--
-- PostgreSQL database dump
--

SET client_encoding = 'UTF8';
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- Name: SCHEMA public; Type: COMMENT; Schema: -; Owner: postgres
--

COMMENT ON SCHEMA public IS 'Standard public schema';


SET search_path = public, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: aliases; Type: TABLE; Schema: public; Owner: evkk; Tablespace: 
--

CREATE TABLE aliases (
    "ID" integer NOT NULL,
    fromword character varying(255),
    "WordID" integer,
    toword character varying(255)
);


ALTER TABLE public.aliases OWNER TO evkk;

--
-- Name: aliidseq; Type: SEQUENCE; Schema: public; Owner: evkk
--

CREATE SEQUENCE aliidseq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.aliidseq OWNER TO evkk;

--
-- Name: aliidseq; Type: SEQUENCE SET; Schema: public; Owner: evkk
--

SELECT pg_catalog.setval('aliidseq', 5, true);


--
-- Name: didseq; Type: SEQUENCE; Schema: public; Owner: evkk
--

CREATE SEQUENCE didseq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.didseq OWNER TO evkk;

--
-- Name: didseq; Type: SEQUENCE SET; Schema: public; Owner: evkk
--

SELECT pg_catalog.setval('didseq', 3759189, true);


--
-- Name: docrefs; Type: TABLE; Schema: public; Owner: evkk; Tablespace: 
--

CREATE TABLE docrefs (
    word character varying(255),
    "DocumentID" character varying(50) NOT NULL,
    "ID" bigint NOT NULL,
    "language" character varying(10),
    wstat integer DEFAULT 0 NOT NULL,
    corpus character varying(25)
);


ALTER TABLE public.docrefs OWNER TO evkk;

--
-- Name: COLUMN docrefs.wstat; Type: COMMENT; Schema: public; Owner: evkk
--

COMMENT ON COLUMN docrefs.wstat IS '0 - not handled
1 - in process
2 - no match
3 - fullmatch (unified, finished)
4 - multimatch (many options, finished)
5 - manual (unified, finished)';


--
-- Name: docfreq; Type: VIEW; Schema: public; Owner: evkk
--

CREATE VIEW docfreq AS
    SELECT docrefs."DocumentID", count(docrefs."DocumentID") AS count FROM docrefs GROUP BY docrefs."DocumentID" ORDER BY count(docrefs."DocumentID") DESC;


ALTER TABLE public.docfreq OWNER TO evkk;

--
-- Name: documents; Type: TABLE; Schema: public; Owner: evkk; Tablespace: 
--

CREATE TABLE documents (
    "DocumentID" character varying(100) NOT NULL,
    title character varying(255),
    corpus character varying(25),
    "language" character varying(10)
);


ALTER TABLE public.documents OWNER TO evkk;

--
-- Name: firstchars; Type: VIEW; Schema: public; Owner: evkk
--

CREATE VIEW firstchars AS
    SELECT DISTINCT substr((docrefs.word)::text, 1, 1) AS "char", count(docrefs.word) AS count FROM docrefs GROUP BY substr((docrefs.word)::text, 1, 1) ORDER BY substr((docrefs.word)::text, 1, 1), count(docrefs.word);


ALTER TABLE public.firstchars OWNER TO evkk;

--
-- Name: undecided; Type: TABLE; Schema: public; Owner: evkk; Tablespace: 
--

CREATE TABLE undecided (
    "ID" integer NOT NULL,
    word character varying(100) NOT NULL,
    "option" character varying(255),
    "language" character varying(4),
    processed boolean DEFAULT false,
    tick boolean
);


ALTER TABLE public.undecided OWNER TO evkk;

--
-- Name: COLUMN undecided.processed; Type: COMMENT; Schema: public; Owner: evkk
--

COMMENT ON COLUMN undecided.processed IS 'is it processed already?';


--
-- Name: COLUMN undecided.tick; Type: COMMENT; Schema: public; Owner: evkk
--

COMMENT ON COLUMN undecided.tick IS 'tick indicates the chosen form of a word. Ticked words will be copied to words table automatically.';


--
-- Name: unidseq; Type: SEQUENCE; Schema: public; Owner: evkk
--

CREATE SEQUENCE unidseq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.unidseq OWNER TO evkk;

--
-- Name: unidseq; Type: SEQUENCE SET; Schema: public; Owner: evkk
--

SELECT pg_catalog.setval('unidseq', 216075, true);


--
-- Name: widseq; Type: SEQUENCE; Schema: public; Owner: evkk
--

CREATE SEQUENCE widseq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.widseq OWNER TO evkk;

--
-- Name: widseq; Type: SEQUENCE SET; Schema: public; Owner: evkk
--

SELECT pg_catalog.setval('widseq', 52318, true);


--
-- Name: words; Type: TABLE; Schema: public; Owner: evkk; Tablespace: 
--

CREATE TABLE words (
    "ID" integer NOT NULL,
    word character varying(255),
    prim character varying(255),
    lemma character varying(255),
    category character varying(10),
    gram character varying(500),
    "language" character varying(4),
    raw character varying(255)
);


ALTER TABLE public.words OWNER TO evkk;

--
-- Name: TABLE words; Type: COMMENT; Schema: public; Owner: evkk
--

COMMENT ON TABLE words IS 'ID          1
word        näitab
freq        123
prim        näita
lemma       näitama
category    !02_AS
gram        (PlG | (SgN
lang        et
raw         aura =aura (SgN >aura !16_S
';


--
-- Data for Name: aliases; Type: TABLE DATA; Schema: public; Owner: evkk
--

COPY aliases ("ID", fromword, "WordID", toword) FROM stdin;
5	1mina	\N	mina
\.


--
-- Data for Name: docrefs; Type: TABLE DATA; Schema: public; Owner: evkk
--

COPY docrefs (word, "DocumentID", "ID", "language", wstat, corpus) FROM stdin;
ma	doc_100636852915_item	2224123	et	3	main
lugesin	doc_100636852915_item	2224124	et	3	main
arvamus	doc_100636852915_item	2224121	et	3	main
suvel	doc_100636852915_item	2224122	et	3	main
läbi	doc_100636852915_item	2224125	et	4	main
kus	doc_100636852915_item	2224127	et	3	main
ajalehe	doc_100636852915_item	2224126	et	3	main
oli	doc_100636852915_item	2224128	et	3	main
väga	doc_100636852915_item	2224129	et	3	main
huvitav	doc_100636852915_item	2224130	et	4	main
artikkel	doc_100636852915_item	2224131	et	3	main
ühest	doc_100636852915_item	2224132	et	4	main
koolist	doc_100636852915_item	2224133	et	4	main
võru	doc_100636852915_item	2224136	et	4	main
alevikust	doc_100636852915_item	2224135	et	4	main
väikesest	doc_100636852915_item	2224134	et	4	main
juures	doc_100636852915_item	2224137	et	4	main
sõmerpalust	doc_100636852915_item	2224138	et	4	main
selles	doc_100636852915_item	2224139	et	4	main
koolis	doc_100636852915_item	2224140	et	4	main
on	doc_100636852915_item	2224141	et	4	main
väga	doc_100636852915_item	2224142	et	3	main
sõbralik	doc_100636852915_item	2224143	et	3	main
ja	doc_100636852915_item	2224144	et	3	main
tähelepanelik	doc_100636852915_item	2224145	et	4	main
kollektiiv	doc_100636852915_item	2224146	et	3	main
viis	doc_100636852915_item	2224147	et	4	main
aastat	doc_100636852915_item	2224148	et	3	main
tagasi	doc_100636852915_item	2224149	et	3	main
raske	doc_100636852915_item	2224161	et	4	main
tegema	doc_100636852915_item	2224167	et	3	main
kuuma	doc_100636852915_item	2224170	et	4	main
ja	doc_100636852915_item	2224176	et	3	main
toa	doc_100636852915_item	2224189	et	3	main
kasvavad	doc_100636852915_item	2224191	et	4	main
aga	doc_100636852915_item	2224198	et	3	main
seisavad	doc_100636852915_item	2224201	et	3	main
veel	doc_100636852915_item	2224209	et	4	main
seal	doc_100636852915_item	2224213	et	4	main
püüton	doc_100636852915_item	2224218	et	3	main
vett	doc_100636852915_item	2224229	et	3	main
õpilased	doc_100636852915_item	2224235	et	3	main
viima	doc_100636852915_item	2224237	et	3	main
ta	doc_100636852915_item	2224248	et	4	main
vastuvad	doc_100636852915_item	2224254	et	4	main
koolis	doc_100636852915_item	2224256	et	4	main
on	doc_100636852915_item	2224261	et	4	main
see	doc_100636852915_item	2224267	et	3	main
sest	doc_100636852915_item	2224269	et	4	main
kus	doc_100636852915_item	2224276	et	3	main
luua	doc_100636852915_item	2224286	et	4	main
minu	doc_100636852916_item	2224320	et	3	main
sõbrad	doc_100636852916_item	2224321	et	3	main
sa	doc_100636852916_item	2224349	et	3	main
reisid	doc_100636852916_item	2224350	et	4	main
rigisse	doc_100636852916_item	2224352	et	4	main
lossi	doc_100636852916_item	2224357	et	4	main
varemetes	doc_100636852916_item	2224360	et	4	main
teisel	doc_100636852916_item	2224362	et	4	main
loojangut	doc_100636852916_item	2224370	et	3	main
mere	doc_100636852916_item	2224372	et	3	main
arvuti	doc_100636852917_item	2224416	et	4	main
ja	doc_100636852917_item	2224418	et	3	main
igasugulased	doc_100636852917_item	2224420	et	3	main
kui	doc_100636852917_item	2224426	et	3	main
arvutipood	doc_100636852917_item	2224434	et	3	main
sellest	doc_100636852917_item	2224437	et	4	main
ma	doc_100636852917_item	2224439	et	3	main
et	doc_100636852917_item	2224442	et	3	main
arvutipood	doc_100636852917_item	2224444	et	3	main
kes	doc_100636852917_item	2224452	et	4	main
aga	doc_100636852917_item	2224455	et	3	main
õpilasele	doc_100636852917_item	2224457	et	3	main
kuni	doc_100636852917_item	2224462	et	3	main
1	doc_100636852917_item	2224478	et	2	main
huvitatud	doc_100636852917_item	2224486	et	4	main
infot	doc_100636852917_item	2224494	et	3	main
netis	doc_100636852917_item	2224496	et	4	main
arvan	doc_100636852917_item	2224499	et	3	main
see	doc_100636852917_item	2224501	et	3	main
kasulik	doc_100636852917_item	2224505	et	3	main
oma	doc_100636852917_item	2224512	et	4	main
osta	doc_100636852917_item	2224518	et	4	main
arvuti	doc_100636852917_item	2224523	et	4	main
eksamitöö	doc_1010138197_item	2224524	et	4	main
i	doc_1010138197_item	2224525	et	4	main
sõnad	doc_1010138197_item	2224529	et	4	main
nägema	doc_1010138197_item	2224538	et	3	main
siberisse	doc_1010138197_item	2224545	et	4	main
külas	doc_1010138197_item	2224548	et	3	main
konkurss	doc_1010138197_item	2224555	et	3	main
nüüd	doc_1010138197_item	2224559	et	4	main
üle	doc_1010138197_item	2224561	et	3	main
eestlastele	doc_1010138197_item	2224565	et	4	main
oodatud	doc_1010138197_item	2224580	et	4	main
kartul	doc_1010138197_item	2224641	et	3	main
räägivad	doc_1010138197_item	2224650	et	3	main
kuidagi	doc_1010138197_item	2224651	et	3	main
mahlakalt	doc_1010138197_item	2224658	et	4	main
nagu	doc_1010138197_item	2224664	et	3	main
kool	doc_1010138197_item	2224672	et	4	main
mulle	doc_1010138197_item	2224712	et	4	main
tooma	doc_1010138197_item	2224714	et	3	main
talvepuud	doc_1010138197_item	2224716	et	4	main
on	doc_1010138197_item	2224718	et	4	main
kooliõpilased	doc_100636852915_item	2224150	et	3	main
õpetajad	doc_100636852915_item	2224152	et	4	main
sest	doc_100636852915_item	2224163	et	4	main
ise	doc_100636852915_item	2224165	et	4	main
ruumis	doc_100636852915_item	2224173	et	4	main
oliks	doc_100636852915_item	2224180	et	4	main
ja	doc_100636852915_item	2224182	et	3	main
väga	doc_100636852915_item	2224186	et	3	main
erinevad	doc_100636852915_item	2224192	et	4	main
taimid	doc_100636852915_item	2224194	et	3	main
ilusad	doc_100636852915_item	2224196	et	3	main
kus	doc_100636852915_item	2224204	et	3	main
papagoid	doc_100636852915_item	2224206	et	4	main
puur	doc_100636852915_item	2224212	et	3	main
tiigri	doc_100636852915_item	2224217	et	3	main
üks	doc_100636852915_item	2224219	et	3	main
ja	doc_100636852915_item	2224151	et	3	main
koos	doc_100636852915_item	2224153	et	4	main
tegid	doc_100636852915_item	2224154	et	4	main
väikeses	doc_100636852915_item	2224155	et	4	main
toad	doc_100636852915_item	2224156	et	3	main
nad	doc_100636852915_item	2224164	et	3	main
pidid	doc_100636852915_item	2224166	et	4	main
suuri	doc_100636852915_item	2224168	et	3	main
et	doc_100636852915_item	2224172	et	3	main
oleks	doc_100636852915_item	2224174	et	3	main
soe	doc_100636852915_item	2224175	et	4	main
hiiglasuuri	doc_100636852915_item	2224177	et	3	main
et	doc_100636852915_item	2224179	et	3	main
on	doc_100636852915_item	2224185	et	4	main
ilus	doc_100636852915_item	2224187	et	4	main
puurid	doc_100636852915_item	2224203	et	4	main
suur	doc_100636852915_item	2224211	et	3	main
madu	doc_100636852915_item	2224215	et	4	main
kui	doc_100636852915_item	2224222	et	3	main
sõmerpalus	doc_100636852915_item	2224223	et	4	main
ei	doc_100636852915_item	2224224	et	4	main
veega	doc_100636852915_item	2224242	et	3	main
sojendama	doc_100636852915_item	2224244	et	4	main
ei	doc_100636852915_item	2224249	et	4	main
see	doc_100636852915_item	2224251	et	3	main
kollektiiv	doc_100636852915_item	2224260	et	3	main
nagu	doc_100636852915_item	2224262	et	3	main
pere	doc_100636852915_item	2224264	et	4	main
meeldib	doc_100636852915_item	2224266	et	3	main
ma	doc_100636852915_item	2224270	et	3	main
et	doc_100636852915_item	2224273	et	3	main
elu	doc_100636852915_item	2224283	et	4	main
katsuvad	doc_100636852915_item	2224285	et	4	main
et	doc_100636852916_item	2224328	et	3	main
aga	doc_100636852916_item	2224334	et	3	main
romaantika	doc_100636852916_item	2224335	et	4	main
igaühe	doc_100636852916_item	2224337	et	4	main
reis	doc_100636852916_item	2224345	et	4	main
romantiline	doc_100636852916_item	2224347	et	3	main
kus	doc_100636852916_item	2224353	et	3	main
hulkuda	doc_100636852916_item	2224355	et	3	main
linna	doc_100636852916_item	2224359	et	4	main
aga	doc_100636852916_item	2224361	et	3	main
meeldib	doc_100636852916_item	2224364	et	3	main
päikese	doc_100636852916_item	2224369	et	4	main
jalutada	doc_100636852916_item	2224371	et	3	main
reklaamiga	doc_100636852917_item	2224410	et	4	main
oli	doc_100636852917_item	2224412	et	3	main
printer	doc_100636852917_item	2224417	et	3	main
töötab	doc_100636852917_item	2224428	et	3	main
reklaamil	doc_100636852917_item	2224430	et	3	main
mikromaailm	doc_100636852917_item	2224445	et	3	main
ostavad	doc_100636852917_item	2224453	et	3	main
õpetajale	doc_100636852917_item	2224456	et	4	main
ja	doc_100636852917_item	2224458	et	3	main
on	doc_100636852917_item	2224460	et	4	main
35-60-245	doc_100636852917_item	2224481	et	4	main
teada	doc_100636852917_item	2224491	et	3	main
et	doc_100636852917_item	2224500	et	3	main
reklaam	doc_100636852917_item	2224502	et	3	main
kes	doc_100636852917_item	2224507	et	4	main
teha	doc_100636852917_item	2224509	et	3	main
kallist	doc_100636852917_item	2224520	et	4	main
sulgudes	doc_1010138197_item	2224527	et	4	main
nägi	doc_1010138197_item	2224539	et	3	main
kuulutus	doc_1010138197_item	2224542	et	4	main
eesti	doc_1010138197_item	2224550	et	4	main
kinnitusel	doc_1010138197_item	2224572	et	4	main
ta	doc_1010138197_item	2224574	et	4	main
jõuda	doc_1010138197_item	2224577	et	3	main
on	doc_1010138197_item	2224579	et	4	main
üsna	doc_1010138197_item	2224582	et	3	main
kool	doc_1010138197_item	2224622	et	4	main
algama	doc_1010138197_item	2224624	et	3	main
võtma	doc_1010138197_item	2224628	et	3	main
tähtis	doc_1010138197_item	2224636	et	4	main
ettevõtmine	doc_1010138197_item	2224638	et	3	main
õppimine	doc_1010138197_item	2224644	et	4	main
hoog	doc_1010138197_item	2224647	et	3	main
ja	doc_1010138197_item	2224657	et	3	main
mitte	doc_1010138197_item	2224659	et	3	main
vaid	doc_1010138197_item	2224663	et	3	main
mõni	doc_1010138197_item	2224665	et	3	main
koolikeskuses	doc_100636852915_item	2224157	et	4	main
see	doc_100636852915_item	2224159	et	3	main
toru	doc_100636852915_item	2224169	et	4	main
veega	doc_100636852915_item	2224171	et	3	main
valgus	doc_100636852915_item	2224181	et	4	main
nüüd	doc_100636852915_item	2224183	et	4	main
keskel	doc_100636852915_item	2224190	et	3	main
piki	doc_100636852915_item	2224199	et	4	main
seima	doc_100636852915_item	2224200	et	4	main
elavad	doc_100636852915_item	2224205	et	4	main
seisab	doc_100636852915_item	2224208	et	3	main
elab	doc_100636852915_item	2224214	et	3	main
kord	doc_100636852915_item	2224220	et	4	main
talvel	doc_100636852915_item	2224221	et	4	main
elektrit	doc_100636852915_item	2224226	et	3	main
õpetajad	doc_100636852915_item	2224233	et	4	main
pidid	doc_100636852915_item	2224236	et	4	main
kooli	doc_100636852915_item	2224238	et	4	main
pudeleid	doc_100636852915_item	2224240	et	3	main
nendega	doc_100636852915_item	2224245	et	4	main
sureks	doc_100636852915_item	2224250	et	3	main
näitab	doc_100636852915_item	2224252	et	3	main
ja	doc_100636852915_item	2224258	et	3	main
atikkel	doc_100636852915_item	2224268	et	4	main
väikeses	doc_100636852915_item	2224274	et	4	main
tean	doc_100636852915_item	2224279	et	3	main
talveaeda	doc_100636852915_item	2224158	et	4	main
oli	doc_100636852915_item	2224160	et	3	main
töö	doc_100636852915_item	2224162	et	4	main
lampe	doc_100636852915_item	2224178	et	3	main
see	doc_100636852915_item	2224184	et	3	main
koht	doc_100636852915_item	2224188	et	3	main
troopilised	doc_100636852915_item	2224193	et	3	main
õitsevad	doc_100636852915_item	2224195	et	4	main
lilled	doc_100636852915_item	2224197	et	3	main
suured	doc_100636852915_item	2224202	et	3	main
nurgas	doc_100636852915_item	2224207	et	3	main
üks	doc_100636852915_item	2224210	et	3	main
suur	doc_100636852915_item	2224216	et	3	main
sooja	doc_100636852915_item	2224228	et	4	main
6	doc_100636852915_item	2224231	et	2	main
ja	doc_100636852915_item	2224234	et	3	main
sooja	doc_100636852915_item	2224241	et	4	main
õpilased	doc_100636852915_item	2224255	et	3	main
kooli	doc_100636852915_item	2224259	et	4	main
sain	doc_100636852915_item	2224271	et	3	main
ma	doc_100636852915_item	2224278	et	3	main
on	doc_100636852915_item	2224280	et	4	main
raske	doc_100636852915_item	2224282	et	4	main
klassis	doc_100636852916_item	2224323	et	3	main
me	doc_100636852916_item	2224324	et	4	main
võib	doc_100636852916_item	2224326	et	3	main
iga	doc_100636852916_item	2224329	et	4	main
on	doc_100636852916_item	2224331	et	4	main
romantika	doc_100636852916_item	2224333	et	4	main
on	doc_100636852916_item	2224336	et	4	main
jaoks	doc_100636852916_item	2224338	et	4	main
inimesed	doc_100636852916_item	2224342	et	3	main
et	doc_100636852916_item	2224344	et	3	main
võid	doc_100636852916_item	2224354	et	4	main
inimesele	doc_100636852916_item	2224363	et	3	main
reisida	doc_100636852916_item	2224365	et	3	main
inimesega	doc_100636852916_item	2224367	et	3	main
kaldal	doc_100636852916_item	2224373	et	3	main
igal	doc_100636852916_item	2224375	et	3	main
kaasaegne	doc_100636852917_item	2224415	et	3	main
oli	doc_100636852915_item	2224225	et	3	main
ja	doc_100636852915_item	2224227	et	3	main
5	doc_100636852915_item	2224230	et	2	main
päevat	doc_100636852915_item	2224232	et	4	main
kodust	doc_100636852915_item	2224239	et	4	main
ja	doc_100636852915_item	2224243	et	3	main
madu	doc_100636852915_item	2224246	et	4	main
et	doc_100636852915_item	2224247	et	3	main
kui	doc_100636852915_item	2224253	et	3	main
on	doc_100636852915_item	2224257	et	4	main
suur	doc_100636852915_item	2224263	et	3	main
mulle	doc_100636852915_item	2224265	et	4	main
teada	doc_100636852915_item	2224272	et	3	main
linnas	doc_100636852915_item	2224275	et	4	main
kui	doc_100636852915_item	2224277	et	3	main
väga	doc_100636852915_item	2224281	et	3	main
inimesed	doc_100636852915_item	2224284	et	3	main
midagi	doc_100636852915_item	2224287	et	4	main
meeldiv	doc_100636852915_item	2224288	et	4	main
ja	doc_100636852915_item	2224289	et	3	main
hea	doc_100636852915_item	2224290	et	4	main
nende	doc_100636852915_item	2224291	et	4	main
jaoks	doc_100636852915_item	2224292	et	4	main
et	doc_100636852915_item	2224293	et	3	main
oleks	doc_100636852915_item	2224294	et	3	main
natukene	doc_100636852915_item	2224295	et	4	main
rõmsaks	doc_100636852915_item	2224296	et	4	main
arvamus	doc_100636852916_item	2224297	et	3	main
ma	doc_100636852916_item	2224298	et	3	main
küsitlesin	doc_100636852916_item	2224299	et	3	main
4	doc_100636852916_item	2224300	et	2	main
inimest	doc_100636852916_item	2224301	et	3	main
meie	doc_100636852916_item	2224302	et	4	main
klassist	doc_100636852916_item	2224303	et	3	main
2	doc_100636852916_item	2224304	et	2	main
tüdrukut	doc_100636852916_item	2224305	et	3	main
ja	doc_100636852916_item	2224306	et	3	main
2	doc_100636852916_item	2224307	et	2	main
poissi	doc_100636852916_item	2224308	et	4	main
elja	doc_100636852916_item	2224309	et	4	main
sveta	doc_100636852916_item	2224310	et	4	main
anton	doc_100636852916_item	2224311	et	4	main
ja	doc_100636852916_item	2224312	et	3	main
misha	doc_100636852916_item	2224313	et	4	main
ma	doc_100636852916_item	2224314	et	3	main
valisin	doc_100636852916_item	2224315	et	3	main
neid	doc_100636852916_item	2224316	et	4	main
sest	doc_100636852916_item	2224317	et	4	main
nad	doc_100636852916_item	2224318	et	3	main
on	doc_100636852916_item	2224319	et	4	main
ja	doc_100636852916_item	2224322	et	3	main
istume	doc_100636852916_item	2224325	et	3	main
olla	doc_100636852916_item	2224327	et	3	main
reis	doc_100636852916_item	2224330	et	4	main
omamoodi	doc_100636852916_item	2224332	et	3	main
oma	doc_100636852916_item	2224339	et	4	main
mõned	doc_100636852916_item	2224341	et	3	main
arvavad	doc_100636852916_item	2224343	et	4	main
on	doc_100636852916_item	2224346	et	4	main
eksootilises	doc_100636852916_item	2224351	et	3	main
armastatud	doc_100636852916_item	2224366	et	4	main
vaadata	doc_100636852916_item	2224368	et	4	main
plakatit	doc_100636852917_item	2224409	et	3	main
ilus	doc_100636852917_item	2224414	et	4	main
veel	doc_100636852917_item	2224419	et	4	main
millised	doc_100636852917_item	2224422	et	3	main
kasuliku	doc_100636852917_item	2224425	et	3	main
sa	doc_100636852917_item	2224427	et	3	main
pealkiri	doc_100636852917_item	2224433	et	3	main
mikromaailm	doc_100636852917_item	2224435	et	3	main
arvutikeskuses	doc_100636852917_item	2224443	et	4	main
ülikooliõpilasele	doc_100636852917_item	2224459	et	3	main
kontakttelefon	doc_100636852917_item	2224479	et	3	main
need	doc_100636852917_item	2224483	et	3	main
on	doc_100636852917_item	2224485	et	4	main
leida	doc_100636852917_item	2224493	et	3	main
inter	doc_100636852917_item	2224495	et	3	main
wwwmikromaailmee	doc_100636852917_item	2224497	et	4	main
ma	doc_100636852917_item	2224498	et	3	main
inimestele	doc_100636852917_item	2224506	et	3	main
jõulukingitust	doc_100636852917_item	2224511	et	4	main
perele	doc_100636852917_item	2224513	et	3	main
kellel	doc_100636852917_item	2224515	et	4	main
võimalus	doc_100636852917_item	2224517	et	3	main
midagi	doc_100636852917_item	2224519	et	4	main
nagu	doc_100636852917_item	2224521	et	3	main
naine	doc_1010138197_item	2224536	et	3	main
küla	doc_1010138197_item	2224547	et	4	main
otsitakse	doc_1010138197_item	2224549	et	3	main
tundis	doc_1010138197_item	2224573	et	3	main
jõudma	doc_1010138197_item	2224576	et	3	main
et	doc_1010138197_item	2224578	et	3	main
olin	doc_1010138197_item	2224581	et	3	main
üllatuma	doc_1010138197_item	2224583	et	3	main
kui	doc_1010138197_item	2224585	et	3	main
polnud	doc_1010138197_item	2224621	et	3	main
kogu	doc_1010138197_item	2224626	et	4	main
kartulivõtt	doc_1010138197_item	2224631	et	3	main
kõige	doc_1010138197_item	2224635	et	4	main
ja	doc_1010138197_item	2224654	et	3	main
mõnusalt	doc_1010138197_item	2224656	et	4	main
vene	doc_1010138197_item	2224660	et	4	main
aktsentiga	doc_1010138197_item	2224662	et	4	main
venemaa	doc_1010138197_item	2224671	et	4	main
õpetatakse	doc_1010138197_item	2224677	et	3	main
ööd	doc_1010138197_item	2224724	et	4	main
ahju	doc_1010138197_item	2224732	et	4	main
kui	doc_1010138197_item	2224735	et	3	main
ostan	doc_1010138197_item	2224737	et	3	main
vildid	doc_1010138197_item	2224740	et	4	main
seal	doc_1010138197_item	2224742	et	4	main
talveks	doc_1010138197_item	2224748	et	4	main
vapralt	doc_1010138197_item	2224752	et	4	main
kasutades	doc_1010138197_item	2224766	et	3	main
ja	doc_1010138197_item	2224773	et	3	main
naeratus	doc_1010138197_item	2224778	et	4	main
naisi	doc_1010138197_item	2224780	et	3	main
ja	doc_1010138197_item	2224784	et	3	main
kaunim	doc_1010138197_item	2224786	et	4	main
kogus	doc_1010138197_item	2224789	et	4	main
panema	doc_1010138197_item	2224791	et	3	main
lisakoormus	doc_1010138197_item	2224795	et	3	main
tooma	doc_1010138197_item	2224797	et	3	main
aga	doc_1010138197_item	2224806	et	3	main
saama	doc_1010138197_item	2224834	et	4	main
maagiline	doc_1010138197_item	2224836	et	4	main
et	doc_1010138197_item	2224838	et	3	main
abil	doc_1010138197_item	2224840	et	4	main
ja	doc_1010138197_item	2224843	et	3	main
selle	doc_1010138197_item	2224852	et	4	main
saab	doc_1010138197_item	2224854	et	3	main
ja	doc_1010138197_item	2224857	et	3	main
nägu	doc_100636852916_item	2224340	et	4	main
kui	doc_100636852916_item	2224348	et	3	main
iidse	doc_100636852916_item	2224356	et	3	main
või	doc_100636852916_item	2224358	et	4	main
mitte	doc_100636852916_item	2224374	et	3	main
reisil	doc_100636852916_item	2224376	et	3	main
on	doc_100636852916_item	2224377	et	4	main
niisuguned	doc_100636852916_item	2224378	et	4	main
võimalused	doc_100636852916_item	2224379	et	3	main
kokkuvõttes	doc_100636852916_item	2224380	et	3	main
võiks	doc_100636852916_item	2224381	et	4	main
öelda	doc_100636852916_item	2224382	et	4	main
et	doc_100636852916_item	2224383	et	3	main
võivad	doc_100636852916_item	2224385	et	4	main
reisid	doc_100636852916_item	2224384	et	4	main
pakuda	doc_100636852916_item	2224386	et	4	main
inimesel	doc_100636852916_item	2224387	et	3	main
uusi	doc_100636852916_item	2224388	et	3	main
elamusi	doc_100636852916_item	2224389	et	3	main
ja	doc_100636852916_item	2224390	et	3	main
omamoodi	doc_100636852916_item	2224391	et	3	main
romantika	doc_100636852916_item	2224392	et	4	main
aga	doc_100636852916_item	2224393	et	3	main
mitte	doc_100636852916_item	2224394	et	3	main
iga	doc_100636852916_item	2224395	et	4	main
reisi	doc_100636852916_item	2224396	et	4	main
arvamus	doc_100636852917_item	2224397	et	3	main
esmaspäeval	doc_100636852917_item	2224398	et	3	main
kui	doc_100636852917_item	2224399	et	3	main
ma	doc_100636852917_item	2224400	et	3	main
läksin	doc_100636852917_item	2224401	et	3	main
koolist	doc_100636852917_item	2224402	et	4	main
kodusse	doc_100636852917_item	2224403	et	3	main
nägin	doc_100636852917_item	2224404	et	3	main
ühe	doc_100636852917_item	2224405	et	4	main
kauplus	doc_100636852917_item	2224406	et	3	main
aknal	doc_100636852917_item	2224407	et	3	main
suurt	doc_100636852917_item	2224408	et	3	main
plakatil	doc_100636852917_item	2224411	et	3	main
kujutatud	doc_100636852917_item	2224413	et	4	main
asjad	doc_100636852917_item	2224421	et	3	main
oli	doc_100636852917_item	2224431	et	3	main
suur	doc_100636852917_item	2224432	et	3	main
reklaamist	doc_100636852917_item	2224438	et	4	main
teada	doc_100636852917_item	2224441	et	3	main
on	doc_100636852917_item	2224447	et	4	main
kingitusi	doc_100636852917_item	2224450	et	4	main
arvuti	doc_100636852917_item	2224454	et	4	main
soodustused	doc_100636852917_item	2224461	et	4	main
on	doc_100636852917_item	2224480	et	4	main
aga	doc_100636852917_item	2224482	et	3	main
reklaamist	doc_100636852917_item	2224487	et	4	main
ja	doc_100636852917_item	2224488	et	3	main
rohkem	doc_100636852917_item	2224490	et	4	main
väga	doc_100636852917_item	2224504	et	3	main
ja	doc_100636852917_item	2224514	et	3	main
on	doc_100636852917_item	2224516	et	4	main
on	doc_100636852917_item	2224423	et	4	main
väga	doc_100636852917_item	2224424	et	3	main
arvutiga	doc_100636852917_item	2224429	et	4	main
ja	doc_100636852917_item	2224436	et	3	main
sain	doc_100636852917_item	2224440	et	3	main
talvel	doc_100636852917_item	2224446	et	4	main
palju	doc_100636852917_item	2224448	et	4	main
jõulu	doc_100636852917_item	2224449	et	4	main
inimestele	doc_100636852917_item	2224451	et	3	main
10	doc_100636852917_item	2224463	et	2	main
ka	doc_100636852917_item	2224464	et	3	main
sul	doc_100636852917_item	2224465	et	3	main
on	doc_100636852917_item	2224466	et	4	main
võiimalus	doc_100636852917_item	2224467	et	4	main
osta	doc_100636852917_item	2224468	et	4	main
arvuti	doc_100636852917_item	2224469	et	4	main
krediiti	doc_100636852917_item	2224470	et	4	main
kaheks	doc_100636852917_item	2224471	et	4	main
see	doc_100636852917_item	2224473	et	3	main
aastaks	doc_100636852917_item	2224472	et	4	main
pood	doc_100636852917_item	2224474	et	4	main
asub	doc_100636852917_item	2224475	et	3	main
narvas	doc_100636852917_item	2224476	et	4	main
energia	doc_100636852917_item	2224477	et	4	main
kes	doc_100636852917_item	2224484	et	4	main
tahavad	doc_100636852917_item	2224489	et	3	main
võivad	doc_100636852917_item	2224492	et	4	main
on	doc_100636852917_item	2224503	et	4	main
tähavad	doc_100636852917_item	2224508	et	4	main
hea	doc_100636852917_item	2224510	et	4	main
olevad	doc_1010138197_item	2224528	et	4	main
õigesse	doc_1010138197_item	2224530	et	3	main
piret	doc_1010138197_item	2224532	et	4	main
toomet	doc_1010138197_item	2224533	et	4	main
ettevõtlik	doc_1010138197_item	2224535	et	3	main
suvel	doc_1010138197_item	2224537	et	3	main
ajalehes	doc_1010138197_item	2224541	et	3	main
kuulutuse	doc_1010138197_item	2224543	et	4	main
et	doc_1010138197_item	2224544	et	3	main
keele	doc_1010138197_item	2224551	et	4	main
piret	doc_1010138197_item	2224553	et	4	main
on	doc_1010138197_item	2224558	et	4	main
juba	doc_1010138197_item	2224560	et	3	main
nädal	doc_1010138197_item	2224562	et	3	main
väikestele	doc_1010138197_item	2224564	et	4	main
need	doc_1010138197_item	2224566	et	3	main
neid	doc_1010138197_item	2224567	et	4	main
õpetama	doc_1010138197_item	2224569	et	3	main
pireti	doc_1010138197_item	2224571	et	4	main
uus	doc_100636852917_item	2224522	et	3	main
pange	doc_1010138197_item	2224526	et	4	main
vormi	doc_1010138197_item	2224531	et	4	main
on	doc_1010138197_item	2224534	et	4	main
ta	doc_1010138197_item	2224540	et	4	main
ülem-suetuki	doc_1010138197_item	2224546	et	4	main
õpetajat	doc_1010138197_item	2224552	et	4	main
võitis	doc_1010138197_item	2224554	et	3	main
konkurssi	doc_1010138197_item	2224556	et	4	main
ja	doc_1010138197_item	2224557	et	3	main
nädalat	doc_1010138197_item	2224563	et	3	main
emakeelt	doc_1010138197_item	2224568	et	4	main
õpetab	doc_1010138197_item	2224570	et	3	main
siberisse	doc_1010138197_item	2224575	et	4	main
üllatunud	doc_1010138197_item	2224584	et	4	main
mulle	doc_1010138197_item	2224586	et	4	main
tulema	doc_1010138197_item	2224587	et	4	main
tuli	doc_1010138197_item	2224588	et	4	main
vastu	doc_1010138197_item	2224589	et	3	main
korralik	doc_1010138197_item	2224590	et	3	main
korraliku	doc_1010138197_item	2224591	et	3	main
audiga	doc_1010138197_item	2224592	et	3	main
mulle	doc_1010138197_item	2224593	et	4	main
maaliti	doc_1010138197_item	2224594	et	3	main
siber	doc_1010138197_item	2224595	et	4	main
siberi	doc_1010138197_item	2224596	et	4	main
selline	doc_1010138197_item	2224597	et	4	main
pilt	doc_1010138197_item	2224598	et	3	main
et	doc_1010138197_item	2224599	et	3	main
seal	doc_1010138197_item	2224600	et	4	main
ei	doc_1010138197_item	2224601	et	4	main
lendama	doc_1010138197_item	2224602	et	3	main
lenda	doc_1010138197_item	2224603	et	4	main
lind	doc_1010138197_item	2224604	et	3	main
ega	doc_1010138197_item	2224605	et	3	main
kasva	doc_1010138197_item	2224606	et	4	main
rohi	doc_1010138197_item	2224607	et	4	main
kui	doc_1010138197_item	2224608	et	3	main
noor	doc_1010138197_item	2224609	et	3	main
ja	doc_1010138197_item	2224610	et	3	main
tahtmine	doc_1010138197_item	2224611	et	4	main
tahtmise	doc_1010138197_item	2224612	et	4	main
täis	doc_1010138197_item	2224613	et	4	main
piret	doc_1010138197_item	2224614	et	4	main
pärast	doc_1010138197_item	2224615	et	4	main
õppeaasta	doc_1010138197_item	2224616	et	4	main
algust	doc_1010138197_item	2224617	et	4	main
koht	doc_1010138197_item	2224618	et	3	main
kohale	doc_1010138197_item	2224619	et	4	main
jõudis	doc_1010138197_item	2224620	et	3	main
alganud	doc_1010138197_item	2224625	et	4	main
küla	doc_1010138197_item	2224627	et	4	main
kartuleid	doc_1010138197_item	2224630	et	3	main
on	doc_1010138197_item	2224632	et	4	main
sügisel	doc_1010138197_item	2224634	et	3	main
on	doc_1010138197_item	2224640	et	4	main
salv	doc_1010138197_item	2224642	et	3	main
ja	doc_1010138197_item	2224643	et	3	main
käib	doc_1010138197_item	2224645	et	3	main
täie	doc_1010138197_item	2224646	et	3	main
siinsed	doc_1010138197_item	2224648	et	3	main
mõnus	doc_1010138197_item	2224653	et	4	main
aktsent	doc_1010138197_item	2224661	et	3	main
murret	doc_1010138197_item	2224667	et	4	main
on	doc_1010138197_item	2224669	et	4	main
aine	doc_1010138197_item	2224675	et	4	main
elab	doc_1010138197_item	2224681	et	3	main
veidi	doc_1010138197_item	2224682	et	3	main
üle	doc_1010138197_item	2224683	et	3	main
kolmsada	doc_1010138197_item	2224684	et	4	main
kolmesaja	doc_1010138197_item	2224685	et	4	main
inimene	doc_1010138197_item	2224686	et	3	main
inimest	doc_1010138197_item	2224687	et	3	main
emakeelt	doc_1010138197_item	2224688	et	4	main
saab	doc_1010138197_item	2224689	et	3	main
kõik	doc_1010138197_item	2224690	et	4	main
rääkida	doc_1010138197_item	2224692	et	3	main
kõike	doc_1010138197_item	2224691	et	4	main
pireti	doc_1010138197_item	2224693	et	4	main
sõnul	doc_1010138197_item	2224694	et	3	main
õpivad	doc_1010138197_item	2224695	et	3	main
lapsed	doc_1010138197_item	2224696	et	3	main
raamatud	doc_1010138197_item	2224698	et	4	main
poolpõlenud	doc_1010138197_item	2224697	et	4	main
raamatuid	doc_1010138197_item	2224699	et	3	main
varsti	doc_1010138197_item	2224700	et	3	main
saatma	doc_1010138197_item	2224701	et	3	main
saatatakse	doc_1010138197_item	2224702	et	4	main
eestist	doc_1010138197_item	2224703	et	3	main
uued	doc_1010138197_item	2224704	et	3	main
õpikud	doc_1010138197_item	2224705	et	3	main
siberi	doc_1010138197_item	2224706	et	4	main
talve	doc_1010138197_item	2224707	et	4	main
piret	doc_1010138197_item	2224708	et	4	main
ei	doc_1010138197_item	2224709	et	4	main
veel	doc_1010138197_item	2224623	et	4	main
võttis	doc_1010138197_item	2224629	et	3	main
siin	doc_1010138197_item	2224633	et	4	main
tähtsam	doc_1010138197_item	2224637	et	4	main
tänaseks	doc_1010138197_item	2224639	et	4	main
eestlased	doc_1010138197_item	2224649	et	3	main
teistmoodi	doc_1010138197_item	2224652	et	3	main
mahlakas	doc_1010138197_item	2224655	et	4	main
mõnet	doc_1010138197_item	2224666	et	4	main
ja	doc_1010138197_item	2224673	et	3	main
vene	doc_1010138197_item	2224678	et	4	main
külas	doc_1010138197_item	2224680	et	3	main
karda	doc_1010138197_item	2224711	et	4	main
juba	doc_1010138197_item	2224713	et	3	main
tooti	doc_1010138197_item	2224715	et	4	main
praegu	doc_1010138197_item	2224717	et	3	main
harjutan	doc_1010138197_item	2224728	et	3	main
suure	doc_1010138197_item	2224730	et	3	main
ega	doc_1010138197_item	2224741	et	3	main
naerab	doc_1010138197_item	2224747	et	3	main
valmistuma	doc_1010138197_item	2224749	et	3	main
piret	doc_1010138197_item	2224751	et	4	main
iii	doc_1010138197_item	2224756	et	4	main
etteantud	doc_1010138197_item	2224758	et	4	main
pannes	doc_1010138197_item	2224761	et	4	main
vormi	doc_1010138197_item	2224764	et	4	main
2	doc_1010138197_item	2224768	et	2	main
naiselikum	doc_1010138197_item	2224772	et	4	main
mehed	doc_1010138197_item	2224774	et	3	main
igaükse	doc_1010138197_item	2224785	et	3	main
võima	doc_1010138197_item	2224796	et	3	main
kogus	doc_1010138197_item	2224801	et	4	main
sportima	doc_1010138197_item	2224821	et	4	main
puhkama	doc_1010138197_item	2224823	et	3	main
tohi	doc_1010138197_item	2224825	et	4	main
tekkida	doc_1010138197_item	2224829	et	3	main
olema	doc_1010138197_item	2224832	et	4	main
lausa	doc_1010138197_item	2224841	et	4	main
tänapaeval	doc_1010138197_item	2224845	et	4	main
nii	doc_1010138197_item	2224848	et	3	main
hingata	doc_1010138197_item	2224858	et	4	main
ka	doc_1010138197_item	2224863	et	3	main
söömine	doc_1010138197_item	2224871	et	4	main
pahandab	doc_1010138197_item	2224872	et	3	main
telesaade	doc_1010138197_item	2224874	et	4	main
aeg	doc_1010138197_item	2224876	et	3	main
katkestab	doc_1010138197_item	2224879	et	3	main
varahommiku	doc_1010138197_item	2224881	et	3	main
ma	doc_1010138197_item	2224925	et	3	main
sa	doc_1010138197_item	2224928	et	3	main
sportiga	doc_1010138197_item	2224931	et	4	main
huvi	doc_1010138197_item	2224935	et	4	main
ilusad	doc_1010138197_item	2224937	et	3	main
difteeriaga	doc_1010138197_item	2224953	et	3	main
uus	doc_1010138197_item	2224956	et	3	main
7	doc_1010138197_item	2224970	et	2	main
kuulub	doc_1010138197_item	2224973	et	3	main
pükstele	doc_1010138197_item	2224982	et	3	main
külmetamine	doc_1010138197_item	2224988	et	4	main
tunnen	doc_1010138197_item	2224992	et	3	main
täitke	doc_1010138197_item	2224999	et	3	main
sobivate	doc_1010138197_item	2225001	et	4	main
kolmekäigulise	doc_1010138197_item	2225005	et	4	main
maksis	doc_1010138197_item	2225009	et	4	main
kohal	doc_1010138197_item	2225012	et	4	main
kõrvallauast	doc_1010138197_item	2225027	et	4	main
anekdooti	doc_1010138197_item	2225034	et	4	main
ei	doc_1010138197_item	2225038	et	4	main
sest	doc_1010138197_item	2225041	et	4	main
tohi	doc_1010138197_item	2225055	et	4	main
ega	doc_1010138197_item	2225057	et	3	main
8	doc_1010138197_item	2225060	et	2	main
tulemust	doc_1010138197_item	2225066	et	4	main
või	doc_1010138197_item	2225074	et	4	main
kuulsin	doc_1010138197_item	2225081	et	3	main
on	doc_1010138198_item	2225096	et	4	main
naine	doc_1010138198_item	2225098	et	3	main
nägema	doc_1010138198_item	2225100	et	3	main
keele	doc_1010138198_item	2225113	et	4	main
õpetajat	doc_1010138198_item	2225114	et	4	main
konkurssi	doc_1010138198_item	2225118	et	4	main
kool	doc_1010138197_item	2224668	et	4	main
siiski	doc_1010138197_item	2224670	et	4	main
ülejäänud	doc_1010138197_item	2224674	et	4	main
ained	doc_1010138197_item	2224676	et	3	main
keeles	doc_1010138197_item	2224679	et	4	main
veel	doc_1010138197_item	2224720	et	4	main
soe	doc_1010138197_item	2224721	et	4	main
kuid	doc_1010138197_item	2224723	et	4	main
juba	doc_1010138197_item	2224725	et	3	main
jahedad	doc_1010138197_item	2224727	et	3	main
juba	doc_1010138197_item	2224729	et	3	main
vene	doc_1010138197_item	2224731	et	4	main
kütmine	doc_1010138197_item	2224733	et	4	main
kütmisele	doc_1010138197_item	2224734	et	4	main
vaja	doc_1010138197_item	2224736	et	4	main
külapood	doc_1010138197_item	2224738	et	3	main
muud	doc_1010138197_item	2224744	et	4	main
ajalehest	doc_1010138197_item	2224754	et	4	main
õigesse	doc_1010138197_item	2224763	et	3	main
kirjavahemärke	doc_1010138197_item	2224767	et	4	main
naised	doc_1010138197_item	2224771	et	3	main
kaunim	doc_1010138197_item	2224777	et	4	main
mehelikum	doc_1010138197_item	2224783	et	4	main
aga	doc_1010138197_item	2224794	et	3	main
tagajärg	doc_1010138197_item	2224799	et	3	main
stress	doc_1010138197_item	2224802	et	3	main
võib	doc_1010138197_item	2224808	et	3	main
soovimatut	doc_1010138197_item	2224810	et	4	main
pinge	doc_1010138197_item	2224828	et	4	main
see	doc_1010138197_item	2224839	et	3	main
telefon	doc_1010138197_item	2224847	et	3	main
abil	doc_1010138197_item	2224853	et	4	main
lausa	doc_1010138197_item	2224855	et	4	main
katkestama	doc_1010138197_item	2224862	et	3	main
pühapäev	doc_1010138197_item	2224864	et	3	main
uni	doc_1010138197_item	2224866	et	3	main
ja	doc_1010138197_item	2224870	et	3	main
huvitav	doc_1010138197_item	2224873	et	4	main
und	doc_1010138197_item	2224882	et	4	main
lõunasöögi	doc_1010138197_item	2224884	et	3	main
ja	doc_1010138197_item	2224886	et	3	main
artikli	doc_1010138197_item	2224921	et	3	main
nõudeid	doc_1010138197_item	2224923	et	3	main
arvasin	doc_1010138197_item	2224926	et	3	main
sa	doc_1010138197_item	2224933	et	3	main
kiirtele	doc_1010138197_item	2224945	et	3	main
töökoht	doc_1010138197_item	2224957	et	3	main
töökoha	doc_1010138197_item	2224959	et	4	main
selles	doc_1010138197_item	2224963	et	4	main
vaid	doc_1010138197_item	2224965	et	3	main
muudatused	doc_1010138197_item	2224967	et	3	main
muudatustega	doc_1010138197_item	2224969	et	3	main
küsimus	doc_1010138197_item	2224972	et	4	main
teine	doc_1010138197_item	2224974	et	3	main
9	doc_1010138197_item	2224983	et	2	main
ajal	doc_1010138197_item	2224985	et	4	main
hoiduma	doc_1010138197_item	2224987	et	3	main
10	doc_1010138197_item	2224990	et	2	main
suvine	doc_1010138197_item	2224994	et	4	main
tellisime	doc_1010138197_item	2225004	et	4	main
lõuna	doc_1010138197_item	2225006	et	4	main
ja	doc_1010138197_item	2225007	et	3	main
palju	doc_1010138197_item	2225010	et	4	main
nii	doc_1010138197_item	2225014	et	3	main
3	doc_1010138197_item	2225018	et	2	main
kartma	doc_1010138197_item	2224710	et	3	main
päevad	doc_1010138197_item	2224719	et	3	main
soojad	doc_1010138197_item	2224722	et	3	main
ei	doc_1010138197_item	2224745	et	4	main
sõnad	doc_1010138197_item	2224762	et	4	main
ja	doc_1010138197_item	2224765	et	3	main
tegema	doc_1010138197_item	2224770	et	3	main
3	doc_1010138197_item	2224787	et	2	main
stress	doc_1010138197_item	2224790	et	3	main
tegutsema	doc_1010138197_item	2224793	et	3	main
soovimatu	doc_1010138197_item	2224798	et	4	main
paras	doc_1010138197_item	2224800	et	3	main
meid	doc_1010138197_item	2224804	et	4	main
lisakoormus	doc_1010138197_item	2224807	et	3	main
tuua	doc_1010138197_item	2224809	et	3	main
jahe	doc_1010138197_item	2224726	et	3	main
külapoest	doc_1010138197_item	2224739	et	4	main
suurt	doc_1010138197_item	2224743	et	3	main
müüdagi	doc_1010138197_item	2224746	et	3	main
valmistuv	doc_1010138197_item	2224750	et	4	main
lühendatud	doc_1010138197_item	2224753	et	4	main
slõhtuleht	doc_1010138197_item	2224755	et	4	main
moodustage	doc_1010138197_item	2224757	et	3	main
sõnadest	doc_1010138197_item	2224759	et	3	main
laused	doc_1010138197_item	2224760	et	3	main
naeratus	doc_1010138197_item	2224769	et	4	main
mehelikum	doc_1010138197_item	2224775	et	4	main
igaüks	doc_1010138197_item	2224776	et	3	main
teeb	doc_1010138197_item	2224779	et	3	main
naiselikum	doc_1010138197_item	2224781	et	4	main
meesteid	doc_1010138197_item	2224782	et	3	main
paras	doc_1010138197_item	2224788	et	3	main
meie	doc_1010138197_item	2224792	et	4	main
paneb	doc_1010138197_item	2224803	et	3	main
tegutsemata	doc_1010138197_item	2224805	et	4	main
tagajärgi	doc_1010138197_item	2224811	et	4	main
4	doc_1010138197_item	2224812	et	2	main
ei	doc_1010138197_item	2224813	et	4	main
tohtima	doc_1010138197_item	2224814	et	3	main
laskma	doc_1010138197_item	2224815	et	3	main
ülekoormus	doc_1010138197_item	2224816	et	3	main
tekkima	doc_1010138197_item	2224817	et	3	main
pinge	doc_1010138197_item	2224818	et	4	main
saama	doc_1010138197_item	2224819	et	4	main
maandama	doc_1010138197_item	2224820	et	3	main
ja	doc_1010138197_item	2224822	et	3	main
ei	doc_1010138197_item	2224824	et	4	main
ülekoormust	doc_1010138197_item	2224826	et	4	main
lasta	doc_1010138197_item	2224827	et	4	main
telefon	doc_1010138197_item	2224831	et	3	main
tänapäev	doc_1010138197_item	2224833	et	3	main
nii	doc_1010138197_item	2224835	et	3	main
aparaat	doc_1010138197_item	2224837	et	3	main
elama	doc_1010138197_item	2224842	et	3	main
hingama	doc_1010138197_item	2224844	et	3	main
on	doc_1010138197_item	2224846	et	4	main
maagiline	doc_1010138197_item	2224849	et	4	main
et	doc_1010138197_item	2224851	et	3	main
6	doc_1010138197_item	2224859	et	2	main
varahommik	doc_1010138197_item	2224865	et	3	main
lõunasöök	doc_1010138197_item	2224868	et	3	main
kuid	doc_1010138197_item	2224877	et	4	main
segab	doc_1010138197_item	2224883	et	3	main
ka	doc_1010138197_item	2224888	et	3	main
5	doc_1010138197_item	2224830	et	2	main
aparaat	doc_1010138197_item	2224850	et	3	main
elada	doc_1010138197_item	2224856	et	3	main
telefonihelin	doc_1010138197_item	2224861	et	3	main
valmistamine	doc_1010138197_item	2224869	et	4	main
telefonihelin	doc_1010138197_item	2224878	et	3	main
pühapäeva	doc_1010138197_item	2224880	et	4	main
valmistamist	doc_1010138197_item	2224885	et	4	main
pahandab	doc_1010138197_item	2224889	et	3	main
telesaade	doc_1010138197_item	2224891	et	4	main
aega	doc_1010138197_item	2224893	et	4	main
vaatamise	doc_1010138197_item	2224892	et	4	main
iv	doc_1010138197_item	2224894	et	4	main
pange	doc_1010138197_item	2224895	et	4	main
sulgudes	doc_1010138197_item	2224896	et	4	main
olevad	doc_1010138197_item	2224897	et	4	main
sõnad	doc_1010138197_item	2224898	et	4	main
õigesse	doc_1010138197_item	2224899	et	3	main
vormi	doc_1010138197_item	2224900	et	4	main
1	doc_1010138197_item	2224901	et	2	main
ma	doc_1010138197_item	2224902	et	3	main
pean	doc_1010138197_item	2224903	et	4	main
väga	doc_1010138197_item	2224904	et	3	main
lugu	doc_1010138197_item	2224905	et	4	main
oma	doc_1010138197_item	2224906	et	4	main
vanemad	doc_1010138197_item	2224907	et	4	main
oma	doc_1010138197_item	2224908	et	4	main
vanemaid	doc_1010138197_item	2224909	et	4	main
sest	doc_1010138197_item	2224910	et	4	main
nad	doc_1010138197_item	2224911	et	3	main
aitavad	doc_1010138197_item	2224912	et	4	main
kõik	doc_1010138197_item	2224913	et	4	main
kõike	doc_1010138197_item	2224914	et	4	main
ja	doc_1010138197_item	2224915	et	3	main
usaldavad	doc_1010138197_item	2224916	et	4	main
igaüks	doc_1010138197_item	2224917	et	3	main
igaükse	doc_1010138197_item	2224918	et	3	main
2	doc_1010138197_item	2224919	et	2	main
kohandasin	doc_1010138197_item	2224920	et	3	main
3	doc_1010138197_item	2224924	et	2	main
sport	doc_1010138197_item	2224930	et	3	main
aga	doc_1010138197_item	2224932	et	3	main
tunned	doc_1010138197_item	2224934	et	3	main
naised	doc_1010138197_item	2224938	et	3	main
autod	doc_1010138197_item	2224941	et	3	main
naistele	doc_1010138197_item	2224943	et	3	main
autodele	doc_1010138197_item	2224946	et	3	main
5	doc_1010138197_item	2224954	et	2	main
kiiresti	doc_1010138197_item	2224960	et	3	main
väikesed	doc_1010138197_item	2224966	et	4	main
valdkond	doc_1010138197_item	2224975	et	3	main
valdkonnale	doc_1010138197_item	2224977	et	4	main
närimiskumm	doc_1010138197_item	2224979	et	3	main
püksid	doc_1010138197_item	2224981	et	3	main
külmetamisest	doc_1010138197_item	2224989	et	4	main
kuid	doc_1010138197_item	2224860	et	4	main
segama	doc_1010138197_item	2224867	et	3	main
vaatamine	doc_1010138197_item	2224875	et	4	main
söömist	doc_1010138197_item	2224887	et	4	main
huvitava	doc_1010138197_item	2224890	et	4	main
nõuded	doc_1010138197_item	2224922	et	3	main
ainult	doc_1010138197_item	2224936	et	4	main
ja	doc_1010138197_item	2224939	et	3	main
6	doc_1010138197_item	2224961	et	2	main
piirdusime	doc_1010138197_item	2224962	et	3	main
küsimuses	doc_1010138197_item	2224964	et	4	main
teisele	doc_1010138197_item	2224976	et	4	main
peab	doc_1010138197_item	2224986	et	4	main
v	doc_1010138197_item	2224998	et	4	main
õpilased	doc_1010138197_item	2225015	et	3	main
oodata	doc_1010138197_item	2225021	et	4	main
vanemad	doc_1010138197_item	2225023	et	4	main
just	doc_1010138197_item	2225033	et	3	main
6	doc_1010138197_item	2225045	et	2	main
siis	doc_1010138197_item	2225048	et	3	main
jalutama	doc_1010138197_item	2225050	et	3	main
baaris	doc_1010138197_item	2225053	et	3	main
töötasid	doc_1010138197_item	2225062	et	4	main
ei	doc_1010138197_item	2225067	et	4	main
kas	doc_1010138197_item	2225070	et	3	main
sõidad	doc_1010138197_item	2225072	et	3	main
jääd	doc_1010138197_item	2225075	et	4	main
koputust	doc_1010138197_item	2225082	et	4	main
eesti	doc_1010138198_item	2225084	et	4	main
test	doc_1010138198_item	2225086	et	3	main
sulgudes	doc_1010138198_item	2225089	et	4	main
õigesse	doc_1010138198_item	2225092	et	3	main
piret	doc_1010138198_item	2225094	et	4	main
suvel	doc_1010138198_item	2225099	et	3	main
nägi	doc_1010138198_item	2225101	et	3	main
et	doc_1010138198_item	2225106	et	3	main
siberisse	doc_1010138198_item	2225107	et	4	main
emakeelt	doc_1010138198_item	2225130	et	4	main
õpetama	doc_1010138198_item	2225131	et	3	main
jõudma	doc_1010138198_item	2225138	et	3	main
olin	doc_1010138198_item	2225143	et	3	main
tulema	doc_1010138198_item	2225149	et	4	main
korralik	doc_1010138198_item	2225152	et	3	main
mulle	doc_1010138198_item	2225155	et	4	main
pilt	doc_1010138198_item	2225160	et	3	main
ei	doc_1010138198_item	2225163	et	4	main
ega	doc_1010138198_item	2225167	et	3	main
kui	doc_1010138198_item	2225170	et	3	main
pärast	doc_1010138198_item	2225177	et	4	main
jõudis	doc_1010138198_item	2225182	et	3	main
alganud	doc_1010138198_item	2225187	et	4	main
võtma	doc_1010138198_item	2225190	et	3	main
on	doc_1010138198_item	2225194	et	4	main
sügisel	doc_1010138198_item	2225196	et	3	main
õppimine	doc_1010138198_item	2225206	et	4	main
et	doc_1010138197_item	2224927	et	3	main
huvitud	doc_1010138197_item	2224929	et	4	main
kiired	doc_1010138197_item	2224940	et	4	main
ilusadele	doc_1010138197_item	2224942	et	4	main
ja	doc_1010138197_item	2224944	et	3	main
4	doc_1010138197_item	2224947	et	2	main
praegu	doc_1010138197_item	2224948	et	3	main
on	doc_1010138197_item	2224949	et	4	main
oht	doc_1010138197_item	2224950	et	3	main
haigestuda	doc_1010138197_item	2224951	et	3	main
difteeria	doc_1010138197_item	2224952	et	4	main
tüdinesin	doc_1010138197_item	2224955	et	3	main
uue	doc_1010138197_item	2224958	et	3	main
väikeste	doc_1010138197_item	2224968	et	4	main
see	doc_1010138197_item	2224971	et	3	main
8	doc_1010138197_item	2224978	et	2	main
kleepus	doc_1010138197_item	2224980	et	3	main
külmal	doc_1010138197_item	2224984	et	3	main
rõõmu	doc_1010138197_item	2224993	et	4	main
suviseks	doc_1010138197_item	2224996	et	4	main
lüngad	doc_1010138197_item	2225000	et	3	main
sidenditega	doc_1010138197_item	2225002	et	3	main
kui	doc_1010138197_item	2225016	et	3	main
lapsel	doc_1010138197_item	2225019	et	4	main
kui	doc_1010138197_item	2225022	et	3	main
tulevad	doc_1010138197_item	2225025	et	4	main
kui	doc_1010138197_item	2225030	et	3	main
keegi	doc_1010138197_item	2225032	et	4	main
rääkinud	doc_1010138197_item	2225035	et	4	main
ta	doc_1010138197_item	2225037	et	4	main
hoopis	doc_1010138197_item	2225043	et	3	main
selles	doc_1010138197_item	2225052	et	4	main
suitsetada	doc_1010138197_item	2225056	et	3	main
alkoholi	doc_1010138197_item	2225058	et	4	main
maale	doc_1010138197_item	2225073	et	4	main
linna	doc_1010138197_item	2225076	et	4	main
keele	doc_1010138198_item	2225085	et	4	main
pange	doc_1010138198_item	2225088	et	4	main
sõnad	doc_1010138198_item	2225091	et	4	main
ajalehes	doc_1010138198_item	2225103	et	3	main
küla	doc_1010138198_item	2225109	et	4	main
otsitakse	doc_1010138198_item	2225111	et	3	main
võitis	doc_1010138198_item	2225116	et	3	main
nädal	doc_1010138198_item	2225124	et	3	main
eestlastele	doc_1010138198_item	2225127	et	4	main
seda	doc_1010138198_item	2225129	et	3	main
siberisse	doc_1010138198_item	2225137	et	4	main
üsna	doc_1010138198_item	2225144	et	3	main
kui	doc_1010138198_item	2225147	et	3	main
korraliku	doc_1010138198_item	2225153	et	3	main
maaliti	doc_1010138198_item	2225156	et	3	main
et	doc_1010138198_item	2225161	et	3	main
ja	doc_1010138198_item	2225172	et	3	main
tahtmise	doc_1010138198_item	2225174	et	4	main
algust	doc_1010138198_item	2225179	et	4	main
kohale	doc_1010138198_item	2225181	et	4	main
algama	doc_1010138198_item	2225186	et	3	main
kogu	doc_1010138198_item	2225188	et	4	main
tähtis	doc_1010138198_item	2225198	et	4	main
tänaseks	doc_1010138198_item	2225201	et	4	main
kartul	doc_1010138198_item	2225203	et	3	main
ja	doc_1010138198_item	2225205	et	3	main
mahlakasem	doc_1010138198_item	2225221	et	4	main
mõni	doc_1010138198_item	2225227	et	3	main
venemaa	doc_1010138198_item	2225232	et	4	main
ülejäänud	doc_1010138198_item	2225235	et	4	main
üle	doc_1010138198_item	2225244	et	3	main
varsti	doc_1010138198_item	2225260	et	3	main
siberi	doc_1010138198_item	2225266	et	4	main
piret	doc_1010138198_item	2225268	et	4	main
kartma	doc_1010138198_item	2225270	et	3	main
on	doc_1010138198_item	2225278	et	4	main
kuid	doc_1010138198_item	2225283	et	4	main
ahju	doc_1010138198_item	2225292	et	4	main
vaja	doc_1010138198_item	2225296	et	4	main
ega	doc_1010138198_item	2225301	et	3	main
suurt	doc_1010138198_item	2225303	et	3	main
ei	doc_1010138198_item	2225305	et	4	main
vapralt	doc_1010138198_item	2225312	et	4	main
etteantud	doc_1010138198_item	2225318	et	4	main
tegema	doc_1010138198_item	2225330	et	3	main
kaunim	doc_1010138198_item	2225337	et	4	main
naeratus	doc_1010138198_item	2225339	et	4	main
naiselikum	doc_1010138198_item	2225343	et	4	main
lisakoormus	doc_1010138198_item	2225367	et	3	main
sportima	doc_1010138198_item	2225381	et	4	main
puhkama	doc_1010138198_item	2225383	et	3	main
ülekoormusel	doc_1010138198_item	2225386	et	3	main
pinget	doc_1010138198_item	2225388	et	3	main
see	doc_1010138198_item	2225399	et	3	main
sul	doc_1010138198_item	2225412	et	3	main
6	doc_1010138198_item	2225419	et	2	main
telefonihelin	doc_1010138198_item	2225421	et	3	main
segama	doc_1010138198_item	2225427	et	3	main
valmistamine	doc_1010138198_item	2225429	et	4	main
vaatamine	doc_1010138198_item	2225435	et	4	main
ma	doc_1010138197_item	2224991	et	3	main
päike	doc_1010138197_item	2224995	et	3	main
päikeseks	doc_1010138197_item	2224997	et	4	main
1	doc_1010138197_item	2225003	et	2	main
see	doc_1010138197_item	2225008	et	3	main
2	doc_1010138197_item	2225011	et	2	main
olid	doc_1010138197_item	2225013	et	4	main
õpetajad	doc_1010138197_item	2225017	et	4	main
paluti	doc_1010138197_item	2225020	et	3	main
kostis	doc_1010138197_item	2225028	et	4	main
oleks	doc_1010138197_item	2225031	et	3	main
tule	doc_1010138197_item	2225039	et	4	main
läheb	doc_1010138197_item	2225042	et	3	main
teatrisse	doc_1010138197_item	2225044	et	3	main
töö	doc_1010138197_item	2225047	et	4	main
7	doc_1010138197_item	2225051	et	2	main
ei	doc_1010138197_item	2225054	et	4	main
tarbida	doc_1010138197_item	2225059	et	3	main
nad	doc_1010138197_item	2225061	et	3	main
pingsalt	doc_1010138197_item	2225064	et	4	main
9	doc_1010138197_item	2225069	et	2	main
sa	doc_1010138197_item	2225071	et	3	main
avasin	doc_1010138197_item	2225078	et	3	main
sest	doc_1010138197_item	2225080	et	4	main
test	doc_1010138198_item	2225083	et	3	main
toomet	doc_1010138198_item	2225095	et	4	main
ettevõtlik	doc_1010138198_item	2225097	et	3	main
ta	doc_1010138198_item	2225102	et	4	main
kuulutust	doc_1010138198_item	2225105	et	4	main
ülem-suetuki	doc_1010138198_item	2225108	et	4	main
piret	doc_1010138198_item	2225115	et	4	main
konkurss	doc_1010138198_item	2225117	et	3	main
on	doc_1010138198_item	2225120	et	4	main
õpetamas	doc_1010138198_item	2225132	et	3	main
tundis	doc_1010138198_item	2225135	et	3	main
jõudmisel	doc_1010138198_item	2225139	et	4	main
et	doc_1010138198_item	2225140	et	3	main
üllatuma	doc_1010138198_item	2225145	et	3	main
siber	doc_1010138198_item	2225157	et	4	main
seal	doc_1010138198_item	2225162	et	4	main
kasva	doc_1010138198_item	2225168	et	4	main
tahtmine	doc_1010138198_item	2225173	et	4	main
polnud	doc_1010138198_item	2225183	et	3	main
veel	doc_1010138198_item	2225185	et	4	main
kartuleid	doc_1010138198_item	2225192	et	3	main
käib	doc_1010138198_item	2225207	et	3	main
vene	doc_1010138198_item	2225223	et	4	main
vaid	doc_1010138198_item	2225225	et	3	main
kool	doc_1010138198_item	2225229	et	4	main
aine	doc_1010138198_item	2225236	et	4	main
õpetatakse	doc_1010138198_item	2225238	et	3	main
elab	doc_1010138198_item	2225242	et	3	main
inimene	doc_1010138198_item	2225247	et	3	main
ei	doc_1010138198_item	2225269	et	4	main
juba	doc_1010138198_item	2225273	et	3	main
ööd	doc_1010138198_item	2225284	et	4	main
jahe	doc_1010138198_item	2225286	et	3	main
harjutan	doc_1010138198_item	2225288	et	3	main
suure	doc_1010138198_item	2225290	et	3	main
kütmist	doc_1010138198_item	2225294	et	4	main
vildid	doc_1010138198_item	2225300	et	4	main
piret	doc_1010138198_item	2225311	et	4	main
lühendatud	doc_1010138198_item	2225313	et	4	main
2	doc_1010138198_item	2225328	et	2	main
mehed	doc_1010138198_item	2225334	et	3	main
igaühe	doc_1010138198_item	2225341	et	4	main
mehelikum	doc_1010138198_item	2225346	et	4	main
soovimatu	doc_1010138198_item	2225358	et	4	main
kogus	doc_1010138198_item	2225364	et	4	main
tua	doc_1010138198_item	2225369	et	4	main
tagajarje	doc_1010138198_item	2225371	et	4	main
saama	doc_1010138198_item	2225379	et	4	main
5	doc_1010138198_item	2225390	et	2	main
tänapäev	doc_1010138198_item	2225393	et	3	main
nii	doc_1010138198_item	2225395	et	3	main
aparaat	doc_1010138198_item	2225397	et	3	main
hingama	doc_1010138198_item	2225404	et	3	main
aparat	doc_1010138198_item	2225410	et	4	main
abil	doc_1010138198_item	2225413	et	4	main
söömine	doc_1010138198_item	2225431	et	4	main
telefonihelin	doc_1010138198_item	2225438	et	3	main
segab	doc_1010138198_item	2225442	et	3	main
valmistamisel	doc_1010138198_item	2225444	et	4	main
pahandab	doc_1010138198_item	2225447	et	3	main
väga	doc_1010138198_item	2225463	et	3	main
tagasi	doc_1010138197_item	2225024	et	3	main
4	doc_1010138197_item	2225026	et	2	main
naeru	doc_1010138197_item	2225029	et	4	main
5	doc_1010138197_item	2225036	et	2	main
trenni	doc_1010138197_item	2225040	et	4	main
lõpetage	doc_1010138197_item	2225046	et	3	main
lähete	doc_1010138197_item	2225049	et	4	main
küll	doc_1010138197_item	2225063	et	4	main
aga	doc_1010138197_item	2225065	et	3	main
olnud	doc_1010138197_item	2225068	et	4	main
10	doc_1010138197_item	2225077	et	2	main
ukse	doc_1010138197_item	2225079	et	3	main
i	doc_1010138198_item	2225087	et	4	main
olevad	doc_1010138198_item	2225090	et	4	main
vormi	doc_1010138198_item	2225093	et	4	main
kuulutus	doc_1010138198_item	2225104	et	4	main
külas	doc_1010138198_item	2225110	et	3	main
eesti	doc_1010138198_item	2225112	et	4	main
ja	doc_1010138198_item	2225119	et	3	main
juba	doc_1010138198_item	2225122	et	3	main
väikestele	doc_1010138198_item	2225126	et	4	main
need	doc_1010138198_item	2225128	et	3	main
pireti	doc_1010138198_item	2225133	et	4	main
ta	doc_1010138198_item	2225136	et	4	main
oodatud	doc_1010138198_item	2225142	et	4	main
mulle	doc_1010138198_item	2225148	et	4	main
vastu	doc_1010138198_item	2225151	et	3	main
selline	doc_1010138198_item	2225159	et	4	main
lendama	doc_1010138198_item	2225164	et	3	main
lind	doc_1010138198_item	2225166	et	3	main
täis	doc_1010138198_item	2225175	et	4	main
kool	doc_1010138198_item	2225184	et	4	main
küla	doc_1010138198_item	2225189	et	4	main
kartulivõtt	doc_1010138198_item	2225193	et	3	main
siin	doc_1010138198_item	2225195	et	4	main
kõige	doc_1010138198_item	2225197	et	4	main
ettevõtmine	doc_1010138198_item	2225200	et	3	main
salv	doc_1010138198_item	2225204	et	3	main
hoog	doc_1010138198_item	2225209	et	3	main
murret	doc_1010138198_item	2225228	et	4	main
siiski	doc_1010138198_item	2225231	et	4	main
vene	doc_1010138198_item	2225239	et	4	main
veidi	doc_1010138198_item	2225243	et	3	main
raamatuid	doc_1010138198_item	2225259	et	3	main
saadavad	doc_1010138198_item	2225262	et	4	main
mulle	doc_1010138198_item	2225272	et	4	main
tooma	doc_1010138198_item	2225274	et	3	main
talvepuud	doc_1010138198_item	2225276	et	4	main
veel	doc_1010138198_item	2225280	et	4	main
juba	doc_1010138198_item	2225285	et	3	main
jahedad	doc_1010138198_item	2225287	et	3	main
kui	doc_1010138198_item	2225295	et	3	main
külapood	doc_1010138198_item	2225298	et	3	main
muud	doc_1010138198_item	2225304	et	4	main
valmistuma	doc_1010138198_item	2225309	et	3	main
slõhtuleht	doc_1010138198_item	2225315	et	4	main
moodustage	doc_1010138198_item	2225317	et	3	main
sõnadest	doc_1010138198_item	2225319	et	3	main
laused	doc_1010138198_item	2225320	et	3	main
sõnad	doc_1010138198_item	2225322	et	4	main
vormi	doc_1010138198_item	2225324	et	4	main
ja	doc_1010138198_item	2225325	et	3	main
kirjavahemärke	doc_1010138198_item	2225327	et	4	main
naised	doc_1010138198_item	2225331	et	3	main
igaüks	doc_1010138198_item	2225336	et	3	main
kaunis	doc_1010138198_item	2225338	et	4	main
naise	doc_1010138198_item	2225342	et	3	main
mehe	doc_1010138198_item	2225345	et	3	main
tegutsema	doc_1010138198_item	2225365	et	3	main
tohtima	doc_1010138198_item	2225374	et	3	main
ülekoormus	doc_1010138198_item	2225376	et	3	main
pinge	doc_1010138198_item	2225378	et	4	main
maandama	doc_1010138198_item	2225380	et	3	main
tohi	doc_1010138198_item	2225385	et	4	main
elama	doc_1010138198_item	2225402	et	3	main
tänapäeval	doc_1010138198_item	2225405	et	3	main
maagiline	doc_1010138198_item	2225409	et	4	main
saab	doc_1010138198_item	2225414	et	3	main
kuid	doc_1010138198_item	2225420	et	4	main
katkestama	doc_1010138198_item	2225422	et	3	main
pühapäev	doc_1010138198_item	2225424	et	3	main
uni	doc_1010138198_item	2225426	et	3	main
huvitav	doc_1010138198_item	2225433	et	4	main
aeg	doc_1010138198_item	2225436	et	3	main
und	doc_1010138198_item	2225441	et	4	main
söömisel	doc_1010138198_item	2225446	et	4	main
huvitava	doc_1010138198_item	2225449	et	4	main
pean	doc_1010138198_item	2225462	et	4	main
ja	doc_1010138198_item	2225474	et	3	main
et	doc_1010138198_item	2225486	et	3	main
nüüd	doc_1010138198_item	2225121	et	4	main
üle	doc_1010138198_item	2225123	et	3	main
nädala	doc_1010138198_item	2225125	et	3	main
kinnitusel	doc_1010138198_item	2225134	et	4	main
on	doc_1010138198_item	2225141	et	4	main
üllatunud	doc_1010138198_item	2225146	et	4	main
tuldi	doc_1010138198_item	2225150	et	3	main
audiga	doc_1010138198_item	2225154	et	3	main
siberist	doc_1010138198_item	2225158	et	4	main
lenda	doc_1010138198_item	2225165	et	4	main
rohi	doc_1010138198_item	2225169	et	4	main
noor	doc_1010138198_item	2225171	et	3	main
piret	doc_1010138198_item	2225176	et	4	main
õppeaasta	doc_1010138198_item	2225178	et	4	main
koht	doc_1010138198_item	2225180	et	3	main
võtis	doc_1010138198_item	2225191	et	3	main
tähtsam	doc_1010138198_item	2225199	et	4	main
on	doc_1010138198_item	2225202	et	4	main
täie	doc_1010138198_item	2225208	et	3	main
hooguga	doc_1010138198_item	2225210	et	4	main
siinsed	doc_1010138198_item	2225211	et	3	main
eestlased	doc_1010138198_item	2225212	et	3	main
räägivad	doc_1010138198_item	2225213	et	3	main
kuidagi	doc_1010138198_item	2225214	et	3	main
teistmoodi	doc_1010138198_item	2225215	et	3	main
mõnus	doc_1010138198_item	2225216	et	4	main
ja	doc_1010138198_item	2225217	et	3	main
mahlakas	doc_1010138198_item	2225218	et	4	main
mõnusam	doc_1010138198_item	2225219	et	4	main
ja	doc_1010138198_item	2225220	et	3	main
mitte	doc_1010138198_item	2225222	et	3	main
nagu	doc_1010138198_item	2225226	et	3	main
kool	doc_1010138198_item	2225233	et	4	main
ained	doc_1010138198_item	2225237	et	3	main
keeles	doc_1010138198_item	2225240	et	4	main
kolmesaja	doc_1010138198_item	2225246	et	4	main
emakeelt	doc_1010138198_item	2225249	et	4	main
saatma	doc_1010138198_item	2225261	et	3	main
uued	doc_1010138198_item	2225264	et	3	main
toodi	doc_1010138198_item	2225275	et	4	main
sojad	doc_1010138198_item	2225282	et	3	main
juba	doc_1010138198_item	2225289	et	3	main
vene	doc_1010138198_item	2225291	et	4	main
ostan	doc_1010138198_item	2225297	et	3	main
seal	doc_1010138198_item	2225302	et	4	main
naerab	doc_1010138198_item	2225307	et	3	main
iii	doc_1010138198_item	2225316	et	4	main
aktsent	doc_1010138198_item	2225224	et	3	main
on	doc_1010138198_item	2225230	et	4	main
ja	doc_1010138198_item	2225234	et	3	main
külas	doc_1010138198_item	2225241	et	3	main
kolmsada	doc_1010138198_item	2225245	et	4	main
inimese	doc_1010138198_item	2225248	et	4	main
saab	doc_1010138198_item	2225250	et	3	main
rääkida	doc_1010138198_item	2225252	et	3	main
kõik	doc_1010138198_item	2225251	et	4	main
pireti	doc_1010138198_item	2225253	et	4	main
sõnul	doc_1010138198_item	2225254	et	3	main
õpivad	doc_1010138198_item	2225255	et	3	main
lapsed	doc_1010138198_item	2225256	et	3	main
poolpõlenud	doc_1010138198_item	2225257	et	4	main
raamatud	doc_1010138198_item	2225258	et	4	main
eestist	doc_1010138198_item	2225263	et	3	main
õpikud	doc_1010138198_item	2225265	et	3	main
talve	doc_1010138198_item	2225267	et	4	main
karta	doc_1010138198_item	2225271	et	3	main
praegu	doc_1010138198_item	2225277	et	3	main
päevad	doc_1010138198_item	2225279	et	3	main
soe	doc_1010138198_item	2225281	et	4	main
kütmine	doc_1010138198_item	2225293	et	4	main
külapoest	doc_1010138198_item	2225299	et	4	main
müüdagi	doc_1010138198_item	2225306	et	3	main
talveks	doc_1010138198_item	2225308	et	4	main
valmistunud	doc_1010138198_item	2225310	et	4	main
ajalehest	doc_1010138198_item	2225314	et	4	main
pannes	doc_1010138198_item	2225321	et	4	main
õigesse	doc_1010138198_item	2225323	et	3	main
kasutades	doc_1010138198_item	2225326	et	3	main
naiselikum	doc_1010138198_item	2225332	et	4	main
ja	doc_1010138198_item	2225333	et	3	main
teeb	doc_1010138198_item	2225340	et	3	main
ja	doc_1010138198_item	2225344	et	3	main
3	doc_1010138198_item	2225347	et	2	main
stress	doc_1010138198_item	2225360	et	3	main
paras	doc_1010138198_item	2225363	et	3	main
ei	doc_1010138198_item	2225373	et	4	main
tekkima	doc_1010138198_item	2225377	et	3	main
ja	doc_1010138198_item	2225382	et	3	main
lasta	doc_1010138198_item	2225387	et	4	main
saama	doc_1010138198_item	2225389	et	4	main
telefon	doc_1010138198_item	2225391	et	3	main
maagiline	doc_1010138198_item	2225396	et	4	main
et	doc_1010138198_item	2225398	et	3	main
abil	doc_1010138198_item	2225400	et	4	main
ja	doc_1010138198_item	2225403	et	3	main
telefon	doc_1010138198_item	2225406	et	3	main
lausa	doc_1010138198_item	2225415	et	4	main
ja	doc_1010138198_item	2225417	et	3	main
ka	doc_1010138198_item	2225423	et	3	main
lõunasöök	doc_1010138198_item	2225428	et	3	main
ja	doc_1010138198_item	2225430	et	3	main
pahandab	doc_1010138198_item	2225432	et	3	main
varahommikku	doc_1010138198_item	2225440	et	4	main
ka	doc_1010138198_item	2225448	et	3	main
pange	doc_1010138198_item	2225454	et	4	main
olevad	doc_1010138198_item	2225456	et	4	main
õigesse	doc_1010138198_item	2225458	et	3	main
ma	doc_1010138198_item	2225461	et	3	main
oma	doc_1010138198_item	2225465	et	4	main
oma	doc_1010138198_item	2225467	et	4	main
aitavad	doc_1010138198_item	2225471	et	4	main
igaühte	doc_1010138198_item	2225477	et	4	main
artikli	doc_1010138198_item	2225480	et	3	main
arvasin	doc_1010138198_item	2225485	et	3	main
huvitud	doc_1010138198_item	2225488	et	4	main
vaikesi	doc_1010138198_item	2225528	et	4	main
teise	doc_1010138198_item	2225536	et	4	main
valdkonda	doc_1010138198_item	2225537	et	4	main
kleepus	doc_1010138198_item	2225540	et	3	main
külmal	doc_1010138198_item	2225544	et	3	main
külmetamist	doc_1010138198_item	2225549	et	4	main
päike	doc_1010138198_item	2225555	et	3	main
lõuna	doc_1010138198_item	2225566	et	4	main
see	doc_1010138198_item	2225568	et	3	main
kohal	doc_1010138198_item	2225572	et	4	main
kõik	doc_1010138198_item	2225574	et	4	main
ja	doc_1010138198_item	2225576	et	3	main
3	doc_1010138198_item	2225579	et	2	main
paluti	doc_1010138198_item	2225581	et	3	main
kaua	doc_1010138198_item	2225584	et	3	main
naeru	doc_1010138198_item	2225592	et	4	main
8	doc_1010138198_item	2225625	et	2	main
töötasid	doc_1010138198_item	2225627	et	4	main
ei	doc_1010138198_item	2225632	et	4	main
avasin	doc_1010138198_item	2225643	et	3	main
piret	doc_1010138199_item	2225659	et	4	main
on	doc_1010138199_item	2225661	et	4	main
nägema	doc_1010138199_item	2225665	et	3	main
kuulutus	doc_1010138199_item	2225669	et	4	main
et	doc_1010138199_item	2225671	et	3	main
külasse	doc_1010138199_item	2225675	et	3	main
eesti	doc_1010138199_item	2225677	et	4	main
ja	doc_1010138199_item	2225684	et	3	main
üle	doc_1010138199_item	2225688	et	3	main
need	doc_1010138199_item	2225693	et	3	main
pireti	doc_1010138199_item	2225698	et	4	main
kinnitusel	doc_1010138199_item	2225699	et	4	main
naeratus	doc_1010138198_item	2225329	et	4	main
mehelikum	doc_1010138198_item	2225335	et	4	main
paras	doc_1010138198_item	2225348	et	3	main
kogus	doc_1010138198_item	2225349	et	4	main
stress	doc_1010138198_item	2225350	et	3	main
meie	doc_1010138198_item	2225352	et	4	main
panema	doc_1010138198_item	2225351	et	3	main
tegutsema	doc_1010138198_item	2225353	et	3	main
aga	doc_1010138198_item	2225354	et	3	main
lisakoormus	doc_1010138198_item	2225355	et	3	main
võima	doc_1010138198_item	2225356	et	3	main
tooma	doc_1010138198_item	2225357	et	3	main
tagajärg	doc_1010138198_item	2225359	et	3	main
paneb	doc_1010138198_item	2225361	et	3	main
meid	doc_1010138198_item	2225362	et	4	main
aga	doc_1010138198_item	2225366	et	3	main
võib	doc_1010138198_item	2225368	et	3	main
soovimatuid	doc_1010138198_item	2225370	et	4	main
4	doc_1010138198_item	2225372	et	2	main
laskma	doc_1010138198_item	2225375	et	3	main
ei	doc_1010138198_item	2225384	et	4	main
olema	doc_1010138198_item	2225392	et	4	main
saama	doc_1010138198_item	2225394	et	4	main
lausa	doc_1010138198_item	2225401	et	4	main
on	doc_1010138198_item	2225407	et	4	main
nii	doc_1010138198_item	2225408	et	3	main
et	doc_1010138198_item	2225411	et	3	main
elada	doc_1010138198_item	2225416	et	3	main
hingata	doc_1010138198_item	2225418	et	4	main
varahommik	doc_1010138198_item	2225425	et	3	main
telesaade	doc_1010138198_item	2225434	et	4	main
katkestab	doc_1010138198_item	2225439	et	3	main
lõunasööki	doc_1010138198_item	2225443	et	4	main
vaatamise	doc_1010138198_item	2225451	et	4	main
iv	doc_1010138198_item	2225453	et	4	main
vormi	doc_1010138198_item	2225459	et	4	main
vanemad	doc_1010138198_item	2225466	et	4	main
kõike	doc_1010138198_item	2225473	et	4	main
usaldavad	doc_1010138198_item	2225475	et	4	main
3	doc_1010138198_item	2225483	et	2	main
sa	doc_1010138198_item	2225487	et	3	main
sport	doc_1010138198_item	2225489	et	3	main
sportis	doc_1010138198_item	2225490	et	3	main
aga	doc_1010138198_item	2225491	et	3	main
sa	doc_1010138198_item	2225492	et	3	main
tunned	doc_1010138198_item	2225493	et	3	main
huvi	doc_1010138198_item	2225494	et	4	main
ainult	doc_1010138198_item	2225495	et	4	main
ilusad	doc_1010138198_item	2225496	et	3	main
naised	doc_1010138198_item	2225497	et	3	main
ja	doc_1010138198_item	2225498	et	3	main
kiired	doc_1010138198_item	2225499	et	4	main
autod	doc_1010138198_item	2225500	et	3	main
ilusate	doc_1010138198_item	2225501	et	3	main
naiste	doc_1010138198_item	2225502	et	3	main
ja	doc_1010138198_item	2225503	et	3	main
kiirde	doc_1010138198_item	2225504	et	4	main
autode	doc_1010138198_item	2225505	et	3	main
kohta	doc_1010138198_item	2225506	et	4	main
4	doc_1010138198_item	2225507	et	2	main
praegu	doc_1010138198_item	2225508	et	3	main
on	doc_1010138198_item	2225509	et	4	main
oht	doc_1010138198_item	2225510	et	3	main
haigestuda	doc_1010138198_item	2225511	et	3	main
difteeria	doc_1010138198_item	2225512	et	4	main
difteeriaga	doc_1010138198_item	2225513	et	3	main
5	doc_1010138198_item	2225514	et	2	main
tüdinesin	doc_1010138198_item	2225515	et	3	main
uus	doc_1010138198_item	2225516	et	3	main
töökoht	doc_1010138198_item	2225517	et	3	main
uest	doc_1010138198_item	2225518	et	4	main
töökohast	doc_1010138198_item	2225519	et	4	main
kiiresti	doc_1010138198_item	2225520	et	3	main
küsimuses	doc_1010138198_item	2225524	et	4	main
teine	doc_1010138198_item	2225534	et	3	main
8	doc_1010138198_item	2225538	et	2	main
9	doc_1010138198_item	2225543	et	2	main
ajal	doc_1010138198_item	2225545	et	4	main
ma	doc_1010138198_item	2225551	et	3	main
rõõmu	doc_1010138198_item	2225553	et	4	main
sobivate	doc_1010138198_item	2225561	et	4	main
tellisime	doc_1010138198_item	2225564	et	4	main
kuid	doc_1010138198_item	2225437	et	4	main
ja	doc_1010138198_item	2225445	et	3	main
telesaade	doc_1010138198_item	2225450	et	4	main
ajal	doc_1010138198_item	2225452	et	4	main
sulgudes	doc_1010138198_item	2225455	et	4	main
sõnad	doc_1010138198_item	2225457	et	4	main
1	doc_1010138198_item	2225460	et	2	main
lugu	doc_1010138198_item	2225464	et	4	main
sest	doc_1010138198_item	2225469	et	4	main
kõik	doc_1010138198_item	2225472	et	4	main
2	doc_1010138198_item	2225478	et	2	main
nõudeid	doc_1010138198_item	2225482	et	3	main
6	doc_1010138198_item	2225521	et	2	main
muudatused	doc_1010138198_item	2225527	et	3	main
7	doc_1010138198_item	2225530	et	2	main
küsimus	doc_1010138198_item	2225532	et	4	main
püksid	doc_1010138198_item	2225541	et	3	main
pükstele	doc_1010138198_item	2225542	et	3	main
hoiduma	doc_1010138198_item	2225547	et	3	main
1	doc_1010138198_item	2225563	et	2	main
ja	doc_1010138198_item	2225567	et	3	main
õpilased	doc_1010138198_item	2225575	et	3	main
lapsel	doc_1010138198_item	2225580	et	4	main
vanemad	doc_1010138198_item	2225586	et	4	main
4	doc_1010138198_item	2225589	et	2	main
keegi	doc_1010138198_item	2225595	et	4	main
küll	doc_1010138198_item	2225628	et	4	main
olnud	doc_1010138198_item	2225633	et	4	main
sa	doc_1010138198_item	2225636	et	3	main
linna	doc_1010138198_item	2225641	et	4	main
eksamitöö	doc_1010138199_item	2225648	et	4	main
naine	doc_1010138199_item	2225663	et	3	main
ajalehes	doc_1010138199_item	2225668	et	3	main
küla	doc_1010138199_item	2225674	et	4	main
õpetajat	doc_1010138199_item	2225679	et	4	main
võitis	doc_1010138199_item	2225681	et	3	main
on	doc_1010138199_item	2225685	et	4	main
nädal	doc_1010138199_item	2225689	et	3	main
väikestele	doc_1010138199_item	2225691	et	4	main
õpetama	doc_1010138199_item	2225696	et	3	main
et	doc_1010138199_item	2225705	et	3	main
oodatud	doc_1010138199_item	2225707	et	4	main
üsna	doc_1010138199_item	2225709	et	3	main
tuli	doc_1010138199_item	2225715	et	4	main
korralik	doc_1010138199_item	2225717	et	3	main
pilt	doc_1010138199_item	2225725	et	3	main
lind	doc_1010138199_item	2225731	et	3	main
algust	doc_1010138199_item	2225744	et	4	main
kohale	doc_1010138199_item	2225746	et	4	main
algama	doc_1010138199_item	2225751	et	3	main
küla	doc_1010138199_item	2225754	et	4	main
sügisel	doc_1010138199_item	2225761	et	3	main
tähtsaim	doc_1010138199_item	2225764	et	4	main
tänaseks	doc_1010138199_item	2225766	et	4	main
üle	doc_1010138199_item	2225812	et	3	main
inimene	doc_1010138199_item	2225815	et	3	main
kõike	doc_1010138199_item	2225820	et	4	main
raamatud	doc_1010138199_item	2225827	et	4	main
saadetakse	doc_1010138199_item	2225830	et	3	main
õpikud	doc_1010138199_item	2225833	et	3	main
talve	doc_1010138199_item	2225835	et	4	main
juba	doc_1010138199_item	2225841	et	3	main
toodi	doc_1010138199_item	2225843	et	4	main
on	doc_1010138199_item	2225846	et	4	main
veel	doc_1010138199_item	2225848	et	4	main
soojad	doc_1010138199_item	2225850	et	3	main
juba	doc_1010138199_item	2225853	et	3	main
juba	doc_1010138199_item	2225857	et	3	main
kui	doc_1010138199_item	2225863	et	3	main
seal	doc_1010138199_item	2225870	et	4	main
ei	doc_1010138199_item	2225873	et	4	main
naerab	doc_1010138199_item	2225875	et	3	main
3	doc_1010138199_item	2225915	et	2	main
paras	doc_1010138199_item	2225928	et	3	main
tagajärjeks	doc_1010138199_item	2225939	et	3	main
ei	doc_1010138199_item	2225941	et	4	main
ülekoormus	doc_1010138199_item	2225944	et	3	main
sportima	doc_1010138199_item	2225949	et	4	main
lasta	doc_1010138199_item	2225954	et	4	main
tekkitav	doc_1010138199_item	2225956	et	4	main
maandada	doc_1010138199_item	2225959	et	3	main
puhata	doc_1010138199_item	2225962	et	4	main
telefon	doc_1010138199_item	2225964	et	3	main
see	doc_1010138199_item	2225972	et	3	main
lausa	doc_1010138199_item	2225974	et	4	main
vanematest	doc_1010138198_item	2225468	et	4	main
nad	doc_1010138198_item	2225470	et	3	main
igaüks	doc_1010138198_item	2225476	et	3	main
kohandasin	doc_1010138198_item	2225479	et	3	main
nõuded	doc_1010138198_item	2225481	et	3	main
ma	doc_1010138198_item	2225484	et	3	main
selles	doc_1010138198_item	2225523	et	4	main
vaid	doc_1010138198_item	2225525	et	3	main
valdkond	doc_1010138198_item	2225535	et	3	main
külmetamine	doc_1010138198_item	2225548	et	4	main
tunnen	doc_1010138198_item	2225552	et	3	main
suvine	doc_1010138198_item	2225554	et	4	main
päikesest	doc_1010138198_item	2225557	et	4	main
täitke	doc_1010138198_item	2225559	et	3	main
kolmekäigulise	doc_1010138198_item	2225565	et	4	main
palju	doc_1010138198_item	2225570	et	4	main
olid	doc_1010138198_item	2225573	et	4	main
nende	doc_1010138198_item	2225577	et	4	main
kui	doc_1010138198_item	2225585	et	3	main
nagu	doc_1010138198_item	2225593	et	3	main
5	doc_1010138198_item	2225599	et	2	main
ta	doc_1010138198_item	2225600	et	4	main
ei	doc_1010138198_item	2225601	et	4	main
tule	doc_1010138198_item	2225602	et	4	main
trenni	doc_1010138198_item	2225603	et	4	main
sest	doc_1010138198_item	2225604	et	4	main
ta	doc_1010138198_item	2225605	et	4	main
läheb	doc_1010138198_item	2225606	et	3	main
hoopis	doc_1010138198_item	2225607	et	3	main
teatrisse	doc_1010138198_item	2225608	et	3	main
6	doc_1010138198_item	2225609	et	2	main
lõpetage	doc_1010138198_item	2225610	et	3	main
töö	doc_1010138198_item	2225611	et	4	main
te	doc_1010138198_item	2225612	et	4	main
varsti	doc_1010138198_item	2225613	et	3	main
lähete	doc_1010138198_item	2225614	et	4	main
jalutama	doc_1010138198_item	2225615	et	3	main
7	doc_1010138198_item	2225616	et	2	main
selles	doc_1010138198_item	2225617	et	4	main
baaris	doc_1010138198_item	2225618	et	3	main
ei	doc_1010138198_item	2225619	et	4	main
tohi	doc_1010138198_item	2225620	et	4	main
piirdusime	doc_1010138198_item	2225522	et	3	main
väikesed	doc_1010138198_item	2225526	et	4	main
muudatusi	doc_1010138198_item	2225529	et	3	main
see	doc_1010138198_item	2225531	et	3	main
kuulub	doc_1010138198_item	2225533	et	3	main
närimiskumm	doc_1010138198_item	2225539	et	3	main
peab	doc_1010138198_item	2225546	et	4	main
10	doc_1010138198_item	2225550	et	2	main
suvisest	doc_1010138198_item	2225556	et	4	main
v	doc_1010138198_item	2225558	et	4	main
lüngad	doc_1010138198_item	2225560	et	3	main
sidenditega	doc_1010138198_item	2225562	et	3	main
maksis	doc_1010138198_item	2225569	et	4	main
2	doc_1010138198_item	2225571	et	2	main
õpetajad	doc_1010138198_item	2225578	et	4	main
nii	doc_1010138198_item	2225583	et	3	main
tagasi	doc_1010138198_item	2225587	et	3	main
kõrvallauast	doc_1010138198_item	2225590	et	4	main
just	doc_1010138198_item	2225596	et	3	main
anekdooti	doc_1010138198_item	2225597	et	4	main
ja	doc_1010138198_item	2225622	et	3	main
nad	doc_1010138198_item	2225626	et	3	main
aga	doc_1010138198_item	2225630	et	3	main
sõidad	doc_1010138198_item	2225637	et	3	main
jääd	doc_1010138198_item	2225640	et	4	main
10	doc_1010138198_item	2225642	et	2	main
kuulsin	doc_1010138198_item	2225646	et	3	main
ettevõtlik	doc_1010138199_item	2225662	et	3	main
nägi	doc_1010138199_item	2225666	et	3	main
ta	doc_1010138199_item	2225667	et	4	main
ülem-suetuki	doc_1010138199_item	2225673	et	4	main
konkurss	doc_1010138199_item	2225682	et	3	main
nädala	doc_1010138199_item	2225690	et	3	main
eestlastele	doc_1010138199_item	2225692	et	4	main
emakeelt	doc_1010138199_item	2225695	et	4	main
siberisse	doc_1010138199_item	2225702	et	4	main
tulema	doc_1010138199_item	2225714	et	4	main
oodata	doc_1010138198_item	2225582	et	4	main
tulevad	doc_1010138198_item	2225588	et	4	main
kostis	doc_1010138198_item	2225591	et	4	main
oleks	doc_1010138198_item	2225594	et	3	main
rääkinud	doc_1010138198_item	2225598	et	4	main
suitsetada	doc_1010138198_item	2225621	et	3	main
alkoholi	doc_1010138198_item	2225623	et	4	main
pingsalt	doc_1010138198_item	2225629	et	4	main
kas	doc_1010138198_item	2225635	et	3	main
voi	doc_1010138198_item	2225639	et	4	main
sest	doc_1010138198_item	2225645	et	4	main
koputust	doc_1010138198_item	2225647	et	4	main
eesti	doc_1010138199_item	2225649	et	4	main
toomet	doc_1010138199_item	2225660	et	4	main
kuulutuse	doc_1010138199_item	2225670	et	4	main
siberisse	doc_1010138199_item	2225672	et	4	main
konkurssist	doc_1010138199_item	2225683	et	4	main
juba	doc_1010138199_item	2225687	et	3	main
jõudma	doc_1010138199_item	2225703	et	3	main
kui	doc_1010138199_item	2225712	et	3	main
siber	doc_1010138199_item	2225722	et	4	main
ei	doc_1010138199_item	2225728	et	4	main
kui	doc_1010138199_item	2225735	et	3	main
täis	doc_1010138199_item	2225740	et	4	main
pärast	doc_1010138199_item	2225742	et	4	main
veel	doc_1010138199_item	2225750	et	4	main
võtma	doc_1010138199_item	2225755	et	3	main
siin	doc_1010138199_item	2225760	et	4	main
tähtis	doc_1010138199_item	2225763	et	4	main
ettevõtmine	doc_1010138199_item	2225765	et	3	main
on	doc_1010138199_item	2225798	et	4	main
ülejäänud	doc_1010138199_item	2225803	et	4	main
ained	doc_1010138199_item	2225805	et	3	main
vene	doc_1010138199_item	2225807	et	4	main
veidi	doc_1010138199_item	2225811	et	3	main
kolmsada	doc_1010138199_item	2225813	et	4	main
emakeelt	doc_1010138199_item	2225817	et	4	main
kõik	doc_1010138199_item	2225819	et	4	main
siberi	doc_1010138199_item	2225834	et	4	main
ei	doc_1010138199_item	2225837	et	4	main
praegu	doc_1010138199_item	2225845	et	3	main
ööd	doc_1010138199_item	2225852	et	4	main
harjutan	doc_1010138199_item	2225856	et	3	main
ostan	doc_1010138199_item	2225865	et	3	main
muud	doc_1010138199_item	2225872	et	4	main
talveks	doc_1010138199_item	2225876	et	4	main
ja	doc_1010138199_item	2225910	et	3	main
lisakoormus	doc_1010138199_item	2225923	et	3	main
kogus	doc_1010138199_item	2225929	et	4	main
meid	doc_1010138199_item	2225932	et	4	main
võib	doc_1010138199_item	2225936	et	3	main
tohtima	doc_1010138199_item	2225942	et	3	main
pinge	doc_1010138199_item	2225946	et	4	main
tohi	doc_1010138199_item	2225953	et	4	main
pinge	doc_1010138199_item	2225957	et	4	main
saab	doc_1010138199_item	2225958	et	3	main
aparaat	doc_1010138199_item	2225970	et	3	main
elama	doc_1010138199_item	2225975	et	3	main
aparaat	doc_1010138199_item	2225983	et	3	main
telefonihelin	doc_1010138199_item	2225994	et	3	main
söömine	doc_1010138199_item	2226021	et	4	main
iv	doc_1010138199_item	2226027	et	4	main
pange	doc_1010138199_item	2226028	et	4	main
sõnad	doc_1010138199_item	2226031	et	4	main
1	doc_1010138199_item	2226034	et	2	main
väga	doc_1010138199_item	2226037	et	3	main
vanemad	doc_1010138199_item	2226040	et	4	main
vanematele	doc_1010138199_item	2226042	et	4	main
nad	doc_1010138199_item	2226044	et	3	main
ja	doc_1010138199_item	2226048	et	3	main
igaüht	doc_1010138199_item	2226051	et	3	main
nõudetele	doc_1010138199_item	2226056	et	4	main
et	doc_1010138199_item	2226060	et	3	main
huvitud	doc_1010138199_item	2226062	et	4	main
naised	doc_1010138199_item	2226071	et	3	main
kiired	doc_1010138199_item	2226073	et	4	main
ilusaid	doc_1010138199_item	2226075	et	3	main
kiireid	doc_1010138199_item	2226078	et	4	main
praegu	doc_1010138199_item	2226081	et	3	main
oht	doc_1010138199_item	2226083	et	3	main
difteeria	doc_1010138199_item	2226085	et	4	main
5	doc_1010138199_item	2226087	et	2	main
6	doc_1010138199_item	2226094	et	2	main
peab	doc_1010138199_item	2226121	et	4	main
külmetamisest	doc_1010138199_item	2226124	et	4	main
tarbida	doc_1010138198_item	2225624	et	3	main
tulemust	doc_1010138198_item	2225631	et	4	main
9	doc_1010138198_item	2225634	et	2	main
maale	doc_1010138198_item	2225638	et	4	main
ukse	doc_1010138198_item	2225644	et	3	main
keele	doc_1010138199_item	2225650	et	4	main
test	doc_1010138199_item	2225651	et	3	main
i	doc_1010138199_item	2225652	et	4	main
pange	doc_1010138199_item	2225653	et	4	main
sulgudes	doc_1010138199_item	2225654	et	4	main
olevad	doc_1010138199_item	2225655	et	4	main
sõnad	doc_1010138199_item	2225656	et	4	main
õigesse	doc_1010138199_item	2225657	et	3	main
vormi	doc_1010138199_item	2225658	et	4	main
suvel	doc_1010138199_item	2225664	et	3	main
otsitakse	doc_1010138199_item	2225676	et	3	main
keele	doc_1010138199_item	2225678	et	4	main
piret	doc_1010138199_item	2225680	et	4	main
nüüd	doc_1010138199_item	2225686	et	4	main
neid	doc_1010138199_item	2225694	et	4	main
õpetanud	doc_1010138199_item	2225697	et	4	main
tundis	doc_1010138199_item	2225700	et	3	main
jõuda	doc_1010138199_item	2225704	et	3	main
olin	doc_1010138199_item	2225708	et	3	main
üllatunud	doc_1010138199_item	2225711	et	4	main
mulle	doc_1010138199_item	2225713	et	4	main
vastu	doc_1010138199_item	2225716	et	3	main
audiga	doc_1010138199_item	2225719	et	3	main
et	doc_1010138199_item	2225726	et	3	main
seal	doc_1010138199_item	2225727	et	4	main
lenda	doc_1010138199_item	2225730	et	4	main
kasva	doc_1010138199_item	2225733	et	4	main
tahtmine	doc_1010138199_item	2225738	et	4	main
jõudis	doc_1010138199_item	2225747	et	3	main
kool	doc_1010138199_item	2225749	et	4	main
kartuleid	doc_1010138199_item	2225757	et	3	main
kõige	doc_1010138199_item	2225762	et	4	main
on	doc_1010138199_item	2225767	et	4	main
murret	doc_1010138199_item	2225796	et	4	main
kool	doc_1010138199_item	2225801	et	4	main
saab	doc_1010138199_item	2225818	et	3	main
ta	doc_1010138199_item	2225701	et	4	main
on	doc_1010138199_item	2225706	et	4	main
üllatuma	doc_1010138199_item	2225710	et	3	main
korraliku	doc_1010138199_item	2225718	et	3	main
mulle	doc_1010138199_item	2225720	et	4	main
maaliti	doc_1010138199_item	2225721	et	3	main
siberist	doc_1010138199_item	2225723	et	4	main
lendama	doc_1010138199_item	2225729	et	3	main
ega	doc_1010138199_item	2225732	et	3	main
ja	doc_1010138199_item	2225737	et	3	main
õppeaasta	doc_1010138199_item	2225743	et	4	main
koht	doc_1010138199_item	2225745	et	3	main
polnud	doc_1010138199_item	2225748	et	3	main
kogu	doc_1010138199_item	2225753	et	4	main
võttis	doc_1010138199_item	2225756	et	3	main
kartulivõtt	doc_1010138199_item	2225758	et	3	main
kartul	doc_1010138199_item	2225768	et	3	main
mõnd	doc_1010138199_item	2225795	et	3	main
kool	doc_1010138199_item	2225797	et	4	main
siiski	doc_1010138199_item	2225799	et	4	main
aine	doc_1010138199_item	2225804	et	4	main
õpetatakse	doc_1010138199_item	2225806	et	3	main
külas	doc_1010138199_item	2225809	et	3	main
kolmesaja	doc_1010138199_item	2225814	et	4	main
rääkida	doc_1010138199_item	2225821	et	3	main
sõnul	doc_1010138199_item	2225823	et	3	main
saatma	doc_1010138199_item	2225829	et	3	main
eestist	doc_1010138199_item	2225831	et	3	main
piret	doc_1010138199_item	2225836	et	4	main
kartma	doc_1010138199_item	2225838	et	3	main
talvepuud	doc_1010138199_item	2225844	et	4	main
jahe	doc_1010138199_item	2225854	et	3	main
suure	doc_1010138199_item	2225858	et	3	main
vaja	doc_1010138199_item	2225864	et	4	main
vildid	doc_1010138199_item	2225868	et	4	main
suurt	doc_1010138199_item	2225871	et	3	main
valmistuma	doc_1010138199_item	2225877	et	3	main
mehi	doc_1010138199_item	2225911	et	3	main
igaüht	doc_1010138199_item	2225913	et	3	main
panema	doc_1010138199_item	2225919	et	3	main
tegutsema	doc_1010138199_item	2225921	et	3	main
stress	doc_1010138199_item	2225930	et	3	main
tegutsema	doc_1010138199_item	2225933	et	3	main
lisakoormus	doc_1010138199_item	2225935	et	3	main
laskma	doc_1010138199_item	2225943	et	3	main
ja	doc_1010138199_item	2225950	et	3	main
ja	doc_1010138199_item	2225961	et	3	main
tänapäev	doc_1010138199_item	2225966	et	3	main
maagiline	doc_1010138199_item	2225969	et	4	main
telefon	doc_1010138199_item	2225979	et	3	main
selle	doc_1010138199_item	2225985	et	4	main
abil	doc_1010138199_item	2225986	et	4	main
elada	doc_1010138199_item	2225989	et	3	main
pühapäev	doc_1010138199_item	2225997	et	3	main
uni	doc_1010138199_item	2225999	et	3	main
huvitava	doc_1010138199_item	2226023	et	4	main
aega	doc_1010138199_item	2226026	et	4	main
oma	doc_1010138199_item	2226041	et	4	main
sest	doc_1010138199_item	2226043	et	4	main
usaldavad	doc_1010138199_item	2226049	et	4	main
igaüks	doc_1010138199_item	2226050	et	3	main
kohandasin	doc_1010138199_item	2226053	et	3	main
nõuded	doc_1010138199_item	2226055	et	3	main
3	doc_1010138199_item	2226057	et	2	main
arvasin	doc_1010138199_item	2226059	et	3	main
ja	doc_1010138199_item	2226072	et	3	main
autosid	doc_1010138199_item	2226079	et	3	main
haigestuda	doc_1010138199_item	2226084	et	3	main
tüdinesin	doc_1010138199_item	2226088	et	3	main
uue	doc_1010138199_item	2226091	et	3	main
vaid	doc_1010138199_item	2226098	et	3	main
rõõmu	doc_1010138199_item	2226128	et	4	main
suvest	doc_1010138199_item	2226131	et	3	main
v	doc_1010138199_item	2226133	et	4	main
lõuna	doc_1010138199_item	2226141	et	4	main
olid	doc_1010138199_item	2226148	et	4	main
just	doc_1010138199_item	2226168	et	3	main
rääkinud	doc_1010138199_item	2226170	et	4	main
tule	doc_1010138199_item	2226174	et	4	main
läheb	doc_1010138199_item	2226177	et	3	main
lähete	doc_1010138199_item	2226184	et	4	main
ei	doc_1010138199_item	2226189	et	4	main
küll	doc_1010138199_item	2226198	et	4	main
tulemust	doc_1010138199_item	2226201	et	4	main
9	doc_1010138199_item	2226204	et	2	main
selline	doc_1010138199_item	2225724	et	4	main
rohi	doc_1010138199_item	2225734	et	4	main
noor	doc_1010138199_item	2225736	et	3	main
tähtmist	doc_1010138199_item	2225739	et	4	main
piret	doc_1010138199_item	2225741	et	4	main
alanud	doc_1010138199_item	2225752	et	4	main
on	doc_1010138199_item	2225759	et	4	main
salv	doc_1010138199_item	2225769	et	3	main
salves	doc_1010138199_item	2225770	et	4	main
ja	doc_1010138199_item	2225771	et	3	main
õppimine	doc_1010138199_item	2225772	et	4	main
käib	doc_1010138199_item	2225773	et	3	main
täie	doc_1010138199_item	2225774	et	3	main
hoog	doc_1010138199_item	2225775	et	3	main
hoos	doc_1010138199_item	2225776	et	3	main
siinsed	doc_1010138199_item	2225777	et	3	main
eestlased	doc_1010138199_item	2225778	et	3	main
räägivad	doc_1010138199_item	2225779	et	3	main
kuidagi	doc_1010138199_item	2225780	et	3	main
teistmoodi	doc_1010138199_item	2225781	et	3	main
mõnus	doc_1010138199_item	2225782	et	4	main
ja	doc_1010138199_item	2225783	et	3	main
mahlakas	doc_1010138199_item	2225784	et	4	main
mõnusamalt	doc_1010138199_item	2225785	et	4	main
ja	doc_1010138199_item	2225786	et	3	main
mahlakalt	doc_1010138199_item	2225787	et	4	main
mitte	doc_1010138199_item	2225788	et	3	main
vene	doc_1010138199_item	2225789	et	4	main
aktsent	doc_1010138199_item	2225790	et	3	main
aktsendiga	doc_1010138199_item	2225791	et	3	main
vaid	doc_1010138199_item	2225792	et	3	main
nagu	doc_1010138199_item	2225793	et	3	main
mõni	doc_1010138199_item	2225794	et	3	main
venemaa	doc_1010138199_item	2225800	et	4	main
ja	doc_1010138199_item	2225802	et	3	main
keeles	doc_1010138199_item	2225808	et	4	main
elab	doc_1010138199_item	2225810	et	3	main
inimest	doc_1010138199_item	2225816	et	3	main
pireti	doc_1010138199_item	2225822	et	4	main
lapsed	doc_1010138199_item	2225825	et	3	main
varsti	doc_1010138199_item	2225828	et	3	main
uued	doc_1010138199_item	2225832	et	3	main
mulle	doc_1010138199_item	2225840	et	4	main
päevad	doc_1010138199_item	2225847	et	3	main
jahedamad	doc_1010138199_item	2225855	et	4	main
vene	doc_1010138199_item	2225859	et	4	main
kütmine	doc_1010138199_item	2225861	et	4	main
külapoest	doc_1010138199_item	2225867	et	4	main
mehelikum	doc_1010138199_item	2225912	et	4	main
paras	doc_1010138199_item	2225916	et	3	main
meie	doc_1010138199_item	2225920	et	4	main
võima	doc_1010138199_item	2225924	et	3	main
tagajärg	doc_1010138199_item	2225927	et	3	main
paneb	doc_1010138199_item	2225931	et	3	main
soovimatu	doc_1010138199_item	2225938	et	4	main
saama	doc_1010138199_item	2225947	et	4	main
ei	doc_1010138199_item	2225952	et	4	main
ülekoormust	doc_1010138199_item	2225955	et	4	main
saama	doc_1010138199_item	2225967	et	4	main
tänapäevaks	doc_1010138199_item	2225978	et	3	main
on	doc_1010138199_item	2225980	et	4	main
et	doc_1010138199_item	2225984	et	3	main
lausa	doc_1010138199_item	2225988	et	4	main
6	doc_1010138199_item	2225992	et	2	main
ka	doc_1010138199_item	2225996	et	3	main
pahandab	doc_1010138199_item	2226022	et	3	main
vormi	doc_1010138199_item	2226033	et	4	main
pean	doc_1010138199_item	2226036	et	4	main
oma	doc_1010138199_item	2226039	et	4	main
kõike	doc_1010138199_item	2226047	et	4	main
sport	doc_1010138199_item	2226063	et	3	main
sporti	doc_1010138199_item	2226064	et	4	main
sa	doc_1010138199_item	2226066	et	3	main
huvi	doc_1010138199_item	2226068	et	4	main
töökoha	doc_1010138199_item	2226092	et	4	main
kiiresti	doc_1010138199_item	2226093	et	3	main
selles	doc_1010138199_item	2226096	et	4	main
hoiduma	doc_1010138199_item	2226122	et	3	main
ma	doc_1010138199_item	2226126	et	3	main
päikest	doc_1010138199_item	2226132	et	4	main
lüngad	doc_1010138199_item	2226135	et	3	main
sidenditega	doc_1010138199_item	2226137	et	3	main
kolmekäigulise	doc_1010138199_item	2226140	et	4	main
kuid	doc_1010138199_item	2226142	et	4	main
palju	doc_1010138199_item	2226145	et	4	main
kostis	doc_1010138199_item	2226163	et	4	main
ei	doc_1010138199_item	2226173	et	4	main
aga	doc_1010138199_item	2226176	et	3	main
6	doc_1010138199_item	2226180	et	2	main
tohi	doc_1010138199_item	2226190	et	4	main
8	doc_1010138199_item	2226195	et	2	main
töötasid	doc_1010138199_item	2226197	et	4	main
kuigi	doc_1010138199_item	2226200	et	3	main
sõidad	doc_1010138199_item	2226207	et	3	main
avasin	doc_1010138199_item	2226213	et	3	main
kui	doc_1010138199_item	2226215	et	3	main
i	doc_1010138200_item	2226219	et	4	main
sõnad	doc_1010138200_item	2226223	et	4	main
ettevõtlik	doc_1010138200_item	2226229	et	3	main
nägema	doc_1010138200_item	2226232	et	3	main
ülem-suetuki	doc_1010138200_item	2226239	et	4	main
külas	doc_1010138200_item	2226241	et	3	main
võitis	doc_1010138200_item	2226247	et	3	main
nädala	doc_1010138200_item	2226256	et	3	main
tundis	doc_1010138200_item	2226266	et	3	main
siberisse	doc_1010138200_item	2226268	et	4	main
jõudis	doc_1010138200_item	2226270	et	3	main
üllatunud	doc_1010138200_item	2226277	et	4	main
mulle	doc_1010138200_item	2226279	et	4	main
korralik	doc_1010138200_item	2226283	et	3	main
maaliti	doc_1010138200_item	2226286	et	3	main
siberi	doc_1010138200_item	2226288	et	4	main
pilt	doc_1010138200_item	2226290	et	3	main
lenda	doc_1010138200_item	2226295	et	4	main
kasva	doc_1010138200_item	2226298	et	4	main
tähtsam	doc_1010138200_item	2226329	et	4	main
salves	doc_1010138200_item	2226335	et	4	main
õppimine	doc_1010138200_item	2226337	et	4	main
õpivad	doc_1010138199_item	2225824	et	3	main
poolpõlenud	doc_1010138199_item	2225826	et	4	main
karta	doc_1010138199_item	2225839	et	3	main
tooma	doc_1010138199_item	2225842	et	3	main
soe	doc_1010138199_item	2225849	et	4	main
kuid	doc_1010138199_item	2225851	et	4	main
ahju	doc_1010138199_item	2225860	et	4	main
kütmist	doc_1010138199_item	2225862	et	4	main
külapood	doc_1010138199_item	2225866	et	3	main
ega	doc_1010138199_item	2225869	et	3	main
müüdagi	doc_1010138199_item	2225874	et	3	main
valmistutud	doc_1010138199_item	2225878	et	4	main
piret	doc_1010138199_item	2225879	et	4	main
vapralt	doc_1010138199_item	2225880	et	4	main
lühendatud	doc_1010138199_item	2225881	et	4	main
ajalehest	doc_1010138199_item	2225882	et	4	main
slõhtuleht	doc_1010138199_item	2225883	et	4	main
iii	doc_1010138199_item	2225884	et	4	main
moodustage	doc_1010138199_item	2225885	et	3	main
etteantud	doc_1010138199_item	2225886	et	4	main
sõnadest	doc_1010138199_item	2225887	et	3	main
laused	doc_1010138199_item	2225888	et	3	main
pannes	doc_1010138199_item	2225889	et	4	main
sõnad	doc_1010138199_item	2225890	et	4	main
õigesse	doc_1010138199_item	2225891	et	3	main
vormi	doc_1010138199_item	2225892	et	4	main
ja	doc_1010138199_item	2225893	et	3	main
kasutades	doc_1010138199_item	2225894	et	3	main
kirjavahemärke	doc_1010138199_item	2225895	et	4	main
2	doc_1010138199_item	2225896	et	2	main
naeratus	doc_1010138199_item	2225897	et	4	main
tegema	doc_1010138199_item	2225898	et	3	main
naised	doc_1010138199_item	2225899	et	3	main
naiselikum	doc_1010138199_item	2225900	et	4	main
ja	doc_1010138199_item	2225901	et	3	main
mehed	doc_1010138199_item	2225902	et	3	main
mehelikum	doc_1010138199_item	2225903	et	4	main
igaüks	doc_1010138199_item	2225904	et	3	main
kaunim	doc_1010138199_item	2225905	et	4	main
naeratus	doc_1010138199_item	2225906	et	4	main
teeb	doc_1010138199_item	2225907	et	3	main
naisi	doc_1010138199_item	2225908	et	3	main
naiselikum	doc_1010138199_item	2225909	et	4	main
kaunim	doc_1010138199_item	2225914	et	4	main
kogus	doc_1010138199_item	2225917	et	4	main
stress	doc_1010138199_item	2225918	et	3	main
aga	doc_1010138199_item	2225922	et	3	main
tooma	doc_1010138199_item	2225925	et	3	main
soovimatu	doc_1010138199_item	2225926	et	4	main
aga	doc_1010138199_item	2225934	et	3	main
tuua	doc_1010138199_item	2225937	et	3	main
4	doc_1010138199_item	2225940	et	2	main
tekkima	doc_1010138199_item	2225945	et	3	main
maandama	doc_1010138199_item	2225948	et	3	main
puhkama	doc_1010138199_item	2225951	et	3	main
sportida	doc_1010138199_item	2225960	et	4	main
5	doc_1010138199_item	2225963	et	2	main
olema	doc_1010138199_item	2225965	et	4	main
nii	doc_1010138199_item	2225968	et	3	main
et	doc_1010138199_item	2225971	et	3	main
abil	doc_1010138199_item	2225973	et	4	main
ja	doc_1010138199_item	2225976	et	3	main
nii	doc_1010138199_item	2225981	et	3	main
hingata	doc_1010138199_item	2225991	et	4	main
katkestama	doc_1010138199_item	2225995	et	3	main
segama	doc_1010138199_item	2226000	et	3	main
valmistamine	doc_1010138199_item	2226002	et	4	main
ja	doc_1010138199_item	2226003	et	3	main
söömine	doc_1010138199_item	2226004	et	4	main
pahandab	doc_1010138199_item	2226005	et	3	main
huvitav	doc_1010138199_item	2226006	et	4	main
telesaade	doc_1010138199_item	2226007	et	4	main
vaatamine	doc_1010138199_item	2226008	et	4	main
aeg	doc_1010138199_item	2226009	et	3	main
kuid	doc_1010138199_item	2226010	et	4	main
telefonihelin	doc_1010138199_item	2226011	et	3	main
katkestab	doc_1010138199_item	2226012	et	3	main
ka	doc_1010138199_item	2226013	et	3	main
pühapäeval	doc_1010138199_item	2226014	et	3	main
varahommikul	doc_1010138199_item	2226015	et	3	main
und	doc_1010138199_item	2226016	et	4	main
segab	doc_1010138199_item	2226017	et	3	main
lõunasööki	doc_1010138199_item	2226018	et	4	main
valmistamist	doc_1010138199_item	2226019	et	4	main
ja	doc_1010138199_item	2226020	et	3	main
vaatamise	doc_1010138199_item	2226025	et	4	main
olevad	doc_1010138199_item	2226030	et	4	main
õigesse	doc_1010138199_item	2226032	et	3	main
kõik	doc_1010138199_item	2226046	et	4	main
2	doc_1010138199_item	2226052	et	2	main
artikli	doc_1010138199_item	2226054	et	3	main
ma	doc_1010138199_item	2226058	et	3	main
tunned	doc_1010138199_item	2226067	et	3	main
ilusad	doc_1010138199_item	2226070	et	3	main
autod	doc_1010138199_item	2226074	et	3	main
naisi	doc_1010138199_item	2226076	et	3	main
on	doc_1010138199_item	2226082	et	4	main
töökoht	doc_1010138199_item	2226090	et	3	main
piirdusime	doc_1010138199_item	2226095	et	3	main
küsimuses	doc_1010138199_item	2226097	et	4	main
külmetamine	doc_1010138199_item	2226123	et	4	main
suvine	doc_1010138199_item	2226129	et	4	main
1	doc_1010138199_item	2226138	et	2	main
see	doc_1010138199_item	2226143	et	3	main
2	doc_1010138199_item	2226146	et	2	main
nii	doc_1010138199_item	2226149	et	3	main
oleks	doc_1010138199_item	2226166	et	3	main
ta	doc_1010138199_item	2226172	et	4	main
trenni	doc_1010138199_item	2226175	et	4	main
teatrisse	doc_1010138199_item	2226179	et	3	main
töö	doc_1010138199_item	2226182	et	4	main
jalutama	doc_1010138199_item	2226185	et	3	main
hingama	doc_1010138199_item	2225977	et	3	main
maagiline	doc_1010138199_item	2225982	et	4	main
saab	doc_1010138199_item	2225987	et	3	main
ja	doc_1010138199_item	2225990	et	3	main
kuid	doc_1010138199_item	2225993	et	4	main
varahommik	doc_1010138199_item	2225998	et	3	main
lõunasöök	doc_1010138199_item	2226001	et	3	main
telesaate	doc_1010138199_item	2226024	et	3	main
sulgudes	doc_1010138199_item	2226029	et	4	main
ma	doc_1010138199_item	2226035	et	3	main
lugu	doc_1010138199_item	2226038	et	4	main
aitavad	doc_1010138199_item	2226045	et	4	main
sa	doc_1010138199_item	2226061	et	3	main
aga	doc_1010138199_item	2226065	et	3	main
ainult	doc_1010138199_item	2226069	et	4	main
ja	doc_1010138199_item	2226077	et	3	main
4	doc_1010138199_item	2226080	et	2	main
difteeriaks	doc_1010138199_item	2226086	et	3	main
uus	doc_1010138199_item	2226089	et	3	main
väikesed	doc_1010138199_item	2226099	et	4	main
muudatused	doc_1010138199_item	2226100	et	3	main
väikeste	doc_1010138199_item	2226101	et	4	main
muudatusega	doc_1010138199_item	2226102	et	3	main
7	doc_1010138199_item	2226103	et	2	main
see	doc_1010138199_item	2226104	et	3	main
küsimus	doc_1010138199_item	2226105	et	4	main
kuulub	doc_1010138199_item	2226106	et	3	main
teine	doc_1010138199_item	2226107	et	3	main
valdkond	doc_1010138199_item	2226108	et	3	main
teisele	doc_1010138199_item	2226109	et	4	main
valdkonnale	doc_1010138199_item	2226110	et	4	main
8	doc_1010138199_item	2226111	et	2	main
närimiskumm	doc_1010138199_item	2226112	et	3	main
kleepus	doc_1010138199_item	2226113	et	3	main
püksid	doc_1010138199_item	2226114	et	3	main
püksidesse	doc_1010138199_item	2226115	et	3	main
pükside	doc_1010138199_item	2226116	et	3	main
peale	doc_1010138199_item	2226117	et	4	main
9	doc_1010138199_item	2226118	et	2	main
külmal	doc_1010138199_item	2226119	et	3	main
ajal	doc_1010138199_item	2226120	et	4	main
10	doc_1010138199_item	2226125	et	2	main
tunnen	doc_1010138199_item	2226127	et	3	main
naa	doc_1010138199_item	2226151	et	3	main
õpilased	doc_1010138199_item	2226150	et	3	main
3	doc_1010138199_item	2226153	et	2	main
õpetajad	doc_1010138199_item	2226152	et	4	main
lapsel	doc_1010138199_item	2226154	et	4	main
paluti	doc_1010138199_item	2226155	et	3	main
oodata	doc_1010138199_item	2226156	et	4	main
kui	doc_1010138199_item	2226157	et	3	main
vanemad	doc_1010138199_item	2226158	et	4	main
tagasi	doc_1010138199_item	2226159	et	3	main
tulevad	doc_1010138199_item	2226160	et	4	main
4	doc_1010138199_item	2226161	et	2	main
kõrvallauast	doc_1010138199_item	2226162	et	4	main
päike	doc_1010138199_item	2226130	et	3	main
täitke	doc_1010138199_item	2226134	et	3	main
sobivate	doc_1010138199_item	2226136	et	4	main
tellisime	doc_1010138199_item	2226139	et	4	main
maksis	doc_1010138199_item	2226144	et	4	main
kohal	doc_1010138199_item	2226147	et	4	main
et	doc_1010138199_item	2226165	et	3	main
keegi	doc_1010138199_item	2226167	et	4	main
anekdooti	doc_1010138199_item	2226169	et	4	main
selles	doc_1010138199_item	2226187	et	4	main
suitsetada	doc_1010138199_item	2226191	et	3	main
alkoholi	doc_1010138199_item	2226193	et	4	main
nad	doc_1010138199_item	2226196	et	3	main
maale	doc_1010138199_item	2226208	et	4	main
10	doc_1010138199_item	2226212	et	2	main
õigesse	doc_1010138200_item	2226224	et	3	main
piret	doc_1010138200_item	2226226	et	4	main
naine	doc_1010138200_item	2226230	et	3	main
siberisse	doc_1010138200_item	2226238	et	4	main
eesti	doc_1010138200_item	2226243	et	4	main
ja	doc_1010138200_item	2226250	et	3	main
õpetab	doc_1010138200_item	2226263	et	3	main
kinnitusel	doc_1010138200_item	2226265	et	4	main
on	doc_1010138200_item	2226272	et	4	main
üsna	doc_1010138200_item	2226275	et	3	main
vastu	doc_1010138200_item	2226282	et	3	main
mulle	doc_1010138200_item	2226285	et	4	main
lendama	doc_1010138200_item	2226294	et	3	main
kartuleid	doc_1010138200_item	2226322	et	3	main
siinsed	doc_1010138200_item	2226341	et	3	main
siiski	doc_1010138200_item	2226363	et	4	main
ja	doc_1010138200_item	2226366	et	3	main
külas	doc_1010138200_item	2226373	et	3	main
emakeelt	doc_1010138200_item	2226381	et	4	main
rääkida	doc_1010138200_item	2226384	et	3	main
varsti	doc_1010138200_item	2226391	et	3	main
saatma	doc_1010138200_item	2226392	et	3	main
uued	doc_1010138200_item	2226395	et	3	main
talve	doc_1010138200_item	2226398	et	4	main
mulle	doc_1010138200_item	2226403	et	4	main
toodi	doc_1010138200_item	2226406	et	4	main
on	doc_1010138200_item	2226409	et	4	main
sojad	doc_1010138200_item	2226413	et	3	main
juba	doc_1010138200_item	2226416	et	3	main
harjutan	doc_1010138200_item	2226419	et	3	main
kütmine	doc_1010138200_item	2226424	et	4	main
kui	doc_1010138200_item	2226426	et	3	main
muud	doc_1010138200_item	2226435	et	4	main
vapralt	doc_1010138200_item	2226443	et	4	main
slõhtuleht	doc_1010138200_item	2226446	et	4	main
etteantud	doc_1010138200_item	2226449	et	4	main
ja	doc_1010138200_item	2226456	et	3	main
tegema	doc_1010138200_item	2226461	et	3	main
lisakoormus	doc_1010138200_item	2226486	et	3	main
meie	doc_1010138200_item	2226495	et	4	main
tuua	doc_1010138200_item	2226500	et	3	main
tagajärgi	doc_1010138200_item	2226502	et	4	main
tohtima	doc_1010138200_item	2226505	et	3	main
saama	doc_1010138200_item	2226510	et	4	main
ja	doc_1010138200_item	2226513	et	3	main
olema	doc_1010138200_item	2226517	et	4	main
aparaat	doc_1010138200_item	2226522	et	3	main
abil	doc_1010138200_item	2226525	et	4	main
elama	doc_1010138200_item	2226527	et	3	main
telefon	doc_1010138200_item	2226531	et	3	main
maagiline	doc_1010138200_item	2226534	et	4	main
selle	doc_1010138200_item	2226537	et	4	main
6	doc_1010138200_item	2226543	et	2	main
söömine	doc_1010138200_item	2226555	et	4	main
lõunasööki	doc_1010138200_item	2226569	et	4	main
telesaade	doc_1010138200_item	2226575	et	4	main
aega	doc_1010138200_item	2226577	et	4	main
pange	doc_1010138200_item	2226579	et	4	main
olevad	doc_1010138200_item	2226581	et	4	main
õigesse	doc_1010138200_item	2226583	et	3	main
väga	doc_1010138200_item	2226588	et	3	main
oma	doc_1010138200_item	2226590	et	4	main
kõik	doc_1010138200_item	2226597	et	4	main
nõuded	doc_1010138200_item	2226606	et	3	main
ma	doc_1010138200_item	2226609	et	3	main
ilusad	doc_1010138200_item	2226621	et	3	main
ja	doc_1010138200_item	2226623	et	3	main
autod	doc_1010138200_item	2226625	et	3	main
oht	doc_1010138200_item	2226634	et	3	main
difteeriaks	doc_1010138200_item	2226637	et	3	main
naeru	doc_1010138199_item	2226164	et	4	main
5	doc_1010138199_item	2226171	et	2	main
hoopis	doc_1010138199_item	2226178	et	3	main
lõpetage	doc_1010138199_item	2226181	et	3	main
siis	doc_1010138199_item	2226183	et	3	main
7	doc_1010138199_item	2226186	et	2	main
baaris	doc_1010138199_item	2226188	et	3	main
pingsalt	doc_1010138199_item	2226199	et	4	main
olnud	doc_1010138199_item	2226203	et	4	main
või	doc_1010138199_item	2226209	et	4	main
linna	doc_1010138199_item	2226211	et	4	main
ukse	doc_1010138199_item	2226214	et	3	main
koputust	doc_1010138199_item	2226217	et	4	main
pange	doc_1010138200_item	2226220	et	4	main
on	doc_1010138200_item	2226228	et	4	main
suvel	doc_1010138200_item	2226231	et	3	main
ajalehes	doc_1010138200_item	2226235	et	3	main
õpetajat	doc_1010138200_item	2226245	et	4	main
konkurss	doc_1010138200_item	2226248	et	3	main
nüüd	doc_1010138200_item	2226252	et	4	main
üle	doc_1010138200_item	2226254	et	3	main
väikestele	doc_1010138200_item	2226257	et	4	main
need	doc_1010138200_item	2226259	et	3	main
emakeelt	doc_1010138200_item	2226261	et	4	main
pireti	doc_1010138200_item	2226264	et	4	main
jõudma	doc_1010138200_item	2226269	et	3	main
olin	doc_1010138200_item	2226274	et	3	main
selline	doc_1010138200_item	2226289	et	4	main
seal	doc_1010138200_item	2226292	et	4	main
ega	doc_1010138200_item	2226297	et	3	main
on	doc_1010138200_item	2226324	et	4	main
siin	doc_1010138200_item	2226325	et	4	main
ettevõtmine	doc_1010138200_item	2226330	et	3	main
kartul	doc_1010138200_item	2226333	et	3	main
ja	doc_1010138200_item	2226336	et	3	main
käib	doc_1010138200_item	2226338	et	3	main
teistmoodi	doc_1010138200_item	2226345	et	3	main
mahlakas	doc_1010138200_item	2226348	et	4	main
vene	doc_1010138200_item	2226371	et	4	main
kolmsada	doc_1010138200_item	2226377	et	4	main
inimene	doc_1010138200_item	2226379	et	3	main
sõnul	doc_1010138200_item	2226386	et	3	main
raamatud	doc_1010138200_item	2226390	et	4	main
siberi	doc_1010138200_item	2226397	et	4	main
piret	doc_1010138200_item	2226399	et	4	main
juba	doc_1010138200_item	2226404	et	3	main
veel	doc_1010138200_item	2226411	et	4	main
jahedad	doc_1010138200_item	2226418	et	3	main
juba	doc_1010138200_item	2226420	et	3	main
suure	doc_1010138200_item	2226421	et	3	main
ahju	doc_1010138200_item	2226423	et	4	main
külapood	doc_1010138200_item	2226429	et	3	main
suurt	doc_1010138200_item	2226434	et	3	main
valmistunud	doc_1010138200_item	2226441	et	4	main
õigesse	doc_1010138200_item	2226454	et	3	main
2	doc_1010138200_item	2226459	et	2	main
tooma	doc_1010138200_item	2226488	et	3	main
stress	doc_1010138200_item	2226493	et	3	main
aga	doc_1010138200_item	2226497	et	3	main
laskma	doc_1010138200_item	2226506	et	3	main
maandama	doc_1010138200_item	2226511	et	3	main
telefon	doc_1010138200_item	2226516	et	3	main
ja	doc_1010138199_item	2226192	et	3	main
tarbida	doc_1010138199_item	2226194	et	3	main
ei	doc_1010138199_item	2226202	et	4	main
kas	doc_1010138199_item	2226205	et	3	main
kuulsin	doc_1010138199_item	2226216	et	3	main
eksamitöö	doc_1010138200_item	2226218	et	4	main
sa	doc_1010138199_item	2226206	et	3	main
jääd	doc_1010138199_item	2226210	et	4	main
sulgudes	doc_1010138200_item	2226221	et	4	main
toomet	doc_1010138200_item	2226227	et	4	main
ta	doc_1010138200_item	2226234	et	4	main
et	doc_1010138200_item	2226237	et	3	main
küla	doc_1010138200_item	2226240	et	4	main
otsitakse	doc_1010138200_item	2226242	et	3	main
keele	doc_1010138200_item	2226244	et	4	main
konkurssi	doc_1010138200_item	2226249	et	4	main
juba	doc_1010138200_item	2226253	et	3	main
eestlastele	doc_1010138200_item	2226258	et	4	main
õpetama	doc_1010138200_item	2226262	et	3	main
ta	doc_1010138200_item	2226267	et	4	main
oodatud	doc_1010138200_item	2226273	et	4	main
kui	doc_1010138200_item	2226278	et	3	main
tulema	doc_1010138200_item	2226280	et	4	main
audiga	doc_1010138200_item	2226284	et	3	main
et	doc_1010138200_item	2226291	et	3	main
ei	doc_1010138200_item	2226293	et	4	main
rohi	doc_1010138200_item	2226299	et	4	main
võtab	doc_1010138200_item	2226321	et	3	main
kõige	doc_1010138200_item	2226327	et	4	main
tähtis	doc_1010138200_item	2226328	et	4	main
tänaseks	doc_1010138200_item	2226331	et	4	main
on	doc_1010138200_item	2226332	et	4	main
hoog	doc_1010138200_item	2226340	et	3	main
räägivad	doc_1010138200_item	2226343	et	3	main
mõnusamalt	doc_1010138200_item	2226349	et	4	main
ja	doc_1010138200_item	2226350	et	3	main
kool	doc_1010138200_item	2226365	et	4	main
ülejäänud	doc_1010138200_item	2226367	et	4	main
ained	doc_1010138200_item	2226369	et	3	main
elab	doc_1010138200_item	2226374	et	3	main
üle	doc_1010138200_item	2226376	et	3	main
inimest	doc_1010138200_item	2226380	et	3	main
pireti	doc_1010138200_item	2226385	et	4	main
õpivad	doc_1010138200_item	2226387	et	3	main
eestist	doc_1010138200_item	2226394	et	3	main
õpikud	doc_1010138200_item	2226396	et	3	main
kartma	doc_1010138200_item	2226401	et	3	main
soe	doc_1010138200_item	2226412	et	4	main
ööd	doc_1010138200_item	2226415	et	4	main
olevad	doc_1010138200_item	2226222	et	4	main
vormi	doc_1010138200_item	2226225	et	4	main
nägi	doc_1010138200_item	2226233	et	3	main
kuulutus	doc_1010138200_item	2226236	et	4	main
piret	doc_1010138200_item	2226246	et	4	main
on	doc_1010138200_item	2226251	et	4	main
nädal	doc_1010138200_item	2226255	et	3	main
nende	doc_1010138200_item	2226260	et	4	main
et	doc_1010138200_item	2226271	et	3	main
üllatuma	doc_1010138200_item	2226276	et	3	main
tuleb	doc_1010138200_item	2226281	et	3	main
siber	doc_1010138200_item	2226287	et	4	main
lind	doc_1010138200_item	2226296	et	3	main
kui	doc_1010138200_item	2226300	et	3	main
noor	doc_1010138200_item	2226301	et	3	main
ja	doc_1010138200_item	2226302	et	3	main
tahtmine	doc_1010138200_item	2226303	et	4	main
täis	doc_1010138200_item	2226305	et	4	main
piret	doc_1010138200_item	2226306	et	4	main
tahtmise	doc_1010138200_item	2226304	et	4	main
pärast	doc_1010138200_item	2226307	et	4	main
õppeaasta	doc_1010138200_item	2226308	et	4	main
algust	doc_1010138200_item	2226309	et	4	main
koht	doc_1010138200_item	2226310	et	3	main
kohta	doc_1010138200_item	2226311	et	4	main
polnud	doc_1010138200_item	2226313	et	3	main
kool	doc_1010138200_item	2226314	et	4	main
jõudis	doc_1010138200_item	2226312	et	3	main
veel	doc_1010138200_item	2226315	et	4	main
algama	doc_1010138200_item	2226316	et	3	main
algab	doc_1010138200_item	2226317	et	3	main
kogu	doc_1010138200_item	2226318	et	4	main
küla	doc_1010138200_item	2226319	et	4	main
võtma	doc_1010138200_item	2226320	et	3	main
kartulivõtt	doc_1010138200_item	2226323	et	3	main
sügisel	doc_1010138200_item	2226326	et	3	main
salv	doc_1010138200_item	2226334	et	3	main
eestlased	doc_1010138200_item	2226342	et	3	main
kuidagi	doc_1010138200_item	2226344	et	3	main
ja	doc_1010138200_item	2226347	et	3	main
mitte	doc_1010138200_item	2226352	et	3	main
mahlakalt	doc_1010138200_item	2226351	et	4	main
vene	doc_1010138200_item	2226353	et	4	main
aktsent	doc_1010138200_item	2226354	et	3	main
aktsentiga	doc_1010138200_item	2226355	et	4	main
vaid	doc_1010138200_item	2226356	et	3	main
nagu	doc_1010138200_item	2226357	et	3	main
mõni	doc_1010138200_item	2226358	et	3	main
mõnega	doc_1010138200_item	2226359	et	3	main
täie	doc_1010138200_item	2226339	et	3	main
mõnus	doc_1010138200_item	2226346	et	4	main
on	doc_1010138200_item	2226362	et	4	main
venemaa	doc_1010138200_item	2226364	et	4	main
aine	doc_1010138200_item	2226368	et	4	main
keeles	doc_1010138200_item	2226372	et	4	main
veidi	doc_1010138200_item	2226375	et	3	main
saab	doc_1010138200_item	2226382	et	3	main
lapsed	doc_1010138200_item	2226388	et	3	main
ei	doc_1010138200_item	2226400	et	4	main
talvepuud	doc_1010138200_item	2226407	et	4	main
praegu	doc_1010138200_item	2226408	et	3	main
päevad	doc_1010138200_item	2226410	et	3	main
jahe	doc_1010138200_item	2226417	et	3	main
vaja	doc_1010138200_item	2226427	et	4	main
külapoest	doc_1010138200_item	2226430	et	4	main
ega	doc_1010138200_item	2226432	et	3	main
naerab	doc_1010138200_item	2226438	et	3	main
valmistuma	doc_1010138200_item	2226440	et	3	main
ajalehest	doc_1010138200_item	2226445	et	4	main
vormi	doc_1010138200_item	2226455	et	4	main
naeratus	doc_1010138200_item	2226460	et	4	main
tegutsema	doc_1010138200_item	2226484	et	3	main
tagajärg	doc_1010138200_item	2226490	et	3	main
kogus	doc_1010138200_item	2226492	et	4	main
paneb	doc_1010138200_item	2226494	et	3	main
võib	doc_1010138200_item	2226499	et	3	main
soovimatu	doc_1010138200_item	2226501	et	4	main
ei	doc_1010138200_item	2226504	et	4	main
pinge	doc_1010138200_item	2226509	et	4	main
sportima	doc_1010138200_item	2226512	et	4	main
puhkama	doc_1010138200_item	2226514	et	3	main
nii	doc_1010138200_item	2226520	et	3	main
maagiline	doc_1010138200_item	2226521	et	4	main
et	doc_1010138200_item	2226523	et	3	main
lausa	doc_1010138200_item	2226526	et	4	main
ja	doc_1010138200_item	2226528	et	3	main
on	doc_1010138200_item	2226532	et	4	main
kuid	doc_1010138200_item	2226544	et	4	main
telesaade	doc_1010138200_item	2226558	et	4	main
kuid	doc_1010138200_item	2226561	et	4	main
katkestab	doc_1010138200_item	2226563	et	3	main
varahommiku	doc_1010138200_item	2226566	et	3	main
pahandab	doc_1010138200_item	2226573	et	3	main
vaatamise	doc_1010138200_item	2226576	et	4	main
iv	doc_1010138200_item	2226578	et	4	main
1	doc_1010138200_item	2226585	et	2	main
oma	doc_1010138200_item	2226592	et	4	main
ja	doc_1010138200_item	2226599	et	3	main
arvasin	doc_1010138200_item	2226610	et	3	main
aga	doc_1010138200_item	2226616	et	3	main
murret	doc_1010138200_item	2226360	et	4	main
kool	doc_1010138200_item	2226361	et	4	main
õpetatakse	doc_1010138200_item	2226370	et	3	main
kolmesaja	doc_1010138200_item	2226378	et	4	main
kõik	doc_1010138200_item	2226383	et	4	main
poolpõlenud	doc_1010138200_item	2226389	et	4	main
saadetakse	doc_1010138200_item	2226393	et	3	main
karda	doc_1010138200_item	2226402	et	4	main
tooma	doc_1010138200_item	2226405	et	3	main
kuid	doc_1010138200_item	2226414	et	4	main
kütmisega	doc_1010138200_item	2226425	et	4	main
ostan	doc_1010138200_item	2226428	et	3	main
seal	doc_1010138200_item	2226433	et	4	main
müüdagi	doc_1010138200_item	2226437	et	3	main
talveks	doc_1010138200_item	2226439	et	4	main
moodustage	doc_1010138200_item	2226448	et	3	main
sõnadest	doc_1010138200_item	2226450	et	3	main
laused	doc_1010138200_item	2226451	et	3	main
sõnad	doc_1010138200_item	2226453	et	4	main
kasutades	doc_1010138200_item	2226457	et	3	main
naised	doc_1010138200_item	2226462	et	3	main
meie	doc_1010138200_item	2226483	et	4	main
lisakoormus	doc_1010138200_item	2226498	et	3	main
ülekoormus	doc_1010138200_item	2226507	et	3	main
5	doc_1010138200_item	2226515	et	2	main
tänapäev	doc_1010138200_item	2226518	et	3	main
see	doc_1010138200_item	2226524	et	3	main
tänapäeval	doc_1010138200_item	2226530	et	3	main
aparaat	doc_1010138200_item	2226535	et	3	main
lausa	doc_1010138200_item	2226539	et	4	main
ja	doc_1010138200_item	2226541	et	3	main
ja	doc_1010138200_item	2226554	et	3	main
vaatamine	doc_1010138200_item	2226559	et	4	main
telefonihelin	doc_1010138200_item	2226562	et	3	main
segab	doc_1010138200_item	2226568	et	3	main
valmistamist	doc_1010138200_item	2226570	et	4	main
huvitava	doc_1010138200_item	2226574	et	4	main
sõnad	doc_1010138200_item	2226582	et	4	main
ma	doc_1010138200_item	2226586	et	3	main
vanemaid	doc_1010138200_item	2226593	et	4	main
nad	doc_1010138200_item	2226595	et	3	main
usaldavad	doc_1010138200_item	2226600	et	4	main
igaüht	doc_1010138200_item	2226602	et	3	main
artikli	doc_1010138200_item	2226605	et	3	main
3	doc_1010138200_item	2226608	et	2	main
huvitud	doc_1010138200_item	2226613	et	4	main
sporti	doc_1010138200_item	2226615	et	4	main
tunned	doc_1010138200_item	2226618	et	3	main
autodeks	doc_1010138200_item	2226630	et	3	main
on	doc_1010138200_item	2226633	et	4	main
5	doc_1010138200_item	2226638	et	2	main
uue	doc_1010138200_item	2226642	et	3	main
kiiresti	doc_1010138200_item	2226644	et	3	main
selles	doc_1010138200_item	2226647	et	4	main
7	doc_1010138200_item	2226654	et	2	main
peab	doc_1010138200_item	2226670	et	4	main
külmetamine	doc_1010138200_item	2226672	et	4	main
10	doc_1010138200_item	2226674	et	2	main
suvisest	doc_1010138200_item	2226680	et	4	main
sidenditega	doc_1010138200_item	2226686	et	3	main
lõuna	doc_1010138200_item	2226690	et	4	main
kuid	doc_1010138200_item	2226692	et	4	main
kohal	doc_1010138200_item	2226697	et	4	main
kui	doc_1010138200_item	2226699	et	3	main
keegi	doc_1010138200_item	2226715	et	4	main
5	doc_1010138200_item	2226719	et	2	main
ei	doc_1010138200_item	2226721	et	4	main
läheb	doc_1010138200_item	2226725	et	3	main
suitsetada	doc_1010138200_item	2226740	et	3	main
pingsalt	doc_1010138200_item	2226748	et	4	main
9	doc_1010138200_item	2226753	et	2	main
kas	doc_1010138200_item	2226754	et	3	main
koputust	doc_1010138200_item	2226766	et	4	main
vene	doc_1010138200_item	2226422	et	4	main
vildid	doc_1010138200_item	2226431	et	4	main
ei	doc_1010138200_item	2226436	et	4	main
piret	doc_1010138200_item	2226442	et	4	main
lühendatud	doc_1010138200_item	2226444	et	4	main
iii	doc_1010138200_item	2226447	et	4	main
pannes	doc_1010138200_item	2226452	et	4	main
kirjavahemärke	doc_1010138200_item	2226458	et	4	main
naiselikum	doc_1010138200_item	2226463	et	4	main
ja	doc_1010138200_item	2226464	et	3	main
mehed	doc_1010138200_item	2226465	et	3	main
mehelikum	doc_1010138200_item	2226466	et	4	main
igaüks	doc_1010138200_item	2226467	et	3	main
naeratus	doc_1010138200_item	2226469	et	4	main
teeb	doc_1010138200_item	2226470	et	3	main
kaunim	doc_1010138200_item	2226468	et	4	main
igaühe	doc_1010138200_item	2226471	et	4	main
kaunim	doc_1010138200_item	2226472	et	4	main
naisi	doc_1010138200_item	2226473	et	3	main
naiselikum	doc_1010138200_item	2226474	et	4	main
ja	doc_1010138200_item	2226475	et	3	main
mehe	doc_1010138200_item	2226476	et	3	main
mehelikum	doc_1010138200_item	2226477	et	4	main
3	doc_1010138200_item	2226478	et	2	main
paras	doc_1010138200_item	2226479	et	3	main
kogus	doc_1010138200_item	2226480	et	4	main
stress	doc_1010138200_item	2226481	et	3	main
panema	doc_1010138200_item	2226482	et	3	main
aga	doc_1010138200_item	2226485	et	3	main
võima	doc_1010138200_item	2226487	et	3	main
soovimatu	doc_1010138200_item	2226489	et	4	main
paras	doc_1010138200_item	2226491	et	3	main
tegutsema	doc_1010138200_item	2226496	et	3	main
4	doc_1010138200_item	2226503	et	2	main
tekkima	doc_1010138200_item	2226508	et	3	main
saama	doc_1010138200_item	2226519	et	4	main
hingama	doc_1010138200_item	2226529	et	3	main
abil	doc_1010138200_item	2226538	et	4	main
elab	doc_1010138200_item	2226540	et	3	main
valmistamine	doc_1010138200_item	2226553	et	4	main
huvitav	doc_1010138200_item	2226557	et	4	main
ka	doc_1010138200_item	2226564	et	3	main
uni	doc_1010138200_item	2226567	et	3	main
ja	doc_1010138200_item	2226571	et	3	main
vormi	doc_1010138200_item	2226584	et	4	main
pean	doc_1010138200_item	2226587	et	4	main
lugu	doc_1010138200_item	2226589	et	4	main
kohandasin	doc_1010138200_item	2226604	et	3	main
nõudeid	doc_1010138200_item	2226607	et	3	main
et	doc_1010138200_item	2226611	et	3	main
ainult	doc_1010138200_item	2226620	et	4	main
naised	doc_1010138200_item	2226622	et	3	main
kiired	doc_1010138200_item	2226624	et	4	main
ilusaks	doc_1010138200_item	2226626	et	4	main
kiireks	doc_1010138200_item	2226629	et	4	main
praegu	doc_1010138200_item	2226632	et	3	main
difteeria	doc_1010138200_item	2226636	et	4	main
tüdinesin	doc_1010138200_item	2226639	et	3	main
küsimuses	doc_1010138200_item	2226648	et	4	main
väikesi	doc_1010138200_item	2226652	et	4	main
külmal	doc_1010138200_item	2226668	et	3	main
külmetamisest	doc_1010138200_item	2226673	et	4	main
täitke	doc_1010138200_item	2226683	et	3	main
tellisime	doc_1010138200_item	2226688	et	4	main
olid	doc_1010138200_item	2226698	et	4	main
õpetajad	doc_1010138200_item	2226702	et	4	main
oodata	doc_1010138200_item	2226706	et	4	main
ta	doc_1010138200_item	2226720	et	4	main
tule	doc_1010138200_item	2226722	et	4	main
trenni	doc_1010138200_item	2226723	et	4	main
siis	doc_1010138200_item	2226731	et	3	main
selles	doc_1010138200_item	2226736	et	4	main
tohi	doc_1010138200_item	2226739	et	4	main
ega	doc_1010138200_item	2226741	et	3	main
küll	doc_1010138200_item	2226747	et	4	main
tulemust	doc_1010138200_item	2226750	et	4	main
olnud	doc_1010138200_item	2226752	et	4	main
sa	doc_1010138200_item	2226755	et	3	main
nii	doc_1010138200_item	2226533	et	3	main
et	doc_1010138200_item	2226536	et	3	main
hingab	doc_1010138200_item	2226542	et	3	main
telefonihelin	doc_1010138200_item	2226545	et	3	main
ka	doc_1010138200_item	2226547	et	3	main
katkestama	doc_1010138200_item	2226546	et	3	main
pühapäev	doc_1010138200_item	2226548	et	3	main
varahommik	doc_1010138200_item	2226549	et	3	main
uni	doc_1010138200_item	2226550	et	3	main
segama	doc_1010138200_item	2226551	et	3	main
lõunasöök	doc_1010138200_item	2226552	et	3	main
pahandab	doc_1010138200_item	2226556	et	3	main
aeg	doc_1010138200_item	2226560	et	3	main
pühapäeva	doc_1010138200_item	2226565	et	4	main
söömist	doc_1010138200_item	2226572	et	4	main
sulgudes	doc_1010138200_item	2226580	et	4	main
vanemad	doc_1010138200_item	2226591	et	4	main
sest	doc_1010138200_item	2226594	et	4	main
aitavad	doc_1010138200_item	2226596	et	4	main
kõike	doc_1010138200_item	2226598	et	4	main
igaüks	doc_1010138200_item	2226601	et	3	main
2	doc_1010138200_item	2226603	et	2	main
sa	doc_1010138200_item	2226612	et	3	main
sport	doc_1010138200_item	2226614	et	3	main
sa	doc_1010138200_item	2226617	et	3	main
huvi	doc_1010138200_item	2226619	et	4	main
ja	doc_1010138200_item	2226628	et	3	main
4	doc_1010138200_item	2226631	et	2	main
töökoha	doc_1010138200_item	2226643	et	4	main
piirdusime	doc_1010138200_item	2226646	et	3	main
muudatused	doc_1010138200_item	2226651	et	3	main
ajal	doc_1010138200_item	2226669	et	4	main
tunnen	doc_1010138200_item	2226676	et	3	main
päike	doc_1010138200_item	2226679	et	3	main
lüngad	doc_1010138200_item	2226684	et	3	main
kolmekäigulise	doc_1010138200_item	2226689	et	4	main
maksis	doc_1010138200_item	2226694	et	4	main
2	doc_1010138200_item	2226696	et	2	main
nii	doc_1010138200_item	2226701	et	3	main
paluti	doc_1010138200_item	2226705	et	3	main
kostis	doc_1010138200_item	2226712	et	4	main
anekdooti	doc_1010138200_item	2226717	et	4	main
töö	doc_1010138200_item	2226730	et	4	main
seejärel	doc_1010138200_item	2226732	et	3	main
7	doc_1010138200_item	2226735	et	2	main
baaris	doc_1010138200_item	2226737	et	3	main
nad	doc_1010138200_item	2226745	et	3	main
või	doc_1010138200_item	2226758	et	4	main
jääd	doc_1010138200_item	2226759	et	4	main
avasin	doc_1010138200_item	2226762	et	3	main
kuulsin	doc_1010138200_item	2226765	et	3	main
naiseks	doc_1010138200_item	2226627	et	3	main
haigestuda	doc_1010138200_item	2226635	et	3	main
töökoht	doc_1010138200_item	2226641	et	3	main
6	doc_1010138200_item	2226645	et	2	main
väikesed	doc_1010138200_item	2226650	et	4	main
muudatusi	doc_1010138200_item	2226653	et	3	main
see	doc_1010138200_item	2226655	et	3	main
küsimus	doc_1010138200_item	2226656	et	4	main
kuulub	doc_1010138200_item	2226657	et	3	main
teine	doc_1010138200_item	2226658	et	3	main
valdkond	doc_1010138200_item	2226659	et	3	main
valdkonnas	doc_1010138200_item	2226661	et	4	main
teises	doc_1010138200_item	2226660	et	4	main
8	doc_1010138200_item	2226662	et	2	main
närimiskumm	doc_1010138200_item	2226663	et	3	main
kleepus	doc_1010138200_item	2226664	et	3	main
püksid	doc_1010138200_item	2226665	et	3	main
püksidele	doc_1010138200_item	2226666	et	3	main
9	doc_1010138200_item	2226667	et	2	main
uus	doc_1010138200_item	2226640	et	3	main
vaid	doc_1010138200_item	2226649	et	3	main
hoiduma	doc_1010138200_item	2226671	et	3	main
rõõmu	doc_1010138200_item	2226677	et	4	main
v	doc_1010138200_item	2226682	et	4	main
1	doc_1010138200_item	2226687	et	2	main
3	doc_1010138200_item	2226703	et	2	main
tagasi	doc_1010138200_item	2226708	et	3	main
4	doc_1010138200_item	2226710	et	2	main
oleks	doc_1010138200_item	2226714	et	3	main
just	doc_1010138200_item	2226716	et	3	main
rääkinud	doc_1010138200_item	2226718	et	4	main
ma	doc_1010138200_item	2226675	et	3	main
suvine	doc_1010138200_item	2226678	et	4	main
päikest	doc_1010138200_item	2226681	et	4	main
sobivate	doc_1010138200_item	2226685	et	4	main
kahjuks	doc_1010138200_item	2226691	et	4	main
see	doc_1010138200_item	2226693	et	3	main
palju	doc_1010138200_item	2226695	et	4	main
õpilased	doc_1010138200_item	2226700	et	3	main
lapsel	doc_1010138200_item	2226704	et	4	main
vanemad	doc_1010138200_item	2226707	et	4	main
tulevad	doc_1010138200_item	2226709	et	4	main
kõrvallauast	doc_1010138200_item	2226711	et	4	main
naeru	doc_1010138200_item	2226713	et	4	main
teatrisse	doc_1010138200_item	2226727	et	3	main
lõpetage	doc_1010138200_item	2226729	et	3	main
8	doc_1010138200_item	2226744	et	2	main
sõidad	doc_1010138200_item	2226756	et	3	main
linna	doc_1010138200_item	2226760	et	4	main
kuna	doc_1010138200_item	2226764	et	3	main
kuna	doc_1010138200_item	2226724	et	3	main
hoopis	doc_1010138200_item	2226726	et	3	main
6	doc_1010138200_item	2226728	et	2	main
lähete	doc_1010138200_item	2226733	et	4	main
jalutama	doc_1010138200_item	2226734	et	3	main
ei	doc_1010138200_item	2226738	et	4	main
alkoholi	doc_1010138200_item	2226742	et	4	main
tarbida	doc_1010138200_item	2226743	et	3	main
töötasid	doc_1010138200_item	2226746	et	4	main
aga	doc_1010138200_item	2226749	et	3	main
ei	doc_1010138200_item	2226751	et	4	main
maale	doc_1010138200_item	2226757	et	4	main
10	doc_1010138200_item	2226761	et	2	main
ukse	doc_1010138200_item	2226763	et	3	main
kontrolltöö	doc_109979842709_item	2232931	et	4	main
a-te	doc_109979842709_item	2232935	et	3	main
eesti	doc_109979842709_item	2232936	et	4	main
taasiseseisvumisel	doc_109979842709_item	2232945	et	3	main
perestroika	doc_109979842709_item	2232948	et	4	main
3	doc_109979842709_item	2232954	et	2	main
ei	doc_109979842709_item	2232968	et	4	main
pankrotti	doc_109979842709_item	2232991	et	4	main
ja	doc_109979842709_item	2232997	et	3	main
väljaviimine	doc_109979842709_item	2233000	et	3	main
perestroika	doc_109979842709_item	2233002	et	4	main
ja	doc_109979842709_item	2233003	et	3	main
osaliselt	doc_109979842709_item	2233008	et	4	main
balti	doc_109979842709_item	2233010	et	3	main
riikides	doc_109979842709_item	2233011	et	3	main
seda	doc_109979842709_item	2233013	et	3	main
kampaaniat	doc_109979842709_item	2233016	et	3	main
laulupeod	doc_109979842709_item	2233030	et	4	main
noore	doc_109979842709_item	2233032	et	3	main
vaimu	doc_109979842709_item	2233034	et	4	main
ühtekuuluvustunnet	doc_109979842709_item	2233035	et	3	main
me	doc_109979842709_item	2233038	et	4	main
rahvamärke	doc_109979842709_item	2233073	et	4	main
kirjanikud	doc_109979842709_item	2233090	et	3	main
oli	doc_109979842709_item	2233097	et	3	main
suurenes	doc_109979842709_item	2233101	et	4	main
vene	doc_109979842709_item	2233109	et	4	main
keelele	doc_109979842709_item	2233110	et	4	main
geograafiale	doc_109979842709_item	2233112	et	3	main
ateistliku	doc_109979842709_item	2233116	et	3	main
eestimaa	doc_109979842709_item	2233145	et	4	main
kassetipõlvkond	doc_109979842709_item	2233157	et	3	main
traat	doc_109979842709_item	2233166	et	3	main
pe	doc_109979842709_item	2233167	et	4	main
1	doc_109979842709_item	2232932	et	2	main
19701980	doc_109979842709_item	2232934	et	2	main
2	doc_109979842709_item	2232938	et	2	main
ja	doc_109979842709_item	2232952	et	3	main
venemaa	doc_109979842709_item	2232955	et	4	main
maailmakaardil	doc_109979842709_item	2232972	et	3	main
näha	doc_109979842709_item	2232973	et	3	main
kiirendasid	doc_109979842709_item	2232976	et	4	main
vähendasid	doc_109979842709_item	2232981	et	4	main
sissetulekuid	doc_109979842709_item	2232982	et	4	main
hindade	doc_109979842709_item	2232984	et	3	main
majandusblokaadiga	doc_109979842709_item	2232987	et	3	main
liit	doc_109979842709_item	2232989	et	3	main
gorbatshovi	doc_109979842709_item	2232992	et	4	main
riigi	doc_109979842709_item	2232998	et	3	main
millega	doc_109979842709_item	2233017	et	3	main
kaasa	doc_109979842709_item	2233019	et	4	main
seisukohad	doc_109979842709_item	2233023	et	4	main
ja	doc_109979842709_item	2233025	et	3	main
põlvkonna	doc_109979842709_item	2233033	et	4	main
oleme	doc_109979842709_item	2233039	et	3	main
ja	doc_109979842709_item	2233047	et	3	main
lauluväljakul	doc_109979842709_item	2233050	et	3	main
rahumeelsed	doc_109979842709_item	2233053	et	3	main
isamaast	doc_109979842709_item	2233075	et	3	main
tugevnes	doc_109979842709_item	2233085	et	3	main
ka	doc_109979842709_item	2233088	et	3	main
ise	doc_109979842709_item	2233091	et	4	main
kirjutada	doc_109979842709_item	2233094	et	3	main
kultuurile	doc_109979842709_item	2233113	et	3	main
ühingud	doc_109979842709_item	2233119	et	3	main
valmistati	doc_109979842709_item	2233129	et	4	main
laulva	doc_109979842709_item	2232941	et	4	main
eesti	doc_109979842709_item	2232944	et	4	main
3	doc_109979842709_item	2232946	et	2	main
tähendus	doc_109979842709_item	2232951	et	4	main
sisu	doc_109979842709_item	2232953	et	4	main
oli	doc_109979842709_item	2232956	et	3	main
inglismaa	doc_109979842709_item	2232967	et	4	main
tahtnud	doc_109979842709_item	2232969	et	4	main
riigid	doc_109979842709_item	2232975	et	3	main
kommunismivastaseid	doc_109979842709_item	2232979	et	3	main
liikumisi	doc_109979842709_item	2232980	et	4	main
nsv	doc_109979842709_item	2232988	et	4	main
läks	doc_109979842709_item	2232990	et	3	main
ülesanneks	doc_109979842709_item	2232993	et	3	main
süsteemi	doc_109979842709_item	2232995	et	4	main
glasnost	doc_109979842709_item	2233004	et	4	main
ühiskonna	doc_109979842709_item	2233007	et	4	main
nagu	doc_109979842709_item	2233015	et	3	main
iseloomustage	doc_109979842709_item	2232933	et	4	main
kultuurielu	doc_109979842709_item	2232937	et	4	main
nn	doc_109979842709_item	2232939	et	4	main
sõnade	doc_109979842709_item	2232947	et	3	main
ja	doc_109979842709_item	2232949	et	3	main
võidurelvastust	doc_109979842709_item	2232977	et	3	main
nafta	doc_109979842709_item	2232983	et	4	main
alandamise	doc_109979842709_item	2232985	et	4	main
oli	doc_109979842709_item	2232994	et	3	main
säilitamine	doc_109979842709_item	2232996	et	4	main
algasid	doc_109979842709_item	2233001	et	4	main
ehk	doc_109979842709_item	2233005	et	3	main
demokratiseeriti	doc_109979842709_item	2233009	et	3	main
võeti	doc_109979842709_item	2233012	et	3	main
vastu	doc_109979842709_item	2233014	et	3	main
tuleb	doc_109979842709_item	2233018	et	3	main
minna	doc_109979842709_item	2233020	et	3	main
avaldati	doc_109979842709_item	2233021	et	3	main
ilmusid	doc_109979842709_item	2233027	et	4	main
2	doc_109979842709_item	2233029	et	2	main
ärkasid	doc_109979842709_item	2233031	et	4	main
et	doc_109979842709_item	2233036	et	3	main
võime	doc_109979842709_item	2233044	et	4	main
toimusid	doc_109979842709_item	2233051	et	4	main
palju	doc_109979842709_item	2233065	et	4	main
mis	doc_109979842709_item	2233077	et	4	main
oli	doc_109979842709_item	2233087	et	3	main
enesetsensuur	doc_109979842709_item	2233089	et	3	main
mis	doc_109979842709_item	2233096	et	4	main
oli	doc_109979842709_item	2233103	et	3	main
all	doc_109979842709_item	2233105	et	3	main
pandi	doc_109979842709_item	2233107	et	4	main
ajaloole	doc_109979842709_item	2233111	et	4	main
viidi	doc_109979842709_item	2233115	et	4	main
propagandat	doc_109979842709_item	2233117	et	3	main
pionerid	doc_109979842709_item	2233120	et	4	main
keskharidus	doc_109979842709_item	2233122	et	3	main
arv	doc_109979842709_item	2233126	et	3	main
aga	doc_109979842709_item	2233128	et	3	main
ei	doc_109979842709_item	2233142	et	4	main
iseseisvaks	doc_109979842709_item	2233148	et	3	main
trükkiste	doc_109979842709_item	2233150	et	4	main
tekkisid	doc_109979842709_item	2233153	et	4	main
noorte	doc_109979842709_item	2233154	et	3	main
sõpruskonnad	doc_109979842709_item	2233156	et	4	main
nad	doc_109979842709_item	2233159	et	3	main
värsi	doc_109979842709_item	2233162	et	3	main
muulastel	doc_109979842709_item	2233191	et	4	main
ja	doc_109979842709_item	2233193	et	3	main
soome	doc_109979842709_item	2233198	et	3	main
eesti	doc_109979842709_item	2233200	et	4	main
raadiosaateid	doc_109979842709_item	2233210	et	3	main
kirjanikke	doc_109979842709_item	2233222	et	3	main
vbeekman	doc_109979842709_item	2233224	et	4	main
tehnikaareng	doc_120968879137_item	2233235	et	3	main
inimesed	doc_120968879137_item	2233240	et	3	main
lennukiga	doc_120968879137_item	2233242	et	3	main
autoga	doc_120968879137_item	2233246	et	3	main
autoga	doc_120968879137_item	2233250	et	3	main
väga	doc_120968879137_item	2233256	et	3	main
sõidasin	doc_120968879137_item	2233260	et	4	main
venemaal	doc_120968879137_item	2233264	et	4	main
meri	doc_120968879137_item	2233269	et	3	main
oleme	doc_120968879137_item	2233273	et	3	main
mitmedes	doc_120968879137_item	2233275	et	4	main
meie	doc_120968879137_item	2233278	et	4	main
ööbis	doc_120968879137_item	2233280	et	3	main
sõidasime	doc_120968879137_item	2233284	et	4	main
moskvas	doc_120968879137_item	2233285	et	4	main
selles	doc_120968879137_item	2233324	et	4	main
peakirikust	doc_120968879137_item	2233329	et	4	main
on	doc_120968879137_item	2233332	et	4	main
ilus	doc_120968879137_item	2233334	et	4	main
sinised	doc_120968879137_item	2233336	et	4	main
ja	doc_120968879137_item	2233355	et	3	main
öölaulupidudeja	doc_109979842709_item	2232940	et	4	main
revolutsiooni	doc_109979842709_item	2232942	et	4	main
osa	doc_109979842709_item	2232943	et	4	main
glasnostj	doc_109979842709_item	2232950	et	4	main
sunnitud	doc_109979842709_item	2232957	et	4	main
reforme	doc_109979842709_item	2232958	et	3	main
üleviima	doc_109979842709_item	2232959	et	4	main
sest	doc_109979842709_item	2232960	et	4	main
riigis	doc_109979842709_item	2232961	et	3	main
valitses	doc_109979842709_item	2232962	et	3	main
majanduskriis	doc_109979842709_item	2232963	et	3	main
lääne	doc_109979842709_item	2232964	et	4	main
riigid	doc_109979842709_item	2232965	et	3	main
nagu	doc_109979842709_item	2232966	et	3	main
nõukogude	doc_109979842709_item	2232970	et	3	main
liidu	doc_109979842709_item	2232971	et	3	main
lääne	doc_109979842709_item	2232974	et	4	main
toetasid	doc_109979842709_item	2232978	et	4	main
ja	doc_109979842709_item	2232986	et	3	main
pankrotist	doc_109979842709_item	2232999	et	3	main
avalikustamine	doc_109979842709_item	2233006	et	4	main
kui	doc_109979842709_item	2233037	et	3	main
kõik	doc_109979842709_item	2233040	et	4	main
siis	doc_109979842709_item	2233042	et	3	main
me	doc_109979842709_item	2233043	et	4	main
midagi	doc_109979842709_item	2233045	et	4	main
teha	doc_109979842709_item	2233046	et	3	main
tallinna	doc_109979842709_item	2233049	et	4	main
eestimaa	doc_109979842709_item	2233056	et	4	main
nad	doc_109979842709_item	2233067	et	3	main
kaasa	doc_109979842709_item	2233069	et	4	main
ja	doc_109979842709_item	2233071	et	3	main
laule	doc_109979842709_item	2233076	et	4	main
vaimustasid	doc_109979842709_item	2233078	et	4	main
nad	doc_109979842709_item	2233080	et	3	main
heasse	doc_109979842709_item	2233082	et	3	main
1	doc_109979842709_item	2233084	et	2	main
tsensuur	doc_109979842709_item	2233086	et	3	main
püüdsid	doc_109979842709_item	2233092	et	4	main
ei	doc_109979842709_item	2233093	et	4	main
sellest	doc_109979842709_item	2233095	et	4	main
administreerimine	doc_109979842709_item	2233100	et	4	main
hariduselu	doc_109979842709_item	2233102	et	4	main
kontrolli	doc_109979842709_item	2233104	et	4	main
õpikutes	doc_109979842709_item	2233106	et	3	main
tähelepanu	doc_109979842709_item	2233108	et	4	main
koolides	doc_109979842709_item	2233114	et	3	main
kommunistlikud	doc_109979842709_item	2233118	et	3	main
kriisi	doc_109979842709_item	2233022	et	4	main
keskkonnaprobleemid	doc_109979842709_item	2233024	et	3	main
stalinismikuriteod	doc_109979842709_item	2233026	et	4	main
keskkonnakaitseklubid	doc_109979842709_item	2233028	et	3	main
koos	doc_109979842709_item	2233041	et	4	main
saavutada	doc_109979842709_item	2233048	et	3	main
avalikud	doc_109979842709_item	2233052	et	3	main
meeleavaldused	doc_109979842709_item	2233054	et	3	main
et	doc_109979842709_item	2233055	et	3	main
tahab	doc_109979842709_item	2233057	et	3	main
olla	doc_109979842709_item	2233058	et	3	main
vabaks	doc_109979842709_item	2233059	et	3	main
ja	doc_109979842709_item	2233060	et	3	main
rahvas	doc_109979842709_item	2233061	et	4	main
toetas	doc_109979842709_item	2233062	et	3	main
seda	doc_109979842709_item	2233063	et	3	main
kogunes	doc_109979842709_item	2233064	et	3	main
rahvast	doc_109979842709_item	2233066	et	4	main
tõid	doc_109979842709_item	2233068	et	4	main
rahvalippe	doc_109979842709_item	2233070	et	3	main
teisi	doc_109979842709_item	2233072	et	4	main
lauldi	doc_109979842709_item	2233074	et	3	main
inimesi	doc_109979842709_item	2233079	et	4	main
ususid	doc_109979842709_item	2233081	et	4	main
tulevikku	doc_109979842709_item	2233083	et	4	main
keelatud	doc_109979842709_item	2233098	et	4	main
kultuurielu	doc_109979842709_item	2233099	et	4	main
üldine	doc_109979842709_item	2233121	et	4	main
piiratud	doc_109979842709_item	2233130	et	4	main
profiliga	doc_109979842709_item	2233134	et	4	main
ühiskonnas	doc_109979842709_item	2233136	et	4	main
tekkis	doc_109979842709_item	2233137	et	3	main
masendus	doc_109979842709_item	2233138	et	4	main
pessimismi	doc_109979842709_item	2233139	et	4	main
saab	doc_109979842709_item	2233147	et	3	main
venekeelseid	doc_109979842709_item	2233149	et	3	main
osakaal	doc_109979842709_item	2233151	et	3	main
kirjanikke	doc_109979842709_item	2233155	et	3	main
kasutasid	doc_109979842709_item	2233160	et	4	main
luik	doc_109979842709_item	2233164	et	3	main
räägiti	doc_109979842709_item	2233188	et	3	main
eesti	doc_109979842709_item	2233194	et	4	main
õppida	doc_109979842709_item	2233196	et	3	main
ja	doc_109979842709_item	2233202	et	3	main
muusika	doc_109979842709_item	2233216	et	4	main
näts	doc_109979842709_item	2233218	et	3	main
defitsiit	doc_109979842709_item	2233220	et	3	main
põlvkond	doc_109979842709_item	2233223	et	3	main
vluik	doc_109979842709_item	2233225	et	4	main
jkaplinski	doc_109979842709_item	2233227	et	4	main
annab	doc_120968879137_item	2233236	et	3	main
võimalusi	doc_120968879137_item	2233238	et	3	main
võivad	doc_120968879137_item	2233241	et	4	main
või	doc_120968879137_item	2233245	et	4	main
reisida	doc_120968879137_item	2233251	et	3	main
et	doc_120968879137_item	2233253	et	3	main
mina	doc_120968879137_item	2233259	et	4	main
me	doc_120968879137_item	2233266	et	4	main
musta	doc_120968879137_item	2233268	et	4	main
ääres	doc_120968879137_item	2233270	et	4	main
me	doc_120968879137_item	2233272	et	4	main
pere	doc_120968879137_item	2233279	et	4	main
ma	doc_120968879137_item	2233287	et	3	main
arhitektuuriga	doc_120968879137_item	2233323	et	3	main
üks	doc_120968879137_item	2233327	et	3	main
peakirik	doc_120968879137_item	2233331	et	3	main
ebatavaliselt	doc_120968879137_item	2233333	et	4	main
oli	doc_120968879137_item	2233343	et	3	main
sõidasime	doc_120968879137_item	2233347	et	4	main
ääres	doc_120968879137_item	2233350	et	4	main
ilus	doc_120968879137_item	2233353	et	4	main
inimese	doc_120968879137_item	2233364	et	4	main
kahe	doc_120968879137_item	2233367	et	3	main
me	doc_120968879137_item	2233370	et	4	main
suplesime	doc_120968879137_item	2233373	et	3	main
silmaringi	doc_120968879137_item	2233404	et	4	main
maailm	doc_120968879137_item	2233408	et	3	main
kuhu	doc_120968879138_item	2233411	et	3	main
mida	doc_120968879138_item	2233414	et	4	main
näinud	doc_120968879138_item	2233416	et	4	main
raske	doc_120968879138_item	2233418	et	4	main
8	doc_109979842709_item	2233123	et	2	main
aastat	doc_109979842709_item	2233124	et	3	main
kõrgkoolide	doc_109979842709_item	2233125	et	3	main
suurenes	doc_109979842709_item	2233127	et	4	main
ja	doc_109979842709_item	2233132	et	3	main
tunne	doc_109979842709_item	2233140	et	4	main
uskunud	doc_109979842709_item	2233143	et	4	main
kunagi	doc_109979842709_item	2233146	et	3	main
luules	doc_109979842709_item	2233158	et	4	main
vaba	doc_109979842709_item	2233161	et	4	main
rummo	doc_109979842709_item	2233168	et	4	main
muusikas	doc_109979842709_item	2233169	et	3	main
loobuti	doc_109979842709_item	2233170	et	3	main
klassikalisest	doc_109979842709_item	2233171	et	4	main
skeemidest	doc_109979842709_item	2233172	et	3	main
harrastati	doc_109979842709_item	2233173	et	3	main
dodekafooniat	doc_109979842709_item	2233174	et	3	main
viidi	doc_109979842709_item	2233175	et	4	main
läbi	doc_109979842709_item	2233176	et	4	main
arenes	doc_109979842709_item	2233178	et	3	main
dzhässfestivale	doc_109979842709_item	2233177	et	4	main
reaal	doc_109979842709_item	2233179	et	3	main
ja	doc_109979842709_item	2233180	et	3	main
loodusteadus	doc_109979842709_item	2233181	et	4	main
kunst	doc_109979842709_item	2233182	et	3	main
oli	doc_109979842709_item	2233183	et	3	main
tasemel	doc_109979842709_item	2233185	et	3	main
silmaringi	doc_109979842709_item	2233131	et	4	main
kitsa	doc_109979842709_item	2233133	et	3	main
spetsialiste	doc_109979842709_item	2233135	et	3	main
inimesed	doc_109979842709_item	2233141	et	3	main
et	doc_109979842709_item	2233144	et	3	main
suurenes	doc_109979842709_item	2233152	et	4	main
v	doc_109979842709_item	2233163	et	4	main
m	doc_109979842709_item	2233165	et	4	main
kusjuures	doc_109979842709_item	2233187	et	3	main
keelt	doc_109979842709_item	2233195	et	4	main
filmikunst	doc_109979842709_item	2233203	et	3	main
mõjutas	doc_109979842709_item	2233212	et	3	main
kultuurile	doc_109979842709_item	2233214	et	3	main
teksad	doc_109979842709_item	2233215	et	4	main
heliplaadid	doc_109979842709_item	2233217	et	3	main
professionaalsel	doc_109979842709_item	2233184	et	3	main
et	doc_109979842709_item	2233190	et	3	main
tuleb	doc_109979842709_item	2233192	et	3	main
arenesilmusid	doc_109979842709_item	2233205	et	4	main
filmid	doc_109979842709_item	2233207	et	4	main
välismaaid	doc_109979842709_item	2233209	et	4	main
läänekultuur	doc_109979842709_item	2233211	et	3	main
kus	doc_120968879137_item	2233230	et	3	main
käinud	doc_120968879137_item	2233232	et	4	main
palju	doc_120968879137_item	2233237	et	4	main
rongiga	doc_120968879137_item	2233244	et	4	main
on	doc_120968879137_item	2233255	et	4	main
koos	doc_120968879137_item	2233261	et	4	main
puhkama	doc_120968879137_item	2233265	et	3	main
aluses	doc_120968879137_item	2233282	et	4	main
mind	doc_120968879137_item	2233321	et	4	main
sirasid	doc_120968879137_item	2233338	et	4	main
selle	doc_120968879137_item	2233341	et	4	main
pärast	doc_120968879137_item	2233345	et	4	main
me	doc_120968879137_item	2233346	et	4	main
musta	doc_120968879137_item	2233348	et	4	main
meri	doc_120968879137_item	2233349	et	3	main
seal	doc_120968879137_item	2233351	et	4	main
loodus	doc_120968879137_item	2233354	et	4	main
ere	doc_120968879137_item	2233356	et	3	main
kohtasid	doc_120968879137_item	2233359	et	4	main
jooksul	doc_120968879137_item	2233369	et	4	main
mere	doc_120968879137_item	2233374	et	3	main
aitab	doc_120968879137_item	2233406	et	3	main
teada	doc_120968879137_item	2233409	et	3	main
sellepärast	doc_120968879138_item	2233420	et	3	main
välismaale	doc_120968879138_item	2233426	et	4	main
kõige	doc_120968879138_item	2233431	et	4	main
mälestused	doc_120968879138_item	2233433	et	4	main
turgis	doc_120968879138_item	2233436	et	4	main
hooned	doc_120968879138_item	2233438	et	4	main
vanemaal	doc_120968879138_item	2233439	et	4	main
riigid	doc_120968879138_item	2233441	et	3	main
olen	doc_120968879138_item	2233443	et	3	main
erisugused	doc_120968879138_item	2233449	et	3	main
kultuurid	doc_120968879138_item	2233450	et	3	main
usk	doc_120968879138_item	2233452	et	3	main
ehitusstiilid	doc_120968879138_item	2233454	et	3	main
saa	doc_120968879138_item	2233461	et	4	main
kõige	doc_120968879138_item	2233466	et	4	main
parem	doc_120968879138_item	2233467	et	4	main
et	doc_120968879138_item	2233469	et	3	main
oma	doc_120968879138_item	2233484	et	4	main
oma	doc_120968879138_item	2233488	et	4	main
jaoks	doc_120968879138_item	2233495	et	4	main
ma	doc_120968879138_item	2233497	et	3	main
külas	doc_120968879138_item	2233501	et	3	main
televisorist	doc_120968879138_item	2233521	et	4	main
üks	doc_120968879138_item	2233523	et	3	main
mida	doc_120968879138_item	2233525	et	4	main
äraolek	doc_120968879138_item	2233531	et	3	main
oli	doc_120968879138_item	2233533	et	3	main
seal	doc_120968879138_item	2233539	et	4	main
olid	doc_120968879138_item	2233540	et	4	main
et	doc_120968879138_item	2233550	et	3	main
elanik	doc_120968879138_item	2233554	et	3	main
kohanematu	doc_120968879138_item	2233558	et	4	main
on	doc_120968879139_item	2233572	et	4	main
aega	doc_120968879139_item	2233599	et	4	main
uurida	doc_120968879139_item	2233602	et	3	main
aga	doc_120968879139_item	2233605	et	3	main
tahtsin	doc_120968879139_item	2233611	et	3	main
edasi	doc_120968879139_item	2233614	et	3	main
olin	doc_120968879139_item	2233616	et	3	main
kaaslasega	doc_120968879139_item	2233621	et	3	main
see	doc_120968879139_item	2233623	et	3	main
väga	doc_120968879139_item	2233625	et	3	main
olin	doc_120968879139_item	2233634	et	3	main
midagi	doc_120968879139_item	2233642	et	4	main
on	doc_120968879139_item	2233650	et	4	main
mu	doc_120968879139_item	2233661	et	3	main
kes	doc_120968879139_item	2233669	et	4	main
on	doc_120968879139_item	2233699	et	4	main
suurem	doc_120968879139_item	2233701	et	4	main
veel	doc_120968879139_item	2233706	et	4	main
seal	doc_120968879139_item	2233712	et	4	main
oli	doc_120968879139_item	2233715	et	3	main
venekeelepropaganda	doc_109979842709_item	2233186	et	4	main
sellest	doc_109979842709_item	2233189	et	4	main
olikättesaadav	doc_109979842709_item	2233197	et	4	main
televisioon	doc_109979842709_item	2233199	et	4	main
televisioon	doc_109979842709_item	2233201	et	4	main
ka	doc_109979842709_item	2233204	et	3	main
eesti	doc_109979842709_item	2233206	et	4	main
kuulati	doc_109979842709_item	2233208	et	4	main
eesti	doc_109979842709_item	2233213	et	4	main
kosmeetika	doc_109979842709_item	2233219	et	4	main
noor	doc_109979842709_item	2233221	et	3	main
perummo	doc_109979842709_item	2233226	et	4	main
dkareva	doc_109979842709_item	2233228	et	4	main
ajal	doc_120968879137_item	2233234	et	4	main
prammiga	doc_120968879137_item	2233243	et	4	main
reisida	doc_120968879137_item	2233247	et	3	main
mina	doc_120968879137_item	2233248	et	4	main
sest	doc_120968879137_item	2233252	et	4	main
see	doc_120968879137_item	2233254	et	3	main
mugav	doc_120968879137_item	2233257	et	3	main
tahtsime	doc_120968879137_item	2233267	et	3	main
sõita	doc_120968879137_item	2233271	et	3	main
käinud	doc_120968879137_item	2233274	et	4	main
sugulastemajas	doc_120968879137_item	2233281	et	3	main
me	doc_120968879137_item	2233283	et	4	main
essee	doc_120968879137_item	2233229	et	4	main
olen	doc_120968879137_item	2233231	et	3	main
meie	doc_120968879137_item	2233233	et	4	main
reisima	doc_120968879137_item	2233239	et	3	main
eelistan	doc_120968879137_item	2233249	et	3	main
suvel	doc_120968879137_item	2233258	et	3	main
oma	doc_120968879137_item	2233262	et	4	main
vanematega	doc_120968879137_item	2233263	et	4	main
linnades	doc_120968879137_item	2233276	et	3	main
kus	doc_120968879137_item	2233277	et	3	main
seal	doc_120968879137_item	2233286	et	4	main
külastasin	doc_120968879137_item	2233288	et	3	main
tretjakovi	doc_120968879137_item	2233289	et	4	main
galerii	doc_120968879137_item	2233290	et	4	main
kus	doc_120968879137_item	2233291	et	3	main
on	doc_120968879137_item	2233292	et	4	main
esitatud	doc_120968879137_item	2233293	et	4	main
tretjakovi	doc_120968879137_item	2233294	et	4	main
pildikogu	doc_120968879137_item	2233295	et	4	main
ma	doc_120968879137_item	2233296	et	3	main
palju	doc_120968879137_item	2233298	et	4	main
tundsin	doc_120968879137_item	2233297	et	3	main
erinevaid	doc_120968879137_item	2233299	et	4	main
asju	doc_120968879137_item	2233300	et	3	main
kunstist	doc_120968879137_item	2233301	et	4	main
ja	doc_120968879137_item	2233302	et	3	main
nägin	doc_120968879137_item	2233303	et	3	main
oma	doc_120968879137_item	2233304	et	4	main
silmades	doc_120968879137_item	2233305	et	3	main
pildid	doc_120968879137_item	2233306	et	3	main
millised	doc_120968879137_item	2233307	et	3	main
kuuluvad	doc_120968879137_item	2233309	et	4	main
on	doc_120968879137_item	2233308	et	4	main
ümbritsev	doc_120968879137_item	2233310	et	4	main
maailmas	doc_120968879137_item	2233311	et	3	main
novotserkask	doc_120968879137_item	2233312	et	4	main
oli	doc_120968879137_item	2233313	et	3	main
teine	doc_120968879137_item	2233314	et	3	main
linn	doc_120968879137_item	2233315	et	3	main
reisis	doc_120968879137_item	2233317	et	4	main
selle	doc_120968879137_item	2233318	et	4	main
meie	doc_120968879137_item	2233316	et	4	main
linn	doc_120968879137_item	2233319	et	3	main
hämmastas	doc_120968879137_item	2233320	et	3	main
oma	doc_120968879137_item	2233322	et	4	main
linnas	doc_120968879137_item	2233325	et	4	main
suurestest	doc_120968879137_item	2233328	et	3	main
maailmas	doc_120968879137_item	2233330	et	3	main
ööpäevas	doc_120968879137_item	2233335	et	3	main
asub	doc_120968879137_item	2233326	et	3	main
abil	doc_120968879137_item	2233340	et	4	main
vaatepilt	doc_120968879137_item	2233342	et	3	main
unustumata	doc_120968879137_item	2233344	et	4	main
palav	doc_120968879137_item	2233357	et	4	main
mina	doc_120968879137_item	2233361	et	4	main
üllatanud	doc_120968879137_item	2233363	et	4	main
arvutu	doc_120968879137_item	2233365	et	4	main
nädala	doc_120968879137_item	2233368	et	3	main
ja	doc_120968879137_item	2233372	et	3	main
oli	doc_120968879137_item	2233377	et	3	main
soe	doc_120968879137_item	2233378	et	4	main
ja	doc_120968879137_item	2233379	et	3	main
läbipäistev	doc_120968879137_item	2233380	et	4	main
lisaks	doc_120968879137_item	2233381	et	4	main
me	doc_120968879137_item	2233382	et	4	main
imetlesime	doc_120968879137_item	2233383	et	3	main
vaatamisväärsustest	doc_120968879137_item	2233384	et	4	main
loodust	doc_120968879137_item	2233385	et	4	main
maastikust	doc_120968879137_item	2233386	et	4	main
teise	doc_120968879137_item	2233387	et	4	main
nädala	doc_120968879137_item	2233388	et	3	main
lõpuks	doc_120968879137_item	2233389	et	4	main
tulime	doc_120968879137_item	2233391	et	3	main
me	doc_120968879137_item	2233390	et	4	main
koju	doc_120968879137_item	2233392	et	3	main
suvi	doc_120968879137_item	2233393	et	3	main
oli	doc_120968879137_item	2233394	et	3	main
tunnetuslik	doc_120968879137_item	2233395	et	3	main
ja	doc_120968879137_item	2233396	et	3	main
unustamatu	doc_120968879137_item	2233397	et	4	main
ma	doc_120968879137_item	2233398	et	3	main
arvan	doc_120968879137_item	2233399	et	3	main
et	doc_120968879137_item	2233400	et	3	main
reisimine	doc_120968879137_item	2233401	et	4	main
laendab	doc_120968879137_item	2233402	et	4	main
inimese	doc_120968879137_item	2233403	et	4	main
kuplid	doc_120968879137_item	2233337	et	3	main
lisavalgustuse	doc_120968879137_item	2233339	et	3	main
on	doc_120968879137_item	2233352	et	4	main
päevitasime	doc_120968879137_item	2233371	et	3	main
vesi	doc_120968879137_item	2233376	et	4	main
ümbritsev	doc_120968879137_item	2233407	et	4	main
essee	doc_120968879138_item	2233410	et	4	main
küsimus	doc_120968879138_item	2233419	et	4	main
et	doc_120968879138_item	2233421	et	3	main
barokko	doc_120968879138_item	2233437	et	4	main
muidugi	doc_120968879138_item	2233456	et	4	main
ei	doc_120968879138_item	2233460	et	4	main
kus	doc_120968879138_item	2233464	et	3	main
sellepärast	doc_120968879138_item	2233468	et	3	main
mida	doc_120968879138_item	2233470	et	4	main
näinud	doc_120968879138_item	2233472	et	4	main
mälestuses	doc_120968879138_item	2233475	et	4	main
kord	doc_120968879138_item	2233478	et	4	main
oli	doc_120968879138_item	2233480	et	3	main
sõit	doc_120968879138_item	2233482	et	3	main
vanematega	doc_120968879138_item	2233485	et	4	main
maale	doc_120968879138_item	2233487	et	4	main
sõit	doc_120968879138_item	2233491	et	3	main
imelik	doc_120968879138_item	2233493	et	3	main
kord	doc_120968879138_item	2233500	et	4	main
kõik	doc_120968879138_item	2233502	et	4	main
minu	doc_120968879138_item	2233506	et	3	main
tekkitas	doc_120968879138_item	2233508	et	4	main
õues	doc_120968879138_item	2233511	et	4	main
koduloomad	doc_120968879138_item	2233513	et	3	main
kord	doc_120968879138_item	2233516	et	4	main
asi	doc_120968879138_item	2233524	et	4	main
see	doc_120968879138_item	2233528	et	3	main
võtma	doc_120968879138_item	2233537	et	3	main
kaevast	doc_120968879138_item	2233538	et	4	main
ebamugavused	doc_120968879138_item	2233542	et	4	main
mina	doc_120968879138_item	2233545	et	4	main
aru	doc_120968879138_item	2233547	et	4	main
asi	doc_120968879138_item	2233549	et	4	main
ja	doc_120968879138_item	2233555	et	3	main
ja	doc_120968879139_item	2233563	et	3	main
käinud	doc_120968879139_item	2233570	et	4	main
väga	doc_120968879139_item	2233573	et	3	main
et	doc_120968879139_item	2233600	et	3	main
kohta	doc_120968879139_item	2233604	et	4	main
polnud	doc_120968879139_item	2233608	et	3	main
soovi	doc_120968879139_item	2233610	et	4	main
kiireneni	doc_120968879139_item	2233612	et	4	main
teises	doc_120968879139_item	2233618	et	4	main
olen	doc_120968879139_item	2233620	et	3	main
ma	doc_120968879139_item	2233629	et	3	main
oma	doc_120968879139_item	2233631	et	4	main
kus	doc_120968879139_item	2233638	et	3	main
polnud	doc_120968879139_item	2233641	et	3	main
huvitavat	doc_120968879139_item	2233644	et	4	main
igas	doc_120968879139_item	2233647	et	3	main
ka	doc_120968879139_item	2233655	et	3	main
seal	doc_120968879139_item	2233656	et	4	main
kai	doc_120968879139_item	2233658	et	4	main
armastab	doc_120968879139_item	2233670	et	3	main
vene	doc_120968879139_item	2233708	et	4	main
väga	doc_120968879139_item	2233713	et	3	main
muusika	doc_120968879139_item	2233714	et	4	main
eneergiline	doc_120968879139_item	2233716	et	4	main
kohti	doc_120968879139_item	2233718	et	4	main
päike	doc_120968879137_item	2233358	et	3	main
meid	doc_120968879137_item	2233360	et	4	main
olin	doc_120968879137_item	2233362	et	3	main
hulka	doc_120968879137_item	2233366	et	4	main
ääres	doc_120968879137_item	2233375	et	4	main
ja	doc_120968879137_item	2233405	et	3	main
käinud	doc_120968879138_item	2233413	et	4	main
olen	doc_120968879138_item	2233415	et	3	main
väga	doc_120968879138_item	2233417	et	3	main
igal	doc_120968879138_item	2233423	et	3	main
lähen	doc_120968879138_item	2233425	et	3	main
mulle	doc_120968879138_item	2233430	et	4	main
kõik	doc_120968879138_item	2233440	et	4	main
inimesed	doc_120968879138_item	2233451	et	3	main
elusuhtumine	doc_120968879138_item	2233453	et	4	main
ja	doc_120968879138_item	2233455	et	3	main
ilm	doc_120968879138_item	2233457	et	3	main
mina	doc_120968879138_item	2233459	et	4	main
öelda	doc_120968879138_item	2233463	et	4	main
ebab	doc_120968879138_item	2233473	et	4	main
minu	doc_120968879138_item	2233474	et	3	main
sugulastele	doc_120968879138_item	2233489	et	4	main
sest	doc_120968879138_item	2233496	et	4	main
esimene	doc_120968879138_item	2233499	et	3	main
inimesed	doc_120968879138_item	2233505	et	3	main
ümber	doc_120968879138_item	2233507	et	3	main
mul	doc_120968879138_item	2233509	et	3	main
silmasin	doc_120968879138_item	2233517	et	3	main
ei	doc_120968879138_item	2233519	et	4	main
olen	doc_120968879138_item	2233412	et	3	main
riik	doc_120968879138_item	2233428	et	3	main
kuldsad	doc_120968879138_item	2233434	et	4	main
kuhu	doc_120968879138_item	2233442	et	3	main
käinud	doc_120968879138_item	2233444	et	4	main
erinevad	doc_120968879138_item	2233446	et	4	main
on	doc_120968879138_item	2233448	et	4	main
täpselt	doc_120968879138_item	2233462	et	4	main
olen	doc_120968879138_item	2233471	et	3	main
aga	doc_120968879138_item	2233476	et	3	main
see	doc_120968879138_item	2233490	et	3	main
oli	doc_120968879138_item	2233492	et	3	main
olin	doc_120968879138_item	2233498	et	3	main
tegid	doc_120968879138_item	2233504	et	4	main
šokki	doc_120968879138_item	2233510	et	2	main
jalutasid	doc_120968879138_item	2233512	et	4	main
mina	doc_120968879138_item	2233514	et	4	main
hirmitas	doc_120968879138_item	2233527	et	4	main
puhkuse	doc_120968879138_item	2233543	et	3	main
saanud	doc_120968879138_item	2233546	et	4	main
linna	doc_120968879138_item	2233553	et	4	main
olen	doc_120968879139_item	2233561	et	3	main
venemaa	doc_120968879139_item	2233571	et	4	main
hästi	doc_120968879139_item	2233601	et	3	main
ka	doc_120968879139_item	2233607	et	3	main
sõida	doc_120968879139_item	2233613	et	4	main
kui	doc_120968879139_item	2233615	et	3	main
juba	doc_120968879139_item	2233617	et	3	main
rongis	doc_120968879139_item	2233619	et	4	main
mina	doc_120968879138_item	2233422	et	4	main
aastal	doc_120968879138_item	2233424	et	3	main
iga	doc_120968879138_item	2233427	et	4	main
jäätab	doc_120968879138_item	2233429	et	3	main
paremad	doc_120968879138_item	2233432	et	4	main
rannad	doc_120968879138_item	2233435	et	3	main
nii	doc_120968879138_item	2233445	et	3	main
seal	doc_120968879138_item	2233447	et	4	main
ka	doc_120968879138_item	2233458	et	3	main
oli	doc_120968879138_item	2233465	et	3	main
üks	doc_120968879138_item	2233477	et	3	main
mul	doc_120968879138_item	2233479	et	3	main
omapärane	doc_120968879138_item	2233481	et	4	main
mina	doc_120968879138_item	2233483	et	4	main
sõitsime	doc_120968879138_item	2233486	et	3	main
minu	doc_120968879138_item	2233494	et	3	main
mida	doc_120968879138_item	2233503	et	4	main
esimene	doc_120968879138_item	2233515	et	3	main
lehm	doc_120968879138_item	2233518	et	3	main
ole	doc_120968879138_item	2233520	et	4	main
mind	doc_120968879138_item	2233526	et	4	main
mugavuse	doc_120968879138_item	2233530	et	4	main
vesi	doc_120968879138_item	2233535	et	4	main
lõpuks	doc_120968879138_item	2233544	et	4	main
olen	doc_120968879138_item	2233552	et	3	main
eluga	doc_120968879138_item	2233556	et	3	main
essee	doc_120968879139_item	2233559	et	4	main
mida	doc_120968879139_item	2233564	et	4	main
olen	doc_120968879139_item	2233565	et	3	main
olen	doc_120968879139_item	2233567	et	3	main
venemaal	doc_120968879139_item	2233569	et	4	main
vähe	doc_120968879139_item	2233598	et	3	main
seda	doc_120968879139_item	2233603	et	3	main
lobinesin	doc_120968879139_item	2233630	et	4	main
peatuseni	doc_120968879139_item	2233632	et	4	main
siis	doc_120968879139_item	2233633	et	3	main
kohas	doc_120968879139_item	2233635	et	4	main
linnas	doc_120968879139_item	2233637	et	4	main
ma	doc_120968879139_item	2233639	et	3	main
seal	doc_120968879139_item	2233649	et	4	main
baarid	doc_120968879139_item	2233651	et	3	main
kinod	doc_120968879139_item	2233653	et	3	main
kai	doc_120968879139_item	2233659	et	4	main
selles	doc_120968879139_item	2233663	et	4	main
selline	doc_120968879139_item	2233667	et	4	main
aga	doc_120968879139_item	2233697	et	3	main
ühendanud	doc_120968879139_item	2233704	et	4	main
mulle	doc_120968879139_item	2233710	et	4	main
oled	doc_120968879139_item	2233721	et	3	main
siis	doc_120968879139_item	2233723	et	3	main
võimalus	doc_120968879139_item	2233726	et	3	main
baari	doc_120968879139_item	2233728	et	4	main
on	doc_120968879139_item	2233746	et	4	main
ilusaim	doc_120968879139_item	2233748	et	4	main
ma	doc_120968879139_item	2233751	et	3	main
seal	doc_120968879139_item	2233754	et	4	main
seeni	doc_120968879139_item	2233755	et	3	main
täpselt	doc_120968879139_item	2233767	et	4	main
nagu	doc_120968879139_item	2233769	et	3	main
suure	doc_120968879139_item	2233774	et	3	main
peaga	doc_120968879139_item	2233776	et	3	main
väikesed	doc_120968879139_item	2233780	et	4	main
polnud	doc_120968879139_item	2233785	et	3	main
ma	doc_120968879139_item	2233793	et	3	main
venemaad	doc_120968879139_item	2233795	et	4	main
aasta	doc_120968879139_item	2233797	et	4	main
ka	doc_120968879139_item	2233804	et	3	main
et	doc_120968879139_item	2233811	et	3	main
ma	doc_120968879139_item	2233813	et	3	main
pole	doc_120968879139_item	2233824	et	3	main
olen	doc_120968879140_item	2233828	et	3	main
see	doc_120968879140_item	2233830	et	3	main
tagasi	doc_120968879140_item	2233835	et	3	main
sõbrad	doc_120968879140_item	2233845	et	3	main
mind	doc_120968879140_item	2233850	et	4	main
autoga	doc_120968879140_item	2233855	et	3	main
see	doc_120968879140_item	2233857	et	3	main
aega	doc_120968879140_item	2233860	et	4	main
odavam	doc_120968879140_item	2233864	et	4	main
kahjuks	doc_120968879140_item	2233873	et	4	main
seal	doc_120968879140_item	2233878	et	4	main
ka	doc_120968879140_item	2233880	et	3	main
veel	doc_120968879138_item	2233522	et	4	main
oli	doc_120968879138_item	2233529	et	3	main
tualett	doc_120968879138_item	2233532	et	3	main
õues	doc_120968879138_item	2233534	et	4	main
peab	doc_120968879138_item	2233536	et	4	main
muud	doc_120968879138_item	2233541	et	4	main
üks	doc_120968879138_item	2233548	et	3	main
ma	doc_120968879138_item	2233551	et	3	main
külas	doc_120968879138_item	2233557	et	3	main
kus	doc_120968879139_item	2233560	et	3	main
käinud	doc_120968879139_item	2233562	et	4	main
näinud	doc_120968879139_item	2233566	et	4	main
suvel	doc_120968879139_item	2233568	et	3	main
suur	doc_120968879139_item	2233574	et	3	main
riik	doc_120968879139_item	2233575	et	3	main
kus	doc_120968879139_item	2233576	et	3	main
on	doc_120968879139_item	2233577	et	4	main
kõik	doc_120968879139_item	2233578	et	4	main
olemas	doc_120968879139_item	2233579	et	4	main
esiteks	doc_120968879139_item	2233580	et	3	main
olen	doc_120968879139_item	2233581	et	3	main
rongijaamaga	doc_120968879139_item	2233582	et	3	main
tutvunud	doc_120968879139_item	2233583	et	4	main
see	doc_120968879139_item	2233584	et	3	main
on	doc_120968879139_item	2233585	et	4	main
küllaltki	doc_120968879139_item	2233586	et	4	main
hall	doc_120968879139_item	2233587	et	4	main
koht	doc_120968879139_item	2233588	et	3	main
kus	doc_120968879139_item	2233589	et	3	main
on	doc_120968879139_item	2233590	et	4	main
ühes	doc_120968879139_item	2233591	et	4	main
kohas	doc_120968879139_item	2233592	et	4	main
kogenenud	doc_120968879139_item	2233593	et	4	main
kõik	doc_120968879139_item	2233594	et	4	main
rahvused	doc_120968879139_item	2233595	et	3	main
mul	doc_120968879139_item	2233596	et	3	main
olnud	doc_120968879139_item	2233597	et	4	main
on	doc_120968879139_item	2233606	et	4	main
mul	doc_120968879139_item	2233609	et	3	main
huvitav	doc_120968879139_item	2233626	et	4	main
kellega	doc_120968879139_item	2233628	et	3	main
selles	doc_120968879139_item	2233636	et	4	main
olin	doc_120968879139_item	2233640	et	3	main
aga	doc_120968879139_item	2233645	et	3	main
nagu	doc_120968879139_item	2233646	et	3	main
linnas	doc_120968879139_item	2233648	et	4	main
on	doc_120968879139_item	2233660	et	4	main
sellepärast	doc_120968879139_item	2233665	et	3	main
inimene	doc_120968879139_item	2233668	et	3	main
istuda	doc_120968879139_item	2233672	et	3	main
kõik	doc_120968879139_item	2233702	et	4	main
on	doc_120968879139_item	2233703	et	4	main
kluubist	doc_120968879139_item	2233709	et	4	main
meeldis	doc_120968879139_item	2233711	et	3	main
sa	doc_120968879139_item	2233720	et	3	main
väsinud	doc_120968879139_item	2233722	et	4	main
sul	doc_120968879139_item	2233724	et	3	main
kino	doc_120968879139_item	2233727	et	4	main
on	doc_120968879139_item	2233731	et	4	main
ja	doc_120968879139_item	2233733	et	3	main
vaatavad	doc_120968879139_item	2233735	et	4	main
viimane	doc_120968879139_item	2233739	et	3	main
tahan	doc_120968879139_item	2233741	et	3	main
on	doc_120968879139_item	2233743	et	4	main
koht	doc_120968879139_item	2233749	et	3	main
väga	doc_120968879139_item	2233758	et	3	main
olen	doc_120968879139_item	2233760	et	3	main
imestanud	doc_120968879139_item	2233762	et	4	main
nad	doc_120968879139_item	2233765	et	3	main
olid	doc_120968879139_item	2233766	et	4	main
sellisid	doc_120968879139_item	2233768	et	3	main
muinasjuttuds	doc_120968879139_item	2233773	et	4	main
punase	doc_120968879139_item	2233775	et	4	main
peal	doc_120968879139_item	2233778	et	4	main
elavad	doc_120968879139_item	2233800	et	4	main
venemaale	doc_120968879139_item	2233817	et	4	main
vist	doc_120968879139_item	2233819	et	4	main
mida	doc_120968879139_item	2233822	et	4	main
sajas	doc_120968879140_item	2233837	et	4	main
lõuna	doc_120968879140_item	2233841	et	4	main
mulle	doc_120968879140_item	2233847	et	4	main
vähem	doc_120968879140_item	2233859	et	4	main
rongiga	doc_120968879140_item	2233862	et	4	main
kui	doc_120968879140_item	2233865	et	3	main
väga	doc_120968879140_item	2233869	et	3	main
ei	doc_120968879140_item	2233875	et	4	main
on	doc_120968879140_item	2233915	et	4	main
me	doc_120968879140_item	2233923	et	4	main
tundi	doc_120968879140_item	2233928	et	4	main
sõidsime	doc_120968879140_item	2233931	et	4	main
aga	doc_120968879140_item	2233934	et	3	main
olnud	doc_120968879140_item	2233938	et	4	main
auto	doc_120968879140_item	2233943	et	4	main
me	doc_120968879140_item	2233946	et	4	main
tagasi	doc_120968879140_item	2233948	et	3	main
meil	doc_120968879140_item	2233949	et	4	main
minna	doc_120968879140_item	2233953	et	3	main
aga	doc_120968879140_item	2233955	et	3	main
juba	doc_120968879140_item	2233957	et	3	main
ei	doc_120968879140_item	2233961	et	4	main
sõitnud	doc_120968879140_item	2233962	et	4	main
asub	doc_120968879140_item	2233982	et	3	main
ma	doc_120968879140_item	2233986	et	3	main
lähen	doc_120968879140_item	2233988	et	3	main
ja	doc_120968879140_item	2233990	et	3	main
käinud	doc_120968879141_item	2233997	et	4	main
olen	doc_120968879141_item	2234000	et	3	main
venemaal	doc_120968879141_item	2234006	et	4	main
arvan	doc_120968879141_item	2234010	et	3	main
juba	doc_120968879141_item	2234013	et	3	main
et	doc_120968879141_item	2234016	et	3	main
on	doc_120968879141_item	2234018	et	4	main
just	doc_120968879141_item	2234025	et	3	main
ja	doc_120968879141_item	2234027	et	3	main
sankt	doc_120968879141_item	2234029	et	4	main
me	doc_120968879141_item	2234037	et	4	main
möödus	doc_120968879141_item	2234043	et	3	main
olime	doc_120968879141_item	2234046	et	3	main
laptšenko	doc_120968879141_item	2234053	et	2	main
picasso	doc_120968879141_item	2234059	et	4	main
tutvudud	doc_120968879139_item	2233622	et	4	main
oli	doc_120968879139_item	2233624	et	3	main
inimene	doc_120968879139_item	2233627	et	3	main
väga	doc_120968879139_item	2233643	et	3	main
kluubid	doc_120968879139_item	2233652	et	4	main
teatrid	doc_120968879139_item	2233654	et	3	main
on	doc_120968879139_item	2233657	et	4	main
lemmikkoht	doc_120968879139_item	2233662	et	3	main
linnas	doc_120968879139_item	2233664	et	4	main
olen	doc_120968879139_item	2233666	et	3	main
lihtsalt	doc_120968879139_item	2233671	et	4	main
mõelda	doc_120968879139_item	2233673	et	4	main
omast	doc_120968879139_item	2233674	et	4	main
ja	doc_120968879139_item	2233675	et	3	main
vaadata	doc_120968879139_item	2233676	et	4	main
laiste	doc_120968879139_item	2233677	et	4	main
peale	doc_120968879139_item	2233678	et	4	main
see	doc_120968879139_item	2233679	et	3	main
nõrgendab	doc_120968879139_item	2233680	et	3	main
mind	doc_120968879139_item	2233681	et	4	main
olen	doc_120968879139_item	2233682	et	3	main
mitu	doc_120968879139_item	2233683	et	4	main
korda	doc_120968879139_item	2233684	et	4	main
kinos	doc_120968879139_item	2233685	et	3	main
käinud	doc_120968879139_item	2233686	et	4	main
võin	doc_120968879139_item	2233687	et	3	main
täpselt	doc_120968879139_item	2233688	et	4	main
ööelda	doc_120968879139_item	2233689	et	4	main
et	doc_120968879139_item	2233690	et	3	main
eesti	doc_120968879139_item	2233691	et	4	main
kinod	doc_120968879139_item	2233692	et	3	main
on	doc_120968879139_item	2233693	et	4	main
parem	doc_120968879139_item	2233694	et	4	main
ja	doc_120968879139_item	2233695	et	3	main
mugavam	doc_120968879139_item	2233696	et	4	main
meil	doc_120968879139_item	2233698	et	4	main
hinnad	doc_120968879139_item	2233700	et	3	main
tahaks	doc_120968879139_item	2233705	et	3	main
jutustada	doc_120968879139_item	2233707	et	3	main
kus	doc_120968879139_item	2233730	et	3	main
tihem	doc_120968879139_item	2233732	et	4	main
kõik	doc_120968879139_item	2233734	et	4	main
millest	doc_120968879139_item	2233740	et	3	main
kirjutada	doc_120968879139_item	2233742	et	3	main
see	doc_120968879139_item	2233745	et	3	main
oli	doc_120968879139_item	2233757	et	3	main
iludusega	doc_120968879139_item	2233764	et	3	main
valged	doc_120968879139_item	2233781	et	3	main
kahjuks	doc_120968879139_item	2233783	et	4	main
säilitada	doc_120968879139_item	2233788	et	3	main
võtta	doc_120968879139_item	2233792	et	3	main
seal	doc_120968879139_item	2233798	et	4	main
mul	doc_120968879139_item	2233799	et	3	main
sugulasi	doc_120968879139_item	2233803	et	3	main
on	doc_120968879139_item	2233806	et	4	main
selliseid	doc_120968879139_item	2233815	et	4	main
palju	doc_120968879139_item	2233717	et	4	main
kui	doc_120968879139_item	2233719	et	3	main
tulla	doc_120968879139_item	2233729	et	3	main
ekraanil	doc_120968879139_item	2233737	et	3	main
mets	doc_120968879139_item	2233744	et	3	main
maailmas	doc_120968879139_item	2233750	et	3	main
korjanud	doc_120968879139_item	2233753	et	4	main
neid	doc_120968879139_item	2233756	et	4	main
palju	doc_120968879139_item	2233759	et	4	main
väga	doc_120968879139_item	2233761	et	3	main
näha	doc_120968879139_item	2233772	et	3	main
mille	doc_120968879139_item	2233777	et	3	main
on	doc_120968879139_item	2233779	et	4	main
täppid	doc_120968879139_item	2233782	et	4	main
mul	doc_120968879139_item	2233784	et	3	main
võimalusi	doc_120968879139_item	2233786	et	3	main
kojju	doc_120968879139_item	2233790	et	4	main
kaasa	doc_120968879139_item	2233791	et	4	main
külastan	doc_120968879139_item	2233794	et	3	main
iga	doc_120968879139_item	2233796	et	4	main
väga	doc_120968879139_item	2233801	et	3	main
palju	doc_120968879139_item	2233807	et	4	main
asju	doc_120968879139_item	2233809	et	3	main
loodan	doc_120968879139_item	2233810	et	3	main
põnevaid	doc_120968879139_item	2233821	et	3	main
ma	doc_120968879139_item	2233823	et	3	main
essee	doc_120968879140_item	2233826	et	4	main
laupäev	doc_120968879140_item	2233832	et	3	main
nädalad	doc_120968879140_item	2233834	et	3	main
homikul	doc_120968879140_item	2233836	et	4	main
vihm	doc_120968879140_item	2233838	et	3	main
pärast	doc_120968879140_item	2233840	et	4	main
ta	doc_120968879140_item	2233842	et	4	main
me	doc_120968879140_item	2233852	et	4	main
keila	doc_120968879140_item	2233867	et	4	main
linn	doc_120968879140_item	2233871	et	3	main
ja	doc_120968879140_item	2233872	et	3	main
seal	doc_120968879140_item	2233874	et	4	main
aga	doc_120968879140_item	2233917	et	3	main
või	doc_120968879140_item	2233919	et	4	main
on	doc_120968879139_item	2233725	et	4	main
suurel	doc_120968879139_item	2233736	et	3	main
filmi	doc_120968879139_item	2233738	et	4	main
täpselt	doc_120968879139_item	2233747	et	4	main
olen	doc_120968879139_item	2233752	et	3	main
kärbseseene	doc_120968879139_item	2233763	et	3	main
me	doc_120968879139_item	2233770	et	4	main
võime	doc_120968879139_item	2233771	et	4	main
neid	doc_120968879139_item	2233787	et	4	main
ja	doc_120968879139_item	2233789	et	3	main
palju	doc_120968879139_item	2233802	et	4	main
venemaal	doc_120968879139_item	2233805	et	4	main
huvitavaid	doc_120968879139_item	2233808	et	4	main
tulevikus	doc_120968879139_item	2233812	et	4	main
jätkan	doc_120968879139_item	2233814	et	3	main
reisseid	doc_120968879139_item	2233816	et	4	main
seal	doc_120968879139_item	2233818	et	4	main
palju	doc_120968879139_item	2233820	et	4	main
käinud	doc_120968879140_item	2233829	et	4	main
oli	doc_120968879140_item	2233831	et	3	main
lõpes	doc_120968879140_item	2233843	et	3	main
mu	doc_120968879140_item	2233844	et	3	main
helistanud	doc_120968879140_item	2233846	et	4	main
ja	doc_120968879140_item	2233848	et	3	main
sest	doc_120968879140_item	2233856	et	4	main
võtab	doc_120968879140_item	2233858	et	3	main
ja	doc_120968879140_item	2233863	et	3	main
maršruttaksoga	doc_120968879140_item	2233866	et	2	main
on	doc_120968879140_item	2233868	et	4	main
väike	doc_120968879140_item	2233870	et	4	main
vaatamisväärsusi	doc_120968879140_item	2233877	et	4	main
on	doc_120968879140_item	2233879	et	4	main
me	doc_120968879140_item	2233918	et	4	main
käia	doc_120968879140_item	2233922	et	4	main
olime	doc_120968879140_item	2233924	et	3	main
natuke	doc_120968879140_item	2233926	et	4	main
ka	doc_120968879140_item	2233951	et	3	main
ta	doc_120968879140_item	2233981	et	4	main
pildistan	doc_120968879140_item	2233991	et	3	main
lennuki	doc_120968879140_item	2233993	et	3	main
kus	doc_120968879141_item	2233995	et	3	main
ma	doc_120968879141_item	2234004	et	3	main
kõik	doc_120968879141_item	2234012	et	4	main
bussiga	doc_120968879141_item	2234032	et	3	main
perega	doc_120968879141_item	2234034	et	3	main
esimene	doc_120968879141_item	2234040	et	3	main
südalinnas	doc_120968879141_item	2234044	et	4	main
meeldis	doc_120968879141_item	2234052	et	3	main
nägin	doc_120968879141_item	2234056	et	3	main
ka	doc_120968879141_item	2234058	et	3	main
ei	doc_120968879141_item	2234061	et	4	main
oli	doc_120968879141_item	2234072	et	3	main
ja	doc_120968879141_item	2234078	et	3	main
mul	doc_120968879141_item	2234082	et	3	main
et	doc_120968879141_item	2234084	et	3	main
aga	doc_120968879141_item	2234124	et	3	main
vene	doc_120968879141_item	2234134	et	4	main
meega	doc_120968879141_item	2234139	et	3	main
puhata	doc_120968879141_item	2234153	et	4	main
kus	doc_120968879142_item	2234157	et	3	main
käinud	doc_120968879142_item	2234159	et	4	main
näinud	doc_120968879142_item	2234163	et	4	main
nädalal	doc_120968879142_item	2234165	et	3	main
oli	doc_120968879142_item	2234167	et	3	main
teele	doc_120968879142_item	2234198	et	3	main
mul	doc_120968879142_item	2234199	et	3	main
jalutada	doc_120968879142_item	2234207	et	3	main
on	doc_120968879142_item	2234221	et	4	main
rigikogus	doc_120968879142_item	2234225	et	4	main
tahavad	doc_120968879142_item	2234232	et	3	main
majja	doc_120968879142_item	2234236	et	3	main
seal	doc_120968879142_item	2234242	et	4	main
näinud	doc_120968879142_item	2234246	et	4	main
suured	doc_120968879142_item	2234248	et	3	main
see	doc_120968879142_item	2234251	et	3	main
väga	doc_120968879142_item	2234253	et	3	main
minu	doc_120968879142_item	2234281	et	3	main
ja	doc_120968879142_item	2234284	et	3	main
teda	doc_120968879142_item	2234289	et	4	main
oma	doc_120968879142_item	2234292	et	4	main
kõige	doc_120968879142_item	2234296	et	4	main
näinud	doc_120968879139_item	2233825	et	4	main
kus	doc_120968879140_item	2233827	et	3	main
kaks	doc_120968879140_item	2233833	et	3	main
aga	doc_120968879140_item	2233839	et	3	main
kutsunud	doc_120968879140_item	2233849	et	4	main
keilasse	doc_120968879140_item	2233851	et	4	main
sõidsime	doc_120968879140_item	2233853	et	4	main
keilasse	doc_120968879140_item	2233854	et	4	main
kui	doc_120968879140_item	2233861	et	3	main
ole	doc_120968879140_item	2233876	et	4	main
aga	doc_120968879140_item	2233882	et	3	main
me	doc_120968879140_item	2233883	et	4	main
tahtnud	doc_120968879140_item	2233885	et	4	main
seal	doc_120968879140_item	2233886	et	4	main
ei	doc_120968879140_item	2233884	et	4	main
minna	doc_120968879140_item	2233887	et	3	main
keila	doc_120968879140_item	2233888	et	4	main
juures	doc_120968879140_item	2233889	et	4	main
on	doc_120968879140_item	2233890	et	4	main
huvitavam	doc_120968879140_item	2233891	et	4	main
asi	doc_120968879140_item	2233892	et	4	main
keilast	doc_120968879140_item	2233893	et	4	main
seisab	doc_120968879140_item	2233894	et	3	main
üks	doc_120968879140_item	2233895	et	3	main
vene	doc_120968879140_item	2233896	et	4	main
lennuk	doc_120968879140_item	2233897	et	3	main
16	doc_120968879140_item	2233899	et	2	main
see	doc_120968879140_item	2233900	et	3	main
an	doc_120968879140_item	2233898	et	4	main
on	doc_120968879140_item	2233901	et	4	main
suur	doc_120968879140_item	2233902	et	3	main
4	doc_120968879140_item	2233903	et	2	main
mootoreline	doc_120968879140_item	2233904	et	4	main
vene	doc_120968879140_item	2233905	et	4	main
lennuk	doc_120968879140_item	2233906	et	3	main
kahjuks	doc_120968879140_item	2233907	et	4	main
ei	doc_120968879140_item	2233909	et	4	main
me	doc_120968879140_item	2233908	et	4	main
saanud	doc_120968879140_item	2233910	et	4	main
sisse	doc_120968879140_item	2233911	et	4	main
minna	doc_120968879140_item	2233912	et	3	main
sest	doc_120968879140_item	2233913	et	4	main
ta	doc_120968879140_item	2233914	et	4	main
kinni	doc_120968879140_item	2233916	et	3	main
veepark	doc_120968879140_item	2233881	et	3	main
ümber	doc_120968879140_item	2233921	et	3	main
sõidsime	doc_120968879140_item	2233947	et	4	main
2130	doc_120968879140_item	2233958	et	2	main
me	doc_120968879140_item	2233960	et	4	main
seal	doc_120968879140_item	2233963	et	4	main
ja	doc_120968879140_item	2233983	et	3	main
laupäeval	doc_120968879140_item	2233985	et	3	main
seal	doc_120968879140_item	2233989	et	4	main
ja	doc_120968879141_item	2233998	et	3	main
mida	doc_120968879141_item	2233999	et	4	main
näinud	doc_120968879141_item	2234001	et	4	main
sel	doc_120968879141_item	2234002	et	3	main
täpsemalt	doc_120968879141_item	2234007	et	4	main
sankt	doc_120968879141_item	2234008	et	4	main
peterburis	doc_120968879141_item	2234009	et	4	main
ammu	doc_120968879141_item	2234014	et	4	main
imelik	doc_120968879141_item	2234019	et	3	main
eriti	doc_120968879141_item	2234021	et	3	main
sügisel	doc_120968879141_item	2234028	et	3	main
sõitsin	doc_120968879141_item	2234031	et	3	main
oma	doc_120968879141_item	2234033	et	4	main
koos	doc_120968879141_item	2234035	et	4	main
seal	doc_120968879141_item	2234036	et	4	main
päev	doc_120968879141_item	2234041	et	3	main
me	doc_120968879141_item	2234045	et	4	main
vene	doc_120968879141_item	2234047	et	4	main
vahva	doc_120968879141_item	2234073	et	4	main
näinud	doc_120968879141_item	2234075	et	4	main
ühel	doc_120968879141_item	2234080	et	3	main
vana	doc_120968879141_item	2234086	et	4	main
lennuki	doc_120968879140_item	2233920	et	3	main
pärast	doc_120968879140_item	2233930	et	4	main
joosse	doc_120968879140_item	2233933	et	4	main
kahjuks	doc_120968879140_item	2233935	et	4	main
kohti	doc_120968879140_item	2233939	et	4	main
kus	doc_120968879140_item	2233940	et	3	main
tasuta	doc_120968879140_item	2233942	et	4	main
parkida	doc_120968879140_item	2233944	et	4	main
ja	doc_120968879140_item	2233945	et	3	main
mõte	doc_120968879140_item	2233952	et	3	main
oli	doc_120968879140_item	2233956	et	3	main
kus	doc_120968879140_item	2233980	et	3	main
see	doc_120968879140_item	2233992	et	3	main
olen	doc_120968879141_item	2233996	et	3	main
teavad	doc_120968879141_item	2234015	et	3	main
seal	doc_120968879140_item	2233925	et	4	main
pool	doc_120968879140_item	2233927	et	4	main
ja	doc_120968879140_item	2233929	et	3	main
keila	doc_120968879140_item	2233932	et	4	main
seal	doc_120968879140_item	2233936	et	4	main
ei	doc_120968879140_item	2233937	et	4	main
võib	doc_120968879140_item	2233941	et	3	main
oli	doc_120968879140_item	2233950	et	3	main
suvilasse	doc_120968879140_item	2233954	et	4	main
ja	doc_120968879140_item	2233959	et	3	main
see	doc_120968879140_item	2233964	et	3	main
laupäev	doc_120968879140_item	2233965	et	3	main
oli	doc_120968879140_item	2233966	et	3	main
väga	doc_120968879140_item	2233967	et	3	main
huvitav	doc_120968879140_item	2233968	et	4	main
ma	doc_120968879140_item	2233970	et	3	main
ei	doc_120968879140_item	2233971	et	4	main
sest	doc_120968879140_item	2233969	et	4	main
näinud	doc_120968879140_item	2233972	et	4	main
enne	doc_120968879140_item	2233973	et	4	main
seda	doc_120968879140_item	2233974	et	3	main
an	doc_120968879140_item	2233975	et	4	main
nüüd	doc_120968879140_item	2233977	et	4	main
16i	doc_120968879140_item	2233976	et	4	main
ma	doc_120968879140_item	2233978	et	3	main
tean	doc_120968879140_item	2233979	et	3	main
järgmisel	doc_120968879140_item	2233984	et	3	main
ise	doc_120968879140_item	2233987	et	4	main
essee	doc_120968879141_item	2233994	et	4	main
suvel	doc_120968879141_item	2234003	et	3	main
olin	doc_120968879141_item	2234005	et	3	main
et	doc_120968879141_item	2234011	et	3	main
see	doc_120968879141_item	2234017	et	3	main
linn	doc_120968879141_item	2234020	et	3	main
ta	doc_120968879141_item	2234022	et	4	main
ilus	doc_120968879141_item	2234024	et	4	main
suvel	doc_120968879141_item	2234026	et	3	main
elasime	doc_120968879141_item	2234038	et	3	main
sugulastel	doc_120968879141_item	2234039	et	4	main
venemaal	doc_120968879141_item	2234042	et	4	main
muuseumis	doc_120968879141_item	2234048	et	3	main
kõige	doc_120968879141_item	2234049	et	4	main
ja	doc_120968879141_item	2234054	et	3	main
mulle	doc_120968879141_item	2234060	et	4	main
jäänud	doc_120968879141_item	2234062	et	4	main
meelde	doc_120968879141_item	2234063	et	3	main
tema	doc_120968879141_item	2234064	et	4	main
pilte	doc_120968879141_item	2234065	et	3	main
oleme	doc_120968879141_item	2234067	et	3	main
ka	doc_120968879141_item	2234069	et	3	main
olin	doc_120968879141_item	2234085	et	3	main
egiptus	doc_120968879141_item	2234087	et	4	main
minu	doc_120968879141_item	2234122	et	3	main
päeva	doc_120968879141_item	2234128	et	4	main
maal	doc_120968879141_item	2234131	et	4	main
poole	doc_120968879141_item	2234141	et	4	main
öelda	doc_120968879141_item	2234143	et	4	main
te	doc_120968879141_item	2234146	et	4	main
vene	doc_120968879141_item	2234148	et	4	main
sõitke	doc_120968879141_item	2234154	et	3	main
tore	doc_120968879142_item	2234169	et	3	main
päev	doc_120968879142_item	2234202	et	3	main
meel	doc_120968879142_item	2234205	et	4	main
ääresse	doc_120968879142_item	2234209	et	3	main
matk	doc_120968879142_item	2234211	et	3	main
ma	doc_120968879142_item	2234212	et	3	main
minu	doc_120968879142_item	2234217	et	3	main
ääres	doc_120968879142_item	2234219	et	4	main
on	doc_120968879141_item	2234023	et	4	main
peterburisse	doc_120968879141_item	2234030	et	4	main
rohkem	doc_120968879141_item	2234050	et	4	main
mulle	doc_120968879141_item	2234051	et	4	main
aivasovski	doc_120968879141_item	2234055	et	4	main
aga	doc_120968879141_item	2234057	et	3	main
siis	doc_120968879141_item	2234066	et	3	main
käinud	doc_120968879141_item	2234068	et	4	main
seal	doc_120968879141_item	2234071	et	4	main
egiptuse	doc_120968879141_item	2234076	et	4	main
püramiidi	doc_120968879141_item	2234077	et	4	main
muinashauakambri	doc_120968879141_item	2234079	et	3	main
hetkel	doc_120968879141_item	2234081	et	4	main
tundakse	doc_120968879141_item	2234083	et	4	main
oli	doc_120968879141_item	2234088	et	3	main
tore	doc_120968879141_item	2234089	et	3	main
ka	doc_120968879141_item	2234090	et	3	main
vene	doc_120968879141_item	2234091	et	4	main
tsaari	doc_120968879141_item	2234092	et	4	main
varamusel	doc_120968879141_item	2234093	et	4	main
järgmine	doc_120968879141_item	2234094	et	3	main
päev	doc_120968879141_item	2234095	et	3	main
me	doc_120968879141_item	2234096	et	4	main
veetsime	doc_120968879141_item	2234097	et	3	main
vanglas	doc_120968879141_item	2234098	et	3	main
ei	doc_120968879141_item	2234099	et	4	main
see	doc_120968879141_item	2234100	et	3	main
ei	doc_120968879141_item	2234101	et	4	main
ole	doc_120968879141_item	2234102	et	4	main
kaasaegne	doc_120968879141_item	2234103	et	3	main
vangla	doc_120968879141_item	2234104	et	4	main
see	doc_120968879141_item	2234105	et	3	main
hoone	doc_120968879141_item	2234106	et	4	main
on	doc_120968879141_item	2234107	et	4	main
üsna	doc_120968879141_item	2234108	et	3	main
vana	doc_120968879141_item	2234109	et	4	main
ja	doc_120968879141_item	2234110	et	3	main
tänapäeval	doc_120968879141_item	2234111	et	3	main
seal	doc_120968879141_item	2234112	et	4	main
asub	doc_120968879141_item	2234113	et	3	main
muuseum	doc_120968879141_item	2234114	et	3	main
ausalt	doc_120968879141_item	2234115	et	4	main
öeldes	doc_120968879141_item	2234116	et	3	main
oli	doc_120968879141_item	2234117	et	3	main
natukene	doc_120968879141_item	2234118	et	4	main
õudselt	doc_120968879141_item	2234119	et	4	main
ja	doc_120968879141_item	2234120	et	3	main
hirmsalt	doc_120968879141_item	2234121	et	4	main
vendadele	doc_120968879141_item	2234123	et	3	main
paar	doc_120968879141_item	2234127	et	3	main
ermitaaži	doc_120968879141_item	2234070	et	2	main
olen	doc_120968879141_item	2234074	et	3	main
väga	doc_120968879141_item	2234126	et	3	main
ja	doc_120968879141_item	2234136	et	3	main
keha	doc_120968879141_item	2234138	et	4	main
soovite	doc_120968879141_item	2234147	et	3	main
essee	doc_120968879142_item	2234156	et	4	main
olen	doc_120968879142_item	2234158	et	3	main
ja	doc_120968879142_item	2234160	et	3	main
olen	doc_120968879142_item	2234162	et	3	main
pühapäeval	doc_120968879142_item	2234166	et	3	main
väga	doc_120968879142_item	2234168	et	3	main
kaugele	doc_120968879142_item	2234197	et	4	main
oli	doc_120968879142_item	2234200	et	3	main
mere	doc_120968879142_item	2234208	et	3	main
maja	doc_120968879142_item	2234218	et	4	main
seal	doc_120968879142_item	2234220	et	4	main
aga	doc_120968879142_item	2234224	et	3	main
sellisel	doc_120968879142_item	2234229	et	4	main
nad	doc_120968879142_item	2234231	et	3	main
seal	doc_120968879142_item	2234233	et	4	main
uusi	doc_120968879142_item	2234235	et	3	main
ehitada	doc_120968879142_item	2234237	et	3	main
ma	doc_120968879142_item	2234240	et	3	main
valged	doc_120968879142_item	2234249	et	3	main
ilus	doc_120968879142_item	2234254	et	4	main
ma	doc_120968879142_item	2234259	et	3	main
armastan	doc_120968879142_item	2234288	et	3	main
see	doc_120968879142_item	2234294	et	3	main
ja	doc_120968879142_item	2234299	et	3	main
ma	doc_120968879142_item	2234301	et	3	main
karta	doc_120968879142_item	2234313	et	3	main
kus	doc_120968879143_item	2234315	et	3	main
käinud	doc_120968879143_item	2234317	et	4	main
näinud	doc_120968879143_item	2234321	et	4	main
töötab	doc_120968879143_item	2234329	et	3	main
ja	doc_120968879143_item	2234337	et	3	main
kohtumiseks	doc_120968879143_item	2234345	et	4	main
juba	doc_120968879143_item	2234350	et	3	main
parendada	doc_120968879143_item	2234364	et	3	main
imestasin	doc_120968879143_item	2234370	et	3	main
oma	doc_120968879143_item	2234375	et	4	main
sest	doc_120968879143_item	2234379	et	4	main
suur	doc_120968879143_item	2234384	et	3	main
kui	doc_120968879143_item	2234385	et	3	main
võrrelda	doc_120968879143_item	2234393	et	4	main
te	doc_120968879143_item	2234424	et	4	main
oma	doc_120968879143_item	2234426	et	4	main
arvan	doc_120968879143_item	2234439	et	3	main
on	doc_120968879143_item	2234444	et	4	main
see	doc_120968879143_item	2234447	et	3	main
ainult	doc_120968879143_item	2234449	et	4	main
üldselt	doc_120968879143_item	2234452	et	4	main
meeldis	doc_120968879143_item	2234455	et	3	main
tema	doc_120968879143_item	2234459	et	4	main
ja	doc_120968879144_item	2234465	et	3	main
olen	doc_120968879144_item	2234470	et	3	main
ma	doc_120968879144_item	2234475	et	3	main
sportiga	doc_120968879144_item	2234477	et	4	main
osa	doc_120968879144_item	2234484	et	4	main
asi	doc_120968879144_item	2234487	et	4	main
ma	doc_120968879144_item	2234489	et	3	main
arvan	doc_120968879144_item	2234501	et	3	main
lennujaam	doc_120968879144_item	2234507	et	3	main
seal	doc_120968879144_item	2234509	et	4	main
ja	doc_120968879144_item	2234519	et	3	main
surepärane	doc_120968879144_item	2234526	et	4	main
linn	doc_120968879144_item	2234527	et	3	main
rootsi	doc_120968879144_item	2234530	et	4	main
tahaksin	doc_120968879144_item	2234546	et	3	main
eestis	doc_120968879144_item	2234548	et	3	main
tooted	doc_120968879144_item	2234558	et	3	main
on	doc_120968879144_item	2234559	et	4	main
kallid	doc_120968879144_item	2234561	et	3	main
eestis	doc_120968879144_item	2234562	et	3	main
näinud	doc_120968879144_item	2234567	et	4	main
nad	doc_120968879144_item	2234578	et	3	main
tahaksin	doc_120968879144_item	2234616	et	3	main
rootslased	doc_120968879144_item	2234618	et	3	main
reisi	doc_120968879144_item	2234620	et	4	main
hästi	doc_120968879144_item	2234625	et	3	main
elada	doc_120968879144_item	2234626	et	3	main
taha	doc_120968879145_item	2234632	et	4	main
meeldis	doc_120968879141_item	2234125	et	3	main
käinud	doc_120968879141_item	2234133	et	4	main
sauna	doc_120968879141_item	2234135	et	4	main
lõpu	doc_120968879141_item	2234140	et	3	main
tahaks	doc_120968879141_item	2234142	et	3	main
kui	doc_120968879141_item	2234145	et	3	main
kombeid	doc_120968879141_item	2234149	et	4	main
ja	doc_120968879141_item	2234151	et	3	main
venemaale	doc_120968879141_item	2234155	et	4	main
mida	doc_120968879142_item	2234161	et	4	main
praegu	doc_120968879142_item	2234171	et	3	main
aasta	doc_120968879142_item	2234172	et	4	main
aeg	doc_120968879142_item	2234173	et	3	main
on	doc_120968879142_item	2234174	et	4	main
sügis	doc_120968879142_item	2234175	et	3	main
eelmisel	doc_120968879142_item	2234177	et	3	main
aga	doc_120968879142_item	2234176	et	3	main
pühapäeval	doc_120968879142_item	2234178	et	3	main
oli	doc_120968879142_item	2234179	et	3	main
nägu	doc_120968879142_item	2234180	et	4	main
kuldsel	doc_120968879142_item	2234181	et	3	main
sügisel	doc_120968879142_item	2234182	et	3	main
päike	doc_120968879142_item	2234183	et	3	main
paistis	doc_120968879142_item	2234184	et	3	main
puhus	doc_120968879142_item	2234185	et	4	main
soe	doc_120968879142_item	2234186	et	4	main
tuul	doc_120968879142_item	2234187	et	3	main
puudel	doc_120968879142_item	2234188	et	4	main
olid	doc_120968879142_item	2234189	et	4	main
kollased	doc_120968879142_item	2234190	et	4	main
ja	doc_120968879142_item	2234191	et	3	main
punased	doc_120968879142_item	2234192	et	4	main
lehed	doc_120968879142_item	2234193	et	3	main
me	doc_120968879141_item	2234129	et	4	main
olime	doc_120968879141_item	2234130	et	3	main
oleme	doc_120968879141_item	2234132	et	3	main
määrisime	doc_120968879141_item	2234137	et	3	main
et	doc_120968879141_item	2234144	et	3	main
uurida	doc_120968879141_item	2234150	et	3	main
lihtsalt	doc_120968879141_item	2234152	et	4	main
eelmisel	doc_120968879142_item	2234164	et	3	main
ilm	doc_120968879142_item	2234170	et	3	main
kõik	doc_120968879142_item	2234194	et	4	main
rändlinnud	doc_120968879142_item	2234195	et	3	main
sättisid	doc_120968879142_item	2234196	et	4	main
vaba	doc_120968879142_item	2234201	et	4	main
hea	doc_120968879142_item	2234204	et	4	main
et	doc_120968879142_item	2234206	et	3	main
oma	doc_120968879142_item	2234210	et	4	main
alustasin	doc_120968879142_item	2234213	et	3	main
mida	doc_120968879142_item	2234215	et	4	main
loodus	doc_120968879142_item	2234223	et	4	main
palju	doc_120968879142_item	2234234	et	4	main
aga	doc_120968879142_item	2234238	et	3	main
ma	doc_120968879142_item	2234244	et	3	main
luiged	doc_120968879142_item	2234250	et	3	main
oli	doc_120968879142_item	2234252	et	3	main
romaantiline	doc_120968879142_item	2234256	et	4	main
pärast	doc_120968879142_item	2234258	et	4	main
sõber	doc_120968879142_item	2234279	et	3	main
kartasin	doc_120968879142_item	2234290	et	4	main
näidata	doc_120968879142_item	2234291	et	4	main
torem	doc_120968879142_item	2234297	et	4	main
päev	doc_120968879142_item	2234298	et	3	main
tean	doc_120968879142_item	2234302	et	3	main
ta	doc_120968879142_item	2234304	et	4	main
armastab	doc_120968879142_item	2234306	et	3	main
ja	doc_120968879142_item	2234308	et	3	main
midagi	doc_120968879142_item	2234311	et	4	main
paar	doc_120968879143_item	2234322	et	3	main
inglismaal	doc_120968879143_item	2234326	et	4	main
seal	doc_120968879143_item	2234328	et	4	main
ta	doc_120968879143_item	2234332	et	4	main
juba	doc_120968879143_item	2234338	et	3	main
mina	doc_120968879143_item	2234342	et	4	main
londonisse	doc_120968879143_item	2234344	et	4	main
sest	doc_120968879143_item	2234346	et	4	main
näinud	doc_120968879143_item	2234348	et	4	main
oli	doc_120968879143_item	2234353	et	3	main
eesmärk	doc_120968879143_item	2234355	et	3	main
külastamiseks	doc_120968879143_item	2234357	et	4	main
oma	doc_120968879143_item	2234365	et	4	main
kuidas	doc_120968879143_item	2234369	et	3	main
nägin	doc_120968879143_item	2234373	et	3	main
ei	doc_120968879143_item	2234381	et	4	main
olnud	doc_120968879143_item	2234382	et	4	main
arvasin	doc_120968879143_item	2234387	et	3	main
nägin	doc_120968879143_item	2234389	et	3	main
teleris	doc_120968879143_item	2234391	et	3	main
tahan	doc_120968879143_item	2234429	et	3	main
pilvine	doc_120968879143_item	2234437	et	4	main
poolest	doc_120968879143_item	2234441	et	4	main
aga	doc_120968879143_item	2234446	et	3	main
ja	doc_120968879143_item	2234458	et	3	main
näinud	doc_120968879144_item	2234468	et	4	main
esimene	doc_120968879144_item	2234486	et	3	main
mida	doc_120968879144_item	2234488	et	4	main
reisis	doc_120968879144_item	2234493	et	4	main
stokholmi	doc_120968879144_item	2234495	et	4	main
et	doc_120968879144_item	2234502	et	3	main
korda	doc_120968879144_item	2234504	et	4	main
kui	doc_120968879144_item	2234506	et	3	main
oma	doc_120968879144_item	2234517	et	4	main
tavaliselt	doc_120968879144_item	2234520	et	4	main
jalutavad	doc_120968879144_item	2234521	et	4	main
ma	doc_120968879144_item	2234523	et	3	main
näinud	doc_120968879144_item	2234525	et	4	main
see	doc_120968879144_item	2234528	et	3	main
stokholmis	doc_120968879144_item	2234533	et	4	main
on	doc_120968879144_item	2234535	et	4	main
hooned	doc_120968879144_item	2234539	et	4	main
on	doc_120968879144_item	2234540	et	4	main
linna	doc_120968879144_item	2234542	et	4	main
on	doc_120968879144_item	2234544	et	4	main
veel	doc_120968879144_item	2234551	et	4	main
ja	doc_120968879142_item	2234203	et	3	main
veekogust	doc_120968879142_item	2234214	et	4	main
asub	doc_120968879142_item	2234216	et	3	main
on	doc_120968879142_item	2234226	et	4	main
proektid	doc_120968879142_item	2234228	et	4	main
veekogusel	doc_120968879142_item	2234230	et	4	main
seal	doc_120968879142_item	2234243	et	4	main
kaks	doc_120968879142_item	2234247	et	3	main
olen	doc_120968879142_item	2234260	et	3	main
käinud	doc_120968879142_item	2234261	et	4	main
see	doc_120968879142_item	2234278	et	3	main
on	doc_120968879142_item	2234280	et	4	main
armas	doc_120968879142_item	2234282	et	3	main
hingepõhjas	doc_120968879142_item	2234285	et	3	main
väga-väga	doc_120968879142_item	2234287	et	3	main
praegu	doc_120968879142_item	2234300	et	3	main
ka	doc_120968879142_item	2234305	et	3	main
mind	doc_120968879142_item	2234307	et	4	main
ma	doc_120968879142_item	2234309	et	3	main
ja	doc_120968879143_item	2234318	et	3	main
külastasin	doc_120968879143_item	2234325	et	3	main
londonis	doc_120968879143_item	2234327	et	4	main
minu	doc_120968879143_item	2234330	et	3	main
professionaalne	doc_120968879143_item	2234339	et	3	main
juuksur	doc_120968879143_item	2234340	et	3	main
ei	doc_120968879143_item	2234347	et	4	main
ammu	doc_120968879143_item	2234351	et	4	main
oli	doc_120968879143_item	2234359	et	3	main
rääkimis	doc_120968879143_item	2234366	et	4	main
kui	doc_120968879143_item	2234371	et	3	main
ta	doc_120968879143_item	2234380	et	4	main
nii	doc_120968879143_item	2234383	et	3	main
tunde	doc_120968879143_item	2234422	et	4	main
linnas	doc_120968879143_item	2234427	et	4	main
tallinnas	doc_120968879143_item	2234428	et	4	main
23	doc_120968879143_item	2234434	et	2	main
on	doc_120968879143_item	2234436	et	4	main
meie	doc_120968879143_item	2234442	et	4	main
sarnased	doc_120968879143_item	2234445	et	4	main
on	doc_120968879143_item	2234448	et	4	main
linn	doc_120968879143_item	2234457	et	3	main
essee	doc_120968879144_item	2234461	et	4	main
olen	doc_120968879144_item	2234463	et	3	main
mida	doc_120968879144_item	2234466	et	4	main
kuus	doc_120968879144_item	2234472	et	4	main
selles	doc_120968879144_item	2234492	et	4	main
väga	doc_120968879144_item	2234499	et	3	main
kümne	doc_120968879144_item	2234503	et	4	main
näinud	doc_120968879144_item	2234511	et	4	main
palju	doc_120968879144_item	2234513	et	4	main
kes	doc_120968879144_item	2234515	et	4	main
otavad	doc_120968879144_item	2234516	et	4	main
edasi	doc_120968879144_item	2234522	et	3	main
oli	doc_120968879144_item	2234529	et	3	main
stokholm	doc_120968879144_item	2234532	et	4	main
tänavad	doc_120968879144_item	2234543	et	4	main
nii	doc_120968879144_item	2234550	et	3	main
ma	doc_120968879144_item	2234552	et	3	main
miks	doc_120968879144_item	2234577	et	4	main
oleksid	doc_120968879144_item	2234610	et	4	main
minuti	doc_120968879144_item	2234612	et	3	main
pärast	doc_120968879144_item	2234619	et	4	main
eestisse	doc_120968879144_item	2234621	et	4	main
ilus	doc_120968879142_item	2234222	et	4	main
palju	doc_120968879142_item	2234227	et	4	main
kui	doc_120968879142_item	2234239	et	3	main
olin	doc_120968879142_item	2234241	et	3	main
olen	doc_120968879142_item	2234245	et	3	main
ja	doc_120968879142_item	2234255	et	3	main
pilt	doc_120968879142_item	2234257	et	3	main
pargis	doc_120968879142_item	2234262	et	3	main
ja	doc_120968879142_item	2234263	et	3	main
leppisin	doc_120968879142_item	2234264	et	3	main
kokku	doc_120968879142_item	2234265	et	3	main
seal	doc_120968879142_item	2234266	et	4	main
oma	doc_120968879142_item	2234267	et	4	main
sõpradega	doc_120968879142_item	2234268	et	3	main
me	doc_120968879142_item	2234269	et	4	main
jalutasime	doc_120968879142_item	2234270	et	3	main
ja	doc_120968879142_item	2234271	et	3	main
vestlesime	doc_120968879142_item	2234272	et	3	main
omast	doc_120968879142_item	2234273	et	4	main
unistusest	doc_120968879142_item	2234274	et	4	main
soovist	doc_120968879142_item	2234275	et	4	main
seisundisest	doc_120968879142_item	2234277	et	4	main
süda	doc_120968879142_item	2234276	et	3	main
mees	doc_120968879142_item	2234283	et	4	main
ma	doc_120968879142_item	2234286	et	3	main
meel	doc_120968879142_item	2234293	et	4	main
oli	doc_120968879142_item	2234295	et	3	main
ei	doc_120968879142_item	2234312	et	4	main
essee	doc_120968879143_item	2234314	et	4	main
olen	doc_120968879143_item	2234316	et	3	main
mida	doc_120968879143_item	2234319	et	4	main
et	doc_120968879142_item	2234303	et	3	main
mitte	doc_120968879142_item	2234310	et	3	main
olen	doc_120968879143_item	2234320	et	3	main
tagasi	doc_120968879143_item	2234324	et	3	main
sõber	doc_120968879143_item	2234331	et	3	main
vana	doc_120968879143_item	2234336	et	4	main
see	doc_120968879143_item	2234352	et	3	main
esimene	doc_120968879143_item	2234354	et	3	main
keele	doc_120968879143_item	2234361	et	4	main
tahtsin	doc_120968879143_item	2234363	et	3	main
oskust	doc_120968879143_item	2234367	et	3	main
mäletan	doc_120968879143_item	2234368	et	3	main
esmakordselt	doc_120968879143_item	2234372	et	4	main
bigbeni	doc_120968879143_item	2234374	et	4	main
silmadega	doc_120968879143_item	2234376	et	3	main
imestasin	doc_120968879143_item	2234378	et	3	main
ma	doc_120968879143_item	2234386	et	3	main
kui	doc_120968879143_item	2234388	et	3	main
nende	doc_120968879143_item	2234394	et	4	main
et	doc_120968879143_item	2234423	et	3	main
olete	doc_120968879143_item	2234425	et	3	main
et	doc_120968879143_item	2234431	et	3	main
londonis	doc_120968879143_item	2234433	et	4	main
aastast	doc_120968879143_item	2234435	et	4	main
linnad	doc_120968879143_item	2234443	et	3	main
minu	doc_120968879143_item	2234450	et	3	main
mulle	doc_120968879143_item	2234453	et	4	main
see	doc_120968879143_item	2234456	et	3	main
elurütm	doc_120968879143_item	2234460	et	3	main
kus	doc_120968879144_item	2234462	et	3	main
ma	doc_120968879144_item	2234469	et	3	main
jaanuari	doc_120968879144_item	2234471	et	4	main
rootsis	doc_120968879144_item	2234473	et	3	main
tegelen	doc_120968879144_item	2234476	et	3	main
ja	doc_120968879144_item	2234478	et	3	main
sõitnud	doc_120968879144_item	2234480	et	4	main
et	doc_120968879144_item	2234482	et	3	main
võtta	doc_120968879144_item	2234485	et	3	main
näinud	doc_120968879144_item	2234491	et	4	main
suurem	doc_120968879144_item	2234505	et	4	main
reisi	doc_120968879144_item	2234518	et	4	main
väga	doc_120968879144_item	2234536	et	3	main
vanad	doc_120968879144_item	2234538	et	3	main
korralikud	doc_120968879144_item	2234545	et	3	main
et	doc_120968879144_item	2234547	et	3	main
olen	doc_120968879144_item	2234553	et	3	main
et	doc_120968879144_item	2234555	et	3	main
kõik	doc_120968879144_item	2234557	et	4	main
et	doc_120968879144_item	2234568	et	3	main
on	doc_120968879144_item	2234570	et	4	main
ma	doc_120968879144_item	2234572	et	3	main
saa	doc_120968879144_item	2234574	et	4	main
viie	doc_120968879144_item	2234611	et	3	main
et	doc_120968879144_item	2234617	et	3	main
jutustavad	doc_120968879144_item	2234622	et	4	main
kuidas	doc_120968879144_item	2234623	et	3	main
siin	doc_120968879144_item	2234624	et	4	main
kus	doc_120968879145_item	2234628	et	3	main
lugeda	doc_120968879145_item	2234633	et	3	main
kus	doc_120968879145_item	2234634	et	3	main
pärast	doc_120968879145_item	2234638	et	4	main
suvi	doc_120968879145_item	2234649	et	3	main
seal	doc_120968879145_item	2234652	et	4	main
kergem	doc_120968879145_item	2234659	et	4	main
oli	doc_120968879145_item	2234661	et	3	main
reamehed	doc_120968879145_item	2234679	et	3	main
juba	doc_120968879145_item	2234694	et	3	main
midagi	doc_120968879145_item	2234706	et	4	main
ühe	doc_120968879145_item	2234713	et	4	main
ringi	doc_120968879145_item	2234716	et	4	main
aega	doc_120968879145_item	2234718	et	4	main
mõtlesin	doc_120968879145_item	2234719	et	3	main
et	doc_120968879145_item	2234720	et	3	main
korras	doc_120968879145_item	2234727	et	4	main
telki	doc_120968879145_item	2234729	et	4	main
ja	doc_120968879145_item	2234730	et	3	main
kohe	doc_120968879145_item	2234731	et	4	main
magama	doc_120968879145_item	2234732	et	3	main
sõjaväest	doc_120968879145_item	2234736	et	3	main
aastat	doc_120968879145_item	2234744	et	3	main
võistluses	doc_120968879145_item	2234751	et	3	main
seal	doc_120968879145_item	2234763	et	4	main
aastat	doc_120968879143_item	2234323	et	3	main
on	doc_120968879143_item	2234333	et	4	main
27	doc_120968879143_item	2234334	et	2	main
aastat	doc_120968879143_item	2234335	et	3	main
ja	doc_120968879143_item	2234341	et	3	main
tulin	doc_120968879143_item	2234343	et	3	main
teda	doc_120968879143_item	2234349	et	4	main
londoni	doc_120968879143_item	2234356	et	4	main
teine	doc_120968879143_item	2234358	et	3	main
aga	doc_120968879143_item	2234360	et	3	main
pärast	doc_120968879143_item	2234362	et	4	main
miks	doc_120968879143_item	2234377	et	4	main
teda	doc_120968879143_item	2234390	et	4	main
võib	doc_120968879143_item	2234392	et	3	main
bigbeni	doc_120968879143_item	2234395	et	4	main
meie	doc_120968879143_item	2234396	et	4	main
oleviste	doc_120968879143_item	2234397	et	4	main
kirikuga	doc_120968879143_item	2234398	et	3	main
aga	doc_120968879143_item	2234399	et	3	main
pean	doc_120968879143_item	2234400	et	4	main
märkama	doc_120968879143_item	2234401	et	3	main
et	doc_120968879143_item	2234402	et	3	main
nende	doc_120968879143_item	2234403	et	4	main
torn	doc_120968879143_item	2234404	et	3	main
on	doc_120968879143_item	2234405	et	4	main
väga	doc_120968879143_item	2234406	et	3	main
ilus	doc_120968879143_item	2234407	et	4	main
ja	doc_120968879143_item	2234408	et	3	main
elekantne	doc_120968879143_item	2234409	et	4	main
veel	doc_120968879143_item	2234410	et	4	main
panin	doc_120968879143_item	2234411	et	3	main
tähele	doc_120968879143_item	2234412	et	3	main
et	doc_120968879143_item	2234413	et	3	main
elustiil	doc_120968879143_item	2234414	et	4	main
ei	doc_120968879143_item	2234416	et	4	main
peaaegu	doc_120968879143_item	2234415	et	3	main
erine	doc_120968879143_item	2234417	et	4	main
meiest	doc_120968879143_item	2234418	et	4	main
ilm	doc_120968879143_item	2234419	et	3	main
teeb	doc_120968879143_item	2234420	et	3	main
niisugust	doc_120968879143_item	2234421	et	3	main
öelda	doc_120968879143_item	2234430	et	4	main
ilm	doc_120968879143_item	2234432	et	3	main
mina	doc_120968879143_item	2234438	et	4	main
sellest	doc_120968879143_item	2234440	et	4	main
arvamus	doc_120968879143_item	2234451	et	3	main
väga	doc_120968879143_item	2234454	et	3	main
käinud	doc_120968879144_item	2234464	et	4	main
olen	doc_120968879144_item	2234467	et	3	main
käinud	doc_120968879144_item	2234474	et	4	main
olen	doc_120968879144_item	2234479	et	3	main
selleks	doc_120968879144_item	2234481	et	4	main
võistluses	doc_120968879144_item	2234483	et	3	main
olen	doc_120968879144_item	2234490	et	3	main
oli	doc_120968879144_item	2234494	et	3	main
lennujaam	doc_120968879144_item	2234496	et	3	main
ta	doc_120968879144_item	2234497	et	4	main
on	doc_120968879144_item	2234498	et	4	main
suur	doc_120968879144_item	2234500	et	3	main
tallinnas	doc_120968879144_item	2234508	et	4	main
olen	doc_120968879144_item	2234510	et	3	main
väga	doc_120968879144_item	2234512	et	3	main
inimesi	doc_120968879144_item	2234514	et	4	main
olen	doc_120968879144_item	2234524	et	3	main
pealinn	doc_120968879144_item	2234531	et	3	main
kõik	doc_120968879144_item	2234534	et	4	main
ilus	doc_120968879144_item	2234537	et	4	main
renoveritud	doc_120968879144_item	2234541	et	4	main
oleks	doc_120968879144_item	2234549	et	3	main
näinud	doc_120968879144_item	2234554	et	4	main
kauplustes	doc_120968879144_item	2234556	et	4	main
kõik	doc_120968879144_item	2234563	et	4	main
vähem	doc_120968879144_item	2234565	et	4	main
teised	doc_120968879144_item	2234571	et	4	main
eestlastest	doc_120968879144_item	2234580	et	4	main
ja	doc_120968879144_item	2234581	et	3	main
venelastest	doc_120968879144_item	2234582	et	4	main
mitte	doc_120968879144_item	2234583	et	3	main
ainult	doc_120968879144_item	2234584	et	4	main
keelt	doc_120968879144_item	2234585	et	4	main
stokholmis	doc_120968879144_item	2234586	et	4	main
olen	doc_120968879144_item	2234587	et	3	main
näinud	doc_120968879144_item	2234588	et	4	main
väga	doc_120968879144_item	2234589	et	3	main
huvilise	doc_120968879144_item	2234590	et	4	main
asi	doc_120968879144_item	2234591	et	4	main
inimese	doc_120968879144_item	2234592	et	4	main
väga	doc_120968879144_item	2234593	et	3	main
palju	doc_120968879144_item	2234594	et	4	main
sõidavad	doc_120968879144_item	2234595	et	3	main
jalgrattaga	doc_120968879144_item	2234596	et	3	main
ja	doc_120968879144_item	2234597	et	3	main
panevaid	doc_120968879144_item	2234598	et	4	main
neid	doc_120968879144_item	2234599	et	4	main
otse	doc_120968879144_item	2234600	et	4	main
kaupluse	doc_120968879144_item	2234601	et	3	main
või	doc_120968879144_item	2234602	et	4	main
teise	doc_120968879144_item	2234603	et	4	main
ess	doc_120968879144_item	2234605	et	3	main
hoone	doc_120968879144_item	2234604	et	4	main
arvan	doc_120968879144_item	2234606	et	3	main
et	doc_120968879144_item	2234607	et	3	main
eestis	doc_120968879144_item	2234608	et	3	main
jalgrattad	doc_120968879144_item	2234609	et	3	main
väga	doc_120968879144_item	2234560	et	3	main
maksab	doc_120968879144_item	2234564	et	3	main
olen	doc_120968879144_item	2234566	et	3	main
inimesed	doc_120968879144_item	2234569	et	3	main
ei	doc_120968879144_item	2234573	et	4	main
täpselt	doc_120968879144_item	2234575	et	4	main
öelda	doc_120968879144_item	2234576	et	4	main
erinevad	doc_120968879144_item	2234579	et	4	main
varastanud	doc_120968879144_item	2234614	et	4	main
käinud	doc_120968879145_item	2234630	et	4	main
et	doc_120968879145_item	2234639	et	3	main
ei	doc_120968879145_item	2234640	et	4	main
tulin	doc_120968879145_item	2234647	et	3	main
palju	doc_120968879145_item	2234656	et	4	main
kõige	doc_120968879145_item	2234658	et	4	main
kursus	doc_120968879145_item	2234665	et	3	main
hea	doc_120968879145_item	2234671	et	4	main
oli	doc_120968879145_item	2234673	et	3	main
jaos	doc_120968879145_item	2234676	et	4	main
oli	doc_120968879145_item	2234677	et	3	main
iga	doc_120968879145_item	2234680	et	4	main
olema	doc_120968879145_item	2234683	et	4	main
ahivalvur	doc_120968879145_item	2234685	et	3	main
valvama	doc_120968879145_item	2234687	et	3	main
istusin	doc_120968879145_item	2234691	et	3	main
minutit	doc_120968879145_item	2234696	et	3	main
tegelema	doc_120968879145_item	2234699	et	3	main
asjadega	doc_120968879145_item	2234701	et	3	main
pime	doc_120968879145_item	2234703	et	3	main
sõnaga	doc_120968879145_item	2234714	et	3	main
kõik	doc_120968879145_item	2234721	et	4	main
kõik	doc_120968879145_item	2234725	et	4	main
võib	doc_120968879145_item	2234733	et	3	main
mees	doc_120968879145_item	2234741	et	4	main
9	doc_120968879145_item	2234743	et	2	main
jalgpalliga	doc_120968879145_item	2234745	et	3	main
sest	doc_120968879145_item	2234748	et	4	main
osa	doc_120968879145_item	2234750	et	4	main
inglismaale	doc_120968879145_item	2234757	et	4	main
kõik	doc_120968879145_item	2234759	et	4	main
see	doc_120968879145_item	2234769	et	3	main
j	doc_120968879145_item	2234779	et	4	main
dover	doc_120968879145_item	2234785	et	4	main
okeani	doc_120968879145_item	2234787	et	4	main
pärast	doc_120968879144_item	2234613	et	4	main
aga	doc_120968879144_item	2234615	et	3	main
essee	doc_120968879145_item	2234627	et	4	main
olen	doc_120968879145_item	2234629	et	3	main
olin	doc_120968879145_item	2234636	et	3	main
kõik	doc_120968879145_item	2234642	et	4	main
olin	doc_120968879145_item	2234651	et	3	main
ja	doc_120968879145_item	2234655	et	3	main
baas	doc_120968879145_item	2234664	et	3	main
esimene	doc_120968879145_item	2234666	et	3	main
metsas	doc_120968879145_item	2234668	et	3	main
mäletan	doc_120968879145_item	2234669	et	3	main
väga	doc_120968879145_item	2234670	et	3	main
ööbimine	doc_120968879145_item	2234672	et	4	main
8	doc_120968879145_item	2234678	et	2	main
üks	doc_120968879145_item	2234681	et	3	main
ahivalvurina	doc_120968879145_item	2234684	et	3	main
et	doc_120968879145_item	2234688	et	3	main
30	doc_120968879145_item	2234695	et	2	main
läks	doc_120968879145_item	2234698	et	3	main
oma	doc_120968879145_item	2234700	et	4	main
oli	doc_120968879145_item	2234704	et	3	main
näe	doc_120968879145_item	2234708	et	4	main
ei	doc_120968879145_item	2234711	et	4	main
jalutasin	doc_120968879145_item	2234715	et	3	main
kaotasin	doc_120968879145_item	2234722	et	3	main
tee	doc_120968879145_item	2234723	et	4	main
tuli	doc_120968879145_item	2234728	et	4	main
mina	doc_120968879145_item	2234738	et	4	main
olen	doc_120968879145_item	2234739	et	3	main
nägin	doc_120968879145_item	2234747	et	3	main
sõidsime	doc_120968879145_item	2234752	et	4	main
muidugi	doc_120968879145_item	2234758	et	4	main
huvitav	doc_120968879145_item	2234762	et	4	main
3	doc_120968879145_item	2234767	et	2	main
ilus	doc_120968879145_item	2234773	et	4	main
palju	doc_120968879145_item	2234780	et	4	main
see	doc_120968879145_item	2234782	et	3	main
käinud	doc_120968879147_item	2234967	et	4	main
kus	doc_120968879147_item	2234972	et	3	main
ma	doc_120968879147_item	2234973	et	3	main
näinud	doc_120968879147_item	2234979	et	4	main
väga	doc_120968879147_item	2234982	et	3	main
nädal	doc_120968879147_item	2234988	et	3	main
sõbrale	doc_120968879147_item	2234997	et	3	main
et	doc_120968879147_item	2235002	et	3	main
sain	doc_120968879147_item	2235014	et	3	main
täisminevik	doc_120968879147_item	2235016	et	3	main
keeles	doc_120968879147_item	2235025	et	4	main
mõtlete	doc_120968879147_item	2235030	et	3	main
ma	doc_120968879147_item	2235032	et	3	main
ei	doc_120968879147_item	2235039	et	4	main
olin	doc_120968879147_item	2235052	et	3	main
üks	doc_120968879147_item	2235057	et	3	main
koguaeg	doc_120968879147_item	2235059	et	3	main
olin	doc_120968879147_item	2235061	et	3	main
või	doc_120968879147_item	2235065	et	4	main
tund	doc_120968879147_item	2235083	et	3	main
kehalinekasvatus	doc_120968879147_item	2235085	et	4	main
ei	doc_120968879145_item	2234631	et	4	main
selle	doc_120968879145_item	2234637	et	4	main
määleta	doc_120968879145_item	2234641	et	4	main
ma	doc_120968879145_item	2234635	et	3	main
jutustan	doc_120968879145_item	2234643	et	3	main
oli	doc_120968879145_item	2234645	et	3	main
kuud	doc_120968879145_item	2234654	et	4	main
nägin	doc_120968879145_item	2234657	et	3	main
aeg	doc_120968879145_item	2234660	et	3	main
sõduri	doc_120968879145_item	2234663	et	3	main
kord	doc_120968879145_item	2234667	et	4	main
telkis	doc_120968879145_item	2234674	et	3	main
ahi	doc_120968879145_item	2234689	et	4	main
ahi	doc_120968879145_item	2234692	et	4	main
pärast	doc_120968879145_item	2234697	et	4	main
ei	doc_120968879145_item	2234707	et	4	main
tea	doc_120968879145_item	2234712	et	4	main
kuidas	doc_120968879145_item	2234644	et	3	main
sõjaväes	doc_120968879145_item	2234646	et	3	main
sõjaväest	doc_120968879145_item	2234648	et	3	main
alguses	doc_120968879145_item	2234650	et	4	main
11	doc_120968879145_item	2234653	et	2	main
sbk	doc_120968879145_item	2234662	et	4	main
meie	doc_120968879145_item	2234675	et	4	main
peab	doc_120968879145_item	2234682	et	4	main
peab	doc_120968879145_item	2234686	et	4	main
põleb	doc_120968879145_item	2234690	et	3	main
juures	doc_120968879145_item	2234693	et	4	main
aga	doc_120968879145_item	2234702	et	3	main
mitte	doc_120968879145_item	2234705	et	3	main
kuhu	doc_120968879145_item	2234709	et	3	main
minna	doc_120968879145_item	2234710	et	3	main
tund	doc_120968879145_item	2234717	et	3	main
ei	doc_120968879145_item	2234724	et	4	main
oli	doc_120968879145_item	2234726	et	3	main
palju	doc_120968879145_item	2234734	et	4	main
palju	doc_120968879145_item	2234746	et	4	main
võtsin	doc_120968879145_item	2234749	et	3	main
narva	doc_120968879145_item	2234755	et	4	main
uus	doc_120968879145_item	2234760	et	3	main
kurortis	doc_120968879145_item	2234772	et	4	main
ilused	doc_120968879145_item	2234777	et	3	main
vaatamisvärsused	doc_120968879145_item	2234781	et	4	main
atlanteline	doc_120968879145_item	2234786	et	4	main
rannas	doc_120968879145_item	2234788	et	3	main
ja	doc_120968879147_item	2234968	et	3	main
olen	doc_120968879147_item	2234974	et	3	main
on	doc_120968879147_item	2234981	et	4	main
huvitav	doc_120968879147_item	2234983	et	4	main
sellepärast	doc_120968879147_item	2234985	et	3	main
käinud	doc_120968879147_item	2234991	et	4	main
ja	doc_120968879147_item	2234993	et	3	main
igav	doc_120968879147_item	2235005	et	3	main
tean	doc_120968879147_item	2235007	et	3	main
minu	doc_120968879147_item	2235022	et	3	main
eesti	doc_120968879147_item	2235024	et	4	main
nalja	doc_120968879147_item	2235034	et	4	main
ainult	doc_120968879147_item	2235038	et	4	main
ttü-s	doc_120968879147_item	2235054	et	3	main
lektsion	doc_120968879147_item	2235058	et	4	main
maganud	doc_120968879147_item	2235062	et	4	main
kolm	doc_120968879147_item	2235064	et	3	main
kui	doc_120968879147_item	2235089	et	3	main
vähe	doc_120968879147_item	2235093	et	3	main
eelmisel	doc_120968879147_item	2235095	et	3	main
ei	doc_120968879147_item	2235097	et	4	main
mul	doc_120968879147_item	2235105	et	3	main
ei	doc_120968879147_item	2235125	et	4	main
minna	doc_120968879147_item	2235137	et	3	main
viimane	doc_120968879147_item	2235140	et	3	main
päeval	doc_120968879147_item	2235151	et	3	main
kuulama	doc_120968879147_item	2235160	et	3	main
sellest	doc_120968879147_item	2235167	et	4	main
mul	doc_120968879147_item	2235168	et	3	main
oli	doc_120968879147_item	2235169	et	3	main
jutustada	doc_120968879145_item	2234735	et	3	main
veel	doc_120968879145_item	2234737	et	4	main
sportlik	doc_120968879145_item	2234740	et	3	main
tegelesin	doc_120968879145_item	2234742	et	3	main
oma	doc_120968879145_item	2234753	et	4	main
meeskonnaga	doc_120968879145_item	2234754	et	4	main
transiga	doc_120968879145_item	2234756	et	4	main
on	doc_120968879145_item	2234761	et	4	main
olime	doc_120968879145_item	2234764	et	3	main
saime	doc_120968879145_item	2234766	et	3	main
oli	doc_120968879145_item	2234771	et	3	main
ilm	doc_120968879145_item	2234774	et	3	main
ilus	doc_120968879145_item	2234775	et	4	main
linn	doc_120968879145_item	2234783	et	3	main
kui	doc_120968879145_item	2234789	et	3	main
treener	doc_120968879145_item	2234790	et	3	main
ei	doc_120968879145_item	2234791	et	4	main
näinud	doc_120968879145_item	2234792	et	4	main
meil	doc_120968879145_item	2234793	et	4	main
muidugi	doc_120968879145_item	2234794	et	4	main
proovisime	doc_120968879145_item	2234795	et	3	main
nende	doc_120968879145_item	2234796	et	4	main
õlu	doc_120968879145_item	2234797	et	3	main
tegin	doc_120968879145_item	2234798	et	3	main
seal	doc_120968879145_item	2234799	et	4	main
pilti	doc_120968879145_item	2234801	et	4	main
aga	doc_120968879145_item	2234802	et	3	main
palju	doc_120968879145_item	2234800	et	4	main
arvan	doc_120968879145_item	2234804	et	3	main
ma	doc_120968879145_item	2234803	et	3	main
küll	doc_120968879145_item	2234805	et	4	main
kõige	doc_120968879145_item	2234806	et	4	main
parem	doc_120968879145_item	2234807	et	4	main
ja	doc_120968879145_item	2234808	et	3	main
armas	doc_120968879145_item	2234809	et	3	main
koht	doc_120968879145_item	2234810	et	3	main
on	doc_120968879145_item	2234811	et	4	main
siin	doc_120968879145_item	2234812	et	4	main
eestis	doc_120968879145_item	2234813	et	3	main
ja	doc_120968879145_item	2234814	et	3	main
minu	doc_120968879145_item	2234815	et	3	main
jaoks	doc_120968879145_item	2234816	et	4	main
narvas	doc_120968879145_item	2234817	et	4	main
olin	doc_120968879145_item	2234818	et	3	main
sündinud	doc_120968879145_item	2234819	et	4	main
seal	doc_120968879145_item	2234820	et	4	main
tasemel	doc_120968879145_item	2234765	et	3	main
koht	doc_120968879145_item	2234768	et	3	main
turnir	doc_120968879145_item	2234770	et	4	main
linn	doc_120968879145_item	2234776	et	3	main
naised	doc_120968879145_item	2234778	et	3	main
oli	doc_120968879145_item	2234784	et	3	main
kus	doc_120968879147_item	2234965	et	3	main
ja	doc_120968879147_item	2234976	et	3	main
olen	doc_120968879147_item	2234978	et	3	main
see	doc_120968879147_item	2234980	et	3	main
kogu	doc_120968879147_item	2234987	et	4	main
ttü-s	doc_120968879147_item	2234992	et	3	main
mõtlen	doc_120968879147_item	2235001	et	3	main
te	doc_120968879147_item	2235009	et	4	main
enneminevik	doc_120968879147_item	2235018	et	3	main
kontrollida	doc_120968879147_item	2235021	et	4	main
et	doc_120968879147_item	2235027	et	3	main
ma	doc_120968879147_item	2235037	et	3	main
millest	doc_120968879147_item	2235041	et	3	main
olen	doc_120968879147_item	2234966	et	3	main
mida	doc_120968879147_item	2234969	et	4	main
olen	doc_120968879147_item	2234970	et	3	main
näinud	doc_120968879147_item	2234971	et	4	main
käinud	doc_120968879147_item	2234975	et	4	main
mida	doc_120968879147_item	2234977	et	4	main
et	doc_120968879147_item	2234986	et	3	main
olin	doc_120968879147_item	2234990	et	3	main
ainult	doc_120968879147_item	2234994	et	4	main
läksin	doc_120968879147_item	2234996	et	3	main
ja	doc_120968879147_item	2234998	et	3	main
see	doc_120968879147_item	2235003	et	3	main
on	doc_120968879147_item	2235004	et	4	main
aga	doc_120968879147_item	2235006	et	3	main
ma	doc_120968879147_item	2235013	et	3	main
lihtminevik	doc_120968879147_item	2235015	et	3	main
ja	doc_120968879147_item	2235017	et	3	main
aru	doc_120968879147_item	2235019	et	4	main
essee	doc_120968879147_item	2234964	et	4	main
küsimus	doc_120968879147_item	2234984	et	4	main
ma	doc_120968879147_item	2234989	et	3	main
laupäeval	doc_120968879147_item	2234995	et	3	main
poodi	doc_120968879147_item	2234999	et	4	main
ma	doc_120968879147_item	2235000	et	3	main
et	doc_120968879147_item	2235008	et	3	main
tahate	doc_120968879147_item	2235010	et	3	main
vaadata	doc_120968879147_item	2235011	et	4	main
kas	doc_120968879147_item	2235012	et	3	main
ja	doc_120968879147_item	2235020	et	3	main
teadmised	doc_120968879147_item	2235023	et	4	main
ei	doc_120968879147_item	2235029	et	4	main
et	doc_120968879147_item	2235031	et	3	main
sellest	doc_120968879147_item	2235035	et	4	main
esse	doc_120968879147_item	2235036	et	3	main
tahan	doc_120968879147_item	2235046	et	3	main
selle	doc_120968879147_item	2235048	et	4	main
kuulsin	doc_120968879147_item	2235056	et	3	main
esimene	doc_120968879147_item	2235082	et	3	main
seale	doc_120968879147_item	2235091	et	3	main
kohta	doc_120968879147_item	2235100	et	4	main
oli	doc_120968879147_item	2235102	et	3	main
valima	doc_120968879147_item	2235108	et	3	main
hea	doc_120968879147_item	2235112	et	4	main
ma	doc_120968879147_item	2235116	et	3	main
ttü-s	doc_120968879147_item	2235119	et	3	main
keele	doc_120968879147_item	2235121	et	4	main
me	doc_120968879147_item	2235128	et	4	main
seda	doc_120968879147_item	2235132	et	3	main
tahaksid	doc_120968879147_item	2235134	et	4	main
see	doc_120968879147_item	2235138	et	3	main
keegi	doc_120968879147_item	2235143	et	4	main
olla	doc_120968879147_item	2235145	et	3	main
vaatama	doc_120968879147_item	2235147	et	3	main
aga	doc_120968879147_item	2235161	et	3	main
lektsionid	doc_120968879147_item	2235163	et	4	main
see	doc_120968879147_item	2235178	et	3	main
ja	doc_120968879147_item	2235181	et	3	main
kuidas	doc_120968879147_item	2235183	et	3	main
loodan	doc_120968879147_item	2235026	et	3	main
te	doc_120968879147_item	2235028	et	4	main
teen	doc_120968879147_item	2235033	et	3	main
tea	doc_120968879147_item	2235040	et	4	main
kirjutama	doc_120968879147_item	2235042	et	3	main
palju	doc_120968879147_item	2235044	et	4	main
töö	doc_120968879147_item	2235049	et	4	main
huvitavam	doc_120968879147_item	2235050	et	4	main
käinud	doc_120968879147_item	2235053	et	4	main
kus	doc_120968879147_item	2235055	et	3	main
ainult	doc_120968879147_item	2235063	et	4	main
neli	doc_120968879147_item	2235066	et	3	main
korda	doc_120968879147_item	2235067	et	4	main
ärkanud	doc_120968879147_item	2235069	et	4	main
olin	doc_120968879147_item	2235068	et	3	main
sellepärast	doc_120968879147_item	2235070	et	3	main
ma	doc_120968879147_item	2235071	et	3	main
ei	doc_120968879147_item	2235072	et	4	main
saa	doc_120968879147_item	2235073	et	4	main
midagi	doc_120968879147_item	2235074	et	4	main
öelda	doc_120968879147_item	2235075	et	4	main
mida	doc_120968879147_item	2235076	et	4	main
olen	doc_120968879147_item	2235078	et	3	main
ma	doc_120968879147_item	2235077	et	3	main
näinud	doc_120968879147_item	2235079	et	4	main
esmaspäeval	doc_120968879147_item	2235080	et	3	main
teisepäeval	doc_120968879147_item	2235081	et	3	main
nii	doc_120968879147_item	2235043	et	3	main
ja	doc_120968879147_item	2235045	et	3	main
teha	doc_120968879147_item	2235047	et	3	main
esmaspäeval	doc_120968879147_item	2235051	et	3	main
ma	doc_120968879147_item	2235060	et	3	main
oli	doc_120968879147_item	2235084	et	3	main
olin	doc_120968879147_item	2235087	et	3	main
inimeste	doc_120968879147_item	2235094	et	3	main
minust	doc_120968879147_item	2235104	et	3	main
ilm	doc_120968879147_item	2235110	et	3	main
samal	doc_120968879147_item	2235114	et	3	main
eesti	doc_120968879147_item	2235120	et	4	main
olnud	doc_120968879147_item	2235126	et	4	main
kui	doc_120968879147_item	2235127	et	3	main
tudengid	doc_120968879147_item	2235129	et	3	main
olid	doc_120968879147_item	2235130	et	4	main
välja	doc_120968879147_item	2235136	et	4	main
oli	doc_120968879147_item	2235139	et	3	main
kodutööga	doc_120968879147_item	2235149	et	3	main
käinud	doc_120968879147_item	2235154	et	4	main
lektsionidele	doc_120968879147_item	2235157	et	4	main
magama	doc_120968879147_item	2235159	et	3	main
algasid	doc_120968879147_item	2235164	et	4	main
kümne	doc_120968879147_item	2235166	et	4	main
ja	doc_120968879147_item	2235173	et	3	main
olnud	doc_120968879147_item	2235175	et	4	main
matanalüs	doc_120968879147_item	2235180	et	4	main
füüsika	doc_120968879147_item	2235182	et	4	main
sa	doc_120968879147_item	2235187	et	3	main
päev	doc_120968879147_item	2235221	et	3	main
ttü-s	doc_120968879147_item	2235227	et	3	main
hommikul	doc_120968879147_item	2235229	et	3	main
ja	doc_120968879147_item	2235233	et	3	main
ttü-s	doc_120968879147_item	2235235	et	3	main
ei	doc_120968879147_item	2235239	et	4	main
midagi	doc_120968879147_item	2235241	et	4	main
töö	doc_120968879147_item	2235247	et	4	main
eksperimendi	doc_120968879147_item	2235255	et	3	main
reedel	doc_120968879147_item	2235267	et	3	main
seda	doc_120968879147_item	2235277	et	3	main
ainult	doc_120968879147_item	2235282	et	4	main
aru	doc_120968879147_item	2235285	et	4	main
ja	doc_120968879147_item	2235287	et	3	main
tegema	doc_120968879147_item	2235293	et	3	main
sõna	doc_120968879147_item	2235297	et	4	main
puhkus	doc_120968879147_item	2235298	et	3	main
puhkama	doc_120968879147_item	2235303	et	3	main
käisin	doc_120968879147_item	2235308	et	3	main
tuleb	doc_120968879147_item	2235316	et	3	main
olla	doc_120968879147_item	2235317	et	3	main
korratusega	doc_120968879147_item	2235318	et	4	main
ma	doc_120968879147_item	2235086	et	3	main
nii	doc_120968879147_item	2235092	et	3	main
nädal	doc_120968879147_item	2235096	et	3	main
vaba	doc_120968879147_item	2235099	et	4	main
hea	doc_120968879147_item	2235103	et	4	main
oli	doc_120968879147_item	2235106	et	3	main
ka	doc_120968879147_item	2235113	et	3	main
päeval	doc_120968879147_item	2235115	et	3	main
käinud	doc_120968879147_item	2235118	et	4	main
imestanud	doc_120968879147_item	2235088	et	4	main
tulin	doc_120968879147_item	2235090	et	3	main
olnud	doc_120968879147_item	2235098	et	4	main
see	doc_120968879147_item	2235101	et	3	main
võimalusi	doc_120968879147_item	2235107	et	3	main
ja	doc_120968879147_item	2235109	et	3	main
oli	doc_120968879147_item	2235111	et	3	main
olen	doc_120968879147_item	2235117	et	3	main
tundi	doc_120968879147_item	2235122	et	4	main
aga	doc_120968879147_item	2235123	et	3	main
teadnud	doc_120968879147_item	2235131	et	4	main
kõik	doc_120968879147_item	2235133	et	4	main
kiiresti	doc_120968879147_item	2235135	et	3	main
tund	doc_120968879147_item	2235141	et	3	main
võib	doc_120968879147_item	2235144	et	3	main
ma	doc_120968879147_item	2235152	et	3	main
ttü-s	doc_120968879147_item	2235155	et	3	main
kell	doc_120968879147_item	2235165	et	3	main
magama	doc_120968879147_item	2235177	et	3	main
magama	doc_120968879147_item	2235185	et	3	main
kui	doc_120968879147_item	2235186	et	3	main
raske	doc_120968879147_item	2235223	et	4	main
ma	doc_120968879147_item	2235224	et	3	main
eksperimendid	doc_120968879147_item	2235231	et	3	main
kuus	doc_120968879147_item	2235237	et	4	main
keegi	doc_120968879147_item	2235249	et	4	main
ei	doc_120968879147_item	2235252	et	4	main
käinud	doc_120968879147_item	2235270	et	4	main
sellest	doc_120968879147_item	2235272	et	4	main
rääkida	doc_120968879147_item	2235276	et	3	main
isegi	doc_120968879147_item	2235280	et	4	main
algasid	doc_120968879147_item	2235288	et	4	main
puhkusel	doc_120968879147_item	2235294	et	4	main
peab	doc_120968879147_item	2235302	et	4	main
ma	doc_120968879147_item	2235305	et	3	main
on	doc_120968879147_item	2235313	et	4	main
ära	doc_120968879147_item	2235325	et	4	main
alati	doc_120968879147_item	2235327	et	4	main
kuhugi	doc_120968879147_item	2235328	et	4	main
ma	doc_120968879147_item	2235331	et	3	main
päev	doc_120968879147_item	2235334	et	3	main
kodu	doc_120968879147_item	2235335	et	4	main
olen	doc_120968879147_item	2235336	et	3	main
lehed	doc_120968879147_item	2235341	et	3	main
olen	doc_120968879147_item	2235343	et	3	main
ma	doc_120968879147_item	2235348	et	3	main
et	doc_120968879147_item	2235350	et	3	main
kui	doc_120968879147_item	2235367	et	3	main
ei	doc_120968879147_item	2235369	et	4	main
palun	doc_120968879147_item	2235374	et	3	main
ütelge	doc_120968879147_item	2235378	et	3	main
ja	doc_120968879147_item	2235380	et	3	main
tegema	doc_120968879147_item	2235385	et	3	main
ja	doc_120968879147_item	2235389	et	3	main
tegema	doc_120968879147_item	2235391	et	3	main
tuleb	doc_120968879147_item	2235401	et	3	main
või	doc_120968879147_item	2235403	et	4	main
käinud	doc_120968879148_item	2235408	et	4	main
mida	doc_120968879148_item	2235410	et	4	main
olen	doc_120968879148_item	2235411	et	3	main
mina	doc_120968879148_item	2235418	et	4	main
ida	doc_120968879148_item	2235420	et	4	main
virumaal	doc_120968879148_item	2235421	et	4	main
linnas	doc_120968879148_item	2235423	et	4	main
näiteks	doc_120968879148_item	2235428	et	4	main
rohkem	doc_120968879148_item	2235437	et	4	main
veedasin	doc_120968879148_item	2235439	et	4	main
veel	doc_120968879148_item	2235443	et	4	main
kord	doc_120968879148_item	2235449	et	4	main
millal	doc_120968879148_item	2235451	et	3	main
ja	doc_120968879148_item	2235457	et	3	main
praegu	doc_120968879148_item	2235465	et	3	main
armastavad	doc_120968879148_item	2235499	et	4	main
aru	doc_120968879148_item	2235509	et	4	main
mina	doc_120968879148_item	2235519	et	4	main
ja	doc_120968879148_item	2235521	et	3	main
meelega	doc_120968879148_item	2235525	et	4	main
ise	doc_120968879148_item	2235527	et	4	main
olen	doc_120968879148_item	2235529	et	3	main
venelane	doc_120968879148_item	2235530	et	3	main
tihti	doc_120968879148_item	2235531	et	3	main
peod	doc_120968879148_item	2235536	et	4	main
ööklubi	doc_120968879148_item	2235543	et	4	main
tema	doc_120968879147_item	2235124	et	4	main
sellest	doc_120968879147_item	2235142	et	4	main
unustasid	doc_120968879147_item	2235146	et	4	main
lehte	doc_120968879147_item	2235148	et	4	main
järgmisel	doc_120968879147_item	2235150	et	3	main
olin	doc_120968879147_item	2235153	et	3	main
kahe	doc_120968879147_item	2235156	et	3	main
mitte	doc_120968879147_item	2235158	et	3	main
need	doc_120968879147_item	2235162	et	3	main
palju	doc_120968879147_item	2235170	et	4	main
oli	doc_120968879147_item	2235179	et	3	main
pead	doc_120968879147_item	2235188	et	4	main
kirjutama	doc_120968879147_item	2235190	et	3	main
ja	doc_120968879147_item	2235191	et	3	main
kuulama	doc_120968879147_item	2235193	et	3	main
see	doc_120968879147_item	2235194	et	3	main
oli	doc_120968879147_item	2235195	et	3	main
päev	doc_120968879147_item	2235197	et	3	main
lühike	doc_120968879147_item	2235196	et	4	main
niimodi	doc_120968879147_item	2235198	et	4	main
mulle	doc_120968879147_item	2235199	et	4	main
näib	doc_120968879147_item	2235200	et	3	main
kui	doc_120968879147_item	2235201	et	3	main
keegi	doc_120968879147_item	2235202	et	4	main
teeb	doc_120968879147_item	2235203	et	3	main
midagi	doc_120968879147_item	2235204	et	4	main
kiiresti	doc_120968879147_item	2235205	et	3	main
ja	doc_120968879147_item	2235206	et	3	main
temal	doc_120968879147_item	2235207	et	3	main
ei	doc_120968879147_item	2235208	et	4	main
ole	doc_120968879147_item	2235209	et	4	main
et	doc_120968879147_item	2235211	et	3	main
aega	doc_120968879147_item	2235210	et	4	main
mõtlema	doc_120968879147_item	2235212	et	3	main
ajast	doc_120968879147_item	2235213	et	4	main
siis	doc_120968879147_item	2235214	et	3	main
mõtled	doc_120968879147_item	2235215	et	3	main
et	doc_120968879147_item	2235216	et	3	main
päev	doc_120968879147_item	2235217	et	3	main
lõpetas	doc_120968879147_item	2235218	et	3	main
kiiresti	doc_120968879147_item	2235219	et	3	main
järgmine	doc_120968879147_item	2235220	et	3	main
olen	doc_120968879147_item	2235225	et	3	main
käinud	doc_120968879147_item	2235226	et	4	main
vara	doc_120968879147_item	2235228	et	4	main
tegin	doc_120968879147_item	2235230	et	3	main
füüsikas	doc_120968879147_item	2235232	et	3	main
huvitav	doc_120968879147_item	2235242	et	4	main
see	doc_120968879147_item	2235243	et	3	main
minu	doc_120968879147_item	2235245	et	3	main
teises	doc_120968879147_item	2235250	et	4	main
ma	doc_120968879147_item	2235268	et	3	main
olen	doc_120968879147_item	2235269	et	3	main
informatikas	doc_120968879147_item	2235271	et	4	main
oska	doc_120968879147_item	2235275	et	4	main
aega	doc_120968879147_item	2235171	et	4	main
ärkama	doc_120968879147_item	2235172	et	3	main
ei	doc_120968879147_item	2235174	et	4	main
võimalusi	doc_120968879147_item	2235176	et	3	main
lektsionil	doc_120968879147_item	2235184	et	4	main
kiiresti	doc_120968879147_item	2235189	et	3	main
natuke	doc_120968879147_item	2235192	et	4	main
kuni	doc_120968879147_item	2235236	et	3	main
füüsikas	doc_120968879147_item	2235238	et	3	main
olnud	doc_120968879147_item	2235240	et	4	main
aga	doc_120968879147_item	2235248	et	3	main
gruppis	doc_120968879147_item	2235251	et	4	main
võib	doc_120968879147_item	2235284	et	3	main
puhkused	doc_120968879147_item	2235289	et	3	main
mida	doc_120968879147_item	2235290	et	4	main
ütleb	doc_120968879147_item	2235299	et	3	main
sõpradele	doc_120968879147_item	2235309	et	3	main
me	doc_120968879147_item	2235319	et	4	main
puhkasin	doc_120968879147_item	2235332	et	3	main
vaatanud	doc_120968879147_item	2235337	et	4	main
olen	doc_120968879147_item	2235339	et	3	main
midagi	doc_120968879147_item	2235346	et	4	main
see	doc_120968879147_item	2235351	et	3	main
olin	doc_120968879147_item	2235360	et	3	main
meeldi	doc_120968879147_item	2235370	et	4	main
siis	doc_120968879147_item	2235373	et	3	main
vihastuge	doc_120968879147_item	2235376	et	3	main
ma	doc_120968879147_item	2235383	et	3	main
proovin	doc_120968879147_item	2235384	et	3	main
ei	doc_120968879147_item	2235397	et	4	main
nimi	doc_120968879148_item	2235414	et	3	main
oli	doc_120968879147_item	2235222	et	3	main
jäin	doc_120968879147_item	2235234	et	3	main
oli	doc_120968879147_item	2235244	et	3	main
esimene	doc_120968879147_item	2235246	et	3	main
olnud	doc_120968879147_item	2235253	et	4	main
valmis	doc_120968879147_item	2235254	et	4	main
tegema	doc_120968879147_item	2235256	et	3	main
sellest	doc_120968879147_item	2235257	et	4	main
õppejõud	doc_120968879147_item	2235258	et	4	main
ei	doc_120968879147_item	2235259	et	4	main
lubanud	doc_120968879147_item	2235260	et	4	main
tema	doc_120968879147_item	2235261	et	4	main
praegu	doc_120968879147_item	2235262	et	3	main
temal	doc_120968879147_item	2235263	et	3	main
juba	doc_120968879147_item	2235264	et	3	main
üks	doc_120968879147_item	2235265	et	3	main
võlg	doc_120968879147_item	2235266	et	3	main
tundi	doc_120968879147_item	2235273	et	4	main
ei	doc_120968879147_item	2235274	et	4	main
vaja	doc_120968879147_item	2235279	et	4	main
saada	doc_120968879147_item	2235286	et	4	main
peab	doc_120968879147_item	2235292	et	4	main
isegi	doc_120968879147_item	2235296	et	4	main
inimene	doc_120968879147_item	2235301	et	3	main
teinud	doc_120968879147_item	2235307	et	4	main
alati	doc_120968879147_item	2235315	et	4	main
olime	doc_120968879147_item	2235320	et	3	main
telerit	doc_120968879147_item	2235338	et	3	main
õlu	doc_120968879147_item	2235364	et	3	main
esse	doc_120968879147_item	2235372	et	3	main
ärge	doc_120968879147_item	2235375	et	3	main
minule	doc_120968879147_item	2235377	et	3	main
nagu	doc_120968879147_item	2235386	et	3	main
vaja	doc_120968879147_item	2235388	et	4	main
aga	doc_120968879147_item	2235395	et	3	main
ta	doc_120968879147_item	2235400	et	4	main
huvitavam	doc_120968879147_item	2235404	et	4	main
kus	doc_120968879148_item	2235406	et	3	main
olen	doc_120968879148_item	2235407	et	3	main
armastan	doc_120968879148_item	2235426	et	3	main
olin	doc_120968879148_item	2235433	et	3	main
venemal	doc_120968879148_item	2235434	et	4	main
eestis	doc_120968879148_item	2235436	et	3	main
aega	doc_120968879148_item	2235438	et	4	main
paides	doc_120968879148_item	2235444	et	4	main
pärnus	doc_120968879148_item	2235445	et	3	main
ja	doc_120968879148_item	2235447	et	3	main
mina	doc_120968879148_item	2235452	et	4	main
mina	doc_120968879148_item	2235458	et	4	main
mäleta	doc_120968879148_item	2235460	et	4	main
mitte	doc_120968879148_item	2235461	et	3	main
tallinnast	doc_120968879148_item	2235463	et	3	main
siin	doc_120968879148_item	2235467	et	4	main
minu	doc_120968879148_item	2235471	et	3	main
inimesi	doc_120968879148_item	2235501	et	4	main
see	doc_120968879148_item	2235503	et	3	main
praegu	doc_120968879148_item	2235507	et	3	main
see	doc_120968879148_item	2235511	et	3	main
viga	doc_120968879148_item	2235514	et	4	main
inimesed	doc_120968879148_item	2235518	et	3	main
on	doc_120968879147_item	2235278	et	4	main
näha	doc_120968879147_item	2235281	et	3	main
siis	doc_120968879147_item	2235283	et	3	main
inimene	doc_120968879147_item	2235291	et	3	main
puhkama	doc_120968879147_item	2235295	et	3	main
et	doc_120968879147_item	2235300	et	3	main
seda	doc_120968879147_item	2235304	et	3	main
olen	doc_120968879147_item	2235306	et	3	main
tema	doc_120968879147_item	2235310	et	4	main
korter	doc_120968879147_item	2235311	et	3	main
oli	doc_120968879147_item	2235312	et	3	main
ja	doc_120968879147_item	2235314	et	3	main
rääkinud	doc_120968879147_item	2235321	et	4	main
ta	doc_120968879147_item	2235323	et	4	main
läks	doc_120968879147_item	2235324	et	3	main
hilineb	doc_120968879147_item	2235329	et	3	main
natuke	doc_120968879147_item	2235345	et	4	main
huvitav	doc_120968879147_item	2235347	et	4	main
leiutada	doc_120968879147_item	2235357	et	3	main
läinud	doc_120968879147_item	2235361	et	4	main
jõin	doc_120968879147_item	2235363	et	3	main
ja	doc_120968879147_item	2235365	et	3	main
mulle	doc_120968879147_item	2235379	et	4	main
jargmisel	doc_120968879147_item	2235381	et	4	main
selle	doc_120968879147_item	2235393	et	4	main
et	doc_120968879147_item	2235399	et	3	main
paremini	doc_120968879147_item	2235402	et	4	main
essee	doc_120968879148_item	2235405	et	4	main
näinud	doc_120968879148_item	2235412	et	4	main
eesnimi	doc_120968879148_item	2235415	et	3	main
üldse	doc_120968879148_item	2235417	et	3	main
elan	doc_120968879148_item	2235419	et	3	main
väga	doc_120968879148_item	2235425	et	3	main
reisida	doc_120968879148_item	2235427	et	3	main
mina	doc_120968879148_item	2235429	et	4	main
väga	doc_120968879148_item	2235430	et	3	main
palju	doc_120968879148_item	2235431	et	4	main
virumaal	doc_120968879148_item	2235441	et	4	main
olin	doc_120968879148_item	2235442	et	3	main
väga	doc_120968879148_item	2235453	et	3	main
midagi	doc_120968879148_item	2235462	et	4	main
aga	doc_120968879148_item	2235464	et	3	main
ttüs	doc_120968879148_item	2235469	et	4	main
vene	doc_120968879148_item	2235500	et	4	main
poole	doc_120968879148_item	2235505	et	4	main
sain	doc_120968879148_item	2235508	et	3	main
on	doc_120968879148_item	2235512	et	4	main
toredad	doc_120968879148_item	2235517	et	3	main
suhtlen	doc_120968879148_item	2235522	et	3	main
toimuvad	doc_120968879148_item	2235533	et	4	main
erinevad	doc_120968879148_item	2235534	et	4	main
väga	doc_120968879148_item	2235539	et	3	main
lõpetuteks	doc_120968879148_item	2235547	et	4	main
väga	doc_120968879148_item	2235552	et	3	main
käinud	doc_120968879148_item	2235557	et	4	main
ma	doc_120968879149_item	2235577	et	3	main
ja	doc_120968879149_item	2235587	et	3	main
et	doc_120968879149_item	2235591	et	3	main
ei	doc_120968879149_item	2235596	et	4	main
nägi	doc_120968879149_item	2235597	et	3	main
õpin	doc_120968879149_item	2235603	et	3	main
on	doc_120968879149_item	2235608	et	4	main
kus	doc_120968879149_item	2235614	et	3	main
tihti	doc_120968879149_item	2235617	et	3	main
ma	doc_120968879149_item	2235622	et	3	main
oma	doc_120968879149_item	2235624	et	4	main
väga	doc_120968879149_item	2235628	et	3	main
keele	doc_120968879149_item	2235639	et	4	main
õpetaja	doc_120968879149_item	2235645	et	4	main
keelega	doc_120968879149_item	2235651	et	3	main
see	doc_120968879149_item	2235653	et	3	main
ja	doc_120968879149_item	2235667	et	3	main
elu	doc_120968879149_item	2235679	et	4	main
on	doc_120968879149_item	2235681	et	4	main
jutustasin	doc_120968879149_item	2235685	et	3	main
ttü-st	doc_120968879149_item	2235686	et	3	main
ma	doc_120968879149_item	2235724	et	3	main
olin	doc_120968879149_item	2235731	et	3	main
et	doc_120968879149_item	2235738	et	3	main
huvitav	doc_120968879149_item	2235741	et	4	main
et	doc_120968879149_item	2235743	et	3	main
kahjuks	doc_120968879149_item	2235750	et	4	main
ja	doc_120968879147_item	2235322	et	3	main
ta	doc_120968879147_item	2235326	et	4	main
pühapäeval	doc_120968879147_item	2235330	et	3	main
terve	doc_120968879147_item	2235333	et	4	main
lugenud	doc_120968879147_item	2235340	et	4	main
internetis	doc_120968879147_item	2235342	et	4	main
harjutanud	doc_120968879147_item	2235344	et	4	main
mõtlen	doc_120968879147_item	2235349	et	3	main
on	doc_120968879147_item	2235352	et	4	main
huvitavam	doc_120968879147_item	2235353	et	4	main
kui	doc_120968879147_item	2235354	et	3	main
ma	doc_120968879147_item	2235355	et	3	main
hakkasin	doc_120968879147_item	2235356	et	3	main
et	doc_120968879147_item	2235358	et	3	main
ma	doc_120968879147_item	2235359	et	3	main
diskole	doc_120968879147_item	2235362	et	4	main
tantsisin	doc_120968879147_item	2235366	et	3	main
teiele	doc_120968879147_item	2235368	et	4	main
minu	doc_120968879147_item	2235371	et	3	main
kord	doc_120968879147_item	2235382	et	4	main
on	doc_120968879147_item	2235387	et	4	main
võib	doc_120968879147_item	2235390	et	3	main
uuesti	doc_120968879147_item	2235392	et	3	main
esse	doc_120968879147_item	2235394	et	3	main
ma	doc_120968879147_item	2235396	et	3	main
mätle	doc_120968879147_item	2235398	et	4	main
ja	doc_120968879148_item	2235409	et	3	main
minu	doc_120968879148_item	2235413	et	3	main
perekonnanimi	doc_120968879148_item	2235416	et	3	main
sillamäe	doc_120968879148_item	2235422	et	3	main
korda	doc_120968879148_item	2235432	et	4	main
aga	doc_120968879148_item	2235435	et	3	main
ida	doc_120968879148_item	2235440	et	4	main
üks	doc_120968879148_item	2235448	et	3	main
väike	doc_120968879148_item	2235454	et	4	main
ja	doc_120968879148_item	2235470	et	3	main
ei	doc_120968879148_item	2235498	et	4	main
muidugi	doc_120968879148_item	2235502	et	4	main
on	doc_120968879148_item	2235504	et	4	main
õige	doc_120968879148_item	2235506	et	4	main
minu	doc_120968879148_item	2235513	et	3	main
estlased	doc_120968879148_item	2235515	et	4	main
aga	doc_120968879148_item	2235526	et	3	main
tallinnas	doc_120968879148_item	2235532	et	4	main
on	doc_120968879148_item	2235538	et	4	main
palju	doc_120968879148_item	2235540	et	4	main
inimesi	doc_120968879148_item	2235542	et	4	main
edasi	doc_120968879148_item	2235546	et	3	main
et	doc_120968879148_item	2235550	et	3	main
meeldib	doc_120968879148_item	2235553	et	3	main
käinud	doc_120968879149_item	2235579	et	4	main
kooli	doc_120968879149_item	2235581	et	4	main
varem	doc_120968879149_item	2235588	et	4	main
mõtlesin	doc_120968879149_item	2235590	et	3	main
mul	doc_120968879149_item	2235606	et	3	main
näha	doc_120968879149_item	2235610	et	3	main
õpetajaid	doc_120968879149_item	2235612	et	4	main
ruumeid	doc_120968879149_item	2235613	et	4	main
ma	doc_120968879149_item	2235615	et	3	main
see	doc_120968879149_item	2235619	et	3	main
kooli	doc_120968879149_item	2235625	et	4	main
ma	doc_120968879149_item	2235633	et	3	main
eesti	doc_120968879149_item	2235638	et	4	main
tund	doc_120968879149_item	2235640	et	3	main
näinud	doc_120968879149_item	2235643	et	4	main
45	doc_120968879149_item	2235648	et	2	main
minutit	doc_120968879149_item	2235649	et	3	main
varem	doc_120968879149_item	2235655	et	4	main
suhtlesin	doc_120968879149_item	2235657	et	3	main
õpetajaga	doc_120968879149_item	2235661	et	4	main
mulle	doc_120968879149_item	2235664	et	4	main
koolis	doc_120968879149_item	2235670	et	4	main
huvitav	doc_120968879149_item	2235678	et	4	main
veel	doc_120968879149_item	2235683	et	4	main
meelde	doc_120968879149_item	2235722	et	3	main
olin	doc_120968879149_item	2235725	et	3	main
tagasi	doc_120968879149_item	2235729	et	3	main
esindus	doc_120968879149_item	2235734	et	4	main
see	doc_120968879149_item	2235739	et	3	main
sest	doc_120968879149_item	2235742	et	4	main
ja	doc_120968879149_item	2235755	et	3	main
kasvatuse	doc_120968879149_item	2235759	et	4	main
oli	doc_120968879149_item	2235763	et	3	main
soov	doc_120968879149_item	2235786	et	3	main
töö	doc_120968879149_item	2235787	et	4	main
kirg	doc_120968879149_item	2235789	et	3	main
ma	doc_120968879148_item	2235424	et	3	main
tartus	doc_120968879148_item	2235446	et	3	main
tallinnas	doc_120968879148_item	2235450	et	4	main
poiss	doc_120968879148_item	2235455	et	3	main
oli	doc_120968879148_item	2235456	et	3	main
ei	doc_120968879148_item	2235459	et	4	main
hakkan	doc_120968879148_item	2235466	et	3	main
õpima	doc_120968879148_item	2235468	et	4	main
silmaring	doc_120968879148_item	2235472	et	3	main
avanes	doc_120968879148_item	2235473	et	3	main
parem	doc_120968879148_item	2235474	et	4	main
see	doc_120968879148_item	2235476	et	3	main
tallinn	doc_120968879148_item	2235475	et	4	main
on	doc_120968879148_item	2235477	et	4	main
väga	doc_120968879148_item	2235478	et	3	main
ilus	doc_120968879148_item	2235479	et	4	main
linn	doc_120968879148_item	2235480	et	3	main
siin	doc_120968879148_item	2235481	et	4	main
on	doc_120968879148_item	2235482	et	4	main
väga	doc_120968879148_item	2235483	et	3	main
tore	doc_120968879148_item	2235484	et	3	main
väga	doc_120968879148_item	2235485	et	3	main
ilusad	doc_120968879148_item	2235486	et	3	main
hooned	doc_120968879148_item	2235487	et	4	main
vanas	doc_120968879148_item	2235488	et	3	main
linnas	doc_120968879148_item	2235489	et	4	main
huvitav	doc_120968879148_item	2235490	et	4	main
kultur	doc_120968879148_item	2235491	et	4	main
ja	doc_120968879148_item	2235492	et	3	main
enne	doc_120968879148_item	2235493	et	4	main
arvasin	doc_120968879148_item	2235495	et	3	main
et	doc_120968879148_item	2235496	et	3	main
mina	doc_120968879148_item	2235494	et	4	main
estlased	doc_120968879148_item	2235497	et	4	main
et	doc_120968879148_item	2235510	et	3	main
väga	doc_120968879148_item	2235516	et	3	main
tutvustan	doc_120968879148_item	2235520	et	3	main
nendega	doc_120968879148_item	2235523	et	4	main
hea	doc_120968879148_item	2235524	et	4	main
kontserdid	doc_120968879148_item	2235535	et	3	main
siin	doc_120968879148_item	2235537	et	4	main
ja	doc_120968879148_item	2235544	et	3	main
tahan	doc_120968879148_item	2235548	et	3	main
siin	doc_120968879148_item	2235554	et	4	main
seal	doc_120968879149_item	2235582	et	4	main
ma	doc_120968879149_item	2235583	et	3	main
12	doc_120968879149_item	2235585	et	2	main
alati	doc_120968879149_item	2235589	et	4	main
kool	doc_120968879149_item	2235594	et	4	main
teda	doc_120968879149_item	2235598	et	4	main
üldse	doc_120968879149_item	2235599	et	3	main
praegu	doc_120968879149_item	2235601	et	3	main
soov	doc_120968879149_item	2235609	et	3	main
oma	doc_120968879149_item	2235611	et	4	main
esmaspäev	doc_120968879149_item	2235621	et	3	main
oli	doc_120968879149_item	2235627	et	3	main
kus	doc_120968879149_item	2235632	et	3	main
koolis	doc_120968879149_item	2235635	et	4	main
ole	doc_120968879149_item	2235637	et	4	main
ma	doc_120968879149_item	2235641	et	3	main
ma	doc_120968879149_item	2235646	et	3	main
oli	doc_120968879149_item	2235654	et	3	main
ma	doc_120968879149_item	2235656	et	3	main
koos	doc_120968879149_item	2235658	et	4	main
ja	doc_120968879149_item	2235660	et	3	main
nad	doc_120968879149_item	2235662	et	3	main
ma	doc_120968879149_item	2235673	et	3	main
kui	doc_120968879149_item	2235675	et	3	main
ja	doc_120968879149_item	2235677	et	3	main
ma	doc_120968879149_item	2235684	et	3	main
siin	doc_120968879149_item	2235688	et	4	main
seadusest	doc_120968879149_item	2235689	et	4	main
mina	doc_120968879148_item	2235528	et	4	main
huvitavad	doc_120968879148_item	2235541	et	4	main
mulle	doc_120968879148_item	2235551	et	4	main
olen	doc_120968879148_item	2235556	et	3	main
tallinnas	doc_120968879148_item	2235558	et	4	main
ja	doc_120968879148_item	2235559	et	3	main
väga	doc_120968879148_item	2235560	et	3	main
palju	doc_120968879148_item	2235561	et	4	main
huvitavat	doc_120968879148_item	2235562	et	4	main
olen	doc_120968879148_item	2235563	et	3	main
näinud	doc_120968879148_item	2235564	et	4	main
essee	doc_120968879149_item	2235565	et	4	main
kus	doc_120968879149_item	2235566	et	3	main
olen	doc_120968879149_item	2235567	et	3	main
käinud	doc_120968879149_item	2235568	et	4	main
mida	doc_120968879149_item	2235569	et	4	main
olen	doc_120968879149_item	2235570	et	3	main
näinud	doc_120968879149_item	2235571	et	4	main
varsti	doc_120968879149_item	2235572	et	3	main
umbes	doc_120968879149_item	2235573	et	4	main
üks	doc_120968879149_item	2235574	et	3	main
nädal	doc_120968879149_item	2235575	et	3	main
nii	doc_120968879148_item	2235545	et	3	main
öelda	doc_120968879148_item	2235549	et	4	main
mina	doc_120968879148_item	2235555	et	4	main
tagasi	doc_120968879149_item	2235576	et	3	main
õppisin	doc_120968879149_item	2235584	et	3	main
aastat	doc_120968879149_item	2235586	et	3	main
kui	doc_120968879149_item	2235592	et	3	main
siis	doc_120968879149_item	2235595	et	3	main
paraku	doc_120968879149_item	2235600	et	3	main
ma	doc_120968879149_item	2235602	et	3	main
ja	doc_120968879149_item	2235605	et	3	main
juba	doc_120968879149_item	2235607	et	3	main
olin	doc_120968879149_item	2235618	et	3	main
olen	doc_120968879149_item	2235578	et	3	main
oma	doc_120968879149_item	2235580	et	4	main
lõpetan	doc_120968879149_item	2235593	et	3	main
ülikoolis	doc_120968879149_item	2235604	et	4	main
nii	doc_120968879149_item	2235616	et	3	main
oli	doc_120968879149_item	2235620	et	3	main
meeleolu	doc_120968879149_item	2235630	et	4	main
see	doc_120968879149_item	2235636	et	3	main
olen	doc_120968879149_item	2235642	et	3	main
oma	doc_120968879149_item	2235644	et	4	main
jutustasid	doc_120968879149_item	2235663	et	4	main
kui	doc_120968879149_item	2235665	et	3	main
igav	doc_120968879149_item	2235668	et	3	main
aga	doc_120968879149_item	2235672	et	3	main
mul	doc_120968879149_item	2235680	et	3	main
õppekavast	doc_120968879149_item	2235687	et	4	main
ja	doc_120968879149_item	2235690	et	3	main
tulin	doc_120968879149_item	2235721	et	3	main
missugu	doc_120968879149_item	2235723	et	4	main
varem	doc_120968879149_item	2235726	et	4	main
kuud	doc_120968879149_item	2235728	et	4	main
pärast	doc_120968879149_item	2235730	et	4	main
näinud	doc_120968879149_item	2235732	et	4	main
kahtlen	doc_120968879149_item	2235737	et	3	main
ma	doc_120968879149_item	2235744	et	3	main
30	doc_120968879149_item	2235747	et	2	main
mäleta	doc_120968879149_item	2235752	et	4	main
mitte	doc_120968879149_item	2235753	et	3	main
ühindasin	doc_120968879149_item	2235785	et	4	main
läksin	doc_120968879149_item	2235623	et	3	main
mul	doc_120968879149_item	2235626	et	3	main
hea	doc_120968879149_item	2235629	et	4	main
esimene	doc_120968879149_item	2235631	et	3	main
olin	doc_120968879149_item	2235634	et	3	main
tegelisin	doc_120968879149_item	2235647	et	4	main
eesti	doc_120968879149_item	2235650	et	4	main
kui	doc_120968879149_item	2235652	et	3	main
õpilastega	doc_120968879149_item	2235659	et	4	main
raske	doc_120968879149_item	2235666	et	4	main
on	doc_120968879149_item	2235669	et	4	main
praegu	doc_120968879149_item	2235671	et	3	main
jutustasin	doc_120968879149_item	2235674	et	3	main
rõõmus	doc_120968879149_item	2235676	et	4	main
tallinnas	doc_120968879149_item	2235682	et	4	main
reeglidest	doc_120968879149_item	2235691	et	4	main
siin	doc_120968879149_item	2235692	et	4	main
olen	doc_120968879149_item	2235693	et	3	main
kindel	doc_120968879149_item	2235694	et	3	main
et	doc_120968879149_item	2235695	et	3	main
nendele	doc_120968879149_item	2235696	et	4	main
meeldis	doc_120968879149_item	2235697	et	3	main
minu	doc_120968879149_item	2235698	et	3	main
jutustus	doc_120968879149_item	2235699	et	4	main
aga	doc_120968879149_item	2235700	et	3	main
mulle	doc_120968879149_item	2235701	et	4	main
meeldis	doc_120968879149_item	2235702	et	3	main
suhtlemine	doc_120968879149_item	2235703	et	4	main
koos	doc_120968879149_item	2235704	et	4	main
pärast	doc_120968879149_item	2235706	et	4	main
nendega	doc_120968879149_item	2235705	et	4	main
olin	doc_120968879149_item	2235707	et	3	main
ka	doc_120968879149_item	2235708	et	3	main
matemaatika	doc_120968879149_item	2235709	et	4	main
tunnile	doc_120968879149_item	2235710	et	3	main
oli	doc_120968879149_item	2235711	et	3	main
ka	doc_120968879149_item	2235712	et	3	main
väga	doc_120968879149_item	2235713	et	3	main
huvitav	doc_120968879149_item	2235714	et	4	main
olen	doc_120968879149_item	2235715	et	3	main
näinud	doc_120968879149_item	2235716	et	4	main
suur	doc_120968879149_item	2235717	et	3	main
õpilastes	doc_120968879149_item	2235719	et	4	main
laisk	doc_120968879149_item	2235718	et	3	main
ja	doc_120968879149_item	2235720	et	3	main
väike	doc_120968879149_item	2235733	et	4	main
aulas	doc_120968879149_item	2235735	et	4	main
magasin	doc_120968879149_item	2235745	et	4	main
ja	doc_120968879149_item	2235749	et	3	main
midagi	doc_120968879149_item	2235754	et	4	main
lõppes	doc_120968879149_item	2235756	et	4	main
ka	doc_120968879149_item	2235762	et	3	main
5	doc_120968879149_item	2235727	et	2	main
seal	doc_120968879149_item	2235736	et	4	main
oli	doc_120968879149_item	2235740	et	3	main
seal	doc_120968879149_item	2235746	et	4	main
minutit	doc_120968879149_item	2235748	et	3	main
ei	doc_120968879149_item	2235751	et	4	main
olin	doc_120968879149_item	2235757	et	3	main
kehaline	doc_120968879149_item	2235758	et	4	main
tunnile	doc_120968879149_item	2235760	et	3	main
huvitav	doc_120968879149_item	2235764	et	4	main
et	doc_120968879149_item	2235766	et	3	main
ma	doc_120968879149_item	2235767	et	3	main
tulin	doc_120968879149_item	2235768	et	3	main
meelde	doc_120968879149_item	2235769	et	3	main
tundi	doc_120968879149_item	2235771	et	4	main
päev	doc_120968879149_item	2235772	et	3	main
sellist	doc_120968879149_item	2235770	et	4	main
lõppes	doc_120968879149_item	2235773	et	4	main
väga	doc_120968879149_item	2235774	et	3	main
kiiresti	doc_120968879149_item	2235775	et	3	main
ja	doc_120968879149_item	2235776	et	3	main
näib	doc_120968879149_item	2235778	et	3	main
et	doc_120968879149_item	2235779	et	3	main
mulle	doc_120968879149_item	2235777	et	4	main
see	doc_120968879149_item	2235780	et	3	main
väga	doc_120968879149_item	2235782	et	3	main
oli	doc_120968879149_item	2235781	et	3	main
põnev	doc_120968879149_item	2235783	et	3	main
see	doc_120968879149_item	2235761	et	3	main
sest	doc_120968879149_item	2235765	et	4	main
teema	doc_120968879151_item	2235927	et	4	main
tahan	doc_120968879151_item	2235929	et	3	main
suvel	doc_120968879151_item	2235933	et	3	main
areneb	doc_120968879151_item	2235940	et	3	main
silmaringi	doc_120968879151_item	2235941	et	4	main
võimalusi	doc_120968879151_item	2235946	et	3	main
ilus	doc_120968879151_item	2235962	et	4	main
sõbrad	doc_120968879151_item	2235971	et	3	main
näinud	doc_120968879151_item	2235977	et	4	main
vanad	doc_120968879151_item	2235985	et	3	main
on	doc_120968879151_item	2235989	et	4	main
lahked	doc_120968879151_item	2235993	et	3	main
kõigepealt	doc_120968879151_item	2235995	et	3	main
mulle	doc_120968879151_item	2236025	et	4	main
näinud	doc_120968879151_item	2236031	et	4	main
esimene	doc_120968879151_item	2236033	et	3	main
kuidas	doc_120968879151_item	2236039	et	3	main
ütlesin	doc_120968879151_item	2236041	et	3	main
seal	doc_120968879151_item	2236043	et	4	main
näiteks	doc_120968879151_item	2236047	et	4	main
pubs	doc_120968879151_item	2236049	et	4	main
noored	doc_120968879151_item	2236052	et	3	main
võivad	doc_120968879151_item	2236057	et	4	main
aega	doc_120968879151_item	2236060	et	4	main
ja	doc_120968879153_item	2236214	et	3	main
ma	doc_120968879149_item	2235784	et	3	main
ja	doc_120968879149_item	2235788	et	3	main
olen	doc_120968879151_item	2235917	et	3	main
väga	doc_120968879151_item	2235925	et	3	main
ma	doc_120968879151_item	2235928	et	3	main
annab	doc_120968879151_item	2235945	et	3	main
ja	doc_120968879151_item	2235949	et	3	main
see	doc_120968879151_item	2235957	et	3	main
country	doc_120968879151_item	2235963	et	4	main
puhkasin	doc_120968879151_item	2235965	et	3	main
seal	doc_120968879151_item	2235968	et	4	main
ja	doc_120968879151_item	2235972	et	3	main
palju	doc_120968879151_item	2235978	et	4	main
ma	doc_120968879151_item	2235980	et	3	main
muuseumis	doc_120968879151_item	2235982	et	3	main
olid	doc_120968879151_item	2235984	et	4	main
väga	doc_120968879151_item	2235990	et	3	main
lõpetades	doc_120968879151_item	2236022	et	3	main
seal	doc_120968879151_item	2236024	et	4	main
ma	doc_120968879151_item	2236029	et	3	main
kord	doc_120968879151_item	2236034	et	4	main
mis	doc_120968879151_item	2236036	et	4	main
puutub	doc_120968879151_item	2236037	et	3	main
puhkusse	doc_120968879151_item	2236038	et	4	main
kohti	doc_120968879151_item	2236046	et	4	main
disco	doc_120968879151_item	2236048	et	4	main
kus	doc_120968879151_item	2236051	et	3	main
neiud	doc_120968879151_item	2236056	et	4	main
näinud	doc_120968879151_item	2235922	et	4	main
et	doc_120968879151_item	2235931	et	3	main
armastan	doc_120968879151_item	2235935	et	3	main
reisimine	doc_120968879151_item	2235944	et	4	main
loodusega	doc_120968879151_item	2235951	et	4	main
suvel	doc_120968879151_item	2235953	et	3	main
ma	doc_120968879151_item	2235954	et	3	main
on	doc_120968879151_item	2235958	et	4	main
sugulased	doc_120968879151_item	2235973	et	3	main
relvad	doc_120968879151_item	2235986	et	3	main
huvitavat	doc_120968879151_item	2235991	et	4	main
mulle	doc_120968879151_item	2235996	et	4	main
meeldis	doc_120968879151_item	2235997	et	3	main
kus	doc_120968879151_item	2235916	et	3	main
käinud	doc_120968879151_item	2235918	et	4	main
mida	doc_120968879151_item	2235920	et	4	main
olen	doc_120968879151_item	2235921	et	3	main
see	doc_120968879151_item	2235923	et	3	main
on	doc_120968879151_item	2235924	et	4	main
huvitav	doc_120968879151_item	2235926	et	4	main
alustada	doc_120968879151_item	2235930	et	3	main
igal	doc_120968879151_item	2235932	et	3	main
ma	doc_120968879151_item	2235934	et	3	main
kuhugi	doc_120968879151_item	2235936	et	4	main
sest	doc_120968879151_item	2235938	et	4	main
reisimine	doc_120968879151_item	2235939	et	4	main
inimestele	doc_120968879151_item	2235947	et	3	main
puhkasin	doc_120968879151_item	2235955	et	3	main
väga	doc_120968879151_item	2235959	et	3	main
ja	doc_120968879151_item	2235961	et	3	main
ma	doc_120968879151_item	2235964	et	3	main
sest	doc_120968879151_item	2235967	et	4	main
elavad	doc_120968879151_item	2235969	et	4	main
minu	doc_120968879151_item	2235970	et	3	main
ma	doc_120968879151_item	2235975	et	3	main
vaatamisväärsusi	doc_120968879151_item	2235979	et	4	main
selles	doc_120968879151_item	2235987	et	4	main
sest	doc_120968879151_item	2236028	et	4	main
nende	doc_120968879151_item	2236032	et	4	main
ma	doc_120968879151_item	2236040	et	3	main
juba	doc_120968879151_item	2236042	et	3	main
mehed	doc_120968879151_item	2236053	et	3	main
vaba	doc_120968879151_item	2236059	et	4	main
nii	doc_120968879151_item	2236061	et	3	main
ma	doc_120968879151_item	2236062	et	3	main
ma	doc_120968879153_item	2236211	et	3	main
näinud	doc_120968879153_item	2236217	et	4	main
ja	doc_120968879153_item	2236223	et	3	main
saa	doc_120968879153_item	2236225	et	4	main
öelda	doc_120968879153_item	2236226	et	4	main
ma	doc_120968879153_item	2236235	et	3	main
mingi	doc_120968879153_item	2236237	et	4	main
kirjutada	doc_120968879153_item	2236243	et	3	main
klassi	doc_120968879153_item	2236247	et	4	main
kaaslastega	doc_120968879153_item	2236248	et	4	main
saaaremaal	doc_120968879153_item	2236250	et	4	main
aga	doc_120968879153_item	2236252	et	3	main
migagi	doc_120968879153_item	2236255	et	3	main
võib	doc_120968879153_item	2236259	et	3	main
liiga	doc_120968879153_item	2236265	et	4	main
tagasi	doc_120968879153_item	2236275	et	3	main
meelde	doc_120968879153_item	2236282	et	3	main
palju	doc_120968879153_item	2236285	et	4	main
erinev	doc_120968879153_item	2236300	et	4	main
lisan	doc_120968879153_item	2236325	et	3	main
ole	doc_120968879153_item	2236336	et	4	main
essee	doc_120968879151_item	2235915	et	4	main
ja	doc_120968879151_item	2235919	et	3	main
reisida	doc_120968879151_item	2235937	et	3	main
aga	doc_120968879151_item	2235942	et	3	main
samuti	doc_120968879151_item	2235943	et	3	main
puhkama	doc_120968879151_item	2235948	et	3	main
nautima	doc_120968879151_item	2235950	et	3	main
sellel	doc_120968879151_item	2235952	et	4	main
saksamaal	doc_120968879151_item	2235956	et	4	main
suur	doc_120968879151_item	2235960	et	3	main
štutgartis	doc_120968879151_item	2235966	et	2	main
štutgartis	doc_120968879151_item	2235974	et	2	main
olen	doc_120968879151_item	2235976	et	3	main
käisin	doc_120968879151_item	2235981	et	3	main
kus	doc_120968879151_item	2235983	et	3	main
linnas	doc_120968879151_item	2235988	et	4	main
ja	doc_120968879151_item	2235992	et	3	main
inimesed	doc_120968879151_item	2235994	et	3	main
selles	doc_120968879151_item	2235998	et	4	main
linnas	doc_120968879151_item	2235999	et	4	main
et	doc_120968879151_item	2236000	et	3	main
selles	doc_120968879151_item	2236001	et	4	main
linnas	doc_120968879151_item	2236002	et	4	main
on	doc_120968879151_item	2236003	et	4	main
vene	doc_120968879151_item	2236004	et	4	main
disco	doc_120968879151_item	2236005	et	4	main
kus	doc_120968879151_item	2236006	et	3	main
puhkavad	doc_120968879151_item	2236007	et	4	main
ainult	doc_120968879151_item	2236008	et	4	main
venelased	doc_120968879151_item	2236009	et	3	main
aga	doc_120968879151_item	2236010	et	3	main
samuti	doc_120968879151_item	2236011	et	3	main
ma	doc_120968879151_item	2236012	et	3	main
olin	doc_120968879151_item	2236013	et	3	main
loomaaias	doc_120968879151_item	2236014	et	4	main
kus	doc_120968879151_item	2236015	et	3	main
olid	doc_120968879151_item	2236016	et	4	main
erinevaid	doc_120968879151_item	2236017	et	4	main
loomi	doc_120968879151_item	2236018	et	4	main
alates	doc_120968879151_item	2236019	et	3	main
ahvi	doc_120968879151_item	2236020	et	4	main
ja	doc_120968879151_item	2236021	et	3	main
lõvi	doc_120968879151_item	2236023	et	4	main
lõvid	doc_120968879151_item	2236027	et	3	main
palju	doc_120968879151_item	2236045	et	4	main
noored	doc_120968879151_item	2236055	et	3	main
puhkasin	doc_120968879151_item	2236063	et	3	main
meeldis	doc_120968879151_item	2236026	et	3	main
olen	doc_120968879151_item	2236030	et	3	main
elus	doc_120968879151_item	2236035	et	4	main
on	doc_120968879151_item	2236044	et	4	main
restoranis	doc_120968879151_item	2236050	et	3	main
ja	doc_120968879151_item	2236054	et	3	main
veetama	doc_120968879151_item	2236058	et	3	main
suvel	doc_120968879151_item	2236064	et	3	main
essee	doc_120968879153_item	2236209	et	4	main
kus	doc_120968879153_item	2236210	et	3	main
olen	doc_120968879153_item	2236216	et	3	main
olen	doc_120968879153_item	2236218	et	3	main
elu	doc_120968879153_item	2236220	et	4	main
tallinnas	doc_120968879153_item	2236221	et	4	main
palju	doc_120968879153_item	2236230	et	4	main
kui	doc_120968879153_item	2236232	et	3	main
sugulaste	doc_120968879153_item	2236238	et	4	main
jurde	doc_120968879153_item	2236239	et	4	main
pole	doc_120968879153_item	2236241	et	3	main
huvitav	doc_120968879153_item	2236242	et	4	main
käinud	doc_120968879153_item	2236249	et	4	main
tartul	doc_120968879153_item	2236251	et	3	main
et	doc_120968879153_item	2236263	et	3	main
ja	doc_120968879153_item	2236267	et	3	main
tahtnud	doc_120968879153_item	2236269	et	4	main
aasta	doc_120968879153_item	2236274	et	4	main
käisime	doc_120968879153_item	2236276	et	3	main
vennaga	doc_120968879153_item	2236278	et	3	main
asjad	doc_120968879153_item	2236286	et	3	main
teist	doc_120968879153_item	2236289	et	4	main
moodi	doc_120968879153_item	2236290	et	4	main
parem	doc_120968879153_item	2236321	et	4	main
eestis	doc_120968879153_item	2236332	et	3	main
niisugust	doc_120968879153_item	2236333	et	3	main
kõige	doc_120968879153_item	2236339	et	4	main
sobivad	doc_120968879153_item	2236342	et	4	main
inimesed	doc_120968879153_item	2236344	et	3	main
ja	doc_120968879153_item	2236360	et	3	main
reisik	doc_120968879153_item	2236363	et	4	main
olulisemad	doc_120968879153_item	2236365	et	4	main
osad	doc_120968879153_item	2236366	et	3	main
praegu	doc_120968879153_item	2236368	et	3	main
ma	doc_120968879153_item	2236369	et	3	main
ma	doc_120968879153_item	2236372	et	3	main
reisimese	doc_120968879153_item	2236376	et	4	main
maksta	doc_120968879153_item	2236378	et	4	main
mul	doc_120968879153_item	2236380	et	3	main
olen	doc_120968879153_item	2236212	et	3	main
elanud	doc_120968879153_item	2236222	et	4	main
et	doc_120968879153_item	2236227	et	3	main
reisisin	doc_120968879153_item	2236228	et	3	main
olen	doc_120968879153_item	2236244	et	3	main
selle	doc_120968879153_item	2236261	et	4	main
ei	doc_120968879153_item	2236268	et	4	main
ümbes	doc_120968879153_item	2236273	et	4	main
jäi	doc_120968879153_item	2236281	et	3	main
välismaal	doc_120968879153_item	2236284	et	4	main
välja	doc_120968879153_item	2236293	et	4	main
linna	doc_120968879153_item	2236297	et	4	main
on	doc_120968879153_item	2236299	et	4	main
ja	doc_120968879153_item	2236301	et	3	main
ainult	doc_120968879153_item	2236326	et	4	main
igav	doc_120968879153_item	2236328	et	3	main
olnud	doc_120968879153_item	2236330	et	4	main
sest	doc_120968879153_item	2236331	et	4	main
on	doc_120968879153_item	2236346	et	4	main
töötada	doc_120968879153_item	2236348	et	3	main
aeg	doc_120968879153_item	2236359	et	3	main
kuhugi	doc_120968879153_item	2236382	et	4	main
ma	doc_120968879155_item	2236540	et	3	main
algusega	doc_120968879155_item	2236549	et	3	main
ei	doc_120968879155_item	2236550	et	4	main
sest	doc_120968879155_item	2236554	et	4	main
esimene	doc_120968879155_item	2236555	et	3	main
sellepärast	doc_120968879155_item	2236561	et	3	main
pean	doc_120968879155_item	2236563	et	4	main
ma	doc_120968879155_item	2236570	et	3	main
hakkan	doc_120968879155_item	2236604	et	3	main
ja	doc_120968879155_item	2236607	et	3	main
buss	doc_120968879155_item	2236611	et	3	main
bussi	doc_120968879155_item	2236616	et	4	main
ma	doc_120968879155_item	2236621	et	3	main
ei	doc_120968879155_item	2236626	et	4	main
oma	doc_120968879155_item	2236628	et	4	main
alati	doc_120968879155_item	2236633	et	4	main
jamind	doc_120968879155_item	2236643	et	4	main
tükkis	doc_120968879155_item	2236644	et	4	main
uni	doc_120968879155_item	2236645	et	3	main
alati	doc_120968879155_item	2236650	et	4	main
loengu	doc_120968879155_item	2236651	et	3	main
ma	doc_120968879155_item	2236656	et	3	main
kojju	doc_120968879155_item	2236658	et	4	main
aga	doc_120968879155_item	2236673	et	3	main
ei	doc_120968879155_item	2236675	et	4	main
naine	doc_120968879155_item	2236681	et	3	main
ütles	doc_120968879155_item	2236686	et	3	main
loengu	doc_120968879155_item	2236689	et	3	main
võttis	doc_120968879155_item	2236693	et	3	main
kell	doc_120968879155_item	2236698	et	3	main
võrdles	doc_120968879155_item	2236700	et	3	main
käinud	doc_120968879153_item	2236213	et	4	main
kogu	doc_120968879153_item	2236219	et	4	main
ei	doc_120968879153_item	2236224	et	4	main
liga	doc_120968879153_item	2236229	et	4	main
tavaliselt	doc_120968879153_item	2236231	et	4	main
ma	doc_120968879153_item	2236233	et	3	main
sõidan	doc_120968879153_item	2236236	et	3	main
oma	doc_120968879153_item	2236246	et	4	main
seal	doc_120968879153_item	2236253	et	4	main
ei	doc_120968879153_item	2236257	et	4	main
leidnud	doc_120968879153_item	2236258	et	4	main
noor	doc_120968879153_item	2236266	et	3	main
juhi	doc_120968879153_item	2236271	et	4	main
koos	doc_120968879153_item	2236277	et	4	main
ekskursioon	doc_120968879153_item	2236280	et	3	main
natuke	doc_120968879153_item	2236288	et	4	main
inimised	doc_120968879153_item	2236292	et	4	main
teistmoodi	doc_120968879153_item	2236296	et	3	main
arhitektuur	doc_120968879153_item	2236298	et	3	main
näha	doc_120968879153_item	2236324	et	3	main
et	doc_120968879153_item	2236327	et	3	main
ei	doc_120968879153_item	2236335	et	4	main
arvates	doc_120968879153_item	2236338	et	4	main
parem	doc_120968879153_item	2236340	et	4	main
kes	doc_120968879153_item	2236345	et	4	main
soov	doc_120968879153_item	2236357	et	3	main
on	doc_120968879153_item	2236362	et	4	main
ei	doc_120968879153_item	2236370	et	4	main
ei	doc_120968879153_item	2236373	et	4	main
eest	doc_120968879153_item	2236377	et	4	main
ei	doc_120968879153_item	2236384	et	4	main
käinud	doc_120968879155_item	2236542	et	4	main
kaheksa	doc_120968879155_item	2236559	et	4	main
ärkama	doc_120968879155_item	2236564	et	3	main
kui	doc_120968879155_item	2236567	et	3	main
et	doc_120968879155_item	2236602	et	3	main
kohale	doc_120968879155_item	2236605	et	4	main
närviline	doc_120968879155_item	2236610	et	4	main
kaks	doc_120968879155_item	2236617	et	3	main
enne	doc_120968879155_item	2236619	et	4	main
mis	doc_120968879153_item	2236215	et	4	main
reisin	doc_120968879153_item	2236234	et	3	main
sellest	doc_120968879153_item	2236240	et	4	main
ka	doc_120968879153_item	2236245	et	3	main
ma	doc_120968879153_item	2236254	et	3	main
vahvat	doc_120968879153_item	2236256	et	3	main
olla	doc_120968879153_item	2236260	et	3	main
pärast	doc_120968879153_item	2236262	et	4	main
olin	doc_120968879153_item	2236264	et	3	main
ekskursiooni	doc_120968879153_item	2236270	et	4	main
kuulata	doc_120968879153_item	2236272	et	4	main
rootsis	doc_120968879153_item	2236279	et	3	main
sest	doc_120968879153_item	2236283	et	4	main
toimuvad	doc_120968879153_item	2236287	et	4	main
näiteks	doc_120968879153_item	2236291	et	4	main
näevad	doc_120968879153_item	2236294	et	3	main
natuke	doc_120968879153_item	2236295	et	4	main
linna	doc_120968879153_item	2236302	et	4	main
keskel	doc_120968879153_item	2236303	et	3	main
oli	doc_120968879153_item	2236304	et	3	main
vähe	doc_120968879153_item	2236305	et	3	main
autod	doc_120968879153_item	2236306	et	3	main
ja	doc_120968879153_item	2236307	et	3	main
palju	doc_120968879153_item	2236308	et	4	main
jalgratad	doc_120968879153_item	2236309	et	4	main
loomulikult	doc_120968879153_item	2236310	et	4	main
käisime	doc_120968879153_item	2236311	et	3	main
muuseumis	doc_120968879153_item	2236312	et	3	main
aga	doc_120968879153_item	2236313	et	3	main
sellest	doc_120968879153_item	2236314	et	4	main
ka	doc_120968879153_item	2236315	et	3	main
kirjuta	doc_120968879153_item	2236317	et	4	main
ei	doc_120968879153_item	2236316	et	4	main
sest	doc_120968879153_item	2236318	et	4	main
seda	doc_120968879153_item	2236319	et	3	main
on	doc_120968879153_item	2236320	et	4	main
oma	doc_120968879153_item	2236322	et	4	main
silmadega	doc_120968879153_item	2236323	et	3	main
ei	doc_120968879153_item	2236329	et	4	main
museumi	doc_120968879153_item	2236334	et	4	main
on	doc_120968879153_item	2236350	et	4	main
palju	doc_120968879153_item	2236351	et	4	main
kellel	doc_120968879153_item	2236349	et	4	main
raha	doc_120968879153_item	2236352	et	4	main
ja	doc_120968879153_item	2236353	et	3	main
kellel	doc_120968879153_item	2236354	et	4	main
on	doc_120968879153_item	2236355	et	4	main
minu	doc_120968879153_item	2236337	et	3	main
reisimiseks	doc_120968879153_item	2236341	et	4	main
vanem	doc_120968879153_item	2236343	et	4	main
väsinud	doc_120968879153_item	2236347	et	4	main
võimalus	doc_120968879153_item	2236361	et	3	main
kõige	doc_120968879153_item	2236364	et	4	main
oma	doc_120968879153_item	2236375	et	4	main
soove	doc_120968879153_item	2236381	et	3	main
sõida	doc_120968879153_item	2236383	et	4	main
igav	doc_120968879153_item	2236356	et	3	main
vaba	doc_120968879153_item	2236358	et	4	main
sest	doc_120968879153_item	2236367	et	4	main
tööta	doc_120968879153_item	2236371	et	4	main
saa	doc_120968879153_item	2236374	et	4	main
seetõttu	doc_120968879153_item	2236379	et	3	main
ole	doc_120968879153_item	2236385	et	4	main
ja	doc_120968879155_item	2236543	et	3	main
oma	doc_120968879155_item	2236548	et	4	main
head	doc_120968879155_item	2236553	et	4	main
kell	doc_120968879155_item	2236558	et	3	main
ja	doc_120968879155_item	2236560	et	3	main
ma	doc_120968879155_item	2236562	et	3	main
ärkas	doc_120968879155_item	2236569	et	3	main
sain	doc_120968879155_item	2236571	et	3	main
olnud	doc_120968879155_item	2236600	et	4	main
kindel	doc_120968879155_item	2236601	et	3	main
sõita	doc_120968879155_item	2236606	et	3	main
sellepärast	doc_120968879155_item	2236608	et	3	main
minutit	doc_120968879155_item	2236618	et	3	main
kaheksa	doc_120968879155_item	2236620	et	4	main
ttüs	doc_120968879155_item	2236624	et	4	main
teen	doc_120968879155_item	2236634	et	3	main
loengus	doc_120968879155_item	2236638	et	3	main
mul	doc_120968879155_item	2236648	et	3	main
puhkama	doc_120968879155_item	2236659	et	3	main
pärast	doc_120968879155_item	2236662	et	4	main
uuesti	doc_120968879155_item	2236665	et	3	main
ttüsse	doc_120968879155_item	2236667	et	4	main
eestikeel	doc_120968879155_item	2236672	et	4	main
õppejõud	doc_120968879155_item	2236674	et	4	main
kõikidele	doc_120968879155_item	2236683	et	4	main
ei	doc_120968879155_item	2236690	et	4	main
harjutusi	doc_120968879155_item	2236694	et	4	main
tulema	doc_120968879155_item	2236709	et	4	main
pärast	doc_120968879155_item	2236712	et	4	main
et	doc_120968879155_item	2236723	et	3	main
on	doc_120968879155_item	2236726	et	4	main
kojju	doc_120968879155_item	2236739	et	4	main
mul	doc_120968879155_item	2236741	et	3	main
teha	doc_120968879155_item	2236746	et	3	main
oli	doc_120968879155_item	2236748	et	3	main
võib	doc_120968879155_item	2236757	et	3	main
olen	doc_120968879155_item	2236541	et	3	main
mida	doc_120968879155_item	2236544	et	4	main
näinud	doc_120968879155_item	2236546	et	4	main
päev	doc_120968879155_item	2236547	et	3	main
soovi	doc_120968879155_item	2236551	et	4	main
loeng	doc_120968879155_item	2236556	et	3	main
kuus	doc_120968879155_item	2236566	et	4	main
et	doc_120968879155_item	2236573	et	3	main
ma	doc_120968879155_item	2236574	et	3	main
tahan	doc_120968879155_item	2236575	et	3	main
magama	doc_120968879155_item	2236576	et	3	main
kell	doc_120968879155_item	2236577	et	3	main
seitse	doc_120968879155_item	2236578	et	3	main
ma	doc_120968879155_item	2236579	et	3	main
oli	doc_120968879155_item	2236580	et	3	main
juba	doc_120968879155_item	2236581	et	3	main
aga	doc_120968879155_item	2236583	et	3	main
bussipeatuses	doc_120968879155_item	2236582	et	4	main
minu	doc_120968879155_item	2236584	et	3	main
buss	doc_120968879155_item	2236585	et	3	main
juba	doc_120968879155_item	2236586	et	3	main
läks	doc_120968879155_item	2236587	et	3	main
ära	doc_120968879155_item	2236588	et	4	main
ma	doc_120968879155_item	2236589	et	3	main
ootasin	doc_120968879155_item	2236590	et	3	main
kakskümmend	doc_120968879155_item	2236591	et	4	main
minutit	doc_120968879155_item	2236592	et	3	main
sest	doc_120968879155_item	2236593	et	4	main
järgmine	doc_120968879155_item	2236594	et	3	main
buss	doc_120968879155_item	2236595	et	3	main
ei	doc_120968879155_item	2236596	et	4	main
tulnud	doc_120968879155_item	2236597	et	4	main
ma	doc_120968879155_item	2236598	et	3	main
essee	doc_120968879155_item	2236538	et	4	main
kus	doc_120968879155_item	2236539	et	3	main
olen	doc_120968879155_item	2236545	et	3	main
midagi	doc_120968879155_item	2236552	et	4	main
algab	doc_120968879155_item	2236557	et	3	main
kell	doc_120968879155_item	2236565	et	3	main
ma	doc_120968879155_item	2236568	et	3	main
aru	doc_120968879155_item	2236572	et	4	main
ma	doc_120968879155_item	2236603	et	3	main
oli	doc_120968879155_item	2236609	et	3	main
tuli	doc_120968879155_item	2236612	et	4	main
ja	doc_120968879155_item	2236613	et	3	main
ma	doc_120968879155_item	2236614	et	3	main
ma	doc_120968879155_item	2236625	et	3	main
pannud	doc_120968879155_item	2236627	et	4	main
jope	doc_120968879155_item	2236629	et	4	main
garderoobisse	doc_120968879155_item	2236630	et	3	main
ma	doc_120968879155_item	2236632	et	3	main
läks	doc_120968879155_item	2236636	et	3	main
midagi	doc_120968879155_item	2236641	et	4	main
peale	doc_120968879155_item	2236646	et	4	main
vaheaeg	doc_120968879155_item	2236654	et	3	main
üks	doc_120968879155_item	2236660	et	3	main
tund	doc_120968879155_item	2236661	et	3	main
puhkemist	doc_120968879155_item	2236663	et	4	main
sõitsin	doc_120968879155_item	2236666	et	3	main
järgmine	doc_120968879155_item	2236669	et	3	main
loeng	doc_120968879155_item	2236670	et	3	main
selle	doc_120968879155_item	2236677	et	4	main
üks	doc_120968879155_item	2236680	et	3	main
andis	doc_120968879155_item	2236682	et	3	main
ja	doc_120968879155_item	2236685	et	3	main
ole	doc_120968879155_item	2236691	et	4	main
ja	doc_120968879155_item	2236695	et	3	main
ei	doc_120968879155_item	2236599	et	4	main
astus	doc_120968879155_item	2236615	et	3	main
juba	doc_120968879155_item	2236623	et	3	main
loengusse	doc_120968879155_item	2236637	et	4	main
ei	doc_120968879155_item	2236639	et	4	main
on	doc_120968879155_item	2236649	et	4	main
poolkaheline	doc_120968879155_item	2236653	et	3	main
sest	doc_120968879155_item	2236668	et	4	main
oli	doc_120968879155_item	2236671	et	3	main
tulnud	doc_120968879155_item	2236676	et	4	main
tuli	doc_120968879155_item	2236679	et	4	main
harjutusi	doc_120968879155_item	2236684	et	4	main
et	doc_120968879155_item	2236687	et	3	main
ma	doc_120968879155_item	2236692	et	3	main
vaatas	doc_120968879155_item	2236696	et	3	main
on	doc_120968879155_item	2236699	et	4	main
aeg	doc_120968879155_item	2236701	et	3	main
ja	doc_120968879155_item	2236703	et	3	main
et	doc_120968879155_item	2236706	et	3	main
peab	doc_120968879155_item	2236708	et	4	main
viimane	doc_120968879155_item	2236724	et	3	main
kuulatlesin	doc_120968879155_item	2236730	et	3	main
akadeemilise	doc_120968879155_item	2236734	et	3	main
ma	doc_120968879155_item	2236751	et	3	main
et	doc_120968879155_item	2236754	et	3	main
ilma	doc_122714475542_item	2236872	et	4	main
saa	doc_122714475542_item	2236875	et	4	main
elada	doc_122714475542_item	2236876	et	3	main
elada	doc_122714475542_item	2236882	et	3	main
ja	doc_122714475542_item	2236884	et	3	main
kasutan	doc_122714475542_item	2236887	et	3	main
asjad	doc_122714475542_item	2236889	et	3	main
päev	doc_122714475542_item	2236891	et	3	main
ei	doc_122714475542_item	2236893	et	4	main
ilma	doc_122714475542_item	2236896	et	4	main
vaja	doc_122714475542_item	2236900	et	4	main
ja	doc_122714475542_item	2236904	et	3	main
muud	doc_122714475542_item	2236905	et	4	main
elekter	doc_122714475542_item	2236917	et	3	main
muud	doc_122714475542_item	2236919	et	4	main
on	doc_122714475542_item	2236931	et	4	main
külm	doc_122714475542_item	2236933	et	3	main
inemene	doc_122714475542_item	2236937	et	4	main
peab	doc_122714475542_item	2236938	et	4	main
teisega	doc_122714475542_item	2236940	et	4	main
pardel	doc_122714475542_item	2236946	et	4	main
seda	doc_122714475542_item	2236948	et	3	main
ma	doc_122714475542_item	2236949	et	3	main
ka	doc_122714475542_item	2236950	et	3	main
ei	doc_122714475542_item	2236956	et	4	main
haige	doc_122714475542_item	2236962	et	4	main
kell	doc_122714475542_item	2236964	et	3	main
tööle	doc_122714475542_item	2236968	et	3	main
milleta	doc_122714475543_item	2236973	et	3	main
elada	doc_122714475543_item	2236977	et	3	main
kõik	doc_122714475543_item	2236985	et	4	main
asjad	doc_122714475543_item	2236992	et	3	main
praegu	doc_122714475543_item	2236996	et	3	main
mul	doc_122714475543_item	2237001	et	3	main
triikisin	doc_122714475543_item	2237008	et	3	main
oli	doc_120968879155_item	2236622	et	3	main
kuidas	doc_120968879155_item	2236631	et	3	main
ja	doc_120968879155_item	2236635	et	3	main
olnud	doc_120968879155_item	2236640	et	4	main
huvitavat	doc_120968879155_item	2236642	et	4	main
teisipäeviti	doc_120968879155_item	2236647	et	4	main
vahel	doc_120968879155_item	2236652	et	4	main
sellepärast	doc_120968879155_item	2236655	et	3	main
sõitsin	doc_120968879155_item	2236657	et	3	main
ma	doc_120968879155_item	2236664	et	3	main
asemel	doc_120968879155_item	2236678	et	4	main
täna	doc_120968879155_item	2236688	et	4	main
mis	doc_120968879155_item	2236697	et	4	main
bussiaedega	doc_120968879155_item	2236702	et	4	main
bussipeatusesse	doc_120968879155_item	2236705	et	4	main
minuti	doc_120968879155_item	2236711	et	3	main
ma	doc_120968879155_item	2236713	et	3	main
jõudnud	doc_120968879155_item	2236715	et	4	main
mitu	doc_120968879155_item	2236716	et	4	main
tunni	doc_120968879155_item	2236717	et	3	main
pärast	doc_120968879155_item	2236718	et	4	main
ma	doc_120968879155_item	2236719	et	3	main
pidin	doc_120968879155_item	2236720	et	3	main
uuesti	doc_120968879155_item	2236721	et	3	main
väga	doc_120968879155_item	2236727	et	3	main
vaevu	doc_120968879155_item	2236729	et	4	main
tunni	doc_120968879155_item	2236735	et	3	main
sõitis	doc_120968879155_item	2236738	et	3	main
kus	doc_120968879155_item	2236740	et	3	main
niisugune	doc_120968879155_item	2236747	et	3	main
teisipäev	doc_120968879155_item	2236750	et	3	main
sain	doc_120968879155_item	2236752	et	3	main
kõik	doc_120968879155_item	2236759	et	4	main
ära	doc_120968879155_item	2236761	et	4	main
asjad	doc_122714475542_item	2236871	et	3	main
ei	doc_122714475542_item	2236880	et	4	main
saaks	doc_122714475542_item	2236881	et	3	main
hambahari	doc_122714475542_item	2236883	et	3	main
hambapasta	doc_122714475542_item	2236885	et	4	main
seeta	doc_122714475542_item	2236897	et	4	main
raha	doc_122714475542_item	2236898	et	4	main
on	doc_122714475542_item	2236899	et	4	main
toit	doc_122714475542_item	2236903	et	3	main
lusikas	doc_122714475542_item	2236908	et	4	main
kahv	doc_122714475542_item	2236910	et	3	main
kõik	doc_122714475542_item	2236918	et	4	main
jooksis	doc_120968879155_item	2236704	et	4	main
buss	doc_120968879155_item	2236707	et	3	main
ühe	doc_120968879155_item	2236710	et	4	main
olen	doc_120968879155_item	2236714	et	3	main
see	doc_120968879155_item	2236732	et	3	main
loeng	doc_120968879155_item	2236736	et	3	main
olnud	doc_120968879155_item	2236743	et	4	main
ei	doc_122714475542_item	2236874	et	4	main
milleta	doc_122714475542_item	2236879	et	3	main
elada	doc_122714475542_item	2236895	et	3	main
asjadbr	doc_122714475542_item	2236906	et	4	main
ja	doc_122714475542_item	2236909	et	3	main
need	doc_122714475542_item	2236911	et	3	main
süüja	doc_122714475542_item	2236916	et	4	main
töötavad	doc_122714475542_item	2236921	et	4	main
iga	doc_122714475542_item	2236927	et	4	main
ilma	doc_122714475542_item	2236934	et	4	main
telefon	doc_122714475542_item	2236936	et	3	main
nii	doc_122714475542_item	2236942	et	3	main
kui	doc_122714475542_item	2236944	et	3	main
saa	doc_122714475542_item	2236952	et	4	main
elada	doc_122714475542_item	2236953	et	3	main
kui	doc_122714475542_item	2236954	et	3	main
kell	doc_122714475542_item	2236963	et	3	main
inimesed	doc_122714475543_item	2236974	et	3	main
saaks	doc_122714475543_item	2236976	et	3	main
elada	doc_122714475543_item	2236988	et	3	main
ilma	doc_122714475543_item	2236993	et	4	main
naiteks	doc_122714475543_item	2237000	et	4	main
eile	doc_122714475543_item	2237002	et	3	main
oli	doc_122714475543_item	2237004	et	3	main
problem	doc_122714475543_item	2237006	et	4	main
katkis	doc_122714475543_item	2237014	et	3	main
välja	doc_122714475543_item	2237021	et	4	main
tööta	doc_122714475543_item	2237030	et	4	main
töötavad	doc_122714475543_item	2237039	et	4	main
tuleb	doc_122714475543_item	2237047	et	3	main
tähendab	doc_122714475543_item	2237051	et	3	main
elada	doc_122714475544_item	2237062	et	3	main
ilma	doc_122714475544_item	2237064	et	4	main
inimesed	doc_122714475544_item	2237066	et	3	main
saaks	doc_122714475544_item	2237073	et	3	main
ilma	doc_122714475544_item	2237075	et	4	main
telerita	doc_122714475544_item	2237079	et	3	main
pesumasinata	doc_122714475544_item	2237081	et	3	main
transportita	doc_122714475544_item	2237086	et	4	main
erinevad	doc_122714475544_item	2237088	et	4	main
päev	doc_122714475544_item	2237099	et	3	main
sõita	doc_120968879155_item	2236722	et	3	main
loeng	doc_120968879155_item	2236725	et	3	main
vajalik	doc_120968879155_item	2236728	et	3	main
lõpuni	doc_120968879155_item	2236731	et	3	main
kahe	doc_120968879155_item	2236733	et	3	main
ja	doc_120968879155_item	2236737	et	3	main
ei	doc_120968879155_item	2236742	et	4	main
jõud	doc_120968879155_item	2236744	et	4	main
midagi	doc_120968879155_item	2236745	et	4	main
minu	doc_120968879155_item	2236749	et	3	main
aru	doc_120968879155_item	2236753	et	4	main
ka	doc_120968879155_item	2236755	et	3	main
tegevusetus	doc_120968879155_item	2236756	et	4	main
võtta	doc_120968879155_item	2236758	et	3	main
jõud	doc_120968879155_item	2236760	et	4	main
asjad	doc_122714475542_item	2236877	et	3	main
et	doc_122714475542_item	2236901	et	3	main
on	doc_122714475542_item	2236913	et	4	main
et	doc_122714475542_item	2236915	et	3	main
asjad	doc_122714475542_item	2236920	et	3	main
elekter	doc_122714475542_item	2236924	et	3	main
riided	doc_122714475542_item	2236929	et	3	main
väga	doc_122714475542_item	2236932	et	3	main
riideta	doc_122714475542_item	2236935	et	3	main
palju	doc_122714475542_item	2236943	et	4	main
pardel	doc_122714475542_item	2236958	et	4	main
ma	doc_122714475542_item	2236960	et	3	main
on	doc_122714475542_item	2236965	et	4	main
et	doc_122714475542_item	2236967	et	3	main
asjad	doc_122714475543_item	2236971	et	3	main
asjad	doc_122714475543_item	2236978	et	3	main
millest	doc_122714475543_item	2236980	et	3	main
inimesed	doc_122714475543_item	2236986	et	3	main
mugavusetega	doc_122714475543_item	2236989	et	3	main
millest	doc_122714475543_item	2236994	et	3	main
ei	doc_122714475543_item	2236997	et	4	main
ma	doc_122714475543_item	2237007	et	3	main
kui	doc_122714475543_item	2237024	et	3	main
elektrivõrk	doc_122714475543_item	2237027	et	3	main
siis	doc_122714475543_item	2237028	et	3	main
raadio	doc_122714475543_item	2237033	et	4	main
pliit	doc_122714475543_item	2237035	et	3	main
sõnaga	doc_122714475543_item	2237037	et	3	main
päeval	doc_122714475543_item	2237045	et	3	main
et	doc_122714475543_item	2237049	et	3	main
palju	doc_122714475543_item	2237055	et	4	main
saaks	doc_122714475544_item	2237061	et	3	main
elada	doc_122714475544_item	2237069	et	3	main
ei	doc_122714475544_item	2237072	et	4	main
elada	doc_122714475544_item	2237074	et	3	main
telefoonita	doc_122714475544_item	2237076	et	4	main
ja	doc_122714475544_item	2237080	et	3	main
külmikuta	doc_122714475544_item	2237083	et	3	main
palju	doc_122714475544_item	2237087	et	4	main
aitavad	doc_122714475544_item	2237090	et	4	main
köögis	doc_122714475544_item	2237092	et	3	main
kasutame	doc_122714475544_item	2237094	et	3	main
iga	doc_122714475544_item	2237098	et	4	main
kinnosse	doc_122714475544_item	2237121	et	4	main
asjad	doc_122714475545_item	2237123	et	3	main
elada	doc_122714475545_item	2237129	et	3	main
ilma	doc_122714475545_item	2237141	et	4	main
inimesed	doc_122714475545_item	2237154	et	3	main
inimesed	doc_122714475545_item	2237159	et	3	main
iga	doc_122714475545_item	2237167	et	4	main
päev	doc_122714475545_item	2237168	et	3	main
väga	doc_122714475546_item	2237177	et	3	main
on	doc_122714475546_item	2237181	et	4	main
see	doc_122714475546_item	2237188	et	3	main
elekter	doc_122714475546_item	2237190	et	3	main
elektri	doc_122714475546_item	2237192	et	3	main
üldse	doc_122714475546_item	2237197	et	3	main
sõitmine	doc_122714475546_item	2237202	et	4	main
on	doc_122714475546_item	2237215	et	4	main
tänu	doc_122714475546_item	2237226	et	4	main
arengus	doc_122714475546_item	2237231	et	3	main
inimesele	doc_122714475546_item	2237233	et	3	main
eesti	doc_124643816973_item	2237241	et	4	main
1	doc_124643816973_item	2237243	et	2	main
mis	doc_124643816973_item	2237244	et	4	main
milleta	doc_122714475542_item	2236873	et	3	main
ilma	doc_122714475542_item	2236878	et	4	main
ma	doc_122714475542_item	2236886	et	3	main
need	doc_122714475542_item	2236888	et	3	main
iga	doc_122714475542_item	2236890	et	4	main
ja	doc_122714475542_item	2236892	et	3	main
saa	doc_122714475542_item	2236894	et	4	main
osta	doc_122714475542_item	2236902	et	4	main
nuga	doc_122714475542_item	2236907	et	4	main
asjad	doc_122714475542_item	2236912	et	3	main
vaja	doc_122714475542_item	2236914	et	4	main
on	doc_122714475542_item	2236925	et	4	main
rääkida	doc_122714475542_item	2236939	et	3	main
inimestega	doc_122714475542_item	2236941	et	3	main
saabbr	doc_122714475542_item	2236945	et	4	main
ilma	doc_122714475542_item	2236947	et	4	main
ei	doc_122714475542_item	2236951	et	4	main
ma	doc_122714475542_item	2236955	et	3	main
vaja	doc_122714475542_item	2236966	et	4	main
p	doc_122714475542_item	2236970	et	4	main
ilma	doc_122714475543_item	2236972	et	4	main
ei	doc_122714475543_item	2236982	et	4	main
elada	doc_122714475543_item	2236984	et	3	main
tahavad	doc_122714475543_item	2236987	et	3	main
aga	doc_122714475543_item	2236990	et	3	main
inimesed	doc_122714475543_item	2236995	et	3	main
elada	doc_122714475543_item	2236999	et	3	main
kodus	doc_122714475543_item	2237003	et	4	main
väike	doc_122714475543_item	2237005	et	4	main
peasu	doc_122714475543_item	2237009	et	4	main
äkki	doc_122714475543_item	2237011	et	3	main
triikraud	doc_122714475543_item	2237013	et	3	main
selle	doc_122714475543_item	2237016	et	4	main
elekter	doc_122714475543_item	2237022	et	3	main
tööta	doc_122714475543_item	2237026	et	4	main
ei	doc_122714475543_item	2237038	et	4	main
milleseid	doc_122714475543_item	2237041	et	4	main
kasutame	doc_122714475543_item	2237043	et	3	main
välja	doc_122714475543_item	2237048	et	4	main
milleta	doc_122714475544_item	2237058	et	3	main
asjad	doc_122714475544_item	2237063	et	3	main
milleta	doc_122714475544_item	2237065	et	3	main
inimesed	doc_122714475544_item	2237071	et	3	main
ilma	doc_122714475544_item	2237078	et	4	main
ilma	doc_122714475544_item	2237085	et	4	main
perenaisele	doc_122714475544_item	2237091	et	3	main
ja	doc_122714475544_item	2237096	et	3	main
informatsiooni	doc_122714475544_item	2237100	et	4	main
saaks	doc_122714475545_item	2237128	et	3	main
milleta	doc_122714475545_item	2237132	et	3	main
ei	doc_122714475545_item	2237134	et	4	main
elada	doc_122714475545_item	2237136	et	3	main
inimesed	doc_122714475545_item	2237143	et	3	main
ka	doc_122714475545_item	2237145	et	3	main
päev	doc_122714475545_item	2237157	et	3	main
saama	doc_122714475545_item	2237161	et	4	main
palk	doc_122714475545_item	2237164	et	3	main
magavad	doc_122714475545_item	2237166	et	4	main
ilma	doc_122714475546_item	2237169	et	4	main
ei	doc_122714475546_item	2237171	et	4	main
on	doc_122714475546_item	2237176	et	4	main
huvitav	doc_122714475546_item	2237178	et	4	main
inimesed	doc_122714475546_item	2237193	et	3	main
saad	doc_122714475546_item	2237195	et	4	main
soe	doc_122714475546_item	2237200	et	4	main
need	doc_122714475546_item	2237204	et	3	main
meile	doc_122714475546_item	2237206	et	4	main
väga	doc_122714475546_item	2237209	et	3	main
raadiot	doc_122714475546_item	2237220	et	3	main
kahte	doc_122714475546_item	2237229	et	4	main
asjad	doc_122714475546_item	2237230	et	3	main
huvitavalt	doc_122714475546_item	2237236	et	4	main
terve	doc_122714475546_item	2237238	et	4	main
nõukogude	doc_124643816973_item	2237246	et	3	main
ja	doc_124643816973_item	2237249	et	3	main
2	doc_124643816973_item	2237252	et	2	main
elu	doc_124643816973_item	2237279	et	4	main
elektriga	doc_122714475542_item	2236922	et	3	main
siis	doc_122714475542_item	2236923	et	3	main
vaja	doc_122714475542_item	2236926	et	4	main
päevbr	doc_122714475542_item	2236928	et	4	main
mul	doc_122714475542_item	2236930	et	3	main
kasuta	doc_122714475542_item	2236957	et	4	main
siis	doc_122714475542_item	2236959	et	3	main
olen	doc_122714475542_item	2236961	et	3	main
minna	doc_122714475542_item	2236969	et	3	main
ei	doc_122714475543_item	2236975	et	4	main
ilma	doc_122714475543_item	2236979	et	4	main
inimesed	doc_122714475543_item	2236981	et	3	main
saaks	doc_122714475543_item	2236983	et	3	main
on	doc_122714475543_item	2236991	et	4	main
saa	doc_122714475543_item	2236998	et	4	main
ära	doc_122714475543_item	2237015	et	4	main
pärast	doc_122714475543_item	2237017	et	4	main
meie	doc_122714475543_item	2237018	et	4	main
korteris	doc_122714475543_item	2237019	et	3	main
lülitakse	doc_122714475543_item	2237020	et	4	main
ei	doc_122714475543_item	2237025	et	4	main
ei	doc_122714475543_item	2237029	et	4	main
me	doc_122714475543_item	2237042	et	4	main
elekter	doc_122714475543_item	2237050	et	3	main
meie	doc_122714475543_item	2237052	et	4	main
ei	doc_122714475544_item	2237060	et	4	main
ei	doc_122714475544_item	2237067	et	4	main
ilma	doc_122714475544_item	2237082	et	4	main
köögimasinad	doc_122714475544_item	2237089	et	3	main
me	doc_122714475544_item	2237093	et	4	main
tööl	doc_122714475544_item	2237095	et	3	main
ilma	doc_122714475545_item	2237124	et	4	main
ei	doc_122714475545_item	2237127	et	4	main
inimesed	doc_122714475545_item	2237133	et	3	main
ei	doc_122714475545_item	2237138	et	4	main
õppima	doc_122714475545_item	2237142	et	3	main
iga	doc_122714475545_item	2237156	et	4	main
iga	doc_122714475545_item	2237162	et	4	main
nad	doc_122714475545_item	2237165	et	3	main
milleta	doc_122714475546_item	2237170	et	3	main
saaks	doc_122714475546_item	2237172	et	3	main
elada	doc_122714475546_item	2237174	et	3	main
võimalik	doc_122714475546_item	2237182	et	3	main
arvan	doc_122714475546_item	2237187	et	3	main
valgus	doc_122714475546_item	2237199	et	4	main
tähtis	doc_122714475546_item	2237210	et	4	main
meie	doc_122714475546_item	2237212	et	4	main
kõik	doc_122714475546_item	2237222	et	4	main
töötavad	doc_122714475546_item	2237225	et	4	main
elektroonikat	doc_122714475546_item	2237227	et	3	main
annab	doc_122714475546_item	2237232	et	3	main
hea	doc_122714475546_item	2237235	et	4	main
ja	doc_122714475546_item	2237237	et	3	main
kontrolltöö	doc_124643816973_item	2237240	et	4	main
peamised	doc_124643816973_item	2237257	et	3	main
3	doc_124643816973_item	2237259	et	2	main
ew	doc_124643816973_item	2237261	et	4	main
teaduselubr	doc_124643816973_item	2237262	et	4	main
br	doc_124643816973_item	2237263	et	4	main
poliitiline	doc_124643816973_item	2237265	et	3	main
et	doc_124643816973_item	2237269	et	3	main
kogu	doc_124643816973_item	2237277	et	4	main
kõike	doc_124643816973_item	2237281	et	4	main
ja	doc_122714475543_item	2237010	et	3	main
minu	doc_122714475543_item	2237012	et	3	main
aga	doc_122714475543_item	2237023	et	3	main
külmkapp	doc_122714475543_item	2237031	et	3	main
teler	doc_122714475543_item	2237032	et	3	main
kodunetelefon	doc_122714475543_item	2237034	et	4	main
ühe	doc_122714475543_item	2237036	et	4	main
seadmed	doc_122714475543_item	2237040	et	3	main
igal	doc_122714475543_item	2237044	et	3	main
siis	doc_122714475543_item	2237046	et	3	main
elus	doc_122714475543_item	2237053	et	4	main
väga	doc_122714475543_item	2237054	et	3	main
asjad	doc_122714475544_item	2237056	et	3	main
ilma	doc_122714475544_item	2237057	et	4	main
inimesed	doc_122714475544_item	2237059	et	3	main
saaks	doc_122714475544_item	2237068	et	3	main
praegu	doc_122714475544_item	2237070	et	3	main
compuuterita	doc_122714475544_item	2237077	et	4	main
ja	doc_122714475544_item	2237084	et	3	main
kodus	doc_122714475544_item	2237097	et	4	main
ja	doc_122714475544_item	2237102	et	3	main
arvutist	doc_122714475544_item	2237101	et	4	main
telerist	doc_122714475544_item	2237103	et	4	main
me	doc_122714475544_item	2237104	et	4	main
helistame	doc_122714475544_item	2237105	et	3	main
sugulase	doc_122714475544_item	2237107	et	3	main
oma	doc_122714475544_item	2237106	et	4	main
ja	doc_122714475544_item	2237108	et	3	main
sõprale	doc_122714475544_item	2237109	et	4	main
ja	doc_122714475544_item	2237110	et	3	main
kokkuleppime	doc_122714475544_item	2237111	et	4	main
kohtumis	doc_122714475544_item	2237112	et	3	main
transporti	doc_122714475544_item	2237113	et	4	main
tänas	doc_122714475544_item	2237114	et	3	main
me	doc_122714475544_item	2237115	et	4	main
jõudsime	doc_122714475544_item	2237116	et	3	main
tööl	doc_122714475544_item	2237117	et	3	main
spordiklubisse	doc_122714475544_item	2237118	et	3	main
kodusse	doc_122714475544_item	2237119	et	3	main
ja	doc_122714475544_item	2237120	et	3	main
p	doc_122714475544_item	2237122	et	4	main
ilma	doc_122714475545_item	2237131	et	4	main
saaks	doc_122714475545_item	2237139	et	3	main
vaja	doc_122714475545_item	2237146	et	4	main
iga	doc_122714475545_item	2237147	et	4	main
sööma	doc_122714475545_item	2237149	et	4	main
peavad	doc_122714475545_item	2237151	et	4	main
käima	doc_122714475545_item	2237152	et	4	main
kaupluses	doc_122714475545_item	2237153	et	3	main
tööle	doc_122714475545_item	2237158	et	3	main
kuu	doc_122714475545_item	2237163	et	4	main
see	doc_122714475546_item	2237175	et	3	main
milleks	doc_122714475546_item	2237180	et	4	main
palju	doc_122714475546_item	2237183	et	4	main
ma	doc_122714475546_item	2237186	et	3	main
sellepärast	doc_122714475546_item	2237198	et	3	main
informatsion	doc_122714475546_item	2237201	et	4	main
kõik	doc_122714475546_item	2237203	et	4	main
annab	doc_122714475546_item	2237205	et	3	main
elektri	doc_122714475546_item	2237207	et	3	main
teiseks	doc_122714475546_item	2237208	et	4	main
asi	doc_122714475546_item	2237211	et	4	main
praegune	doc_122714475546_item	2237213	et	3	main
elus	doc_122714475546_item	2237214	et	4	main
milleta	doc_122714475545_item	2237125	et	3	main
inimsed	doc_122714475545_item	2237126	et	4	main
asjad	doc_122714475545_item	2237130	et	3	main
saaks	doc_122714475545_item	2237135	et	3	main
inimesed	doc_122714475545_item	2237137	et	3	main
elada	doc_122714475545_item	2237140	et	3	main
on	doc_122714475545_item	2237144	et	4	main
päev	doc_122714475545_item	2237148	et	3	main
inimesed	doc_122714475545_item	2237150	et	3	main
käivad	doc_122714475545_item	2237155	et	4	main
peavad	doc_122714475545_item	2237160	et	4	main
inimesed	doc_122714475546_item	2237173	et	3	main
teema	doc_122714475546_item	2237179	et	4	main
räägita	doc_122714475546_item	2237184	et	4	main
esimiseks	doc_122714475546_item	2237185	et	4	main
on	doc_122714475546_item	2237189	et	4	main
ilma	doc_122714475546_item	2237191	et	4	main
ei	doc_122714475546_item	2237194	et	4	main
elada	doc_122714475546_item	2237196	et	3	main
elektronika	doc_122714475546_item	2237216	et	4	main
sest	doc_122714475546_item	2237217	et	4	main
arvutid	doc_122714475546_item	2237218	et	4	main
telerit	doc_122714475546_item	2237219	et	3	main
selle	doc_122714475546_item	2237228	et	4	main
kultuuriloost	doc_124643816973_item	2237242	et	4	main
ühiskonna	doc_124643816973_item	2237247	et	4	main
majanduslikku	doc_124643816973_item	2237250	et	4	main
millised	doc_124643816973_item	2237253	et	3	main
vabadussõja	doc_124643816973_item	2237255	et	3	main
1	doc_124643816973_item	2237264	et	2	main
süsteem	doc_124643816973_item	2237266	et	3	main
selline	doc_124643816973_item	2237268	et	4	main
partei	doc_124643816973_item	2237273	et	4	main
partei	doc_124643816973_item	2237275	et	4	main
juhtis	doc_124643816973_item	2237276	et	3	main
ja	doc_124643816973_item	2237318	et	3	main
pidid	doc_124643816973_item	2237320	et	4	main
oma	doc_124643816973_item	2237321	et	4	main
karju	doc_124643816973_item	2237324	et	4	main
kõik	doc_124643816973_item	2237327	et	4	main
kolhoosile	doc_124643816973_item	2237331	et	3	main
sovhoosile	doc_124643816973_item	2237333	et	3	main
peaaegu	doc_124643816973_item	2237335	et	3	main
see	doc_124643816973_item	2237341	et	3	main
riigile	doc_124643816973_item	2237345	et	3	main
muidugi	doc_124643816973_item	2237347	et	4	main
ei	doc_124643816973_item	2237358	et	4	main
see	doc_124643816973_item	2237361	et	3	main
oli	doc_124643816973_item	2237366	et	3	main
tehaseid	doc_124643816973_item	2237368	et	3	main
tähtsamaid	doc_124643816973_item	2237380	et	4	main
majanduslikku	doc_124643816973_item	2237382	et	4	main
tehtud	doc_124643816973_item	2237387	et	4	main
vaemistatud	doc_124643816973_item	2237389	et	4	main
tekstiilist	doc_124643816973_item	2237391	et	4	main
võidu	doc_124643816973_item	2237396	et	4	main
kõige	doc_124643816973_item	2237407	et	4	main
kõik	doc_124643816973_item	2237416	et	4	main
kokku	doc_124643816973_item	2237418	et	3	main
ei	doc_124643816973_item	2237423	et	4	main
ew	doc_124643816973_item	2237435	et	4	main
ew	doc_124643816973_item	2237437	et	4	main
ja	doc_124643816973_item	2237449	et	3	main
head	doc_124643816973_item	2237451	et	4	main
kultuuriloo	doc_124643816974_item	2237458	et	4	main
kelle	doc_124643816974_item	2237461	et	4	main
loosung	doc_124643816974_item	2237473	et	3	main
arvan	doc_124643816974_item	2237510	et	3	main
side	doc_122714475546_item	2237221	et	4	main
need	doc_122714475546_item	2237223	et	3	main
seadmed	doc_122714475546_item	2237224	et	3	main
elada	doc_122714475546_item	2237234	et	3	main
p	doc_122714475546_item	2237239	et	4	main
olid	doc_124643816973_item	2237254	et	4	main
võidu	doc_124643816973_item	2237256	et	4	main
põhjused	doc_124643816973_item	2237258	et	3	main
iseloomustage	doc_124643816973_item	2237260	et	4	main
kõige	doc_124643816973_item	2237270	et	4	main
oli	doc_124643816973_item	2237272	et	3	main
ja	doc_124643816973_item	2237274	et	3	main
otsustas	doc_124643816973_item	2237280	et	3	main
oli	doc_124643816973_item	2237284	et	3	main
stalini	doc_124643816973_item	2237285	et	4	main
ideoloogia	doc_124643816973_item	2237286	et	4	main
see	doc_124643816973_item	2237287	et	3	main
oli	doc_124643816973_item	2237288	et	3	main
üks	doc_124643816973_item	2237289	et	3	main
ja	doc_124643816973_item	2237290	et	3	main
ainult	doc_124643816973_item	2237291	et	4	main
valitseja	doc_124643816973_item	2237292	et	4	main
kõik	doc_124643816973_item	2237294	et	4	main
pidati	doc_124643816973_item	2237295	et	4	main
keda	doc_124643816973_item	2237293	et	4	main
nagu	doc_124643816973_item	2237296	et	3	main
jumalat	doc_124643816973_item	2237297	et	3	main
kõik	doc_124643816973_item	2237298	et	4	main
seadused	doc_124643816973_item	2237299	et	3	main
kõik	doc_124643816973_item	2237300	et	4	main
sõja	doc_124643816973_item	2237301	et	3	main
küsimused	doc_124643816973_item	2237302	et	4	main
ja	doc_124643816973_item	2237303	et	3	main
otsused	doc_124643816973_item	2237304	et	3	main
olid	doc_124643816973_item	2237305	et	4	main
stalini	doc_124643816973_item	2237306	et	4	main
käes	doc_124643816973_item	2237307	et	4	main
partei	doc_124643816973_item	2237308	et	4	main
käes	doc_124643816973_item	2237309	et	4	main
majanduses	doc_124643816973_item	2237310	et	4	main
oli	doc_124643816973_item	2237311	et	3	main
kollektivisatsiooni	doc_124643816973_item	2237312	et	4	main
süsteem	doc_124643816973_item	2237313	et	3	main
kus	doc_124643816973_item	2237314	et	3	main
kõik	doc_124643816973_item	2237315	et	4	main
maad	doc_124643816973_item	2237316	et	4	main
iseloomustab	doc_124643816973_item	2237245	et	4	main
poliitilist	doc_124643816973_item	2237248	et	3	main
süsteemibr	doc_124643816973_item	2237251	et	4	main
oli	doc_124643816973_item	2237267	et	3	main
olulisem	doc_124643816973_item	2237271	et	4	main
riigi	doc_124643816973_item	2237278	et	3	main
küsimusi	doc_124643816973_item	2237283	et	4	main
ja	doc_124643816973_item	2237326	et	3	main
maad	doc_124643816973_item	2237329	et	4	main
vilju	doc_124643816973_item	2237339	et	4	main
kolhoos	doc_124643816973_item	2237342	et	3	main
vaevad	doc_124643816973_item	2237350	et	4	main
ja	doc_124643816973_item	2237351	et	3	main
mitte	doc_124643816973_item	2237354	et	3	main
suur	doc_124643816973_item	2237371	et	3	main
nõukogude	doc_124643816973_item	2237384	et	3	main
raudemasi	doc_124643816973_item	2237392	et	4	main
peamised	doc_124643816973_item	2237397	et	3	main
väga	doc_124643816973_item	2237402	et	3	main
minu	doc_124643816973_item	2237405	et	3	main
tahtmine	doc_124643816973_item	2237412	et	4	main
vaim	doc_124643816973_item	2237415	et	3	main
tahtejõudu	doc_124643816973_item	2237420	et	4	main
kasulik	doc_124643816973_item	2237428	et	3	main
abi	doc_124643816973_item	2237429	et	4	main
soome	doc_124643816973_item	2237430	et	3	main
inglismaa	doc_124643816973_item	2237432	et	4	main
tol	doc_124643816973_item	2237438	et	3	main
ajal	doc_124643816973_item	2237439	et	4	main
tugevasti	doc_124643816973_item	2237442	et	3	main
tü	doc_124643816973_item	2237444	et	4	main
oli	doc_124643816973_item	2237445	et	3	main
arenenud	doc_124643816973_item	2237447	et	4	main
erialal	doc_124643816973_item	2237454	et	3	main
kreedo	doc_124643816974_item	2237463	et	4	main
oli	doc_124643816974_item	2237464	et	3	main
eestlased	doc_124643816974_item	2237466	et	3	main
on	doc_124643816974_item	2237471	et	4	main
eestlasteks	doc_124643816974_item	2237503	et	4	main
ma	doc_124643816974_item	2237509	et	3	main
see	doc_124643816974_item	2237511	et	3	main
oli	doc_124643816974_item	2237514	et	3	main
intelligentsi	doc_124643816974_item	2237517	et	4	main
ju	doc_124643816974_item	2237522	et	3	main
kunst	doc_124643816974_item	2237528	et	3	main
rohkem	doc_124643816974_item	2237535	et	4	main
ma	doc_124643816974_item	2237545	et	3	main
looming	doc_124643816974_item	2237549	et	3	main
et	doc_124643816974_item	2237560	et	3	main
ühiskonnas	doc_124643816974_item	2237567	et	4	main
samuti	doc_124643816974_item	2237577	et	3	main
euroopa	doc_124643816974_item	2237586	et	4	main
ma	doc_124643816974_item	2237589	et	3	main
sisseastumine	doc_124643816974_item	2237594	et	3	main
toimus	doc_124643816974_item	2237596	et	3	main
kui	doc_124643816974_item	2237602	et	3	main
et	doc_124643816974_item	2237606	et	3	main
tol	doc_124643816974_item	2237614	et	3	main
2	doc_124643816974_item	2237620	et	2	main
ma	doc_124643816974_item	2237621	et	3	main
rohkem	doc_124643816974_item	2237627	et	4	main
alustan	doc_124643816974_item	2237632	et	3	main
et	doc_124643816974_item	2237634	et	3	main
wabariik	doc_124643816974_item	2237636	et	4	main
tormi	doc_124643816974_item	2237640	et	4	main
tulemusel	doc_124643816974_item	2237641	et	3	main
eelnevad	doc_124643816974_item	2237646	et	4	main
tohutut	doc_124643816974_item	2237658	et	4	main
need	doc_124643816974_item	2237660	et	3	main
arusaamisele	doc_124643816974_item	2237670	et	4	main
parandada	doc_124643816974_item	2237675	et	3	main
ei	doc_124643816974_item	2237681	et	4	main
alati	doc_124643816974_item	2237723	et	4	main
all	doc_124643816974_item	2237727	et	3	main
ole	doc_124643816974_item	2237744	et	4	main
jõudu	doc_124643816974_item	2237746	et	4	main
mitteainult	doc_124643816974_item	2237752	et	4	main
eesti	doc_124643816974_item	2237760	et	4	main
tol	doc_124643816974_item	2237786	et	3	main
kirjanik	doc_124643816974_item	2237798	et	3	main
tema	doc_124643816974_item	2237808	et	4	main
mille	doc_124643816974_item	2237815	et	3	main
majanduslikke	doc_124643816973_item	2237282	et	3	main
loome	doc_124643816973_item	2237325	et	4	main
oma	doc_124643816973_item	2237328	et	4	main
ja	doc_124643816973_item	2237334	et	3	main
mis	doc_124643816973_item	2237340	et	4	main
talumehed	doc_124643816973_item	2237346	et	3	main
väga	doc_124643816973_item	2237349	et	3	main
teha	doc_124643816973_item	2237357	et	3	main
br	doc_124643816973_item	2237364	et	4	main
linnades	doc_124643816973_item	2237365	et	3	main
palju	doc_124643816973_item	2237367	et	4	main
kus	doc_124643816973_item	2237369	et	3	main
inimesi	doc_124643816973_item	2237373	et	4	main
see	doc_124643816973_item	2237375	et	3	main
muidugi	doc_124643816973_item	2237377	et	4	main
oli	doc_124643816973_item	2237386	et	3	main
vabadussõja	doc_124643816973_item	2237395	et	3	main
põhjused	doc_124643816973_item	2237398	et	3	main
erinevad	doc_124643816973_item	2237400	et	4	main
oluline	doc_124643816973_item	2237403	et	4	main
oli	doc_124643816973_item	2237409	et	3	main
võidu	doc_124643816973_item	2237411	et	4	main
tugev	doc_124643816973_item	2237426	et	4	main
teaduselubr	doc_124643816973_item	2237436	et	4	main
ülikoolid	doc_124643816973_item	2237443	et	3	main
omal	doc_124643816973_item	2237453	et	3	main
kontrolltöö	doc_124643816974_item	2237459	et	4	main
olgem	doc_124643816974_item	2237465	et	3	main
ka	doc_124643816974_item	2237475	et	3	main
jätta	doc_124643816974_item	2237504	et	3	main
ka	doc_124643816974_item	2237507	et	3	main
loominguline	doc_124643816974_item	2237512	et	4	main
eelkõige	doc_124643816974_item	2237515	et	3	main
kodanluse	doc_124643816974_item	2237519	et	4	main
euroopaga	doc_124643816974_item	2237521	et	3	main
ja	doc_124643816974_item	2237529	et	3	main
kultuur	doc_124643816974_item	2237531	et	3	main
üldse	doc_124643816974_item	2237533	et	3	main
et	doc_124643816974_item	2237547	et	3	main
tänases	doc_124643816974_item	2237551	et	3	main
tehakse	doc_124643816974_item	2237557	et	3	main
kõik	doc_124643816974_item	2237559	et	4	main
euroopa	doc_124643816974_item	2237563	et	4	main
igasugused	doc_124643816974_item	2237569	et	3	main
muidugi	doc_124643816974_item	2237576	et	4	main
loodan	doc_124643816974_item	2237590	et	3	main
euroopa	doc_124643816974_item	2237592	et	4	main
mis	doc_124643816974_item	2237595	et	4	main
halbu	doc_124643816974_item	2237603	et	3	main
mul	doc_124643816974_item	2237604	et	3	main
paljude	doc_124643816974_item	2237611	et	3	main
ka	doc_124643816974_item	2237617	et	3	main
br	doc_124643816974_item	2237619	et	4	main
iseseisvumine	doc_124643816974_item	2237625	et	3	main
oli	doc_124643816974_item	2237626	et	3	main
revolutsioonide	doc_124643816974_item	2237638	et	3	main
iseseisvusele	doc_124643816974_item	2237645	et	4	main
ja	doc_124643816974_item	2237650	et	3	main
teine	doc_124643816974_item	2237653	et	3	main
sõda	doc_124643816974_item	2237655	et	4	main
tõi	doc_124643816974_item	2237656	et	3	main
ja	doc_124643816974_item	2237662	et	3	main
kultuurielule	doc_124643816974_item	2237666	et	3	main
et	doc_124643816974_item	2237671	et	3	main
vaja	doc_124643816974_item	2237673	et	4	main
inimeste	doc_124643816974_item	2237676	et	3	main
ees	doc_124643816974_item	2237678	et	4	main
pärast	doc_124643816974_item	2237721	et	4	main
väike	doc_124643816974_item	2237728	et	4	main
säilitada	doc_124643816974_item	2237731	et	3	main
kultuuri	doc_124643816974_item	2237735	et	4	main
võõrast	doc_124643816974_item	2237739	et	4	main
saama	doc_124643816974_item	2237749	et	4	main
faktoridest	doc_124643816974_item	2237757	et	4	main
ka	doc_124643816974_item	2237758	et	3	main
sündis	doc_124643816974_item	2237759	et	3	main
tahan	doc_124643816974_item	2237764	et	3	main
öelda	doc_124643816974_item	2237765	et	4	main
üldse	doc_124643816974_item	2237767	et	3	main
ajal	doc_124643816974_item	2237787	et	4	main
figuriiks	doc_124643816974_item	2237790	et	4	main
külad	doc_124643816973_item	2237317	et	3	main
talud	doc_124643816973_item	2237319	et	4	main
oma	doc_124643816973_item	2237323	et	4	main
anda	doc_124643816973_item	2237330	et	3	main
või	doc_124643816973_item	2237332	et	4	main
raha	doc_124643816973_item	2237337	et	4	main
annab	doc_124643816973_item	2237343	et	3	main
oli	doc_124643816973_item	2237348	et	3	main
ebaõnnestunud	doc_124643816973_item	2237352	et	4	main
midagi	doc_124643816973_item	2237355	et	4	main
sest	doc_124643816973_item	2237360	et	4	main
kohustuslik	doc_124643816973_item	2237363	et	3	main
töötas	doc_124643816973_item	2237370	et	3	main
hulk	doc_124643816973_item	2237372	et	3	main
ja	doc_124643816973_item	2237374	et	3	main
oli	doc_124643816973_item	2237376	et	3	main
üks	doc_124643816973_item	2237379	et	3	main
osa	doc_124643816973_item	2237381	et	4	main
süsteemis	doc_124643816973_item	2237383	et	3	main
riigidel	doc_124643816973_item	2237385	et	4	main
br	doc_124643816973_item	2237393	et	4	main
muidugi	doc_124643816973_item	2237401	et	4	main
ja	doc_124643816973_item	2237404	et	3	main
tähtsam	doc_124643816973_item	2237408	et	4	main
ja	doc_124643816973_item	2237413	et	3	main
oma	doc_124643816973_item	2237419	et	4	main
raha	doc_124643816973_item	2237322	et	4	main
kõik	doc_124643816973_item	2237336	et	4	main
või	doc_124643816973_item	2237338	et	4	main
läks	doc_124643816973_item	2237344	et	3	main
aga	doc_124643816973_item	2237353	et	3	main
vastu	doc_124643816973_item	2237356	et	3	main
saa	doc_124643816973_item	2237359	et	4	main
oli	doc_124643816973_item	2237362	et	3	main
ka	doc_124643816973_item	2237378	et	3	main
ja	doc_124643816973_item	2237388	et	3	main
kõik	doc_124643816973_item	2237390	et	4	main
2	doc_124643816973_item	2237394	et	2	main
olid	doc_124643816973_item	2237399	et	4	main
meeles	doc_124643816973_item	2237406	et	3	main
eestlaste	doc_124643816973_item	2237410	et	4	main
ühtne	doc_124643816973_item	2237414	et	3	main
panid	doc_124643816973_item	2237417	et	4	main
ja	doc_124643816973_item	2237421	et	3	main
eitada	doc_124643816973_item	2237425	et	3	main
pooltbr	doc_124643816973_item	2237433	et	4	main
juba	doc_124643816973_item	2237441	et	3	main
kõige	doc_124643816973_item	2237446	et	4	main
neist	doc_124643816973_item	2237448	et	4	main
opetsialiste	doc_124643816973_item	2237452	et	4	main
body	doc_124643816973_item	2237456	et	4	main
eesti	doc_124643816974_item	2237457	et	4	main
1	doc_124643816974_item	2237460	et	2	main
kuid	doc_124643816974_item	2237467	et	4	main
ka	doc_124643816974_item	2237469	et	3	main
eurooplasteks	doc_124643816974_item	2237470	et	3	main
nii	doc_124643816974_item	2237502	et	3	main
kuid	doc_124643816974_item	2237505	et	4	main
euroopasse	doc_124643816974_item	2237508	et	3	main
haritud	doc_124643816974_item	2237516	et	4	main
ja	doc_124643816974_item	2237518	et	3	main
oma	doc_124643816974_item	2237520	et	4	main
oli	doc_124643816974_item	2237523	et	3	main
kõrgharidus	doc_124643816974_item	2237525	et	3	main
teadus	doc_124643816974_item	2237527	et	4	main
üldse	doc_124643816974_item	2237530	et	3	main
ja	doc_124643816974_item	2237539	et	3	main
oskusi	doc_124643816974_item	2237541	et	3	main
eesti	doc_124643816974_item	2237552	et	4	main
ju	doc_124643816974_item	2237558	et	3	main
heaks	doc_124643816974_item	2237562	et	4	main
liidu	doc_124643816974_item	2237564	et	3	main
poliitiilistes	doc_124643816974_item	2237574	et	4	main
väiksel	doc_124643816974_item	2237579	et	4	main
õigus	doc_124643816974_item	2237584	et	4	main
liikmeks	doc_124643816974_item	2237588	et	3	main
toob	doc_124643816974_item	2237598	et	3	main
rohkem	doc_124643816974_item	2237600	et	4	main
tsiviliseerimisse	doc_124643816974_item	2237607	et	4	main
on	doc_124643816974_item	2237610	et	4	main
unistus	doc_124643816974_item	2237612	et	4	main
kui	doc_124643816974_item	2237616	et	3	main
et	doc_124643816974_item	2237623	et	3	main
ma	doc_124643816974_item	2237631	et	3	main
sellest	doc_124643816974_item	2237633	et	4	main
eesti	doc_124643816974_item	2237635	et	4	main
sündis	doc_124643816974_item	2237637	et	3	main
ja	doc_124643816974_item	2237639	et	3	main
tähendab	doc_124643816974_item	2237643	et	3	main
eestile	doc_124643816974_item	2237657	et	3	main
kahju	doc_124643816974_item	2237659	et	4	main
sõjad	doc_124643816974_item	2237661	et	3	main
mõjusid	doc_124643816974_item	2237664	et	4	main
nende	doc_124643816974_item	2237667	et	4	main
midagi	doc_124643816974_item	2237674	et	4	main
poliitiline	doc_124643816974_item	2237679	et	3	main
midagi	doc_124643816974_item	2237683	et	4	main
rahvas	doc_124643816974_item	2237686	et	4	main
ta	doc_124643816974_item	2237725	et	4	main
oma	doc_124643816974_item	2237732	et	4	main
ja	doc_124643816974_item	2237734	et	3	main
omandama	doc_124643816974_item	2237741	et	3	main
miks	doc_124643816974_item	2237742	et	4	main
et	doc_124643816974_item	2237747	et	3	main
3	doc_124643816974_item	2237762	et	2	main
ainult	doc_124643816974_item	2237797	et	4	main
ajal	doc_124643816974_item	2237805	et	4	main
sündima	doc_124643816974_item	2237807	et	3	main
võimu	doc_124643816973_item	2237422	et	4	main
saa	doc_124643816973_item	2237424	et	4	main
ja	doc_124643816973_item	2237427	et	3	main
ja	doc_124643816973_item	2237431	et	3	main
3	doc_124643816973_item	2237434	et	2	main
töötasid	doc_124643816973_item	2237440	et	4	main
kasutas	doc_124643816973_item	2237450	et	3	main
br	doc_124643816973_item	2237455	et	4	main
loominguline	doc_124643816974_item	2237462	et	4	main
saagem	doc_124643816974_item	2237468	et	3	main
see	doc_124643816974_item	2237472	et	3	main
aktuaalne	doc_124643816974_item	2237474	et	3	main
tänases	doc_124643816974_item	2237476	et	3	main
eesti	doc_124643816974_item	2237477	et	4	main
ühiskonnas	doc_124643816974_item	2237478	et	4	main
2	doc_124643816974_item	2237479	et	2	main
kas	doc_124643816974_item	2237480	et	3	main
eesti	doc_124643816974_item	2237481	et	4	main
iseseisvumine	doc_124643816974_item	2237482	et	3	main
oli	doc_124643816974_item	2237483	et	3	main
juhus	doc_124643816974_item	2237484	et	4	main
seaduspärasus	doc_124643816974_item	2237486	et	4	main
põhjendabr	doc_124643816974_item	2237487	et	4	main
või	doc_124643816974_item	2237485	et	4	main
3	doc_124643816974_item	2237488	et	2	main
ahtammsaare	doc_124643816974_item	2237489	et	4	main
looming	doc_124643816974_item	2237490	et	3	main
ew-s	doc_124643816974_item	2237491	et	3	main
br	doc_124643816974_item	2237492	et	4	main
br	doc_124643816974_item	2237493	et	4	main
1	doc_124643816974_item	2237494	et	2	main
see	doc_124643816974_item	2237495	et	3	main
oli	doc_124643816974_item	2237496	et	3	main
eesti	doc_124643816974_item	2237497	et	4	main
rahva	doc_124643816974_item	2237498	et	3	main
kes	doc_124643816974_item	2237500	et	4	main
kreedo	doc_124643816974_item	2237499	et	4	main
tahtis	doc_124643816974_item	2237501	et	3	main
integreerida	doc_124643816974_item	2237506	et	3	main
kreedo	doc_124643816974_item	2237513	et	4	main
seotud	doc_124643816974_item	2237524	et	4	main
heatasemeline	doc_124643816974_item	2237526	et	4	main
võimalusi	doc_124643816974_item	2237536	et	3	main
mozeditorbogusnodetrue	doc_124643816974_item	2237544	et	4	main
see	doc_124643816974_item	2237548	et	3	main
liikmeks	doc_124643816974_item	2237565	et	3	main
muutused	doc_124643816974_item	2237570	et	4	main
majanduspoliitikas	doc_124643816974_item	2237572	et	3	main
riigil	doc_124643816974_item	2237580	et	3	main
eestil	doc_124643816974_item	2237582	et	3	main
liidu	doc_124643816974_item	2237587	et	3	main
liidu	doc_124643816974_item	2237593	et	3	main
meile	doc_124643816974_item	2237599	et	4	main
häid	doc_124643816974_item	2237601	et	3	main
tundub	doc_124643816974_item	2237605	et	3	main
euroopasse	doc_124643816974_item	2237608	et	3	main
nii	doc_124643816974_item	2237613	et	3	main
arvan	doc_124643816974_item	2237622	et	3	main
seaduspärasus	doc_124643816974_item	2237628	et	4	main
kui	doc_124643816974_item	2237629	et	3	main
juhus	doc_124643816974_item	2237630	et	4	main
et	doc_124643816974_item	2237644	et	3	main
palju	doc_124643816974_item	2237647	et	4	main
poliitilisis	doc_124643816974_item	2237649	et	3	main
protsessebr	doc_124643816974_item	2237652	et	4	main
maailma	doc_124643816974_item	2237654	et	4	main
enesekindlusele	doc_124643816974_item	2237668	et	4	main
silmade	doc_124643816974_item	2237677	et	3	main
võim	doc_124643816974_item	2237680	et	3	main
muuta	doc_124643816974_item	2237684	et	4	main
ja	doc_124643816974_item	2237685	et	3	main
seal	doc_124643816974_item	2237532	et	4	main
oli	doc_124643816974_item	2237534	et	3	main
enese	doc_124643816974_item	2237537	et	4	main
arenemiseks	doc_124643816974_item	2237538	et	4	main
oma	doc_124643816974_item	2237540	et	4	main
avaldamiseks	doc_124643816974_item	2237542	et	4	main
br	doc_124643816974_item	2237543	et	4	main
arvan	doc_124643816974_item	2237546	et	3	main
ka	doc_124643816974_item	2237550	et	3	main
päris	doc_124643816974_item	2237554	et	4	main
ühiskonnas	doc_124643816974_item	2237553	et	4	main
aktuaalne	doc_124643816974_item	2237555	et	3	main
tänapäeval	doc_124643816974_item	2237556	et	3	main
olema	doc_124643816974_item	2237561	et	4	main
meie	doc_124643816974_item	2237566	et	4	main
toimuvad	doc_124643816974_item	2237568	et	4	main
ka	doc_124643816974_item	2237571	et	3	main
sotsiaalsfääris	doc_124643816974_item	2237573	et	3	main
oludes	doc_124643816974_item	2237575	et	3	main
nii	doc_124643816974_item	2237578	et	3	main
nagu	doc_124643816974_item	2237581	et	3	main
on	doc_124643816974_item	2237583	et	4	main
olema	doc_124643816974_item	2237585	et	4	main
et	doc_124643816974_item	2237591	et	3	main
juba	doc_124643816974_item	2237597	et	3	main
edasiliikumine	doc_124643816974_item	2237609	et	3	main
ajal	doc_124643816974_item	2237615	et	4	main
tänapäeval	doc_124643816974_item	2237618	et	3	main
eesti	doc_124643816974_item	2237624	et	4	main
see	doc_124643816974_item	2237642	et	3	main
ühiskondliku	doc_124643816974_item	2237648	et	3	main
muid	doc_124643816974_item	2237651	et	4	main
segadused	doc_124643816974_item	2237663	et	3	main
inimeste	doc_124643816974_item	2237665	et	3	main
viisid	doc_124643816974_item	2237669	et	4	main
on	doc_124643816974_item	2237672	et	4	main
saanud	doc_124643816974_item	2237682	et	4	main
hakkas	doc_124643816974_item	2237687	et	3	main
nõudma	doc_124643816974_item	2237688	et	3	main
poliitilise	doc_124643816974_item	2237689	et	3	main
ja	doc_124643816974_item	2237690	et	3	main
majanduse	doc_124643816974_item	2237691	et	4	main
olukorra	doc_124643816974_item	2237692	et	3	main
parandamist	doc_124643816974_item	2237693	et	4	main
riigis	doc_124643816974_item	2237694	et	3	main
puudusid	doc_124643816974_item	2237695	et	4	main
peamised	doc_124643816974_item	2237696	et	3	main
inimõigused	doc_124643816974_item	2237697	et	4	main
sotsiaalsed	doc_124643816974_item	2237698	et	3	main
erinevused	doc_124643816974_item	2237699	et	4	main
kodanluse	doc_124643816974_item	2237700	et	4	main
ja	doc_124643816974_item	2237701	et	3	main
vabrikutööliste	doc_124643816974_item	2237702	et	4	main
vahel	doc_124643816974_item	2237703	et	4	main
olid	doc_124643816974_item	2237704	et	4	main
väga	doc_124643816974_item	2237705	et	3	main
tugevad	doc_124643816974_item	2237706	et	4	main
aga	doc_124643816974_item	2237707	et	3	main
kõige	doc_124643816974_item	2237708	et	4	main
oluline	doc_124643816974_item	2237709	et	4	main
oli	doc_124643816974_item	2237710	et	3	main
see	doc_124643816974_item	2237711	et	3	main
faktor	doc_124643816974_item	2237712	et	3	main
et	doc_124643816974_item	2237713	et	3	main
eestlased	doc_124643816974_item	2237714	et	3	main
muidugi	doc_124643816974_item	2237715	et	4	main
tahtsid	doc_124643816974_item	2237716	et	4	main
olla	doc_124643816974_item	2237717	et	3	main
vabaks	doc_124643816974_item	2237718	et	3	main
rahvaks	doc_124643816974_item	2237719	et	3	main
selle	doc_124643816974_item	2237720	et	4	main
et	doc_124643816974_item	2237722	et	3	main
tahtis	doc_124643816974_item	2237730	et	3	main
peab	doc_124643816974_item	2237737	et	4	main
ei	doc_124643816974_item	2237743	et	4	main
oli	doc_124643816974_item	2237724	et	3	main
mõju	doc_124643816974_item	2237726	et	4	main
rahvas	doc_124643816974_item	2237729	et	4	main
identiteedi	doc_124643816974_item	2237733	et	4	main
miks	doc_124643816974_item	2237736	et	4	main
ta	doc_124643816974_item	2237738	et	4	main
kultuuri	doc_124643816974_item	2237740	et	4	main
iseseisvaks	doc_124643816974_item	2237748	et	3	main
arvan	doc_124643816974_item	2237751	et	3	main
nendest	doc_124643816974_item	2237753	et	4	main
teistest	doc_124643816974_item	2237756	et	4	main
ma	doc_124643816974_item	2237763	et	3	main
wabariigis	doc_124643816974_item	2237769	et	4	main
eesti	doc_124643816974_item	2237768	et	4	main
oli	doc_124643816974_item	2237770	et	3	main
kultuuri	doc_124643816974_item	2237771	et	4	main
õitse	doc_124643816974_item	2237772	et	4	main
aeg	doc_124643816974_item	2237773	et	3	main
selles	doc_124643816974_item	2237774	et	4	main
ajas	doc_124643816974_item	2237775	et	4	main
arenesid	doc_124643816974_item	2237776	et	4	main
keel	doc_124643816974_item	2237777	et	4	main
kirjandus	doc_124643816974_item	2237778	et	3	main
ajakirjandus	doc_124643816974_item	2237779	et	3	main
teadus	doc_124643816974_item	2237780	et	4	main
teatrikunst	doc_124643816974_item	2237781	et	3	main
anton	doc_124643816974_item	2237782	et	4	main
hannsen	doc_124643816974_item	2237783	et	4	main
tammsaare	doc_124643816974_item	2237784	et	3	main
oli	doc_124643816974_item	2237785	et	3	main
tal	doc_124643816974_item	2237745	et	3	main
ma	doc_124643816974_item	2237750	et	3	main
vaid	doc_124643816974_item	2237754	et	3	main
paljudest	doc_124643816974_item	2237755	et	3	main
iseseisvuminebr	doc_124643816974_item	2237761	et	4	main
et	doc_124643816974_item	2237766	et	3	main
ew-kirjanduselus	doc_124643816974_item	2237791	et	4	main
kirjanduse	doc_124643816974_item	2237800	et	3	main
tõlkija	doc_124643816974_item	2237803	et	4	main
ja	doc_124643816974_item	2237813	et	3	main
ta	doc_124643816974_item	2237818	et	4	main
köite	doc_124643816974_item	2237828	et	4	main
tema	doc_124643816974_item	2237836	et	4	main
kõige	doc_124643816974_item	2237841	et	4	main
body	doc_124643816974_item	2237846	et	4	main
küsimusele	doc_12501346824_item	2237848	et	4	main
kui	doc_12501346824_item	2237854	et	3	main
inemeste	doc_12501346824_item	2237863	et	4	main
kuulen	doc_12501346824_item	2237870	et	3	main
on	doc_12501346824_item	2237890	et	4	main
kohustuslik	doc_12501346824_item	2237891	et	3	main
inimeste	doc_12501346824_item	2237893	et	3	main
sõna	doc_12501346824_item	2237923	et	4	main
mõtlen	doc_12501346824_item	2237927	et	3	main
kirjanikutest	doc_12501346824_item	2237929	et	3	main
olema	doc_12501346824_item	2237936	et	4	main
eest	doc_12501346824_item	2237941	et	4	main
ma	doc_12501346824_item	2237944	et	3	main
on	doc_12501346824_item	2237955	et	4	main
meeldib	doc_12501346824_item	2237963	et	3	main
promet	doc_12501346824_item	2237965	et	4	main
nende	doc_12501346824_item	2237968	et	4	main
muutused	doc_125394962863_item	2237974	et	4	main
ja	doc_125394962863_item	2237975	et	3	main
elus	doc_125394962863_item	2237980	et	4	main
mida	doc_125394962863_item	2237982	et	4	main
tähendab	doc_125394962863_item	2237983	et	3	main
1	doc_125394962863_item	2237986	et	2	main
saama	doc_125394962863_item	2238028	et	4	main
ja	doc_125394962863_item	2238034	et	3	main
vabariigi	doc_125394962863_item	2238040	et	3	main
valitsust	doc_125394962863_item	2238046	et	4	main
tunnistas	doc_125394962863_item	2238054	et	3	main
ametlikult	doc_125394962863_item	2238055	et	4	main
ja	doc_125394962863_item	2238058	et	3	main
eestis	doc_125394962863_item	2238060	et	3	main
orienteeruda	doc_125394962863_item	2238107	et	3	main
pankrotti	doc_125394962863_item	2238116	et	4	main
uue	doc_125394962863_item	2238118	et	3	main
väga	doc_125394962863_item	2238121	et	3	main
kohandada	doc_125394962863_item	2238123	et	3	main
l	doc_125394962863_item	2238134	et	4	main
toimus	doc_125394962863_item	2238142	et	3	main
kurss	doc_125394962863_item	2238150	et	3	main
kõik	doc_125394962863_item	2238156	et	4	main
muutused	doc_125394962863_item	2238157	et	4	main
said	doc_125394962863_item	2238158	et	4	main
tõeliseks	doc_125394962863_item	2238159	et	4	main
sokiks	doc_125394962863_item	2238160	et	3	main
olid	doc_125394962863_item	2238172	et	4	main
vene	doc_125394962863_item	2238178	et	4	main
valitsus	doc_125394962863_item	2238181	et	4	main
võimalikult	doc_125394962863_item	2238182	et	4	main
sedaprotsessi	doc_125394962863_item	2238184	et	4	main
maadel	doc_125394962863_item	2238186	et	4	main
tol	doc_125394962863_item	2238188	et	3	main
samasugused	doc_125394962863_item	2238190	et	3	main
1989	doc_125394962863_item	2238229	et	2	main
vabaks	doc_125394962863_item	2238235	et	3	main
tegutsevad	doc_125394962863_item	2238243	et	4	main
koos	doc_125394962863_item	2238245	et	4	main
valitsus	doc_125394962863_item	2238254	et	4	main
saanud	doc_125394962863_item	2238256	et	4	main
enam	doc_125394962863_item	2238257	et	4	main
nõuded	doc_125394962863_item	2238263	et	3	main
revolutsioon	doc_125394962863_item	2238265	et	3	main
võimaluse	doc_125394962863_item	2238267	et	3	main
eneseväljendamiseks	doc_125394962863_item	2238269	et	3	main
eesti	doc_125394962864_item	2238274	et	4	main
1	doc_125394962864_item	2238282	et	2	main
11	doc_125394962864_item	2238288	et	2	main
kedagi	doc_125394962864_item	2238297	et	4	main
väga	doc_124643816974_item	2237788	et	3	main
tähtsaks	doc_124643816974_item	2237789	et	4	main
ta	doc_124643816974_item	2237794	et	4	main
vaid	doc_124643816974_item	2237799	et	3	main
hakkas	doc_124643816974_item	2237806	et	3	main
romaan	doc_124643816974_item	2237811	et	3	main
eest	doc_124643816974_item	2237816	et	4	main
sai	doc_124643816974_item	2237817	et	4	main
presidentist	doc_124643816974_item	2237821	et	4	main
ilmus	doc_124643816974_item	2237824	et	4	main
ta	doc_124643816974_item	2237829	et	4	main
palju	doc_124643816974_item	2237831	et	4	main
aga	doc_124643816974_item	2237835	et	3	main
parem	doc_124643816974_item	2237842	et	4	main
1	doc_12501346824_item	2237850	et	2	main
te	doc_12501346824_item	2237852	et	4	main
kuulete	doc_12501346824_item	2237855	et	4	main
sõna	doc_12501346824_item	2237856	et	4	main
minu	doc_12501346824_item	2237859	et	3	main
ma	doc_12501346824_item	2237873	et	3	main
ja	doc_12501346824_item	2237876	et	3	main
kuidas	doc_12501346824_item	2237878	et	3	main
ma	doc_12501346824_item	2237885	et	3	main
et	doc_12501346824_item	2237887	et	3	main
eesti	doc_12501346824_item	2237924	et	4	main
eesti	doc_12501346824_item	2237928	et	4	main
kunstnikutest	doc_12501346824_item	2237931	et	3	main
eestlased	doc_12501346824_item	2237934	et	3	main
traditsioonide	doc_12501346824_item	2237940	et	3	main
kui	doc_12501346824_item	2237943	et	3	main
meenutan	doc_12501346824_item	2237950	et	3	main
ja	doc_12501346824_item	2237952	et	3	main
mul	doc_12501346824_item	2237954	et	3	main
ja	doc_12501346824_item	2237961	et	3	main
vene	doc_12501346824_item	2237970	et	4	main
revolutsioon	doc_125394962863_item	2237985	et	3	main
enam	doc_125394962863_item	2238022	et	4	main
ise	doc_125394962863_item	2238026	et	4	main
eesti	doc_125394962863_item	2238032	et	4	main
valimised	doc_125394962863_item	2238036	et	4	main
võeti	doc_125394962863_item	2238038	et	3	main
algas	doc_125394962863_item	2238042	et	3	main
periood	doc_125394962863_item	2238044	et	3	main
juhtima	doc_125394962863_item	2238048	et	4	main
savisaar	doc_125394962863_item	2238050	et	3	main
aastal	doc_125394962863_item	2238052	et	3	main
eesti	doc_125394962863_item	2238056	et	4	main
hakkati	doc_125394962863_item	2238061	et	3	main
kõige	doc_125394962863_item	2238066	et	4	main
ime	doc_125394962863_item	2238074	et	4	main
tol	doc_125394962863_item	2238114	et	3	main
sest	doc_125394962863_item	2238117	et	4	main
poliitilise	doc_125394962863_item	2238129	et	3	main
seisukohast	doc_125394962863_item	2238130	et	4	main
meri	doc_125394962863_item	2238135	et	3	main
vastu	doc_125394962863_item	2238137	et	3	main
eesti	doc_125394962863_item	2238139	et	4	main
kasutusele	doc_125394962863_item	2238145	et	4	main
kroon	doc_125394962863_item	2238148	et	3	main
rangelt	doc_125394962863_item	2238152	et	4	main
margaga	doc_125394962863_item	2238155	et	3	main
kelle	doc_125394962863_item	2238162	et	4	main
halvenes	doc_125394962863_item	2238164	et	3	main
vabanemisega	doc_125394962863_item	2238175	et	4	main
territooriumit	doc_125394962863_item	2238177	et	3	main
ajal	doc_125394962863_item	2238189	et	4	main
huvid	doc_125394962863_item	2238191	et	3	main
ja	doc_125394962863_item	2238192	et	3	main
hakkasid	doc_125394962863_item	2238196	et	4	main
etapiks	doc_125394962863_item	2238225	et	3	main
iseseisvuse	doc_125394962863_item	2238227	et	4	main
rahvas	doc_125394962863_item	2238232	et	4	main
tundsid	doc_125394962863_item	2238237	et	4	main
kõik	doc_125394962863_item	2238244	et	4	main
aitas	doc_125394962863_item	2238250	et	3	main
rahvast	doc_125394962863_item	2238259	et	4	main
ristiusustamise	doc_125394962864_item	2238272	et	3	main
ühiskonnakorraldusele	doc_125394962864_item	2238275	et	3	main
sajandil	doc_125394962864_item	2238277	et	3	main
tähendab	doc_125394962864_item	2238280	et	3	main
ristiusustamisega	doc_125394962864_item	2238283	et	3	main
kohaselt	doc_125394962864_item	2238294	et	4	main
ja	doc_124643816974_item	2237792	et	3	main
kultuurielus	doc_124643816974_item	2237793	et	4	main
oli	doc_124643816974_item	2237795	et	3	main
mitte	doc_124643816974_item	2237796	et	3	main
uurija	doc_124643816974_item	2237801	et	4	main
ja	doc_124643816974_item	2237802	et	3	main
tol	doc_124643816974_item	2237804	et	3	main
3-me	doc_124643816974_item	2237809	et	4	main
tõde	doc_124643816974_item	2237812	et	4	main
õigus	doc_124643816974_item	2237814	et	4	main
riigi	doc_124643816974_item	2237819	et	3	main
köiteline	doc_124643816974_item	2237810	et	4	main
1926	doc_124643816974_item	2237822	et	2	main
tema	doc_124643816974_item	2237825	et	4	main
ja	doc_124643816974_item	2237838	et	3	main
iseloomustab	doc_124643816974_item	2237843	et	4	main
loomingubr	doc_124643816974_item	2237845	et	4	main
see	doc_12501346824_item	2237861	et	3	main
ja	doc_12501346824_item	2237865	et	3	main
kui	doc_12501346824_item	2237868	et	3	main
elasid	doc_12501346824_item	2237880	et	4	main
ajal	doc_12501346824_item	2237882	et	4	main
tegelesid	doc_12501346824_item	2237884	et	4	main
see	doc_12501346824_item	2237889	et	3	main
auhinna	doc_124643816974_item	2237820	et	3	main
kirjutas	doc_124643816974_item	2237830	et	3	main
muinasjuttusi	doc_124643816974_item	2237832	et	4	main
ja	doc_124643816974_item	2237833	et	3	main
õigus	doc_124643816974_item	2237839	et	4	main
teda	doc_124643816974_item	2237844	et	4	main
kultuur	doc_12501346824_item	2237857	et	3	main
tavad	doc_12501346824_item	2237864	et	3	main
traditsioonid	doc_12501346824_item	2237866	et	3	main
sõna	doc_12501346824_item	2237871	et	4	main
ajaloost	doc_12501346824_item	2237875	et	4	main
tsivilisatsioonist	doc_12501346824_item	2237877	et	3	main
arvan	doc_12501346824_item	2237886	et	3	main
kuulen	doc_12501346824_item	2237922	et	3	main
kultuur	doc_12501346824_item	2237925	et	3	main
ja	doc_12501346824_item	2237930	et	3	main
saavad	doc_12501346824_item	2237935	et	4	main
uhke	doc_12501346824_item	2237937	et	4	main
oma	doc_12501346824_item	2237938	et	4	main
kultuuri	doc_12501346824_item	2237939	et	4	main
sõna	doc_12501346824_item	2237946	et	4	main
lemmik	doc_12501346824_item	2237957	et	3	main
lugesin	doc_12501346824_item	2237967	et	3	main
1	doc_125394962863_item	2237973	et	2	main
eesti	doc_125394962863_item	2237978	et	4	main
aastal	doc_124643816974_item	2237823	et	3	main
roomani	doc_124643816974_item	2237826	et	3	main
teine	doc_124643816974_item	2237827	et	3	main
juttusi	doc_124643816974_item	2237834	et	4	main
tõde	doc_124643816974_item	2237837	et	4	main
tänapäevani	doc_124643816974_item	2237840	et	3	main
vastus	doc_12501346824_item	2237847	et	3	main
kultuur	doc_12501346824_item	2237849	et	3	main
mida	doc_12501346824_item	2237851	et	4	main
mõtlete	doc_12501346824_item	2237853	et	3	main
1	doc_12501346824_item	2237858	et	2	main
arvates	doc_12501346824_item	2237860	et	4	main
on	doc_12501346824_item	2237862	et	4	main
2	doc_12501346824_item	2237867	et	2	main
ma	doc_12501346824_item	2237869	et	3	main
kultuur	doc_12501346824_item	2237872	et	3	main
mõtlen	doc_12501346824_item	2237874	et	3	main
inimesed	doc_12501346824_item	2237879	et	3	main
tol	doc_12501346824_item	2237881	et	3	main
millega	doc_12501346824_item	2237883	et	3	main
kultuur	doc_12501346824_item	2237888	et	3	main
osa	doc_12501346824_item	2237892	et	4	main
elus	doc_12501346824_item	2237894	et	4	main
kultuur	doc_12501346824_item	2237895	et	3	main
alati	doc_12501346824_item	2237896	et	4	main
seotud	doc_12501346824_item	2237897	et	4	main
rahvaomapärasusega	doc_12501346824_item	2237898	et	4	main
see	doc_12501346824_item	2237899	et	3	main
on	doc_12501346824_item	2237900	et	4	main
veel	doc_12501346824_item	2237902	et	4	main
oluline	doc_12501346824_item	2237901	et	4	main
ma	doc_12501346824_item	2237903	et	3	main
meenutan	doc_12501346824_item	2237904	et	3	main
kultuursetest	doc_12501346824_item	2237905	et	4	main
inimestest	doc_12501346824_item	2237906	et	3	main
intelligentsusest	doc_12501346824_item	2237907	et	4	main
ja	doc_12501346824_item	2237908	et	3	main
etikeedist	doc_12501346824_item	2237909	et	4	main
2	doc_12501346824_item	2237910	et	2	main
mida	doc_12501346824_item	2237911	et	4	main
te	doc_12501346824_item	2237912	et	4	main
mõtlete	doc_12501346824_item	2237913	et	3	main
kui	doc_12501346824_item	2237914	et	3	main
kuulete	doc_12501346824_item	2237915	et	4	main
sõna	doc_12501346824_item	2237916	et	4	main
eesti	doc_12501346824_item	2237917	et	4	main
kultuur	doc_12501346824_item	2237918	et	3	main
2	doc_12501346824_item	2237919	et	2	main
kui	doc_12501346824_item	2237920	et	3	main
ma	doc_12501346824_item	2237921	et	3	main
meeles	doc_12501346824_item	2237933	et	3	main
eesti	doc_12501346824_item	2237947	et	4	main
ma	doc_12501346824_item	2237949	et	3	main
oskar	doc_12501346824_item	2237959	et	4	main
mulle	doc_12501346824_item	2237962	et	4	main
lilli	doc_12501346824_item	2237964	et	4	main
mina	doc_12501346824_item	2237966	et	4	main
keeles	doc_12501346824_item	2237971	et	4	main
ma	doc_12501346824_item	2237926	et	3	main
minu	doc_12501346824_item	2237932	et	3	main
veel	doc_12501346824_item	2237942	et	4	main
kuulen	doc_12501346824_item	2237945	et	3	main
kultuur	doc_12501346824_item	2237948	et	3	main
tantsu	doc_12501346824_item	2237951	et	4	main
laulufestivaalidest	doc_12501346824_item	2237953	et	4	main
oma	doc_12501346824_item	2237956	et	4	main
kirjanik	doc_12501346824_item	2237958	et	3	main
luts	doc_12501346824_item	2237960	et	3	main
raamatuid	doc_12501346824_item	2237969	et	3	main
muudatused	doc_125394962863_item	2237976	et	3	main
2	doc_125394962863_item	2237981	et	2	main
oma	doc_125394962863_item	2237987	et	4	main
eesti	doc_125394962863_item	2237990	et	4	main
elus	doc_125394962863_item	2237992	et	4	main
toimusid	doc_125394962863_item	2237993	et	4	main
muutused	doc_125394962863_item	2237995	et	4	main
suured	doc_125394962863_item	2237994	et	3	main
taasiseseisvunud	doc_125394962863_item	2237996	et	4	main
eesti	doc_125394962863_item	2237997	et	4	main
edasiarenemine	doc_125394962863_item	2237998	et	3	main
oli	doc_125394962863_item	2237999	et	3	main
sellega	doc_125394962863_item	2238000	et	3	main
tihedalt	doc_125394962863_item	2238001	et	4	main
seotud	doc_125394962863_item	2238002	et	4	main
rõõm	doc_125394962863_item	2238003	et	3	main
sellest	doc_125394962863_item	2238004	et	4	main
et	doc_125394962863_item	2238005	et	3	main
eesti	doc_125394962863_item	2238006	et	4	main
sai	doc_125394962863_item	2238007	et	4	main
lõpuks	doc_125394962863_item	2238008	et	4	main
iseseisvaks	doc_125394962863_item	2238009	et	3	main
ei	doc_125394962863_item	2238010	et	4	main
kestnud	doc_125394962863_item	2238011	et	4	main
väga	doc_125394962863_item	2238012	et	3	main
kaua	doc_125394962863_item	2238013	et	3	main
sest	doc_125394962863_item	2238014	et	4	main
kohe	doc_125394962863_item	2238015	et	4	main
tekkisid	doc_125394962863_item	2238016	et	4	main
ka	doc_125394962863_item	2238017	et	3	main
probleemid	doc_125394962863_item	2238018	et	3	main
eesti	doc_125394962863_item	2238019	et	4	main
ei	doc_125394962863_item	2238020	et	4	main
sõltunud	doc_125394962863_item	2238021	et	4	main
nliidust	doc_125394962863_item	2238023	et	4	main
ja	doc_125394962863_item	2238024	et	3	main
aastal	doc_125394962863_item	2238030	et	3	main
kongressi	doc_125394962863_item	2238033	et	4	main
ülemnõukogu	doc_125394962863_item	2238035	et	4	main
kasutusele	doc_125394962863_item	2238037	et	4	main
hakkas	doc_125394962863_item	2238047	et	3	main
e	doc_125394962863_item	2238049	et	4	main
kontrolltöö	doc_125394962863_item	2237972	et	4	main
taasiseseisvunud	doc_125394962863_item	2237977	et	4	main
poliitilises	doc_125394962863_item	2237979	et	3	main
laulev	doc_125394962863_item	2237984	et	4	main
teel	doc_125394962863_item	2237988	et	4	main
iseseisvusele	doc_125394962863_item	2237989	et	4	main
poliitilises	doc_125394962863_item	2237991	et	3	main
1989	doc_125394962863_item	2238029	et	2	main
eesti	doc_125394962863_item	2238039	et	4	main
nimetus	doc_125394962863_item	2238041	et	4	main
ülemineku	doc_125394962863_item	2238043	et	3	main
nliit	doc_125394962863_item	2238053	et	4	main
viima	doc_125394962863_item	2238063	et	3	main
poliitikat	doc_125394962863_item	2238065	et	3	main
rohkem	doc_125394962863_item	2238108	et	4	main
maadele	doc_125394962863_item	2238110	et	4	main
ettevõtted	doc_125394962863_item	2238112	et	3	main
süsteemiga	doc_125394962863_item	2238119	et	3	main
oli	doc_125394962863_item	2238120	et	3	main
väga	doc_125394962863_item	2238127	et	3	main
kõigepealt	doc_125394962863_item	2238131	et	3	main
põhiseadus	doc_125394962863_item	2238141	et	4	main
reform	doc_125394962863_item	2238144	et	3	main
oli	doc_125394962863_item	2238151	et	3	main
inimestele	doc_125394962863_item	2238161	et	3	main
eluase	doc_125394962863_item	2238163	et	3	main
kaotasid	doc_125394962863_item	2238166	et	4	main
reformi	doc_125394962863_item	2238169	et	4	main
probleemid	doc_125394962863_item	2238171	et	3	main
sõjaväest	doc_125394962863_item	2238179	et	3	main
siis	doc_125394962863_item	2238194	et	3	main
tegutsema	doc_125394962863_item	2238197	et	3	main
revolutsioon	doc_125394962863_item	2238222	et	3	main
sai	doc_125394962863_item	2238223	et	4	main
eesti	doc_125394962863_item	2238231	et	4	main
enda	doc_125394962863_item	2238234	et	4	main
tegevus	doc_125394962863_item	2238247	et	4	main
rahvamasse	doc_125394962863_item	2238249	et	3	main
ignoreerida	doc_125394962863_item	2238258	et	3	main
ja	doc_125394962863_item	2238262	et	3	main
andis	doc_125394962863_item	2238266	et	3	main
rahvuse	doc_125394962863_item	2238268	et	3	main
kontrolltöö	doc_125394962864_item	2238270	et	4	main
1316	doc_125394962864_item	2238276	et	2	main
mida	doc_125394962864_item	2238279	et	4	main
sõdimine	doc_125394962864_item	2238285	et	4	main
saj	doc_125394962864_item	2238289	et	4	main
loobub	doc_125394962864_item	2238291	et	3	main
mille	doc_125394962864_item	2238293	et	3	main
ei	doc_125394962864_item	2238295	et	4	main
ristisõdijad	doc_125394962864_item	2238300	et	3	main
pattudest	doc_125394962864_item	2238302	et	3	main
lunastust	doc_125394962864_item	2238304	et	4	main
liivlaste	doc_125394962864_item	2238310	et	4	main
abil	doc_125394962864_item	2238312	et	4	main
sunniti	doc_125394962864_item	2238314	et	3	main
vastu	doc_125394962864_item	2238316	et	3	main
kirjakultuur	doc_125394962864_item	2238323	et	3	main
lõppes	doc_125394962864_item	2238325	et	4	main
saarlastega	doc_125394962864_item	2238328	et	4	main
lubati	doc_125394962864_item	2238338	et	3	main
muistsest	doc_125394962864_item	2238347	et	3	main
jäälahing	doc_125394962864_item	2238350	et	3	main
kiriku	doc_125394962864_item	2238359	et	3	main
võimu	doc_125394962864_item	2238370	et	4	main
piirkonnaks	doc_125394962864_item	2238376	et	4	main
feodaalriigid	doc_125394962864_item	2238381	et	4	main
põhja-eestit	doc_125394962864_item	2238388	et	3	main
läänemaa	doc_125394962864_item	2238394	et	4	main
saared	doc_125394962864_item	2238396	et	3	main
valitseda	doc_125394962864_item	2238400	et	3	main
piiskopkond	doc_125394962864_item	2238404	et	3	main
kaheks	doc_125394962864_item	2238407	et	4	main
maarahvas	doc_125394962864_item	2238408	et	4	main
maarahvas	doc_125394962864_item	2238412	et	4	main
kombed	doc_125394962864_item	2238416	et	3	main
kuni	doc_125394962864_item	2238424	et	3	main
poliitiliseks	doc_125394962864_item	2238427	et	3	main
võimuks	doc_125394962864_item	2238428	et	4	main
talupoegadelt	doc_125394962864_item	2238430	et	3	main
peaks	doc_125394962863_item	2238025	et	4	main
hakkama	doc_125394962863_item	2238027	et	3	main
toimusid	doc_125394962863_item	2238031	et	4	main
uut	doc_125394962863_item	2238045	et	3	main
siis	doc_125394962863_item	2238059	et	3	main
tähtsam	doc_125394962863_item	2238067	et	4	main
aasta	doc_125394962863_item	2238070	et	4	main
muidugi	doc_125394962863_item	2238073	et	4	main
isemajandav	doc_125394962863_item	2238076	et	3	main
vaatamata	doc_125394962863_item	2238078	et	4	main
sellele	doc_125394962863_item	2238079	et	4	main
et	doc_125394962863_item	2238080	et	3	main
see	doc_125394962863_item	2238081	et	3	main
peaks	doc_125394962863_item	2238082	et	4	main
tooma	doc_125394962863_item	2238083	et	3	main
kasu	doc_125394962863_item	2238084	et	4	main
kõigepealt	doc_125394962863_item	2238085	et	3	main
eesti	doc_125394962863_item	2238086	et	4	main
majandusele	doc_125394962863_item	2238087	et	4	main
selle	doc_125394962863_item	2238088	et	4	main
elluviimine	doc_125394962863_item	2238089	et	3	main
oli	doc_125394962863_item	2238090	et	3	main
väga	doc_125394962863_item	2238091	et	3	main
probleemne	doc_125394962863_item	2238092	et	3	main
eesti	doc_125394962863_item	2238093	et	4	main
tööstus	doc_125394962863_item	2238094	et	3	main
ja	doc_125394962863_item	2238095	et	3	main
majandus	doc_125394962863_item	2238096	et	4	main
sõltus	doc_125394962863_item	2238097	et	4	main
täiesti	doc_125394962863_item	2238098	et	3	main
nõukogude	doc_125394962863_item	2238099	et	3	main
liidust	doc_125394962863_item	2238100	et	4	main
siis	doc_125394962863_item	2238101	et	3	main
tuleks	doc_125394962863_item	2238102	et	4	main
alustada	doc_125394962863_item	2238103	et	3	main
kaubavahetuse	doc_125394962863_item	2238104	et	4	main
ümberehitamisest	doc_125394962863_item	2238105	et	3	main
tuleks	doc_125394962863_item	2238106	et	4	main
1991	doc_125394962863_item	2238051	et	2	main
iseseisvust	doc_125394962863_item	2238057	et	4	main
ellu	doc_125394962863_item	2238062	et	4	main
uut	doc_125394962863_item	2238064	et	3	main
juba	doc_125394962863_item	2238068	et	3	main
mitu	doc_125394962863_item	2238069	et	4	main
jooksul	doc_125394962863_item	2238071	et	4	main
oli	doc_125394962863_item	2238072	et	3	main
idee	doc_125394962863_item	2238075	et	4	main
eesti	doc_125394962863_item	2238077	et	4	main
paljud	doc_125394962863_item	2238111	et	3	main
läksid	doc_125394962863_item	2238113	et	4	main
ajal	doc_125394962863_item	2238115	et	4	main
aasta	doc_125394962863_item	2238125	et	4	main
tähtsaks	doc_125394962863_item	2238128	et	4	main
presidentiks	doc_125394962863_item	2238132	et	4	main
võeti	doc_125394962863_item	2238146	et	3	main
saksa	doc_125394962863_item	2238154	et	4	main
paljud	doc_125394962863_item	2238165	et	3	main
käigus	doc_125394962863_item	2238170	et	4	main
seotud	doc_125394962863_item	2238173	et	4	main
ka	doc_125394962863_item	2238174	et	3	main
vene	doc_125394962863_item	2238180	et	4	main
pidurdas	doc_125394962863_item	2238183	et	3	main
eesmärgid	doc_125394962863_item	2238193	et	3	main
nad	doc_125394962863_item	2238195	et	3	main
koos	doc_125394962863_item	2238198	et	4	main
poliitika	doc_125394962863_item	2238200	et	4	main
tähtsaks	doc_125394962863_item	2238224	et	4	main
eesti	doc_125394962863_item	2238226	et	4	main
teel	doc_125394962863_item	2238228	et	4	main
laulis	doc_125394962863_item	2238233	et	4	main
eestlased	doc_125394962863_item	2238236	et	3	main
et	doc_125394962863_item	2238238	et	3	main
on	doc_125394962863_item	2238240	et	4	main
kui	doc_125394962863_item	2238242	et	3	main
näidata	doc_125394962863_item	2238252	et	4	main
nende	doc_125394962863_item	2238260	et	4	main
1	doc_125394962864_item	2238271	et	2	main
mõjud	doc_125394962864_item	2238273	et	4	main
2	doc_125394962864_item	2238278	et	2	main
reformatsioon	doc_125394962864_item	2238281	et	3	main
kaasnes	doc_125394962864_item	2238284	et	3	main
katolik	doc_125394962864_item	2238286	et	4	main
tohi	doc_125394962864_item	2238296	et	4	main
vägivaldselt	doc_125394962864_item	2238298	et	4	main
ordu	doc_125394962864_item	2238307	et	4	main
alistati	doc_125394962864_item	2238309	et	3	main
ristiusku	doc_125394962864_item	2238315	et	4	main
oli	doc_125394962864_item	2238319	et	3	main
lääne	doc_125394962863_item	2238109	et	4	main
raske	doc_125394962863_item	2238122	et	4	main
1992	doc_125394962863_item	2238124	et	2	main
sai	doc_125394962863_item	2238126	et	4	main
sa	doc_125394962863_item	2238133	et	3	main
oli	doc_125394962863_item	2238136	et	3	main
võetud	doc_125394962863_item	2238138	et	4	main
vabariigi	doc_125394962863_item	2238140	et	3	main
raha	doc_125394962863_item	2238143	et	4	main
eesti	doc_125394962863_item	2238147	et	4	main
mille	doc_125394962863_item	2238149	et	3	main
seotud	doc_125394962863_item	2238153	et	4	main
oma	doc_125394962863_item	2238167	et	4	main
raha	doc_125394962863_item	2238168	et	4	main
eesti	doc_125394962863_item	2238176	et	4	main
balti	doc_125394962863_item	2238185	et	3	main
oli	doc_125394962863_item	2238187	et	3	main
nende	doc_125394962863_item	2238199	et	4	main
oli	doc_125394962863_item	2238201	et	3	main
juba	doc_125394962863_item	2238202	et	3	main
avatud	doc_125394962863_item	2238204	et	4	main
sõlmiti	doc_125394962863_item	2238205	et	3	main
rohkem	doc_125394962863_item	2238203	et	4	main
kontaktid	doc_125394962863_item	2238206	et	3	main
lääne	doc_125394962863_item	2238207	et	4	main
maadega	doc_125394962863_item	2238208	et	3	main
üldse	doc_125394962863_item	2238209	et	3	main
aga	doc_125394962863_item	2238210	et	3	main
toimus	doc_125394962863_item	2238211	et	3	main
elu	doc_125394962863_item	2238213	et	4	main
poliitilise	doc_125394962863_item	2238212	et	3	main
ümberehitamine	doc_125394962863_item	2238214	et	3	main
ja	doc_125394962863_item	2238215	et	3	main
algas	doc_125394962863_item	2238217	et	3	main
eesti	doc_125394962863_item	2238216	et	4	main
uut	doc_125394962863_item	2238218	et	3	main
2	doc_125394962863_item	2238220	et	2	main
elu	doc_125394962863_item	2238219	et	4	main
laulev	doc_125394962863_item	2238221	et	4	main
aastal	doc_125394962863_item	2238230	et	3	main
nad	doc_125394962863_item	2238239	et	3	main
tugevam	doc_125394962863_item	2238241	et	4	main
rahvarinne	doc_125394962863_item	2238246	et	3	main
ühendas	doc_125394962863_item	2238248	et	3	main
selgelt	doc_125394962863_item	2238251	et	4	main
eesmärke	doc_125394962863_item	2238253	et	4	main
ei	doc_125394962863_item	2238255	et	4	main
püüdlused	doc_125394962863_item	2238261	et	3	main
laulev	doc_125394962863_item	2238264	et	4	main
kirik	doc_125394962864_item	2238287	et	3	main
keskpaiku	doc_125394962864_item	2238290	et	4	main
reeglitest	doc_125394962864_item	2238292	et	4	main
ristiusustada	doc_125394962864_item	2238299	et	3	main
vajasid	doc_125394962864_item	2238301	et	4	main
mõõgavendade	doc_125394962864_item	2238306	et	3	main
lätlaste	doc_125394962864_item	2238311	et	3	main
võtma	doc_125394962864_item	2238317	et	3	main
linna-	doc_125394962864_item	2238321	et	4	main
1241	doc_125394962864_item	2238330	et	2	main
maksta	doc_125394962864_item	2238337	et	4	main
elusalt	doc_125394962864_item	2238343	et	4	main
erinesid	doc_125394962864_item	2238346	et	4	main
ajast	doc_125394962864_item	2238348	et	4	main
taanlased	doc_125394962864_item	2238361	et	3	main
siinsest	doc_125394962864_item	2238363	et	3	main
alast	doc_125394962864_item	2238364	et	4	main
sellega	doc_125394962864_item	2238365	et	3	main
killustatus	doc_125394962864_item	2238367	et	4	main
taani	doc_125394962864_item	2238369	et	4	main
jagatakse	doc_125394962864_item	2238373	et	3	main
väikesed	doc_125394962864_item	2238380	et	4	main
kesk-	doc_125394962864_item	2238382	et	3	main
ja	doc_125394962864_item	2238383	et	3	main
liivi	doc_125394962864_item	2238386	et	4	main
osa	doc_125394962864_item	2238391	et	4	main
rannikueesti	doc_125394962864_item	2238393	et	4	main
ja	doc_125394962864_item	2238395	et	3	main
tartu	doc_125394962864_item	2238403	et	4	main
rahvas	doc_125394962864_item	2238405	et	4	main
sakslane	doc_125394962864_item	2238411	et	3	main
ümberorienteeruma	doc_125394962864_item	2238415	et	4	main
tavad	doc_125394962864_item	2238417	et	3	main
jääb	doc_125394962864_item	2238422	et	3	main
aastas	doc_125394962864_item	2238434	et	3	main
lapsed	doc_125394962864_item	2238444	et	3	main
mulda	doc_125394962864_item	2238450	et	4	main
peab	doc_125394962864_item	2238452	et	4	main
talu	doc_125394962864_item	2238461	et	4	main
maa	doc_125394962864_item	2238472	et	4	main
jaotuse	doc_125394962864_item	2238474	et	4	main
1517	doc_125394962864_item	2238520	et	2	main
liivimaal	doc_125394962864_item	2238521	et	4	main
kirikuvara	doc_125394962864_item	2238527	et	4	main
üheks	doc_125394962864_item	2238534	et	3	main
kontrolltöö	doc_125394962865_item	2238539	et	4	main
ja	doc_125394962865_item	2238542	et	3	main
eesti	doc_125394962865_item	2238545	et	4	main
baltikumi	doc_125394962865_item	2238555	et	4	main
hariduselu	doc_125394962865_item	2238559	et	4	main
ajal	doc_125394962865_item	2238561	et	4	main
1	doc_125394962865_item	2238562	et	2	main
põhikooliks	doc_125394962865_item	2238585	et	4	main
varem	doc_125394962865_item	2238587	et	4	main
katedraal	doc_125394962865_item	2238589	et	3	main
õppetool	doc_125394962865_item	2238591	et	3	main
taastatakse	doc_125394962865_item	2238593	et	3	main
keelatud	doc_125394962865_item	2238600	et	4	main
ainekavadele	doc_125394962865_item	2238612	et	3	main
õpitakse	doc_125394962865_item	2238615	et	4	main
järgi	doc_125394962865_item	2238618	et	4	main
hakab	doc_125394962865_item	2238620	et	4	main
eestisse	doc_125394962865_item	2238623	et	4	main
taastati	doc_125394962865_item	2238630	et	4	main
ainuke	doc_125394962865_item	2238636	et	4	main
kuhu	doc_125394962865_item	2238638	et	3	main
nii	doc_125394962865_item	2238640	et	3	main
kui	doc_125394962865_item	2238642	et	3	main
soost	doc_125394962865_item	2238644	et	4	main
et	doc_125394962865_item	2238654	et	3	main
kasutusele	doc_125394962865_item	2238658	et	4	main
taastati	doc_125394962865_item	2238661	et	4	main
mõju	doc_125394962865_item	2238683	et	4	main
rääkida	doc_125394962865_item	2238689	et	3	main
kasutama	doc_125394962865_item	2238692	et	3	main
pääsemiseks	doc_125394962864_item	2238303	et	4	main
rüüstades	doc_125394962864_item	2238313	et	4	main
feodaalkord	doc_125394962864_item	2238320	et	4	main
ja	doc_125394962864_item	2238322	et	3	main
ristiusustamine	doc_125394962864_item	2238324	et	3	main
saaremaa	doc_125394962864_item	2238326	et	4	main
kirjalik	doc_125394962864_item	2238331	et	3	main
saarlased	doc_125394962864_item	2238333	et	3	main
teraviljas	doc_125394962864_item	2238339	et	3	main
tabatu	doc_125394962864_item	2238341	et	4	main
kirjalikud	doc_125394962864_item	2238345	et	3	main
1242	doc_125394962864_item	2238349	et	2	main
eestlaste	doc_125394962864_item	2238351	et	4	main
kreeka-rooma	doc_125394962864_item	2238358	et	4	main
kaasneb	doc_125394962864_item	2238366	et	3	main
all	doc_125394962864_item	2238371	et	3	main
4	doc_125394962864_item	2238374	et	2	main
valitseja	doc_125394962864_item	2238379	et	4	main
lõuna-eesti	doc_125394962864_item	2238384	et	4	main
moodustatakse	doc_125394962864_item	2238402	et	3	main
mentaliteet	doc_125394962864_item	2238418	et	3	main
1202	doc_125394962864_item	2238305	et	2	main
eestlased	doc_125394962864_item	2238308	et	3	main
uus	doc_125394962864_item	2238318	et	3	main
alistamine	doc_125394962864_item	2238327	et	4	main
leping	doc_125394962864_item	2238332	et	3	main
vabatahtlikult	doc_125394962864_item	2238335	et	4	main
varguselt	doc_125394962864_item	2238340	et	3	main
piirid	doc_125394962864_item	2238360	et	3	main
huvitatud	doc_125394962864_item	2238362	et	4	main
eesti	doc_125394962864_item	2238368	et	4	main
eesti	doc_125394962864_item	2238372	et	4	main
igaühel	doc_125394962864_item	2238377	et	3	main
oma	doc_125394962864_item	2238378	et	4	main
ordule	doc_125394962864_item	2238387	et	3	main
jääb	doc_125394962864_item	2238389	et	3	main
saare-lääne	doc_125394962864_item	2238398	et	4	main
piiskopkonna	doc_125394962864_item	2238399	et	3	main
kagu-eestis	doc_125394962864_item	2238401	et	3	main
eestlane	doc_125394962864_item	2238409	et	3	main
on	doc_125394962864_item	2238413	et	4	main
sunnitud	doc_125394962864_item	2238414	et	4	main
ühiskondlik	doc_125394962864_item	2238419	et	3	main
kord	doc_125394962864_item	2238420	et	4	main
16	doc_125394962864_item	2238425	et	2	main
hakatakse	doc_125394962864_item	2238431	et	3	main
ehitama	doc_125394962864_item	2238437	et	4	main
kirikud	doc_125394962864_item	2238439	et	3	main
sündides	doc_125394962864_item	2238445	et	4	main
surnud	doc_125394962864_item	2238447	et	4	main
pühitsetudõnnistatud	doc_125394962864_item	2238449	et	4	main
talurahvas	doc_125394962864_item	2238451	et	4	main
ülemkihti	doc_125394962864_item	2238453	et	4	main
varustama	doc_125394962864_item	2238455	et	3	main
ümber	doc_125394962864_item	2238471	et	3	main
misjonitööga	doc_125394962864_item	2238479	et	3	main
luther	doc_125394962864_item	2238513	et	4	main
reformatsioon	doc_125394962864_item	2238517	et	3	main
sõlmiti	doc_125394962864_item	2238329	et	3	main
pöörduvad	doc_125394962864_item	2238334	et	4	main
ristiusku	doc_125394962864_item	2238336	et	4	main
maeti	doc_125394962864_item	2238342	et	3	main
seadused	doc_125394962864_item	2238344	et	3	main
ja	doc_125394962864_item	2238352	et	3	main
venelaste	doc_125394962864_item	2238353	et	4	main
valul	doc_125394962864_item	2238354	et	3	main
peipsil	doc_125394962864_item	2238355	et	4	main
see	doc_125394962864_item	2238356	et	3	main
otsustab	doc_125394962864_item	2238357	et	3	main
omaette	doc_125394962864_item	2238375	et	3	main
kuulub	doc_125394962864_item	2238385	et	3	main
mingi	doc_125394962864_item	2238390	et	4	main
taanile	doc_125394962864_item	2238392	et	4	main
jäävad	doc_125394962864_item	2238397	et	4	main
kujuneb	doc_125394962864_item	2238406	et	3	main
ülemkiht	doc_125394962864_item	2238410	et	3	main
stabiilne	doc_125394962864_item	2238421	et	3	main
püsima	doc_125394962864_item	2238423	et	3	main
saj	doc_125394962864_item	2238426	et	4	main
ordu	doc_125394962864_item	2238429	et	4	main
kord	doc_125394962864_item	2238433	et	4	main
kümnist	doc_125394962864_item	2238435	et	3	main
peavad	doc_125394962864_item	2238441	et	4	main
mitmenaisepidamisest	doc_125394962864_item	2238443	et	3	main
aastaks	doc_125394962864_item	2238465	et	4	main
kasvavad	doc_125394962864_item	2238468	et	4	main
kirikukihelkond	doc_125394962864_item	2238475	et	3	main
rändmungad	doc_125394962864_item	2238476	et	3	main
muuta	doc_125394962864_item	2238516	et	4	main
algas	doc_125394962864_item	2238518	et	3	main
1521	doc_125394962864_item	2238522	et	2	main
purustati	doc_125394962864_item	2238524	et	3	main
lõhuti	doc_125394962864_item	2238526	et	3	main
kirikureformid	doc_125394962864_item	2238528	et	3	main
nõudsid	doc_125394962864_item	2238529	et	4	main
patu	doc_125394962864_item	2238531	et	3	main
reformatsiooni	doc_125394962864_item	2238533	et	4	main
muutused	doc_125394962865_item	2238541	et	4	main
kultuurielus	doc_125394962865_item	2238546	et	4	main
mis	doc_125394962865_item	2238548	et	4	main
sündmus	doc_125394962865_item	2238549	et	3	main
balti	doc_125394962865_item	2238551	et	3	main
ja	doc_125394962865_item	2238557	et	3	main
muudeti	doc_125394962865_item	2238563	et	3	main
gümnaasiumiks	doc_125394962865_item	2238582	et	3	main
klass	doc_125394962865_item	2238584	et	3	main
mõned	doc_125394962865_item	2238594	et	3	main
nl-s	doc_125394962865_item	2238598	et	3	main
on	doc_125394962865_item	2238605	et	4	main
kursuse	doc_125394962865_item	2238608	et	3	main
minnakse	doc_125394962865_item	2238610	et	3	main
välismaalt	doc_125394962865_item	2238626	et	3	main
korporatsiooni	doc_125394962865_item	2238631	et	4	main
mees-	doc_125394962865_item	2238641	et	4	main
naiss	doc_125394962865_item	2238643	et	4	main
kaob	doc_125394962865_item	2238646	et	3	main
räägitakse	doc_125394962865_item	2238651	et	3	main
uuesti	doc_125394962865_item	2238657	et	3	main
erialaseltse	doc_125394962865_item	2238663	et	3	main
ei	doc_125394962865_item	2238687	et	4	main
eestis	doc_125394962865_item	2238699	et	3	main
on	doc_125394962865_item	2238713	et	4	main
piiriäärne	doc_125394962865_item	2238714	et	3	main
kaua	doc_125394962865_item	2238718	et	3	main
hakatakse	doc_125394962864_item	2238436	et	3	main
tööoskused	doc_125394962864_item	2238457	et	3	main
maaharimine	doc_125394962864_item	2238459	et	3	main
jääb	doc_125394962864_item	2238463	et	3	main
korraldab	doc_125394962864_item	2238470	et	3	main
adminastriinse	doc_125394962864_item	2238473	et	4	main
valdavalt	doc_125394962864_item	2238478	et	4	main
pakkusid	doc_125394962864_item	2238480	et	4	main
rahvale	doc_125394962864_item	2238481	et	3	main
ka	doc_125394962864_item	2238482	et	3	main
arstiabi	doc_125394962864_item	2238483	et	4	main
uusi	doc_125394962864_item	2238485	et	3	main
töövõtteid	doc_125394962864_item	2238486	et	3	main
õpetasid	doc_125394962864_item	2238484	et	4	main
haridus	doc_125394962864_item	2238487	et	3	main
seotud	doc_125394962864_item	2238488	et	4	main
kirikuga	doc_125394962864_item	2238489	et	3	main
keskajal	doc_125394962864_item	2238490	et	3	main
2	doc_125394962864_item	2238491	et	2	main
katoliku	doc_125394962864_item	2238492	et	3	main
kiriku	doc_125394962864_item	2238493	et	3	main
eesmärgiks	doc_125394962864_item	2238494	et	3	main
tundus	doc_125394962864_item	2238495	et	3	main
olevat	doc_125394962864_item	2238496	et	4	main
ainult	doc_125394962864_item	2238497	et	4	main
materjaalne	doc_125394962864_item	2238498	et	4	main
rikastumine	doc_125394962864_item	2238499	et	4	main
nõudis	doc_125394962864_item	2238500	et	3	main
kõigilt	doc_125394962864_item	2238501	et	4	main
makse	doc_125394962864_item	2238502	et	4	main
raha	doc_125394962864_item	2238503	et	4	main
vara	doc_125394962864_item	2238504	et	4	main
vaimu	doc_125394962864_item	2238505	et	4	main
ja	doc_125394962864_item	2238506	et	3	main
hingega	doc_125394962864_item	2238507	et	3	main
tegeleti	doc_125394962864_item	2238508	et	3	main
vähe	doc_125394962864_item	2238509	et	3	main
kirik	doc_125394962864_item	2238510	et	3	main
ilmastus	doc_125394962864_item	2238511	et	3	main
m	doc_125394962864_item	2238512	et	4	main
nõudma	doc_125394962864_item	2238432	et	3	main
kabeleid	doc_125394962864_item	2238438	et	4	main
kloostreid	doc_125394962864_item	2238440	et	3	main
loobuma	doc_125394962864_item	2238442	et	3	main
ristima	doc_125394962864_item	2238446	et	4	main
matma	doc_125394962864_item	2238448	et	3	main
toiduga	doc_125394962864_item	2238454	et	3	main
uued	doc_125394962864_item	2238456	et	3	main
käsitöö	doc_125394962864_item	2238458	et	4	main
küla	doc_125394962864_item	2238460	et	4	main
agraarühiskond	doc_125394962864_item	2238462	et	3	main
mitmesajaks	doc_125394962864_item	2238464	et	3	main
linnad	doc_125394962864_item	2238466	et	3	main
muudkui	doc_125394962864_item	2238467	et	3	main
kirik	doc_125394962864_item	2238469	et	3	main
tegelesid	doc_125394962864_item	2238477	et	4	main
tahtis	doc_125394962864_item	2238514	et	3	main
olukorda	doc_125394962864_item	2238515	et	4	main
kohalikelt	doc_125394962864_item	2238530	et	3	main
õppimist	doc_125394962864_item	2238532	et	4	main
nõudeks	doc_125394962864_item	2238535	et	4	main
jumalateenistus	doc_125394962864_item	2238538	et	3	main
muudatused	doc_125394962865_item	2238543	et	3	main
oli	doc_125394962865_item	2238550	et	3	main
rahavstele	doc_125394962865_item	2238556	et	4	main
maailmale	doc_125394962865_item	2238558	et	4	main
oli	doc_125394962865_item	2238588	et	3	main
nüüd	doc_125394962865_item	2238590	et	4	main
olid	doc_125394962865_item	2238599	et	4	main
nt	doc_125394962865_item	2238601	et	4	main
usuteadus	doc_125394962865_item	2238602	et	4	main
ülikoolides	doc_125394962865_item	2238604	et	3	main
süsteemist	doc_125394962865_item	2238609	et	4	main
üle	doc_125394962865_item	2238611	et	3	main
aastal	doc_125394962865_item	2238614	et	3	main
32	doc_125394962865_item	2238616	et	2	main
4	doc_125394962865_item	2238619	et	2	main
saksamaal	doc_125394962864_item	2238519	et	4	main
ikoone	doc_125394962864_item	2238525	et	3	main
oli	doc_125394962864_item	2238536	et	3	main
taasiseseisvunud	doc_125394962865_item	2238544	et	4	main
2	doc_125394962865_item	2238547	et	2	main
selle	doc_125394962865_item	2238553	et	4	main
1-9	doc_125394962865_item	2238583	et	2	main
2	doc_125394962865_item	2238592	et	2	main
mis	doc_125394962865_item	2238596	et	4	main
3	doc_125394962865_item	2238603	et	2	main
süsteem	doc_125394962865_item	2238607	et	3	main
programmi	doc_125394962865_item	2238617	et	4	main
toimuma	doc_125394962865_item	2238621	et	3	main
ja	doc_125394962865_item	2238627	et	3	main
vastupidi	doc_125394962865_item	2238628	et	3	main
kultuuri	doc_125394962865_item	2238632	et	4	main
kuulusid	doc_125394962865_item	2238639	et	4	main
kuigi	doc_125394962865_item	2238648	et	3	main
koolivormi	doc_125394962865_item	2238655	et	4	main
7	doc_125394962865_item	2238660	et	2	main
avaldas	doc_125394962865_item	2238681	et	3	main
kultuurilelule	doc_125394962865_item	2238684	et	3	main
regionaalkeelt	doc_125394962865_item	2238686	et	4	main
tohtinud	doc_125394962865_item	2238688	et	4	main
pidid	doc_125394962865_item	2238691	et	4	main
taasiseseisvunud	doc_125394962865_item	2238698	et	4	main
ka	doc_125394962865_item	2238701	et	3	main
õpetama	doc_125394962865_item	2238703	et	3	main
pidada	doc_125394962865_item	2238709	et	4	main
setu	doc_125394962865_item	2238710	et	4	main
õigeusu	doc_125394962865_item	2238719	et	3	main
keel	doc_125394962865_item	2238728	et	4	main
kultuur	doc_125394962865_item	2238729	et	3	main
kõrgkultuur	doc_125394962865_item	2238731	et	3	main
pöördusid	doc_125394962865_item	2238734	et	4	main
ja	doc_125394962865_item	2238737	et	3	main
nt	doc_125394962865_item	2238743	et	4	main
kangro	doc_125394962865_item	2238757	et	4	main
preemia	doc_125394962865_item	2238759	et	4	main
igalpool	doc_125394962865_item	2238766	et	4	main
mobiiltelefone	doc_125394962865_item	2238771	et	3	main
kasutamine	doc_125394962865_item	2238774	et	4	main
on	doc_125394962865_item	2238775	et	4	main
infot	doc_125394962865_item	2238779	et	3	main
ajal	doc_125394962865_item	2238783	et	4	main
keele	doc_125394962865_item	2238794	et	4	main
võib	doc_125394962865_item	2238800	et	3	main
juba	doc_125394962865_item	2238803	et	3	main
ja	doc_125394962865_item	2238807	et	3	main
suureks	doc_125394962865_item	2238813	et	4	main
aga	doc_125394962865_item	2238816	et	3	main
et	doc_125394962865_item	2238818	et	3	main
pildirüüsted	doc_125394962864_item	2238523	et	3	main
emakeelne	doc_125394962864_item	2238537	et	3	main
1	doc_125394962865_item	2238540	et	2	main
kett	doc_125394962865_item	2238552	et	4	main
tähendus	doc_125394962865_item	2238554	et	4	main
taasiseseisvuse	doc_125394962865_item	2238560	et	4	main
paljud	doc_125394962865_item	2238564	et	3	main
nimetused	doc_125394962865_item	2238565	et	4	main
nt	doc_125394962865_item	2238566	et	4	main
tr	doc_125394962865_item	2238567	et	4	main
tü	doc_125394962865_item	2238568	et	4	main
koolidele	doc_125394962865_item	2238569	et	3	main
pandi	doc_125394962865_item	2238570	et	4	main
ka	doc_125394962865_item	2238571	et	3	main
uued	doc_125394962865_item	2238572	et	3	main
nimed	doc_125394962865_item	2238573	et	3	main
kasutusele	doc_125394962865_item	2238574	et	4	main
tuli	doc_125394962865_item	2238575	et	4	main
uus	doc_125394962865_item	2238576	et	3	main
mõiste	doc_125394962865_item	2238577	et	4	main
kolledž	doc_125394962865_item	2238578	et	2	main
keskkooli	doc_125394962865_item	2238579	et	4	main
hakatakse	doc_125394962865_item	2238580	et	3	main
nimetama	doc_125394962865_item	2238581	et	3	main
ülikoolides	doc_125394962865_item	2238586	et	3	main
teaduskonnad	doc_125394962865_item	2238595	et	4	main
varem	doc_125394962865_item	2238597	et	4	main
uus	doc_125394962865_item	2238606	et	3	main
viimasel	doc_125394962865_item	2238613	et	3	main
5	doc_125394962865_item	2238629	et	2	main
6	doc_125394962865_item	2238645	et	2	main
koolivorm	doc_125394962865_item	2238647	et	3	main
juba	doc_125394962865_item	2238650	et	3	main
sellest	doc_125394962865_item	2238653	et	4	main
võtta	doc_125394962865_item	2238659	et	3	main
ka	doc_125394962865_item	2238662	et	3	main
nt	doc_125394962865_item	2238664	et	4	main
poliitika	doc_125394962865_item	2238680	et	4	main
nl-s	doc_125394962865_item	2238685	et	3	main
üht	doc_125394962865_item	2238693	et	3	main
keelt	doc_125394962865_item	2238696	et	4	main
hakati	doc_125394962865_item	2238700	et	3	main
peaaegu	doc_125394962865_item	2238705	et	3	main
see	doc_125394962865_item	2238712	et	3	main
kes	doc_125394962865_item	2238716	et	4	main
mõju	doc_125394962865_item	2238720	et	4	main
ja	doc_125394962865_item	2238722	et	3	main
on	doc_125394962865_item	2238724	et	4	main
inimestel	doc_125394962865_item	2238726	et	3	main
välismaalt	doc_125394962865_item	2238735	et	3	main
arvo	doc_125394962865_item	2238744	et	4	main
neeme	doc_125394962865_item	2238746	et	4	main
kirjaniketele	doc_125394962865_item	2238750	et	4	main
andma	doc_125394962865_item	2238752	et	3	main
nt	doc_125394962865_item	2238754	et	4	main
nimeline	doc_125394962865_item	2238758	et	4	main
kasutama	doc_125394962865_item	2238768	et	3	main
aga	doc_125394962865_item	2238772	et	3	main
õigel	doc_125394962865_item	2238782	et	3	main
uuesti	doc_125394962865_item	2238789	et	3	main
tööd	doc_125394962865_item	2238791	et	4	main
ajal	doc_125394962865_item	2238799	et	4	main
sellel	doc_125394962865_item	2238804	et	4	main
eesti	doc_125394962865_item	2238808	et	4	main
probleemiks	doc_125394962865_item	2238814	et	4	main
eestis	doc_125394962865_item	2238819	et	3	main
40	doc_125394962865_item	2238822	et	2	main
poliitilise	doc_125394962865_item	2238826	et	3	main
tagapoole	doc_125394962865_item	2238836	et	4	main
vanad	doc_125394962865_item	2238837	et	3	main
hakatakse	doc_125394962865_item	2238846	et	3	main
üsna	doc_125394962865_item	2238851	et	3	main
sai	doc_125394962865_item	2238859	et	4	main
narkomaania	doc_125394962865_item	2238861	et	4	main
tegelevad	doc_125394962865_item	2238864	et	4	main
millioni	doc_125394962865_item	2238876	et	4	main
kättest	doc_125394962865_item	2238887	et	4	main
nad	doc_125394962865_item	2238891	et	3	main
see	doc_125394962865_item	2238897	et	3	main
välisvahetus	doc_125394962865_item	2238622	et	4	main
tuleb	doc_125394962865_item	2238624	et	3	main
õpilase	doc_125394962865_item	2238625	et	3	main
nt	doc_125394962865_item	2238633	et	4	main
eüs	doc_125394962865_item	2238634	et	4	main
veljesto	doc_125394962865_item	2238635	et	4	main
selts	doc_125394962865_item	2238637	et	3	main
praegu	doc_125394962865_item	2238649	et	3	main
palju	doc_125394962865_item	2238652	et	4	main
võiks	doc_125394962865_item	2238656	et	4	main
ões	doc_125394962865_item	2238665	et	4	main
ars	doc_125394962865_item	2238666	et	4	main
ats	doc_125394962865_item	2238667	et	3	main
mõned	doc_125394962865_item	2238668	et	3	main
andsid	doc_125394962865_item	2238669	et	4	main
välja	doc_125394962865_item	2238670	et	4	main
ka	doc_125394962865_item	2238671	et	3	main
oma	doc_125394962865_item	2238672	et	4	main
ajakirju	doc_125394962865_item	2238673	et	4	main
püüdsid	doc_125394962865_item	2238675	et	4	main
normaliseeruda	doc_125394962865_item	2238676	et	3	main
nad	doc_125394962865_item	2238674	et	3	main
kultuurisuhted	doc_125394962865_item	2238677	et	3	main
välismaaga	doc_125394962865_item	2238678	et	3	main
regionaalne	doc_125394962865_item	2238679	et	3	main
ka	doc_125394962865_item	2238682	et	3	main
kõik	doc_125394962865_item	2238690	et	4	main
murreid	doc_125394962865_item	2238702	et	4	main
näiteks	doc_125394962865_item	2238704	et	4	main
eraldi	doc_125394962865_item	2238706	et	4	main
võib	doc_125394962865_item	2238708	et	3	main
rahva	doc_125394962865_item	2238711	et	3	main
paljud	doc_125394962865_item	2238732	et	3	main
kodumaale	doc_125394962865_item	2238736	et	4	main
tutvustavad	doc_125394962865_item	2238738	et	4	main
oma	doc_125394962865_item	2238741	et	4	main
hakati	doc_125394962865_item	2238751	et	3	main
selle	doc_125394962865_item	2238760	et	4	main
ka	doc_125394962865_item	2238763	et	3	main
hakati	doc_125394962865_item	2238767	et	3	main
arvutit	doc_125394962865_item	2238769	et	3	main
arvutite	doc_125394962865_item	2238773	et	4	main
kõik	doc_125394962865_item	2238784	et	4	main
siis	doc_125394962865_item	2238787	et	3	main
eesti	doc_125394962865_item	2238793	et	4	main
integratsiooni	doc_125394962865_item	2238796	et	4	main
potentsiaalsed	doc_125394962865_item	2238810	et	3	main
kurssi	doc_125394962865_item	2238827	et	4	main
õigesti	doc_125394962865_item	2238828	et	3	main
aga	doc_125394962865_item	2238840	et	3	main
poole	doc_125394962865_item	2238845	et	4	main
nende	doc_125394962865_item	2238855	et	4	main
eest	doc_125394962865_item	2238856	et	4	main
2	doc_125394962865_item	2238866	et	2	main
nn	doc_125394962865_item	2238869	et	4	main
elanikku	doc_125394962865_item	2238881	et	4	main
ketti	doc_125394962865_item	2238884	et	4	main
kõik	doc_125394962865_item	2238886	et	4	main
tahtsid	doc_125394962865_item	2238890	et	4	main
püüdlust	doc_125394962865_item	2238895	et	3	main
vabadusele	doc_125394962865_item	2238896	et	4	main
sündmus	doc_125394962865_item	2238898	et	3	main
tähelepanu	doc_125394962865_item	2238902	et	4	main
referaat	doc_13389385120_item	2238998	et	3	main
eesti	doc_13389385120_item	2239004	et	4	main
võõrkelena	doc_13389385120_item	2239006	et	4	main
rahvuspärimuse	doc_13389385120_item	2239011	et	3	main
õppimine	doc_13389385120_item	2239014	et	4	main
tallinn	doc_13389385120_item	2239018	et	4	main
lk2	doc_13389385120_item	2239021	et	4	main
sissejuhatus	doc_13389385120_item	2239024	et	4	main
õpetamine	doc_13389385120_item	2239027	et	4	main
11eesti	doc_13389385120_item	2239029	et	4	main
ja	doc_13389385120_item	2239031	et	3	main
teda	doc_13389385120_item	2239032	et	4	main
tegurid	doc_13389385120_item	2239034	et	3	main
eesti	doc_13389385120_item	2239037	et	4	main
sissejuhatus	doc_13389385120_item	2239042	et	4	main
13	doc_13389385120_item	2239044	et	2	main
kooliõppekava	doc_13389385120_item	2239051	et	4	main
õiget	doc_125394962865_item	2238694	et	3	main
eesti	doc_125394962865_item	2238695	et	4	main
nüüd	doc_125394962865_item	2238697	et	4	main
rahvaks	doc_125394962865_item	2238707	et	3	main
rahvas	doc_125394962865_item	2238715	et	4	main
oli	doc_125394962865_item	2238717	et	3	main
sfääris	doc_125394962865_item	2238721	et	3	main
seetõttu	doc_125394962865_item	2238723	et	3	main
kirjanikud	doc_125394962865_item	2238733	et	3	main
eesti	doc_125394962865_item	2238740	et	4	main
kultuuri	doc_125394962865_item	2238742	et	4	main
b	doc_125394962865_item	2238756	et	4	main
kiire	doc_125394962865_item	2238764	et	4	main
telefoni	doc_125394962865_item	2238770	et	4	main
ka	doc_125394962865_item	2238776	et	3	main
kui	doc_125394962865_item	2238778	et	3	main
salvesta	doc_125394962865_item	2238781	et	4	main
kaduda	doc_125394962865_item	2238786	et	3	main
peab	doc_125394962865_item	2238788	et	4	main
sama	doc_125394962865_item	2238790	et	4	main
ja	doc_125394962865_item	2238795	et	3	main
taasiseseisvuse	doc_125394962865_item	2238798	et	4	main
et	doc_125394962865_item	2238802	et	3	main
ajal	doc_125394962865_item	2238805	et	4	main
oli	doc_125394962865_item	2238809	et	3	main
see	doc_125394962865_item	2238817	et	3	main
nt	doc_125394962865_item	2238820	et	4	main
oli	doc_125394962865_item	2238821	et	3	main
sest	doc_125394962865_item	2238830	et	4	main
keskealised	doc_125394962865_item	2238833	et	4	main
arusaamad	doc_125394962865_item	2238839	et	3	main
noored	doc_125394962865_item	2238841	et	3	main
rohkem	doc_125394962865_item	2238847	et	4	main
pööratakse	doc_125394962865_item	2238849	et	3	main
palju	doc_125394962865_item	2238852	et	4	main
ka	doc_125394962865_item	2238860	et	3	main
samuti	doc_125394962865_item	2238863	et	3	main
sotsiaaltöötajad	doc_125394962865_item	2238865	et	3	main
23089	doc_125394962865_item	2238867	et	2	main
leedu	doc_125394962865_item	2238880	et	4	main
moodustasid	doc_125394962865_item	2238882	et	4	main
kinni	doc_125394962865_item	2238888	et	3	main
maailmale	doc_125394962865_item	2238892	et	4	main
tõesti	doc_125394962865_item	2238900	et	3	main
baltikumi	doc_125394962865_item	2238903	et	4	main
filoloogia	doc_13389385120_item	2239002	et	4	main
ja	doc_13389385120_item	2239007	et	3	main
eesti	doc_13389385120_item	2239008	et	4	main
ja	doc_13389385120_item	2239013	et	3	main
koolis	doc_13389385120_item	2239016	et	4	main
sisukord	doc_13389385120_item	2239022	et	3	main
keele	doc_13389385120_item	2239038	et	4	main
riigiõppekava	doc_13389385120_item	2239039	et	4	main
121	doc_13389385120_item	2239041	et	2	main
tallinna	doc_13389385120_item	2239045	et	4	main
vene	doc_13389385120_item	2239047	et	4	main
2õppimine	doc_13389385120_item	2239053	et	4	main
sissejuhatus	doc_13389385120_item	2239073	et	4	main
oma	doc_13389385120_item	2239074	et	4	main
ma	doc_13389385120_item	2239076	et	3	main
ja	doc_13389385120_item	2239082	et	3	main
valinud	doc_13389385120_item	2239087	et	4	main
teema	doc_13389385120_item	2239089	et	4	main
et	doc_13389385120_item	2239091	et	3	main
pakub	doc_13389385120_item	2239093	et	3	main
peale	doc_13389385120_item	2239099	et	4	main
hakkama	doc_13389385120_item	2239102	et	3	main
ning	doc_13389385120_item	2239104	et	3	main
minu	doc_13389385120_item	2239106	et	3	main
on	doc_13389385120_item	2239108	et	4	main
ja	doc_13389385120_item	2239112	et	3	main
nendel	doc_125394962865_item	2238725	et	4	main
oma	doc_125394962865_item	2238727	et	4	main
kombed	doc_125394962865_item	2238730	et	3	main
nüüd	doc_125394962865_item	2238739	et	4	main
part	doc_125394962865_item	2238745	et	4	main
järvi	doc_125394962865_item	2238747	et	4	main
b	doc_125394962865_item	2238748	et	4	main
kangro	doc_125394962865_item	2238749	et	4	main
preemiat	doc_125394962865_item	2238753	et	3	main
oli	doc_125394962865_item	2238755	et	3	main
aja	doc_125394962865_item	2238761	et	4	main
iseloomustab	doc_125394962865_item	2238762	et	4	main
tehtikaareng	doc_125394962865_item	2238765	et	4	main
ohtlik	doc_125394962865_item	2238777	et	3	main
ei	doc_125394962865_item	2238780	et	4	main
võib	doc_125394962865_item	2238785	et	3	main
tegema	doc_125394962865_item	2238792	et	3	main
poliitika	doc_125394962865_item	2238797	et	4	main
öelda	doc_125394962865_item	2238801	et	4	main
läti	doc_125394962865_item	2238806	et	4	main
el	doc_125394962865_item	2238811	et	4	main
liikmed	doc_125394962865_item	2238812	et	3	main
oli	doc_125394962865_item	2238815	et	3	main
raske	doc_125394962865_item	2238824	et	4	main
oli	doc_125394962865_item	2238825	et	3	main
vaatasid	doc_125394962865_item	2238842	et	4	main
euroopa	doc_125394962865_item	2238844	et	4	main
tööd	doc_125394962865_item	2238853	et	4	main
umbes	doc_125394962865_item	2238874	et	4	main
ja	doc_125394962865_item	2238879	et	3	main
võetes	doc_125394962865_item	2238885	et	4	main
näidata	doc_125394962865_item	2238893	et	4	main
oma	doc_125394962865_item	2238894	et	4	main
pööras	doc_125394962865_item	2238899	et	4	main
suurt	doc_125394962865_item	2238901	et	3	main
probleemidele	doc_125394962865_item	2238904	et	3	main
ülikool	doc_13389385120_item	2239000	et	4	main
seminaritöö	doc_13389385120_item	2239017	et	4	main
muulasi	doc_125394962865_item	2238823	et	4	main
valida	doc_125394962865_item	2238829	et	3	main
vanad	doc_125394962865_item	2238831	et	3	main
ja	doc_125394962865_item	2238832	et	3	main
vaatasid	doc_125394962865_item	2238834	et	4	main
veel	doc_125394962865_item	2238835	et	4	main
kommed	doc_125394962865_item	2238838	et	4	main
ettepoole	doc_125394962865_item	2238843	et	3	main
tähelepanu	doc_125394962865_item	2238848	et	4	main
sotsiaalprobleemidele	doc_125394962865_item	2238850	et	3	main
saavad	doc_125394962865_item	2238854	et	4	main
suureks	doc_125394962865_item	2238857	et	4	main
probleemiks	doc_125394962865_item	2238858	et	4	main
millega	doc_125394962865_item	2238862	et	3	main
toimus	doc_125394962865_item	2238868	et	3	main
balti	doc_125394962865_item	2238870	et	3	main
kett	doc_125394962865_item	2238871	et	4	main
sellel	doc_125394962865_item	2238872	et	4	main
päeval	doc_125394962865_item	2238873	et	3	main
2	doc_125394962865_item	2238875	et	2	main
eesti	doc_125394962865_item	2238877	et	4	main
läti	doc_125394962865_item	2238878	et	4	main
pikka	doc_125394962865_item	2238883	et	4	main
sellega	doc_125394962865_item	2238889	et	3	main
tallinna	doc_13389385120_item	2238999	et	4	main
keel	doc_13389385120_item	2239005	et	4	main
kultuur	doc_13389385120_item	2239009	et	3	main
sisukord	doc_13389385120_item	2239020	et	3	main
lk6	doc_13389385120_item	2239040	et	4	main
õismäe	doc_13389385120_item	2239046	et	3	main
kasutatud	doc_13389385120_item	2239070	et	4	main
venekeelses	doc_13389385120_item	2239084	et	3	main
olen	doc_13389385120_item	2239086	et	3	main
sellepärast	doc_13389385120_item	2239090	et	3	main
ma	doc_13389385120_item	2239097	et	3	main
ülikooli	doc_13389385120_item	2239100	et	4	main
kooliõpetajaks	doc_13389385120_item	2239103	et	3	main
õppekavas	doc_13389385120_item	2239107	et	3	main
ka	doc_13389385120_item	2239109	et	3	main
koolis	doc_13389385120_item	2239117	et	4	main
on	doc_13389385120_item	2239130	et	4	main
selles	doc_13389385120_item	2239132	et	4	main
teema	doc_13389385120_item	2239134	et	4	main
mulle	doc_13389385120_item	2239136	et	4	main
aktuaalne	doc_13389385120_item	2239139	et	3	main
räägitakse	doc_13389385120_item	2239142	et	3	main
toimub	doc_13389385120_item	2239149	et	3	main
probleemid	doc_13389385120_item	2239154	et	3	main
tekivad	doc_13389385120_item	2239163	et	3	main
on	doc_13389385120_item	2239166	et	4	main
et	doc_13389385120_item	2239169	et	3	main
tähelepanu	doc_13389385120_item	2239174	et	4	main
minu	doc_13389385120_item	2239178	et	3	main
mida	doc_13389385120_item	2239183	et	4	main
on	doc_13389385120_item	2239193	et	4	main
raskusi	doc_13389385120_item	2239195	et	4	main
et	doc_13389385120_item	2239197	et	3	main
mis	doc_13389385120_item	2239230	et	4	main
ja	doc_13389385120_item	2239247	et	3	main
kasutan	doc_13389385120_item	2239252	et	3	main
samas	doc_13389385120_item	2239255	et	4	main
õpetamine	doc_13389385120_item	2239263	et	4	main
eesti	doc_13389385120_item	2239270	et	4	main
seisnud	doc_13389385120_item	2239272	et	4	main
mõistmiseks	doc_13389385120_item	2239300	et	4	main
on	doc_13389385120_item	2239305	et	4	main
väikese	doc_13389385120_item	2239307	et	4	main
ja	doc_13389385120_item	2239315	et	3	main
vaimuilm	doc_13389385120_item	2239323	et	3	main
tegelased	doc_13389385120_item	2239331	et	3	main
mõlematega	doc_13389385120_item	2239333	et	3	main
hästi	doc_13389385120_item	2239335	et	3	main
rahvapärimuse	doc_13389385120_item	2239338	et	3	main
seisukohalt	doc_13389385120_item	2239339	et	4	main
eesti	doc_13389385120_item	2239001	et	4	main
teaduskond	doc_13389385120_item	2239003	et	3	main
eesti	doc_13389385120_item	2239010	et	4	main
õpetamine	doc_13389385120_item	2239012	et	4	main
venekeelses	doc_13389385120_item	2239015	et	3	main
2005	doc_13389385120_item	2239019	et	2	main
lk3	doc_13389385120_item	2239023	et	4	main
lk4	doc_13389385120_item	2239025	et	4	main
lk4	doc_13389385120_item	2239028	et	4	main
rahvuspärimus	doc_13389385120_item	2239030	et	3	main
lk6	doc_13389385120_item	2239035	et	4	main
lk8	doc_13389385120_item	2239043	et	4	main
lütseumi	doc_13389385120_item	2239048	et	4	main
valinud	doc_13389385120_item	2239078	et	4	main
ta	doc_13389385120_item	2239092	et	4	main
mulle	doc_13389385120_item	2239094	et	4	main
huvi	doc_13389385120_item	2239095	et	4	main
kavatsen	doc_13389385120_item	2239098	et	3	main
kuna	doc_13389385120_item	2239105	et	3	main
kultuuri	doc_13389385120_item	2239118	et	4	main
mu	doc_13389385120_item	2239121	et	3	main
teada	doc_13389385120_item	2239125	et	3	main
tundub	doc_13389385120_item	2239135	et	3	main
väga	doc_13389385120_item	2239138	et	3	main
palju	doc_13389385120_item	2239143	et	4	main
millised	doc_13389385120_item	2239150	et	3	main
sellega	doc_13389385120_item	2239152	et	3	main
kuidas	doc_13389385120_item	2239155	et	3	main
neid	doc_13389385120_item	2239157	et	4	main
ja	doc_13389385120_item	2239159	et	3	main
kuidas	doc_13389385120_item	2239160	et	3	main
tööhüpoteesiks	doc_13389385120_item	2239165	et	4	main
näidata	doc_13389385120_item	2239167	et	4	main
on	doc_13389385120_item	2239171	et	4	main
lapsed	doc_13389385120_item	2239184	et	3	main
eesti	doc_13389385120_item	2239186	et	4	main
selleks	doc_13389385120_item	2239196	et	4	main
tööhüpoteesi	doc_13389385120_item	2239199	et	4	main
vene	doc_13389385120_item	2239222	et	4	main
kooliõppekava	doc_13389385120_item	2239226	et	4	main
puudutab	doc_13389385120_item	2239231	et	3	main
õppekavast	doc_13389385120_item	2239240	et	4	main
kultuuri	doc_13389385120_item	2239244	et	4	main
õppimiseks	doc_13389385120_item	2239246	et	4	main
uuringus	doc_13389385120_item	2239250	et	3	main
mõnda	doc_13389385120_item	2239258	et	4	main
ja	doc_13389385120_item	2239260	et	3	main
ja	doc_13389385120_item	2239266	et	3	main
tõdeda	doc_13389385120_item	2239302	et	3	main
see	doc_13389385120_item	2239304	et	3	main
vastuoluline	doc_13389385120_item	2239319	et	4	main
oli	doc_13389385120_item	2239320	et	3	main
tuli	doc_13389385120_item	2239334	et	4	main
kõrg-eesti	doc_13389385120_item	2239341	et	4	main
oma	doc_13389385120_item	2239343	et	4	main
lähialadega	doc_13389385120_item	2239344	et	3	main
lõuna-eesti	doc_13389385120_item	2239348	et	4	main
kultuuriline	doc_13389385120_item	2239358	et	4	main
vahel	doc_13389385120_item	2239368	et	4	main
geograafiliselt	doc_13389385120_item	2239377	et	4	main
soode	doc_13389385120_item	2239383	et	3	main
naabritega	doc_13389385120_item	2239394	et	3	main
rannikuala	doc_13389385120_item	2239398	et	4	main
mõjutustele	doc_13389385120_item	2239404	et	4	main
ei	doc_13389385120_item	2239408	et	4	main
enam	doc_13389385120_item	2239419	et	4	main
1	doc_13389385120_item	2239026	et	2	main
mõjutavad	doc_13389385120_item	2239033	et	4	main
12	doc_13389385120_item	2239036	et	2	main
eesti	doc_13389385120_item	2239049	et	4	main
keele	doc_13389385120_item	2239050	et	4	main
lk15	doc_13389385120_item	2239052	et	4	main
lk15	doc_13389385120_item	2239054	et	4	main
21	doc_13389385120_item	2239057	et	2	main
7	doc_13389385120_item	2239058	et	2	main
lk15	doc_13389385120_item	2239056	et	4	main
testianalüüs	doc_13389385120_item	2239060	et	3	main
klassi	doc_13389385120_item	2239059	et	4	main
lk	doc_13389385120_item	2239061	et	4	main
17	doc_13389385120_item	2239062	et	2	main
22	doc_13389385120_item	2239063	et	2	main
11	doc_13389385120_item	2239064	et	2	main
klassi	doc_13389385120_item	2239065	et	4	main
testianalüüs	doc_13389385120_item	2239066	et	3	main
lk20	doc_13389385120_item	2239067	et	4	main
kokkuvõte	doc_13389385120_item	2239068	et	3	main
sissejuhatus	doc_13389385120_item	2239055	et	4	main
lk21	doc_13389385120_item	2239069	et	4	main
kirjandus	doc_13389385120_item	2239071	et	3	main
lisad	doc_13389385120_item	2239072	et	4	main
seminaritööteemaks	doc_13389385120_item	2239075	et	4	main
eesti	doc_13389385120_item	2239079	et	4	main
õpetamine	doc_13389385120_item	2239081	et	4	main
selle	doc_13389385120_item	2239088	et	4	main
ja	doc_13389385120_item	2239096	et	3	main
lõpetamist	doc_13389385120_item	2239101	et	4	main
kultuuriõpe	doc_13389385120_item	2239110	et	3	main
olnud	doc_13389385120_item	2239111	et	4	main
samas	doc_13389385120_item	2239113	et	4	main
on	doc_13389385120_item	2239115	et	4	main
õpetada	doc_13389385120_item	2239119	et	3	main
väga	doc_13389385120_item	2239123	et	3	main
mis	doc_13389385120_item	2239126	et	4	main
toimub	doc_13389385120_item	2239127	et	3	main
valdkonnassee	doc_13389385120_item	2239133	et	4	main
kuna	doc_13389385120_item	2239140	et	3	main
integratsioonist	doc_13389385120_item	2239144	et	3	main
kuidas	doc_13389385120_item	2239146	et	3	main
protsess	doc_13389385120_item	2239148	et	3	main
saaks	doc_13389385120_item	2239156	et	3	main
need	doc_13389385120_item	2239161	et	3	main
minu	doc_13389385120_item	2239164	et	3	main
vähe	doc_13389385120_item	2239173	et	3	main
kultuuri	doc_13389385120_item	2239176	et	4	main
on	doc_13389385120_item	2239180	et	4	main
kultuurist	doc_13389385120_item	2239187	et	3	main
lapsed	doc_13389385120_item	2239189	et	3	main
millega	doc_13389385120_item	2239192	et	3	main
olen	doc_13389385120_item	2239077	et	3	main
rahvuspärimuse	doc_13389385120_item	2239080	et	3	main
õppimine	doc_13389385120_item	2239083	et	4	main
koolisma	doc_13389385120_item	2239085	et	4	main
mul	doc_13389385120_item	2239114	et	3	main
vaja	doc_13389385120_item	2239116	et	4	main
on	doc_13389385120_item	2239120	et	4	main
jaoks	doc_13389385120_item	2239122	et	4	main
kultuuriõppimisega	doc_13389385120_item	2239128	et	3	main
olukord	doc_13389385120_item	2239131	et	3	main
tänapäeval	doc_13389385120_item	2239141	et	3	main
see	doc_13389385120_item	2239147	et	3	main
probleemid	doc_13389385120_item	2239162	et	3	main
see	doc_13389385120_item	2239168	et	3	main
riigiõppekavas	doc_13389385120_item	2239170	et	3	main
väga	doc_13389385120_item	2239172	et	3	main
pööratud	doc_13389385120_item	2239175	et	4	main
õppimiseks	doc_13389385120_item	2239177	et	4	main
välja	doc_13389385120_item	2239181	et	4	main
selgitada	doc_13389385120_item	2239182	et	3	main
sooviksid	doc_13389385120_item	2239190	et	4	main
õppida	doc_13389385120_item	2239191	et	3	main
lütseumi	doc_13389385120_item	2239223	et	4	main
eesti	doc_13389385120_item	2239224	et	4	main
keele	doc_13389385120_item	2239225	et	4	main
ainult	doc_13389385120_item	2239228	et	4	main
õpetamist	doc_13389385120_item	2239233	et	4	main
õpetajatega	doc_13389385120_item	2239235	et	4	main
meetodid	doc_13389385120_item	2239243	et	3	main
oma	doc_13389385120_item	2239249	et	4	main
ma	doc_13389385120_item	2239251	et	3	main
kvalitatiivsed	doc_13389385120_item	2239253	et	3	main
1	doc_13389385120_item	2239262	et	2	main
11eesti	doc_13389385120_item	2239264	et	4	main
rahvapärimus	doc_13389385120_item	2239265	et	3	main
teda	doc_13389385120_item	2239267	et	4	main
maal	doc_13389385120_item	2239309	et	4	main
ka	doc_13389385120_item	2239321	et	3	main
eksisteerisid	doc_13389385120_item	2239325	et	4	main
läbi	doc_13389385120_item	2239336	et	4	main
põhja-	doc_13389385120_item	2239345	et	4	main
lõuna-eestiks	doc_13389385120_item	2239347	et	4	main
ala	doc_13389385120_item	2239353	et	4	main
viitab	doc_13389385120_item	2239355	et	3	main
kõrg-	doc_13389385120_item	2239365	et	4	main
ja	doc_13389385120_item	2239366	et	3	main
mis	doc_13389385120_item	2239373	et	4	main
tallinnast	doc_13389385120_item	2239375	et	3	main
see	doc_13389385120_item	2239379	et	3	main
metsade	doc_13389385120_item	2239381	et	3	main
kultuurivaldkondade	doc_13389385120_item	2239385	et	3	main
eeldustest	doc_13389385120_item	2239390	et	4	main
olulisemad	doc_13389385120_item	2239392	et	4	main
kontaktid	doc_13389385120_item	2239393	et	3	main
olid	doc_13389385120_item	2239399	et	4	main
on	doc_13389385120_item	2239412	et	4	main
pikka	doc_13389385120_item	2239415	et	4	main
uuendustele	doc_13389385120_item	2239417	et	4	main
põhja-eesti	doc_13389385120_item	2239423	et	4	main
tähtsa	doc_13389385120_item	2239427	et	3	main
andis	doc_13389385120_item	2239434	et	3	main
kiiresti	doc_13389385120_item	2239437	et	3	main
seevastu	doc_13389385120_item	2239442	et	3	main
mis	doc_13389385120_item	2239465	et	4	main
kõige	doc_13389385120_item	2239469	et	4	main
rehielamut	doc_13389385120_item	2239476	et	4	main
ajaloolisest	doc_13389385120_item	2239496	et	4	main
on	doc_13389385120_item	2239498	et	4	main
kolm	doc_13389385120_item	2239502	et	3	main
murranguperioodi	doc_13389385120_item	2239503	et	4	main
katoliku	doc_13389385120_item	2239515	et	3	main
lõi	doc_13389385120_item	2239528	et	4	main
eestikeelse	doc_13389385120_item	2239530	et	3	main
osa	doc_13389385120_item	2239546	et	4	main
pärimuse	doc_13389385120_item	2239551	et	4	main
ja	doc_13389385120_item	2239553	et	3	main
arusaamade	doc_13389385120_item	2239555	et	3	main
siiski	doc_13389385120_item	2239557	et	4	main
see	doc_13389385120_item	2239559	et	3	main
teisel	doc_13389385120_item	2239579	et	4	main
selle	doc_13389385120_item	2239581	et	4	main
alanud	doc_13389385120_item	2239586	et	4	main
tuleb	doc_13389385120_item	2239592	et	3	main
ja	doc_13389385120_item	2239596	et	3	main
ja	doc_13389385120_item	2239605	et	3	main
mõis	doc_13389385120_item	2239609	et	3	main
teravaid	doc_13389385120_item	2239616	et	3	main
kui	doc_13389385120_item	2239621	et	3	main
oluline	doc_13389385120_item	2239124	et	4	main
milline	doc_13389385120_item	2239129	et	3	main
olevat	doc_13389385120_item	2239137	et	4	main
sellest	doc_13389385120_item	2239145	et	4	main
on	doc_13389385120_item	2239151	et	4	main
seonduvad	doc_13389385120_item	2239153	et	4	main
lahendada	doc_13389385120_item	2239158	et	3	main
tööeesmärgiks	doc_13389385120_item	2239179	et	3	main
teavad	doc_13389385120_item	2239185	et	3	main
mida	doc_13389385120_item	2239188	et	4	main
neil	doc_13389385120_item	2239194	et	4	main
oma	doc_13389385120_item	2239198	et	4	main
kaitsta	doc_13389385120_item	2239200	et	4	main
ma	doc_13389385120_item	2239201	et	3	main
korraldan	doc_13389385120_item	2239202	et	3	main
teste	doc_13389385120_item	2239203	et	3	main
näitavad	doc_13389385120_item	2239205	et	4	main
õpilaste	doc_13389385120_item	2239206	et	4	main
mis	doc_13389385120_item	2239204	et	4	main
õppeedukust	doc_13389385120_item	2239207	et	4	main
ma	doc_13389385120_item	2239209	et	3	main
toon	doc_13389385120_item	2239210	et	4	main
samas	doc_13389385120_item	2239208	et	4	main
esile	doc_13389385120_item	2239211	et	3	main
riigiõppekava	doc_13389385120_item	2239212	et	4	main
selleks	doc_13389385120_item	2239213	et	4	main
et	doc_13389385120_item	2239214	et	3	main
tõestada	doc_13389385120_item	2239215	et	3	main
mu	doc_13389385120_item	2239216	et	3	main
hüpoteesi	doc_13389385120_item	2239217	et	4	main
toon	doc_13389385120_item	2239218	et	4	main
esile	doc_13389385120_item	2239219	et	3	main
tallinna	doc_13389385120_item	2239220	et	4	main
õismäe	doc_13389385120_item	2239221	et	3	main
aga	doc_13389385120_item	2239227	et	3	main
seda	doc_13389385120_item	2239229	et	3	main
avaldan	doc_13389385120_item	2239237	et	3	main
arvamust	doc_13389385120_item	2239239	et	3	main
ja	doc_13389385120_item	2239241	et	3	main
nende	doc_13389385120_item	2239242	et	4	main
kasutan	doc_13389385120_item	2239257	et	3	main
interneti-	doc_13389385120_item	2239259	et	4	main
kirjanduseallikad	doc_13389385120_item	2239261	et	3	main
tegurid	doc_13389385120_item	2239269	et	3	main
on	doc_13389385120_item	2239271	et	4	main
omal	doc_13389385120_item	2239308	et	3	main
seisusest	doc_13389385120_item	2239311	et	4	main
erakordselt	doc_13389385120_item	2239313	et	4	main
olemise	doc_13389385120_item	2239317	et	4	main
kultuuriloo	doc_13389385120_item	2239232	et	4	main
vestlen	doc_13389385120_item	2239234	et	3	main
ja	doc_13389385120_item	2239236	et	3	main
nende	doc_13389385120_item	2239238	et	4	main
paremaks	doc_13389385120_item	2239245	et	4	main
arusaamiseks	doc_13389385120_item	2239248	et	4	main
meetodid	doc_13389385120_item	2239254	et	3	main
ma	doc_13389385120_item	2239256	et	3	main
mõjutavad	doc_13389385120_item	2239268	et	4	main
pikki	doc_13389385120_item	2239273	et	4	main
sajandeid	doc_13389385120_item	2239274	et	3	main
isegi	doc_13389385120_item	2239275	et	4	main
aastatuhandeid	doc_13389385120_item	2239276	et	4	main
euroopas	doc_13389385120_item	2239277	et	3	main
lääne	doc_13389385120_item	2239278	et	4	main
ja	doc_13389385120_item	2239279	et	3	main
pii	doc_13389385120_item	2239281	et	4	main
ida	doc_13389385120_item	2239280	et	4	main
ril	doc_13389385120_item	2239282	et	4	main
see	doc_13389385120_item	2239283	et	3	main
asend	doc_13389385120_item	2239284	et	3	main
on	doc_13389385120_item	2239285	et	4	main
määranud	doc_13389385120_item	2239286	et	4	main
rahvapärimuse	doc_13389385120_item	2239287	et	3	main
näo	doc_13389385120_item	2239288	et	3	main
mille	doc_13389385120_item	2239289	et	3	main
iseloomustavad	doc_13389385120_item	2239291	et	4	main
tervikpilti	doc_13389385120_item	2239290	et	4	main
juba	doc_13389385120_item	2239292	et	3	main
kaugest	doc_13389385120_item	2239293	et	3	main
minevikust	doc_13389385120_item	2239294	et	3	main
pärinevad	doc_13389385120_item	2239295	et	4	main
kohalikud	doc_13389385120_item	2239296	et	3	main
erijooned	doc_13389385120_item	2239297	et	3	main
rahvapärimuse	doc_13389385120_item	2239299	et	3	main
eesti	doc_13389385120_item	2239298	et	4	main
tulebki	doc_13389385120_item	2239301	et	3	main
et	doc_13389385120_item	2239303	et	3	main
ühe	doc_13389385120_item	2239306	et	4	main
alamast	doc_13389385120_item	2239310	et	4	main
rahva	doc_13389385120_item	2239312	et	3	main
keeruline	doc_13389385120_item	2239314	et	4	main
mitmekihiline	doc_13389385120_item	2239316	et	4	main
viis	doc_13389385120_item	2239318	et	4	main
nii	doc_13389385120_item	2239327	et	3	main
kui	doc_13389385120_item	2239329	et	3	main
ja	doc_13389385120_item	2239332	et	3	main
koos	doc_13389385120_item	2239342	et	4	main
tuumikuks	doc_13389385120_item	2239349	et	4	main
on	doc_13389385120_item	2239360	et	4	main
esiajaloolisest	doc_13389385120_item	2239363	et	4	main
lai	doc_13389385120_item	2239370	et	3	main
pärnuni	doc_13389385120_item	2239376	et	4	main
kattub	doc_13389385120_item	2239378	et	3	main
on	doc_13389385120_item	2239388	et	4	main
eesti	doc_13389385120_item	2239395	et	4	main
ja	doc_13389385120_item	2239397	et	3	main
skandinaavia	doc_13389385120_item	2239403	et	4	main
eestimaale	doc_13389385120_item	2239407	et	4	main
ulatunud	doc_13389385120_item	2239409	et	4	main
seisukohalt	doc_13389385120_item	2239411	et	4	main
keskendus	doc_13389385120_item	2239424	et	4	main
kui	doc_13389385120_item	2239426	et	3	main
alates	doc_13389385120_item	2239431	et	3	main
sajandist	doc_13389385120_item	2239433	et	3	main
peterburi	doc_13389385120_item	2239439	et	4	main
lähedus	doc_13389385120_item	2239440	et	4	main
jäi	doc_13389385120_item	2239443	et	3	main
linna	doc_13389385120_item	2239445	et	4	main
siiski	doc_13389385120_item	2239447	et	4	main
liivimaa	doc_13389385120_item	2239448	et	4	main
kubermangu	doc_13389385120_item	2239449	et	4	main
ääremaaks	doc_13389385120_item	2239451	et	3	main
piirkondlikest	doc_13389385120_item	2239453	et	3	main
vanal	doc_13389385120_item	2239457	et	3	main
üle	doc_13389385120_item	2239460	et	3	main
tervikuks	doc_13389385120_item	2239467	et	4	main
liitsid	doc_13389385120_item	2239468	et	4	main
elamut	doc_13389385120_item	2239479	et	3	main
ka	doc_13389385120_item	2239486	et	3	main
pulma-	doc_13389385120_item	2239489	et	4	main
külvinädalate	doc_13389385120_item	2239492	et	3	main
algas	doc_13389385120_item	2239506	et	3	main
reformatsioon	doc_13389385120_item	2239525	et	3	main
eestikeelne	doc_13389385120_item	2239526	et	3	main
tingimused	doc_13389385120_item	2239529	et	3	main
omakorda	doc_13389385120_item	2239536	et	3	main
aluse	doc_13389385120_item	2239538	et	4	main
kirjaoskusele	doc_13389385120_item	2239540	et	3	main
kokku	doc_13389385120_item	2239543	et	3	main
1860	doc_13389385120_item	2239584	et	2	main
talude	doc_13389385120_item	2239587	et	3	main
eesti	doc_13389385120_item	2239589	et	4	main
ka	doc_13389385120_item	2239594	et	3	main
nii	doc_13389385120_item	2239603	et	3	main
kui	doc_13389385120_item	2239607	et	3	main
eestlastel	doc_13389385120_item	2239612	et	4	main
siiski	doc_13389385120_item	2239614	et	4	main
nii	doc_13389385120_item	2239618	et	3	main
vaimses	doc_13389385120_item	2239620	et	3	main
kultuuris	doc_13389385120_item	2239623	et	3	main
ning	doc_13389385120_item	2239624	et	3	main
enda	doc_13389385120_item	2239627	et	4	main
ja	doc_13389385120_item	2239634	et	3	main
teadma	doc_13389385120_item	2239643	et	3	main
õpetatava	doc_13389385120_item	2239651	et	4	main
keele	doc_13389385120_item	2239652	et	4	main
või	doc_13389385120_item	2239653	et	4	main
rahvapärimust	doc_13389385120_item	2239657	et	4	main
ja	doc_13389385120_item	2239665	et	3	main
õppimiseks	doc_13389385120_item	2239667	et	4	main
vähe	doc_13389385120_item	2239671	et	3	main
eesti	doc_13389385120_item	2239675	et	4	main
valdamine	doc_13389385120_item	2239679	et	4	main
on	doc_13389385120_item	2239681	et	4	main
selle	doc_13389385120_item	2239693	et	4	main
rahvapärimusest	doc_13389385120_item	2239694	et	4	main
tundide	doc_13389385120_item	2239696	et	3	main
peaks	doc_13389385120_item	2239726	et	4	main
muutma	doc_13389385120_item	2239728	et	3	main
eestlase	doc_13389385120_item	2239322	et	3	main
kus	doc_13389385120_item	2239324	et	3	main
koos	doc_13389385120_item	2239326	et	4	main
kristlikud	doc_13389385120_item	2239328	et	3	main
paganlikud	doc_13389385120_item	2239330	et	3	main
saada	doc_13389385120_item	2239337	et	4	main
ja	doc_13389385120_item	2239346	et	3	main
on	doc_13389385120_item	2239350	et	4	main
sellele	doc_13389385120_item	2239356	et	4	main
ajast	doc_13389385120_item	2239364	et	4	main
üleminekuala	doc_13389385120_item	2239372	et	4	main
samasuunaliste	doc_13389385120_item	2239380	et	4	main
ja	doc_13389385120_item	2239382	et	3	main
puhul	doc_13389385120_item	2239387	et	4	main
siiski	doc_13389385120_item	2239391	et	4	main
rajajooneks	doc_13389385120_item	2239401	et	3	main
rahvapärimuse	doc_13389385120_item	2239410	et	3	main
olnud	doc_13389385120_item	2239414	et	4	main
aega	doc_13389385120_item	2239416	et	4	main
avatud	doc_13389385120_item	2239420	et	4	main
tallinna	doc_13389385120_item	2239425	et	4	main
ja	doc_13389385120_item	2239430	et	3	main
ka	doc_13389385120_item	2239436	et	3	main
suhtes	doc_13389385120_item	2239446	et	4	main
kõikidest	doc_13389385120_item	2239452	et	4	main
erinevustest	doc_13389385120_item	2239454	et	4	main
hoolimata	doc_13389385120_item	2239455	et	4	main
eesti	doc_13389385120_item	2239458	et	4	main
maa	doc_13389385120_item	2239462	et	4	main
neist	doc_13389385120_item	2239471	et	4	main
võib	doc_13389385120_item	2239472	et	3	main
kui	doc_13389385120_item	2239477	et	3	main
hapendatud	doc_13389385120_item	2239482	et	4	main
rukkileiba	doc_13389385120_item	2239483	et	4	main
oli	doc_13389385120_item	2239485	et	3	main
suur	doc_13389385120_item	2239487	et	3	main
eristatavad	doc_13389385120_item	2239501	et	4	main
esimene	doc_13389385120_item	2239504	et	3	main
neist	doc_13389385120_item	2239505	et	4	main
13	doc_13389385120_item	2239507	et	2	main
seoses	doc_13389385120_item	2239509	et	4	main
vallutustega	doc_13389385120_item	2239511	et	4	main
maale	doc_13389385120_item	2239514	et	4	main
jaguneb	doc_13389385120_item	2239340	et	3	main
lõuna-eesti	doc_13389385120_item	2239351	et	4	main
murde	doc_13389385120_item	2239352	et	4	main
mis	doc_13389385120_item	2239354	et	4	main
et	doc_13389385120_item	2239357	et	3	main
erinevus	doc_13389385120_item	2239359	et	4	main
pärit	doc_13389385120_item	2239361	et	3	main
juba	doc_13389385120_item	2239362	et	3	main
madal-eesti	doc_13389385120_item	2239367	et	4	main
on	doc_13389385120_item	2239369	et	4	main
kultuuriline	doc_13389385120_item	2239371	et	4	main
ulatub	doc_13389385120_item	2239374	et	3	main
vööndiga	doc_13389385120_item	2239384	et	3	main
sünni	doc_13389385120_item	2239386	et	4	main
looduslikest	doc_13389385120_item	2239389	et	3	main
saared	doc_13389385120_item	2239396	et	3	main
omamoodi	doc_13389385120_item	2239400	et	3	main
mitmetele	doc_13389385120_item	2239402	et	4	main
mis	doc_13389385120_item	2239405	et	4	main
kaugemale	doc_13389385120_item	2239406	et	4	main
põhja-eesti	doc_13389385120_item	2239413	et	4	main
tunduvalt	doc_13389385120_item	2239418	et	4	main
kui	doc_13389385120_item	2239421	et	3	main
ümber	doc_13389385120_item	2239429	et	3	main
areneva	doc_13389385120_item	2239438	et	4	main
teisekeelseks	doc_13389385120_item	2239450	et	4	main
oli	doc_13389385120_item	2239456	et	3	main
tuntud	doc_13389385120_item	2239463	et	4	main
ühisjooni	doc_13389385120_item	2239464	et	3	main
selle	doc_13389385120_item	2239466	et	4	main
regivärsilist	doc_13389385120_item	2239474	et	4	main
tüüpilist	doc_13389385120_item	2239478	et	3	main
ja	doc_13389385120_item	2239480	et	3	main
osa	doc_13389385120_item	2239488	et	4	main
ja	doc_13389385120_item	2239490	et	3	main
lugemine	doc_13389385120_item	2239493	et	4	main
ja	doc_13389385120_item	2239494	et	3	main
rahvakultuuris	doc_13389385120_item	2239499	et	3	main
selgesti	doc_13389385120_item	2239500	et	3	main
sajandil	doc_13389385120_item	2239508	et	3	main
ja	doc_13389385120_item	2239512	et	3	main
tõi	doc_13389385120_item	2239513	et	3	main
jumalateenistus	doc_13389385120_item	2239527	et	3	main
ja	doc_13389385120_item	2239532	et	3	main
tekkeks	doc_13389385120_item	2239534	et	3	main
rahva	doc_13389385120_item	2239539	et	3	main
kõik	doc_13389385120_item	2239541	et	4	main
ja	doc_13389385120_item	2239549	et	3	main
murenemises	doc_13389385120_item	2239552	et	4	main
kujunemises	doc_13389385120_item	2239556	et	4	main
oli	doc_13389385120_item	2239558	et	3	main
oli	doc_13389385120_item	2239583	et	3	main
rahvakultuuri	doc_13389385120_item	2239597	et	4	main
siin	doc_13389385120_item	2239602	et	4	main
õnnestus	doc_13389385120_item	2239613	et	4	main
vastuolusid	doc_13389385120_item	2239617	et	3	main
oma	doc_13389385120_item	2239619	et	4	main
materiaalses	doc_13389385120_item	2239622	et	3	main
uus	doc_13389385120_item	2239633	et	3	main
võõras	doc_13389385120_item	2239635	et	4	main
12riigiõppekava	doc_13389385120_item	2239637	et	4	main
rahvapärimust	doc_13389385120_item	2239644	et	4	main
enda	doc_13389385120_item	2239646	et	4	main
maa	doc_13389385120_item	2239656	et	4	main
praegune	doc_13389385120_item	2239658	et	3	main
pea	doc_13389385120_item	2239661	et	4	main
oluliseks	doc_13389385120_item	2239663	et	4	main
väga	doc_13389385120_item	2239670	et	3	main
keele	doc_13389385120_item	2239676	et	4	main
ja	doc_13389385120_item	2239678	et	3	main
inimene	doc_13389385120_item	2239688	et	3	main
oska	doc_13389385120_item	2239690	et	4	main
öelda	doc_13389385120_item	2239692	et	4	main
peab	doc_13389385120_item	2239722	et	4	main
haridusministeeriumilt	doc_13389385120_item	2239724	et	3	main
õppekava	doc_13389385120_item	2239729	et	4	main
aga	doc_13389385120_item	2239731	et	3	main
seda	doc_13389385120_item	2239736	et	3	main
jaoks	doc_13389385120_item	2239755	et	4	main
eraldi	doc_13389385120_item	2239758	et	4	main
on	doc_13389385120_item	2239762	et	4	main
ja	doc_13389385120_item	2239766	et	3	main
õppimist	doc_13389385120_item	2239777	et	4	main
edaspidi	doc_13389385120_item	2239783	et	3	main
lõuna-eesti	doc_13389385120_item	2239422	et	4	main
kaubanduskeskuse	doc_13389385120_item	2239428	et	3	main
18	doc_13389385120_item	2239432	et	2	main
tunda	doc_13389385120_item	2239435	et	3	main
lõuna-eesti	doc_13389385120_item	2239441	et	4	main
riia	doc_13389385120_item	2239444	et	4	main
talupojakultuuril	doc_13389385120_item	2239459	et	3	main
kogu	doc_13389385120_item	2239461	et	4	main
tunnuslikumaks	doc_13389385120_item	2239470	et	4	main
pidada	doc_13389385120_item	2239473	et	4	main
rahvalaulu	doc_13389385120_item	2239475	et	4	main
pehmet	doc_13389385120_item	2239481	et	3	main
ühine	doc_13389385120_item	2239484	et	4	main
jõulukombestikust	doc_13389385120_item	2239491	et	4	main
hingedeaeg	doc_13389385120_item	2239495	et	3	main
vaatevinklist	doc_13389385120_item	2239497	et	4	main
saksa	doc_13389385120_item	2239510	et	4	main
usu	doc_13389385120_item	2239516	et	4	main
ühiskonna	doc_13389385120_item	2239518	et	4	main
seisusliku	doc_13389385120_item	2239517	et	3	main
ja	doc_13389385120_item	2239519	et	3	main
linnakultuuri	doc_13389385120_item	2239520	et	4	main
teise	doc_13389385120_item	2239521	et	4	main
tõi	doc_13389385120_item	2239523	et	3	main
trükisõna	doc_13389385120_item	2239531	et	4	main
pani	doc_13389385120_item	2239537	et	4	main
etendas	doc_13389385120_item	2239544	et	3	main
muusikalise	doc_13389385120_item	2239550	et	4	main
uute	doc_13389385120_item	2239554	et	3	main
protsess	doc_13389385120_item	2239561	et	3	main
ajendiks	doc_13389385120_item	2239582	et	3	main
aastatel	doc_13389385120_item	2239585	et	4	main
rahvakultuuri	doc_13389385120_item	2239590	et	4	main
ajaloos	doc_13389385120_item	2239591	et	4	main
vahendajateks	doc_13389385120_item	2239600	et	4	main
kirik	doc_13389385120_item	2239604	et	3	main
klooster	doc_13389385120_item	2239606	et	3	main
ka	doc_13389385120_item	2239608	et	3	main
ja	doc_13389385120_item	2239610	et	3	main
vältida	doc_13389385120_item	2239615	et	3	main
ja	doc_13389385120_item	2239629	et	3	main
ürgne	doc_13389385120_item	2239630	et	3	main
saabunud	doc_13389385120_item	2239632	et	4	main
httpwwwestonicaorgestluguhtmlmenyyid175kateg5alam19leht1	doc_13389385120_item	2239636	et	4	main
sissejuhatus	doc_13389385120_item	2239638	et	4	main
iga	doc_13389385120_item	2239639	et	4	main
peab	doc_13389385120_item	2239642	et	4	main
rahvapärimust	doc_13389385120_item	2239648	et	4	main
ei	doc_13389385120_item	2239660	et	4	main
seda	doc_13389385120_item	2239662	et	3	main
peetakse	doc_13389385120_item	2239674	et	3	main
aga	doc_13389385120_item	2239680	et	3	main
kuidagi	doc_13389385120_item	2239682	et	3	main
vabalt	doc_13389385120_item	2239686	et	4	main
ei	doc_13389385120_item	2239689	et	4	main
midagi	doc_13389385120_item	2239691	et	4	main
initsiatiiv	doc_13389385120_item	2239721	et	3	main
tulema	doc_13389385120_item	2239723	et	4	main
et	doc_13389385120_item	2239734	et	3	main
praegu	doc_13389385120_item	2239735	et	3	main
kultuuriga	doc_13389385120_item	2239752	et	4	main
kultuuriloo	doc_13389385120_item	2239754	et	4	main
koostatud	doc_13389385120_item	2239759	et	4	main
eesti	doc_13389385120_item	2239763	et	4	main
ainult	doc_13389385120_item	2239771	et	4	main
osad	doc_13389385120_item	2239773	et	3	main
gümnaasiumi	doc_13389385120_item	2239780	et	4	main
riiklik	doc_13389385120_item	2239781	et	3	main
edaspidi	doc_13389385120_item	2239791	et	3	main
õppe-	doc_13389385120_item	2239793	et	4	main
kasvatustegevuse	doc_13389385120_item	2239795	et	4	main
õppekava	doc_13389385120_item	2239798	et	4	main
ülesehituse	doc_13389385120_item	2239815	et	3	main
13	doc_13389385120_item	2239826	et	2	main
esmased	doc_13389385120_item	2239830	et	3	main
rahvakalendri	doc_13389385120_item	2239835	et	3	main
mina	doc_13389385120_item	2239837	et	4	main
üldandmedrahvussümbolikarahvuslindlillpuu	doc_13389385120_item	2239841	et	4	main
murrangu	doc_13389385120_item	2239522	et	3	main
kaasa	doc_13389385120_item	2239524	et	4	main
kooliõpetuse	doc_13389385120_item	2239533	et	3	main
mis	doc_13389385120_item	2239535	et	4	main
see	doc_13389385120_item	2239542	et	3	main
olulist	doc_13389385120_item	2239545	et	4	main
vana	doc_13389385120_item	2239547	et	4	main
suulise	doc_13389385120_item	2239548	et	4	main
aeganõudev	doc_13389385120_item	2239560	et	3	main
ja	doc_13389385120_item	2239562	et	3	main
muudatused	doc_13389385120_item	2239563	et	3	main
hoogu	doc_13389385120_item	2239565	et	4	main
võtma	doc_13389385120_item	2239566	et	3	main
alles	doc_13389385120_item	2239567	et	3	main
18	doc_13389385120_item	2239568	et	2	main
hakkasid	doc_13389385120_item	2239564	et	4	main
sajandi	doc_13389385120_item	2239569	et	3	main
lõpul	doc_13389385120_item	2239570	et	3	main
suur	doc_13389385120_item	2239572	et	3	main
tõeliselt	doc_13389385120_item	2239571	et	4	main
pööre	doc_13389385120_item	2239573	et	4	main
leidis	doc_13389385120_item	2239575	et	4	main
rahvakultuuris	doc_13389385120_item	2239574	et	3	main
aset	doc_13389385120_item	2239576	et	3	main
19	doc_13389385120_item	2239577	et	2	main
sajandi	doc_13389385120_item	2239578	et	3	main
poolel	doc_13389385120_item	2239580	et	4	main
päriseksostmine	doc_13389385120_item	2239588	et	3	main
rõhutada	doc_13389385120_item	2239593	et	3	main
kõrg-	doc_13389385120_item	2239595	et	4	main
vastastikuseid	doc_13389385120_item	2239598	et	4	main
mõjutusi	doc_13389385120_item	2239599	et	4	main
olid	doc_13389385120_item	2239601	et	4	main
linn	doc_13389385120_item	2239611	et	3	main
sulatada	doc_13389385120_item	2239625	et	3	main
ning	doc_13389385120_item	2239631	et	3	main
haritud	doc_13389385120_item	2239640	et	4	main
nii	doc_13389385120_item	2239645	et	3	main
kuid	doc_13389385120_item	2239649	et	4	main
kultuuri	doc_13389385120_item	2239666	et	4	main
on	doc_13389385120_item	2239668	et	4	main
andnud	doc_13389385120_item	2239669	et	4	main
oluliseks	doc_13389385120_item	2239673	et	4	main
õppimine	doc_13389385120_item	2239677	et	4	main
kui	doc_13389385120_item	2239684	et	3	main
jooksul	doc_13389385120_item	2239697	et	4	main
mis	doc_13389385120_item	2239698	et	4	main
on	doc_13389385120_item	2239699	et	4	main
määratletud	doc_13389385120_item	2239700	et	4	main
rahvapärimuse	doc_13389385120_item	2239701	et	3	main
õppimiseks	doc_13389385120_item	2239702	et	4	main
saab	doc_13389385120_item	2239703	et	3	main
anda	doc_13389385120_item	2239704	et	3	main
vaid	doc_13389385120_item	2239705	et	3	main
kuigi	doc_13389385120_item	2239707	et	3	main
lühiülevaade	doc_13389385120_item	2239706	et	3	main
loomulikult	doc_13389385120_item	2239708	et	4	main
see	doc_13389385120_item	2239709	et	3	main
pole	doc_13389385120_item	2239710	et	3	main
piisav	doc_13389385120_item	2239711	et	4	main
samas	doc_13389385120_item	2239712	et	4	main
vene	doc_13389385120_item	2239713	et	4	main
koolid	doc_13389385120_item	2239714	et	3	main
ei	doc_13389385120_item	2239715	et	4	main
saa	doc_13389385120_item	2239716	et	4	main
midagi	doc_13389385120_item	2239717	et	4	main
õppekavas	doc_13389385120_item	2239718	et	3	main
muuta	doc_13389385120_item	2239719	et	4	main
see	doc_13389385120_item	2239720	et	3	main
ühte	doc_13389385120_item	2239626	et	4	main
vana	doc_13389385120_item	2239628	et	4	main
inimene	doc_13389385120_item	2239641	et	3	main
maa	doc_13389385120_item	2239647	et	4	main
ka	doc_13389385120_item	2239650	et	3	main
valitud	doc_13389385120_item	2239654	et	4	main
elamiseks	doc_13389385120_item	2239655	et	4	main
õppekava	doc_13389385120_item	2239659	et	4	main
rahvapärimuse	doc_13389385120_item	2239664	et	3	main
aega	doc_13389385120_item	2239672	et	4	main
kummaline	doc_13389385120_item	2239683	et	3	main
keelt	doc_13389385120_item	2239685	et	4	main
valdav	doc_13389385120_item	2239687	et	4	main
selliste	doc_13389385120_item	2239695	et	4	main
sisu	doc_13389385120_item	2239730	et	4	main
ei	doc_13389385120_item	2239737	et	4	main
peetakse	doc_13389385120_item	2239743	et	3	main
keele	doc_13389385120_item	2239744	et	4	main
ja	doc_13389385120_item	2239746	et	3	main
tutvustamine	doc_13389385120_item	2239753	et	4	main
ole	doc_13389385120_item	2239757	et	4	main
keele	doc_13389385120_item	2239764	et	4	main
õppekavas	doc_13389385120_item	2239765	et	3	main
õppekavast	doc_13389385120_item	2239768	et	4	main
ma	doc_13389385120_item	2239769	et	3	main
need	doc_13389385120_item	2239772	et	3	main
määrab	doc_13389385120_item	2239786	et	3	main
ning	doc_13389385120_item	2239813	et	3	main
ja	doc_13389385120_item	2239816	et	3	main
põhimõtted	doc_13389385120_item	2239818	et	3	main
kes	doc_13389385120_item	2239725	et	4	main
ise	doc_13389385120_item	2239727	et	4	main
ma	doc_13389385120_item	2239732	et	3	main
punktiks	doc_13389385120_item	2239742	et	4	main
õppimine	doc_13389385120_item	2239745	et	4	main
valdamine	doc_13389385120_item	2239747	et	4	main
mitte	doc_13389385120_item	2239748	et	3	main
õpetatava	doc_13389385120_item	2239749	et	4	main
keele	doc_13389385120_item	2239750	et	4	main
rahva	doc_13389385120_item	2239751	et	3	main
arvan	doc_13389385120_item	2239733	et	3	main
maksa	doc_13389385120_item	2239738	et	4	main
lootagi	doc_13389385120_item	2239739	et	4	main
sest	doc_13389385120_item	2239740	et	4	main
oluliseks	doc_13389385120_item	2239741	et	4	main
ei	doc_13389385120_item	2239756	et	4	main
õppekava	doc_13389385120_item	2239760	et	4	main
sellest	doc_13389385120_item	2239767	et	4	main
puudutavad	doc_13389385120_item	2239775	et	4	main
kultuuriloo	doc_13389385120_item	2239776	et	4	main
põhikooli	doc_13389385120_item	2239778	et	4	main
ja	doc_13389385120_item	2239779	et	3	main
riiklik	doc_13389385120_item	2239784	et	3	main
ja	doc_13389385120_item	2239789	et	3	main
kool	doc_13389385120_item	2239792	et	4	main
ja	doc_13389385120_item	2239794	et	3	main
õppekorralduse	doc_13389385120_item	2239802	et	3	main
alused	doc_13389385120_item	2239803	et	4	main
õppeained	doc_13389385120_item	2239805	et	3	main
tunnijaotusplaani	doc_13389385120_item	2239807	et	4	main
kooliastmete	doc_13389385120_item	2239809	et	3	main
kooli	doc_13389385120_item	2239811	et	4	main
koostamise	doc_13389385120_item	2239817	et	4	main
omandab	doc_13389385120_item	2239829	et	3	main
tähtpäevadest	doc_13389385120_item	2239836	et	3	main
eesti	doc_13389385120_item	2239840	et	4	main
ja	doc_13389385120_item	2239843	et	3	main
eesti	doc_13389385120_item	2239848	et	4	main
sel	doc_13389385120_item	2239853	et	3	main
sellest	doc_13389385120_item	2239861	et	4	main
keeles	doc_13389385120_item	2239863	et	4	main
eesti	doc_13389385120_item	2239903	et	4	main
aktiivset	doc_13389385120_item	2239910	et	3	main
osavõttu	doc_13389385120_item	2239911	et	4	main
kultuurielust	doc_13389385120_item	2239913	et	3	main
kultuurpaikkonna	doc_13389385120_item	2239925	et	3	main
eesti	doc_13389385120_item	2239927	et	4	main
kultuuriloo	doc_13389385120_item	2239928	et	4	main
muistenditest	doc_13389385120_item	2239939	et	3	main
2-3	doc_13389385120_item	2239951	et	2	main
kultuuriloo	doc_13389385120_item	2239958	et	4	main
2-3	doc_13389385120_item	2239963	et	2	main
eesti	doc_13389385120_item	2239967	et	4	main
ning	doc_13389385120_item	2239969	et	3	main
eesti	doc_13389385120_item	2239971	et	4	main
liigendub	doc_13389385120_item	2239979	et	3	main
laulupidude	doc_13389385120_item	2240019	et	4	main
see	doc_13389385120_item	2239761	et	3	main
valisin	doc_13389385120_item	2239770	et	3	main
mis	doc_13389385120_item	2239774	et	4	main
õppekava	doc_13389385120_item	2239782	et	4	main
õppekava	doc_13389385120_item	2239785	et	4	main
kindlaks	doc_13389385120_item	2239787	et	3	main
põhikooli	doc_13389385120_item	2239788	et	4	main
gümnaasiumi	doc_13389385120_item	2239790	et	4	main
eesmärgid	doc_13389385120_item	2239796	et	3	main
omandatavad	doc_13389385120_item	2239800	et	4	main
pädevused	doc_13389385120_item	2239801	et	4	main
kohustuslikud	doc_13389385120_item	2239804	et	3	main
nõuded	doc_13389385120_item	2239808	et	3	main
lõpetamiseks	doc_13389385120_item	2239812	et	4	main
kooliõppekava	doc_13389385120_item	2239814	et	4	main
olenemata	doc_13389385120_item	2239819	et	4	main
ainekava	doc_13389385120_item	2239825	et	4	main
kultuur	doc_13389385120_item	2239839	et	3	main
emadepäev	doc_13389385120_item	2239847	et	3	main
46	doc_13389385120_item	2239851	et	2	main
oma	doc_13389385120_item	2239857	et	4	main
kodukoha	doc_13389385120_item	2239858	et	4	main
eripära	doc_13389385120_item	2239859	et	4	main
õpib	doc_13389385120_item	2239860	et	3	main
mina	doc_13389385120_item	2239870	et	4	main
koliastmel	doc_13389385120_item	2239901	et	3	main
enam	doc_13389385120_item	2239907	et	4	main
õpilasele	doc_13389385120_item	2239909	et	3	main
eestikeelseid	doc_13389385120_item	2239915	et	3	main
üritusi	doc_13389385120_item	2239917	et	4	main
kontserditel	doc_13389385120_item	2239920	et	4	main
muuseumides	doc_13389385120_item	2239921	et	3	main
tähtsamad	doc_13389385120_item	2239929	et	4	main
ja	doc_13389385120_item	2239932	et	3	main
katked	doc_13389385120_item	2239935	et	4	main
näiteid	doc_13389385120_item	2239937	et	3	main
põhikooli	doc_13389385120_item	2239942	et	4	main
teab	doc_13389385120_item	2239944	et	3	main
noorsookirjanikku	doc_13389385120_item	2239946	et	4	main
proosateksti	doc_13389385120_item	2239956	et	4	main
huviväärsustest	doc_13389385120_item	2239970	et	4	main
keele	doc_13389385120_item	2239972	et	4	main
ainekava	doc_13389385120_item	2239978	et	4	main
kutselise	doc_13389385120_item	2240016	et	4	main
ja	doc_13389385120_item	2240018	et	3	main
20	doc_13389385120_item	2240022	et	2	main
poole	doc_13389385120_item	2240025	et	4	main
ajakirjandusest	doc_13389385120_item	2240029	et	4	main
poole	doc_13389385120_item	2240036	et	4	main
kultuurielu	doc_13389385120_item	2240037	et	4	main
näiteid	doc_13389385120_item	2240038	et	3	main
luulest	doc_13389385120_item	2240041	et	4	main
filmilinal	doc_13389385120_item	2240044	et	3	main
ja	doc_13389385120_item	2240047	et	3	main
eesti	doc_13389385120_item	2240055	et	4	main
kujunemine	doc_13389385120_item	2240073	et	4	main
keeleteadlase	doc_13389385120_item	2240075	et	3	main
koostamise	doc_13389385120_item	2240079	et	4	main
õismäe	doc_13389385120_item	2240089	et	3	main
keele	doc_13389385120_item	2240093	et	4	main
rahvussümboolikastlindlillpuu	doc_13389385120_item	2240107	et	4	main
rahvakalendri	doc_13389385120_item	2240109	et	3	main
nende	doc_13389385120_item	2240121	et	4	main
tunnis	doc_13389385120_item	2240127	et	3	main
tähistavad	doc_13389385120_item	2240134	et	4	main
kokku	doc_13389385120_item	2240142	et	3	main
lange	doc_13389385120_item	2240144	et	4	main
on	doc_13389385120_item	2240148	et	4	main
nad	doc_13389385120_item	2240151	et	3	main
klass	doc_13389385120_item	2240158	et	3	main
õpilasel	doc_13389385120_item	2240159	et	3	main
tegevust	doc_13389385120_item	2240170	et	4	main
klassidevaheline	doc_13389385120_item	2240222	et	4	main
julupühade	doc_13389385120_item	2240229	et	4	main
tähistamine	doc_13389385120_item	2240230	et	4	main
tähistamine	doc_13389385120_item	2240232	et	4	main
eesti	doc_13389385120_item	2240242	et	4	main
tiritamm	doc_13389385120_item	2240246	et	3	main
mõistavad	doc_13389385120_item	2240252	et	3	main
ja	doc_13389385120_item	2240254	et	3	main
ja	doc_13389385120_item	2240270	et	3	main
on	doc_13389385120_item	2240279	et	4	main
mardisantidel	doc_13389385120_item	2240281	et	3	main
riikliku	doc_13389385120_item	2239797	et	3	main
põhimõtted	doc_13389385120_item	2239799	et	3	main
ja	doc_13389385120_item	2239806	et	3	main
ja	doc_13389385120_item	2239810	et	3	main
kooli	doc_13389385120_item	2239820	et	4	main
õiguslikust	doc_13389385120_item	2239821	et	4	main
eesti	doc_13389385120_item	2239823	et	4	main
keele	doc_13389385120_item	2239824	et	4	main
õpilane	doc_13389385120_item	2239828	et	3	main
ja	doc_13389385120_item	2239834	et	3	main
jõulud	doc_13389385120_item	2239845	et	3	main
klassile	doc_13389385120_item	2239852	et	3	main
kooliastmel	doc_13389385120_item	2239854	et	3	main
õpilane	doc_13389385120_item	2239856	et	3	main
teadmised	doc_13389385120_item	2239866	et	4	main
paikkonna	doc_13389385120_item	2239873	et	3	main
eripäraleloodus	doc_13389385120_item	2239904	et	4	main
kultuurilugusenisest	doc_13389385120_item	2239906	et	3	main
pakutakse	doc_13389385120_item	2239908	et	3	main
eesti	doc_13389385120_item	2239912	et	4	main
korraldatakse	doc_13389385120_item	2239914	et	3	main
seisundist	doc_13389385120_item	2239822	et	3	main
klassile	doc_13389385120_item	2239827	et	3	main
teadmised	doc_13389385120_item	2239831	et	4	main
eestist	doc_13389385120_item	2239832	et	3	main
rahvussümbolikast	doc_13389385120_item	2239833	et	3	main
ja	doc_13389385120_item	2239838	et	3	main
mardipäev	doc_13389385120_item	2239844	et	3	main
sõbrapäev	doc_13389385120_item	2239846	et	3	main
keele	doc_13389385120_item	2239849	et	4	main
jutustama	doc_13389385120_item	2239864	et	3	main
õpilase	doc_13389385120_item	2239865	et	3	main
eesti	doc_13389385120_item	2239867	et	4	main
kultuurist	doc_13389385120_item	2239868	et	3	main
ja	doc_13389385120_item	2239875	et	3	main
kultuuritegelasedraamatukogujutte	doc_13389385120_item	2239876	et	4	main
ja	doc_13389385120_item	2239877	et	3	main
luuletusi	doc_13389385120_item	2239878	et	4	main
eesti	doc_13389385120_item	2239879	et	4	main
lastekirjandusestnäited	doc_13389385120_item	2239880	et	4	main
vanasõnadest	doc_13389385120_item	2239881	et	3	main
mõistatusest	doc_13389385120_item	2239882	et	4	main
kõnekäändusest	doc_13389385120_item	2239883	et	3	main
riigipühad	doc_13389385120_item	2239884	et	3	main
ja	doc_13389385120_item	2239885	et	3	main
tähtpäevadeesti	doc_13389385120_item	2239886	et	4	main
lippvapphümneesti	doc_13389385120_item	2239887	et	4	main
president	doc_13389385120_item	2239888	et	3	main
6klassi	doc_13389385120_item	2239889	et	4	main
lõpetaja	doc_13389385120_item	2239890	et	4	main
teab	doc_13389385120_item	2239891	et	3	main
eesti	doc_13389385120_item	2239892	et	4	main
sümboleid	doc_13389385120_item	2239893	et	3	main
eesti	doc_13389385120_item	2239894	et	4	main
keele	doc_13389385120_item	2239895	et	4	main
ainekava	doc_13389385120_item	2239896	et	4	main
7	doc_13389385120_item	2239897	et	2	main
kadri-	doc_13389385120_item	2239842	et	4	main
ainekava	doc_13389385120_item	2239850	et	4	main
teadvustab	doc_13389385120_item	2239855	et	3	main
eesti	doc_13389385120_item	2239862	et	4	main
laienevad	doc_13389385120_item	2239869	et	4	main
ja	doc_13389385120_item	2239871	et	3	main
kultuur	doc_13389385120_item	2239872	et	3	main
vaatamisväärsused	doc_13389385120_item	2239874	et	4	main
9	doc_13389385120_item	2239898	et	2	main
sel	doc_13389385120_item	2239900	et	3	main
keskendutakse	doc_13389385120_item	2239902	et	3	main
kliima	doc_13389385120_item	2239905	et	4	main
klassiväliseid	doc_13389385120_item	2239916	et	4	main
käiakse	doc_13389385120_item	2239918	et	3	main
jm	doc_13389385120_item	2239922	et	4	main
ja	doc_13389385120_item	2239924	et	3	main
objektid	doc_13389385120_item	2239930	et	3	main
sündmused	doc_13389385120_item	2239931	et	3	main
noorsookirjandusest	doc_13389385120_item	2239936	et	4	main
eesti	doc_13389385120_item	2239948	et	4	main
keeles	doc_13389385120_item	2239949	et	4	main
kultuuritegelastjutustab	doc_13389385120_item	2239964	et	4	main
ja	doc_13389385120_item	2239966	et	3	main
gümnaasiumile	doc_13389385120_item	2239974	et	3	main
gümnaasiumi	doc_13389385120_item	2239975	et	4	main
traditsiooni	doc_13389385120_item	2240020	et	4	main
i	doc_13389385120_item	2240024	et	4	main
näiteid	doc_13389385120_item	2240027	et	3	main
teadusest	doc_13389385120_item	2240032	et	4	main
sajandi	doc_13389385120_item	2240034	et	3	main
kirjandus	doc_13389385120_item	2240043	et	3	main
kunstniku	doc_13389385120_item	2240048	et	3	main
tutvustus	doc_13389385120_item	2240050	et	4	main
kultuurisaate	doc_13389385120_item	2240052	et	3	main
23	doc_13389385120_item	2240074	et	2	main
printsiibid	doc_13389385120_item	2240080	et	3	main
lütseumi	doc_13389385120_item	2240091	et	4	main
kooliõppekava	doc_13389385120_item	2240094	et	4	main
1klass	doc_13389385120_item	2240095	et	3	main
õpilane	doc_13389385120_item	2240096	et	3	main
tekste	doc_13389385120_item	2240099	et	3	main
jm	doc_13389385120_item	2240102	et	4	main
esmased	doc_13389385120_item	2240104	et	3	main
ja	doc_13389385120_item	2240125	et	3	main
ja	doc_13389385120_item	2240132	et	3	main
millal	doc_13389385120_item	2240133	et	3	main
vene	doc_13389385120_item	2240140	et	4	main
tähendusi	doc_13389385120_item	2240156	et	4	main
kontakt	doc_13389385120_item	2240161	et	3	main
kasutatakse	doc_13389385120_item	2240166	et	3	main
tähelepanu	doc_13389385120_item	2240173	et	4	main
lugemine	doc_13389385120_item	2240177	et	4	main
põhjal	doc_13389385120_item	2240180	et	4	main
vastamine	doc_13389385120_item	2240182	et	4	main
jutustamine	doc_13389385120_item	2240184	et	4	main
emadepäeva	doc_13389385120_item	2240231	et	4	main
laste	doc_13389385120_item	2240233	et	4	main
kasutatakse	doc_13389385120_item	2240235	et	3	main
raamatuid	doc_13389385120_item	2240238	et	3	main
mõista	doc_13389385120_item	2240240	et	4	main
tallinn	doc_13389385120_item	2240245	et	4	main
1992laulukogumikkeeesti	doc_13389385120_item	2240247	et	4	main
nende	doc_13389385120_item	2240258	et	4	main
seotud	doc_13389385120_item	2240260	et	4	main
laulma	doc_13389385120_item	2240269	et	3	main
neile	doc_13389385120_item	2240273	et	4	main
ande	doc_13389385120_item	2240275	et	4	main
ja	doc_13389385120_item	2240282	et	3	main
jääb	doc_13389385120_item	2240285	et	3	main
lill	doc_13389385120_item	2240297	et	3	main
on	doc_13389385120_item	2240331	et	4	main
eesti	doc_13389385120_item	2240337	et	4	main
täiendab	doc_13389385120_item	2240339	et	3	main
tähtpäevadest	doc_13389385120_item	2240346	et	3	main
neid	doc_13389385120_item	2240362	et	4	main
praktikal	doc_13389385120_item	2240364	et	3	main
mardipäeva	doc_13389385120_item	2240368	et	4	main
emadepäeva	doc_13389385120_item	2240376	et	4	main
kus	doc_13389385120_item	2240378	et	3	main
näha	doc_13389385120_item	2240382	et	3	main
päevad	doc_13389385120_item	2240385	et	3	main
selle	doc_13389385120_item	2240393	et	4	main
miks	doc_13389385120_item	2240397	et	4	main
klassile	doc_13389385120_item	2239899	et	3	main
tetris	doc_13389385120_item	2239919	et	4	main
kultuurielu	doc_13389385120_item	2239926	et	4	main
olulised	doc_13389385120_item	2239933	et	4	main
muinasjuttudest	doc_13389385120_item	2239938	et	3	main
naljanditest	doc_13389385120_item	2239940	et	3	main
lõpetaja	doc_13389385120_item	2239943	et	4	main
2-3	doc_13389385120_item	2239945	et	2	main
keeleliselt	doc_13389385120_item	2239954	et	4	main
jõukohast	doc_13389385120_item	2239955	et	4	main
ja	doc_13389385120_item	2239962	et	3	main
paikkonna	doc_13389385120_item	2239965	et	3	main
eluolust	doc_13389385120_item	2239968	et	3	main
eesti	doc_13389385120_item	2239976	et	4	main
keele	doc_13389385120_item	2239977	et	4	main
9	doc_13389385120_item	2239980	et	2	main
kursuseks	doc_13389385120_item	2239982	et	3	main
teatri	doc_13389385120_item	2240017	et	3	main
sajandi	doc_13389385120_item	2240023	et	3	main
kultuurielu	doc_13389385120_item	2240026	et	4	main
eesti	doc_13389385120_item	2240042	et	4	main
ja	doc_13389385120_item	2240057	et	3	main
tegevuse	doc_13389385120_item	2240076	et	4	main
õigekeelsussõnaraamatu	doc_13389385120_item	2240078	et	4	main
ja	doc_13389385120_item	2240081	et	3	main
seosed	doc_13389385120_item	2240085	et	3	main
tõlkekirjandus	doc_13389385120_item	2240086	et	3	main
kirjutab	doc_13389385120_item	2240097	et	3	main
tähtpäevadestjõulud	doc_13389385120_item	2240110	et	4	main
emadepäev	doc_13389385120_item	2240112	et	3	main
õpilane	doc_13389385120_item	2240115	et	3	main
eesti	doc_13389385120_item	2240118	et	4	main
ja	doc_13389385120_item	2240120	et	3	main
tähendust	doc_13389385120_item	2240122	et	4	main
eesti	doc_13389385120_item	2240129	et	4	main
jõulutraditsioone	doc_13389385120_item	2240130	et	3	main
jõulud	doc_13389385120_item	2240141	et	3	main
ja	doc_13389385120_item	2240146	et	3	main
õpilastele	doc_13389385120_item	2240149	et	4	main
keeleõppes	doc_13389385120_item	2240167	et	3	main
ja	doc_13389385120_item	2240171	et	3	main
lihtsamaid	doc_13389385120_item	2240187	et	4	main
tähtpäevakaarte	doc_13389385120_item	2240189	et	4	main
sünnipäevakutseid	doc_13389385120_item	2240190	et	3	main
mardipäeva	doc_13389385120_item	2240223	et	4	main
tähistamine	doc_13389385120_item	2240224	et	4	main
kadripäeva	doc_13389385120_item	2240226	et	4	main
tähistamine	doc_13389385120_item	2240227	et	4	main
klassidevaheline	doc_13389385120_item	2240228	et	4	main
arenguks	doc_13389385120_item	2240234	et	3	main
peale	doc_13389385120_item	2240236	et	4	main
ka	doc_13389385120_item	2240239	et	3	main
rahva	doc_13389385120_item	2240243	et	3	main
õpetajate	doc_13389385120_item	2240249	et	4	main
õpilased	doc_13389385120_item	2240251	et	3	main
päevadega	doc_13389385120_item	2240259	et	3	main
et	doc_13389385120_item	2240264	et	3	main
ja	doc_13389385120_item	2240266	et	3	main
antakse	doc_13389385120_item	2240274	et	3	main
kuid	doc_13389385120_item	2240276	et	4	main
roll	doc_13389385120_item	2240278	et	3	main
mõistatuseks	doc_13389385120_item	2240287	et	4	main
õpilased	doc_13389385120_item	2240288	et	3	main
puu	doc_13389385120_item	2240299	et	4	main
enamus	doc_13389385120_item	2240301	et	4	main
õpilastel	doc_13389385120_item	2240302	et	4	main
kuuluvad	doc_13389385120_item	2240306	et	4	main
rahvussümboolika	doc_13389385120_item	2240310	et	4	main
mina	doc_13389385120_item	2239923	et	4	main
kultuuritegelased	doc_13389385120_item	2239934	et	3	main
legendidest	doc_13389385120_item	2239941	et	3	main
on	doc_13389385120_item	2239947	et	4	main
lugenud	doc_13389385120_item	2239950	et	4	main
eakohast	doc_13389385120_item	2239952	et	4	main
ja	doc_13389385120_item	2239953	et	3	main
eesti	doc_13389385120_item	2239957	et	4	main
tähtsamaid	doc_13389385120_item	2239959	et	4	main
objekte	doc_13389385120_item	2239960	et	3	main
sündmusi	doc_13389385120_item	2239961	et	3	main
ainekava	doc_13389385120_item	2239973	et	4	main
kohustusliks	doc_13389385120_item	2239981	et	4	main
ühe	doc_13389385120_item	2239983	et	4	main
kursuse	doc_13389385120_item	2239984	et	3	main
maht	doc_13389385120_item	2239985	et	3	main
on	doc_13389385120_item	2239986	et	4	main
35	doc_13389385120_item	2239987	et	2	main
õppetundi	doc_13389385120_item	2239988	et	4	main
kursuste	doc_13389385120_item	2239989	et	3	main
järjestus	doc_13389385120_item	2239990	et	4	main
ja	doc_13389385120_item	2239991	et	3	main
maht	doc_13389385120_item	2239992	et	3	main
kooliõppekavas	doc_13389385120_item	2239994	et	3	main
fikseeritakse	doc_13389385120_item	2239993	et	3	main
kultuuriloo	doc_13389385120_item	2239995	et	4	main
õpetamiseks	doc_13389385120_item	2239996	et	4	main
on	doc_13389385120_item	2239997	et	4	main
kavandatud	doc_13389385120_item	2239998	et	4	main
2	doc_13389385120_item	2239999	et	2	main
kursust	doc_13389385120_item	2240000	et	3	main
kuid	doc_13389385120_item	2240001	et	4	main
seda	doc_13389385120_item	2240002	et	3	main
võib	doc_13389385120_item	2240003	et	3	main
õpetada	doc_13389385120_item	2240004	et	3	main
ka	doc_13389385120_item	2240005	et	3	main
35-tunnise	doc_13389385120_item	2240006	et	4	main
kursusena	doc_13389385120_item	2240007	et	3	main
ärkamisaegne	doc_13389385120_item	2240009	et	3	main
kultuurilugu	doc_13389385120_item	2240008	et	4	main
kultuurielu	doc_13389385120_item	2240010	et	4	main
rahvusliku	doc_13389385120_item	2240011	et	3	main
kirjanduse	doc_13389385120_item	2240012	et	3	main
ja	doc_13389385120_item	2240013	et	3	main
kunsti	doc_13389385120_item	2240014	et	4	main
sünd	doc_13389385120_item	2240015	et	3	main
kirjandusest	doc_13389385120_item	2240028	et	4	main
kunstist	doc_13389385120_item	2240030	et	4	main
ii	doc_13389385120_item	2240035	et	4	main
ja	doc_13389385120_item	2240040	et	3	main
23	doc_13389385120_item	2240045	et	2	main
arutelu	doc_13389385120_item	2240054	et	4	main
keel	doc_13389385120_item	2240056	et	4	main
teised	doc_13389385120_item	2240058	et	4	main
keeled	doc_13389385120_item	2240059	et	3	main
eesti	doc_13389385120_item	2240060	et	4	main
keel	doc_13389385120_item	2240061	et	4	main
soomeugri	doc_13389385120_item	2240063	et	4	main
kui	doc_13389385120_item	2240062	et	3	main
keel	doc_13389385120_item	2240064	et	4	main
struktuurilised	doc_13389385120_item	2240065	et	4	main
erinevused	doc_13389385120_item	2240066	et	4	main
eesti	doc_13389385120_item	2240067	et	4	main
ja	doc_13389385120_item	2240068	et	3	main
keeles	doc_13389385120_item	2240070	et	4	main
vene	doc_13389385120_item	2240069	et	4	main
algus	doc_13389385120_item	2240021	et	4	main
muusikast	doc_13389385120_item	2240031	et	4	main
20	doc_13389385120_item	2240033	et	2	main
proosast	doc_13389385120_item	2240039	et	4	main
muusikategelase	doc_13389385120_item	2240046	et	3	main
loomingu	doc_13389385120_item	2240049	et	3	main
eestikeelse	doc_13389385120_item	2240051	et	3	main
teatrietenduse	doc_13389385120_item	2240053	et	3	main
eesti	doc_13389385120_item	2240071	et	4	main
tutvustus	doc_13389385120_item	2240077	et	4	main
kasutamine	doc_13389385120_item	2240082	et	4	main
vahelised	doc_13389385120_item	2240084	et	4	main
13tallinna	doc_13389385120_item	2240088	et	4	main
eesti	doc_13389385120_item	2240092	et	4	main
sünnipäevakutseid	doc_13389385120_item	2240101	et	3	main
teadmised	doc_13389385120_item	2240105	et	4	main
eestist	doc_13389385120_item	2240106	et	3	main
ja	doc_13389385120_item	2240108	et	3	main
õpetaja	doc_13389385120_item	2240113	et	4	main
kommentaar	doc_13389385120_item	2240114	et	3	main
õpib	doc_13389385120_item	2240116	et	3	main
eesti	doc_13389385120_item	2240123	et	4	main
kuidas	doc_13389385120_item	2240131	et	3	main
eestlased	doc_13389385120_item	2240135	et	3	main
miks	doc_13389385120_item	2240137	et	4	main
sõbrapäev	doc_13389385120_item	2240145	et	3	main
mõistetavamad	doc_13389385120_item	2240150	et	4	main
oskavad	doc_13389385120_item	2240152	et	4	main
nende	doc_13389385120_item	2240154	et	4	main
tekib	doc_13389385120_item	2240160	et	3	main
kultuuriruumiga	doc_13389385120_item	2240163	et	4	main
palju	doc_13389385120_item	2240168	et	4	main
on	doc_13389385120_item	2240175	et	4	main
vestlemine	doc_13389385120_item	2240183	et	4	main
õpilane	doc_13389385120_item	2240185	et	3	main
jm	doc_13389385120_item	2240191	et	4	main
täiendab	doc_13389385120_item	2240192	et	3	main
oma	doc_13389385120_item	2240193	et	4	main
nt	doc_13389385120_item	2240221	et	4	main
klassidevaheline	doc_13389385120_item	2240225	et	4	main
mõista	doc_13389385120_item	2240241	et	4	main
mõistatusi	doc_13389385120_item	2240244	et	4	main
kommentaarid	doc_13389385120_item	2240250	et	3	main
teavad	doc_13389385120_item	2240263	et	3	main
mardisandid	doc_13389385120_item	2240265	et	4	main
peavad	doc_13389385120_item	2240268	et	4	main
tantsima	doc_13389385120_item	2240271	et	3	main
mis	doc_13389385120_item	2240277	et	4	main
tegelikult	doc_13389385120_item	2240280	et	4	main
neile	doc_13389385120_item	2240286	et	4	main
tea	doc_13389385120_item	2240290	et	4	main
toovad	doc_13389385120_item	2240293	et	4	main
ja	doc_13389385120_item	2240298	et	3	main
just	doc_13389385120_item	2240307	et	3	main
eesti	doc_13389385120_item	2240309	et	4	main
on	doc_13389385120_item	2240321	et	4	main
täiesti	doc_13389385120_item	2240324	et	3	main
õppeeesmärgideks	doc_13389385120_item	2240330	et	3	main
see	doc_13389385120_item	2240332	et	3	main
et	doc_13389385120_item	2240333	et	3	main
eestist	doc_13389385120_item	2240342	et	3	main
õpilane	doc_13389385120_item	2240347	et	3	main
puu	doc_13389385120_item	2240354	et	4	main
mardipäev	doc_13389385120_item	2240357	et	3	main
jaanipäevet	doc_13389385120_item	2240361	et	4	main
teadmisi	doc_13389385120_item	2240363	et	4	main
korraldatakse	doc_13389385120_item	2240366	et	3	main
kadripäeva	doc_13389385120_item	2240371	et	4	main
endast	doc_13389385120_item	2240386	et	4	main
üritused	doc_13389385120_item	2240396	et	4	main
seda	doc_13389385120_item	2240399	et	3	main
kuidas	doc_13389385120_item	2240401	et	3	main
ning	doc_13389385120_item	2240405	et	3	main
juba	doc_13389385120_item	2240411	et	3	main
eesti	doc_13389385120_item	2240430	et	4	main
rääkida	doc_13389385120_item	2240433	et	3	main
tähtpäevast	doc_13389385120_item	2240436	et	4	main
ja	doc_13389385120_item	2240438	et	3	main
on	doc_13389385120_item	2240445	et	4	main
või	doc_13389385120_item	2240449	et	4	main
tähtpäevadega	doc_13389385120_item	2240450	et	3	main
teemat	doc_13389385120_item	2240452	et	3	main
koduloo	doc_13389385120_item	2240454	et	4	main
tunnid	doc_13389385120_item	2240455	et	3	main
kirjakeele	doc_13389385120_item	2240072	et	4	main
kultuuride	doc_13389385120_item	2240083	et	3	main
httpswwwriigiteatajaeeertactjspid802290	doc_13389385120_item	2240087	et	4	main
vene	doc_13389385120_item	2240090	et	4	main
lihtsamaid	doc_13389385120_item	2240098	et	4	main
tähtpäevakaarte	doc_13389385120_item	2240100	et	4	main
omandab	doc_13389385120_item	2240103	et	3	main
sõbrapäev	doc_13389385120_item	2240111	et	3	main
tundma	doc_13389385120_item	2240117	et	3	main
rahvussümboolikat	doc_13389385120_item	2240119	et	3	main
keele	doc_13389385120_item	2240124	et	4	main
koduloo	doc_13389385120_item	2240126	et	4	main
õpitakse	doc_13389385120_item	2240128	et	4	main
jõule	doc_13389385120_item	2240136	et	4	main
eesti	doc_13389385120_item	2240138	et	4	main
ja	doc_13389385120_item	2240139	et	3	main
ei	doc_13389385120_item	2240143	et	4	main
emadepäev	doc_13389385120_item	2240147	et	3	main
mõista	doc_13389385120_item	2240153	et	4	main
tähtpäevade	doc_13389385120_item	2240155	et	3	main
2	doc_13389385120_item	2240157	et	2	main
eesti	doc_13389385120_item	2240162	et	4	main
sel	doc_13389385120_item	2240164	et	3	main
kooliastmel	doc_13389385120_item	2240165	et	3	main
praktilist	doc_13389385120_item	2240169	et	3	main
mängu	doc_13389385120_item	2240172	et	4	main
keskmes	doc_13389385120_item	2240174	et	3	main
häälega	doc_13389385120_item	2240176	et	3	main
ja	doc_13389385120_item	2240178	et	3	main
loetu	doc_13389385120_item	2240179	et	4	main
küsimustele	doc_13389385120_item	2240181	et	4	main
kirjutab	doc_13389385120_item	2240186	et	3	main
tekste	doc_13389385120_item	2240188	et	3	main
teadmisi	doc_13389385120_item	2240194	et	4	main
eestistüldandmed	doc_13389385120_item	2240195	et	4	main
rahvussümboolikast	doc_13389385120_item	2240196	et	4	main
rahvuslind	doc_13389385120_item	2240197	et	3	main
lill	doc_13389385120_item	2240198	et	3	main
puu	doc_13389385120_item	2240199	et	4	main
ja	doc_13389385120_item	2240200	et	3	main
rahvakalendri	doc_13389385120_item	2240201	et	3	main
tähtpäevadest	doc_13389385120_item	2240202	et	3	main
kadri-	doc_13389385120_item	2240203	et	4	main
ja	doc_13389385120_item	2240204	et	3	main
mardipäev	doc_13389385120_item	2240205	et	3	main
jõulud	doc_13389385120_item	2240206	et	3	main
sõbrapäev	doc_13389385120_item	2240207	et	3	main
emadepäev	doc_13389385120_item	2240208	et	3	main
jaanipäev	doc_13389385120_item	2240209	et	3	main
samas	doc_13389385120_item	2240210	et	4	main
on	doc_13389385120_item	2240211	et	4	main
käivel	doc_13389385120_item	2240212	et	4	main
mitmesugused	doc_13389385120_item	2240213	et	3	main
ainetevahelised	doc_13389385120_item	2240214	et	4	main
klassidevahelised	doc_13389385120_item	2240215	et	4	main
ülekoolilised	doc_13389385120_item	2240216	et	4	main
ja	doc_13389385120_item	2240217	et	3	main
pikaajalised	doc_13389385120_item	2240218	et	4	main
koolidevahelised	doc_13389385120_item	2240219	et	4	main
projektid	doc_13389385120_item	2240220	et	3	main
õppekavajärgseid	doc_13389385120_item	2240237	et	3	main
muinasjutte	doc_13389385120_item	2240248	et	3	main
kadripäeva	doc_13389385120_item	2240253	et	4	main
mardipäeva	doc_13389385120_item	2240255	et	4	main
tähendust	doc_13389385120_item	2240256	et	4	main
teavad	doc_13389385120_item	2240257	et	3	main
tavasid	doc_13389385120_item	2240261	et	3	main
nad	doc_13389385120_item	2240262	et	3	main
kadrisandid	doc_13389385120_item	2240267	et	4	main
ning	doc_13389385120_item	2240272	et	3	main
kadrisantidel	doc_13389385120_item	2240283	et	3	main
ei	doc_13389385120_item	2240289	et	4	main
nad	doc_13389385120_item	2240292	et	3	main
rahvuslind	doc_13389385120_item	2240296	et	3	main
on	doc_13389385120_item	2240300	et	4	main
hulka	doc_13389385120_item	2240311	et	4	main
seda	doc_13389385120_item	2240312	et	3	main
nad	doc_13389385120_item	2240313	et	3	main
jällegi	doc_13389385120_item	2240314	et	4	main
ei	doc_13389385120_item	2240315	et	4	main
tea	doc_13389385120_item	2240316	et	4	main
ainuke	doc_13389385120_item	2240317	et	4	main
päev	doc_13389385120_item	2240318	et	3	main
mis	doc_13389385120_item	2240319	et	4	main
neil	doc_13389385120_item	2240320	et	4	main
ja	doc_13389385120_item	2240323	et	3	main
mõistetav	doc_13389385120_item	2240325	et	4	main
3	doc_13389385120_item	2240328	et	2	main
kontakt	doc_13389385120_item	2240336	et	3	main
oma	doc_13389385120_item	2240340	et	4	main
teadmisi	doc_13389385120_item	2240341	et	4	main
rääkidaeesti	doc_13389385120_item	2240349	et	4	main
rahvussümboolikast	doc_13389385120_item	2240351	et	4	main
rahvuslind	doc_13389385120_item	2240352	et	3	main
jõulud	doc_13389385120_item	2240358	et	3	main
emadepäev	doc_13389385120_item	2240360	et	3	main
rakendada	doc_13389385120_item	2240365	et	3	main
klassidevaheline	doc_13389385120_item	2240367	et	4	main
tähistamine	doc_13389385120_item	2240369	et	4	main
klassidevaheline	doc_13389385120_item	2240370	et	4	main
jõulupühade	doc_13389385120_item	2240374	et	3	main
saavad	doc_13389385120_item	2240380	et	4	main
mis	doc_13389385120_item	2240383	et	4	main
juurde	doc_13389385120_item	2240390	et	4	main
jaanipäev	doc_13389385120_item	2240392	et	3	main
tähistatakse	doc_13389385120_item	2240402	et	3	main
päeva	doc_13389385120_item	2240404	et	4	main
otsitakse	doc_13389385120_item	2240407	et	3	main
sõnajalaõit	doc_13389385120_item	2240408	et	3	main
kadrisanti	doc_13389385120_item	2240415	et	4	main
see	doc_13389385120_item	2240284	et	3	main
et	doc_13389385120_item	2240291	et	3	main
vilja-ja	doc_13389385120_item	2240294	et	3	main
karjaõnne	doc_13389385120_item	2240295	et	4	main
selge	doc_13389385120_item	2240303	et	4	main
kuid	doc_13389385120_item	2240304	et	4	main
miks	doc_13389385120_item	2240305	et	4	main
nemad	doc_13389385120_item	2240308	et	3	main
klass	doc_13389385120_item	2240329	et	3	main
tekib	doc_13389385120_item	2240335	et	3	main
rahvussümboolikast	doc_13389385120_item	2240343	et	4	main
rahvakalendri	doc_13389385120_item	2240345	et	3	main
oskab	doc_13389385120_item	2240348	et	3	main
üldandmetest	doc_13389385120_item	2240350	et	4	main
lill	doc_13389385120_item	2240353	et	3	main
rahvuskalendritähtpäevadestkadri-	doc_13389385120_item	2240355	et	4	main
tähistamine	doc_13389385120_item	2240372	et	4	main
klassidevaheline	doc_13389385120_item	2240373	et	4	main
reaalselt	doc_13389385120_item	2240381	et	4	main
need	doc_13389385120_item	2240384	et	3	main
õpetajate	doc_13389385120_item	2240388	et	4	main
lisandub	doc_13389385120_item	2240391	et	3	main
seotud	doc_13389385120_item	2240395	et	4	main
päeva	doc_13389385120_item	2240400	et	4	main
seda	doc_13389385120_item	2240403	et	3	main
miks	doc_13389385120_item	2240406	et	4	main
õpilased	doc_13389385120_item	2240409	et	3	main
ise	doc_13389385120_item	2240412	et	4	main
ja	doc_13389385120_item	2240414	et	3	main
oskavad	doc_13389385120_item	2240416	et	4	main
eesti	doc_13389385120_item	2240424	et	4	main
rahvussümboolikat	doc_13389385120_item	2240425	et	3	main
kolmanda	doc_13389385120_item	2240426	et	3	main
õpilane	doc_13389385120_item	2240428	et	3	main
tunneb	doc_13389385120_item	2240429	et	3	main
eesti	doc_13389385120_item	2240462	et	4	main
keeles	doc_13389385120_item	2240463	et	4	main
4	doc_13389385120_item	2240464	et	2	main
huvi	doc_13389385120_item	2240469	et	4	main
vastu	doc_13389385120_item	2240474	et	3	main
vastu	doc_13389385120_item	2240481	et	3	main
paikkonna	doc_13389385120_item	2240487	et	3	main
ja	doc_13389385120_item	2240489	et	3	main
kultuuritegelasiselleks	doc_13389385120_item	2240490	et	4	main
rohkem	doc_13389385120_item	2240492	et	4	main
saada	doc_13389385120_item	2240494	et	4	main
kultuurist	doc_13389385120_item	2240495	et	3	main
lapsed	doc_13389385120_item	2240496	et	3	main
lastekirjandusest	doc_13389385120_item	2240502	et	4	main
vanasõnadest	doc_13389385120_item	2240504	et	3	main
kõnekäändudest	doc_13389385120_item	2240506	et	3	main
rahvussümbolitest	doc_13389385120_item	2240513	et	4	main
eesti	doc_13389385120_item	2240514	et	4	main
vapp	doc_13389385120_item	2240516	et	3	main
presidentselleks	doc_13389385120_item	2240518	et	4	main
et	doc_13389385120_item	2240519	et	3	main
teadmisi	doc_13389385120_item	2240522	et	4	main
vastlad	doc_13389385120_item	2240529	et	3	main
klassidevahelised	doc_13389385120_item	2240531	et	4	main
kas	doc_13389385120_item	2240535	et	3	main
sa	doc_13389385120_item	2240536	et	3	main
eesti	doc_13389385120_item	2240538	et	4	main
olümpiaadid	doc_13389385120_item	2240549	et	3	main
ja	doc_13389385120_item	2240556	et	3	main
koolidevahelised	doc_13389385120_item	2240569	et	4	main
teab	doc_13389385120_item	2240576	et	3	main
keeles	doc_13389385120_item	2240582	et	4	main
keeleliselt	doc_13389385120_item	2240587	et	4	main
muidugi	doc_13389385120_item	2240627	et	4	main
seda	doc_13389385120_item	2240629	et	3	main
selleks	doc_13389385120_item	2240631	et	4	main
kohta	doc_13389385120_item	2240639	et	4	main
tund	doc_13389385120_item	2240643	et	3	main
lastekirjandusest	doc_13389385120_item	2240645	et	4	main
mis	doc_13389385120_item	2240646	et	4	main
tunnijaotusplaani	doc_13389385120_item	2240650	et	4	main
initsiatiivil	doc_13389385120_item	2240656	et	3	main
lastekirjanike	doc_13389385120_item	2240662	et	3	main
oskavad	doc_13389385120_item	2240669	et	4	main
tekitada	doc_13389385120_item	2240670	et	3	main
raamatute	doc_13389385120_item	2240673	et	3	main
kus	doc_13389385120_item	2240705	et	3	main
lapsed	doc_13389385120_item	2240707	et	3	main
selge	doc_13389385120_item	2240322	et	4	main
on	doc_13389385120_item	2240326	et	4	main
emadepäev	doc_13389385120_item	2240327	et	3	main
õpilasel	doc_13389385120_item	2240334	et	3	main
kultuuriruumigata	doc_13389385120_item	2240338	et	4	main
ja	doc_13389385120_item	2240344	et	3	main
ja	doc_13389385120_item	2240356	et	3	main
sõbrapäev	doc_13389385120_item	2240359	et	3	main
tähistamine	doc_13389385120_item	2240375	et	4	main
tähistamine	doc_13389385120_item	2240377	et	4	main
lapsed	doc_13389385120_item	2240379	et	3	main
kujutlevad	doc_13389385120_item	2240387	et	4	main
kommentaarid	doc_13389385120_item	2240389	et	3	main
päevaga	doc_13389385120_item	2240394	et	3	main
mardisanti	doc_13389385120_item	2240413	et	4	main
ja	doc_13389385120_item	2240419	et	3	main
vene	doc_13389385120_item	2240420	et	4	main
mõnedest	doc_13389385120_item	2240434	et	3	main
osalevad	doc_13389385120_item	2240441	et	4	main
üritustel	doc_13389385120_item	2240443	et	4	main
sümboolikaga	doc_13389385120_item	2240448	et	3	main
seda	doc_13389385120_item	2240451	et	3	main
mis	doc_13389385120_item	2240456	et	4	main
vene	doc_13389385120_item	2240460	et	4	main
on	doc_13389385120_item	2240467	et	4	main
armastus	doc_13389385120_item	2240471	et	4	main
kelle	doc_13389385120_item	2240475	et	4	main
elatakse	doc_13389385120_item	2240477	et	3	main
kus	doc_13389385120_item	2240482	et	3	main
elatakse	doc_13389385120_item	2240483	et	3	main
vaatamisväärsusi	doc_13389385120_item	2240488	et	4	main
jutte	doc_13389385120_item	2240498	et	3	main
samas	doc_13389385120_item	2240507	et	4	main
teadmisi	doc_13389385120_item	2240509	et	4	main
praktikal	doc_13389385120_item	2240520	et	3	main
peod	doc_13389385120_item	2240525	et	4	main
nt	doc_13389385120_item	2240526	et	4	main
kadripäev	doc_13389385120_item	2240527	et	3	main
jne	doc_13389385120_item	2240544	et	4	main
peod	doc_13389385120_item	2240546	et	4	main
lapsed	doc_13389385120_item	2240551	et	3	main
oma	doc_13389385120_item	2240553	et	4	main
saavad	doc_13389385120_item	2240558	et	4	main
ülevaade	doc_13389385120_item	2240559	et	3	main
kuidas	doc_13389385120_item	2240560	et	3	main
on	doc_13389385120_item	2240562	et	4	main
uue	doc_13389385120_item	2240563	et	3	main
omandanud	doc_13389385120_item	2240565	et	4	main
klassi	doc_13389385120_item	2240574	et	4	main
on	doc_13389385120_item	2240580	et	4	main
eakohast	doc_13389385120_item	2240585	et	4	main
ainult	doc_13389385120_item	2240621	et	4	main
ülevaate	doc_13389385120_item	2240623	et	4	main
nendest	doc_13389385120_item	2240624	et	4	main
et	doc_13389385120_item	2240632	et	3	main
saaks	doc_13389385120_item	2240634	et	3	main
peaks	doc_13389385120_item	2240640	et	4	main
vene	doc_13389385120_item	2240648	et	4	main
kooli	doc_13389385120_item	2240649	et	4	main
kutsuda	doc_13389385120_item	2240659	et	3	main
eesti	doc_13389385120_item	2240661	et	4	main
oma	doc_13389385120_item	2240665	et	4	main
huvi	doc_13389385120_item	2240672	et	4	main
vastu	doc_13389385120_item	2240704	et	3	main
õpivad	doc_13389385120_item	2240708	et	3	main
ja	doc_13389385120_item	2240712	et	3	main
kultuuritegelasiselleks	doc_13389385120_item	2240713	et	4	main
saada	doc_13389385120_item	2240717	et	4	main
lapsed	doc_13389385120_item	2240719	et	3	main
ja	doc_13389385120_item	2240722	et	3	main
samas	doc_13389385120_item	2240729	et	4	main
eesti	doc_13389385120_item	2240735	et	4	main
hümneesti	doc_13389385120_item	2240740	et	4	main
klassidevahelised	doc_13389385120_item	2240743	et	4	main
peod	doc_13389385120_item	2240744	et	4	main
kadripäev	doc_13389385120_item	2240745	et	3	main
vastlad	doc_13389385120_item	2240747	et	3	main
klassidevahelised	doc_13389385120_item	2240749	et	4	main
kas	doc_13389385120_item	2240753	et	3	main
eesti	doc_13389385120_item	2240756	et	4	main
kas	doc_13389385120_item	2240758	et	3	main
tunned	doc_13389385120_item	2240760	et	3	main
tähistatakse	doc_13389385120_item	2240398	et	3	main
jooksevad	doc_13389385120_item	2240410	et	4	main
võrrelda	doc_13389385120_item	2240417	et	4	main
eesti	doc_13389385120_item	2240418	et	4	main
jõulukombeid	doc_13389385120_item	2240421	et	4	main
teavad	doc_13389385120_item	2240423	et	3	main
klassi	doc_13389385120_item	2240427	et	4	main
õpilased	doc_13389385120_item	2240440	et	3	main
koolisisestel	doc_13389385120_item	2240442	et	3	main
seotud	doc_13389385120_item	2240446	et	4	main
on	doc_13389385120_item	2240457	et	4	main
klass	doc_13389385120_item	2240465	et	3	main
äratada	doc_13389385120_item	2240468	et	3	main
selle	doc_13389385120_item	2240472	et	4	main
maa	doc_13389385120_item	2240480	et	4	main
lapsed	doc_13389385120_item	2240484	et	3	main
et	doc_13389385120_item	2240491	et	3	main
loevad	doc_13389385120_item	2240497	et	3	main
luuletusi	doc_13389385120_item	2240500	et	4	main
mõistatustest	doc_13389385120_item	2240505	et	4	main
lipp	doc_13389385120_item	2240515	et	3	main
viktoriinid	doc_13389385120_item	2240534	et	3	main
keelt	doc_13389385120_item	2240539	et	4	main
tunned	doc_13389385120_item	2240542	et	3	main
siin	doc_13389385120_item	2240550	et	4	main
lapsed	doc_13389385120_item	2240561	et	3	main
samas	doc_13389385120_item	2240566	et	4	main
käivel	doc_13389385120_item	2240568	et	4	main
4	doc_13389385120_item	2240573	et	2	main
ta	doc_13389385120_item	2240590	et	4	main
samuti	doc_13389385120_item	2240422	et	3	main
sümboolikat	doc_13389385120_item	2240431	et	3	main
oskab	doc_13389385120_item	2240432	et	3	main
rahvakalendri	doc_13389385120_item	2240435	et	3	main
mardipäev	doc_13389385120_item	2240437	et	3	main
kadripäev	doc_13389385120_item	2240439	et	3	main
mis	doc_13389385120_item	2240444	et	4	main
eesti	doc_13389385120_item	2240447	et	4	main
toetavad	doc_13389385120_item	2240453	et	4	main
õismäe	doc_13389385120_item	2240459	et	3	main
lütseumis	doc_13389385120_item	2240461	et	3	main
õppeeeasmärgiks	doc_13389385120_item	2240466	et	4	main
rahva	doc_13389385120_item	2240473	et	3	main
keskel	doc_13389385120_item	2240476	et	3	main
ja	doc_13389385120_item	2240478	et	3	main
õpivad	doc_13389385120_item	2240485	et	3	main
eesti	doc_13389385120_item	2240501	et	4	main
näiteid	doc_13389385120_item	2240503	et	3	main
arendatakse	doc_13389385120_item	2240508	et	3	main
tähtpäevadesteesti	doc_13389385120_item	2240512	et	4	main
hümneesti	doc_13389385120_item	2240517	et	4	main
tallinna	doc_13389385120_item	2240458	et	4	main
ja	doc_13389385120_item	2240470	et	3	main
selle	doc_13389385120_item	2240479	et	4	main
tundma	doc_13389385120_item	2240486	et	3	main
aru	doc_13389385120_item	2240493	et	4	main
ja	doc_13389385120_item	2240499	et	3	main
riigipühadest	doc_13389385120_item	2240510	et	3	main
ja	doc_13389385120_item	2240511	et	3	main
rakendada	doc_13389385120_item	2240521	et	3	main
korraldatakse	doc_13389385120_item	2240523	et	3	main
kas	doc_13389385120_item	2240540	et	3	main
sa	doc_13389385120_item	2240541	et	3	main
ja	doc_13389385120_item	2240548	et	3	main
saavad	doc_13389385120_item	2240552	et	4	main
täiendada	doc_13389385120_item	2240555	et	3	main
materjali	doc_13389385120_item	2240564	et	4	main
on	doc_13389385120_item	2240567	et	4	main
projektid	doc_13389385120_item	2240570	et	3	main
järgi	doc_13389385120_item	2240572	et	4	main
lastekirjanikke	doc_13389385120_item	2240578	et	3	main
ta	doc_13389385120_item	2240579	et	4	main
eesti	doc_13389385120_item	2240581	et	4	main
lugenud	doc_13389385120_item	2240583	et	4	main
ja	doc_13389385120_item	2240586	et	3	main
jõukohast	doc_13389385120_item	2240588	et	4	main
lasteraamatut	doc_13389385120_item	2240589	et	3	main
kirjanikest	doc_13389385120_item	2240625	et	3	main
olema	doc_13389385120_item	2240641	et	4	main
on	doc_13389385120_item	2240657	et	4	main
lähemalt	doc_13389385120_item	2240667	et	4	main
ja	doc_13389385120_item	2240668	et	3	main
tundma	doc_13389385120_item	2240709	et	3	main
vaatamisväärsusi	doc_13389385120_item	2240711	et	4	main
eesti	doc_13389385120_item	2240724	et	4	main
riigipühadest	doc_13389385120_item	2240732	et	3	main
vapp	doc_13389385120_item	2240739	et	3	main
viktoriinid	doc_13389385120_item	2240752	et	3	main
keelt	doc_13389385120_item	2240757	et	4	main
plaani	doc_13389385120_item	2240769	et	4	main
lastekirjanikke	doc_13389385120_item	2240776	et	3	main
eesti	doc_13389385120_item	2240778	et	4	main
jõukohast	doc_13389385120_item	2240785	et	4	main
on	doc_13389385120_item	2240792	et	4	main
raua	doc_13389385120_item	2240822	et	3	main
kõik	doc_13389385120_item	2240827	et	4	main
õnn	doc_13389385120_item	2240831	et	3	main
ning	doc_13389385120_item	2240843	et	3	main
tutvutud	doc_13389385120_item	2240847	et	4	main
tutvutakse	doc_13389385120_item	2240850	et	3	main
emakeele	doc_13389385120_item	2240852	et	4	main
ning	doc_13389385120_item	2240854	et	3	main
siis	doc_13389385120_item	2240858	et	3	main
on	doc_13389385120_item	2240869	et	4	main
ning	doc_13389385120_item	2240883	et	3	main
tegelesid	doc_13389385120_item	2240886	et	4	main
on	doc_13389385120_item	2240888	et	4	main
traditsioonid	doc_13389385120_item	2240892	et	3	main
5	doc_13389385120_item	2240898	et	2	main
ajalootunnid	doc_13389385120_item	2240900	et	3	main
sellest	doc_13389385120_item	2240924	et	4	main
lapsed	doc_13389385120_item	2240932	et	3	main
tundma	doc_13389385120_item	2240934	et	3	main
et	doc_13389385120_item	2240939	et	3	main
rohkem	doc_13389385120_item	2240941	et	4	main
saada	doc_13389385120_item	2240943	et	4	main
lapsed	doc_13389385120_item	2240944	et	3	main
kõnekäändudest	doc_13389385120_item	2240954	et	3	main
teadmisi	doc_13389385120_item	2240957	et	4	main
toimub	doc_13389385120_item	2240967	et	3	main
rahvakalendri	doc_13389385120_item	2240968	et	3	main
klassidevaheline	doc_13389385120_item	2240970	et	4	main
tähistamineülekoolilised	doc_13389385120_item	2240975	et	4	main
klassidevaheline	doc_13389385120_item	2240979	et	4	main
viktoriin	doc_13389385120_item	2240980	et	3	main
eestimaad	doc_13389385120_item	2240983	et	4	main
lastekirjanikke	doc_13389385120_item	2240988	et	3	main
4-5	doc_13389385120_item	2240993	et	2	main
jõukohast	doc_13389385120_item	2240997	et	4	main
eesti	doc_13389385120_item	2240999	et	4	main
vanasõnu	doc_13389385120_item	2241022	et	3	main
kõnekäände	doc_13389385120_item	2241024	et	4	main
suurem	doc_13389385120_item	2241028	et	4	main
läbivatele	doc_13389385120_item	2241033	et	4	main
klassidevahelised	doc_13389385120_item	2240524	et	4	main
mardipäev	doc_13389385120_item	2240528	et	3	main
jne	doc_13389385120_item	2240530	et	4	main
võistlused	doc_13389385120_item	2240532	et	3	main
ja	doc_13389385120_item	2240533	et	3	main
oskad	doc_13389385120_item	2240537	et	3	main
eestimaad	doc_13389385120_item	2240543	et	4	main
üldkoolilised	doc_13389385120_item	2240545	et	4	main
viktoriinid	doc_13389385120_item	2240547	et	3	main
teadmisi	doc_13389385120_item	2240554	et	4	main
õpetajad	doc_13389385120_item	2240557	et	4	main
plaani	doc_13389385120_item	2240571	et	4	main
lõpetaja	doc_13389385120_item	2240575	et	4	main
eesti	doc_13389385120_item	2240577	et	4	main
2-3	doc_13389385120_item	2240584	et	2	main
oskab	doc_13389385120_item	2240591	et	3	main
nimetada	doc_13389385120_item	2240592	et	3	main
eesti	doc_13389385120_item	2240593	et	4	main
riigi	doc_13389385120_item	2240594	et	3	main
sümboleid	doc_13389385120_item	2240595	et	3	main
õpetaja	doc_13389385120_item	2240596	et	4	main
kommentaar	doc_13389385120_item	2240597	et	3	main
klassi	doc_13389385120_item	2240599	et	4	main
õpilased	doc_13389385120_item	2240600	et	3	main
neljanda	doc_13389385120_item	2240598	et	3	main
tutvuvad	doc_13389385120_item	2240601	et	4	main
jõukohaste	doc_13389385120_item	2240602	et	4	main
lasteraamatutega	doc_13389385120_item	2240603	et	3	main
külastavad	doc_13389385120_item	2240604	et	4	main
nukuteatrit	doc_13389385120_item	2240605	et	3	main
ning	doc_13389385120_item	2240606	et	3	main
telesaateid	doc_13389385120_item	2240608	et	3	main
see	doc_13389385120_item	2240609	et	3	main
vaatavad	doc_13389385120_item	2240607	et	4	main
on	doc_13389385120_item	2240610	et	4	main
esimene	doc_13389385120_item	2240611	et	3	main
selline	doc_13389385120_item	2240612	et	4	main
tutvus	doc_13389385120_item	2240613	et	4	main
eesti	doc_13389385120_item	2240614	et	4	main
lastekirjanikega	doc_13389385120_item	2240615	et	3	main
kuid	doc_13389385120_item	2240616	et	4	main
kahjuks	doc_13389385120_item	2240617	et	4	main
saab	doc_13389385120_item	2240618	et	3	main
tundides	doc_13389385120_item	2240619	et	3	main
anda	doc_13389385120_item	2240620	et	3	main
põgusa	doc_13389385120_item	2240622	et	3	main
ning	doc_13389385120_item	2240626	et	3	main
ilusa	doc_13389385120_item	2240635	et	3	main
eesti	doc_13389385120_item	2240637	et	4	main
eraldi	doc_13389385120_item	2240642	et	4	main
eesti	doc_13389385120_item	2240644	et	4	main
mahu	doc_13389385120_item	2240652	et	4	main
ainult	doc_13389385120_item	2240653	et	4	main
kooli	doc_13389385120_item	2240654	et	4	main
on	doc_13389385120_item	2240628	et	4	main
vähe	doc_13389385120_item	2240630	et	3	main
õpilane	doc_13389385120_item	2240633	et	3	main
ülevaate	doc_13389385120_item	2240636	et	4	main
lastekirjanduse	doc_13389385120_item	2240638	et	3	main
kahjuks	doc_13389385120_item	2240647	et	4	main
ei	doc_13389385120_item	2240651	et	4	main
võimalik	doc_13389385120_item	2240658	et	3	main
kes	doc_13389385120_item	2240663	et	4	main
õpilastes	doc_13389385120_item	2240671	et	4	main
tallinna	doc_13389385120_item	2240675	et	4	main
õismäe	doc_13389385120_item	2240676	et	3	main
vene	doc_13389385120_item	2240677	et	4	main
lütseumi	doc_13389385120_item	2240678	et	4	main
on	doc_13389385120_item	2240679	et	4	main
külastanud	doc_13389385120_item	2240680	et	4	main
leelo	doc_13389385120_item	2240681	et	4	main
jaan	doc_13389385120_item	2240683	et	3	main
tungal	doc_13389385120_item	2240682	et	4	main
rannap	doc_13389385120_item	2240684	et	4	main
henno	doc_13389385120_item	2240685	et	4	main
käo	doc_13389385120_item	2240686	et	3	main
jne	doc_13389385120_item	2240687	et	4	main
5klass	doc_13389385120_item	2240688	et	3	main
esmärgiks	doc_13389385120_item	2240689	et	4	main
on	doc_13389385120_item	2240690	et	4	main
äratada	doc_13389385120_item	2240691	et	3	main
huvi	doc_13389385120_item	2240692	et	4	main
ja	doc_13389385120_item	2240693	et	3	main
armastus	doc_13389385120_item	2240694	et	4	main
selle	doc_13389385120_item	2240695	et	4	main
rahva	doc_13389385120_item	2240696	et	3	main
vastu	doc_13389385120_item	2240697	et	3	main
kelle	doc_13389385120_item	2240698	et	4	main
keskel	doc_13389385120_item	2240699	et	3	main
elatakse	doc_13389385120_item	2240700	et	3	main
ja	doc_13389385120_item	2240701	et	3	main
selle	doc_13389385120_item	2240702	et	4	main
maa	doc_13389385120_item	2240703	et	4	main
enda	doc_13389385120_item	2240655	et	4	main
kooli	doc_13389385120_item	2240660	et	4	main
räägivad	doc_13389385120_item	2240664	et	3	main
loomingust	doc_13389385120_item	2240666	et	3	main
vastu	doc_13389385120_item	2240674	et	3	main
elatakse	doc_13389385120_item	2240706	et	3	main
kultuurist	doc_13389385120_item	2240718	et	3	main
paikkonna	doc_13389385120_item	2240710	et	3	main
et	doc_13389385120_item	2240714	et	3	main
rohkem	doc_13389385120_item	2240715	et	4	main
loevad	doc_13389385120_item	2240720	et	3	main
lastekirjandusestnäiteid	doc_13389385120_item	2240725	et	4	main
arendatakse	doc_13389385120_item	2240730	et	3	main
ja	doc_13389385120_item	2240733	et	3	main
jne	doc_13389385120_item	2240748	et	4	main
oskad	doc_13389385120_item	2240755	et	3	main
jneekskursioonidüldkoolilised	doc_13389385120_item	2240762	et	4	main
projektid	doc_13389385120_item	2240768	et	3	main
2-3	doc_13389385120_item	2240781	et	2	main
keeleliselt	doc_13389385120_item	2240784	et	4	main
lasteraamatut	doc_13389385120_item	2240786	et	3	main
siin	doc_13389385120_item	2240790	et	4	main
tv-	doc_13389385120_item	2240793	et	4	main
ja	doc_13389385120_item	2240794	et	3	main
kuid	doc_13389385120_item	2240824	et	4	main
see	doc_13389385120_item	2240825	et	3	main
ja	doc_13389385120_item	2240829	et	3	main
kui	doc_13389385120_item	2240833	et	3	main
eesti	doc_13389385120_item	2240834	et	4	main
ja	doc_13389385120_item	2240836	et	3	main
teha	doc_13389385120_item	2240841	et	3	main
tunnis	doc_13389385120_item	2240853	et	3	main
loetakse	doc_13389385120_item	2240859	et	3	main
autorite	doc_13389385120_item	2240865	et	3	main
viiendas	doc_13389385120_item	2240867	et	3	main
selle	doc_13389385120_item	2240873	et	4	main
raames	doc_13389385120_item	2240875	et	4	main
õpilased	doc_13389385120_item	2240877	et	3	main
saanud	doc_13389385120_item	2240890	et	4	main
õpib	doc_13389385120_item	2240923	et	3	main
õpilase	doc_13389385120_item	2240928	et	3	main
vaatamisväärsusi	doc_13389385120_item	2240936	et	4	main
kultuuritegelasiselleks	doc_13389385120_item	2240938	et	4	main
kultuurist	doc_13389385120_item	2240940	et	3	main
luuletusi	doc_13389385120_item	2240948	et	4	main
eesti	doc_13389385120_item	2240949	et	4	main
näiteid	doc_13389385120_item	2240951	et	3	main
vanasõnadest	doc_13389385120_item	2240952	et	3	main
samas	doc_13389385120_item	2240955	et	4	main
eesti	doc_13389385120_item	2240962	et	4	main
vapp	doc_13389385120_item	2240964	et	3	main
tähistamine	doc_13389385120_item	2240973	et	4	main
kas	doc_13389385120_item	2240981	et	3	main
tunned	doc_13389385120_item	2240982	et	3	main
lõpetaja	doc_13389385120_item	2240986	et	4	main
lugenud	doc_13389385120_item	2240992	et	4	main
keeleliselt	doc_13389385120_item	2240996	et	4	main
lasteraamatut	doc_13389385120_item	2240998	et	3	main
meetmed	doc_13389385120_item	2241003	et	3	main
ja	doc_13389385120_item	2241032	et	3	main
teemadele	doc_13389385120_item	2241034	et	3	main
eesti	doc_13389385120_item	2241044	et	4	main
mõtet	doc_13389385120_item	2241050	et	3	main
selle	doc_13389385120_item	2241069	et	4	main
teema	doc_13389385120_item	2241070	et	4	main
kohta	doc_13389385120_item	2241071	et	4	main
tallinna	doc_13389385120_item	2241072	et	4	main
õismäe	doc_13389385120_item	2241073	et	3	main
on	doc_13389385120_item	2241091	et	4	main
koolis	doc_13389385120_item	2241093	et	4	main
7	doc_13389385120_item	2241098	et	2	main
eesti	doc_13389385120_item	2241101	et	4	main
rahva	doc_13389385120_item	2241117	et	3	main
ja	doc_13389385120_item	2241119	et	3	main
huvitub	doc_13389385120_item	2241121	et	3	main
kaasaegsest	doc_13389385120_item	2241122	et	3	main
oma	doc_13389385120_item	2241129	et	4	main
mõtte-	doc_13389385120_item	2241131	et	3	main
eesti	doc_13389385120_item	2241135	et	4	main
loodus	doc_13389385120_item	2241137	et	4	main
pakutakse	doc_13389385120_item	2241142	et	3	main
osavõttu	doc_13389385120_item	2241145	et	4	main
kultuurielust	doc_13389385120_item	2241147	et	3	main
korraldatakse	doc_13389385120_item	2241148	et	3	main
klassiväliseid	doc_13389385120_item	2241150	et	4	main
käiakse	doc_13389385120_item	2241152	et	3	main
teatrites	doc_13389385120_item	2241153	et	3	main
kontserditel	doc_13389385120_item	2241154	et	4	main
saab	doc_13389385120_item	2241156	et	3	main
ta	doc_13389385120_item	2241169	et	4	main
rakendab	doc_13389385120_item	2241174	et	3	main
aru	doc_13389385120_item	2240716	et	4	main
luuletusi	doc_13389385120_item	2240723	et	4	main
mõistatustest	doc_13389385120_item	2240727	et	4	main
kõnekäändudest	doc_13389385120_item	2240728	et	3	main
tähtpäevadest	doc_13389385120_item	2240734	et	3	main
rahvussümbolitest	doc_13389385120_item	2240736	et	4	main
lipp	doc_13389385120_item	2240738	et	3	main
presidentsamas	doc_13389385120_item	2240741	et	4	main
võistlused	doc_13389385120_item	2240750	et	3	main
sa	doc_13389385120_item	2240759	et	3	main
viktoriinid	doc_13389385120_item	2240764	et	3	main
5	doc_13389385120_item	2240771	et	2	main
klassi	doc_13389385120_item	2240772	et	4	main
teab	doc_13389385120_item	2240774	et	3	main
eesti	doc_13389385120_item	2240775	et	4	main
on	doc_13389385120_item	2240777	et	4	main
keeles	doc_13389385120_item	2240779	et	4	main
ja	doc_13389385120_item	2240783	et	3	main
sümboleid	doc_13389385120_item	2240789	et	3	main
raadiosaated	doc_13389385120_item	2240795	et	3	main
pealiskaudne	doc_13389385120_item	2240828	et	3	main
süsteemitu	doc_13389385120_item	2240830	et	4	main
on	doc_13389385120_item	2240832	et	4	main
vene	doc_13389385120_item	2240837	et	4	main
keele	doc_13389385120_item	2240838	et	4	main
koostööd	doc_13389385120_item	2240842	et	4	main
raamatute	doc_13389385120_item	2240848	et	3	main
kui	doc_13389385120_item	2240855	et	3	main
vene	doc_13389385120_item	2240860	et	4	main
tunnis	doc_13389385120_item	2240862	et	3	main
klassis	doc_13389385120_item	2240868	et	3	main
ajaloo	doc_13389385120_item	2240871	et	4	main
tunni	doc_13389385120_item	2240874	et	3	main
nad	doc_13389385120_item	2240885	et	3	main
kust	doc_13389385120_item	2240887	et	4	main
õismäe	doc_13389385120_item	2240894	et	3	main
lütseumis	doc_13389385120_item	2240896	et	3	main
klassi	doc_13389385120_item	2240899	et	4	main
jutustama	doc_13389385120_item	2240927	et	3	main
eestist	doc_13389385120_item	2240930	et	3	main
õpivad	doc_13389385120_item	2240933	et	3	main
aru	doc_13389385120_item	2240942	et	4	main
loevad	doc_13389385120_item	2240945	et	3	main
presidentsamas	doc_13389385120_item	2240966	et	4	main
ja	doc_13389385120_item	2240971	et	3	main
ülekooliline	doc_13389385120_item	2240972	et	4	main
emakeelepäeva	doc_13389385120_item	2240974	et	4	main
olümpiaadid	doc_13389385120_item	2240977	et	3	main
konkurssid	doc_13389385120_item	2240978	et	4	main
keeles	doc_13389385120_item	2240991	et	4	main
ja	doc_13389385120_item	2240995	et	3	main
kasutatavad	doc_13389385120_item	2241002	et	4	main
on	doc_13389385120_item	2241004	et	4	main
jutte	doc_13389385120_item	2240721	et	3	main
vanasõnadest	doc_13389385120_item	2240726	et	3	main
teadmisi	doc_13389385120_item	2240731	et	4	main
eesti	doc_13389385120_item	2240737	et	4	main
toimuvad	doc_13389385120_item	2240742	et	4	main
mardipäev	doc_13389385120_item	2240746	et	3	main
ja	doc_13389385120_item	2240751	et	3	main
sa	doc_13389385120_item	2240754	et	3	main
eestimaad	doc_13389385120_item	2240761	et	4	main
peod	doc_13389385120_item	2240763	et	4	main
koolidevahelised	doc_13389385120_item	2240767	et	4	main
järgi	doc_13389385120_item	2240770	et	4	main
lõpetaja	doc_13389385120_item	2240773	et	4	main
eakohast	doc_13389385120_item	2240782	et	4	main
eesti	doc_13389385120_item	2240787	et	4	main
abiks	doc_13389385120_item	2240791	et	3	main
videofilmid	doc_13389385120_item	2240797	et	3	main
õpetaja	doc_13389385120_item	2240798	et	4	main
kommentaar	doc_13389385120_item	2240799	et	3	main
viiendas	doc_13389385120_item	2240800	et	3	main
klassis	doc_13389385120_item	2240801	et	3	main
on	doc_13389385120_item	2240802	et	4	main
4	doc_13389385120_item	2240803	et	2	main
tundi	doc_13389385120_item	2240804	et	4	main
eesti	doc_13389385120_item	2240805	et	4	main
keelt	doc_13389385120_item	2240806	et	4	main
enamus	doc_13389385120_item	2240807	et	4	main
aur	doc_13389385120_item	2240808	et	3	main
läheb	doc_13389385120_item	2240809	et	3	main
eesti	doc_13389385120_item	2240810	et	4	main
keele	doc_13389385120_item	2240811	et	4	main
grammatika	doc_13389385120_item	2240812	et	4	main
õppimisele	doc_13389385120_item	2240813	et	4	main
muidugi	doc_13389385120_item	2240814	et	4	main
õpitakse	doc_13389385120_item	2240815	et	4	main
tundma	doc_13389385120_item	2240816	et	3	main
ka	doc_13389385120_item	2240817	et	3	main
lastekirjanikke	doc_13389385120_item	2240818	et	3	main
loomingut	doc_13389385120_item	2240819	et	3	main
näiteks	doc_13389385120_item	2240820	et	4	main
e	doc_13389385120_item	2240821	et	4	main
naksitrallid	doc_13389385120_item	2240823	et	3	main
keele	doc_13389385120_item	2240835	et	4	main
suudavad	doc_13389385120_item	2240840	et	3	main
eesti	doc_13389385120_item	2240844	et	4	main
ka	doc_13389385120_item	2240851	et	3	main
on	doc_13389385120_item	2240856	et	4	main
keele	doc_13389385120_item	2240861	et	4	main
kursus	doc_13389385120_item	2240872	et	3	main
saavad	doc_13389385120_item	2240876	et	4	main
kuidas	doc_13389385120_item	2240879	et	3	main
muistsed	doc_13389385120_item	2240881	et	3	main
eestlased	doc_13389385120_item	2240882	et	3	main
millega	doc_13389385120_item	2240884	et	3	main
paljud	doc_13389385120_item	2240891	et	3	main
tallinna	doc_13389385120_item	2240893	et	4	main
on	doc_13389385120_item	2240897	et	4	main
ja	doc_13389385120_item	2240765	et	3	main
olümpiaadid	doc_13389385120_item	2240766	et	3	main
lugenud	doc_13389385120_item	2240780	et	4	main
riigi	doc_13389385120_item	2240788	et	3	main
ajakirjad	doc_13389385120_item	2240796	et	3	main
on	doc_13389385120_item	2240826	et	4	main
õpetajad	doc_13389385120_item	2240839	et	4	main
keele	doc_13389385120_item	2240845	et	4	main
tunnis	doc_13389385120_item	2240846	et	3	main
tegelastega	doc_13389385120_item	2240849	et	3	main
võimalus	doc_13389385120_item	2240857	et	3	main
ka	doc_13389385120_item	2240863	et	3	main
eesti	doc_13389385120_item	2240864	et	4	main
kirjandust	doc_13389385120_item	2240866	et	3	main
eesti	doc_13389385120_item	2240870	et	4	main
teada	doc_13389385120_item	2240878	et	3	main
elasid	doc_13389385120_item	2240880	et	4	main
alguse	doc_13389385120_item	2240889	et	3	main
vene	doc_13389385120_item	2240895	et	4	main
eesti	doc_13389385120_item	2240901	et	4	main
keeles	doc_13389385120_item	2240902	et	4	main
ja	doc_13389385120_item	2240903	et	3	main
et	doc_13389385120_item	2240904	et	3	main
õpilased	doc_13389385120_item	2240905	et	3	main
paremaid	doc_13389385120_item	2240907	et	4	main
saaksid	doc_13389385120_item	2240906	et	4	main
tulemusi	doc_13389385120_item	2240908	et	4	main
on	doc_13389385120_item	2240909	et	4	main
klass	doc_13389385120_item	2240910	et	3	main
2	doc_13389385120_item	2240911	et	2	main
rühmaks	doc_13389385120_item	2240912	et	4	main
jagatud	doc_13389385120_item	2240913	et	4	main
6	doc_13389385120_item	2240914	et	2	main
klass	doc_13389385120_item	2240915	et	3	main
sel	doc_13389385120_item	2240916	et	3	main
kooliastmel	doc_13389385120_item	2240917	et	3	main
teadvustab	doc_13389385120_item	2240918	et	3	main
õpilane	doc_13389385120_item	2240919	et	3	main
oma	doc_13389385120_item	2240920	et	4	main
omapära	doc_13389385120_item	2240922	et	4	main
keeles	doc_13389385120_item	2240926	et	4	main
laienevad	doc_13389385120_item	2240931	et	4	main
jutte	doc_13389385120_item	2240946	et	3	main
lastekirjandusest	doc_13389385120_item	2240950	et	4	main
mõistatustest	doc_13389385120_item	2240953	et	4	main
ja	doc_13389385120_item	2240959	et	3	main
rahvussümbolitest	doc_13389385120_item	2240961	et	4	main
lipp	doc_13389385120_item	2240963	et	3	main
6	doc_13389385120_item	2240984	et	2	main
klassi	doc_13389385120_item	2240985	et	4	main
on	doc_13389385120_item	2240989	et	4	main
eakohast	doc_13389385120_item	2240994	et	4	main
arvutiprogrammid	doc_13389385120_item	2241005	et	3	main
tundma	doc_13389385120_item	2241021	et	3	main
mõistatusi	doc_13389385120_item	2241023	et	4	main
ikkagi	doc_13389385120_item	2241026	et	4	main
on	doc_13389385120_item	2241027	et	4	main
rõhk	doc_13389385120_item	2241029	et	3	main
pandud	doc_13389385120_item	2241030	et	4	main
kui	doc_13389385120_item	2241038	et	3	main
õpetajad	doc_13389385120_item	2241040	et	4	main
sümboolika	doc_13389385120_item	2241045	et	4	main
rahvuskultuuri	doc_13389385120_item	2241047	et	4	main
lütseumis	doc_13389385120_item	2241075	et	3	main
loodusõpetust	doc_13389385120_item	2241077	et	3	main
seotud	doc_13389385120_item	2241080	et	4	main
kuid	doc_13389385120_item	2241084	et	4	main
ning	doc_13389385120_item	2241089	et	3	main
kirjandus	doc_13389385120_item	2241097	et	3	main
kodukoha	doc_13389385120_item	2240921	et	4	main
eesti	doc_13389385120_item	2240925	et	4	main
teadmised	doc_13389385120_item	2240929	et	4	main
paikkonna	doc_13389385120_item	2240935	et	3	main
ja	doc_13389385120_item	2240937	et	3	main
ja	doc_13389385120_item	2240947	et	3	main
arendatakse	doc_13389385120_item	2240956	et	3	main
riigipühadest	doc_13389385120_item	2240958	et	3	main
tähtpäevadesteesti	doc_13389385120_item	2240960	et	4	main
hümneesti	doc_13389385120_item	2240965	et	4	main
tähtpäevade	doc_13389385120_item	2240969	et	3	main
üritused	doc_13389385120_item	2240976	et	4	main
teabeesti	doc_13389385120_item	2240987	et	4	main
eesti	doc_13389385120_item	2240990	et	4	main
riigi	doc_13389385120_item	2241000	et	3	main
sümboleid	doc_13389385120_item	2241001	et	3	main
töölehed	doc_13389385120_item	2241006	et	3	main
juhised	doc_13389385120_item	2241007	et	3	main
ristsõnad	doc_13389385120_item	2241008	et	3	main
jne	doc_13389385120_item	2241009	et	4	main
meedia	doc_13389385120_item	2241010	et	4	main
ajakirjad	doc_13389385120_item	2241011	et	3	main
ja	doc_13389385120_item	2241012	et	3	main
ajalehed	doc_13389385120_item	2241013	et	3	main
sõnastikud	doc_13389385120_item	2241014	et	3	main
ja	doc_13389385120_item	2241015	et	3	main
teatmeteosed	doc_13389385120_item	2241016	et	3	main
õpetaja	doc_13389385120_item	2241017	et	4	main
õpilased	doc_13389385120_item	2241019	et	3	main
õpivad	doc_13389385120_item	2241020	et	3	main
kommentaar	doc_13389385120_item	2241018	et	3	main
kuid	doc_13389385120_item	2241025	et	4	main
tihti	doc_13389385120_item	2241035	et	3	main
ka	doc_13389385120_item	2241039	et	3	main
on	doc_13389385120_item	2241041	et	4	main
pole	doc_13389385120_item	2241049	et	3	main
nii	doc_13389385120_item	2241051	et	3	main
teagi	doc_13389385120_item	2241066	et	4	main
mis	doc_13389385120_item	2241078	et	4	main
eestiga	doc_13389385120_item	2241081	et	4	main
ka	doc_13389385120_item	2241085	et	3	main
on	doc_13389385120_item	2241087	et	4	main
vähe	doc_13389385120_item	2241088	et	3	main
valikainena	doc_13389385120_item	2241090	et	3	main
selles	doc_13389385120_item	2241092	et	4	main
6	doc_13389385120_item	2241094	et	2	main
klass	doc_13389385120_item	2241099	et	3	main
taotleb	doc_13389385120_item	2241104	et	3	main
tundma	doc_13389385120_item	2241108	et	3	main
ja	doc_13389385120_item	2241110	et	3	main
olulisemaid	doc_13389385120_item	2241115	et	4	main
kultuurielust	doc_13389385120_item	2241125	et	3	main
kliima	doc_13389385120_item	2241138	et	4	main
õpilasele	doc_13389385120_item	2241143	et	3	main
aktiivset	doc_13389385120_item	2241144	et	3	main
kultuurielust	doc_13389385120_item	2241160	et	3	main
kultuuriloo	doc_13389385120_item	2241162	et	4	main
tähtsamatest	doc_13389385120_item	2241163	et	4	main
olulisematest	doc_13389385120_item	2241167	et	4	main
noorsookirjandusest	doc_13389385120_item	2241172	et	4	main
legendidesttoimub	doc_13389385120_item	2241180	et	4	main
viktoriin	doc_13389385120_item	2241182	et	3	main
aastapäevale	doc_13389385120_item	2241189	et	4	main
eluolust	doc_13389385120_item	2241199	et	3	main
grammatikale	doc_13389385120_item	2241031	et	3	main
nii	doc_13389385120_item	2241036	et	3	main
arvamusel	doc_13389385120_item	2241042	et	3	main
peale	doc_13389385120_item	2241048	et	4	main
palju	doc_13389385120_item	2241052	et	4	main
aega	doc_13389385120_item	2241053	et	4	main
raisata	doc_13389385120_item	2241054	et	4	main
neid	doc_13389385120_item	2241055	et	4	main
teemasid	doc_13389385120_item	2241056	et	3	main
õpitakse	doc_13389385120_item	2241057	et	4	main
kahjuks	doc_13389385120_item	2241058	et	4	main
nagu	doc_13389385120_item	2241059	et	3	main
minnes	doc_13389385120_item	2241061	et	3	main
mööda	doc_13389385120_item	2241060	et	4	main
ning	doc_13389385120_item	2241062	et	3	main
seetõttu	doc_13389385120_item	2241063	et	3	main
õpilased	doc_13389385120_item	2241037	et	3	main
et	doc_13389385120_item	2241043	et	3	main
ja	doc_13389385120_item	2241046	et	3	main
õpilased	doc_13389385120_item	2241064	et	3	main
midagi	doc_13389385120_item	2241068	et	4	main
vene	doc_13389385120_item	2241074	et	4	main
õpitakse	doc_13389385120_item	2241076	et	4	main
sellest	doc_13389385120_item	2241086	et	4	main
eesti	doc_13389385120_item	2241096	et	4	main
7klassi	doc_13389385120_item	2241100	et	4	main
et	doc_13389385120_item	2241105	et	3	main
mõistma	doc_13389385120_item	2241109	et	3	main
eesti	doc_13389385120_item	2241112	et	4	main
ajaloofakte	doc_13389385120_item	2241116	et	3	main
kombeid	doc_13389385120_item	2241120	et	4	main
ja	doc_13389385120_item	2241124	et	3	main
ja	doc_13389385120_item	2241132	et	3	main
keskendutakse	doc_13389385120_item	2241134	et	3	main
kultuurilugu	doc_13389385120_item	2241139	et	4	main
senisest	doc_13389385120_item	2241140	et	3	main
paikkonna	doc_13389385120_item	2241159	et	3	main
objektidest	doc_13389385120_item	2241164	et	3	main
ja	doc_13389385120_item	2241166	et	3	main
kultuuritegelastest	doc_13389385120_item	2241168	et	4	main
ta	doc_13389385120_item	2241173	et	4	main
oma	doc_13389385120_item	2241175	et	4	main
naljanditest	doc_13389385120_item	2241179	et	3	main
minu	doc_13389385120_item	2241185	et	3	main
lõpetaja	doc_13389385120_item	2241193	et	4	main
ja	doc_13389385120_item	2241197	et	3	main
ning	doc_13389385120_item	2241200	et	3	main
kombeid	doc_13389385120_item	2241225	et	4	main
isegi	doc_13389385120_item	2241233	et	4	main
õppisid	doc_13389385120_item	2241237	et	4	main
teadsid	doc_13389385120_item	2241239	et	4	main
valmistab	doc_13389385120_item	2241241	et	3	main
tunne	doc_13389385120_item	2241250	et	4	main
kurb	doc_13389385120_item	2241258	et	3	main
peavad	doc_13389385120_item	2241272	et	4	main
8	doc_13389385120_item	2241276	et	2	main
8	doc_13389385120_item	2241278	et	2	main
eesti	doc_13389385120_item	2241280	et	4	main
keele	doc_13389385120_item	2241281	et	4	main
ajaloofakte	doc_13389385120_item	2241295	et	3	main
kombeid	doc_13389385120_item	2241299	et	4	main
ja	doc_13389385120_item	2241304	et	3	main
kultuurielust	doc_13389385120_item	2241305	et	3	main
oma	doc_13389385120_item	2241309	et	4	main
teatrites	doc_13389385120_item	2241333	et	3	main
ja	doc_13389385120_item	2241346	et	3	main
kultuuritegelastestõpilane	doc_13389385120_item	2241348	et	3	main
muinasjuttud	doc_13389385120_item	2241351	et	4	main
naljandid	doc_13389385120_item	2241353	et	3	main
oskab	doc_13389385120_item	2241355	et	3	main
eesti	doc_13389385120_item	2241359	et	4	main
ning	doc_13389385120_item	2241361	et	3	main
minu	doc_13389385120_item	2241368	et	3	main
õpitakse	doc_13389385120_item	2241381	et	4	main
loomingut	doc_13389385120_item	2241387	et	3	main
vähe	doc_13389385120_item	2241393	et	3	main
ei	doc_13389385120_item	2241400	et	4	main
õpetajad	doc_13389385120_item	2241407	et	4	main
ei	doc_13389385120_item	2241421	et	4	main
ning	doc_13389385120_item	2241423	et	3	main
klass	doc_13389385120_item	2241430	et	3	main
õpib	doc_13389385120_item	2241438	et	3	main
tundma	doc_13389385120_item	2241439	et	3	main
eesti	doc_13389385120_item	2241443	et	4	main
püsiväärtusi	doc_13389385120_item	2241445	et	3	main
tavasid	doc_13389385120_item	2241449	et	3	main
keskendutakse	doc_13389385120_item	2241452	et	3	main
klassiväliseid	doc_13389385120_item	2241468	et	4	main
kultuuriloo	doc_13389385120_item	2241480	et	4	main
olulisemad	doc_13389385120_item	2241485	et	4	main
oskab	doc_13389385120_item	2241487	et	3	main
näiteid	doc_13389385120_item	2241495	et	3	main
jutustada	doc_13389385120_item	2241501	et	3	main
huviväärsustest	doc_13389385120_item	2241507	et	4	main
klassidevaheline	doc_13389385120_item	2241509	et	4	main
ei	doc_13389385120_item	2241065	et	4	main
peaaegu	doc_13389385120_item	2241067	et	3	main
on	doc_13389385120_item	2241079	et	4	main
eesti	doc_13389385120_item	2241082	et	4	main
keeles	doc_13389385120_item	2241083	et	4	main
klassis	doc_13389385120_item	2241095	et	3	main
keele	doc_13389385120_item	2241102	et	4	main
õpib	doc_13389385120_item	2241107	et	3	main
hindama	doc_13389385120_item	2241111	et	3	main
kultuuri	doc_13389385120_item	2241113	et	4	main
püsiväärtusi	doc_13389385120_item	2241114	et	3	main
selle	doc_13389385120_item	2241127	et	4	main
eripärale	doc_13389385120_item	2241136	et	3	main
enam	doc_13389385120_item	2241141	et	4	main
muuseumidesõpilane	doc_13389385120_item	2241155	et	4	main
uued	doc_13389385120_item	2241157	et	3	main
eesti	doc_13389385120_item	2241161	et	4	main
sündmustest	doc_13389385120_item	2241165	et	4	main
muinasjuttudest	doc_13389385120_item	2241177	et	3	main
muistenditest	doc_13389385120_item	2241178	et	3	main
eesti	doc_13389385120_item	2241183	et	4	main
tähistamine	doc_13389385120_item	2241191	et	4	main
7klassi	doc_13389385120_item	2241192	et	4	main
jutustada	doc_13389385120_item	2241195	et	3	main
tundma	doc_13389385120_item	2241221	et	3	main
tavasid	doc_13389385120_item	2241223	et	3	main
mida	doc_13389385120_item	2241235	et	4	main
algklassides	doc_13389385120_item	2241236	et	3	main
ja	doc_13389385120_item	2241238	et	3	main
raskusi	doc_13389385120_item	2241240	et	4	main
absoluutselt	doc_13389385120_item	2241242	et	4	main
teatreid	doc_13389385120_item	2241252	et	3	main
näitusi	doc_13389385120_item	2241257	et	3	main
ei	doc_13389385120_item	2241266	et	4	main
teadmisi	doc_13389385120_item	2241274	et	4	main
et	doc_13389385120_item	2241284	et	3	main
ja	doc_13389385120_item	2241289	et	3	main
kultuuri	doc_13389385120_item	2241292	et	4	main
ja	doc_13389385120_item	2241298	et	3	main
huvitub	doc_13389385120_item	2241301	et	3	main
rikastab	doc_13389385120_item	2241306	et	3	main
aktiivset	doc_13389385120_item	2241324	et	3	main
eestikeelseid	doc_13389385120_item	2241329	et	3	main
üritusi	doc_13389385120_item	2241331	et	4	main
muuseumides	doc_13389385120_item	2241335	et	3	main
tähtsamatest	doc_13389385120_item	2241343	et	4	main
loeb	doc_13389385120_item	2241349	et	3	main
paikonna	doc_13389385120_item	2241357	et	4	main
aastapäevale	doc_13389385120_item	2241372	et	4	main
emadepäeva	doc_13389385120_item	2241375	et	4	main
tähistamine	doc_13389385120_item	2241376	et	4	main
8	doc_13389385120_item	2241379	et	2	main
o	doc_13389385120_item	2241382	et	4	main
tammsaare	doc_13389385120_item	2241386	et	3	main
ikkagi	doc_13389385120_item	2241392	et	4	main
loetakse	doc_13389385120_item	2241395	et	3	main
needki	doc_13389385120_item	2241399	et	3	main
ole	doc_13389385120_item	2241401	et	4	main
originaaltekstid	doc_13389385120_item	2241403	et	3	main
sellele	doc_13389385120_item	2241425	et	4	main
rõhku	doc_13389385120_item	2241426	et	4	main
ei	doc_13389385120_item	2241427	et	4	main
pane	doc_13389385120_item	2241428	et	4	main
õpetus	doc_13389385120_item	2241434	et	4	main
ja	doc_13389385120_item	2241441	et	3	main
loodus	doc_13389385120_item	2241455	et	4	main
kontserditel	doc_13389385120_item	2241472	et	4	main
on	doc_13389385120_item	2241476	et	4	main
ja	doc_13389385120_item	2241484	et	3	main
jutustada	doc_13389385120_item	2241488	et	3	main
kultuurielustloeb	doc_13389385120_item	2241490	et	4	main
tuua	doc_13389385120_item	2241494	et	3	main
legendidest	doc_13389385120_item	2241499	et	3	main
ja	doc_13389385120_item	2241503	et	3	main
vabariigi	doc_13389385120_item	2241516	et	3	main
aastapäevale	doc_13389385120_item	2241517	et	4	main
emakeelepäeva	doc_13389385120_item	2241518	et	4	main
kasutavad	doc_13389385120_item	2241532	et	4	main
audeerimismaterjalid	doc_13389385120_item	2241538	et	4	main
seotud	doc_13389385120_item	2241548	et	4	main
küsimusi	doc_13389385120_item	2241549	et	4	main
küsimused	doc_13389385120_item	2241554	et	4	main
palju	doc_13389385120_item	2241562	et	4	main
saladus	doc_13389385120_item	2241568	et	3	main
õpetus	doc_13389385120_item	2241103	et	4	main
õpilane	doc_13389385120_item	2241106	et	3	main
tavasid	doc_13389385120_item	2241118	et	3	main
ühiskondlikust	doc_13389385120_item	2241123	et	4	main
rikastab	doc_13389385120_item	2241126	et	3	main
kaudu	doc_13389385120_item	2241128	et	3	main
teadmisi	doc_13389385120_item	2241130	et	4	main
tundemaailma	doc_13389385120_item	2241133	et	4	main
eesti	doc_13389385120_item	2241146	et	4	main
eestikeelseid	doc_13389385120_item	2241149	et	3	main
üritusi	doc_13389385120_item	2241151	et	4	main
teadmised	doc_13389385120_item	2241158	et	4	main
loeb	doc_13389385120_item	2241170	et	3	main
katkendeid	doc_13389385120_item	2241171	et	3	main
klassidevaheline	doc_13389385120_item	2241181	et	4	main
vabariigi	doc_13389385120_item	2241188	et	3	main
emakeelepäeva	doc_13389385120_item	2241190	et	4	main
oskab	doc_13389385120_item	2241194	et	3	main
eesti	doc_13389385120_item	2241198	et	4	main
huviväärsustest	doc_13389385120_item	2241201	et	4	main
peale	doc_13389385120_item	2241202	et	4	main
õpikuid	doc_13389385120_item	2241203	et	4	main
kasutavad	doc_13389385120_item	2241204	et	4	main
õppematerjalid	doc_13389385120_item	2241205	et	3	main
on	doc_13389385120_item	2241206	et	4	main
tv-	doc_13389385120_item	2241207	et	4	main
ja	doc_13389385120_item	2241208	et	3	main
raadiosaated	doc_13389385120_item	2241209	et	3	main
ajakirjandus	doc_13389385120_item	2241210	et	3	main
videofilmid	doc_13389385120_item	2241211	et	3	main
õpetaja	doc_13389385120_item	2241212	et	4	main
kommentaar	doc_13389385120_item	2241213	et	3	main
7	doc_13389385120_item	2241214	et	2	main
klassi	doc_13389385120_item	2241215	et	4	main
peaksid	doc_13389385120_item	2241217	et	4	main
õpilased	doc_13389385120_item	2241216	et	3	main
teadma	doc_13389385120_item	2241218	et	3	main
eesti	doc_13389385120_item	2241219	et	4	main
hümni	doc_13389385120_item	2241220	et	4	main
eestlaste	doc_13389385120_item	2241222	et	4	main
ning	doc_13389385120_item	2241224	et	3	main
kuid	doc_13389385120_item	2241226	et	4	main
näitab	doc_13389385120_item	2241228	et	3	main
nad	doc_13389385120_item	2241230	et	3	main
nad	doc_13389385120_item	2241246	et	3	main
kultuuritegelasi	doc_13389385120_item	2241248	et	3	main
nad	doc_13389385120_item	2241251	et	3	main
külasta	doc_13389385120_item	2241254	et	4	main
ega	doc_13389385120_item	2241256	et	3	main
vene	doc_13389385120_item	2241261	et	4	main
õpilased	doc_13389385120_item	2241263	et	3	main
vene	doc_13389385120_item	2241267	et	4	main
ka	doc_13389385120_item	2241269	et	3	main
kultuuri	doc_13389385120_item	2241271	et	4	main
klass	doc_13389385120_item	2241277	et	3	main
õpetus	doc_13389385120_item	2241282	et	4	main
mõistma	doc_13389385120_item	2241288	et	3	main
olulisemaid	doc_13389385120_item	2241294	et	4	main
tavasid	doc_13389385120_item	2241297	et	3	main
ühiskondlikust	doc_13389385120_item	2241303	et	4	main
selle	doc_13389385120_item	2241307	et	4	main
teadmisi	doc_13389385120_item	2241176	et	4	main
on	doc_13389385120_item	2241184	et	4	main
kodu	doc_13389385120_item	2241186	et	4	main
pühendatud	doc_13389385120_item	2241187	et	4	main
paikonna	doc_13389385120_item	2241196	et	4	main
praktika	doc_13389385120_item	2241227	et	4	main
et	doc_13389385120_item	2241229	et	3	main
unustama	doc_13389385120_item	2241232	et	3	main
seda	doc_13389385120_item	2241234	et	3	main
ei	doc_13389385120_item	2241244	et	4	main
tea	doc_13389385120_item	2241245	et	4	main
ei	doc_13389385120_item	2241253	et	4	main
muuseume	doc_13389385120_item	2241255	et	3	main
et	doc_13389385120_item	2241260	et	3	main
koolide	doc_13389385120_item	2241262	et	3	main
ei	doc_13389385120_item	2241264	et	4	main
ega	doc_13389385120_item	2241268	et	3	main
eesti	doc_13389385120_item	2241270	et	4	main
taotleb	doc_13389385120_item	2241283	et	3	main
õpilane	doc_13389385120_item	2241285	et	3	main
tundma	doc_13389385120_item	2241287	et	3	main
hindama	doc_13389385120_item	2241290	et	3	main
püsiväärtusi	doc_13389385120_item	2241293	et	3	main
kaasaegsest	doc_13389385120_item	2241302	et	3	main
laiendab	doc_13389385120_item	2241337	et	3	main
paikkonna	doc_13389385120_item	2241339	et	3	main
objektidest	doc_13389385120_item	2241344	et	3	main
sündmustest	doc_13389385120_item	2241345	et	4	main
olulisematest	doc_13389385120_item	2241347	et	4	main
noorsookirjandust	doc_13389385120_item	2241350	et	3	main
muistendid	doc_13389385120_item	2241352	et	3	main
ja	doc_13389385120_item	2241358	et	3	main
eluolust	doc_13389385120_item	2241360	et	3	main
toimub	doc_13389385120_item	2241363	et	3	main
klassidevaheline	doc_13389385120_item	2241364	et	4	main
eesti	doc_13389385120_item	2241366	et	4	main
pühendatud	doc_13389385120_item	2241370	et	4	main
õpetaja	doc_13389385120_item	2241377	et	4	main
klassis	doc_13389385120_item	2241380	et	3	main
ah	doc_13389385120_item	2241385	et	3	main
sest	doc_13389385120_item	2241394	et	4	main
ainult	doc_13389385120_item	2241396	et	4	main
katkendeid	doc_13389385120_item	2241397	et	3	main
kõik	doc_13389385120_item	2241402	et	4	main
klassis	doc_13389385120_item	2241405	et	3	main
hakkavad	doc_13389385120_item	2241406	et	4	main
mõtlema	doc_13389385120_item	2241408	et	3	main
sellele	doc_13389385120_item	2241409	et	4	main
hakkavad	doc_13389385120_item	2241231	et	4	main
kõik	doc_13389385120_item	2241243	et	4	main
eesti	doc_13389385120_item	2241247	et	4	main
ei	doc_13389385120_item	2241249	et	4	main
on	doc_13389385120_item	2241259	et	4	main
tunne	doc_13389385120_item	2241265	et	4	main
neid	doc_13389385120_item	2241273	et	4	main
üleliigseteks	doc_13389385120_item	2241275	et	4	main
klassi	doc_13389385120_item	2241279	et	4	main
õpib	doc_13389385120_item	2241286	et	3	main
eesti	doc_13389385120_item	2241291	et	4	main
rahva	doc_13389385120_item	2241296	et	3	main
ta	doc_13389385120_item	2241300	et	4	main
kaudu	doc_13389385120_item	2241308	et	3	main
teadmisi	doc_13389385120_item	2241310	et	4	main
mõtte-	doc_13389385120_item	2241311	et	3	main
ja	doc_13389385120_item	2241312	et	3	main
tundemaailma	doc_13389385120_item	2241313	et	4	main
keskendutakse	doc_13389385120_item	2241314	et	3	main
eesti	doc_13389385120_item	2241315	et	4	main
eripärale	doc_13389385120_item	2241316	et	3	main
loodus	doc_13389385120_item	2241317	et	4	main
kliima	doc_13389385120_item	2241318	et	4	main
kultuurilugu	doc_13389385120_item	2241319	et	4	main
senisest	doc_13389385120_item	2241320	et	3	main
enam	doc_13389385120_item	2241321	et	4	main
õpilasele	doc_13389385120_item	2241323	et	3	main
osavõttu	doc_13389385120_item	2241325	et	4	main
kultuurielust	doc_13389385120_item	2241327	et	3	main
kontserditel	doc_13389385120_item	2241334	et	4	main
teadmisi	doc_13389385120_item	2241338	et	4	main
kultuurielust	doc_13389385120_item	2241340	et	3	main
kultuuriloo	doc_13389385120_item	2241342	et	4	main
legendid	doc_13389385120_item	2241354	et	3	main
huviväärsustest	doc_13389385120_item	2241362	et	4	main
kodu	doc_13389385120_item	2241369	et	4	main
tähistamine	doc_13389385120_item	2241374	et	4	main
lutsu	doc_13389385120_item	2241383	et	4	main
nendest	doc_13389385120_item	2241389	et	4	main
8	doc_13389385120_item	2241404	et	2	main
õpetajad	doc_13389385120_item	2241424	et	4	main
eesti	doc_13389385120_item	2241432	et	4	main
keele	doc_13389385120_item	2241433	et	4	main
õpilane	doc_13389385120_item	2241437	et	3	main
mõistma	doc_13389385120_item	2241440	et	3	main
hindama	doc_13389385120_item	2241442	et	3	main
kultuuri	doc_13389385120_item	2241444	et	4	main
ajaloofakte	doc_13389385120_item	2241447	et	3	main
eesti	doc_13389385120_item	2241453	et	4	main
eripärale	doc_13389385120_item	2241454	et	3	main
tähtsamad	doc_13389385120_item	2241481	et	4	main
esile	doc_13389385120_item	2241493	et	3	main
muinasjuttudest	doc_13389385120_item	2241496	et	3	main
naljanditest	doc_13389385120_item	2241498	et	3	main
ning	doc_13389385120_item	2241506	et	3	main
tähistamine	doc_13389385120_item	2241521	et	4	main
9klassi	doc_13389385120_item	2241522	et	4	main
oskab	doc_13389385120_item	2241524	et	3	main
eesti	doc_13389385120_item	2241528	et	4	main
õpetamismeetodid	doc_13389385120_item	2241533	et	4	main
ajakirjad	doc_13389385120_item	2241535	et	3	main
põhikoolilõpetaja	doc_13389385120_item	2241541	et	4	main
algtaseme	doc_13389385120_item	2241543	et	3	main
ning	doc_13389385120_item	2241545	et	3	main
kultuuriga	doc_13389385120_item	2241547	et	4	main
kõik	doc_13389385120_item	2241551	et	4	main
seotud	doc_13389385120_item	2241553	et	4	main
kanda	doc_13389385120_item	2241558	et	4	main
pole	doc_13389385120_item	2241567	et	3	main
et	doc_13389385120_item	2241569	et	3	main
õpetajal	doc_13389385120_item	2241572	et	4	main
puudu	doc_13389385120_item	2241574	et	4	main
pakutakse	doc_13389385120_item	2241322	et	3	main
eesti	doc_13389385120_item	2241326	et	4	main
korraldatakse	doc_13389385120_item	2241328	et	3	main
klassiväliseid	doc_13389385120_item	2241330	et	4	main
käiakse	doc_13389385120_item	2241332	et	3	main
jmõpilane	doc_13389385120_item	2241336	et	4	main
eesti	doc_13389385120_item	2241341	et	4	main
jutustada	doc_13389385120_item	2241356	et	3	main
viktoriin	doc_13389385120_item	2241365	et	3	main
on	doc_13389385120_item	2241367	et	4	main
vabariigi	doc_13389385120_item	2241371	et	3	main
emakeelepäeva	doc_13389385120_item	2241373	et	4	main
kommentaar	doc_13389385120_item	2241378	et	3	main
ja	doc_13389385120_item	2241384	et	3	main
kuid	doc_13389385120_item	2241388	et	4	main
tundidest	doc_13389385120_item	2241390	et	3	main
on	doc_13389385120_item	2241391	et	4	main
ja	doc_13389385120_item	2241398	et	3	main
kuidas	doc_13389385120_item	2241410	et	3	main
valmistada	doc_13389385120_item	2241411	et	3	main
õpilasi	doc_13389385120_item	2241412	et	3	main
ette	doc_13389385120_item	2241413	et	4	main
põhikooli	doc_13389385120_item	2241414	et	4	main
eksamiks	doc_13389385120_item	2241415	et	3	main
kahjuks	doc_13389385120_item	2241416	et	4	main
selle	doc_13389385120_item	2241417	et	4	main
alaseid	doc_13389385120_item	2241418	et	4	main
teadmisi	doc_13389385120_item	2241419	et	4	main
seal	doc_13389385120_item	2241420	et	4	main
9	doc_13389385120_item	2241429	et	2	main
et	doc_13389385120_item	2241436	et	3	main
kombeid	doc_13389385120_item	2241451	et	4	main
kliima	doc_13389385120_item	2241456	et	4	main
muuseumides	doc_13389385120_item	2241473	et	3	main
õpilane	doc_13389385120_item	2241475	et	3	main
nimetada	doc_13389385120_item	2241478	et	3	main
objektid	doc_13389385120_item	2241482	et	3	main
kultuuritegelasi	doc_13389385120_item	2241486	et	3	main
saab	doc_13389385120_item	2241492	et	3	main
muistenditest	doc_13389385120_item	2241497	et	3	main
paikonna	doc_13389385120_item	2241502	et	4	main
eesti	doc_13389385120_item	2241504	et	4	main
minu	doc_13389385120_item	2241513	et	3	main
pühendatud	doc_13389385120_item	2241515	et	4	main
tähistamine	doc_13389385120_item	2241519	et	4	main
paikonna	doc_13389385120_item	2241526	et	4	main
huviväärsustest	doc_13389385120_item	2241531	et	4	main
sooritab	doc_13389385120_item	2241542	et	3	main
jäävad	doc_13389385120_item	2241555	et	4	main
ja	doc_13389385120_item	2241560	et	3	main
õpilastele	doc_13389385120_item	2241564	et	4	main
kogu	doc_13389385120_item	2241576	et	4	main
ikkagi	doc_13389385120_item	2241579	et	4	main
grammtikale	doc_13389385120_item	2241580	et	4	main
klass	doc_13389385120_item	2241587	et	3	main
õpilane	doc_13389385120_item	2241601	et	3	main
kontrollita	doc_13389385120_item	2241422	et	4	main
9klassi	doc_13389385120_item	2241431	et	4	main
taotleb	doc_13389385120_item	2241435	et	3	main
olulisemaid	doc_13389385120_item	2241446	et	4	main
rahva	doc_13389385120_item	2241448	et	3	main
ja	doc_13389385120_item	2241450	et	3	main
kultuurilugu	doc_13389385120_item	2241457	et	4	main
senisest	doc_13389385120_item	2241458	et	3	main
enam	doc_13389385120_item	2241459	et	4	main
pakutakse	doc_13389385120_item	2241460	et	3	main
õpilasele	doc_13389385120_item	2241461	et	3	main
aktiivset	doc_13389385120_item	2241462	et	3	main
osavõttu	doc_13389385120_item	2241463	et	4	main
eesti	doc_13389385120_item	2241464	et	4	main
kultuurielust	doc_13389385120_item	2241465	et	3	main
korraldatakse	doc_13389385120_item	2241466	et	3	main
eestikeelseid	doc_13389385120_item	2241467	et	3	main
üritusi	doc_13389385120_item	2241469	et	4	main
jm	doc_13389385120_item	2241474	et	4	main
käiakse	doc_13389385120_item	2241470	et	3	main
teatrites	doc_13389385120_item	2241471	et	3	main
võimeline	doc_13389385120_item	2241477	et	4	main
eesti	doc_13389385120_item	2241479	et	4	main
sündmused	doc_13389385120_item	2241483	et	3	main
paikkonna	doc_13389385120_item	2241489	et	3	main
noorsookirjandust	doc_13389385120_item	2241491	et	3	main
oskab	doc_13389385120_item	2241500	et	3	main
eluolust	doc_13389385120_item	2241505	et	3	main
toimuvad	doc_13389385120_item	2241508	et	4	main
viktoriin	doc_13389385120_item	2241510	et	3	main
eesti	doc_13389385120_item	2241511	et	4	main
on	doc_13389385120_item	2241512	et	4	main
kodu	doc_13389385120_item	2241514	et	4	main
emadepäeva	doc_13389385120_item	2241520	et	4	main
ja	doc_13389385120_item	2241527	et	3	main
eluolust	doc_13389385120_item	2241529	et	3	main
video-	doc_13389385120_item	2241536	et	4	main
õpetaja	doc_13389385120_item	2241539	et	4	main
kommentaar	doc_13389385120_item	2241540	et	3	main
kultuuriga	doc_13389385120_item	2241552	et	4	main
enda	doc_13389385120_item	2241557	et	4	main
kui	doc_13389385120_item	2241561	et	3	main
seda	doc_13389385120_item	2241563	et	3	main
anda	doc_13389385120_item	2241565	et	3	main
alati	doc_13389385120_item	2241570	et	4	main
jõud	doc_13389385120_item	2241577	et	4	main
pannakse	doc_13389385120_item	2241578	et	3	main
igapäeva	doc_13389385120_item	2241582	et	4	main
on	doc_13389385120_item	2241589	et	4	main
pööratud	doc_13389385120_item	2241591	et	4	main
väga	doc_13389385120_item	2241592	et	3	main
tähelepanu	doc_13389385120_item	2241594	et	4	main
eesti	doc_13389385120_item	2241596	et	4	main
õpetusega	doc_13389385120_item	2241598	et	4	main
taotletakse	doc_13389385120_item	2241599	et	3	main
eesti	doc_13389385120_item	2241603	et	4	main
kultuurielust	doc_13389385120_item	2241622	et	3	main
ja	doc_13389385120_item	2241627	et	3	main
proosateost	doc_13389385120_item	2241629	et	4	main
on	doc_13389385120_item	2241641	et	4	main
ja	doc_13389385120_item	2241645	et	3	main
eesti	doc_13389385120_item	2241649	et	4	main
ühiskonnale	doc_13389385120_item	2241650	et	4	main
iseloomulikke	doc_13389385120_item	2241651	et	3	main
ja	doc_13389385120_item	2241653	et	3	main
35	doc_13389385120_item	2241662	et	2	main
1õppe-eesmärgid	doc_13389385120_item	2241664	et	3	main
eesti	doc_13389385120_item	2241666	et	4	main
õpetus	doc_13389385120_item	2241670	et	4	main
suhtub	doc_13389385120_item	2241674	et	3	main
kultuurilukku	doc_13389385120_item	2241676	et	4	main
kirjanduse	doc_13389385120_item	2241681	et	3	main
rikkusena	doc_13389385120_item	2241692	et	3	main
erivormina	doc_13389385120_item	2241694	et	3	main
keele	doc_13389385120_item	2241696	et	4	main
kultuuriprotsessidest	doc_13389385120_item	2241708	et	3	main
ajastu	doc_13389385120_item	2241711	et	4	main
ja	doc_13389385120_item	2241714	et	3	main
esteetilist	doc_13389385120_item	2241721	et	3	main
lugejakultuuri	doc_13389385120_item	2241723	et	4	main
võimeid	doc_13389385120_item	2241725	et	3	main
eesti	doc_13389385120_item	2241729	et	4	main
tunnetamine	doc_13389385120_item	2241745	et	4	main
õpetamine	doc_13389385120_item	2241747	et	4	main
piirdu	doc_13389385120_item	2241749	et	4	main
ja	doc_13389385120_item	2241751	et	3	main
andmetega	doc_13389385120_item	2241753	et	3	main
semiootikast	doc_13389385120_item	2241760	et	4	main
kirjandusteoreetilisi	doc_13389385120_item	2241762	et	3	main
eelistatakse	doc_13389385120_item	2241765	et	3	main
meetodeid	doc_13389385120_item	2241767	et	3	main
mis	doc_13389385120_item	2241769	et	4	main
initsiatiivi	doc_13389385120_item	2241771	et	4	main
raamatu	doc_13389385120_item	2241776	et	4	main
suits	doc_13389385120_item	2241822	et	3	main
friedebert	doc_13389385120_item	2241823	et	4	main
2-3	doc_13389385120_item	2241837	et	2	main
ja	doc_13389385120_item	2241839	et	3	main
loomingu	doc_13389385120_item	2241841	et	3	main
hando	doc_13389385120_item	2241852	et	4	main
runnel	doc_13389385120_item	2241853	et	4	main
mati	doc_13389385120_item	2241854	et	4	main
lõpetaja	doc_13389385120_item	2241523	et	4	main
jutustada	doc_13389385120_item	2241525	et	3	main
ning	doc_13389385120_item	2241530	et	3	main
ajalehed	doc_13389385120_item	2241534	et	3	main
ja	doc_13389385120_item	2241537	et	3	main
eksami	doc_13389385120_item	2241544	et	3	main
seal	doc_13389385120_item	2241546	et	4	main
pole	doc_13389385120_item	2241550	et	3	main
õpetaja	doc_13389385120_item	2241556	et	4	main
kas	doc_13389385120_item	2241559	et	3	main
kuid	doc_13389385120_item	2241566	et	4	main
jääb	doc_13389385120_item	2241571	et	3	main
tunde	doc_13389385120_item	2241573	et	4	main
puudutavatele	doc_13389385120_item	2241584	et	4	main
keele	doc_13389385120_item	2241597	et	4	main
sotsiaalsfääris	doc_13389385120_item	2241606	et	3	main
on	doc_13389385120_item	2241608	et	4	main
nimetada	doc_13389385120_item	2241610	et	3	main
eesti	doc_13389385120_item	2241611	et	4	main
kultuuriloo	doc_13389385120_item	2241612	et	4	main
tähtsamad	doc_13389385120_item	2241613	et	4	main
objektid	doc_13389385120_item	2241614	et	3	main
sündmused	doc_13389385120_item	2241615	et	3	main
ja	doc_13389385120_item	2241616	et	3	main
olulisemad	doc_13389385120_item	2241617	et	4	main
kultuuritegelasi	doc_13389385120_item	2241618	et	3	main
oskab	doc_13389385120_item	2241619	et	3	main
jutustada	doc_13389385120_item	2241620	et	3	main
on	doc_13389385120_item	2241623	et	4	main
eesti	doc_13389385120_item	2241625	et	4	main
ja	doc_13389385120_item	2241636	et	3	main
teab	doc_13389385120_item	2241638	et	3	main
lugenud	doc_13389385120_item	2241642	et	4	main
proosateost	doc_13389385120_item	2241647	et	4	main
eesti	doc_13389385120_item	2241655	et	4	main
kirjanduse	doc_13389385120_item	2241658	et	3	main
11	doc_13389385120_item	2241660	et	2	main
taotleb	doc_13389385120_item	2241671	et	3	main
kirjandusse	doc_13389385120_item	2241678	et	3	main
allika	doc_13389385120_item	2241687	et	3	main
tähtsaima	doc_13389385120_item	2241689	et	4	main
ja	doc_13389385120_item	2241697	et	3	main
oma	doc_13389385120_item	2241702	et	4	main
maitset	doc_13389385120_item	2241722	et	3	main
loeb	doc_13389385120_item	2241726	et	3	main
ja	doc_13389385120_item	2241731	et	3	main
sel	doc_13389385120_item	2241739	et	3	main
süveneb	doc_13389385120_item	2241741	et	3	main
ja	doc_13389385120_item	2241743	et	3	main
saavad	doc_13389385120_item	2241755	et	4	main
arengut	doc_13389385120_item	2241772	et	3	main
eduard	doc_13389385120_item	2241817	et	4	main
juhan	doc_13389385120_item	2241819	et	3	main
liiv	doc_13389385120_item	2241820	et	3	main
20	doc_13389385120_item	2241826	et	2	main
filmilinal	doc_13389385120_item	2241836	et	3	main
muusikategelase	doc_13389385120_item	2241838	et	3	main
unt	doc_13389385120_item	2241855	et	4	main
struktuurilised	doc_13389385120_item	2241869	et	4	main
erinevused	doc_13389385120_item	2241870	et	4	main
tõlkekirjandus	doc_13389385120_item	2241894	et	3	main
koolibri	doc_13389385120_item	2241904	et	4	main
virgela	doc_13389385120_item	2241906	et	4	main
väike	doc_13389385120_item	2241908	et	4	main
leksikon	doc_13389385120_item	2241911	et	3	main
p	doc_13389385120_item	2241913	et	4	main
12	doc_13389385120_item	2241917	et	2	main
1996	doc_13389385120_item	2241920	et	2	main
a	doc_13389385120_item	2241921	et	4	main
fraseoloogia	doc_13389385120_item	2241923	et	4	main
rohkem	doc_13389385120_item	2241938	et	4	main
tähelepanu	doc_13389385120_item	2241939	et	4	main
jääb	doc_13389385120_item	2241946	et	3	main
ning	doc_13389385120_item	2241575	et	3	main
10	doc_13389385120_item	2241586	et	2	main
kultuuriõppimisele	doc_13389385120_item	2241590	et	3	main
vähe	doc_13389385120_item	2241593	et	3	main
10klassi	doc_13389385120_item	2241595	et	4	main
et	doc_13389385120_item	2241600	et	3	main
õpilane	doc_13389385120_item	2241607	et	3	main
õpilane	doc_13389385120_item	2241632	et	3	main
eesti	doc_13389385120_item	2241634	et	4	main
sotsiallsfääris	doc_13389385120_item	2241637	et	4	main
eesti	doc_13389385120_item	2241639	et	4	main
teab	doc_13389385120_item	2241648	et	3	main
käitumis-	doc_13389385120_item	2241652	et	4	main
suhtlemisnorme	doc_13389385120_item	2241654	et	3	main
kultuuriloo	doc_13389385120_item	2241667	et	4	main
lugupidavalt	doc_13389385120_item	2241679	et	4	main
selles	doc_13389385120_item	2241683	et	4	main
rahva	doc_13389385120_item	2241684	et	3	main
vaimse	doc_13389385120_item	2241685	et	3	main
kultuuri	doc_13389385120_item	2241686	et	4	main
kaudu	doc_13389385120_item	2241701	et	3	main
omandab	doc_13389385120_item	2241705	et	3	main
vahekorrast	doc_13389385120_item	2241712	et	4	main
vaimsete	doc_13389385120_item	2241716	et	4	main
otsingute	doc_13389385120_item	2241717	et	3	main
ja	doc_13389385120_item	2241581	et	3	main
elu	doc_13389385120_item	2241583	et	4	main
küsimustele	doc_13389385120_item	2241585	et	4	main
gümnaasiumiastmel	doc_13389385120_item	2241588	et	3	main
orienteerub	doc_13389385120_item	2241602	et	3	main
kultuuris	doc_13389385120_item	2241604	et	3	main
ja	doc_13389385120_item	2241605	et	3	main
võimeline	doc_13389385120_item	2241609	et	4	main
lugenud	doc_13389385120_item	2241624	et	4	main
luulet	doc_13389385120_item	2241626	et	3	main
3-4	doc_13389385120_item	2241628	et	2	main
klass	doc_13389385120_item	2241631	et	3	main
orienteerub	doc_13389385120_item	2241633	et	3	main
eesti	doc_13389385120_item	2241643	et	4	main
3-4	doc_13389385120_item	2241646	et	2	main
kultuuriloo	doc_13389385120_item	2241656	et	4	main
ainekava	doc_13389385120_item	2241659	et	4	main
klass	doc_13389385120_item	2241661	et	3	main
tundi	doc_13389385120_item	2241663	et	4	main
ja	doc_13389385120_item	2241668	et	3	main
kirjanduse	doc_13389385120_item	2241669	et	3	main
tunnustades	doc_13389385120_item	2241680	et	3	main
osa	doc_13389385120_item	2241682	et	4	main
ja	doc_13389385120_item	2241688	et	3	main
osana	doc_13389385120_item	2241690	et	3	main
õpetuse	doc_13389385120_item	2241700	et	4	main
oskusi	doc_13389385120_item	2241704	et	3	main
ja	doc_13389385120_item	2241710	et	3	main
inimese	doc_13389385120_item	2241715	et	4	main
arendab	doc_13389385120_item	2241719	et	3	main
oma	doc_13389385120_item	2241720	et	4	main
loomingulisi	doc_13389385120_item	2241724	et	4	main
tundma	doc_13389385120_item	2241728	et	3	main
arenemise	doc_13389385120_item	2241735	et	4	main
protsesse	doc_13389385120_item	2241736	et	3	main
ajaloolis-kultuuriliste	doc_13389385120_item	2241752	et	4	main
ja	doc_13389385120_item	2241759	et	3	main
üldistatakse	doc_13389385120_item	2241761	et	3	main
õppeprotsessis	doc_13389385120_item	2241764	et	3	main
vorme	doc_13389385120_item	2241766	et	3	main
võtteid	doc_13389385120_item	2241768	et	3	main
soodustavad	doc_13389385120_item	2241770	et	4	main
kunsti	doc_13389385120_item	2241774	et	4	main
ja	doc_13389385120_item	2241775	et	3	main
ajakirjandusest	doc_13389385120_item	2241812	et	4	main
muusikast	doc_13389385120_item	2241814	et	4	main
vilde	doc_13389385120_item	2241818	et	4	main
3	doc_13389385120_item	2241825	et	2	main
poole	doc_13389385120_item	2241829	et	4	main
kultuurielu	doc_13389385120_item	2241830	et	4	main
proosa	doc_13389385120_item	2241831	et	4	main
luule	doc_13389385120_item	2241833	et	4	main
eesti	doc_13389385120_item	2241834	et	4	main
eestikeelse	doc_13389385120_item	2241843	et	3	main
teatrietenduse	doc_13389385120_item	2241845	et	3	main
kirjanikud	doc_13389385120_item	2241847	et	3	main
kross	doc_13389385120_item	2241849	et	3	main
juhan	doc_13389385120_item	2241856	et	3	main
eesti	doc_13389385120_item	2241859	et	4	main
teised	doc_13389385120_item	2241862	et	4	main
keel	doc_13389385120_item	2241868	et	4	main
õppekirjandus	doc_13389385120_item	2241897	et	3	main
eesti	doc_13389385120_item	2241902	et	4	main
koolikirjandus	doc_13389385120_item	2241907	et	3	main
eesti	doc_13389385120_item	2241909	et	4	main
kirjanike	doc_13389385120_item	2241910	et	3	main
1998	doc_13389385120_item	2241912	et	2	main
kirjandus	doc_13389385120_item	2241916	et	3	main
koolibri	doc_13389385120_item	2241919	et	4	main
kõige	doc_13389385120_item	2241937	et	4	main
pööratud	doc_13389385120_item	2241941	et	4	main
seega	doc_13389385120_item	2241943	et	4	main
õppimiseks	doc_13389385120_item	2241945	et	4	main
12	doc_13389385120_item	2241950	et	2	main
oskab	doc_13389385120_item	2241953	et	3	main
ja	doc_13389385120_item	2241957	et	3	main
eesti	doc_13389385120_item	2241971	et	4	main
samuti	doc_13389385120_item	2242024	et	3	main
ununenud	doc_13389385120_item	2242026	et	4	main
teatakse	doc_13389385120_item	2242029	et	3	main
küll	doc_13389385120_item	2242030	et	4	main
lipuvärve	doc_13389385120_item	2242032	et	3	main
on	doc_13389385120_item	2242036	et	4	main
lipu	doc_13389385120_item	2242041	et	3	main
paikkonna	doc_13389385120_item	2241621	et	3	main
11	doc_13389385120_item	2241630	et	2	main
kultuuris	doc_13389385120_item	2241635	et	3	main
kultuuritegelasi	doc_13389385120_item	2241640	et	3	main
luulet	doc_13389385120_item	2241644	et	3	main
ja	doc_13389385120_item	2241657	et	3	main
gümnaasiumi	doc_13389385120_item	2241665	et	4	main
et	doc_13389385120_item	2241672	et	3	main
õpilane	doc_13389385120_item	2241673	et	3	main
eesti	doc_13389385120_item	2241675	et	4	main
ja	doc_13389385120_item	2241677	et	3	main
rahvusliku	doc_13389385120_item	2241691	et	3	main
suhtluse	doc_13389385120_item	2241693	et	3	main
täiustab	doc_13389385120_item	2241695	et	3	main
kirjanduse	doc_13389385120_item	2241698	et	3	main
integreeritud	doc_13389385120_item	2241699	et	4	main
kommunikatiivseid	doc_13389385120_item	2241703	et	3	main
küllaldase	doc_13389385120_item	2241706	et	3	main
arusaama	doc_13389385120_item	2241707	et	4	main
kirjanduse	doc_13389385120_item	2241709	et	3	main
kirjanduse	doc_13389385120_item	2241713	et	3	main
seostest	doc_13389385120_item	2241718	et	3	main
õpib	doc_13389385120_item	2241727	et	3	main
kirjanduse	doc_13389385120_item	2241732	et	3	main
kultuuri	doc_13389385120_item	2241734	et	4	main
2	doc_13389385120_item	2241737	et	2	main
kooliastmel	doc_13389385120_item	2241740	et	3	main
kirjanduse	doc_13389385120_item	2241742	et	3	main
biograafiliste	doc_13389385120_item	2241750	et	4	main
õpilased	doc_13389385120_item	2241754	et	3	main
teadmisi	doc_13389385120_item	2241756	et	4	main
ilukirjandusteksti	doc_13389385120_item	2241757	et	4	main
huvi	doc_13389385120_item	2241773	et	4	main
3	doc_13389385120_item	2241778	et	2	main
teadusest	doc_13389385120_item	2241815	et	4	main
keele	doc_13389385120_item	2241730	et	4	main
ning	doc_13389385120_item	2241733	et	3	main
õppetegevus	doc_13389385120_item	2241738	et	4	main
kultuuriruumi	doc_13389385120_item	2241744	et	4	main
kirjanduse	doc_13389385120_item	2241746	et	3	main
ei	doc_13389385120_item	2241748	et	4	main
stilistikast	doc_13389385120_item	2241758	et	4	main
teadmisi	doc_13389385120_item	2241763	et	4	main
vastu	doc_13389385120_item	2241777	et	3	main
õppesisu	doc_13389385120_item	2241779	et	4	main
1	doc_13389385120_item	2241780	et	2	main
ärkamisaegne	doc_13389385120_item	2241781	et	3	main
kultuurielu	doc_13389385120_item	2241782	et	4	main
rahvusliku	doc_13389385120_item	2241783	et	3	main
kirjanduse	doc_13389385120_item	2241784	et	3	main
ja	doc_13389385120_item	2241785	et	3	main
kunsti	doc_13389385120_item	2241786	et	4	main
sünd	doc_13389385120_item	2241787	et	3	main
kutselise	doc_13389385120_item	2241788	et	4	main
teatri	doc_13389385120_item	2241789	et	3	main
ja	doc_13389385120_item	2241790	et	3	main
laulupidude	doc_13389385120_item	2241791	et	4	main
traditsiooni	doc_13389385120_item	2241792	et	4	main
kirjanikud	doc_13389385120_item	2241794	et	3	main
friedrich	doc_13389385120_item	2241795	et	4	main
algus	doc_13389385120_item	2241793	et	4	main
reinhold	doc_13389385120_item	2241796	et	4	main
kreutzwald	doc_13389385120_item	2241797	et	4	main
lydia	doc_13389385120_item	2241798	et	4	main
koidula	doc_13389385120_item	2241799	et	4	main
eduard	doc_13389385120_item	2241800	et	4	main
bornhöhe	doc_13389385120_item	2241801	et	4	main
anna	doc_13389385120_item	2241802	et	4	main
haava	doc_13389385120_item	2241803	et	4	main
2	doc_13389385120_item	2241804	et	2	main
20	doc_13389385120_item	2241805	et	2	main
sajandi	doc_13389385120_item	2241806	et	3	main
i	doc_13389385120_item	2241807	et	4	main
poole	doc_13389385120_item	2241808	et	4	main
kultuurielu	doc_13389385120_item	2241809	et	4	main
kirjandus	doc_13389385120_item	2241810	et	3	main
näiteid	doc_13389385120_item	2241811	et	3	main
kunstist	doc_13389385120_item	2241813	et	4	main
kirjanikud	doc_13389385120_item	2241816	et	3	main
gustav	doc_13389385120_item	2241821	et	4	main
ii	doc_13389385120_item	2241828	et	4	main
ja	doc_13389385120_item	2241832	et	3	main
kirjandus	doc_13389385120_item	2241835	et	3	main
tutvustus	doc_13389385120_item	2241842	et	4	main
jaan	doc_13389385120_item	2241848	et	3	main
paul-eerik	doc_13389385120_item	2241850	et	4	main
ja	doc_13389385120_item	2241861	et	3	main
eesti	doc_13389385120_item	2241864	et	4	main
seosed	doc_13389385120_item	2241893	et	3	main
4	doc_13389385120_item	2241895	et	2	main
kasutatav	doc_13389385120_item	2241896	et	4	main
õppevahendid	doc_13389385120_item	2241898	et	3	main
väike	doc_13389385120_item	2241901	et	4	main
tuglas	doc_13389385120_item	2241824	et	4	main
sajandi	doc_13389385120_item	2241827	et	3	main
kunstniku	doc_13389385120_item	2241840	et	3	main
kultuurisaate	doc_13389385120_item	2241844	et	3	main
arutelu	doc_13389385120_item	2241846	et	4	main
rummo	doc_13389385120_item	2241851	et	4	main
viiding	doc_13389385120_item	2241857	et	4	main
keeled	doc_13389385120_item	2241863	et	3	main
keel	doc_13389385120_item	2241865	et	4	main
kui	doc_13389385120_item	2241866	et	3	main
soomeugri	doc_13389385120_item	2241867	et	4	main
eesti	doc_13389385120_item	2241871	et	4	main
ja	doc_13389385120_item	2241872	et	3	main
vene	doc_13389385120_item	2241873	et	4	main
keeles	doc_13389385120_item	2241874	et	4	main
kirjanikud	doc_13389385120_item	2241875	et	3	main
andrus	doc_13389385120_item	2241876	et	3	main
kivirähk	doc_13389385120_item	2241877	et	3	main
5	doc_13389385120_item	2241878	et	2	main
eesti	doc_13389385120_item	2241879	et	4	main
kirjakeele	doc_13389385120_item	2241880	et	4	main
kujunemine	doc_13389385120_item	2241881	et	4	main
2-3	doc_13389385120_item	2241882	et	2	main
keeleteadlase	doc_13389385120_item	2241883	et	3	main
tegevuse	doc_13389385120_item	2241884	et	4	main
tutvustus	doc_13389385120_item	2241885	et	4	main
koostamise	doc_13389385120_item	2241887	et	4	main
õigekeelsussõnaraamatu	doc_13389385120_item	2241886	et	4	main
printsiibid	doc_13389385120_item	2241888	et	3	main
ja	doc_13389385120_item	2241889	et	3	main
kasutamine	doc_13389385120_item	2241890	et	4	main
kultuuride	doc_13389385120_item	2241891	et	3	main
vahelised	doc_13389385120_item	2241892	et	4	main
4	doc_13389385120_item	2241858	et	2	main
keel	doc_13389385120_item	2241860	et	4	main
m	doc_13389385120_item	2241899	et	4	main
lias	doc_13389385120_item	2241914	et	4	main
klassile	doc_13389385120_item	2241918	et	3	main
kki	doc_13389385120_item	2241926	et	4	main
1999	doc_13389385120_item	2241934	et	2	main
kultuuri	doc_13389385120_item	2241944	et	4	main
aega	doc_13389385120_item	2241949	et	4	main
klassi	doc_13389385120_item	2241951	et	4	main
orienteeruda	doc_13389385120_item	2241954	et	3	main
teab	doc_13389385120_item	2241960	et	3	main
kultuuritegelasi	doc_13389385120_item	2241962	et	3	main
lugenud	doc_13389385120_item	2241964	et	4	main
proosateost	doc_13389385120_item	2241969	et	4	main
iseloomulikke	doc_13389385120_item	2241973	et	3	main
kommentaar	doc_13389385120_item	2241978	et	3	main
hennoste	doc_13389385120_item	2241900	et	4	main
kirjanduslugu	doc_13389385120_item	2241903	et	4	main
1997	doc_13389385120_item	2241905	et	2	main
eesti	doc_13389385120_item	2241915	et	4	main
sõnaraamat	doc_13389385120_item	2241924	et	3	main
eta	doc_13389385120_item	2241925	et	4	main
1993	doc_13389385120_item	2241927	et	2	main
joonuks	doc_13389385120_item	2241929	et	4	main
paiku	doc_13389385120_item	2241931	et	4	main
koolibri	doc_13389385120_item	2241933	et	4	main
klass	doc_13389385120_item	2241936	et	3	main
on	doc_13389385120_item	2241940	et	4	main
eesti	doc_13389385120_item	2241955	et	4	main
sotsiaalsfääris	doc_13389385120_item	2241958	et	3	main
eesti	doc_13389385120_item	2241965	et	4	main
luulet	doc_13389385120_item	2241966	et	3	main
2-3	doc_13389385120_item	2241968	et	2	main
teab	doc_13389385120_item	2241970	et	3	main
õpetaja	doc_13389385120_item	2241977	et	4	main
klassi	doc_13389385120_item	2241980	et	4	main
õppekavast	doc_13389385120_item	2241981	et	4	main
gümnaasiumi	doc_13389385120_item	2241982	et	4	main
tunnise	doc_13389385120_item	2241986	et	4	main
juba	doc_13389385120_item	2242037	et	3	main
ununenud	doc_13389385120_item	2242039	et	4	main
klassis	doc_13389385120_item	2242059	et	3	main
tähtpäevadega	doc_13389385120_item	2242069	et	3	main
kahjuks	doc_13389385120_item	2242075	et	4	main
koolis	doc_13389385120_item	2242079	et	4	main
seis	doc_13389385120_item	2242080	et	4	main
kurb	doc_13389385120_item	2242082	et	3	main
loota	doc_13389385120_item	2242124	et	4	main
anonüümne	doc_13389385120_item	2242146	et	3	main
õpilased	doc_13389385120_item	2242148	et	3	main
nad	doc_13389385120_item	2242153	et	3	main
mida	doc_13389385120_item	2242156	et	4	main
tühja	doc_13389385120_item	2242163	et	4	main
jätta	doc_13389385120_item	2242165	et	3	main
see	doc_13389385120_item	2242167	et	3	main
harjutus	doc_13389385120_item	2242172	et	4	main
ning	doc_13389385120_item	2242178	et	3	main
tulemusi	doc_13389385120_item	2242185	et	4	main
2	doc_13389385120_item	2242189	et	2	main
esimene	doc_13389385120_item	2242191	et	3	main
18	doc_13389385120_item	2242198	et	2	main
oli	doc_13389385120_item	2242202	et	3	main
õim	doc_13389385120_item	2241922	et	4	main
h	doc_13389385120_item	2241928	et	4	main
kirjanduslikke	doc_13389385120_item	2241930	et	3	main
eestis	doc_13389385120_item	2241932	et	3	main
12	doc_13389385120_item	2241935	et	2	main
riigieksamile	doc_13389385120_item	2241942	et	3	main
vähe	doc_13389385120_item	2241948	et	3	main
kultuuris	doc_13389385120_item	2241956	et	3	main
on	doc_13389385120_item	2241963	et	4	main
ühiskonnale	doc_13389385120_item	2241972	et	4	main
ja	doc_13389385120_item	2241975	et	3	main
õpilane	doc_13389385120_item	2241983	et	3	main
läbib	doc_13389385120_item	2241984	et	3	main
eesti	doc_13389385120_item	2241988	et	4	main
rahvuskultuuri	doc_13389385120_item	2241989	et	4	main
kohta	doc_13389385120_item	2241990	et	4	main
ja	doc_13389385120_item	2241991	et	3	main
sellega	doc_13389385120_item	2241992	et	3	main
asi	doc_13389385120_item	2241993	et	4	main
piirdubki	doc_13389385120_item	2241994	et	3	main
kui	doc_13389385120_item	2241995	et	3	main
õpilane	doc_13389385120_item	2241996	et	3	main
valikainena	doc_13389385120_item	2241998	et	3	main
valib	doc_13389385120_item	2241997	et	3	main
eesti	doc_13389385120_item	2241999	et	4	main
kirjanduse	doc_13389385120_item	2242000	et	3	main
siis	doc_13389385120_item	2242001	et	3	main
saab	doc_13389385120_item	2242002	et	3	main
ta	doc_13389385120_item	2242003	et	4	main
veel	doc_13389385120_item	2242004	et	4	main
35	doc_13389385120_item	2242005	et	2	main
tunni	doc_13389385120_item	2242006	et	3	main
ulatuses	doc_13389385120_item	2242007	et	4	main
teadmisi	doc_13389385120_item	2242008	et	4	main
kirjanduse	doc_13389385120_item	2242010	et	3	main
eesti	doc_13389385120_item	2242009	et	4	main
kohta	doc_13389385120_item	2242011	et	4	main
ning	doc_13389385120_item	2242012	et	3	main
ongi	doc_13389385120_item	2242013	et	4	main
kõik	doc_13389385120_item	2242014	et	4	main
kahjuks	doc_13389385120_item	2242015	et	4	main
ei	doc_13389385120_item	2242016	et	4	main
suuda	doc_13389385120_item	2242017	et	4	main
gümnaasiumi	doc_13389385120_item	2242018	et	4	main
õpilane	doc_13389385120_item	2242019	et	3	main
nimetada	doc_13389385120_item	2242020	et	3	main
on	doc_13389385120_item	2242025	et	4	main
eesti	doc_13389385120_item	2242027	et	4	main
hümn	doc_13389385120_item	2242028	et	3	main
eesti	doc_13389385120_item	2242031	et	4	main
nende	doc_13389385120_item	2242034	et	4	main
ajaloost	doc_13389385120_item	2242042	et	4	main
teaks	doc_13389385120_item	2242054	et	3	main
väga	doc_13389385120_item	2241947	et	3	main
õpilane	doc_13389385120_item	2241952	et	3	main
ta	doc_13389385120_item	2241959	et	4	main
eesti	doc_13389385120_item	2241961	et	4	main
ja	doc_13389385120_item	2241967	et	3	main
käitumis-	doc_13389385120_item	2241974	et	4	main
suhtlemisnorme	doc_13389385120_item	2241976	et	3	main
1012	doc_13389385120_item	2241979	et	2	main
35	doc_13389385120_item	2241985	et	2	main
kursuse	doc_13389385120_item	2241987	et	3	main
eesti	doc_13389385120_item	2242021	et	4	main
tähendus	doc_13389385120_item	2242035	et	4	main
ammu	doc_13389385120_item	2242038	et	4	main
ning	doc_13389385120_item	2242040	et	3	main
teata	doc_13389385120_item	2242044	et	4	main
rahvapärimust	doc_13389385120_item	2242056	et	4	main
peaks	doc_13389385120_item	2242057	et	4	main
üks	doc_13389385120_item	2242061	et	3	main
nädalas	doc_13389385120_item	2242063	et	3	main
kultuurilugu	doc_13389385120_item	2242065	et	4	main
rahvakalendri	doc_13389385120_item	2242068	et	3	main
muukeelses	doc_13389385120_item	2242078	et	4	main
üpris	doc_13389385120_item	2242081	et	3	main
eesti	doc_13389385120_item	2242085	et	4	main
paremaks	doc_13389385120_item	2242121	et	4	main
rohkem	doc_13389385120_item	2242130	et	4	main
ruumi	doc_13389385120_item	2242131	et	4	main
jaoks	doc_13389385120_item	2242135	et	4	main
ma	doc_13389385120_item	2242142	et	3	main
seega	doc_13389385120_item	2242147	et	4	main
said	doc_13389385120_item	2242149	et	4	main
ausalt	doc_13389385120_item	2242150	et	4	main
mida	doc_13389385120_item	2242152	et	4	main
teavad	doc_13389385120_item	2242154	et	3	main
teadnud	doc_13389385120_item	2242159	et	4	main
ole	doc_13389385120_item	2242170	et	4	main
ei	doc_13389385120_item	2242174	et	4	main
selleks	doc_13389385120_item	2242181	et	4	main
et	doc_13389385120_item	2242182	et	3	main
oli	doc_13389385120_item	2242187	et	3	main
7	doc_13389385120_item	2242193	et	2	main
küsimustest	doc_13389385120_item	2242199	et	4	main
teine	doc_13389385120_item	2242201	et	3	main
üldse	doc_13389385120_item	2242245	et	3	main
aga	doc_13389385120_item	2242254	et	3	main
voldemarperekonnanimi	doc_13389385120_item	2242275	et	4	main
lihtsalt	doc_13389385120_item	2242279	et	4	main
ning	doc_13389385120_item	2242284	et	3	main
ning	doc_13389385120_item	2242293	et	3	main
inimest	doc_13389385120_item	2242295	et	3	main
frederik	doc_13389385120_item	2242307	et	4	main
ja	doc_13389385120_item	2242309	et	3	main
ainult	doc_13389385120_item	2242314	et	4	main
tulemus	doc_13389385120_item	2242317	et	3	main
kultuuritegelasi	doc_13389385120_item	2242022	et	3	main
rahatähtedel	doc_13389385120_item	2242023	et	4	main
kuid	doc_13389385120_item	2242033	et	4	main
ei	doc_13389385120_item	2242043	et	4	main
ka	doc_13389385120_item	2242045	et	3	main
midagi	doc_13389385120_item	2242046	et	4	main
vene	doc_13389385120_item	2242049	et	4	main
ja	doc_13389385120_item	2242053	et	3	main
eesti	doc_13389385120_item	2242055	et	4	main
olema	doc_13389385120_item	2242060	et	4	main
tutvutakse	doc_13389385120_item	2242067	et	3	main
ajalooga	doc_13389385120_item	2242071	et	4	main
jne	doc_13389385120_item	2242074	et	4	main
on	doc_13389385120_item	2242076	et	4	main
koolis	doc_13389385120_item	2242086	et	4	main
mis	doc_13389385120_item	2242089	et	4	main
kiita	doc_13389385120_item	2242090	et	4	main
ole	doc_13389385120_item	2242091	et	4	main
kõik	doc_13389385120_item	2242092	et	4	main
sõltub	doc_13389385120_item	2242093	et	3	main
koolist	doc_13389385120_item	2242094	et	4	main
ja	doc_13389385120_item	2242095	et	3	main
selles	doc_13389385120_item	2242096	et	4	main
koolis	doc_13389385120_item	2242097	et	4	main
töötavatest	doc_13389385120_item	2242098	et	4	main
õpetajatest	doc_13389385120_item	2242099	et	4	main
kui	doc_13389385120_item	2242100	et	3	main
õpetaja	doc_13389385120_item	2242101	et	4	main
on	doc_13389385120_item	2242102	et	4	main
kiiksuga	doc_13389385120_item	2242104	et	4	main
nn	doc_13389385120_item	2242103	et	4	main
siis	doc_13389385120_item	2242105	et	3	main
õpivad	doc_13389385120_item	2242106	et	3	main
tema	doc_13389385120_item	2242108	et	4	main
ka	doc_13389385120_item	2242107	et	3	main
õpilased	doc_13389385120_item	2242109	et	3	main
kultuurilugu	doc_13389385120_item	2242110	et	4	main
tundma	doc_13389385120_item	2242111	et	3	main
kui	doc_13389385120_item	2242112	et	3	main
aga	doc_13389385120_item	2242113	et	3	main
pole	doc_13389385120_item	2242114	et	3	main
siis	doc_13389385120_item	2242115	et	3	main
ei	doc_13389385120_item	2242116	et	4	main
ole	doc_13389385120_item	2242117	et	4	main
lootustki	doc_13389385120_item	2242118	et	4	main
et	doc_13389385120_item	2242119	et	3	main
midagi	doc_13389385120_item	2242120	et	4	main
muutub	doc_13389385120_item	2242122	et	3	main
jääb	doc_13389385120_item	2242123	et	3	main
et	doc_13389385120_item	2242125	et	3	main
riiklikus	doc_13389385120_item	2242127	et	4	main
tundide	doc_13389385120_item	2242134	et	3	main
tööhüpoteesi	doc_13389385120_item	2242140	et	4	main
selleks	doc_13389385120_item	2242047	et	4	main
et	doc_13389385120_item	2242048	et	3	main
kooli	doc_13389385120_item	2242050	et	4	main
lõpetaja	doc_13389385120_item	2242051	et	4	main
tunneks	doc_13389385120_item	2242052	et	4	main
igas	doc_13389385120_item	2242058	et	3	main
tund	doc_13389385120_item	2242062	et	3	main
eesti	doc_13389385120_item	2242064	et	4	main
kus	doc_13389385120_item	2242066	et	3	main
eesti	doc_13389385120_item	2242070	et	4	main
kirjandusega	doc_13389385120_item	2242072	et	3	main
geograafia	doc_13389385120_item	2242073	et	4	main
ka	doc_13389385120_item	2242084	et	3	main
see	doc_13389385120_item	2242087	et	3	main
jääb	doc_13389385120_item	2242129	et	3	main
ka	doc_13389385120_item	2242132	et	3	main
kultuuriloo	doc_13389385120_item	2242133	et	4	main
testid	doc_13389385120_item	2242137	et	4	main
oma	doc_13389385120_item	2242139	et	4	main
testidtest	doc_13389385120_item	2242144	et	4	main
kirjutada	doc_13389385120_item	2242151	et	3	main
ning	doc_13389385120_item	2242155	et	3	main
ei	doc_13389385120_item	2242157	et	4	main
olnud	doc_13389385120_item	2242158	et	4	main
vabalt	doc_13389385120_item	2242162	et	4	main
töö	doc_13389385120_item	2242168	et	4	main
hindeline	doc_13389385120_item	2242171	et	4	main
siis	doc_13389385120_item	2242173	et	3	main
ole	doc_13389385120_item	2242175	et	4	main
mul	doc_13389385120_item	2242186	et	3	main
tehtud	doc_13389385120_item	2242188	et	4	main
jaoks	doc_13389385120_item	2242195	et	4	main
ja	doc_13389385120_item	2242196	et	3	main
koosnes	doc_13389385120_item	2242197	et	3	main
ja	doc_13389385120_item	2242200	et	3	main
millised	doc_13389385120_item	2242222	et	3	main
riigisümbolid	doc_13389385120_item	2242225	et	3	main
vastusteks	doc_13389385120_item	2242227	et	4	main
ootasin	doc_13389385120_item	2242229	et	3	main
vapi	doc_13389385120_item	2242233	et	3	main
kirjutasid	doc_13389385120_item	2242237	et	4	main
teadnud	doc_13389385120_item	2242244	et	4	main
ja	doc_13389385120_item	2242247	et	3	main
hakkkasid	doc_13389385120_item	2242249	et	4	main
on	doc_13389385120_item	2242252	et	4	main
frederik	doc_13389385120_item	2242283	et	4	main
ei	doc_13389385120_item	2242288	et	4	main
midagi	doc_13389385120_item	2242291	et	4	main
kirjutasid	doc_13389385120_item	2242296	et	4	main
hümni	doc_13389385120_item	2242303	et	4	main
autor	doc_13389385120_item	2242305	et	3	main
koidula	doc_13389385120_item	2242312	et	4	main
olla	doc_13389385120_item	2242319	et	3	main
põhjustatud	doc_13389385120_item	2242320	et	4	main
et	doc_13389385120_item	2242322	et	3	main
mainitud	doc_13389385120_item	2242329	et	4	main
mis	doc_13389385120_item	2242340	et	4	main
lilli	doc_13389385120_item	2242344	et	4	main
ainult	doc_13389385120_item	2242350	et	4	main
õppima	doc_13389385120_item	2242371	et	3	main
iga	doc_13389385120_item	2242375	et	4	main
on	doc_13389385120_item	2242381	et	4	main
paljude	doc_13389385120_item	2242383	et	3	main
küsimus	doc_13389385120_item	2242389	et	4	main
andsid	doc_13389385120_item	2242394	et	4	main
palju	doc_13389385120_item	2242409	et	4	main
selge	doc_13389385120_item	2242413	et	4	main
millal	doc_13389385120_item	2242414	et	3	main
ja	doc_13389385120_item	2242415	et	3	main
täna	doc_13389385120_item	2242077	et	4	main
ega	doc_13389385120_item	2242083	et	3	main
tea	doc_13389385120_item	2242088	et	4	main
uues	doc_13389385120_item	2242126	et	3	main
õppekavas	doc_13389385120_item	2242128	et	3	main
2õppimine	doc_13389385120_item	2242136	et	4	main
sissejuhatus	doc_13389385120_item	2242138	et	4	main
tõestamiseks	doc_13389385120_item	2242141	et	4	main
siis	doc_13389385120_item	2242160	et	3	main
kohta	doc_13389385120_item	2242164	et	4	main
kuna	doc_13389385120_item	2242166	et	3	main
ei	doc_13389385120_item	2242169	et	4	main
vaja	doc_13389385120_item	2242176	et	4	main
kirjutada	doc_13389385120_item	2242180	et	3	main
häid	doc_13389385120_item	2242184	et	3	main
11	doc_13389385120_item	2242203	et	2	main
klassi	doc_13389385120_item	2242204	et	4	main
ja	doc_13389385120_item	2242206	et	3	main
jaoks	doc_13389385120_item	2242205	et	4	main
28	doc_13389385120_item	2242208	et	2	main
koosnes	doc_13389385120_item	2242207	et	3	main
küsimutest	doc_13389385120_item	2242209	et	3	main
21	doc_13389385120_item	2242210	et	2	main
testianalüüs	doc_13389385120_item	2242212	et	3	main
7klassi	doc_13389385120_item	2242211	et	4	main
kokku	doc_13389385120_item	2242213	et	3	main
oli	doc_13389385120_item	2242214	et	3	main
läbi	doc_13389385120_item	2242215	et	4	main
küsitud	doc_13389385120_item	2242216	et	4	main
32	doc_13389385120_item	2242217	et	2	main
õpilast	doc_13389385120_item	2242218	et	4	main
esimeseks	doc_13389385120_item	2242219	et	3	main
küsimiseks	doc_13389385120_item	2242220	et	4	main
eesti	doc_13389385120_item	2242224	et	4	main
ja	doc_13389385120_item	2242234	et	3	main
selliseid	doc_13389385120_item	2242235	et	4	main
vastuseid	doc_13389385120_item	2242236	et	3	main
5	doc_13389385120_item	2242239	et	2	main
ei	doc_13389385120_item	2242243	et	4	main
rahvuslindlillkivi	doc_13389385120_item	2242253	et	4	main
oli	doc_13389385120_item	2242256	et	3	main
eraldi	doc_13389385120_item	2242258	et	4	main
puudu	doc_13389385120_item	2242280	et	4	main
oli	doc_13389385120_item	2242281	et	3	main
kirjutanud	doc_13389385120_item	2242289	et	4	main
mitte	doc_13389385120_item	2242290	et	3	main
voldemar	doc_13389385120_item	2242298	et	4	main
9	doc_13389385120_item	2242300	et	2	main
võib	doc_13389385120_item	2242318	et	3	main
sellega	doc_13389385120_item	2242321	et	3	main
pacius	doc_13389385120_item	2242323	et	4	main
ei	doc_13389385120_item	2242328	et	4	main
et	doc_13389385120_item	2242331	et	3	main
et	doc_13389385120_item	2242333	et	3	main
töötas	doc_13389385120_item	2242335	et	3	main
juhendamise	doc_13389385120_item	2242337	et	4	main
küsimused	doc_13389385120_item	2242339	et	4	main
hakatakse	doc_13389385120_item	2242370	et	3	main
alates	doc_13389385120_item	2242372	et	3	main
ja	doc_13389385120_item	2242374	et	3	main
samas	doc_13389385120_item	2242378	et	4	main
sümbolid	doc_13389385120_item	2242380	et	3	main
kirjas	doc_13389385120_item	2242382	et	4	main
kõik	doc_13389385120_item	2242393	et	4	main
ei	doc_13389385120_item	2242400	et	4	main
midagi	doc_13389385120_item	2242404	et	4	main
tekitas	doc_13389385120_item	2242407	et	3	main
ole	doc_13389385120_item	2242412	et	4	main
absurdseid	doc_13389385120_item	2242434	et	3	main
vastuseidseal	doc_13389385120_item	2242435	et	4	main
korraldasin	doc_13389385120_item	2242143	et	3	main
oli	doc_13389385120_item	2242145	et	3	main
võiksid	doc_13389385120_item	2242161	et	4	main
pingutada	doc_13389385120_item	2242177	et	3	main
maha	doc_13389385120_item	2242179	et	4	main
saavutada	doc_13389385120_item	2242183	et	3	main
testivarianti	doc_13389385120_item	2242190	et	4	main
oli	doc_13389385120_item	2242192	et	3	main
klassi	doc_13389385120_item	2242194	et	4	main
oli	doc_13389385120_item	2242221	et	3	main
on	doc_13389385120_item	2242223	et	4	main
ning	doc_13389385120_item	2242226	et	3	main
ma	doc_13389385120_item	2242228	et	3	main
eesti	doc_13389385120_item	2242230	et	4	main
ja	doc_13389385120_item	2242232	et	3	main
inimest	doc_13389385120_item	2242240	et	3	main
6	doc_13389385120_item	2242242	et	2	main
vastust	doc_13389385120_item	2242246	et	4	main
kes	doc_13389385120_item	2242251	et	4	main
paljudel	doc_13389385120_item	2242277	et	3	main
inimestel	doc_13389385120_item	2242278	et	3	main
ka	doc_13389385120_item	2242282	et	3	main
inimest	doc_13389385120_item	2242286	et	3	main
vastuseks	doc_13389385120_item	2242292	et	4	main
õpilast	doc_13389385120_item	2242301	et	4	main
oli	doc_13389385120_item	2242306	et	3	main
õiget	doc_13389385120_item	2242310	et	3	main
üks	doc_13389385120_item	2242315	et	3	main
on	doc_13389385120_item	2242324	et	4	main
koidulat	doc_13389385120_item	2242327	et	4	main
sellepärast	doc_13389385120_item	2242330	et	3	main
puudutasid	doc_13389385120_item	2242341	et	4	main
eesti	doc_13389385120_item	2242342	et	4	main
rahvuslidu	doc_13389385120_item	2242343	et	4	main
kõikidel	doc_13389385120_item	2242347	et	4	main
vastused	doc_13389385120_item	2242349	et	3	main
põhjustatud	doc_13389385120_item	2242365	et	4	main
et	doc_13389385120_item	2242368	et	3	main
1klassist	doc_13389385120_item	2242373	et	3	main
eesti	doc_13389385120_item	2242384	et	4	main
esikaaneteloli	doc_13389385120_item	2242387	et	4	main
öeldes	doc_13389385120_item	2242398	et	3	main
oodanud	doc_13389385120_item	2242402	et	4	main
mitte	doc_13389385120_item	2242403	et	3	main
muudküsimus	doc_13389385120_item	2242405	et	3	main
oli	doc_13389385120_item	2242417	et	3	main
laulupidu	doc_13389385120_item	2242419	et	4	main
tihti	doc_13389385120_item	2242421	et	3	main
peetakse	doc_13389385120_item	2242423	et	3	main
keegi	doc_13389385120_item	2242425	et	4	main
osanud	doc_13389385120_item	2242427	et	4	main
esimene	doc_13389385120_item	2242447	et	3	main
peetakse	doc_13389385120_item	2242454	et	3	main
millal	doc_13389385120_item	2242460	et	3	main
korraldatakse	doc_13389385120_item	2242470	et	3	main
perioodil	doc_13389385120_item	2242478	et	3	main
saa	doc_13389385120_item	2242480	et	4	main
rääkidantminna	doc_13389385120_item	2242487	et	4	main
mis	doc_13389385120_item	2242490	et	4	main
vastustseega	doc_13389385120_item	2242496	et	4	main
ei	doc_13389385120_item	2242500	et	4	main
midagi	doc_13389385120_item	2242502	et	4	main
ja	doc_13389385120_item	2242504	et	3	main
kummalist	doc_13389385120_item	2242507	et	3	main
veebruar	doc_13389385120_item	2242509	et	3	main
detsembermiks	doc_13389385120_item	2242512	et	4	main
järgmine	doc_13389385120_item	2242520	et	3	main
puudutas	doc_13389385120_item	2242522	et	3	main
räägitakse	doc_13389385120_item	2242545	et	3	main
igapäeva	doc_13389385120_item	2242549	et	4	main
põhjustas	doc_13389385120_item	2242553	et	3	main
raske	doc_13389385120_item	2242557	et	4	main
välja	doc_13389385120_item	2242558	et	4	main
tuleb	doc_13389385120_item	2242588	et	3	main
muutuda	doc_13389385120_item	2242590	et	3	main
lisada	doc_13389385120_item	2242592	et	3	main
mis	doc_13389385120_item	2242601	et	4	main
ei	doc_13389385120_item	2242608	et	4	main
sellepärast	doc_13389385120_item	2242612	et	3	main
seal	doc_13389385120_item	2242614	et	4	main
õpilased	doc_13389385120_item	2242620	et	3	main
eesti	doc_13389385120_item	2242625	et	4	main
vanasõnadega	doc_13389385120_item	2242626	et	3	main
õpilane	doc_13389385120_item	2242641	et	3	main
lippuhümni	doc_13389385120_item	2242231	et	4	main
ainult	doc_13389385120_item	2242238	et	4	main
32st	doc_13389385120_item	2242241	et	3	main
ülejäänud	doc_13389385120_item	2242248	et	4	main
kirjutama	doc_13389385120_item	2242250	et	3	main
selleks	doc_13389385120_item	2242255	et	4	main
mul	doc_13389385120_item	2242257	et	3	main
küsimusedteiseks	doc_13389385120_item	2242259	et	4	main
küsimuseks	doc_13389385120_item	2242260	et	4	main
oli	doc_13389385120_item	2242261	et	3	main
kes	doc_13389385120_item	2242262	et	4	main
on	doc_13389385120_item	2242263	et	4	main
eesti	doc_13389385120_item	2242264	et	4	main
hümni	doc_13389385120_item	2242265	et	4	main
sõnade	doc_13389385120_item	2242266	et	3	main
kirjutaja	doc_13389385120_item	2242267	et	4	main
olid	doc_13389385120_item	2242269	et	4	main
mainitud	doc_13389385120_item	2242270	et	4	main
vastusteks	doc_13389385120_item	2242268	et	4	main
jakob	doc_13389385120_item	2242271	et	4	main
hurt	doc_13389385120_item	2242272	et	3	main
jakobson	doc_13389385120_item	2242273	et	4	main
johan	doc_13389385120_item	2242274	et	4	main
oli	doc_13389385120_item	2242276	et	3	main
8	doc_13389385120_item	2242285	et	2	main
32st	doc_13389385120_item	2242287	et	3	main
11	doc_13389385120_item	2242294	et	2	main
johan	doc_13389385120_item	2242297	et	4	main
jansen	doc_13389385120_item	2242299	et	4	main
arvasidet	doc_13389385120_item	2242302	et	4	main
sõnade	doc_13389385120_item	2242304	et	3	main
pacius	doc_13389385120_item	2242308	et	4	main
vastust-lydia	doc_13389385120_item	2242311	et	4	main
kirjutas	doc_13389385120_item	2242313	et	3	main
õpilaneselline	doc_13389385120_item	2242316	et	4	main
helilooja	doc_13389385120_item	2242325	et	4	main
ja	doc_13389385120_item	2242326	et	3	main
all	doc_13389385120_item	2242338	et	3	main
puu	doc_13389385120_item	2242345	et	4	main
olid	doc_13389385120_item	2242346	et	4	main
õiged	doc_13389385120_item	2242348	et	3	main
2	doc_13389385120_item	2242351	et	2	main
sellega	doc_13389385120_item	2242366	et	3	main
rahvussümbolid	doc_13389385120_item	2242369	et	3	main
korratakse	doc_13389385120_item	2242377	et	4	main
need	doc_13389385120_item	2242379	et	3	main
presidendist	doc_13389385120_item	2242391	et	4	main
õiged	doc_13389385120_item	2242395	et	3	main
ausalt	doc_13389385120_item	2242397	et	4	main
ole	doc_13389385120_item	2242401	et	4	main
kus	doc_13389385120_item	2242416	et	3	main
ei	doc_13389385120_item	2242426	et	4	main
anda	doc_13389385120_item	2242428	et	3	main
vastust	doc_13389385120_item	2242430	et	4	main
pakutud	doc_13389385120_item	2242432	et	4	main
rahvuslaulelaua	doc_13389385120_item	2242438	et	4	main
peal	doc_13389385120_item	2242439	et	4	main
kus	doc_13389385120_item	2242445	et	3	main
seda	doc_13389385120_item	2242453	et	3	main
ja	doc_13389385120_item	2242455	et	3	main
põhjuseks	doc_13389385120_item	2242464	et	3	main
laulupidu	doc_13389385120_item	2242469	et	4	main
väga	doc_13389385120_item	2242471	et	3	main
ei	doc_13389385120_item	2242479	et	4	main
paljud	doc_13389385120_item	2242493	et	3	main
andsid	doc_13389385120_item	2242494	et	4	main
küsimus	doc_13389385120_item	2242521	et	4	main
eesti	doc_13389385120_item	2242523	et	4	main
rahvuseepose	doc_13389385120_item	2242524	et	3	main
teadsid	doc_13389385120_item	2242528	et	4	main
ka	doc_13389385120_item	2242531	et	3	main
6	doc_13389385120_item	2242536	et	2	main
ei	doc_13389385120_item	2242538	et	4	main
eepost	doc_13389385120_item	2242541	et	3	main
sellest	doc_13389385120_item	2242544	et	4	main
palju	doc_13389385120_item	2242546	et	4	main
nimetada	doc_13389385120_item	2242564	et	3	main
rahvuslaule	doc_13389385120_item	2242566	et	4	main
sinna	doc_13389385120_item	2242593	et	3	main
sellekset	doc_13389385120_item	2242595	et	4	main
endale	doc_13389385120_item	2242598	et	4	main
lapsi	doc_13389385120_item	2242607	et	4	main
vana	doc_13389385120_item	2242617	et	4	main
ei	doc_13389385120_item	2242622	et	4	main
mõned	doc_13389385120_item	2242627	et	3	main
segamini	doc_13389385120_item	2242630	et	4	main
tulemus	doc_13389385120_item	2242635	et	3	main
et	doc_13389385120_item	2242638	et	3	main
läheb	doc_13389385120_item	2242649	et	3	main
vaja	doc_13389385120_item	2242655	et	4	main
õpetada	doc_13389385120_item	2242659	et	3	main
vanasõna	doc_13389385120_item	2242660	et	4	main
järgmiseks	doc_13389385120_item	2242696	et	3	main
mõistatustele	doc_13389385120_item	2242700	et	4	main
küsimusega	doc_13389385120_item	2242708	et	4	main
seega	doc_13389385120_item	2242709	et	4	main
teadmine	doc_13389385120_item	2242715	et	4	main
väga	doc_13389385120_item	2242717	et	3	main
küsisin	doc_13389385120_item	2242721	et	3	main
jumalate	doc_13389385120_item	2242725	et	3	main
vastuseid	doc_13389385120_item	2242728	et	3	main
olid	doc_13389385120_item	2242733	et	4	main
olid	doc_13389385120_item	2242739	et	4	main
rahvakalendristnimelt	doc_13389385120_item	2242740	et	4	main
rahvakalendripäevi	doc_13389385120_item	2242744	et	4	main
reedet	doc_13389385120_item	2242752	et	3	main
küsimus	doc_13389385120_item	2242754	et	4	main
milliseid	doc_13389385120_item	2242757	et	3	main
arvati	doc_13389385120_item	2242332	et	4	main
ta	doc_13389385120_item	2242334	et	4	main
jannseni	doc_13389385120_item	2242336	et	4	main
õpilast	doc_13389385120_item	2242352	et	4	main
ei	doc_13389385120_item	2242353	et	4	main
suutnud	doc_13389385120_item	2242354	et	4	main
kirjutada	doc_13389385120_item	2242355	et	3	main
mis	doc_13389385120_item	2242356	et	4	main
on	doc_13389385120_item	2242357	et	4	main
rahvuspuu	doc_13389385120_item	2242358	et	4	main
selline	doc_13389385120_item	2242359	et	4	main
suur	doc_13389385120_item	2242360	et	3	main
arv	doc_13389385120_item	2242361	et	3	main
õigeid	doc_13389385120_item	2242362	et	3	main
vastuseid	doc_13389385120_item	2242363	et	3	main
oli	doc_13389385120_item	2242364	et	3	main
et	doc_13389385120_item	2242367	et	3	main
aasta	doc_13389385120_item	2242376	et	4	main
keele	doc_13389385120_item	2242385	et	4	main
õpikute	doc_13389385120_item	2242386	et	3	main
ka	doc_13389385120_item	2242388	et	3	main
eesti	doc_13389385120_item	2242390	et	4	main
ning	doc_13389385120_item	2242392	et	3	main
vastused	doc_13389385120_item	2242396	et	3	main
ma	doc_13389385120_item	2242399	et	3	main
laulupeost	doc_13389385120_item	2242406	et	4	main
päris	doc_13389385120_item	2242408	et	4	main
probleemeõpilastel	doc_13389385120_item	2242410	et	4	main
ei	doc_13389385120_item	2242411	et	4	main
esimene	doc_13389385120_item	2242418	et	3	main
kui	doc_13389385120_item	2242420	et	3	main
mitte	doc_13389385120_item	2242424	et	3	main
täpset	doc_13389385120_item	2242429	et	3	main
oli	doc_13389385120_item	2242431	et	3	main
palju	doc_13389385120_item	2242433	et	4	main
voldemar	doc_13389385120_item	2242442	et	4	main
2	doc_13389385120_item	2242456	et	2	main
esimene	doc_13389385120_item	2242462	et	3	main
see	doc_13389385120_item	2242467	et	3	main
toimub	doc_13389385120_item	2242474	et	3	main
et	doc_13389385120_item	2242483	et	3	main
koos	doc_13389385120_item	2242488	et	4	main
iseseisvuspäeva	doc_13389385120_item	2242492	et	4	main
õiget	doc_13389385120_item	2242495	et	3	main
26	doc_13389385120_item	2242497	et	2	main
õpilast	doc_13389385120_item	2242498	et	4	main
andsid	doc_13389385120_item	2242506	et	4	main
vastust16	doc_13389385120_item	2242508	et	4	main
ja	doc_13389385120_item	2242510	et	3	main
olid	doc_13389385120_item	2242514	et	4	main
raske	doc_13389385120_item	2242518	et	4	main
arvata	doc_13389385120_item	2242519	et	4	main
seda	doc_13389385120_item	2242422	et	3	main
inimesed	doc_13389385120_item	2242436	et	3	main
esimeneoli	doc_13389385120_item	2242441	et	4	main
jannsenpaljud	doc_13389385120_item	2242443	et	4	main
oli	doc_13389385120_item	2242446	et	3	main
laulupidu10	doc_13389385120_item	2242448	et	4	main
teavad	doc_13389385120_item	2242450	et	3	main
kui	doc_13389385120_item	2242451	et	3	main
inimest	doc_13389385120_item	2242457	et	3	main
võib	doc_13389385120_item	2242465	et	3	main
see	doc_13389385120_item	2242473	et	3	main
suvevaheajal	doc_13389385120_item	2242475	et	3	main
midagi	doc_13389385120_item	2242481	et	4	main
korraldada	doc_13389385120_item	2242482	et	3	main
õpilastele	doc_13389385120_item	2242484	et	4	main
lähimalt	doc_13389385120_item	2242486	et	4	main
olnud	doc_13389385120_item	2242501	et	4	main
kirjutanud	doc_13389385120_item	2242503	et	4	main
24	doc_13389385120_item	2242511	et	2	main
vastused	doc_13389385120_item	2242513	et	3	main
on	doc_13389385120_item	2242516	et	4	main
ning	doc_13389385120_item	2242535	et	3	main
osanud	doc_13389385120_item	2242539	et	4	main
ja	doc_13389385120_item	2242548	et	3	main
elus	doc_13389385120_item	2242550	et	4	main
puudumist	doc_13389385120_item	2242555	et	4	main
13	doc_13389385120_item	2242567	et	2	main
alusel	doc_13389385120_item	2242587	et	4	main
õpilased	doc_13389385120_item	2242596	et	3	main
rahvuslaul	doc_13389385120_item	2242603	et	4	main
üldse	doc_13389385120_item	2242604	et	3	main
et	doc_13389385120_item	2242613	et	3	main
on	doc_13389385120_item	2242615	et	4	main
sõnavara	doc_13389385120_item	2242618	et	4	main
laulavad	doc_13389385120_item	2242437	et	4	main
oli	doc_13389385120_item	2242440	et	3	main
teadsid	doc_13389385120_item	2242444	et	4	main
õpilast	doc_13389385120_item	2242449	et	4	main
tihti	doc_13389385120_item	2242452	et	3	main
on	doc_13389385120_item	2242458	et	4	main
maininud	doc_13389385120_item	2242459	et	4	main
oli	doc_13389385120_item	2242461	et	3	main
selle	doc_13389385120_item	2242463	et	4	main
olla	doc_13389385120_item	2242466	et	3	main
et	doc_13389385120_item	2242468	et	3	main
harva	doc_13389385120_item	2242472	et	4	main
ja	doc_13389385120_item	2242476	et	3	main
sel	doc_13389385120_item	2242477	et	3	main
sellest	doc_13389385120_item	2242485	et	4	main
laulupeolesee	doc_13389385120_item	2242489	et	4	main
puudutab	doc_13389385120_item	2242491	et	3	main
4	doc_13389385120_item	2242499	et	2	main
2	doc_13389385120_item	2242505	et	2	main
sellisedseda	doc_13389385120_item	2242515	et	4	main
väga	doc_13389385120_item	2242517	et	3	main
väga	doc_13389385120_item	2242526	et	3	main
vastuseks	doc_13389385120_item	2242532	et	4	main
kalev	doc_13389385120_item	2242534	et	3	main
vastatakalevipoja	doc_13389385120_item	2242540	et	4	main
õpitakse	doc_13389385120_item	2242542	et	4	main
ning	doc_13389385120_item	2242551	et	3	main
mis	doc_13389385120_item	2242552	et	4	main
raskeid	doc_13389385120_item	2242562	et	3	main
eesti	doc_13389385120_item	2242565	et	4	main
õppekava	doc_13389385120_item	2242591	et	4	main
audiomaterjale	doc_13389385120_item	2242594	et	3	main
ette	doc_13389385120_item	2242599	et	4	main
samas	doc_13389385120_item	2242606	et	4	main
rahvuslaulud	doc_13389385120_item	2242610	et	3	main
millest	doc_13389385120_item	2242619	et	3	main
aru	doc_13389385120_item	2242621	et	4	main
saasama	doc_13389385120_item	2242623	et	4	main
mitte	doc_13389385120_item	2242639	et	3	main
igapäevases	doc_13389385120_item	2242651	et	4	main
midagi	doc_13389385120_item	2242656	et	4	main
või	doc_13389385120_item	2242658	et	4	main
see	doc_13389385120_item	2242664	et	3	main
pühendada	doc_13389385120_item	2242672	et	3	main
küsimuseks	doc_13389385120_item	2242697	et	4	main
tulemus	doc_13389385120_item	2242702	et	3	main
sama	doc_13389385120_item	2242705	et	4	main
eelneva	doc_13389385120_item	2242707	et	4	main
ei	doc_13389385120_item	2242712	et	4	main
ma	doc_13389385120_item	2242720	et	3	main
nimesid	doc_13389385120_item	2242726	et	3	main
väga	doc_13389385120_item	2242730	et	3	main
mõned	doc_13389385120_item	2242732	et	3	main
naljakad	doc_13389385120_item	2242735	et	3	main
kalevipoegjeesuslydiajärgmised	doc_13389385120_item	2242737	et	4	main
küsimused	doc_13389385120_item	2242738	et	4	main
kirjutada	doc_13389385120_item	2242742	et	3	main
nad	doc_13389385120_item	2242745	et	3	main
rohkem	doc_13389385120_item	2242747	et	4	main
teati	doc_13389385120_item	2242748	et	3	main
jõulud	doc_13389385120_item	2242749	et	3	main
kõlas	doc_13389385120_item	2242755	et	4	main
vastlad	doc_13389385120_item	2242764	et	3	main
mardi-ja	doc_13389385120_item	2242766	et	3	main
tähistatkse	doc_13389385120_item	2242768	et	4	main
palju	doc_13389385120_item	2242770	et	4	main
teadmised	doc_13389385120_item	2242772	et	4	main
on	doc_13389385120_item	2242774	et	4	main
sellepärast	doc_13389385120_item	2242777	et	3	main
nendest	doc_13389385120_item	2242779	et	4	main
peamiselt	doc_13389385120_item	2242813	et	4	main
ka	doc_13389385120_item	2242817	et	3	main
paar	doc_13389385120_item	2242820	et	3	main
põhjusel	doc_13389385120_item	2242829	et	3	main
nimetas	doc_13389385120_item	2242848	et	3	main
koolis	doc_13389385120_item	2242854	et	4	main
sellest	doc_13389385120_item	2242856	et	4	main
küsimusele	doc_13389385120_item	2242861	et	4	main
nimetada	doc_13389385120_item	2242878	et	3	main
näitlejad	doc_13389385120_item	2242882	et	4	main
õpilased99	doc_13389385120_item	2242884	et	3	main
sõpruslavastusi	doc_13389385120_item	2242917	et	3	main
1	doc_13389385120_item	2242920	et	2	main
kirjutanudneed	doc_13389385120_item	2242928	et	4	main
nimet	doc_13389385120_item	2242525	et	4	main
paljud	doc_13389385120_item	2242527	et	3	main
õiget	doc_13389385120_item	2242529	et	3	main
vastustoli	doc_13389385120_item	2242530	et	4	main
pakutud	doc_13389385120_item	2242533	et	4	main
õpilast	doc_13389385120_item	2242537	et	4	main
5klassis	doc_13389385120_item	2242543	et	3	main
koolis	doc_13389385120_item	2242547	et	4	main
vastuse	doc_13389385120_item	2242554	et	3	main
on	doc_13389385120_item	2242556	et	4	main
selgitadasamas	doc_13389385120_item	2242559	et	4	main
ma	doc_13389385120_item	2242560	et	3	main
küsisin	doc_13389385120_item	2242561	et	3	main
küsimisepalusin	doc_13389385120_item	2242563	et	4	main
küsitlenust	doc_13389385120_item	2242568	et	4	main
ei	doc_13389385120_item	2242569	et	4	main
kirjutanud	doc_13389385120_item	2242570	et	4	main
mitte	doc_13389385120_item	2242571	et	3	main
midagi	doc_13389385120_item	2242572	et	4	main
13	doc_13389385120_item	2242573	et	2	main
pidas	doc_13389385120_item	2242574	et	3	main
eesti	doc_13389385120_item	2242575	et	4	main
hümni	doc_13389385120_item	2242576	et	4	main
rahvuslauluks	doc_13389385120_item	2242577	et	4	main
ja	doc_13389385120_item	2242578	et	3	main
niigi	doc_13389385120_item	2242579	et	4	main
kirjutasid	doc_13389385120_item	2242580	et	4	main
ülejäänud	doc_13389385120_item	2242581	et	4	main
pakusid	doc_13389385120_item	2242582	et	4	main
mitmesuguseid	doc_13389385120_item	2242583	et	3	main
õigeid	doc_13389385120_item	2242584	et	3	main
vastuseidselle	doc_13389385120_item	2242585	et	4	main
tulemuse	doc_13389385120_item	2242586	et	3	main
kindlasti	doc_13389385120_item	2242589	et	3	main
saaksid	doc_13389385120_item	2242597	et	4	main
kujutleda	doc_13389385120_item	2242600	et	3	main
see	doc_13389385120_item	2242602	et	3	main
on	doc_13389385120_item	2242605	et	4	main
huvita	doc_13389385120_item	2242609	et	4	main
ka	doc_13389385120_item	2242611	et	3	main
kasutatud	doc_13389385120_item	2242616	et	4	main
ajasid	doc_13389385120_item	2242629	et	4	main
rahvamõistatusi	doc_13389385120_item	2242631	et	3	main
ja	doc_13389385120_item	2242632	et	3	main
seega	doc_13389385120_item	2242634	et	4	main
oli	doc_13389385120_item	2242636	et	3	main
ükski	doc_13389385120_item	2242640	et	4	main
sellele	doc_13389385120_item	2242644	et	4	main
vaja	doc_13389385120_item	2242650	et	4	main
elus	doc_13389385120_item	2242652	et	4	main
on	doc_13389385120_item	2242654	et	4	main
abil	doc_13389385120_item	2242662	et	4	main
aitab	doc_13389385120_item	2242665	et	3	main
arvan	doc_13389385120_item	2242668	et	3	main
õppekavas	doc_13389385120_item	2242670	et	3	main
ja	doc_13389385120_item	2242701	et	3	main
kui	doc_13389385120_item	2242706	et	3	main
osanud	doc_13389385120_item	2242713	et	4	main
oli	doc_13389385120_item	2242624	et	3	main
õpilased	doc_13389385120_item	2242628	et	3	main
vanasõnu	doc_13389385120_item	2242633	et	3	main
selline	doc_13389385120_item	2242637	et	4	main
ei	doc_13389385120_item	2242642	et	4	main
vastanud	doc_13389385120_item	2242643	et	4	main
küsimusele	doc_13389385120_item	2242645	et	4	main
aga	doc_13389385120_item	2242646	et	3	main
vanasõnu	doc_13389385120_item	2242647	et	3	main
kommenteerida	doc_13389385120_item	2242657	et	3	main
samas	doc_13389385120_item	2242663	et	4	main
rikastada	doc_13389385120_item	2242666	et	3	main
saaks	doc_13389385120_item	2242671	et	3	main
kas	doc_13389385120_item	2242673	et	3	main
või	doc_13389385120_item	2242674	et	4	main
üks	doc_13389385120_item	2242675	et	3	main
tund	doc_13389385120_item	2242676	et	3	main
õppeaasta	doc_13389385120_item	2242677	et	4	main
jooksul	doc_13389385120_item	2242678	et	4	main
sellekset	doc_13389385120_item	2242679	et	4	main
sellist	doc_13389385120_item	2242680	et	4	main
olukorda	doc_13389385120_item	2242681	et	4	main
parandada	doc_13389385120_item	2242682	et	3	main
tuleb	doc_13389385120_item	2242684	et	3	main
enne	doc_13389385120_item	2242685	et	4	main
samas	doc_13389385120_item	2242683	et	4	main
õppeteksti	doc_13389385120_item	2242686	et	4	main
lisada	doc_13389385120_item	2242687	et	3	main
vanasõnu	doc_13389385120_item	2242688	et	3	main
selle	doc_13389385120_item	2242690	et	4	main
teksti	doc_13389385120_item	2242691	et	4	main
mis	doc_13389385120_item	2242689	et	4	main
sisuga	doc_13389385120_item	2242692	et	3	main
hästi	doc_13389385120_item	2242693	et	3	main
omavahel	doc_13389385120_item	2242694	et	3	main
sobiksid	doc_13389385120_item	2242695	et	4	main
oli	doc_13389385120_item	2242698	et	3	main
tihti	doc_13389385120_item	2242648	et	3	main
kui	doc_13389385120_item	2242653	et	3	main
kasutamise	doc_13389385120_item	2242661	et	4	main
kõnema	doc_13389385120_item	2242667	et	4	main
et	doc_13389385120_item	2242669	et	3	main
vastata	doc_13389385120_item	2242699	et	4	main
oli	doc_13389385120_item	2242703	et	3	main
keegi	doc_13389385120_item	2242711	et	4	main
vastatarahvatarkuste	doc_13389385120_item	2242714	et	4	main
ja	doc_13389385120_item	2242727	et	3	main
väga	doc_13389385120_item	2242734	et	3	main
näiteks	doc_13389385120_item	2242736	et	4	main
suurt	doc_13389385120_item	2242751	et	3	main
tähistavad	doc_13389385120_item	2242760	et	4	main
vastused	doc_13389385120_item	2242762	et	3	main
kadripäevperedes	doc_13389385120_item	2242767	et	3	main
üpris	doc_13389385120_item	2242769	et	3	main
ka	doc_13389385120_item	2242776	et	3	main
väikestele	doc_13389385120_item	2242814	et	4	main
ellen	doc_13389385120_item	2242818	et	4	main
peaaegu	doc_13389385120_item	2242704	et	3	main
mitte	doc_13389385120_item	2242710	et	3	main
on	doc_13389385120_item	2242716	et	4	main
nõrgal	doc_13389385120_item	2242718	et	3	main
tasemeltestis	doc_13389385120_item	2242719	et	4	main
eesti	doc_13389385120_item	2242723	et	4	main
sain	doc_13389385120_item	2242729	et	3	main
teavadkõige	doc_13389385120_item	2242746	et	4	main
jaanipäeva	doc_13389385120_item	2242750	et	4	main
õpilased	doc_13389385120_item	2242759	et	3	main
peamised	doc_13389385120_item	2242761	et	3	main
et	doc_13389385120_item	2242778	et	3	main
niit	doc_13389385120_item	2242819	et	4	main
lydia	doc_13389385120_item	2242823	et	4	main
tammsaarevilde	doc_13389385120_item	2242825	et	4	main
oli	doc_13389385120_item	2242833	et	3	main
ja	doc_13389385120_item	2242838	et	3	main
tobiasoli	doc_13389385120_item	2242840	et	4	main
kummaline	doc_13389385120_item	2242842	et	3	main
et	doc_13389385120_item	2242844	et	3	main
üks	doc_13389385120_item	2242846	et	3	main
selle	doc_13389385120_item	2242860	et	4	main
siiski	doc_13389385120_item	2242867	et	4	main
leidus	doc_13389385120_item	2242868	et	4	main
midagieelviimaseks	doc_13389385120_item	2242875	et	3	main
32st	doc_13389385120_item	2242922	et	3	main
tulemused	doc_13389385120_item	2242929	et	3	main
eesti	doc_13389385120_item	2242936	et	4	main
kuna	doc_13389385120_item	2242941	et	3	main
veelkord	doc_13389385120_item	2242947	et	3	main
tõestab	doc_13389385120_item	2242948	et	3	main
on	doc_13389385120_item	2242951	et	4	main
aega	doc_13389385120_item	2242954	et	4	main
jäätnud	doc_13389385120_item	2242955	et	4	main
kultuuriõppimiseksviimane	doc_13389385120_item	2242956	et	3	main
kultuuritegelased	doc_13389385120_item	2242960	et	3	main
rahakupüüridel	doc_13389385120_item	2242963	et	3	main
õpilast	doc_13389385120_item	2242969	et	4	main
pool	doc_13389385120_item	2242974	et	4	main
andsid	doc_13389385120_item	2242977	et	4	main
ülevaade	doc_13389385120_item	2242979	et	3	main
4	doc_13389385120_item	2242981	et	2	main
tarkused	doc_13389385120_item	2243028	et	4	main
kõigile	doc_13389385120_item	2243030	et	4	main
tuleb	doc_13389385120_item	2243031	et	3	main
uue	doc_13389385120_item	2243035	et	3	main
koostamiselõpilastega	doc_13389385120_item	2243037	et	4	main
et	doc_13389385120_item	2243040	et	3	main
rohkem	doc_13389385120_item	2243043	et	4	main
teada	doc_13389385120_item	2243044	et	3	main
muuseumidest	doc_13389385120_item	2243046	et	3	main
ei	doc_13389385120_item	2243053	et	4	main
raskelt	doc_13389385120_item	2243064	et	4	main
nende	doc_13389385120_item	2243070	et	4	main
22	doc_13389385120_item	2243081	et	2	main
klassi	doc_13389385120_item	2243083	et	4	main
selles	doc_13389385120_item	2243085	et	4	main
osalesid	doc_13389385120_item	2243092	et	4	main
esimesed	doc_13389385120_item	2243098	et	3	main
ja	doc_13389385120_item	2243112	et	3	main
küsimust	doc_13389385120_item	2243127	et	4	main
küsimuseks	doc_13389385120_item	2243129	et	4	main
riigisümboleid	doc_13389385120_item	2243133	et	3	main
vastasid	doc_13389385120_item	2243141	et	4	main
ja	doc_13389385120_item	2243146	et	3	main
ei	doc_13389385120_item	2243148	et	4	main
on	doc_13389385120_item	2243155	et	4	main
sümbolid	doc_13389385120_item	2243157	et	3	main
õigesti	doc_13389385120_item	2243170	et	3	main
oli	doc_13389385120_item	2243172	et	3	main
presidenti	doc_13389385120_item	2243214	et	4	main
kõik	doc_13389385120_item	2243217	et	4	main
nendele	doc_13389385120_item	2243225	et	4	main
teadmised	doc_13389385120_item	2243240	et	4	main
õpilast	doc_13389385120_item	2243246	et	4	main
õigesti	doc_13389385120_item	2243248	et	3	main
18	doc_13389385120_item	2243250	et	2	main
see	doc_13389385120_item	2243254	et	3	main
nimi	doc_13389385120_item	2243290	et	3	main
võrreldes	doc_13389385120_item	2243300	et	3	main
paranenudoli	doc_13389385120_item	2243303	et	4	main
variante	doc_13389385120_item	2243307	et	3	main
ka	doc_13389385120_item	2243318	et	3	main
laulme	doc_13389385120_item	2243325	et	4	main
ka	doc_13389385120_item	2242722	et	3	main
muisete	doc_13389385120_item	2242724	et	4	main
erinevaid	doc_13389385120_item	2242731	et	4	main
palusin	doc_13389385120_item	2242741	et	3	main
missuguseid	doc_13389385120_item	2242743	et	3	main
vastlapäevajärgnev	doc_13389385120_item	2242753	et	3	main
nii	doc_13389385120_item	2242756	et	3	main
rahvuspidusid	doc_13389385120_item	2242758	et	4	main
olidjõulud	doc_13389385120_item	2242763	et	4	main
pühadest	doc_13389385120_item	2242773	et	3	main
põhjalikud	doc_13389385120_item	2242775	et	3	main
koolis	doc_13389385120_item	2242780	et	4	main
räägitakse	doc_13389385120_item	2242781	et	3	main
palju	doc_13389385120_item	2242782	et	4	main
nende	doc_13389385120_item	2242784	et	4	main
korraldatakse	doc_13389385120_item	2242783	et	3	main
peode	doc_13389385120_item	2242785	et	3	main
tähistamine	doc_13389385120_item	2242786	et	4	main
ja	doc_13389385120_item	2242787	et	3	main
näidatakse	doc_13389385120_item	2242788	et	3	main
traditsioonid	doc_13389385120_item	2242789	et	3	main
järgmises	doc_13389385120_item	2242790	et	3	main
küsimuses	doc_13389385120_item	2242791	et	4	main
oli	doc_13389385120_item	2242792	et	3	main
vaja	doc_13389385120_item	2242793	et	4	main
nimetada	doc_13389385120_item	2242794	et	3	main
eesti	doc_13389385120_item	2242795	et	4	main
kirjanikkevastuseid	doc_13389385120_item	2242796	et	4	main
oli	doc_13389385120_item	2242797	et	3	main
palju	doc_13389385120_item	2242798	et	4	main
ja	doc_13389385120_item	2242799	et	3	main
nimetati	doc_13389385120_item	2242802	et	4	main
kõige	doc_13389385120_item	2242800	et	4	main
rohkem	doc_13389385120_item	2242801	et	4	main
eno	doc_13389385120_item	2242803	et	4	main
rauda	doc_13389385120_item	2242804	et	4	main
see	doc_13389385120_item	2242805	et	3	main
oli	doc_13389385120_item	2242806	et	3	main
kuidagi	doc_13389385120_item	2242807	et	3	main
imelik	doc_13389385120_item	2242808	et	3	main
kuna	doc_13389385120_item	2242809	et	3	main
see	doc_13389385120_item	2242810	et	3	main
kirjanik	doc_13389385120_item	2242811	et	3	main
jaanipäev	doc_13389385120_item	2242765	et	3	main
pühasid	doc_13389385120_item	2242771	et	3	main
lasteleoli	doc_13389385120_item	2242815	et	4	main
inimest	doc_13389385120_item	2242821	et	3	main
koidulat	doc_13389385120_item	2242824	et	4	main
smuul	doc_13389385120_item	2242826	et	4	main
hulka	doc_13389385120_item	2242832	et	4	main
ka	doc_13389385120_item	2242841	et	3	main
see	doc_13389385120_item	2242843	et	3	main
kuigi	doc_13389385120_item	2242850	et	3	main
õpetatakse	doc_13389385120_item	2242853	et	3	main
kirjandeidvõrreldes	doc_13389385120_item	2242857	et	4	main
oli	doc_13389385120_item	2242863	et	3	main
palju	doc_13389385120_item	2242865	et	4	main
õpilast	doc_13389385120_item	2242870	et	4	main
küsimuseks	doc_13389385120_item	2242876	et	4	main
tuntumad	doc_13389385120_item	2242880	et	4	main
näitlejaid	doc_13389385120_item	2242923	et	4	main
ole	doc_13389385120_item	2242925	et	4	main
kui	doc_13389385120_item	2242931	et	3	main
ka	doc_13389385120_item	2242939	et	3	main
see	doc_13389385120_item	2242942	et	3	main
kultuuri	doc_13389385120_item	2242944	et	4	main
lahendamata	doc_13389385120_item	2242945	et	4	main
et	doc_13389385120_item	2242949	et	3	main
väga	doc_13389385120_item	2242952	et	3	main
küsimus	doc_13389385120_item	2242957	et	4	main
on	doc_13389385120_item	2242961	et	4	main
et	doc_13389385120_item	2242967	et	3	main
kirjutanud	doc_13389385120_item	2242973	et	4	main
eesti	doc_13389385120_item	2243025	et	4	main
muistendid	doc_13389385120_item	2243027	et	3	main
rahvuslaulud-sellele	doc_13389385120_item	2243029	et	4	main
tähelepanu	doc_13389385120_item	2243033	et	4	main
pöörata	doc_13389385120_item	2243034	et	4	main
õppekava	doc_13389385120_item	2243036	et	4	main
vesteldes	doc_13389385120_item	2243038	et	3	main
selgus	doc_13389385120_item	2243039	et	4	main
nad	doc_13389385120_item	2243041	et	3	main
tahaksid	doc_13389385120_item	2243042	et	4	main
sajandisee	doc_13389385120_item	2243051	et	4	main
pakkunud	doc_13389385120_item	2243054	et	4	main
olid	doc_13389385120_item	2243057	et	4	main
rahvuslaulud	doc_13389385120_item	2243058	et	3	main
on	doc_13389385120_item	2243062	et	4	main
nad	doc_13389385120_item	2243067	et	3	main
tähelepanu	doc_13389385120_item	2243077	et	4	main
tegeldakse	doc_13389385120_item	2243079	et	3	main
anonüümnetestis	doc_13389385120_item	2243091	et	4	main
kokku	doc_13389385120_item	2243093	et	3	main
28	doc_13389385120_item	2243097	et	2	main
samas	doc_13389385120_item	2243101	et	4	main
nagu	doc_13389385120_item	2243102	et	3	main
7klassi	doc_13389385120_item	2243103	et	4	main
testis	doc_13389385120_item	2243104	et	4	main
niimodi	doc_13389385120_item	2243105	et	4	main
ma	doc_13389385120_item	2243106	et	3	main
sellepärast	doc_13389385120_item	2243108	et	3	main
hoopiski	doc_13389385120_item	2243121	et	3	main
juurde	doc_13389385120_item	2243125	et	4	main
esimeseks	doc_13389385120_item	2243128	et	3	main
14	doc_13389385120_item	2243140	et	2	main
mis	doc_13389385120_item	2243154	et	4	main
riigi	doc_13389385120_item	2243156	et	3	main
võrreldes	doc_13389385120_item	2243158	et	3	main
oli	doc_13389385120_item	2243160	et	3	main
arv	doc_13389385120_item	2243162	et	3	main
küsimus	doc_13389385120_item	2243164	et	4	main
puudutas	doc_13389385120_item	2243165	et	3	main
sõnadeautori	doc_13389385120_item	2243168	et	3	main
võrreldes	doc_13389385120_item	2243175	et	3	main
aga	doc_13389385120_item	2243210	et	3	main
õigesti	doc_13389385120_item	2243216	et	3	main
õpilased	doc_13389385120_item	2243218	et	3	main
rahvuspuudaga	doc_13389385120_item	2243224	et	3	main
vastuseid	doc_13389385120_item	2243227	et	3	main
teadma	doc_13389385120_item	2243229	et	3	main
need	doc_13389385120_item	2243232	et	3	main
küsimus	doc_13389385120_item	2243236	et	4	main
on	doc_13389385120_item	2243241	et	4	main
märgatavalt	doc_13389385120_item	2243242	et	4	main
aasta	doc_13389385120_item	2243249	et	4	main
õigesti	doc_13389385120_item	2243252	et	3	main
õigesti	doc_13389385120_item	2243270	et	3	main
kirjutas	doc_13389385120_item	2242812	et	3	main
mainitud	doc_13389385120_item	2242816	et	4	main
mainisid	doc_13389385120_item	2242822	et	4	main
aga	doc_13389385120_item	2242827	et	3	main
eesti	doc_13389385120_item	2242830	et	4	main
kirjanikke	doc_13389385120_item	2242831	et	3	main
astrid	doc_13389385120_item	2242836	et	3	main
rudolph	doc_13389385120_item	2242839	et	4	main
ainult	doc_13389385120_item	2242845	et	4	main
õpilane	doc_13389385120_item	2242847	et	3	main
olutsu	doc_13389385120_item	2242849	et	4	main
tema	doc_13389385120_item	2242851	et	4	main
teiste	doc_13389385120_item	2242858	et	4	main
üpris	doc_13389385120_item	2242864	et	3	main
oli	doc_13389385120_item	2242877	et	3	main
ja	doc_13389385120_item	2242916	et	3	main
teadis	doc_13389385120_item	2242918	et	4	main
mingil	doc_13389385120_item	2242828	et	4	main
sattunud	doc_13389385120_item	2242834	et	4	main
ka	doc_13389385120_item	2242835	et	3	main
lingren	doc_13389385120_item	2242837	et	4	main
teosed	doc_13389385120_item	2242852	et	3	main
kirjutatakse	doc_13389385120_item	2242855	et	3	main
küsimustega	doc_13389385120_item	2242859	et	4	main
vastajaid	doc_13389385120_item	2242862	et	4	main
aga	doc_13389385120_item	2242866	et	3	main
2	doc_13389385120_item	2242869	et	2	main
kes	doc_13389385120_item	2242871	et	4	main
ei	doc_13389385120_item	2242872	et	4	main
olnud	doc_13389385120_item	2242873	et	4	main
vastanud	doc_13389385120_item	2242874	et	4	main
eesti	doc_13389385120_item	2242879	et	4	main
teatrid	doc_13389385120_item	2242881	et	3	main
lavastusedpaljud	doc_13389385120_item	2242883	et	4	main
nimetasid	doc_13389385120_item	2242885	et	4	main
tallinnas	doc_13389385120_item	2242887	et	4	main
olevaid	doc_13389385120_item	2242888	et	4	main
ainult	doc_13389385120_item	2242886	et	4	main
teatreid	doc_13389385120_item	2242889	et	3	main
ja	doc_13389385120_item	2242890	et	3	main
ainult	doc_13389385120_item	2242891	et	4	main
tuntumaidteater	doc_13389385120_item	2242892	et	4	main
estonia	doc_13389385120_item	2242893	et	4	main
ja	doc_13389385120_item	2242894	et	3	main
teater	doc_13389385120_item	2242896	et	3	main
näiteks	doc_13389385120_item	2242897	et	4	main
vene	doc_13389385120_item	2242895	et	4	main
vanalinnastuudiost	doc_13389385120_item	2242898	et	3	main
ole	doc_13389385120_item	2242900	et	4	main
juttugi	doc_13389385120_item	2242901	et	4	main
ei	doc_13389385120_item	2242899	et	4	main
ainult	doc_13389385120_item	2242902	et	4	main
üks	doc_13389385120_item	2242903	et	3	main
õpilane	doc_13389385120_item	2242904	et	3	main
nimetas	doc_13389385120_item	2242905	et	3	main
vanemuineteatri	doc_13389385120_item	2242906	et	4	main
hulka	doc_13389385120_item	2242907	et	4	main
ka	doc_13389385120_item	2242908	et	3	main
õpilaste	doc_13389385120_item	2242909	et	4	main
arvates	doc_13389385120_item	2242910	et	4	main
kuulusid	doc_13389385120_item	2242911	et	4	main
coca-cola	doc_13389385120_item	2242912	et	4	main
plaza	doc_13389385120_item	2242913	et	4	main
kino	doc_13389385120_item	2242914	et	4	main
kosmos	doc_13389385120_item	2242915	et	3	main
ainult	doc_13389385120_item	2242919	et	4	main
ei	doc_13389385120_item	2242924	et	4	main
mitte	doc_13389385120_item	2242926	et	3	main
näitavad	doc_13389385120_item	2242930	et	4	main
viletsad	doc_13389385120_item	2242932	et	3	main
teadmised	doc_13389385120_item	2242935	et	4	main
teatrielust	doc_13389385120_item	2242937	et	3	main
seega	doc_13389385120_item	2242938	et	4	main
osasee	doc_13389385120_item	2242946	et	4	main
vähe	doc_13389385120_item	2242953	et	3	main
niimillised	doc_13389385120_item	2242959	et	4	main
oli	doc_13389385120_item	2242965	et	3	main
midagi	doc_13389385120_item	2242972	et	4	main
15	doc_13389385120_item	2242976	et	2	main
lydia	doc_13389385120_item	2242984	et	4	main
üks	doc_13389385120_item	2242988	et	3	main
sellega	doc_13389385120_item	2243022	et	3	main
vanasõnad	doc_13389385120_item	2243026	et	3	main
tetritest	doc_13389385120_item	2243045	et	4	main
kirjanikest	doc_13389385120_item	2243047	et	3	main
just	doc_13389385120_item	2243049	et	3	main
kuna	doc_13389385120_item	2243059	et	3	main
mainisid	doc_13389385120_item	2243068	et	4	main
et	doc_13389385120_item	2243069	et	3	main
õpetamisele	doc_13389385120_item	2243073	et	4	main
rohkem	doc_13389385120_item	2243078	et	4	main
keelestruktuuridega	doc_13389385120_item	2243080	et	3	main
klassis	doc_13389385120_item	2243086	et	3	main
test	doc_13389385120_item	2243088	et	3	main
samuti	doc_13389385120_item	2243090	et	3	main
30	doc_13389385120_item	2243094	et	2	main
oli	doc_13389385120_item	2243096	et	3	main
kontrollida	doc_13389385120_item	2243111	et	4	main
ma	doc_13389385120_item	2243123	et	3	main
10	doc_13389385120_item	2243126	et	2	main
eesti	doc_13389385120_item	2243132	et	4	main
palju	doc_13389385120_item	2243134	et	4	main
nimetasid	doc_13389385120_item	2243136	et	4	main
eesti	doc_13389385120_item	2243137	et	4	main
rahvuslindulilli-kivekokku	doc_13389385120_item	2243138	et	4	main
vapulippu	doc_13389385120_item	2243145	et	4	main
on	doc_13389385120_item	2243151	et	4	main
7klassiga	doc_13389385120_item	2243159	et	3	main
vastajate	doc_13389385120_item	2243161	et	4	main
eesti	doc_13389385120_item	2243166	et	4	main
2	doc_13389385120_item	2243173	et	2	main
küsimuse	doc_13389385120_item	2243178	et	4	main
pakkusid	doc_13389385120_item	2243211	et	4	main
õpilane	doc_13389385120_item	2242921	et	3	main
keegi	doc_13389385120_item	2242927	et	4	main
laste	doc_13389385120_item	2242934	et	4	main
on	doc_13389385120_item	2242943	et	4	main
kõlas	doc_13389385120_item	2242958	et	4	main
selline	doc_13389385120_item	2242966	et	4	main
ja	doc_13389385120_item	2242980	et	3	main
mainisid	doc_13389385120_item	2242982	et	4	main
oli	doc_13389385120_item	2242986	et	3	main
originaalne	doc_13389385120_item	2242989	et	3	main
vastuskalevipoegsellist	doc_13389385120_item	2242990	et	4	main
küsimust	doc_13389385120_item	2242991	et	4	main
küsides	doc_13389385120_item	2242992	et	3	main
ma	doc_13389385120_item	2242993	et	3	main
olin	doc_13389385120_item	2242994	et	3	main
kindel	doc_13389385120_item	2242995	et	3	main
et	doc_13389385120_item	2242996	et	3	main
saan	doc_13389385120_item	2242997	et	4	main
konkreetsed	doc_13389385120_item	2242998	et	3	main
vastused	doc_13389385120_item	2242999	et	3	main
teksti	doc_13389385120_item	2243000	et	4	main
analüüsides	doc_13389385120_item	2243001	et	4	main
ma	doc_13389385120_item	2243002	et	3	main
sain	doc_13389385120_item	2243003	et	3	main
teada	doc_13389385120_item	2243004	et	3	main
et	doc_13389385120_item	2243005	et	3	main
et	doc_13389385120_item	2243006	et	3	main
õpilaste	doc_13389385120_item	2243007	et	4	main
teadmised	doc_13389385120_item	2243008	et	4	main
kultuurist	doc_13389385120_item	2243009	et	3	main
on	doc_13389385120_item	2243010	et	4	main
madalal	doc_13389385120_item	2243011	et	4	main
tasemelnõrgad	doc_13389385120_item	2243012	et	4	main
kohad	doc_13389385120_item	2243013	et	4	main
õppekavas	doc_13389385120_item	2243014	et	3	main
onteater	doc_13389385120_item	2243015	et	4	main
lavastused	doc_13389385120_item	2243016	et	4	main
näitlejad	doc_13389385120_item	2243017	et	4	main
kirjanduseesti	doc_13389385120_item	2243018	et	4	main
kirjanikud	doc_13389385120_item	2243019	et	3	main
laulupidu	doc_13389385120_item	2243020	et	4	main
ja	doc_13389385120_item	2243021	et	3	main
on	doc_13389385120_item	2242933	et	4	main
kultuurist	doc_13389385120_item	2242940	et	3	main
õppekavas	doc_13389385120_item	2242950	et	3	main
eesti	doc_13389385120_item	2242962	et	4	main
tulemus	doc_13389385120_item	2242964	et	3	main
15	doc_13389385120_item	2242968	et	2	main
ei	doc_13389385120_item	2242970	et	4	main
ole	doc_13389385120_item	2242971	et	4	main
küsitletust	doc_13389385120_item	2242975	et	4	main
täieliku	doc_13389385120_item	2242978	et	3	main
ainult	doc_13389385120_item	2242983	et	4	main
koidulat	doc_13389385120_item	2242985	et	4	main
ka	doc_13389385120_item	2242987	et	3	main
seonduvad	doc_13389385120_item	2243023	et	4	main
rohkem	doc_13389385120_item	2243032	et	4	main
20	doc_13389385120_item	2243050	et	2	main
neile	doc_13389385120_item	2243056	et	4	main
keel	doc_13389385120_item	2243061	et	4	main
samas	doc_13389385120_item	2243066	et	4	main
rahvapärimuse	doc_13389385120_item	2243072	et	3	main
on	doc_13389385120_item	2243074	et	4	main
korraldatav	doc_13389385120_item	2243087	et	4	main
oli	doc_13389385120_item	2243089	et	3	main
olid	doc_13389385120_item	2243100	et	4	main
et	doc_13389385120_item	2243109	et	3	main
võrrelda	doc_13389385120_item	2243113	et	4	main
traditsioonid	doc_13389385120_item	2243024	et	3	main
kirjandusest	doc_13389385120_item	2243048	et	4	main
mis	doc_13389385120_item	2243052	et	4	main
huvi	doc_13389385120_item	2243055	et	4	main
sealolev	doc_13389385120_item	2243060	et	3	main
väga	doc_13389385120_item	2243063	et	3	main
arusaadav	doc_13389385120_item	2243065	et	4	main
arvates	doc_13389385120_item	2243071	et	4	main
pööratud	doc_13389385120_item	2243075	et	4	main
vähe	doc_13389385120_item	2243076	et	3	main
11	doc_13389385120_item	2243082	et	2	main
testianalüüs	doc_13389385120_item	2243084	et	3	main
õpilastküsimusi	doc_13389385120_item	2243095	et	4	main
18	doc_13389385120_item	2243099	et	2	main
tegin	doc_13389385120_item	2243107	et	3	main
tahtsin	doc_13389385120_item	2243110	et	3	main
teadmisi	doc_13389385120_item	2243114	et	4	main
kuivõrd	doc_13389385120_item	2243115	et	3	main
nad	doc_13389385120_item	2243116	et	3	main
on	doc_13389385120_item	2243117	et	4	main
paranenud	doc_13389385120_item	2243118	et	4	main
arenenud	doc_13389385120_item	2243119	et	4	main
või	doc_13389385120_item	2243120	et	4	main
oli	doc_13389385120_item	2243130	et	3	main
õpilased	doc_13389385120_item	2243135	et	3	main
16ainult	doc_13389385120_item	2243139	et	4	main
õigestiseega	doc_13389385120_item	2243142	et	4	main
eesti	doc_13389385120_item	2243144	et	4	main
selgemis	doc_13389385120_item	2243150	et	4	main
ja	doc_13389385120_item	2243153	et	3	main
hümni	doc_13389385120_item	2243167	et	4	main
ja	doc_13389385120_item	2243169	et	3	main
7klassiga	doc_13389385120_item	2243176	et	3	main
rahuslilleks	doc_13389385120_item	2243212	et	4	main
sinililleeesti	doc_13389385120_item	2243213	et	4	main
nimetasid	doc_13389385120_item	2243215	et	4	main
õigesti	doc_13389385120_item	2243222	et	3	main
kõik	doc_13389385120_item	2243230	et	4	main
oli	doc_13389385120_item	2243237	et	3	main
võrreldes	doc_13389385120_item	2243239	et	3	main
25	doc_13389385120_item	2243244	et	2	main
kirjutasid	doc_13389385120_item	2243251	et	4	main
et	doc_13389385120_item	2243253	et	3	main
arv	doc_13389385120_item	2243272	et	3	main
vastasid	doc_13389385120_item	2243285	et	4	main
rahvuseepose	doc_13389385120_item	2243289	et	3	main
õigeid	doc_13389385120_item	2243306	et	3	main
ja	doc_13389385120_item	2243308	et	3	main
kirjutanud	doc_13389385120_item	2243316	et	4	main
oli	doc_13389385120_item	2243317	et	3	main
nteesti	doc_13389385120_item	2243321	et	4	main
vastupiditestisse	doc_13389385120_item	2243122	et	3	main
lisasin	doc_13389385120_item	2243124	et	3	main
nimetada	doc_13389385120_item	2243131	et	3	main
kirjutasid	doc_13389385120_item	2243143	et	4	main
hümniõpilastel	doc_13389385120_item	2243147	et	4	main
ole	doc_13389385120_item	2243149	et	4	main
rahvasümbolid	doc_13389385120_item	2243152	et	3	main
suurenenudteine	doc_13389385120_item	2243163	et	4	main
vastajaid	doc_13389385120_item	2243171	et	4	main
seega	doc_13389385120_item	2243174	et	4	main
selle	doc_13389385120_item	2243177	et	4	main
oskajate	doc_13389385120_item	2243179	et	4	main
arv	doc_13389385120_item	2243180	et	3	main
suurendas	doc_13389385120_item	2243181	et	3	main
ainult	doc_13389385120_item	2243182	et	4	main
ühe	doc_13389385120_item	2243183	et	4	main
inimese	doc_13389385120_item	2243184	et	4	main
võrra	doc_13389385120_item	2243185	et	3	main
23	doc_13389385120_item	2243186	et	2	main
õpilast	doc_13389385120_item	2243187	et	4	main
olid	doc_13389385120_item	2243188	et	4	main
aga	doc_13389385120_item	2243189	et	3	main
kindladet	doc_13389385120_item	2243190	et	4	main
sõnadeautor	doc_13389385120_item	2243191	et	3	main
on	doc_13389385120_item	2243192	et	4	main
johann	doc_13389385120_item	2243193	et	4	main
voldemar	doc_13389385120_item	2243194	et	4	main
küsimused	doc_13389385120_item	2243196	et	4	main
jannsenjärgmised	doc_13389385120_item	2243195	et	4	main
olid	doc_13389385120_item	2243197	et	4	main
rahvuslinnust	doc_13389385120_item	2243199	et	4	main
eesti	doc_13389385120_item	2243198	et	4	main
ja	doc_13389385120_item	2243200	et	3	main
rahvuslillest	doc_13389385120_item	2243201	et	4	main
sellele	doc_13389385120_item	2243202	et	4	main
küsimusele	doc_13389385120_item	2243203	et	4	main
vastasid	doc_13389385120_item	2243204	et	4	main
õigesti	doc_13389385120_item	2243205	et	3	main
peaaegu	doc_13389385120_item	2243206	et	3	main
kõik	doc_13389385120_item	2243207	et	4	main
õpilased	doc_13389385120_item	2243208	et	3	main
2	doc_13389385120_item	2243209	et	2	main
samas	doc_13389385120_item	2243219	et	4	main
kõik	doc_13389385120_item	2243220	et	4	main
nimetasid	doc_13389385120_item	2243221	et	4	main
eesti	doc_13389385120_item	2243223	et	4	main
kuna	doc_13389385120_item	2243231	et	3	main
on	doc_13389385120_item	2243233	et	4	main
laulupeost7klassiga	doc_13389385120_item	2243238	et	4	main
paranenud	doc_13389385120_item	2243243	et	4	main
toimub	doc_13389385120_item	2243255	et	3	main
on	doc_13389385120_item	2243278	et	4	main
iseseisvuspäevast	doc_13389385120_item	2243284	et	4	main
kõik	doc_13389385120_item	2243286	et	4	main
kirjutasid	doc_13389385120_item	2243291	et	4	main
raskusi	doc_13389385120_item	2243297	et	4	main
on	doc_13389385120_item	2243302	et	4	main
nimetatud	doc_13389385120_item	2243304	et	4	main
palju	doc_13389385120_item	2243305	et	4	main
vastasid	doc_13389385120_item	2243310	et	4	main
õpilast14	doc_13389385120_item	2243312	et	4	main
ei	doc_13389385120_item	2243313	et	4	main
midagi	doc_13389385120_item	2243315	et	4	main
vastuseid	doc_13389385120_item	2243320	et	3	main
rahvuslaulude	doc_13389385120_item	2243337	et	3	main
ja	doc_13389385120_item	2243338	et	3	main
mitte	doc_13389385120_item	2243343	et	3	main
keegi	doc_13389385120_item	2243344	et	4	main
nimesidvalesti	doc_13389385120_item	2243357	et	4	main
oli	doc_13389385120_item	2243359	et	3	main
inimest	doc_13389385120_item	2243364	et	3	main
varianteaga	doc_13389385120_item	2243372	et	4	main
vanasõnu	doc_13389385120_item	2243381	et	3	main
ülesannega	doc_13389385120_item	2243383	et	4	main
ning	doc_13389385120_item	2243387	et	3	main
midagi	doc_13389385120_item	2243391	et	4	main
palju	doc_13389385120_item	2243397	et	4	main
kes	doc_13389385120_item	2243403	et	4	main
õpilast	doc_13389385120_item	2243424	et	4	main
ühe	doc_13389385120_item	2243430	et	4	main
vastanud	doc_13389385120_item	2243436	et	4	main
küsimusele	doc_13389385120_item	2243439	et	4	main
klassiljärgmise	doc_13389385120_item	2243448	et	4	main
küsimuse	doc_13389385120_item	2243449	et	4	main
tundmisest	doc_13389385120_item	2243452	et	4	main
erinevaid	doc_13389385120_item	2243457	et	4	main
kõige	doc_13389385120_item	2243459	et	4	main
jõuludemadepäevmind	doc_13389385120_item	2243463	et	4	main
eesti	doc_13389385120_item	2243488	et	4	main
ole	doc_13389385120_item	2243493	et	4	main
28	doc_13389385120_item	2243497	et	2	main
oli	doc_13389385120_item	2243501	et	3	main
mõnus	doc_13389385120_item	2243503	et	4	main
nimetati	doc_13389385120_item	2243505	et	4	main
me	doc_13389385120_item	2243520	et	4	main
eesti	doc_13389385120_item	2243533	et	4	main
näitlejäid	doc_13389385120_item	2243544	et	4	main
ainult	doc_13389385120_item	2243546	et	4	main
lavastusi	doc_13389385120_item	2243550	et	4	main
teatriteadmised	doc_13389385120_item	2243555	et	3	main
eesti	doc_13389385120_item	2243566	et	4	main
konkreetsed	doc_13389385120_item	2243571	et	3	main
aga	doc_13389385120_item	2243573	et	3	main
kreutzwaldi	doc_13389385120_item	2243580	et	4	main
kohta	doc_13389385120_item	2243581	et	4	main
õiged	doc_13389385120_item	2243584	et	3	main
eluaastaidlydia	doc_13389385120_item	2243591	et	4	main
olid	doc_13389385120_item	2243593	et	4	main
27	doc_13389385120_item	2243597	et	2	main
aabitsast	doc_13389385120_item	2243622	et	4	main
koostajast	doc_13389385120_item	2243625	et	4	main
tahtsin	doc_13389385120_item	2243632	et	3	main
kirjanikke	doc_13389385120_item	2243638	et	3	main
pakkusid	doc_13389385120_item	2243643	et	4	main
ei	doc_13389385120_item	2243648	et	4	main
ole	doc_13389385120_item	2243649	et	4	main
kirjutada	doc_13389385120_item	2243660	et	3	main
aga	doc_13389385120_item	2243667	et	3	main
ühtki	doc_13389385120_item	2243669	et	4	main
ei	doc_13389385120_item	2243671	et	4	main
ma	doc_13389385120_item	2243674	et	3	main
23	doc_13389385120_item	2243680	et	2	main
oli	doc_13389385120_item	2243691	et	3	main
ketist	doc_13389385120_item	2243693	et	3	main
kirjutada	doc_13389385120_item	2243697	et	3	main
teadmisi	doc_13389385120_item	2243699	et	4	main
küsimustele	doc_13389385120_item	2243226	et	4	main
peavad	doc_13389385120_item	2243228	et	4	main
baasteadmised	doc_13389385120_item	2243234	et	3	main
kultuuristseitsmes	doc_13389385120_item	2243235	et	4	main
30st	doc_13389385120_item	2243245	et	3	main
kirjutasid	doc_13389385120_item	2243247	et	4	main
iga	doc_13389385120_item	2243256	et	4	main
5	doc_13389385120_item	2243257	et	2	main
aastat	doc_13389385120_item	2243258	et	3	main
ja	doc_13389385120_item	2243259	et	3	main
kõik	doc_13389385120_item	2243260	et	4	main
et	doc_13389385120_item	2243262	et	3	main
vastasid	doc_13389385120_item	2243261	et	4	main
esimene	doc_13389385120_item	2243263	et	3	main
laulupidu	doc_13389385120_item	2243264	et	4	main
toimus	doc_13389385120_item	2243265	et	3	main
tartus	doc_13389385120_item	2243266	et	3	main
ma	doc_13389385120_item	2243267	et	3	main
arvan	doc_13389385120_item	2243268	et	3	main
et	doc_13389385120_item	2243269	et	3	main
vastanute	doc_13389385120_item	2243271	et	4	main
suurenes	doc_13389385120_item	2243273	et	4	main
sellepärast	doc_13389385120_item	2243275	et	3	main
11klassis	doc_13389385120_item	2243277	et	3	main
35-tunniline	doc_13389385120_item	2243279	et	4	main
kultuuristjärgmisele	doc_13389385120_item	2243282	et	4	main
õpilased	doc_13389385120_item	2243287	et	3	main
kõik	doc_13389385120_item	2243293	et	4	main
õigestirahvuslauludega	doc_13389385120_item	2243294	et	4	main
ka	doc_13389385120_item	2243296	et	3	main
aga	doc_13389385120_item	2243298	et	3	main
olukord	doc_13389385120_item	2243299	et	3	main
7klassiga	doc_13389385120_item	2243301	et	3	main
16	doc_13389385120_item	2243311	et	2	main
naljakaid	doc_13389385120_item	2243319	et	4	main
osutus	doc_13389385120_item	2243323	et	4	main
tahaks	doc_13389385120_item	2243330	et	3	main
nimelt	doc_13389385120_item	2243342	et	4	main
kirjutanud	doc_13389385120_item	2243347	et	4	main
eesti	doc_13389385120_item	2243348	et	4	main
rohkem	doc_13389385120_item	2243360	et	4	main
pool	doc_13389385120_item	2243362	et	4	main
vastasid	doc_13389385120_item	2243367	et	4	main
vanaisajärgmise	doc_13389385120_item	2243375	et	3	main
ülesanne	doc_13389385120_item	2243377	et	4	main
said	doc_13389385120_item	2243384	et	4	main
kirjutanud	doc_13389385120_item	2243392	et	4	main
õppinudkõike	doc_13389385120_item	2243399	et	4	main
levinum	doc_13389385120_item	2243400	et	4	main
oli	doc_13389385120_item	2243402	et	3	main
meeskolmeteiskümnendas	doc_13389385120_item	2243405	et	4	main
mõistatusele	doc_13389385120_item	2243410	et	4	main
3	doc_13389385120_item	2243415	et	2	main
õpilastkes	doc_13389385120_item	2243418	et	4	main
vastanud	doc_13389385120_item	2243420	et	4	main
ka	doc_13389385120_item	2243274	et	3	main
et	doc_13389385120_item	2243276	et	3	main
kursus	doc_13389385120_item	2243280	et	3	main
eesti	doc_13389385120_item	2243281	et	4	main
küsimusele	doc_13389385120_item	2243283	et	4	main
õigesti	doc_13389385120_item	2243288	et	3	main
ka	doc_13389385120_item	2243292	et	3	main
esinesid	doc_13389385120_item	2243295	et	4	main
õigesti	doc_13389385120_item	2243309	et	3	main
olnud	doc_13389385120_item	2243314	et	4	main
pappi	doc_13389385120_item	2243326	et	4	main
selge	doc_13389385120_item	2243335	et	4	main
piir	doc_13389385120_item	2243336	et	3	main
eesti	doc_13389385120_item	2243339	et	4	main
vastanuid	doc_13389385120_item	2243358	et	4	main
14	doc_13389385120_item	2243368	et	2	main
õpilastnad	doc_13389385120_item	2243369	et	4	main
mitu	doc_13389385120_item	2243371	et	4	main
enamus	doc_13389385120_item	2243373	et	4	main
nimetada	doc_13389385120_item	2243379	et	3	main
hakkama18	doc_13389385120_item	2243385	et	3	main
õpilast60	doc_13389385120_item	2243386	et	4	main
ei	doc_13389385120_item	2243389	et	4	main
ole	doc_13389385120_item	2243390	et	4	main
õpilased	doc_13389385120_item	2243396	et	3	main
juurde	doc_13389385120_item	2243398	et	4	main
vastus	doc_13389385120_item	2243401	et	3	main
eessee	doc_13389385120_item	2243404	et	4	main
antud	doc_13389385120_item	2243409	et	4	main
kirjutada	doc_13389385120_item	2243411	et	3	main
2	doc_13389385120_item	2243417	et	2	main
vastuse	doc_13389385120_item	2243431	et	3	main
ja	doc_13389385120_item	2243432	et	3	main
palju	doc_13389385120_item	2243444	et	4	main
päeva	doc_13389385120_item	2243451	et	4	main
ülejäänud	doc_13389385120_item	2243496	et	4	main
et	doc_13389385120_item	2243504	et	3	main
nii	doc_13389385120_item	2243506	et	3	main
kui	doc_13389385120_item	2243509	et	3	main
kirjanikkekuna	doc_13389385120_item	2243512	et	4	main
selline	doc_13389385120_item	2243513	et	4	main
näha	doc_13389385120_item	2243522	et	3	main
et	doc_13389385120_item	2243523	et	3	main
on	doc_13389385120_item	2243525	et	4	main
oli	doc_13389385120_item	2243529	et	3	main
tuntumad	doc_13389385120_item	2243532	et	4	main
peamiselt	doc_13389385120_item	2243541	et	4	main
mainisid	doc_13389385120_item	2243545	et	4	main
6	doc_13389385120_item	2243547	et	2	main
ei	doc_13389385120_item	2243556	et	4	main
kultuuritegelasi	doc_13389385120_item	2243563	et	3	main
on	doc_13389385120_item	2243565	et	4	main
küsimuses	doc_13389385120_item	2243579	et	4	main
nimetasid	doc_13389385120_item	2243589	et	4	main
tema	doc_13389385120_item	2243590	et	4	main
rahvuslauluks	doc_13389385120_item	2243322	et	4	main
räpp	doc_13389385120_item	2243324	et	3	main
samas	doc_13389385120_item	2243329	et	4	main
õpilastel	doc_13389385120_item	2243333	et	4	main
hümnijärgmises	doc_13389385120_item	2243349	et	3	main
küsimuses	doc_13389385120_item	2243350	et	4	main
oli	doc_13389385120_item	2243351	et	3	main
vaja	doc_13389385120_item	2243352	et	4	main
nimetada	doc_13389385120_item	2243353	et	3	main
eesti	doc_13389385120_item	2243354	et	4	main
muistsete	doc_13389385120_item	2243355	et	3	main
jumalate	doc_13389385120_item	2243356	et	3	main
ei	doc_13389385120_item	2243327	et	4	main
saa	doc_13389385120_item	2243328	et	4	main
mainida	doc_13389385120_item	2243331	et	3	main
et	doc_13389385120_item	2243332	et	3	main
on	doc_13389385120_item	2243334	et	4	main
hümni	doc_13389385120_item	2243340	et	4	main
vahel	doc_13389385120_item	2243341	et	4	main
ei	doc_13389385120_item	2243345	et	4	main
ole	doc_13389385120_item	2243346	et	4	main
kui	doc_13389385120_item	2243361	et	3	main
klassst16	doc_13389385120_item	2243363	et	4	main
ning	doc_13389385120_item	2243365	et	3	main
vastas	doc_13389385120_item	2243374	et	4	main
eesti	doc_13389385120_item	2243380	et	4	main
7klassiga	doc_13389385120_item	2243394	et	3	main
küsimuses	doc_13389385120_item	2243406	et	4	main
vaja	doc_13389385120_item	2243408	et	4	main
õigeid	doc_13389385120_item	2243412	et	3	main
kokku	doc_13389385120_item	2243414	et	3	main
küsimustele	doc_13389385120_item	2243422	et	4	main
kahele	doc_13389385120_item	2243426	et	4	main
ole	doc_13389385120_item	2243435	et	4	main
mitte	doc_13389385120_item	2243437	et	3	main
ühtele	doc_13389385120_item	2243438	et	3	main
on	doc_13389385120_item	2243443	et	4	main
nimetatud	doc_13389385120_item	2243454	et	4	main
ka	doc_13389385120_item	2243465	et	3	main
kirjanikkeainult	doc_13389385120_item	2243489	et	4	main
õpilast	doc_13389385120_item	2243491	et	4	main
ei	doc_13389385120_item	2243492	et	4	main
ka	doc_13389385120_item	2243502	et	3	main
teema	doc_13389385120_item	2243514	et	4	main
klassi	doc_13389385120_item	2243517	et	4	main
võime	doc_13389385120_item	2243521	et	4	main
väga	doc_13389385120_item	2243526	et	3	main
nimetada	doc_13389385120_item	2243531	et	3	main
näitlejaid	doc_13389385120_item	2243535	et	4	main
mainitud	doc_13389385120_item	2243537	et	4	main
asuvaid	doc_13389385120_item	2243543	et	4	main
inimest	doc_13389385120_item	2243553	et	3	main
ole	doc_13389385120_item	2243557	et	4	main
paranenudveel	doc_13389385120_item	2243559	et	4	main
kes	doc_13389385120_item	2243564	et	4	main
olid	doc_13389385120_item	2243568	et	4	main
pole	doc_13389385120_item	2243576	et	3	main
kõik	doc_13389385120_item	2243583	et	4	main
vastused	doc_13389385120_item	2243585	et	3	main
aga	doc_13389385120_item	2243587	et	3	main
vastajaid	doc_13389385120_item	2243595	et	4	main
keegi	doc_13389385120_item	2243627	et	4	main
eesti	doc_13389385120_item	2243637	et	4	main
variante	doc_13389385120_item	2243645	et	3	main
aga	doc_13389385120_item	2243647	et	3	main
oma	doc_13389385120_item	2243661	et	4	main
õpilast76	doc_13389385120_item	2243681	et	4	main
vastanudviimane	doc_13389385120_item	2243689	et	4	main
ma	doc_13389385120_item	2243695	et	3	main
kirjutasid	doc_13389385120_item	2243709	et	4	main
kuupäeva	doc_13389385120_item	2243711	et	4	main
ja	doc_13389385120_item	2243712	et	3	main
4	doc_13389385120_item	2243714	et	2	main
11klassi	doc_13389385120_item	2243721	et	4	main
jaoks	doc_13389385120_item	2243722	et	4	main
kõik	doc_13389385120_item	2243728	et	4	main
on	doc_13389385120_item	2243738	et	4	main
eesti	doc_13389385120_item	2243748	et	4	main
iseseisvuselebalti	doc_13389385120_item	2243749	et	4	main
ning	doc_13389385120_item	2243751	et	3	main
eesti	doc_13389385120_item	2243753	et	4	main
kohad	doc_13389385120_item	2243755	et	4	main
järeldusele	doc_13389385120_item	2243776	et	4	main
arvates	doc_13389385120_item	2243788	et	4	main
tunde	doc_13389385120_item	2243792	et	4	main
et	doc_13389385120_item	2243794	et	3	main
põhjalikult	doc_13389385120_item	2243796	et	4	main
audio	doc_13389385120_item	2243801	et	4	main
mis	doc_13389385120_item	2243808	et	4	main
pakub	doc_13389385120_item	2243809	et	3	main
õpetajad	doc_13389385120_item	2243822	et	4	main
korraldama	doc_13389385120_item	2243841	et	3	main
kultuurist	doc_13389385120_item	2243856	et	3	main
tulemusi	doc_13389385120_item	2243871	et	4	main
see	doc_13389385120_item	2243877	et	3	main
kui	doc_13389385120_item	2243881	et	3	main
peetaksekoolid	doc_13389385120_item	2243883	et	4	main
õigesti	doc_13389385120_item	2243366	et	3	main
pakusid	doc_13389385120_item	2243370	et	4	main
küsimuse	doc_13389385120_item	2243376	et	4	main
oli	doc_13389385120_item	2243378	et	3	main
selle	doc_13389385120_item	2243382	et	4	main
12	doc_13389385120_item	2243388	et	2	main
võrreldes	doc_13389385120_item	2243393	et	3	main
on	doc_13389385120_item	2243395	et	4	main
oli	doc_13389385120_item	2243407	et	3	main
vastuseidoli	doc_13389385120_item	2243413	et	4	main
mõistatustoli	doc_13389385120_item	2243416	et	4	main
on	doc_13389385120_item	2243419	et	4	main
kõigidele	doc_13389385120_item	2243421	et	4	main
vastasid	doc_13389385120_item	2243425	et	4	main
7	doc_13389385120_item	2243428	et	2	main
ei	doc_13389385120_item	2243434	et	4	main
seega	doc_13389385120_item	2243440	et	4	main
11klassi	doc_13389385120_item	2243441	et	4	main
kõrgem	doc_13389385120_item	2243445	et	4	main
rahvakalendri	doc_13389385120_item	2243450	et	3	main
hästi	doc_13389385120_item	2243455	et	3	main
päevi	doc_13389385120_item	2243458	et	4	main
populaarsemad	doc_13389385120_item	2243460	et	4	main
olid	doc_13389385120_item	2243461	et	4	main
selline	doc_13389385120_item	2243466	et	4	main
2	doc_13389385120_item	2243490	et	2	main
midagi	doc_13389385120_item	2243494	et	4	main
vastanus	doc_13389385120_item	2243495	et	4	main
vastusevariante	doc_13389385120_item	2243500	et	4	main
ka	doc_13389385120_item	2243510	et	3	main
11	doc_13389385120_item	2243516	et	2	main
spetsiaalses	doc_13389385120_item	2243518	et	3	main
küsimuses	doc_13389385120_item	2243528	et	4	main
vaja	doc_13389385120_item	2243530	et	4	main
lavastusioli	doc_13389385120_item	2243536	et	4	main
teatreid	doc_13389385120_item	2243539	et	3	main
tallinnas	doc_13389385120_item	2243542	et	4	main
6	doc_13389385120_item	2243552	et	2	main
vaja	doc_13389385120_item	2243561	et	4	main
rahakupüüridel	doc_13389385120_item	2243567	et	3	main
palju	doc_13389385120_item	2243570	et	4	main
õpilast	doc_13389385120_item	2243575	et	4	main
midagi	doc_13389385120_item	2243577	et	4	main
kirjutanudjärgnevas	doc_13389385120_item	2243578	et	4	main
mõned	doc_13389385120_item	2243586	et	3	main
isegi	doc_13389385120_item	2243588	et	4	main
õigesti	doc_13389385120_item	2243594	et	3	main
vähem	doc_13389385120_item	2243596	et	4	main
selle	doc_13389385120_item	2243624	et	4	main
ei	doc_13389385120_item	2243628	et	4	main
nimetanudsamas	doc_13389385120_item	2243630	et	4	main
milliseid	doc_13389385120_item	2243635	et	3	main
nimetada	doc_13389385120_item	2243641	et	3	main
nimelt	doc_13389385120_item	2243657	et	4	main
oli	doc_13389385120_item	2243665	et	3	main
ole	doc_13389385120_item	2243672	et	4	main
olnudveel	doc_13389385120_item	2243673	et	4	main
õpilaste	doc_13389385120_item	2243676	et	4	main
eesti	doc_13389385120_item	2243678	et	4	main
nimetasid	doc_13389385120_item	2243682	et	4	main
ülejäänud	doc_13389385120_item	2243685	et	4	main
palusin	doc_13389385120_item	2243696	et	3	main
oma	doc_13389385120_item	2243698	et	4	main
olid	doc_13389385120_item	2243703	et	4	main
ei	doc_13389385120_item	2243705	et	4	main
ainult	doc_13389385120_item	2243713	et	4	main
kirjutasid	doc_13389385120_item	2243715	et	4	main
üldiselt	doc_13389385120_item	2243717	et	4	main
teadmised	doc_13389385120_item	2243719	et	4	main
8	doc_13389385120_item	2243423	et	2	main
mõistatusele	doc_13389385120_item	2243427	et	4	main
kirjutasid	doc_13389385120_item	2243429	et	4	main
13	doc_13389385120_item	2243433	et	2	main
teadmisteskaal	doc_13389385120_item	2243442	et	4	main
kui	doc_13389385120_item	2243446	et	3	main
seitsmendal	doc_13389385120_item	2243447	et	3	main
oli	doc_13389385120_item	2243453	et	3	main
palju	doc_13389385120_item	2243456	et	4	main
jaanipäev	doc_13389385120_item	2243462	et	3	main
huvitas	doc_13389385120_item	2243464	et	3	main
asi	doc_13389385120_item	2243467	et	4	main
et	doc_13389385120_item	2243468	et	3	main
milliseid	doc_13389385120_item	2243469	et	3	main
päevi	doc_13389385120_item	2243470	et	4	main
õpilased	doc_13389385120_item	2243471	et	3	main
tähistavad	doc_13389385120_item	2243472	et	4	main
vastused	doc_13389385120_item	2243473	et	3	main
olid	doc_13389385120_item	2243474	et	4	main
sellisedesimene	doc_13389385120_item	2243475	et	4	main
jaanipäevsiis	doc_13389385120_item	2243477	et	4	main
jõulud	doc_13389385120_item	2243478	et	3	main
on	doc_13389385120_item	2243476	et	4	main
ning	doc_13389385120_item	2243479	et	3	main
kolmandal	doc_13389385120_item	2243480	et	3	main
kohal	doc_13389385120_item	2243481	et	4	main
mardi-ja	doc_13389385120_item	2243482	et	3	main
kadripäevviieteistkümnendal	doc_13389385120_item	2243483	et	4	main
küsimusel	doc_13389385120_item	2243484	et	4	main
oli	doc_13389385120_item	2243485	et	3	main
vaja	doc_13389385120_item	2243486	et	4	main
nimetada	doc_13389385120_item	2243487	et	3	main
pakkusid	doc_13389385120_item	2243498	et	4	main
erinevaid	doc_13389385120_item	2243499	et	4	main
19sajandi	doc_13389385120_item	2243507	et	3	main
kirjanikke	doc_13389385120_item	2243508	et	3	main
kaasaegseid	doc_13389385120_item	2243511	et	3	main
on	doc_13389385120_item	2243515	et	4	main
kultuuriprogrammis	doc_13389385120_item	2243519	et	3	main
tulemused	doc_13389385120_item	2243524	et	3	main
headjärgmises	doc_13389385120_item	2243527	et	3	main
teatreid	doc_13389385120_item	2243534	et	3	main
palju	doc_13389385120_item	2243538	et	4	main
aga	doc_13389385120_item	2243540	et	3	main
inimest	doc_13389385120_item	2243548	et	3	main
ning	doc_13389385120_item	2243549	et	3	main
kirjutasid	doc_13389385120_item	2243551	et	4	main
seega	doc_13389385120_item	2243554	et	4	main
eriti	doc_13389385120_item	2243558	et	3	main
oli	doc_13389385120_item	2243560	et	3	main
nimetada	doc_13389385120_item	2243562	et	3	main
päris	doc_13389385120_item	2243569	et	4	main
vastuseid	doc_13389385120_item	2243572	et	3	main
7	doc_13389385120_item	2243574	et	2	main
olid	doc_13389385120_item	2243582	et	4	main
koidulast	doc_13389385120_item	2243592	et	4	main
30	doc_13389385120_item	2243598	et	2	main
strahvatansu	doc_13389385120_item	2243599	et	4	main
teadsid	doc_13389385120_item	2243600	et	4	main
18	doc_13389385120_item	2243601	et	2	main
õpilast	doc_13389385120_item	2243602	et	4	main
60	doc_13389385120_item	2243603	et	2	main
esimest	doc_13389385120_item	2243604	et	4	main
eesti	doc_13389385120_item	2243605	et	4	main
ajalehe	doc_13389385120_item	2243606	et	3	main
nime	doc_13389385120_item	2243607	et	4	main
24	doc_13389385120_item	2243609	et	2	main
mainisid	doc_13389385120_item	2243608	et	4	main
õpilast	doc_13389385120_item	2243610	et	4	main
ning	doc_13389385120_item	2243611	et	3	main
eesti	doc_13389385120_item	2243612	et	4	main
algust	doc_13389385120_item	2243614	et	4	main
rahvusärkamisaega	doc_13389385120_item	2243613	et	4	main
õigesti	doc_13389385120_item	2243616	et	3	main
nimetasid	doc_13389385120_item	2243615	et	4	main
vaid	doc_13389385120_item	2243617	et	3	main
pool	doc_13389385120_item	2243618	et	4	main
küsinutest15	doc_13389385120_item	2243619	et	4	main
inimest	doc_13389385120_item	2243620	et	3	main
eesti	doc_13389385120_item	2243621	et	4	main
ja	doc_13389385120_item	2243623	et	3	main
mitte	doc_13389385120_item	2243626	et	3	main
teada	doc_13389385120_item	2243633	et	3	main
kaasaegseid	doc_13389385120_item	2243636	et	3	main
õpilased	doc_13389385120_item	2243639	et	3	main
mitte	doc_13389385120_item	2243650	et	3	main
teadmisi	doc_13389385120_item	2243662	et	4	main
absurdseid	doc_13389385120_item	2243666	et	3	main
mitte	doc_13389385120_item	2243668	et	3	main
filmidest	doc_13389385120_item	2243679	et	3	main
filme	doc_13389385120_item	2243684	et	3	main
küsimus	doc_13389385120_item	2243690	et	4	main
midagi	doc_13389385120_item	2243707	et	4	main
lisaandmed	doc_13389385120_item	2243716	et	3	main
keskmisest	doc_13389385120_item	2243723	et	3	main
õppeastmel	doc_13389385120_item	2243727	et	3	main
eesti	doc_13389385120_item	2243739	et	4	main
aabits	doc_13389385120_item	2243743	et	3	main
mis	doc_13389385120_item	2243746	et	4	main
aga	doc_13389385120_item	2243757	et	3	main
ole	doc_13389385120_item	2243629	et	4	main
ma	doc_13389385120_item	2243631	et	3	main
et	doc_13389385120_item	2243634	et	3	main
oskavad	doc_13389385120_item	2243640	et	4	main
14	doc_13389385120_item	2243642	et	2	main
erinevaid	doc_13389385120_item	2243644	et	4	main
16	doc_13389385120_item	2243646	et	2	main
midagi	doc_13389385120_item	2243651	et	4	main
kirjutanudjärgmine	doc_13389385120_item	2243652	et	4	main
küsimus	doc_13389385120_item	2243653	et	4	main
oli	doc_13389385120_item	2243654	et	3	main
suhteliselt	doc_13389385120_item	2243655	et	4	main
raske	doc_13389385120_item	2243656	et	4	main
oli	doc_13389385120_item	2243658	et	3	main
vaja	doc_13389385120_item	2243659	et	4	main
kasettpõlvkonnast	doc_13389385120_item	2243663	et	4	main
vastuseid	doc_13389385120_item	2243664	et	3	main
õiget	doc_13389385120_item	2243670	et	3	main
küsisin	doc_13389385120_item	2243675	et	3	main
teadmisest	doc_13389385120_item	2243677	et	4	main
mitmesuguseid	doc_13389385120_item	2243683	et	3	main
7	doc_13389385120_item	2243686	et	2	main
aga	doc_13389385120_item	2243687	et	3	main
ei	doc_13389385120_item	2243688	et	4	main
balti	doc_13389385120_item	2243692	et	3	main
ja	doc_13389385120_item	2243694	et	3	main
järgmised13	doc_13389385120_item	2243704	et	3	main
kirjutanud16	doc_13389385120_item	2243708	et	4	main
on	doc_13389385120_item	2243718	et	4	main
kultuuriloost	doc_13389385120_item	2243720	et	4	main
suunatud	doc_13389385120_item	2243731	et	4	main
keeleõppimisele	doc_13389385120_item	2243734	et	3	main
kohad	doc_13389385120_item	2243736	et	4	main
teater	doc_13389385120_item	2243740	et	3	main
sündmused	doc_13389385120_item	2243745	et	3	main
on	doc_13389385120_item	2243756	et	4	main
eesti	doc_13389385120_item	2243758	et	4	main
teadminemõistatustele	doc_13389385120_item	2243760	et	4	main
peale	doc_13389385120_item	2243768	et	4	main
testide	doc_13389385120_item	2243769	et	3	main
ja	doc_13389385120_item	2243771	et	3	main
et	doc_13389385120_item	2243777	et	3	main
eesti	doc_13389385120_item	2243779	et	4	main
lühike	doc_13389385120_item	2243786	et	4	main
õppekavas	doc_13389385120_item	2243791	et	3	main
õpetada	doc_13389385120_item	2243795	et	3	main
piisavalt	doc_13389385120_item	2243800	et	4	main
rohkem	doc_13389385120_item	2243811	et	4	main
nagu	doc_13389385120_item	2243815	et	3	main
arvavad	doc_13389385120_item	2243823	et	4	main
õppekavas	doc_13389385120_item	2243825	et	3	main
et	doc_13389385120_item	2243832	et	3	main
rakendada	doc_13389385120_item	2243834	et	3	main
mitmesugusid	doc_13389385120_item	2243842	et	3	main
selleks	doc_13389385120_item	2243847	et	4	main
et	doc_13389385120_item	2243848	et	3	main
aru	doc_13389385120_item	2243852	et	4	main
5klassi	doc_13389385120_item	2243858	et	4	main
pole	doc_13389385120_item	2243861	et	3	main
jäetud	doc_13389385120_item	2243863	et	4	main
me	doc_13389385120_item	2243868	et	4	main
oli	doc_13389385120_item	2243879	et	3	main
tihti	doc_13389385120_item	2243882	et	3	main
midagi	doc_13389385120_item	2243889	et	4	main
tollast	doc_13389385120_item	2243700	et	3	main
ajast	doc_13389385120_item	2243701	et	4	main
tulemused	doc_13389385120_item	2243702	et	3	main
ole	doc_13389385120_item	2243706	et	4	main
ainult	doc_13389385120_item	2243710	et	4	main
madalamal	doc_13389385120_item	2243724	et	4	main
sel	doc_13389385120_item	2243726	et	3	main
on	doc_13389385120_item	2243730	et	4	main
riigieksamile	doc_13389385120_item	2243732	et	3	main
st	doc_13389385120_item	2243733	et	3	main
nõrgad	doc_13389385120_item	2243735	et	3	main
kultuuriteadmises	doc_13389385120_item	2243737	et	3	main
eesti	doc_13389385120_item	2243741	et	4	main
esimene	doc_13389385120_item	2243742	et	3	main
viisid	doc_13389385120_item	2243747	et	4	main
kett	doc_13389385120_item	2243750	et	4	main
kaasaaegne	doc_13389385120_item	2243752	et	3	main
kirjanduskasettpõlvkondtugevad	doc_13389385120_item	2243754	et	4	main
ajalehest	doc_13389385120_item	2243763	et	4	main
eesti	doc_13389385120_item	2243765	et	4	main
analüüsimist	doc_13389385120_item	2243770	et	4	main
ma	doc_13389385120_item	2243774	et	3	main
määratud	doc_13389385120_item	2243782	et	4	main
aeg	doc_13389385120_item	2243783	et	3	main
väga	doc_13389385120_item	2243785	et	3	main
ei	doc_13389385120_item	2243789	et	4	main
kultuuri	doc_13389385120_item	2243797	et	4	main
ei	doc_13389385120_item	2243798	et	4	main
ja	doc_13389385120_item	2243802	et	3	main
mida	doc_13389385120_item	2243804	et	4	main
näidata	doc_13389385120_item	2243806	et	4	main
ja	doc_13389385120_item	2243807	et	3	main
õpikud	doc_13389385120_item	2243814	et	3	main
oma	doc_13389385120_item	2243818	et	4	main
silm	doc_13389385120_item	2243819	et	3	main
on	doc_13389385120_item	2243826	et	4	main
jäetud	doc_13389385120_item	2243830	et	4	main
praktikal	doc_13389385120_item	2243833	et	3	main
oma	doc_13389385120_item	2243835	et	4	main
koolid	doc_13389385120_item	2243838	et	3	main
ise	doc_13389385120_item	2243840	et	4	main
mõtlema	doc_13389385120_item	2243846	et	3	main
lastel	doc_13389385120_item	2243849	et	4	main
kergem	doc_13389385120_item	2243851	et	4	main
saada	doc_13389385120_item	2243853	et	4	main
eesti	doc_13389385120_item	2243854	et	4	main
õppimiseks	doc_13389385120_item	2243866	et	4	main
välja	doc_13389385120_item	2243887	et	4	main
mõtlema	doc_13389385120_item	2243888	et	3	main
jagatud	doc_13389385120_item	2243924	et	4	main
kuna	doc_13389385120_item	2243925	et	3	main
õpilased	doc_13389385120_item	2243930	et	3	main
mis	doc_13389385120_item	2243934	et	4	main
juba	doc_13389385120_item	2243936	et	3	main
vanasõnu	doc_13389385120_item	2243942	et	3	main
kõnekäände	doc_13389385120_item	2243944	et	4	main
rõhk	doc_13389385120_item	2243949	et	3	main
läbivatele	doc_13389385120_item	2243953	et	4	main
tutvutud	doc_13389385120_item	2243978	et	4	main
raamatute	doc_13389385120_item	2243979	et	3	main
ning	doc_13389385120_item	2243988	et	3	main
näitama	doc_13389385120_item	2244007	et	3	main
samuti	doc_13389385120_item	2244010	et	3	main
kurss	doc_13389385120_item	2244020	et	3	main
kultuurist	doc_13389385120_item	2244022	et	3	main
seda	doc_13389385120_item	2244024	et	3	main
kursusel	doc_13389385120_item	2244029	et	3	main
kutsuvad	doc_13389385120_item	2244038	et	4	main
eesti	doc_13389385120_item	2244040	et	4	main
näitustel	doc_13389385120_item	2244045	et	4	main
teatritesüldiselt	doc_13389385120_item	2244046	et	4	main
loodavad	doc_13389385120_item	2244054	et	4	main
uus	doc_13389385120_item	2244056	et	3	main
õpilased	doc_13389385120_item	2244073	et	3	main
rohkem	doc_13389385120_item	2244075	et	4	main
teadmised	doc_13389385120_item	2244082	et	4	main
tasemel	doc_13389385120_item	2244087	et	3	main
nad	doc_13389385120_item	2244089	et	3	main
tuleb	doc_13389385120_item	2244097	et	3	main
eesti	doc_13389385120_item	2244099	et	4	main
samas	doc_13389385120_item	2244101	et	4	main
keeleõppimine	doc_13389385120_item	2244122	et	3	main
saab	doc_13389385120_item	2244128	et	3	main
põhjendada	doc_13389385120_item	2244130	et	3	main
tasandilkuna	doc_13389385120_item	2243725	et	4	main
tähelepanu	doc_13389385120_item	2243729	et	4	main
ning	doc_13389385120_item	2243744	et	3	main
vastamineteadmised	doc_13389385120_item	2243761	et	4	main
kultuuritegelastestkoidulakreutzwaldeesti	doc_13389385120_item	2243762	et	4	main
tantsust	doc_13389385120_item	2243766	et	3	main
kokkuvõte	doc_13389385120_item	2243767	et	3	main
vestlemist	doc_13389385120_item	2243773	et	4	main
tulin	doc_13389385120_item	2243775	et	3	main
õppekavas	doc_13389385120_item	2243778	et	3	main
õppimiseks	doc_13389385120_item	2243781	et	4	main
piisa	doc_13389385120_item	2243790	et	4	main
võiks	doc_13389385120_item	2243805	et	4	main
huvi	doc_13389385120_item	2243812	et	4	main
kui	doc_13389385120_item	2243813	et	3	main
öeldakse	doc_13389385120_item	2243816	et	3	main
on	doc_13389385120_item	2243820	et	4	main
kuningassamas	doc_13389385120_item	2243821	et	4	main
väga	doc_13389385120_item	2243827	et	3	main
vähe	doc_13389385120_item	2243828	et	3	main
teadmisi	doc_13389385120_item	2243836	et	4	main
ning	doc_13389385120_item	2243837	et	3	main
pidustusi	doc_13389385120_item	2243843	et	3	main
välja	doc_13389385120_item	2243845	et	4	main
rahva	doc_13389385120_item	2243855	et	3	main
riigiõppekava	doc_13389385120_item	2243859	et	4	main
aega	doc_13389385120_item	2243862	et	4	main
seega	doc_13389385120_item	2243867	et	4	main
selliseid	doc_13389385120_item	2243870	et	4	main
et	doc_13389385120_item	2243872	et	3	main
õpilased	doc_13389385120_item	2243873	et	3	main
ei	doc_13389385120_item	2243874	et	4	main
tea	doc_13389385120_item	2243875	et	4	main
millal	doc_13389385120_item	2243876	et	3	main
laulupidu	doc_13389385120_item	2243878	et	4	main
ja	doc_13389385120_item	2243880	et	3	main
oleksid	doc_13389385120_item	2243892	et	4	main
haritud	doc_13389385120_item	2243894	et	4	main
2	doc_13389385120_item	2243922	et	2	main
ei	doc_13389385120_item	2243926	et	4	main
süstemmatiliselt	doc_13389385120_item	2243928	et	4	main
sageli	doc_13389385120_item	2243931	et	3	main
tundma	doc_13389385120_item	2243941	et	3	main
on	doc_13389385120_item	2243947	et	4	main
pandud	doc_13389385120_item	2243950	et	4	main
peavad	doc_13389385120_item	2243971	et	4	main
koostööd	doc_13389385120_item	2243973	et	4	main
emakeele	doc_13389385120_item	2243983	et	4	main
ainuld	doc_13389385120_item	2243985	et	4	main
9klassi	doc_13389385120_item	2243990	et	4	main
suunatud	doc_13389385120_item	2243993	et	4	main
ees	doc_13389385120_item	2243996	et	4	main
põhikoolieksam	doc_13389385120_item	2243998	et	3	main
tulemusigümnaasiumiastmes	doc_13389385120_item	2244009	et	3	main
peale	doc_13389385120_item	2244031	et	4	main
materjali	doc_13389385120_item	2244033	et	4	main
korrata	doc_13389385120_item	2244034	et	4	main
vanasamas	doc_13389385120_item	2244036	et	4	main
ei	doc_13389385120_item	2244048	et	4	main
praeguse	doc_13389385120_item	2244051	et	3	main
et	doc_13389385120_item	2244055	et	3	main
õppekava	doc_13389385120_item	2244057	et	4	main
samuti	doc_13389385120_item	2244068	et	3	main
pole	doc_13389385120_item	2244070	et	3	main
paljud	doc_13389385120_item	2244072	et	3	main
tahaksid	doc_13389385120_item	2244074	et	4	main
nende	doc_13389385120_item	2244079	et	4	main
nende	doc_13389385120_item	2244081	et	4	main
ole	doc_13389385120_item	2244085	et	4	main
kõrgel	doc_13389385120_item	2244086	et	4	main
vestelda	doc_13389385120_item	2244098	et	4	main
nad	doc_13389385120_item	2244102	et	3	main
keele	doc_13389385120_item	2244124	et	4	main
on	doc_13389385120_item	2244126	et	4	main
seda	doc_13389385120_item	2244129	et	3	main
et	doc_13389385120_item	2244132	et	3	main
mingit	doc_13389385120_item	2244140	et	3	main
vesteldes	doc_13389385120_item	2244143	et	3	main
kaasaaegsed	doc_13389385120_item	2244152	et	3	main
sellest	doc_13389385120_item	2244185	et	4	main
see	doc_13389385120_item	2244199	et	3	main
arusaadavaks	doc_13389385120_item	2244201	et	4	main
juba	doc_13389385120_item	2244202	et	3	main
vanasõnade	doc_13389385120_item	2243759	et	3	main
ja	doc_13389385120_item	2243764	et	3	main
õpetajatega	doc_13389385120_item	2243772	et	4	main
kultuurile	doc_13389385120_item	2243780	et	3	main
on	doc_13389385120_item	2243784	et	4	main
õpetajate	doc_13389385120_item	2243787	et	4	main
selleks	doc_13389385120_item	2243793	et	4	main
ole	doc_13389385120_item	2243799	et	4	main
videomaterjali	doc_13389385120_item	2243803	et	4	main
õpilastele	doc_13389385120_item	2243810	et	4	main
et	doc_13389385120_item	2243817	et	3	main
et	doc_13389385120_item	2243824	et	3	main
aega	doc_13389385120_item	2243829	et	4	main
selleks	doc_13389385120_item	2243831	et	4	main
peavad	doc_13389385120_item	2243839	et	4	main
ja	doc_13389385120_item	2243844	et	3	main
oleks	doc_13389385120_item	2243850	et	3	main
näiteks	doc_13389385120_item	2243857	et	4	main
järgi	doc_13389385120_item	2243860	et	4	main
eesti	doc_13389385120_item	2243864	et	4	main
ajaloo	doc_13389385120_item	2243865	et	4	main
saame	doc_13389385120_item	2243869	et	4	main
aga	doc_13389385120_item	2243884	et	3	main
ise	doc_13389385120_item	2243886	et	4	main
koolilõpetajad	doc_13389385120_item	2243891	et	3	main
inimesed	doc_13389385120_item	2243895	et	3	main
seega	doc_13389385120_item	2243896	et	4	main
viiendas	doc_13389385120_item	2243897	et	3	main
klassis	doc_13389385120_item	2243898	et	3	main
on	doc_13389385120_item	2243899	et	4	main
eesti	doc_13389385120_item	2243900	et	4	main
ajaloo	doc_13389385120_item	2243901	et	4	main
kursus	doc_13389385120_item	2243902	et	3	main
ning	doc_13389385120_item	2243903	et	3	main
tallinna	doc_13389385120_item	2243904	et	4	main
õismäe	doc_13389385120_item	2243905	et	3	main
vene	doc_13389385120_item	2243906	et	4	main
lütseumis	doc_13389385120_item	2243907	et	3	main
on	doc_13389385120_item	2243908	et	4	main
5	doc_13389385120_item	2243909	et	2	main
klassi	doc_13389385120_item	2243910	et	4	main
ajalootunnid	doc_13389385120_item	2243911	et	3	main
keeles	doc_13389385120_item	2243913	et	4	main
ja	doc_13389385120_item	2243914	et	3	main
eesti	doc_13389385120_item	2243912	et	4	main
et	doc_13389385120_item	2243915	et	3	main
õpilased	doc_13389385120_item	2243916	et	3	main
saaksid	doc_13389385120_item	2243917	et	4	main
paremaid	doc_13389385120_item	2243918	et	4	main
teadmisi	doc_13389385120_item	2243919	et	4	main
on	doc_13389385120_item	2243920	et	4	main
klass	doc_13389385120_item	2243921	et	3	main
ole	doc_13389385120_item	2243927	et	4	main
kultuuriõppimist	doc_13389385120_item	2243929	et	3	main
unustavad	doc_13389385120_item	2243932	et	4	main
algklassides	doc_13389385120_item	2243937	et	3	main
õpivad	doc_13389385120_item	2243940	et	3	main
ikkagi	doc_13389385120_item	2243946	et	4	main
tegelastega	doc_13389385120_item	2243980	et	3	main
terve	doc_13389385120_item	2243989	et	4	main
õppeaeg	doc_13389385120_item	2243991	et	3	main
on	doc_13389385120_item	2243997	et	4	main
kontrollitakse	doc_13389385120_item	2244000	et	4	main
mitte	doc_13389385120_item	2244002	et	3	main
kõik	doc_13389385120_item	2244011	et	4	main
riigieksamile	doc_13389385120_item	2244015	et	3	main
peaks	doc_13389385120_item	2244017	et	4	main
parandama	doc_13389385120_item	2244018	et	3	main
35-tunniline	doc_13389385120_item	2244019	et	4	main
peavad	doc_13389385120_item	2243885	et	4	main
et	doc_13389385120_item	2243890	et	3	main
ikka	doc_13389385120_item	2243893	et	4	main
rühmaks	doc_13389385120_item	2243923	et	4	main
seda	doc_13389385120_item	2243933	et	3	main
omandasid	doc_13389385120_item	2243935	et	4	main
6klassis	doc_13389385120_item	2243938	et	3	main
õpilased	doc_13389385120_item	2243939	et	3	main
suurem	doc_13389385120_item	2243948	et	4	main
grammatikale	doc_13389385120_item	2243951	et	3	main
ja	doc_13389385120_item	2243952	et	3	main
ning	doc_13389385120_item	2243955	et	3	main
tegema	doc_13389385120_item	2243972	et	3	main
ning	doc_13389385120_item	2243974	et	3	main
eesti	doc_13389385120_item	2243975	et	4	main
tutvutakse	doc_13389385120_item	2243981	et	3	main
tunnisloetakse	doc_13389385120_item	2243984	et	4	main
katkendeid	doc_13389385120_item	2243986	et	3	main
keeleõppimisele	doc_13389385120_item	2243994	et	3	main
rahvapärimuseteadmisi	doc_13389385120_item	2244003	et	4	main
õpetajad	doc_13389385120_item	2244005	et	4	main
parimaid	doc_13389385120_item	2244008	et	4	main
on	doc_13389385120_item	2244013	et	4	main
pööratud	doc_13389385120_item	2244014	et	4	main
olukorda	doc_13389385120_item	2244016	et	4	main
eesti	doc_13389385120_item	2244021	et	4	main
on	doc_13389385120_item	2244025	et	4	main
kuna	doc_13389385120_item	2244027	et	3	main
sel	doc_13389385120_item	2244028	et	3	main
ka	doc_13389385120_item	2244035	et	3	main
näitlejaid	doc_13389385120_item	2244042	et	4	main
ekskursioonidel	doc_13389385120_item	2244044	et	3	main
rahul	doc_13389385120_item	2244050	et	4	main
ja	doc_13389385120_item	2244053	et	3	main
annab	doc_13389385120_item	2244058	et	3	main
võimalusi	doc_13389385120_item	2244061	et	3	main
ainult	doc_13389385120_item	2244063	et	4	main
kultuuriõppimine	doc_13389385120_item	2244069	et	3	main
õppida	doc_13389385120_item	2244076	et	3	main
kultuuris	doc_13389385120_item	2244083	et	3	main
situatsioon	doc_13389385120_item	2244094	et	3	main
kultuurist	doc_13389385120_item	2244100	et	3	main
oskavad	doc_13389385120_item	2244103	et	4	main
mõistatusi	doc_13389385120_item	2243943	et	4	main
kuid	doc_13389385120_item	2243945	et	4	main
teemadele	doc_13389385120_item	2243954	et	3	main
rahvapärimust	doc_13389385120_item	2243956	et	4	main
mööda	doc_13389385120_item	2243958	et	4	main
minnes	doc_13389385120_item	2243959	et	3	main
kirjanikke	doc_13389385120_item	2243960	et	3	main
õpetatakse	doc_13389385120_item	2243957	et	3	main
loomingust	doc_13389385120_item	2243961	et	3	main
õpetatakse	doc_13389385120_item	2243962	et	3	main
väga	doc_13389385120_item	2243963	et	3	main
kuna	doc_13389385120_item	2243965	et	3	main
kaudselt	doc_13389385120_item	2243964	et	4	main
sellele	doc_13389385120_item	2243966	et	4	main
on	doc_13389385120_item	2243967	et	4	main
väga	doc_13389385120_item	2243968	et	3	main
vähe	doc_13389385120_item	2243969	et	3	main
aegaõpetajad	doc_13389385120_item	2243970	et	3	main
keele	doc_13389385120_item	2243976	et	4	main
tunnis	doc_13389385120_item	2243977	et	3	main
ka	doc_13389385120_item	2243982	et	3	main
raamatutest	doc_13389385120_item	2243987	et	4	main
on	doc_13389385120_item	2243992	et	4	main
kuna	doc_13389385120_item	2243995	et	3	main
kus	doc_13389385120_item	2243999	et	3	main
grammatikat	doc_13389385120_item	2244001	et	3	main
ning	doc_13389385120_item	2244004	et	3	main
peavad	doc_13389385120_item	2244006	et	4	main
tähelepanu	doc_13389385120_item	2244012	et	4	main
tuleb	doc_13389385120_item	2244030	et	3	main
õpetajad	doc_13389385120_item	2244037	et	4	main
käiakse	doc_13389385120_item	2244043	et	3	main
õpetajad	doc_13389385120_item	2244047	et	4	main
õppekavaga	doc_13389385120_item	2244052	et	3	main
rohkem	doc_13389385120_item	2244060	et	4	main
piisav	doc_13389385120_item	2244071	et	4	main
kuna	doc_13389385120_item	2244078	et	3	main
arvates	doc_13389385120_item	2244080	et	4	main
ja	doc_13389385120_item	2244088	et	3	main
et	doc_13389385120_item	2244091	et	3	main
selline	doc_13389385120_item	2244093	et	4	main
neil	doc_13389385120_item	2244096	et	4	main
keelt	doc_13389385120_item	2244105	et	4	main
aga	doc_13389385120_item	2244106	et	3	main
sellega	doc_13389385120_item	2244131	et	3	main
alles	doc_13389385120_item	2244134	et	3	main
õppitakse	doc_13389385120_item	2244135	et	4	main
vabandust	doc_13389385120_item	2244141	et	4	main
sain	doc_13389385120_item	2244145	et	3	main
teada	doc_13389385120_item	2244146	et	3	main
rohkem	doc_13389385120_item	2244149	et	4	main
huvitavad	doc_13389385120_item	2244151	et	4	main
eesti	doc_13389385120_item	2244153	et	4	main
kirjanikud	doc_13389385120_item	2244154	et	3	main
nende	doc_13389385120_item	2244155	et	4	main
looming	doc_13389385120_item	2244156	et	3	main
ülikoolis	doc_13389385120_item	2244189	et	4	main
aga	doc_13389385120_item	2244190	et	3	main
järgmises	doc_13389385120_item	2244192	et	3	main
ning	doc_13389385120_item	2244196	et	3	main
saab	doc_13389385120_item	2244198	et	3	main
järeldustega	doc_13389385120_item	2244205	et	4	main
õpetajate	doc_13389385120_item	2244207	et	4	main
arvamustega	doc_13389385120_item	2244208	et	3	main
rahvuspärimuse	doc_13389385120_item	2244216	et	3	main
httpswwwriigiteatajaeeertactjspid802290	doc_13389385120_item	2244232	et	4	main
эстонской	doc_13389385120_item	2244251	et	2	main
и	doc_13389385120_item	2244255	et	2	main
ээсти	doc_13389385120_item	2244259	et	2	main
1980	doc_13389385120_item	2244261	et	2	main
283	doc_13389385120_item	2244265	et	2	main
valikuliselt	doc_13389385120_item	2244271	et	4	main
vastus	doc_134822946562_item	2244272	et	3	main
1	doc_134822946562_item	2244274	et	2	main
miks	doc_134822946562_item	2244275	et	4	main
ma	doc_134822946562_item	2244278	et	3	main
saada	doc_134822946562_item	2244290	et	4	main
palju	doc_134822946562_item	2244298	et	4	main
ja	doc_134822946562_item	2244300	et	3	main
raskusi	doc_134822946562_item	2244321	et	4	main
ei	doc_134822946562_item	2244329	et	4	main
tean	doc_134822946562_item	2244337	et	3	main
see	doc_134822946562_item	2244339	et	3	main
3	doc_134822946562_item	2244342	et	2	main
kui	doc_134822946562_item	2244356	et	3	main
aga	doc_134822946562_item	2244361	et	3	main
tõsine	doc_134822946562_item	2244363	et	4	main
minu	doc_134822946562_item	2244364	et	3	main
eestis	doc_134822946562_item	2244369	et	3	main
eesti	doc_134822946562_item	2244372	et	4	main
õppida	doc_134822946562_item	2244378	et	3	main
teine	doc_134822946562_item	2244381	et	3	main
kus	doc_134822946562_item	2244390	et	3	main
edasi	doc_134822946562_item	2244392	et	3	main
ma	doc_134822946562_item	2244396	et	3	main
arvan	doc_134822946562_item	2244401	et	3	main
kui	doc_134822946562_item	2244403	et	3	main
siis	doc_134822946562_item	2244423	et	3	main
kain	doc_134822946562_item	2244426	et	3	main
on	doc_134822946562_item	2244440	et	4	main
12	doc_134822946562_item	2244469	et	2	main
ma	doc_134822946562_item	2244477	et	3	main
aga	doc_13389385120_item	2244023	et	3	main
vähe	doc_13389385120_item	2244026	et	3	main
uut	doc_13389385120_item	2244032	et	3	main
kooli	doc_13389385120_item	2244039	et	4	main
kirjanikke	doc_13389385120_item	2244041	et	3	main
ole	doc_13389385120_item	2244049	et	4	main
neile	doc_13389385120_item	2244059	et	4	main
mitte	doc_13389385120_item	2244062	et	3	main
keeleõppimiseks	doc_13389385120_item	2244064	et	3	main
õpilaste	doc_13389385120_item	2244065	et	4	main
arvates	doc_13389385120_item	2244066	et	4	main
on	doc_13389385120_item	2244067	et	4	main
kultuuri	doc_13389385120_item	2244077	et	4	main
ei	doc_13389385120_item	2244084	et	4	main
kardavad	doc_13389385120_item	2244090	et	4	main
tekib	doc_13389385120_item	2244092	et	3	main
et	doc_13389385120_item	2244095	et	3	main
eesti	doc_13389385120_item	2244104	et	4	main
ei	doc_13389385120_item	2244107	et	4	main
oska	doc_13389385120_item	2244108	et	4	main
mitte	doc_13389385120_item	2244109	et	3	main
midagi	doc_13389385120_item	2244110	et	4	main
öelda	doc_13389385120_item	2244111	et	4	main
kultuurist	doc_13389385120_item	2244112	et	3	main
samuti	doc_13389385120_item	2244113	et	3	main
nende	doc_13389385120_item	2244114	et	4	main
arvates	doc_13389385120_item	2244115	et	4	main
kultuuriteadmine	doc_13389385120_item	2244116	et	3	main
on	doc_13389385120_item	2244117	et	4	main
samal	doc_13389385120_item	2244118	et	3	main
tähtsal	doc_13389385120_item	2244119	et	3	main
tasemel	doc_13389385120_item	2244120	et	3	main
kui	doc_13389385120_item	2244121	et	3	main
kui	doc_13389385120_item	2244123	et	3	main
saa	doc_13389385120_item	2244139	et	4	main
ma	doc_13389385120_item	2244144	et	3	main
neid	doc_13389385120_item	2244150	et	4	main
filmid	doc_13389385120_item	2244158	et	4	main
vanasõnad	doc_13389385120_item	2244160	et	3	main
ja	doc_13389385120_item	2244161	et	3	main
sain	doc_13389385120_item	2244184	et	3	main
teada	doc_13389385120_item	2244187	et	3	main
loodameet	doc_13389385120_item	2244191	et	4	main
koolis	doc_13389385120_item	2244203	et	4	main
testideanalüüsidega	doc_13389385120_item	2244206	et	4	main
oma	doc_13389385120_item	2244211	et	4	main
töös	doc_13389385120_item	2244212	et	3	main
pandnud	doc_13389385120_item	2244213	et	4	main
hüpoteesi	doc_13389385120_item	2244214	et	4	main
et	doc_13389385120_item	2244215	et	3	main
õpetamiseks	doc_13389385120_item	2244219	et	4	main
on	doc_13389385120_item	2244220	et	4	main
riigiõõpekavas	doc_13389385120_item	2244221	et	4	main
vähe	doc_13389385120_item	2244223	et	3	main
2	doc_13389385120_item	2244229	et	2	main
3	doc_13389385120_item	2244231	et	2	main
valikuliselt	doc_13389385120_item	2244233	et	4	main
andres	doc_13389385120_item	2244235	et	4	main
eesti	doc_13389385120_item	2244238	et	4	main
lk	doc_13389385120_item	2244246	et	4	main
наук	doc_13389385120_item	2244250	et	2	main
языка	doc_13389385120_item	2244254	et	2	main
фольклорталлин	doc_13389385120_item	2244258	et	2	main
lk	doc_13389385120_item	2244262	et	4	main
õpin	doc_134822946562_item	2244277	et	3	main
tahan	doc_134822946562_item	2244282	et	3	main
hea	doc_134822946562_item	2244283	et	4	main
töökoht	doc_134822946562_item	2244289	et	3	main
töökoht	doc_134822946562_item	2244295	et	3	main
teadmised	doc_13389385120_item	2244125	et	4	main
ebapiisavad	doc_13389385120_item	2244127	et	3	main
kõige	doc_13389385120_item	2244148	et	4	main
mõistatused	doc_13389385120_item	2244162	et	4	main
mida	doc_13389385120_item	2244163	et	4	main
saab	doc_13389385120_item	2244164	et	3	main
kasutada	doc_13389385120_item	2244165	et	3	main
igas	doc_13389385120_item	2244166	et	3	main
situatsioonis	doc_13389385120_item	2244167	et	3	main
ja	doc_13389385120_item	2244168	et	3	main
rikastada	doc_13389385120_item	2244169	et	3	main
oma	doc_13389385120_item	2244170	et	4	main
kõne	doc_13389385120_item	2244171	et	4	main
sams	doc_13389385120_item	2244172	et	4	main
neid	doc_13389385120_item	2244173	et	4	main
huvitas	doc_13389385120_item	2244174	et	3	main
selline	doc_13389385120_item	2244175	et	4	main
terminkasettpõlvkond	doc_13389385120_item	2244176	et	4	main
mida	doc_13389385120_item	2244177	et	4	main
päris	doc_13389385120_item	2244178	et	4	main
tihti	doc_13389385120_item	2244179	et	3	main
kasutatakse	doc_13389385120_item	2244180	et	3	main
ausalt	doc_13389385120_item	2244181	et	4	main
öeldes	doc_13389385120_item	2244182	et	3	main
ma	doc_13389385120_item	2244183	et	3	main
keelt	doc_13389385120_item	2244133	et	4	main
kuid	doc_13389385120_item	2244136	et	4	main
kultuuriteadmistepuudulikkusele	doc_13389385120_item	2244137	et	4	main
ei	doc_13389385120_item	2244138	et	4	main
leidaõpilastega	doc_13389385120_item	2244142	et	4	main
et	doc_13389385120_item	2244147	et	3	main
eesti	doc_13389385120_item	2244157	et	4	main
eesti	doc_13389385120_item	2244159	et	4	main
õppekavas	doc_13389385120_item	2244193	et	3	main
termin	doc_13389385120_item	2244200	et	3	main
selliste	doc_13389385120_item	2244204	et	4	main
ma	doc_13389385120_item	2244209	et	3	main
jäetud	doc_13389385120_item	2244222	et	4	main
1	doc_13389385120_item	2244227	et	2	main
4	doc_13389385120_item	2244234	et	2	main
valdmaa	doc_13389385120_item	2244237	et	4	main
ajalugu	doc_13389385120_item	2244239	et	4	main
gümnaasiumile	doc_13389385120_item	2244240	et	3	main
koolibri	doc_13389385120_item	2244242	et	4	main
2001	doc_13389385120_item	2244243	et	2	main
lk	doc_13389385120_item	2244244	et	4	main
сср	doc_13389385120_item	2244252	et	2	main
литературы	doc_13389385120_item	2244256	et	2	main
54-122	doc_13389385120_item	2244263	et	2	main
2	doc_13389385120_item	2244267	et	2	main
httpwwwestonicaorgestluguhtmlmenyyid175kateg5alam19leht1	doc_13389385120_item	2244270	et	4	main
küsimusele	doc_134822946562_item	2244273	et	4	main
sest	doc_134822946562_item	2244280	et	4	main
hariduse	doc_134822946562_item	2244284	et	3	main
kui	doc_134822946562_item	2244292	et	3	main
hea	doc_134822946562_item	2244294	et	4	main
ta	doc_134822946562_item	2244296	et	4	main
teenib	doc_134822946562_item	2244297	et	3	main
minu	doc_134822946562_item	2244322	et	3	main
ma	doc_134822946562_item	2244328	et	3	main
saa	doc_134822946562_item	2244330	et	4	main
teha	doc_134822946562_item	2244335	et	3	main
õppida	doc_134822946562_item	2244346	et	3	main
raske	doc_134822946562_item	2244354	et	4	main
siis	doc_134822946562_item	2244358	et	3	main
välismaal	doc_134822946562_item	2244360	et	4	main
ma	doc_134822946562_item	2244367	et	3	main
see	doc_134822946562_item	2244370	et	3	main
minule	doc_134822946562_item	2244377	et	3	main
võimalus	doc_134822946562_item	2244382	et	3	main
ei	doc_134822946562_item	2244398	et	4	main
et	doc_134822946562_item	2244402	et	3	main
soovid	doc_134822946562_item	2244429	et	4	main
omandada	doc_134822946562_item	2244431	et	3	main
kõigepealt	doc_134822946562_item	2244432	et	3	main
tahan	doc_134822946562_item	2244433	et	3	main
sest	doc_134822946562_item	2244436	et	4	main
prestiizne	doc_134822946562_item	2244441	et	4	main
edasi	doc_134822946562_item	2244443	et	3	main
see	doc_134822946562_item	2244445	et	3	main
hea	doc_134822946562_item	2244448	et	4	main
saan	doc_134822946562_item	2244460	et	4	main
sisendavad	doc_134822946562_item	2244465	et	4	main
see	doc_134822946562_item	2244466	et	3	main
6	doc_134822946562_item	2244471	et	2	main
haridus	doc_134822946562_item	2244476	et	3	main
ei	doc_134822946562_item	2244481	et	4	main
aga	doc_134822946562_item	2244483	et	3	main
osa	doc_134822946562_item	2244485	et	4	main
kindlasti	doc_134822946562_item	2244487	et	3	main
see	doc_134822946562_item	2244488	et	3	main
olla	doc_134822946562_item	2244491	et	3	main
eesti	doc_142308885626_item	2244499	et	4	main
taasavamise	doc_142308885626_item	2244504	et	4	main
tähtsus	doc_142308885626_item	2244505	et	4	main
haridus-	doc_142308885626_item	2244507	et	3	main
ja	doc_142308885626_item	2244508	et	3	main
millal	doc_142308885626_item	2244511	et	3	main
eestlased	doc_142308885626_item	2244513	et	3	main
ja	doc_142308885626_item	2244515	et	3	main
tähendas	doc_142308885626_item	2244521	et	3	main
avatakse	doc_142308885626_item	2244524	et	4	main
ideid	doc_142308885626_item	2244531	et	3	main
arvab	doc_142308885626_item	2244533	et	3	main
ning	doc_142308885626_item	2244534	et	3	main
et	doc_142308885626_item	2244536	et	3	main
kaotada	doc_142308885626_item	2244539	et	3	main
terminist	doc_13389385120_item	2244186	et	3	main
ainult	doc_13389385120_item	2244188	et	4	main
tulevad	doc_13389385120_item	2244194	et	4	main
muutused	doc_13389385120_item	2244195	et	4	main
lastele	doc_13389385120_item	2244197	et	4	main
tõestasin	doc_13389385120_item	2244210	et	3	main
õppimiseks	doc_13389385120_item	2244217	et	4	main
aega	doc_13389385120_item	2244224	et	4	main
mytele2eeoldjyrimarijyrivalikuliselt	doc_13389385120_item	2244228	et	4	main
adamsonsulev	doc_13389385120_item	2244236	et	4	main
119-124	doc_13389385120_item	2244245	et	2	main
249	doc_13389385120_item	2244247	et	2	main
академия	doc_13389385120_item	2244249	et	2	main
эстонский	doc_13389385120_item	2244257	et	2	main
7	doc_13389385120_item	2244269	et	2	main
ma	doc_134822946562_item	2244276	et	3	main
ma	doc_134822946562_item	2244281	et	3	main
ja	doc_134822946562_item	2244286	et	3	main
hea	doc_134822946562_item	2244288	et	4	main
inimesel	doc_134822946562_item	2244293	et	3	main
raha	doc_134822946562_item	2244299	et	4	main
see	doc_134822946562_item	2244325	et	3	main
töö	doc_134822946562_item	2244334	et	4	main
vaja	doc_134822946562_item	2244341	et	4	main
parem	doc_134822946562_item	2244345	et	4	main
eestis	doc_134822946562_item	2244347	et	3	main
või	doc_134822946562_item	2244348	et	4	main
ma	doc_134822946562_item	2244350	et	3	main
on	doc_134822946562_item	2244353	et	4	main
prooblem	doc_134822946562_item	2244365	et	4	main
on	doc_134822946562_item	2244371	et	4	main
keel	doc_134822946562_item	2244373	et	4	main
ja	doc_134822946562_item	2244374	et	3	main
aga	doc_134822946562_item	2244380	et	3	main
eesti	doc_134822946562_item	2244385	et	4	main
parem	doc_134822946562_item	2244387	et	4	main
aga	doc_134822946562_item	2244400	et	3	main
seda	doc_134822946562_item	2244421	et	3	main
võimalik	doc_134822946562_item	2244424	et	3	main
5	doc_134822946562_item	2244427	et	2	main
miks	doc_134822946562_item	2244428	et	4	main
kõrgharidus	doc_134822946562_item	2244434	et	3	main
mind	doc_134822946562_item	2244446	et	4	main
aitab	doc_134822946562_item	2244447	et	3	main
töö	doc_134822946562_item	2244449	et	4	main
ja	doc_134822946562_item	2244451	et	3	main
omandada	doc_134822946562_item	2244462	et	3	main
kas	doc_134822946562_item	2244472	et	3	main
väärtustavad	doc_134822946562_item	2244475	et	4	main
rohkem	doc_134822946562_item	2244484	et	4	main
see	doc_134822946562_item	2244493	et	3	main
kontrolltöö	doc_142308885626_item	2244498	et	4	main
tartu	doc_142308885626_item	2244502	et	4	main
eesti	doc_142308885626_item	2244506	et	4	main
2	doc_142308885626_item	2244510	et	2	main
ja	doc_13389385120_item	2244218	et	3	main
kasutatud	doc_13389385120_item	2244225	et	4	main
kirjandus	doc_13389385120_item	2244226	et	3	main
httpwwwermeelangestnode201	doc_13389385120_item	2244230	et	4	main
tallinn	doc_13389385120_item	2244241	et	4	main
1	doc_13389385120_item	2244248	et	2	main
институт	doc_13389385120_item	2244253	et	2	main
раамат	doc_13389385120_item	2244260	et	2	main
278	doc_13389385120_item	2244264	et	2	main
307-323	doc_13389385120_item	2244266	et	2	main
httpwwwtovltlneduee	doc_13389385120_item	2244268	et	4	main
õpin	doc_134822946562_item	2244279	et	3	main
saada	doc_134822946562_item	2244285	et	4	main
sellepärast	doc_134822946562_item	2244287	et	3	main
sest	doc_134822946562_item	2244291	et	4	main
elab	doc_134822946562_item	2244301	et	3	main
kui	doc_134822946562_item	2244303	et	3	main
parem	doc_134822946562_item	2244302	et	4	main
need	doc_134822946562_item	2244304	et	3	main
inimesed	doc_134822946562_item	2244305	et	3	main
kes	doc_134822946562_item	2244306	et	4	main
teenivad	doc_134822946562_item	2244307	et	4	main
vähem	doc_134822946562_item	2244308	et	4	main
raha	doc_134822946562_item	2244309	et	4	main
2	doc_134822946562_item	2244310	et	2	main
missugused	doc_134822946562_item	2244311	et	3	main
raskused	doc_134822946562_item	2244312	et	4	main
on	doc_134822946562_item	2244313	et	4	main
õpetöös	doc_134822946562_item	2244314	et	4	main
ma	doc_134822946562_item	2244315	et	3	main
arvan	doc_134822946562_item	2244316	et	3	main
et	doc_134822946562_item	2244317	et	3	main
on	doc_134822946562_item	2244319	et	4	main
palju	doc_134822946562_item	2244320	et	4	main
õpetöös	doc_134822946562_item	2244318	et	4	main
jaoks	doc_134822946562_item	2244323	et	4	main
kõigepealt	doc_134822946562_item	2244324	et	3	main
on	doc_134822946562_item	2244326	et	4	main
lajsk	doc_134822946562_item	2244327	et	4	main
sundida	doc_134822946562_item	2244332	et	4	main
kodu	doc_134822946562_item	2244333	et	4	main
et	doc_134822946562_item	2244338	et	3	main
on	doc_134822946562_item	2244340	et	4	main
kus	doc_134822946562_item	2244343	et	3	main
välismaal	doc_134822946562_item	2244349	et	4	main
et	doc_134822946562_item	2244352	et	3	main
ka	doc_134822946562_item	2244359	et	3	main
kui	doc_134822946562_item	2244366	et	3	main
õpin	doc_134822946562_item	2244368	et	3	main
välismaal	doc_134822946562_item	2244376	et	4	main
on	doc_134822946562_item	2244384	et	4	main
õppida	doc_134822946562_item	2244393	et	3	main
miks	doc_134822946562_item	2244395	et	4	main
tea	doc_134822946562_item	2244399	et	4	main
ptus	doc_134822946562_item	2244425	et	4	main
see	doc_134822946562_item	2244439	et	3	main
rohkem	doc_134822946562_item	2244452	et	4	main
raha	doc_134822946562_item	2244453	et	4	main
minule	doc_134822946562_item	2244467	et	3	main
aastat	doc_134822946562_item	2244470	et	3	main
noored	doc_134822946562_item	2244474	et	3	main
arvan	doc_134822946562_item	2244478	et	3	main
mõned	doc_134822946562_item	2244480	et	3	main
väärtustavad	doc_134822946562_item	2244482	et	4	main
end	doc_134822946562_item	2244331	et	4	main
aga	doc_134822946562_item	2244336	et	3	main
on	doc_134822946562_item	2244344	et	4	main
arvan	doc_134822946562_item	2244351	et	3	main
õppida	doc_134822946562_item	2244355	et	3	main
eestis	doc_134822946562_item	2244357	et	3	main
kõige	doc_134822946562_item	2244362	et	4	main
võjmalik	doc_134822946562_item	2244375	et	4	main
parem	doc_134822946562_item	2244379	et	4	main
see	doc_134822946562_item	2244383	et	3	main
keel	doc_134822946562_item	2244386	et	4	main
õppida	doc_134822946562_item	2244388	et	3	main
4	doc_134822946562_item	2244389	et	2	main
sooviksid	doc_134822946562_item	2244391	et	4	main
ja	doc_134822946562_item	2244394	et	3	main
täpselt	doc_134822946562_item	2244397	et	4	main
ma	doc_134822946562_item	2244404	et	3	main
12	doc_134822946562_item	2244405	et	2	main
aastat	doc_134822946562_item	2244406	et	3	main
koolis	doc_134822946562_item	2244407	et	4	main
õpin	doc_134822946562_item	2244408	et	3	main
siis	doc_134822946562_item	2244409	et	3	main
pean	doc_134822946562_item	2244410	et	4	main
ülikoolis	doc_134822946562_item	2244411	et	4	main
edasi	doc_134822946562_item	2244412	et	3	main
õppida	doc_134822946562_item	2244413	et	3	main
ja	doc_134822946562_item	2244414	et	3	main
omandada	doc_134822946562_item	2244416	et	3	main
kõrgharidust	doc_134822946562_item	2244415	et	4	main
aga	doc_134822946562_item	2244417	et	3	main
kui	doc_134822946562_item	2244418	et	3	main
ei	doc_134822946562_item	2244419	et	4	main
saa	doc_134822946562_item	2244420	et	4	main
teha	doc_134822946562_item	2244422	et	3	main
kõrgharidust	doc_134822946562_item	2244430	et	4	main
omandada	doc_134822946562_item	2244435	et	3	main
arvan	doc_134822946562_item	2244437	et	3	main
et	doc_134822946562_item	2244438	et	3	main
ja	doc_134822946562_item	2244442	et	3	main
elus	doc_134822946562_item	2244444	et	4	main
saada	doc_134822946562_item	2244450	et	4	main
teenida	doc_134822946562_item	2244454	et	3	main
ja	doc_134822946562_item	2244455	et	3	main
arvan	doc_134822946562_item	2244456	et	3	main
ka	doc_134822946562_item	2244457	et	3	main
et	doc_134822946562_item	2244458	et	3	main
ma	doc_134822946562_item	2244459	et	3	main
kõrgharidus	doc_134822946562_item	2244461	et	3	main
mind	doc_134822946562_item	2244463	et	4	main
vanemad	doc_134822946562_item	2244464	et	4	main
juba	doc_134822946562_item	2244468	et	3	main
tänapäeva	doc_134822946562_item	2244473	et	4	main
et	doc_134822946562_item	2244479	et	3	main
kontrolltöö	doc_142308885626_item	2244497	et	4	main
pärisorjusest	doc_142308885626_item	2244514	et	4	main
nende	doc_142308885626_item	2244518	et	4	main
1802	doc_142308885626_item	2244523	et	2	main
pooldab	doc_142308885626_item	2244529	et	3	main
valgustuslikke	doc_142308885626_item	2244530	et	3	main
arvab	doc_142308885626_item	2244535	et	3	main
pärisorjus	doc_142308885626_item	2244537	et	3	main
müüapärandada	doc_142308885626_item	2244545	et	4	main
tingimusel	doc_142308885626_item	2244546	et	3	main
eesti	doc_142308885626_item	2244559	et	4	main
keele	doc_142308885626_item	2244560	et	4	main
lektor	doc_142308885626_item	2244561	et	3	main
on	doc_142308885626_item	2244562	et	4	main
panema	doc_142308885626_item	2244571	et	3	main
keele	doc_142308885626_item	2244573	et	4	main
uues	doc_142308885626_item	2244592	et	3	main
ahrensi	doc_142308885626_item	2244594	et	4	main
kreutzwald	doc_142308885626_item	2244598	et	4	main
talupojad	doc_142308885626_item	2244604	et	4	main
vabad	doc_142308885626_item	2244606	et	3	main
ise	doc_142308885626_item	2244608	et	4	main
kinnisvara	doc_142308885626_item	2244611	et	4	main
talupoeg	doc_142308885626_item	2244618	et	3	main
venemaalt	doc_142308885626_item	2244627	et	3	main
alles	doc_142308885626_item	2244630	et	3	main
algul	doc_142308885626_item	2244639	et	4	main
arv	doc_142308885626_item	2244649	et	3	main
1810	doc_142308885626_item	2244655	et	2	main
1856	doc_142308885626_item	2244662	et	2	main
rikkad	doc_142308885626_item	2244668	et	4	main
liikumi	doc_142308885627_item	2244709	et	4	main
ilma	doc_142308885627_item	2244715	et	4	main
maata	doc_142308885627_item	2244716	et	3	main
ja	doc_142308885627_item	2244717	et	3	main
talupoegadel	doc_142308885627_item	2244725	et	3	main
kinni	doc_142308885627_item	2244733	et	3	main
tasandil	doc_142308885627_item	2244740	et	3	main
pärisorjuse	doc_142308885627_item	2244741	et	3	main
ei	doc_142308885627_item	2244743	et	4	main
seda	doc_142308885627_item	2244745	et	3	main
isegi	doc_142308885627_item	2244754	et	4	main
karmimaks	doc_142308885627_item	2244755	et	4	main
vaatamata	doc_142308885627_item	2244757	et	4	main
elutingimuste	doc_142308885627_item	2244759	et	3	main
vabastamine	doc_142308885627_item	2244762	et	4	main
talupoja	doc_142308885627_item	2244765	et	4	main
see	doc_142308885627_item	2244767	et	3	main
eesti	doc_142308885627_item	2244801	et	4	main
ja	doc_142308885627_item	2244806	et	3	main
aastal	doc_142308885627_item	2244812	et	3	main
väärtustavad	doc_134822946562_item	2244486	et	4	main
alati	doc_134822946562_item	2244489	et	4	main
kõrgharidus	doc_134822946562_item	2244492	et	3	main
on	doc_134822946562_item	2244494	et	4	main
elus	doc_134822946562_item	2244496	et	4	main
1	doc_142308885626_item	2244501	et	2	main
mida	doc_142308885626_item	2244516	et	4	main
jaoks	doc_142308885626_item	2244519	et	4	main
1	doc_142308885626_item	2244522	et	2	main
ning	doc_142308885626_item	2244532	et	3	main
oma	doc_142308885626_item	2244541	et	4	main
mida	doc_142308885626_item	2244543	et	4	main
õppida	doc_142308885626_item	2244564	et	3	main
soome	doc_142308885626_item	2244572	et	3	main
uus	doc_142308885626_item	2244576	et	3	main
keelde	doc_142308885626_item	2244581	et	4	main
sõnu	doc_142308885626_item	2244583	et	4	main
saab	doc_142308885626_item	2244585	et	3	main
kirjaviis	doc_142308885626_item	2244587	et	4	main
enamik	doc_142308885626_item	2244589	et	3	main
trükiseid	doc_142308885626_item	2244590	et	3	main
ilmub	doc_142308885626_item	2244591	et	3	main
kirjaviisis	doc_142308885626_item	2244593	et	3	main
ideid	doc_142308885626_item	2244595	et	3	main
ka	doc_142308885626_item	2244597	et	3	main
eestimaal	doc_142308885626_item	2244600	et	4	main
sõlmivad	doc_142308885626_item	2244607	et	4	main
vahetada	doc_142308885626_item	2244617	et	3	main
nii	doc_134822946562_item	2244490	et	3	main
tee	doc_134822946562_item	2244495	et	4	main
kultuuriloost	doc_142308885626_item	2244500	et	4	main
ülikooli	doc_142308885626_item	2244503	et	4	main
kultuurielule	doc_142308885626_item	2244509	et	3	main
vabastati	doc_142308885626_item	2244512	et	3	main
see	doc_142308885626_item	2244517	et	3	main
sisuliselt	doc_142308885626_item	2244520	et	4	main
taas	doc_142308885626_item	2244525	et	3	main
tü	doc_142308885626_item	2244526	et	4	main
rektoriks	doc_142308885626_item	2244527	et	3	main
parrot	doc_142308885626_item	2244528	et	4	main
tuleb	doc_142308885626_item	2244538	et	3	main
et	doc_142308885626_item	2244547	et	3	main
loenguid	doc_142308885626_item	2244557	et	4	main
pidama	doc_142308885626_item	2244558	et	4	main
võimalik	doc_142308885626_item	2244563	et	3	main
keelt	doc_142308885626_item	2244568	et	4	main
hakatakse	doc_142308885626_item	2244569	et	3	main
kirja	doc_142308885626_item	2244570	et	4	main
eesti	doc_142308885626_item	2244580	et	4	main
1870	doc_142308885626_item	2244584	et	2	main
uus	doc_142308885626_item	2244586	et	3	main
võidu	doc_142308885626_item	2244588	et	4	main
lepinguid	doc_142308885626_item	2244609	et	3	main
osta	doc_142308885626_item	2244616	et	4	main
vabalt	doc_142308885626_item	2244624	et	4	main
ka	doc_142308885626_item	2244626	et	3	main
1832	doc_142308885626_item	2244631	et	2	main
kohtukorraldust	doc_142308885626_item	2244634	et	3	main
19	doc_142308885626_item	2244637	et	2	main
pärisorjuse	doc_142308885626_item	2244645	et	3	main
talupoeg	doc_142308885626_item	2244657	et	3	main
oma	doc_142308885626_item	2244659	et	4	main
eestimaal	doc_142308885627_item	2244698	et	4	main
kaotatud	doc_142308885627_item	2244703	et	4	main
ikka	doc_142308885627_item	2244708	et	4	main
oli	doc_142308885627_item	2244710	et	3	main
piiratud	doc_142308885627_item	2244712	et	4	main
tööga	doc_142308885627_item	2244732	et	3	main
omavalitsuse	doc_142308885627_item	2244735	et	3	main
ainult	doc_142308885627_item	2244738	et	4	main
valla	doc_142308885627_item	2244739	et	4	main
et	doc_142308885627_item	2244746	et	3	main
kergemaks	doc_142308885627_item	2244749	et	4	main
mõjutas	doc_142308885627_item	2244768	et	3	main
nüüd	doc_142308885627_item	2244770	et	4	main
tundis	doc_142308885627_item	2244771	et	3	main
sai	doc_142308885627_item	2244799	et	4	main
nüüd	doc_142308885627_item	2244804	et	4	main
tartu	doc_142308885627_item	2244815	et	4	main
ülikool	doc_142308885627_item	2244816	et	4	main
toimus	doc_142308885627_item	2244818	et	3	main
seal	doc_142308885627_item	2244819	et	4	main
ikka	doc_142308885627_item	2244820	et	4	main
teistest	doc_142308885627_item	2244831	et	4	main
tartust	doc_142308885627_item	2244833	et	3	main
kultuuri	doc_142308885627_item	2244835	et	4	main
tuntud	doc_142308885627_item	2244844	et	4	main
jakobi	doc_142308885627_item	2244849	et	4	main
oli	doc_142308885627_item	2244862	et	3	main
tähtis	doc_142308885627_item	2244864	et	4	main
aja	doc_142308885627_item	2244866	et	4	main
sai	doc_142308885627_item	2244870	et	4	main
tartu	doc_142308885627_item	2244872	et	4	main
kultuuri	doc_142308885627_item	2244880	et	4	main
võimalus	doc_142308885627_item	2244886	et	3	main
valdkondades	doc_142308885627_item	2244890	et	3	main
ka	doc_142308885627_item	2244892	et	3	main
arvamus	doc_15203423346_item	2244895	et	3	main
tuleb	doc_15203423346_item	2244903	et	3	main
on	doc_15203423346_item	2244909	et	4	main
kui	doc_15203423346_item	2244911	et	3	main
situatsioonid	doc_15203423346_item	2244916	et	3	main
rõõmsate	doc_15203423346_item	2244936	et	3	main
pulmad	doc_15203423346_item	2244939	et	3	main
end	doc_15203423346_item	2244954	et	4	main
halvasti	doc_15203423346_item	2244955	et	3	main
aga	doc_15203423346_item	2244956	et	3	main
ei	doc_15203423346_item	2244958	et	4	main
arsti	doc_15203423346_item	2244961	et	4	main
seal	doc_15203423346_item	2244964	et	4	main
talupoegadel	doc_142308885626_item	2244540	et	3	main
ei	doc_142308885626_item	2244548	et	4	main
olda	doc_142308885626_item	2244549	et	3	main
mõisale	doc_142308885626_item	2244550	et	3	main
ega	doc_142308885626_item	2244551	et	3	main
kohtule	doc_142308885626_item	2244552	et	3	main
võlgu	doc_142308885626_item	2244553	et	4	main
1802	doc_142308885626_item	2244554	et	2	main
hakkab	doc_142308885626_item	2244555	et	3	main
vallasvara	doc_142308885626_item	2244542	et	4	main
võib	doc_142308885626_item	2244544	et	3	main
tü	doc_142308885626_item	2244556	et	4	main
keelt	doc_142308885626_item	2244566	et	4	main
1843	doc_142308885626_item	2244575	et	2	main
kirjaviis	doc_142308885626_item	2244577	et	4	main
ahrens	doc_142308885626_item	2244578	et	4	main
uusi	doc_142308885626_item	2244582	et	3	main
isiklikult	doc_142308885626_item	2244605	et	4	main
saa	doc_142308885626_item	2244614	et	4	main
müüa	doc_142308885626_item	2244615	et	3	main
sai	doc_142308885626_item	2244619	et	4	main
rännata	doc_142308885626_item	2244625	et	4	main
võimalus	doc_142308885626_item	2244629	et	3	main
täpsustati	doc_142308885626_item	2244632	et	4	main
kaotati	doc_142308885626_item	2244636	et	3	main
saj	doc_142308885626_item	2244638	et	4	main
talupoeg	doc_142308885626_item	2244640	et	3	main
enam	doc_142308885626_item	2244643	et	4	main
pärast	doc_142308885626_item	2244644	et	4	main
kaotamist	doc_142308885626_item	2244646	et	4	main
kasvama	doc_142308885626_item	2244651	et	3	main
tekivad	doc_142308885626_item	2244653	et	3	main
tekkisid	doc_142308885626_item	2244666	et	4	main
kontrolltöö	doc_142308885627_item	2244671	et	4	main
kultuuriloost	doc_142308885627_item	2244673	et	4	main
kaotati	doc_142308885627_item	2244697	et	3	main
1816	doc_142308885627_item	2244699	et	2	main
oli	doc_142308885627_item	2244702	et	3	main
pärisorjus	doc_142308885627_item	2244704	et	3	main
taluomanikuga	doc_142308885627_item	2244720	et	3	main
raha	doc_142308885627_item	2244724	et	4	main
veel	doc_142308885627_item	2244726	et	4	main
maksma	doc_142308885627_item	2244734	et	3	main
sai	doc_142308885627_item	2244736	et	4	main
tähendanud	doc_142308885627_item	2244744	et	4	main
taluoja	doc_142308885627_item	2244747	et	4	main
muutub	doc_142308885627_item	2244750	et	3	main
aga	doc_142308885627_item	2244756	et	3	main
rasketele	doc_142308885627_item	2244758	et	3	main
tähendas	doc_142308885627_item	2244760	et	3	main
palju	doc_142308885627_item	2244764	et	4	main
jaoks	doc_142308885627_item	2244766	et	4	main
talupojal	doc_142308885627_item	2244802	et	4	main
aegadele	doc_142308885627_item	2244809	et	3	main
õppetöö	doc_142308885627_item	2244817	et	4	main
hakkasid	doc_142308885627_item	2244825	et	4	main
teadlased	doc_142308885627_item	2244830	et	3	main
keskus	doc_142308885627_item	2244838	et	3	main
töötas	doc_142308885627_item	2244840	et	3	main
von	doc_142308885627_item	2244845	et	4	main
tartu	doc_142308885627_item	2244856	et	4	main
ülikolis	doc_142308885627_item	2244857	et	3	main
väga	doc_142308885627_item	2244863	et	3	main
toll	doc_142308885627_item	2244865	et	3	main
ülikoolis	doc_142308885627_item	2244873	et	4	main
arenemisest	doc_142308885627_item	2244883	et	4	main
oli	doc_142308885627_item	2244884	et	3	main
uuringuid	doc_142308885627_item	2244888	et	3	main
paljudes	doc_142308885627_item	2244889	et	3	main
neid	doc_142308885627_item	2244893	et	4	main
ma	doc_15203423346_item	2244896	et	3	main
tihti	doc_15203423346_item	2244905	et	3	main
juhtuvad	doc_15203423346_item	2244907	et	4	main
hea	doc_15203423346_item	2244910	et	4	main
õnnetus	doc_15203423346_item	2244913	et	4	main
ei	doc_15203423346_item	2244919	et	4	main
eesti	doc_142308885626_item	2244565	et	4	main
eesti	doc_142308885626_item	2244567	et	4	main
eeskujul	doc_142308885626_item	2244574	et	3	main
toob	doc_142308885626_item	2244579	et	3	main
pooldab	doc_142308885626_item	2244596	et	3	main
2	doc_142308885626_item	2244599	et	2	main
1816	doc_142308885626_item	2244601	et	2	main
liivimaal	doc_142308885626_item	2244602	et	4	main
1819	doc_142308885626_item	2244603	et	2	main
vallasvara	doc_142308885626_item	2244610	et	4	main
talupoegi	doc_142308885626_item	2244612	et	4	main
ei	doc_142308885626_item	2244613	et	4	main
kodanikuõigusi	doc_142308885626_item	2244620	et	4	main
perekonnanime	doc_142308885626_item	2244621	et	4	main
linnadesse	doc_142308885626_item	2244623	et	3	main
see	doc_142308885626_item	2244628	et	3	main
ihunuhtlus	doc_142308885626_item	2244635	et	3	main
ei	doc_142308885626_item	2244641	et	4	main
eestlaste	doc_142308885626_item	2244648	et	4	main
linnades	doc_142308885626_item	2244652	et	3	main
võib	doc_142308885626_item	2244656	et	3	main
päriseksostmise	doc_142308885626_item	2244664	et	3	main
ka	doc_142308885626_item	2244667	et	3	main
kontrolltöö	doc_142308885627_item	2244670	et	4	main
eesti	doc_142308885627_item	2244672	et	4	main
pärisorjus	doc_142308885627_item	2244696	et	3	main
liivimaal	doc_142308885627_item	2244700	et	4	main
teoorjus	doc_142308885627_item	2244706	et	3	main
nad	doc_142308885627_item	2244718	et	3	main
said	doc_142308885626_item	2244622	et	4	main
ka	doc_142308885626_item	2244633	et	3	main
nälgi	doc_142308885626_item	2244642	et	4	main
hakkab	doc_142308885626_item	2244647	et	3	main
linnas	doc_142308885626_item	2244650	et	4	main
vabrikud	doc_142308885626_item	2244654	et	3	main
vabalt	doc_142308885626_item	2244658	et	4	main
toodangut	doc_142308885626_item	2244660	et	3	main
müüa	doc_142308885626_item	2244661	et	3	main
talude	doc_142308885626_item	2244663	et	3	main
seadus	doc_142308885626_item	2244665	et	4	main
talupojad	doc_142308885626_item	2244669	et	4	main
1	doc_142308885627_item	2244674	et	2	main
tartu	doc_142308885627_item	2244675	et	4	main
ülikooli	doc_142308885627_item	2244676	et	4	main
taasavamise	doc_142308885627_item	2244677	et	4	main
tähtsus	doc_142308885627_item	2244678	et	4	main
eesti	doc_142308885627_item	2244679	et	4	main
haridus-	doc_142308885627_item	2244680	et	3	main
ja	doc_142308885627_item	2244681	et	3	main
kultuurielule	doc_142308885627_item	2244682	et	3	main
2	doc_142308885627_item	2244683	et	2	main
millal	doc_142308885627_item	2244684	et	3	main
vabastati	doc_142308885627_item	2244685	et	3	main
eestlased	doc_142308885627_item	2244686	et	3	main
pärisorjusest	doc_142308885627_item	2244687	et	4	main
ja	doc_142308885627_item	2244688	et	3	main
see	doc_142308885627_item	2244690	et	3	main
mida	doc_142308885627_item	2244689	et	4	main
nende	doc_142308885627_item	2244691	et	4	main
sisuliselt	doc_142308885627_item	2244693	et	4	main
tähendas	doc_142308885627_item	2244694	et	3	main
jaoks	doc_142308885627_item	2244692	et	4	main
2	doc_142308885627_item	2244695	et	2	main
1819a	doc_142308885627_item	2244701	et	4	main
aga	doc_142308885627_item	2244705	et	3	main
säilis	doc_142308885627_item	2244707	et	4	main
ikka	doc_142308885627_item	2244711	et	4	main
talupoegi	doc_142308885627_item	2244713	et	4	main
vabastati	doc_142308885627_item	2244714	et	3	main
pidid	doc_142308885627_item	2244719	et	4	main
rendileppingu	doc_142308885627_item	2244721	et	4	main
kuna	doc_142308885627_item	2244723	et	3	main
pidid	doc_142308885627_item	2244729	et	4	main
nad	doc_142308885627_item	2244730	et	3	main
talupoeg	doc_142308885627_item	2244737	et	3	main
kohati	doc_142308885627_item	2244751	et	4	main
muutus	doc_142308885627_item	2244752	et	4	main
psühholoogiliselt	doc_142308885627_item	2244769	et	4	main
m	doc_142308885627_item	2244797	et	4	main
oli	doc_142308885627_item	2244803	et	3	main
lootus	doc_142308885627_item	2244807	et	4	main
1	doc_142308885627_item	2244810	et	2	main
avati	doc_142308885627_item	2244813	et	3	main
veel	doc_142308885627_item	2244821	et	4	main
keeles	doc_142308885627_item	2244823	et	4	main
jälle	doc_142308885627_item	2244824	et	3	main
sai	doc_142308885627_item	2244834	et	4	main
palju	doc_142308885627_item	2244841	et	4	main
maailma	doc_142308885627_item	2244843	et	4	main
struve	doc_142308885627_item	2244851	et	4	main
paljud	doc_142308885627_item	2244853	et	3	main
olid	doc_142308885627_item	2244858	et	4	main
kultuuri	doc_142308885627_item	2244867	et	4	main
arengule	doc_142308885627_item	2244868	et	3	main
kõrgharidus	doc_142308885627_item	2244869	et	3	main
inimesed	doc_142308885627_item	2244875	et	3	main
kes	doc_142308885627_item	2244876	et	4	main
huvitatud	doc_142308885627_item	2244878	et	4	main
ja	doc_142308885627_item	2244881	et	3	main
olen	doc_15203423346_item	2244897	et	3	main
kodustel	doc_15203423346_item	2244900	et	4	main
puudumine	doc_15203423346_item	2244902	et	4	main
uputus	doc_15203423346_item	2244927	et	4	main
ootamine	doc_15203423346_item	2244929	et	4	main
kohta	doc_15203423346_item	2244938	et	4	main
tähtpäevad	doc_15203423346_item	2244940	et	3	main
puudun	doc_15203423346_item	2244942	et	3	main
kõrge	doc_15203423346_item	2244950	et	4	main
või	doc_15203423346_item	2244952	et	4	main
minna	doc_15203423346_item	2244960	et	3	main
sest	doc_15203423346_item	2244963	et	4	main
et	doc_15203423346_item	2244970	et	3	main
ei	doc_15203423346_item	2244972	et	4	main
kahjuks	doc_15203423346_item	2244977	et	4	main
vanemad	doc_15203423346_item	2244979	et	4	main
seletuskirju	doc_15203423346_item	2244981	et	4	main
ja	doc_15203423346_item	2244986	et	3	main
käi	doc_15203423346_item	2244988	et	4	main
et	doc_15203423346_item	2244992	et	3	main
ei	doc_15203423346_item	2244995	et	4	main
laps	doc_15203423346_item	2245001	et	4	main
ta	doc_15203423346_item	2245005	et	4	main
seda	doc_15203423346_item	2245007	et	3	main
ülalpool	doc_15203423346_item	2245009	et	3	main
näitab	doc_15203423346_item	2245011	et	3	main
tuleb	doc_15203423346_item	2245016	et	3	main
ja	doc_15203423346_item	2245021	et	3	main
lugesin	doc_15203423347_item	2245025	et	3	main
see	doc_15203423347_item	2245028	et	3	main
narva	doc_15203423347_item	2245030	et	4	main
on	doc_15203423347_item	2245035	et	4	main
kultuurist	doc_15203423347_item	2245046	et	3	main
kolme	doc_15203423347_item	2245048	et	4	main
mäng	doc_15203423347_item	2245056	et	3	main
kingitakse	doc_15203423347_item	2245058	et	4	main
on	doc_15203423347_item	2245067	et	4	main
kokku	doc_15203423347_item	2245099	et	3	main
ilmub	doc_15203423347_item	2245103	et	3	main
selle	doc_15203423347_item	2245107	et	4	main
artiklist	doc_15203423348_item	2245114	et	4	main
noored	doc_15203423348_item	2245117	et	3	main
artikli	doc_15203423348_item	2245118	et	3	main
sõlmima	doc_142308885627_item	2244722	et	4	main
ei	doc_142308885627_item	2244727	et	4	main
olnud	doc_142308885627_item	2244728	et	4	main
renti	doc_142308885627_item	2244731	et	4	main
kaotamine	doc_142308885627_item	2244742	et	4	main
elu	doc_142308885627_item	2244748	et	4	main
ta	doc_142308885627_item	2244753	et	4	main
parisorjusest	doc_142308885627_item	2244761	et	4	main
väga	doc_142308885627_item	2244763	et	3	main
talupoeg	doc_142308885627_item	2244772	et	3	main
vabadust	doc_142308885627_item	2244773	et	4	main
ta	doc_142308885627_item	2244774	et	4	main
vastutas	doc_142308885627_item	2244775	et	3	main
ise	doc_142308885627_item	2244776	et	4	main
enda	doc_142308885627_item	2244777	et	4	main
eest	doc_142308885627_item	2244778	et	4	main
nüüd	doc_142308885627_item	2244779	et	4	main
oli	doc_142308885627_item	2244780	et	3	main
talupojal	doc_142308885627_item	2244781	et	4	main
võimalus	doc_142308885627_item	2244782	et	3	main
oma	doc_142308885627_item	2244783	et	4	main
maad	doc_142308885627_item	2244784	et	4	main
välja	doc_142308885627_item	2244785	et	4	main
osta	doc_142308885627_item	2244786	et	4	main
kuigi	doc_142308885627_item	2244787	et	3	main
tol	doc_142308885627_item	2244788	et	3	main
ajal	doc_142308885627_item	2244789	et	4	main
see	doc_142308885627_item	2244790	et	3	main
oli	doc_142308885627_item	2244791	et	3	main
ainult	doc_142308885627_item	2244792	et	4	main
unistus	doc_142308885627_item	2244793	et	4	main
aga	doc_142308885627_item	2244794	et	3	main
näiteks	doc_142308885627_item	2244795	et	4	main
talupoeg	doc_142308885627_item	2244796	et	3	main
erdell	doc_142308885627_item	2244798	et	4	main
mõisaomanikuks	doc_142308885627_item	2244800	et	4	main
usk	doc_142308885627_item	2244805	et	3	main
parematele	doc_142308885627_item	2244808	et	4	main
1802	doc_142308885627_item	2244811	et	2	main
uuesti	doc_142308885627_item	2244814	et	3	main
saksa	doc_142308885627_item	2244822	et	4	main
tulema	doc_142308885627_item	2244827	et	4	main
professorid	doc_142308885627_item	2244828	et	3	main
tartus	doc_142308885627_item	2244839	et	3	main
astronoom	doc_142308885627_item	2244852	et	3	main
töötasid	doc_142308885627_item	2244855	et	4	main
valgustusideaalidest	doc_142308885627_item	2244860	et	3	main
see	doc_142308885627_item	2244861	et	3	main
kättesaadavaks	doc_142308885627_item	2244871	et	4	main
õppisid	doc_142308885627_item	2244874	et	4	main
olid	doc_142308885627_item	2244877	et	4	main
eesti	doc_142308885627_item	2244879	et	4	main
hariduse	doc_142308885627_item	2244882	et	3	main
nüüd	doc_142308885627_item	2244885	et	4	main
teha	doc_142308885627_item	2244887	et	3	main
nõus	doc_15203423346_item	2244898	et	4	main
et	doc_15203423346_item	2244899	et	3	main
põhjustel	doc_15203423346_item	2244901	et	3	main
õnnelikult	doc_15203423346_item	2244915	et	4	main
kui	doc_15203423346_item	2244917	et	3	main
matus	doc_15203423346_item	2244930	et	3	main
kaaluvad	doc_15203423346_item	2244931	et	4	main
võivad	doc_15203423346_item	2244933	et	4	main
olla	doc_15203423346_item	2244934	et	3	main
sündmuste	doc_15203423346_item	2244937	et	3	main
ma	doc_15203423346_item	2244941	et	3	main
harva	doc_15203423346_item	2244944	et	4	main
mõnikord	doc_15203423346_item	2244945	et	3	main
ma	doc_15203423346_item	2244957	et	3	main
viitsi	doc_15203423346_item	2244959	et	4	main
on	doc_15203423346_item	2244965	et	4	main
mõned	doc_15203423346_item	2244978	et	3	main
õpilane	doc_15203423346_item	2244983	et	3	main
koolis	doc_15203423346_item	2244989	et	4	main
arvan	doc_15203423346_item	2244991	et	3	main
ole	doc_15203423346_item	2244996	et	4	main
väga	doc_15203423346_item	2244997	et	3	main
tahab	doc_15203423346_item	2245002	et	3	main
öeldu	doc_15203423346_item	2245010	et	4	main
et	doc_15203423346_item	2245012	et	3	main
seadustada	doc_15203423346_item	2245017	et	3	main
milles	doc_15203423347_item	2245034	et	3	main
esimeselt	doc_15203423347_item	2245038	et	3	main
fotoga	doc_15203423347_item	2245050	et	3	main
viiendal	doc_15203423347_item	2245051	et	3	main
ja	doc_15203423347_item	2245055	et	3	main
suurem	doc_15203423347_item	2245061	et	4	main
on	doc_15203423347_item	2245063	et	4	main
krooni	doc_15203423347_item	2245071	et	4	main
neljandalt	doc_15203423347_item	2245105	et	3	main
aastalt	doc_15203423347_item	2245106	et	3	main
ajalehe	doc_15203423347_item	2245108	et	3	main
on	doc_15203423347_item	2245110	et	4	main
ajalehest	doc_15203423348_item	2245115	et	4	main
kolm	doc_15203423348_item	2245124	et	3	main
sarve	doc_15203423348_item	2245125	et	4	main
kus	doc_15203423348_item	2245141	et	3	main
kujutatud	doc_15203423348_item	2245143	et	4	main
ja	doc_15203423348_item	2245145	et	3	main
peamõte	doc_15203423348_item	2245154	et	3	main
kolm	doc_15203423348_item	2245166	et	3	main
kitse	doc_15203423348_item	2245168	et	4	main
omanik	doc_15203423348_item	2245169	et	3	main
teda	doc_15203423348_item	2245178	et	4	main
belkal	doc_15203423348_item	2245181	et	4	main
kolm	doc_15203423348_item	2245188	et	3	main
see	doc_15203423348_item	2245190	et	3	main
rahustab	doc_15203423348_item	2245199	et	3	main
spetsialistid	doc_15203423348_item	2245201	et	3	main
loomad	doc_15203423348_item	2245209	et	3	main
meeldis	doc_15203423348_item	2245237	et	3	main
tavaline	doc_15203423348_item	2245241	et	4	main
eestisse	doc_142308885627_item	2244826	et	4	main
ja	doc_142308885627_item	2244829	et	3	main
riikidest	doc_142308885627_item	2244832	et	3	main
ja	doc_142308885627_item	2244836	et	3	main
hariduse	doc_142308885627_item	2244837	et	3	main
inimesi	doc_142308885627_item	2244842	et	4	main
baer	doc_142308885627_item	2244846	et	4	main
embrüoloogia	doc_142308885627_item	2244847	et	4	main
rajaja	doc_142308885627_item	2244848	et	4	main
w	doc_142308885627_item	2244850	et	4	main
kes	doc_142308885627_item	2244854	et	4	main
huvitatud	doc_142308885627_item	2244859	et	4	main
ja	doc_142308885627_item	2244891	et	3	main
arendama	doc_142308885627_item	2244894	et	3	main
seadustada	doc_15203423346_item	2244904	et	3	main
kodus	doc_15203423346_item	2244906	et	4	main
õnnetused	doc_15203423346_item	2244908	et	4	main
see	doc_15203423346_item	2244912	et	3	main
lõpeb	doc_15203423346_item	2244914	et	4	main
laps	doc_15203423346_item	2244918	et	4	main
saa	doc_15203423346_item	2244920	et	4	main
minna	doc_15203423346_item	2244921	et	3	main
igasugused	doc_15203423346_item	2244924	et	3	main
näiteks	doc_15203423346_item	2244925	et	4	main
vee	doc_15203423346_item	2244926	et	3	main
töömehe	doc_15203423346_item	2244928	et	3	main
põhjused	doc_15203423346_item	2244932	et	3	main
ka	doc_15203423346_item	2244935	et	3	main
mul	doc_15203423346_item	2244946	et	3	main
nohu	doc_15203423346_item	2244948	et	4	main
palavik	doc_15203423346_item	2244951	et	3	main
tunnen	doc_15203423346_item	2244953	et	3	main
juurde	doc_15203423346_item	2244962	et	4	main
siis	doc_15203423346_item	2244967	et	3	main
mind	doc_15203423346_item	2244971	et	4	main
olnud	doc_15203423346_item	2244973	et	4	main
koolis	doc_15203423346_item	2244974	et	4	main
kodusel	doc_15203423346_item	2244975	et	4	main
jalutab	doc_15203423346_item	2244985	et	3	main
teha	doc_15203423346_item	2245004	et	3	main
kõik	doc_15203423346_item	2245008	et	4	main
kodustel	doc_15203423346_item	2245013	et	4	main
kooli	doc_15203423346_item	2244922	et	4	main
on	doc_15203423346_item	2244923	et	4	main
tundidel	doc_15203423346_item	2244943	et	3	main
on	doc_15203423346_item	2244947	et	4	main
köha	doc_15203423346_item	2244949	et	4	main
kirjutab	doc_15203423346_item	2244969	et	3	main
kirjutavad	doc_15203423346_item	2244980	et	4	main
kergekäeliselt	doc_15203423346_item	2244982	et	4	main
lihtsalt	doc_15203423346_item	2244984	et	4	main
juhtum	doc_15203423346_item	2244994	et	3	main
tähtis	doc_15203423346_item	2244998	et	4	main
sest	doc_15203423346_item	2244999	et	4	main
poppi	doc_15203423346_item	2245003	et	4	main
põhjustel	doc_15203423346_item	2245014	et	3	main
nii	doc_15203423346_item	2245018	et	3	main
kergem	doc_15203423346_item	2245020	et	4	main
mugavam	doc_15203423346_item	2245022	et	4	main
ajalehte	doc_15203423347_item	2245026	et	4	main
ajaleht	doc_15203423347_item	2245033	et	3	main
neljanda	doc_15203423347_item	2245039	et	3	main
on	doc_15203423347_item	2245041	et	4	main
poliitikast	doc_15203423347_item	2245045	et	4	main
värvilise	doc_15203423347_item	2245049	et	4	main
leheküljel	doc_15203423347_item	2245052	et	3	main
teised	doc_15203423347_item	2245066	et	4	main
ja	doc_15203423347_item	2245069	et	3	main
seitse	doc_15203423347_item	2245100	et	3	main
linn	doc_15203423347_item	2245102	et	3	main
kahetuhande	doc_15203423347_item	2245104	et	4	main
number	doc_15203423347_item	2245109	et	3	main
lühikokkuvõtte	doc_15203423348_item	2245113	et	4	main
on	doc_15203423348_item	2245120	et	4	main
ja	doc_15203423348_item	2245128	et	3	main
foto	doc_15203423348_item	2245140	et	4	main
naine	doc_15203423348_item	2245147	et	3	main
on	doc_15203423348_item	2245149	et	4	main
leheküljel	doc_15203423348_item	2245152	et	3	main
vene	doc_15203423348_item	2245159	et	4	main
sündis	doc_15203423348_item	2245161	et	3	main
kits	doc_15203423348_item	2245162	et	3	main
ta	doc_15203423348_item	2245176	et	4	main
tahtis	doc_15203423348_item	2245177	et	3	main
tappa	doc_15203423348_item	2245179	et	4	main
aga	doc_15203423348_item	2245180	et	3	main
andis	doc_15203423348_item	2245184	et	3	main
liitrit	doc_15203423348_item	2245189	et	3	main
see	doc_15203423348_item	2245195	et	3	main
külmatust	doc_15203423348_item	2245197	et	4	main
et	doc_15203423348_item	2245203	et	3	main
ei	doc_15203423348_item	2245211	et	4	main
järjekorrad	doc_15203423346_item	2244966	et	3	main
ema	doc_15203423346_item	2244968	et	4	main
põhjusel	doc_15203423346_item	2244976	et	3	main
ei	doc_15203423346_item	2244987	et	4	main
ma	doc_15203423346_item	2244990	et	3	main
see	doc_15203423346_item	2244993	et	3	main
kui	doc_15203423346_item	2245000	et	3	main
teeb	doc_15203423346_item	2245006	et	3	main
puudumine	doc_15203423346_item	2245015	et	4	main
on	doc_15203423346_item	2245019	et	4	main
kirjeldus	doc_15203423347_item	2245023	et	4	main
ma	doc_15203423347_item	2245024	et	3	main
linn	doc_15203423347_item	2245027	et	3	main
on	doc_15203423347_item	2245029	et	4	main
iganädalane	doc_15203423347_item	2245031	et	4	main
tasuta	doc_15203423347_item	2245032	et	4	main
kuusteist	doc_15203423347_item	2245036	et	4	main
leheküljeni	doc_15203423347_item	2245040	et	3	main
trükitud	doc_15203423347_item	2245042	et	4	main
uudised	doc_15203423347_item	2245043	et	3	main
eesti	doc_15203423347_item	2245044	et	4	main
ristsõna	doc_15203423347_item	2245054	et	4	main
kõige	doc_15203423347_item	2245060	et	4	main
viissada	doc_15203423347_item	2245064	et	4	main
kakssada	doc_15203423347_item	2245068	et	4	main
artiklit	doc_15203423347_item	2245101	et	3	main
pealkiri	doc_15203423348_item	2245119	et	3	main
kits	doc_15203423348_item	2245121	et	3	main
on	doc_15203423348_item	2245123	et	4	main
piima	doc_15203423348_item	2245127	et	4	main
ja	doc_15203423348_item	2245131	et	3	main
selle	doc_15203423348_item	2245132	et	4	main
autor	doc_15203423348_item	2245133	et	3	main
nvinner	doc_15203423348_item	2245135	et	4	main
artikli	doc_15203423348_item	2245136	et	3	main
asub	doc_15203423348_item	2245138	et	3	main
mustvalge	doc_15203423348_item	2245139	et	4	main
on	doc_15203423348_item	2245142	et	4	main
vana	doc_15203423348_item	2245146	et	4	main
kolmandal	doc_15203423348_item	2245151	et	3	main
on	doc_15203423348_item	2245155	et	4	main
kellel	doc_15203423348_item	2245164	et	4	main
on	doc_15203423348_item	2245165	et	4	main
umbes	doc_15203423348_item	2245187	et	4	main
ebatavaline	doc_15203423348_item	2245193	et	4	main
sest	doc_15203423348_item	2245194	et	4	main
raavib	doc_15203423348_item	2245196	et	4	main
see	doc_15203423348_item	2245204	et	3	main
huvitav	doc_15203423348_item	2245206	et	4	main
defektidega	doc_15203423348_item	2245210	et	3	main
on	doc_15203423348_item	2245226	et	4	main
lühike	doc_15203423348_item	2245227	et	4	main
ma	doc_15203423348_item	2245230	et	3	main
ei	doc_15203423348_item	2245231	et	4	main
on	doc_15203423348_item	2245240	et	4	main
lehekülge	doc_15203423347_item	2245037	et	4	main
koos	doc_15203423347_item	2245047	et	4	main
asub	doc_15203423347_item	2245053	et	3	main
võitjatele	doc_15203423347_item	2245057	et	4	main
auhinnad	doc_15203423347_item	2245059	et	3	main
auhind	doc_15203423347_item	2245062	et	3	main
krooni	doc_15203423347_item	2245065	et	4	main
sada	doc_15203423347_item	2245070	et	4	main
järgmistel	doc_15203423347_item	2245072	et	3	main
lehekülgedel	doc_15203423347_item	2245073	et	4	main
on	doc_15203423347_item	2245074	et	4	main
televisiooni	doc_15203423347_item	2245075	et	4	main
kava	doc_15203423347_item	2245076	et	4	main
kolmekümnendalt	doc_15203423347_item	2245077	et	3	main
novembrilt	doc_15203423347_item	2245078	et	3	main
viienda	doc_15203423347_item	2245079	et	3	main
detsembrini	doc_15203423347_item	2245080	et	3	main
kokku	doc_15203423347_item	2245081	et	3	main
kolmteist	doc_15203423347_item	2245082	et	4	main
kanalit	doc_15203423347_item	2245083	et	3	main
kaks	doc_15203423347_item	2245084	et	3	main
eestikeelset	doc_15203423347_item	2245085	et	3	main
ja	doc_15203423347_item	2245086	et	3	main
üksteist	doc_15203423347_item	2245087	et	4	main
venekeelset	doc_15203423347_item	2245088	et	3	main
viimastel	doc_15203423347_item	2245089	et	3	main
kahel	doc_15203423347_item	2245090	et	4	main
on	doc_15203423347_item	2245092	et	4	main
lehekülgedel	doc_15203423347_item	2245091	et	4	main
reklaam	doc_15203423347_item	2245093	et	3	main
ja	doc_15203423347_item	2245094	et	3	main
kasteist	doc_15203423347_item	2245095	et	4	main
kuulutust	doc_15203423347_item	2245096	et	4	main
ajalehes	doc_15203423347_item	2245097	et	3	main
on	doc_15203423347_item	2245098	et	4	main
kolmteist	doc_15203423347_item	2245111	et	4	main
kirjeldus	doc_15203423348_item	2245112	et	4	main
eesti	doc_15203423348_item	2245116	et	4	main
annab	doc_15203423348_item	2245126	et	3	main
ravib	doc_15203423348_item	2245129	et	3	main
inimesi	doc_15203423348_item	2245130	et	4	main
juures	doc_15203423348_item	2245137	et	4	main
artikkel	doc_15203423348_item	2245148	et	3	main
selles	doc_15203423348_item	2245156	et	4	main
ühes	doc_15203423348_item	2245158	et	4	main
maal	doc_15203423348_item	2245160	et	4	main
belka	doc_15203423348_item	2245163	et	4	main
on	doc_15203423348_item	2245170	et	4	main
lesk	doc_15203423348_item	2245172	et	3	main
zorina	doc_15203423348_item	2245174	et	4	main
alguses	doc_15203423348_item	2245175	et	4	main
ta	doc_15203423348_item	2245183	et	4	main
palju	doc_15203423348_item	2245185	et	4	main
piima	doc_15203423348_item	2245186	et	4	main
on	doc_15203423348_item	2245192	et	4	main
ja	doc_15203423348_item	2245198	et	3	main
närve	doc_15203423348_item	2245200	et	3	main
räägivad	doc_15203423348_item	2245202	et	3	main
on	doc_15203423348_item	2245205	et	4	main
juhtum	doc_15203423348_item	2245207	et	3	main
kerge	doc_15203423348_item	2245222	et	4	main
see	doc_15203423348_item	2245235	et	3	main
artikkel	doc_15203423348_item	2245236	et	3	main
mulle	doc_15203423348_item	2245238	et	4	main
tähtis	doc_15203423348_item	2245245	et	4	main
kellel	doc_15203423348_item	2245122	et	4	main
on	doc_15203423348_item	2245134	et	4	main
kits	doc_15203423348_item	2245144	et	3	main
trükitatud	doc_15203423348_item	2245150	et	4	main
artikli	doc_15203423348_item	2245153	et	3	main
et	doc_15203423348_item	2245157	et	3	main
sarve	doc_15203423348_item	2245167	et	4	main
seitsmekümneaastane	doc_15203423348_item	2245171	et	4	main
anna	doc_15203423348_item	2245173	et	4	main
õnnestus	doc_15203423348_item	2245182	et	4	main
piim	doc_15203423348_item	2245191	et	3	main
sest	doc_15203423348_item	2245208	et	4	main
ela	doc_15203423348_item	2245212	et	4	main
kaua	doc_15203423348_item	2245213	et	3	main
aga	doc_15203423348_item	2245214	et	3	main
belka	doc_15203423348_item	2245215	et	4	main
on	doc_15203423348_item	2245216	et	4	main
juba	doc_15203423348_item	2245217	et	3	main
neljaastane	doc_15203423348_item	2245218	et	4	main
seda	doc_15203423348_item	2245219	et	3	main
artiklit	doc_15203423348_item	2245220	et	3	main
lugeda	doc_15203423348_item	2245223	et	3	main
ja	doc_15203423348_item	2245228	et	3	main
saa	doc_15203423348_item	2245232	et	4	main
öelda	doc_15203423348_item	2245233	et	4	main
et	doc_15203423348_item	2245234	et	3	main
ei	doc_15203423348_item	2245243	et	4	main
et	doc_15203423351_item	2245483	et	3	main
psüühikaga	doc_15203423351_item	2245497	et	3	main
mitte	doc_15203423351_item	2245504	et	3	main
on	doc_15203423351_item	2245507	et	4	main
oli	doc_15203423348_item	2245221	et	3	main
sest	doc_15203423348_item	2245224	et	4	main
see	doc_15203423348_item	2245225	et	3	main
venekeelne	doc_15203423348_item	2245229	et	3	main
sest	doc_15203423348_item	2245239	et	4	main
ja	doc_15203423348_item	2245242	et	3	main
ole	doc_15203423348_item	2245244	et	4	main
võivad	doc_15203423351_item	2245487	et	4	main
näitlejaks	doc_15203423351_item	2245489	et	4	main
inimesed	doc_15203423351_item	2245506	et	3	main
niisugused	doc_15203423351_item	2245508	et	3	main
on	doc_15203423351_item	2245510	et	4	main
et	doc_15203423351_item	2245513	et	3	main
oma	doc_15203423351_item	2245516	et	4	main
inimesed	doc_15203423351_item	2245526	et	3	main
minu	doc_15203423351_item	2245527	et	3	main
on	doc_15203423351_item	2245529	et	4	main
babonina	doc_15203423351_item	2245531	et	4	main
on	doc_15203423351_item	2245545	et	4	main
elurõõmus	doc_15203423351_item	2245546	et	4	main
seesmiselt	doc_15203423351_item	2245552	et	4	main
suhelda	doc_15203423351_item	2245562	et	4	main
palju	doc_15203423351_item	2245563	et	4	main
räägivad	doc_15203423351_item	2245566	et	3	main
on	doc_15203423351_item	2245570	et	4	main
sis	doc_15203423351_item	2245575	et	3	main
olla	doc_15203423351_item	2245581	et	3	main
õpib	doc_15203423351_item	2245588	et	3	main
ja	doc_15203423351_item	2245591	et	3	main
temast	doc_15203423351_item	2245596	et	3	main
natuke	doc_15203423351_item	2245601	et	4	main
oma	doc_15203423351_item	2245603	et	4	main
iseloomu	doc_15203423351_item	2245604	et	4	main
oma	doc_15203423351_item	2245606	et	4	main
paremusele	doc_15203423351_item	2245608	et	4	main
et	doc_15203423351_item	2245614	et	3	main
ei	doc_15203423351_item	2245617	et	4	main
palju	doc_15203423351_item	2245625	et	4	main
viis	doc_15203423352_item	2245630	et	4	main
mida	doc_15203423352_item	2245632	et	4	main
kolivaheajal	doc_15203423352_item	2245634	et	3	main
sõit	doc_15203423352_item	2245636	et	3	main
leedusse	doc_15203423352_item	2245638	et	4	main
kõigepealt	doc_15203423352_item	2245639	et	3	main
tahaksin	doc_15203423352_item	2245641	et	3	main
kunstikoolide	doc_15203423352_item	2245647	et	3	main
meeldib	doc_15203423352_item	2245653	et	3	main
savist	doc_15203423352_item	2245656	et	4	main
arvates	doc_15203423352_item	2245659	et	4	main
oleks	doc_15203423352_item	2245661	et	3	main
veeta	doc_15203423352_item	2245669	et	4	main
sõit	doc_15203423352_item	2245714	et	3	main
õe	doc_15203423352_item	2245716	et	4	main
sõidan	doc_15203423352_item	2245724	et	3	main
seal	doc_15203423352_item	2245733	et	4	main
nädalat	doc_15203423352_item	2245735	et	3	main
ei	doc_15203423352_item	2245737	et	4	main
on	doc_15203423352_item	2245749	et	4	main
tutvusin	doc_15203423352_item	2245752	et	3	main
vene	doc_15203423352_item	2245764	et	4	main
loetelu	doc_15203423352_item	2245771	et	4	main
vaja	doc_15203423352_item	2245774	et	4	main
suplemine	doc_15203423352_item	2245783	et	4	main
näitleja	doc_15203423351_item	2245480	et	4	main
ainult	doc_15203423351_item	2245484	et	4	main
inimesed	doc_15203423351_item	2245486	et	3	main
kõik	doc_15203423351_item	2245490	et	4	main
inimesed	doc_15203423351_item	2245491	et	3	main
arvamus	doc_15203423351_item	2245475	et	3	main
inimesest	doc_15203423351_item	2245477	et	3	main
saada	doc_15203423351_item	2245479	et	4	main
ma	doc_15203423351_item	2245481	et	3	main
on	doc_15203423351_item	2245492	et	4	main
näitleja	doc_15203423351_item	2245498	et	4	main
huumorimeelne	doc_15203423351_item	2245503	et	3	main
hea	doc_15203423351_item	2245511	et	4	main
õppida	doc_15203423351_item	2245514	et	3	main
väike	doc_15203423351_item	2245535	et	4	main
teas	doc_15203423351_item	2245539	et	4	main
saab	doc_15203423351_item	2245542	et	3	main
ilus	doc_15203423351_item	2245548	et	4	main
väliselt	doc_15203423351_item	2245550	et	4	main
tähtis	doc_15203423351_item	2245555	et	4	main
et	doc_15203423351_item	2245567	et	3	main
võib	doc_15203423351_item	2245580	et	3	main
inimesel	doc_15203423351_item	2245583	et	3	main
suur	doc_15203423351_item	2245585	et	3	main
laulma	doc_15203423351_item	2245590	et	3	main
välimuse	doc_15203423351_item	2245594	et	3	main
me	doc_15203423351_item	2245599	et	4	main
muuta	doc_15203423351_item	2245602	et	4	main
pöörduda	doc_15203423351_item	2245609	et	3	main
ülalpool	doc_15203423351_item	2245611	et	3	main
näitab	doc_15203423351_item	2245613	et	3	main
näitlejaks	doc_15203423351_item	2245621	et	4	main
peab	doc_15203423351_item	2245624	et	4	main
töötama	doc_15203423351_item	2245626	et	3	main
õppima	doc_15203423351_item	2245628	et	3	main
plaanin	doc_15203423352_item	2245633	et	3	main
teha	doc_15203423352_item	2245635	et	3	main
laagri	doc_15203423352_item	2245637	et	3	main
ma	doc_15203423352_item	2245640	et	3	main
see	doc_15203423352_item	2245645	et	3	main
õpilastele	doc_15203423352_item	2245648	et	4	main
lihtsalt	doc_15203423352_item	2245650	et	4	main
inimestele	doc_15203423352_item	2245651	et	3	main
võib	doc_15203423352_item	2245664	et	3	main
uute	doc_15203423352_item	2245666	et	3	main
ja	doc_15203423352_item	2245668	et	3	main
ja	doc_15203423352_item	2245672	et	3	main
tema	doc_15203423352_item	2245725	et	4	main
tallinna	doc_15203423352_item	2245727	et	4	main
igal	doc_15203423352_item	2245729	et	3	main
olla	doc_15203423352_item	2245732	et	3	main
on	doc_15203423352_item	2245742	et	4	main
sõbrad	doc_15203423352_item	2245750	et	3	main
õpetaja	doc_15203423352_item	2245766	et	4	main
on	doc_15203423352_item	2245773	et	4	main
lugeda	doc_15203423352_item	2245775	et	3	main
paksu	doc_15203423352_item	2245776	et	4	main
raamatuid	doc_15203423352_item	2245777	et	3	main
oleks	doc_15203423352_item	2245781	et	3	main
õues	doc_15203423352_item	2245793	et	4	main
peab	doc_153483594920_item	2245811	et	4	main
mitte	doc_153483594920_item	2245822	et	3	main
on	doc_153483594920_item	2245835	et	4	main
see	doc_153483594920_item	2245849	et	3	main
kuritegelikule	doc_153483594920_item	2245853	et	3	main
mitte	doc_153483594920_item	2245856	et	3	main
võib	doc_153483594920_item	2245858	et	3	main
noortele	doc_153483594920_item	2245860	et	3	main
vaata	doc_153483594920_item	2245864	et	4	main
rohkem	doc_153483594920_item	2245868	et	4	main
politseinikke	doc_153483594920_item	2245871	et	3	main
on	doc_153483594920_item	2245874	et	4	main
vaja	doc_153483594921_item	2245913	et	4	main
neid	doc_153483594921_item	2245928	et	4	main
võtta	doc_153483594921_item	2245929	et	3	main
on	doc_153483594921_item	2245931	et	4	main
terve	doc_153483594921_item	2245934	et	4	main
eest	doc_153483594921_item	2245941	et	4	main
olema	doc_153483594921_item	2245949	et	4	main
edu	doc_153483594921_item	2245961	et	4	main
lugupeetud	doc_153483594922_item	2245964	et	4	main
ma	doc_153483594922_item	2245966	et	3	main
tänavas	doc_153483594922_item	2245974	et	4	main
föön	doc_153483594922_item	2245976	et	3	main
1500	doc_153483594922_item	2245979	et	2	main
ta	doc_153483594922_item	2245985	et	4	main
igast	doc_15203423351_item	2245476	et	3	main
võib	doc_15203423351_item	2245478	et	3	main
arvan	doc_15203423351_item	2245482	et	3	main
mõned	doc_15203423351_item	2245485	et	3	main
saada	doc_15203423351_item	2245488	et	4	main
ja	doc_15203423351_item	2245496	et	3	main
peab	doc_15203423351_item	2245499	et	4	main
olema	doc_15203423351_item	2245500	et	4	main
ja	doc_15203423351_item	2245502	et	3	main
näitlejatel	doc_15203423351_item	2245509	et	4	main
mälu	doc_15203423351_item	2245512	et	4	main
head	doc_15203423351_item	2245522	et	4	main
on	doc_15203423351_item	2245524	et	4	main
lemmiknäitleja	doc_15203423351_item	2245528	et	4	main
aljona	doc_15203423351_item	2245530	et	4	main
kui	doc_15203423351_item	2245532	et	3	main
juba	doc_15203423351_item	2245538	et	3	main
et	doc_15203423351_item	2245540	et	3	main
ja	doc_15203423351_item	2245547	et	3	main
nii	doc_15203423351_item	2245549	et	3	main
kui	doc_15203423351_item	2245551	et	3	main
töö	doc_15203423351_item	2245557	et	4	main
ajal	doc_15203423351_item	2245558	et	4	main
on	doc_15203423351_item	2245560	et	4	main
mõned	doc_15203423351_item	2245565	et	3	main
inimene	doc_15203423351_item	2245569	et	3	main
püüdlik	doc_15203423351_item	2245572	et	3	main
töökas	doc_15203423351_item	2245574	et	4	main
ta	doc_15203423351_item	2245576	et	4	main
kui	doc_15203423351_item	2245582	et	3	main
eest	doc_15203423351_item	2245595	et	4	main
saab	doc_15203423351_item	2245597	et	3	main
kõik	doc_15203423351_item	2245610	et	4	main
häid	doc_15203423351_item	2245615	et	3	main
ole	doc_15203423351_item	2245618	et	4	main
saada	doc_15203423351_item	2245622	et	4	main
inimene	doc_15203423351_item	2245623	et	3	main
sõita	doc_15203423352_item	2245642	et	3	main
joonistada	doc_15203423352_item	2245654	et	3	main
see	doc_15203423352_item	2245660	et	3	main
tutvuda	doc_15203423352_item	2245665	et	3	main
aega	doc_15203423352_item	2245670	et	4	main
rõõmsalt	doc_15203423352_item	2245671	et	4	main
hiline	doc_15203423352_item	2245674	et	4	main
üles	doc_15203423352_item	2245675	et	3	main
tallinnasse	doc_15203423352_item	2245715	et	3	main
juurde	doc_15203423352_item	2245717	et	4	main
erinevad	doc_15203423351_item	2245493	et	4	main
erineva	doc_15203423351_item	2245494	et	4	main
iseloomu	doc_15203423351_item	2245495	et	4	main
lahtine	doc_15203423351_item	2245501	et	3	main
kõik	doc_15203423351_item	2245505	et	4	main
pähe	doc_15203423351_item	2245515	et	4	main
rolli	doc_15203423351_item	2245517	et	4	main
tema	doc_15203423351_item	2245518	et	4	main
töö	doc_15203423351_item	2245519	et	4	main
on	doc_15203423351_item	2245520	et	4	main
raske	doc_15203423351_item	2245521	et	4	main
näitlejad	doc_15203423351_item	2245523	et	4	main
andekad	doc_15203423351_item	2245525	et	3	main
ta	doc_15203423351_item	2245533	et	4	main
tüdruk	doc_15203423351_item	2245536	et	3	main
temast	doc_15203423351_item	2245541	et	3	main
aljona	doc_15203423351_item	2245544	et	4	main
on	doc_15203423351_item	2245554	et	4	main
sest	doc_15203423351_item	2245556	et	4	main
tal	doc_15203423351_item	2245559	et	3	main
vaja	doc_15203423351_item	2245561	et	4	main
kui	doc_15203423351_item	2245568	et	3	main
kannatlik	doc_15203423351_item	2245571	et	3	main
ta	doc_15203423351_item	2245587	et	4	main
hoolitseb	doc_15203423351_item	2245592	et	3	main
oma	doc_15203423351_item	2245593	et	4	main
võime	doc_15203423351_item	2245600	et	4	main
öeldu	doc_15203423351_item	2245612	et	4	main
andeid	doc_15203423351_item	2245616	et	3	main
oli	doc_15203423351_item	2245534	et	3	main
ta	doc_15203423351_item	2245537	et	4	main
täht	doc_15203423351_item	2245543	et	3	main
see	doc_15203423351_item	2245553	et	3	main
inimestega	doc_15203423351_item	2245564	et	3	main
ja	doc_15203423351_item	2245573	et	3	main
alati	doc_15203423351_item	2245577	et	4	main
taotleb	doc_15203423351_item	2245578	et	3	main
edu	doc_15203423351_item	2245579	et	4	main
on	doc_15203423351_item	2245584	et	4	main
soov	doc_15203423351_item	2245586	et	3	main
tantsima	doc_15203423351_item	2245589	et	3	main
näitleja	doc_15203423351_item	2245598	et	4	main
treenida	doc_15203423351_item	2245605	et	3	main
mälu	doc_15203423351_item	2245607	et	4	main
piisav	doc_15203423351_item	2245619	et	4	main
et	doc_15203423351_item	2245620	et	3	main
ja	doc_15203423351_item	2245627	et	3	main
kirjeldus	doc_15203423352_item	2245629	et	4	main
tegevust	doc_15203423352_item	2245631	et	4	main
leedusse	doc_15203423352_item	2245644	et	4	main
lager	doc_15203423352_item	2245646	et	4	main
kellele	doc_15203423352_item	2245652	et	4	main
minu	doc_15203423352_item	2245658	et	3	main
tore	doc_15203423352_item	2245662	et	3	main
kasulikult	doc_15203423352_item	2245673	et	4	main
tõusmine	doc_15203423352_item	2245676	et	4	main
veel	doc_15203423352_item	2245718	et	4	main
plaanin	doc_15203423352_item	2245719	et	3	main
külastada	doc_15203423352_item	2245720	et	3	main
oma	doc_15203423352_item	2245721	et	4	main
ma	doc_15203423352_item	2245723	et	3	main
vaheajal	doc_15203423352_item	2245730	et	3	main
igav	doc_15203423352_item	2245740	et	3	main
palju	doc_15203423352_item	2245744	et	4	main
tegevusi	doc_15203423352_item	2245746	et	4	main
mul	doc_15203423352_item	2245748	et	3	main
kellega	doc_15203423352_item	2245751	et	3	main
andis	doc_15203423352_item	2245767	et	3	main
et	doc_15203423352_item	2245778	et	3	main
igal	doc_15203423352_item	2245790	et	3	main
on	doc_15203423352_item	2245798	et	4	main
meres	doc_15203423352_item	2245800	et	3	main
iga	doc_153483594920_item	2245809	et	4	main
kuritegude	doc_153483594920_item	2245814	et	3	main
eest	doc_153483594920_item	2245815	et	4	main
inimene	doc_153483594920_item	2245817	et	3	main
võib	doc_153483594920_item	2245818	et	3	main
korterisse	doc_153483594920_item	2245820	et	3	main
kurjategijatel	doc_153483594920_item	2245828	et	3	main
geneetiline	doc_153483594920_item	2245830	et	3	main
ebanormaalne	doc_153483594920_item	2245836	et	3	main
kõigidel	doc_153483594920_item	2245842	et	4	main
on	doc_153483594920_item	2245844	et	4	main
kooliharidusest	doc_153483594920_item	2245847	et	4	main
sõltub	doc_153483594920_item	2245848	et	3	main
ei	doc_153483594920_item	2245863	et	4	main
mida	doc_153483594920_item	2245867	et	4	main
seda	doc_153483594920_item	2245872	et	3	main
elu	doc_153483594920_item	2245875	et	4	main
sest	doc_153483594921_item	2245910	et	4	main
on	doc_153483594921_item	2245912	et	4	main
rohkem	doc_153483594921_item	2245914	et	4	main
vabaaega	doc_153483594921_item	2245915	et	4	main
laagri	doc_15203423352_item	2245643	et	3	main
ja	doc_15203423352_item	2245649	et	3	main
ja	doc_15203423352_item	2245655	et	3	main
voolida	doc_15203423352_item	2245657	et	3	main
reis	doc_15203423352_item	2245663	et	4	main
inimestega	doc_15203423352_item	2245667	et	3	main
see	doc_15203423352_item	2245677	et	3	main
punkt	doc_15203423352_item	2245678	et	4	main
on	doc_15203423352_item	2245679	et	4	main
väga	doc_15203423352_item	2245680	et	3	main
tähtis	doc_15203423352_item	2245681	et	4	main
minu	doc_15203423352_item	2245682	et	3	main
jaoks	doc_15203423352_item	2245683	et	4	main
sest	doc_15203423352_item	2245684	et	4	main
ma	doc_15203423352_item	2245685	et	3	main
olen	doc_15203423352_item	2245686	et	3	main
nagu	doc_15203423352_item	2245687	et	3	main
mul	doc_15203423352_item	2245689	et	3	main
öökull	doc_15203423352_item	2245688	et	3	main
on	doc_15203423352_item	2245690	et	4	main
mugav	doc_15203423352_item	2245691	et	3	main
magama	doc_15203423352_item	2245692	et	3	main
minna	doc_15203423352_item	2245693	et	3	main
hiljemini	doc_15203423352_item	2245694	et	3	main
öösel	doc_15203423352_item	2245695	et	4	main
kell	doc_15203423352_item	2245696	et	3	main
kolm	doc_15203423352_item	2245697	et	3	main
või	doc_15203423352_item	2245698	et	4	main
neli	doc_15203423352_item	2245699	et	3	main
kooliajal	doc_15203423352_item	2245700	et	3	main
on	doc_15203423352_item	2245701	et	4	main
raske	doc_15203423352_item	2245702	et	4	main
üles	doc_15203423352_item	2245703	et	3	main
tõusta	doc_15203423352_item	2245704	et	4	main
aga	doc_15203423352_item	2245705	et	3	main
vaheajal	doc_15203423352_item	2245706	et	3	main
on	doc_15203423352_item	2245707	et	4	main
võimalus	doc_15203423352_item	2245708	et	3	main
magada	doc_15203423352_item	2245709	et	3	main
nii	doc_15203423352_item	2245710	et	3	main
kaua	doc_15203423352_item	2245711	et	3	main
kui	doc_15203423352_item	2245712	et	3	main
tahad	doc_15203423352_item	2245713	et	3	main
õde	doc_15203423352_item	2245722	et	4	main
plaanin	doc_15203423352_item	2245731	et	3	main
paar	doc_15203423352_item	2245734	et	3	main
nii	doc_15203423352_item	2245743	et	3	main
igasuguseid	doc_15203423352_item	2245745	et	3	main
internetis	doc_15203423352_item	2245753	et	4	main
olen	doc_15203423352_item	2245754	et	3	main
kindel	doc_15203423352_item	2245755	et	3	main
et	doc_15203423352_item	2245756	et	3	main
puhkan	doc_15203423352_item	2245757	et	3	main
tallinnas	doc_15203423352_item	2245758	et	4	main
hästi	doc_15203423352_item	2245759	et	3	main
raamatuid	doc_15203423352_item	2245760	et	3	main
lugemine	doc_15203423352_item	2245761	et	4	main
suveks	doc_15203423352_item	2245762	et	3	main
meie	doc_15203423352_item	2245763	et	4	main
juurde	doc_15203423352_item	2245726	et	4	main
praktiliselt	doc_15203423352_item	2245728	et	4	main
tallinnas	doc_15203423352_item	2245736	et	4	main
ole	doc_15203423352_item	2245738	et	4	main
kunagi	doc_15203423352_item	2245739	et	3	main
ja	doc_15203423352_item	2245741	et	3	main
seal	doc_15203423352_item	2245747	et	4	main
keele	doc_15203423352_item	2245765	et	4	main
meile	doc_15203423352_item	2245768	et	4	main
suurt	doc_15203423352_item	2245769	et	3	main
üheteistkümnendas	doc_15203423352_item	2245779	et	4	main
klassis	doc_15203423352_item	2245780	et	3	main
kergem	doc_15203423352_item	2245782	et	4	main
meres	doc_15203423352_item	2245784	et	3	main
see	doc_15203423352_item	2245785	et	3	main
minu	doc_15203423352_item	2245787	et	3	main
soov	doc_15203423352_item	2245789	et	3	main
toredam	doc_15203423352_item	2245797	et	4	main
ujuda	doc_15203423352_item	2245799	et	3	main
süüa	doc_15203423352_item	2245804	et	3	main
väited	doc_153483594920_item	2245806	et	3	main
inimene	doc_153483594920_item	2245810	et	3	main
ennast	doc_153483594920_item	2245812	et	4	main
ise	doc_153483594920_item	2245813	et	4	main
panna	doc_153483594920_item	2245819	et	4	main
raamatud	doc_15203423352_item	2245770	et	4	main
sellepärast	doc_15203423352_item	2245772	et	3	main
on	doc_15203423352_item	2245786	et	4	main
kui	doc_15203423352_item	2245792	et	3	main
on	doc_15203423352_item	2245794	et	4	main
kõige	doc_15203423352_item	2245796	et	4	main
päevitada	doc_15203423352_item	2245801	et	3	main
ja	doc_15203423352_item	2245803	et	3	main
kohta	doc_153483594920_item	2245808	et	4	main
signalisatsiooni	doc_153483594920_item	2245821	et	4	main
kõigidel	doc_153483594920_item	2245823	et	4	main
on	doc_153483594920_item	2245824	et	4	main
seda	doc_153483594920_item	2245826	et	3	main
kuritegevusele	doc_153483594920_item	2245832	et	4	main
see	doc_153483594920_item	2245833	et	3	main
ja	doc_153483594920_item	2245837	et	3	main
lapsepõlvest	doc_153483594920_item	2245840	et	4	main
kuritegijadel	doc_153483594920_item	2245843	et	4	main
kas	doc_153483594920_item	2245850	et	3	main
lähevad	doc_153483594920_item	2245852	et	3	main
või	doc_153483594920_item	2245855	et	4	main
mõjuda	doc_153483594920_item	2245859	et	3	main
on	doc_153483594920_item	2245869	et	4	main
riigis	doc_153483594920_item	2245870	et	3	main
olen	doc_153483594920_item	2245876	et	3	main
on	doc_153483594921_item	2245917	et	4	main
õpikud	doc_153483594921_item	2245920	et	3	main
koju	doc_153483594921_item	2245925	et	3	main
luba	doc_153483594921_item	2245927	et	4	main
kolmas	doc_153483594921_item	2245930	et	3	main
selle	doc_153483594921_item	2245940	et	4	main
vastutavaks	doc_153483594921_item	2245942	et	4	main
määran	doc_153483594921_item	2245943	et	3	main
tegevused	doc_153483594921_item	2245947	et	4	main
15	doc_153483594921_item	2245952	et	2	main
tähelepanu	doc_153483594921_item	2245956	et	4	main
kaebus	doc_153483594922_item	2245963	et	3	main
teie	doc_153483594922_item	2245971	et	4	main
viru	doc_153483594922_item	2245973	et	4	main
20	doc_153483594922_item	2245975	et	2	main
eesnimi	doc_153483594923_item	2245995	et	3	main
taamsaare	doc_153483594923_item	2245997	et	4	main
tallinn	doc_153483594923_item	2245999	et	4	main
03	doc_153483594923_item	2246002	et	2	main
p	doc_153483594923_item	2246003	et	4	main
autoga	doc_153483594923_item	2246006	et	3	main
ja	doc_153483594923_item	2246008	et	3	main
millal	doc_153483594923_item	2246020	et	3	main
rääkisin	doc_153483594923_item	2246022	et	3	main
auto	doc_153483594923_item	2246024	et	4	main
b	doc_153483594923_item	2246033	et	4	main
vaadata	doc_153483594923_item	2246037	et	4	main
kas	doc_153483594924_item	2246044	et	3	main
kas	doc_153483594924_item	2246049	et	3	main
peavad	doc_153483594924_item	2246051	et	4	main
selline	doc_153483594924_item	2246056	et	4	main
kui	doc_153483594924_item	2246058	et	3	main
on	doc_153483594924_item	2246060	et	4	main
taskuraha	doc_153483594924_item	2246070	et	4	main
et	doc_153483594924_item	2246079	et	3	main
aitab	doc_153483594924_item	2246116	et	3	main
edasi	doc_153483594924_item	2246120	et	3	main
õpivad	doc_153483594924_item	2246126	et	3	main
moraalselt	doc_153483594924_item	2246133	et	4	main
füüsiliselt	doc_153483594924_item	2246135	et	4	main
olevad	doc_153483594924_item	2246159	et	4	main
või	doc_153483594924_item	2246163	et	4	main
tundi	doc_153483594924_item	2246165	et	4	main
töödistsipliinit	doc_153483594924_item	2246169	et	4	main
kui	doc_153483594924_item	2246170	et	3	main
võivad	doc_153483594924_item	2246175	et	4	main
harjumusi	doc_153483594924_item	2246178	et	4	main
lapsed	doc_153483594924_item	2246180	et	3	main
kerge	doc_153483594924_item	2246182	et	4	main
ma	doc_153483594924_item	2246191	et	3	main
töötada	doc_153483594924_item	2246194	et	3	main
laps	doc_153483594924_item	2246198	et	4	main
vanematega	doc_153483594924_item	2246202	et	4	main
see	doc_153483594925_item	2246230	et	3	main
kohutav	doc_153483594925_item	2246232	et	4	main
et	doc_153483594925_item	2246233	et	3	main
inimene	doc_153483594925_item	2246234	et	3	main
tavaline	doc_15203423352_item	2245788	et	4	main
suvel	doc_15203423352_item	2245791	et	3	main
palav	doc_15203423352_item	2245795	et	4	main
rannas	doc_15203423352_item	2245802	et	3	main
jäätist	doc_15203423352_item	2245805	et	3	main
kuritegevuse	doc_153483594920_item	2245807	et	4	main
kaitsma	doc_153483594920_item	2245816	et	3	main
raha	doc_153483594920_item	2245825	et	4	main
on	doc_153483594920_item	2245829	et	4	main
soodumus	doc_153483594920_item	2245831	et	3	main
see	doc_153483594920_item	2245838	et	3	main
on	doc_153483594920_item	2245839	et	4	main
mitte	doc_153483594920_item	2245841	et	3	main
geneetiline	doc_153483594920_item	2245845	et	3	main
kooliharidus	doc_153483594920_item	2245857	et	3	main
vanemad	doc_153483594920_item	2245862	et	4	main
eest	doc_153483594920_item	2245866	et	4	main
turvalisem	doc_153483594920_item	2245873	et	4	main
tel	doc_153483594921_item	2245911	et	4	main
see	doc_153483594921_item	2245918	et	3	main
peab	doc_153483594921_item	2245921	et	4	main
koolis	doc_153483594921_item	2245923	et	4	main
kaasa	doc_153483594921_item	2245924	et	4	main
et	doc_153483594921_item	2245933	et	3	main
klass	doc_153483594921_item	2245935	et	3	main
valida	doc_153483594921_item	2245937	et	3	main
õpetajaid	doc_153483594921_item	2245939	et	4	main
xxx	doc_153483594921_item	2245944	et	4	main
kavandatavat	doc_153483594921_item	2245946	et	4	main
peavad	doc_153483594921_item	2245948	et	4	main
12	doc_153483594921_item	2245953	et	2	main
tänan	doc_153483594921_item	2245955	et	3	main
eest	doc_153483594921_item	2245957	et	4	main
ja	doc_153483594921_item	2245958	et	3	main
soovin	doc_153483594921_item	2245959	et	3	main
03	doc_153483594922_item	2245970	et	2	main
maksab	doc_153483594922_item	2245978	et	3	main
25	doc_153483594922_item	2245982	et	2	main
seletuskiri	doc_153483594923_item	2245994	et	3	main
26	doc_153483594923_item	2246000	et	2	main
distantsiooni	doc_153483594923_item	2246011	et	4	main
c	doc_153483594923_item	2246014	et	4	main
b	doc_153483594923_item	2246025	et	4	main
auto	doc_153483594923_item	2246030	et	4	main
töötama	doc_153483594924_item	2246048	et	3	main
suvi	doc_153483594924_item	2246054	et	3	main
töötada	doc_153483594924_item	2246067	et	3	main
veada	doc_153483594924_item	2246073	et	4	main
aega	doc_153483594924_item	2246074	et	4	main
on	doc_153483594924_item	2246075	et	4	main
poolt	doc_153483594924_item	2246076	et	4	main
tööd	doc_153483594924_item	2246080	et	4	main
aitavad	doc_153483594924_item	2246081	et	4	main
distsiplineeritud	doc_153483594924_item	2246114	et	4	main
lapsell	doc_153483594924_item	2246117	et	3	main
kuhu	doc_153483594924_item	2246119	et	3	main
õppida	doc_153483594924_item	2246122	et	3	main
pool	doc_153483594924_item	2246124	et	4	main
lapsed	doc_153483594924_item	2246125	et	3	main
nad	doc_153483594924_item	2246131	et	3	main
väsivad	doc_153483594924_item	2246132	et	4	main
terve	doc_153483594924_item	2246142	et	4	main
et	doc_153483594924_item	2246144	et	3	main
tuleks	doc_153483594924_item	2246146	et	4	main
depressiooni	doc_153483594924_item	2246147	et	4	main
tingimustega	doc_153483594924_item	2246155	et	3	main
ei	doc_153483594924_item	2246158	et	4	main
25	doc_153483594924_item	2246162	et	2	main
inimestega	doc_153483594924_item	2246174	et	3	main
kui	doc_153483594924_item	2246179	et	3	main
teenivad	doc_153483594924_item	2246181	et	4	main
nad	doc_153483594924_item	2246185	et	3	main
taha	doc_153483594924_item	2246187	et	4	main
rohkem	doc_153483594924_item	2246188	et	4	main
kas	doc_153483594924_item	2246193	et	3	main
otsustama	doc_153483594924_item	2246200	et	3	main
teha	doc_153483594920_item	2245827	et	3	main
inimene	doc_153483594920_item	2245834	et	3	main
soodumus	doc_153483594920_item	2245846	et	3	main
noored	doc_153483594920_item	2245851	et	3	main
teele	doc_153483594920_item	2245854	et	3	main
tihti	doc_153483594920_item	2245861	et	3	main
lapse	doc_153483594920_item	2245865	et	4	main
sellega	doc_153483594920_item	2245877	et	3	main
nõus	doc_153483594920_item	2245878	et	4	main
aga	doc_153483594920_item	2245879	et	3	main
neid	doc_153483594920_item	2245880	et	4	main
peavad	doc_153483594920_item	2245881	et	4	main
olema	doc_153483594920_item	2245882	et	4	main
aused	doc_153483594920_item	2245883	et	4	main
palju	doc_153483594920_item	2245884	et	4	main
politseinikud	doc_153483594920_item	2245885	et	4	main
võtavad	doc_153483594920_item	2245886	et	3	main
altkäemaksad	doc_153483594920_item	2245887	et	3	main
direktori	doc_153483594921_item	2245888	et	3	main
kõne	doc_153483594921_item	2245889	et	4	main
tere	doc_153483594921_item	2245890	et	3	main
austatud	doc_153483594921_item	2245891	et	4	main
kuulajad	doc_153483594921_item	2245892	et	4	main
täna	doc_153483594921_item	2245893	et	4	main
on	doc_153483594921_item	2245894	et	4	main
siia	doc_153483594921_item	2245895	et	4	main
kogunenud	doc_153483594921_item	2245896	et	4	main
et	doc_153483594921_item	2245897	et	3	main
te	doc_153483594921_item	2245898	et	4	main
teate	doc_153483594921_item	2245899	et	4	main
uusi	doc_153483594921_item	2245900	et	3	main
muudatusi	doc_153483594921_item	2245901	et	3	main
esimene	doc_153483594921_item	2245902	et	3	main
on	doc_153483594921_item	2245903	et	4	main
see	doc_153483594921_item	2245904	et	3	main
rohkem	doc_153483594921_item	2245905	et	4	main
koduülesandeid	doc_153483594921_item	2245906	et	3	main
me	doc_153483594921_item	2245907	et	4	main
ei	doc_153483594921_item	2245908	et	4	main
anta	doc_153483594921_item	2245909	et	3	main
teine	doc_153483594921_item	2245916	et	3	main
kõik	doc_153483594921_item	2245919	et	4	main
see	doc_153483594921_item	2245932	et	3	main
xxxx	doc_153483594921_item	2245945	et	4	main
ollu	doc_153483594921_item	2245950	et	4	main
teile	doc_153483594921_item	2245960	et	4	main
kaebus	doc_153483594922_item	2245962	et	3	main
ostsin	doc_153483594922_item	2245967	et	3	main
11	doc_153483594922_item	2245969	et	2	main
eile	doc_153483594922_item	2245981	et	3	main
03	doc_153483594922_item	2245984	et	2	main
läks	doc_153483594922_item	2245986	et	3	main
ma	doc_153483594922_item	2245988	et	3	main
saada	doc_153483594922_item	2245990	et	4	main
kaupluselt	doc_153483594922_item	2245992	et	3	main
tagasi	doc_153483594922_item	2245993	et	3	main
sõidan	doc_153483594923_item	2246005	et	3	main
c	doc_153483594923_item	2246007	et	4	main
autode	doc_153483594923_item	2246015	et	3	main
ühel	doc_153483594923_item	2246018	et	3	main
olema	doc_153483594921_item	2245922	et	4	main
ei	doc_153483594921_item	2245926	et	4	main
võib	doc_153483594921_item	2245936	et	3	main
kooli	doc_153483594921_item	2245938	et	4	main
viidud	doc_153483594921_item	2245951	et	4	main
03	doc_153483594921_item	2245954	et	2	main
ak	doc_153483594922_item	2245965	et	4	main
10	doc_153483594922_item	2245968	et	2	main
kauplusest	doc_153483594922_item	2245972	et	4	main
ta	doc_153483594922_item	2245977	et	4	main
krooni	doc_153483594922_item	2245980	et	4	main
11	doc_153483594922_item	2245983	et	2	main
katki	doc_153483594922_item	2245987	et	4	main
raha	doc_153483594922_item	2245991	et	4	main
perekonnanimi	doc_153483594923_item	2245996	et	3	main
ma	doc_153483594923_item	2246004	et	3	main
ei	doc_153483594923_item	2246009	et	4	main
b	doc_153483594923_item	2246012	et	4	main
vahel	doc_153483594923_item	2246016	et	4	main
pidurdas	doc_153483594923_item	2246027	et	3	main
minu	doc_153483594923_item	2246029	et	3	main
ma	doc_153483594923_item	2246034	et	3	main
juhtus	doc_153483594923_item	2246039	et	3	main
auto	doc_153483594923_item	2246040	et	4	main
vigastas	doc_153483594923_item	2246042	et	3	main
jalgraturi	doc_153483594923_item	2246043	et	4	main
lapsed	doc_153483594924_item	2246045	et	3	main
suvel	doc_153483594924_item	2246052	et	3	main
on	doc_153483594924_item	2246055	et	4	main
lapsel	doc_153483594924_item	2246059	et	4	main
palju	doc_153483594924_item	2246061	et	4	main
vaba	doc_153483594924_item	2246062	et	4	main
aega	doc_153483594924_item	2246063	et	4	main
mõned	doc_153483594924_item	2246064	et	3	main
lapsed	doc_153483594924_item	2246065	et	3	main
tahavad	doc_153483594924_item	2246066	et	3	main
ja	doc_153483594924_item	2246071	et	3	main
töö	doc_153483594924_item	2246115	et	4	main
otsustama	doc_153483594924_item	2246118	et	3	main
teisel	doc_153483594924_item	2246123	et	4	main
õppeaasta	doc_153483594924_item	2246128	et	4	main
üheksa	doc_153483594924_item	2246129	et	4	main
kuud	doc_153483594924_item	2246130	et	4	main
nendel	doc_153483594924_item	2246136	et	4	main
vaja	doc_153483594924_item	2246138	et	4	main
olla	doc_153483594924_item	2246141	et	3	main
ja	doc_153483594924_item	2246143	et	3	main
ei	doc_153483594924_item	2246145	et	4	main
olla	doc_153483594924_item	2246150	et	3	main
huvitamatu	doc_153483594924_item	2246152	et	4	main
paha	doc_153483594924_item	2246154	et	4	main
lapsed	doc_153483594924_item	2246157	et	3	main
töötada	doc_153483594924_item	2246161	et	3	main
tea	doc_153483594924_item	2246168	et	4	main
halbu	doc_153483594924_item	2246177	et	3	main
õppida	doc_153483594924_item	2246189	et	3	main
kokkuvõttes	doc_153483594924_item	2246190	et	3	main
suvel	doc_153483594924_item	2246195	et	3	main
mitte	doc_153483594924_item	2246197	et	3	main
et	doc_153483594925_item	2246224	et	3	main
kõige	doc_153483594925_item	2246227	et	4	main
haiguse	doc_153483594925_item	2246239	et	4	main
toitumine	doc_153483594925_item	2246245	et	4	main
ja	doc_153483594925_item	2246253	et	3	main
saan	doc_153483594925_item	2246254	et	4	main
on	doc_153483594925_item	2246259	et	4	main
väga	doc_153483594925_item	2246261	et	3	main
ei	doc_153483594925_item	2246266	et	4	main
selline	doc_153483594925_item	2246268	et	4	main
suitsetamist	doc_153483594925_item	2246281	et	4	main
see	doc_153483594925_item	2246282	et	3	main
mõjutab	doc_153483594925_item	2246286	et	3	main
oska	doc_153483594925_item	2246291	et	4	main
ja	doc_153483594925_item	2246294	et	3	main
kõik	doc_153483594925_item	2246296	et	4	main
meie	doc_153483594925_item	2246297	et	4	main
tööintervjuuks	doc_153483594926_item	2246300	et	3	main
pole	doc_153483594926_item	2246301	et	3	main
ole	doc_153483594926_item	2246306	et	4	main
soovin	doc_153483594922_item	2245989	et	3	main
77-88br	doc_153483594923_item	2245998	et	4	main
11	doc_153483594923_item	2246001	et	2	main
hoidanud	doc_153483594923_item	2246010	et	4	main
ja	doc_153483594923_item	2246013	et	3	main
ja	doc_153483594923_item	2246017	et	3	main
momendil	doc_153483594923_item	2246019	et	3	main
ma	doc_153483594923_item	2246021	et	3	main
mobelega	doc_153483594923_item	2246023	et	4	main
väljutasin	doc_153483594923_item	2246035	et	3	main
peavad	doc_153483594924_item	2246046	et	4	main
aeg	doc_153483594924_item	2246057	et	3	main
teenida	doc_153483594924_item	2246069	et	3	main
kasulikult	doc_153483594924_item	2246072	et	4	main
siin	doc_153483594924_item	2246077	et	4	main
see	doc_153483594924_item	2246078	et	3	main
ja	doc_153483594924_item	2246134	et	3	main
puhata	doc_153483594924_item	2246139	et	4	main
töö	doc_153483594924_item	2246148	et	4	main
raske	doc_153483594924_item	2246151	et	4	main
tervistkahjustav	doc_153483594924_item	2246153	et	3	main
mõned	doc_153483594924_item	2246156	et	3	main
30	doc_153483594924_item	2246164	et	2	main
nädalas	doc_153483594924_item	2246166	et	3	main
ei	doc_153483594924_item	2246167	et	4	main
töötavad	doc_153483594924_item	2246171	et	4	main
koos	doc_153483594924_item	2246172	et	4	main
omandada	doc_153483594924_item	2246176	et	3	main
raha	doc_153483594924_item	2246184	et	4	main
või	doc_153483594924_item	2246196	et	4	main
koos	doc_153483594924_item	2246201	et	4	main
pärilikkust	doc_153483594925_item	2246221	et	4	main
kannatab	doc_153483594925_item	2246235	et	3	main
veel	doc_153483594925_item	2246241	et	4	main
kui	doc_153483594925_item	2246249	et	3	main
haige	doc_153483594925_item	2246252	et	4	main
kiiresti	doc_153483594925_item	2246255	et	3	main
meil	doc_153483594925_item	2246265	et	4	main
on	doc_153483594925_item	2246275	et	4	main
meie	doc_153483594925_item	2246287	et	4	main
haigused	doc_153483594925_item	2246298	et	4	main
vaja	doc_153483594926_item	2246302	et	4	main
nõus	doc_153483594926_item	2246307	et	4	main
lakoonilised	doc_153483594926_item	2246332	et	3	main
et	doc_153483594926_item	2246337	et	3	main
lakoonilised	doc_153483594926_item	2246345	et	3	main
ise	doc_153483594926_item	2246352	et	4	main
ja	doc_153483594926_item	2246356	et	3	main
aitavad	doc_153483594926_item	2246359	et	4	main
leida	doc_153483594926_item	2246361	et	3	main
riietus	doc_153483594926_item	2246370	et	4	main
annavad	doc_153483594926_item	2246374	et	3	main
plusid	doc_153483594926_item	2246375	et	4	main
soovib	doc_153483594926_item	2246377	et	3	main
peaks	doc_153483594926_item	2246381	et	4	main
kui	doc_153483594926_item	2246388	et	3	main
enast	doc_153483594926_item	2246392	et	4	main
kus	doc_153483594926_item	2246398	et	3	main
peab	doc_153483594926_item	2246424	et	4	main
et	doc_153483594926_item	2246429	et	3	main
millist	doc_153483594926_item	2246444	et	3	main
tarbijakaitseamet	doc_153483594926_item	2246447	et	3	main
on	doc_153483594926_item	2246452	et	4	main
suuremad	doc_153483594926_item	2246456	et	4	main
probleemid	doc_153483594926_item	2246457	et	3	main
ei	doc_153483594926_item	2246472	et	4	main
soovi	doc_153483594926_item	2246473	et	4	main
selle	doc_153483594926_item	2246476	et	4	main
need	doc_153483594926_item	2246481	et	3	main
ei	doc_153483594926_item	2246483	et	4	main
erineb	doc_153483594926_item	2246489	et	3	main
kõrgkoolis	doc_153483594926_item	2246490	et	4	main
erinevad	doc_153483594926_item	2246498	et	4	main
ained	doc_153483594926_item	2246499	et	3	main
aga	doc_153483594926_item	2246500	et	3	main
mida	doc_153483594926_item	2246505	et	4	main
mida	doc_153483594926_item	2246510	et	4	main
taha	doc_153483594926_item	2246512	et	4	main
peaks	doc_153483594926_item	2246514	et	4	main
inimene	doc_153483594926_item	2246515	et	3	main
tegema	doc_153483594926_item	2246516	et	3	main
järsult	doc_153483594923_item	2246026	et	4	main
ja	doc_153483594923_item	2246028	et	3	main
miklis	doc_153483594923_item	2246031	et	4	main
autot	doc_153483594923_item	2246032	et	3	main
autost	doc_153483594923_item	2246036	et	3	main
mis	doc_153483594923_item	2246038	et	4	main
b	doc_153483594923_item	2246041	et	4	main
suvel	doc_153483594924_item	2246047	et	3	main
lapsed	doc_153483594924_item	2246050	et	3	main
töötama	doc_153483594924_item	2246053	et	3	main
et	doc_153483594924_item	2246068	et	3	main
lastele	doc_153483594924_item	2246082	et	4	main
saada	doc_153483594924_item	2246083	et	4	main
kui	doc_153483594924_item	2246084	et	3	main
raskelt	doc_153483594924_item	2246085	et	4	main
vanemad	doc_153483594924_item	2246086	et	4	main
teenevad	doc_153483594924_item	2246087	et	4	main
raha	doc_153483594924_item	2246088	et	4	main
nad	doc_153483594924_item	2246089	et	3	main
näevad	doc_153483594924_item	2246090	et	3	main
kust	doc_153483594924_item	2246091	et	4	main
ja	doc_153483594924_item	2246092	et	3	main
kuidas	doc_153483594924_item	2246093	et	3	main
tuleb	doc_153483594924_item	2246094	et	3	main
raha	doc_153483594924_item	2246095	et	4	main
ja	doc_153483594924_item	2246096	et	3	main
õpivad	doc_153483594924_item	2246097	et	3	main
teda	doc_153483594924_item	2246098	et	4	main
õigesti	doc_153483594924_item	2246099	et	3	main
kulutama	doc_153483594924_item	2246100	et	4	main
lapsed	doc_153483594924_item	2246101	et	3	main
õpivad	doc_153483594924_item	2246102	et	3	main
uued	doc_153483594924_item	2246103	et	3	main
erialad	doc_153483594924_item	2246104	et	3	main
püüavad	doc_153483594924_item	2246105	et	3	main
töötama	doc_153483594924_item	2246106	et	3	main
iseseisvalt	doc_153483594924_item	2246107	et	4	main
tunnevad	doc_153483594924_item	2246108	et	3	main
rohkem	doc_153483594924_item	2246110	et	4	main
ennast	doc_153483594924_item	2246109	et	4	main
täiskasvanuna	doc_153483594924_item	2246111	et	3	main
õpivad	doc_153483594924_item	2246112	et	3	main
olema	doc_153483594924_item	2246113	et	4	main
minna	doc_153483594924_item	2246121	et	3	main
terve	doc_153483594924_item	2246127	et	4	main
on	doc_153483594924_item	2246137	et	4	main
et	doc_153483594924_item	2246140	et	3	main
võib	doc_153483594924_item	2246149	et	3	main
valmis	doc_153483594924_item	2246160	et	4	main
täiskasvanute	doc_153483594924_item	2246173	et	3	main
palju	doc_153483594924_item	2246183	et	4	main
ei	doc_153483594924_item	2246186	et	4	main
mõtlen	doc_153483594924_item	2246192	et	3	main
peab	doc_153483594924_item	2246199	et	4	main
sest	doc_153483594924_item	2246203	et	4	main
nad	doc_153483594924_item	2246204	et	3	main
parem	doc_153483594924_item	2246205	et	4	main
teavad	doc_153483594924_item	2246206	et	3	main
ja	doc_153483594924_item	2246208	et	3	main
elu	doc_153483594924_item	2246207	et	4	main
oma	doc_153483594924_item	2246209	et	4	main
last	doc_153483594924_item	2246210	et	4	main
millest	doc_153483594925_item	2246211	et	3	main
sõltub	doc_153483594925_item	2246212	et	3	main
eluiga	doc_153483594925_item	2246213	et	4	main
millest	doc_153483594925_item	2246214	et	3	main
sõltub	doc_153483594925_item	2246215	et	3	main
eluiga	doc_153483594925_item	2246216	et	4	main
kõige	doc_153483594925_item	2246217	et	4	main
pealt	doc_153483594925_item	2246218	et	4	main
eluiga	doc_153483594925_item	2246219	et	4	main
sõltub	doc_153483594925_item	2246220	et	3	main
see	doc_153483594925_item	2246225	et	3	main
tähtsam	doc_153483594925_item	2246228	et	4	main
põhjus	doc_153483594925_item	2246229	et	4	main
on	doc_153483594925_item	2246231	et	4	main
mingi	doc_153483594925_item	2246238	et	4	main
areng	doc_153483594925_item	2246248	et	3	main
olen	doc_153483594925_item	2246251	et	3	main
see	doc_153483594925_item	2246258	et	3	main
ka	doc_153483594925_item	2246260	et	3	main
tähtis	doc_153483594925_item	2246262	et	4	main
narkotikumist	doc_153483594925_item	2246279	et	4	main
ka	doc_153483594925_item	2246284	et	3	main
ei	doc_153483594925_item	2246290	et	4	main
pingeid	doc_153483594925_item	2246292	et	3	main
sellest	doc_153483594925_item	2246295	et	4	main
ma	doc_153483594926_item	2246304	et	3	main
mis	doc_153483594926_item	2246322	et	4	main
räägi	doc_153483594926_item	2246324	et	4	main
cv	doc_153483594926_item	2246325	et	4	main
nõus	doc_153483594926_item	2246335	et	4	main
ja	doc_153483594926_item	2246339	et	3	main
peavad	doc_153483594926_item	2246341	et	4	main
seal	doc_153483594926_item	2246346	et	4	main
tähtsam	doc_153483594926_item	2246350	et	4	main
riietus	doc_153483594926_item	2246355	et	4	main
ma	doc_153483594926_item	2246362	et	3	main
nõus	doc_153483594926_item	2246364	et	4	main
ja	doc_153483594926_item	2246371	et	3	main
välimus	doc_153483594926_item	2246373	et	3	main
tööd	doc_153483594926_item	2246378	et	4	main
leida	doc_153483594926_item	2246379	et	3	main
tööintervjuul	doc_153483594926_item	2246380	et	3	main
palju	doc_153483594926_item	2246383	et	4	main
te	doc_153483594926_item	2246389	et	4	main
kõige	doc_153483594926_item	2246393	et	4	main
ma	doc_153483594925_item	2246222	et	3	main
arvan	doc_153483594925_item	2246223	et	3	main
on	doc_153483594925_item	2246226	et	4	main
elu	doc_153483594925_item	2246237	et	4	main
tõttu	doc_153483594925_item	2246240	et	4	main
eluiga	doc_153483594925_item	2246243	et	4	main
sõltub	doc_153483594925_item	2246244	et	3	main
meditsiini	doc_153483594925_item	2246247	et	4	main
ma	doc_153483594925_item	2246250	et	3	main
siis	doc_153483594925_item	2246257	et	3	main
praegu	doc_153483594925_item	2246264	et	3	main
elu	doc_153483594925_item	2246277	et	4	main
ilma	doc_153483594925_item	2246278	et	4	main
ja	doc_153483594925_item	2246280	et	3	main
on	doc_153483594925_item	2246283	et	4	main
väga	doc_153483594925_item	2246285	et	3	main
me	doc_153483594925_item	2246289	et	4	main
maandada	doc_153483594925_item	2246293	et	3	main
kontrolltöö	doc_153483594926_item	2246299	et	4	main
ei	doc_153483594926_item	2246305	et	4	main
tööintervjuuks	doc_153483594926_item	2246309	et	3	main
vaja	doc_153483594926_item	2246311	et	4	main
pole	doc_153483594926_item	2246310	et	3	main
selle	doc_153483594926_item	2246313	et	4	main
valmistuda	doc_153483594926_item	2246312	et	3	main
pärast	doc_153483594926_item	2246314	et	4	main
et	doc_153483594926_item	2246315	et	3	main
te	doc_153483594926_item	2246316	et	4	main
peate	doc_153483594926_item	2246317	et	4	main
teadma	doc_153483594926_item	2246318	et	3	main
mis	doc_153483594926_item	2246319	et	4	main
rääkima	doc_153483594926_item	2246320	et	3	main
ja	doc_153483594926_item	2246321	et	3	main
ei	doc_153483594926_item	2246323	et	4	main
avaldus	doc_153483594926_item	2246327	et	4	main
olema	doc_153483594926_item	2246329	et	4	main
ma	doc_153483594926_item	2246333	et	3	main
lühikesed	doc_153483594926_item	2246343	et	4	main
kõige	doc_153483594926_item	2246349	et	4	main
hea	doc_153483594926_item	2246357	et	4	main
sellega	doc_153483594926_item	2246365	et	3	main
selle	doc_153483594926_item	2246366	et	4	main
pärast	doc_153483594926_item	2246367	et	4	main
endast	doc_153483594926_item	2246382	et	4	main
jah	doc_153483594926_item	2246387	et	3	main
ise	doc_153483594926_item	2246391	et	4	main
kogu	doc_153483594925_item	2246236	et	4	main
meie	doc_153483594925_item	2246242	et	4	main
ja	doc_153483594925_item	2246246	et	3	main
arstiabi	doc_153483594925_item	2246256	et	4	main
kahjuks	doc_153483594925_item	2246263	et	4	main
ole	doc_153483594925_item	2246267	et	4	main
meditsiini	doc_153483594925_item	2246269	et	4	main
areng	doc_153483594925_item	2246270	et	3	main
aga	doc_153483594925_item	2246271	et	3	main
kõige	doc_153483594925_item	2246272	et	4	main
tähtsam	doc_153483594925_item	2246273	et	4	main
see	doc_153483594925_item	2246274	et	3	main
tervislik	doc_153483594925_item	2246276	et	3	main
eluiga	doc_153483594925_item	2246288	et	4	main
valmistuda	doc_153483594926_item	2246303	et	3	main
et	doc_153483594926_item	2246308	et	3	main
lühikesed	doc_153483594926_item	2246330	et	4	main
ja	doc_153483594926_item	2246331	et	3	main
cv	doc_153483594926_item	2246338	et	4	main
ja	doc_153483594926_item	2246344	et	3	main
olema	doc_153483594926_item	2246348	et	4	main
enast	doc_153483594926_item	2246353	et	4	main
sobiv	doc_153483594926_item	2246354	et	4	main
välimus	doc_153483594926_item	2246358	et	3	main
et	doc_153483594926_item	2246368	et	3	main
kes	doc_153483594926_item	2246376	et	4	main
võib	doc_153483594926_item	2246385	et	3	main
töötas	doc_153483594926_item	2246397	et	3	main
õpis	doc_153483594926_item	2246399	et	3	main
on	doc_153483594926_item	2246401	et	4	main
tarbija	doc_153483594926_item	2246402	et	4	main
põhiõigused	doc_153483594926_item	2246404	et	4	main
teil	doc_153483594926_item	2246434	et	4	main
probleemid	doc_153483594926_item	2246436	et	3	main
on	doc_153483594926_item	2246441	et	4	main
p	doc_153483594926_item	2246443	et	4	main
ei	doc_153483594926_item	2246448	et	4	main
viska	doc_153483594926_item	2246449	et	4	main
ma	doc_153483594926_item	2246458	et	3	main
palju	doc_153483594926_item	2246465	et	4	main
suurem	doc_153483594926_item	2246469	et	4	main
et	doc_153483594926_item	2246480	et	3	main
mille	doc_153483594926_item	2246487	et	3	main
on	doc_153483594926_item	2246495	et	4	main
soovite	doc_153483594926_item	2246507	et	3	main
aga	doc_153483594926_item	2246509	et	3	main
vähendada	doc_153483594926_item	2246518	et	3	main
ohvriks	doc_153483594926_item	2246520	et	3	main
kus	doc_153483594926_item	2246528	et	3	main
span2span	doc_153483594926_item	2246533	et	4	main
stylefont-family	doc_153483594926_item	2246534	et	4	main
times	doc_153483594926_item	2246535	et	4	main
font-size-adjust	doc_153483594926_item	2246548	et	4	main
span	doc_153483594926_item	2246552	et	4	main
roman	doc_153483594926_item	2246559	et	4	main
7pt	doc_153483594926_item	2246567	et	4	main
silmas	doc_153483594926_item	2246584	et	4	main
tähelepanelik	doc_153483594926_item	2246589	et	4	main
vooli	doc_153483594926_item	2246594	et	4	main
ilma	doc_153483594927_item	2246596	et	4	main
igal	doc_153483594927_item	2246622	et	3	main
kuhugi	doc_153483594927_item	2246626	et	4	main
kui	doc_153483594927_item	2246628	et	3	main
oli	doc_153483594927_item	2246630	et	3	main
me	doc_153483594927_item	2246632	et	4	main
koolis	doc_153483594927_item	2246634	et	4	main
pussiga	doc_153483594927_item	2246635	et	4	main
tööle	doc_153483594927_item	2246641	et	3	main
kokku	doc_153483594927_item	2246656	et	3	main
aeg	doc_153483594927_item	2246658	et	3	main
1	doc_154182424413_item	2246662	et	2	main
2	doc_154182424413_item	2246670	et	2	main
kõige	doc_154182424413_item	2246675	et	4	main
saada	doc_154182424413_item	2246682	et	4	main
eestlaste	doc_154182424413_item	2246684	et	4	main
hariduse	doc_154182424413_item	2246701	et	3	main
ning	doc_154182424413_item	2246703	et	3	main
usku	doc_154182424413_item	2246708	et	4	main
a	doc_154182424413_item	2246719	et	4	main
ja	doc_153483594926_item	2246326	et	3	main
peavad	doc_153483594926_item	2246328	et	4	main
olen	doc_153483594926_item	2246334	et	3	main
sellega	doc_153483594926_item	2246336	et	3	main
avaldus	doc_153483594926_item	2246340	et	4	main
olema	doc_153483594926_item	2246342	et	4	main
peab	doc_153483594926_item	2246347	et	4	main
informatsiooni	doc_153483594926_item	2246351	et	4	main
tööd	doc_153483594926_item	2246360	et	4	main
olen	doc_153483594926_item	2246363	et	3	main
sobiv	doc_153483594926_item	2246369	et	4	main
hea	doc_153483594926_item	2246372	et	4	main
rääkima	doc_153483594926_item	2246384	et	3	main
olla	doc_153483594926_item	2246386	et	3	main
räägite	doc_153483594926_item	2246390	et	3	main
tähtsam	doc_153483594926_item	2246394	et	4	main
mis	doc_153483594926_item	2246400	et	4	main
põhiõigused	doc_153483594926_item	2246403	et	4	main
et	doc_153483594926_item	2246407	et	3	main
ta	doc_153483594926_item	2246408	et	4	main
saab	doc_153483594926_item	2246409	et	3	main
tarbijal	doc_153483594926_item	2246406	et	4	main
tulla	doc_153483594926_item	2246410	et	3	main
tarbijakaitseametis	doc_153483594926_item	2246411	et	3	main
kui	doc_153483594926_item	2246412	et	3	main
kampsun	doc_153483594926_item	2246413	et	3	main
tõmbas	doc_153483594926_item	2246414	et	3	main
kokku	doc_153483594926_item	2246415	et	3	main
ja	doc_153483594926_item	2246416	et	3	main
vaetab	doc_153483594926_item	2246417	et	4	main
kampsun	doc_153483594926_item	2246418	et	3	main
et	doc_153483594926_item	2246419	et	3	main
teil	doc_153483594926_item	2246420	et	4	main
ostutšeki	doc_153483594926_item	2246422	et	2	main
kirjutatud	doc_153483594926_item	2246426	et	4	main
ostutšekile	doc_153483594926_item	2246428	et	2	main
te	doc_153483594926_item	2246430	et	4	main
kaubadega	doc_153483594926_item	2246438	et	4	main
ostutšekki	doc_153483594926_item	2246450	et	2	main
praegu	doc_153483594926_item	2246461	et	3	main
probleemid	doc_153483594926_item	2246466	et	3	main
et	doc_153483594926_item	2246470	et	3	main
käia	doc_153483594926_item	2246474	et	4	main
pärast	doc_153483594926_item	2246477	et	4	main
ained	doc_153483594926_item	2246482	et	3	main
ole	doc_153483594926_item	2246484	et	4	main
vaja	doc_153483594926_item	2246485	et	4	main
poolest	doc_153483594926_item	2246488	et	4	main
õppimisest	doc_153483594926_item	2246493	et	4	main
koolis	doc_153483594926_item	2246494	et	4	main
te	doc_153483594926_item	2246506	et	4	main
õpida	doc_153483594926_item	2246508	et	4	main
sattumise	doc_153483594926_item	2246521	et	4	main
jalutama	doc_153483594926_item	2246526	et	3	main
ole	doc_153483594926_item	2246530	et	4	main
palju	doc_153483594926_item	2246531	et	4	main
roman	doc_153483594926_item	2246537	et	4	main
font-style	doc_153483594926_item	2246538	et	4	main
normal	doc_153483594926_item	2246547	et	4	main
none	doc_153483594926_item	2246549	et	4	main
span3span	doc_153483594926_item	2246555	et	4	main
normal	doc_153483594926_item	2246561	et	4	main
font-size-adjust	doc_153483594926_item	2246570	et	4	main
none	doc_153483594926_item	2246571	et	4	main
normal	doc_153483594926_item	2246573	et	4	main
span	doc_153483594926_item	2246574	et	4	main
informatsioon	doc_153483594926_item	2246395	et	3	main
kus	doc_153483594926_item	2246396	et	3	main
on	doc_153483594926_item	2246405	et	4	main
oleks	doc_153483594926_item	2246421	et	3	main
saate	doc_153483594926_item	2246431	et	4	main
vaetada	doc_153483594926_item	2246432	et	4	main
kui	doc_153483594926_item	2246433	et	3	main
on	doc_153483594926_item	2246435	et	4	main
asjadega	doc_153483594926_item	2246437	et	3	main
teil	doc_153483594926_item	2246440	et	4	main
ostutšekki	doc_153483594926_item	2246442	et	2	main
mis	doc_153483594926_item	2246451	et	4	main
praegu	doc_153483594926_item	2246453	et	3	main
koolis	doc_153483594926_item	2246454	et	4	main
arvan	doc_153483594926_item	2246459	et	3	main
koolis	doc_153483594926_item	2246462	et	4	main
on	doc_153483594926_item	2246463	et	4	main
väga	doc_153483594926_item	2246464	et	3	main
kõige	doc_153483594926_item	2246468	et	4	main
koolis	doc_153483594926_item	2246475	et	4	main
mõtlevad	doc_153483594926_item	2246479	et	4	main
õppimine	doc_153483594926_item	2246491	et	4	main
koolis	doc_153483594926_item	2246492	et	4	main
palju	doc_153483594926_item	2246497	et	4	main
te	doc_153483594926_item	2246502	et	4	main
ei	doc_153483594926_item	2246511	et	4	main
mida	doc_153483594926_item	2246513	et	4	main
et	doc_153483594926_item	2246517	et	3	main
riski	doc_153483594926_item	2246522	et	4	main
ei	doc_153483594926_item	2246524	et	4	main
new	doc_153483594926_item	2246536	et	4	main
font-variant	doc_153483594926_item	2246540	et	3	main
font-weight	doc_153483594926_item	2246542	et	4	main
normal	doc_153483594926_item	2246543	et	4	main
font-size	doc_153483594926_item	2246544	et	4	main
7pt	doc_153483594926_item	2246545	et	4	main
stylefont-family	doc_153483594926_item	2246556	et	4	main
normal	doc_153483594926_item	2246563	et	4	main
ei	doc_153483594926_item	2246575	et	4	main
näitama	doc_153483594926_item	2246577	et	3	main
asjad	doc_153483594926_item	2246579	et	3	main
töötate	doc_153483594926_item	2246592	et	3	main
saaks	doc_153483594927_item	2246599	et	3	main
elada	doc_153483594927_item	2246601	et	3	main
päeval	doc_153483594927_item	2246623	et	3	main
vaja	doc_153483594927_item	2246625	et	4	main
minna	doc_153483594927_item	2246627	et	3	main
hommikuti	doc_153483594927_item	2246636	et	4	main
õhtuti	doc_153483594927_item	2246643	et	3	main
hoijan	doc_153483594927_item	2246655	et	4	main
minu	doc_153483594927_item	2246657	et	3	main
kirjalikud	doc_154182424413_item	2246664	et	3	main
meile	doc_154182424413_item	2246667	et	4	main
1	doc_154182424413_item	2246674	et	2	main
olulisem	doc_154182424413_item	2246676	et	4	main
on	doc_154182424413_item	2246686	et	4	main
a	doc_154182424413_item	2246697	et	4	main
sai	doc_154182424413_item	2246699	et	4	main
eesti	doc_154182424413_item	2246705	et	4	main
levitama	doc_154182424413_item	2246709	et	4	main
kroonikat	doc_154182424413_item	2246712	et	3	main
keeles	doc_154182424413_item	2246724	et	4	main
käsikiri	doc_154182424413_item	2246726	et	3	main
ainult	doc_154182424413_item	2246735	et	4	main
kroonikas	doc_154182424413_item	2246739	et	3	main
kohanimesid	doc_154182424413_item	2246747	et	3	main
ja	doc_154182424413_item	2246752	et	3	main
on	doc_154182424413_item	2246755	et	4	main
kohta	doc_154182424413_item	2246760	et	4	main
ning	doc_154182424413_item	2246769	et	3	main
kõige	doc_154182424413_item	2246771	et	4	main
tharapita	doc_154182424413_item	2246775	et	4	main
pikse	doc_154182424413_item	2246781	et	3	main
trükis	doc_154182424413_item	2246785	et	4	main
tõlges	doc_154182424413_item	2246797	et	3	main
inglise	doc_154182424413_item	2246803	et	4	main
kohta	doc_154182424413_item	2246822	et	4	main
ning	doc_154182424413_item	2246831	et	3	main
keeles	doc_154182424413_item	2246836	et	4	main
see	doc_154182424413_item	2246848	et	3	main
1525a	doc_154182424413_item	2246851	et	4	main
kiriku	doc_154182424413_item	2246862	et	3	main
mis	doc_153483594926_item	2246423	et	4	main
olema	doc_153483594926_item	2246425	et	4	main
korrektsele	doc_153483594926_item	2246427	et	3	main
kui	doc_153483594926_item	2246439	et	3	main
nõu	doc_153483594926_item	2246445	et	4	main
annab	doc_153483594926_item	2246446	et	3	main
kõige	doc_153483594926_item	2246455	et	4	main
et	doc_153483594926_item	2246460	et	3	main
aga	doc_153483594926_item	2246467	et	3	main
lapsed	doc_153483594926_item	2246471	et	3	main
nad	doc_153483594926_item	2246478	et	3	main
õpida	doc_153483594926_item	2246486	et	4	main
väga	doc_153483594926_item	2246496	et	3	main
kõrgkoolis	doc_153483594926_item	2246501	et	4	main
peate	doc_153483594926_item	2246503	et	4	main
vaalima	doc_153483594926_item	2246504	et	3	main
kuriteo	doc_153483594926_item	2246519	et	4	main
pea	doc_153483594926_item	2246525	et	4	main
öösel	doc_153483594926_item	2246527	et	4	main
ei	doc_153483594926_item	2246529	et	4	main
normal	doc_153483594926_item	2246539	et	4	main
normal	doc_153483594926_item	2246541	et	4	main
line-height	doc_153483594926_item	2246546	et	4	main
tähelepanelikuks	doc_153483594926_item	2246554	et	4	main
times	doc_153483594926_item	2246557	et	4	main
font-variant	doc_153483594926_item	2246562	et	3	main
font-weight	doc_153483594926_item	2246564	et	4	main
normal	doc_153483594926_item	2246569	et	4	main
font-stretch	doc_153483594926_item	2246572	et	4	main
inimesi	doc_153483594926_item	2246581	et	4	main
elektriseadmetega	doc_153483594926_item	2246586	et	3	main
te	doc_153483594926_item	2246591	et	4	main
suur	doc_153483594926_item	2246593	et	3	main
pinge	doc_153483594926_item	2246595	et	4	main
ei	doc_153483594927_item	2246598	et	4	main
lähen	doc_153483594927_item	2246638	et	3	main
koos	doc_153483594927_item	2246640	et	4	main
autoga	doc_153483594927_item	2246642	et	3	main
või	doc_153483594927_item	2246652	et	4	main
vastus	doc_154182424413_item	2246660	et	3	main
tähendab	doc_154182424413_item	2246672	et	3	main
võimalik	doc_154182424413_item	2246680	et	3	main
teada	doc_154182424413_item	2246681	et	3	main
muistse	doc_154182424413_item	2246683	et	3	main
liivimaa	doc_154182424413_item	2246687	et	4	main
kroonika	doc_154182424413_item	2246688	et	4	main
autor	doc_154182424413_item	2246690	et	3	main
henricus	doc_154182424413_item	2246691	et	4	main
hea	doc_154182424413_item	2246700	et	4	main
hakkas	doc_154182424413_item	2246711	et	3	main
1224	doc_154182424413_item	2246714	et	2	main
12278	doc_154182424413_item	2246718	et	2	main
originaal	doc_154182424413_item	2246721	et	3	main
ole	doc_154182424413_item	2246728	et	4	main
säilinud	doc_154182424413_item	2246729	et	4	main
me	doc_154182424413_item	2246730	et	4	main
kaudu	doc_154182424413_item	2246738	et	3	main
toodud	doc_154182424413_item	2246744	et	4	main
eesti	doc_154182424413_item	2246758	et	4	main
mainitud	doc_154182424413_item	2246763	et	4	main
puud	doc_154182424413_item	2246765	et	4	main
e	doc_154182424413_item	2246776	et	4	main
esimest	doc_154182424413_item	2246788	et	4	main
korda	doc_154182424413_item	2246789	et	4	main
1740a	doc_154182424413_item	2246790	et	4	main
kroonika	doc_154182424413_item	2246798	et	4	main
tõlgitud	doc_154182424413_item	2246800	et	4	main
lahingute	doc_154182424413_item	2246821	et	4	main
vägiveod	doc_154182424413_item	2246824	et	3	main
kirikureformatsiooni	doc_154182424413_item	2246826	et	4	main
hakkas	doc_154182424413_item	2246827	et	3	main
eestikeelne	doc_154182424413_item	2246828	et	3	main
arenema	doc_154182424413_item	2246830	et	3	main
teoseid	doc_154182424413_item	2246834	et	3	main
autor	doc_154182424413_item	2246857	et	3	main
wandradt	doc_154182424413_item	2246859	et	4	main
jutustaja	doc_154182424413_item	2246863	et	4	main
keelde	doc_154182424413_item	2246868	et	4	main
1575a	doc_154182424413_item	2246884	et	4	main
oli	doc_154182424413_item	2246890	et	3	main
kohustus	doc_154182424413_item	2246912	et	4	main
1	doc_153483594926_item	2246523	et	2	main
inimesi	doc_153483594926_item	2246532	et	4	main
font-stretch	doc_153483594926_item	2246550	et	4	main
normal	doc_153483594926_item	2246551	et	4	main
olema	doc_153483594926_item	2246553	et	4	main
new	doc_153483594926_item	2246558	et	4	main
font-style	doc_153483594926_item	2246560	et	4	main
normal	doc_153483594926_item	2246565	et	4	main
font-size	doc_153483594926_item	2246566	et	4	main
line-height	doc_153483594926_item	2246568	et	4	main
pea	doc_153483594926_item	2246576	et	4	main
ebatuntud	doc_153483594926_item	2246580	et	4	main
mida	doc_153483594926_item	2246582	et	4	main
pidama	doc_153483594926_item	2246585	et	4	main
töötamisel	doc_153483594926_item	2246587	et	4	main
milleta	doc_153483594927_item	2246597	et	3	main
inimesed	doc_153483594927_item	2246600	et	3	main
ilma	doc_153483594927_item	2246602	et	4	main
milleta	doc_153483594927_item	2246603	et	3	main
inimesed	doc_153483594927_item	2246604	et	3	main
ei	doc_153483594927_item	2246605	et	4	main
saaks	doc_153483594927_item	2246606	et	3	main
elada	doc_153483594927_item	2246607	et	3	main
ma	doc_153483594927_item	2246608	et	3	main
et	doc_153483594927_item	2246610	et	3	main
igas	doc_153483594927_item	2246611	et	3	main
mõtlen	doc_153483594927_item	2246609	et	3	main
inimeses	doc_153483594927_item	2246612	et	3	main
on	doc_153483594927_item	2246613	et	4	main
oma	doc_153483594927_item	2246614	et	4	main
asjad	doc_153483594927_item	2246615	et	3	main
ei	doc_153483594927_item	2246617	et	4	main
saa	doc_153483594927_item	2246618	et	4	main
elada	doc_153483594927_item	2246619	et	3	main
ilma	doc_153483594927_item	2246620	et	4	main
ma	doc_153483594927_item	2246616	et	3	main
odavad	doc_153483594926_item	2246578	et	3	main
peaks	doc_153483594926_item	2246583	et	4	main
ole	doc_153483594926_item	2246588	et	4	main
kui	doc_153483594926_item	2246590	et	3	main
transpordita	doc_153483594927_item	2246621	et	4	main
ma	doc_153483594927_item	2246637	et	3	main
abikaasaga	doc_153483594927_item	2246639	et	3	main
koju	doc_153483594927_item	2246645	et	3	main
pussiga	doc_153483594927_item	2246646	et	4	main
nädalavahetusel	doc_153483594927_item	2246648	et	4	main
transport	doc_153483594927_item	2246654	et	3	main
küsimusele	doc_154182424413_item	2246661	et	4	main
millised	doc_154182424413_item	2246663	et	3	main
jutustavad	doc_154182424413_item	2246666	et	4	main
eestimaa	doc_154182424413_item	2246668	et	4	main
keskajast	doc_154182424413_item	2246669	et	4	main
mida	doc_154182424413_item	2246671	et	4	main
teoorjus	doc_154182424413_item	2246673	et	3	main
on	doc_154182424413_item	2246679	et	4	main
kohta	doc_154182424413_item	2246685	et	4	main
selle	doc_154182424413_item	2246689	et	4	main
de	doc_154182424413_item	2246692	et	4	main
on	doc_154182424413_item	2246694	et	4	main
sündinud	doc_154182424413_item	2246695	et	4	main
1185	doc_154182424413_item	2246696	et	2	main
tuli	doc_154182424413_item	2246704	et	4	main
missionääriks	doc_154182424413_item	2246706	et	4	main
risti	doc_154182424413_item	2246707	et	4	main
kirjutama	doc_154182424413_item	2246713	et	3	main
ja	doc_154182424413_item	2246716	et	3	main
ladina	doc_154182424413_item	2246723	et	4	main
võime	doc_154182424413_item	2246731	et	4	main
teost	doc_154182424413_item	2246733	et	4	main
hilisemate	doc_154182424413_item	2246736	et	4	main
esimest	doc_154182424413_item	2246741	et	4	main
korda	doc_154182424413_item	2246742	et	4	main
ja	doc_154182424413_item	2246748	et	3	main
kroonikas	doc_154182424413_item	2246754	et	3	main
palju	doc_154182424413_item	2246756	et	4	main
informatsiooni	doc_154182424413_item	2246757	et	4	main
seal	doc_154182424413_item	2246761	et	4	main
pühad	doc_154182424413_item	2246764	et	3	main
matmistoit	doc_154182424413_item	2246766	et	3	main
jumalaks	doc_154182424413_item	2246773	et	3	main
ja	doc_154182424413_item	2246780	et	3	main
jumala	doc_154182424413_item	2246782	et	3	main
variant	doc_154182424413_item	2246792	et	3	main
jungi	doc_154182424413_item	2246796	et	4	main
vene	doc_154182424413_item	2246801	et	4	main
saksa	doc_154182424413_item	2246802	et	4	main
on	doc_153483594927_item	2246624	et	4	main
tüttar	doc_153483594927_item	2246629	et	4	main
väike	doc_153483594927_item	2246631	et	4	main
käisime	doc_153483594927_item	2246633	et	3	main
lähen	doc_153483594927_item	2246644	et	3	main
igal	doc_153483594927_item	2246647	et	3	main
käin	doc_153483594927_item	2246649	et	3	main
suvilas	doc_153483594927_item	2246650	et	3	main
rongiga	doc_153483594927_item	2246651	et	4	main
autoga	doc_153483594927_item	2246653	et	3	main
p	doc_153483594927_item	2246659	et	4	main
allikad	doc_154182424413_item	2246665	et	3	main
teos	doc_154182424413_item	2246677	et	4	main
millest	doc_154182424413_item	2246678	et	3	main
lettis	doc_154182424413_item	2246693	et	4	main
saksamaal	doc_154182424413_item	2246698	et	4	main
kloostrist	doc_154182424413_item	2246702	et	3	main
ta	doc_154182424413_item	2246710	et	4	main
aastal	doc_154182424413_item	2246715	et	3	main
lõpetas	doc_154182424413_item	2246717	et	3	main
kroonika	doc_154182424413_item	2246720	et	4	main
oli	doc_154182424413_item	2246722	et	3	main
kuid	doc_154182424413_item	2246725	et	4	main
ümberkirjutiste	doc_154182424413_item	2246737	et	3	main
on	doc_154182424413_item	2246740	et	4	main
väljendeid	doc_154182424413_item	2246751	et	3	main
lauseid	doc_154182424413_item	2246753	et	3	main
usundi	doc_154182424413_item	2246759	et	3	main
on	doc_154182424413_item	2246762	et	4	main
kombed	doc_154182424413_item	2246768	et	3	main
taara	doc_154182424413_item	2246777	et	4	main
skandinaavlaste	doc_154182424413_item	2246778	et	3	main
thor	doc_154182424413_item	2246783	et	4	main
nimelt	doc_154182424413_item	2246784	et	4	main
ilmus	doc_154182424413_item	2246786	et	4	main
kroonika	doc_154182424413_item	2246787	et	4	main
ilmus	doc_154182424413_item	2246793	et	4	main
jaani	doc_154182424413_item	2246795	et	4	main
ja	doc_154182424413_item	2246804	et	3	main
ilmus	doc_154182424413_item	2246832	et	4	main
eesti	doc_154182424413_item	2246835	et	4	main
kõige	doc_154182424413_item	2246837	et	4	main
vanem	doc_154182424413_item	2246838	et	4	main
on	doc_154182424413_item	2246844	et	4	main
koelli	doc_154182424413_item	2246846	et	4	main
selle	doc_154182424413_item	2246856	et	4	main
simon	doc_154182424413_item	2246858	et	4	main
niguliste	doc_154182424413_item	2246861	et	4	main
tõlgis	doc_154182424413_item	2246865	et	3	main
katekismuse	doc_154182424413_item	2246866	et	3	main
eesti	doc_154182424413_item	2246867	et	4	main
hans	doc_154182424413_item	2246872	et	4	main
kuulusid	doc_154182424413_item	2246877	et	4	main
vaimulikud	doc_154182424413_item	2246878	et	3	main
see	doc_154182424413_item	2246880	et	3	main
nimetuse	doc_154182424413_item	2246882	et	4	main
ilmus	doc_154182424413_item	2246885	et	4	main
eestikeelne	doc_154182424413_item	2246887	et	3	main
kirjutatud	doc_154182424413_item	2246891	et	4	main
2	doc_154182424413_item	2246893	et	2	main
mõisas	doc_154182424413_item	2246897	et	3	main
mida	doc_154182424413_item	2246905	et	4	main
läks	doc_154182424413_item	2246908	et	3	main
oli	doc_154182424413_item	2246916	et	3	main
aluseks	doc_154182424413_item	2246918	et	4	main
küsimusele	doc_154182424414_item	2246920	et	4	main
eesti	doc_154182424414_item	2246923	et	4	main
tähendus	doc_154182424414_item	2246928	et	4	main
oli	doc_154182424414_item	2246930	et	3	main
territooriumil	doc_154182424414_item	2246932	et	3	main
vikingid	doc_154182424414_item	2246935	et	4	main
kaupmehed	doc_154182424414_item	2246937	et	3	main
kauplesid	doc_154182424414_item	2246939	et	4	main
vaht	doc_154182424414_item	2246944	et	3	main
ehted	doc_154182424414_item	2246946	et	3	main
kõige	doc_154182424414_item	2246948	et	4	main
metall	doc_154182424414_item	2246950	et	3	main
hõbe	doc_154182424414_item	2246952	et	3	main
münte	doc_154182424414_item	2246958	et	3	main
toodete	doc_154182424414_item	2246966	et	3	main
eest	doc_154182424414_item	2246967	et	4	main
hobune	doc_154182424414_item	2246969	et	4	main
maksis	doc_154182424414_item	2246970	et	4	main
250-300gr	doc_154182424414_item	2246971	et	4	main
gr	doc_154182424414_item	2246975	et	4	main
hõbedat	doc_154182424414_item	2246981	et	3	main
palju	doc_154182424414_item	2246985	et	4	main
sõjalisi	doc_154182424414_item	2246986	et	4	main
pikemad	doc_154182424414_item	2246993	et	4	main
räägitakse	doc_154182424414_item	2246996	et	3	main
ajaloosündusdest	doc_154182424414_item	2246998	et	4	main
ei	doc_154182424413_item	2246727	et	4	main
seda	doc_154182424413_item	2246732	et	3	main
uurida	doc_154182424413_item	2246734	et	3	main
välja	doc_154182424413_item	2246743	et	4	main
eesti	doc_154182424413_item	2246745	et	4	main
keelseid	doc_154182424413_item	2246746	et	3	main
inimeste	doc_154182424413_item	2246749	et	3	main
nimesid	doc_154182424413_item	2246750	et	3	main
ja	doc_154182424413_item	2246767	et	3	main
jumalad	doc_154182424413_item	2246770	et	3	main
tähtsamaks	doc_154182424413_item	2246772	et	4	main
oli	doc_154182424413_item	2246774	et	3	main
päikese	doc_154182424413_item	2246779	et	4	main
eestikeelne	doc_154182424413_item	2246791	et	3	main
1881a	doc_154182424413_item	2246794	et	4	main
on	doc_154182424413_item	2246799	et	4	main
läti	doc_154182424413_item	2246805	et	4	main
keelde	doc_154182424413_item	2246806	et	4	main
eestikeelseid	doc_154182424413_item	2246807	et	3	main
kohtade	doc_154182424413_item	2246808	et	3	main
ja	doc_154182424413_item	2246809	et	3	main
inimeste	doc_154182424413_item	2246810	et	3	main
nimesid	doc_154182424413_item	2246811	et	3	main
võib	doc_154182424413_item	2246812	et	3	main
kohtuda	doc_154182424413_item	2246813	et	3	main
taani	doc_154182424413_item	2246814	et	4	main
hindamisraamatus	doc_154182424413_item	2246815	et	4	main
seal	doc_154182424413_item	2246816	et	4	main
on	doc_154182424413_item	2246817	et	4	main
ka	doc_154182424413_item	2246818	et	3	main
palju	doc_154182424413_item	2246819	et	4	main
teateid	doc_154182424413_item	2246820	et	3	main
kirjandus	doc_154182424413_item	2246829	et	3	main
palju	doc_154182424413_item	2246833	et	4	main
tekst	doc_154182424413_item	2246843	et	3	main
wandradt	doc_154182424413_item	2246845	et	4	main
oli	doc_154182424413_item	2246849	et	3	main
tallinna	doc_154182424413_item	2246869	et	4	main
linnakooli	doc_154182424413_item	2246870	et	4	main
kuhu	doc_154182424413_item	2246876	et	3	main
sai	doc_154182424413_item	2246881	et	4	main
katekismus	doc_154182424413_item	2246883	et	3	main
mis	doc_154182424413_item	2246889	et	4	main
teoorjus	doc_154182424413_item	2246894	et	3	main
poole	doc_154182424413_item	2246903	et	4	main
talupoja	doc_154182424413_item	2246911	et	4	main
2	doc_154182424414_item	2246925	et	2	main
viikingiaeg	doc_154182424414_item	2246929	et	3	main
pkr	doc_154182424414_item	2246934	et	4	main
hõbe	doc_154182424414_item	2246957	et	3	main
ajale	doc_154182424414_item	2246962	et	3	main
kõige	doc_154182424414_item	2246965	et	4	main
nt	doc_154182424414_item	2246968	et	4	main
200	doc_154182424414_item	2246974	et	2	main
org	doc_154182424414_item	2246978	et	3	main
300	doc_154182424414_item	2246979	et	2	main
sellest	doc_154182424414_item	2246990	et	4	main
saagades	doc_154182424414_item	2246992	et	3	main
lugulaulud	doc_154182424414_item	2246994	et	3	main
aastal	doc_154182424414_item	2247004	et	3	main
jaroslav	doc_154182424414_item	2247007	et	4	main
sajandil	doc_154182424414_item	2247022	et	3	main
slaavi	doc_154182424414_item	2247027	et	3	main
irboska	doc_154182424414_item	2247029	et	4	main
eesti	doc_154182424414_item	2247037	et	4	main
sellest	doc_154182424414_item	2247039	et	4	main
taanlaste	doc_154182424413_item	2246823	et	3	main
pärast	doc_154182424413_item	2246825	et	4	main
eesti	doc_154182424413_item	2246839	et	4	main
keeles	doc_154182424413_item	2246840	et	4	main
kirju	doc_154182424413_item	2246841	et	4	main
tatud	doc_154182424413_item	2246842	et	4	main
katekismus	doc_154182424413_item	2246847	et	3	main
kirjutatud	doc_154182424413_item	2246850	et	4	main
lübeckis	doc_154182424413_item	2246852	et	4	main
vaimuliku	doc_154182424413_item	2246853	et	3	main
dialoogi	doc_154182424413_item	2246854	et	4	main
kujul	doc_154182424413_item	2246855	et	4	main
oli	doc_154182424413_item	2246860	et	3	main
ta	doc_154182424413_item	2246864	et	4	main
õpetaja	doc_154182424413_item	2246871	et	4	main
koostas	doc_154182424413_item	2246874	et	4	main
aabits	doc_154182424413_item	2246888	et	3	main
puutahvlil	doc_154182424413_item	2246892	et	3	main
füüsiline	doc_154182424413_item	2246895	et	3	main
mida	doc_154182424413_item	2246898	et	4	main
üle	doc_154182424413_item	2246902	et	3	main
seda	doc_154182424413_item	2246904	et	3	main
mõisnikule	doc_154182424413_item	2246909	et	3	main
pärisorjuse	doc_154182424413_item	2246917	et	3	main
vastus	doc_154182424414_item	2246919	et	3	main
muinasaeg	doc_154182424414_item	2246927	et	3	main
kes	doc_154182424414_item	2246938	et	4	main
eestlastega	doc_154182424414_item	2246940	et	4	main
oli	doc_154182424414_item	2246942	et	3	main
mesi	doc_154182424414_item	2246943	et	4	main
orjed	doc_154182424414_item	2246945	et	4	main
väärtuslikum	doc_154182424414_item	2246949	et	4	main
hõbega	doc_154182424414_item	2246963	et	4	main
gr	doc_154182424414_item	2246980	et	4	main
ajal	doc_154182424414_item	2246983	et	4	main
eriti	doc_154182424414_item	2246988	et	3	main
1030	doc_154182424414_item	2247003	et	2	main
slavlasttel	doc_154182424414_item	2247030	et	4	main
sõnad	doc_154182424414_item	2247043	et	4	main
besmen	doc_154182424414_item	2247045	et	4	main
eestlased	doc_154182424414_item	2247047	et	3	main
sõjaliselt	doc_154182424414_item	2247051	et	4	main
aga	doc_154182424414_item	2247053	et	3	main
on	doc_154182424414_item	2247056	et	4	main
palju	doc_154182424414_item	2247058	et	4	main
araabia	doc_154182424414_item	2247059	et	4	main
siis	doc_154182424414_item	2247068	et	3	main
ja	doc_154182424414_item	2247091	et	3	main
seetõttu	doc_154182424414_item	2247093	et	3	main
olid	doc_154182424414_item	2247095	et	4	main
kirves	doc_154182424414_item	2247102	et	4	main
vilja	doc_154182424414_item	2247110	et	4	main
mille	doc_154182424414_item	2247113	et	3	main
seda	doc_154182424414_item	2247115	et	3	main
inimesed	doc_154182424414_item	2247117	et	3	main
rikkamad	doc_154182424414_item	2247119	et	4	main
ja	doc_154182424414_item	2247120	et	3	main
ajavahemik	doc_154182424414_item	2247128	et	3	main
mis	doc_154182424414_item	2247129	et	4	main
kuni	doc_154182424414_item	2247131	et	3	main
kristluse	doc_154182424414_item	2247132	et	4	main
1	doc_154182424415_item	2247137	et	2	main
eestlaste	doc_154182424415_item	2247138	et	4	main
üldiseloomustus	doc_154182424415_item	2247140	et	4	main
on	doc_154182424415_item	2247143	et	4	main
alepõllundus	doc_154182424415_item	2247144	et	3	main
eestlaste	doc_154182424415_item	2247146	et	4	main
üldiselt	doc_154182424415_item	2247148	et	4	main
on	doc_154182424415_item	2247149	et	4	main
oli	doc_154182424415_item	2247155	et	3	main
toimusid	doc_154182424415_item	2247160	et	4	main
arengu	doc_154182424415_item	2247163	et	3	main
et	doc_154182424415_item	2247169	et	3	main
ja	doc_154182424415_item	2247179	et	3	main
territooriumile	doc_154182424415_item	2247184	et	3	main
susi	doc_154182424413_item	2246873	et	4	main
käsikirja	doc_154182424413_item	2246875	et	4	main
laulud	doc_154182424413_item	2246879	et	3	main
esimene	doc_154182424413_item	2246886	et	3	main
töö	doc_154182424413_item	2246896	et	4	main
pidid	doc_154182424413_item	2246899	et	4	main
tegema	doc_154182424413_item	2246900	et	3	main
talupojad	doc_154182424413_item	2246901	et	4	main
tootis	doc_154182424413_item	2246906	et	3	main
talupoeg	doc_154182424413_item	2246907	et	3	main
maksule	doc_154182424413_item	2246910	et	4	main
kasvab	doc_154182424413_item	2246913	et	3	main
kahekordselt	doc_154182424413_item	2246914	et	4	main
see	doc_154182424413_item	2246915	et	3	main
1	doc_154182424414_item	2246921	et	2	main
territooriumil	doc_154182424414_item	2246924	et	3	main
mõiste	doc_154182424414_item	2246926	et	4	main
eesti	doc_154182424414_item	2246931	et	4	main
olid	doc_154182424414_item	2246936	et	4	main
koduloomad	doc_154182424414_item	2246947	et	3	main
eesti	doc_154182424414_item	2246953	et	4	main
on	doc_154182424414_item	2246955	et	4	main
mis	doc_154182424414_item	2246959	et	4	main
sellele	doc_154182424414_item	2246961	et	4	main
hõbedat	doc_154182424414_item	2246972	et	3	main
h	doc_154182424414_item	2246976	et	4	main
aga	doc_154182424414_item	2246977	et	3	main
kus	doc_154182424414_item	2246995	et	3	main
tähtsadest	doc_154182424414_item	2246997	et	4	main
esimene	doc_154182424414_item	2246999	et	3	main
sõjakontlikt	doc_154182424414_item	2247001	et	4	main
sellel	doc_154182424414_item	2247005	et	4	main
viikingiaeg	doc_154182424414_item	2246922	et	3	main
800-1050	doc_154182424414_item	2246933	et	2	main
toodeks	doc_154182424414_item	2246941	et	3	main
oli	doc_154182424414_item	2246951	et	3	main
territooriumil	doc_154182424414_item	2246954	et	3	main
leitud	doc_154182424414_item	2246956	et	4	main
kuuluvad	doc_154182424414_item	2246960	et	4	main
maksti	doc_154182424414_item	2246964	et	3	main
orjatar	doc_154182424414_item	2246973	et	3	main
sellel	doc_154182424414_item	2246982	et	4	main
oli	doc_154182424414_item	2246984	et	3	main
kontlikte	doc_154182424414_item	2246987	et	4	main
skandinaavlastega	doc_154182424414_item	2246989	et	3	main
räägitakse	doc_154182424414_item	2246991	et	3	main
ajal	doc_154182424414_item	2247006	et	4	main
tark	doc_154182424414_item	2247008	et	3	main
rajab	doc_154182424414_item	2247009	et	3	main
linna	doc_154182424414_item	2247010	et	4	main
jurjev	doc_154182424414_item	2247011	et	4	main
see	doc_154182424414_item	2247012	et	3	main
sai	doc_154182424414_item	2247013	et	4	main
esimeseks	doc_154182424414_item	2247014	et	3	main
vene	doc_154182424414_item	2247015	et	4	main
tugipunktiks	doc_154182424414_item	2247016	et	4	main
millest	doc_154182424414_item	2247017	et	3	main
kirjutatakse	doc_154182424414_item	2247018	et	3	main
ka	doc_154182424414_item	2247019	et	3	main
kroonikas	doc_154182424414_item	2247020	et	3	main
9-10	doc_154182424414_item	2247021	et	2	main
järve	doc_154182424414_item	2247024	et	4	main
kasutusel	doc_154182424414_item	2247032	et	4	main
mõned	doc_154182424414_item	2247042	et	3	main
kaal	doc_154182424414_item	2247046	et	3	main
aktiivsed	doc_154182424414_item	2247052	et	3	main
hobuloomad	doc_154182424414_item	2247062	et	3	main
vajalikud	doc_154182424414_item	2247065	et	3	main
põllumajandust	doc_154182424414_item	2247108	et	3	main
2	doc_154182424414_item	2247126	et	2	main
kestab	doc_154182424414_item	2247130	et	4	main
lõpuni	doc_154182424414_item	2247134	et	3	main
küsimusele	doc_154182424415_item	2247136	et	4	main
2	doc_154182424415_item	2247141	et	2	main
muinasusundi	doc_154182424415_item	2247147	et	3	main
päris	doc_154182424415_item	2247156	et	4	main
igasugused	doc_154182424415_item	2247161	et	3	main
inimestel	doc_154182424415_item	2247170	et	3	main
keeruline	doc_154182424415_item	2247172	et	4	main
ja	doc_154182424415_item	2247175	et	3	main
hauatagusest	doc_154182424415_item	2247177	et	3	main
hingest	doc_154182424415_item	2247180	et	4	main
maeti	doc_154182424415_item	2247182	et	3	main
tarbeesemed	doc_154182424415_item	2247230	et	3	main
saj	doc_154182424415_item	2247233	et	4	main
ilmusid	doc_154182424415_item	2247236	et	4	main
olid	doc_154182424415_item	2247240	et	4	main
suurematest	doc_154182424415_item	2247242	et	4	main
kivimetest	doc_154182424415_item	2247243	et	4	main
ja	doc_154182424415_item	2247254	et	3	main
ka	doc_154182424415_item	2247263	et	3	main
sümbol	doc_154182424415_item	2247273	et	3	main
arvasid	doc_154182424415_item	2247278	et	4	main
et	doc_154182424415_item	2247279	et	3	main
ja	doc_154182424415_item	2247281	et	3	main
hiljemalt	doc_154182424415_item	2247290	et	3	main
hõbedat	doc_154182424415_item	2247292	et	3	main
tööriist	doc_154182424415_item	2247296	et	3	main
mida	doc_154182424415_item	2247297	et	4	main
jõkke	doc_154182424415_item	2247299	et	3	main
suur	doc_154182424414_item	2247000	et	3	main
oli	doc_154182424414_item	2247002	et	3	main
ääres	doc_154182424414_item	2247025	et	4	main
tekivad	doc_154182424414_item	2247026	et	3	main
on	doc_154182424414_item	2247031	et	4	main
kaalusüsteem	doc_154182424414_item	2247033	et	3	main
mis	doc_154182424414_item	2247034	et	4	main
ka	doc_154182424414_item	2247036	et	3	main
territooriumi	doc_154182424414_item	2247038	et	4	main
ka	doc_154182424414_item	2247041	et	3	main
suhtes	doc_154182424414_item	2247055	et	4	main
münte	doc_154182424414_item	2247060	et	3	main
kallid	doc_154182424414_item	2247067	et	3	main
suulata	doc_154182424414_item	2247092	et	4	main
tööriistad	doc_154182424414_item	2247094	et	3	main
areneda	doc_154182424414_item	2247109	et	3	main
oli	doc_154182424414_item	2247111	et	3	main
peipsi	doc_154182424414_item	2247023	et	4	main
asulad	doc_154182424414_item	2247028	et	3	main
tuleb	doc_154182424414_item	2247035	et	3	main
tulevad	doc_154182424414_item	2247040	et	4	main
nt	doc_154182424414_item	2247044	et	4	main
ise	doc_154182424414_item	2247048	et	4	main
ka	doc_154182424414_item	2247050	et	3	main
lääne	doc_154182424414_item	2247054	et	4	main
väga	doc_154182424414_item	2247064	et	3	main
ja	doc_154182424414_item	2247066	et	3	main
tegelesid	doc_154182424414_item	2247070	et	4	main
kasvatamisega	doc_154182424414_item	2247072	et	4	main
inimesed	doc_154182424414_item	2247073	et	3	main
koduloomade	doc_154182424414_item	2247071	et	4	main
elasid	doc_154182424414_item	2247074	et	4	main
rohkem	doc_154182424414_item	2247075	et	4	main
veekogude	doc_154182424414_item	2247076	et	3	main
juures	doc_154182424414_item	2247077	et	4	main
seal	doc_154182424414_item	2247078	et	4	main
kus	doc_154182424414_item	2247079	et	3	main
saab	doc_154182424414_item	2247080	et	3	main
palju	doc_154182424414_item	2247081	et	4	main
head	doc_154182424414_item	2247082	et	4	main
heina	doc_154182424414_item	2247083	et	4	main
inimesed	doc_154182424414_item	2247084	et	3	main
oskasid	doc_154182424414_item	2247085	et	4	main
juba	doc_154182424414_item	2247086	et	3	main
pronksi	doc_154182424414_item	2247087	et	4	main
ja	doc_154182424414_item	2247088	et	3	main
metalli	doc_154182424414_item	2247089	et	4	main
töödelda	doc_154182424414_item	2247090	et	4	main
olid	doc_154182424414_item	2247049	et	4	main
leitud	doc_154182424414_item	2247057	et	4	main
kuna	doc_154182424414_item	2247061	et	3	main
olid	doc_154182424414_item	2247063	et	4	main
paljud	doc_154182424414_item	2247069	et	3	main
tugev	doc_154182424414_item	2247098	et	4	main
need	doc_154182424414_item	2247104	et	3	main
aitasid	doc_154182424414_item	2247106	et	4	main
üle	doc_154182424414_item	2247112	et	3	main
pärast	doc_154182424414_item	2247114	et	4	main
olid	doc_154182424414_item	2247118	et	4	main
tahtsid	doc_154182424414_item	2247122	et	4	main
oma	doc_154182424414_item	2247124	et	4	main
muinasusundi	doc_154182424415_item	2247139	et	3	main
üsna	doc_154182424415_item	2247150	et	3	main
kuna	doc_154182424415_item	2247153	et	3	main
kuid	doc_154182424415_item	2247165	et	4	main
kindlasti	doc_154182424415_item	2247167	et	3	main
ettekujutus	doc_154182424415_item	2247176	et	4	main
surnuid	doc_154182424415_item	2247181	et	4	main
mugavas	doc_154182424415_item	2247221	et	3	main
hauapanused	doc_154182424415_item	2247224	et	3	main
endiselt	doc_154182424415_item	2247226	et	4	main
ekr	doc_154182424415_item	2247234	et	4	main
rajutati	doc_154182424415_item	2247246	et	3	main
sõdade	doc_154182424415_item	2247253	et	3	main
aeg	doc_154182424415_item	2247256	et	3	main
ajal	doc_154182424415_item	2247258	et	4	main
surnutele	doc_154182424415_item	2247260	et	4	main
muinasaja	doc_154182424415_item	2247275	et	3	main
inimesed	doc_154182424415_item	2247277	et	3	main
surnute	doc_154182424415_item	2247284	et	4	main
ohverdati	doc_154182424415_item	2247298	et	3	main
rahva	doc_154182424415_item	2247305	et	3	main
erilise	doc_154182424415_item	2247307	et	4	main
ei	doc_154182424415_item	2247319	et	4	main
ennast	doc_154182424415_item	2247321	et	4	main
ja	doc_154182424415_item	2247323	et	3	main
sellepärast	doc_154182424415_item	2247324	et	3	main
püsis	doc_154182424415_item	2247326	et	4	main
kõige	doc_154182424415_item	2247327	et	4	main
raiuti	doc_154182424415_item	2247355	et	3	main
ja	doc_154182424415_item	2247357	et	3	main
vältel	doc_154182424415_item	2247365	et	4	main
hakkati	doc_154182424415_item	2247370	et	3	main
eestlaste	doc_154182424416_item	2247378	et	4	main
kogu	doc_154182424416_item	2247409	et	4	main
protsessi	doc_154182424416_item	2247410	et	4	main
iseloomulik	doc_154182424416_item	2247412	et	3	main
näiteks	doc_154182424416_item	2247416	et	4	main
loodusel	doc_154182424416_item	2247418	et	4	main
ja	doc_154182424416_item	2247419	et	3	main
hing	doc_154182424416_item	2247425	et	3	main
kõrval	doc_154182424416_item	2247430	et	4	main
oli	doc_154182424416_item	2247431	et	3	main
eluta	doc_154182424416_item	2247436	et	3	main
puid	doc_154182424416_item	2247438	et	3	main
hakati	doc_154182424416_item	2247441	et	3	main
suur	doc_154182424416_item	2247449	et	3	main
leiba	doc_154182424416_item	2247459	et	4	main
ehteid	doc_154182424416_item	2247462	et	3	main
vahel	doc_154182424416_item	2247464	et	4	main
ka	doc_154182424416_item	2247466	et	3	main
ohverdamisega	doc_154182424416_item	2247467	et	4	main
kuni	doc_154182424416_item	2247470	et	3	main
peale	doc_154182424416_item	2247477	et	4	main
viidud	doc_154182424416_item	2247510	et	4	main
mõjub	doc_154182424416_item	2247516	et	3	main
hästi	doc_154182424416_item	2247518	et	3	main
seda	doc_154182424416_item	2247520	et	3	main
vaimud	doc_154182424416_item	2247528	et	3	main
õnn	doc_154182424416_item	2247540	et	3	main
küsimusele	doc_154182424417_item	2247555	et	4	main
muinasusundi	doc_154182424417_item	2247558	et	3	main
mis	doc_154182424417_item	2247561	et	4	main
1	doc_154182424417_item	2247564	et	2	main
ei	doc_154182424417_item	2247573	et	4	main
surnuid	doc_154182424417_item	2247579	et	4	main
ka	doc_154182424417_item	2247584	et	3	main
sisse	doc_154182424417_item	2247591	et	4	main
koos	doc_154182424417_item	2247609	et	4	main
rauaajal	doc_154182424417_item	2247613	et	3	main
juba	doc_154182424414_item	2247096	et	3	main
paremad	doc_154182424414_item	2247097	et	4	main
teraga	doc_154182424414_item	2247099	et	3	main
nt	doc_154182424414_item	2247100	et	4	main
sirp	doc_154182424414_item	2247101	et	3	main
oder	doc_154182424414_item	2247103	et	3	main
tööriistad	doc_154182424414_item	2247105	et	3	main
ka	doc_154182424414_item	2247107	et	3	main
müüdi	doc_154182424414_item	2247116	et	4	main
loomulikult	doc_154182424414_item	2247121	et	4	main
kaitsta	doc_154182424414_item	2247123	et	4	main
tulekutrauaaja	doc_154182424414_item	2247133	et	4	main
vastus	doc_154182424415_item	2247135	et	3	main
kirjeldada	doc_154182424415_item	2247152	et	3	main
pikk	doc_154182424415_item	2247157	et	4	main
ajajärk	doc_154182424415_item	2247158	et	3	main
ja	doc_154182424415_item	2247159	et	3	main
ja	doc_154182424415_item	2247162	et	3	main
protsess	doc_154182424415_item	2247164	et	3	main
öelda	doc_154182424415_item	2247168	et	4	main
oli	doc_154182424415_item	2247171	et	3	main
uskumuste	doc_154182424415_item	2247173	et	4	main
süsteem	doc_154182424415_item	2247174	et	3	main
elust	doc_154182424415_item	2247178	et	3	main
poosis	doc_154182424415_item	2247222	et	3	main
8	doc_154182424415_item	2247231	et	2	main
eestis	doc_154182424415_item	2247235	et	3	main
nö	doc_154182424415_item	2247237	et	4	main
ja	doc_154182424415_item	2247244	et	3	main
noorem	doc_154182424415_item	2247250	et	4	main
relvi	doc_154182424415_item	2247264	et	4	main
vahel	doc_154182424415_item	2247265	et	4	main
elu	doc_154182424415_item	2247270	et	4	main
kõigi	doc_154182424415_item	2247274	et	4	main
jooksul	doc_154182424415_item	2247276	et	4	main
ohverdati	doc_154182424415_item	2247286	et	3	main
tööriistu	doc_154182424415_item	2247287	et	3	main
oli	doc_154182424415_item	2247295	et	3	main
peamiseks	doc_154182424415_item	2247302	et	3	main
jaoks	doc_154182424415_item	2247306	et	4	main
teada	doc_154182424415_item	2247315	et	3	main
rahvad	doc_154182424415_item	2247318	et	3	main
komme	doc_154182424415_item	2247335	et	4	main
mis	doc_154182424415_item	2247336	et	4	main
ja	doc_154182424415_item	2247340	et	3	main
soov	doc_154182424415_item	2247346	et	3	main
põllumaa	doc_154182424415_item	2247352	et	4	main
jäi	doc_154182424415_item	2247360	et	3	main
aasta	doc_154182424415_item	2247364	et	4	main
varasel	doc_154182424415_item	2247372	et	4	main
muinasusundi	doc_154182424416_item	2247379	et	3	main
elus	doc_154182424416_item	2247420	et	4	main
puudel	doc_154182424416_item	2247422	et	4	main
elus	doc_154182424416_item	2247435	et	4	main
allikaid	doc_154182424416_item	2247440	et	3	main
pühaks	doc_154182424416_item	2247442	et	3	main
sest	doc_154182424416_item	2247444	et	4	main
oli	doc_154182424416_item	2247452	et	3	main
ohverdati	doc_154182424416_item	2247456	et	3	main
vilja	doc_154182424416_item	2247458	et	4	main
liha	doc_154182424416_item	2247460	et	4	main
maagia	doc_154182424416_item	2247469	et	4	main
13	doc_154182424416_item	2247471	et	2	main
inimesi	doc_154182424416_item	2247474	et	4	main
põletusmatus	doc_154182424416_item	2247476	et	3	main
ja	doc_154182424416_item	2247512	et	3	main
varat	doc_154182424414_item	2247125	et	4	main
muinasaeg	doc_154182424414_item	2247127	et	3	main
mis	doc_154182424415_item	2247142	et	4	main
1	doc_154182424415_item	2247145	et	2	main
raske	doc_154182424415_item	2247151	et	4	main
muinasaeg	doc_154182424415_item	2247154	et	3	main
võib	doc_154182424415_item	2247166	et	3	main
asula	doc_154182424415_item	2247183	et	4	main
vahel	doc_154182424415_item	2247185	et	4	main
püstkoja	doc_154182424415_item	2247187	et	3	main
põranda	doc_154182424415_item	2247188	et	3	main
isegi	doc_154182424415_item	2247186	et	4	main
alla	doc_154182424415_item	2247189	et	3	main
kaasa	doc_154182424415_item	2247190	et	4	main
pandi	doc_154182424415_item	2247191	et	4	main
tööriistu	doc_154182424415_item	2247192	et	3	main
tarbeesemeid	doc_154182424415_item	2247193	et	3	main
amuleti	doc_154182424415_item	2247194	et	3	main
ja	doc_154182424415_item	2247195	et	3	main
ehte	doc_154182424415_item	2247196	et	3	main
funktsioonis	doc_154182424415_item	2247197	et	3	main
merevaik	doc_154182424415_item	2247198	et	3	main
mis	doc_154182424415_item	2247199	et	4	main
oli	doc_154182424415_item	2247200	et	3	main
asukate	doc_154182424415_item	2247201	et	4	main
jaoks	doc_154182424415_item	2247202	et	4	main
päikese	doc_154182424415_item	2247203	et	4	main
kivi	doc_154182424415_item	2247204	et	4	main
nöörkeraamika	doc_154182424415_item	2247205	et	4	main
hõimudeni	doc_154182424415_item	2247206	et	3	main
neoliitikumi	doc_154182424415_item	2247207	et	4	main
teisel	doc_154182424415_item	2247208	et	4	main
poolel	doc_154182424415_item	2247209	et	4	main
jõudsid	doc_154182424415_item	2247210	et	4	main
kalmed	doc_154182424415_item	2247211	et	3	main
väljaspool	doc_154182424415_item	2247212	et	3	main
asula	doc_154182424415_item	2247213	et	4	main
inimesi	doc_154182424415_item	2247215	et	4	main
sängitati	doc_154182424415_item	2247216	et	3	main
territooriumi	doc_154182424415_item	2247214	et	4	main
nüüd	doc_154182424415_item	2247217	et	4	main
mitte	doc_154182424415_item	2247218	et	3	main
selili	doc_154182424415_item	2247219	et	3	main
vaid	doc_154182424415_item	2247220	et	3	main
9	doc_154182424415_item	2247232	et	2	main
küljel	doc_154182424415_item	2247223	et	3	main
olid	doc_154182424415_item	2247225	et	4	main
tööriistad	doc_154182424415_item	2247227	et	3	main
ehted	doc_154182424415_item	2247228	et	3	main
ja	doc_154182424415_item	2247229	et	3	main
kirst	doc_154182424415_item	2247247	et	3	main
keskmine	doc_154182424415_item	2247248	et	3	main
ja	doc_154182424415_item	2247249	et	3	main
rauaaeg	doc_154182424415_item	2247251	et	3	main
konfliktide	doc_154182424415_item	2247255	et	3	main
sellel	doc_154182424415_item	2247257	et	4	main
vere	doc_154182424415_item	2247272	et	3	main
austamisest	doc_154182424415_item	2247285	et	4	main
ja	doc_154182424415_item	2247288	et	3	main
ka	doc_154182424415_item	2247291	et	3	main
näiteks	doc_154182424415_item	2247293	et	4	main
rooma	doc_154182424415_item	2247300	et	4	main
elatusalaks	doc_154182424415_item	2247303	et	3	main
toimingud	doc_154182424415_item	2247311	et	3	main
mõjutamiseks	doc_154182424415_item	2247313	et	4	main
lubanud	doc_154182424415_item	2247320	et	4	main
kivikirstkalmed	doc_154182424415_item	2247238	et	4	main
mis	doc_154182424415_item	2247239	et	4	main
valmistatud	doc_154182424415_item	2247241	et	4	main
sisse	doc_154182424415_item	2247245	et	4	main
oli	doc_154182424415_item	2247252	et	3	main
hakkati	doc_154182424415_item	2247259	et	3	main
kaasa	doc_154182424415_item	2247261	et	4	main
panema	doc_154182424415_item	2247262	et	3	main
haudadest	doc_154182424415_item	2247266	et	3	main
avastatud	doc_154182424415_item	2247267	et	4	main
ka	doc_154182424415_item	2247268	et	3	main
okrit	doc_154182424415_item	2247269	et	4	main
ja	doc_154182424415_item	2247271	et	3	main
edu	doc_154182424415_item	2247280	et	4	main
õnne	doc_154182424415_item	2247282	et	4	main
sõltuvad	doc_154182424415_item	2247283	et	4	main
tarbeesemeid	doc_154182424415_item	2247289	et	3	main
sirp	doc_154182424415_item	2247294	et	3	main
on	doc_154182424415_item	2247304	et	4	main
omandanud	doc_154182424415_item	2247309	et	4	main
et	doc_154182424415_item	2247316	et	3	main
kauem	doc_154182424415_item	2247328	et	4	main
muinasusklikuna	doc_154182424415_item	2247329	et	3	main
ulatub	doc_154182424415_item	2247337	et	3	main
rooma	doc_154182424415_item	2247338	et	4	main
rauaaega	doc_154182424415_item	2247339	et	4	main
uskumuslikuks	doc_154182424415_item	2247342	et	4	main
on	doc_154182424415_item	2247344	et	4	main
suurendada	doc_154182424415_item	2247347	et	3	main
väge	doc_154182424415_item	2247349	et	3	main
kasutati	doc_154182424415_item	2247362	et	4	main
mulla	doc_154182424415_item	2247367	et	4	main
ajal	doc_154182424415_item	2247374	et	4	main
küsimusele	doc_154182424416_item	2247376	et	4	main
1	doc_154182424416_item	2247411	et	2	main
animism	doc_154182424416_item	2247413	et	3	main
et	doc_154182424416_item	2247415	et	3	main
eluta	doc_154182424416_item	2247417	et	3	main
esivanemate	doc_154182424416_item	2247427	et	4	main
kive	doc_154182424416_item	2247439	et	3	main
neil	doc_154182424416_item	2247447	et	4	main
villa	doc_154182424416_item	2247457	et	4	main
kaasnes	doc_154182424416_item	2247468	et	3	main
maeti	doc_154182424416_item	2247473	et	3	main
põletatult	doc_154182424416_item	2247475	et	4	main
kalmed	doc_154182424416_item	2247481	et	3	main
allikavee	doc_154182424416_item	2247514	et	3	main
tervisele	doc_154182424416_item	2247517	et	3	main
ka	doc_154182424416_item	2247530	et	3	main
eestlased	doc_154182424416_item	2247534	et	3	main
uskusid	doc_154182424416_item	2247535	et	4	main
taarat	doc_154182424416_item	2247536	et	3	main
edu	doc_154182424416_item	2247537	et	4	main
majanduslik	doc_154182424416_item	2247539	et	3	main
eestlaste	doc_154182424416_item	2247543	et	4	main
kõige	doc_154182424416_item	2247549	et	4	main
tugevamaks	doc_154182424416_item	2247550	et	4	main
loodusjõuks	doc_154182424416_item	2247551	et	3	main
1	doc_154182424417_item	2247556	et	2	main
neoliitikumi	doc_154182424417_item	2247565	et	4	main
ettekujutus	doc_154182424417_item	2247568	et	4	main
uskust	doc_154182424417_item	2247569	et	4	main
oli	doc_154182424417_item	2247570	et	3	main
tihti	doc_154182424417_item	2247583	et	3	main
põranda	doc_154182424417_item	2247586	et	3	main
magavas	doc_154182424417_item	2247588	et	4	main
tööriistu	doc_154182424417_item	2247596	et	3	main
ehted	doc_154182424417_item	2247598	et	3	main
ettekujutust	doc_154182424417_item	2247602	et	4	main
inimestega	doc_154182424417_item	2247610	et	3	main
toimingud	doc_154182424417_item	2247615	et	3	main
juba	doc_154182424417_item	2247617	et	3	main
arvatakse	doc_154182424417_item	2247622	et	3	main
tuule	doc_154182424417_item	2247628	et	3	main
peale	doc_154182424417_item	2247633	et	4	main
elus	doc_154182424417_item	2247642	et	4	main
inimesed	doc_154182424417_item	2247647	et	3	main
et	doc_154182424417_item	2247659	et	3	main
alepõllundus	doc_154182424417_item	2247665	et	3	main
põletatakse	doc_154182424417_item	2247673	et	3	main
perestroika	doc_158183956827_item	2247714	et	4	main
rauaajal	doc_154182424415_item	2247301	et	3	main
tähtsuse	doc_154182424415_item	2247308	et	4	main
maagilised	doc_154182424415_item	2247310	et	4	main
ilmastiku	doc_154182424415_item	2247312	et	4	main
on	doc_154182424415_item	2247314	et	4	main
baltimaade	doc_154182424415_item	2247317	et	3	main
ristida	doc_154182424415_item	2247322	et	4	main
on	doc_154182424415_item	2247332	et	4	main
jäänud	doc_154182424415_item	2247333	et	4	main
tagamaaks	doc_154182424415_item	2247343	et	3	main
olnud	doc_154182424415_item	2247345	et	4	main
mets	doc_154182424415_item	2247354	et	3	main
kuni	doc_154182424415_item	2247366	et	3	main
viljakus	doc_154182424415_item	2247368	et	4	main
langes	doc_154182424415_item	2247369	et	4	main
kasutama	doc_154182424415_item	2247371	et	3	main
metalli	doc_154182424415_item	2247373	et	4	main
1	doc_154182424416_item	2247377	et	2	main
üldiseloomustus	doc_154182424416_item	2247380	et	4	main
usuti	doc_154182424416_item	2247414	et	3	main
baltimaa	doc_154182424415_item	2247325	et	4	main
tänase	doc_154182424415_item	2247330	et	3	main
päevani	doc_154182424415_item	2247331	et	3	main
jaanitule	doc_154182424415_item	2247334	et	4	main
mille	doc_154182424415_item	2247341	et	3	main
päikese	doc_154182424415_item	2247348	et	4	main
2	doc_154182424415_item	2247350	et	2	main
alepõllundus	doc_154182424415_item	2247351	et	3	main
saamiseks	doc_154182424415_item	2247353	et	4	main
maha	doc_154182424415_item	2247356	et	4	main
põletati	doc_154182424415_item	2247358	et	3	main
tuhk	doc_154182424415_item	2247359	et	3	main
väetiseks	doc_154182424415_item	2247361	et	3	main
mõne	doc_154182424415_item	2247363	et	3	main
vastus	doc_154182424416_item	2247375	et	3	main
2	doc_154182424416_item	2247381	et	2	main
mis	doc_154182424416_item	2247382	et	4	main
on	doc_154182424416_item	2247383	et	4	main
alepõllundus	doc_154182424416_item	2247384	et	3	main
2	doc_154182424416_item	2247385	et	2	main
mets	doc_154182424416_item	2247386	et	3	main
raiuti	doc_154182424416_item	2247387	et	3	main
põletati	doc_154182424416_item	2247388	et	3	main
maha	doc_154182424416_item	2247389	et	4	main
tuhk	doc_154182424416_item	2247390	et	3	main
jäi	doc_154182424416_item	2247391	et	3	main
väetiseks	doc_154182424416_item	2247392	et	3	main
kasutati	doc_154182424416_item	2247393	et	4	main
ainult	doc_154182424416_item	2247394	et	4	main
paar	doc_154182424416_item	2247395	et	3	main
aastat	doc_154182424416_item	2247396	et	3	main
kuni	doc_154182424416_item	2247397	et	3	main
mulla	doc_154182424416_item	2247398	et	4	main
viljakus	doc_154182424416_item	2247399	et	4	main
langes	doc_154182424416_item	2247400	et	4	main
kasvatati	doc_154182424416_item	2247401	et	3	main
uus	doc_154182424416_item	2247402	et	3	main
võsa	doc_154182424416_item	2247403	et	4	main
peale	doc_154182424416_item	2247404	et	4	main
mõnekümne	doc_154182424416_item	2247405	et	4	main
aasta	doc_154182424416_item	2247406	et	4	main
pärast	doc_154182424416_item	2247407	et	4	main
korrati	doc_154182424416_item	2247408	et	4	main
on	doc_154182424416_item	2247424	et	4	main
vägi	doc_154182424416_item	2247434	et	3	main
looduses	doc_154182424416_item	2247437	et	4	main
on	doc_154182424416_item	2247448	et	4	main
levinud	doc_154182424416_item	2247451	et	4	main
ohverdamine	doc_154182424416_item	2247453	et	4	main
loodusobjektidele	doc_154182424416_item	2247454	et	3	main
ka	doc_154182424416_item	2247461	et	3	main
ning	doc_154182424416_item	2247463	et	3	main
loomi	doc_154182424416_item	2247465	et	4	main
saj	doc_154182424416_item	2247472	et	4	main
ristiusustamist	doc_154182424416_item	2247478	et	3	main
lõppes	doc_154182424416_item	2247479	et	4	main
selle	doc_154182424416_item	2247513	et	4	main
joomine	doc_154182424416_item	2247515	et	4	main
veel	doc_154182424416_item	2247521	et	4	main
et	doc_154182424416_item	2247523	et	3	main
keda	doc_154182424416_item	2247532	et	4	main
muistsete	doc_154182424416_item	2247542	et	3	main
arvates	doc_154182424416_item	2247544	et	4	main
heast	doc_154182424416_item	2247545	et	3	main
läbisaamisest	doc_154182424416_item	2247546	et	4	main
esivanematega	doc_154182424416_item	2247548	et	4	main
äike	doc_154182424416_item	2247553	et	3	main
ajal	doc_154182424417_item	2247566	et	4	main
saanud	doc_154182424417_item	2247574	et	4	main
mis	doc_154182424417_item	2247576	et	4	main
on	doc_154182424417_item	2247577	et	4	main
surm	doc_154182424417_item	2247578	et	3	main
sängitati	doc_154182424417_item	2247580	et	3	main
alla	doc_154182424417_item	2247587	et	3	main
haua	doc_154182424417_item	2247590	et	3	main
pani	doc_154182424417_item	2247592	et	4	main
nn	doc_154182424417_item	2247593	et	4	main
ning	doc_154182424417_item	2247600	et	3	main
religioon	doc_154182424417_item	2247607	et	3	main
siis	doc_154182424417_item	2247611	et	3	main
vanemal	doc_154182424417_item	2247612	et	4	main
maagilised	doc_154182424417_item	2247614	et	4	main
olid	doc_154182424417_item	2247616	et	4	main
jaoks	doc_154182424417_item	2247621	et	4	main
et	doc_154182424417_item	2247623	et	3	main
neile	doc_154182424417_item	2247636	et	4	main
mis	doc_154182424417_item	2247639	et	4	main
järgmises	doc_154182424417_item	2247641	et	3	main
huvitama	doc_154182424417_item	2247654	et	3	main
religiooniga	doc_154182424417_item	2247655	et	3	main
inimestel	doc_154182424417_item	2247660	et	3	main
toimus	doc_154182424417_item	2247661	et	3	main
2	doc_154182424417_item	2247664	et	2	main
kasutatakse	doc_154182424417_item	2247680	et	3	main
mõisted	doc_158183956827_item	2247711	et	3	main
on	doc_158183956827_item	2247718	et	4	main
rahvarinde	doc_158183956827_item	2247719	et	4	main
ei	doc_158183956827_item	2247737	et	4	main
saa	doc_158183956827_item	2247738	et	4	main
aita	doc_158183956827_item	2247744	et	4	main
peab	doc_158183956827_item	2247749	et	4	main
valitud	doc_158183956827_item	2247763	et	4	main
rääkima	doc_158183956827_item	2247766	et	3	main
need	doc_158183956827_item	2247774	et	3	main
sõna	doc_158183956827_item	2247796	et	4	main
nsvsse	doc_158183956827_item	2247799	et	4	main
loodusel	doc_154182424416_item	2247421	et	4	main
kividel	doc_154182424416_item	2247423	et	3	main
surnute	doc_154182424416_item	2247426	et	4	main
austamine	doc_154182424416_item	2247428	et	4	main
hinge	doc_154182424416_item	2247429	et	4	main
tähtis	doc_154182424416_item	2247432	et	4	main
ka	doc_154182424416_item	2247433	et	3	main
pidama	doc_154182424416_item	2247443	et	4	main
usuti	doc_154182424416_item	2247445	et	3	main
et	doc_154182424416_item	2247446	et	3	main
vägi	doc_154182424416_item	2247450	et	3	main
põhiliselt	doc_154182424416_item	2247455	et	4	main
see	doc_154182424416_item	2247480	et	3	main
e	doc_154182424416_item	2247482	et	4	main
muistsed	doc_154182424416_item	2247483	et	3	main
matusepaigad	doc_154182424416_item	2247484	et	3	main
seal	doc_154182424416_item	2247485	et	4	main
ohverdati	doc_154182424416_item	2247486	et	3	main
surnute	doc_154182424416_item	2247487	et	4	main
hingedele	doc_154182424416_item	2247488	et	3	main
toitu	doc_154182424416_item	2247489	et	4	main
oad	doc_154182424416_item	2247490	et	3	main
herned	doc_154182424416_item	2247491	et	3	main
jm	doc_154182424416_item	2247492	et	4	main
kuni	doc_154182424416_item	2247493	et	3	main
tänase	doc_154182424416_item	2247494	et	3	main
päevani	doc_154182424416_item	2247495	et	3	main
on	doc_154182424416_item	2247496	et	4	main
eestlastel	doc_154182424416_item	2247497	et	4	main
kokkukuuluvus	doc_154182424416_item	2247498	et	4	main
surnud	doc_154182424416_item	2247499	et	4	main
esivanematega	doc_154182424416_item	2247500	et	4	main
kalmistupühad	doc_154182424416_item	2247501	et	3	main
puudele	doc_154182424416_item	2247502	et	4	main
ohverdati	doc_154182424416_item	2247503	et	3	main
värvilisi	doc_154182424416_item	2247504	et	4	main
paelu	doc_154182424416_item	2247505	et	4	main
juurtele	doc_154182424416_item	2247506	et	3	main
valati	doc_154182424416_item	2247507	et	3	main
ohvrijooki	doc_154182424416_item	2247508	et	4	main
allikaveele	doc_154182424416_item	2247509	et	3	main
hõberaha	doc_154182424416_item	2247511	et	4	main
usuti	doc_154182424416_item	2247519	et	3	main
usuti	doc_154182424416_item	2247522	et	3	main
loodust	doc_154182424416_item	2247524	et	4	main
valvavad	doc_154182424416_item	2247525	et	4	main
ja	doc_154182424416_item	2247526	et	3	main
kaitsevad	doc_154182424416_item	2247527	et	4	main
tekkisid	doc_154182424416_item	2247529	et	4	main
ja	doc_154182424416_item	2247538	et	3	main
surnud	doc_154182424416_item	2247547	et	4	main
oli	doc_154182424416_item	2247552	et	3	main
eestlaste	doc_154182424417_item	2247557	et	4	main
üldiseloomustus	doc_154182424417_item	2247559	et	4	main
on	doc_154182424417_item	2247562	et	4	main
alepõllundus	doc_154182424417_item	2247563	et	3	main
keeruline	doc_154182424417_item	2247571	et	4	main
territooriumile	doc_154182424417_item	2247582	et	3	main
püstkoja	doc_154182424417_item	2247585	et	3	main
loomakujukesed	doc_154182424417_item	2247597	et	4	main
hingest	doc_154182424417_item	2247603	et	4	main
ei	doc_154182424417_item	2247604	et	4	main
olnud	doc_154182424417_item	2247605	et	4	main
pärineb	doc_154182424417_item	2247626	et	3	main
jaani	doc_154182424417_item	2247627	et	4	main
komme	doc_154182424417_item	2247629	et	4	main
maeti	doc_154182424417_item	2247631	et	3	main
esemed	doc_154182424417_item	2247638	et	3	main
on	doc_154182424417_item	2247643	et	4	main
jooksul	doc_154182424417_item	2247646	et	4	main
hakkasid	doc_154182424417_item	2247648	et	4	main
näitabki	doc_154182424417_item	2247658	et	3	main
maaharimise	doc_154182424417_item	2247667	et	3	main
viis	doc_154182424417_item	2247668	et	4	main
mets	doc_154182424417_item	2247670	et	3	main
saab	doc_154182424417_item	2247677	et	3	main
viljekuks	doc_154182424417_item	2247678	et	4	main
seda	doc_154182424417_item	2247679	et	3	main
2	doc_158183956827_item	2247708	et	2	main
mida	doc_158183956827_item	2247709	et	4	main
minu	doc_158183956827_item	2247716	et	3	main
väga	doc_158183956827_item	2247721	et	3	main
rahvas	doc_158183956827_item	2247730	et	4	main
mängis	doc_158183956827_item	2247731	et	3	main
isesesvumisprotsessis	doc_158183956827_item	2247732	et	4	main
osa	doc_158183956827_item	2247734	et	4	main
ju	doc_158183956827_item	2247748	et	3	main
rahvaga	doc_158183956827_item	2247750	et	3	main
ja	doc_158183956827_item	2247752	et	3	main
julgustama	doc_158183956827_item	2247753	et	3	main
võitlema	doc_158183956827_item	2247755	et	3	main
oma	doc_158183956827_item	2247756	et	4	main
kodumaa	doc_158183956827_item	2247757	et	4	main
üks	doc_158183956827_item	2247761	et	3	main
kõrgemal	doc_158183956827_item	2247770	et	4	main
poliitilisel	doc_158183956827_item	2247771	et	3	main
siis	doc_158183956827_item	2247781	et	3	main
arvan	doc_158183956827_item	2247783	et	3	main
rahvarinde	doc_158183956827_item	2247785	et	4	main
ja	doc_158183956827_item	2247792	et	3	main
glasnost	doc_158183956827_item	2247795	et	4	main
vabadus	doc_158183956827_item	2247797	et	4	main
tuli	doc_158183956827_item	2247800	et	4	main
glasnost	doc_158183956827_item	2247801	et	4	main
see	doc_158183956827_item	2247821	et	3	main
perestroika	doc_158183956827_item	2247826	et	4	main
mis	doc_158183956827_item	2247831	et	4	main
pidi	doc_158183956827_item	2247832	et	4	main
riiki	doc_158183956827_item	2247838	et	4	main
vaesusesse	doc_158183956827_item	2247839	et	4	main
mis	doc_158183956827_item	2247850	et	4	main
kuid	doc_158183956827_item	2247855	et	4	main
ei	doc_158183956827_item	2247859	et	4	main
roll	doc_158183956828_item	2247868	et	3	main
2	doc_158183956828_item	2247871	et	2	main
sellega	doc_158183956828_item	2247884	et	3	main
muutused	doc_158183956828_item	2247887	et	4	main
kaotati	doc_158183956828_item	2247891	et	3	main
ülikoolid	doc_158183956828_item	2247895	et	3	main
ja	doc_158183956828_item	2247902	et	3	main
koolimütse	doc_158183956828_item	2247905	et	3	main
koolides	doc_158183956828_item	2247913	et	3	main
gümnaasiumiteks	doc_158183956828_item	2247921	et	3	main
jumalad	doc_154182424416_item	2247531	et	3	main
usuti	doc_154182424416_item	2247533	et	3	main
sõltus	doc_154182424416_item	2247541	et	4	main
vastus	doc_154182424417_item	2247554	et	3	main
2	doc_154182424417_item	2247560	et	2	main
inimeste	doc_154182424417_item	2247567	et	3	main
nad	doc_154182424417_item	2247572	et	3	main
aru	doc_154182424417_item	2247575	et	4	main
asula	doc_154182424417_item	2247581	et	4	main
asendis	doc_154182424417_item	2247589	et	3	main
hauapanuseid	doc_154182424417_item	2247594	et	3	main
näiteks	doc_154182424417_item	2247595	et	4	main
jne	doc_154182424417_item	2247599	et	4	main
selges	doc_154182424417_item	2247601	et	3	main
kuna	doc_154182424417_item	2247606	et	3	main
areneb	doc_154182424417_item	2247608	et	3	main
päris	doc_154182424417_item	2247618	et	4	main
tähtsad	doc_154182424417_item	2247619	et	3	main
inimeste	doc_154182424417_item	2247620	et	3	main
ajast	doc_154182424417_item	2247625	et	4	main
surnuid	doc_154182424417_item	2247630	et	4	main
anti	doc_154182424417_item	2247635	et	3	main
mõned	doc_154182424417_item	2247637	et	3	main
on	doc_154182424417_item	2247640	et	4	main
aja	doc_154182424417_item	2247645	et	4	main
holitsema	doc_154182424417_item	2247650	et	4	main
surnute	doc_154182424417_item	2247651	et	4	main
ja	doc_154182424417_item	2247653	et	3	main
ning	doc_154182424417_item	2247656	et	3	main
vaimne	doc_154182424417_item	2247662	et	3	main
millal	doc_154182424417_item	2247669	et	3	main
rajatakse	doc_154182424417_item	2247671	et	4	main
siis	doc_154182424417_item	2247674	et	3	main
maa	doc_154182424417_item	2247676	et	4	main
aastate	doc_154182424417_item	2247681	et	3	main
jooksul	doc_154182424417_item	2247682	et	4	main
aga	doc_154182424417_item	2247683	et	3	main
kui	doc_154182424417_item	2247684	et	3	main
maa	doc_154182424417_item	2247685	et	4	main
omadused	doc_154182424417_item	2247686	et	4	main
halvenevad	doc_154182424417_item	2247687	et	4	main
jälle	doc_154182424417_item	2247688	et	3	main
kõik	doc_154182424417_item	2247689	et	4	main
põletatakse	doc_154182424417_item	2247690	et	3	main
ära	doc_154182424417_item	2247691	et	4	main
ning	doc_154182424417_item	2247692	et	3	main
alustatakse	doc_154182424417_item	2247693	et	3	main
algust	doc_154182424417_item	2247694	et	4	main
alepõllundusega	doc_154182424417_item	2247696	et	3	main
peale	doc_154182424417_item	2247695	et	4	main
inimesed	doc_154182424417_item	2247697	et	3	main
hakkasid	doc_154182424417_item	2247698	et	4	main
tegelema	doc_154182424417_item	2247699	et	3	main
varasel	doc_154182424417_item	2247700	et	4	main
rauaajal	doc_154182424417_item	2247701	et	3	main
1	doc_158183956827_item	2247703	et	2	main
kontrolltöö	doc_158183956827_item	2247702	et	4	main
rahvarinde	doc_158183956827_item	2247704	et	4	main
roll	doc_158183956827_item	2247705	et	3	main
eesti	doc_158183956827_item	2247706	et	4	main
sellest	doc_154182424417_item	2247624	et	4	main
maa	doc_154182424417_item	2247632	et	4	main
ning	doc_154182424417_item	2247634	et	3	main
vajalikud	doc_154182424417_item	2247644	et	3	main
rohkem	doc_154182424417_item	2247649	et	4	main
eest	doc_154182424417_item	2247652	et	4	main
see	doc_154182424417_item	2247657	et	3	main
areng	doc_154182424417_item	2247663	et	3	main
so	doc_154182424417_item	2247666	et	4	main
ja	doc_154182424417_item	2247672	et	3	main
kui	doc_154182424417_item	2247675	et	3	main
tähendavad	doc_158183956827_item	2247710	et	4	main
ja	doc_158183956827_item	2247713	et	3	main
1	doc_158183956827_item	2247715	et	2	main
oluline	doc_158183956827_item	2247723	et	4	main
isegi	doc_158183956827_item	2247725	et	4	main
muidugi	doc_158183956827_item	2247727	et	4	main
ka	doc_158183956827_item	2247728	et	3	main
surt	doc_158183956827_item	2247733	et	4	main
rahvas	doc_158183956827_item	2247736	et	4	main
kaugele	doc_158183956827_item	2247739	et	4	main
jõuda	doc_158183956827_item	2247740	et	3	main
kui	doc_158183956827_item	2247741	et	3	main
teda	doc_158183956827_item	2247742	et	4	main
ei	doc_158183956827_item	2247743	et	4	main
keegi	doc_158183956827_item	2247745	et	4	main
keegi	doc_158183956827_item	2247747	et	4	main
ja	doc_158183956827_item	2247759	et	3	main
aspekt	doc_158183956827_item	2247762	et	3	main
peavad	doc_158183956827_item	2247765	et	4	main
astmel	doc_158183956827_item	2247772	et	3	main
pavad	doc_158183956827_item	2247776	et	4	main
millest	doc_158183956827_item	2247778	et	3	main
mina	doc_158183956827_item	2247782	et	4	main
oli	doc_158183956827_item	2247789	et	3	main
2	doc_158183956827_item	2247794	et	2	main
siis	doc_158183956827_item	2247802	et	3	main
natuke	doc_158183956827_item	2247823	et	4	main
leebemaks	doc_158183956827_item	2247824	et	4	main
viis	doc_158183956827_item	2247837	et	4	main
laostama	doc_158183956827_item	2247844	et	3	main
nagu	doc_158183956827_item	2247856	et	3	main
see	doc_158183956827_item	2247858	et	3	main
rahvarinde	doc_158183956828_item	2247867	et	4	main
taasiseseivumisprotsessis	doc_158183956828_item	2247870	et	4	main
mida	doc_158183956828_item	2247872	et	4	main
ja	doc_158183956828_item	2247876	et	3	main
1	doc_158183956828_item	2247878	et	2	main
taasiseseisvaks	doc_158183956828_item	2247883	et	3	main
alguses	doc_158183956828_item	2247890	et	4	main
ära	doc_158183956828_item	2247892	et	4	main
oma	doc_158183956828_item	2247897	et	4	main
3	doc_158183956828_item	2247903	et	2	main
ei	doc_158183956828_item	2247906	et	4	main
on	doc_158183956828_item	2247914	et	4	main
koolid	doc_158183956828_item	2247918	et	3	main
ümber	doc_158183956828_item	2247920	et	3	main
mitte	doc_158183956828_item	2247923	et	3	main
nädalaks	doc_158183956828_item	2247935	et	3	main
oli	doc_158183956828_item	2247937	et	3	main
maksab	doc_158183956828_item	2247943	et	3	main
kõik	doc_158183956828_item	2247949	et	4	main
oli	doc_158183956828_item	2247956	et	3	main
päeval	doc_158183956828_item	2247964	et	3	main
muud	doc_158183956828_item	2247972	et	4	main
sa	doc_158183956828_item	2247974	et	3	main
kirjaliku	doc_158183956828_item	2247984	et	3	main
loa	doc_158183956828_item	2247985	et	4	main
mõne	doc_158183956828_item	2247986	et	3	main
on	doc_158183956828_item	2247991	et	4	main
hiv-positiivne	doc_158183956828_item	2247997	et	3	main
aids	doc_158183956828_item	2247998	et	4	main
oli	doc_158183956828_item	2248001	et	3	main
töökohti	doc_158183956828_item	2248003	et	4	main
tegelikult	doc_158183956828_item	2248005	et	4	main
muudatusi	doc_158183956828_item	2248023	et	3	main
nt	doc_158183956828_item	2248024	et	4	main
tehnikas	doc_158183956828_item	2248025	et	3	main
praegu	doc_158183956828_item	2248032	et	3	main
olnud	doc_158183956828_item	2248041	et	4	main
muusikakeskuseid	doc_158183956828_item	2248042	et	3	main
praegu	doc_158183956828_item	2248048	et	3	main
taasiseseivumisprotsessis	doc_158183956827_item	2247707	et	4	main
glasnost	doc_158183956827_item	2247712	et	4	main
arvates	doc_158183956827_item	2247717	et	4	main
roll	doc_158183956827_item	2247720	et	3	main
väga	doc_158183956827_item	2247722	et	3	main
kuid	doc_158183956827_item	2247735	et	4	main
ülevalt	doc_158183956827_item	2247746	et	4	main
rääkima	doc_158183956827_item	2247751	et	3	main
eest	doc_158183956827_item	2247758	et	4	main
inimesed	doc_158183956827_item	2247764	et	3	main
inimestega	doc_158183956827_item	2247767	et	3	main
seisavad	doc_158183956827_item	2247769	et	3	main
inimesed	doc_158183956827_item	2247775	et	3	main
teadma	doc_158183956827_item	2247777	et	3	main
rääkida	doc_158183956827_item	2247779	et	3	main
suurem	doc_158183956827_item	2247791	et	4	main
kui	doc_158183956827_item	2247798	et	3	main
see	doc_158183956827_item	2247827	et	3	main
gorbatsjovi	doc_158183956827_item	2247829	et	4	main
programm	doc_158183956827_item	2247842	et	3	main
vana	doc_158183956827_item	2247845	et	4	main
eluviisi	doc_158183956827_item	2247846	et	4	main
kaasaegsem	doc_158183956827_item	2247852	et	4	main
gumannsem	doc_158183956827_item	2247854	et	4	main
näha	doc_158183956827_item	2247857	et	3	main
õnnestunud	doc_158183956827_item	2247860	et	4	main
laostus	doc_158183956827_item	2247862	et	4	main
riigi	doc_158183956827_item	2247864	et	3	main
tähendavad	doc_158183956828_item	2247873	et	4	main
koolivorm	doc_158183956828_item	2247893	et	3	main
pidanud	doc_158183956828_item	2247907	et	4	main
enam	doc_158183956828_item	2247908	et	4	main
kandma	doc_158183956828_item	2247909	et	3	main
kuigi	doc_158183956828_item	2247910	et	3	main
praegu	doc_158183956828_item	2247911	et	3	main
see	doc_158183956828_item	2247915	et	3	main
aga	doc_158183956828_item	2247922	et	3	main
2	doc_158183956828_item	2247934	et	2	main
arstiabi	doc_158183956828_item	2247936	et	4	main
tasuta	doc_158183956828_item	2247939	et	4	main
haigekassa	doc_158183956828_item	2247944	et	4	main
mõned	doc_158183956828_item	2247945	et	3	main
ajal	doc_158183956828_item	2247951	et	4	main
asja	doc_158183956828_item	2247953	et	4	main
ei	doc_158183956828_item	2247954	et	4	main
kui	doc_158183956828_item	2247961	et	3	main
osta	doc_158183956828_item	2247966	et	4	main
külmkappi	doc_158183956828_item	2247969	et	4	main
pea	doc_158183956828_item	2247976	et	4	main
luba	doc_158183956828_item	2247979	et	4	main
tol	doc_158183956828_item	2247981	et	3	main
pidid	doc_158183956828_item	2247983	et	4	main
asja	doc_158183956828_item	2247988	et	4	main
muutunud	doc_158183956828_item	2247994	et	4	main
ei	doc_158183956828_item	2248006	et	4	main
ka	doc_158183956828_item	2248021	et	3	main
90	doc_158183956828_item	2248026	et	2	main
ei	doc_158183956828_item	2248040	et	4	main
mida	doc_158183956828_item	2248050	et	4	main
võime	doc_158183956828_item	2248052	et	4	main
osta	doc_158183956828_item	2248053	et	4	main
eest	doc_158183956828_item	2248055	et	4	main
eesti	doc_158183956828_item	2248063	et	4	main
läheb	doc_158183956828_item	2248064	et	3	main
aastat	doc_158183956828_item	2248094	et	3	main
perestroika	doc_158183956829_item	2248112	et	4	main
rahvarinne	doc_158183956829_item	2248114	et	3	main
a	doc_158183956829_item	2248117	et	4	main
mille	doc_158183956829_item	2248121	et	3	main
endasse	doc_158183956829_item	2248128	et	4	main
kultuuritegelasi	doc_158183956829_item	2248132	et	3	main
eesti	doc_158183956829_item	2248137	et	4	main
nsv	doc_158183956829_item	2248140	et	4	main
autonoomia	doc_158183956829_item	2248145	et	4	main
rahvarinde	doc_158183956829_item	2248147	et	4	main
veidi	doc_158183956829_item	2248151	et	3	main
muinsuskaitse	doc_158183956829_item	2248157	et	4	main
poliitikutel	doc_158183956829_item	2248159	et	3	main
paljud	doc_158183956829_item	2248161	et	3	main
impeeriumimeelselt	doc_158183956829_item	2248169	et	4	main
peamiselt	doc_158183956829_item	2248171	et	4	main
võib-olla	doc_158183956827_item	2247724	et	3	main
otsustav	doc_158183956827_item	2247726	et	4	main
eesti	doc_158183956827_item	2247729	et	4	main
teda	doc_158183956827_item	2247754	et	4	main
veel	doc_158183956827_item	2247760	et	4	main
kes	doc_158183956827_item	2247768	et	4	main
ja	doc_158183956827_item	2247773	et	3	main
nii	doc_158183956827_item	2247780	et	3	main
et	doc_158183956827_item	2247784	et	3	main
roll	doc_158183956827_item	2247786	et	3	main
eesti	doc_158183956827_item	2247787	et	4	main
taasiseseisvumisprotsessis	doc_158183956827_item	2247788	et	3	main
kõige	doc_158183956827_item	2247790	et	4	main
otsustavam	doc_158183956827_item	2247793	et	4	main
räägiti	doc_158183956827_item	2247803	et	3	main
et	doc_158183956827_item	2247804	et	3	main
nüüd	doc_158183956827_item	2247805	et	4	main
võib	doc_158183956827_item	2247806	et	3	main
kõike	doc_158183956827_item	2247807	et	4	main
öelda	doc_158183956827_item	2247808	et	4	main
ja	doc_158183956827_item	2247809	et	3	main
teha	doc_158183956827_item	2247810	et	3	main
mida	doc_158183956827_item	2247811	et	4	main
tahad	doc_158183956827_item	2247812	et	3	main
tsensuur	doc_158183956827_item	2247813	et	3	main
pidavat	doc_158183956827_item	2247814	et	4	main
üldse	doc_158183956827_item	2247815	et	3	main
kaoma	doc_158183956827_item	2247816	et	4	main
kuid	doc_158183956827_item	2247817	et	4	main
minu	doc_158183956827_item	2247818	et	3	main
arust	doc_158183956827_item	2247819	et	4	main
oli	doc_158183956827_item	2247820	et	3	main
läinud	doc_158183956827_item	2247825	et	4	main
on	doc_158183956827_item	2247828	et	4	main
programm	doc_158183956827_item	2247830	et	3	main
tegema	doc_158183956827_item	2247835	et	3	main
see	doc_158183956827_item	2247840	et	3	main
pidi	doc_158183956827_item	2247843	et	4	main
uue	doc_158183956827_item	2247849	et	3	main
ja	doc_158183956827_item	2247853	et	3	main
vaid	doc_158183956827_item	2247861	et	3	main
1	doc_158183956828_item	2247866	et	2	main
eesti	doc_158183956828_item	2247869	et	4	main
mõisted	doc_158183956828_item	2247874	et	3	main
kaasnesid	doc_158183956828_item	2247885	et	4	main
90	doc_158183956828_item	2247888	et	2	main
a	doc_158183956828_item	2247889	et	4	main
paljud	doc_158183956828_item	2247894	et	3	main
muutsid	doc_158183956828_item	2247896	et	4	main
nime	doc_158183956828_item	2247898	et	4	main
mõnikord	doc_158183956828_item	2247899	et	3	main
isegi	doc_158183956828_item	2247900	et	4	main
korda	doc_158183956828_item	2247904	et	4	main
mõnedes	doc_158183956828_item	2247912	et	3	main
alles	doc_158183956828_item	2247916	et	3	main
lihtsalt	doc_158183956827_item	2247822	et	4	main
elu	doc_158183956827_item	2247833	et	4	main
paremaks	doc_158183956827_item	2247834	et	4	main
kuid	doc_158183956827_item	2247836	et	4	main
uus	doc_158183956827_item	2247841	et	3	main
ja	doc_158183956827_item	2247847	et	3	main
ehitama	doc_158183956827_item	2247848	et	4	main
on	doc_158183956827_item	2247851	et	4	main
terve	doc_158183956827_item	2247863	et	4	main
kontrolltöö	doc_158183956828_item	2247865	et	4	main
glasnost	doc_158183956828_item	2247875	et	4	main
perestroika	doc_158183956828_item	2247877	et	4	main
90	doc_158183956828_item	2247879	et	2	main
aastatel	doc_158183956828_item	2247880	et	4	main
sai	doc_158183956828_item	2247881	et	4	main
eesti	doc_158183956828_item	2247882	et	4	main
uures	doc_158183956828_item	2247886	et	3	main
2	doc_158183956828_item	2247901	et	2	main
jäänud	doc_158183956828_item	2247917	et	4	main
nimetati	doc_158183956828_item	2247919	et	4	main
kõik	doc_158183956828_item	2247924	et	4	main
haiglasse	doc_158183956828_item	2247928	et	4	main
tõttu	doc_158183956828_item	2247933	et	4	main
praeguga	doc_158183956828_item	2247941	et	4	main
praegu	doc_158183956828_item	2247942	et	3	main
mitte	doc_158183956828_item	2247948	et	3	main
tola	doc_158183956828_item	2247950	et	4	main
olnud	doc_158183956828_item	2247955	et	4	main
praegu	doc_158183956828_item	2247962	et	3	main
või	doc_158183956828_item	2247970	et	4	main
ei	doc_158183956828_item	2247975	et	4	main
käest	doc_158183956828_item	2247978	et	4	main
ajal	doc_158183956828_item	2247982	et	4	main
ostmiseks	doc_158183956828_item	2247989	et	4	main
poole	doc_158183956828_item	2247993	et	4	main
on	doc_158183956828_item	2247995	et	4	main
palju	doc_158183956828_item	2248002	et	4	main
oli	doc_158183956828_item	2247926	et	3	main
sotsallaabi	doc_158183956828_item	2247927	et	4	main
pandi	doc_158183956828_item	2247929	et	4	main
minisuguse	doc_158183956828_item	2247930	et	3	main
vigastuse	doc_158183956828_item	2247932	et	4	main
ka	doc_158183956828_item	2247938	et	3	main
kulud	doc_158183956828_item	2247946	et	4	main
aga	doc_158183956828_item	2247947	et	3	main
sellist	doc_158183956828_item	2247952	et	4	main
palju	doc_158183956828_item	2247957	et	4	main
autot	doc_158183956828_item	2247967	et	3	main
midagi	doc_158183956828_item	2247971	et	4	main
siis	doc_158183956828_item	2247973	et	3	main
ja	doc_158183956828_item	2247999	et	3	main
mida	doc_158183956828_item	2248004	et	4	main
vaja	doc_158183956828_item	2248008	et	4	main
tööd	doc_158183956828_item	2248009	et	4	main
oli	doc_158183956828_item	2248010	et	3	main
suhteliselt	doc_158183956828_item	2248011	et	4	main
kerge	doc_158183956828_item	2248012	et	4	main
leida	doc_158183956828_item	2248013	et	3	main
praegu	doc_158183956828_item	2248014	et	3	main
aga	doc_158183956828_item	2248015	et	3	main
ööd	doc_158183956828_item	2248017	et	4	main
raske	doc_158183956828_item	2248016	et	4	main
head	doc_158183956828_item	2248018	et	4	main
leida	doc_158183956828_item	2248019	et	3	main
on	doc_158183956828_item	2248020	et	4	main
olid	doc_158183956828_item	2248028	et	4	main
hästi	doc_158183956828_item	2248030	et	3	main
väikesed	doc_158183956828_item	2248037	et	4	main
siis	doc_158183956828_item	2248039	et	3	main
muud	doc_158183956828_item	2248045	et	4	main
palju	doc_158183956828_item	2248058	et	4	main
ma	doc_158183956828_item	2248060	et	3	main
muudatused	doc_158183956828_item	2248082	et	3	main
need	doc_158183956828_item	2248085	et	3	main
on	doc_158183956828_item	2248086	et	4	main
muudatused	doc_158183956828_item	2248087	et	3	main
mis	doc_158183956828_item	2248088	et	4	main
tagasi	doc_158183956828_item	2248095	et	3	main
mis	doc_158183956828_item	2248097	et	4	main
nüüd	doc_158183956828_item	2248099	et	4	main
2	doc_158183956829_item	2248106	et	2	main
1	doc_158183956829_item	2248113	et	2	main
1988	doc_158183956829_item	2248116	et	2	main
tasuta	doc_158183956828_item	2247925	et	4	main
väikese	doc_158183956828_item	2247931	et	4	main
võrreldes	doc_158183956828_item	2247940	et	3	main
odavam	doc_158183956828_item	2247958	et	4	main
kui	doc_158183956828_item	2247959	et	3	main
praegu	doc_158183956828_item	2247960	et	3	main
tänasel	doc_158183956828_item	2247963	et	3	main
tahad	doc_158183956828_item	2247965	et	3	main
vaipa	doc_158183956828_item	2247968	et	4	main
kellegi	doc_158183956828_item	2247977	et	4	main
küsima	doc_158183956828_item	2247980	et	3	main
suurema	doc_158183956828_item	2247987	et	4	main
see	doc_158183956828_item	2247990	et	3	main
parema	doc_158183956828_item	2247992	et	4	main
tulnud	doc_158183956828_item	2247996	et	4	main
ne	doc_158183956828_item	2248000	et	4	main
olnud	doc_158183956828_item	2248007	et	4	main
a	doc_158183956828_item	2248027	et	4	main
suured	doc_158183956828_item	2248031	et	3	main
on	doc_158183956828_item	2248033	et	4	main
aga	doc_158183956828_item	2248035	et	3	main
palju	doc_158183956828_item	2248044	et	4	main
on	doc_158183956828_item	2248047	et	4	main
me	doc_158183956828_item	2248051	et	4	main
muudatusi	doc_158183956828_item	2248056	et	3	main
ja	doc_158183956828_item	2248059	et	3	main
iseseisvumisajal	doc_158183956828_item	2248090	et	3	main
mis	doc_158183956828_item	2248091	et	4	main
on	doc_158183956828_item	2248098	et	4	main
kontrolltöö	doc_158183956829_item	2248100	et	4	main
glasnost	doc_158183956829_item	2248110	et	4	main
loodi	doc_158183956829_item	2248115	et	4	main
rahva	doc_158183956829_item	2248118	et	3	main
etteotsa	doc_158183956829_item	2248122	et	3	main
edgar	doc_158183956829_item	2248124	et	4	main
koondas	doc_158183956829_item	2248127	et	3	main
poliitikuid	doc_158183956829_item	2248130	et	3	main
kes	doc_158183956829_item	2248133	et	4	main
ei	doc_158183956829_item	2248135	et	4	main
staatuse	doc_158183956829_item	2248146	et	3	main
kui	doc_158183956829_item	2248153	et	3	main
meelestatud	doc_158183956829_item	2248155	et	4	main
astusid	doc_158183956829_item	2248162	et	4	main
isamaaliitu	doc_158183956829_item	2248164	et	4	main
toetas	doc_158183956829_item	2248176	et	3	main
bürokraatia	doc_158183956829_item	2248186	et	4	main
kus	doc_158183956829_item	2248203	et	3	main
eesti	doc_158183956829_item	2248209	et	4	main
laulis	doc_158183956829_item	2248219	et	4	main
vabaks	doc_158183956829_item	2248221	et	3	main
ime	doc_158183956829_item	2248228	et	4	main
eesti	doc_158183956829_item	2248230	et	4	main
ka	doc_158183956829_item	2248236	et	3	main
edgar	doc_158183956829_item	2248237	et	4	main
ekp	doc_158183956829_item	2248239	et	4	main
võttis	doc_158183956829_item	2248240	et	3	main
vastu	doc_158183956829_item	2248241	et	3	main
eesti	doc_158183956829_item	2248246	et	4	main
andmise	doc_158183956829_item	2248254	et	4	main
mitte	doc_158183956829_item	2248258	et	3	main
vaid	doc_158183956829_item	2248260	et	3	main
tegi	doc_158183956829_item	2248261	et	4	main
otsuseid	doc_158183956829_item	2248264	et	3	main
oli	doc_158183956829_item	2248266	et	3	main
rühmitustest	doc_158183956829_item	2248270	et	4	main
osa	doc_158183956829_item	2248283	et	4	main
veel	doc_158183956829_item	2248284	et	4	main
kuid	doc_158183956829_item	2248323	et	4	main
käitumise	doc_158183956829_item	2248325	et	4	main
rahvarinde	doc_158183956829_item	2248335	et	4	main
ehk	doc_158183956829_item	2248352	et	3	main
on	doc_158183956829_item	2248354	et	4	main
tulnud	doc_158183956829_item	2248364	et	4	main
viimase	doc_158183956829_item	2248367	et	3	main
presidendi	doc_158183956829_item	2248370	et	4	main
gorbatšoviga	doc_158183956829_item	2248372	et	2	main
tähendust	doc_158183956829_item	2248374	et	4	main
staali	doc_158183956829_item	2248380	et	4	main
terroreziimist	doc_158183956829_item	2248382	et	4	main
ka	doc_158183956829_item	2248386	et	3	main
poliitika	doc_158183956829_item	2248401	et	4	main
palju	doc_158183956828_item	2248022	et	4	main
arvutid	doc_158183956828_item	2248029	et	4	main
nad	doc_158183956828_item	2248034	et	3	main
nagu	doc_158183956828_item	2248036	et	3	main
telekad	doc_158183956828_item	2248038	et	3	main
ja	doc_158183956828_item	2248043	et	3	main
mida	doc_158183956828_item	2248046	et	4	main
raha	doc_158183956828_item	2248054	et	4	main
arvan	doc_158183956828_item	2248061	et	3	main
paremaks	doc_158183956828_item	2248065	et	4	main
tulevad	doc_158183956828_item	2248066	et	4	main
võimalused	doc_158183956828_item	2248068	et	3	main
kui	doc_158183956828_item	2248069	et	3	main
uued	doc_158183956828_item	2248067	et	3	main
eesti	doc_158183956828_item	2248070	et	4	main
astub	doc_158183956828_item	2248071	et	3	main
euroopa	doc_158183956828_item	2248073	et	4	main
sisse	doc_158183956828_item	2248072	et	4	main
liitu	doc_158183956828_item	2248074	et	4	main
siis	doc_158183956828_item	2248075	et	3	main
arenevad	doc_158183956828_item	2248076	et	4	main
uued	doc_158183956828_item	2248077	et	3	main
võimalused	doc_158183956828_item	2248078	et	3	main
ja	doc_158183956828_item	2248079	et	3	main
toimuvad	doc_158183956828_item	2248080	et	4	main
uued	doc_158183956828_item	2248081	et	3	main
2	doc_158183956828_item	2248083	et	2	main
ja	doc_158183956828_item	2248049	et	3	main
on	doc_158183956828_item	2248057	et	4	main
et	doc_158183956828_item	2248062	et	3	main
perestroika	doc_158183956828_item	2248084	et	4	main
toimusid	doc_158183956828_item	2248089	et	4	main
oli	doc_158183956828_item	2248092	et	3	main
1	doc_158183956829_item	2248101	et	2	main
rahvarinde	doc_158183956829_item	2248102	et	4	main
roll	doc_158183956829_item	2248103	et	3	main
eesti	doc_158183956829_item	2248104	et	4	main
ja	doc_158183956829_item	2248111	et	3	main
organisatsioonina	doc_158183956829_item	2248120	et	3	main
rahvarinne	doc_158183956829_item	2248126	et	3	main
otseselt	doc_158183956829_item	2248134	et	4	main
taotledes	doc_158183956829_item	2248142	et	3	main
kellest	doc_158183956829_item	2248160	et	4	main
ka	doc_158183956829_item	2248167	et	3	main
ja	doc_158183956829_item	2248178	et	3	main
vabameelselt	doc_158183956829_item	2248179	et	4	main
meelestatud	doc_158183956829_item	2248180	et	4	main
ja	doc_158183956829_item	2248188	et	3	main
aktiivselt	doc_158183956829_item	2248193	et	4	main
ka	doc_158183956829_item	2248195	et	3	main
tallinna	doc_158183956829_item	2248197	et	4	main
inimeste	doc_158183956829_item	2248200	et	3	main
öid	doc_158183956829_item	2248212	et	3	main
rahvas	doc_158183956829_item	2248218	et	4	main
ekp	doc_158183956829_item	2248224	et	4	main
ka	doc_158183956829_item	2248226	et	3	main
isemajandava	doc_158183956829_item	2248229	et	3	main
programmi	doc_158183956829_item	2248231	et	4	main
mille	doc_158183956829_item	2248232	et	3	main
savisaar	doc_158183956829_item	2248238	et	3	main
ka	doc_158183956829_item	2248242	et	3	main
nõudmised	doc_158183956829_item	2248244	et	4	main
kui	doc_158183956829_item	2248248	et	3	main
riigi	doc_158183956829_item	2248250	et	3	main
riikliku	doc_158183956829_item	2248252	et	3	main
läbimõeldud	doc_158183956829_item	2248262	et	4	main
hoolutud	doc_158183956829_item	2248263	et	4	main
ka	doc_158183956829_item	2248267	et	3	main
23	doc_158183956829_item	2248274	et	2	main
balti	doc_158183956829_item	2248277	et	3	main
ei	doc_158183956829_item	2248281	et	4	main
moskva-meelseks	doc_158183956829_item	2248322	et	3	main
selline	doc_158183956829_item	2248324	et	4	main
teeneks	doc_158183956829_item	2248336	et	4	main
eesti	doc_158183956829_item	2248341	et	4	main
möödus	doc_158183956829_item	2248343	et	3	main
glasnost	doc_158183956829_item	2248348	et	4	main
ja	doc_158183956829_item	2248350	et	3	main
1985	doc_158183956829_item	2248359	et	2	main
võimule	doc_158183956829_item	2248363	et	3	main
ja	doc_158183956829_item	2248366	et	3	main
glasnost	doc_158183956829_item	2248373	et	4	main
avalikult	doc_158183956829_item	2248378	et	4	main
varjatud	doc_158183956829_item	2248389	et	4	main
ajakirjandus	doc_158183956829_item	2248391	et	3	main
mõtte-	doc_158183956829_item	2248394	et	3	main
ja	doc_158183956829_item	2248395	et	3	main
sõnavabadust	doc_158183956829_item	2248396	et	4	main
tähendas	doc_158183956829_item	2248398	et	3	main
pankrotistuvat	doc_158183956829_item	2248422	et	4	main
ja	doc_158183956829_item	2248423	et	3	main
mõrenevat	doc_158183956829_item	2248424	et	4	main
kuid	doc_158183956829_item	2248430	et	4	main
oli	doc_158183956829_item	2248432	et	3	main
et	doc_158183956829_item	2248435	et	3	main
muud	doc_158183956829_item	2248439	et	4	main
kui	doc_158183956829_item	2248441	et	3	main
kõiki	doc_158183956829_item	2248443	et	4	main
perestroika	doc_158183956829_item	2248444	et	4	main
tunda	doc_158183956829_item	2248451	et	3	main
viisid	doc_158183956829_item	2248462	et	4	main
ühiskonnakorraldusele	doc_167143726882_item	2248472	et	3	main
2	doc_167143726882_item	2248475	et	2	main
mida	doc_167143726882_item	2248476	et	4	main
oli	doc_167143726882_item	2248482	et	3	main
enda	doc_167143726882_item	2248492	et	4	main
piirkondadeks	doc_167143726882_item	2248505	et	3	main
ja	doc_167143726882_item	2248507	et	3	main
10	doc_158183956828_item	2248093	et	2	main
ja	doc_158183956828_item	2248096	et	3	main
taasiseseivumisprotsessis	doc_158183956829_item	2248105	et	4	main
mida	doc_158183956829_item	2248107	et	4	main
tähendavad	doc_158183956829_item	2248108	et	4	main
mõisted	doc_158183956829_item	2248109	et	3	main
omaalgatusliku	doc_158183956829_item	2248119	et	3	main
tõusis	doc_158183956829_item	2248123	et	4	main
vabameelseid	doc_158183956829_item	2248129	et	3	main
ja	doc_158183956829_item	2248131	et	3	main
nõudnud	doc_158183956829_item	2248136	et	4	main
pigem	doc_158183956829_item	2248143	et	3	main
eestile	doc_158183956829_item	2248144	et	3	main
seltsi	doc_158183956829_item	2248158	et	4	main
hiljem	doc_158183956829_item	2248163	et	3	main
rahvarinne	doc_158183956829_item	2248165	et	3	main
muulastest	doc_158183956829_item	2248172	et	4	main
rahvas	doc_158183956829_item	2248182	et	4	main
proletariaat	doc_158183956829_item	2248190	et	3	main
lauluväljakul	doc_158183956829_item	2248198	et	3	main
öisetel	doc_158183956829_item	2248201	et	4	main
isamaalisi	doc_158183956829_item	2248205	et	4	main
neid	doc_158183956829_item	2248211	et	4	main
nimetati	doc_158183956829_item	2248213	et	4	main
laulvaks	doc_158183956829_item	2248215	et	4	main
revolutsiooniks	doc_158183956829_item	2248216	et	3	main
kus	doc_158183956829_item	2248217	et	3	main
püüdis	doc_158183956829_item	2248223	et	3	main
läbisuruda	doc_158183956829_item	2248225	et	4	main
oli	doc_158183956829_item	2248235	et	3	main
rahvusrinde	doc_158183956829_item	2248243	et	4	main
kodakondsusest	doc_158183956829_item	2248245	et	4	main
keelelele	doc_158183956829_item	2248247	et	4	main
staatuse	doc_158183956829_item	2248253	et	3	main
rahvusrinne	doc_158183956829_item	2248255	et	3	main
küll	doc_158183956829_item	2248257	et	4	main
rahvarinne	doc_158183956829_item	2248265	et	3	main
nendest	doc_158183956829_item	2248269	et	4	main
võttis	doc_158183956829_item	2248272	et	3	main
aug	doc_158183956829_item	2248275	et	4	main
võtnud	doc_158183956829_item	2248282	et	4	main
ja	doc_158183956829_item	2248329	et	3	main
shokegija	doc_158183956829_item	2248331	et	4	main
ometi	doc_158183956829_item	2248333	et	3	main
ka	doc_158183956829_item	2248334	et	3	main
taasiseseisvumine	doc_158183956829_item	2248342	et	3	main
avalikustamine	doc_158183956829_item	2248349	et	4	main
mis	doc_158183956829_item	2248357	et	4	main
käisid	doc_158183956829_item	2248358	et	4	main
seda	doc_158183956829_item	2248375	et	3	main
et	doc_158183956829_item	2248376	et	3	main
nsv	doc_158183956829_item	2248387	et	4	main
sai	doc_158183956829_item	2248392	et	4	main
nsv	doc_158183956829_item	2248399	et	4	main
liidu	doc_158183956829_item	2248400	et	3	main
savisaar	doc_158183956829_item	2248125	et	3	main
välja	doc_158183956829_item	2248138	et	4	main
astumist	doc_158183956829_item	2248139	et	4	main
liidust	doc_158183956829_item	2248141	et	4	main
poliitiline	doc_158183956829_item	2248148	et	3	main
hoiak	doc_158183956829_item	2248149	et	3	main
oli	doc_158183956829_item	2248150	et	3	main
tagasihoidlikum	doc_158183956829_item	2248152	et	4	main
radikaalselt	doc_158183956829_item	2248154	et	4	main
eesti	doc_158183956829_item	2248156	et	4	main
tekkis	doc_158183956829_item	2248166	et	3	main
vastukaaluks	doc_158183956829_item	2248168	et	3	main
ja	doc_158183956829_item	2248170	et	3	main
rahvarinnet	doc_158183956829_item	2248175	et	3	main
aga	doc_158183956829_item	2248183	et	3	main
moskva	doc_158183956829_item	2248185	et	4	main
võtab	doc_158183956829_item	2248192	et	3	main
osa	doc_158183956829_item	2248194	et	4	main
1988	doc_158183956829_item	2248196	et	2	main
toimuvatest	doc_158183956829_item	2248199	et	4	main
kokkusaamistel	doc_158183956829_item	2248202	et	4	main
lauldi	doc_158183956829_item	2248204	et	3	main
laule	doc_158183956829_item	2248206	et	4	main
ja	doc_158183956829_item	2248207	et	3	main
koosnevale	doc_158183956829_item	2248173	et	4	main
interliikumisel	doc_158183956829_item	2248174	et	3	main
uuendus	doc_158183956829_item	2248177	et	4	main
eesti	doc_158183956829_item	2248181	et	4	main
interliikumist	doc_158183956829_item	2248184	et	3	main
lodvik	doc_158183956829_item	2248187	et	4	main
siinne	doc_158183956829_item	2248189	et	3	main
interrinne	doc_158183956829_item	2248191	et	3	main
kasutati	doc_158183956829_item	2248208	et	4	main
rahvussümboolikat	doc_158183956829_item	2248210	et	3	main
ajaloos	doc_158183956829_item	2248214	et	4	main
end	doc_158183956829_item	2248220	et	4	main
rahvarinne	doc_158183956829_item	2248222	et	3	main
üheks	doc_158183956829_item	2248233	et	3	main
eesti	doc_158183956829_item	2248249	et	4	main
tegutses	doc_158183956829_item	2248256	et	3	main
kes	doc_158183956829_item	2248271	et	4	main
osa	doc_158183956829_item	2248273	et	4	main
1990	doc_158183956829_item	2248276	et	2	main
organiseerimises	doc_158183956829_item	2248279	et	4	main
rahvarinne	doc_158183956829_item	2248280	et	3	main
ja	doc_158183956829_item	2248321	et	3	main
oli	doc_158183956829_item	2248326	et	3	main
ratsionaalne	doc_158183956829_item	2248330	et	3	main
sest	doc_158183956829_item	2248332	et	4	main
oli	doc_158183956829_item	2248337	et	3	main
see	doc_158183956829_item	2248339	et	3	main
et	doc_158183956829_item	2248340	et	3	main
jaoks	doc_158183956829_item	2248345	et	4	main
2	doc_158183956829_item	2248347	et	2	main
uuendamine	doc_158183956829_item	2248353	et	4	main
kaks	doc_158183956829_item	2248355	et	3	main
nsv	doc_158183956829_item	2248361	et	4	main
liidus	doc_158183956829_item	2248362	et	4	main
nsv	doc_158183956829_item	2248368	et	4	main
liidu	doc_158183956829_item	2248369	et	3	main
mihhail	doc_158183956829_item	2248371	et	4	main
rääkima	doc_158183956829_item	2248379	et	3	main
aegses	doc_158183956829_item	2248381	et	3	main
liidu	doc_158183956829_item	2248388	et	3	main
poliitikast	doc_158183956829_item	2248390	et	4	main
perestroika	doc_158183956829_item	2248397	et	4	main
liberaalsemaks	doc_158183956829_item	2248402	et	4	main
muutmist	doc_158183956829_item	2248403	et	4	main
süvenenud	doc_158183956829_item	2248434	et	4	main
liidul	doc_158183956829_item	2248437	et	3	main
ksoteh	doc_158183956829_item	2248442	et	4	main
glasnostiga	doc_158183956829_item	2248446	et	4	main
need	doc_158183956829_item	2248455	et	3	main
ja	doc_158183956829_item	2248457	et	3	main
poliitika	doc_158183956829_item	2248460	et	4	main
küsimusele	doc_167143726882_item	2248467	et	4	main
tähendab	doc_167143726882_item	2248477	et	3	main
ühiskonnakorraldus	doc_167143726882_item	2248481	et	3	main
13	doc_167143726882_item	2248484	et	2	main
kui	doc_167143726882_item	2248487	et	3	main
võimu	doc_167143726882_item	2248491	et	4	main
ristisõda	doc_167143726882_item	2248494	et	4	main
ordule	doc_167143726882_item	2248511	et	3	main
tähtsam	doc_167143726882_item	2248513	et	4	main
saare-lääne	doc_167143726882_item	2248522	et	4	main
eesti	doc_167143726882_item	2248523	et	4	main
tallinnas	doc_167143726882_item	2248539	et	4	main
elas	doc_167143726882_item	2248540	et	3	main
7-8	doc_167143726882_item	2248542	et	2	main
tuhat	doc_167143726882_item	2248543	et	4	main
5-6	doc_167143726882_item	2248547	et	2	main
peale	doc_167143726882_item	2248550	et	4	main
olid	doc_167143726882_item	2248552	et	4	main
ka	doc_167143726882_item	2248553	et	3	main
viljandi	doc_167143726882_item	2248554	et	4	main
ja	doc_167143726882_item	2248555	et	3	main
linnad	doc_167143726882_item	2248558	et	3	main
maksustamine	doc_167143726882_item	2248587	et	4	main
otsustamine	doc_167143726882_item	2248590	et	4	main
linna	doc_167143726882_item	2248595	et	4	main
elama	doc_167143726882_item	2248596	et	3	main
linnaelanikud	doc_167143726882_item	2248597	et	3	main
gildisse	doc_167143726882_item	2248599	et	3	main
kokku	doc_167143726882_item	2248611	et	3	main
olid	doc_167143726882_item	2248625	et	4	main
1987	doc_158183956829_item	2248227	et	2	main
loojaks	doc_158183956829_item	2248234	et	4	main
keelele	doc_158183956829_item	2248251	et	4	main
emotsionaalselt	doc_158183956829_item	2248259	et	4	main
üks	doc_158183956829_item	2248268	et	3	main
ketti	doc_158183956829_item	2248278	et	4	main
veebruar	doc_158183956829_item	2248286	et	3	main
1990	doc_158183956829_item	2248287	et	2	main
eesti	doc_158183956829_item	2248288	et	4	main
24	doc_158183956829_item	2248285	et	2	main
komitee	doc_158183956829_item	2248289	et	4	main
valimistest	doc_158183956829_item	2248290	et	4	main
kuid	doc_158183956829_item	2248291	et	4	main
20	doc_158183956829_item	2248292	et	2	main
sept	doc_158183956829_item	2248293	et	4	main
1991	doc_158183956829_item	2248294	et	2	main
a	doc_158183956829_item	2248295	et	4	main
riigikogu	doc_158183956829_item	2248296	et	4	main
ja	doc_158183956829_item	2248297	et	3	main
presidendi	doc_158183956829_item	2248298	et	4	main
valimistel	doc_158183956829_item	2248299	et	4	main
sai	doc_158183956829_item	2248300	et	4	main
rahvarinde	doc_158183956829_item	2248301	et	4	main
juht	doc_158183956829_item	2248302	et	3	main
savisaar	doc_158183956829_item	2248304	et	3	main
peaministri	doc_158183956829_item	2248305	et	3	main
edgar	doc_158183956829_item	2248303	et	4	main
koha	doc_158183956829_item	2248306	et	4	main
arvan	doc_158183956829_item	2248307	et	3	main
et	doc_158183956829_item	2248308	et	3	main
rahvarinde	doc_158183956829_item	2248309	et	4	main
panus	doc_158183956829_item	2248310	et	4	main
eesti	doc_158183956829_item	2248311	et	4	main
taasiseseisvumisprotsessis	doc_158183956829_item	2248312	et	3	main
on	doc_158183956829_item	2248313	et	4	main
suure	doc_158183956829_item	2248314	et	3	main
kuuluga	doc_158183956829_item	2248315	et	4	main
mõned	doc_158183956829_item	2248316	et	3	main
hindasid	doc_158183956829_item	2248317	et	4	main
savisaare	doc_158183956829_item	2248318	et	3	main
tegevust	doc_158183956829_item	2248319	et	4	main
reetlikuks	doc_158183956829_item	2248320	et	3	main
pigem	doc_158183956829_item	2248327	et	3	main
hoolutletud	doc_158183956829_item	2248328	et	4	main
ka	doc_158183956829_item	2248338	et	3	main
rahva	doc_158183956829_item	2248344	et	3	main
veretult	doc_158183956829_item	2248346	et	4	main
perestroika	doc_158183956829_item	2248351	et	4	main
terminit	doc_158183956829_item	2248356	et	3	main
a	doc_158183956829_item	2248360	et	4	main
esimese	doc_158183956829_item	2248365	et	3	main
hakati	doc_158183956829_item	2248377	et	3	main
küüsitamistest	doc_158183956829_item	2248383	et	4	main
repressioonidest	doc_158183956829_item	2248384	et	3	main
ning	doc_158183956829_item	2248385	et	3	main
rohkem	doc_158183956829_item	2248393	et	4	main
lähedasemaks	doc_158183956829_item	2248405	et	4	main
majanduses	doc_158183956829_item	2248406	et	4	main
tähendus	doc_158183956829_item	2248407	et	4	main
see	doc_158183956829_item	2248408	et	3	main
uut	doc_158183956829_item	2248409	et	3	main
moodi	doc_158183956829_item	2248410	et	4	main
mõtlemise	doc_158183956829_item	2248411	et	4	main
ühistud	doc_158183956829_item	2248412	et	3	main
kooperatiivid	doc_158183956829_item	2248413	et	3	main
neid	doc_158183956829_item	2248415	et	4	main
kõiki	doc_158183956829_item	2248414	et	4	main
meetmeid	doc_158183956829_item	2248416	et	3	main
võttis	doc_158183956829_item	2248417	et	3	main
selleks	doc_158183956829_item	2248419	et	4	main
et	doc_158183956829_item	2248420	et	3	main
gorbatšov	doc_158183956829_item	2248418	et	2	main
liitu	doc_158183956829_item	2248426	et	4	main
kuidagi	doc_158183956829_item	2248427	et	3	main
päästa	doc_158183956829_item	2248429	et	4	main
võimalust	doc_158183956829_item	2248440	et	3	main
ensv	doc_158183956829_item	2248453	et	4	main
kus	doc_158183956829_item	2248454	et	3	main
protsessid	doc_158183956829_item	2248456	et	4	main
suud	doc_158183956829_item	2248461	et	4	main
vabariigi	doc_158183956829_item	2248464	et	3	main
ristiusustamise	doc_167143726882_item	2248469	et	3	main
eesti	doc_167143726882_item	2248471	et	4	main
väga	doc_167143726882_item	2248496	et	3	main
eesti	doc_167143726882_item	2248499	et	4	main
omaette	doc_167143726882_item	2248504	et	3	main
lõuna	doc_167143726882_item	2248506	et	4	main
keskosa	doc_167143726882_item	2248508	et	4	main
seal	doc_167143726882_item	2248516	et	4	main
oli	doc_167143726882_item	2248517	et	3	main
rannik	doc_167143726882_item	2248519	et	3	main
rahvale	doc_158183956829_item	2248404	et	3	main
niigi	doc_158183956829_item	2248421	et	4	main
nsv	doc_158183956829_item	2248425	et	4	main
veel	doc_158183956829_item	2248428	et	4	main
polnud	doc_158183956829_item	2248438	et	3	main
sai	doc_158183956829_item	2248450	et	4	main
valitud	doc_158183956829_item	2248459	et	4	main
reformatsioon	doc_167143726882_item	2248478	et	3	main
katkestatud	doc_167143726882_item	2248483	et	4	main
alguses	doc_167143726882_item	2248486	et	4	main
katoliku	doc_167143726882_item	2248488	et	3	main
kätte	doc_167143726882_item	2248493	et	4	main
mõjus	doc_167143726882_item	2248495	et	4	main
eesti	doc_167143726882_item	2248497	et	4	main
ühiskonnakorraldusele	doc_167143726882_item	2248498	et	3	main
jagama	doc_167143726882_item	2248502	et	3	main
kuulus	doc_167143726882_item	2248509	et	4	main
kõige	doc_167143726882_item	2248512	et	4	main
mee	doc_167143726882_item	2248514	et	3	main
ordumeister	doc_167143726882_item	2248518	et	3	main
kuulus	doc_167143726882_item	2248520	et	4	main
taanile	doc_167143726882_item	2248521	et	4	main
ja	doc_167143726882_item	2248526	et	3	main
lõuna	doc_167143726882_item	2248527	et	4	main
suuremad	doc_167143726882_item	2248532	et	4	main
tallinn	doc_167143726882_item	2248536	et	4	main
tartu	doc_167143726882_item	2248538	et	4	main
umbes	doc_167143726882_item	2248541	et	4	main
tuh	doc_167143726882_item	2248548	et	4	main
uus-pärnu	doc_167143726882_item	2248556	et	4	main
punkt	doc_167143726882_item	2248566	et	4	main
seadustega	doc_167143726882_item	2248568	et	3	main
oli	doc_167143726882_item	2248574	et	3	main
ja	doc_167143726882_item	2248576	et	3	main
aasta	doc_167143726882_item	2248582	et	4	main
olid	doc_167143726882_item	2248585	et	4	main
tsunftis	doc_167143726882_item	2248612	et	3	main
lihtkäistöölised	doc_167143726882_item	2248622	et	4	main
korraldas	doc_167143726882_item	2248637	et	3	main
oli	doc_167143726882_item	2248643	et	3	main
kirikukihelkondadeks	doc_167143726882_item	2248645	et	3	main
oli	doc_167143726882_item	2248648	et	3	main
jumalasõna	doc_167143726882_item	2248658	et	4	main
tilkima	doc_167143726882_item	2248660	et	4	main
on	doc_170347281009_item	2248679	et	4	main
et	doc_170347281009_item	2248689	et	3	main
ülem-suetuki	doc_170347281009_item	2248691	et	4	main
keele	doc_170347281009_item	2248696	et	4	main
emakeelt	doc_170347281009_item	2248713	et	4	main
tundis	doc_170347281009_item	2248718	et	3	main
üllatuma	doc_170347281009_item	2248728	et	3	main
korralik	doc_170347281009_item	2248735	et	3	main
lendama	doc_170347281009_item	2248747	et	3	main
piret	doc_170347281009_item	2248759	et	4	main
siin	doc_170347281009_item	2248778	et	4	main
ettevõtmine	doc_170347281009_item	2248782	et	3	main
on	doc_170347281009_item	2248784	et	4	main
salv	doc_170347281009_item	2248786	et	3	main
ja	doc_170347281009_item	2248788	et	3	main
käib	doc_170347281009_item	2248790	et	3	main
hooga	doc_170347281009_item	2248793	et	3	main
ja	doc_170347281009_item	2248800	et	3	main
mõnusalt	doc_170347281009_item	2248802	et	4	main
mitte	doc_170347281009_item	2248804	et	3	main
vene	doc_170347281009_item	2248805	et	4	main
mõni	doc_170347281009_item	2248810	et	3	main
kool	doc_170347281009_item	2248817	et	4	main
kriis	doc_158183956829_item	2248431	et	3	main
niivõrd	doc_158183956829_item	2248433	et	3	main
nsv	doc_158183956829_item	2248436	et	4	main
ja	doc_158183956829_item	2248445	et	3	main
käsikäes	doc_158183956829_item	2248447	et	3	main
käivaid	doc_158183956829_item	2248448	et	4	main
protsesse	doc_158183956829_item	2248449	et	3	main
ka	doc_158183956829_item	2248452	et	3	main
gorbtšov	doc_158183956829_item	2248458	et	2	main
eesti	doc_158183956829_item	2248463	et	4	main
tekkeni	doc_158183956829_item	2248465	et	3	main
vastus	doc_167143726882_item	2248466	et	3	main
1	doc_167143726882_item	2248468	et	2	main
mõjud	doc_167143726882_item	2248470	et	4	main
1316	doc_167143726882_item	2248473	et	2	main
sajandil	doc_167143726882_item	2248474	et	3	main
1	doc_167143726882_item	2248479	et	2	main
iseseisev	doc_167143726882_item	2248480	et	3	main
saj	doc_167143726882_item	2248485	et	4	main
kirik	doc_167143726882_item	2248489	et	3	main
võtab	doc_167143726882_item	2248490	et	3	main
territooriumi	doc_167143726882_item	2248500	et	4	main
hakati	doc_167143726882_item	2248501	et	3	main
neljaks	doc_167143726882_item	2248503	et	4	main
viirumaa	doc_167143726882_item	2248528	et	4	main
tartu	doc_167143726882_item	2248529	et	4	main
piiskopkonnale	doc_167143726882_item	2248530	et	3	main
kõige	doc_167143726882_item	2248531	et	4	main
tollajal	doc_167143726882_item	2248534	et	4	main
hansa	doc_167143726882_item	2248559	et	4	main
nagu	doc_167143726882_item	2248564	et	3	main
oma	doc_167143726882_item	2248567	et	4	main
ja	doc_167143726882_item	2248569	et	3	main
kõrgeim	doc_167143726882_item	2248571	et	4	main
koht	doc_167143726882_item	2248573	et	3	main
road	doc_167143726882_item	2248575	et	4	main
magistraat	doc_167143726882_item	2248577	et	3	main
magistraati	doc_167143726882_item	2248578	et	4	main
toimusid	doc_167143726882_item	2248580	et	4	main
tema	doc_167143726882_item	2248583	et	4	main
ülesanned	doc_167143726882_item	2248584	et	4	main
pidamine	doc_167143726882_item	2248589	et	4	main
kas	doc_167143726882_item	2248591	et	3	main
koos	doc_167143726882_item	2248601	et	4	main
selle	doc_167143726882_item	2248607	et	4	main
nt	doc_167143726882_item	2248615	et	4	main
liivi	doc_167143726882_item	2248510	et	4	main
mees	doc_167143726882_item	2248515	et	4	main
saare-lääne	doc_167143726882_item	2248524	et	4	main
linnad	doc_167143726882_item	2248533	et	3	main
aga	doc_167143726882_item	2248545	et	3	main
selle	doc_167143726882_item	2248551	et	4	main
need	doc_167143726882_item	2248557	et	3	main
iga	doc_167143726882_item	2248561	et	4	main
oli	doc_167143726882_item	2248563	et	3	main
omavalitsuse	doc_167143726882_item	2248565	et	3	main
valitsusega	doc_167143726882_item	2248570	et	4	main
linnavalitsuse	doc_167143726882_item	2248572	et	3	main
linnakodanike	doc_167143726882_item	2248586	et	3	main
kohtu	doc_167143726882_item	2248588	et	4	main
ja	doc_167143726882_item	2248592	et	3	main
võtta	doc_167143726882_item	2248594	et	3	main
koondasid	doc_167143726882_item	2248598	et	4	main
seal	doc_167143726882_item	2248600	et	4	main
peale	doc_167143726882_item	2248606	et	4	main
inimesed	doc_167143726882_item	2248608	et	3	main
olid	doc_167143726882_item	2248609	et	4	main
võimuesindajad	doc_167143726882_item	2248630	et	3	main
ii	doc_167143726882_item	2248634	et	4	main
võim	doc_167143726882_item	2248635	et	3	main
maa	doc_167143726882_item	2248639	et	4	main
korralduse	doc_167143726882_item	2248641	et	4	main
kultuur	doc_167143726882_item	2248652	et	3	main
reformatsioon	doc_167143726882_item	2248654	et	3	main
hakati	doc_167143726882_item	2248659	et	3	main
ema	doc_167143726882_item	2248661	et	4	main
naine	doc_170347281009_item	2248681	et	3	main
nägema	doc_170347281009_item	2248683	et	3	main
ta	doc_170347281009_item	2248685	et	4	main
konkurss	doc_170347281009_item	2248700	et	3	main
ja	doc_170347281009_item	2248702	et	3	main
väikestele	doc_170347281009_item	2248709	et	4	main
need	doc_170347281009_item	2248711	et	3	main
nende	doc_170347281009_item	2248712	et	4	main
kinnitusel	doc_170347281009_item	2248717	et	4	main
ja	doc_167143726882_item	2248537	et	3	main
piiskopkonnale	doc_167143726882_item	2248525	et	3	main
olid	doc_167143726882_item	2248535	et	4	main
inimest	doc_167143726882_item	2248544	et	3	main
tartus	doc_167143726882_item	2248546	et	3	main
inimest	doc_167143726882_item	2248549	et	3	main
liidus	doc_167143726882_item	2248560	et	4	main
linn	doc_167143726882_item	2248562	et	3	main
valimised	doc_167143726882_item	2248579	et	4	main
iga	doc_167143726882_item	2248581	et	4	main
keda	doc_167143726882_item	2248593	et	4	main
töötasid	doc_167143726882_item	2248602	et	4	main
kaupmehed	doc_167143726882_item	2248603	et	3	main
või	doc_167143726882_item	2248604	et	4	main
käsitöölised	doc_167143726882_item	2248605	et	3	main
organiseeritud	doc_167143726882_item	2248610	et	4	main
seal	doc_167143726882_item	2248613	et	4	main
olid	doc_167143726882_item	2248614	et	4	main
käsitöölised	doc_167143726882_item	2248616	et	3	main
pagarad	doc_167143726882_item	2248617	et	4	main
linnaselavad	doc_167143726882_item	2248618	et	4	main
eestlased	doc_167143726882_item	2248619	et	3	main
olid	doc_167143726882_item	2248620	et	4	main
põhiliselt	doc_167143726882_item	2248621	et	4	main
aga	doc_167143726882_item	2248623	et	3	main
käsitöömeistrid	doc_167143726882_item	2248626	et	3	main
ja	doc_167143726882_item	2248628	et	3	main
oli	doc_167143726882_item	2248632	et	3	main
see	doc_167143726882_item	2248636	et	3	main
ümber	doc_167143726882_item	2248638	et	3	main
administratiivse	doc_167143726882_item	2248640	et	3	main
iga	doc_167143726882_item	2248646	et	4	main
ja	doc_167143726882_item	2248651	et	3	main
murred	doc_167143726882_item	2248653	et	4	main
võitlus	doc_167143726882_item	2248656	et	3	main
võitis	doc_170347281009_item	2248699	et	3	main
on	doc_170347281009_item	2248703	et	4	main
nüüd	doc_170347281009_item	2248704	et	4	main
üle	doc_170347281009_item	2248706	et	3	main
õpetama	doc_170347281009_item	2248714	et	3	main
ta	doc_170347281009_item	2248719	et	4	main
jõudma	doc_170347281009_item	2248721	et	3	main
et	doc_170347281009_item	2248723	et	3	main
on	doc_170347281009_item	2248724	et	4	main
ei	doc_170347281009_item	2248746	et	4	main
lind	doc_170347281009_item	2248749	et	3	main
tänaseks	doc_170347281009_item	2248783	et	4	main
täie	doc_170347281009_item	2248791	et	3	main
kuidagi	doc_170347281009_item	2248797	et	3	main
nagu	doc_170347281009_item	2248809	et	3	main
venemaa	doc_170347281009_item	2248816	et	4	main
keeles	doc_170347281009_item	2248824	et	4	main
üle	doc_170347281009_item	2248828	et	3	main
inimene	doc_170347281009_item	2248830	et	3	main
uued	doc_170347281009_item	2248847	et	3	main
ei	doc_170347281009_item	2248852	et	4	main
on	doc_170347281009_item	2248861	et	4	main
päevad	doc_170347281009_item	2248862	et	3	main
kui	doc_170347281009_item	2248877	et	3	main
vaja	doc_170347281009_item	2248878	et	4	main
külapood	doc_170347281009_item	2248880	et	3	main
vildid	doc_170347281009_item	2248882	et	4	main
müüdagi	doc_170347281009_item	2248888	et	3	main
lühendatud	doc_170347281009_item	2248895	et	4	main
slõhtuleht	doc_170347281009_item	2248897	et	4	main
sõnadest	doc_170347281009_item	2248901	et	3	main
sõnad	doc_170347281009_item	2248904	et	4	main
õigesse	doc_170347281009_item	2248905	et	3	main
naised	doc_170347281009_item	2248913	et	3	main
teeb	doc_170347281009_item	2248921	et	3	main
naiselikum	doc_170347281009_item	2248923	et	4	main
mehi	doc_170347281009_item	2248925	et	3	main
võima	doc_170347281009_item	2248938	et	3	main
paras	doc_170347281009_item	2248942	et	3	main
meid	doc_170347281009_item	2248946	et	4	main
soovimatu	doc_170347281009_item	2248952	et	4	main
puhkama	doc_170347281009_item	2248965	et	3	main
laskma	doc_170347281009_item	2248968	et	3	main
et	doc_170347281009_item	2248998	et	3	main
sakslased	doc_167143726882_item	2248624	et	3	main
kaupmehed	doc_167143726882_item	2248627	et	3	main
muidugi	doc_167143726882_item	2248629	et	4	main
kirik	doc_167143726882_item	2248631	et	3	main
nadu	doc_167143726882_item	2248633	et	4	main
kombed	doc_167143726882_item	2248650	et	3	main
korruptsiooniga	doc_167143726882_item	2248657	et	3	main
jumalateenistus	doc_167143726882_item	2248663	et	3	main
viidi	doc_167143726882_item	2248664	et	4	main
läbi	doc_167143726882_item	2248665	et	4	main
ka	doc_167143726882_item	2248666	et	3	main
ema	doc_167143726882_item	2248667	et	4	main
keeles	doc_167143726882_item	2248668	et	4	main
eksamitöö	doc_170347281009_item	2248669	et	4	main
i	doc_170347281009_item	2248670	et	4	main
pange	doc_170347281009_item	2248671	et	4	main
sulgudes	doc_170347281009_item	2248672	et	4	main
olevad	doc_170347281009_item	2248673	et	4	main
sõnad	doc_170347281009_item	2248674	et	4	main
õigesse	doc_170347281009_item	2248675	et	3	main
vormi	doc_170347281009_item	2248676	et	4	main
piret	doc_170347281009_item	2248677	et	4	main
toomet	doc_170347281009_item	2248678	et	4	main
eesti	doc_167143726882_item	2248642	et	4	main
jagatud	doc_167143726882_item	2248644	et	4	main
kihelkonnal	doc_167143726882_item	2248647	et	3	main
omaette	doc_167143726882_item	2248649	et	3	main
usupuhastus	doc_167143726882_item	2248655	et	3	main
keelde	doc_167143726882_item	2248662	et	4	main
ettevõtlik	doc_170347281009_item	2248680	et	3	main
siberisse	doc_170347281009_item	2248690	et	4	main
küla	doc_170347281009_item	2248692	et	4	main
külas	doc_170347281009_item	2248693	et	3	main
eesti	doc_170347281009_item	2248695	et	4	main
õpetajat	doc_170347281009_item	2248697	et	4	main
konkurssi	doc_170347281009_item	2248701	et	4	main
juba	doc_170347281009_item	2248705	et	3	main
nädal	doc_170347281009_item	2248707	et	3	main
pireti	doc_170347281009_item	2248716	et	4	main
siberisse	doc_170347281009_item	2248720	et	4	main
maaliti	doc_170347281009_item	2248739	et	3	main
siberist	doc_170347281009_item	2248741	et	4	main
lenda	doc_170347281009_item	2248748	et	4	main
ega	doc_170347281009_item	2248750	et	3	main
kui	doc_170347281009_item	2248753	et	3	main
tahtmine	doc_170347281009_item	2248756	et	4	main
täis	doc_170347281009_item	2248758	et	4	main
algust	doc_170347281009_item	2248762	et	4	main
on	doc_170347281009_item	2248777	et	4	main
sügisel	doc_170347281009_item	2248779	et	3	main
õppimine	doc_170347281009_item	2248789	et	4	main
hoog	doc_170347281009_item	2248792	et	3	main
siinsed	doc_170347281009_item	2248794	et	3	main
mõnus	doc_170347281009_item	2248799	et	4	main
murret	doc_170347281009_item	2248812	et	4	main
siiski	doc_170347281009_item	2248815	et	4	main
aine	doc_170347281009_item	2248820	et	4	main
õpetatakse	doc_170347281009_item	2248822	et	3	main
külas	doc_170347281009_item	2248825	et	3	main
veidi	doc_170347281009_item	2248827	et	3	main
kõik	doc_170347281009_item	2248834	et	4	main
pireti	doc_170347281009_item	2248836	et	4	main
õpivad	doc_170347281009_item	2248838	et	3	main
poolpõlenud	doc_170347281009_item	2248840	et	4	main
varsti	doc_170347281009_item	2248843	et	3	main
saadavad	doc_170347281009_item	2248845	et	4	main
soe	doc_170347281009_item	2248864	et	4	main
kuid	doc_170347281009_item	2248865	et	4	main
ööd	doc_170347281009_item	2248866	et	4	main
jahe	doc_170347281009_item	2248868	et	3	main
harjutan	doc_170347281009_item	2248870	et	3	main
suure	doc_170347281009_item	2248872	et	3	main
ahju	doc_170347281009_item	2248874	et	4	main
seal	doc_170347281009_item	2248884	et	4	main
muud	doc_170347281009_item	2248886	et	4	main
valmistuma	doc_170347281009_item	2248891	et	3	main
piret	doc_170347281009_item	2248893	et	4	main
pannes	doc_170347281009_item	2248903	et	4	main
naeratus	doc_170347281009_item	2248911	et	4	main
ja	doc_170347281009_item	2248915	et	3	main
ja	doc_170347281009_item	2248924	et	3	main
mehelikum	doc_170347281009_item	2248926	et	4	main
kaunim	doc_170347281009_item	2248928	et	4	main
stress	doc_170347281009_item	2248932	et	3	main
meie	doc_170347281009_item	2248934	et	4	main
aga	doc_170347281009_item	2248936	et	3	main
tooma	doc_170347281009_item	2248939	et	3	main
tagajärg	doc_170347281009_item	2248941	et	3	main
4	doc_170347281009_item	2248954	et	2	main
laskma	doc_170347281009_item	2248957	et	3	main
pinge	doc_170347281009_item	2248960	et	4	main
ülekoormust	doc_170347281009_item	2248969	et	4	main
on	doc_170347281009_item	2248993	et	4	main
nii	doc_170347281009_item	2248995	et	3	main
saab	doc_170347281009_item	2249001	et	3	main
ja	doc_170347281009_item	2249004	et	3	main
ka	doc_170347281009_item	2249010	et	3	main
varahommik	doc_170347281009_item	2249012	et	3	main
söömine	doc_170347281009_item	2249018	et	4	main
pahandab	doc_170347281009_item	2249019	et	3	main
aeg	doc_170347281009_item	2249023	et	3	main
suvel	doc_170347281009_item	2248682	et	3	main
nägi	doc_170347281009_item	2248684	et	3	main
ajalehes	doc_170347281009_item	2248686	et	3	main
kuulutus	doc_170347281009_item	2248687	et	4	main
kuulutuse	doc_170347281009_item	2248688	et	4	main
otsitakse	doc_170347281009_item	2248694	et	3	main
piret	doc_170347281009_item	2248698	et	4	main
nädalat	doc_170347281009_item	2248708	et	3	main
eestlastele	doc_170347281009_item	2248710	et	4	main
õpetab	doc_170347281009_item	2248715	et	3	main
olin	doc_170347281009_item	2248726	et	3	main
üsna	doc_170347281009_item	2248727	et	3	main
kui	doc_170347281009_item	2248730	et	3	main
tuli	doc_170347281009_item	2248733	et	4	main
vastu	doc_170347281009_item	2248734	et	3	main
korraliku	doc_170347281009_item	2248736	et	3	main
mulle	doc_170347281009_item	2248738	et	4	main
siber	doc_170347281009_item	2248740	et	4	main
selline	doc_170347281009_item	2248742	et	4	main
et	doc_170347281009_item	2248744	et	3	main
kasva	doc_170347281009_item	2248751	et	4	main
ja	doc_170347281009_item	2248755	et	3	main
õppeaasta	doc_170347281009_item	2248761	et	4	main
koht	doc_170347281009_item	2248763	et	3	main
tähtis	doc_170347281009_item	2248781	et	4	main
salves	doc_170347281009_item	2248787	et	4	main
räägivad	doc_170347281009_item	2248796	et	3	main
teistmoodi	doc_170347281009_item	2248798	et	3	main
aktsenti	doc_170347281009_item	2248807	et	4	main
mõnd	doc_170347281009_item	2248811	et	3	main
kool	doc_170347281009_item	2248813	et	4	main
ja	doc_170347281009_item	2248818	et	3	main
ülejäänud	doc_170347281009_item	2248819	et	4	main
ained	doc_170347281009_item	2248821	et	3	main
vene	doc_170347281009_item	2248823	et	4	main
emakeelt	doc_170347281009_item	2248832	et	4	main
õpikud	doc_170347281009_item	2248848	et	3	main
siberi	doc_170347281009_item	2248849	et	4	main
veel	doc_170347281009_item	2248863	et	4	main
jahedad	doc_170347281009_item	2248869	et	3	main
külapoest	doc_170347281009_item	2248881	et	4	main
talveks	doc_170347281009_item	2248890	et	4	main
ajalehest	doc_170347281009_item	2248896	et	4	main
etteantud	doc_170347281009_item	2248900	et	4	main
laused	doc_170347281009_item	2248902	et	3	main
kasutades	doc_170347281009_item	2248908	et	3	main
2	doc_170347281009_item	2248910	et	2	main
lisakoormus	doc_170347281009_item	2248937	et	3	main
soovimatu	doc_170347281009_item	2248940	et	4	main
kogus	doc_170347281009_item	2248943	et	4	main
aga	doc_170347281009_item	2248948	et	3	main
tuua	doc_170347281009_item	2248951	et	3	main
tohtima	doc_170347281009_item	2248956	et	3	main
ülekoormus	doc_170347281009_item	2248958	et	3	main
aparaat	doc_170347281009_item	2248997	et	3	main
lausa	doc_170347281009_item	2249002	et	4	main
pühapäev	doc_170347281009_item	2249011	et	3	main
pühapäeva	doc_170347281009_item	2249028	et	4	main
une	doc_170347281009_item	2249030	et	3	main
vaatamise	doc_170347281009_item	2249039	et	4	main
iv	doc_170347281009_item	2249041	et	4	main
sulgudes	doc_170347281009_item	2249043	et	4	main
pean	doc_170347281009_item	2249050	et	4	main
vanematest	doc_170347281009_item	2249056	et	4	main
nõuded	doc_170347281009_item	2249069	et	3	main
et	doc_170347281009_item	2249074	et	3	main
sa	doc_170347281009_item	2249080	et	3	main
autod	doc_170347281009_item	2249088	et	3	main
naisi	doc_170347281009_item	2249090	et	3	main
4	doc_170347281009_item	2249094	et	2	main
difteeria	doc_170347281009_item	2249099	et	4	main
närimiskumm	doc_170347281009_item	2249126	et	3	main
püksidele	doc_170347281009_item	2249129	et	3	main
peab	doc_170347281009_item	2249133	et	4	main
hoiduma	doc_170347281009_item	2249134	et	3	main
tunnen	doc_170347281009_item	2249139	et	3	main
päikest	doc_170347281009_item	2249144	et	4	main
kolmekäigulise	doc_170347281009_item	2249152	et	4	main
kuigi	doc_170347281009_item	2249154	et	3	main
2	doc_170347281009_item	2249158	et	2	main
lapsel	doc_170347281009_item	2249166	et	4	main
jõuda	doc_170347281009_item	2248722	et	3	main
oodatud	doc_170347281009_item	2248725	et	4	main
üllatunud	doc_170347281009_item	2248729	et	4	main
mulle	doc_170347281009_item	2248731	et	4	main
tulema	doc_170347281009_item	2248732	et	4	main
audiga	doc_170347281009_item	2248737	et	3	main
pilt	doc_170347281009_item	2248743	et	3	main
seal	doc_170347281009_item	2248745	et	4	main
rohi	doc_170347281009_item	2248752	et	4	main
noor	doc_170347281009_item	2248754	et	3	main
tahtmise	doc_170347281009_item	2248757	et	4	main
pärast	doc_170347281009_item	2248760	et	4	main
kohale	doc_170347281009_item	2248764	et	4	main
jõudis	doc_170347281009_item	2248765	et	3	main
polnud	doc_170347281009_item	2248766	et	3	main
kool	doc_170347281009_item	2248767	et	4	main
algama	doc_170347281009_item	2248769	et	3	main
veel	doc_170347281009_item	2248768	et	4	main
alatud	doc_170347281009_item	2248770	et	4	main
kogu	doc_170347281009_item	2248771	et	4	main
küla	doc_170347281009_item	2248772	et	4	main
võtma	doc_170347281009_item	2248773	et	3	main
võttis	doc_170347281009_item	2248774	et	3	main
kartuleid	doc_170347281009_item	2248775	et	3	main
kartulivõtt	doc_170347281009_item	2248776	et	3	main
kõige	doc_170347281009_item	2248780	et	4	main
kartul	doc_170347281009_item	2248785	et	3	main
eestlased	doc_170347281009_item	2248795	et	3	main
mahlakas	doc_170347281009_item	2248801	et	4	main
mahlakalt	doc_170347281009_item	2248803	et	4	main
aktsent	doc_170347281009_item	2248806	et	3	main
vaid	doc_170347281009_item	2248808	et	3	main
on	doc_170347281009_item	2248814	et	4	main
saab	doc_170347281009_item	2248833	et	3	main
rääkida	doc_170347281009_item	2248835	et	3	main
sõnul	doc_170347281009_item	2248837	et	3	main
saatma	doc_170347281009_item	2248844	et	3	main
talve	doc_170347281009_item	2248850	et	4	main
kartma	doc_170347281009_item	2248853	et	3	main
mulle	doc_170347281009_item	2248855	et	4	main
tõid	doc_170347281009_item	2248858	et	4	main
praegu	doc_170347281009_item	2248860	et	3	main
juba	doc_170347281009_item	2248867	et	3	main
ostan	doc_170347281009_item	2248879	et	3	main
suurt	doc_170347281009_item	2248885	et	3	main
ei	doc_170347281009_item	2248887	et	4	main
valmistub	doc_170347281009_item	2248892	et	3	main
vapralt	doc_170347281009_item	2248894	et	4	main
vormi	doc_170347281009_item	2248906	et	4	main
kirjavahemärke	doc_170347281009_item	2248909	et	4	main
naiselikum	doc_170347281009_item	2248914	et	4	main
naisi	doc_170347281009_item	2248922	et	3	main
3	doc_170347281009_item	2248929	et	2	main
kogus	doc_170347281009_item	2248931	et	4	main
stress	doc_170347281009_item	2248944	et	3	main
tegutsema	doc_170347281009_item	2248947	et	3	main
lisakoormus	doc_170347281009_item	2248949	et	3	main
tagajärgu	doc_170347281009_item	2248953	et	3	main
tekkima	doc_170347281009_item	2248959	et	3	main
saama	doc_170347281009_item	2248961	et	4	main
maandama	doc_170347281009_item	2248962	et	3	main
sportima	doc_170347281009_item	2248963	et	4	main
ja	doc_170347281009_item	2248964	et	3	main
ei	doc_170347281009_item	2248966	et	4	main
tänapäeval	doc_170347281009_item	2248994	et	3	main
abil	doc_170347281009_item	2249000	et	4	main
katkestama	doc_170347281009_item	2249009	et	3	main
uni	doc_170347281009_item	2249013	et	3	main
kuid	doc_170347281009_item	2249024	et	4	main
varahommiku	doc_170347281009_item	2249029	et	3	main
segab	doc_170347281009_item	2249031	et	3	main
huvitavat	doc_170347281009_item	2249037	et	4	main
nad	doc_170347281009_item	2249058	et	3	main
artikli	doc_170347281009_item	2249068	et	3	main
nõuetega	doc_170347281009_item	2249070	et	4	main
sa	doc_170347281009_item	2249075	et	3	main
huvitud	doc_170347281009_item	2249076	et	4	main
aga	doc_170347281009_item	2249079	et	3	main
ainult	doc_170347281009_item	2249083	et	4	main
kiireid	doc_170347281009_item	2249092	et	4	main
5	doc_170347281009_item	2249101	et	2	main
uus	doc_170347281009_item	2249103	et	3	main
uue	doc_170347281009_item	2249105	et	3	main
elab	doc_170347281009_item	2248826	et	3	main
kolmsada	doc_170347281009_item	2248829	et	4	main
inimest	doc_170347281009_item	2248831	et	3	main
lapsed	doc_170347281009_item	2248839	et	3	main
raamatud	doc_170347281009_item	2248841	et	4	main
raamatutest	doc_170347281009_item	2248842	et	4	main
eestist	doc_170347281009_item	2248846	et	3	main
piret	doc_170347281009_item	2248851	et	4	main
karda	doc_170347281009_item	2248854	et	4	main
juba	doc_170347281009_item	2248856	et	3	main
tooma	doc_170347281009_item	2248857	et	3	main
talvepuud	doc_170347281009_item	2248859	et	4	main
juba	doc_170347281009_item	2248871	et	3	main
vene	doc_170347281009_item	2248873	et	4	main
kütmine	doc_170347281009_item	2248875	et	4	main
kütmist	doc_170347281009_item	2248876	et	4	main
ega	doc_170347281009_item	2248883	et	3	main
naerab	doc_170347281009_item	2248889	et	3	main
iii	doc_170347281009_item	2248898	et	4	main
moodustage	doc_170347281009_item	2248899	et	3	main
ja	doc_170347281009_item	2248907	et	3	main
tegema	doc_170347281009_item	2248912	et	3	main
mehed	doc_170347281009_item	2248916	et	3	main
mehelikum	doc_170347281009_item	2248917	et	4	main
igaüks	doc_170347281009_item	2248918	et	3	main
kaunim	doc_170347281009_item	2248919	et	4	main
naeratus	doc_170347281009_item	2248920	et	4	main
igaühe	doc_170347281009_item	2248927	et	4	main
paras	doc_170347281009_item	2248930	et	3	main
panema	doc_170347281009_item	2248933	et	3	main
tegutsema	doc_170347281009_item	2248935	et	3	main
paneb	doc_170347281009_item	2248945	et	3	main
võib	doc_170347281009_item	2248950	et	3	main
ei	doc_170347281009_item	2248955	et	4	main
tohti	doc_170347281009_item	2248967	et	4	main
tekkida	doc_170347281009_item	2248970	et	3	main
pinget	doc_170347281009_item	2248971	et	3	main
saab	doc_170347281009_item	2248972	et	3	main
maandada	doc_170347281009_item	2248973	et	3	main
sportida	doc_170347281009_item	2248974	et	4	main
ja	doc_170347281009_item	2248975	et	3	main
puhata	doc_170347281009_item	2248976	et	4	main
5	doc_170347281009_item	2248977	et	2	main
telefon	doc_170347281009_item	2248978	et	3	main
olema	doc_170347281009_item	2248979	et	4	main
tänapäev	doc_170347281009_item	2248980	et	3	main
nii	doc_170347281009_item	2248982	et	3	main
maagiline	doc_170347281009_item	2248983	et	4	main
aparaat	doc_170347281009_item	2248984	et	3	main
saama	doc_170347281009_item	2248981	et	4	main
et	doc_170347281009_item	2248985	et	3	main
see	doc_170347281009_item	2248986	et	3	main
abil	doc_170347281009_item	2248987	et	4	main
lausa	doc_170347281009_item	2248988	et	4	main
elama	doc_170347281009_item	2248989	et	3	main
ja	doc_170347281009_item	2248990	et	3	main
hingama	doc_170347281009_item	2248991	et	3	main
telefon	doc_170347281009_item	2248992	et	3	main
maagiline	doc_170347281009_item	2248996	et	4	main
selle	doc_170347281009_item	2248999	et	4	main
hingata	doc_170347281009_item	2249005	et	4	main
lõunasöök	doc_170347281009_item	2249015	et	3	main
ja	doc_170347281009_item	2249017	et	3	main
huvitav	doc_170347281009_item	2249020	et	4	main
telefonihelin	doc_170347281009_item	2249025	et	3	main
lõunasööki	doc_170347281009_item	2249032	et	4	main
ja	doc_170347281009_item	2249034	et	3	main
telesaade	doc_170347281009_item	2249038	et	4	main
pange	doc_170347281009_item	2249042	et	4	main
sõnad	doc_170347281009_item	2249045	et	4	main
õigesse	doc_170347281009_item	2249046	et	3	main
1	doc_170347281009_item	2249048	et	2	main
ma	doc_170347281009_item	2249049	et	3	main
lugu	doc_170347281009_item	2249052	et	4	main
aitavad	doc_170347281009_item	2249059	et	4	main
kõik	doc_170347281009_item	2249060	et	4	main
ja	doc_170347281009_item	2249062	et	3	main
igaüks	doc_170347281009_item	2249064	et	3	main
igaüht	doc_170347281009_item	2249065	et	3	main
2	doc_170347281009_item	2249066	et	2	main
tunned	doc_170347281009_item	2249081	et	3	main
naised	doc_170347281009_item	2249085	et	3	main
ja	doc_170347281009_item	2249086	et	3	main
ilusaid	doc_170347281009_item	2249089	et	3	main
difteeriad	doc_170347281009_item	2249100	et	3	main
tüdinesin	doc_170347281009_item	2249102	et	3	main
teine	doc_170347281009_item	2249121	et	3	main
valdkonnale	doc_170347281009_item	2249124	et	4	main
ajal	doc_170347281009_item	2249132	et	4	main
10	doc_170347281009_item	2249137	et	2	main
lüngad	doc_170347281009_item	2249147	et	3	main
maksis	doc_170347281009_item	2249156	et	4	main
3	doc_170347281009_item	2249165	et	2	main
oodata	doc_170347281009_item	2249168	et	4	main
vanemad	doc_170347281009_item	2249170	et	4	main
tagasi	doc_170347281009_item	2249171	et	3	main
naeru	doc_170347281009_item	2249176	et	4	main
ta	doc_170347281009_item	2249184	et	4	main
töö	doc_170347281009_item	2249194	et	4	main
siis	doc_170347281009_item	2249195	et	3	main
7	doc_170347281009_item	2249198	et	2	main
küll	doc_170347281009_item	2249210	et	4	main
sõidad	doc_170347281009_item	2249219	et	3	main
või	doc_170347281009_item	2249221	et	4	main
10	doc_170347281009_item	2249224	et	2	main
kui	doc_170347281009_item	2249227	et	3	main
koputust	doc_170347281009_item	2249229	et	4	main
i	doc_170347281010_item	2249231	et	4	main
ta	doc_170347281010_item	2249246	et	4	main
kuulutus	doc_170347281010_item	2249248	et	4	main
et	doc_170347281010_item	2249250	et	3	main
siberisse	doc_170347281010_item	2249251	et	4	main
eesti	doc_170347281010_item	2249256	et	4	main
konkurss	doc_170347281010_item	2249261	et	3	main
konkursi	doc_170347281010_item	2249262	et	3	main
nädala	doc_170347281010_item	2249269	et	3	main
eestlastele	doc_170347281010_item	2249271	et	4	main
õpetama	doc_170347281010_item	2249275	et	3	main
kinnitusel	doc_170347281010_item	2249278	et	4	main
õppeaasta	doc_170347281010_item	2249322	et	4	main
veel	doc_170347281010_item	2249329	et	4	main
kartuleid	doc_170347281010_item	2249336	et	3	main
tähtsam	doc_170347281010_item	2249343	et	4	main
tänaseks	doc_170347281010_item	2249345	et	4	main
kartul	doc_170347281010_item	2249347	et	3	main
salvis	doc_170347281010_item	2249349	et	4	main
ja	doc_170347281010_item	2249350	et	3	main
õppimine	doc_170347281010_item	2249351	et	4	main
käib	doc_170347281010_item	2249352	et	3	main
täie	doc_170347281010_item	2249353	et	3	main
räägivad	doc_170347281010_item	2249358	et	3	main
mõnus	doc_170347281010_item	2249361	et	4	main
mahlakas	doc_170347281010_item	2249363	et	4	main
mitte	doc_170347281010_item	2249367	et	3	main
nagu	doc_170347281010_item	2249372	et	3	main
on	doc_170347281010_item	2249377	et	4	main
ülejäänud	doc_170347281010_item	2249382	et	4	main
vene	doc_170347281010_item	2249386	et	4	main
keeles	doc_170347281010_item	2249387	et	4	main
elada	doc_170347281009_item	2249003	et	3	main
6	doc_170347281009_item	2249006	et	2	main
kuid	doc_170347281009_item	2249007	et	4	main
telefonihelin	doc_170347281009_item	2249008	et	3	main
segama	doc_170347281009_item	2249014	et	3	main
valmistamine	doc_170347281009_item	2249016	et	4	main
telesaade	doc_170347281009_item	2249021	et	4	main
katkestab	doc_170347281009_item	2249026	et	3	main
ka	doc_170347281009_item	2249027	et	3	main
ajal	doc_170347281009_item	2249040	et	4	main
väga	doc_170347281009_item	2249051	et	3	main
sest	doc_170347281009_item	2249057	et	4	main
kohandasin	doc_170347281009_item	2249067	et	3	main
ma	doc_170347281009_item	2249072	et	3	main
sport	doc_170347281009_item	2249077	et	3	main
huvi	doc_170347281009_item	2249082	et	4	main
ilusad	doc_170347281009_item	2249084	et	3	main
kiired	doc_170347281009_item	2249087	et	4	main
autosid	doc_170347281009_item	2249093	et	3	main
on	doc_170347281009_item	2249096	et	4	main
haigestuda	doc_170347281009_item	2249098	et	3	main
töökoha	doc_170347281009_item	2249106	et	4	main
8	doc_170347281009_item	2249125	et	2	main
9	doc_170347281009_item	2249130	et	2	main
ma	doc_170347281009_item	2249138	et	3	main
rõõmu	doc_170347281009_item	2249140	et	4	main
päike	doc_170347281009_item	2249142	et	3	main
täitke	doc_170347281009_item	2249146	et	3	main
sidenditega	doc_170347281009_item	2249149	et	3	main
see	doc_170347281009_item	2249155	et	3	main
õpetajad	doc_170347281009_item	2249164	et	4	main
kõrvallauast	doc_170347281009_item	2249174	et	4	main
see	doc_170347281009_item	2249177	et	3	main
keegi	doc_170347281009_item	2249179	et	4	main
rääkinud	doc_170347281009_item	2249182	et	4	main
trenni	doc_170347281009_item	2249187	et	4	main
6	doc_170347281009_item	2249192	et	2	main
selles	doc_170347281009_item	2249199	et	4	main
ei	doc_170347281009_item	2249201	et	4	main
ning	doc_170347281009_item	2249204	et	3	main
tarbida	doc_170347281009_item	2249206	et	3	main
aga	doc_170347281009_item	2249212	et	3	main
jääd	doc_170347281009_item	2249222	et	4	main
linna	doc_170347281009_item	2249223	et	4	main
avasin	doc_170347281009_item	2249225	et	3	main
pange	doc_170347281010_item	2249232	et	4	main
piret	doc_170347281010_item	2249238	et	4	main
nägema	doc_170347281010_item	2249244	et	3	main
ülem-suetuki	doc_170347281010_item	2249252	et	4	main
küla	doc_170347281010_item	2249253	et	4	main
ja	doc_170347281010_item	2249263	et	3	main
need	doc_170347281010_item	2249272	et	3	main
siberisse	doc_170347281010_item	2249281	et	4	main
tahtmist	doc_170347281010_item	2249318	et	4	main
kohale	doc_170347281010_item	2249325	et	4	main
kool	doc_170347281010_item	2249328	et	4	main
algama	doc_170347281010_item	2249330	et	3	main
kartulivõtt	doc_170347281010_item	2249337	et	3	main
siin	doc_170347281010_item	2249339	et	4	main
sügisel	doc_170347281010_item	2249340	et	3	main
hooga	doc_170347281010_item	2249355	et	3	main
teistmoodi	doc_170347281010_item	2249360	et	3	main
aktsendiga	doc_170347281010_item	2249370	et	3	main
mõni	doc_170347281010_item	2249373	et	3	main
kool	doc_170347281010_item	2249380	et	4	main
elab	doc_170347281010_item	2249389	et	3	main
üle	doc_170347281010_item	2249391	et	3	main
kolmesaja	doc_170347281010_item	2249393	et	4	main
emakeelt	doc_170347281010_item	2249396	et	4	main
kõigil	doc_170347281010_item	2249399	et	4	main
raamatud	doc_170347281010_item	2249406	et	4	main
raamatuid	doc_170347281010_item	2249407	et	3	main
tooma	doc_170347281010_item	2249422	et	3	main
talvepuud	doc_170347281010_item	2249424	et	4	main
praegu	doc_170347281010_item	2249425	et	3	main
on	doc_170347281010_item	2249426	et	4	main
suure	doc_170347281010_item	2249438	et	3	main
ahju	doc_170347281010_item	2249440	et	4	main
vaja	doc_170347281010_item	2249444	et	4	main
suurt	doc_170347281010_item	2249451	et	3	main
vapralt	doc_170347281010_item	2249460	et	4	main
vaatamine	doc_170347281009_item	2249022	et	4	main
valmistamist	doc_170347281009_item	2249033	et	4	main
söömist	doc_170347281009_item	2249035	et	4	main
pahandab	doc_170347281009_item	2249036	et	3	main
olevad	doc_170347281009_item	2249044	et	4	main
vormi	doc_170347281009_item	2249047	et	4	main
oma	doc_170347281009_item	2249053	et	4	main
vanemad	doc_170347281009_item	2249054	et	4	main
oma	doc_170347281009_item	2249055	et	4	main
kõike	doc_170347281009_item	2249061	et	4	main
usaldavad	doc_170347281009_item	2249063	et	4	main
3	doc_170347281009_item	2249071	et	2	main
arvasin	doc_170347281009_item	2249073	et	3	main
sporti	doc_170347281009_item	2249078	et	4	main
ja	doc_170347281009_item	2249091	et	3	main
praegu	doc_170347281009_item	2249095	et	3	main
oht	doc_170347281009_item	2249097	et	3	main
töökoht	doc_170347281009_item	2249104	et	3	main
kiiresti	doc_170347281009_item	2249107	et	3	main
6	doc_170347281009_item	2249108	et	2	main
piirdusime	doc_170347281009_item	2249109	et	3	main
selles	doc_170347281009_item	2249110	et	4	main
küsimuses	doc_170347281009_item	2249111	et	4	main
vaid	doc_170347281009_item	2249112	et	3	main
väikesed	doc_170347281009_item	2249113	et	4	main
muudatused	doc_170347281009_item	2249114	et	3	main
väikesi	doc_170347281009_item	2249115	et	4	main
muudatusi	doc_170347281009_item	2249116	et	3	main
7	doc_170347281009_item	2249117	et	2	main
see	doc_170347281009_item	2249118	et	3	main
küsimus	doc_170347281009_item	2249119	et	4	main
kuulub	doc_170347281009_item	2249120	et	3	main
teisele	doc_170347281009_item	2249123	et	4	main
püksid	doc_170347281009_item	2249128	et	3	main
külmetamine	doc_170347281009_item	2249135	et	4	main
v	doc_170347281009_item	2249145	et	4	main
sobivate	doc_170347281009_item	2249148	et	4	main
palju	doc_170347281009_item	2249157	et	4	main
olid	doc_170347281009_item	2249160	et	4	main
paluti	doc_170347281009_item	2249167	et	3	main
kuni	doc_170347281009_item	2249169	et	3	main
4	doc_170347281009_item	2249173	et	2	main
5	doc_170347281009_item	2249183	et	2	main
tule	doc_170347281009_item	2249186	et	4	main
sest	doc_170347281009_item	2249188	et	4	main
teatrisse	doc_170347281009_item	2249191	et	3	main
lähete	doc_170347281009_item	2249196	et	4	main
alkoholi	doc_170347281009_item	2249205	et	4	main
nad	doc_170347281009_item	2249208	et	3	main
tulemust	doc_170347281009_item	2249213	et	4	main
olnud	doc_170347281009_item	2249215	et	4	main
kas	doc_170347281009_item	2249217	et	3	main
sa	doc_170347281009_item	2249218	et	3	main
maale	doc_170347281009_item	2249220	et	4	main
olevad	doc_170347281010_item	2249234	et	4	main
on	doc_170347281010_item	2249240	et	4	main
nägi	doc_170347281010_item	2249245	et	3	main
otsitakse	doc_170347281010_item	2249255	et	3	main
on	doc_170347281010_item	2249264	et	4	main
juba	doc_170347281010_item	2249266	et	3	main
emakeelt	doc_170347281010_item	2249274	et	4	main
jõudma	doc_170347281010_item	2249282	et	3	main
valdkond	doc_170347281009_item	2249122	et	3	main
kleepus	doc_170347281009_item	2249127	et	3	main
külmal	doc_170347281009_item	2249131	et	3	main
külmetamist	doc_170347281009_item	2249136	et	4	main
suvine	doc_170347281009_item	2249141	et	4	main
suvist	doc_170347281009_item	2249143	et	4	main
1	doc_170347281009_item	2249150	et	2	main
tellisime	doc_170347281009_item	2249151	et	4	main
lõuna	doc_170347281009_item	2249153	et	4	main
kohal	doc_170347281009_item	2249159	et	4	main
nii	doc_170347281009_item	2249161	et	3	main
õpilased	doc_170347281009_item	2249162	et	3	main
kui	doc_170347281009_item	2249163	et	3	main
tulevad	doc_170347281009_item	2249172	et	4	main
just	doc_170347281009_item	2249180	et	3	main
ei	doc_170347281009_item	2249185	et	4	main
läheb	doc_170347281009_item	2249189	et	3	main
hoopis	doc_170347281009_item	2249190	et	3	main
jalutama	doc_170347281009_item	2249197	et	3	main
baaris	doc_170347281009_item	2249200	et	3	main
tohi	doc_170347281009_item	2249202	et	4	main
suitsetada	doc_170347281009_item	2249203	et	3	main
pingsalt	doc_170347281009_item	2249211	et	4	main
9	doc_170347281009_item	2249216	et	2	main
kostis	doc_170347281009_item	2249175	et	4	main
oleks	doc_170347281009_item	2249178	et	3	main
anekdooti	doc_170347281009_item	2249181	et	4	main
lõpetage	doc_170347281009_item	2249193	et	3	main
8	doc_170347281009_item	2249207	et	2	main
töötasid	doc_170347281009_item	2249209	et	4	main
ei	doc_170347281009_item	2249214	et	4	main
ukse	doc_170347281009_item	2249226	et	3	main
kuulsin	doc_170347281009_item	2249228	et	3	main
eksamitöö	doc_170347281010_item	2249230	et	4	main
sõnad	doc_170347281010_item	2249235	et	4	main
vormi	doc_170347281010_item	2249237	et	4	main
ettevõtlik	doc_170347281010_item	2249241	et	3	main
suvel	doc_170347281010_item	2249243	et	3	main
ajalehes	doc_170347281010_item	2249247	et	3	main
kuulutuse	doc_170347281010_item	2249249	et	4	main
külla	doc_170347281010_item	2249254	et	4	main
õpetajat	doc_170347281010_item	2249258	et	4	main
piret	doc_170347281010_item	2249259	et	4	main
nüüd	doc_170347281010_item	2249265	et	4	main
nädal	doc_170347281010_item	2249268	et	3	main
väikestele	doc_170347281010_item	2249270	et	4	main
nende	doc_170347281010_item	2249273	et	4	main
ta	doc_170347281010_item	2249280	et	4	main
tahtmine	doc_170347281010_item	2249317	et	4	main
pärast	doc_170347281010_item	2249321	et	4	main
algust	doc_170347281010_item	2249323	et	4	main
polnud	doc_170347281010_item	2249327	et	3	main
alganud	doc_170347281010_item	2249331	et	4	main
küla	doc_170347281010_item	2249333	et	4	main
võtma	doc_170347281010_item	2249334	et	3	main
võttis	doc_170347281010_item	2249335	et	3	main
tähtis	doc_170347281010_item	2249342	et	4	main
on	doc_170347281010_item	2249346	et	4	main
hoog	doc_170347281010_item	2249354	et	3	main
siinsed	doc_170347281010_item	2249356	et	3	main
mõnusam	doc_170347281010_item	2249364	et	4	main
vene	doc_170347281010_item	2249368	et	4	main
kool	doc_170347281010_item	2249376	et	4	main
ja	doc_170347281010_item	2249381	et	3	main
aine	doc_170347281010_item	2249383	et	4	main
õpetatakse	doc_170347281010_item	2249385	et	3	main
saab	doc_170347281010_item	2249397	et	3	main
sõnul	doc_170347281010_item	2249402	et	3	main
poolpõlenud	doc_170347281010_item	2249405	et	4	main
varsti	doc_170347281010_item	2249408	et	3	main
juba	doc_170347281010_item	2249421	et	3	main
toodi	doc_170347281010_item	2249423	et	4	main
veel	doc_170347281010_item	2249428	et	4	main
ööd	doc_170347281010_item	2249432	et	4	main
jahedad	doc_170347281010_item	2249435	et	3	main
juba	doc_170347281010_item	2249437	et	3	main
vene	doc_170347281010_item	2249439	et	4	main
muud	doc_170347281010_item	2249452	et	4	main
valmistuma	doc_170347281010_item	2249457	et	3	main
sõnad	doc_170347281010_item	2249470	et	4	main
kasutades	doc_170347281010_item	2249474	et	3	main
naeratus	doc_170347281010_item	2249477	et	4	main
kaunim	doc_170347281010_item	2249485	et	4	main
teeb	doc_170347281010_item	2249487	et	3	main
mehi	doc_170347281010_item	2249490	et	3	main
stress	doc_170347281010_item	2249498	et	3	main
ülekoormus	doc_170347281010_item	2249524	et	3	main
ja	doc_170347281010_item	2249530	et	3	main
maandada	doc_170347281010_item	2249539	et	3	main
ja	doc_170347281010_item	2249541	et	3	main
5	doc_170347281010_item	2249543	et	2	main
olema	doc_170347281010_item	2249545	et	4	main
aparaat	doc_170347281010_item	2249550	et	3	main
see	doc_170347281010_item	2249552	et	3	main
on	doc_170347281010_item	2249559	et	4	main
saanud	doc_170347281010_item	2249561	et	4	main
lausa	doc_170347281010_item	2249568	et	4	main
telefonihelin	doc_170347281010_item	2249574	et	3	main
varahommik	doc_170347281010_item	2249578	et	3	main
söömine	doc_170347281010_item	2249584	et	4	main
katkestab	doc_170347281010_item	2249591	et	3	main
varahommikul	doc_170347281010_item	2249593	et	3	main
ka	doc_170347281010_item	2249601	et	3	main
sulgudes	doc_170347281010_item	2249608	et	4	main
vanemad	doc_170347281010_item	2249619	et	4	main
sulgudes	doc_170347281010_item	2249233	et	4	main
õigesse	doc_170347281010_item	2249236	et	3	main
toomet	doc_170347281010_item	2249239	et	4	main
naine	doc_170347281010_item	2249242	et	3	main
keele	doc_170347281010_item	2249257	et	4	main
võitis	doc_170347281010_item	2249260	et	3	main
üle	doc_170347281010_item	2249267	et	3	main
õpetanud	doc_170347281010_item	2249276	et	4	main
pireti	doc_170347281010_item	2249277	et	4	main
tundis	doc_170347281010_item	2249279	et	3	main
jõudnud	doc_170347281010_item	2249283	et	4	main
et	doc_170347281010_item	2249284	et	3	main
on	doc_170347281010_item	2249285	et	4	main
oodatud	doc_170347281010_item	2249286	et	4	main
olin	doc_170347281010_item	2249287	et	3	main
üsna	doc_170347281010_item	2249288	et	3	main
üllatunud	doc_170347281010_item	2249290	et	4	main
kui	doc_170347281010_item	2249291	et	3	main
üllatuma	doc_170347281010_item	2249289	et	3	main
mulle	doc_170347281010_item	2249292	et	4	main
tulema	doc_170347281010_item	2249293	et	4	main
tuldi	doc_170347281010_item	2249294	et	3	main
vastu	doc_170347281010_item	2249295	et	3	main
korralik	doc_170347281010_item	2249296	et	3	main
korraliku	doc_170347281010_item	2249297	et	3	main
audiga	doc_170347281010_item	2249298	et	3	main
mulle	doc_170347281010_item	2249299	et	4	main
maaliti	doc_170347281010_item	2249300	et	3	main
siber	doc_170347281010_item	2249301	et	4	main
siberist	doc_170347281010_item	2249302	et	4	main
selline	doc_170347281010_item	2249303	et	4	main
pilt	doc_170347281010_item	2249304	et	3	main
et	doc_170347281010_item	2249305	et	3	main
seal	doc_170347281010_item	2249306	et	4	main
ei	doc_170347281010_item	2249307	et	4	main
lendama	doc_170347281010_item	2249308	et	3	main
lenda	doc_170347281010_item	2249309	et	4	main
lind	doc_170347281010_item	2249310	et	3	main
ega	doc_170347281010_item	2249311	et	3	main
kasva	doc_170347281010_item	2249312	et	4	main
rohi	doc_170347281010_item	2249313	et	4	main
kui	doc_170347281010_item	2249314	et	3	main
noor	doc_170347281010_item	2249315	et	3	main
ja	doc_170347281010_item	2249316	et	3	main
täis	doc_170347281010_item	2249319	et	4	main
piret	doc_170347281010_item	2249320	et	4	main
koht	doc_170347281010_item	2249324	et	3	main
kõige	doc_170347281010_item	2249341	et	4	main
salv	doc_170347281010_item	2249348	et	3	main
eestlased	doc_170347281010_item	2249357	et	3	main
ja	doc_170347281010_item	2249362	et	3	main
ja	doc_170347281010_item	2249365	et	3	main
mõnda	doc_170347281010_item	2249374	et	4	main
venemaa	doc_170347281010_item	2249379	et	4	main
ained	doc_170347281010_item	2249384	et	3	main
inimest	doc_170347281010_item	2249395	et	3	main
pireti	doc_170347281010_item	2249401	et	4	main
lapsed	doc_170347281010_item	2249404	et	3	main
päevad	doc_170347281010_item	2249427	et	3	main
jahe	doc_170347281010_item	2249434	et	3	main
kui	doc_170347281010_item	2249443	et	3	main
seal	doc_170347281010_item	2249450	et	4	main
naerab	doc_170347281010_item	2249455	et	3	main
valmistunud	doc_170347281010_item	2249458	et	4	main
piret	doc_170347281010_item	2249459	et	4	main
iii	doc_170347281010_item	2249464	et	4	main
õigesse	doc_170347281010_item	2249471	et	3	main
naiselikum	doc_170347281010_item	2249480	et	4	main
mehelikum	doc_170347281010_item	2249483	et	4	main
igaüks	doc_170347281010_item	2249484	et	3	main
naeratus	doc_170347281010_item	2249486	et	4	main
ja	doc_170347281010_item	2249492	et	3	main
kaunimaks	doc_170347281010_item	2249494	et	4	main
ei	doc_170347281010_item	2249521	et	4	main
ülekoormusel	doc_170347281010_item	2249532	et	3	main
tohi	doc_170347281010_item	2249534	et	4	main
sportimise-	doc_170347281010_item	2249540	et	4	main
puhkamisega	doc_170347281010_item	2249542	et	4	main
saama	doc_170347281010_item	2249547	et	4	main
lausa	doc_170347281010_item	2249554	et	4	main
hingama	doc_170347281010_item	2249557	et	3	main
et	doc_170347281010_item	2249565	et	3	main
lõunasöök	doc_170347281010_item	2249581	et	3	main
telefonihelin	doc_170347281010_item	2249590	et	3	main
segab	doc_170347281010_item	2249595	et	3	main
lõunasööki	doc_170347281010_item	2249596	et	4	main
kuid	doc_170347281010_item	2249600	et	4	main
telesaade	doc_170347281010_item	2249604	et	4	main
pean	doc_170347281010_item	2249615	et	4	main
oma	doc_170347281010_item	2249620	et	4	main
kõik	doc_170347281010_item	2249625	et	4	main
igaüht	doc_170347281010_item	2249630	et	3	main
kohandasin	doc_170347281010_item	2249632	et	3	main
sa	doc_170347281010_item	2249640	et	3	main
sport	doc_170347281010_item	2249642	et	3	main
sa	doc_170347281010_item	2249645	et	3	main
huvi	doc_170347281010_item	2249647	et	4	main
naised	doc_170347281010_item	2249650	et	3	main
ja	doc_170347281010_item	2249651	et	3	main
ilusate	doc_170347281010_item	2249654	et	3	main
vastu	doc_170347281010_item	2249659	et	3	main
on	doc_170347281010_item	2249662	et	4	main
töökoht	doc_170347281010_item	2249670	et	3	main
6	doc_170347281010_item	2249674	et	2	main
küsimus	doc_170347281010_item	2249685	et	4	main
kuulub	doc_170347281010_item	2249686	et	3	main
valdkond	doc_170347281010_item	2249688	et	3	main
peab	doc_170347281010_item	2249699	et	4	main
päike	doc_170347281010_item	2249708	et	3	main
see	doc_170347281010_item	2249721	et	3	main
palju	doc_170347281010_item	2249723	et	4	main
kohal	doc_170347281010_item	2249725	et	4	main
3	doc_170347281010_item	2249732	et	2	main
rääkinud	doc_170347281010_item	2249749	et	4	main
teatrisse	doc_170347281010_item	2249758	et	3	main
töö	doc_170347281010_item	2249761	et	4	main
lähete	doc_170347281010_item	2249763	et	4	main
7	doc_170347281010_item	2249765	et	2	main
ei	doc_170347281010_item	2249768	et	4	main
koputust	doc_170347281010_item	2249796	et	4	main
i	doc_170347281011_item	2249798	et	4	main
pange	doc_170347281011_item	2249799	et	4	main
sõnad	doc_170347281011_item	2249802	et	4	main
õigesse	doc_170347281011_item	2249803	et	3	main
ettevõtlik	doc_170347281011_item	2249808	et	3	main
jõudis	doc_170347281010_item	2249326	et	3	main
kogu	doc_170347281010_item	2249332	et	4	main
on	doc_170347281010_item	2249338	et	4	main
ettevõtmine	doc_170347281010_item	2249344	et	3	main
kuidagi	doc_170347281010_item	2249359	et	3	main
mahlakam	doc_170347281010_item	2249366	et	4	main
aktsent	doc_170347281010_item	2249369	et	3	main
vaid	doc_170347281010_item	2249371	et	3	main
murret	doc_170347281010_item	2249375	et	4	main
siiski	doc_170347281010_item	2249378	et	4	main
külas	doc_170347281010_item	2249388	et	3	main
veidi	doc_170347281010_item	2249390	et	3	main
kolmsada	doc_170347281010_item	2249392	et	4	main
inimene	doc_170347281010_item	2249394	et	3	main
rääkida	doc_170347281010_item	2249400	et	3	main
õpivad	doc_170347281010_item	2249403	et	3	main
saatma	doc_170347281010_item	2249409	et	3	main
saadetakse	doc_170347281010_item	2249410	et	3	main
eestist	doc_170347281010_item	2249411	et	3	main
uued	doc_170347281010_item	2249412	et	3	main
õpikud	doc_170347281010_item	2249413	et	3	main
siberi	doc_170347281010_item	2249414	et	4	main
talve	doc_170347281010_item	2249415	et	4	main
piret	doc_170347281010_item	2249416	et	4	main
ei	doc_170347281010_item	2249417	et	4	main
kartma	doc_170347281010_item	2249418	et	3	main
karda	doc_170347281010_item	2249419	et	4	main
mulle	doc_170347281010_item	2249420	et	4	main
soe	doc_170347281010_item	2249429	et	4	main
kuid	doc_170347281010_item	2249431	et	4	main
juba	doc_170347281010_item	2249433	et	3	main
harjutan	doc_170347281010_item	2249436	et	3	main
kütmine	doc_170347281010_item	2249441	et	4	main
külapood	doc_170347281010_item	2249446	et	3	main
ei	doc_170347281010_item	2249453	et	4	main
müüdagi	doc_170347281010_item	2249454	et	3	main
talveks	doc_170347281010_item	2249456	et	4	main
ajalehest	doc_170347281010_item	2249462	et	4	main
slõhtuleht	doc_170347281010_item	2249463	et	4	main
moodustage	doc_170347281010_item	2249465	et	3	main
sõnadest	doc_170347281010_item	2249467	et	3	main
naised	doc_170347281010_item	2249479	et	3	main
ja	doc_170347281010_item	2249481	et	3	main
mehelikumaks	doc_170347281010_item	2249491	et	4	main
igaüht	doc_170347281010_item	2249493	et	3	main
paras	doc_170347281010_item	2249496	et	3	main
kõik	doc_170347281010_item	2249398	et	4	main
soojad	doc_170347281010_item	2249430	et	3	main
kütmist	doc_170347281010_item	2249442	et	4	main
ostan	doc_170347281010_item	2249445	et	3	main
külapoest	doc_170347281010_item	2249447	et	4	main
vildid	doc_170347281010_item	2249448	et	4	main
ega	doc_170347281010_item	2249449	et	3	main
laused	doc_170347281010_item	2249468	et	3	main
vormi	doc_170347281010_item	2249472	et	4	main
2	doc_170347281010_item	2249476	et	2	main
tegema	doc_170347281010_item	2249478	et	3	main
naiselikumaks	doc_170347281010_item	2249489	et	4	main
meie	doc_170347281010_item	2249500	et	4	main
tegutsema	doc_170347281010_item	2249501	et	3	main
aga	doc_170347281010_item	2249502	et	3	main
lisakoormus	doc_170347281010_item	2249503	et	3	main
võima	doc_170347281010_item	2249504	et	3	main
tooma	doc_170347281010_item	2249505	et	3	main
soovimatu	doc_170347281010_item	2249506	et	4	main
tagajärg	doc_170347281010_item	2249507	et	3	main
parajas	doc_170347281010_item	2249508	et	3	main
kogus	doc_170347281010_item	2249509	et	4	main
stress	doc_170347281010_item	2249510	et	3	main
paneb	doc_170347281010_item	2249511	et	3	main
meid	doc_170347281010_item	2249512	et	4	main
tegutsema	doc_170347281010_item	2249513	et	3	main
aga	doc_170347281010_item	2249514	et	3	main
lisakoormus	doc_170347281010_item	2249515	et	3	main
võib	doc_170347281010_item	2249516	et	3	main
soovimatu	doc_170347281010_item	2249518	et	4	main
tagajärge	doc_170347281010_item	2249519	et	4	main
4	doc_170347281010_item	2249520	et	2	main
tuua	doc_170347281010_item	2249517	et	3	main
laskma	doc_170347281010_item	2249523	et	3	main
pinge	doc_170347281010_item	2249526	et	4	main
saab	doc_170347281010_item	2249538	et	3	main
tänapäev	doc_170347281010_item	2249546	et	3	main
abil	doc_170347281010_item	2249553	et	4	main
maagiliseks	doc_170347281010_item	2249563	et	4	main
ja	doc_170347281010_item	2249570	et	3	main
6	doc_170347281010_item	2249572	et	2	main
pühapäev	doc_170347281010_item	2249577	et	3	main
segama	doc_170347281010_item	2249580	et	3	main
valmistamine	doc_170347281010_item	2249582	et	4	main
pühapäeviti	doc_170347281010_item	2249592	et	4	main
und	doc_170347281010_item	2249594	et	4	main
pahandab	doc_170347281010_item	2249602	et	3	main
pange	doc_170347281010_item	2249607	et	4	main
olevad	doc_170347281010_item	2249609	et	4	main
lugu	doc_170347281010_item	2249617	et	4	main
lühendatud	doc_170347281010_item	2249461	et	4	main
etteantud	doc_170347281010_item	2249466	et	4	main
pannes	doc_170347281010_item	2249469	et	4	main
ja	doc_170347281010_item	2249473	et	3	main
kirjavahemärke	doc_170347281010_item	2249475	et	4	main
mehed	doc_170347281010_item	2249482	et	3	main
naisi	doc_170347281010_item	2249488	et	3	main
3	doc_170347281010_item	2249495	et	2	main
kogus	doc_170347281010_item	2249497	et	4	main
panema	doc_170347281010_item	2249499	et	3	main
tohtima	doc_170347281010_item	2249522	et	3	main
saama	doc_170347281010_item	2249527	et	4	main
telefon	doc_170347281010_item	2249544	et	3	main
ja	doc_170347281010_item	2249556	et	3	main
aparaadiks	doc_170347281010_item	2249564	et	3	main
ka	doc_170347281010_item	2249576	et	3	main
uni	doc_170347281010_item	2249579	et	3	main
ja	doc_170347281010_item	2249583	et	3	main
huvitav	doc_170347281010_item	2249586	et	4	main
huvitava	doc_170347281010_item	2249603	et	4	main
vaatamisaega	doc_170347281010_item	2249605	et	4	main
iv	doc_170347281010_item	2249606	et	4	main
sõnad	doc_170347281010_item	2249610	et	4	main
õigesse	doc_170347281010_item	2249611	et	3	main
1	doc_170347281010_item	2249613	et	2	main
ma	doc_170347281010_item	2249614	et	3	main
väga	doc_170347281010_item	2249616	et	3	main
sest	doc_170347281010_item	2249622	et	4	main
aitavad	doc_170347281010_item	2249624	et	4	main
arvasin	doc_170347281010_item	2249638	et	3	main
ja	doc_170347281010_item	2249656	et	3	main
autode	doc_170347281010_item	2249658	et	3	main
uus	doc_170347281010_item	2249669	et	3	main
teise	doc_170347281010_item	2249689	et	4	main
närimiskumm	doc_170347281010_item	2249692	et	3	main
pükstele	doc_170347281010_item	2249695	et	3	main
külmal	doc_170347281010_item	2249697	et	3	main
suvine	doc_170347281010_item	2249707	et	4	main
täitke	doc_170347281010_item	2249712	et	3	main
lüngad	doc_170347281010_item	2249713	et	3	main
kui	doc_170347281010_item	2249729	et	3	main
õpetajad	doc_170347281010_item	2249731	et	4	main
tulevad	doc_170347281010_item	2249739	et	4	main
oleks	doc_170347281010_item	2249745	et	3	main
just	doc_170347281010_item	2249747	et	3	main
trenni	doc_170347281010_item	2249754	et	4	main
läheb	doc_170347281010_item	2249756	et	3	main
6	doc_170347281010_item	2249759	et	2	main
baaris	doc_170347281010_item	2249767	et	3	main
oloevad	doc_170347281011_item	2249801	et	4	main
on	doc_170347281011_item	2249807	et	4	main
nägi	doc_170347281011_item	2249812	et	3	main
ajalehes	doc_170347281011_item	2249814	et	3	main
kuulutust	doc_170347281011_item	2249816	et	4	main
et	doc_170347281011_item	2249817	et	3	main
konkurss	doc_170347281011_item	2249828	et	3	main
nädala	doc_170347281011_item	2249836	et	3	main
emakeelt	doc_170347281011_item	2249841	et	4	main
ta	doc_170347281011_item	2249847	et	4	main
siberisse	doc_170347281011_item	2249848	et	4	main
kui	doc_170347281011_item	2249858	et	3	main
kasva	doc_170347281011_item	2249879	et	4	main
noor	doc_170347281011_item	2249882	et	3	main
tahtmine	doc_170347281011_item	2249884	et	4	main
täis	doc_170347281011_item	2249886	et	4	main
polnud	doc_170347281011_item	2249894	et	3	main
kartuleid	doc_170347281011_item	2249903	et	3	main
kartulivõtt	doc_170347281011_item	2249904	et	3	main
sügisel	doc_170347281011_item	2249907	et	3	main
kartul	doc_170347281011_item	2249913	et	3	main
ja	doc_170347281011_item	2249916	et	3	main
täie	doc_170347281011_item	2249919	et	3	main
hooga	doc_170347281011_item	2249921	et	3	main
ja	doc_170347281011_item	2249928	et	3	main
siiski	doc_170347281011_item	2249943	et	4	main
vene	doc_170347281011_item	2249951	et	4	main
elab	doc_170347281011_item	2249954	et	3	main
kolmsada	doc_170347281011_item	2249957	et	4	main
lapsed	doc_170347281011_item	2249969	et	3	main
ramatutega	doc_170347281011_item	2249972	et	4	main
talve	doc_170347281011_item	2249980	et	4	main
piret	doc_170347281011_item	2250024	et	4	main
tekkima	doc_170347281010_item	2249525	et	3	main
maandama	doc_170347281010_item	2249528	et	3	main
sportima	doc_170347281010_item	2249529	et	4	main
puhkama	doc_170347281010_item	2249531	et	3	main
ei	doc_170347281010_item	2249533	et	4	main
lasta	doc_170347281010_item	2249535	et	4	main
tekkida	doc_170347281010_item	2249536	et	3	main
pinget	doc_170347281010_item	2249537	et	3	main
nii	doc_170347281010_item	2249548	et	3	main
maagiline	doc_170347281010_item	2249549	et	4	main
et	doc_170347281010_item	2249551	et	3	main
elama	doc_170347281010_item	2249555	et	3	main
telefon	doc_170347281010_item	2249558	et	3	main
tänapäeval	doc_170347281010_item	2249560	et	3	main
nii	doc_170347281010_item	2249562	et	3	main
selle	doc_170347281010_item	2249566	et	4	main
abil	doc_170347281010_item	2249567	et	4	main
elaks	doc_170347281010_item	2249569	et	3	main
hingaks	doc_170347281010_item	2249571	et	3	main
kuid	doc_170347281010_item	2249573	et	4	main
katkestama	doc_170347281010_item	2249575	et	3	main
pahandab	doc_170347281010_item	2249585	et	3	main
telesaade	doc_170347281010_item	2249587	et	4	main
vaatamine	doc_170347281010_item	2249588	et	4	main
aeg	doc_170347281010_item	2249589	et	3	main
valmistamist	doc_170347281010_item	2249597	et	4	main
ja	doc_170347281010_item	2249598	et	3	main
söömist	doc_170347281010_item	2249599	et	4	main
vormi	doc_170347281010_item	2249612	et	4	main
oma	doc_170347281010_item	2249618	et	4	main
vanematest	doc_170347281010_item	2249621	et	4	main
ja	doc_170347281010_item	2249627	et	3	main
igaüks	doc_170347281010_item	2249629	et	3	main
artikli	doc_170347281010_item	2249633	et	3	main
nõuetega	doc_170347281010_item	2249635	et	4	main
huvitud	doc_170347281010_item	2249641	et	4	main
ainult	doc_170347281010_item	2249648	et	4	main
naiste	doc_170347281010_item	2249655	et	3	main
kiirte	doc_170347281010_item	2249657	et	3	main
4	doc_170347281010_item	2249660	et	2	main
haigestuda	doc_170347281010_item	2249664	et	3	main
5	doc_170347281010_item	2249667	et	2	main
uuest	doc_170347281010_item	2249671	et	3	main
kiiresti	doc_170347281010_item	2249673	et	3	main
selles	doc_170347281010_item	2249676	et	4	main
vaid	doc_170347281010_item	2249678	et	3	main
7	doc_170347281010_item	2249683	et	2	main
8	doc_170347281010_item	2249691	et	2	main
kleepus	doc_170347281010_item	2249693	et	3	main
9	doc_170347281010_item	2249696	et	2	main
hoiduma	doc_170347281010_item	2249700	et	3	main
külmetamisest	doc_170347281010_item	2249702	et	4	main
rõõmu	doc_170347281010_item	2249706	et	4	main
päikesest	doc_170347281010_item	2249710	et	4	main
v	doc_170347281010_item	2249711	et	4	main
maksis	doc_170347281010_item	2249722	et	4	main
õpilased	doc_170347281010_item	2249728	et	3	main
lapsel	doc_170347281010_item	2249733	et	4	main
ta	doc_170347281010_item	2249751	et	4	main
ei	doc_170347281010_item	2249752	et	4	main
jalutama	doc_170347281010_item	2249764	et	3	main
selles	doc_170347281010_item	2249766	et	4	main
ega	doc_170347281010_item	2249771	et	3	main
vormi	doc_170347281011_item	2249804	et	4	main
piret	doc_170347281011_item	2249805	et	4	main
toomet	doc_170347281011_item	2249806	et	4	main
küla	doc_170347281011_item	2249820	et	4	main
külla	doc_170347281011_item	2249821	et	4	main
ja	doc_170347281011_item	2249830	et	3	main
nüüd	doc_170347281011_item	2249832	et	4	main
eestlastele	doc_170347281011_item	2249838	et	4	main
kinnitusel	doc_170347281011_item	2249845	et	4	main
et	doc_170347281011_item	2249851	et	3	main
oodatud	doc_170347281011_item	2249853	et	4	main
üllatuma	doc_170347281011_item	2249856	et	3	main
korralik	doc_170347281011_item	2249863	et	3	main
rohi	doc_170347281011_item	2249880	et	4	main
kui	doc_170347281011_item	2249881	et	3	main
pärast	doc_170347281011_item	2249888	et	4	main
jõudis	doc_170347281011_item	2249893	et	3	main
küla	doc_170347281011_item	2249900	et	4	main
siin	doc_170347281011_item	2249906	et	4	main
kõige	doc_170347281011_item	2249908	et	4	main
tänaseks	doc_170347281011_item	2249911	et	4	main
käib	doc_170347281011_item	2249918	et	3	main
kuidagi	doc_170347281011_item	2249925	et	3	main
kõiki	doc_170347281010_item	2249626	et	4	main
usaldavad	doc_170347281010_item	2249628	et	4	main
2	doc_170347281010_item	2249631	et	2	main
3	doc_170347281010_item	2249636	et	2	main
aga	doc_170347281010_item	2249644	et	3	main
tunned	doc_170347281010_item	2249646	et	3	main
ilusad	doc_170347281010_item	2249649	et	3	main
kiired	doc_170347281010_item	2249652	et	4	main
praegu	doc_170347281010_item	2249661	et	3	main
piirdusime	doc_170347281010_item	2249675	et	3	main
küsimuses	doc_170347281010_item	2249677	et	4	main
väikeste	doc_170347281010_item	2249681	et	4	main
teine	doc_170347281010_item	2249687	et	3	main
püksid	doc_170347281010_item	2249694	et	3	main
külmetamine	doc_170347281010_item	2249701	et	4	main
10	doc_170347281010_item	2249703	et	2	main
tunnen	doc_170347281010_item	2249705	et	3	main
sobivate	doc_170347281010_item	2249714	et	4	main
sidenditega	doc_170347281010_item	2249715	et	3	main
1	doc_170347281010_item	2249716	et	2	main
tellisime	doc_170347281010_item	2249717	et	4	main
kolmekäigulise	doc_170347281010_item	2249718	et	4	main
lõuna	doc_170347281010_item	2249719	et	4	main
kuid	doc_170347281010_item	2249720	et	4	main
nad	doc_170347281010_item	2249623	et	3	main
nõuded	doc_170347281010_item	2249634	et	3	main
ma	doc_170347281010_item	2249637	et	3	main
et	doc_170347281010_item	2249639	et	3	main
spordist	doc_170347281010_item	2249643	et	3	main
autod	doc_170347281010_item	2249653	et	3	main
oht	doc_170347281010_item	2249663	et	3	main
difteeria	doc_170347281010_item	2249665	et	4	main
difteeriat	doc_170347281010_item	2249666	et	3	main
tüdinesin	doc_170347281010_item	2249668	et	3	main
töökohast	doc_170347281010_item	2249672	et	4	main
väikesed	doc_170347281010_item	2249679	et	4	main
muudatused	doc_170347281010_item	2249680	et	3	main
muudatustega	doc_170347281010_item	2249682	et	3	main
see	doc_170347281010_item	2249684	et	3	main
valdkonda	doc_170347281010_item	2249690	et	4	main
ajal	doc_170347281010_item	2249698	et	4	main
ma	doc_170347281010_item	2249704	et	3	main
suvisest	doc_170347281010_item	2249709	et	4	main
2	doc_170347281010_item	2249724	et	2	main
olid	doc_170347281010_item	2249726	et	4	main
ka	doc_170347281010_item	2249730	et	3	main
kui	doc_170347281010_item	2249736	et	3	main
tagasi	doc_170347281010_item	2249738	et	3	main
4	doc_170347281010_item	2249740	et	2	main
kõrvallauast	doc_170347281010_item	2249741	et	4	main
kostis	doc_170347281010_item	2249742	et	4	main
naeru	doc_170347281010_item	2249743	et	4	main
nagu	doc_170347281010_item	2249744	et	3	main
keegi	doc_170347281010_item	2249746	et	4	main
anekdooti	doc_170347281010_item	2249748	et	4	main
lõpetage	doc_170347281010_item	2249760	et	3	main
suitsetada	doc_170347281010_item	2249770	et	3	main
kuulsin	doc_170347281010_item	2249795	et	3	main
sulgudes	doc_170347281011_item	2249800	et	4	main
suvel	doc_170347281011_item	2249810	et	3	main
siberisse	doc_170347281011_item	2249818	et	4	main
ülem-suetuki	doc_170347281011_item	2249819	et	4	main
nii	doc_170347281010_item	2249727	et	3	main
paluti	doc_170347281010_item	2249734	et	3	main
oodata	doc_170347281010_item	2249735	et	4	main
vanemad	doc_170347281010_item	2249737	et	4	main
5	doc_170347281010_item	2249750	et	2	main
tule	doc_170347281010_item	2249753	et	4	main
vaid	doc_170347281010_item	2249755	et	3	main
hoopis	doc_170347281010_item	2249757	et	3	main
siis	doc_170347281010_item	2249762	et	3	main
tohi	doc_170347281010_item	2249769	et	4	main
alkoholi	doc_170347281010_item	2249772	et	4	main
tarbida	doc_170347281010_item	2249773	et	3	main
8	doc_170347281010_item	2249774	et	2	main
nad	doc_170347281010_item	2249775	et	3	main
töötasid	doc_170347281010_item	2249776	et	4	main
küll	doc_170347281010_item	2249777	et	4	main
pingsalt	doc_170347281010_item	2249778	et	4	main
aga	doc_170347281010_item	2249779	et	3	main
tulemust	doc_170347281010_item	2249780	et	4	main
ei	doc_170347281010_item	2249781	et	4	main
olnud	doc_170347281010_item	2249782	et	4	main
9	doc_170347281010_item	2249783	et	2	main
kas	doc_170347281010_item	2249784	et	3	main
sa	doc_170347281010_item	2249785	et	3	main
sõidad	doc_170347281010_item	2249786	et	3	main
maale	doc_170347281010_item	2249787	et	4	main
või	doc_170347281010_item	2249788	et	4	main
jääd	doc_170347281010_item	2249789	et	4	main
linna	doc_170347281010_item	2249790	et	4	main
10	doc_170347281010_item	2249791	et	2	main
avasin	doc_170347281010_item	2249792	et	3	main
ukse	doc_170347281010_item	2249793	et	3	main
kui	doc_170347281010_item	2249794	et	3	main
eksamitöö	doc_170347281011_item	2249797	et	4	main
naine	doc_170347281011_item	2249809	et	3	main
nägema	doc_170347281011_item	2249811	et	3	main
ta	doc_170347281011_item	2249813	et	4	main
kuulutus	doc_170347281011_item	2249815	et	4	main
eesti	doc_170347281011_item	2249823	et	4	main
keele	doc_170347281011_item	2249824	et	4	main
õpetajat	doc_170347281011_item	2249825	et	4	main
piret	doc_170347281011_item	2249826	et	4	main
nädal	doc_170347281011_item	2249835	et	3	main
õpetamas	doc_170347281011_item	2249843	et	3	main
jõudmisega	doc_170347281011_item	2249850	et	4	main
tulema	doc_170347281011_item	2249860	et	4	main
tulid	doc_170347281011_item	2249861	et	4	main
koht	doc_170347281011_item	2249891	et	3	main
kohale	doc_170347281011_item	2249892	et	4	main
võtma	doc_170347281011_item	2249901	et	3	main
on	doc_170347281011_item	2249905	et	4	main
on	doc_170347281011_item	2249912	et	4	main
salvetud	doc_170347281011_item	2249915	et	4	main
õppimine	doc_170347281011_item	2249917	et	4	main
konkursi	doc_170347281011_item	2249829	et	3	main
on	doc_170347281011_item	2249831	et	4	main
juba	doc_170347281011_item	2249833	et	3	main
üle	doc_170347281011_item	2249834	et	3	main
väikestele	doc_170347281011_item	2249837	et	4	main
need	doc_170347281011_item	2249839	et	3	main
õpetama	doc_170347281011_item	2249842	et	3	main
jõudma	doc_170347281011_item	2249849	et	3	main
on	doc_170347281011_item	2249852	et	4	main
olin	doc_170347281011_item	2249854	et	3	main
üsna	doc_170347281011_item	2249855	et	3	main
mulle	doc_170347281011_item	2249859	et	4	main
korraliku	doc_170347281011_item	2249864	et	3	main
audiga	doc_170347281011_item	2249865	et	3	main
mulle	doc_170347281011_item	2249866	et	4	main
maaliti	doc_170347281011_item	2249867	et	3	main
siber	doc_170347281011_item	2249868	et	4	main
siberist	doc_170347281011_item	2249869	et	4	main
selline	doc_170347281011_item	2249870	et	4	main
pilt	doc_170347281011_item	2249871	et	3	main
et	doc_170347281011_item	2249872	et	3	main
seal	doc_170347281011_item	2249873	et	4	main
ei	doc_170347281011_item	2249874	et	4	main
lendama	doc_170347281011_item	2249875	et	3	main
lenda	doc_170347281011_item	2249876	et	4	main
otsitakse	doc_170347281011_item	2249822	et	3	main
võitis	doc_170347281011_item	2249827	et	3	main
nende	doc_170347281011_item	2249840	et	4	main
pireti	doc_170347281011_item	2249844	et	4	main
tundis	doc_170347281011_item	2249846	et	3	main
üllatanud	doc_170347281011_item	2249857	et	4	main
vastu	doc_170347281011_item	2249862	et	3	main
ega	doc_170347281011_item	2249878	et	3	main
ja	doc_170347281011_item	2249883	et	3	main
tahtmist	doc_170347281011_item	2249885	et	4	main
algust	doc_170347281011_item	2249890	et	4	main
algama	doc_170347281011_item	2249897	et	3	main
kogu	doc_170347281011_item	2249899	et	4	main
ettevõtmine	doc_170347281011_item	2249910	et	3	main
siinsed	doc_170347281011_item	2249922	et	3	main
teistmoodi	doc_170347281011_item	2249926	et	3	main
ja	doc_170347281011_item	2249931	et	3	main
nagu	doc_170347281011_item	2249938	et	3	main
kool	doc_170347281011_item	2249941	et	4	main
ained	doc_170347281011_item	2249949	et	3	main
üle	doc_170347281011_item	2249956	et	3	main
kõik	doc_170347281011_item	2249963	et	4	main
kõikjal	doc_170347281011_item	2249964	et	3	main
pireti	doc_170347281011_item	2249966	et	4	main
õpivad	doc_170347281011_item	2249968	et	3	main
eestist	doc_170347281011_item	2249976	et	3	main
ostan	doc_170347281011_item	2250010	et	3	main
külapoest	doc_170347281011_item	2250012	et	4	main
seal	doc_170347281011_item	2250015	et	4	main
pannes	doc_170347281011_item	2250034	et	4	main
2	doc_170347281011_item	2250041	et	2	main
mehed	doc_170347281011_item	2250047	et	3	main
mehi	doc_170347281011_item	2250056	et	3	main
tegutsema	doc_170347281011_item	2250066	et	3	main
võima	doc_170347281011_item	2250069	et	3	main
meid	doc_170347281011_item	2250077	et	4	main
soovitamatu	doc_170347281011_item	2250083	et	4	main
laskma	doc_170347281011_item	2250088	et	3	main
saama	doc_170347281011_item	2250092	et	4	main
ja	doc_170347281011_item	2250095	et	3	main
puhkama	doc_170347281011_item	2250096	et	3	main
aparaatiks	doc_170347281011_item	2250128	et	4	main
katkestama	doc_170347281011_item	2250140	et	3	main
aeg	doc_170347281011_item	2250154	et	3	main
kuid	doc_170347281011_item	2250155	et	4	main
telefonihelin	doc_170347281011_item	2250156	et	3	main
und	doc_170347281011_item	2250161	et	4	main
lõunasööki	doc_170347281011_item	2250163	et	4	main
iv	doc_170347281011_item	2250172	et	4	main
õigesse	doc_170347281011_item	2250177	et	3	main
väga	doc_170347281011_item	2250182	et	3	main
ja	doc_170347281011_item	2250193	et	3	main
3	doc_170347281011_item	2250200	et	2	main
sa	doc_170347281011_item	2250204	et	3	main
ilusad	doc_170347281011_item	2250214	et	3	main
autod	doc_170347281011_item	2250218	et	3	main
kiiredest	doc_170347281011_item	2250222	et	4	main
praegu	doc_170347281011_item	2250225	et	3	main
5	doc_170347281011_item	2250231	et	2	main
küsimuses	doc_170347281011_item	2250241	et	4	main
muudatustega	doc_170347281011_item	2250246	et	3	main
see	doc_170347281011_item	2250248	et	3	main
kuulub	doc_170347281011_item	2250250	et	3	main
valdkond	doc_170347281011_item	2250252	et	3	main
närimiskumm	doc_170347281011_item	2250256	et	3	main
külmal	doc_170347281011_item	2250263	et	3	main
hoiduma	doc_170347281011_item	2250266	et	3	main
ma	doc_170347281011_item	2250270	et	3	main
v	doc_170347281011_item	2250277	et	4	main
lõuna	doc_170347281011_item	2250285	et	4	main
2	doc_170347281011_item	2250290	et	2	main
oodata	doc_170347281011_item	2250301	et	4	main
keegi	doc_170347281011_item	2250312	et	4	main
ei	doc_170347281011_item	2250318	et	4	main
trenni	doc_170347281011_item	2250320	et	4	main
hoopis	doc_170347281011_item	2250324	et	3	main
6	doc_170347281011_item	2250326	et	2	main
töö	doc_170347281011_item	2250328	et	4	main
lähete	doc_170347281011_item	2250330	et	4	main
7	doc_170347281011_item	2250332	et	2	main
suitsetada	doc_170347281011_item	2250337	et	3	main
küll	doc_170347281011_item	2250344	et	4	main
lind	doc_170347281011_item	2249877	et	3	main
piret	doc_170347281011_item	2249887	et	4	main
õppeaasta	doc_170347281011_item	2249889	et	4	main
kool	doc_170347281011_item	2249895	et	4	main
veel	doc_170347281011_item	2249896	et	4	main
algamas	doc_170347281011_item	2249898	et	3	main
võttis	doc_170347281011_item	2249902	et	3	main
tähtis	doc_170347281011_item	2249909	et	4	main
salv	doc_170347281011_item	2249914	et	3	main
hoog	doc_170347281011_item	2249920	et	3	main
eestlased	doc_170347281011_item	2249923	et	3	main
mõnus	doc_170347281011_item	2249927	et	4	main
mitte	doc_170347281011_item	2249933	et	3	main
aktsent	doc_170347281011_item	2249935	et	3	main
mõni	doc_170347281011_item	2249939	et	3	main
on	doc_170347281011_item	2249942	et	4	main
külas	doc_170347281011_item	2249953	et	3	main
emakeelt	doc_170347281011_item	2249961	et	4	main
raamatud	doc_170347281011_item	2249971	et	4	main
saatma	doc_170347281011_item	2249974	et	3	main
külapood	doc_170347281011_item	2250011	et	3	main
vildid	doc_170347281011_item	2250013	et	4	main
muud	doc_170347281011_item	2250017	et	4	main
naerab	doc_170347281011_item	2250020	et	3	main
valmistuma	doc_170347281011_item	2250022	et	3	main
valmistatud	doc_170347281011_item	2250023	et	4	main
ajalehest	doc_170347281011_item	2250027	et	4	main
sõnadest	doc_170347281011_item	2250032	et	3	main
kaunim	doc_170347281011_item	2250050	et	4	main
naisi	doc_170347281011_item	2250053	et	3	main
igaüks	doc_170347281011_item	2250058	et	3	main
3	doc_170347281011_item	2250060	et	2	main
kogus	doc_170347281011_item	2250062	et	4	main
stress	doc_170347281011_item	2250063	et	3	main
soovimatu	doc_170347281011_item	2250071	et	4	main
koguses	doc_170347281011_item	2250074	et	4	main
tegutsema	doc_170347281011_item	2250078	et	3	main
lisakoormus	doc_170347281011_item	2250080	et	3	main
tekkima	doc_170347281011_item	2250090	et	3	main
telefon	doc_170347281011_item	2250122	et	3	main
et	doc_170347281011_item	2250129	et	3	main
lausa	doc_170347281011_item	2250133	et	4	main
ka	doc_170347281011_item	2250141	et	3	main
varahommik	doc_170347281011_item	2250143	et	3	main
segama	doc_170347281011_item	2250145	et	3	main
valmistamine	doc_170347281011_item	2250147	et	4	main
vaatamine	doc_170347281011_item	2250153	et	4	main
ka	doc_170347281011_item	2250158	et	3	main
segab	doc_170347281011_item	2250162	et	3	main
ja	doc_170347281011_item	2250165	et	3	main
vaatamise	doc_170347281011_item	2250170	et	4	main
pange	doc_170347281011_item	2250173	et	4	main
lugu	doc_170347281011_item	2250183	et	4	main
oma	doc_170347281011_item	2250186	et	4	main
usaldavad	doc_170347281011_item	2250194	et	4	main
2	doc_170347281011_item	2250196	et	2	main
nõuded	doc_170347281011_item	2250199	et	3	main
et	doc_170347281011_item	2250203	et	3	main
huvi	doc_170347281011_item	2250212	et	4	main
ja	doc_170347281011_item	2250221	et	3	main
autodest	doc_170347281011_item	2250223	et	3	main
on	doc_170347281011_item	2250226	et	4	main
oht	doc_170347281011_item	2250227	et	3	main
difteeriat	doc_170347281011_item	2250230	et	3	main
uus	doc_170347281011_item	2250233	et	3	main
6	doc_170347281011_item	2250238	et	2	main
väikestega	doc_170347281011_item	2250245	et	4	main
teise	doc_170347281011_item	2250253	et	4	main
püksid	doc_170347281011_item	2250258	et	3	main
pükste	doc_170347281011_item	2250260	et	3	main
päike	doc_170347281011_item	2250274	et	3	main
päikesest	doc_170347281011_item	2250276	et	4	main
täitke	doc_170347281011_item	2250278	et	3	main
sobivate	doc_170347281011_item	2250280	et	4	main
palju	doc_170347281011_item	2250289	et	4	main
kohal	doc_170347281011_item	2250291	et	4	main
paluti	doc_170347281011_item	2250300	et	3	main
kuna	doc_170347281011_item	2250302	et	3	main
vanemad	doc_170347281011_item	2250303	et	4	main
tagasi	doc_170347281011_item	2250304	et	3	main
4	doc_170347281011_item	2250306	et	2	main
räägivad	doc_170347281011_item	2249924	et	3	main
mõnusalt	doc_170347281011_item	2249930	et	4	main
vene	doc_170347281011_item	2249934	et	4	main
aktsendita	doc_170347281011_item	2249936	et	3	main
murretu	doc_170347281011_item	2249940	et	4	main
venemaa	doc_170347281011_item	2249944	et	4	main
kool	doc_170347281011_item	2249945	et	4	main
ülejäänud	doc_170347281011_item	2249947	et	4	main
õpetatakse	doc_170347281011_item	2249950	et	3	main
veidi	doc_170347281011_item	2249955	et	3	main
kolmesaja	doc_170347281011_item	2249958	et	4	main
inimene	doc_170347281011_item	2249959	et	3	main
inimest	doc_170347281011_item	2249960	et	3	main
rääkida	doc_170347281011_item	2249965	et	3	main
sõnul	doc_170347281011_item	2249967	et	3	main
piret	doc_170347281011_item	2249981	et	4	main
ei	doc_170347281011_item	2249982	et	4	main
kartma	doc_170347281011_item	2249983	et	3	main
karda	doc_170347281011_item	2249984	et	4	main
mulle	doc_170347281011_item	2249985	et	4	main
juba	doc_170347281011_item	2249986	et	3	main
tooma	doc_170347281011_item	2249987	et	3	main
toodi	doc_170347281011_item	2249988	et	4	main
praegu	doc_170347281011_item	2249990	et	3	main
on	doc_170347281011_item	2249991	et	4	main
päevad	doc_170347281011_item	2249992	et	3	main
talvepuud	doc_170347281011_item	2249989	et	4	main
veel	doc_170347281011_item	2249993	et	4	main
soojad	doc_170347281011_item	2249995	et	3	main
soe	doc_170347281011_item	2249994	et	4	main
kuid	doc_170347281011_item	2249996	et	4	main
ööd	doc_170347281011_item	2249997	et	4	main
juba	doc_170347281011_item	2249998	et	3	main
jahe	doc_170347281011_item	2249999	et	3	main
jahedad	doc_170347281011_item	2250000	et	3	main
harjutan	doc_170347281011_item	2250001	et	3	main
juba	doc_170347281011_item	2250002	et	3	main
suure	doc_170347281011_item	2250003	et	3	main
vene	doc_170347281011_item	2250004	et	4	main
ahju	doc_170347281011_item	2250005	et	4	main
kütmine	doc_170347281011_item	2250006	et	4	main
kütmist	doc_170347281011_item	2250007	et	4	main
kui	doc_170347281011_item	2250008	et	3	main
mahlakas	doc_170347281011_item	2249929	et	4	main
mahlakaselt	doc_170347281011_item	2249932	et	3	main
vaid	doc_170347281011_item	2249937	et	3	main
ja	doc_170347281011_item	2249946	et	3	main
aine	doc_170347281011_item	2249948	et	4	main
keeles	doc_170347281011_item	2249952	et	4	main
saab	doc_170347281011_item	2249962	et	3	main
poolpõlenud	doc_170347281011_item	2249970	et	4	main
varsti	doc_170347281011_item	2249973	et	3	main
saavad	doc_170347281011_item	2249975	et	4	main
uued	doc_170347281011_item	2249977	et	3	main
õpikud	doc_170347281011_item	2249978	et	3	main
siberi	doc_170347281011_item	2249979	et	4	main
ega	doc_170347281011_item	2250014	et	3	main
talveks	doc_170347281011_item	2250021	et	4	main
lühendatud	doc_170347281011_item	2250026	et	4	main
slõhtuleht	doc_170347281011_item	2250028	et	4	main
sõnad	doc_170347281011_item	2250035	et	4	main
õigesse	doc_170347281011_item	2250036	et	3	main
ja	doc_170347281011_item	2250038	et	3	main
naised	doc_170347281011_item	2250044	et	3	main
naeratus	doc_170347281011_item	2250051	et	4	main
ja	doc_170347281011_item	2250055	et	3	main
mehelikumaks	doc_170347281011_item	2250057	et	4	main
kaunimaks	doc_170347281011_item	2250059	et	4	main
paras	doc_170347281011_item	2250061	et	3	main
aga	doc_170347281011_item	2250067	et	3	main
stress	doc_170347281011_item	2250075	et	3	main
4	doc_170347281011_item	2250085	et	2	main
ei	doc_170347281011_item	2250086	et	4	main
tohtima	doc_170347281011_item	2250087	et	3	main
ei	doc_170347281011_item	2250097	et	4	main
hingama	doc_170347281011_item	2250121	et	3	main
tänapäeval	doc_170347281011_item	2250124	et	3	main
abil	doc_170347281011_item	2250131	et	4	main
6	doc_170347281011_item	2250137	et	2	main
kuid	doc_170347281011_item	2250138	et	4	main
uni	doc_170347281011_item	2250144	et	3	main
ja	doc_170347281011_item	2250148	et	3	main
huvitav	doc_170347281011_item	2250151	et	4	main
telesaade	doc_170347281011_item	2250152	et	4	main
katkestab	doc_170347281011_item	2250157	et	3	main
sulgudes	doc_170347281011_item	2250174	et	4	main
sõnad	doc_170347281011_item	2250176	et	4	main
vormi	doc_170347281011_item	2250178	et	4	main
1	doc_170347281011_item	2250179	et	2	main
ma	doc_170347281011_item	2250180	et	3	main
pean	doc_170347281011_item	2250181	et	4	main
vanemad	doc_170347281011_item	2250185	et	4	main
vanematest	doc_170347281011_item	2250187	et	4	main
kõiki	doc_170347281011_item	2250192	et	4	main
artikli	doc_170347281011_item	2250198	et	3	main
aga	doc_170347281011_item	2250209	et	3	main
ja	doc_170347281011_item	2250216	et	3	main
vaja	doc_170347281011_item	2250009	et	4	main
suurt	doc_170347281011_item	2250016	et	3	main
ei	doc_170347281011_item	2250018	et	4	main
müüdagi	doc_170347281011_item	2250019	et	3	main
vapralt	doc_170347281011_item	2250025	et	4	main
iii	doc_170347281011_item	2250029	et	4	main
etteantud	doc_170347281011_item	2250031	et	4	main
kasutades	doc_170347281011_item	2250039	et	3	main
igaüks	doc_170347281011_item	2250049	et	3	main
teeb	doc_170347281011_item	2250052	et	3	main
meie	doc_170347281011_item	2250065	et	4	main
tagajärg	doc_170347281011_item	2250072	et	3	main
paneb	doc_170347281011_item	2250076	et	3	main
aga	doc_170347281011_item	2250079	et	3	main
võib	doc_170347281011_item	2250081	et	3	main
pinge	doc_170347281011_item	2250091	et	4	main
maandama	doc_170347281011_item	2250093	et	3	main
tohi	doc_170347281011_item	2250098	et	4	main
lasta	doc_170347281011_item	2250099	et	4	main
ülekoormusele	doc_170347281011_item	2250100	et	3	main
tekkida	doc_170347281011_item	2250101	et	3	main
pingele	doc_170347281011_item	2250102	et	4	main
maandata	doc_170347281011_item	2250103	et	3	main
sportida	doc_170347281011_item	2250104	et	4	main
ja	doc_170347281011_item	2250105	et	3	main
puhata	doc_170347281011_item	2250106	et	4	main
5	doc_170347281011_item	2250107	et	2	main
olema	doc_170347281011_item	2250109	et	4	main
tänapäev	doc_170347281011_item	2250110	et	3	main
saama	doc_170347281011_item	2250111	et	4	main
telefon	doc_170347281011_item	2250108	et	3	main
nii	doc_170347281011_item	2250112	et	3	main
maagiline	doc_170347281011_item	2250113	et	4	main
aparaat	doc_170347281011_item	2250114	et	3	main
et	doc_170347281011_item	2250115	et	3	main
see	doc_170347281011_item	2250116	et	3	main
abil	doc_170347281011_item	2250117	et	4	main
lausa	doc_170347281011_item	2250118	et	4	main
elama	doc_170347281011_item	2250119	et	3	main
ja	doc_170347281011_item	2250120	et	3	main
moodustage	doc_170347281011_item	2250030	et	3	main
laused	doc_170347281011_item	2250033	et	3	main
vormi	doc_170347281011_item	2250037	et	4	main
kirjavahemärke	doc_170347281011_item	2250040	et	4	main
naeratus	doc_170347281011_item	2250042	et	4	main
tegema	doc_170347281011_item	2250043	et	3	main
naiselikum	doc_170347281011_item	2250045	et	4	main
ja	doc_170347281011_item	2250046	et	3	main
mehelikum	doc_170347281011_item	2250048	et	4	main
naiselikumaks	doc_170347281011_item	2250054	et	4	main
panema	doc_170347281011_item	2250064	et	3	main
lisakoormus	doc_170347281011_item	2250068	et	3	main
tooma	doc_170347281011_item	2250070	et	3	main
parases	doc_170347281011_item	2250073	et	4	main
tuua	doc_170347281011_item	2250082	et	3	main
tagajärgi	doc_170347281011_item	2250084	et	4	main
ülekoormus	doc_170347281011_item	2250089	et	3	main
sportima	doc_170347281011_item	2250094	et	4	main
on	doc_170347281011_item	2250123	et	4	main
saanud	doc_170347281011_item	2250125	et	4	main
nii	doc_170347281011_item	2250126	et	3	main
maagiliks	doc_170347281011_item	2250127	et	4	main
elada	doc_170347281011_item	2250134	et	3	main
ja	doc_170347281011_item	2250135	et	3	main
pühapäev	doc_170347281011_item	2250142	et	3	main
pahandab	doc_170347281011_item	2250150	et	3	main
pühapäeva	doc_170347281011_item	2250159	et	4	main
valmistamise	doc_170347281011_item	2250164	et	4	main
söömise	doc_170347281011_item	2250166	et	4	main
telesaade	doc_170347281011_item	2250169	et	4	main
olevad	doc_170347281011_item	2250175	et	4	main
kõik	doc_170347281011_item	2250191	et	4	main
arvasin	doc_170347281011_item	2250202	et	3	main
huvitud	doc_170347281011_item	2250205	et	4	main
huvitatud	doc_170347281011_item	2250207	et	4	main
spordist	doc_170347281011_item	2250208	et	3	main
tunned	doc_170347281011_item	2250211	et	3	main
ainult	doc_170347281011_item	2250213	et	4	main
kiired	doc_170347281011_item	2250217	et	4	main
piirdusime	doc_170347281011_item	2250239	et	3	main
7	doc_170347281011_item	2250247	et	2	main
valdkonda	doc_170347281011_item	2250254	et	4	main
külga	doc_170347281011_item	2250261	et	4	main
külmatamisest	doc_170347281011_item	2250268	et	4	main
suvine	doc_170347281011_item	2250273	et	4	main
1	doc_170347281011_item	2250282	et	2	main
kolmekäigulise	doc_170347281011_item	2250284	et	4	main
ja	doc_170347281011_item	2250286	et	3	main
meie	doc_170347281011_item	2250293	et	4	main
meie	doc_170347281011_item	2250296	et	4	main
lapsel	doc_170347281011_item	2250299	et	4	main
tulevad	doc_170347281011_item	2250305	et	4	main
nagu	doc_170347281011_item	2250310	et	3	main
anekdooti	doc_170347281011_item	2250314	et	4	main
tule	doc_170347281011_item	2250319	et	4	main
selle	doc_170347281011_item	2250130	et	4	main
ei	doc_170347281011_item	2250132	et	4	main
hingata	doc_170347281011_item	2250136	et	4	main
telefonihelin	doc_170347281011_item	2250139	et	3	main
lõunasöök	doc_170347281011_item	2250146	et	3	main
söömine	doc_170347281011_item	2250149	et	4	main
varahommiku	doc_170347281011_item	2250160	et	3	main
pahandab	doc_170347281011_item	2250167	et	3	main
huvitava	doc_170347281011_item	2250168	et	4	main
aega	doc_170347281011_item	2250171	et	4	main
oma	doc_170347281011_item	2250184	et	4	main
sest	doc_170347281011_item	2250188	et	4	main
nad	doc_170347281011_item	2250189	et	3	main
aitavad	doc_170347281011_item	2250190	et	4	main
igaüks	doc_170347281011_item	2250195	et	3	main
kohandasin	doc_170347281011_item	2250197	et	3	main
ma	doc_170347281011_item	2250201	et	3	main
sport	doc_170347281011_item	2250206	et	3	main
sa	doc_170347281011_item	2250210	et	3	main
naised	doc_170347281011_item	2250215	et	3	main
ilusatest	doc_170347281011_item	2250219	et	3	main
naistest	doc_170347281011_item	2250220	et	4	main
4	doc_170347281011_item	2250224	et	2	main
difteeria	doc_170347281011_item	2250229	et	4	main
uuesse	doc_170347281011_item	2250235	et	3	main
kiiresti	doc_170347281011_item	2250237	et	3	main
teine	doc_170347281011_item	2250251	et	3	main
pükstele	doc_170347281011_item	2250259	et	3	main
9	doc_170347281011_item	2250262	et	2	main
ajal	doc_170347281011_item	2250264	et	4	main
külmetamine	doc_170347281011_item	2250267	et	4	main
rõõmu	doc_170347281011_item	2250272	et	4	main
lüngad	doc_170347281011_item	2250279	et	3	main
tellisime	doc_170347281011_item	2250283	et	4	main
maksis	doc_170347281011_item	2250288	et	4	main
olid	doc_170347281011_item	2250292	et	4	main
ja	doc_170347281011_item	2250295	et	3	main
3	doc_170347281011_item	2250298	et	2	main
kõrvallauast	doc_170347281011_item	2250307	et	4	main
oleks	doc_170347281011_item	2250311	et	3	main
rääkinud	doc_170347281011_item	2250315	et	4	main
ta	doc_170347281011_item	2250317	et	4	main
sellepärast	doc_170347281011_item	2250321	et	3	main
läheb	doc_170347281011_item	2250323	et	3	main
teatrisse	doc_170347281011_item	2250325	et	3	main
ei	doc_170347281011_item	2250335	et	4	main
tarbida	doc_170347281011_item	2250340	et	3	main
olnud	doc_170347281011_item	2250349	et	4	main
sa	doc_170347281011_item	2250352	et	3	main
kuulsin	doc_170347281011_item	2250362	et	3	main
olevad	doc_170347281012_item	2250368	et	4	main
sõnad	doc_170347281012_item	2250369	et	4	main
küla	doc_170347281012_item	2250387	et	4	main
ja	doc_170347281012_item	2250397	et	3	main
nädal	doc_170347281012_item	2250402	et	3	main
väikestele	doc_170347281012_item	2250404	et	4	main
need	doc_170347281012_item	2250406	et	3	main
siberisse	doc_170347281012_item	2250415	et	4	main
on	doc_170347281012_item	2250419	et	4	main
üllatuma	doc_170347281012_item	2250423	et	3	main
audiga	doc_170347281012_item	2250432	et	3	main
ega	doc_170347281012_item	2250445	et	3	main
kui	doc_170347281012_item	2250448	et	3	main
ja	doc_170347281012_item	2250450	et	3	main
piret	doc_170347281012_item	2250454	et	4	main
alanud	doc_170347281012_item	2250465	et	4	main
sügisel	doc_170347281012_item	2250474	et	3	main
tänaseks	doc_170347281012_item	2250479	et	4	main
siiski	doc_170347281012_item	2250512	et	4	main
kool	doc_170347281012_item	2250514	et	4	main
elab	doc_170347281012_item	2250523	et	3	main
kolmsada	doc_170347281012_item	2250526	et	4	main
inimene	doc_170347281012_item	2250528	et	3	main
pireti	doc_170347281012_item	2250535	et	4	main
sõnul	doc_170347281012_item	2250536	et	3	main
saadetakse	doc_170347281012_item	2250544	et	3	main
kartma	doc_170347281012_item	2250552	et	3	main
tooma	doc_170347281012_item	2250556	et	3	main
päevad	doc_170347281012_item	2250561	et	3	main
kuid	doc_170347281012_item	2250565	et	4	main
vene	doc_170347281012_item	2250573	et	4	main
kütmine	doc_170347281012_item	2250575	et	4	main
kui	doc_170347281012_item	2250577	et	3	main
mehed	doc_170347281012_item	2250616	et	3	main
stress	doc_170347281012_item	2250632	et	3	main
meie	doc_170347281012_item	2250634	et	4	main
haigestuda	doc_170347281011_item	2250228	et	3	main
tüdinesin	doc_170347281011_item	2250232	et	3	main
töökoht	doc_170347281011_item	2250234	et	3	main
töökta	doc_170347281011_item	2250236	et	4	main
selles	doc_170347281011_item	2250240	et	4	main
vaid	doc_170347281011_item	2250242	et	3	main
väikesed	doc_170347281011_item	2250243	et	4	main
muudatused	doc_170347281011_item	2250244	et	3	main
küsimus	doc_170347281011_item	2250249	et	4	main
8	doc_170347281011_item	2250255	et	2	main
kleepus	doc_170347281011_item	2250257	et	3	main
peab	doc_170347281011_item	2250265	et	4	main
10	doc_170347281011_item	2250269	et	2	main
tunnen	doc_170347281011_item	2250271	et	3	main
suvisest	doc_170347281011_item	2250275	et	4	main
sidenditega	doc_170347281011_item	2250281	et	3	main
see	doc_170347281011_item	2250287	et	3	main
õpilased	doc_170347281011_item	2250294	et	3	main
õpetajad	doc_170347281011_item	2250297	et	4	main
naeru	doc_170347281011_item	2250309	et	4	main
5	doc_170347281011_item	2250316	et	2	main
baaris	doc_170347281011_item	2250334	et	3	main
ega	doc_170347281011_item	2250338	et	3	main
9	doc_170347281011_item	2250350	et	2	main
sõidad	doc_170347281011_item	2250353	et	3	main
või	doc_170347281011_item	2250355	et	4	main
linna	doc_170347281011_item	2250357	et	4	main
ja	doc_170347281011_item	2250361	et	3	main
koputust	doc_170347281011_item	2250363	et	4	main
i	doc_170347281012_item	2250365	et	4	main
pange	doc_170347281012_item	2250366	et	4	main
õigesse	doc_170347281012_item	2250370	et	3	main
ajalehes	doc_170347281012_item	2250381	et	3	main
kuulutust	doc_170347281012_item	2250383	et	4	main
eesti	doc_170347281012_item	2250390	et	4	main
nüüd	doc_170347281012_item	2250399	et	4	main
juba	doc_170347281012_item	2250400	et	3	main
üle	doc_170347281012_item	2250401	et	3	main
nädala	doc_170347281012_item	2250403	et	3	main
eestlastele	doc_170347281012_item	2250405	et	4	main
õpetama	doc_170347281012_item	2250409	et	3	main
kinnitusel	doc_170347281012_item	2250412	et	4	main
jõudma	doc_170347281012_item	2250416	et	3	main
et	doc_170347281012_item	2250418	et	3	main
üsna	doc_170347281012_item	2250422	et	3	main
korralik	doc_170347281012_item	2250430	et	3	main
lenda	doc_170347281012_item	2250443	et	4	main
tahtmine	doc_170347281012_item	2250451	et	4	main
tahtmist	doc_170347281012_item	2250452	et	4	main
kogu	doc_170347281012_item	2250466	et	4	main
võttis	doc_170347281012_item	2250469	et	3	main
kõige	doc_170347281012_item	2250475	et	4	main
aine	doc_170347281012_item	2250517	et	4	main
saab	doc_170347281012_item	2250531	et	3	main
lapsed	doc_170347281012_item	2250538	et	3	main
raamatud	doc_170347281012_item	2250540	et	4	main
varsti	doc_170347281012_item	2250542	et	3	main
talve	doc_170347281012_item	2250549	et	4	main
ei	doc_170347281012_item	2250551	et	4	main
talvepuud	doc_170347281012_item	2250558	et	4	main
suure	doc_170347281012_item	2250572	et	3	main
vormi	doc_170347281012_item	2250606	et	4	main
kirjavahemärke	doc_170347281012_item	2250609	et	4	main
ja	doc_170347281012_item	2250615	et	3	main
kostis	doc_170347281011_item	2250308	et	4	main
just	doc_170347281011_item	2250313	et	3	main
tohi	doc_170347281011_item	2250336	et	4	main
8	doc_170347281011_item	2250341	et	2	main
töötasid	doc_170347281011_item	2250343	et	4	main
pingsalt	doc_170347281011_item	2250345	et	4	main
jääd	doc_170347281011_item	2250356	et	4	main
10	doc_170347281011_item	2250358	et	2	main
ukse	doc_170347281011_item	2250360	et	3	main
vormi	doc_170347281012_item	2250371	et	4	main
on	doc_170347281012_item	2250374	et	4	main
naine	doc_170347281012_item	2250376	et	3	main
nägema	doc_170347281012_item	2250378	et	3	main
ta	doc_170347281012_item	2250380	et	4	main
kuulutus	doc_170347281012_item	2250382	et	4	main
et	doc_170347281012_item	2250384	et	3	main
siberisse	doc_170347281012_item	2250385	et	4	main
ülem-suetuki	doc_170347281012_item	2250386	et	4	main
külasse	doc_170347281012_item	2250388	et	3	main
piret	doc_170347281012_item	2250393	et	4	main
konkursi	doc_170347281012_item	2250396	et	3	main
nende	doc_170347281012_item	2250407	et	4	main
ta	doc_170347281012_item	2250414	et	4	main
et	doc_170347281011_item	2250322	et	3	main
lõpetage	doc_170347281011_item	2250327	et	3	main
et	doc_170347281011_item	2250329	et	3	main
jalutama	doc_170347281011_item	2250331	et	3	main
selles	doc_170347281011_item	2250333	et	4	main
alkoholi	doc_170347281011_item	2250339	et	4	main
nad	doc_170347281011_item	2250342	et	3	main
tulemust	doc_170347281011_item	2250347	et	4	main
aga	doc_170347281011_item	2250346	et	3	main
ei	doc_170347281011_item	2250348	et	4	main
kas	doc_170347281011_item	2250351	et	3	main
maale	doc_170347281011_item	2250354	et	4	main
avasin	doc_170347281011_item	2250359	et	3	main
eksamitöö	doc_170347281012_item	2250364	et	4	main
piret	doc_170347281012_item	2250372	et	4	main
ettevõtlik	doc_170347281012_item	2250375	et	3	main
suvel	doc_170347281012_item	2250377	et	3	main
keele	doc_170347281012_item	2250391	et	4	main
õpetajat	doc_170347281012_item	2250392	et	4	main
võitis	doc_170347281012_item	2250394	et	3	main
konkurss	doc_170347281012_item	2250395	et	3	main
emakeelt	doc_170347281012_item	2250408	et	4	main
pireti	doc_170347281012_item	2250411	et	4	main
tundis	doc_170347281012_item	2250413	et	3	main
jõudes	doc_170347281012_item	2250417	et	3	main
olin	doc_170347281012_item	2250421	et	3	main
korraliku	doc_170347281012_item	2250431	et	3	main
maaliti	doc_170347281012_item	2250434	et	3	main
seal	doc_170347281012_item	2250440	et	4	main
kasva	doc_170347281012_item	2250446	et	4	main
rohi	doc_170347281012_item	2250447	et	4	main
noor	doc_170347281012_item	2250449	et	3	main
pärast	doc_170347281012_item	2250455	et	4	main
algust	doc_170347281012_item	2250457	et	4	main
küla	doc_170347281012_item	2250467	et	4	main
kartuleid	doc_170347281012_item	2250470	et	3	main
on	doc_170347281012_item	2250472	et	4	main
tähtis	doc_170347281012_item	2250476	et	4	main
ettevõtmine	doc_170347281012_item	2250478	et	3	main
venemaa	doc_170347281012_item	2250513	et	4	main
ja	doc_170347281012_item	2250515	et	3	main
ülejäänud	doc_170347281012_item	2250516	et	4	main
ained	doc_170347281012_item	2250518	et	3	main
õpetatakse	doc_170347281012_item	2250519	et	3	main
vene	doc_170347281012_item	2250520	et	4	main
keeles	doc_170347281012_item	2250521	et	4	main
veidi	doc_170347281012_item	2250524	et	3	main
üle	doc_170347281012_item	2250525	et	3	main
kolmesaja	doc_170347281012_item	2250527	et	4	main
emakeelt	doc_170347281012_item	2250530	et	4	main
rääkida	doc_170347281012_item	2250534	et	3	main
õpivad	doc_170347281012_item	2250537	et	3	main
poolpõlenud	doc_170347281012_item	2250539	et	4	main
uued	doc_170347281012_item	2250546	et	3	main
siberi	doc_170347281012_item	2250548	et	4	main
mulle	doc_170347281012_item	2250554	et	4	main
on	doc_170347281012_item	2250560	et	4	main
ööd	doc_170347281012_item	2250566	et	4	main
juba	doc_170347281012_item	2250571	et	3	main
kütmist	doc_170347281012_item	2250576	et	4	main
ja	doc_170347281012_item	2250607	et	3	main
2	doc_170347281012_item	2250610	et	2	main
naiselikum	doc_170347281012_item	2250614	et	4	main
kaunim	doc_170347281012_item	2250619	et	4	main
teeb	doc_170347281012_item	2250621	et	3	main
3	doc_170347281012_item	2250629	et	2	main
kogus	doc_170347281012_item	2250631	et	4	main
tegutsema	doc_170347281012_item	2250635	et	3	main
lisakoormus	doc_170347281012_item	2250637	et	3	main
tagajärg	doc_170347281012_item	2250641	et	3	main
paras	doc_170347281012_item	2250642	et	3	main
soovimatuid	doc_170347281012_item	2250652	et	4	main
tagajärje	doc_170347281012_item	2250655	et	3	main
tohtima	doc_170347281012_item	2250658	et	3	main
ülekoormuse	doc_170347281012_item	2250671	et	3	main
sportides	doc_170347281012_item	2250676	et	4	main
puhates	doc_170347281012_item	2250678	et	3	main
aparaat	doc_170347281012_item	2250686	et	3	main
see	doc_170347281012_item	2250688	et	3	main
lausa	doc_170347281012_item	2250690	et	4	main
hingama	doc_170347281012_item	2250693	et	3	main
aparaadiks	doc_170347281012_item	2250700	et	3	main
selle	doc_170347281012_item	2250702	et	4	main
abil	doc_170347281012_item	2250703	et	4	main
lausa	doc_170347281012_item	2250704	et	4	main
elatakse	doc_170347281012_item	2250705	et	3	main
hingatakse	doc_170347281012_item	2250707	et	3	main
uni	doc_170347281012_item	2250715	et	3	main
ja	doc_170347281012_item	2250719	et	3	main
sulgudes	doc_170347281012_item	2250367	et	4	main
toomet	doc_170347281012_item	2250373	et	4	main
nägi	doc_170347281012_item	2250379	et	3	main
otsitakse	doc_170347281012_item	2250389	et	3	main
on	doc_170347281012_item	2250398	et	4	main
õpetamas	doc_170347281012_item	2250410	et	3	main
oodatud	doc_170347281012_item	2250420	et	4	main
kui	doc_170347281012_item	2250425	et	3	main
mulle	doc_170347281012_item	2250426	et	4	main
tuldi	doc_170347281012_item	2250428	et	3	main
vastu	doc_170347281012_item	2250429	et	3	main
mulle	doc_170347281012_item	2250433	et	4	main
siber	doc_170347281012_item	2250435	et	4	main
selline	doc_170347281012_item	2250437	et	4	main
pilt	doc_170347281012_item	2250438	et	3	main
et	doc_170347281012_item	2250439	et	3	main
ei	doc_170347281012_item	2250441	et	4	main
lendama	doc_170347281012_item	2250442	et	3	main
õppeaasta	doc_170347281012_item	2250456	et	4	main
koht	doc_170347281012_item	2250458	et	3	main
veel	doc_170347281012_item	2250463	et	4	main
võtma	doc_170347281012_item	2250468	et	3	main
siin	doc_170347281012_item	2250473	et	4	main
murret	doc_170347281012_item	2250509	et	4	main
kool	doc_170347281012_item	2250510	et	4	main
üllatunud	doc_170347281012_item	2250424	et	4	main
tulema	doc_170347281012_item	2250427	et	4	main
siberist	doc_170347281012_item	2250436	et	4	main
lind	doc_170347281012_item	2250444	et	3	main
täis	doc_170347281012_item	2250453	et	4	main
kohale	doc_170347281012_item	2250459	et	4	main
jõudis	doc_170347281012_item	2250460	et	3	main
polnud	doc_170347281012_item	2250461	et	3	main
kool	doc_170347281012_item	2250462	et	4	main
algama	doc_170347281012_item	2250464	et	3	main
kartulivõtt	doc_170347281012_item	2250471	et	3	main
tähtsam	doc_170347281012_item	2250477	et	4	main
on	doc_170347281012_item	2250480	et	4	main
kartul	doc_170347281012_item	2250481	et	3	main
salv	doc_170347281012_item	2250482	et	3	main
salves	doc_170347281012_item	2250483	et	4	main
ja	doc_170347281012_item	2250484	et	3	main
õppimine	doc_170347281012_item	2250485	et	4	main
käib	doc_170347281012_item	2250486	et	3	main
täie	doc_170347281012_item	2250487	et	3	main
hoog	doc_170347281012_item	2250488	et	3	main
hooguga	doc_170347281012_item	2250489	et	4	main
siinsed	doc_170347281012_item	2250490	et	3	main
eestlased	doc_170347281012_item	2250491	et	3	main
räägivad	doc_170347281012_item	2250492	et	3	main
kuidagi	doc_170347281012_item	2250493	et	3	main
teistmoodi	doc_170347281012_item	2250494	et	3	main
mõnus	doc_170347281012_item	2250495	et	4	main
ja	doc_170347281012_item	2250496	et	3	main
mahlakas	doc_170347281012_item	2250497	et	4	main
ja	doc_170347281012_item	2250499	et	3	main
mahlakalt	doc_170347281012_item	2250500	et	4	main
mõnusalt	doc_170347281012_item	2250498	et	4	main
mitte	doc_170347281012_item	2250501	et	3	main
vene	doc_170347281012_item	2250502	et	4	main
aktsent	doc_170347281012_item	2250503	et	3	main
aktsendiga	doc_170347281012_item	2250504	et	3	main
vaid	doc_170347281012_item	2250505	et	3	main
nagu	doc_170347281012_item	2250506	et	3	main
mõni	doc_170347281012_item	2250507	et	3	main
mõnda	doc_170347281012_item	2250508	et	4	main
on	doc_170347281012_item	2250511	et	4	main
külas	doc_170347281012_item	2250522	et	3	main
kõik	doc_170347281012_item	2250532	et	4	main
saatma	doc_170347281012_item	2250543	et	3	main
õpikud	doc_170347281012_item	2250547	et	3	main
piret	doc_170347281012_item	2250550	et	4	main
juba	doc_170347281012_item	2250555	et	3	main
praegu	doc_170347281012_item	2250559	et	3	main
soe	doc_170347281012_item	2250563	et	4	main
juba	doc_170347281012_item	2250567	et	3	main
jahedad	doc_170347281012_item	2250569	et	3	main
ahju	doc_170347281012_item	2250574	et	4	main
naised	doc_170347281012_item	2250613	et	3	main
igaüks	doc_170347281012_item	2250618	et	3	main
ja	doc_170347281012_item	2250624	et	3	main
mehi	doc_170347281012_item	2250625	et	3	main
igaühe	doc_170347281012_item	2250627	et	4	main
kaunimaks	doc_170347281012_item	2250628	et	4	main
paras	doc_170347281012_item	2250630	et	3	main
panema	doc_170347281012_item	2250633	et	3	main
võima	doc_170347281012_item	2250638	et	3	main
soovimatu	doc_170347281012_item	2250640	et	4	main
kogus	doc_170347281012_item	2250643	et	4	main
meid	doc_170347281012_item	2250646	et	4	main
tekkima	doc_170347281012_item	2250661	et	3	main
ei	doc_170347281012_item	2250668	et	4	main
maandada	doc_170347281012_item	2250675	et	3	main
maagiline	doc_170347281012_item	2250685	et	4	main
et	doc_170347281012_item	2250687	et	3	main
saanud	doc_170347281012_item	2250697	et	4	main
ja	doc_170347281012_item	2250706	et	3	main
telefonihelin	doc_170347281012_item	2250710	et	3	main
ka	doc_170347281012_item	2250712	et	3	main
lõunasöök	doc_170347281012_item	2250717	et	3	main
pahandab	doc_170347281012_item	2250721	et	3	main
telesaade	doc_170347281012_item	2250723	et	4	main
kuid	doc_170347281012_item	2250726	et	4	main
telefonihelin	doc_170347281012_item	2250727	et	3	main
katkestab	doc_170347281012_item	2250728	et	3	main
pühapäeva	doc_170347281012_item	2250730	et	4	main
varahommiku	doc_170347281012_item	2250731	et	3	main
söömist	doc_170347281012_item	2250737	et	4	main
iv	doc_170347281012_item	2250743	et	4	main
pange	doc_170347281012_item	2250744	et	4	main
sulgudes	doc_170347281012_item	2250745	et	4	main
1	doc_170347281012_item	2250750	et	2	main
nad	doc_170347281012_item	2250760	et	3	main
ja	doc_170347281012_item	2250764	et	3	main
nõuetega	doc_170347281012_item	2250772	et	4	main
selles	doc_170347281012_item	2250813	et	4	main
küsimus	doc_170347281012_item	2250822	et	4	main
peab	doc_170347281012_item	2250836	et	4	main
hoiduma	doc_170347281012_item	2250837	et	3	main
külmetamine	doc_170347281012_item	2250838	et	4	main
suvise	doc_170347281012_item	2250846	et	4	main
üle	doc_170347281012_item	2250848	et	3	main
v	doc_170347281012_item	2250849	et	4	main
2	doc_170347281012_item	2250862	et	2	main
kui	doc_170347281012_item	2250867	et	3	main
siis	doc_170347281012_item	2250900	et	3	main
suitsetada	doc_170347281012_item	2250908	et	3	main
nad	doc_170347281012_item	2250913	et	3	main
kuid	doc_170347281012_item	2250917	et	4	main
inimest	doc_170347281012_item	2250529	et	3	main
kõigega	doc_170347281012_item	2250533	et	3	main
raamatutest	doc_170347281012_item	2250541	et	4	main
eestist	doc_170347281012_item	2250545	et	3	main
karda	doc_170347281012_item	2250553	et	4	main
toodi	doc_170347281012_item	2250557	et	4	main
veel	doc_170347281012_item	2250562	et	4	main
soojad	doc_170347281012_item	2250564	et	3	main
jahe	doc_170347281012_item	2250568	et	3	main
harjutan	doc_170347281012_item	2250570	et	3	main
vaja	doc_170347281012_item	2250578	et	4	main
ostan	doc_170347281012_item	2250579	et	3	main
külapood	doc_170347281012_item	2250580	et	3	main
külapoest	doc_170347281012_item	2250581	et	4	main
vildid	doc_170347281012_item	2250582	et	4	main
ega	doc_170347281012_item	2250583	et	3	main
seal	doc_170347281012_item	2250584	et	4	main
suurt	doc_170347281012_item	2250585	et	3	main
ei	doc_170347281012_item	2250587	et	4	main
müüdagi	doc_170347281012_item	2250588	et	3	main
muud	doc_170347281012_item	2250586	et	4	main
naerab	doc_170347281012_item	2250589	et	3	main
talveks	doc_170347281012_item	2250590	et	4	main
valmistuma	doc_170347281012_item	2250591	et	3	main
valmistuv	doc_170347281012_item	2250592	et	4	main
piret	doc_170347281012_item	2250593	et	4	main
vapralt	doc_170347281012_item	2250594	et	4	main
lühendatud	doc_170347281012_item	2250595	et	4	main
ajalehest	doc_170347281012_item	2250596	et	4	main
iii	doc_170347281012_item	2250598	et	4	main
moodustage	doc_170347281012_item	2250599	et	3	main
slõhtuleht	doc_170347281012_item	2250597	et	4	main
etteantud	doc_170347281012_item	2250600	et	4	main
sõnadest	doc_170347281012_item	2250601	et	3	main
laused	doc_170347281012_item	2250602	et	3	main
pannes	doc_170347281012_item	2250603	et	4	main
sõnad	doc_170347281012_item	2250604	et	4	main
õigesse	doc_170347281012_item	2250605	et	3	main
kasutades	doc_170347281012_item	2250608	et	3	main
naeratus	doc_170347281012_item	2250611	et	4	main
tegema	doc_170347281012_item	2250612	et	3	main
mehelikum	doc_170347281012_item	2250617	et	4	main
naeratus	doc_170347281012_item	2250620	et	4	main
naisi	doc_170347281012_item	2250622	et	3	main
4	doc_170347281012_item	2250656	et	2	main
laskma	doc_170347281012_item	2250659	et	3	main
saama	doc_170347281012_item	2250663	et	4	main
maandama	doc_170347281012_item	2250664	et	3	main
tohi	doc_170347281012_item	2250669	et	4	main
lasta	doc_170347281012_item	2250670	et	4	main
tekkimist	doc_170347281012_item	2250672	et	4	main
saab	doc_170347281012_item	2250674	et	3	main
ja	doc_170347281012_item	2250677	et	3	main
5	doc_170347281012_item	2250679	et	2	main
saama	doc_170347281012_item	2250683	et	4	main
nii	doc_170347281012_item	2250684	et	3	main
telefon	doc_170347281012_item	2250694	et	3	main
kuid	doc_170347281012_item	2250709	et	4	main
katkestama	doc_170347281012_item	2250711	et	3	main
valmistamine	doc_170347281012_item	2250718	et	4	main
aeg	doc_170347281012_item	2250725	et	3	main
naiselikumaks	doc_170347281012_item	2250623	et	4	main
mehelikumaks	doc_170347281012_item	2250626	et	4	main
stressi	doc_170347281012_item	2250644	et	4	main
tegutsema	doc_170347281012_item	2250647	et	3	main
aga	doc_170347281012_item	2250648	et	3	main
lisakoormus	doc_170347281012_item	2250649	et	3	main
võib	doc_170347281012_item	2250650	et	3	main
tuua	doc_170347281012_item	2250651	et	3	main
aga	doc_170347281012_item	2250636	et	3	main
tooma	doc_170347281012_item	2250639	et	3	main
paneb	doc_170347281012_item	2250645	et	3	main
soovimatu	doc_170347281012_item	2250654	et	4	main
ei	doc_170347281012_item	2250657	et	4	main
ülekoormus	doc_170347281012_item	2250660	et	3	main
pinge	doc_170347281012_item	2250662	et	4	main
ja	doc_170347281012_item	2250666	et	3	main
pinget	doc_170347281012_item	2250673	et	3	main
olema	doc_170347281012_item	2250681	et	4	main
abil	doc_170347281012_item	2250689	et	4	main
elama	doc_170347281012_item	2250691	et	3	main
ja	doc_170347281012_item	2250692	et	3	main
tänapäeval	doc_170347281012_item	2250696	et	3	main
maagiliseks	doc_170347281012_item	2250699	et	4	main
et	doc_170347281012_item	2250701	et	3	main
6	doc_170347281012_item	2250708	et	2	main
varahommik	doc_170347281012_item	2250714	et	3	main
lõunasöögi	doc_170347281012_item	2250734	et	3	main
huvitava	doc_170347281012_item	2250739	et	4	main
sõnad	doc_170347281012_item	2250747	et	4	main
ma	doc_170347281012_item	2250751	et	3	main
väga	doc_170347281012_item	2250753	et	3	main
vanemad	doc_170347281012_item	2250756	et	4	main
vanematest	doc_170347281012_item	2250758	et	4	main
sest	doc_170347281012_item	2250759	et	4	main
usaldavad	doc_170347281012_item	2250765	et	4	main
igaüks	doc_170347281012_item	2250766	et	3	main
2	doc_170347281012_item	2250768	et	2	main
artikli	doc_170347281012_item	2250770	et	3	main
3	doc_170347281012_item	2250773	et	2	main
arvasin	doc_170347281012_item	2250775	et	3	main
sport	doc_170347281012_item	2250779	et	3	main
tagajärgi	doc_170347281012_item	2250653	et	4	main
sportima	doc_170347281012_item	2250665	et	4	main
puhkama	doc_170347281012_item	2250667	et	3	main
telefon	doc_170347281012_item	2250680	et	3	main
tänapäev	doc_170347281012_item	2250682	et	3	main
on	doc_170347281012_item	2250695	et	4	main
nii	doc_170347281012_item	2250698	et	3	main
pühapäev	doc_170347281012_item	2250713	et	3	main
segama	doc_170347281012_item	2250716	et	3	main
söömine	doc_170347281012_item	2250720	et	4	main
huvitav	doc_170347281012_item	2250722	et	4	main
ka	doc_170347281012_item	2250729	et	3	main
und	doc_170347281012_item	2250732	et	4	main
telesaate	doc_170347281012_item	2250740	et	3	main
olevad	doc_170347281012_item	2250746	et	4	main
lugu	doc_170347281012_item	2250754	et	4	main
kõiki	doc_170347281012_item	2250763	et	4	main
nõuded	doc_170347281012_item	2250771	et	3	main
ma	doc_170347281012_item	2250774	et	3	main
et	doc_170347281012_item	2250776	et	3	main
piirdusime	doc_170347281012_item	2250812	et	3	main
küsimuses	doc_170347281012_item	2250814	et	4	main
see	doc_170347281012_item	2250821	et	3	main
teine	doc_170347281012_item	2250824	et	3	main
kleepus	doc_170347281012_item	2250830	et	3	main
pükstesse	doc_170347281012_item	2250832	et	3	main
külmal	doc_170347281012_item	2250834	et	3	main
rõõmu	doc_170347281012_item	2250843	et	4	main
päikese	doc_170347281012_item	2250847	et	4	main
täitke	doc_170347281012_item	2250850	et	3	main
lüngad	doc_170347281012_item	2250851	et	3	main
1	doc_170347281012_item	2250854	et	2	main
tellisime	doc_170347281012_item	2250855	et	4	main
lõuna	doc_170347281012_item	2250857	et	4	main
kuigi	doc_170347281012_item	2250858	et	3	main
see	doc_170347281012_item	2250859	et	3	main
palju	doc_170347281012_item	2250861	et	4	main
vaid	doc_170347281012_item	2250893	et	3	main
teatrisse	doc_170347281012_item	2250896	et	3	main
ei	doc_170347281012_item	2250906	et	4	main
ega	doc_170347281012_item	2250909	et	3	main
8	doc_170347281012_item	2250912	et	2	main
tulemust	doc_170347281012_item	2250918	et	4	main
olnud	doc_170347281012_item	2250920	et	4	main
kas	doc_170347281012_item	2250922	et	3	main
sõidad	doc_170347281012_item	2250924	et	3	main
avasin	doc_170347281012_item	2250930	et	3	main
eksamitöö	doc_170347281013_item	2250935	et	4	main
vormi	doc_170347281013_item	2250942	et	4	main
ettevõtlik	doc_170347281013_item	2250946	et	3	main
nägema	doc_170347281013_item	2250949	et	3	main
kuulutus	doc_170347281013_item	2250953	et	4	main
külasse	doc_170347281013_item	2250959	et	3	main
otsitakse	doc_170347281013_item	2250960	et	3	main
keele	doc_170347281013_item	2250962	et	4	main
juba	doc_170347281013_item	2250971	et	3	main
väikestele	doc_170347281013_item	2250975	et	4	main
emakeelt	doc_170347281013_item	2250979	et	4	main
ta	doc_170347281013_item	2250985	et	4	main
jõudes	doc_170347281013_item	2250988	et	3	main
üllatuma	doc_170347281013_item	2250994	et	3	main
pilt	doc_170347281013_item	2251009	et	3	main
lenda	doc_170347281013_item	2251014	et	4	main
valmistamist	doc_170347281012_item	2250735	et	4	main
aega	doc_170347281012_item	2250742	et	4	main
õigesse	doc_170347281012_item	2250748	et	3	main
pean	doc_170347281012_item	2250752	et	4	main
oma	doc_170347281012_item	2250757	et	4	main
kõik	doc_170347281012_item	2250762	et	4	main
igaüht	doc_170347281012_item	2250767	et	3	main
kohandasin	doc_170347281012_item	2250769	et	3	main
huvitud	doc_170347281012_item	2250778	et	4	main
spordist	doc_170347281012_item	2250780	et	3	main
aga	doc_170347281012_item	2250781	et	3	main
sa	doc_170347281012_item	2250782	et	3	main
tunned	doc_170347281012_item	2250783	et	3	main
huvi	doc_170347281012_item	2250784	et	4	main
ilusad	doc_170347281012_item	2250786	et	3	main
naised	doc_170347281012_item	2250787	et	3	main
ja	doc_170347281012_item	2250788	et	3	main
kiired	doc_170347281012_item	2250789	et	4	main
autod	doc_170347281012_item	2250790	et	3	main
ainult	doc_170347281012_item	2250785	et	4	main
ilusate	doc_170347281012_item	2250791	et	3	main
naiste	doc_170347281012_item	2250792	et	3	main
ja	doc_170347281012_item	2250793	et	3	main
kiirte	doc_170347281012_item	2250794	et	3	main
autode	doc_170347281012_item	2250795	et	3	main
vastu	doc_170347281012_item	2250796	et	3	main
4	doc_170347281012_item	2250797	et	2	main
praegu	doc_170347281012_item	2250798	et	3	main
on	doc_170347281012_item	2250799	et	4	main
oht	doc_170347281012_item	2250800	et	3	main
haigestuda	doc_170347281012_item	2250801	et	3	main
difteeria	doc_170347281012_item	2250802	et	4	main
difteeriasse	doc_170347281012_item	2250803	et	3	main
5	doc_170347281012_item	2250804	et	2	main
tüdinesin	doc_170347281012_item	2250805	et	3	main
uus	doc_170347281012_item	2250806	et	3	main
töökoht	doc_170347281012_item	2250807	et	3	main
uuest	doc_170347281012_item	2250808	et	3	main
töökohast	doc_170347281012_item	2250809	et	4	main
kiiresti	doc_170347281012_item	2250810	et	3	main
6	doc_170347281012_item	2250811	et	2	main
vaatamine	doc_170347281012_item	2250724	et	4	main
segab	doc_170347281012_item	2250733	et	3	main
ja	doc_170347281012_item	2250736	et	3	main
pahandab	doc_170347281012_item	2250738	et	3	main
vaatamise	doc_170347281012_item	2250741	et	4	main
vormi	doc_170347281012_item	2250749	et	4	main
oma	doc_170347281012_item	2250755	et	4	main
aitavad	doc_170347281012_item	2250761	et	4	main
sa	doc_170347281012_item	2250777	et	3	main
vaid	doc_170347281012_item	2250815	et	3	main
väikesed	doc_170347281012_item	2250816	et	4	main
muudatused	doc_170347281012_item	2250817	et	3	main
väikeste	doc_170347281012_item	2250818	et	4	main
muudatustega	doc_170347281012_item	2250819	et	3	main
valdkond	doc_170347281012_item	2250825	et	3	main
valdkonda	doc_170347281012_item	2250827	et	4	main
püksid	doc_170347281012_item	2250831	et	3	main
ajal	doc_170347281012_item	2250835	et	4	main
sobivate	doc_170347281012_item	2250852	et	4	main
sidenditega	doc_170347281012_item	2250853	et	3	main
olid	doc_170347281012_item	2250864	et	4	main
õpilased	doc_170347281012_item	2250866	et	3	main
õpetajad	doc_170347281012_item	2250869	et	4	main
läheb	doc_170347281012_item	2250894	et	3	main
lõpetage	doc_170347281012_item	2250898	et	3	main
lähete	doc_170347281012_item	2250901	et	4	main
alkoholi	doc_170347281012_item	2250910	et	4	main
töötasid	doc_170347281012_item	2250914	et	4	main
küll	doc_170347281012_item	2250915	et	4	main
pingsalt	doc_170347281012_item	2250916	et	4	main
9	doc_170347281012_item	2250921	et	2	main
või	doc_170347281012_item	2250926	et	4	main
kuulsin	doc_170347281012_item	2250933	et	3	main
olevad	doc_170347281013_item	2250939	et	4	main
piret	doc_170347281013_item	2250943	et	4	main
küla	doc_170347281013_item	2250958	et	4	main
konkurss	doc_170347281013_item	2250966	et	3	main
konkurssi	doc_170347281013_item	2250967	et	4	main
nädalat	doc_170347281013_item	2250974	et	3	main
kinnitusel	doc_170347281013_item	2250983	et	4	main
siberisse	doc_170347281013_item	2250986	et	4	main
oodatud	doc_170347281013_item	2250991	et	4	main
tulema	doc_170347281013_item	2250998	et	4	main
tullakse	doc_170347281013_item	2250999	et	3	main
siberist	doc_170347281013_item	2251007	et	4	main
et	doc_170347281013_item	2251010	et	3	main
ei	doc_170347281013_item	2251012	et	4	main
lendama	doc_170347281013_item	2251013	et	3	main
kasva	doc_170347281013_item	2251017	et	4	main
piret	doc_170347281013_item	2251025	et	4	main
koht	doc_170347281013_item	2251029	et	3	main
jõudis	doc_170347281013_item	2251031	et	3	main
kool	doc_170347281013_item	2251033	et	4	main
algama	doc_170347281013_item	2251035	et	3	main
kartuleid	doc_170347281013_item	2251041	et	3	main
sügisel	doc_170347281013_item	2251045	et	3	main
tähtis	doc_170347281013_item	2251047	et	4	main
tähtsam	doc_170347281013_item	2251048	et	4	main
ettevõtmine	doc_170347281013_item	2251049	et	3	main
eestlased	doc_170347281013_item	2251062	et	3	main
räägivad	doc_170347281013_item	2251063	et	3	main
teistmoodi	doc_170347281013_item	2251065	et	3	main
ja	doc_170347281013_item	2251067	et	3	main
mõnusamalt	doc_170347281013_item	2251069	et	4	main
ja	doc_170347281013_item	2251070	et	3	main
mõnd	doc_170347281013_item	2251079	et	3	main
kool	doc_170347281013_item	2251085	et	4	main
aineid	doc_170347281013_item	2251089	et	3	main
õpivad	doc_170347281013_item	2251108	et	3	main
poolpõlenud	doc_170347281013_item	2251110	et	4	main
raamatutega	doc_170347281013_item	2251112	et	3	main
mulle	doc_170347281013_item	2251125	et	4	main
tooma	doc_170347281013_item	2251127	et	3	main
praegu	doc_170347281013_item	2251129	et	3	main
päevad	doc_170347281013_item	2251131	et	3	main
soojad	doc_170347281013_item	2251134	et	3	main
jahe	doc_170347281013_item	2251138	et	3	main
vene	doc_170347281013_item	2251143	et	4	main
kui	doc_170347281013_item	2251147	et	3	main
seal	doc_170347281013_item	2251154	et	4	main
valmistuma	doc_170347281013_item	2251161	et	3	main
7	doc_170347281012_item	2250820	et	2	main
8	doc_170347281012_item	2250828	et	2	main
külmetamist	doc_170347281012_item	2250839	et	4	main
ma	doc_170347281012_item	2250841	et	3	main
suvine	doc_170347281012_item	2250844	et	4	main
maksis	doc_170347281012_item	2250860	et	4	main
nii	doc_170347281012_item	2250865	et	3	main
ka	doc_170347281012_item	2250868	et	3	main
hoopis	doc_170347281012_item	2250895	et	3	main
6	doc_170347281012_item	2250897	et	2	main
7	doc_170347281012_item	2250903	et	2	main
tarbida	doc_170347281012_item	2250911	et	3	main
jääd	doc_170347281012_item	2250927	et	4	main
koputust	doc_170347281012_item	2250934	et	4	main
toomet	doc_170347281013_item	2250944	et	4	main
ta	doc_170347281013_item	2250951	et	4	main
eesti	doc_170347281013_item	2250961	et	4	main
võitis	doc_170347281013_item	2250965	et	3	main
on	doc_170347281013_item	2250969	et	4	main
nüüd	doc_170347281013_item	2250970	et	4	main
nädal	doc_170347281013_item	2250973	et	3	main
õpetama	doc_170347281013_item	2250980	et	3	main
õpetab	doc_170347281013_item	2250981	et	3	main
on	doc_170347281013_item	2250990	et	4	main
üsna	doc_170347281013_item	2250993	et	3	main
audiga	doc_170347281013_item	2251003	et	3	main
maaliti	doc_170347281013_item	2251005	et	3	main
selline	doc_170347281013_item	2251008	et	4	main
ega	doc_170347281013_item	2251016	et	3	main
noor	doc_170347281013_item	2251020	et	3	main
täis	doc_170347281013_item	2251024	et	4	main
õppeaasta	doc_170347281013_item	2251027	et	4	main
alanud	doc_170347281013_item	2251036	et	4	main
kartulivõtt	doc_170347281013_item	2251042	et	3	main
siin	doc_170347281013_item	2251044	et	4	main
kõige	doc_170347281013_item	2251046	et	4	main
kartul	doc_170347281013_item	2251052	et	3	main
hooga	doc_170347281013_item	2251060	et	3	main
mahlakamalt	doc_170347281013_item	2251071	et	4	main
aktsendiga	doc_170347281013_item	2251075	et	3	main
nagu	doc_170347281013_item	2251077	et	3	main
murret	doc_170347281013_item	2251080	et	4	main
ülejäänud	doc_170347281013_item	2251087	et	4	main
õpetatakse	doc_170347281013_item	2251090	et	3	main
emakeelt	doc_170347281013_item	2251101	et	4	main
kõik	doc_170347281013_item	2251103	et	4	main
uued	doc_170347281013_item	2251117	et	3	main
siberi	doc_170347281013_item	2251119	et	4	main
talve	doc_170347281013_item	2251120	et	4	main
veel	doc_170347281013_item	2251132	et	4	main
jahedad	doc_170347281013_item	2251139	et	3	main
ahju	doc_170347281013_item	2251144	et	4	main
vaja	doc_170347281013_item	2251148	et	4	main
muud	doc_170347281013_item	2251156	et	4	main
kaunim	doc_170347281013_item	2251189	et	4	main
teeb	doc_170347281013_item	2251191	et	3	main
kaunimaks	doc_170347281013_item	2251198	et	4	main
tagajärg	doc_170347281013_item	2251211	et	3	main
meid	doc_170347281013_item	2251216	et	4	main
laskma	doc_170347281013_item	2251227	et	3	main
tekkima	doc_170347281013_item	2251229	et	3	main
saama	doc_170347281013_item	2251231	et	4	main
pinget	doc_170347281013_item	2251241	et	3	main
maandada	doc_170347281013_item	2251243	et	3	main
tänapäev	doc_170347281013_item	2251250	et	3	main
nii	doc_170347281013_item	2251252	et	3	main
et	doc_170347281013_item	2251255	et	3	main
hingatakse	doc_170347281013_item	2251275	et	3	main
segama	doc_170347281013_item	2251284	et	3	main
ja	doc_170347281013_item	2251287	et	3	main
vaatamine	doc_170347281013_item	2251292	et	4	main
katkestab	doc_170347281013_item	2251296	et	3	main
und	doc_170347281013_item	2251300	et	4	main
pahandab	doc_170347281013_item	2251306	et	3	main
huvitava	doc_170347281013_item	2251307	et	4	main
vaatamise	doc_170347281013_item	2251309	et	4	main
pange	doc_170347281013_item	2251312	et	4	main
sulgudes	doc_170347281013_item	2251313	et	4	main
kuulub	doc_170347281012_item	2250823	et	3	main
teisse	doc_170347281012_item	2250826	et	4	main
närimiskumm	doc_170347281012_item	2250829	et	3	main
9	doc_170347281012_item	2250833	et	2	main
10	doc_170347281012_item	2250840	et	2	main
tunnen	doc_170347281012_item	2250842	et	3	main
päike	doc_170347281012_item	2250845	et	3	main
kolmekäigulise	doc_170347281012_item	2250856	et	4	main
kohal	doc_170347281012_item	2250863	et	4	main
lapsel	doc_170347281012_item	2250871	et	4	main
paluti	doc_170347281012_item	2250872	et	3	main
3	doc_170347281012_item	2250870	et	2	main
oodata	doc_170347281012_item	2250873	et	4	main
kuni	doc_170347281012_item	2250874	et	3	main
vanemad	doc_170347281012_item	2250875	et	4	main
tulevad	doc_170347281012_item	2250877	et	4	main
4	doc_170347281012_item	2250878	et	2	main
tagasi	doc_170347281012_item	2250876	et	3	main
kõrvallauast	doc_170347281012_item	2250879	et	4	main
kostis	doc_170347281012_item	2250880	et	4	main
naeru	doc_170347281012_item	2250881	et	4	main
nagu	doc_170347281012_item	2250882	et	3	main
oleks	doc_170347281012_item	2250883	et	3	main
keegi	doc_170347281012_item	2250884	et	4	main
just	doc_170347281012_item	2250885	et	3	main
anekdooti	doc_170347281012_item	2250886	et	4	main
rääkinud	doc_170347281012_item	2250887	et	4	main
5	doc_170347281012_item	2250888	et	2	main
ta	doc_170347281012_item	2250889	et	4	main
ei	doc_170347281012_item	2250890	et	4	main
trenni	doc_170347281012_item	2250892	et	4	main
tule	doc_170347281012_item	2250891	et	4	main
töö	doc_170347281012_item	2250899	et	4	main
jalutama	doc_170347281012_item	2250902	et	3	main
selles	doc_170347281012_item	2250904	et	4	main
baaris	doc_170347281012_item	2250905	et	3	main
tohi	doc_170347281012_item	2250907	et	4	main
ei	doc_170347281012_item	2250919	et	4	main
linna	doc_170347281012_item	2250928	et	4	main
ukse	doc_170347281012_item	2250931	et	3	main
pange	doc_170347281013_item	2250937	et	4	main
on	doc_170347281013_item	2250945	et	4	main
nägi	doc_170347281013_item	2250950	et	3	main
ajalehes	doc_170347281013_item	2250952	et	3	main
kuulutust	doc_170347281013_item	2250954	et	4	main
siberisse	doc_170347281013_item	2250956	et	4	main
ülem-suetuki	doc_170347281013_item	2250957	et	4	main
piret	doc_170347281013_item	2250964	et	4	main
ja	doc_170347281013_item	2250968	et	3	main
üle	doc_170347281013_item	2250972	et	3	main
nende	doc_170347281013_item	2250978	et	4	main
pireti	doc_170347281013_item	2250982	et	4	main
jõudma	doc_170347281013_item	2250987	et	3	main
olin	doc_170347281013_item	2250992	et	3	main
mulle	doc_170347281013_item	2250997	et	4	main
mulle	doc_170347281013_item	2251004	et	4	main
seal	doc_170347281013_item	2251011	et	4	main
rohi	doc_170347281013_item	2251018	et	4	main
kui	doc_170347281013_item	2251019	et	3	main
tahtmise	doc_170347281013_item	2251023	et	4	main
kogu	doc_170347281013_item	2251037	et	4	main
küla	doc_170347281013_item	2251038	et	4	main
võtma	doc_170347281013_item	2251039	et	3	main
ja	doc_170347281013_item	2251055	et	3	main
siinsed	doc_170347281013_item	2251061	et	3	main
kuidagi	doc_170347281013_item	2251064	et	3	main
vene	doc_170347281013_item	2251073	et	4	main
kool	doc_170347281013_item	2251081	et	4	main
ja	doc_170347281013_item	2251086	et	3	main
keeles	doc_170347281013_item	2251092	et	4	main
külas	doc_170347281013_item	2251093	et	3	main
elab	doc_170347281013_item	2251094	et	3	main
veidi	doc_170347281013_item	2251095	et	3	main
üle	doc_170347281013_item	2251096	et	3	main
kolmesaja	doc_170347281013_item	2251098	et	4	main
inimene	doc_170347281013_item	2251099	et	3	main
inimest	doc_170347281013_item	2251100	et	3	main
raamatud	doc_170347281013_item	2251111	et	4	main
varsti	doc_170347281013_item	2251113	et	3	main
piret	doc_170347281013_item	2251121	et	4	main
kartma	doc_170347281013_item	2251123	et	3	main
karda	doc_170347281013_item	2251124	et	4	main
soe	doc_170347281013_item	2251133	et	4	main
harjutan	doc_170347281013_item	2251140	et	3	main
kütmine	doc_170347281013_item	2251145	et	4	main
suurt	doc_170347281013_item	2251155	et	3	main
müüdagi	doc_170347281013_item	2251158	et	3	main
naerab	doc_170347281013_item	2251159	et	3	main
naeratus	doc_170347281013_item	2251181	et	4	main
naised	doc_170347281013_item	2251183	et	3	main
ja	doc_170347281013_item	2251185	et	3	main
mehelikum	doc_170347281013_item	2251187	et	4	main
igaühe	doc_170347281013_item	2251197	et	4	main
paras	doc_170347281013_item	2251200	et	3	main
stress	doc_170347281013_item	2251202	et	3	main
tohtima	doc_170347281013_item	2251226	et	3	main
ja	doc_170347281013_item	2251234	et	3	main
puhkama	doc_170347281013_item	2251235	et	3	main
saab	doc_170347281013_item	2251242	et	3	main
sportida	doc_170347281013_item	2251244	et	4	main
saama	doc_170347281013_item	2251251	et	4	main
maagiline	doc_170347281013_item	2251253	et	4	main
abil	doc_170347281013_item	2251271	et	4	main
6	doc_170347281013_item	2251276	et	2	main
uni	doc_170347281013_item	2251283	et	3	main
ka	doc_170347281013_item	2251297	et	3	main
varahommiku	doc_170347281013_item	2251299	et	3	main
lõunasööki	doc_170347281013_item	2251302	et	4	main
sõnad	doc_170347281013_item	2251315	et	4	main
õigesse	doc_170347281013_item	2251316	et	3	main
1	doc_170347281013_item	2251318	et	2	main
vanemad	doc_170347281013_item	2251324	et	4	main
vanemaid	doc_170347281013_item	2251326	et	4	main
sa	doc_170347281012_item	2250923	et	3	main
maale	doc_170347281012_item	2250925	et	4	main
10	doc_170347281012_item	2250929	et	2	main
kui	doc_170347281012_item	2250932	et	3	main
i	doc_170347281013_item	2250936	et	4	main
sulgudes	doc_170347281013_item	2250938	et	4	main
sõnad	doc_170347281013_item	2250940	et	4	main
õigesse	doc_170347281013_item	2250941	et	3	main
naine	doc_170347281013_item	2250947	et	3	main
suvel	doc_170347281013_item	2250948	et	3	main
et	doc_170347281013_item	2250955	et	3	main
õpetajat	doc_170347281013_item	2250963	et	4	main
eestlastele	doc_170347281013_item	2250976	et	4	main
need	doc_170347281013_item	2250977	et	3	main
tundis	doc_170347281013_item	2250984	et	3	main
et	doc_170347281013_item	2250989	et	3	main
üllatunud	doc_170347281013_item	2250995	et	4	main
kui	doc_170347281013_item	2250996	et	3	main
vastu	doc_170347281013_item	2251000	et	3	main
korralik	doc_170347281013_item	2251001	et	3	main
korraliku	doc_170347281013_item	2251002	et	3	main
siber	doc_170347281013_item	2251006	et	4	main
lind	doc_170347281013_item	2251015	et	3	main
ja	doc_170347281013_item	2251021	et	3	main
kohale	doc_170347281013_item	2251030	et	4	main
polnud	doc_170347281013_item	2251032	et	3	main
veel	doc_170347281013_item	2251034	et	4	main
võttis	doc_170347281013_item	2251040	et	3	main
on	doc_170347281013_item	2251051	et	4	main
salves	doc_170347281013_item	2251054	et	4	main
õppimine	doc_170347281013_item	2251056	et	4	main
täie	doc_170347281013_item	2251058	et	3	main
mahlakas	doc_170347281013_item	2251068	et	4	main
vaid	doc_170347281013_item	2251076	et	3	main
on	doc_170347281013_item	2251082	et	4	main
venemaa	doc_170347281013_item	2251084	et	4	main
aine	doc_170347281013_item	2251088	et	4	main
pireti	doc_170347281013_item	2251106	et	4	main
saatma	doc_170347281013_item	2251114	et	3	main
eestist	doc_170347281013_item	2251116	et	3	main
õpikud	doc_170347281013_item	2251118	et	3	main
tahtmine	doc_170347281013_item	2251022	et	4	main
pärast	doc_170347281013_item	2251026	et	4	main
algust	doc_170347281013_item	2251028	et	4	main
on	doc_170347281013_item	2251043	et	4	main
tänaseks	doc_170347281013_item	2251050	et	4	main
salv	doc_170347281013_item	2251053	et	3	main
käib	doc_170347281013_item	2251057	et	3	main
hoog	doc_170347281013_item	2251059	et	3	main
mõnus	doc_170347281013_item	2251066	et	4	main
mitte	doc_170347281013_item	2251072	et	3	main
aktsent	doc_170347281013_item	2251074	et	3	main
mõni	doc_170347281013_item	2251078	et	3	main
siiski	doc_170347281013_item	2251083	et	4	main
vene	doc_170347281013_item	2251091	et	4	main
kolmsada	doc_170347281013_item	2251097	et	4	main
saab	doc_170347281013_item	2251102	et	3	main
kõikidega	doc_170347281013_item	2251104	et	4	main
rääkida	doc_170347281013_item	2251105	et	3	main
sõnul	doc_170347281013_item	2251107	et	3	main
lapsed	doc_170347281013_item	2251109	et	3	main
saadakse	doc_170347281013_item	2251115	et	3	main
ei	doc_170347281013_item	2251122	et	4	main
on	doc_170347281013_item	2251130	et	4	main
ööd	doc_170347281013_item	2251136	et	4	main
juba	doc_170347281013_item	2251141	et	3	main
kütmist	doc_170347281013_item	2251146	et	4	main
külapood	doc_170347281013_item	2251150	et	3	main
külapoest	doc_170347281013_item	2251151	et	4	main
ega	doc_170347281013_item	2251153	et	3	main
valmistunud	doc_170347281013_item	2251162	et	4	main
ja	doc_170347281013_item	2251177	et	3	main
2	doc_170347281013_item	2251180	et	2	main
tegema	doc_170347281013_item	2251182	et	3	main
naisi	doc_170347281013_item	2251192	et	3	main
mehi	doc_170347281013_item	2251195	et	3	main
3	doc_170347281013_item	2251199	et	2	main
kogus	doc_170347281013_item	2251201	et	4	main
panema	doc_170347281013_item	2251203	et	3	main
tegutsema	doc_170347281013_item	2251205	et	3	main
võima	doc_170347281013_item	2251208	et	3	main
soovimatu	doc_170347281013_item	2251210	et	4	main
paras	doc_170347281013_item	2251212	et	3	main
stress	doc_170347281013_item	2251214	et	3	main
paneb	doc_170347281013_item	2251215	et	3	main
tegutsema	doc_170347281013_item	2251217	et	3	main
lisakoormus	doc_170347281013_item	2251219	et	3	main
juba	doc_170347281013_item	2251126	et	3	main
talvepuud	doc_170347281013_item	2251128	et	4	main
kuid	doc_170347281013_item	2251135	et	4	main
juba	doc_170347281013_item	2251137	et	3	main
suure	doc_170347281013_item	2251142	et	3	main
ostan	doc_170347281013_item	2251149	et	3	main
vildid	doc_170347281013_item	2251152	et	4	main
ei	doc_170347281013_item	2251157	et	4	main
talveks	doc_170347281013_item	2251160	et	4	main
piret	doc_170347281013_item	2251163	et	4	main
lühendatud	doc_170347281013_item	2251165	et	4	main
ajalehest	doc_170347281013_item	2251166	et	4	main
vapralt	doc_170347281013_item	2251164	et	4	main
slõhtuleht	doc_170347281013_item	2251167	et	4	main
iii	doc_170347281013_item	2251168	et	4	main
moodustage	doc_170347281013_item	2251169	et	3	main
etteantud	doc_170347281013_item	2251170	et	4	main
sõnadest	doc_170347281013_item	2251171	et	3	main
laused	doc_170347281013_item	2251172	et	3	main
pannes	doc_170347281013_item	2251173	et	4	main
sõnad	doc_170347281013_item	2251174	et	4	main
õigesse	doc_170347281013_item	2251175	et	3	main
vormi	doc_170347281013_item	2251176	et	4	main
kasutades	doc_170347281013_item	2251178	et	3	main
igaüks	doc_170347281013_item	2251188	et	3	main
naeratus	doc_170347281013_item	2251190	et	4	main
ja	doc_170347281013_item	2251194	et	3	main
aga	doc_170347281013_item	2251206	et	3	main
tooma	doc_170347281013_item	2251209	et	3	main
kogus	doc_170347281013_item	2251213	et	4	main
aga	doc_170347281013_item	2251218	et	3	main
võib	doc_170347281013_item	2251220	et	3	main
soovimatu	doc_170347281013_item	2251222	et	4	main
tagajärgi	doc_170347281013_item	2251223	et	4	main
sportima	doc_170347281013_item	2251233	et	4	main
ei	doc_170347281013_item	2251236	et	4	main
lasta	doc_170347281013_item	2251238	et	4	main
ülekoormust	doc_170347281013_item	2251239	et	4	main
tekitada	doc_170347281013_item	2251240	et	3	main
5	doc_170347281013_item	2251247	et	2	main
telefon	doc_170347281013_item	2251248	et	3	main
lausa	doc_170347281013_item	2251272	et	4	main
kuid	doc_170347281013_item	2251277	et	4	main
katkestama	doc_170347281013_item	2251279	et	3	main
pühapäev	doc_170347281013_item	2251281	et	3	main
lõunasöök	doc_170347281013_item	2251285	et	3	main
söömine	doc_170347281013_item	2251288	et	4	main
huvitav	doc_170347281013_item	2251290	et	4	main
ja	doc_170347281013_item	2251304	et	3	main
pean	doc_170347281013_item	2251320	et	4	main
lugu	doc_170347281013_item	2251322	et	4	main
aitavad	doc_170347281013_item	2251329	et	4	main
igaüks	doc_170347281013_item	2251334	et	3	main
artikli	doc_170347281013_item	2251338	et	3	main
tunned	doc_170347281013_item	2251350	et	3	main
ainult	doc_170347281013_item	2251352	et	4	main
kiired	doc_170347281013_item	2251356	et	4	main
ilusate	doc_170347281013_item	2251358	et	3	main
on	doc_170347281013_item	2251366	et	4	main
tüdinesin	doc_170347281013_item	2251372	et	3	main
selles	doc_170347281013_item	2251380	et	4	main
teine	doc_170347281013_item	2251391	et	3	main
pükstes	doc_170347281013_item	2251399	et	3	main
külmetamisest	doc_170347281013_item	2251406	et	4	main
kolmekäigulise	doc_170347281013_item	2251422	et	4	main
õpetajad	doc_170347281013_item	2251435	et	4	main
lapsel	doc_170347281013_item	2251437	et	4	main
oodata	doc_170347281013_item	2251439	et	4	main
naeru	doc_170347281013_item	2251447	et	4	main
rääkinud	doc_170347281013_item	2251453	et	4	main
teatrisse	doc_170347281013_item	2251462	et	3	main
töö	doc_170347281013_item	2251465	et	4	main
lähete	doc_170347281013_item	2251467	et	4	main
9	doc_170347281013_item	2251487	et	2	main
sõidad	doc_170347281013_item	2251490	et	3	main
sest	doc_170347281013_item	2251498	et	4	main
19102005br	doc_171929905767_item	2251510	et	4	main
tungmise	doc_171929905767_item	2251516	et	4	main
tehtud	doc_171929905767_item	2251521	et	4	main
juurdlus	doc_171929905767_item	2251523	et	3	main
ja	doc_171929905767_item	2251524	et	3	main
14	doc_171929905767_item	2251527	et	2	main
kella	doc_171929905767_item	2251529	et	4	main
valvapostil	doc_171929905767_item	2251531	et	4	main
y	doc_171929905767_item	2251535	et	4	main
valvesignalisatsioon	doc_171929905767_item	2251557	et	3	main
juhtunust	doc_171929905767_item	2251601	et	4	main
kordapidaja	doc_171929905767_item	2251602	et	4	main
ole	doc_171929905767_item	2251608	et	4	main
saatnud	doc_171929905767_item	2251609	et	4	main
minuti	doc_171929905767_item	2251612	et	3	main
territoiumi	doc_171929905767_item	2251617	et	4	main
et	doc_171929905767_item	2251620	et	3	main
mantee	doc_171929905767_item	2251621	et	4	main
ole	doc_171929905767_item	2251623	et	4	main
selle	doc_171929905767_item	2251628	et	4	main
mitte	doc_171929905767_item	2251641	et	3	main
saanud	doc_171929905767_item	2251647	et	4	main
pärast	doc_171929905767_item	2251649	et	4	main
sportliku	doc_171929905767_item	2251657	et	3	main
valvur	doc_171929905767_item	2251666	et	3	main
varjas	doc_171929905767_item	2251671	et	4	main
valvur	doc_171929905767_item	2251674	et	3	main
on	doc_171929905767_item	2251690	et	4	main
kirjavahemärke	doc_170347281013_item	2251179	et	4	main
naiselikum	doc_170347281013_item	2251184	et	4	main
mehed	doc_170347281013_item	2251186	et	3	main
naiselikumateks	doc_170347281013_item	2251193	et	4	main
mehelikumateks	doc_170347281013_item	2251196	et	4	main
meie	doc_170347281013_item	2251204	et	4	main
lisakoormus	doc_170347281013_item	2251207	et	3	main
tuua	doc_170347281013_item	2251221	et	3	main
4	doc_170347281013_item	2251224	et	2	main
ei	doc_170347281013_item	2251225	et	4	main
ülekoormus	doc_170347281013_item	2251228	et	3	main
pinge	doc_170347281013_item	2251230	et	4	main
tohi	doc_170347281013_item	2251237	et	4	main
ja	doc_170347281013_item	2251245	et	3	main
see	doc_170347281013_item	2251256	et	3	main
elatakse	doc_170347281013_item	2251273	et	3	main
varahommik	doc_170347281013_item	2251282	et	3	main
pahandab	doc_170347281013_item	2251289	et	3	main
kuid	doc_170347281013_item	2251294	et	4	main
valmistamist	doc_170347281013_item	2251303	et	4	main
olevad	doc_170347281013_item	2251314	et	4	main
sest	doc_170347281013_item	2251327	et	4	main
igaüht	doc_170347281013_item	2251335	et	3	main
kohandasin	doc_170347281013_item	2251337	et	3	main
nõudeid	doc_170347281013_item	2251340	et	3	main
ma	doc_170347281013_item	2251342	et	3	main
huvi	doc_170347281013_item	2251351	et	4	main
autode	doc_170347281013_item	2251362	et	3	main
difteeriasse	doc_170347281013_item	2251370	et	3	main
töökoht	doc_170347281013_item	2251374	et	3	main
töökohast	doc_170347281013_item	2251376	et	4	main
küsimuses	doc_170347281013_item	2251381	et	4	main
kuulub	doc_170347281013_item	2251390	et	3	main
8	doc_170347281013_item	2251395	et	2	main
kleepus	doc_170347281013_item	2251397	et	3	main
9	doc_170347281013_item	2251400	et	2	main
hoiduma	doc_170347281013_item	2251404	et	3	main
sest	doc_170347281013_item	2251424	et	4	main
nii	doc_170347281013_item	2251431	et	3	main
3	doc_170347281013_item	2251436	et	2	main
tulevad	doc_170347281013_item	2251443	et	4	main
kostis	doc_170347281013_item	2251446	et	4	main
nagu	doc_170347281013_item	2251448	et	3	main
anekdooti	doc_170347281013_item	2251452	et	4	main
ei	doc_170347281013_item	2251456	et	4	main
trenni	doc_170347281013_item	2251458	et	4	main
või	doc_170347281013_item	2251492	et	4	main
linna	doc_170347281013_item	2251494	et	4	main
ametlik	doc_171929905767_item	2251501	et	3	main
alevik	doc_171929905767_item	2251507	et	3	main
valvataval	doc_171929905767_item	2251511	et	4	main
öösel	doc_171929905767_item	2251513	et	4	main
fakti	doc_171929905767_item	2251517	et	4	main
meiega	doc_171929905767_item	2251519	et	4	main
x	doc_171929905767_item	2251534	et	4	main
ta	doc_171929905767_item	2251536	et	4	main
territoriumi	doc_171929905767_item	2251538	et	4	main
kirjutas	doc_171929905767_item	2251541	et	3	main
päevikus	doc_171929905767_item	2251542	et	3	main
nagu	doc_171929905767_item	2251549	et	3	main
kohaseltbr	doc_171929905767_item	2251551	et	4	main
tulekut	doc_171929905767_item	2251554	et	3	main
valvur	doc_171929905767_item	2251556	et	3	main
paigaltud	doc_171929905767_item	2251558	et	4	main
ringkäik	doc_171929905767_item	2251566	et	3	main
kordapidaja	doc_171929905767_item	2251603	et	4	main
kohale	doc_171929905767_item	2251610	et	4	main
silmestasid	doc_171929905767_item	2251616	et	4	main
pool	doc_171929905767_item	2251622	et	4	main
tara	doc_171929905767_item	2251625	et	4	main
kaudu	doc_171929905767_item	2251630	et	3	main
patruliga	doc_171929905767_item	2251634	et	4	main
asuva	doc_171929905767_item	2251637	et	4	main
territorium	doc_171929905767_item	2251639	et	4	main
vaid	doc_171929905767_item	2251643	et	3	main
avastada	doc_171929905767_item	2251648	et	3	main
valvur	doc_171929905767_item	2251651	et	3	main
kuuritegija	doc_171929905767_item	2251653	et	4	main
pika	doc_171929905767_item	2251655	et	4	main
seisnud	doc_171929905767_item	2251662	et	4	main
lähedal	doc_171929905767_item	2251664	et	4	main
maandama	doc_170347281013_item	2251232	et	3	main
puhata	doc_170347281013_item	2251246	et	4	main
olema	doc_170347281013_item	2251249	et	4	main
aparaat	doc_170347281013_item	2251254	et	3	main
abil	doc_170347281013_item	2251257	et	4	main
lausa	doc_170347281013_item	2251258	et	4	main
elama	doc_170347281013_item	2251259	et	3	main
ja	doc_170347281013_item	2251260	et	3	main
hingama	doc_170347281013_item	2251261	et	3	main
telefon	doc_170347281013_item	2251262	et	3	main
on	doc_170347281013_item	2251263	et	4	main
tänapäeval	doc_170347281013_item	2251264	et	3	main
saanud	doc_170347281013_item	2251265	et	4	main
nii	doc_170347281013_item	2251266	et	3	main
maagiliseks	doc_170347281013_item	2251267	et	4	main
aparaadiks	doc_170347281013_item	2251268	et	3	main
et	doc_170347281013_item	2251269	et	3	main
selle	doc_170347281013_item	2251270	et	4	main
ja	doc_170347281013_item	2251274	et	3	main
telefonihelin	doc_170347281013_item	2251278	et	3	main
ka	doc_170347281013_item	2251280	et	3	main
valmistamine	doc_170347281013_item	2251286	et	4	main
telesaade	doc_170347281013_item	2251291	et	4	main
aeg	doc_170347281013_item	2251293	et	3	main
telefonihelin	doc_170347281013_item	2251295	et	3	main
pühapäeva	doc_170347281013_item	2251298	et	4	main
segab	doc_170347281013_item	2251301	et	3	main
söömist	doc_170347281013_item	2251305	et	4	main
telesaade	doc_170347281013_item	2251308	et	4	main
aega	doc_170347281013_item	2251310	et	4	main
iv	doc_170347281013_item	2251311	et	4	main
vormi	doc_170347281013_item	2251317	et	4	main
ma	doc_170347281013_item	2251319	et	3	main
väga	doc_170347281013_item	2251321	et	3	main
oma	doc_170347281013_item	2251323	et	4	main
nad	doc_170347281013_item	2251328	et	3	main
kõik	doc_170347281013_item	2251330	et	4	main
kõiki	doc_170347281013_item	2251331	et	4	main
ja	doc_170347281013_item	2251332	et	3	main
nõuded	doc_170347281013_item	2251339	et	3	main
huvitud	doc_170347281013_item	2251346	et	4	main
ja	doc_170347281013_item	2251355	et	3	main
autod	doc_170347281013_item	2251357	et	3	main
difteeria	doc_170347281013_item	2251369	et	4	main
uus	doc_170347281013_item	2251373	et	3	main
uuest	doc_170347281013_item	2251375	et	3	main
vaid	doc_170347281013_item	2251382	et	3	main
7	doc_170347281013_item	2251387	et	2	main
küsimus	doc_170347281013_item	2251389	et	4	main
valdkonda	doc_170347281013_item	2251394	et	4	main
närimiskumm	doc_170347281013_item	2251396	et	3	main
püksid	doc_170347281013_item	2251398	et	3	main
külmal	doc_170347281013_item	2251401	et	3	main
oma	doc_170347281013_item	2251325	et	4	main
2	doc_170347281013_item	2251336	et	2	main
et	doc_170347281013_item	2251344	et	3	main
aga	doc_170347281013_item	2251348	et	3	main
ilusad	doc_170347281013_item	2251353	et	3	main
naiste	doc_170347281013_item	2251359	et	3	main
kiirete	doc_170347281013_item	2251361	et	4	main
vastu	doc_170347281013_item	2251363	et	3	main
praegu	doc_170347281013_item	2251365	et	3	main
oht	doc_170347281013_item	2251367	et	3	main
5	doc_170347281013_item	2251371	et	2	main
6	doc_170347281013_item	2251378	et	2	main
väikesed	doc_170347281013_item	2251383	et	4	main
väikeste	doc_170347281013_item	2251385	et	4	main
valdkond	doc_170347281013_item	2251392	et	3	main
teise	doc_170347281013_item	2251393	et	4	main
10	doc_170347281013_item	2251407	et	2	main
külmetamine	doc_170347281013_item	2251405	et	4	main
ma	doc_170347281013_item	2251408	et	3	main
tunnen	doc_170347281013_item	2251409	et	3	main
rõõmu	doc_170347281013_item	2251410	et	4	main
suvine	doc_170347281013_item	2251411	et	4	main
päike	doc_170347281013_item	2251412	et	3	main
suvisest	doc_170347281013_item	2251413	et	4	main
päikesest	doc_170347281013_item	2251414	et	4	main
v	doc_170347281013_item	2251415	et	4	main
täitke	doc_170347281013_item	2251416	et	3	main
lüngad	doc_170347281013_item	2251417	et	3	main
sobivate	doc_170347281013_item	2251418	et	4	main
sidenditega	doc_170347281013_item	2251419	et	3	main
1	doc_170347281013_item	2251420	et	2	main
tellisime	doc_170347281013_item	2251421	et	4	main
lõuna	doc_170347281013_item	2251423	et	4	main
maksis	doc_170347281013_item	2251426	et	4	main
2	doc_170347281013_item	2251428	et	2	main
ka	doc_170347281013_item	2251434	et	3	main
paluti	doc_170347281013_item	2251438	et	3	main
kõrvallauast	doc_170347281013_item	2251445	et	4	main
oleks	doc_170347281013_item	2251449	et	3	main
5	doc_170347281013_item	2251454	et	2	main
läheb	doc_170347281013_item	2251460	et	3	main
maale	doc_170347281013_item	2251491	et	4	main
10	doc_170347281013_item	2251495	et	2	main
koputust	doc_170347281013_item	2251500	et	4	main
kiri	doc_171929905767_item	2251502	et	3	main
n	doc_171929905767_item	2251504	et	4	main
2	doc_171929905767_item	2251505	et	2	main
p	doc_171929905767_item	2251506	et	4	main
i	doc_171929905767_item	2251508	et	4	main
oktoobril	doc_171929905767_item	2251515	et	3	main
järgi	doc_171929905767_item	2251518	et	4	main
oli	doc_171929905767_item	2251520	et	3	main
järgminebr	doc_171929905767_item	2251526	et	4	main
tegi	doc_171929905767_item	2251537	et	4	main
ringkäiku	doc_171929905767_item	2251539	et	4	main
tagantjärale	doc_171929905767_item	2251543	et	4	main
tegi	doc_171929905767_item	2251544	et	4	main
ringkäikuid	doc_171929905767_item	2251546	et	4	main
igal	doc_171929905767_item	2251547	et	3	main
ümbermõõtul	doc_171929905767_item	2251560	et	4	main
järjekorse	doc_171929905767_item	2251565	et	4	main
ja	doc_171929905767_item	2251567	et	3	main
märkinud	doc_171929905767_item	2251569	et	4	main
x	doc_171929905767_item	2251599	et	4	main
teatas	doc_171929905767_item	2251600	et	3	main
objektidele	doc_171929905767_item	2251606	et	3	main
7-10	doc_171929905767_item	2251611	et	2	main
avastasid	doc_171929905767_item	2251619	et	4	main
usaldavad	doc_170347281013_item	2251333	et	4	main
3	doc_170347281013_item	2251341	et	2	main
arvasin	doc_170347281013_item	2251343	et	3	main
sa	doc_170347281013_item	2251345	et	3	main
sport	doc_170347281013_item	2251347	et	3	main
sa	doc_170347281013_item	2251349	et	3	main
naised	doc_170347281013_item	2251354	et	3	main
ja	doc_170347281013_item	2251360	et	3	main
4	doc_170347281013_item	2251364	et	2	main
haigestuda	doc_170347281013_item	2251368	et	3	main
kiiresti	doc_170347281013_item	2251377	et	3	main
piirdusime	doc_170347281013_item	2251379	et	3	main
muudatused	doc_170347281013_item	2251384	et	3	main
muudatustega	doc_170347281013_item	2251386	et	3	main
see	doc_170347281013_item	2251388	et	3	main
ajal	doc_170347281013_item	2251402	et	4	main
peab	doc_170347281013_item	2251403	et	4	main
see	doc_170347281013_item	2251425	et	3	main
palju	doc_170347281013_item	2251427	et	4	main
kohal	doc_170347281013_item	2251429	et	4	main
õpilased	doc_170347281013_item	2251432	et	3	main
4	doc_170347281013_item	2251444	et	2	main
keegi	doc_170347281013_item	2251450	et	4	main
sest	doc_170347281013_item	2251459	et	4	main
hoopis	doc_170347281013_item	2251461	et	3	main
lõpetage	doc_170347281013_item	2251464	et	3	main
kas	doc_170347281013_item	2251488	et	3	main
jääd	doc_170347281013_item	2251493	et	4	main
avasin	doc_170347281013_item	2251496	et	3	main
ukse	doc_170347281013_item	2251497	et	3	main
valdbr	doc_171929905767_item	2251509	et	4	main
olid	doc_170347281013_item	2251430	et	4	main
kui	doc_170347281013_item	2251433	et	3	main
kui	doc_170347281013_item	2251440	et	3	main
vanemad	doc_170347281013_item	2251441	et	4	main
tagasi	doc_170347281013_item	2251442	et	3	main
just	doc_170347281013_item	2251451	et	3	main
ta	doc_170347281013_item	2251455	et	4	main
tule	doc_170347281013_item	2251457	et	4	main
6	doc_170347281013_item	2251463	et	2	main
pärast	doc_170347281013_item	2251466	et	4	main
jalutama	doc_170347281013_item	2251468	et	3	main
7	doc_170347281013_item	2251469	et	2	main
selles	doc_170347281013_item	2251470	et	4	main
baaris	doc_170347281013_item	2251471	et	3	main
ei	doc_170347281013_item	2251472	et	4	main
tohi	doc_170347281013_item	2251473	et	4	main
suitsetada	doc_170347281013_item	2251474	et	3	main
ega	doc_170347281013_item	2251475	et	3	main
alkoholi	doc_170347281013_item	2251476	et	4	main
tarbida	doc_170347281013_item	2251477	et	3	main
8	doc_170347281013_item	2251478	et	2	main
nad	doc_170347281013_item	2251479	et	3	main
töötasid	doc_170347281013_item	2251480	et	4	main
küll	doc_170347281013_item	2251481	et	4	main
pingsalt	doc_170347281013_item	2251482	et	4	main
kuid	doc_170347281013_item	2251483	et	4	main
tulemust	doc_170347281013_item	2251484	et	4	main
ei	doc_170347281013_item	2251485	et	4	main
olnud	doc_170347281013_item	2251486	et	4	main
sa	doc_170347281013_item	2251489	et	3	main
kuulsin	doc_170347281013_item	2251499	et	3	main
as	doc_171929905767_item	2251503	et	4	main
territoriumil	doc_171929905767_item	2251512	et	4	main
14-15	doc_171929905767_item	2251514	et	2	main
ameti	doc_171929905767_item	2251522	et	3	main
oktoobril	doc_171929905767_item	2251528	et	3	main
1700	doc_171929905767_item	2251530	et	2	main
saabus	doc_171929905767_item	2251532	et	3	main
millest	doc_171929905767_item	2251540	et	3	main
tunnil	doc_171929905767_item	2251548	et	3	main
juhandi	doc_171929905767_item	2251550	et	4	main
pärast	doc_171929905767_item	2251552	et	4	main
pidemiku	doc_171929905767_item	2251553	et	3	main
kella	doc_171929905767_item	2251561	et	4	main
tegi	doc_171929905767_item	2251563	et	4	main
valvur	doc_171929905767_item	2251564	et	3	main
ei	doc_171929905767_item	2251568	et	4	main
ta	doc_171929905767_item	2251581	et	4	main
saatis	doc_171929905767_item	2251604	et	3	main
pärast	doc_171929905767_item	2251613	et	4	main
nad	doc_171929905767_item	2251615	et	3	main
ja	doc_171929905767_item	2251618	et	3	main
maha	doc_171929905767_item	2251627	et	4	main
lähedus	doc_171929905767_item	2251636	et	4	main
aga	doc_171929905767_item	2251640	et	3	main
oli	doc_171929905767_item	2251654	et	3	main
kasvu	doc_171929905767_item	2251656	et	4	main
rides	doc_171929905767_item	2251661	et	4	main
ei	doc_171929905767_item	2251667	et	4	main
lisaks	doc_171929905767_item	2251673	et	4	main
palju	doc_171929905767_item	2251679	et	4	main
astus	doc_171929905767_item	2251687	et	3	main
pealebr	doc_171929905767_item	2251689	et	4	main
tara	doc_171929905767_item	2251695	et	4	main
tuvastatud	doc_171929905767_item	2251525	et	4	main
valvur	doc_171929905767_item	2251533	et	3	main
x	doc_171929905767_item	2251545	et	4	main
lülitas	doc_171929905767_item	2251555	et	3	main
tara	doc_171929905767_item	2251559	et	4	main
0200	doc_171929905767_item	2251562	et	2	main
midagi	doc_171929905767_item	2251570	et	4	main
kahtlast	doc_171929905767_item	2251571	et	4	main
kella	doc_171929905767_item	2251572	et	4	main
0210	doc_171929905767_item	2251573	et	2	main
töötas	doc_171929905767_item	2251574	et	3	main
signalisatsioon	doc_171929905767_item	2251575	et	3	main
sellel	doc_171929905767_item	2251576	et	4	main
ajal	doc_171929905767_item	2251577	et	4	main
oli	doc_171929905767_item	2251578	et	3	main
valvur	doc_171929905767_item	2251579	et	3	main
putkas	doc_171929905767_item	2251580	et	4	main
jooksis	doc_171929905767_item	2251582	et	4	main
välja	doc_171929905767_item	2251583	et	4	main
ja	doc_171929905767_item	2251584	et	3	main
nägi	doc_171929905767_item	2251585	et	3	main
tundmatu	doc_171929905767_item	2251586	et	4	main
inimest	doc_171929905767_item	2251587	et	3	main
kes	doc_171929905767_item	2251588	et	4	main
veeretas	doc_171929905767_item	2251589	et	3	main
rohlat	doc_171929905767_item	2251590	et	4	main
tundmatu	doc_171929905767_item	2251591	et	4	main
inimene	doc_171929905767_item	2251592	et	3	main
nägi	doc_171929905767_item	2251593	et	3	main
valvurit	doc_171929905767_item	2251594	et	3	main
viskas	doc_171929905767_item	2251595	et	3	main
rohlat	doc_171929905767_item	2251596	et	4	main
ja	doc_171929905767_item	2251597	et	3	main
varjus	doc_171929905767_item	2251598	et	4	main
patruli	doc_171929905767_item	2251605	et	4	main
missugune	doc_171929905767_item	2251607	et	3	main
koos	doc_171929905767_item	2251614	et	4	main
sektsioon	doc_171929905767_item	2251626	et	3	main
ava	doc_171929905767_item	2251629	et	4	main
varjus	doc_171929905767_item	2251631	et	4	main
valvur	doc_171929905767_item	2251633	et	3	main
silmistas	doc_171929905767_item	2251635	et	4	main
objektile	doc_171929905767_item	2251638	et	3	main
ei	doc_171929905767_item	2251646	et	4	main
et	doc_171929905767_item	2251652	et	3	main
riietud	doc_171929905767_item	2251659	et	3	main
kuhagi	doc_171929905767_item	2251663	et	4	main
ole	doc_171929905767_item	2251668	et	4	main
märkinud	doc_171929905767_item	2251669	et	4	main
ei	doc_171929905767_item	2251675	et	4	main
saanud	doc_171929905767_item	2251676	et	4	main
määletada	doc_171929905767_item	2251677	et	4	main
kui	doc_171929905767_item	2251678	et	3	main
täpselt	doc_171929905767_item	2251680	et	4	main
rohlat	doc_171929905767_item	2251681	et	4	main
oli	doc_171929905767_item	2251682	et	3	main
vahetuse	doc_171929905767_item	2251688	et	4	main
ei	doc_171929905767_item	2251699	et	4	main
vasta	doc_171929905767_item	2251700	et	4	main
turvalisuse	doc_171929905767_item	2251701	et	4	main
nõudele	doc_171929905767_item	2251702	et	4	main
väikese	doc_171929905767_item	2251703	et	4	main
raadiusi	doc_171929905767_item	2251704	et	3	main
tõttu	doc_171929905767_item	2251705	et	4	main
kuni	doc_171929905767_item	2251706	et	3	main
10	doc_171929905767_item	2251707	et	2	main
mbr	doc_171929905767_item	2251708	et	4	main
tara	doc_171929905767_item	2251709	et	4	main
sektsioonid	doc_171929905767_item	2251710	et	3	main
on	doc_171929905767_item	2251711	et	4	main
võtta	doc_171929905767_item	2251713	et	3	main
kiiresti	doc_171929905767_item	2251714	et	3	main
võimalik	doc_171929905767_item	2251712	et	3	main
lahti	doc_171929905767_item	2251715	et	4	main
aga	doc_171929905767_item	2251716	et	3	main
vajatakse	doc_171929905767_item	2251717	et	4	main
spetsiaalset	doc_171929905767_item	2251718	et	3	main
võtti	doc_171929905767_item	2251719	et	4	main
tara	doc_171929905767_item	2251720	et	4	main
oli	doc_171929905767_item	2251722	et	3	main
keskmisel	doc_171929905767_item	2251726	et	3	main
kurjategijale	doc_171929905767_item	2251736	et	3	main
br	doc_171929905767_item	2251744	et	4	main
valvekorda	doc_171929905767_item	2251748	et	4	main
andmise	doc_171929905767_item	2251750	et	4	main
z-le	doc_171929905767_item	2251752	et	3	main
märkis	doc_171929905767_item	2251754	et	3	main
et	doc_171929905767_item	2251756	et	3	main
sellest	doc_171929905767_item	2251762	et	4	main
tara	doc_171929905767_item	2251797	et	4	main
16	doc_171929905767_item	2251806	et	2	main
jooksul	doc_171929905767_item	2251812	et	4	main
kontori	doc_171929905767_item	2251816	et	4	main
kus	doc_171929905767_item	2251818	et	3	main
q	doc_171929905767_item	2251825	et	4	main
saanud	doc_171929905767_item	2251827	et	4	main
nii	doc_171929905767_item	2251834	et	3	main
võtnud	doc_171929905767_item	2251624	et	4	main
tundmatu	doc_171929905767_item	2251632	et	4	main
midagi	doc_171929905767_item	2251642	et	4	main
br	doc_171929905767_item	2251644	et	4	main
kedagi	doc_171929905767_item	2251645	et	4	main
selgitas	doc_171929905767_item	2251650	et	3	main
kehaehitusega	doc_171929905767_item	2251658	et	3	main
tumedas	doc_171929905767_item	2251660	et	3	main
auto	doc_171929905767_item	2251665	et	4	main
tundumatu	doc_171929905767_item	2251670	et	4	main
kontori	doc_171929905767_item	2251683	et	4	main
ta	doc_171929905767_item	2251686	et	4	main
valvesignalisatsioon	doc_171929905767_item	2251694	et	3	main
paigaldadud	doc_171929905767_item	2251697	et	4	main
võtnud	doc_171929905767_item	2251723	et	4	main
järeldust	doc_171929905767_item	2251733	et	4	main
teha	doc_171929905767_item	2251734	et	3	main
15	doc_171929905767_item	2251746	et	2	main
x	doc_171929905767_item	2251755	et	4	main
z	doc_171929905767_item	2251757	et	4	main
pole	doc_171929905767_item	2251758	et	3	main
ja	doc_171929905767_item	2251764	et	3	main
sõitis	doc_171929905767_item	2251766	et	3	main
valvur	doc_171929905767_item	2251792	et	3	main
silmistas	doc_171929905767_item	2251794	et	4	main
tugebdas	doc_171929905767_item	2251796	et	4	main
sõnades	doc_171929905767_item	2251801	et	4	main
x	doc_171929905767_item	2251808	et	4	main
vahetab	doc_171929905767_item	2251809	et	3	main
nad	doc_171929905767_item	2251813	et	3	main
klimaator	doc_171929905767_item	2251821	et	4	main
on	doc_171929905767_item	2251823	et	4	main
ei	doc_171929905767_item	2251826	et	4	main
täpselt	doc_171929905767_item	2251828	et	4	main
öelda	doc_171929905767_item	2251829	et	4	main
kas	doc_171929905767_item	2251830	et	3	main
tema	doc_171929905767_item	2251839	et	4	main
juhtimina	doc_171929905767_item	2251846	et	4	main
oli	doc_171929905767_item	2251847	et	3	main
edaspidi	doc_171929905767_item	2251852	et	3	main
juhtumit	doc_171929905767_item	2251855	et	3	main
ou	doc_171929905767_item	2251862	et	4	main
kultuuriloost	doc_171929905768_item	2251867	et	4	main
ühiskonna	doc_171929905768_item	2251872	et	4	main
rahvuslikud	doc_171929905768_item	2251896	et	3	main
hakkasid	doc_171929905768_item	2251901	et	4	main
eestis	doc_171929905768_item	2251905	et	3	main
madalaks	doc_171929905768_item	2251918	et	3	main
rahumeelsete	doc_171929905768_item	2251920	et	3	main
tulistamist	doc_171929905768_item	2251922	et	4	main
demokraatlikke	doc_171929905768_item	2251932	et	3	main
suurendati	doc_171929905768_item	2251935	et	3	main
abinõusidbr	doc_171929905768_item	2251937	et	4	main
kartuli	doc_171929905768_item	2251943	et	3	main
19	doc_171929905768_item	2251945	et	2	main
domineerisid	doc_171929905768_item	2251948	et	4	main
või	doc_171929905768_item	2251968	et	4	main
mittetootlik	doc_171929905768_item	2251969	et	3	main
rahvas	doc_171929905768_item	2251970	et	4	main
suurenes	doc_171929905768_item	2251971	et	4	main
kiir	doc_171929905768_item	2251972	et	4	main
elualadel	doc_171929905768_item	2251975	et	3	main
hoogsalt	doc_171929905768_item	2251977	et	4	main
jahutööstuse	doc_171929905768_item	2251981	et	3	main
1903	doc_171929905768_item	2251984	et	2	main
peamised	doc_171929905768_item	2251989	et	3	main
kõigepealt	doc_171929905768_item	2251991	et	3	main
saja-aastast	doc_171929905768_item	2252024	et	4	main
tartu	doc_171929905768_item	2252028	et	4	main
tartus	doc_171929905768_item	2252030	et	3	main
ka	doc_171929905768_item	2252032	et	3	main
näiteks	doc_171929905768_item	2252036	et	4	main
1865	doc_171929905768_item	2252038	et	2	main
maailmasõja	doc_171929905768_item	2252054	et	3	main
väga	doc_171929905768_item	2252055	et	3	main
ja	doc_171929905768_item	2252060	et	3	main
hakkasid	doc_171929905768_item	2252062	et	4	main
eestlaste	doc_171929905768_item	2252087	et	4	main
ühtseks	doc_171929905768_item	2252089	et	4	main
ametnikud	doc_171929905768_item	2252094	et	3	main
eestlastega	doc_171929905768_item	2252095	et	4	main
metsas	doc_171929905767_item	2251672	et	3	main
juures	doc_171929905767_item	2251684	et	4	main
kui	doc_171929905767_item	2251685	et	3	main
tara	doc_171929905767_item	2251725	et	4	main
andurile	doc_171929905767_item	2251729	et	3	main
on	doc_171929905767_item	2251731	et	4	main
objekti	doc_171929905767_item	2251739	et	4	main
kaine	doc_171929905767_item	2251759	et	4	main
teatas	doc_171929905767_item	2251761	et	3	main
qni	doc_171929905767_item	2251810	et	4	main
märkasid	doc_171929905767_item	2251814	et	4	main
oli	doc_171929905767_item	2251820	et	3	main
või	doc_171929905767_item	2251832	et	4	main
eelõhtul	doc_171929905767_item	2251835	et	3	main
kinnitas	doc_171929905767_item	2251837	et	3	main
jooksul	doc_171929905767_item	2251841	et	4	main
järeldusi	doc_171929905767_item	2251850	et	4	main
luba	doc_171929905767_item	2251857	et	4	main
pbr	doc_171929905767_item	2251861	et	4	main
kontrolltöö	doc_171929905768_item	2251865	et	4	main
lätis	doc_171929905768_item	2251900	et	4	main
sotsiaaldemokratlikud	doc_171929905768_item	2251903	et	4	main
töölis	doc_171929905768_item	2251908	et	4	main
klass	doc_171929905768_item	2251909	et	3	main
pärast	doc_171929905768_item	2251919	et	4	main
kogu	doc_171929905768_item	2251924	et	4	main
saj	doc_171929905768_item	2251946	et	4	main
baltikumi	doc_171929905768_item	2251949	et	4	main
valgustaja	doc_171929905768_item	2251951	et	4	main
ideed	doc_171929905768_item	2251952	et	4	main
nõudis	doc_171929905768_item	2251954	et	3	main
järgnevatel	doc_171929905768_item	2251961	et	4	main
rahvastik	doc_171929905768_item	2251964	et	3	main
vähenes	doc_171929905768_item	2251965	et	3	main
pooltootlik	doc_171929905768_item	2251967	et	3	main
laieneminebr	doc_171929905768_item	2251982	et	4	main
majanduskriis	doc_171929905768_item	2251985	et	3	main
vabadussõja	doc_171929905768_item	2251988	et	3	main
põhjused	doc_171929905768_item	2251990	et	3	main
jälle	doc_171929905768_item	2252027	et	3	main
töötas	doc_171929905768_item	2252031	et	3	main
ii	doc_171929905768_item	2252053	et	4	main
levinud	doc_171929905768_item	2252056	et	4	main
maanõukogu	doc_171929905768_item	2252083	et	4	main
kubermangukomissar	doc_171929905768_item	2252085	et	3	main
otsustati	doc_171929905768_item	2252096	et	3	main
emakeelne	doc_171929905768_item	2252098	et	3	main
okkupatsiooni	doc_171929905768_item	2252116	et	4	main
kokkuvarisemisel	doc_171929905768_item	2252117	et	3	main
saksa	doc_171929905768_item	2252119	et	4	main
vaja	doc_171929905767_item	2251691	et	4	main
märkida	doc_171929905767_item	2251692	et	4	main
et	doc_171929905767_item	2251693	et	3	main
perimetril	doc_171929905767_item	2251696	et	4	main
meiega	doc_171929905767_item	2251698	et	4	main
sektsioon	doc_171929905767_item	2251721	et	3	main
mittesaavutav	doc_171929905767_item	2251728	et	3	main
oli	doc_171929905767_item	2251737	et	3	main
territorium	doc_171929905767_item	2251740	et	4	main
valve	doc_171929905767_item	2251742	et	4	main
valvurile	doc_171929905767_item	2251751	et	3	main
jooksul	doc_171929905767_item	2251753	et	4	main
x	doc_171929905767_item	2251760	et	4	main
kordpidajale	doc_171929905767_item	2251763	et	3	main
patrull	doc_171929905767_item	2251767	et	3	main
võimalik	doc_171929905767_item	2251785	et	3	main
oli	doc_171929905767_item	2251787	et	3	main
tehtud	doc_171929905767_item	2251788	et	4	main
1100	doc_171929905767_item	2251790	et	2	main
saabunud	doc_171929905767_item	2251791	et	4	main
sektsioon	doc_171929905767_item	2251798	et	3	main
tema	doc_171929905767_item	2251800	et	4	main
sündmusi	doc_171929905767_item	2251802	et	3	main
pole	doc_171929905767_item	2251803	et	3	main
hommikul	doc_171929905767_item	2251805	et	3	main
oktoobril	doc_171929905767_item	2251807	et	3	main
et	doc_171929905767_item	2251815	et	3	main
varem	doc_171929905767_item	2251819	et	4	main
lahti	doc_171929905767_item	2251724	et	4	main
kaugusel	doc_171929905767_item	2251727	et	4	main
sellest	doc_171929905767_item	2251730	et	4	main
võimalik	doc_171929905767_item	2251732	et	3	main
et	doc_171929905767_item	2251735	et	3	main
tundud	doc_171929905767_item	2251738	et	3	main
ja	doc_171929905767_item	2251741	et	3	main
süsteem	doc_171929905767_item	2251743	et	3	main
hommikul	doc_171929905767_item	2251745	et	3	main
oktoobril	doc_171929905767_item	2251747	et	3	main
üle	doc_171929905767_item	2251749	et	3	main
kohale	doc_171929905767_item	2251765	et	4	main
patrull	doc_171929905767_item	2251768	et	3	main
oli	doc_171929905767_item	2251769	et	3	main
nõus	doc_171929905767_item	2251770	et	4	main
et	doc_171929905767_item	2251771	et	3	main
z	doc_171929905767_item	2251772	et	4	main
tuli	doc_171929905767_item	2251773	et	4	main
tööle	doc_171929905767_item	2251774	et	3	main
alkohooli	doc_171929905767_item	2251775	et	3	main
joobetunnustega	doc_171929905767_item	2251776	et	3	main
see	doc_171929905767_item	2251777	et	3	main
oli	doc_171929905767_item	2251778	et	3	main
puhkepäev	doc_171929905767_item	2251779	et	3	main
ja	doc_171929905767_item	2251780	et	3	main
muuta	doc_171929905767_item	2251781	et	4	main
kohe	doc_171929905767_item	2251782	et	4	main
valvurit	doc_171929905767_item	2251783	et	3	main
pole	doc_171929905767_item	2251784	et	3	main
muutmine	doc_171929905767_item	2251786	et	4	main
kella	doc_171929905767_item	2251789	et	4	main
q	doc_171929905767_item	2251793	et	4	main
territooriumi	doc_171929905767_item	2251795	et	4	main
hommikuni	doc_171929905767_item	2251799	et	4	main
br	doc_171929905767_item	2251804	et	4	main
ümbermineku	doc_171929905767_item	2251811	et	3	main
seinalt	doc_171929905767_item	2251817	et	3	main
pole	doc_171929905767_item	2251833	et	3	main
et	doc_171929905767_item	2251838	et	3	main
vahetuse	doc_171929905767_item	2251840	et	4	main
korras	doc_171929905767_item	2251844	et	4	main
samasugust	doc_171929905767_item	2251854	et	3	main
eesti	doc_171929905768_item	2251866	et	4	main
teravnesid	doc_171929905768_item	2251892	et	4	main
ning	doc_171929905768_item	2251895	et	3	main
eestis	doc_171929905768_item	2251898	et	3	main
ideed	doc_171929905768_item	2251904	et	4	main
lätis	doc_171929905768_item	2251907	et	4	main
kuid	doc_171929905768_item	2251912	et	4	main
kindlustatuse	doc_171929905768_item	2251914	et	4	main
väga	doc_171929905768_item	2251917	et	3	main
manifest	doc_171929905768_item	2251929	et	3	main
ka	doc_171929905768_item	2251936	et	3	main
väga	doc_171929905768_item	2251938	et	3	main
kasvatus	doc_171929905768_item	2251944	et	4	main
eestlastele	doc_171929905768_item	2251955	et	4	main
võrdseid	doc_171929905768_item	2251958	et	3	main
1897	doc_171929905768_item	2251960	et	2	main
aastakümnetel	doc_171929905768_item	2251962	et	4	main
põllumajanduslik	doc_171929905768_item	2251963	et	3	main
tööstuslik	doc_171929905768_item	2251966	et	3	main
kõigil	doc_171929905768_item	2251974	et	4	main
laienes	doc_171929905768_item	2251976	et	3	main
metalli	doc_171929905768_item	2251978	et	4	main
masinatööstus	doc_171929905768_item	2251980	et	3	main
viiner	doc_171929905767_item	2251822	et	3	main
katkestanud	doc_171929905767_item	2251824	et	4	main
oli	doc_171929905767_item	2251831	et	3	main
x	doc_171929905767_item	2251836	et	4	main
kõik	doc_171929905767_item	2251842	et	4	main
tehtus	doc_171929905767_item	2251848	et	4	main
juhtumist	doc_171929905767_item	2251849	et	4	main
ja	doc_171929905767_item	2251851	et	3	main
ei	doc_171929905767_item	2251856	et	4	main
br	doc_171929905767_item	2251858	et	4	main
lugupidamisega	doc_171929905767_item	2251859	et	3	main
e	doc_171929905767_item	2251860	et	4	main
turvateenistus	doc_171929905767_item	2251863	et	3	main
1	doc_171929905768_item	2251868	et	2	main
mis	doc_171929905768_item	2251869	et	4	main
nõukogude	doc_171929905768_item	2251871	et	3	main
poliitilist	doc_171929905768_item	2251873	et	3	main
ja	doc_171929905768_item	2251874	et	3	main
majanduslikku	doc_171929905768_item	2251875	et	4	main
süsteemi	doc_171929905768_item	2251876	et	4	main
2	doc_171929905768_item	2251877	et	2	main
millised	doc_171929905768_item	2251878	et	3	main
olid	doc_171929905768_item	2251879	et	4	main
vabadussõja	doc_171929905768_item	2251880	et	3	main
võidu	doc_171929905768_item	2251881	et	4	main
peamised	doc_171929905768_item	2251882	et	3	main
põhjusedbr	doc_171929905768_item	2251883	et	4	main
3	doc_171929905768_item	2251884	et	2	main
iseloomustage	doc_171929905768_item	2251885	et	4	main
ew	doc_171929905768_item	2251886	et	4	main
teaduselu	doc_171929905768_item	2251887	et	4	main
br	doc_171929905768_item	2251888	et	4	main
1905	doc_171929905768_item	2251890	et	2	main
1	doc_171929905768_item	2251889	et	2	main
oli	doc_171929905767_item	2251843	et	3	main
br	doc_171929905767_item	2251845	et	4	main
püüab	doc_171929905767_item	2251853	et	3	main
tegevdirektorbr	doc_171929905767_item	2251864	et	4	main
iseloomustab	doc_171929905768_item	2251870	et	4	main
poliitilised	doc_171929905768_item	2251894	et	3	main
ja	doc_171929905768_item	2251899	et	3	main
suurenes	doc_171929905768_item	2251910	et	4	main
jäi	doc_171929905768_item	2251916	et	3	main
demonstrantide	doc_171929905768_item	2251921	et	3	main
haaras	doc_171929905768_item	2251923	et	4	main
maad	doc_171929905768_item	2251925	et	4	main
avaldati	doc_171929905768_item	2251927	et	3	main
kus	doc_171929905768_item	2251930	et	3	main
lubati	doc_171929905768_item	2251931	et	3	main
aga	doc_171929905768_item	2251934	et	3	main
mängis	doc_171929905768_item	2251940	et	3	main
majanduslikku	doc_171929905768_item	2251941	et	4	main
elus	doc_171929905768_item	2251942	et	4	main
algul	doc_171929905768_item	2251947	et	4	main
vaimuelus	doc_171929905768_item	2251950	et	4	main
crjakobson	doc_171929905768_item	2251953	et	4	main
baltisaksa	doc_171929905768_item	2251956	et	4	main
areng	doc_171929905768_item	2251973	et	3	main
ja	doc_171929905768_item	2251979	et	3	main
br	doc_171929905768_item	2251986	et	4	main
aasta	doc_171929905768_item	2252022	et	4	main
ülikooli	doc_171929905768_item	2252029	et	4	main
palju	doc_171929905768_item	2252033	et	4	main
vanemuine	doc_171929905768_item	2252043	et	4	main
br	doc_171929905768_item	2252044	et	4	main
kiiresti	doc_171929905768_item	2252046	et	3	main
разв-ся	doc_171929905768_item	2252048	et	2	main
ja	doc_171929905768_item	2252050	et	3	main
pärast	doc_171929905768_item	2252052	et	4	main
peod	doc_171929905768_item	2252059	et	4	main
järgnevalt	doc_171929905768_item	2252091	et	4	main
kehtestada	doc_171929905768_item	2252097	et	3	main
veebruar	doc_171929905768_item	2252102	et	3	main
ajutine	doc_171929905768_item	2252105	et	4	main
valitsus	doc_171929905768_item	2252106	et	4	main
peaministr	doc_171929905768_item	2252107	et	4	main
päts	doc_171929905768_item	2252109	et	3	main
võim	doc_171929905768_item	2252111	et	3	main
läks	doc_171929905768_item	2252115	et	3	main
sai	doc_171929905768_item	2252118	et	4	main
mille	doc_171929905768_item	2252121	et	3	main
1918	doc_171929905768_item	2252124	et	2	main
gne	doc_171929905768_item	2252127	et	4	main
a	doc_171929905768_item	2251891	et	4	main
venemaal	doc_171929905768_item	2251893	et	4	main
vastuolud	doc_171929905768_item	2251897	et	3	main
levima	doc_171929905768_item	2251902	et	3	main
ja	doc_171929905768_item	2251906	et	3	main
kiiresti	doc_171929905768_item	2251911	et	3	main
nende	doc_171929905768_item	2251913	et	4	main
tase	doc_171929905768_item	2251915	et	3	main
rahulolematuselaine	doc_171929905768_item	2251926	et	4	main
tsaari	doc_171929905768_item	2251928	et	4	main
vabadusi	doc_171929905768_item	2251933	et	4	main
palju	doc_171929905768_item	2251939	et	4	main
aadliga	doc_171929905768_item	2251957	et	3	main
õigusi	doc_171929905768_item	2251959	et	4	main
1900	doc_171929905768_item	2251983	et	2	main
2	doc_171929905768_item	2251987	et	2	main
eesti	doc_171929905768_item	2251992	et	4	main
tahtis	doc_171929905768_item	2251994	et	3	main
vabaks	doc_171929905768_item	2251995	et	3	main
rahvas	doc_171929905768_item	2251993	et	4	main
saada	doc_171929905768_item	2251996	et	4	main
kõik	doc_171929905768_item	2251997	et	4	main
paremat	doc_171929905768_item	2251999	et	4	main
tahtsid	doc_171929905768_item	2251998	et	4	main
elut	doc_171929905768_item	2252000	et	4	main
sellepärast	doc_171929905768_item	2252001	et	3	main
et	doc_171929905768_item	2252002	et	3	main
oli	doc_171929905768_item	2252003	et	3	main
juba	doc_171929905768_item	2252004	et	3	main
nii	doc_171929905768_item	2252005	et	3	main
raske	doc_171929905768_item	2252006	et	4	main
elada	doc_171929905768_item	2252007	et	3	main
majanduslikud	doc_171929905768_item	2252009	et	3	main
kriisid	doc_171929905768_item	2252010	et	3	main
kõik	doc_171929905768_item	2252008	et	4	main
br	doc_171929905768_item	2252011	et	4	main
tarbekaupade	doc_171929905768_item	2252012	et	3	main
vähesus	doc_171929905768_item	2252013	et	4	main
põhjustas	doc_171929905768_item	2252014	et	3	main
hinnadetõusu	doc_171929905768_item	2252015	et	4	main
ja	doc_171929905768_item	2252016	et	3	main
ülikiire	doc_171929905768_item	2252017	et	4	main
inflatsiooni	doc_171929905768_item	2252018	et	4	main
br	doc_171929905768_item	2252019	et	4	main
3	doc_171929905768_item	2252020	et	2	main
1802	doc_171929905768_item	2252021	et	2	main
avati	doc_171929905768_item	2252026	et	3	main
maailmamainega	doc_171929905768_item	2252034	et	4	main
ja	doc_171929905768_item	2252041	et	3	main
hakkas	doc_171929905768_item	2252047	et	3	main
teadus	doc_171929905768_item	2252049	et	4	main
kultuurielu	doc_171929905768_item	2252051	et	4	main
laulu	doc_171929905768_item	2252058	et	4	main
tantsimispeod	doc_171929905768_item	2252061	et	4	main
oma	doc_171929905768_item	2252063	et	4	main
tööd	doc_171929905768_item	2252064	et	4	main
kirjutada	doc_171929905768_item	2252065	et	3	main
asualad	doc_171929905768_item	2252088	et	3	main
br	doc_171929905768_item	2252100	et	4	main
1918	doc_171929905768_item	2252103	et	2	main
kogu	doc_171929905768_item	2252110	et	4	main
pärast	doc_171929905768_item	2252023	et	4	main
vaheaega	doc_171929905768_item	2252025	et	4	main
teadlasi	doc_171929905768_item	2252035	et	3	main
jcstruve	doc_171929905768_item	2252037	et	4	main
asutati	doc_171929905768_item	2252039	et	4	main
laulu-	doc_171929905768_item	2252040	et	4	main
mänguseltsi	doc_171929905768_item	2252042	et	4	main
väga	doc_171929905768_item	2252045	et	3	main
olid	doc_171929905768_item	2252057	et	4	main
novelle	doc_171929905768_item	2252066	et	3	main
ja	doc_171929905768_item	2252067	et	3	main
luuletusi	doc_171929905768_item	2252068	et	4	main
paljud	doc_171929905768_item	2252069	et	3	main
autorid	doc_171929905768_item	2252070	et	3	main
üks	doc_171929905768_item	2252071	et	3	main
nendes	doc_171929905768_item	2252072	et	4	main
oli	doc_171929905768_item	2252073	et	3	main
jkrossbr	doc_171929905768_item	2252074	et	4	main
1	doc_171929905768_item	2252075	et	2	main
1917	doc_171929905768_item	2252076	et	2	main
vene	doc_171929905768_item	2252077	et	4	main
ajutine	doc_171929905768_item	2252078	et	4	main
valitsus	doc_171929905768_item	2252079	et	4	main
autonoomia	doc_171929905768_item	2252080	et	4	main
eestimaa	doc_171929905768_item	2252081	et	4	main
ajutine	doc_171929905768_item	2252082	et	4	main
jposka	doc_171929905768_item	2252084	et	4	main
ühendati	doc_171929905768_item	2252086	et	4	main
haldusüksuseks	doc_171929905768_item	2252090	et	4	main
asendati	doc_171929905768_item	2252092	et	3	main
vene	doc_171929905768_item	2252093	et	4	main
24	doc_171929905768_item	2252101	et	2	main
a	doc_171929905768_item	2252104	et	4	main
eestis	doc_171929905768_item	2252114	et	3	main
kirjutati	doc_171929905768_item	2252123	et	3	main
vaherahu	doc_171929905768_item	2252128	et	4	main
ei	doc_177993561423_item	2252384	et	4	main
tänapäeval	doc_177993561423_item	2252387	et	3	main
milleta	doc_177993561423_item	2252390	et	3	main
see	doc_177993561423_item	2252396	et	3	main
sellest	doc_177993561423_item	2252406	et	4	main
kohal	doc_177993561423_item	2252412	et	4	main
teisel	doc_177993561423_item	2252420	et	4	main
töö	doc_177993561423_item	2252423	et	4	main
palju	doc_177993561423_item	2252434	et	4	main
kõige	doc_177993561423_item	2252436	et	4	main
saa	doc_177993561423_item	2252444	et	4	main
sellepärast	doc_177993561423_item	2252449	et	3	main
ilma	doc_177993561423_item	2252453	et	4	main
inimsel	doc_177993561423_item	2252465	et	4	main
ja	doc_177993561423_item	2252469	et	3	main
praegu	doc_177993561423_item	2252473	et	3	main
tal	doc_177993561423_item	2252477	et	3	main
ja	doc_177993561423_item	2252518	et	3	main
on	doc_177993561423_item	2252520	et	4	main
väga	doc_177993561423_item	2252521	et	3	main
sellepärast	doc_177993561423_item	2252523	et	3	main
töötab	doc_177993561423_item	2252525	et	3	main
ja	doc_177993561423_item	2252527	et	3	main
on	doc_177993561423_item	2252529	et	4	main
ei	doc_177993561423_item	2252535	et	4	main
elada	doc_177993561423_item	2252537	et	3	main
ilma	doc_177993561423_item	2252538	et	4	main
sõpradeta	doc_177993561423_item	2252541	et	3	main
ei	doc_177993561423_item	2252543	et	4	main
elada	doc_177993561423_item	2252545	et	3	main
looduseta	doc_177993561423_item	2252554	et	4	main
ei	doc_177993561424_item	2252557	et	4	main
elada	doc_177993561424_item	2252568	et	3	main
ma	doc_177993561424_item	2252569	et	3	main
et	doc_177993561424_item	2252571	et	3	main
elada	doc_177993561424_item	2252576	et	3	main
elada	doc_177993561424_item	2252621	et	3	main
ei	doc_177993561424_item	2252628	et	4	main
on	doc_177993561424_item	2252634	et	4	main
elada	doc_177993561424_item	2252638	et	3	main
kooliharidus	doc_171929905768_item	2252099	et	3	main
konstantin	doc_171929905768_item	2252108	et	4	main
tulemusena	doc_171929905768_item	2252122	et	3	main
body	doc_171929905768_item	2252129	et	4	main
lätis	doc_171929905768_item	2252112	et	4	main
ja	doc_171929905768_item	2252113	et	3	main
revolutsioon	doc_171929905768_item	2252120	et	3	main
a	doc_171929905768_item	2252125	et	4	main
alla	doc_171929905768_item	2252126	et	3	main
elada	doc_177993561423_item	2252388	et	3	main
ei	doc_177993561423_item	2252391	et	4	main
saa	doc_177993561423_item	2252392	et	4	main
inimene	doc_177993561423_item	2252393	et	3	main
iseloomust	doc_177993561423_item	2252400	et	4	main
inimese	doc_177993561423_item	2252408	et	4	main
inimese	doc_177993561423_item	2252414	et	4	main
tähtsam	doc_177993561423_item	2252417	et	4	main
on	doc_177993561423_item	2252418	et	4	main
on	doc_177993561423_item	2252422	et	4	main
inimene	doc_177993561423_item	2252432	et	3	main
peab	doc_177993561423_item	2252439	et	4	main
tööta	doc_177993561423_item	2252454	et	4	main
inimene	doc_177993561423_item	2252456	et	3	main
on	doc_177993561423_item	2252466	et	4	main
kõik	doc_177993561423_item	2252470	et	4	main
korras	doc_177993561423_item	2252472	et	4	main
tugev	doc_177993561423_item	2252479	et	4	main
tervis	doc_177993561423_item	2252480	et	3	main
ilus	doc_177993561423_item	2252484	et	4	main
vähe	doc_177993561423_item	2252531	et	3	main
ta	doc_177993561423_item	2252542	et	4	main
ta	doc_177993561423_item	2252550	et	4	main
milleta	doc_177993561424_item	2252556	et	3	main
milleta	doc_177993561424_item	2252563	et	3	main
ei	doc_177993561424_item	2252574	et	4	main
elus	doc_177993561424_item	2252580	et	4	main
see	doc_177993561424_item	2252582	et	3	main
on	doc_177993561424_item	2252583	et	4	main
laste	doc_177993561424_item	2252618	et	4	main
lapsed	doc_177993561424_item	2252633	et	3	main
ning	doc_177993561424_item	2252645	et	3	main
saa	doc_177993561423_item	2252385	et	4	main
inimene	doc_177993561423_item	2252386	et	3	main
ilma	doc_177993561423_item	2252389	et	4	main
sõltub	doc_177993561423_item	2252397	et	3	main
erialast	doc_177993561423_item	2252402	et	4	main
vanusest	doc_177993561423_item	2252403	et	4	main
on	doc_177993561423_item	2252410	et	4	main
ilma	doc_177993561423_item	2252375	et	4	main
milleta	doc_177993561423_item	2252376	et	3	main
ei	doc_177993561423_item	2252377	et	4	main
saa	doc_177993561423_item	2252378	et	4	main
inimene	doc_177993561423_item	2252379	et	3	main
tänapäeval	doc_177993561423_item	2252380	et	3	main
elada	doc_177993561423_item	2252381	et	3	main
milleta	doc_177993561423_item	2252383	et	3	main
ilma	doc_177993561423_item	2252382	et	4	main
tänapäeval	doc_177993561423_item	2252394	et	3	main
inimesest	doc_177993561423_item	2252398	et	3	main
ja	doc_177993561423_item	2252405	et	3	main
mis	doc_177993561423_item	2252407	et	4	main
elus	doc_177993561423_item	2252409	et	4	main
ühe	doc_177993561423_item	2252413	et	4	main
elus	doc_177993561423_item	2252415	et	4	main
kõige	doc_177993561423_item	2252416	et	4	main
pere	doc_177993561423_item	2252419	et	4	main
see	doc_177993561423_item	2252425	et	3	main
nii	doc_177993561423_item	2252429	et	3	main
tänapäeval	doc_177993561423_item	2252431	et	3	main
sellepärast	doc_177993561423_item	2252441	et	3	main
rahata	doc_177993561423_item	2252447	et	4	main
kui	doc_177993561423_item	2252455	et	3	main
siis	doc_177993561423_item	2252464	et	3	main
tahab	doc_177993561423_item	2252475	et	3	main
oleks	doc_177993561423_item	2252483	et	3	main
elada	doc_177993561423_item	2252395	et	3	main
tema	doc_177993561423_item	2252399	et	4	main
tema	doc_177993561423_item	2252401	et	4	main
elukohast	doc_177993561423_item	2252404	et	4	main
esimesel	doc_177993561423_item	2252411	et	3	main
kolmandal	doc_177993561423_item	2252424	et	3	main
on	doc_177993561423_item	2252426	et	4	main
ja	doc_177993561423_item	2252428	et	3	main
tahab	doc_177993561423_item	2252433	et	3	main
aga	doc_177993561423_item	2252435	et	3	main
eest	doc_177993561423_item	2252437	et	4	main
inimene	doc_177993561423_item	2252438	et	3	main
maksma	doc_177993561423_item	2252440	et	3	main
ei	doc_177993561423_item	2252443	et	4	main
elada	doc_177993561423_item	2252445	et	3	main
ilma	doc_177993561423_item	2252446	et	4	main
ja	doc_177993561423_item	2252448	et	3	main
ta	doc_177993561423_item	2252450	et	4	main
saa	doc_177993561423_item	2252452	et	4	main
rahuldab	doc_177993561423_item	2252457	et	3	main
eluliseid	doc_177993561423_item	2252459	et	4	main
teisi	doc_177993561423_item	2252462	et	4	main
on	doc_177993561423_item	2252471	et	4	main
inimene	doc_177993561423_item	2252474	et	3	main
ta	doc_177993561423_item	2252482	et	4	main
olulised	doc_177993561423_item	2252522	et	4	main
inimene	doc_177993561423_item	2252524	et	3	main
palju	doc_177993561423_item	2252526	et	4	main
temal	doc_177993561423_item	2252528	et	3	main
väga	doc_177993561423_item	2252530	et	3	main
aegabr	doc_177993561423_item	2252533	et	4	main
saa	doc_177993561423_item	2252544	et	4	main
ja	doc_177993561423_item	2252548	et	3	main
ilma	doc_177993561424_item	2252555	et	4	main
inimene	doc_177993561424_item	2252560	et	3	main
saa	doc_177993561424_item	2252565	et	4	main
arvan	doc_177993561424_item	2252570	et	3	main
inimene	doc_177993561424_item	2252573	et	3	main
ilma	doc_177993561424_item	2252577	et	4	main
eest	doc_177993561424_item	2252620	et	4	main
tohi	doc_177993561424_item	2252623	et	4	main
ette	doc_177993561424_item	2252630	et	4	main
kui	doc_177993561424_item	2252631	et	3	main
ja	doc_177993561424_item	2252636	et	3	main
ma	doc_177993561424_item	2252641	et	3	main
ilma	doc_177993561424_item	2252643	et	4	main
ei	doc_177993561424_item	2252646	et	4	main
istuda	doc_177993561424_item	2252652	et	3	main
taga	doc_177993561424_item	2252655	et	4	main
ma	doc_177993561424_item	2252662	et	3	main
et	doc_177993561424_item	2252664	et	3	main
kui	doc_177993561424_item	2252676	et	3	main
ei	doc_177993561424_item	2252725	et	4	main
p	doc_177993561424_item	2252728	et	4	main
saa	doc_177993561425_item	2252738	et	4	main
tänapäeval	doc_177993561425_item	2252739	et	3	main
kõik	doc_177993561425_item	2252741	et	4	main
erinevad	doc_177993561425_item	2252745	et	4	main
sellepärast	doc_177993561425_item	2252747	et	3	main
nendel	doc_177993561425_item	2252748	et	4	main
kõik	doc_177993561425_item	2252753	et	4	main
keskkonnas	doc_177993561425_item	2252756	et	3	main
esialgu	doc_177993561425_item	2252761	et	3	main
missugused	doc_177993561425_item	2252764	et	3	main
keskkonnas	doc_177993561425_item	2252769	et	3	main
arvan	doc_177993561425_item	2252772	et	3	main
haritud	doc_177993561425_item	2252779	et	4	main
palka	doc_177993561425_item	2252786	et	4	main
see	doc_177993561423_item	2252421	et	3	main
sõbrad	doc_177993561423_item	2252427	et	3	main
edasi	doc_177993561423_item	2252430	et	3	main
inimene	doc_177993561423_item	2252442	et	3	main
ei	doc_177993561423_item	2252451	et	4	main
oma	doc_177993561423_item	2252458	et	4	main
kultuuriliseid	doc_177993561423_item	2252460	et	4	main
ja	doc_177993561423_item	2252461	et	3	main
vajadusi	doc_177993561423_item	2252463	et	3	main
hea	doc_177993561423_item	2252467	et	4	main
tuju	doc_177993561423_item	2252468	et	4	main
et	doc_177993561423_item	2252476	et	3	main
oleks	doc_177993561423_item	2252478	et	3	main
et	doc_177993561423_item	2252481	et	3	main
et	doc_177993561423_item	2252485	et	3	main
tal	doc_177993561423_item	2252486	et	3	main
oleks	doc_177993561423_item	2252487	et	3	main
kodu	doc_177993561423_item	2252489	et	4	main
ja	doc_177993561423_item	2252490	et	3	main
pere	doc_177993561423_item	2252491	et	4	main
et	doc_177993561423_item	2252492	et	3	main
tal	doc_177993561423_item	2252493	et	3	main
hea	doc_177993561423_item	2252488	et	4	main
oleks	doc_177993561423_item	2252494	et	3	main
auto	doc_177993561423_item	2252495	et	4	main
et	doc_177993561423_item	2252496	et	3	main
ta	doc_177993561423_item	2252497	et	4	main
saaks	doc_177993561423_item	2252498	et	3	main
reisidaspan	doc_177993561423_item	2252499	et	4	main
spanja	doc_177993561423_item	2252500	et	4	main
puhata	doc_177993561423_item	2252501	et	4	main
kus	doc_177993561423_item	2252502	et	3	main
ta	doc_177993561423_item	2252503	et	4	main
tahab	doc_177993561423_item	2252504	et	3	main
et	doc_177993561423_item	2252505	et	3	main
tal	doc_177993561423_item	2252506	et	3	main
ja	doc_177993561423_item	2252507	et	3	main
lastel	doc_177993561423_item	2252509	et	4	main
tema	doc_177993561423_item	2252508	et	4	main
oleks	doc_177993561423_item	2252510	et	3	main
hiilgav	doc_177993561423_item	2252511	et	4	main
haridus	doc_177993561423_item	2252512	et	3	main
ja	doc_177993561423_item	2252513	et	3	main
muud	doc_177993561423_item	2252514	et	4	main
sellesarnast	doc_177993561423_item	2252515	et	4	main
kahjuks	doc_177993561423_item	2252516	et	4	main
raha	doc_177993561423_item	2252517	et	4	main
töö	doc_177993561423_item	2252519	et	4	main
inimene	doc_177993561423_item	2252534	et	3	main
saa	doc_177993561423_item	2252536	et	4	main
ilma	doc_177993561423_item	2252546	et	4	main
hobbita	doc_177993561423_item	2252549	et	4	main
ei	doc_177993561423_item	2252551	et	4	main
saa	doc_177993561423_item	2252552	et	4	main
tänapäeval	doc_177993561424_item	2252559	et	3	main
elada	doc_177993561424_item	2252561	et	3	main
tänapäeval	doc_177993561424_item	2252566	et	3	main
tänapäeval	doc_177993561424_item	2252572	et	3	main
rahata	doc_177993561424_item	2252578	et	4	main
vaba	doc_177993561423_item	2252532	et	4	main
suhtlemiseta	doc_177993561423_item	2252539	et	4	main
ja	doc_177993561423_item	2252540	et	3	main
lemmikraamatuteta	doc_177993561423_item	2252547	et	3	main
elada	doc_177993561423_item	2252553	et	3	main
saa	doc_177993561424_item	2252558	et	4	main
ilma	doc_177993561424_item	2252562	et	4	main
ei	doc_177993561424_item	2252564	et	4	main
inimene	doc_177993561424_item	2252567	et	3	main
saa	doc_177993561424_item	2252575	et	4	main
minu	doc_177993561424_item	2252579	et	3	main
raha	doc_177993561424_item	2252581	et	4	main
võimalus	doc_177993561424_item	2252584	et	3	main
õppida	doc_177993561424_item	2252585	et	3	main
käia	doc_177993561424_item	2252586	et	4	main
mingides	doc_177993561424_item	2252587	et	4	main
kursuses	doc_177993561424_item	2252588	et	3	main
osta	doc_177993561424_item	2252589	et	4	main
raamatuid	doc_177993561424_item	2252590	et	3	main
kui	doc_177993561424_item	2252591	et	3	main
ma	doc_177993561424_item	2252592	et	3	main
saan	doc_177993561424_item	2252593	et	4	main
rohkem	doc_177993561424_item	2252595	et	4	main
kui	doc_177993561424_item	2252596	et	3	main
raha	doc_177993561424_item	2252594	et	4	main
mul	doc_177993561424_item	2252597	et	3	main
ja	doc_177993561424_item	2252598	et	3	main
minu	doc_177993561424_item	2252599	et	3	main
perele	doc_177993561424_item	2252600	et	3	main
on	doc_177993561424_item	2252601	et	4	main
vaja	doc_177993561424_item	2252602	et	4	main
et	doc_177993561424_item	2252603	et	3	main
elu	doc_177993561424_item	2252604	et	4	main
püsida	doc_177993561424_item	2252605	et	3	main
ma	doc_177993561424_item	2252606	et	3	main
võin	doc_177993561424_item	2252607	et	3	main
reisida	doc_177993561424_item	2252608	et	3	main
sest	doc_177993561424_item	2252609	et	4	main
ma	doc_177993561424_item	2252610	et	3	main
väga	doc_177993561424_item	2252611	et	3	main
huvitan	doc_177993561424_item	2252612	et	3	main
sellest	doc_177993561424_item	2252613	et	4	main
ma	doc_177993561424_item	2252614	et	3	main
saan	doc_177993561424_item	2252615	et	4	main
maksta	doc_177993561424_item	2252616	et	4	main
oma	doc_177993561424_item	2252617	et	4	main
hariduse	doc_177993561424_item	2252619	et	3	main
ei	doc_177993561424_item	2252622	et	4	main
ainult	doc_177993561424_item	2252624	et	4	main
rahaga	doc_177993561424_item	2252625	et	4	main
praegu	doc_177993561424_item	2252626	et	3	main
kasvavad	doc_177993561424_item	2252635	et	4	main
tahavad	doc_177993561424_item	2252637	et	3	main
eraldi	doc_177993561424_item	2252639	et	4	main
koolist	doc_177993561424_item	2252651	et	4	main
töö	doc_177993561424_item	2252680	et	4	main
tähtis	doc_177993561424_item	2252686	et	4	main
ma	doc_177993561424_item	2252627	et	3	main
kujuta	doc_177993561424_item	2252629	et	4	main
minu	doc_177993561424_item	2252632	et	3	main
kuidas	doc_177993561424_item	2252640	et	3	main
nendeta	doc_177993561424_item	2252644	et	4	main
nendega	doc_177993561424_item	2252653	et	4	main
laua	doc_177993561424_item	2252654	et	3	main
ja	doc_177993561424_item	2252656	et	3	main
läks	doc_177993561424_item	2252660	et	3	main
arvan	doc_177993561424_item	2252663	et	3	main
kõigedele	doc_177993561424_item	2252665	et	4	main
elada	doc_177993561424_item	2252675	et	3	main
tal	doc_177993561424_item	2252677	et	3	main
lemmik	doc_177993561424_item	2252679	et	3	main
väga	doc_177993561424_item	2252685	et	3	main
saab	doc_177993561424_item	2252690	et	3	main
sind	doc_177993561424_item	2252691	et	4	main
aru	doc_177993561424_item	2252692	et	4	main
ja	doc_177993561424_item	2252693	et	3	main
võib	doc_177993561424_item	2252694	et	3	main
sind	doc_177993561424_item	2252695	et	4	main
aidata	doc_177993561424_item	2252696	et	4	main
mul	doc_177993561424_item	2252697	et	3	main
on	doc_177993561424_item	2252698	et	4	main
veedas	doc_177993561424_item	2252699	et	4	main
et	doc_177993561424_item	2252700	et	3	main
minu	doc_177993561424_item	2252701	et	3	main
abikaasal	doc_177993561424_item	2252702	et	3	main
on	doc_177993561424_item	2252703	et	4	main
harastused	doc_177993561424_item	2252705	et	4	main
kui	doc_177993561424_item	2252706	et	3	main
sama	doc_177993561424_item	2252704	et	4	main
minul	doc_177993561424_item	2252707	et	3	main
ja	doc_177993561424_item	2252708	et	3	main
tema	doc_177993561424_item	2252709	et	4	main
targem	doc_177993561424_item	2252710	et	4	main
kui	doc_177993561424_item	2252711	et	3	main
mina	doc_177993561424_item	2252712	et	4	main
teab	doc_177993561424_item	2252713	et	3	main
rohkem	doc_177993561424_item	2252714	et	4	main
ning	doc_177993561424_item	2252715	et	3	main
võib	doc_177993561424_item	2252716	et	3	main
seletada	doc_177993561424_item	2252717	et	3	main
midagi	doc_177993561424_item	2252718	et	4	main
mulle	doc_177993561424_item	2252719	et	4	main
see	doc_177993561424_item	2252720	et	3	main
on	doc_177993561424_item	2252721	et	4	main
elada	doc_177993561424_item	2252727	et	3	main
saa	doc_177993561425_item	2252732	et	4	main
elada	doc_177993561425_item	2252740	et	3	main
me	doc_177993561425_item	2252754	et	4	main
seas	doc_177993561425_item	2252758	et	4	main
muidugi	doc_177993561425_item	2252760	et	4	main
elan	doc_177993561424_item	2252642	et	3	main
neid	doc_177993561424_item	2252650	et	4	main
kuidas	doc_177993561424_item	2252658	et	3	main
päev	doc_177993561424_item	2252659	et	3	main
inimestele	doc_177993561424_item	2252666	et	3	main
on	doc_177993561424_item	2252667	et	4	main
tähtis	doc_177993561424_item	2252669	et	4	main
oma	doc_177993561424_item	2252670	et	4	main
perebr	doc_177993561424_item	2252671	et	4	main
tänapäeval	doc_177993561424_item	2252672	et	3	main
kergem	doc_177993561424_item	2252674	et	4	main
oma	doc_177993561424_item	2252681	et	4	main
kodu	doc_177993561424_item	2252682	et	4	main
sõbralik	doc_177993561424_item	2252683	et	3	main
et	doc_177993561424_item	2252687	et	3	main
kes	doc_177993561424_item	2252689	et	4	main
kõik	doc_177993561424_item	2252722	et	4	main
saa	doc_177993561424_item	2252726	et	4	main
ei	doc_177993561425_item	2252731	et	4	main
elada	doc_177993561425_item	2252734	et	3	main
milleta	doc_177993561425_item	2252736	et	3	main
inimesed	doc_177993561425_item	2252742	et	3	main
väga	doc_177993561425_item	2252744	et	3	main
elus	doc_177993561425_item	2252752	et	4	main
ja	doc_177993561425_item	2252759	et	3	main
peame	doc_177993561425_item	2252762	et	4	main
arvestama	doc_177993561425_item	2252763	et	3	main
on	doc_177993561425_item	2252766	et	4	main
ma	doc_177993561425_item	2252771	et	3	main
ilma	doc_177993561425_item	2252777	et	4	main
hariduseta	doc_177993561425_item	2252778	et	3	main
ja	doc_177993561425_item	2252784	et	3	main
kõrgharidus	doc_177993561425_item	2252790	et	3	main
saa	doc_177993561425_item	2252823	et	4	main
elada	doc_177993561425_item	2252824	et	3	main
muidugi	doc_177993561425_item	2252825	et	4	main
hea	doc_177993561425_item	2252833	et	4	main
mis	doc_177993561425_item	2252835	et	4	main
reisida	doc_177993561425_item	2252840	et	3	main
vaba	doc_177993561425_item	2252850	et	4	main
teatris	doc_177993561425_item	2252853	et	3	main
toitlustada	doc_177993561425_item	2252855	et	3	main
meie	doc_177993561425_item	2252858	et	4	main
mitte	doc_177993561425_item	2252869	et	3	main
on	doc_177993561425_item	2252881	et	4	main
lõbus	doc_177993561425_item	2252882	et	4	main
kui	doc_177993561425_item	2252894	et	3	main
pole	doc_177993561425_item	2252900	et	3	main
raisata	doc_177993561425_item	2252902	et	4	main
kellega	doc_177993561425_item	2252922	et	3	main
meie	doc_177993561425_item	2252936	et	4	main
käime	doc_177993561425_item	2252937	et	4	main
lõbus	doc_177993561425_item	2252948	et	4	main
nemad	doc_177993561425_item	2252950	et	3	main
meid	doc_177993561425_item	2252952	et	4	main
aitavaid	doc_177993561425_item	2252954	et	4	main
kui	doc_177993561425_item	2252956	et	3	main
nõu	doc_177993561425_item	2252961	et	4	main
üldse	doc_177993561425_item	2252963	et	3	main
on	doc_177993561425_item	2252965	et	4	main
ma	doc_177993561425_item	2252967	et	3	main
kuiuta	doc_177993561425_item	2252969	et	4	main
ilma	doc_177993561425_item	2252974	et	4	main
on	doc_177993561425_item	2252976	et	4	main
täispere	doc_177993561425_item	2252978	et	4	main
minu	doc_177993561425_item	2252988	et	3	main
elus	doc_177993561425_item	2252989	et	4	main
kaks	doc_177993561425_item	2252993	et	3	main
on	doc_177993561425_item	2253027	et	4	main
kõik	doc_177993561425_item	2253029	et	4	main
saa	doc_177993561425_item	2253038	et	4	main
ilma	doc_177993561425_item	2253040	et	4	main
kodumaa	doc_177993561425_item	2253045	et	4	main
pere	doc_177993561425_item	2253047	et	4	main
lemmik	doc_177993561425_item	2253049	et	3	main
saa	doc_177993561426_item	2253056	et	4	main
elada	doc_177993561426_item	2253058	et	3	main
milleta	doc_177993561426_item	2253060	et	3	main
töö	doc_177993561426_item	2253084	et	4	main
ajal	doc_177993561426_item	2253086	et	4	main
kiiresti	doc_177993561426_item	2253091	et	3	main
mitme	doc_177993561426_item	2253104	et	4	main
nende	doc_177993561426_item	2253106	et	4	main
ole	doc_177993561424_item	2252647	et	4	main
vaja	doc_177993561424_item	2252648	et	4	main
oodata	doc_177993561424_item	2252649	et	4	main
vestelda	doc_177993561424_item	2252657	et	4	main
mööda	doc_177993561424_item	2252661	et	4	main
väga	doc_177993561424_item	2252668	et	3	main
inimene	doc_177993561424_item	2252673	et	3	main
on	doc_177993561424_item	2252678	et	4	main
abikaasa	doc_177993561424_item	2252684	et	4	main
olemas	doc_177993561424_item	2252688	et	4	main
mina	doc_177993561424_item	2252724	et	4	main
milleta	doc_177993561425_item	2252730	et	3	main
tänapäeval	doc_177993561425_item	2252733	et	3	main
ilma	doc_177993561425_item	2252735	et	4	main
on	doc_177993561425_item	2252743	et	4	main
on	doc_177993561425_item	2252749	et	4	main
erinevad	doc_177993561425_item	2252750	et	4	main
väärtused	doc_177993561425_item	2252751	et	3	main
inimeste	doc_177993561425_item	2252757	et	3	main
väärtused	doc_177993561425_item	2252765	et	3	main
meie	doc_177993561425_item	2252768	et	4	main
tänavu	doc_177993561425_item	2252773	et	3	main
tänapäeval	doc_177993561425_item	2252821	et	3	main
palka	doc_177993561425_item	2252834	et	4	main
annab	doc_177993561425_item	2252836	et	3	main
saada	doc_177993561425_item	2252838	et	4	main
hariduse	doc_177993561425_item	2252839	et	3	main
sooja	doc_177993561425_item	2252841	et	4	main
üle	doc_177993561425_item	2252844	et	3	main
hobbiga	doc_177993561425_item	2252848	et	4	main
ajal	doc_177993561425_item	2252851	et	4	main
tänapäeval	doc_177993561425_item	2252870	et	3	main
inimene	doc_177993561425_item	2252872	et	3	main
talle	doc_177993561425_item	2252876	et	4	main
meeldib	doc_177993561425_item	2252878	et	3	main
käia	doc_177993561425_item	2252884	et	4	main
tööl	doc_177993561425_item	2252885	et	3	main
selle	doc_177993561425_item	2252889	et	4	main
on	doc_177993561425_item	2252891	et	4	main
meeldiv	doc_177993561425_item	2252892	et	4	main
jätkub	doc_177993561425_item	2252908	et	3	main
tegeleda	doc_177993561425_item	2252910	et	3	main
kui	doc_177993561425_item	2252913	et	3	main
inimene	doc_177993561425_item	2252914	et	3	main
nad	doc_177993561425_item	2252923	et	3	main
sõbrad	doc_177993561425_item	2252927	et	3	main
on	doc_177993561425_item	2252928	et	4	main
need	doc_177993561425_item	2252929	et	3	main
külas	doc_177993561425_item	2252938	et	3	main
peod	doc_177993561425_item	2252941	et	4	main
sünnipäevad	doc_177993561425_item	2252943	et	3	main
käime	doc_177993561425_item	2252944	et	4	main
sõpradega	doc_177993561425_item	2252946	et	3	main
on	doc_177993561425_item	2252958	et	4	main
ja	doc_177993561425_item	2252962	et	3	main
ei	doc_177993561425_item	2252968	et	4	main
elada	doc_177993561425_item	2252973	et	3	main
pereta	doc_177993561425_item	2252975	et	3	main
või	doc_177993561425_item	2252979	et	4	main
üksteist	doc_177993561425_item	2252985	et	4	main
on	doc_177993561425_item	2252996	et	4	main
tänapäeval	doc_177993561425_item	2253022	et	3	main
elus	doc_177993561425_item	2253028	et	4	main
et	doc_177993561425_item	2253035	et	3	main
sõbrad	doc_177993561425_item	2253048	et	3	main
töö	doc_177993561425_item	2253050	et	4	main
p	doc_177993561425_item	2253052	et	4	main
ilma	doc_177993561426_item	2253053	et	4	main
ja	doc_177993561426_item	2253077	et	3	main
muudatakse	doc_177993561426_item	2253090	et	4	main
noor	doc_177993561426_item	2253100	et	3	main
teavad	doc_177993561426_item	2253103	et	3	main
tööd	doc_177993561426_item	2253109	et	4	main
keeleoskusi	doc_177993561426_item	2253114	et	3	main
tööostjate	doc_177993561426_item	2253116	et	3	main
prooblemiks	doc_177993561426_item	2253117	et	4	main
et	doc_177993561426_item	2253120	et	3	main
keelt	doc_177993561426_item	2253126	et	4	main
teised	doc_177993561426_item	2253127	et	4	main
firmad	doc_177993561426_item	2253128	et	3	main
tahavad	doc_177993561426_item	2253129	et	3	main
inimeste	doc_177993561426_item	2253139	et	3	main
milleta	doc_177993561424_item	2252723	et	3	main
ilma	doc_177993561425_item	2252729	et	4	main
ei	doc_177993561425_item	2252737	et	4	main
ja	doc_177993561425_item	2252746	et	3	main
elame	doc_177993561425_item	2252755	et	3	main
esiteks	doc_177993561425_item	2252770	et	3	main
saa	doc_177993561425_item	2252775	et	4	main
elada	doc_177993561425_item	2252776	et	3	main
inimesed	doc_177993561425_item	2252780	et	3	main
saavad	doc_177993561425_item	2252781	et	4	main
parema	doc_177993561425_item	2252782	et	4	main
töökoha	doc_177993561425_item	2252783	et	4	main
mul	doc_177993561425_item	2252787	et	3	main
on	doc_177993561425_item	2252789	et	4	main
ma	doc_177993561425_item	2252792	et	3	main
arvan	doc_177993561425_item	2252793	et	3	main
et	doc_177993561425_item	2252794	et	3	main
palju	doc_177993561425_item	2252795	et	4	main
huvitavam	doc_177993561425_item	2252796	et	4	main
on	doc_177993561425_item	2252797	et	4	main
suhelda	doc_177993561425_item	2252798	et	4	main
ja	doc_177993561425_item	2252799	et	3	main
vestelda	doc_177993561425_item	2252800	et	4	main
haritud	doc_177993561425_item	2252801	et	4	main
inimestega	doc_177993561425_item	2252802	et	3	main
kahjuks	doc_177993561425_item	2252803	et	4	main
tänavu	doc_177993561425_item	2252804	et	3	main
haridus	doc_177993561425_item	2252805	et	3	main
on	doc_177993561425_item	2252806	et	4	main
tasuline	doc_177993561425_item	2252807	et	4	main
ja	doc_177993561425_item	2252808	et	3	main
noored	doc_177993561425_item	2252809	et	3	main
inimsed	doc_177993561425_item	2252810	et	4	main
peavad	doc_177993561425_item	2252811	et	4	main
pankast	doc_177993561425_item	2252812	et	4	main
laenu	doc_177993561425_item	2252813	et	4	main
võtma	doc_177993561425_item	2252814	et	3	main
et	doc_177993561425_item	2252815	et	3	main
omada	doc_177993561425_item	2252816	et	3	main
kõrghariduse	doc_177993561425_item	2252817	et	3	main
sellepärast	doc_177993561425_item	2252818	et	3	main
minu	doc_177993561425_item	2252819	et	3	main
arvates	doc_177993561425_item	2252820	et	4	main
kõik	doc_177993561425_item	2252830	et	4	main
võimaluse	doc_177993561425_item	2252837	et	3	main
käia	doc_177993561425_item	2252849	et	4	main
tervislikkult	doc_177993561425_item	2252854	et	4	main
kuidas	doc_177993561425_item	2252857	et	3	main
sõltub	doc_177993561425_item	2252860	et	3	main
tervis	doc_177993561425_item	2252862	et	3	main
ei	doc_177993561425_item	2252864	et	4	main
üldse	doc_177993561425_item	2252866	et	3	main
kui	doc_177993561425_item	2252871	et	3	main
nimelt	doc_177993561425_item	2252767	et	4	main
ei	doc_177993561425_item	2252774	et	4	main
suurema	doc_177993561425_item	2252785	et	4	main
iseendal	doc_177993561425_item	2252788	et	3	main
ja	doc_177993561425_item	2252791	et	3	main
ei	doc_177993561425_item	2252822	et	4	main
oleks	doc_177993561425_item	2252827	et	3	main
tore	doc_177993561425_item	2252828	et	3	main
saavad	doc_177993561425_item	2252832	et	4	main
maal	doc_177993561425_item	2252842	et	4	main
ja	doc_177993561425_item	2252843	et	3	main
tegeleda	doc_177993561425_item	2252846	et	3	main
lemmiku	doc_177993561425_item	2252847	et	3	main
kinos	doc_177993561425_item	2252852	et	3	main
toitlustasime	doc_177993561425_item	2252859	et	3	main
milleta	doc_177993561425_item	2252863	et	3	main
saa	doc_177993561425_item	2252865	et	4	main
elada	doc_177993561425_item	2252867	et	3	main
tervis	doc_177993561425_item	2252874	et	3	main
üldse	doc_177993561425_item	2252877	et	3	main
tahab	doc_177993561425_item	2252883	et	3	main
inimestega	doc_177993561425_item	2252890	et	3	main
vaja	doc_177993561425_item	2252901	et	4	main
oma	doc_177993561425_item	2252903	et	4	main
ja	doc_177993561425_item	2252906	et	3	main
hobiga	doc_177993561425_item	2252911	et	3	main
ja	doc_177993561425_item	2252912	et	3	main
mingi	doc_177993561425_item	2252916	et	4	main
tegelevad	doc_177993561425_item	2252924	et	4	main
koos	doc_177993561425_item	2252926	et	4	main
inimesed	doc_177993561425_item	2252930	et	3	main
saa	doc_177993561425_item	2252933	et	4	main
elada	doc_177993561425_item	2252935	et	3	main
jälutamas	doc_177993561425_item	2252945	et	4	main
saavad	doc_177993561425_item	2252951	et	4	main
aru	doc_177993561425_item	2252953	et	4	main
meil	doc_177993561425_item	2252957	et	4	main
annavad	doc_177993561425_item	2252960	et	3	main
nendeta	doc_177993561425_item	2252964	et	4	main
ette	doc_177993561425_item	2252970	et	4	main
kuidas	doc_177993561425_item	2252971	et	3	main
lahutatud	doc_177993561425_item	2252983	et	4	main
juba	doc_177993561425_item	2252984	et	3	main
ja	doc_177993561425_item	2252987	et	3	main
on	doc_177993561425_item	2252990	et	4	main
tähtsamat	doc_177993561425_item	2252992	et	4	main
inimest	doc_177993561425_item	2252994	et	3	main
tore	doc_177993561425_item	2253025	et	3	main
tahan	doc_177993561425_item	2253033	et	3	main
elada	doc_177993561425_item	2253039	et	3	main
ümbritseb	doc_177993561425_item	2253044	et	3	main
loodus	doc_177993561425_item	2253046	et	4	main
sugulased	doc_177993561425_item	2253051	et	3	main
ilma	doc_177993561426_item	2253059	et	4	main
veel	doc_177993561426_item	2253078	et	4	main
et	doc_177993561426_item	2253079	et	3	main
millal	doc_177993561426_item	2253080	et	3	main
olemas	doc_177993561426_item	2253083	et	4	main
elu	doc_177993561426_item	2253089	et	4	main
praegu	doc_177993561426_item	2253092	et	3	main
kergem	doc_177993561426_item	2253095	et	4	main
inimene	doc_177993561426_item	2253098	et	3	main
võrkkeelte	doc_177993561426_item	2253105	et	3	main
lihtsam	doc_177993561426_item	2253107	et	4	main
otsida	doc_177993561426_item	2253108	et	4	main
ma	doc_177993561426_item	2253112	et	3	main
panaksin	doc_177993561426_item	2253113	et	4	main
praegu	doc_177993561426_item	2253115	et	3	main
töötaja	doc_177993561426_item	2253131	et	4	main
soome	doc_177993561426_item	2253133	et	3	main
vanuse	doc_177993561426_item	2253138	et	4	main
valdavad	doc_177993561426_item	2253141	et	4	main
väga	doc_177993561426_item	2253148	et	3	main
ning	doc_177993561426_item	2253164	et	3	main
elu	doc_177993561426_item	2253166	et	4	main
ja	doc_177993561426_item	2253172	et	3	main
lõpuks	doc_177993561426_item	2253176	et	4	main
milleta	doc_177993561427_item	2253186	et	3	main
saa	doc_177993561427_item	2253188	et	4	main
ilma	doc_177993561427_item	2253191	et	4	main
elada	doc_177993561427_item	2253196	et	3	main
rahata	doc_177993561425_item	2252826	et	4	main
et	doc_177993561425_item	2252829	et	3	main
inimesed	doc_177993561425_item	2252831	et	3	main
eesti	doc_177993561425_item	2252845	et	4	main
sellest	doc_177993561425_item	2252856	et	4	main
meie	doc_177993561425_item	2252861	et	4	main
vaid	doc_177993561425_item	2252868	et	3	main
on	doc_177993561425_item	2252873	et	4	main
siis	doc_177993561425_item	2252875	et	3	main
elada	doc_177993561425_item	2252879	et	3	main
tegeleda	doc_177993561425_item	2252886	et	3	main
reisida	doc_177993561425_item	2252888	et	3	main
on	doc_177993561425_item	2252896	et	4	main
siis	doc_177993561425_item	2252898	et	3	main
ravimetele	doc_177993561425_item	2252905	et	4	main
seejärel	doc_177993561425_item	2252907	et	3	main
raha	doc_177993561425_item	2252909	et	4	main
hobiga	doc_177993561425_item	2252917	et	3	main
tegeleb	doc_177993561425_item	2252915	et	3	main
siis	doc_177993561425_item	2252918	et	3	main
tal	doc_177993561425_item	2252919	et	3	main
on	doc_177993561425_item	2252920	et	4	main
sõbrad	doc_177993561425_item	2252921	et	3	main
kelleta	doc_177993561425_item	2252931	et	3	main
ei	doc_177993561425_item	2252932	et	4	main
tänapäeval	doc_177993561425_item	2252934	et	3	main
koos	doc_177993561425_item	2252940	et	4	main
näiteks	doc_177993561425_item	2252942	et	4	main
on	doc_177993561425_item	2252947	et	4	main
suhelda	doc_177993561425_item	2252949	et	4	main
raske	doc_177993561425_item	2252959	et	4	main
igav	doc_177993561425_item	2252966	et	3	main
võib	doc_177993561425_item	2252972	et	3	main
mitte	doc_177993561425_item	2252980	et	3	main
mina	doc_177993561425_item	2252981	et	4	main
kõike	doc_177993561425_item	2252991	et	4	main
ma	doc_177993561425_item	2253021	et	3	main
ta	doc_177993561425_item	2252880	et	4	main
spordiga	doc_177993561425_item	2252887	et	3	main
suhelda	doc_177993561425_item	2252893	et	4	main
inimene	doc_177993561425_item	2252895	et	3	main
tervis	doc_177993561425_item	2252897	et	3	main
tal	doc_177993561425_item	2252899	et	3	main
raha	doc_177993561425_item	2252904	et	4	main
sellega	doc_177993561425_item	2252925	et	3	main
pidutseme	doc_177993561425_item	2252939	et	3	main
meid	doc_177993561425_item	2252955	et	4	main
see	doc_177993561425_item	2252977	et	3	main
olen	doc_177993561425_item	2252982	et	3	main
aastat	doc_177993561425_item	2252986	et	3	main
need	doc_177993561425_item	2252995	et	3	main
minu	doc_177993561425_item	2252997	et	3	main
kaks	doc_177993561425_item	2252998	et	3	main
poega	doc_177993561425_item	2252999	et	4	main
mõlemad	doc_177993561425_item	2253000	et	3	main
omandavad	doc_177993561425_item	2253001	et	4	main
haridust	doc_177993561425_item	2253002	et	4	main
õppivad	doc_177993561425_item	2253003	et	4	main
stipeendiumiga	doc_177993561425_item	2253004	et	4	main
samal	doc_177993561425_item	2253005	et	3	main
ajal	doc_177993561425_item	2253006	et	4	main
käivad	doc_177993561425_item	2253007	et	4	main
tööl	doc_177993561425_item	2253008	et	3	main
mõlemad	doc_177993561425_item	2253009	et	3	main
ei	doc_177993561425_item	2253010	et	4	main
suitseta	doc_177993561425_item	2253011	et	4	main
ma	doc_177993561425_item	2253012	et	3	main
armastan	doc_177993561425_item	2253013	et	3	main
neid	doc_177993561425_item	2253014	et	4	main
väga	doc_177993561425_item	2253015	et	3	main
ja	doc_177993561425_item	2253016	et	3	main
ilma	doc_177993561425_item	2253017	et	4	main
nendeta	doc_177993561425_item	2253018	et	4	main
saa	doc_177993561425_item	2253020	et	4	main
ei	doc_177993561425_item	2253019	et	4	main
oleks	doc_177993561425_item	2253024	et	3	main
meie	doc_177993561425_item	2253030	et	4	main
ma	doc_177993561425_item	2253032	et	3	main
ei	doc_177993561425_item	2253037	et	4	main
ei	doc_177993561426_item	2253055	et	4	main
ei	doc_177993561426_item	2253061	et	4	main
saa	doc_177993561426_item	2253062	et	4	main
on	doc_177993561426_item	2253082	et	4	main
viimasel	doc_177993561426_item	2253085	et	3	main
muidugi	doc_177993561426_item	2253087	et	4	main
meie	doc_177993561426_item	2253088	et	4	main
lihtsam	doc_177993561426_item	2253093	et	4	main
või	doc_177993561426_item	2253094	et	4	main
elada	doc_177993561426_item	2253096	et	3	main
millal	doc_177993561426_item	2253097	et	3	main
veel	doc_177993561426_item	2253099	et	4	main
praegune	doc_177993561426_item	2253101	et	3	main
teisele	doc_177993561426_item	2253110	et	4	main
see	doc_177993561426_item	2253119	et	3	main
vaid	doc_177993561426_item	2253124	et	3	main
et	doc_177993561426_item	2253130	et	3	main
teab	doc_177993561426_item	2253132	et	3	main
keskmise	doc_177993561426_item	2253137	et	3	main
rool	doc_177993561426_item	2253150	et	4	main
raskebr	doc_177993561426_item	2253161	et	4	main
õnnelik	doc_177993561426_item	2253163	et	3	main
tais	doc_177993561426_item	2253165	et	3	main
sõbradeta	doc_177993561426_item	2253171	et	4	main
elada	doc_177993561425_item	2253023	et	3	main
et	doc_177993561425_item	2253026	et	3	main
sugulased	doc_177993561425_item	2253031	et	3	main
öelda	doc_177993561425_item	2253034	et	4	main
üldiselt	doc_177993561425_item	2253036	et	4	main
selleta	doc_177993561425_item	2253041	et	3	main
mis	doc_177993561425_item	2253042	et	4	main
meid	doc_177993561425_item	2253043	et	4	main
milleta	doc_177993561426_item	2253054	et	3	main
tänapäeval	doc_177993561426_item	2253057	et	3	main
tänapäeval	doc_177993561426_item	2253063	et	3	main
elada	doc_177993561426_item	2253064	et	3	main
kõige	doc_177993561426_item	2253065	et	4	main
tähtsam	doc_177993561426_item	2253066	et	4	main
on	doc_177993561426_item	2253067	et	4	main
tervis	doc_177993561426_item	2253068	et	3	main
kui	doc_177993561426_item	2253069	et	3	main
inimene	doc_177993561426_item	2253070	et	3	main
on	doc_177993561426_item	2253071	et	4	main
terve	doc_177993561426_item	2253072	et	4	main
siis	doc_177993561426_item	2253073	et	3	main
elu	doc_177993561426_item	2253074	et	4	main
läheb	doc_177993561426_item	2253075	et	3	main
hea	doc_177993561426_item	2253076	et	4	main
temal	doc_177993561426_item	2253081	et	3	main
noored	doc_177993561426_item	2253102	et	3	main
kohale	doc_177993561426_item	2253111	et	4	main
on	doc_177993561426_item	2253118	et	4	main
osatakse	doc_177993561426_item	2253122	et	4	main
sageli	doc_177993561426_item	2253123	et	3	main
rootsi	doc_177993561426_item	2253134	et	4	main
keelte	doc_177993561426_item	2253136	et	3	main
emakeeltest	doc_177993561426_item	2253143	et	4	main
raha	doc_177993561426_item	2253144	et	4	main
ka	doc_177993561426_item	2253147	et	3	main
suur	doc_177993561426_item	2253149	et	3	main
raha	doc_177993561426_item	2253152	et	4	main
ole	doc_177993561426_item	2253154	et	4	main
või	doc_177993561426_item	2253155	et	4	main
või	doc_177993561426_item	2253168	et	4	main
olla	doc_177993561426_item	2253169	et	3	main
ei	doc_177993561427_item	2253187	et	4	main
elada	doc_177993561427_item	2253190	et	3	main
milleta	doc_177993561427_item	2253192	et	3	main
ajal	doc_177993561427_item	2253198	et	4	main
muidugi	doc_177993561427_item	2253199	et	4	main
meie	doc_177993561427_item	2253200	et	4	main
elu	doc_177993561427_item	2253201	et	4	main
muutakse	doc_177993561427_item	2253202	et	3	main
kiiresti	doc_177993561427_item	2253203	et	3	main
käesoleval	doc_177993561427_item	2253204	et	3	main
ajal	doc_177993561427_item	2253205	et	4	main
me	doc_177993561427_item	2253206	et	4	main
elame	doc_177993561427_item	2253207	et	3	main
mitte	doc_177993561427_item	2253208	et	3	main
ainult	doc_177993561427_item	2253209	et	4	main
eesti	doc_177993561427_item	2253210	et	4	main
vabariigis	doc_177993561427_item	2253211	et	3	main
aga	doc_177993561427_item	2253212	et	3	main
euroliidus	doc_177993561427_item	2253213	et	4	main
ka	doc_177993561427_item	2253214	et	3	main
see	doc_177993561427_item	2253215	et	3	main
annab	doc_177993561427_item	2253216	et	3	main
tõenäolisi	doc_177993561427_item	2253218	et	4	main
võimalusi	doc_177993561427_item	2253219	et	3	main
meile	doc_177993561427_item	2253217	et	4	main
aga	doc_177993561427_item	2253220	et	3	main
samamoodi	doc_177993561427_item	2253221	et	3	main
inimene	doc_177993561427_item	2253227	et	3	main
hästi	doc_177993561427_item	2253229	et	3	main
ning	doc_177993561427_item	2253231	et	3	main
teenida	doc_177993561427_item	2253243	et	3	main
ei	doc_177993561427_item	2253247	et	4	main
ole	doc_177993561427_item	2253248	et	4	main
jaoks	doc_177993561427_item	2253259	et	4	main
juba	doc_177993561427_item	2253269	et	3	main
sellest	doc_177993561427_item	2253276	et	4	main
pole	doc_177993561427_item	2253280	et	3	main
ilma	doc_177993561427_item	2253285	et	4	main
saa	doc_177993561427_item	2253288	et	4	main
kuna	doc_177993561427_item	2253295	et	3	main
ei	doc_177993561427_item	2253298	et	4	main
saa	doc_177993561427_item	2253299	et	4	main
elada	doc_177993561427_item	2253300	et	3	main
siis	doc_177993561427_item	2253301	et	3	main
õppida	doc_177993561427_item	2253303	et	3	main
vajalik	doc_177993561427_item	2253322	et	3	main
inglisekeel	doc_177993561427_item	2253326	et	4	main
võõrkeeltest	doc_177993561426_item	2253121	et	4	main
inglise	doc_177993561426_item	2253125	et	4	main
saksa	doc_177993561426_item	2253135	et	4	main
ei	doc_177993561426_item	2253153	et	4	main
siis	doc_177993561426_item	2253157	et	3	main
ka	doc_177993561426_item	2253159	et	3	main
muidugi	doc_177993561426_item	2253162	et	4	main
ilma	doc_177993561426_item	2253170	et	4	main
ilma	doc_177993561426_item	2253173	et	4	main
pereta	doc_177993561426_item	2253175	et	3	main
tahaksin	doc_177993561426_item	2253177	et	3	main
lisada	doc_177993561426_item	2253178	et	3	main
veel	doc_177993561426_item	2253179	et	4	main
et	doc_177993561426_item	2253180	et	3	main
vaja	doc_177993561426_item	2253182	et	4	main
rõõmustada	doc_177993561426_item	2253183	et	3	main
elude	doc_177993561426_item	2253184	et	3	main
saa	doc_177993561427_item	2253194	et	4	main
tõstetatud	doc_177993561427_item	2253225	et	4	main
ta	doc_177993561427_item	2253235	et	4	main
raha	doc_177993561427_item	2253242	et	4	main
töö	doc_177993561427_item	2253246	et	4	main
et	doc_177993561427_item	2253260	et	3	main
rahalist	doc_177993561427_item	2253264	et	4	main
tuleb	doc_177993561427_item	2253266	et	3	main
on	doc_177993561427_item	2253270	et	4	main
aga	doc_177993561427_item	2253272	et	3	main
arvan	doc_177993561427_item	2253274	et	3	main
vähe	doc_177993561427_item	2253279	et	3	main
ennast	doc_177993561427_item	2253290	et	4	main
tuleb	doc_177993561427_item	2253293	et	3	main
on	doc_177993561427_item	2253321	et	4	main
kindlasti	doc_177993561427_item	2253330	et	3	main
haridus	doc_177993561427_item	2253332	et	3	main
siis	doc_177993561427_item	2253343	et	3	main
ma	doc_177993561427_item	2253350	et	3	main
näe	doc_177993561427_item	2253355	et	4	main
täiskasvanu	doc_177993561427_item	2253362	et	4	main
oleks	doc_177993561427_item	2253369	et	3	main
elu	doc_177993561427_item	2253378	et	4	main
hoidma	doc_177993561427_item	2253411	et	3	main
tänapäeval	doc_177993561428_item	2253418	et	3	main
tänapäeval	doc_177993561428_item	2253420	et	3	main
kui	doc_177993561428_item	2253427	et	3	main
tööd	doc_177993561428_item	2253430	et	4	main
ole	doc_177993561428_item	2253433	et	4	main
tänapäeva	doc_177993561428_item	2253436	et	4	main
eest	doc_177993561428_item	2253441	et	4	main
on	doc_177993561428_item	2253442	et	4	main
kaks	doc_177993561428_item	2253455	et	3	main
instituudis	doc_177993561428_item	2253464	et	3	main
olen	doc_177993561428_item	2253468	et	3	main
riideid	doc_177993561428_item	2253475	et	3	main
teha	doc_177993561428_item	2253476	et	3	main
lastele	doc_177993561428_item	2253478	et	4	main
mõnikord	doc_177993561428_item	2253480	et	3	main
minu	doc_177993561428_item	2253485	et	3	main
peab	doc_177993561428_item	2253488	et	4	main
inimesi	doc_177993561428_item	2253494	et	4	main
haridus	doc_177993561428_item	2253499	et	3	main
väga	doc_177993561428_item	2253501	et	3	main
tänapäeval	doc_177993561428_item	2253508	et	3	main
kes	doc_177993561428_item	2253511	et	4	main
sul	doc_177993561428_item	2253520	et	3	main
kergem	doc_177993561428_item	2253525	et	4	main
minu	doc_177993561428_item	2253538	et	3	main
suur	doc_177993561428_item	2253540	et	3	main
palju	doc_177993561428_item	2253552	et	4	main
tänapäeval	doc_177993561429_item	2253557	et	3	main
ei	doc_177993561429_item	2253561	et	4	main
on	doc_177993561429_item	2253566	et	4	main
elu	doc_177993561429_item	2253568	et	4	main
hästi	doc_177993561429_item	2253576	et	3	main
rahata	doc_177993561429_item	2253583	et	4	main
saa	doc_177993561429_item	2253585	et	4	main
otsida	doc_177993561429_item	2253595	et	4	main
tervise	doc_177993561429_item	2253612	et	3	main
ilma	doc_177993561429_item	2253614	et	4	main
kui	doc_177993561429_item	2253620	et	3	main
iga	doc_177993561429_item	2253631	et	4	main
vaja	doc_177993561429_item	2253634	et	4	main
lugeda	doc_177993561429_item	2253635	et	3	main
tihti	doc_177993561426_item	2253140	et	3	main
ainult	doc_177993561426_item	2253142	et	4	main
mängib	doc_177993561426_item	2253145	et	3	main
elus	doc_177993561426_item	2253146	et	4	main
kui	doc_177993561426_item	2253151	et	3	main
väha	doc_177993561426_item	2253156	et	4	main
elada	doc_177993561426_item	2253158	et	3	main
väga	doc_177993561426_item	2253160	et	3	main
ei	doc_177993561426_item	2253167	et	4	main
hea	doc_177993561426_item	2253174	et	4	main
on	doc_177993561426_item	2253181	et	4	main
tänapäeval	doc_177993561427_item	2253189	et	3	main
tänapäeval	doc_177993561427_item	2253195	et	3	main
ka	doc_177993561427_item	2253224	et	3	main
tahab	doc_177993561427_item	2253228	et	3	main
rõõmsalt	doc_177993561427_item	2253232	et	4	main
siis	doc_177993561427_item	2253234	et	3	main
aga	doc_177993561427_item	2253244	et	3	main
rahul	doc_177993561427_item	2253257	et	4	main
selle	doc_177993561427_item	2253258	et	4	main
ning	doc_177993561427_item	2253263	et	3	main
õppida	doc_177993561427_item	2253267	et	3	main
on	doc_177993561427_item	2253277	et	4	main
piisav	doc_177993561427_item	2253281	et	4	main
et	doc_177993561427_item	2253284	et	3	main
ja	doc_177993561427_item	2253291	et	3	main
pidevalt	doc_177993561427_item	2253294	et	4	main
tuleb	doc_177993561427_item	2253302	et	3	main
ja	doc_177993561427_item	2253329	et	3	main
kindlasti	doc_177993561427_item	2253335	et	3	main
kui	doc_177993561427_item	2253337	et	3	main
meil	doc_177993561427_item	2253339	et	4	main
olen	doc_177993561427_item	2253351	et	3	main
mind	doc_177993561427_item	2253356	et	4	main
mul	doc_177993561427_item	2253360	et	3	main
ma	doc_177993561427_item	2253365	et	3	main
haritud	doc_177993561427_item	2253370	et	4	main
täis	doc_177993561427_item	2253377	et	4	main
ei	doc_177993561427_item	2253379	et	4	main
p	doc_177993561427_item	2253412	et	4	main
ilma	doc_177993561428_item	2253413	et	4	main
milleta	doc_177993561428_item	2253414	et	3	main
ei	doc_177993561428_item	2253415	et	4	main
ei	doc_177993561428_item	2253421	et	4	main
elada	doc_177993561428_item	2253423	et	3	main
ilma	doc_177993561428_item	2253424	et	4	main
sest	doc_177993561428_item	2253426	et	4	main
tänu	doc_177993561428_item	2253445	et	4	main
mul	doc_177993561428_item	2253448	et	3	main
võimalus	doc_177993561428_item	2253453	et	3	main
haridus	doc_177993561428_item	2253459	et	3	main
kuna	doc_177993561428_item	2253460	et	3	main
minu	doc_177993561428_item	2253461	et	3	main
õpib	doc_177993561428_item	2253463	et	3	main
haritud	doc_177993561428_item	2253490	et	4	main
kõike	doc_177993561428_item	2253493	et	4	main
võimelised	doc_177993561428_item	2253495	et	4	main
saada	doc_177993561428_item	2253496	et	4	main
hariduse	doc_177993561428_item	2253498	et	3	main
parema	doc_177993561428_item	2253506	et	4	main
väga	doc_177993561428_item	2253509	et	3	main
ja	doc_177993561428_item	2253517	et	3	main
ilma	doc_177993561427_item	2253185	et	4	main
ei	doc_177993561427_item	2253193	et	4	main
viimasel	doc_177993561427_item	2253197	et	3	main
nõudmisi	doc_177993561427_item	2253223	et	4	main
puhata	doc_177993561427_item	2253233	et	4	main
töötama	doc_177993561427_item	2253237	et	3	main
töö	doc_177993561427_item	2253238	et	4	main
annab	doc_177993561427_item	2253239	et	3	main
meile	doc_177993561427_item	2253240	et	4	main
kui	doc_177993561427_item	2253245	et	3	main
inimene	doc_177993561427_item	2253251	et	3	main
saa	doc_177993561427_item	2253253	et	4	main
olla	doc_177993561427_item	2253254	et	3	main
eluga	doc_177993561427_item	2253256	et	3	main
omama	doc_177993561427_item	2253261	et	4	main
kõrgharidus	doc_177993561427_item	2253271	et	3	main
ma	doc_177993561427_item	2253273	et	3	main
et	doc_177993561427_item	2253275	et	3	main
minu	doc_177993561427_item	2253282	et	3	main
ei	doc_177993561427_item	2253287	et	4	main
arendada	doc_177993561427_item	2253289	et	3	main
õppida	doc_177993561427_item	2253292	et	3	main
tööta	doc_177993561427_item	2253297	et	4	main
on	doc_177993561427_item	2253222	et	4	main
kui	doc_177993561427_item	2253226	et	3	main
elada	doc_177993561427_item	2253230	et	3	main
peab	doc_177993561427_item	2253236	et	4	main
võimalus	doc_177993561427_item	2253241	et	3	main
huvitav	doc_177993561427_item	2253249	et	4	main
siis	doc_177993561427_item	2253250	et	3	main
ei	doc_177993561427_item	2253252	et	4	main
oma	doc_177993561427_item	2253255	et	4	main
huvitavat	doc_177993561427_item	2253262	et	4	main
tööd	doc_177993561427_item	2253265	et	4	main
mul	doc_177993561427_item	2253268	et	3	main
liga	doc_177993561427_item	2253278	et	4	main
arvamus	doc_177993561427_item	2253283	et	3	main
õppimist	doc_177993561427_item	2253286	et	4	main
ilma	doc_177993561427_item	2253296	et	4	main
käesoleval	doc_177993561427_item	2253304	et	3	main
ajal	doc_177993561427_item	2253305	et	4	main
meie	doc_177993561427_item	2253306	et	4	main
riigi	doc_177993561427_item	2253307	et	3	main
piired	doc_177993561427_item	2253308	et	4	main
on	doc_177993561427_item	2253309	et	4	main
avatud	doc_177993561427_item	2253310	et	4	main
ning	doc_177993561427_item	2253311	et	3	main
on	doc_177993561427_item	2253312	et	4	main
kõik	doc_177993561427_item	2253313	et	4	main
võimalusi	doc_177993561427_item	2253314	et	3	main
reisida	doc_177993561427_item	2253315	et	3	main
ja	doc_177993561427_item	2253316	et	3	main
elada	doc_177993561427_item	2253317	et	3	main
spansuhtlemise	doc_177993561427_item	2253319	et	4	main
jaoks	doc_177993561427_item	2253320	et	4	main
huvitavamspan	doc_177993561427_item	2253318	et	4	main
keelde	doc_177993561427_item	2253323	et	4	main
näiteks	doc_177993561427_item	2253325	et	4	main
huvitavam	doc_177993561427_item	2253346	et	4	main
elamebr	doc_177993561427_item	2253348	et	4	main
ma	doc_177993561427_item	2253353	et	3	main
ilma	doc_177993561427_item	2253357	et	4	main
pereta	doc_177993561427_item	2253359	et	3	main
on	doc_177993561427_item	2253361	et	4	main
et	doc_177993561427_item	2253367	et	3	main
mees	doc_177993561427_item	2253372	et	4	main
muidugi	doc_177993561427_item	2253374	et	4	main
teadmisi	doc_177993561427_item	2253324	et	4	main
on	doc_177993561427_item	2253333	et	4	main
meile	doc_177993561427_item	2253334	et	4	main
vajalik	doc_177993561427_item	2253336	et	3	main
ja	doc_177993561427_item	2253345	et	3	main
naine	doc_177993561427_item	2253352	et	3	main
minu	doc_177993561427_item	2253358	et	3	main
tahaksin	doc_177993561427_item	2253366	et	3	main
huvitav	doc_177993561427_item	2253371	et	4	main
tulevikus	doc_177993561427_item	2253373	et	4	main
õnnelik	doc_177993561427_item	2253375	et	3	main
või	doc_177993561427_item	2253380	et	4	main
olla	doc_177993561427_item	2253381	et	3	main
ilma	doc_177993561427_item	2253382	et	4	main
terviseta	doc_177993561427_item	2253383	et	3	main
selle	doc_177993561427_item	2253384	et	4	main
jäoks	doc_177993561427_item	2253385	et	4	main
tuleb	doc_177993561427_item	2253386	et	3	main
spordiga	doc_177993561427_item	2253387	et	3	main
koos	doc_177993561427_item	2253389	et	4	main
tegeleda	doc_177993561427_item	2253388	et	3	main
oma	doc_177993561427_item	2253390	et	4	main
perega	doc_177993561427_item	2253391	et	3	main
tihti	doc_177993561427_item	2253392	et	3	main
me	doc_177993561427_item	2253393	et	4	main
puhkame	doc_177993561427_item	2253394	et	3	main
looduses	doc_177993561427_item	2253395	et	4	main
värskes	doc_177993561427_item	2253397	et	4	main
jalutame	doc_177993561427_item	2253396	et	3	main
õhkus	doc_177993561427_item	2253398	et	3	main
ujume	doc_177993561427_item	2253399	et	3	main
meres	doc_177993561427_item	2253400	et	3	main
eestis	doc_177993561427_item	2253401	et	3	main
väga	doc_177993561427_item	2253402	et	3	main
ilus	doc_177993561427_item	2253403	et	4	main
loodus	doc_177993561427_item	2253404	et	4	main
eriti	doc_177993561427_item	2253405	et	3	main
saartel	doc_177993561427_item	2253406	et	3	main
ning	doc_177993561427_item	2253407	et	3	main
tuleb	doc_177993561427_item	2253408	et	3	main
teda	doc_177993561427_item	2253409	et	4	main
saksakeel	doc_177993561427_item	2253327	et	4	main
soomekeel	doc_177993561427_item	2253328	et	4	main
eestikeel	doc_177993561427_item	2253331	et	4	main
rohkem	doc_177993561427_item	2253338	et	4	main
teadmisi	doc_177993561427_item	2253340	et	4	main
oskusi	doc_177993561427_item	2253341	et	3	main
kogemusi	doc_177993561427_item	2253342	et	3	main
parem	doc_177993561427_item	2253344	et	4	main
me	doc_177993561427_item	2253347	et	4	main
kuna	doc_177993561427_item	2253349	et	3	main
ei	doc_177993561427_item	2253354	et	4	main
poeg	doc_177993561427_item	2253363	et	3	main
ja	doc_177993561427_item	2253364	et	3	main
ta	doc_177993561427_item	2253368	et	4	main
ning	doc_177993561427_item	2253376	et	3	main
inimene	doc_177993561428_item	2253417	et	3	main
elada	doc_177993561428_item	2253419	et	3	main
saa	doc_177993561428_item	2253422	et	4	main
ole	doc_177993561428_item	2253429	et	4	main
siis	doc_177993561428_item	2253431	et	3	main
raha	doc_177993561428_item	2253435	et	4	main
elu	doc_177993561428_item	2253437	et	4	main
on	doc_177993561428_item	2253438	et	4	main
kõige	doc_177993561428_item	2253440	et	4	main
sellele	doc_177993561428_item	2253446	et	4	main
on	doc_177993561428_item	2253449	et	4	main
mul	doc_177993561428_item	2253451	et	3	main
anda	doc_177993561428_item	2253457	et	3	main
tütar	doc_177993561428_item	2253462	et	3	main
võimeline	doc_177993561428_item	2253469	et	4	main
korteri	doc_177993561428_item	2253471	et	3	main
eest	doc_177993561428_item	2253473	et	4	main
või	doc_177993561428_item	2253483	et	4	main
inimene	doc_177993561428_item	2253487	et	3	main
kuid	doc_177993561428_item	2253491	et	4	main
head	doc_177993561428_item	2253497	et	4	main
inimene	doc_177993561428_item	2253504	et	3	main
millised	doc_177993561428_item	2253514	et	3	main
siis	doc_177993561428_item	2253524	et	3	main
sõprade	doc_177993561428_item	2253527	et	3	main
alati	doc_177993561428_item	2253529	et	4	main
probleeme	doc_177993561428_item	2253533	et	3	main
leida	doc_177993561428_item	2253535	et	3	main
otsustbr	doc_177993561428_item	2253537	et	4	main
armastuse	doc_177993561428_item	2253543	et	4	main
ei	doc_177993561428_item	2253549	et	4	main
ole	doc_177993561428_item	2253550	et	4	main
nii	doc_177993561428_item	2253551	et	3	main
saa	doc_177993561429_item	2253556	et	4	main
milleta	doc_177993561429_item	2253560	et	3	main
praigu	doc_177993561429_item	2253565	et	4	main
raha	doc_177993561429_item	2253573	et	4	main
ma	doc_177993561429_item	2253579	et	3	main
arvan	doc_177993561429_item	2253580	et	3	main
ei	doc_177993561429_item	2253584	et	4	main
tänapäeval	doc_177993561429_item	2253586	et	3	main
ole	doc_177993561429_item	2253590	et	4	main
sis	doc_177993561429_item	2253592	et	3	main
esiteks	doc_177993561429_item	2253598	et	3	main
et	doc_177993561429_item	2253604	et	3	main
millega	doc_177993561429_item	2253609	et	3	main
ei	doc_177993561429_item	2253616	et	4	main
saa	doc_177993561429_item	2253617	et	4	main
elada	doc_177993561429_item	2253619	et	3	main
sõbrad	doc_177993561429_item	2253621	et	3	main
sis	doc_177993561429_item	2253623	et	3	main
rohkem	doc_177993561429_item	2253624	et	4	main
midagi	doc_177993561429_item	2253626	et	4	main
et	doc_177993561429_item	2253630	et	3	main
vaadata	doc_177993561429_item	2253638	et	4	main
auto	doc_177993561429_item	2253650	et	4	main
minu	doc_177993561429_item	2253654	et	3	main
nii	doc_177993561429_item	2253657	et	3	main
kõik	doc_177993561429_item	2253659	et	4	main
oma	doc_177993561429_item	2253666	et	4	main
saa	doc_177993561430_item	2253700	et	4	main
valdab	doc_177993561430_item	2253711	et	3	main
või	doc_177993561430_item	2253713	et	4	main
ja	doc_177993561430_item	2253716	et	3	main
aegsel	doc_177993561430_item	2253724	et	3	main
kus	doc_177993561430_item	2253725	et	3	main
ja	doc_177993561430_item	2253734	et	3	main
aitab	doc_177993561430_item	2253742	et	3	main
eriti	doc_177993561427_item	2253410	et	3	main
saa	doc_177993561428_item	2253416	et	4	main
ei	doc_177993561428_item	2253428	et	4	main
ei	doc_177993561428_item	2253432	et	4	main
ka	doc_177993561428_item	2253434	et	3	main
et	doc_177993561428_item	2253447	et	3	main
on	doc_177993561428_item	2253452	et	4	main
last	doc_177993561428_item	2253456	et	4	main
nendele	doc_177993561428_item	2253458	et	4	main
osakonnas	doc_177993561428_item	2253466	et	4	main
maksta	doc_177993561428_item	2253470	et	4	main
kinno	doc_177993561428_item	2253484	et	3	main
arvates	doc_177993561428_item	2253486	et	4	main
mitte	doc_177993561428_item	2253492	et	3	main
töökoha	doc_177993561428_item	2253507	et	4	main
ümbritseb	doc_177993561428_item	2253513	et	3	main
tuttavad	doc_177993561428_item	2253516	et	4	main
sõbrad	doc_177993561428_item	2253518	et	3	main
on	doc_177993561428_item	2253521	et	4	main
elada	doc_177993561428_item	2253526	et	3	main
oma	doc_177993561428_item	2253532	et	4	main
ja	doc_177993561428_item	2253534	et	3	main
milleta	doc_177993561429_item	2253554	et	3	main
ilma	doc_177993561429_item	2253559	et	4	main
saa	doc_177993561429_item	2253562	et	4	main
kellel	doc_177993561429_item	2253569	et	4	main
tööd	doc_177993561429_item	2253571	et	4	main
neid	doc_177993561429_item	2253574	et	4	main
selle	doc_177993561429_item	2253577	et	4	main
ilma	doc_177993561429_item	2253582	et	4	main
kui	doc_177993561429_item	2253588	et	3	main
haridus	doc_177993561429_item	2253591	et	3	main
ka	doc_177993561429_item	2253593	et	3	main
aga	doc_177993561429_item	2253597	et	3	main
vaja	doc_177993561429_item	2253600	et	4	main
hoia	doc_177993561429_item	2253603	et	4	main
rahat	doc_177993561429_item	2253608	et	4	main
võib	doc_177993561429_item	2253610	et	3	main
osta	doc_177993561429_item	2253613	et	4	main
sõpradeta	doc_177993561429_item	2253615	et	3	main
päev	doc_177993561429_item	2253632	et	3	main
telerit	doc_177993561429_item	2253639	et	3	main
uudisedabr	doc_177993561429_item	2253642	et	4	main
kujuta	doc_177993561429_item	2253645	et	4	main
oma	doc_177993561429_item	2253647	et	4	main
tee	doc_177993561429_item	2253665	et	4	main
autoga	doc_177993561429_item	2253667	et	3	main
iga	doc_177993561429_item	2253668	et	4	main
inimene	doc_177993561429_item	2253669	et	3	main
ilma	doc_177993561430_item	2253691	et	4	main
ei	doc_177993561430_item	2253693	et	4	main
saa	doc_177993561430_item	2253694	et	4	main
tänapäeval	doc_177993561430_item	2253695	et	3	main
elada	doc_177993561430_item	2253696	et	3	main
ilma	doc_177993561430_item	2253697	et	4	main
milleta	doc_177993561430_item	2253698	et	3	main
intensiivne	doc_177993561430_item	2253707	et	3	main
sain	doc_177993561430_item	2253717	et	3	main
haridus	doc_177993561430_item	2253719	et	3	main
paremine	doc_177993561430_item	2253721	et	4	main
elame	doc_177993561430_item	2253723	et	3	main
on	doc_177993561430_item	2253727	et	4	main
sellega	doc_177993561430_item	2253730	et	3	main
arvuti	doc_177993561430_item	2253736	et	4	main
praegu	doc_177993561430_item	2253738	et	3	main
ettevõtted	doc_177993561430_item	2253740	et	3	main
praegu	doc_177993561430_item	2253760	et	3	main
kirju	doc_177993561430_item	2253763	et	4	main
kui	doc_177993561430_item	2253770	et	3	main
kohe	doc_177993561430_item	2253775	et	4	main
me	doc_177993561430_item	2253783	et	4	main
kolm	doc_177993561430_item	2253788	et	3	main
nädalat	doc_177993561430_item	2253789	et	3	main
arvutioperaatorina	doc_177993561430_item	2253793	et	3	main
ja	doc_177993561430_item	2253794	et	3	main
reisida	doc_177993561430_item	2253821	et	3	main
mida	doc_177993561430_item	2253837	et	4	main
sööme	doc_177993561430_item	2253839	et	4	main
värske	doc_177993561430_item	2253840	et	4	main
või	doc_177993561430_item	2253841	et	4	main
tervis	doc_177993561430_item	2253845	et	3	main
sõltub	doc_177993561430_item	2253847	et	3	main
tööd	doc_177993561428_item	2253425	et	4	main
kallis	doc_177993561428_item	2253439	et	4	main
vaja	doc_177993561428_item	2253443	et	4	main
maksta	doc_177993561428_item	2253444	et	4	main
töö	doc_177993561428_item	2253450	et	4	main
toetada	doc_177993561428_item	2253454	et	3	main
tasulise	doc_177993561428_item	2253465	et	4	main
ma	doc_177993561428_item	2253467	et	3	main
üüri	doc_177993561428_item	2253472	et	4	main
osta	doc_177993561428_item	2253474	et	4	main
süüa	doc_177993561428_item	2253477	et	3	main
samuti	doc_177993561428_item	2253479	et	3	main
käia	doc_177993561428_item	2253481	et	4	main
teatrisse	doc_177993561428_item	2253482	et	3	main
olema	doc_177993561428_item	2253489	et	4	main
on	doc_177993561428_item	2253500	et	4	main
tähtis	doc_177993561428_item	2253502	et	4	main
haritud	doc_177993561428_item	2253503	et	4	main
saab	doc_177993561428_item	2253505	et	3	main
tähtis	doc_177993561428_item	2253510	et	4	main
sind	doc_177993561428_item	2253512	et	4	main
sul	doc_177993561428_item	2253515	et	3	main
kui	doc_177993561428_item	2253519	et	3	main
sõbrad	doc_177993561428_item	2253523	et	3	main
võib	doc_177993561428_item	2253530	et	3	main
meelest	doc_177993561428_item	2253539	et	4	main
kui	doc_177993561428_item	2253544	et	3	main
armastus	doc_177993561428_item	2253546	et	4	main
siis	doc_177993561428_item	2253547	et	3	main
probleeme	doc_177993561428_item	2253548	et	3	main
ilma	doc_177993561429_item	2253553	et	4	main
tänapäeval	doc_177993561429_item	2253563	et	3	main
on	doc_177993561429_item	2253570	et	4	main
ja	doc_177993561429_item	2253572	et	3	main
et	doc_177993561429_item	2253581	et	3	main
ei	doc_177993561429_item	2253589	et	4	main
raske	doc_177993561429_item	2253594	et	4	main
nisuguset	doc_177993561429_item	2253607	et	4	main
oma	doc_177993561429_item	2253611	et	4	main
head	doc_177993561428_item	2253522	et	4	main
ringis	doc_177993561428_item	2253528	et	4	main
arutada	doc_177993561428_item	2253531	et	3	main
mingit	doc_177993561428_item	2253536	et	3	main
tähendus	doc_177993561428_item	2253541	et	4	main
kuulub	doc_177993561428_item	2253542	et	3	main
on	doc_177993561428_item	2253545	et	4	main
ei	doc_177993561429_item	2253555	et	4	main
elada	doc_177993561429_item	2253558	et	3	main
elada	doc_177993561429_item	2253564	et	3	main
lõbus	doc_177993561429_item	2253567	et	4	main
elavad	doc_177993561429_item	2253575	et	4	main
pärast	doc_177993561429_item	2253578	et	4	main
elada	doc_177993561429_item	2253587	et	3	main
tööd	doc_177993561429_item	2253596	et	4	main
on	doc_177993561429_item	2253599	et	4	main
oma	doc_177993561429_item	2253601	et	4	main
tervise	doc_177993561429_item	2253602	et	3	main
ei	doc_177993561429_item	2253605	et	4	main
ole	doc_177993561429_item	2253606	et	4	main
tänapäeval	doc_177993561429_item	2253618	et	3	main
võimaliku	doc_177993561429_item	2253625	et	3	main
ma	doc_177993561429_item	2253628	et	3	main
arvan	doc_177993561429_item	2253629	et	3	main
on	doc_177993561429_item	2253633	et	4	main
hädavajaliku	doc_177993561429_item	2253640	et	3	main
on	doc_177993561429_item	2253651	et	4	main
jalad	doc_177993561429_item	2253653	et	3	main
elada	doc_177993561429_item	2253690	et	3	main
ei	doc_177993561430_item	2253699	et	4	main
kõrg	doc_177993561430_item	2253718	et	4	main
elada	doc_177993561430_item	2253720	et	3	main
me	doc_177993561430_item	2253722	et	4	main
vaja	doc_177993561430_item	2253731	et	4	main
teha	doc_177993561430_item	2253744	et	3	main
suheldada	doc_177993561430_item	2253746	et	4	main
teist	doc_177993561430_item	2253747	et	4	main
ettevõttest	doc_177993561430_item	2253748	et	4	main
raamatupidajat	doc_177993561430_item	2253753	et	3	main
politsei	doc_177993561430_item	2253754	et	4	main
palju	doc_177993561430_item	2253757	et	4	main
ettevõtteid	doc_177993561430_item	2253759	et	3	main
aadressi	doc_177993561430_item	2253768	et	4	main
palju	doc_177993561430_item	2253780	et	4	main
ootame	doc_177993561430_item	2253784	et	3	main
kaks	doc_177993561430_item	2253786	et	3	main
suheldab	doc_177993561430_item	2253795	et	4	main
on	doc_177993561429_item	2253622	et	4	main
teada	doc_177993561429_item	2253627	et	3	main
ajalehed	doc_177993561429_item	2253636	et	3	main
või	doc_177993561429_item	2253637	et	4	main
ei	doc_177993561429_item	2253644	et	4	main
elu	doc_177993561429_item	2253648	et	4	main
autodeta	doc_177993561429_item	2253649	et	3	main
ja	doc_177993561429_item	2253656	et	3	main
mis	doc_177993561429_item	2253660	et	4	main
ma	doc_177993561429_item	2253661	et	3	main
jõuan	doc_177993561429_item	2253662	et	3	main
iga	doc_177993561429_item	2253671	et	4	main
tahab	doc_177993561429_item	2253670	et	3	main
päev	doc_177993561429_item	2253672	et	3	main
söema	doc_177993561429_item	2253673	et	4	main
sellepärast	doc_177993561429_item	2253674	et	3	main
ilma	doc_177993561429_item	2253675	et	4	main
toiduainedeta	doc_177993561429_item	2253676	et	4	main
ka	doc_177993561429_item	2253677	et	3	main
ei	doc_177993561429_item	2253678	et	4	main
sa	doc_177993561429_item	2253679	et	3	main
elada	doc_177993561429_item	2253680	et	3	main
ja	doc_177993561429_item	2253681	et	3	main
palju	doc_177993561429_item	2253682	et	4	main
veel	doc_177993561429_item	2253683	et	4	main
asjad	doc_177993561429_item	2253685	et	3	main
millega	doc_177993561429_item	2253686	et	3	main
ei	doc_177993561429_item	2253687	et	4	main
saa	doc_177993561429_item	2253688	et	4	main
muud	doc_177993561429_item	2253684	et	4	main
tänapäeval	doc_177993561429_item	2253689	et	3	main
jalgida	doc_177993561429_item	2253641	et	4	main
mina	doc_177993561429_item	2253643	et	4	main
ette	doc_177993561429_item	2253646	et	4	main
minu	doc_177993561429_item	2253652	et	3	main
käed	doc_177993561429_item	2253655	et	3	main
edasi	doc_177993561429_item	2253658	et	3	main
teha	doc_177993561429_item	2253663	et	3	main
ma	doc_177993561429_item	2253664	et	3	main
elada	doc_177993561430_item	2253702	et	3	main
tänapäeva	doc_177993561430_item	2253703	et	4	main
on	doc_177993561430_item	2253705	et	4	main
väga	doc_177993561430_item	2253706	et	3	main
ja	doc_177993561430_item	2253708	et	3	main
kolm	doc_177993561430_item	2253714	et	3	main
keelega	doc_177993561430_item	2253715	et	3	main
koguaeg	doc_177993561430_item	2253732	et	3	main
iga	doc_177993561430_item	2253739	et	4	main
tööd	doc_177993561430_item	2253743	et	4	main
kiiremine	doc_177993561430_item	2253745	et	4	main
ehitus	doc_177993561430_item	2253751	et	4	main
ja	doc_177993561430_item	2253756	et	3	main
saadeti	doc_177993561430_item	2253766	et	3	main
sain	doc_177993561430_item	2253773	et	3	main
tagasi	doc_177993561430_item	2253782	et	3	main
oskab	doc_177993561430_item	2253823	et	3	main
hoiab	doc_177993561430_item	2253826	et	3	main
aega	doc_177993561430_item	2253828	et	4	main
teine	doc_177993561430_item	2253829	et	3	main
ostavad	doc_177993561430_item	2253851	et	3	main
supermarketis	doc_177993561430_item	2253853	et	4	main
osta	doc_177993561430_item	2253872	et	4	main
juurvilju	doc_177993561430_item	2253874	et	3	main
perenaine	doc_177993561430_item	2253880	et	3	main
võttab	doc_177993561430_item	2253881	et	4	main
valmistab	doc_177993561430_item	2253893	et	3	main
kodust	doc_177993561430_item	2253895	et	4	main
ilma	doc_177993561431_item	2253903	et	4	main
asjast	doc_177993561431_item	2253917	et	4	main
see	doc_177993561431_item	2253919	et	3	main
töö	doc_177993561431_item	2253927	et	4	main
kui	doc_177993561431_item	2253928	et	3	main
hea	doc_177993561431_item	2253932	et	4	main
siis	doc_177993561431_item	2253933	et	3	main
teiseks	doc_177993561431_item	2253946	et	4	main
saa	doc_177993561431_item	2253948	et	4	main
elada	doc_177993561431_item	2253949	et	3	main
armastuseta	doc_177993561431_item	2253952	et	4	main
on	doc_177993561431_item	2253955	et	4	main
raske	doc_177993561431_item	2253962	et	4	main
pere	doc_177993561431_item	2253966	et	4	main
rahuldust	doc_177993561431_item	2253969	et	4	main
on	doc_177993561431_item	2253972	et	4	main
ja	doc_177993561431_item	2253974	et	3	main
siis	doc_177993561431_item	2253976	et	3	main
on	doc_177993561431_item	2253982	et	4	main
töötada	doc_177993561431_item	2253984	et	3	main
areneda	doc_177993561431_item	2253987	et	3	main
te	doc_177993561431_item	2253993	et	4	main
kõik	doc_177993561431_item	2253995	et	4	main
milleta	doc_177993561430_item	2253692	et	3	main
tänapäeval	doc_177993561430_item	2253701	et	3	main
elu	doc_177993561430_item	2253704	et	4	main
raske	doc_177993561430_item	2253709	et	4	main
kes	doc_177993561430_item	2253710	et	4	main
kaks	doc_177993561430_item	2253712	et	3	main
kõik	doc_177993561430_item	2253726	et	4	main
kompjutiseerida	doc_177993561430_item	2253728	et	4	main
ja	doc_177993561430_item	2253729	et	3	main
õppida	doc_177993561430_item	2253733	et	3	main
oppida	doc_177993561430_item	2253735	et	4	main
kasutab	doc_177993561430_item	2253737	et	3	main
arvuti	doc_177993561430_item	2253741	et	4	main
arvuti	doc_177993561430_item	2253749	et	4	main
kasutab	doc_177993561430_item	2253750	et	3	main
firmat	doc_177993561430_item	2253752	et	3	main
sõidujaamat	doc_177993561430_item	2253755	et	4	main
teist	doc_177993561430_item	2253758	et	4	main
arvutis	doc_177993561430_item	2253764	et	4	main
ja	doc_177993561430_item	2253765	et	3	main
sõber	doc_177993561430_item	2253772	et	3	main
kiri	doc_177993561430_item	2253774	et	3	main
vastan	doc_177993561430_item	2253777	et	3	main
kiiresti	doc_177993561430_item	2253778	et	3	main
kui	doc_177993561430_item	2253779	et	3	main
aastat	doc_177993561430_item	2253781	et	3	main
praegu	doc_177993561430_item	2253790	et	3	main
ma	doc_177993561430_item	2253791	et	3	main
töötan	doc_177993561430_item	2253792	et	3	main
sõpraga	doc_177993561430_item	2253797	et	4	main
arvutuga	doc_177993561430_item	2253798	et	4	main
kasutab	doc_177993561430_item	2253799	et	3	main
arvuti	doc_177993561430_item	2253800	et	4	main
võib	doc_177993561430_item	2253801	et	3	main
otsida	doc_177993561430_item	2253802	et	4	main
uus	doc_177993561430_item	2253803	et	3	main
uudiseid	doc_177993561430_item	2253804	et	3	main
lugeda	doc_177993561430_item	2253805	et	3	main
lehed	doc_177993561430_item	2253806	et	3	main
raamatud	doc_177993561430_item	2253807	et	4	main
ajakirjad	doc_177993561430_item	2253808	et	3	main
internetis	doc_177993561430_item	2253809	et	4	main
me	doc_177993561430_item	2253810	et	4	main
otsime	doc_177993561430_item	2253811	et	4	main
kuhu	doc_177993561430_item	2253812	et	3	main
me	doc_177993561430_item	2253813	et	4	main
sõidame	doc_177993561430_item	2253814	et	3	main
puhata	doc_177993561430_item	2253815	et	4	main
samatooriumi	doc_177993561430_item	2253816	et	4	main
või	doc_177993561430_item	2253817	et	4	main
sõidame	doc_177993561430_item	2253818	et	3	main
teise	doc_177993561430_item	2253819	et	4	main
mailmas	doc_177993561430_item	2253820	et	4	main
internetis	doc_177993561430_item	2253824	et	4	main
palju	doc_177993561430_item	2253827	et	4	main
saa	doc_177993561430_item	2253832	et	4	main
külmkapp	doc_177993561430_item	2253836	et	3	main
halb	doc_177993561430_item	2253842	et	3	main
sellega	doc_177993561430_item	2253848	et	3	main
või	doc_177993561430_item	2253855	et	4	main
võib	doc_177993561430_item	2253871	et	3	main
puuvilju	doc_177993561430_item	2253875	et	3	main
ja	doc_177993561430_item	2253884	et	3	main
maitse	doc_177993561430_item	2253886	et	4	main
paremine	doc_177993561430_item	2253761	et	4	main
kirjutada	doc_177993561430_item	2253762	et	3	main
emeile	doc_177993561430_item	2253767	et	4	main
sõprale	doc_177993561430_item	2253769	et	4	main
postiga	doc_177993561430_item	2253771	et	4	main
ja	doc_177993561430_item	2253776	et	3	main
kiri	doc_177993561430_item	2253785	et	3	main
või	doc_177993561430_item	2253787	et	4	main
oma	doc_177993561430_item	2253796	et	4	main
kes	doc_177993561430_item	2253822	et	4	main
millega	doc_177993561430_item	2253830	et	3	main
on	doc_177993561430_item	2253835	et	4	main
me	doc_177993561430_item	2253838	et	4	main
toiduainet	doc_177993561430_item	2253843	et	3	main
on	doc_177993561430_item	2253846	et	4	main
inimeseid	doc_177993561430_item	2253850	et	4	main
nädalat	doc_177993561430_item	2253858	et	3	main
palju	doc_177993561430_item	2253873	et	4	main
piima	doc_177993561430_item	2253876	et	4	main
värske	doc_177993561430_item	2253882	et	4	main
riigil	doc_177993561430_item	2253890	et	3	main
perenaine	doc_177993561430_item	2253892	et	3	main
ei	doc_177993561431_item	2253899	et	4	main
saa	doc_177993561431_item	2253900	et	4	main
saa	doc_177993561431_item	2253906	et	4	main
et	doc_177993561431_item	2253911	et	3	main
ei	doc_177993561431_item	2253913	et	4	main
mitmest	doc_177993561431_item	2253916	et	4	main
ole	doc_177993561431_item	2253931	et	4	main
väike	doc_177993561431_item	2253937	et	4	main
ja	doc_177993561431_item	2253944	et	3	main
huvitavamat	doc_177993561431_item	2253945	et	4	main
pereta	doc_177993561431_item	2253950	et	3	main
moraalselt	doc_177993561431_item	2253965	et	4	main
kogu	doc_177993561431_item	2253979	et	4	main
vaja	doc_177993561431_item	2253983	et	4	main
õppida	doc_177993561431_item	2253985	et	3	main
ja	doc_177993561431_item	2253986	et	3	main
seotud	doc_177993561431_item	2253996	et	4	main
ja	doc_177993561431_item	2254021	et	3	main
sõltub	doc_177993561431_item	2254035	et	3	main
konkurentsivõime	doc_177993561431_item	2254037	et	4	main
tööturul	doc_177993561431_item	2254038	et	3	main
terviseta	doc_177993561431_item	2254043	et	3	main
aga	doc_177993561431_item	2254055	et	3	main
tervisega	doc_177993561431_item	2254057	et	3	main
kahjuks	doc_177993561431_item	2254063	et	4	main
ühiskondas	doc_177993561431_item	2254065	et	4	main
viimasel	doc_177993561431_item	2254067	et	3	main
ajal	doc_177993561431_item	2254068	et	4	main
invaliidide	doc_177993561431_item	2254069	et	3	main
läks	doc_177993561431_item	2254071	et	3	main
informatsioonita	doc_177993561431_item	2254076	et	3	main
annab	doc_177993561431_item	2254087	et	3	main
midagi	doc_177993561431_item	2254089	et	4	main
huvitavat	doc_177993561431_item	2254090	et	4	main
elu	doc_177993561431_item	2254100	et	4	main
mobiiltelefonita	doc_177993561431_item	2254101	et	3	main
ma	doc_177993561431_item	2254105	et	3	main
kirjutada	doc_177993561431_item	2254107	et	3	main
elus	doc_177993561431_item	2254110	et	4	main
milleta	doc_177993561432_item	2254115	et	3	main
elada	doc_177993561432_item	2254119	et	3	main
ei	doc_177993561432_item	2254122	et	4	main
elada	doc_177993561432_item	2254125	et	3	main
hea	doc_177993561432_item	2254130	et	4	main
pere	doc_177993561432_item	2254133	et	4	main
on	doc_177993561432_item	2254135	et	4	main
abikaasa	doc_177993561432_item	2254144	et	4	main
kergem	doc_177993561432_item	2254155	et	4	main
teha	doc_177993561432_item	2254172	et	3	main
hea	doc_177993561432_item	2254174	et	4	main
sellepärast	doc_177993561432_item	2254179	et	3	main
on	doc_177993561432_item	2254182	et	4	main
et	doc_177993561432_item	2254221	et	3	main
kolmandal	doc_177993561432_item	2254225	et	3	main
väga	doc_177993561432_item	2254233	et	3	main
elus	doc_177993561432_item	2254237	et	4	main
on	doc_177993561432_item	2254240	et	4	main
punktid	doc_177993561432_item	2254242	et	4	main
hästi	doc_177993561432_item	2254253	et	3	main
saa	doc_177993561433_item	2254258	et	4	main
kasutada	doc_177993561430_item	2253825	et	3	main
ei	doc_177993561430_item	2253831	et	4	main
tänapaeval	doc_177993561430_item	2253833	et	4	main
elada	doc_177993561430_item	2253834	et	3	main
meie	doc_177993561430_item	2253844	et	4	main
praegu	doc_177993561430_item	2253849	et	3	main
toidu	doc_177993561430_item	2253852	et	3	main
üks	doc_177993561430_item	2253854	et	3	main
kaks	doc_177993561430_item	2253856	et	3	main
ja	doc_177993561430_item	2253859	et	3	main
panevad	doc_177993561430_item	2253860	et	4	main
kõik	doc_177993561430_item	2253861	et	4	main
toidu	doc_177993561430_item	2253862	et	3	main
külmkappi	doc_177993561430_item	2253863	et	4	main
kodust	doc_177993561430_item	2253864	et	4	main
praegu	doc_177993561430_item	2253865	et	3	main
on	doc_177993561430_item	2253866	et	4	main
väga	doc_177993561430_item	2253867	et	3	main
suur	doc_177993561430_item	2253868	et	3	main
assortiment	doc_177993561430_item	2253869	et	4	main
korda	doc_177993561430_item	2253857	et	4	main
perele	doc_177993561430_item	2253888	et	3	main
toit	doc_177993561430_item	2253894	et	3	main
tänapäeval	doc_177993561431_item	2253901	et	3	main
ei	doc_177993561431_item	2253905	et	4	main
elada	doc_177993561431_item	2253908	et	3	main
arvan	doc_177993561431_item	2253910	et	3	main
tänapäeval	doc_177993561431_item	2253912	et	3	main
elada	doc_177993561431_item	2253915	et	3	main
on	doc_177993561431_item	2253920	et	4	main
haridus	doc_177993561431_item	2253921	et	3	main
ei	doc_177993561431_item	2253923	et	4	main
ei	doc_177993561431_item	2253930	et	4	main
palk	doc_177993561431_item	2253935	et	3	main
rohkem	doc_177993561431_item	2253939	et	4	main
midagi	doc_177993561431_item	2253942	et	4	main
ei	doc_177993561431_item	2253947	et	4	main
üksi	doc_177993561431_item	2253956	et	4	main
talle	doc_177993561431_item	2253958	et	4	main
inimestele	doc_177993561431_item	2253968	et	3	main
mõtleb	doc_177993561431_item	2253978	et	3	main
aeg	doc_177993561431_item	2253980	et	3	main
sõltub	doc_177993561431_item	2253989	et	3	main
ja	doc_177993561431_item	2253991	et	3	main
edasi	doc_177993561431_item	2254025	et	3	main
kõrgkoolis	doc_177993561431_item	2254028	et	4	main
tähtis	doc_177993561431_item	2254030	et	4	main
sinu	doc_177993561431_item	2254036	et	3	main
elada	doc_177993561431_item	2254041	et	3	main
tervisega	doc_177993561431_item	2254045	et	3	main
probleemid	doc_177993561431_item	2254059	et	3	main
meie	doc_177993561431_item	2254064	et	4	main
raamatut	doc_177993561431_item	2254077	et	3	main
ajakirjad	doc_177993561431_item	2254079	et	3	main
ja	doc_177993561431_item	2254082	et	3	main
tänapäeval	doc_177993561431_item	2254086	et	3	main
uut	doc_177993561431_item	2254092	et	3	main
arvutitabr	doc_177993561431_item	2254103	et	4	main
kõik	doc_177993561431_item	2254112	et	4	main
saa	doc_177993561432_item	2254117	et	4	main
milleta	doc_177993561432_item	2254121	et	3	main
tänapäeval	doc_177993561432_item	2254124	et	3	main
esimesel	doc_177993561432_item	2254126	et	3	main
ka	doc_177993561432_item	2254131	et	3	main
raske	doc_177993561432_item	2254137	et	4	main
on	doc_177993561432_item	2254142	et	4	main
sinu	doc_177993561432_item	2254149	et	3	main
paremaks	doc_177993561432_item	2254152	et	4	main
paneksin	doc_177993561432_item	2254162	et	3	main
oleks	doc_177993561432_item	2254165	et	3	main
kui	doc_177993561432_item	2254175	et	3	main
arvan	doc_177993561432_item	2254220	et	3	main
tähtis	doc_177993561432_item	2254234	et	4	main
saad	doc_177993561432_item	2254245	et	4	main
ei	doc_177993561433_item	2254257	et	4	main
inimene	doc_177993561433_item	2254259	et	3	main
tänapäeval	doc_177993561433_item	2254260	et	3	main
temno	doc_177993561433_item	2254268	et	4	main
stress	doc_177993561433_item	2254270	et	3	main
kogu	doc_177993561433_item	2254272	et	4	main
peab	doc_177993561433_item	2254274	et	4	main
töötada	doc_177993561433_item	2254276	et	3	main
sinul	doc_177993561433_item	2254284	et	3	main
suhtlemine	doc_177993561433_item	2254289	et	4	main
kollektiivis	doc_177993561433_item	2254290	et	3	main
ilus	doc_177993561433_item	2254293	et	4	main
kes	doc_177993561433_item	2254297	et	4	main
millega	doc_177993561433_item	2254309	et	3	main
elada	doc_177993561433_item	2254314	et	3	main
halb	doc_177993561433_item	2254324	et	3	main
ei	doc_177993561433_item	2254326	et	4	main
töötada	doc_177993561433_item	2254328	et	3	main
palju	doc_177993561433_item	2254329	et	4	main
seetõttu	doc_177993561433_item	2254332	et	3	main
ole	doc_177993561433_item	2254334	et	4	main
mõnd	doc_177993561433_item	2254335	et	3	main
kui	doc_177993561433_item	2254349	et	3	main
mugav	doc_177993561433_item	2254391	et	3	main
ilma	doc_177993561433_item	2254402	et	4	main
ei	doc_177993561433_item	2254404	et	4	main
on	doc_177993561433_item	2254408	et	4	main
telerit	doc_177993561433_item	2254412	et	3	main
toidu	doc_177993561430_item	2253870	et	3	main
toitu	doc_177993561430_item	2253877	et	4	main
liha	doc_177993561430_item	2253878	et	4	main
toitu	doc_177993561430_item	2253879	et	4	main
toidu	doc_177993561430_item	2253883	et	3	main
valmistab	doc_177993561430_item	2253885	et	3	main
toit	doc_177993561430_item	2253887	et	3	main
p	doc_177993561430_item	2253896	et	4	main
ilma	doc_177993561431_item	2253897	et	4	main
elada	doc_177993561431_item	2253902	et	3	main
tänapäeval	doc_177993561431_item	2253907	et	3	main
ma	doc_177993561431_item	2253909	et	3	main
saa	doc_177993561431_item	2253914	et	4	main
on	doc_177993561431_item	2253936	et	4	main
leida	doc_177993561431_item	2253941	et	3	main
paremat	doc_177993561431_item	2253943	et	4	main
ja	doc_177993561431_item	2253951	et	3	main
inimene	doc_177993561431_item	2253954	et	3	main
siis	doc_177993561431_item	2253957	et	3	main
elada	doc_177993561431_item	2253959	et	3	main
on	doc_177993561431_item	2253960	et	4	main
väga	doc_177993561431_item	2253961	et	3	main
materiaalselt	doc_177993561431_item	2253963	et	4	main
nagu	doc_177993561431_item	2253964	et	3	main
kui	doc_177993561431_item	2253970	et	3	main
et	doc_177993561431_item	2253981	et	3	main
kus	doc_177993561431_item	2253992	et	3	main
elate	doc_177993561431_item	2253994	et	3	main
omavahel	doc_177993561431_item	2253997	et	3	main
sinu	doc_177993561431_item	2254022	et	3	main
on	doc_177993561431_item	2254029	et	4	main
taibukalt	doc_177993561431_item	2254031	et	4	main
eriala	doc_177993561431_item	2254032	et	4	main
saa	doc_177993561431_item	2254040	et	4	main
on	doc_177993561431_item	2254046	et	4	main
korras	doc_177993561431_item	2254048	et	4	main
sportiga	doc_177993561431_item	2254054	et	4	main
raskused	doc_177993561431_item	2254062	et	4	main
elu	doc_177993561431_item	2254070	et	4	main
ei	doc_177993561431_item	2254073	et	4	main
teler	doc_177993561431_item	2254080	et	3	main
meile	doc_177993561431_item	2254088	et	4	main
viimasel	doc_177993561431_item	2254093	et	3	main
ilma	doc_177993561432_item	2254120	et	4	main
saa	doc_177993561432_item	2254123	et	4	main
peab	doc_177993561432_item	2254128	et	4	main
elada	doc_177993561432_item	2254138	et	3	main
armas	doc_177993561432_item	2254143	et	3	main
lapsed	doc_177993561432_item	2254147	et	3	main
elu	doc_177993561432_item	2254150	et	4	main
probleeme	doc_177993561432_item	2254158	et	3	main
hea	doc_177993561432_item	2254163	et	4	main
karjääri	doc_177993561432_item	2254171	et	4	main
tõuseb	doc_177993561432_item	2254178	et	3	main
ilma	doc_177993561432_item	2254180	et	4	main
raske	doc_177993561432_item	2254184	et	4	main
eladabr	doc_177993561432_item	2254185	et	4	main
meie	doc_177993561430_item	2253889	et	4	main
iga	doc_177993561430_item	2253891	et	4	main
milleta	doc_177993561431_item	2253898	et	3	main
milleta	doc_177993561431_item	2253904	et	3	main
kõigepealt	doc_177993561431_item	2253918	et	3	main
hariduseta	doc_177993561431_item	2253922	et	3	main
saa	doc_177993561431_item	2253924	et	4	main
leida	doc_177993561431_item	2253925	et	3	main
kvalifitseeritud	doc_177993561431_item	2253926	et	4	main
töö	doc_177993561431_item	2253929	et	4	main
loomulikult	doc_177993561431_item	2253934	et	4	main
haridusega	doc_177993561431_item	2253938	et	3	main
võimalust	doc_177993561431_item	2253940	et	3	main
kui	doc_177993561431_item	2253953	et	3	main
annab	doc_177993561431_item	2253967	et	3	main
inimestel	doc_177993561431_item	2253971	et	3	main
perekond	doc_177993561431_item	2253973	et	3	main
lapsed	doc_177993561431_item	2253975	et	3	main
ta	doc_177993561431_item	2253977	et	4	main
sinult	doc_177993561431_item	2253988	et	3	main
kuidas	doc_177993561431_item	2253990	et	3	main
haridus	doc_177993561431_item	2253998	et	3	main
töö	doc_177993561431_item	2253999	et	4	main
raha	doc_177993561431_item	2254000	et	4	main
tervis	doc_177993561431_item	2254001	et	3	main
perekond	doc_177993561431_item	2254002	et	3	main
sõltub	doc_177993561431_item	2254004	et	3	main
töö	doc_177993561431_item	2254003	et	4	main
rahad	doc_177993561431_item	2254006	et	4	main
haridusest	doc_177993561431_item	2254005	et	4	main
sõltuvad	doc_177993561431_item	2254007	et	4	main
tööstbr	doc_177993561431_item	2254008	et	4	main
rahata	doc_177993561431_item	2254009	et	4	main
ka	doc_177993561431_item	2254010	et	3	main
ei	doc_177993561431_item	2254011	et	4	main
saa	doc_177993561431_item	2254012	et	4	main
tänapäeval	doc_177993561431_item	2254013	et	3	main
elada	doc_177993561431_item	2254014	et	3	main
kui	doc_177993561431_item	2254015	et	3	main
sul	doc_177993561431_item	2254016	et	3	main
on	doc_177993561431_item	2254017	et	4	main
raha	doc_177993561431_item	2254018	et	4	main
siis	doc_177993561431_item	2254019	et	3	main
sina	doc_177993561431_item	2254020	et	4	main
lapsed	doc_177993561431_item	2254023	et	3	main
õppida	doc_177993561431_item	2254026	et	3	main
valida	doc_177993561431_item	2254033	et	3	main
kõik	doc_177993561431_item	2254047	et	4	main
siis	doc_177993561431_item	2254049	et	3	main
inimene	doc_177993561431_item	2254050	et	3	main
töötab	doc_177993561431_item	2254051	et	3	main
reisib	doc_177993561431_item	2254052	et	3	main
tegeleb	doc_177993561431_item	2254053	et	3	main
kui	doc_177993561431_item	2254056	et	3	main
siis	doc_177993561431_item	2254060	et	3	main
elada	doc_177993561431_item	2254075	et	3	main
ajalehed	doc_177993561431_item	2254078	et	3	main
raadio	doc_177993561431_item	2254081	et	4	main
kõik	doc_177993561431_item	2254084	et	4	main
on	doc_177993561431_item	2254085	et	4	main
ajal	doc_177993561431_item	2254094	et	4	main
ei	doc_177993561431_item	2254096	et	4	main
kujutavad	doc_177993561431_item	2254097	et	4	main
ette	doc_177993561431_item	2254098	et	4	main
võivad	doc_177993561431_item	2254024	et	4	main
kõrgkoolis	doc_177993561431_item	2254027	et	4	main
sellest	doc_177993561431_item	2254034	et	4	main
ei	doc_177993561431_item	2254039	et	4	main
ilma	doc_177993561431_item	2254042	et	4	main
kui	doc_177993561431_item	2254044	et	3	main
on	doc_177993561431_item	2254058	et	4	main
tulevad	doc_177993561431_item	2254061	et	4	main
ainult	doc_177993561431_item	2254066	et	4	main
paremaksbr	doc_177993561431_item	2254072	et	4	main
saa	doc_177993561431_item	2254074	et	4	main
internet	doc_177993561431_item	2254083	et	4	main
ja	doc_177993561431_item	2254091	et	3	main
inimesed	doc_177993561431_item	2254095	et	3	main
oma	doc_177993561431_item	2254099	et	4	main
internetita	doc_177993561431_item	2254102	et	4	main
lõpuks	doc_177993561431_item	2254104	et	4	main
tahan	doc_177993561431_item	2254106	et	3	main
meie	doc_177993561431_item	2254109	et	4	main
on	doc_177993561431_item	2254111	et	4	main
ei	doc_177993561432_item	2254116	et	4	main
et	doc_177993561431_item	2254108	et	3	main
tähtis	doc_177993561431_item	2254113	et	4	main
ilma	doc_177993561432_item	2254114	et	4	main
tänapäeval	doc_177993561432_item	2254118	et	3	main
kohal	doc_177993561432_item	2254127	et	4	main
sõbralik	doc_177993561432_item	2254132	et	3	main
tänapäeval	doc_177993561432_item	2254134	et	3	main
väga	doc_177993561432_item	2254136	et	3	main
sul	doc_177993561432_item	2254141	et	3	main
vahvad	doc_177993561432_item	2254146	et	3	main
on	doc_177993561432_item	2254154	et	4	main
kõiki	doc_177993561432_item	2254157	et	4	main
teisele	doc_177993561432_item	2254159	et	4	main
kohale	doc_177993561432_item	2254160	et	4	main
ma	doc_177993561432_item	2254161	et	3	main
kui	doc_177993561432_item	2254167	et	3	main
palk	doc_177993561432_item	2254176	et	3	main
palju	doc_177993561432_item	2254186	et	4	main
teiseski	doc_177993561432_item	2254223	et	4	main
on	doc_177993561432_item	2254227	et	4	main
väga	doc_177993561432_item	2254228	et	3	main
suhtlemine	doc_177993561432_item	2254231	et	4	main
kõiged	doc_177993561432_item	2254241	et	4	main
sa	doc_177993561432_item	2254244	et	3	main
elada	doc_177993561432_item	2254251	et	3	main
p	doc_177993561432_item	2254254	et	4	main
milleta	doc_177993561433_item	2254256	et	3	main
liiga	doc_177993561433_item	2254264	et	4	main
raske	doc_177993561433_item	2254265	et	4	main
palju	doc_177993561433_item	2254275	et	4	main
on	doc_177993561433_item	2254278	et	4	main
parem	doc_177993561433_item	2254282	et	4	main
mugav	doc_177993561433_item	2254291	et	3	main
inimesed	doc_177993561433_item	2254302	et	3	main
seda	doc_177993561433_item	2254304	et	3	main
ole	doc_177993561433_item	2254306	et	4	main
saa	doc_177993561433_item	2254312	et	4	main
et	doc_177993561433_item	2254317	et	3	main
olema	doc_177993561432_item	2254129	et	4	main
üksinda	doc_177993561432_item	2254139	et	4	main
kui	doc_177993561432_item	2254140	et	3	main
ja	doc_177993561432_item	2254145	et	3	main
siis	doc_177993561432_item	2254148	et	3	main
hakkab	doc_177993561432_item	2254151	et	3	main
siis	doc_177993561432_item	2254153	et	3	main
otsustada	doc_177993561432_item	2254156	et	3	main
töö	doc_177993561432_item	2254164	et	4	main
hea	doc_177993561432_item	2254166	et	4	main
töö	doc_177993561432_item	2254168	et	4	main
annab	doc_177993561432_item	2254169	et	3	main
võimalust	doc_177993561432_item	2254170	et	3	main
oleks	doc_177993561432_item	2254173	et	3	main
piidevalt	doc_177993561432_item	2254177	et	4	main
rahata	doc_177993561432_item	2254181	et	4	main
väga	doc_177993561432_item	2254183	et	3	main
inimesi	doc_177993561432_item	2254187	et	4	main
tahaks	doc_177993561432_item	2254188	et	3	main
teatris	doc_177993561432_item	2254190	et	3	main
kinos	doc_177993561432_item	2254191	et	3	main
mõnikord	doc_177993561432_item	2254192	et	3	main
käia	doc_177993561432_item	2254189	et	4	main
restoranis	doc_177993561432_item	2254193	et	3	main
kohvikus	doc_177993561432_item	2254194	et	3	main
ja	doc_177993561432_item	2254195	et	3	main
keegi	doc_177993561432_item	2254197	et	4	main
tahaks	doc_177993561432_item	2254198	et	3	main
osta	doc_177993561432_item	2254199	et	4	main
autod	doc_177993561432_item	2254200	et	3	main
reisida	doc_177993561432_item	2254196	et	3	main
või	doc_177993561432_item	2254201	et	4	main
korterit	doc_177993561432_item	2254202	et	3	main
kahjuks	doc_177993561432_item	2254203	et	4	main
tänapäeval	doc_177993561432_item	2254204	et	3	main
raha	doc_177993561432_item	2254205	et	4	main
väga	doc_177993561432_item	2254206	et	3	main
tugevalt	doc_177993561432_item	2254207	et	4	main
mõjuvad	doc_177993561432_item	2254208	et	4	main
meie	doc_177993561432_item	2254209	et	4	main
elu	doc_177993561432_item	2254210	et	4	main
olgugi	doc_177993561432_item	2254211	et	4	main
et	doc_177993561432_item	2254212	et	3	main
raha	doc_177993561432_item	2254213	et	4	main
mängivad	doc_177993561432_item	2254214	et	4	main
suurt	doc_177993561432_item	2254215	et	3	main
rolli	doc_177993561432_item	2254216	et	4	main
meie	doc_177993561432_item	2254217	et	4	main
elus	doc_177993561432_item	2254218	et	4	main
ma	doc_177993561432_item	2254219	et	3	main
õnne	doc_177993561432_item	2254222	et	4	main
seisneb	doc_177993561432_item	2254224	et	3	main
sõbrad	doc_177993561432_item	2254230	et	3	main
on	doc_177993561432_item	2254232	et	4	main
meie	doc_177993561432_item	2254236	et	4	main
kui	doc_177993561432_item	2254238	et	3	main
sul	doc_177993561432_item	2254239	et	3	main
siis	doc_177993561432_item	2254243	et	3	main
ilma	doc_177993561433_item	2254255	et	4	main
elada	doc_177993561433_item	2254261	et	3	main
eluviis	doc_177993561433_item	2254266	et	3	main
ülekormus	doc_177993561433_item	2254269	et	4	main
inimene	doc_177993561433_item	2254271	et	3	main
aeg	doc_177993561433_item	2254273	et	3	main
sellepärast	doc_177993561433_item	2254277	et	3	main
huvitav	doc_177993561433_item	2254286	et	4	main
sulle	doc_177993561433_item	2254299	et	3	main
kellel	doc_177993561433_item	2254303	et	4	main
ei	doc_177993561433_item	2254305	et	4	main
üldse	doc_177993561433_item	2254310	et	3	main
arvan	doc_177993561433_item	2254316	et	3	main
on	doc_177993561433_item	2254319	et	4	main
siis	doc_177993561433_item	2254325	et	3	main
sul	doc_177993561433_item	2254331	et	3	main
arstiabi	doc_177993561433_item	2254338	et	4	main
liiga	doc_177993561433_item	2254340	et	4	main
hea	doc_177993561433_item	2254347	et	4	main
sina	doc_177993561433_item	2254350	et	4	main
soe	doc_177993561433_item	2254386	et	4	main
peres	doc_177993561433_item	2254388	et	3	main
viisakaid	doc_177993561433_item	2254389	et	4	main
lapsed	doc_177993561433_item	2254390	et	3	main
sulle	doc_177993561433_item	2254394	et	3	main
palju	doc_177993561433_item	2254400	et	4	main
elekter	doc_177993561433_item	2254413	et	3	main
et	doc_177993561433_item	2254421	et	3	main
kõigele	doc_177993561433_item	2254425	et	4	main
sportlane	doc_177993561434_item	2254433	et	3	main
peab	doc_177993561434_item	2254435	et	4	main
tegelema	doc_177993561434_item	2254436	et	3	main
hea	doc_177993561434_item	2254453	et	4	main
treenida	doc_177993561434_item	2254458	et	3	main
kui	doc_177993561434_item	2254460	et	3	main
siis	doc_177993561434_item	2254462	et	3	main
kes	doc_177993561434_item	2254486	et	4	main
kes	doc_177993561434_item	2254490	et	4	main
süüdi	doc_177993561434_item	2254492	et	4	main
selle	doc_177993561434_item	2254493	et	4	main
võtma	doc_177993561434_item	2254502	et	3	main
vastu	doc_177993561434_item	2254504	et	3	main
peab	doc_177993561434_item	2254506	et	4	main
kuulma	doc_177993561434_item	2254508	et	3	main
pärast	doc_177993561434_item	2254515	et	4	main
kohtunik	doc_177993561434_item	2254517	et	3	main
olema	doc_177993561434_item	2254523	et	4	main
tagasihoitud	doc_177993561434_item	2254527	et	4	main
oma	doc_177993561435_item	2254533	et	4	main
firma	doc_177993561435_item	2254537	et	4	main
koostab	doc_177993561435_item	2254540	et	3	main
ja	doc_177993561435_item	2254542	et	3	main
ja	doc_177993561435_item	2254552	et	3	main
oskusid	doc_177993561435_item	2254553	et	4	main
ja	doc_177993561435_item	2254576	et	3	main
disaini	doc_177993561435_item	2254578	et	4	main
joonestamis	doc_177993561435_item	2254582	et	4	main
tsirklid	doc_177993561435_item	2254586	et	4	main
väga	doc_177993561435_item	2254591	et	3	main
stiili	doc_177993561435_item	2254595	et	4	main
inimesena	doc_177993561435_item	2254601	et	3	main
uue	doc_177993561436_item	2254611	et	3	main
leidmine	doc_177993561436_item	2254613	et	4	main
olema	doc_177993561436_item	2254620	et	4	main
töö	doc_177993561436_item	2254630	et	4	main
ja	doc_177993561436_item	2254638	et	3	main
tal	doc_177993561436_item	2254643	et	3	main
ja	doc_177993561436_item	2254647	et	3	main
sihikindlust	doc_177993561436_item	2254654	et	4	main
võtta	doc_177993561436_item	2254662	et	3	main
nad	doc_177993561436_item	2254675	et	3	main
pidavad	doc_177993561436_item	2254676	et	4	main
kohal	doc_177993561432_item	2254226	et	4	main
head	doc_177993561432_item	2254229	et	4	main
osa	doc_177993561432_item	2254235	et	4	main
elada	doc_177993561432_item	2254246	et	3	main
normaalselt	doc_177993561432_item	2254247	et	4	main
kuna	doc_177993561432_item	2254248	et	3	main
on	doc_177993561432_item	2254249	et	4	main
vaja	doc_177993561432_item	2254250	et	4	main
väga	doc_177993561432_item	2254252	et	3	main
tänapäeval	doc_177993561433_item	2254262	et	3	main
suur	doc_177993561433_item	2254267	et	3	main
palju	doc_177993561433_item	2254280	et	4	main
on	doc_177993561433_item	2254285	et	4	main
töö	doc_177993561433_item	2254287	et	4	main
hea	doc_177993561433_item	2254288	et	4	main
töökoht	doc_177993561433_item	2254292	et	3	main
kodu	doc_177993561433_item	2254294	et	4	main
ja	doc_177993561433_item	2254295	et	3	main
abukasa	doc_177993561433_item	2254296	et	4	main
on	doc_177993561433_item	2254300	et	4	main
paljud	doc_177993561433_item	2254301	et	3	main
ilma	doc_177993561433_item	2254308	et	4	main
ei	doc_177993561433_item	2254311	et	4	main
tänapäeval	doc_177993561433_item	2254313	et	3	main
ma	doc_177993561433_item	2254315	et	3	main
tervis	doc_177993561433_item	2254320	et	3	main
kui	doc_177993561433_item	2254321	et	3	main
ja	doc_177993561433_item	2254330	et	3	main
ja	doc_177993561433_item	2254337	et	3	main
eriala	doc_177993561433_item	2254348	et	4	main
ei	doc_177993561433_item	2254355	et	4	main
on	doc_177993561433_item	2254360	et	4	main
suhtlemine	doc_177993561433_item	2254387	et	4	main
kodus	doc_177993561433_item	2254392	et	4	main
veel	doc_177993561433_item	2254397	et	4	main
radio	doc_177993561433_item	2254415	et	4	main
veel	doc_177993561433_item	2254417	et	4	main
tahan	doc_177993561433_item	2254419	et	3	main
elu	doc_177993561433_item	2254424	et	4	main
toidu	doc_177993561433_item	2254429	et	3	main
kutseline	doc_177993561434_item	2254432	et	4	main
iga	doc_177993561434_item	2254438	et	4	main
saama	doc_177993561434_item	2254445	et	4	main
tema	doc_177993561434_item	2254447	et	4	main
on	doc_177993561434_item	2254449	et	4	main
kui	doc_177993561434_item	2254451	et	3	main
siis	doc_177993561434_item	2254455	et	3	main
võib	doc_177993561434_item	2254457	et	3	main
paha	doc_177993561434_item	2254461	et	4	main
spordisaalis	doc_177993561434_item	2254465	et	3	main
on	doc_177993561434_item	2254487	et	4	main
teadma	doc_177993561434_item	2254497	et	3	main
ja	doc_177993561434_item	2254499	et	3	main
kui	doc_177993561434_item	2254511	et	3	main
prokuröri	doc_177993561434_item	2254513	et	4	main
oma	doc_177993561434_item	2254519	et	4	main
on	doc_177993561433_item	2254263	et	4	main
vaja	doc_177993561433_item	2254279	et	4	main
raha	doc_177993561433_item	2254281	et	4	main
kui	doc_177993561433_item	2254283	et	3	main
aitab	doc_177993561433_item	2254298	et	3	main
aga	doc_177993561433_item	2254307	et	3	main
see	doc_177993561433_item	2254318	et	3	main
on	doc_177993561433_item	2254323	et	4	main
saa	doc_177993561433_item	2254327	et	4	main
on	doc_177993561433_item	2254339	et	4	main
kallis	doc_177993561433_item	2254341	et	4	main
teisest	doc_177993561433_item	2254342	et	4	main
on	doc_177993561433_item	2254343	et	4	main
vajas	doc_177993561433_item	2254344	et	4	main
hea	doc_177993561433_item	2254345	et	4	main
haridus	doc_177993561433_item	2254346	et	3	main
on	doc_177993561433_item	2254351	et	4	main
siis	doc_177993561433_item	2254354	et	3	main
ole	doc_177993561433_item	2254356	et	4	main
probleeme	doc_177993561433_item	2254357	et	3	main
tööl	doc_177993561433_item	2254358	et	3	main
tööl	doc_177993561433_item	2254359	et	3	main
vaja	doc_177993561433_item	2254361	et	4	main
keeleoskus	doc_177993561433_item	2254362	et	3	main
parem	doc_177993561433_item	2254363	et	4	main
kui	doc_177993561433_item	2254364	et	3	main
annavad	doc_177993561433_item	2254393	et	3	main
tuju	doc_177993561433_item	2254396	et	4	main
tänapäeval	doc_177993561433_item	2254398	et	3	main
on	doc_177993561433_item	2254399	et	4	main
nendega	doc_177993561433_item	2254403	et	4	main
saa	doc_177993561433_item	2254405	et	4	main
elada	doc_177993561433_item	2254406	et	3	main
see	doc_177993561433_item	2254407	et	3	main
internet	doc_177993561433_item	2254410	et	4	main
külmkapp	doc_177993561433_item	2254414	et	3	main
ma	doc_177993561433_item	2254418	et	3	main
tervis	doc_177993561433_item	2254322	et	3	main
ei	doc_177993561433_item	2254333	et	4	main
võimalust	doc_177993561433_item	2254336	et	3	main
kvaliteetne	doc_177993561433_item	2254352	et	3	main
töötaja	doc_177993561433_item	2254353	et	4	main
sina	doc_177993561433_item	2254365	et	4	main
oskad	doc_177993561433_item	2254366	et	3	main
2-3	doc_177993561433_item	2254367	et	2	main
keele	doc_177993561433_item	2254368	et	4	main
töö	doc_177993561433_item	2254369	et	4	main
tekitab	doc_177993561433_item	2254370	et	3	main
stressi	doc_177993561433_item	2254371	et	4	main
ja	doc_177993561433_item	2254372	et	3	main
inimene	doc_177993561433_item	2254373	et	3	main
peab	doc_177993561433_item	2254374	et	4	main
puhkada	doc_177993561433_item	2254375	et	4	main
ja	doc_177993561433_item	2254376	et	3	main
kontrollida	doc_177993561433_item	2254377	et	4	main
oma	doc_177993561433_item	2254378	et	4	main
tervis	doc_177993561433_item	2254379	et	3	main
väga	doc_177993561433_item	2254380	et	3	main
tähtis	doc_177993561433_item	2254381	et	4	main
kuidas	doc_177993561433_item	2254382	et	3	main
on	doc_177993561433_item	2254383	et	4	main
suhtlemine	doc_177993561433_item	2254384	et	4	main
peres	doc_177993561433_item	2254385	et	3	main
hea	doc_177993561433_item	2254395	et	4	main
mugavust	doc_177993561433_item	2254401	et	4	main
arvuti	doc_177993561433_item	2254409	et	4	main
mobiiltelefon	doc_177993561433_item	2254411	et	3	main
ühistransport	doc_177993561433_item	2254416	et	3	main
loodus	doc_177993561433_item	2254427	et	4	main
tervislik	doc_177993561433_item	2254428	et	3	main
kirjeldus	doc_177993561434_item	2254431	et	4	main
käima	doc_177993561434_item	2254440	et	4	main
võistlustel	doc_177993561434_item	2254443	et	3	main
töövahendid	doc_177993561434_item	2254448	et	3	main
ilm	doc_177993561434_item	2254454	et	3	main
tuleb	doc_177993561434_item	2254463	et	3	main
treenida	doc_177993561434_item	2254464	et	3	main
peab	doc_177993561434_item	2254484	et	4	main
ja	doc_177993561434_item	2254489	et	3	main
on	doc_177993561434_item	2254491	et	4	main
peab	doc_177993561434_item	2254496	et	4	main
järgi	doc_177993561434_item	2254501	et	4	main
nii	doc_177993561434_item	2254509	et	3	main
otsustamist	doc_177993561434_item	2254520	et	4	main
ta	doc_177993561434_item	2254521	et	4	main
teiste	doc_177993561435_item	2254535	et	4	main
edasi	doc_177993561435_item	2254544	et	3	main
tema	doc_177993561435_item	2254550	et	4	main
teadma	doc_177993561435_item	2254567	et	3	main
uueid	doc_177993561435_item	2254569	et	4	main
tehnoloogijaid	doc_177993561435_item	2254570	et	4	main
materjale	doc_177993561435_item	2254572	et	3	main
arhitektil	doc_177993561435_item	2254588	et	3	main
kujund	doc_177993561435_item	2254593	et	3	main
ja	doc_177993561435_item	2254594	et	3	main
maitse	doc_177993561435_item	2254596	et	4	main
ta	doc_177993561435_item	2254597	et	4	main
p	doc_177993561435_item	2254602	et	4	main
kirjeldus	doc_177993561436_item	2254604	et	4	main
tema	doc_177993561436_item	2254606	et	4	main
töökohustused	doc_177993561436_item	2254607	et	3	main
on	doc_177993561436_item	2254608	et	4	main
informatsiooni	doc_177993561436_item	2254612	et	4	main
peab	doc_177993561436_item	2254619	et	4	main
isegi	doc_177993561436_item	2254625	et	4	main
kõmuajakirjanikul	doc_177993561436_item	2254627	et	3	main
on	doc_177993561436_item	2254628	et	4	main
otsima	doc_177993561436_item	2254636	et	4	main
on	doc_177993561436_item	2254644	et	4	main
kõmuajakirjaniku	doc_177993561436_item	2254649	et	3	main
töökohustused	doc_177993561436_item	2254659	et	3	main
õpetada	doc_177993561436_item	2254661	et	3	main
seletada	doc_177993561436_item	2254665	et	3	main
tavaliselt	doc_177993561436_item	2254674	et	4	main
laud	doc_177993561436_item	2254683	et	4	main
tahvel	doc_177993561436_item	2254685	et	3	main
liisada	doc_177993561433_item	2254420	et	4	main
vaja	doc_177993561433_item	2254422	et	4	main
ta	doc_177993561434_item	2254434	et	4	main
treeningul	doc_177993561434_item	2254441	et	3	main
osalema	doc_177993561434_item	2254442	et	3	main
ja	doc_177993561434_item	2254444	et	3	main
sportlane	doc_177993561434_item	2254456	et	3	main
õige	doc_177993561434_item	2254488	et	4	main
seadusi	doc_177993561434_item	2254498	et	3	main
seaduste	doc_177993561434_item	2254500	et	4	main
otsustamist	doc_177993561434_item	2254503	et	4	main
advokaati	doc_177993561434_item	2254510	et	4	main
ka	doc_177993561434_item	2254512	et	3	main
ja	doc_177993561434_item	2254514	et	3	main
räägib	doc_177993561434_item	2254518	et	3	main
ametite	doc_177993561435_item	2254529	et	3	main
juhib	doc_177993561435_item	2254532	et	3	main
või	doc_177993561435_item	2254534	et	4	main
nii	doc_177993561435_item	2254543	et	3	main
töövahendid	doc_177993561435_item	2254545	et	3	main
tema	doc_177993561435_item	2254547	et	4	main
ja	doc_177993561435_item	2254549	et	3	main
projekteerib	doc_177993561435_item	2254574	et	3	main
töövahendid	doc_177993561435_item	2254580	et	3	main
on	doc_177993561435_item	2254581	et	4	main
vahendid	doc_177993561435_item	2254583	et	3	main
pliiatsid	doc_177993561435_item	2254585	et	4	main
paber	doc_177993561435_item	2254587	et	3	main
hea	doc_177993561435_item	2254592	et	4	main
peab	doc_177993561435_item	2254598	et	4	main
kõmuajakirjanik	doc_177993561436_item	2254605	et	3	main
inimestega	doc_177993561436_item	2254615	et	3	main
oma	doc_177993561436_item	2254640	et	4	main
nende	doc_177993561436_item	2254658	et	4	main
on	doc_177993561436_item	2254660	et	4	main
eksameid	doc_177993561436_item	2254663	et	3	main
vastu	doc_177993561436_item	2254664	et	3	main
pastapliiats	doc_177993561436_item	2254670	et	4	main
õpikud	doc_177993561436_item	2254671	et	3	main
neil	doc_177993561436_item	2254680	et	4	main
on	doc_177993561436_item	2254681	et	4	main
treeningusse	doc_177993561437_item	2254721	et	4	main
vaja	doc_177993561437_item	2254723	et	4	main
spordipüksid	doc_177993561437_item	2254725	et	3	main
meeldima	doc_177993561437_item	2254730	et	3	main
töötada	doc_177993561437_item	2254731	et	3	main
suhelda	doc_177993561437_item	2254733	et	4	main
sellepärast	doc_177993561437_item	2254740	et	3	main
elada	doc_177993561437_item	2254745	et	3	main
probleemidest	doc_177993561437_item	2254753	et	3	main
haiglas	doc_177993561437_item	2254756	et	3	main
tal	doc_177993561437_item	2254761	et	3	main
suurte	doc_177993561437_item	2254767	et	3	main
ka	doc_177993561437_item	2254769	et	3	main
inimeste	doc_177993561437_item	2254779	et	3	main
kirjeldus	doc_177993561438_item	2254786	et	4	main
ehitajad	doc_177993561438_item	2254788	et	4	main
erilised	doc_177993561438_item	2254790	et	4	main
nad	doc_177993561438_item	2254792	et	3	main
väga	doc_177993561438_item	2254812	et	3	main
töö	doc_177993561438_item	2254814	et	4	main
ettevaatust	doc_177993561438_item	2254817	et	3	main
raamatud	doc_177993561438_item	2254822	et	4	main
niipalju	doc_177993561438_item	2254836	et	3	main
tahab	doc_177993561438_item	2254838	et	3	main
peab	doc_177993561438_item	2254844	et	4	main
tak	doc_177993561438_item	2254846	et	4	main
rahva	doc_177993561438_item	2254851	et	3	main
ja	doc_177993561438_item	2254853	et	3	main
grammatiliselt	doc_177993561438_item	2254855	et	4	main
kirjutama	doc_177993561438_item	2254857	et	3	main
huvitav	doc_177993561439_item	2254864	et	4	main
teistele	doc_177993561439_item	2254881	et	4	main
saada	doc_177993561439_item	2254888	et	4	main
peab	doc_177993561439_item	2254889	et	4	main
päeval	doc_177993561439_item	2254897	et	3	main
rahulik	doc_177993561433_item	2254423	et	3	main
puhtaks	doc_177993561433_item	2254426	et	3	main
ametite	doc_177993561434_item	2254430	et	3	main
spordiga	doc_177993561434_item	2254437	et	3	main
päev	doc_177993561434_item	2254439	et	3	main
auhindu	doc_177993561434_item	2254446	et	4	main
spordisisustus	doc_177993561434_item	2254450	et	3	main
on	doc_177993561434_item	2254452	et	4	main
staadionil	doc_177993561434_item	2254459	et	3	main
jõusaalis	doc_177993561434_item	2254466	et	3	main
temal	doc_177993561434_item	2254468	et	3	main
peab	doc_177993561434_item	2254469	et	4	main
olema	doc_177993561434_item	2254470	et	4	main
muidugi	doc_177993561434_item	2254467	et	4	main
spordisisustus	doc_177993561434_item	2254471	et	3	main
ja	doc_177993561434_item	2254472	et	3	main
oma	doc_177993561434_item	2254473	et	4	main
treener	doc_177993561434_item	2254474	et	3	main
sportlane	doc_177993561434_item	2254475	et	3	main
peab	doc_177993561434_item	2254476	et	4	main
enesekindel	doc_177993561434_item	2254478	et	3	main
sihikindel	doc_177993561434_item	2254479	et	3	main
olema	doc_177993561434_item	2254477	et	4	main
ja	doc_177993561434_item	2254480	et	3	main
püüdlik	doc_177993561434_item	2254481	et	3	main
kohtunik	doc_177993561434_item	2254482	et	3	main
ta	doc_177993561434_item	2254483	et	4	main
otsustama	doc_177993561434_item	2254485	et	3	main
jaoks	doc_177993561434_item	2254494	et	4	main
ta	doc_177993561434_item	2254495	et	4	main
kohtunik	doc_177993561434_item	2254505	et	3	main
ära	doc_177993561434_item	2254507	et	4	main
seda	doc_177993561434_item	2254516	et	3	main
peab	doc_177993561434_item	2254522	et	4	main
ja	doc_177993561434_item	2254526	et	3	main
p	doc_177993561434_item	2254528	et	4	main
kirjeldus	doc_177993561435_item	2254530	et	4	main
firmajuhtija	doc_177993561435_item	2254531	et	4	main
inimeste	doc_177993561435_item	2254536	et	3	main
tööd	doc_177993561435_item	2254539	et	4	main
tööprojekti	doc_177993561435_item	2254541	et	4	main
on	doc_177993561435_item	2254546	et	4	main
ise	doc_177993561435_item	2254548	et	4	main
aja	doc_177993561435_item	2254565	et	4	main
jallas	doc_177993561435_item	2254566	et	4	main
kõik	doc_177993561435_item	2254568	et	4	main
hooneid	doc_177993561435_item	2254575	et	4	main
kujundab	doc_177993561435_item	2254577	et	3	main
tema	doc_177993561435_item	2254579	et	4	main
nagu	doc_177993561435_item	2254584	et	3	main
peab	doc_177993561435_item	2254589	et	4	main
olema	doc_177993561435_item	2254599	et	4	main
kirjuatmine	doc_177993561436_item	2254610	et	4	main
jaoks	doc_177993561436_item	2254617	et	4	main
paber	doc_177993561436_item	2254621	et	3	main
fotoapparat	doc_177993561436_item	2254623	et	4	main
rasked	doc_177993561436_item	2254629	et	3	main
ta	doc_177993561436_item	2254632	et	4	main
iga	doc_177993561436_item	2254634	et	4	main
päev	doc_177993561436_item	2254635	et	3	main
kirjutada	doc_177993561436_item	2254639	et	3	main
artikleid	doc_177993561436_item	2254641	et	3	main
tavaliselt	doc_177993561436_item	2254642	et	4	main
kabinet	doc_177993561436_item	2254646	et	3	main
arvuti	doc_177993561436_item	2254648	et	4	main
töö	doc_177993561436_item	2254650	et	4	main
nõuab	doc_177993561436_item	2254651	et	3	main
hea	doc_177993561436_item	2254652	et	4	main
ja	doc_177993561436_item	2254655	et	3	main
õppejõud	doc_177993561436_item	2254657	et	4	main
õppematerjali	doc_177993561436_item	2254666	et	4	main
peab	doc_177993561436_item	2254668	et	4	main
olema	doc_177993561436_item	2254669	et	4	main
loengukonspektid	doc_177993561436_item	2254673	et	3	main
loenguid	doc_177993561436_item	2254677	et	4	main
seal	doc_177993561436_item	2254679	et	4	main
ja	doc_177993561436_item	2254684	et	3	main
peab	doc_177993561436_item	2254687	et	4	main
olema	doc_177993561436_item	2254688	et	4	main
kannatlik	doc_177993561436_item	2254689	et	3	main
on	doc_177993561437_item	2254722	et	4	main
inimestega	doc_177993561437_item	2254732	et	3	main
peab	doc_177993561437_item	2254735	et	4	main
ja	doc_177993561437_item	2254738	et	3	main
sport	doc_177993561437_item	2254742	et	3	main
ta	doc_177993561437_item	2254747	et	4	main
omandama	doc_177993561437_item	2254758	et	3	main
peab	doc_177993561437_item	2254762	et	4	main
inimestega	doc_177993561437_item	2254765	et	3	main
kui	doc_177993561437_item	2254768	et	3	main
ta	doc_177993561437_item	2254771	et	4	main
peab	doc_177993561437_item	2254772	et	4	main
teadma	doc_177993561437_item	2254773	et	3	main
tal	doc_177993561437_item	2254776	et	3	main
eest	doc_177993561437_item	2254780	et	4	main
on	doc_177993561437_item	2254782	et	4	main
ametite	doc_177993561438_item	2254785	et	3	main
hooned	doc_177993561438_item	2254791	et	4	main
ehitajate	doc_177993561438_item	2254796	et	4	main
ehitajaks	doc_177993561438_item	2254802	et	4	main
on	doc_177993561438_item	2254805	et	4	main
ehitajatel	doc_177993561438_item	2254810	et	4	main
mis	doc_177993561438_item	2254815	et	4	main
õiglane	doc_177993561434_item	2254524	et	3	main
täpne	doc_177993561434_item	2254525	et	3	main
korraldab	doc_177993561435_item	2254538	et	3	main
haridus	doc_177993561435_item	2254551	et	3	main
ta	doc_177993561435_item	2254554	et	4	main
peab	doc_177993561435_item	2254555	et	4	main
olema	doc_177993561435_item	2254556	et	4	main
aktiivse	doc_177993561435_item	2254557	et	3	main
ja	doc_177993561435_item	2254558	et	3	main
julge	doc_177993561435_item	2254559	et	4	main
inimesena	doc_177993561435_item	2254560	et	3	main
veel	doc_177993561435_item	2254561	et	4	main
ta	doc_177993561435_item	2254562	et	4	main
peab	doc_177993561435_item	2254563	et	4	main
käima	doc_177993561435_item	2254564	et	4	main
ja	doc_177993561435_item	2254571	et	3	main
arhitekst	doc_177993561435_item	2254573	et	4	main
olema	doc_177993561435_item	2254590	et	4	main
aktiivse	doc_177993561435_item	2254600	et	3	main
ametite	doc_177993561436_item	2254603	et	3	main
kõmuuudiste	doc_177993561436_item	2254609	et	3	main
suhtlemine	doc_177993561436_item	2254614	et	4	main
töö	doc_177993561436_item	2254616	et	4	main
tal	doc_177993561436_item	2254618	et	3	main
pastapliiats	doc_177993561436_item	2254622	et	4	main
ja	doc_177993561436_item	2254624	et	3	main
auto	doc_177993561436_item	2254626	et	4	main
tingimused	doc_177993561436_item	2254631	et	3	main
peab	doc_177993561436_item	2254633	et	4	main
informatsiooni	doc_177993561436_item	2254637	et	4	main
oma	doc_177993561436_item	2254645	et	4	main
suhtlemisoskust	doc_177993561436_item	2254653	et	3	main
tahtejõulisust	doc_177993561436_item	2254656	et	4	main
nendel	doc_177993561436_item	2254667	et	4	main
või	doc_177993561436_item	2254672	et	4	main
oma	doc_177993561436_item	2254682	et	4	main
õppejõud	doc_177993561436_item	2254686	et	4	main
väga	doc_177993561436_item	2254691	et	3	main
p	doc_177993561436_item	2254693	et	4	main
ametite	doc_177993561437_item	2254694	et	3	main
kirjeldus	doc_177993561437_item	2254695	et	4	main
ravivõimlemise	doc_177993561437_item	2254696	et	3	main
treener	doc_177993561437_item	2254697	et	3	main
ta	doc_177993561437_item	2254698	et	4	main
töötab	doc_177993561437_item	2254699	et	3	main
väljas	doc_177993561437_item	2254700	et	4	main
saalis	doc_177993561437_item	2254701	et	4	main
või	doc_177993561437_item	2254702	et	4	main
ujulas	doc_177993561437_item	2254703	et	3	main
tal	doc_177993561437_item	2254704	et	3	main
on	doc_177993561437_item	2254705	et	4	main
vaja	doc_177993561437_item	2254706	et	4	main
pallid	doc_177993561437_item	2254707	et	4	main
väikesed	doc_177993561437_item	2254708	et	4	main
vaibad	doc_177993561437_item	2254709	et	3	main
mattid	doc_177993561437_item	2254710	et	4	main
ribad	doc_177993561437_item	2254711	et	3	main
ja	doc_177993561437_item	2254712	et	3	main
muusika	doc_177993561437_item	2254713	et	4	main
naitab	doc_177993561437_item	2254715	et	4	main
erinevaid	doc_177993561437_item	2254716	et	4	main
ta	doc_177993561437_item	2254714	et	4	main
ülesandeid	doc_177993561437_item	2254717	et	3	main
koos	doc_177993561437_item	2254718	et	4	main
muusikuga	doc_177993561437_item	2254719	et	4	main
inimestele	doc_177993561437_item	2254720	et	3	main
ja	doc_177993561437_item	2254726	et	3	main
peab	doc_177993561437_item	2254729	et	4	main
optimistlik	doc_177993561437_item	2254739	et	3	main
meid	doc_177993561437_item	2254744	et	4	main
meeldima	doc_177993561437_item	2254763	et	3	main
töötada	doc_177993561437_item	2254764	et	3	main
nii	doc_177993561437_item	2254766	et	3	main
erinevaid	doc_177993561437_item	2254774	et	4	main
haigusi	doc_177993561437_item	2254775	et	4	main
ta	doc_177993561437_item	2254781	et	4	main
viisakas	doc_177993561437_item	2254784	et	4	main
auditooriumis	doc_177993561436_item	2254678	et	3	main
ja	doc_177993561436_item	2254690	et	3	main
tark	doc_177993561436_item	2254692	et	3	main
võtta	doc_177993561437_item	2254724	et	3	main
t-särk	doc_177993561437_item	2254727	et	3	main
ta	doc_177993561437_item	2254734	et	4	main
ja	doc_177993561437_item	2254746	et	3	main
arstbr	doc_177993561437_item	2254754	et	4	main
töötab	doc_177993561437_item	2254755	et	3	main
peab	doc_177993561437_item	2254757	et	4	main
haridust	doc_177993561437_item	2254760	et	4	main
meeldib	doc_177993561437_item	2254777	et	3	main
ehitaja	doc_177993561438_item	2254787	et	4	main
teevad	doc_177993561438_item	2254793	et	3	main
palju	doc_177993561438_item	2254794	et	4	main
tööd	doc_177993561438_item	2254795	et	4	main
vahendid	doc_177993561438_item	2254797	et	3	main
kõik	doc_177993561438_item	2254799	et	4	main
on	doc_177993561438_item	2254811	et	4	main
raske	doc_177993561438_item	2254813	et	4	main
inimesed	doc_177993561438_item	2254820	et	3	main
kirjutavad	doc_177993561438_item	2254821	et	4	main
raamatud	doc_177993561438_item	2254830	et	4	main
ning	doc_177993561438_item	2254831	et	3	main
sõnaraamatud	doc_177993561438_item	2254832	et	4	main
tööaega	doc_177993561438_item	2254842	et	4	main
milline	doc_177993561438_item	2254848	et	3	main
ajaloo	doc_177993561438_item	2254850	et	4	main
väga	doc_177993561439_item	2254863	et	3	main
suur	doc_177993561439_item	2254871	et	3	main
millega	doc_177993561439_item	2254873	et	3	main
ujuda	doc_177993561439_item	2254880	et	3	main
autoga	doc_177993561439_item	2254882	et	3	main
edukaks	doc_177993561439_item	2254887	et	3	main
ja	doc_177993561439_item	2254894	et	3	main
sportlane	doc_177993561439_item	2254901	et	3	main
palk	doc_177993561439_item	2254903	et	3	main
aitab	doc_177993561439_item	2254923	et	3	main
õige	doc_177993561439_item	2254929	et	4	main
ja	doc_177993561439_item	2254930	et	3	main
soovib	doc_177993561439_item	2254934	et	3	main
ametnikul	doc_177993561439_item	2254939	et	3	main
hea	doc_177993561439_item	2254942	et	4	main
teenindamine	doc_177993561439_item	2254946	et	4	main
töö	doc_177993561439_item	2254953	et	4	main
pole	doc_177993561439_item	2254957	et	3	main
töö	doc_177993561439_item	2254961	et	4	main
oskused	doc_177993561439_item	2254968	et	3	main
ja	doc_177993561440_item	2254974	et	3	main
ta	doc_177993561440_item	2254984	et	4	main
huvitav	doc_177993561440_item	2254988	et	4	main
temaga	doc_177993561440_item	2254990	et	3	main
või	doc_177993561440_item	2255001	et	4	main
suures	doc_177993561440_item	2255027	et	3	main
kauplustes	doc_177993561440_item	2255032	et	4	main
p	doc_177993561440_item	2255037	et	4	main
kunstnik	doc_177993561441_item	2255041	et	3	main
see	doc_177993561441_item	2255043	et	3	main
inimene	doc_177993561441_item	2255045	et	3	main
vabakutseline	doc_177993561441_item	2255050	et	4	main
võib	doc_177993561441_item	2255056	et	3	main
ja	doc_177993561441_item	2255062	et	3	main
ise	doc_177993561441_item	2255065	et	4	main
näiteks	doc_177993561441_item	2255067	et	4	main
ta	doc_177993561441_item	2255068	et	4	main
võib	doc_177993561441_item	2255069	et	3	main
ei	doc_177993561441_item	2255082	et	4	main
ja	doc_177993561441_item	2255085	et	3	main
sööb	doc_177993561441_item	2255087	et	3	main
töötada	doc_177993561441_item	2255093	et	3	main
olema	doc_177993561441_item	2255097	et	4	main
peab	doc_177993561441_item	2255103	et	4	main
mõtlema	doc_177993561441_item	2255110	et	3	main
isegi	doc_177993561441_item	2255120	et	4	main
ametnik	doc_177993561442_item	2255126	et	3	main
kui	doc_177993561442_item	2255128	et	3	main
oled	doc_177993561442_item	2255130	et	3	main
igav	doc_177993561442_item	2255142	et	3	main
on	doc_177993561442_item	2255147	et	4	main
inimestega	doc_177993561442_item	2255156	et	3	main
poliitikast	doc_177993561442_item	2255159	et	4	main
optimistlik	doc_177993561442_item	2255170	et	3	main
treenerile	doc_177993561437_item	2254728	et	3	main
olema	doc_177993561437_item	2254736	et	4	main
sportlik	doc_177993561437_item	2254737	et	3	main
et	doc_177993561437_item	2254741	et	3	main
aitab	doc_177993561437_item	2254743	et	3	main
meid	doc_177993561437_item	2254749	et	4	main
annab	doc_177993561437_item	2254748	et	3	main
võimalust	doc_177993561437_item	2254750	et	3	main
unustada	doc_177993561437_item	2254751	et	3	main
oma	doc_177993561437_item	2254752	et	4	main
meditsiini	doc_177993561437_item	2254759	et	4	main
väikestega	doc_177993561437_item	2254770	et	4	main
hoolisteda	doc_177993561437_item	2254778	et	4	main
sõbralik	doc_177993561437_item	2254783	et	3	main
ehitavad	doc_177993561438_item	2254789	et	4	main
on	doc_177993561438_item	2254798	et	4	main
ehitustööristad	doc_177993561438_item	2254800	et	4	main
et	doc_177993561438_item	2254801	et	3	main
ehitusoskusi	doc_177993561438_item	2254809	et	3	main
kirjanik	doc_177993561438_item	2254818	et	3	main
kirjaniku	doc_177993561438_item	2254823	et	3	main
kirjanik	doc_177993561438_item	2254833	et	3	main
tal	doc_177993561438_item	2254839	et	3	main
ametite	doc_177993561439_item	2254859	et	3	main
sportlane	doc_177993561439_item	2254861	et	3	main
on	doc_177993561439_item	2254870	et	4	main
valik	doc_177993561439_item	2254872	et	3	main
sportlane	doc_177993561439_item	2254885	et	3	main
ennast	doc_177993561439_item	2254891	et	4	main
hoidma	doc_177993561439_item	2254893	et	3	main
treenima	doc_177993561439_item	2254895	et	3	main
kui	doc_177993561439_item	2254898	et	3	main
edukas	doc_177993561439_item	2254900	et	4	main
suur	doc_177993561439_item	2254902	et	3	main
on	doc_177993561439_item	2254904	et	4	main
ei	doc_177993561439_item	2254908	et	4	main
teile	doc_177993561439_item	2254925	et	4	main
teile	doc_177993561439_item	2254932	et	4	main
et	doc_177993561439_item	2254937	et	3	main
on	doc_177993561439_item	2254947	et	4	main
ei	doc_177993561439_item	2254954	et	4	main
kõige	doc_177993561439_item	2254962	et	4	main
tööl	doc_177993561439_item	2254965	et	3	main
suhtlemise	doc_177993561439_item	2254967	et	4	main
ametite	doc_177993561440_item	2254969	et	3	main
õppejõud	doc_177993561440_item	2254971	et	4	main
tal	doc_177993561440_item	2254977	et	3	main
õpikud	doc_177993561440_item	2254979	et	3	main
pastapliatsid	doc_177993561440_item	2254983	et	4	main
on	doc_177993561440_item	2254985	et	4	main
alati	doc_177993561440_item	2254991	et	4	main
on	doc_177993561440_item	2254992	et	4	main
rääkima	doc_177993561440_item	2254994	et	3	main
erafirmas	doc_177993561440_item	2255002	et	3	main
me	doc_177993561440_item	2255025	et	4	main
elame	doc_177993561440_item	2255026	et	3	main
majas	doc_177993561440_item	2255028	et	3	main
ja	doc_177993561440_item	2255031	et	3	main
kirjeldus	doc_177993561441_item	2255039	et	4	main
kunstnik	doc_177993561441_item	2255042	et	3	main
et	doc_177993561441_item	2255053	et	3	main
kunstnik	doc_177993561441_item	2255055	et	3	main
ise	doc_177993561441_item	2255060	et	4	main
tahab	doc_177993561441_item	2255061	et	3	main
ta	doc_177993561441_item	2255064	et	4	main
tahab	doc_177993561441_item	2255066	et	3	main
metsas	doc_177993561441_item	2255072	et	3	main
temal	doc_177993561441_item	2255078	et	3	main
üldse	doc_177993561441_item	2255084	et	3	main
inimene	doc_177993561441_item	2255090	et	3	main
tahab	doc_177993561441_item	2255092	et	3	main
kunstnikuna	doc_177993561441_item	2255095	et	3	main
peab	doc_177993561441_item	2255096	et	4	main
väga	doc_177993561441_item	2255098	et	3	main
emotsionaalne	doc_177993561441_item	2255099	et	3	main
peab	doc_177993561441_item	2255100	et	4	main
loomulikult	doc_177993561441_item	2255108	et	4	main
peab	doc_177993561441_item	2255109	et	4	main
ainult	doc_177993561441_item	2255111	et	4	main
oma	doc_177993561441_item	2255112	et	4	main
on	doc_177993561441_item	2255115	et	4	main
betoon	doc_177993561441_item	2255121	et	3	main
olla	doc_177993561441_item	2255123	et	3	main
on	doc_177993561442_item	2255134	et	4	main
see	doc_177993561442_item	2255138	et	3	main
on	doc_177993561442_item	2255140	et	4	main
öelda	doc_177993561442_item	2255144	et	4	main
ja	doc_177993561442_item	2255157	et	3	main
töötada	doc_177993561442_item	2255163	et	3	main
ja	doc_177993561442_item	2255172	et	3	main
on	doc_177993561442_item	2255175	et	4	main
saama	doc_177993561438_item	2254803	et	4	main
siis	doc_177993561438_item	2254804	et	3	main
vaja	doc_177993561438_item	2254806	et	4	main
jõudu	doc_177993561438_item	2254807	et	4	main
ja	doc_177993561438_item	2254808	et	3	main
nõuab	doc_177993561438_item	2254816	et	3	main
need	doc_177993561438_item	2254819	et	3	main
on	doc_177993561438_item	2254825	et	4	main
paber	doc_177993561438_item	2254826	et	3	main
ja	doc_177993561438_item	2254828	et	3	main
kodus	doc_177993561438_item	2254835	et	4	main
ole	doc_177993561438_item	2254841	et	4	main
kirjanik	doc_177993561438_item	2254843	et	3	main
olla	doc_177993561438_item	2254845	et	3	main
inimene	doc_177993561438_item	2254847	et	3	main
kombet	doc_177993561438_item	2254852	et	3	main
oskab	doc_177993561438_item	2254854	et	3	main
ilusti	doc_177993561438_item	2254856	et	3	main
on	doc_177993561439_item	2254862	et	4	main
raske	doc_177993561439_item	2254866	et	4	main
igal	doc_177993561439_item	2254868	et	3	main
inimesel	doc_177993561439_item	2254869	et	3	main
tegeleda	doc_177993561439_item	2254875	et	3	main
meeldib	doc_177993561439_item	2254877	et	3	main
mõnedele	doc_177993561439_item	2254879	et	3	main
sõita	doc_177993561439_item	2254883	et	3	main
tahab	doc_177993561439_item	2254886	et	3	main
ise	doc_177993561439_item	2254890	et	4	main
vormis	doc_177993561439_item	2254892	et	4	main
garanteeritud	doc_177993561439_item	2254905	et	4	main
iga	doc_177993561439_item	2254906	et	4	main
üks	doc_177993561439_item	2254907	et	3	main
kes	doc_177993561439_item	2254922	et	4	main
mis	doc_177993561439_item	2254927	et	4	main
rohkem	doc_177993561439_item	2254933	et	4	main
ma	doc_177993561439_item	2254935	et	3	main
peab	doc_177993561439_item	2254940	et	4	main
alati	doc_177993561439_item	2254941	et	4	main
tuju	doc_177993561439_item	2254943	et	4	main
olema	doc_177993561439_item	2254944	et	4	main
mõnedele	doc_177993561439_item	2254951	et	3	main
sellel	doc_177993561439_item	2254964	et	4	main
ülikoolis	doc_177993561440_item	2254975	et	4	main
alati	doc_177993561440_item	2254976	et	4	main
millest	doc_177993561440_item	2254993	et	3	main
ta	doc_177993561440_item	2254995	et	4	main
üliõpilasi	doc_177993561440_item	2254997	et	3	main
ärijuht	doc_177993561440_item	2254998	et	3	main
töötab	doc_177993561440_item	2254999	et	3	main
alati	doc_177993561440_item	2255003	et	4	main
ajalehed	doc_177993561440_item	2255007	et	3	main
mida	doc_177993561440_item	2255021	et	4	main
tema	doc_177993561440_item	2255023	et	4	main
abil	doc_177993561440_item	2255024	et	4	main
uues	doc_177993561440_item	2255029	et	3	main
on	doc_177993561440_item	2255033	et	4	main
toidud	doc_177993561440_item	2255036	et	3	main
ametite	doc_177993561441_item	2255038	et	3	main
see	doc_177993561441_item	2255054	et	3	main
mida	doc_177993561441_item	2255058	et	4	main
joonistada	doc_177993561441_item	2255070	et	3	main
vabakutselise	doc_177993561441_item	2255094	et	4	main
joonistama	doc_177993561441_item	2255102	et	3	main
värvid	doc_177993561441_item	2255117	et	4	main
plastiliin	doc_177993561441_item	2255118	et	3	main
vahendid	doc_177993561438_item	2254824	et	3	main
pliiats	doc_177993561438_item	2254827	et	4	main
erilised	doc_177993561438_item	2254829	et	4	main
töötab	doc_177993561438_item	2254834	et	3	main
ta	doc_177993561438_item	2254837	et	4	main
ei	doc_177993561438_item	2254840	et	4	main
teab	doc_177993561438_item	2254849	et	3	main
p	doc_177993561438_item	2254858	et	4	main
kirjeldus	doc_177993561439_item	2254860	et	4	main
aga	doc_177993561439_item	2254865	et	3	main
tegevus	doc_177993561439_item	2254867	et	4	main
sportiga	doc_177993561439_item	2254874	et	4	main
mõnedele	doc_177993561439_item	2254876	et	3	main
jooksuga	doc_177993561439_item	2254878	et	3	main
kui	doc_177993561439_item	2254884	et	3	main
igal	doc_177993561439_item	2254896	et	3	main
oled	doc_177993561439_item	2254899	et	3	main
saa	doc_177993561439_item	2254909	et	4	main
sportiga	doc_177993561439_item	2254910	et	4	main
tegeleda	doc_177993561439_item	2254911	et	3	main
sest	doc_177993561439_item	2254912	et	4	main
see	doc_177993561439_item	2254913	et	3	main
on	doc_177993561439_item	2254914	et	4	main
väga	doc_177993561439_item	2254915	et	3	main
raske	doc_177993561439_item	2254916	et	4	main
ja	doc_177993561439_item	2254917	et	3	main
füüsiline	doc_177993561439_item	2254918	et	3	main
tegevus	doc_177993561439_item	2254919	et	4	main
müügiesindaja	doc_177993561439_item	2254920	et	4	main
inimene	doc_177993561439_item	2254921	et	3	main
arvan	doc_177993561439_item	2254936	et	3	main
sellel	doc_177993561439_item	2254938	et	4	main
kliendi	doc_177993561439_item	2254945	et	3	main
meeldi	doc_177993561439_item	2254955	et	4	main
see	doc_177993561439_item	2254956	et	3	main
raske	doc_177993561439_item	2254958	et	4	main
igav	doc_177993561439_item	2254960	et	3	main
tähtsam	doc_177993561439_item	2254963	et	4	main
on	doc_177993561439_item	2254966	et	4	main
kõrgkoolis	doc_177993561440_item	2254973	et	4	main
on	doc_177993561440_item	2254978	et	4	main
vihikud	doc_177993561440_item	2254980	et	3	main
ja	doc_177993561440_item	2254982	et	3	main
tark	doc_177993561440_item	2254986	et	3	main
valida	doc_177993561439_item	2254924	et	3	main
kaupa	doc_177993561439_item	2254926	et	4	main
on	doc_177993561439_item	2254928	et	4	main
mis	doc_177993561439_item	2254931	et	4	main
huvitav	doc_177993561439_item	2254948	et	4	main
töö	doc_177993561439_item	2254949	et	4	main
aga	doc_177993561439_item	2254950	et	3	main
selline	doc_177993561439_item	2254952	et	4	main
ja	doc_177993561439_item	2254959	et	3	main
kirjeldus	doc_177993561440_item	2254970	et	4	main
töötab	doc_177993561440_item	2254972	et	3	main
pliatsid	doc_177993561440_item	2254981	et	4	main
ja	doc_177993561440_item	2254987	et	3	main
inimene	doc_177993561440_item	2254989	et	3	main
õpitab	doc_177993561440_item	2254996	et	4	main
oma	doc_177993561440_item	2255000	et	4	main
tal	doc_177993561440_item	2255004	et	3	main
on	doc_177993561440_item	2255005	et	4	main
mobiiltelefon	doc_177993561440_item	2255006	et	3	main
ja	doc_177993561440_item	2255008	et	3	main
ilus	doc_177993561440_item	2255009	et	4	main
auto	doc_177993561440_item	2255010	et	4	main
ta	doc_177993561440_item	2255011	et	4	main
on	doc_177993561440_item	2255012	et	4	main
asjatundja	doc_177993561440_item	2255013	et	4	main
tark	doc_177993561440_item	2255014	et	3	main
ilus	doc_177993561440_item	2255015	et	4	main
naeratusega	doc_177993561440_item	2255016	et	4	main
ja	doc_177993561440_item	2255017	et	3	main
ta	doc_177993561440_item	2255018	et	4	main
täpselt	doc_177993561440_item	2255019	et	4	main
teab	doc_177993561440_item	2255020	et	3	main
korteris	doc_177993561440_item	2255030	et	3	main
vabakutseline	doc_177993561441_item	2255040	et	4	main
tähendab	doc_177993561441_item	2255052	et	3	main
teha	doc_177993561441_item	2255057	et	3	main
kus	doc_177993561441_item	2255063	et	3	main
tema	doc_177993561441_item	2255073	et	4	main
on	doc_177993561441_item	2255075	et	4	main
mõnikord	doc_177993561441_item	2255077	et	3	main
ole	doc_177993561441_item	2255083	et	4	main
ta	doc_177993561441_item	2255086	et	4	main
makaroonid	doc_177993561441_item	2255089	et	4	main
oskama	doc_177993561441_item	2255104	et	3	main
kujundada	doc_177993561441_item	2255106	et	3	main
ja	doc_177993561441_item	2255107	et	3	main
tööst	doc_177993561441_item	2255113	et	3	main
töövahendid	doc_177993561441_item	2255114	et	3	main
sa	doc_177993561442_item	2255129	et	3	main
siis	doc_177993561442_item	2255132	et	3	main
et	doc_177993561442_item	2255145	et	3	main
päev	doc_177993561442_item	2255150	et	3	main
pead	doc_177993561442_item	2255152	et	4	main
rääkima	doc_177993561442_item	2255158	et	3	main
inimene	doc_177993561442_item	2255160	et	3	main
tark	doc_177993561442_item	2255169	et	3	main
reisida	doc_177993561442_item	2255180	et	3	main
omandada	doc_177993561442_item	2255182	et	3	main
on	doc_177993561442_item	2255186	et	4	main
töötada	doc_177993561442_item	2255192	et	3	main
ja	doc_177993561443_item	2255207	et	3	main
sõltub	doc_177993561443_item	2255214	et	3	main
missugune	doc_177993561443_item	2255216	et	3	main
ta	doc_177993561443_item	2255218	et	4	main
nendel	doc_177993561443_item	2255221	et	4	main
alati	doc_177993561443_item	2255223	et	4	main
pastapliiats	doc_177993561443_item	2255225	et	4	main
kuna	doc_177993561443_item	2255226	et	3	main
olema	doc_177993561443_item	2255234	et	4	main
tegema	doc_177993561440_item	2255022	et	3	main
alati	doc_177993561440_item	2255034	et	4	main
head	doc_177993561440_item	2255035	et	4	main
on	doc_177993561441_item	2255044	et	4	main
kes	doc_177993561441_item	2255046	et	4	main
on	doc_177993561441_item	2255047	et	4	main
seotud	doc_177993561441_item	2255048	et	4	main
kunstiga	doc_177993561441_item	2255049	et	4	main
aga	doc_177993561441_item	2255051	et	3	main
ta	doc_177993561441_item	2255059	et	4	main
kuskil	doc_177993561441_item	2255071	et	3	main
palk	doc_177993561441_item	2255074	et	3	main
ebastabiilne	doc_177993561441_item	2255076	et	3	main
on	doc_177993561441_item	2255079	et	4	main
raha	doc_177993561441_item	2255080	et	4	main
mõnikord	doc_177993561441_item	2255081	et	3	main
ainult	doc_177993561441_item	2255088	et	4	main
kes	doc_177993561441_item	2255091	et	4	main
hästi	doc_177993561441_item	2255101	et	3	main
midagi	doc_177993561441_item	2255105	et	4	main
erilised	doc_177993561441_item	2255116	et	4	main
paber	doc_177993561441_item	2255119	et	3	main
kirjeldus	doc_177993561442_item	2255125	et	4	main
riigiametnik	doc_177993561442_item	2255127	et	3	main
sul	doc_177993561442_item	2255133	et	3	main
aga	doc_177993561442_item	2255137	et	3	main
võime	doc_177993561442_item	2255143	et	4	main
see	doc_177993561442_item	2255146	et	3	main
töötama	doc_177993561442_item	2255153	et	3	main
paberitega	doc_177993561442_item	2255154	et	3	main
suhelda	doc_177993561442_item	2255155	et	4	main
kes	doc_177993561442_item	2255161	et	4	main
ametnikuna	doc_177993561442_item	2255164	et	3	main
mis	doc_177993561442_item	2255174	et	4	main
on	doc_177993561442_item	2255178	et	4	main
ka	doc_177993561442_item	2255187	et	3	main
arvutiga	doc_177993561442_item	2255193	et	4	main
p	doc_177993561442_item	2255198	et	4	main
kirjeldus	doc_177993561443_item	2255200	et	4	main
on	doc_177993561443_item	2255222	et	4	main
kaasas	doc_177993561443_item	2255224	et	4	main
see	doc_177993561443_item	2255227	et	3	main
ole	doc_177993561443_item	2255229	et	4	main
ta	doc_177993561443_item	2255232	et	4	main
valget	doc_177993561443_item	2255238	et	3	main
töö	doc_177993561443_item	2255246	et	4	main
et	doc_177993561443_item	2255248	et	3	main
oleks	doc_177993561443_item	2255250	et	3	main
peab	doc_177993561443_item	2255257	et	4	main
tema	doc_177993561443_item	2255264	et	4	main
tema	doc_177993561443_item	2255268	et	4	main
kruvikeeraja	doc_177993561443_item	2255271	et	4	main
saak	doc_177993561443_item	2255272	et	3	main
ilm	doc_177993561443_item	2255298	et	3	main
teda	doc_177993561443_item	2255299	et	4	main
korralagetus	doc_177993561443_item	2255302	et	4	main
ehitaja	doc_177993561443_item	2255305	et	4	main
ka	doc_177993561443_item	2255308	et	3	main
moraalselt	doc_177993561443_item	2255315	et	4	main
peab	doc_177993561443_item	2255317	et	4	main
võiks	doc_177993561441_item	2255122	et	4	main
ametite	doc_177993561442_item	2255124	et	3	main
ametnik	doc_177993561442_item	2255131	et	3	main
hea	doc_177993561442_item	2255135	et	4	main
palk	doc_177993561442_item	2255136	et	3	main
töö	doc_177993561442_item	2255139	et	4	main
väga	doc_177993561442_item	2255141	et	3	main
rutiintöö	doc_177993561442_item	2255148	et	4	main
iga	doc_177993561442_item	2255149	et	4	main
sa	doc_177993561442_item	2255151	et	3	main
tahab	doc_177993561442_item	2255162	et	3	main
peab	doc_177993561442_item	2255165	et	4	main
olema	doc_177993561442_item	2255166	et	4	main
väga	doc_177993561442_item	2255167	et	3	main
intelligentne	doc_177993561442_item	2255168	et	3	main
punktuaalne	doc_177993561442_item	2255171	et	4	main
tõsine	doc_177993561442_item	2255173	et	4	main
võimalus	doc_177993561442_item	2255179	et	3	main
oma	doc_177993561442_item	2255183	et	4	main
sa	doc_177993561442_item	2255190	et	3	main
ja	doc_177993561442_item	2255194	et	3	main
ametite	doc_177993561443_item	2255199	et	3	main
arst	doc_177993561443_item	2255201	et	3	main
ta	doc_177993561443_item	2255202	et	4	main
kohustuslikuna	doc_177993561443_item	2255208	et	3	main
tema	doc_177993561443_item	2255210	et	4	main
erinevad	doc_177993561443_item	2255212	et	4	main
see	doc_177993561443_item	2255213	et	3	main
aga	doc_177993561443_item	2255220	et	3	main
hea	doc_177993561442_item	2255176	et	4	main
see	doc_177993561442_item	2255177	et	3	main
või	doc_177993561442_item	2255181	et	4	main
tähtis	doc_177993561442_item	2255188	et	4	main
kui	doc_177993561442_item	2255189	et	3	main
on	doc_177993561442_item	2255196	et	4	main
peab	doc_177993561443_item	2255203	et	4	main
olema	doc_177993561443_item	2255204	et	4	main
väga	doc_177993561443_item	2255205	et	3	main
täpsena	doc_177993561443_item	2255206	et	3	main
asjatundjana	doc_177993561443_item	2255209	et	3	main
töövahdid	doc_177993561443_item	2255211	et	4	main
sellest	doc_177993561443_item	2255215	et	4	main
peab	doc_177993561443_item	2255233	et	4	main
peab	doc_177993561443_item	2255236	et	4	main
ja	doc_177993561443_item	2255239	et	3	main
nõuab	doc_177993561443_item	2255247	et	3	main
natuke	doc_177993561443_item	2255253	et	4	main
kannatlik	doc_177993561443_item	2255254	et	3	main
ehitaja	doc_177993561443_item	2255255	et	4	main
kohustuslik	doc_177993561443_item	2255261	et	3	main
ja	doc_177993561443_item	2255262	et	3	main
ehitada	doc_177993561443_item	2255267	et	3	main
on	doc_177993561443_item	2255270	et	4	main
tolm	doc_177993561443_item	2255304	et	3	main
peab	doc_177993561443_item	2255306	et	4	main
tal	doc_177993561443_item	2255316	et	3	main
olema	doc_177993561443_item	2255318	et	4	main
kirjeldus	doc_177993561444_item	2255321	et	4	main
tugev	doc_177993561444_item	2255334	et	4	main
juhtima	doc_177993561444_item	2255343	et	4	main
oma	doc_177993561444_item	2255344	et	4	main
töövahendid	doc_177993561444_item	2255361	et	3	main
ametite	doc_177993561445_item	2255367	et	3	main
õpetaja	doc_177993561445_item	2255369	et	4	main
peab	doc_177993561445_item	2255371	et	4	main
õpetada	doc_177993561445_item	2255376	et	3	main
inimesi	doc_177993561445_item	2255378	et	4	main
ta	doc_177993561445_item	2255379	et	4	main
võib	doc_177993561445_item	2255380	et	3	main
töötada	doc_177993561445_item	2255381	et	3	main
õpetaja	doc_177993561445_item	2255389	et	4	main
peab	doc_177993561445_item	2255390	et	4	main
oma	doc_177993561445_item	2255393	et	4	main
tema	doc_177993561445_item	2255395	et	4	main
suurt	doc_177993561445_item	2255401	et	3	main
on	doc_177993561445_item	2255410	et	4	main
väga	doc_177993561445_item	2255411	et	3	main
raske	doc_177993561445_item	2255412	et	4	main
hästi	doc_177993561445_item	2255420	et	3	main
patsienti	doc_177993561445_item	2255421	et	4	main
see	doc_177993561445_item	2255427	et	3	main
oskusi	doc_177993561445_item	2255431	et	3	main
peab	doc_177993561446_item	2255440	et	4	main
töötama	doc_177993561446_item	2255441	et	3	main
töö	doc_177993561446_item	2255452	et	4	main
ole	doc_177993561446_item	2255454	et	4	main
ta	doc_177993561446_item	2255466	et	4	main
peab	doc_177993561446_item	2255467	et	4	main
teadma	doc_177993561446_item	2255468	et	3	main
ja	doc_177993561446_item	2255471	et	3	main
aus	doc_177993561446_item	2255473	et	4	main
nii	doc_177993561446_item	2255481	et	3	main
ja	doc_177993561447_item	2255520	et	3	main
vaja	doc_177993561447_item	2255523	et	4	main
uurida	doc_177993561447_item	2255534	et	3	main
peab	doc_177993561447_item	2255542	et	4	main
on	doc_177993561447_item	2255547	et	4	main
amet	doc_177993561447_item	2255552	et	3	main
teada	doc_177993561447_item	2255555	et	3	main
hästi	doc_177993561447_item	2255557	et	3	main
loodusõppetus	doc_177993561447_item	2255561	et	4	main
olema	doc_177993561447_item	2255564	et	4	main
hea	doc_177993561447_item	2255568	et	4	main
inimestele	doc_177993561447_item	2255571	et	3	main
kabinet	doc_177993561442_item	2255184	et	3	main
praegu	doc_177993561442_item	2255185	et	3	main
võid	doc_177993561442_item	2255191	et	4	main
sul	doc_177993561442_item	2255195	et	3	main
juhiload	doc_177993561442_item	2255197	et	4	main
arst	doc_177993561443_item	2255217	et	3	main
on	doc_177993561443_item	2255219	et	4	main
aga	doc_177993561443_item	2255231	et	3	main
arst	doc_177993561443_item	2255235	et	3	main
kandma	doc_177993561443_item	2255237	et	3	main
puhast	doc_177993561443_item	2255240	et	3	main
see	doc_177993561443_item	2255242	et	3	main
tingimus	doc_177993561443_item	2255244	et	4	main
julge	doc_177993561443_item	2255251	et	4	main
ta	doc_177993561443_item	2255256	et	4	main
täpne	doc_177993561443_item	2255260	et	3	main
töö	doc_177993561443_item	2255265	et	4	main
töövandid	doc_177993561443_item	2255269	et	3	main
pidevalt	doc_177993561443_item	2255301	et	4	main
ja	doc_177993561443_item	2255303	et	3	main
kannatlik	doc_177993561443_item	2255309	et	3	main
kui	doc_177993561443_item	2255311	et	3	main
ning	doc_177993561443_item	2255313	et	3	main
ametite	doc_177993561444_item	2255320	et	3	main
turvamees	doc_177993561444_item	2255322	et	4	main
rahulik	doc_177993561444_item	2255335	et	3	main
ta	doc_177993561444_item	2255350	et	4	main
tema	doc_177993561444_item	2255360	et	4	main
pea	doc_177993561444_item	2255364	et	4	main
lapsi	doc_177993561445_item	2255373	et	4	main
lasteaias	doc_177993561445_item	2255383	et	4	main
õpetajal	doc_177993561445_item	2255385	et	4	main
olema	doc_177993561445_item	2255387	et	4	main
kõrgharidus	doc_177993561445_item	2255388	et	3	main
suuri	doc_177993561445_item	2255398	et	3	main
arst	doc_177993561445_item	2255404	et	3	main
inimest	doc_177993561445_item	2255407	et	3	main
on	doc_177993561445_item	2255413	et	4	main
diagnoost	doc_177993561445_item	2255417	et	4	main
mis	doc_177993561445_item	2255424	et	4	main
jne	doc_177993561445_item	2255426	et	4	main
töö	doc_177993561445_item	2255428	et	4	main
nõuab	doc_177993561445_item	2255429	et	3	main
kõrgharidust	doc_177993561445_item	2255433	et	4	main
ta	doc_177993561446_item	2255439	et	4	main
riigile	doc_177993561446_item	2255442	et	3	main
kaitsma	doc_177993561446_item	2255443	et	3	main
ta	doc_177993561446_item	2255445	et	4	main
olema	doc_177993561446_item	2255447	et	4	main
valmis	doc_177993561446_item	2255448	et	4	main
ta	doc_177993561446_item	2255462	et	4	main
inimeste	doc_177993561446_item	2255474	et	3	main
abivalmis	doc_177993561447_item	2255519	et	3	main
töötada	doc_177993561447_item	2255524	et	3	main
ja	doc_177993561447_item	2255527	et	3	main
sulle	doc_177993561447_item	2255529	et	3	main
kõike	doc_177993561447_item	2255537	et	4	main
seotud	doc_177993561447_item	2255540	et	4	main
sul	doc_177993561447_item	2255541	et	3	main
diploom	doc_177993561447_item	2255544	et	4	main
ja	doc_177993561447_item	2255551	et	3	main
palju	doc_177993561447_item	2255556	et	4	main
teada	doc_177993561447_item	2255558	et	3	main
töökas	doc_177993561447_item	2255565	et	4	main
abivalmis	doc_177993561447_item	2255566	et	3	main
ja	doc_177993561447_item	2255567	et	3	main
ei	doc_177993561443_item	2255228	et	4	main
töövahend	doc_177993561443_item	2255230	et	3	main
rõivast	doc_177993561443_item	2255241	et	4	main
on	doc_177993561443_item	2255243	et	4	main
see	doc_177993561443_item	2255245	et	3	main
arst	doc_177993561443_item	2255249	et	3	main
tark	doc_177993561443_item	2255252	et	3	main
olema	doc_177993561443_item	2255258	et	4	main
asjatundja	doc_177993561443_item	2255263	et	4	main
on	doc_177993561443_item	2255266	et	4	main
hammer	doc_177993561443_item	2255273	et	4	main
ja	doc_177993561443_item	2255274	et	3	main
nii	doc_177993561443_item	2255275	et	3	main
edasi	doc_177993561443_item	2255276	et	3	main
aga	doc_177993561443_item	2255277	et	3	main
abiks	doc_177993561443_item	2255278	et	3	main
on	doc_177993561443_item	2255279	et	4	main
veel	doc_177993561443_item	2255280	et	4	main
autod	doc_177993561443_item	2255281	et	3	main
näiteks	doc_177993561443_item	2255282	et	4	main
ehituskraan	doc_177993561443_item	2255283	et	3	main
tingimused	doc_177993561443_item	2255284	et	3	main
ehitajate	doc_177993561443_item	2255285	et	4	main
jaoks	doc_177993561443_item	2255286	et	4	main
on	doc_177993561443_item	2255287	et	4	main
väga	doc_177993561443_item	2255288	et	3	main
rasked	doc_177993561443_item	2255289	et	3	main
nad	doc_177993561443_item	2255290	et	3	main
võivad	doc_177993561443_item	2255291	et	4	main
töötada	doc_177993561443_item	2255292	et	3	main
tänaval	doc_177993561443_item	2255293	et	4	main
isegi	doc_177993561443_item	2255294	et	4	main
kui	doc_177993561443_item	2255295	et	3	main
on	doc_177993561443_item	2255296	et	4	main
ka	doc_177993561443_item	2255259	et	3	main
külm	doc_177993561443_item	2255297	et	3	main
tugev	doc_177993561443_item	2255310	et	4	main
füüsiliselt	doc_177993561443_item	2255312	et	4	main
tahtejõudu	doc_177993561443_item	2255319	et	4	main
igasuguseid	doc_177993561444_item	2255324	et	3	main
vastutab	doc_177993561444_item	2255327	et	3	main
olema	doc_177993561444_item	2255332	et	4	main
töötab	doc_177993561444_item	2255337	et	3	main
väljas	doc_177993561444_item	2255338	et	4	main
sees	doc_177993561444_item	2255340	et	4	main
firmajuht	doc_177993561444_item	2255341	et	3	main
peab	doc_177993561444_item	2255342	et	4	main
tema	doc_177993561444_item	2255348	et	4	main
õpetaja	doc_177993561445_item	2255370	et	4	main
õpetama	doc_177993561445_item	2255372	et	3	main
ja	doc_177993561445_item	2255400	et	3	main
arst	doc_177993561445_item	2255403	et	3	main
töö	doc_177993561445_item	2255409	et	4	main
vaja	doc_177993561445_item	2255414	et	4	main
läbi	doc_177993561445_item	2255422	et	4	main
ja	doc_177993561445_item	2255432	et	3	main
ka	doc_177993561445_item	2255434	et	3	main
ametite	doc_177993561446_item	2255436	et	3	main
kirjeldus	doc_177993561446_item	2255437	et	4	main
politseinik	doc_177993561446_item	2255438	et	4	main
olukorraks	doc_177993561446_item	2255450	et	3	main
ei	doc_177993561446_item	2255453	et	4	main
vastupidi	doc_177993561446_item	2255456	et	3	main
on	doc_177993561446_item	2255458	et	4	main
riskantne	doc_177993561446_item	2255460	et	3	main
peab	doc_177993561446_item	2255463	et	4	main
seadusi	doc_177993561446_item	2255470	et	3	main
olema	doc_177993561446_item	2255472	et	4	main
õpetaja	doc_177993561446_item	2255476	et	4	main
teodolitidega	doc_177993561447_item	2255526	et	4	main
gps-iga	doc_177993561447_item	2255528	et	3	main
palju	doc_177993561447_item	2255532	et	4	main
maapinna	doc_177993561447_item	2255535	et	3	main
olema	doc_177993561447_item	2255543	et	4	main
see	doc_177993561447_item	2255546	et	3	main
väga	doc_177993561447_item	2255548	et	3	main
töö	doc_177993561447_item	2255550	et	4	main
peaks	doc_177993561447_item	2255554	et	4	main
terminis	doc_177993561447_item	2255559	et	3	main
sa	doc_177993561447_item	2255562	et	3	main
ma	doc_187964557897_item	2255679	et	3	main
ilusad	doc_187964557897_item	2255721	et	3	main
huvitav	doc_187964557897_item	2255723	et	4	main
ja	doc_187964557897_item	2255724	et	3	main
mida	doc_187964557897_item	2255732	et	4	main
loengus	doc_187964557897_item	2255734	et	3	main
õpima	doc_187964557897_item	2255739	et	4	main
hästi	doc_187964557897_item	2255743	et	3	main
see	doc_187964557897_item	2255747	et	3	main
lodan	doc_187964557897_item	2255751	et	4	main
aastal	doc_187964557898_item	2255761	et	3	main
töötasin	doc_187964557898_item	2255768	et	3	main
muusikakooli	doc_187964557898_item	2255775	et	4	main
lõppuni	doc_187964557898_item	2255781	et	3	main
astusin	doc_187964557898_item	2255783	et	3	main
tehnika	doc_187964557898_item	2255785	et	4	main
mulle	doc_187964557898_item	2255822	et	4	main
meeldin	doc_187964557898_item	2255830	et	3	main
ttus	doc_187964557898_item	2255837	et	4	main
või	doc_187964557898_item	2255839	et	4	main
nad	doc_187964557898_item	2255842	et	3	main
mind	doc_187964557898_item	2255844	et	4	main
aga	doc_187964557898_item	2255850	et	3	main
ja	doc_187964557898_item	2255854	et	3	main
osakondes	doc_187964557898_item	2255856	et	3	main
ümbritseb	doc_177993561443_item	2255300	et	3	main
olema	doc_177993561443_item	2255307	et	4	main
ka	doc_177993561443_item	2255314	et	3	main
valvab	doc_177993561444_item	2255323	et	3	main
objektid	doc_177993561444_item	2255325	et	3	main
eest	doc_177993561444_item	2255329	et	4	main
ta	doc_177993561444_item	2255330	et	4	main
peab	doc_177993561444_item	2255331	et	4	main
ta	doc_177993561444_item	2255336	et	4	main
või	doc_177993561444_item	2255339	et	4	main
vastutab	doc_177993561444_item	2255347	et	3	main
eest	doc_177993561444_item	2255349	et	4	main
esinduslik	doc_177993561444_item	2255359	et	3	main
tarkus	doc_177993561444_item	2255365	et	4	main
kõiki	doc_177993561445_item	2255377	et	4	main
jne	doc_177993561445_item	2255384	et	4	main
suhtlema	doc_177993561445_item	2255392	et	3	main
õpilastega	doc_177993561445_item	2255394	et	4	main
nõuab	doc_177993561445_item	2255397	et	3	main
ravima	doc_177993561445_item	2255406	et	4	main
teha	doc_177993561445_item	2255415	et	3	main
ta	doc_177993561444_item	2255326	et	4	main
korra	doc_177993561444_item	2255328	et	4	main
füüsiliselt	doc_177993561444_item	2255333	et	4	main
firmat	doc_177993561444_item	2255345	et	3	main
ta	doc_177993561444_item	2255346	et	4	main
peab	doc_177993561444_item	2255351	et	4	main
jälgima	doc_177993561444_item	2255352	et	4	main
kõikide	doc_177993561444_item	2255353	et	4	main
firmajuht	doc_177993561444_item	2255355	et	3	main
peab	doc_177993561444_item	2255356	et	4	main
eest	doc_177993561444_item	2255354	et	4	main
ettevõtlik	doc_177993561444_item	2255358	et	3	main
olema	doc_177993561444_item	2255357	et	4	main
on	doc_177993561444_item	2255362	et	4	main
tema	doc_177993561444_item	2255363	et	4	main
p	doc_177993561444_item	2255366	et	4	main
kirjeldus	doc_177993561445_item	2255368	et	4	main
õpetaja	doc_177993561445_item	2255374	et	4	main
saab	doc_177993561445_item	2255375	et	3	main
koolis	doc_177993561445_item	2255382	et	4	main
peab	doc_177993561445_item	2255386	et	4	main
hästi	doc_177993561445_item	2255391	et	3	main
töö	doc_177993561445_item	2255396	et	4	main
oskusi	doc_177993561445_item	2255399	et	3	main
vastupanu	doc_177993561445_item	2255402	et	4	main
peab	doc_177993561445_item	2255405	et	4	main
tema	doc_177993561445_item	2255408	et	4	main
õiget	doc_177993561445_item	2255416	et	3	main
arst	doc_177993561445_item	2255418	et	3	main
peab	doc_177993561445_item	2255419	et	4	main
juhtus	doc_177993561445_item	2255425	et	3	main
p	doc_177993561445_item	2255435	et	4	main
igaks	doc_177993561446_item	2255449	et	3	main
kerge	doc_177993561446_item	2255455	et	4	main
töö	doc_177993561446_item	2255461	et	4	main
olema	doc_177993561446_item	2255464	et	4	main
külmavereline	doc_177993561446_item	2255465	et	4	main
vastu	doc_177993561446_item	2255475	et	3	main
peab	doc_177993561446_item	2255478	et	4	main
õpetama	doc_177993561446_item	2255479	et	3	main
amet	doc_177993561447_item	2255515	et	3	main
inimene	doc_177993561447_item	2255516	et	3	main
kuulama	doc_177993561445_item	2255423	et	3	main
suuri	doc_177993561445_item	2255430	et	3	main
seda	doc_177993561446_item	2255444	et	3	main
peab	doc_177993561446_item	2255446	et	4	main
tema	doc_177993561446_item	2255451	et	4	main
see	doc_177993561446_item	2255457	et	3	main
väga	doc_177993561446_item	2255459	et	3	main
kõike	doc_177993561446_item	2255469	et	4	main
ta	doc_177993561446_item	2255477	et	4	main
lapsi	doc_177993561446_item	2255480	et	4	main
kooliprogrammi	doc_177993561446_item	2255482	et	4	main
järgi	doc_177993561446_item	2255483	et	4	main
kui	doc_177993561446_item	2255484	et	3	main
ka	doc_177993561446_item	2255485	et	3	main
oma	doc_177993561446_item	2255486	et	4	main
kogemuste	doc_177993561446_item	2255487	et	3	main
järgi	doc_177993561446_item	2255488	et	4	main
kuidas	doc_177993561446_item	2255489	et	3	main
vastu	doc_177993561446_item	2255490	et	3	main
pidama	doc_177993561446_item	2255491	et	4	main
selles	doc_177993561446_item	2255492	et	4	main
maailmas	doc_177993561446_item	2255493	et	3	main
õpetaja	doc_177993561446_item	2255494	et	4	main
peab	doc_177993561446_item	2255495	et	4	main
olema	doc_177993561446_item	2255496	et	4	main
rahulik	doc_177993561446_item	2255497	et	3	main
kuid	doc_177993561446_item	2255498	et	4	main
ka	doc_177993561446_item	2255499	et	3	main
korrapeetja	doc_177993561446_item	2255500	et	4	main
ta	doc_177993561446_item	2255501	et	4	main
peab	doc_177993561446_item	2255502	et	4	main
olema	doc_177993561446_item	2255503	et	4	main
rõõmus	doc_177993561446_item	2255504	et	4	main
ja	doc_177993561446_item	2255505	et	3	main
sõbralik	doc_177993561446_item	2255506	et	3	main
ametite	doc_177993561447_item	2255507	et	3	main
kirjeldus	doc_177993561447_item	2255508	et	4	main
geodeesia	doc_177993561447_item	2255509	et	4	main
see	doc_177993561447_item	2255510	et	3	main
ei	doc_177993561447_item	2255511	et	4	main
ole	doc_177993561447_item	2255512	et	4	main
väga	doc_177993561447_item	2255513	et	3	main
kerge	doc_177993561447_item	2255514	et	4	main
peab	doc_177993561447_item	2255517	et	4	main
olema	doc_177993561447_item	2255518	et	4	main
töökas	doc_177993561447_item	2255521	et	4	main
niiveliiriga	doc_177993561447_item	2255525	et	4	main
vaja	doc_177993561447_item	2255530	et	4	main
lahendada	doc_177993561447_item	2255531	et	3	main
mis	doc_177993561447_item	2255538	et	4	main
arst	doc_177993561447_item	2255545	et	3	main
raske	doc_177993561447_item	2255549	et	4	main
peab	doc_177993561447_item	2255563	et	4	main
nõudnik	doc_177993561447_item	2255569	et	4	main
sul	doc_177993561447_item	2255522	et	3	main
probleeme	doc_177993561447_item	2255533	et	3	main
ja	doc_177993561447_item	2255536	et	3	main
sellega	doc_177993561447_item	2255539	et	3	main
sa	doc_177993561447_item	2255553	et	3	main
ja	doc_177993561447_item	2255560	et	3	main
sellele	doc_177993561447_item	2255570	et	4	main
oli	doc_177993561447_item	2255572	et	3	main
vaja	doc_177993561447_item	2255573	et	4	main
töötad	doc_177993561447_item	2255574	et	3	main
paljuga	doc_177993561447_item	2255575	et	3	main
instrumentiga	doc_177993561447_item	2255576	et	4	main
sul	doc_177993561447_item	2255577	et	3	main
peab	doc_177993561447_item	2255578	et	4	main
olema	doc_177993561447_item	2255579	et	4	main
diploom	doc_177993561447_item	2255580	et	4	main
ja	doc_177993561447_item	2255581	et	3	main
praktika	doc_177993561447_item	2255582	et	4	main
tööd	doc_177993561447_item	2255583	et	4	main
elasin	doc_187964557897_item	2255680	et	3	main
ja	doc_187964557897_item	2255682	et	3	main
praigu	doc_187964557897_item	2255687	et	4	main
väga	doc_187964557897_item	2255728	et	3	main
ma	doc_187964557897_item	2255737	et	3	main
tahan	doc_187964557897_item	2255738	et	3	main
kirjutama	doc_187964557897_item	2255746	et	3	main
mina	doc_187964557898_item	2255757	et	4	main
ülikool	doc_187964557898_item	2255759	et	4	main
kool	doc_187964557898_item	2255764	et	4	main
tagasi	doc_187964557898_item	2255772	et	3	main
ma	doc_187964557898_item	2255782	et	3	main
essee	doc_187964557897_item	2255675	et	4	main
mina	doc_187964557897_item	2255676	et	4	main
ja	doc_187964557897_item	2255677	et	3	main
ma	doc_187964557897_item	2255688	et	3	main
tulen	doc_187964557897_item	2255689	et	3	main
tallinnas	doc_187964557897_item	2255690	et	4	main
õpima	doc_187964557897_item	2255691	et	4	main
ttu	doc_187964557897_item	2255692	et	4	main
ma	doc_187964557897_item	2255693	et	3	main
mõtlin	doc_187964557897_item	2255694	et	4	main
et	doc_187964557897_item	2255695	et	3	main
õpivad	doc_187964557897_item	2255696	et	3	main
ttu	doc_187964557897_item	2255697	et	4	main
väga	doc_187964557897_item	2255698	et	3	main
pristizne	doc_187964557897_item	2255699	et	4	main
ja	doc_187964557897_item	2255700	et	3	main
huvitav	doc_187964557897_item	2255701	et	4	main
siis	doc_187964557897_item	2255702	et	3	main
on	doc_187964557897_item	2255703	et	4	main
väga	doc_187964557897_item	2255704	et	3	main
palju	doc_187964557897_item	2255705	et	4	main
perspektivid	doc_187964557897_item	2255706	et	4	main
kus	doc_187964557897_item	2255707	et	3	main
päiv	doc_187964557897_item	2255709	et	4	main
esmas	doc_187964557897_item	2255708	et	4	main
ma	doc_187964557897_item	2255710	et	3	main
tulesin	doc_187964557897_item	2255711	et	4	main
ttus	doc_187964557897_item	2255712	et	4	main
mul	doc_187964557897_item	2255713	et	3	main
oli	doc_187964557897_item	2255714	et	3	main
hastid	doc_187964557897_item	2255715	et	4	main
ja	doc_187964557897_item	2255716	et	3	main
huvitav	doc_187964557897_item	2255717	et	4	main
muljed	doc_187964557897_item	2255718	et	3	main
see	doc_187964557897_item	2255719	et	3	main
on	doc_187964557897_item	2255720	et	4	main
pedagogid	doc_187964557897_item	2255726	et	4	main
sõbrad	doc_187964557897_item	2255731	et	3	main
keele	doc_187964557897_item	2255736	et	4	main
ülikool	doc_187964557897_item	2255678	et	4	main
kohtla-järves	doc_187964557897_item	2255681	et	4	main
kesklina	doc_187964557897_item	2255684	et	4	main
aga	doc_187964557897_item	2255686	et	3	main
klaasid	doc_187964557897_item	2255722	et	4	main
ja	doc_187964557897_item	2255727	et	3	main
üsed	doc_187964557897_item	2255730	et	4	main
see	doc_187964557897_item	2255753	et	3	main
realiserima	doc_187964557897_item	2255755	et	4	main
ma	doc_187964557898_item	2255762	et	3	main
ma	doc_187964557898_item	2255773	et	3	main
pärast	doc_187964557898_item	2255776	et	4	main
spordiga	doc_187964557898_item	2255779	et	3	main
astusin	doc_187964557898_item	2255790	et	3	main
meeldip	doc_187964557898_item	2255823	et	4	main
palju	doc_187964557898_item	2255833	et	4	main
kaks	doc_187964557898_item	2255840	et	3	main
keel	doc_187964557898_item	2255849	et	4	main
ma	doc_187964557898_item	2255862	et	3	main
eestis	doc_187964557898_item	2255864	et	3	main
teada	doc_187964557898_item	2255868	et	3	main
on	doc_187964557898_item	2255874	et	4	main
väga	doc_187964557898_item	2255875	et	3	main
ujumine	doc_187964557899_item	2255907	et	4	main
väga	doc_187964557899_item	2255913	et	3	main
ttüsse	doc_187964557899_item	2255917	et	4	main
sest	doc_187964557899_item	2255921	et	4	main
on	doc_187964557899_item	2255923	et	4	main
või	doc_187964557899_item	2255930	et	4	main
ttüs	doc_187964557899_item	2255933	et	4	main
erineb	doc_187964557899_item	2255934	et	3	main
gümnasiuumis	doc_187964557899_item	2255936	et	4	main
reeglid	doc_187964557899_item	2255940	et	3	main
palju	doc_187964557899_item	2255951	et	4	main
rohkem	doc_187964557899_item	2255952	et	4	main
essee	doc_187964557900_item	2255985	et	4	main
ülikool	doc_187964557900_item	2255988	et	4	main
maailmas	doc_187964557900_item	2255990	et	3	main
tähtis	doc_187964557900_item	2255994	et	4	main
inimestele	doc_187964557900_item	2255996	et	3	main
haridus	doc_187964557900_item	2256021	et	3	main
sugulastest	doc_187964557900_item	2256050	et	4	main
kui	doc_187964557900_item	2256054	et	3	main
ja	doc_187964557900_item	2256056	et	3	main
ka	doc_187964557900_item	2256068	et	3	main
nad	doc_187964557900_item	2256076	et	3	main
õpisin	doc_187964557897_item	2255683	et	4	main
gümnaasium	doc_187964557897_item	2255685	et	3	main
targad	doc_187964557897_item	2255725	et	3	main
palju	doc_187964557897_item	2255729	et	4	main
ma	doc_187964557897_item	2255733	et	3	main
eesti	doc_187964557897_item	2255735	et	4	main
rägima	doc_187964557897_item	2255744	et	4	main
ja	doc_187964557897_item	2255749	et	3	main
ja	doc_187964557898_item	2255758	et	3	main
lõpetasin	doc_187964557898_item	2255763	et	3	main
kõik	doc_187964557898_item	2255765	et	4	main
suvel	doc_187964557898_item	2255766	et	3	main
ma	doc_187964557898_item	2255767	et	3	main
kaks	doc_187964557898_item	2255770	et	3	main
aastat	doc_187964557898_item	2255771	et	3	main
ma	doc_187964557898_item	2255777	et	3	main
ma	doc_187964557898_item	2255789	et	3	main
sest	doc_187964557898_item	2255792	et	4	main
et	doc_187964557898_item	2255793	et	3	main
mulle	doc_187964557898_item	2255794	et	4	main
meeldib	doc_187964557898_item	2255795	et	3	main
see	doc_187964557898_item	2255796	et	3	main
eriala	doc_187964557898_item	2255797	et	4	main
mulle	doc_187964557898_item	2255798	et	4	main
meeldin	doc_187964557898_item	2255799	et	3	main
ka	doc_187964557898_item	2255800	et	3	main
ehitaja	doc_187964557898_item	2255801	et	4	main
fakultet	doc_187964557898_item	2255802	et	4	main
aga	doc_187964557898_item	2255803	et	3	main
ma	doc_187964557898_item	2255804	et	3	main
astusin	doc_187964557898_item	2255805	et	3	main
mehannikasse	doc_187964557898_item	2255806	et	4	main
ttüs	doc_187964557898_item	2255807	et	4	main
on	doc_187964557898_item	2255808	et	4	main
huvitavaid	doc_187964557898_item	2255810	et	4	main
erialad	doc_187964557898_item	2255811	et	3	main
palju	doc_187964557898_item	2255809	et	4	main
palju	doc_187964557898_item	2255812	et	4	main
minu	doc_187964557898_item	2255813	et	3	main
sõbrad	doc_187964557898_item	2255814	et	3	main
astusin	doc_187964557898_item	2255815	et	3	main
energeetikusse	doc_187964557898_item	2255816	et	3	main
fakultetis	doc_187964557898_item	2255817	et	4	main
mulle	doc_187964557898_item	2255818	et	4	main
meeldib	doc_187964557898_item	2255819	et	3	main
õppida	doc_187964557898_item	2255820	et	3	main
ttüs	doc_187964557898_item	2255821	et	4	main
inimesed	doc_187964557898_item	2255824	et	3	main
koos	doc_187964557898_item	2255827	et	4	main
mulle	doc_187964557898_item	2255829	et	4	main
tallinnas	doc_187964557898_item	2255832	et	4	main
sõbrad	doc_187964557898_item	2255835	et	3	main
kolm	doc_187964557898_item	2255838	et	3	main
aitavad	doc_187964557898_item	2255843	et	4	main
koolis	doc_187964557898_item	2255845	et	4	main
mul	doc_187964557898_item	2255846	et	3	main
eesti	doc_187964557897_item	2255740	et	4	main
keel	doc_187964557897_item	2255741	et	4	main
väga	doc_187964557897_item	2255742	et	3	main
ja	doc_187964557897_item	2255745	et	3	main
keel	doc_187964557897_item	2255748	et	4	main
ma	doc_187964557897_item	2255750	et	3	main
et	doc_187964557897_item	2255752	et	3	main
on	doc_187964557897_item	2255754	et	4	main
essee	doc_187964557898_item	2255756	et	4	main
sellel	doc_187964557898_item	2255760	et	4	main
ehitajana	doc_187964557898_item	2255769	et	4	main
lõpetasin	doc_187964557898_item	2255774	et	3	main
tegelesin	doc_187964557898_item	2255778	et	3	main
suvel	doc_187964557898_item	2255780	et	3	main
tallinna	doc_187964557898_item	2255784	et	4	main
ülikoolis	doc_187964557898_item	2255786	et	4	main
mehannikase	doc_187964557898_item	2255787	et	4	main
fakultetis	doc_187964557898_item	2255788	et	4	main
mehannikasse	doc_187964557898_item	2255791	et	4	main
elada	doc_187964557898_item	2255831	et	3	main
aastat	doc_187964557898_item	2255841	et	3	main
eesti	doc_187964557898_item	2255848	et	4	main
pean	doc_187964557898_item	2255867	et	4	main
eesti	doc_187964557898_item	2255871	et	4	main
see	doc_187964557898_item	2255873	et	3	main
autojuhatamine	doc_187964557899_item	2255910	et	3	main
astusin	doc_187964557899_item	2255916	et	3	main
tootmistehnika	doc_187964557899_item	2255918	et	4	main
eriala	doc_187964557899_item	2255919	et	4	main
õppima	doc_187964557899_item	2255920	et	3	main
see	doc_187964557899_item	2255922	et	3	main
arendav	doc_187964557899_item	2255925	et	4	main
suurega	doc_187964557899_item	2255927	et	4	main
amet	doc_187964557899_item	2255929	et	3	main
õppimine	doc_187964557899_item	2255932	et	4	main
rohkem	doc_187964557899_item	2255939	et	4	main
muljet	doc_187964557899_item	2255954	et	3	main
ootan	doc_187964557899_item	2255962	et	3	main
õppimises	doc_187964557899_item	2255969	et	4	main
eesti	doc_187964557899_item	2255970	et	4	main
keel	doc_187964557899_item	2255971	et	4	main
ja	doc_187964557899_item	2255972	et	3	main
teised	doc_187964557899_item	2255973	et	4	main
head	doc_187964557899_item	2255979	et	4	main
on	doc_187964557899_item	2255982	et	4	main
kõik	doc_187964557899_item	2255983	et	4	main
ja	doc_187964557900_item	2255987	et	3	main
kõrgharidus	doc_187964557900_item	2255991	et	3	main
töökohti	doc_187964557900_item	2256025	et	4	main
liiga	doc_187964557900_item	2256038	et	4	main
saada	doc_187964557900_item	2256042	et	4	main
tekib	doc_187964557900_item	2256044	et	3	main
eriti	doc_187964557900_item	2256052	et	3	main
vanematest	doc_187964557900_item	2256053	et	4	main
ema	doc_187964557900_item	2256055	et	4	main
lapsel	doc_187964557900_item	2256062	et	4	main
on	doc_187964557900_item	2256063	et	4	main
saada	doc_187964557900_item	2256067	et	4	main
ja	doc_187964557900_item	2256070	et	3	main
avaldavad	doc_187964557900_item	2256072	et	4	main
oma	doc_187964557900_item	2256073	et	4	main
seal	doc_187964557900_item	2256083	et	4	main
on	doc_187964557900_item	2256117	et	4	main
ka	doc_187964557900_item	2256119	et	3	main
vajalik	doc_187964557900_item	2256126	et	3	main
mind	doc_187964557900_item	2256133	et	4	main
nende	doc_187964557900_item	2256148	et	4	main
mina	doc_187964557901_item	2256152	et	4	main
ja	doc_187964557901_item	2256153	et	3	main
ülikool	doc_187964557901_item	2256154	et	4	main
kaheksateistkümnene	doc_187964557901_item	2256159	et	3	main
ammu	doc_187964557901_item	2256176	et	4	main
sellepärast	doc_187964557901_item	2256177	et	3	main
palju	doc_187964557901_item	2256186	et	4	main
nad	doc_187964557901_item	2256194	et	3	main
asju	doc_187964557901_item	2256199	et	3	main
ülikool	doc_187964557901_item	2256204	et	4	main
õpivad	doc_187964557901_item	2256206	et	3	main
miks	doc_187964557901_item	2256213	et	4	main
ma	doc_187964557901_item	2256214	et	3	main
juba	doc_187964557901_item	2256218	et	3	main
meeldib	doc_187964557901_item	2256221	et	3	main
kes	doc_187964557898_item	2255825	et	4	main
õpivad	doc_187964557898_item	2255826	et	3	main
minuga	doc_187964557898_item	2255828	et	3	main
minu	doc_187964557898_item	2255834	et	3	main
õppivad	doc_187964557898_item	2255836	et	4	main
elan	doc_187964557898_item	2255852	et	3	main
ida-virumaas	doc_187964557898_item	2255853	et	3	main
selles	doc_187964557898_item	2255855	et	4	main
palju	doc_187964557898_item	2255857	et	4	main
inimesed	doc_187964557898_item	2255858	et	3	main
räägivad	doc_187964557898_item	2255859	et	3	main
keelte	doc_187964557898_item	2255861	et	3	main
elan	doc_187964557898_item	2255863	et	3	main
riigi	doc_187964557898_item	2255869	et	3	main
olulise	doc_187964557898_item	2255876	et	4	main
essee	doc_187964557899_item	2255878	et	4	main
tere	doc_187964557899_item	2255882	et	3	main
minu	doc_187964557899_item	2255883	et	3	main
nimi	doc_187964557899_item	2255884	et	3	main
on	doc_187964557899_item	2255885	et	4	main
eesnimi	doc_187964557899_item	2255886	et	3	main
ma	doc_187964557899_item	2255887	et	3	main
lõpetasin	doc_187964557899_item	2255888	et	3	main
sellel	doc_187964557899_item	2255889	et	4	main
aastal	doc_187964557899_item	2255890	et	3	main
sillamäe	doc_187964557899_item	2255891	et	3	main
kannuka	doc_187964557899_item	2255892	et	4	main
kool	doc_187964557899_item	2255893	et	4	main
ma	doc_187964557899_item	2255894	et	3	main
olen	doc_187964557899_item	2255895	et	3	main
üheksateist	doc_187964557899_item	2255896	et	4	main
aastane	doc_187964557899_item	2255898	et	4	main
minu	doc_187964557899_item	2255899	et	3	main
kümne	doc_187964557899_item	2255897	et	4	main
lemmikaine	doc_187964557899_item	2255900	et	4	main
koolis	doc_187964557899_item	2255901	et	4	main
oli	doc_187964557899_item	2255902	et	3	main
matemaatika	doc_187964557899_item	2255903	et	4	main
minu	doc_187964557899_item	2255904	et	3	main
hobisid	doc_187964557899_item	2255905	et	3	main
on	doc_187964557899_item	2255906	et	4	main
jooksmine	doc_187964557899_item	2255908	et	4	main
ja	doc_187964557899_item	2255909	et	3	main
on	doc_187964557898_item	2255847	et	4	main
ma	doc_187964557898_item	2255851	et	3	main
vene	doc_187964557898_item	2255860	et	4	main
ja	doc_187964557898_item	2255865	et	3	main
ja	doc_187964557899_item	2255880	et	3	main
ülikool	doc_187964557899_item	2255881	et	4	main
ma	doc_187964557899_item	2255911	et	3	main
see	doc_187964557899_item	2255944	et	3	main
elu	doc_187964557899_item	2255947	et	4	main
jatkab	doc_187964557899_item	2255950	et	4	main
toredad	doc_187964557899_item	2255953	et	3	main
kui	doc_187964557899_item	2255955	et	3	main
ja	doc_187964557899_item	2255965	et	3	main
nõuavad	doc_187964557899_item	2255975	et	4	main
palju	doc_187964557899_item	2255976	et	4	main
ja	doc_187964557899_item	2255978	et	3	main
eesnimi	doc_187964557899_item	2255984	et	3	main
mina	doc_187964557900_item	2255986	et	4	main
tänapäevases	doc_187964557900_item	2255989	et	4	main
hariduseta	doc_187964557900_item	2255995	et	3	main
on	doc_187964557900_item	2256023	et	4	main
ei	doc_187964557900_item	2256027	et	4	main
mingit	doc_187964557900_item	2256030	et	3	main
haridust	doc_187964557900_item	2256031	et	4	main
aga	doc_187964557900_item	2256032	et	3	main
siis	doc_187964557900_item	2256033	et	3	main
madal	doc_187964557900_item	2256039	et	3	main
soov	doc_187964557900_item	2256041	et	3	main
kõrgharidust	doc_187964557900_item	2256043	et	4	main
ja	doc_187964557900_item	2256051	et	3	main
isa	doc_187964557900_item	2256057	et	4	main
on	doc_187964557900_item	2256058	et	4	main
hariduseta	doc_187964557900_item	2256059	et	3	main
siis	doc_187964557900_item	2256060	et	3	main
ka	doc_187964557900_item	2256061	et	3	main
seda	doc_187964557900_item	2256066	et	3	main
kõik	doc_187964557900_item	2256077	et	4	main
töötavad	doc_187964557900_item	2256078	et	4	main
näiteks	doc_187964557900_item	2256079	et	4	main
tassivad	doc_187964557900_item	2256082	et	4	main
siis	doc_187964557900_item	2256085	et	3	main
olen	doc_187964557900_item	2256127	et	3	main
kõik	doc_187964557900_item	2256135	et	4	main
sõbrad	doc_187964557900_item	2256137	et	3	main
nagu	doc_187964557900_item	2256141	et	3	main
ütlesin	doc_187964557900_item	2256144	et	3	main
erituma	doc_187964557900_item	2256150	et	4	main
essee	doc_187964557901_item	2256151	et	4	main
aastane	doc_187964557901_item	2256160	et	4	main
gümnaasiumi	doc_187964557901_item	2256168	et	4	main
ja	doc_187964557901_item	2256169	et	3	main
astusin	doc_187964557901_item	2256170	et	3	main
meeldib	doc_187964557901_item	2256173	et	3	main
siin	doc_187964557901_item	2256181	et	4	main
inimesed	doc_187964557901_item	2256184	et	3	main
palju	doc_187964557901_item	2256190	et	4	main
mu	doc_187964557901_item	2256191	et	3	main
sõpru	doc_187964557901_item	2256192	et	3	main
ja	doc_187964557901_item	2256193	et	3	main
häid	doc_187964557901_item	2256198	et	3	main
on	doc_187964557901_item	2256201	et	4	main
palju	doc_187964557901_item	2256207	et	4	main
inimesi	doc_187964557901_item	2256208	et	4	main
ja	doc_187964557901_item	2256209	et	3	main
tesduskond	doc_187964557901_item	2256217	et	4	main
lapsepõlvest	doc_187964557901_item	2256219	et	4	main
ei	doc_187964557901_item	2256229	et	4	main
raamatupidajana	doc_187964557901_item	2256232	et	3	main
on	doc_187964557901_item	2256240	et	4	main
avada	doc_187964557901_item	2256245	et	3	main
veel	doc_187964557901_item	2256249	et	4	main
on	doc_187964557901_item	2256250	et	4	main
olla	doc_187964557901_item	2256262	et	3	main
mulle	doc_187964557901_item	2256265	et	4	main
tahaksin	doc_187964557901_item	2256271	et	3	main
suudan	doc_187964557901_item	2256278	et	3	main
kuidas	doc_187964557901_item	2256283	et	3	main
ma	doc_187964557898_item	2255866	et	3	main
keel	doc_187964557898_item	2255870	et	4	main
keel	doc_187964557898_item	2255872	et	4	main
minuga	doc_187964557898_item	2255877	et	3	main
mina	doc_187964557899_item	2255879	et	4	main
rahul	doc_187964557899_item	2255914	et	4	main
olen	doc_187964557899_item	2255912	et	3	main
et	doc_187964557899_item	2255915	et	3	main
väga	doc_187964557899_item	2255924	et	3	main
elusuund	doc_187964557899_item	2255931	et	3	main
on	doc_187964557899_item	2255938	et	4	main
aga	doc_187964557899_item	2255941	et	3	main
vabadust	doc_187964557899_item	2255943	et	4	main
on	doc_187964557899_item	2255945	et	4	main
muu	doc_187964557899_item	2255946	et	4	main
halba	doc_187964557899_item	2255956	et	4	main
tundist	doc_187964557899_item	2255958	et	4	main
infot	doc_187964557899_item	2255964	et	3	main
abit	doc_187964557899_item	2255966	et	4	main
keele	doc_187964557899_item	2255968	et	4	main
keeled	doc_187964557899_item	2255974	et	3	main
aega	doc_187964557899_item	2255977	et	4	main
on	doc_187964557900_item	2255992	et	4	main
ja	doc_187964557899_item	2255926	et	3	main
palkaga	doc_187964557899_item	2255928	et	4	main
õppimisest	doc_187964557899_item	2255935	et	4	main
nüüd	doc_187964557899_item	2255937	et	4	main
ka	doc_187964557899_item	2255942	et	3	main
ja	doc_187964557899_item	2255948	et	3	main
see	doc_187964557899_item	2255949	et	3	main
sellest	doc_187964557899_item	2255957	et	4	main
ja	doc_187964557899_item	2255959	et	3	main
jargmistest	doc_187964557899_item	2255960	et	4	main
ma	doc_187964557899_item	2255961	et	3	main
arusaadavat	doc_187964557899_item	2255963	et	3	main
eesti	doc_187964557899_item	2255967	et	4	main
õpetajat	doc_187964557899_item	2255980	et	4	main
see	doc_187964557899_item	2255981	et	3	main
väga	doc_187964557900_item	2255993	et	3	main
on	doc_187964557900_item	2255997	et	4	main
raskem	doc_187964557900_item	2255998	et	4	main
leida	doc_187964557900_item	2255999	et	3	main
tööd	doc_187964557900_item	2256000	et	4	main
ja	doc_187964557900_item	2256001	et	3	main
kahjuks	doc_187964557900_item	2256002	et	4	main
ka	doc_187964557900_item	2256003	et	3	main
palk	doc_187964557900_item	2256004	et	3	main
ei	doc_187964557900_item	2256005	et	4	main
ole	doc_187964557900_item	2256006	et	4	main
rahuldav	doc_187964557900_item	2256007	et	4	main
ma	doc_187964557900_item	2256008	et	3	main
ise	doc_187964557900_item	2256009	et	4	main
astusin	doc_187964557900_item	2256010	et	3	main
ülikooli	doc_187964557900_item	2256011	et	4	main
sellepärast	doc_187964557900_item	2256012	et	3	main
et	doc_187964557900_item	2256013	et	3	main
olen	doc_187964557900_item	2256014	et	3	main
kindel	doc_187964557900_item	2256015	et	3	main
et	doc_187964557900_item	2256016	et	3	main
inimesel	doc_187964557900_item	2256017	et	3	main
olema	doc_187964557900_item	2256019	et	4	main
peab	doc_187964557900_item	2256018	et	4	main
hea	doc_187964557900_item	2256020	et	4	main
palju	doc_187964557900_item	2256024	et	4	main
on	doc_187964557900_item	2256035	et	4	main
teadmistele	doc_187964557900_item	2256037	et	4	main
keskkonnast	doc_187964557900_item	2256046	et	4	main
tuttavatest	doc_187964557900_item	2256049	et	4	main
tõuge	doc_187964557900_item	2256065	et	4	main
ja	doc_187964557900_item	2256081	et	3	main
telliskive	doc_187964557900_item	2256084	et	3	main
õpima	doc_187964557900_item	2256120	et	4	main
kõrgharidus	doc_187964557900_item	2256123	et	3	main
et	doc_187964557900_item	2256130	et	3	main
aitab	doc_187964557900_item	2256132	et	3	main
ülikoolides	doc_187964557900_item	2256139	et	3	main
ma	doc_187964557900_item	2256142	et	3	main
eesnimi	doc_187964557901_item	2256156	et	3	main
olen	doc_187964557901_item	2256158	et	3	main
tüdruk	doc_187964557901_item	2256161	et	3	main
maardus	doc_187964557901_item	2256163	et	4	main
muidugi	doc_187964557900_item	2256022	et	4	main
mis	doc_187964557900_item	2256026	et	4	main
vaja	doc_187964557900_item	2256028	et	4	main
üldse	doc_187964557900_item	2256029	et	3	main
palk	doc_187964557900_item	2256034	et	3	main
võrdne	doc_187964557900_item	2256036	et	3	main
inimese	doc_187964557900_item	2256040	et	4	main
tema	doc_187964557900_item	2256045	et	4	main
palju	doc_187964557900_item	2256047	et	4	main
oleneb	doc_187964557900_item	2256048	et	3	main
vähem	doc_187964557900_item	2256064	et	4	main
sõbrad	doc_187964557900_item	2256069	et	3	main
tuttavad	doc_187964557900_item	2256071	et	4	main
mõju	doc_187964557900_item	2256074	et	4	main
kui	doc_187964557900_item	2256075	et	3	main
ehitusplatsil	doc_187964557900_item	2256080	et	3	main
inimene	doc_187964557900_item	2256086	et	3	main
ei	doc_187964557900_item	2256087	et	4	main
hakka	doc_187964557900_item	2256088	et	4	main
nende	doc_187964557900_item	2256089	et	4	main
hulgast	doc_187964557900_item	2256090	et	4	main
erituma	doc_187964557900_item	2256091	et	4	main
mõned	doc_187964557900_item	2256092	et	3	main
kardavad	doc_187964557900_item	2256093	et	4	main
raskusi	doc_187964557900_item	2256094	et	4	main
mis	doc_187964557900_item	2256095	et	4	main
võivad	doc_187964557900_item	2256096	et	4	main
tekkida	doc_187964557900_item	2256097	et	3	main
õpimise	doc_187964557900_item	2256098	et	4	main
protsessis	doc_187964557900_item	2256099	et	4	main
paljude	doc_187964557900_item	2256100	et	3	main
jaoks	doc_187964557900_item	2256101	et	4	main
see	doc_187964557900_item	2256102	et	3	main
on	doc_187964557900_item	2256103	et	4	main
üsna	doc_187964557900_item	2256104	et	3	main
kallis	doc_187964557900_item	2256105	et	4	main
seepärast	doc_187964557900_item	2256106	et	3	main
õpilane	doc_187964557900_item	2256107	et	3	main
töötab	doc_187964557900_item	2256108	et	3	main
ja	doc_187964557900_item	2256109	et	3	main
kahjuks	doc_187964557900_item	2256110	et	4	main
paljud	doc_187964557900_item	2256111	et	3	main
oma	doc_187964557900_item	2256112	et	4	main
töö	doc_187964557900_item	2256113	et	4	main
pärast	doc_187964557900_item	2256114	et	4	main
unustavad	doc_187964557900_item	2256115	et	4	main
et	doc_187964557900_item	2256116	et	3	main
vaja	doc_187964557900_item	2256118	et	4	main
minu	doc_187964557900_item	2256121	et	3	main
on	doc_187964557900_item	2256124	et	4	main
tõesti	doc_187964557900_item	2256125	et	3	main
kindel	doc_187964557900_item	2256128	et	3	main
minu	doc_187964557900_item	2256136	et	3	main
juba	doc_187964557900_item	2256143	et	3	main
ei	doc_187964557900_item	2256146	et	4	main
mina	doc_187964557901_item	2256155	et	4	main
perekonnanimi	doc_187964557901_item	2256157	et	3	main
aastal	doc_187964557901_item	2256165	et	3	main
maardu	doc_187964557901_item	2256167	et	4	main
ttüs	doc_187964557901_item	2256171	et	4	main
olin	doc_187964557901_item	2256180	et	3	main
ja	doc_187964557901_item	2256183	et	3	main
siin	doc_187964557901_item	2256188	et	4	main
palju	doc_187964557901_item	2256197	et	4	main
kvalifitseeritud	doc_187964557901_item	2256211	et	4	main
jaoks	doc_187964557900_item	2256122	et	4	main
selles	doc_187964557900_item	2256129	et	4	main
see	doc_187964557900_item	2256131	et	3	main
tulevikus	doc_187964557900_item	2256134	et	4	main
õpivad	doc_187964557900_item	2256138	et	3	main
ja	doc_187964557900_item	2256140	et	3	main
ma	doc_187964557900_item	2256145	et	3	main
taha	doc_187964557900_item	2256147	et	4	main
hulgast	doc_187964557900_item	2256149	et	4	main
elan	doc_187964557901_item	2256162	et	3	main
lõpetasin	doc_187964557901_item	2256166	et	3	main
ttü	doc_187964557901_item	2256172	et	4	main
ma	doc_187964557901_item	2256179	et	3	main
rääkisid	doc_187964557901_item	2256185	et	4	main
huvitavaid	doc_187964557901_item	2256187	et	4	main
õpivad	doc_187964557901_item	2256189	et	3	main
ka	doc_187964557901_item	2256195	et	3	main
ttü	doc_187964557901_item	2256200	et	4	main
kõige	doc_187964557901_item	2256202	et	4	main
väga	doc_187964557901_item	2256210	et	3	main
õppejõud	doc_187964557901_item	2256212	et	4	main
valisin	doc_187964557901_item	2256215	et	3	main
juhtuda	doc_187964557901_item	2256226	et	3	main
tööta	doc_187964557901_item	2256230	et	4	main
näiteks	doc_187964557901_item	2256231	et	4	main
aga	doc_187964557901_item	2256233	et	3	main
majanduses	doc_187964557901_item	2256237	et	4	main
võin	doc_187964557901_item	2256244	et	3	main
minu	doc_187964557901_item	2256254	et	3	main
ja	doc_187964557901_item	2256256	et	3	main
kõik	doc_187964557901_item	2256280	et	4	main
minust	doc_187964557901_item	2256282	et	3	main
ülikool	doc_187964557903_item	2256432	et	4	main
minu	doc_187964557903_item	2256433	et	3	main
kõik	doc_187964557903_item	2256439	et	4	main
paljud	doc_187964557903_item	2256442	et	3	main
vened	doc_187964557903_item	2256443	et	3	main
nimetakse	doc_187964557903_item	2256444	et	3	main
perekonna	doc_187964557903_item	2256446	et	4	main
kuus	doc_187964557903_item	2256458	et	4	main
riigieksamid	doc_187964557903_item	2256459	et	3	main
ma	doc_187964557903_item	2256477	et	3	main
praegu	doc_187964557903_item	2256487	et	3	main
on	doc_187964557903_item	2256489	et	4	main
spetsialistide	doc_187964557903_item	2256491	et	3	main
arv	doc_187964557903_item	2256492	et	3	main
eriala	doc_187964557903_item	2256499	et	4	main
muidugi	doc_187964557903_item	2256500	et	4	main
ainult	doc_187964557903_item	2256503	et	4	main
osakond	doc_187964557903_item	2256505	et	3	main
oli	doc_187964557903_item	2256507	et	3	main
ma	doc_187964557903_item	2256511	et	3	main
sain	doc_187964557903_item	2256518	et	3	main
kool	doc_187964557903_item	2256524	et	4	main
on	doc_187964557903_item	2256526	et	4	main
siin	doc_187964557903_item	2256534	et	4	main
loengud	doc_187964557903_item	2256541	et	3	main
ja	doc_187964557903_item	2256542	et	3	main
on	doc_187964557903_item	2256556	et	4	main
sest	doc_187964557903_item	2256560	et	4	main
ei	doc_187964557903_item	2256566	et	4	main
linn	doc_187964557903_item	2256571	et	3	main
suur	doc_187964557903_item	2256574	et	3	main
ei	doc_187964557903_item	2256579	et	4	main
on	doc_187964557903_item	2256588	et	4	main
pluss	doc_187964557903_item	2256590	et	3	main
mulle	doc_187964557903_item	2256593	et	4	main
see	doc_187964557903_item	2256596	et	3	main
et	doc_187964557903_item	2256598	et	3	main
eesti	doc_187964557903_item	2256624	et	4	main
on	doc_187964557903_item	2256628	et	4	main
punktid	doc_187964557903_item	2256630	et	4	main
spikirdasin	doc_187964557903_item	2256633	et	4	main
olin	doc_187964557903_item	2256651	et	3	main
sellel	doc_187964557901_item	2256164	et	4	main
mulle	doc_187964557901_item	2256174	et	4	main
juba	doc_187964557901_item	2256175	et	3	main
et	doc_187964557901_item	2256178	et	3	main
ekskursioonis	doc_187964557901_item	2256182	et	3	main
räägivad	doc_187964557901_item	2256196	et	3	main
tuntud	doc_187964557901_item	2256203	et	4	main
siin	doc_187964557901_item	2256205	et	4	main
majanduse	doc_187964557901_item	2256216	et	4	main
mulle	doc_187964557901_item	2256220	et	4	main
pärast	doc_187964557901_item	2256223	et	4	main
võib	doc_187964557901_item	2256225	et	3	main
et	doc_187964557901_item	2256227	et	3	main
ma	doc_187964557901_item	2256228	et	3	main
võin	doc_187964557901_item	2256235	et	3	main
aga	doc_187964557901_item	2256238	et	3	main
oma	doc_187964557901_item	2256246	et	4	main
ja	doc_187964557901_item	2256248	et	3	main
isa	doc_187964557901_item	2256257	et	4	main
on	doc_187964557901_item	2256258	et	4	main
ka	doc_187964557901_item	2256259	et	3	main
see	doc_187964557901_item	2256263	et	3	main
mõjustab	doc_187964557901_item	2256264	et	3	main
eesti	doc_187964557901_item	2256267	et	4	main
keelt	doc_187964557901_item	2256268	et	4	main
ja	doc_187964557901_item	2256269	et	3	main
oma	doc_187964557901_item	2256273	et	4	main
aga	doc_187964557901_item	2256279	et	3	main
sõltub	doc_187964557901_item	2256281	et	3	main
ma	doc_187964557901_item	2256284	et	3	main
matemaatikat	doc_187964557901_item	2256222	et	3	main
orienteeruda	doc_187964557901_item	2256236	et	3	main
see	doc_187964557901_item	2256239	et	3	main
kasulik	doc_187964557901_item	2256242	et	3	main
väga	doc_187964557901_item	2256251	et	3	main
majandusetundjad	doc_187964557901_item	2256260	et	3	main
meeldib	doc_187964557901_item	2256266	et	3	main
teadmisi	doc_187964557901_item	2256274	et	4	main
et	doc_187964557901_item	2256276	et	3	main
õpin	doc_187964557901_item	2256285	et	3	main
ökonoomika	doc_187964557901_item	2256224	et	4	main
ma	doc_187964557901_item	2256234	et	3	main
väga	doc_187964557901_item	2256241	et	3	main
ma	doc_187964557901_item	2256243	et	3	main
firma	doc_187964557901_item	2256247	et	4	main
palju	doc_187964557901_item	2256252	et	4	main
võimalusi	doc_187964557901_item	2256253	et	3	main
ema	doc_187964557901_item	2256255	et	4	main
võib	doc_187964557901_item	2256261	et	3	main
ma	doc_187964557901_item	2256270	et	3	main
süveneda	doc_187964557901_item	2256272	et	3	main
loodan	doc_187964557901_item	2256275	et	3	main
ma	doc_187964557901_item	2256277	et	3	main
ja	doc_187964557903_item	2256431	et	3	main
eesnimi	doc_187964557903_item	2256436	et	3	main
lõpetasin	doc_187964557903_item	2256450	et	3	main
tallinna	doc_187964557903_item	2256451	et	4	main
gümnaasiumi	doc_187964557903_item	2256453	et	4	main
sellel	doc_187964557903_item	2256454	et	4	main
eriala	doc_187964557903_item	2256480	et	4	main
et	doc_187964557903_item	2256482	et	3	main
on	doc_187964557903_item	2256435	et	4	main
perekonnanimi	doc_187964557903_item	2256437	et	3	main
estlased	doc_187964557903_item	2256440	et	4	main
nimi	doc_187964557903_item	2256447	et	3	main
aastal	doc_187964557903_item	2256455	et	3	main
sooritasin	doc_187964557903_item	2256457	et	3	main
valitsin	doc_187964557903_item	2256478	et	4	main
oma	doc_187964557903_item	2256479	et	4	main
sest	doc_187964557903_item	2256481	et	4	main
ja	doc_187964557903_item	2256493	et	3	main
oli	doc_187964557903_item	2256502	et	3	main
vimane	doc_187964557903_item	2256504	et	4	main
re	doc_187964557903_item	2256508	et	4	main
esimesel	doc_187964557903_item	2256513	et	3	main
loengule	doc_187964557903_item	2256516	et	3	main
aru	doc_187964557903_item	2256519	et	4	main
see	doc_187964557903_item	2256521	et	3	main
ole	doc_187964557903_item	2256523	et	4	main
sööklad	doc_187964557903_item	2256528	et	3	main
mitte	doc_187964557903_item	2256539	et	3	main
ei	doc_187964557903_item	2256546	et	4	main
meeldib	doc_187964557903_item	2256553	et	3	main
staadion	doc_187964557903_item	2256559	et	3	main
mitte	doc_187964557903_item	2256564	et	3	main
ole	doc_187964557903_item	2256567	et	4	main
kolmkümne	doc_187964557903_item	2256576	et	4	main
et	doc_187964557903_item	2256582	et	3	main
tuleb	doc_187964557903_item	2256583	et	3	main
loengule	doc_187964557903_item	2256585	et	3	main
arves	doc_187964557903_item	2256622	et	4	main
keele	doc_187964557903_item	2256636	et	4	main
ootan	doc_187964557903_item	2256639	et	3	main
paar	doc_187964557903_item	2256647	et	3	main
tagasi	doc_187964557903_item	2256649	et	3	main
ööklubis	doc_187964557903_item	2256653	et	3	main
aga	doc_187964557903_item	2256659	et	3	main
estlased	doc_187964557903_item	2256663	et	4	main
tulin	doc_187964557903_item	2256672	et	3	main
räägid	doc_187964557903_item	2256676	et	4	main
olen	doc_187964557904_item	2256702	et	3	main
narvast	doc_187964557904_item	2256704	et	4	main
pärast	doc_187964557904_item	2256711	et	4	main
kooli	doc_187964557904_item	2256712	et	4	main
leida	doc_187964557904_item	2256727	et	3	main
otsustasin	doc_187964557904_item	2256737	et	3	main
ma	doc_187964557904_item	2256741	et	3	main
õppima	doc_187964557904_item	2256745	et	3	main
sõbrad	doc_187964557904_item	2256757	et	3	main
arvan	doc_187964557904_item	2256760	et	3	main
eriala	doc_187964557904_item	2256766	et	4	main
vendenud	doc_187964557904_item	2256768	et	4	main
energeetika	doc_187964557904_item	2256771	et	4	main
ei	doc_187964557904_item	2256772	et	4	main
või	doc_187964557904_item	2256773	et	4	main
praegu	doc_187964557904_item	2256775	et	3	main
kõikidele	doc_187964557904_item	2256777	et	4	main
ma	doc_187964557904_item	2256782	et	3	main
kõik	doc_187964557904_item	2256792	et	4	main
mina	doc_187964557903_item	2256430	et	4	main
kahjuks	doc_187964557903_item	2256438	et	4	main
ja	doc_187964557903_item	2256441	et	3	main
minu	doc_187964557903_item	2256445	et	3	main
valesti	doc_187964557903_item	2256448	et	3	main
osakonnas	doc_187964557903_item	2256476	et	4	main
eriala	doc_187964557903_item	2256485	et	4	main
maailmas	doc_187964557903_item	2256488	et	3	main
väike	doc_187964557903_item	2256490	et	4	main
sest	doc_187964557903_item	2256494	et	4	main
perspektiivne	doc_187964557903_item	2256498	et	3	main
see	doc_187964557903_item	2256501	et	3	main
korral	doc_187964557903_item	2256514	et	4	main
ma	doc_187964557903_item	2256517	et	3	main
ei	doc_187964557903_item	2256522	et	4	main
tasuta	doc_187964557903_item	2256532	et	4	main
piim	doc_187964557903_item	2256533	et	3	main
sa	doc_187964557903_item	2256535	et	3	main
korda	doc_187964557903_item	2256540	et	4	main
midagi	doc_187964557903_item	2256545	et	4	main
ütle	doc_187964557903_item	2256547	et	4	main
ei	doc_187964557903_item	2256549	et	4	main
ka	doc_187964557903_item	2256551	et	3	main
mulle	doc_187964557903_item	2256552	et	4	main
siin	doc_187964557903_item	2256555	et	4	main
ttü	doc_187964557903_item	2256569	et	4	main
aga	doc_187964557903_item	2256586	et	3	main
osa	doc_187964557903_item	2256592	et	4	main
fakt	doc_187964557903_item	2256597	et	3	main
keel	doc_187964557903_item	2256625	et	4	main
ma	doc_187964557903_item	2256638	et	3	main
et	doc_187964557903_item	2256640	et	3	main
lihtsal	doc_187964557903_item	2256643	et	3	main
vaba	doc_187964557903_item	2256645	et	4	main
uues	doc_187964557903_item	2256652	et	3	main
olid	doc_187964557903_item	2256655	et	4	main
minu	doc_187964557903_item	2256665	et	3	main
leidsib	doc_187964557903_item	2256667	et	4	main
nendega	doc_187964557903_item	2256674	et	4	main
ja	doc_187964557903_item	2256675	et	3	main
ma	doc_187964557904_item	2256706	et	3	main
kooli	doc_187964557904_item	2256709	et	4	main
õppida	doc_187964557904_item	2256715	et	3	main
tehnika	doc_187964557904_item	2256717	et	4	main
tööd	doc_187964557904_item	2256729	et	4	main
ja	doc_187964557904_item	2256730	et	3	main
elada	doc_187964557904_item	2256732	et	3	main
stabiiltselt	doc_187964557904_item	2256733	et	4	main
pärast	doc_187964557904_item	2256735	et	4	main
ma	doc_187964557904_item	2256736	et	3	main
energeetikat	doc_187964557904_item	2256744	et	3	main
ei	doc_187964557904_item	2256747	et	4	main
see	doc_187964557904_item	2256762	et	3	main
olen	doc_187964557904_item	2256767	et	3	main
et	doc_187964557904_item	2256769	et	3	main
vaja	doc_187964557904_item	2256779	et	4	main
õppima	doc_187964557904_item	2256784	et	3	main
seda	doc_187964557904_item	2256790	et	3	main
suurused	doc_187964557904_item	2256823	et	4	main
ole	doc_187964557904_item	2256825	et	4	main
end	doc_187964557904_item	2256830	et	4	main
õppelast	doc_187964557904_item	2256844	et	4	main
kuigi	doc_187964557904_item	2256850	et	3	main
on	doc_187964557904_item	2256852	et	4	main
sest	doc_187964557904_item	2256854	et	4	main
mul	doc_187964557904_item	2256855	et	3	main
on	doc_187964557904_item	2256856	et	4	main
siin	doc_187964557904_item	2256867	et	4	main
füüsikaga	doc_187964557904_item	2256877	et	3	main
ja	doc_187964557904_item	2256878	et	3	main
saan	doc_187964557904_item	2256882	et	4	main
essee	doc_187964557903_item	2256429	et	4	main
nimi	doc_187964557903_item	2256434	et	3	main
ma	doc_187964557903_item	2256449	et	3	main
kesklinnavene	doc_187964557903_item	2256452	et	4	main
ma	doc_187964557903_item	2256456	et	3	main
kahjuks	doc_187964557903_item	2256460	et	4	main
vene	doc_187964557903_item	2256462	et	4	main
ainult	doc_187964557903_item	2256461	et	4	main
keele	doc_187964557903_item	2256463	et	4	main
eksami	doc_187964557903_item	2256464	et	3	main
tulemused	doc_187964557903_item	2256465	et	3	main
on	doc_187964557903_item	2256466	et	4	main
suurem	doc_187964557903_item	2256467	et	4	main
kui	doc_187964557903_item	2256468	et	3	main
80	doc_187964557903_item	2256469	et	2	main
praegu	doc_187964557903_item	2256471	et	3	main
punktid	doc_187964557903_item	2256470	et	4	main
ma	doc_187964557903_item	2256472	et	3	main
opin	doc_187964557903_item	2256473	et	4	main
ttüs	doc_187964557903_item	2256474	et	4	main
mehanika	doc_187964557903_item	2256475	et	4	main
see	doc_187964557903_item	2256483	et	3	main
ja	doc_187964557903_item	2256486	et	3	main
et	doc_187964557903_item	2256495	et	3	main
väga	doc_187964557903_item	2256497	et	3	main
kus	doc_187964557903_item	2256506	et	3	main
millal	doc_187964557903_item	2256510	et	3	main
et	doc_187964557903_item	2256520	et	3	main
siin	doc_187964557903_item	2256525	et	4	main
kolm	doc_187964557903_item	2256527	et	3	main
ei	doc_187964557903_item	2256530	et	4	main
ole	doc_187964557903_item	2256531	et	4	main
võid	doc_187964557903_item	2256536	et	4	main
tule	doc_187964557903_item	2256538	et	4	main
mitte	doc_187964557903_item	2256544	et	3	main
et	doc_187964557903_item	2256554	et	3	main
ja	doc_187964557903_item	2256558	et	3	main
pärast	doc_187964557903_item	2256562	et	4	main
ümberehitamist	doc_187964557903_item	2256563	et	3	main
midagi	doc_187964557903_item	2256565	et	4	main
on	doc_187964557903_item	2256572	et	4	main
väga	doc_187964557903_item	2256573	et	3	main
ja	doc_187964557903_item	2256575	et	3	main
minutid	doc_187964557903_item	2256577	et	3	main
jargmisele	doc_187964557903_item	2256584	et	4	main
see	doc_187964557903_item	2256587	et	3	main
ka	doc_187964557903_item	2256589	et	3	main
on	doc_187964557903_item	2256595	et	4	main
uus	doc_187964557903_item	2256484	et	3	main
see	doc_187964557903_item	2256496	et	3	main
kohtad	doc_187964557903_item	2256509	et	3	main
tulin	doc_187964557903_item	2256512	et	3	main
ttüs	doc_187964557903_item	2256515	et	4	main
aga	doc_187964557903_item	2256529	et	3	main
ei	doc_187964557903_item	2256537	et	4	main
sul	doc_187964557903_item	2256543	et	3	main
ja	doc_187964557903_item	2256548	et	3	main
tegi	doc_187964557903_item	2256550	et	4	main
spordihoone	doc_187964557903_item	2256557	et	4	main
koolis	doc_187964557903_item	2256561	et	4	main
kahjuks	doc_187964557903_item	2256568	et	4	main
üliõpilane	doc_187964557903_item	2256570	et	3	main
vaheaega	doc_187964557903_item	2256578	et	4	main
ole	doc_187964557903_item	2256580	et	4	main
palju	doc_187964557903_item	2256581	et	4	main
negatiivne	doc_187964557903_item	2256591	et	3	main
arvamisel	doc_187964557903_item	2256594	et	4	main
ma	doc_187964557903_item	2256599	et	3	main
õppida	doc_187964557903_item	2256601	et	3	main
üheksast	doc_187964557903_item	2256602	et	4	main
üheksani	doc_187964557903_item	2256603	et	3	main
pean	doc_187964557903_item	2256600	et	4	main
ja	doc_187964557903_item	2256604	et	3	main
ma	doc_187964557903_item	2256605	et	3	main
ei	doc_187964557903_item	2256606	et	4	main
tea	doc_187964557903_item	2256607	et	4	main
millal	doc_187964557903_item	2256608	et	3	main
ma	doc_187964557903_item	2256609	et	3	main
võin	doc_187964557903_item	2256610	et	3	main
teha	doc_187964557903_item	2256611	et	3	main
kodutöö	doc_187964557903_item	2256612	et	4	main
kuidas	doc_187964557903_item	2256613	et	3	main
ma	doc_187964557903_item	2256614	et	3	main
ütlen	doc_187964557903_item	2256615	et	3	main
ma	doc_187964557903_item	2256616	et	3	main
kirjutasin	doc_187964557903_item	2256617	et	3	main
halb	doc_187964557903_item	2256618	et	3	main
missugused	doc_187964557903_item	2256619	et	3	main
eksaamid	doc_187964557903_item	2256620	et	3	main
nende	doc_187964557903_item	2256621	et	4	main
on	doc_187964557903_item	2256623	et	4	main
saan	doc_187964557903_item	2256642	et	4	main
rääkida	doc_187964557903_item	2256644	et	3	main
päeva	doc_187964557903_item	2256648	et	4	main
kõik	doc_187964557903_item	2256660	et	4	main
oma	doc_187964557903_item	2256668	et	4	main
koos	doc_187964557903_item	2256673	et	4	main
lõpetasin	doc_187964557904_item	2256707	et	3	main
ja	doc_187964557904_item	2256710	et	3	main
näiteb	doc_187964557904_item	2256720	et	4	main
ilma	doc_187964557904_item	2256722	et	4	main
raske	doc_187964557904_item	2256726	et	4	main
üldse	doc_187964557904_item	2256731	et	3	main
selle	doc_187964557904_item	2256734	et	4	main
kõrgharidusi	doc_187964557904_item	2256738	et	3	main
just	doc_187964557904_item	2256743	et	3	main
et	doc_187964557904_item	2256761	et	3	main
perspektiivne	doc_187964557904_item	2256765	et	3	main
ilma	doc_187964557904_item	2256770	et	4	main
on	doc_187964557904_item	2256778	et	4	main
sest	doc_187964557904_item	2256786	et	4	main
mulle	doc_187964557904_item	2256788	et	4	main
meeldib	doc_187964557904_item	2256789	et	3	main
ka	doc_187964557903_item	2256626	et	3	main
mul	doc_187964557903_item	2256627	et	3	main
79	doc_187964557903_item	2256629	et	2	main
aga	doc_187964557903_item	2256631	et	3	main
ma	doc_187964557903_item	2256632	et	3	main
natuke	doc_187964557903_item	2256634	et	4	main
eesti	doc_187964557903_item	2256635	et	4	main
loengudest	doc_187964557903_item	2256637	et	4	main
ma	doc_187964557903_item	2256641	et	3	main
estlastega	doc_187964557903_item	2256646	et	4	main
ma	doc_187964557903_item	2256650	et	3	main
kus	doc_187964557903_item	2256654	et	3	main
armastus	doc_187964557903_item	2256669	et	4	main
ma	doc_187964557903_item	2256671	et	3	main
teiega	doc_187964557903_item	2256677	et	3	main
eesti	doc_187964557903_item	2256678	et	4	main
keeles	doc_187964557903_item	2256679	et	4	main
ma	doc_187964557903_item	2256680	et	3	main
ei	doc_187964557903_item	2256681	et	4	main
valeta	doc_187964557903_item	2256682	et	4	main
kui	doc_187964557903_item	2256683	et	3	main
ütlen	doc_187964557903_item	2256684	et	3	main
et	doc_187964557903_item	2256685	et	3	main
mul	doc_187964557903_item	2256686	et	3	main
oli	doc_187964557903_item	2256687	et	3	main
natuke	doc_187964557903_item	2256688	et	4	main
kahju	doc_187964557903_item	2256689	et	4	main
et	doc_187964557903_item	2256690	et	3	main
ma	doc_187964557903_item	2256691	et	3	main
ei	doc_187964557903_item	2256692	et	4	main
tea	doc_187964557903_item	2256693	et	4	main
eesti	doc_187964557903_item	2256694	et	4	main
keel	doc_187964557903_item	2256695	et	4	main
hea	doc_187964557903_item	2256696	et	4	main
essee	doc_187964557904_item	2256697	et	4	main
mina	doc_187964557904_item	2256698	et	4	main
ja	doc_187964557904_item	2256699	et	3	main
ülikool	doc_187964557904_item	2256700	et	4	main
ma	doc_187964557904_item	2256701	et	3	main
palju	doc_187964557903_item	2256656	et	4	main
ilused	doc_187964557903_item	2256657	et	3	main
tüdrukud	doc_187964557903_item	2256658	et	3	main
nad	doc_187964557903_item	2256661	et	3	main
oli	doc_187964557903_item	2256662	et	3	main
aga	doc_187964557903_item	2256664	et	3	main
sõber	doc_187964557903_item	2256666	et	3	main
klubisse	doc_187964557903_item	2256670	et	3	main
narvas	doc_187964557904_item	2256705	et	4	main
6	doc_187964557904_item	2256708	et	2	main
otsustasin	doc_187964557904_item	2256714	et	3	main
tallinna	doc_187964557904_item	2256716	et	4	main
ülikoolis	doc_187964557904_item	2256718	et	4	main
elu	doc_187964557904_item	2256719	et	4	main
et	doc_187964557904_item	2256721	et	3	main
hariduseta	doc_187964557904_item	2256723	et	3	main
väga	doc_187964557904_item	2256725	et	3	main
saada	doc_187964557904_item	2256739	et	4	main
tulin	doc_187964557904_item	2256742	et	3	main
seda	doc_187964557904_item	2256752	et	3	main
õppima	doc_187964557904_item	2256754	et	3	main
ma	doc_187964557904_item	2256759	et	3	main
väga	doc_187964557904_item	2256764	et	3	main
elada	doc_187964557904_item	2256774	et	3	main
veel	doc_187964557904_item	2256781	et	4	main
tulin	doc_187964557904_item	2256783	et	3	main
energeetikat	doc_187964557904_item	2256785	et	3	main
mis	doc_187964557904_item	2256793	et	4	main
sellega	doc_187964557904_item	2256796	et	3	main
niimoodi	doc_187964557904_item	2256797	et	3	main
esimeses	doc_187964557904_item	2256800	et	3	main
praegu	doc_187964557904_item	2256822	et	3	main
ei	doc_187964557904_item	2256824	et	4	main
probleem	doc_187964557904_item	2256826	et	3	main
nagu	doc_187964557904_item	2256831	et	3	main
siin	doc_187964557904_item	2256834	et	4	main
õpib	doc_187964557904_item	2256835	et	3	main
oli	doc_187964557904_item	2256841	et	3	main
900	doc_187964557904_item	2256843	et	2	main
palju	doc_187964557904_item	2256857	et	4	main
kahjuks	doc_187964557904_item	2256866	et	4	main
on	doc_187964557904_item	2256868	et	4	main
väga	doc_187964557904_item	2256869	et	3	main
suured	doc_187964557904_item	2256873	et	3	main
probleemid	doc_187964557904_item	2256874	et	3	main
aastane	doc_187964557906_item	2257012	et	4	main
praegu	doc_187964557906_item	2257015	et	3	main
uus	doc_187964557906_item	2257017	et	3	main
minu	doc_187964557906_item	2257019	et	3	main
üliõpilaseks	doc_187964557906_item	2257023	et	3	main
olen	doc_187964557906_item	2257024	et	3	main
et	doc_187964557906_item	2257027	et	3	main
olla	doc_187964557906_item	2257030	et	3	main
kõige	doc_187964557906_item	2257035	et	4	main
aeg	doc_187964557906_item	2257037	et	3	main
et	doc_187964557906_item	2257046	et	3	main
koolist	doc_187964557906_item	2257052	et	4	main
eriti	doc_187964557906_item	2257056	et	3	main
hoonet	doc_187964557906_item	2257062	et	4	main
ja	doc_187964557906_item	2257064	et	3	main
siin	doc_187964557906_item	2257074	et	4	main
palju	doc_187964557906_item	2257080	et	4	main
kool	doc_187964557906_item	2257084	et	4	main
pärit	doc_187964557904_item	2256703	et	3	main
lõpetamist	doc_187964557904_item	2256713	et	4	main
on	doc_187964557904_item	2256724	et	4	main
hea	doc_187964557904_item	2256728	et	4	main
miks	doc_187964557904_item	2256740	et	4	main
täpselt	doc_187964557904_item	2256746	et	4	main
või	doc_187964557904_item	2256748	et	4	main
öelda	doc_187964557904_item	2256749	et	4	main
vaid	doc_187964557904_item	2256750	et	3	main
esiteks	doc_187964557904_item	2256751	et	3	main
eriala	doc_187964557904_item	2256753	et	4	main
soovitasid	doc_187964557904_item	2256755	et	4	main
minu	doc_187964557904_item	2256756	et	3	main
ja	doc_187964557904_item	2256758	et	3	main
on	doc_187964557904_item	2256763	et	4	main
maailmas	doc_187964557904_item	2256776	et	3	main
energiat	doc_187964557904_item	2256780	et	3	main
et	doc_187964557904_item	2256787	et	3	main
ja	doc_187964557904_item	2256791	et	3	main
kui	doc_187964557904_item	2256798	et	3	main
ma	doc_187964557904_item	2256799	et	3	main
kordas	doc_187964557904_item	2256801	et	3	main
tiulin	doc_187964557904_item	2256802	et	4	main
ttü-sse	doc_187964557904_item	2256803	et	3	main
esimene	doc_187964557904_item	2256804	et	3	main
mulje	doc_187964557904_item	2256805	et	4	main
oli	doc_187964557904_item	2256806	et	3	main
see	doc_187964557904_item	2256807	et	3	main
on	doc_187964557904_item	2256808	et	4	main
nii	doc_187964557904_item	2256809	et	3	main
suur	doc_187964557904_item	2256810	et	3	main
siin	doc_187964557904_item	2256811	et	4	main
on	doc_187964557904_item	2256812	et	4	main
nii	doc_187964557904_item	2256813	et	3	main
palju	doc_187964557904_item	2256814	et	4	main
auditooriumid	doc_187964557904_item	2256815	et	3	main
ja	doc_187964557904_item	2256816	et	3	main
korpuseid	doc_187964557904_item	2256817	et	3	main
kuidas	doc_187964557904_item	2256818	et	3	main
leida	doc_187964557904_item	2256819	et	3	main
oma	doc_187964557904_item	2256820	et	4	main
kuigi	doc_187964557904_item	2256821	et	3	main
minu	doc_187964557904_item	2256827	et	3	main
tunen	doc_187964557904_item	2256829	et	4	main
tudengeid	doc_187964557904_item	2256838	et	3	main
minu	doc_187964557904_item	2256839	et	3	main
ainult	doc_187964557904_item	2256842	et	4	main
mittu	doc_187964557904_item	2256847	et	4	main
võimalusi	doc_187964557904_item	2256858	et	3	main
see	doc_187964557904_item	2256862	et	3	main
muidugi	doc_187964557904_item	2256864	et	4	main
raske	doc_187964557904_item	2256870	et	4	main
õppima	doc_187964557904_item	2256871	et	3	main
on	doc_187964557904_item	2256876	et	4	main
on	doc_187964557904_item	2256794	et	4	main
seotud	doc_187964557904_item	2256795	et	4	main
jaoks	doc_187964557904_item	2256828	et	4	main
kodus	doc_187964557904_item	2256832	et	4	main
veel	doc_187964557904_item	2256833	et	4	main
väga	doc_187964557904_item	2256836	et	3	main
siin	doc_187964557904_item	2256846	et	4	main
tuhad	doc_187964557904_item	2256848	et	3	main
tudengeid	doc_187964557904_item	2256849	et	3	main
see	doc_187964557904_item	2256851	et	3	main
parem	doc_187964557904_item	2256853	et	4	main
uue	doc_187964557904_item	2256859	et	3	main
leida	doc_187964557904_item	2256861	et	3	main
tore	doc_187964557904_item	2256865	et	3	main
matemaatikaga	doc_187964557904_item	2256879	et	3	main
et	doc_187964557904_item	2256881	et	3	main
eksmati	doc_187964557904_item	2256883	et	4	main
palju	doc_187964557904_item	2256837	et	4	main
koolis	doc_187964557904_item	2256840	et	4	main
aga	doc_187964557904_item	2256845	et	3	main
sõpru	doc_187964557904_item	2256860	et	3	main
on	doc_187964557904_item	2256863	et	4	main
kõige	doc_187964557904_item	2256872	et	4	main
mul	doc_187964557904_item	2256875	et	3	main
kardan	doc_187964557904_item	2256880	et	4	main
üheksateistkümne	doc_187964557906_item	2257011	et	4	main
noormees	doc_187964557906_item	2257013	et	4	main
algab	doc_187964557906_item	2257016	et	3	main
saan	doc_187964557906_item	2257022	et	4	main
võib	doc_187964557906_item	2257029	et	3	main
ilusam	doc_187964557906_item	2257033	et	4	main
astusin	doc_187964557906_item	2257042	et	3	main
ootasin	doc_187964557906_item	2257045	et	3	main
võib	doc_187964557906_item	2257050	et	3	main
kord	doc_187964557906_item	2257060	et	4	main
sain	doc_187964557906_item	2257070	et	3	main
et	doc_187964557906_item	2257072	et	3	main
teistmoodi	doc_187964557906_item	2257076	et	3	main
on	doc_187964557906_item	2257079	et	4	main
suuurem	doc_187964557906_item	2257081	et	4	main
kui	doc_187964557906_item	2257082	et	3	main
või	doc_187964557906_item	2257088	et	4	main
plus	doc_187964557906_item	2257091	et	4	main
teiseks	doc_187964557906_item	2257093	et	4	main
maksma	doc_187964557906_item	2257122	et	3	main
minna	doc_187964557906_item	2257124	et	3	main
avatud	doc_187964557906_item	2257125	et	4	main
ja	doc_187964557906_item	2257135	et	3	main
aastad	doc_187964557906_item	2257139	et	3	main
ma	doc_187964557906_item	2257143	et	3	main
arvamust	doc_187964557906_item	2257150	et	3	main
nende	doc_187964557906_item	2257157	et	4	main
eest	doc_187964557906_item	2257159	et	4	main
makstakse	doc_187964557906_item	2257160	et	3	main
väga	doc_187964557906_item	2257161	et	3	main
ja	doc_187964557906_item	2257169	et	3	main
sellest	doc_187964557906_item	2257174	et	4	main
rohkem	doc_187964557906_item	2257180	et	4	main
oskust	doc_187964557906_item	2257182	et	3	main
ja	doc_187964557906_item	2257014	et	3	main
lehekülg	doc_187964557906_item	2257018	et	3	main
elus	doc_187964557906_item	2257020	et	4	main
raskem	doc_187964557906_item	2257036	et	4	main
ma	doc_187964557906_item	2257044	et	3	main
see	doc_187964557906_item	2257047	et	3	main
nägin	doc_187964557906_item	2257063	et	3	main
loengul	doc_187964557906_item	2257069	et	3	main
tegada	doc_187964557906_item	2257071	et	4	main
kõik	doc_187964557906_item	2257073	et	4	main
üülikool	doc_187964557906_item	2257078	et	4	main
tunniplaani	doc_187964557906_item	2257098	et	4	main
ma	doc_187964557906_item	2257130	et	3	main
kolm	doc_187964557906_item	2257138	et	3	main
seda	doc_187964557906_item	2257145	et	3	main
on	doc_187964557906_item	2257153	et	4	main
alati	doc_187964557906_item	2257164	et	4	main
töötada	doc_187964557906_item	2257170	et	3	main
tundidest	doc_187964557906_item	2257176	et	3	main
loodan	doc_187964557906_item	2257178	et	3	main
mina	doc_187964557908_item	2257314	et	4	main
olen	doc_187964557908_item	2257323	et	3	main
vaikne	doc_187964557908_item	2257325	et	3	main
on	doc_187964557908_item	2257333	et	4	main
just	doc_187964557908_item	2257336	et	3	main
pärast	doc_187964557908_item	2257338	et	4	main
mängin	doc_187964557908_item	2257341	et	3	main
oli	doc_187964557908_item	2257345	et	3	main
klassis	doc_187964557908_item	2257353	et	3	main
jätkada	doc_187964557908_item	2257355	et	4	main
elu	doc_187964557908_item	2257358	et	4	main
et	doc_187964557908_item	2257362	et	3	main
areneb	doc_187964557908_item	2257364	et	3	main
kiiresti	doc_187964557908_item	2257366	et	3	main
spetsialiste	doc_187964557908_item	2257372	et	3	main
saada	doc_187964557908_item	2257377	et	4	main
mina	doc_187964557908_item	2257390	et	4	main
see	doc_187964557908_item	2257393	et	3	main
esimene	doc_187964557908_item	2257395	et	3	main
ehituses	doc_187964557908_item	2257397	et	4	main
essee	doc_187964557906_item	2257005	et	4	main
mina	doc_187964557906_item	2257006	et	4	main
ja	doc_187964557906_item	2257007	et	3	main
ülikool	doc_187964557906_item	2257008	et	4	main
mina	doc_187964557906_item	2257009	et	4	main
olen	doc_187964557906_item	2257010	et	3	main
arvamust	doc_187964557906_item	2257026	et	3	main
see	doc_187964557906_item	2257028	et	3	main
kõige	doc_187964557906_item	2257032	et	4	main
nig	doc_187964557906_item	2257034	et	4	main
inimese	doc_187964557906_item	2257038	et	4	main
elus	doc_187964557906_item	2257039	et	4	main
ma	doc_187964557906_item	2257041	et	3	main
uus	doc_187964557906_item	2257048	et	3	main
ma	doc_187964557906_item	2257058	et	3	main
veedsin	doc_187964557906_item	2257065	et	4	main
tundi	doc_187964557906_item	2257067	et	4	main
esimeseks	doc_187964557906_item	2257077	et	3	main
siin	doc_187964557906_item	2257085	et	4	main
kaheksa	doc_187964557906_item	2257089	et	4	main
iseendale	doc_187964557906_item	2257097	et	3	main
ja	doc_187964557906_item	2257099	et	3	main
keegi	doc_187964557906_item	2257100	et	4	main
ei	doc_187964557906_item	2257101	et	4	main
seisa	doc_187964557906_item	2257102	et	4	main
selja	doc_187964557906_item	2257103	et	3	main
taga	doc_187964557906_item	2257104	et	4	main
ja	doc_187964557906_item	2257105	et	3	main
ei	doc_187964557906_item	2257106	et	4	main
ütle	doc_187964557906_item	2257107	et	4	main
et	doc_187964557906_item	2257108	et	3	main
õppima	doc_187964557906_item	2257109	et	3	main
pea	doc_187964557906_item	2257110	et	4	main
ja	doc_187964557906_item	2257111	et	3	main
kolmeks	doc_187964557906_item	2257112	et	4	main
kui	doc_187964557906_item	2257113	et	3	main
hakkad	doc_187964557906_item	2257114	et	3	main
halvasti	doc_187964557906_item	2257115	et	3	main
õppida	doc_187964557906_item	2257116	et	3	main
pead	doc_187964557906_item	2257117	et	4	main
sa	doc_187964557906_item	2257118	et	3	main
oma	doc_187964557906_item	2257119	et	4	main
õppimise	doc_187964557906_item	2257120	et	4	main
või	doc_187964557906_item	2257127	et	4	main
tööle	doc_187964557906_item	2257128	et	3	main
õppima	doc_187964557906_item	2257132	et	3	main
õnnestub	doc_187964557906_item	2257137	et	3	main
mehatroonikuks	doc_187964557906_item	2257142	et	4	main
et	doc_187964557906_item	2257151	et	3	main
mina	doc_187964557906_item	2257163	et	4	main
palju	doc_187964557906_item	2257166	et	4	main
saada	doc_187964557906_item	2257168	et	4	main
tundi	doc_187964557906_item	2257172	et	4	main
saada	doc_187964557906_item	2257179	et	4	main
ma	doc_187964557906_item	2257021	et	3	main
kuulnud	doc_187964557906_item	2257025	et	4	main
nii	doc_187964557906_item	2257031	et	3	main
kui	doc_187964557906_item	2257040	et	3	main
ülikooli	doc_187964557906_item	2257043	et	4	main
õppeasutus	doc_187964557906_item	2257049	et	4	main
natuke	doc_187964557906_item	2257051	et	4	main
erinema	doc_187964557906_item	2257053	et	3	main
aga	doc_187964557906_item	2257054	et	3	main
mitte	doc_187964557906_item	2257055	et	3	main
kui	doc_187964557906_item	2257057	et	3	main
esimene	doc_187964557906_item	2257059	et	3	main
ttü	doc_187964557906_item	2257061	et	4	main
paar	doc_187964557906_item	2257066	et	3	main
õppingukorralduse	doc_187964557906_item	2257068	et	4	main
on	doc_187964557906_item	2257075	et	4	main
tavaline	doc_187964557906_item	2257083	et	4	main
seitse	doc_187964557906_item	2257087	et	3	main
spordihoone	doc_187964557906_item	2257092	et	4	main
peab	doc_187964557906_item	2257095	et	4	main
teha	doc_187964557906_item	2257096	et	3	main
eest	doc_187964557906_item	2257121	et	4	main
ja	doc_187964557906_item	2257123	et	3	main
hakkan	doc_187964557906_item	2257131	et	3	main
kondal	doc_187964557906_item	2257134	et	4	main
kui	doc_187964557906_item	2257136	et	3	main
saan	doc_187964557906_item	2257141	et	4	main
eriala	doc_187964557906_item	2257146	et	4	main
ma	doc_187964557906_item	2257148	et	3	main
jagan	doc_187964557906_item	2257149	et	3	main
meehatroomikud	doc_187964557906_item	2257152	et	4	main
tahtud	doc_187964557906_item	2257154	et	4	main
hästi	doc_187964557906_item	2257162	et	3	main
paar	doc_187964557906_item	2257171	et	3	main
päeval	doc_187964557906_item	2257173	et	3	main
ma	doc_187964557906_item	2257177	et	3	main
rägimis	doc_187964557906_item	2257181	et	4	main
ülikool	doc_187964557908_item	2257316	et	4	main
et	doc_187964557908_item	2257321	et	3	main
rahulik	doc_187964557908_item	2257324	et	3	main
mis	doc_187964557908_item	2257332	et	4	main
mul	doc_187964557908_item	2257346	et	3	main
arstiks	doc_187964557908_item	2257348	et	4	main
kümnendas	doc_187964557908_item	2257352	et	3	main
minu	doc_187964557908_item	2257356	et	3	main
on	doc_187964557908_item	2257369	et	4	main
vaja	doc_187964557908_item	2257370	et	4	main
ma	doc_187964557908_item	2257374	et	3	main
soovin	doc_187964557908_item	2257376	et	3	main
selle	doc_187964557908_item	2257381	et	4	main
et	doc_187964557908_item	2257383	et	3	main
nagu	doc_187964557908_item	2257389	et	3	main
on	doc_187964557906_item	2257086	et	4	main
õppehooned	doc_187964557906_item	2257090	et	4	main
inimene	doc_187964557906_item	2257094	et	3	main
ülikooli	doc_187964557906_item	2257126	et	4	main
praegu	doc_187964557906_item	2257129	et	3	main
mehaanikateadus	doc_187964557906_item	2257133	et	4	main
pärast	doc_187964557906_item	2257140	et	4	main
valin	doc_187964557906_item	2257144	et	3	main
sest	doc_187964557906_item	2257147	et	4	main
spetsialistid	doc_187964557906_item	2257155	et	3	main
ja	doc_187964557906_item	2257156	et	3	main
töö	doc_187964557906_item	2257158	et	4	main
tahtnud	doc_187964557906_item	2257165	et	4	main
raha	doc_187964557906_item	2257167	et	4	main
eestikeele	doc_187964557906_item	2257175	et	4	main
essee	doc_187964557908_item	2257313	et	4	main
üheksateistkümne	doc_187964557908_item	2257318	et	4	main
arvan	doc_187964557908_item	2257320	et	3	main
saladuslik	doc_187964557908_item	2257327	et	3	main
muusikaga	doc_187964557908_item	2257335	et	3	main
gitarri	doc_187964557908_item	2257342	et	4	main
saada	doc_187964557908_item	2257349	et	4	main
elutus	doc_187964557908_item	2257363	et	4	main
väga	doc_187964557908_item	2257365	et	3	main
just	doc_187964557908_item	2257375	et	3	main
valisin	doc_187964557908_item	2257379	et	3	main
see	doc_187964557908_item	2257384	et	3	main
tase	doc_187964557908_item	2257396	et	3	main
olen	doc_187964557908_item	2257317	et	3	main
ja	doc_187964557908_item	2257326	et	3	main
inimene	doc_187964557908_item	2257328	et	3	main
huvitab	doc_187964557908_item	2257330	et	3	main
kõik	doc_187964557908_item	2257331	et	4	main
seotud	doc_187964557908_item	2257334	et	4	main
selle	doc_187964557908_item	2257337	et	4	main
mina	doc_187964557908_item	2257339	et	4	main
ise	doc_187964557908_item	2257340	et	4	main
minu	doc_187964557908_item	2257343	et	3	main
lastepõlves	doc_187964557908_item	2257344	et	4	main
soov	doc_187964557908_item	2257347	et	3	main
kuskil	doc_187964557908_item	2257351	et	3	main
ehitajana	doc_187964557908_item	2257359	et	4	main
olen	doc_187964557908_item	2257360	et	3	main
seisukohal	doc_187964557908_item	2257361	et	4	main
tänapäeval	doc_187964557908_item	2257368	et	3	main
geodeesiat	doc_187964557908_item	2257380	et	3	main
pärast	doc_187964557908_item	2257382	et	4	main
on	doc_187964557908_item	2257385	et	4	main
väga	doc_187964557908_item	2257386	et	3	main
eriala	doc_187964557908_item	2257388	et	4	main
tean	doc_187964557908_item	2257392	et	3	main
sellest	doc_187964557908_item	2257398	et	4	main
ttü	doc_187964557908_item	2257423	et	4	main
ja	doc_187964557908_item	2257424	et	3	main
praegu	doc_187964557908_item	2257431	et	3	main
ei	doc_187964557908_item	2257434	et	4	main
probleem	doc_187964557908_item	2257443	et	3	main
minu	doc_187964557908_item	2257444	et	3	main
mul	doc_187964557908_item	2257451	et	3	main
olid	doc_187964557908_item	2257453	et	4	main
kõik	doc_187964557908_item	2257456	et	4	main
mina	doc_187964557908_item	2257464	et	4	main
loengutelt	doc_187964557908_item	2257468	et	4	main
ja	doc_187964557908_item	2257315	et	3	main
aastane	doc_187964557908_item	2257319	et	4	main
mina	doc_187964557908_item	2257322	et	4	main
mind	doc_187964557908_item	2257329	et	4	main
aga	doc_187964557908_item	2257350	et	3	main
otsustasin	doc_187964557908_item	2257354	et	3	main
tuleviku	doc_187964557908_item	2257357	et	4	main
ja	doc_187964557908_item	2257367	et	3	main
palju	doc_187964557908_item	2257371	et	4	main
kelleks	doc_187964557908_item	2257373	et	4	main
mina	doc_187964557908_item	2257378	et	4	main
oluline	doc_187964557908_item	2257387	et	4	main
on	doc_187964557908_item	2257394	et	4	main
väga	doc_187964557908_item	2257399	et	3	main
palju	doc_187964557908_item	2257400	et	4	main
sõltub	doc_187964557908_item	2257401	et	3	main
valisin	doc_187964557908_item	2257402	et	3	main
ttü	doc_187964557908_item	2257403	et	4	main
õppimiseks	doc_187964557908_item	2257404	et	4	main
arvan	doc_187964557908_item	2257406	et	3	main
et	doc_187964557908_item	2257407	et	3	main
sest	doc_187964557908_item	2257405	et	4	main
siin	doc_187964557908_item	2257408	et	4	main
on	doc_187964557908_item	2257409	et	4	main
võimalus	doc_187964557908_item	2257410	et	3	main
häid	doc_187964557908_item	2257411	et	3	main
haridust	doc_187964557908_item	2257412	et	4	main
saada	doc_187964557908_item	2257413	et	4	main
arvatakse	doc_187964557908_item	2257414	et	3	main
et	doc_187964557908_item	2257415	et	3	main
kõige	doc_187964557908_item	2257416	et	4	main
kuulsamad	doc_187964557908_item	2257417	et	4	main
ja	doc_187964557908_item	2257418	et	3	main
paremad	doc_187964557908_item	2257419	et	4	main
ülikoolid	doc_187964557908_item	2257420	et	3	main
ülikool	doc_187964557908_item	2257426	et	4	main
mu	doc_187964557908_item	2257427	et	3	main
tea	doc_187964557908_item	2257435	et	4	main
mis	doc_187964557908_item	2257437	et	4	main
eesti	doc_187964557908_item	2257447	et	4	main
keelne	doc_187964557908_item	2257448	et	3	main
õppime	doc_187964557908_item	2257449	et	4	main
soobivad	doc_187964557908_item	2257462	et	4	main
mida	doc_187964557908_item	2257463	et	4	main
eesti	doc_187964557908_item	2257466	et	4	main
juba	doc_187964557908_item	2257391	et	3	main
muljed	doc_187964557908_item	2257429	et	3	main
muidugi	doc_187964557908_item	2257436	et	4	main
suurem	doc_187964557908_item	2257442	et	4	main
asjad	doc_187964557908_item	2257458	et	3	main
ja	doc_187964557908_item	2257459	et	3	main
tingimused	doc_187964557908_item	2257460	et	3	main
mulle	doc_187964557908_item	2257461	et	4	main
ootan	doc_187964557908_item	2257465	et	3	main
mina	doc_187964557910_item	2257639	et	4	main
õpin	doc_187964557910_item	2257648	et	3	main
seda	doc_187964557910_item	2257655	et	3	main
karjamaa	doc_187964557910_item	2257659	et	4	main
ehituse	doc_187964557910_item	2257663	et	4	main
ehitusteaduskonda	doc_187964557910_item	2257674	et	4	main
mulle	doc_187964557910_item	2257676	et	4	main
teine	doc_187964557910_item	2257685	et	3	main
siin	doc_187964557910_item	2257689	et	4	main
lihtsalt	doc_187964557910_item	2257692	et	4	main
siin	doc_187964557910_item	2257696	et	4	main
võib	doc_187964557910_item	2257702	et	3	main
õpitamise	doc_187964557910_item	2257706	et	4	main
õppejõud	doc_187964557910_item	2257712	et	4	main
kõik	doc_187964557910_item	2257717	et	4	main
on	doc_187964557908_item	2257422	et	4	main
tartu	doc_187964557908_item	2257425	et	4	main
ülikoolist	doc_187964557908_item	2257430	et	4	main
veel	doc_187964557908_item	2257432	et	4	main
head	doc_187964557908_item	2257433	et	4	main
kõige	doc_187964557908_item	2257441	et	4	main
on	doc_187964557908_item	2257446	et	4	main
alati	doc_187964557908_item	2257452	et	4	main
teised	doc_187964557908_item	2257457	et	4	main
keele	doc_187964557908_item	2257467	et	4	main
ei	doc_187964557908_item	2257469	et	4	main
täpselt	doc_187964557908_item	2257471	et	4	main
aga	doc_187964557908_item	2257472	et	3	main
tea	doc_187964557908_item	2257470	et	4	main
arvan	doc_187964557908_item	2257473	et	3	main
et	doc_187964557908_item	2257474	et	3	main
suuline	doc_187964557908_item	2257475	et	4	main
osa	doc_187964557908_item	2257476	et	4	main
minu	doc_187964557908_item	2257477	et	3	main
jaoks	doc_187964557908_item	2257478	et	4	main
on	doc_187964557908_item	2257479	et	4	main
olulisem	doc_187964557908_item	2257480	et	4	main
ja	doc_187964557908_item	2257481	et	3	main
muidugi	doc_187964557908_item	2257482	et	4	main
kõik	doc_187964557908_item	2257483	et	4	main
mis	doc_187964557908_item	2257484	et	4	main
seotud	doc_187964557908_item	2257486	et	4	main
on	doc_187964557908_item	2257485	et	4	main
minu	doc_187964557908_item	2257487	et	3	main
erialaga	doc_187964557908_item	2257488	et	3	main
eestis	doc_187964557908_item	2257421	et	3	main
esimesed	doc_187964557908_item	2257428	et	3	main
mind	doc_187964557908_item	2257438	et	4	main
ootab	doc_187964557908_item	2257439	et	3	main
tulevikus	doc_187964557908_item	2257440	et	4	main
jaoks	doc_187964557908_item	2257445	et	4	main
sest	doc_187964557908_item	2257450	et	4	main
probleemid	doc_187964557908_item	2257454	et	3	main
keeltega	doc_187964557908_item	2257455	et	3	main
ülikool	doc_187964557910_item	2257641	et	4	main
olen	doc_187964557910_item	2257642	et	3	main
eesnimi	doc_187964557910_item	2257643	et	3	main
perekonnanimi	doc_187964557910_item	2257644	et	3	main
aastat	doc_187964557910_item	2257646	et	3	main
sellepärast	doc_187964557910_item	2257653	et	3	main
hästi	doc_187964557910_item	2257657	et	3	main
olen	doc_187964557910_item	2257661	et	3	main
suur	doc_187964557910_item	2257662	et	3	main
alati	doc_187964557910_item	2257667	et	4	main
inseneeriks	doc_187964557910_item	2257669	et	4	main
saada	doc_187964557910_item	2257670	et	4	main
valisin	doc_187964557910_item	2257672	et	3	main
mulle	doc_187964557910_item	2257687	et	4	main
veetma	doc_187964557910_item	2257693	et	3	main
aega	doc_187964557910_item	2257694	et	4	main
palju	doc_187964557910_item	2257698	et	4	main
teha	doc_187964557910_item	2257703	et	3	main
suur	doc_187964557910_item	2257710	et	3	main
peaaegu	doc_187964557910_item	2257716	et	3	main
on	doc_187964557910_item	2257722	et	4	main
meeldib	doc_187964557910_item	2257726	et	3	main
ja	doc_187964557910_item	2257738	et	3	main
alati	doc_187964557910_item	2257740	et	4	main
spordihoone	doc_187964557910_item	2257745	et	4	main
mängin	doc_187964557910_item	2257747	et	3	main
lahendamist	doc_187964557910_item	2257757	et	4	main
keele	doc_187964557910_item	2257760	et	4	main
oleks	doc_187964557910_item	2257778	et	3	main
õppimine	doc_187964557910_item	2257782	et	4	main
eesti	doc_187964557910_item	2257784	et	4	main
essee	doc_187964557911_item	2257786	et	4	main
mina	doc_187964557911_item	2257787	et	4	main
ja	doc_187964557911_item	2257788	et	3	main
nimi	doc_187964557911_item	2257791	et	3	main
19	doc_187964557911_item	2257796	et	2	main
õismäe	doc_187964557911_item	2257803	et	3	main
ttü	doc_187964557911_item	2257805	et	4	main
olen	doc_187964557911_item	2257807	et	3	main
mängin	doc_187964557911_item	2257810	et	3	main
juba	doc_187964557911_item	2257812	et	3	main
mul	doc_187964557911_item	2257815	et	3	main
koostis	doc_187964557911_item	2257821	et	4	main
kahjuks	doc_187964557911_item	2257828	et	4	main
palju	doc_187964557911_item	2257838	et	4	main
õppida	doc_187964557911_item	2257842	et	3	main
olen	doc_187964557911_item	2257847	et	3	main
töö	doc_187964557911_item	2257855	et	4	main
praegu	doc_187964557911_item	2257859	et	3	main
see	doc_187964557911_item	2257865	et	3	main
sõbralik	doc_187964557911_item	2257867	et	3	main
essee	doc_187964557910_item	2257638	et	4	main
ja	doc_187964557910_item	2257640	et	3	main
juba	doc_187964557910_item	2257650	et	3	main
kolmanda	doc_187964557910_item	2257651	et	3	main
just	doc_187964557910_item	2257673	et	3	main
kõik	doc_187964557910_item	2257675	et	4	main
tööstus-	doc_187964557910_item	2257678	et	3	main
erialas	doc_187964557910_item	2257681	et	3	main
on	doc_187964557910_item	2257683	et	4	main
kodu	doc_187964557910_item	2257686	et	4	main
ja	doc_187964557910_item	2257691	et	3	main
huvitavaid	doc_187964557910_item	2257699	et	4	main
asju	doc_187964557910_item	2257705	et	3	main
on	doc_187964557910_item	2257708	et	4	main
aga	doc_187964557910_item	2257718	et	3	main
ikka	doc_187964557910_item	2257719	et	4	main
peaaegu	doc_187964557910_item	2257720	et	3	main
mis	doc_187964557910_item	2257725	et	4	main
on	doc_187964557910_item	2257731	et	4	main
saavad	doc_187964557910_item	2257736	et	4	main
jalgpalli	doc_187964557910_item	2257749	et	4	main
eesti	doc_187964557910_item	2257752	et	4	main
loengutelt	doc_187964557910_item	2257754	et	4	main
ootan	doc_187964557910_item	2257755	et	3	main
sõnavara	doc_187964557910_item	2257756	et	4	main
kergem	doc_187964557910_item	2257779	et	4	main
perekonnanimi	doc_187964557911_item	2257794	et	3	main
õneks	doc_187964557911_item	2257802	et	4	main
asub	doc_187964557911_item	2257804	et	3	main
juures	doc_187964557911_item	2257806	et	4	main
jalgpallur	doc_187964557911_item	2257809	et	3	main
väga	doc_187964557911_item	2257817	et	3	main
mis	doc_187964557911_item	2257820	et	4	main
kolmast	doc_187964557911_item	2257822	et	3	main
isa	doc_187964557911_item	2257824	et	4	main
ja	doc_187964557911_item	2257826	et	3	main
pärast	doc_187964557911_item	2257834	et	4	main
alati	doc_187964557911_item	2257840	et	4	main
ja	doc_187964557911_item	2257844	et	3	main
ja	doc_187964557911_item	2257856	et	3	main
on	doc_187964557911_item	2257866	et	4	main
problem	doc_187964557911_item	2257896	et	4	main
on	doc_187964557911_item	2257898	et	4	main
kabinet	doc_187964557911_item	2257904	et	3	main
eest	doc_187964557911_item	2257906	et	4	main
ma	doc_187964557911_item	2257913	et	3	main
aitavad	doc_187964557911_item	2257919	et	4	main
keelt	doc_187964557911_item	2257924	et	4	main
õppida	doc_187964557911_item	2257940	et	3	main
keelt	doc_187964557911_item	2257942	et	4	main
ttüs	doc_187964557910_item	2257649	et	4	main
sõber	doc_187964557910_item	2257664	et	3	main
lapsepõlvest	doc_187964557910_item	2257666	et	4	main
sellepärast	doc_187964557910_item	2257671	et	3	main
meeldib	doc_187964557910_item	2257677	et	3	main
ja	doc_187964557910_item	2257679	et	3	main
meeldib	doc_187964557910_item	2257688	et	3	main
sõpradega	doc_187964557910_item	2257695	et	3	main
kellega	doc_187964557910_item	2257701	et	3	main
päris	doc_187964557910_item	2257709	et	4	main
annavad	doc_187964557910_item	2257713	et	3	main
hästi	doc_187964557910_item	2257715	et	3	main
mulle	doc_187964557910_item	2257727	et	4	main
mul	doc_187964557910_item	2257730	et	3	main
alati	doc_187964557910_item	2257735	et	4	main
kellele	doc_187964557910_item	2257739	et	4	main
aitan	doc_187964557910_item	2257741	et	3	main
seal	doc_187964557910_item	2257748	et	4	main
keele	doc_187964557910_item	2257753	et	4	main
rohkem	doc_187964557910_item	2257759	et	4	main
õppida	doc_187964557910_item	2257780	et	3	main
tuleb	doc_187964557910_item	2257783	et	3	main
keeles	doc_187964557910_item	2257785	et	4	main
on	doc_187964557911_item	2257792	et	4	main
vana	doc_187964557911_item	2257798	et	4	main
elan	doc_187964557911_item	2257799	et	3	main
on	doc_187964557911_item	2257816	et	4	main
21	doc_187964557910_item	2257645	et	2	main
vana	doc_187964557910_item	2257647	et	4	main
aasta	doc_187964557910_item	2257652	et	4	main
tunnen	doc_187964557910_item	2257654	et	3	main
päris	doc_187964557910_item	2257656	et	4	main
lõpetasin	doc_187964557910_item	2257658	et	3	main
gümnaasiumi	doc_187964557910_item	2257660	et	4	main
juba	doc_187964557910_item	2257665	et	3	main
tahtsin	doc_187964557910_item	2257668	et	3	main
tsiviilehituse	doc_187964557910_item	2257680	et	3	main
ttü	doc_187964557910_item	2257682	et	4	main
minu	doc_187964557910_item	2257684	et	3	main
õppida	doc_187964557910_item	2257690	et	3	main
on	doc_187964557910_item	2257697	et	4	main
inimesi	doc_187964557910_item	2257700	et	4	main
igasuguseid	doc_187964557910_item	2257704	et	3	main
tase	doc_187964557910_item	2257707	et	3	main
ja	doc_187964557910_item	2257711	et	3	main
materiaal	doc_187964557910_item	2257714	et	4	main
ttüs	doc_187964557910_item	2257721	et	4	main
aktiivne	doc_187964557910_item	2257723	et	3	main
tudengielu	doc_187964557910_item	2257724	et	4	main
palju	doc_187964557910_item	2257732	et	4	main
sõpru	doc_187964557910_item	2257733	et	3	main
aidata	doc_187964557910_item	2257737	et	4	main
veelgi	doc_187964557910_item	2257743	et	4	main
ja	doc_187964557910_item	2257750	et	3	main
ja	doc_187964557910_item	2257758	et	3	main
kui	doc_187964557910_item	2257781	et	3	main
ülikool	doc_187964557911_item	2257789	et	4	main
minu	doc_187964557911_item	2257790	et	3	main
olen	doc_187964557911_item	2257795	et	3	main
a	doc_187964557911_item	2257797	et	4	main
tallinnass	doc_187964557911_item	2257800	et	3	main
sportlane	doc_187964557911_item	2257808	et	3	main
jalgpallis	doc_187964557911_item	2257811	et	3	main
kümme	doc_187964557911_item	2257813	et	3	main
perekond	doc_187964557911_item	2257819	et	3	main
mul	doc_187964557911_item	2257829	et	3	main
ei	doc_187964557911_item	2257830	et	4	main
ole	doc_187964557911_item	2257837	et	4	main
tahaksin	doc_187964557911_item	2257841	et	3	main
saada	doc_187964557911_item	2257852	et	4	main
suur	doc_187964557911_item	2257857	et	3	main
on	doc_187964557911_item	2257872	et	4	main
abituriendidele	doc_187964557911_item	2257897	et	4	main
mõnikord	doc_187964557911_item	2257899	et	3	main
väga	doc_187964557911_item	2257900	et	3	main
raske	doc_187964557911_item	2257901	et	4	main
oma	doc_187964557911_item	2257903	et	4	main
raske	doc_187964557911_item	2257911	et	4	main
loodan	doc_187964557911_item	2257914	et	3	main
eesti	doc_187964557911_item	2257916	et	4	main
loendud	doc_187964557911_item	2257918	et	3	main
eesti	doc_187964557911_item	2257923	et	4	main
keelt	doc_187964557911_item	2257927	et	4	main
hakkan	doc_187964557911_item	2257937	et	3	main
hästi	doc_187964557911_item	2257947	et	3	main
väga	doc_187964557910_item	2257728	et	3	main
ülikoolis	doc_187964557910_item	2257729	et	4	main
kes	doc_187964557910_item	2257734	et	4	main
mina	doc_187964557910_item	2257742	et	4	main
olen	doc_187964557910_item	2257744	et	3	main
fänn	doc_187964557910_item	2257746	et	3	main
lauatennist	doc_187964557910_item	2257751	et	3	main
praktikat	doc_187964557910_item	2257761	et	3	main
et	doc_187964557910_item	2257762	et	3	main
ikka	doc_187964557910_item	2257763	et	4	main
õppida	doc_187964557910_item	2257764	et	3	main
keele	doc_187964557910_item	2257765	et	4	main
valdata	doc_187964557910_item	2257766	et	4	main
nagu	doc_187964557910_item	2257767	et	3	main
eestlane	doc_187964557910_item	2257768	et	3	main
veelgi	doc_187964557910_item	2257769	et	4	main
tahaks	doc_187964557910_item	2257770	et	3	main
õppida	doc_187964557910_item	2257771	et	3	main
midagi	doc_187964557910_item	2257772	et	4	main
oma	doc_187964557910_item	2257773	et	4	main
eriala	doc_187964557910_item	2257774	et	4	main
kohta	doc_187964557910_item	2257775	et	4	main
et	doc_187964557910_item	2257776	et	3	main
tulevikus	doc_187964557910_item	2257777	et	4	main
eesnimi	doc_187964557911_item	2257793	et	3	main
õismäel	doc_187964557911_item	2257801	et	3	main
aastat	doc_187964557911_item	2257814	et	3	main
sõbralik	doc_187964557911_item	2257818	et	3	main
ema	doc_187964557911_item	2257825	et	4	main
ole	doc_187964557911_item	2257831	et	4	main
mul	doc_187964557911_item	2257835	et	3	main
ei	doc_187964557911_item	2257836	et	4	main
ülikoolis	doc_187964557911_item	2257843	et	4	main
valin	doc_187964557911_item	2257845	et	3	main
ttü	doc_187964557911_item	2257846	et	4	main
tulevikus	doc_187964557911_item	2257853	et	4	main
hea	doc_187964557911_item	2257854	et	4	main
väga	doc_187964557911_item	2257861	et	3	main
ttüs	doc_187964557911_item	2257863	et	4	main
koht	doc_187964557911_item	2257868	et	3	main
seal	doc_187964557911_item	2257870	et	4	main
leida	doc_187964557911_item	2257902	et	3	main
on	doc_187964557911_item	2257909	et	4	main
läbi	doc_187964557911_item	2257921	et	4	main
saan	doc_187964557911_item	2257930	et	4	main
hea	doc_187964557911_item	2257932	et	4	main
tugev	doc_187964557911_item	2257939	et	4	main
inimest	doc_187964557911_item	2257823	et	3	main
mina	doc_187964557911_item	2257827	et	4	main
koduloomat	doc_187964557911_item	2257832	et	4	main
selle	doc_187964557911_item	2257833	et	4	main
aega	doc_187964557911_item	2257839	et	4	main
valinud	doc_187964557911_item	2257848	et	4	main
soojustehnika	doc_187964557911_item	2257849	et	4	main
et	doc_187964557911_item	2257850	et	3	main
tahan	doc_187964557911_item	2257851	et	3	main
palk	doc_187964557911_item	2257858	et	3	main
mulle	doc_187964557911_item	2257860	et	4	main
meeldib	doc_187964557911_item	2257862	et	3	main
olla	doc_187964557911_item	2257864	et	3	main
palju	doc_187964557911_item	2257873	et	4	main
sõpru	doc_187964557911_item	2257874	et	3	main
väga	doc_187964557911_item	2257875	et	3	main
tähtis	doc_187964557911_item	2257876	et	4	main
on	doc_187964557911_item	2257877	et	4	main
seda	doc_187964557911_item	2257878	et	3	main
et	doc_187964557911_item	2257879	et	3	main
seal	doc_187964557911_item	2257880	et	4	main
on	doc_187964557911_item	2257881	et	4	main
mugav	doc_187964557911_item	2257882	et	3	main
ja	doc_187964557911_item	2257883	et	3	main
odav	doc_187964557911_item	2257884	et	3	main
söökla	doc_187964557911_item	2257885	et	4	main
praegu	doc_187964557911_item	2257886	et	3	main
ma	doc_187964557911_item	2257887	et	3	main
saan	doc_187964557911_item	2257888	et	4	main
aru	doc_187964557911_item	2257889	et	4	main
et	doc_187964557911_item	2257890	et	3	main
ttüs	doc_187964557911_item	2257891	et	4	main
on	doc_187964557911_item	2257892	et	4	main
ainult	doc_187964557911_item	2257893	et	4	main
väike	doc_187964557911_item	2257895	et	4	main
ja	doc_187964557911_item	2257869	et	3	main
mul	doc_187964557911_item	2257871	et	3	main
üks	doc_187964557911_item	2257894	et	3	main
minu	doc_187964557911_item	2257905	et	3	main
eesti	doc_187964557911_item	2257907	et	4	main
väga	doc_187964557911_item	2257910	et	3	main
et	doc_187964557911_item	2257915	et	3	main
keele	doc_187964557911_item	2257917	et	4	main
ilma	doc_187964557911_item	2257925	et	4	main
saada	doc_187964557911_item	2257931	et	4	main
ma	doc_187964557911_item	2257936	et	3	main
eesti	doc_187964557911_item	2257941	et	4	main
et	doc_187964557911_item	2257944	et	3	main
tuleb	doc_187964557911_item	2257946	et	3	main
keel	doc_187964557911_item	2257908	et	4	main
aga	doc_187964557911_item	2257912	et	3	main
mulle	doc_187964557911_item	2257920	et	4	main
õppida	doc_187964557911_item	2257922	et	3	main
eesti	doc_187964557911_item	2257926	et	4	main
ma	doc_187964557911_item	2257928	et	3	main
ei	doc_187964557911_item	2257929	et	4	main
töö	doc_187964557911_item	2257933	et	4	main
selle	doc_187964557911_item	2257934	et	4	main
pärast	doc_187964557911_item	2257935	et	4	main
väga	doc_187964557911_item	2257938	et	3	main
loodan	doc_187964557911_item	2257943	et	3	main
kõik	doc_187964557911_item	2257945	et	4	main
ja	doc_193540241566_item	2259537	et	3	main
sisulised	doc_193540241566_item	2259550	et	4	main
kasutage	doc_193540241566_item	2259552	et	3	main
1	doc_193540241566_item	2259554	et	2	main
faktorid	doc_193540241566_item	2259561	et	3	main
ja	doc_193540241566_item	2259563	et	3	main
sajandi	doc_193540241566_item	2259579	et	3	main
identiteedi	doc_193540241566_item	2259589	et	4	main
ning	doc_193540241566_item	2259591	et	3	main
et	doc_193540241566_item	2259605	et	3	main
on	doc_193540241566_item	2259609	et	4	main
suurt	doc_193540241566_item	2259617	et	3	main
selles	doc_193540241566_item	2259619	et	4	main
tekstidest	doc_193540241566_item	2259523	et	3	main
camus	doc_193540241566_item	2259532	et	4	main
võõras	doc_193540241566_item	2259533	et	4	main
omased	doc_193540241566_item	2259547	et	3	main
lüürikat	doc_193540241566_item	2259557	et	3	main
lüürikat	doc_193540241566_item	2259580	et	3	main
jagada	doc_193540241566_item	2259582	et	3	main
suureks	doc_193540241566_item	2259584	et	4	main
teemad	doc_193540241566_item	2259593	et	3	main
algusel	doc_193540241566_item	2259600	et	4	main
sellega	doc_193540241566_item	2259601	et	3	main
tahaksid	doc_193540241566_item	2259603	et	4	main
ole	doc_193540241566_item	2259612	et	4	main
ühiskond	doc_193540241566_item	2259614	et	3	main
uuendamist	doc_193540241566_item	2259616	et	4	main
luuletused	doc_193540241566_item	2259631	et	4	main
paremat	doc_193540241566_item	2259639	et	4	main
mineviku	doc_193540241566_item	2259642	et	3	main
näitasid	doc_193540241566_item	2259645	et	4	main
mis	doc_193540241566_item	2259652	et	4	main
aastatel	doc_193540241566_item	2259656	et	4	main
olid	doc_193540241566_item	2259658	et	4	main
väga	doc_193540241566_item	2259659	et	3	main
radikaalsed	doc_193540241566_item	2259660	et	3	main
arvasid	doc_193540241566_item	2259661	et	4	main
juhus	doc_193540241566_item	2259671	et	4	main
oluline	doc_193540241566_item	2259673	et	4	main
ning	doc_193540241566_item	2259679	et	3	main
arvatavasti	doc_193540241566_item	2259686	et	3	main
või	doc_193540241566_item	2259691	et	4	main
nonsence	doc_193540241566_item	2259697	et	4	main
mida	doc_193540241566_item	2259701	et	4	main
see	doc_193540241566_item	2259724	et	3	main
hõlmas	doc_193540241566_item	2259725	et	4	main
oli	doc_193540241566_item	2259735	et	3	main
samal	doc_193540241566_item	2259739	et	3	main
eeldas	doc_193540241566_item	2259741	et	3	main
ekspressionistid	doc_193540241566_item	2259743	et	3	main
ühenesid	doc_193540241566_item	2259745	et	4	main
andsind	doc_193540241566_item	2259747	et	4	main
der	doc_193540241566_item	2259754	et	4	main
club	doc_193540241566_item	2259756	et	4	main
ning	doc_193540241566_item	2259757	et	3	main
autoritest	doc_193540241566_item	2259521	et	4	main
2	doc_193540241566_item	2259524	et	2	main
tekstile	doc_193540241566_item	2259527	et	3	main
f	doc_193540241566_item	2259534	et	4	main
välja	doc_193540241566_item	2259544	et	4	main
ja	doc_193540241566_item	2259549	et	3	main
tunnused	doc_193540241566_item	2259551	et	3	main
on	doc_193540241566_item	2259558	et	4	main
paljud	doc_193540241566_item	2259560	et	3	main
keele	doc_193540241566_item	2259586	et	4	main
suund	doc_193540241566_item	2259588	et	3	main
algasid	doc_193540241566_item	2259597	et	4	main
sajandi	doc_193540241566_item	2259599	et	3	main
nad	doc_193540241566_item	2259602	et	3	main
näidata	doc_193540241566_item	2259604	et	4	main
vananenud	doc_193540241566_item	2259610	et	4	main
ei	doc_193540241566_item	2259611	et	4	main
rolli	doc_193540241566_item	2259618	et	4	main
on	doc_193540241566_item	2259620	et	4	main
mänginud	doc_193540241566_item	2259621	et	4	main
maailmasõda	doc_193540241566_item	2259623	et	4	main
uued	doc_193540241566_item	2259630	et	3	main
vanu	doc_193540241566_item	2259633	et	4	main
autorid	doc_193540241566_item	2259635	et	3	main
maailma	doc_193540241566_item	2259640	et	4	main
vigadeta	doc_193540241566_item	2259643	et	3	main
arp	doc_193540241566_item	2259649	et	3	main
1922	doc_193540241566_item	2259655	et	2	main
et	doc_193540241566_item	2259662	et	3	main
ja	doc_193540241566_item	2259664	et	3	main
kõige	doc_193540241566_item	2259667	et	4	main
voola	doc_193540241566_item	2259681	et	4	main
on	doc_193540241566_item	2259683	et	4	main
mõttetust	doc_193540241566_item	2259693	et	4	main
tahaksid	doc_193540241566_item	2259695	et	4	main
kunsti	doc_193540241566_item	2259698	et	4	main
asju	doc_193540241566_item	2259700	et	3	main
raske	doc_193540241566_item	2259722	et	4	main
gruppe	doc_193540241566_item	2259727	et	3	main
lüürikas	doc_193540241566_item	2259733	et	3	main
ajal	doc_193540241566_item	2259740	et	4	main
klubidesse	doc_193540241566_item	2259746	et	3	main
välja	doc_193540241566_item	2259748	et	4	main
nt	doc_193540241566_item	2259750	et	4	main
selle	doc_193540241566_item	2259758	et	4	main
der	doc_193540241566_item	2259760	et	4	main
ekspressionistid	doc_193540241566_item	2259762	et	3	main
omad	doc_193540241566_item	2259771	et	4	main
lahkarvamused	doc_193540241566_item	2259772	et	3	main
lõpu	doc_193540241566_item	2259779	et	3	main
ja	doc_193540241566_item	2259799	et	3	main
tähtsamad	doc_193540241566_item	2259801	et	4	main
on	doc_193540241566_item	2259803	et	4	main
ning	doc_193540241566_item	2259808	et	3	main
tööd	doc_193540241566_item	2259811	et	4	main
ei	doc_193540241566_item	2259812	et	4	main
saa	doc_193540241566_item	2259813	et	4	main
eksam	doc_193540241566_item	2259507	et	3	main
1	doc_193540241566_item	2259508	et	2	main
iseloomustage	doc_193540241566_item	2259509	et	4	main
sajandi	doc_193540241566_item	2259511	et	3	main
20	doc_193540241566_item	2259510	et	2	main
lüürikale	doc_193540241566_item	2259512	et	3	main
omaseid	doc_193540241566_item	2259513	et	3	main
teemakomplekse	doc_193540241566_item	2259514	et	3	main
ja	doc_193540241566_item	2259515	et	3	main
tooge	doc_193540241566_item	2259517	et	3	main
vormivõtteid	doc_193540241566_item	2259516	et	3	main
näiteid	doc_193540241566_item	2259518	et	3	main
erinevate	doc_193540241566_item	2259519	et	4	main
rahvuskirjanduste	doc_193540241566_item	2259520	et	3	main
a	doc_193540241566_item	2259531	et	4	main
metamorfoos	doc_193540241566_item	2259538	et	3	main
stepihunt	doc_193540241566_item	2259540	et	3	main
sein	doc_193540241566_item	2259542	et	3	main
eksistentsialistlikule	doc_193540241566_item	2259545	et	4	main
vormilised	doc_193540241566_item	2259548	et	4	main
tekstinäiteid	doc_193540241566_item	2259553	et	3	main
20	doc_193540241566_item	2259555	et	2	main
mõjutanud	doc_193540241566_item	2259559	et	4	main
maailmasõda	doc_193540241566_item	2259565	et	4	main
20	doc_193540241566_item	2259578	et	2	main
võib	doc_193540241566_item	2259581	et	3	main
osaks	doc_193540241566_item	2259585	et	3	main
eksperementatiivne	doc_193540241566_item	2259587	et	4	main
sotsiaal-poliitilised	doc_193540241566_item	2259592	et	3	main
eksperemente	doc_193540241566_item	2259594	et	4	main
luuletajad	doc_193540241566_item	2259596	et	4	main
20	doc_193540241566_item	2259598	et	2	main
autorite	doc_193540241566_item	2259607	et	3	main
kaasaegsed	doc_193540241566_item	2259613	et	3	main
vajab	doc_193540241566_item	2259615	et	3	main
oli	doc_193540241566_item	2259625	et	3	main
euroopa	doc_193540241566_item	2259628	et	4	main
unistustes	doc_193540241566_item	2259629	et	4	main
eitasid	doc_193540241566_item	2259632	et	4	main
ilma	doc_193540241566_item	2259641	et	4	main
esimestena	doc_193540241566_item	2259644	et	3	main
oma	doc_193540241566_item	2259646	et	4	main
dadaistid	doc_193540241566_item	2259648	et	4	main
1916	doc_193540241566_item	2259654	et	2	main
irratsionaalsus	doc_193540241566_item	2259665	et	4	main
oma	doc_193540241566_item	2259677	et	4	main
nimetus	doc_193540241566_item	2259682	et	4	main
ilma	doc_193540241566_item	2259684	et	4	main
tähenduseta	doc_193540241566_item	2259685	et	4	main
liitudes	doc_193540241566_item	2259699	et	4	main
defineerida	doc_193540241566_item	2259723	et	3	main
maalis	doc_193540241566_item	2259731	et	4	main
ja	doc_193540241566_item	2259522	et	3	main
iseloomustage	doc_193540241566_item	2259525	et	4	main
loetud	doc_193540241566_item	2259526	et	4	main
toetudes	doc_193540241566_item	2259528	et	3	main
eksistentsialistlikku	doc_193540241566_item	2259529	et	4	main
kirjandust	doc_193540241566_item	2259530	et	3	main
kafka	doc_193540241566_item	2259535	et	4	main
protsess	doc_193540241566_item	2259536	et	3	main
hhesse	doc_193540241566_item	2259539	et	4	main
jpsartre	doc_193540241566_item	2259541	et	4	main
tooge	doc_193540241566_item	2259543	et	3	main
kirjandusele	doc_193540241566_item	2259546	et	3	main
sajandi	doc_193540241566_item	2259556	et	3	main
i	doc_193540241566_item	2259562	et	4	main
ii	doc_193540241566_item	2259564	et	4	main
urbanisatsioon	doc_193540241566_item	2259566	et	3	main
naiste	doc_193540241566_item	2259568	et	3	main
võitlus	doc_193540241566_item	2259567	et	3	main
õiguste	doc_193540241566_item	2259569	et	4	main
eest	doc_193540241566_item	2259570	et	4	main
fašism	doc_193540241566_item	2259571	et	2	main
ja	doc_193540241566_item	2259572	et	3	main
kommunism	doc_193540241566_item	2259573	et	3	main
uute	doc_193540241566_item	2259574	et	3	main
normide	doc_193540241566_item	2259575	et	3	main
otsing	doc_193540241566_item	2259576	et	3	main
kirjanduses	doc_193540241566_item	2259577	et	3	main
kolmeks	doc_193540241566_item	2259583	et	4	main
otsimine	doc_193540241566_item	2259590	et	4	main
keelega	doc_193540241566_item	2259595	et	3	main
eelmiste	doc_193540241566_item	2259606	et	3	main
teosed	doc_193540241566_item	2259608	et	3	main
i	doc_193540241566_item	2259622	et	4	main
suur	doc_193540241566_item	2259626	et	3	main
pettumus	doc_193540241566_item	2259627	et	4	main
tahtsid	doc_193540241566_item	2259636	et	4	main
uut	doc_193540241566_item	2259638	et	3	main
protesti	doc_193540241566_item	2259647	et	4	main
destruktsioon	doc_193540241566_item	2259663	et	3	main
on	doc_193540241566_item	2259672	et	4	main
nad	doc_193540241566_item	2259674	et	3	main
esitasid	doc_193540241566_item	2259675	et	4	main
töödes	doc_193540241566_item	2259678	et	3	main
isegi	doc_193540241566_item	2259680	et	4	main
dada	doc_193540241566_item	2259687	et	4	main
tähendab	doc_193540241566_item	2259688	et	3	main
lällutust	doc_193540241566_item	2259690	et	4	main
luua	doc_193540241566_item	2259696	et	4	main
päris	doc_193540241566_item	2259721	et	4	main
inimesi	doc_193540241566_item	2259728	et	4	main
emotsioone	doc_193540241566_item	2259737	et	3	main
none	doc_193540241566_item	2259755	et	4	main
ajakiri	doc_193540241566_item	2259759	et	3	main
sturm	doc_193540241566_item	2259761	et	4	main
kahjuks	doc_193540241566_item	2259766	et	4	main
ka	doc_193540241566_item	2259770	et	3	main
lõpude	doc_193540241566_item	2259774	et	4	main
olid	doc_193540241566_item	2259776	et	4	main
grupp	doc_193540241566_item	2259782	et	3	main
keeleeksperementatiivse	doc_193540241566_item	2259783	et	4	main
on	doc_193540241566_item	2259785	et	4	main
hõlmab	doc_193540241566_item	2259789	et	3	main
ka	doc_193540241566_item	2259806	et	3	main
kunstniku	doc_193540241566_item	2259817	et	3	main
filmitegijat	doc_193540241566_item	2259820	et	3	main
eesmärk	doc_193540241566_item	2259823	et	3	main
uuendust	doc_193540241566_item	2259827	et	4	main
uni	doc_193540241566_item	2259842	et	3	main
ning	doc_193540241566_item	2259845	et	3	main
vorm	doc_193540241566_item	2259872	et	3	main
palju	doc_193540241566_item	2259874	et	4	main
tähtsam	doc_193540241566_item	2259875	et	4	main
gruppi	doc_193540241566_item	2259879	et	4	main
jaoks	doc_193540241566_item	2259880	et	4	main
mõtlemisvõimalusi	doc_193540241566_item	2259896	et	3	main
anclister	doc_193540241566_item	2259897	et	4	main
bager	doc_193540241566_item	2259899	et	3	main
nad	doc_193540241566_item	2259942	et	3	main
sõna	doc_193540241566_item	2259946	et	4	main
kirjutasid	doc_193540241566_item	2259958	et	4	main
teosed	doc_193540241566_item	2259960	et	3	main
matemaatikud	doc_193540241566_item	2259975	et	3	main
tuntumad	doc_193540241566_item	2259977	et	4	main
ja	doc_193540241566_item	2259982	et	3	main
ainult	doc_193540241566_item	2259990	et	4	main
igavesed	doc_193540241566_item	2259995	et	3	main
probleemid	doc_193540241566_item	2259997	et	3	main
otsing	doc_193540241566_item	2259999	et	3	main
loodus	doc_193540241566_item	2260001	et	4	main
ja	doc_193540241566_item	2260002	et	3	main
poole	doc_193540241566_item	2260008	et	4	main
ja	doc_193540241566_item	2260012	et	3	main
koha	doc_193540241566_item	2260015	et	4	main
urbaniseerutud	doc_193540241566_item	2260017	et	4	main
luuletajaid	doc_193540241566_item	2260020	et	4	main
oli	doc_193540241566_item	2260025	et	3	main
palju	doc_193540241566_item	2260027	et	4	main
rilket	doc_193540241566_item	2260039	et	4	main
on	doc_193540241566_item	2260043	et	4	main
humanistlik	doc_193540241566_item	2260045	et	3	main
üksindust	doc_193540241566_item	2260050	et	3	main
natuuri	doc_193540241566_item	2260069	et	4	main
ahhmatova	doc_193540241566_item	2260084	et	4	main
ja	doc_193540241566_item	2260090	et	3	main
noorusest	doc_193540241566_item	2260097	et	4	main
loomulikult	doc_193540241566_item	2260098	et	4	main
tsvetajeva	doc_193540241566_item	2260112	et	4	main
hingele	doc_193540241566_item	2260127	et	4	main
mis	doc_193540241566_item	2259624	et	4	main
norme	doc_193540241566_item	2259634	et	3	main
luua	doc_193540241566_item	2259637	et	4	main
ball	doc_193540241566_item	2259650	et	3	main
schvitters	doc_193540241566_item	2259651	et	4	main
tegelesid	doc_193540241566_item	2259653	et	4	main
nemad	doc_193540241566_item	2259657	et	3	main
on	doc_193540241566_item	2259666	et	4	main
tähtsamad	doc_193540241566_item	2259668	et	4	main
mõted	doc_193540241566_item	2259669	et	4	main
et	doc_193540241566_item	2259670	et	3	main
tähendust	doc_193540241566_item	2259676	et	4	main
laste	doc_193540241566_item	2259689	et	4	main
lihtsalt	doc_193540241566_item	2259692	et	4	main
autorid	doc_193540241566_item	2259694	et	3	main
ei	doc_193540241566_item	2259702	et	4	main
ole	doc_193540241566_item	2259703	et	4	main
võimalik	doc_193540241566_item	2259704	et	3	main
kokku	doc_193540241566_item	2259705	et	3	main
panna	doc_193540241566_item	2259706	et	4	main
pärast	doc_193540241566_item	2259707	et	4	main
dadaismi	doc_193540241566_item	2259708	et	4	main
tuli	doc_193540241566_item	2259709	et	4	main
selle	doc_193540241566_item	2259711	et	4	main
ekspressionism	doc_193540241566_item	2259710	et	3	main
peaesindajad	doc_193540241566_item	2259712	et	3	main
on	doc_193540241566_item	2259713	et	4	main
benn	doc_193540241566_item	2259714	et	4	main
trakt	doc_193540241566_item	2259715	et	3	main
j	doc_193540241566_item	2259716	et	4	main
von	doc_193540241566_item	2259717	et	4	main
hoddis	doc_193540241566_item	2259718	et	4	main
ekspressionismi	doc_193540241566_item	2259719	et	4	main
on	doc_193540241566_item	2259720	et	4	main
suuri	doc_193540241566_item	2259726	et	3	main
kunstis	doc_193540241566_item	2259729	et	3	main
muusikas	doc_193540241566_item	2259730	et	3	main
ka	doc_193540241566_item	2259732	et	3	main
ekspressionism	doc_193540241566_item	2259734	et	3	main
täis	doc_193540241566_item	2259736	et	4	main
aga	doc_193540241566_item	2259738	et	3	main
tihti	doc_193540241566_item	2259744	et	3	main
saksamaal	doc_193540241566_item	2259751	et	4	main
oli	doc_193540241566_item	2259752	et	3	main
tuntud	doc_193540241566_item	2259753	et	4	main
sotsiaalkriitikat	doc_193540241566_item	2259742	et	3	main
ajakirja	doc_193540241566_item	2259749	et	4	main
gruppi	doc_193540241566_item	2259767	et	4	main
selle	doc_193540241566_item	2259777	et	4	main
voola	doc_193540241566_item	2259778	et	4	main
ja	doc_193540241566_item	2259793	et	3	main
maali	doc_193540241566_item	2259795	et	4	main
ja	doc_193540241566_item	2259796	et	3	main
fotograafiat	doc_193540241566_item	2259797	et	3	main
aragon	doc_193540241566_item	2259805	et	4	main
eluard	doc_193540241566_item	2259807	et	4	main
hilisemad	doc_193540241566_item	2259809	et	4	main
jäeta	doc_193540241566_item	2259815	et	3	main
ka	doc_193540241566_item	2259816	et	3	main
ning	doc_193540241566_item	2259819	et	3	main
ühiskonnas	doc_193540241566_item	2259828	et	4	main
kasutasid	doc_193540241566_item	2259833	et	4	main
ning	doc_193540241566_item	2259851	et	3	main
ka	doc_193540241566_item	2259853	et	3	main
oma	doc_193540241566_item	2259859	et	4	main
omapärasust	doc_193540241566_item	2259860	et	4	main
ning	doc_193540241566_item	2259861	et	3	main
viimane	doc_193540241566_item	2259863	et	3	main
keeleeksperementatiivne	doc_193540241566_item	2259865	et	4	main
et	doc_193540241566_item	2259871	et	3	main
on	doc_193540241566_item	2259873	et	4	main
arvasid	doc_193540241566_item	2259891	et	4	main
et	doc_193540241566_item	2259892	et	3	main
keel	doc_193540241566_item	2259894	et	4	main
eksperementeerisid	doc_193540241566_item	2259900	et	4	main
nad	doc_193540241566_item	2259902	et	3	main
või	doc_193540241566_item	2259921	et	4	main
lõid	doc_193540241566_item	2259925	et	4	main
figuure	doc_193540241566_item	2259927	et	3	main
tõesti	doc_193540241566_item	2259938	et	3	main
eksperimentidega	doc_193540241566_item	2259940	et	3	main
võtsid	doc_193540241566_item	2259943	et	4	main
iga	doc_193540241566_item	2259944	et	4	main
panid	doc_193540241566_item	2259949	et	4	main
lipograami	doc_193540241566_item	2259957	et	4	main
prantsusmaal	doc_193540241566_item	2259967	et	4	main
kõige	doc_193540241566_item	2259976	et	4	main
konkretistid	doc_193540241566_item	2259978	et	4	main
on	doc_193540241566_item	2259979	et	4	main
quenan	doc_193540241566_item	2259984	et	4	main
ning	doc_193540241566_item	2260006	et	3	main
püüdlemine	doc_193540241566_item	2260009	et	4	main
sõda	doc_193540241566_item	2260013	et	4	main
tegelesid	doc_193540241566_item	2259763	et	4	main
paljudes	doc_193540241566_item	2259764	et	3	main
maades	doc_193540241566_item	2259765	et	4	main
järgmine	doc_193540241566_item	2259781	et	3	main
suunast	doc_193540241566_item	2259784	et	4	main
sürrealistid	doc_193540241566_item	2259786	et	3	main
see	doc_193540241566_item	2259787	et	3	main
mitmeid	doc_193540241566_item	2259790	et	4	main
luule	doc_193540241566_item	2259792	et	4	main
proosa	doc_193540241566_item	2259794	et	4	main
luuletajad	doc_193540241566_item	2259802	et	4	main
dali	doc_193540241566_item	2259818	et	4	main
nad	doc_193540241566_item	2259829	et	3	main
saavutada	doc_193540241566_item	2259831	et	3	main
oma	doc_193540241566_item	2259834	et	4	main
töödes	doc_193540241566_item	2259835	et	3	main
nt	doc_193540241566_item	2259841	et	4	main
või	doc_193540241566_item	2259843	et	4	main
on	doc_193540241566_item	2259849	et	4	main
tänapäeval	doc_193540241566_item	2259854	et	3	main
kaasaegsust	doc_193540241566_item	2259862	et	4	main
tuntud	doc_193540241566_item	2259864	et	4	main
vool	doc_193540241566_item	2259866	et	4	main
on	doc_193540241566_item	2259867	et	4	main
arvasid	doc_193540241566_item	2259870	et	4	main
kui	doc_193540241566_item	2259876	et	3	main
viini	doc_193540241566_item	2259878	et	4	main
ja	doc_193540241566_item	2259884	et	3	main
gruppi	doc_193540241566_item	2259886	et	4	main
kasutasid	doc_193540241566_item	2259888	et	4	main
sest	doc_193540241566_item	2259890	et	4	main
artmann	doc_193540241566_item	2259898	et	4	main
osade	doc_193540241566_item	2259923	et	3	main
kasutades	doc_193540241566_item	2259928	et	3	main
ja	doc_193540241566_item	2259930	et	3	main
tuntud	doc_193540241566_item	2259934	et	4	main
grupp	doc_193540241566_item	2259935	et	3	main
oulipo	doc_193540241566_item	2259936	et	4	main
tegeles	doc_193540241566_item	2259937	et	3	main
unikaalsete	doc_193540241566_item	2259939	et	4	main
7	doc_193540241566_item	2259945	et	2	main
ning	doc_193540241566_item	2259948	et	3	main
mingit	doc_193540241566_item	2259962	et	3	main
kasutamiseta	doc_193540241566_item	2259964	et	4	main
grupp	doc_193540241566_item	2259965	et	3	main
tegeles	doc_193540241566_item	2259966	et	3	main
perec	doc_193540241566_item	2259981	et	4	main
raymond	doc_193540241566_item	2259983	et	4	main
sajandil	doc_193540241566_item	2259986	et	3	main
luuletajad	doc_193540241566_item	2259987	et	4	main
mitte	doc_193540241566_item	2259989	et	3	main
neid	doc_193540241566_item	2259992	et	4	main
huvitasid	doc_193540241566_item	2259993	et	4	main
linn	doc_193540241566_item	2260003	et	3	main
humanism	doc_193540241566_item	2260011	et	3	main
uues	doc_193540241566_item	2260016	et	3	main
maailmas	doc_193540241566_item	2260018	et	3	main
kes	doc_193540241566_item	2260021	et	4	main
probleemidest	doc_193540241566_item	2260024	et	3	main
tõesti	doc_193540241566_item	2260026	et	3	main
naisluuletajad	doc_193540241566_item	2260032	et	3	main
mina	doc_193540241566_item	2260033	et	4	main
tähele	doc_193540241566_item	2260035	et	3	main
luuletajat	doc_193540241566_item	2260038	et	4	main
sest	doc_193540241566_item	2260040	et	4	main
tema	doc_193540241566_item	2260041	et	4	main
looming	doc_193540241566_item	2260042	et	3	main
tunneb	doc_193540241566_item	2260047	et	3	main
ta	doc_193540241566_item	2260066	et	4	main
inimese	doc_193540241566_item	2260068	et	4	main
on	doc_193540241566_item	2260073	et	4	main
nobeli	doc_193540241566_item	2260075	et	4	main
auhinna	doc_193540241566_item	2260076	et	3	main
on	doc_193540241566_item	2260080	et	4	main
marina	doc_193540241566_item	2260086	et	3	main
kodumaalt	doc_193540241566_item	2260101	et	3	main
armastas	doc_193540241566_item	2260106	et	3	main
metafooriline	doc_193540241566_item	2260113	et	4	main
sees	doc_193540241566_item	2259768	et	4	main
olid	doc_193540241566_item	2259769	et	4	main
mis	doc_193540241566_item	2259773	et	4	main
lõpuks	doc_193540241566_item	2259775	et	4	main
põhjuseks	doc_193540241566_item	2259780	et	3	main
vool	doc_193540241566_item	2259788	et	4	main
kunstiliike	doc_193540241566_item	2259791	et	4	main
filmikunsti	doc_193540241566_item	2259798	et	4	main
teater	doc_193540241566_item	2259800	et	3	main
breton	doc_193540241566_item	2259804	et	4	main
schwittersi	doc_193540241566_item	2259810	et	4	main
rääkimata	doc_193540241566_item	2259814	et	4	main
dlynchi	doc_193540241566_item	2259821	et	4	main
oli	doc_193540241566_item	2259824	et	3	main
totaalset	doc_193540241566_item	2259826	et	3	main
tahaksid	doc_193540241566_item	2259830	et	4	main
vabadust	doc_193540241566_item	2259832	et	4	main
absurdi	doc_193540241566_item	2259836	et	4	main
erinevaid	doc_193540241566_item	2259839	et	4	main
hallunatsioon	doc_193540241566_item	2259844	et	4	main
tavaline	doc_193540241566_item	2259846	et	4	main
sürrealism	doc_193540241566_item	2259848	et	3	main
sest	doc_193540241566_item	2259855	et	4	main
see	doc_193540241566_item	2259856	et	3	main
ei	doc_193540241566_item	2259857	et	4	main
konkretism	doc_193540241566_item	2259868	et	4	main
konkretistid	doc_193540241566_item	2259869	et	4	main
sisu	doc_193540241566_item	2259877	et	4	main
dadaismis	doc_193540241566_item	2259883	et	3	main
keelega	doc_193540241566_item	2259901	et	3	main
nende	doc_193540241566_item	2259922	et	4	main
kordumist	doc_193540241566_item	2259924	et	4	main
erinevaid	doc_193540241566_item	2259926	et	4	main
üks	doc_193540241566_item	2259929	et	3	main
sõna	doc_193540241566_item	2259932	et	4	main
näiteks	doc_193540241566_item	2259941	et	4	main
mitte	doc_193540241566_item	2259970	et	3	main
georges	doc_193540241566_item	2259980	et	4	main
20	doc_193540241566_item	2259985	et	2	main
tegelesid	doc_193540241566_item	2259988	et	4	main
ka	doc_193540241566_item	2259994	et	3	main
armastus	doc_193540241566_item	2260000	et	4	main
traditsioonide	doc_193540241566_item	2260004	et	3	main
oma	doc_193540241566_item	2260014	et	4	main
tahaksin	doc_193540241566_item	2260034	et	3	main
austria	doc_193540241566_item	2260037	et	4	main
väga	doc_193540241566_item	2260044	et	3	main
lugeja	doc_193540241566_item	2260046	et	4	main
luule	doc_193540241566_item	2260053	et	4	main
mahukaid	doc_193540241566_item	2260071	et	4	main
jaoks	doc_193540241566_item	2260079	et	4	main
eriti	doc_193540241566_item	2260081	et	3	main
huvitavad	doc_193540241566_item	2260082	et	4	main
anna	doc_193540241566_item	2260083	et	4	main
looming	doc_193540241566_item	2260089	et	3	main
elu	doc_193540241566_item	2260091	et	4	main
on	doc_193540241566_item	2260092	et	4	main
armastusest	doc_193540241566_item	2260096	et	4	main
oma	doc_193540241566_item	2260100	et	4	main
mida	doc_193540241566_item	2260103	et	4	main
aga	doc_193540241566_item	2260107	et	3	main
luuletused	doc_193540241566_item	2260115	et	4	main
ja	doc_193540241566_item	2260117	et	3	main
üksindusest	doc_193540241566_item	2260118	et	4	main
kõik	doc_193540241566_item	2260122	et	4	main
see	doc_193540241566_item	2260123	et	3	main
luuletusi	doc_193540241566_item	2260133	et	4	main
20	doc_193540241566_item	2260136	et	2	main
ühiskonna	doc_193540241566_item	2260142	et	4	main
kodanluse	doc_193540241566_item	2260148	et	4	main
režiimide	doc_193540241566_item	2260150	et	2	main
autorite	doc_193540241566_item	2260152	et	3	main
bbrecht	doc_193540241566_item	2260155	et	4	main
ja	doc_193540241566_item	2260156	et	3	main
pablo	doc_193540241566_item	2260157	et	4	main
majakovski	doc_193540241566_item	2260169	et	4	main
omapärase	doc_193540241566_item	2260172	et	4	main
unikaalse	doc_193540241566_item	2260173	et	3	main
tema	doc_193540241566_item	2260181	et	4	main
luuletused	doc_193540241566_item	2260186	et	4	main
sõjakas	doc_193540241566_item	2260195	et	4	main
sürrealistide	doc_193540241566_item	2259822	et	3	main
luua	doc_193540241566_item	2259825	et	4	main
paradoksi	doc_193540241566_item	2259837	et	4	main
kombineerisid	doc_193540241566_item	2259838	et	4	main
reaalsusi	doc_193540241566_item	2259840	et	4	main
elu	doc_193540241566_item	2259847	et	4	main
austatud	doc_193540241566_item	2259850	et	4	main
armastatud	doc_193540241566_item	2259852	et	4	main
kaota	doc_193540241566_item	2259858	et	4	main
eeskujud	doc_193540241566_item	2259881	et	3	main
olid	doc_193540241566_item	2259882	et	4	main
sürrealismis	doc_193540241566_item	2259885	et	3	main
liikmed	doc_193540241566_item	2259887	et	3	main
keelekriitikat	doc_193540241566_item	2259889	et	3	main
meie	doc_193540241566_item	2259893	et	4	main
piirab	doc_193540241566_item	2259895	et	3	main
et	doc_193540241566_item	2259904	et	3	main
üks	doc_193540241566_item	2259905	et	3	main
arvasid	doc_193540241566_item	2259903	et	4	main
sõna	doc_193540241566_item	2259906	et	4	main
nt	doc_193540241566_item	2259907	et	4	main
lumi	doc_193540241566_item	2259908	et	3	main
väljendada	doc_193540241566_item	2259910	et	3	main
võib	doc_193540241566_item	2259909	et	3	main
rohkem	doc_193540241566_item	2259911	et	4	main
kui	doc_193540241566_item	2259912	et	3	main
poeem	doc_193540241566_item	2259914	et	3	main
terve	doc_193540241566_item	2259913	et	4	main
oma	doc_193540241566_item	2259915	et	4	main
luules	doc_193540241566_item	2259916	et	4	main
nad	doc_193540241566_item	2259917	et	3	main
tihti	doc_193540241566_item	2259918	et	3	main
kasutasid	doc_193540241566_item	2259919	et	4	main
sõnade	doc_193540241566_item	2259920	et	3	main
sama	doc_193540241566_item	2259931	et	4	main
teine	doc_193540241566_item	2259933	et	3	main
teoses	doc_193540241566_item	2259947	et	3	main
selle	doc_193540241566_item	2259950	et	4	main
asemel	doc_193540241566_item	2259951	et	4	main
järgnev	doc_193540241566_item	2259952	et	4	main
sõna	doc_193540241566_item	2259953	et	4	main
sõnaraamatust	doc_193540241566_item	2259954	et	4	main
samuti	doc_193540241566_item	2259955	et	3	main
kasutasid	doc_193540241566_item	2259956	et	4	main
terved	doc_193540241566_item	2259959	et	4	main
ilma	doc_193540241566_item	2259961	et	4	main
tähte	doc_193540241566_item	2259963	et	4	main
selles	doc_193540241566_item	2259968	et	4	main
olid	doc_193540241566_item	2259969	et	4	main
ainult	doc_193540241566_item	2259971	et	4	main
luuletajad	doc_193540241566_item	2259972	et	4	main
aga	doc_193540241566_item	2259973	et	3	main
ka	doc_193540241566_item	2259974	et	3	main
keeleeksperimentidega	doc_193540241566_item	2259991	et	3	main
inimkonna	doc_193540241566_item	2259996	et	4	main
mina	doc_193540241566_item	2259998	et	4	main
säilitamine	doc_193540241566_item	2260005	et	4	main
uuenduste	doc_193540241566_item	2260007	et	4	main
kultuur	doc_193540241566_item	2260010	et	3	main
otsimine	doc_193540241566_item	2260019	et	4	main
kirjutasid	doc_193540241566_item	2260022	et	4	main
nendest	doc_193540241566_item	2260023	et	4	main
nende	doc_193540241566_item	2260028	et	4	main
hulgas	doc_193540241566_item	2260029	et	4	main
ka	doc_193540241566_item	2260030	et	3	main
panna	doc_193540241566_item	2260036	et	4	main
kurbust	doc_193540241566_item	2260048	et	4	main
ja	doc_193540241566_item	2260049	et	3	main
tseliot	doc_193540241566_item	2260065	et	4	main
analüüsis	doc_193540241566_item	2260067	et	4	main
kirjutas	doc_193540241566_item	2260070	et	3	main
naisluuletajatest	doc_193540241566_item	2260077	et	3	main
ahhmatova	doc_193540241566_item	2260088	et	4	main
traagilised	doc_193540241566_item	2260093	et	3	main
ta	doc_193540241566_item	2260094	et	4	main
ka	doc_193540241566_item	2260099	et	3	main
venemaalt	doc_193540241566_item	2260102	et	3	main
ta	doc_193540241566_item	2260104	et	4	main
väga	doc_193540241566_item	2260105	et	3	main
mis	doc_193540241566_item	2260108	et	4	main
pani	doc_193540241566_item	2260109	et	4	main
teda	doc_193540241566_item	2260110	et	4	main
kannatada	doc_193540241566_item	2260111	et	3	main
keel	doc_193540241566_item	2260114	et	4	main
mõnikord	doc_193540241566_item	2260119	et	3	main
isegi	doc_193540241566_item	2260120	et	4	main
maksimalism	doc_193540241566_item	2260121	et	3	main
et	doc_193540241566_item	2260135	et	3	main
luuletajad	doc_193540241566_item	2260139	et	4	main
kriitikaga	doc_193540241566_item	2260143	et	3	main
vananemist	doc_193540241566_item	2260151	et	4	main
neruda	doc_193540241566_item	2260158	et	4	main
vene	doc_193540241566_item	2260161	et	4	main
lõi	doc_193540241566_item	2260171	et	4	main
stiili	doc_193540241566_item	2260174	et	4	main
inimeste	doc_193540241566_item	2260177	et	3	main
looming	doc_193540241566_item	2260182	et	3	main
väga	doc_193540241566_item	2260184	et	3	main
emotsionaalne	doc_193540241566_item	2260185	et	3	main
löövad	doc_193540241566_item	2260187	et	4	main
võimatute	doc_193540241566_item	2260191	et	4	main
on	doc_193540241566_item	2260194	et	4	main
energiline	doc_193540241566_item	2260196	et	3	main
kahjuks	doc_193540241566_item	2260197	et	4	main
otsused	doc_193540241566_item	2260225	et	3	main
teoses	doc_193540241566_item	2260234	et	3	main
peategelane	doc_193540241566_item	2260236	et	3	main
tõeline	doc_193540241566_item	2260242	et	4	main
muutuda	doc_193540241566_item	2260248	et	3	main
on	doc_193540241566_item	2260255	et	4	main
aga	doc_193540241566_item	2260258	et	3	main
ta	doc_193540241566_item	2260264	et	4	main
surm	doc_193540241566_item	2260279	et	3	main
meile	doc_193540241566_item	2260288	et	4	main
toimi	doc_193540241566_item	2260290	et	4	main
kritiseerib	doc_193540241566_item	2260323	et	3	main
suhtumist	doc_193540241566_item	2260325	et	4	main
ja	doc_193540241566_item	2260327	et	3	main
valiku	doc_193540241566_item	2260329	et	3	main
vabaduse	doc_193540241566_item	2260330	et	4	main
pere	doc_193540241566_item	2260344	et	4	main
toitja	doc_193540241566_item	2260346	et	4	main
sartre	doc_193540241566_item	2260353	et	4	main
on	doc_193540241566_item	2260355	et	4	main
kirjutatud	doc_193540241566_item	2260359	et	4	main
mitmed	doc_193540241566_item	2260031	et	4	main
läbi	doc_193540241566_item	2260051	et	4	main
rilke	doc_193540241566_item	2260052	et	4	main
aga	doc_193540241566_item	2260054	et	3	main
ka	doc_193540241566_item	2260055	et	3	main
armastust	doc_193540241566_item	2260056	et	4	main
inimeste	doc_193540241566_item	2260057	et	3	main
looduse	doc_193540241566_item	2260058	et	4	main
elu	doc_193540241566_item	2260059	et	4	main
vastu	doc_193540241566_item	2260060	et	3	main
teine	doc_193540241566_item	2260061	et	3	main
silmapaistev	doc_193540241566_item	2260062	et	4	main
luuletaja	doc_193540241566_item	2260063	et	4	main
on	doc_193540241566_item	2260064	et	4	main
poeeme	doc_193540241566_item	2260072	et	3	main
saanud	doc_193540241566_item	2260074	et	4	main
minu	doc_193540241566_item	2260078	et	3	main
ja	doc_193540241566_item	2260085	et	3	main
tsvetajeva	doc_193540241566_item	2260087	et	4	main
kirjutas	doc_193540241566_item	2260095	et	3	main
armastusest	doc_193540241566_item	2260116	et	4	main
luuge	doc_193540241566_item	2260125	et	4	main
ja	doc_193540241566_item	2260126	et	3	main
paneb	doc_193540241566_item	2260128	et	3	main
mind	doc_193540241566_item	2260129	et	4	main
lugeda	doc_193540241566_item	2260131	et	3	main
oma	doc_193540241566_item	2260145	et	4	main
luules	doc_193540241566_item	2260146	et	4	main
sotsiaalprobleeme	doc_193540241566_item	2260147	et	3	main
hulgas	doc_193540241566_item	2260153	et	4	main
sotsialistid	doc_193540241566_item	2260159	et	3	main
sotsialismi	doc_193540241566_item	2260162	et	4	main
ja	doc_193540241566_item	2260163	et	3	main
kommunismi	doc_193540241566_item	2260165	et	4	main
oli	doc_193540241566_item	2260167	et	3	main
vladimir	doc_193540241566_item	2260168	et	4	main
probleemidest	doc_193540241566_item	2260178	et	3	main
süüdistas	doc_193540241566_item	2260179	et	3	main
on	doc_193540241566_item	2260183	et	4	main
rütm	doc_193540241566_item	2260193	et	3	main
surm	doc_193540241566_item	2260200	et	3	main
tunned	doc_193540241566_item	2260221	et	3	main
inimese	doc_193540241566_item	2260226	et	4	main
areng	doc_193540241566_item	2260227	et	3	main
degradeerimine	doc_193540241566_item	2260229	et	4	main
võõras	doc_193540241566_item	2260235	et	4	main
ei	doc_193540241566_item	2260245	et	4	main
minu	doc_193540241566_item	2260252	et	3	main
ta	doc_193540241566_item	2260254	et	4	main
süü	doc_193540241566_item	2260263	et	4	main
inimesed	doc_193540241566_item	2260270	et	3	main
elada	doc_193540241566_item	2260273	et	3	main
teiste	doc_193540241566_item	2260274	et	4	main
on	doc_193540241566_item	2260283	et	4	main
sest	doc_193540241566_item	2260285	et	4	main
mõjutab	doc_193540241566_item	2260124	et	3	main
loomulik	doc_193540241566_item	2260134	et	3	main
sajandil	doc_193540241566_item	2260137	et	3	main
näitasid	doc_193540241566_item	2260144	et	4	main
bürokraatiat	doc_193540241566_item	2260149	et	3	main
olid	doc_193540241566_item	2260154	et	4	main
humanistid	doc_193540241566_item	2260160	et	3	main
isegi	doc_193540241566_item	2260164	et	4	main
hääletoruks	doc_193540241566_item	2260166	et	3	main
tema	doc_193540241566_item	2260170	et	4	main
rääkis	doc_193540241566_item	2260175	et	3	main
metafooridega	doc_193540241566_item	2260190	et	4	main
võrdlustega	doc_193540241566_item	2260192	et	4	main
nähtavasti	doc_193540241566_item	2260203	et	3	main
lõpetas	doc_193540241566_item	2260205	et	3	main
selle	doc_193540241566_item	2260206	et	4	main
autori	doc_193540241566_item	2260207	et	3	main
produktiivse	doc_193540241566_item	2260208	et	3	main
loomingu	doc_193540241566_item	2260209	et	3	main
2	doc_193540241566_item	2260210	et	2	main
eksistentsialistlikule	doc_193540241566_item	2260211	et	4	main
kirjandusele	doc_193540241566_item	2260212	et	3	main
omane	doc_193540241566_item	2260214	et	3	main
sisemaailma	doc_193540241566_item	2260216	et	4	main
kirjeldamine	doc_193540241566_item	2260217	et	4	main
on	doc_193540241566_item	2260213	et	4	main
inimese	doc_193540241566_item	2260215	et	4	main
tema	doc_193540241566_item	2260218	et	4	main
mõtted	doc_193540241566_item	2260219	et	3	main
plaanid	doc_193540241566_item	2260220	et	4	main
nende	doc_193540241566_item	2260223	et	4	main
isiku	doc_193540241566_item	2260230	et	3	main
a	doc_193540241566_item	2260232	et	4	main
on	doc_193540241566_item	2260237	et	4	main
ühiskonna	doc_193540241566_item	2260238	et	4	main
karm	doc_193540241566_item	2260240	et	4	main
tõesti	doc_193540241566_item	2260256	et	3	main
ole	doc_193540241566_item	2260261	et	4	main
tema	doc_193540241566_item	2260262	et	4	main
sellisena	doc_193540241566_item	2260268	et	4	main
inimeste	doc_193540241566_item	2260276	et	3	main
võõras	doc_193540241566_item	2260284	et	4	main
ei	doc_193540241566_item	2260289	et	4	main
protsess	doc_193540241566_item	2260322	et	3	main
näeme	doc_193540241566_item	2260333	et	3	main
poja	doc_193540241566_item	2260340	et	4	main
vastu	doc_193540241566_item	2260347	et	3	main
hesse	doc_193540241566_item	2260349	et	4	main
stepihunt	doc_193540241566_item	2260350	et	3	main
ja	doc_193540241566_item	2260351	et	3	main
ja	doc_193540241566_item	2260381	et	3	main
viib	doc_193540241566_item	2260392	et	3	main
olekute	doc_193540241566_item	2260397	et	3	main
seina	doc_193540241566_item	2260401	et	4	main
sest	doc_193540241566_item	2260408	et	4	main
elasin	doc_193540241566_item	2260410	et	3	main
hirmu	doc_193540241566_item	2260418	et	4	main
uuesti	doc_193540241566_item	2260130	et	3	main
tema	doc_193540241566_item	2260132	et	4	main
paljud	doc_193540241566_item	2260138	et	3	main
tegelesid	doc_193540241566_item	2260140	et	4	main
ka	doc_193540241566_item	2260141	et	3	main
vaeste	doc_193540241566_item	2260176	et	4	main
rikkaid	doc_193540241566_item	2260180	et	4	main
lugejat	doc_193540241566_item	2260188	et	4	main
rüümidega	doc_193540241566_item	2260189	et	3	main
luuletaja	doc_193540241566_item	2260198	et	4	main
vara	doc_193540241566_item	2260199	et	4	main
enetapmine	doc_193540241566_item	2260204	et	4	main
mis	doc_193540241566_item	2260201	et	4	main
oli	doc_193540241566_item	2260202	et	3	main
või	doc_193540241566_item	2260222	et	4	main
või	doc_193540241566_item	2260228	et	4	main
muutumine	doc_193540241566_item	2260231	et	4	main
monstr	doc_193540241566_item	2260243	et	4	main
isegi	doc_193540241566_item	2260249	et	4	main
ema	doc_193540241566_item	2260250	et	4	main
võõras	doc_193540241566_item	2260257	et	4	main
see	doc_193540241566_item	2260259	et	3	main
ei	doc_193540241566_item	2260271	et	4	main
saa	doc_193540241566_item	2260272	et	4	main
tema	doc_193540241566_item	2260278	et	4	main
loogiline	doc_193540241566_item	2260281	et	4	main
ta	doc_193540241566_item	2260282	et	4	main
sarnane	doc_193540241566_item	2260287	et	4	main
inimeste	doc_193540241566_item	2260324	et	3	main
oma	doc_193540241566_item	2260328	et	4	main
põlgust	doc_193540241566_item	2260335	et	3	main
ja	doc_193540241566_item	2260336	et	3	main
tunnet	doc_193540241566_item	2260338	et	3	main
jp	doc_193540241566_item	2260352	et	4	main
kirjeldab	doc_193540241566_item	2260383	et	3	main
mõisted	doc_193540241566_item	2260391	et	3	main
kompromissile	doc_193540241566_item	2260394	et	3	main
erinevate	doc_193540241566_item	2260396	et	4	main
vahel	doc_193540241566_item	2260398	et	4	main
jp	doc_193540241566_item	2260399	et	4	main
sartre	doc_193540241566_item	2260400	et	4	main
lugeda	doc_193540241566_item	2260407	et	3	main
mina	doc_193540241566_item	2260409	et	4	main
kõike	doc_193540241566_item	2260412	et	4	main
ja	doc_193540241566_item	2260419	et	3	main
füüsilist	doc_193540241566_item	2260420	et	3	main
surma	doc_193540241566_item	2260422	et	4	main
et	doc_193540241566_item	2260426	et	3	main
poolest	doc_193540241566_item	2260448	et	4	main
tsükliline	doc_193540241566_item	2260451	et	4	main
nt	doc_193540241566_item	2260453	et	4	main
tema	doc_193540241566_item	2260464	et	4	main
ümber	doc_193540241566_item	2260465	et	3	main
teosed	doc_193540241566_item	2260466	et	3	main
realistlikud	doc_193540241566_item	2260470	et	3	main
maagiliste	doc_193540241566_item	2260474	et	4	main
elementide	doc_193540241566_item	2260475	et	3	main
reaalsusele	doc_193540241566_item	2260477	et	4	main
ka	doc_193540241566_item	2260485	et	3	main
esimeses	doc_193540241566_item	2260488	et	3	main
seaduse	doc_193540241566_item	2260490	et	3	main
ning	doc_193540241566_item	2260492	et	3	main
informatsiooni	doc_193540241566_item	2260499	et	4	main
meelitab	doc_193540241566_item	2260502	et	3	main
sügava	doc_193540241566_item	2260505	et	4	main
selles	doc_193540241566_item	2260508	et	4	main
maailma	doc_193540241566_item	2260521	et	4	main
ning	doc_193540241566_item	2260523	et	3	main
saama	doc_193540241566_item	2260527	et	4	main
seaduse	doc_193540241567_item	2260541	et	3	main
ees	doc_193540241567_item	2260547	et	4	main
protsess	doc_193540241567_item	2260553	et	3	main
et	doc_193540241567_item	2260557	et	3	main
suureks	doc_193540241567_item	2260582	et	4	main
protsess	doc_193540241567_item	2260587	et	3	main
üks	doc_193540241567_item	2260590	et	3	main
allegooria	doc_193540241567_item	2260594	et	4	main
ta	doc_193540241567_item	2260603	et	4	main
ta	doc_193540241567_item	2260608	et	4	main
süüdi	doc_193540241567_item	2260610	et	4	main
josef	doc_193540241567_item	2260611	et	4	main
peab	doc_193540241567_item	2260621	et	4	main
ei	doc_193540241567_item	2260629	et	4	main
on	doc_193540241567_item	2260635	et	4	main
eitada	doc_193540241567_item	2260641	et	3	main
panna	doc_193540241567_item	2260645	et	4	main
tähele	doc_193540241567_item	2260646	et	3	main
sõltuv	doc_193540241567_item	2260654	et	4	main
arvamusest	doc_193540241567_item	2260657	et	4	main
ei	doc_193540241567_item	2260659	et	4	main
suuda	doc_193540241567_item	2260660	et	4	main
tõenäolisema	doc_193540241567_item	2260681	et	4	main
mees	doc_193540241567_item	2260683	et	4	main
väravavaht	doc_193540241567_item	2260689	et	3	main
puudumine	doc_193540241566_item	2260224	et	4	main
camus	doc_193540241566_item	2260233	et	4	main
silmades	doc_193540241566_item	2260239	et	3	main
hingeta	doc_193540241566_item	2260241	et	3	main
midagi	doc_193540241566_item	2260244	et	4	main
saa	doc_193540241566_item	2260246	et	4	main
teda	doc_193540241566_item	2260247	et	4	main
surm	doc_193540241566_item	2260251	et	3	main
silmades	doc_193540241566_item	2260253	et	3	main
ei	doc_193540241566_item	2260260	et	4	main
on	doc_193540241566_item	2260265	et	4	main
lihtsalt	doc_193540241566_item	2260266	et	4	main
loodud	doc_193540241566_item	2260267	et	4	main
võõrad	doc_193540241566_item	2260269	et	3	main
tavaliste	doc_193540241566_item	2260275	et	4	main
ühiskonnas	doc_193540241566_item	2260277	et	4	main
on	doc_193540241566_item	2260280	et	4	main
ei	doc_193540241566_item	2260286	et	4	main
meile	doc_193540241566_item	2260291	et	4	main
omaste	doc_193540241566_item	2260292	et	4	main
konventsioonide	doc_193540241566_item	2260293	et	3	main
järgi	doc_193540241566_item	2260294	et	4	main
fkafka	doc_193540241566_item	2260295	et	4	main
protsess	doc_193540241566_item	2260296	et	3	main
ja	doc_193540241566_item	2260297	et	3	main
metamorfoos	doc_193540241566_item	2260298	et	3	main
on	doc_193540241566_item	2260299	et	4	main
minu	doc_193540241566_item	2260300	et	3	main
näided	doc_193540241566_item	2260302	et	4	main
lemmikud	doc_193540241566_item	2260301	et	3	main
eksistentsialistlikust	doc_193540241566_item	2260303	et	4	main
kirjandusest	doc_193540241566_item	2260304	et	4	main
tappev	doc_193540241566_item	2260305	et	4	main
emotsionaalsus	doc_193540241566_item	2260306	et	4	main
absurdsed	doc_193540241566_item	2260307	et	3	main
olukorrad	doc_193540241566_item	2260308	et	3	main
tegelaste	doc_193540241566_item	2260309	et	3	main
ebanormaalne	doc_193540241566_item	2260310	et	3	main
käitumine	doc_193540241566_item	2260311	et	4	main
ebanormaalsetes	doc_193540241566_item	2260312	et	4	main
olukordades	doc_193540241566_item	2260313	et	3	main
ühiskonna	doc_193540241566_item	2260314	et	4	main
protsesside	doc_193540241566_item	2260315	et	3	main
selle	doc_193540241566_item	2260317	et	4	main
ja	doc_193540241566_item	2260316	et	3	main
esindajate	doc_193540241566_item	2260318	et	4	main
käitumise	doc_193540241566_item	2260319	et	4	main
kriitika	doc_193540241566_item	2260320	et	4	main
nii	doc_193540241566_item	2260321	et	3	main
metamorfoosis	doc_193540241566_item	2260331	et	3	main
seadusse	doc_193540241566_item	2260326	et	4	main
pereliikmete	doc_193540241566_item	2260334	et	3	main
ainukese	doc_193540241566_item	2260345	et	4	main
h	doc_193540241566_item	2260348	et	4	main
eriti	doc_193540241566_item	2260362	et	3	main
sügava	doc_193540241566_item	2260363	et	4	main
psühhoanalüüsiga	doc_193540241566_item	2260364	et	3	main
teosed	doc_193540241566_item	2260365	et	3	main
stepihundis	doc_193540241566_item	2260366	et	3	main
autor	doc_193540241566_item	2260367	et	3	main
jutustab	doc_193540241566_item	2260368	et	3	main
harry	doc_193540241566_item	2260369	et	4	main
kasvust	doc_193540241566_item	2260370	et	3	main
igavast	doc_193540241566_item	2260371	et	3	main
elust	doc_193540241566_item	2260372	et	3	main
kaugelseisavast	doc_193540241566_item	2260373	et	4	main
kirjanikust	doc_193540241566_item	2260374	et	3	main
tõelise	doc_193540241566_item	2260375	et	4	main
kogenud	doc_193540241566_item	2260376	et	4	main
eluarmastajani	doc_193540241566_item	2260377	et	3	main
hhesse	doc_193540241566_item	2260378	et	4	main
väga	doc_193540241566_item	2260379	et	3	main
me	doc_193540241566_item	2260332	et	4	main
vastikus	doc_193540241566_item	2260337	et	4	main
oma	doc_193540241566_item	2260339	et	4	main
ja	doc_193540241566_item	2260341	et	3	main
venna	doc_193540241566_item	2260342	et	3	main
ning	doc_193540241566_item	2260343	et	3	main
sein	doc_193540241566_item	2260354	et	3	main
väga	doc_193540241566_item	2260356	et	3	main
erinevatele	doc_193540241566_item	2260357	et	4	main
teemadele	doc_193540241566_item	2260358	et	3	main
aga	doc_193540241566_item	2260360	et	3	main
ühtlasi	doc_193540241566_item	2260361	et	4	main
ja	doc_193540241566_item	2260386	et	3	main
vahel	doc_193540241566_item	2260388	et	4	main
mõlemad	doc_193540241566_item	2260390	et	3	main
harry	doc_193540241566_item	2260393	et	4	main
jaoks	doc_193540241566_item	2260404	et	4	main
läbi	doc_193540241566_item	2260411	et	4	main
tema	doc_193540241566_item	2260417	et	4	main
seisundit	doc_193540241566_item	2260421	et	3	main
ühiskonna	doc_193540241566_item	2260435	et	4	main
psühholoogia	doc_193540241566_item	2260441	et	4	main
ajavoolu	doc_193540241566_item	2260447	et	4	main
nagu	doc_193540241566_item	2260452	et	3	main
paljudes	doc_193540241566_item	2260455	et	3	main
peategelane	doc_193540241566_item	2260457	et	3	main
üks	doc_193540241566_item	2260459	et	3	main
on	doc_193540241566_item	2260467	et	4	main
kasvõi	doc_193540241566_item	2260468	et	3	main
sein	doc_193540241566_item	2260472	et	3	main
protsessis	doc_193540241566_item	2260480	et	4	main
on	doc_193540241566_item	2260483	et	4	main
teos	doc_193540241566_item	2260486	et	4	main
teoses	doc_193540241566_item	2260487	et	3	main
teises	doc_193540241566_item	2260493	et	4	main
kirjandus	doc_193540241566_item	2260501	et	3	main
peenelt	doc_193540241566_item	2260380	et	4	main
täpselt	doc_193540241566_item	2260382	et	4	main
võitlust	doc_193540241566_item	2260384	et	3	main
tema	doc_193540241566_item	2260395	et	4	main
oli	doc_193540241566_item	2260402	et	3	main
raske	doc_193540241566_item	2260406	et	4	main
omal	doc_193540241566_item	2260430	et	3	main
kritiseerivaid	doc_193540241566_item	2260432	et	4	main
ja	doc_193540241566_item	2260434	et	3	main
puute	doc_193540241566_item	2260436	et	3	main
kõikide	doc_193540241566_item	2260443	et	4	main
teoste	doc_193540241566_item	2260444	et	3	main
struktuur	doc_193540241566_item	2260445	et	3	main
mitte	doc_193540241566_item	2260450	et	3	main
teostes	doc_193540241566_item	2260456	et	3	main
peamiselt	doc_193540241566_item	2260462	et	4	main
toimub	doc_193540241566_item	2260463	et	3	main
või	doc_193540241566_item	2260473	et	4	main
ja	doc_193540241566_item	2260481	et	3	main
mõistujutt	doc_193540241566_item	2260489	et	3	main
mis	doc_193540241566_item	2260496	et	4	main
peamist	doc_193540241566_item	2260498	et	3	main
eksistentsialistlik	doc_193540241566_item	2260500	et	4	main
psühhoanalüüsi	doc_193540241566_item	2260506	et	4	main
poolest	doc_193540241566_item	2260507	et	4	main
ma	doc_193540241566_item	2260509	et	3	main
nendest	doc_193540241566_item	2260525	et	4	main
eksistentsialistlik	doc_193540241566_item	2260530	et	4	main
kaasaegne	doc_193540241566_item	2260534	et	3	main
kafka	doc_193540241567_item	2260540	et	4	main
tõlke	doc_193540241567_item	2260543	et	4	main
interpretatsioon	doc_193540241567_item	2260544	et	3	main
osa	doc_193540241567_item	2260549	et	4	main
terve	doc_193540241567_item	2260561	et	4	main
peaidee	doc_193540241567_item	2260563	et	4	main
romaan	doc_193540241567_item	2260586	et	3	main
suur	doc_193540241567_item	2260591	et	3	main
et	doc_193540241567_item	2260602	et	3	main
ette	doc_193540241567_item	2260606	et	4	main
milles	doc_193540241567_item	2260607	et	3	main
k	doc_193540241567_item	2260612	et	4	main
usub	doc_193540241567_item	2260614	et	3	main
alanud	doc_193540241567_item	2260619	et	4	main
siis	doc_193540241567_item	2260620	et	3	main
ka	doc_193540241567_item	2260623	et	3	main
luba	doc_193540241567_item	2260630	et	4	main
mõtet	doc_193540241567_item	2260631	et	3	main
et	doc_193540241567_item	2260632	et	3	main
käes	doc_193540241567_item	2260634	et	4	main
lõpetada	doc_193540241567_item	2260638	et	3	main
kahjuks	doc_193540241567_item	2260650	et	4	main
teiste	doc_193540241567_item	2260655	et	4	main
ise	doc_193540241567_item	2260661	et	4	main
kõige	doc_193540241567_item	2260680	et	4	main
vahel	doc_193540241567_item	2260707	et	4	main
tulla	doc_193540241567_item	2260711	et	3	main
võidelda	doc_193540241567_item	2260719	et	4	main
mõistujutt	doc_193540241567_item	2260728	et	3	main
räägib	doc_193540241567_item	2260730	et	3	main
meie	doc_193540241567_item	2260762	et	4	main
otsime	doc_193540241567_item	2260781	et	4	main
väljastpoolt	doc_193540241567_item	2260785	et	3	main
las	doc_193540241567_item	2260788	et	4	main
annab	doc_193540241567_item	2260790	et	3	main
lubab	doc_193540241567_item	2260794	et	3	main
sul	doc_193540241567_item	2260805	et	3	main
ise	doc_193540241567_item	2260829	et	4	main
siseneda	doc_193540241567_item	2260833	et	3	main
on	doc_193540241567_item	2260852	et	4	main
nähtavasti	doc_193540241567_item	2260853	et	3	main
josef	doc_193540241567_item	2260854	et	4	main
aga	doc_193540241567_item	2260857	et	3	main
ta	doc_193540241567_item	2260863	et	4	main
püstitanud	doc_193540241567_item	2260885	et	4	main
ise	doc_193540241567_item	2260889	et	4	main
lase	doc_193540241567_item	2260891	et	4	main
ennast	doc_193540241567_item	2260892	et	4	main
hirmuga	doc_193540241567_item	2260897	et	3	main
sest	doc_193540241567_item	2260906	et	4	main
südames	doc_193540241567_item	2260907	et	3	main
teab	doc_193540241567_item	2260909	et	3	main
inimese	doc_193540241566_item	2260385	et	4	main
hundi	doc_193540241566_item	2260387	et	3	main
avardab	doc_193540241566_item	2260389	et	3	main
minu	doc_193540241566_item	2260403	et	3	main
väga	doc_193540241566_item	2260405	et	3	main
mis	doc_193540241566_item	2260413	et	4	main
juhtus	doc_193540241566_item	2260414	et	3	main
peategelasega	doc_193540241566_item	2260415	et	3	main
tundsin	doc_193540241566_item	2260416	et	3	main
vaatamata	doc_193540241566_item	2260424	et	4	main
sellele	doc_193540241566_item	2260425	et	4	main
kõik	doc_193540241566_item	2260427	et	4	main
mooel	doc_193540241566_item	2260431	et	4	main
on	doc_193540241566_item	2260438	et	4	main
on	doc_193540241566_item	2260446	et	4	main
jooneline	doc_193540241566_item	2260449	et	4	main
lisamisega	doc_193540241566_item	2260476	et	4	main
metamorfoos	doc_193540241566_item	2260478	et	3	main
olemas	doc_193540241566_item	2260484	et	4	main
traktaat	doc_193540241566_item	2260494	et	3	main
stepihundist	doc_193540241566_item	2260495	et	3	main
sisaldab	doc_193540241566_item	2260497	et	3	main
just	doc_193540241566_item	2260504	et	3	main
tajumist	doc_193540241566_item	2260522	et	4	main
minu	doc_193540241566_item	2260528	et	3	main
kirjandus	doc_193540241566_item	2260531	et	3	main
ja	doc_193540241566_item	2260535	et	3	main
franz	doc_193540241567_item	2260539	et	4	main
ees	doc_193540241567_item	2260542	et	4	main
seaduse	doc_193540241567_item	2260546	et	3	main
kafka	doc_193540241567_item	2260551	et	4	main
on	doc_193540241567_item	2260559	et	4	main
selle	doc_193540241567_item	2260564	et	4	main
teoseks	doc_193540241567_item	2260583	et	4	main
et	doc_193540241567_item	2260585	et	3	main
mõistujutt	doc_193540241567_item	2260592	et	3	main
ei	doc_193540241567_item	2260604	et	4	main
kujuta	doc_193540241567_item	2260605	et	4	main
kohe	doc_193540241567_item	2260613	et	4	main
et	doc_193540241567_item	2260615	et	3	main
kohtuprotsess	doc_193540241567_item	2260617	et	3	main
ees	doc_193540241566_item	2260423	et	4	main
loetud	doc_193540241566_item	2260428	et	4	main
autorid	doc_193540241566_item	2260429	et	3	main
inimeste	doc_193540241566_item	2260433	et	3	main
nad	doc_193540241566_item	2260437	et	3	main
humanistid	doc_193540241566_item	2260439	et	3	main
inimeste	doc_193540241566_item	2260440	et	3	main
uurijad	doc_193540241566_item	2260442	et	4	main
post-modernismi	doc_193540241566_item	2260454	et	4	main
on	doc_193540241566_item	2260458	et	4	main
kõik	doc_193540241566_item	2260460	et	4	main
tegevus	doc_193540241566_item	2260461	et	4	main
täiesti	doc_193540241566_item	2260469	et	3	main
võõras	doc_193540241566_item	2260471	et	4	main
stepihunt	doc_193540241566_item	2260479	et	3	main
stepihundis	doc_193540241566_item	2260482	et	3	main
sees	doc_193540241566_item	2260491	et	4	main
mind	doc_193540241566_item	2260503	et	4	main
võin	doc_193540241566_item	2260510	et	3	main
leida	doc_193540241566_item	2260511	et	3	main
palju	doc_193540241566_item	2260512	et	4	main
vastuseid	doc_193540241566_item	2260513	et	3	main
küsimustele	doc_193540241566_item	2260514	et	4	main
mis	doc_193540241566_item	2260515	et	4	main
mind	doc_193540241566_item	2260516	et	4	main
huvitavad	doc_193540241566_item	2260517	et	4	main
jälgida	doc_193540241566_item	2260518	et	3	main
erinevate	doc_193540241566_item	2260519	et	4	main
inimeste	doc_193540241566_item	2260520	et	3	main
arvates	doc_193540241566_item	2260529	et	4	main
on	doc_193540241566_item	2260532	et	4	main
alati	doc_193540241566_item	2260536	et	4	main
essee	doc_193540241567_item	2260538	et	4	main
paljud	doc_193540241567_item	2260554	et	3	main
kriitikud	doc_193540241567_item	2260555	et	3	main
peidetud	doc_193540241567_item	2260560	et	4	main
romaani	doc_193540241567_item	2260562	et	4	main
paistab	doc_193540241567_item	2260584	et	3	main
on	doc_193540241567_item	2260588	et	4	main
sürrealistlik	doc_193540241567_item	2260593	et	3	main
selle	doc_193540241567_item	2260595	et	4	main
peategelasele	doc_193540241567_item	2260596	et	3	main
esitatakse	doc_193540241567_item	2260598	et	3	main
süüdistust	doc_193540241567_item	2260599	et	4	main
vaatamata	doc_193540241567_item	2260600	et	4	main
on	doc_193540241567_item	2260618	et	4	main
põhjus	doc_193540241567_item	2260625	et	4	main
süü	doc_193540241567_item	2260627	et	4	main
või	doc_193540241567_item	2260642	et	4	main
tsirkust	doc_193540241567_item	2260649	et	3	main
protagonist	doc_193540241567_item	2260651	et	4	main
liiga	doc_193540241567_item	2260653	et	4	main
maalt	doc_193540241567_item	2260684	et	3	main
isikustab	doc_193540241567_item	2260690	et	3	main
bürokraatiat	doc_193540241567_item	2260691	et	3	main
ei	doc_193540241567_item	2260693	et	4	main
värav	doc_193540241567_item	2260699	et	3	main
füüsiline	doc_193540241567_item	2260702	et	3	main
tavainimese	doc_193540241567_item	2260704	et	4	main
seaduse	doc_193540241567_item	2260706	et	3	main
kuidas	doc_193540241567_item	2260708	et	3	main
lõhkuda	doc_193540241567_item	2260715	et	3	main
väravavahi	doc_193540241567_item	2260717	et	3	main
paremani	doc_193540241566_item	2260524	et	4	main
aru	doc_193540241566_item	2260526	et	4	main
väga	doc_193540241566_item	2260533	et	3	main
kohapärane	doc_193540241566_item	2260537	et	4	main
mõistujutt	doc_193540241567_item	2260545	et	3	main
on	doc_193540241567_item	2260548	et	4	main
franz	doc_193540241567_item	2260550	et	4	main
romaanist	doc_193540241567_item	2260552	et	3	main
arvavad	doc_193540241567_item	2260556	et	4	main
mõistujutus	doc_193540241567_item	2260558	et	3	main
mõte	doc_193540241567_item	2260565	et	3	main
moraal	doc_193540241567_item	2260566	et	3	main
on	doc_193540241567_item	2260567	et	4	main
teatud	doc_193540241567_item	2260568	et	4	main
et	doc_193540241567_item	2260569	et	3	main
fkafka	doc_193540241567_item	2260571	et	4	main
mõnikord	doc_193540241567_item	2260570	et	3	main
alguses	doc_193540241567_item	2260572	et	4	main
kirjutas	doc_193540241567_item	2260573	et	3	main
mõistujuttu	doc_193540241567_item	2260575	et	4	main
lühikest	doc_193540241567_item	2260574	et	4	main
ja	doc_193540241567_item	2260576	et	3	main
alles	doc_193540241567_item	2260577	et	3	main
siis	doc_193540241567_item	2260578	et	3	main
vormistas	doc_193540241567_item	2260579	et	3	main
selle	doc_193540241567_item	2260580	et	4	main
umber	doc_193540241567_item	2260581	et	3	main
ka	doc_193540241567_item	2260589	et	3	main
josefile	doc_193540241567_item	2260597	et	4	main
sellele	doc_193540241567_item	2260601	et	4	main
on	doc_193540241567_item	2260609	et	4	main
kui	doc_193540241567_item	2260616	et	3	main
olema	doc_193540241567_item	2260622	et	4	main
tema	doc_193540241567_item	2260626	et	4	main
ta	doc_193540241567_item	2260628	et	4	main
tema	doc_193540241567_item	2260633	et	4	main
lihtsalt	doc_193540241567_item	2260643	et	4	main
mitte	doc_193540241567_item	2260644	et	3	main
inimeste	doc_193540241567_item	2260656	et	3	main
ta	doc_193540241567_item	2260658	et	4	main
mõistujuttu	doc_193540241567_item	2260679	et	4	main
viisiga	doc_193540241567_item	2260682	et	4	main
mis	doc_193540241567_item	2260692	et	4	main
lase	doc_193540241567_item	2260694	et	4	main
inimest	doc_193540241567_item	2260695	et	3	main
seaduse	doc_193540241567_item	2260696	et	3	main
juurde	doc_193540241567_item	2260697	et	4	main
kas	doc_193540241567_item	2260712	et	3	main
värav	doc_193540241567_item	2260713	et	3	main
äkki	doc_193540241567_item	2260720	et	3	main
kättesaamatusest	doc_193540241567_item	2260732	et	4	main
see	doc_193540241567_item	2260742	et	3	main
sees	doc_193540241567_item	2260763	et	4	main
seadus	doc_193540241567_item	2260764	et	4	main
õigus	doc_193540241567_item	2260772	et	4	main
valest	doc_193540241567_item	2260782	et	4	main
kuskilt	doc_193540241567_item	2260784	et	4	main
ootame	doc_193540241567_item	2260786	et	3	main
et	doc_193540241567_item	2260787	et	3	main
seaduse	doc_193540241567_item	2260791	et	3	main
väravavaht	doc_193540241567_item	2260798	et	3	main
keela	doc_193540241567_item	2260800	et	4	main
tahtmine	doc_193540241567_item	2260809	et	4	main
mingi	doc_193540241567_item	2260624	et	4	main
õigus	doc_193540241567_item	2260636	et	4	main
protsessi	doc_193540241567_item	2260637	et	4	main
oma	doc_193540241567_item	2260639	et	4	main
süüdi	doc_193540241567_item	2260640	et	4	main
seda	doc_193540241567_item	2260647	et	3	main
absurdset	doc_193540241567_item	2260648	et	3	main
on	doc_193540241567_item	2260652	et	4	main
midagi	doc_193540241567_item	2260662	et	4	main
otsustada	doc_193540241567_item	2260663	et	3	main
sellest	doc_193540241567_item	2260664	et	4	main
räägib	doc_193540241567_item	2260665	et	3	main
ka	doc_193540241567_item	2260666	et	3	main
mõistujutt	doc_193540241567_item	2260667	et	3	main
aga	doc_193540241567_item	2260668	et	3	main
kes	doc_193540241567_item	2260669	et	4	main
on	doc_193540241567_item	2260670	et	4	main
kes	doc_193540241567_item	2260671	et	4	main
paraboolis	doc_193540241567_item	2260672	et	4	main
seaduse	doc_193540241567_item	2260673	et	3	main
ees	doc_193540241567_item	2260674	et	4	main
loomulikult	doc_193540241567_item	2260675	et	4	main
on	doc_193540241567_item	2260676	et	4	main
võimalik	doc_193540241567_item	2260677	et	3	main
seletada	doc_193540241567_item	2260678	et	3	main
on	doc_193540241567_item	2260685	et	4	main
tavaline	doc_193540241567_item	2260686	et	4	main
inimene	doc_193540241567_item	2260687	et	3	main
kuid	doc_193540241567_item	2260688	et	4	main
on	doc_193540241567_item	2260700	et	4	main
nagu	doc_193540241567_item	2260701	et	3	main
takistus	doc_193540241567_item	2260703	et	4	main
ja	doc_193540241567_item	2260705	et	3	main
siis	doc_193540241567_item	2260709	et	3	main
ära	doc_193540241567_item	2260714	et	4	main
sügavam	doc_193540241567_item	2260726	et	4	main
ikka	doc_193540241567_item	2260729	et	4	main
ei	doc_193540241567_item	2260735	et	4	main
lihtsalt	doc_193540241567_item	2260737	et	4	main
bürokraatlik	doc_193540241567_item	2260739	et	3	main
kohus	doc_193540241567_item	2260740	et	4	main
on	doc_193540241567_item	2260743	et	4	main
mis	doc_193540241567_item	2260745	et	4	main
kehastab	doc_193540241567_item	2260746	et	3	main
ja	doc_193540241567_item	2260749	et	3	main
seaduse	doc_193540241567_item	2260756	et	3	main
ebaloogiline	doc_193540241567_item	2260758	et	4	main
seadus	doc_193540241567_item	2260760	et	4	main
ole	doc_193540241567_item	2260766	et	4	main
see	doc_193540241567_item	2260769	et	3	main
on	doc_193540241567_item	2260774	et	4	main
meie	doc_193540241567_item	2260779	et	4	main
keegi	doc_193540241567_item	2260789	et	4	main
las	doc_193540241567_item	2260792	et	4	main
ei	doc_193540241567_item	2260799	et	4	main
ju	doc_193540241567_item	2260801	et	3	main
mehele	doc_193540241567_item	2260802	et	3	main
nii	doc_193540241567_item	2260807	et	3	main
teha	doc_193540241567_item	2260826	et	3	main
ei	doc_193540241567_item	2260835	et	4	main
tegude	doc_193540241567_item	2260839	et	3	main
ootab	doc_193540241567_item	2260843	et	3	main
sisse	doc_193540241567_item	2260849	et	4	main
k	doc_193540241567_item	2260855	et	4	main
ise	doc_193540241567_item	2260856	et	4	main
kes	doc_193540241567_item	2260858	et	4	main
iseloomustab	doc_193540241567_item	2260864	et	4	main
endale	doc_193540241567_item	2260886	et	4	main
end	doc_193540241567_item	2260895	et	4	main
õigustades	doc_193540241567_item	2260896	et	3	main
veelgi	doc_193540241567_item	2260899	et	4	main
valvurite	doc_193540241567_item	2260901	et	3	main
ta	doc_193540241567_item	2260908	et	4	main
et	doc_193540241567_item	2260910	et	3	main
ei	doc_193540241567_item	2260918	et	4	main
vaid	doc_193540241567_item	2260921	et	3	main
ta	doc_193540241567_item	2260924	et	4	main
teisi	doc_193540241567_item	2260926	et	4	main
sama	doc_193540241567_item	2260927	et	4	main
mõlemad	doc_193540241567_item	2260934	et	3	main
väravavaht	doc_193540241567_item	2260937	et	3	main
juures	doc_193540241567_item	2260948	et	4	main
siis	doc_193540241567_item	2260953	et	3	main
seletab	doc_193540241567_item	2260955	et	3	main
mehele	doc_193540241567_item	2260956	et	3	main
näidata	doc_193540241567_item	2260969	et	4	main
mõistujutus	doc_193540241567_item	2260986	et	3	main
ise	doc_193540241567_item	2260990	et	4	main
aru	doc_193540241567_item	2260994	et	4	main
on	doc_193540241567_item	2260996	et	4	main
poolt	doc_193540241568_item	2261026	et	4	main
courage	doc_193540241568_item	2261031	et	4	main
frkafka	doc_193540241568_item	2261038	et	4	main
kujutatud	doc_193540241568_item	2261041	et	4	main
on	doc_193540241568_item	2261051	et	4	main
või	doc_193540241568_item	2261054	et	4	main
kultuuriruumile	doc_193540241568_item	2261058	et	3	main
nähtustega	doc_193540241568_item	2261060	et	4	main
vormikeelt	doc_193540241568_item	2261067	et	4	main
näiteid	doc_193540241568_item	2261073	et	3	main
bbrecht	doc_193540241568_item	2261076	et	4	main
naisest	doc_193540241568_item	2261081	et	3	main
püüab	doc_193540241568_item	2261083	et	3	main
aga	doc_193540241568_item	2261088	et	3	main
kaob	doc_193540241568_item	2261090	et	3	main
siis	doc_193540241567_item	2260698	et	3	main
sisse	doc_193540241567_item	2260710	et	4	main
või	doc_193540241567_item	2260716	et	4	main
vastu	doc_193540241567_item	2260718	et	3	main
mõte	doc_193540241567_item	2260721	et	3	main
natuke	doc_193540241567_item	2260723	et	4	main
laiem	doc_193540241567_item	2260724	et	4	main
see	doc_193540241567_item	2260733	et	3	main
ole	doc_193540241567_item	2260736	et	4	main
madal	doc_193540241567_item	2260738	et	3	main
vaid	doc_193540241567_item	2260741	et	3	main
seadus	doc_193540241567_item	2260744	et	4	main
õiglust	doc_193540241567_item	2260747	et	4	main
mõistus	doc_193540241567_item	2260748	et	4	main
samal	doc_193540241567_item	2260751	et	3	main
ajal	doc_193540241567_item	2260752	et	4	main
räägib	doc_193540241567_item	2260754	et	3	main
ka	doc_193540241567_item	2260755	et	3	main
kättesaadavusest	doc_193540241567_item	2260757	et	4	main
aga	doc_193540241567_item	2260759	et	3	main
on	doc_193540241567_item	2260761	et	4	main
ei	doc_193540241567_item	2260765	et	4	main
luba	doc_193540241567_item	2260768	et	4	main
on	doc_193540241567_item	2260770	et	4	main
meie	doc_193540241567_item	2260771	et	4	main
inimeste	doc_193540241567_item	2260775	et	3	main
tahe	doc_193540241567_item	2260776	et	4	main
ja	doc_193540241567_item	2260777	et	3	main
kohast	doc_193540241567_item	2260783	et	4	main
ta	doc_193540241567_item	2260793	et	4	main
või	doc_193540241567_item	2260795	et	4	main
keela	doc_193540241567_item	2260796	et	4	main
siseneda	doc_193540241567_item	2260803	et	3	main
kange	doc_193540241567_item	2260808	et	4	main
temal	doc_193540241567_item	2260821	et	3	main
puudub	doc_193540241567_item	2260823	et	3	main
aga	doc_193540241567_item	2260827	et	3	main
ning	doc_193540241567_item	2260841	et	3	main
mees	doc_193540241567_item	2260851	et	4	main
on	doc_193540241567_item	2260859	et	4	main
peegeldus	doc_193540241567_item	2260881	et	4	main
ise	doc_193540241567_item	2260883	et	4	main
on	doc_193540241567_item	2260884	et	4	main
ei	doc_193540241567_item	2260890	et	4	main
kardab	doc_193540241567_item	2260904	et	4	main
ei	doc_193540241567_item	2260912	et	4	main
nii	doc_193540241567_item	2260914	et	3	main
enda	doc_193540241567_item	2260930	et	4	main
saa	doc_193540241567_item	2260939	et	4	main
seaduse	doc_193540241567_item	2260940	et	3	main
väljaspool	doc_193540241567_item	2260946	et	3	main
surmani	doc_193540241567_item	2260951	et	3	main
ainult	doc_193540241567_item	2260952	et	4	main
väravavaht	doc_193540241567_item	2260954	et	3	main
et	doc_193540241567_item	2260957	et	3	main
tahtis	doc_193540241567_item	2260968	et	3	main
on	doc_193540241567_item	2260973	et	4	main
ning	doc_193540241567_item	2260978	et	3	main
käest	doc_193540241567_item	2260981	et	4	main
kahjuks	doc_193540241567_item	2260983	et	4	main
kui	doc_193540241567_item	2260987	et	3	main
surm	doc_193540241567_item	2260995	et	3	main
nende	doc_193540241567_item	2260997	et	4	main
karistus	doc_193540241567_item	2260998	et	4	main
mõistuse	doc_193540241567_item	2260999	et	3	main
ja	doc_193540241568_item	2261021	et	3	main
ema	doc_193540241568_item	2261030	et	4	main
mbulgakov	doc_193540241568_item	2261032	et	4	main
cwolf	doc_193540241568_item	2261035	et	4	main
hääled	doc_193540241568_item	2261037	et	3	main
probleemidega	doc_193540241568_item	2261053	et	3	main
iseloomulike	doc_193540241568_item	2261059	et	3	main
nende	doc_193540241568_item	2261066	et	4	main
põhjendage	doc_193540241568_item	2261068	et	3	main
seisukohti	doc_193540241568_item	2261070	et	4	main
tuleb	doc_193540241568_item	2261080	et	3	main
kes	doc_193540241568_item	2261082	et	4	main
sõja	doc_193540241568_item	2261084	et	3	main
elu	doc_193540241568_item	2261086	et	4	main
surevad	doc_193540241568_item	2261098	et	4	main
unusta	doc_193540241568_item	2261102	et	4	main
ise	doc_193540241568_item	2261103	et	4	main
on	doc_193540241567_item	2260722	et	4	main
ja	doc_193540241567_item	2260725	et	3	main
kindlasti	doc_193540241567_item	2260727	et	3	main
seaduse	doc_193540241567_item	2260731	et	3	main
seadus	doc_193540241567_item	2260734	et	4	main
tõtt	doc_193540241567_item	2260750	et	4	main
mõistujutt	doc_193540241567_item	2260753	et	3	main
ülemuse	doc_193540241567_item	2260767	et	4	main
seadus	doc_193540241567_item	2260773	et	4	main
valikuvabadus	doc_193540241567_item	2260778	et	4	main
lihtsalt	doc_193540241567_item	2260780	et	4	main
midagi	doc_193540241567_item	2260797	et	4	main
kui	doc_193540241567_item	2260804	et	3	main
on	doc_193540241567_item	2260806	et	4	main
eks	doc_193540241567_item	2260810	et	3	main
sa	doc_193540241567_item	2260811	et	3	main
siis	doc_193540241567_item	2260812	et	3	main
proovi	doc_193540241567_item	2260813	et	4	main
minu	doc_193540241567_item	2260814	et	3	main
keelust	doc_193540241567_item	2260815	et	4	main
hoolimata	doc_193540241567_item	2260816	et	4	main
sisse	doc_193540241567_item	2260817	et	4	main
minna	doc_193540241567_item	2260818	et	3	main
võib	doc_193540241567_item	2260819	et	3	main
olla	doc_193540241567_item	2260820	et	3	main
mees	doc_193540241567_item	2260828	et	4	main
ei	doc_193540241567_item	2260830	et	4	main
mõtle	doc_193540241567_item	2260831	et	4	main
võimalusest	doc_193540241567_item	2260832	et	4	main
eest	doc_193540241567_item	2260840	et	4	main
parem	doc_193540241567_item	2260842	et	4	main
kuni	doc_193540241567_item	2260844	et	3	main
keegi	doc_193540241567_item	2260845	et	4	main
teine	doc_193540241567_item	2260846	et	3	main
laseb	doc_193540241567_item	2260847	et	3	main
mingeid	doc_193540241567_item	2260865	et	3	main
tema	doc_193540241567_item	2260882	et	4	main
takistuse	doc_193540241567_item	2260887	et	4	main
seaduse	doc_193540241567_item	2260893	et	3	main
juurde	doc_193540241567_item	2260894	et	4	main
ees	doc_193540241567_item	2260902	et	4	main
inimene	doc_193540241567_item	2260903	et	3	main
ta	doc_193540241567_item	2260911	et	4	main
tema	doc_193540241567_item	2260916	et	4	main
koosne	doc_193540241567_item	2260919	et	4	main
kohut	doc_193540241567_item	2260932	et	3	main
ja	doc_193540241567_item	2260936	et	3	main
juurde	doc_193540241567_item	2260941	et	4	main
nad	doc_193540241567_item	2260943	et	3	main
seadusest	doc_193540241567_item	2260945	et	4	main
väravate	doc_193540241567_item	2260947	et	3	main
ainult	doc_193540241567_item	2260961	et	4	main
jutustaja	doc_193540241567_item	2260967	et	4	main
josefile	doc_193540241567_item	2260970	et	4	main
temal	doc_193540241567_item	2260972	et	3	main
veel	doc_193540241567_item	2260974	et	4	main
võimalus	doc_193540241567_item	2260975	et	3	main
protsessi	doc_193540241567_item	2260976	et	4	main
vältida	doc_193540241567_item	2260977	et	3	main
end	doc_193540241567_item	2260979	et	4	main
päästa	doc_193540241567_item	2260982	et	4	main
nii	doc_193540241567_item	2260984	et	3	main
õpetusest	doc_193540241567_item	2260993	et	4	main
piiratuse	doc_193540241567_item	2261000	et	4	main
mitmes	doc_193540241568_item	2261024	et	4	main
üksikisiku	doc_193540241568_item	2261042	et	3	main
konflikti	doc_193540241568_item	2261043	et	4	main
ühiskonnaga	doc_193540241568_item	2261044	et	4	main
sellise	doc_193540241568_item	2261047	et	4	main
ja	doc_193540241568_item	2261057	et	3	main
ja	doc_193540241568_item	2261071	et	3	main
isegi	doc_193540241567_item	2260822	et	4	main
õigus	doc_193540241567_item	2260824	et	4	main
seda	doc_193540241567_item	2260825	et	3	main
ta	doc_193540241567_item	2260834	et	4	main
taha	doc_193540241567_item	2260836	et	4	main
vastutada	doc_193540241567_item	2260837	et	3	main
oma	doc_193540241567_item	2260838	et	4	main
teda	doc_193540241567_item	2260848	et	4	main
see	doc_193540241567_item	2260850	et	3	main
siis	doc_193540241567_item	2260860	et	3	main
väravavaht	doc_193540241567_item	2260861	et	3	main
kas	doc_193540241567_item	2260862	et	3	main
välisjõude	doc_193540241567_item	2260866	et	3	main
minu	doc_193540241567_item	2260867	et	3	main
arvates	doc_193540241567_item	2260868	et	4	main
väravavaht	doc_193540241567_item	2260869	et	3	main
pigem	doc_193540241567_item	2260871	et	3	main
mehe	doc_193540241567_item	2260872	et	3	main
teine	doc_193540241567_item	2260873	et	3	main
on	doc_193540241567_item	2260870	et	4	main
olek	doc_193540241567_item	2260874	et	3	main
tema	doc_193540241567_item	2260875	et	4	main
mõistete	doc_193540241567_item	2260876	et	3	main
tunnete	doc_193540241567_item	2260877	et	4	main
ja	doc_193540241567_item	2260878	et	3	main
ootuste	doc_193540241567_item	2260879	et	3	main
füüsiline	doc_193540241567_item	2260880	et	3	main
ning	doc_193540241567_item	2260888	et	3	main
teiste	doc_193540241567_item	2260898	et	4	main
vägevamate	doc_193540241567_item	2260900	et	4	main
õiglust	doc_193540241567_item	2260905	et	4	main
ole	doc_193540241567_item	2260913	et	4	main
kuriteost	doc_193540241567_item	2260920	et	4	main
et	doc_193540241567_item	2260923	et	3	main
inimesi	doc_193540241567_item	2260929	et	4	main
üle	doc_193540241567_item	2260931	et	3	main
pääseda	doc_193540241567_item	2260942	et	3	main
kuni	doc_193540241567_item	2260949	et	3	main
sissepääs	doc_193540241567_item	2260958	et	3	main
määratud	doc_193540241567_item	2260960	et	4	main
sinu	doc_193540241567_item	2260962	et	3	main
jaoks	doc_193540241567_item	2260963	et	4	main
minu	doc_193540241567_item	2260965	et	3	main
surma	doc_193540241567_item	2260980	et	4	main
mees	doc_193540241567_item	2260985	et	4	main
saanud	doc_193540241567_item	2260992	et	4	main
tekstidest	doc_193540241568_item	2261022	et	3	main
bbrecht	doc_193540241568_item	2261029	et	4	main
munad	doc_193540241568_item	2261034	et	3	main
medeia	doc_193540241568_item	2261036	et	4	main
protsess	doc_193540241568_item	2261039	et	3	main
on	doc_193540241568_item	2261040	et	4	main
viib	doc_193540241568_item	2261046	et	3	main
kujutatud	doc_193540241568_item	2261055	et	4	main
aja-	doc_193540241568_item	2261056	et	4	main
skitseerige	doc_193540241568_item	2261061	et	3	main
probleemistik	doc_193540241568_item	2261063	et	4	main
kirjeldage	doc_193540241568_item	2261065	et	3	main
tooge	doc_193540241568_item	2261072	et	3	main
tekstidest	doc_193540241568_item	2261074	et	3	main
ema	doc_193540241568_item	2261077	et	4	main
jääda	doc_193540241568_item	2261087	et	4	main
oma	doc_193540241568_item	2261091	et	4	main
kolm	doc_193540241568_item	2261092	et	3	main
last	doc_193540241568_item	2261093	et	4	main
aga	doc_193540241568_item	2261099	et	3	main
laulab	doc_193540241568_item	2261108	et	3	main
võidulaulu	doc_193540241568_item	2261109	et	4	main
saatuslikud	doc_193540241568_item	2261111	et	3	main
selles	doc_193540241568_item	2261113	et	4	main
ühe	doc_193540241568_item	2261118	et	4	main
kuid	doc_193540241568_item	2261121	et	4	main
professor	doc_193540241568_item	2261123	et	3	main
selles	doc_193540241568_item	2261127	et	4	main
juhtus	doc_193540241568_item	2261129	et	3	main
professori	doc_193540241568_item	2261136	et	3	main
võib	doc_193540241568_item	2261138	et	3	main
neid	doc_193540241568_item	2261141	et	4	main
cwolf	doc_193540241568_item	2261144	et	4	main
ühe	doc_193540241568_item	2261152	et	4	main
naise	doc_193540241568_item	2261153	et	3	main
vastu	doc_193540241568_item	2261154	et	3	main
patriarhaalne	doc_193540241568_item	2261157	et	3	main
euroopas	doc_193540241568_item	2261171	et	3	main
mõttes	doc_193540241568_item	2261177	et	3	main
üksisiku	doc_193540241568_item	2261180	et	4	main
kõige	doc_193540241568_item	2261185	et	4	main
lugeja	doc_193540241568_item	2261189	et	4	main
peategija	doc_193540241568_item	2261195	et	4	main
süütu	doc_193540241567_item	2260915	et	4	main
süü	doc_193540241567_item	2260917	et	4	main
sellest	doc_193540241567_item	2260922	et	4	main
laseb	doc_193540241567_item	2260925	et	3	main
patuseid	doc_193540241567_item	2260928	et	4	main
mõista	doc_193540241567_item	2260933	et	4	main
mees	doc_193540241567_item	2260935	et	4	main
ei	doc_193540241567_item	2260938	et	4	main
seisavad	doc_193540241567_item	2260944	et	3	main
mehe	doc_193540241567_item	2260950	et	3	main
oli	doc_193540241567_item	2260959	et	3	main
sellega	doc_193540241567_item	2260964	et	3	main
arvates	doc_193540241567_item	2260966	et	4	main
et	doc_193540241567_item	2260971	et	3	main
ka	doc_193540241567_item	2260988	et	3	main
josef	doc_193540241567_item	2260989	et	4	main
ei	doc_193540241567_item	2260991	et	4	main
nürimeelsuse	doc_193540241567_item	2261001	et	4	main
ja	doc_193540241567_item	2261002	et	3	main
tahtejõu	doc_193540241567_item	2261003	et	3	main
puudumise	doc_193540241567_item	2261004	et	4	main
eest	doc_193540241567_item	2261005	et	4	main
eksam	doc_193540241568_item	2261006	et	3	main
1	doc_193540241568_item	2261007	et	2	main
iseloomustage	doc_193540241568_item	2261008	et	4	main
20	doc_193540241568_item	2261009	et	2	main
sajandi	doc_193540241568_item	2261010	et	3	main
modernistliku	doc_193540241568_item	2261011	et	3	main
lüürika	doc_193540241568_item	2261012	et	4	main
teemasid	doc_193540241568_item	2261013	et	3	main
ja	doc_193540241568_item	2261014	et	3	main
vormivõtteid	doc_193540241568_item	2261015	et	3	main
tooge	doc_193540241568_item	2261016	et	3	main
näiteid	doc_193540241568_item	2261017	et	3	main
erinevate	doc_193540241568_item	2261018	et	4	main
rahvuskirjanduste	doc_193540241568_item	2261019	et	3	main
autoritest	doc_193540241568_item	2261020	et	4	main
2	doc_193540241568_item	2261023	et	2	main
teie	doc_193540241568_item	2261025	et	4	main
loetud	doc_193540241568_item	2261027	et	4	main
teoses	doc_193540241568_item	2261028	et	3	main
saatuslikud	doc_193540241568_item	2261033	et	3	main
mis	doc_193540241568_item	2261045	et	4	main
vastasseisuni	doc_193540241568_item	2261048	et	3	main
kas	doc_193540241568_item	2261049	et	3	main
tegemist	doc_193540241568_item	2261050	et	4	main
üldinimlike	doc_193540241568_item	2261052	et	3	main
teoste	doc_193540241568_item	2261062	et	3	main
ning	doc_193540241568_item	2261064	et	3	main
oma	doc_193540241568_item	2261069	et	4	main
2	doc_193540241568_item	2261075	et	2	main
jutt	doc_193540241568_item	2261079	et	3	main
samas	doc_193540241568_item	2261089	et	4	main
tütar	doc_193540241568_item	2261097	et	3	main
endast	doc_193540241568_item	2261104	et	4	main
lõppus	doc_193540241568_item	2261107	et	4	main
inimese	doc_193540241568_item	2261119	et	4	main
süüdi	doc_193540241568_item	2261126	et	4	main
riigis	doc_193540241568_item	2261130	et	3	main
ühiskond	doc_193540241568_item	2261150	et	3	main
kirjanik	doc_193540241568_item	2261160	et	3	main
näite	doc_193540241568_item	2261162	et	4	main
aga	doc_193540241568_item	2261164	et	3	main
seda	doc_193540241568_item	2261166	et	3	main
probleemidega	doc_193540241568_item	2261168	et	3	main
ja	doc_193540241568_item	2261170	et	3	main
demonstreeritud	doc_193540241568_item	2261184	et	4	main
parem	doc_193540241568_item	2261186	et	4	main
leheküljest	doc_193540241568_item	2261188	et	4	main
saab	doc_193540241568_item	2261190	et	3	main
aru	doc_193540241568_item	2261191	et	4	main
et	doc_193540241568_item	2261192	et	3	main
ühiskonna	doc_193540241568_item	2261193	et	4	main
õige	doc_193540241568_item	2261227	et	4	main
tuleb	doc_193540241568_item	2261232	et	3	main
ühiskonnaga	doc_193540241568_item	2261235	et	4	main
aja-	doc_193540241568_item	2261239	et	4	main
ja	doc_193540241568_item	2261240	et	3	main
raamatute	doc_193540241568_item	2261252	et	3	main
unustama	doc_193540241568_item	2261259	et	3	main
inimese	doc_193540241568_item	2261262	et	4	main
on	doc_193540241568_item	2261264	et	4	main
kallis	doc_193540241568_item	2261273	et	4	main
küljest	doc_193540241568_item	2261281	et	4	main
nagu	doc_193540241568_item	2261289	et	3	main
mõtleksid	doc_193540241568_item	2261297	et	4	main
sellest	doc_193540241568_item	2261298	et	4	main
kuidas	doc_193540241568_item	2261299	et	3	main
elavad	doc_193540241568_item	2261301	et	4	main
analüüs	doc_193540241570_item	2261485	et	3	main
katkendi	doc_193540241570_item	2261490	et	3	main
ehk	doc_193540241570_item	2261495	et	3	main
courage	doc_193540241568_item	2261078	et	4	main
jooksul	doc_193540241568_item	2261085	et	4	main
ta	doc_193540241568_item	2261100	et	4	main
ei	doc_193540241568_item	2261101	et	4	main
mbulgakov	doc_193540241568_item	2261110	et	4	main
munad	doc_193540241568_item	2261112	et	3	main
on	doc_193540241568_item	2261117	et	4	main
polnud	doc_193540241568_item	2261125	et	3	main
raamatu	doc_193540241568_item	2261131	et	4	main
kaheksandas	doc_193540241568_item	2261132	et	3	main
olla	doc_193540241568_item	2261139	et	3	main
aga	doc_193540241568_item	2261148	et	3	main
on	doc_193540241568_item	2261151	et	4	main
on	doc_193540241568_item	2261155	et	4	main
toob	doc_193540241568_item	2261161	et	3	main
võrdleb	doc_193540241568_item	2261165	et	3	main
sõja	doc_193540241568_item	2261173	et	3	main
protsess	doc_193540241568_item	2261175	et	3	main
selles	doc_193540241568_item	2261178	et	4	main
ühiskonnaga	doc_193540241568_item	2261182	et	4	main
võib	doc_193540241568_item	2261221	et	3	main
vastasseisund	doc_193540241568_item	2261225	et	3	main
teoses	doc_193540241568_item	2261230	et	3	main
niisugune	doc_193540241568_item	2261243	et	3	main
kes	doc_193540241568_item	2261245	et	4	main
kogu	doc_193540241568_item	2261247	et	4	main
ühiskonna	doc_193540241568_item	2261248	et	4	main
nende	doc_193540241568_item	2261251	et	4	main
et	doc_193540241568_item	2261260	et	3	main
ise	doc_193540241568_item	2261268	et	4	main
ja	doc_193540241568_item	2261274	et	3	main
pole	doc_193540241568_item	2261277	et	3	main
gerooiline	doc_193540241568_item	2261278	et	4	main
aga	doc_193540241568_item	2261279	et	3	main
inimeseta	doc_193540241568_item	2261283	et	3	main
on	doc_193540241568_item	2261288	et	4	main
argument	doc_193540241568_item	2261292	et	3	main
et	doc_193540241568_item	2261294	et	3	main
inimesed	doc_193540241568_item	2261296	et	3	main
kivirähki	doc_193540241570_item	2261492	et	4	main
romaanist	doc_193540241570_item	2261493	et	3	main
körti	doc_193540241570_item	2261507	et	4	main
küsis	doc_193540241570_item	2261509	et	3	main
mis	doc_193540241570_item	2261511	et	4	main
oli	doc_193540241570_item	2261514	et	3	main
kallal	doc_193540241570_item	2261517	et	4	main
ah	doc_193540241570_item	2261519	et	3	main
vana	doc_193540241570_item	2261527	et	4	main
sahvris	doc_193540241570_item	2261531	et	3	main
poleks	doc_193540241570_item	2261537	et	3	main
hambutu	doc_193540241570_item	2261548	et	4	main
ikka	doc_193540241570_item	2261552	et	4	main
olen	doc_193540241570_item	2261555	et	3	main
käisin	doc_193540241570_item	2261565	et	3	main
mõisast	doc_193540241570_item	2261567	et	4	main
ja	doc_193540241570_item	2261590	et	3	main
tema	doc_193540241568_item	2261094	et	4	main
pojad	doc_193540241568_item	2261095	et	4	main
ja	doc_193540241568_item	2261096	et	3	main
ja	doc_193540241568_item	2261105	et	3	main
ühiskond	doc_193540241568_item	2261116	et	3	main
teose	doc_193540241568_item	2261106	et	3	main
teoses	doc_193540241568_item	2261114	et	3	main
kogu	doc_193540241568_item	2261115	et	4	main
vastu	doc_193540241568_item	2261120	et	3	main
ühiskond	doc_193540241568_item	2261134	et	3	main
inimesi	doc_193540241568_item	2261142	et	4	main
kogu	doc_193540241568_item	2261149	et	4	main
ka	doc_193540241568_item	2261156	et	3	main
motiiv	doc_193540241568_item	2261158	et	3	main
mifoloogiast	doc_193540241568_item	2261163	et	4	main
tänapäeva	doc_193540241568_item	2261167	et	4	main
enne	doc_193540241568_item	2261172	et	4	main
teoses	doc_193540241568_item	2261179	et	3	main
konflikt	doc_193540241568_item	2261181	et	3	main
on	doc_193540241568_item	2261183	et	4	main
ja	doc_193540241568_item	2261194	et	3	main
vahel	doc_193540241568_item	2261196	et	4	main
selline	doc_193540241568_item	2261224	et	4	main
nendes	doc_193540241568_item	2261229	et	4	main
jutt	doc_193540241568_item	2261231	et	3	main
kultuuriruumil	doc_193540241568_item	2261241	et	3	main
vastu	doc_193540241568_item	2261249	et	3	main
niisugune	doc_193540241568_item	2261261	et	3	main
saatus	doc_193540241568_item	2261263	et	3	main
traagiline	doc_193540241568_item	2261265	et	3	main
või	doc_193540241568_item	2261269	et	4	main
midagi	doc_193540241568_item	2261271	et	4	main
väga	doc_193540241568_item	2261272	et	3	main
ei	doc_193540241568_item	2261285	et	4	main
ta	doc_193540241568_item	2261287	et	4	main
sümbol	doc_193540241568_item	2261290	et	3	main
aga	doc_193540241568_item	2261122	et	3	main
persikov	doc_193540241568_item	2261124	et	4	main
mis	doc_193540241568_item	2261128	et	4	main
peatükkis	doc_193540241568_item	2261133	et	4	main
tapab	doc_193540241568_item	2261135	et	3	main
kes	doc_193540241568_item	2261137	et	4	main
võiks	doc_193540241568_item	2261140	et	4	main
päästa	doc_193540241568_item	2261143	et	4	main
medeia	doc_193540241568_item	2261145	et	4	main
hääled	doc_193540241568_item	2261146	et	3	main
siin	doc_193540241568_item	2261147	et	4	main
saksa	doc_193540241568_item	2261159	et	4	main
saksamaal	doc_193540241568_item	2261169	et	4	main
frkafka	doc_193540241568_item	2261174	et	4	main
minu	doc_193540241568_item	2261176	et	3	main
esimesest	doc_193540241568_item	2261187	et	3	main
juhtus	doc_193540241568_item	2261197	et	3	main
kohutav	doc_193540241568_item	2261198	et	4	main
arusaamatus	doc_193540241568_item	2261199	et	4	main
mis	doc_193540241568_item	2261200	et	4	main
lõpeb	doc_193540241568_item	2261201	et	4	main
k	doc_193540241568_item	2261202	et	4	main
surmaga	doc_193540241568_item	2261203	et	3	main
algusest	doc_193540241568_item	2261204	et	4	main
lõppuni	doc_193540241568_item	2261205	et	3	main
püüab	doc_193540241568_item	2261207	et	3	main
k	doc_193540241568_item	2261206	et	4	main
teha	doc_193540241568_item	2261208	et	3	main
midagi	doc_193540241568_item	2261209	et	4	main
et	doc_193540241568_item	2261210	et	3	main
enda	doc_193540241568_item	2261211	et	4	main
päästa	doc_193540241568_item	2261212	et	4	main
ühiskonna	doc_193540241568_item	2261213	et	4	main
kattest	doc_193540241568_item	2261214	et	4	main
aga	doc_193540241568_item	2261215	et	3	main
asjad	doc_193540241568_item	2261216	et	3	main
muutuvad	doc_193540241568_item	2261217	et	4	main
veel	doc_193540241568_item	2261218	et	4	main
traagilisemaks	doc_193540241568_item	2261219	et	4	main
niisiis	doc_193540241568_item	2261220	et	3	main
et	doc_193540241568_item	2261223	et	3	main
on	doc_193540241568_item	2261226	et	4	main
sest	doc_193540241568_item	2261228	et	4	main
konfliktist	doc_193540241568_item	2261233	et	3	main
ühiskonnas	doc_193540241568_item	2261237	et	4	main
leidub	doc_193540241568_item	2261242	et	3	main
inimene	doc_193540241568_item	2261244	et	3	main
seisab	doc_193540241568_item	2261246	et	3	main
räägivad	doc_193540241568_item	2261254	et	3	main
ei	doc_193540241568_item	2261257	et	4	main
sureb	doc_193540241568_item	2261267	et	3	main
selline	doc_193540241568_item	2261275	et	4	main
selleks	doc_193540241568_item	2261293	et	4	main
öelda	doc_193540241568_item	2261222	et	4	main
üksisiku	doc_193540241568_item	2261234	et	4	main
igas	doc_193540241568_item	2261236	et	3	main
igas	doc_193540241568_item	2261238	et	3	main
ja	doc_193540241568_item	2261250	et	3	main
autorid	doc_193540241568_item	2261253	et	3	main
sellest	doc_193540241568_item	2261255	et	4	main
et	doc_193540241568_item	2261256	et	3	main
pea	doc_193540241568_item	2261258	et	4	main
ta	doc_193540241568_item	2261266	et	4	main
kaob	doc_193540241568_item	2261270	et	3	main
lõpp	doc_193540241568_item	2261276	et	3	main
teisest	doc_193540241568_item	2261280	et	4	main
niisuguse	doc_193540241568_item	2261282	et	3	main
ka	doc_193540241568_item	2261284	et	3	main
saa	doc_193540241568_item	2261286	et	4	main
ja	doc_193540241568_item	2261291	et	3	main
teised	doc_193540241568_item	2261295	et	4	main
nad	doc_193540241568_item	2261300	et	3	main
teksti	doc_193540241570_item	2261486	et	4	main
analüüsiks	doc_193540241570_item	2261488	et	4	main
november	doc_193540241570_item	2261496	et	3	main
rehepapp	doc_193540241570_item	2261498	et	3	main
jõudis	doc_193540241570_item	2261500	et	3	main
vana	doc_193540241570_item	2261502	et	4	main
joosep	doc_193540241570_item	2261504	et	4	main
kuuma	doc_193540241570_item	2261506	et	4	main
häda	doc_193540241570_item	2261513	et	4	main
kõrvutavlingvistiliseks	doc_193540241570_item	2261487	et	4	main
valisin	doc_193540241570_item	2261489	et	3	main
andrus	doc_193540241570_item	2261491	et	3	main
kui	doc_193540241570_item	2261497	et	3	main
luupainaja	doc_193540241570_item	2261515	et	4	main
luupainaja	doc_193540241570_item	2261521	et	4	main
käis	doc_193540241570_item	2261529	et	4	main
sisse	doc_193540241570_item	2261535	et	4	main
sõi	doc_193540241570_item	2261541	et	3	main
ükspäev	doc_193540241570_item	2261563	et	3	main
nagu	doc_193540241570_item	2261593	et	3	main
ristirahvas	doc_193540241570_item	2261605	et	4	main
jätke	doc_193540241570_item	2261610	et	4	main
sooled	doc_193540241570_item	2261612	et	3	main
võtsin	doc_193540241570_item	2261621	et	3	main
ja	doc_193540241570_item	2261624	et	3	main
olid	doc_193540241570_item	2261630	et	4	main
sai	doc_193540241570_item	2261637	et	4	main
endale	doc_193540241570_item	2261655	et	4	main
toomata	doc_193540241570_item	2261678	et	4	main
ise	doc_193540241570_item	2261682	et	4	main
vedama	doc_193540241570_item	2261683	et	3	main
on	doc_193540241570_item	2261685	et	4	main
rumalus	doc_193540241570_item	2261687	et	4	main
tõlke	doc_193540241570_item	2261688	et	4	main
autor	doc_193540241570_item	2261689	et	3	main
xxx	doc_193540241570_item	2261690	et	4	main
allikas	doc_193540241570_item	2261691	et	4	main
httpadmhmaorupeoplefinougrhtmlprozaestoncikivirahkr1html	doc_193540241570_item	2261692	et	4	main
гуменщик	doc_193540241570_item	2261694	et	2	main
история	doc_193540241570_item	2261725	et	2	main
полакомиться	doc_193540241570_item	2261730	et	2	main
следует	doc_193540241570_item	2261735	et	2	main
эх-хе-хе	doc_193540241570_item	2261739	et	2	main
люди	doc_193540241570_item	2261744	et	2	main
посмотрю	doc_193540241570_item	2261747	et	2	main
они	doc_193540241570_item	2261753	et	2	main
за	doc_193540241570_item	2261762	et	2	main
тебя	doc_193540241570_item	2261766	et	2	main
из	doc_193540241570_item	2261770	et	2	main
соседней	doc_193540241570_item	2261771	et	2	main
и	doc_193540241570_item	2261775	et	2	main
они	doc_193540241570_item	2261779	et	2	main
сидит	doc_193540241570_item	2261783	et	2	main
восковые	doc_193540241570_item	2261791	et	2	main
порядочный	doc_193540241570_item	2261796	et	2	main
по	doc_193540241570_item	2261798	et	2	main
им	doc_193540241570_item	2261802	et	2	main
свечами	doc_193540241570_item	2261808	et	2	main
они	doc_193540241570_item	2261815	et	2	main
rehepapp	doc_193540241570_item	2261494	et	3	main
koju	doc_193540241570_item	2261499	et	3	main
talle	doc_193540241570_item	2261505	et	4	main
ja	doc_193540241570_item	2261508	et	3	main
noh	doc_193540241570_item	2261510	et	3	main
käis	doc_193540241570_item	2261516	et	4	main
rehepapp	doc_193540241570_item	2261525	et	3	main
maiustamas	doc_193540241570_item	2261532	et	3	main
ajas	doc_193540241570_item	2261534	et	4	main
mida	doc_193540241570_item	2261536	et	4	main
vaja	doc_193540241570_item	2261538	et	4	main
seepi	doc_193540241570_item	2261540	et	4	main
naeris	doc_193540241570_item	2261545	et	4	main
vana	doc_193540241570_item	2261546	et	4	main
kratt	doc_193540241570_item	2261547	et	3	main
mis	doc_193540241570_item	2261559	et	4	main
nad	doc_193540241570_item	2261560	et	3	main
teinekord	doc_193540241570_item	2261561	et	3	main
toomas	doc_193540241570_item	2261569	et	3	main
lõikas	doc_193540241570_item	2261591	et	3	main
tubli	doc_193540241570_item	2261597	et	4	main
ütlen	doc_193540241570_item	2261602	et	3	main
kallis	doc_193540241570_item	2261604	et	4	main
ega	doc_193540241570_item	2261606	et	3	main
ega	doc_193540241570_item	2261617	et	3	main
tulema	doc_193540241570_item	2261626	et	4	main
kõik	doc_193540241570_item	2261631	et	4	main
sellest	doc_193540241570_item	2261634	et	4	main
liiva-annus	doc_193540241570_item	2261636	et	3	main
aru	doc_193540241570_item	2261642	et	4	main
mina	doc_193540241570_item	2261645	et	4	main
öelnud	doc_193540241570_item	2261648	et	4	main
ei	doc_193540241570_item	2261652	et	4	main
tema	doc_193540241570_item	2261659	et	4	main
veab	doc_193540241570_item	2261660	et	3	main
kratt	doc_193540241570_item	2261661	et	3	main
solki	doc_193540241570_item	2261663	et	4	main
ei	doc_193540241570_item	2261665	et	4	main
too	doc_193540241570_item	2261666	et	4	main
mis	doc_193540241570_item	2261675	et	4	main
head-paremat	doc_193540241570_item	2261676	et	4	main
kratt	doc_193540241570_item	2261677	et	3	main
jätab	doc_193540241570_item	2261679	et	3	main
ja	doc_193540241570_item	2261680	et	3	main
see	doc_193540241570_item	2261684	et	3	main
selge	doc_193540241570_item	2261686	et	4	main
в	doc_193540241570_item	2261727	et	2	main
pakkus	doc_193540241570_item	2261501	et	3	main
kratt	doc_193540241570_item	2261503	et	3	main
sulasel	doc_193540241570_item	2261512	et	3	main
või	doc_193540241570_item	2261518	et	4	main
mis	doc_193540241570_item	2261520	et	4	main
lugu	doc_193540241570_item	2261528	et	4	main
ja	doc_193540241570_item	2261533	et	3	main
tola	doc_193540241570_item	2261542	et	4	main
eh-eh-hee	doc_193540241570_item	2261544	et	3	main
on	doc_193540241570_item	2261551	et	4	main
rumalad	doc_193540241570_item	2261553	et	3	main
ma	doc_193540241570_item	2261554	et	3	main
näinud	doc_193540241570_item	2261557	et	4	main
vahaküünlaid	doc_193540241570_item	2261592	et	3	main
leiba	doc_193540241570_item	2261594	et	4	main
mõtlesin	doc_193540241570_item	2261600	et	3	main
neile	doc_193540241570_item	2261603	et	4	main
mauk	doc_193540241570_item	2261609	et	3	main
järele	doc_193540241570_item	2261611	et	4	main
lähevad	doc_193540241570_item	2261613	et	3	main
aga	doc_193540241570_item	2261615	et	3	main
nad	doc_193540241570_item	2261618	et	3	main
kuula	doc_193540241570_item	2261620	et	4	main
tulin	doc_193540241570_item	2261625	et	3	main
kuulsin	doc_193540241570_item	2261628	et	3	main
surnud	doc_193540241570_item	2261633	et	4	main
hea	doc_193540241570_item	2261638	et	4	main
inimestel	doc_193540241570_item	2261644	et	3	main
olen	doc_193540241570_item	2261646	et	3	main
oska	doc_193540241570_item	2261653	et	4	main
ja	doc_193540241570_item	2261657	et	3	main
juba	doc_193540241570_item	2261662	et	3	main
ei	doc_193540241570_item	2261669	et	4	main
mõtlevad	doc_193540241570_item	2261671	et	4	main
махнул	doc_193540241570_item	2261721	et	2	main
наведался	doc_193540241570_item	2261726	et	2	main
и	doc_193540241570_item	2261731	et	2	main
мыла	doc_193540241570_item	2261736	et	2	main
старый	doc_193540241570_item	2261742	et	2	main
совсем	doc_193540241570_item	2261748	et	2	main
я	doc_193540241570_item	2261756	et	2	main
деревни	doc_193540241570_item	2261772	et	2	main
так	doc_193540241570_item	2261778	et	2	main
на	doc_193540241570_item	2261784	et	2	main
в	doc_193540241570_item	2261787	et	2	main
словно	doc_193540241570_item	2261793	et	2	main
кусок	doc_193540241570_item	2261797	et	2	main
очереди	doc_193540241570_item	2261799	et	2	main
кто	doc_193540241570_item	2261805	et	2	main
бросьте	doc_193540241570_item	2261810	et	2	main
домовика	doc_193540241570_item	2261816	et	2	main
а	doc_193540241570_item	2261825	et	2	main
что	doc_193540241570_item	2261829	et	2	main
свечи	doc_193540241570_item	2261834	et	2	main
поживилась	doc_193540241570_item	2261837	et	2	main
я	doc_193540241570_item	2261842	et	2	main
умеешь	doc_193540241570_item	2261849	et	2	main
подсобляет	doc_193540241570_item	2261855	et	2	main
принесет	doc_193540241570_item	2261861	et	2	main
верят	doc_193540241570_item	2261865	et	2	main
добро	doc_193540241570_item	2261870	et	2	main
сами	doc_193540241570_item	2261875	et	2	main
jubal	doc_193540241570_item	2261879	et	4	main
teksti	doc_193540241570_item	2261880	et	4	main
lugejal	doc_193540241570_item	2261886	et	4	main
püsitegelane	doc_193540241570_item	2261894	et	3	main
igast	doc_193540241570_item	2261900	et	3	main
november	doc_193540241570_item	2261902	et	3	main
peab	doc_193540241570_item	2261912	et	4	main
selliseid	doc_193540241570_item	2261921	et	4	main
pole	doc_193540241570_item	2261923	et	3	main
ega	doc_193540241570_item	2261930	et	3	main
teatud	doc_193540241570_item	2261933	et	4	main
kindlate	doc_193540241570_item	2261934	et	3	main
on	doc_193540241570_item	2261949	et	4	main
teiste	doc_193540241570_item	2261951	et	4	main
tulesabaga	doc_193540241570_item	2261959	et	3	main
kes	doc_193540241570_item	2261961	et	4	main
folkloori	doc_193540241570_item	2261974	et	4	main
домовой	doc_193540241570_item	2261977	et	2	main
ei	doc_193540241570_item	2261984	et	4	main
sihukesel	doc_193540241570_item	2261522	et	4	main
prussakal	doc_193540241570_item	2261523	et	3	main
lõi	doc_193540241570_item	2261524	et	4	main
käega	doc_193540241570_item	2261526	et	3	main
mõisa	doc_193540241570_item	2261530	et	3	main
olnud	doc_193540241570_item	2261539	et	4	main
selline	doc_193540241570_item	2261543	et	4	main
suuga	doc_193540241570_item	2261549	et	3	main
inimesed	doc_193540241570_item	2261550	et	3	main
ju	doc_193540241570_item	2261556	et	3	main
küll	doc_193540241570_item	2261558	et	4	main
teevad	doc_193540241570_item	2261562	et	3	main
alles	doc_193540241570_item	2261564	et	3	main
sulle	doc_193540241570_item	2261566	et	3	main
nisujahu	doc_193540241570_item	2261568	et	4	main
siis	doc_193540241570_item	2261570	et	3	main
oli	doc_193540241570_item	2261571	et	3	main
üks	doc_193540241570_item	2261573	et	3	main
perekond	doc_193540241570_item	2261574	et	3	main
naaberkülast	doc_193540241570_item	2261575	et	4	main
isa	doc_193540241570_item	2261576	et	4	main
seal	doc_193540241570_item	2261572	et	4	main
ema	doc_193540241570_item	2261577	et	4	main
ja	doc_193540241570_item	2261578	et	3	main
kuus	doc_193540241570_item	2261579	et	4	main
last	doc_193540241570_item	2261580	et	4	main
kõik	doc_193540241570_item	2261581	et	4	main
sõid	doc_193540241570_item	2261582	et	4	main
küünlaid	doc_193540241570_item	2261583	et	3	main
isa	doc_193540241570_item	2261584	et	4	main
istus	doc_193540241570_item	2261585	et	4	main
tünni	doc_193540241570_item	2261586	et	4	main
otsas	doc_193540241570_item	2261587	et	4	main
nuga	doc_193540241570_item	2261588	et	4	main
käes	doc_193540241570_item	2261589	et	4	main
ma	doc_193540241570_item	2261599	et	3	main
pole	doc_193540241570_item	2261608	et	3	main
no	doc_193540241570_item	2261616	et	3	main
hiljem	doc_193540241570_item	2261627	et	3	main
noosi	doc_193540241570_item	2261639	et	4	main
ei	doc_193540241570_item	2261640	et	4	main
peas	doc_193540241570_item	2261643	et	4	main
tee	doc_193540241570_item	2261654	et	4	main
las	doc_193540241570_item	2261658	et	4	main
koju	doc_193540241570_item	2261664	et	3	main
aga	doc_193540241570_item	2261667	et	3	main
kes	doc_193540241570_item	2261673	et	4	main
sõidavad	doc_193540241570_item	2261681	et	3	main
воротился	doc_193540241570_item	2261695	et	2	main
старая	doc_193540241570_item	2261724	et	2	main
барскую	doc_193540241570_item	2261728	et	2	main
не	doc_193540241570_item	2261734	et	2	main
болван	doc_193540241570_item	2261738	et	2	main
засмеялся	doc_193540241570_item	2261740	et	2	main
я	doc_193540241570_item	2261746	et	2	main
дурные	doc_193540241570_item	2261749	et	2	main
что	doc_193540241570_item	2261752	et	2	main
мызу	doc_193540241570_item	2261761	et	2	main
для	doc_193540241570_item	2261765	et	2	main
семейство	doc_193540241570_item	2261769	et	2	main
мать	doc_193540241570_item	2261774	et	2	main
шестеро	doc_193540241570_item	2261776	et	2	main
отец	doc_193540241570_item	2261782	et	2	main
бочке	doc_193540241570_item	2261785	et	2	main
свечи	doc_193540241570_item	2261792	et	2	main
каждому	doc_193540241570_item	2261795	et	2	main
думал	doc_193540241570_item	2261800	et	2	main
люди	doc_193540241570_item	2261803	et	2	main
же	doc_193540241570_item	2261806	et	2	main
забьются	doc_193540241570_item	2261812	et	2	main
послушают	doc_193540241570_item	2261817	et	2	main
свою	doc_193540241570_item	2261820	et	2	main
таков	doc_193540241570_item	2261824	et	2	main
все	doc_193540241570_item	2261830	et	2	main
костлявая	doc_193540241570_item	2261835	et	2	main
ума	doc_193540241570_item	2261841	et	2	main
лезь	doc_193540241570_item	2261846	et	2	main
домовика	doc_193540241570_item	2261852	et	2	main
дрянь	doc_193540241570_item	2261857	et	2	main
да	doc_193540241570_item	2261862	et	2	main
ли	doc_193540241570_item	2261868	et	2	main
не	doc_193540241570_item	2261872	et	2	main
за	doc_193540241570_item	2261877	et	2	main
lugemise	doc_193540241570_item	2261882	et	4	main
eelteadmistega	doc_193540241570_item	2261888	et	3	main
rehepapp	doc_193540241570_item	2261890	et	3	main
kes	doc_193540241570_item	2261895	et	4	main
hingedekuu	doc_193540241570_item	2261909	et	4	main
lugejal	doc_193540241570_item	2261915	et	4	main
igaühele	doc_193540241570_item	2261595	et	3	main
järgemööda	doc_193540241570_item	2261596	et	3	main
viilaka	doc_193540241570_item	2261598	et	4	main
et	doc_193540241570_item	2261601	et	3	main
küünal	doc_193540241570_item	2261607	et	3	main
umbe	doc_193540241570_item	2261614	et	4	main
kratti	doc_193540241570_item	2261619	et	4	main
oma	doc_193540241570_item	2261622	et	4	main
jahu	doc_193540241570_item	2261623	et	4	main
et	doc_193540241570_item	2261629	et	3	main
ära	doc_193540241570_item	2261632	et	4	main
küünlasöömisest	doc_193540241570_item	2261635	et	4	main
ole	doc_193540241570_item	2261641	et	4	main
ikka	doc_193540241570_item	2261647	et	4	main
ära	doc_193540241570_item	2261649	et	4	main
tüki	doc_193540241570_item	2261650	et	4	main
kui	doc_193540241570_item	2261651	et	3	main
kratt	doc_193540241570_item	2261656	et	3	main
inimesed	doc_193540241570_item	2261668	et	3	main
usalda	doc_193540241570_item	2261670	et	4	main
et	doc_193540241570_item	2261672	et	3	main
teab	doc_193540241570_item	2261674	et	3	main
когда	doc_193540241570_item	2261693	et	2	main
домой	doc_193540241570_item	2261696	et	2	main
старый	doc_193540241570_item	2261697	et	2	main
ёзеп	doc_193540241570_item	2261699	et	2	main
домовик	doc_193540241570_item	2261698	et	2	main
предложил	doc_193540241570_item	2261700	et	2	main
ему	doc_193540241570_item	2261701	et	2	main
горячей	doc_193540241570_item	2261702	et	2	main
похлебки	doc_193540241570_item	2261703	et	2	main
ну	doc_193540241570_item	2261706	et	2	main
и	doc_193540241570_item	2261704	et	2	main
поинтересовался	doc_193540241570_item	2261705	et	2	main
что	doc_193540241570_item	2261707	et	2	main
батраком	doc_193540241570_item	2261710	et	2	main
с	doc_193540241570_item	2261709	et	2	main
небось	doc_193540241570_item	2261712	et	2	main
там	doc_193540241570_item	2261708	et	2	main
стряслось	doc_193540241570_item	2261711	et	2	main
кошмары	doc_193540241570_item	2261713	et	2	main
замучили	doc_193540241570_item	2261714	et	2	main
да	doc_193540241570_item	2261715	et	2	main
какие	doc_193540241570_item	2261716	et	2	main
кошмары	doc_193540241570_item	2261717	et	2	main
у	doc_193540241570_item	2261718	et	2	main
таракана	doc_193540241570_item	2261720	et	2	main
такого	doc_193540241570_item	2261719	et	2	main
рукой	doc_193540241570_item	2261722	et	2	main
чего	doc_193540241570_item	2261733	et	2	main
домовик	doc_193540241570_item	2261743	et	2	main
я	doc_193540241570_item	2261751	et	2	main
отправился	doc_193540241570_item	2261759	et	2	main
мукой	doc_193540241570_item	2261764	et	2	main
а	doc_193540241570_item	2261767	et	2	main
отец	doc_193540241570_item	2261773	et	2	main
ребят	doc_193540241570_item	2261777	et	2	main
ели	doc_193540241570_item	2261781	et	2	main
нож	doc_193540241570_item	2261786	et	2	main
руке	doc_193540241570_item	2261788	et	2	main
и	doc_193540241570_item	2261789	et	2	main
гуменщик	doc_193540241570_item	2261723	et	2	main
кладовую	doc_193540241570_item	2261729	et	2	main
нажрался	doc_193540241570_item	2261732	et	2	main
нажрался	doc_193540241570_item	2261737	et	2	main
беззубо	doc_193540241570_item	2261741	et	2	main
как	doc_193540241570_item	2261745	et	2	main
видал	doc_193540241570_item	2261750	et	2	main
бывает	doc_193540241570_item	2261754	et	2	main
вытворяют	doc_193540241570_item	2261755	et	2	main
тут	doc_193540241570_item	2261757	et	2	main
на	doc_193540241570_item	2261760	et	2	main
недавно	doc_193540241570_item	2261758	et	2	main
пшеничной	doc_193540241570_item	2261763	et	2	main
там	doc_193540241570_item	2261768	et	2	main
свечи	doc_193540241570_item	2261780	et	2	main
режет	doc_193540241570_item	2261790	et	2	main
сказать	doc_193540241570_item	2261801	et	2	main
добрые	doc_193540241570_item	2261804	et	2	main
закусывает	doc_193540241570_item	2261809	et	2	main
да	doc_193540241570_item	2261813	et	2	main
забрал	doc_193540241570_item	2261818	et	2	main
и	doc_193540241570_item	2261822	et	2	main
слух	doc_193540241570_item	2261827	et	2	main
эти	doc_193540241570_item	2261833	et	2	main
нет	doc_193540241570_item	2261838	et	2	main
не	doc_193540241570_item	2261845	et	2	main
сделай	doc_193540241570_item	2261850	et	2	main
он	doc_193540241570_item	2261854	et	2	main
дом	doc_193540241570_item	2261859	et	2	main
думают	doc_193540241570_item	2261866	et	2	main
догадается	doc_193540241570_item	2261873	et	2	main
добычей	doc_193540241570_item	2261878	et	2	main
pealkirja	doc_193540241570_item	2261881	et	4	main
hetkel	doc_193540241570_item	2261883	et	4	main
eesti	doc_193540241570_item	2261885	et	4	main
eesti	doc_193540241570_item	2261892	et	4	main
oma	doc_193540241570_item	2261897	et	4	main
välja	doc_193540241570_item	2261899	et	4	main
on	doc_193540241570_item	2261903	et	4	main
üks	doc_193540241570_item	2261906	et	3	main
kuid	doc_193540241570_item	2261908	et	4	main
ei	doc_193540241570_item	2261925	et	4	main
lugejale	doc_193540241570_item	2261927	et	4	main
kuju	doc_193540241570_item	2261929	et	4	main
tekstide	doc_193540241570_item	2261939	et	3	main
seetõttu	doc_193540241570_item	2261942	et	3	main
tegelaste	doc_193540241570_item	2261952	et	3	main
eesti	doc_193540241570_item	2261956	et	4	main
röövib	doc_193540241570_item	2261962	et	3	main
rikkust	doc_193540241570_item	2261965	et	3	main
on	doc_193540241570_item	2261968	et	4	main
pigem	doc_193540241570_item	2261970	et	3	main
ukraina	doc_193540241570_item	2261971	et	4	main
tegelane	doc_193540241570_item	2261975	et	3	main
vargustega	doc_193540241570_item	2261980	et	3	main
mässa	doc_193540241570_item	2261982	et	4	main
luupainaja	doc_193540241570_item	2261989	et	4	main
ka	doc_193540241570_item	2261991	et	3	main
vaevab	doc_193540241570_item	2261996	et	3	main
peale	doc_193540241570_item	2262007	et	4	main
viha	doc_193540241570_item	2262009	et	4	main
kannab	doc_193540241570_item	2262010	et	3	main
tõlge	doc_193540241570_item	2262015	et	3	main
õudset	doc_193540241570_item	2262022	et	3	main
tema	doc_193540241570_item	2262024	et	4	main
luupainaja	doc_193540241570_item	2262031	et	4	main
käis	doc_193540241570_item	2262032	et	4	main
sulast	doc_193540241570_item	2262036	et	4	main
piinas	doc_193540241570_item	2262039	et	4	main
sulane	doc_193540241570_item	2262043	et	4	main
ta	doc_193540241570_item	2262047	et	4	main
ei	doc_193540241570_item	2262058	et	4	main
võimaluse	doc_193540241570_item	2262063	et	3	main
rääkida	doc_193540241570_item	2262064	et	3	main
kujutab	doc_193540241570_item	2262069	et	3	main
luupainaja	doc_193540241570_item	2262109	et	4	main
sihukesel	doc_193540241570_item	2262110	et	4	main
käis	doc_193540241570_item	2262117	et	4	main
ja	doc_193540241570_item	2262121	et	3	main
seepi	doc_193540241570_item	2262128	et	4	main
tola	doc_193540241570_item	2262130	et	4	main
repliikide	doc_193540241570_item	2262132	et	3	main
toetub	doc_193540241570_item	2262134	et	3	main
tõttu	doc_193540241570_item	2262143	et	4	main
sisu	doc_193540241570_item	2262149	et	4	main
mis	doc_193540241570_item	2262151	et	4	main
sulasega	doc_193540241570_item	2262152	et	3	main
käis	doc_193540241570_item	2262154	et	4	main
vahendid	doc_193540241570_item	2262162	et	3	main
referents	doc_193540241570_item	2262165	et	4	main
ellips	doc_193540241570_item	2262173	et	3	main
kolmas	doc_193540241570_item	2262180	et	3	main
ei	doc_193540241570_item	2262183	et	4	main
хлеб	doc_193540241570_item	2261794	et	2	main
это	doc_193540241570_item	2261807	et	2	main
кишки	doc_193540241570_item	2261811	et	2	main
разве	doc_193540241570_item	2261814	et	2	main
я	doc_193540241570_item	2261819	et	2	main
муку	doc_193540241570_item	2261821	et	2	main
потом	doc_193540241570_item	2261826	et	2	main
прошел	doc_193540241570_item	2261828	et	2	main
через	doc_193540241570_item	2261832	et	2	main
неплохо	doc_193540241570_item	2261836	et	2	main
людей	doc_193540241570_item	2261840	et	2	main
говорю	doc_193540241570_item	2261844	et	2	main
не	doc_193540241570_item	2261848	et	2	main
пусть	doc_193540241570_item	2261853	et	2	main
в	doc_193540241570_item	2261858	et	2	main
не	doc_193540241570_item	2261864	et	2	main
какое	doc_193540241570_item	2261869	et	2	main
прихватить	doc_193540241570_item	2261874	et	2	main
tekib	doc_193540241570_item	2261884	et	3	main
seos	doc_193540241570_item	2261887	et	3	main
on	doc_193540241570_item	2261891	et	4	main
olukorrast	doc_193540241570_item	2261901	et	4	main
omapäraseim	doc_193540241570_item	2261907	et	4	main
seega	doc_193540241570_item	2261910	et	4	main
eesti	doc_193540241570_item	2261914	et	4	main
ettekujutust	doc_193540241570_item	2261916	et	4	main
romaanis	doc_193540241570_item	2261917	et	3	main
ole	doc_193540241570_item	2261926	et	4	main
ja	doc_193540241570_item	2261937	et	3	main
kratt	doc_193540241570_item	2261954	et	3	main
kokku	doc_193540241570_item	2261966	et	3	main
esiteks	doc_193540241570_item	2261969	et	3	main
kui	doc_193540241570_item	2261972	et	3	main
teiseks	doc_193540241570_item	2261976	et	4	main
ei	doc_193540241570_item	2261981	et	4	main
ise	doc_193540241570_item	2261987	et	4	main
on	doc_193540241570_item	2261990	et	4	main
liik	doc_193540241570_item	2261995	et	3	main
kelle	doc_193540241570_item	2262005	et	4	main
ta	doc_193540241570_item	2262008	et	4	main
кошмары	doc_193540241570_item	2262013	et	2	main
tähendab	doc_193540241570_item	2262016	et	3	main
nägi	doc_193540241570_item	2262021	et	3	main
unenägu	doc_193540241570_item	2262023	et	4	main
ei	doc_193540241570_item	2262025	et	4	main
tähendab	doc_193540241570_item	2262034	et	3	main
tõlke	doc_193540241570_item	2262056	et	4	main
kokku	doc_193540241570_item	2262060	et	3	main
lause	doc_193540241570_item	2262065	et	4	main
endast	doc_193540241570_item	2262070	et	4	main
eesmärk	doc_193540241570_item	2262078	et	3	main
lõi	doc_193540241570_item	2262112	et	4	main
vana	doc_193540241570_item	2262115	et	4	main
lugu	doc_193540241570_item	2262116	et	4	main
maiustamas	doc_193540241570_item	2262120	et	3	main
ajas	doc_193540241570_item	2262122	et	4	main
mida	doc_193540241570_item	2262124	et	4	main
poleks	doc_193540241570_item	2262125	et	3	main
vaja	doc_193540241570_item	2262126	et	4	main
vestluses	doc_193540241570_item	2262135	et	3	main
tuntud	doc_193540241570_item	2262137	et	4	main
ühistele	doc_193540241570_item	2262140	et	3	main
dialoogi	doc_193540241570_item	2262148	et	4	main
ja	doc_193540241570_item	2262157	et	3	main
rehepapp	doc_193540241570_item	2262171	et	3	main
ta	doc_193540241570_item	2262172	et	4	main
leksikaalsed	doc_193540241570_item	2262174	et	3	main
on	doc_193540241570_item	2262179	et	4	main
lange	doc_193540241570_item	2262184	et	4	main
kokku	doc_193540241570_item	2262187	et	3	main
isikus	doc_193540241570_item	2262190	et	3	main
tekstile	doc_193540241570_item	2262192	et	3	main
emotsionaalselt	doc_193540241570_item	2262201	et	4	main
leksikaalsete	doc_193540241570_item	2262234	et	3	main
домовик	doc_193540241570_item	2262253	et	2	main
ja	doc_193540241570_item	2262257	et	3	main
situatsioonile	doc_193540241570_item	2262261	et	3	main
ja	doc_193540241570_item	2262266	et	3	main
viidates	doc_193540241570_item	2262268	et	3	main
aeg	doc_193540241570_item	2262279	et	3	main
antud	doc_193540241570_item	2262280	et	4	main
был	doc_193540241570_item	2261823	et	2	main
померли	doc_193540241570_item	2261831	et	2	main
у	doc_193540241570_item	2261839	et	2	main
всегда	doc_193540241570_item	2261843	et	2	main
коли	doc_193540241570_item	2261847	et	2	main
себе	doc_193540241570_item	2261851	et	2	main
домовик	doc_193540241570_item	2261856	et	2	main
не	doc_193540241570_item	2261860	et	2	main
люди	doc_193540241570_item	2261863	et	2	main
мало	doc_193540241570_item	2261867	et	2	main
домовик	doc_193540241570_item	2261871	et	2	main
отправляются	doc_193540241570_item	2261876	et	2	main
rehepapist	doc_193540241570_item	2261889	et	4	main
muinasjuttude	doc_193540241570_item	2261893	et	4	main
tuleb	doc_193540241570_item	2261896	et	3	main
nutikusega	doc_193540241570_item	2261898	et	4	main
eesti	doc_193540241570_item	2261904	et	4	main
rahvakalendris	doc_193540241570_item	2261905	et	3	main
pealkiri	doc_193540241570_item	2261911	et	3	main
looma	doc_193540241570_item	2261913	et	4	main
toimuvast	doc_193540241570_item	2261918	et	4	main
vene	doc_193540241570_item	2261919	et	4	main
lugejal	doc_193540241570_item	2261920	et	4	main
eelteadmisi	doc_193540241570_item	2261922	et	3	main
tuttav	doc_193540241570_item	2261928	et	3	main
seostu	doc_193540241570_item	2261931	et	4	main
eesti	doc_193540241570_item	2261936	et	4	main
ootused	doc_193540241570_item	2261944	et	3	main
suhtes	doc_193540241570_item	2261946	et	4	main
tõlkega	doc_193540241570_item	2261953	et	3	main
on	doc_193540241570_item	2261955	et	4	main
mütoloogias	doc_193540241570_item	2261957	et	3	main
lendav	doc_193540241570_item	2261958	et	4	main
tegelane	doc_193540241570_item	2261960	et	3	main
ahnele	doc_193540241570_item	2261963	et	4	main
vene	doc_193540241570_item	2261973	et	4	main
ei	doc_193540241570_item	2261978	et	4	main
tegele	doc_193540241570_item	2261979	et	4	main
kodukäija	doc_193540241570_item	2261994	et	4	main
või	doc_193540241570_item	2262004	et	4	main
sulane	doc_193540241570_item	2262018	et	4	main
magas	doc_193540241570_item	2262019	et	4	main
füüsiliselt	doc_193540241570_item	2262027	et	4	main
kallal	doc_193540241570_item	2262033	et	4	main
vihane	doc_193540241570_item	2262040	et	4	main
vaim	doc_193540241570_item	2262041	et	3	main
vigastusi	doc_193540241570_item	2262046	et	4	main
sisu	doc_193540241570_item	2262057	et	4	main
lange	doc_193540241570_item	2262059	et	4	main
tõlke	doc_193540241570_item	2262066	et	4	main
ebaadekvaatsusest	doc_193540241570_item	2262067	et	4	main
rehepapi	doc_193540241570_item	2262072	et	4	main
informeerida	doc_193540241570_item	2262079	et	3	main
prussakal	doc_193540241570_item	2262111	et	3	main
käega	doc_193540241570_item	2262114	et	3	main
mõisa	doc_193540241570_item	2262118	et	3	main
olnud	doc_193540241570_item	2262127	et	4	main
sõi	doc_193540241570_item	2262129	et	3	main
osalejatele	doc_193540241570_item	2262136	et	4	main
situatsioonile	doc_193540241570_item	2262138	et	3	main
selle	doc_193540241570_item	2262142	et	4	main
juhtus	doc_193540241570_item	2262153	et	3	main
mõisas	doc_193540241570_item	2262155	et	3	main
sõi	doc_193540241570_item	2262158	et	3	main
teksti	doc_193540241570_item	2262160	et	4	main
tola	doc_193540241570_item	2262169	et	4	main
isik	doc_193540241570_item	2262181	et	3	main
kolmandas	doc_193540241570_item	2262189	et	3	main
võime	doc_193540241570_item	2262199	et	4	main
targaks	doc_193540241570_item	2262226	et	3	main
ja	doc_193540241570_item	2262227	et	3	main
räägib	doc_193540241570_item	2262233	et	3	main
suuga	doc_193540241570_item	2262241	et	3	main
joonistas	doc_193540241570_item	2262243	et	3	main
беззубо	doc_193540241570_item	2262251	et	2	main
беззубо	doc_193540241570_item	2262254	et	2	main
ja	doc_193540241570_item	2262259	et	3	main
гуменщик	doc_193540241570_item	2261924	et	2	main
temal	doc_193540241570_item	2261932	et	3	main
iseloomuomadustega	doc_193540241570_item	2261935	et	4	main
vene	doc_193540241570_item	2261938	et	4	main
lugejatel	doc_193540241570_item	2261940	et	4	main
kujunevad	doc_193540241570_item	2261941	et	4	main
erinevad	doc_193540241570_item	2261943	et	4	main
teksti	doc_193540241570_item	2261945	et	4	main
sama	doc_193540241570_item	2261947	et	4	main
probleem	doc_193540241570_item	2261948	et	3	main
ka	doc_193540241570_item	2261950	et	3	main
peremehele	doc_193540241570_item	2261964	et	3	main
домовик	doc_193540241570_item	2261967	et	2	main
peremees	doc_193540241570_item	2261983	et	4	main
saa	doc_193540241570_item	2261985	et	4	main
ja	doc_193540241570_item	2261997	et	3	main
ta	doc_193540241570_item	2261999	et	4	main
ainult	doc_193540241570_item	2262000	et	4	main
neid	doc_193540241570_item	2262001	et	4	main
peremehe	doc_193540241570_item	2262006	et	3	main
небось	doc_193540241570_item	2262012	et	2	main
замучили	doc_193540241570_item	2262014	et	2	main
et	doc_193540241570_item	2262017	et	3	main
teda	doc_193540241570_item	2261986	et	4	main
teha	doc_193540241570_item	2261988	et	3	main
mütoloogia	doc_193540241570_item	2261992	et	4	main
tegelane	doc_193540241570_item	2261993	et	3	main
piinab	doc_193540241570_item	2261998	et	3	main
kelle	doc_193540241570_item	2262002	et	4	main
peale	doc_193540241570_item	2262003	et	4	main
lause	doc_193540241570_item	2262011	et	4	main
ja	doc_193540241570_item	2262020	et	3	main
saanud	doc_193540241570_item	2262026	et	4	main
originaalis	doc_193540241570_item	2262029	et	3	main
lause	doc_193540241570_item	2262030	et	4	main
ründas	doc_193540241570_item	2262037	et	3	main
elukas	doc_193540241570_item	2262042	et	4	main
sai	doc_193540241570_item	2262044	et	4	main
all	doc_193540241570_item	2262051	et	3	main
ja	doc_193540241570_item	2262055	et	3	main
annab	doc_193540241570_item	2262062	et	3	main
tekstilõik	doc_193540241570_item	2262068	et	3	main
ja	doc_193540241570_item	2262073	et	3	main
vahel	doc_193540241570_item	2262075	et	4	main
tekstil	doc_193540241570_item	2262076	et	3	main
on	doc_193540241570_item	2262077	et	4	main
rehepapp	doc_193540241570_item	2262113	et	3	main
sahvris	doc_193540241570_item	2262119	et	3	main
sisse	doc_193540241570_item	2262123	et	4	main
vahetus	doc_193540241570_item	2262133	et	4	main
ja	doc_193540241570_item	2262139	et	3	main
teadmistele	doc_193540241570_item	2262141	et	4	main
nende	doc_193540241570_item	2262144	et	4	main
on	doc_193540241570_item	2262146	et	4	main
elliptiline	doc_193540241570_item	2262147	et	3	main
on	doc_193540241570_item	2262150	et	4	main
varastamas	doc_193540241570_item	2262156	et	3	main
on	doc_193540241570_item	2262163	et	4	main
prussakas	doc_193540241570_item	2262168	et	4	main
jutustaja	doc_193540241570_item	2262178	et	4	main
kes	doc_193540241570_item	2262182	et	4	main
jutustamine	doc_193540241570_item	2262188	et	4	main
annab	doc_193540241570_item	2262191	et	3	main
jutustaja	doc_193540241570_item	2262196	et	4	main
võetagi	doc_193540241570_item	2262221	et	3	main
inimeseks	doc_193540241570_item	2262229	et	3	main
kratti	doc_193540241570_item	2262232	et	4	main
valik	doc_193540241570_item	2262236	et	3	main
jutustaja	doc_193540241570_item	2262242	et	4	main
hea	doc_193540241570_item	2262245	et	4	main
ohutu	doc_193540241570_item	2262246	et	4	main
vaimu	doc_193540241570_item	2262247	et	4	main
pildi	doc_193540241570_item	2262248	et	4	main
старый	doc_193540241570_item	2262252	et	2	main
kus	doc_193540241570_item	2262262	et	3	main
naerab	doc_193540241570_item	2262264	et	3	main
iseloomule	doc_193540241570_item	2262270	et	3	main
ja	doc_193540241570_item	2262276	et	3	main
hetk	doc_193540241570_item	2262281	et	3	main
hiljutine	doc_193540241570_item	2262286	et	3	main
sahver	doc_193540241570_item	2262289	et	3	main
lugu	doc_193540241570_item	2262291	et	4	main
minevik	doc_193540241570_item	2262293	et	3	main
sisse	doc_193540241570_item	2262298	et	4	main
see	doc_193540241570_item	2262306	et	3	main
võis	doc_193540241570_item	2262307	et	4	main
iganes	doc_193540241570_item	2262310	et	4	main
jutustab	doc_193540241570_item	2262313	et	3	main
et	doc_193540241570_item	2262317	et	3	main
tegevuse	doc_193540241570_item	2262337	et	4	main
на	doc_193540241570_item	2262347	et	2	main
руке	doc_193540241570_item	2262351	et	2	main
каждому	doc_193540241570_item	2262358	et	2	main
очереди	doc_193540241570_item	2262362	et	2	main
vormiga	doc_193540241570_item	2262364	et	4	main
on	doc_193540241570_item	2262370	et	4	main
vastab	doc_193540241570_item	2262379	et	3	main
originaalile	doc_193540241570_item	2262380	et	3	main
teema	doc_193540241570_item	2262387	et	4	main
on	doc_193540241570_item	2262388	et	4	main
tingitud	doc_193540241570_item	2262392	et	4	main
on	doc_193540241570_item	2262428	et	4	main
vabastama	doc_193540241570_item	2262432	et	3	main
teine	doc_193540241570_item	2262439	et	3	main
vigastada	doc_193540241570_item	2262028	et	3	main
et	doc_193540241570_item	2262035	et	3	main
või	doc_193540241570_item	2262038	et	4	main
füüsilisi	doc_193540241570_item	2262045	et	3	main
kannatab	doc_193540241570_item	2262048	et	3	main
füüsilise	doc_193540241570_item	2262049	et	3	main
valu	doc_193540241570_item	2262050	et	4	main
selle	doc_193540241570_item	2262052	et	4	main
lause	doc_193540241570_item	2262053	et	4	main
originaali	doc_193540241570_item	2262054	et	4	main
mis	doc_193540241570_item	2262061	et	4	main
dialoogi	doc_193540241570_item	2262071	et	4	main
krati	doc_193540241570_item	2262074	et	4	main
lugejat	doc_193540241570_item	2262080	et	4	main
krattidesse	doc_193540241570_item	2262081	et	3	main
suhtumisest	doc_193540241570_item	2262082	et	4	main
ja	doc_193540241570_item	2262083	et	3	main
mõjutada	doc_193540241570_item	2262084	et	3	main
lugejat	doc_193540241570_item	2262085	et	4	main
emotsionaalselt	doc_193540241570_item	2262086	et	4	main
kratt	doc_193540241570_item	2262087	et	3	main
küsib	doc_193540241570_item	2262088	et	3	main
rehepapilt	doc_193540241570_item	2262089	et	4	main
informatsiooni	doc_193540241570_item	2262090	et	4	main
sulasega	doc_193540241570_item	2262091	et	3	main
juhtunust	doc_193540241570_item	2262092	et	4	main
algul	doc_193540241570_item	2262093	et	4	main
vestlus	doc_193540241570_item	2262094	et	3	main
käib	doc_193540241570_item	2262095	et	3	main
küsimuste-vastuste	doc_193540241570_item	2262096	et	4	main
vormis	doc_193540241570_item	2262097	et	4	main
noh	doc_193540241570_item	2262098	et	3	main
mis	doc_193540241570_item	2262099	et	4	main
sulasel	doc_193540241570_item	2262100	et	3	main
häda	doc_193540241570_item	2262101	et	4	main
oli	doc_193540241570_item	2262102	et	3	main
luupainaja	doc_193540241570_item	2262103	et	4	main
käis	doc_193540241570_item	2262104	et	4	main
kallal	doc_193540241570_item	2262105	et	4	main
või	doc_193540241570_item	2262106	et	4	main
ah	doc_193540241570_item	2262107	et	3	main
mis	doc_193540241570_item	2262108	et	4	main
selline	doc_193540241570_item	2262131	et	4	main
kõne	doc_193540241570_item	2262145	et	4	main
seepi	doc_193540241570_item	2262159	et	4	main
sidususe	doc_193540241570_item	2262161	et	4	main
siin	doc_193540241570_item	2262164	et	4	main
sulane	doc_193540241570_item	2262166	et	4	main
sihukene	doc_193540241570_item	2262167	et	3	main
selline	doc_193540241570_item	2262170	et	4	main
vahendid	doc_193540241570_item	2262175	et	3	main
kordused	doc_193540241570_item	2262176	et	3	main
loo	doc_193540241570_item	2262177	et	4	main
kõne	doc_193540241570_item	2262185	et	4	main
subjektiga	doc_193540241570_item	2262186	et	3	main
neutraalsuse	doc_193540241570_item	2262194	et	4	main
objektiivsuse	doc_193540241570_item	2262195	et	4	main
tegelastesse	doc_193540241570_item	2262198	et	3	main
järeldada	doc_193540241570_item	2262200	et	3	main
värvitud	doc_193540241570_item	2262202	et	4	main
fraasist	doc_193540241570_item	2262203	et	3	main
lõi	doc_193540241570_item	2262204	et	4	main
rehepapp	doc_193540241570_item	2262205	et	3	main
käega	doc_193540241570_item	2262206	et	3	main
mis	doc_193540241570_item	2262207	et	4	main
võib	doc_193540241570_item	2262208	et	3	main
tähistada	doc_193540241570_item	2262209	et	3	main
kahetsust	doc_193540241570_item	2262211	et	4	main
rehepapi	doc_193540241570_item	2262210	et	4	main
juhtunust	doc_193540241570_item	2262212	et	4	main
pettumust	doc_193540241570_item	2262213	et	4	main
sulase	doc_193540241570_item	2262214	et	3	main
arukuses	doc_193540241570_item	2262215	et	4	main
loobumist	doc_193540241570_item	2262216	et	4	main
nõuandmisest	doc_193540241570_item	2262217	et	3	main
kuna	doc_193540241570_item	2262218	et	3	main
ei	doc_193540241570_item	2262220	et	4	main
neid	doc_193540241570_item	2262219	et	4	main
peab	doc_193540241570_item	2262224	et	4	main
teatud	doc_193540241570_item	2262193	et	4	main
suhtumist	doc_193540241570_item	2262197	et	4	main
jutustaja	doc_193540241570_item	2262223	et	4	main
rehepappi	doc_193540241570_item	2262225	et	4	main
usaldusväärseks	doc_193540241570_item	2262228	et	4	main
suhtumisest	doc_193540241570_item	2262231	et	4	main
vana	doc_193540241570_item	2262238	et	4	main
kratt	doc_193540241570_item	2262239	et	3	main
hambutu	doc_193540241570_item	2262240	et	4	main
засмеялся	doc_193540241570_item	2262250	et	2	main
tähendada	doc_193540241570_item	2262256	et	3	main
беззлобно	doc_193540241570_item	2262258	et	2	main
kratt	doc_193540241570_item	2262263	et	3	main
dialoogi	doc_193540241570_item	2262278	et	4	main
sulase	doc_193540241570_item	2262284	et	3	main
minevik	doc_193540241570_item	2262287	et	3	main
mõis	doc_193540241570_item	2262294	et	3	main
juhatatud	doc_193540241570_item	2262299	et	4	main
umbmäärane	doc_193540241570_item	2262305	et	4	main
edasistest	doc_193540241570_item	2262311	et	4	main
tema	doc_193540241570_item	2262318	et	4	main
kandub	doc_193540241570_item	2262320	et	3	main
minevikku	doc_193540241570_item	2262321	et	4	main
ta	doc_193540241570_item	2262323	et	4	main
sõnaga	doc_193540241570_item	2262331	et	3	main
on	doc_193540241570_item	2262334	et	4	main
küünlasöömise	doc_193540241570_item	2262340	et	4	main
lugu	doc_193540241570_item	2262341	et	4	main
бочке	doc_193540241570_item	2262348	et	2	main
режет	doc_193540241570_item	2262353	et	2	main
свечи	doc_193540241570_item	2262355	et	2	main
кусок	doc_193540241570_item	2262360	et	2	main
saavutatakse	doc_193540241570_item	2262365	et	3	main
loo	doc_193540241570_item	2262375	et	4	main
kasutamine	doc_193540241570_item	2262383	et	4	main
valest	doc_193540241570_item	2262394	et	4	main
kratt	doc_193540241570_item	2262427	et	3	main
võimeline	doc_193540241570_item	2262429	et	4	main
kratti	doc_193540241570_item	2262450	et	4	main
kontrolltöö	doc_196962140767_item	2262453	et	4	main
tähendab	doc_196962140767_item	2262458	et	3	main
erikord	doc_196962140767_item	2262460	et	3	main
tegeles	doc_196962140767_item	2262463	et	3	main
ja	doc_196962140767_item	2262467	et	3	main
1	doc_196962140767_item	2262471	et	2	main
oli	doc_196962140767_item	2262479	et	3	main
õigussüsteem	doc_196962140767_item	2262491	et	3	main
vaimuelus	doc_196962140767_item	2262492	et	4	main
autonoomne	doc_196962140767_item	2262505	et	3	main
olukord	doc_196962140767_item	2262508	et	3	main
kui	doc_196962140767_item	2262512	et	3	main
omavalitsust	doc_196962140767_item	2262514	et	3	main
sisekubermangude	doc_196962140767_item	2262518	et	3	main
õpetatud	doc_196962140767_item	2262526	et	4	main
kuni	doc_196962140767_item	2262539	et	3	main
surmani	doc_196962140767_item	2262540	et	3	main
tegeles	doc_196962140767_item	2262542	et	3	main
keele	doc_196962140767_item	2262544	et	4	main
liikmed	doc_196962140767_item	2262553	et	3	main
selles	doc_196962140767_item	2262560	et	4	main
tööd	doc_196962140767_item	2262564	et	4	main
nn	doc_196962140767_item	2262568	et	4	main
kalevipoja	doc_196962140767_item	2262569	et	4	main
tegeles	doc_200257165102_item	2262602	et	3	main
langeb	doc_200257165102_item	2262612	et	3	main
euroopas	doc_200257165102_item	2262620	et	3	main
pärisorjus	doc_200257165102_item	2262629	et	3	main
taheti	doc_200257165102_item	2262632	et	3	main
mõisnike	doc_200257165102_item	2262638	et	3	main
talupoegade	doc_200257165102_item	2262640	et	3	main
linnades	doc_200257165102_item	2262645	et	3	main
ainult	doc_200257165102_item	2262647	et	4	main
ülejäänud	doc_200257165102_item	2262653	et	4	main
rahvas	doc_200257165102_item	2262654	et	4	main
ajal	doc_200257165102_item	2262659	et	4	main
pärast	doc_200257165102_item	2262665	et	4	main
põgenemine	doc_200257165102_item	2262673	et	4	main
pandi	doc_200257165102_item	2262679	et	4	main
inimeste	doc_200257165102_item	2262693	et	3	main
püüti	doc_200257165102_item	2262695	et	3	main
kuulda	doc_193540241570_item	2262222	et	4	main
jutustaja	doc_193540241570_item	2262230	et	4	main
vahendite	doc_193540241570_item	2262235	et	3	main
naeris	doc_193540241570_item	2262237	et	4	main
koduse	doc_193540241570_item	2262244	et	4	main
lauses	doc_193540241570_item	2262249	et	3	main
võib	doc_193540241570_item	2262255	et	3	main
vastandada	doc_193540241570_item	2262260	et	3	main
kurjalt	doc_193540241570_item	2262265	et	3	main
lahkelt	doc_193540241570_item	2262267	et	4	main
aja-	doc_193540241570_item	2262275	et	4	main
rehepapi	doc_193540241570_item	2262282	et	4	main
on	doc_193540241570_item	2262297	et	4	main
ükspäev	doc_193540241570_item	2262301	et	3	main
ajaliselt	doc_193540241570_item	2262303	et	4	main
juhtuda	doc_193540241570_item	2262308	et	3	main
ja	doc_193540241570_item	2262322	et	3	main
väljendatud	doc_193540241570_item	2262325	et	4	main
tegevusele	doc_193540241570_item	2262326	et	4	main
tõlkes	doc_193540241570_item	2262328	et	3	main
tegevus	doc_193540241570_item	2262329	et	4	main
millel	doc_193540241570_item	2262333	et	3	main
selgem	doc_193540241570_item	2262335	et	4	main
toimumise	doc_193540241570_item	2262338	et	4	main
tõlkes	doc_193540241570_item	2262343	et	3	main
сидит	doc_193540241570_item	2262346	et	2	main
в	doc_193540241570_item	2262350	et	2	main
хлеб	doc_193540241570_item	2262357	et	2	main
oleviku	doc_193540241570_item	2262363	et	3	main
lugeja	doc_193540241570_item	2262366	et	4	main
toimuvasse	doc_193540241570_item	2262368	et	4	main
kujutlev	doc_193540241570_item	2262371	et	4	main
mitte	doc_193540241570_item	2262373	et	3	main
sisuliselt	doc_193540241570_item	2262377	et	4	main
ja	doc_193540241570_item	2262381	et	3	main
mis	doc_193540241570_item	2262390	et	4	main
on	doc_193540241570_item	2262391	et	4	main
inimese	doc_193540241570_item	2262421	et	4	main
üle	doc_193540241570_item	2262423	et	3	main
et	doc_193540241570_item	2262426	et	3	main
inimest	doc_193540241570_item	2262430	et	3	main
varastamine	doc_193540241570_item	2262436	et	4	main
hoolde	doc_193540241570_item	2262438	et	4	main
teema	doc_193540241570_item	2262440	et	4	main
rumalus	doc_193540241570_item	2262443	et	4	main
teksti	doc_193540241570_item	2262444	et	4	main
pragmaatiline	doc_193540241570_item	2262445	et	3	main
on	doc_193540241570_item	2262447	et	4	main
usaldama	doc_193540241570_item	2262451	et	3	main
kultuuriloost	doc_196962140767_item	2262455	et	4	main
2	doc_196962140767_item	2262461	et	2	main
kes	doc_196962140767_item	2262468	et	4	main
kuulusid	doc_196962140767_item	2262470	et	4	main
baltisaksa	doc_196962140767_item	2262498	et	4	main
õnnestus	doc_196962140767_item	2262500	et	4	main
balti	doc_196962140767_item	2262503	et	3	main
omavalitsussüsteem	doc_196962140767_item	2262506	et	3	main
tähtsamaks	doc_196962140767_item	2262529	et	4	main
faehlmann	doc_196962140767_item	2262534	et	4	main
ja	doc_196962140767_item	2262548	et	3	main
selle	doc_196962140767_item	2262551	et	4	main
rahvuseepose	doc_196962140767_item	2262555	et	3	main
esimesed	doc_196962140767_item	2262557	et	3	main
tema	doc_196962140767_item	2262563	et	4	main
toimusid	doc_196962140767_item	2262567	et	4	main
õhtud	doc_196962140767_item	2262570	et	3	main
seltsi	doc_196962140767_item	2262573	et	4	main
ja	doc_200257165102_item	2262606	et	3	main
isanda	doc_200257165102_item	2262614	et	3	main
alla	doc_200257165102_item	2262616	et	3	main
pärisori	doc_200257165102_item	2262618	et	4	main
heitlikule	doc_193540241570_item	2262269	et	3	main
teksti	doc_193540241570_item	2262271	et	4	main
tegevus	doc_193540241570_item	2262272	et	4	main
toimub	doc_193540241570_item	2262273	et	3	main
mitmel	doc_193540241570_item	2262274	et	4	main
kohatasandil	doc_193540241570_item	2262277	et	3	main
lugu	doc_193540241570_item	2262285	et	4	main
küünlasöömise	doc_193540241570_item	2262295	et	4	main
lugu	doc_193540241570_item	2262296	et	4	main
mis	doc_193540241570_item	2262302	et	4	main
on	doc_193540241570_item	2262304	et	4	main
millal	doc_193540241570_item	2262309	et	3	main
sündmustest	doc_193540241570_item	2262312	et	4	main
kõneleja	doc_193540241570_item	2262314	et	4	main
tähendab	doc_193540241570_item	2262316	et	3	main
kujutlus	doc_193540241570_item	2262319	et	4	main
elab	doc_193540241570_item	2262324	et	3	main
ajaga	doc_193540241570_item	2262339	et	3	main
olevikus	doc_193540241570_item	2262344	et	3	main
нож	doc_193540241570_item	2262349	et	2	main
восковые	doc_193540241570_item	2262354	et	2	main
порядочный	doc_193540241570_item	2262359	et	2	main
kaasamist	doc_193540241570_item	2262367	et	4	main
oluline	doc_193540241570_item	2262369	et	4	main
toimuva	doc_193540241570_item	2262374	et	4	main
aeg	doc_193540241570_item	2262376	et	3	main
olevikuvormi	doc_193540241570_item	2262382	et	4	main
on	doc_193540241570_item	2262384	et	4	main
õigustatud	doc_193540241570_item	2262385	et	4	main
häda	doc_193540241570_item	2262389	et	4	main
neist	doc_193540241570_item	2262431	et	4	main
vaid	doc_193540241570_item	2262434	et	3	main
inimese	doc_193540241570_item	2262442	et	4	main
eesmärk	doc_193540241570_item	2262446	et	3	main
lugejat	doc_193540241570_item	2262449	et	4	main
1	doc_196962140767_item	2262456	et	2	main
õpetatud	doc_196962140767_item	2262464	et	4	main
selts	doc_196962140767_item	2262466	et	3	main
sinna	doc_196962140767_item	2262469	et	3	main
pärast	doc_196962140767_item	2262472	et	4	main
põhjasõda	doc_196962140767_item	2262473	et	4	main
eestis	doc_196962140767_item	2262474	et	3	main
saksakeelne	doc_196962140767_item	2262486	et	3	main
aadlil	doc_196962140767_item	2262499	et	3	main
erikord	doc_196962140767_item	2262504	et	3	main
säilis	doc_196962140767_item	2262509	et	4	main
aadli	doc_196962140767_item	2262513	et	3	main
vene	doc_196962140767_item	2262517	et	4	main
1838	doc_196962140767_item	2262521	et	2	main
oli	doc_196962140767_item	2262524	et	3	main
selts	doc_196962140767_item	2262541	et	3	main
säilitamisega	doc_196962140767_item	2262549	et	4	main
tegelesid	doc_196962140767_item	2262554	et	4	main
kirjutamisega	doc_196962140767_item	2262556	et	4	main
sammud	doc_196962140767_item	2262558	et	4	main
faehlmann	doc_196962140767_item	2262562	et	4	main
õe	doc_196962140767_item	2262572	et	4	main
tegelased	doc_196962140767_item	2262574	et	3	main
õpetatud	doc_200257165102_item	2262603	et	4	main
sinna	doc_200257165102_item	2262608	et	3	main
2	doc_200257165102_item	2262613	et	2	main
võimu	doc_200257165102_item	2262615	et	4	main
talupoeg	doc_200257165102_item	2262617	et	3	main
kuid	doc_200257165102_item	2262619	et	4	main
ja	doc_200257165102_item	2262627	et	3	main
kõik	doc_200257165102_item	2262633	et	4	main
omaks	doc_200257165102_item	2262639	et	4	main
suhtes	doc_200257165102_item	2262641	et	4	main
rootsiaja	doc_200257165102_item	2262643	et	3	main
10	doc_200257165102_item	2262648	et	2	main
on	doc_200257165102_item	2262651	et	4	main
talurahvas	doc_200257165102_item	2262657	et	4	main
talupojad	doc_200257165102_item	2262667	et	4	main
mõisnikele	doc_200257165102_item	2262668	et	3	main
kui	doc_200257165102_item	2262675	et	3	main
entsüklopeediat	doc_200257165102_item	2262689	et	3	main
sellega	doc_200257165102_item	2262690	et	3	main
vabastada	doc_200257165102_item	2262696	et	3	main
neid	doc_200257165102_item	2262697	et	4	main
dogmast	doc_200257165102_item	2262698	et	4	main
hiljem	doc_200257165102_item	2262701	et	3	main
tare	doc_193540241570_item	2262283	et	4	main
mõisa	doc_193540241570_item	2262288	et	3	main
küünlasöömise	doc_193540241570_item	2262290	et	4	main
kauge	doc_193540241570_item	2262292	et	4	main
sõnaga	doc_193540241570_item	2262300	et	3	main
lihtminevikus	doc_193540241570_item	2262315	et	3	main
kaasa	doc_193540241570_item	2262327	et	4	main
algab	doc_193540241570_item	2262330	et	3	main
недавно	doc_193540241570_item	2262332	et	2	main
seos	doc_193540241570_item	2262336	et	3	main
on	doc_193540241570_item	2262342	et	4	main
отец	doc_193540241570_item	2262345	et	2	main
и	doc_193540241570_item	2262352	et	2	main
словно	doc_193540241570_item	2262356	et	2	main
по	doc_193540241570_item	2262361	et	2	main
pilt	doc_193540241570_item	2262372	et	3	main
tõlketekst	doc_193540241570_item	2262378	et	3	main
teksti	doc_193540241570_item	2262386	et	4	main
inimese	doc_193540241570_item	2262393	et	4	main
käitumisest	doc_193540241570_item	2262395	et	4	main
tekstis	doc_193540241570_item	2262396	et	3	main
on	doc_193540241570_item	2262397	et	4	main
kaks	doc_193540241570_item	2262398	et	3	main
põhjus-tagajärg	doc_193540241570_item	2262399	et	3	main
struktuuriga	doc_193540241570_item	2262400	et	3	main
lugu	doc_193540241570_item	2262401	et	4	main
1	doc_193540241570_item	2262402	et	2	main
sulane	doc_193540241570_item	2262403	et	4	main
käis	doc_193540241570_item	2262404	et	4	main
mõisa	doc_193540241570_item	2262405	et	3	main
sahvris	doc_193540241570_item	2262406	et	3	main
maiustamas	doc_193540241570_item	2262407	et	3	main
piinleb	doc_193540241570_item	2262408	et	3	main
nüüd	doc_193540241570_item	2262409	et	4	main
kõhuvalus	doc_193540241570_item	2262410	et	4	main
2	doc_193540241570_item	2262411	et	2	main
pererahvas	doc_193540241570_item	2262412	et	4	main
käis	doc_193540241570_item	2262413	et	4	main
varastamas	doc_193540241570_item	2262414	et	3	main
sõi	doc_193540241570_item	2262415	et	3	main
küünlaid	doc_193540241570_item	2262416	et	3	main
ja	doc_193540241570_item	2262417	et	3	main
suri	doc_193540241570_item	2262418	et	3	main
kratt	doc_193540241570_item	2262419	et	3	main
arutleb	doc_193540241570_item	2262420	et	3	main
hädade	doc_193540241570_item	2262422	et	3	main
ja	doc_193540241570_item	2262424	et	3	main
tõdeb	doc_193540241570_item	2262425	et	3	main
tuleb	doc_193540241570_item	2262433	et	3	main
jätta	doc_193540241570_item	2262435	et	3	main
krattide	doc_193540241570_item	2262437	et	3	main
on	doc_193540241570_item	2262441	et	4	main
õpetada	doc_193540241570_item	2262448	et	3	main
kontrolltöö	doc_196962140767_item	2262452	et	4	main
eesti	doc_196962140767_item	2262454	et	4	main
balti	doc_196962140767_item	2262459	et	3	main
eesti	doc_196962140767_item	2262465	et	4	main
kubermangudeks	doc_196962140767_item	2262477	et	3	main
ajal	doc_196962140767_item	2262481	et	4	main
18	doc_196962140767_item	2262483	et	2	main
sajandil	doc_196962140767_item	2262484	et	3	main
asjaajamine	doc_196962140767_item	2262487	et	4	main
koht	doc_196962140767_item	2262494	et	3	main
oli	doc_196962140767_item	2262495	et	3	main
kirikul	doc_196962140767_item	2262497	et	3	main
oma	doc_196962140767_item	2262502	et	4	main
selline	doc_196962140767_item	2262507	et	4	main
korraldati	doc_196962140767_item	2262515	et	3	main
eeskujul	doc_196962140767_item	2262519	et	3	main
2	doc_196962140767_item	2262520	et	2	main
mida	doc_196962140767_item	2262457	et	4	main
millega	doc_196962140767_item	2262462	et	3	main
säilis	doc_196962140767_item	2262475	et	4	main
haldusjaotus	doc_196962140767_item	2262476	et	4	main
nagu	doc_196962140767_item	2262478	et	3	main
rootsi	doc_196962140767_item	2262480	et	4	main
samuti	doc_196962140767_item	2262482	et	3	main
säilis	doc_196962140767_item	2262485	et	4	main
oma	doc_196962140767_item	2262488	et	4	main
maksustuskord	doc_196962140767_item	2262489	et	4	main
ja	doc_196962140767_item	2262490	et	3	main
domineeriv	doc_196962140767_item	2262493	et	4	main
luteri	doc_196962140767_item	2262496	et	3	main
säilitada	doc_196962140767_item	2262501	et	3	main
1780	doc_196962140767_item	2262510	et	2	main
aastateni	doc_196962140767_item	2262511	et	3	main
ümber	doc_196962140767_item	2262516	et	3	main
aastal	doc_196962140767_item	2262522	et	3	main
eesti	doc_196962140767_item	2262527	et	4	main
sai	doc_196962140767_item	2262531	et	4	main
fr	doc_196962140767_item	2262532	et	4	main
r	doc_196962140767_item	2262533	et	4	main
kes	doc_196962140767_item	2262535	et	4	main
õli	doc_196962140767_item	2262536	et	4	main
ões	doc_196962140767_item	2262537	et	4	main
eesti	doc_196962140767_item	2262543	et	4	main
kirjanduse	doc_196962140767_item	2262546	et	3	main
arenemisega	doc_196962140767_item	2262547	et	4	main
samuti	doc_196962140767_item	2262550	et	3	main
lõpetas	doc_196962140767_item	2262565	et	3	main
samuti	doc_196962140767_item	2262571	et	3	main
2	doc_200257165102_item	2262600	et	2	main
selts	doc_200257165102_item	2262605	et	3	main
kes	doc_200257165102_item	2262607	et	4	main
kuulusid	doc_200257165102_item	2262609	et	4	main
1	doc_200257165102_item	2262610	et	2	main
talupoeg	doc_200257165102_item	2262611	et	3	main
venemaal	doc_200257165102_item	2262628	et	4	main
elab	doc_200257165102_item	2262646	et	3	main
inimestest	doc_200257165102_item	2262649	et	3	main
elab	doc_200257165102_item	2262655	et	3	main
maal	doc_200257165102_item	2262656	et	4	main
õigus	doc_200257165102_item	2262662	et	4	main
see	doc_200257165102_item	2262670	et	3	main
venemaale	doc_200257165102_item	2262674	et	4	main
leiti	doc_200257165102_item	2262676	et	3	main
põgeneja	doc_200257165102_item	2262677	et	4	main
talle	doc_200257165102_item	2262680	et	4	main
kehale	doc_200257165102_item	2262682	et	3	main
antakse	doc_200257165102_item	2262685	et	3	main
kujulise	doc_200257165102_item	2262688	et	4	main
aastat	doc_200257165102_item	2262700	et	3	main
jõuab	doc_200257165102_item	2262704	et	3	main
valgustusajastu	doc_200257165102_item	2262706	et	4	main
erikord	doc_200257165102_item	2262710	et	3	main
tartus	doc_196962140767_item	2262523	et	3	main
asutatud	doc_196962140767_item	2262525	et	4	main
selts	doc_196962140767_item	2262528	et	3	main
tegelaseks	doc_196962140767_item	2262530	et	3	main
esimeheks	doc_196962140767_item	2262538	et	3	main
ja	doc_196962140767_item	2262545	et	3	main
seltsi	doc_196962140767_item	2262552	et	4	main
tegi	doc_196962140767_item	2262559	et	4	main
suunas	doc_196962140767_item	2262561	et	4	main
kreutzwald	doc_196962140767_item	2262566	et	4	main
olid	doc_196962140767_item	2262575	et	4	main
eesti	doc_196962140767_item	2262577	et	4	main
ajaloost	doc_196962140767_item	2262578	et	4	main
huvitatud	doc_196962140767_item	2262576	et	4	main
sinna	doc_196962140767_item	2262579	et	3	main
kuulus	doc_196962140767_item	2262580	et	4	main
ka	doc_196962140767_item	2262581	et	3	main
jakob	doc_196962140767_item	2262582	et	4	main
hurt	doc_196962140767_item	2262583	et	3	main
ärkamisajal	doc_196962140767_item	2262584	et	3	main
edendas	doc_196962140767_item	2262585	et	3	main
õpetatud	doc_196962140767_item	2262586	et	4	main
eesti	doc_196962140767_item	2262587	et	4	main
selts	doc_196962140767_item	2262588	et	3	main
tähtsamat	doc_196962140767_item	2262589	et	4	main
rolli	doc_196962140767_item	2262590	et	4	main
kontrolltöö	doc_200257165102_item	2262591	et	4	main
kontrolltöö	doc_200257165102_item	2262592	et	4	main
eesti	doc_200257165102_item	2262593	et	4	main
kultuuriloost	doc_200257165102_item	2262594	et	4	main
1	doc_200257165102_item	2262595	et	2	main
mida	doc_200257165102_item	2262596	et	4	main
tähendab	doc_200257165102_item	2262597	et	3	main
balti	doc_200257165102_item	2262598	et	3	main
erikord	doc_200257165102_item	2262599	et	3	main
millega	doc_200257165102_item	2262601	et	3	main
eesti	doc_200257165102_item	2262604	et	4	main
see	doc_200257165102_item	2262622	et	3	main
pärast	doc_200257165102_item	2262624	et	4	main
teha	doc_200257165102_item	2262635	et	3	main
pärisorjadeks	doc_200257165102_item	2262636	et	3	main
sellel	doc_200257165102_item	2262658	et	4	main
kodukari	doc_200257165102_item	2262661	et	4	main
sellise	doc_200257165102_item	2262663	et	4	main
korra	doc_200257165102_item	2262664	et	4	main
vastu	doc_200257165102_item	2262669	et	3	main
oli	doc_200257165102_item	2262671	et	3	main
üles	doc_200257165102_item	2262678	et	3	main
1751	doc_200257165102_item	2262683	et	2	main
välja	doc_200257165102_item	2262686	et	4	main
taheti	doc_200257165102_item	2262691	et	3	main
100	doc_200257165102_item	2262699	et	2	main
eesti	doc_200257165102_item	2262712	et	4	main
kuna	doc_200257165102_item	2262714	et	3	main
eestisse	doc_200257165102_item	2262722	et	4	main
inimesed	doc_200257165102_item	2262725	et	3	main
ja	doc_200257165102_item	2262744	et	3	main
valgustusidee	doc_200257165102_item	2262746	et	4	main
enda	doc_200257165102_item	2262752	et	4	main
midagi	doc_200257165102_item	2262757	et	4	main
vabadust	doc_200257165102_item	2262763	et	4	main
valgustusajastu	doc_200257165102_item	2262764	et	4	main
ratsionalismi	doc_200257165102_item	2262765	et	4	main
alas	doc_200257165102_item	2262772	et	3	main
valgustatud	doc_200257165102_item	2262777	et	4	main
mees	doc_200257165102_item	2262791	et	4	main
balti	doc_200257165102_item	2262799	et	3	main
oma	doc_200257165102_item	2262804	et	4	main
tema	doc_200257165102_item	2262817	et	4	main
huvitas	doc_200257165102_item	2262834	et	3	main
mis	doc_200257165102_item	2262836	et	4	main
peamiselt	doc_200257165102_item	2262844	et	4	main
elust	doc_200257165102_item	2262861	et	3	main
elu	doc_200257165102_item	2262865	et	4	main
õpetatud	doc_200257165102_item	2262868	et	4	main
selts	doc_200257165102_item	2262870	et	3	main
1	doc_200257165103_item	2262879	et	2	main
tähendab	doc_200257165103_item	2262881	et	3	main
õpetatud	doc_200257165103_item	2262887	et	4	main
selts	doc_200257165103_item	2262889	et	3	main
kuulusid	doc_200257165103_item	2262893	et	4	main
erikord	doc_200257165103_item	2262896	et	3	main
kui	doc_200257165103_item	2262903	et	3	main
baltisakslaste	doc_200257165103_item	2262908	et	4	main
poolehoidu	doc_200257165103_item	2262910	et	4	main
pärast	doc_200257165103_item	2262911	et	4	main
jättis	doc_200257165103_item	2262913	et	3	main
liivimaal	doc_200257165103_item	2262917	et	4	main
senised	doc_200257165103_item	2262919	et	3	main
ja	doc_200257165103_item	2262921	et	3	main
venemaal	doc_200257165103_item	2262923	et	4	main
jõudsid	doc_200257165103_item	2262927	et	4	main
olid	doc_200257165103_item	2262933	et	4	main
kohaliku	doc_200257165103_item	2262934	et	3	main
võimu	doc_200257165103_item	2262935	et	4	main
asutati	doc_200257165103_item	2262939	et	4	main
kõrgem	doc_200257165103_item	2262947	et	4	main
kohus	doc_200257165103_item	2262948	et	4	main
riigi	doc_200257165103_item	2262952	et	3	main
luteri	doc_200257165103_item	2262978	et	3	main
põgeneva	doc_200257165103_item	2263000	et	4	main
balti	doc_200257165103_item	2263003	et	3	main
üks	doc_200257165103_item	2263008	et	3	main
külg	doc_200257165103_item	2263010	et	3	main
harimisel	doc_200257165103_item	2263018	et	4	main
õpetati	doc_200257165103_item	2263020	et	3	main
ainult	doc_200257165103_item	2263021	et	4	main
lugemise	doc_200257165103_item	2263023	et	4	main
ja	doc_200257165103_item	2263024	et	3	main
rehkendamise	doc_200257165103_item	2263025	et	4	main
säilimine	doc_200257165103_item	2263031	et	4	main
ning	doc_200257165103_item	2263032	et	3	main
assimileerimine	doc_200257165103_item	2263036	et	4	main
ajal	doc_200257165103_item	2263042	et	4	main
maakoolide	doc_200257165103_item	2263047	et	3	main
ligi	doc_200257165103_item	2263049	et	3	main
oli	doc_200257165102_item	2262621	et	3	main
kaotatud	doc_200257165102_item	2262623	et	4	main
põhjasõda	doc_200257165102_item	2262625	et	4	main
baltikumis	doc_200257165102_item	2262626	et	4	main
isegi	doc_200257165102_item	2262630	et	4	main
tugevnes	doc_200257165102_item	2262631	et	3	main
talupojad	doc_200257165102_item	2262634	et	4	main
ehk	doc_200257165102_item	2262637	et	3	main
kehtivad	doc_200257165102_item	2262642	et	4	main
seadused	doc_200257165102_item	2262644	et	3	main
need	doc_200257165102_item	2262650	et	3	main
maaaadlikud	doc_200257165102_item	2262652	et	3	main
ilmub	doc_200257165102_item	2262660	et	3	main
hakkavad	doc_200257165102_item	2262666	et	4	main
talupoegade	doc_200257165102_item	2262672	et	3	main
häbimärk	doc_200257165102_item	2262681	et	3	main
aastal	doc_200257165102_item	2262684	et	3	main
sõnaraamatu	doc_200257165102_item	2262687	et	4	main
süvendada	doc_200257165102_item	2262692	et	3	main
haridust	doc_200257165102_item	2262694	et	4	main
baltikumi	doc_200257165102_item	2262705	et	4	main
arvatakse	doc_200257165102_item	2262707	et	3	main
balti	doc_200257165102_item	2262709	et	3	main
suhtlesid	doc_200257165102_item	2262716	et	4	main
talupoegadega	doc_200257165102_item	2262717	et	3	main
emakeeles	doc_200257165102_item	2262719	et	4	main
1730-1740	doc_200257165102_item	2262720	et	2	main
nende	doc_200257165102_item	2262718	et	4	main
põhja-	doc_200257165102_item	2262731	et	4	main
kui	doc_200257165102_item	2262732	et	3	main
lõuna-eestisse	doc_200257165102_item	2262734	et	4	main
toimub	doc_200257165102_item	2262737	et	3	main
valgustusfilosoofiat	doc_200257165102_item	2262740	et	3	main
paremaks	doc_200257165102_item	2262754	et	4	main
tegema	doc_200257165102_item	2262758	et	3	main
eitasid	doc_200257165102_item	2262759	et	4	main
ratsionalism	doc_200257165102_item	2262768	et	3	main
haridusedga	doc_200257165102_item	2262782	et	4	main
teadmistega	doc_200257165102_item	2262784	et	4	main
sellelperioodil	doc_200257165102_item	2262786	et	4	main
herder	doc_200257165102_item	2262793	et	4	main
sünd	doc_200257165102_item	2262798	et	3	main
peeter	doc_200257165102_item	2262802	et	3	main
sellega	doc_200257165102_item	2262806	et	3	main
kui	doc_200257165102_item	2262702	et	3	main
euroopas	doc_200257165102_item	2262703	et	3	main
päästis	doc_200257165102_item	2262711	et	3	main
keelt	doc_200257165102_item	2262713	et	4	main
võrdsed	doc_200257165102_item	2262727	et	3	main
need	doc_200257165102_item	2262728	et	3	main
nii	doc_200257165102_item	2262730	et	3	main
ka	doc_200257165102_item	2262733	et	3	main
toetas	doc_200257165102_item	2262741	et	3	main
haridus	doc_200257165102_item	2262743	et	3	main
teadus	doc_200257165102_item	2262745	et	4	main
elu	doc_200257165102_item	2262753	et	4	main
peab	doc_200257165102_item	2262755	et	4	main
mõiste	doc_200257165102_item	2262766	et	4	main
toimub	doc_200257165102_item	2262773	et	3	main
arenemine	doc_200257165102_item	2262776	et	4	main
peaksid	doc_200257165102_item	2262779	et	4	main
maksimaalse	doc_200257165102_item	2262781	et	3	main
ja	doc_200257165102_item	2262783	et	3	main
inimesed	doc_200257165102_item	2262785	et	3	main
oli	doc_200257165102_item	2262787	et	3	main
säilis	doc_200257165102_item	2262801	et	4	main
ta	doc_200257165102_item	2262807	et	4	main
rahvaga	doc_200257165102_item	2262811	et	3	main
et	doc_200257165102_item	2262814	et	3	main
õpetatud	doc_200257165102_item	2262820	et	4	main
eesti	doc_200257165102_item	2262821	et	4	main
väga	doc_200257165102_item	2262828	et	3	main
tähtsate	doc_200257165102_item	2262829	et	3	main
küsimustega	doc_200257165102_item	2262830	et	4	main
oli	doc_200257165102_item	2262837	et	3	main
kultuur	doc_200257165102_item	2262840	et	3	main
kirjandus	doc_200257165102_item	2262841	et	3	main
huvitas	doc_200257165102_item	2262863	et	3	main
materiaalne	doc_200257165102_item	2262867	et	3	main
tartus	doc_200257165102_item	2262874	et	3	main
kes	doc_200257165103_item	2262891	et	4	main
i	doc_200257165103_item	2262902	et	4	main
otsustas	doc_200257165103_item	2262906	et	3	main
vallutamist	doc_200257165103_item	2262912	et	4	main
et	doc_200257165102_item	2262708	et	3	main
balti-sakslased	doc_200257165102_item	2262715	et	3	main
levisid	doc_200257165102_item	2262721	et	4	main
hernhuutlased	doc_200257165102_item	2262723	et	3	main
kõik	doc_200257165102_item	2262724	et	4	main
on	doc_200257165102_item	2262726	et	4	main
sellel	doc_200257165102_item	2262735	et	4	main
valgustus	doc_200257165102_item	2262738	et	4	main
levik	doc_200257165102_item	2262739	et	3	main
kunst	doc_200257165102_item	2262742	et	3	main
nõudsid	doc_200257165102_item	2262761	et	4	main
isikute	doc_200257165102_item	2262762	et	4	main
ilmub	doc_200257165102_item	2262767	et	3	main
saavutustele	doc_200257165102_item	2262770	et	4	main
loodusteaduste	doc_200257165102_item	2262771	et	3	main
teaduste	doc_200257165102_item	2262774	et	3	main
monarhia	doc_200257165102_item	2262778	et	4	main
olema	doc_200257165102_item	2262780	et	4	main
euroopas	doc_200257165102_item	2262788	et	3	main
tuntud	doc_200257165102_item	2262790	et	4	main
j	doc_200257165102_item	2262792	et	4	main
kelle	doc_200257165102_item	2262794	et	4	main
tegevusele	doc_200257165102_item	2262795	et	4	main
järgnes	doc_200257165102_item	2262796	et	3	main
kasuks	doc_200257165102_item	2262805	et	4	main
tahtis	doc_200257165102_item	2262808	et	3	main
baltikumi	doc_200257165102_item	2262810	et	4	main
ehk	doc_200257165102_item	2262812	et	3	main
oleksid	doc_200257165102_item	2262816	et	4	main
pool	doc_200257165102_item	2262818	et	4	main
2	doc_200257165102_item	2262819	et	2	main
tegeles	doc_200257165102_item	2262824	et	3	main
eestis	doc_200257165102_item	2262825	et	3	main
probleemidega	doc_200257165102_item	2262832	et	3	main
seotud	doc_200257165102_item	2262838	et	4	main
elu-ja	doc_200257165102_item	2262846	et	3	main
õpetatud	doc_200257165102_item	2262848	et	4	main
eesti	doc_200257165102_item	2262849	et	4	main
eesti	doc_200257165103_item	2262877	et	4	main
kultuuriloost	doc_200257165103_item	2262878	et	4	main
erikord	doc_200257165103_item	2262883	et	3	main
millega	doc_200257165103_item	2262885	et	3	main
sinna	doc_200257165103_item	2262892	et	3	main
1	doc_200257165103_item	2262894	et	2	main
juurdus	doc_200257165103_item	2262897	et	3	main
eestimaal	doc_200257165103_item	2262898	et	4	main
pärast	doc_200257165103_item	2262899	et	4	main
peeter	doc_200257165103_item	2262901	et	3	main
kaval	doc_200257165103_item	2262904	et	4	main
saavutada	doc_200257165103_item	2262907	et	3	main
seas	doc_200257165103_item	2262909	et	4	main
ta	doc_200257165103_item	2262914	et	4	main
ja	doc_200257165103_item	2262916	et	3	main
liivi	doc_200257165103_item	2262928	et	4	main
poolt	doc_200257165103_item	2262936	et	4	main
registreeritud	doc_200257165103_item	2262937	et	4	main
peterbusis	doc_200257165103_item	2262938	et	4	main
eestimaa	doc_200257165103_item	2262941	et	4	main
liivimaa	doc_200257165103_item	2262943	et	4	main
institutsioonidest	doc_200257165103_item	2262953	et	3	main
kohad	doc_200257165103_item	2262955	et	4	main
eesti-	doc_200257165103_item	2262959	et	4	main
keel	doc_200257165103_item	2262981	et	4	main
ja	doc_200257165103_item	2262986	et	3	main
kui	doc_200257165103_item	2262988	et	3	main
ja	doc_200257165103_item	2262995	et	3	main
venemaa	doc_200257165103_item	2262997	et	4	main
vahel	doc_200257165103_item	2262998	et	4	main
tollipiirid	doc_200257165103_item	2262999	et	3	main
positiivne	doc_200257165103_item	2263009	et	3	main
mõisniku	doc_200257165103_item	2263014	et	3	main
vastupanule	doc_200257165103_item	2263016	et	3	main
elementaarset	doc_200257165103_item	2263022	et	3	main
algteadmisi	doc_200257165103_item	2263026	et	3	main
oli	doc_200257165103_item	2263033	et	3	main
põlisrahva	doc_200257165103_item	2263035	et	3	main
talurahva	doc_200257165103_item	2263046	et	3	main
¾	doc_200257165103_item	2263050	et	2	main
elanikes	doc_200257165103_item	2263053	et	3	main
oli	doc_200257165103_item	2263060	et	3	main
üldse	doc_200257165103_item	2263063	et	3	main
jõudsid	doc_200257165102_item	2262729	et	4	main
perioodil	doc_200257165102_item	2262736	et	3	main
kritiseeris	doc_200257165102_item	2262747	et	3	main
feodaalkorda	doc_200257165102_item	2262748	et	4	main
ja	doc_200257165102_item	2262749	et	3	main
kirikut	doc_200257165102_item	2262750	et	3	main
inimese	doc_200257165102_item	2262751	et	4	main
ise	doc_200257165102_item	2262756	et	4	main
pärisorjust	doc_200257165102_item	2262760	et	3	main
tugines	doc_200257165102_item	2262769	et	3	main
edasi	doc_200257165102_item	2262775	et	3	main
väga	doc_200257165102_item	2262789	et	3	main
rahvaluule	doc_200257165102_item	2262797	et	4	main
erikorda	doc_200257165102_item	2262800	et	4	main
i	doc_200257165102_item	2262803	et	4	main
läheneda	doc_200257165102_item	2262809	et	3	main
tahtis	doc_200257165102_item	2262813	et	3	main
nad	doc_200257165102_item	2262815	et	3	main
jaoks	doc_200257165102_item	2262827	et	4	main
ões-it	doc_200257165102_item	2262833	et	4	main
kõik	doc_200257165102_item	2262835	et	4	main
eestirahvaga	doc_200257165102_item	2262839	et	3	main
haridus	doc_200257165102_item	2262842	et	3	main
tegeles	doc_200257165102_item	2262845	et	3	main
kultuurilooga	doc_200257165102_item	2262847	et	4	main
asutas	doc_200257165102_item	2262851	et	3	main
hurt	doc_200257165102_item	2262852	et	3	main
teda	doc_200257165102_item	2262862	et	4	main
vaimulik	doc_200257165102_item	2262864	et	3	main
mitte	doc_200257165102_item	2262866	et	3	main
oli	doc_200257165102_item	2262871	et	3	main
1838a	doc_200257165102_item	2262873	et	4	main
kontrolltöö	doc_200257165103_item	2262876	et	4	main
mida	doc_200257165103_item	2262880	et	4	main
balti	doc_200257165103_item	2262882	et	3	main
2	doc_200257165103_item	2262884	et	2	main
tegeles	doc_200257165103_item	2262886	et	3	main
ja	doc_200257165103_item	2262890	et	3	main
põhjasõda	doc_200257165103_item	2262900	et	4	main
strotug	doc_200257165103_item	2262905	et	4	main
eestimaal	doc_200257165103_item	2262915	et	4	main
vastu	doc_200257165103_item	2262924	et	3	main
kui	doc_200257165103_item	2262932	et	3	main
isegi	doc_200257165103_item	2262940	et	4	main
ja	doc_200257165103_item	2262942	et	3	main
asjade	doc_200257165103_item	2262944	et	3	main
pististikolleegium	doc_200257165103_item	2262945	et	4	main
ning	doc_200257165103_item	2262946	et	3	main
venemaa	doc_200257165103_item	2262950	et	4	main
ja	doc_200257165103_item	2262960	et	3	main
saj	doc_200257165103_item	2262990	et	4	main
lõpuni	doc_200257165103_item	2262991	et	3	main
kubermangude	doc_200257165103_item	2262994	et	3	main
talupoegade	doc_200257165103_item	2263001	et	3	main
ägedale	doc_200257165103_item	2263015	et	3	main
välditud	doc_200257165103_item	2263034	et	4	main
panus	doc_200257165103_item	2263045	et	4	main
eesti	doc_200257165103_item	2263051	et	4	main
venemaal	doc_200257165103_item	2263062	et	4	main
võib	doc_200257165103_item	2263064	et	3	main
ka	doc_200257165103_item	2263066	et	3	main
et	doc_200257165103_item	2263068	et	3	main
erikorra	doc_200257165103_item	2263070	et	3	main
20	doc_200257165103_item	2263097	et	2	main
2	doc_200257165103_item	2263101	et	2	main
robert	doc_200257165103_item	2263103	et	4	main
selts	doc_200257165103_item	2263112	et	3	main
soost	doc_200257165103_item	2263117	et	4	main
sinna	doc_200257165103_item	2263120	et	3	main
õpetlased	doc_200257165103_item	2263122	et	3	main
rahva	doc_200257165103_item	2263127	et	3	main
ja	doc_200257165103_item	2263129	et	3	main
suulist	doc_200257165103_item	2263130	et	4	main
kogumisse	doc_200257165103_item	2263134	et	4	main
suure	doc_200257165103_item	2263136	et	3	main
ka	doc_200257165103_item	2263138	et	3	main
fr	doc_200257165103_item	2263147	et	4	main
päevik	doc_213943984903_item	2263160	et	3	main
ärkasin	doc_213943984903_item	2263164	et	3	main
berliinis	doc_213943984903_item	2263171	et	4	main
kuum	doc_213943984903_item	2263181	et	3	main
üheksa	doc_213943984903_item	2263192	et	4	main
lendasis	doc_213943984903_item	2263196	et	4	main
välja	doc_213943984903_item	2263197	et	4	main
täna	doc_213943984903_item	2263226	et	4	main
olnud	doc_213943984903_item	2263229	et	4	main
olen	doc_213943984903_item	2263235	et	3	main
selts	doc_200257165102_item	2262822	et	3	main
ões	doc_200257165102_item	2262823	et	4	main
eestirahva	doc_200257165102_item	2262826	et	3	main
ja	doc_200257165102_item	2262831	et	3	main
kuid	doc_200257165102_item	2262843	et	4	main
seltsi	doc_200257165102_item	2262850	et	4	main
kes	doc_200257165102_item	2262853	et	4	main
oli	doc_200257165102_item	2262854	et	3	main
vilets	doc_200257165102_item	2262855	et	3	main
poliitik	doc_200257165102_item	2262856	et	3	main
kuid	doc_200257165102_item	2262857	et	4	main
taibas	doc_200257165102_item	2262858	et	4	main
palju	doc_200257165102_item	2262859	et	4	main
rahva	doc_200257165102_item	2262860	et	3	main
eesti	doc_200257165102_item	2262869	et	4	main
asutatud	doc_200257165102_item	2262872	et	4	main
kontrolltöö	doc_200257165103_item	2262875	et	4	main
eesti	doc_200257165103_item	2262888	et	4	main
balti	doc_200257165103_item	2262895	et	3	main
kehtima	doc_200257165103_item	2262918	et	3	main
seadused	doc_200257165103_item	2262920	et	3	main
seadused	doc_200257165103_item	2262926	et	3	main
ja	doc_200257165103_item	2262929	et	3	main
üksnes	doc_200257165103_item	2262931	et	3	main
kubermanguvalimise	doc_200257165103_item	2262954	et	3	main
täideti	doc_200257165103_item	2262956	et	3	main
baltisaksasoost	doc_200257165103_item	2262957	et	4	main
ametnikega	doc_200257165103_item	2262958	et	3	main
liivimaa	doc_200257165103_item	2262961	et	4	main
saksa	doc_200257165103_item	2262980	et	4	main
jäi	doc_200257165103_item	2262982	et	3	main
kohaliku	doc_200257165103_item	2262983	et	3	main
asjaajamis-	doc_200257165103_item	2262984	et	4	main
18	doc_200257165103_item	2262989	et	2	main
kehtisid	doc_200257165103_item	2262992	et	4	main
oli	doc_200257165103_item	2263005	et	3	main
ka	doc_200257165103_item	2263007	et	3	main
nimelt	doc_200257165103_item	2263011	et	4	main
tänu	doc_200257165103_item	2263012	et	4	main
põlisrahva	doc_200257165103_item	2263017	et	3	main
suunas	doc_200257165103_item	2263019	et	4	main
maksud	doc_200257165103_item	2262922	et	3	main
võetud	doc_200257165103_item	2262925	et	4	main
eestimaale	doc_200257165103_item	2262930	et	4	main
eraldi	doc_200257165103_item	2262949	et	4	main
enda	doc_200257165103_item	2262951	et	4	main
oli	doc_200257165103_item	2262962	et	3	main
vene	doc_200257165103_item	2262963	et	4	main
riigi	doc_200257165103_item	2262964	et	3	main
koosseisus	doc_200257165103_item	2262965	et	4	main
kuid	doc_200257165103_item	2262966	et	4	main
sisuliselt	doc_200257165103_item	2262967	et	4	main
need	doc_200257165103_item	2262969	et	3	main
kubermangud	doc_200257165103_item	2262970	et	3	main
baltisakslase	doc_200257165103_item	2262971	et	3	main
eksisteerisid	doc_200257165103_item	2262968	et	4	main
valiseva	doc_200257165103_item	2262972	et	4	main
ikke	doc_200257165103_item	2262973	et	3	main
all	doc_200257165103_item	2262974	et	3	main
endiselt	doc_200257165103_item	2262975	et	4	main
jäi	doc_200257165103_item	2262976	et	3	main
valitsevaks	doc_200257165103_item	2262977	et	4	main
usk	doc_200257165103_item	2262979	et	3	main
haridus-	doc_200257165103_item	2262985	et	3	main
kohtukeeleks	doc_200257165103_item	2262987	et	4	main
balti	doc_200257165103_item	2262993	et	3	main
ülejäänud	doc_200257165103_item	2262996	et	4	main
tabamiseks	doc_200257165103_item	2263002	et	4	main
erikorrale	doc_200257165103_item	2263004	et	3	main
iseloomulik	doc_200257165103_item	2263006	et	3	main
baltisaksa	doc_200257165103_item	2263013	et	4	main
sai	doc_200257165103_item	2263027	et	4	main
eesti	doc_200257165103_item	2263029	et	4	main
saksastumine	doc_200257165103_item	2263037	et	4	main
venestumine	doc_200257165103_item	2263039	et	4	main
erikorra	doc_200257165103_item	2263041	et	3	main
eesti	doc_200257165103_item	2263056	et	4	main
kubermangu	doc_200257165103_item	2263057	et	4	main
esimese	doc_200257165103_item	2263099	et	3	main
friedrich	doc_200257165103_item	2263102	et	4	main
faehmann	doc_200257165103_item	2263104	et	4	main
üks	doc_200257165103_item	2263106	et	3	main
õpetatud	doc_200257165103_item	2263107	et	4	main
küll	doc_200257165103_item	2263114	et	4	main
saksa	doc_200257165103_item	2263116	et	4	main
ent	doc_200257165103_item	2263119	et	3	main
kuulunud	doc_200257165103_item	2263121	et	4	main
hakkasid	doc_200257165103_item	2263123	et	4	main
uurima	doc_200257165103_item	2263124	et	3	main
eesti	doc_200257165103_item	2263125	et	4	main
minevikku	doc_200257165103_item	2263128	et	4	main
1857	doc_200257165103_item	2263142	et	2	main
kirjutanud	doc_200257165103_item	2263146	et	4	main
ões	doc_200257165103_item	2263149	et	4	main
avalik	doc_200257165103_item	2263152	et	3	main
mis	doc_200257165103_item	2263154	et	4	main
tegelema	doc_200257165103_item	2263156	et	3	main
täna	doc_213943984903_item	2263162	et	4	main
ma	doc_213943984903_item	2263167	et	3	main
emaga	doc_213943984903_item	2263170	et	3	main
me	doc_213943984903_item	2263173	et	4	main
oli	doc_213943984903_item	2263179	et	3	main
ja	doc_213943984903_item	2263185	et	3	main
kell	doc_213943984903_item	2263191	et	3	main
kesklinnas	doc_213943984903_item	2263230	et	4	main
eesti	doc_213943984905_item	2263350	et	4	main
jagas	doc_213943984905_item	2263358	et	3	main
toa	doc_213943984905_item	2263359	et	3	main
tingimustes	doc_213943984905_item	2263364	et	3	main
toimetas	doc_213943984905_item	2263376	et	3	main
oli	doc_213943984905_item	2263390	et	3	main
ja	doc_213943984905_item	2263392	et	3	main
põõsed	doc_213943984905_item	2263427	et	4	main
kuigi	doc_213943984905_item	2263433	et	3	main
kosmeetikat	doc_213943984905_item	2263438	et	3	main
paistis	doc_213943984905_item	2263444	et	3	main
pidas	doc_213943984905_item	2263453	et	3	main
ja	doc_213943984905_item	2263463	et	3	main
mõtles	doc_213943984905_item	2263468	et	3	main
seitse	doc_213943984905_item	2263478	et	3	main
ja	doc_213943984905_item	2263480	et	3	main
kuid	doc_213943984905_item	2263487	et	4	main
sümpaatne	doc_213943984905_item	2263496	et	3	main
juba	doc_213943984905_item	2263502	et	3	main
kinkis	doc_213943984905_item	2263505	et	3	main
sõrmust	doc_213943984905_item	2263511	et	3	main
kingitus	doc_213943984905_item	2263514	et	4	main
andnud	doc_213943984905_item	2263516	et	4	main
võrreldagi	doc_213943984905_item	2263517	et	4	main
võimalikuks	doc_200257165103_item	2263028	et	3	main
kultuuri	doc_200257165103_item	2263030	et	4	main
või	doc_200257165103_item	2263038	et	4	main
balti	doc_200257165103_item	2263040	et	3	main
tehti	doc_200257165103_item	2263043	et	3	main
suur	doc_200257165103_item	2263044	et	3	main
rajamiseks	doc_200257165103_item	2263048	et	4	main
lugeda	doc_200257165103_item	2263055	et	3	main
sellinne	doc_200257165103_item	2263058	et	4	main
näit	doc_200257165103_item	2263059	et	3	main
täheldada	doc_200257165103_item	2263065	et	3	main
seda	doc_200257165103_item	2263067	et	3	main
ei	doc_200257165103_item	2263072	et	4	main
eesti	doc_200257165103_item	2263074	et	4	main
mehed	doc_200257165103_item	2263075	et	3	main
vene	doc_200257165103_item	2263076	et	4	main
armeesse	doc_200257165103_item	2263077	et	4	main
nekrutisse	doc_200257165103_item	2263078	et	3	main
minema	doc_200257165103_item	2263079	et	3	main
võib	doc_200257165103_item	2263080	et	3	main
julgelt	doc_200257165103_item	2263081	et	4	main
öelda	doc_200257165103_item	2263082	et	4	main
et	doc_200257165103_item	2263083	et	3	main
põhjasõja-järgsel	doc_200257165103_item	2263084	et	3	main
perioodil	doc_200257165103_item	2263085	et	3	main
saadik	doc_200257165103_item	2263086	et	4	main
juurdunud	doc_200257165103_item	2263087	et	4	main
balti	doc_200257165103_item	2263088	et	3	main
erikord	doc_200257165103_item	2263089	et	3	main
kehtis	doc_200257165103_item	2263090	et	3	main
väheste	doc_200257165103_item	2263091	et	3	main
väiksemal	doc_200257165103_item	2263092	et	4	main
või	doc_200257165103_item	2263093	et	4	main
suuremal	doc_200257165103_item	2263094	et	4	main
kubermangu	doc_200257165103_item	2263052	et	4	main
oskas	doc_200257165103_item	2263054	et	3	main
kõrgeim	doc_200257165103_item	2263061	et	4	main
algusaastatel	doc_200257165103_item	2263071	et	4	main
pidanud	doc_200257165103_item	2263073	et	4	main
kuni	doc_200257165103_item	2263096	et	3	main
1838	doc_200257165103_item	2263111	et	2	main
pärimust	doc_200257165103_item	2263131	et	4	main
pani	doc_200257165103_item	2263135	et	4	main
panuse	doc_200257165103_item	2263137	et	3	main
ões	doc_200257165103_item	2263139	et	4	main
1861	doc_200257165103_item	2263143	et	2	main
kreutzwald	doc_200257165103_item	2263148	et	4	main
rahvaloo	doc_200257165103_item	2263158	et	4	main
uurimisega	doc_200257165103_item	2263159	et	4	main
25072006	doc_213943984903_item	2263161	et	2	main
kell	doc_213943984903_item	2263165	et	3	main
minu	doc_213943984903_item	2263169	et	3	main
kuna	doc_213943984903_item	2263172	et	3	main
lendasime	doc_213943984903_item	2263174	et	3	main
tallinnasse	doc_213943984903_item	2263176	et	3	main
ilm	doc_213943984903_item	2263178	et	3	main
linnud	doc_213943984903_item	2263183	et	3	main
päike	doc_213943984903_item	2263186	et	3	main
sõitsime	doc_213943984903_item	2263189	et	3	main
meie	doc_213943984903_item	2263194	et	4	main
lennuk	doc_213943984903_item	2263195	et	3	main
balti	doc_200257165103_item	2263069	et	3	main
muutustega	doc_200257165103_item	2263095	et	4	main
saj	doc_200257165103_item	2263098	et	4	main
koondas	doc_200257165103_item	2263113	et	3	main
estofiile	doc_200257165103_item	2263118	et	4	main
pooleni	doc_200257165103_item	2263100	et	3	main
oli	doc_200257165103_item	2263105	et	3	main
eesti	doc_200257165103_item	2263108	et	4	main
seltsi	doc_200257165103_item	2263109	et	4	main
rajajatest	doc_200257165103_item	2263110	et	4	main
peamiselt	doc_200257165103_item	2263115	et	4	main
tegutsenud	doc_200257165103_item	2263141	et	4	main
kalevipoega	doc_200257165103_item	2263145	et	4	main
eesti	doc_200257165103_item	2263157	et	4	main
laulsid	doc_213943984903_item	2263184	et	4	main
me	doc_213943984903_item	2263188	et	4	main
ja	doc_213943984903_item	2263193	et	3	main
academic	doc_213943984903_item	2263222	et	4	main
me	doc_213943984903_item	2263227	et	4	main
poes	doc_213943984903_item	2263233	et	3	main
uinuv	doc_213943984905_item	2263341	et	4	main
elas	doc_213943984905_item	2263343	et	3	main
mustamäel	doc_213943984905_item	2263345	et	3	main
perenaine	doc_213943984905_item	2263353	et	3	main
ja	doc_213943984905_item	2263354	et	3	main
vanaemaga	doc_213943984905_item	2263361	et	3	main
korteris	doc_213943984905_item	2263366	et	3	main
köögiga	doc_213943984905_item	2263368	et	3	main
neiu	doc_213943984905_item	2263370	et	4	main
käisid	doc_213943984905_item	2263372	et	4	main
tehases	doc_213943984905_item	2263373	et	3	main
tööl	doc_213943984905_item	2263374	et	3	main
ja	doc_213943984905_item	2263378	et	3	main
ise	doc_213943984905_item	2263380	et	4	main
koolis	doc_213943984905_item	2263383	et	4	main
nende	doc_213943984905_item	2263386	et	4	main
kõrval	doc_213943984905_item	2263388	et	4	main
kõik	doc_213943984905_item	2263389	et	4	main
pikad	doc_213943984905_item	2263421	et	4	main
lokis	doc_213943984905_item	2263423	et	3	main
anna	doc_213943984905_item	2263428	et	4	main
oli	doc_213943984905_item	2263430	et	3	main
tütarlaps	doc_213943984905_item	2263432	et	4	main
ta	doc_213943984905_item	2263434	et	4	main
kasutanud	doc_213943984905_item	2263436	et	4	main
silma	doc_213943984905_item	2263445	et	4	main
päeval	doc_213943984905_item	2263452	et	3	main
võin	doc_213943984905_item	2263464	et	3	main
tantsimas	doc_213943984905_item	2263466	et	3	main
neiu	doc_213943984905_item	2263469	et	4	main
sünnipäevapeole	doc_213943984905_item	2263471	et	4	main
klassikaaslasi	doc_213943984905_item	2263477	et	3	main
poisi	doc_213943984905_item	2263482	et	3	main
sai	doc_213943984905_item	2263484	et	4	main
artur	doc_213943984905_item	2263488	et	4	main
teda	doc_213943984905_item	2263490	et	4	main
rohkem	doc_213943984905_item	2263492	et	4	main
anna	doc_213943984905_item	2263500	et	4	main
see	doc_213943984905_item	2263513	et	3	main
kinkekaardidega	doc_213943984905_item	2263519	et	3	main
sai	doc_213943984905_item	2263528	et	4	main
nagu	doc_213943984905_item	2263540	et	3	main
ta	doc_213943984905_item	2263550	et	4	main
äkki	doc_213943984905_item	2263555	et	3	main
kõik	doc_213943984905_item	2263557	et	4	main
paanikasse	doc_213943984905_item	2263562	et	4	main
ja	doc_213943984905_item	2263575	et	3	main
aken	doc_213943984905_item	2263577	et	3	main
ilme	doc_213943984905_item	2263596	et	4	main
äkki	doc_213943984905_item	2263598	et	3	main
keelt	doc_200257165103_item	2263126	et	4	main
faelmanni	doc_200257165103_item	2263132	et	4	main
vägilasmuistendite	doc_200257165103_item	2263133	et	4	main
juures	doc_200257165103_item	2263140	et	4	main
aastal	doc_200257165103_item	2263144	et	3	main
oli	doc_200257165103_item	2263150	et	3	main
esimene	doc_200257165103_item	2263151	et	3	main
selts	doc_200257165103_item	2263153	et	3	main
hakkas	doc_200257165103_item	2263155	et	3	main
ma	doc_213943984903_item	2263163	et	3	main
kaheksa	doc_213943984903_item	2263166	et	4	main
olin	doc_213943984903_item	2263168	et	3	main
siit	doc_213943984903_item	2263175	et	3	main
berliinis	doc_213943984903_item	2263177	et	4	main
nii	doc_213943984903_item	2263180	et	3	main
aga	doc_213943984903_item	2263182	et	3	main
paistsis	doc_213943984903_item	2263187	et	4	main
lennujaamasse	doc_213943984903_item	2263190	et	3	main
kell	doc_213943984903_item	2263198	et	3	main
pool	doc_213943984903_item	2263199	et	4	main
üksteist	doc_213943984903_item	2263200	et	4	main
ma	doc_213943984903_item	2263201	et	3	main
tundsin	doc_213943984903_item	2263202	et	3	main
rõõmu	doc_213943984903_item	2263203	et	4	main
kun	doc_213943984903_item	2263204	et	4	main
nägin	doc_213943984903_item	2263205	et	3	main
tallinn	doc_213943984903_item	2263206	et	4	main
sest	doc_213943984903_item	2263207	et	4	main
mulle	doc_213943984903_item	2263208	et	4	main
väga	doc_213943984903_item	2263209	et	3	main
meeldib	doc_213943984903_item	2263210	et	3	main
see	doc_213943984903_item	2263211	et	3	main
meie	doc_213943984903_item	2263213	et	4	main
hotell	doc_213943984903_item	2263214	et	3	main
on	doc_213943984903_item	2263215	et	4	main
tallinnas	doc_213943984903_item	2263216	et	4	main
linn	doc_213943984903_item	2263212	et	3	main
mustamäel	doc_213943984903_item	2263217	et	3	main
ma	doc_213943984903_item	2263218	et	3	main
usun	doc_213943984903_item	2263219	et	3	main
see	doc_213943984903_item	2263220	et	3	main
on	doc_213943984903_item	2263221	et	4	main
hostel	doc_213943984903_item	2263223	et	4	main
akadeemia	doc_213943984903_item	2263224	et	4	main
ei	doc_213943984903_item	2263228	et	4	main
väsinud	doc_213943984903_item	2263237	et	4	main
lähen	doc_213943984903_item	2263239	et	3	main
teel	doc_213943984903_item	2263225	et	4	main
ainult	doc_213943984903_item	2263231	et	4	main
väikes	doc_213943984903_item	2263232	et	4	main
praegu	doc_213943984903_item	2263234	et	3	main
väga	doc_213943984903_item	2263236	et	3	main
ja	doc_213943984903_item	2263238	et	3	main
magama	doc_213943984903_item	2263240	et	3	main
essee	doc_213943984905_item	2263340	et	4	main
tavalises	doc_213943984905_item	2263346	et	4	main
perekond	doc_213943984905_item	2263351	et	3	main
peremees	doc_213943984905_item	2263352	et	4	main
kes	doc_213943984905_item	2263357	et	4	main
elasid	doc_213943984905_item	2263362	et	4	main
kolmetoalises	doc_213943984905_item	2263365	et	4	main
kodus	doc_213943984905_item	2263377	et	4	main
tavalises	doc_213943984905_item	2263382	et	4	main
maja	doc_213943984905_item	2263387	et	4	main
peale	doc_213943984905_item	2263394	et	4	main
siidpehmed	doc_213943984905_item	2263422	et	3	main
ja	doc_213943984905_item	2263425	et	3	main
kevadisel	doc_213943984905_item	2263450	et	4	main
päikesepaistelisel	doc_213943984905_item	2263451	et	4	main
bella	doc_213943984905_item	2263455	et	4	main
viimaks	doc_213943984905_item	2263458	et	4	main
oma	doc_213943984905_item	2263474	et	4	main
sõpru	doc_213943984905_item	2263475	et	3	main
tüdrukut	doc_213943984905_item	2263479	et	3	main
kingitusi	doc_213943984905_item	2263486	et	4	main
väga	doc_213943984905_item	2263495	et	3	main
noormees	doc_213943984905_item	2263497	et	4	main
meeldis	doc_213943984905_item	2263499	et	3	main
sada	doc_213943984905_item	2263507	et	4	main
ta	doc_213943984905_item	2263529	et	4	main
oli	doc_213943984905_item	2263530	et	3	main
nii	doc_213943984905_item	2263531	et	3	main
lilli	doc_213943984905_item	2263539	et	4	main
peale	doc_213943984905_item	2263547	et	4	main
kuid	doc_213943984905_item	2263554	et	4	main
sattus	doc_213943984905_item	2263561	et	3	main
tundus	doc_213943984905_item	2263579	et	3	main
et	doc_213943984905_item	2263580	et	3	main
mitte	doc_213943984905_item	2263581	et	3	main
ei	doc_213943984905_item	2263583	et	4	main
hingetuna	doc_213943984905_item	2263588	et	4	main
tema	doc_213943984905_item	2263590	et	4	main
huuled	doc_213943984905_item	2263592	et	3	main
muutusid	doc_213943984905_item	2263593	et	4	main
ja	doc_213943984905_item	2263595	et	3	main
kahvatuks	doc_213943984905_item	2263597	et	4	main
tuli	doc_213943984905_item	2263622	et	4	main
et	doc_213943984905_item	2263626	et	3	main
ja	doc_213943984905_item	2263633	et	3	main
teeskles	doc_213943984905_item	2263634	et	3	main
suure	doc_213943984905_item	2263641	et	3	main
sel	doc_213943984905_item	2263643	et	3	main
nad	doc_213943984905_item	2263645	et	3	main
tundsid	doc_213943984905_item	2263649	et	4	main
bella	doc_213943984905_item	2263653	et	4	main
kalendris	doc_213943984905_item	2263662	et	3	main
essee	doc_213943984906_item	2263666	et	4	main
elasid	doc_213943984906_item	2263668	et	4	main
üks	doc_213943984906_item	2263670	et	3	main
kai	doc_213943984906_item	2263676	et	4	main
gerdale	doc_213943984906_item	2263683	et	4	main
viis	doc_213943984906_item	2263685	et	4	main
päevas	doc_213943984906_item	2263687	et	3	main
ümber	doc_213943984906_item	2263688	et	3	main
riietuda	doc_213943984906_item	2263689	et	3	main
arvutimängude	doc_213943984906_item	2263695	et	3	main
ja	doc_213943984906_item	2263721	et	3	main
teise	doc_213943984906_item	2263724	et	4	main
villa	doc_213943984906_item	2263741	et	4	main
need	doc_213943984906_item	2263747	et	3	main
gerda	doc_213943984906_item	2263749	et	4	main
kai	doc_213943984906_item	2263751	et	4	main
kuninganna	doc_213943984906_item	2263753	et	4	main
vaikisid	doc_213943984906_item	2263770	et	4	main
viiekorruselises	doc_213943984905_item	2263347	et	4	main
tavaline	doc_213943984905_item	2263349	et	4	main
nende	doc_213943984905_item	2263355	et	4	main
oma	doc_213943984905_item	2263360	et	4	main
tavalistes	doc_213943984905_item	2263363	et	4	main
neiu	doc_213943984905_item	2263379	et	4	main
käis	doc_213943984905_item	2263381	et	4	main
mis	doc_213943984905_item	2263384	et	4	main
lihtne	doc_213943984905_item	2263393	et	3	main
juuksed	doc_213943984905_item	2263424	et	3	main
roosad	doc_213943984905_item	2263426	et	4	main
imekaunis	doc_213943984905_item	2263431	et	4	main
ei	doc_213943984905_item	2263435	et	4	main
kunagi	doc_213943984905_item	2263437	et	3	main
ei	doc_213943984905_item	2263440	et	4	main
kõigega	doc_213943984905_item	2263446	et	3	main
kõigile	doc_213943984905_item	2263448	et	4	main
anna	doc_213943984905_item	2263454	et	4	main
oma	doc_213943984905_item	2263456	et	4	main
saan	doc_213943984905_item	2263460	et	4	main
ma	doc_213943984905_item	2263461	et	3	main
kaheksateist	doc_213943984905_item	2263462	et	4	main
klubides	doc_213943984905_item	2263465	et	3	main
käia	doc_213943984905_item	2263467	et	4	main
oma	doc_213943984905_item	2263470	et	4	main
ja	doc_213943984905_item	2263476	et	3	main
artur	doc_213943984905_item	2263493	et	4	main
oli	doc_213943984905_item	2263494	et	3	main
kes	doc_213943984905_item	2263498	et	4	main
bellale	doc_213943984905_item	2263501	et	4	main
punast	doc_213943984905_item	2263508	et	4	main
ja	doc_213943984905_item	2263510	et	3	main
kullast	doc_213943984905_item	2263512	et	4	main
ei	doc_213943984905_item	2263515	et	4	main
teiste	doc_213943984905_item	2263518	et	4	main
šampoonidega	doc_213943984905_item	2263522	et	2	main
bella	doc_213943984905_item	2263525	et	4	main
tol	doc_213943984905_item	2263526	et	3	main
et	doc_213943984905_item	2263533	et	3	main
iga	doc_213943984905_item	2263538	et	4	main
tahtis	doc_213943984905_item	2263549	et	3	main
ema	doc_213943984905_item	2263560	et	4	main
keegi	doc_213943984905_item	2263564	et	4	main
teadnud	doc_213943984905_item	2263566	et	4	main
mida	doc_213943984905_item	2263567	et	4	main
magamistuppa	doc_213943984905_item	2263573	et	3	main
tehti	doc_213943984905_item	2263576	et	3	main
väikesed	doc_213943984905_item	2263591	et	4	main
ja	doc_213943984905_item	2263624	et	3	main
elu	doc_213943984905_item	2263631	et	4	main
lõbutsesid	doc_213943984905_item	2263640	et	4	main
kambaga	doc_213943984905_item	2263642	et	3	main
anna	doc_213943984905_item	2263652	et	4	main
ja	doc_213943984905_item	2263654	et	3	main
jaoks	doc_213943984905_item	2263656	et	4	main
on	doc_213943984905_item	2263659	et	4	main
eriline	doc_213943984905_item	2263664	et	4	main
väike	doc_213943984906_item	2263671	et	4	main
vanaema	doc_213943984906_item	2263678	et	4	main
kail	doc_213943984906_item	2263690	et	4	main
teisel	doc_213943984906_item	2263702	et	4	main
kiusakas	doc_213943984906_item	2263705	et	4	main
ta	doc_213943984906_item	2263722	et	4	main
laevale	doc_213943984906_item	2263729	et	4	main
ja	doc_213943984906_item	2263730	et	3	main
ära	doc_213943984906_item	2263732	et	4	main
mille	doc_213943984906_item	2263742	et	3	main
kuna	doc_213943984906_item	2263752	et	3	main
ja	doc_213943984906_item	2263769	et	3	main
vaikite	doc_213943984906_item	2263773	et	3	main
koju	doc_213943984906_item	2263784	et	3	main
vanaemale	doc_213943984906_item	2263788	et	3	main
nägisid	doc_213943984906_item	2263791	et	4	main
kartke	doc_213943984906_item	2263793	et	3	main
teda	doc_213943984906_item	2263794	et	4	main
ja	doc_213943984906_item	2263800	et	3	main
kaunitar	doc_213943984905_item	2263342	et	3	main
kord	doc_213943984905_item	2263344	et	4	main
paneelmajas	doc_213943984905_item	2263348	et	3	main
tütar	doc_213943984905_item	2263356	et	3	main
väikese	doc_213943984905_item	2263367	et	4	main
noore	doc_213943984905_item	2263369	et	3	main
vanemad	doc_213943984905_item	2263371	et	4	main
vanaema	doc_213943984905_item	2263375	et	4	main
asus	doc_213943984905_item	2263385	et	4	main
tavaline	doc_213943984905_item	2263391	et	4	main
selle	doc_213943984905_item	2263395	et	4	main
noore	doc_213943984905_item	2263396	et	3	main
neiu	doc_213943984905_item	2263397	et	4	main
anna	doc_213943984905_item	2263398	et	4	main
bella	doc_213943984905_item	2263399	et	4	main
oli	doc_213943984905_item	2263400	et	3	main
alles	doc_213943984905_item	2263401	et	3	main
seitseteist	doc_213943984905_item	2263402	et	4	main
kuid	doc_213943984905_item	2263403	et	4	main
tundus	doc_213943984905_item	2263404	et	3	main
et	doc_213943984905_item	2263405	et	3	main
ta	doc_213943984905_item	2263406	et	4	main
teadis	doc_213943984905_item	2263407	et	4	main
kõike	doc_213943984905_item	2263408	et	4	main
ta	doc_213943984905_item	2263409	et	4	main
läks	doc_213943984905_item	2263410	et	3	main
viieteistaastaselt	doc_213943984905_item	2263411	et	4	main
kooli	doc_213943984905_item	2263412	et	4	main
ja	doc_213943984905_item	2263413	et	3	main
ta	doc_213943984905_item	2263414	et	4	main
oli	doc_213943984905_item	2263415	et	3	main
alati	doc_213943984905_item	2263416	et	4	main
viiene	doc_213943984905_item	2263417	et	4	main
laps	doc_213943984905_item	2263418	et	4	main
tal	doc_213943984905_item	2263419	et	3	main
oli	doc_213943984905_item	2263420	et	3	main
ja	doc_213943984905_item	2263439	et	3	main
bella	doc_213943984905_item	2263429	et	4	main
külastanud	doc_213943984905_item	2263441	et	4	main
ilusalonge	doc_213943984905_item	2263442	et	3	main
ta	doc_213943984905_item	2263443	et	4	main
ja	doc_213943984905_item	2263447	et	3	main
ühel	doc_213943984905_item	2263449	et	3	main
sünnipäeva	doc_213943984905_item	2263457	et	4	main
ometi	doc_213943984905_item	2263459	et	3	main
kutsus	doc_213943984905_item	2263472	et	4	main
ta	doc_213943984905_item	2263473	et	4	main
kolm	doc_213943984905_item	2263481	et	3	main
tema	doc_213943984905_item	2263483	et	4	main
igasuguseid	doc_213943984905_item	2263485	et	3	main
üllatas	doc_213943984905_item	2263489	et	3	main
kõige	doc_213943984905_item	2263491	et	4	main
ammu	doc_213943984905_item	2263503	et	4	main
artur	doc_213943984905_item	2263504	et	4	main
tütarlapsele	doc_213943984905_item	2263506	et	4	main
roosi	doc_213943984905_item	2263509	et	4	main
aluspesuga	doc_213943984905_item	2263520	et	3	main
ja	doc_213943984905_item	2263521	et	3	main
õnnelik	doc_213943984905_item	2263532	et	3	main
roosid	doc_213943984905_item	2263536	et	4	main
nuusutas	doc_213943984905_item	2263537	et	3	main
oleksid	doc_213943984905_item	2263541	et	4	main
kõik	doc_213943984905_item	2263543	et	4	main
moodi	doc_213943984905_item	2263545	et	4	main
lõhnanud	doc_213943984905_item	2263546	et	4	main
selle	doc_213943984905_item	2263548	et	4	main
põsemusi	doc_213943984905_item	2263552	et	4	main
ja	doc_213943984905_item	2263563	et	3	main
ei	doc_213943984905_item	2263565	et	4	main
tegema	doc_213943984905_item	2263569	et	3	main
anna	doc_213943984905_item	2263570	et	4	main
bellat	doc_213943984905_item	2263571	et	4	main
toimetati	doc_213943984905_item	2263572	et	4	main
diivanile	doc_213943984905_item	2263574	et	3	main
lahti	doc_213943984905_item	2263578	et	4	main
midagi	doc_213943984905_item	2263582	et	4	main
aita	doc_213943984905_item	2263584	et	4	main
artur	doc_213943984905_item	2263599	et	4	main
tuli	doc_213943984905_item	2263600	et	4	main
juurde	doc_213943984905_item	2263602	et	4	main
lasi	doc_213943984905_item	2263603	et	4	main
on	doc_213943984905_item	2263628	et	4	main
et	doc_213943984905_item	2263635	et	3	main
teadvuse	doc_213943984905_item	2263637	et	4	main
nad	doc_213943984905_item	2263639	et	3	main
õhtul	doc_213943984905_item	2263644	et	3	main
tantsisid	doc_213943984905_item	2263647	et	4	main
tüdruk	doc_213943984906_item	2263672	et	3	main
mererannas	doc_213943984906_item	2263679	et	3	main
kolmekorruselises	doc_213943984906_item	2263681	et	4	main
aga	doc_213943984906_item	2263692	et	3	main
huvi	doc_213943984906_item	2263694	et	4	main
pirukaid	doc_213943984906_item	2263700	et	3	main
rannal	doc_213943984906_item	2263703	et	3	main
elas	doc_213943984906_item	2263704	et	3	main
külastada	doc_213943984906_item	2263727	et	3	main
sõitis	doc_213943984906_item	2263731	et	3	main
kui	doc_213943984906_item	2263733	et	3	main
rannale	doc_213943984906_item	2263736	et	3	main
lumekuninganna	doc_213943984906_item	2263738	et	4	main
õues	doc_213943984906_item	2263743	et	4	main
kaks	doc_213943984906_item	2263745	et	3	main
olid	doc_213943984906_item	2263748	et	4	main
ja	doc_213943984906_item	2263750	et	3	main
lapsed	doc_213943984906_item	2263765	et	3	main
võõrase	doc_213943984906_item	2263767	et	3	main
gerda	doc_213943984906_item	2263781	et	4	main
ja	doc_213943984906_item	2263782	et	3	main
nad	doc_213943984906_item	2263787	et	3	main
keda	doc_213943984906_item	2263789	et	4	main
avanes	doc_213943984906_item	2263799	et	3	main
lumemajja	doc_213943984906_item	2263808	et	3	main
sõidame	doc_213943984906_item	2263816	et	3	main
siia	doc_213943984906_item	2263822	et	4	main
kõik	doc_213943984906_item	2263828	et	4	main
ei	doc_213943984906_item	2263833	et	4	main
mina	doc_213943984906_item	2263834	et	4	main
tahan	doc_213943984906_item	2263835	et	3	main
mis	doc_213943984905_item	2263523	et	4	main
anna	doc_213943984905_item	2263524	et	4	main
päeval	doc_213943984905_item	2263527	et	3	main
haaras	doc_213943984905_item	2263534	et	4	main
kõik	doc_213943984905_item	2263535	et	4	main
nad	doc_213943984905_item	2263542	et	3	main
erinevat	doc_213943984905_item	2263544	et	4	main
arturile	doc_213943984905_item	2263551	et	4	main
anda	doc_213943984905_item	2263553	et	3	main
minestas	doc_213943984905_item	2263556	et	3	main
hakkasid	doc_213943984905_item	2263558	et	4	main
muretsema	doc_213943984905_item	2263559	et	3	main
peab	doc_213943984905_item	2263568	et	4	main
sest	doc_213943984905_item	2263585	et	4	main
tema	doc_213943984905_item	2263586	et	4	main
lamas	doc_213943984905_item	2263587	et	3	main
voodis	doc_213943984905_item	2263589	et	3	main
heleroosadeks	doc_213943984905_item	2263594	et	3	main
tema	doc_213943984905_item	2263601	et	4	main
ennast	doc_213943984905_item	2263604	et	4	main
põlvele	doc_213943984905_item	2263605	et	4	main
ja	doc_213943984905_item	2263606	et	3	main
suudles	doc_213943984905_item	2263607	et	3	main
teda	doc_213943984905_item	2263608	et	4	main
ta	doc_213943984905_item	2263609	et	4	main
puutus	doc_213943984905_item	2263610	et	4	main
noore	doc_213943984905_item	2263611	et	3	main
ja	doc_213943984905_item	2263612	et	3	main
sinitu	doc_213943984905_item	2263613	et	4	main
neiu	doc_213943984905_item	2263614	et	4	main
huuli	doc_213943984905_item	2263615	et	3	main
suure	doc_213943984905_item	2263616	et	3	main
õrnusega	doc_213943984905_item	2263617	et	4	main
ja	doc_213943984905_item	2263618	et	3	main
armastusega	doc_213943984905_item	2263619	et	4	main
anna	doc_213943984905_item	2263620	et	4	main
bell	doc_213943984905_item	2263621	et	3	main
teadvusele	doc_213943984905_item	2263623	et	4	main
tunnistas	doc_213943984905_item	2263625	et	3	main
ta	doc_213943984905_item	2263627	et	4	main
seda	doc_213943984905_item	2263629	et	3	main
kaotas	doc_213943984905_item	2263636	et	3	main
nii	doc_213943984905_item	2263638	et	3	main
naersid	doc_213943984905_item	2263646	et	4	main
ennast	doc_213943984905_item	2263650	et	4	main
vabalt	doc_213943984905_item	2263651	et	4	main
arturi	doc_213943984905_item	2263655	et	4	main
poisike	doc_213943984906_item	2263675	et	4	main
villas	doc_213943984906_item	2263682	et	4	main
oli	doc_213943984906_item	2263691	et	3	main
suur	doc_213943984906_item	2263693	et	3	main
vastu	doc_213943984906_item	2263696	et	3	main
öö-paev	doc_213943984906_item	2263699	et	4	main
mere	doc_213943984906_item	2263701	et	3	main
otsustas	doc_213943984906_item	2263723	et	3	main
ranna	doc_213943984906_item	2263725	et	3	main
elanikke	doc_213943984906_item	2263726	et	3	main
laev	doc_213943984906_item	2263734	et	3	main
ilusat	doc_213943984906_item	2263740	et	3	main
vestlesid	doc_213943984906_item	2263744	et	4	main
last	doc_213943984906_item	2263746	et	4	main
nägid	doc_213943984906_item	2263766	et	4	main
küsis	doc_213943984906_item	2263774	et	3	main
kuri	doc_213943984906_item	2263776	et	4	main
häälega	doc_213943984906_item	2263777	et	3	main
terve	doc_213943984905_item	2263630	et	4	main
oodanud	doc_213943984905_item	2263632	et	4	main
ja	doc_213943984905_item	2263648	et	3	main
nüüdsest	doc_213943984905_item	2263657	et	3	main
ajast	doc_213943984905_item	2263658	et	4	main
see	doc_213943984905_item	2263660	et	3	main
päev	doc_213943984905_item	2263661	et	3	main
on	doc_213943984905_item	2263663	et	4	main
tähtpäev	doc_213943984905_item	2263665	et	3	main
lumekuninganna	doc_213943984906_item	2263667	et	4	main
kord	doc_213943984906_item	2263669	et	4	main
gerda	doc_213943984906_item	2263673	et	4	main
ja	doc_213943984906_item	2263674	et	3	main
oma	doc_213943984906_item	2263677	et	4	main
asuvas	doc_213943984906_item	2263680	et	4	main
meeldis	doc_213943984906_item	2263684	et	3	main
korda	doc_213943984906_item	2263686	et	4	main
vanaemake	doc_213943984906_item	2263697	et	4	main
küpsetas	doc_213943984906_item	2263698	et	3	main
lumekuninganna	doc_213943984906_item	2263706	et	4	main
kelle	doc_213943984906_item	2263707	et	4	main
maja	doc_213943984906_item	2263708	et	4	main
oli	doc_213943984906_item	2263709	et	3	main
lumest	doc_213943984906_item	2263710	et	3	main
ehitatud	doc_213943984906_item	2263711	et	4	main
elas	doc_213943984906_item	2263713	et	3	main
üksi	doc_213943984906_item	2263714	et	4	main
kuninganna	doc_213943984906_item	2263712	et	4	main
ühel	doc_213943984906_item	2263715	et	3	main
päeval	doc_213943984906_item	2263716	et	3	main
oli	doc_213943984906_item	2263717	et	3	main
tal	doc_213943984906_item	2263718	et	3	main
väga	doc_213943984906_item	2263719	et	3	main
igav	doc_213943984906_item	2263720	et	3	main
istus	doc_213943984906_item	2263728	et	4	main
saabus	doc_213943984906_item	2263735	et	3	main
nägi	doc_213943984906_item	2263737	et	3	main
suurt	doc_213943984906_item	2263739	et	3	main
oli	doc_213943984906_item	2263754	et	3	main
mitte	doc_213943984906_item	2263755	et	3	main
ainult	doc_213943984906_item	2263756	et	4	main
kiusakas	doc_213943984906_item	2263757	et	4	main
kui	doc_213943984906_item	2263758	et	3	main
ka	doc_213943984906_item	2263759	et	3	main
uudishimulik	doc_213943984906_item	2263760	et	3	main
läks	doc_213943984906_item	2263761	et	3	main
ta	doc_213943984906_item	2263762	et	4	main
nende	doc_213943984906_item	2263763	et	4	main
juurde	doc_213943984906_item	2263764	et	4	main
tädike	doc_213943984906_item	2263768	et	4	main
miks	doc_213943984906_item	2263771	et	4	main
midagi	doc_213943984906_item	2263778	et	4	main
vastates	doc_213943984906_item	2263779	et	4	main
läksid	doc_213943984906_item	2263780	et	4	main
köögis	doc_213943984906_item	2263785	et	3	main
vanaema	doc_213943984906_item	2263796	et	4	main
kööki	doc_213943984906_item	2263801	et	4	main
tädike	doc_213943984906_item	2263810	et	4	main
tore	doc_213943984906_item	2263813	et	3	main
sina	doc_213943984906_item	2263820	et	4	main
sõita	doc_213943984906_item	2263838	et	3	main
aega	doc_213943984906_item	2263844	et	4	main
meres	doc_213943984906_item	2263852	et	3	main
röövijatega	doc_213943984906_item	2263855	et	4	main
õige	doc_213943984906_item	2263859	et	4	main
teed	doc_213943984906_item	2263860	et	4	main
lumekuninganna	doc_213943984906_item	2263862	et	4	main
majake	doc_213943984906_item	2263863	et	4	main
kuna	doc_213943984906_item	2263869	et	3	main
oli	doc_213943984906_item	2263871	et	3	main
külm	doc_213943984906_item	2263877	et	3	main
tülitseb	doc_213943984906_item	2263883	et	3	main
appi	doc_213943984906_item	2263887	et	4	main
helistas	doc_213943984906_item	2263889	et	3	main
teie	doc_213943984906_item	2263772	et	4	main
lumekuninganna	doc_213943984906_item	2263775	et	4	main
jutustasid	doc_213943984906_item	2263786	et	4	main
nad	doc_213943984906_item	2263790	et	3	main
ütles	doc_213943984906_item	2263795	et	3	main
maja	doc_213943984906_item	2263797	et	4	main
lumekuninganna	doc_213943984906_item	2263803	et	4	main
kaasa	doc_213943984906_item	2263807	et	4	main
lauses	doc_213943984906_item	2263809	et	3	main
oh	doc_213943984906_item	2263811	et	3	main
ütlesid	doc_213943984906_item	2263814	et	4	main
kõneles	doc_213943984906_item	2263818	et	3	main
gerda	doc_213943984906_item	2263819	et	4	main
kai	doc_213943984906_item	2263783	et	4	main
ärge	doc_213943984906_item	2263792	et	3	main
uks	doc_213943984906_item	2263798	et	3	main
ma	doc_213943984906_item	2263804	et	3	main
sind	doc_213943984906_item	2263806	et	4	main
lapsed	doc_213943984906_item	2263815	et	3	main
siis	doc_213943984906_item	2263817	et	3	main
kai	doc_213943984906_item	2263827	et	4	main
on	doc_213943984906_item	2263829	et	4	main
ütles	doc_213943984906_item	2263839	et	3	main
sõida	doc_213943984906_item	2263841	et	4	main
rahulikult	doc_213943984906_item	2263847	et	4	main
rannale	doc_213943984906_item	2263851	et	3	main
ei	doc_213943984906_item	2263865	et	4	main
gerdale	doc_213943984906_item	2263868	et	4	main
majake	doc_213943984906_item	2263870	et	4	main
väga	doc_213943984906_item	2263876	et	3	main
on	doc_213943984906_item	2263879	et	4	main
et	doc_213943984906_item	2263881	et	3	main
kuningannaga	doc_213943984906_item	2263884	et	4	main
olid	doc_213943984907_item	2263923	et	4	main
vanad	doc_213943984907_item	2263925	et	3	main
mees	doc_213943984907_item	2263943	et	4	main
pitsaks	doc_213943984907_item	2263944	et	3	main
taignast	doc_213943984907_item	2263945	et	4	main
ostma	doc_213943984907_item	2263946	et	3	main
peal	doc_213943984907_item	2263954	et	4	main
pähe	doc_213943984907_item	2263960	et	4	main
teeks	doc_213943984907_item	2263962	et	4	main
süüa	doc_213943984907_item	2263970	et	3	main
teeks	doc_213943984907_item	2263972	et	4	main
hoopis	doc_213943984907_item	2263973	et	3	main
nende	doc_213943984907_item	2264010	et	4	main
anti	doc_213943984907_item	2264014	et	3	main
laps	doc_213943984907_item	2264018	et	4	main
tal	doc_213943984907_item	2264021	et	3	main
jalgu	doc_213943984907_item	2264025	et	4	main
nad	doc_213943984907_item	2264027	et	3	main
mutandi	doc_213943984907_item	2264029	et	3	main
kuna	doc_213943984907_item	2264032	et	3	main
oli	doc_213943984907_item	2264034	et	3	main
vanemate	doc_213943984907_item	2264036	et	4	main
käes	doc_213943984907_item	2264046	et	4	main
ei	doc_213943984907_item	2264063	et	4	main
midagi	doc_213943984907_item	2264065	et	4	main
pea	doc_213943984907_item	2264071	et	4	main
mingeid	doc_213943984907_item	2264072	et	3	main
kehaosasid	doc_213943984907_item	2264074	et	3	main
välja	doc_213943984907_item	2264084	et	4	main
nimi	doc_213943984907_item	2264092	et	3	main
astus	doc_213943984906_item	2263802	et	3	main
võtan	doc_213943984906_item	2263805	et	3	main
kui	doc_213943984906_item	2263812	et	3	main
jäid	doc_213943984906_item	2263821	et	4	main
käskis	doc_213943984906_item	2263823	et	4	main
kuninganna	doc_213943984906_item	2263824	et	4	main
ja	doc_213943984906_item	2263825	et	3	main
varastas	doc_213943984906_item	2263826	et	3	main
vanaema	doc_213943984906_item	2263832	et	4	main
ka	doc_213943984906_item	2263836	et	3	main
kõneles	doc_213943984906_item	2263845	et	3	main
sõitis	doc_213943984906_item	2263849	et	3	main
meeldinud	doc_213943984906_item	2263866	et	4	main
väike	doc_213943984906_item	2263872	et	4	main
ja	doc_213943984906_item	2263873	et	3	main
oli	doc_213943984906_item	2263875	et	3	main
kutsub	doc_213943984906_item	2263886	et	3	main
tüdruke	doc_213943984906_item	2263888	et	4	main
nad	doc_213943984907_item	2263922	et	3	main
aga	doc_213943984907_item	2263926	et	3	main
mehe	doc_213943984907_item	2263935	et	3	main
oli	doc_213943984907_item	2263939	et	3	main
säästukas	doc_213943984907_item	2263940	et	4	main
pidi	doc_213943984907_item	2263942	et	4	main
ja	doc_213943984907_item	2263952	et	3	main
tuli	doc_213943984907_item	2263955	et	4	main
äkki	doc_213943984907_item	2263961	et	3	main
ei	doc_213943984907_item	2263966	et	4	main
seda	doc_213943984907_item	2263968	et	3	main
pärast	doc_213943984907_item	2264007	et	4	main
tuli	doc_213943984907_item	2264008	et	4	main
lapseke	doc_213943984907_item	2264011	et	4	main
aga	doc_213943984907_item	2264016	et	3	main
ei	doc_213943984907_item	2264022	et	4	main
ega	doc_213943984907_item	2264024	et	3	main
välja	doc_213943984907_item	2264030	et	4	main
olid	doc_213943984907_item	2264049	et	4	main
asus	doc_213943984907_item	2264058	et	4	main
peale	doc_213943984907_item	2264070	et	4	main
muid	doc_213943984907_item	2264073	et	4	main
juhtu	doc_213943984907_item	2264078	et	4	main
kauplust	doc_213943984907_item	2264090	et	4	main
osta	doc_213943984907_item	2264122	et	4	main
kakuke	doc_213943984907_item	2264124	et	4	main
ütles	doc_213943984907_item	2264125	et	3	main
iseseisev	doc_213943984907_item	2264129	et	3	main
tal	doc_213943984907_item	2264132	et	3	main
ole	doc_213943984907_item	2264137	et	4	main
pettunud	doc_213943984907_item	2264138	et	4	main
läks	doc_213943984907_item	2264140	et	3	main
ära	doc_213943984907_item	2264141	et	4	main
kakukest	doc_213943984907_item	2264144	et	4	main
tema	doc_213943984907_item	2264164	et	4	main
edasi	doc_213943984907_item	2264170	et	3	main
kakuke	doc_213943984907_item	2264173	et	4	main
rebast	doc_213943984907_item	2264174	et	4	main
kakukest	doc_213943984907_item	2264189	et	4	main
alla	doc_213943984907_item	2264197	et	3	main
nõustus	doc_213943984907_item	2264210	et	4	main
et	doc_213943984907_item	2264223	et	3	main
nii	doc_213943984907_item	2264233	et	3	main
läks	doc_213943984907_item	2264240	et	3	main
jooksuga	doc_213943984907_item	2264241	et	3	main
võtsid	doc_213943984907_item	2264246	et	4	main
poja	doc_213943984907_item	2264248	et	4	main
essee	doc_213943984908_item	2264260	et	4	main
tuhkatriinu	doc_213943984908_item	2264280	et	4	main
suures	doc_213943984908_item	2264287	et	3	main
majas	doc_213943984908_item	2264289	et	3	main
teinud	doc_213943984908_item	2264293	et	4	main
ta	doc_213943984908_item	2264306	et	4	main
karm	doc_213943984908_item	2264315	et	4	main
tema	doc_213943984908_item	2264317	et	4	main
ainult	doc_213943984908_item	2264330	et	4	main
osta	doc_213943984908_item	2264335	et	4	main
tuhkatriinu	doc_213943984908_item	2264336	et	4	main
teistest	doc_213943984908_item	2264339	et	4	main
luges	doc_213943984908_item	2264343	et	3	main
õppis	doc_213943984908_item	2264345	et	3	main
oli	doc_213943984908_item	2264352	et	3	main
nii	doc_213943984908_item	2264358	et	3	main
süvenenud	doc_213943984908_item	2264360	et	4	main
korras	doc_213943984906_item	2263830	et	4	main
lauses	doc_213943984906_item	2263831	et	3	main
teisele	doc_213943984906_item	2263850	et	4	main
ta	doc_213943984906_item	2263854	et	4	main
kes	doc_213943984906_item	2263856	et	4	main
aitasid	doc_213943984906_item	2263857	et	4	main
temal	doc_213943984906_item	2263858	et	3	main
leida	doc_213943984906_item	2263861	et	3	main
nähes	doc_213943984906_item	2263864	et	4	main
sees	doc_213943984906_item	2263874	et	4	main
kai	doc_213943984906_item	2263882	et	4	main
ja	doc_213943984906_item	2263885	et	3	main
tuttavale	doc_213943984906_item	2263890	et	4	main
politseinikule	doc_213943984906_item	2263891	et	4	main
kes	doc_213943984906_item	2263892	et	4	main
päästaski	doc_213943984906_item	2263893	et	4	main
neid	doc_213943984906_item	2263894	et	4	main
lapsed	doc_213943984906_item	2263895	et	3	main
tulid	doc_213943984906_item	2263896	et	4	main
vanaema	doc_213943984906_item	2263897	et	4	main
juurde	doc_213943984906_item	2263898	et	4	main
tagasi	doc_213943984906_item	2263899	et	3	main
ja	doc_213943984906_item	2263900	et	3	main
elu	doc_213943984906_item	2263901	et	4	main
kulges	doc_213943984906_item	2263902	et	3	main
edasi	doc_213943984906_item	2263903	et	3	main
gerda	doc_213943984906_item	2263904	et	4	main
riietub	doc_213943984906_item	2263905	et	3	main
viis	doc_213943984906_item	2263906	et	4	main
korda	doc_213943984906_item	2263907	et	4	main
päevas	doc_213943984906_item	2263908	et	3	main
kai	doc_213943984906_item	2263909	et	4	main
mängib	doc_213943984906_item	2263910	et	3	main
aga	doc_213943984906_item	2263911	et	3	main
arvutit	doc_213943984906_item	2263912	et	3	main
essee	doc_213943984907_item	2263913	et	4	main
kakuke	doc_213943984907_item	2263914	et	4	main
elas	doc_213943984907_item	2263915	et	3	main
kord	doc_213943984907_item	2263916	et	4	main
tallinnas	doc_213943984907_item	2263917	et	4	main
pere	doc_213943984907_item	2263918	et	4	main
mees	doc_213943984907_item	2263919	et	4	main
ja	doc_213943984907_item	2263920	et	3	main
naine	doc_213943984907_item	2263921	et	3	main
lapsi	doc_213943984907_item	2263927	et	4	main
ei	doc_213943984907_item	2263929	et	4	main
olnud	doc_213943984907_item	2263930	et	4	main
ükskord	doc_213943984907_item	2263931	et	3	main
naine	doc_213943984907_item	2263933	et	3	main
sealt	doc_213943984907_item	2263941	et	4	main
ta	doc_213943984907_item	2263947	et	4	main
nendega	doc_213943984906_item	2263837	et	4	main
gerda	doc_213943984906_item	2263840	et	4	main
siis	doc_213943984906_item	2263842	et	3	main
head	doc_213943984906_item	2263843	et	4	main
vanaema	doc_213943984906_item	2263846	et	4	main
gerda	doc_213943984906_item	2263848	et	4	main
tutvus	doc_213943984906_item	2263853	et	4	main
see	doc_213943984906_item	2263867	et	3	main
gerda	doc_213943984906_item	2263878	et	4	main
kuulnud	doc_213943984906_item	2263880	et	4	main
juba	doc_213943984907_item	2263924	et	3	main
neil	doc_213943984907_item	2263928	et	4	main
oma	doc_213943984907_item	2263934	et	4	main
poodi	doc_213943984907_item	2263936	et	4	main
kõige	doc_213943984907_item	2263937	et	4	main
lähem	doc_213943984907_item	2263938	et	4	main
taigna	doc_213943984907_item	2263949	et	3	main
seekord	doc_213943984907_item	2263963	et	3	main
enam	doc_213943984907_item	2263969	et	4	main
lapse	doc_213943984907_item	2263974	et	4	main
sealt	doc_213943984907_item	2264009	et	4	main
käsi	doc_213943984907_item	2264023	et	4	main
peale	doc_213943984907_item	2264037	et	4	main
kuri	doc_213943984907_item	2264038	et	4	main
ta	doc_213943984907_item	2264040	et	4	main
lahkuda	doc_213943984907_item	2264042	et	3	main
õnneks	doc_213943984907_item	2264043	et	4	main
suvi	doc_213943984907_item	2264045	et	3	main
oli	doc_213943984907_item	2264054	et	3	main
et	doc_213943984907_item	2264056	et	3	main
aga	doc_213943984907_item	2264061	et	3	main
ole	doc_213943984907_item	2264064	et	4	main
mõtles	doc_213943984907_item	2264066	et	3	main
kakuke	doc_213943984907_item	2264067	et	4	main
kuna	doc_213943984907_item	2264068	et	3	main
mul	doc_213943984907_item	2264069	et	3	main
minuga	doc_213943984907_item	2264079	et	3	main
ja	doc_213943984907_item	2264081	et	3	main
aknast	doc_213943984907_item	2264083	et	4	main
järsku	doc_213943984907_item	2264085	et	4	main
nägi	doc_213943984907_item	2264086	et	3	main
ta	doc_213943984907_item	2264087	et	4	main
suurt	doc_213943984907_item	2264088	et	3	main
ilusat	doc_213943984907_item	2264089	et	3	main
abi	doc_213943984907_item	2264134	et	4	main
märkis	doc_213943984907_item	2264143	et	3	main
hunt	doc_213943984907_item	2264145	et	3	main
ning	doc_213943984907_item	2264146	et	3	main
kakuke	doc_213943984907_item	2264151	et	4	main
ega	doc_213943984907_item	2264163	et	3	main
mingi	doc_213943984907_item	2264165	et	4	main
ja	doc_213943984907_item	2264168	et	3	main
loom	doc_213943984907_item	2264176	et	3	main
aga	doc_213943984907_item	2264183	et	3	main
ning	doc_213943984907_item	2264191	et	3	main
kohe	doc_213943984907_item	2264193	et	4	main
kakuke	doc_213943984907_item	2264195	et	4	main
teel	doc_213943984907_item	2264198	et	4	main
pani	doc_213943984907_item	2264200	et	4	main
seekord	doc_213943984907_item	2264208	et	3	main
midagi	doc_213943984907_item	2264216	et	4	main
siin	doc_213943984907_item	2264218	et	4	main
rebane	doc_213943984907_item	2264224	et	4	main
hakkas	doc_213943984907_item	2264225	et	3	main
imeliku	doc_213943984907_item	2264226	et	3	main
hüppas	doc_213943984907_item	2264236	et	3	main
välja	doc_213943984907_item	2264238	et	4	main
tagasi	doc_213943984907_item	2264243	et	3	main
vanemad	doc_213943984907_item	2264245	et	4	main
tuhkatriinu	doc_213943984908_item	2264261	et	4	main
tagasi	doc_213943984908_item	2264278	et	3	main
elas	doc_213943984908_item	2264281	et	3	main
ja	doc_213943984908_item	2264283	et	3	main
kahe	doc_213943984908_item	2264285	et	3	main
kolmekorrusselises	doc_213943984908_item	2264288	et	4	main
see	doc_213943984908_item	2264290	et	3	main
ema	doc_213943984908_item	2264299	et	4	main
kogu	doc_213943984908_item	2264309	et	4	main
aeg	doc_213943984908_item	2264310	et	3	main
kasuema	doc_213943984908_item	2264311	et	4	main
nalja	doc_213943984908_item	2264320	et	4	main
ja	doc_213943984908_item	2264332	et	3	main
noorukitest	doc_213943984908_item	2264340	et	4	main
saatis	doc_213943984907_item	2263932	et	3	main
ostis	doc_213943984907_item	2263948	et	4	main
koju	doc_213943984907_item	2263951	et	3	main
tee	doc_213943984907_item	2263953	et	4	main
järsku	doc_213943984907_item	2263957	et	4	main
mõte	doc_213943984907_item	2263959	et	3	main
pitsat	doc_213943984907_item	2263965	et	4	main
niisama	doc_213943984907_item	2263975	et	3	main
välja	doc_213943984907_item	2263976	et	4	main
ei	doc_213943984907_item	2263977	et	4	main
tule	doc_213943984907_item	2263978	et	4	main
prooviks	doc_213943984907_item	2263979	et	4	main
teisi	doc_213943984907_item	2263980	et	4	main
meetodeid	doc_213943984907_item	2263981	et	3	main
koju	doc_213943984907_item	2263982	et	3	main
jõudes	doc_213943984907_item	2263983	et	3	main
mees	doc_213943984907_item	2263984	et	4	main
rääkis	doc_213943984907_item	2263985	et	3	main
ideest	doc_213943984907_item	2263987	et	4	main
naisele	doc_213943984907_item	2263988	et	3	main
naisel	doc_213943984907_item	2263989	et	3	main
oma	doc_213943984907_item	2263986	et	4	main
tõusid	doc_213943984907_item	2263990	et	4	main
juuksed	doc_213943984907_item	2263991	et	3	main
püsti	doc_213943984907_item	2263992	et	3	main
aga	doc_213943984907_item	2263993	et	3	main
ikka	doc_213943984907_item	2263994	et	4	main
nad	doc_213943984907_item	2263995	et	3	main
otsustasid	doc_213943984907_item	2263996	et	4	main
idee	doc_213943984907_item	2263998	et	4	main
ellu	doc_213943984907_item	2263999	et	4	main
selle	doc_213943984907_item	2263997	et	4	main
panid	doc_213943984907_item	2264001	et	4	main
viia	doc_213943984907_item	2264000	et	3	main
mikrolaineahju	doc_213943984907_item	2264002	et	4	main
taigna	doc_213943984907_item	2264003	et	3	main
ja	doc_213943984907_item	2264004	et	3	main
poole	doc_213943984907_item	2264005	et	4	main
tunni	doc_213943984907_item	2264006	et	3	main
läks	doc_213943984907_item	2263950	et	3	main
talle	doc_213943984907_item	2263956	et	4	main
hull	doc_213943984907_item	2263958	et	3	main
mitte	doc_213943984907_item	2263964	et	3	main
taha	doc_213943984907_item	2263967	et	4	main
vaid	doc_213943984907_item	2263971	et	3	main
välja	doc_213943984907_item	2264012	et	4	main
kakuke	doc_213943984907_item	2264015	et	4	main
vaene	doc_213943984907_item	2264017	et	4	main
ei	doc_213943984907_item	2264019	et	4	main
ole	doc_213943984907_item	2264020	et	4	main
nimeks	doc_213943984907_item	2264013	et	3	main
mõtlesid	doc_213943984907_item	2264031	et	4	main
kakuke	doc_213943984907_item	2264033	et	4	main
oma	doc_213943984907_item	2264035	et	4	main
otsustas	doc_213943984907_item	2264039	et	3	main
kohe	doc_213943984907_item	2264041	et	4	main
oli	doc_213943984907_item	2264044	et	3	main
aknad	doc_213943984907_item	2264048	et	3	main
lahti	doc_213943984907_item	2264050	et	4	main
jäetud	doc_213943984907_item	2264051	et	4	main
teine	doc_213943984907_item	2264052	et	3	main
sellest	doc_213943984907_item	2264062	et	4	main
ei	doc_213943984907_item	2264075	et	4	main
ole	doc_213943984907_item	2264076	et	4	main
midagi	doc_213943984907_item	2264080	et	4	main
hüppas	doc_213943984907_item	2264082	et	3	main
ja	doc_213943984907_item	2264131	et	3	main
mingit	doc_213943984907_item	2264133	et	3	main
karu	doc_213943984907_item	2264139	et	4	main
järgmisena	doc_213943984907_item	2264142	et	3	main
talle	doc_213943984907_item	2264148	et	4	main
erand	doc_213943984907_item	2264166	et	3	main
läks	doc_213943984907_item	2264169	et	3	main
lõpuks	doc_213943984907_item	2264171	et	4	main
talle	doc_213943984907_item	2264178	et	4	main
poolt	doc_213943984907_item	2264180	et	4	main
väga	doc_213943984907_item	2264184	et	3	main
kutsus	doc_213943984907_item	2264188	et	4	main
andis	doc_213943984907_item	2264196	et	3	main
diskole	doc_213943984907_item	2264199	et	4	main
rebane	doc_213943984907_item	2264201	et	4	main
ette	doc_213943984907_item	2264203	et	4	main
veel	doc_213943984907_item	2264204	et	4	main
kodunt	doc_213943984907_item	2264205	et	3	main
läbi	doc_213943984907_item	2264206	et	4	main
minna	doc_213943984907_item	2264207	et	3	main
koju	doc_213943984907_item	2264211	et	3	main
tundis	doc_213943984907_item	2264213	et	3	main
et	doc_213943984907_item	2264215	et	3	main
on	doc_213943984907_item	2264217	et	4	main
kust	doc_213943984907_item	2264026	et	4	main
sellise	doc_213943984907_item	2264028	et	4	main
ning	doc_213943984907_item	2264047	et	3	main
asi	doc_213943984907_item	2264053	et	4	main
see	doc_213943984907_item	2264055	et	3	main
korter	doc_213943984907_item	2264057	et	3	main
kaheksandal	doc_213943984907_item	2264059	et	3	main
korrusel	doc_213943984907_item	2264060	et	3	main
ei	doc_213943984907_item	2264077	et	4	main
mille	doc_213943984907_item	2264091	et	3	main
oli	doc_213943984907_item	2264093	et	3	main
lasnamäe	doc_213943984907_item	2264094	et	3	main
centrum	doc_213943984907_item	2264095	et	4	main
astus	doc_213943984907_item	2264096	et	3	main
kakuke	doc_213943984907_item	2264097	et	4	main
sisse	doc_213943984907_item	2264098	et	4	main
ja	doc_213943984907_item	2264099	et	3	main
hakkas	doc_213943984907_item	2264100	et	3	main
ümbritsevat	doc_213943984907_item	2264101	et	4	main
vaatama	doc_213943984907_item	2264102	et	3	main
sel	doc_213943984907_item	2264103	et	3	main
ajal	doc_213943984907_item	2264104	et	4	main
tuli	doc_213943984907_item	2264105	et	4	main
karu	doc_213943984907_item	2264106	et	4	main
ta	doc_213943984907_item	2264107	et	4	main
juurde	doc_213943984907_item	2264108	et	4	main
ning	doc_213943984907_item	2264109	et	3	main
pakkus	doc_213943984907_item	2264110	et	3	main
abi	doc_213943984907_item	2264111	et	4	main
akki	doc_213943984907_item	2264112	et	4	main
tahad	doc_213943984907_item	2264113	et	3	main
minuga	doc_213943984907_item	2264114	et	3	main
koos	doc_213943984907_item	2264115	et	4	main
tulla	doc_213943984907_item	2264116	et	3	main
näitan	doc_213943984907_item	2264117	et	3	main
sulle	doc_213943984907_item	2264118	et	3	main
kust	doc_213943984907_item	2264119	et	4	main
siin	doc_213943984907_item	2264120	et	4	main
midagi	doc_213943984907_item	2264121	et	4	main
mees	doc_213943984907_item	2264130	et	4	main
vaja	doc_213943984907_item	2264135	et	4	main
tahtis	doc_213943984907_item	2264147	et	3	main
näidata	doc_213943984907_item	2264150	et	4	main
aga	doc_213943984907_item	2264152	et	3	main
vastas	doc_213943984907_item	2264153	et	4	main
kaval	doc_213943984907_item	2264175	et	4	main
tundus	doc_213943984907_item	2264177	et	3	main
ühelt	doc_213943984907_item	2264179	et	3	main
teiselt	doc_213943984907_item	2264182	et	4	main
meeldiv	doc_213943984907_item	2264185	et	4	main
rebane	doc_213943984907_item	2264187	et	4	main
pakkus	doc_213943984907_item	2264192	et	3	main
pileteid	doc_213943984907_item	2264194	et	3	main
tulles	doc_213943984907_item	2264212	et	4	main
saab	doc_213943984907_item	2264123	et	3	main
et	doc_213943984907_item	2264126	et	3	main
ta	doc_213943984907_item	2264127	et	4	main
on	doc_213943984907_item	2264128	et	4	main
ei	doc_213943984907_item	2264136	et	4	main
alkoholiletti	doc_213943984907_item	2264149	et	4	main
talle	doc_213943984907_item	2264154	et	4	main
et	doc_213943984907_item	2264155	et	3	main
selliseid	doc_213943984907_item	2264156	et	4	main
kohti	doc_213943984907_item	2264157	et	4	main
peab	doc_213943984907_item	2264158	et	4	main
iga	doc_213943984907_item	2264159	et	4	main
mees	doc_213943984907_item	2264160	et	4	main
ise	doc_213943984907_item	2264161	et	4	main
teadma	doc_213943984907_item	2264162	et	3	main
ole	doc_213943984907_item	2264167	et	4	main
kohtas	doc_213943984907_item	2264172	et	3	main
ohtlik	doc_213943984907_item	2264181	et	3	main
olevat	doc_213943984907_item	2264186	et	4	main
diskole	doc_213943984907_item	2264190	et	4	main
kakukesele	doc_213943984907_item	2264202	et	4	main
kakuke	doc_213943984907_item	2264209	et	4	main
kakuke	doc_213943984907_item	2264214	et	4	main
valesti	doc_213943984907_item	2264219	et	3	main
äkki	doc_213943984907_item	2264220	et	3	main
nägi	doc_213943984907_item	2264221	et	3	main
ta	doc_213943984907_item	2264228	et	4	main
juurde	doc_213943984907_item	2264229	et	4	main
hirmutatud	doc_213943984907_item	2264234	et	4	main
köögiaknast	doc_213943984907_item	2264237	et	4	main
ning	doc_213943984907_item	2264239	et	3	main
koju	doc_213943984907_item	2264242	et	3	main
oma	doc_213943984907_item	2264247	et	4	main
nad	doc_213943984907_item	2264253	et	3	main
tee	doc_213943984907_item	2264256	et	4	main
enam	doc_213943984907_item	2264257	et	4	main
aknaid	doc_213943984907_item	2264258	et	3	main
lahti	doc_213943984907_item	2264259	et	4	main
tema	doc_213943984908_item	2264284	et	4	main
õnnelikuks	doc_213943984908_item	2264295	et	3	main
oma	doc_213943984908_item	2264298	et	4	main
kodus	doc_213943984908_item	2264302	et	4	main
ka	doc_213943984908_item	2264303	et	3	main
vähe	doc_213943984908_item	2264304	et	3	main
sest	doc_213943984908_item	2264305	et	4	main
teenis	doc_213943984908_item	2264307	et	3	main
oli	doc_213943984908_item	2264312	et	3	main
tegid	doc_213943984908_item	2264319	et	4	main
tema	doc_213943984908_item	2264321	et	4	main
kasuõed	doc_213943984908_item	2264323	et	3	main
sest	doc_213943984908_item	2264327	et	4	main
nad	doc_213943984908_item	2264328	et	3	main
aga	doc_213943984908_item	2264337	et	3	main
eesmärgiks	doc_213943984908_item	2264351	et	3	main
et	doc_213943984908_item	2264361	et	3	main
solaariumis	doc_213943984908_item	2264374	et	3	main
nagu	doc_213943984908_item	2264377	et	3	main
ta	doc_213943984908_item	2264381	et	4	main
elaski	doc_213943984908_item	2264382	et	3	main
ühel	doc_213943984908_item	2264383	et	3	main
nende	doc_213943984908_item	2264386	et	4	main
üks	doc_213943984908_item	2264388	et	3	main
ja	doc_213943984908_item	2264433	et	3	main
kunstjuuksed	doc_213943984908_item	2264434	et	3	main
aga	doc_213943984908_item	2264436	et	3	main
midagi	doc_213943984908_item	2264446	et	4	main
seal	doc_213943984908_item	2264452	et	4	main
oli	doc_213943984908_item	2264453	et	3	main
noormees	doc_213943984908_item	2264454	et	4	main
kes	doc_213943984908_item	2264455	et	4	main
küsis	doc_213943984908_item	2264456	et	3	main
raamatupidajalt	doc_213943984908_item	2264457	et	3	main
ühe	doc_213943984908_item	2264458	et	4	main
see	doc_213943984908_item	2264461	et	3	main
uus	doc_213943984908_item	2264464	et	3	main
raamatukogu	doc_213943984908_item	2264472	et	4	main
välja	doc_213943984908_item	2264502	et	4	main
ainult	doc_213943984908_item	2264512	et	4	main
veel	doc_213943984908_item	2264518	et	4	main
nägi	doc_213943984908_item	2264528	et	3	main
ta	doc_213943984908_item	2264529	et	4	main
oma	doc_213943984908_item	2264531	et	4	main
ema	doc_213943984908_item	2264532	et	4	main
kes	doc_213943984908_item	2264533	et	4	main
ja	doc_213943984908_item	2264542	et	3	main
räägin	doc_213943984908_item	2264554	et	3	main
ilust	doc_213943984908_item	2264556	et	3	main
oma	doc_213943984908_item	2264563	et	4	main
aga	doc_213943984908_item	2264565	et	3	main
mis	doc_213943984908_item	2264568	et	4	main
et	doc_213943984908_item	2264582	et	3	main
kakuke	doc_213943984907_item	2264231	et	4	main
oli	doc_213943984907_item	2264232	et	3	main
vastu	doc_213943984907_item	2264249	et	3	main
ning	doc_213943984907_item	2264250	et	3	main
nüüd	doc_213943984907_item	2264251	et	4	main
elavad	doc_213943984907_item	2264252	et	4	main
koos	doc_213943984907_item	2264254	et	4	main
ega	doc_213943984907_item	2264255	et	3	main
kord	doc_213943984908_item	2264263	et	4	main
oma	doc_213943984908_item	2264265	et	4	main
isaga	doc_213943984908_item	2264266	et	3	main
tuhkatriinu	doc_213943984908_item	2264264	et	4	main
isa	doc_213943984908_item	2264267	et	4	main
oli	doc_213943984908_item	2264268	et	3	main
tal	doc_213943984908_item	2264269	et	3	main
väga	doc_213943984908_item	2264270	et	3	main
töökas	doc_213943984908_item	2264271	et	4	main
peaaegu	doc_213943984908_item	2264272	et	3	main
tööalkohoolik	doc_213943984908_item	2264273	et	3	main
ema	doc_213943984908_item	2264274	et	4	main
hukkus	doc_213943984908_item	2264275	et	3	main
kümme	doc_213943984908_item	2264276	et	3	main
aastat	doc_213943984908_item	2264277	et	3	main
suusakurordil	doc_213943984908_item	2264279	et	4	main
ta	doc_213943984907_item	2264222	et	4	main
pilguga	doc_213943984907_item	2264227	et	3	main
tulema	doc_213943984907_item	2264230	et	4	main
et	doc_213943984907_item	2264235	et	3	main
õnnelikud	doc_213943984907_item	2264244	et	3	main
elas	doc_213943984908_item	2264262	et	3	main
tütrega	doc_213943984908_item	2264286	et	3	main
ei	doc_213943984908_item	2264292	et	4	main
tuhkatriinut	doc_213943984908_item	2264294	et	3	main
tuhkatriinu	doc_213943984908_item	2264313	et	4	main
kasuemaga	doc_213943984908_item	2264282	et	3	main
aga	doc_213943984908_item	2264291	et	3	main
ta	doc_213943984908_item	2264296	et	4	main
igatses	doc_213943984908_item	2264297	et	3	main
isa	doc_213943984908_item	2264300	et	4	main
ilmus	doc_213943984908_item	2264301	et	4	main
raha	doc_213943984908_item	2264308	et	4	main
vastu	doc_213943984908_item	2264314	et	3	main
ja	doc_213943984908_item	2264316	et	3	main
tütred	doc_213943984908_item	2264318	et	3	main
üle	doc_213943984908_item	2264322	et	3	main
käinud	doc_213943984908_item	2264325	et	4	main
koolis	doc_213943984908_item	2264326	et	4	main
tahtsid	doc_213943984908_item	2264329	et	4	main
pidutseda	doc_213943984908_item	2264331	et	3	main
uusi	doc_213943984908_item	2264333	et	3	main
ta	doc_213943984908_item	2264342	et	4	main
ja	doc_213943984908_item	2264347	et	3	main
ballitantsuga	doc_213943984908_item	2264349	et	3	main
oli	doc_213943984908_item	2264357	et	3	main
ta	doc_213943984908_item	2264362	et	4	main
unustas	doc_213943984908_item	2264363	et	3	main
oma	doc_213943984908_item	2264364	et	4	main
ei	doc_213943984908_item	2264372	et	4	main
ja	doc_213943984908_item	2264375	et	3	main
juuksuris	doc_213943984908_item	2264376	et	3	main
kõik	doc_213943984908_item	2264390	et	4	main
olid	doc_213943984908_item	2264391	et	4	main
temaga	doc_213943984908_item	2264392	et	3	main
ei	doc_213943984908_item	2264324	et	4	main
kleite	doc_213943984908_item	2264334	et	3	main
oli	doc_213943984908_item	2264338	et	3	main
raamatuid	doc_213943984908_item	2264344	et	3	main
võõrkeeli	doc_213943984908_item	2264346	et	3	main
tegeles	doc_213943984908_item	2264348	et	3	main
tema	doc_213943984908_item	2264350	et	4	main
saada	doc_213943984908_item	2264353	et	4	main
kuulsaks	doc_213943984908_item	2264354	et	4	main
tantsijaks	doc_213943984908_item	2264355	et	4	main
tuhkatriinu	doc_213943984908_item	2264356	et	4	main
välimusest	doc_213943984908_item	2264365	et	4	main
hambabrekette	doc_213943984908_item	2264371	et	4	main
õed	doc_213943984908_item	2264379	et	3	main
kolis	doc_213943984908_item	2264385	et	4	main
linna	doc_213943984908_item	2264387	et	4	main
noormees	doc_213943984908_item	2264389	et	4	main
huvitatud	doc_213943984908_item	2264394	et	4	main
seetõttu	doc_213943984908_item	2264395	et	3	main
korraldas	doc_213943984908_item	2264396	et	3	main
tuhkatriinu	doc_213943984908_item	2264397	et	4	main
nende	doc_213943984908_item	2264398	et	4	main
majas	doc_213943984908_item	2264399	et	3	main
balli	doc_213943984908_item	2264400	et	4	main
kuhu	doc_213943984908_item	2264401	et	3	main
kutsus	doc_213943984908_item	2264402	et	4	main
kõiki	doc_213943984908_item	2264403	et	4	main
elanikke	doc_213943984908_item	2264404	et	3	main
ja	doc_213943984908_item	2264405	et	3	main
ka	doc_213943984908_item	2264407	et	3	main
seda	doc_213943984908_item	2264408	et	3	main
noormehe	doc_213943984908_item	2264409	et	3	main
loomulikult	doc_213943984908_item	2264406	et	4	main
kasuõed	doc_213943984908_item	2264410	et	3	main
ootasid	doc_213943984908_item	2264411	et	4	main
seda	doc_213943984908_item	2264412	et	3	main
hetke	doc_213943984908_item	2264413	et	4	main
suure	doc_213943984908_item	2264414	et	3	main
ootamatusega	doc_213943984908_item	2264415	et	4	main
ja	doc_213943984908_item	2264416	et	3	main
ettevalmistusid	doc_213943984908_item	2264417	et	4	main
hoolega	doc_213943984908_item	2264418	et	3	main
üks	doc_213943984908_item	2264419	et	3	main
tegi	doc_213943984908_item	2264420	et	4	main
endale	doc_213943984908_item	2264421	et	4	main
salongis	doc_213943984908_item	2264428	et	3	main
tuhkatriinu	doc_213943984908_item	2264435	et	4	main
luges	doc_213943984908_item	2264437	et	3	main
ajal	doc_213943984908_item	2264439	et	4	main
detektiivromaani	doc_213943984908_item	2264441	et	4	main
ja	doc_213943984908_item	2264442	et	3	main
teadnud	doc_213943984908_item	2264444	et	4	main
ta	doc_213943984908_item	2264449	et	4	main
ja	doc_213943984908_item	2264451	et	3	main
erinev	doc_213943984908_item	2264341	et	4	main
õppimisse	doc_213943984908_item	2264359	et	4	main
hoolitseda	doc_213943984908_item	2264366	et	3	main
kandis	doc_213943984908_item	2264368	et	4	main
ja	doc_213943984908_item	2264370	et	3	main
tema	doc_213943984908_item	2264378	et	4	main
nii	doc_213943984908_item	2264380	et	3	main
suvel	doc_213943984908_item	2264384	et	3	main
tutvumises	doc_213943984908_item	2264393	et	4	main
selja	doc_213943984908_item	2264422	et	3	main
peal	doc_213943984908_item	2264423	et	4	main
tol	doc_213943984908_item	2264438	et	3	main
ei	doc_213943984908_item	2264443	et	4	main
läks	doc_213943984908_item	2264448	et	3	main
kahjuks	doc_213943984908_item	2264460	et	4	main
mõtles	doc_213943984908_item	2264503	et	3	main
ära	doc_213943984908_item	2264507	et	4	main
päevast	doc_213943984908_item	2264509	et	4	main
mõtles	doc_213943984908_item	2264510	et	3	main
tema	doc_213943984908_item	2264367	et	4	main
prille	doc_213943984908_item	2264369	et	3	main
käinud	doc_213943984908_item	2264373	et	4	main
käis	doc_213943984908_item	2264427	et	4	main
et	doc_213943984908_item	2264429	et	3	main
teha	doc_213943984908_item	2264430	et	3	main
kunstrüpsmed	doc_213943984908_item	2264432	et	4	main
ükskord	doc_213943984908_item	2264447	et	3	main
raamatukokku	doc_213943984908_item	2264450	et	4	main
väga	doc_213943984908_item	2264463	et	3	main
ja	doc_213943984908_item	2264465	et	3	main
meil	doc_213943984908_item	2264466	et	4	main
ole	doc_213943984908_item	2264468	et	4	main
seda	doc_213943984908_item	2264469	et	3	main
ja	doc_213943984908_item	2264505	et	3	main
ta	doc_213943984908_item	2264515	et	4	main
käis	doc_213943984908_item	2264517	et	4	main
ühel	doc_213943984908_item	2264526	et	3	main
öösel	doc_213943984908_item	2264527	et	4	main
ütles	doc_213943984908_item	2264534	et	3	main
talle	doc_213943984908_item	2264535	et	4	main
mul	doc_213943984908_item	2264539	et	3	main
tark	doc_213943984908_item	2264541	et	3	main
lahke	doc_213943984908_item	2264543	et	4	main
ja	doc_213943984908_item	2264545	et	3	main
on	doc_213943984908_item	2264558	et	4	main
kui	doc_213943984908_item	2264560	et	3	main
mitte	doc_213943984908_item	2264566	et	3	main
tuhkatriinu	doc_213943984908_item	2264574	et	4	main
ja	doc_213943984908_item	2264576	et	3	main
elasid	doc_213943984908_item	2264621	et	4	main
ühel	doc_213943984908_item	2264625	et	3	main
korrusel	doc_213943984909_item	2264636	et	3	main
paar	doc_213943984909_item	2264638	et	3	main
arvutit	doc_213943984909_item	2264642	et	3	main
mobiiltelefoni	doc_213943984909_item	2264646	et	4	main
olnud	doc_213943984909_item	2264649	et	4	main
peale	doc_213943984909_item	2264653	et	4	main
mikrolaineahi	doc_213943984909_item	2264656	et	3	main
ühel	doc_213943984909_item	2264662	et	3	main
plahvatused	doc_213943984909_item	2264673	et	4	main
nüüd	doc_213943984909_item	2264678	et	4	main
lainete	doc_213943984909_item	2264680	et	3	main
oht	doc_213943984909_item	2264682	et	3	main
vanainimesed	doc_213943984909_item	2264684	et	3	main
ei	doc_213943984909_item	2264686	et	4	main
pööranud	doc_213943984909_item	2264687	et	4	main
nad	doc_213943984909_item	2264688	et	3	main
sellele	doc_213943984909_item	2264689	et	4	main
mikrolaineahjust	doc_213943984909_item	2264699	et	3	main
see	doc_213943984909_item	2264706	et	3	main
tatöveeringut	doc_213943984908_item	2264424	et	4	main
ja	doc_213943984908_item	2264425	et	3	main
teine	doc_213943984908_item	2264426	et	3	main
endale	doc_213943984908_item	2264431	et	4	main
põneva	doc_213943984908_item	2264440	et	3	main
sellest	doc_213943984908_item	2264445	et	4	main
on	doc_213943984908_item	2264462	et	4	main
ei	doc_213943984908_item	2264467	et	4	main
luges	doc_213943984908_item	2264475	et	3	main
juba	doc_213943984908_item	2264476	et	3	main
tuhkatriinu	doc_213943984908_item	2264474	et	4	main
selle	doc_213943984908_item	2264477	et	4	main
raamatu	doc_213943984908_item	2264478	et	4	main
läbi	doc_213943984908_item	2264479	et	4	main
ma	doc_213943984908_item	2264480	et	3	main
võin	doc_213943984908_item	2264481	et	3	main
teile	doc_213943984908_item	2264482	et	4	main
laenata	doc_213943984908_item	2264483	et	4	main
ütles	doc_213943984908_item	2264484	et	3	main
tema	doc_213943984908_item	2264485	et	4	main
ja	doc_213943984908_item	2264486	et	3	main
punastas	doc_213943984908_item	2264487	et	3	main
see	doc_213943984908_item	2264488	et	3	main
noormes	doc_213943984908_item	2264489	et	4	main
vaatas	doc_213943984908_item	2264490	et	3	main
temale	doc_213943984908_item	2264491	et	3	main
otse	doc_213943984908_item	2264492	et	4	main
silma	doc_213943984908_item	2264493	et	4	main
oli	doc_213943984908_item	2264495	et	3	main
ja	doc_213943984908_item	2264494	et	3	main
imeilus	doc_213943984908_item	2264496	et	4	main
isand	doc_213943984908_item	2264497	et	3	main
ma	doc_213943984908_item	2264498	et	3	main
näen	doc_213943984908_item	2264499	et	3	main
nii	doc_213943984908_item	2264500	et	3	main
raamatu	doc_213943984908_item	2264459	et	4	main
veel	doc_213943984908_item	2264470	et	4	main
lausus	doc_213943984908_item	2264471	et	4	main
töötaja	doc_213943984908_item	2264473	et	4	main
jube	doc_213943984908_item	2264501	et	4	main
tuhkatriinu	doc_213943984908_item	2264504	et	4	main
ta	doc_213943984908_item	2264511	et	4	main
isegi	doc_213943984908_item	2264516	et	4	main
korda	doc_213943984908_item	2264520	et	4	main
raamatukogus	doc_213943984908_item	2264521	et	4	main
ei	doc_213943984908_item	2264523	et	4	main
tütreke	doc_213943984908_item	2264536	et	4	main
peale	doc_213943984908_item	2264546	et	4	main
oled	doc_213943984908_item	2264548	et	3	main
väga	doc_213943984908_item	2264550	et	3	main
aga	doc_213943984908_item	2264552	et	3	main
sisemisest	doc_213943984908_item	2264555	et	3	main
tähtsam	doc_213943984908_item	2264559	et	4	main
süda	doc_213943984908_item	2264564	et	3	main
teised	doc_213943984908_item	2264569	et	4	main
räägivad	doc_213943984908_item	2264570	et	3	main
järgmisel	doc_213943984908_item	2264571	et	3	main
hommikul	doc_213943984908_item	2264572	et	3	main
läks	doc_213943984908_item	2264573	et	3	main
ilusalongi	doc_213943984908_item	2264575	et	4	main
riidepoodi	doc_213943984908_item	2264578	et	4	main
mõistas	doc_213943984908_item	2264580	et	4	main
ja	doc_213943984908_item	2264623	et	3	main
päeval	doc_213943984908_item	2264626	et	3	main
brilliantmunad	doc_213943984909_item	2264629	et	4	main
tavalises	doc_213943984909_item	2264632	et	4	main
paneelmajas	doc_213943984909_item	2264634	et	3	main
elasid	doc_213943984909_item	2264639	et	4	main
ainukeseks	doc_213943984909_item	2264650	et	4	main
oli	doc_213943984909_item	2264659	et	3	main
nad	doc_213943984909_item	2264665	et	3	main
öeldi	doc_213943984909_item	2264668	et	3	main
toimusid	doc_213943984909_item	2264671	et	4	main
mille	doc_213943984909_item	2264674	et	3	main
on	doc_213943984909_item	2264676	et	4	main
atakki	doc_213943984909_item	2264681	et	4	main
ühel	doc_213943984909_item	2264694	et	3	main
hommikul	doc_213943984909_item	2264695	et	3	main
avastas	doc_213943984909_item	2264696	et	3	main
oma	doc_213943984909_item	2264698	et	4	main
kuldse	doc_213943984909_item	2264700	et	3	main
ta	doc_213943984909_item	2264704	et	4	main
on	doc_213943984909_item	2264707	et	4	main
üllatus	doc_213943984909_item	2264725	et	4	main
see	doc_213943984909_item	2264726	et	3	main
me	doc_213943984909_item	2264742	et	4	main
kodulaenu	doc_213943984909_item	2264745	et	4	main
tuppa	doc_213943984909_item	2264749	et	3	main
munaga	doc_213943984909_item	2264750	et	3	main
nutt	doc_213943984909_item	2264778	et	3	main
hääled	doc_213943984909_item	2264786	et	3	main
jooksis	doc_213943984909_item	2264794	et	4	main
kööki	doc_213943984909_item	2264795	et	4	main
et	doc_213943984909_item	2264798	et	3	main
peal	doc_213943984909_item	2264800	et	4	main
oli	doc_213943984909_item	2264801	et	3	main
teile	doc_213943984909_item	2264809	et	4	main
kõik	doc_213943984909_item	2264832	et	4	main
essee	doc_213943984910_item	2264837	et	4	main
mõtlen	doc_213943984910_item	2264843	et	3	main
on	doc_213943984910_item	2264849	et	4	main
ma	doc_213943984910_item	2264853	et	3	main
mõtted	doc_213943984910_item	2264863	et	3	main
suunas	doc_213943984910_item	2264867	et	4	main
ära	doc_213943984910_item	2264872	et	4	main
äkki	doc_213943984910_item	2264873	et	3	main
vastas	doc_213943984910_item	2264876	et	4	main
natuke	doc_213943984910_item	2264883	et	4	main
olnudki	doc_213943984910_item	2264922	et	4	main
vaja	doc_213943984910_item	2264923	et	4	main
et	doc_213943984910_item	2264924	et	3	main
vaikselt	doc_213943984910_item	2264942	et	4	main
toimuvat	doc_213943984910_item	2264946	et	4	main
paigast	doc_213943984910_item	2264966	et	4	main
liikunud	doc_213943984910_item	2264967	et	4	main
see	doc_213943984910_item	2264974	et	3	main
läks	doc_213943984910_item	2264975	et	3	main
jooksis	doc_213943984908_item	2264506	et	4	main
sellest	doc_213943984908_item	2264508	et	4	main
selle	doc_213943984908_item	2264513	et	4	main
noormehele	doc_213943984908_item	2264514	et	3	main
paar	doc_213943984908_item	2264519	et	3	main
aga	doc_213943984908_item	2264522	et	3	main
kohtunud	doc_213943984908_item	2264524	et	4	main
temaga	doc_213943984908_item	2264525	et	3	main
oled	doc_213943984908_item	2264538	et	3	main
väga	doc_213943984908_item	2264540	et	3	main
selle	doc_213943984908_item	2264547	et	4	main
sa	doc_213943984908_item	2264549	et	3	main
see	doc_213943984908_item	2264557	et	3	main
kuula	doc_213943984908_item	2264562	et	4	main
seda	doc_213943984908_item	2264567	et	3	main
pärast	doc_213943984908_item	2264577	et	4	main
ta	doc_213943984908_item	2264579	et	4	main
seda	doc_213943984908_item	2264581	et	3	main
sisemine	doc_213943984908_item	2264583	et	3	main
kaua	doc_213943984908_item	2264622	et	3	main
essee	doc_213943984909_item	2264627	et	4	main
elas	doc_213943984909_item	2264630	et	3	main
teisel	doc_213943984909_item	2264635	et	4	main
vana	doc_213943984909_item	2264637	et	4	main
dvd	doc_213943984909_item	2264643	et	4	main
playerit	doc_213943984909_item	2264644	et	4	main
ega	doc_213943984909_item	2264645	et	3	main
teleri	doc_213943984909_item	2264654	et	3	main
oli	doc_213943984909_item	2264655	et	3	main
peal	doc_213943984909_item	2264658	et	4	main
uudiseid	doc_213943984909_item	2264666	et	3	main
et	doc_213943984909_item	2264669	et	3	main
ikka	doc_213943984909_item	2264685	et	4	main
erilist	doc_213943984909_item	2264691	et	4	main
alguses	doc_213943984909_item	2264702	et	4	main
tema	doc_213943984909_item	2264708	et	4	main
ning	doc_213943984909_item	2264722	et	3	main
hakkas	doc_213943984909_item	2264727	et	3	main
brilliandimoodi	doc_213943984909_item	2264728	et	4	main
ta	doc_213943984909_item	2264730	et	4	main
seda	doc_213943984909_item	2264732	et	3	main
nüüd	doc_213943984909_item	2264734	et	4	main
meie	doc_213943984909_item	2264736	et	4	main
mured	doc_213943984909_item	2264737	et	3	main
kuidas	doc_213943984909_item	2264764	et	3	main
nad	doc_213943984909_item	2264766	et	3	main
süüdistas	doc_213943984909_item	2264769	et	3	main
naist	doc_213943984909_item	2264770	et	3	main
ja	doc_213943984909_item	2264779	et	3	main
see	doc_213943984909_item	2264788	et	3	main
ei	doc_213943984909_item	2264789	et	4	main
paar	doc_213943984909_item	2264793	et	3	main
nüüd	doc_213943984909_item	2264802	et	4	main
kanapea	doc_213943984909_item	2264803	et	4	main
ärge	doc_213943984909_item	2264804	et	3	main
munen	doc_213943984909_item	2264806	et	3	main
veel	doc_213943984909_item	2264808	et	4	main
mune	doc_213943984909_item	2264810	et	4	main
järgmisel	doc_213943984909_item	2264811	et	3	main
juba	doc_213943984909_item	2264814	et	3	main
loomingust	doc_213943984909_item	2264818	et	3	main
ahi	doc_213943984909_item	2264820	et	4	main
paar	doc_213943984909_item	2264822	et	3	main
nii	doc_213943984909_item	2264824	et	3	main
majanduslikud	doc_213943984909_item	2264834	et	3	main
linnani	doc_213943984910_item	2264851	et	3	main
elama	doc_213943984910_item	2264855	et	3	main
ikka	doc_213943984910_item	2264864	et	4	main
minu	doc_213943984910_item	2264875	et	3	main
eemale	doc_213943984910_item	2264884	et	3	main
istunud	doc_213943984910_item	2264886	et	4	main
anda	doc_213943984910_item	2264929	et	3	main
ka	doc_213943984910_item	2264931	et	3	main
paar	doc_213943984910_item	2264933	et	3	main
arutanud	doc_213943984910_item	2264935	et	4	main
probleeme	doc_213943984910_item	2264937	et	3	main
ega	doc_213943984910_item	2264938	et	3	main
nalja	doc_213943984910_item	2264940	et	4	main
nende	doc_213943984910_item	2264944	et	4	main
välja	doc_213943984910_item	2264950	et	4	main
pagasiriiulist	doc_213943984910_item	2264969	et	4	main
kohver	doc_213943984910_item	2264973	et	3	main
unes	doc_213943984908_item	2264530	et	3	main
sa	doc_213943984908_item	2264537	et	3	main
laps	doc_213943984908_item	2264544	et	4	main
ilus	doc_213943984908_item	2264551	et	4	main
ma	doc_213943984908_item	2264553	et	3	main
välimus	doc_213943984908_item	2264561	et	3	main
ilu	doc_213943984908_item	2264584	et	4	main
on	doc_213943984908_item	2264585	et	4	main
tähtis	doc_213943984908_item	2264586	et	4	main
kuid	doc_213943984908_item	2264587	et	4	main
ta	doc_213943984908_item	2264588	et	4	main
teadis	doc_213943984908_item	2264589	et	4	main
et	doc_213943984908_item	2264590	et	3	main
kahjuks	doc_213943984908_item	2264591	et	4	main
arvavad	doc_213943984908_item	2264592	et	4	main
inimesed	doc_213943984908_item	2264593	et	3	main
alguses	doc_213943984908_item	2264594	et	4	main
ainult	doc_213943984908_item	2264595	et	4	main
välimuse	doc_213943984908_item	2264596	et	3	main
järgi	doc_213943984908_item	2264597	et	4	main
kui	doc_213943984908_item	2264598	et	3	main
kõik	doc_213943984908_item	2264599	et	4	main
protseduurid	doc_213943984908_item	2264600	et	3	main
olid	doc_213943984908_item	2264601	et	4	main
tehtud	doc_213943984908_item	2264602	et	4	main
töötajad	doc_213943984908_item	2264604	et	4	main
ilusalongi	doc_213943984908_item	2264603	et	4	main
imestasid	doc_213943984908_item	2264605	et	4	main
kaunis	doc_213943984908_item	2264607	et	4	main
kui	doc_213943984908_item	2264606	et	3	main
tuhkatriinu	doc_213943984908_item	2264608	et	4	main
oli	doc_213943984908_item	2264609	et	3	main
ta	doc_213943984908_item	2264610	et	4	main
tuli	doc_213943984908_item	2264611	et	4	main
balli	doc_213943984908_item	2264612	et	4	main
ja	doc_213943984908_item	2264613	et	3	main
noormees	doc_213943984908_item	2264614	et	4	main
armus	doc_213943984908_item	2264615	et	4	main
temasse	doc_213943984908_item	2264616	et	3	main
esimesest	doc_213943984908_item	2264617	et	3	main
pilgust	doc_213943984908_item	2264618	et	4	main
ja	doc_213943984908_item	2264619	et	3	main
nad	doc_213943984908_item	2264620	et	3	main
neil	doc_213943984909_item	2264647	et	4	main
omandiks	doc_213943984909_item	2264652	et	3	main
surid	doc_213943984908_item	2264624	et	4	main
faberge	doc_213943984909_item	2264628	et	4	main
kord	doc_213943984909_item	2264631	et	4	main
lasnamäe	doc_213943984909_item	2264633	et	3	main
nad	doc_213943984909_item	2264640	et	3	main
vaeselt	doc_213943984909_item	2264641	et	4	main
ei	doc_213943984909_item	2264648	et	4	main
vääriliseks	doc_213943984909_item	2264651	et	4	main
mille	doc_213943984909_item	2264657	et	3	main
logo	doc_213943984909_item	2264661	et	4	main
õhtul	doc_213943984909_item	2264663	et	3	main
kus	doc_213943984909_item	2264667	et	3	main
suured	doc_213943984909_item	2264672	et	3	main
tõttu	doc_213943984909_item	2264675	et	4	main
maal	doc_213943984909_item	2264677	et	4	main
kuid	doc_213943984909_item	2264693	et	4	main
et	doc_213943984909_item	2264705	et	3	main
lapselaste	doc_213943984909_item	2264709	et	4	main
nali	doc_213943984909_item	2264710	et	3	main
nad	doc_213943984909_item	2264711	et	3	main
käisid	doc_213943984909_item	2264712	et	4	main
just	doc_213943984909_item	2264713	et	3	main
päev	doc_213943984909_item	2264714	et	3	main
tagasi	doc_213943984909_item	2264715	et	3	main
külas	doc_213943984909_item	2264716	et	3	main
perenaine	doc_213943984909_item	2264717	et	3	main
hõõrus	doc_213943984909_item	2264718	et	4	main
seda	doc_213943984909_item	2264719	et	3	main
kolm	doc_213943984909_item	2264720	et	3	main
üllatus	doc_213943984909_item	2264723	et	4	main
mis	doc_213943984909_item	2264724	et	4	main
silmitses	doc_213943984909_item	2264731	et	4	main
huviga	doc_213943984909_item	2264733	et	3	main
ta	doc_213943984909_item	2264741	et	4	main
ta	doc_213943984909_item	2264747	et	4	main
jooksis	doc_213943984909_item	2264748	et	4	main
hakkasid	doc_213943984909_item	2264765	et	4	main
selles	doc_213943984909_item	2264771	et	4	main
ja	doc_213943984909_item	2264773	et	3	main
kui	doc_213943984909_item	2264781	et	3	main
kostsid	doc_213943984909_item	2264783	et	4	main
vana	doc_213943984909_item	2264792	et	4	main
vaielge	doc_213943984909_item	2264805	et	3	main
ma	doc_213943984909_item	2264807	et	3	main
korral	doc_213943984909_item	2264812	et	4	main
aga	doc_213943984909_item	2264813	et	3	main
oli	doc_213943984909_item	2264823	et	3	main
õnnelik	doc_213943984909_item	2264825	et	3	main
tantsu	doc_213943984909_item	2264828	et	4	main
lööma	doc_213943984909_item	2264829	et	4	main
nüüdsest	doc_213943984909_item	2264830	et	3	main
nende	doc_213943984909_item	2264833	et	4	main
lahendatud	doc_213943984909_item	2264836	et	4	main
vaadates	doc_213943984910_item	2264840	et	3	main
aknast	doc_213943984910_item	2264841	et	4	main
ma	doc_213943984910_item	2264844	et	3	main
kui	doc_213943984910_item	2264846	et	3	main
maa	doc_213943984910_item	2264848	et	4	main
nüüdsest	doc_213943984910_item	2264854	et	3	main
kuid	doc_213943984910_item	2264862	et	4	main
köhiseb	doc_213943984910_item	2264874	et	4	main
kes	doc_213943984910_item	2264879	et	4	main
naisest	doc_213943984910_item	2264882	et	3	main
kõige	doc_213943984910_item	2264925	et	4	main
mõtteid	doc_213943984910_item	2264927	et	3	main
edasi	doc_213943984910_item	2264928	et	3	main
vaid	doc_213943984910_item	2264941	et	3	main
silmitsesid	doc_213943984910_item	2264943	et	4	main
ümber	doc_213943984910_item	2264945	et	3	main
järel	doc_213943984910_item	2264954	et	4	main
kana	doc_213943984909_item	2264660	et	4	main
vaatasid	doc_213943984909_item	2264664	et	4	main
päikesel	doc_213943984909_item	2264670	et	4	main
radioaktiivsete	doc_213943984909_item	2264679	et	4	main
nagu	doc_213943984909_item	2264683	et	3	main
teatele	doc_213943984909_item	2264690	et	3	main
tähelepanu	doc_213943984909_item	2264692	et	4	main
perenaine	doc_213943984909_item	2264697	et	3	main
muna	doc_213943984909_item	2264701	et	4	main
arvas	doc_213943984909_item	2264703	et	3	main
korda	doc_213943984909_item	2264721	et	4	main
särama	doc_213943984909_item	2264729	et	3	main
on	doc_213943984909_item	2264735	et	4	main
lõpule	doc_213943984909_item	2264738	et	3	main
saanud	doc_213943984909_item	2264739	et	4	main
hüüatas	doc_213943984909_item	2264740	et	3	main
nüüd	doc_213943984909_item	2264744	et	4	main
tagastada	doc_213943984909_item	2264746	et	3	main
et	doc_213943984909_item	2264751	et	3	main
vanamees	doc_213943984909_item	2264768	et	4	main
ei	doc_213943984909_item	2264775	et	4	main
äkki	doc_213943984909_item	2264782	et	3	main
nägi	doc_213943984909_item	2264797	et	3	main
mikrolaineahju	doc_213943984909_item	2264799	et	4	main
midagi	doc_213943984909_item	2264815	et	4	main
hilisemast	doc_213943984909_item	2264817	et	4	main
vana	doc_213943984909_item	2264821	et	4	main
et	doc_213943984909_item	2264826	et	3	main
mured	doc_213943984909_item	2264835	et	3	main
kupees	doc_213943984910_item	2264839	et	3	main
välja	doc_213943984910_item	2264842	et	4	main
sellest	doc_213943984910_item	2264845	et	4	main
selle	doc_213943984910_item	2264850	et	4	main
kuhu	doc_213943984910_item	2264852	et	3	main
rongis	doc_213943984910_item	2264857	et	4	main
kostav	doc_213943984910_item	2264858	et	4	main
mürin	doc_213943984910_item	2264859	et	3	main
aina	doc_213943984910_item	2264860	et	4	main
uinatab	doc_213943984910_item	2264861	et	4	main
liiguvad	doc_213943984910_item	2264865	et	3	main
samas	doc_213943984910_item	2264866	et	4	main
ei	doc_213943984910_item	2264868	et	4	main
lase	doc_213943984910_item	2264869	et	4	main
sihtmärki	doc_213943984910_item	2264870	et	4	main
silmast	doc_213943984910_item	2264871	et	4	main
istuv	doc_213943984910_item	2264877	et	4	main
on	doc_213943984910_item	2264885	et	4	main
et	doc_213943984910_item	2264887	et	3	main
saame	doc_213943984909_item	2264743	et	4	main
näidata	doc_213943984909_item	2264752	et	4	main
seda	doc_213943984909_item	2264753	et	3	main
mehele	doc_213943984909_item	2264754	et	3	main
kuid	doc_213943984909_item	2264755	et	4	main
komistas	doc_213943984909_item	2264756	et	3	main
muna	doc_213943984909_item	2264757	et	4	main
kukkus	doc_213943984909_item	2264758	et	3	main
imepisikesed	doc_213943984909_item	2264759	et	4	main
killukesed	doc_213943984909_item	2264760	et	4	main
olid	doc_213943984909_item	2264761	et	4	main
põrandal	doc_213943984909_item	2264762	et	3	main
laiali	doc_213943984909_item	2264763	et	3	main
nutma	doc_213943984909_item	2264767	et	3	main
patus	doc_213943984909_item	2264772	et	3	main
kuidagi	doc_213943984909_item	2264774	et	3	main
lõpenud	doc_213943984909_item	2264776	et	4	main
see	doc_213943984909_item	2264777	et	3	main
karjumine	doc_213943984909_item	2264780	et	4	main
köögist	doc_213943984909_item	2264784	et	3	main
imelikud	doc_213943984909_item	2264785	et	3	main
kaagutamine	doc_213943984909_item	2264787	et	4	main
ole	doc_213943984909_item	2264790	et	4	main
võimalik	doc_213943984909_item	2264791	et	3	main
ja	doc_213943984909_item	2264796	et	3	main
faberge	doc_213943984909_item	2264816	et	4	main
ütles	doc_213943984909_item	2264819	et	3	main
hakkasid	doc_213943984909_item	2264827	et	4	main
olid	doc_213943984909_item	2264831	et	4	main
juhtum	doc_213943984910_item	2264838	et	3	main
pikk	doc_213943984910_item	2264847	et	4	main
asun	doc_213943984910_item	2264856	et	3	main
mees	doc_213943984910_item	2264878	et	4	main
oma	doc_213943984910_item	2264880	et	4	main
kõrvalistuvast	doc_213943984910_item	2264881	et	3	main
näha	doc_213943984910_item	2264888	et	3	main
mis	doc_213943984910_item	2264889	et	4	main
aknast	doc_213943984910_item	2264890	et	4	main
väljaspool	doc_213943984910_item	2264891	et	3	main
toimub	doc_213943984910_item	2264892	et	3	main
see	doc_213943984910_item	2264893	et	3	main
paar	doc_213943984910_item	2264894	et	3	main
meenutas	doc_213943984910_item	2264895	et	3	main
mulle	doc_213943984910_item	2264896	et	4	main
mu	doc_213943984910_item	2264897	et	3	main
vanemaid	doc_213943984910_item	2264898	et	4	main
kunagi	doc_213943984910_item	2264900	et	3	main
reisisid	doc_213943984910_item	2264901	et	4	main
koos	doc_213943984910_item	2264902	et	4	main
kes	doc_213943984910_item	2264899	et	4	main
siberisse	doc_213943984910_item	2264903	et	4	main
et	doc_213943984910_item	2264904	et	3	main
uurida	doc_213943984910_item	2264905	et	3	main
sealsetes	doc_213943984910_item	2264906	et	4	main
metsades	doc_213943984910_item	2264907	et	3	main
kasvavaid	doc_213943984910_item	2264908	et	4	main
puid	doc_213943984910_item	2264909	et	3	main
nemad	doc_213943984910_item	2264910	et	3	main
ei	doc_213943984910_item	2264911	et	4	main
rääkinud	doc_213943984910_item	2264912	et	4	main
üksteisega	doc_213943984910_item	2264913	et	3	main
palju	doc_213943984910_item	2264914	et	4	main
kuid	doc_213943984910_item	2264915	et	4	main
silmadest	doc_213943984910_item	2264916	et	3	main
võis	doc_213943984910_item	2264917	et	4	main
lugeda	doc_213943984910_item	2264918	et	3	main
et	doc_213943984910_item	2264919	et	3	main
sõnu	doc_213943984910_item	2264920	et	4	main
ei	doc_213943984910_item	2264921	et	4	main
tähtsamaid	doc_213943984910_item	2264926	et	4	main
nii	doc_213943984910_item	2264930	et	3	main
see	doc_213943984910_item	2264932	et	3	main
viis	doc_213943984910_item	2264949	et	4	main
rongipidurite	doc_213943984910_item	2264951	et	3	main
mille	doc_213943984910_item	2264953	et	3	main
ja	doc_213943984910_item	2264968	et	3	main
kukkus	doc_213943984910_item	2264970	et	3	main
ei	doc_213943984910_item	2264934	et	4	main
oma	doc_213943984910_item	2264936	et	4	main
teinud	doc_213943984910_item	2264939	et	4	main
mu	doc_213943984910_item	2264947	et	3	main
mõttetest	doc_213943984910_item	2264948	et	3	main
kisa	doc_213943984910_item	2264952	et	4	main
rong	doc_213943984910_item	2264955	et	3	main
seisma	doc_213943984910_item	2264956	et	3	main
jäi	doc_213943984910_item	2264957	et	3	main
nii	doc_213943984910_item	2264958	et	3	main
hoogsa	doc_213943984910_item	2264959	et	3	main
pidurdamise	doc_213943984910_item	2264960	et	4	main
järel	doc_213943984910_item	2264961	et	4	main
olid	doc_213943984910_item	2264962	et	4	main
paljud	doc_213943984910_item	2264963	et	3	main
asjad	doc_213943984910_item	2264964	et	3	main
oma	doc_213943984910_item	2264965	et	4	main
põrandale	doc_213943984910_item	2264971	et	3	main
uurima	doc_213943984910_item	2264988	et	3	main
ei	doc_213943984910_item	2264992	et	4	main
hammer	doc_213943984910_item	2264996	et	4	main
kruuvikeerajad	doc_213943984910_item	2264997	et	4	main
väikestes	doc_213943984910_item	2265001	et	4	main
ja	doc_213943984910_item	2265003	et	3	main
terroristid	doc_213943984910_item	2265005	et	3	main
naine	doc_213943984910_item	2265007	et	3	main
see	doc_213943984910_item	2265011	et	3	main
olla	doc_213943984910_item	2265013	et	3	main
kellegi	doc_213943984910_item	2265018	et	4	main
oma	doc_213943984910_item	2265019	et	4	main
kes	doc_213943984910_item	2265020	et	4	main
pruun	doc_213943984910_item	2264972	et	3	main
kuna	doc_213943984910_item	2264977	et	3	main
selle	doc_213943984910_item	2264978	et	4	main
jõud	doc_213943984910_item	2264980	et	4	main
suur	doc_213943984910_item	2264982	et	3	main
sõitjad	doc_213943984910_item	2264984	et	4	main
kohvrisisu	doc_213943984910_item	2264986	et	4	main
saak	doc_213943984910_item	2264995	et	3	main
mingi	doc_213943984910_item	2264998	et	4	main
imelik	doc_213943984910_item	2264999	et	3	main
miks	doc_213943984910_item	2265008	et	4	main
lukkseppa	doc_213943984910_item	2265015	et	4	main
on	doc_213943984910_item	2265021	et	4	main
siin	doc_213943984910_item	2265023	et	4	main
mees	doc_213943984910_item	2265027	et	4	main
jätnud	doc_213943984910_item	2265031	et	4	main
abi	doc_213943984910_item	2265040	et	4	main
arvates	doc_213943984910_item	2265043	et	4	main
suurustanud	doc_213943984910_item	2265047	et	4	main
ja	doc_213943984910_item	2265055	et	3	main
hakkasin	doc_213943984910_item	2265057	et	3	main
ettekujutama	doc_213943984910_item	2265061	et	4	main
küll	doc_213943984910_item	2265064	et	4	main
lahti	doc_213943984910_item	2264976	et	4	main
seal	doc_213943984910_item	2264990	et	4	main
terroristid	doc_213943984910_item	2265010	et	3	main
tema	doc_213943984910_item	2265026	et	4	main
naine	doc_213943984910_item	2265029	et	3	main
ta	doc_213943984910_item	2265035	et	4	main
ja	doc_213943984910_item	2265036	et	3	main
kupeest	doc_213943984910_item	2265038	et	4	main
välja	doc_213943984910_item	2265039	et	4	main
otsima	doc_213943984910_item	2265041	et	4	main
natuke	doc_213943984910_item	2265046	et	4	main
kuid	doc_213943984910_item	2265049	et	4	main
ka	doc_213943984910_item	2265052	et	3	main
mis	doc_213943984910_item	2265062	et	4	main
kui	doc_213943984910_item	2265066	et	3	main
teha	doc_213943984910_item	2265069	et	3	main
äkki	doc_213943984910_item	2265071	et	3	main
kohver	doc_213943984910_item	2265082	et	3	main
ma	doc_213943984910_item	2265084	et	3	main
oli	doc_213943984910_item	2265121	et	3	main
toibudes	doc_213943984910_item	2265139	et	3	main
et	doc_213943984910_item	2265143	et	3	main
tänulik	doc_213943984910_item	2265155	et	3	main
et	doc_213943984910_item	2265157	et	3	main
в	doc_213943984912_item	2265292	et	2	main
13	doc_213943984912_item	2265295	et	2	main
концерт	doc_213943984912_item	2265300	et	2	main
россии	doc_213943984912_item	2265305	et	2	main
бортнянского	doc_213943984912_item	2265310	et	2	main
гречанинова	doc_213943984912_item	2265314	et	2	main
ансамбль	doc_213943984912_item	2265319	et	2	main
из	doc_213943984912_item	2265322	et	2	main
консерватории	doc_213943984912_item	2265327	et	2	main
коллективах	doc_213943984912_item	2265333	et	2	main
солистами	doc_213943984912_item	2265338	et	2	main
и	doc_213943984912_item	2265346	et	2	main
репертуаре	doc_213943984912_item	2265352	et	2	main
старинных	doc_213943984912_item	2265358	et	2	main
до	doc_213943984912_item	2265362	et	2	main
композиторов	doc_213943984912_item	2265366	et	2	main
так	doc_213943984912_item	2265385	et	2	main
ансамбля	doc_213943984912_item	2265389	et	2	main
творчестве	doc_213943984912_item	2265394	et	2	main
русских	doc_213943984912_item	2265399	et	2	main
рахманинова	doc_213943984912_item	2265403	et	2	main
лиры	doc_213943984912_item	2265409	et	2	main
1900	doc_213943984912_item	2265416	et	2	main
tulnud	doc_213943984912_item	2265421	et	4	main
lüüra	doc_213943984912_item	2265423	et	4	main
gretšaninovi	doc_213943984912_item	2265431	et	2	main
teiste	doc_213943984912_item	2265433	et	4	main
lauluansambel	doc_213943984912_item	2265436	et	3	main
peterburgi	doc_213943984912_item	2265439	et	4	main
koorikollektiivides	doc_213943984912_item	2265447	et	3	main
solistidena	doc_213943984912_item	2265450	et	3	main
vene	doc_213943984912_item	2265457	et	4	main
kollektiivi	doc_213943984912_item	2265462	et	4	main
pärineb	doc_213943984912_item	2265469	et	3	main
vanaaegsatest	doc_213943984912_item	2265470	et	3	main
kirikulauludest	doc_213943984912_item	2265472	et	3	main
teosteni	doc_213943984912_item	2265483	et	3	main
lauluansambel	doc_213943984912_item	2265484	et	3	main
kontserdil	doc_213943984912_item	2265523	et	3	main
хвосте	doc_213943984913_item	2265526	et	2	main
свежем	doc_213943984913_item	2265531	et	2	main
эстония	doc_213943984913_item	2265536	et	2	main
äripäev	doc_213943984913_item	2265540	et	3	main
хвосте	doc_213943984913_item	2265546	et	2	main
kukkumise	doc_213943984910_item	2264979	et	4	main
oli	doc_213943984910_item	2264981	et	3	main
kõik	doc_213943984910_item	2264983	et	4	main
mis	doc_213943984910_item	2264989	et	4	main
ka	doc_213943984910_item	2264991	et	3	main
vedelik	doc_213943984910_item	2265000	et	3	main
pudelites	doc_213943984910_item	2265002	et	3	main
võib	doc_213943984910_item	2265012	et	3	main
ka	doc_213943984910_item	2265014	et	3	main
oma	doc_213943984910_item	2265016	et	4	main
või	doc_213943984910_item	2265017	et	4	main
varem	doc_213943984910_item	2265022	et	4	main
vastas	doc_213943984910_item	2265025	et	4	main
järele	doc_213943984910_item	2265032	et	4	main
minu	doc_213943984910_item	2265042	et	3	main
oli	doc_213943984910_item	2265044	et	3	main
juhtunut	doc_213943984910_item	2265048	et	4	main
kohvrisisu	doc_213943984910_item	2265050	et	4	main
mulle	doc_213943984910_item	2265053	et	4	main
muljet	doc_213943984910_item	2265054	et	3	main
ma	doc_213943984910_item	2265056	et	3	main
juba	doc_213943984910_item	2265058	et	3	main
pomm	doc_213943984910_item	2265070	et	3	main
pärast	doc_213943984910_item	2265132	et	4	main
tuli	doc_213943984910_item	2265134	et	4	main
ta	doc_213943984910_item	2265135	et	4	main
rongist	doc_213943984910_item	2265136	et	4	main
välja	doc_213943984910_item	2265137	et	4	main
ei	doc_213943984910_item	2265146	et	4	main
vea	doc_213943984910_item	2265147	et	4	main
nagu	doc_213943984910_item	2265149	et	3	main
täna	doc_213943984910_item	2265151	et	4	main
ma	doc_213943984910_item	2265153	et	3	main
olema	doc_213943984910_item	2265156	et	4	main
хоровая	doc_213943984912_item	2265291	et	2	main
в	doc_213943984912_item	2265297	et	2	main
ансамбля	doc_213943984912_item	2265302	et	2	main
прозвучат	doc_213943984912_item	2265308	et	2	main
рахманинова	doc_213943984912_item	2265313	et	2	main
выпускников	doc_213943984912_item	2265325	et	2	main
в	doc_213943984912_item	2265330	et	2	main
в	doc_213943984912_item	2265335	et	2	main
главной	doc_213943984912_item	2265340	et	2	main
популяризацию	doc_213943984912_item	2265347	et	2	main
коллектива	doc_213943984912_item	2265353	et	2	main
от	doc_213943984912_item	2265357	et	2	main
песнопений	doc_213943984912_item	2265361	et	2	main
редко	doc_213943984912_item	2265368	et	2	main
значительную	doc_213943984912_item	2265390	et	2	main
естественно	doc_213943984912_item	2265395	et	2	main
чайковского	doc_213943984912_item	2265401	et	2	main
на	doc_213943984912_item	2265406	et	2	main
13	doc_213943984912_item	2265413	et	2	main
jaanuaril	doc_213943984912_item	2265414	et	3	main
preobraženski	doc_213943984912_item	2265417	et	2	main
toimub	doc_213943984912_item	2265419	et	3	main
kontsert	doc_213943984912_item	2265424	et	3	main
helisevad	doc_213943984912_item	2265426	et	4	main
tšesnokovi	doc_213943984912_item	2265429	et	2	main
rahmaninovi	doc_213943984912_item	2265430	et	4	main
teosed	doc_213943984912_item	2265435	et	3	main
eesmärgiks	doc_213943984912_item	2265453	et	3	main
hakkasid	doc_213943984910_item	2264985	et	4	main
silmaga	doc_213943984910_item	2264987	et	3	main
olnud	doc_213943984910_item	2264993	et	4	main
püstol	doc_213943984910_item	2264994	et	3	main
nöör	doc_213943984910_item	2265004	et	3	main
karjatas	doc_213943984910_item	2265006	et	3	main
just	doc_213943984910_item	2265009	et	3	main
kuid	doc_213943984910_item	2265028	et	4	main
lõpuks	doc_213943984910_item	2265033	et	4	main
jooksis	doc_213943984910_item	2265037	et	4	main
tema	doc_213943984910_item	2265045	et	4	main
tagajärgi	doc_213943984910_item	2265060	et	4	main
sellest	doc_213943984910_item	2265067	et	4	main
kõigest	doc_213943984910_item	2265068	et	4	main
peale	doc_213943984910_item	2265073	et	4	main
ilmus	doc_213943984910_item	2265074	et	4	main
kes	doc_213943984910_item	2265076	et	4	main
ohkas	doc_213943984910_item	2265077	et	3	main
ah	doc_213943984910_item	2265078	et	3	main
siin	doc_213943984910_item	2265079	et	4	main
see	doc_213943984910_item	2265080	et	3	main
neetud	doc_213943984910_item	2265081	et	4	main
kõik	doc_213943984910_item	2265086	et	4	main
ja	doc_213943984910_item	2265127	et	3	main
kui	doc_213943984910_item	2265128	et	3	main
2	doc_213943984910_item	2265130	et	2	main
peatus	doc_213943984910_item	2265133	et	4	main
ehmatusest	doc_213943984910_item	2265138	et	4	main
langenud	doc_213943984910_item	2265159	et	4	main
terroristi	doc_213943984910_item	2265160	et	4	main
sõitnud	doc_213943984910_item	2265024	et	4	main
ei	doc_213943984910_item	2265030	et	4	main
tõusis	doc_213943984910_item	2265034	et	4	main
avaldas	doc_213943984910_item	2265051	et	3	main
halbu	doc_213943984910_item	2265059	et	3	main
võis	doc_213943984910_item	2265063	et	4	main
juhtuda	doc_213943984910_item	2265065	et	3	main
ukse	doc_213943984910_item	2265072	et	3	main
vanamees	doc_213943984910_item	2265075	et	4	main
on	doc_213943984910_item	2265083	et	4	main
otsisin	doc_213943984910_item	2265085	et	3	main
kupeed	doc_213943984910_item	2265087	et	4	main
läbi	doc_213943984910_item	2265088	et	4	main
ja	doc_213943984910_item	2265089	et	3	main
siin	doc_213943984910_item	2265090	et	4	main
ta	doc_213943984910_item	2265091	et	4	main
nüüd	doc_213943984910_item	2265092	et	4	main
ongi	doc_213943984910_item	2265093	et	4	main
ta	doc_213943984910_item	2265094	et	4	main
korjas	doc_213943984910_item	2265095	et	3	main
asju	doc_213943984910_item	2265096	et	3	main
kokku	doc_213943984910_item	2265097	et	3	main
ja	doc_213943984910_item	2265098	et	3	main
pani	doc_213943984910_item	2265099	et	4	main
kohver	doc_213943984910_item	2265100	et	3	main
kinni	doc_213943984910_item	2265101	et	3	main
ma	doc_213943984910_item	2265102	et	3	main
ehmusin	doc_213943984910_item	2265103	et	3	main
kui	doc_213943984910_item	2265104	et	3	main
nägin	doc_213943984910_item	2265105	et	3	main
mis	doc_213943984910_item	2265106	et	4	main
kurja	doc_213943984910_item	2265107	et	4	main
pilguga	doc_213943984910_item	2265108	et	3	main
ta	doc_213943984910_item	2265109	et	4	main
mind	doc_213943984910_item	2265110	et	4	main
vaatas	doc_213943984910_item	2265111	et	3	main
kuid	doc_213943984910_item	2265112	et	4	main
ei	doc_213943984910_item	2265113	et	4	main
hakkanud	doc_213943984910_item	2265114	et	4	main
küsima	doc_213943984910_item	2265115	et	3	main
talle	doc_213943984910_item	2265117	et	4	main
neid	doc_213943984910_item	2265118	et	4	main
asju	doc_213943984910_item	2265119	et	3	main
milleks	doc_213943984910_item	2265116	et	4	main
tarvis	doc_213943984910_item	2265120	et	3	main
kõndis	doc_213943984910_item	2265123	et	3	main
samal	doc_213943984910_item	2265124	et	3	main
välja	doc_213943984910_item	2265126	et	4	main
minuti	doc_213943984910_item	2265131	et	3	main
sain	doc_213943984910_item	2265140	et	3	main
vanamees	doc_213943984910_item	2265122	et	4	main
hetkel	doc_213943984910_item	2265125	et	4	main
rong	doc_213943984910_item	2265129	et	3	main
ma	doc_213943984910_item	2265141	et	3	main
inimesele	doc_213943984910_item	2265145	et	3	main
ei	doc_213943984910_item	2265158	et	4	main
aru	doc_213943984910_item	2265142	et	4	main
igale	doc_213943984910_item	2265144	et	3	main
nii	doc_213943984910_item	2265148	et	3	main
mulle	doc_213943984910_item	2265150	et	4	main
ja	doc_213943984910_item	2265152	et	3	main
peaksin	doc_213943984910_item	2265154	et	4	main
ohvriks	doc_213943984910_item	2265161	et	3	main
звучит	doc_213943984912_item	2265289	et	2	main
преображенской	doc_213943984912_item	2265293	et	2	main
1900	doc_213943984912_item	2265298	et	2	main
лира	doc_213943984912_item	2265303	et	2	main
программе	doc_213943984912_item	2265307	et	2	main
чеснокова	doc_213943984912_item	2265312	et	2	main
композиторов	doc_213943984912_item	2265317	et	2	main
русская	doc_213943984912_item	2265290	et	2	main
января	doc_213943984912_item	2265296	et	2	main
вокального	doc_213943984912_item	2265301	et	2	main
в	doc_213943984912_item	2265306	et	2	main
чайковского	doc_213943984912_item	2265311	et	2	main
и	doc_213943984912_item	2265315	et	2	main
лира	doc_213943984912_item	2265320	et	2	main
и	doc_213943984912_item	2265324	et	2	main
которые	doc_213943984912_item	2265328	et	2	main
и	doc_213943984912_item	2265334	et	2	main
своей	doc_213943984912_item	2265339	et	2	main
ансамбль	doc_213943984912_item	2265342	et	2	main
исследование	doc_213943984912_item	2265345	et	2	main
музыки	doc_213943984912_item	2265350	et	2	main
музыка	doc_213943984912_item	2265356	et	2	main
русских	doc_213943984912_item	2265365	et	2	main
исполняемых	doc_213943984912_item	2265369	et	2	main
в	doc_213943984912_item	2265392	et	2	main
музыка	doc_213943984912_item	2265397	et	2	main
звучит	doc_213943984912_item	2265405	et	2	main
каждом	doc_213943984912_item	2265407	et	2	main
ja	doc_213943984912_item	2265432	et	3	main
lüüra	doc_213943984912_item	2265437	et	4	main
ja	doc_213943984912_item	2265442	et	3	main
kes	doc_213943984912_item	2265444	et	4	main
ooperiteatrites	doc_213943984912_item	2265449	et	3	main
lüüra	doc_213943984912_item	2265456	et	4	main
uurimist	doc_213943984912_item	2265459	et	4	main
muusika	doc_213943984912_item	2265467	et	4	main
ja	doc_213943984912_item	2265478	et	3	main
harva	doc_213943984912_item	2265481	et	4	main
esitavate	doc_213943984912_item	2265482	et	4	main
esitab	doc_213943984912_item	2265485	et	3	main
rahvuslaule	doc_213943984912_item	2265487	et	4	main
tantsu-	doc_213943984912_item	2265489	et	4	main
ja	doc_213943984912_item	2265490	et	3	main
nii	doc_213943984912_item	2265492	et	3	main
lüüra	doc_213943984912_item	2265521	et	4	main
в	doc_213943984913_item	2265525	et	2	main
самом	doc_213943984913_item	2265530	et	2	main
посвященном	doc_213943984913_item	2265534	et	2	main
пишет	doc_213943984913_item	2265538	et	2	main
в	doc_213943984913_item	2265542	et	2	main
речь	doc_213943984913_item	2265548	et	2	main
развития	doc_213943984913_item	2265554	et	2	main
об	doc_213943984913_item	2265565	et	2	main
эстония	doc_213943984913_item	2265573	et	2	main
в	doc_213943984913_item	2265579	et	2	main
испанией	doc_213943984913_item	2265584	et	2	main
уровню	doc_213943984913_item	2265589	et	2	main
латвию	doc_213943984913_item	2265593	et	2	main
других	doc_213943984913_item	2265598	et	2	main
исследования	doc_213943984913_item	2265604	et	2	main
экономики	doc_213943984913_item	2265610	et	2	main
показателям	doc_213943984913_item	2265615	et	2	main
деле	doc_213943984913_item	2265619	et	2	main
улучшила	doc_213943984913_item	2265621	et	2	main
в	doc_213943984913_item	2265625	et	2	main
удалось	doc_213943984913_item	2265629	et	2	main
таммисте	doc_213943984913_item	2265637	et	2	main
эстонии	doc_213943984913_item	2265640	et	2	main
tõlge	doc_213943984912_item	2265288	et	3	main
церкви	doc_213943984912_item	2265294	et	2	main
состоится	doc_213943984912_item	2265299	et	2	main
из	doc_213943984912_item	2265304	et	2	main
произведения	doc_213943984912_item	2265309	et	2	main
других	doc_213943984912_item	2265316	et	2	main
вокальний	doc_213943984912_item	2265318	et	2	main
студентов	doc_213943984912_item	2265323	et	2	main
работают	doc_213943984912_item	2265329	et	2	main
хоровых	doc_213943984912_item	2265332	et	2	main
театрах	doc_213943984912_item	2265337	et	2	main
лира	doc_213943984912_item	2265343	et	2	main
русской	doc_213943984912_item	2265348	et	2	main
в	doc_213943984912_item	2265351	et	2	main
духовная	doc_213943984912_item	2265355	et	2	main
церковных	doc_213943984912_item	2265359	et	2	main
малоизвестных	doc_213943984912_item	2265363	et	2	main
и	doc_213943984912_item	2265367	et	2	main
часть	doc_213943984912_item	2265391	et	2	main
занимает	doc_213943984912_item	2265396	et	2	main
композиторов	doc_213943984912_item	2265400	et	2	main
которая	doc_213943984912_item	2265404	et	2	main
концерте	doc_213943984912_item	2265408	et	2	main
vene	doc_213943984912_item	2265411	et	4	main
venemaalt	doc_213943984912_item	2265420	et	3	main
lauluansambli	doc_213943984912_item	2265422	et	3	main
kavas	doc_213943984912_item	2265425	et	3	main
tšaikovski	doc_213943984912_item	2265428	et	2	main
heliloojade	doc_213943984912_item	2265434	et	4	main
koosneb	doc_213943984912_item	2265438	et	3	main
tudengitest	doc_213943984912_item	2265441	et	4	main
lõpetajatest	doc_213943984912_item	2265443	et	4	main
töötavad	doc_213943984912_item	2265445	et	4	main
erinevates	doc_213943984912_item	2265446	et	4	main
ja	doc_213943984912_item	2265448	et	3	main
oma	doc_213943984912_item	2265451	et	4	main
ja	doc_213943984912_item	2265460	et	3	main
levitamist	doc_213943984912_item	2265461	et	4	main
on	doc_213943984912_item	2265464	et	4	main
mis	doc_213943984912_item	2265468	et	4	main
ka	doc_213943984912_item	2265486	et	3	main
состоит	doc_213943984912_item	2265321	et	2	main
петербургской	doc_213943984912_item	2265326	et	2	main
разных	doc_213943984912_item	2265331	et	2	main
оперных	doc_213943984912_item	2265336	et	2	main
целью	doc_213943984912_item	2265341	et	2	main
считает	doc_213943984912_item	2265344	et	2	main
хоровой	doc_213943984912_item	2265349	et	2	main
русская	doc_213943984912_item	2265354	et	2	main
православных	doc_213943984912_item	2265360	et	2	main
сочинений	doc_213943984912_item	2265364	et	2	main
произведений	doc_213943984912_item	2265370	et	2	main
xviii-xx	doc_213943984912_item	2265371	et	4	main
веков	doc_213943984912_item	2265372	et	2	main
ансамбль	doc_213943984912_item	2265373	et	2	main
исполняет	doc_213943984912_item	2265374	et	2	main
и	doc_213943984912_item	2265375	et	2	main
народные	doc_213943984912_item	2265376	et	2	main
лирические	doc_213943984912_item	2265378	et	2	main
песни	doc_213943984912_item	2265377	et	2	main
танцевальные	doc_213943984912_item	2265379	et	2	main
ритуальные	doc_213943984912_item	2265380	et	2	main
аранжированные	doc_213943984912_item	2265381	et	2	main
как	doc_213943984912_item	2265382	et	2	main
известными	doc_213943984912_item	2265383	et	2	main
композиторами	doc_213943984912_item	2265384	et	2	main
и	doc_213943984912_item	2265386	et	2	main
самими	doc_213943984912_item	2265387	et	2	main
участниками	doc_213943984912_item	2265388	et	2	main
их	doc_213943984912_item	2265393	et	2	main
великих	doc_213943984912_item	2265398	et	2	main
танеева	doc_213943984912_item	2265402	et	2	main
kõlab	doc_213943984912_item	2265410	et	3	main
koorilaul	doc_213943984912_item	2265412	et	4	main
kell	doc_213943984912_item	2265415	et	3	main
kirikus	doc_213943984912_item	2265418	et	3	main
bortnjanski	doc_213943984912_item	2265427	et	4	main
konservatooriumi	doc_213943984912_item	2265440	et	4	main
peamiseks	doc_213943984912_item	2265452	et	3	main
peab	doc_213943984912_item	2265454	et	4	main
koorimuusika	doc_213943984912_item	2265458	et	4	main
vaimne	doc_213943984912_item	2265466	et	3	main
õigeusu	doc_213943984912_item	2265471	et	3	main
heliloojade	doc_213943984912_item	2265474	et	4	main
tuntud	doc_213943984912_item	2265476	et	4	main
teoste	doc_213943984912_item	2265477	et	3	main
xviii-xx	doc_213943984912_item	2265479	et	4	main
kuulsate	doc_213943984912_item	2265493	et	3	main
heliloojade	doc_213943984912_item	2265494	et	4	main
kui	doc_213943984912_item	2265495	et	3	main
ansambli	doc_213943984912_item	2265497	et	3	main
ka	doc_213943984912_item	2265496	et	3	main
liikmete	doc_213943984912_item	2265498	et	3	main
poolt	doc_213943984912_item	2265499	et	4	main
orkestreeritud	doc_213943984912_item	2265500	et	4	main
laule	doc_213943984912_item	2265501	et	4	main
nende	doc_213943984912_item	2265502	et	4	main
loomingus	doc_213943984912_item	2265503	et	3	main
tunduv	doc_213943984912_item	2265504	et	4	main
osa	doc_213943984912_item	2265505	et	4	main
mängib	doc_213943984912_item	2265506	et	3	main
suurt	doc_213943984912_item	2265507	et	3	main
rolli	doc_213943984912_item	2265508	et	4	main
kuulsate	doc_213943984912_item	2265510	et	3	main
vene	doc_213943984912_item	2265511	et	4	main
heliloojade	doc_213943984912_item	2265512	et	4	main
nagu	doc_213943984912_item	2265513	et	3	main
selliste	doc_213943984912_item	2265509	et	4	main
tšaikovski	doc_213943984912_item	2265514	et	2	main
tanejevi	doc_213943984912_item	2265515	et	4	main
ja	doc_213943984912_item	2265516	et	3	main
rahmaninovi	doc_213943984912_item	2265517	et	4	main
muusika	doc_213943984912_item	2265518	et	4	main
mis	doc_213943984912_item	2265519	et	4	main
kõlab	doc_213943984912_item	2265520	et	3	main
igal	doc_213943984912_item	2265522	et	3	main
европейских	doc_213943984913_item	2265527	et	2	main
европейском	doc_213943984913_item	2265532	et	2	main
как	doc_213943984913_item	2265537	et	2	main
помещена	doc_213943984913_item	2265541	et	2	main
плетущихся	doc_213943984913_item	2265544	et	2	main
по	doc_213943984913_item	2265549	et	2	main
фонда	doc_213943984913_item	2265553	et	2	main
абсолютном	doc_213943984913_item	2265566	et	2	main
уточнить	doc_213943984913_item	2265570	et	2	main
сейчас	doc_213943984913_item	2265575	et	2	main
плетущихся	doc_213943984913_item	2265578	et	2	main
италией	doc_213943984913_item	2265583	et	2	main
инноваций	doc_213943984913_item	2265590	et	2	main
lauluansambel	doc_213943984912_item	2265455	et	3	main
repertuaaris	doc_213943984912_item	2265463	et	3	main
vene	doc_213943984912_item	2265465	et	4	main
vene	doc_213943984912_item	2265473	et	4	main
vähe	doc_213943984912_item	2265475	et	3	main
sajandite	doc_213943984912_item	2265480	et	3	main
lüürilisi	doc_213943984912_item	2265488	et	3	main
rituaallaule	doc_213943984912_item	2265491	et	4	main
tõlge	doc_213943984913_item	2265524	et	3	main
в	doc_213943984913_item	2265529	et	2	main
инновациям	doc_213943984913_item	2265535	et	2	main
категорию	doc_213943984913_item	2265543	et	2	main
правда	doc_213943984913_item	2265547	et	2	main
председателя	doc_213943984913_item	2265552	et	2	main
положении	doc_213943984913_item	2265567	et	2	main
что	doc_213943984913_item	2265571	et	2	main
категорию	doc_213943984913_item	2265577	et	2	main
с	doc_213943984913_item	2265582	et	2	main
по	doc_213943984913_item	2265587	et	2	main
ми	doc_213943984913_item	2265591	et	2	main
литву	doc_213943984913_item	2265594	et	2	main
новых	doc_213943984913_item	2265599	et	2	main
результаты	doc_213943984913_item	2265603	et	2	main
экономического	doc_213943984913_item	2265607	et	2	main
таммисте	doc_213943984913_item	2265612	et	2	main
эстония	doc_213943984913_item	2265616	et	2	main
свои	doc_213943984913_item	2265622	et	2	main
другим	doc_213943984913_item	2265628	et	2	main
большей	doc_213943984913_item	2265633	et	2	main
главная	doc_213943984913_item	2265638	et	2	main
с	doc_213943984913_item	2265643	et	2	main
и	doc_213943984913_item	2265648	et	2	main
развитии	doc_213943984913_item	2265653	et	2	main
мы	doc_213943984913_item	2265657	et	2	main
инвестициям	doc_213943984913_item	2265663	et	2	main
тройке	doc_213943984913_item	2265668	et	2	main
людей	doc_213943984913_item	2265672	et	2	main
образованием	doc_213943984913_item	2265675	et	2	main
высок	doc_213943984913_item	2265679	et	2	main
мелких	doc_213943984913_item	2265685	et	2	main
пояснил	doc_213943984913_item	2265716	et	2	main
его	doc_213943984913_item	2265720	et	2	main
реальное	doc_213943984913_item	2265725	et	2	main
в	doc_213943984913_item	2265727	et	2	main
исследований	doc_213943984913_item	2265735	et	2	main
пока	doc_213943984913_item	2265741	et	2	main
больше	doc_213943984913_item	2265746	et	2	main
не	doc_213943984913_item	2265751	et	2	main
kõige	doc_213943984913_item	2265759	et	4	main
selgus	doc_213943984913_item	2265767	et	4	main
sörgib	doc_213943984913_item	2265770	et	3	main
sabas	doc_213943984913_item	2265796	et	3	main
slovakkiaga	doc_213943984913_item	2265801	et	4	main
innovatsioonide	doc_213943984913_item	2265802	et	4	main
taseme	doc_213943984913_item	2265803	et	3	main
leedust	doc_213943984913_item	2265807	et	4	main
ja	doc_213943984913_item	2265809	et	3	main
ees	doc_213943984913_item	2265816	et	4	main
kommentaare	doc_213943984913_item	2265819	et	3	main
инноваций	doc_213943984913_item	2265528	et	2	main
исследовании	doc_213943984913_item	2265533	et	2	main
газета	doc_213943984913_item	2265539	et	2	main
в	doc_213943984913_item	2265545	et	2	main
словам	doc_213943984913_item	2265550	et	2	main
эрика	doc_213943984913_item	2265555	et	2	main
идет	doc_213943984913_item	2265557	et	2	main
в	doc_213943984913_item	2265558	et	2	main
данном	doc_213943984913_item	2265559	et	2	main
случае	doc_213943984913_item	2265560	et	2	main
о	doc_213943984913_item	2265561	et	2	main
динамике	doc_213943984913_item	2265562	et	2	main
а	doc_213943984913_item	2265563	et	2	main
не	doc_213943984913_item	2265564	et	2	main
заместителя	doc_213943984913_item	2265551	et	2	main
терка	doc_213943984913_item	2265556	et	2	main
надо	doc_213943984913_item	2265569	et	2	main
попала	doc_213943984913_item	2265574	et	2	main
хвосте	doc_213943984913_item	2265580	et	2	main
словакией	doc_213943984913_item	2265586	et	2	main
опережаем	doc_213943984913_item	2265592	et	2	main
большинство	doc_213943984913_item	2265597	et	2	main
ес	doc_213943984913_item	2265601	et	2	main
службы	doc_213943984913_item	2265606	et	2	main
лаури	doc_213943984913_item	2265611	et	2	main
на	doc_213943984913_item	2265617	et	2	main
во-первых	doc_213943984913_item	2265568	et	2	main
хотя	doc_213943984913_item	2265572	et	2	main
в	doc_213943984913_item	2265576	et	2	main
вместе	doc_213943984913_item	2265581	et	2	main
и	doc_213943984913_item	2265585	et	2	main
достигнутому	doc_213943984913_item	2265588	et	2	main
и	doc_213943984913_item	2265596	et	2	main
прокомментировал	doc_213943984913_item	2265602	et	2	main
анализа	doc_213943984913_item	2265608	et	2	main
по	doc_213943984913_item	2265613	et	2	main
самом	doc_213943984913_item	2265618	et	2	main
позиции	doc_213943984913_item	2265623	et	2	main
что	doc_213943984913_item	2265627	et	2	main
еще	doc_213943984913_item	2265632	et	2	main
оценке	doc_213943984913_item	2265636	et	2	main
слабость	doc_213943984913_item	2265639	et	2	main
европейскими	doc_213943984913_item	2265644	et	2	main
швейцарией	doc_213943984913_item	2265649	et	2	main
с	doc_213943984913_item	2265654	et	2	main
в	doc_213943984913_item	2265660	et	2	main
по	doc_213943984913_item	2265662	et	2	main
в	doc_213943984913_item	2265667	et	2	main
с	doc_213943984913_item	2265673	et	2	main
нас	doc_213943984913_item	2265677	et	2	main
да	doc_213943984913_item	2265683	et	2	main
таммисте	doc_213943984913_item	2265717	et	2	main
польшу	doc_213943984913_item	2265595	et	2	main
стран	doc_213943984913_item	2265600	et	2	main
начальник	doc_213943984913_item	2265605	et	2	main
министерства	doc_213943984913_item	2265609	et	2	main
многим	doc_213943984913_item	2265614	et	2	main
даже	doc_213943984913_item	2265620	et	2	main
проблема	doc_213943984913_item	2265624	et	2	main
это	doc_213943984913_item	2265630	et	2	main
по	doc_213943984913_item	2265635	et	2	main
по	doc_213943984913_item	2265641	et	2	main
финляндией	doc_213943984913_item	2265646	et	2	main
неоднородном	doc_213943984913_item	2265652	et	2	main
стороны	doc_213943984913_item	2265656	et	2	main
европе	doc_213943984913_item	2265661	et	2	main
технологии	doc_213943984913_item	2265666	et	2	main
лучших	doc_213943984913_item	2265669	et	2	main
высшим	doc_213943984913_item	2265674	et	2	main
инновационный	doc_213943984913_item	2265680	et	2	main
и	doc_213943984913_item	2265684	et	2	main
по	doc_213943984913_item	2265719	et	2	main
приняться	doc_213943984913_item	2265723	et	2	main
принятой	doc_213943984913_item	2265729	et	2	main
научных	doc_213943984913_item	2265734	et	2	main
развития	doc_213943984913_item	2265737	et	2	main
годы	doc_213943984913_item	2265740	et	2	main
предприниматели	doc_213943984913_item	2265744	et	2	main
машины	doc_213943984913_item	2265749	et	2	main
в	doc_213943984913_item	2265752	et	2	main
eesti	doc_213943984913_item	2265755	et	4	main
innovatsiooni	doc_213943984913_item	2265757	et	4	main
uuringus	doc_213943984913_item	2265761	et	3	main
pühendatud	doc_213943984913_item	2265765	et	4	main
innovatsioonidele	doc_213943984913_item	2265766	et	4	main
koos	doc_213943984913_item	2265797	et	4	main
itaaliaga	doc_213943984913_item	2265798	et	4	main
kohaselt	doc_213943984913_item	2265804	et	4	main
paljudest	doc_213943984913_item	2265810	et	3	main
euroopa	doc_213943984913_item	2265812	et	4	main
oma	doc_213943984913_item	2265818	et	4	main
tulemuste	doc_213943984913_item	2265821	et	4	main
on	doc_213943984913_item	2265826	et	4	main
majandusministeeriumi	doc_213943984913_item	2265827	et	4	main
paljude	doc_213943984913_item	2265831	et	3	main
kõrgemaks	doc_213943984913_item	2265837	et	4	main
et	doc_213943984913_item	2265842	et	3	main
said	doc_213943984913_item	2265844	et	4	main
euroopa	doc_213943984913_item	2265851	et	4	main
rootsi	doc_213943984913_item	2265854	et	4	main
võrreldes	doc_213943984913_item	2265857	et	3	main
koht	doc_213943984913_item	2265860	et	3	main
ebaühtlane	doc_213943984913_item	2265862	et	3	main
ühelt	doc_213943984913_item	2265865	et	3	main
esimeste	doc_213943984913_item	2265873	et	4	main
seas	doc_213943984913_item	2265874	et	4	main
kõrgharidusega	doc_213943984913_item	2265875	et	3	main
esikolmikus	doc_213943984913_item	2265879	et	3	main
ka	doc_213943984913_item	2265886	et	3	main
erasektori	doc_213943984913_item	2265892	et	3	main
uurimustööle	doc_213943984913_item	2265894	et	3	main
tehnoloogiate	doc_213943984913_item	2265905	et	3	main
kohaselt	doc_213943984913_item	2265907	et	4	main
uut	doc_213943984913_item	2265918	et	3	main
arengu	doc_213943984913_item	2265921	et	3	main
aastateks	doc_213943984913_item	2265923	et	4	main
ettevõtjad	doc_213943984913_item	2265934	et	3	main
investeerima	doc_213943984913_item	2265936	et	3	main
том	doc_213943984913_item	2265626	et	2	main
в	doc_213943984913_item	2265631	et	2	main
степени	doc_213943984913_item	2265634	et	2	main
сравнению	doc_213943984913_item	2265642	et	2	main
швецией	doc_213943984913_item	2265647	et	2	main
в	doc_213943984913_item	2265651	et	2	main
среди	doc_213943984913_item	2265658	et	2	main
информационно-коммуникационные	doc_213943984913_item	2265665	et	2	main
по	doc_213943984913_item	2265670	et	2	main
у	doc_213943984913_item	2265676	et	2	main
уровень	doc_213943984913_item	2265681	et	2	main
предприятий	doc_213943984913_item	2265686	et	2	main
но	doc_213943984913_item	2265687	et	2	main
с	doc_213943984913_item	2265688	et	2	main
другой	doc_213943984913_item	2265689	et	2	main
занимаем	doc_213943984913_item	2265691	et	2	main
мы	doc_213943984913_item	2265690	et	2	main
очень	doc_213943984913_item	2265692	et	2	main
место	doc_213943984913_item	2265694	et	2	main
скромное	doc_213943984913_item	2265693	et	2	main
расходам	doc_213943984913_item	2265696	et	2	main
по	doc_213943984913_item	2265695	et	2	main
частного	doc_213943984913_item	2265697	et	2	main
сектора	doc_213943984913_item	2265698	et	2	main
на	doc_213943984913_item	2265699	et	2	main
научно-исследовательскую	doc_213943984913_item	2265700	et	2	main
и	doc_213943984913_item	2265701	et	2	main
опытно-конструкторскую	doc_213943984913_item	2265702	et	2	main
работу	doc_213943984913_item	2265703	et	2	main
по	doc_213943984913_item	2265704	et	2	main
патентованию	doc_213943984913_item	2265705	et	2	main
по	doc_213943984913_item	2265706	et	2	main
количеству	doc_213943984913_item	2265707	et	2	main
выпускников	doc_213943984913_item	2265708	et	2	main
естественно-научных	doc_213943984913_item	2265709	et	2	main
специальностей	doc_213943984913_item	2265710	et	2	main
и	doc_213943984913_item	2265711	et	2	main
по	doc_213943984913_item	2265712	et	2	main
экспорту	doc_213943984913_item	2265713	et	2	main
высоких	doc_213943984913_item	2265714	et	2	main
технологий	doc_213943984913_item	2265715	et	2	main
лидерами	doc_213943984913_item	2265645	et	2	main
заключается	doc_213943984913_item	2265650	et	2	main
одной	doc_213943984913_item	2265655	et	2	main
первых	doc_213943984913_item	2265659	et	2	main
в	doc_213943984913_item	2265664	et	2	main
доле	doc_213943984913_item	2265671	et	2	main
достаточно	doc_213943984913_item	2265678	et	2	main
средних	doc_213943984913_item	2265682	et	2	main
словам	doc_213943984913_item	2265721	et	2	main
недавно	doc_213943984913_item	2265730	et	2	main
стратегии	doc_213943984913_item	2265733	et	2	main
2007-2013	doc_213943984913_item	2265739	et	2	main
же	doc_213943984913_item	2265742	et	2	main
инвестировать	doc_213943984913_item	2265747	et	2	main
образованного	doc_213943984913_item	2265753	et	2	main
eesti	doc_213943984913_item	2265769	et	4	main
oleme	doc_213943984913_item	2265805	et	3	main
poolast	doc_213943984913_item	2265808	et	3	main
andis	doc_213943984913_item	2265817	et	3	main
uuringu	doc_213943984913_item	2265820	et	3	main
lauri	doc_213943984913_item	2265823	et	4	main
tammiste	doc_213943984913_item	2265824	et	4	main
majandusanalüüsi	doc_213943984913_item	2265828	et	4	main
näitajate	doc_213943984913_item	2265832	et	4	main
eesti	doc_213943984913_item	2265835	et	4	main
positsioonid	doc_213943984913_item	2265836	et	3	main
seisneb	doc_213943984913_item	2265840	et	3	main
hakkama	doc_213943984913_item	2265847	et	3	main
soome	doc_213943984913_item	2265853	et	3	main
šveitsiga	doc_213943984913_item	2265856	et	2	main
tehnoloogiade	doc_213943984913_item	2265870	et	4	main
kohaselt	doc_213943984913_item	2265872	et	4	main
teiselt	doc_213943984913_item	2265890	et	4	main
teaduslikule	doc_213943984913_item	2265893	et	3	main
erialade	doc_213943984913_item	2265901	et	3	main
ja	doc_213943984913_item	2265903	et	3	main
teaduslike	doc_213943984913_item	2265919	et	3	main
правительству	doc_213943984913_item	2265718	et	2	main
необходимо	doc_213943984913_item	2265722	et	2	main
претворение	doc_213943984913_item	2265726	et	2	main
парламентом	doc_213943984913_item	2265731	et	2	main
и	doc_213943984913_item	2265736	et	2	main
эстонские	doc_213943984913_item	2265743	et	2	main
в	doc_213943984913_item	2265748	et	2	main
человека	doc_213943984913_item	2265754	et	2	main
euroopa	doc_213943984913_item	2265756	et	4	main
mis	doc_213943984913_item	2265763	et	4	main
et	doc_213943984913_item	2265768	et	3	main
teatab	doc_213943984913_item	2265772	et	3	main
sörgib	doc_213943984913_item	2265795	et	3	main
liidu	doc_213943984913_item	2265813	et	3	main
riikidest	doc_213943984913_item	2265815	et	3	main
esimees	doc_213943984913_item	2265830	et	4	main
järgi	doc_213943984913_item	2265833	et	4	main
on	doc_213943984913_item	2265834	et	4	main
hinnangul	doc_213943984913_item	2265849	et	3	main
teiste	doc_213943984913_item	2265850	et	4	main
oleme	doc_213943984913_item	2265867	et	3	main
investeeringu	doc_213943984913_item	2265871	et	3	main
arvu	doc_213943984913_item	2265877	et	4	main
üsna	doc_213943984913_item	2265884	et	3	main
väikeste	doc_213943984913_item	2265887	et	4	main
ettevõtete	doc_213943984913_item	2265888	et	3	main
ja	doc_213943984913_item	2265896	et	3	main
loodus-teaduslike	doc_213943984913_item	2265900	et	3	main
oleme	doc_213943984913_item	2265908	et	3	main
riigikogu	doc_213943984913_item	2265915	et	4	main
peab	doc_213943984913_item	2265916	et	4	main
teostama	doc_213943984913_item	2265917	et	3	main
uurimiste	doc_213943984913_item	2265920	et	4	main
strateegiat	doc_213943984913_item	2265922	et	3	main
2013	doc_213943984913_item	2265925	et	2	main
oli	doc_213943984913_item	2265927	et	3	main
vastu	doc_213943984913_item	2265931	et	3	main
autodesse	doc_213943984913_item	2265937	et	3	main
mitte	doc_213943984913_item	2265938	et	3	main
за	doc_213943984913_item	2265724	et	2	main
жизнь	doc_213943984913_item	2265728	et	2	main
новой	doc_213943984913_item	2265732	et	2	main
на	doc_213943984913_item	2265738	et	2	main
склонны	doc_213943984913_item	2265745	et	2	main
а	doc_213943984913_item	2265750	et	2	main
sabas	doc_213943984913_item	2265758	et	3	main
värskemas	doc_213943984913_item	2265760	et	4	main
euroopas	doc_213943984913_item	2265762	et	3	main
oli	doc_213943984913_item	2265764	et	3	main
sabas	doc_213943984913_item	2265771	et	3	main
ajaleht	doc_213943984913_item	2265773	et	3	main
äripäev	doc_213943984913_item	2265774	et	3	main
kuigi	doc_213943984913_item	2265775	et	3	main
arengufondi	doc_213943984913_item	2265776	et	4	main
aseesimehe	doc_213943984913_item	2265777	et	3	main
eriku	doc_213943984913_item	2265778	et	4	main
tergi	doc_213943984913_item	2265779	et	4	main
sõnul	doc_213943984913_item	2265780	et	3	main
on	doc_213943984913_item	2265781	et	4	main
küsimus	doc_213943984913_item	2265782	et	4	main
dünaamikas	doc_213943984913_item	2265783	et	3	main
aga	doc_213943984913_item	2265785	et	3	main
absoluutses	doc_213943984913_item	2265786	et	3	main
seisundis	doc_213943984913_item	2265787	et	3	main
mitte	doc_213943984913_item	2265784	et	3	main
esiteks	doc_213943984913_item	2265788	et	3	main
on	doc_213943984913_item	2265789	et	4	main
vaja	doc_213943984913_item	2265790	et	4	main
täpsustada	doc_213943984913_item	2265791	et	3	main
et	doc_213943984913_item	2265792	et	3	main
ehkki	doc_213943984913_item	2265793	et	3	main
eesti	doc_213943984913_item	2265794	et	4	main
hispaania	doc_213943984913_item	2265799	et	4	main
ja	doc_213943984913_item	2265800	et	3	main
lätist	doc_213943984913_item	2265806	et	4	main
teistest	doc_213943984913_item	2265811	et	4	main
uudest	doc_213943984913_item	2265814	et	4	main
teenistuse	doc_213943984913_item	2265829	et	3	main
probleem	doc_213943984913_item	2265839	et	3	main
selles	doc_213943984913_item	2265841	et	4	main
teised	doc_213943984913_item	2265843	et	4	main
tammiste	doc_213943984913_item	2265848	et	4	main
liidritega	doc_213943984913_item	2265852	et	3	main
eesti	doc_213943984913_item	2265858	et	4	main
nõrk	doc_213943984913_item	2265859	et	3	main
on	doc_213943984913_item	2265861	et	4	main
areng	doc_213943984913_item	2265864	et	3	main
poolt	doc_213943984913_item	2265866	et	4	main
poolest	doc_213943984913_item	2265878	et	4	main
meie	doc_213943984913_item	2265880	et	4	main
innovatsiooni	doc_213943984913_item	2265881	et	4	main
tase	doc_213943984913_item	2265882	et	3	main
on	doc_213943984913_item	2265883	et	4	main
hulgas	doc_213943984913_item	2265889	et	4	main
katsemisele	doc_213943984913_item	2265895	et	4	main
konstrueerimisele	doc_213943984913_item	2265897	et	4	main
patentimise	doc_213943984913_item	2265899	et	4	main
tagasihoidlikul	doc_213943984913_item	2265909	et	3	main
selgitas	doc_213943984913_item	2265911	et	3	main
tammiste	doc_213943984913_item	2265912	et	4	main
tema	doc_213943984913_item	2265913	et	4	main
sõnul	doc_213943984913_item	2265914	et	3	main
2003	doc_213943984913_item	2265924	et	2	main
eesti	doc_213943984913_item	2265933	et	4	main
kippuvad	doc_213943984913_item	2265935	et	4	main
aga	doc_213943984913_item	2265939	et	3	main
soomes	doc_213943984915_item	2266212	et	4	main
autonoomiat	doc_213943984915_item	2266214	et	3	main
1809-1917	doc_213943984915_item	2266224	et	2	main
impeeriumi	doc_213943984915_item	2266229	et	4	main
osa	doc_213943984915_item	2266230	et	4	main
aleksandri	doc_213943984915_item	2266235	et	4	main
õppima	doc_213943984915_item	2266245	et	3	main
alandi	doc_213943984915_item	2266251	et	4	main
kokku	doc_213943984915_item	2266257	et	3	main
selleks	doc_213943984915_item	2266259	et	4	main
lõpp	doc_213943984915_item	2266265	et	3	main
umbes	doc_213943984915_item	2266268	et	4	main
ehitatud	doc_213943984915_item	2266277	et	4	main
linn	doc_213943984915_item	2266280	et	3	main
mis	doc_213943984915_item	2266281	et	4	main
poolt	doc_213943984915_item	2266286	et	4	main
teemal	doc_213943984913_item	2265822	et	3	main
kes	doc_213943984913_item	2265825	et	4	main
läinud	doc_213943984913_item	2265838	et	4	main
sellega	doc_213943984913_item	2265845	et	3	main
paremini	doc_213943984913_item	2265846	et	4	main
ja	doc_213943984913_item	2265855	et	3	main
majanduslik	doc_213943984913_item	2265863	et	3	main
euroopas	doc_213943984913_item	2265868	et	3	main
info-kommunikatsiooni	doc_213943984913_item	2265869	et	4	main
inimeste	doc_213943984913_item	2265876	et	3	main
kõrge	doc_213943984913_item	2265885	et	4	main
poolt	doc_213943984913_item	2265891	et	4	main
kulude	doc_213943984913_item	2265898	et	3	main
omandajate	doc_213943984913_item	2265902	et	4	main
kõrgete	doc_213943984913_item	2265904	et	4	main
ekspordi	doc_213943984913_item	2265906	et	4	main
kohal	doc_213943984913_item	2265910	et	4	main
mis	doc_213943984913_item	2265926	et	4	main
hiljuti	doc_213943984913_item	2265928	et	4	main
haritud	doc_213943984913_item	2265940	et	4	main
on	doc_213943984915_item	2266200	et	4	main
vene	doc_213943984915_item	2266202	et	4	main
elavad	doc_213943984915_item	2266208	et	4	main
on	doc_213943984915_item	2266215	et	4	main
kaitseala	doc_213943984915_item	2266221	et	4	main
aastatel	doc_213943984915_item	2266223	et	4	main
vene	doc_213943984915_item	2266228	et	4	main
marieham	doc_213943984915_item	2266233	et	4	main
parlamendi	doc_213943984913_item	2265929	et	3	main
poolt	doc_213943984913_item	2265930	et	4	main
võetud	doc_213943984913_item	2265932	et	4	main
inimesse	doc_213943984913_item	2265941	et	3	main
kus	doc_213943984915_item	2266207	et	3	main
kes	doc_213943984915_item	2266210	et	4	main
asutasid	doc_213943984915_item	2266211	et	4	main
kultuuri	doc_213943984915_item	2266220	et	4	main
olid	doc_213943984915_item	2266225	et	4	main
saared	doc_213943984915_item	2266227	et	3	main
aga	doc_213943984915_item	2266231	et	3	main
veel	doc_213943984915_item	2266246	et	4	main
rootsi	doc_213943984915_item	2266250	et	4	main
saartel	doc_213943984915_item	2266252	et	3	main
kongress	doc_213943984915_item	2266254	et	3	main
mis	doc_213943984915_item	2266255	et	4	main
seaduslikult	doc_213943984915_item	2266261	et	4	main
saarele	doc_213943984915_item	2266272	et	3	main
suursaadikute	doc_213943984915_item	2266279	et	3	main
ka	doc_213943984915_item	2266294	et	3	main
hoopis	doc_213943984915_item	2266323	et	3	main
kes	doc_213943984915_item	2266328	et	4	main
kurameerivad	doc_213943984915_item	2266329	et	4	main
südamlikkult	doc_213943984915_item	2266333	et	4	main
armastan	doc_213943984915_item	2266335	et	3	main
sind	doc_213943984915_item	2266337	et	4	main
öeldakse	doc_213943984915_item	2266342	et	3	main
armastan	doc_213943984915_item	2266347	et	3	main
krapula	doc_213943984915_item	2266354	et	4	main
venemaast	doc_213943984915_item	2266372	et	3	main
saartele	doc_213943984915_item	2266375	et	3	main
jäänud	doc_213943984915_item	2266421	et	4	main
postkontori	doc_213943984915_item	2266423	et	4	main
aja	doc_213943984915_item	2266446	et	4	main
kui	doc_213943984915_item	2266449	et	3	main
saartel	doc_213943984915_item	2266455	et	3	main
algas	doc_213943984915_item	2266464	et	3	main
mingisugune	doc_213943984915_item	2266466	et	3	main
venelastele	doc_213943984915_item	2266473	et	4	main
mõistatus	doc_213943984915_item	2266479	et	4	main
kiiresti	doc_213943984915_item	2266481	et	3	main
meelde	doc_213943984915_item	2266490	et	3	main
oma	doc_213943984915_item	2266493	et	4	main
att	doc_213943984915_item	2266525	et	3	main
perenaine	doc_213943984915_item	2266529	et	3	main
rootsi	doc_213943984915_item	2266531	et	4	main
tähendab	doc_213943984915_item	2266537	et	3	main
kõlavad	doc_213943984915_item	2266547	et	4	main
rootslaste	doc_213943984915_item	2266549	et	4	main
omad	doc_213943984915_item	2266552	et	4	main
hleib	doc_213943984915_item	2266563	et	4	main
leib	doc_213943984915_item	2266566	et	3	main
leiba	doc_213943984915_item	2266573	et	4	main
isegi	doc_213943984915_item	2266574	et	4	main
tõlge	doc_213943984915_item	2266198	et	3	main
rootslased	doc_213943984915_item	2266199	et	3	main
eelkäjate	doc_213943984915_item	2266203	et	4	main
alandi	doc_213943984915_item	2266205	et	4	main
rootslased	doc_213943984915_item	2266209	et	3	main
oma	doc_213943984915_item	2266213	et	4	main
tõeline	doc_213943984915_item	2266216	et	4	main
vene	doc_213943984915_item	2266217	et	4	main
põhjamaades	doc_213943984915_item	2266222	et	4	main
pealinn	doc_213943984915_item	2266232	et	3	main
naise	doc_213943984915_item	2266237	et	3	main
ajal	doc_213943984915_item	2266248	et	4	main
oli	doc_213943984915_item	2266256	et	3	main
kutsutud	doc_213943984915_item	2266258	et	4	main
kinnitada	doc_213943984915_item	2266262	et	3	main
kestsid	doc_213943984915_item	2266267	et	4	main
poolteist	doc_213943984915_item	2266269	et	4	main
love	doc_213943984915_item	2266271	et	4	main
teist	doc_213943984915_item	2266321	et	4	main
avaldamise	doc_213943984915_item	2266325	et	4	main
tunnistasid	doc_213943984915_item	2266332	et	4	main
ma	doc_213943984915_item	2266334	et	3	main
ainult	doc_213943984915_item	2266336	et	4	main
rõhutades	doc_213943984915_item	2266338	et	3	main
viimast	doc_213943984915_item	2266339	et	4	main
lovel	doc_213943984915_item	2266344	et	3	main
mis	doc_213943984915_item	2266345	et	4	main
tähendab	doc_213943984915_item	2266346	et	3	main
ihkan	doc_213943984915_item	2266349	et	3	main
üks	doc_213943984915_item	2266351	et	3	main
venekeelne	doc_213943984915_item	2266352	et	3	main
on	doc_213943984915_item	2266357	et	4	main
maha	doc_213943984915_item	2266369	et	4	main
sajandi	doc_213943984915_item	2266371	et	3	main
väga	doc_213943984915_item	2266377	et	3	main
sõnu	doc_213943984915_item	2266379	et	4	main
on	doc_213943984915_item	2266419	et	4	main
mis	doc_213943984915_item	2266429	et	4	main
ajal	doc_213943984915_item	2266435	et	4	main
sõja	doc_213943984915_item	2266451	et	3	main
adressaati	doc_213943984915_item	2266460	et	4	main
kümnendil	doc_213943984915_item	2266463	et	3	main
palju	doc_213943984915_item	2266468	et	4	main
tuletasid	doc_213943984915_item	2266487	et	4	main
ning	doc_213943984915_item	2266491	et	3	main
ja	doc_213943984915_item	2266497	et	3	main
ja-a	doc_213943984915_item	2266523	et	4	main
durak	doc_213943984915_item	2266524	et	4	main
kuka	doc_213943984915_item	2266526	et	4	main
see	doc_213943984915_item	2266536	et	3	main
ma	doc_213943984915_item	2266538	et	3	main
soome	doc_213943984915_item	2266548	et	3	main
suust	doc_213943984915_item	2266550	et	3	main
ehk	doc_213943984915_item	2266560	et	3	main
uhked	doc_213943984915_item	2266201	et	4	main
üle	doc_213943984915_item	2266204	et	3	main
saared	doc_213943984915_item	2266206	et	3	main
keele	doc_213943984915_item	2266218	et	4	main
ja	doc_213943984915_item	2266219	et	3	main
alandi	doc_213943984915_item	2266226	et	4	main
ii	doc_213943984915_item	2266236	et	4	main
aleksandrova	doc_213943984915_item	2266239	et	4	main
keelt	doc_213943984915_item	2266242	et	4	main
hakati	doc_213943984915_item	2266243	et	3	main
siin	doc_213943984915_item	2266244	et	4	main
läbirääkimised	doc_213943984915_item	2266266	et	3	main
aastat	doc_213943984915_item	2266270	et	3	main
nimetus	doc_213943984915_item	2266274	et	4	main
oli	doc_213943984915_item	2266276	et	3	main
terve	doc_213943984915_item	2266278	et	4	main
kaardiväelaste	doc_213943984915_item	2266285	et	4	main
major	doc_213943984915_item	2266287	et	3	main
käe	doc_213943984915_item	2266289	et	3	main
kui	doc_213943984915_item	2266291	et	3	main
tollest	doc_213943984915_item	2266298	et	4	main
ajast	doc_213943984915_item	2266299	et	4	main
jäi	doc_213943984915_item	2266300	et	3	main
alles	doc_213943984915_item	2266301	et	3	main
mitte	doc_213943984915_item	2266302	et	3	main
sõjaväe	doc_213943984915_item	2266303	et	3	main
ega	doc_213943984915_item	2266304	et	3	main
tehniline	doc_213943984915_item	2266305	et	3	main
leksika	doc_213943984915_item	2266306	et	4	main
vaid	doc_213943984915_item	2266307	et	3	main
kaks	doc_213943984915_item	2266309	et	3	main
hoopis	doc_213943984915_item	2266308	et	3	main
optimistlikku	doc_213943984915_item	2266310	et	4	main
sõna	doc_213943984915_item	2266311	et	4	main
karašo	doc_213943984915_item	2266312	et	2	main
ja	doc_213943984915_item	2266313	et	3	main
tjebja	doc_213943984915_item	2266314	et	4	main
kui	doc_213943984915_item	2266315	et	3	main
esimest	doc_213943984915_item	2266316	et	4	main
kasutatakse	doc_213943984915_item	2266317	et	3	main
õiges	doc_213943984915_item	2266318	et	3	main
tähenduses	doc_213943984915_item	2266319	et	4	main
siis	doc_213943984915_item	2266320	et	3	main
armastuse	doc_213943984915_item	2266324	et	4	main
eesmargiks	doc_213943984915_item	2266326	et	3	main
sõna	doc_213943984915_item	2266340	et	4	main
sõna	doc_213943984915_item	2266353	et	4	main
meil	doc_213943984915_item	2266356	et	4	main
vaid	doc_213943984915_item	2266364	et	3	main
väljendist	doc_213943984915_item	2266366	et	3	main
pohmell	doc_213943984915_item	2266367	et	4	main
murdis	doc_213943984915_item	2266368	et	3	main
on	doc_213943984915_item	2266373	et	4	main
seisid	doc_213943984915_item	2266381	et	4	main
bomarsundi	doc_213943984915_item	2266383	et	4	main
kusjuures	doc_213943984915_item	2266425	et	3	main
ehitatud	doc_213943984915_item	2266431	et	4	main
nikolai	doc_213943984915_item	2266432	et	4	main
i	doc_213943984915_item	2266433	et	4	main
välja	doc_213943984915_item	2266439	et	4	main
uus	doc_213943984915_item	2266441	et	3	main
kp	doc_213943984915_item	2266443	et	4	main
korrespondendile	doc_213943984915_item	2266444	et	3	main
nimetati	doc_213943984915_item	2266234	et	4	main
maria	doc_213943984915_item	2266238	et	4	main
auks	doc_213943984915_item	2266240	et	3	main
vene	doc_213943984915_item	2266241	et	4	main
peetri	doc_213943984915_item	2266247	et	3	main
kui	doc_213943984915_item	2266249	et	3	main
toimus	doc_213943984915_item	2266253	et	3	main
et	doc_213943984915_item	2266260	et	3	main
põhja	doc_213943984915_item	2266263	et	4	main
sõja	doc_213943984915_item	2266264	et	3	main
vana	doc_213943984915_item	2266273	et	4	main
sundšer	doc_213943984915_item	2266275	et	2	main
oli	doc_213943984915_item	2266282	et	3	main
seadmestatud	doc_213943984915_item	2266283	et	4	main
peetri-aegsete	doc_213943984915_item	2266284	et	4	main
imelik	doc_213943984915_item	2266292	et	3	main
ei	doc_213943984915_item	2266295	et	4	main
aga	doc_213943984915_item	2266297	et	3	main
anitškovi	doc_213943984915_item	2266288	et	2	main
all	doc_213943984915_item	2266290	et	3	main
see	doc_213943984915_item	2266293	et	3	main
tunduks	doc_213943984915_item	2266296	et	3	main
kasutatakse	doc_213943984915_item	2266322	et	3	main
ja	doc_213943984915_item	2266348	et	3	main
veel	doc_213943984915_item	2266350	et	4	main
millest	doc_213943984915_item	2266355	et	3	main
aru	doc_213943984915_item	2266359	et	4	main
on	doc_213943984915_item	2266363	et	4	main
lühend	doc_213943984915_item	2266365	et	3	main
19	doc_213943984915_item	2266370	et	2	main
alandi	doc_213943984915_item	2266374	et	4	main
palju	doc_213943984915_item	2266378	et	4	main
venelased	doc_213943984915_item	2266380	et	3	main
saartel	doc_213943984915_item	2266382	et	3	main
siia	doc_213943984915_item	2266420	et	4	main
ekkeri	doc_213943984915_item	2266422	et	3	main
töötajad	doc_213943984915_item	2266424	et	4	main
impeeriumi	doc_213943984915_item	2266426	et	4	main
stiilis	doc_213943984915_item	2266427	et	4	main
oli	doc_213943984915_item	2266430	et	3	main
valitsemise	doc_213943984915_item	2266434	et	4	main
1828	doc_213943984915_item	2266436	et	2	main
aastal	doc_213943984915_item	2266437	et	3	main
tendentsist	doc_213943984915_item	2266448	et	3	main
vene	doc_213943984915_item	2266458	et	4	main
siis	doc_213943984915_item	2266461	et	3	main
hoopis	doc_213943984915_item	2266465	et	3	main
on	doc_213943984915_item	2266476	et	4	main
need	doc_213943984915_item	2266482	et	3	main
seda	doc_213943984915_item	2266489	et	3	main
vana-vanaisade	doc_213943984915_item	2266494	et	3	main
sidorovite	doc_213943984915_item	2266495	et	4	main
perepelkinite	doc_213943984915_item	2266498	et	4	main
naudinguks	doc_213943984915_item	2266522	et	3	main
novgorodi	doc_213943984915_item	2266533	et	4	main
keele	doc_213943984915_item	2266534	et	4	main
segu	doc_213943984915_item	2266535	et	4	main
borši	doc_213943984915_item	2266541	et	2	main
kui	doc_213943984915_item	2266544	et	3	main
ikkagi	doc_213943984915_item	2266546	et	4	main
будка	doc_213943984915_item	2266561	et	2	main
хлеб	doc_213943984915_item	2266565	et	2	main
siiani	doc_213943984915_item	2266570	et	4	main
pirukad	doc_213943984915_item	2266586	et	3	main
форточка	doc_213943984915_item	2266589	et	2	main
tegemise	doc_213943984915_item	2266599	et	4	main
lihtsustas	doc_213943984915_item	2266601	et	3	main
мед	doc_213943984915_item	2266605	et	2	main
ehk	doc_213943984915_item	2266612	et	3	main
ärge	doc_213943984915_item	2266615	et	3	main
alandi	doc_213943984915_item	2266619	et	4	main
teil	doc_213943984915_item	2266623	et	4	main
sarska	doc_213943984915_item	2266624	et	4	main
heita	doc_213943984915_item	2266628	et	3	main
tema	doc_213943984915_item	2266630	et	4	main
see	doc_213943984915_item	2266640	et	3	main
tähenda	doc_213943984915_item	2266642	et	4	main
siin	doc_213943984915_item	2266643	et	4	main
midagi	doc_213943984915_item	2266644	et	4	main
vaid	doc_213943984915_item	2266646	et	3	main
kotkase	doc_213943984915_item	2266657	et	4	main
hakatigi	doc_213943984915_item	2266666	et	3	main
perekonnanimi	doc_213943984915_item	2266673	et	3	main
kes	doc_213943984916_item	2266701	et	4	main
sõnas	doc_213943984916_item	2266704	et	4	main
linnaosa	doc_213943984916_item	2266706	et	4	main
savisaar	doc_213943984916_item	2266709	et	3	main
hetkest	doc_213943984916_item	2266721	et	4	main
ent	doc_213943984916_item	2266724	et	3	main
areng	doc_213943984916_item	2266726	et	3	main
süsteemitu	doc_213943984916_item	2266728	et	4	main
määravateks	doc_213943984916_item	2266730	et	4	main
huvid	doc_213943984916_item	2266737	et	3	main
hakati	doc_213943984916_item	2266744	et	3	main
aastal	doc_213943984916_item	2266748	et	3	main
lisaks	doc_213943984916_item	2266756	et	4	main
loetelu	doc_213943984916_item	2266762	et	4	main
eelseisvaks	doc_213943984916_item	2266763	et	3	main
lähi	doc_213943984916_item	2266765	et	4	main
venelased	doc_213943984915_item	2266327	et	3	main
kohalike	doc_213943984915_item	2266330	et	4	main
neidudega	doc_213943984915_item	2266331	et	3	main
tjebja	doc_213943984915_item	2266341	et	4	main
nüüd	doc_213943984915_item	2266343	et	4	main
raske	doc_213943984915_item	2266358	et	4	main
saada	doc_213943984915_item	2266360	et	4	main
kuigi	doc_213943984915_item	2266361	et	3	main
see	doc_213943984915_item	2266362	et	3	main
jäänud	doc_213943984915_item	2266376	et	4	main
ehitamise	doc_213943984915_item	2266384	et	4	main
perioodil	doc_213943984915_item	2266385	et	3	main
rohkem	doc_213943984915_item	2266386	et	4	main
kui	doc_213943984915_item	2266387	et	3	main
kahe	doc_213943984915_item	2266388	et	3	main
kümnendi	doc_213943984915_item	2266389	et	3	main
kuni	doc_213943984915_item	2266391	et	3	main
1854	doc_213943984915_item	2266392	et	2	main
aastani	doc_213943984915_item	2266393	et	3	main
kui	doc_213943984915_item	2266394	et	3	main
bomarsund	doc_213943984915_item	2266395	et	4	main
vältel	doc_213943984915_item	2266390	et	4	main
lammutati	doc_213943984915_item	2266396	et	3	main
krimmi	doc_213943984915_item	2266397	et	4	main
sõjas	doc_213943984915_item	2266398	et	3	main
maha	doc_213943984915_item	2266399	et	4	main
hiljem	doc_213943984915_item	2266400	et	3	main
isegi	doc_213943984915_item	2266401	et	4	main
kuni	doc_213943984915_item	2266402	et	3	main
oktoobri	doc_213943984915_item	2266403	et	3	main
revolutsioonini	doc_213943984915_item	2266404	et	3	main
kas	doc_213943984915_item	2266405	et	3	main
on	doc_213943984915_item	2266406	et	4	main
rääkida	doc_213943984915_item	2266408	et	3	main
vaja	doc_213943984915_item	2266407	et	4	main
kui	doc_213943984915_item	2266409	et	3	main
suur	doc_213943984915_item	2266410	et	3	main
hulk	doc_213943984915_item	2266411	et	3	main
meie	doc_213943984915_item	2266412	et	4	main
sõjaväelaste	doc_213943984915_item	2266413	et	4	main
ohvitseride	doc_213943984915_item	2266414	et	3	main
kaupmeeste	doc_213943984915_item	2266415	et	4	main
ja	doc_213943984915_item	2266416	et	3	main
meistrite	doc_213943984915_item	2266417	et	3	main
järeltulijaid	doc_213943984915_item	2266418	et	3	main
postihoone	doc_213943984915_item	2266428	et	4	main
näeb	doc_213943984915_item	2266438	et	3	main
nagu	doc_213943984915_item	2266440	et	3	main
rääkisid	doc_213943984915_item	2266442	et	4	main
külma	doc_213943984915_item	2266450	et	4	main
ajal	doc_213943984915_item	2266452	et	4	main
polnud	doc_213943984915_item	2266453	et	3	main
alandi	doc_213943984915_item	2266454	et	4	main
ühtegi	doc_213943984915_item	2266457	et	4	main
viimasel	doc_213943984915_item	2266462	et	3	main
buum	doc_213943984915_item	2266467	et	3	main
rohkem	doc_213943984915_item	2266469	et	4	main
posti	doc_213943984915_item	2266470	et	4	main
kohale	doc_213943984915_item	2266472	et	4	main
kuigi	doc_213943984915_item	2266474	et	3	main
elanikud	doc_213943984915_item	2266475	et	3	main
lahenes	doc_213943984915_item	2266480	et	3	main
kes	doc_213943984915_item	2266483	et	4	main
vene	doc_213943984915_item	2266485	et	4	main
juuri	doc_213943984915_item	2266486	et	4	main
äkki	doc_213943984915_item	2266488	et	3	main
üle	doc_213943984915_item	2266499	et	3	main
uhkust	doc_213943984915_item	2266501	et	4	main
tundma	doc_213943984915_item	2266502	et	3	main
venekeelset	doc_213943984915_item	2266503	et	3	main
kõnet	doc_213943984915_item	2266504	et	3	main
aga	doc_213943984915_item	2266505	et	3	main
ei	doc_213943984915_item	2266506	et	4	main
suutnud	doc_213943984915_item	2266507	et	4	main
sõda	doc_213943984915_item	2266508	et	4	main
summutada	doc_213943984915_item	2266509	et	3	main
sellepärast	doc_213943984915_item	2266510	et	3	main
võib	doc_213943984915_item	2266511	et	3	main
meie	doc_213943984915_item	2266512	et	4	main
turisti	doc_213943984915_item	2266513	et	4	main
jaoks	doc_213943984915_item	2266514	et	4	main
kõnelemine	doc_213943984915_item	2266515	et	4	main
põlise	doc_213943984915_item	2266516	et	4	main
alandi	doc_213943984915_item	2266517	et	4	main
elanikuga	doc_213943984915_item	2266519	et	3	main
saarte	doc_213943984915_item	2266518	et	3	main
kujuneda	doc_213943984915_item	2266520	et	3	main
viimase	doc_213943984915_item	2266445	et	3	main
imelikust	doc_213943984915_item	2266447	et	4	main
peaaegu	doc_213943984915_item	2266456	et	3	main
perekonnanimega	doc_213943984915_item	2266459	et	3	main
toimetatakse	doc_213943984915_item	2266471	et	3	main
jäänud	doc_213943984915_item	2266477	et	4	main
samadeks	doc_213943984915_item	2266478	et	3	main
varjasid	doc_213943984915_item	2266484	et	4	main
hakkasid	doc_213943984915_item	2266492	et	4	main
petrovide	doc_213943984915_item	2266496	et	4	main
isegi	doc_213943984915_item	2266500	et	4	main
tõeliseks	doc_213943984915_item	2266521	et	4	main
borštš	doc_213943984915_item	2266527	et	2	main
ole	doc_213943984915_item	2266540	et	4	main
meister	doc_213943984915_item	2266543	et	3	main
meie	doc_213943984915_item	2266551	et	4	main
sõnad	doc_213943984915_item	2266553	et	4	main
ehk	doc_213943984915_item	2266555	et	3	main
soni	doc_213943984915_item	2266557	et	4	main
vajalikud	doc_213943984915_item	2266577	et	3	main
on	doc_213943984915_item	2266579	et	4	main
meie	doc_213943984915_item	2266581	et	4	main
omad	doc_213943984915_item	2266582	et	4	main
venelased	doc_213943984915_item	2266594	et	3	main
selgeks	doc_213943984915_item	2266597	et	3	main
ehk	doc_213943984915_item	2266604	et	3	main
kofta	doc_213943984915_item	2266607	et	4	main
siis	doc_213943984915_item	2266616	et	3	main
tunnistab	doc_213943984915_item	2266528	et	3	main
rääkides	doc_213943984915_item	2266530	et	4	main
ja	doc_213943984915_item	2266532	et	3	main
ei	doc_213943984915_item	2266539	et	4	main
keetmise	doc_213943984915_item	2266542	et	4	main
toredalt	doc_213943984915_item	2266545	et	4	main
kartuh	doc_213943984915_item	2266554	et	4	main
картуз	doc_213943984915_item	2266556	et	2	main
ek	doc_213943984915_item	2266558	et	4	main
butka	doc_213943984915_item	2266559	et	4	main
ehk	doc_213943984915_item	2266564	et	3	main
siin	doc_213943984915_item	2266567	et	4	main
kusjuures	doc_213943984915_item	2266568	et	3	main
süüakse	doc_213943984915_item	2266569	et	3	main
ehtsat	doc_213943984915_item	2266571	et	3	main
vene	doc_213943984915_item	2266572	et	4	main
pirogi	doc_213943984915_item	2266583	et	4	main
пироги	doc_213943984915_item	2266585	et	2	main
ehk	doc_213943984915_item	2266588	et	3	main
õpetasid	doc_213943984915_item	2266592	et	4	main
elanikele	doc_213943984915_item	2266596	et	3	main
õhuakende	doc_213943984915_item	2266598	et	3	main
mis	doc_213943984915_item	2266600	et	4	main
imestage	doc_213943984915_item	2266617	et	3	main
elanik	doc_213943984915_item	2266621	et	3	main
sai	doc_213943984915_item	2266632	et	4	main
kellegi	doc_213943984915_item	2266634	et	4	main
muu	doc_213943984915_item	2266635	et	4	main
kui	doc_213943984915_item	2266636	et	3	main
ei	doc_213943984915_item	2266641	et	4	main
trükitud	doc_213943984915_item	2266650	et	4	main
samasugune	doc_213943984915_item	2266661	et	3	main
ka	doc_213943984915_item	2266663	et	3	main
medalitel	doc_213943984915_item	2266664	et	3	main
autasu	doc_213943984915_item	2266668	et	4	main
eesnimi	doc_213943984915_item	2266672	et	3	main
osa	doc_213943984916_item	2266712	et	4	main
põhja-tallinn	doc_213943984916_item	2266714	et	4	main
arenes	doc_213943984916_item	2266715	et	3	main
jõudsalt	doc_213943984916_item	2266716	et	4	main
selle	doc_213943984916_item	2266719	et	4	main
see	doc_213943984916_item	2266725	et	3	main
arenguplaani	doc_213943984916_item	2266743	et	4	main
väljatöötama	doc_213943984916_item	2266745	et	4	main
eelmisel	doc_213943984916_item	2266750	et	3	main
eesmärkidele	doc_213943984916_item	2266757	et	3	main
neljaks	doc_213943984916_item	2266764	et	4	main
paika	doc_213943984916_item	2266768	et	4	main
tähtaegadega	doc_213943984916_item	2266770	et	3	main
on	doc_213943984916_item	2266772	et	4	main
arendajad	doc_213943984916_item	2266775	et	4	main
rahastajad	doc_213943984916_item	2266776	et	4	main
kui	doc_213943984916_item	2266777	et	3	main
ellu	doc_213943984916_item	2266781	et	4	main
2010	doc_213943984916_item	2266787	et	2	main
ühiselamud	doc_213943984916_item	2266833	et	3	main
eelseisva	doc_213943984916_item	2266854	et	3	main
peamisteks	doc_213943984916_item	2266856	et	3	main
kopli	doc_213943984916_item	2266859	et	3	main
sirbi-vasara	doc_213943984916_item	2266862	et	3	main
kvartali	doc_213943984916_item	2266863	et	3	main
vanad	doc_213943984916_item	2266869	et	3	main
kus	doc_213943984916_item	2266871	et	3	main
lähiaastate	doc_213943984916_item	2266877	et	3	main
kimbutama	doc_213943984916_item	2266891	et	3	main
on	doc_213943984916_item	2266897	et	4	main
kalamaja	doc_213943984916_item	2266900	et	4	main
tänava	doc_213943984916_item	2266907	et	4	main
transpordisõlm	doc_213943984916_item	2266909	et	3	main
põhja-tallinna	doc_213943984916_item	2266910	et	4	main
ning	doc_213943984916_item	2266920	et	3	main
lasteaiad	doc_213943984916_item	2266921	et	4	main
täiustada	doc_213943984916_item	2266923	et	3	main
uute	doc_213943984916_item	2266924	et	3	main
ehitustöödega	doc_213943984916_item	2266932	et	3	main
saanud	doc_213943984916_item	2266946	et	4	main
linlaste	doc_213943984916_item	2266947	et	3	main
ning	doc_213943984916_item	2266952	et	3	main
seetõttu	doc_213943984916_item	2266960	et	3	main
aga	doc_213943984916_item	2266970	et	3	main
heakorrastada	doc_213943984916_item	2266971	et	3	main
kuur	doc_213943984915_item	2266562	et	3	main
ehk	doc_213943984915_item	2266584	et	3	main
õhuaken	doc_213943984915_item	2266590	et	3	main
muuseas	doc_213943984915_item	2266591	et	3	main
just	doc_213943984915_item	2266593	et	3	main
saarte	doc_213943984915_item	2266595	et	3	main
med	doc_213943984915_item	2266603	et	4	main
кофтка	doc_213943984915_item	2266609	et	2	main
гостинцы	doc_213943984915_item	2266613	et	2	main
kui	doc_213943984915_item	2266618	et	3	main
pilk	doc_213943984915_item	2266626	et	3	main
mille	doc_213943984915_item	2266629	et	3	main
vene	doc_213943984915_item	2266637	et	4	main
valitseja	doc_213943984915_item	2266638	et	4	main
käest	doc_213943984915_item	2266639	et	4	main
söödavat	doc_213943984915_item	2266645	et	4	main
präänikute	doc_213943984915_item	2266652	et	3	main
peal	doc_213943984915_item	2266653	et	4	main
oli	doc_213943984915_item	2266654	et	3	main
tavaliselt	doc_213943984915_item	2266655	et	4	main
tempel	doc_213943984915_item	2266659	et	3	main
peaaegu	doc_213943984915_item	2266660	et	3	main
nimetama	doc_213943984915_item	2266670	et	3	main
tallinna	doc_213943984916_item	2266710	et	4	main
alates	doc_213943984916_item	2266718	et	3	main
loomise	doc_213943984916_item	2266720	et	4	main
juba	doc_213943984916_item	2266746	et	3	main
kinnitati	doc_213943984916_item	2266752	et	4	main
see	doc_213943984916_item	2266753	et	3	main
tallinna	doc_213943984916_item	2266754	et	4	main
linnavolikogus	doc_213943984916_item	2266755	et	4	main
sisaldab	doc_213943984916_item	2266758	et	3	main
arengukava	doc_213943984916_item	2266759	et	4	main
konkreetsete	doc_213943984916_item	2266760	et	3	main
määratud	doc_213943984916_item	2266771	et	4	main
konkreetsed	doc_213943984916_item	2266774	et	3	main
kõik	doc_213943984916_item	2266778	et	4	main
saab	doc_213943984916_item	2266782	et	3	main
väita	doc_213943984916_item	2266789	et	4	main
arhitektuuriliselt	doc_213943984916_item	2266821	et	4	main
rajatisi	doc_213943984916_item	2266823	et	3	main
ootavad	doc_213943984916_item	2266830	et	4	main
küllatki	doc_213943984916_item	2266840	et	4	main
räsitud	doc_213943984916_item	2266842	et	4	main
plaanis	doc_213943984916_item	2266844	et	4	main
on	doc_213943984916_item	2266858	et	4	main
liinide	doc_213943984916_item	2266860	et	3	main
ning	doc_213943984916_item	2266861	et	3	main
moodustavad	doc_213943984916_item	2266868	et	4	main
tehnovõrkudega	doc_213943984916_item	2266876	et	3	main
plaanides	doc_213943984916_item	2266878	et	4	main
koplis	doc_213943984916_item	2266885	et	3	main
linnaosa	doc_213943984916_item	2266888	et	4	main
ümberehitamine	doc_213943984916_item	2266895	et	3	main
mõttes	doc_213943984916_item	2266899	et	3	main
aga	doc_213943984916_item	2266904	et	3	main
sitsi	doc_213943984916_item	2266906	et	4	main
alguse	doc_213943984916_item	2266908	et	3	main
arengukavas	doc_213943984916_item	2266911	et	3	main
renoveerimist	doc_213943984916_item	2266917	et	4	main
tehnikavahenditega	doc_213943984916_item	2266925	et	3	main
spordikompleksi	doc_213943984916_item	2266931	et	4	main
ning	doc_213943984916_item	2266933	et	3	main
renoveerimisega	doc_213943984916_item	2266936	et	4	main
meelispuhkepaik	doc_213943984916_item	2266948	et	3	main
suvel	doc_213943984916_item	2266950	et	3	main
piirkondadest	doc_213943984916_item	2266959	et	3	main
on	doc_213943984916_item	2266961	et	4	main
muuta	doc_213943984916_item	2266963	et	4	main
enam	doc_213943984916_item	2266967	et	4	main
ligipääsetavamaks	doc_213943984916_item	2266968	et	4	main
mis	doc_213943984917_item	2267009	et	4	main
väljapeetud	doc_213943984917_item	2267011	et	4	main
kohvik	doc_213943984917_item	2267017	et	3	main
mis	doc_213943984917_item	2267022	et	4	main
aadressil	doc_213943984917_item	2267027	et	3	main
22	doc_213943984917_item	2267029	et	2	main
ning	doc_213943984917_item	2267030	et	3	main
ilmestavad	doc_213943984917_item	2267044	et	4	main
ajastutruu	doc_213943984917_item	2267051	et	4	main
selle	doc_213943984915_item	2266575	et	4	main
tootmiseks	doc_213943984915_item	2266576	et	4	main
ahjud	doc_213943984915_item	2266578	et	3	main
jäänud	doc_213943984915_item	2266580	et	4	main
fortuška	doc_213943984915_item	2266587	et	2	main
tuulutamist	doc_213943984915_item	2266602	et	4	main
mesi	doc_213943984915_item	2266606	et	4	main
ehk	doc_213943984915_item	2266608	et	3	main
kampsun	doc_213943984915_item	2266610	et	3	main
gastinsõ	doc_213943984915_item	2266611	et	4	main
külakost	doc_213943984915_item	2266614	et	3	main
saarte	doc_213943984915_item	2266620	et	3	main
pakub	doc_213943984915_item	2266622	et	3	main
prännikule	doc_213943984915_item	2266625	et	4	main
vana-vanaisa	doc_213943984915_item	2266631	et	4	main
või	doc_213943984915_item	2266648	et	4	main
medalit	doc_213943984915_item	2266649	et	3	main
vene	doc_213943984915_item	2266651	et	4	main
nii	doc_213943984915_item	2266665	et	3	main
maiustuseks	doc_213943984915_item	2266669	et	4	main
põhja-tallinna	doc_213943984916_item	2266705	et	4	main
vilja	doc_213943984916_item	2266708	et	4	main
v	doc_213943984916_item	2266713	et	4	main
juba	doc_213943984916_item	2266717	et	3	main
1993	doc_213943984916_item	2266722	et	2	main
peamisteks	doc_213943984916_item	2266729	et	3	main
asjaoludeks	doc_213943984916_item	2266731	et	3	main
seni	doc_213943984916_item	2266733	et	3	main
olnud	doc_213943984916_item	2266734	et	4	main
erinevad	doc_213943984916_item	2266735	et	4	main
majanduslikud	doc_213943984916_item	2266736	et	3	main
märkis	doc_213943984916_item	2266738	et	3	main
vanem	doc_213943984916_item	2266740	et	4	main
põhja-tallinna	doc_213943984916_item	2266741	et	4	main
tasakaalustatud	doc_213943984916_item	2266742	et	4	main
2003	doc_213943984916_item	2266747	et	2	main
projektide	doc_213943984916_item	2266761	et	3	main
ühes	doc_213943984916_item	2266767	et	4	main
viidud	doc_213943984916_item	2266783	et	4	main
keegi	doc_213943984916_item	2266786	et	4	main
pelgalt	doc_213943984916_item	2266793	et	4	main
lihvimata	doc_213943984916_item	2266794	et	4	main
teemant	doc_213943984916_item	2266795	et	4	main
väärtuslikke	doc_213943984916_item	2266822	et	3	main
ning	doc_213943984916_item	2266824	et	3	main
alles	doc_213943984916_item	2266827	et	3	main
renoveerimist	doc_213943984916_item	2266829	et	4	main
munitsipaalomandis	doc_213943984916_item	2266831	et	3	main
paljud	doc_213943984916_item	2266835	et	3	main
väljanägemisega	doc_213943984916_item	2266843	et	3	main
on	doc_213943984916_item	2266845	et	4	main
jätkata	doc_213943984916_item	2266846	et	4	main
munitsipaalelamufondi	doc_213943984916_item	2266847	et	4	main
sotsiaalmajade	doc_213943984916_item	2266848	et	3	main
varjupaikade	doc_213943984916_item	2266850	et	4	main
rajamist	doc_213943984916_item	2266852	et	4	main
loomist	doc_213943984916_item	2266853	et	4	main
aasta	doc_213943984916_item	2266855	et	4	main
plaanideks	doc_213943984916_item	2266857	et	3	main
suurema	doc_213943984916_item	2266865	et	4	main
esinevad	doc_213943984916_item	2266873	et	4	main
probleemid	doc_213943984916_item	2266875	et	3	main
renoveerimistööd	doc_213943984916_item	2266883	et	4	main
elanikke	doc_213943984916_item	2266889	et	3	main
teede	doc_213943984916_item	2266894	et	3	main
eelistumad	doc_213943984916_item	2266896	et	4	main
ümbersõidud	doc_213943984916_item	2266903	et	3	main
sotsiaalobjektide	doc_213943984916_item	2266915	et	3	main
ootavad	doc_213943984916_item	2266918	et	4	main
kultuuriasutusi	doc_213943984916_item	2266927	et	4	main
gümnaasiumi	doc_213943984916_item	2266930	et	4	main
spordirajatiste	doc_213943984916_item	2266935	et	3	main
luuakse	doc_213943984916_item	2266937	et	3	main
noorte	doc_213943984916_item	2266940	et	3	main
põhja-tallinnast	doc_213943984916_item	2266942	et	3	main
juba	doc_213943984916_item	2266944	et	3	main
eriti	doc_213943984916_item	2266949	et	3	main
tallinlasi	doc_213943984916_item	2266955	et	3	main
ennekõike	doc_213943984916_item	2266969	et	3	main
peale	doc_213943984915_item	2266627	et	4	main
ei	doc_213943984915_item	2266633	et	4	main
hoopisordenit	doc_213943984915_item	2266647	et	3	main
kuningliku	doc_213943984915_item	2266656	et	3	main
kujuga	doc_213943984915_item	2266658	et	3	main
nagu	doc_213943984915_item	2266662	et	3	main
vene	doc_213943984915_item	2266667	et	4	main
stockholm	doc_213943984915_item	2266671	et	4	main
tõlge	doc_213943984916_item	2266674	et	3	main
stroomi	doc_213943984916_item	2266675	et	4	main
randa	doc_213943984916_item	2266676	et	4	main
tuleb	doc_213943984916_item	2266677	et	3	main
veepark	doc_213943984916_item	2266678	et	3	main
esimesel	doc_213943984916_item	2266679	et	3	main
pärast	doc_213943984916_item	2266680	et	4	main
jõulupühi	doc_213943984916_item	2266681	et	3	main
pealinna	doc_213943984916_item	2266682	et	4	main
volikogu	doc_213943984916_item	2266683	et	4	main
istungil	doc_213943984916_item	2266684	et	3	main
kinnitati	doc_213943984916_item	2266685	et	4	main
põhja-tallinna	doc_213943984916_item	2266686	et	4	main
linnaosa	doc_213943984916_item	2266687	et	4	main
arengukava	doc_213943984916_item	2266688	et	4	main
kinnitatud	doc_213943984916_item	2266689	et	4	main
arengukava	doc_213943984916_item	2266690	et	4	main
kohaselt	doc_213943984916_item	2266691	et	4	main
2007	doc_213943984916_item	2266692	et	2	main
2010	doc_213943984916_item	2266693	et	2	main
aastal	doc_213943984916_item	2266694	et	3	main
saab	doc_213943984916_item	2266695	et	3	main
linnaosa	doc_213943984916_item	2266696	et	4	main
jätkuvalt	doc_213943984916_item	2266697	et	4	main
areneda	doc_213943984916_item	2266698	et	3	main
olenemata	doc_213943984916_item	2266699	et	4	main
sellest	doc_213943984916_item	2266700	et	4	main
saab	doc_213943984916_item	2266702	et	3	main
võmule	doc_213943984916_item	2266703	et	4	main
vanem	doc_213943984916_item	2266707	et	4	main
põhjapoolne	doc_213943984916_item	2266711	et	3	main
aastal	doc_213943984916_item	2266723	et	3	main
oli	doc_213943984916_item	2266727	et	3	main
on	doc_213943984916_item	2266732	et	4	main
linnaosa	doc_213943984916_item	2266739	et	4	main
ning	doc_213943984916_item	2266749	et	3	main
neljapäeval	doc_213943984916_item	2266751	et	3	main
pandud	doc_213943984916_item	2266769	et	4	main
plaanitu	doc_213943984916_item	2266779	et	4	main
ei	doc_213943984916_item	2266784	et	4	main
et	doc_213943984916_item	2266790	et	3	main
on	doc_213943984916_item	2266792	et	4	main
on	doc_213943984916_item	2266797	et	4	main
korda	doc_213943984916_item	2266798	et	4	main
teha	doc_213943984916_item	2266799	et	3	main
saada	doc_213943984916_item	2266800	et	4	main
vanad	doc_213943984916_item	2266801	et	3	main
hooned	doc_213943984916_item	2266802	et	4	main
ehitised	doc_213943984916_item	2266803	et	3	main
lammutada	doc_213943984916_item	2266804	et	3	main
või	doc_213943984916_item	2266805	et	4	main
taastada	doc_213943984916_item	2266806	et	3	main
renoveerida	doc_213943984916_item	2266807	et	4	main
amortiseeritud	doc_213943984916_item	2266808	et	4	main
ning	doc_213943984916_item	2266809	et	3	main
omanike	doc_213943984916_item	2266810	et	3	main
hüljatud	doc_213943984916_item	2266811	et	4	main
mahajäetud	doc_213943984916_item	2266812	et	4	main
maju	doc_213943984916_item	2266813	et	3	main
see	doc_213943984916_item	2266814	et	3	main
on	doc_213943984916_item	2266815	et	4	main
keeruline	doc_213943984916_item	2266816	et	4	main
ülesanne	doc_213943984916_item	2266817	et	4	main
sest	doc_213943984916_item	2266818	et	4	main
piirkonnas	doc_213943984916_item	2266819	et	4	main
on	doc_213943984916_item	2266820	et	4	main
aastaks	doc_213943984916_item	2266766	et	4	main
ka	doc_213943984916_item	2266773	et	3	main
ka	doc_213943984916_item	2266780	et	3	main
saa	doc_213943984916_item	2266785	et	4	main
aastal	doc_213943984916_item	2266788	et	3	main
põhja-tallinn	doc_213943984916_item	2266791	et	4	main
plaanis	doc_213943984916_item	2266796	et	4	main
tuleks	doc_213943984916_item	2266826	et	4	main
mis	doc_213943984916_item	2266838	et	4	main
on	doc_213943984916_item	2266839	et	4	main
kulunud	doc_213943984916_item	2266841	et	4	main
kvartalid	doc_213943984916_item	2266870	et	3	main
teatavasti	doc_213943984916_item	2266872	et	3	main
märkimisväärsed	doc_213943984916_item	2266874	et	3	main
on	doc_213943984916_item	2266879	et	4	main
mahukad	doc_213943984916_item	2266881	et	3	main
veevärgi	doc_213943984916_item	2266882	et	3	main
kalamajas	doc_213943984916_item	2266884	et	3	main
pelgulinnas	doc_213943984916_item	2266887	et	4	main
ka	doc_213943984916_item	2266892	et	3	main
selles	doc_213943984916_item	2266898	et	4	main
ning	doc_213943984916_item	2266901	et	3	main
on	doc_213943984916_item	2266912	et	4	main
suur	doc_213943984916_item	2266913	et	3	main
neid	doc_213943984916_item	2266825	et	4	main
jätta	doc_213943984916_item	2266828	et	3	main
olevad	doc_213943984916_item	2266832	et	4	main
ka	doc_213943984916_item	2266834	et	3	main
mitmed	doc_213943984916_item	2266836	et	4	main
paneelelamud	doc_213943984916_item	2266837	et	3	main
ning	doc_213943984916_item	2266849	et	3	main
hooldekodude	doc_213943984916_item	2266851	et	3	main
renoveerimisprojektid	doc_213943984916_item	2266864	et	3	main
osa	doc_213943984916_item	2266866	et	4	main
põhja-tallinnast	doc_213943984916_item	2266867	et	3	main
veel	doc_213943984916_item	2266880	et	4	main
ja	doc_213943984916_item	2266886	et	3	main
hakkab	doc_213943984916_item	2266890	et	3	main
suuremahuline	doc_213943984916_item	2266893	et	4	main
pelgulinna	doc_213943984916_item	2266902	et	4	main
ka	doc_213943984916_item	2266905	et	3	main
rõhk	doc_213943984916_item	2266914	et	3	main
renoveerimisele	doc_213943984916_item	2266916	et	4	main
munitsipaalkoolid	doc_213943984916_item	2266919	et	3	main
plaanitakse	doc_213943984916_item	2266922	et	4	main
õppe-ning	doc_213943984916_item	2266926	et	3	main
alustatakse	doc_213943984916_item	2266928	et	3	main
olemasolevate	doc_213943984916_item	2266934	et	3	main
avatud	doc_213943984916_item	2266939	et	4	main
keskus	doc_213943984916_item	2266941	et	3	main
supelrannad	doc_213943984916_item	2266953	et	3	main
meelitavad	doc_213943984916_item	2266954	et	4	main
ka	doc_213943984916_item	2266956	et	3	main
teistest	doc_213943984916_item	2266957	et	4	main
linna	doc_213943984916_item	2266958	et	4	main
otsustatud	doc_213943984916_item	2266962	et	4	main
rannajoon	doc_213943984916_item	2266964	et	3	main
linlastele	doc_213943984916_item	2266965	et	3	main
veel	doc_213943984916_item	2266966	et	4	main
kus	doc_213943984916_item	2266974	et	3	main
vanaaegsete	doc_213943984917_item	2267012	et	4	main
viini	doc_213943984917_item	2267013	et	4	main
paikneb	doc_213943984917_item	2267018	et	3	main
vanas	doc_213943984917_item	2267020	et	3	main
osa	doc_213943984917_item	2267024	et	4	main
külastajale	doc_213943984917_item	2267035	et	4	main
kohviku	doc_213943984917_item	2267036	et	3	main
on	doc_213943984917_item	2267038	et	4	main
kohviku	doc_213943984917_item	2267042	et	3	main
on	doc_213943984917_item	2267050	et	4	main
ning	doc_213943984917_item	2267062	et	3	main
saab	doc_213943984917_item	2267066	et	3	main
pargiteemalist	doc_213943984917_item	2267068	et	4	main
ning	doc_213943984917_item	2267070	et	3	main
postereid	doc_213943984917_item	2267072	et	4	main
veel	doc_213943984917_item	2267074	et	4	main
kohviku	doc_213943984917_item	2267084	et	3	main
teostas	doc_213943984917_item	2267086	et	3	main
sõle	doc_213943984916_item	2266929	et	3	main
ka	doc_213943984916_item	2266938	et	3	main
on	doc_213943984916_item	2266943	et	4	main
ammu	doc_213943984916_item	2266945	et	4	main
pargid	doc_213943984916_item	2266951	et	4	main
ka	doc_213943984916_item	2266978	et	3	main
rannapark	doc_213943984916_item	2266979	et	3	main
ning	doc_213943984916_item	2266980	et	3	main
merimets	doc_213943984916_item	2266981	et	3	main
on	doc_213943984916_item	2266977	et	4	main
srtoomi	doc_213943984916_item	2266982	et	4	main
ranna	doc_213943984916_item	2266983	et	3	main
vetelpääste	doc_213943984916_item	2266984	et	4	main
hoone	doc_213943984916_item	2266985	et	4	main
kõrvale	doc_213943984916_item	2266986	et	4	main
rajatakse	doc_213943984916_item	2266987	et	4	main
varsti	doc_213943984916_item	2266988	et	3	main
ka	doc_213943984916_item	2266989	et	3	main
kaasaegne	doc_213943984916_item	2266990	et	3	main
veepark	doc_213943984916_item	2266991	et	3	main
tõlge	doc_213943984917_item	2266992	et	3	main
kadriorus	doc_213943984917_item	2266993	et	3	main
uus	doc_213943984917_item	2266995	et	3	main
avati	doc_213943984917_item	2266994	et	3	main
kohvik	doc_213943984917_item	2266996	et	3	main
tiigi	doc_213943984917_item	2266997	et	3	main
ääres	doc_213943984917_item	2266998	et	4	main
möödunud	doc_213943984917_item	2266999	et	4	main
pühapäeval	doc_213943984917_item	2267000	et	3	main
avati	doc_213943984917_item	2267001	et	3	main
kadriorus	doc_213943984917_item	2267002	et	3	main
luigetiigi	doc_213943984917_item	2267003	et	3	main
ääres	doc_213943984917_item	2267004	et	4	main
kohvik	doc_213943984917_item	2267006	et	3	main
park	doc_213943984917_item	2267007	et	3	main
uus	doc_213943984917_item	2267005	et	3	main
cafe	doc_213943984917_item	2267008	et	4	main
stroomi	doc_213943984916_item	2266972	et	4	main
lisaks	doc_213943984916_item	2266975	et	4	main
supelrannale	doc_213943984916_item	2266976	et	3	main
kohvikute	doc_213943984917_item	2267015	et	4	main
traditsioonis	doc_213943984917_item	2267016	et	3	main
majakeses	doc_213943984917_item	2267021	et	4	main
on	doc_213943984917_item	2267023	et	4	main
weizenbergi	doc_213943984917_item	2267028	et	4	main
40-le	doc_213943984917_item	2267033	et	3	main
suveterrass	doc_213943984917_item	2267037	et	3	main
interjööri	doc_213943984917_item	2267043	et	4	main
ettekandjate	doc_213943984917_item	2267048	et	3	main
kavatsetakse	doc_213943984917_item	2267054	et	3	main
pargi	doc_213943984917_item	2267056	et	4	main
võimalust	doc_213943984917_item	2267061	et	3	main
kust	doc_213943984917_item	2267065	et	4	main
aga	doc_213943984917_item	2267079	et	3	main
ning	doc_213943984917_item	2267081	et	3	main
vabaõhuüritusi	doc_213943984917_item	2267083	et	3	main
renoveerimistöid	doc_213943984917_item	2267085	et	3	main
as	doc_213943984917_item	2267089	et	4	main
sisekujunduse	doc_213943984917_item	2267090	et	3	main
autor	doc_213943984917_item	2267091	et	3	main
on	doc_213943984917_item	2267092	et	4	main
kohvik	doc_213943984917_item	2267095	et	3	main
tammsaare	doc_213943984917_item	2267129	et	3	main
väliskunsti	doc_213943984917_item	2267136	et	4	main
oma	doc_213943984917_item	2267140	et	4	main
järge	doc_213943984917_item	2267141	et	4	main
veel	doc_213943984917_item	2267143	et	4	main
muuseum	doc_213943984917_item	2267145	et	3	main
ning	doc_213943984917_item	2267146	et	3	main
русская	doc_213943984918_item	2267153	et	2	main
церкви	doc_213943984918_item	2267157	et	2	main
состоится	doc_213943984918_item	2267162	et	2	main
россии	doc_213943984918_item	2267168	et	2	main
чайковского	doc_213943984918_item	2267174	et	2	main
вокальний	doc_213943984918_item	2267181	et	2	main
и	doc_213943984918_item	2267187	et	2	main
которые	doc_213943984918_item	2267191	et	2	main
хоровых	doc_213943984918_item	2267195	et	2	main
оперных	doc_213943984918_item	2267199	et	2	main
целью	doc_213943984918_item	2267204	et	2	main
считает	doc_213943984918_item	2267207	et	2	main
хоровой	doc_213943984918_item	2267212	et	2	main
русская	doc_213943984918_item	2267217	et	2	main
песнопений	doc_213943984918_item	2267224	et	2	main
и	doc_213943984918_item	2267230	et	2	main
самими	doc_213943984918_item	2267250	et	2	main
значительную	doc_213943984918_item	2267253	et	2	main
их	doc_213943984918_item	2267256	et	2	main
великих	doc_213943984918_item	2267261	et	2	main
танеева	doc_213943984918_item	2267265	et	2	main
на	doc_213943984918_item	2267269	et	2	main
koorilaul	doc_213943984918_item	2267275	et	4	main
jaanuaril	doc_213943984918_item	2267277	et	3	main
tulnud	doc_213943984918_item	2267284	et	4	main
ning	doc_213943984918_item	2267295	et	3	main
heliloojade	doc_213943984918_item	2267298	et	4	main
sealhulgas	doc_213943984918_item	2267330	et	3	main
harvaesitatud	doc_213943984918_item	2267339	et	3	main
ansambel	doc_213943984918_item	2267343	et	3	main
ka	doc_213943984918_item	2267345	et	3	main
tantsu-	doc_213943984918_item	2267350	et	4	main
ja	doc_213943984918_item	2267351	et	3	main
kui	doc_213943984918_item	2267357	et	3	main
liikmed	doc_213943984918_item	2267360	et	3	main
on	doc_213943984919_item	2267384	et	4	main
vene	doc_213943984919_item	2267386	et	4	main
on	doc_213943984919_item	2267392	et	4	main
asustatud	doc_213943984919_item	2267393	et	4	main
oma	doc_213943984919_item	2267399	et	4	main
vene	doc_213943984919_item	2267403	et	4	main
looduskaitseala	doc_213943984919_item	2267407	et	4	main
olid	doc_213943984919_item	2267411	et	4	main
alandi	doc_213943984919_item	2267412	et	4	main
saared	doc_213943984919_item	2267413	et	3	main
nimetati	doc_213943984919_item	2267420	et	4	main
aleksandrovna	doc_213943984919_item	2267425	et	4	main
puhkeala	doc_213943984916_item	2266973	et	4	main
on	doc_213943984917_item	2267010	et	4	main
kuulsate	doc_213943984917_item	2267014	et	3	main
pargivahi	doc_213943984917_item	2267019	et	3	main
on	doc_213943984917_item	2267031	et	4	main
mõeldud	doc_213943984917_item	2267032	et	4	main
kohviku	doc_213943984917_item	2267034	et	3	main
inimesele	doc_213943984917_item	2267041	et	3	main
pargivaadetega	doc_213943984917_item	2267046	et	3	main
gravüürid	doc_213943984917_item	2267047	et	3	main
riietus	doc_213943984917_item	2267049	et	4	main
suvel	doc_213943984917_item	2267052	et	3	main
pakkuda	doc_213943984917_item	2267055	et	3	main
ostmise	doc_213943984917_item	2267060	et	4	main
osta	doc_213943984917_item	2267067	et	4	main
teisi	doc_213943984917_item	2267082	et	4	main
xxx	doc_213943984917_item	2267088	et	4	main
perekonnanimi	doc_213943984917_item	2267094	et	3	main
jääb	doc_213943984917_item	2267096	et	3	main
argipäevadel	doc_213943984917_item	2267098	et	3	main
teatavasti	doc_213943984917_item	2267125	et	3	main
paiknevad	doc_213943984917_item	2267127	et	4	main
ning	doc_213943984917_item	2267130	et	3	main
mikkeli	doc_213943984917_item	2267134	et	4	main
ning	doc_213943984917_item	2267138	et	3	main
ootab	doc_213943984917_item	2267142	et	3	main
perekonnanimi	doc_213943984917_item	2267150	et	3	main
хоровая	doc_213943984918_item	2267154	et	2	main
13	doc_213943984918_item	2267158	et	2	main
ансамбля	doc_213943984918_item	2267165	et	2	main
программе	doc_213943984918_item	2267170	et	2	main
чеснокова	doc_213943984918_item	2267175	et	2	main
композиторов	doc_213943984918_item	2267180	et	2	main
из	doc_213943984918_item	2267185	et	2	main
консерватории	doc_213943984918_item	2267190	et	2	main
и	doc_213943984918_item	2267197	et	2	main
своей	doc_213943984918_item	2267202	et	2	main
и	doc_213943984918_item	2267209	et	2	main
в	doc_213943984918_item	2267214	et	2	main
музыка	doc_213943984918_item	2267219	et	2	main
церковных	doc_213943984918_item	2267222	et	2	main
композиторов	doc_213943984918_item	2267229	et	2	main
веков	doc_213943984918_item	2267235	et	2	main
народные	doc_213943984918_item	2267239	et	2	main
аранжированные	doc_213943984918_item	2267244	et	2	main
так	doc_213943984918_item	2267248	et	2	main
часть	doc_213943984918_item	2267254	et	2	main
занимает	doc_213943984918_item	2267259	et	2	main
чайковского	doc_213943984918_item	2267264	et	2	main
каждом	doc_213943984918_item	2267270	et	2	main
kõlab	doc_213943984918_item	2267273	et	3	main
13	doc_213943984918_item	2267276	et	2	main
1900	doc_213943984918_item	2267279	et	2	main
tšesnokovi	doc_213943984918_item	2267292	et	2	main
koorilaulu	doc_213943984918_item	2267321	et	4	main
vaimumuusika	doc_213943984918_item	2267329	et	4	main
laulud	doc_213943984918_item	2267333	et	3	main
heliloojate	doc_213943984918_item	2267335	et	3	main
muusikateosed	doc_213943984918_item	2267337	et	3	main
xviii-xx	doc_213943984918_item	2267340	et	4	main
suur	doc_213943984918_item	2267362	et	3	main
alandi	doc_213943984919_item	2267389	et	4	main
mis	doc_213943984919_item	2267391	et	4	main
1809-1917	doc_213943984919_item	2267410	et	2	main
ning	doc_213943984919_item	2267417	et	3	main
pealinn	doc_213943984919_item	2267418	et	3	main
mariehamn	doc_213943984919_item	2267419	et	4	main
aleksandr	doc_213943984919_item	2267421	et	4	main
naise	doc_213943984919_item	2267423	et	3	main
alandi	doc_213943984919_item	2267438	et	4	main
kinnitada	doc_213943984919_item	2267448	et	3	main
lõpp	doc_213943984919_item	2267451	et	3	main
love	doc_213943984919_item	2267457	et	4	main
oli	doc_213943984919_item	2267462	et	3	main
ehitatud	doc_213943984919_item	2267464	et	4	main
seadmestasid	doc_213943984919_item	2267470	et	4	main
anitshkovi	doc_213943984919_item	2267472	et	4	main
imelik	doc_213943984919_item	2267476	et	3	main
aga	doc_213943984919_item	2267481	et	3	main
tehniline	doc_213943984919_item	2267490	et	3	main
pargi	doc_213943984917_item	2267025	et	4	main
arhitektuuransamblist	doc_213943984917_item	2267026	et	4	main
arvestatud	doc_213943984917_item	2267039	et	4	main
60-le	doc_213943984917_item	2267040	et	3	main
vanaaegsete	doc_213943984917_item	2267045	et	4	main
avada	doc_213943984917_item	2267063	et	3	main
postkaarte	doc_213943984917_item	2267071	et	4	main
tulevikuplaanides	doc_213943984917_item	2267073	et	3	main
korraldada	doc_213943984917_item	2267075	et	3	main
ääres	doc_213943984917_item	2267078	et	4	main
eesnimi	doc_213943984917_item	2267093	et	3	main
9-19	doc_213943984917_item	2267099	et	2	main
laupäeviti	doc_213943984917_item	2267100	et	4	main
9-19	doc_213943984917_item	2267101	et	2	main
ning	doc_213943984917_item	2267102	et	3	main
pühapäeviti	doc_213943984917_item	2267103	et	4	main
10-18	doc_213943984917_item	2267104	et	2	main
abilinnapea	doc_213943984917_item	2267105	et	4	main
eesnimi	doc_213943984917_item	2267106	et	3	main
perekonnanimi	doc_213943984917_item	2267107	et	3	main
sõnade	doc_213943984917_item	2267108	et	3	main
kohaselt	doc_213943984917_item	2267109	et	4	main
kohviku	doc_213943984917_item	2267110	et	3	main
rajati	doc_213943984917_item	2267111	et	3	main
kadrioru	doc_213943984917_item	2267112	et	3	main
arengukava	doc_213943984917_item	2267113	et	4	main
raames	doc_213943984917_item	2267114	et	4	main
sama	doc_213943984917_item	2267115	et	4	main
kava	doc_213943984917_item	2267116	et	4	main
kohaselt	doc_213943984917_item	2267117	et	4	main
peaks	doc_213943984917_item	2267118	et	4	main
tulevikus	doc_213943984917_item	2267119	et	4	main
pargist	doc_213943984917_item	2267120	et	3	main
saama	doc_213943984917_item	2267121	et	4	main
anton-hannsemi	doc_213943984917_item	2267128	et	4	main
vilde	doc_213943984917_item	2267132	et	4	main
majamuuseumid	doc_213943984917_item	2267133	et	3	main
galerii	doc_213943984917_item	2267135	et	4	main
muuseum	doc_213943984917_item	2267137	et	3	main
kumu	doc_213943984917_item	2267139	et	4	main
laste	doc_213943984917_item	2267147	et	4	main
tõlge	doc_213943984918_item	2267151	et	3	main
в	doc_213943984918_item	2267155	et	2	main
в	doc_213943984918_item	2267160	et	2	main
лира	doc_213943984918_item	2267166	et	2	main
прозвучат	doc_213943984918_item	2267171	et	2	main
и	doc_213943984918_item	2267178	et	2	main
ансамбль	doc_213943984918_item	2267182	et	2	main
выпускников	doc_213943984918_item	2267188	et	2	main
в	doc_213943984918_item	2267193	et	2	main
солистами	doc_213943984918_item	2267201	et	2	main
исследование	doc_213943984918_item	2267208	et	2	main
музыки	doc_213943984918_item	2267213	et	2	main
духовная	doc_213943984918_item	2267218	et	2	main
plaanitakse	doc_213943984917_item	2267053	et	4	main
külastajatele	doc_213943984917_item	2267057	et	4	main
suvitajatele	doc_213943984917_item	2267058	et	4	main
piknikukorvide	doc_213943984917_item	2267059	et	3	main
müügipunkt	doc_213943984917_item	2267064	et	3	main
kirjandust	doc_213943984917_item	2267069	et	3	main
kohvikukontserte	doc_213943984917_item	2267076	et	3	main
tiigi	doc_213943984917_item	2267077	et	3	main
jõululaada	doc_213943984917_item	2267080	et	3	main
xxx	doc_213943984917_item	2267087	et	4	main
avatuks	doc_213943984917_item	2267097	et	4	main
park	doc_213943984917_item	2267123	et	3	main
eduard	doc_213943984917_item	2267131	et	4	main
vene	doc_213943984917_item	2267144	et	4	main
преображенской	doc_213943984918_item	2267156	et	2	main
1900	doc_213943984918_item	2267161	et	2	main
вокального	doc_213943984918_item	2267164	et	2	main
из	doc_213943984918_item	2267167	et	2	main
произведения	doc_213943984918_item	2267172	et	2	main
рахманинова	doc_213943984918_item	2267176	et	2	main
других	doc_213943984918_item	2267179	et	2	main
состоит	doc_213943984918_item	2267184	et	2	main
студентов	doc_213943984918_item	2267186	et	2	main
работают	doc_213943984918_item	2267192	et	2	main
коллективах	doc_213943984918_item	2267196	et	2	main
в	doc_213943984918_item	2267198	et	2	main
главной	doc_213943984918_item	2267203	et	2	main
лира	doc_213943984918_item	2267206	et	2	main
популяризацию	doc_213943984918_item	2267210	et	2	main
репертуаре	doc_213943984918_item	2267215	et	2	main
от	doc_213943984918_item	2267220	et	2	main
православных	doc_213943984918_item	2267223	et	2	main
русских	doc_213943984918_item	2267228	et	2	main
произведений	doc_213943984918_item	2267233	et	2	main
исполняет	doc_213943984918_item	2267237	et	2	main
песни	doc_213943984918_item	2267240	et	2	main
ритуальные	doc_213943984918_item	2267243	et	2	main
известными	doc_213943984918_item	2267246	et	2	main
участниками	doc_213943984918_item	2267251	et	2	main
естественно	doc_213943984918_item	2267258	et	2	main
русских	doc_213943984918_item	2267262	et	2	main
звучит	doc_213943984918_item	2267268	et	2	main
toimub	doc_213943984918_item	2267280	et	3	main
lira	doc_213943984918_item	2267286	et	4	main
kontsert	doc_213943984918_item	2267287	et	3	main
on	doc_213943984918_item	2267289	et	4	main
tuntud	doc_213943984918_item	2267297	et	4	main
lauluansambel	doc_213943984918_item	2267300	et	3	main
ja	doc_213943984918_item	2267338	et	3	main
sajandi	doc_213943984918_item	2267341	et	3	main
laulab	doc_213943984918_item	2267344	et	3	main
rahvalaule	doc_213943984918_item	2267347	et	4	main
heliloojad	doc_213943984918_item	2267356	et	3	main
ka	doc_213943984918_item	2267358	et	3	main
eelkäijate	doc_213943984919_item	2267387	et	3	main
saared	doc_213943984919_item	2267390	et	3	main
kes	doc_213943984919_item	2267396	et	4	main
rajasid	doc_213943984919_item	2267397	et	4	main
soome	doc_213943984919_item	2267398	et	3	main
põhjamaades	doc_213943984919_item	2267408	et	4	main
aastatel	doc_213943984919_item	2267409	et	4	main
impeeriumi	doc_213943984919_item	2267415	et	4	main
osa	doc_213943984919_item	2267416	et	4	main
ii	doc_213943984919_item	2267422	et	4	main
keelt	doc_213943984919_item	2267428	et	4	main
saartel	doc_213943984919_item	2267439	et	3	main
nimetus	doc_213943984919_item	2267460	et	4	main
sundsher	doc_213943984919_item	2267461	et	4	main
all	doc_213943984919_item	2267474	et	3	main
ei	doc_213943984919_item	2267479	et	4	main
jäi	doc_213943984919_item	2267484	et	3	main
sõjaväe	doc_213943984919_item	2267487	et	3	main
ka	doc_213943984919_item	2267489	et	3	main
sõnavara	doc_213943984919_item	2267491	et	4	main
optimistlikku	doc_213943984919_item	2267496	et	4	main
sõna	doc_213943984919_item	2267525	et	4	main
tjebja	doc_213943984919_item	2267526	et	4	main
see	doc_213943984919_item	2267531	et	3	main
muuseum	doc_213943984917_item	2267122	et	3	main
pargis	doc_213943984917_item	2267124	et	3	main
juba	doc_213943984917_item	2267126	et	3	main
muuseum	doc_213943984917_item	2267148	et	3	main
lausus	doc_213943984917_item	2267149	et	4	main
звучит	doc_213943984918_item	2267152	et	2	main
января	doc_213943984918_item	2267159	et	2	main
концерт	doc_213943984918_item	2267163	et	2	main
в	doc_213943984918_item	2267169	et	2	main
бортнянского	doc_213943984918_item	2267173	et	2	main
гречанинова	doc_213943984918_item	2267177	et	2	main
лира	doc_213943984918_item	2267183	et	2	main
петербургской	doc_213943984918_item	2267189	et	2	main
разных	doc_213943984918_item	2267194	et	2	main
театрах	doc_213943984918_item	2267200	et	2	main
ансамбль	doc_213943984918_item	2267205	et	2	main
русской	doc_213943984918_item	2267211	et	2	main
коллектива	doc_213943984918_item	2267216	et	2	main
старинных	doc_213943984918_item	2267221	et	2	main
малоизвестных	doc_213943984918_item	2267226	et	2	main
редко	doc_213943984918_item	2267231	et	2	main
xviii-xx	doc_213943984918_item	2267234	et	4	main
и	doc_213943984918_item	2267238	et	2	main
лирические	doc_213943984918_item	2267241	et	2	main
как	doc_213943984918_item	2267245	et	2	main
композиторами	doc_213943984918_item	2267247	et	2	main
ансамбля	doc_213943984918_item	2267252	et	2	main
творчестве	doc_213943984918_item	2267257	et	2	main
композиторов	doc_213943984918_item	2267263	et	2	main
рахманинова	doc_213943984918_item	2267266	et	2	main
концерте	doc_213943984918_item	2267271	et	2	main
preobraženski	doc_213943984918_item	2267281	et	2	main
kirikus	doc_213943984918_item	2267282	et	3	main
lauluansambli	doc_213943984918_item	2267285	et	3	main
kavas	doc_213943984918_item	2267288	et	3	main
bortnjanski	doc_213943984918_item	2267290	et	4	main
gretšaninovi	doc_213943984918_item	2267294	et	2	main
teiste	doc_213943984918_item	2267296	et	4	main
muusikateosed	doc_213943984918_item	2267299	et	3	main
до	doc_213943984918_item	2267225	et	2	main
сочинений	doc_213943984918_item	2267227	et	2	main
исполняемых	doc_213943984918_item	2267232	et	2	main
ансамбль	doc_213943984918_item	2267236	et	2	main
танцевальные	doc_213943984918_item	2267242	et	2	main
и	doc_213943984918_item	2267249	et	2	main
в	doc_213943984918_item	2267255	et	2	main
музыка	doc_213943984918_item	2267260	et	2	main
которая	doc_213943984918_item	2267267	et	2	main
лиры	doc_213943984918_item	2267272	et	2	main
vene	doc_213943984918_item	2267274	et	4	main
kell	doc_213943984918_item	2267278	et	3	main
venemaalt	doc_213943984918_item	2267283	et	3	main
tšaikovski	doc_213943984918_item	2267291	et	2	main
rahmaninovi	doc_213943984918_item	2267293	et	4	main
lira	doc_213943984918_item	2267301	et	4	main
koosneb	doc_213943984918_item	2267302	et	3	main
peterburi	doc_213943984918_item	2267303	et	4	main
konservatooriumi	doc_213943984918_item	2267304	et	4	main
üliõpilastest	doc_213943984918_item	2267305	et	4	main
ja	doc_213943984918_item	2267306	et	3	main
vilistlastest	doc_213943984918_item	2267307	et	4	main
kes	doc_213943984918_item	2267308	et	4	main
erinevad	doc_213943984918_item	2267309	et	4	main
erinevates	doc_213943984918_item	2267310	et	4	main
koorides	doc_213943984918_item	2267311	et	4	main
ja	doc_213943984918_item	2267312	et	3	main
ooperiteatrites	doc_213943984918_item	2267313	et	3	main
solistidena	doc_213943984918_item	2267314	et	3	main
peamiseks	doc_213943984918_item	2267315	et	3	main
eesmärgiks	doc_213943984918_item	2267316	et	3	main
on	doc_213943984918_item	2267317	et	4	main
lira	doc_213943984918_item	2267318	et	4	main
ansamblil	doc_213943984918_item	2267319	et	3	main
vene	doc_213943984918_item	2267320	et	4	main
ja	doc_213943984918_item	2267323	et	3	main
levitamine	doc_213943984918_item	2267324	et	4	main
repertuaaris	doc_213943984918_item	2267326	et	3	main
iidsed	doc_213943984918_item	2267331	et	3	main
õigeusukiriku	doc_213943984918_item	2267332	et	3	main
muusikateosed	doc_213943984918_item	2267342	et	3	main
selliseid	doc_213943984918_item	2267346	et	4	main
nagu	doc_213943984918_item	2267348	et	3	main
lüürika-	doc_213943984918_item	2267349	et	4	main
rituaallaule	doc_213943984918_item	2267352	et	4	main
orkestreerivad	doc_213943984918_item	2267354	et	4	main
ansambli	doc_213943984918_item	2267359	et	3	main
osa	doc_213943984918_item	2267363	et	4	main
nende	doc_213943984918_item	2267364	et	4	main
kontserdil	doc_213943984918_item	2267381	et	3	main
rootslased	doc_213943984919_item	2267383	et	3	main
uhked	doc_213943984919_item	2267385	et	4	main
rootsalste	doc_213943984919_item	2267394	et	4	main
autonoomia	doc_213943984919_item	2267400	et	4	main
tõeline	doc_213943984919_item	2267402	et	4	main
ja	doc_213943984919_item	2267405	et	3	main
maria	doc_213943984919_item	2267424	et	4	main
auks	doc_213943984919_item	2267426	et	3	main
seal	doc_213943984919_item	2267430	et	4	main
ajal	doc_213943984919_item	2267435	et	4	main
sõja	doc_213943984919_item	2267450	et	3	main
uurimine	doc_213943984918_item	2267322	et	4	main
kollektiivi	doc_213943984918_item	2267325	et	4	main
on	doc_213943984918_item	2267327	et	4	main
vene	doc_213943984918_item	2267328	et	4	main
vene	doc_213943984918_item	2267334	et	4	main
vähetuntud	doc_213943984918_item	2267336	et	3	main
mida	doc_213943984918_item	2267353	et	4	main
tuntud	doc_213943984918_item	2267355	et	4	main
loomingust	doc_213943984918_item	2267365	et	3	main
ise	doc_213943984918_item	2267361	et	4	main
on	doc_213943984918_item	2267366	et	4	main
loomulikult	doc_213943984918_item	2267367	et	4	main
tuntud	doc_213943984918_item	2267368	et	4	main
vene	doc_213943984918_item	2267369	et	4	main
komponistide	doc_213943984918_item	2267370	et	3	main
tšaikovski	doc_213943984918_item	2267371	et	2	main
tanejevi	doc_213943984918_item	2267372	et	4	main
rahmaninovi	doc_213943984918_item	2267374	et	4	main
ja	doc_213943984918_item	2267373	et	3	main
muusika	doc_213943984918_item	2267375	et	4	main
mis	doc_213943984918_item	2267376	et	4	main
kõlab	doc_213943984918_item	2267377	et	3	main
lira	doc_213943984918_item	2267378	et	4	main
ansambli	doc_213943984918_item	2267379	et	3	main
igal	doc_213943984918_item	2267380	et	3	main
tõlge	doc_213943984919_item	2267382	et	3	main
üle	doc_213943984919_item	2267388	et	3	main
poolt	doc_213943984919_item	2267395	et	4	main
on	doc_213943984919_item	2267401	et	4	main
keele	doc_213943984919_item	2267404	et	4	main
kultuuri	doc_213943984919_item	2267406	et	4	main
vene	doc_213943984919_item	2267414	et	4	main
vene	doc_213943984919_item	2267427	et	4	main
hakati	doc_213943984919_item	2267429	et	3	main
õppima	doc_213943984919_item	2267431	et	3	main
veel	doc_213943984919_item	2267432	et	4	main
peeter	doc_213943984919_item	2267433	et	3	main
i	doc_213943984919_item	2267434	et	4	main
kui	doc_213943984919_item	2267436	et	3	main
rootsi	doc_213943984919_item	2267437	et	4	main
kongress	doc_213943984919_item	2267441	et	3	main
oli	doc_213943984919_item	2267443	et	3	main
kutsutud	doc_213943984919_item	2267445	et	4	main
et	doc_213943984919_item	2267446	et	3	main
seaduslikult	doc_213943984919_item	2267447	et	4	main
põhja	doc_213943984919_item	2267449	et	4	main
saarele	doc_213943984919_item	2267458	et	3	main
mida	doc_213943984919_item	2267467	et	4	main
peetri-aegsed	doc_213943984919_item	2267468	et	3	main
see	doc_213943984919_item	2267477	et	3	main
tollest	doc_213943984919_item	2267482	et	4	main
mitte	doc_213943984919_item	2267486	et	3	main
hoopis	doc_213943984919_item	2267493	et	3	main
sõna	doc_213943984919_item	2267497	et	4	main
karasho	doc_213943984919_item	2267498	et	4	main
ja	doc_213943984919_item	2267499	et	3	main
tjebja	doc_213943984919_item	2267500	et	4	main
kui	doc_213943984919_item	2267501	et	3	main
sõna	doc_213943984919_item	2267503	et	4	main
kasutatakse	doc_213943984919_item	2267504	et	3	main
esimest	doc_213943984919_item	2267502	et	4	main
õiges	doc_213943984919_item	2267505	et	3	main
tähenduses	doc_213943984919_item	2267506	et	4	main
siis	doc_213943984919_item	2267507	et	3	main
teist	doc_213943984919_item	2267508	et	4	main
kasutatakse	doc_213943984919_item	2267509	et	3	main
hoopis	doc_213943984919_item	2267510	et	3	main
armastuse	doc_213943984919_item	2267511	et	4	main
avaldamiseks	doc_213943984919_item	2267512	et	4	main
kurameerides	doc_213943984919_item	2267513	et	4	main
kohalike	doc_213943984919_item	2267514	et	4	main
neidudega	doc_213943984919_item	2267515	et	3	main
kinnitasid	doc_213943984919_item	2267516	et	4	main
venelased	doc_213943984919_item	2267517	et	3	main
siiralt	doc_213943984919_item	2267518	et	4	main
ma	doc_213943984919_item	2267519	et	3	main
armastan	doc_213943984919_item	2267520	et	3	main
toimus	doc_213943984919_item	2267440	et	3	main
mis	doc_213943984919_item	2267442	et	4	main
kokku	doc_213943984919_item	2267444	et	3	main
kestsid	doc_213943984919_item	2267453	et	4	main
poolteist	doc_213943984919_item	2267455	et	4	main
aastat	doc_213943984919_item	2267456	et	3	main
linn	doc_213943984919_item	2267466	et	3	main
kaardiväelased	doc_213943984919_item	2267469	et	3	main
käe	doc_213943984919_item	2267473	et	3	main
kui	doc_213943984919_item	2267475	et	3	main
ka	doc_213943984919_item	2267478	et	3	main
ajast	doc_213943984919_item	2267483	et	4	main
alles	doc_213943984919_item	2267485	et	3	main
ega	doc_213943984919_item	2267488	et	3	main
kaks	doc_213943984919_item	2267494	et	3	main
üsnagi	doc_213943984919_item	2267495	et	3	main
ainult	doc_213943984919_item	2267521	et	4	main
nüüd	doc_213943984919_item	2267528	et	4	main
armastan	doc_213943984919_item	2267533	et	3	main
on	doc_213943984919_item	2267541	et	4	main
aru	doc_213943984919_item	2267544	et	4	main
kuigi	doc_213943984919_item	2267546	et	3	main
murdis	doc_213943984919_item	2267553	et	3	main
19	doc_213943984919_item	2267555	et	2	main
alandi	doc_213943984919_item	2267559	et	4	main
jäänud	doc_213943984919_item	2267561	et	4	main
ehitamise	doc_213943984919_item	2267570	et	4	main
perioodil	doc_213943984919_item	2267571	et	3	main
kahe	doc_213943984919_item	2267574	et	3	main
sõjas	doc_213943984919_item	2267584	et	3	main
vaja	doc_213943984919_item	2267593	et	4	main
impeeriumi	doc_213943984919_item	2267612	et	4	main
see	doc_213943984919_item	2267623	et	3	main
uus	doc_213943984919_item	2267627	et	3	main
viimase	doc_213943984919_item	2267631	et	3	main
aja	doc_213943984919_item	2267632	et	4	main
tendentsist	doc_213943984919_item	2267634	et	3	main
alandi	doc_213943984919_item	2267640	et	4	main
hulgal	doc_213943984919_item	2267660	et	3	main
venelastele	doc_213943984919_item	2267661	et	4	main
nendel	doc_213943984919_item	2267670	et	4	main
venekeelset	doc_213943984919_item	2267692	et	3	main
ei	doc_213943984919_item	2267694	et	4	main
sõda	doc_213943984919_item	2267696	et	4	main
elanikuga	doc_213943984919_item	2267705	et	3	main
durak	doc_213943984919_item	2267713	et	4	main
rääkides	doc_213943984919_item	2267719	et	4	main
läbirääkimised	doc_213943984919_item	2267452	et	3	main
peaaegu	doc_213943984919_item	2267454	et	3	main
vana	doc_213943984919_item	2267459	et	4	main
kogunisti	doc_213943984919_item	2267463	et	3	main
saadikute	doc_213943984919_item	2267465	et	3	main
major	doc_213943984919_item	2267471	et	3	main
tunduks	doc_213943984919_item	2267480	et	3	main
vaid	doc_213943984919_item	2267492	et	3	main
sind	doc_213943984919_item	2267522	et	4	main
öeldakse	doc_213943984919_item	2267527	et	3	main
lovel	doc_213943984919_item	2267529	et	3	main
sõnast	doc_213943984919_item	2267539	et	4	main
krapula	doc_213943984919_item	2267540	et	4	main
on	doc_213943984919_item	2267548	et	4	main
väljendist	doc_213943984919_item	2267551	et	3	main
saartele	doc_213943984919_item	2267560	et	3	main
sõnavara	doc_213943984919_item	2267564	et	4	main
saartel	doc_213943984919_item	2267567	et	3	main
kindluse	doc_213943984919_item	2267569	et	4	main
rohkem	doc_213943984919_item	2267572	et	4	main
kui	doc_213943984919_item	2267573	et	3	main
bomarsund	doc_213943984919_item	2267581	et	4	main
krimmi	doc_213943984919_item	2267583	et	4	main
öelda	doc_213943984919_item	2267594	et	4	main
meistrite	doc_213943984919_item	2267603	et	3	main
on	doc_213943984919_item	2267605	et	4	main
jäänud	doc_213943984919_item	2267607	et	4	main
ekkeri	doc_213943984919_item	2267608	et	3	main
postkontori	doc_213943984919_item	2267609	et	4	main
rõhutades	doc_213943984919_item	2267523	et	3	main
viimast	doc_213943984919_item	2267524	et	4	main
ning	doc_213943984919_item	2267530	et	3	main
ühest	doc_213943984919_item	2267537	et	4	main
lühend	doc_213943984919_item	2267550	et	3	main
maha	doc_213943984919_item	2267554	et	4	main
sajandi	doc_213943984919_item	2267556	et	3	main
väga	doc_213943984919_item	2267562	et	3	main
palju	doc_213943984919_item	2267563	et	4	main
seisid	doc_213943984919_item	2267566	et	4	main
kümnendi	doc_213943984919_item	2267575	et	3	main
kuni	doc_213943984919_item	2267577	et	3	main
aastani	doc_213943984919_item	2267579	et	3	main
kui	doc_213943984919_item	2267580	et	3	main
lammutati	doc_213943984919_item	2267582	et	3	main
maha	doc_213943984919_item	2267585	et	4	main
hiljem	doc_213943984919_item	2267586	et	3	main
isegi	doc_213943984919_item	2267587	et	4	main
kuni	doc_213943984919_item	2267588	et	3	main
revolutsioonini	doc_213943984919_item	2267590	et	3	main
ongi	doc_213943984919_item	2267592	et	4	main
suur	doc_213943984919_item	2267596	et	3	main
meie	doc_213943984919_item	2267598	et	4	main
ohvitseride	doc_213943984919_item	2267600	et	3	main
järeltulijaid	doc_213943984919_item	2267604	et	3	main
siia	doc_213943984919_item	2267606	et	4	main
stiilis	doc_213943984919_item	2267613	et	4	main
postkontori	doc_213943984919_item	2267614	et	4	main
hoone	doc_213943984919_item	2267615	et	4	main
ehitati	doc_213943984919_item	2267616	et	3	main
nikolai	doc_213943984919_item	2267617	et	4	main
i	doc_213943984919_item	2267618	et	4	main
valitsusajal	doc_213943984919_item	2267619	et	3	main
1828	doc_213943984919_item	2267620	et	2	main
välja	doc_213943984919_item	2267625	et	4	main
saartel	doc_213943984919_item	2267641	et	3	main
ühtegi	doc_213943984919_item	2267644	et	4	main
saajat	doc_213943984919_item	2267648	et	4	main
toimetatakse	doc_213943984919_item	2267656	et	3	main
varjasid	doc_213943984919_item	2267672	et	4	main
siiski	doc_213943984919_item	2267697	et	4	main
naudinguks	doc_213943984919_item	2267711	et	3	main
ja	doc_213943984919_item	2267712	et	3	main
borštš	doc_213943984919_item	2267716	et	2	main
ja	doc_213943984919_item	2267721	et	3	main
segu	doc_213943984919_item	2267724	et	4	main
suust	doc_213943984919_item	2267739	et	3	main
kuur	doc_213943984919_item	2267746	et	3	main
süüakse	doc_213943984919_item	2267750	et	3	main
vene	doc_213943984919_item	2267753	et	4	main
tuulutamist	doc_213943984919_item	2267777	et	4	main
siis	doc_213943984919_item	2267782	et	3	main
imestage	doc_213943984919_item	2267783	et	3	main
teil	doc_213943984919_item	2267789	et	4	main
tema	doc_213943984919_item	2267796	et	4	main
tähenda	doc_213943984919_item	2267808	et	4	main
siin	doc_213943984919_item	2267809	et	4	main
või	doc_213943984919_item	2267815	et	4	main
präänikute	doc_213943984919_item	2267818	et	3	main
peal	doc_213943984919_item	2267819	et	4	main
oli	doc_213943984919_item	2267820	et	3	main
tähendab	doc_213943984919_item	2267532	et	3	main
ja	doc_213943984919_item	2267534	et	3	main
veel	doc_213943984919_item	2267536	et	4	main
venekeelsest	doc_213943984919_item	2267538	et	3	main
meil	doc_213943984919_item	2267542	et	4	main
see	doc_213943984919_item	2267547	et	3	main
on	doc_213943984919_item	2267558	et	4	main
oktoobri	doc_213943984919_item	2267589	et	3	main
kas	doc_213943984919_item	2267591	et	3	main
sõjaväelaste	doc_213943984919_item	2267599	et	4	main
kaupmeeste	doc_213943984919_item	2267601	et	4	main
ja	doc_213943984919_item	2267602	et	3	main
töötajad	doc_213943984919_item	2267610	et	4	main
ning	doc_213943984919_item	2267622	et	3	main
kp	doc_213943984919_item	2267629	et	4	main
reporterile	doc_213943984919_item	2267630	et	3	main
ajal	doc_213943984919_item	2267638	et	4	main
vene	doc_213943984919_item	2267645	et	4	main
siis	doc_213943984919_item	2267649	et	3	main
kümnendil	doc_213943984919_item	2267651	et	3	main
mingisugune	doc_213943984919_item	2267653	et	3	main
kohale	doc_213943984919_item	2267657	et	4	main
üha	doc_213943984919_item	2267658	et	3	main
jäänud	doc_213943984919_item	2267665	et	4	main
samadeks	doc_213943984919_item	2267666	et	3	main
võib	doc_213943984919_item	2267700	et	3	main
põlise	doc_213943984919_item	2267702	et	4	main
alandi	doc_213943984919_item	2267703	et	4	main
saarte	doc_213943984919_item	2267704	et	3	main
kujuneda	doc_213943984919_item	2267706	et	3	main
turisti	doc_213943984919_item	2267708	et	4	main
kuka	doc_213943984919_item	2267715	et	4	main
see	doc_213943984919_item	2267725	et	3	main
ole	doc_213943984919_item	2267729	et	4	main
meister	doc_213943984919_item	2267732	et	3	main
rootslaste	doc_213943984919_item	2267738	et	4	main
sõnad	doc_213943984919_item	2267742	et	4	main
kartuh	doc_213943984919_item	2267743	et	4	main
siin	doc_213943984919_item	2267748	et	4	main
siiani	doc_213943984919_item	2267751	et	4	main
ehtsat	doc_213943984919_item	2267752	et	3	main
elanikele	doc_213943984919_item	2267771	et	3	main
gastinsõ	doc_213943984919_item	2267780	et	4	main
alandi	doc_213943984919_item	2267785	et	4	main
saarte	doc_213943984919_item	2267786	et	3	main
pakub	doc_213943984919_item	2267788	et	3	main
peale	doc_213943984919_item	2267793	et	4	main
sai	doc_213943984919_item	2267798	et	4	main
vene	doc_213943984919_item	2267803	et	4	main
üldsegi	doc_213943984919_item	2267810	et	3	main
söödavat	doc_213943984919_item	2267811	et	4	main
vaid	doc_213943984919_item	2267812	et	3	main
nagu	doc_213943984919_item	2267826	et	3	main
nii	doc_213943984919_item	2267829	et	3	main
linnavalitsuse	doc_213943984920_item	2267851	et	3	main
projekti	doc_213943984920_item	2267854	et	4	main
ja	doc_213943984920_item	2267864	et	3	main
projekti	doc_213943984920_item	2267875	et	4	main
toimub	doc_213943984920_item	2267883	et	3	main
programmi	doc_213943984920_item	2267885	et	4	main
koostöö	doc_213943984920_item	2267899	et	4	main
on	doc_213943984920_item	2267903	et	4	main
võrgu-	doc_213943984920_item	2267910	et	3	main
korraldada	doc_213943984920_item	2267934	et	3	main
külaskäik	doc_213943984920_item	2267939	et	3	main
peterburi	doc_213943984920_item	2267949	et	4	main
sellest	doc_213943984920_item	2267957	et	4	main
ka	doc_213943984920_item	2267989	et	3	main
projekti	doc_213943984920_item	2267998	et	4	main
lähemale	doc_213943984920_item	2268012	et	4	main
selle	doc_213943984920_item	2268015	et	4	main
olemus	doc_213943984920_item	2268017	et	3	main
võrgukogu	doc_213943984920_item	2268023	et	4	main
järgneva	doc_213943984920_item	2268027	et	4	main
aasta	doc_213943984920_item	2268028	et	4	main
kavatsetakse	doc_213943984920_item	2268030	et	3	main
selekteerida	doc_213943984920_item	2268031	et	3	main
vene	doc_213943984920_item	2268038	et	4	main
neid	doc_213943984920_item	2268044	et	4	main
väljavalitud	doc_213943984920_item	2268052	et	4	main
neli	doc_213943984920_item	2268054	et	3	main
ihkan	doc_213943984919_item	2267535	et	3	main
raske	doc_213943984919_item	2267543	et	4	main
saada	doc_213943984919_item	2267545	et	4	main
kõigest	doc_213943984919_item	2267549	et	4	main
pohmell	doc_213943984919_item	2267552	et	4	main
venemaast	doc_213943984919_item	2267557	et	3	main
venelased	doc_213943984919_item	2267565	et	3	main
bomarsundi	doc_213943984919_item	2267568	et	4	main
vältel	doc_213943984919_item	2267576	et	4	main
1854	doc_213943984919_item	2267578	et	2	main
kui	doc_213943984919_item	2267595	et	3	main
hulk	doc_213943984919_item	2267597	et	3	main
kusjuures	doc_213943984919_item	2267611	et	3	main
aastal	doc_213943984919_item	2267621	et	3	main
rääkisid	doc_213943984919_item	2267628	et	4	main
imelikust	doc_213943984919_item	2267633	et	4	main
külma	doc_213943984919_item	2267636	et	4	main
sõja	doc_213943984919_item	2267637	et	3	main
polnud	doc_213943984919_item	2267639	et	3	main
kirjade	doc_213943984919_item	2267647	et	3	main
algas	doc_213943984919_item	2267652	et	3	main
buum	doc_213943984919_item	2267654	et	3	main
elanikud	doc_213943984919_item	2267663	et	3	main
kes	doc_213943984919_item	2267671	et	4	main
kõnet	doc_213943984919_item	2267693	et	3	main
suutnud	doc_213943984919_item	2267695	et	4	main
seetõttu	doc_213943984919_item	2267699	et	3	main
kõnelemine	doc_213943984919_item	2267701	et	4	main
meie	doc_213943984919_item	2267707	et	4	main
jaoks	doc_213943984919_item	2267709	et	4	main
tõeliseks	doc_213943984919_item	2267710	et	4	main
perenaine	doc_213943984919_item	2267718	et	3	main
rootsi	doc_213943984919_item	2267720	et	4	main
novgorodi	doc_213943984919_item	2267722	et	4	main
keele	doc_213943984919_item	2267723	et	4	main
ma	doc_213943984919_item	2267727	et	3	main
borši	doc_213943984919_item	2267730	et	2	main
keetmise	doc_213943984919_item	2267731	et	4	main
toredalt	doc_213943984919_item	2267734	et	4	main
kõlavad	doc_213943984919_item	2267736	et	4	main
soome	doc_213943984919_item	2267737	et	3	main
hleib	doc_213943984919_item	2267747	et	4	main
kusjuures	doc_213943984919_item	2267749	et	3	main
kohandamise	doc_213943984919_item	2267774	et	4	main
med	doc_213943984919_item	2267778	et	4	main
kofta	doc_213943984919_item	2267779	et	4	main
ärge	doc_213943984919_item	2267781	et	3	main
kui	doc_213943984919_item	2267784	et	3	main
elanik	doc_213943984919_item	2267787	et	3	main
prännikule	doc_213943984919_item	2267791	et	4	main
mille	doc_213943984919_item	2267795	et	3	main
vana-vanaisa	doc_213943984919_item	2267797	et	4	main
kellegi	doc_213943984919_item	2267800	et	4	main
kui	doc_213943984919_item	2267802	et	3	main
valitseja	doc_213943984919_item	2267804	et	4	main
hoopis	doc_213943984919_item	2267813	et	3	main
kotkas	doc_213943984919_item	2267823	et	4	main
samasugune	doc_213943984919_item	2267825	et	3	main
hakatigi	doc_213943984919_item	2267830	et	3	main
maiustuseks	doc_213943984919_item	2267833	et	4	main
kohtla-järve	doc_213943984920_item	2267850	et	4	main
krooni	doc_213943984920_item	2267881	et	4	main
interreg	doc_213943984920_item	2267884	et	4	main
kaudu	doc_213943984920_item	2267886	et	3	main
vene	doc_213943984920_item	2267887	et	4	main
koostöö	doc_213943984920_item	2267892	et	4	main
seda	doc_213943984920_item	2267900	et	3	main
meie	doc_213943984920_item	2267907	et	4	main
boiko	doc_213943984920_item	2267922	et	4	main
viimase	doc_213943984920_item	2267924	et	3	main
peterburi	doc_213943984920_item	2267940	et	4	main
väljapanekuga	doc_213943984920_item	2267946	et	3	main
noori	doc_213943984920_item	2267950	et	3	main
projekti	doc_213943984920_item	2267953	et	4	main
ning	doc_213943984920_item	2267963	et	3	main
toode	doc_213943984920_item	2267965	et	3	main
võib	doc_213943984920_item	2267967	et	3	main
tuli	doc_213943984920_item	2267993	et	4	main
tihendada	doc_213943984920_item	2267995	et	3	main
hoogustada	doc_213943984920_item	2267996	et	3	main
juurde	doc_213943984920_item	2267999	et	4	main
näeb	doc_213943984919_item	2267624	et	3	main
nagu	doc_213943984919_item	2267626	et	3	main
kui	doc_213943984919_item	2267635	et	3	main
peaaegu	doc_213943984919_item	2267642	et	3	main
et	doc_213943984919_item	2267643	et	3	main
perekonnanimega	doc_213943984919_item	2267646	et	3	main
viimasel	doc_213943984919_item	2267650	et	3	main
posti	doc_213943984919_item	2267655	et	4	main
suuremal	doc_213943984919_item	2267659	et	4	main
kuigi	doc_213943984919_item	2267662	et	3	main
on	doc_213943984919_item	2267664	et	4	main
mõistatus	doc_213943984919_item	2267667	et	4	main
lahenes	doc_213943984919_item	2267668	et	3	main
kiiresti	doc_213943984919_item	2267669	et	3	main
vene	doc_213943984919_item	2267673	et	4	main
juuri	doc_213943984919_item	2267674	et	4	main
tuli	doc_213943984919_item	2267675	et	4	main
see	doc_213943984919_item	2267676	et	3	main
äkitselt	doc_213943984919_item	2267677	et	3	main
meelde	doc_213943984919_item	2267678	et	3	main
ning	doc_213943984919_item	2267679	et	3	main
nad	doc_213943984919_item	2267680	et	3	main
hakkasid	doc_213943984919_item	2267681	et	4	main
oma	doc_213943984919_item	2267682	et	4	main
vana-vanaisade	doc_213943984919_item	2267683	et	3	main
sidorovite	doc_213943984919_item	2267684	et	4	main
petrovide	doc_213943984919_item	2267685	et	4	main
ja	doc_213943984919_item	2267686	et	3	main
perepelkinite	doc_213943984919_item	2267687	et	4	main
üle	doc_213943984919_item	2267688	et	3	main
isegi	doc_213943984919_item	2267689	et	4	main
uhkust	doc_213943984919_item	2267690	et	4	main
tundma	doc_213943984919_item	2267691	et	3	main
summutada	doc_213943984919_item	2267698	et	3	main
att	doc_213943984919_item	2267714	et	3	main
tunnistab	doc_213943984919_item	2267717	et	3	main
tähendab	doc_213943984919_item	2267726	et	3	main
ei	doc_213943984919_item	2267728	et	4	main
ikkagi	doc_213943984919_item	2267735	et	4	main
meie	doc_213943984919_item	2267740	et	4	main
butka	doc_213943984919_item	2267745	et	4	main
leiba	doc_213943984919_item	2267754	et	4	main
isegi	doc_213943984919_item	2267755	et	4	main
saarte	doc_213943984919_item	2267770	et	3	main
õhuakende	doc_213943984919_item	2267773	et	3	main
lihtsustas	doc_213943984919_item	2267776	et	3	main
sarska	doc_213943984919_item	2267790	et	4	main
ei	doc_213943984919_item	2267799	et	4	main
ei	doc_213943984919_item	2267807	et	4	main
ordenit	doc_213943984919_item	2267814	et	3	main
vene	doc_213943984919_item	2267817	et	4	main
tavaliselt	doc_213943984919_item	2267821	et	4	main
medalitel	doc_213943984919_item	2267828	et	3	main
tõlge	doc_213943984920_item	2267838	et	3	main
jätkab	doc_213943984920_item	2267840	et	3	main
muuseumiga	doc_213943984920_item	2267843	et	3	main
kohtla-järve	doc_213943984920_item	2267844	et	4	main
põlevkivimuuseum	doc_213943984920_item	2267845	et	3	main
koostöös	doc_213943984920_item	2267846	et	3	main
lõid	doc_213943984920_item	2267853	et	4	main
uue	doc_213943984920_item	2267855	et	3	main
turismisuuna	doc_213943984920_item	2267856	et	4	main
muuseumi	doc_213943984920_item	2267860	et	4	main
arengu	doc_213943984920_item	2267862	et	3	main
noorte	doc_213943984920_item	2267866	et	3	main
on	doc_213943984920_item	2267871	et	4	main
mõeldud	doc_213943984920_item	2267872	et	4	main
2-le	doc_213943984920_item	2267873	et	3	main
aastale	doc_213943984920_item	2267874	et	3	main
maht	doc_213943984920_item	2267876	et	3	main
eelarve	doc_213943984920_item	2267877	et	4	main
ületab	doc_213943984920_item	2267878	et	3	main
linna	doc_213943984920_item	2267891	et	4	main
on	doc_213943984920_item	2267893	et	4	main
tõhus	doc_213943984920_item	2267897	et	4	main
oma	doc_213943984920_item	2267904	et	4	main
alguse	doc_213943984920_item	2267905	et	3	main
saanud	doc_213943984920_item	2267906	et	4	main
muuseumi	doc_213943984920_item	2267908	et	4	main
neti-	doc_213943984920_item	2267909	et	4	main
kohtla-järvel	doc_213943984920_item	2267927	et	4	main
piirialase	doc_213943984920_item	2267928	et	4	main
koostöö	doc_213943984920_item	2267929	et	4	main
on	doc_213943984920_item	2267932	et	4	main
kus	doc_213943984920_item	2267941	et	3	main
nad	doc_213943984920_item	2267942	et	3	main
selle	doc_213943984920_item	2267952	et	4	main
projektist	doc_213943984920_item	2267958	et	3	main
harumuuseum	doc_213943984920_item	2267991	et	3	main
otsusele	doc_213943984920_item	2267994	et	4	main
koostööd	doc_213943984920_item	2267997	et	4	main
turismialase	doc_213943984920_item	2268005	et	4	main
kui	doc_213943984919_item	2267733	et	3	main
omad	doc_213943984919_item	2267741	et	4	main
soni	doc_213943984919_item	2267744	et	4	main
selle	doc_213943984919_item	2267756	et	4	main
tootmiseks	doc_213943984919_item	2267757	et	4	main
vajalikud	doc_213943984919_item	2267758	et	3	main
ahjud	doc_213943984919_item	2267759	et	3	main
on	doc_213943984919_item	2267760	et	4	main
jäänud	doc_213943984919_item	2267761	et	4	main
meie	doc_213943984919_item	2267762	et	4	main
pirogi	doc_213943984919_item	2267764	et	4	main
fortuška	doc_213943984919_item	2267765	et	2	main
kusjuures	doc_213943984919_item	2267766	et	3	main
omad	doc_213943984919_item	2267763	et	4	main
õpetasid	doc_213943984919_item	2267767	et	4	main
just	doc_213943984919_item	2267768	et	3	main
venelased	doc_213943984919_item	2267769	et	3	main
selgeks	doc_213943984919_item	2267772	et	3	main
mis	doc_213943984919_item	2267775	et	4	main
pilk	doc_213943984919_item	2267792	et	3	main
heita	doc_213943984919_item	2267794	et	3	main
muu	doc_213943984919_item	2267801	et	4	main
käest	doc_213943984919_item	2267805	et	4	main
see	doc_213943984919_item	2267806	et	3	main
medalit	doc_213943984919_item	2267816	et	3	main
peaaegu	doc_213943984919_item	2267824	et	3	main
autasu	doc_213943984919_item	2267832	et	4	main
nimetama	doc_213943984919_item	2267834	et	3	main
stockholm	doc_213943984919_item	2267835	et	4	main
eesnimi	doc_213943984919_item	2267836	et	3	main
perekonnanimi	doc_213943984919_item	2267837	et	3	main
kohtla-järve	doc_213943984920_item	2267839	et	4	main
koostööd	doc_213943984920_item	2267841	et	4	main
muuseumiga	doc_213943984920_item	2267849	et	3	main
läbi	doc_213943984920_item	2267858	et	4	main
vene	doc_213943984920_item	2267859	et	4	main
eesti	doc_213943984920_item	2267865	et	4	main
osalemisel	doc_213943984920_item	2267868	et	4	main
projekt	doc_213943984920_item	2267870	et	3	main
4	doc_213943984920_item	2267879	et	2	main
ja	doc_213943984920_item	2267889	et	3	main
kohtla-järve	doc_213943984920_item	2267890	et	4	main
tõeliselt	doc_213943984920_item	2267895	et	4	main
edukas	doc_213943984920_item	2267896	et	4	main
osa	doc_213943984920_item	2267901	et	4	main
virtuaalharu	doc_213943984920_item	2267912	et	4	main
kohtlajärvel	doc_213943984920_item	2267914	et	4	main
vene	doc_213943984920_item	2267842	et	4	main
kuninglik	doc_213943984919_item	2267822	et	3	main
ka	doc_213943984919_item	2267827	et	3	main
vene	doc_213943984919_item	2267831	et	4	main
stpeterburi	doc_213943984920_item	2267847	et	4	main
vene	doc_213943984920_item	2267848	et	4	main
osalemisel	doc_213943984920_item	2267852	et	4	main
loomine	doc_213943984920_item	2267857	et	4	main
virtuaalmaailma	doc_213943984920_item	2267861	et	4	main
vene	doc_213943984920_item	2267863	et	4	main
eestvedamisel	doc_213943984920_item	2267867	et	3	main
osalusel	doc_213943984920_item	2267869	et	4	main
mln	doc_213943984920_item	2267880	et	4	main
rahastamine	doc_213943984920_item	2267882	et	4	main
muuseumi	doc_213943984920_item	2267888	et	4	main
olnud	doc_213943984920_item	2267894	et	4	main
jätkame	doc_213943984920_item	2267898	et	3	main
mis	doc_213943984920_item	2267902	et	4	main
internetipõhine	doc_213943984920_item	2267911	et	4	main
avamisest	doc_213943984920_item	2267913	et	4	main
sõnas	doc_213943984920_item	2267915	et	4	main
vene	doc_213943984920_item	2267916	et	4	main
muuseumi	doc_213943984920_item	2267917	et	4	main
esindaja	doc_213943984920_item	2267918	et	4	main
filosoofia	doc_213943984920_item	2267919	et	4	main
doktor	doc_213943984920_item	2267920	et	3	main
aleksei	doc_213943984920_item	2267921	et	4	main
oma	doc_213943984920_item	2267923	et	4	main
külaskäigu	doc_213943984920_item	2267925	et	3	main
programmi	doc_213943984920_item	2267930	et	4	main
raames	doc_213943984920_item	2267931	et	4	main
saavad	doc_213943984920_item	2267943	et	4	main
tutvuda	doc_213943984920_item	2267944	et	3	main
muuseumi	doc_213943984920_item	2267945	et	4	main
aga	doc_213943984920_item	2267947	et	3	main
ka	doc_213943984920_item	2267948	et	3	main
nö	doc_213943984920_item	2267959	et	4	main
kultuurialane	doc_213943984920_item	2267960	et	4	main
kultuurialane	doc_213943984920_item	2267962	et	4	main
informatiivne	doc_213943984920_item	2267964	et	3	main
millest	doc_213943984920_item	2267966	et	3	main
kohtla-järve	doc_213943984920_item	2267969	et	4	main
võrgupõhine	doc_213943984920_item	2267990	et	4	main
otsustas	doc_213943984920_item	2267992	et	3	main
peterbuuri	doc_213943984920_item	2268008	et	4	main
tuua	doc_213943984920_item	2268010	et	3	main
seisneb	doc_213943984920_item	2268018	et	3	main
sõeluda	doc_213943984920_item	2268033	et	3	main
välja	doc_213943984920_item	2268034	et	4	main
nii	doc_213943984920_item	2268035	et	3	main
eesti	doc_213943984920_item	2268036	et	4	main
venemaal	doc_213943984920_item	2268061	et	4	main
koolituse	doc_213943984920_item	2268062	et	4	main
noored	doc_213943984920_item	2268064	et	3	main
kogemuse	doc_213943984920_item	2268071	et	3	main
saavad	doc_213943984920_item	2268072	et	4	main
rakendada	doc_213943984920_item	2268074	et	3	main
vene	doc_213943984920_item	2268082	et	4	main
viivad	doc_213943984920_item	2268085	et	4	main
2006	doc_213943984920_item	2268097	et	2	main
kohtla-järve	doc_213943984920_item	2268110	et	4	main
eriolümpiaadis	doc_213943984920_item	2268114	et	3	main
peterburi	doc_213943984920_item	2268119	et	4	main
kokku	doc_213943984920_item	2268126	et	3	main
rootslased	doc_213943984921_item	2268136	et	3	main
on	doc_213943984921_item	2268145	et	4	main
rootslastega	doc_213943984921_item	2268147	et	4	main
kes	doc_213943984921_item	2268148	et	4	main
on	doc_213943984921_item	2268155	et	4	main
kultuuri	doc_213943984921_item	2268161	et	4	main
alates	doc_213943984921_item	2268164	et	3	main
kuni	doc_213943984921_item	2268167	et	3	main
vene	doc_213943984921_item	2268171	et	4	main
on	doc_213943984921_item	2268178	et	4	main
aleksander	doc_213943984921_item	2268182	et	4	main
järgi	doc_213943984921_item	2268186	et	4	main
ajal	doc_213943984920_item	2267926	et	4	main
plaanis	doc_213943984920_item	2267933	et	4	main
kohtla-järve	doc_213943984920_item	2267935	et	4	main
koolinoorte	doc_213943984920_item	2267936	et	3	main
ning	doc_213943984920_item	2267937	et	3	main
üliõpilaste	doc_213943984920_item	2267938	et	4	main
kaastata	doc_213943984920_item	2267951	et	4	main
juurde	doc_213943984920_item	2267954	et	4	main
et	doc_213943984920_item	2267955	et	3	main
saada	doc_213943984920_item	2267956	et	4	main
teabeprodukt	doc_213943984920_item	2267961	et	3	main
saada	doc_213943984920_item	2267968	et	4	main
kultuuriväärtus	doc_213943984920_item	2267970	et	3	main
projekt	doc_213943984920_item	2267971	et	3	main
põhineb	doc_213943984920_item	2267972	et	3	main
vene	doc_213943984920_item	2267973	et	4	main
muuseumi	doc_213943984920_item	2267974	et	4	main
internetipõhise	doc_213943984920_item	2267975	et	3	main
võrgupõhise	doc_213943984920_item	2267976	et	3	main
haru	doc_213943984920_item	2267977	et	4	main
eduka	doc_213943984920_item	2267978	et	3	main
toimimise	doc_213943984920_item	2267979	et	4	main
toimimise	doc_213943984920_item	2267980	et	4	main
kogemuse	doc_213943984920_item	2267981	et	3	main
põlevkivi	doc_213943984920_item	2267983	et	4	main
muuseumi	doc_213943984920_item	2267984	et	4	main
juhtkond	doc_213943984920_item	2267985	et	3	main
kohtla-järves	doc_213943984920_item	2267982	et	4	main
mille	doc_213943984920_item	2267986	et	3	main
allüksusena	doc_213943984920_item	2267987	et	3	main
esineb	doc_213943984920_item	2267988	et	3	main
noori	doc_213943984920_item	2268000	et	3	main
kavas	doc_213943984920_item	2268002	et	3	main
ka	doc_213943984920_item	2268004	et	3	main
erisuuna	doc_213943984920_item	2268006	et	4	main
suurlinna	doc_213943984920_item	2268013	et	4	main
et	doc_213943984920_item	2268020	et	3	main
vene	doc_213943984920_item	2268021	et	4	main
põhjalikul	doc_213943984920_item	2268024	et	3	main
jooksul	doc_213943984920_item	2268029	et	4	main
it	doc_213943984920_item	2268040	et	4	main
tudeng	doc_213943984920_item	2268041	et	3	main
tudengite	doc_213943984920_item	2268042	et	3	main
rakendada	doc_213943984920_item	2268047	et	3	main
oma	doc_213943984920_item	2268048	et	4	main
kultuurivaldkonnas	doc_213943984920_item	2268050	et	4	main
need	doc_213943984920_item	2268051	et	3	main
millest	doc_213943984920_item	2268056	et	3	main
kaks	doc_213943984920_item	2268060	et	3	main
saanud	doc_213943984920_item	2268063	et	4	main
võrgupõhiste	doc_213943984920_item	2268067	et	3	main
kohtla-järve	doc_213943984920_item	2268076	et	4	main
võrgupõhise	doc_213943984920_item	2268077	et	3	main
harumuuseumi	doc_213943984920_item	2268078	et	4	main
töötajad	doc_213943984920_item	2268084	et	4	main
viis	doc_213943984920_item	2268091	et	4	main
läbi	doc_213943984920_item	2268092	et	4	main
ühe	doc_213943984920_item	2268093	et	4	main
novembris	doc_213943984920_item	2268096	et	3	main
pälvis	doc_213943984920_item	2268100	et	3	main
publiku	doc_213943984920_item	2268102	et	3	main
sai	doc_213943984920_item	2268104	et	4	main
tähelepanu	doc_213943984920_item	2268106	et	4	main
osaliseks	doc_213943984920_item	2268109	et	4	main
avar	doc_213943984920_item	2268117	et	3	main
külastamiseks	doc_213943984920_item	2268120	et	4	main
et	doc_213943984920_item	2268121	et	3	main
linna	doc_213943984920_item	2268123	et	4	main
võttis	doc_213943984920_item	2268125	et	3	main
projektijuht	doc_213943984920_item	2268127	et	3	main
töörühma	doc_213943984920_item	2268128	et	4	main
liige	doc_213943984920_item	2268132	et	4	main
dusman	doc_213943984920_item	2268134	et	4	main
esivanemate	doc_213943984921_item	2268141	et	4	main
üle	doc_213943984921_item	2268142	et	3	main
ahvenamaa	doc_213943984921_item	2268143	et	4	main
oma	doc_213943984921_item	2268151	et	4	main
tõeline	doc_213943984921_item	2268162	et	4	main
kuulus	doc_213943984921_item	2268170	et	4	main
suurriigi	doc_213943984921_item	2268173	et	3	main
selle	doc_213943984921_item	2268175	et	4	main
pealinn	doc_213943984921_item	2268176	et	3	main
mariehamn	doc_213943984921_item	2268177	et	4	main
oma	doc_213943984921_item	2268180	et	4	main
nime	doc_213943984921_item	2268181	et	4	main
seadistasid	doc_213943984921_item	2268223	et	4	main
küll	doc_213943984921_item	2268231	et	4	main
ei	doc_213943984921_item	2268239	et	4	main
sõjaline	doc_213943984921_item	2268240	et	4	main
ka	doc_213943984921_item	2268242	et	3	main
küllatki	doc_213943984921_item	2268249	et	4	main
taustaga	doc_213943984921_item	2268251	et	3	main
neist	doc_213943984921_item	2268257	et	4	main
on	doc_213943984921_item	2268258	et	4	main
on	doc_213943984921_item	2268263	et	4	main
kurameerides	doc_213943984921_item	2268271	et	4	main
siiralt	doc_213943984921_item	2268273	et	4	main
rõhku	doc_213943984921_item	2268279	et	4	main
just	doc_213943984921_item	2268280	et	3	main
viimasele	doc_213943984921_item	2268281	et	3	main
sõnale	doc_213943984921_item	2268282	et	3	main
ihkan	doc_213943984921_item	2268293	et	3	main
on	doc_213943984921_item	2268300	et	4	main
raske	doc_213943984921_item	2268302	et	4	main
saada	doc_213943984921_item	2268304	et	4	main
kuid	doc_213943984921_item	2268305	et	4	main
sõnavara	doc_213943984921_item	2268321	et	4	main
asunikud	doc_213943984921_item	2268323	et	3	main
1854	doc_213943984921_item	2268335	et	2	main
hiljem	doc_213943984921_item	2268344	et	3	main
palju	doc_213943984921_item	2268349	et	4	main
kaasates	doc_213943984920_item	2268001	et	4	main
on	doc_213943984920_item	2268003	et	4	main
avamine	doc_213943984920_item	2268007	et	4	main
et	doc_213943984920_item	2268009	et	3	main
noortele	doc_213943984920_item	2268011	et	3	main
kultuuriväärtused	doc_213943984920_item	2268014	et	3	main
projekti	doc_213943984920_item	2268016	et	4	main
selles	doc_213943984920_item	2268019	et	4	main
muuseumi	doc_213943984920_item	2268022	et	4	main
kahe	doc_213943984920_item	2268026	et	3	main
kui	doc_213943984920_item	2268037	et	3	main
seast	doc_213943984920_item	2268043	et	4	main
tahaksid	doc_213943984920_item	2268046	et	4	main
läbivad	doc_213943984920_item	2268053	et	4	main
on	doc_213943984920_item	2268058	et	4	main
saadud	doc_213943984920_item	2268070	et	4	main
noored	doc_213943984920_item	2268073	et	3	main
ka	doc_213943984920_item	2268075	et	3	main
lisaks	doc_213943984920_item	2268080	et	4	main
õppeseminari	doc_213943984920_item	2268087	et	4	main
dr	doc_213943984920_item	2268088	et	4	main
boiko	doc_213943984920_item	2268089	et	4	main
juba	doc_213943984920_item	2268090	et	3	main
loengutsükkel	doc_213943984920_item	2268099	et	3	main
suurt	doc_213943984920_item	2268101	et	3	main
menu	doc_213943984920_item	2268108	et	4	main
õpilased	doc_213943984920_item	2268112	et	3	main
osalevad	doc_213943984920_item	2268113	et	4	main
luuakse	doc_213943984920_item	2268115	et	3	main
võimalus	doc_213943984920_item	2268118	et	3	main
aleksander	doc_213943984920_item	2268133	et	4	main
tõlge	doc_213943984921_item	2268135	et	3	main
saarestik	doc_213943984921_item	2268144	et	3	main
autonoomia	doc_213943984921_item	2268152	et	4	main
sellest	doc_213943984921_item	2268154	et	4	main
saanud	doc_213943984921_item	2268156	et	4	main
põhjamaade	doc_213943984921_item	2268157	et	3	main
vene	doc_213943984921_item	2268158	et	4	main
kaitseala	doc_213943984921_item	2268163	et	4	main
aastast	doc_213943984921_item	2268166	et	4	main
ahvenamaa	doc_213943984921_item	2268168	et	4	main
maria	doc_213943984921_item	2268185	et	4	main
linnak	doc_213943984921_item	2268221	et	3	main
kaardiväelased	doc_213943984921_item	2268226	et	3	main
kõnepruuk	doc_213943984921_item	2268245	et	3	main
ning	doc_213943984921_item	2268254	et	3	main
kasutusel	doc_213943984921_item	2268259	et	4	main
puhtalt	doc_213943984921_item	2268260	et	4	main
armutunnete	doc_213943984921_item	2268265	et	3	main
kinnitasid	doc_213943984921_item	2268272	et	4	main
nüüd	doc_213943984921_item	2268285	et	4	main
saarel	doc_213943984921_item	2268287	et	3	main
ning	doc_213943984921_item	2268288	et	3	main
tähendab	doc_213943984921_item	2268290	et	3	main
veel	doc_213943984921_item	2268294	et	4	main
millest	doc_213943984921_item	2268299	et	3	main
19	doc_213943984921_item	2268312	et	2	main
analüüsimisel	doc_213943984920_item	2268025	et	4	main
välja	doc_213943984920_item	2268032	et	4	main
infotehnoloogia	doc_213943984920_item	2268039	et	4	main
kes	doc_213943984920_item	2268045	et	4	main
teadmisi	doc_213943984920_item	2268049	et	4	main
õppekursust	doc_213943984920_item	2268055	et	3	main
kaks	doc_213943984920_item	2268057	et	3	main
hakkavad	doc_213943984920_item	2268065	et	4	main
tegelema	doc_213943984920_item	2268066	et	3	main
arvutiprogrammide	doc_213943984920_item	2268068	et	3	main
töös	doc_213943984920_item	2268079	et	3	main
muuseumi	doc_213943984920_item	2268083	et	4	main
kohtla-järvel	doc_213943984920_item	2268095	et	4	main
gümnaasiumide	doc_213943984920_item	2268111	et	3	main
võimalus	doc_213943984920_item	2268116	et	3	main
kultuuripärandiga	doc_213943984920_item	2268124	et	4	main
juht	doc_213943984920_item	2268129	et	3	main
töörühma	doc_213943984920_item	2268131	et	4	main
oma	doc_213943984921_item	2268139	et	4	main
venelastest	doc_213943984921_item	2268140	et	4	main
lõid	doc_213943984921_item	2268149	et	4	main
keele	doc_213943984921_item	2268159	et	4	main
saarestik	doc_213943984921_item	2268169	et	3	main
saanud	doc_213943984921_item	2268179	et	4	main
abikaasa	doc_213943984921_item	2268184	et	4	main
vene	doc_213943984921_item	2268187	et	4	main
hakati	doc_213943984921_item	2268189	et	3	main
siin	doc_213943984921_item	2268190	et	4	main
õppima	doc_213943984921_item	2268191	et	3	main
mille	doc_213943984921_item	2268222	et	3	main
i	doc_213943984921_item	2268225	et	4	main
major	doc_213943984921_item	2268227	et	3	main
juhtimisel	doc_213943984921_item	2268229	et	4	main
peale	doc_213943984921_item	2268236	et	4	main
ega	doc_213943984921_item	2268241	et	3	main
leksika	doc_213943984921_item	2268244	et	4	main
küll	doc_213943984921_item	2268246	et	4	main
otstarbekohaselt	doc_213943984921_item	2268261	et	4	main
aga	doc_213943984921_item	2268264	et	3	main
avaldamiseks	doc_213943984921_item	2268266	et	4	main
kohalike	doc_213943984921_item	2268269	et	4	main
loewe	doc_213943984921_item	2268286	et	4	main
armastan	doc_213943984921_item	2268291	et	3	main
üks	doc_213943984921_item	2268295	et	3	main
küll	doc_213943984921_item	2268301	et	4	main
aru	doc_213943984921_item	2268303	et	4	main
see	doc_213943984921_item	2268306	et	3	main
lühend	doc_213943984921_item	2268307	et	3	main
tähendama	doc_213943984921_item	2268309	et	3	main
õudsat	doc_213943984921_item	2268310	et	4	main
pohmakat	doc_213943984921_item	2268311	et	4	main
sajandi	doc_213943984921_item	2268313	et	3	main
saarestikul	doc_213943984921_item	2268325	et	3	main
rajamise	doc_213943984921_item	2268328	et	4	main
20	doc_213943984921_item	2268332	et	2	main
mil	doc_213943984921_item	2268336	et	4	main
ning	doc_213943984921_item	2268343	et	3	main
on	doc_213943984921_item	2268350	et	4	main
saarestikule	doc_213943984921_item	2268351	et	3	main
oskasid	doc_213943984921_item	2268364	et	4	main
veidrast	doc_213943984921_item	2268371	et	3	main
stiilis	doc_213943984921_item	2268376	et	4	main
ajal	doc_213943984921_item	2268383	et	4	main
28	doc_213943984921_item	2268386	et	2	main
sõja	doc_213943984921_item	2268396	et	3	main
vene	doc_213943984921_item	2268408	et	4	main
plahvatuslikult	doc_213943984921_item	2268413	et	4	main
kasvanud	doc_213943984921_item	2268414	et	4	main
päritolu	doc_213943984921_item	2268431	et	4	main
on	doc_213943984921_item	2268432	et	4	main
sellest	doc_213943984921_item	2268434	et	4	main
üle	doc_213943984921_item	2268435	et	3	main
ning	doc_213943984921_item	2268436	et	3	main
on	doc_213943984921_item	2268437	et	4	main
nimed	doc_213943984921_item	2268443	et	3	main
puhtvenelaslikud	doc_213943984921_item	2268445	et	3	main
perepjolkin	doc_213943984921_item	2268449	et	4	main
nüüd	doc_213943984921_item	2268458	et	4	main
turistid	doc_213943984921_item	2268460	et	3	main
боршч	doc_213943984921_item	2268471	et	2	main
ning	doc_213943984921_item	2268479	et	3	main
boršši	doc_213943984921_item	2268488	et	2	main
põnevalt	doc_213943984921_item	2268491	et	4	main
картух	doc_213943984921_item	2268499	et	2	main
eestis	doc_213943984920_item	2268059	et	3	main
loomisega	doc_213943984920_item	2268069	et	4	main
kõigele	doc_213943984920_item	2268081	et	4	main
läbi	doc_213943984920_item	2268086	et	4	main
loengukursuse	doc_213943984920_item	2268094	et	3	main
kõnealune	doc_213943984920_item	2268098	et	4	main
menu	doc_213943984920_item	2268103	et	4	main
suure	doc_213943984920_item	2268105	et	3	main
osaliseks	doc_213943984920_item	2268107	et	4	main
tutvuda	doc_213943984920_item	2268122	et	3	main
projekti	doc_213943984920_item	2268130	et	4	main
tunnevad	doc_213943984921_item	2268137	et	3	main
uhkust	doc_213943984921_item	2268138	et	4	main
asustatud	doc_213943984921_item	2268146	et	4	main
soomes	doc_213943984921_item	2268150	et	4	main
ning	doc_213943984921_item	2268153	et	3	main
ja	doc_213943984921_item	2268160	et	3	main
1809	doc_213943984921_item	2268165	et	2	main
impeeriumi	doc_213943984921_item	2268172	et	4	main
koosseisu	doc_213943984921_item	2268174	et	4	main
ii	doc_213943984921_item	2268183	et	4	main
veel	doc_213943984921_item	2268192	et	4	main
peeter	doc_213943984921_item	2268193	et	3	main
i	doc_213943984921_item	2268194	et	4	main
ajal	doc_213943984921_item	2268195	et	4	main
kui	doc_213943984921_item	2268196	et	3	main
saarestikul	doc_213943984921_item	2268197	et	3	main
toimus	doc_213943984921_item	2268198	et	3	main
kongress	doc_213943984921_item	2268199	et	3	main
mis	doc_213943984921_item	2268200	et	4	main
pidi	doc_213943984921_item	2268201	et	4	main
andma	doc_213943984921_item	2268202	et	3	main
seadusliku	doc_213943984921_item	2268203	et	3	main
aluse	doc_213943984921_item	2268204	et	4	main
põhjasõja	doc_213943984921_item	2268205	et	3	main
lõppemisele	doc_213943984921_item	2268206	et	4	main
läbirääkimised	doc_213943984921_item	2268207	et	3	main
kestsid	doc_213943984921_item	2268208	et	4	main
pea	doc_213943984921_item	2268209	et	4	main
poolteist	doc_213943984921_item	2268210	et	4	main
aastat	doc_213943984921_item	2268211	et	3	main
loewe	doc_213943984921_item	2268212	et	4	main
saarel	doc_213943984921_item	2268213	et	3	main
varajasem	doc_213943984921_item	2268214	et	4	main
nimi	doc_213943984921_item	2268215	et	3	main
sundsher	doc_213943984921_item	2268216	et	4	main
oli	doc_213943984921_item	2268217	et	3	main
ehitatud	doc_213943984921_item	2268218	et	4	main
koguni	doc_213943984921_item	2268219	et	4	main
saadikute	doc_213943984921_item	2268220	et	3	main
keelt	doc_213943984921_item	2268188	et	4	main
peeter	doc_213943984921_item	2268224	et	3	main
anetškovi	doc_213943984921_item	2268228	et	2	main
kõlab	doc_213943984921_item	2268230	et	3	main
imelikult	doc_213943984921_item	2268232	et	4	main
aga	doc_213943984921_item	2268247	et	3	main
armastan	doc_213943984921_item	2268275	et	3	main
vaid	doc_213943984921_item	2268276	et	3	main
тьебя	doc_213943984921_item	2268283	et	2	main
ja	doc_213943984921_item	2268292	et	3	main
vene	doc_213943984921_item	2268296	et	4	main
sõna	doc_213943984921_item	2268297	et	4	main
bomarsundi	doc_213943984921_item	2268326	et	4	main
kuni	doc_213943984921_item	2268334	et	3	main
kuni	doc_213943984921_item	2268345	et	3	main
oktoobrirevolutsioonini	doc_213943984921_item	2268347	et	3	main
vene	doc_213943984921_item	2268353	et	4	main
sõjameeste	doc_213943984921_item	2268354	et	4	main
järglasi	doc_213943984921_item	2268358	et	3	main
aimata	doc_213943984921_item	2268360	et	4	main
ajalehe	doc_213943984921_item	2268366	et	3	main
on	doc_213943984921_item	2268379	et	4	main
nikolai	doc_213943984921_item	2268381	et	4	main
on	doc_213943984921_item	2268389	et	4	main
tänapäevani	doc_213943984921_item	2268391	et	3	main
väljanägemise	doc_213943984921_item	2268394	et	3	main
ei	doc_213943984921_item	2268398	et	4	main
peaaegu	doc_213943984921_item	2268401	et	3	main
viimasel	doc_213943984921_item	2268406	et	3	main
ehkki	doc_213943984921_item	2268415	et	3	main
kes	doc_213943984921_item	2268426	et	4	main
vene	doc_213943984921_item	2268430	et	4	main
üle	doc_213943984921_item	2268441	et	3	main
on	doc_213943984921_item	2268444	et	4	main
sidorov	doc_213943984921_item	2268446	et	4	main
ei	doc_213943984921_item	2268452	et	4	main
saanud	doc_213943984921_item	2268453	et	4	main
summutada	doc_213943984921_item	2268454	et	3	main
põlisahvenamaalastega	doc_213943984921_item	2268464	et	4	main
keelt	doc_213943984921_item	2268466	et	4	main
атт	doc_213943984921_item	2268469	et	2	main
rootsi	doc_213943984921_item	2268477	et	4	main
tõlkes	doc_213943984921_item	2268481	et	3	main
ma	doc_213943984921_item	2268485	et	3	main
tõeliselt	doc_213943984921_item	2268490	et	4	main
soome	doc_213943984921_item	2268493	et	3	main
müts	doc_213943984921_item	2268501	et	4	main
putka	doc_213943984921_item	2268503	et	4	main
leiba	doc_213943984921_item	2268512	et	4	main
küpsetusahjud	doc_213943984921_item	2268519	et	3	main
pirukad	doc_213943984921_item	2268521	et	3	main
mesi	doc_213943984921_item	2268536	et	4	main
гастинсы	doc_213943984921_item	2268539	et	2	main
ahvenamaalane	doc_213943984921_item	2268545	et	3	main
teile	doc_213943984921_item	2268547	et	4	main
mille	doc_213943984921_item	2268551	et	3	main
eneselt	doc_213943984921_item	2268557	et	4	main
kõnepruugis	doc_213943984921_item	2268559	et	3	main
vaid	doc_213943984921_item	2268564	et	3	main
tsaarikotkast	doc_213943984921_item	2268573	et	4	main
1917	doc_213943984922_item	2268614	et	2	main
aastani	doc_213943984922_item	2268615	et	3	main
impeeriumi	doc_213943984922_item	2268619	et	4	main
sai	doc_213943984922_item	2268622	et	4	main
naise	doc_213943984922_item	2268629	et	3	main
vene	doc_213943984922_item	2268631	et	4	main
hakati	doc_213943984922_item	2268633	et	3	main
siin	doc_213943984922_item	2268634	et	4	main
toimus	doc_213943984922_item	2268642	et	3	main
juriidiliselt	doc_213943984922_item	2268646	et	4	main
umbes	doc_213943984922_item	2268652	et	4	main
kohandasid	doc_213943984922_item	2268665	et	4	main
ei	doc_213943984922_item	2268674	et	4	main
mitte	doc_213943984922_item	2268676	et	3	main
sõja-	doc_213943984922_item	2268677	et	3	main
või	doc_213943984922_item	2268678	et	4	main
jäid	doc_213943984922_item	2268681	et	4	main
teist	doc_213943984922_item	2268684	et	4	main
hea	doc_213943984922_item	2268688	et	4	main
тьебя	doc_213943984922_item	2268691	et	2	main
teisega	doc_213943984922_item	2268699	et	4	main
kuid	doc_213943984921_item	2268233	et	4	main
sellest	doc_213943984921_item	2268234	et	4	main
ajast	doc_213943984921_item	2268235	et	4	main
ei	doc_213943984921_item	2268237	et	4	main
juurdunud	doc_213943984921_item	2268238	et	4	main
tehniline	doc_213943984921_item	2268243	et	3	main
kaks	doc_213943984921_item	2268248	et	3	main
optimistlikku	doc_213943984921_item	2268250	et	4	main
sõna	doc_213943984921_item	2268252	et	4	main
hästi	doc_213943984921_item	2268253	et	3	main
sind	doc_213943984921_item	2268255	et	4	main
esimene	doc_213943984921_item	2268256	et	3	main
teine	doc_213943984921_item	2268262	et	3	main
vene	doc_213943984921_item	2268267	et	4	main
noored	doc_213943984921_item	2268268	et	3	main
neidudega	doc_213943984921_item	2268270	et	3	main
ma	doc_213943984921_item	2268274	et	3	main
sind	doc_213943984921_item	2268277	et	4	main
asetades	doc_213943984921_item	2268278	et	3	main
räägitakse	doc_213943984921_item	2268284	et	3	main
see	doc_213943984921_item	2268289	et	3	main
крапула	doc_213943984921_item	2268298	et	2	main
peaks	doc_213943984921_item	2268308	et	4	main
venemaast	doc_213943984921_item	2268314	et	3	main
on	doc_213943984921_item	2268315	et	4	main
ahvenamaale	doc_213943984921_item	2268316	et	4	main
järele	doc_213943984921_item	2268317	et	4	main
jäänud	doc_213943984921_item	2268318	et	4	main
tunduvalt	doc_213943984921_item	2268319	et	4	main
rohkem	doc_213943984921_item	2268320	et	4	main
elasid	doc_213943984921_item	2268324	et	4	main
kindluse	doc_213943984921_item	2268327	et	4	main
ajal	doc_213943984921_item	2268329	et	4	main
kindlus	doc_213943984921_item	2268337	et	4	main
hävitatud	doc_213943984921_item	2268339	et	4	main
sõja	doc_213943984921_item	2268341	et	3	main
ajal	doc_213943984921_item	2268342	et	4	main
käsitööliste	doc_213943984921_item	2268357	et	4	main
võib	doc_213943984921_item	2268359	et	3	main
postijaama	doc_213943984921_item	2268362	et	4	main
töötajad	doc_213943984921_item	2268363	et	4	main
rääkida	doc_213943984921_item	2268365	et	3	main
trendist	doc_213943984921_item	2268372	et	4	main
muide	doc_213943984921_item	2268373	et	3	main
suurejooneline	doc_213943984921_item	2268374	et	4	main
postijaam	doc_213943984921_item	2268378	et	3	main
1	doc_213943984921_item	2268384	et	2	main
ning	doc_213943984921_item	2268388	et	3	main
säilitanud	doc_213943984921_item	2268390	et	4	main
värske	doc_213943984921_item	2268393	et	4	main
olnud	doc_213943984921_item	2268399	et	4	main
ühtegi	doc_213943984921_item	2268402	et	4	main
arv	doc_213943984921_item	2268411	et	3	main
on	doc_213943984921_item	2268417	et	4	main
jäänud	doc_213943984921_item	2268419	et	4	main
samaks	doc_213943984921_item	2268420	et	3	main
vene	doc_213943984921_item	2268322	et	4	main
enam	doc_213943984921_item	2268330	et	4	main
kui	doc_213943984921_item	2268331	et	3	main
aastat	doc_213943984921_item	2268333	et	3	main
oli	doc_213943984921_item	2268338	et	3	main
krimmi	doc_213943984921_item	2268340	et	4	main
suure	doc_213943984921_item	2268346	et	3	main
kui	doc_213943984921_item	2268348	et	3	main
kaupmeeste	doc_213943984921_item	2268355	et	4	main
ning	doc_213943984921_item	2268356	et	3	main
äkkere	doc_213943984921_item	2268361	et	3	main
kп	doc_213943984921_item	2268367	et	2	main
viimase	doc_213943984921_item	2268369	et	3	main
suurriigi	doc_213943984921_item	2268375	et	3	main
8	doc_213943984921_item	2268385	et	2	main
aastal	doc_213943984921_item	2268387	et	3	main
külma	doc_213943984921_item	2268395	et	4	main
vene	doc_213943984921_item	2268403	et	4	main
postisaajat	doc_213943984921_item	2268405	et	3	main
on	doc_213943984921_item	2268412	et	4	main
valdavalt	doc_213943984921_item	2268418	et	4	main
mõistatusel	doc_213943984921_item	2268421	et	4	main
lihtne	doc_213943984921_item	2268423	et	3	main
varjasid	doc_213943984921_item	2268428	et	4	main
oma	doc_213943984921_item	2268429	et	4	main
saanud	doc_213943984921_item	2268433	et	4	main
esivanemate	doc_213943984921_item	2268440	et	4	main
ka	doc_213943984921_item	2268450	et	3	main
ning	doc_213943984921_item	2268457	et	3	main
harrastada	doc_213943984921_item	2268463	et	3	main
vene	doc_213943984921_item	2268465	et	4	main
дурак	doc_213943984921_item	2268468	et	2	main
üks	doc_213943984921_item	2268473	et	3	main
vene	doc_213943984921_item	2268475	et	4	main
peaks	doc_213943984921_item	2268482	et	4	main
kõlavad	doc_213943984921_item	2268492	et	4	main
rootslaste	doc_213943984921_item	2268494	et	4	main
suus	doc_213943984921_item	2268495	et	3	main
meile	doc_213943984921_item	2268496	et	4	main
saanud	doc_213943984921_item	2268498	et	4	main
kaheksanurkne	doc_213943984921_item	2268500	et	3	main
leib	doc_213943984921_item	2268505	et	3	main
ehtsat	doc_213943984921_item	2268510	et	3	main
vene	doc_213943984921_item	2268511	et	4	main
küpsetamiseks	doc_213943984921_item	2268514	et	4	main
venelastest	doc_213943984921_item	2268525	et	4	main
on	doc_213943984921_item	2268526	et	4	main
tuulutamist	doc_213943984921_item	2268534	et	4	main
kui	doc_213943984921_item	2268544	et	3	main
tsaari	doc_213943984921_item	2268549	et	4	main
ole	doc_213943984921_item	2268561	et	4	main
või	doc_213943984921_item	2268566	et	4	main
medalitelgi	doc_213943984921_item	2268575	et	4	main
kuulusid	doc_213943984922_item	2268616	et	4	main
jäänud	doc_213943984921_item	2268352	et	4	main
reporterile	doc_213943984921_item	2268368	et	3	main
aja	doc_213943984921_item	2268370	et	4	main
ehitatud	doc_213943984921_item	2268377	et	4	main
ehitatud	doc_213943984921_item	2268380	et	4	main
i	doc_213943984921_item	2268382	et	4	main
oma	doc_213943984921_item	2268392	et	4	main
ajal	doc_213943984921_item	2268397	et	4	main
ahvenamaal	doc_213943984921_item	2268400	et	4	main
nimega	doc_213943984921_item	2268404	et	3	main
aastakümnendil	doc_213943984921_item	2268407	et	3	main
nimedega	doc_213943984921_item	2268409	et	3	main
aadressaatide	doc_213943984921_item	2268410	et	4	main
elanikkond	doc_213943984921_item	2268416	et	3	main
on	doc_213943984921_item	2268422	et	4	main
need	doc_213943984921_item	2268425	et	3	main
varem	doc_213943984921_item	2268427	et	4	main
uhked	doc_213943984921_item	2268438	et	4	main
oma	doc_213943984921_item	2268439	et	4	main
vene	doc_213943984921_item	2268455	et	4	main
meie	doc_213943984921_item	2268459	et	4	main
tunnistab	doc_213943984921_item	2268472	et	3	main
tähendama	doc_213943984921_item	2268484	et	3	main
ei	doc_213943984921_item	2268486	et	4	main
oska	doc_213943984921_item	2268487	et	4	main
keeta	doc_213943984921_item	2268489	et	4	main
бутка	doc_213943984921_item	2268502	et	2	main
хлейб	doc_213943984921_item	2268504	et	2	main
süüakse	doc_213943984921_item	2268507	et	3	main
selle	doc_213943984921_item	2268513	et	4	main
on	doc_213943984921_item	2268515	et	4	main
фортушка	doc_213943984921_item	2268522	et	2	main
мед	doc_213943984921_item	2268535	et	2	main
kampsun	doc_213943984921_item	2268538	et	3	main
siis	doc_213943984921_item	2268542	et	3	main
on	doc_213943984921_item	2268552	et	4	main
saanud	doc_213943984921_item	2268554	et	4	main
vene	doc_213943984921_item	2268555	et	4	main
tsaarilt	doc_213943984921_item	2268556	et	3	main
kohalikus	doc_213943984921_item	2268558	et	4	main
ei	doc_213943984921_item	2268560	et	4	main
toiduaine	doc_213943984921_item	2268563	et	4	main
orden	doc_213943984921_item	2268565	et	3	main
medal	doc_213943984921_item	2268567	et	3	main
präänikutele	doc_213943984921_item	2268571	et	3	main
kujutati	doc_213943984921_item	2268572	et	4	main
nagu	doc_213943984921_item	2268574	et	3	main
saanud	doc_213943984921_item	2268578	et	4	main
aurahast	doc_213943984921_item	2268580	et	4	main
1809	doc_213943984922_item	2268612	et	2	main
aastast	doc_213943984922_item	2268613	et	4	main
pealinn	doc_213943984922_item	2268620	et	3	main
aleksander	doc_213943984922_item	2268627	et	4	main
kui	doc_213943984922_item	2268639	et	3	main
rootsi	doc_213943984922_item	2268640	et	4	main
alandidel	doc_213943984922_item	2268641	et	4	main
kongress	doc_213943984922_item	2268643	et	3	main
kinnistama	doc_213943984922_item	2268647	et	3	main
saatkonnalinn	doc_213943984922_item	2268663	et	3	main
kaardiväelased	doc_213943984922_item	2268668	et	3	main
sellest	doc_213943984922_item	2268672	et	4	main
tehnikasõnavara	doc_213943984922_item	2268679	et	4	main
sõna	doc_213943984922_item	2268686	et	4	main
ja	doc_213943984922_item	2268689	et	3	main
esimest	doc_213943984922_item	2268692	et	4	main
kasutatakse	doc_213943984922_item	2268694	et	3	main
esialgses	doc_213943984922_item	2268696	et	3	main
tähenduses	doc_213943984922_item	2268697	et	4	main
kuid	doc_213943984922_item	2268698	et	4	main
kohalikke	doc_213943984922_item	2268702	et	4	main
neidudega	doc_213943984922_item	2268703	et	3	main
kinnitasid	doc_213943984922_item	2268705	et	4	main
ma	doc_213943984922_item	2268709	et	3	main
langes	doc_213943984922_item	2268714	et	4	main
sõnale	doc_213943984922_item	2268717	et	3	main
nüüd	doc_213943984922_item	2268720	et	4	main
lovel	doc_213943984922_item	2268721	et	3	main
praegu	doc_213943984922_item	2268728	et	3	main
joomisest	doc_213943984922_item	2268736	et	4	main
pea	doc_213943984922_item	2268737	et	4	main
otsas	doc_213943984922_item	2268739	et	4	main
lahendus	doc_213943984921_item	2268424	et	4	main
kelle	doc_213943984921_item	2268442	et	4	main
petrov	doc_213943984921_item	2268447	et	4	main
ning	doc_213943984921_item	2268448	et	3	main
sõda	doc_213943984921_item	2268451	et	4	main
keelt	doc_213943984921_item	2268456	et	4	main
saavad	doc_213943984921_item	2268461	et	4	main
meeleldi	doc_213943984921_item	2268462	et	3	main
я-я	doc_213943984921_item	2268467	et	2	main
кука	doc_213943984921_item	2268470	et	2	main
perenaine	doc_213943984921_item	2268474	et	3	main
ja	doc_213943984921_item	2268476	et	3	main
segakeeles	doc_213943984921_item	2268478	et	4	main
vabas	doc_213943984921_item	2268480	et	3	main
see	doc_213943984921_item	2268483	et	3	main
armsaks	doc_213943984921_item	2268497	et	3	main
tõelist	doc_213943984921_item	2268509	et	4	main
säilinud	doc_213943984921_item	2268516	et	4	main
isegi	doc_213943984921_item	2268517	et	4	main
siin	doc_213943984921_item	2268506	et	4	main
siiamaani	doc_213943984921_item	2268508	et	3	main
tolleaegsed	doc_213943984921_item	2268518	et	3	main
пироги	doc_213943984921_item	2268520	et	2	main
õhuaken	doc_213943984921_item	2268523	et	3	main
komme	doc_213943984921_item	2268528	et	4	main
teha	doc_213943984921_item	2268529	et	3	main
mis	doc_213943984921_item	2268531	et	4	main
elamute	doc_213943984921_item	2268533	et	3	main
pole	doc_213943984921_item	2268541	et	3	main
imestada	doc_213943984921_item	2268543	et	3	main
soovib	doc_213943984921_item	2268546	et	3	main
näidata	doc_213943984921_item	2268548	et	4	main
vanavanaisa	doc_213943984921_item	2268553	et	4	main
on	doc_213943984921_item	2268577	et	4	main
põhjamaades	doc_213943984922_item	2268611	et	4	main
marienhamn	doc_213943984922_item	2268621	et	4	main
oma	doc_213943984922_item	2268623	et	4	main
teise	doc_213943984922_item	2268628	et	4	main
keelt	doc_213943984922_item	2268632	et	4	main
õpetama	doc_213943984922_item	2268635	et	3	main
pidi	doc_213943984922_item	2268645	et	4	main
lõppu	doc_213943984922_item	2268649	et	4	main
kestsid	doc_213943984922_item	2268651	et	4	main
peetri	doc_213943984922_item	2268667	et	3	main
majoor	doc_213943984922_item	2268669	et	4	main
ajast	doc_213943984922_item	2268673	et	4	main
карашо	doc_213943984922_item	2268687	et	2	main
oma	doc_213943984922_item	2268695	et	4	main
armastusavaldusi	doc_213943984922_item	2268701	et	3	main
noormehed	doc_213943984922_item	2268707	et	3	main
just	doc_213943984922_item	2268715	et	3	main
тьебя	doc_213943984922_item	2268718	et	2	main
see	doc_213943984922_item	2268723	et	3	main
armastan	doc_213943984922_item	2268725	et	3	main
aga	doc_213943984922_item	2268735	et	3	main
lõhub	doc_213943984922_item	2268738	et	3	main
rohkem	doc_213943984922_item	2268746	et	4	main
kindluse	doc_213943984922_item	2268753	et	4	main
rajamise	doc_213943984922_item	2268754	et	4	main
perioodil	doc_213943984922_item	2268755	et	3	main
umbes	doc_213943984922_item	2268756	et	4	main
hävitatud	doc_213943984922_item	2268764	et	4	main
hiljemalt	doc_213943984922_item	2268767	et	3	main
vene	doc_213943984922_item	2268774	et	4	main
ekkeri	doc_213943984922_item	2268780	et	3	main
hoone	doc_213943984922_item	2268784	et	4	main
ehitatud	doc_213943984922_item	2268786	et	4	main
kirju	doc_213943984922_item	2268825	et	4	main
jäi	doc_213943984922_item	2268829	et	3	main
need	doc_213943984922_item	2268835	et	3	main
kes	doc_213943984922_item	2268836	et	4	main
hakkasid	doc_213943984922_item	2268841	et	4	main
uhkust	doc_213943984922_item	2268848	et	4	main
esiisade	doc_213943984922_item	2268850	et	3	main
suutnud	doc_213943984922_item	2268859	et	4	main
атт	doc_213943984922_item	2268875	et	2	main
tunnistab	doc_213943984922_item	2268878	et	3	main
tähendab	doc_213943984922_item	2268884	et	3	main
pirukad	doc_213943984922_item	2268917	et	3	main
just	doc_213943984921_item	2268524	et	3	main
jäänud	doc_213943984921_item	2268527	et	4	main
õhuaknad	doc_213943984921_item	2268530	et	3	main
kergendab	doc_213943984921_item	2268532	et	3	main
кофта	doc_213943984921_item	2268537	et	2	main
külakost	doc_213943984921_item	2268540	et	3	main
präänikut	doc_213943984921_item	2268550	et	3	main
see	doc_213943984921_item	2268562	et	3	main
venelaste	doc_213943984921_item	2268568	et	4	main
vormitud	doc_213943984921_item	2268569	et	4	main
küpsetatud	doc_213943984921_item	2268570	et	4	main
nii	doc_213943984921_item	2268576	et	3	main
vene	doc_213943984921_item	2268579	et	4	main
tore	doc_213943984921_item	2268581	et	3	main
maiustus	doc_213943984921_item	2268582	et	4	main
maiuspala	doc_213943984921_item	2268583	et	4	main
tõlge	doc_213943984922_item	2268584	et	3	main
rootslased	doc_213943984922_item	2268585	et	3	main
tunnevad	doc_213943984922_item	2268586	et	3	main
oma	doc_213943984922_item	2268588	et	4	main
uhkust	doc_213943984922_item	2268587	et	4	main
üle	doc_213943984922_item	2268590	et	3	main
esivanemate	doc_213943984922_item	2268589	et	4	main
alandi	doc_213943984922_item	2268591	et	4	main
saared	doc_213943984922_item	2268592	et	3	main
on	doc_213943984922_item	2268593	et	4	main
asustatud	doc_213943984922_item	2268594	et	4	main
rootslastega	doc_213943984922_item	2268595	et	4	main
kes	doc_213943984922_item	2268596	et	4	main
rajasid	doc_213943984922_item	2268597	et	4	main
soome	doc_213943984922_item	2268598	et	3	main
koosseisus	doc_213943984922_item	2268599	et	4	main
oma	doc_213943984922_item	2268600	et	4	main
autonoomia	doc_213943984922_item	2268601	et	4	main
need	doc_213943984922_item	2268602	et	3	main
saared	doc_213943984922_item	2268603	et	3	main
on	doc_213943984922_item	2268604	et	4	main
tuntud	doc_213943984922_item	2268605	et	4	main
vene	doc_213943984922_item	2268606	et	4	main
keele	doc_213943984922_item	2268607	et	4	main
ja	doc_213943984922_item	2268608	et	3	main
kultuuri	doc_213943984922_item	2268609	et	4	main
kaitseala	doc_213943984922_item	2268610	et	4	main
alandid	doc_213943984922_item	2268617	et	4	main
vene	doc_213943984922_item	2268618	et	4	main
nime	doc_213943984922_item	2268624	et	4	main
maria	doc_213943984922_item	2268625	et	4	main
aleksandrovna	doc_213943984922_item	2268626	et	4	main
veel	doc_213943984922_item	2268636	et	4	main
peetri	doc_213943984922_item	2268637	et	3	main
ajal	doc_213943984922_item	2268638	et	4	main
läbirääkimised	doc_213943984922_item	2268650	et	3	main
mida	doc_213943984922_item	2268664	et	4	main
varustasid	doc_213943984922_item	2268666	et	4	main
juhtimisel	doc_213943984922_item	2268671	et	4	main
säilinud	doc_213943984922_item	2268675	et	4	main
kaks	doc_213943984922_item	2268683	et	3	main
sind	doc_213943984922_item	2268690	et	4	main
sõna	doc_213943984922_item	2268693	et	4	main
tehakse	doc_213943984922_item	2268700	et	3	main
vene	doc_213943984922_item	2268706	et	4	main
südamlikult	doc_213943984922_item	2268708	et	4	main
ainult	doc_213943984922_item	2268711	et	4	main
rõhk	doc_213943984922_item	2268713	et	3	main
ütlevad	doc_213943984922_item	2268719	et	4	main
ja	doc_213943984922_item	2268722	et	3	main
mitte	doc_213943984922_item	2268729	et	3	main
midagi	doc_213943984922_item	2268730	et	4	main
sõna	doc_213943984922_item	2268732	et	4	main
крапула	doc_213943984922_item	2268733	et	2	main
tähendab	doc_213943984922_item	2268734	et	3	main
ajast	doc_213943984922_item	2268743	et	4	main
saartel	doc_213943984922_item	2268751	et	3	main
kui	doc_213943984922_item	2268761	et	3	main
oli	doc_213943984922_item	2268763	et	3	main
ajal	doc_213943984922_item	2268766	et	4	main
palju	doc_213943984922_item	2268773	et	4	main
ohvitsere	doc_213943984922_item	2268776	et	3	main
ja	doc_213943984922_item	2268778	et	3	main
töötajad	doc_213943984922_item	2268782	et	4	main
ajal	doc_213943984922_item	2268793	et	4	main
ning	doc_213943984922_item	2268794	et	3	main
praegu	doc_213943984922_item	2268795	et	3	main
ja	doc_213943984922_item	2268823	et	3	main
mõistatuse	doc_213943984922_item	2268831	et	4	main
neid	doc_213943984922_item	2268842	et	4	main
tuletama	doc_213943984922_item	2268844	et	3	main
sõda	doc_213943984922_item	2268861	et	4	main
selletõttu	doc_213943984922_item	2268864	et	4	main
põlisalandlastega	doc_213943984922_item	2268870	et	4	main
tõeline	doc_213943984922_item	2268871	et	4	main
кука	doc_213943984922_item	2268876	et	2	main
nižninovgorodi	doc_213943984922_item	2268881	et	2	main
tootmiseks	doc_213943984922_item	2268915	et	4	main
just	doc_213943984922_item	2268920	et	3	main
tunduvalt	doc_213943984922_item	2268928	et	4	main
lihtsustas	doc_213943984922_item	2268929	et	3	main
гастинсы	doc_213943984922_item	2268935	et	2	main
präänik	doc_213943984922_item	2268948	et	3	main
vanavanaisa	doc_213943984922_item	2268952	et	4	main
tähenda	doc_213943984922_item	2268959	et	4	main
ordenit	doc_213943984922_item	2268967	et	3	main
trükiti	doc_213943984922_item	2268973	et	3	main
kotkast	doc_213943984922_item	2268975	et	4	main
sellepärast	doc_213943984922_item	2268980	et	3	main
järgi	doc_213943984922_item	2268630	et	4	main
mis	doc_213943984922_item	2268644	et	4	main
põhjasõja	doc_213943984922_item	2268648	et	3	main
aastat	doc_213943984922_item	2268654	et	3	main
pool	doc_213943984922_item	2268653	et	4	main
love	doc_213943984922_item	2268655	et	4	main
saarele	doc_213943984922_item	2268656	et	3	main
vana	doc_213943984922_item	2268657	et	4	main
nimetuse	doc_213943984922_item	2268658	et	4	main
järgi	doc_213943984922_item	2268659	et	4	main
sundšer	doc_213943984922_item	2268660	et	2	main
oli	doc_213943984922_item	2268661	et	3	main
rajatud	doc_213943984922_item	2268662	et	4	main
anitškovi	doc_213943984922_item	2268670	et	2	main
vaid	doc_213943984922_item	2268680	et	3	main
püsima	doc_213943984922_item	2268682	et	3	main
laadi	doc_213943984922_item	2268685	et	4	main
kurameerides	doc_213943984922_item	2268704	et	4	main
sind	doc_213943984922_item	2268712	et	4	main
armastan	doc_213943984922_item	2268710	et	3	main
viimasele	doc_213943984922_item	2268716	et	3	main
tähendab	doc_213943984922_item	2268724	et	3	main
ja	doc_213943984922_item	2268726	et	3	main
19	doc_213943984922_item	2268740	et	2	main
sajandi	doc_213943984922_item	2268741	et	3	main
venemaa	doc_213943984922_item	2268742	et	4	main
sõnu	doc_213943984922_item	2268747	et	4	main
käibele	doc_213943984922_item	2268748	et	4	main
viibisid	doc_213943984922_item	2268750	et	4	main
bomarsundi	doc_213943984922_item	2268752	et	4	main
aastakümnet	doc_213943984922_item	2268758	et	4	main
jäid	doc_213943984922_item	2268771	et	4	main
sõdureid	doc_213943984922_item	2268775	et	3	main
käsitöölisi	doc_213943984922_item	2268779	et	3	main
i	doc_213943984922_item	2268791	et	4	main
valitsemise	doc_213943984922_item	2268792	et	4	main
ihkan	doc_213943984922_item	2268727	et	3	main
ütlev	doc_213943984922_item	2268731	et	4	main
jäi	doc_213943984922_item	2268744	et	3	main
kaks	doc_213943984922_item	2268757	et	3	main
1854	doc_213943984922_item	2268759	et	2	main
krimmisõja	doc_213943984922_item	2268765	et	3	main
oktoobri	doc_213943984922_item	2268768	et	3	main
revolutsioonini	doc_213943984922_item	2268769	et	3	main
siia	doc_213943984922_item	2268770	et	4	main
elama	doc_213943984922_item	2268772	et	3	main
kaupmehi	doc_213943984922_item	2268777	et	3	main
postkontori	doc_213943984922_item	2268781	et	4	main
see	doc_213943984922_item	2268783	et	3	main
oli	doc_213943984922_item	2268785	et	3	main
impeeriumistiilis	doc_213943984922_item	2268787	et	3	main
1828	doc_213943984922_item	2268788	et	2	main
aastal	doc_213943984922_item	2268789	et	3	main
näeb	doc_213943984922_item	2268796	et	3	main
uuena	doc_213943984922_item	2268797	et	3	main
välja	doc_213943984922_item	2268798	et	4	main
jutustasid	doc_213943984922_item	2268799	et	4	main
komsomolskaja	doc_213943984922_item	2268800	et	4	main
pravda	doc_213943984922_item	2268801	et	4	main
korrespondentile	doc_213943984922_item	2268802	et	4	main
viimase	doc_213943984922_item	2268803	et	3	main
aja	doc_213943984922_item	2268804	et	4	main
kummalisest	doc_213943984922_item	2268805	et	3	main
tendentsist	doc_213943984922_item	2268806	et	3	main
kui	doc_213943984922_item	2268807	et	3	main
külma	doc_213943984922_item	2268808	et	4	main
sõja	doc_213943984922_item	2268809	et	3	main
ajal	doc_213943984922_item	2268810	et	4	main
ei	doc_213943984922_item	2268811	et	4	main
olnud	doc_213943984922_item	2268812	et	4	main
vene	doc_213943984922_item	2268814	et	4	main
perekonnanimedega	doc_213943984922_item	2268815	et	3	main
adressaate	doc_213943984922_item	2268816	et	3	main
alandidel	doc_213943984922_item	2268813	et	4	main
siis	doc_213943984922_item	2268817	et	3	main
viimasel	doc_213943984922_item	2268818	et	3	main
aastakümnel	doc_213943984922_item	2268819	et	4	main
toimetatakse	doc_213943984922_item	2268820	et	3	main
rohkem	doc_213943984922_item	2268824	et	4	main
kuigi	doc_213943984922_item	2268827	et	3	main
lahendus	doc_213943984922_item	2268832	et	4	main
lihtne	doc_213943984922_item	2268834	et	3	main
vene	doc_213943984922_item	2268839	et	4	main
meelde	doc_213943984922_item	2268843	et	3	main
ja	doc_213943984922_item	2268845	et	3	main
sidorovite	doc_213943984922_item	2268851	et	4	main
panna	doc_213943984922_item	2268863	et	4	main
ongi	doc_213943984922_item	2268865	et	4	main
vene	doc_213943984922_item	2268866	et	4	main
turistide	doc_213943984922_item	2268867	et	3	main
jaoks	doc_213943984922_item	2268868	et	4	main
яа	doc_213943984922_item	2268873	et	2	main
alandidel	doc_213943984922_item	2268745	et	4	main
venelased	doc_213943984922_item	2268749	et	3	main
aastani	doc_213943984922_item	2268760	et	3	main
bomarsund	doc_213943984922_item	2268762	et	4	main
nikolai	doc_213943984922_item	2268790	et	4	main
rohkem	doc_213943984922_item	2268822	et	4	main
venelastele	doc_213943984922_item	2268826	et	4	main
elanikkond	doc_213943984922_item	2268828	et	3	main
samaks	doc_213943984922_item	2268830	et	3	main
juuri	doc_213943984922_item	2268840	et	4	main
tunnevad	doc_213943984922_item	2268846	et	3	main
oma	doc_213943984922_item	2268849	et	4	main
vene	doc_213943984922_item	2268856	et	4	main
ei	doc_213943984922_item	2268858	et	4	main
vaikima	doc_213943984922_item	2268862	et	4	main
vestlus	doc_213943984922_item	2268869	et	3	main
nauding	doc_213943984922_item	2268872	et	3	main
боршч	doc_213943984922_item	2268877	et	2	main
perenaine	doc_213943984922_item	2268879	et	3	main
кофта	doc_213943984922_item	2268933	et	2	main
kamsun	doc_213943984922_item	2268934	et	4	main
kingitused	doc_213943984922_item	2268936	et	4	main
pole	doc_213943984922_item	2268937	et	3	main
alandlane	doc_213943984922_item	2268941	et	4	main
сарска	doc_213943984922_item	2268945	et	2	main
mida	doc_213943984922_item	2268950	et	4	main
oli	doc_213943984922_item	2268951	et	3	main
ei	doc_213943984922_item	2268958	et	4	main
söödavat	doc_213943984922_item	2268961	et	4	main
vaid	doc_213943984922_item	2268963	et	3	main
hoopis	doc_213943984922_item	2268964	et	3	main
präänikutele	doc_213943984922_item	2268971	et	3	main
tsaari	doc_213943984922_item	2268974	et	4	main
maiustuseks	doc_213943984922_item	2268983	et	4	main
üha	doc_213943984922_item	2268821	et	3	main
on	doc_213943984922_item	2268833	et	4	main
varem	doc_213943984922_item	2268837	et	4	main
varjasid	doc_213943984922_item	2268838	et	4	main
isegi	doc_213943984922_item	2268847	et	4	main
petrovide	doc_213943984922_item	2268852	et	4	main
ja	doc_213943984922_item	2268853	et	3	main
perepjolkinite	doc_213943984922_item	2268854	et	4	main
üle	doc_213943984922_item	2268855	et	3	main
keelt	doc_213943984922_item	2268857	et	4	main
aga	doc_213943984922_item	2268860	et	3	main
дурак	doc_213943984922_item	2268874	et	2	main
rootsi	doc_213943984922_item	2268880	et	4	main
segakeeles	doc_213943984922_item	2268882	et	4	main
see	doc_213943984922_item	2268883	et	3	main
ma	doc_213943984922_item	2268885	et	3	main
ei	doc_213943984922_item	2268886	et	4	main
oska	doc_213943984922_item	2268887	et	4	main
hästi	doc_213943984922_item	2268888	et	3	main
borši	doc_213943984922_item	2268889	et	2	main
keeta	doc_213943984922_item	2268890	et	4	main
suus	doc_213943984922_item	2268892	et	3	main
soomerootslaste	doc_213943984922_item	2268891	et	4	main
tunduvad	doc_213943984922_item	2268893	et	4	main
järgmised	doc_213943984922_item	2268894	et	3	main
sõnad	doc_213943984922_item	2268895	et	4	main
nii	doc_213943984922_item	2268896	et	3	main
картух	doc_213943984922_item	2268898	et	2	main
lähedased	doc_213943984922_item	2268897	et	3	main
kartuus	doc_213943984922_item	2268899	et	4	main
бутка	doc_213943984922_item	2268900	et	2	main
putka	doc_213943984922_item	2268901	et	4	main
хлейб	doc_213943984922_item	2268902	et	2	main
leib	doc_213943984922_item	2268903	et	3	main
siiamaani	doc_213943984922_item	2268904	et	3	main
süüakse	doc_213943984922_item	2268905	et	3	main
siin	doc_213943984922_item	2268906	et	4	main
ehtsat	doc_213943984922_item	2268907	et	3	main
vene	doc_213943984922_item	2268908	et	4	main
leiba	doc_213943984922_item	2268909	et	4	main
isegi	doc_213943984922_item	2268910	et	4	main
ahjud	doc_213943984922_item	2268911	et	3	main
on	doc_213943984922_item	2268912	et	4	main
säilinud	doc_213943984922_item	2268913	et	4	main
leiba	doc_213943984922_item	2268914	et	4	main
пироги	doc_213943984922_item	2268916	et	2	main
õhuaken	doc_213943984922_item	2268919	et	3	main
saarlasi	doc_213943984922_item	2268923	et	3	main
tuulutamist	doc_213943984922_item	2268930	et	4	main
мёд	doc_213943984922_item	2268931	et	2	main
mesi	doc_213943984922_item	2268932	et	4	main
vaja	doc_213943984922_item	2268938	et	4	main
kui	doc_213943984922_item	2268940	et	3	main
heita	doc_213943984922_item	2268943	et	3	main
прянника	doc_213943984922_item	2268946	et	2	main
saanud	doc_213943984922_item	2268956	et	4	main
see	doc_213943984922_item	2268957	et	3	main
pressitud	doc_213943984922_item	2268969	et	4	main
kirjaga	doc_213943984922_item	2268970	et	3	main
nimetatigi	doc_213943984922_item	2268981	et	4	main
pühapäeval	doc_213943984924_item	2269127	et	3	main
mis	doc_213943984924_item	2269133	et	4	main
järgib	doc_213943984924_item	2269134	et	3	main
mis	doc_213943984924_item	2269143	et	4	main
22	doc_213943984924_item	2269147	et	2	main
aga	doc_213943984924_item	2269155	et	3	main
müüa	doc_213943984924_item	2269174	et	3	main
piknikukorve	doc_213943984924_item	2269176	et	3	main
hakatakse	doc_213943984924_item	2269178	et	3	main
ja	doc_213943984924_item	2269183	et	3	main
tulevikus	doc_213943984924_item	2269185	et	4	main
luigetiigi	doc_213943984924_item	2269191	et	3	main
ning	doc_213943984924_item	2269193	et	3	main
üritusi	doc_213943984924_item	2269195	et	4	main
фортушка	doc_213943984922_item	2268918	et	2	main
venelased	doc_213943984922_item	2268921	et	3	main
külge	doc_213943984922_item	2268925	et	4	main
kinnitama	doc_213943984922_item	2268926	et	3	main
mis	doc_213943984922_item	2268927	et	4	main
imestada	doc_213943984922_item	2268939	et	3	main
pakub	doc_213943984922_item	2268942	et	3	main
käest	doc_213943984922_item	2268955	et	4	main
medalit	doc_213943984922_item	2268965	et	3	main
vene	doc_213943984922_item	2268968	et	4	main
peaaegu	doc_213943984922_item	2268976	et	3	main
nagu	doc_213943984922_item	2268978	et	3	main
autasu	doc_213943984922_item	2268982	et	4	main
tõlge	doc_213943984924_item	2269124	et	3	main
kohvik	doc_213943984924_item	2269126	et	3	main
avati	doc_213943984924_item	2269128	et	3	main
pargis	doc_213943984924_item	2269130	et	3	main
kohvikute	doc_213943984924_item	2269136	et	4	main
vahiputkas	doc_213943984924_item	2269141	et	3	main
kohvik	doc_213943984924_item	2269159	et	3	main
seest	doc_213943984924_item	2269161	et	3	main
kujundatud	doc_213943984924_item	2269162	et	4	main
pargivaadetega	doc_213943984924_item	2269163	et	3	main
vanade	doc_213943984924_item	2269164	et	3	main
riietus	doc_213943984924_item	2269167	et	4	main
suvel	doc_213943984924_item	2269172	et	3	main
samuti	doc_213943984924_item	2269177	et	3	main
seal	doc_213943984924_item	2269179	et	4	main
pargiainelisi	doc_213943984924_item	2269181	et	4	main
ääres	doc_213943984924_item	2269192	et	4	main
hoone	doc_213943984924_item	2269196	et	4	main
9	doc_213943984924_item	2269221	et	2	main
pühapäeviti	doc_213943984924_item	2269224	et	4	main
pargikohvik	doc_213943984924_item	2269232	et	3	main
arendamise	doc_213943984924_item	2269235	et	4	main
muutub	doc_213943984924_item	2269241	et	3	main
pargi	doc_213943984924_item	2269244	et	4	main
muuseum	doc_213943984924_item	2269250	et	3	main
peale	doc_213943984925_item	2269273	et	4	main
stabiilselt	doc_213943984925_item	2269290	et	4	main
areneda	doc_213943984925_item	2269291	et	3	main
kes	doc_213943984925_item	2269294	et	4	main
ütleb	doc_213943984925_item	2269297	et	3	main
vilja	doc_213943984925_item	2269301	et	4	main
kiiresti	doc_213943984925_item	2269306	et	3	main
loomise	doc_213943984925_item	2269309	et	4	main
1993	doc_213943984925_item	2269311	et	2	main
aastal	doc_213943984925_item	2269312	et	3	main
erinevad	doc_213943984925_item	2269325	et	4	main
arengu	doc_213943984925_item	2269333	et	3	main
plaani	doc_213943984925_item	2269334	et	4	main
töötama	doc_213943984925_item	2269337	et	3	main
neljapäeval	doc_213943984925_item	2269342	et	3	main
projektide	doc_213943984925_item	2269353	et	3	main
õpetasid	doc_213943984922_item	2268922	et	4	main
õhuaknaid	doc_213943984922_item	2268924	et	3	main
pilku	doc_213943984922_item	2268944	et	4	main
tsaari	doc_213943984922_item	2268947	et	4	main
peale	doc_213943984922_item	2268949	et	4	main
vene	doc_213943984922_item	2268953	et	4	main
tsaari	doc_213943984922_item	2268954	et	4	main
veel	doc_213943984922_item	2268960	et	4	main
maguspala	doc_213943984922_item	2268962	et	4	main
või	doc_213943984922_item	2268966	et	4	main
tihti	doc_213943984922_item	2268972	et	3	main
samagust	doc_213943984922_item	2268977	et	4	main
medalitelgi	doc_213943984922_item	2268979	et	4	main
tiigiäärne	doc_213943984924_item	2269125	et	3	main
kadrioru	doc_213943984924_item	2269129	et	3	main
vanas	doc_213943984924_item	2269140	et	3	main
maja	doc_213943984924_item	2269142	et	4	main
kuulub	doc_213943984924_item	2269144	et	3	main
lossikompleksi	doc_213943984924_item	2269145	et	4	main
weizenbergi	doc_213943984924_item	2269146	et	4	main
on	doc_213943984924_item	2269149	et	4	main
neljakümnele	doc_213943984924_item	2269151	et	4	main
külastajale	doc_213943984924_item	2269152	et	4	main
suveterass	doc_213943984924_item	2269153	et	4	main
mahutab	doc_213943984924_item	2269154	et	3	main
veel	doc_213943984924_item	2269156	et	4	main
kelnerite	doc_213943984924_item	2269166	et	3	main
ajaloolisele	doc_213943984924_item	2269170	et	4	main
müüma	doc_213943984924_item	2269180	et	3	main
postkaarte	doc_213943984924_item	2269182	et	4	main
brošüüre	doc_213943984924_item	2269184	et	2	main
19	doc_213943984924_item	2269222	et	2	main
18	doc_213943984924_item	2269226	et	2	main
sõnul	doc_213943984924_item	2269230	et	3	main
millele	doc_213943984924_item	2269239	et	3	main
kunstimuuseum	doc_213943984924_item	2269260	et	3	main
tõlge	doc_213943984925_item	2269270	et	3	main
jõulupühi	doc_213943984925_item	2269274	et	3	main
toimunud	doc_213943984925_item	2269276	et	4	main
kinnitas	doc_213943984925_item	2269278	et	3	main
2007	doc_213943984925_item	2269284	et	2	main
tuleb	doc_213943984925_item	2269295	et	3	main
võimule	doc_213943984925_item	2269296	et	3	main
linnaosa	doc_213943984925_item	2269299	et	4	main
on	doc_213943984925_item	2269305	et	4	main
see	doc_213943984925_item	2269314	et	3	main
majanduslikud	doc_213943984925_item	2269326	et	3	main
huvid	doc_213943984925_item	2269327	et	3	main
linnaosavanem	doc_213943984925_item	2269329	et	4	main
tasakaalustatud	doc_213943984925_item	2269332	et	4	main
hakati	doc_213943984925_item	2269335	et	3	main
2003	doc_213943984925_item	2269338	et	2	main
cafe	doc_213943984924_item	2269131	et	4	main
ning	doc_213943984924_item	2269148	et	3	main
mõeldud	doc_213943984924_item	2269150	et	4	main
60	doc_213943984924_item	2269157	et	2	main
gravüüridega	doc_213943984924_item	2269165	et	3	main
pargi	doc_213943984924_item	2269169	et	4	main
kavatsetakse	doc_213943984924_item	2269186	et	3	main
kohvikus	doc_213943984924_item	2269187	et	3	main
kontserte	doc_213943984924_item	2269189	et	3	main
jõululaada	doc_213943984924_item	2269190	et	3	main
teisi	doc_213943984924_item	2269194	et	4	main
ja	doc_213943984924_item	2269223	et	3	main
10	doc_213943984924_item	2269225	et	2	main
on	doc_213943984924_item	2269231	et	4	main
loodud	doc_213943984924_item	2269233	et	4	main
kadrioru	doc_213943984924_item	2269234	et	3	main
programmi	doc_213943984924_item	2269236	et	4	main
ahtammsaare	doc_213943984924_item	2269248	et	4	main
väliskunsti	doc_213943984924_item	2269256	et	4	main
ja	doc_213943984924_item	2269258	et	3	main
veepark	doc_213943984925_item	2269271	et	3	main
istungil	doc_213943984925_item	2269277	et	3	main
põhja-tallinna	doc_213943984925_item	2269280	et	4	main
võib	doc_213943984925_item	2269288	et	3	main
sellest	doc_213943984925_item	2269293	et	4	main
arenenud	doc_213943984925_item	2269307	et	4	main
on	doc_213943984925_item	2269315	et	4	main
kohviku	doc_213943984924_item	2269132	et	3	main
viini	doc_213943984924_item	2269135	et	4	main
traditsioone	doc_213943984924_item	2269137	et	3	main
kohvik	doc_213943984924_item	2269138	et	3	main
asub	doc_213943984924_item	2269139	et	3	main
inimest	doc_213943984924_item	2269158	et	3	main
on	doc_213943984924_item	2269160	et	4	main
vastab	doc_213943984924_item	2269168	et	3	main
miljööle	doc_213943984924_item	2269171	et	3	main
plaanitakse	doc_213943984924_item	2269173	et	4	main
pargikülastajatele	doc_213943984924_item	2269175	et	3	main
korraldada	doc_213943984924_item	2269188	et	3	main
sisetöid	doc_213943984924_item	2269197	et	3	main
mille	doc_213943984924_item	2269198	et	3	main
maksumus	doc_213943984924_item	2269199	et	3	main
oli	doc_213943984924_item	2269200	et	3	main
2	doc_213943984924_item	2269201	et	2	main
krooni	doc_213943984924_item	2269203	et	4	main
teostas	doc_213943984924_item	2269204	et	3	main
xxx	doc_213943984924_item	2269205	et	4	main
xxx	doc_213943984924_item	2269206	et	4	main
mln	doc_213943984924_item	2269202	et	4	main
as	doc_213943984924_item	2269207	et	4	main
sisekujundamisel	doc_213943984924_item	2269208	et	3	main
võttis	doc_213943984924_item	2269209	et	3	main
osa	doc_213943984924_item	2269210	et	4	main
arhitekt	doc_213943984924_item	2269211	et	3	main
eesnimi	doc_213943984924_item	2269212	et	3	main
perekonnanimi	doc_213943984924_item	2269213	et	3	main
kohvik	doc_213943984924_item	2269214	et	3	main
on	doc_213943984924_item	2269215	et	4	main
tööpäevadel	doc_213943984924_item	2269217	et	3	main
830	doc_213943984924_item	2269218	et	2	main
2000	doc_213943984924_item	2269219	et	2	main
laupäeviti	doc_213943984924_item	2269220	et	4	main
avatud	doc_213943984924_item	2269216	et	4	main
eesnimi	doc_213943984924_item	2269228	et	3	main
park	doc_213943984924_item	2269242	et	3	main
muuseumiks	doc_213943984924_item	2269243	et	3	main
territooriumil	doc_213943984924_item	2269245	et	3	main
juba	doc_213943984924_item	2269246	et	3	main
paiknevad	doc_213943984924_item	2269247	et	4	main
on	doc_213943984924_item	2269262	et	4	main
vene	doc_213943984924_item	2269264	et	4	main
muuseum	doc_213943984924_item	2269265	et	3	main
ja	doc_213943984924_item	2269266	et	3	main
lastemuuseum	doc_213943984924_item	2269267	et	3	main
lisas	doc_213943984924_item	2269268	et	4	main
stroomirannas	doc_213943984925_item	2269272	et	4	main
2010	doc_213943984925_item	2269285	et	2	main
alusel	doc_213943984925_item	2269287	et	4	main
piirkond	doc_213943984925_item	2269289	et	3	main
savisaar	doc_213943984925_item	2269302	et	3	main
linna	doc_213943984925_item	2269303	et	4	main
põhjaosa	doc_213943984925_item	2269304	et	4	main
kuid	doc_213943984925_item	2269313	et	4	main
kontrollile	doc_213943984925_item	2269317	et	3	main
alumatult	doc_213943984925_item	2269318	et	4	main
abilinnapea	doc_213943984924_item	2269227	et	4	main
perekonnanimi	doc_213943984924_item	2269229	et	3	main
raames	doc_213943984924_item	2269237	et	4	main
vastavalt	doc_213943984924_item	2269238	et	4	main
park	doc_213943984924_item	2269240	et	3	main
evilde	doc_213943984924_item	2269251	et	4	main
maja	doc_213943984924_item	2269252	et	4	main
muuseum	doc_213943984924_item	2269253	et	3	main
maja	doc_213943984924_item	2269249	et	4	main
mikkeli	doc_213943984924_item	2269254	et	4	main
galerii	doc_213943984924_item	2269255	et	4	main
muuseum	doc_213943984924_item	2269257	et	3	main
eesti	doc_213943984924_item	2269259	et	4	main
tulekul	doc_213943984924_item	2269261	et	3	main
veel	doc_213943984924_item	2269263	et	4	main
perekonnanimi	doc_213943984924_item	2269269	et	3	main
esimesel	doc_213943984925_item	2269275	et	3	main
linnavalitsus	doc_213943984925_item	2269279	et	3	main
linnaosa	doc_213943984925_item	2269281	et	4	main
arenguplaani	doc_213943984925_item	2269282	et	4	main
heakskiidetud	doc_213943984925_item	2269283	et	4	main
arenguprogrammi	doc_213943984925_item	2269286	et	4	main
sõltumata	doc_213943984925_item	2269292	et	4	main
põhja-tallinna	doc_213943984925_item	2269298	et	4	main
vanem	doc_213943984925_item	2269300	et	4	main
selle	doc_213943984925_item	2269308	et	4	main
hetkest	doc_213943984925_item	2269310	et	4	main
toimunud	doc_213943984925_item	2269316	et	4	main
peamiseks	doc_213943984925_item	2269319	et	3	main
seni	doc_213943984925_item	2269323	et	3	main
aastal	doc_213943984925_item	2269339	et	3	main
poolt	doc_213943984925_item	2269346	et	4	main
dokument	doc_213943984925_item	2269351	et	3	main
paika	doc_213943984925_item	2269360	et	4	main
pandud	doc_213943984925_item	2269361	et	4	main
vanu	doc_213943984925_item	2269384	et	4	main
taastada	doc_213943984925_item	2269388	et	3	main
majaperemeeste	doc_213943984925_item	2269391	et	4	main
on	doc_213943984925_item	2269395	et	4	main
mis	doc_213943984925_item	2269403	et	4	main
kuuluvad	doc_213943984925_item	2269416	et	4	main
paljud	doc_213943984925_item	2269418	et	3	main
paneelmajad	doc_213943984925_item	2269419	et	3	main
üsna	doc_213943984925_item	2269421	et	3	main
piirkonnas	doc_213943984925_item	2269424	et	4	main
ja	doc_213943984925_item	2269432	et	3	main
kuid	doc_213943984925_item	2269434	et	4	main
sirbi-vasara	doc_213943984925_item	2269443	et	3	main
põhiosa	doc_213943984925_item	2269447	et	4	main
lähimatel	doc_213943984925_item	2269458	et	4	main
ümber	doc_213943984925_item	2269460	et	3	main
ehitada	doc_213943984925_item	2269461	et	3	main
veevarustuse	doc_213943984925_item	2269462	et	3	main
võrku	doc_213943984925_item	2269463	et	4	main
kanalisatsiooni	doc_213943984925_item	2269465	et	4	main
on	doc_213943984925_item	2269478	et	4	main
ümbersõiduteed	doc_213943984925_item	2269480	et	4	main
pööratakse	doc_213943984925_item	2269486	et	3	main
ja	doc_213943984925_item	2269522	et	3	main
platse	doc_213943984925_item	2269523	et	3	main
luua	doc_213943984925_item	2269525	et	4	main
juba	doc_213943984925_item	2269530	et	3	main
saanud	doc_213943984925_item	2269532	et	4	main
üks	doc_213943984925_item	2269533	et	3	main
puhkuse	doc_213943984925_item	2269535	et	3	main
tallinlasi	doc_213943984925_item	2269545	et	3	main
ligi	doc_213943984925_item	2269546	et	3	main
kõikidest	doc_213943984925_item	2269547	et	4	main
inimeste	doc_213943984925_item	2269555	et	3	main
jaoks	doc_213943984925_item	2269556	et	4	main
ligipääsetavaks	doc_213943984925_item	2269558	et	4	main
kuuluvad	doc_213943984925_item	2269566	et	4	main
ranna	doc_213943984925_item	2269568	et	3	main
park	doc_213943984925_item	2269575	et	3	main
teel	doc_213943984926_item	2269610	et	4	main
koostöös	doc_213943984926_item	2269611	et	3	main
projekt	doc_213943984926_item	2269626	et	3	main
interreg	doc_213943984926_item	2269628	et	4	main
programmi	doc_213943984926_item	2269629	et	4	main
järve	doc_213943984926_item	2269635	et	4	main
linna	doc_213943984926_item	2269636	et	4	main
vaheline	doc_213943984926_item	2269637	et	4	main
me	doc_213943984926_item	2269641	et	4	main
piirialase	doc_213943984926_item	2269659	et	4	main
sankt-peterburi	doc_213943984926_item	2269669	et	4	main
projektiga	doc_213943984926_item	2269678	et	4	main
ning	doc_213943984926_item	2269681	et	3	main
kogemused	doc_213943984926_item	2269686	et	3	main
kohtla	doc_213943984926_item	2269688	et	4	main
pärandiks	doc_213943984926_item	2269690	et	4	main
omandiks	doc_213943984926_item	2269691	et	3	main
määravaks	doc_213943984925_item	2269320	et	4	main
faktoriks	doc_213943984925_item	2269321	et	3	main
olnud	doc_213943984925_item	2269324	et	4	main
linnaosa	doc_213943984925_item	2269331	et	4	main
välja	doc_213943984925_item	2269336	et	4	main
ning	doc_213943984925_item	2269340	et	3	main
linnavalitsuse	doc_213943984925_item	2269345	et	3	main
kinnitatud	doc_213943984925_item	2269347	et	4	main
peale	doc_213943984925_item	2269348	et	4	main
järgnevaks	doc_213943984925_item	2269355	et	4	main
või	doc_213943984925_item	2269387	et	4	main
mahajäetud	doc_213943984925_item	2269393	et	4	main
see	doc_213943984925_item	2269394	et	3	main
palju	doc_213943984925_item	2269401	et	4	main
säilitada	doc_213943984925_item	2269411	et	3	main
räbaldunud	doc_213943984925_item	2269422	et	4	main
jätkata	doc_213943984925_item	2269426	et	4	main
ehitatakse	doc_213943984925_item	2269429	et	3	main
liinide	doc_213943984925_item	2269441	et	3	main
kalamajas	doc_213943984925_item	2269466	et	3	main
pelgulinnas	doc_213943984925_item	2269469	et	4	main
elanikke	doc_213943984925_item	2269471	et	3	main
ka	doc_213943984925_item	2269473	et	3	main
teedeehitus	doc_213943984925_item	2269475	et	4	main
seatud	doc_213943984925_item	2269479	et	4	main
transpordi	doc_213943984925_item	2269488	et	4	main
on	doc_213943984925_item	2269322	et	4	main
märkis	doc_213943984925_item	2269328	et	3	main
põhja-tallinna	doc_213943984925_item	2269330	et	4	main
oli	doc_213943984925_item	2269343	et	3	main
ülesannete	doc_213943984925_item	2269349	et	3	main
nimestikku	doc_213943984925_item	2269354	et	4	main
neljaks	doc_213943984925_item	2269356	et	4	main
teostamisaeg	doc_213943984925_item	2269362	et	3	main
investorid	doc_213943984925_item	2269365	et	4	main
kui	doc_213943984925_item	2269366	et	3	main
kõik	doc_213943984925_item	2269367	et	4	main
kavandatud	doc_213943984925_item	2269368	et	4	main
on	doc_213943984925_item	2269369	et	4	main
täidetud	doc_213943984925_item	2269370	et	4	main
siis	doc_213943984925_item	2269371	et	3	main
2010-l	doc_213943984925_item	2269372	et	3	main
aastal	doc_213943984925_item	2269373	et	3	main
ei	doc_213943984925_item	2269374	et	4	main
nimeta	doc_213943984925_item	2269375	et	4	main
enam	doc_213943984925_item	2269376	et	4	main
keegi	doc_213943984925_item	2269377	et	4	main
põhja-tallinna	doc_213943984925_item	2269378	et	4	main
lihvimata	doc_213943984925_item	2269379	et	4	main
teemandiks	doc_213943984925_item	2269380	et	4	main
siin	doc_213943984925_item	2269381	et	4	main
kavatsetakse	doc_213943984925_item	2269382	et	3	main
eelmisel	doc_213943984925_item	2269341	et	3	main
see	doc_213943984925_item	2269344	et	3	main
sisaldab	doc_213943984925_item	2269350	et	3	main
konkreetsete	doc_213943984925_item	2269352	et	3	main
aastaks	doc_213943984925_item	2269357	et	4	main
kus	doc_213943984925_item	2269358	et	3	main
on	doc_213943984925_item	2269359	et	4	main
ja	doc_213943984925_item	2269363	et	3	main
piirkonnas	doc_213943984925_item	2269399	et	4	main
asub	doc_213943984925_item	2269400	et	3	main
linnale	doc_213943984925_item	2269415	et	4	main
potentsiaalsed	doc_213943984925_item	2269364	et	3	main
korrastada	doc_213943984925_item	2269383	et	3	main
hooneid	doc_213943984925_item	2269385	et	4	main
lammutada	doc_213943984925_item	2269386	et	3	main
ja	doc_213943984925_item	2269390	et	3	main
poolt	doc_213943984925_item	2269392	et	4	main
kuna	doc_213943984925_item	2269398	et	3	main
on	doc_213943984925_item	2269404	et	4	main
poolest	doc_213943984925_item	2269406	et	4	main
neid	doc_213943984925_item	2269409	et	4	main
vajavad	doc_213943984925_item	2269413	et	4	main
ühiselamud	doc_213943984925_item	2269417	et	3	main
munitsipaalelamute	doc_213943984925_item	2269427	et	3	main
ka	doc_213943984925_item	2269430	et	3	main
aasta	doc_213943984925_item	2269436	et	4	main
peamiseks	doc_213943984925_item	2269437	et	3	main
kvartali	doc_213943984925_item	2269444	et	3	main
põhja-tallinna	doc_213943984925_item	2269446	et	4	main
kujundavad	doc_213943984925_item	2269448	et	4	main
vanad	doc_213943984925_item	2269449	et	3	main
kus	doc_213943984925_item	2269451	et	3	main
probleemid	doc_213943984925_item	2269454	et	3	main
piirkonna	doc_213943984925_item	2269470	et	4	main
pelgulinna	doc_213943984925_item	2269483	et	4	main
ümber	doc_213943984925_item	2269484	et	3	main
samuti	doc_213943984925_item	2269485	et	3	main
põhja-tallinnast	doc_213943984925_item	2269528	et	3	main
eriti	doc_213943984925_item	2269537	et	3	main
pargid	doc_213943984925_item	2269541	et	4	main
ja	doc_213943984925_item	2269542	et	3	main
linna	doc_213943984925_item	2269548	et	4	main
seepärast	doc_213943984925_item	2269550	et	3	main
peale	doc_213943984925_item	2269567	et	4	main
iseenda	doc_213943984925_item	2269569	et	3	main
metsapark	doc_213943984925_item	2269571	et	3	main
ranniku	doc_213943984925_item	2269574	et	3	main
muuseumi	doc_213943984926_item	2269607	et	4	main
kestab	doc_213943984926_item	2269617	et	4	main
aastat	doc_213943984926_item	2269619	et	3	main
lagunenud	doc_213943984925_item	2269389	et	4	main
raske	doc_213943984925_item	2269396	et	4	main
töö	doc_213943984925_item	2269397	et	4	main
hooneid	doc_213943984925_item	2269402	et	4	main
arhitektuuri	doc_213943984925_item	2269405	et	4	main
väärtuslikud	doc_213943984925_item	2269407	et	3	main
ning	doc_213943984925_item	2269408	et	3	main
tuleb	doc_213943984925_item	2269410	et	3	main
samuti	doc_213943984925_item	2269412	et	3	main
rekontruktsiooni	doc_213943984925_item	2269414	et	4	main
näevad	doc_213943984925_item	2269420	et	3	main
välja	doc_213943984925_item	2269423	et	4	main
sotsiaalmaju	doc_213943984925_item	2269431	et	3	main
varjupaike	doc_213943984925_item	2269433	et	4	main
järgneva	doc_213943984925_item	2269435	et	4	main
on	doc_213943984925_item	2269439	et	4	main
ja	doc_213943984925_item	2269442	et	3	main
rekonstruktsioon	doc_213943984925_item	2269445	et	3	main
piirkonnad	doc_213943984925_item	2269450	et	4	main
on	doc_213943984925_item	2269452	et	4	main
kommunikatsioonidega	doc_213943984925_item	2269455	et	3	main
selletõttu	doc_213943984925_item	2269456	et	4	main
aastatel	doc_213943984925_item	2269459	et	4	main
ja	doc_213943984925_item	2269468	et	3	main
suur	doc_213943984925_item	2269474	et	3	main
kalamaja	doc_213943984925_item	2269481	et	4	main
sportsaale	doc_213943984925_item	2269521	et	3	main
noortekeskust	doc_213943984925_item	2269527	et	4	main
kohti	doc_213943984925_item	2269536	et	4	main
kui	doc_213943984925_item	2269540	et	3	main
meelitavad	doc_213943984925_item	2269544	et	4	main
otsustatud	doc_213943984925_item	2269552	et	4	main
muuta	doc_213943984925_item	2269554	et	4	main
võimalikult	doc_213943984925_item	2269557	et	4	main
merimetsa	doc_213943984925_item	2269572	et	4	main
arendamise	doc_213943984926_item	2269609	et	4	main
projekt	doc_213943984926_item	2269616	et	3	main
miljonit	doc_213943984926_item	2269624	et	3	main
finanseeritakse	doc_213943984926_item	2269627	et	4	main
vene	doc_213943984926_item	2269631	et	4	main
kohtla	doc_213943984926_item	2269634	et	4	main
edukalt	doc_213943984926_item	2269640	et	4	main
aleksei	doc_213943984926_item	2269657	et	4	main
kus	doc_213943984926_item	2269670	et	3	main
peterburi	doc_213943984926_item	2269679	et	4	main
kokkupuutumisest	doc_213943984926_item	2269684	et	3	main
tekkinud	doc_213943984926_item	2269685	et	4	main
järve	doc_213943984926_item	2269695	et	4	main
filiaali	doc_213943984926_item	2269699	et	4	main
filiaal	doc_213943984926_item	2269710	et	3	main
otsustas	doc_213943984926_item	2269711	et	3	main
muuseumide	doc_213943984926_item	2269713	et	3	main
spetsiaalse	doc_213943984926_item	2269721	et	3	main
baas	doc_213943984926_item	2269740	et	3	main
valitakse	doc_213943984926_item	2269741	et	3	main
vene	doc_213943984926_item	2269743	et	4	main
kes	doc_213943984926_item	2269748	et	4	main
ning	doc_213943984926_item	2269764	et	3	main
hiljem	doc_213943984926_item	2269770	et	3	main
kohtla	doc_213943984926_item	2269773	et	4	main
läbi	doc_213943984926_item	2269783	et	4	main
töörühma	doc_213943984926_item	2269818	et	4	main
liige	doc_213943984926_item	2269819	et	4	main
adusman	doc_213943984926_item	2269820	et	4	main
essee	doc_213943984927_item	2269821	et	4	main
15	doc_213943984927_item	2269824	et	2	main
augustil	doc_213943984927_item	2269825	et	3	main
maardus	doc_213943984927_item	2269832	et	4	main
19	doc_213943984927_item	2269834	et	2	main
aastat	doc_213943984927_item	2269835	et	3	main
hakkasin	doc_213943984927_item	2269840	et	3	main
aga	doc_213943984927_item	2269843	et	3	main
hakkasin	doc_213943984927_item	2269853	et	3	main
pedagoogika	doc_213943984927_item	2269868	et	4	main
olin	doc_213943984927_item	2269873	et	3	main
aastat	doc_213943984927_item	2269875	et	3	main
suvel	doc_213943984927_item	2269877	et	3	main
mul	doc_213943984927_item	2269888	et	3	main
sündmus	doc_213943984927_item	2269900	et	3	main
ma	doc_213943984927_item	2269904	et	3	main
mul	doc_213943984927_item	2269919	et	3	main
plaanitakse	doc_213943984925_item	2269425	et	4	main
ehitamist	doc_213943984925_item	2269428	et	4	main
projektiks	doc_213943984925_item	2269438	et	4	main
kopli	doc_213943984925_item	2269440	et	3	main
suured	doc_213943984925_item	2269453	et	3	main
kavatsetakse	doc_213943984925_item	2269457	et	3	main
ja	doc_213943984925_item	2269464	et	3	main
koplis	doc_213943984925_item	2269467	et	3	main
ootab	doc_213943984925_item	2269472	et	3	main
kuid	doc_213943984925_item	2269476	et	4	main
prioriteediks	doc_213943984925_item	2269477	et	3	main
ja	doc_213943984925_item	2269482	et	3	main
tähelepanu	doc_213943984925_item	2269487	et	4	main
sõlmile	doc_213943984925_item	2269489	et	4	main
sitsi	doc_213943984925_item	2269490	et	4	main
mäel	doc_213943984925_item	2269491	et	3	main
linnaosa	doc_213943984925_item	2269493	et	4	main
arenguprogrammis	doc_213943984925_item	2269494	et	3	main
põhja-tallinna	doc_213943984925_item	2269492	et	4	main
on	doc_213943984925_item	2269495	et	4	main
eriline	doc_213943984925_item	2269496	et	4	main
tähelepanu	doc_213943984925_item	2269497	et	4	main
pööratud	doc_213943984925_item	2269498	et	4	main
sotsiaalsetele	doc_213943984925_item	2269499	et	4	main
objektidele	doc_213943984925_item	2269500	et	3	main
munitsipaalkoolid	doc_213943984925_item	2269501	et	3	main
ja	doc_213943984925_item	2269502	et	3	main
lasteaiad	doc_213943984925_item	2269503	et	4	main
rekonstrueeritakse	doc_213943984925_item	2269504	et	3	main
täiendatakse	doc_213943984925_item	2269505	et	4	main
õppe-	doc_213943984925_item	2269506	et	4	main
ja	doc_213943984925_item	2269507	et	3	main
kultuuriasutuste	doc_213943984925_item	2269508	et	4	main
materiaal-tehnilist	doc_213943984925_item	2269509	et	3	main
baasi	doc_213943984925_item	2269510	et	4	main
alustatakse	doc_213943984925_item	2269511	et	3	main
sõle	doc_213943984925_item	2269512	et	3	main
gümnaasiumi	doc_213943984925_item	2269513	et	4	main
juurde	doc_213943984925_item	2269514	et	4	main
spordikeskuse	doc_213943984925_item	2269515	et	3	main
ehitamist	doc_213943984925_item	2269516	et	4	main
ning	doc_213943984925_item	2269517	et	3	main
uuendatakse	doc_213943984925_item	2269518	et	3	main
juba	doc_213943984925_item	2269519	et	3	main
olemasolevaid	doc_213943984925_item	2269520	et	3	main
plaanitakse	doc_213943984925_item	2269524	et	4	main
avatud	doc_213943984925_item	2269526	et	4	main
ajal	doc_213943984925_item	2269539	et	4	main
on	doc_213943984925_item	2269529	et	4	main
ammu	doc_213943984925_item	2269531	et	4	main
lemmikumaid	doc_213943984925_item	2269534	et	4	main
suve	doc_213943984925_item	2269538	et	4	main
piirkondadest	doc_213943984925_item	2269549	et	3	main
rannatsooni	doc_213943984925_item	2269553	et	4	main
kuhu	doc_213943984925_item	2269565	et	3	main
ja	doc_213943984925_item	2269573	et	3	main
rannamajakese	doc_213943984925_item	2269576	et	4	main
kõrvale	doc_213943984925_item	2269577	et	4	main
peaks	doc_213943984925_item	2269578	et	4	main
lähiajal	doc_213943984925_item	2269579	et	3	main
ilmuma	doc_213943984925_item	2269580	et	3	main
veepark	doc_213943984925_item	2269581	et	3	main
tõlge	doc_213943984926_item	2269582	et	3	main
kohtla	doc_213943984926_item	2269583	et	4	main
järve	doc_213943984926_item	2269584	et	4	main
arendab	doc_213943984926_item	2269585	et	3	main
koostööd	doc_213943984926_item	2269586	et	4	main
vene	doc_213943984926_item	2269587	et	4	main
muuseumiga	doc_213943984926_item	2269588	et	3	main
kohtla	doc_213943984926_item	2269589	et	4	main
järve	doc_213943984926_item	2269590	et	4	main
põlevkivi	doc_213943984926_item	2269591	et	4	main
muuseum	doc_213943984926_item	2269592	et	3	main
koos	doc_213943984926_item	2269593	et	4	main
sankt-peterburi	doc_213943984926_item	2269594	et	4	main
vene	doc_213943984926_item	2269595	et	4	main
muuseumi	doc_213943984926_item	2269596	et	4	main
ning	doc_213943984926_item	2269597	et	3	main
kohtla	doc_213943984926_item	2269598	et	4	main
järve	doc_213943984926_item	2269599	et	4	main
linnavalitsusega	doc_213943984926_item	2269600	et	3	main
koostasid	doc_213943984926_item	2269601	et	4	main
projekti	doc_213943984926_item	2269602	et	4	main
uue	doc_213943984926_item	2269603	et	3	main
rannad	doc_213943984925_item	2269543	et	3	main
on	doc_213943984925_item	2269551	et	4	main
enne	doc_213943984925_item	2269559	et	4	main
kõige	doc_213943984925_item	2269560	et	4	main
kavatsetakse	doc_213943984925_item	2269561	et	3	main
korrastada	doc_213943984925_item	2269562	et	3	main
stroomi	doc_213943984925_item	2269563	et	4	main
rannatsooni	doc_213943984925_item	2269564	et	4	main
ka	doc_213943984925_item	2269570	et	3	main
turismimarsruudi	doc_213943984926_item	2269604	et	3	main
loomine	doc_213943984926_item	2269605	et	4	main
vene	doc_213943984926_item	2269606	et	4	main
ja	doc_213943984926_item	2269613	et	3	main
eesti	doc_213943984926_item	2269614	et	4	main
eelarve	doc_213943984926_item	2269621	et	4	main
kaudu	doc_213943984926_item	2269630	et	3	main
areneb	doc_213943984926_item	2269639	et	3	main
jätkame	doc_213943984926_item	2269642	et	3	main
kohtla	doc_213943984926_item	2269643	et	4	main
muuseumi	doc_213943984926_item	2269645	et	4	main
virtuaalse	doc_213943984926_item	2269646	et	3	main
avamisest	doc_213943984926_item	2269648	et	4	main
boiko	doc_213943984926_item	2269658	et	4	main
raames	doc_213943984926_item	2269661	et	4	main
neile	doc_213943984926_item	2269671	et	4	main
tutvustatakse	doc_213943984926_item	2269672	et	3	main
muuseumi	doc_213943984926_item	2269673	et	4	main
kultuuriga	doc_213943984926_item	2269683	et	4	main
vene	doc_213943984926_item	2269696	et	4	main
virtuaalse	doc_213943984926_item	2269698	et	3	main
edukal	doc_213943984926_item	2269700	et	3	main
töökogemusel	doc_213943984926_item	2269701	et	3	main
põlevkivi	doc_213943984926_item	2269702	et	4	main
koostööd	doc_213943984926_item	2269715	et	4	main
kaudu	doc_213943984926_item	2269718	et	3	main
pärandiga	doc_213943984926_item	2269726	et	4	main
tutvumiseks	doc_213943984926_item	2269727	et	4	main
vene	doc_213943984926_item	2269737	et	4	main
infotehnolooge	doc_213943984926_item	2269747	et	4	main
teadmisi	doc_213943984926_item	2269751	et	4	main
rakendada	doc_213943984926_item	2269752	et	3	main
kaks	doc_213943984926_item	2269762	et	3	main
seejärel	doc_213943984926_item	2269765	et	3	main
virtuaalsete	doc_213943984926_item	2269767	et	3	main
arendamist	doc_213943984926_item	2269769	et	4	main
filiaalis	doc_213943984926_item	2269776	et	3	main
selle	doc_213943984926_item	2269778	et	4	main
töötajad	doc_213943984926_item	2269782	et	4	main
virtuaalmaailma	doc_213943984926_item	2269608	et	4	main
veene	doc_213943984926_item	2269612	et	4	main
noortega	doc_213943984926_item	2269615	et	3	main
2	doc_213943984926_item	2269618	et	2	main
selle	doc_213943984926_item	2269620	et	4	main
on	doc_213943984926_item	2269622	et	4	main
doktorikraadiga	doc_213943984926_item	2269656	et	3	main
koostöö	doc_213943984926_item	2269660	et	4	main
väljapanekuid	doc_213943984926_item	2269674	et	3	main
samuti	doc_213943984926_item	2269675	et	3	main
selle	doc_213943984926_item	2269677	et	4	main
noori	doc_213943984926_item	2269680	et	3	main
kokkuvõttes	doc_213943984926_item	2269682	et	3	main
jäävad	doc_213943984926_item	2269687	et	4	main
kohtla	doc_213943984926_item	2269694	et	4	main
mille	doc_213943984926_item	2269705	et	3	main
kuulub	doc_213943984926_item	2269707	et	3	main
4	doc_213943984926_item	2269623	et	2	main
krooni	doc_213943984926_item	2269625	et	4	main
muuseumi	doc_213943984926_item	2269632	et	4	main
ja	doc_213943984926_item	2269633	et	3	main
koostöö	doc_213943984926_item	2269638	et	4	main
järve	doc_213943984926_item	2269644	et	4	main
filiaali	doc_213943984926_item	2269647	et	4	main
alustatud	doc_213943984926_item	2269649	et	4	main
koostööd	doc_213943984926_item	2269650	et	4	main
ütles	doc_213943984926_item	2269651	et	3	main
vene	doc_213943984926_item	2269652	et	4	main
muuseumi	doc_213943984926_item	2269653	et	4	main
esindaja	doc_213943984926_item	2269654	et	4	main
filosoofia	doc_213943984926_item	2269655	et	4	main
korraldatakse	doc_213943984926_item	2269662	et	3	main
kohtla	doc_213943984926_item	2269663	et	4	main
järve	doc_213943984926_item	2269664	et	4	main
õpilastele	doc_213943984926_item	2269665	et	4	main
ja	doc_213943984926_item	2269666	et	3	main
üliõpilastele	doc_213943984926_item	2269667	et	4	main
reisi	doc_213943984926_item	2269668	et	4	main
kaasatakse	doc_213943984926_item	2269676	et	4	main
järve	doc_213943984926_item	2269689	et	4	main
muuseumi	doc_213943984926_item	2269697	et	4	main
muusemi	doc_213943984926_item	2269703	et	4	main
juhtkond	doc_213943984926_item	2269704	et	3	main
struktuuri	doc_213943984926_item	2269706	et	4	main
virtuaalne	doc_213943984926_item	2269709	et	3	main
arendada	doc_213943984926_item	2269712	et	3	main
vahelist	doc_213943984926_item	2269714	et	4	main
noorte	doc_213943984926_item	2269716	et	3	main
samuti	doc_213943984926_item	2269719	et	3	main
loomist	doc_213943984926_item	2269723	et	4	main
sankt-peterburi	doc_213943984926_item	2269724	et	4	main
muuseumi	doc_213943984926_item	2269738	et	4	main
tahaksid	doc_213943984926_item	2269749	et	4	main
kultuuri	doc_213943984926_item	2269753	et	4	main
alal	doc_213943984926_item	2269754	et	4	main
nad	doc_213943984926_item	2269755	et	3	main
läbivad	doc_213943984926_item	2269756	et	4	main
neli	doc_213943984926_item	2269757	et	3	main
kursust	doc_213943984926_item	2269759	et	3	main
venemaal	doc_213943984926_item	2269763	et	4	main
peale	doc_213943984926_item	2269777	et	4	main
viivad	doc_213943984926_item	2269779	et	4	main
kolm	doc_213943984926_item	2269784	et	3	main
aastal	doc_213943984927_item	2269827	et	3	main
minu	doc_213943984927_item	2269829	et	3	main
ja	doc_213943984927_item	2269839	et	3	main
kooli	doc_213943984927_item	2269841	et	4	main
kooli	doc_213943984927_item	2269851	et	4	main
ülikooli	doc_213943984927_item	2269869	et	4	main
ma	doc_213943984927_item	2269872	et	3	main
vana	doc_213943984927_item	2269876	et	4	main
minu	doc_213943984927_item	2269878	et	3	main
kukkus	doc_213943984927_item	2269882	et	3	main
ole	doc_213943984927_item	2269891	et	4	main
minu	doc_213943984927_item	2269901	et	3	main
õppida	doc_213943984927_item	2269907	et	3	main
pean	doc_213943984927_item	2269909	et	4	main
mida	doc_213943984927_item	2269911	et	4	main
vanemad	doc_213943984927_item	2269912	et	4	main
halb	doc_213943984927_item	2269916	et	3	main
sündmus	doc_213943984927_item	2269917	et	3	main
ma	doc_213943984927_item	2269921	et	3	main
üks	doc_213943984927_item	2269927	et	3	main
käe	doc_213943984927_item	2269931	et	3	main
peale	doc_213943984927_item	2269933	et	4	main
pärast	doc_213943984927_item	2269937	et	4	main
kui	doc_213943984927_item	2269944	et	3	main
aja	doc_213943984927_item	2269955	et	4	main
andestasin	doc_213943984927_item	2269958	et	3	main
ma	doc_213943984927_item	2269981	et	3	main
see	doc_213943984927_item	2269990	et	3	main
oli	doc_213943984927_item	2269991	et	3	main
minu	doc_213943984927_item	2269994	et	3	main
sest	doc_213943984927_item	2269996	et	4	main
seal	doc_213943984927_item	2269997	et	4	main
ma	doc_213943984927_item	2269998	et	3	main
tutvusin	doc_213943984927_item	2269999	et	3	main
sinna	doc_213943984927_item	2270010	et	3	main
ühes	doc_213943984927_item	2270021	et	4	main
firmas	doc_213943984927_item	2270023	et	3	main
ja	doc_213943984927_item	2270024	et	3	main
see	doc_213943984927_item	2270028	et	3	main
teine	doc_213943984927_item	2270030	et	3	main
elus	doc_213943984927_item	2270034	et	4	main
selle	doc_213943984927_item	2270035	et	4	main
ma	doc_213943984927_item	2270037	et	3	main
arendasin	doc_213943984927_item	2270038	et	3	main
seal	doc_213943984927_item	2270039	et	4	main
asju	doc_213943984928_item	2270055	et	3	main
elus	doc_213943984928_item	2270064	et	4	main
ka	doc_213943984928_item	2270067	et	3	main
toimuvad	doc_213943984928_item	2270068	et	4	main
euroopa	doc_213943984928_item	2270100	et	4	main
ei	doc_213943984928_item	2270111	et	4	main
saanud	doc_213943984928_item	2270112	et	4	main
väga	doc_213943984928_item	2270119	et	3	main
sisseastumiseksamid	doc_213943984928_item	2270141	et	3	main
ja	doc_213943984928_item	2270144	et	3	main
sooritasin	doc_213943984928_item	2270155	et	3	main
on	doc_213943984928_item	2270164	et	4	main
projekt	doc_213943984926_item	2269692	et	3	main
tugineb	doc_213943984926_item	2269693	et	3	main
ka	doc_213943984926_item	2269708	et	3	main
kaasnemise	doc_213943984926_item	2269717	et	4	main
plaanitakse	doc_213943984926_item	2269720	et	4	main
kultuurse	doc_213943984926_item	2269725	et	3	main
olemus	doc_213943984926_item	2269729	et	3	main
selles	doc_213943984926_item	2269731	et	4	main
et	doc_213943984926_item	2269732	et	3	main
kahe	doc_213943984926_item	2269733	et	3	main
aasta	doc_213943984926_item	2269734	et	4	main
analüüsitakse	doc_213943984926_item	2269736	et	4	main
virtuaalne	doc_213943984926_item	2269739	et	3	main
välja	doc_213943984926_item	2269742	et	4	main
eesti	doc_213943984926_item	2269745	et	4	main
üliõpilastest	doc_213943984926_item	2269746	et	4	main
väljaõpe	doc_213943984926_item	2269758	et	3	main
eestis	doc_213943984926_item	2269761	et	3	main
alustavad	doc_213943984926_item	2269766	et	4	main
järve	doc_213943984926_item	2269774	et	4	main
muuseumi	doc_213943984926_item	2269781	et	4	main
ma	doc_213943984927_item	2269822	et	3	main
tallinnas	doc_213943984927_item	2269828	et	4	main
perekond	doc_213943984927_item	2269830	et	3	main
elab	doc_213943984927_item	2269831	et	3	main
juba	doc_213943984927_item	2269833	et	3	main
seal	doc_213943984927_item	2269836	et	4	main
ma	doc_213943984927_item	2269837	et	3	main
kasvasin	doc_213943984927_item	2269838	et	3	main
kolm	doc_213943984927_item	2269844	et	3	main
kooli	doc_213943984927_item	2269847	et	4	main
ma	doc_213943984927_item	2269849	et	3	main
sisse	doc_213943984927_item	2269870	et	4	main
kui	doc_213943984927_item	2269871	et	3	main
6	doc_213943984927_item	2269874	et	2	main
peal	doc_213943984927_item	2269894	et	4	main
küüst	doc_213943984927_item	2269895	et	3	main
kõige	doc_213943984927_item	2269898	et	4	main
sellest	doc_213943984927_item	2269906	et	4	main
teha	doc_213943984927_item	2269914	et	3	main
teine	doc_213943984927_item	2269915	et	3	main
oli	doc_213943984927_item	2269918	et	3	main
turismimarsruuti	doc_213943984926_item	2269722	et	4	main
projekti	doc_213943984926_item	2269728	et	4	main
seisneb	doc_213943984926_item	2269730	et	3	main
jooksul	doc_213943984926_item	2269735	et	4	main
ja	doc_213943984926_item	2269744	et	3	main
oma	doc_213943984926_item	2269750	et	4	main
kaks	doc_213943984926_item	2269760	et	3	main
programmide	doc_213943984926_item	2269768	et	3	main
kasutatakse	doc_213943984926_item	2269771	et	3	main
seda	doc_213943984926_item	2269772	et	3	main
virtuaalses	doc_213943984926_item	2269775	et	3	main
vene	doc_213943984926_item	2269780	et	4	main
seminari	doc_213943984926_item	2269785	et	4	main
doktor	doc_213943984926_item	2269786	et	3	main
boiko	doc_213943984926_item	2269787	et	4	main
on	doc_213943984926_item	2269788	et	4	main
juba	doc_213943984926_item	2269789	et	3	main
lugenud	doc_213943984926_item	2269790	et	4	main
ühe	doc_213943984926_item	2269791	et	4	main
kursuse	doc_213943984926_item	2269792	et	3	main
2006	doc_213943984926_item	2269793	et	2	main
novembris	doc_213943984926_item	2269795	et	3	main
kohtla	doc_213943984926_item	2269796	et	4	main
järvel	doc_213943984926_item	2269797	et	4	main
ning	doc_213943984926_item	2269798	et	3	main
aasta	doc_213943984926_item	2269794	et	4	main
see	doc_213943984926_item	2269799	et	3	main
tekitas	doc_213943984926_item	2269800	et	3	main
kuulajates	doc_213943984926_item	2269801	et	4	main
suurt	doc_213943984926_item	2269802	et	3	main
huvi	doc_213943984926_item	2269803	et	4	main
gümnaasiumiõpilased	doc_213943984926_item	2269804	et	3	main
võtavad	doc_213943984926_item	2269805	et	3	main
osa	doc_213943984926_item	2269806	et	4	main
olümpiaadis	doc_213943984926_item	2269807	et	3	main
samuti	doc_213943984926_item	2269808	et	3	main
avaneb	doc_213943984926_item	2269809	et	3	main
võimalus	doc_213943984926_item	2269810	et	3	main
sankt-peterburi	doc_213943984926_item	2269811	et	4	main
külastamiseks	doc_213943984926_item	2269812	et	4	main
kultuuripärandi	doc_213943984926_item	2269813	et	3	main
tutvumise	doc_213943984926_item	2269814	et	4	main
eesmärgil	doc_213943984926_item	2269815	et	3	main
jutustas	doc_213943984926_item	2269816	et	3	main
projekti	doc_213943984926_item	2269817	et	4	main
minema	doc_213943984927_item	2269842	et	3	main
vahetasin	doc_213943984927_item	2269850	et	3	main
õpima	doc_213943984927_item	2269854	et	4	main
tallinna	doc_213943984927_item	2269855	et	4	main
juudi	doc_213943984927_item	2269856	et	3	main
koolis	doc_213943984927_item	2269857	et	4	main
mille	doc_213943984927_item	2269858	et	3	main
ma	doc_213943984927_item	2269859	et	3	main
lõpetasin	doc_213943984927_item	2269860	et	3	main
eelmisel	doc_213943984927_item	2269861	et	3	main
aastal	doc_213943984927_item	2269862	et	3	main
eelmisel	doc_213943984927_item	2269863	et	3	main
suvel	doc_213943984927_item	2269864	et	3	main
ma	doc_213943984927_item	2269865	et	3	main
astusin	doc_213943984927_item	2269866	et	3	main
tallinna	doc_213943984927_item	2269867	et	4	main
sündisin	doc_213943984927_item	2269823	et	3	main
1985	doc_213943984927_item	2269826	et	2	main
aastat	doc_213943984927_item	2269845	et	3	main
pärast	doc_213943984927_item	2269846	et	4	main
astumist	doc_213943984927_item	2269848	et	4	main
ja	doc_213943984927_item	2269852	et	3	main
sõrmu	doc_213943984927_item	2269880	et	4	main
ja	doc_213943984927_item	2269885	et	3	main
selle	doc_213943984927_item	2269886	et	4	main
ei	doc_213943984927_item	2269890	et	4	main
selle	doc_213943984927_item	2269892	et	4	main
sõrmu	doc_213943984927_item	2269893	et	4	main
oli	doc_213943984927_item	2269897	et	3	main
aga	doc_213943984927_item	2269903	et	3	main
sain	doc_213943984927_item	2269905	et	3	main
ütlevad	doc_213943984927_item	2269913	et	4	main
pois	doc_213943984927_item	2269928	et	3	main
seda	doc_213943984927_item	2269938	et	3	main
ma	doc_213943984927_item	2269940	et	3	main
käede	doc_213943984927_item	2269949	et	4	main
aga	doc_213943984927_item	2269953	et	3	main
poisi	doc_213943984927_item	2269960	et	3	main
purjetasin	doc_213943984927_item	2269982	et	3	main
igal	doc_213943984927_item	2269986	et	3	main
naudingu	doc_213943984927_item	2269988	et	3	main
aega	doc_213943984927_item	2270008	et	4	main
tegelema	doc_213943984927_item	2270015	et	3	main
jala	doc_213943984927_item	2269879	et	4	main
peale	doc_213943984927_item	2269881	et	4	main
kamiini	doc_213943984927_item	2269883	et	4	main
katus	doc_213943984927_item	2269884	et	4	main
pärast	doc_213943984927_item	2269887	et	4	main
praegu	doc_213943984927_item	2269889	et	3	main
see	doc_213943984927_item	2269896	et	3	main
halvem	doc_213943984927_item	2269899	et	4	main
elus	doc_213943984927_item	2269902	et	4	main
et	doc_213943984927_item	2269908	et	3	main
kuulama	doc_213943984927_item	2269910	et	3	main
kui	doc_213943984927_item	2269920	et	3	main
õpisin	doc_213943984927_item	2269922	et	4	main
klassil	doc_213943984927_item	2269924	et	3	main
sõrme	doc_213943984927_item	2269932	et	4	main
ja	doc_213943984927_item	2269934	et	3	main
seda	doc_213943984927_item	2269936	et	3	main
hakkasin	doc_213943984927_item	2269941	et	3	main
hirmu	doc_213943984927_item	2269943	et	4	main
midagi	doc_213943984927_item	2269945	et	4	main
minu	doc_213943984927_item	2269948	et	3	main
mõne	doc_213943984927_item	2269954	et	3	main
ma	doc_213943984927_item	2269957	et	3	main
seda	doc_213943984927_item	2269959	et	3	main
kui	doc_213943984927_item	2269980	et	3	main
mul	doc_213943984927_item	2269984	et	3	main
õnnelikum	doc_213943984927_item	2269992	et	4	main
elus	doc_213943984927_item	2269995	et	4	main
uute	doc_213943984927_item	2270001	et	3	main
ja	doc_213943984927_item	2270012	et	3	main
ma	doc_213943984927_item	2270013	et	3	main
purjetamisega	doc_213943984927_item	2270016	et	4	main
ma	doc_213943984927_item	2270019	et	3	main
oli	doc_213943984927_item	2270029	et	3	main
inimestega	doc_213943984927_item	2270042	et	3	main
meie	doc_213943984928_item	2270058	et	4	main
ja	doc_213943984928_item	2270061	et	3	main
nad	doc_213943984928_item	2270066	et	3	main
mina	doc_213943984928_item	2270072	et	4	main
reisisime	doc_213943984928_item	2270075	et	3	main
riigid	doc_213943984928_item	2270101	et	3	main
ole	doc_213943984928_item	2270105	et	4	main
nii	doc_213943984928_item	2270107	et	3	main
astuda	doc_213943984928_item	2270113	et	3	main
tasuta	doc_213943984928_item	2270114	et	4	main
ülikooli	doc_213943984928_item	2270115	et	4	main
õppima	doc_213943984928_item	2270116	et	3	main
sest	doc_213943984928_item	2270121	et	4	main
oli	doc_213943984928_item	2270123	et	3	main
raamastusin	doc_213943984928_item	2270127	et	3	main
perekonnaga	doc_213943984928_item	2270133	et	4	main
meie	doc_213943984928_item	2270134	et	4	main
sugulastele	doc_213943984928_item	2270135	et	4	main
tollal	doc_213943984928_item	2270138	et	3	main
oli	doc_213943984928_item	2270140	et	3	main
oli	doc_213943984928_item	2270146	et	3	main
väga	doc_213943984928_item	2270149	et	3	main
sain	doc_213943984928_item	2270152	et	3	main
ei	doc_213943984928_item	2270166	et	4	main
unustasin	doc_213943984929_item	2270190	et	3	main
üks	doc_213943984929_item	2270194	et	3	main
isa	doc_213943984929_item	2270197	et	4	main
et	doc_213943984929_item	2270199	et	3	main
tallinna	doc_213943984929_item	2270202	et	4	main
tööd	doc_213943984929_item	2270209	et	4	main
see	doc_213943984929_item	2270210	et	3	main
tore	doc_213943984929_item	2270215	et	3	main
me	doc_213943984929_item	2270219	et	4	main
narvas	doc_213943984929_item	2270221	et	4	main
mina	doc_213943984929_item	2270223	et	4	main
olin	doc_213943984929_item	2270224	et	3	main
pärast	doc_213943984929_item	2270226	et	4	main
koolis	doc_213943984929_item	2270228	et	4	main
mul	doc_213943984929_item	2270229	et	3	main
oli	doc_213943984929_item	2270235	et	3	main
olime	doc_213943984929_item	2270241	et	3	main
koos	doc_213943984929_item	2270248	et	4	main
et	doc_213943984929_item	2270258	et	3	main
teda	doc_213943984929_item	2270283	et	4	main
ei	doc_213943984929_item	2270286	et	4	main
näe	doc_213943984929_item	2270287	et	4	main
kohtasin	doc_213943984929_item	2270291	et	3	main
keskkooli	doc_213943984929_item	2270300	et	4	main
sündmust	doc_213943984927_item	2269939	et	3	main
tundma	doc_213943984927_item	2269942	et	3	main
või	doc_213943984927_item	2269950	et	4	main
peale	doc_213943984927_item	2269952	et	4	main
pärast	doc_213943984927_item	2269956	et	4	main
kui	doc_213943984927_item	2269961	et	3	main
ma	doc_213943984927_item	2269962	et	3	main
olin	doc_213943984927_item	2269963	et	3	main
umbes	doc_213943984927_item	2269964	et	4	main
neliteist	doc_213943984927_item	2269965	et	4	main
aastat	doc_213943984927_item	2269966	et	3	main
vana	doc_213943984927_item	2269967	et	4	main
ma	doc_213943984927_item	2269968	et	3	main
hakkasin	doc_213943984927_item	2269969	et	3	main
balt	doc_213943984927_item	2269970	et	4	main
saili	doc_213943984927_item	2269971	et	4	main
purjetamise	doc_213943984927_item	2269972	et	4	main
kluubis	doc_213943984927_item	2269973	et	4	main
mina	doc_213943984927_item	2269975	et	4	main
käima	doc_213943984927_item	2269974	et	4	main
lapsepõlvest	doc_213943984927_item	2269976	et	4	main
armastan	doc_213943984927_item	2269977	et	3	main
neljandal	doc_213943984927_item	2269923	et	3	main
kehalisekasvatuse	doc_213943984927_item	2269925	et	4	main
tunnis	doc_213943984927_item	2269926	et	3	main
astus	doc_213943984927_item	2269929	et	3	main
minu	doc_213943984927_item	2269930	et	3	main
lõhkus	doc_213943984927_item	2269935	et	3	main
hakkas	doc_213943984927_item	2269946	et	3	main
kukkuma	doc_213943984927_item	2269947	et	3	main
jalade	doc_213943984927_item	2269951	et	4	main
ja	doc_213943984927_item	2269979	et	3	main
korral	doc_213943984927_item	2269987	et	4	main
aeg	doc_213943984927_item	2269993	et	3	main
sõpradega	doc_213943984927_item	2270002	et	3	main
kahjuks	doc_213943984927_item	2270004	et	4	main
mul	doc_213943984927_item	2270005	et	3	main
ei	doc_213943984927_item	2270006	et	4	main
olnud	doc_213943984927_item	2270007	et	4	main
minna	doc_213943984927_item	2270011	et	3	main
lõpetasin	doc_213943984927_item	2270014	et	3	main
suvel	doc_213943984927_item	2270018	et	3	main
et	doc_213943984927_item	2270027	et	3	main
pärast	doc_213943984927_item	2270036	et	4	main
teada	doc_213943984927_item	2270045	et	3	main
hästi	doc_213943984928_item	2270060	et	3	main
mulle	doc_213943984928_item	2270070	et	4	main
klassikaaslastega	doc_213943984928_item	2270074	et	4	main
meil	doc_213943984928_item	2270098	et	4	main
ei	doc_213943984928_item	2270104	et	4	main
kõik	doc_213943984928_item	2270106	et	4	main
näiteks	doc_213943984928_item	2270109	et	4	main
mina	doc_213943984928_item	2270110	et	4	main
merd	doc_213943984927_item	2269978	et	3	main
siis	doc_213943984927_item	2269983	et	3	main
tekkis	doc_213943984927_item	2269985	et	3	main
tunne	doc_213943984927_item	2269989	et	4	main
palju	doc_213943984927_item	2270000	et	4	main
aga	doc_213943984927_item	2270003	et	3	main
tihti	doc_213943984927_item	2270009	et	3	main
esimesel	doc_213943984927_item	2270017	et	3	main
töötasin	doc_213943984927_item	2270020	et	3	main
arvan	doc_213943984927_item	2270026	et	3	main
hea	doc_213943984927_item	2270031	et	4	main
minu	doc_213943984927_item	2270033	et	3	main
oma	doc_213943984927_item	2270040	et	4	main
sain	doc_213943984927_item	2270044	et	3	main
palju	doc_213943984927_item	2270046	et	4	main
inimesi	doc_213943984927_item	2270048	et	4	main
igasuguseid	doc_213943984928_item	2270054	et	3	main
nad	doc_213943984928_item	2270056	et	3	main
minu	doc_213943984928_item	2270063	et	3	main
muidugi	doc_213943984928_item	2270065	et	4	main
mullu	doc_213943984928_item	2270069	et	3	main
mõnikord	doc_213943984928_item	2270103	et	3	main
mul	doc_213943984928_item	2270117	et	3	main
solvavalt	doc_213943984928_item	2270120	et	4	main
mull	doc_213943984928_item	2270122	et	3	main
pall	doc_213943984928_item	2270125	et	3	main
sest	doc_213943984928_item	2270137	et	4	main
emal	doc_213943984928_item	2270143	et	3	main
hiljuti	doc_213943984928_item	2270148	et	4	main
rõõmustasin	doc_213943984928_item	2270150	et	3	main
et	doc_213943984928_item	2270151	et	3	main
stipendiumi	doc_213943984928_item	2270153	et	4	main
sest	doc_213943984928_item	2270154	et	4	main
et	doc_213943984928_item	2270161	et	3	main
saa	doc_213943984928_item	2270167	et	4	main
suuremas	doc_213943984929_item	2270191	et	4	main
kord	doc_213943984929_item	2270195	et	4	main
rohkem	doc_213943984929_item	2270208	et	4	main
otsustus	doc_213943984929_item	2270216	et	4	main
lõppuks	doc_213943984929_item	2270218	et	3	main
turismi	doc_213943984927_item	2270022	et	4	main
ma	doc_213943984927_item	2270025	et	3	main
sündmus	doc_213943984927_item	2270032	et	3	main
suhtlemisoskust	doc_213943984927_item	2270041	et	3	main
ja	doc_213943984927_item	2270043	et	3	main
uusi	doc_213943984927_item	2270047	et	3	main
essee	doc_213943984928_item	2270049	et	4	main
kõikidel	doc_213943984928_item	2270050	et	4	main
inimestel	doc_213943984928_item	2270051	et	3	main
elus	doc_213943984928_item	2270052	et	4	main
juhtuvad	doc_213943984928_item	2270053	et	4	main
mõjuvad	doc_213943984928_item	2270057	et	4	main
ulule	doc_213943984928_item	2270059	et	3	main
halvasti	doc_213943984928_item	2270062	et	3	main
vedus	doc_213943984928_item	2270071	et	3	main
oma	doc_213943984928_item	2270073	et	4	main
euroopas	doc_213943984928_item	2270076	et	3	main
see	doc_213943984928_item	2270077	et	3	main
oli	doc_213943984928_item	2270078	et	3	main
suurepärane	doc_213943984928_item	2270079	et	4	main
reisi	doc_213943984928_item	2270080	et	4	main
hind	doc_213943984928_item	2270081	et	3	main
oli	doc_213943984928_item	2270082	et	3	main
ainult	doc_213943984928_item	2270083	et	4	main
üks	doc_213943984928_item	2270084	et	3	main
tuhat	doc_213943984928_item	2270085	et	4	main
krooni	doc_213943984928_item	2270086	et	4	main
sest	doc_213943984928_item	2270087	et	4	main
üks	doc_213943984928_item	2270088	et	3	main
poiss	doc_213943984928_item	2270089	et	3	main
meie	doc_213943984928_item	2270090	et	4	main
klassis	doc_213943984928_item	2270091	et	3	main
võitis	doc_213943984928_item	2270092	et	3	main
mängus	doc_213943984928_item	2270093	et	3	main
ja	doc_213943984928_item	2270094	et	3	main
euroopa	doc_213943984928_item	2270095	et	4	main
liit	doc_213943984928_item	2270096	et	3	main
aitas	doc_213943984928_item	2270097	et	3	main
näha	doc_213943984928_item	2270099	et	3	main
paraku	doc_213943984928_item	2270102	et	3	main
hästi	doc_213943984928_item	2270108	et	3	main
oli	doc_213943984928_item	2270118	et	3	main
veenemaale	doc_213943984928_item	2270136	et	4	main
mull	doc_213943984928_item	2270139	et	3	main
isal	doc_213943984928_item	2270145	et	3	main
puhkus	doc_213943984928_item	2270147	et	3	main
arvan	doc_213943984928_item	2270160	et	3	main
triibuline	doc_213943984928_item	2270165	et	4	main
kõik	doc_213943984928_item	2270169	et	4	main
ütles	doc_213943984929_item	2270198	et	3	main
oleks	doc_213943984929_item	2270205	et	3	main
nii	doc_213943984929_item	2270214	et	3	main
jäime	doc_213943984929_item	2270220	et	3	main
ja	doc_213943984929_item	2270222	et	3	main
sõpru	doc_213943984929_item	2270233	et	3	main
väga	doc_213943984929_item	2270237	et	3	main
sõbranna	doc_213943984929_item	2270239	et	4	main
me	doc_213943984929_item	2270240	et	4	main
sõbranna	doc_213943984929_item	2270255	et	4	main
ja	doc_213943984929_item	2270261	et	3	main
et	doc_213943984929_item	2270281	et	3	main
aga	doc_213943984929_item	2270288	et	3	main
hiljem	doc_213943984929_item	2270289	et	3	main
uusi	doc_213943984929_item	2270292	et	3	main
hästi	doc_213943984929_item	2270301	et	3	main
ja	doc_213943984929_item	2270302	et	3	main
ülikooli	doc_213943984929_item	2270304	et	4	main
aastal	doc_213943984929_item	2270309	et	3	main
usunud	doc_213943984929_item	2270316	et	4	main
see	doc_213943984929_item	2270319	et	3	main
siin	doc_213943984929_item	2270331	et	4	main
konkurssi	doc_213943984929_item	2270335	et	4	main
sellepärast	doc_213943984929_item	2270337	et	3	main
ma	doc_213943984929_item	2270351	et	3	main
tahtnud	doc_213943984929_item	2270353	et	4	main
et	doc_213943984929_item	2270360	et	3	main
ei	doc_213943984929_item	2270361	et	4	main
teised	doc_213943984929_item	2270365	et	4	main
aga	doc_213943984929_item	2270371	et	3	main
ei	doc_213943984929_item	2270372	et	4	main
kahjuks	doc_213943984929_item	2270374	et	4	main
asjad	doc_213943984929_item	2270375	et	3	main
nii	doc_213943984929_item	2270376	et	3	main
lihtsad	doc_213943984929_item	2270377	et	3	main
kui	doc_213943984929_item	2270378	et	3	main
mõtlema	doc_213943984929_item	2270381	et	3	main
pärast	doc_213943984929_item	2270383	et	4	main
kooli	doc_213943984929_item	2270384	et	4	main
minna	doc_213943984929_item	2270385	et	3	main
tahtsin	doc_213943984929_item	2270386	et	3	main
ma	doc_213943984929_item	2270387	et	3	main
saksa	doc_213943984929_item	2270388	et	4	main
juba	doc_213943984929_item	2270397	et	3	main
võimalust	doc_213943984929_item	2270424	et	3	main
saksa	doc_213943984929_item	2270425	et	4	main
rõõmu	doc_213943984929_item	2270435	et	4	main
õnnetusi	doc_213943984929_item	2270437	et	4	main
teha	doc_213943984929_item	2270444	et	3	main
minu	doc_213943984930_item	2270446	et	3	main
minu	doc_213943984930_item	2270448	et	3	main
aastat	doc_213943984930_item	2270452	et	3	main
väikeses	doc_213943984930_item	2270454	et	4	main
anti	doc_213943984930_item	2270464	et	3	main
et	doc_213943984930_item	2270483	et	3	main
elada	doc_213943984930_item	2270496	et	3	main
läks	doc_213943984930_item	2270500	et	3	main
lasteaias	doc_213943984930_item	2270506	et	4	main
töötasid	doc_213943984930_item	2270508	et	4	main
esimesse	doc_213943984930_item	2270519	et	4	main
ma	doc_213943984930_item	2270521	et	3	main
rahulik	doc_213943984930_item	2270524	et	3	main
hoian	doc_213943984930_item	2270539	et	3	main
mu	doc_213943984930_item	2270544	et	3	main
soovitas	doc_213943984930_item	2270546	et	3	main
mu	doc_213943984930_item	2270582	et	3	main
kaheksa	doc_213943984930_item	2270584	et	4	main
aasta	doc_213943984930_item	2270585	et	4	main
ma	doc_213943984930_item	2270595	et	3	main
eest	doc_213943984930_item	2270599	et	4	main
hea	doc_213943984928_item	2270124	et	4	main
mina	doc_213943984928_item	2270126	et	4	main
kui	doc_213943984928_item	2270128	et	3	main
ei	doc_213943984928_item	2270129	et	4	main
saanud	doc_213943984928_item	2270130	et	4	main
sõita	doc_213943984928_item	2270131	et	3	main
oma	doc_213943984928_item	2270132	et	4	main
aga	doc_213943984928_item	2270142	et	3	main
kõik	doc_213943984928_item	2270156	et	4	main
eksamid	doc_213943984928_item	2270157	et	3	main
hästi	doc_213943984928_item	2270158	et	3	main
mina	doc_213943984928_item	2270159	et	4	main
meie	doc_213943984928_item	2270162	et	4	main
elu	doc_213943984928_item	2270163	et	4	main
olla	doc_213943984928_item	2270168	et	3	main
või	doc_213943984928_item	2270171	et	4	main
halvasti	doc_213943984928_item	2270172	et	3	main
alati	doc_213943984928_item	2270173	et	4	main
essee	doc_213943984929_item	2270174	et	4	main
ma	doc_213943984929_item	2270175	et	3	main
olen	doc_213943984929_item	2270176	et	3	main
tallinna	doc_213943984929_item	2270177	et	4	main
pedagoogikaülikooli	doc_213943984929_item	2270178	et	4	main
õpilane	doc_213943984929_item	2270179	et	3	main
aga	doc_213943984929_item	2270180	et	3	main
enne	doc_213943984929_item	2270181	et	4	main
elasin	doc_213943984929_item	2270182	et	3	main
ma	doc_213943984929_item	2270183	et	3	main
narvas	doc_213943984929_item	2270184	et	4	main
ja	doc_213943984929_item	2270185	et	3	main
nagu	doc_213943984929_item	2270186	et	3	main
kõik	doc_213943984929_item	2270187	et	4	main
noored	doc_213943984929_item	2270188	et	3	main
inimesed	doc_213943984929_item	2270189	et	3	main
hästi	doc_213943984928_item	2270170	et	3	main
elada	doc_213943984929_item	2270193	et	3	main
meil	doc_213943984929_item	2270200	et	4	main
tuleb	doc_213943984929_item	2270201	et	3	main
minna	doc_213943984929_item	2270203	et	3	main
sest	doc_213943984929_item	2270204	et	4	main
tal	doc_213943984929_item	2270206	et	3	main
aga	doc_213943984929_item	2270217	et	3	main
ei	doc_213943984929_item	2270230	et	4	main
palju	doc_213943984929_item	2270232	et	4	main
üks	doc_213943984929_item	2270236	et	3	main
koolis	doc_213943984929_item	2270242	et	4	main
koos	doc_213943984929_item	2270244	et	4	main
tegime	doc_213943984929_item	2270247	et	3	main
õpetajatest	doc_213943984929_item	2270249	et	4	main
minu	doc_213943984929_item	2270254	et	3	main
kadus	doc_213943984929_item	2270256	et	3	main
pole	doc_213943984929_item	2270259	et	3	main
ta	doc_213943984929_item	2270262	et	4	main
üldse	doc_213943984929_item	2270285	et	3	main
kõik	doc_213943984929_item	2270295	et	4	main
korraks	doc_213943984929_item	2270297	et	4	main
ma	doc_213943984929_item	2270298	et	3	main
astusin	doc_213943984929_item	2270307	et	3	main
esimesele	doc_213943984929_item	2270310	et	3	main
paljud	doc_213943984929_item	2270321	et	3	main
pole	doc_213943984929_item	2270330	et	3	main
suure	doc_213943984929_item	2270334	et	3	main
tohi	doc_213943984929_item	2270339	et	4	main
keelteõppimise	doc_213943984929_item	2270348	et	3	main
et	doc_213943984929_item	2270350	et	3	main
olen	doc_213943984929_item	2270358	et	3	main
rahul	doc_213943984929_item	2270359	et	4	main
mida	doc_213943984929_item	2270364	et	4	main
sain	doc_213943984929_item	2270368	et	3	main
olnud	doc_213943984929_item	2270373	et	4	main
ma	doc_213943984929_item	2270379	et	3	main
keele	doc_213943984929_item	2270395	et	4	main
linnas	doc_213943984929_item	2270192	et	4	main
minu	doc_213943984929_item	2270196	et	3	main
seal	doc_213943984929_item	2270207	et	4	main
oli	doc_213943984929_item	2270211	et	3	main
minu	doc_213943984929_item	2270212	et	3	main
jaoks	doc_213943984929_item	2270213	et	4	main
selle	doc_213943984929_item	2270225	et	4	main
kurb	doc_213943984929_item	2270227	et	3	main
olnud	doc_213943984929_item	2270231	et	4	main
hea	doc_213943984929_item	2270238	et	4	main
nalja	doc_213943984929_item	2270250	et	4	main
kuni	doc_213943984929_item	2270251	et	3	main
ühel	doc_213943984929_item	2270252	et	3	main
uusaastal	doc_213943984929_item	2270253	et	3	main
ma	doc_213943984929_item	2270282	et	3	main
ma	doc_213943984929_item	2270290	et	3	main
sõpru	doc_213943984929_item	2270293	et	3	main
otsustasin	doc_213943984929_item	2270303	et	3	main
eelmisel	doc_213943984929_item	2270308	et	3	main
et	doc_213943984929_item	2270317	et	3	main
mul	doc_213943984929_item	2270318	et	3	main
tutvused	doc_213943984929_item	2270323	et	3	main
et	doc_213943984929_item	2270325	et	3	main
inglise	doc_213943984929_item	2270326	et	4	main
õppekohta	doc_213943984929_item	2270328	et	4	main
saada	doc_213943984929_item	2270329	et	4	main
tugev	doc_213943984929_item	2270347	et	4	main
kuulnud	doc_213943984929_item	2270362	et	4	main
sest	doc_213943984929_item	2270367	et	4	main
filoloogiks	doc_213943984929_item	2270389	et	3	main
lapsepõlves	doc_213943984929_item	2270398	et	4	main
ma	doc_213943984929_item	2270428	et	3	main
veel	doc_213943984929_item	2270441	et	4	main
elu	doc_213943984930_item	2270449	et	4	main
narva	doc_213943984930_item	2270455	et	4	main
elasid	doc_213943984930_item	2270459	et	4	main
korteris	doc_213943984930_item	2270461	et	3	main
harjuda	doc_213943984930_item	2270487	et	3	main
vanaemaga	doc_213943984930_item	2270497	et	3	main
kõik	doc_213943984930_item	2270499	et	4	main
käisin	doc_213943984930_item	2270505	et	3	main
kodus	doc_213943984930_item	2270511	et	4	main
muutused	doc_213943984930_item	2270512	et	4	main
hakkasid	doc_213943984930_item	2270513	et	4	main
siis	doc_213943984930_item	2270515	et	3	main
ma	doc_213943984930_item	2270517	et	3	main
aga	doc_213943984929_item	2270234	et	3	main
alati	doc_213943984929_item	2270243	et	4	main
ja	doc_213943984929_item	2270245	et	3	main
tunnides	doc_213943984929_item	2270246	et	4	main
mõtlesin	doc_213943984929_item	2270257	et	3	main
viga	doc_213943984929_item	2270260	et	4	main
jäi	doc_213943984929_item	2270263	et	3	main
haigeks	doc_213943984929_item	2270264	et	4	main
aga	doc_213943984929_item	2270265	et	3	main
hiljem	doc_213943984929_item	2270266	et	3	main
sain	doc_213943984929_item	2270267	et	3	main
temast	doc_213943984929_item	2270268	et	3	main
kirja	doc_213943984929_item	2270269	et	4	main
et	doc_213943984929_item	2270270	et	3	main
ta	doc_213943984929_item	2270271	et	4	main
läks	doc_213943984929_item	2270272	et	3	main
inglismaale	doc_213943984929_item	2270273	et	4	main
sest	doc_213943984929_item	2270274	et	4	main
tema	doc_213943984929_item	2270275	et	4	main
vanemad	doc_213943984929_item	2270276	et	4	main
nii	doc_213943984929_item	2270277	et	3	main
otsustasid	doc_213943984929_item	2270278	et	4	main
mulle	doc_213943984929_item	2270279	et	4	main
tundus	doc_213943984929_item	2270280	et	3	main
rohkem	doc_213943984929_item	2270284	et	4	main
ja	doc_213943984929_item	2270294	et	3	main
sai	doc_213943984929_item	2270296	et	4	main
lõpetasin	doc_213943984929_item	2270299	et	3	main
ma	doc_213943984929_item	2270306	et	3	main
sisse	doc_213943984929_item	2270312	et	4	main
ei	doc_213943984929_item	2270315	et	4	main
õnnestub	doc_213943984929_item	2270320	et	3	main
ütlesid	doc_213943984929_item	2270324	et	4	main
võimalik	doc_213943984929_item	2270332	et	3	main
liiga	doc_213943984929_item	2270333	et	4	main
tõttu	doc_213943984929_item	2270336	et	4	main
mul	doc_213943984929_item	2270340	et	3	main
proovida	doc_213943984929_item	2270342	et	3	main
mul	doc_213943984929_item	2270344	et	3	main
nii	doc_213943984929_item	2270346	et	3	main
räägisid	doc_213943984929_item	2270366	et	4	main
kohe	doc_213943984929_item	2270369	et	4	main
tõttu	doc_213943984929_item	2270421	et	4	main
polnud	doc_213943984929_item	2270423	et	3	main
loodan	doc_213943984929_item	2270429	et	3	main
on	doc_213943984929_item	2270432	et	4	main
kui	doc_213943984929_item	2270436	et	3	main
sest	doc_213943984929_item	2270438	et	4	main
essee	doc_213943984930_item	2270445	et	4	main
elulugu	doc_213943984930_item	2270447	et	4	main
algas	doc_213943984930_item	2270450	et	3	main
minu	doc_213943984930_item	2270457	et	3	main
kuni	doc_213943984930_item	2270462	et	3	main
oli	doc_213943984930_item	2270485	et	3	main
eluga	doc_213943984930_item	2270489	et	3	main
niimoodi	doc_213943984930_item	2270492	et	3	main
vähem	doc_213943984930_item	2270502	et	4	main
ma	doc_213943984930_item	2270504	et	3	main
vanaema	doc_213943984930_item	2270509	et	4	main
istus	doc_213943984930_item	2270510	et	4	main
kui	doc_213943984930_item	2270516	et	3	main
vaikne	doc_213943984930_item	2270525	et	3	main
isegi	doc_213943984930_item	2270528	et	4	main
ma	doc_213943984930_item	2270532	et	3	main
uusi	doc_213943984930_item	2270535	et	3	main
ma	doc_213943984930_item	2270538	et	3	main
oma	doc_213943984930_item	2270540	et	4	main
muusikakooli	doc_213943984930_item	2270549	et	4	main
oli	doc_213943984930_item	2270555	et	3	main
kõikide	doc_213943984930_item	2270573	et	4	main
eriti	doc_213943984930_item	2270575	et	3	main
jaoks	doc_213943984930_item	2270583	et	4	main
paljudest	doc_213943984930_item	2270590	et	3	main
konkurssidest	doc_213943984930_item	2270591	et	3	main
auhinda	doc_213943984930_item	2270594	et	4	main
muutusin	doc_213943984930_item	2270606	et	3	main
kuigi	doc_213943984930_item	2270608	et	3	main
ja	doc_213943984930_item	2270623	et	3	main
nelja	doc_213943984930_item	2270624	et	4	main
arvates	doc_213943984930_item	2270630	et	4	main
aastat	doc_213943984930_item	2270637	et	3	main
parimad	doc_213943984930_item	2270640	et	4	main
ja	doc_213943984930_item	2270641	et	3	main
mulle	doc_213943984930_item	2270650	et	4	main
langused	doc_213943984930_item	2270654	et	3	main
saan	doc_213943984930_item	2270659	et	4	main
periood	doc_213943984930_item	2270665	et	3	main
tekkis	doc_213943984930_item	2270669	et	3	main
sõitsin	doc_213943984930_item	2270687	et	3	main
astusin	doc_213943984930_item	2270691	et	3	main
mul	doc_213943984930_item	2270695	et	3	main
te	doc_213943984930_item	2270730	et	4	main
eksite	doc_213943984930_item	2270731	et	3	main
elu	doc_213943984930_item	2270733	et	4	main
ja	doc_213943984930_item	2270738	et	3	main
joontest	doc_213943984930_item	2270748	et	3	main
alati	doc_213943984930_item	2270761	et	4	main
olukorrast	doc_213943984930_item	2270764	et	4	main
tallinna	doc_213943984931_item	2270782	et	4	main
ajal	doc_213943984931_item	2270788	et	4	main
viiuli	doc_213943984931_item	2270790	et	3	main
ole	doc_213943984931_item	2270793	et	4	main
lõbus	doc_213943984931_item	2270813	et	4	main
huvitav	doc_213943984931_item	2270815	et	4	main
minna	doc_213943984929_item	2270305	et	3	main
kursusele	doc_213943984929_item	2270311	et	3	main
aga	doc_213943984929_item	2270313	et	3	main
ise	doc_213943984929_item	2270314	et	4	main
mu	doc_213943984929_item	2270322	et	3	main
filoloogias	doc_213943984929_item	2270327	et	3	main
ei	doc_213943984929_item	2270338	et	4	main
isegi	doc_213943984929_item	2270341	et	4	main
aga	doc_213943984929_item	2270343	et	3	main
oli	doc_213943984929_item	2270345	et	3	main
soov	doc_213943984929_item	2270349	et	3	main
ei	doc_213943984929_item	2270352	et	4	main
sellest	doc_213943984929_item	2270354	et	4	main
loobuda	doc_213943984929_item	2270355	et	3	main
nüüd	doc_213943984929_item	2270356	et	4	main
ma	doc_213943984929_item	2270357	et	3	main
palju	doc_213943984929_item	2270363	et	4	main
sisse	doc_213943984929_item	2270370	et	4	main
hakkasin	doc_213943984929_item	2270380	et	3	main
kuhu	doc_213943984929_item	2270382	et	3	main
saada	doc_213943984929_item	2270390	et	4	main
ma	doc_213943984929_item	2270391	et	3	main
tundsin	doc_213943984929_item	2270392	et	3	main
huvi	doc_213943984929_item	2270393	et	4	main
saksa	doc_213943984929_item	2270394	et	4	main
vastu	doc_213943984929_item	2270396	et	3	main
ja	doc_213943984929_item	2270399	et	3	main
olen	doc_213943984929_item	2270400	et	3	main
natuke	doc_213943984929_item	2270401	et	4	main
iseseisvalt	doc_213943984929_item	2270402	et	4	main
saksa	doc_213943984929_item	2270403	et	4	main
keelt	doc_213943984929_item	2270404	et	4	main
õppinud	doc_213943984929_item	2270405	et	4	main
aga	doc_213943984929_item	2270406	et	3	main
koolis	doc_213943984929_item	2270407	et	4	main
õppisin	doc_213943984929_item	2270408	et	3	main
ma	doc_213943984929_item	2270409	et	3	main
inglise	doc_213943984929_item	2270410	et	4	main
keelt	doc_213943984929_item	2270411	et	4	main
ning	doc_213943984929_item	2270412	et	3	main
saksa	doc_213943984929_item	2270413	et	4	main
keeles	doc_213943984929_item	2270414	et	4	main
ei	doc_213943984929_item	2270415	et	4	main
olnud	doc_213943984929_item	2270416	et	4	main
mul	doc_213943984929_item	2270417	et	3	main
riigieksam	doc_213943984929_item	2270418	et	3	main
sooritatud	doc_213943984929_item	2270419	et	4	main
see	doc_213943984929_item	2270420	et	3	main
mul	doc_213943984929_item	2270422	et	3	main
filoloogiks	doc_213943984929_item	2270426	et	3	main
kandideerida	doc_213943984929_item	2270427	et	3	main
et	doc_213943984929_item	2270430	et	3	main
elus	doc_213943984929_item	2270433	et	4	main
ma	doc_213943984929_item	2270439	et	3	main
kavatsen	doc_213943984929_item	2270440	et	3	main
palju	doc_213943984929_item	2270442	et	4	main
vanemad	doc_213943984930_item	2270458	et	4	main
mul	doc_213943984930_item	2270484	et	3	main
juhtus	doc_213943984930_item	2270491	et	3	main
meil	doc_213943984930_item	2270494	et	4	main
aga	doc_213943984930_item	2270498	et	3	main
hästi	doc_213943984930_item	2270503	et	3	main
tekkima	doc_213943984930_item	2270514	et	3	main
läksin	doc_213943984930_item	2270518	et	3	main
mul	doc_213943984929_item	2270431	et	3	main
rohkem	doc_213943984929_item	2270434	et	4	main
asju	doc_213943984929_item	2270443	et	3	main
20	doc_213943984930_item	2270451	et	2	main
tagasi	doc_213943984930_item	2270453	et	3	main
linnas	doc_213943984930_item	2270456	et	4	main
ühetoalises	doc_213943984930_item	2270460	et	4	main
neile	doc_213943984930_item	2270463	et	4	main
kolmetoalise	doc_213943984930_item	2270465	et	4	main
uue	doc_213943984930_item	2270466	et	3	main
korteri	doc_213943984930_item	2270467	et	3	main
ja	doc_213943984930_item	2270468	et	3	main
me	doc_213943984930_item	2270469	et	4	main
kolisime	doc_213943984930_item	2270470	et	3	main
muidugi	doc_213943984930_item	2270471	et	4	main
mina	doc_213943984930_item	2270472	et	4	main
ei	doc_213943984930_item	2270473	et	4	main
mäleta	doc_213943984930_item	2270474	et	4	main
mitte	doc_213943984930_item	2270475	et	3	main
midagi	doc_213943984930_item	2270476	et	4	main
sellest	doc_213943984930_item	2270477	et	4	main
perioodist	doc_213943984930_item	2270478	et	3	main
aga	doc_213943984930_item	2270479	et	3	main
ema	doc_213943984930_item	2270480	et	4	main
tihti	doc_213943984930_item	2270481	et	3	main
jutustab	doc_213943984930_item	2270482	et	3	main
raske	doc_213943984930_item	2270486	et	4	main
uue	doc_213943984930_item	2270488	et	3	main
lisaks	doc_213943984930_item	2270490	et	4	main
et	doc_213943984930_item	2270493	et	3	main
tuleb	doc_213943984930_item	2270495	et	3	main
enam	doc_213943984930_item	2270501	et	4	main
vanemad	doc_213943984930_item	2270507	et	4	main
klassi	doc_213943984930_item	2270520	et	4	main
olin	doc_213943984930_item	2270522	et	3	main
ja	doc_213943984930_item	2270526	et	3	main
laps	doc_213943984930_item	2270530	et	4	main
leidsin	doc_213943984930_item	2270533	et	3	main
kiiresti	doc_213943984930_item	2270534	et	3	main
sõpru	doc_213943984930_item	2270536	et	3	main
proovisin	doc_213943984930_item	2270551	et	3	main
väga	doc_213943984930_item	2270556	et	3	main
keelt	doc_213943984930_item	2270572	et	4	main
klaveriõpetajaga	doc_213943984930_item	2270577	et	3	main
sai	doc_213943984930_item	2270579	et	4	main
emaks	doc_213943984930_item	2270581	et	3	main
ma	doc_213943984930_item	2270587	et	3	main
selle	doc_213943984930_item	2270598	et	4	main
et	doc_213943984930_item	2270600	et	3	main
mulle	doc_213943984930_item	2270603	et	4	main
ma	doc_213943984930_item	2270605	et	3	main
väga	doc_213943984930_item	2270607	et	3	main
hinges	doc_213943984930_item	2270609	et	4	main
lõpetasin	doc_213943984930_item	2270618	et	3	main
ainult	doc_213943984930_item	2270620	et	4	main
need	doc_213943984930_item	2270631	et	3	main
kaheksa	doc_213943984930_item	2270636	et	4	main
oli	doc_213943984930_item	2270639	et	3	main
tuletan	doc_213943984930_item	2270643	et	3	main
neid	doc_213943984930_item	2270645	et	4	main
need	doc_213943984930_item	2270647	et	3	main
ebaõnneliku	doc_213943984930_item	2270656	et	3	main
öelda	doc_213943984930_item	2270660	et	4	main
positiivne	doc_213943984930_item	2270664	et	3	main
kuhu	doc_213943984930_item	2270671	et	3	main
probleem	doc_213943984930_item	2270678	et	3	main
alati	doc_213943984930_item	2270682	et	4	main
saada	doc_213943984930_item	2270684	et	4	main
tallinna	doc_213943984930_item	2270692	et	4	main
et	doc_213943984930_item	2270722	et	3	main
elus	doc_213943984930_item	2270724	et	4	main
oli	doc_213943984930_item	2270726	et	3	main
aga	doc_213943984930_item	2270729	et	3	main
lihtsalt	doc_213943984930_item	2270741	et	4	main
ei	doc_213943984930_item	2270743	et	4	main
armasta	doc_213943984930_item	2270744	et	4	main
veel	doc_213943984930_item	2270749	et	4	main
et	doc_213943984930_item	2270752	et	3	main
ta	doc_213943984930_item	2270760	et	4	main
õppisin	doc_213943984931_item	2270781	et	3	main
käisin	doc_213943984931_item	2270789	et	3	main
tundides	doc_213943984931_item	2270791	et	3	main
põhikooli	doc_213943984931_item	2270803	et	4	main
klassis	doc_213943984931_item	2270810	et	3	main
tehnikaülikooli	doc_213943984931_item	2270823	et	4	main
sisse	doc_213943984931_item	2270826	et	4	main
erialale	doc_213943984931_item	2270828	et	3	main
samal	doc_213943984931_item	2270829	et	3	main
pean	doc_213943984931_item	2270833	et	4	main
ise	doc_213943984931_item	2270834	et	4	main
lahkusin	doc_213943984931_item	2270837	et	4	main
ja	doc_213943984931_item	2270839	et	3	main
minu	doc_213943984931_item	2270842	et	3	main
ma	doc_213943984931_item	2270849	et	3	main
ajal	doc_213943984931_item	2270854	et	4	main
sain	doc_213943984931_item	2270855	et	3	main
olen	doc_213943984931_item	2270872	et	3	main
õppima	doc_213943984931_item	2270874	et	3	main
vaja	doc_213943984931_item	2270877	et	4	main
oli	doc_213943984931_item	2270880	et	3	main
raske	doc_213943984931_item	2270884	et	4	main
ei	doc_213943984931_item	2270887	et	4	main
mulle	doc_213943984931_item	2270889	et	4	main
tehnikasuunaga	doc_213943984931_item	2270890	et	4	main
et	doc_213943984931_item	2270898	et	3	main
ma	doc_213943984931_item	2270899	et	3	main
saa	doc_213943984931_item	2270901	et	4	main
kellega	doc_213943984930_item	2270537	et	3	main
ja	doc_213943984930_item	2270552	et	3	main
see	doc_213943984930_item	2270554	et	3	main
tõsine	doc_213943984930_item	2270557	et	4	main
ja	doc_213943984930_item	2270558	et	3	main
õnnelik	doc_213943984930_item	2270559	et	3	main
hetk	doc_213943984930_item	2270560	et	3	main
mu	doc_213943984930_item	2270561	et	3	main
elus	doc_213943984930_item	2270562	et	4	main
mäletan	doc_213943984930_item	2270563	et	3	main
et	doc_213943984930_item	2270564	et	3	main
mulle	doc_213943984930_item	2270565	et	4	main
meeldisid	doc_213943984930_item	2270566	et	4	main
kõik	doc_213943984930_item	2270567	et	4	main
ained	doc_213943984930_item	2270568	et	3	main
ma	doc_213943984930_item	2270569	et	3	main
leidsin	doc_213943984930_item	2270570	et	3	main
ühist	doc_213943984930_item	2270571	et	3	main
väga	doc_213943984930_item	2270523	et	3	main
võib-olla	doc_213943984930_item	2270527	et	3	main
kinnine	doc_213943984930_item	2270529	et	3	main
ehkki	doc_213943984930_item	2270531	et	3	main
kontakte	doc_213943984930_item	2270541	et	3	main
teises	doc_213943984930_item	2270542	et	4	main
klassis	doc_213943984930_item	2270543	et	3	main
klassiõpetaja	doc_213943984930_item	2270545	et	4	main
mulle	doc_213943984930_item	2270547	et	4	main
astuda	doc_213943984930_item	2270548	et	3	main
ma	doc_213943984930_item	2270550	et	3	main
astusin	doc_213943984930_item	2270553	et	3	main
mu	doc_213943984930_item	2270576	et	3	main
teiseks	doc_213943984930_item	2270580	et	4	main
jooksul	doc_213943984930_item	2270586	et	4	main
võitsin	doc_213943984930_item	2270588	et	3	main
sain	doc_213943984930_item	2270593	et	3	main
tänan	doc_213943984930_item	2270596	et	3	main
samaks	doc_213943984930_item	2270611	et	3	main
sellele	doc_213943984930_item	2270613	et	4	main
ma	doc_213943984930_item	2270614	et	3	main
keskkoolis	doc_213943984930_item	2270616	et	4	main
hästi	doc_213943984930_item	2270617	et	3	main
muusikakooli	doc_213943984930_item	2270619	et	4	main
neljaga	doc_213943984930_item	2270622	et	4	main
kuldmedaliga	doc_213943984930_item	2270628	et	3	main
12	doc_213943984930_item	2270632	et	2	main
aastat	doc_213943984930_item	2270633	et	3	main
meelde	doc_213943984930_item	2270644	et	3	main
armastusega	doc_213943984930_item	2270646	et	4	main
aastad	doc_213943984930_item	2270648	et	3	main
armastuse	doc_213943984930_item	2270657	et	4	main
klassi	doc_213943984930_item	2270668	et	4	main
ma	doc_213943984930_item	2270674	et	3	main
kiiresti	doc_213943984930_item	2270681	et	3	main
ja	doc_213943984930_item	2270689	et	3	main
praegu	doc_213943984930_item	2270694	et	3	main
õpetajatega	doc_213943984930_item	2270574	et	4	main
kes	doc_213943984930_item	2270578	et	4	main
osa	doc_213943984930_item	2270589	et	4	main
ja	doc_213943984930_item	2270592	et	3	main
muusikakooli	doc_213943984930_item	2270597	et	4	main
õpisin	doc_213943984930_item	2270615	et	4	main
aastat	doc_213943984930_item	2270625	et	3	main
pärast	doc_213943984930_item	2270626	et	4	main
mu	doc_213943984930_item	2270629	et	3	main
koolis	doc_213943984930_item	2270634	et	4	main
muusikakoolis	doc_213943984930_item	2270638	et	4	main
andsid	doc_213943984930_item	2270649	et	4	main
tõused	doc_213943984930_item	2270652	et	3	main
aga	doc_213943984930_item	2270658	et	3	main
et	doc_213943984930_item	2270661	et	3	main
see	doc_213943984930_item	2270662	et	3	main
oli	doc_213943984930_item	2270663	et	3	main
kaheteistkümnenda	doc_213943984930_item	2270667	et	4	main
kelleks	doc_213943984930_item	2270673	et	4	main
saada	doc_213943984930_item	2270676	et	4	main
see	doc_213943984930_item	2270677	et	3	main
lahenes	doc_213943984930_item	2270679	et	3	main
väga	doc_213943984930_item	2270680	et	3	main
tallinnasse	doc_213943984930_item	2270688	et	3	main
edukalt	doc_213943984930_item	2270690	et	4	main
meeldib	doc_213943984930_item	2270696	et	3	main
tunduda	doc_213943984930_item	2270721	et	3	main
minu	doc_213943984930_item	2270723	et	3	main
negatiivseid	doc_213943984930_item	2270727	et	3	main
sündmusi	doc_213943984930_item	2270728	et	3	main
on	doc_213943984930_item	2270734	et	4	main
veendunud	doc_213943984930_item	2270754	et	4	main
inimene	doc_213943984930_item	2270756	et	3	main
enesekindel	doc_213943984930_item	2270758	et	3	main
igast	doc_213943984930_item	2270763	et	3	main
keskkoolis	doc_213943984931_item	2270784	et	4	main
klassis	doc_213943984931_item	2270786	et	3	main
samal	doc_213943984931_item	2270787	et	3	main
ei	doc_213943984931_item	2270792	et	4	main
muusikaks	doc_213943984931_item	2270796	et	3	main
lõpetamist	doc_213943984931_item	2270804	et	4	main
olen	doc_213943984931_item	2270805	et	3	main
õppinud	doc_213943984931_item	2270806	et	4	main
juriidiliste	doc_213943984931_item	2270808	et	3	main
kooli	doc_213943984931_item	2270818	et	4	main
lõpetamist	doc_213943984931_item	2270819	et	4	main
läksin	doc_213943984931_item	2270820	et	3	main
ma	doc_213943984931_item	2270821	et	3	main
sain	doc_213943984931_item	2270825	et	3	main
hakkas	doc_213943984931_item	2270841	et	3	main
ma	doc_213943984931_item	2270846	et	3	main
palju	doc_213943984931_item	2270857	et	4	main
ma	doc_213943984931_item	2270859	et	3	main
paljudes	doc_213943984931_item	2270861	et	3	main
kohtades	doc_213943984931_item	2270862	et	3	main
kioskis	doc_213943984931_item	2270864	et	3	main
treeneri	doc_213943984931_item	2270868	et	3	main
ole	doc_213943984931_item	2270876	et	4	main
eriti	doc_213943984931_item	2270883	et	3	main
meeldinud	doc_213943984931_item	2270888	et	4	main
aastat	doc_213943984931_item	2270894	et	3	main
sain	doc_213943984931_item	2270896	et	3	main
xxx	doc_213943984931_item	2270926	et	4	main
aasta	doc_213943984931_item	2270930	et	4	main
kontrollöörina	doc_213943984931_item	2270932	et	3	main
kuid	doc_213943984931_item	2270933	et	4	main
sellel	doc_213943984931_item	2270939	et	4	main
suur	doc_213943984931_item	2270945	et	3	main
oli	doc_213943984931_item	2270948	et	3	main
sellepärast	doc_213943984931_item	2270950	et	3	main
ma	doc_213943984931_item	2270952	et	3	main
muusikat	doc_213943984931_item	2270955	et	3	main
saanud	doc_213943984931_item	2270975	et	4	main
ülikooli	doc_213943984931_item	2270979	et	4	main
idamaade	doc_213943984931_item	2270980	et	3	main
hommikul	doc_213943984932_item	2270992	et	3	main
kokkulangemine	doc_213943984932_item	2270995	et	3	main
lemmikuks	doc_213943984932_item	2270998	et	4	main
oma	doc_213943984932_item	2271021	et	4	main
mul	doc_213943984932_item	2271023	et	3	main
huvi	doc_213943984932_item	2271029	et	4	main
ta	doc_213943984930_item	2270601	et	4	main
andis	doc_213943984930_item	2270602	et	3	main
enesekindlust	doc_213943984930_item	2270604	et	4	main
jäin	doc_213943984930_item	2270610	et	3	main
lisaks	doc_213943984930_item	2270612	et	4	main
ühe	doc_213943984930_item	2270621	et	4	main
keskkooli	doc_213943984930_item	2270627	et	4	main
ja	doc_213943984930_item	2270635	et	3	main
ma	doc_213943984930_item	2270642	et	3	main
esimesed	doc_213943984930_item	2270651	et	3	main
ja	doc_213943984930_item	2270653	et	3	main
esimese	doc_213943984930_item	2270655	et	3	main
pärast	doc_213943984930_item	2270666	et	4	main
küsimus	doc_213943984930_item	2270670	et	4	main
astuda	doc_213943984930_item	2270672	et	3	main
tahaks	doc_213943984930_item	2270675	et	3	main
tahaksin	doc_213943984930_item	2270683	et	3	main
õpetajaks	doc_213943984930_item	2270685	et	4	main
siis	doc_213943984930_item	2270686	et	3	main
pedagoogikaülikooli	doc_213943984930_item	2270693	et	4	main
õppida	doc_213943984930_item	2270697	et	3	main
väga	doc_213943984930_item	2270698	et	3	main
aga	doc_213943984930_item	2270699	et	3	main
ma	doc_213943984930_item	2270700	et	3	main
kaotas	doc_213943984930_item	2270701	et	3	main
suhelda	doc_213943984930_item	2270703	et	4	main
võimalust	doc_213943984930_item	2270702	et	3	main
sõpradega	doc_213943984930_item	2270704	et	3	main
tihti	doc_213943984930_item	2270705	et	3	main
negatiivne	doc_213943984930_item	2270706	et	3	main
punkt	doc_213943984930_item	2270707	et	4	main
alguses	doc_213943984930_item	2270708	et	4	main
muretsesin	doc_213943984930_item	2270709	et	3	main
praegu	doc_213943984930_item	2270710	et	3	main
olen	doc_213943984930_item	2270711	et	3	main
harjunud	doc_213943984930_item	2270712	et	4	main
sellega	doc_213943984930_item	2270713	et	3	main
minu	doc_213943984930_item	2270714	et	3	main
lõpeb	doc_213943984930_item	2270716	et	4	main
tean	doc_213943984930_item	2270717	et	3	main
jutt	doc_213943984930_item	2270715	et	3	main
et	doc_213943984930_item	2270718	et	3	main
teile	doc_213943984930_item	2270719	et	4	main
võiks	doc_213943984930_item	2270720	et	4	main
ei	doc_213943984930_item	2270725	et	4	main
mustade	doc_213943984930_item	2270737	et	3	main
valgete	doc_213943984930_item	2270739	et	4	main
rääkida	doc_213943984930_item	2270746	et	3	main
lisata	doc_213943984930_item	2270751	et	4	main
on	doc_213943984930_item	2270757	et	4	main
siis	doc_213943984930_item	2270759	et	3	main
11	doc_213943984931_item	2270783	et	2	main
muusika	doc_213943984931_item	2270785	et	4	main
tahtnud	doc_213943984931_item	2270794	et	4	main
kuid	doc_213943984931_item	2270798	et	4	main
gümnaasiumis	doc_213943984931_item	2270807	et	3	main
suunaga	doc_213943984931_item	2270809	et	4	main
see	doc_213943984931_item	2270811	et	3	main
ning	doc_213943984931_item	2270814	et	3	main
kuid	doc_213943984931_item	2270816	et	4	main
pärast	doc_213943984931_item	2270817	et	4	main
ja	doc_213943984931_item	2270824	et	3	main
ajal	doc_213943984931_item	2270830	et	4	main
otsustasin	doc_213943984931_item	2270831	et	3	main
kuna	doc_213943984930_item	2270732	et	3	main
nagu	doc_213943984930_item	2270735	et	3	main
ülekäikurada	doc_213943984930_item	2270736	et	4	main
joontega	doc_213943984930_item	2270740	et	3	main
ma	doc_213943984930_item	2270742	et	3	main
palju	doc_213943984930_item	2270745	et	4	main
mustatest	doc_213943984930_item	2270747	et	4	main
tahaksin	doc_213943984930_item	2270750	et	3	main
olen	doc_213943984930_item	2270753	et	3	main
kui	doc_213943984930_item	2270755	et	3	main
leiab	doc_213943984930_item	2270762	et	3	main
lahendust	doc_213943984930_item	2270765	et	4	main
essee	doc_213943984931_item	2270766	et	4	main
mina	doc_213943984931_item	2270767	et	4	main
on	doc_213943984931_item	2270768	et	4	main
sündinud	doc_213943984931_item	2270769	et	4	main
tallinnas	doc_213943984931_item	2270770	et	4	main
minu	doc_213943984931_item	2270771	et	3	main
vanemad	doc_213943984931_item	2270772	et	4	main
töötasid	doc_213943984931_item	2270773	et	4	main
tehases	doc_213943984931_item	2270774	et	3	main
isa	doc_213943984931_item	2270775	et	4	main
inseneerina	doc_213943984931_item	2270776	et	4	main
aga	doc_213943984931_item	2270777	et	3	main
ema	doc_213943984931_item	2270778	et	4	main
plekkplaadi	doc_213943984931_item	2270779	et	3	main
monteerijana	doc_213943984931_item	2270780	et	4	main
eriti	doc_213943984931_item	2270795	et	3	main
saada	doc_213943984931_item	2270797	et	4	main
lihtsalt	doc_213943984931_item	2270799	et	4	main
muusikat	doc_213943984931_item	2270800	et	3	main
armastan	doc_213943984931_item	2270801	et	3	main
pärast	doc_213943984931_item	2270802	et	4	main
oli	doc_213943984931_item	2270812	et	3	main
tallinna	doc_213943984931_item	2270822	et	4	main
informaatika	doc_213943984931_item	2270827	et	4	main
enda	doc_213943984931_item	2270835	et	4	main
elu	doc_213943984931_item	2270844	et	4	main
mõtlen	doc_213943984931_item	2270847	et	3	main
ma	doc_213943984931_item	2270856	et	3	main
töötasin	doc_213943984931_item	2270860	et	3	main
müüjana	doc_213943984931_item	2270865	et	4	main
abistajana	doc_213943984931_item	2270869	et	4	main
samal	doc_213943984931_item	2270870	et	3	main
minule	doc_213943984931_item	2270882	et	3	main
et	doc_213943984931_item	2270886	et	3	main
tegelda	doc_213943984931_item	2270891	et	4	main
tööle	doc_213943984931_item	2270923	et	3	main
kus	doc_213943984931_item	2270927	et	3	main
ühe	doc_213943984931_item	2270929	et	4	main
jooksul	doc_213943984931_item	2270931	et	4	main
ja	doc_213943984931_item	2270938	et	3	main
oli	doc_213943984931_item	2270941	et	3	main
juba	doc_213943984931_item	2270943	et	3	main
unistus	doc_213943984931_item	2270946	et	4	main
see	doc_213943984931_item	2270947	et	3	main
köitnud	doc_213943984931_item	2270958	et	4	main
tantsuga	doc_213943984931_item	2270960	et	3	main
püüdsin	doc_213943984931_item	2270961	et	3	main
ise	doc_213943984931_item	2270964	et	4	main
õppida	doc_213943984931_item	2270965	et	3	main
gümnaasiumi	doc_213943984931_item	2270969	et	4	main
juba	doc_213943984931_item	2270972	et	3	main
tallinna	doc_213943984931_item	2270977	et	4	main
ma	doc_213943984932_item	2270984	et	3	main
25	doc_213943984932_item	2270986	et	2	main
see	doc_213943984932_item	2270993	et	3	main
viis	doc_213943984932_item	2270997	et	4	main
vedas	doc_213943984932_item	2271001	et	4	main
ta	doc_213943984932_item	2271003	et	4	main
et	doc_213943984931_item	2270832	et	3	main
praegu	doc_213943984931_item	2270845	et	3	main
et	doc_213943984931_item	2270848	et	3	main
eksinud	doc_213943984931_item	2270851	et	4	main
sel	doc_213943984931_item	2270853	et	3	main
elukogemusi	doc_213943984931_item	2270858	et	3	main
nagu	doc_213943984931_item	2270863	et	3	main
või	doc_213943984931_item	2270866	et	4	main
öelda	doc_213943984931_item	2270878	et	4	main
et	doc_213943984931_item	2270879	et	3	main
sellepärast	doc_213943984931_item	2270885	et	3	main
pärast	doc_213943984931_item	2270892	et	4	main
aru	doc_213943984931_item	2270897	et	4	main
ei	doc_213943984931_item	2270900	et	4	main
rohkem	doc_213943984931_item	2270902	et	4	main
ebameeldiva	doc_213943984931_item	2270903	et	3	main
erialaga	doc_213943984931_item	2270904	et	3	main
tegelema	doc_213943984931_item	2270905	et	3	main
ja	doc_213943984931_item	2270906	et	3	main
katkestasin	doc_213943984931_item	2270907	et	3	main
õppimist	doc_213943984931_item	2270908	et	4	main
samal	doc_213943984931_item	2270909	et	3	main
ajal	doc_213943984931_item	2270910	et	4	main
otsustasin	doc_213943984931_item	2270911	et	3	main
koju	doc_213943984931_item	2270912	et	3	main
tagasi	doc_213943984931_item	2270913	et	3	main
minna	doc_213943984931_item	2270914	et	3	main
sest	doc_213943984931_item	2270915	et	4	main
oma	doc_213943984931_item	2270916	et	4	main
pere	doc_213943984931_item	2270917	et	4	main
olin	doc_213943984931_item	2270918	et	3	main
igatsenud	doc_213943984931_item	2270919	et	4	main
siis	doc_213943984931_item	2270920	et	3	main
xxx	doc_213943984931_item	2270925	et	4	main
see	doc_213943984931_item	2270934	et	3	main
ajal	doc_213943984931_item	2270940	et	4	main
mul	doc_213943984931_item	2270942	et	3	main
üks	doc_213943984931_item	2270944	et	3	main
armastasin	doc_213943984931_item	2270953	et	3	main
olen	doc_213943984931_item	2270957	et	3	main
keelt	doc_213943984931_item	2270963	et	4	main
kevadel	doc_213943984931_item	2270966	et	4	main
jälle	doc_213943984931_item	2270968	et	3	main
lõpueksameid	doc_213943984931_item	2270970	et	3	main
sügisel	doc_213943984931_item	2270973	et	3	main
sisse	doc_213943984931_item	2270976	et	4	main
1985	doc_213943984932_item	2270988	et	2	main
kell	doc_213943984932_item	2270990	et	3	main
rabav	doc_213943984932_item	2270994	et	4	main
arvuks	doc_213943984932_item	2270999	et	4	main
ja	doc_213943984932_item	2271033	et	3	main
alguses	doc_213943984932_item	2271043	et	4	main
kooli	doc_213943984932_item	2271048	et	4	main
2	doc_213943984932_item	2271050	et	2	main
1	doc_213943984932_item	2271053	et	2	main
st	doc_213943984932_item	2271054	et	3	main
septembrist	doc_213943984932_item	2271055	et	3	main
väga	doc_213943984932_item	2271081	et	3	main
7	doc_213943984932_item	2271086	et	2	main
olid	doc_213943984932_item	2271093	et	4	main
ühtsust	doc_213943984932_item	2271105	et	4	main
kooli	doc_213943984932_item	2271109	et	4	main
üldse	doc_213943984932_item	2271114	et	3	main
ainult	doc_213943984932_item	2271131	et	4	main
eksami	doc_213943984932_item	2271137	et	3	main
polnud	doc_213943984932_item	2271139	et	3	main
elama	doc_213943984931_item	2270836	et	3	main
kojust	doc_213943984931_item	2270838	et	4	main
siis	doc_213943984931_item	2270840	et	3	main
iseseisev	doc_213943984931_item	2270843	et	3	main
olen	doc_213943984931_item	2270850	et	3	main
kuid	doc_213943984931_item	2270852	et	4	main
hippodroomis	doc_213943984931_item	2270867	et	4	main
ajal	doc_213943984931_item	2270871	et	4	main
püüdnud	doc_213943984931_item	2270873	et	4	main
ei	doc_213943984931_item	2270875	et	4	main
see	doc_213943984931_item	2270881	et	3	main
3	doc_213943984931_item	2270893	et	2	main
õppimist	doc_213943984931_item	2270895	et	4	main
ma	doc_213943984931_item	2270921	et	3	main
töötasin	doc_213943984931_item	2270928	et	3	main
oli	doc_213943984931_item	2270936	et	3	main
idamaise	doc_213943984931_item	2270959	et	4	main
sooritasin	doc_213943984931_item	2270967	et	3	main
ja	doc_213943984931_item	2270971	et	3	main
on	doc_213943984931_item	2270974	et	4	main
pedagoogika	doc_213943984931_item	2270978	et	4	main
filoloogia	doc_213943984931_item	2270981	et	4	main
õppesuunasse	doc_213943984931_item	2270982	et	3	main
essee	doc_213943984932_item	2270983	et	4	main
emaga	doc_213943984932_item	2271002	et	3	main
proovida	doc_213943984932_item	2271026	et	3	main
karateni	doc_213943984932_item	2271035	et	3	main
kui	doc_213943984932_item	2271036	et	3	main
sain	doc_213943984932_item	2271038	et	3	main
kooli	doc_213943984932_item	2271042	et	4	main
mind	doc_213943984932_item	2271044	et	4	main
mind	doc_213943984932_item	2271058	et	4	main
pöörati	doc_213943984932_item	2271076	et	3	main
kuigi	doc_213943984932_item	2271077	et	3	main
raske	doc_213943984932_item	2271082	et	4	main
kui	doc_213943984932_item	2271084	et	3	main
sse	doc_213943984932_item	2271087	et	4	main
tavalisesse	doc_213943984932_item	2271089	et	4	main
eriti	doc_213943984932_item	2271095	et	3	main
meie	doc_213943984932_item	2271097	et	4	main
inimeste	doc_213943984932_item	2271100	et	3	main
mingit	doc_213943984932_item	2271104	et	3	main
igaüks	doc_213943984932_item	2271106	et	3	main
üksikolend	doc_213943984932_item	2271108	et	3	main
19	doc_213943984932_item	2271112	et	2	main
teadnud	doc_213943984932_item	2271116	et	4	main
kuhu	doc_213943984932_item	2271117	et	3	main
astusin	doc_213943984931_item	2270922	et	3	main
plastikatehasse	doc_213943984931_item	2270924	et	4	main
töö	doc_213943984931_item	2270935	et	4	main
igavlev	doc_213943984931_item	2270937	et	4	main
idamaad	doc_213943984931_item	2270949	et	4	main
et	doc_213943984931_item	2270951	et	3	main
idamaist	doc_213943984931_item	2270954	et	4	main
ja	doc_213943984931_item	2270956	et	3	main
araabia	doc_213943984931_item	2270962	et	4	main
sündisin	doc_213943984932_item	2270985	et	3	main
mail	doc_213943984932_item	2270987	et	4	main
aastal	doc_213943984932_item	2270989	et	3	main
555	doc_213943984932_item	2270991	et	2	main
tegi	doc_213943984932_item	2270996	et	4	main
mulle	doc_213943984932_item	2271000	et	4	main
alati	doc_213943984932_item	2271004	et	4	main
lubas	doc_213943984932_item	2271005	et	3	main
mulle	doc_213943984932_item	2271006	et	4	main
teha	doc_213943984932_item	2271007	et	3	main
kõike	doc_213943984932_item	2271008	et	4	main
mida	doc_213943984932_item	2271009	et	4	main
ma	doc_213943984932_item	2271010	et	3	main
tahtsin	doc_213943984932_item	2271011	et	3	main
alates	doc_213943984932_item	2271012	et	3	main
juuste	doc_213943984932_item	2271013	et	4	main
värvimisest	doc_213943984932_item	2271014	et	4	main
kuni	doc_213943984932_item	2271015	et	3	main
mingi	doc_213943984932_item	2271016	et	4	main
uue	doc_213943984932_item	2271017	et	3	main
gruppidega	doc_213943984932_item	2271019	et	3	main
liitumist	doc_213943984932_item	2271020	et	4	main
huvi	doc_213943984932_item	2271018	et	4	main
kuidagi	doc_213943984932_item	2271024	et	3	main
õnnestus	doc_213943984932_item	2271025	et	4	main
end	doc_213943984932_item	2271027	et	4	main
joonistamisest	doc_213943984932_item	2271032	et	4	main
väljaõmblemisest	doc_213943984932_item	2271034	et	3	main
võtsid	doc_213943984932_item	2271045	et	4	main
kuid	doc_213943984932_item	2271049	et	4	main
enne	doc_213943984932_item	2271052	et	4	main
ema	doc_213943984932_item	2271056	et	4	main
meile	doc_213943984932_item	2271072	et	4	main
kõigele	doc_213943984932_item	2271073	et	4	main
oli	doc_213943984932_item	2271080	et	3	main
harjuda	doc_213943984932_item	2271083	et	3	main
da	doc_213943984932_item	2271099	et	4	main
klassiga	doc_213943984932_item	2271101	et	3	main
oli	doc_213943984932_item	2271107	et	3	main
lõpetasin	doc_213943984932_item	2271110	et	3	main
ühe	doc_213943984932_item	2271132	et	4	main
ülikooli	doc_213943984932_item	2271133	et	4	main
kuhu	doc_213943984932_item	2271134	et	3	main
turismiettevõtmisele	doc_213943984932_item	2271135	et	3	main
sain	doc_213943984932_item	2271142	et	3	main
ülikoolis	doc_213943984932_item	2271146	et	4	main
pärast	doc_213943984932_item	2271164	et	4	main
puhkust	doc_213943984932_item	2271167	et	4	main
siiski	doc_213943984932_item	2271169	et	4	main
tuli	doc_213943984932_item	2271174	et	4	main
ka	doc_213943984932_item	2271175	et	3	main
aga	doc_213943984932_item	2271185	et	3	main
juba	doc_213943984932_item	2271189	et	3	main
tpüsse	doc_213943984932_item	2271194	et	4	main
medaleid	doc_213943984932_item	2271199	et	3	main
ainult	doc_213943984932_item	2271213	et	4	main
lapsepõlves	doc_213943984932_item	2271022	et	4	main
erinevates	doc_213943984932_item	2271028	et	4	main
alates	doc_213943984932_item	2271031	et	3	main
ma	doc_213943984932_item	2271037	et	3	main
aastaseks	doc_213943984932_item	2271040	et	4	main
32	doc_213943984932_item	2271047	et	2	main
päeva	doc_213943984932_item	2271051	et	4	main
era	doc_213943984932_item	2271059	et	4	main
kooli	doc_213943984932_item	2271060	et	4	main
panna	doc_213943984932_item	2271061	et	4	main
ühelt	doc_213943984932_item	2271062	et	3	main
poolt	doc_213943984932_item	2271063	et	4	main
see	doc_213943984932_item	2271064	et	3	main
oli	doc_213943984932_item	2271065	et	3	main
hea	doc_213943984932_item	2271066	et	4	main
sest	doc_213943984932_item	2271067	et	4	main
klassid	doc_213943984932_item	2271068	et	3	main
olid	doc_213943984932_item	2271069	et	4	main
väikesed	doc_213943984932_item	2271070	et	4	main
ja	doc_213943984932_item	2271071	et	3	main
ringides	doc_213943984932_item	2271030	et	4	main
seitsme	doc_213943984932_item	2271039	et	3	main
läksin	doc_213943984932_item	2271041	et	3	main
arvele	doc_213943984932_item	2271046	et	4	main
otsustas	doc_213943984932_item	2271057	et	3	main
teiselt	doc_213943984932_item	2271078	et	4	main
poolt	doc_213943984932_item	2271079	et	4	main
koolisse	doc_213943984932_item	2271090	et	4	main
klassid	doc_213943984932_item	2271092	et	3	main
võrreldes	doc_213943984932_item	2271096	et	3	main
polnud	doc_213943984932_item	2271102	et	3	main
aastasena	doc_213943984932_item	2271113	et	4	main
edasi	doc_213943984932_item	2271118	et	3	main
astuda	doc_213943984932_item	2271120	et	3	main
kuna	doc_213943984932_item	2271121	et	3	main
turismiga	doc_213943984932_item	2271127	et	3	main
sooritamist	doc_213943984932_item	2271138	et	4	main
et	doc_213943984932_item	2271144	et	3	main
alati	doc_213943984932_item	2271152	et	4	main
oma	doc_213943984932_item	2271165	et	4	main
mainori	doc_213943984932_item	2271179	et	4	main
mind	doc_213943984932_item	2271181	et	4	main
kohe	doc_213943984932_item	2271182	et	4	main
vastu	doc_213943984932_item	2271183	et	3	main
võeti	doc_213943984932_item	2271184	et	3	main
tahtsin	doc_213943984932_item	2271192	et	3	main
liiga	doc_213943984932_item	2271197	et	4	main
suur	doc_213943984932_item	2271198	et	3	main
mul	doc_213943984932_item	2271200	et	3	main
olnud	doc_213943984932_item	2271202	et	4	main
olin	doc_213943984932_item	2271204	et	3	main
5	doc_213943984932_item	2271206	et	2	main
dal	doc_213943984932_item	2271207	et	4	main
kohal	doc_213943984932_item	2271208	et	4	main
oli	doc_213943984932_item	2271218	et	3	main
soov	doc_213943984932_item	2271221	et	3	main
õppida	doc_213943984932_item	2271223	et	3	main
vanemad	doc_213943984932_item	2271225	et	4	main
ei	doc_213943984932_item	2271227	et	4	main
tudeng	doc_213943984932_item	2271234	et	3	main
tore	doc_213943984932_item	2271241	et	3	main
selle	doc_213943984932_item	2271247	et	4	main
ta	doc_213943984932_item	2271250	et	4	main
tunneb	doc_213943984932_item	2271252	et	3	main
aasta	doc_213943984932_item	2271254	et	4	main
ka	doc_213943984932_item	2271257	et	3	main
essee	doc_213943984933_item	2271270	et	4	main
eesnimi	doc_213943984933_item	2271274	et	3	main
ma	doc_213943984933_item	2271276	et	3	main
kiviõlis	doc_213943984933_item	2271285	et	4	main
venelane	doc_213943984933_item	2271288	et	3	main
1986	doc_213943984933_item	2271321	et	2	main
hakkasin	doc_213943984933_item	2271324	et	3	main
lõbusam	doc_213943984933_item	2271331	et	4	main
väikesena	doc_213943984933_item	2271334	et	4	main
mulle	doc_213943984933_item	2271335	et	4	main
meeldis	doc_213943984933_item	2271336	et	3	main
kleite	doc_213943984933_item	2271349	et	3	main
õppima	doc_213943984933_item	2271353	et	3	main
esimene	doc_213943984933_item	2271360	et	3	main
oli	doc_213943984933_item	2271362	et	3	main
koolis	doc_213943984933_item	2271371	et	4	main
informaatika	doc_213943984933_item	2271376	et	4	main
joonistamine	doc_213943984933_item	2271377	et	4	main
ajalugu	doc_213943984933_item	2271379	et	4	main
osalesin	doc_213943984933_item	2271386	et	3	main
esinesin	doc_213943984933_item	2271391	et	3	main
näitustest	doc_213943984933_item	2271396	et	4	main
tõi	doc_213943984933_item	2271398	et	3	main
naudingu	doc_213943984933_item	2271400	et	3	main
suure	doc_213943984933_item	2271402	et	3	main
elamusi	doc_213943984933_item	2271404	et	3	main
klassi	doc_213943984933_item	2271407	et	4	main
ma	doc_213943984933_item	2271421	et	3	main
läksin	doc_213943984933_item	2271436	et	3	main
kunstide	doc_213943984933_item	2271439	et	3	main
töö	doc_213943984933_item	2271444	et	4	main
graafik	doc_213943984933_item	2271445	et	3	main
küllalt	doc_213943984933_item	2271447	et	4	main
päeval	doc_213943984933_item	2271449	et	3	main
õhtul	doc_213943984933_item	2271454	et	3	main
trenni	doc_213943984933_item	2271472	et	4	main
palju	doc_213943984932_item	2271074	et	4	main
tähelepanu	doc_213943984932_item	2271075	et	4	main
ma	doc_213943984932_item	2271085	et	3	main
klassisse	doc_213943984932_item	2271088	et	3	main
läksin	doc_213943984932_item	2271091	et	3	main
hiigelsuured	doc_213943984932_item	2271094	et	3	main
8	doc_213943984932_item	2271098	et	2	main
ka	doc_213943984932_item	2271103	et	3	main
ma	doc_213943984932_item	2271111	et	3	main
ei	doc_213943984932_item	2271115	et	4	main
õppima	doc_213943984932_item	2271119	et	3	main
puudus	doc_213943984932_item	2271123	et	4	main
valida	doc_213943984932_item	2271125	et	3	main
seotud	doc_213943984932_item	2271128	et	4	main
kahjuks	doc_213943984932_item	2271129	et	4	main
juhuslikult	doc_213943984932_item	2271141	et	4	main
teada	doc_213943984932_item	2271143	et	3	main
mina	doc_213943984932_item	2271151	et	4	main
vastu	doc_213943984932_item	2271154	et	3	main
kolmandat	doc_213943984932_item	2271166	et	3	main
sooritada	doc_213943984932_item	2271178	et	3	main
kõrgkooli	doc_213943984932_item	2271180	et	4	main
ajaks	doc_213943984932_item	2271187	et	4	main
ainult	doc_213943984932_item	2271193	et	4	main
ei	doc_213943984932_item	2271201	et	4	main
õppida	doc_213943984932_item	2271210	et	3	main
mul	doc_213943984932_item	2271217	et	3	main
tpüs	doc_213943984932_item	2271222	et	4	main
ka	doc_213943984932_item	2271224	et	3	main
vastu	doc_213943984932_item	2271226	et	3	main
olnud	doc_213943984932_item	2271228	et	4	main
idamaade	doc_213943984932_item	2271232	et	3	main
see	doc_213943984932_item	2271239	et	3	main
õppida	doc_213943984932_item	2271245	et	3	main
vastu	doc_213943984932_item	2271249	et	3	main
hästi	doc_213943984932_item	2271260	et	3	main
uue	doc_213943984932_item	2271265	et	3	main
minu	doc_213943984933_item	2271271	et	3	main
on	doc_213943984933_item	2271273	et	4	main
perekonnanimi	doc_213943984933_item	2271275	et	3	main
sündinud	doc_213943984933_item	2271278	et	4	main
2	doc_213943984933_item	2271279	et	2	main
novembril	doc_213943984933_item	2271280	et	3	main
meie	doc_213943984933_item	2271289	et	4	main
on	doc_213943984933_item	2271291	et	4	main
käima	doc_213943984933_item	2271325	et	4	main
lapsepõlve	doc_213943984933_item	2271332	et	4	main
laulda	doc_213943984933_item	2271338	et	4	main
kelgutada	doc_213943984933_item	2271341	et	3	main
rahvastepalli	doc_213943984933_item	2271344	et	4	main
hüpenööriga	doc_213943984933_item	2271346	et	4	main
nukudele	doc_213943984933_item	2271348	et	4	main
aastal	doc_213943984933_item	2271351	et	3	main
gümnaasiumisse	doc_213943984933_item	2271358	et	3	main
mulle	doc_213943984933_item	2271368	et	4	main
mulle	doc_213943984933_item	2271374	et	4	main
ja	doc_213943984933_item	2271378	et	3	main
õpilane	doc_213943984933_item	2271384	et	3	main
paljudes	doc_213943984933_item	2271388	et	3	main
11	doc_213943984933_item	2271406	et	2	main
astuda	doc_213943984933_item	2271424	et	3	main
kunsti	doc_213943984933_item	2271426	et	4	main
ma	doc_213943984933_item	2271428	et	3	main
pidin	doc_213943984933_item	2271429	et	3	main
selle	doc_213943984933_item	2271433	et	4	main
ma	doc_213943984933_item	2271435	et	3	main
kooli	doc_213943984933_item	2271440	et	4	main
olin	doc_213943984933_item	2271451	et	3	main
inglise	doc_213943984933_item	2271456	et	4	main
ka	doc_213943984933_item	2271468	et	3	main
käisin	doc_213943984933_item	2271471	et	3	main
korda	doc_213943984933_item	2271474	et	4	main
nädalas	doc_213943984933_item	2271475	et	3	main
kui	doc_213943984933_item	2271476	et	3	main
rahuliku	doc_213943984933_item	2271481	et	3	main
või	doc_213943984933_item	2271482	et	4	main
teist	doc_213943984933_item	2271488	et	4	main
ainult	doc_213943984933_item	2271495	et	4	main
üsna	doc_213943984933_item	2271511	et	3	main
gümnaasiumi	doc_213943984933_item	2271514	et	4	main
ma	doc_213943984933_item	2271520	et	3	main
täppisteadusvõime	doc_213943984932_item	2271122	et	4	main
otsustasin	doc_213943984932_item	2271124	et	3	main
midagi	doc_213943984932_item	2271126	et	4	main
leidsin	doc_213943984932_item	2271130	et	3	main
matemaatika	doc_213943984932_item	2271136	et	4	main
vajalik	doc_213943984932_item	2271140	et	3	main
õppida	doc_213943984932_item	2271150	et	3	main
idamaade	doc_213943984932_item	2271153	et	3	main
suurt	doc_213943984932_item	2271155	et	3	main
huvi	doc_213943984932_item	2271156	et	4	main
tundsin	doc_213943984932_item	2271157	et	3	main
iseseisvalt	doc_213943984932_item	2271159	et	4	main
hakkasin	doc_213943984932_item	2271160	et	3	main
isegi	doc_213943984932_item	2271158	et	4	main
türgi	doc_213943984932_item	2271161	et	4	main
keelt	doc_213943984932_item	2271162	et	4	main
pedagoogika	doc_213943984932_item	2271145	et	4	main
on	doc_213943984932_item	2271147	et	4	main
võimalik	doc_213943984932_item	2271148	et	3	main
idakeeli	doc_213943984932_item	2271149	et	3	main
õppima	doc_213943984932_item	2271163	et	3	main
eksameid	doc_213943984932_item	2271177	et	3	main
tolleks	doc_213943984932_item	2271186	et	4	main
mõtlesin	doc_213943984932_item	2271191	et	3	main
konkurs	doc_213943984932_item	2271195	et	4	main
oli	doc_213943984932_item	2271196	et	3	main
nimekirjas	doc_213943984932_item	2271203	et	3	main
ma	doc_213943984932_item	2271205	et	3	main
said	doc_213943984932_item	2271212	et	4	main
3	doc_213943984932_item	2271214	et	2	main
esimest	doc_213943984932_item	2271215	et	4	main
kindel	doc_213943984932_item	2271220	et	3	main
nüüdki	doc_213943984932_item	2271229	et	4	main
olen	doc_213943984932_item	2271230	et	3	main
õppimine	doc_213943984932_item	2271235	et	4	main
on	doc_213943984932_item	2271240	et	4	main
just	doc_213943984932_item	2271246	et	3	main
kiiresti	doc_213943984932_item	2271255	et	3	main
esimene	doc_213943984932_item	2271258	et	3	main
läks	doc_213943984932_item	2271261	et	3	main
jätkan	doc_213943984932_item	2271263	et	3	main
aastal	doc_213943984933_item	2271282	et	3	main
väikeses	doc_213943984933_item	2271284	et	4	main
rahvusest	doc_213943984933_item	2271286	et	4	main
perekonnas	doc_213943984933_item	2271290	et	4	main
aastal	doc_213943984933_item	2271322	et	3	main
joonistada	doc_213943984933_item	2271342	et	3	main
õmmelda	doc_213943984933_item	2271347	et	4	main
1991	doc_213943984933_item	2271350	et	2	main
minu	doc_213943984933_item	2271363	et	3	main
kaheteistkümnenda	doc_213943984933_item	2271366	et	4	main
õppida	doc_213943984933_item	2271370	et	3	main
enamasti	doc_213943984933_item	2271372	et	4	main
ja	doc_213943984933_item	2271385	et	3	main
kontsertidel	doc_213943984933_item	2271392	et	3	main
võtsin	doc_213943984933_item	2271394	et	3	main
see	doc_213943984933_item	2271397	et	3	main
pärast	doc_213943984933_item	2271405	et	4	main
tallinna	doc_213943984933_item	2271425	et	4	main
sisseastumiseks	doc_213943984933_item	2271432	et	3	main
õppima	doc_213943984933_item	2271437	et	3	main
kaheteistkümnendas	doc_213943984933_item	2271441	et	4	main
klassis	doc_213943984933_item	2271442	et	3	main
ma	doc_213943984933_item	2271450	et	3	main
tunnid	doc_213943984933_item	2271470	et	3	main
oleks	doc_213943984933_item	2271478	et	3	main
vahel	doc_213943984933_item	2271485	et	4	main
valiksin	doc_213943984933_item	2271487	et	3	main
sellepärast	doc_213943984933_item	2271489	et	3	main
et	doc_213943984933_item	2271494	et	3	main
saavutada	doc_213943984933_item	2271500	et	3	main
midagi	doc_213943984933_item	2271501	et	4	main
tulevikus	doc_213943984933_item	2271502	et	4	main
see	doc_213943984933_item	2271509	et	3	main
närvipingeline	doc_213943984933_item	2271512	et	4	main
lõpetasin	doc_213943984933_item	2271516	et	3	main
õnnelik	doc_213943984933_item	2271523	et	3	main
saan	doc_213943984933_item	2271534	et	4	main
tallinnasse	doc_213943984933_item	2271540	et	3	main
oma	doc_213943984933_item	2271544	et	4	main
akademiasse	doc_213943984933_item	2271548	et	4	main
koosnesid	doc_213943984933_item	2271553	et	4	main
kahest	doc_213943984933_item	2271554	et	4	main
oma	doc_213943984933_item	2271559	et	4	main
esitlemine	doc_213943984933_item	2271561	et	4	main
vastuvõtukomisjonile	doc_213943984933_item	2271562	et	3	main
edukalt	doc_213943984933_item	2271565	et	4	main
eksamid	doc_213943984933_item	2271571	et	3	main
kompositsiooni	doc_213943984933_item	2271574	et	4	main
joonistamine	doc_213943984933_item	2271577	et	4	main
10	doc_213943984933_item	2271585	et	2	main
veel	doc_213943984933_item	2271591	et	4	main
selleks	doc_213943984933_item	2271624	et	4	main
sellepärast	doc_213943984933_item	2271628	et	3	main
saanud	doc_213943984933_item	2271636	et	4	main
pettunud	doc_213943984933_item	2271642	et	4	main
mul	doc_213943984933_item	2271644	et	3	main
türgis	doc_213943984932_item	2271168	et	4	main
andsin	doc_213943984932_item	2271170	et	3	main
oma	doc_213943984932_item	2271171	et	4	main
dokumendid	doc_213943984932_item	2271172	et	3	main
mõlematesse	doc_213943984932_item	2271173	et	3	main
mitu	doc_213943984932_item	2271176	et	4	main
mina	doc_213943984932_item	2271188	et	4	main
ümber	doc_213943984932_item	2271190	et	3	main
tasuta	doc_213943984932_item	2271209	et	4	main
võimaluse	doc_213943984932_item	2271211	et	3	main
kuid	doc_213943984932_item	2271216	et	4	main
juba	doc_213943984932_item	2271219	et	3	main
meeldib	doc_213943984932_item	2271238	et	3	main
inimene	doc_213943984932_item	2271243	et	3	main
saab	doc_213943984932_item	2271244	et	3	main
huvi	doc_213943984932_item	2271251	et	4	main
sessioon	doc_213943984932_item	2271259	et	3	main
õppimist	doc_213943984932_item	2271264	et	4	main
j	doc_213943984932_item	2271269	et	4	main
olen	doc_213943984933_item	2271277	et	3	main
olen	doc_213943984933_item	2271287	et	3	main
lasteaias	doc_213943984933_item	2271326	et	4	main
see	doc_213943984933_item	2271328	et	3	main
oli	doc_213943984933_item	2271329	et	3	main
aeg	doc_213943984933_item	2271333	et	3	main
kiigel	doc_213943984933_item	2271340	et	4	main
mängida	doc_213943984933_item	2271343	et	3	main
hüpata	doc_213943984933_item	2271345	et	4	main
läksin	doc_213943984933_item	2271352	et	3	main
esimesse	doc_213943984933_item	2271354	et	4	main
kiviõli	doc_213943984933_item	2271356	et	4	main
vene	doc_213943984933_item	2271357	et	4	main
klassini	doc_213943984933_item	2271367	et	3	main
meeldisid	doc_213943984933_item	2271373	et	4	main
tihti	doc_213943984933_item	2271387	et	3	main
ja	doc_213943984933_item	2271393	et	3	main
ja	doc_213943984933_item	2271401	et	3	main
hulga	doc_213943984933_item	2271403	et	4	main
sisse	doc_213943984933_item	2271423	et	4	main
jaoks	doc_213943984933_item	2271434	et	4	main
minu	doc_213943984933_item	2271443	et	3	main
koolis	doc_213943984933_item	2271452	et	4	main
aga	doc_213943984933_item	2271453	et	3	main
käisin	doc_213943984933_item	2271455	et	3	main
keele	doc_213943984933_item	2271457	et	4	main
3	doc_213943984933_item	2271473	et	2	main
aktiivse	doc_213943984933_item	2271483	et	3	main
elu	doc_213943984933_item	2271484	et	4	main
töö	doc_213943984933_item	2271496	et	4	main
aitavad	doc_213943984933_item	2271499	et	4	main
kaheteistkümnendas	doc_213943984933_item	2271504	et	4	main
klassis	doc_213943984933_item	2271505	et	3	main
tuli	doc_213943984933_item	2271506	et	4	main
sooritada	doc_213943984933_item	2271507	et	3	main
riigieksameid	doc_213943984933_item	2271508	et	3	main
väga	doc_213943984933_item	2271522	et	3	main
kõik	doc_213943984933_item	2271524	et	4	main
olid	doc_213943984933_item	2271526	et	4	main
avatud	doc_213943984933_item	2271529	et	4	main
et	doc_213943984933_item	2271532	et	3	main
ma	doc_213943984933_item	2271533	et	3	main
kergelt	doc_213943984933_item	2271536	et	4	main
ning	doc_213943984933_item	2271541	et	3	main
sisse	doc_213943984933_item	2271543	et	4	main
dokumentid	doc_213943984933_item	2271545	et	4	main
etapist	doc_213943984933_item	2271555	et	3	main
sain	doc_213943984933_item	2271566	et	3	main
ja	doc_213943984933_item	2271576	et	3	main
saanud	doc_213943984933_item	2271590	et	4	main
ma	doc_213943984932_item	2271231	et	3	main
filoloogia	doc_213943984932_item	2271233	et	4	main
mulle	doc_213943984932_item	2271236	et	4	main
väga	doc_213943984932_item	2271237	et	3	main
kui	doc_213943984932_item	2271242	et	3	main
mille	doc_213943984932_item	2271248	et	3	main
pool	doc_213943984932_item	2271253	et	4	main
möödas	doc_213943984932_item	2271256	et	3	main
praegu	doc_213943984932_item	2271262	et	3	main
sessiooni	doc_213943984932_item	2271266	et	4	main
kannatamatult	doc_213943984932_item	2271267	et	4	main
oodates	doc_213943984932_item	2271268	et	3	main
nimi	doc_213943984933_item	2271272	et	3	main
1983	doc_213943984933_item	2271281	et	2	main
ida-virumaal	doc_213943984933_item	2271283	et	4	main
4	doc_213943984933_item	2271292	et	2	main
inimest	doc_213943984933_item	2271293	et	3	main
ema	doc_213943984933_item	2271294	et	4	main
isa	doc_213943984933_item	2271295	et	4	main
mina	doc_213943984933_item	2271296	et	4	main
ja	doc_213943984933_item	2271297	et	3	main
noorem	doc_213943984933_item	2271298	et	4	main
vend	doc_213943984933_item	2271299	et	3	main
ema	doc_213943984933_item	2271300	et	4	main
töötab	doc_213943984933_item	2271301	et	3	main
aktsiaseltsis	doc_213943984933_item	2271302	et	3	main
eesti	doc_213943984933_item	2271303	et	4	main
raudtee	doc_213943984933_item	2271304	et	4	main
xxx	doc_213943984933_item	2271306	et	4	main
jaamakorraldajana	doc_213943984933_item	2271305	et	3	main
raudteejaamas	doc_213943984933_item	2271307	et	3	main
isa	doc_213943984933_item	2271308	et	4	main
töötab	doc_213943984933_item	2271309	et	3	main
aktsiaseltsis	doc_213943984933_item	2271310	et	3	main
xxx	doc_213943984933_item	2271311	et	4	main
operaatorina	doc_213943984933_item	2271312	et	3	main
vend	doc_213943984933_item	2271313	et	3	main
on	doc_213943984933_item	2271314	et	4	main
kaheksanda	doc_213943984933_item	2271315	et	3	main
klassi	doc_213943984933_item	2271316	et	4	main
õpilane	doc_213943984933_item	2271317	et	3	main
kiviõli	doc_213943984933_item	2271318	et	4	main
3	doc_213943984933_item	2271319	et	2	main
keskkoolis	doc_213943984933_item	2271320	et	4	main
ma	doc_213943984933_item	2271323	et	3	main
xxx	doc_213943984933_item	2271327	et	4	main
kõige	doc_213943984933_item	2271330	et	4	main
maalida	doc_213943984933_item	2271337	et	3	main
kiikuda	doc_213943984933_item	2271339	et	3	main
klassi	doc_213943984933_item	2271355	et	4	main
minu	doc_213943984933_item	2271359	et	3	main
õpetaja	doc_213943984933_item	2271361	et	4	main
klassijuhataja	doc_213943984933_item	2271364	et	4	main
kuni	doc_213943984933_item	2271365	et	3	main
meeldis	doc_213943984933_item	2271369	et	3	main
matemaatika	doc_213943984933_item	2271375	et	4	main
koolis	doc_213943984933_item	2271380	et	4	main
ma	doc_213943984933_item	2271381	et	3	main
olin	doc_213943984933_item	2271382	et	3	main
aktiivne	doc_213943984933_item	2271383	et	3	main
kooli	doc_213943984933_item	2271389	et	4	main
üritustes	doc_213943984933_item	2271390	et	4	main
osa	doc_213943984933_item	2271395	et	4	main
mulle	doc_213943984933_item	2271399	et	4	main
lõpetamist	doc_213943984933_item	2271408	et	4	main
ma	doc_213943984933_item	2271409	et	3	main
hakkasin	doc_213943984933_item	2271410	et	3	main
mõtlema	doc_213943984933_item	2271411	et	3	main
tulevasest	doc_213943984933_item	2271412	et	4	main
elukutsest	doc_213943984933_item	2271413	et	4	main
mulle	doc_213943984933_item	2271414	et	4	main
meeldis	doc_213943984933_item	2271415	et	3	main
arhitektuur	doc_213943984933_item	2271416	et	3	main
korterite	doc_213943984933_item	2271417	et	3	main
ja	doc_213943984933_item	2271418	et	3	main
majade	doc_213943984933_item	2271419	et	3	main
disain	doc_213943984933_item	2271420	et	3	main
otsustasin	doc_213943984933_item	2271422	et	3	main
akademiasse	doc_213943984933_item	2271427	et	4	main
valmistama	doc_213943984933_item	2271430	et	3	main
töid	doc_213943984933_item	2271431	et	3	main
kiviõli	doc_213943984933_item	2271438	et	4	main
oli	doc_213943984933_item	2271446	et	3	main
tihe	doc_213943984933_item	2271448	et	3	main
kursustel	doc_213943984933_item	2271458	et	3	main
ja	doc_213943984933_item	2271459	et	3	main
joonistamas	doc_213943984933_item	2271460	et	3	main
isegi	doc_213943984933_item	2271461	et	4	main
sellisesse	doc_213943984933_item	2271462	et	4	main
grafikusse	doc_213943984933_item	2271463	et	4	main
ma	doc_213943984933_item	2271464	et	3	main
suutsin	doc_213943984933_item	2271465	et	3	main
sisse	doc_213943984933_item	2271466	et	4	main
kirjutada	doc_213943984933_item	2271467	et	3	main
aeroobika	doc_213943984933_item	2271469	et	4	main
mulle	doc_213943984933_item	2271477	et	4	main
valida	doc_213943984933_item	2271480	et	3	main
ma	doc_213943984933_item	2271491	et	3	main
kindel	doc_213943984933_item	2271493	et	3	main
ja	doc_213943984933_item	2271497	et	3	main
elus	doc_213943984933_item	2271503	et	4	main
oli	doc_213943984933_item	2271510	et	3	main
aeg	doc_213943984933_item	2271513	et	3	main
üsna	doc_213943984933_item	2271517	et	3	main
kuldmedaliga	doc_213943984933_item	2271519	et	3	main
pakutud	doc_213943984933_item	2271479	et	4	main
ma	doc_213943984933_item	2271486	et	3	main
et	doc_213943984933_item	2271490	et	3	main
olen	doc_213943984933_item	2271492	et	3	main
kannatus	doc_213943984933_item	2271498	et	4	main
ma	doc_213943984933_item	2271515	et	3	main
edukalt	doc_213943984933_item	2271518	et	4	main
jaoks	doc_213943984933_item	2271528	et	4	main
mulle	doc_213943984933_item	2271530	et	4	main
tundis	doc_213943984933_item	2271531	et	3	main
ma	doc_213943984933_item	2271538	et	3	main
sõitsin	doc_213943984933_item	2271539	et	3	main
kunsti	doc_213943984933_item	2271547	et	4	main
linna	doc_213943984933_item	2271549	et	4	main
etapp	doc_213943984933_item	2271557	et	3	main
tööde	doc_213943984933_item	2271560	et	3	main
läbi	doc_213943984933_item	2271567	et	4	main
joonestamine	doc_213943984933_item	2271573	et	4	main
koostamine	doc_213943984933_item	2271575	et	4	main
kuna	doc_213943984933_item	2271578	et	3	main
vastu	doc_213943984933_item	2271583	et	3	main
mina	doc_213943984933_item	2271587	et	4	main
vajalikke	doc_213943984933_item	2271622	et	3	main
punkte	doc_213943984933_item	2271623	et	3	main
et	doc_213943984933_item	2271625	et	3	main
konkursis	doc_213943984933_item	2271627	et	3	main
ma	doc_213943984933_item	2271629	et	3	main
ebaõnneliku	doc_213943984933_item	2271638	et	3	main
sisseastumist	doc_213943984933_item	2271639	et	3	main
väga	doc_213943984933_item	2271641	et	3	main
ja	doc_213943984933_item	2271648	et	3	main
häbi	doc_213943984933_item	2271650	et	4	main
aga	doc_213943984933_item	2271653	et	3	main
minul	doc_213943984933_item	2271655	et	3	main
toredad	doc_213943984933_item	2271657	et	3	main
nad	doc_213943984933_item	2271659	et	3	main
ema	doc_213943984933_item	2271668	et	4	main
ning	doc_213943984933_item	2271676	et	3	main
aastal	doc_213943984933_item	2271678	et	3	main
sisse	doc_213943984933_item	2271681	et	4	main
käima	doc_213943984933_item	2271689	et	4	main
ma	doc_213943984933_item	2271704	et	3	main
teed	doc_213943984933_item	2271525	et	4	main
minu	doc_213943984933_item	2271527	et	3	main
esimene	doc_213943984933_item	2271556	et	3	main
oli	doc_213943984933_item	2271558	et	3	main
mille	doc_213943984933_item	2271563	et	3	main
teisel	doc_213943984933_item	2271568	et	4	main
olid	doc_213943984933_item	2271570	et	4	main
oli	doc_213943984933_item	2271580	et	3	main
võeti	doc_213943984933_item	2271582	et	3	main
ainult	doc_213943984933_item	2271584	et	4	main
inimest	doc_213943984933_item	2271586	et	3	main
sisse	doc_213943984933_item	2271588	et	4	main
ma	doc_213943984933_item	2271592	et	3	main
astuda	doc_213943984933_item	2271594	et	3	main
üritasin	doc_213943984933_item	2271593	et	3	main
sisse	doc_213943984933_item	2271595	et	4	main
ka	doc_213943984933_item	2271596	et	3	main
tallinna	doc_213943984933_item	2271597	et	4	main
tehnika	doc_213943984933_item	2271598	et	4	main
kõrgkooli	doc_213943984933_item	2271599	et	4	main
arhitektuuri	doc_213943984933_item	2271600	et	4	main
erialale	doc_213943984933_item	2271601	et	3	main
kõrgkoolis	doc_213943984933_item	2271602	et	4	main
pidin	doc_213943984933_item	2271603	et	3	main
sooritama	doc_213943984933_item	2271604	et	3	main
kaks	doc_213943984933_item	2271605	et	3	main
eksamit	doc_213943984933_item	2271606	et	3	main
joonistamises	doc_213943984933_item	2271607	et	4	main
ja	doc_213943984933_item	2271608	et	3	main
kompositsioonis	doc_213943984933_item	2271609	et	4	main
kuigi	doc_213943984933_item	2271610	et	3	main
joonistamise	doc_213943984933_item	2271611	et	4	main
eksam	doc_213943984933_item	2271612	et	3	main
mul	doc_213943984933_item	2271613	et	3	main
läks	doc_213943984933_item	2271614	et	3	main
hästi	doc_213943984933_item	2271615	et	3	main
kompositsiooni	doc_213943984933_item	2271616	et	4	main
tegemisel	doc_213943984933_item	2271617	et	4	main
ma	doc_213943984933_item	2271618	et	3	main
ei	doc_213943984933_item	2271619	et	4	main
saanud	doc_213943984933_item	2271620	et	4	main
osaleda	doc_213943984933_item	2271626	et	3	main
ei	doc_213943984933_item	2271635	et	4	main
kõigest	doc_213943984933_item	2271643	et	4	main
vanemad	doc_213943984933_item	2271658	et	4	main
mind	doc_213943984933_item	2271662	et	4	main
püüda	doc_213943984933_item	2271679	et	3	main
uuesti	doc_213943984933_item	2271680	et	3	main
kursustel	doc_213943984933_item	2271693	et	3	main
et	doc_213943984933_item	2271697	et	3	main
ei	doc_213943984933_item	2271701	et	4	main
palju	doc_213943984933_item	2271706	et	4	main
olin	doc_213943984933_item	2271521	et	3	main
kõigiga	doc_213943984933_item	2271535	et	4	main
hakkama	doc_213943984933_item	2271537	et	3	main
andsin	doc_213943984933_item	2271542	et	3	main
tallinna	doc_213943984933_item	2271546	et	4	main
arhitektuuri	doc_213943984933_item	2271550	et	4	main
erialale	doc_213943984933_item	2271551	et	3	main
sisseastumiskatsed	doc_213943984933_item	2271552	et	3	main
ma	doc_213943984933_item	2271564	et	3	main
etapil	doc_213943984933_item	2271569	et	3	main
maalimine	doc_213943984933_item	2271572	et	4	main
sisseastumiskonkurs	doc_213943984933_item	2271579	et	4	main
suur	doc_213943984933_item	2271581	et	3	main
ei	doc_213943984933_item	2271589	et	4	main
minimaalselt	doc_213943984933_item	2271621	et	4	main
langesin	doc_213943984933_item	2271630	et	3	main
pingereast	doc_213943984933_item	2271631	et	4	main
sisse	doc_213943984933_item	2271634	et	4	main
olin	doc_213943984933_item	2271640	et	3	main
teiste	doc_213943984933_item	2271651	et	4	main
õnneks	doc_213943984933_item	2271654	et	4	main
aidata	doc_213943984933_item	2271664	et	4	main
astuda	doc_213943984933_item	2271682	et	3	main
ülikooli	doc_213943984933_item	2271683	et	4	main
laupäeviti	doc_213943984933_item	2271687	et	4	main
ettevalmistus	doc_213943984933_item	2271692	et	3	main
arhitektuuri	doc_213943984933_item	2271694	et	4	main
otsustasin	doc_213943984933_item	2271696	et	3	main
ma	doc_213943984933_item	2271700	et	3	main
anna	doc_213943984933_item	2271702	et	4	main
jõudsin	doc_213943984933_item	2271710	et	3	main
järeldusele	doc_213943984933_item	2271711	et	4	main
et	doc_213943984933_item	2271712	et	3	main
elus	doc_213943984933_item	2271723	et	4	main
palju	doc_213943984933_item	2271725	et	4	main
elukutseid	doc_213943984933_item	2271727	et	3	main
proovida	doc_213943984933_item	2271730	et	3	main
veel	doc_213943984933_item	2271732	et	4	main
kaaludes	doc_213943984933_item	2271733	et	4	main
kogemus	doc_213943984933_item	2271741	et	3	main
enda	doc_213943984933_item	2271744	et	4	main
veadel	doc_213943984933_item	2271746	et	4	main
inimene	doc_213943984933_item	2271747	et	3	main
õpib	doc_213943984933_item	2271748	et	3	main
möödus	doc_213943984933_item	2271750	et	3	main
algas	doc_213943984933_item	2271759	et	3	main
abiturientide	doc_213943984933_item	2271760	et	3	main
tehnika	doc_213943984933_item	2271780	et	4	main
ülikooli	doc_213943984933_item	2271785	et	4	main
suure	doc_213943984933_item	2271805	et	3	main
valiku	doc_213943984933_item	2271806	et	3	main
valik	doc_213943984933_item	2271809	et	3	main
tallinna	doc_213943984933_item	2271811	et	4	main
ülikooli	doc_213943984933_item	2271813	et	4	main
olen	doc_213943984933_item	2271817	et	3	main
ülikoolis	doc_213943984933_item	2271823	et	4	main
toredad	doc_213943984933_item	2271831	et	3	main
joonistamine	doc_213943984933_item	2271833	et	4	main
last	doc_213943984933_item	2271834	et	4	main
jäeb	doc_213943984933_item	2271835	et	4	main
hobiks	doc_213943984933_item	2271837	et	3	main
olen	doc_213943984934_item	2271840	et	3	main
tallinnas	doc_213943984934_item	2271844	et	4	main
ema	doc_213943984934_item	2271846	et	4	main
hindasid	doc_213943984934_item	2271851	et	4	main
inimeste	doc_213943984934_item	2271854	et	3	main
armastuse	doc_213943984934_item	2271855	et	4	main
saanud	doc_213943984934_item	2271859	et	4	main
suudan	doc_213943984934_item	2271866	et	3	main
ei	doc_213943984934_item	2271893	et	4	main
pettunud	doc_213943984934_item	2271894	et	4	main
saada	doc_213943984934_item	2271898	et	4	main
2002	doc_213943984934_item	2271900	et	2	main
füüsika	doc_213943984934_item	2271907	et	4	main
kõrvalainega	doc_213943984934_item	2271908	et	4	main
erialale	doc_213943984934_item	2271909	et	3	main
ma	doc_213943984934_item	2271910	et	3	main
väga	doc_213943984934_item	2271912	et	3	main
oli	doc_213943984934_item	2271916	et	3	main
kus	doc_213943984934_item	2271923	et	3	main
see	doc_213943984934_item	2271926	et	3	main
välja	doc_213943984933_item	2271632	et	4	main
ja	doc_213943984933_item	2271633	et	3	main
peale	doc_213943984933_item	2271637	et	4	main
oli	doc_213943984933_item	2271645	et	3	main
nutumaik	doc_213943984933_item	2271646	et	3	main
suus	doc_213943984933_item	2271647	et	3	main
oli	doc_213943984933_item	2271649	et	3	main
on	doc_213943984933_item	2271656	et	4	main
ja	doc_213943984933_item	2271663	et	3	main
elada	doc_213943984933_item	2271667	et	3	main
soovitas	doc_213943984933_item	2271669	et	3	main
sisse	doc_213943984933_item	2271671	et	4	main
infotehnoloogiat	doc_213943984933_item	2271674	et	3	main
erialale	doc_213943984933_item	2271695	et	3	main
juhul	doc_213943984933_item	2271699	et	3	main
alla	doc_213943984933_item	2271703	et	3	main
võib	doc_213943984933_item	2271713	et	3	main
olla	doc_213943984933_item	2271714	et	3	main
arhitektuur	doc_213943984933_item	2271715	et	3	main
kutsumus	doc_213943984933_item	2271721	et	3	main
midagi	doc_213943984933_item	2271731	et	4	main
kõik	doc_213943984933_item	2271734	et	4	main
tegin	doc_213943984933_item	2271737	et	3	main
et	doc_213943984933_item	2271739	et	3	main
tehtud	doc_213943984933_item	2271745	et	4	main
küllaldki	doc_213943984933_item	2271751	et	4	main
ruttu	doc_213943984933_item	2271752	et	4	main
oli	doc_213943984933_item	2271754	et	3	main
ülikoolides	doc_213943984933_item	2271758	et	3	main
ülikooli	doc_213943984933_item	2271778	et	4	main
tallinna	doc_213943984933_item	2271779	et	4	main
erialale	doc_213943984933_item	2271787	et	3	main
informaatika	doc_213943984933_item	2271798	et	4	main
erialale	doc_213943984933_item	2271799	et	3	main
õnnelik	doc_213943984933_item	2271801	et	3	main
ma	doc_213943984933_item	2271803	et	3	main
pedagoogika	doc_213943984933_item	2271812	et	4	main
rahulik	doc_213943984933_item	2271818	et	3	main
mulle	doc_213943984933_item	2271819	et	4	main
ees	doc_213943984933_item	2271652	et	4	main
suudsid	doc_213943984933_item	2271660	et	4	main
lohustada	doc_213943984933_item	2271661	et	4	main
sellest	doc_213943984933_item	2271665	et	4	main
üle	doc_213943984933_item	2271666	et	3	main
astuda	doc_213943984933_item	2271670	et	3	main
kohtla-järve	doc_213943984933_item	2271672	et	4	main
polütehnikumisse	doc_213943984933_item	2271673	et	4	main
õppima	doc_213943984933_item	2271675	et	3	main
järgmisel	doc_213943984933_item	2271677	et	3	main
nii	doc_213943984933_item	2271684	et	3	main
ma	doc_213943984933_item	2271685	et	3	main
tegingi	doc_213943984933_item	2271686	et	3	main
hakkasin	doc_213943984933_item	2271688	et	3	main
tallinnas	doc_213943984933_item	2271690	et	4	main
tehnikakõrgkoolis	doc_213943984933_item	2271691	et	4	main
mingil	doc_213943984933_item	2271698	et	4	main
mõtlesin	doc_213943984933_item	2271705	et	3	main
elukutse	doc_213943984933_item	2271707	et	4	main
ning	doc_213943984933_item	2271709	et	3	main
joonistamine	doc_213943984933_item	2271717	et	4	main
kuna	doc_213943984933_item	2271722	et	3	main
teisi	doc_213943984933_item	2271726	et	4	main
tasub	doc_213943984933_item	2271729	et	3	main
vastu	doc_213943984933_item	2271736	et	3	main
kokkuvõtte	doc_213943984933_item	2271738	et	4	main
negatiivne	doc_213943984933_item	2271740	et	3	main
nelja	doc_213943984933_item	2271777	et	4	main
ülikooli	doc_213943984933_item	2271781	et	4	main
informaatika	doc_213943984933_item	2271782	et	4	main
erialale	doc_213943984933_item	2271783	et	3	main
tartu	doc_213943984933_item	2271788	et	4	main
ülikooli	doc_213943984933_item	2271790	et	4	main
erialale	doc_213943984933_item	2271793	et	3	main
pedagoogika	doc_213943984933_item	2271796	et	4	main
ülikooli	doc_213943984933_item	2271797	et	4	main
meeldib	doc_213943984933_item	2271820	et	3	main
siin	doc_213943984933_item	2271824	et	4	main
targad	doc_213943984933_item	2271826	et	3	main
õpetajad	doc_213943984933_item	2271832	et	4	main
minu	doc_213943984933_item	2271836	et	3	main
minu	doc_213943984934_item	2271845	et	3	main
töötas	doc_213943984934_item	2271847	et	3	main
ja	doc_213943984934_item	2271853	et	3	main
ise	doc_213943984934_item	2271868	et	4	main
sest	doc_213943984934_item	2271896	et	4	main
tahtsin	doc_213943984934_item	2271897	et	3	main
kõrgharidust	doc_213943984934_item	2271899	et	4	main
olin	doc_213943984934_item	2271911	et	3	main
soov	doc_213943984934_item	2271919	et	3	main
paralleelselt	doc_213943984934_item	2271920	et	4	main
töötasin	doc_213943984934_item	2271921	et	3	main
mulle	doc_213943984934_item	2271928	et	4	main
tahan	doc_213943984934_item	2271942	et	3	main
oma	doc_213943984934_item	2271944	et	4	main
praegu	doc_213943984934_item	2271946	et	3	main
ma	doc_213943984934_item	2271958	et	3	main
oma	doc_213943984934_item	2271961	et	4	main
essee	doc_213943984935_item	2271963	et	4	main
venemaal	doc_213943984935_item	2271969	et	4	main
käisin	doc_213943984935_item	2272001	et	3	main
palju	doc_213943984935_item	2272012	et	4	main
õmblemine	doc_213943984935_item	2272020	et	4	main
käisin	doc_213943984935_item	2272022	et	3	main
tänaseni	doc_213943984935_item	2272027	et	4	main
mulle	doc_213943984935_item	2272028	et	4	main
teha	doc_213943984935_item	2272030	et	3	main
ise	doc_213943984935_item	2272032	et	4	main
postkaarte	doc_213943984935_item	2272033	et	4	main
kingitused	doc_213943984935_item	2272038	et	4	main
olid	doc_213943984935_item	2272043	et	4	main
üheksateist	doc_213943984935_item	2272047	et	4	main
aastat	doc_213943984935_item	2272048	et	3	main
elan	doc_213943984935_item	2272049	et	3	main
oma	doc_213943984935_item	2272050	et	4	main
majas	doc_213943984935_item	2272051	et	3	main
see	doc_213943984935_item	2272052	et	3	main
meeldib	doc_213943984935_item	2272053	et	3	main
loobuma	doc_213943984935_item	2272065	et	3	main
hakkasin	doc_213943984935_item	2272072	et	3	main
mulle	doc_213943984935_item	2272081	et	4	main
valikust	doc_213943984933_item	2271708	et	4	main
ja	doc_213943984933_item	2271716	et	3	main
ei	doc_213943984933_item	2271718	et	4	main
ole	doc_213943984933_item	2271719	et	4	main
minu	doc_213943984933_item	2271720	et	3	main
mul	doc_213943984933_item	2271728	et	3	main
kasulik	doc_213943984933_item	2271743	et	3	main
suvi	doc_213943984933_item	2271755	et	3	main
ja	doc_213943984933_item	2271757	et	3	main
sisse	doc_213943984933_item	2271776	et	4	main
tartu	doc_213943984933_item	2271784	et	4	main
planeerimise	doc_213943984933_item	2271792	et	4	main
ja	doc_213943984933_item	2271794	et	3	main
olin	doc_213943984933_item	2271800	et	3	main
nüüd	doc_213943984933_item	2271802	et	4	main
minu	doc_213943984933_item	2271808	et	3	main
langes	doc_213943984933_item	2271810	et	4	main
täna	doc_213943984933_item	2271815	et	4	main
ma	doc_213943984933_item	2271816	et	3	main
õppida	doc_213943984933_item	2271821	et	3	main
head	doc_213943984933_item	2271828	et	4	main
essee	doc_213943984934_item	2271838	et	4	main
mina	doc_213943984934_item	2271839	et	4	main
sündinud	doc_213943984934_item	2271841	et	4	main
eestis	doc_213943984934_item	2271842	et	3	main
pealinnas	doc_213943984934_item	2271843	et	4	main
pärast	doc_213943984934_item	2271856	et	4	main
temalt	doc_213943984934_item	2271857	et	3	main
olengi	doc_213943984934_item	2271858	et	4	main
oskan	doc_213943984934_item	2271864	et	3	main
ka	doc_213943984934_item	2271867	et	3	main
sain	doc_213943984934_item	2271902	et	3	main
pedagoogika	doc_213943984934_item	2271905	et	4	main
õnnelik	doc_213943984934_item	2271913	et	3	main
on	doc_213943984933_item	2271724	et	4	main
ja	doc_213943984933_item	2271735	et	3	main
on	doc_213943984933_item	2271742	et	4	main
aasta	doc_213943984933_item	2271749	et	4	main
peagi	doc_213943984933_item	2271753	et	4	main
käes	doc_213943984933_item	2271756	et	4	main
vastuvõtt	doc_213943984933_item	2271761	et	3	main
ma	doc_213943984933_item	2271762	et	3	main
andsin	doc_213943984933_item	2271763	et	3	main
sisse	doc_213943984933_item	2271764	et	4	main
dokumendid	doc_213943984933_item	2271765	et	3	main
kohe	doc_213943984933_item	2271766	et	4	main
mitmesse	doc_213943984933_item	2271767	et	4	main
ülikoolisse	doc_213943984933_item	2271768	et	4	main
2004	doc_213943984933_item	2271769	et	2	main
aasta	doc_213943984933_item	2271770	et	4	main
oli	doc_213943984933_item	2271771	et	3	main
minu	doc_213943984933_item	2271772	et	3	main
aasta	doc_213943984933_item	2271773	et	4	main
ma	doc_213943984933_item	2271774	et	3	main
sain	doc_213943984933_item	2271775	et	3	main
infotehnoloogia	doc_213943984933_item	2271786	et	4	main
põllumajandus	doc_213943984933_item	2271789	et	3	main
kinnisvara	doc_213943984933_item	2271791	et	4	main
tallinna	doc_213943984933_item	2271795	et	4	main
seisin	doc_213943984933_item	2271804	et	3	main
ees	doc_213943984933_item	2271807	et	4	main
peale	doc_213943984933_item	2271814	et	4	main
on	doc_213943984933_item	2271825	et	4	main
kompetentsed	doc_213943984933_item	2271827	et	3	main
lasteaia	doc_213943984934_item	2271848	et	4	main
kasvatajana	doc_213943984934_item	2271849	et	4	main
teda	doc_213943984934_item	2271850	et	4	main
nii	doc_213943984934_item	2271860	et	3	main
armastust	doc_213943984934_item	2271862	et	4	main
et	doc_213943984934_item	2271863	et	3	main
ja	doc_213943984934_item	2271865	et	3	main
selles	doc_213943984934_item	2271895	et	4	main
sisse	doc_213943984934_item	2271903	et	4	main
tallinna	doc_213943984934_item	2271904	et	4	main
ülikooli	doc_213943984934_item	2271906	et	4	main
see	doc_213943984934_item	2271915	et	3	main
salajasim	doc_213943984934_item	2271918	et	4	main
töö	doc_213943984934_item	2271927	et	4	main
meeldis	doc_213943984934_item	2271930	et	3	main
tegelda	doc_213943984934_item	2271938	et	4	main
ja	doc_213943984934_item	2271940	et	3	main
tulevikus	doc_213943984934_item	2271941	et	4	main
firmat	doc_213943984934_item	2271945	et	3	main
lõpetan	doc_213943984934_item	2271947	et	3	main
kursust	doc_213943984934_item	2271949	et	3	main
kaitsta	doc_213943984934_item	2271953	et	4	main
tööd	doc_213943984934_item	2271955	et	4	main
kuigi	doc_213943984934_item	2271956	et	3	main
lõpeta	doc_213943984934_item	2271960	et	4	main
ma	doc_213943984935_item	2271964	et	3	main
aga	doc_213943984935_item	2272005	et	3	main
jätsin	doc_213943984935_item	2272006	et	3	main
kergejõustiku	doc_213943984935_item	2272007	et	3	main
oli	doc_213943984935_item	2272011	et	3	main
kaasaegsedtansud	doc_213943984935_item	2272015	et	4	main
pärast	doc_213943984935_item	2272021	et	4	main
õmblemiskursustel	doc_213943984935_item	2272023	et	4	main
see	doc_213943984935_item	2272024	et	3	main
parimad	doc_213943984935_item	2272037	et	4	main
ise	doc_213943984935_item	2272041	et	4	main
ja	doc_213943984935_item	2272045	et	3	main
ümber	doc_213943984935_item	2272056	et	3	main
meil	doc_213943984935_item	2272059	et	4	main
me	doc_213943984935_item	2272062	et	4	main
põhikoolis	doc_213943984935_item	2272071	et	4	main
kahjuks	doc_213943984935_item	2272074	et	4	main
selleks	doc_213943984935_item	2272078	et	4	main
aega	doc_213943984935_item	2272079	et	4	main
käin	doc_213943984935_item	2272085	et	3	main
seda	doc_213943984935_item	2272089	et	3	main
unistusin	doc_213943984935_item	2272091	et	4	main
oma	doc_213943984936_item	2272121	et	4	main
pedagoogika	doc_213943984933_item	2271822	et	4	main
elurõõmsad	doc_213943984933_item	2271829	et	3	main
avalikud	doc_213943984933_item	2271830	et	3	main
tööoskuse	doc_213943984934_item	2271852	et	3	main
palju	doc_213943984934_item	2271861	et	4	main
teisi	doc_213943984934_item	2271869	et	4	main
inimesi	doc_213943984934_item	2271870	et	4	main
lapsepõlvest	doc_213943984934_item	2271872	et	4	main
armastada	doc_213943984934_item	2271871	et	3	main
saadik	doc_213943984934_item	2271873	et	4	main
olen	doc_213943984934_item	2271874	et	3	main
ma	doc_213943984934_item	2271875	et	3	main
tahtnud	doc_213943984934_item	2271876	et	4	main
õppida	doc_213943984934_item	2271877	et	3	main
sellepärast	doc_213943984934_item	2271878	et	3	main
otsustasingi	doc_213943984934_item	2271879	et	3	main
pärast	doc_213943984934_item	2271880	et	4	main
tallinna	doc_213943984934_item	2271881	et	4	main
pae	doc_213943984934_item	2271882	et	3	main
gümnaasiumi	doc_213943984934_item	2271883	et	4	main
lõpetamist	doc_213943984934_item	2271884	et	4	main
minna	doc_213943984934_item	2271885	et	3	main
tallinna	doc_213943984934_item	2271886	et	4	main
majanduskooli	doc_213943984934_item	2271887	et	4	main
kuid	doc_213943984934_item	2271888	et	4	main
sisse	doc_213943984934_item	2271889	et	4	main
ei	doc_213943984934_item	2271890	et	4	main
saanud	doc_213943984934_item	2271891	et	4	main
ma	doc_213943984934_item	2271892	et	3	main
aastal	doc_213943984934_item	2271901	et	3	main
sest	doc_213943984934_item	2271914	et	4	main
minu	doc_213943984934_item	2271917	et	3	main
firmas	doc_213943984934_item	2271922	et	3	main
kudusin	doc_213943984934_item	2271924	et	3	main
kampsunit	doc_213943984934_item	2271925	et	3	main
vähe	doc_213943984934_item	2271934	et	3	main
kudumisega	doc_213943984934_item	2271939	et	4	main
ja	doc_213943984934_item	2271951	et	3	main
sündinud	doc_213943984935_item	2271966	et	4	main
aastal	doc_213943984935_item	2271968	et	3	main
gümnaasiumi	doc_213943984935_item	2271993	et	4	main
õpisin	doc_213943984935_item	2271995	et	4	main
keelt	doc_213943984935_item	2271997	et	4	main
aastasest	doc_213943984935_item	2272000	et	4	main
trennis	doc_213943984935_item	2272003	et	3	main
pärast	doc_213943984935_item	2272010	et	4	main
pehmete	doc_213943984935_item	2272018	et	3	main
meeldib	doc_213943984935_item	2272029	et	3	main
kingitusi	doc_213943984935_item	2272035	et	4	main
maja	doc_213943984935_item	2272057	et	4	main
sest	doc_213943984935_item	2272066	et	4	main
ta	doc_213943984935_item	2272067	et	4	main
käima	doc_213943984935_item	2272073	et	4	main
mul	doc_213943984935_item	2272075	et	3	main
praegu	doc_213943984935_item	2272077	et	3	main
õpetajaks	doc_213943984935_item	2272093	et	4	main
sai	doc_213943984936_item	2272124	et	4	main
kui	doc_213943984936_item	2272127	et	3	main
sündisin	doc_213943984936_item	2272129	et	3	main
ma	doc_213943984936_item	2272139	et	3	main
tahtsin	doc_213943984936_item	2272149	et	3	main
viimased	doc_213943984936_item	2272155	et	3	main
ehk	doc_213943984936_item	2272158	et	3	main
ema	doc_213943984936_item	2272160	et	4	main
sündmus	doc_213943984936_item	2272165	et	3	main
minu	doc_213943984936_item	2272174	et	3	main
väga	doc_213943984936_item	2272184	et	3	main
veel	doc_213943984936_item	2272192	et	4	main
sissesaamine	doc_213943984936_item	2272196	et	4	main
pedagoogikaülikooli	doc_213943984936_item	2272198	et	4	main
siin	doc_213943984936_item	2272199	et	4	main
avanesid	doc_213943984936_item	2272200	et	4	main
teed	doc_213943984936_item	2272203	et	4	main
ootasid	doc_213943984936_item	2272207	et	4	main
palju	doc_213943984936_item	2272215	et	4	main
kuid	doc_213943984934_item	2271931	et	4	main
oli	doc_213943984934_item	2271933	et	3	main
aga	doc_213943984934_item	2271935	et	3	main
armastan	doc_213943984934_item	2271937	et	3	main
luua	doc_213943984934_item	2271943	et	4	main
ei	doc_213943984934_item	2271959	et	4	main
õppimist	doc_213943984934_item	2271962	et	4	main
1984	doc_213943984935_item	2271967	et	2	main
me	doc_213943984935_item	2271970	et	4	main
tulime	doc_213943984935_item	2271971	et	3	main
eestisse	doc_213943984935_item	2271972	et	4	main
kui	doc_213943984935_item	2271974	et	3	main
enne	doc_213943984935_item	2271973	et	4	main
ma	doc_213943984935_item	2271975	et	3	main
olin	doc_213943984935_item	2271976	et	3	main
aastaseks	doc_213943984935_item	2271977	et	4	main
saanud	doc_213943984935_item	2271978	et	4	main
olen	doc_213943984935_item	2271979	et	3	main
kasvanud	doc_213943984935_item	2271980	et	4	main
ja	doc_213943984935_item	2271981	et	3	main
koolis	doc_213943984935_item	2271982	et	4	main
käinud	doc_213943984935_item	2271983	et	4	main
tallinnas	doc_213943984935_item	2271984	et	4	main
ma	doc_213943984935_item	2271985	et	3	main
õpisin	doc_213943984935_item	2271986	et	4	main
ehte	doc_213943984935_item	2271987	et	3	main
humanitaar	doc_213943984935_item	2271988	et	4	main
gümnaasiumis	doc_213943984935_item	2271989	et	3	main
esimest	doc_213943984935_item	2271990	et	4	main
klassist	doc_213943984935_item	2271991	et	3	main
väga	doc_213943984934_item	2271929	et	3	main
tellimusi	doc_213943984934_item	2271932	et	3	main
ma	doc_213943984934_item	2271936	et	3	main
kolmandat	doc_213943984934_item	2271948	et	3	main
kirjutan	doc_213943984934_item	2271950	et	3	main
kavatsen	doc_213943984934_item	2271952	et	3	main
bakalaurest	doc_213943984934_item	2271954	et	4	main
sellega	doc_213943984934_item	2271957	et	3	main
olen	doc_213943984935_item	2271965	et	3	main
prantsuse	doc_213943984935_item	2271996	et	3	main
alates	doc_213943984935_item	2271998	et	3	main
trenni	doc_213943984935_item	2272008	et	4	main
pooleli	doc_213943984935_item	2272009	et	3	main
joonistamine	doc_213943984935_item	2272017	et	4	main
aitab	doc_213943984935_item	2272025	et	3	main
mind	doc_213943984935_item	2272026	et	4	main
kõige	doc_213943984935_item	2272036	et	4	main
ma	doc_213943984935_item	2272040	et	3	main
kaisukaru	doc_213943984935_item	2272044	et	4	main
mulle	doc_213943984935_item	2272054	et	4	main
pidime	doc_213943984935_item	2272063	et	3	main
temast	doc_213943984935_item	2272064	et	3	main
pole	doc_213943984935_item	2272076	et	3	main
kuid	doc_213943984935_item	2272080	et	4	main
meeldib	doc_213943984935_item	2272083	et	3	main
matemaatika	doc_213943984935_item	2272092	et	4	main
elust	doc_213943984936_item	2272122	et	3	main
esimene	doc_213943984936_item	2272135	et	3	main
kuulnud	doc_213943984936_item	2272154	et	4	main
oli	doc_213943984936_item	2272167	et	3	main
oli	doc_213943984936_item	2272173	et	3	main
kindlasti	doc_213943984936_item	2272180	et	3	main
jaoks	doc_213943984936_item	2272183	et	4	main
kolmas	doc_213943984936_item	2272190	et	3	main
uued	doc_213943984936_item	2272202	et	3	main
juhtub	doc_213943984936_item	2272213	et	3	main
püüan	doc_213943984936_item	2272221	et	3	main
unustan	doc_213943984936_item	2272225	et	3	main
meenutan	doc_213943984936_item	2272230	et	3	main
ise	doc_213943984936_item	2272245	et	4	main
olen	doc_213943984936_item	2272246	et	3	main
väga	doc_213943984936_item	2272247	et	3	main
minu	doc_213943984937_item	2272283	et	3	main
on	doc_213943984937_item	2272292	et	4	main
mõlemad	doc_213943984937_item	2272293	et	3	main
elasid	doc_213943984937_item	2272309	et	4	main
tallinna	doc_213943984937_item	2272315	et	4	main
ma	doc_213943984937_item	2272325	et	3	main
klassi	doc_213943984937_item	2272334	et	4	main
astusin	doc_213943984937_item	2272337	et	3	main
filoloogia	doc_213943984937_item	2272342	et	4	main
bakalauruse	doc_213943984937_item	2272377	et	4	main
negatiivsed	doc_213943984937_item	2272384	et	3	main
on	doc_213943984937_item	2272386	et	4	main
minu	doc_213943984937_item	2272388	et	3	main
esimene	doc_213943984937_item	2272401	et	3	main
ka	doc_213943984937_item	2272408	et	3	main
külg	doc_213943984937_item	2272410	et	3	main
vana	doc_213943984937_item	2272425	et	4	main
teeb	doc_213943984937_item	2272427	et	3	main
kolmandaks	doc_213943984937_item	2272436	et	4	main
sest	doc_213943984937_item	2272440	et	4	main
kaotasin	doc_213943984937_item	2272442	et	3	main
ajaks	doc_213943984937_item	2272446	et	4	main
minu	doc_213943984937_item	2272447	et	3	main
on	doc_213943984937_item	2272453	et	4	main
kassi	doc_213943984937_item	2272456	et	4	main
ma	doc_213943984937_item	2272459	et	3	main
teda	doc_213943984937_item	2272461	et	4	main
juhtus	doc_213943984937_item	2272464	et	3	main
seda	doc_213943984937_item	2272471	et	3	main
et	doc_213943984937_item	2272472	et	3	main
asjal	doc_213943984937_item	2272474	et	3	main
positiivne	doc_213943984937_item	2272477	et	3	main
ka	doc_213943984937_item	2272479	et	3	main
astumine	doc_213943984937_item	2272484	et	4	main
prantsuse	doc_213943984938_item	2272526	et	3	main
seal	doc_213943984938_item	2272529	et	4	main
osa	doc_213943984938_item	2272538	et	4	main
prantsuse	doc_213943984938_item	2272539	et	3	main
loengutel	doc_213943984938_item	2272541	et	4	main
kultuuri	doc_213943984938_item	2272543	et	4	main
kuni	doc_213943984935_item	2271992	et	3	main
lõpuni	doc_213943984935_item	2271994	et	3	main
kuue	doc_213943984935_item	2271999	et	4	main
kergejõustiku	doc_213943984935_item	2272002	et	3	main
kahjuks	doc_213943984935_item	2272004	et	4	main
erinevaid	doc_213943984935_item	2272013	et	4	main
kunstiringe	doc_213943984935_item	2272014	et	4	main
ballett	doc_213943984935_item	2272016	et	3	main
mänguasjade	doc_213943984935_item	2272019	et	3	main
midagi	doc_213943984935_item	2272031	et	4	main
või	doc_213943984935_item	2272034	et	4	main
mis	doc_213943984935_item	2272039	et	4	main
tegin	doc_213943984935_item	2272042	et	3	main
müts	doc_213943984935_item	2272046	et	4	main
väga	doc_213943984935_item	2272055	et	3	main
jooksis	doc_213943984935_item	2272058	et	4	main
koer	doc_213943984935_item	2272060	et	3	main
aga	doc_213943984935_item	2272061	et	3	main
oli	doc_213943984935_item	2272068	et	3	main
liiga	doc_213943984935_item	2272069	et	4	main
kuri	doc_213943984935_item	2272070	et	4	main
väga	doc_213943984935_item	2272082	et	3	main
ülikooli	doc_213943984935_item	2272086	et	4	main
õpin	doc_213943984935_item	2272088	et	3	main
see	doc_213943984935_item	2272094	et	3	main
minu	doc_213943984935_item	2272096	et	3	main
on	doc_213943984935_item	2272095	et	4	main
ammune	doc_213943984935_item	2272097	et	4	main
unistus	doc_213943984935_item	2272098	et	4	main
mulle	doc_213943984935_item	2272099	et	4	main
meeldib	doc_213943984935_item	2272100	et	3	main
matemaatika	doc_213943984935_item	2272101	et	4	main
lastega	doc_213943984935_item	2272102	et	3	main
leian	doc_213943984935_item	2272103	et	3	main
kergesti	doc_213943984935_item	2272104	et	3	main
ühiskeele	doc_213943984935_item	2272105	et	4	main
sellest	doc_213943984935_item	2272106	et	4	main
ka	doc_213943984935_item	2272107	et	3	main
soov	doc_213943984935_item	2272108	et	3	main
saada	doc_213943984935_item	2272109	et	4	main
õpetajaks	doc_213943984935_item	2272110	et	4	main
essee	doc_213943984936_item	2272111	et	4	main
tere	doc_213943984936_item	2272112	et	3	main
minu	doc_213943984936_item	2272113	et	3	main
nimi	doc_213943984936_item	2272114	et	3	main
on	doc_213943984936_item	2272115	et	4	main
eesnimi	doc_213943984936_item	2272116	et	3	main
tahan	doc_213943984936_item	2272117	et	3	main
teile	doc_213943984936_item	2272118	et	4	main
rääkida	doc_213943984936_item	2272119	et	3	main
natuke	doc_213943984936_item	2272120	et	4	main
siis	doc_213943984936_item	2272126	et	3	main
ma	doc_213943984936_item	2272128	et	3	main
elus	doc_213943984936_item	2272134	et	4	main
positiivne	doc_213943984936_item	2272136	et	3	main
võisin	doc_213943984936_item	2272140	et	3	main
peale	doc_213943984936_item	2272142	et	4	main
reageerida	doc_213943984936_item	2272143	et	3	main
arvatavasti	doc_213943984936_item	2272144	et	3	main
kuulda	doc_213943984936_item	2272150	et	4	main
üheksa	doc_213943984936_item	2272156	et	4	main
kuud	doc_213943984936_item	2272157	et	4	main
teine	doc_213943984936_item	2272163	et	3	main
positiivne	doc_213943984936_item	2272164	et	3	main
tantsida	doc_213943984935_item	2272084	et	3	main
ja	doc_213943984935_item	2272087	et	3	main
millest	doc_213943984935_item	2272090	et	3	main
kõik	doc_213943984936_item	2272123	et	4	main
see	doc_213943984936_item	2272131	et	3	main
minu	doc_213943984936_item	2272133	et	3	main
sündmus	doc_213943984936_item	2272137	et	3	main
selle	doc_213943984936_item	2272141	et	4	main
seda	doc_213943984936_item	2272151	et	3	main
olen	doc_213943984936_item	2272153	et	3	main
kuidas	doc_213943984936_item	2272159	et	3	main
lööb	doc_213943984936_item	2272162	et	3	main
keskkooli	doc_213943984936_item	2272169	et	4	main
lõpetamine	doc_213943984936_item	2272170	et	4	main
kuna	doc_213943984936_item	2272171	et	3	main
elu	doc_213943984936_item	2272175	et	4	main
minu	doc_213943984936_item	2272182	et	3	main
sündmusele	doc_213943984936_item	2272189	et	3	main
sündmus	doc_213943984936_item	2272194	et	3	main
mulle	doc_213943984936_item	2272201	et	4	main
ja	doc_213943984936_item	2272204	et	3	main
kuna	doc_213943984936_item	2272210	et	3	main
sama	doc_213943984936_item	2272214	et	4	main
või	doc_213943984936_item	2272216	et	4	main
mitte	doc_213943984936_item	2272222	et	3	main
võimalikult	doc_213943984936_item	2272227	et	4	main
näeb	doc_213943984936_item	2272236	et	3	main
välja	doc_213943984936_item	2272240	et	4	main
tundlik	doc_213943984936_item	2272248	et	3	main
ja	doc_213943984936_item	2272250	et	3	main
kergesti	doc_213943984936_item	2272252	et	3	main
depressiooni	doc_213943984936_item	2272254	et	4	main
kakskümend	doc_213943984937_item	2272269	et	4	main
aastat	doc_213943984937_item	2272271	et	3	main
üheksasaja	doc_213943984937_item	2272277	et	4	main
moskvas	doc_213943984937_item	2272282	et	4	main
õppinud	doc_213943984937_item	2272290	et	4	main
nad	doc_213943984937_item	2272291	et	3	main
vanemad	doc_213943984937_item	2272299	et	4	main
tallinnasse	doc_213943984937_item	2272301	et	3	main
kus	doc_213943984937_item	2272302	et	3	main
on	doc_213943984937_item	2272303	et	4	main
minu	doc_213943984937_item	2272304	et	3	main
sündinud	doc_213943984937_item	2272306	et	4	main
ja	doc_213943984937_item	2272307	et	3	main
kus	doc_213943984937_item	2272308	et	3	main
ma	doc_213943984937_item	2272312	et	3	main
alguse	doc_213943984936_item	2272125	et	3	main
ja	doc_213943984936_item	2272130	et	3	main
oli	doc_213943984936_item	2272132	et	3	main
kuidas	doc_213943984936_item	2272138	et	3	main
ma	doc_213943984936_item	2272145	et	3	main
valjusti	doc_213943984936_item	2272146	et	3	main
karjusin	doc_213943984936_item	2272147	et	3	main
ja	doc_213943984936_item	2272148	et	3	main
mida	doc_213943984936_item	2272152	et	4	main
süda	doc_213943984936_item	2272161	et	3	main
arvan	doc_213943984936_item	2272166	et	3	main
edukas	doc_213943984936_item	2272168	et	4	main
see	doc_213943984936_item	2272172	et	3	main
ühe	doc_213943984936_item	2272176	et	4	main
läbimine	doc_213943984936_item	2272178	et	4	main
mõjus	doc_213943984936_item	2272187	et	4	main
järgnevale	doc_213943984936_item	2272188	et	4	main
ja	doc_213943984936_item	2272191	et	3	main
tallinna	doc_213943984936_item	2272197	et	4	main
horisontid	doc_213943984936_item	2272205	et	4	main
uued	doc_213943984936_item	2272208	et	3	main
sündmusi	doc_213943984936_item	2272212	et	3	main
meie	doc_213943984936_item	2272219	et	4	main
elus	doc_213943984936_item	2272220	et	4	main
mõelda	doc_213943984936_item	2272223	et	4	main
ainult	doc_213943984936_item	2272231	et	4	main
ja	doc_213943984936_item	2272238	et	3	main
eredam	doc_213943984936_item	2272239	et	4	main
on	doc_213943984936_item	2272242	et	4	main
väga	doc_213943984936_item	2272251	et	3	main
taastumine	doc_213943984936_item	2272256	et	4	main
olen	doc_213943984937_item	2272268	et	3	main
üks	doc_213943984937_item	2272270	et	3	main
venemaal	doc_213943984937_item	2272281	et	4	main
seal	doc_213943984937_item	2272288	et	4	main
ülikoolis	doc_213943984937_item	2272289	et	4	main
ülikooli	doc_213943984937_item	2272296	et	4	main
minu	doc_213943984937_item	2272310	et	3	main
käinud	doc_213943984937_item	2272314	et	4	main
ehte	doc_213943984937_item	2272316	et	3	main
humanitaar	doc_213943984937_item	2272317	et	4	main
gümnaasiumis	doc_213943984937_item	2272318	et	3	main
keele	doc_213943984937_item	2272322	et	4	main
olen	doc_213943984937_item	2272326	et	3	main
ja	doc_213943984937_item	2272344	et	3	main
erialale	doc_213943984937_item	2272351	et	3	main
otsustanud	doc_213943984937_item	2272354	et	4	main
üliõpilane	doc_213943984937_item	2272362	et	3	main
lisaeriala	doc_213943984937_item	2272364	et	4	main
inglise	doc_213943984937_item	2272366	et	4	main
keel	doc_213943984937_item	2272367	et	4	main
pean	doc_213943984937_item	2272372	et	4	main
sündmused	doc_213943984937_item	2272385	et	3	main
sest	doc_213943984937_item	2272391	et	4	main
jaoks	doc_213943984937_item	2272395	et	4	main
inimene	doc_213943984937_item	2272397	et	3	main
ja	doc_213943984937_item	2272398	et	3	main
on	doc_213943984937_item	2272407	et	4	main
andis	doc_213943984937_item	2272413	et	3	main
isiksuse	doc_213943984937_item	2272416	et	3	main
klassil	doc_213943984937_item	2272420	et	3	main
veel	doc_213943984937_item	2272429	et	4	main
valu	doc_213943984937_item	2272430	et	4	main
õues	doc_213943984937_item	2272432	et	4	main
koera	doc_213943984937_item	2272438	et	4	main
meeleolu	doc_213943984937_item	2272444	et	4	main
kõige	doc_213943984937_item	2272449	et	4	main
positiivsed	doc_213943984937_item	2272451	et	3	main
sündmused	doc_213943984937_item	2272452	et	3	main
esiteks	doc_213943984937_item	2272454	et	3	main
pärast	doc_213943984937_item	2272465	et	4	main
minu	doc_213943984937_item	2272466	et	3	main
kadumist	doc_213943984937_item	2272468	et	4	main
kui	doc_213943984937_item	2272478	et	3	main
negatiivne	doc_213943984937_item	2272480	et	3	main
sest	doc_213943984937_item	2272485	et	4	main
saada	doc_213943984938_item	2272521	et	4	main
prantsuse	doc_213943984938_item	2272532	et	3	main
keelt	doc_213943984938_item	2272533	et	4	main
üks	doc_213943984938_item	2272534	et	3	main
stuudios	doc_213943984938_item	2272559	et	3	main
ära	doc_213943984938_item	2272561	et	4	main
seal	doc_213943984938_item	2272563	et	4	main
õpilastele	doc_213943984938_item	2272565	et	4	main
suhtumine	doc_213943984938_item	2272567	et	4	main
et	doc_213943984938_item	2272571	et	3	main
kursused	doc_213943984938_item	2272575	et	3	main
seal	doc_213943984938_item	2272577	et	4	main
kursustel	doc_213943984938_item	2272580	et	3	main
etapi	doc_213943984936_item	2272177	et	3	main
ja	doc_213943984936_item	2272179	et	3	main
oli	doc_213943984936_item	2272181	et	3	main
tähtis	doc_213943984936_item	2272185	et	4	main
ja	doc_213943984936_item	2272186	et	3	main
positiivsem	doc_213943984936_item	2272193	et	4	main
oli	doc_213943984936_item	2272195	et	3	main
ja	doc_213943984936_item	2272206	et	3	main
elukatsed	doc_213943984936_item	2272209	et	3	main
negatiivseid	doc_213943984936_item	2272211	et	3	main
isegi	doc_213943984936_item	2272217	et	4	main
rohkem	doc_213943984936_item	2272218	et	4	main
neid	doc_213943984936_item	2272226	et	4	main
kiiresti	doc_213943984936_item	2272228	et	3	main
sündmusi	doc_213943984936_item	2272233	et	3	main
elu	doc_213943984936_item	2272235	et	4	main
parem	doc_213943984936_item	2272237	et	4	main
tegelikult	doc_213943984936_item	2272244	et	4	main
langen	doc_213943984936_item	2272253	et	3	main
aga	doc_213943984936_item	2272255	et	3	main
vana	doc_213943984937_item	2272272	et	4	main
olen	doc_213943984937_item	2272274	et	3	main
tuhande	doc_213943984937_item	2272276	et	3	main
kaheksakümne	doc_213943984937_item	2272278	et	4	main
neljandal	doc_213943984937_item	2272279	et	3	main
aastal	doc_213943984937_item	2272280	et	3	main
ja	doc_213943984937_item	2272285	et	3	main
insenerid-geodesistid	doc_213943984937_item	2272294	et	4	main
minu	doc_213943984937_item	2272298	et	3	main
sõitsid	doc_213943984937_item	2272300	et	4	main
see	doc_213943984937_item	2272319	et	3	main
on	doc_213943984937_item	2272320	et	4	main
prantsuse	doc_213943984937_item	2272321	et	3	main
kool	doc_213943984937_item	2272324	et	4	main
prantsuse	doc_213943984937_item	2272328	et	3	main
lõpetamist	doc_213943984937_item	2272335	et	4	main
tallinna	doc_213943984937_item	2272338	et	4	main
pedagoogika	doc_213943984937_item	2272339	et	4	main
ülikooli	doc_213943984937_item	2272340	et	4	main
olen	doc_213943984937_item	2272353	et	3	main
minu	doc_213943984937_item	2272363	et	3	main
on	doc_213943984937_item	2272365	et	4	main
lõppuni	doc_213943984937_item	2272370	et	3	main
saama	doc_213943984937_item	2272379	et	4	main
olulisemad	doc_213943984937_item	2272383	et	4	main
ta	doc_213943984937_item	2272392	et	4	main
sugulase	doc_213943984937_item	2272402	et	3	main
sündmusel	doc_213943984937_item	2272406	et	3	main
positiivne	doc_213943984937_item	2272409	et	3	main
pähe	doc_213943984937_item	2272421	et	4	main
sest	doc_213943984937_item	2272423	et	4	main
haav	doc_213943984937_item	2272426	et	3	main
ikka	doc_213943984937_item	2272428	et	4	main
on	doc_213943984937_item	2272433	et	4	main
paha	doc_213943984937_item	2272434	et	4	main
ilm	doc_213943984937_item	2272435	et	3	main
ärajooks	doc_213943984937_item	2272439	et	3	main
elu	doc_213943984937_item	2272448	et	4	main
ostmine	doc_213943984937_item	2272457	et	4	main
ja	doc_213943984937_item	2272469	et	3	main
pool	doc_213943984937_item	2272481	et	4	main
ülikooli	doc_213943984937_item	2272483	et	4	main
ma	doc_213943984938_item	2272523	et	3	main
nendest	doc_213943984936_item	2272224	et	4	main
ja	doc_213943984936_item	2272229	et	3	main
häid	doc_213943984936_item	2272232	et	3	main
siis	doc_213943984936_item	2272234	et	3	main
kui	doc_213943984936_item	2272241	et	3	main
võib-olla	doc_213943984936_item	2272243	et	3	main
inimene	doc_213943984936_item	2272249	et	3	main
on	doc_213943984936_item	2272257	et	4	main
pikk	doc_213943984936_item	2272258	et	4	main
ja	doc_213943984936_item	2272259	et	3	main
vaevaline	doc_213943984936_item	2272260	et	4	main
essee	doc_213943984937_item	2272261	et	4	main
minu	doc_213943984937_item	2272262	et	3	main
nimi	doc_213943984937_item	2272263	et	3	main
on	doc_213943984937_item	2272264	et	4	main
eesnimi	doc_213943984937_item	2272265	et	3	main
perekonnanimi	doc_213943984937_item	2272266	et	3	main
ma	doc_213943984937_item	2272267	et	3	main
ma	doc_213943984937_item	2272273	et	3	main
sündinud	doc_213943984937_item	2272275	et	4	main
isa	doc_213943984937_item	2272284	et	4	main
ema	doc_213943984937_item	2272286	et	4	main
on	doc_213943984937_item	2272287	et	4	main
pärast	doc_213943984937_item	2272295	et	4	main
lõpetamist	doc_213943984937_item	2272297	et	4	main
ema	doc_213943984937_item	2272305	et	4	main
vanavanemad	doc_213943984937_item	2272311	et	4	main
olen	doc_213943984937_item	2272313	et	3	main
spetsialiseerimisega	doc_213943984937_item	2272323	et	4	main
kaheteistkümnenda	doc_213943984937_item	2272333	et	4	main
erialale	doc_213943984937_item	2272343	et	3	main
tartu	doc_213943984937_item	2272345	et	4	main
keele	doc_213943984937_item	2272348	et	4	main
ja	doc_213943984937_item	2272349	et	3	main
romanistika	doc_213943984937_item	2272350	et	4	main
ma	doc_213943984937_item	2272352	et	3	main
õppeaasta	doc_213943984937_item	2272369	et	4	main
diplomitööd	doc_213943984937_item	2272373	et	4	main
kirjutama	doc_213943984937_item	2272374	et	3	main
et	doc_213943984937_item	2272376	et	3	main
elu	doc_213943984937_item	2272381	et	4	main
esiteks	doc_213943984937_item	2272387	et	3	main
vanaisa	doc_213943984937_item	2272389	et	4	main
oli	doc_213943984937_item	2272393	et	3	main
oli	doc_213943984937_item	2272400	et	3	main
kaotamine	doc_213943984937_item	2272403	et	4	main
see	doc_213943984937_item	2272412	et	3	main
minu	doc_213943984937_item	2272415	et	3	main
esimesel	doc_213943984937_item	2272419	et	3	main
kukkumine	doc_213943984937_item	2272422	et	4	main
kui	doc_213943984937_item	2272431	et	3	main
ma	doc_213943984937_item	2272441	et	3	main
olulisemad	doc_213943984937_item	2272450	et	4	main
sest	doc_213943984937_item	2272458	et	4	main
armastan	doc_213943984937_item	2272460	et	3	main
väga	doc_213943984937_item	2272462	et	3	main
see	doc_213943984937_item	2272463	et	3	main
tõendab	doc_213943984937_item	2272470	et	3	main
igal	doc_213943984937_item	2272473	et	3	main
ma	doc_213943984937_item	2272486	et	3	main
kartsin	doc_213943984937_item	2272487	et	3	main
õpisin	doc_213943984938_item	2272524	et	4	main
kord	doc_213943984938_item	2272535	et	4	main
siis	doc_213943984938_item	2272545	et	3	main
teatri	doc_213943984938_item	2272552	et	3	main
kahe	doc_213943984938_item	2272554	et	3	main
jätsin	doc_213943984938_item	2272560	et	3	main
oli	doc_213943984938_item	2272564	et	3	main
teada	doc_213943984938_item	2272570	et	3	main
väga	doc_213943984938_item	2272586	et	3	main
pärast	doc_213943984938_item	2272588	et	4	main
lõpetamist	doc_213943984938_item	2272590	et	4	main
läksin	doc_213943984938_item	2272601	et	3	main
ks	doc_213943984938_item	2272604	et	4	main
lõpitamist	doc_213943984938_item	2272609	et	4	main
minu	doc_213943984938_item	2272615	et	3	main
on	doc_213943984938_item	2272619	et	4	main
keskkooli	doc_213943984938_item	2272621	et	4	main
minu	doc_213943984938_item	2272628	et	3	main
koolis	doc_213943984938_item	2272635	et	4	main
õppinud	doc_213943984937_item	2272327	et	4	main
keelt	doc_213943984937_item	2272329	et	4	main
esimesest	doc_213943984937_item	2272330	et	3	main
klassist	doc_213943984937_item	2272331	et	3	main
pärast	doc_213943984937_item	2272332	et	4	main
ma	doc_213943984937_item	2272336	et	3	main
prantsuse	doc_213943984937_item	2272341	et	3	main
ülikooli	doc_213943984937_item	2272346	et	4	main
prantsuse	doc_213943984937_item	2272347	et	3	main
õppida	doc_213943984937_item	2272355	et	3	main
tallinnas	doc_213943984937_item	2272356	et	4	main
ma	doc_213943984937_item	2272358	et	3	main
praegu	doc_213943984937_item	2272357	et	3	main
olen	doc_213943984937_item	2272359	et	3	main
kolmanda	doc_213943984937_item	2272360	et	3	main
kursuse	doc_213943984937_item	2272361	et	3	main
selle	doc_213943984937_item	2272368	et	4	main
ma	doc_213943984937_item	2272371	et	3	main
selleks	doc_213943984937_item	2272375	et	4	main
astmet	doc_213943984937_item	2272378	et	4	main
minu	doc_213943984937_item	2272380	et	3	main
kõige	doc_213943984937_item	2272382	et	4	main
surm	doc_213943984937_item	2272390	et	3	main
minu	doc_213943984937_item	2272394	et	3	main
kallim	doc_213943984937_item	2272396	et	4	main
see	doc_213943984937_item	2272399	et	3	main
kuigi	doc_213943984937_item	2272404	et	3	main
sellel	doc_213943984937_item	2272405	et	4	main
kuna	doc_213943984937_item	2272411	et	3	main
impulsi	doc_213943984937_item	2272414	et	3	main
arenemiseks	doc_213943984937_item	2272417	et	4	main
teiseks	doc_213943984937_item	2272418	et	4	main
see	doc_213943984937_item	2272424	et	3	main
minu	doc_213943984937_item	2272437	et	3	main
head	doc_213943984937_item	2272443	et	4	main
pikkaks	doc_213943984937_item	2272445	et	4	main
minu	doc_213943984937_item	2272455	et	3	main
koera	doc_213943984937_item	2272467	et	4	main
on	doc_213943984937_item	2272475	et	4	main
nii	doc_213943984937_item	2272476	et	3	main
teiseks	doc_213943984937_item	2272482	et	4	main
et	doc_213943984937_item	2272488	et	3	main
ei	doc_213943984937_item	2272489	et	4	main
saa	doc_213943984937_item	2272490	et	4	main
sellega	doc_213943984937_item	2272491	et	3	main
hakkama	doc_213943984937_item	2272492	et	3	main
ja	doc_213943984937_item	2272493	et	3	main
kolmandaks	doc_213943984937_item	2272494	et	4	main
eesti	doc_213943984937_item	2272495	et	4	main
kodakontsuse	doc_213943984937_item	2272496	et	4	main
saamine	doc_213943984937_item	2272497	et	4	main
sest	doc_213943984937_item	2272498	et	4	main
ma	doc_213943984937_item	2272499	et	3	main
ei	doc_213943984937_item	2272500	et	4	main
usunud	doc_213943984937_item	2272501	et	4	main
et	doc_213943984937_item	2272503	et	3	main
juba	doc_213943984937_item	2272502	et	3	main
saan	doc_213943984937_item	2272504	et	4	main
kodanikuks	doc_213943984937_item	2272505	et	4	main
kuna	doc_213943984937_item	2272506	et	3	main
mul	doc_213943984937_item	2272507	et	3	main
olid	doc_213943984937_item	2272508	et	4	main
probleemid	doc_213943984937_item	2272509	et	3	main
taotlusanketti	doc_213943984937_item	2272510	et	4	main
täitmisega	doc_213943984937_item	2272511	et	4	main
essee	doc_213943984938_item	2272512	et	4	main
ma	doc_213943984938_item	2272513	et	3	main
olen	doc_213943984938_item	2272514	et	3	main
sündinud	doc_213943984938_item	2272515	et	4	main
tallinna	doc_213943984938_item	2272516	et	4	main
linnas	doc_213943984938_item	2272517	et	4	main
lapsepõlvest	doc_213943984938_item	2272518	et	4	main
ma	doc_213943984938_item	2272519	et	3	main
tahtsin	doc_213943984938_item	2272520	et	3	main
näitlijaks	doc_213943984938_item	2272522	et	4	main
hümnaasiumis	doc_213943984938_item	2272528	et	4	main
ma	doc_213943984938_item	2272530	et	3	main
õpisin	doc_213943984938_item	2272531	et	4	main
võtsin	doc_213943984938_item	2272537	et	3	main
keele	doc_213943984938_item	2272540	et	4	main
prantsuse	doc_213943984938_item	2272542	et	3	main
ehte	doc_213943984938_item	2272525	et	3	main
humanitaar	doc_213943984938_item	2272527	et	4	main
nädalas	doc_213943984938_item	2272536	et	3	main
keskuses	doc_213943984938_item	2272544	et	4	main
õpisin	doc_213943984938_item	2272547	et	4	main
üheksandas	doc_213943984938_item	2272548	et	3	main
läksin	doc_213943984938_item	2272550	et	3	main
aasta	doc_213943984938_item	2272555	et	4	main
osalema	doc_213943984938_item	2272581	et	3	main
kuna	doc_213943984938_item	2272583	et	3	main
seal	doc_213943984938_item	2272584	et	4	main
oli	doc_213943984938_item	2272585	et	3	main
prantsuse	doc_213943984938_item	2272593	et	3	main
tallinna	doc_213943984938_item	2272595	et	4	main
peale	doc_213943984938_item	2272607	et	4	main
järgmised	doc_213943984938_item	2272620	et	3	main
inglismaal	doc_213943984938_item	2272627	et	4	main
negatiivsed	doc_213943984938_item	2272629	et	3	main
teatri	doc_213943984938_item	2272634	et	3	main
kui	doc_213943984938_item	2272546	et	3	main
õppima	doc_213943984938_item	2272551	et	3	main
pärast	doc_213943984938_item	2272556	et	4	main
õppimise	doc_213943984938_item	2272557	et	4	main
teatri	doc_213943984938_item	2272558	et	3	main
sain	doc_213943984938_item	2272569	et	3	main
meil	doc_213943984938_item	2272572	et	4	main
ajakirjanduse	doc_213943984938_item	2272574	et	3	main
hakkasin	doc_213943984938_item	2272576	et	3	main
jätsin	doc_213943984938_item	2272579	et	3	main
igav	doc_213943984938_item	2272587	et	3	main
keskkooli	doc_213943984938_item	2272589	et	4	main
filoloogiat	doc_213943984938_item	2272594	et	3	main
pedagoogika	doc_213943984938_item	2272596	et	4	main
ülikoolis	doc_213943984938_item	2272597	et	4	main
õpides	doc_213943984938_item	2272598	et	4	main
esimesel	doc_213943984938_item	2272599	et	3	main
astuda	doc_213943984938_item	2272611	et	3	main
ülikooli	doc_213943984938_item	2272614	et	4	main
positiivsed	doc_213943984938_item	2272616	et	3	main
klassis	doc_213943984938_item	2272549	et	3	main
studiasse	doc_213943984938_item	2272553	et	4	main
kuna	doc_213943984938_item	2272562	et	3	main
halb	doc_213943984938_item	2272566	et	3	main
koolis	doc_213943984938_item	2272568	et	4	main
on	doc_213943984938_item	2272573	et	4	main
osalema	doc_213943984938_item	2272578	et	3	main
ära	doc_213943984938_item	2272582	et	4	main
õppima	doc_213943984938_item	2272592	et	3	main
ka	doc_213943984938_item	2272603	et	3	main
teatri	doc_213943984938_item	2272605	et	3	main
teatri	doc_213943984938_item	2272613	et	3	main
sündmused	doc_213943984938_item	2272617	et	3	main
ajaviitmine	doc_213943984938_item	2272626	et	3	main
sündmused	doc_213943984938_item	2272630	et	3	main
esimeses	doc_213943984938_item	2272633	et	3	main
ma	doc_213943984940_item	2272806	et	3	main
muusikakool	doc_213943984940_item	2272820	et	4	main
elule	doc_213943984940_item	2272823	et	3	main
õnnestumine	doc_213943984940_item	2272825	et	4	main
see	doc_213943984940_item	2272827	et	3	main
ma	doc_213943984940_item	2272840	et	3	main
sest	doc_213943984940_item	2272845	et	4	main
kuulsin	doc_213943984940_item	2272852	et	3	main
sõita	doc_213943984940_item	2272887	et	3	main
on	doc_213943984940_item	2272892	et	4	main
ja	doc_213943984940_item	2272900	et	3	main
seda	doc_213943984940_item	2272904	et	3	main
onu	doc_213943984940_item	2272913	et	4	main
oli	doc_213943984940_item	2272916	et	3	main
aastusin	doc_213943984938_item	2272591	et	4	main
kursusel	doc_213943984938_item	2272600	et	3	main
õppima	doc_213943984938_item	2272602	et	3	main
stuudiasse	doc_213943984938_item	2272606	et	4	main
ülikooli	doc_213943984938_item	2272608	et	4	main
tahan	doc_213943984938_item	2272610	et	3	main
õppima	doc_213943984938_item	2272612	et	3	main
elus	doc_213943984938_item	2272618	et	4	main
lõpitamine	doc_213943984938_item	2272622	et	4	main
ks	doc_213943984938_item	2272623	et	4	main
stuudios	doc_213943984938_item	2272624	et	3	main
õpimine	doc_213943984938_item	2272625	et	4	main
on	doc_213943984938_item	2272631	et	4	main
muusikakoolisse	doc_213943984940_item	2272803	et	4	main
klaveril	doc_213943984940_item	2272805	et	3	main
hakkasin	doc_213943984940_item	2272807	et	3	main
aastast	doc_213943984940_item	2272810	et	4	main
sündist	doc_213943984940_item	2272812	et	4	main
oli	doc_213943984940_item	2272814	et	3	main
olin	doc_213943984940_item	2272818	et	3	main
järgmised	doc_213943984938_item	2272632	et	3	main
õpimine	doc_213943984938_item	2272636	et	4	main
laulda	doc_213943984940_item	2272811	et	4	main
päikesepaisteline	doc_213943984940_item	2272815	et	4	main
ma	doc_213943984940_item	2272817	et	3	main
minu	doc_213943984940_item	2272822	et	3	main
kardsin	doc_213943984940_item	2272833	et	4	main
kardsin	doc_213943984940_item	2272841	et	4	main
ikka	doc_213943984940_item	2272855	et	4	main
siis	doc_213943984940_item	2272857	et	3	main
oli	doc_213943984940_item	2272876	et	3	main
nii	doc_213943984940_item	2272882	et	3	main
ei	doc_213943984940_item	2272885	et	4	main
koju	doc_213943984940_item	2272888	et	3	main
palju	doc_213943984940_item	2272894	et	4	main
mulle	doc_213943984940_item	2272896	et	4	main
ma	doc_213943984940_item	2272901	et	3	main
tahad	doc_213943984940_item	2272902	et	3	main
minu	doc_213943984940_item	2272908	et	3	main
ebaõnnestumine	doc_213943984940_item	2272912	et	3	main
see	doc_213943984940_item	2272915	et	3	main
mure	doc_213943984940_item	2272918	et	4	main
ma	doc_213943984940_item	2272928	et	3	main
seda	doc_213943984940_item	2272930	et	3	main
ei	doc_213943984940_item	2272932	et	4	main
et	doc_213943984940_item	2272934	et	3	main
see	doc_213943984940_item	2272935	et	3	main
ma	doc_213943984940_item	2272945	et	3	main
ei	doc_213943984940_item	2272946	et	4	main
teasin	doc_213943984940_item	2272966	et	4	main
olen	doc_213943984940_item	2272968	et	3	main
tpü-sse	doc_213943984940_item	2272970	et	3	main
olin	doc_213943984940_item	2272978	et	3	main
aga	doc_213943984940_item	2272991	et	3	main
kogemus	doc_213943984940_item	2272999	et	3	main
kanda	doc_213943984940_item	2273001	et	4	main
essee	doc_213943984940_item	2272793	et	4	main
minu	doc_213943984940_item	2272794	et	3	main
elus	doc_213943984940_item	2272795	et	4	main
oli	doc_213943984940_item	2272796	et	3	main
üks	doc_213943984940_item	2272797	et	3	main
oluline	doc_213943984940_item	2272798	et	4	main
õnnestumine	doc_213943984940_item	2272799	et	4	main
kui	doc_213943984940_item	2272800	et	3	main
ma	doc_213943984940_item	2272801	et	3	main
astusin	doc_213943984940_item	2272802	et	3	main
juba	doc_213943984940_item	2272808	et	3	main
rõõmus	doc_213943984940_item	2272819	et	4	main
teine	doc_213943984940_item	2272824	et	3	main
astusin	doc_213943984940_item	2272830	et	3	main
ma	doc_213943984940_item	2272835	et	3	main
astu	doc_213943984940_item	2272837	et	4	main
elada	doc_213943984940_item	2272842	et	3	main
linnas	doc_213943984940_item	2272844	et	4	main
elasin	doc_213943984940_item	2272846	et	3	main
kui	doc_213943984940_item	2272850	et	3	main
ma	doc_213943984940_item	2272851	et	3	main
et	doc_213943984940_item	2272853	et	3	main
ma	doc_213943984940_item	2272858	et	3	main
elus	doc_213943984940_item	2272874	et	4	main
poola	doc_213943984940_item	2272879	et	4	main
meeldis	doc_213943984940_item	2272881	et	3	main
et	doc_213943984940_item	2272883	et	3	main
seal	doc_213943984940_item	2272890	et	4	main
sõpru	doc_213943984940_item	2272895	et	3	main
poola	doc_213943984940_item	2272898	et	4	main
suur	doc_213943984940_item	2272917	et	3	main
onul	doc_213943984940_item	2272919	et	3	main
suur	doc_213943984940_item	2272921	et	3	main
jäid	doc_213943984940_item	2272924	et	4	main
olla	doc_213943984940_item	2272937	et	3	main
ikkagi	doc_213943984940_item	2272939	et	4	main
astunud	doc_213943984940_item	2272947	et	4	main
ülikoolisse	doc_213943984940_item	2272949	et	4	main
täiesti	doc_213943984940_item	2272963	et	3	main
sest	doc_213943984940_item	2272965	et	4	main
oli	doc_213943984940_item	2272975	et	3	main
see	doc_213943984940_item	2272985	et	3	main
oli	doc_213943984940_item	2272986	et	3	main
probleem	doc_213943984940_item	2272990	et	3	main
arvan	doc_213943984940_item	2272994	et	3	main
ära	doc_213943984940_item	2273000	et	4	main
ma	doc_213943984941_item	2273011	et	3	main
vana	doc_213943984941_item	2273015	et	4	main
elan	doc_213943984941_item	2273016	et	3	main
maardus	doc_213943984941_item	2273017	et	4	main
kahetoaline	doc_213943984941_item	2273024	et	4	main
pedagoogikaülikoolis	doc_213943984941_item	2273029	et	4	main
aga	doc_213943984941_item	2273039	et	3	main
jõua	doc_213943984941_item	2273048	et	4	main
korralikult	doc_213943984941_item	2273049	et	4	main
momente	doc_213943984941_item	2273062	et	3	main
peavad	doc_213943984941_item	2273072	et	4	main
meeles	doc_213943984941_item	2273073	et	3	main
ebameeldivaid	doc_213943984941_item	2273074	et	3	main
kus	doc_213943984941_item	2273076	et	3	main
elus	doc_213943984941_item	2273078	et	4	main
toimusid	doc_213943984941_item	2273079	et	4	main
peres	doc_213943984941_item	2273080	et	3	main
muutused	doc_213943984941_item	2273081	et	4	main
nii	doc_213943984941_item	2273086	et	3	main
minu	doc_213943984941_item	2273088	et	3	main
ma	doc_213943984941_item	2273094	et	3	main
6-aastane	doc_213943984941_item	2273096	et	4	main
mäletan	doc_213943984941_item	2273104	et	3	main
see	doc_213943984941_item	2273106	et	3	main
mäleta	doc_213943984941_item	2273111	et	4	main
mängida	doc_213943984940_item	2272804	et	3	main
viiest	doc_213943984940_item	2272809	et	4	main
see	doc_213943984940_item	2272813	et	3	main
päev	doc_213943984940_item	2272816	et	3	main
mõjus	doc_213943984940_item	2272821	et	4	main
et	doc_213943984940_item	2272834	et	3	main
ei	doc_213943984940_item	2272836	et	4	main
ülikoolisse	doc_213943984940_item	2272838	et	4	main
veel	doc_213943984940_item	2272839	et	4	main
linnas	doc_213943984940_item	2272849	et	4	main
mina	doc_213943984940_item	2272854	et	4	main
sündmus	doc_213943984940_item	2272871	et	3	main
minu	doc_213943984940_item	2272873	et	3	main
see	doc_213943984940_item	2272875	et	3	main
poolasse	doc_213943984940_item	2272878	et	3	main
mul	doc_213943984940_item	2272891	et	3	main
nüüd	doc_213943984940_item	2272893	et	4	main
meeldis	doc_213943984940_item	2272897	et	3	main
aastal	doc_213943984940_item	2272906	et	3	main
elus	doc_213943984940_item	2272909	et	4	main
ka	doc_213943984940_item	2272911	et	3	main
tapmine	doc_213943984940_item	2272914	et	4	main
oli	doc_213943984940_item	2272920	et	3	main
pere	doc_213943984940_item	2272922	et	4	main
isata	doc_213943984940_item	2272926	et	3	main
kuulsin	doc_213943984940_item	2272929	et	3	main
aga	doc_213943984940_item	2272938	et	3	main
teine	doc_213943984940_item	2272941	et	3	main
oli	doc_213943984940_item	2272943	et	3	main
jäin	doc_213943984940_item	2272962	et	3	main
et	doc_213943984940_item	2272967	et	3	main
astunud	doc_213943984940_item	2272969	et	4	main
kui	doc_213943984940_item	2272976	et	3	main
ma	doc_213943984940_item	2272977	et	3	main
seal	doc_213943984940_item	2272981	et	4	main
ma	doc_213943984940_item	2272993	et	3	main
kasulik	doc_213943984940_item	2272998	et	3	main
kottis	doc_213943984940_item	2273004	et	3	main
kaasa	doc_213943984940_item	2273005	et	4	main
olen	doc_213943984941_item	2273012	et	3	main
kolmandal	doc_213943984941_item	2273020	et	3	main
korter	doc_213943984941_item	2273022	et	3	main
on	doc_213943984941_item	2273023	et	4	main
olen	doc_213943984941_item	2273025	et	3	main
õpin	doc_213943984941_item	2273028	et	3	main
teisel	doc_213943984941_item	2273031	et	4	main
veel	doc_213943984941_item	2273035	et	4	main
mustakivi	doc_213943984941_item	2273036	et	4	main
ära	doc_213943984941_item	2273043	et	4	main
sest	doc_213943984941_item	2273046	et	4	main
elu	doc_213943984941_item	2273058	et	4	main
ka	doc_213943984941_item	2273066	et	3	main
vanematest	doc_213943984941_item	2273085	et	4	main
suri	doc_213943984941_item	2273091	et	3	main
olin	doc_213943984941_item	2273095	et	3	main
ma	doc_213943984941_item	2273097	et	3	main
momenti	doc_213943984941_item	2273103	et	4	main
toimus	doc_213943984941_item	2273107	et	3	main
ma	doc_213943984941_item	2273109	et	3	main
minuga	doc_213943984941_item	2273113	et	3	main
suri	doc_213943984941_item	2273116	et	3	main
kes	doc_213943984941_item	2273119	et	4	main
terve	doc_213943984941_item	2273122	et	4	main
suur	doc_213943984941_item	2273127	et	3	main
parata	doc_213943984941_item	2273132	et	3	main
aeg	doc_213943984941_item	2273133	et	3	main
väga	doc_213943984941_item	2273135	et	3	main
oli	doc_213943984941_item	2273137	et	3	main
venemaale	doc_213943984941_item	2273144	et	4	main
meie	doc_213943984941_item	2273148	et	4	main
jalutasime	doc_213943984941_item	2273154	et	3	main
nad	doc_213943984941_item	2273156	et	3	main
tegime	doc_213943984941_item	2273162	et	3	main
terve	doc_213943984941_item	2273163	et	4	main
et	doc_213943984941_item	2273165	et	3	main
sest	doc_213943984941_item	2273168	et	4	main
natukene	doc_213943984941_item	2273173	et	4	main
lõppude	doc_213943984941_item	2273179	et	4	main
jõudsime	doc_213943984941_item	2273181	et	3	main
minu	doc_213943984941_item	2273185	et	3	main
parim	doc_213943984941_item	2273187	et	4	main
me	doc_213943984941_item	2273190	et	4	main
2	doc_213943984941_item	2273192	et	2	main
oli	doc_213943984940_item	2272826	et	3	main
kui	doc_213943984940_item	2272828	et	3	main
ma	doc_213943984940_item	2272829	et	3	main
tpü-sse	doc_213943984940_item	2272831	et	3	main
ma	doc_213943984940_item	2272832	et	3	main
suures	doc_213943984940_item	2272843	et	3	main
siiamani	doc_213943984940_item	2272847	et	4	main
väikses	doc_213943984940_item	2272848	et	4	main
astusin	doc_213943984940_item	2272856	et	3	main
olin	doc_213943984940_item	2272859	et	3	main
õnnelik	doc_213943984940_item	2272860	et	3	main
ja	doc_213943984940_item	2272861	et	3	main
praegu	doc_213943984940_item	2272862	et	3	main
ma	doc_213943984940_item	2272863	et	3	main
ei	doc_213943984940_item	2272864	et	4	main
karda	doc_213943984940_item	2272865	et	4	main
juba	doc_213943984940_item	2272866	et	3	main
tallinna	doc_213943984940_item	2272867	et	4	main
veel	doc_213943984940_item	2272868	et	4	main
üks	doc_213943984940_item	2272869	et	3	main
positiivne	doc_213943984940_item	2272870	et	3	main
oli	doc_213943984940_item	2272872	et	3	main
sõit	doc_213943984940_item	2272877	et	3	main
mulle	doc_213943984940_item	2272880	et	4	main
ma	doc_213943984940_item	2272884	et	3	main
tahtnud	doc_213943984940_item	2272886	et	4	main
tagasi	doc_213943984940_item	2272889	et	3	main
keel	doc_213943984940_item	2272899	et	4	main
õppida	doc_213943984940_item	2272903	et	3	main
järgmisel	doc_213943984940_item	2272905	et	3	main
aga	doc_213943984940_item	2272907	et	3	main
oli	doc_213943984940_item	2272910	et	3	main
lapsed	doc_213943984940_item	2272923	et	3	main
ma	doc_213943984940_item	2272931	et	3	main
usunud	doc_213943984940_item	2272933	et	4	main
võib	doc_213943984940_item	2272940	et	3	main
ebaõnnestumine	doc_213943984940_item	2272942	et	3	main
tartu	doc_213943984940_item	2272948	et	4	main
ei	doc_213943984940_item	2272951	et	4	main
ükskõikseks	doc_213943984940_item	2272964	et	4	main
sündmus	doc_213943984940_item	2272974	et	3	main
ja	doc_213943984940_item	2272980	et	3	main
unustasin	doc_213943984940_item	2272982	et	3	main
oma	doc_213943984940_item	2272983	et	4	main
passi	doc_213943984940_item	2272984	et	4	main
hirmus	doc_213943984940_item	2272987	et	4	main
päev	doc_213943984940_item	2272988	et	3	main
et	doc_213943984940_item	2272995	et	3	main
oli	doc_213943984940_item	2272997	et	3	main
oma	doc_213943984940_item	2273003	et	4	main
essee	doc_213943984941_item	2273006	et	4	main
minu	doc_213943984941_item	2273007	et	3	main
nimi	doc_213943984941_item	2273008	et	3	main
on	doc_213943984941_item	2273009	et	4	main
eesnimi	doc_213943984941_item	2273010	et	3	main
21	doc_213943984941_item	2273013	et	2	main
majas	doc_213943984941_item	2273019	et	3	main
vabaabielus	doc_213943984941_item	2273026	et	4	main
kursusel	doc_213943984941_item	2273032	et	3	main
citymarketis	doc_213943984941_item	2273037	et	4	main
kassapidajana	doc_213943984941_item	2273038	et	3	main
lähen	doc_213943984941_item	2273041	et	3	main
ei	doc_213943984941_item	2273047	et	4	main
õppida	doc_213943984941_item	2273050	et	3	main
on	doc_213943984941_item	2273067	et	4	main
pärast	doc_213943984941_item	2273069	et	4	main
näiteks	doc_213943984941_item	2273082	et	4	main
kui	doc_213943984941_item	2273090	et	3	main
isa	doc_213943984941_item	2273093	et	4	main
veel	doc_213943984941_item	2273099	et	4	main
selle	doc_213943984941_item	2273102	et	4	main
eile	doc_213943984941_item	2273108	et	3	main
toimus	doc_213943984941_item	2273114	et	3	main
minu	doc_213943984941_item	2273117	et	3	main
elas	doc_213943984941_item	2273120	et	3	main
meiega	doc_213943984941_item	2273121	et	4	main
elu	doc_213943984941_item	2273123	et	4	main
see	doc_213943984941_item	2273124	et	3	main
kaotus	doc_213943984941_item	2273128	et	4	main
me	doc_213943984941_item	2273139	et	4	main
ja	doc_213943984941_item	2273145	et	3	main
nägime	doc_213943984941_item	2273146	et	3	main
me	doc_213943984941_item	2273150	et	4	main
elavad	doc_213943984941_item	2273157	et	4	main
kiirovis	doc_213943984941_item	2273158	et	4	main
moskvas	doc_213943984941_item	2273159	et	4	main
me	doc_213943984941_item	2273169	et	4	main
ja	doc_213943984941_item	2273178	et	3	main
krasnodaari	doc_213943984941_item	2273182	et	4	main
elam	doc_213943984941_item	2273184	et	4	main
ema	doc_213943984941_item	2273186	et	4	main
sõbrana	doc_213943984941_item	2273188	et	3	main
puhkasime	doc_213943984941_item	2273191	et	3	main
mustmeres	doc_213943984941_item	2273195	et	3	main
oli	doc_213943984941_item	2273198	et	3	main
sul	doc_213943984941_item	2273213	et	3	main
on	doc_213943984941_item	2273215	et	4	main
elanud	doc_213943984942_item	2273226	et	4	main
mu	doc_213943984942_item	2273228	et	3	main
ema	doc_213943984942_item	2273229	et	4	main
koolis	doc_213943984942_item	2273239	et	4	main
keskkooli	doc_213943984942_item	2273241	et	4	main
ka	doc_213943984942_item	2273245	et	3	main
ilma	doc_213943984940_item	2272925	et	4	main
kui	doc_213943984940_item	2272927	et	3	main
võib	doc_213943984940_item	2272936	et	3	main
kui	doc_213943984940_item	2272944	et	3	main
mul	doc_213943984940_item	2272950	et	3	main
olnud	doc_213943984940_item	2272952	et	4	main
inglise	doc_213943984940_item	2272953	et	4	main
keele	doc_213943984940_item	2272954	et	4	main
eksamit	doc_213943984940_item	2272955	et	3	main
siis	doc_213943984940_item	2272956	et	3	main
ma	doc_213943984940_item	2272957	et	3	main
ei	doc_213943984940_item	2272958	et	4	main
astunud	doc_213943984940_item	2272959	et	4	main
aga	doc_213943984940_item	2272960	et	3	main
ma	doc_213943984940_item	2272961	et	3	main
veel	doc_213943984940_item	2272971	et	4	main
üks	doc_213943984940_item	2272972	et	3	main
negatiivne	doc_213943984940_item	2272973	et	3	main
ukrainas	doc_213943984940_item	2272979	et	4	main
suur	doc_213943984940_item	2272989	et	3	main
praegu	doc_213943984940_item	2272992	et	3	main
see	doc_213943984940_item	2272996	et	3	main
passi	doc_213943984940_item	2273002	et	4	main
aastat	doc_213943984941_item	2273014	et	3	main
üheksakorrulises	doc_213943984941_item	2273018	et	4	main
korrusel	doc_213943984941_item	2273021	et	3	main
ma	doc_213943984941_item	2273027	et	3	main
koolimuusikat	doc_213943984941_item	2273030	et	3	main
õppimisega	doc_213943984941_item	2273045	et	4	main
töötan	doc_213943984941_item	2273051	et	3	main
lõbusaid	doc_213943984941_item	2273061	et	3	main
kuid	doc_213943984941_item	2273063	et	4	main
ikka	doc_213943984941_item	2273065	et	4	main
hetke	doc_213943984941_item	2273075	et	4	main
tema	doc_213943984941_item	2273084	et	4	main
toimuski	doc_213943984941_item	2273087	et	3	main
peres	doc_213943984941_item	2273089	et	3	main
aga	doc_213943984941_item	2273101	et	3	main
mis	doc_213943984941_item	2273112	et	4	main
tolaastal	doc_213943984941_item	2273115	et	4	main
aga	doc_213943984941_item	2273129	et	3	main
midagi	doc_213943984941_item	2273131	et	4	main
kui	doc_213943984941_item	2273138	et	3	main
sõitsime	doc_213943984941_item	2273140	et	3	main
suplesime	doc_213943984941_item	2273151	et	3	main
koos	doc_213943984941_item	2273155	et	4	main
kõike	doc_213943984941_item	2273166	et	4	main
rohkem	doc_213943984941_item	2273174	et	4	main
kui	doc_213943984941_item	2273175	et	3	main
seal	doc_213943984941_item	2273189	et	4	main
nädalat	doc_213943984941_item	2273193	et	3	main
kift	doc_213943984941_item	2273200	et	4	main
meelest	doc_213943984941_item	2273202	et	4	main
oma	doc_213943984941_item	2273207	et	4	main
elus	doc_213943984941_item	2273208	et	4	main
on	doc_213943984942_item	2273219	et	4	main
eesnimi	doc_213943984942_item	2273220	et	3	main
perekonnanimi	doc_213943984942_item	2273221	et	3	main
olen	doc_213943984942_item	2273223	et	3	main
ning	doc_213943984942_item	2273225	et	3	main
tallinnas	doc_213943984942_item	2273227	et	4	main
ja	doc_213943984942_item	2273232	et	3	main
õpib	doc_213943984942_item	2273237	et	3	main
on	doc_213943984942_item	2273249	et	4	main
sõbranna	doc_213943984942_item	2273254	et	4	main
nii	doc_213943984942_item	2273259	et	3	main
armastust	doc_213943984942_item	2273261	et	4	main
ning	doc_213943984942_item	2273262	et	3	main
teadmisi	doc_213943984942_item	2273263	et	4	main
kuidas	doc_213943984942_item	2273264	et	3	main
korraldada	doc_213943984942_item	2273275	et	3	main
ka	doc_213943984942_item	2273284	et	3	main
õppida	doc_213943984942_item	2273291	et	3	main
olen	doc_213943984942_item	2273332	et	3	main
korvpalliga	doc_213943984942_item	2273334	et	3	main
ajaga	doc_213943984942_item	2273343	et	3	main
saanud	doc_213943984942_item	2273345	et	4	main
ning	doc_213943984942_item	2273347	et	3	main
olen	doc_213943984942_item	2273352	et	3	main
minu	doc_213943984942_item	2273353	et	3	main
tulemused	doc_213943984942_item	2273360	et	3	main
seda	doc_213943984942_item	2273375	et	3	main
astusin	doc_213943984942_item	2273377	et	3	main
trenni	doc_213943984942_item	2273386	et	4	main
mu	doc_213943984942_item	2273393	et	3	main
sündmusena	doc_213943984942_item	2273398	et	3	main
võib	doc_213943984942_item	2273399	et	3	main
ellu	doc_213943984942_item	2273406	et	4	main
inimest	doc_213943984942_item	2273418	et	3	main
nüüd	doc_213943984942_item	2273424	et	4	main
elus	doc_213943984942_item	2273427	et	4	main
selline	doc_213943984942_item	2273429	et	4	main
elu	doc_213943984942_item	2273432	et	4	main
minu	doc_213943984942_item	2273437	et	3	main
siis	doc_213943984942_item	2273440	et	3	main
paha	doc_213943984942_item	2273450	et	4	main
ka	doc_213943984942_item	2273455	et	3	main
parallelselt	doc_213943984941_item	2273033	et	4	main
töötan	doc_213943984941_item	2273034	et	3	main
varsti	doc_213943984941_item	2273040	et	3	main
töölt	doc_213943984941_item	2273042	et	3	main
seoses	doc_213943984941_item	2273044	et	4	main
tavaliselt	doc_213943984941_item	2273052	et	4	main
õhtuti	doc_213943984941_item	2273053	et	3	main
kooli	doc_213943984941_item	2273055	et	4	main
minu	doc_213943984941_item	2273056	et	3	main
pärast	doc_213943984941_item	2273054	et	4	main
arvates	doc_213943984941_item	2273057	et	4	main
on	doc_213943984941_item	2273059	et	4	main
täis	doc_213943984941_item	2273060	et	4	main
kurvad	doc_213943984941_item	2273064	et	3	main
millegi	doc_213943984941_item	2273068	et	4	main
inimesed	doc_213943984941_item	2273070	et	3	main
enamus	doc_213943984941_item	2273071	et	4	main
nende	doc_213943984941_item	2273077	et	4	main
surm	doc_213943984941_item	2273083	et	3	main
minu	doc_213943984941_item	2273092	et	3	main
olin	doc_213943984941_item	2273098	et	3	main
väike	doc_213943984941_item	2273100	et	4	main
kuigi	doc_213943984941_item	2273105	et	3	main
ei	doc_213943984941_item	2273110	et	4	main
vanaema	doc_213943984941_item	2273118	et	4	main
on	doc_213943984941_item	2273125	et	4	main
ravib	doc_213943984941_item	2273134	et	3	main
oma	doc_213943984941_item	2273142	et	4	main
perega	doc_213943984941_item	2273143	et	3	main
sugulasi	doc_213943984941_item	2273149	et	3	main
ja	doc_213943984941_item	2273153	et	3	main
me	doc_213943984941_item	2273161	et	4	main
reisi	doc_213943984941_item	2273164	et	4	main
näinud	doc_213943984941_item	2273171	et	4	main
10	doc_213943984941_item	2273176	et	2	main
aastat	doc_213943984941_item	2273177	et	3	main
kui	doc_213943984941_item	2273183	et	3	main
suplesime	doc_213943984941_item	2273194	et	3	main
väga	doc_213943984941_item	2273199	et	3	main
minu	doc_213943984941_item	2273201	et	3	main
hetkega	doc_213943984941_item	2273206	et	3	main
mis	doc_213943984941_item	2273212	et	4	main
sündinud	doc_213943984942_item	2273224	et	4	main
veel	doc_213943984942_item	2273238	et	4	main
lõpetab	doc_213943984942_item	2273240	et	3	main
peale	doc_213943984942_item	2273242	et	4	main
seda	doc_213943984942_item	2273243	et	3	main
läheb	doc_213943984942_item	2273244	et	3	main
temalt	doc_213943984942_item	2273256	et	3	main
nii	doc_213943984942_item	2273273	et	3	main
tahtnud	doc_213943984942_item	2273290	et	4	main
lihtsalt	doc_213943984942_item	2273321	et	4	main
siis	doc_213943984942_item	2273323	et	3	main
hariduse	doc_213943984942_item	2273325	et	3	main
keele	doc_213943984942_item	2273327	et	4	main
möödunud	doc_213943984942_item	2273337	et	4	main
olen	doc_213943984942_item	2273344	et	3	main
tugevamaks	doc_213943984942_item	2273346	et	4	main
mänginud	doc_213943984942_item	2273355	et	4	main
4	doc_213943984942_item	2273357	et	2	main
iga	doc_213943984942_item	2273362	et	4	main
otsustasingi	doc_213943984942_item	2273367	et	3	main
tallinna	doc_213943984942_item	2273369	et	4	main
sisse	doc_213943984942_item	2273379	et	4	main
hakkasin	doc_213943984942_item	2273380	et	3	main
tööl	doc_213943984942_item	2273381	et	3	main
käima	doc_213943984942_item	2273382	et	4	main
tüdrukutele	doc_213943984942_item	2273388	et	4	main
kõige	doc_213943984942_item	2273396	et	4	main
parema	doc_213943984942_item	2273397	et	4	main
et	doc_213943984942_item	2273404	et	3	main
tuli	doc_213943984942_item	2273407	et	4	main
arvan	doc_213943984942_item	2273414	et	3	main
armastuseta	doc_213943984942_item	2273423	et	4	main
tunne	doc_213943984942_item	2273430	et	4	main
oli	doc_213943984942_item	2273439	et	3	main
kui	doc_213943984942_item	2273441	et	3	main
meistriliigas	doc_213943984942_item	2273443	et	3	main
hakkasin	doc_213943984942_item	2273445	et	3	main
kuna	doc_213943984942_item	2273451	et	3	main
treeneriga	doc_213943984942_item	2273483	et	3	main
arvan	doc_213943984942_item	2273485	et	3	main
situatsioonis	doc_213943984942_item	2273488	et	3	main
meie	doc_213943984942_item	2273499	et	4	main
treeneriga	doc_213943984942_item	2273501	et	3	main
ning	doc_213943984942_item	2273510	et	3	main
ajal	doc_213943984942_item	2273512	et	4	main
mulle	doc_213943984943_item	2273531	et	4	main
oli	doc_213943984943_item	2273535	et	3	main
kingitus	doc_213943984943_item	2273537	et	4	main
kutsusin	doc_213943984943_item	2273539	et	3	main
sõpru	doc_213943984943_item	2273540	et	3	main
õue	doc_213943984943_item	2273542	et	4	main
see	doc_213943984943_item	2273547	et	3	main
vahva	doc_213943984943_item	2273549	et	4	main
väga	doc_213943984941_item	2273126	et	3	main
pole	doc_213943984941_item	2273130	et	3	main
lõbus	doc_213943984941_item	2273136	et	4	main
koos	doc_213943984941_item	2273141	et	4	main
kõik	doc_213943984941_item	2273147	et	4	main
päevitasime	doc_213943984941_item	2273152	et	3	main
peterburis	doc_213943984941_item	2273160	et	4	main
näha	doc_213943984941_item	2273167	et	3	main
ei	doc_213943984941_item	2273170	et	4	main
tükkaega	doc_213943984941_item	2273172	et	4	main
lõpuks	doc_213943984941_item	2273180	et	4	main
azoovi	doc_213943984941_item	2273196	et	4	main
meres	doc_213943984941_item	2273197	et	3	main
nautida	doc_213943984941_item	2273204	et	3	main
on	doc_213943984942_item	2273230	et	4	main
isa	doc_213943984942_item	2273233	et	4	main
noorem	doc_213943984942_item	2273235	et	4	main
ülikooli	doc_213943984942_item	2273246	et	4	main
õppima	doc_213943984942_item	2273247	et	3	main
olnud	doc_213943984942_item	2273252	et	4	main
olengi	doc_213943984942_item	2273257	et	4	main
saanud	doc_213943984942_item	2273258	et	4	main
palju	doc_213943984942_item	2273260	et	4	main
ma	doc_213943984942_item	2273268	et	3	main
ära	doc_213943984942_item	2273274	et	4	main
aega	doc_213943984942_item	2273279	et	4	main
sellepärast	doc_213943984942_item	2273292	et	3	main
ning	doc_213943984942_item	2273326	et	3	main
klassist	doc_213943984942_item	2273330	et	3	main
juba	doc_213943984942_item	2273338	et	3	main
kümme	doc_213943984942_item	2273339	et	3	main
ning	doc_213943984942_item	2273341	et	3	main
aina	doc_213943984942_item	2273348	et	4	main
hakkanud	doc_213943984942_item	2273351	et	4	main
naiskonnas	doc_213943984942_item	2273354	et	4	main
aastat	doc_213943984942_item	2273358	et	3	main
kasvavad	doc_213943984942_item	2273361	et	4	main
päev	doc_213943984942_item	2273363	et	3	main
pärast	doc_213943984942_item	2273364	et	4	main
õppima	doc_213943984942_item	2273373	et	3	main
ülikooli	doc_213943984942_item	2273378	et	4	main
andnud	doc_213943984942_item	2273385	et	4	main
väikestele	doc_213943984942_item	2273387	et	4	main
mis	doc_213943984942_item	2273389	et	4	main
rõõmu	doc_213943984942_item	2273392	et	4	main
ellu	doc_213943984942_item	2273394	et	4	main
toonud	doc_213943984942_item	2273395	et	4	main
mu	doc_213943984942_item	2273400	et	3	main
nimetada	doc_213943984942_item	2273402	et	3	main
ma	doc_213943984942_item	2273413	et	3	main
et	doc_213943984942_item	2273415	et	3	main
ole	doc_213943984942_item	2273417	et	4	main
kui	doc_213943984942_item	2273425	et	3	main
on	doc_213943984942_item	2273431	et	4	main
halvemaid	doc_213943984942_item	2273435	et	4	main
elus	doc_213943984942_item	2273438	et	4	main
siis	doc_213943984942_item	2273449	et	3	main
tervis	doc_213943984942_item	2273452	et	3	main
tihtipeale	doc_213943984942_item	2273457	et	3	main
pärast	doc_213943984942_item	2273460	et	4	main
mul	doc_213943984942_item	2273462	et	3	main
tolles	doc_213943984942_item	2273487	et	4	main
kaua	doc_213943984942_item	2273498	et	3	main
paranesid	doc_213943984942_item	2273502	et	4	main
kiiresti	doc_213943984942_item	2273504	et	3	main
paremini	doc_213943984942_item	2273506	et	4	main
ei	doc_213943984942_item	2273513	et	4	main
ole	doc_213943984942_item	2273514	et	4	main
temaga	doc_213943984942_item	2273515	et	3	main
mingeid	doc_213943984942_item	2273516	et	3	main
tülisid	doc_213943984942_item	2273517	et	3	main
olnud	doc_213943984942_item	2273518	et	4	main
minu	doc_213943984943_item	2273520	et	3	main
perekonnanimi	doc_213943984943_item	2273524	et	3	main
kuueaastane	doc_213943984943_item	2273527	et	4	main
ema	doc_213943984943_item	2273529	et	4	main
rulluiskudega	doc_213943984943_item	2273541	et	3	main
koos	doc_213943984943_item	2273543	et	4	main
õhtul	doc_213943984943_item	2273551	et	3	main
põlved	doc_213943984943_item	2273563	et	4	main
mul	doc_213943984943_item	2273567	et	3	main
väga	doc_213943984943_item	2273569	et	3	main
lapsepõlvest	doc_213943984943_item	2273571	et	4	main
ma	doc_213943984943_item	2273574	et	3	main
vaja	doc_213943984941_item	2273203	et	4	main
iga	doc_213943984941_item	2273205	et	4	main
ja	doc_213943984941_item	2273209	et	3	main
väärtustama	doc_213943984941_item	2273210	et	3	main
seda	doc_213943984941_item	2273211	et	3	main
juba	doc_213943984941_item	2273214	et	3	main
essee	doc_213943984942_item	2273216	et	4	main
minu	doc_213943984942_item	2273217	et	3	main
nimi	doc_213943984942_item	2273218	et	3	main
ma	doc_213943984942_item	2273222	et	3	main
medõde	doc_213943984942_item	2273231	et	4	main
töötaja	doc_213943984942_item	2273234	et	4	main
vend	doc_213943984942_item	2273236	et	3	main
nagu	doc_213943984942_item	2273253	et	3	main
saada	doc_213943984942_item	2273267	et	4	main
olen	doc_213943984942_item	2273269	et	3	main
et	doc_213943984942_item	2273276	et	3	main
lapsepõlvest	doc_213943984942_item	2273287	et	4	main
saati	doc_213943984942_item	2273288	et	3	main
olen	doc_213943984942_item	2273289	et	3	main
pärast	doc_213943984942_item	2273294	et	4	main
üheksanda	doc_213943984942_item	2273295	et	3	main
klassi	doc_213943984942_item	2273296	et	4	main
lõpetamist	doc_213943984942_item	2273297	et	4	main
minna	doc_213943984942_item	2273298	et	3	main
eesti	doc_213943984942_item	2273299	et	4	main
kooli	doc_213943984942_item	2273300	et	4	main
vene	doc_213943984942_item	2273301	et	4	main
klassi	doc_213943984942_item	2273302	et	4	main
ja	doc_213943984942_item	2273303	et	3	main
sealt	doc_213943984942_item	2273304	et	4	main
edasi	doc_213943984942_item	2273305	et	3	main
ülikooli	doc_213943984942_item	2273306	et	4	main
mitte	doc_213943984942_item	2273307	et	3	main
et	doc_213943984942_item	2273308	et	3	main
eesti	doc_213943984942_item	2273309	et	4	main
kool	doc_213943984942_item	2273310	et	4	main
oleks	doc_213943984942_item	2273311	et	3	main
mulle	doc_213943984942_item	2273312	et	4	main
hirmsasti	doc_213943984942_item	2273313	et	3	main
meeldinud	doc_213943984942_item	2273314	et	4	main
või	doc_213943984942_item	2273315	et	4	main
põhieesmärgiks	doc_213943984942_item	2273316	et	3	main
olnud	doc_213943984942_item	2273317	et	4	main
ma	doc_213943984942_item	2273318	et	3	main
teadsin	doc_213943984942_item	2273319	et	3	main
et	doc_213943984942_item	2273320	et	3	main
ema	doc_213943984942_item	2273248	et	4	main
mulle	doc_213943984942_item	2273250	et	4	main
alati	doc_213943984942_item	2273251	et	4	main
just	doc_213943984942_item	2273255	et	3	main
elus	doc_213943984942_item	2273265	et	4	main
hakkama	doc_213943984942_item	2273266	et	3	main
suutnud	doc_213943984942_item	2273270	et	4	main
oma	doc_213943984942_item	2273271	et	4	main
elu	doc_213943984942_item	2273272	et	4	main
mul	doc_213943984942_item	2273277	et	3	main
on	doc_213943984942_item	2273278	et	4	main
nii	doc_213943984942_item	2273280	et	3	main
sõprade	doc_213943984942_item	2273281	et	3	main
jaoks	doc_213943984942_item	2273282	et	4	main
kui	doc_213943984942_item	2273283	et	3	main
harrastuste	doc_213943984942_item	2273285	et	4	main
jaoks	doc_213943984942_item	2273286	et	4	main
otsustasingi	doc_213943984942_item	2273293	et	3	main
saan	doc_213943984942_item	2273322	et	4	main
korraliku	doc_213943984942_item	2273324	et	3	main
suhu	doc_213943984942_item	2273328	et	3	main
neljandast	doc_213943984942_item	2273329	et	3	main
peale	doc_213943984942_item	2273331	et	4	main
aastat	doc_213943984942_item	2273340	et	3	main
paremini	doc_213943984942_item	2273349	et	4	main
juba	doc_213943984942_item	2273356	et	3	main
kooli	doc_213943984942_item	2273365	et	4	main
lõpetamist	doc_213943984942_item	2273366	et	4	main
minna	doc_213943984942_item	2273368	et	3	main
pedagoogika	doc_213943984942_item	2273370	et	4	main
ülikooli	doc_213943984942_item	2273371	et	4	main
kehakultuuri	doc_213943984942_item	2273372	et	4	main
kui	doc_213943984942_item	2273376	et	3	main
olen	doc_213943984942_item	2273383	et	3	main
ka	doc_213943984942_item	2273391	et	3	main
elus	doc_213943984942_item	2273401	et	4	main
seda	doc_213943984942_item	2273403	et	3	main
ja	doc_213943984942_item	2273409	et	3	main
tegelenud	doc_213943984942_item	2273333	et	4	main
praeguseks	doc_213943984942_item	2273335	et	3	main
on	doc_213943984942_item	2273336	et	4	main
selle	doc_213943984942_item	2273342	et	4	main
mängima	doc_213943984942_item	2273350	et	3	main
mu	doc_213943984942_item	2273359	et	3	main
peale	doc_213943984942_item	2273374	et	4	main
sügisest	doc_213943984942_item	2273384	et	4	main
on	doc_213943984942_item	2273390	et	4	main
mu	doc_213943984942_item	2273405	et	3	main
suur	doc_213943984942_item	2273408	et	3	main
hele	doc_213943984942_item	2273410	et	3	main
tunne	doc_213943984942_item	2273411	et	4	main
armastus	doc_213943984942_item	2273412	et	4	main
ei	doc_213943984942_item	2273416	et	4	main
maal	doc_213943984942_item	2273419	et	4	main
kes	doc_213943984942_item	2273420	et	4	main
saaks	doc_213943984942_item	2273421	et	3	main
on	doc_213943984942_item	2273428	et	4	main
üks	doc_213943984942_item	2273434	et	3	main
tundeid	doc_213943984942_item	2273436	et	3	main
mängima	doc_213943984942_item	2273444	et	3	main
sest	doc_213943984942_item	2273446	et	4	main
oli	doc_213943984942_item	2273448	et	3	main
vedasalt	doc_213943984942_item	2273453	et	4	main
tervise	doc_213943984942_item	2273459	et	3	main
ka	doc_213943984942_item	2273463	et	3	main
ma	doc_213943984942_item	2273484	et	3	main
et	doc_213943984942_item	2273486	et	3	main
mina	doc_213943984942_item	2273490	et	4	main
süüdi	doc_213943984942_item	2273491	et	4	main
aga	doc_213943984942_item	2273493	et	3	main
kestnud	doc_213943984942_item	2273495	et	4	main
üsna	doc_213943984942_item	2273503	et	3	main
mängima	doc_213943984942_item	2273509	et	3	main
on	doc_213943984943_item	2273522	et	4	main
eesnimi	doc_213943984943_item	2273523	et	3	main
kui	doc_213943984943_item	2273525	et	3	main
olin	doc_213943984943_item	2273526	et	3	main
laps	doc_213943984943_item	2273528	et	4	main
ma	doc_213943984943_item	2273538	et	3	main
oli	doc_213943984943_item	2273548	et	3	main
kutsus	doc_213943984943_item	2273554	et	4	main
mind	doc_213943984943_item	2273555	et	4	main
sõitsin	doc_213943984943_item	2273558	et	3	main
krimustusega	doc_213943984943_item	2273565	et	4	main
ja	doc_213943984943_item	2273566	et	3	main
valus	doc_213943984943_item	2273570	et	4	main
saadik	doc_213943984943_item	2273572	et	4	main
andis	doc_213943984943_item	2273579	et	3	main
peotantsuringi	doc_213943984943_item	2273581	et	4	main
see	doc_213943984943_item	2273582	et	3	main
mulle	doc_213943984943_item	2273584	et	4	main
olin	doc_213943984943_item	2273591	et	3	main
liiga	doc_213943984943_item	2273592	et	4	main
kõik	doc_213943984943_item	2273636	et	4	main
kõik	doc_213943984943_item	2273652	et	4	main
3	doc_213943984944_item	2273661	et	2	main
1984	doc_213943984944_item	2273663	et	2	main
laohoidjana	doc_213943984944_item	2273670	et	3	main
ta	doc_213943984944_item	2273673	et	4	main
ja	doc_213943984944_item	2273677	et	3	main
inimene	doc_213943984944_item	2273679	et	3	main
soojendab	doc_213943984944_item	2273682	et	3	main
teed	doc_213943984944_item	2273699	et	4	main
ma	doc_213943984944_item	2273724	et	3	main
siis	doc_213943984944_item	2273727	et	3	main
kohal	doc_213943984944_item	2273743	et	4	main
mul	doc_213943984944_item	2273745	et	3	main
oligi	doc_213943984944_item	2273758	et	3	main
see	doc_213943984944_item	2273764	et	3	main
oma	doc_213943984944_item	2273787	et	4	main
taltsutamiseks	doc_213943984944_item	2273789	et	4	main
ja	doc_213943984944_item	2273790	et	3	main
edasi	doc_213943984944_item	2273797	et	3	main
iga	doc_213943984944_item	2273799	et	4	main
esimesed	doc_213943984944_item	2273803	et	3	main
eksamid	doc_213943984944_item	2273805	et	3	main
lõpetamise	doc_213943984944_item	2273808	et	4	main
kooli	doc_213943984944_item	2273810	et	4	main
ka	doc_213943984944_item	2273821	et	3	main
elada	doc_213943984942_item	2273422	et	3	main
mu	doc_213943984942_item	2273426	et	3	main
muutunud	doc_213943984942_item	2273433	et	4	main
ma	doc_213943984942_item	2273442	et	3	main
tervis	doc_213943984942_item	2273447	et	3	main
oli	doc_213943984942_item	2273454	et	3	main
tuju	doc_213943984942_item	2273456	et	4	main
on	doc_213943984942_item	2273461	et	4	main
probleeme	doc_213943984942_item	2273465	et	3	main
kuna	doc_213943984942_item	2273466	et	3	main
puudun	doc_213943984942_item	2273467	et	3	main
tihti	doc_213943984942_item	2273468	et	3	main
aga	doc_213943984942_item	2273469	et	3	main
see	doc_213943984942_item	2273470	et	3	main
ei	doc_213943984942_item	2273471	et	4	main
ole	doc_213943984942_item	2273472	et	4	main
kõige	doc_213943984942_item	2273473	et	4	main
hullem	doc_213943984942_item	2273474	et	4	main
kõige	doc_213943984942_item	2273475	et	4	main
kurvem	doc_213943984942_item	2273476	et	4	main
mu	doc_213943984942_item	2273477	et	3	main
elus	doc_213943984942_item	2273478	et	4	main
oli	doc_213943984942_item	2273479	et	3	main
see	doc_213943984942_item	2273480	et	3	main
kui	doc_213943984942_item	2273481	et	3	main
tülitsesime	doc_213943984942_item	2273482	et	3	main
sant	doc_213943984942_item	2273458	et	3	main
ülikoolis	doc_213943984942_item	2273464	et	4	main
olin	doc_213943984942_item	2273489	et	3	main
õnneks	doc_213943984942_item	2273492	et	4	main
ei	doc_213943984942_item	2273494	et	4	main
suhted	doc_213943984942_item	2273500	et	3	main
ja	doc_213943984942_item	2273508	et	3	main
viimasel	doc_213943984942_item	2273511	et	3	main
see	doc_213943984942_item	2273496	et	3	main
arusaamatus	doc_213943984942_item	2273497	et	4	main
hakkasin	doc_213943984942_item	2273505	et	3	main
treenima	doc_213943984942_item	2273507	et	3	main
essee	doc_213943984943_item	2273519	et	4	main
nimi	doc_213943984943_item	2273521	et	3	main
rulluisud	doc_213943984943_item	2273533	et	3	main
me	doc_213943984943_item	2273544	et	4	main
aga	doc_213943984943_item	2273550	et	3	main
kui	doc_213943984943_item	2273552	et	3	main
koju	doc_213943984943_item	2273556	et	3	main
maha	doc_213943984943_item	2273561	et	4	main
mu	doc_213943984943_item	2273562	et	3	main
olid	doc_213943984943_item	2273564	et	4	main
oli	doc_213943984943_item	2273568	et	3	main
olen	doc_213943984943_item	2273573	et	3	main
ja	doc_213943984943_item	2273589	et	3	main
ülikooli	doc_213943984943_item	2273621	et	4	main
oli	doc_213943984943_item	2273623	et	3	main
ma	doc_213943984943_item	2273628	et	3	main
et	doc_213943984943_item	2273635	et	3	main
eesti	doc_213943984943_item	2273639	et	4	main
keeles	doc_213943984943_item	2273640	et	4	main
aga	doc_213943984943_item	2273641	et	3	main
praegu	doc_213943984943_item	2273642	et	3	main
loodan	doc_213943984943_item	2273650	et	3	main
et	doc_213943984943_item	2273651	et	3	main
sündisin	doc_213943984944_item	2273659	et	3	main
aastal	doc_213943984944_item	2273664	et	3	main
sõbralik	doc_213943984944_item	2273676	et	3	main
naeratus	doc_213943984944_item	2273681	et	4	main
oleme	doc_213943984944_item	2273685	et	3	main
väga	doc_213943984944_item	2273687	et	3	main
tema	doc_213943984944_item	2273689	et	4	main
ja	doc_213943984944_item	2273691	et	3	main
õiget	doc_213943984944_item	2273698	et	3	main
elus	doc_213943984944_item	2273700	et	4	main
kinkis	doc_213943984943_item	2273530	et	3	main
sünnipäevaks	doc_213943984943_item	2273532	et	3	main
see	doc_213943984943_item	2273534	et	3	main
tore	doc_213943984943_item	2273536	et	3	main
uisutasime	doc_213943984943_item	2273545	et	3	main
ja	doc_213943984943_item	2273546	et	3	main
mina	doc_213943984943_item	2273557	et	4	main
ja	doc_213943984943_item	2273559	et	3	main
tantsida	doc_213943984943_item	2273576	et	3	main
ema	doc_213943984943_item	2273578	et	4	main
mind	doc_213943984943_item	2273580	et	4	main
mul	doc_213943984943_item	2273585	et	3	main
palju	doc_213943984943_item	2273587	et	4	main
ma	doc_213943984943_item	2273590	et	3	main
väsinud	doc_213943984943_item	2273593	et	4	main
aga	doc_213943984943_item	2273594	et	3	main
mõni	doc_213943984943_item	2273595	et	3	main
aega	doc_213943984943_item	2273596	et	4	main
pärast	doc_213943984943_item	2273597	et	4	main
ma	doc_213943984943_item	2273598	et	3	main
osalesin	doc_213943984943_item	2273599	et	3	main
võistluses	doc_213943984943_item	2273600	et	3	main
ja	doc_213943984943_item	2273601	et	3	main
esimest	doc_213943984943_item	2273603	et	4	main
sain	doc_213943984943_item	2273602	et	3	main
kohta	doc_213943984943_item	2273604	et	4	main
ma	doc_213943984943_item	2273605	et	3	main
oli	doc_213943984943_item	2273606	et	3	main
õnnelik	doc_213943984943_item	2273607	et	3	main
ja	doc_213943984943_item	2273608	et	3	main
tahtsin	doc_213943984943_item	2273609	et	3	main
rohkem	doc_213943984943_item	2273610	et	4	main
trennida	doc_213943984943_item	2273611	et	4	main
ja	doc_213943984943_item	2273612	et	3	main
tantsida	doc_213943984943_item	2273613	et	3	main
kõige	doc_213943984943_item	2273614	et	4	main
olulisem	doc_213943984943_item	2273615	et	4	main
oli	doc_213943984943_item	2273616	et	3	main
sündmus	doc_213943984943_item	2273617	et	3	main
kui	doc_213943984943_item	2273618	et	3	main
ma	doc_213943984943_item	2273619	et	3	main
ostusin	doc_213943984943_item	2273620	et	4	main
raske	doc_213943984943_item	2273625	et	4	main
õppida	doc_213943984943_item	2273626	et	3	main
sest	doc_213943984943_item	2273627	et	4	main
ei	doc_213943984943_item	2273631	et	4	main
saanud	doc_213943984943_item	2273632	et	4	main
aru	doc_213943984943_item	2273633	et	4	main
loengut	doc_213943984943_item	2273637	et	3	main
õpin	doc_213943984943_item	2273644	et	3	main
saab	doc_213943984943_item	2273653	et	3	main
minu	doc_213943984944_item	2273665	et	3	main
töötab	doc_213943984944_item	2273667	et	3	main
sadamas	doc_213943984944_item	2273669	et	4	main
oma	doc_213943984944_item	2273671	et	4	main
me	doc_213943984944_item	2273684	et	4	main
jõudu	doc_213943984944_item	2273695	et	4	main
ema	doc_213943984943_item	2273553	et	4	main
kukkusin	doc_213943984943_item	2273560	et	3	main
tahtnud	doc_213943984943_item	2273575	et	4	main
meeldis	doc_213943984943_item	2273583	et	3	main
oli	doc_213943984943_item	2273586	et	3	main
trennisid	doc_213943984943_item	2273588	et	3	main
algusest	doc_213943984943_item	2273622	et	4	main
väga	doc_213943984943_item	2273624	et	3	main
mitte	doc_213943984943_item	2273629	et	3	main
midagi	doc_213943984943_item	2273630	et	4	main
olid	doc_213943984943_item	2273638	et	4	main
eesti	doc_213943984943_item	2273646	et	4	main
keelt	doc_213943984943_item	2273647	et	4	main
ära	doc_213943984943_item	2273648	et	4	main
ja	doc_213943984943_item	2273649	et	3	main
korda	doc_213943984943_item	2273654	et	4	main
minu	doc_213943984944_item	2273656	et	3	main
ma	doc_213943984944_item	2273658	et	3	main
südamet	doc_213943984944_item	2273683	et	4	main
emaga	doc_213943984944_item	2273686	et	3	main
lähedased	doc_213943984944_item	2273688	et	3	main
leida	doc_213943984944_item	2273696	et	3	main
oma	doc_213943984944_item	2273697	et	4	main
lapsepõlvest	doc_213943984944_item	2273701	et	4	main
tegema	doc_213943984944_item	2273721	et	3	main
astusin	doc_213943984944_item	2273725	et	3	main
võistlust	doc_213943984944_item	2273733	et	3	main
esimesel	doc_213943984944_item	2273742	et	3	main
oli	doc_213943984944_item	2273746	et	3	main
üks	doc_213943984944_item	2273753	et	3	main
saavutamine	doc_213943984944_item	2273761	et	4	main
kergejõustiku	doc_213943984944_item	2273762	et	3	main
oli	doc_213943984944_item	2273765	et	3	main
tegevusala	doc_213943984944_item	2273786	et	4	main
tunnete	doc_213943984944_item	2273792	et	4	main
läks	doc_213943984944_item	2273795	et	3	main
ja	doc_213943984944_item	2273798	et	3	main
lähenesid	doc_213943984944_item	2273801	et	4	main
päev	doc_213943984944_item	2273809	et	3	main
lõpetamine	doc_213943984944_item	2273811	et	4	main
oli	doc_213943984944_item	2273812	et	3	main
minu	doc_213943984944_item	2273813	et	3	main
jaoks	doc_213943984944_item	2273814	et	4	main
sündmus	doc_213943984944_item	2273817	et	3	main
kurb	doc_213943984944_item	2273823	et	3	main
mu	doc_213943984944_item	2273827	et	3	main
mõnikord	doc_213943984944_item	2273847	et	3	main
ka	doc_213943984944_item	2273848	et	3	main
kui	doc_213943984944_item	2273859	et	3	main
me	doc_213943984944_item	2273860	et	4	main
oli	doc_213943984944_item	2273866	et	3	main
meel	doc_213943984944_item	2273869	et	4	main
ma	doc_213943984944_item	2273871	et	3	main
ja	doc_213943984944_item	2273875	et	3	main
järgmine	doc_213943984944_item	2273879	et	3	main
oli	doc_213943984944_item	2273881	et	3	main
oma	doc_213943984944_item	2273893	et	4	main
tulevikku	doc_213943984944_item	2273895	et	4	main
õppimisega	doc_213943984944_item	2273898	et	4	main
läksin	doc_213943984944_item	2273902	et	3	main
prantsuse	doc_213943984944_item	2273912	et	3	main
huvitavate	doc_213943984944_item	2273927	et	4	main
ja	doc_213943984944_item	2273930	et	3	main
kõrval	doc_213943984944_item	2273933	et	4	main
hakkas	doc_213943984944_item	2273949	et	3	main
kohe	doc_213943984944_item	2273951	et	4	main
sõbralik	doc_213943984944_item	2273956	et	3	main
päeval	doc_213943984944_item	2273967	et	3	main
ma	doc_213943984944_item	2273968	et	3	main
teine	doc_213943984944_item	2273999	et	3	main
ma	doc_213943984944_item	2274009	et	3	main
mõnele	doc_213943984944_item	2274015	et	3	main
võib	doc_213943984944_item	2274017	et	3	main
kellega	doc_213943984944_item	2274021	et	3	main
end	doc_213943984944_item	2274028	et	4	main
ma	doc_213943984944_item	2274032	et	3	main
sündmus	doc_213943984944_item	2274041	et	3	main
ma	doc_213943984944_item	2274067	et	3	main
õnneks	doc_213943984944_item	2274072	et	4	main
teda	doc_213943984944_item	2274073	et	4	main
üles	doc_213943984944_item	2274075	et	3	main
üks	doc_213943984944_item	2274076	et	3	main
siis	doc_213943984943_item	2273577	et	3	main
sellepärast	doc_213943984943_item	2273634	et	3	main
ma	doc_213943984943_item	2273643	et	3	main
siin	doc_213943984943_item	2273645	et	4	main
essee	doc_213943984944_item	2273655	et	4	main
elulugu	doc_213943984944_item	2273657	et	4	main
tallinnas	doc_213943984944_item	2273660	et	4	main
novembril	doc_213943984944_item	2273662	et	3	main
ema	doc_213943984944_item	2273666	et	4	main
paljassaare	doc_213943984944_item	2273668	et	3	main
iseloomult	doc_213943984944_item	2273672	et	3	main
on	doc_213943984944_item	2273674	et	4	main
väga	doc_213943984944_item	2273675	et	3	main
rõõmsameelne	doc_213943984944_item	2273678	et	3	main
kelle	doc_213943984944_item	2273680	et	4	main
armastus	doc_213943984944_item	2273690	et	4	main
tähelepanu	doc_213943984944_item	2273692	et	4	main
annavad	doc_213943984944_item	2273693	et	3	main
mulle	doc_213943984944_item	2273694	et	4	main
saadik	doc_213943984944_item	2273702	et	4	main
olen	doc_213943984944_item	2273703	et	3	main
harrastanud	doc_213943984944_item	2273704	et	4	main
mitut	doc_213943984944_item	2273705	et	4	main
asja	doc_213943984944_item	2273706	et	4	main
korraga	doc_213943984944_item	2273707	et	4	main
aga	doc_213943984944_item	2273708	et	3	main
minu	doc_213943984944_item	2273709	et	3	main
lemmiktegevus	doc_213943984944_item	2273710	et	4	main
oli	doc_213943984944_item	2273711	et	3	main
ikkagi	doc_213943984944_item	2273712	et	4	main
sport	doc_213943984944_item	2273713	et	3	main
juba	doc_213943984944_item	2273714	et	3	main
5	doc_213943984944_item	2273715	et	2	main
eluaastast	doc_213943984944_item	2273716	et	4	main
hakkas	doc_213943984944_item	2273717	et	3	main
isa	doc_213943984944_item	2273718	et	4	main
minuga	doc_213943984944_item	2273719	et	3	main
trenni	doc_213943984944_item	2273720	et	4	main
kui	doc_213943984944_item	2273723	et	3	main
ei	doc_213943984944_item	2273729	et	4	main
see	doc_213943984944_item	2273735	et	3	main
minu	doc_213943984944_item	2273737	et	3	main
sest	doc_213943984944_item	2273739	et	4	main
kuigi	doc_213943984944_item	2273744	et	3	main
võimalusi	doc_213943984944_item	2273749	et	3	main
tulevikus	doc_213943984944_item	2273751	et	4	main
sündmustest	doc_213943984944_item	2273755	et	4	main
võistlusel	doc_213943984944_item	2273763	et	3	main
aeg	doc_213943984944_item	2273794	et	3	main
kooli	doc_213943984944_item	2273807	et	4	main
ma	doc_213943984944_item	2273728	et	3	main
jätnud	doc_213943984944_item	2273730	et	4	main
harrastuseks	doc_213943984944_item	2273738	et	4	main
olid	doc_213943984944_item	2273741	et	4	main
palju	doc_213943984944_item	2273747	et	4	main
minu	doc_213943984944_item	2273756	et	3	main
koha	doc_213943984944_item	2273760	et	4	main
kõige	doc_213943984944_item	2273766	et	4	main
meenukam	doc_213943984944_item	2273767	et	4	main
päev	doc_213943984944_item	2273768	et	3	main
sest	doc_213943984944_item	2273769	et	4	main
kõik	doc_213943984944_item	2273770	et	4	main
oli	doc_213943984944_item	2273771	et	3	main
nii	doc_213943984944_item	2273772	et	3	main
ootamatu	doc_213943984944_item	2273773	et	4	main
ma	doc_213943984944_item	2273774	et	3	main
hüppasin	doc_213943984944_item	2273775	et	3	main
rõõmust	doc_213943984944_item	2273776	et	3	main
tundsin	doc_213943984944_item	2273777	et	3	main
end	doc_213943984944_item	2273778	et	4	main
õnnelikuima	doc_213943984944_item	2273779	et	4	main
inimesena	doc_213943984944_item	2273780	et	3	main
sport	doc_213943984944_item	2273781	et	3	main
on	doc_213943984944_item	2273782	et	4	main
minu	doc_213943984944_item	2273783	et	3	main
arvates	doc_213943984944_item	2273784	et	4	main
parim	doc_213943984944_item	2273785	et	4	main
ja	doc_213943984944_item	2273722	et	3	main
kooli	doc_213943984944_item	2273726	et	4	main
vahele	doc_213943984944_item	2273731	et	4	main
ühtki	doc_213943984944_item	2273732	et	4	main
kahjuks	doc_213943984944_item	2273734	et	4	main
jäigi	doc_213943984944_item	2273736	et	4	main
õpingud	doc_213943984944_item	2273740	et	3	main
häid	doc_213943984944_item	2273748	et	3	main
saada	doc_213943984944_item	2273750	et	4	main
tippsportlaseks	doc_213943984944_item	2273752	et	3	main
positiivsetest	doc_213943984944_item	2273754	et	3	main
elus	doc_213943984944_item	2273757	et	4	main
esimese	doc_213943984944_item	2273759	et	3	main
energia	doc_213943984944_item	2273788	et	4	main
positiivsete	doc_213943984944_item	2273791	et	3	main
päevaga	doc_213943984944_item	2273800	et	3	main
minu	doc_213943984944_item	2273802	et	3	main
tõsised	doc_213943984944_item	2273804	et	4	main
samal	doc_213943984944_item	2273819	et	3	main
oli	doc_213943984944_item	2273826	et	3	main
kodu	doc_213943984944_item	2273829	et	4	main
aja	doc_213943984944_item	2273831	et	4	main
jooksul	doc_213943984944_item	2273832	et	4	main
poolt	doc_213943984944_item	2273839	et	4	main
kus	doc_213943984944_item	2273840	et	3	main
püüdsime	doc_213943984944_item	2273841	et	3	main
naljakaid	doc_213943984944_item	2273845	et	4	main
ebameeldivaid	doc_213943984944_item	2273849	et	3	main
samas	doc_213943984944_item	2273851	et	4	main
formaalne	doc_213943984944_item	2273857	et	3	main
edukalt	doc_213943984944_item	2273874	et	4	main
ülikooli	doc_213943984944_item	2273882	et	4	main
et	doc_213943984944_item	2273891	et	3	main
keele	doc_213943984944_item	2273897	et	4	main
nõnda	doc_213943984944_item	2273900	et	3	main
ja	doc_213943984944_item	2273908	et	3	main
ma	doc_213943984944_item	2273911	et	3	main
filoloogias	doc_213943984944_item	2273913	et	3	main
muutunud	doc_213943984944_item	2273922	et	4	main
sõpru	doc_213943984944_item	2273925	et	3	main
tutvusin	doc_213943984944_item	2273926	et	3	main
ühes	doc_213943984944_item	2273944	et	4	main
mulle	doc_213943984944_item	2273950	et	4	main
palju	doc_213943984944_item	2273959	et	4	main
asju	doc_213943984944_item	2273961	et	3	main
oleks	doc_213943984944_item	2273963	et	3	main
hästi	doc_213943984944_item	2273964	et	3	main
teada	doc_213943984944_item	2273970	et	3	main
väga	doc_213943984944_item	2274000	et	3	main
saamiseks	doc_213943984944_item	2273793	et	4	main
aga	doc_213943984944_item	2273796	et	3	main
ja	doc_213943984944_item	2273806	et	3	main
teine	doc_213943984944_item	2273815	et	3	main
positiivne	doc_213943984944_item	2273816	et	3	main
ehkki	doc_213943984944_item	2273818	et	3	main
ajal	doc_213943984944_item	2273820	et	4	main
teine	doc_213943984944_item	2273828	et	3	main
lõpuaktuseks	doc_213943984944_item	2273833	et	3	main
kontserdi	doc_213943984944_item	2273837	et	3	main
välja	doc_213943984944_item	2273842	et	4	main
kuid	doc_213943984944_item	2273850	et	4	main
pool	doc_213943984944_item	2273858	et	4	main
kätte	doc_213943984944_item	2273862	et	4	main
oma	doc_213943984944_item	2273863	et	4	main
lõputunnistused	doc_213943984944_item	2273864	et	3	main
väga	doc_213943984944_item	2273867	et	3	main
lõpetasin	doc_213943984944_item	2273872	et	3	main
sisseastumine	doc_213943984944_item	2273883	et	3	main
prantsuse	doc_213943984944_item	2273896	et	3	main
ja	doc_213943984944_item	2273899	et	3	main
ma	doc_213943984944_item	2273901	et	3	main
pedagoogika	doc_213943984944_item	2273903	et	4	main
ülikooli	doc_213943984944_item	2273904	et	4	main
sisseastumine	doc_213943984944_item	2273905	et	3	main
läks	doc_213943984944_item	2273906	et	3	main
edukalt	doc_213943984944_item	2273907	et	4	main
sellega	doc_213943984944_item	2273916	et	3	main
natuke	doc_213943984944_item	2273822	et	4	main
sest	doc_213943984944_item	2273824	et	4	main
pika	doc_213943984944_item	2273830	et	4	main
tegime	doc_213943984944_item	2273835	et	3	main
klassi	doc_213943984944_item	2273838	et	4	main
õpetlike	doc_213943984944_item	2273852	et	3	main
situatsioone	doc_213943984944_item	2273853	et	3	main
pärast	doc_213943984944_item	2273854	et	4	main
seda	doc_213943984944_item	2273855	et	3	main
saime	doc_213943984944_item	2273861	et	3	main
hea	doc_213943984944_item	2273868	et	4	main
et	doc_213943984944_item	2273870	et	3	main
kooli	doc_213943984944_item	2273873	et	4	main
isegi	doc_213943984944_item	2273877	et	4	main
selleks	doc_213943984944_item	2273884	et	4	main
olin	doc_213943984944_item	2273886	et	3	main
ma	doc_213943984944_item	2273887	et	3	main
juba	doc_213943984944_item	2273888	et	3	main
otsustanud	doc_213943984944_item	2273890	et	4	main
lähimat	doc_213943984944_item	2273894	et	4	main
praegu	doc_213943984944_item	2273909	et	3	main
olen	doc_213943984944_item	2273915	et	3	main
väga	doc_213943984944_item	2273917	et	3	main
rahul	doc_213943984944_item	2273918	et	4	main
minu	doc_213943984944_item	2273919	et	3	main
elu	doc_213943984944_item	2273920	et	4	main
on	doc_213943984944_item	2273921	et	4	main
leidsin	doc_213943984944_item	2273923	et	3	main
uusi	doc_213943984944_item	2273924	et	3	main
heade	doc_213943984944_item	2273929	et	3	main
sündmuste	doc_213943984944_item	2273932	et	3	main
negatiivsed	doc_213943984944_item	2273936	et	3	main
aastal	doc_213943984944_item	2273938	et	3	main
töö	doc_213943984944_item	2273948	et	4	main
meeldima	doc_213943984944_item	2273952	et	3	main
kuna	doc_213943984944_item	2273953	et	3	main
oli	doc_213943984944_item	2273955	et	3	main
ja	doc_213943984944_item	2273957	et	3	main
ühel	doc_213943984944_item	2273966	et	3	main
sain	doc_213943984944_item	2273969	et	3	main
firma	doc_213943984944_item	2273972	et	4	main
sündmus	doc_213943984944_item	2274002	et	3	main
juhtus	doc_213943984944_item	2274003	et	3	main
magasin	doc_213943984944_item	2274013	et	4	main
ei	doc_213943984944_item	2274023	et	4	main
aga	doc_213943984944_item	2274026	et	3	main
väga	doc_213943984944_item	2274029	et	3	main
kuna	doc_213943984944_item	2274031	et	3	main
püüdsin	doc_213943984944_item	2274033	et	3	main
olla	doc_213943984944_item	2274034	et	3	main
juhtus	doc_213943984944_item	2274042	et	3	main
kui	doc_213943984944_item	2274045	et	3	main
jooksis	doc_213943984944_item	2274048	et	4	main
teda	doc_213943984944_item	2274053	et	4	main
kurvastasin	doc_213943984944_item	2274062	et	3	main
aeg-ajalt	doc_213943984944_item	2274065	et	4	main
nii	doc_213943984944_item	2274070	et	3	main
leidis	doc_213943984944_item	2274074	et	4	main
tagasi	doc_213943984944_item	2274082	et	3	main
ajast	doc_213943984944_item	2274088	et	4	main
ta	doc_213943984944_item	2274099	et	4	main
ei	doc_213943984944_item	2274118	et	4	main
kool	doc_213943984944_item	2273825	et	4	main
me	doc_213943984944_item	2273834	et	4	main
väikse	doc_213943984944_item	2273836	et	4	main
tuua	doc_213943984944_item	2273843	et	3	main
häid	doc_213943984944_item	2273844	et	3	main
ja	doc_213943984944_item	2273846	et	3	main
oli	doc_213943984944_item	2273856	et	3	main
mul	doc_213943984944_item	2273865	et	3	main
sain	doc_213943984944_item	2273876	et	3	main
medali	doc_213943984944_item	2273878	et	3	main
samm	doc_213943984944_item	2273880	et	3	main
ajaks	doc_213943984944_item	2273885	et	4	main
kindlalt	doc_213943984944_item	2273889	et	4	main
seon	doc_213943984944_item	2273892	et	3	main
õpin	doc_213943984944_item	2273910	et	3	main
ja	doc_213943984944_item	2273914	et	3	main
inimestega	doc_213943984944_item	2273928	et	3	main
rõõmsate	doc_213943984944_item	2273931	et	3	main
ma	doc_213943984944_item	2273940	et	3	main
raamatupidaja	doc_213943984944_item	2273942	et	4	main
kohalikus	doc_213943984944_item	2273945	et	4	main
see	doc_213943984944_item	2273947	et	3	main
meeskond	doc_213943984944_item	2273954	et	3	main
kuid	doc_213943984944_item	2273965	et	4	main
et	doc_213943984944_item	2273971	et	3	main
läks	doc_213943984944_item	2273973	et	3	main
kooli	doc_213943984944_item	2274005	et	4	main
kui	doc_213943984944_item	2274007	et	3	main
hilinesin	doc_213943984944_item	2274010	et	3	main
tundi	doc_213943984944_item	2274011	et	4	main
sest	doc_213943984944_item	2274012	et	4	main
see	doc_213943984944_item	2274018	et	3	main
imelik	doc_213943984944_item	2274020	et	3	main
mina	doc_213943984944_item	2274025	et	4	main
ebamugavalt	doc_213943984944_item	2274030	et	4	main
ja	doc_213943984944_item	2274036	et	3	main
kolmas	doc_213943984944_item	2274039	et	3	main
1995	doc_213943984944_item	2274043	et	2	main
minu	doc_213943984944_item	2274046	et	3	main
otsisime	doc_213943984944_item	2274052	et	3	main
väga	doc_213943984944_item	2274063	et	3	main
kiindunud	doc_213943984944_item	2274071	et	4	main
olin	doc_213943984944_item	2274084	et	3	main
elab	doc_213943984944_item	2274100	et	3	main
juba	doc_213943984944_item	2274102	et	3	main
ja	doc_213943984944_item	2274105	et	3	main
loodan	doc_213943984944_item	2274107	et	3	main
elabki	doc_213943984944_item	2274109	et	3	main
rohkem	doc_213943984944_item	2274111	et	4	main
niipalju	doc_213943984944_item	2274112	et	3	main
siis	doc_213943984944_item	2274113	et	3	main
minu	doc_213943984944_item	2274114	et	3	main
ma	doc_213943984944_item	2274117	et	3	main
palju	doc_213943984944_item	2274121	et	4	main
ma	doc_213943984944_item	2274124	et	3	main
ka	doc_213943984944_item	2274129	et	3	main
juhtuks	doc_213943984944_item	2274131	et	4	main
võtta	doc_213943984944_item	2274136	et	3	main
järjekordset	doc_213943984944_item	2274138	et	3	main
mis	doc_213943984944_item	2274140	et	4	main
paneb	doc_213943984944_item	2274145	et	3	main
elu	doc_213943984944_item	2274152	et	4	main
on	doc_213943984944_item	2274157	et	4	main
kus	doc_213943984944_item	2274159	et	3	main
rõõm	doc_213943984944_item	2274160	et	3	main
looduse	doc_213943984944_item	2274168	et	4	main
olen	doc_213943984945_item	2274172	et	3	main
sündinud	doc_213943984945_item	2274173	et	4	main
tallinnas	doc_213943984945_item	2274174	et	4	main
ning	doc_213943984945_item	2274175	et	3	main
elan	doc_213943984945_item	2274176	et	3	main
pedagoogikaülikoolis	doc_213943984945_item	2274184	et	4	main
kolmandal	doc_213943984945_item	2274188	et	3	main
aastal	doc_213943984945_item	2274193	et	3	main
õnnelik	doc_213943984945_item	2274201	et	3	main
üldse	doc_213943984945_item	2274207	et	3	main
inimene	doc_213943984945_item	2274209	et	3	main
ning	doc_213943984945_item	2274217	et	3	main
midagi	doc_213943984945_item	2274221	et	4	main
korraks	doc_213943984945_item	2274229	et	4	main
see	doc_213943984945_item	2274232	et	3	main
võimalust	doc_213943984945_item	2274236	et	3	main
olid	doc_213943984944_item	2273934	et	4	main
ka	doc_213943984944_item	2273935	et	3	main
2003	doc_213943984944_item	2273937	et	2	main
asusin	doc_213943984944_item	2273939	et	3	main
tööle	doc_213943984944_item	2273941	et	3	main
abilisena	doc_213943984944_item	2273943	et	4	main
ettevõtes	doc_213943984944_item	2273946	et	3	main
õppisin	doc_213943984944_item	2273958	et	3	main
kasulikke	doc_213943984944_item	2273960	et	3	main
kõik	doc_213943984944_item	2273962	et	4	main
pankrotti	doc_213943984944_item	2273974	et	4	main
alguses	doc_213943984944_item	2273975	et	4	main
see	doc_213943984944_item	2273976	et	3	main
kurvastas	doc_213943984944_item	2273977	et	3	main
mind	doc_213943984944_item	2273978	et	4	main
kuid	doc_213943984944_item	2273979	et	4	main
pärast	doc_213943984944_item	2273980	et	4	main
ma	doc_213943984944_item	2273981	et	3	main
võtsin	doc_213943984944_item	2273982	et	3	main
end	doc_213943984944_item	2273983	et	4	main
kokku	doc_213943984944_item	2273984	et	3	main
ja	doc_213943984944_item	2273985	et	3	main
hakkasin	doc_213943984944_item	2273986	et	3	main
väljapääsu	doc_213943984944_item	2273987	et	4	main
otsima	doc_213943984944_item	2273988	et	4	main
nüüd	doc_213943984944_item	2273989	et	4	main
ma	doc_213943984944_item	2273990	et	3	main
annan	doc_213943984944_item	2273991	et	3	main
eratunde	doc_213943984944_item	2273992	et	4	main
inglise	doc_213943984944_item	2273993	et	4	main
ja	doc_213943984944_item	2273994	et	3	main
prantsuse	doc_213943984944_item	2273995	et	3	main
keeles	doc_213943984944_item	2273996	et	4	main
kooliealistele	doc_213943984944_item	2273997	et	4	main
lastele	doc_213943984944_item	2273998	et	4	main
ebameeldiv	doc_213943984944_item	2274001	et	3	main
minuga	doc_213943984944_item	2274004	et	3	main
ajal	doc_213943984944_item	2274006	et	4	main
ükskord	doc_213943984944_item	2274008	et	3	main
sisse	doc_213943984944_item	2274014	et	4	main
inimesele	doc_213943984944_item	2274016	et	3	main
tunduda	doc_213943984944_item	2274019	et	3	main
seda	doc_213943984944_item	2274022	et	3	main
tundsin	doc_213943984944_item	2274027	et	3	main
aastal	doc_213943984944_item	2274044	et	3	main
kodust	doc_213943984944_item	2274049	et	4	main
ära	doc_213943984944_item	2274050	et	4	main
nutsin	doc_213943984944_item	2274064	et	4	main
olin	doc_213943984944_item	2274068	et	3	main
temasse	doc_213943984944_item	2274069	et	3	main
naabritest	doc_213943984944_item	2274078	et	4	main
meile	doc_213943984944_item	2274081	et	4	main
ma	doc_213943984944_item	2274083	et	3	main
ja	doc_213943984944_item	2274086	et	3	main
eesnimi	doc_213943984944_item	2274098	et	3	main
aastat	doc_213943984944_item	2274104	et	3	main
ma	doc_213943984944_item	2274106	et	3	main
et	doc_213943984944_item	2274108	et	3	main
ole	doc_213943984944_item	2274119	et	4	main
veel	doc_213943984944_item	2274120	et	4	main
elus	doc_213943984944_item	2274133	et	4	main
seda	doc_213943984944_item	2274135	et	3	main
kui	doc_213943984944_item	2274137	et	3	main
meid	doc_213943984944_item	2274146	et	4	main
mõtlema	doc_213943984944_item	2274150	et	3	main
on	doc_213943984944_item	2274167	et	4	main
seadus	doc_213943984944_item	2274169	et	4	main
prantsuse	doc_213943984945_item	2274185	et	3	main
sellel	doc_213943984945_item	2274192	et	4	main
ülikooli	doc_213943984945_item	2274194	et	4	main
lõpetada	doc_213943984945_item	2274195	et	3	main
ning	doc_213943984945_item	2274196	et	3	main
olen	doc_213943984945_item	2274197	et	3	main
ma	doc_213943984945_item	2274203	et	3	main
arvan	doc_213943984945_item	2274204	et	3	main
olen	doc_213943984945_item	2274206	et	3	main
ma	doc_213943984945_item	2274210	et	3	main
juhtu	doc_213943984944_item	2274024	et	4	main
punktuaalne	doc_213943984944_item	2274035	et	4	main
vastutustundlik	doc_213943984944_item	2274037	et	3	main
inimene	doc_213943984944_item	2274038	et	3	main
negatiivne	doc_213943984944_item	2274040	et	3	main
kass	doc_213943984944_item	2274047	et	3	main
me	doc_213943984944_item	2274051	et	4	main
kolm	doc_213943984944_item	2274054	et	3	main
päeva	doc_213943984944_item	2274055	et	4	main
juba	doc_213943984944_item	2274057	et	3	main
ja	doc_213943984944_item	2274056	et	3	main
lootust	doc_213943984944_item	2274059	et	4	main
hakkasime	doc_213943984944_item	2274058	et	3	main
kaotama	doc_213943984944_item	2274060	et	4	main
ma	doc_213943984944_item	2274061	et	3	main
sest	doc_213943984944_item	2274066	et	4	main
tõi	doc_213943984944_item	2274080	et	3	main
sellest	doc_213943984944_item	2274087	et	4	main
hakkasin	doc_213943984944_item	2274089	et	3	main
veel	doc_213943984944_item	2274090	et	4	main
hoolitsema	doc_213943984944_item	2274094	et	4	main
kassi	doc_213943984944_item	2274095	et	4	main
nimi	doc_213943984944_item	2274096	et	3	main
on	doc_213943984944_item	2274097	et	4	main
elust	doc_213943984944_item	2274115	et	3	main
elanud	doc_213943984944_item	2274122	et	4	main
et	doc_213943984944_item	2274127	et	3	main
meie	doc_213943984944_item	2274132	et	4	main
tuleb	doc_213943984944_item	2274134	et	3	main
oma	doc_213943984944_item	2274147	et	4	main
lihtne	doc_213943984944_item	2274155	et	3	main
see	doc_213943984944_item	2274156	et	3	main
ja	doc_213943984944_item	2274161	et	3	main
see	doc_213943984944_item	2274166	et	3	main
essee	doc_213943984945_item	2274170	et	4	main
ma	doc_213943984945_item	2274171	et	3	main
terve	doc_213943984945_item	2274178	et	4	main
filoloogia	doc_213943984945_item	2274186	et	4	main
ma	doc_213943984945_item	2274190	et	3	main
pärast	doc_213943984945_item	2274199	et	4	main
tegelikult	doc_213943984945_item	2274202	et	4	main
et	doc_213943984945_item	2274205	et	3	main
optimistlikult	doc_213943984945_item	2274215	et	4	main
hea	doc_213943984945_item	2274222	et	4	main
läksin	doc_213943984945_item	2274230	et	3	main
prantsuse	doc_213943984945_item	2274237	et	3	main
mind	doc_213943984945_item	2274244	et	4	main
aktiivseks	doc_213943984945_item	2274245	et	4	main
seda	doc_213943984945_item	2274249	et	3	main
reisimist	doc_213943984945_item	2274250	et	4	main
teise	doc_213943984945_item	2274277	et	4	main
ma	doc_213943984945_item	2274282	et	3	main
sõita	doc_213943984945_item	2274289	et	3	main
ma	doc_213943984945_item	2274292	et	3	main
ka	doc_213943984945_item	2274294	et	3	main
tekkis	doc_213943984945_item	2274298	et	3	main
tuleb	doc_213943984945_item	2274311	et	3	main
tänu	doc_213943984945_item	2274317	et	4	main
ma	doc_213943984945_item	2274319	et	3	main
meie	doc_213943984944_item	2274077	et	4	main
ja	doc_213943984944_item	2274079	et	3	main
üliõnnelik	doc_213943984944_item	2274085	et	3	main
paremini	doc_213943984944_item	2274091	et	4	main
tema	doc_213943984944_item	2274092	et	4	main
eest	doc_213943984944_item	2274093	et	4	main
minuga	doc_213943984944_item	2274101	et	3	main
15	doc_213943984944_item	2274103	et	2	main
veel	doc_213943984944_item	2274110	et	4	main
kuigi	doc_213943984944_item	2274116	et	3	main
tahaksin	doc_213943984944_item	2274125	et	3	main
elukogemust	doc_213943984944_item	2274139	et	3	main
suunab	doc_213943984944_item	2274142	et	3	main
meid	doc_213943984944_item	2274143	et	4	main
üle	doc_213943984944_item	2274149	et	3	main
meie	doc_213943984944_item	2274151	et	4	main
ei	doc_213943984944_item	2274153	et	4	main
ole	doc_213943984944_item	2274154	et	4	main
elu	doc_213943984944_item	2274158	et	4	main
häda	doc_213943984944_item	2274162	et	4	main
ma	doc_213943984945_item	2274181	et	3	main
tallinna	doc_213943984945_item	2274183	et	4	main
selle	doc_213943984945_item	2274198	et	4	main
õnnelik	doc_213943984945_item	2274208	et	3	main
püüan	doc_213943984945_item	2274211	et	3	main
aeg	doc_213943984945_item	2274213	et	3	main
suhtuda	doc_213943984945_item	2274216	et	3	main
olen	doc_213943984945_item	2274224	et	3	main
kui	doc_213943984945_item	2274227	et	3	main
keele	doc_213943984945_item	2274238	et	4	main
ma	doc_213943984945_item	2274251	et	3	main
paar	doc_213943984945_item	2274258	et	3	main
ja	doc_213943984945_item	2274275	et	3	main
elu	doc_213943984945_item	2274280	et	4	main
lubab	doc_213943984945_item	2274288	et	3	main
prantsusmaale	doc_213943984945_item	2274290	et	4	main
puhkuseks	doc_213943984945_item	2274291	et	4	main
üliõnnelik	doc_213943984945_item	2274295	et	3	main
võimalus	doc_213943984945_item	2274299	et	3	main
iga	doc_213943984945_item	2274312	et	4	main
autole	doc_213943984945_item	2274318	et	3	main
ka	doc_213943984945_item	2274321	et	3	main
ausalt	doc_213943984945_item	2274332	et	4	main
mõtlesin	doc_213943984945_item	2274347	et	3	main
olen	doc_213943984945_item	2274349	et	3	main
lootustega	doc_213943984945_item	2274369	et	4	main
päev	doc_213943984945_item	2274375	et	3	main
on	doc_213943984945_item	2274381	et	4	main
kõige	doc_213943984945_item	2274383	et	4	main
õnnelikumatest	doc_213943984945_item	2274384	et	4	main
kodus	doc_213943984946_item	2274389	et	4	main
elab	doc_213943984946_item	2274390	et	3	main
koduloom	doc_213943984946_item	2274393	et	3	main
päris	doc_213943984946_item	2274407	et	4	main
rahulik	doc_213943984946_item	2274408	et	3	main
sellist	doc_213943984946_item	2274416	et	4	main
siis	doc_213943984946_item	2274421	et	3	main
meie	doc_213943984946_item	2274432	et	4	main
meie	doc_213943984946_item	2274436	et	4	main
istus	doc_213943984946_item	2274441	et	4	main
otsale	doc_213943984946_item	2274446	et	4	main
sattus	doc_213943984946_item	2274447	et	3	main
saanud	doc_213943984946_item	2274455	et	4	main
ära	doc_213943984946_item	2274456	et	4	main
siis	doc_213943984946_item	2274460	et	3	main
karjus	doc_213943984946_item	2274464	et	4	main
pärast	doc_213943984946_item	2274471	et	4	main
kahju	doc_213943984946_item	2274476	et	4	main
meie	doc_213943984946_item	2274486	et	4	main
kass	doc_213943984946_item	2274487	et	3	main
natuke	doc_213943984946_item	2274491	et	4	main
terve	doc_213943984946_item	2274497	et	4	main
siis	doc_213943984946_item	2274499	et	3	main
mis	doc_213943984946_item	2274501	et	4	main
on	doc_213943984946_item	2274504	et	4	main
üks	doc_213943984947_item	2274508	et	3	main
väga	doc_213943984947_item	2274512	et	3	main
õues	doc_213943984947_item	2274522	et	4	main
ütlesid	doc_213943984947_item	2274532	et	4	main
nad	doc_213943984947_item	2274541	et	3	main
teda	doc_213943984947_item	2274543	et	4	main
elada	doc_213943984947_item	2274545	et	3	main
üht	doc_213943984944_item	2274123	et	3	main
lisada	doc_213943984944_item	2274126	et	3	main
mida	doc_213943984944_item	2274128	et	4	main
ei	doc_213943984944_item	2274130	et	4	main
õpetab	doc_213943984944_item	2274141	et	3	main
ja	doc_213943984944_item	2274144	et	3	main
elu	doc_213943984944_item	2274148	et	4	main
käivad	doc_213943984944_item	2274163	et	4	main
käsikäes	doc_213943984944_item	2274164	et	3	main
sest	doc_213943984944_item	2274165	et	4	main
siin	doc_213943984945_item	2274177	et	4	main
oma	doc_213943984945_item	2274179	et	4	main
elu	doc_213943984945_item	2274180	et	4	main
õppin	doc_213943984945_item	2274182	et	4	main
teaduskonna	doc_213943984945_item	2274187	et	4	main
kursusel	doc_213943984945_item	2274189	et	3	main
planeerin	doc_213943984945_item	2274191	et	3	main
väga	doc_213943984945_item	2274200	et	3	main
kogu	doc_213943984945_item	2274212	et	4	main
elusse	doc_213943984945_item	2274214	et	3	main
rõõmustan	doc_213943984945_item	2274218	et	3	main
alati	doc_213943984945_item	2274219	et	4	main
kui	doc_213943984945_item	2274220	et	3	main
näiteks	doc_213943984945_item	2274225	et	4	main
üleõnnelik	doc_213943984945_item	2274226	et	3	main
esimeseks	doc_213943984945_item	2274228	et	3	main
prantsusmaale	doc_213943984945_item	2274231	et	4	main
reis	doc_213943984945_item	2274233	et	4	main
andis	doc_213943984945_item	2274234	et	3	main
kasutama	doc_213943984945_item	2274241	et	3	main
muutis	doc_213943984945_item	2274243	et	3	main
ja	doc_213943984945_item	2274246	et	3	main
pärast	doc_213943984945_item	2274248	et	4	main
prantsusmaale	doc_213943984945_item	2274253	et	4	main
õppimas	doc_213943984945_item	2274254	et	3	main
ning	doc_213943984945_item	2274256	et	3	main
leidsin	doc_213943984945_item	2274276	et	3	main
leidsin	doc_213943984945_item	2274283	et	3	main
head	doc_213943984945_item	2274285	et	4	main
tööd	doc_213943984945_item	2274286	et	4	main
olin	doc_213943984945_item	2274293	et	3	main
endale	doc_213943984945_item	2274301	et	4	main
auto	doc_213943984945_item	2274303	et	4	main
on	doc_213943984945_item	2274304	et	4	main
minu	doc_213943984945_item	2274305	et	3	main
töö	doc_213943984945_item	2274306	et	4	main
jaoks	doc_213943984945_item	2274307	et	4	main
hädavajalik	doc_213943984945_item	2274308	et	3	main
kohtadesse	doc_213943984945_item	2274315	et	3	main
saan	doc_213943984945_item	2274320	et	4	main
nädalavahetustel	doc_213943984945_item	2274323	et	4	main
oma	doc_213943984945_item	2274324	et	4	main
külla	doc_213943984945_item	2274326	et	4	main
kaitseväes	doc_213943984945_item	2274331	et	3	main
oli	doc_213943984945_item	2274335	et	3	main
puudu	doc_213943984945_item	2274345	et	4	main
terve	doc_213943984945_item	2274351	et	4	main
aga	doc_213943984945_item	2274354	et	3	main
elus	doc_213943984945_item	2274386	et	4	main
essee	doc_213943984946_item	2274387	et	4	main
tubli	doc_213943984946_item	2274406	et	4	main
loomake	doc_213943984946_item	2274409	et	4	main
hakkan	doc_213943984946_item	2274412	et	3	main
mis	doc_213943984946_item	2274414	et	4	main
lõbusat	doc_213943984946_item	2274419	et	3	main
juhtub	doc_213943984945_item	2274223	et	3	main
mulle	doc_213943984945_item	2274235	et	4	main
oskust	doc_213943984945_item	2274239	et	3	main
otsustasin	doc_213943984945_item	2274252	et	3	main
minna	doc_213943984945_item	2274255	et	3	main
proovisin	doc_213943984945_item	2274257	et	3	main
ülikooli	doc_213943984945_item	2274261	et	4	main
tuluusi	doc_213943984945_item	2274260	et	4	main
astuda	doc_213943984945_item	2274262	et	3	main
muidugi	doc_213943984945_item	2274263	et	4	main
minu	doc_213943984945_item	2274264	et	3	main
ebaõnnestunud	doc_213943984945_item	2274265	et	4	main
katsed	doc_213943984945_item	2274266	et	3	main
ei	doc_213943984945_item	2274267	et	4	main
jäänud	doc_213943984945_item	2274268	et	4	main
mind	doc_213943984945_item	2274269	et	4	main
ükskõikseks	doc_213943984945_item	2274270	et	4	main
ma	doc_213943984945_item	2274271	et	3	main
analüüsisin	doc_213943984945_item	2274272	et	3	main
ebaõnnestumise	doc_213943984945_item	2274273	et	3	main
praktikas	doc_213943984945_item	2274240	et	3	main
ning	doc_213943984945_item	2274242	et	3	main
energiliseks	doc_213943984945_item	2274247	et	3	main
korda	doc_213943984945_item	2274259	et	4	main
põhjusi	doc_213943984945_item	2274274	et	3	main
oma	doc_213943984945_item	2274279	et	4	main
korraldama	doc_213943984945_item	2274281	et	3	main
mul	doc_213943984945_item	2274297	et	3	main
sest	doc_213943984945_item	2274309	et	4	main
paljudesse	doc_213943984945_item	2274314	et	3	main
sõita	doc_213943984945_item	2274322	et	3	main
praegu	doc_213943984945_item	2274329	et	3	main
rääkides	doc_213943984945_item	2274333	et	4	main
kui	doc_213943984945_item	2274338	et	3	main
väkke	doc_213943984945_item	2274341	et	3	main
tundsin	doc_213943984945_item	2274343	et	3	main
ja	doc_213943984945_item	2274346	et	3	main
kui	doc_213943984945_item	2274355	et	3	main
kolm	doc_213943984945_item	2274358	et	3	main
koju	doc_213943984945_item	2274380	et	3	main
üks	doc_213943984945_item	2274382	et	3	main
minu	doc_213943984945_item	2274385	et	3	main
selline	doc_213943984946_item	2274391	et	4	main
tore	doc_213943984946_item	2274392	et	3	main
nagu	doc_213943984946_item	2274394	et	3	main
on	doc_213943984946_item	2274403	et	4	main
mul	doc_213943984946_item	2274404	et	3	main
väga	doc_213943984946_item	2274405	et	3	main
ma	doc_213943984946_item	2274411	et	3	main
juhtus	doc_213943984946_item	2274420	et	3	main
tuleb	doc_213943984946_item	2274423	et	3	main
suvel	doc_213943984946_item	2274427	et	3	main
minu	doc_213943984946_item	2274429	et	3	main
puhkas	doc_213943984946_item	2274431	et	3	main
suvilas	doc_213943984946_item	2274433	et	3	main
ronis	doc_213943984946_item	2274435	et	4	main
kirsipuu	doc_213943984946_item	2274438	et	4	main
seal	doc_213943984946_item	2274442	et	4	main
kergesti	doc_213943984946_item	2274449	et	3	main
ja	doc_213943984946_item	2274458	et	3	main
puu	doc_213943984946_item	2274461	et	4	main
varres	doc_213943984946_item	2274467	et	4	main
minu	doc_213943984946_item	2274478	et	3	main
ja	doc_213943984946_item	2274482	et	3	main
ise	doc_213943984946_item	2274488	et	4	main
päev	doc_213943984946_item	2274498	et	3	main
naljakas	doc_213943984946_item	2274506	et	4	main
kord	doc_213943984947_item	2274509	et	4	main
oli	doc_213943984947_item	2274511	et	3	main
võimaluse	doc_213943984945_item	2274278	et	3	main
endale	doc_213943984945_item	2274284	et	4	main
mis	doc_213943984945_item	2274287	et	4	main
kui	doc_213943984945_item	2274296	et	3	main
osta	doc_213943984945_item	2274300	et	4	main
autot	doc_213943984945_item	2274302	et	3	main
mul	doc_213943984945_item	2274310	et	3	main
päev	doc_213943984945_item	2274313	et	3	main
sõita	doc_213943984945_item	2274316	et	3	main
kes	doc_213943984945_item	2274327	et	4	main
viljandis	doc_213943984945_item	2274330	et	4	main
mul	doc_213943984945_item	2274334	et	3	main
raske	doc_213943984945_item	2274337	et	4	main
läks	doc_213943984945_item	2274340	et	3	main
et	doc_213943984945_item	2274348	et	3	main
ainult	doc_213943984945_item	2274357	et	4	main
et	doc_213943984945_item	2274373	et	3	main
kui	doc_213943984945_item	2274376	et	3	main
tagasi	doc_213943984945_item	2274379	et	3	main
armas	doc_213943984946_item	2274395	et	3	main
kassikene	doc_213943984946_item	2274397	et	4	main
nimi	doc_213943984946_item	2274399	et	3	main
on	doc_213943984946_item	2274400	et	4	main
eesnimi	doc_213943984946_item	2274401	et	3	main
ta	doc_213943984946_item	2274402	et	4	main
meelde	doc_213943984946_item	2274424	et	3	main
ülejärgmisel	doc_213943984946_item	2274426	et	3	main
kui	doc_213943984946_item	2274428	et	3	main
perekond	doc_213943984946_item	2274430	et	3	main
otsale	doc_213943984946_item	2274439	et	4	main
puu	doc_213943984946_item	2274445	et	4	main
ta	doc_213943984946_item	2274448	et	4	main
küll	doc_213943984946_item	2274452	et	4	main
tulla	doc_213943984946_item	2274457	et	3	main
otsas	doc_213943984946_item	2274462	et	4	main
suur	doc_213943984946_item	2274466	et	3	main
täitsa	doc_213943984946_item	2274469	et	3	main
meie	doc_213943984946_item	2274484	et	4	main
näeb	doc_213943984946_item	2274489	et	3	main
kõik	doc_213943984946_item	2274500	et	4	main
natuke	doc_213943984946_item	2274505	et	4	main
kaks	doc_213943984947_item	2274515	et	3	main
me	doc_213943984947_item	2274518	et	4	main
väikeses	doc_213943984947_item	2274523	et	4	main
elas	doc_213943984947_item	2274525	et	3	main
enam	doc_213943984947_item	2274531	et	4	main
et	doc_213943984947_item	2274533	et	3	main
kass	doc_213943984947_item	2274535	et	3	main
nende	doc_213943984947_item	2274537	et	4	main
jätsid	doc_213943984947_item	2274542	et	4	main
ütlesid	doc_213943984947_item	2274547	et	4	main
et	doc_213943984947_item	2274548	et	3	main
see	doc_213943984947_item	2274549	et	3	main
on	doc_213943984947_item	2274551	et	4	main
nagu	doc_213943984947_item	2274572	et	3	main
ja	doc_213943984947_item	2274574	et	3	main
kassi	doc_213943984947_item	2274584	et	4	main
ärkas	doc_213943984947_item	2274605	et	3	main
kutsusin	doc_213943984947_item	2274617	et	3	main
isa	doc_213943984947_item	2274619	et	4	main
ja	doc_213943984947_item	2274625	et	3	main
äkki	doc_213943984947_item	2274627	et	3	main
liigutama	doc_213943984947_item	2274629	et	4	main
ei	doc_213943984947_item	2274634	et	4	main
mitte	doc_213943984947_item	2274636	et	3	main
väga	doc_213943984947_item	2274641	et	3	main
aga	doc_213943984947_item	2274647	et	3	main
kirjeldamine	doc_213943984948_item	2274654	et	4	main
on	doc_213943984948_item	2274657	et	4	main
juba	doc_213943984948_item	2274663	et	3	main
kaks	doc_213943984948_item	2274664	et	3	main
emaga	doc_213943984948_item	2274666	et	3	main
koos	doc_213943984948_item	2274671	et	4	main
asub	doc_213943984948_item	2274673	et	3	main
on	doc_213943984948_item	2274727	et	4	main
tervisele	doc_213943984948_item	2274729	et	3	main
jõudu	doc_213943984948_item	2274733	et	4	main
ja	doc_213943984948_item	2274734	et	3	main
tuju	doc_213943984948_item	2274736	et	4	main
elada	doc_213943984948_item	2274738	et	3	main
on	doc_213943984948_item	2274740	et	4	main
mitte	doc_213943984948_item	2274741	et	3	main
nagu	doc_213943984948_item	2274743	et	3	main
noormehe	doc_213943984945_item	2274325	et	3	main
ona	doc_213943984945_item	2274328	et	4	main
väga	doc_213943984945_item	2274336	et	3	main
ta	doc_213943984945_item	2274339	et	4	main
ma	doc_213943984945_item	2274342	et	3	main
temast	doc_213943984945_item	2274344	et	3	main
üksinda	doc_213943984945_item	2274350	et	4	main
maailmas	doc_213943984945_item	2274352	et	3	main
praegu	doc_213943984945_item	2274353	et	3	main
jääb	doc_213943984945_item	2274356	et	3	main
kuud	doc_213943984945_item	2274359	et	4	main
enne	doc_213943984945_item	2274360	et	4	main
tema	doc_213943984945_item	2274361	et	4	main
tagasitulekut	doc_213943984945_item	2274362	et	3	main
ma	doc_213943984945_item	2274363	et	3	main
ootan	doc_213943984945_item	2274364	et	3	main
kannatamatult	doc_213943984945_item	2274366	et	4	main
teda	doc_213943984945_item	2274365	et	4	main
ja	doc_213943984945_item	2274367	et	3	main
suurte	doc_213943984945_item	2274368	et	3	main
mina	doc_213943984945_item	2274370	et	4	main
samuti	doc_213943984945_item	2274371	et	3	main
arvan	doc_213943984945_item	2274372	et	3	main
see	doc_213943984945_item	2274374	et	3	main
tema	doc_213943984945_item	2274377	et	4	main
tuleb	doc_213943984945_item	2274378	et	3	main
minu	doc_213943984946_item	2274388	et	3	main
väike	doc_213943984946_item	2274396	et	4	main
kelle	doc_213943984946_item	2274398	et	4	main
kui	doc_213943984946_item	2274410	et	3	main
meenutama	doc_213943984946_item	2274413	et	4	main
temaga	doc_213943984946_item	2274415	et	3	main
toredat	doc_213943984946_item	2274417	et	3	main
ja	doc_213943984946_item	2274418	et	3	main
mulle	doc_213943984946_item	2274422	et	4	main
toilas	doc_213943984946_item	2274434	et	4	main
ja	doc_213943984946_item	2274440	et	3	main
terve	doc_213943984946_item	2274443	et	4	main
aga	doc_213943984946_item	2274450	et	3	main
alla	doc_213943984946_item	2274451	et	3	main
ise	doc_213943984946_item	2274453	et	4	main
nagu	doc_213943984946_item	2274465	et	3	main
naljakas	doc_213943984946_item	2274470	et	4	main
meil	doc_213943984946_item	2274472	et	4	main
hakkas	doc_213943984946_item	2274473	et	3	main
temast	doc_213943984946_item	2274474	et	3	main
ja	doc_213943984946_item	2274477	et	3	main
isa	doc_213943984946_item	2274479	et	4	main
võttis	doc_213943984946_item	2274480	et	3	main
redeli	doc_213943984946_item	2274481	et	3	main
päästis	doc_213943984946_item	2274483	et	3	main
ta	doc_213943984946_item	2274502	et	4	main
teeb	doc_213943984946_item	2274503	et	3	main
meil	doc_213943984947_item	2274510	et	4	main
huvitav	doc_213943984947_item	2274513	et	4	main
juhi	doc_213943984947_item	2274514	et	4	main
tagasi	doc_213943984947_item	2274517	et	3	main
seal	doc_213943984947_item	2274521	et	4	main
inimesed	doc_213943984947_item	2274527	et	3	main
majas	doc_213943984947_item	2274530	et	3	main
ise	doc_213943984947_item	2274539	et	4	main
õues	doc_213943984947_item	2274544	et	4	main
nad	doc_213943984947_item	2274546	et	3	main
üks	doc_213943984947_item	2274575	et	3	main
tulin	doc_213943984947_item	2274579	et	3	main
õue	doc_213943984947_item	2274581	et	4	main
tahtsin	doc_213943984947_item	2274583	et	3	main
lamab	doc_213943984947_item	2274594	et	3	main
ma	doc_213943984947_item	2274598	et	3	main
teda	doc_213943984947_item	2274600	et	4	main
puutuma	doc_213943984947_item	2274602	et	4	main
ta	doc_213943984947_item	2274607	et	4	main
külm	doc_213943984947_item	2274609	et	3	main
ma	doc_213943984947_item	2274613	et	3	main
tõmbas	doc_213943984947_item	2274620	et	3	main
kast	doc_213943984947_item	2274621	et	3	main
hakkas	doc_213943984947_item	2274628	et	3	main
ja	doc_213943984947_item	2274630	et	3	main
nii	doc_213943984947_item	2274632	et	3	main
aru	doc_213943984947_item	2274638	et	4	main
õnnelikud	doc_213943984947_item	2274642	et	3	main
isa	doc_213943984947_item	2274648	et	4	main
naeratas	doc_213943984947_item	2274649	et	3	main
elukoha	doc_213943984948_item	2274653	et	4	main
kahekorruseline	doc_213943984948_item	2274658	et	4	main
väike	doc_213943984948_item	2274669	et	4	main
selle	doc_213943984948_item	2274682	et	4	main
see	doc_213943984948_item	2274683	et	3	main
vaikne	doc_213943984948_item	2274686	et	3	main
kasulik	doc_213943984948_item	2274728	et	3	main
on	doc_213943984948_item	2274745	et	4	main
ka	doc_213943984948_item	2274748	et	3	main
küttepuid	doc_213943984948_item	2274756	et	3	main
osta	doc_213943984948_item	2274757	et	4	main
ja	doc_213943984948_item	2274766	et	3	main
majas	doc_213943984948_item	2274771	et	3	main
vähem	doc_213943984948_item	2274778	et	4	main
rohkem	doc_213943984948_item	2274791	et	4	main
aga	doc_213943984948_item	2274804	et	3	main
süüa	doc_213943984948_item	2274810	et	3	main
parem	doc_213943984948_item	2274818	et	4	main
kuidas	doc_213943984946_item	2274425	et	3	main
kass	doc_213943984946_item	2274437	et	3	main
päev	doc_213943984946_item	2274444	et	3	main
ei	doc_213943984946_item	2274454	et	4	main
istus	doc_213943984946_item	2274459	et	4	main
ja	doc_213943984946_item	2274463	et	3	main
oli	doc_213943984946_item	2274468	et	3	main
vaeseke	doc_213943984946_item	2274475	et	4	main
kassikest	doc_213943984946_item	2274485	et	4	main
välja	doc_213943984946_item	2274490	et	4	main
naljakas	doc_213943984946_item	2274492	et	4	main
ja	doc_213943984946_item	2274493	et	3	main
kui	doc_213943984946_item	2274494	et	3	main
teda	doc_213943984946_item	2274495	et	4	main
jälgida	doc_213943984946_item	2274496	et	3	main
essee	doc_213943984947_item	2274507	et	4	main
aastat	doc_213943984947_item	2274516	et	3	main
koolisime	doc_213943984947_item	2274519	et	4	main
eramajja	doc_213943984947_item	2274520	et	3	main
kass	doc_213943984947_item	2274526	et	3	main
kes	doc_213943984947_item	2274528	et	4	main
juurde	doc_213943984947_item	2274538	et	4	main
kass	doc_213943984947_item	2274550	et	3	main
ja	doc_213943984947_item	2274554	et	3	main
armastasime	doc_213943984947_item	2274570	et	3	main
oma	doc_213943984947_item	2274573	et	4	main
ma	doc_213943984947_item	2274578	et	3	main
õhtul	doc_213943984947_item	2274580	et	3	main
ma	doc_213943984947_item	2274586	et	3	main
nägisin	doc_213943984947_item	2274591	et	4	main
et	doc_213943984947_item	2274592	et	3	main
mitte	doc_213943984947_item	2274596	et	3	main
käega	doc_213943984947_item	2274601	et	3	main
et	doc_213943984947_item	2274603	et	3	main
ta	doc_213943984947_item	2274604	et	4	main
oli	doc_213943984947_item	2274608	et	3	main
liigu	doc_213943984947_item	2274612	et	4	main
ja	doc_213943984947_item	2274616	et	3	main
isat	doc_213943984947_item	2274618	et	4	main
kassi	doc_213943984947_item	2274623	et	4	main
ta	doc_213943984947_item	2274626	et	4	main
vaatas	doc_213943984947_item	2274631	et	3	main
nagu	doc_213943984947_item	2274633	et	3	main
midagi	doc_213943984947_item	2274637	et	4	main
et	doc_213943984947_item	2274643	et	3	main
lihtsalt	doc_213943984947_item	2274645	et	4	main
pärast	doc_213943984947_item	2274650	et	4	main
minu	doc_213943984948_item	2274655	et	3	main
eramaja	doc_213943984948_item	2274659	et	4	main
elan	doc_213943984948_item	2274661	et	3	main
aastat	doc_213943984948_item	2274665	et	3	main
ja	doc_213943984948_item	2274668	et	3	main
maja	doc_213943984948_item	2274672	et	4	main
jõe	doc_213943984948_item	2274674	et	3	main
raijoon	doc_213943984948_item	2274687	et	4	main
nabrid	doc_213943984948_item	2274689	et	4	main
rahulikud	doc_213943984948_item	2274691	et	3	main
ja	doc_213943984948_item	2274692	et	3	main
kastis	doc_213943984947_item	2274524	et	4	main
elasid	doc_213943984947_item	2274529	et	4	main
see	doc_213943984947_item	2274534	et	3	main
tuli	doc_213943984947_item	2274536	et	4	main
ja	doc_213943984947_item	2274540	et	3	main
nad	doc_213943984947_item	2274555	et	3	main
ei	doc_213943984947_item	2274556	et	4	main
tea	doc_213943984947_item	2274557	et	4	main
kui	doc_213943984947_item	2274558	et	3	main
kaua	doc_213943984947_item	2274559	et	3	main
ta	doc_213943984947_item	2274560	et	4	main
veel	doc_213943984947_item	2274561	et	4	main
elada	doc_213943984947_item	2274562	et	3	main
me	doc_213943984947_item	2274564	et	4	main
hakkame	doc_213943984947_item	2274565	et	3	main
elada	doc_213943984947_item	2274566	et	3	main
selles	doc_213943984947_item	2274567	et	4	main
väga	doc_213943984947_item	2274552	et	3	main
vana	doc_213943984947_item	2274553	et	4	main
saab	doc_213943984947_item	2274563	et	3	main
ja	doc_213943984947_item	2274569	et	3	main
kassi	doc_213943984947_item	2274571	et	4	main
kui	doc_213943984947_item	2274577	et	3	main
ma	doc_213943984947_item	2274582	et	3	main
teda	doc_213943984947_item	2274588	et	4	main
ja	doc_213943984947_item	2274595	et	3	main
aga	doc_213943984947_item	2274606	et	3	main
ei	doc_213943984947_item	2274611	et	4	main
hakkasin	doc_213943984947_item	2274614	et	3	main
et	doc_213943984947_item	2274622	et	3	main
me	doc_213943984947_item	2274639	et	4	main
magas	doc_213943984947_item	2274646	et	4	main
palju	doc_213943984947_item	2274651	et	4	main
essee	doc_213943984948_item	2274652	et	4	main
elukoht	doc_213943984948_item	2274656	et	3	main
seal	doc_213943984948_item	2274662	et	4	main
isaga	doc_213943984948_item	2274667	et	3	main
on	doc_213943984948_item	2274678	et	4	main
ilus	doc_213943984948_item	2274679	et	4	main
vaade	doc_213943984948_item	2274680	et	3	main
peale	doc_213943984948_item	2274681	et	4	main
on	doc_213943984948_item	2274684	et	4	main
väga	doc_213943984948_item	2274685	et	3	main
meil	doc_213943984948_item	2274721	et	4	main
ka	doc_213943984948_item	2274723	et	3	main
jaoks	doc_213943984948_item	2274730	et	4	main
nii	doc_213943984948_item	2274742	et	3	main
korteris	doc_213943984948_item	2274744	et	3	main
minusi	doc_213943984948_item	2274747	et	4	main
vaja	doc_213943984948_item	2274755	et	4	main
istuda	doc_213943984948_item	2274765	et	3	main
tuli	doc_213943984948_item	2274767	et	4	main
vaadata	doc_213943984948_item	2274768	et	4	main
kahjuks	doc_213943984948_item	2274769	et	4	main
kaabeltelevisiooni	doc_213943984948_item	2274773	et	4	main
me	doc_213943984948_item	2274785	et	4	main
elades	doc_213943984948_item	2274794	et	4	main
suve	doc_213943984948_item	2274802	et	4	main
ju	doc_213943984948_item	2274807	et	3	main
nad	doc_213943984948_item	2274815	et	3	main
koguaeg	doc_213943984948_item	2274817	et	3	main
ja	doc_213943984948_item	2274819	et	3	main
me	doc_213943984948_item	2274825	et	4	main
ausalt	doc_213943984948_item	2274829	et	4	main
ööeldes	doc_213943984948_item	2274830	et	4	main
meeldinud	doc_213943984948_item	2274834	et	4	main
eramajas	doc_213943984948_item	2274835	et	3	main
olin	doc_213943984948_item	2274839	et	3	main
korteris	doc_213943984948_item	2274843	et	3	main
on	doc_213943984948_item	2274853	et	4	main
muidugi	doc_213943984948_item	2274854	et	4	main
plussid	doc_213943984948_item	2274856	et	3	main
minu	doc_213943984948_item	2274864	et	3	main
lugu	doc_213943984949_item	2274868	et	4	main
see	doc_213943984949_item	2274869	et	3	main
juhtus	doc_213943984949_item	2274870	et	3	main
umbes	doc_213943984949_item	2274871	et	4	main
aastat	doc_213943984949_item	2274873	et	3	main
tagasi	doc_213943984949_item	2274874	et	3	main
kui	doc_213943984949_item	2274875	et	3	main
koer	doc_213943984949_item	2274877	et	3	main
veel	doc_213943984949_item	2274879	et	4	main
oli	doc_213943984949_item	2274883	et	3	main
vanaema	doc_213943984949_item	2274895	et	4	main
oli	doc_213943984949_item	2274897	et	3	main
üleannetu	doc_213943984949_item	2274901	et	4	main
tahas	doc_213943984949_item	2274904	et	4	main
puuris	doc_213943984949_item	2274922	et	4	main
kuidas	doc_213943984949_item	2274932	et	3	main
koerad	doc_213943984949_item	2274941	et	3	main
ja	doc_213943984949_item	2274945	et	3	main
kindel	doc_213943984949_item	2274948	et	3	main
tal	doc_213943984949_item	2274956	et	3	main
käpades	doc_213943984949_item	2274959	et	4	main
naabri	doc_213943984949_item	2274961	et	3	main
kindlasti	doc_213943984949_item	2274964	et	3	main
ma	doc_213943984950_item	2274973	et	3	main
külla	doc_213943984950_item	2274983	et	4	main
istusime	doc_213943984950_item	2275035	et	3	main
banaan	doc_213943984950_item	2275049	et	3	main
majas	doc_213943984947_item	2274568	et	3	main
kord	doc_213943984947_item	2274576	et	4	main
näha	doc_213943984947_item	2274585	et	3	main
vaatasin	doc_213943984947_item	2274587	et	3	main
kastisse	doc_213943984947_item	2274589	et	4	main
ja	doc_213943984947_item	2274590	et	3	main
kass	doc_213943984947_item	2274593	et	3	main
liigub	doc_213943984947_item	2274597	et	3	main
hakkasin	doc_213943984947_item	2274599	et	3	main
ja	doc_213943984947_item	2274610	et	3	main
nutma	doc_213943984947_item	2274615	et	3	main
võtta	doc_213943984947_item	2274624	et	3	main
saa	doc_213943984947_item	2274635	et	4	main
olime	doc_213943984947_item	2274640	et	3	main
kass	doc_213943984947_item	2274644	et	3	main
ma	doc_213943984948_item	2274660	et	3	main
vennaga	doc_213943984948_item	2274670	et	3	main
ääres	doc_213943984948_item	2274675	et	4	main
ja	doc_213943984948_item	2274676	et	3	main
aknast	doc_213943984948_item	2274677	et	4	main
ja	doc_213943984948_item	2274688	et	3	main
on	doc_213943984948_item	2274690	et	4	main
heatundlikud	doc_213943984948_item	2274693	et	3	main
õhtul	doc_213943984948_item	2274694	et	3	main
meil	doc_213943984948_item	2274695	et	4	main
on	doc_213943984948_item	2274696	et	4	main
tore	doc_213943984948_item	2274697	et	3	main
võimalus	doc_213943984948_item	2274698	et	3	main
jõe	doc_213943984948_item	2274699	et	3	main
ääres	doc_213943984948_item	2274700	et	4	main
jalutada	doc_213943984948_item	2274701	et	3	main
ja	doc_213943984948_item	2274702	et	3	main
puhke	doc_213943984948_item	2274703	et	4	main
õhuga	doc_213943984948_item	2274704	et	3	main
hingata	doc_213943984948_item	2274705	et	4	main
aga	doc_213943984948_item	2274706	et	3	main
maja	doc_213943984948_item	2274707	et	4	main
ees	doc_213943984948_item	2274708	et	4	main
on	doc_213943984948_item	2274709	et	4	main
väike	doc_213943984948_item	2274710	et	4	main
plats	doc_213943984948_item	2274712	et	4	main
mängu	doc_213943984948_item	2274711	et	4	main
kus	doc_213943984948_item	2274713	et	3	main
armastab	doc_213943984948_item	2274714	et	3	main
mängida	doc_213943984948_item	2274715	et	3	main
minu	doc_213943984948_item	2274716	et	3	main
vend	doc_213943984948_item	2274717	et	3	main
oma	doc_213943984948_item	2274718	et	4	main
sõbradega	doc_213943984948_item	2274719	et	4	main
koos	doc_213943984948_item	2274720	et	4	main
see	doc_213943984948_item	2274731	et	3	main
eramajas	doc_213943984948_item	2274739	et	3	main
on	doc_213943984948_item	2274754	et	4	main
on	doc_213943984948_item	2274760	et	4	main
nii	doc_213943984948_item	2274761	et	3	main
kamini	doc_213943984948_item	2274763	et	3	main
ees	doc_213943984948_item	2274764	et	4	main
meie	doc_213943984948_item	2274770	et	4	main
eesti	doc_213943984948_item	2274788	et	4	main
kanalid	doc_213943984948_item	2274790	et	3	main
veel	doc_213943984948_item	2274792	et	4	main
eramajas	doc_213943984948_item	2274793	et	3	main
on	doc_213943984948_item	2274795	et	4	main
eriti	doc_213943984948_item	2274801	et	3	main
ajal	doc_213943984948_item	2274803	et	4	main
oma	doc_213943984948_item	2274811	et	4	main
on	doc_213943984948_item	2274722	et	4	main
saun	doc_213943984948_item	2274724	et	3	main
saunasse	doc_213943984948_item	2274725	et	3	main
käimine	doc_213943984948_item	2274726	et	4	main
annab	doc_213943984948_item	2274732	et	3	main
tõstab	doc_213943984948_item	2274735	et	3	main
muidugi	doc_213943984948_item	2274737	et	4	main
mingid	doc_213943984948_item	2274746	et	4	main
meil	doc_213943984948_item	2274749	et	4	main
aga	doc_213943984948_item	2274758	et	3	main
meeldiv	doc_213943984948_item	2274762	et	4	main
see	doc_213943984948_item	2274775	et	3	main
istuda	doc_213943984948_item	2274777	et	3	main
teleri	doc_213943984948_item	2274779	et	3	main
ees	doc_213943984948_item	2274780	et	4	main
ja	doc_213943984948_item	2274781	et	3	main
teeb	doc_213943984948_item	2274782	et	3	main
silmad	doc_213943984948_item	2274783	et	4	main
hakkame	doc_213943984948_item	2274786	et	3	main
vaja	doc_213943984948_item	2274796	et	4	main
palju	doc_213943984948_item	2274797	et	4	main
pärast	doc_213943984948_item	2274805	et	4	main
nii	doc_213943984948_item	2274808	et	3	main
ja	doc_213943984948_item	2274813	et	3	main
maitsvam	doc_213943984948_item	2274820	et	4	main
kui	doc_213943984948_item	2274821	et	3	main
mulle	doc_213943984948_item	2274832	et	4	main
elada	doc_213943984948_item	2274836	et	3	main
tavalises	doc_213943984948_item	2274842	et	4	main
aga	doc_213943984948_item	2274844	et	3	main
aru	doc_213943984948_item	2274848	et	4	main
majas	doc_213943984948_item	2274852	et	3	main
parem	doc_213943984948_item	2274855	et	4	main
nimi	doc_213943984949_item	2274882	et	3	main
olime	doc_213943984949_item	2274890	et	3	main
väga	doc_213943984949_item	2274898	et	3	main
kaks	doc_213943984949_item	2274925	et	3	main
ja	doc_213943984949_item	2274927	et	3	main
ma	doc_213943984949_item	2274929	et	3	main
olin	doc_213943984949_item	2274930	et	3	main
koer	doc_213943984949_item	2274933	et	3	main
saada	doc_213943984949_item	2274937	et	4	main
ja	doc_213943984949_item	2274939	et	3	main
ma	doc_213943984949_item	2274946	et	3	main
kana	doc_213943984949_item	2274951	et	4	main
aastat	doc_213943984950_item	2274970	et	3	main
kui	doc_213943984950_item	2274972	et	3	main
olin	doc_213943984950_item	2274974	et	3	main
väike	doc_213943984950_item	2274976	et	4	main
moskvasse	doc_213943984950_item	2274981	et	4	main
tädi	doc_213943984950_item	2274982	et	4	main
fotosid	doc_213943984950_item	2275024	et	3	main
tegime	doc_213943984950_item	2275037	et	3	main
ahvi	doc_213943984950_item	2275048	et	4	main
peale	doc_213943984950_item	2275058	et	4	main
ahv	doc_213943984950_item	2275064	et	3	main
ise	doc_213943984950_item	2275067	et	4	main
essee	doc_213943984951_item	2275074	et	4	main
tagasi	doc_213943984951_item	2275077	et	3	main
kass	doc_213943984951_item	2275080	et	3	main
ainult	doc_213943984951_item	2275090	et	4	main
ära	doc_213943984951_item	2275102	et	4	main
me	doc_213943984951_item	2275103	et	4	main
aru	doc_213943984951_item	2275107	et	4	main
olla	doc_213943984951_item	2275111	et	3	main
ei	doc_213943984951_item	2275115	et	4	main
kodus	doc_213943984951_item	2275119	et	4	main
igal	doc_213943984951_item	2275125	et	3	main
kassi	doc_213943984951_item	2275129	et	4	main
kass	doc_213943984951_item	2275134	et	3	main
ära	doc_213943984951_item	2275137	et	4	main
siis	doc_213943984951_item	2275148	et	3	main
ja	doc_213943984951_item	2275150	et	3	main
sõbrannad	doc_213943984951_item	2275152	et	3	main
uuesti	doc_213943984951_item	2275154	et	3	main
lei	doc_213943984951_item	2275157	et	4	main
kass	doc_213943984951_item	2275160	et	3	main
üldse	doc_213943984951_item	2275171	et	3	main
suur	doc_213943984952_item	2275179	et	3	main
moodsad	doc_213943984952_item	2275212	et	3	main
kaubad	doc_213943984952_item	2275215	et	3	main
heal	doc_213943984952_item	2275220	et	3	main
aga	doc_213943984952_item	2275222	et	3	main
müüjad	doc_213943984952_item	2275240	et	4	main
juurde	doc_213943984952_item	2275246	et	4	main
on	doc_213943984952_item	2275254	et	4	main
minu	doc_213943984952_item	2275256	et	3	main
essee	doc_213943984953_item	2275258	et	4	main
riideid	doc_213943984953_item	2275259	et	3	main
on	doc_213943984948_item	2274750	et	4	main
väga	doc_213943984948_item	2274751	et	3	main
kallis	doc_213943984948_item	2274752	et	4	main
küte	doc_213943984948_item	2274753	et	3	main
see	doc_213943984948_item	2274759	et	3	main
pole	doc_213943984948_item	2274772	et	3	main
aga	doc_213943984948_item	2274774	et	3	main
aitab	doc_213943984948_item	2274776	et	3	main
tervem	doc_213943984948_item	2274784	et	4	main
vaatama	doc_213943984948_item	2274787	et	3	main
keelsed	doc_213943984948_item	2274789	et	3	main
tööd	doc_213943984948_item	2274798	et	4	main
aias	doc_213943984948_item	2274799	et	4	main
teha	doc_213943984948_item	2274800	et	3	main
on	doc_213943984948_item	2274806	et	4	main
tore	doc_213943984948_item	2274809	et	3	main
puuviljad	doc_213943984948_item	2274814	et	3	main
on	doc_213943984948_item	2274816	et	4	main
ostetud	doc_213943984948_item	2274823	et	4	main
sest	doc_213943984948_item	2274824	et	4	main
ei	doc_213943984948_item	2274833	et	4	main
ma	doc_213943984948_item	2274838	et	3	main
saan	doc_213943984948_item	2274847	et	4	main
elu	doc_213943984948_item	2274850	et	4	main
on	doc_213943984948_item	2274857	et	4	main
maja	doc_213943984948_item	2274865	et	4	main
minu	doc_213943984949_item	2274876	et	3	main
eesnimi	doc_213943984949_item	2274884	et	3	main
tõug	doc_213943984949_item	2274886	et	3	main
kutsipõlves	doc_213943984949_item	2274902	et	4	main
kogu	doc_213943984949_item	2274905	et	4	main
elasid	doc_213943984949_item	2274924	et	4	main
valvekoerad	doc_213943984949_item	2274926	et	3	main
ükski	doc_213943984949_item	2274928	et	4	main
näinud	doc_213943984949_item	2274931	et	4	main
kätte	doc_213943984949_item	2274936	et	4	main
puurist	doc_213943984949_item	2274938	et	4	main
huuvidest	doc_213943984949_item	2274944	et	4	main
olen	doc_213943984949_item	2274947	et	3	main
et	doc_213943984949_item	2274949	et	3	main
juhtus	doc_213943984950_item	2274968	et	3	main
tagasi	doc_213943984950_item	2274971	et	3	main
päeval	doc_213943984950_item	2274985	et	3	main
pakkus	doc_213943984950_item	2275023	et	3	main
teha	doc_213943984950_item	2275025	et	3	main
ja	doc_213943984950_item	2275027	et	3	main
teha	doc_213943984950_item	2275031	et	3	main
sheesi	doc_213943984950_item	2275038	et	4	main
jäätis	doc_213943984950_item	2275044	et	3	main
kukkus	doc_213943984950_item	2275045	et	3	main
ise	doc_213943984950_item	2275055	et	4	main
hüppas	doc_213943984950_item	2275056	et	3	main
isa	doc_213943984950_item	2275057	et	4	main
kus	doc_213943984950_item	2275063	et	3	main
mitu	doc_213943984951_item	2275075	et	4	main
oli	doc_213943984951_item	2275079	et	3	main
minuga	doc_213943984951_item	2275091	et	3	main
üks	doc_213943984951_item	2275094	et	3	main
kus	doc_213943984951_item	2275108	et	3	main
võiks	doc_213943984951_item	2275110	et	4	main
kui	doc_213943984951_item	2275112	et	3	main
ole	doc_213943984951_item	2275123	et	4	main
jooksis	doc_213943984951_item	2275136	et	4	main
kui	doc_213943984951_item	2275138	et	3	main
me	doc_213943984951_item	2275139	et	4	main
minu	doc_213943984951_item	2275151	et	3	main
hakkasime	doc_213943984951_item	2275153	et	3	main
otsima	doc_213943984951_item	2275155	et	4	main
peal	doc_213943984951_item	2275163	et	4	main
stockmann	doc_213943984952_item	2275174	et	4	main
plussiks	doc_213943984952_item	2275177	et	4	main
on	doc_213943984952_item	2275210	et	4	main
on	doc_213943984952_item	2275219	et	4	main
puuduseks	doc_213943984952_item	2275224	et	4	main
kõrged	doc_213943984952_item	2275226	et	3	main
mulle	doc_213943984952_item	2275228	et	4	main
tundub	doc_213943984952_item	2275229	et	3	main
rikka	doc_213943984952_item	2275236	et	4	main
lõpetuseks	doc_213943984952_item	2275247	et	4	main
tahan	doc_213943984952_item	2275249	et	3	main
jaoks	doc_213943984952_item	2275257	et	4	main
võib	doc_213943984953_item	2275260	et	3	main
juurviljad	doc_213943984948_item	2274812	et	3	main
kauplusest	doc_213943984948_item	2274822	et	4	main
kasvatame	doc_213943984948_item	2274826	et	3	main
hingega	doc_213943984948_item	2274828	et	3	main
sest	doc_213943984948_item	2274837	et	4	main
elada	doc_213943984948_item	2274841	et	3	main
ma	doc_213943984948_item	2274846	et	3	main
et	doc_213943984948_item	2274849	et	3	main
rohkem	doc_213943984948_item	2274858	et	4	main
ja	doc_213943984948_item	2274859	et	3	main
midagi	doc_213943984948_item	2274861	et	4	main
saa	doc_213943984948_item	2274863	et	4	main
tema	doc_213943984949_item	2274885	et	4	main
on	doc_213943984949_item	2274887	et	4	main
me	doc_213943984949_item	2274889	et	4	main
koer	doc_213943984949_item	2274896	et	3	main
energiline	doc_213943984949_item	2274899	et	3	main
neid	doc_213943984948_item	2274827	et	4	main
algusel	doc_213943984948_item	2274831	et	4	main
harjunud	doc_213943984948_item	2274840	et	4	main
praegu	doc_213943984948_item	2274845	et	3	main
oma	doc_213943984948_item	2274851	et	4	main
mitte	doc_213943984948_item	2274860	et	3	main
ei	doc_213943984948_item	2274862	et	4	main
asendada	doc_213943984948_item	2274866	et	3	main
essee	doc_213943984949_item	2274867	et	4	main
viis	doc_213943984949_item	2274872	et	4	main
oli	doc_213943984949_item	2274878	et	3	main
elav	doc_213943984949_item	2274880	et	4	main
tema	doc_213943984949_item	2274881	et	4	main
afganihurt	doc_213943984949_item	2274888	et	4	main
saaremaal	doc_213943984949_item	2274891	et	4	main
siin	doc_213943984949_item	2274892	et	4	main
elas	doc_213943984949_item	2274893	et	3	main
minu	doc_213943984949_item	2274894	et	3	main
ja	doc_213943984949_item	2274900	et	3	main
ta	doc_213943984949_item	2274903	et	4	main
aeg	doc_213943984949_item	2274906	et	3	main
mängida	doc_213943984949_item	2274907	et	3	main
meie	doc_213943984949_item	2274908	et	4	main
naabril	doc_213943984949_item	2274909	et	3	main
oli	doc_213943984949_item	2274910	et	3	main
kaks	doc_213943984949_item	2274911	et	3	main
koera	doc_213943984949_item	2274912	et	4	main
ja	doc_213943984949_item	2274913	et	3	main
veel	doc_213943984949_item	2274914	et	4	main
koduloomad	doc_213943984949_item	2274915	et	3	main
siga	doc_213943984949_item	2274916	et	4	main
lambad	doc_213943984949_item	2274917	et	3	main
kanad	doc_213943984949_item	2274918	et	3	main
kanad	doc_213943984949_item	2274919	et	3	main
elasid	doc_213943984949_item	2274920	et	4	main
tagahoovis	doc_213943984949_item	2274921	et	4	main
tagahoovis	doc_213943984949_item	2274923	et	4	main
kanad	doc_213943984949_item	2274935	et	3	main
ainult	doc_213943984949_item	2274942	et	4	main
ta	doc_213943984949_item	2274952	et	4	main
ikkagi	doc_213943984949_item	2274953	et	4	main
sõi	doc_213943984949_item	2274954	et	3	main
sellepärast	doc_213943984949_item	2274955	et	3	main
oli	doc_213943984949_item	2274957	et	3	main
olid	doc_213943984949_item	2274963	et	4	main
essee	doc_213943984950_item	2274966	et	4	main
see	doc_213943984950_item	2274967	et	3	main
tüdruk	doc_213943984950_item	2274977	et	3	main
pere	doc_213943984950_item	2274979	et	4	main
ühel	doc_213943984950_item	2274984	et	3	main
tahtis	doc_213943984949_item	2274934	et	3	main
naabri	doc_213943984949_item	2274940	et	3	main
vaatasid	doc_213943984949_item	2274943	et	4	main
üht	doc_213943984949_item	2274950	et	3	main
veri	doc_213943984949_item	2274958	et	3	main
aga	doc_213943984949_item	2274960	et	3	main
valvekoerad	doc_213943984949_item	2274962	et	3	main
karistanud	doc_213943984949_item	2274965	et	4	main
kaksteist	doc_213943984950_item	2274969	et	4	main
seitsmeaastane	doc_213943984950_item	2274975	et	4	main
minu	doc_213943984950_item	2274978	et	3	main
sõitis	doc_213943984950_item	2274980	et	3	main
me	doc_213943984950_item	2274986	et	4	main
läksime	doc_213943984950_item	2274987	et	3	main
loomaaeda	doc_213943984950_item	2274988	et	4	main
ema	doc_213943984950_item	2274989	et	4	main
tädiga	doc_213943984950_item	2274990	et	3	main
jalutasid	doc_213943984950_item	2274991	et	4	main
aga	doc_213943984950_item	2274992	et	3	main
mina	doc_213943984950_item	2274993	et	4	main
isaga	doc_213943984950_item	2274994	et	3	main
läksime	doc_213943984950_item	2274995	et	3	main
jäätist	doc_213943984950_item	2274996	et	3	main
osta	doc_213943984950_item	2274997	et	4	main
kui	doc_213943984950_item	2274998	et	3	main
me	doc_213943984950_item	2274999	et	4	main
ostsime	doc_213943984950_item	2275000	et	3	main
läksime	doc_213943984950_item	2275001	et	3	main
tagasi	doc_213943984950_item	2275002	et	3	main
loomi	doc_213943984950_item	2275003	et	4	main
vaadata	doc_213943984950_item	2275004	et	4	main
ja	doc_213943984950_item	2275005	et	3	main
seal	doc_213943984950_item	2275006	et	4	main
oli	doc_213943984950_item	2275007	et	3	main
mees	doc_213943984950_item	2275008	et	4	main
fotoapparadiga	doc_213943984950_item	2275009	et	4	main
ja	doc_213943984950_item	2275010	et	3	main
ahviga	doc_213943984950_item	2275011	et	3	main
ahv	doc_213943984950_item	2275012	et	3	main
oli	doc_213943984950_item	2275013	et	3	main
väga	doc_213943984950_item	2275014	et	3	main
hoolikas	doc_213943984950_item	2275015	et	4	main
ta	doc_213943984950_item	2275016	et	4	main
istus	doc_213943984950_item	2275017	et	4	main
toolis	doc_213943984950_item	2275018	et	3	main
ja	doc_213943984950_item	2275019	et	3	main
sõi	doc_213943984950_item	2275020	et	3	main
mees	doc_213943984950_item	2275022	et	4	main
banaani	doc_213943984950_item	2275021	et	4	main
me	doc_213943984950_item	2275028	et	4	main
seda	doc_213943984950_item	2275030	et	3	main
me	doc_213943984950_item	2275033	et	4	main
ahv	doc_213943984950_item	2275040	et	3	main
ära	doc_213943984950_item	2275042	et	4	main
isale	doc_213943984950_item	2275046	et	3	main
ja	doc_213943984950_item	2275053	et	3	main
mees	doc_213943984950_item	2275059	et	4	main
fotosid	doc_213943984950_item	2275062	et	3	main
oli	doc_213943984950_item	2275065	et	3	main
olid	doc_213943984950_item	2275071	et	4	main
näod	doc_213943984950_item	2275073	et	3	main
nimi	doc_213943984951_item	2275082	et	3	main
eesnimi	doc_213943984951_item	2275084	et	3	main
ei	doc_213943984951_item	2275086	et	4	main
käinud	doc_213943984951_item	2275087	et	4	main
õuele	doc_213943984951_item	2275088	et	3	main
ja	doc_213943984951_item	2275093	et	3	main
kord	doc_213943984951_item	2275095	et	4	main
meie	doc_213943984951_item	2275099	et	4	main
üldse	doc_213943984951_item	2275106	et	3	main
õues	doc_213943984951_item	2275113	et	4	main
teda	doc_213943984951_item	2275114	et	4	main
ahviga	doc_213943984950_item	2275026	et	3	main
otsustasime	doc_213943984950_item	2275029	et	3	main
kui	doc_213943984950_item	2275032	et	3	main
juba	doc_213943984950_item	2275034	et	3	main
ja	doc_213943984950_item	2275036	et	3	main
isale	doc_213943984950_item	2275039	et	3	main
ehmatis	doc_213943984950_item	2275041	et	4	main
minu	doc_213943984950_item	2275043	et	3	main
ära	doc_213943984950_item	2275047	et	4	main
kukkus	doc_213943984950_item	2275050	et	3	main
peale	doc_213943984950_item	2275052	et	4	main
ahv	doc_213943984950_item	2275054	et	3	main
tegi	doc_213943984950_item	2275060	et	4	main
lõbusad	doc_213943984950_item	2275061	et	3	main
peas	doc_213943984950_item	2275068	et	4	main
ja	doc_213943984950_item	2275069	et	3	main
meil	doc_213943984950_item	2275070	et	4	main
aastat	doc_213943984951_item	2275076	et	3	main
mul	doc_213943984951_item	2275078	et	3	main
kelle	doc_213943984951_item	2275081	et	4	main
ta	doc_213943984951_item	2275085	et	4	main
koos	doc_213943984951_item	2275092	et	4	main
nii	doc_213943984951_item	2275097	et	3	main
ei	doc_213943984951_item	2275104	et	4	main
saanud	doc_213943984951_item	2275105	et	4	main
kassi	doc_213943984951_item	2275120	et	4	main
ei	doc_213943984951_item	2275122	et	4	main
ei	doc_213943984951_item	2275130	et	4	main
kuidagi	doc_213943984951_item	2275135	et	3	main
kõik	doc_213943984951_item	2275142	et	4	main
juba	doc_213943984951_item	2275144	et	3	main
kurvad	doc_213943984951_item	2275146	et	3	main
mina	doc_213943984951_item	2275149	et	4	main
д	doc_213943984951_item	2275158	et	2	main
magas	doc_213943984951_item	2275161	et	4	main
voodi	doc_213943984951_item	2275162	et	4	main
tekikottis	doc_213943984951_item	2275164	et	4	main
nii	doc_213943984951_item	2275165	et	3	main
et	doc_213943984951_item	2275166	et	3	main
teda	doc_213943984951_item	2275167	et	4	main
olnu	doc_213943984951_item	2275169	et	4	main
erinevad	doc_213943984952_item	2275211	et	4	main
arvates	doc_213943984952_item	2275217	et	4	main
tasemel	doc_213943984952_item	2275221	et	3	main
nii	doc_213943984952_item	2275230	et	3	main
kuna	doc_213943984952_item	2275231	et	3	main
eestis	doc_213943984952_item	2275232	et	3	main
palju	doc_213943984952_item	2275235	et	4	main
inimesi	doc_213943984952_item	2275237	et	4	main
häirib	doc_213943984952_item	2275239	et	3	main
kes	doc_213943984952_item	2275241	et	4	main
iga	doc_213943984952_item	2275242	et	4	main
minut	doc_213943984952_item	2275243	et	3	main
sinu	doc_213943984952_item	2275245	et	3	main
ma	doc_213943984952_item	2275248	et	3	main
pood	doc_213943984952_item	2275253	et	4	main
parem	doc_213943984952_item	2275255	et	4	main
kaob	doc_213943984953_item	2275264	et	3	main
turude	doc_213943984953_item	2275266	et	4	main
on	doc_213943984953_item	2275312	et	4	main
üles	doc_213943984953_item	2275314	et	3	main
puuduseks	doc_213943984953_item	2275318	et	4	main
näiteks	doc_213943984953_item	2275326	et	4	main
võimalik	doc_213943984953_item	2275328	et	3	main
mingi	doc_213943984953_item	2275338	et	4	main
kuidagi	doc_213943984953_item	2275340	et	3	main
saa	doc_213943984953_item	2275342	et	4	main
turul	doc_213943984953_item	2275350	et	3	main
ikka	doc_213943984953_item	2275353	et	4	main
on	doc_213943984953_item	2275354	et	4	main
plusse	doc_213943984953_item	2275358	et	3	main
sobivat	doc_213943984953_item	2275370	et	4	main
leida	doc_213943984953_item	2275371	et	3	main
et	doc_213943984953_item	2275378	et	3	main
kel	doc_213943984953_item	2275382	et	3	main
missimõõte	doc_213943984953_item	2275384	et	4	main
sobivat	doc_213943984953_item	2275388	et	4	main
minu	doc_213943984950_item	2275051	et	3	main
istudes	doc_213943984950_item	2275066	et	4	main
растерянные	doc_213943984950_item	2275072	et	2	main
oli	doc_213943984951_item	2275083	et	3	main
üksinda	doc_213943984951_item	2275089	et	4	main
juhtus	doc_213943984951_item	2275096	et	3	main
et	doc_213943984951_item	2275098	et	3	main
kass	doc_213943984951_item	2275100	et	3	main
kadus	doc_213943984951_item	2275101	et	3	main
ta	doc_213943984951_item	2275109	et	4	main
saa	doc_213943984951_item	2275116	et	4	main
olla	doc_213943984951_item	2275117	et	3	main
ja	doc_213943984951_item	2275118	et	3	main
pool	doc_213943984951_item	2275126	et	4	main
igas	doc_213943984951_item	2275127	et	3	main
olnud	doc_213943984951_item	2275131	et	4	main
et	doc_213943984951_item	2275133	et	3	main
ukse	doc_213943984951_item	2275141	et	3	main
ja	doc_213943984951_item	2275147	et	3	main
ja	doc_213943984951_item	2275156	et	3	main
sime	doc_213943984951_item	2275159	et	4	main
ei	doc_213943984951_item	2275168	et	4	main
näha	doc_213943984951_item	2275172	et	3	main
essee	doc_213943984952_item	2275173	et	4	main
ja	doc_213943984952_item	2275213	et	3	main
ka	doc_213943984951_item	2275121	et	3	main
vaatasime	doc_213943984951_item	2275124	et	3	main
toas	doc_213943984951_item	2275128	et	3	main
arvasime	doc_213943984951_item	2275132	et	3	main
avasime	doc_213943984951_item	2275140	et	3	main
olid	doc_213943984951_item	2275143	et	4	main
väga	doc_213943984951_item	2275145	et	3	main
д	doc_213943984951_item	2275170	et	2	main
stockmanni	doc_213943984952_item	2275175	et	4	main
suureks	doc_213943984952_item	2275176	et	4	main
on	doc_213943984952_item	2275178	et	4	main
valik	doc_213943984952_item	2275180	et	3	main
seal	doc_213943984952_item	2275181	et	4	main
võib	doc_213943984952_item	2275182	et	3	main
leida	doc_213943984952_item	2275183	et	3	main
kõik	doc_213943984952_item	2275184	et	4	main
mis	doc_213943984952_item	2275185	et	4	main
sulle	doc_213943984952_item	2275186	et	3	main
on	doc_213943984952_item	2275187	et	4	main
vaja	doc_213943984952_item	2275188	et	4	main
ma	doc_213943984952_item	2275189	et	3	main
eelistan	doc_213943984952_item	2275190	et	3	main
seda	doc_213943984952_item	2275191	et	3	main
kaupluse	doc_213943984952_item	2275192	et	3	main
kaubad	doc_213943984952_item	2275193	et	3	main
sellepärast	doc_213943984952_item	2275194	et	3	main
et	doc_213943984952_item	2275195	et	3	main
nad	doc_213943984952_item	2275196	et	3	main
on	doc_213943984952_item	2275197	et	4	main
kvaliteetsed	doc_213943984952_item	2275198	et	3	main
ma	doc_213943984952_item	2275199	et	3	main
olen	doc_213943984952_item	2275200	et	3	main
ülimalt	doc_213943984952_item	2275201	et	4	main
rahul	doc_213943984952_item	2275202	et	4	main
asjaga	doc_213943984952_item	2275203	et	3	main
mis	doc_213943984952_item	2275204	et	4	main
võib	doc_213943984952_item	2275205	et	3	main
stockmannis	doc_213943984952_item	2275207	et	4	main
osta	doc_213943984952_item	2275206	et	4	main
sest	doc_213943984952_item	2275208	et	4	main
seal	doc_213943984952_item	2275209	et	4	main
ebaühtemoodid	doc_213943984952_item	2275214	et	4	main
minu	doc_213943984952_item	2275216	et	3	main
teenindamine	doc_213943984952_item	2275218	et	4	main
kaupluse	doc_213943984952_item	2275223	et	3	main
ei	doc_213943984952_item	2275233	et	4	main
vaatavad	doc_213943984952_item	2275244	et	4	main
öelda	doc_213943984952_item	2275250	et	4	main
seda	doc_213943984952_item	2275252	et	3	main
turult	doc_213943984953_item	2275262	et	3	main
populaarsus	doc_213943984953_item	2275267	et	4	main
põhjaks	doc_213943984953_item	2275269	et	4	main
esiteks	doc_213943984953_item	2275275	et	3	main
leida	doc_213943984953_item	2275315	et	3	main
on	doc_213943984953_item	2275319	et	4	main
et	doc_213943984953_item	2275321	et	3	main
originaalsed	doc_213943984953_item	2275325	et	3	main
samasugust	doc_213943984953_item	2275329	et	3	main
asja	doc_213943984953_item	2275330	et	4	main
kümme	doc_213943984953_item	2275331	et	3	main
korda	doc_213943984953_item	2275332	et	4	main
näha	doc_213943984953_item	2275334	et	3	main
nagu	doc_213943984953_item	2275335	et	3	main
see	doc_213943984953_item	2275336	et	3	main
oleks	doc_213943984953_item	2275337	et	3	main
et	doc_213943984953_item	2275346	et	3	main
kvaliteet	doc_213943984953_item	2275348	et	3	main
jube	doc_213943984953_item	2275351	et	4	main
selle	doc_213943984953_item	2275359	et	4	main
plussiks	doc_213943984953_item	2275361	et	4	main
on	doc_213943984953_item	2275362	et	4	main
valik	doc_213943984953_item	2275365	et	3	main
igale	doc_213943984953_item	2275367	et	3	main
eriti	doc_213943984953_item	2275372	et	3	main
on	doc_213943984953_item	2275374	et	4	main
turu	doc_213943984953_item	2275375	et	3	main
eest	doc_213943984953_item	2275376	et	4	main
see	doc_213943984953_item	2275377	et	3	main
eakad	doc_213943984953_item	2275380	et	3	main
pole	doc_213943984953_item	2275383	et	3	main
endale	doc_213943984953_item	2275387	et	4	main
ka	doc_213943984953_item	2275391	et	3	main
on	doc_213943984953_item	2275393	et	4	main
heal	doc_213943984953_item	2275394	et	3	main
tasemel	doc_213943984953_item	2275395	et	3	main
essee	doc_213943984954_item	2275396	et	4	main
keskuse	doc_213943984954_item	2275398	et	3	main
suureks	doc_213943984954_item	2275399	et	4	main
läbi	doc_213943984954_item	2275422	et	4	main
lihtsalt	doc_213943984954_item	2275423	et	4	main
võib	doc_213943984954_item	2275424	et	3	main
eelistan	doc_213943984954_item	2275430	et	3	main
huvitavate	doc_213943984954_item	2275438	et	4	main
aeg	doc_213943984954_item	2275453	et	3	main
ja	doc_213943984954_item	2275459	et	3	main
päris	doc_213943984954_item	2275460	et	4	main
osta	doc_213943984954_item	2275462	et	4	main
midagi	doc_213943984954_item	2275463	et	4	main
soodsa	doc_213943984954_item	2275464	et	4	main
aga	doc_213943984954_item	2275466	et	3	main
ventilatsiooni	doc_213943984954_item	2275472	et	4	main
on	doc_213943984954_item	2275476	et	4	main
saa	doc_213943984954_item	2275482	et	4	main
jatkuda	doc_213943984954_item	2275483	et	4	main
oma	doc_213943984954_item	2275484	et	4	main
kristiine	doc_213943984954_item	2275487	et	4	main
heal	doc_213943984954_item	2275495	et	3	main
saa	doc_213943984954_item	2275502	et	4	main
jääda	doc_213943984954_item	2275504	et	4	main
sellega	doc_213943984954_item	2275505	et	3	main
mis	doc_213943984954_item	2275532	et	4	main
meeldib	doc_213943984954_item	2275533	et	3	main
kristiine	doc_213943984954_item	2275537	et	4	main
väga	doc_213943984954_item	2275539	et	3	main
suur	doc_213943984954_item	2275543	et	3	main
sealt	doc_213943984954_item	2275552	et	4	main
midagi	doc_213943984954_item	2275560	et	4	main
oma	doc_213943984954_item	2275561	et	4	main
lemmikloomadele	doc_213943984954_item	2275562	et	3	main
kosmeetika	doc_213943984954_item	2275563	et	4	main
on	doc_213943984954_item	2275564	et	4	main
aeda	doc_213943984954_item	2275572	et	4	main
eest	doc_213943984954_item	2275573	et	4	main
on	doc_213943984952_item	2275225	et	4	main
hinnad	doc_213943984952_item	2275227	et	3	main
ole	doc_213943984952_item	2275234	et	4	main
pisut	doc_213943984952_item	2275238	et	3	main
et	doc_213943984952_item	2275251	et	3	main
osta	doc_213943984953_item	2275261	et	4	main
miinused	doc_213943984953_item	2275274	et	3	main
ehmatada	doc_213943984953_item	2275278	et	3	main
see	doc_213943984953_item	2275279	et	3	main
et	doc_213943984953_item	2275280	et	3	main
turul	doc_213943984953_item	2275281	et	3	main
on	doc_213943984953_item	2275282	et	4	main
mustust	doc_213943984953_item	2275284	et	4	main
ja	doc_213943984953_item	2275285	et	3	main
palju	doc_213943984953_item	2275283	et	4	main
varastamist	doc_213943984953_item	2275286	et	4	main
praegu	doc_213943984953_item	2275287	et	3	main
on	doc_213943984953_item	2275288	et	4	main
situatsioon	doc_213943984953_item	2275289	et	3	main
natuke	doc_213943984953_item	2275290	et	4	main
paranenud	doc_213943984953_item	2275291	et	4	main
aga	doc_213943984953_item	2275292	et	3	main
päris	doc_213943984953_item	2275293	et	4	main
heaks	doc_213943984953_item	2275294	et	4	main
ta	doc_213943984953_item	2275295	et	4	main
iialgi	doc_213943984953_item	2275296	et	4	main
ei	doc_213943984953_item	2275297	et	4	main
saa	doc_213943984953_item	2275298	et	4	main
turg	doc_213943984953_item	2275299	et	3	main
on	doc_213943984953_item	2275300	et	4	main
ju	doc_213943984953_item	2275301	et	3	main
turg	doc_213943984953_item	2275302	et	3	main
pisut	doc_213943984953_item	2275303	et	3	main
häirib	doc_213943984953_item	2275304	et	3	main
et	doc_213943984953_item	2275305	et	3	main
turul	doc_213943984953_item	2275306	et	3	main
on	doc_213943984953_item	2275307	et	4	main
kõik	doc_213943984953_item	2275308	et	4	main
segamini	doc_213943984953_item	2275309	et	4	main
ja	doc_213943984953_item	2275310	et	3	main
tänapäeval	doc_213943984953_item	2275263	et	3	main
ja	doc_213943984953_item	2275268	et	3	main
sellele	doc_213943984953_item	2275270	et	4	main
on	doc_213943984953_item	2275271	et	4	main
turude	doc_213943984953_item	2275272	et	4	main
suured	doc_213943984953_item	2275273	et	3	main
tarbijaid	doc_213943984953_item	2275276	et	4	main
raske	doc_213943984953_item	2275311	et	4	main
midagi	doc_213943984953_item	2275313	et	4	main
see	doc_213943984953_item	2275320	et	3	main
asjad	doc_213943984953_item	2275322	et	3	main
on	doc_213943984953_item	2275327	et	4	main
linnas	doc_213943984953_item	2275333	et	4	main
jääda	doc_213943984953_item	2275344	et	4	main
asjade	doc_213943984953_item	2275347	et	3	main
turul	doc_213943984953_item	2275355	et	3	main
muidugi	doc_213943984953_item	2275363	et	4	main
võib	doc_213943984953_item	2275366	et	3	main
võivad	doc_213943984953_item	2275385	et	4	main
osta	doc_213943984954_item	2275425	et	4	main
ühes	doc_213943984954_item	2275427	et	4	main
kohas	doc_213943984954_item	2275428	et	4	main
mina	doc_213943984954_item	2275429	et	4	main
seal	doc_213943984954_item	2275435	et	4	main
kauplust	doc_213943984954_item	2275440	et	4	main
võib	doc_213943984954_item	2275442	et	3	main
osta	doc_213943984954_item	2275443	et	4	main
midagi	doc_213943984954_item	2275444	et	4	main
meeldiv	doc_213943984954_item	2275447	et	4	main
meeldiv	doc_213943984954_item	2275461	et	4	main
keskuse	doc_213943984954_item	2275467	et	3	main
süsteem	doc_213943984954_item	2275473	et	3	main
rohkem	doc_213943984954_item	2275480	et	4	main
kaupluses	doc_213943984954_item	2275486	et	3	main
suur	doc_213943984954_item	2275491	et	3	main
tasemel	doc_213943984954_item	2275496	et	3	main
ütlema	doc_213943984954_item	2275499	et	3	main
ei	doc_213943984954_item	2275501	et	4	main
rahule	doc_213943984954_item	2275503	et	4	main
suurte	doc_213943984954_item	2275521	et	3	main
probleem	doc_213943984954_item	2275523	et	3	main
on	doc_213943984954_item	2275525	et	4	main
palju	doc_213943984954_item	2275526	et	4	main
ei	doc_213943984954_item	2275527	et	4	main
tea	doc_213943984954_item	2275528	et	4	main
ja	doc_213943984954_item	2275531	et	3	main
aga	doc_213943984954_item	2275534	et	3	main
värske	doc_213943984954_item	2275551	et	4	main
osta	doc_213943984954_item	2275554	et	4	main
joogid	doc_213943984954_item	2275558	et	4	main
ka	doc_213943984954_item	2275565	et	3	main
ja	doc_213943984954_item	2275571	et	3	main
kaubamaja	doc_213943984956_item	2275693	et	4	main
suur	doc_213943984956_item	2275697	et	3	main
valik	doc_213943984956_item	2275699	et	3	main
butikkega	doc_213943984956_item	2275727	et	4	main
ma	doc_213943984956_item	2275740	et	3	main
butik	doc_213943984956_item	2275743	et	4	main
heal	doc_213943984956_item	2275745	et	3	main
turu	doc_213943984956_item	2275747	et	3	main
proovimist	doc_213943984956_item	2275760	et	4	main
valmistada	doc_213943984956_item	2275763	et	3	main
hinnad	doc_213943984956_item	2275771	et	3	main
teenindusega	doc_213943984956_item	2275778	et	4	main
aga	doc_213943984953_item	2275265	et	3	main
võib	doc_213943984953_item	2275277	et	3	main
üheks	doc_213943984953_item	2275317	et	3	main
veel	doc_213943984953_item	2275316	et	4	main
ei	doc_213943984953_item	2275323	et	4	main
ei	doc_213943984953_item	2275341	et	4	main
rahule	doc_213943984953_item	2275343	et	4	main
see	doc_213943984953_item	2275345	et	3	main
ka	doc_213943984953_item	2275356	et	3	main
suureks	doc_213943984953_item	2275360	et	4	main
suur	doc_213943984953_item	2275364	et	3	main
midagi	doc_213943984953_item	2275369	et	4	main
ka	doc_213943984953_item	2275379	et	3	main
sealt	doc_213943984953_item	2275386	et	4	main
leida	doc_213943984953_item	2275390	et	3	main
kristiine	doc_213943984954_item	2275397	et	4	main
kristiine	doc_213943984954_item	2275431	et	4	main
sellepärast	doc_213943984954_item	2275433	et	3	main
moodsat	doc_213943984954_item	2275445	et	3	main
eriti	doc_213943984954_item	2275446	et	3	main
allahindlused	doc_213943984954_item	2275458	et	3	main
loomulikult	doc_213943984954_item	2275470	et	4	main
seda	doc_213943984954_item	2275471	et	3	main
palav	doc_213943984954_item	2275478	et	4	main
jalutamist	doc_213943984954_item	2275485	et	4	main
autoparkla	doc_213943984954_item	2275492	et	4	main
väga	doc_213943984954_item	2275494	et	3	main
keskus	doc_213943984954_item	2275507	et	3	main
ole	doc_213943984953_item	2275324	et	4	main
univorm	doc_213943984953_item	2275339	et	4	main
on	doc_213943984953_item	2275349	et	4	main
aga	doc_213943984953_item	2275352	et	3	main
oma	doc_213943984953_item	2275357	et	4	main
maitsele	doc_213943984953_item	2275368	et	3	main
meeldiv	doc_213943984953_item	2275373	et	4	main
naised	doc_213943984953_item	2275381	et	3	main
kehakated	doc_213943984953_item	2275389	et	4	main
kauplemine	doc_213943984953_item	2275392	et	4	main
plussiks	doc_213943984954_item	2275400	et	4	main
on	doc_213943984954_item	2275401	et	4	main
see	doc_213943984954_item	2275402	et	3	main
et	doc_213943984954_item	2275403	et	3	main
on	doc_213943984954_item	2275404	et	4	main
võimalus	doc_213943984954_item	2275405	et	3	main
osta	doc_213943984954_item	2275406	et	4	main
riided	doc_213943984954_item	2275407	et	3	main
toitu	doc_213943984954_item	2275408	et	4	main
ja	doc_213943984954_item	2275409	et	3	main
koduses	doc_213943984954_item	2275410	et	4	main
vajalikud	doc_213943984954_item	2275411	et	3	main
asjad	doc_213943984954_item	2275412	et	3	main
kõik	doc_213943984954_item	2275413	et	4	main
mida	doc_213943984954_item	2275414	et	4	main
vajad	doc_213943984954_item	2275415	et	4	main
ja	doc_213943984954_item	2275416	et	3	main
ei	doc_213943984954_item	2275417	et	4	main
pea	doc_213943984954_item	2275418	et	4	main
sõida	doc_213943984954_item	2275419	et	4	main
kogu	doc_213943984954_item	2275420	et	4	main
linna	doc_213943984954_item	2275421	et	4	main
keskust	doc_213943984954_item	2275432	et	4	main
on	doc_213943984954_item	2275436	et	4	main
mitu	doc_213943984954_item	2275437	et	4	main
riietega	doc_213943984954_item	2275439	et	3	main
on	doc_213943984954_item	2275448	et	4	main
kristiine	doc_213943984954_item	2275449	et	4	main
keskuses	doc_213943984954_item	2275450	et	4	main
see	doc_213943984954_item	2275451	et	3	main
et	doc_213943984954_item	2275452	et	3	main
ajalt	doc_213943984954_item	2275454	et	4	main
seal	doc_213943984954_item	2275456	et	4	main
hinnaga	doc_213943984954_item	2275465	et	3	main
on	doc_213943984954_item	2275469	et	4	main
tasuta	doc_213943984954_item	2275489	et	4	main
pean	doc_213943984954_item	2275498	et	4	main
olen	doc_213943984954_item	2275535	et	3	main
keskusega	doc_213943984954_item	2275538	et	3	main
ja	doc_213943984954_item	2275556	et	3	main
ja	doc_213943984954_item	2275559	et	3	main
vajalikud	doc_213943984954_item	2275568	et	3	main
asjad	doc_213943984954_item	2275569	et	3	main
autole	doc_213943984954_item	2275570	et	3	main
j	doc_213943984954_item	2275574	et	4	main
kõik	doc_213943984954_item	2275426	et	4	main
et	doc_213943984954_item	2275434	et	3	main
kust	doc_213943984954_item	2275441	et	4	main
on	doc_213943984954_item	2275455	et	4	main
suured	doc_213943984954_item	2275457	et	3	main
puuduseks	doc_213943984954_item	2275468	et	4	main
tihti	doc_213943984954_item	2275474	et	3	main
keskuses	doc_213943984954_item	2275475	et	4	main
nii	doc_213943984954_item	2275477	et	3	main
et	doc_213943984954_item	2275479	et	3	main
ei	doc_213943984954_item	2275481	et	4	main
keskuse	doc_213943984954_item	2275488	et	3	main
ja	doc_213943984954_item	2275490	et	3	main
on	doc_213943984954_item	2275493	et	4	main
aga	doc_213943984954_item	2275497	et	3	main
et	doc_213943984954_item	2275500	et	3	main
et	doc_213943984954_item	2275506	et	3	main
on	doc_213943984954_item	2275508	et	4	main
nii	doc_213943984954_item	2275509	et	3	main
suur	doc_213943984954_item	2275510	et	3	main
et	doc_213943984954_item	2275511	et	3	main
parast	doc_213943984954_item	2275512	et	3	main
külastamist	doc_213943984954_item	2275513	et	4	main
tundub	doc_213943984954_item	2275514	et	3	main
end	doc_213943984954_item	2275515	et	4	main
väga	doc_213943984954_item	2275516	et	3	main
väsinud	doc_213943984954_item	2275517	et	4	main
see	doc_213943984954_item	2275518	et	3	main
on	doc_213943984954_item	2275519	et	4	main
kõige	doc_213943984954_item	2275520	et	4	main
kaubanduskeskuste	doc_213943984954_item	2275522	et	4	main
kaupa	doc_213943984954_item	2275524	et	4	main
mida	doc_213943984954_item	2275529	et	4	main
võta	doc_213943984954_item	2275530	et	4	main
on	doc_213943984954_item	2275541	et	4	main
toidupood	doc_213943984954_item	2275542	et	3	main
alati	doc_213943984954_item	2275545	et	4	main
valik	doc_213943984954_item	2275548	et	3	main
kaup	doc_213943984954_item	2275549	et	3	main
puuvilju	doc_213943984954_item	2275557	et	3	main
suureks	doc_213943984956_item	2275694	et	4	main
odav	doc_213943984956_item	2275722	et	3	main
rahul	doc_213943984956_item	2275726	et	4	main
et	doc_213943984956_item	2275734	et	3	main
kaup	doc_213943984956_item	2275735	et	3	main
modsam	doc_213943984956_item	2275739	et	4	main
tasemel	doc_213943984956_item	2275746	et	3	main
puuduseks	doc_213943984956_item	2275748	et	4	main
halp	doc_213943984956_item	2275750	et	4	main
kaupa	doc_213943984956_item	2275751	et	4	main
järjekorrad	doc_213943984956_item	2275756	et	3	main
võib	doc_213943984956_item	2275762	et	3	main
rahul	doc_213943984954_item	2275536	et	4	main
mugav	doc_213943984954_item	2275540	et	3	main
ja	doc_213943984954_item	2275544	et	3	main
on	doc_213943984954_item	2275546	et	4	main
lai	doc_213943984954_item	2275547	et	3	main
on	doc_213943984954_item	2275550	et	4	main
võib	doc_213943984954_item	2275553	et	3	main
liha	doc_213943984954_item	2275555	et	4	main
olemas	doc_213943984954_item	2275566	et	4	main
isegi	doc_213943984954_item	2275567	et	4	main
essee	doc_213943984956_item	2275692	et	4	main
ma	doc_213943984956_item	2275700	et	3	main
ma	doc_213943984956_item	2275723	et	3	main
seal	doc_213943984956_item	2275736	et	4	main
naudin	doc_213943984956_item	2275741	et	3	main
on	doc_213943984956_item	2275749	et	4	main
häirib	doc_213943984956_item	2275754	et	3	main
ehmatada	doc_213943984956_item	2275769	et	3	main
saa	doc_213943984956_item	2275774	et	4	main
jääda	doc_213943984956_item	2275776	et	4	main
olin	doc_213943984958_item	2276095	et	3	main
minu	doc_213943984958_item	2276112	et	3	main
moodi	doc_213943984958_item	2276119	et	4	main
õppima	doc_213943984958_item	2276120	et	3	main
ei	doc_213943984958_item	2276123	et	4	main
kui	doc_213943984958_item	2276126	et	3	main
tahab	doc_213943984958_item	2276137	et	3	main
päeva	doc_213943984958_item	2276147	et	4	main
kui	doc_213943984958_item	2276155	et	3	main
aeg	doc_213943984958_item	2276157	et	3	main
oma	doc_213943984958_item	2276159	et	4	main
kooliaasta	doc_213943984958_item	2276165	et	4	main
on	doc_213943984956_item	2275696	et	4	main
kaupa	doc_213943984956_item	2275698	et	4	main
eelistan	doc_213943984956_item	2275701	et	3	main
kaubamaja	doc_213943984956_item	2275702	et	4	main
sellepärast	doc_213943984956_item	2275703	et	3	main
et	doc_213943984956_item	2275704	et	3	main
kõik	doc_213943984956_item	2275705	et	4	main
võib	doc_213943984956_item	2275706	et	3	main
ühest	doc_213943984956_item	2275708	et	4	main
kohast	doc_213943984956_item	2275709	et	4	main
osta	doc_213943984956_item	2275707	et	4	main
turu	doc_213943984956_item	2275710	et	3	main
peamine	doc_213943984956_item	2275711	et	3	main
eelis	doc_213943984956_item	2275712	et	3	main
teiste	doc_213943984956_item	2275713	et	4	main
kohtade	doc_213943984956_item	2275714	et	3	main
ees	doc_213943984956_item	2275715	et	4	main
on	doc_213943984956_item	2275716	et	4	main
see	doc_213943984956_item	2275717	et	3	main
et	doc_213943984956_item	2275718	et	3	main
kaup	doc_213943984956_item	2275719	et	3	main
seal	doc_213943984956_item	2275720	et	4	main
on	doc_213943984956_item	2275721	et	4	main
ülimalt	doc_213943984956_item	2275725	et	4	main
eriti	doc_213943984956_item	2275728	et	3	main
meeldiv	doc_213943984956_item	2275729	et	4	main
on	doc_213943984956_item	2275730	et	4	main
kõige	doc_213943984956_item	2275738	et	4	main
on	doc_213943984956_item	2275744	et	4	main
pisut	doc_213943984956_item	2275753	et	3	main
ei	doc_213943984956_item	2275758	et	4	main
pettumuse	doc_213943984956_item	2275761	et	4	main
halp	doc_213943984956_item	2275764	et	4	main
kaupa	doc_213943984956_item	2275765	et	4	main
kvaliteet	doc_213943984956_item	2275766	et	3	main
suured	doc_213943984956_item	2275770	et	3	main
ei	doc_213943984956_item	2275773	et	4	main
rahule	doc_213943984956_item	2275775	et	4	main
kindlasti	doc_213943984956_item	2275779	et	3	main
vajaks	doc_213943984956_item	2275780	et	4	main
ümberkorraldamist	doc_213943984956_item	2275781	et	3	main
plussiks	doc_213943984956_item	2275695	et	4	main
olen	doc_213943984956_item	2275724	et	3	main
butikki	doc_213943984956_item	2275731	et	4	main
juures	doc_213943984956_item	2275732	et	4	main
see	doc_213943984956_item	2275733	et	3	main
on	doc_213943984956_item	2275737	et	4	main
kaubamaja	doc_213943984956_item	2275742	et	4	main
kvaliteet	doc_213943984956_item	2275752	et	3	main
pikkad	doc_213943984956_item	2275755	et	4	main
turu	doc_213943984956_item	2275757	et	3	main
võimalda	doc_213943984956_item	2275759	et	4	main
tarbijaid	doc_213943984956_item	2275767	et	4	main
võib	doc_213943984956_item	2275768	et	3	main
halba	doc_213943984956_item	2275777	et	4	main
kuidagi	doc_213943984956_item	2275772	et	3	main
9	doc_213943984958_item	2276096	et	2	main
ei	doc_213943984958_item	2276110	et	4	main
instrument	doc_213943984958_item	2276113	et	3	main
korda	doc_213943984958_item	2276115	et	4	main
ma	doc_213943984958_item	2276116	et	3	main
algasin	doc_213943984958_item	2276117	et	3	main
era	doc_213943984958_item	2276118	et	4	main
aga	doc_213943984958_item	2276121	et	3	main
12	doc_213943984958_item	2276129	et	2	main
minu	doc_213943984958_item	2276135	et	3	main
mulle	doc_213943984958_item	2276143	et	4	main
pärast	doc_213943984958_item	2276148	et	4	main
maardu	doc_213943984958_item	2276152	et	4	main
mina	doc_213943984958_item	2276161	et	4	main
nukrat	doc_213943984958_item	2276172	et	3	main
tuli	doc_213943984958_item	2276184	et	4	main
õpetaja	doc_213943984958_item	2276221	et	4	main
isegi	doc_213943984958_item	2276232	et	4	main
kooli	doc_213943984958_item	2276245	et	4	main
õppimist	doc_213943984958_item	2276263	et	4	main
viimast	doc_213943984958_item	2276267	et	4	main
aastat	doc_213943984958_item	2276268	et	3	main
ma	doc_213943984958_item	2276269	et	3	main
mul	doc_213943984958_item	2276280	et	3	main
kooli	doc_213943984958_item	2276284	et	4	main
3	doc_213943984958_item	2276288	et	2	main
aga	doc_213943984958_item	2276290	et	3	main
olin	doc_213943984958_item	2276292	et	3	main
et	doc_213943984958_item	2276300	et	3	main
muusika	doc_213943984958_item	2276301	et	4	main
minu	doc_213943984958_item	2276303	et	3	main
valdkond	doc_213943984958_item	2276304	et	3	main
suure	doc_213943984958_item	2276315	et	3	main
juba	doc_213943984958_item	2276098	et	3	main
noodi	doc_213943984958_item	2276100	et	3	main
klaverit	doc_213943984958_item	2276103	et	3	main
ma	doc_213943984958_item	2276106	et	3	main
et	doc_213943984958_item	2276108	et	3	main
hakkama	doc_213943984958_item	2276122	et	3	main
saanud	doc_213943984958_item	2276124	et	4	main
mina	doc_213943984958_item	2276127	et	4	main
ma	doc_213943984958_item	2276131	et	3	main
teada	doc_213943984958_item	2276133	et	3	main
viiulit	doc_213943984958_item	2276138	et	3	main
ja	doc_213943984958_item	2276140	et	3	main
astuda	doc_213943984958_item	2276142	et	3	main
mitu	doc_213943984958_item	2276146	et	4	main
juba	doc_213943984958_item	2276150	et	3	main
olime	doc_213943984958_item	2276151	et	3	main
muusikakooli	doc_213943984958_item	2276153	et	4	main
7	doc_213943984958_item	2276164	et	2	main
jooksul	doc_213943984958_item	2276166	et	4	main
palju	doc_213943984958_item	2276168	et	4	main
huvitavat	doc_213943984958_item	2276169	et	4	main
rõõmsat	doc_213943984958_item	2276170	et	3	main
3	doc_213943984958_item	2276173	et	2	main
pärast	doc_213943984958_item	2276177	et	4	main
õpetaja	doc_213943984958_item	2276181	et	4	main
oli	doc_213943984958_item	2276189	et	3	main
unustamatu	doc_213943984958_item	2276195	et	4	main
proovisin	doc_213943984958_item	2276102	et	3	main
mängida	doc_213943984958_item	2276104	et	3	main
see	doc_213943984958_item	2276109	et	3	main
mitu	doc_213943984958_item	2276114	et	4	main
aga	doc_213943984958_item	2276125	et	3	main
aastaseks	doc_213943984958_item	2276130	et	4	main
sain	doc_213943984958_item	2276132	et	3	main
et	doc_213943984958_item	2276134	et	3	main
mängida	doc_213943984958_item	2276139	et	3	main
muusikakooli	doc_213943984958_item	2276141	et	4	main
idee	doc_213943984958_item	2276144	et	4	main
me	doc_213943984958_item	2276149	et	4	main
õpilased	doc_213943984958_item	2276154	et	3	main
tuli	doc_213943984958_item	2276156	et	4	main
astumise	doc_213943984958_item	2276176	et	4	main
koolist	doc_213943984958_item	2276178	et	4	main
teisesse	doc_213943984958_item	2276185	et	4	main
koolisse	doc_213943984958_item	2276186	et	4	main
minna	doc_213943984958_item	2276187	et	3	main
see	doc_213943984958_item	2276188	et	3	main
aeg	doc_213943984958_item	2276193	et	3	main
mina	doc_213943984958_item	2276231	et	4	main
otsustasin	doc_213943984958_item	2276233	et	3	main
aga	doc_213943984958_item	2276236	et	3	main
olen	doc_213943984958_item	2276239	et	3	main
oma	doc_213943984958_item	2276244	et	4	main
kool	doc_213943984958_item	2276252	et	4	main
on	doc_213943984958_item	2276253	et	4	main
mina	doc_213943984958_item	2276260	et	4	main
2	doc_213943984958_item	2276266	et	2	main
õppinud	doc_213943984958_item	2276271	et	4	main
maardus	doc_213943984958_item	2276272	et	4	main
oli	doc_213943984958_item	2276281	et	3	main
otsustatud	doc_213943984958_item	2276294	et	4	main
aru	doc_213943984958_item	2276299	et	4	main
aga	doc_213943984958_item	2276312	et	3	main
ei	doc_213943984958_item	2276313	et	4	main
soovitajate	doc_213943984958_item	2276316	et	4	main
juba	doc_213943984958_item	2276322	et	3	main
ja	doc_213943984958_item	2276324	et	3	main
sõjaväkke	doc_213943984958_item	2276328	et	3	main
lapsepõlvest	doc_213943984958_item	2276341	et	4	main
ja	doc_213943984958_item	2276344	et	3	main
sain	doc_213943984958_item	2276351	et	3	main
kui	doc_213943984958_item	2276357	et	3	main
et	doc_213943984958_item	2276365	et	3	main
aja	doc_213943984958_item	2276373	et	4	main
3	doc_213943984958_item	2276377	et	2	main
reeageresin	doc_213943984959_item	2276427	et	4	main
pahast	doc_213943984959_item	2276429	et	4	main
ole	doc_213943984959_item	2276432	et	4	main
jaoks	doc_213943984959_item	2276437	et	4	main
see	doc_213943984959_item	2276438	et	3	main
on	doc_213943984959_item	2276439	et	4	main
ma	doc_213943984959_item	2276441	et	3	main
sõbranna	doc_213943984959_item	2276447	et	4	main
saanud	doc_213943984959_item	2276452	et	4	main
sest	doc_213943984959_item	2276453	et	4	main
ma	doc_213943984958_item	2276074	et	3	main
essee	doc_213943984958_item	2276073	et	4	main
olen	doc_213943984958_item	2276075	et	3	main
tallinnas	doc_213943984958_item	2276077	et	4	main
ma	doc_213943984958_item	2276078	et	3	main
sündinud	doc_213943984958_item	2276076	et	4	main
elan	doc_213943984958_item	2276079	et	3	main
siin	doc_213943984958_item	2276080	et	4	main
ja	doc_213943984958_item	2276081	et	3	main
kavatse	doc_213943984958_item	2276083	et	4	main
välismaalis	doc_213943984958_item	2276084	et	3	main
elada	doc_213943984958_item	2276085	et	3	main
ei	doc_213943984958_item	2276082	et	4	main
minu	doc_213943984958_item	2276086	et	3	main
mulle	doc_213943984958_item	2276088	et	4	main
õpetati	doc_213943984958_item	2276089	et	3	main
muusikat	doc_213943984958_item	2276090	et	3	main
lapsepõlvest	doc_213943984958_item	2276087	et	4	main
ja	doc_213943984958_item	2276091	et	3	main
sellepärast	doc_213943984958_item	2276092	et	3	main
kui	doc_213943984958_item	2276093	et	3	main
mina	doc_213943984958_item	2276094	et	4	main
aastane	doc_213943984958_item	2276097	et	4	main
teadsin	doc_213943984958_item	2276099	et	3	main
ja	doc_213943984958_item	2276101	et	3	main
kuid	doc_213943984958_item	2276105	et	4	main
tundsin	doc_213943984958_item	2276107	et	3	main
ole	doc_213943984958_item	2276111	et	4	main
sain	doc_213943984958_item	2276128	et	3	main
vend	doc_213943984958_item	2276136	et	3	main
meeldis	doc_213943984958_item	2276145	et	3	main
valida	doc_213943984958_item	2276158	et	3	main
instrument	doc_213943984958_item	2276160	et	3	main
valisin	doc_213943984958_item	2276162	et	3	main
saksofon	doc_213943984958_item	2276163	et	3	main
juhtus	doc_213943984958_item	2276167	et	3	main
aastat	doc_213943984958_item	2276174	et	3	main
minu	doc_213943984958_item	2276175	et	3	main
minu	doc_213943984958_item	2276180	et	3	main
mul	doc_213943984958_item	2276183	et	3	main
gümnaasiuum	doc_213943984958_item	2276191	et	4	main
see	doc_213943984958_item	2276192	et	3	main
me	doc_213943984958_item	2276196	et	4	main
mängisime	doc_213943984958_item	2276197	et	3	main
orkestriga	doc_213943984958_item	2276198	et	3	main
paljudes	doc_213943984958_item	2276199	et	3	main
kohtades	doc_213943984958_item	2276200	et	3	main
mina	doc_213943984958_item	2276201	et	4	main
palju	doc_213943984958_item	2276202	et	4	main
esinesin	doc_213943984958_item	2276203	et	3	main
võtsin	doc_213943984958_item	2276204	et	3	main
osa	doc_213943984958_item	2276205	et	4	main
konkurssidest	doc_213943984958_item	2276206	et	3	main
jne	doc_213943984958_item	2276207	et	4	main
aga	doc_213943984958_item	2276208	et	3	main
see	doc_213943984958_item	2276209	et	3	main
kõik	doc_213943984958_item	2276210	et	4	main
lõppes	doc_213943984958_item	2276211	et	4	main
vähem	doc_213943984958_item	2276212	et	4	main
kui	doc_213943984958_item	2276213	et	3	main
2	doc_213943984958_item	2276214	et	2	main
aastat	doc_213943984958_item	2276215	et	3	main
pärast	doc_213943984958_item	2276216	et	4	main
kui	doc_213943984958_item	2276217	et	3	main
ka	doc_213943984958_item	2276218	et	3	main
minu	doc_213943984958_item	2276219	et	3	main
teine	doc_213943984958_item	2276220	et	3	main
lahkus	doc_213943984958_item	2276222	et	4	main
see	doc_213943984958_item	2276223	et	3	main
minu	doc_213943984958_item	2276225	et	3	main
jaoks	doc_213943984958_item	2276226	et	4	main
raske	doc_213943984958_item	2276228	et	4	main
õppimist	doc_213943984958_item	2276235	et	4	main
ma	doc_213943984958_item	2276238	et	3	main
selle	doc_213943984958_item	2276240	et	4	main
peale	doc_213943984958_item	2276241	et	4	main
mõtelnud	doc_213943984958_item	2276242	et	4	main
ja	doc_213943984958_item	2276243	et	3	main
minu	doc_213943984958_item	2276254	et	3	main
jaoks	doc_213943984958_item	2276255	et	4	main
oma	doc_213943984958_item	2276262	et	4	main
ja	doc_213943984958_item	2276273	et	3	main
lõpetasin	doc_213943984958_item	2276274	et	3	main
see	doc_213943984958_item	2276275	et	3	main
austusega	doc_213943984958_item	2276276	et	4	main
selle	doc_213943984958_item	2276277	et	4	main
ja	doc_213943984958_item	2276171	et	3	main
lahkus	doc_213943984958_item	2276179	et	4	main
ja	doc_213943984958_item	2276182	et	3	main
laagna	doc_213943984958_item	2276190	et	4	main
oli	doc_213943984958_item	2276194	et	3	main
ja	doc_213943984958_item	2276230	et	3	main
oma	doc_213943984958_item	2276234	et	4	main
kui	doc_213943984958_item	2276237	et	3	main
avakontserdil	doc_213943984958_item	2276246	et	3	main
ma	doc_213943984958_item	2276248	et	3	main
aru	doc_213943984958_item	2276250	et	4	main
nagu	doc_213943984958_item	2276256	et	3	main
teine	doc_213943984958_item	2276257	et	3	main
kodu	doc_213943984958_item	2276258	et	4	main
jätkuda	doc_213943984958_item	2276264	et	3	main
2	doc_213943984958_item	2276282	et	2	main
instrumenti	doc_213943984958_item	2276286	et	4	main
ja	doc_213943984958_item	2276287	et	3	main
õpetajat	doc_213943984958_item	2276289	et	4	main
tegeleda	doc_213943984958_item	2276296	et	3	main
õnnestunud	doc_213943984958_item	2276314	et	4	main
mina	doc_213943984958_item	2276321	et	4	main
ahastanud	doc_213943984958_item	2276323	et	4	main
pakkus	doc_213943984958_item	2276332	et	3	main
astuda	doc_213943984958_item	2276334	et	3	main
siin	doc_213943984958_item	2276339	et	4	main
teadsin	doc_213943984958_item	2276342	et	3	main
klaverit	doc_213943984958_item	2276346	et	3	main
kui	doc_213943984958_item	2276349	et	3	main
12	doc_213943984958_item	2276352	et	2	main
astusin	doc_213943984958_item	2276354	et	3	main
muusikakoolisse	doc_213943984958_item	2276355	et	4	main
jööksul	doc_213943984958_item	2276374	et	4	main
ei	doc_213943984958_item	2276380	et	4	main
hulga	doc_213943984958_item	2276386	et	4	main
pärast	doc_213943984958_item	2276387	et	4	main
essee	doc_213943984959_item	2276388	et	4	main
elus	doc_213943984959_item	2276390	et	4	main
oli	doc_213943984959_item	2276391	et	3	main
oli	doc_213943984958_item	2276224	et	3	main
väga	doc_213943984958_item	2276227	et	3	main
aeg	doc_213943984958_item	2276229	et	3	main
käinud	doc_213943984958_item	2276247	et	4	main
sain	doc_213943984958_item	2276249	et	3	main
et	doc_213943984958_item	2276251	et	3	main
ja	doc_213943984958_item	2276259	et	3	main
pean	doc_213943984958_item	2276261	et	4	main
oma	doc_213943984958_item	2276265	et	4	main
olen	doc_213943984958_item	2276270	et	3	main
aja	doc_213943984958_item	2276278	et	4	main
jooksul	doc_213943984958_item	2276279	et	4	main
mina	doc_213943984958_item	2276291	et	4	main
sain	doc_213943984958_item	2276298	et	3	main
sellel	doc_213943984958_item	2276305	et	4	main
ajal	doc_213943984958_item	2276306	et	4	main
proovisin	doc_213943984958_item	2276308	et	3	main
kooli	doc_213943984958_item	2276310	et	4	main
pärast	doc_213943984958_item	2276318	et	4	main
hetkel	doc_213943984958_item	2276320	et	4	main
tuleb	doc_213943984958_item	2276327	et	3	main
aga	doc_213943984958_item	2276330	et	3	main
ma	doc_213943984958_item	2276336	et	3	main
just	doc_213943984958_item	2276338	et	3	main
mina	doc_213943984958_item	2276350	et	4	main
ma	doc_213943984958_item	2276358	et	3	main
tean	doc_213943984958_item	2276364	et	3	main
ole	doc_213943984958_item	2276368	et	4	main
2	doc_213943984958_item	2276371	et	2	main
oli	doc_213943984958_item	2276376	et	3	main
3	doc_213943984958_item	2276379	et	2	main
otsa	doc_213943984958_item	2276382	et	4	main
kuidas	doc_213943984959_item	2276425	et	3	main
ei	doc_213943984959_item	2276431	et	4	main
tahaksin	doc_213943984959_item	2276442	et	3	main
riia	doc_213943984959_item	2276444	et	4	main
juurde	doc_213943984959_item	2276448	et	4	main
ja	doc_213943984959_item	2276485	et	3	main
inimesega	doc_213943984959_item	2276493	et	3	main
üks	doc_213943984959_item	2276500	et	3	main
varastada	doc_213943984959_item	2276504	et	3	main
minu	doc_213943984959_item	2276514	et	3	main
head	doc_213943984959_item	2276519	et	4	main
muusika	doc_213943984958_item	2276283	et	4	main
4	doc_213943984958_item	2276285	et	2	main
kindlalt	doc_213943984958_item	2276293	et	4	main
muusikaga	doc_213943984958_item	2276295	et	3	main
ja	doc_213943984958_item	2276297	et	3	main
on	doc_213943984958_item	2276302	et	4	main
ma	doc_213943984958_item	2276307	et	3	main
otsa	doc_213943984958_item	2276309	et	4	main
astuda	doc_213943984958_item	2276311	et	3	main
hulga	doc_213943984958_item	2276317	et	4	main
ühel	doc_213943984958_item	2276319	et	3	main
ema	doc_213943984958_item	2276331	et	4	main
tpusse	doc_213943984958_item	2276333	et	4	main
praegu	doc_213943984958_item	2276335	et	3	main
1	doc_213943984958_item	2276340	et	2	main
noodi	doc_213943984958_item	2276343	et	3	main
2	doc_213943984958_item	2276348	et	2	main
aastaseks	doc_213943984958_item	2276353	et	4	main
3	doc_213943984958_item	2276356	et	2	main
muusikakooli	doc_213943984958_item	2276360	et	4	main
ülikoolisse	doc_213943984958_item	2276362	et	4	main
klaver	doc_213943984958_item	2276366	et	3	main
mul	doc_213943984958_item	2276375	et	3	main
õnnestunud	doc_213943984958_item	2276381	et	4	main
koolisse	doc_213943984958_item	2276383	et	4	main
suure	doc_213943984958_item	2276384	et	3	main
soovitajate	doc_213943984958_item	2276385	et	4	main
minu	doc_213943984959_item	2276389	et	3	main
palju	doc_213943984959_item	2276392	et	4	main
sündmusi	doc_213943984959_item	2276393	et	3	main
nad	doc_213943984959_item	2276394	et	3	main
olid	doc_213943984959_item	2276395	et	4	main
head	doc_213943984959_item	2276396	et	4	main
ja	doc_213943984959_item	2276397	et	3	main
pahad	doc_213943984959_item	2276398	et	4	main
tähtsad	doc_213943984959_item	2276399	et	3	main
ja	doc_213943984959_item	2276400	et	3	main
mitte	doc_213943984959_item	2276401	et	3	main
väga	doc_213943984959_item	2276402	et	3	main
tähtsad	doc_213943984959_item	2276403	et	3	main
mõned	doc_213943984959_item	2276404	et	3	main
ma	doc_213943984959_item	2276405	et	3	main
ei	doc_213943984959_item	2276406	et	4	main
mäletagi	doc_213943984959_item	2276407	et	4	main
aga	doc_213943984959_item	2276408	et	3	main
mõned	doc_213943984959_item	2276409	et	3	main
jäävad	doc_213943984959_item	2276410	et	4	main
mälus	doc_213943984959_item	2276412	et	4	main
minu	doc_213943984959_item	2276411	et	3	main
igaveseks	doc_213943984959_item	2276413	et	4	main
praegu	doc_213943984959_item	2276414	et	3	main
ma	doc_213943984959_item	2276415	et	3	main
püüan	doc_213943984959_item	2276416	et	3	main
kirjeldada	doc_213943984959_item	2276417	et	3	main
kolm	doc_213943984959_item	2276418	et	3	main
negativseid	doc_213943984959_item	2276419	et	4	main
ja	doc_213943984959_item	2276420	et	3	main
kolm	doc_213943984959_item	2276421	et	3	main
ma	doc_213943984959_item	2276426	et	3	main
alustan	doc_213943984959_item	2276428	et	3	main
see	doc_213943984959_item	2276430	et	3	main
solvatav	doc_213943984959_item	2276440	et	4	main
aga	doc_213943984959_item	2276449	et	3	main
ei	doc_213943984959_item	2276454	et	4	main
arvasin	doc_213943984958_item	2276325	et	3	main
et	doc_213943984958_item	2276326	et	3	main
minna	doc_213943984958_item	2276329	et	3	main
õpin	doc_213943984958_item	2276337	et	3	main
proovisin	doc_213943984958_item	2276345	et	3	main
mängida	doc_213943984958_item	2276347	et	3	main
lõpetasin	doc_213943984958_item	2276359	et	3	main
astusin	doc_213943984958_item	2276361	et	3	main
1	doc_213943984958_item	2276363	et	2	main
ei	doc_213943984958_item	2276367	et	4	main
minu	doc_213943984958_item	2276369	et	3	main
instrument	doc_213943984958_item	2276370	et	3	main
õppimise	doc_213943984958_item	2276372	et	4	main
õpetajat	doc_213943984958_item	2276378	et	4	main
positivseid	doc_213943984959_item	2276422	et	4	main
ja	doc_213943984959_item	2276424	et	3	main
väga	doc_213943984959_item	2276433	et	3	main
aga	doc_213943984959_item	2276435	et	3	main
sõida	doc_213943984959_item	2276443	et	4	main
minu	doc_213943984959_item	2276446	et	3	main
ei	doc_213943984959_item	2276451	et	4	main
rahat	doc_213943984959_item	2276456	et	4	main
üks	doc_213943984959_item	2276487	et	3	main
tutvusin	doc_213943984959_item	2276489	et	3	main
väga	doc_213943984959_item	2276491	et	3	main
asjad	doc_213943984959_item	2276497	et	3	main
jne	doc_213943984959_item	2276498	et	4	main
ja	doc_213943984959_item	2276499	et	3	main
sõbranna	doc_213943984959_item	2276509	et	4	main
kiiresti	doc_213943984959_item	2276512	et	3	main
jäi	doc_213943984959_item	2276516	et	3	main
ka	doc_213943984959_item	2276522	et	3	main
öeldi	doc_213943984959_item	2276524	et	3	main
näitusele	doc_213943984959_item	2276529	et	4	main
see	doc_213943984959_item	2276530	et	3	main
meeldiv	doc_213943984959_item	2276533	et	4	main
ma	doc_213943984959_item	2276534	et	3	main
kõigele	doc_213943984959_item	2276537	et	4	main
ja	doc_213943984959_item	2276538	et	3	main
täpselt	doc_213943984959_item	2276542	et	4	main
see	doc_213943984959_item	2276546	et	3	main
sel	doc_213943984959_item	2276548	et	3	main
sündmus	doc_213943984959_item	2276552	et	3	main
see	doc_213943984959_item	2276553	et	3	main
ja	doc_213943984959_item	2276581	et	3	main
mina	doc_213943984959_item	2276585	et	4	main
ka	doc_213943984959_item	2276590	et	3	main
kogu	doc_213943984959_item	2276598	et	4	main
valmistasin	doc_213943984959_item	2276601	et	3	main
sündmuseid	doc_213943984959_item	2276423	et	3	main
tähtis	doc_213943984959_item	2276434	et	4	main
minu	doc_213943984959_item	2276436	et	3	main
veebruaris	doc_213943984959_item	2276445	et	3	main
ma	doc_213943984959_item	2276450	et	3	main
olin	doc_213943984959_item	2276460	et	3	main
mina	doc_213943984959_item	2276464	et	4	main
otsustasin	doc_213943984959_item	2276465	et	3	main
sõida	doc_213943984959_item	2276466	et	4	main
kindlasti	doc_213943984959_item	2276467	et	3	main
aga	doc_213943984959_item	2276469	et	3	main
kevadel	doc_213943984959_item	2276470	et	4	main
teine	doc_213943984959_item	2276471	et	3	main
riia	doc_213943984959_item	2276468	et	4	main
sündmus	doc_213943984959_item	2276472	et	3	main
üks	doc_213943984959_item	2276473	et	3	main
kord	doc_213943984959_item	2276474	et	4	main
suri	doc_213943984959_item	2276475	et	3	main
minu	doc_213943984959_item	2276476	et	3	main
koer	doc_213943984959_item	2276477	et	3	main
ma	doc_213943984959_item	2276478	et	3	main
armastasin	doc_213943984959_item	2276479	et	3	main
seda	doc_213943984959_item	2276480	et	3	main
ja	doc_213943984959_item	2276481	et	3	main
loomulikult	doc_213943984959_item	2276482	et	4	main
olnud	doc_213943984959_item	2276455	et	4	main
sellele	doc_213943984959_item	2276463	et	4	main
ühe	doc_213943984959_item	2276490	et	4	main
ta	doc_213943984959_item	2276494	et	4	main
ta	doc_213943984959_item	2276502	et	4	main
püüdis	doc_213943984959_item	2276503	et	3	main
minu	doc_213943984959_item	2276505	et	3	main
aga	doc_213943984959_item	2276507	et	3	main
väga	doc_213943984959_item	2276511	et	3	main
et	doc_213943984959_item	2276525	et	3	main
oli	doc_213943984959_item	2276531	et	3	main
ütlesin	doc_213943984959_item	2276539	et	3	main
kus	doc_213943984959_item	2276540	et	3	main
töö	doc_213943984959_item	2276544	et	4	main
on	doc_213943984959_item	2276547	et	4	main
tähtsaim	doc_213943984959_item	2276551	et	4	main
sünd	doc_213943984959_item	2276557	et	3	main
olin	doc_213943984959_item	2276589	et	3	main
seda	doc_213943984959_item	2276594	et	3	main
2	doc_213943984960_item	2276614	et	2	main
ma	doc_213943984960_item	2276617	et	3	main
tallinna	doc_213943984960_item	2276619	et	4	main
kalamaja	doc_213943984960_item	2276627	et	4	main
abikaasa	doc_213943984960_item	2276641	et	4	main
ja	doc_213943984960_item	2276642	et	3	main
kolmanda	doc_213943984960_item	2276649	et	3	main
teisel	doc_213943984960_item	2276663	et	4	main
kursusel	doc_213943984960_item	2276664	et	3	main
puhkuse	doc_213943984960_item	2276668	et	3	main
lapsega	doc_213943984960_item	2276679	et	3	main
olime	doc_213943984960_item	2276690	et	3	main
maal	doc_213943984960_item	2276703	et	4	main
elab	doc_213943984960_item	2276705	et	3	main
palju	doc_213943984960_item	2276713	et	4	main
õhul	doc_213943984960_item	2276717	et	3	main
oli	doc_213943984960_item	2276729	et	3	main
ma	doc_213943984960_item	2276732	et	3	main
kõik	doc_213943984960_item	2276738	et	4	main
lepingu	doc_213943984960_item	2276748	et	3	main
valvamisest	doc_213943984960_item	2276750	et	4	main
isa	doc_213943984960_item	2276755	et	4	main
oli	doc_213943984960_item	2276767	et	3	main
tahtnud	doc_213943984960_item	2276772	et	4	main
teha	doc_213943984960_item	2276778	et	3	main
olin	doc_213943984960_item	2276780	et	3	main
kodus	doc_213943984960_item	2276781	et	4	main
ja	doc_213943984960_item	2276782	et	3	main
see	doc_213943984960_item	2276783	et	3	main
oli	doc_213943984960_item	2276784	et	3	main
periood	doc_213943984960_item	2276786	et	3	main
meeldib	doc_213943984960_item	2276792	et	3	main
ülikoolis	doc_213943984960_item	2276795	et	4	main
palju	doc_213943984960_item	2276800	et	4	main
uusi	doc_213943984960_item	2276801	et	3	main
päev	doc_213943984960_item	2276805	et	3	main
midagi	doc_213943984960_item	2276806	et	4	main
uut	doc_213943984960_item	2276807	et	3	main
minu	doc_213943984960_item	2276822	et	3	main
mul	doc_213943984960_item	2276828	et	3	main
valutas	doc_213943984960_item	2276829	et	3	main
istusin	doc_213943984960_item	2276835	et	3	main
mängisin	doc_213943984960_item	2276845	et	3	main
meil	doc_213943984960_item	2276853	et	4	main
väga	doc_213943984960_item	2276855	et	3	main
koos	doc_213943984960_item	2276857	et	4	main
päris	doc_213943984961_item	2276868	et	4	main
heas	doc_213943984961_item	2276869	et	3	main
palju	doc_213943984961_item	2276879	et	4	main
maja	doc_213943984961_item	2276882	et	4	main
on	doc_213943984961_item	2276884	et	4	main
elan	doc_213943984961_item	2276923	et	3	main
seisukoras	doc_213943984961_item	2276927	et	4	main
ei	doc_213943984961_item	2276932	et	4	main
miinused	doc_213943984961_item	2276935	et	3	main
ikkagi	doc_213943984961_item	2276937	et	4	main
peatuste	doc_213943984961_item	2276942	et	4	main
päris	doc_213943984961_item	2276950	et	4	main
nad	doc_213943984961_item	2276953	et	3	main
on	doc_213943984961_item	2276964	et	4	main
mõnus	doc_213943984961_item	2276966	et	4	main
minutiga	doc_213943984961_item	2276969	et	3	main
saab	doc_213943984961_item	2276970	et	3	main
saada	doc_213943984961_item	2276973	et	4	main
ja	doc_213943984959_item	2276457	et	3	main
aega	doc_213943984959_item	2276458	et	4	main
ma	doc_213943984959_item	2276459	et	3	main
segaduses	doc_213943984959_item	2276461	et	3	main
vaatamata	doc_213943984959_item	2276462	et	4	main
mina	doc_213943984959_item	2276483	et	4	main
veel	doc_213943984959_item	2276486	et	4	main
mina	doc_213943984959_item	2276488	et	4	main
tegi	doc_213943984959_item	2276495	et	4	main
pahad	doc_213943984959_item	2276496	et	4	main
minu	doc_213943984959_item	2276508	et	3	main
ja	doc_213943984959_item	2276513	et	3	main
käes	doc_213943984959_item	2276518	et	4	main
on	doc_213943984959_item	2276521	et	4	main
jutustasin	doc_213943984959_item	2276535	et	3	main
minu	doc_213943984959_item	2276543	et	3	main
hetkel	doc_213943984959_item	2276549	et	4	main
kõige	doc_213943984959_item	2276550	et	4	main
ta	doc_213943984959_item	2276558	et	4	main
veel	doc_213943984959_item	2276560	et	4	main
üks	doc_213943984959_item	2276583	et	3	main
asutasin	doc_213943984959_item	2276586	et	3	main
ülikooli	doc_213943984959_item	2276587	et	4	main
mina	doc_213943984959_item	2276588	et	4	main
elan	doc_213943984960_item	2276609	et	3	main
lasnamäel	doc_213943984960_item	2276611	et	3	main
mul	doc_213943984960_item	2276612	et	3	main
ülikooli	doc_213943984960_item	2276621	et	4	main
gümnaasiumis	doc_213943984960_item	2276629	et	3	main
meie	doc_213943984960_item	2276643	et	4	main
sündis	doc_213943984960_item	2276653	et	3	main
õppisin	doc_213943984960_item	2276662	et	3	main
lapse	doc_213943984960_item	2276669	et	4	main
puhul	doc_213943984960_item	2276671	et	4	main
suurepärane	doc_213943984960_item	2276674	et	4	main
olin	doc_213943984960_item	2276677	et	3	main
kodus	doc_213943984960_item	2276680	et	4	main
homikust	doc_213943984960_item	2276682	et	4	main
me	doc_213943984960_item	2276689	et	4	main
kõik	doc_213943984960_item	2276691	et	4	main
ei	doc_213943984960_item	2276695	et	4	main
olin	doc_213943984960_item	2276701	et	3	main
isa	doc_213943984960_item	2276707	et	4	main
mere	doc_213943984960_item	2276710	et	3	main
värskel	doc_213943984960_item	2276716	et	4	main
jaanuaris	doc_213943984960_item	2276718	et	3	main
nuttasin	doc_213943984959_item	2276484	et	4	main
paha	doc_213943984959_item	2276492	et	4	main
kord	doc_213943984959_item	2276501	et	4	main
mobiiltelefon	doc_213943984959_item	2276506	et	3	main
reeageris	doc_213943984959_item	2276510	et	4	main
telefon	doc_213943984959_item	2276515	et	3	main
minu	doc_213943984959_item	2276517	et	3	main
sündmused	doc_213943984959_item	2276520	et	3	main
mulle	doc_213943984959_item	2276523	et	4	main
tuleb	doc_213943984959_item	2276528	et	3	main
väga	doc_213943984959_item	2276532	et	3	main
asub	doc_213943984959_item	2276541	et	3	main
teine	doc_213943984959_item	2276545	et	3	main
õetütra	doc_213943984959_item	2276556	et	4	main
väike	doc_213943984959_item	2276561	et	4	main
õnnelik	doc_213943984959_item	2276580	et	3	main
veel	doc_213943984959_item	2276582	et	4	main
kui	doc_213943984959_item	2276584	et	3	main
õnnelik	doc_213943984959_item	2276592	et	3	main
pärast	doc_213943984959_item	2276593	et	4	main
uudist	doc_213943984959_item	2276595	et	3	main
puhkan	doc_213943984959_item	2276597	et	3	main
suvi	doc_213943984959_item	2276599	et	3	main
essee	doc_213943984960_item	2276603	et	4	main
minu	doc_213943984960_item	2276604	et	3	main
nimi	doc_213943984960_item	2276605	et	3	main
tallinnas	doc_213943984960_item	2276610	et	4	main
on	doc_213943984960_item	2276613	et	4	main
toaline	doc_213943984960_item	2276615	et	4	main
korter	doc_213943984960_item	2276616	et	3	main
olen	doc_213943984960_item	2276618	et	3	main
pedagoogika	doc_213943984960_item	2276620	et	4	main
üliõpilane	doc_213943984960_item	2276622	et	3	main
veel	doc_213943984960_item	2276623	et	4	main
ma	doc_213943984960_item	2276624	et	3	main
aastane	doc_213943984960_item	2276634	et	4	main
elame	doc_213943984960_item	2276638	et	3	main
kolmekesi	doc_213943984960_item	2276639	et	3	main
mina	doc_213943984960_item	2276640	et	4	main
poeg	doc_213943984960_item	2276645	et	3	main
kahe	doc_213943984960_item	2276647	et	3	main
ma	doc_213943984960_item	2276661	et	3	main
ja	doc_213943984960_item	2276665	et	3	main
akadeemilise	doc_213943984960_item	2276667	et	3	main
see	doc_213943984960_item	2276672	et	3	main
ainult	doc_213943984960_item	2276678	et	4	main
kahekesi	doc_213943984960_item	2276681	et	3	main
õhtuni	doc_213943984960_item	2276683	et	3	main
tuli	doc_213943984960_item	2276685	et	4	main
õhtul	doc_213943984960_item	2276687	et	3	main
ja	doc_213943984960_item	2276688	et	3	main
ääres	doc_213943984960_item	2276711	et	4	main
pargis	doc_213943984960_item	2276712	et	3	main
juhtus	doc_213943984960_item	2276719	et	3	main
isaga	doc_213943984960_item	2276721	et	3	main
tema	doc_213943984960_item	2276726	et	4	main
praegu	doc_213943984960_item	2276736	et	3	main
firmaga	doc_213943984960_item	2276747	et	3	main
ma	doc_213943984960_item	2276770	et	3	main
tahtnud	doc_213943984960_item	2276776	et	4	main
minu	doc_213943984960_item	2276787	et	3	main
praegu	doc_213943984960_item	2276790	et	3	main
sõpru	doc_213943984960_item	2276802	et	3	main
iga	doc_213943984960_item	2276804	et	4	main
väga	doc_213943984960_item	2276810	et	3	main
ja	doc_213943984960_item	2276820	et	3	main
armastan	doc_213943984960_item	2276821	et	3	main
oli	doc_213943984960_item	2276831	et	3	main
ja	doc_213943984960_item	2276837	et	3	main
võtsin	doc_213943984960_item	2276838	et	3	main
mul	doc_213943984960_item	2276840	et	3	main
vaba	doc_213943984960_item	2276842	et	4	main
aeg	doc_213943984960_item	2276843	et	3	main
minu	doc_213943984960_item	2276846	et	3	main
vaatasime	doc_213943984960_item	2276851	et	3	main
kiiresti	doc_213943984960_item	2276862	et	3	main
mitte	doc_213943984961_item	2276874	et	3	main
lähedal	doc_213943984961_item	2276877	et	4	main
kauplusi	doc_213943984961_item	2276880	et	3	main
bissi	doc_213943984961_item	2276886	et	4	main
üheksakorruseline	doc_213943984961_item	2276890	et	4	main
selle	doc_213943984961_item	2276893	et	4	main
minu	doc_213943984959_item	2276526	et	3	main
töö	doc_213943984959_item	2276527	et	4	main
sellest	doc_213943984959_item	2276536	et	4	main
on	doc_213943984959_item	2276554	et	4	main
minu	doc_213943984959_item	2276555	et	3	main
on	doc_213943984959_item	2276559	et	4	main
aga	doc_213943984959_item	2276562	et	3	main
ta	doc_213943984959_item	2276563	et	4	main
on	doc_213943984959_item	2276564	et	4	main
nagu	doc_213943984959_item	2276565	et	3	main
noorem	doc_213943984959_item	2276566	et	4	main
õde	doc_213943984959_item	2276567	et	4	main
mulle	doc_213943984959_item	2276568	et	4	main
ma	doc_213943984959_item	2276569	et	3	main
armastan	doc_213943984959_item	2276570	et	3	main
teda	doc_213943984959_item	2276571	et	4	main
kui	doc_213943984959_item	2276573	et	3	main
ma	doc_213943984959_item	2276574	et	3	main
teadsin	doc_213943984959_item	2276575	et	3	main
teda	doc_213943984959_item	2276576	et	4	main
sündist	doc_213943984959_item	2276577	et	4	main
ja	doc_213943984959_item	2276572	et	3	main
mina	doc_213943984959_item	2276578	et	4	main
olin	doc_213943984959_item	2276579	et	3	main
väga	doc_213943984959_item	2276591	et	3	main
ma	doc_213943984959_item	2276596	et	3	main
ja	doc_213943984959_item	2276600	et	3	main
õppimist	doc_213943984959_item	2276602	et	4	main
on	doc_213943984960_item	2276606	et	4	main
eesnimi	doc_213943984960_item	2276607	et	3	main
ma	doc_213943984960_item	2276608	et	3	main
töötan	doc_213943984960_item	2276625	et	3	main
muusikaõpetajana	doc_213943984960_item	2276630	et	3	main
34	doc_213943984960_item	2276633	et	2	main
ja	doc_213943984960_item	2276635	et	3	main
me	doc_213943984960_item	2276637	et	4	main
väike	doc_213943984960_item	2276644	et	4	main
tuhande	doc_213943984960_item	2276648	et	3	main
augustis	doc_213943984960_item	2276651	et	3	main
hoidamise	doc_213943984960_item	2276670	et	4	main
oli	doc_213943984960_item	2276673	et	3	main
ma	doc_213943984960_item	2276676	et	3	main
koos	doc_213943984960_item	2276692	et	4	main
mitte	doc_213943984960_item	2276693	et	3	main
kunagi	doc_213943984960_item	2276694	et	3	main
lapsega	doc_213943984960_item	2276702	et	3	main
kus	doc_213943984960_item	2276704	et	3	main
minu	doc_213943984960_item	2276706	et	3	main
me	doc_213943984960_item	2276708	et	4	main
jalutasime	doc_213943984960_item	2276709	et	3	main
aega	doc_213943984960_item	2276714	et	4	main
isale	doc_213943984960_item	2276723	et	3	main
tungiti	doc_213943984960_item	2276724	et	3	main
teda	doc_213943984960_item	2276734	et	4	main
on	doc_213943984960_item	2276737	et	4	main
korras	doc_213943984960_item	2276739	et	4	main
ta	doc_213943984960_item	2276740	et	4	main
tegime	doc_213943984960_item	2276745	et	3	main
väga	doc_213943984960_item	2276753	et	3	main
minu	doc_213943984960_item	2276754	et	3	main
pärast	doc_213943984960_item	2276756	et	4	main
hirmus	doc_213943984960_item	2276768	et	4	main
ei	doc_213943984960_item	2276771	et	4	main
väljas	doc_213943984960_item	2276773	et	4	main
mulle	doc_213943984960_item	2276791	et	4	main
on	doc_213943984960_item	2276797	et	4	main
väga	doc_213943984960_item	2276798	et	3	main
rõõmus	doc_213943984960_item	2276811	et	4	main
ma	doc_213943984960_item	2276813	et	3	main
õpin	doc_213943984960_item	2276814	et	3	main
ma	doc_213943984960_item	2276816	et	3	main
töötan	doc_213943984960_item	2276817	et	3	main
oma	doc_213943984960_item	2276818	et	4	main
erialal	doc_213943984960_item	2276819	et	3	main
tööd	doc_213943984960_item	2276823	et	4	main
ma	doc_213943984960_item	2276825	et	3	main
olin	doc_213943984960_item	2276826	et	3	main
kurk	doc_213943984960_item	2276830	et	3	main
ma	doc_213943984960_item	2276834	et	3	main
kodus	doc_213943984960_item	2276836	et	4	main
lugesin	doc_213943984960_item	2276848	et	3	main
olla	doc_213943984960_item	2276858	et	3	main
ja	doc_213943984960_item	2276859	et	3	main
sain	doc_213943984960_item	2276861	et	3	main
maja	doc_213943984961_item	2276866	et	4	main
kaugel	doc_213943984961_item	2276876	et	4	main
ümber	doc_213943984961_item	2276883	et	3	main
2	doc_213943984961_item	2276885	et	2	main
maja	doc_213943984961_item	2276888	et	4	main
ma	doc_213943984961_item	2276922	et	3	main
halvas	doc_213943984961_item	2276926	et	4	main
hoolitsetakse	doc_213943984961_item	2276933	et	3	main
aga	doc_213943984961_item	2276934	et	3	main
päris	doc_213943984961_item	2276938	et	4	main
et	doc_213943984961_item	2276947	et	3	main
busse	doc_213943984961_item	2276948	et	3	main
haige	doc_213943984961_item	2276961	et	4	main
5	doc_213943984961_item	2276968	et	2	main
arsti	doc_213943984961_item	2276971	et	4	main
maja	doc_213943984961_item	2276974	et	4	main
et	doc_213943984961_item	2276980	et	3	main
ikka	doc_213943984961_item	2276990	et	4	main
olemas	doc_213943984961_item	2276991	et	4	main
ütlema	doc_213943984961_item	2276996	et	3	main
nad	doc_213943984961_item	2276998	et	3	main
teeb	doc_213943984962_item	2277007	et	3	main
asub	doc_213943984962_item	2277011	et	3	main
vana	doc_213943984960_item	2276626	et	4	main
täiskasvatuse	doc_213943984960_item	2276628	et	3	main
mina	doc_213943984960_item	2276631	et	4	main
olen	doc_213943984960_item	2276632	et	3	main
abielus	doc_213943984960_item	2276636	et	4	main
eesnimi	doc_213943984960_item	2276646	et	3	main
aasta	doc_213943984960_item	2276650	et	4	main
mul	doc_213943984960_item	2276652	et	3	main
poeglaps	doc_213943984960_item	2276654	et	4	main
ma	doc_213943984960_item	2276655	et	3	main
olin	doc_213943984960_item	2276656	et	3	main
väga	doc_213943984960_item	2276657	et	3	main
õnnelik	doc_213943984960_item	2276658	et	3	main
tol	doc_213943984960_item	2276659	et	3	main
ajal	doc_213943984960_item	2276660	et	4	main
vormistasin	doc_213943984960_item	2276666	et	3	main
aeg	doc_213943984960_item	2276675	et	3	main
siis	doc_213943984960_item	2276684	et	3	main
abikaasa	doc_213943984960_item	2276686	et	4	main
olnud	doc_213943984960_item	2276696	et	4	main
vaja	doc_213943984960_item	2276697	et	4	main
kiirustada	doc_213943984960_item	2276698	et	3	main
suvel	doc_213943984960_item	2276699	et	3	main
ma	doc_213943984960_item	2276700	et	3	main
olime	doc_213943984960_item	2276715	et	3	main
minu	doc_213943984960_item	2276720	et	3	main
ta	doc_213943984960_item	2276728	et	4	main
ja	doc_213943984960_item	2276731	et	3	main
külastamas	doc_213943984960_item	2276735	et	3	main
me	doc_213943984960_item	2276744	et	4	main
maja	doc_213943984960_item	2276749	et	4	main
ma	doc_213943984960_item	2276751	et	3	main
kardan	doc_213943984960_item	2276752	et	4	main
käja	doc_213943984960_item	2276774	et	4	main
midagi	doc_213943984960_item	2276777	et	4	main
raske	doc_213943984960_item	2276785	et	4	main
elus	doc_213943984960_item	2276788	et	4	main
aga	doc_213943984960_item	2276789	et	3	main
huvitav	doc_213943984960_item	2276799	et	4	main
ma	doc_213943984960_item	2276808	et	3	main
et	doc_213943984960_item	2276812	et	3	main
siin	doc_213943984960_item	2276815	et	4	main
hiljuti	doc_213943984960_item	2276824	et	4	main
kõrge	doc_213943984960_item	2276832	et	4	main
palavik	doc_213943984960_item	2276833	et	3	main
ma	doc_213943984960_item	2276844	et	3	main
pojaga	doc_213943984960_item	2276847	et	4	main
ramatut	doc_213943984960_item	2276850	et	4	main
telerit	doc_213943984960_item	2276852	et	3	main
lõbus	doc_213943984960_item	2276856	et	4	main
mina	doc_213943984960_item	2276860	et	4	main
minu	doc_213943984961_item	2276865	et	3	main
asub	doc_213943984961_item	2276867	et	3	main
mikrorajoonis	doc_213943984961_item	2276870	et	4	main
lasnamä	doc_213943984961_item	2276871	et	4	main
linnast	doc_213943984961_item	2276873	et	4	main
väga	doc_213943984961_item	2276875	et	3	main
on	doc_213943984961_item	2276878	et	4	main
ja	doc_213943984961_item	2276881	et	3	main
peatust	doc_213943984961_item	2276887	et	4	main
on	doc_213943984961_item	2276889	et	4	main
maasti	doc_213943984961_item	2276891	et	4	main
hoolitseb	doc_213943984961_item	2276892	et	3	main
õnnetus	doc_213943984960_item	2276722	et	4	main
kallale	doc_213943984960_item	2276725	et	4	main
majas	doc_213943984960_item	2276727	et	3	main
haiglas	doc_213943984960_item	2276730	et	3	main
käisin	doc_213943984960_item	2276733	et	3	main
on	doc_213943984960_item	2276741	et	4	main
juba	doc_213943984960_item	2276742	et	3	main
kodus	doc_213943984960_item	2276743	et	4	main
turva	doc_213943984960_item	2276746	et	4	main
selle	doc_213943984960_item	2276757	et	4	main
pärast	doc_213943984960_item	2276758	et	4	main
et	doc_213943984960_item	2276759	et	3	main
palju	doc_213943984960_item	2276760	et	4	main
aastat	doc_213943984960_item	2276761	et	3	main
tagasi	doc_213943984960_item	2276762	et	3	main
suri	doc_213943984960_item	2276763	et	3	main
minu	doc_213943984960_item	2276764	et	3	main
ema	doc_213943984960_item	2276765	et	4	main
see	doc_213943984960_item	2276766	et	3	main
aeg	doc_213943984960_item	2276769	et	3	main
ei	doc_213943984960_item	2276775	et	4	main
pidevalt	doc_213943984960_item	2276779	et	4	main
õppida	doc_213943984960_item	2276793	et	3	main
pedagoogika	doc_213943984960_item	2276794	et	4	main
see	doc_213943984960_item	2276796	et	3	main
tutvusi	doc_213943984960_item	2276803	et	3	main
olen	doc_213943984960_item	2276809	et	3	main
haige	doc_213943984960_item	2276827	et	4	main
ravimeid	doc_213943984960_item	2276839	et	3	main
oli	doc_213943984960_item	2276841	et	3	main
temale	doc_213943984960_item	2276849	et	3	main
oli	doc_213943984960_item	2276854	et	3	main
terveks	doc_213943984960_item	2276863	et	4	main
essee	doc_213943984961_item	2276864	et	4	main
keskel	doc_213943984961_item	2276872	et	3	main
trepikoda	doc_213943984961_item	2276895	et	4	main
on	doc_213943984961_item	2276896	et	4	main
lukus	doc_213943984961_item	2276897	et	3	main
aga	doc_213943984961_item	2276898	et	3	main
kehv	doc_213943984961_item	2276899	et	3	main
on	doc_213943984961_item	2276900	et	4	main
see	doc_213943984961_item	2276901	et	3	main
et	doc_213943984961_item	2276902	et	3	main
buside	doc_213943984961_item	2276903	et	4	main
peatustele	doc_213943984961_item	2276904	et	4	main
on	doc_213943984961_item	2276905	et	4	main
päris	doc_213943984961_item	2276906	et	4	main
kaua	doc_213943984961_item	2276907	et	3	main
kõndima	doc_213943984961_item	2276908	et	3	main
vaja	doc_213943984961_item	2276909	et	4	main
5-6	doc_213943984961_item	2276910	et	2	main
minutit	doc_213943984961_item	2276911	et	3	main
talvel	doc_213943984961_item	2276912	et	4	main
see	doc_213943984961_item	2276913	et	3	main
on	doc_213943984961_item	2276914	et	4	main
päris	doc_213943984961_item	2276915	et	4	main
raske	doc_213943984961_item	2276916	et	4	main
mõni	doc_213943984961_item	2276917	et	3	main
teha	doc_213943984961_item	2276919	et	3	main
maja	doc_213943984961_item	2276920	et	4	main
kord	doc_213943984961_item	2276918	et	4	main
kus	doc_213943984961_item	2276921	et	3	main
on	doc_213943984961_item	2276924	et	4	main
vähe	doc_213943984961_item	2276939	et	3	main
siis	doc_213943984961_item	2276963	et	3	main
paha	doc_213943984961_item	2276975	et	4	main
on	doc_213943984961_item	2276977	et	4	main
on	doc_213943984961_item	2276989	et	4	main
kui	doc_213943984961_item	2276997	et	3	main
ja	doc_213943984962_item	2277005	et	3	main
ja	doc_213943984962_item	2277014	et	3	main
teeb	doc_213943984962_item	2277016	et	3	main
kesklinnas	doc_213943984962_item	2277023	et	4	main
väljas	doc_213943984962_item	2277028	et	4	main
see	doc_213943984962_item	2277041	et	3	main
inimeste	doc_213943984962_item	2277046	et	3	main
elan	doc_213943984962_item	2277048	et	3	main
juures	doc_213943984962_item	2277051	et	4	main
kiiresti	doc_213943984962_item	2277054	et	3	main
osta	doc_213943984962_item	2277056	et	4	main
minule	doc_213943984962_item	2277066	et	3	main
külaskäiguks	doc_213943984962_item	2277077	et	3	main
eest	doc_213943984961_item	2276894	et	4	main
päris	doc_213943984961_item	2276925	et	4	main
on	doc_213943984961_item	2276936	et	4	main
on	doc_213943984961_item	2276957	et	4	main
ka	doc_213943984961_item	2276958	et	3	main
polikliinik	doc_213943984961_item	2276959	et	3	main
kui	doc_213943984961_item	2276960	et	3	main
väga	doc_213943984961_item	2276965	et	3	main
et	doc_213943984961_item	2276967	et	3	main
sellega	doc_213943984961_item	2276979	et	3	main
on	doc_213943984961_item	2276982	et	4	main
aeg	doc_213943984961_item	2276984	et	3	main
võiks	doc_213943984961_item	2276992	et	4	main
talle	doc_213943984961_item	2276993	et	4	main
oma	doc_213943984961_item	2276994	et	4	main
probleemid	doc_213943984961_item	2276995	et	3	main
olemas	doc_213943984961_item	2276999	et	4	main
see	doc_213943984962_item	2277006	et	3	main
soojaks	doc_213943984962_item	2277009	et	4	main
pole	doc_213943984962_item	2277017	et	3	main
korter	doc_213943984962_item	2277021	et	3	main
eest	doc_213943984962_item	2277042	et	4	main
käiks	doc_213943984962_item	2277047	et	3	main
on	doc_213943984962_item	2277058	et	4	main
naabrid	doc_213943984962_item	2277061	et	3	main
abiks	doc_213943984962_item	2277067	et	3	main
on	doc_213943984962_item	2277069	et	4	main
tuba	doc_213943984962_item	2277071	et	4	main
siis	doc_213943984962_item	2277072	et	3	main
sõbrad	doc_213943984962_item	2277073	et	3	main
mulle	doc_213943984962_item	2277075	et	4	main
selle	doc_213943984961_item	2276928	et	4	main
järgi	doc_213943984961_item	2276929	et	4	main
päris	doc_213943984961_item	2276930	et	4	main
hästi	doc_213943984961_item	2276931	et	3	main
näiteks	doc_213943984961_item	2276940	et	4	main
busside	doc_213943984961_item	2276941	et	3	main
kaugus	doc_213943984961_item	2276943	et	4	main
on	doc_213943984961_item	2276944	et	4	main
kompenseeritud	doc_213943984961_item	2276945	et	4	main
sellega	doc_213943984961_item	2276946	et	3	main
on	doc_213943984961_item	2276949	et	4	main
palju	doc_213943984961_item	2276951	et	4	main
ja	doc_213943984961_item	2276952	et	3	main
tihti	doc_213943984961_item	2276954	et	3	main
käivad	doc_213943984961_item	2276955	et	4	main
lähedal	doc_213943984961_item	2276956	et	4	main
oled	doc_213943984961_item	2276962	et	3	main
juurde	doc_213943984961_item	2276972	et	4	main
seisukord	doc_213943984961_item	2276976	et	3	main
väga	doc_213943984961_item	2276985	et	3	main
maasti	doc_213943984961_item	2276988	et	4	main
essee	doc_213943984962_item	2277001	et	4	main
ma	doc_213943984962_item	2277002	et	3	main
elan	doc_213943984962_item	2277003	et	3	main
tellishoones	doc_213943984962_item	2277004	et	4	main
korrusel	doc_213943984962_item	2277013	et	3	main
see	doc_213943984962_item	2277015	et	3	main
transportimine	doc_213943984962_item	2277020	et	4	main
asub	doc_213943984962_item	2277022	et	3	main
germani	doc_213943984962_item	2277024	et	4	main
kindluse	doc_213943984962_item	2277025	et	4	main
juures	doc_213943984962_item	2277026	et	4	main
sest	doc_213943984962_item	2277032	et	4	main
paljud	doc_213943984962_item	2277034	et	3	main
ukselukk	doc_213943984962_item	2277036	et	3	main
on	doc_213943984962_item	2277043	et	4	main
trepikojas	doc_213943984962_item	2277044	et	3	main
suure	doc_213943984962_item	2277049	et	3	main
siis	doc_213943984962_item	2277052	et	3	main
majas	doc_213943984962_item	2277057	et	3	main
alati	doc_213943984962_item	2277064	et	4	main
mul	doc_213943984962_item	2277068	et	3	main
kompenseeritud	doc_213943984961_item	2276978	et	4	main
treppikoda	doc_213943984961_item	2276981	et	4	main
kogu	doc_213943984961_item	2276983	et	4	main
puhas	doc_213943984961_item	2276986	et	3	main
ja	doc_213943984961_item	2276987	et	3	main
on	doc_213943984961_item	2277000	et	4	main
eriti	doc_213943984962_item	2277008	et	3	main
korter	doc_213943984962_item	2277010	et	3	main
viimasel	doc_213943984962_item	2277012	et	3	main
möbli	doc_213943984962_item	2277019	et	4	main
mugavaks	doc_213943984962_item	2277018	et	3	main
on	doc_213943984962_item	2277029	et	4	main
suur	doc_213943984962_item	2277030	et	3	main
müra	doc_213943984962_item	2277031	et	4	main
küllastajad	doc_213943984962_item	2277035	et	4	main
on	doc_213943984962_item	2277037	et	4	main
tehtud	doc_213943984962_item	2277038	et	4	main
katki	doc_213943984962_item	2277039	et	4	main
aga	doc_213943984962_item	2277040	et	3	main
võõraste	doc_213943984962_item	2277045	et	4	main
kaupluse	doc_213943984962_item	2277050	et	3	main
saaks	doc_213943984962_item	2277053	et	3	main
toiduained	doc_213943984962_item	2277055	et	3	main
hea	doc_213943984962_item	2277060	et	4	main
ja	doc_213943984962_item	2277062	et	3	main
tulevad	doc_213943984962_item	2277065	et	4	main
ja	doc_213943984962_item	2277027	et	3	main
nii	doc_213943984962_item	2277033	et	3	main
väga	doc_213943984962_item	2277059	et	3	main
nad	doc_213943984962_item	2277063	et	3	main
oma	doc_213943984962_item	2277070	et	4	main
olevad	doc_213943984962_item	2277074	et	4	main
tihti	doc_213943984962_item	2277076	et	3	main
me	doc_213943984966_item	2277756	et	4	main
oma	doc_213943984966_item	2277766	et	4	main
korter	doc_213943984966_item	2277768	et	3	main
soe	doc_213943984966_item	2277770	et	4	main
on	doc_213943984966_item	2277776	et	4	main
ukkem	doc_213943984966_item	2277778	et	4	main
osta	doc_213943984966_item	2277781	et	4	main
mailm	doc_213943984966_item	2277791	et	4	main
karm	doc_213943984966_item	2277794	et	4	main
kodu	doc_213943984966_item	2277743	et	4	main
sündinud	doc_213943984966_item	2277746	et	4	main
majas	doc_213943984966_item	2277750	et	3	main
kolmetoaline	doc_213943984966_item	2277762	et	4	main
kõigel	doc_213943984966_item	2277764	et	4	main
selle	doc_213943984966_item	2277782	et	4	main
palju	doc_213943984966_item	2277785	et	4	main
väga	doc_213943984966_item	2277793	et	3	main
omatakse	doc_213943984966_item	2277821	et	4	main
korteri	doc_213943984966_item	2277824	et	3	main
oli	doc_213943984966_item	2277828	et	3	main
me	doc_213943984966_item	2277833	et	4	main
meie	doc_213943984966_item	2277835	et	4	main
kõigile	doc_213943984966_item	2277838	et	4	main
seinas	doc_213943984966_item	2277845	et	3	main
posterid	doc_213943984966_item	2277848	et	3	main
milliseid	doc_213943984966_item	2277850	et	3	main
seinas	doc_213943984966_item	2277854	et	3	main
keskes	doc_213943984966_item	2277855	et	4	main
seisas	doc_213943984966_item	2277857	et	4	main
kus	doc_213943984966_item	2277860	et	3	main
magan	doc_213943984966_item	2277863	et	3	main
ei	doc_213943984966_item	2277871	et	4	main
suur	doc_213943984966_item	2277874	et	3	main
kõige	doc_213943984966_item	2277875	et	4	main
suurem	doc_213943984966_item	2277876	et	4	main
kus	doc_213943984966_item	2277882	et	3	main
aega	doc_213943984966_item	2277889	et	4	main
toas	doc_213943984966_item	2277891	et	3	main
oli	doc_213943984966_item	2277752	et	3	main
uude	doc_213943984966_item	2277757	et	3	main
maja	doc_213943984966_item	2277758	et	4	main
kolime	doc_213943984966_item	2277759	et	3	main
seda	doc_213943984966_item	2277760	et	3	main
on	doc_213943984966_item	2277761	et	4	main
on	doc_213943984966_item	2277769	et	4	main
ja	doc_213943984966_item	2277771	et	3	main
väga	doc_213943984966_item	2277772	et	3	main
mugav	doc_213943984966_item	2277773	et	3	main
suur	doc_213943984966_item	2277774	et	3	main
tuba	doc_213943984966_item	2277775	et	4	main
korter	doc_213943984966_item	2277783	et	3	main
ja	doc_213943984966_item	2277787	et	3	main
otame	doc_213943984966_item	2277788	et	4	main
ja	doc_213943984966_item	2277795	et	3	main
petma	doc_213943984966_item	2277798	et	3	main
meiega	doc_213943984966_item	2277826	et	4	main
sõbralik	doc_213943984966_item	2277830	et	3	main
ja	doc_213943984966_item	2277831	et	3	main
meldib	doc_213943984966_item	2277840	et	4	main
minu	doc_213943984966_item	2277843	et	3	main
armastan	doc_213943984966_item	2277852	et	3	main
on	doc_213943984966_item	2277856	et	4	main
vodi	doc_213943984966_item	2277864	et	4	main
kap	doc_213943984966_item	2277868	et	4	main
minu	doc_213943984966_item	2277869	et	3	main
asi	doc_213943984966_item	2277877	et	4	main
toas	doc_213943984966_item	2277878	et	3	main
minu	doc_213943984966_item	2277880	et	3	main
seisas	doc_213943984966_item	2277883	et	4	main
leian	doc_213943984966_item	2277887	et	3	main
minu	doc_213943984966_item	2277890	et	3	main
ma	doc_213943984966_item	2277893	et	3	main
armastan	doc_213943984966_item	2277895	et	3	main
kodu	doc_213943984966_item	2277897	et	4	main
ilus	doc_213943984966_item	2277903	et	4	main
siin	doc_213943984966_item	2277923	et	4	main
minu	doc_213943984966_item	2277928	et	3	main
päris	doc_213943984967_item	2277939	et	4	main
viimasel	doc_213943984967_item	2277950	et	3	main
et	doc_213943984967_item	2277954	et	3	main
ole	doc_213943984967_item	2277962	et	4	main
endaga	doc_213943984967_item	2277963	et	4	main
inimestele	doc_213943984967_item	2277967	et	3	main
midagi	doc_213943984967_item	2277969	et	4	main
põnevat	doc_213943984967_item	2277974	et	3	main
ei	doc_213943984967_item	2277975	et	4	main
lõppenud	doc_213943984967_item	2277986	et	4	main
kurvalt	doc_213943984967_item	2277987	et	4	main
mis	doc_213943984967_item	2277993	et	4	main
esimene	doc_213943984967_item	2278004	et	3	main
tol	doc_213943984967_item	2278029	et	3	main
liiga	doc_213943984967_item	2278042	et	4	main
korteris	doc_213943984966_item	2277748	et	3	main
ni	doc_213943984966_item	2277753	et	4	main
sellepärast	doc_213943984966_item	2277755	et	3	main
korter	doc_213943984966_item	2277763	et	3	main
kõige	doc_213943984966_item	2277777	et	4	main
et	doc_213943984966_item	2277780	et	3	main
me	doc_213943984966_item	2277784	et	4	main
tingitsem	doc_213943984966_item	2277786	et	4	main
meie	doc_213943984966_item	2277789	et	4	main
tahavad	doc_213943984966_item	2277797	et	3	main
raha	doc_213943984966_item	2277822	et	4	main
ja	doc_213943984966_item	2277823	et	3	main
praegu	doc_213943984966_item	2277832	et	3	main
elame	doc_213943984966_item	2277834	et	3	main
minu	doc_213943984966_item	2277841	et	3	main
on	doc_213943984966_item	2277846	et	4	main
palju	doc_213943984966_item	2277847	et	4	main
paremas	doc_213943984966_item	2277853	et	4	main
ma	doc_213943984966_item	2277862	et	3	main
laul	doc_213943984966_item	2277881	et	4	main
arvuti	doc_213943984966_item	2277885	et	4	main
palju	doc_213943984966_item	2277888	et	4	main
ja	doc_213943984966_item	2277892	et	3	main
väga	doc_213943984966_item	2277902	et	3	main
on	doc_213943984966_item	2277905	et	4	main
essee	doc_213943984966_item	2277741	et	4	main
minu	doc_213943984966_item	2277742	et	3	main
ma	doc_213943984966_item	2277744	et	3	main
olin	doc_213943984966_item	2277745	et	3	main
kahetoalises	doc_213943984966_item	2277747	et	4	main
hrushovi	doc_213943984966_item	2277749	et	4	main
seda	doc_213943984966_item	2277751	et	3	main
mugav	doc_213943984966_item	2277754	et	3	main
on	doc_213943984966_item	2277765	et	4	main
toa	doc_213943984966_item	2277767	et	3	main
aga	doc_213943984966_item	2277779	et	3	main
tänäpäevane	doc_213943984966_item	2277790	et	4	main
on	doc_213943984966_item	2277792	et	4	main
kõik	doc_213943984966_item	2277796	et	4	main
selle	doc_213943984966_item	2277800	et	4	main
teineteist	doc_213943984966_item	2277799	et	4	main
pärast	doc_213943984966_item	2277801	et	4	main
on	doc_213943984966_item	2277802	et	4	main
vaja	doc_213943984966_item	2277803	et	4	main
olla	doc_213943984966_item	2277804	et	3	main
väga	doc_213943984966_item	2277805	et	3	main
ettevatlik	doc_213943984966_item	2277806	et	4	main
nisuguseid	doc_213943984966_item	2277807	et	4	main
küsimuseid	doc_213943984966_item	2277808	et	4	main
nagu	doc_213943984966_item	2277809	et	3	main
korteri	doc_213943984966_item	2277810	et	3	main
vahetamine	doc_213943984966_item	2277811	et	4	main
on	doc_213943984966_item	2277812	et	4	main
palju	doc_213943984966_item	2277813	et	4	main
inimesed	doc_213943984966_item	2277814	et	3	main
kes	doc_213943984966_item	2277815	et	4	main
olnud	doc_213943984966_item	2277816	et	4	main
petakse	doc_213943984966_item	2277817	et	4	main
ja	doc_213943984966_item	2277818	et	3	main
praegu	doc_213943984966_item	2277819	et	3	main
ei	doc_213943984966_item	2277820	et	4	main
saatus	doc_213943984966_item	2277827	et	3	main
vaga	doc_213943984966_item	2277829	et	4	main
surepärases	doc_213943984966_item	2277836	et	4	main
korteris	doc_213943984966_item	2277837	et	3	main
toas	doc_213943984966_item	2277844	et	3	main
ma	doc_213943984966_item	2277861	et	3	main
minu	doc_213943984966_item	2277884	et	3	main
meie	doc_213943984966_item	2277898	et	4	main
piirkond	doc_213943984966_item	2277899	et	3	main
ka	doc_213943984966_item	2277901	et	3	main
rand	doc_213943984966_item	2277906	et	3	main
ei	doc_213943984966_item	2277921	et	4	main
ohtis	doc_213943984966_item	2277925	et	4	main
armastan	doc_213943984966_item	2277927	et	3	main
ka	doc_213943984966_item	2277930	et	3	main
minu	doc_213943984967_item	2277932	et	3	main
18	doc_213943984967_item	2277936	et	2	main
ka	doc_213943984967_item	2277945	et	3	main
olen	doc_213943984967_item	2277952	et	3	main
märganud	doc_213943984967_item	2277953	et	4	main
agressiivne	doc_213943984967_item	2277957	et	3	main
ma	doc_213943984967_item	2277960	et	3	main
aga	doc_213943984966_item	2277825	et	3	main
mulle	doc_213943984966_item	2277839	et	4	main
toa	doc_213943984966_item	2277842	et	3	main
rockbändis	doc_213943984966_item	2277849	et	4	main
ma	doc_213943984966_item	2277851	et	3	main
minu	doc_213943984966_item	2277858	et	3	main
vodi	doc_213943984966_item	2277859	et	4	main
ees	doc_213943984966_item	2277865	et	4	main
televisoon	doc_213943984966_item	2277866	et	4	main
ja	doc_213943984966_item	2277867	et	3	main
toa	doc_213943984966_item	2277870	et	3	main
oli	doc_213943984966_item	2277872	et	3	main
ni	doc_213943984966_item	2277873	et	4	main
on	doc_213943984966_item	2277879	et	4	main
ma	doc_213943984966_item	2277886	et	3	main
seal	doc_213943984966_item	2277904	et	4	main
ja	doc_213943984966_item	2277907	et	3	main
mets	doc_213943984966_item	2277908	et	3	main
palju	doc_213943984966_item	2277909	et	4	main
inimiseid	doc_213943984966_item	2277910	et	4	main
ütlevad	doc_213943984966_item	2277911	et	4	main
et	doc_213943984966_item	2277912	et	3	main
meie	doc_213943984966_item	2277913	et	4	main
piirkond	doc_213943984966_item	2277914	et	3	main
ei	doc_213943984966_item	2277915	et	4	main
oli	doc_213943984966_item	2277916	et	3	main
ni	doc_213943984966_item	2277917	et	4	main
turvaline	doc_213943984966_item	2277918	et	4	main
aga	doc_213943984966_item	2277919	et	3	main
mina	doc_213943984966_item	2277920	et	4	main
suuremas	doc_213943984966_item	2277924	et	4	main
essee	doc_213943984967_item	2277931	et	4	main
elu	doc_213943984967_item	2277933	et	4	main
ma	doc_213943984967_item	2277934	et	3	main
olen	doc_213943984967_item	2277935	et	3	main
aastat	doc_213943984967_item	2277937	et	3	main
inimestele	doc_213943984967_item	2277946	et	3	main
ümbritsevad	doc_213943984967_item	2277948	et	4	main
mind	doc_213943984967_item	2277949	et	4	main
olen	doc_213943984967_item	2277955	et	3	main
uut	doc_213943984967_item	2277970	et	3	main
aga	doc_213943984967_item	2277971	et	3	main
noor	doc_213943984967_item	2277978	et	3	main
on	doc_213943984967_item	2277985	et	4	main
on	doc_213943984967_item	2278002	et	4	main
toimus	doc_213943984967_item	2278028	et	3	main
ma	doc_213943984967_item	2278032	et	3	main
noor	doc_213943984967_item	2278043	et	3	main
minu	doc_213943984967_item	2278051	et	3	main
tema	doc_213943984967_item	2278067	et	4	main
et	doc_213943984967_item	2278071	et	3	main
et	doc_213943984967_item	2278080	et	3	main
pärast	doc_213943984967_item	2278085	et	4	main
ei	doc_213943984967_item	2278090	et	4	main
nii	doc_213943984967_item	2278095	et	3	main
haigus	doc_213943984967_item	2278097	et	4	main
nädalat	doc_213943984967_item	2278101	et	3	main
enda	doc_213943984967_item	2278108	et	4	main
aastast	doc_213943984967_item	2278117	et	4	main
rohkem	doc_213943984967_item	2278120	et	4	main
kaotasin	doc_213943984967_item	2278123	et	3	main
ma	doc_213943984967_item	2278125	et	3	main
hüljatud	doc_213943984967_item	2278127	et	4	main
probleemi	doc_213943984967_item	2278137	et	4	main
keegi	doc_213943984967_item	2278146	et	4	main
ei	doc_213943984967_item	2278147	et	4	main
et	doc_213943984967_item	2278150	et	3	main
ma	doc_213943984967_item	2278156	et	3	main
ma	doc_213943984967_item	2278175	et	3	main
väga	doc_213943984966_item	2277894	et	3	main
minu	doc_213943984966_item	2277896	et	3	main
on	doc_213943984966_item	2277900	et	4	main
tunnen	doc_213943984966_item	2277922	et	3	main
ma	doc_213943984966_item	2277926	et	3	main
piirkond	doc_213943984966_item	2277929	et	3	main
raske	doc_213943984967_item	2277940	et	4	main
eluperiood	doc_213943984967_item	2277941	et	3	main
minu	doc_213943984967_item	2277942	et	3	main
jaoks	doc_213943984967_item	2277943	et	4	main
kui	doc_213943984967_item	2277944	et	3	main
kes	doc_213943984967_item	2277947	et	4	main
ajal	doc_213943984967_item	2277951	et	4	main
väga	doc_213943984967_item	2277956	et	3	main
vihane	doc_213943984967_item	2277959	et	4	main
ei	doc_213943984967_item	2277961	et	4	main
midagi	doc_213943984967_item	2277973	et	4	main
toimu	doc_213943984967_item	2277976	et	4	main
on	doc_213943984967_item	2277980	et	4	main
aasta	doc_213943984967_item	2277989	et	4	main
toimub	doc_213943984967_item	2277995	et	3	main
oma	doc_213943984967_item	2278003	et	4	main
hülgati	doc_213943984967_item	2278022	et	4	main
raske	doc_213943984967_item	2278024	et	4	main
ajal	doc_213943984967_item	2278030	et	4	main
et	doc_213943984967_item	2278044	et	3	main
usuma	doc_213943984967_item	2278047	et	4	main
igal	doc_213943984967_item	2278049	et	3	main
igal	doc_213943984967_item	2278072	et	3	main
maa	doc_213943984967_item	2278074	et	4	main
lõpp	doc_213943984967_item	2278078	et	3	main
sain	doc_213943984967_item	2278087	et	3	main
haigeks	doc_213943984967_item	2278088	et	4	main
et	doc_213943984967_item	2278092	et	3	main
tõsine	doc_213943984967_item	2278096	et	4	main
kaks	doc_213943984967_item	2278100	et	3	main
ja	doc_213943984967_item	2278102	et	3	main
nüüd	doc_213943984967_item	2278105	et	4	main
eest	doc_213943984967_item	2278109	et	4	main
ja	doc_213943984967_item	2278110	et	3	main
ettevaatlikum	doc_213943984967_item	2278111	et	4	main
oma	doc_213943984967_item	2278113	et	4	main
negatiivsus	doc_213943984967_item	2278121	et	4	main
olin	doc_213943984967_item	2278126	et	3	main
võiks	doc_213943984967_item	2278134	et	4	main
jagada	doc_213943984967_item	2278135	et	3	main
nii	doc_213943984967_item	2278136	et	3	main
oli	doc_213943984967_item	2278143	et	3	main
tunne	doc_213943984967_item	2278144	et	4	main
mind	doc_213943984967_item	2278149	et	4	main
sain	doc_213943984967_item	2278157	et	3	main
parem	doc_213943984967_item	2278167	et	4	main
keda	doc_213943984967_item	2278174	et	4	main
ja	doc_213943984967_item	2278177	et	3	main
varem	doc_213943984967_item	2278181	et	4	main
ma	doc_213943984967_item	2278182	et	3	main
ei	doc_213943984967_item	2278183	et	4	main
see	doc_213943984967_item	2278223	et	3	main
moment	doc_213943984967_item	2278227	et	3	main
uhke	doc_213943984967_item	2278230	et	4	main
sain	doc_213943984967_item	2278232	et	3	main
kolisin	doc_213943984967_item	2278235	et	3	main
tallinnase	doc_213943984967_item	2278236	et	3	main
uus	doc_213943984967_item	2278237	et	3	main
uued	doc_213943984967_item	2278239	et	3	main
kõik	doc_213943984967_item	2278241	et	4	main
teistmoodi	doc_213943984967_item	2278243	et	3	main
päris	doc_213943984967_item	2278246	et	4	main
essee	doc_213943984968_item	2278257	et	4	main
isa	doc_213943984968_item	2278267	et	4	main
töötab	doc_213943984968_item	2278268	et	3	main
arvutifirmas	doc_213943984968_item	2278269	et	3	main
seitsme	doc_213943984968_item	2278275	et	3	main
õppisin	doc_213943984968_item	2278277	et	3	main
tundidest	doc_213943984968_item	2278288	et	3	main
parem	doc_213943984968_item	2278293	et	4	main
kunstikoolis	doc_213943984968_item	2278325	et	4	main
astusin	doc_213943984968_item	2278328	et	3	main
saavutas	doc_213943984968_item	2278333	et	3	main
käis	doc_213943984968_item	2278345	et	4	main
tulnud	doc_213943984968_item	2278352	et	4	main
akademiasse	doc_213943984968_item	2278362	et	4	main
vana	doc_213943984967_item	2277938	et	4	main
ja	doc_213943984967_item	2277958	et	3	main
rahul	doc_213943984967_item	2277964	et	4	main
ootan	doc_213943984967_item	2277968	et	3	main
mitte	doc_213943984967_item	2277972	et	3	main
olen	doc_213943984967_item	2277977	et	3	main
aga	doc_213943984967_item	2277979	et	3	main
tunne	doc_213943984967_item	2277981	et	4	main
et	doc_213943984967_item	2277982	et	3	main
mu	doc_213943984967_item	2277983	et	3	main
viie	doc_213943984967_item	2277988	et	3	main
jooksul	doc_213943984967_item	2277990	et	4	main
mõista	doc_213943984967_item	2277992	et	4	main
ja	doc_213943984967_item	2277996	et	3	main
on	doc_213943984967_item	2277998	et	4	main
inimesel	doc_213943984967_item	2278001	et	3	main
armastuse	doc_213943984967_item	2278005	et	4	main
kogemus	doc_213943984967_item	2278006	et	3	main
minu	doc_213943984967_item	2278007	et	3	main
armastuse	doc_213943984967_item	2278008	et	4	main
kogemus	doc_213943984967_item	2278009	et	3	main
väga	doc_213943984967_item	2278011	et	3	main
kurb	doc_213943984967_item	2278012	et	3	main
on	doc_213943984967_item	2278010	et	4	main
ehkki	doc_213943984967_item	2278013	et	3	main
see	doc_213943984967_item	2278014	et	3	main
oli	doc_213943984967_item	2278015	et	3	main
ammu	doc_213943984967_item	2278016	et	4	main
ma	doc_213943984967_item	2278017	et	3	main
mäletan	doc_213943984967_item	2278018	et	3	main
siiamani	doc_213943984967_item	2278019	et	4	main
kuidas	doc_213943984967_item	2278020	et	3	main
ei	doc_213943984967_item	2277965	et	4	main
usu	doc_213943984967_item	2277966	et	4	main
elu	doc_213943984967_item	2277984	et	4	main
ei	doc_213943984967_item	2277991	et	4	main
minuga	doc_213943984967_item	2277994	et	3	main
sellele	doc_213943984967_item	2277997	et	4	main
põhjus	doc_213943984967_item	2277999	et	4	main
igal	doc_213943984967_item	2278000	et	3	main
mind	doc_213943984967_item	2278021	et	4	main
väga	doc_213943984967_item	2278023	et	3	main
kirjeldada	doc_213943984967_item	2278025	et	3	main
mis	doc_213943984967_item	2278026	et	4	main
minuga	doc_213943984967_item	2278027	et	3	main
end	doc_213943984967_item	2278034	et	4	main
polnud	doc_213943984967_item	2278037	et	3	main
südi	doc_213943984967_item	2278038	et	4	main
me	doc_213943984967_item	2278040	et	4	main
nii	doc_213943984967_item	2278045	et	3	main
ei	doc_213943984967_item	2278064	et	4	main
ole	doc_213943984967_item	2278065	et	4	main
mõistan	doc_213943984967_item	2278070	et	3	main
oma	doc_213943984967_item	2278077	et	4	main
üksi	doc_213943984967_item	2278084	et	4	main
ma	doc_213943984967_item	2278089	et	3	main
hoolitsen	doc_213943984967_item	2278107	et	3	main
tervisele	doc_213943984967_item	2278114	et	3	main
ma	doc_213943984967_item	2278122	et	3	main
kõrval	doc_213943984967_item	2278131	et	4	main
inimest	doc_213943984967_item	2278132	et	3	main
ka	doc_213943984967_item	2278139	et	3	main
ajal	doc_213943984967_item	2278142	et	4	main
et	doc_213943984967_item	2278145	et	3	main
mind	doc_213943984967_item	2278151	et	4	main
mis	doc_213943984967_item	2278159	et	4	main
oli	doc_213943984967_item	2278161	et	3	main
sõbranna	doc_213943984967_item	2278168	et	4	main
minu	doc_213943984967_item	2278169	et	3	main
õde	doc_213943984967_item	2278170	et	4	main
on	doc_213943984967_item	2278172	et	4	main
aitab	doc_213943984967_item	2278179	et	3	main
positiivne	doc_213943984967_item	2278226	et	3	main
see	doc_213943984967_item	2278244	et	3	main
kõik	doc_213943984967_item	2278249	et	4	main
olla	doc_213943984967_item	2278254	et	3	main
olen	doc_213943984968_item	2278259	et	3	main
enne	doc_213943984968_item	2278274	et	4	main
üsna	doc_213943984968_item	2278278	et	3	main
probleeme	doc_213943984968_item	2278286	et	3	main
kui	doc_213943984968_item	2278294	et	3	main
teised	doc_213943984968_item	2278296	et	4	main
vaid	doc_213943984967_item	2278031	et	3	main
südistasin	doc_213943984967_item	2278033	et	4	main
tegelikult	doc_213943984967_item	2278035	et	4	main
keegi	doc_213943984967_item	2278036	et	4	main
sest	doc_213943984967_item	2278039	et	4	main
olime	doc_213943984967_item	2278041	et	3	main
juhul	doc_213943984967_item	2278050	et	3	main
oli	doc_213943984967_item	2278053	et	3	main
valus	doc_213943984967_item	2278055	et	4	main
pisarad	doc_213943984967_item	2278056	et	3	main
pettus	doc_213943984967_item	2278057	et	4	main
kõik	doc_213943984967_item	2278058	et	4	main
on	doc_213943984967_item	2278059	et	4	main
möödunud	doc_213943984967_item	2278060	et	4	main
ja	doc_213943984967_item	2278061	et	3	main
praegu	doc_213943984967_item	2278062	et	3	main
ma	doc_213943984967_item	2278063	et	3	main
tõsiselt	doc_213943984967_item	2278046	et	4	main
armastusse	doc_213943984967_item	2278048	et	4	main
süda	doc_213943984967_item	2278052	et	3	main
rikutud	doc_213943984967_item	2278054	et	4	main
vihane	doc_213943984967_item	2278066	et	4	main
peale	doc_213943984967_item	2278068	et	4	main
sest	doc_213943984967_item	2278069	et	4	main
räägitakse	doc_213943984967_item	2278079	et	3	main
õnnetus	doc_213943984967_item	2278081	et	4	main
teadnud	doc_213943984967_item	2278091	et	4	main
oli	doc_213943984967_item	2278094	et	3	main
olin	doc_213943984967_item	2278098	et	3	main
terveks	doc_213943984967_item	2278104	et	4	main
ma	doc_213943984967_item	2278106	et	3	main
suhtun	doc_213943984967_item	2278112	et	3	main
14	doc_213943984967_item	2278116	et	2	main
on	doc_213943984967_item	2278119	et	4	main
asjal	doc_213943984967_item	2278073	et	3	main
peal	doc_213943984967_item	2278075	et	4	main
on	doc_213943984967_item	2278076	et	4	main
ei	doc_213943984967_item	2278082	et	4	main
tule	doc_213943984967_item	2278083	et	4	main
ma	doc_213943984967_item	2278086	et	3	main
mul	doc_213943984967_item	2278093	et	3	main
haiglas	doc_213943984967_item	2278099	et	3	main
sain	doc_213943984967_item	2278103	et	3	main
alates	doc_213943984967_item	2278115	et	3	main
mul	doc_213943984967_item	2278118	et	3	main
mul	doc_213943984967_item	2278128	et	3	main
olnud	doc_213943984967_item	2278130	et	4	main
kellega	doc_213943984967_item	2278133	et	3	main
õnne	doc_213943984967_item	2278140	et	4	main
ümbritsevad	doc_213943984967_item	2278152	et	4	main
vaid	doc_213943984967_item	2278153	et	3	main
aga	doc_213943984967_item	2278155	et	3	main
hakkama	doc_213943984967_item	2278158	et	3	main
hea	doc_213943984967_item	2278160	et	4	main
elus	doc_213943984967_item	2278163	et	4	main
praegu	doc_213943984967_item	2278164	et	3	main
mul	doc_213943984967_item	2278165	et	3	main
see	doc_213943984967_item	2278171	et	3	main
inimene	doc_213943984967_item	2278173	et	3	main
arvan	doc_213943984967_item	2278221	et	3	main
ma	doc_213943984967_item	2278228	et	3	main
olen	doc_213943984967_item	2278229	et	3	main
ma	doc_213943984967_item	2278234	et	3	main
on	doc_213943984967_item	2278242	et	4	main
on	doc_213943984967_item	2278250	et	4	main
korras	doc_213943984967_item	2278251	et	4	main
tahaksin	doc_213943984967_item	2278253	et	3	main
elulugu	doc_213943984968_item	2278258	et	4	main
tallinnas	doc_213943984968_item	2278262	et	4	main
ema	doc_213943984968_item	2278264	et	4	main
õppisin	doc_213943984968_item	2278270	et	3	main
reaalkoolis	doc_213943984968_item	2278273	et	4	main
palju	doc_213943984968_item	2278285	et	4	main
lõpetasin	doc_213943984968_item	2278290	et	3	main
ja	doc_213943984968_item	2278292	et	3	main
paljud	doc_213943984968_item	2278295	et	3	main
lapsepõlvest	doc_213943984968_item	2278297	et	4	main
viie	doc_213943984968_item	2278321	et	3	main
12	doc_213943984968_item	2278326	et	2	main
ema	doc_213943984968_item	2278335	et	4	main
kätt	doc_213943984968_item	2278338	et	3	main
õpetajad	doc_213943984968_item	2278341	et	4	main
tasku	doc_213943984968_item	2278347	et	4	main
ma	doc_213943984968_item	2278361	et	3	main
astuda	doc_213943984968_item	2278363	et	3	main
kuus	doc_213943984968_item	2278366	et	4	main
enne	doc_213943984968_item	2278369	et	4	main
maale	doc_213943984968_item	2278378	et	4	main
oma	doc_213943984968_item	2278382	et	4	main
luba	doc_213943984968_item	2278385	et	4	main
läbi	doc_213943984968_item	2278390	et	4	main
tollal	doc_213943984968_item	2278400	et	3	main
minema	doc_213943984968_item	2278404	et	3	main
öeldes	doc_213943984968_item	2278406	et	3	main
akademias	doc_213943984968_item	2278413	et	4	main
võib	doc_213943984968_item	2278415	et	3	main
mind	doc_213943984968_item	2278421	et	4	main
sain	doc_213943984968_item	2278428	et	3	main
esmakordselt	doc_213943984968_item	2278430	et	4	main
vedas	doc_213943984968_item	2278431	et	4	main
linnas	doc_213943984969_item	2278442	et	4	main
mul	doc_213943984969_item	2278443	et	3	main
kuigi	doc_213943984969_item	2278456	et	3	main
kui	doc_213943984969_item	2278467	et	3	main
olin	doc_213943984969_item	2278469	et	3	main
mul	doc_213943984969_item	2278474	et	3	main
esimene	doc_213943984969_item	2278487	et	3	main
klassis	doc_213943984969_item	2278534	et	3	main
palju	doc_213943984969_item	2278538	et	4	main
soome	doc_213943984969_item	2278549	et	3	main
kahekesi	doc_213943984969_item	2278554	et	3	main
töötama	doc_213943984969_item	2278556	et	3	main
me	doc_213943984969_item	2278559	et	4	main
õppilased	doc_213943984969_item	2278565	et	4	main
enam	doc_213943984969_item	2278566	et	4	main
sündmus	doc_213943984969_item	2278577	et	3	main
sõbrannat	doc_213943984967_item	2278124	et	3	main
ei	doc_213943984967_item	2278129	et	4	main
kui	doc_213943984967_item	2278138	et	3	main
tol	doc_213943984967_item	2278141	et	3	main
mõista	doc_213943984967_item	2278148	et	4	main
vaenlased	doc_213943984967_item	2278154	et	3	main
minu	doc_213943984967_item	2278162	et	3	main
on	doc_213943984967_item	2278166	et	4	main
usun	doc_213943984967_item	2278176	et	3	main
kes	doc_213943984967_item	2278178	et	4	main
mind	doc_213943984967_item	2278180	et	4	main
võimalik	doc_213943984967_item	2278187	et	3	main
sõbrustama	doc_213943984967_item	2278188	et	3	main
õega	doc_213943984967_item	2278189	et	3	main
kuna	doc_213943984967_item	2278190	et	3	main
meie	doc_213943984967_item	2278191	et	4	main
vahel	doc_213943984967_item	2278192	et	4	main
ei	doc_213943984967_item	2278193	et	4	main
ole	doc_213943984967_item	2278194	et	4	main
liiga	doc_213943984967_item	2278195	et	4	main
suur	doc_213943984967_item	2278196	et	3	main
vanuse	doc_213943984967_item	2278197	et	4	main
vahe	doc_213943984967_item	2278198	et	4	main
ta	doc_213943984967_item	2278199	et	4	main
on	doc_213943984967_item	2278200	et	4	main
natukene	doc_213943984967_item	2278201	et	4	main
vanem	doc_213943984967_item	2278202	et	4	main
on	doc_213943984967_item	2278204	et	4	main
sarnased	doc_213943984967_item	2278205	et	4	main
meil	doc_213943984967_item	2278203	et	4	main
huvid	doc_213943984967_item	2278206	et	3	main
me	doc_213943984967_item	2278207	et	4	main
mõistame	doc_213943984967_item	2278208	et	3	main
teineteist	doc_213943984967_item	2278209	et	4	main
jne	doc_213943984967_item	2278210	et	4	main
olen	doc_213943984967_item	2278211	et	3	main
rõõmus	doc_213943984967_item	2278212	et	4	main
et	doc_213943984967_item	2278213	et	3	main
mul	doc_213943984967_item	2278214	et	3	main
on	doc_213943984967_item	2278215	et	4	main
sellel	doc_213943984967_item	2278217	et	4	main
õde	doc_213943984967_item	2278216	et	4	main
aasta	doc_213943984967_item	2278218	et	4	main
astusin	doc_213943984967_item	2278219	et	3	main
ülikooli	doc_213943984967_item	2278220	et	4	main
et	doc_213943984967_item	2278222	et	3	main
on	doc_213943984967_item	2278224	et	4	main
et	doc_213943984967_item	2278231	et	3	main
sisse	doc_213943984967_item	2278233	et	4	main
teadnud	doc_213943984967_item	2278184	et	4	main
et	doc_213943984967_item	2278185	et	3	main
on	doc_213943984967_item	2278186	et	4	main
väga	doc_213943984967_item	2278225	et	3	main
linn	doc_213943984967_item	2278238	et	3	main
on	doc_213943984967_item	2278245	et	4	main
vapustav	doc_213943984967_item	2278247	et	4	main
ühesõnaga	doc_213943984967_item	2278248	et	3	main
kuigi	doc_213943984967_item	2278252	et	3	main
natukene	doc_213943984967_item	2278255	et	4	main
harjumaal	doc_213943984968_item	2278261	et	4	main
tõnismäe	doc_213943984968_item	2278272	et	3	main
klassi	doc_213943984968_item	2278276	et	4	main
hästi	doc_213943984968_item	2278279	et	3	main
kaheksandas	doc_213943984968_item	2278281	et	3	main
on	doc_213943984968_item	2278283	et	4	main
põhikooli	doc_213943984968_item	2278291	et	4	main
saadik	doc_213943984968_item	2278298	et	4	main
olen	doc_213943984968_item	2278299	et	3	main
ma	doc_213943984968_item	2278300	et	3	main
otsustanud	doc_213943984968_item	2278301	et	4	main
kunstnikuks	doc_213943984968_item	2278302	et	3	main
saada	doc_213943984968_item	2278303	et	4	main
kuna	doc_213943984968_item	2278304	et	3	main
oma	doc_213943984968_item	2278305	et	4	main
terve	doc_213943984968_item	2278306	et	4	main
elu	doc_213943984968_item	2278307	et	4	main
kui	doc_213943984968_item	2278308	et	3	main
kaua	doc_213943984968_item	2278309	et	3	main
mäletan	doc_213943984968_item	2278310	et	3	main
ennast	doc_213943984968_item	2278311	et	4	main
olen	doc_213943984968_item	2278312	et	3	main
ma	doc_213943984968_item	2278313	et	3	main
alati	doc_213943984968_item	2278314	et	4	main
joonistanud	doc_213943984968_item	2278315	et	4	main
esiteks	doc_213943984968_item	2278316	et	3	main
käisin	doc_213943984968_item	2278317	et	3	main
laste	doc_213943984968_item	2278318	et	4	main
kunstistuudios	doc_213943984968_item	2278319	et	3	main
pärast	doc_213943984968_item	2278320	et	4	main
aasta	doc_213943984968_item	2278322	et	4	main
klassis	doc_213943984968_item	2278327	et	3	main
olgugi	doc_213943984968_item	2278349	et	4	main
tarvis	doc_213943984968_item	2278365	et	3	main
eksami	doc_213943984968_item	2278367	et	3	main
valik	doc_213943984968_item	2278372	et	3	main
voor	doc_213943984968_item	2278373	et	4	main
oli	doc_213943984968_item	2278375	et	3	main
ja	doc_213943984968_item	2278379	et	3	main
ma	doc_213943984968_item	2278388	et	3	main
juba	doc_213943984968_item	2278391	et	3	main
nii	doc_213943984968_item	2278402	et	3	main
ausalt	doc_213943984968_item	2278405	et	4	main
ajal	doc_213943984968_item	2278408	et	4	main
ei	doc_213943984968_item	2278409	et	4	main
hirmustas	doc_213943984968_item	2278420	et	4	main
tulin	doc_213943984968_item	2278424	et	3	main
ma	doc_213943984968_item	2278425	et	3	main
pedagoogikaülikooli	doc_213943984968_item	2278427	et	4	main
ma	doc_213943984969_item	2278437	et	3	main
olen	doc_213943984969_item	2278438	et	3	main
väga	doc_213943984969_item	2278445	et	3	main
lapsepõlv	doc_213943984969_item	2278447	et	3	main
elasin	doc_213943984969_item	2278449	et	3	main
inimesed	doc_213943984967_item	2278240	et	3	main
õnnelikum	doc_213943984967_item	2278256	et	4	main
sündinud	doc_213943984968_item	2278260	et	4	main
minu	doc_213943984968_item	2278263	et	3	main
on	doc_213943984968_item	2278265	et	4	main
raamatupidaja	doc_213943984968_item	2278266	et	4	main
tallinna	doc_213943984968_item	2278271	et	4	main
kuid	doc_213943984968_item	2278280	et	4	main
klassis	doc_213943984968_item	2278282	et	3	main
tekkinud	doc_213943984968_item	2278284	et	4	main
osavõttega	doc_213943984968_item	2278287	et	3	main
ehkki	doc_213943984968_item	2278289	et	3	main
jooksul	doc_213943984968_item	2278323	et	4	main
ettevalmiskursustele	doc_213943984968_item	2278329	et	3	main
akadeemias	doc_213943984968_item	2278331	et	3	main
seda	doc_213943984968_item	2278332	et	3	main
jalga	doc_213943984968_item	2278339	et	4	main
mööda	doc_213943984968_item	2278340	et	4	main
vahetusid	doc_213943984968_item	2278342	et	4	main
pidevalt	doc_213943984968_item	2278343	et	4	main
meile	doc_213943984968_item	2278346	et	4	main
pihta	doc_213943984968_item	2278348	et	4	main
et	doc_213943984968_item	2278350	et	3	main
ei	doc_213943984968_item	2278351	et	4	main
veel	doc_213943984968_item	2278371	et	4	main
vaja	doc_213943984968_item	2278376	et	4	main
esimesel	doc_213943984968_item	2278392	et	3	main
vihane	doc_213943984968_item	2278397	et	4	main
mõtlesin	doc_213943984968_item	2278399	et	3	main
kaduge	doc_213943984968_item	2278403	et	3	main
sel	doc_213943984968_item	2278407	et	3	main
eksamite	doc_213943984968_item	2278417	et	3	main
nii	doc_213943984968_item	2278419	et	3	main
südamega	doc_213943984968_item	2278423	et	3	main
sisse	doc_213943984968_item	2278429	et	4	main
essee	doc_213943984969_item	2278434	et	4	main
ida-virumaal	doc_213943984969_item	2278440	et	4	main
oli	doc_213943984969_item	2278444	et	3	main
ma	doc_213943984969_item	2278448	et	3	main
minu	doc_213943984969_item	2278451	et	3	main
õega	doc_213943984969_item	2278455	et	3	main
me	doc_213943984969_item	2278457	et	4	main
olime	doc_213943984969_item	2278461	et	3	main
ja	doc_213943984969_item	2278464	et	3	main
perekond	doc_213943984969_item	2278466	et	3	main
seitsemeaastane	doc_213943984969_item	2278470	et	4	main
väga	doc_213943984969_item	2278476	et	3	main
sõpru	doc_213943984969_item	2278480	et	3	main
minu	doc_213943984969_item	2278522	et	3	main
murdsin	doc_213943984969_item	2278527	et	3	main
aastavahetusel	doc_213943984969_item	2278529	et	4	main
õppisin	doc_213943984969_item	2278532	et	3	main
ja	doc_213943984969_item	2278535	et	3	main
mul	doc_213943984969_item	2278536	et	3	main
suvereis	doc_213943984969_item	2278548	et	4	main
ei	doc_213943984969_item	2278557	et	4	main
kuna	doc_213943984969_item	2278562	et	3	main
halba	doc_213943984969_item	2278568	et	4	main
hea	doc_213943984969_item	2278576	et	4	main
olin	doc_213943984969_item	2278581	et	3	main
alati	doc_213943984969_item	2278585	et	4	main
unistanud	doc_213943984969_item	2278587	et	4	main
olin	doc_213943984969_item	2278596	et	3	main
meiega	doc_213943984969_item	2278603	et	4	main
ujuma	doc_213943984969_item	2278630	et	3	main
mu	doc_213943984969_item	2278639	et	3	main
tähtsam	doc_213943984969_item	2278642	et	4	main
sündmus	doc_213943984969_item	2278643	et	3	main
väga	doc_213943984970_item	2278668	et	3	main
inimene	doc_213943984970_item	2278670	et	3	main
aastal	doc_213943984970_item	2278675	et	3	main
läänemere	doc_213943984970_item	2278677	et	3	main
gümnaasiumi	doc_213943984970_item	2278678	et	4	main
pärast	doc_213943984970_item	2278679	et	4	main
astusin	doc_213943984970_item	2278680	et	3	main
ülikooli	doc_213943984970_item	2278696	et	4	main
suur	doc_213943984970_item	2278708	et	3	main
gümnaasiumi	doc_213943984970_item	2278710	et	4	main
ma	doc_213943984970_item	2278715	et	3	main
endaga	doc_213943984970_item	2278717	et	4	main
rahul	doc_213943984970_item	2278719	et	4	main
tallinna	doc_213943984968_item	2278324	et	4	main
kunsti	doc_213943984968_item	2278330	et	4	main
minu	doc_213943984968_item	2278334	et	3	main
õpetamine	doc_213943984968_item	2278336	et	4	main
toimus	doc_213943984968_item	2278337	et	3	main
õpetus	doc_213943984968_item	2278344	et	4	main
sellest	doc_213943984968_item	2278353	et	4	main
midagi	doc_213943984968_item	2278354	et	4	main
välja	doc_213943984968_item	2278355	et	4	main
pärast	doc_213943984968_item	2278356	et	4	main
kooli	doc_213943984968_item	2278357	et	4	main
lõpetamist	doc_213943984968_item	2278358	et	4	main
loomulikult	doc_213943984968_item	2278359	et	4	main
proovisin	doc_213943984968_item	2278360	et	3	main
oli	doc_213943984968_item	2278364	et	3	main
oli	doc_213943984968_item	2278370	et	3	main
oma	doc_213943984968_item	2278377	et	4	main
joonistusi	doc_213943984968_item	2278380	et	4	main
ei	doc_213943984968_item	2278384	et	4	main
eksamitele	doc_213943984968_item	2278387	et	3	main
jooksul	doc_213943984968_item	2278393	et	4	main
olin	doc_213943984968_item	2278395	et	3	main
ah	doc_213943984968_item	2278401	et	3	main
tahtnud	doc_213943984968_item	2278410	et	4	main
ma	doc_213943984968_item	2278411	et	3	main
enam	doc_213943984968_item	2278412	et	4	main
õppida	doc_213943984968_item	2278414	et	3	main
olla	doc_213943984968_item	2278416	et	3	main
sooritada	doc_213943984968_item	2278368	et	3	main
kus	doc_213943984968_item	2278374	et	3	main
näidata	doc_213943984968_item	2278381	et	4	main
häbiks	doc_213943984968_item	2278383	et	3	main
mind	doc_213943984968_item	2278386	et	4	main
kukusin	doc_213943984968_item	2278389	et	4	main
tingimatu	doc_213943984968_item	2278394	et	4	main
ma	doc_213943984968_item	2278396	et	3	main
ma	doc_213943984968_item	2278398	et	3	main
arv	doc_213943984968_item	2278418	et	3	main
siis	doc_213943984968_item	2278426	et	3	main
oma	doc_213943984969_item	2278435	et	4	main
elust	doc_213943984969_item	2278436	et	3	main
kohtla-järve	doc_213943984969_item	2278441	et	4	main
koos	doc_213943984969_item	2278450	et	4	main
vanematega	doc_213943984969_item	2278452	et	4	main
väikeses	doc_213943984969_item	2278459	et	4	main
ma	doc_213943984969_item	2278468	et	3	main
läksin	doc_213943984969_item	2278472	et	3	main
hea	doc_213943984969_item	2278477	et	4	main
palju	doc_213943984969_item	2278479	et	4	main
ja	doc_213943984969_item	2278481	et	3	main
negatiivne	doc_213943984969_item	2278488	et	3	main
elus	doc_213943984969_item	2278523	et	4	main
ma	doc_213943984969_item	2278526	et	3	main
kaheteistkümnendas	doc_213943984969_item	2278533	et	4	main
oli	doc_213943984969_item	2278537	et	3	main
minu	doc_213943984969_item	2278545	et	3	main
raha	doc_213943984969_item	2278561	et	4	main
midagi	doc_213943984969_item	2278567	et	4	main
tule	doc_213943984969_item	2278572	et	4	main
minu	doc_213943984969_item	2278573	et	3	main
esimene	doc_213943984969_item	2278574	et	3	main
et	doc_213943984969_item	2278583	et	3	main
ma	doc_213943984969_item	2278584	et	3	main
koera	doc_213943984969_item	2278589	et	4	main
ning	doc_213943984969_item	2278599	et	3	main
koer	doc_213943984969_item	2278601	et	3	main
tänaseni	doc_213943984969_item	2278605	et	4	main
magasime	doc_213943984969_item	2278621	et	3	main
telkides	doc_213943984969_item	2278623	et	4	main
ilus	doc_213943984969_item	2278627	et	4	main
käisime	doc_213943984969_item	2278629	et	3	main
ning	doc_213943984969_item	2278631	et	3	main
külastasime	doc_213943984969_item	2278633	et	3	main
olevat	doc_213943984969_item	2278635	et	4	main
kõige	doc_213943984969_item	2278641	et	4	main
tpü-sse	doc_213943984969_item	2278645	et	3	main
saamine	doc_213943984969_item	2278647	et	4	main
seoses	doc_213943984969_item	2278648	et	4	main
lapsepõlvest	doc_213943984970_item	2278666	et	4	main
olin	doc_213943984970_item	2278667	et	3	main
transpordikooli	doc_213943984970_item	2278683	et	4	main
ja	doc_213943984970_item	2278684	et	3	main
tugispetsialisti	doc_213943984970_item	2278690	et	4	main
edasi	doc_213943984970_item	2278692	et	3	main
õnnetus	doc_213943984970_item	2278709	et	4	main
tulemused	doc_213943984970_item	2278721	et	3	main
ma	doc_213943984970_item	2278729	et	3	main
endale	doc_213943984970_item	2278731	et	4	main
oli	doc_213943984970_item	2278735	et	3	main
on	doc_213943984970_item	2278749	et	4	main
minu	doc_213943984970_item	2278757	et	3	main
teine	doc_213943984970_item	2278758	et	3	main
ma	doc_213943984970_item	2278760	et	3	main
seda	doc_213943984970_item	2278762	et	3	main
venemaale	doc_213943984970_item	2278772	et	4	main
lähedam	doc_213943984970_item	2278776	et	4	main
inimene	doc_213943984970_item	2278777	et	3	main
sõltunud	doc_213943984970_item	2278781	et	4	main
siiamani	doc_213943984970_item	2278784	et	4	main
mul	doc_213943984970_item	2278785	et	3	main
ei	doc_213943984970_item	2278786	et	4	main
ole	doc_213943984970_item	2278787	et	4	main
sellist	doc_213943984970_item	2278788	et	4	main
situatsioon	doc_213943984970_item	2278825	et	3	main
praeguni	doc_213943984970_item	2278827	et	4	main
vanemad	doc_213943984970_item	2278829	et	4	main
ma	doc_213943984970_item	2278833	et	3	main
õppida	doc_213943984970_item	2278843	et	3	main
kõik	doc_213943984970_item	2278850	et	4	main
korras	doc_213943984970_item	2278851	et	4	main
rahuliku	doc_213943984968_item	2278422	et	3	main
mul	doc_213943984968_item	2278432	et	3	main
tõeliselt	doc_213943984968_item	2278433	et	4	main
sündinud	doc_213943984969_item	2278439	et	4	main
õnnelik	doc_213943984969_item	2278446	et	3	main
vennaga	doc_213943984969_item	2278453	et	3	main
ja	doc_213943984969_item	2278454	et	3	main
korteris	doc_213943984969_item	2278460	et	3	main
ma	doc_213943984969_item	2278471	et	3	main
oli	doc_213943984969_item	2278475	et	3	main
klass	doc_213943984969_item	2278478	et	3	main
alati	doc_213943984969_item	2278482	et	4	main
head	doc_213943984969_item	2278484	et	4	main
hinded	doc_213943984969_item	2278485	et	3	main
minu	doc_213943984969_item	2278486	et	3	main
sündmus	doc_213943984969_item	2278489	et	3	main
elus	doc_213943984969_item	2278490	et	4	main
oli	doc_213943984969_item	2278491	et	3	main
kui	doc_213943984969_item	2278492	et	3	main
me	doc_213943984969_item	2278493	et	4	main
kolisime	doc_213943984969_item	2278494	et	3	main
teisesse	doc_213943984969_item	2278495	et	4	main
rajoonisse	doc_213943984969_item	2278496	et	3	main
pidin	doc_213943984969_item	2278497	et	3	main
ma	doc_213943984969_item	2278498	et	3	main
kooli	doc_213943984969_item	2278499	et	4	main
vahetama	doc_213943984969_item	2278500	et	3	main
ehki	doc_213943984969_item	2278501	et	4	main
uus	doc_213943984969_item	2278502	et	3	main
kool	doc_213943984969_item	2278503	et	4	main
oli	doc_213943984969_item	2278504	et	3	main
väga	doc_213943984969_item	2278505	et	3	main
hea	doc_213943984969_item	2278506	et	4	main
igatsesin	doc_213943984969_item	2278507	et	3	main
ma	doc_213943984969_item	2278508	et	3	main
vana	doc_213943984969_item	2278510	et	4	main
oma	doc_213943984969_item	2278509	et	4	main
klassi	doc_213943984969_item	2278511	et	4	main
seoses	doc_213943984969_item	2278512	et	4	main
sellega	doc_213943984969_item	2278513	et	3	main
kaasnesid	doc_213943984969_item	2278514	et	4	main
mul	doc_213943984969_item	2278515	et	3	main
mitmed	doc_213943984969_item	2278516	et	4	main
probleemid	doc_213943984969_item	2278517	et	3	main
õppimises	doc_213943984969_item	2278518	et	4	main
teine	doc_213943984969_item	2278519	et	3	main
paha	doc_213943984969_item	2278520	et	4	main
elasime	doc_213943984969_item	2278458	et	3	main
alati	doc_213943984969_item	2278462	et	4	main
õnnelik	doc_213943984969_item	2278463	et	3	main
sõbralik	doc_213943984969_item	2278465	et	3	main
kooli	doc_213943984969_item	2278473	et	4	main
oled	doc_213943984969_item	2278483	et	3	main
sündmus	doc_213943984969_item	2278521	et	3	main
jalaluumurd	doc_213943984969_item	2278525	et	3	main
raskusi	doc_213943984969_item	2278539	et	4	main
eksamite	doc_213943984969_item	2278540	et	3	main
sooritamisega	doc_213943984969_item	2278541	et	4	main
kolmas	doc_213943984969_item	2278542	et	3	main
olgugi	doc_213943984969_item	2278550	et	4	main
sinna	doc_213943984969_item	2278553	et	3	main
saanud	doc_213943984969_item	2278558	et	4	main
palju	doc_213943984969_item	2278560	et	4	main
pähe	doc_213943984969_item	2278570	et	4	main
oli	doc_213943984969_item	2278578	et	3	main
elab	doc_213943984969_item	2278602	et	3	main
seal	doc_213943984969_item	2278622	et	4	main
päeval	doc_213943984969_item	2278624	et	3	main
oli	doc_213943984969_item	2278626	et	3	main
õhtul	doc_213943984969_item	2278632	et	3	main
muidugi	doc_213943984969_item	2278638	et	4	main
sellega	doc_213943984969_item	2278649	et	3	main
ma	doc_213943984969_item	2278650	et	3	main
sündisin	doc_213943984970_item	2278660	et	3	main
tallinnas	doc_213943984970_item	2278661	et	4	main
augusti	doc_213943984970_item	2278664	et	3	main
õppisin	doc_213943984970_item	2278671	et	3	main
2002	doc_213943984970_item	2278674	et	2	main
tallinna	doc_213943984970_item	2278682	et	4	main
lõpetasin	doc_213943984970_item	2278687	et	3	main
pedagoogika	doc_213943984970_item	2278695	et	4	main
nüüd	doc_213943984970_item	2278698	et	4	main
mäleta	doc_213943984970_item	2278706	et	4	main
esimene	doc_213943984970_item	2278707	et	3	main
lõpetamine	doc_213943984970_item	2278711	et	4	main
kõrged	doc_213943984970_item	2278725	et	3	main
teine	doc_213943984970_item	2278726	et	3	main
asi	doc_213943984970_item	2278728	et	4	main
leidsin	doc_213943984970_item	2278730	et	3	main
tööt	doc_213943984970_item	2278732	et	4	main
kuna	doc_213943984970_item	2278733	et	3	main
see	doc_213943984970_item	2278734	et	3	main
aga	doc_213943984970_item	2278738	et	3	main
see	doc_213943984970_item	2278739	et	3	main
kasulik	doc_213943984970_item	2278741	et	3	main
ja	doc_213943984970_item	2278743	et	3	main
aga	doc_213943984970_item	2278745	et	3	main
tähtsam	doc_213943984970_item	2278747	et	4	main
asi	doc_213943984970_item	2278748	et	4	main
leidmine	doc_213943984970_item	2278752	et	4	main
minu	doc_213943984970_item	2278753	et	3	main
sõit	doc_213943984970_item	2278771	et	3	main
ta	doc_213943984970_item	2278773	et	4	main
oli	doc_213943984970_item	2278774	et	3	main
minu	doc_213943984970_item	2278775	et	3	main
aga	doc_213943984970_item	2278778	et	3	main
oli	doc_213943984969_item	2278524	et	3	main
jala	doc_213943984969_item	2278528	et	4	main
kui	doc_213943984969_item	2278530	et	3	main
ma	doc_213943984969_item	2278531	et	3	main
ebaõnnestunud	doc_213943984969_item	2278543	et	4	main
sündmus	doc_213943984969_item	2278544	et	3	main
elus	doc_213943984969_item	2278546	et	4	main
oli	doc_213943984969_item	2278547	et	3	main
me	doc_213943984969_item	2278551	et	4	main
läksime	doc_213943984969_item	2278552	et	3	main
sõbrannaga	doc_213943984969_item	2278555	et	3	main
olime	doc_213943984969_item	2278563	et	3	main
alles	doc_213943984969_item	2278564	et	3	main
mul	doc_213943984969_item	2278569	et	3	main
ei	doc_213943984969_item	2278571	et	4	main
suur	doc_213943984969_item	2278575	et	3	main
ma	doc_213943984969_item	2278580	et	3	main
üheksaastane	doc_213943984969_item	2278582	et	4	main
väga	doc_213943984969_item	2278597	et	3	main
see	doc_213943984969_item	2278600	et	3	main
meeldejääv	doc_213943984969_item	2278607	et	4	main
teine	doc_213943984969_item	2278606	et	3	main
sündmus	doc_213943984969_item	2278608	et	3	main
on	doc_213943984969_item	2278609	et	4	main
kaheteistkümnenda	doc_213943984969_item	2278610	et	4	main
klassi	doc_213943984969_item	2278611	et	4	main
lõpetamine	doc_213943984969_item	2278612	et	4	main
ma	doc_213943984969_item	2278613	et	3	main
pidasin	doc_213943984969_item	2278614	et	3	main
oma	doc_213943984969_item	2278615	et	4	main
lõpupidu	doc_213943984969_item	2278616	et	4	main
pärmiskülas	doc_213943984969_item	2278617	et	4	main
oma	doc_213943984969_item	2278618	et	4	main
sõbradega	doc_213943984969_item	2278619	et	4	main
me	doc_213943984969_item	2278620	et	4	main
kui	doc_213943984969_item	2278579	et	3	main
olen	doc_213943984969_item	2278586	et	3	main
endale	doc_213943984969_item	2278588	et	4	main
sain	doc_213943984969_item	2278590	et	3	main
ma	doc_213943984969_item	2278591	et	3	main
seda	doc_213943984969_item	2278592	et	3	main
oma	doc_213943984969_item	2278593	et	4	main
sünnipäevaks	doc_213943984969_item	2278594	et	3	main
ma	doc_213943984969_item	2278595	et	3	main
õnnelik	doc_213943984969_item	2278598	et	3	main
kuni	doc_213943984969_item	2278604	et	3	main
kui	doc_213943984969_item	2278625	et	3	main
ja	doc_213943984969_item	2278637	et	3	main
on	doc_213943984969_item	2278644	et	4	main
elan	doc_213943984969_item	2278651	et	3	main
kuus	doc_213943984970_item	2278665	et	4	main
iseseisvas	doc_213943984970_item	2278669	et	3	main
lõpetasin	doc_213943984970_item	2278673	et	3	main
aastal	doc_213943984970_item	2278686	et	3	main
infotehnoloogia	doc_213943984970_item	2278689	et	4	main
diplomiga	doc_213943984970_item	2278691	et	3	main
tallinna	doc_213943984970_item	2278694	et	4	main
ja	doc_213943984970_item	2278697	et	3	main
ajakirjandust	doc_213943984970_item	2278700	et	3	main
kahjuks	doc_213943984970_item	2278701	et	4	main
lapsepõlves	doc_213943984970_item	2278702	et	4	main
ma	doc_213943984970_item	2278703	et	3	main
end	doc_213943984970_item	2278704	et	4	main
ja	doc_213943984970_item	2278712	et	3	main
sooritamine	doc_213943984970_item	2278714	et	4	main
olin	doc_213943984970_item	2278716	et	3	main
igati	doc_213943984970_item	2278718	et	3	main
väga	doc_213943984970_item	2278724	et	3	main
positiivne	doc_213943984970_item	2278727	et	3	main
töö	doc_213943984970_item	2278737	et	4	main
kogemus	doc_213943984970_item	2278742	et	3	main
mees	doc_213943984970_item	2278754	et	4	main
pool	doc_213943984970_item	2278759	et	4	main
usun	doc_213943984970_item	2278761	et	3	main
üks	doc_213943984970_item	2278763	et	3	main
sündmust	doc_213943984970_item	2278765	et	3	main
minu	doc_213943984970_item	2278767	et	3	main
ei	doc_213943984970_item	2278780	et	4	main
minust	doc_213943984970_item	2278782	et	3	main
inimest	doc_213943984970_item	2278789	et	3	main
keda	doc_213943984970_item	2278790	et	4	main
ma	doc_213943984970_item	2278791	et	3	main
kurvastasin	doc_213943984970_item	2278821	et	3	main
kolmas	doc_213943984970_item	2278823	et	3	main
kehtib	doc_213943984970_item	2278826	et	3	main
minu	doc_213943984970_item	2278828	et	3	main
taha	doc_213943984970_item	2278831	et	4	main
hakkas	doc_213943984970_item	2278836	et	3	main
mul	doc_213943984970_item	2278848	et	3	main
ma	doc_213943984970_item	2278853	et	3	main
elust	doc_213943984971_item	2278860	et	3	main
sündinud	doc_213943984971_item	2278863	et	4	main
tallinnas	doc_213943984971_item	2278864	et	4	main
kogu	doc_213943984971_item	2278866	et	4	main
minu	doc_213943984971_item	2278867	et	3	main
elu	doc_213943984971_item	2278868	et	4	main
ma	doc_213943984971_item	2278876	et	3	main
käisin	doc_213943984971_item	2278877	et	3	main
palju	doc_213943984971_item	2278887	et	4	main
sündmusi	doc_213943984971_item	2278889	et	3	main
halvad	doc_213943984971_item	2278891	et	4	main
ka	doc_213943984971_item	2278893	et	3	main
üks	doc_213943984971_item	2278901	et	3	main
mis	doc_213943984971_item	2278903	et	4	main
7	doc_213943984971_item	2278910	et	2	main
väike	doc_213943984971_item	2278914	et	4	main
pole	doc_213943984971_item	2278916	et	3	main
võimalik	doc_213943984971_item	2278917	et	3	main
ilm	doc_213943984969_item	2278628	et	3	main
seal	doc_213943984969_item	2278634	et	4	main
klubi	doc_213943984969_item	2278636	et	4	main
viimane	doc_213943984969_item	2278640	et	3	main
sisse	doc_213943984969_item	2278646	et	4	main
nüüd	doc_213943984969_item	2278652	et	4	main
tallinnas	doc_213943984969_item	2278653	et	4	main
ning	doc_213943984969_item	2278654	et	3	main
elan	doc_213943984969_item	2278655	et	3	main
iseseisvat	doc_213943984969_item	2278656	et	3	main
elu	doc_213943984969_item	2278657	et	4	main
essee	doc_213943984970_item	2278658	et	4	main
ma	doc_213943984970_item	2278659	et	3	main
1984	doc_213943984970_item	2278662	et	2	main
aastal	doc_213943984970_item	2278663	et	3	main
hästi	doc_213943984970_item	2278672	et	3	main
tallinna	doc_213943984970_item	2278676	et	4	main
sisse	doc_213943984970_item	2278681	et	4	main
2004	doc_213943984970_item	2278685	et	2	main
seda	doc_213943984970_item	2278688	et	3	main
astusin	doc_213943984970_item	2278693	et	3	main
õppin	doc_213943984970_item	2278699	et	4	main
ei	doc_213943984970_item	2278705	et	4	main
eksami	doc_213943984970_item	2278713	et	3	main
ehhki	doc_213943984970_item	2278720	et	4	main
ei	doc_213943984970_item	2278722	et	4	main
kolmas	doc_213943984970_item	2278744	et	3	main
kõige	doc_213943984970_item	2278746	et	4	main
on	doc_213943984970_item	2278755	et	4	main
negatiivsest	doc_213943984970_item	2278764	et	3	main
on	doc_213943984970_item	2278766	et	4	main
sõbranna	doc_213943984970_item	2278769	et	4	main
ära	doc_213943984970_item	2278770	et	4	main
see	doc_213943984970_item	2278779	et	3	main
kuna	doc_213943984970_item	2278783	et	3	main
usaldaksin	doc_213943984970_item	2278792	et	3	main
nagu	doc_213943984970_item	2278793	et	3	main
temale	doc_213943984970_item	2278794	et	3	main
sõbranna	doc_213943984970_item	2278795	et	4	main
ühiskonnas	doc_213943984970_item	2278796	et	4	main
teine	doc_213943984970_item	2278797	et	3	main
õnnetus	doc_213943984970_item	2278798	et	4	main
juhtus	doc_213943984970_item	2278799	et	3	main
millal	doc_213943984970_item	2278800	et	3	main
minu	doc_213943984970_item	2278801	et	3	main
koer	doc_213943984970_item	2278802	et	3	main
sattis	doc_213943984970_item	2278803	et	4	main
auto	doc_213943984970_item	2278804	et	4	main
alla	doc_213943984970_item	2278805	et	3	main
ja	doc_213943984970_item	2278806	et	3	main
talle	doc_213943984970_item	2278807	et	4	main
tehti	doc_213943984970_item	2278808	et	3	main
3	doc_213943984970_item	2278809	et	2	main
operatsiooni	doc_213943984970_item	2278810	et	4	main
ei	doc_213943984970_item	2278812	et	4	main
saa	doc_213943984970_item	2278813	et	4	main
ta	doc_213943984970_item	2278811	et	4	main
ise	doc_213943984970_item	2278814	et	4	main
käia	doc_213943984970_item	2278815	et	4	main
ja	doc_213943984970_item	2278816	et	3	main
siiamani	doc_213943984970_item	2278817	et	4	main
kardab	doc_213943984970_item	2278818	et	4	main
autot	doc_213943984970_item	2278819	et	3	main
ma	doc_213943984970_item	2278820	et	3	main
väga	doc_213943984970_item	2278822	et	3	main
negatiivne	doc_213943984970_item	2278824	et	3	main
õppiksin	doc_213943984970_item	2278834	et	4	main
valjapääsu	doc_213943984970_item	2278838	et	4	main
leidiski	doc_213943984970_item	2278840	et	4	main
võimaluse	doc_213943984970_item	2278842	et	3	main
toetuseta	doc_213943984970_item	2278845	et	4	main
praegu	doc_213943984970_item	2278847	et	3	main
essee	doc_213943984971_item	2278858	et	4	main
ja	doc_213943984971_item	2278865	et	3	main
siin	doc_213943984971_item	2278871	et	4	main
lapsed	doc_213943984971_item	2278875	et	3	main
lasteaias	doc_213943984971_item	2278878	et	4	main
nii	doc_213943984971_item	2278886	et	3	main
olnud	doc_213943984970_item	2278723	et	4	main
halb	doc_213943984970_item	2278736	et	3	main
oli	doc_213943984970_item	2278740	et	3	main
oma	doc_213943984970_item	2278750	et	4	main
armastuse	doc_213943984970_item	2278751	et	4	main
tõesti	doc_213943984970_item	2278756	et	3	main
parem	doc_213943984970_item	2278768	et	4	main
ei	doc_213943984970_item	2278830	et	4	main
uue	doc_213943984970_item	2278841	et	3	main
lootusrikas	doc_213943984970_item	2278857	et	4	main
oma	doc_213943984971_item	2278859	et	4	main
olen	doc_213943984971_item	2278862	et	3	main
ma	doc_213943984971_item	2278869	et	3	main
kõik	doc_213943984971_item	2278873	et	4	main
ja	doc_213943984971_item	2278879	et	3	main
oli	doc_213943984971_item	2278885	et	3	main
erinevaid	doc_213943984971_item	2278888	et	4	main
meelde	doc_213943984971_item	2278899	et	3	main
mulle	doc_213943984971_item	2278905	et	4	main
ma	doc_213943984971_item	2278908	et	3	main
olin	doc_213943984971_item	2278909	et	3	main
oli	doc_213943984971_item	2278923	et	3	main
kass	doc_213943984971_item	2278925	et	3	main
minuga	doc_213943984971_item	2278933	et	3	main
kuna	doc_213943984971_item	2278934	et	3	main
vanemad	doc_213943984971_item	2278936	et	4	main
olid	doc_213943984971_item	2278937	et	4	main
väga	doc_213943984971_item	2278938	et	3	main
range	doc_213943984971_item	2278939	et	4	main
et	doc_213943984971_item	2278942	et	3	main
väga	doc_213943984971_item	2278945	et	3	main
ma	doc_213943984971_item	2278968	et	3	main
vihkasin	doc_213943984971_item	2278981	et	3	main
õues	doc_213943984971_item	2278987	et	4	main
nukkuga	doc_213943984971_item	2278990	et	4	main
mitte	doc_213943984971_item	2278993	et	3	main
see	doc_213943984971_item	2279004	et	3	main
ma	doc_213943984971_item	2279033	et	3	main
venemaal	doc_213943984971_item	2279049	et	4	main
aastal	doc_213943984971_item	2279057	et	3	main
poolaastal	doc_213943984971_item	2279067	et	3	main
mina	doc_213943984971_item	2279088	et	4	main
kahtlesin	doc_213943984971_item	2279089	et	3	main
et	doc_213943984971_item	2279090	et	3	main
saan	doc_213943984971_item	2279091	et	4	main
õppida	doc_213943984971_item	2279092	et	3	main
kus	doc_213943984971_item	2279100	et	3	main
raha	doc_213943984971_item	2279103	et	4	main
töötada	doc_213943984971_item	2279108	et	3	main
ma	doc_213943984971_item	2279115	et	3	main
eesmärke	doc_213943984971_item	2279118	et	4	main
et	doc_213943984970_item	2278832	et	3	main
ma	doc_213943984970_item	2278835	et	3	main
otsima	doc_213943984970_item	2278837	et	4	main
ja	doc_213943984970_item	2278839	et	3	main
ilma	doc_213943984970_item	2278844	et	4	main
on	doc_213943984970_item	2278849	et	4	main
nendest	doc_213943984970_item	2278846	et	4	main
ma	doc_213943984971_item	2278861	et	3	main
olen	doc_213943984971_item	2278870	et	3	main
normaalsed	doc_213943984971_item	2278874	et	3	main
koolis	doc_213943984971_item	2278881	et	4	main
loomulikult	doc_213943984971_item	2278882	et	4	main
elus	doc_213943984971_item	2278884	et	4	main
oli	doc_213943984971_item	2278900	et	3	main
sünnipäevile	doc_213943984971_item	2278907	et	4	main
aastane	doc_213943984971_item	2278911	et	4	main
ja	doc_213943984971_item	2278912	et	3	main
sain	doc_213943984971_item	2278913	et	3	main
kassi	doc_213943984971_item	2278915	et	4	main
mille	doc_213943984971_item	2278920	et	3	main
see	doc_213943984971_item	2278922	et	3	main
nad	doc_213943984971_item	2278940	et	3	main
aga	doc_213943984971_item	2278947	et	3	main
kui	doc_213943984971_item	2278952	et	3	main
õpikute	doc_213943984971_item	2278954	et	3	main
seepärast	doc_213943984971_item	2278956	et	3	main
aastat	doc_213943984971_item	2278967	et	3	main
tänulik	doc_213943984971_item	2278974	et	3	main
vanematele	doc_213943984971_item	2278976	et	4	main
kuid	doc_213943984971_item	2278977	et	4	main
tollal	doc_213943984971_item	2278978	et	3	main
ma	doc_213943984971_item	2278979	et	3	main
peres	doc_213943984971_item	2278998	et	3	main
suri	doc_213943984971_item	2279003	et	3	main
oli	doc_213943984971_item	2279005	et	3	main
suur	doc_213943984971_item	2279007	et	3	main
ka	doc_213943984971_item	2279009	et	3	main
jaoks	doc_213943984971_item	2279011	et	4	main
ta	doc_213943984971_item	2279021	et	4	main
mul	doc_213943984971_item	2279023	et	3	main
harva	doc_213943984971_item	2279031	et	4	main
10	doc_213943984971_item	2279035	et	2	main
ma	doc_213943984971_item	2279037	et	3	main
kohtusin	doc_213943984971_item	2279043	et	4	main
oma	doc_213943984971_item	2279044	et	4	main
ja	doc_213943984971_item	2279046	et	3	main
nädala	doc_213943984971_item	2279051	et	3	main
järgmisel	doc_213943984971_item	2279056	et	3	main
ma	doc_213943984971_item	2279058	et	3	main
sõitsin	doc_213943984971_item	2279059	et	3	main
kord	doc_213943984971_item	2279062	et	4	main
vanemateta	doc_213943984971_item	2279063	et	4	main
ja	doc_213943984971_item	2279064	et	3	main
tasuta	doc_213943984971_item	2279093	et	4	main
praegu	doc_213943984971_item	2279097	et	3	main
vaid	doc_213943984971_item	2279102	et	3	main
mul	doc_213943984971_item	2279105	et	3	main
eest	doc_213943984971_item	2279113	et	4	main
aga	doc_213943984971_item	2279114	et	3	main
kõige	doc_213943984971_item	2279122	et	4	main
minuga	doc_213943984971_item	2279127	et	3	main
minu	doc_213943984971_item	2279130	et	3	main
kellega	doc_213943984971_item	2279151	et	3	main
jaoks	doc_213943984971_item	2279161	et	4	main
me	doc_213943984971_item	2279163	et	4	main
võin	doc_213943984971_item	2279168	et	3	main
rääkida	doc_213943984971_item	2279170	et	3	main
rahul	doc_213943984971_item	2279175	et	4	main
kõigepealt	doc_213943984972_item	2279184	et	3	main
ja	doc_213943984972_item	2279191	et	3	main
neiu	doc_213943984972_item	2279192	et	4	main
mõtlevad	doc_213943984972_item	2279193	et	4	main
tahavad	doc_213943984972_item	2279199	et	3	main
ülikooli	doc_213943984972_item	2279206	et	4	main
ülikooli	doc_213943984972_item	2279216	et	4	main
otsustada	doc_213943984972_item	2279219	et	3	main
pärast	doc_213943984972_item	2279224	et	4	main
eksameid	doc_213943984972_item	2279226	et	3	main
otsustada	doc_213943984972_item	2279229	et	3	main
ja	doc_213943984972_item	2279243	et	3	main
et	doc_213943984972_item	2279255	et	3	main
olla	doc_213943984972_item	2279257	et	3	main
kätte	doc_213943984972_item	2279259	et	4	main
õppimise	doc_213943984972_item	2279264	et	4	main
mu	doc_213943984972_item	2279270	et	3	main
et	doc_213943984972_item	2279280	et	3	main
raha	doc_213943984972_item	2279285	et	4	main
ootan	doc_213943984972_item	2279288	et	3	main
ja	doc_213943984970_item	2278852	et	3	main
on	doc_213943984970_item	2278854	et	4	main
ootusärav	doc_213943984970_item	2278855	et	4	main
ja	doc_213943984970_item	2278856	et	3	main
nagu	doc_213943984971_item	2278872	et	3	main
edasi	doc_213943984971_item	2278880	et	3	main
minu	doc_213943984971_item	2278883	et	3	main
esimene	doc_213943984971_item	2278895	et	3	main
mul	doc_213943984971_item	2278897	et	3	main
kinkisid	doc_213943984971_item	2278904	et	4	main
vanemad	doc_213943984971_item	2278906	et	4	main
ette	doc_213943984971_item	2278919	et	4	main
kasvab	doc_213943984971_item	2278926	et	3	main
minuga	doc_213943984971_item	2278928	et	3	main
ta	doc_213943984971_item	2278930	et	4	main
on	doc_213943984971_item	2278931	et	4	main
seni	doc_213943984971_item	2278932	et	3	main
minu	doc_213943984971_item	2278935	et	3	main
tahtsin	doc_213943984971_item	2278949	et	3	main
jalutada	doc_213943984971_item	2278951	et	3	main
ma	doc_213943984971_item	2278960	et	3	main
mängima	doc_213943984971_item	2278963	et	3	main
järgmised	doc_213943984971_item	2278965	et	3	main
mängida	doc_213943984971_item	2278970	et	3	main
neid	doc_213943984971_item	2278982	et	4	main
või	doc_213943984971_item	2278989	et	4	main
aga	doc_213943984971_item	2278991	et	3	main
õnnestus	doc_213943984971_item	2279000	et	4	main
teda	doc_213943984971_item	2279029	et	4	main
klassis	doc_213943984971_item	2279036	et	3	main
peterburis	doc_213943984971_item	2279039	et	4	main
seal	doc_213943984971_item	2279041	et	4	main
sõbrannaga	doc_213943984971_item	2279045	et	3	main
need	doc_213943984971_item	2279052	et	3	main
päevad	doc_213943984971_item	2279055	et	3	main
kuid	doc_213943984971_item	2279087	et	4	main
juhtus	doc_213943984971_item	2279096	et	3	main
et	doc_213943984971_item	2279109	et	3	main
ja	doc_213943984971_item	2279119	et	3	main
sündmus	doc_213943984971_item	2279124	et	3	main
juhtus	doc_213943984971_item	2279126	et	3	main
on	doc_213943984971_item	2279129	et	4	main
selline	doc_213943984971_item	2279137	et	4	main
keda	doc_213943984971_item	2279146	et	4	main
ma	doc_213943984971_item	2279147	et	3	main
võin	doc_213943984971_item	2279148	et	3	main
nüüd	doc_213943984971_item	2279162	et	4	main
elame	doc_213943984971_item	2279164	et	3	main
õnnelik	doc_213943984971_item	2279178	et	3	main
essee	doc_213943984972_item	2279180	et	4	main
et	doc_213943984972_item	2279188	et	3	main
iga	doc_213943984972_item	2279189	et	4	main
minna	doc_213943984972_item	2279202	et	3	main
ja	doc_213943984972_item	2279203	et	3	main
tõttu	doc_213943984972_item	2279205	et	4	main
nii	doc_213943984972_item	2279209	et	3	main
mida	doc_213943984972_item	2279220	et	4	main
ma	doc_213943984972_item	2279221	et	3	main
minna	doc_213943984972_item	2279231	et	3	main
oota	doc_213943984972_item	2279234	et	4	main
raha	doc_213943984972_item	2279241	et	4	main
eest	doc_213943984972_item	2279242	et	4	main
mille	doc_213943984972_item	2279249	et	3	main
ja	doc_213943984972_item	2279261	et	3	main
annab	doc_213943984972_item	2279272	et	3	main
kahju	doc_213943984972_item	2279279	et	4	main
maksan	doc_213943984972_item	2279282	et	3	main
suure	doc_213943984972_item	2279284	et	3	main
minu	doc_213943984972_item	2279319	et	3	main
nii	doc_213943984971_item	2278890	et	3	main
kui	doc_213943984971_item	2278892	et	3	main
head	doc_213943984971_item	2278894	et	4	main
mis	doc_213943984971_item	2278896	et	4	main
jäin	doc_213943984971_item	2278898	et	3	main
kingitus	doc_213943984971_item	2278902	et	4	main
kujutada	doc_213943984971_item	2278918	et	3	main
minu	doc_213943984971_item	2278924	et	3	main
õpin	doc_213943984971_item	2278944	et	3	main
ma	doc_213943984971_item	2278948	et	3	main
rohkem	doc_213943984971_item	2278950	et	4	main
ema	doc_213943984971_item	2278957	et	4	main
käskis	doc_213943984971_item	2278958	et	4	main
et	doc_213943984971_item	2278959	et	3	main
klaverit	doc_213943984971_item	2278962	et	3	main
ja	doc_213943984971_item	2278964	et	3	main
ma	doc_213943984971_item	2278972	et	3	main
peaaegu	doc_213943984971_item	2278980	et	3	main
et	doc_213943984971_item	2278983	et	3	main
mängivad	doc_213943984971_item	2278986	et	4	main
mina	doc_213943984971_item	2278992	et	4	main
umbes	doc_213943984971_item	2278994	et	4	main
tol	doc_213943984971_item	2278995	et	3	main
ajal	doc_213943984971_item	2278996	et	4	main
minu	doc_213943984971_item	2278997	et	3	main
juhtus	doc_213943984971_item	2278999	et	3	main
minu	doc_213943984971_item	2279001	et	3	main
väga	doc_213943984971_item	2279006	et	3	main
tragöödia	doc_213943984971_item	2279008	et	4	main
et	doc_213943984971_item	2279026	et	3	main
olin	doc_213943984971_item	2279034	et	3	main
sõitsin	doc_213943984971_item	2279038	et	3	main
üksinda	doc_213943984971_item	2279040	et	4	main
ma	doc_213943984971_item	2279042	et	3	main
me	doc_213943984971_item	2279047	et	4	main
viitsime	doc_213943984971_item	2279048	et	4	main
olid	doc_213943984971_item	2279053	et	4	main
seal	doc_213943984971_item	2279060	et	4	main
nii	doc_213943984971_item	2279095	et	3	main
õpin	doc_213943984971_item	2279099	et	3	main
tahtsin	doc_213943984971_item	2279101	et	3	main
eest	doc_213943984971_item	2279104	et	4	main
tuleb	doc_213943984971_item	2279106	et	3	main
palju	doc_213943984971_item	2279107	et	4	main
maksta	doc_213943984971_item	2279110	et	4	main
õppimise	doc_213943984971_item	2279112	et	4	main
oma	doc_213943984971_item	2279117	et	4	main
positiivsem	doc_213943984971_item	2279123	et	4	main
minu	doc_213943984971_item	2279132	et	3	main
ta	doc_213943984971_item	2279135	et	4	main
inimene	doc_213943984971_item	2279138	et	3	main
hoolitseb	doc_213943984971_item	2279140	et	3	main
eest	doc_213943984971_item	2279142	et	4	main
ja	doc_213943984971_item	2279143	et	3	main
armastab	doc_213943984971_item	2279144	et	3	main
ja	doc_213943984971_item	2279150	et	3	main
koos	doc_213943984971_item	2279165	et	4	main
oma	doc_213943984971_item	2279173	et	4	main
eluga	doc_213943984971_item	2279174	et	3	main
ja	doc_213943984971_item	2279176	et	3	main
olen	doc_213943984971_item	2279177	et	3	main
tahan	doc_213943984972_item	2279185	et	3	main
sellest	doc_213943984972_item	2279187	et	4	main
pärast	doc_213943984972_item	2279196	et	4	main
nad	doc_213943984972_item	2279198	et	3	main
on	doc_213943984972_item	2279208	et	4	main
minu	doc_213943984972_item	2279211	et	3	main
väga	doc_213943984972_item	2279214	et	3	main
valida	doc_213943984972_item	2279217	et	3	main
tahan	doc_213943984972_item	2279222	et	3	main
ma	doc_213943984972_item	2279227	et	3	main
kuhu	doc_213943984972_item	2279230	et	3	main
ma	doc_213943984972_item	2279233	et	3	main
väga	doc_213943984972_item	2279235	et	3	main
see	doc_213943984972_item	2279244	et	3	main
põhjus	doc_213943984972_item	2279248	et	4	main
järgi	doc_213943984972_item	2279250	et	4	main
pean	doc_213943984972_item	2279252	et	4	main
hästi	doc_213943984972_item	2279253	et	3	main
õppima	doc_213943984972_item	2279254	et	3	main
poleks	doc_213943984972_item	2279278	et	3	main
nii	doc_213943984972_item	2279283	et	3	main
veel	doc_213943984972_item	2279286	et	4	main
üllatusena	doc_213943984971_item	2278921	et	4	main
koos	doc_213943984971_item	2278927	et	4	main
ja	doc_213943984971_item	2278929	et	3	main
tahavad	doc_213943984971_item	2278941	et	3	main
ma	doc_213943984971_item	2278943	et	3	main
hästi	doc_213943984971_item	2278946	et	3	main
istuda	doc_213943984971_item	2278953	et	3	main
eest	doc_213943984971_item	2278955	et	4	main
hakkasin	doc_213943984971_item	2278961	et	3	main
6	doc_213943984971_item	2278966	et	2	main
õppisin	doc_213943984971_item	2278969	et	3	main
praegu	doc_213943984971_item	2278971	et	3	main
olen	doc_213943984971_item	2278973	et	3	main
oma	doc_213943984971_item	2278975	et	4	main
kõik	doc_213943984971_item	2278984	et	4	main
lapsed	doc_213943984971_item	2278985	et	3	main
palliga	doc_213943984971_item	2278988	et	3	main
vanaema	doc_213943984971_item	2279002	et	4	main
minu	doc_213943984971_item	2279010	et	3	main
ma	doc_213943984971_item	2279012	et	3	main
isegi	doc_213943984971_item	2279013	et	4	main
ei	doc_213943984971_item	2279014	et	4	main
teadnud	doc_213943984971_item	2279015	et	4	main
kuidas	doc_213943984971_item	2279016	et	3	main
ma	doc_213943984971_item	2279017	et	3	main
armastasin	doc_213943984971_item	2279018	et	3	main
teda	doc_213943984971_item	2279019	et	4	main
kuni	doc_213943984971_item	2279020	et	3	main
suri	doc_213943984971_item	2279022	et	3	main
on	doc_213943984971_item	2279024	et	4	main
kahju	doc_213943984971_item	2279025	et	4	main
ma	doc_213943984971_item	2279027	et	3	main
külastasin	doc_213943984971_item	2279028	et	3	main
nii	doc_213943984971_item	2279030	et	3	main
kui	doc_213943984971_item	2279032	et	3	main
ühe	doc_213943984971_item	2279050	et	4	main
suurepärased	doc_213943984971_item	2279054	et	4	main
veel	doc_213943984971_item	2279061	et	4	main
nüüd	doc_213943984971_item	2279065	et	4	main
igal	doc_213943984971_item	2279066	et	3	main
ma	doc_213943984971_item	2279068	et	3	main
käin	doc_213943984971_item	2279069	et	3	main
peterburis	doc_213943984971_item	2279070	et	4	main
oma	doc_213943984971_item	2279071	et	4	main
sõbrannaga	doc_213943984971_item	2279072	et	3	main
pärast	doc_213943984971_item	2279073	et	4	main
kooli	doc_213943984971_item	2279074	et	4	main
mul	doc_213943984971_item	2279075	et	3	main
oli	doc_213943984971_item	2279076	et	3	main
üks	doc_213943984971_item	2279077	et	3	main
raske	doc_213943984971_item	2279078	et	4	main
valik	doc_213943984971_item	2279079	et	3	main
kuhu	doc_213943984971_item	2279080	et	3	main
minna	doc_213943984971_item	2279081	et	3	main
minu	doc_213943984971_item	2279082	et	3	main
soov	doc_213943984971_item	2279083	et	3	main
pole	doc_213943984971_item	2279084	et	3	main
suur	doc_213943984971_item	2279085	et	3	main
probleem	doc_213943984971_item	2279086	et	3	main
ja	doc_213943984971_item	2279094	et	3	main
ma	doc_213943984971_item	2279098	et	3	main
oma	doc_213943984971_item	2279111	et	4	main
saavutasin	doc_213943984971_item	2279116	et	3	main
võib	doc_213943984971_item	2279120	et	3	main
olla	doc_213943984971_item	2279121	et	3	main
elus	doc_213943984971_item	2279128	et	4	main
armas	doc_213943984971_item	2279133	et	3	main
kes	doc_213943984971_item	2279139	et	4	main
võin	doc_213943984971_item	2279152	et	3	main
ma	doc_213943984971_item	2279167	et	3	main
olen	doc_213943984971_item	2279172	et	3	main
öelda	doc_213943984972_item	2279186	et	4	main
oma	doc_213943984972_item	2279194	et	4	main
tulevikust	doc_213943984972_item	2279195	et	4	main
õppida	doc_213943984972_item	2279201	et	3	main
valik	doc_213943984972_item	2279207	et	3	main
tähtis	doc_213943984972_item	2279210	et	4	main
raske	doc_213943984972_item	2279215	et	4	main
ainult	doc_213943984972_item	2279223	et	4	main
kooli	doc_213943984972_item	2279225	et	4	main
palju	doc_213943984972_item	2279236	et	4	main
õpin	doc_213943984972_item	2279240	et	3	main
on	doc_213943984972_item	2279245	et	4	main
ma	doc_213943984972_item	2279251	et	3	main
natuke	doc_213943984972_item	2279262	et	4	main
et	doc_213943984972_item	2279269	et	3	main
ma	doc_213943984972_item	2279281	et	3	main
jääb	doc_213943984972_item	2279318	et	3	main
aga	doc_213943984972_item	2279323	et	3	main
sel	doc_213943984972_item	2279328	et	3	main
jaoks	doc_213943984972_item	2279336	et	4	main
et	doc_213943984972_item	2279339	et	3	main
huvitavaid	doc_213943984972_item	2279344	et	4	main
ja	doc_213943984972_item	2279345	et	3	main
meeldivaks	doc_213943984972_item	2279353	et	4	main
mille	doc_213943984973_item	2279365	et	3	main
mõtleb	doc_213943984973_item	2279377	et	3	main
ülikooli	doc_213943984973_item	2279382	et	4	main
peale	doc_213943984973_item	2279384	et	4	main
öeldi	doc_213943984973_item	2279399	et	3	main
aga	doc_213943984973_item	2279406	et	3	main
nad	doc_213943984973_item	2279408	et	3	main
ei	doc_213943984973_item	2279410	et	4	main
ültse	doc_213943984973_item	2279412	et	4	main
mõtlen	doc_213943984973_item	2279414	et	3	main
väga	doc_213943984973_item	2279427	et	3	main
et	doc_213943984973_item	2279431	et	3	main
elus	doc_213943984973_item	2279437	et	4	main
on	doc_213943984973_item	2279447	et	4	main
ma	doc_213943984973_item	2279452	et	3	main
leida	doc_213943984973_item	2279454	et	3	main
väga	doc_213943984973_item	2279462	et	3	main
leida	doc_213943984973_item	2279464	et	3	main
olukord	doc_213943984973_item	2279471	et	3	main
oodata	doc_213943984973_item	2279502	et	4	main
ülikool	doc_213943984973_item	2279508	et	4	main
tunnil	doc_213943984973_item	2279515	et	3	main
elu	doc_213943984973_item	2279519	et	4	main
seda	doc_213943984973_item	2279522	et	3	main
aga	doc_213943984973_item	2279524	et	3	main
kõigile	doc_213943984973_item	2279527	et	4	main
mind	doc_213943984973_item	2279529	et	4	main
ootab	doc_213943984973_item	2279530	et	3	main
see	doc_213943984974_item	2279536	et	3	main
õppida	doc_213943984974_item	2279544	et	3	main
sügisel	doc_213943984974_item	2279547	et	3	main
liitusin	doc_213943984974_item	2279549	et	4	main
ma	doc_213943984974_item	2279553	et	3	main
kui	doc_213943984974_item	2279570	et	3	main
õppivad	doc_213943984974_item	2279577	et	4	main
head	doc_213943984974_item	2279578	et	4	main
sõbrad	doc_213943984974_item	2279579	et	3	main
ülikoolielu	doc_213943984974_item	2279585	et	4	main
muidugi	doc_213943984974_item	2279587	et	4	main
väga	doc_213943984974_item	2279590	et	3	main
see	doc_213943984974_item	2279593	et	3	main
on	doc_213943984974_item	2279594	et	4	main
väga	doc_213943984974_item	2279595	et	3	main
inimesel	doc_213943984974_item	2279602	et	3	main
siis	doc_213943984974_item	2279606	et	3	main
mis	doc_213943984971_item	2279125	et	4	main
armastus	doc_213943984971_item	2279131	et	4	main
noormees	doc_213943984971_item	2279134	et	4	main
on	doc_213943984971_item	2279136	et	4	main
minu	doc_213943984971_item	2279141	et	3	main
mind	doc_213943984971_item	2279145	et	4	main
usaldada	doc_213943984971_item	2279149	et	3	main
rääkida	doc_213943984971_item	2279153	et	3	main
kõigest	doc_213943984971_item	2279154	et	4	main
see	doc_213943984971_item	2279155	et	3	main
on	doc_213943984971_item	2279156	et	4	main
kõige	doc_213943984971_item	2279157	et	4	main
lähedasem	doc_213943984971_item	2279158	et	4	main
inimene	doc_213943984971_item	2279159	et	3	main
minu	doc_213943984971_item	2279160	et	3	main
ja	doc_213943984971_item	2279166	et	3	main
julgelt	doc_213943984971_item	2279169	et	4	main
et	doc_213943984971_item	2279171	et	3	main
inimene	doc_213943984971_item	2279179	et	3	main
mida	doc_213943984972_item	2279181	et	4	main
ootan	doc_213943984972_item	2279182	et	3	main
ülikoolilt	doc_213943984972_item	2279183	et	4	main
noormees	doc_213943984972_item	2279190	et	4	main
kooli	doc_213943984972_item	2279197	et	4	main
edasi	doc_213943984972_item	2279200	et	3	main
see	doc_213943984972_item	2279204	et	3	main
jaoks	doc_213943984972_item	2279212	et	4	main
oli	doc_213943984972_item	2279213	et	3	main
ja	doc_213943984972_item	2279218	et	3	main
võiksin	doc_213943984972_item	2279228	et	3	main
loomulikult	doc_213943984972_item	2279232	et	4	main
oma	doc_213943984972_item	2279237	et	4	main
ülikoolilt	doc_213943984972_item	2279238	et	4	main
ma	doc_213943984972_item	2279239	et	3	main
ka	doc_213943984972_item	2279246	et	3	main
üks	doc_213943984972_item	2279247	et	3	main
võib	doc_213943984972_item	2279256	et	3	main
õpetoetust	doc_213943984972_item	2279258	et	4	main
saada	doc_213943984972_item	2279260	et	4	main
väheneda	doc_213943984972_item	2279263	et	3	main
eest	doc_213943984972_item	2279265	et	4	main
tasu	doc_213943984972_item	2279266	et	4	main
ma	doc_213943984972_item	2279267	et	3	main
ootan	doc_213943984972_item	2279268	et	3	main
ülikool	doc_213943984972_item	2279271	et	4	main
mulle	doc_213943984972_item	2279273	et	4	main
häid	doc_213943984972_item	2279274	et	3	main
teadmisi	doc_213943984972_item	2279275	et	4	main
et	doc_213943984972_item	2279276	et	3	main
mul	doc_213943984972_item	2279277	et	3	main
ülikoolilt	doc_213943984972_item	2279289	et	4	main
huvitavat	doc_213943984972_item	2279290	et	4	main
elu	doc_213943984972_item	2279291	et	4	main
palju	doc_213943984972_item	2279292	et	4	main
uusi	doc_213943984972_item	2279293	et	3	main
tuttavaid	doc_213943984972_item	2279294	et	3	main
ja	doc_213943984972_item	2279295	et	3	main
võib	doc_213943984972_item	2279296	et	3	main
olla	doc_213943984972_item	2279297	et	3	main
sõpru	doc_213943984972_item	2279298	et	3	main
ma	doc_213943984972_item	2279299	et	3	main
tahan	doc_213943984972_item	2279300	et	3	main
et	doc_213943984972_item	2279301	et	3	main
iga	doc_213943984972_item	2279302	et	4	main
tudeng	doc_213943984972_item	2279303	et	3	main
tunneb	doc_213943984972_item	2279304	et	3	main
end	doc_213943984972_item	2279305	et	4	main
nagu	doc_213943984972_item	2279306	et	3	main
ta	doc_213943984972_item	2279307	et	4	main
on	doc_213943984972_item	2279308	et	4	main
oma	doc_213943984972_item	2279309	et	4	main
sõpru	doc_213943984972_item	2279310	et	3	main
vahel	doc_213943984972_item	2279311	et	4	main
ma	doc_213943984972_item	2279312	et	3	main
tahaksin	doc_213943984972_item	2279313	et	3	main
et	doc_213943984972_item	2279314	et	3	main
meie	doc_213943984972_item	2279315	et	4	main
ülikooli	doc_213943984972_item	2279316	et	4	main
elu	doc_213943984972_item	2279317	et	4	main
ma	doc_213943984972_item	2279287	et	3	main
on	doc_213943984972_item	2279325	et	4	main
inimese	doc_213943984973_item	2279361	et	4	main
igaüks	doc_213943984973_item	2279369	et	3	main
sella	doc_213943984973_item	2279371	et	4	main
aega	doc_213943984973_item	2279372	et	4	main
mina	doc_213943984973_item	2279380	et	4	main
aja	doc_213943984973_item	2279383	et	4	main
nüüd	doc_213943984973_item	2279388	et	4	main
ei	doc_213943984973_item	2279390	et	4	main
mida	doc_213943984973_item	2279392	et	4	main
mu	doc_213943984973_item	2279396	et	3	main
tihti	doc_213943984973_item	2279398	et	3	main
on	doc_213943984973_item	2279403	et	4	main
lõbus	doc_213943984973_item	2279405	et	4	main
et	doc_213943984973_item	2279415	et	3	main
on	doc_213943984973_item	2279422	et	4	main
mis	doc_213943984973_item	2279424	et	4	main
võiks	doc_213943984973_item	2279438	et	4	main
inimestega	doc_213943984973_item	2279448	et	3	main
sest	doc_213943984973_item	2279470	et	4	main
on	doc_213943984973_item	2279473	et	4	main
mulle	doc_213943984973_item	2279510	et	4	main
minu	doc_213943984973_item	2279517	et	3	main
ülikool	doc_213943984974_item	2279535	et	4	main
on	doc_213943984974_item	2279537	et	4	main
ülikoolis	doc_213943984974_item	2279545	et	4	main
ma	doc_213943984974_item	2279580	et	3	main
et	doc_213943984974_item	2279582	et	3	main
kuid	doc_213943984974_item	2279592	et	4	main
sellepärast	doc_213943984974_item	2279599	et	3	main
et	doc_213943984974_item	2279600	et	3	main
tal	doc_213943984974_item	2279607	et	3	main
ja	doc_213943984974_item	2279611	et	3	main
jõuad	doc_213943984974_item	2279631	et	3	main
kohtla	doc_213943984974_item	2279635	et	4	main
aga	doc_213943984974_item	2279637	et	3	main
praegu	doc_213943984974_item	2279638	et	3	main
ma	doc_213943984974_item	2279639	et	3	main
elan	doc_213943984974_item	2279640	et	3	main
ühiselamus	doc_213943984974_item	2279641	et	4	main
aastal	doc_213943984974_item	2279643	et	3	main
omaelu	doc_213943984974_item	2279647	et	4	main
seal	doc_213943984974_item	2279648	et	4	main
nii	doc_213943984974_item	2279650	et	3	main
raske	doc_213943984974_item	2279651	et	4	main
mis	doc_213943984974_item	2279656	et	4	main
aine	doc_213943984974_item	2279658	et	4	main
punktid	doc_213943984974_item	2279659	et	4	main
kus	doc_213943984974_item	2279664	et	3	main
tahan	doc_213943984974_item	2279669	et	3	main
ma	doc_213943984974_item	2279673	et	3	main
loodan	doc_213943984975_item	2279716	et	3	main
lektorid	doc_213943984975_item	2279718	et	3	main
ma	doc_213943984975_item	2279724	et	3	main
saan	doc_213943984975_item	2279734	et	4	main
informatsioone	doc_213943984975_item	2279739	et	3	main
inimesi	doc_213943984975_item	2279759	et	4	main
olla	doc_213943984975_item	2279760	et	3	main
inimesi	doc_213943984975_item	2279765	et	4	main
olla	doc_213943984975_item	2279770	et	3	main
usun	doc_213943984975_item	2279774	et	3	main
selliseid	doc_213943984975_item	2279779	et	4	main
ennas	doc_213943984975_item	2279805	et	4	main
silmaringi	doc_213943984975_item	2279811	et	4	main
kujundada	doc_213943984975_item	2279813	et	3	main
kuulata	doc_213943984975_item	2279823	et	4	main
inimesi	doc_213943984975_item	2279824	et	4	main
seisukohta	doc_213943984975_item	2279828	et	4	main
essee	doc_213943984976_item	2279831	et	4	main
ootan	doc_213943984976_item	2279833	et	3	main
kui	doc_213943984976_item	2279845	et	3	main
väikse	doc_213943984976_item	2279851	et	4	main
otsustasin	doc_213943984976_item	2279854	et	3	main
kindlasti	doc_213943984976_item	2279856	et	3	main
küll	doc_213943984976_item	2279861	et	4	main
juba	doc_213943984976_item	2279869	et	3	main
tean	doc_213943984976_item	2279872	et	3	main
inimene	doc_213943984976_item	2279887	et	3	main
sinu	doc_213943984976_item	2279889	et	3	main
pead	doc_213943984976_item	2279896	et	4	main
telliskivilt	doc_213943984976_item	2279899	et	3	main
meelesse	doc_213943984972_item	2279320	et	3	main
väga	doc_213943984972_item	2279321	et	3	main
võimalik	doc_213943984972_item	2279326	et	3	main
kui	doc_213943984972_item	2279330	et	3	main
ma	doc_213943984972_item	2279337	et	3	main
on	doc_213943984972_item	2279342	et	4	main
inimesi	doc_213943984972_item	2279347	et	4	main
ootan	doc_213943984973_item	2279358	et	3	main
ülikoolilt	doc_213943984973_item	2279359	et	4	main
iga	doc_213943984973_item	2279360	et	4	main
tuleb	doc_213943984973_item	2279363	et	3	main
kardab	doc_213943984973_item	2279374	et	4	main
tihti	doc_213943984973_item	2279376	et	3	main
mõtlesin	doc_213943984973_item	2279381	et	3	main
aga	doc_213943984973_item	2279387	et	3	main
et	doc_213943984973_item	2279400	et	3	main
peaaegu	doc_213943984973_item	2279409	et	3	main
rääkinud	doc_213943984973_item	2279411	et	4	main
ma	doc_213943984973_item	2279413	et	3	main
eriala	doc_213943984973_item	2279423	et	4	main
mind	doc_213943984973_item	2279425	et	4	main
ja	doc_213943984973_item	2279428	et	3	main
loodan	doc_213943984973_item	2279430	et	3	main
ülikool	doc_213943984973_item	2279432	et	4	main
mulle	doc_213943984973_item	2279434	et	4	main
informatsioni	doc_213943984973_item	2279435	et	4	main
kasulik	doc_213943984973_item	2279439	et	3	main
asi	doc_213943984973_item	2279442	et	4	main
väga	doc_213943984973_item	2279446	et	3	main
sarnaste	doc_213943984973_item	2279456	et	4	main
mis	doc_213943984973_item	2279458	et	4	main
on	doc_213943984973_item	2279460	et	4	main
mõnikord	doc_213943984973_item	2279461	et	3	main
elu	doc_213943984973_item	2279466	et	4	main
ei	doc_213943984973_item	2279499	et	4	main
olen	doc_213943984973_item	2279505	et	3	main
siin	doc_213943984973_item	2279513	et	4	main
mina	doc_213943984973_item	2279520	et	4	main
kardan	doc_213943984973_item	2279521	et	4	main
essee	doc_213943984974_item	2279531	et	4	main
minu	doc_213943984974_item	2279538	et	3	main
ma	doc_213943984974_item	2279548	et	3	main
tallinna	doc_213943984974_item	2279550	et	4	main
pedagoogikaülikooli	doc_213943984974_item	2279551	et	4	main
teha	doc_213943984974_item	2279584	et	3	main
on	doc_213943984974_item	2279589	et	4	main
raske	doc_213943984974_item	2279591	et	4	main
haridus	doc_213943984974_item	2279605	et	3	main
töö	doc_213943984974_item	2279610	et	4	main
vaid	doc_213943984974_item	2279623	et	3	main
on	doc_213943984974_item	2279626	et	4	main
väga	doc_213943984974_item	2279627	et	3	main
sel	doc_213943984974_item	2279642	et	3	main
praegu	doc_213943984974_item	2279652	et	3	main
kes	doc_213943984974_item	2279660	et	4	main
on	doc_213943984974_item	2279661	et	4	main
ülikoolielus	doc_213943984974_item	2279672	et	4	main
tulevikule	doc_213943984974_item	2279675	et	4	main
kõrgharidust	doc_213943984975_item	2279713	et	4	main
mind	doc_213943984975_item	2279720	et	4	main
saada	doc_213943984975_item	2279721	et	4	main
teadmisi	doc_213943984975_item	2279723	et	4	main
et	doc_213943984975_item	2279731	et	3	main
palju	doc_213943984975_item	2279735	et	4	main
mul	doc_213943984975_item	2279741	et	3	main
saada	doc_213943984975_item	2279744	et	4	main
õpetajaks	doc_213943984975_item	2279745	et	4	main
ja	doc_213943984975_item	2279746	et	3	main
usun	doc_213943984975_item	2279747	et	3	main
et	doc_213943984975_item	2279748	et	3	main
ülikoolil	doc_213943984975_item	2279749	et	4	main
ma	doc_213943984975_item	2279750	et	3	main
õppisin	doc_213943984975_item	2279751	et	3	main
sellest	doc_213943984975_item	2279752	et	4	main
tähtis	doc_213943984975_item	2279757	et	4	main
hea	doc_213943984975_item	2279771	et	4	main
ma	doc_213943984975_item	2279777	et	3	main
turvalisena	doc_213943984975_item	2279806	et	4	main
sa	doc_213943984975_item	2279807	et	3	main
oma	doc_213943984975_item	2279810	et	4	main
ja	doc_213943984975_item	2279812	et	3	main
sul	doc_213943984975_item	2279815	et	3	main
see	doc_213943984972_item	2279324	et	3	main
ainult	doc_213943984972_item	2279327	et	4	main
juhul	doc_213943984972_item	2279329	et	3	main
iga	doc_213943984972_item	2279331	et	4	main
ootan	doc_213943984972_item	2279338	et	3	main
minu	doc_213943984972_item	2279340	et	3	main
rõõmsaid	doc_213943984972_item	2279346	et	3	main
aeg	doc_213943984973_item	2279364	et	3	main
nimi	doc_213943984973_item	2279366	et	3	main
ülikool	doc_213943984973_item	2279368	et	4	main
kes	doc_213943984973_item	2279373	et	4	main
kes	doc_213943984973_item	2279375	et	4	main
selle	doc_213943984973_item	2279378	et	4	main
päris	doc_213943984973_item	2279385	et	4	main
ma	doc_213943984973_item	2279389	et	3	main
tea	doc_213943984973_item	2279391	et	4	main
ülikoolilt	doc_213943984973_item	2279394	et	4	main
vanemad	doc_213943984973_item	2279397	et	4	main
tudengina	doc_213943984973_item	2279401	et	3	main
päris	doc_213943984973_item	2279404	et	4	main
õpimisest	doc_213943984973_item	2279407	et	4	main
õpimine	doc_213943984973_item	2279417	et	4	main
on	doc_213943984973_item	2279418	et	4	main
väga	doc_213943984973_item	2279419	et	3	main
tähtis	doc_213943984973_item	2279420	et	4	main
kaua	doc_213943984972_item	2279322	et	3	main
tudeng	doc_213943984972_item	2279332	et	3	main
teeks	doc_213943984972_item	2279333	et	4	main
midagi	doc_213943984972_item	2279334	et	4	main
selle	doc_213943984972_item	2279335	et	4	main
gruppis	doc_213943984972_item	2279341	et	4	main
palju	doc_213943984972_item	2279343	et	4	main
kes	doc_213943984972_item	2279348	et	4	main
püüavad	doc_213943984972_item	2279349	et	3	main
teha	doc_213943984972_item	2279350	et	3	main
meie	doc_213943984972_item	2279351	et	4	main
elu	doc_213943984972_item	2279352	et	4	main
ja	doc_213943984972_item	2279354	et	3	main
kadedusväärseks	doc_213943984972_item	2279355	et	4	main
essee	doc_213943984973_item	2279356	et	4	main
mida	doc_213943984973_item	2279357	et	4	main
elus	doc_213943984973_item	2279362	et	4	main
on	doc_213943984973_item	2279367	et	4	main
ootab	doc_213943984973_item	2279370	et	3	main
peale	doc_213943984973_item	2279379	et	4	main
kaua	doc_213943984973_item	2279386	et	3	main
mulle	doc_213943984973_item	2279393	et	4	main
oodata	doc_213943984973_item	2279395	et	4	main
olla	doc_213943984973_item	2279402	et	3	main
ülikoolis	doc_213943984973_item	2279416	et	4	main
ajakirjandus	doc_213943984973_item	2279421	et	3	main
ma	doc_213943984973_item	2279429	et	3	main
annab	doc_213943984973_item	2279433	et	3	main
mis	doc_213943984973_item	2279436	et	4	main
olla	doc_213943984973_item	2279440	et	3	main
teine	doc_213943984973_item	2279441	et	3	main
ma	doc_213943984973_item	2279444	et	3	main
suhtlemine	doc_213943984973_item	2279449	et	4	main
sest	doc_213943984973_item	2279450	et	4	main
sõpru	doc_213943984973_item	2279455	et	3	main
huvidega	doc_213943984973_item	2279457	et	3	main
elus	doc_213943984973_item	2279459	et	4	main
ülikoolis	doc_213943984973_item	2279472	et	4	main
mida	doc_213943984973_item	2279501	et	4	main
ma	doc_213943984973_item	2279504	et	3	main
et	doc_213943984973_item	2279507	et	3	main
toob	doc_213943984973_item	2279509	et	3	main
pallju	doc_213943984973_item	2279511	et	4	main
üllatusi	doc_213943984973_item	2279512	et	4	main
algab	doc_213943984973_item	2279516	et	3	main
huvitab	doc_213943984973_item	2279426	et	3	main
mida	doc_213943984973_item	2279443	et	4	main
ootan	doc_213943984973_item	2279445	et	3	main
siin	doc_213943984973_item	2279451	et	4	main
saan	doc_213943984973_item	2279453	et	4	main
raske	doc_213943984973_item	2279463	et	4	main
ja	doc_213943984973_item	2279465	et	3	main
muutub	doc_213943984973_item	2279467	et	3	main
nüüd	doc_213943984973_item	2279468	et	4	main
teistsuguseks	doc_213943984973_item	2279469	et	4	main
väga	doc_213943984973_item	2279474	et	3	main
erinev	doc_213943984973_item	2279475	et	4	main
ja	doc_213943984973_item	2279476	et	3	main
mõtted	doc_213943984973_item	2279477	et	3	main
tulevad	doc_213943984973_item	2279478	et	4	main
siin	doc_213943984973_item	2279479	et	4	main
päris	doc_213943984973_item	2279480	et	4	main
teistsugused	doc_213943984973_item	2279481	et	3	main
ja	doc_213943984973_item	2279482	et	3	main
mõnikord	doc_213943984973_item	2279483	et	3	main
pärast	doc_213943984973_item	2279484	et	4	main
ülikooli	doc_213943984973_item	2279485	et	4	main
muudavad	doc_213943984973_item	2279486	et	4	main
isegi	doc_213943984973_item	2279487	et	4	main
inimeste	doc_213943984973_item	2279488	et	3	main
unistused	doc_213943984973_item	2279489	et	4	main
ja	doc_213943984973_item	2279490	et	3	main
nad	doc_213943984973_item	2279491	et	3	main
tegema	doc_213943984973_item	2279493	et	3	main
hoopis	doc_213943984973_item	2279494	et	3	main
hakkavad	doc_213943984973_item	2279492	et	4	main
midagi	doc_213943984973_item	2279495	et	4	main
muud	doc_213943984973_item	2279496	et	4	main
selleperast	doc_213943984973_item	2279497	et	4	main
ma	doc_213943984973_item	2279498	et	3	main
teagi	doc_213943984973_item	2279500	et	4	main
aga	doc_213943984973_item	2279503	et	3	main
kindel	doc_213943984973_item	2279506	et	3	main
esimesel	doc_213943984973_item	2279514	et	3	main
uus	doc_213943984973_item	2279518	et	3	main
nattuke	doc_213943984973_item	2279523	et	4	main
valmis	doc_213943984973_item	2279526	et	4	main
mis	doc_213943984973_item	2279528	et	4	main
ootan	doc_213943984974_item	2279533	et	3	main
unistus	doc_213943984974_item	2279539	et	4	main
juba	doc_213943984974_item	2279540	et	3	main
lapsepõlves	doc_213943984974_item	2279541	et	4	main
tahaksin	doc_213943984974_item	2279543	et	3	main
perega	doc_213943984974_item	2279552	et	3	main
ülikooliaastad	doc_213943984974_item	2279556	et	3	main
kodu	doc_213943984974_item	2279572	et	4	main
õpilased	doc_213943984974_item	2279574	et	3	main
seal	doc_213943984974_item	2279576	et	4	main
tean	doc_213943984974_item	2279581	et	3	main
tuleb	doc_213943984974_item	2279583	et	3	main
korraldust	doc_213943984974_item	2279586	et	4	main
see	doc_213943984974_item	2279588	et	3	main
hea	doc_213943984974_item	2279604	et	4	main
hea	doc_213943984974_item	2279609	et	4	main
peab	doc_213943984974_item	2279617	et	4	main
andma	doc_213943984974_item	2279618	et	3	main
olen	doc_213943984973_item	2279525	et	3	main
mida	doc_213943984974_item	2279532	et	4	main
ülikoolilt	doc_213943984974_item	2279534	et	4	main
ma	doc_213943984974_item	2279542	et	3	main
sel	doc_213943984974_item	2279546	et	3	main
tahan	doc_213943984974_item	2279554	et	3	main
et	doc_213943984974_item	2279555	et	3	main
saaksid	doc_213943984974_item	2279557	et	4	main
mulle	doc_213943984974_item	2279558	et	4	main
kui	doc_213943984974_item	2279559	et	3	main
elu	doc_213943984974_item	2279560	et	4	main
parimad	doc_213943984974_item	2279561	et	4	main
aastad	doc_213943984974_item	2279562	et	3	main
ma	doc_213943984974_item	2279563	et	3	main
ootan	doc_213943984974_item	2279564	et	3	main
ülikoolilt	doc_213943984974_item	2279565	et	4	main
et	doc_213943984974_item	2279566	et	3	main
ta	doc_213943984974_item	2279567	et	4	main
saab	doc_213943984974_item	2279568	et	3	main
mulle	doc_213943984974_item	2279569	et	4	main
teine	doc_213943984974_item	2279571	et	3	main
aga	doc_213943984974_item	2279573	et	3	main
kes	doc_213943984974_item	2279575	et	4	main
tähtis	doc_213943984974_item	2279596	et	4	main
meie	doc_213943984974_item	2279597	et	4	main
elus	doc_213943984974_item	2279598	et	4	main
kui	doc_213943984974_item	2279601	et	3	main
on	doc_213943984974_item	2279603	et	4	main
on	doc_213943984974_item	2279608	et	4	main
tulevik	doc_213943984974_item	2279613	et	3	main
ülikooli	doc_213943984974_item	2279615	et	4	main
ainult	doc_213943984974_item	2279621	et	4	main
see	doc_213943984974_item	2279625	et	3	main
võimalus	doc_213943984974_item	2279629	et	3	main
ma	doc_213943984974_item	2279633	et	3	main
algan	doc_213943984974_item	2279645	et	3	main
ei	doc_213943984974_item	2279654	et	4	main
aga	doc_213943984974_item	2279667	et	3	main
ma	doc_213943984974_item	2279668	et	3	main
ja	doc_213943984974_item	2279676	et	3	main
ma	doc_213943984975_item	2279710	et	3	main
ma	doc_213943984975_item	2279715	et	3	main
tutvustada	doc_213943984975_item	2279726	et	3	main
tudengidega	doc_213943984975_item	2279728	et	4	main
loodan	doc_213943984975_item	2279730	et	3	main
uusi	doc_213943984975_item	2279736	et	3	main
heatahtlikuks	doc_213943984975_item	2279761	et	3	main
oskada	doc_213943984975_item	2279763	et	4	main
olukordades	doc_213943984975_item	2279767	et	3	main
õpetajaks	doc_213943984975_item	2279772	et	4	main
et	doc_213943984975_item	2279775	et	3	main
võimalus	doc_213943984975_item	2279817	et	3	main
ennast	doc_213943984975_item	2279819	et	4	main
õppida	doc_213943984975_item	2279822	et	3	main
ülikoolilt	doc_213943984976_item	2279834	et	4	main
mulle	doc_213943984976_item	2279839	et	4	main
ülikoolis	doc_213943984976_item	2279842	et	4	main
see	doc_213943984976_item	2279847	et	3	main
siis	doc_213943984976_item	2279849	et	3	main
et	doc_213943984976_item	2279855	et	3	main
hakkan	doc_213943984976_item	2279857	et	3	main
ülikoolis	doc_213943984976_item	2279859	et	4	main
olen	doc_213943984976_item	2279868	et	3	main
on	doc_213943984976_item	2279879	et	4	main
raske	doc_213943984976_item	2279881	et	4	main
sina	doc_213943984976_item	2279884	et	4	main
inimesi	doc_213943984976_item	2279894	et	4	main
oma	doc_213943984976_item	2279900	et	4	main
töö	doc_213943984976_item	2279921	et	4	main
ka	doc_213943984976_item	2279933	et	3	main
matemaatika	doc_213943984976_item	2279941	et	4	main
füüsika	doc_213943984976_item	2279942	et	4	main
saan	doc_213943984976_item	2279963	et	4	main
õpetajana	doc_213943984976_item	2279964	et	4	main
mul	doc_213943984976_item	2279972	et	3	main
essee	doc_213943984977_item	2280000	et	4	main
mina	doc_213943984977_item	2280002	et	4	main
olen	doc_213943984977_item	2280003	et	3	main
mulle	doc_213943984977_item	2280008	et	4	main
aafrikast	doc_213943984977_item	2280009	et	4	main
õnnelik	doc_213943984974_item	2279612	et	3	main
veel	doc_213943984974_item	2279614	et	4	main
õppimine	doc_213943984974_item	2279616	et	4	main
mulle	doc_213943984974_item	2279619	et	4	main
mitte	doc_213943984974_item	2279620	et	3	main
kõrgharidus	doc_213943984974_item	2279622	et	3	main
ka	doc_213943984974_item	2279624	et	3	main
proovida	doc_213943984974_item	2279632	et	3	main
elan	doc_213943984974_item	2279634	et	3	main
järvel	doc_213943984974_item	2279636	et	4	main
uue	doc_213943984974_item	2279646	et	3	main
on	doc_213943984974_item	2279649	et	4	main
ma	doc_213943984974_item	2279653	et	3	main
on	doc_213943984974_item	2279657	et	4	main
dotsent	doc_213943984974_item	2279662	et	3	main
ja	doc_213943984974_item	2279663	et	3	main
asuvad	doc_213943984974_item	2279665	et	4	main
õppehooned	doc_213943984974_item	2279666	et	4	main
aktiivselt	doc_213943984974_item	2279670	et	4	main
ülikoolilt	doc_213943984975_item	2279709	et	4	main
tahan	doc_213943984975_item	2279711	et	3	main
ja	doc_213943984975_item	2279714	et	3	main
et	doc_213943984975_item	2279717	et	3	main
hea	doc_213943984974_item	2279628	et	4	main
oma	doc_213943984974_item	2279630	et	4	main
ma	doc_213943984974_item	2279644	et	3	main
tea	doc_213943984974_item	2279655	et	4	main
osaleda	doc_213943984974_item	2279671	et	3	main
mõtlen	doc_213943984974_item	2279674	et	3	main
loodan	doc_213943984974_item	2279677	et	3	main
et	doc_213943984974_item	2279678	et	3	main
ülikooli	doc_213943984974_item	2279679	et	4	main
õppimine	doc_213943984974_item	2279680	et	4	main
annab	doc_213943984974_item	2279681	et	3	main
mulle	doc_213943984974_item	2279682	et	4	main
hea	doc_213943984974_item	2279683	et	4	main
haridus	doc_213943984974_item	2279684	et	3	main
ja	doc_213943984974_item	2279685	et	3	main
ma	doc_213943984974_item	2279686	et	3	main
tegin	doc_213943984974_item	2279687	et	3	main
karjääri	doc_213943984974_item	2279688	et	4	main
selleks	doc_213943984974_item	2279689	et	4	main
on	doc_213943984974_item	2279690	et	4	main
ülikoolis	doc_213943984974_item	2279691	et	4	main
mitmeid	doc_213943984974_item	2279692	et	4	main
võimalusi	doc_213943984974_item	2279693	et	3	main
ma	doc_213943984974_item	2279694	et	3	main
tulen	doc_213943984974_item	2279695	et	3	main
ülikooli	doc_213943984974_item	2279696	et	4	main
sellepärast	doc_213943984974_item	2279697	et	3	main
et	doc_213943984974_item	2279698	et	3	main
ma	doc_213943984974_item	2279699	et	3	main
mõtlen	doc_213943984974_item	2279700	et	3	main
oma	doc_213943984974_item	2279701	et	4	main
tulevikule	doc_213943984974_item	2279702	et	4	main
juba	doc_213943984974_item	2279703	et	3	main
täna	doc_213943984974_item	2279704	et	4	main
essee	doc_213943984975_item	2279705	et	4	main
mida	doc_213943984975_item	2279706	et	4	main
ma	doc_213943984975_item	2279707	et	3	main
ootan	doc_213943984975_item	2279708	et	3	main
saada	doc_213943984975_item	2279712	et	4	main
aitavad	doc_213943984975_item	2279719	et	4	main
heid	doc_213943984975_item	2279722	et	4	main
tahan	doc_213943984975_item	2279725	et	3	main
ma	doc_213943984975_item	2279729	et	3	main
ma	doc_213943984975_item	2279733	et	3	main
huvitavaid	doc_213943984975_item	2279738	et	4	main
lapsepõlvest	doc_213943984975_item	2279740	et	4	main
arusaada	doc_213943984975_item	2279758	et	4	main
ja	doc_213943984975_item	2279773	et	3	main
laiendada	doc_213943984975_item	2279809	et	3	main
maailmavaadet	doc_213943984975_item	2279814	et	3	main
ja	doc_213943984975_item	2279825	et	3	main
isa	doc_213943984976_item	2279837	et	4	main
õpis	doc_213943984976_item	2279843	et	3	main
oli	doc_213943984976_item	2279848	et	3	main
tüdrukuna	doc_213943984976_item	2279852	et	3	main
ka	doc_213943984976_item	2279858	et	3	main
ei	doc_213943984976_item	2279862	et	4	main
mina	doc_213943984976_item	2279867	et	4	main
ja	doc_213943984976_item	2279871	et	3	main
et	doc_213943984976_item	2279874	et	3	main
kõrghariduseta	doc_213943984976_item	2279876	et	3	main
selles	doc_213943984976_item	2279877	et	4	main
maailmas	doc_213943984976_item	2279878	et	3	main
oled	doc_213943984976_item	2279885	et	3	main
ei	doc_213943984976_item	2279891	et	4	main
ole	doc_213943984976_item	2279892	et	4	main
uusi	doc_213943984975_item	2279727	et	3	main
ülikoolist	doc_213943984975_item	2279732	et	4	main
ja	doc_213943984975_item	2279737	et	3	main
oli	doc_213943984975_item	2279742	et	3	main
soov	doc_213943984975_item	2279743	et	3	main
meie	doc_213943984975_item	2279753	et	4	main
elus	doc_213943984975_item	2279754	et	4	main
on	doc_213943984975_item	2279755	et	4	main
väga	doc_213943984975_item	2279756	et	3	main
ja	doc_213943984975_item	2279762	et	3	main
toetada	doc_213943984975_item	2279764	et	3	main
rasketes	doc_213943984975_item	2279766	et	3	main
mina	doc_213943984975_item	2279768	et	4	main
tahan	doc_213943984975_item	2279769	et	3	main
ülikoolis	doc_213943984975_item	2279776	et	4	main
võiksin	doc_213943984975_item	2279778	et	3	main
asju	doc_213943984975_item	2279780	et	3	main
õppida	doc_213943984975_item	2279781	et	3	main
olen	doc_213943984975_item	2279782	et	3	main
seisukohal	doc_213943984975_item	2279783	et	4	main
et	doc_213943984975_item	2279784	et	3	main
inimene	doc_213943984975_item	2279785	et	3	main
peab	doc_213943984975_item	2279786	et	4	main
kätt	doc_213943984975_item	2279787	et	3	main
elus	doc_213943984975_item	2279788	et	4	main
tuiksoonel	doc_213943984975_item	2279789	et	3	main
hoia	doc_213943984975_item	2279790	et	4	main
ja	doc_213943984975_item	2279791	et	3	main
minna	doc_213943984975_item	2279792	et	3	main
oma	doc_213943984975_item	2279793	et	4	main
soovi	doc_213943984975_item	2279794	et	4	main
minu	doc_213943984975_item	2279795	et	3	main
arust	doc_213943984975_item	2279796	et	4	main
ülikool	doc_213943984975_item	2279797	et	4	main
see	doc_213943984975_item	2279798	et	3	main
on	doc_213943984975_item	2279799	et	4	main
koht	doc_213943984975_item	2279800	et	3	main
sa	doc_213943984975_item	2279802	et	3	main
kus	doc_213943984975_item	2279801	et	3	main
võid	doc_213943984975_item	2279803	et	4	main
tunda	doc_213943984975_item	2279804	et	3	main
võid	doc_213943984975_item	2279808	et	4	main
näita	doc_213943984975_item	2279818	et	4	main
on	doc_213943984975_item	2279816	et	4	main
heas	doc_213943984975_item	2279820	et	3	main
valguses	doc_213943984975_item	2279821	et	4	main
oma	doc_213943984975_item	2279827	et	4	main
anda	doc_213943984975_item	2279829	et	3	main
minu	doc_213943984976_item	2279836	et	3	main
ta	doc_213943984976_item	2279841	et	4	main
ja	doc_213943984976_item	2279844	et	3	main
suurepäraselt	doc_213943984976_item	2279846	et	4	main
mina	doc_213943984976_item	2279853	et	4	main
teadnud	doc_213943984976_item	2279863	et	4	main
mille	doc_213943984976_item	2279864	et	3	main
jaoks	doc_213943984976_item	2279865	et	4	main
praegu	doc_213943984976_item	2279866	et	3	main
täpselt	doc_213943984976_item	2279873	et	4	main
üsna	doc_213943984976_item	2279880	et	3	main
kui	doc_213943984976_item	2279883	et	3	main
vanemad	doc_213943984976_item	2279890	et	4	main
siis	doc_213943984976_item	2279895	et	3	main
ise	doc_213943984976_item	2279897	et	4	main
telliskivi	doc_213943984976_item	2279898	et	4	main
raske	doc_213943984976_item	2279924	et	4	main
sellepärast	doc_213943984976_item	2279934	et	3	main
mina	doc_213943984976_item	2279945	et	4	main
neid	doc_213943984976_item	2279955	et	4	main
või	doc_213943984976_item	2279965	et	4	main
tõlkijana	doc_213943984976_item	2279966	et	4	main
see	doc_213943984976_item	2279968	et	3	main
et	doc_213943984976_item	2279970	et	3	main
isa	doc_213943984976_item	2279999	et	4	main
kui	doc_213943984977_item	2280001	et	3	main
ta	doc_213943984977_item	2280011	et	4	main
suur	doc_213943984977_item	2280014	et	3	main
ilus	doc_213943984977_item	2280016	et	4	main
aga	doc_213943984977_item	2280017	et	3	main
rumal	doc_213943984977_item	2280018	et	3	main
elas	doc_213943984977_item	2280021	et	3	main
ja	doc_213943984977_item	2280024	et	3	main
pidime	doc_213943984977_item	2280026	et	3	main
iga	doc_213943984977_item	2280032	et	4	main
öösel	doc_213943984977_item	2280033	et	4	main
ta	doc_213943984977_item	2280034	et	4	main
elas	doc_213943984977_item	2280048	et	3	main
oma	doc_213943984977_item	2280050	et	4	main
kõik	doc_213943984977_item	2280057	et	4	main
magasid	doc_213943984977_item	2280058	et	4	main
ära	doc_213943984977_item	2280065	et	4	main
hommikul	doc_213943984977_item	2280066	et	3	main
ei	doc_213943984977_item	2280072	et	4	main
lendas	doc_213943984977_item	2280076	et	3	main
ja	doc_213943984977_item	2280078	et	3	main
papagoi	doc_213943984977_item	2280091	et	4	main
lendas	doc_213943984977_item	2280092	et	3	main
ära	doc_213943984977_item	2280093	et	4	main
see	doc_213943984977_item	2280094	et	3	main
oli	doc_213943984977_item	2280095	et	3	main
minu	doc_213943984977_item	2280097	et	3	main
maganud	doc_213943984977_item	2280111	et	4	main
rääkida	doc_213943984975_item	2279826	et	3	main
nõusid	doc_213943984975_item	2279830	et	3	main
mida	doc_213943984976_item	2279832	et	4	main
lapsepõlves	doc_213943984976_item	2279835	et	4	main
jutustas	doc_213943984976_item	2279838	et	3	main
kuidas	doc_213943984976_item	2279840	et	3	main
juba	doc_213943984976_item	2279850	et	3	main
õppima	doc_213943984976_item	2279860	et	3	main
täiskasvanud	doc_213943984976_item	2279870	et	4	main
ilma	doc_213943984976_item	2279875	et	4	main
elada	doc_213943984976_item	2279882	et	3	main
tavaline	doc_213943984976_item	2279886	et	4	main
ning	doc_213943984976_item	2279888	et	3	main
rikkaid	doc_213943984976_item	2279893	et	4	main
elu	doc_213943984976_item	2279901	et	4	main
ehitada	doc_213943984976_item	2279902	et	3	main
iga	doc_213943984976_item	2279903	et	4	main
inimene	doc_213943984976_item	2279904	et	3	main
on	doc_213943984976_item	2279905	et	4	main
õnne	doc_213943984976_item	2279907	et	4	main
oma	doc_213943984976_item	2279906	et	4	main
sepp	doc_213943984976_item	2279908	et	3	main
kõigepealt	doc_213943984976_item	2279909	et	3	main
ülikoolis	doc_213943984976_item	2279910	et	4	main
mina	doc_213943984976_item	2279911	et	4	main
tahan	doc_213943984976_item	2279912	et	3	main
omandada	doc_213943984976_item	2279913	et	3	main
valitud	doc_213943984976_item	2279914	et	4	main
eriala	doc_213943984976_item	2279915	et	4	main
mina	doc_213943984976_item	2279916	et	4	main
arvama	doc_213943984976_item	2279918	et	3	main
et	doc_213943984976_item	2279919	et	3	main
õpetaja	doc_213943984976_item	2279920	et	4	main
kaldun	doc_213943984976_item	2279917	et	3	main
aga	doc_213943984976_item	2279925	et	3	main
meeldib	doc_213943984976_item	2279927	et	3	main
et	doc_213943984976_item	2279935	et	3	main
keemiaga	doc_213943984976_item	2279944	et	3	main
mind	doc_213943984976_item	2279950	et	4	main
huvitavad	doc_213943984976_item	2279951	et	4	main
õppeained	doc_213943984976_item	2279953	et	3	main
lõpetamist	doc_213943984976_item	2279961	et	4	main
mina	doc_213943984976_item	2279962	et	4	main
töötada	doc_213943984976_item	2279967	et	3	main
tähendab	doc_213943984976_item	2279969	et	3	main
tööturul	doc_213943984976_item	2279971	et	3	main
minu	doc_213943984976_item	2279998	et	3	main
väga	doc_213943984977_item	2280013	et	3	main
ta	doc_213943984977_item	2280022	et	4	main
igapäev	doc_213943984977_item	2280028	et	3	main
uut	doc_213943984977_item	2280030	et	3	main
auku	doc_213943984977_item	2280037	et	4	main
lendas	doc_213943984977_item	2280039	et	3	main
üks	doc_213943984977_item	2280053	et	3	main
öösel	doc_213943984977_item	2280055	et	4	main
papagoi	doc_213943984977_item	2280059	et	4	main
lõhkus	doc_213943984977_item	2280060	et	3	main
ärkasid	doc_213943984977_item	2280069	et	4	main
märkanud	doc_213943984977_item	2280073	et	4	main
ära	doc_213943984977_item	2280077	et	4	main
vanaema	doc_213943984977_item	2280082	et	4	main
ta	doc_213943984977_item	2280088	et	4	main
üsna	doc_213943984976_item	2279923	et	3	main
filoloogiat	doc_213943984976_item	2279932	et	3	main
kõikidest	doc_213943984976_item	2279936	et	4	main
seotud	doc_213943984976_item	2279940	et	4	main
ei	doc_213943984976_item	2279946	et	4	main
midagi	doc_213943984976_item	2279948	et	4	main
teada	doc_213943984976_item	2279949	et	3	main
ja	doc_213943984976_item	2279954	et	3	main
mina	doc_213943984976_item	2279956	et	4	main
tahan	doc_213943984976_item	2279957	et	3	main
õppida	doc_213943984976_item	2279958	et	3	main
pärast	doc_213943984976_item	2279959	et	4	main
mingi	doc_213943984976_item	2279974	et	4	main
valik	doc_213943984976_item	2279975	et	3	main
kõrgharidus	doc_213943984976_item	2279976	et	3	main
on	doc_213943984976_item	2279977	et	4	main
küll	doc_213943984976_item	2279978	et	4	main
vaja	doc_213943984976_item	2279979	et	4	main
et	doc_213943984976_item	2279980	et	3	main
oma	doc_213943984976_item	2279981	et	4	main
väärtushinanguid	doc_213943984976_item	2279982	et	4	main
laiendada	doc_213943984976_item	2279983	et	3	main
et	doc_213943984976_item	2279984	et	3	main
intellektuaalselt	doc_213943984976_item	2279985	et	4	main
arenenud	doc_213943984976_item	2279986	et	4	main
olla	doc_213943984976_item	2279987	et	3	main
tahaks	doc_213943984976_item	2279988	et	3	main
aru	doc_213943984976_item	2279990	et	4	main
saada	doc_213943984976_item	2279991	et	4	main
ka	doc_213943984976_item	2279989	et	3	main
millist	doc_213943984976_item	2279992	et	3	main
elust	doc_213943984976_item	2279993	et	3	main
ülikoolis	doc_213943984976_item	2279994	et	4	main
nii	doc_213943984976_item	2279995	et	3	main
tihti	doc_213943984976_item	2279996	et	3	main
jutustas	doc_213943984976_item	2279997	et	3	main
on	doc_213943984976_item	2279922	et	4	main
mulle	doc_213943984976_item	2279926	et	4	main
lapsedega	doc_213943984976_item	2279928	et	3	main
olla	doc_213943984976_item	2279929	et	3	main
mina	doc_213943984976_item	2279930	et	4	main
valisin	doc_213943984976_item	2279931	et	3	main
valdkonnadest	doc_213943984976_item	2279937	et	3	main
mis	doc_213943984976_item	2279938	et	4	main
on	doc_213943984976_item	2279939	et	4	main
või	doc_213943984976_item	2279943	et	4	main
taha	doc_213943984976_item	2279947	et	4	main
humanitaarsed	doc_213943984976_item	2279952	et	3	main
ülikooli	doc_213943984976_item	2279960	et	4	main
on	doc_213943984976_item	2279973	et	4	main
isa	doc_213943984977_item	2280006	et	4	main
papagoit	doc_213943984977_item	2280010	et	4	main
oli	doc_213943984977_item	2280012	et	3	main
ja	doc_213943984977_item	2280015	et	3	main
esimene	doc_213943984977_item	2280019	et	3	main
karbis	doc_213943984977_item	2280023	et	3	main
leida	doc_213943984977_item	2280029	et	3	main
sest	doc_213943984977_item	2280031	et	4	main
ja	doc_213943984977_item	2280038	et	3	main
ära	doc_213943984977_item	2280040	et	4	main
suvel	doc_213943984977_item	2280047	et	3	main
puurus	doc_213943984977_item	2280051	et	4	main
rõdul	doc_213943984977_item	2280052	et	3	main
puuru	doc_213943984977_item	2280062	et	4	main
ja	doc_213943984977_item	2280063	et	3	main
lendas	doc_213943984977_item	2280064	et	3	main
kõik	doc_213943984977_item	2280068	et	4	main
ainult	doc_213943984977_item	2280079	et	4	main
talle	doc_213943984977_item	2280084	et	4	main
süüja	doc_213943984977_item	2280085	et	4	main
anda	doc_213943984977_item	2280086	et	3	main
ütles	doc_213943984977_item	2280087	et	3	main
keegi	doc_213943984977_item	2280107	et	4	main
seda	doc_213943984977_item	2280109	et	3	main
kassi	doc_213943984979_item	2280262	et	4	main
mu	doc_213943984979_item	2280271	et	3	main
sõbraks	doc_213943984979_item	2280273	et	3	main
päeval	doc_213943984979_item	2280276	et	3	main
naabrite	doc_213943984979_item	2280280	et	3	main
tapas	doc_213943984979_item	2280284	et	3	main
kass	doc_213943984979_item	2280286	et	3	main
endale	doc_213943984979_item	2280296	et	4	main
ühel	doc_213943984979_item	2280299	et	3	main
esiteks	doc_213943984979_item	2280308	et	3	main
mingi	doc_213943984979_item	2280313	et	4	main
või	doc_213943984979_item	2280315	et	4	main
küünistamine	doc_213943984979_item	2280317	et	4	main
lapsena	doc_213943984977_item	2280004	et	3	main
mu	doc_213943984977_item	2280005	et	3	main
tõi	doc_213943984977_item	2280007	et	3	main
nädal	doc_213943984977_item	2280020	et	3	main
me	doc_213943984977_item	2280025	et	4	main
talle	doc_213943984977_item	2280027	et	4	main
tegi	doc_213943984977_item	2280035	et	4	main
seal	doc_213943984977_item	2280036	et	4	main
pärast	doc_213943984977_item	2280041	et	4	main
kord	doc_213943984977_item	2280054	et	4	main
kui	doc_213943984977_item	2280056	et	3	main
kui	doc_213943984977_item	2280067	et	3	main
keegi	doc_213943984977_item	2280071	et	4	main
et	doc_213943984977_item	2280074	et	3	main
kui	doc_213943984977_item	2280081	et	3	main
läks	doc_213943984977_item	2280083	et	3	main
et	doc_213943984977_item	2280089	et	3	main
õnn	doc_213943984977_item	2280096	et	3	main
mitte	doc_213943984977_item	2280106	et	3	main
ei	doc_213943984977_item	2280110	et	4	main
ma	doc_213943984979_item	2280256	et	3	main
vanemad	doc_213943984979_item	2280259	et	4	main
kingisid	doc_213943984979_item	2280260	et	3	main
muutus	doc_213943984979_item	2280270	et	4	main
paremaks	doc_213943984979_item	2280272	et	4	main
juhtus	doc_213943984979_item	2280277	et	3	main
koletis	doc_213943984979_item	2280283	et	3	main
tahtnud	doc_213943984979_item	2280295	et	4	main
kassi	doc_213943984979_item	2280298	et	4	main
arvasin	doc_213943984979_item	2280309	et	3	main
see	doc_213943984979_item	2280311	et	3	main
läksin	doc_213943984979_item	2280323	et	3	main
kes	doc_213943984979_item	2280327	et	4	main
on	doc_213943984979_item	2280329	et	4	main
ole	doc_213943984979_item	2280331	et	4	main
võimalik	doc_213943984979_item	2280332	et	3	main
kirjutada	doc_213943984979_item	2280333	et	3	main
olin	doc_213943984979_item	2280336	et	3	main
lasin	doc_213943984979_item	2280346	et	3	main
tuppa	doc_213943984979_item	2280348	et	3	main
kass	doc_213943984979_item	2280350	et	3	main
isegi	doc_213943984979_item	2280358	et	4	main
ja	doc_213943984979_item	2280366	et	3	main
tahaks	doc_213943984979_item	2280372	et	3	main
midagi	doc_213943984979_item	2280374	et	4	main
läksin	doc_213943984979_item	2280379	et	3	main
me	doc_213943984979_item	2280384	et	4	main
juba	doc_213943984979_item	2280389	et	3	main
jooksis	doc_213943984979_item	2280404	et	4	main
ja	doc_213943984979_item	2280411	et	3	main
oma	doc_213943984979_item	2280421	et	4	main
näha	doc_213943984979_item	2280423	et	3	main
me	doc_213943984977_item	2280042	et	4	main
ostsime	doc_213943984977_item	2280043	et	3	main
talle	doc_213943984977_item	2280044	et	4	main
puuru	doc_213943984977_item	2280045	et	4	main
iga	doc_213943984977_item	2280046	et	4	main
papagoi	doc_213943984977_item	2280049	et	4	main
ära	doc_213943984977_item	2280061	et	4	main
mitte	doc_213943984977_item	2280070	et	3	main
papagoi	doc_213943984977_item	2280075	et	4	main
siis	doc_213943984977_item	2280080	et	3	main
meie	doc_213943984977_item	2280090	et	4	main
sest	doc_213943984977_item	2280099	et	4	main
pärast	doc_213943984977_item	2280108	et	4	main
kui	doc_213943984979_item	2280255	et	3	main
nimetasin	doc_213943984979_item	2280263	et	3	main
eesnimi	doc_213943984979_item	2280265	et	3	main
väga	doc_213943984979_item	2280267	et	3	main
ta	doc_213943984979_item	2280269	et	4	main
tragöödia	doc_213943984979_item	2280278	et	4	main
olin	doc_213943984979_item	2280289	et	3	main
siis	doc_213943984979_item	2280290	et	3	main
kurb	doc_213943984979_item	2280292	et	3	main
uue	doc_213943984979_item	2280297	et	3	main
kuulsin	doc_213943984979_item	2280301	et	3	main
et	doc_213943984979_item	2280310	et	3	main
oli	doc_213943984979_item	2280312	et	3	main
varblane	doc_213943984979_item	2280316	et	3	main
segas	doc_213943984979_item	2280318	et	3	main
ja	doc_213943984979_item	2280321	et	3	main
seal	doc_213943984979_item	2280328	et	4	main
kuidas	doc_213943984979_item	2280334	et	3	main
üllatanud	doc_213943984979_item	2280337	et	4	main
kassi	doc_213943984979_item	2280344	et	4	main
ja	doc_213943984979_item	2280349	et	3	main
läks	doc_213943984979_item	2280351	et	3	main
ukse	doc_213943984979_item	2280353	et	3	main
juurde	doc_213943984979_item	2280354	et	4	main
pime	doc_213943984979_item	2280365	et	3	main
öelda	doc_213943984979_item	2280375	et	4	main
või	doc_213943984979_item	2280376	et	4	main
mina	doc_213943984979_item	2280378	et	4	main
ja	doc_213943984979_item	2280383	et	3	main
astusime	doc_213943984979_item	2280385	et	3	main
majja	doc_213943984979_item	2280387	et	3	main
kus	doc_213943984979_item	2280388	et	3	main
palju	doc_213943984979_item	2280390	et	4	main
erinevate	doc_213943984981_item	2280548	et	4	main
jaoks	doc_213943984977_item	2280098	et	4	main
iga	doc_213943984977_item	2280100	et	4	main
hommikul	doc_213943984977_item	2280101	et	3	main
ta	doc_213943984977_item	2280102	et	4	main
hakkas	doc_213943984977_item	2280103	et	3	main
karjuma	doc_213943984977_item	2280104	et	3	main
ja	doc_213943984977_item	2280105	et	3	main
essee	doc_213943984979_item	2280254	et	4	main
olin	doc_213943984979_item	2280257	et	3	main
mulle	doc_213943984979_item	2280261	et	4	main
teda	doc_213943984979_item	2280264	et	4	main
ja	doc_213943984979_item	2280266	et	3	main
kiiresti	doc_213943984979_item	2280268	et	3	main
rotveiler	doc_213943984979_item	2280281	et	4	main
mu	doc_213943984979_item	2280285	et	3	main
ära	doc_213943984979_item	2280288	et	4	main
väga	doc_213943984979_item	2280291	et	3	main
ei	doc_213943984979_item	2280294	et	4	main
et	doc_213943984979_item	2280302	et	3	main
küünistab	doc_213943984979_item	2280304	et	3	main
tuvi	doc_213943984979_item	2280314	et	4	main
mind	doc_213943984979_item	2280319	et	4	main
magada	doc_213943984979_item	2280320	et	3	main
juurde	doc_213943984979_item	2280325	et	4	main
vaatamas	doc_213943984979_item	2280326	et	3	main
ma	doc_213943984979_item	2280335	et	3	main
oma	doc_213943984979_item	2280342	et	4	main
surnud	doc_213943984979_item	2280343	et	4	main
jälitasin	doc_213943984979_item	2280356	et	3	main
kass	doc_213943984979_item	2280368	et	3	main
vaatas	doc_213943984979_item	2280369	et	3	main
nagu	doc_213943984979_item	2280371	et	3	main
mulle	doc_213943984979_item	2280373	et	4	main
näidata	doc_213943984979_item	2280377	et	4	main
vana	doc_213943984979_item	2280386	et	4	main
keegi	doc_213943984979_item	2280392	et	4	main
et	doc_213943984979_item	2280399	et	3	main
ette	doc_213943984979_item	2280405	et	4	main
kadus	doc_213943984979_item	2280407	et	3	main
momentil	doc_213943984979_item	2280409	et	4	main
kaheksaastane	doc_213943984979_item	2280258	et	4	main
aga	doc_213943984979_item	2280274	et	3	main
ühel	doc_213943984979_item	2280275	et	3	main
minu	doc_213943984979_item	2280279	et	3	main
hirmus	doc_213943984979_item	2280282	et	4	main
i	doc_213943984979_item	2280287	et	4	main
ja	doc_213943984979_item	2280293	et	3	main
õhtul	doc_213943984979_item	2280300	et	3	main
keegi	doc_213943984979_item	2280303	et	4	main
mu	doc_213943984979_item	2280305	et	3	main
akna	doc_213943984979_item	2280306	et	3	main
taga	doc_213943984979_item	2280307	et	4	main
akna	doc_213943984979_item	2280324	et	3	main
sest	doc_213943984979_item	2280338	et	4	main
et	doc_213943984979_item	2280339	et	3	main
nägin	doc_213943984979_item	2280340	et	3	main
seal	doc_213943984979_item	2280341	et	4	main
ma	doc_213943984979_item	2280345	et	3	main
ma	doc_213943984979_item	2280355	et	3	main
ta	doc_213943984979_item	2280360	et	4	main
vaikne	doc_213943984979_item	2280367	et	3	main
minule	doc_213943984979_item	2280370	et	3	main
tema	doc_213943984979_item	2280381	et	4	main
ei	doc_213943984979_item	2280393	et	4	main
maja	doc_213943984979_item	2280395	et	4	main
keskaegses	doc_213943984979_item	2280401	et	3	main
kass	doc_213943984979_item	2280403	et	3	main
ja	doc_213943984979_item	2280406	et	3	main
kassi	doc_213943984979_item	2280422	et	4	main
võtsin	doc_213943984981_item	2280570	et	3	main
sarja	doc_213943984981_item	2280573	et	4	main
mind	doc_213943984981_item	2280583	et	4	main
komöödiat	doc_213943984981_item	2280588	et	3	main
mcguire	doc_213943984981_item	2280590	et	4	main
ja	doc_213943984981_item	2280592	et	3	main
ilusad	doc_213943984981_item	2280598	et	3	main
3	doc_213943984981_item	2280600	et	2	main
pisiasjade	doc_213943984981_item	2280607	et	3	main
ilmunud	doc_213943984981_item	2280615	et	4	main
õigeaegselt	doc_213943984981_item	2280617	et	4	main
kui	doc_213943984981_item	2280619	et	3	main
avas	doc_213943984981_item	2280622	et	4	main
ekraanilt	doc_213943984981_item	2280625	et	3	main
kõnevooru	doc_213943984981_item	2280627	et	4	main
kus	doc_213943984981_item	2280633	et	3	main
seetõttu	doc_213943984981_item	2280648	et	3	main
osa	doc_213943984981_item	2280650	et	4	main
ja	doc_213943984981_item	2280660	et	3	main
oli	doc_213943984981_item	2280665	et	3	main
right	doc_213943984981_item	2280677	et	4	main
märkasin	doc_213943984981_item	2280726	et	3	main
selles	doc_213943984981_item	2280728	et	4	main
kateiks	doc_213943984981_item	2280734	et	4	main
2	doc_213943984981_item	2280736	et	2	main
nagu	doc_213943984981_item	2280742	et	3	main
1	doc_213943984981_item	2280745	et	2	main
subtiitrite	doc_213943984981_item	2280752	et	4	main
et	doc_213943984981_item	2280756	et	3	main
võimalik	doc_213943984981_item	2280758	et	3	main
jälgimiseks	doc_213943984981_item	2280767	et	4	main
puudus	doc_213943984981_item	2280782	et	4	main
pöördumine	doc_213943984981_item	2280785	et	4	main
ma	doc_213943984979_item	2280322	et	3	main
ei	doc_213943984979_item	2280330	et	4	main
teda	doc_213943984979_item	2280347	et	4	main
kohe	doc_213943984979_item	2280352	et	4	main
teda	doc_213943984979_item	2280357	et	4	main
kui	doc_213943984979_item	2280359	et	3	main
õue	doc_213943984979_item	2280361	et	4	main
läks	doc_213943984979_item	2280362	et	3	main
õuel	doc_213943984979_item	2280363	et	3	main
oli	doc_213943984979_item	2280364	et	3	main
jalle	doc_213943984979_item	2280380	et	4	main
järele	doc_213943984979_item	2280382	et	4	main
aastaid	doc_213943984979_item	2280391	et	4	main
ela	doc_213943984979_item	2280394	et	4	main
sees	doc_213943984979_item	2280396	et	4	main
leidsin	doc_213943984979_item	2280397	et	3	main
välja	doc_213943984979_item	2280398	et	4	main
olin	doc_213943984979_item	2280400	et	3	main
lossis	doc_213943984979_item	2280402	et	4	main
sel	doc_213943984979_item	2280408	et	3	main
ärkasin	doc_213943984979_item	2280410	et	3	main
tundsin	doc_213943984979_item	2280412	et	3	main
et	doc_213943984979_item	2280413	et	3	main
see	doc_213943984979_item	2280414	et	3	main
ainult	doc_213943984979_item	2280416	et	4	main
oli	doc_213943984979_item	2280415	et	3	main
unistus	doc_213943984979_item	2280417	et	4	main
oli	doc_213943984979_item	2280418	et	3	main
hea	doc_213943984979_item	2280419	et	4	main
unistuses	doc_213943984979_item	2280420	et	4	main
telekanalite	doc_213943984981_item	2280549	et	3	main
selles	doc_213943984981_item	2280552	et	4	main
kus	doc_213943984981_item	2280557	et	3	main
subtiitrite	doc_213943984981_item	2280559	et	4	main
ülesehitust	doc_213943984981_item	2280560	et	4	main
poolt	doc_213943984981_item	2280563	et	4	main
tõlke	doc_213943984981_item	2280565	et	4	main
ja	doc_213943984981_item	2280575	et	3	main
mcleodi	doc_213943984981_item	2280580	et	4	main
kateiks	doc_213943984981_item	2280584	et	4	main
ja	doc_213943984981_item	2280586	et	3	main
kaks	doc_213943984981_item	2280587	et	3	main
lizzi	doc_213943984981_item	2280589	et	4	main
3	doc_213943984981_item	2280594	et	2	main
tv-2	doc_213943984981_item	2280595	et	4	main
ja	doc_213943984981_item	2280597	et	3	main
üsna	doc_213943984981_item	2280603	et	3	main
võiks	doc_213943984981_item	2280609	et	4	main
1	doc_213943984981_item	2280611	et	2	main
mitte	doc_213943984981_item	2280612	et	3	main
ekraanile	doc_213943984981_item	2280618	et	3	main
suu	doc_213943984981_item	2280621	et	4	main
ja	doc_213943984981_item	2280623	et	3	main
enne	doc_213943984981_item	2280626	et	4	main
2	doc_213943984981_item	2280629	et	2	main
oli	doc_213943984981_item	2280631	et	3	main
kiiresti	doc_213943984981_item	2280638	et	3	main
ei	doc_213943984981_item	2280642	et	4	main
kõike	doc_213943984981_item	2280644	et	4	main
olnud	doc_213943984981_item	2280654	et	4	main
saada	doc_213943984981_item	2280657	et	4	main
räägib	doc_213943984981_item	2280659	et	3	main
3	doc_213943984981_item	2280664	et	2	main
jäetud	doc_213943984981_item	2280666	et	4	main
tõlkimata	doc_213943984981_item	2280668	et	4	main
oli	doc_213943984981_item	2280671	et	3	main
nt	doc_213943984981_item	2280673	et	4	main
olid	doc_213943984981_item	2280721	et	4	main
siin	doc_213943984981_item	2280737	et	4	main
praktilised	doc_213943984981_item	2280739	et	3	main
kasutatakse	doc_213943984981_item	2280751	et	3	main
lugeda	doc_213943984981_item	2280759	et	3	main
kohtades	doc_213943984981_item	2280806	et	3	main
ei	doc_213943984981_item	2280813	et	4	main
jälgida	doc_213943984981_item	2280816	et	3	main
toimuvat	doc_213943984981_item	2280818	et	4	main
ma	doc_213943984981_item	2280554	et	3	main
ülevaade	doc_213943984981_item	2280556	et	3	main
adekvaatsust	doc_213943984981_item	2280566	et	4	main
ja	doc_213943984981_item	2280567	et	3	main
sünkroonsust	doc_213943984981_item	2280568	et	4	main
töösse	doc_213943984981_item	2280571	et	3	main
dramaatilise	doc_213943984981_item	2280578	et	3	main
tv-2	doc_213943984981_item	2280585	et	4	main
tv-3	doc_213943984981_item	2280591	et	4	main
vaprad	doc_213943984981_item	2280596	et	3	main
tv	doc_213943984981_item	2280599	et	4	main
üldmulje	doc_213943984981_item	2280601	et	4	main
kuigi	doc_213943984981_item	2280605	et	3	main
ei	doc_213943984981_item	2280614	et	4	main
tegelane	doc_213943984981_item	2280620	et	3	main
lõppu	doc_213943984981_item	2280628	et	4	main
kohti	doc_213943984981_item	2280632	et	4	main
subtiitrid	doc_213943984981_item	2280634	et	4	main
vahetusid	doc_213943984981_item	2280635	et	4	main
ma	doc_213943984981_item	2280641	et	3	main
ning	doc_213943984981_item	2280647	et	3	main
jäi	doc_213943984981_item	2280649	et	3	main
sarjast	doc_213943984981_item	2280651	et	4	main
arusaamatuks	doc_213943984981_item	2280652	et	4	main
on	doc_213943984981_item	2280662	et	4	main
midagi	doc_213943984981_item	2280667	et	4	main
a	doc_213943984981_item	2280674	et	4	main
is	doc_213943984981_item	2280675	et	4	main
ei	doc_213943984981_item	2280680	et	4	main
esimene	doc_213943984981_item	2280682	et	3	main
referaat	doc_213943984981_item	2280546	et	3	main
eesti	doc_213943984981_item	2280547	et	4	main
subtitreerimispõhimõtete	doc_213943984981_item	2280550	et	4	main
analüüs	doc_213943984981_item	2280551	et	3	main
töös	doc_213943984981_item	2280553	et	3	main
koostan	doc_213943984981_item	2280555	et	3	main
keelelist	doc_213943984981_item	2280562	et	4	main
ma	doc_213943984981_item	2280569	et	3	main
ilusad	doc_213943984981_item	2280576	et	3	main
oli	doc_213943984981_item	2280602	et	3	main
subtiitrid	doc_213943984981_item	2280616	et	4	main
kadusid	doc_213943984981_item	2280624	et	4	main
liiga	doc_213943984981_item	2280637	et	4	main
nii	doc_213943984981_item	2280639	et	3	main
võimalik	doc_213943984981_item	2280655	et	3	main
millest	doc_213943984981_item	2280661	et	3	main
jutt	doc_213943984981_item	2280663	et	3	main
tõlge	doc_213943984981_item	2280670	et	3	main
all	doc_213943984981_item	2280676	et	3	main
max	doc_213943984981_item	2280679	et	4	main
jäetud	doc_213943984981_item	2280685	et	4	main
tõlkimata	doc_213943984981_item	2280686	et	4	main
b	doc_213943984981_item	2280687	et	4	main
pisiasjad	doc_213943984981_item	2280723	et	3	main
ma	doc_213943984981_item	2280725	et	3	main
olid	doc_213943984981_item	2280738	et	4	main
vead	doc_213943984981_item	2280741	et	4	main
eelmises	doc_213943984981_item	2280743	et	3	main
kasti	doc_213943984981_item	2280755	et	4	main
oleks	doc_213943984981_item	2280757	et	3	main
heledal	doc_213943984981_item	2280768	et	3	main
taustal	doc_213943984981_item	2280769	et	3	main
kõik	doc_213943984981_item	2280775	et	4	main
nimed	doc_213943984981_item	2280776	et	3	main
sarjas	doc_213943984981_item	2280777	et	4	main
sageli	doc_213943984981_item	2280781	et	3	main
ilmunud	doc_213943984981_item	2280790	et	4	main
õigeaegselt	doc_213943984981_item	2280792	et	4	main
suu	doc_213943984981_item	2280796	et	4	main
ekraanilt	doc_213943984981_item	2280800	et	3	main
kõnevooru	doc_213943984981_item	2280802	et	4	main
rääkis	doc_213943984981_item	2280811	et	3	main
ajal	doc_213943984981_item	2280821	et	4	main
teksti	doc_213943984981_item	2280823	et	4	main
kuna	doc_213943984981_item	2280824	et	3	main
on	doc_213943984981_item	2280833	et	4	main
jälgida	doc_213943984981_item	2280838	et	3	main
loeb	doc_213943984981_item	2280847	et	3	main
või	doc_213943984981_item	2280848	et	4	main
tõlkija	doc_213943984981_item	2280869	et	4	main
vormistus	doc_213943984981_item	2280871	et	4	main
paigutus	doc_213943984981_item	2280874	et	4	main
ning	doc_213943984981_item	2280881	et	3	main
asemel	doc_213943984981_item	2280883	et	4	main
märgitud	doc_213943984981_item	2280885	et	4	main
tõlkis	doc_213943984981_item	2280886	et	3	main
üldmulje	doc_213943984981_item	2280887	et	4	main
vaatleja	doc_213943984981_item	2280893	et	4	main
mingeid	doc_213943984981_item	2280896	et	3	main
ja	doc_213943984981_item	2280898	et	3	main
subtiitrite	doc_213943984981_item	2280902	et	4	main
kujundamise	doc_213943984981_item	2280903	et	4	main
mcguire	doc_213943984981_item	2280906	et	4	main
filmis	doc_213943984981_item	2280909	et	4	main
ole	doc_213943984981_item	2280911	et	4	main
nii	doc_213943984981_item	2280912	et	3	main
palju	doc_213943984981_item	2280913	et	4	main
dialooge	doc_213943984981_item	2280914	et	3	main
oleks	doc_213943984981_item	2280916	et	3	main
istuda	doc_213943984981_item	2280918	et	3	main
ja	doc_213943984981_item	2280921	et	3	main
jälgida	doc_213943984981_item	2280933	et	3	main
saab	doc_213943984981_item	2280935	et	3	main
ekraanil	doc_213943984981_item	2280937	et	3	main
kaudu	doc_213943984981_item	2280940	et	3	main
milles	doc_213943984981_item	2280943	et	3	main
viga	doc_213943984981_item	2280945	et	4	main
tõlge	doc_213943984981_item	2280947	et	3	main
või	doc_213943984981_item	2280949	et	4	main
filmis	doc_213943984981_item	2280954	et	4	main
kus	doc_213943984981_item	2280956	et	3	main
tuttav	doc_213943984981_item	2280967	et	3	main
ei	doc_213943984981_item	2280972	et	4	main
tõlkida	doc_213943984981_item	2281011	et	3	main
analüüsin	doc_213943984981_item	2280558	et	3	main
paigutust	doc_213943984981_item	2280561	et	4	main
ka	doc_213943984981_item	2280564	et	3	main
melodramaatilise	doc_213943984981_item	2280572	et	3	main
vaprad	doc_213943984981_item	2280574	et	3	main
tv-3	doc_213943984981_item	2280577	et	4	main
sarja	doc_213943984981_item	2280579	et	4	main
tütred	doc_213943984981_item	2280581	et	3	main
kutsuge	doc_213943984981_item	2280582	et	3	main
politseiakadeemia	doc_213943984981_item	2280593	et	4	main
hea	doc_213943984981_item	2280604	et	4	main
mõnede	doc_213943984981_item	2280606	et	3	main
kallal	doc_213943984981_item	2280608	et	4	main
norida	doc_213943984981_item	2280610	et	3	main
alati	doc_213943984981_item	2280613	et	4	main
sarjas	doc_213943984981_item	2280630	et	4	main
ekraanil	doc_213943984981_item	2280636	et	3	main
et	doc_213943984981_item	2280640	et	3	main
jõudnud	doc_213943984981_item	2280643	et	4	main
läbi	doc_213943984981_item	2280645	et	4	main
lugeda	doc_213943984981_item	2280646	et	3	main
ei	doc_213943984981_item	2280653	et	4	main
aru	doc_213943984981_item	2280656	et	4	main
kes	doc_213943984981_item	2280658	et	4	main
või	doc_213943984981_item	2280669	et	4	main
ebatäpne	doc_213943984981_item	2280672	et	3	main
no	doc_213943984981_item	2280678	et	3	main
max	doc_213943984981_item	2280681	et	4	main
osa	doc_213943984981_item	2280683	et	4	main
on	doc_213943984981_item	2280684	et	4	main
okey	doc_213943984981_item	2280688	et	4	main
pole	doc_213943984981_item	2280689	et	3	main
viga	doc_213943984981_item	2280690	et	4	main
ebatäpne	doc_213943984981_item	2280691	et	3	main
tõlge	doc_213943984981_item	2280692	et	3	main
c	doc_213943984981_item	2280693	et	4	main
no	doc_213943984981_item	2280694	et	3	main
ei	doc_213943984981_item	2280696	et	4	main
4	doc_213943984981_item	2280697	et	2	main
subtiitrite	doc_213943984981_item	2280698	et	4	main
nähtavus	doc_213943984981_item	2280699	et	4	main
ekraanil	doc_213943984981_item	2280700	et	3	main
oli	doc_213943984981_item	2280701	et	3	main
hea	doc_213943984981_item	2280702	et	4	main
ashli	doc_213943984981_item	2280695	et	4	main
kuna	doc_213943984981_item	2280703	et	3	main
toimus	doc_213943984981_item	2280705	et	3	main
tegevus	doc_213943984981_item	2280704	et	4	main
tumedas	doc_213943984981_item	2280706	et	3	main
ruumissiis	doc_213943984981_item	2280707	et	4	main
puudusid	doc_213943984981_item	2280708	et	4	main
valged	doc_213943984981_item	2280709	et	3	main
kohad	doc_213943984981_item	2280710	et	4	main
mis	doc_213943984981_item	2280711	et	4	main
oleks	doc_213943984981_item	2280712	et	3	main
raskendanud	doc_213943984981_item	2280713	et	4	main
subtiitrite	doc_213943984981_item	2280714	et	4	main
lugemist	doc_213943984981_item	2280715	et	4	main
5	doc_213943984981_item	2280716	et	2	main
kursiivi	doc_213943984981_item	2280717	et	4	main
ei	doc_213943984981_item	2280718	et	4	main
kasutatud	doc_213943984981_item	2280719	et	4	main
need	doc_213943984981_item	2280720	et	3	main
n-ö	doc_213943984981_item	2280722	et	4	main
just	doc_213943984981_item	2280727	et	3	main
sarjas	doc_213943984981_item	2280729	et	4	main
mcleodi	doc_213943984981_item	2280730	et	4	main
tütred	doc_213943984981_item	2280731	et	3	main
kutsuge	doc_213943984981_item	2280732	et	3	main
mind	doc_213943984981_item	2280733	et	4	main
kanal	doc_213943984981_item	2280735	et	4	main
samad	doc_213943984981_item	2280740	et	3	main
kuna	doc_213943984981_item	2280746	et	3	main
toimub	doc_213943984981_item	2280748	et	3	main
looduses	doc_213943984981_item	2280749	et	4	main
siis	doc_213943984981_item	2280750	et	3	main
musta	doc_213943984981_item	2280754	et	4	main
millest	doc_213943984981_item	2280760	et	3	main
räägivad	doc_213943984981_item	2280761	et	3	main
tegelased	doc_213943984981_item	2280762	et	3	main
musta	doc_213943984981_item	2280763	et	4	main
kasti	doc_213943984981_item	2280764	et	4	main
kasutamine	doc_213943984981_item	2280765	et	4	main
subtiitrite	doc_213943984981_item	2280766	et	4	main
mida	doc_213943984981_item	2280724	et	4	main
sarjas	doc_213943984981_item	2280744	et	4	main
tegevus	doc_213943984981_item	2280747	et	4	main
näitamiseks	doc_213943984981_item	2280753	et	4	main
on	doc_213943984981_item	2280770	et	4	main
lahendus	doc_213943984981_item	2280772	et	4	main
ei	doc_213943984981_item	2280778	et	4	main
olnud	doc_213943984981_item	2280779	et	4	main
tegelase	doc_213943984981_item	2280783	et	3	main
3	doc_213943984981_item	2280786	et	2	main
alati	doc_213943984981_item	2280788	et	4	main
kui	doc_213943984981_item	2280794	et	3	main
enne	doc_213943984981_item	2280801	et	4	main
lõppu	doc_213943984981_item	2280803	et	4	main
4	doc_213943984981_item	2280804	et	2	main
mõnedes	doc_213943984981_item	2280805	et	3	main
jäi	doc_213943984981_item	2280807	et	3	main
kes	doc_213943984981_item	2280809	et	4	main
olnud	doc_213943984981_item	2280814	et	4	main
kahte	doc_213943984981_item	2280829	et	4	main
korraga	doc_213943984981_item	2280831	et	4	main
endamisi	doc_213943984981_item	2280846	et	3	main
mõtleb	doc_213943984981_item	2280849	et	3	main
parem	doc_213943984981_item	2280851	et	4	main
vaheldus	doc_213943984981_item	2280858	et	4	main
ei	doc_213943984981_item	2280861	et	4	main
ja	doc_213943984981_item	2280864	et	3	main
6	doc_213943984981_item	2280866	et	2	main
lõpus	doc_213943984981_item	2280868	et	4	main
oli	doc_213943984981_item	2280872	et	3	main
oli	doc_213943984981_item	2280884	et	3	main
ei	doc_213943984981_item	2280894	et	4	main
märka	doc_213943984981_item	2280895	et	4	main
ei	doc_213943984981_item	2280899	et	4	main
norida	doc_213943984981_item	2280901	et	3	main
tv-3	doc_213943984981_item	2280907	et	4	main
lugeda	doc_213943984981_item	2280923	et	3	main
ole	doc_213943984981_item	2280925	et	4	main
midagi	doc_213943984981_item	2280926	et	4	main
hirmsat	doc_213943984981_item	2280927	et	3	main
tegevuse	doc_213943984981_item	2280939	et	4	main
ebatäpne	doc_213943984981_item	2280951	et	3	main
itaalia	doc_213943984981_item	2280959	et	4	main
keeles	doc_213943984981_item	2280960	et	4	main
oli	doc_213943984981_item	2280966	et	3	main
arusaadav	doc_213943984981_item	2280969	et	4	main
gracia	doc_213943984981_item	2280971	et	4	main
küll	doc_213943984981_item	2280974	et	4	main
õigekirjutust	doc_213943984981_item	2280977	et	3	main
tuleks	doc_213943984981_item	2281009	et	4	main
3	doc_213943984981_item	2281012	et	2	main
ekraanil	doc_213943984981_item	2281015	et	3	main
kiirusega	doc_213943984981_item	2281017	et	4	main
on	doc_213943984981_item	2281020	et	4	main
ka	doc_213943984981_item	2281021	et	3	main
perefilm	doc_213943984981_item	2281026	et	3	main
vaatavad	doc_213943984981_item	2281029	et	4	main
lapsed	doc_213943984981_item	2281031	et	3	main
kes	doc_213943984981_item	2281032	et	4	main
aeglasemalt	doc_213943984981_item	2281034	et	4	main
kõik	doc_213943984981_item	2281041	et	4	main
subtiitrite	doc_213943984981_item	2281051	et	4	main
on	doc_213943984981_item	2281053	et	4	main
minu	doc_213943984981_item	2281072	et	3	main
olen	doc_213943984981_item	2281076	et	3	main
nii	doc_213943984981_item	2281078	et	3	main
kordi	doc_213943984981_item	2281080	et	4	main
et	doc_213943984981_item	2281081	et	3	main
kõik	doc_213943984981_item	2281082	et	4	main
on	doc_213943984981_item	2281083	et	4	main
arusaadav	doc_213943984981_item	2281084	et	4	main
subtiitrite	doc_213943984981_item	2281093	et	4	main
mitte	doc_213943984981_item	2281096	et	3	main
nimed	doc_213943984981_item	2281098	et	3	main
sageli	doc_213943984981_item	2281103	et	3	main
poole	doc_213943984981_item	2281106	et	4	main
sõnaühend	doc_213943984981_item	2281112	et	3	main
söör	doc_213943984981_item	2281114	et	3	main
tagaplaanil	doc_213943984981_item	2281116	et	4	main
alati	doc_213943984981_item	2281124	et	4	main
ekraanile	doc_213943984981_item	2281129	et	3	main
kui	doc_213943984981_item	2281130	et	3	main
hea	doc_213943984981_item	2280771	et	4	main
2	doc_213943984981_item	2280773	et	2	main
mitte	doc_213943984981_item	2280774	et	3	main
helindatud	doc_213943984981_item	2280780	et	4	main
poole	doc_213943984981_item	2280784	et	4	main
subtiitrid	doc_213943984981_item	2280791	et	4	main
ekraanile	doc_213943984981_item	2280793	et	3	main
tegelane	doc_213943984981_item	2280795	et	3	main
võimalik	doc_213943984981_item	2280815	et	3	main
ekraanil	doc_213943984981_item	2280817	et	3	main
ja	doc_213943984981_item	2280819	et	3	main
samal	doc_213943984981_item	2280820	et	3	main
asja	doc_213943984981_item	2280830	et	4	main
tundub	doc_213943984981_item	2280842	et	3	main
oleks	doc_213943984981_item	2280850	et	3	main
subtiitrid	doc_213943984981_item	2280852	et	4	main
panna	doc_213943984981_item	2280853	et	4	main
kursiiviga	doc_213943984981_item	2280854	et	3	main
seejuures	doc_213943984981_item	2280855	et	3	main
mingi	doc_213943984981_item	2280857	et	4	main
lugemine	doc_213943984981_item	2280860	et	4	main
väsitavaks	doc_213943984981_item	2280865	et	4	main
sarja	doc_213943984981_item	2280867	et	4	main
ei	doc_213943984981_item	2280875	et	4	main
keskel	doc_213943984981_item	2280877	et	3	main
vaid	doc_213943984981_item	2280878	et	3	main
vasakus	doc_213943984981_item	2280879	et	4	main
tõlkinud	doc_213943984981_item	2280882	et	4	main
taha	doc_213943984981_item	2280900	et	4	main
ei	doc_213943984981_item	2280910	et	4	main
vaja	doc_213943984981_item	2280917	et	4	main
ees	doc_213943984981_item	2280920	et	4	main
ei	doc_213943984981_item	2280929	et	4	main
1	doc_213943984981_item	2280946	et	2	main
nt	doc_213943984981_item	2280952	et	4	main
moment	doc_213943984981_item	2280955	et	3	main
vestlesid	doc_213943984981_item	2280958	et	4	main
keelne	doc_213943984981_item	2280963	et	3	main
vaatajale	doc_213943984981_item	2280970	et	4	main
itaalia	doc_213943984981_item	2280975	et	4	main
samuti	doc_213943984981_item	2281010	et	3	main
vaheldusid	doc_213943984981_item	2281014	et	4	main
keskmise	doc_213943984981_item	2281016	et	3	main
ja	doc_213943984981_item	2281018	et	3	main
mitte	doc_213943984981_item	2280787	et	3	main
ei	doc_213943984981_item	2280789	et	4	main
avas	doc_213943984981_item	2280797	et	4	main
ja	doc_213943984981_item	2280798	et	3	main
kadusid	doc_213943984981_item	2280799	et	4	main
ebaselgeks	doc_213943984981_item	2280808	et	3	main
just	doc_213943984981_item	2280810	et	3	main
silmadega	doc_213943984981_item	2280812	et	3	main
soovisin	doc_213943984981_item	2280825	et	4	main
kõike	doc_213943984981_item	2280826	et	4	main
lugeda	doc_213943984981_item	2280828	et	3	main
teksti	doc_213943984981_item	2280836	et	4	main
5	doc_213943984981_item	2280840	et	2	main
et	doc_213943984981_item	2280843	et	3	main
kui	doc_213943984981_item	2280844	et	3	main
igavaks	doc_213943984981_item	2280863	et	4	main
subtiitrite	doc_213943984981_item	2280870	et	4	main
ebakorrektne	doc_213943984981_item	2280873	et	3	main
on	doc_213943984981_item	2280888	et	4	main
muidugi	doc_213943984981_item	2280889	et	4	main
hea	doc_213943984981_item	2280890	et	4	main
kuna	doc_213943984981_item	2280891	et	3	main
juures	doc_213943984981_item	2280904	et	4	main
selles	doc_213943984981_item	2280908	et	4	main
et	doc_213943984981_item	2280915	et	3	main
lugeda	doc_213943984981_item	2280822	et	3	main
läbi	doc_213943984981_item	2280827	et	4	main
teha	doc_213943984981_item	2280832	et	3	main
raske-	doc_213943984981_item	2280834	et	4	main
lugeda	doc_213943984981_item	2280835	et	3	main
ja	doc_213943984981_item	2280837	et	3	main
tegevust	doc_213943984981_item	2280839	et	4	main
mulle	doc_213943984981_item	2280841	et	4	main
tegelane	doc_213943984981_item	2280845	et	3	main
toimub	doc_213943984981_item	2280856	et	3	main
ja	doc_213943984981_item	2280859	et	3	main
muutu	doc_213943984981_item	2280862	et	4	main
olnud	doc_213943984981_item	2280876	et	4	main
nurgas	doc_213943984981_item	2280880	et	3	main
tavaline	doc_213943984981_item	2280892	et	4	main
pisiasju	doc_213943984981_item	2280897	et	3	main
lizzi	doc_213943984981_item	2280905	et	4	main
teleri	doc_213943984981_item	2280919	et	3	main
tähelepanelikult	doc_213943984981_item	2280922	et	4	main
kõiki	doc_213943984981_item	2280931	et	4	main
selgeks	doc_213943984981_item	2280936	et	3	main
toimuva	doc_213943984981_item	2280938	et	4	main
te	doc_213943984981_item	2280941	et	4	main
küsitite	doc_213943984981_item	2280942	et	3	main
siis	doc_213943984981_item	2280944	et	3	main
puudus	doc_213943984981_item	2280948	et	4	main
tegelased	doc_213943984981_item	2280957	et	3	main
üks	doc_213943984981_item	2280961	et	3	main
itaalia	doc_213943984981_item	2280962	et	4	main
sõna	doc_213943984981_item	2280964	et	4	main
tea	doc_213943984981_item	2280973	et	4	main
laulu	doc_213943984981_item	2281007	et	4	main
arusaadav	doc_213943984981_item	2281022	et	4	main
film	doc_213943984981_item	2281024	et	3	main
seda	doc_213943984981_item	2281028	et	3	main
ka	doc_213943984981_item	2281030	et	3	main
loevad	doc_213943984981_item	2281033	et	3	main
kui	doc_213943984981_item	2281035	et	3	main
ei	doc_213943984981_item	2281039	et	4	main
helindatud	doc_213943984981_item	2281043	et	4	main
et	doc_213943984981_item	2281050	et	3	main
kogu	doc_213943984981_item	2281058	et	4	main
ma	doc_213943984981_item	2281075	et	3	main
palju	doc_213943984981_item	2281079	et	4	main
paar	doc_213943984981_item	2281091	et	3	main
kujundamisel	doc_213943984981_item	2281094	et	4	main
helindatud	doc_213943984981_item	2281102	et	4	main
tegelase	doc_213943984981_item	2281105	et	3	main
kadettide	doc_213943984981_item	2281109	et	3	main
kõnelused	doc_213943984981_item	2281118	et	4	main
jäid	doc_213943984981_item	2281119	et	4	main
ei	doc_213943984981_item	2280924	et	4	main
kui	doc_213943984981_item	2280928	et	3	main
jõua	doc_213943984981_item	2280930	et	4	main
subtiitreid	doc_213943984981_item	2280932	et	4	main
kõik	doc_213943984981_item	2280934	et	4	main
oli	doc_213943984981_item	2280950	et	3	main
oli	doc_213943984981_item	2280953	et	3	main
tekstis	doc_213943984981_item	2280965	et	3	main
ja	doc_213943984981_item	2280968	et	3	main
keele	doc_213943984981_item	2280976	et	4	main
aga	doc_213943984981_item	2280978	et	3	main
tean	doc_213943984981_item	2280979	et	3	main
et	doc_213943984981_item	2280980	et	3	main
see	doc_213943984981_item	2280981	et	3	main
tähandab	doc_213943984981_item	2280982	et	4	main
aitähh	doc_213943984981_item	2280983	et	4	main
ja	doc_213943984981_item	2280984	et	3	main
teine	doc_213943984981_item	2280985	et	3	main
prego	doc_213943984981_item	2280987	et	4	main
ausalt	doc_213943984981_item	2280988	et	4	main
sõna	doc_213943984981_item	2280986	et	4	main
ei	doc_213943984981_item	2280989	et	4	main
tea	doc_213943984981_item	2280990	et	4	main
tõlget	doc_213943984981_item	2280991	et	3	main
järelikult	doc_213943984981_item	2280992	et	3	main
on	doc_213943984981_item	2280993	et	4	main
vajalik	doc_213943984981_item	2280994	et	3	main
tõlge	doc_213943984981_item	2280995	et	3	main
2	doc_213943984981_item	2280996	et	2	main
filmis	doc_213943984981_item	2280997	et	4	main
olid	doc_213943984981_item	2280998	et	4	main
ka	doc_213943984981_item	2280999	et	3	main
mis	doc_213943984981_item	2281001	et	4	main
olid	doc_213943984981_item	2281002	et	4	main
laulud	doc_213943984981_item	2281000	et	3	main
jäätud	doc_213943984981_item	2281003	et	4	main
tõlkimata	doc_213943984981_item	2281004	et	4	main
arvan	doc_213943984981_item	2281005	et	3	main
et	doc_213943984981_item	2281006	et	3	main
algust	doc_213943984981_item	2281008	et	4	main
subtiitrid	doc_213943984981_item	2281013	et	4	main
see	doc_213943984981_item	2281019	et	3	main
ja	doc_213943984981_item	2281027	et	3	main
vanemad	doc_213943984981_item	2281036	et	4	main
tihti	doc_213943984981_item	2281044	et	3	main
üsna	doc_213943984981_item	2281054	et	3	main
ja	doc_213943984981_item	2281056	et	3	main
lemmikfilm	doc_213943984981_item	2281073	et	3	main
näinud	doc_213943984981_item	2281077	et	4	main
ilma	doc_213943984981_item	2281085	et	4	main
sõnadeta	doc_213943984981_item	2281086	et	3	main
m	doc_213943984981_item	2281087	et	4	main
ä	doc_213943984981_item	2281088	et	4	main
viga	doc_213943984981_item	2281092	et	4	main
kõik	doc_213943984981_item	2281097	et	4	main
puudus	doc_213943984981_item	2281104	et	4	main
nt	doc_213943984981_item	2281108	et	4	main
nimed	doc_213943984981_item	2281110	et	3	main
jah	doc_213943984981_item	2281113	et	3	main
muidugi	doc_213943984981_item	2281120	et	4	main
subtiitrid	doc_213943984981_item	2281127	et	4	main
õigeaegselt	doc_213943984981_item	2281128	et	4	main
avas	doc_213943984981_item	2281133	et	4	main
enne	doc_213943984981_item	2281137	et	4	main
subtiitrid	doc_213943984981_item	2281141	et	4	main
keskmise	doc_213943984981_item	2281144	et	3	main
kui	doc_213943984981_item	2281152	et	3	main
kokkuvõttes	doc_213943984981_item	2281167	et	3	main
on	doc_213943984981_item	2281174	et	4	main
vaadata	doc_213943984981_item	2281180	et	4	main
ei	doc_213943984981_item	2281187	et	4	main
teist	doc_213943984981_item	2281189	et	4	main
alternattivi	doc_213943984981_item	2281190	et	4	main
subtiitrite	doc_213943984981_item	2281195	et	4	main
filmi	doc_213943984981_item	2281205	et	4	main
eestikeelsed	doc_213943984981_item	2281210	et	3	main
subtiitrid	doc_213943984981_item	2281211	et	4	main
ei	doc_213943984981_item	2281212	et	4	main
ole	doc_213943984981_item	2281213	et	4	main
4	doc_213943984981_item	2281037	et	2	main
vahel	doc_213943984981_item	2281038	et	4	main
olnud	doc_213943984981_item	2281040	et	4	main
puudus	doc_213943984981_item	2281045	et	4	main
inimeste	doc_213943984981_item	2281047	et	3	main
poole	doc_213943984981_item	2281048	et	4	main
arvan	doc_213943984981_item	2281049	et	3	main
informatsioon	doc_213943984981_item	2281059	et	3	main
on	doc_213943984981_item	2281060	et	4	main
filmis	doc_213943984981_item	2281061	et	4	main
ja	doc_213943984981_item	2281062	et	3	main
põhiidee	doc_213943984981_item	2281063	et	4	main
ei	doc_213943984981_item	2281064	et	4	main
kao	doc_213943984981_item	2281065	et	4	main
politseiakadeemia	doc_213943984981_item	2281066	et	4	main
3	doc_213943984981_item	2281067	et	2	main
kanal	doc_213943984981_item	2281068	et	4	main
2	doc_213943984981_item	2281069	et	2	main
see	doc_213943984981_item	2281070	et	3	main
on	doc_213943984981_item	2281071	et	4	main
kuna	doc_213943984981_item	2281023	et	3	main
on	doc_213943984981_item	2281025	et	4	main
nimed	doc_213943984981_item	2281042	et	3	main
pöördumine	doc_213943984981_item	2281046	et	4	main
kujundus	doc_213943984981_item	2281052	et	4	main
hea	doc_213943984981_item	2281055	et	4	main
korrektne	doc_213943984981_item	2281057	et	3	main
rkasin	doc_213943984981_item	2281089	et	4	main
1	doc_213943984981_item	2281095	et	2	main
olnud	doc_213943984981_item	2281101	et	4	main
toimuvad	doc_213943984981_item	2281117	et	4	main
tõlkimata	doc_213943984981_item	2281121	et	4	main
ja	doc_213943984981_item	2281134	et	3	main
lõppu	doc_213943984981_item	2281139	et	4	main
kiirusega	doc_213943984981_item	2281145	et	4	main
muidugi	doc_213943984981_item	2281172	et	4	main
parem	doc_213943984981_item	2281173	et	4	main
üheaegselt	doc_213943984981_item	2281182	et	4	main
on	doc_213943984981_item	2281197	et	4	main
ma	doc_213943984981_item	2281206	et	3	main
öelda	doc_213943984981_item	2281208	et	4	main
sai	doc_213943984982_item	2281228	et	4	main
mul	doc_213943984982_item	2281230	et	3	main
nimi	doc_213943984982_item	2281238	et	3	main
palju	doc_213943984982_item	2281253	et	4	main
ta	doc_213943984982_item	2281258	et	4	main
noorem	doc_213943984982_item	2281261	et	4	main
meie	doc_213943984982_item	2281283	et	4	main
hommikul	doc_213943984982_item	2281289	et	3	main
sibulat	doc_213943984982_item	2281296	et	3	main
märkasin	doc_213943984982_item	2281304	et	3	main
rea	doc_213943984982_item	2281308	et	3	main
väga	doc_213943984982_item	2281312	et	3	main
naabri	doc_213943984982_item	2281319	et	3	main
natukene	doc_213943984982_item	2281326	et	4	main
vanem	doc_213943984982_item	2281327	et	4	main
minu	doc_213943984982_item	2281329	et	3	main
minu	doc_213943984982_item	2281331	et	3	main
kangekaelne	doc_213943984982_item	2281336	et	3	main
teda	doc_213943984982_item	2281339	et	4	main
aga	doc_213943984982_item	2281341	et	3	main
talle	doc_213943984982_item	2281349	et	4	main
lihtsalt	doc_213943984982_item	2281355	et	4	main
siis	doc_213943984982_item	2281359	et	3	main
mul	doc_213943984982_item	2281360	et	3	main
tekkis	doc_213943984982_item	2281361	et	3	main
võib	doc_213943984982_item	2281367	et	3	main
on	doc_213943984982_item	2281405	et	4	main
mida	doc_213943984981_item	2281074	et	4	main
ainult	doc_213943984981_item	2281090	et	4	main
sarjas	doc_213943984981_item	2281099	et	4	main
ei	doc_213943984981_item	2281100	et	4	main
pöördumine	doc_213943984981_item	2281107	et	4	main
ja	doc_213943984981_item	2281111	et	3	main
2	doc_213943984981_item	2281115	et	2	main
3	doc_213943984981_item	2281122	et	2	main
ei	doc_213943984981_item	2281125	et	4	main
ilmunud	doc_213943984981_item	2281126	et	4	main
tegelane	doc_213943984981_item	2281131	et	3	main
kõnevooru	doc_213943984981_item	2281138	et	4	main
filmis	doc_213943984981_item	2281146	et	4	main
oli	doc_213943984981_item	2281147	et	3	main
esikohal	doc_213943984981_item	2281148	et	4	main
seal	doc_213943984981_item	2281149	et	4	main
tegevus	doc_213943984981_item	2281151	et	4	main
filmi	doc_213943984981_item	2281178	et	4	main
kui	doc_213943984981_item	2281179	et	3	main
lugeda	doc_213943984981_item	2281183	et	3	main
kui	doc_213943984981_item	2281186	et	3	main
parem	doc_213943984981_item	2281193	et	4	main
korrektne	doc_213943984981_item	2281198	et	3	main
ja	doc_213943984981_item	2281199	et	3	main
neli	doc_213943984981_item	2281204	et	3	main
nii	doc_213943984981_item	2281214	et	3	main
halvad	doc_213943984981_item	2281215	et	4	main
varsti	doc_213943984982_item	2281234	et	3	main
saab	doc_213943984982_item	2281235	et	3	main
vaatamata	doc_213943984982_item	2281241	et	4	main
ta	doc_213943984982_item	2281244	et	4	main
tukastama	doc_213943984982_item	2281252	et	3	main
näiteks	doc_213943984982_item	2281254	et	4	main
ainult	doc_213943984982_item	2281275	et	4	main
eelmisel	doc_213943984982_item	2281280	et	3	main
juhtus	doc_213943984982_item	2281282	et	3	main
juhtum	doc_213943984982_item	2281287	et	3	main
ja	doc_213943984982_item	2281292	et	3	main
porgandit	doc_213943984982_item	2281298	et	3	main
ühel	doc_213943984982_item	2281301	et	3	main
ma	doc_213943984982_item	2281303	et	3	main
väga	doc_213943984982_item	2281305	et	3	main
ilusat	doc_213943984982_item	2281306	et	3	main
olid	doc_213943984982_item	2281311	et	4	main
tegi	doc_213943984982_item	2281321	et	4	main
ta	doc_213943984982_item	2281323	et	4	main
ma	doc_213943984982_item	2281337	et	3	main
õpetada	doc_213943984982_item	2281340	et	3	main
kahjuks	doc_213943984982_item	2281342	et	4	main
isegi	doc_213943984982_item	2281347	et	4	main
pistisin	doc_213943984982_item	2281348	et	4	main
aga	doc_213943984982_item	2281353	et	3	main
ära	doc_213943984982_item	2281358	et	4	main
või	doc_213943984982_item	2281363	et	4	main
olla	doc_213943984982_item	2281368	et	3	main
ei	doc_213943984982_item	2281371	et	4	main
kindel	doc_213943984982_item	2281373	et	3	main
essee	doc_213943984983_item	2281409	et	4	main
minu	doc_213943984983_item	2281411	et	3	main
oli	doc_213943984983_item	2281419	et	3	main
tark	doc_213943984983_item	2281423	et	3	main
ema	doc_213943984983_item	2281430	et	4	main
suvilas	doc_213943984983_item	2281433	et	3	main
pärast	doc_213943984983_item	2281451	et	4	main
käisid	doc_213943984983_item	2281465	et	4	main
minu	doc_213943984983_item	2281468	et	3	main
kord	doc_213943984983_item	2281476	et	4	main
piima	doc_213943984983_item	2281478	et	4	main
nende	doc_213943984983_item	2281479	et	4	main
kiusata	doc_213943984983_item	2281486	et	4	main
kuid	doc_213943984983_item	2281487	et	4	main
teda	doc_213943984983_item	2281489	et	4	main
ei	doc_213943984983_item	2281490	et	4	main
siis	doc_213943984983_item	2281497	et	3	main
pannud	doc_213943984983_item	2281503	et	4	main
tähele	doc_213943984983_item	2281504	et	3	main
ja	doc_213943984983_item	2281505	et	3	main
vaid	doc_213943984983_item	2281512	et	3	main
meie	doc_213943984984_item	2281521	et	4	main
on	doc_213943984984_item	2281523	et	4	main
suur	doc_213943984984_item	2281524	et	3	main
papagoi	doc_213943984984_item	2281525	et	4	main
tõi	doc_213943984984_item	2281531	et	3	main
mitte	doc_213943984981_item	2281123	et	3	main
ekraanilt	doc_213943984981_item	2281136	et	3	main
kõne	doc_213943984981_item	2281153	et	4	main
seetõttu	doc_213943984981_item	2281154	et	3	main
subtiitrite	doc_213943984981_item	2281155	et	4	main
kiire	doc_213943984981_item	2281156	et	4	main
vahetus	doc_213943984981_item	2281157	et	4	main
ei	doc_213943984981_item	2281158	et	4	main
häirinud	doc_213943984981_item	2281159	et	4	main
tähtsam	doc_213943984981_item	2281160	et	4	main
oli	doc_213943984981_item	2281161	et	3	main
tegevus	doc_213943984981_item	2281162	et	4	main
mis	doc_213943984981_item	2281163	et	4	main
seal	doc_213943984981_item	2281164	et	4	main
tegelikult	doc_213943984981_item	2281165	et	4	main
toimus	doc_213943984981_item	2281166	et	3	main
suu	doc_213943984981_item	2281132	et	4	main
kadusid	doc_213943984981_item	2281135	et	4	main
4	doc_213943984981_item	2281140	et	2	main
vaheldusid	doc_213943984981_item	2281142	et	4	main
ekraanil	doc_213943984981_item	2281143	et	3	main
toimuv	doc_213943984981_item	2281150	et	4	main
tahaks	doc_213943984981_item	2281169	et	3	main
et	doc_213943984981_item	2281171	et	3	main
ja	doc_213943984981_item	2281181	et	3	main
subtiitre	doc_213943984981_item	2281184	et	4	main
siis	doc_213943984981_item	2281191	et	3	main
kujundus	doc_213943984981_item	2281196	et	4	main
tõlge	doc_213943984981_item	2281200	et	3	main
vaadates	doc_213943984981_item	2281202	et	3	main
mille	doc_213943984982_item	2281226	et	3	main
kes	doc_213943984982_item	2281233	et	4	main
on	doc_213943984982_item	2281239	et	4	main
veel	doc_213943984982_item	2281246	et	4	main
suvel	doc_213943984982_item	2281256	et	3	main
oli	doc_213943984982_item	2281259	et	3	main
kass	doc_213943984982_item	2281274	et	3	main
suvel	doc_213943984982_item	2281281	et	3	main
suvilas	doc_213943984982_item	2281284	et	3	main
naljakas	doc_213943984982_item	2281286	et	4	main
läksin	doc_213943984982_item	2281293	et	3	main
mahast	doc_213943984982_item	2281299	et	4	main
teel	doc_213943984982_item	2281302	et	4	main
pandud	doc_213943984982_item	2281314	et	4	main
ma	doc_213943984981_item	2281168	et	3	main
öelda	doc_213943984981_item	2281170	et	4	main
vaadata	doc_213943984981_item	2281175	et	4	main
ja	doc_213943984981_item	2281176	et	3	main
kuulata	doc_213943984981_item	2281177	et	4	main
aga	doc_213943984981_item	2281185	et	3	main
ole	doc_213943984981_item	2281188	et	4	main
on	doc_213943984981_item	2281192	et	4	main
kui	doc_213943984981_item	2281194	et	3	main
täpne	doc_213943984981_item	2281201	et	3	main
need	doc_213943984981_item	2281203	et	3	main
tahaksin	doc_213943984981_item	2281207	et	3	main
et	doc_213943984981_item	2281209	et	3	main
ja	doc_213943984981_item	2281216	et	3	main
on	doc_213943984981_item	2281217	et	4	main
muidugi	doc_213943984981_item	2281218	et	4	main
soov	doc_213943984981_item	2281219	et	3	main
eestikeelseid	doc_213943984981_item	2281220	et	3	main
kanaleid	doc_213943984981_item	2281221	et	4	main
essee	doc_213943984982_item	2281223	et	4	main
tore	doc_213943984982_item	2281224	et	3	main
kass	doc_213943984982_item	2281232	et	3	main
aastaks	doc_213943984982_item	2281236	et	4	main
ta	doc_213943984982_item	2281249	et	4	main
juba	doc_213943984982_item	2281250	et	3	main
kipub	doc_213943984982_item	2281251	et	3	main
kui	doc_213943984982_item	2281257	et	3	main
laisk	doc_213943984982_item	2281273	et	3	main
jööb	doc_213943984982_item	2281277	et	4	main
lamab	doc_213943984982_item	2281279	et	3	main
üks	doc_213943984982_item	2281285	et	3	main
ma	doc_213943984982_item	2281290	et	3	main
tahtsin	doc_213943984982_item	2281295	et	3	main
kõik	doc_213943984982_item	2281309	et	4	main
korralikult	doc_213943984982_item	2281313	et	4	main
aimasin	doc_213943984982_item	2281317	et	3	main
juba	doc_213943984982_item	2281325	et	3	main
kass	doc_213943984982_item	2281333	et	3	main
väga	doc_213943984982_item	2281335	et	3	main
ta	doc_213943984982_item	2281343	et	4	main
ei	doc_213943984982_item	2281344	et	4	main
soovinud	doc_213943984982_item	2281345	et	4	main
ninna	doc_213943984982_item	2281350	et	3	main
mõned	doc_213943984982_item	2281351	et	3	main
jooksis	doc_213943984982_item	2281356	et	4	main
isegi	doc_213943984982_item	2281364	et	4	main
tunne	doc_213943984982_item	2281365	et	4	main
et	doc_213943984982_item	2281366	et	3	main
emased	doc_213943984982_item	2281375	et	4	main
lihtsalt	doc_213943984982_item	2281406	et	4	main
minu	doc_213943984982_item	2281407	et	3	main
arvamus	doc_213943984982_item	2281408	et	3	main
sülekoer	doc_213943984983_item	2281415	et	3	main
loom	doc_213943984983_item	2281418	et	3	main
kartis	doc_213943984983_item	2281427	et	3	main
suvel	doc_213943984983_item	2281429	et	3	main
võttis	doc_213943984983_item	2281435	et	3	main
koera	doc_213943984983_item	2281437	et	4	main
oli	doc_213943984983_item	2281442	et	3	main
see	doc_213943984983_item	2281445	et	3	main
jubedalt	doc_213943984983_item	2281447	et	4	main
tulevad	doc_213943984983_item	2281453	et	4	main
suvilas	doc_213943984983_item	2281464	et	3	main
ja	doc_213943984983_item	2281467	et	3	main
andis	doc_213943984983_item	2281470	et	3	main
piima	doc_213943984983_item	2281472	et	4	main
iga	doc_213943984983_item	2281475	et	4	main
seda	doc_213943984983_item	2281477	et	3	main
püüdis	doc_213943984983_item	2281484	et	3	main
siilid	doc_213943984983_item	2281488	et	3	main
teda	doc_213943984983_item	2281496	et	4	main
vihastas	doc_213943984983_item	2281499	et	3	main
teda	doc_213943984983_item	2281501	et	4	main
haukuma	doc_213943984983_item	2281509	et	3	main
kuid	doc_213943984983_item	2281510	et	4	main
siilid	doc_213943984983_item	2281511	et	3	main
essee	doc_213943984984_item	2281520	et	4	main
ta	doc_213943984984_item	2281530	et	4	main
kuskilt	doc_213943984984_item	2281533	et	4	main
ilus	doc_213943984984_item	2281537	et	4	main
lind	doc_213943984984_item	2281539	et	3	main
tiivadega	doc_213943984984_item	2281541	et	4	main
ta	doc_213943984984_item	2281544	et	4	main
vaadata	doc_213943984981_item	2281222	et	4	main
juhtum	doc_213943984982_item	2281225	et	3	main
tegelaseks	doc_213943984982_item	2281227	et	3	main
loom	doc_213943984982_item	2281229	et	3	main
on	doc_213943984982_item	2281231	et	4	main
tema	doc_213943984982_item	2281237	et	4	main
eesnimi	doc_213943984982_item	2281240	et	3	main
sellele	doc_213943984982_item	2281242	et	4	main
et	doc_213943984982_item	2281243	et	3	main
on	doc_213943984982_item	2281245	et	4	main
väga	doc_213943984982_item	2281247	et	3	main
noor	doc_213943984982_item	2281248	et	3	main
eelmisel	doc_213943984982_item	2281255	et	3	main
veelgi	doc_213943984982_item	2281260	et	4	main
ma	doc_213943984982_item	2281262	et	3	main
püüdsin	doc_213943984982_item	2281263	et	3	main
teda	doc_213943984982_item	2281264	et	4	main
õpetada	doc_213943984982_item	2281265	et	3	main
närilisi	doc_213943984982_item	2281266	et	3	main
jähima	doc_213943984982_item	2281267	et	4	main
aga	doc_213943984982_item	2281268	et	3	main
kahjuks	doc_213943984982_item	2281269	et	4	main
ta	doc_213943984982_item	2281270	et	4	main
on	doc_213943984982_item	2281271	et	4	main
väga	doc_213943984982_item	2281272	et	3	main
sööb	doc_213943984982_item	2281276	et	3	main
ja	doc_213943984982_item	2281278	et	3	main
vara	doc_213943984982_item	2281288	et	4	main
tõusin	doc_213943984982_item	2281291	et	3	main
aeda	doc_213943984982_item	2281294	et	4	main
ja	doc_213943984982_item	2281297	et	3	main
võtta	doc_213943984982_item	2281300	et	3	main
hiirte	doc_213943984982_item	2281307	et	3	main
nad	doc_213943984982_item	2281310	et	3	main
ma	doc_213943984982_item	2281315	et	3	main
järsku	doc_213943984982_item	2281316	et	4	main
et	doc_213943984982_item	2281318	et	3	main
kass	doc_213943984982_item	2281320	et	3	main
seda	doc_213943984982_item	2281322	et	3	main
kui	doc_213943984982_item	2281328	et	3	main
kass	doc_213943984982_item	2281330	et	3	main
oli	doc_213943984982_item	2281334	et	3	main
mina	doc_213943984982_item	2281346	et	4	main
mulje	doc_213943984982_item	2281362	et	4	main
ma	doc_213943984982_item	2281370	et	3	main
ainult	doc_213943984982_item	2281374	et	4	main
oli	doc_213943984983_item	2281413	et	3	main
päris	doc_213943984983_item	2281416	et	4	main
tore	doc_213943984983_item	2281417	et	3	main
oli	doc_213943984983_item	2281421	et	3	main
ja	doc_213943984983_item	2281424	et	3	main
puhkas	doc_213943984983_item	2281432	et	3	main
ja	doc_213943984983_item	2281434	et	3	main
kartis	doc_213943984983_item	2281448	et	3	main
vanaema	doc_213943984983_item	2281469	et	4	main
neile	doc_213943984983_item	2281471	et	4	main
koer	doc_213943984983_item	2281473	et	3	main
ei	doc_213943984983_item	2281494	et	4	main
ei	doc_213943984983_item	2281502	et	4	main
nende	doc_213943984983_item	2281507	et	4	main
on	doc_213943984982_item	2281324	et	4	main
aga	doc_213943984982_item	2281332	et	3	main
püüdsin	doc_213943984982_item	2281338	et	3	main
hiired	doc_213943984982_item	2281352	et	3	main
ta	doc_213943984982_item	2281354	et	4	main
minult	doc_213943984982_item	2281357	et	3	main
aga	doc_213943984982_item	2281369	et	3	main
ole	doc_213943984982_item	2281372	et	4	main
jahivad	doc_213943984982_item	2281377	et	3	main
närilisi	doc_213943984982_item	2281378	et	3	main
kassid	doc_213943984982_item	2281376	et	3	main
ja	doc_213943984982_item	2281379	et	3	main
hiiri	doc_213943984982_item	2281380	et	4	main
sest	doc_213943984982_item	2281381	et	4	main
paljud	doc_213943984982_item	2281382	et	3	main
raamatud	doc_213943984982_item	2281383	et	4	main
kirjutavad	doc_213943984982_item	2281384	et	4	main
ja	doc_213943984982_item	2281386	et	3	main
muinasjutudes	doc_213943984982_item	2281387	et	4	main
on	doc_213943984982_item	2281388	et	4	main
palju	doc_213943984982_item	2281389	et	4	main
sellest	doc_213943984982_item	2281385	et	4	main
juhtumeid	doc_213943984982_item	2281390	et	3	main
et	doc_213943984982_item	2281391	et	3	main
ainult	doc_213943984982_item	2281392	et	4	main
emane	doc_213943984982_item	2281393	et	4	main
kass	doc_213943984982_item	2281394	et	3	main
jahib	doc_213943984982_item	2281395	et	3	main
hiire	doc_213943984982_item	2281396	et	4	main
võib	doc_213943984982_item	2281397	et	3	main
olla	doc_213943984982_item	2281398	et	3	main
see	doc_213943984982_item	2281399	et	3	main
ei	doc_213943984982_item	2281400	et	4	main
ole	doc_213943984982_item	2281401	et	4	main
õige	doc_213943984982_item	2281402	et	4	main
aga	doc_213943984982_item	2281403	et	3	main
see	doc_213943984982_item	2281404	et	3	main
kunagi	doc_213943984983_item	2281410	et	3	main
emal	doc_213943984983_item	2281412	et	3	main
väike	doc_213943984983_item	2281414	et	4	main
ta	doc_213943984983_item	2281420	et	4	main
kuid	doc_213943984983_item	2281426	et	4	main
alati	doc_213943984983_item	2281431	et	4	main
kaasa	doc_213943984983_item	2281438	et	4	main
selle	doc_213943984983_item	2281439	et	4	main
koera	doc_213943984983_item	2281440	et	4	main
eesnimi	doc_213943984983_item	2281443	et	3	main
ja	doc_213943984983_item	2281444	et	3	main
koer	doc_213943984983_item	2281446	et	3	main
limukaid	doc_213943984983_item	2281449	et	3	main
siilid	doc_213943984983_item	2281466	et	3	main
neid	doc_213943984983_item	2281485	et	4	main
ja	doc_213943984983_item	2281492	et	3	main
isegi	doc_213943984983_item	2281493	et	4	main
kui	doc_213943984983_item	2281500	et	3	main
peale	doc_213943984983_item	2281508	et	4	main
tema	doc_213943984983_item	2281514	et	4	main
peale	doc_213943984983_item	2281515	et	4	main
ja	doc_213943984984_item	2281529	et	3	main
on	doc_213943984984_item	2281536	et	4	main
kopeerida	doc_213943984984_item	2281549	et	4	main
lugu	doc_213943984984_item	2281554	et	4	main
ja	doc_213943984984_item	2281588	et	3	main
korda	doc_213943984984_item	2281594	et	4	main
ta	doc_213943984984_item	2281595	et	4	main
kodus	doc_213943984984_item	2281598	et	4	main
on	doc_213943984984_item	2281599	et	4	main
räägiv	doc_213943984984_item	2281600	et	4	main
läks	doc_213943984984_item	2281605	et	3	main
tudeng	doc_213943984985_item	2281619	et	3	main
väga	doc_213943984983_item	2281422	et	3	main
sõbralik	doc_213943984983_item	2281425	et	3	main
kõike	doc_213943984983_item	2281428	et	4	main
oma	doc_213943984983_item	2281436	et	4	main
nimi	doc_213943984983_item	2281441	et	3	main
mis	doc_213943984983_item	2281450	et	4	main
vihma	doc_213943984983_item	2281452	et	4	main
ta	doc_213943984983_item	2281454	et	4	main
hakkas	doc_213943984983_item	2281455	et	3	main
kohe	doc_213943984983_item	2281456	et	4	main
nende	doc_213943984983_item	2281457	et	4	main
peale	doc_213943984983_item	2281458	et	4	main
haukuma	doc_213943984983_item	2281459	et	3	main
kui	doc_213943984983_item	2281460	et	3	main
neid	doc_213943984983_item	2281461	et	4	main
nägi	doc_213943984983_item	2281462	et	3	main
meil	doc_213943984983_item	2281463	et	4	main
tahtis	doc_213943984983_item	2281474	et	3	main
eest	doc_213943984983_item	2281480	et	4	main
ära	doc_213943984983_item	2281481	et	4	main
juua	doc_213943984983_item	2281482	et	3	main
ja	doc_213943984983_item	2281483	et	3	main
kartnud	doc_213943984983_item	2281491	et	4	main
märganud	doc_213943984983_item	2281495	et	4	main
koer	doc_213943984983_item	2281498	et	3	main
hakkas	doc_213943984983_item	2281506	et	3	main
turtsusid	doc_213943984983_item	2281513	et	4	main
ja	doc_213943984983_item	2281516	et	3	main
läksid	doc_213943984983_item	2281517	et	4	main
tagasi	doc_213943984983_item	2281518	et	3	main
metsa	doc_213943984983_item	2281519	et	4	main
peresõpradel	doc_213943984984_item	2281522	et	3	main
on	doc_213943984984_item	2281527	et	4	main
papagoi	doc_213943984984_item	2281535	et	4	main
sinikate	doc_213943984984_item	2281540	et	4	main
rääkida	doc_213943984984_item	2281547	et	3	main
ning	doc_213943984984_item	2281548	et	3	main
oma	doc_213943984984_item	2281550	et	4	main
pereliikmete	doc_213943984984_item	2281551	et	3	main
häälesid	doc_213943984984_item	2281552	et	4	main
tema	doc_213943984984_item	2281557	et	4	main
minu	doc_213943984984_item	2281561	et	3	main
kella	doc_213943984984_item	2281567	et	4	main
eesnimi	doc_213943984984_item	2281585	et	3	main
loomulikult	doc_213943984984_item	2281589	et	4	main
unustas	doc_213943984984_item	2281596	et	3	main
mina	doc_213943984985_item	2281616	et	4	main
olen	doc_213943984985_item	2281617	et	3	main
praegu	doc_213943984985_item	2281618	et	3	main
et	doc_213943984985_item	2281625	et	3	main
õpin	doc_213943984985_item	2281629	et	3	main
elan	doc_213943984985_item	2281636	et	3	main
et	doc_213943984985_item	2281641	et	3	main
minu	doc_213943984985_item	2281647	et	3	main
jaoks	doc_213943984985_item	2281648	et	4	main
viiendal	doc_213943984985_item	2281654	et	3	main
minu	doc_213943984985_item	2281657	et	3	main
sees	doc_213943984985_item	2281666	et	4	main
remont	doc_213943984985_item	2281669	et	3	main
hästi	doc_213943984985_item	2281698	et	3	main
on	doc_213943984985_item	2281700	et	4	main
kõik	doc_213943984985_item	2281708	et	4	main
mul	doc_213943984985_item	2281710	et	3	main
mulle	doc_213943984985_item	2281713	et	4	main
meeldivad	doc_213943984985_item	2281714	et	4	main
ka	doc_213943984985_item	2281715	et	3	main
tüdrukud	doc_213943984985_item	2281716	et	3	main
kellega	doc_213943984985_item	2281717	et	3	main
ma	doc_213943984985_item	2281718	et	3	main
pereisa	doc_213943984984_item	2281526	et	4	main
meremees	doc_213943984984_item	2281528	et	4	main
selle	doc_213943984984_item	2281532	et	4	main
lõunamaadest	doc_213943984984_item	2281534	et	4	main
roheline	doc_213943984984_item	2281538	et	4	main
nokaga	doc_213943984984_item	2281543	et	3	main
isegi	doc_213943984984_item	2281545	et	4	main
lõbus	doc_213943984984_item	2281553	et	4	main
toimus	doc_213943984984_item	2281555	et	3	main
lobisemise	doc_213943984984_item	2281558	et	4	main
tõttu	doc_213943984984_item	2281559	et	4	main
kui	doc_213943984984_item	2281560	et	3	main
ja	doc_213943984984_item	2281568	et	3	main
tuttav	doc_213943984984_item	2281569	et	3	main
hääl	doc_213943984984_item	2281570	et	3	main
küsis	doc_213943984984_item	2281571	et	3	main
kes	doc_213943984984_item	2281572	et	4	main
siin	doc_213943984984_item	2281573	et	4	main
on	doc_213943984984_item	2281574	et	4	main
isa	doc_213943984984_item	2281575	et	4	main
vastas	doc_213943984984_item	2281576	et	4	main
jälle	doc_213943984984_item	2281577	et	3	main
järgnes	doc_213943984984_item	2281578	et	3	main
sama	doc_213943984984_item	2281579	et	4	main
küsimus	doc_213943984984_item	2281580	et	4	main
ma	doc_213943984984_item	2281581	et	3	main
ütlesin	doc_213943984984_item	2281582	et	3	main
ju	doc_213943984984_item	2281583	et	3	main
mina	doc_213943984984_item	2281584	et	4	main
ja	doc_213943984984_item	2281542	et	3	main
oskab	doc_213943984984_item	2281546	et	3	main
just	doc_213943984984_item	2281556	et	3	main
isa	doc_213943984984_item	2281562	et	4	main
tuli	doc_213943984984_item	2281563	et	4	main
nende	doc_213943984984_item	2281564	et	4	main
külla	doc_213943984984_item	2281565	et	4	main
ta	doc_213943984984_item	2281587	et	4	main
küsimust	doc_213943984984_item	2281592	et	4	main
mitu	doc_213943984984_item	2281593	et	4	main
et	doc_213943984984_item	2281597	et	3	main
ajas	doc_213943984984_item	2281602	et	4	main
hiljem	doc_213943984984_item	2281607	et	3	main
selgus	doc_213943984984_item	2281608	et	4	main
naljakas	doc_213943984984_item	2281610	et	4	main
arusaamatus	doc_213943984984_item	2281611	et	4	main
essee	doc_213943984985_item	2281613	et	4	main
elukoha	doc_213943984985_item	2281614	et	4	main
kirjeldamine	doc_213943984985_item	2281615	et	4	main
meditsiinikooli	doc_213943984985_item	2281622	et	4	main
asub	doc_213943984985_item	2281632	et	3	main
kolmandal	doc_213943984985_item	2281637	et	3	main
variant	doc_213943984985_item	2281646	et	3	main
ma	doc_213943984985_item	2281650	et	3	main
liiga	doc_213943984985_item	2281660	et	4	main
raske	doc_213943984985_item	2281661	et	4	main
kõrgemale	doc_213943984985_item	2281663	et	4	main
mulle	doc_213943984985_item	2281695	et	4	main
sobib	doc_213943984985_item	2281697	et	3	main
see	doc_213943984985_item	2281699	et	3	main
suur	doc_213943984985_item	2281701	et	3	main
toas	doc_213943984985_item	2281706	et	3	main
on	doc_213943984985_item	2281727	et	4	main
üür	doc_213943984985_item	2281729	et	3	main
ainult	doc_213943984985_item	2281732	et	4	main
vaja	doc_213943984985_item	2281739	et	4	main
ja	doc_213943984985_item	2281743	et	3	main
internet	doc_213943984985_item	2281748	et	4	main
muidugi	doc_213943984985_item	2281749	et	4	main
elamises	doc_213943984985_item	2281750	et	4	main
või	doc_213943984985_item	2281757	et	4	main
kodus	doc_213943984985_item	2281760	et	4	main
elada	doc_213943984985_item	2281764	et	3	main
ainult	doc_213943984985_item	2281773	et	4	main
on	doc_213943984985_item	2281780	et	4	main
vaja	doc_213943984985_item	2281781	et	4	main
oma	doc_213943984985_item	2281793	et	4	main
ühiselamu	doc_213943984985_item	2281810	et	4	main
olema	doc_213943984985_item	2281815	et	4	main
kella	doc_213943984985_item	2281818	et	4	main
õhtul	doc_213943984985_item	2281820	et	3	main
aga	doc_213943984985_item	2281821	et	3	main
tudengielu	doc_213943984985_item	2281825	et	4	main
mul	doc_213943984985_item	2281826	et	3	main
tean	doc_213943984985_item	2281830	et	3	main
sest	doc_213943984985_item	2281837	et	4	main
tallinnas	doc_213943984985_item	2281838	et	4	main
palju	doc_213943984985_item	2281840	et	4	main
või	doc_213943984985_item	2281848	et	4	main
mõnedele	doc_213943984985_item	2281849	et	3	main
veel	doc_213943984985_item	2281857	et	4	main
olen	doc_213943984985_item	2281863	et	3	main
enam	doc_213943984985_item	2281866	et	4	main
rahul	doc_213943984985_item	2281868	et	4	main
helistas	doc_213943984984_item	2281566	et	3	main
sama	doc_213943984984_item	2281591	et	4	main
papagoi	doc_213943984984_item	2281601	et	4	main
närvi	doc_213943984984_item	2281603	et	4	main
ja	doc_213943984984_item	2281604	et	3	main
see	doc_213943984984_item	2281609	et	3	main
ja	doc_213943984985_item	2281620	et	3	main
ühielamus	doc_213943984985_item	2281623	et	4	main
pärnust	doc_213943984985_item	2281627	et	4	main
mina	doc_213943984985_item	2281635	et	4	main
korrusel	doc_213943984985_item	2281638	et	3	main
ja	doc_213943984985_item	2281639	et	3	main
arvan	doc_213943984985_item	2281640	et	3	main
see	doc_213943984985_item	2281642	et	3	main
kõige	doc_213943984985_item	2281644	et	4	main
elaksin	doc_213943984985_item	2281651	et	3	main
neljandal	doc_213943984985_item	2281652	et	3	main
siis	doc_213943984985_item	2281656	et	3	main
oleks	doc_213943984985_item	2281659	et	3	main
maia	doc_213943984985_item	2281665	et	4	main
tehtud	doc_213943984985_item	2281668	et	4	main
ja	doc_213943984985_item	2281705	et	3	main
on	doc_213943984985_item	2281707	et	4	main
mis	doc_213943984985_item	2281709	et	4	main
on	doc_213943984985_item	2281721	et	4	main
üks	doc_213943984985_item	2281723	et	3	main
suur	doc_213943984985_item	2281724	et	3	main
pluss	doc_213943984985_item	2281725	et	3	main
maksan	doc_213943984985_item	2281731	et	3	main
sada	doc_213943984985_item	2281734	et	4	main
maksta	doc_213943984985_item	2281741	et	4	main
ühiselamus	doc_213943984985_item	2281745	et	4	main
on	doc_213943984985_item	2281746	et	4	main
na	doc_213943984985_item	2281758	et	3	main
parem	doc_213943984985_item	2281763	et	4	main
näiteks	doc_213943984985_item	2281765	et	4	main
ebamugav	doc_213943984985_item	2281767	et	3	main
et	doc_213943984985_item	2281770	et	3	main
vahel	doc_213943984985_item	2281779	et	4	main
alati	doc_213943984985_item	2281788	et	4	main
meie	doc_213943984985_item	2281792	et	4	main
seda	doc_213943984985_item	2281796	et	3	main
väga	doc_213943984985_item	2281807	et	3	main
on	doc_213943984985_item	2281809	et	4	main
külalised	doc_213943984985_item	2281813	et	4	main
on	doc_213943984985_item	2281827	et	4	main
halvem	doc_213943984985_item	2281834	et	4	main
kui	doc_213943984985_item	2281835	et	3	main
elavad	doc_213943984985_item	2281855	et	4	main
nii	doc_213943984985_item	2281860	et	3	main
õpimisest	doc_213943984987_item	2282028	et	4	main
sellel	doc_213943984987_item	2282029	et	4	main
1	doc_213943984987_item	2282034	et	2	main
valisin	doc_213943984987_item	2282037	et	3	main
sellel	doc_213943984987_item	2282049	et	4	main
proovin	doc_213943984987_item	2282052	et	3	main
võimalus	doc_213943984987_item	2282066	et	3	main
mis	doc_213943984987_item	2282075	et	4	main
ja	doc_213943984987_item	2282086	et	3	main
kordas	doc_213943984984_item	2281586	et	3	main
kuulas	doc_213943984984_item	2281590	et	3	main
ära	doc_213943984984_item	2281606	et	4	main
välja	doc_213943984984_item	2281612	et	4	main
elan	doc_213943984985_item	2281621	et	3	main
sellepärast	doc_213943984985_item	2281624	et	3	main
olen	doc_213943984985_item	2281626	et	3	main
aga	doc_213943984985_item	2281628	et	3	main
õpilaskodu	doc_213943984985_item	2281631	et	4	main
viiekorruselises	doc_213943984985_item	2281633	et	4	main
parim	doc_213943984985_item	2281645	et	4	main
jaoks	doc_213943984985_item	2281658	et	4	main
nii	doc_213943984985_item	2281662	et	3	main
käia	doc_213943984985_item	2281664	et	4	main
on	doc_213943984985_item	2281667	et	4	main
tuba	doc_213943984985_item	2281702	et	4	main
helesiniste	doc_213943984985_item	2281703	et	4	main
seinadega	doc_213943984985_item	2281704	et	3	main
vaja	doc_213943984985_item	2281711	et	4	main
on	doc_213943984985_item	2281712	et	4	main
elan	doc_213943984985_item	2281719	et	3	main
neli	doc_213943984985_item	2281733	et	3	main
aga	doc_213943984985_item	2281759	et	3	main
väga	doc_213943984985_item	2281766	et	3	main
on	doc_213943984985_item	2281768	et	4	main
üks	doc_213943984985_item	2281774	et	3	main
korridoris	doc_213943984985_item	2281787	et	4	main
väga	doc_213943984985_item	2281797	et	3	main
on	doc_213943984985_item	2281800	et	4	main
üks	doc_213943984985_item	2281802	et	3	main
asi	doc_213943984985_item	2281803	et	4	main
mis	doc_213943984985_item	2281804	et	4	main
närveerib	doc_213943984985_item	2281805	et	3	main
mind	doc_213943984985_item	2281806	et	4	main
reegel	doc_213943984985_item	2281811	et	3	main
peavad	doc_213943984985_item	2281814	et	4	main
seitsmeni	doc_213943984985_item	2281819	et	3	main
ja	doc_213943984985_item	2281828	et	3	main
mina	doc_213943984985_item	2281836	et	4	main
ühikaid	doc_213943984985_item	2281841	et	4	main
kus	doc_213943984985_item	2281842	et	3	main
ei	doc_213943984985_item	2281844	et	4	main
veel	doc_213943984985_item	2281846	et	4	main
tehtud	doc_213943984985_item	2281847	et	4	main
kellega	doc_213943984985_item	2281853	et	3	main
minu	doc_213943984985_item	2281864	et	3	main
tallinnas	doc_213943984985_item	2281630	et	4	main
hoones	doc_213943984985_item	2281634	et	4	main
on	doc_213943984985_item	2281643	et	4	main
kui	doc_213943984985_item	2281649	et	3	main
või	doc_213943984985_item	2281653	et	4	main
korrusel	doc_213943984985_item	2281655	et	3	main
aga	doc_213943984985_item	2281670	et	3	main
näiteks	doc_213943984985_item	2281671	et	4	main
viiendal	doc_213943984985_item	2281672	et	3	main
korrusel	doc_213943984985_item	2281673	et	3	main
köögis	doc_213943984985_item	2281674	et	3	main
ja	doc_213943984985_item	2281675	et	3	main
vannitoas	doc_213943984985_item	2281676	et	3	main
remont	doc_213943984985_item	2281677	et	3	main
ei	doc_213943984985_item	2281678	et	4	main
ole	doc_213943984985_item	2281679	et	4	main
veel	doc_213943984985_item	2281680	et	4	main
tehtud	doc_213943984985_item	2281681	et	4	main
minu	doc_213943984985_item	2281682	et	3	main
korrusel	doc_213943984985_item	2281683	et	3	main
on	doc_213943984985_item	2281684	et	4	main
aga	doc_213943984985_item	2281685	et	3	main
kõik	doc_213943984985_item	2281686	et	4	main
remonditud	doc_213943984985_item	2281687	et	4	main
ja	doc_213943984985_item	2281688	et	3	main
mugavasti	doc_213943984985_item	2281689	et	3	main
tehtud	doc_213943984985_item	2281690	et	4	main
tuba	doc_213943984985_item	2281691	et	4	main
kus	doc_213943984985_item	2281692	et	3	main
ma	doc_213943984985_item	2281693	et	3	main
elan	doc_213943984985_item	2281694	et	3	main
ka	doc_213943984985_item	2281696	et	3	main
ühiselamuses	doc_213943984985_item	2281720	et	3	main
see	doc_213943984985_item	2281726	et	3	main
eraldi	doc_213943984985_item	2281740	et	4	main
kommunaalmakseid	doc_213943984985_item	2281742	et	3	main
veel	doc_213943984985_item	2281744	et	4	main
miinused	doc_213943984985_item	2281755	et	3	main
on	doc_213943984985_item	2281761	et	4	main
duširuum	doc_213943984985_item	2281778	et	2	main
duširuumi	doc_213943984985_item	2281784	et	2	main
ja	doc_213943984985_item	2281786	et	3	main
keegi	doc_213943984985_item	2281789	et	4	main
ja	doc_213943984985_item	2281791	et	3	main
toas	doc_213943984985_item	2281794	et	3	main
hästi	doc_213943984985_item	2281798	et	3	main
veel	doc_213943984985_item	2281801	et	4	main
see	doc_213943984985_item	2281808	et	3	main
ainult	doc_213943984985_item	2281817	et	4	main
mis	doc_213943984985_item	2281822	et	4	main
teha	doc_213943984985_item	2281823	et	3	main
et	doc_213943984985_item	2281831	et	3	main
paljud	doc_213943984985_item	2281832	et	3	main
on	doc_213943984985_item	2281839	et	4	main
ei	doc_213943984985_item	2281850	et	4	main
inimesed	doc_213943984985_item	2281852	et	3	main
nad	doc_213943984985_item	2281854	et	3	main
või	doc_213943984985_item	2281856	et	4	main
midagi	doc_213943984985_item	2281858	et	4	main
muu	doc_213943984985_item	2281859	et	4	main
mina	doc_213943984985_item	2281862	et	4	main
vähem	doc_213943984985_item	2281867	et	4	main
veel	doc_213943984985_item	2281722	et	4	main
ühiselamu	doc_213943984985_item	2281728	et	4	main
mina	doc_213943984985_item	2281730	et	4	main
krooni	doc_213943984985_item	2281735	et	4	main
kuus	doc_213943984985_item	2281736	et	4	main
ja	doc_213943984985_item	2281737	et	3	main
pole	doc_213943984985_item	2281738	et	3	main
tasuta	doc_213943984985_item	2281747	et	4	main
õpilaskodus	doc_213943984985_item	2281751	et	3	main
on	doc_213943984985_item	2281752	et	4	main
ka	doc_213943984985_item	2281753	et	3	main
oma	doc_213943984985_item	2281754	et	4	main
nii	doc_213943984985_item	2281756	et	3	main
ikkagi	doc_213943984985_item	2281762	et	4	main
see	doc_213943984985_item	2281769	et	3	main
korrusel	doc_213943984985_item	2281771	et	3	main
on	doc_213943984985_item	2281772	et	4	main
köök	doc_213943984985_item	2281775	et	3	main
wc	doc_213943984985_item	2281776	et	4	main
ja	doc_213943984985_item	2281777	et	3	main
oodata	doc_213943984985_item	2281782	et	4	main
millal	doc_213943984985_item	2281783	et	3	main
vabanetakse	doc_213943984985_item	2281785	et	3	main
käib	doc_213943984985_item	2281790	et	3	main
kuulame	doc_213943984985_item	2281795	et	4	main
ja	doc_213943984985_item	2281799	et	3	main
et	doc_213943984985_item	2281812	et	3	main
sees	doc_213943984985_item	2281816	et	4	main
niisugune	doc_213943984985_item	2281824	et	3	main
mina	doc_213943984985_item	2281829	et	4	main
elavad	doc_213943984985_item	2281833	et	4	main
remont	doc_213943984985_item	2281843	et	3	main
ole	doc_213943984985_item	2281845	et	4	main
meeldi	doc_213943984985_item	2281851	et	4	main
et	doc_213943984985_item	2281861	et	3	main
elamiskohaga	doc_213943984985_item	2281865	et	4	main
miks	doc_213943984987_item	2282020	et	4	main
valisin	doc_213943984987_item	2282022	et	3	main
ja	doc_213943984987_item	2282031	et	3	main
miks	doc_213943984987_item	2282035	et	4	main
selle	doc_213943984987_item	2282038	et	4	main
eriala	doc_213943984987_item	2282039	et	4	main
küsimus	doc_213943984987_item	2282041	et	4	main
mõelnud	doc_213943984987_item	2282048	et	4	main
sul	doc_213943984987_item	2282064	et	3	main
on	doc_213943984987_item	2282065	et	4	main
nende	doc_213943984987_item	2282072	et	4	main
tahavad	doc_213943984987_item	2282078	et	3	main
ühesõnaga	doc_213943984987_item	2282080	et	3	main
kirjutada	doc_213943984987_item	2282087	et	3	main
lihtsalt	doc_213943984987_item	2282088	et	4	main
proovida	doc_213943984987_item	2282090	et	3	main
asjas	doc_213943984987_item	2282094	et	3	main
praegu	doc_213943984987_item	2282103	et	3	main
2	doc_213943984987_item	2282112	et	2	main
mida	doc_213943984987_item	2282113	et	4	main
ootan	doc_213943984987_item	2282115	et	3	main
mida	doc_213943984987_item	2282119	et	4	main
hea	doc_213943984987_item	2282125	et	4	main
töökoht	doc_213943984987_item	2282126	et	3	main
igav	doc_213943984987_item	2282139	et	3	main
et	doc_213943984987_item	2282144	et	3	main
olen	doc_213943984987_item	2282145	et	3	main
et	doc_213943984987_item	2282154	et	3	main
õpetati	doc_213943984987_item	2282156	et	3	main
vaja	doc_213943984987_item	2282160	et	4	main
ajakirjanikule	doc_213943984987_item	2282162	et	3	main
sellel	doc_213943984989_item	2282393	et	4	main
on	doc_213943984989_item	2282402	et	4	main
eriala	doc_213943984989_item	2282405	et	4	main
ei	doc_213943984989_item	2282412	et	4	main
ole	doc_213943984989_item	2282413	et	4	main
1	doc_213943984987_item	2282019	et	2	main
eriala	doc_213943984987_item	2282024	et	4	main
erialal	doc_213943984987_item	2282030	et	3	main
ma	doc_213943984987_item	2282036	et	3	main
praegu	doc_213943984987_item	2282051	et	3	main
formuleerida	doc_213943984987_item	2282053	et	3	main
teiste	doc_213943984987_item	2282069	et	4	main
inimesed	doc_213943984987_item	2282077	et	3	main
teada	doc_213943984987_item	2282079	et	3	main
informeerida	doc_213943984987_item	2282081	et	3	main
ma	doc_213943984987_item	2282083	et	3	main
jõudu	doc_213943984987_item	2282092	et	4	main
selles	doc_213943984987_item	2282093	et	4	main
lahe	doc_213943984987_item	2282096	et	4	main
kirjutada	doc_213943984987_item	2282101	et	3	main
väga	doc_213943984987_item	2282105	et	3	main
minu	doc_213943984987_item	2282107	et	3	main
põhjendada	doc_213943984987_item	2282109	et	3	main
oma	doc_213943984987_item	2282110	et	4	main
on	doc_213943984987_item	2282122	et	4	main
ma	doc_213943984987_item	2282130	et	3	main
mu	doc_213943984987_item	2282133	et	3	main
sellepärast	doc_213943984987_item	2282143	et	3	main
selles	doc_213943984987_item	2282151	et	4	main
tahan	doc_213943984987_item	2282153	et	3	main
mind	doc_213943984987_item	2282155	et	4	main
essee	doc_213943984987_item	2282018	et	4	main
ma	doc_213943984987_item	2282021	et	3	main
selle	doc_213943984987_item	2282023	et	4	main
2	doc_213943984987_item	2282025	et	2	main
ootan	doc_213943984987_item	2282027	et	3	main
ülikoolis	doc_213943984987_item	2282033	et	4	main
tänapäeva	doc_213943984987_item	2282044	et	4	main
ma	doc_213943984987_item	2282045	et	3	main
kunagi	doc_213943984987_item	2282046	et	3	main
teemal	doc_213943984987_item	2282050	et	3	main
suhelda	doc_213943984987_item	2282068	et	4	main
küsida	doc_213943984987_item	2282071	et	3	main
teised	doc_213943984987_item	2282076	et	4	main
lugeda	doc_213943984987_item	2282085	et	3	main
võimalus	doc_213943984987_item	2282100	et	3	main
valikut	doc_213943984987_item	2282111	et	3	main
kõige	doc_213943984987_item	2282116	et	4	main
mida	doc_213943984987_item	2282026	et	4	main
tallinna	doc_213943984987_item	2282032	et	4	main
huvitav	doc_213943984987_item	2282040	et	4	main
kahjuks	doc_213943984987_item	2282042	et	4	main
enne	doc_213943984987_item	2282043	et	4	main
ei	doc_213943984987_item	2282047	et	4	main
miks	doc_213943984987_item	2282054	et	4	main
esiteks	doc_213943984987_item	2282055	et	3	main
mulle	doc_213943984987_item	2282056	et	4	main
tundub	doc_213943984987_item	2282057	et	3	main
et	doc_213943984987_item	2282058	et	3	main
see	doc_213943984987_item	2282059	et	3	main
väga	doc_213943984987_item	2282061	et	3	main
huvitav	doc_213943984987_item	2282062	et	4	main
eriala	doc_213943984987_item	2282063	et	4	main
on	doc_213943984987_item	2282060	et	4	main
koguaeg	doc_213943984987_item	2282067	et	3	main
inimestega	doc_213943984987_item	2282070	et	3	main
käest	doc_213943984987_item	2282073	et	4	main
kõik	doc_213943984987_item	2282074	et	4	main
teiseks	doc_213943984987_item	2282082	et	4	main
armastan	doc_213943984987_item	2282084	et	3	main
ka	doc_213943984987_item	2282095	et	3	main
kui	doc_213943984987_item	2282097	et	3	main
on	doc_213943984987_item	2282099	et	4	main
on	doc_213943984987_item	2282104	et	4	main
raske	doc_213943984987_item	2282106	et	4	main
ma	doc_213943984987_item	2282114	et	3	main
ootan	doc_213943984987_item	2282121	et	3	main
lõpetamisest	doc_213943984987_item	2282128	et	4	main
veel	doc_213943984987_item	2282129	et	4	main
et	doc_213943984987_item	2282132	et	3	main
tü	doc_213943984987_item	2282142	et	4	main
korraldusest	doc_213943984987_item	2282150	et	4	main
kõigest	doc_213943984987_item	2282157	et	4	main
1	doc_213943984989_item	2282383	et	2	main
2	doc_213943984989_item	2282389	et	2	main
ülikoolis	doc_213943984989_item	2282397	et	4	main
kindlasti	doc_213943984989_item	2282407	et	3	main
on	doc_213943984989_item	2282416	et	4	main
mõeldud	doc_213943984989_item	2282417	et	4	main
hea	doc_213943984989_item	2282420	et	4	main
inimestele	doc_213943984989_item	2282422	et	3	main
rahalikult	doc_213943984989_item	2282426	et	4	main
istuda	doc_213943984989_item	2282428	et	3	main
kes	doc_213943984989_item	2282430	et	4	main
valisin	doc_213943984989_item	2282437	et	3	main
kirjutada	doc_213943984989_item	2282444	et	3	main
esseet	doc_213943984989_item	2282447	et	4	main
need	doc_213943984989_item	2282457	et	3	main
asi	doc_213943984989_item	2282462	et	4	main
valisin	doc_213943984989_item	2282465	et	3	main
võimalusi	doc_213943984989_item	2282474	et	3	main
olla	doc_213943984989_item	2282479	et	3	main
ja	doc_213943984989_item	2282482	et	3	main
füüsika	doc_213943984989_item	2282493	et	4	main
kindlasti	doc_213943984989_item	2282521	et	3	main
ajakirjandus	doc_213943984989_item	2282526	et	3	main
nii	doc_213943984989_item	2282536	et	3	main
ka	doc_213943984989_item	2282540	et	3	main
suhtlemist	doc_213943984989_item	2282543	et	4	main
ma	doc_213943984989_item	2282545	et	3	main
palju	doc_213943984989_item	2282549	et	4	main
tuleb	doc_213943984989_item	2282552	et	3	main
lugeda	doc_213943984989_item	2282553	et	3	main
referaadid	doc_213943984989_item	2282568	et	3	main
ka	doc_213943984989_item	2282576	et	3	main
olen	doc_213943984989_item	2282581	et	3	main
sooviks	doc_213943984987_item	2282089	et	4	main
oma	doc_213943984987_item	2282091	et	4	main
sul	doc_213943984987_item	2282098	et	3	main
artkle	doc_213943984987_item	2282102	et	4	main
jaoks	doc_213943984987_item	2282108	et	4	main
tähtsam	doc_213943984987_item	2282117	et	4	main
asi	doc_213943984987_item	2282118	et	4	main
ma	doc_213943984987_item	2282120	et	3	main
kõrgharidus	doc_213943984987_item	2282123	et	3	main
pärast	doc_213943984987_item	2282127	et	4	main
tahaks	doc_213943984987_item	2282131	et	3	main
elu	doc_213943984987_item	2282134	et	4	main
oli	doc_213943984987_item	2282135	et	3	main
ja	doc_213943984987_item	2282137	et	3	main
valisin	doc_213943984987_item	2282141	et	3	main
kuulnud	doc_213943984987_item	2282146	et	4	main
hea	doc_213943984987_item	2282148	et	4	main
ülikoolis	doc_213943984987_item	2282152	et	4	main
on	doc_213943984987_item	2282159	et	4	main
teada	doc_213943984987_item	2282161	et	3	main
valisin	doc_213943984989_item	2282386	et	3	main
selle	doc_213943984989_item	2282387	et	4	main
eriala	doc_213943984989_item	2282388	et	4	main
mida	doc_213943984989_item	2282390	et	4	main
ootan	doc_213943984989_item	2282391	et	3	main
ja	doc_213943984989_item	2282395	et	3	main
minu	doc_213943984989_item	2282399	et	3	main
tore	doc_213943984989_item	2282404	et	3	main
on	doc_213943984989_item	2282408	et	4	main
väga	doc_213943984989_item	2282409	et	3	main
saa	doc_213943984989_item	2282425	et	4	main
ning	doc_213943984989_item	2282429	et	3	main
elu	doc_213943984989_item	2282435	et	4	main
ma	doc_213943984989_item	2282436	et	3	main
mulle	doc_213943984989_item	2282441	et	4	main
alati	doc_213943984989_item	2282442	et	4	main
erinevaid	doc_213943984989_item	2282445	et	4	main
jne	doc_213943984989_item	2282449	et	4	main
teine	doc_213943984989_item	2282461	et	3	main
uue	doc_213943984989_item	2282476	et	3	main
seas	doc_213943984989_item	2282481	et	4	main
rääkida	doc_213943984989_item	2282483	et	3	main
või	doc_213943984989_item	2282492	et	4	main
on	doc_213943984989_item	2282497	et	4	main
ja	doc_213943984987_item	2282124	et	3	main
huvitav	doc_213943984987_item	2282136	et	4	main
mitte	doc_213943984987_item	2282138	et	3	main
ma	doc_213943984987_item	2282140	et	3	main
palju	doc_213943984987_item	2282147	et	4	main
asju	doc_213943984987_item	2282149	et	3	main
mis	doc_213943984987_item	2282158	et	4	main
essee	doc_213943984989_item	2282382	et	4	main
miks	doc_213943984989_item	2282384	et	4	main
ma	doc_213943984989_item	2282385	et	3	main
õppimisest	doc_213943984989_item	2282392	et	4	main
tallinna	doc_213943984989_item	2282396	et	4	main
1	doc_213943984989_item	2282398	et	2	main
arvates	doc_213943984989_item	2282400	et	4	main
ajakirjandus	doc_213943984989_item	2282401	et	3	main
see	doc_213943984989_item	2282406	et	3	main
ja	doc_213943984989_item	2282411	et	3	main
aktiivsetele	doc_213943984989_item	2282418	et	4	main
ja	doc_213943984989_item	2282419	et	3	main
erialal	doc_213943984989_item	2282394	et	3	main
väga	doc_213943984989_item	2282403	et	3	main
huvitav	doc_213943984989_item	2282410	et	4	main
igav	doc_213943984989_item	2282414	et	3	main
ajakirjandus	doc_213943984989_item	2282415	et	3	main
suhtlemisoskusega	doc_213943984989_item	2282421	et	3	main
kes	doc_213943984989_item	2282423	et	4	main
soovi	doc_213943984989_item	2282432	et	4	main
referaate	doc_213943984989_item	2282446	et	3	main
niimodi	doc_213943984989_item	2282455	et	4	main
tegema	doc_213943984989_item	2282460	et	3	main
selle	doc_213943984989_item	2282467	et	4	main
avab	doc_213943984989_item	2282473	et	3	main
alati	doc_213943984989_item	2282478	et	4	main
teaduskonnad	doc_213943984989_item	2282494	et	4	main
2	doc_213943984989_item	2282525	et	2	main
niimodi	doc_213943984989_item	2282532	et	4	main
sest	doc_213943984989_item	2282533	et	4	main
see	doc_213943984989_item	2282534	et	3	main
puudutab	doc_213943984989_item	2282535	et	3	main
inimestiga	doc_213943984989_item	2282542	et	4	main
mida	doc_213943984989_item	2282544	et	4	main
teadmisi	doc_213943984989_item	2282551	et	4	main
ja	doc_213943984989_item	2282556	et	3	main
töid	doc_213943984989_item	2282567	et	3	main
aruanned	doc_213943984989_item	2282570	et	4	main
mulle	doc_213943984989_item	2282573	et	4	main
meeldib	doc_213943984989_item	2282574	et	3	main
aktiivset	doc_213943984989_item	2282578	et	3	main
sest	doc_213943984989_item	2282580	et	4	main
tallinna	doc_213943984989_item	2282592	et	4	main
palju	doc_213943984989_item	2282595	et	4	main
häid	doc_213943984989_item	2282599	et	3	main
inimesed	doc_213943984989_item	2282607	et	3	main
valisin	doc_213943984990_item	2282612	et	3	main
pakub	doc_213943984990_item	2282630	et	3	main
võimalusi	doc_213943984990_item	2282632	et	3	main
eestis	doc_213943984990_item	2282635	et	3	main
asjad	doc_213943984990_item	2282643	et	3	main
ilma	doc_213943984990_item	2282660	et	4	main
ülikoolis	doc_213943984990_item	2282667	et	4	main
humanitaarteadused	doc_213943984990_item	2282673	et	3	main
on	doc_213943984990_item	2282674	et	4	main
kui	doc_213943984990_item	2282679	et	3	main
seda	doc_213943984990_item	2282681	et	3	main
riigieksamid	doc_213943984990_item	2282685	et	3	main
on	doc_213943984990_item	2282723	et	4	main
juba	doc_213943984990_item	2282733	et	3	main
tagasi	doc_213943984990_item	2282736	et	3	main
polnud	doc_213943984990_item	2282737	et	3	main
ülikooli	doc_213943984990_item	2282740	et	4	main
kaua	doc_213943984990_item	2282747	et	3	main
elu	doc_213943984990_item	2282754	et	4	main
minu	doc_213943984990_item	2282761	et	3	main
arvamus	doc_213943984990_item	2282763	et	3	main
teisse	doc_213943984990_item	2282773	et	4	main
elamusi	doc_213943984990_item	2282806	et	3	main
ole	doc_213943984990_item	2282818	et	4	main
valikus	doc_213943984990_item	2282820	et	3	main
vahet	doc_213943984990_item	2282822	et	3	main
pole	doc_213943984990_item	2282823	et	3	main
sattun	doc_213943984990_item	2282826	et	3	main
peale	doc_213943984990_item	2282828	et	4	main
töö	doc_213943984990_item	2282831	et	4	main
ajalehes	doc_213943984990_item	2282834	et	3	main
miks	doc_213943984991_item	2282845	et	4	main
selle	doc_213943984991_item	2282848	et	4	main
mida	doc_213943984991_item	2282851	et	4	main
ootan	doc_213943984991_item	2282852	et	3	main
sellel	doc_213943984991_item	2282854	et	4	main
erialal	doc_213943984991_item	2282855	et	3	main
tallinna	doc_213943984991_item	2282857	et	4	main
ülikoolis	doc_213943984991_item	2282858	et	4	main
1	doc_213943984991_item	2282859	et	2	main
kes	doc_213943984991_item	2282864	et	4	main
ei	doc_213943984989_item	2282424	et	4	main
kodus	doc_213943984989_item	2282427	et	4	main
meeldis	doc_213943984989_item	2282443	et	3	main
aruannet	doc_213943984989_item	2282448	et	4	main
aga	doc_213943984989_item	2282450	et	3	main
eriala	doc_213943984989_item	2282452	et	4	main
kindlasti	doc_213943984989_item	2282453	et	3	main
koostatud	doc_213943984989_item	2282454	et	4	main
et	doc_213943984989_item	2282456	et	3	main
asjad	doc_213943984989_item	2282458	et	3	main
miks	doc_213943984989_item	2282463	et	4	main
ma	doc_213943984989_item	2282464	et	3	main
inimeste	doc_213943984989_item	2282480	et	3	main
huvitavatest	doc_213943984989_item	2282485	et	4	main
asjadest	doc_213943984989_item	2282486	et	3	main
mõned	doc_213943984989_item	2282487	et	3	main
jaoks	doc_213943984989_item	2282496	et	4	main
igavad	doc_213943984989_item	2282499	et	3	main
loodan	doc_213943984989_item	2282507	et	3	main
et	doc_213943984989_item	2282508	et	3	main
tegin	doc_213943984989_item	2282509	et	3	main
õige	doc_213943984989_item	2282510	et	4	main
valik	doc_213943984989_item	2282511	et	3	main
kavatsen	doc_213943984989_item	2282512	et	3	main
õppida	doc_213943984989_item	2282513	et	3	main
edukalt	doc_213943984989_item	2282514	et	4	main
sest	doc_213943984989_item	2282515	et	4	main
leidsin	doc_213943984989_item	2282517	et	3	main
eriala	doc_213943984989_item	2282518	et	4	main
mis	doc_213943984989_item	2282519	et	4	main
siiski	doc_213943984989_item	2282516	et	4	main
mulle	doc_213943984989_item	2282520	et	4	main
ei	doc_213943984989_item	2282431	et	4	main
endale	doc_213943984989_item	2282433	et	4	main
igavuiset	doc_213943984989_item	2282434	et	4	main
selle	doc_213943984989_item	2282438	et	4	main
eriala	doc_213943984989_item	2282439	et	4	main
sest	doc_213943984989_item	2282440	et	4	main
ajakirjanduse	doc_213943984989_item	2282451	et	3	main
peaks	doc_213943984989_item	2282459	et	4	main
just	doc_213943984989_item	2282466	et	3	main
eriala	doc_213943984989_item	2282468	et	4	main
on	doc_213943984989_item	2282469	et	4	main
fakt	doc_213943984989_item	2282470	et	3	main
et	doc_213943984989_item	2282471	et	3	main
ajakirjandus	doc_213943984989_item	2282472	et	3	main
suhelda	doc_213943984989_item	2282475	et	4	main
inimestega	doc_213943984989_item	2282477	et	3	main
nendega	doc_213943984989_item	2282484	et	4	main
teised	doc_213943984989_item	2282488	et	4	main
erialad	doc_213943984989_item	2282489	et	3	main
näiteks	doc_213943984989_item	2282490	et	4	main
matemaatika	doc_213943984989_item	2282491	et	4	main
minu	doc_213943984989_item	2282495	et	3	main
mitte	doc_213943984989_item	2282501	et	3	main
mind	doc_213943984989_item	2282503	et	4	main
ja	doc_213943984989_item	2282523	et	3	main
on	doc_213943984989_item	2282527	et	4	main
rahulikuid	doc_213943984989_item	2282537	et	4	main
uusi	doc_213943984989_item	2282550	et	3	main
kirjalikuid	doc_213943984989_item	2282566	et	4	main
esseed	doc_213943984989_item	2282569	et	4	main
jne	doc_213943984989_item	2282571	et	4	main
ootan	doc_213943984989_item	2282577	et	3	main
ootan	doc_213943984989_item	2282587	et	3	main
huvitavat	doc_213943984989_item	2282589	et	4	main
elu	doc_213943984989_item	2282590	et	4	main
tuttavaid	doc_213943984989_item	2282597	et	3	main
töötajaid	doc_213943984989_item	2282600	et	4	main
targad	doc_213943984989_item	2282606	et	3	main
mida	doc_213943984990_item	2282616	et	4	main
ootan	doc_213943984990_item	2282617	et	3	main
ja	doc_213943984990_item	2282621	et	3	main
ülikoolis	doc_213943984990_item	2282623	et	4	main
valisin	doc_213943984990_item	2282625	et	3	main
selle	doc_213943984990_item	2282626	et	4	main
arendamiseks	doc_213943984990_item	2282633	et	4	main
nii	doc_213943984990_item	2282634	et	3	main
ka	doc_213943984990_item	2282637	et	3	main
riikides	doc_213943984990_item	2282639	et	3	main
on	doc_213943984990_item	2282641	et	4	main
iseloom	doc_213943984990_item	2282645	et	3	main
suur	doc_213943984990_item	2282650	et	3	main
arvan	doc_213943984990_item	2282652	et	3	main
et	doc_213943984990_item	2282658	et	3	main
abita	doc_213943984990_item	2282661	et	3	main
hakkama	doc_213943984990_item	2282663	et	3	main
tingimustega	doc_213943984990_item	2282665	et	3	main
alati	doc_213943984990_item	2282675	et	4	main
lähedamad	doc_213943984990_item	2282678	et	4	main
ka	doc_213943984990_item	2282683	et	3	main
et	doc_213943984990_item	2282687	et	3	main
valisin	doc_213943984990_item	2282692	et	3	main
pealegi	doc_213943984990_item	2282721	et	4	main
kogemust	doc_213943984990_item	2282725	et	3	main
lõpetasin	doc_213943984990_item	2282731	et	3	main
just	doc_213943984990_item	2282744	et	3	main
sellepärast	doc_213943984990_item	2282745	et	3	main
nüüd	doc_213943984990_item	2282756	et	4	main
on	doc_213943984990_item	2282760	et	4	main
aga	doc_213943984990_item	2282764	et	3	main
eriala	doc_213943984990_item	2282802	et	4	main
palju	doc_213943984990_item	2282804	et	4	main
kaasamõtlejaid	doc_213943984990_item	2282811	et	3	main
ja	doc_213943984990_item	2282812	et	3	main
tõestan	doc_213943984990_item	2282813	et	3	main
ma	doc_213943984990_item	2282816	et	3	main
liiga	doc_213943984989_item	2282498	et	4	main
ja	doc_213943984989_item	2282500	et	3	main
kunagi	doc_213943984989_item	2282502	et	3	main
ei	doc_213943984989_item	2282504	et	4	main
huvitanud	doc_213943984989_item	2282505	et	4	main
niisiis	doc_213943984989_item	2282506	et	3	main
meeldib	doc_213943984989_item	2282522	et	3	main
lai	doc_213943984989_item	2282528	et	3	main
töid	doc_213943984989_item	2282538	et	3	main
ootan	doc_213943984989_item	2282546	et	3	main
kõigepealt	doc_213943984989_item	2282548	et	3	main
raamatuid	doc_213943984989_item	2282555	et	3	main
tegema	doc_213943984989_item	2282575	et	3	main
õppimisest	doc_213943984989_item	2282591	et	4	main
kes	doc_213943984989_item	2282601	et	4	main
abivalmisad	doc_213943984989_item	2282603	et	4	main
ja	doc_213943984989_item	2282604	et	3	main
1	doc_213943984990_item	2282609	et	2	main
eriala	doc_213943984990_item	2282614	et	4	main
2	doc_213943984990_item	2282615	et	2	main
erialal	doc_213943984990_item	2282620	et	3	main
peamised	doc_213943984990_item	2282642	et	3	main
eneseväljendamise	doc_213943984990_item	2282646	et	3	main
seda	doc_213943984990_item	2282654	et	3	main
loodan	doc_213943984990_item	2282657	et	3	main
ja	doc_213943984990_item	2282668	et	3	main
õppida	doc_213943984990_item	2282671	et	3	main
nii	doc_213943984990_item	2282686	et	3	main
valik	doc_213943984990_item	2282689	et	3	main
sobib	doc_213943984989_item	2282524	et	3	main
eriala	doc_213943984989_item	2282529	et	4	main
ma	doc_213943984989_item	2282530	et	3	main
arvan	doc_213943984989_item	2282531	et	3	main
kui	doc_213943984989_item	2282539	et	3	main
aktiivset	doc_213943984989_item	2282541	et	3	main
ajakirjandusest	doc_213943984989_item	2282547	et	4	main
palju	doc_213943984989_item	2282554	et	4	main
palju	doc_213943984989_item	2282557	et	4	main
suhelda	doc_213943984989_item	2282558	et	4	main
inimestega	doc_213943984989_item	2282559	et	3	main
lisaks	doc_213943984989_item	2282560	et	4	main
sellele	doc_213943984989_item	2282561	et	4	main
peaksin	doc_213943984989_item	2282562	et	4	main
vist	doc_213943984989_item	2282563	et	4	main
tegema	doc_213943984989_item	2282564	et	3	main
palju	doc_213943984989_item	2282565	et	4	main
mis	doc_213943984989_item	2282572	et	4	main
eluviisi	doc_213943984989_item	2282579	et	4	main
kavatsenud	doc_213943984989_item	2282582	et	4	main
ühesõnaga	doc_213943984989_item	2282586	et	3	main
ilusat	doc_213943984989_item	2282588	et	3	main
on	doc_213943984989_item	2282602	et	4	main
lihtsalt	doc_213943984989_item	2282605	et	4	main
ma	doc_213943984990_item	2282611	et	3	main
selle	doc_213943984990_item	2282613	et	4	main
sellel	doc_213943984990_item	2282619	et	4	main
alati	doc_213943984989_item	2282583	et	4	main
millega	doc_213943984989_item	2282584	et	3	main
tegeleda	doc_213943984989_item	2282585	et	3	main
ülikoolis	doc_213943984989_item	2282593	et	4	main
ootan	doc_213943984989_item	2282594	et	3	main
uusi	doc_213943984989_item	2282596	et	3	main
ja	doc_213943984989_item	2282598	et	3	main
essee	doc_213943984990_item	2282608	et	4	main
miks	doc_213943984990_item	2282610	et	4	main
õppimisest	doc_213943984990_item	2282618	et	4	main
kui	doc_213943984990_item	2282636	et	3	main
teistes	doc_213943984990_item	2282638	et	4	main
ajakirjanduses	doc_213943984990_item	2282640	et	3	main
ja	doc_213943984990_item	2282648	et	3	main
et	doc_213943984990_item	2282653	et	3	main
mul	doc_213943984990_item	2282655	et	3	main
mitte	doc_213943984990_item	2282659	et	3	main
saan	doc_213943984990_item	2282662	et	4	main
uute	doc_213943984990_item	2282664	et	3	main
tallinna	doc_213943984990_item	2282666	et	4	main
lõpuni	doc_213943984990_item	2282672	et	3	main
minule	doc_213943984990_item	2282677	et	3	main
täpsed	doc_213943984990_item	2282680	et	3	main
oli	doc_213943984990_item	2282690	et	3	main
natuke	doc_213943984990_item	2282724	et	4	main
piirkonnas	doc_213943984990_item	2282727	et	4	main
kuna	doc_213943984990_item	2282729	et	3	main
kooli	doc_213943984990_item	2282732	et	4	main
aastat	doc_213943984990_item	2282735	et	3	main
kerge	doc_213943984990_item	2282743	et	4	main
oma	doc_213943984990_item	2282753	et	4	main
et	doc_213943984990_item	2282758	et	3	main
lõplik	doc_213943984990_item	2282762	et	3	main
on	doc_213943984990_item	2282771	et	4	main
pakub	doc_213943984990_item	2282803	et	3	main
huvitavaid	doc_213943984990_item	2282805	et	4	main
leian	doc_213943984990_item	2282808	et	3	main
palju	doc_213943984990_item	2282810	et	4	main
endale	doc_213943984990_item	2282814	et	4	main
eksinud	doc_213943984990_item	2282819	et	4	main
ma	doc_213943984990_item	2282825	et	3	main
ma	doc_213943984991_item	2282846	et	3	main
2	doc_213943984991_item	2282850	et	2	main
ja	doc_213943984991_item	2282856	et	3	main
niisugused	doc_213943984991_item	2282862	et	3	main
armastavad	doc_213943984991_item	2282866	et	4	main
pliiatsiga	doc_213943984991_item	2282875	et	4	main
mille	doc_213943984991_item	2282877	et	3	main
neil	doc_213943984991_item	2282879	et	4	main
raske	doc_213943984991_item	2282891	et	4	main
vaid	doc_213943984991_item	2282893	et	3	main
igavalt	doc_213943984991_item	2282899	et	4	main
midagi	doc_213943984991_item	2282904	et	4	main
isegi	doc_213943984991_item	2282929	et	4	main
looda	doc_213943984991_item	2282932	et	4	main
või	doc_213943984991_item	2282933	et	4	main
hävitada	doc_213943984991_item	2282934	et	3	main
võin	doc_213943984991_item	2282941	et	3	main
inimeste	doc_213943984991_item	2282943	et	3	main
näha	doc_213943984991_item	2282945	et	3	main
on	doc_213943984991_item	2282953	et	4	main
avada	doc_213943984991_item	2282967	et	3	main
jaoks	doc_213943984991_item	2282969	et	4	main
minu	doc_213943984991_item	2282978	et	3	main
nii	doc_213943984991_item	2283017	et	3	main
on	doc_213943984991_item	2283020	et	4	main
vältida	doc_213943984991_item	2283031	et	3	main
ajakirjanik	doc_213943984991_item	2283032	et	3	main
inimene	doc_213943984991_item	2283034	et	3	main
kelle	doc_213943984991_item	2283035	et	4	main
tema	doc_213943984991_item	2283040	et	4	main
peavad	doc_213943984991_item	2283042	et	4	main
säilitada	doc_213943984991_item	2283043	et	3	main
inimesena	doc_213943984991_item	2283064	et	3	main
on	doc_213943984991_item	2283075	et	4	main
nagu	doc_213943984991_item	2283077	et	3	main
paremaks	doc_213943984991_item	2283094	et	4	main
tahan	doc_213943984991_item	2283098	et	3	main
tahtmine	doc_213943984991_item	2283112	et	4	main
tallinna	doc_213943984990_item	2282622	et	4	main
mina	doc_213943984990_item	2282624	et	4	main
eriala	doc_213943984990_item	2282627	et	4	main
sest	doc_213943984990_item	2282628	et	4	main
ta	doc_213943984990_item	2282629	et	4	main
palju	doc_213943984990_item	2282631	et	4	main
loominguline	doc_213943984990_item	2282644	et	4	main
oskus	doc_213943984990_item	2282647	et	3	main
tõesti	doc_213943984990_item	2282649	et	3	main
kiindumus	doc_213943984990_item	2282651	et	4	main
leidub	doc_213943984990_item	2282656	et	3	main
jätkub	doc_213943984990_item	2282669	et	3	main
jõudu	doc_213943984990_item	2282670	et	4	main
olnud	doc_213943984990_item	2282676	et	4	main
tõestasid	doc_213943984990_item	2282682	et	4	main
minu	doc_213943984990_item	2282684	et	3	main
minu	doc_213943984990_item	2282688	et	3	main
tõenähtav	doc_213943984990_item	2282691	et	3	main
õppimise	doc_213943984990_item	2282693	et	4	main
vene	doc_213943984990_item	2282694	et	4	main
keeles	doc_213943984990_item	2282695	et	4	main
sest	doc_213943984990_item	2282696	et	4	main
et	doc_213943984990_item	2282697	et	3	main
arvan	doc_213943984990_item	2282698	et	3	main
et	doc_213943984990_item	2282699	et	3	main
see	doc_213943984990_item	2282700	et	3	main
on	doc_213943984990_item	2282701	et	4	main
mulle	doc_213943984990_item	2282702	et	4	main
lihtsam	doc_213943984990_item	2282703	et	4	main
ja	doc_213943984990_item	2282704	et	3	main
igaühele	doc_213943984990_item	2282705	et	3	main
oleks	doc_213943984990_item	2282706	et	3	main
parem	doc_213943984990_item	2282707	et	4	main
õppida	doc_213943984990_item	2282708	et	3	main
just	doc_213943984990_item	2282709	et	3	main
emakeeles	doc_213943984990_item	2282710	et	4	main
kolmest	doc_213943984990_item	2282711	et	4	main
erialast	doc_213943984990_item	2282712	et	4	main
vene	doc_213943984990_item	2282713	et	4	main
õppekeelega	doc_213943984990_item	2282714	et	3	main
kõige	doc_213943984990_item	2282715	et	4	main
minu	doc_213943984990_item	2282717	et	3	main
huvitavam	doc_213943984990_item	2282716	et	4	main
jaoks	doc_213943984990_item	2282718	et	4	main
tundus	doc_213943984990_item	2282719	et	3	main
ajakirjandus	doc_213943984990_item	2282720	et	3	main
selles	doc_213943984990_item	2282726	et	4	main
ma	doc_213943984990_item	2282730	et	3	main
kuus	doc_213943984990_item	2282734	et	4	main
see	doc_213943984990_item	2282738	et	3	main
teine	doc_213943984990_item	2282739	et	3	main
sisseastumine	doc_213943984990_item	2282741	et	3	main
päris	doc_213943984990_item	2282746	et	4	main
suutnud	doc_213943984990_item	2282749	et	4	main
mul	doc_213943984990_item	2282722	et	3	main
kooliajast	doc_213943984990_item	2282728	et	4	main
eriti	doc_213943984990_item	2282742	et	3	main
ei	doc_213943984990_item	2282748	et	4	main
siduda	doc_213943984990_item	2282755	et	3	main
arvan	doc_213943984990_item	2282757	et	3	main
teab	doc_213943984990_item	2282766	et	3	main
sõita	doc_213943984990_item	2282772	et	3	main
riiki	doc_213943984990_item	2282774	et	4	main
ja	doc_213943984990_item	2282775	et	3	main
õppida	doc_213943984990_item	2282776	et	3	main
ajakirjandust	doc_213943984990_item	2282777	et	3	main
ka	doc_213943984990_item	2282778	et	3	main
kodust	doc_213943984990_item	2282779	et	4	main
kaugemal	doc_213943984990_item	2282780	et	4	main
ei	doc_213943984990_item	2282781	et	4	main
tea	doc_213943984990_item	2282782	et	4	main
kas	doc_213943984990_item	2282783	et	3	main
tõesti	doc_213943984990_item	2282784	et	3	main
saan	doc_213943984990_item	2282785	et	4	main
eestis	doc_213943984990_item	2282786	et	3	main
leida	doc_213943984990_item	2282787	et	3	main
ennast	doc_213943984990_item	2282788	et	4	main
sellel	doc_213943984990_item	2282789	et	4	main
erialal	doc_213943984990_item	2282790	et	3	main
aga	doc_213943984990_item	2282791	et	3	main
kui	doc_213943984990_item	2282792	et	3	main
tuleb	doc_213943984990_item	2282793	et	3	main
ette	doc_213943984990_item	2282794	et	4	main
selline	doc_213943984990_item	2282795	et	4	main
võimalus	doc_213943984990_item	2282796	et	3	main
siis	doc_213943984990_item	2282797	et	3	main
loodan	doc_213943984990_item	2282799	et	3	main
kindlasti	doc_213943984990_item	2282798	et	3	main
et	doc_213943984990_item	2282800	et	3	main
valiku	doc_213943984990_item	2282750	et	3	main
teha	doc_213943984990_item	2282751	et	3	main
millega	doc_213943984990_item	2282752	et	3	main
see	doc_213943984990_item	2282759	et	3	main
kes	doc_213943984990_item	2282765	et	4	main
mis	doc_213943984990_item	2282767	et	4	main
edasi	doc_213943984990_item	2282768	et	3	main
juhtub	doc_213943984990_item	2282769	et	3	main
plaanis	doc_213943984990_item	2282770	et	4	main
see	doc_213943984990_item	2282801	et	3	main
siin	doc_213943984990_item	2282809	et	4	main
ei	doc_213943984990_item	2282817	et	4	main
eriti	doc_213943984990_item	2282821	et	3	main
kuhu	doc_213943984990_item	2282824	et	3	main
ajakirjas	doc_213943984990_item	2282832	et	3	main
raadios	doc_213943984990_item	2282835	et	3	main
presssekretärina	doc_213943984990_item	2282837	et	4	main
essee	doc_213943984991_item	2282843	et	4	main
õppimisest	doc_213943984991_item	2282853	et	4	main
olemas	doc_213943984991_item	2282861	et	4	main
kirjutada	doc_213943984991_item	2282865	et	3	main
palju	doc_213943984991_item	2282870	et	4	main
iseloom	doc_213943984991_item	2282887	et	3	main
see	doc_213943984991_item	2282894	et	3	main
elada	doc_213943984991_item	2282898	et	3	main
või	doc_213943984991_item	2282907	et	4	main
meeldinud	doc_213943984991_item	2282909	et	4	main
midagi	doc_213943984991_item	2282923	et	4	main
elud	doc_213943984991_item	2282931	et	3	main
mida	doc_213943984991_item	2282936	et	4	main
et	doc_213943984991_item	2282940	et	3	main
kirjeldada	doc_213943984991_item	2282947	et	3	main
ajakirjaniku	doc_213943984991_item	2282949	et	3	main
ülikoolis	doc_213943984991_item	2282951	et	4	main
tahaksin	doc_213943984991_item	2282966	et	3	main
näidata	doc_213943984991_item	2282973	et	4	main
mind	doc_213943984991_item	2282975	et	4	main
jaoks	doc_213943984991_item	2282979	et	4	main
väja	doc_213943984991_item	2282980	et	4	main
tihti	doc_213943984991_item	2283015	et	3	main
et	doc_213943984991_item	2283027	et	3	main
vaid	doc_213943984991_item	2283039	et	3	main
on	doc_213943984991_item	2283046	et	4	main
mõtlen	doc_213943984991_item	2283060	et	3	main
tean	doc_213943984991_item	2283062	et	3	main
peab	doc_213943984991_item	2283065	et	4	main
just	doc_213943984991_item	2283076	et	3	main
unist	doc_213943984991_item	2283079	et	4	main
töö	doc_213943984991_item	2283084	et	4	main
iga	doc_213943984991_item	2283085	et	4	main
jaoks	doc_213943984991_item	2283087	et	4	main
ideaalne	doc_213943984991_item	2283088	et	3	main
end	doc_213943984991_item	2283093	et	4	main
saada	doc_213943984991_item	2283100	et	4	main
õppida	doc_213943984991_item	2283106	et	3	main
ajakirjanduse	doc_213943984991_item	2283107	et	3	main
mul	doc_213943984991_item	2283109	et	3	main
see	doc_213943984991_item	2283124	et	3	main
mind	doc_213943984991_item	2283136	et	4	main
et	doc_213943984991_item	2283147	et	3	main
ülikoolis	doc_213943984991_item	2283148	et	4	main
meeldivaks	doc_213943984991_item	2283154	et	4	main
mälestuseks	doc_213943984991_item	2283155	et	4	main
et	doc_213943984991_item	2283158	et	3	main
ilmusid	doc_213943984991_item	2283160	et	4	main
truud	doc_213943984991_item	2283162	et	4	main
sõbrad	doc_213943984991_item	2283163	et	3	main
oma	doc_213943984991_item	2283166	et	4	main
vahendada	doc_213943984991_item	2283168	et	3	main
inimesed	doc_213943984991_item	2283179	et	3	main
teada	doc_213943984991_item	2283182	et	3	main
lihtsalt	doc_213943984991_item	2283191	et	4	main
sellele	doc_213943984991_item	2283201	et	4	main
kirjutada	doc_213943984991_item	2283203	et	3	main
et	doc_213943984991_item	2283221	et	3	main
1	doc_213943984992_item	2283229	et	2	main
selle	doc_213943984992_item	2283233	et	4	main
mida	doc_213943984992_item	2283236	et	4	main
ootan	doc_213943984992_item	2283237	et	3	main
õppimisest	doc_213943984992_item	2283238	et	4	main
1	doc_213943984992_item	2283244	et	2	main
kõigepealt	doc_213943984992_item	2283245	et	3	main
et	doc_213943984990_item	2282807	et	3	main
et	doc_213943984990_item	2282815	et	3	main
õppimist	doc_213943984990_item	2282829	et	4	main
kas	doc_213943984990_item	2282830	et	3	main
või	doc_213943984990_item	2282836	et	4	main
töö	doc_213943984990_item	2282838	et	4	main
valisin	doc_213943984991_item	2282847	et	3	main
eriala	doc_213943984991_item	2282849	et	4	main
inimesed	doc_213943984991_item	2282863	et	3	main
tunnevad	doc_213943984991_item	2282868	et	3	main
paremini	doc_213943984991_item	2282871	et	4	main
lehe	doc_213943984991_item	2282873	et	3	main
ja	doc_213943984991_item	2282874	et	3	main
maailm	doc_213943984991_item	2282883	et	3	main
on	doc_213943984991_item	2282885	et	4	main
niisugune	doc_213943984991_item	2282886	et	3	main
päris	doc_213943984991_item	2282890	et	4	main
ei	doc_213943984991_item	2282895	et	4	main
et	doc_213943984991_item	2282897	et	3	main
päev	doc_213943984991_item	2282901	et	3	main
kirjutan	doc_213943984991_item	2282903	et	3	main
raamatutest	doc_213943984991_item	2282908	et	4	main
tööle	doc_213943984990_item	2282827	et	3	main
või	doc_213943984990_item	2282833	et	4	main
peaks	doc_213943984990_item	2282839	et	4	main
mulle	doc_213943984990_item	2282840	et	4	main
tõesti	doc_213943984990_item	2282841	et	3	main
meeldima	doc_213943984990_item	2282842	et	3	main
1	doc_213943984991_item	2282844	et	2	main
on	doc_213943984991_item	2282860	et	4	main
nad	doc_213943984991_item	2282867	et	3	main
valge	doc_213943984991_item	2282872	et	4	main
muuga	doc_213943984991_item	2282878	et	4	main
omapärane	doc_213943984991_item	2282881	et	4	main
sisene	doc_213943984991_item	2282882	et	4	main
neil	doc_213943984991_item	2282884	et	4	main
millega	doc_213943984991_item	2282888	et	3	main
elada	doc_213943984991_item	2282892	et	3	main
iga	doc_213943984991_item	2282900	et	4	main
ma	doc_213943984991_item	2282902	et	3	main
mõtteid	doc_213943984991_item	2282906	et	3	main
sõnad	doc_213943984991_item	2282910	et	4	main
mulle	doc_213943984991_item	2282911	et	4	main
meeldib	doc_213943984991_item	2282912	et	3	main
see	doc_213943984991_item	2282913	et	3	main
tunne	doc_213943984991_item	2282914	et	4	main
mis	doc_213943984991_item	2282915	et	4	main
tekkib	doc_213943984991_item	2282916	et	3	main
lehtede	doc_213943984991_item	2282917	et	4	main
vaadest	doc_213943984991_item	2282918	et	3	main
see	doc_213943984991_item	2282919	et	3	main
rahu	doc_213943984991_item	2282920	et	4	main
ja	doc_213943984991_item	2282921	et	3	main
kättedega	doc_213943984991_item	2282925	et	3	main
tahaksin	doc_213943984991_item	2282937	et	3	main
mõtlesin	doc_213943984991_item	2282939	et	3	main
nimelt	doc_213943984991_item	2282954	et	4	main
asi	doc_213943984991_item	2282956	et	4	main
tahaksin	doc_213943984991_item	2282958	et	3	main
kirjutada	doc_213943984991_item	2282960	et	3	main
nende	doc_213943984991_item	2282968	et	4	main
oma	doc_213943984991_item	2282970	et	4	main
kuidas	doc_213943984991_item	2282974	et	3	main
ümbritsevad	doc_213943984991_item	2282976	et	4	main
inimesed	doc_213943984991_item	2282977	et	3	main
et	doc_213943984991_item	2283018	et	3	main
end	doc_213943984991_item	2282869	et	4	main
kui	doc_213943984991_item	2282876	et	3	main
on	doc_213943984991_item	2282880	et	4	main
on	doc_213943984991_item	2282889	et	4	main
tähenda	doc_213943984991_item	2282896	et	4	main
oma	doc_213943984991_item	2282905	et	4	main
oma	doc_213943984991_item	2282924	et	4	main
ma	doc_213943984991_item	2282927	et	3	main
võin	doc_213943984991_item	2282928	et	3	main
inimeste	doc_213943984991_item	2282930	et	3	main
kui	doc_213943984991_item	2282938	et	3	main
reaalse	doc_213943984991_item	2282942	et	3	main
elud	doc_213943984991_item	2282944	et	3	main
see	doc_213943984991_item	2282952	et	3	main
see	doc_213943984991_item	2282955	et	3	main
teha	doc_213943984991_item	2282959	et	3	main
teised	doc_213943984991_item	2282962	et	4	main
võiksid	doc_213943984991_item	2282963	et	4	main
seda	doc_213943984991_item	2282964	et	3	main
lugeda	doc_213943984991_item	2282965	et	3	main
maailma	doc_213943984991_item	2282971	et	4	main
juhtub	doc_213943984991_item	2283016	et	3	main
informatsiooni	doc_213943984991_item	2283019	et	4	main
vähe	doc_213943984991_item	2283021	et	3	main
see	doc_213943984991_item	2283023	et	3	main
vaja	doc_213943984991_item	2283029	et	4	main
on	doc_213943984991_item	2283033	et	4	main
sellepärast	doc_213943984991_item	2283045	et	3	main
tahtis	doc_213943984991_item	2283047	et	3	main
teistele	doc_213943984991_item	2283057	et	4	main
missuguse	doc_213943984991_item	2283063	et	3	main
olema	doc_213943984991_item	2283067	et	4	main
ja	doc_213943984991_item	2283068	et	3	main
ka	doc_213943984991_item	2283070	et	3	main
elu	doc_213943984991_item	2283072	et	4	main
see	doc_213943984991_item	2283074	et	3	main
minu	doc_213943984991_item	2283078	et	3	main
on	doc_213943984991_item	2283081	et	4	main
ei	doc_213943984991_item	2283091	et	4	main
ajakirjanikuks	doc_213943984991_item	2283095	et	3	main
ainult	doc_213943984991_item	2283097	et	4	main
ma	doc_213943984991_item	2283102	et	3	main
ju	doc_213943984991_item	2283103	et	3	main
ülikooli	doc_213943984991_item	2283105	et	4	main
erialal	doc_213943984991_item	2283108	et	3	main
ja	doc_213943984991_item	2283113	et	3	main
päris	doc_213943984991_item	2283114	et	4	main
head	doc_213943984991_item	2283115	et	4	main
looduslikud	doc_213943984991_item	2283116	et	3	main
oskused	doc_213943984991_item	2283117	et	3	main
selleparast	doc_213943984991_item	2283118	et	3	main
ma	doc_213943984991_item	2283119	et	3	main
on	doc_213943984991_item	2283125	et	4	main
minu	doc_213943984991_item	2283126	et	3	main
ülikooli	doc_213943984991_item	2283128	et	4	main
tund	doc_213943984991_item	2283129	et	3	main
mis	doc_213943984991_item	2283134	et	4	main
teel	doc_213943984991_item	2283138	et	4	main
ise	doc_213943984991_item	2283141	et	4	main
tahaksin	doc_213943984991_item	2283157	et	3	main
saaksin	doc_213943984991_item	2283165	et	3	main
ma	doc_213943984991_item	2283169	et	3	main
et	doc_213943984991_item	2283171	et	3	main
on	doc_213943984991_item	2283173	et	4	main
tahavad	doc_213943984991_item	2283181	et	3	main
saada	doc_213943984991_item	2283183	et	4	main
ilmunud	doc_213943984991_item	2283185	et	4	main
või	doc_213943984991_item	2283190	et	4	main
kirjutada	doc_213943984991_item	2283192	et	3	main
võib	doc_213943984991_item	2283202	et	3	main
ja	doc_213943984991_item	2283205	et	3	main
on	doc_213943984991_item	2283225	et	4	main
essee	doc_213943984992_item	2283228	et	4	main
valisin	doc_213943984992_item	2283232	et	3	main
2	doc_213943984992_item	2283235	et	2	main
ülikoolis	doc_213943984992_item	2283243	et	4	main
mulle	doc_213943984992_item	2283249	et	4	main
alati	doc_213943984992_item	2283250	et	4	main
erialad	doc_213943984992_item	2283252	et	3	main
muusikast	doc_213943984992_item	2283265	et	4	main
elust	doc_213943984992_item	2283268	et	3	main
kui	doc_213943984992_item	2283296	et	3	main
tahtmine	doc_213943984991_item	2282922	et	4	main
looda	doc_213943984991_item	2282926	et	4	main
kõik	doc_213943984991_item	2282935	et	4	main
ja	doc_213943984991_item	2282946	et	3	main
valisingi	doc_213943984991_item	2282948	et	3	main
eriala	doc_213943984991_item	2282950	et	4	main
mida	doc_213943984991_item	2282957	et	4	main
et	doc_213943984991_item	2282961	et	3	main
ja	doc_213943984991_item	2282972	et	3	main
näevad	doc_213943984991_item	2282981	et	3	main
ma	doc_213943984991_item	2282982	et	3	main
tahaksin	doc_213943984991_item	2282983	et	3	main
kirjutada	doc_213943984991_item	2282984	et	3	main
maailmast	doc_213943984991_item	2282985	et	4	main
mis	doc_213943984991_item	2282986	et	4	main
muutub	doc_213943984991_item	2282987	et	3	main
iga	doc_213943984991_item	2282988	et	4	main
tunniga	doc_213943984991_item	2282989	et	3	main
tahaksin	doc_213943984991_item	2282990	et	3	main
jälgida	doc_213943984991_item	2282991	et	3	main
iga	doc_213943984991_item	2282992	et	4	main
muutumist	doc_213943984991_item	2282993	et	4	main
ja	doc_213943984991_item	2282994	et	3	main
teatada	doc_213943984991_item	2282995	et	3	main
sellest	doc_213943984991_item	2282996	et	4	main
kõikidele	doc_213943984991_item	2282997	et	4	main
kellel	doc_213943984991_item	2282998	et	4	main
on	doc_213943984991_item	2282999	et	4	main
see	doc_213943984991_item	2283000	et	3	main
tähtis	doc_213943984991_item	2283001	et	4	main
ning	doc_213943984991_item	2283002	et	3	main
on	doc_213943984991_item	2283004	et	4	main
ka	doc_213943984991_item	2283005	et	3	main
see	doc_213943984991_item	2283003	et	3	main
oluline	doc_213943984991_item	2283006	et	4	main
teatada	doc_213943984991_item	2283007	et	3	main
nii	doc_213943984991_item	2283009	et	3	main
õige	doc_213943984991_item	2283010	et	4	main
kui	doc_213943984991_item	2283011	et	3	main
objektiivselt	doc_213943984991_item	2283008	et	4	main
see	doc_213943984991_item	2283012	et	3	main
on	doc_213943984991_item	2283013	et	4	main
võimalik	doc_213943984991_item	2283014	et	3	main
või	doc_213943984991_item	2283022	et	4	main
vale	doc_213943984991_item	2283025	et	4	main
on	doc_213943984991_item	2283028	et	4	main
võib	doc_213943984991_item	2283037	et	3	main
kaotada	doc_213943984991_item	2283038	et	3	main
sõnad	doc_213943984991_item	2283041	et	4	main
mida	doc_213943984991_item	2283053	et	4	main
kirjutakse	doc_213943984991_item	2283054	et	4	main
või	doc_213943984991_item	2283055	et	4	main
öeldakse	doc_213943984991_item	2283056	et	3	main
ajakirjanik	doc_213943984991_item	2283066	et	3	main
tahaksin	doc_213943984991_item	2283069	et	3	main
seda	doc_213943984991_item	2283071	et	3	main
elada	doc_213943984991_item	2283073	et	3	main
kõikidel	doc_213943984991_item	2283082	et	4	main
inimese	doc_213943984991_item	2283086	et	4	main
töö	doc_213943984991_item	2283089	et	4	main
ma	doc_213943984991_item	2283090	et	3	main
selleks	doc_213943984991_item	2283099	et	4	main
tugev	doc_213943984991_item	2283111	et	4	main
valisin	doc_213943984991_item	2283120	et	3	main
eriala	doc_213943984991_item	2283122	et	4	main
ja	doc_213943984991_item	2283130	et	3	main
ei	doc_213943984991_item	2283132	et	4	main
tea	doc_213943984991_item	2283133	et	4	main
viitud	doc_213943984991_item	2283149	et	4	main
kõige	doc_213943984991_item	2283153	et	4	main
olen	doc_213943984991_item	2283178	et	3	main
nad	doc_213943984991_item	2283194	et	3	main
sest	doc_213943984991_item	2283196	et	4	main
leht	doc_213943984991_item	2283198	et	3	main
pole	doc_213943984991_item	2283199	et	3	main
tü	doc_213943984991_item	2283222	et	4	main
ideaalne	doc_213943984991_item	2283226	et	3	main
miks	doc_213943984992_item	2283230	et	4	main
ja	doc_213943984992_item	2283241	et	3	main
tallinna	doc_213943984992_item	2283242	et	4	main
et	doc_213943984992_item	2283248	et	3	main
meeldisid	doc_213943984992_item	2283251	et	4	main
mis	doc_213943984992_item	2283253	et	4	main
seotud	doc_213943984992_item	2283254	et	4	main
ja	doc_213943984992_item	2283266	et	3	main
kultuuri	doc_213943984992_item	2283267	et	4	main
ma	doc_213943984992_item	2283297	et	3	main
ma	doc_213943984992_item	2283302	et	3	main
et	doc_213943984992_item	2283304	et	3	main
võimalus	doc_213943984992_item	2283311	et	3	main
sellest	doc_213943984992_item	2283313	et	4	main
on	doc_213943984991_item	2283024	et	4	main
mõtlen	doc_213943984991_item	2283026	et	3	main
seda	doc_213943984991_item	2283030	et	3	main
nägu	doc_213943984991_item	2283036	et	4	main
ajaloos	doc_213943984991_item	2283044	et	4	main
end	doc_213943984991_item	2283048	et	4	main
alati	doc_213943984991_item	2283049	et	4	main
kontrollida	doc_213943984991_item	2283050	et	4	main
ja	doc_213943984991_item	2283051	et	3	main
mõtelda	doc_213943984991_item	2283052	et	4	main
inimestele	doc_213943984991_item	2283058	et	3	main
ma	doc_213943984991_item	2283059	et	3	main
et	doc_213943984991_item	2283061	et	3	main
kus	doc_213943984991_item	2283080	et	3	main
oma	doc_213943984991_item	2283083	et	4	main
pea	doc_213943984991_item	2283092	et	4	main
ma	doc_213943984991_item	2283096	et	3	main
sellepärast	doc_213943984991_item	2283101	et	3	main
tulingi	doc_213943984991_item	2283104	et	3	main
on	doc_213943984991_item	2283110	et	4	main
selle	doc_213943984991_item	2283121	et	4	main
esimene	doc_213943984991_item	2283127	et	3	main
sellel	doc_213943984991_item	2283137	et	4	main
mina	doc_213943984991_item	2283140	et	4	main
ootan	doc_213943984991_item	2283142	et	3	main
palju	doc_213943984991_item	2283143	et	4	main
ma	doc_213943984991_item	2283144	et	3	main
tahaksin	doc_213943984991_item	2283145	et	3	main
küll	doc_213943984991_item	2283146	et	4	main
saaks	doc_213943984991_item	2283151	et	3	main
minu	doc_213943984991_item	2283152	et	3	main
tõelised	doc_213943984991_item	2283161	et	4	main
kellega	doc_213943984991_item	2283164	et	3	main
mõttedega	doc_213943984991_item	2283167	et	4	main
loodan	doc_213943984991_item	2283170	et	3	main
natuke	doc_213943984991_item	2283174	et	4	main
mina	doc_213943984991_item	2283176	et	4	main
ise	doc_213943984991_item	2283177	et	4	main
hiljuti	doc_213943984991_item	2283184	et	4	main
asjadest	doc_213943984991_item	2283186	et	3	main
ja	doc_213943984991_item	2283187	et	3	main
mõtlevad	doc_213943984991_item	2283195	et	4	main
2	doc_213943984991_item	2283123	et	2	main
ma	doc_213943984991_item	2283131	et	3	main
ootab	doc_213943984991_item	2283135	et	3	main
vaid	doc_213943984991_item	2283139	et	3	main
aeg	doc_213943984991_item	2283150	et	3	main
ma	doc_213943984991_item	2283156	et	3	main
mul	doc_213943984991_item	2283159	et	3	main
nad	doc_213943984991_item	2283172	et	3	main
nagu	doc_213943984991_item	2283175	et	3	main
kes	doc_213943984991_item	2283180	et	4	main
kirjeldada	doc_213943984991_item	2283188	et	3	main
neid	doc_213943984991_item	2283189	et	4	main
mida	doc_213943984991_item	2283193	et	4	main
valge	doc_213943984991_item	2283197	et	4	main
inimene	doc_213943984991_item	2283200	et	3	main
kõikest	doc_213943984991_item	2283204	et	4	main
kõigest	doc_213943984991_item	2283206	et	4	main
mina	doc_213943984991_item	2283207	et	4	main
ka	doc_213943984991_item	2283208	et	3	main
tahaksin	doc_213943984991_item	2283209	et	3	main
seda	doc_213943984991_item	2283211	et	3	main
küll	doc_213943984991_item	2283210	et	4	main
eriala	doc_213943984991_item	2283212	et	4	main
hästi	doc_213943984991_item	2283213	et	3	main
õppida	doc_213943984991_item	2283214	et	3	main
et	doc_213943984991_item	2283215	et	3	main
professionaaliks	doc_213943984991_item	2283216	et	4	main
oma	doc_213943984991_item	2283217	et	4	main
töös	doc_213943984991_item	2283218	et	3	main
saada	doc_213943984991_item	2283219	et	4	main
mõtlen	doc_213943984991_item	2283220	et	3	main
selle	doc_213943984991_item	2283223	et	4	main
jaoks	doc_213943984991_item	2283224	et	4	main
ma	doc_213943984992_item	2283231	et	3	main
sellel	doc_213943984992_item	2283239	et	4	main
erialal	doc_213943984992_item	2283240	et	3	main
ütelda	doc_213943984992_item	2283247	et	4	main
inimestega	doc_213943984992_item	2283255	et	3	main
suhtlemistega	doc_213943984992_item	2283257	et	4	main
ma	doc_213943984992_item	2283259	et	3	main
koolis	doc_213943984992_item	2283261	et	4	main
kirjutasin	doc_213943984992_item	2283263	et	3	main
probleemid	doc_213943984992_item	2283295	et	3	main
on	doc_213943984992_item	2283315	et	4	main
kõigepealt	doc_213943984992_item	2283320	et	3	main
pead	doc_213943984992_item	2283322	et	4	main
auselt	doc_213943984992_item	2283325	et	4	main
valida	doc_213943984992_item	2283329	et	3	main
ma	doc_213943984992_item	2283331	et	3	main
õppima	doc_213943984992_item	2283333	et	3	main
omandamine	doc_213943984992_item	2283350	et	4	main
meeldib	doc_213943984992_item	2283366	et	3	main
inimesed	doc_213943984992_item	2283372	et	3	main
ülikooli	doc_213943984992_item	2283380	et	4	main
see	doc_213943984992_item	2283388	et	3	main
meeldib	doc_213943984992_item	2283395	et	3	main
sõbrad	doc_213943984992_item	2283397	et	3	main
et	doc_213943984992_item	2283405	et	3	main
põnev	doc_213943984992_item	2283410	et	3	main
et	doc_213943984992_item	2283412	et	3	main
siin	doc_213943984992_item	2283414	et	4	main
teadmisi	doc_213943984992_item	2283416	et	4	main
mis	doc_213943984992_item	2283417	et	4	main
atavad	doc_213943984992_item	2283418	et	3	main
tean	doc_213943984992_item	2283421	et	3	main
valida	doc_213943984992_item	2283426	et	3	main
õppeaineid	doc_213943984992_item	2283429	et	3	main
koht	doc_213943984991_item	2283227	et	3	main
eriala	doc_213943984992_item	2283234	et	4	main
tahaksin	doc_213943984992_item	2283246	et	3	main
kui	doc_213943984992_item	2283258	et	3	main
õppisin	doc_213943984992_item	2283260	et	3	main
ma	doc_213943984992_item	2283262	et	3	main
linnas	doc_213943984992_item	2283270	et	4	main
neid	doc_213943984992_item	2283271	et	4	main
artikleid	doc_213943984992_item	2283272	et	3	main
ma	doc_213943984992_item	2283273	et	3	main
panin	doc_213943984992_item	2283274	et	3	main
internetile	doc_213943984992_item	2283275	et	4	main
üks	doc_213943984992_item	2283276	et	3	main
kord	doc_213943984992_item	2283277	et	4	main
minu	doc_213943984992_item	2283278	et	3	main
tuttav	doc_213943984992_item	2283279	et	3	main
ajakirjanik	doc_213943984992_item	2283280	et	3	main
ütles	doc_213943984992_item	2283281	et	3	main
mulle	doc_213943984992_item	2283282	et	4	main
et	doc_213943984992_item	2283283	et	3	main
on	doc_213943984992_item	2283284	et	4	main
võimalik	doc_213943984992_item	2283285	et	3	main
kirjutada	doc_213943984992_item	2283286	et	3	main
artikli	doc_213943984992_item	2283287	et	3	main
ajalehesse	doc_213943984992_item	2283288	et	3	main
artikli	doc_213943984992_item	2283289	et	3	main
oli	doc_213943984992_item	2283291	et	3	main
noored	doc_213943984992_item	2283292	et	3	main
ja	doc_213943984992_item	2283293	et	3	main
nende	doc_213943984992_item	2283294	et	4	main
teema	doc_213943984992_item	2283290	et	4	main
ja	doc_213943984992_item	2283256	et	3	main
artikli	doc_213943984992_item	2283264	et	3	main
meie	doc_213943984992_item	2283269	et	4	main
ajalehti	doc_213943984992_item	2283299	et	4	main
see	doc_213943984992_item	2283305	et	3	main
suurepärane	doc_213943984992_item	2283307	et	4	main
kui	doc_213943984992_item	2283308	et	3	main
sul	doc_213943984992_item	2283309	et	3	main
mis	doc_213943984992_item	2283314	et	4	main
teistele	doc_213943984992_item	2283318	et	4	main
selle	doc_213943984992_item	2283324	et	4	main
konkreetselt	doc_213943984992_item	2283335	et	4	main
mida	doc_213943984992_item	2283337	et	4	main
2	doc_213943984992_item	2283340	et	2	main
et	doc_213943984992_item	2283343	et	3	main
tallinna	doc_213943984992_item	2283345	et	4	main
ja	doc_213943984992_item	2283347	et	3	main
ajakirjanike	doc_213943984992_item	2283348	et	3	main
eriala	doc_213943984992_item	2283349	et	4	main
aitab	doc_213943984992_item	2283351	et	3	main
mulle	doc_213943984992_item	2283352	et	4	main
tegelema	doc_213943984992_item	2283353	et	3	main
nad	doc_213943984992_item	2283368	et	3	main
meeskonnaks	doc_213943984992_item	2283376	et	4	main
on	doc_213943984992_item	2283385	et	4	main
õppida	doc_213943984992_item	2283387	et	3	main
sulle	doc_213943984992_item	2283394	et	3	main
minu	doc_213943984992_item	2283396	et	3	main
ütlesid	doc_213943984992_item	2283404	et	4	main
elu	doc_213943984992_item	2283407	et	4	main
loodan	doc_213943984992_item	2283411	et	3	main
hoidsin	doc_213943984992_item	2283298	et	3	main
minu	doc_213943984992_item	2283300	et	3	main
tundsin	doc_213943984992_item	2283303	et	3	main
on	doc_213943984992_item	2283306	et	4	main
tahtis	doc_213943984992_item	2283316	et	3	main
teada	doc_213943984992_item	2283317	et	3	main
tegema	doc_213943984992_item	2283323	et	3	main
tuli	doc_213943984992_item	2283327	et	4	main
kuhu	doc_213943984992_item	2283330	et	3	main
lähen	doc_213943984992_item	2283332	et	3	main
tahaksin	doc_213943984992_item	2283339	et	3	main
ma	doc_213943984992_item	2283341	et	3	main
ülikoolis	doc_213943984992_item	2283346	et	4	main
tõesti	doc_213943984992_item	2283370	et	3	main
huvitav	doc_213943984992_item	2283386	et	4	main
ja	doc_213943984992_item	2283403	et	3	main
omandan	doc_213943984992_item	2283413	et	3	main
mind	doc_213943984992_item	2283419	et	4	main
võimalus	doc_213943984992_item	2283425	et	3	main
huvitavaid	doc_213943984992_item	2283428	et	4	main
saada	doc_213943984992_item	2283431	et	4	main
loodan	doc_213943984992_item	2283434	et	3	main
tallina	doc_213943984992_item	2283436	et	3	main
aitab	doc_213943984992_item	2283438	et	3	main
eriala	doc_213943984993_item	2283446	et	4	main
ootan	doc_213943984993_item	2283449	et	3	main
sellel	doc_213943984993_item	2283451	et	4	main
erialal	doc_213943984993_item	2283452	et	3	main
ja	doc_213943984993_item	2283453	et	3	main
milleks	doc_213943984993_item	2283461	et	4	main
on	doc_213943984993_item	2283469	et	4	main
need	doc_213943984993_item	2283505	et	3	main
siis	doc_213943984993_item	2283508	et	3	main
ja	doc_213943984993_item	2283511	et	3	main
tudengi	doc_213943984993_item	2283514	et	3	main
elust	doc_213943984993_item	2283522	et	3	main
kohas	doc_213943984993_item	2283533	et	4	main
meist	doc_213943984993_item	2283536	et	3	main
ning	doc_213943984993_item	2283542	et	3	main
eluvaade	doc_213943984993_item	2283544	et	3	main
ja	doc_213943984993_item	2283550	et	3	main
ainult	doc_213943984993_item	2283553	et	4	main
oleks	doc_213943984993_item	2283602	et	3	main
et	doc_213943984993_item	2283605	et	3	main
ma	doc_213943984993_item	2283607	et	3	main
selle	doc_213943984993_item	2283608	et	4	main
jaoks	doc_213943984993_item	2283619	et	4	main
õige	doc_213943984993_item	2283620	et	4	main
jõudmiseks	doc_213943984993_item	2283625	et	4	main
esimest	doc_213943984993_item	2283628	et	4	main
siia	doc_213943984993_item	2283630	et	4	main
astudes	doc_213943984993_item	2283632	et	3	main
sain	doc_213943984993_item	2283634	et	3	main
ei	doc_213943984993_item	2283638	et	4	main
enne	doc_213943984993_item	2283643	et	4	main
saades	doc_213943984993_item	2283645	et	3	main
teadsin	doc_213943984993_item	2283647	et	3	main
õpitakse	doc_213943984993_item	2283653	et	4	main
oli	doc_213943984993_item	2283655	et	3	main
mulle	doc_213943984993_item	2283656	et	4	main
minu	doc_213943984993_item	2283657	et	3	main
ning	doc_213943984993_item	2283666	et	3	main
ma	doc_213943984993_item	2283668	et	3	main
teiste	doc_213943984993_item	2283672	et	4	main
ka	doc_213943984993_item	2283704	et	3	main
oleks	doc_213943984993_item	2283707	et	3	main
tegevusest	doc_213943984993_item	2283710	et	4	main
enda	doc_213943984993_item	2283714	et	4	main
nõudmisi	doc_213943984993_item	2283724	et	4	main
mulle	doc_213943984993_item	2283731	et	4	main
tahan	doc_213943984993_item	2283737	et	3	main
on	doc_213943984993_item	2283739	et	4	main
mulle	doc_213943984993_item	2283740	et	4	main
kasulik	doc_213943984993_item	2283744	et	3	main
asja	doc_213943984993_item	2283749	et	4	main
täita	doc_213943984993_item	2283763	et	4	main
meile	doc_213943984993_item	2283772	et	4	main
unistus	doc_213943984994_item	2283784	et	4	main
või	doc_213943984994_item	2283788	et	4	main
aga	doc_213943984994_item	2283790	et	3	main
õnnestunud	doc_213943984994_item	2283796	et	4	main
astuda	doc_213943984994_item	2283800	et	3	main
artikliga	doc_213943984992_item	2283301	et	3	main
on	doc_213943984992_item	2283310	et	4	main
rääkida	doc_213943984992_item	2283312	et	3	main
inimestele	doc_213943984992_item	2283319	et	3	main
sa	doc_213943984992_item	2283321	et	3	main
kui	doc_213943984992_item	2283326	et	3	main
teadsin	doc_213943984992_item	2283336	et	3	main
ma	doc_213943984992_item	2283338	et	3	main
mõtlen	doc_213943984992_item	2283342	et	3	main
on	doc_213943984992_item	2283369	et	4	main
siin	doc_213943984992_item	2283384	et	4	main
alati	doc_213943984992_item	2283390	et	4	main
teha	doc_213943984992_item	2283392	et	3	main
kes	doc_213943984992_item	2283398	et	4	main
on	doc_213943984992_item	2283399	et	4	main
vanem	doc_213943984992_item	2283400	et	4	main
õppisid	doc_213943984992_item	2283401	et	4	main
palju	doc_213943984992_item	2283415	et	4	main
mul	doc_213943984992_item	2283423	et	3	main
et	doc_213943984992_item	2283435	et	3	main
essee	doc_213943984993_item	2283440	et	4	main
valisin	doc_213943984993_item	2283444	et	3	main
ülikoolis	doc_213943984993_item	2283455	et	4	main
miks	doc_213943984993_item	2283456	et	4	main
ma	doc_213943984993_item	2283457	et	3	main
valisin	doc_213943984993_item	2283458	et	3	main
ajakirjanduse	doc_213943984993_item	2283459	et	3	main
üldse	doc_213943984993_item	2283463	et	3	main
ülikooli	doc_213943984993_item	2283466	et	4	main
vastu	doc_213943984993_item	2283503	et	3	main
mõne	doc_213943984993_item	2283513	et	3	main
saada	doc_213943984993_item	2283521	et	4	main
bakalauruse	doc_213943984993_item	2283526	et	4	main
hea	doc_213943984993_item	2283529	et	4	main
rikkalikum	doc_213943984993_item	2283543	et	4	main
valivad	doc_213943984993_item	2283547	et	4	main
teid	doc_213943984993_item	2283549	et	4	main
mitte	doc_213943984993_item	2283552	et	3	main
põhjusel	doc_213943984993_item	2283565	et	3	main
nad	doc_213943984993_item	2283567	et	3	main
kasuks	doc_213943984993_item	2283588	et	4	main
see	doc_213943984993_item	2283590	et	3	main
hea	doc_213943984993_item	2283592	et	4	main
siin	doc_213943984993_item	2283594	et	4	main
klassis	doc_213943984993_item	2283595	et	3	main
teiste	doc_213943984993_item	2283596	et	4	main
tuplide	doc_213943984993_item	2283597	et	4	main
nii	doc_213943984993_item	2283604	et	3	main
miks	doc_213943984993_item	2283606	et	4	main
see	doc_213943984993_item	2283615	et	3	main
ainus	doc_213943984993_item	2283622	et	4	main
majja	doc_213943984993_item	2283631	et	3	main
kohe	doc_213943984993_item	2283633	et	4	main
tunda	doc_213943984993_item	2283635	et	3	main
et	doc_213943984993_item	2283636	et	3	main
juba	doc_213943984993_item	2283642	et	3	main
ma	doc_213943984993_item	2283646	et	3	main
siin	doc_213943984993_item	2283649	et	4	main
õde	doc_213943984993_item	2283658	et	4	main
kes	doc_213943984993_item	2283660	et	4	main
mida	doc_213943984993_item	2283667	et	4	main
ka	doc_213943984993_item	2283671	et	3	main
mida	doc_213943984993_item	2283711	et	4	main
ei	doc_213943984993_item	2283720	et	4	main
aeg	doc_213943984992_item	2283328	et	3	main
ma	doc_213943984992_item	2283334	et	3	main
õppimine	doc_213943984992_item	2283344	et	4	main
sellega	doc_213943984992_item	2283354	et	3	main
mis	doc_213943984992_item	2283355	et	4	main
mulle	doc_213943984992_item	2283356	et	4	main
tõesti	doc_213943984992_item	2283357	et	3	main
meeldib	doc_213943984992_item	2283358	et	3	main
ma	doc_213943984992_item	2283359	et	3	main
loodan	doc_213943984992_item	2283360	et	3	main
et	doc_213943984992_item	2283361	et	3	main
meie	doc_213943984992_item	2283362	et	4	main
rühm	doc_213943984992_item	2283363	et	3	main
mis	doc_213943984992_item	2283364	et	4	main
väga	doc_213943984992_item	2283365	et	3	main
mulle	doc_213943984992_item	2283367	et	4	main
huvitavad	doc_213943984992_item	2283371	et	4	main
tulevikus	doc_213943984992_item	2283373	et	4	main
saab	doc_213943984992_item	2283374	et	3	main
sõbralikuks	doc_213943984992_item	2283375	et	3	main
mulle	doc_213943984992_item	2283377	et	4	main
meeldib	doc_213943984992_item	2283378	et	3	main
tallinna	doc_213943984992_item	2283379	et	4	main
atmosfäär	doc_213943984992_item	2283381	et	3	main
mõtlen	doc_213943984992_item	2283382	et	3	main
et	doc_213943984992_item	2283383	et	3	main
on	doc_213943984992_item	2283389	et	4	main
huvitav	doc_213943984992_item	2283391	et	4	main
mis	doc_213943984992_item	2283393	et	4	main
siin	doc_213943984992_item	2283402	et	4	main
ülikooli	doc_213943984992_item	2283406	et	4	main
on	doc_213943984992_item	2283408	et	4	main
väga	doc_213943984992_item	2283409	et	3	main
tulevikus	doc_213943984992_item	2283420	et	4	main
et	doc_213943984992_item	2283422	et	3	main
palju	doc_213943984992_item	2283427	et	4	main
ja	doc_213943984992_item	2283433	et	3	main
mind	doc_213943984992_item	2283439	et	4	main
1	doc_213943984993_item	2283441	et	2	main
selle	doc_213943984993_item	2283445	et	4	main
mida	doc_213943984993_item	2283448	et	4	main
õppimisest	doc_213943984993_item	2283450	et	4	main
tulin	doc_213943984993_item	2283464	et	3	main
mul	doc_213943984993_item	2283496	et	3	main
olnud	doc_213943984993_item	2283499	et	4	main
huvi	doc_213943984993_item	2283501	et	4	main
ajakirjanduse	doc_213943984993_item	2283502	et	3	main
tunduks	doc_213943984993_item	2283507	et	3	main
tavapärased	doc_213943984993_item	2283510	et	4	main
küll	doc_213943984993_item	2283516	et	4	main
on	doc_213943984992_item	2283424	et	4	main
spetsialistiks	doc_213943984992_item	2283432	et	3	main
ülikool	doc_213943984992_item	2283437	et	4	main
miks	doc_213943984993_item	2283442	et	4	main
ma	doc_213943984993_item	2283443	et	3	main
tallinna	doc_213943984993_item	2283454	et	4	main
tallinna	doc_213943984993_item	2283465	et	4	main
need	doc_213943984993_item	2283467	et	3	main
head	doc_213943984993_item	2283470	et	4	main
küsimustest	doc_213943984993_item	2283472	et	4	main
millega	doc_213943984993_item	2283473	et	3	main
saab	doc_213943984993_item	2283474	et	3	main
rebase	doc_213943984993_item	2283475	et	4	main
mõtlema	doc_213943984993_item	2283476	et	3	main
panna	doc_213943984993_item	2283477	et	4	main
ja	doc_213943984993_item	2283478	et	3	main
omaenda	doc_213943984993_item	2283479	et	3	main
tahtmises	doc_213943984993_item	2283480	et	4	main
ja	doc_213943984993_item	2283481	et	3	main
soovides	doc_213943984993_item	2283482	et	4	main
orienteeruda	doc_213943984993_item	2283484	et	3	main
täpsemini	doc_213943984993_item	2283483	et	4	main
kuid	doc_213943984993_item	2283485	et	4	main
kas	doc_213943984993_item	2283486	et	3	main
sellised	doc_213943984993_item	2283487	et	4	main
vastused	doc_213943984993_item	2283488	et	3	main
nagu	doc_213943984993_item	2283489	et	3	main
ma	doc_213943984993_item	2283490	et	3	main
tõepoolest	doc_213943984993_item	2283491	et	3	main
tahan	doc_213943984993_item	2283492	et	3	main
ajakirjanikuks	doc_213943984993_item	2283493	et	3	main
saada	doc_213943984993_item	2283494	et	4	main
või	doc_213943984993_item	2283495	et	4	main
tahaksin	doc_213943984992_item	2283430	et	3	main
2	doc_213943984993_item	2283447	et	2	main
eriala	doc_213943984993_item	2283460	et	4	main
ma	doc_213943984993_item	2283462	et	3	main
siin	doc_213943984993_item	2283468	et	4	main
näidised	doc_213943984993_item	2283471	et	3	main
alati	doc_213943984993_item	2283498	et	4	main
tõsine	doc_213943984993_item	2283500	et	4	main
kas	doc_213943984993_item	2283504	et	3	main
natukene	doc_213943984993_item	2283523	et	4	main
ajakirjanduses	doc_213943984993_item	2283528	et	3	main
palk	doc_213943984993_item	2283530	et	3	main
eneseväärikust	doc_213943984993_item	2283541	et	4	main
inimesed	doc_213943984993_item	2283546	et	3	main
enda	doc_213943984993_item	2283556	et	4	main
kindlustada	doc_213943984993_item	2283558	et	3	main
saades	doc_213943984993_item	2283559	et	3	main
ka	doc_213943984993_item	2283563	et	3	main
et	doc_213943984993_item	2283566	et	3	main
ka	doc_213943984993_item	2283586	et	3	main
kas	doc_213943984993_item	2283589	et	3	main
oleks	doc_213943984993_item	2283591	et	3	main
jah	doc_213943984993_item	2283603	et	3	main
eriala	doc_213943984993_item	2283609	et	4	main
valisin	doc_213943984993_item	2283610	et	3	main
sest	doc_213943984993_item	2283611	et	4	main
ma	doc_213943984993_item	2283612	et	3	main
arvan	doc_213943984993_item	2283613	et	3	main
tee	doc_213943984993_item	2283616	et	4	main
on	doc_213943984993_item	2283497	et	4	main
ei	doc_213943984993_item	2283506	et	4	main
kuidagi	doc_213943984993_item	2283509	et	3	main
banaalsed	doc_213943984993_item	2283512	et	3	main
puhul	doc_213943984993_item	2283515	et	4	main
sest	doc_213943984993_item	2283517	et	4	main
mõned	doc_213943984993_item	2283518	et	3	main
meist	doc_213943984993_item	2283519	et	3	main
tahavad	doc_213943984993_item	2283520	et	3	main
kui	doc_213943984993_item	2283525	et	3	main
kraad	doc_213943984993_item	2283527	et	3	main
on	doc_213943984993_item	2283537	et	4	main
rohkem	doc_213943984993_item	2283538	et	4	main
unistusi	doc_213943984993_item	2283539	et	4	main
rohkem	doc_213943984993_item	2283540	et	4	main
selleks	doc_213943984993_item	2283554	et	4	main
tuleviku	doc_213943984993_item	2283557	et	4	main
hea	doc_213943984993_item	2283560	et	4	main
kui	doc_213943984993_item	2283585	et	3	main
inimestega	doc_213943984993_item	2283598	et	3	main
viibimiseks	doc_213943984993_item	2283599	et	4	main
minu	doc_213943984993_item	2283600	et	3	main
et	doc_213943984993_item	2283614	et	3	main
minu	doc_213943984993_item	2283618	et	3	main
eesmärkideni	doc_213943984993_item	2283624	et	3	main
ja	doc_213943984993_item	2283626	et	3	main
tegu	doc_213943984993_item	2283637	et	4	main
ülikooliga	doc_213943984993_item	2283641	et	4	main
õpetatakse	doc_213943984993_item	2283650	et	3	main
rääkinud	doc_213943984993_item	2283659	et	4	main
on	doc_213943984993_item	2283661	et	4	main
siin	doc_213943984993_item	2283662	et	4	main
juba	doc_213943984993_item	2283663	et	3	main
kuulnud	doc_213943984993_item	2283670	et	4	main
rebastel	doc_213943984993_item	2283706	et	4	main
näidis	doc_213943984993_item	2283709	et	4	main
ka	doc_213943984993_item	2283713	et	3	main
tavapäraseks	doc_213943984993_item	2283716	et	4	main
vaid	doc_213943984993_item	2283729	et	3	main
õppida	doc_213943984993_item	2283734	et	3	main
huvi	doc_213943984993_item	2283741	et	4	main
pakkuv	doc_213943984993_item	2283742	et	4	main
ja	doc_213943984993_item	2283743	et	3	main
et	doc_213943984993_item	2283756	et	3	main
ning	doc_213943984993_item	2283764	et	3	main
saada	doc_213943984994_item	2283786	et	4	main
aastal	doc_213943984994_item	2283792	et	3	main
ma	doc_213943984994_item	2283797	et	3	main
moskvas	doc_213943984994_item	2283801	et	4	main
mulle	doc_213943984994_item	2283806	et	4	main
kõige	doc_213943984994_item	2283807	et	4	main
tunnen	doc_213943984994_item	2283815	et	3	main
luulejaks	doc_213943984994_item	2283829	et	3	main
et	doc_213943984994_item	2283831	et	3	main
ideesid	doc_213943984994_item	2283835	et	3	main
ja	doc_213943984994_item	2283836	et	3	main
mõttesid	doc_213943984994_item	2283837	et	4	main
ka	doc_213943984994_item	2283844	et	3	main
aru	doc_213943984994_item	2283848	et	4	main
teiselt	doc_213943984994_item	2283850	et	4	main
ei	doc_213943984994_item	2283854	et	4	main
ole	doc_213943984994_item	2283855	et	4	main
nii	doc_213943984994_item	2283856	et	3	main
romaane	doc_213943984994_item	2283860	et	3	main
ajakirjandus	doc_213943984994_item	2283863	et	3	main
mulle	doc_213943984994_item	2283865	et	4	main
tahaksin	doc_213943984994_item	2283867	et	3	main
et	doc_213943984994_item	2283869	et	3	main
et	doc_213943984994_item	2283875	et	3	main
muutuksid	doc_213943984994_item	2283878	et	4	main
et	doc_213943984994_item	2283880	et	3	main
oli	doc_213943984994_item	2283918	et	3	main
paremini	doc_213943984994_item	2283930	et	4	main
keeli	doc_213943984994_item	2283947	et	4	main
kirjandusest	doc_213943984994_item	2283954	et	4	main
on	doc_213943984994_item	2283962	et	4	main
tark	doc_213943984994_item	2283963	et	3	main
ja	doc_213943984994_item	2283974	et	3	main
elu	doc_213943984994_item	2283976	et	4	main
huvitavaks	doc_213943984994_item	2283978	et	4	main
1	doc_213943984995_item	2284018	et	2	main
ma	doc_213943984995_item	2284020	et	3	main
rohkem	doc_213943984993_item	2283524	et	4	main
kuskil	doc_213943984993_item	2283531	et	3	main
heas	doc_213943984993_item	2283532	et	3	main
jne	doc_213943984993_item	2283534	et	4	main
mõnel	doc_213943984993_item	2283535	et	3	main
need	doc_213943984993_item	2283545	et	3	main
erinevaid	doc_213943984993_item	2283548	et	4	main
võimalusi	doc_213943984993_item	2283551	et	3	main
et	doc_213943984993_item	2283555	et	3	main
hariduse	doc_213943984993_item	2283561	et	3	main
kuid	doc_213943984993_item	2283562	et	4	main
sel	doc_213943984993_item	2283564	et	3	main
tahavad	doc_213943984993_item	2283568	et	3	main
avastada	doc_213943984993_item	2283569	et	3	main
endas	doc_213943984993_item	2283570	et	4	main
uue	doc_213943984993_item	2283571	et	3	main
ja	doc_213943984993_item	2283572	et	3	main
parema	doc_213943984993_item	2283573	et	4	main
isiksuse	doc_213943984993_item	2283574	et	3	main
anda	doc_213943984993_item	2283575	et	3	main
ühiskonnale	doc_213943984993_item	2283576	et	4	main
mõtleva	doc_213943984993_item	2283577	et	4	main
ja	doc_213943984993_item	2283578	et	3	main
kindla	doc_213943984993_item	2283579	et	3	main
arusaamisega	doc_213943984993_item	2283580	et	4	main
inimese	doc_213943984993_item	2283581	et	4	main
mitte	doc_213943984993_item	2283582	et	3	main
vaid	doc_213943984993_item	2283583	et	3	main
enda	doc_213943984993_item	2283584	et	4	main
teiste	doc_213943984993_item	2283587	et	4	main
põhjus	doc_213943984993_item	2283593	et	4	main
arust	doc_213943984993_item	2283601	et	4	main
on	doc_213943984993_item	2283617	et	4	main
ja	doc_213943984993_item	2283621	et	3	main
minu	doc_213943984993_item	2283623	et	3	main
realiseerimiseks	doc_213943984993_item	2283627	et	4	main
lihtsa	doc_213943984993_item	2283640	et	3	main
ka	doc_213943984993_item	2283652	et	3	main
mida	doc_213943984993_item	2283654	et	4	main
magistrikraadi	doc_213943984993_item	2283664	et	4	main
tegemas	doc_213943984993_item	2283665	et	3	main
olen	doc_213943984993_item	2283669	et	3	main
tuttavate	doc_213943984993_item	2283673	et	3	main
meil	doc_213943984993_item	2283705	et	4	main
peab	doc_213943984993_item	2283712	et	4	main
otsi	doc_213943984993_item	2283721	et	4	main
eirlisi	doc_213943984993_item	2283723	et	4	main
et	doc_213943984993_item	2283730	et	3	main
võimalus	doc_213943984993_item	2283733	et	3	main
seda	doc_213943984993_item	2283735	et	3	main
mis	doc_213943984993_item	2283738	et	4	main
kindel	doc_213943984993_item	2283746	et	3	main
minu	doc_213943984993_item	2283753	et	3	main
klassikaaslased	doc_213943984993_item	2283754	et	3	main
nii	doc_213943984993_item	2283755	et	3	main
nõudmist	doc_213943984993_item	2283760	et	4	main
ise	doc_213943984993_item	2283766	et	4	main
sellega	doc_213943984993_item	2283769	et	3	main
äitahh	doc_213943984993_item	2283773	et	4	main
essee	doc_213943984994_item	2283775	et	4	main
ma	doc_213943984994_item	2283777	et	3	main
valisin	doc_213943984994_item	2283778	et	3	main
selle	doc_213943984994_item	2283779	et	4	main
lauljaks	doc_213943984994_item	2283787	et	4	main
näitlejaks	doc_213943984994_item	2283789	et	4	main
sellel	doc_213943984994_item	2283791	et	4	main
proovisin	doc_213943984994_item	2283798	et	3	main
ja	doc_213943984994_item	2283811	et	3	main
huvi	doc_213943984994_item	2283816	et	4	main
vastu	doc_213943984994_item	2283818	et	3	main
loen	doc_213943984994_item	2283820	et	3	main
sellepärast	doc_213943984994_item	2283830	et	3	main
mul	doc_213943984994_item	2283832	et	3	main
inimesed	doc_213943984994_item	2283843	et	3	main
selles	doc_213943984994_item	2283861	et	4	main
sobib	doc_213943984994_item	2283864	et	3	main
järelduseks	doc_213943984994_item	2283866	et	4	main
armastan	doc_213943984994_item	2283871	et	3	main
ja	doc_213943984994_item	2283873	et	3	main
koguaeg	doc_213943984994_item	2283877	et	3	main
et	doc_213943984994_item	2283915	et	3	main
mulle	doc_213943984994_item	2283921	et	4	main
tahaksin	doc_213943984994_item	2283924	et	3	main
siin	doc_213943984994_item	2283926	et	4	main
vene	doc_213943984994_item	2283935	et	4	main
eesti	doc_213943984994_item	2283938	et	4	main
inglise	doc_213943984994_item	2283939	et	4	main
prantsuse	doc_213943984994_item	2283940	et	3	main
tahan	doc_213943984994_item	2283948	et	3	main
ma	doc_213943984994_item	2283967	et	3	main
siit	doc_213943984994_item	2283971	et	3	main
sõpru	doc_213943984994_item	2283973	et	3	main
ülikooli	doc_213943984994_item	2283975	et	4	main
minu	doc_213943984994_item	2283984	et	3	main
essee	doc_213943984995_item	2284017	et	4	main
korda	doc_213943984993_item	2283629	et	4	main
ole	doc_213943984993_item	2283639	et	4	main
siia	doc_213943984993_item	2283644	et	4	main
kuidas	doc_213943984993_item	2283648	et	3	main
ning	doc_213943984993_item	2283651	et	3	main
käest	doc_213943984993_item	2283674	et	4	main
kes	doc_213943984993_item	2283675	et	4	main
on	doc_213943984993_item	2283676	et	4	main
selles	doc_213943984993_item	2283677	et	4	main
majas	doc_213943984993_item	2283678	et	3	main
õppinud	doc_213943984993_item	2283679	et	4	main
või	doc_213943984993_item	2283680	et	4	main
on	doc_213943984993_item	2283681	et	4	main
hariduse	doc_213943984993_item	2283682	et	3	main
saamisel	doc_213943984993_item	2283683	et	4	main
et	doc_213943984993_item	2283684	et	3	main
mida	doc_213943984993_item	2283685	et	4	main
ma	doc_213943984993_item	2283686	et	3	main
ootan	doc_213943984993_item	2283687	et	3	main
meie	doc_213943984993_item	2283688	et	4	main
ülikoolis	doc_213943984993_item	2283689	et	4	main
õppimisest	doc_213943984993_item	2283690	et	4	main
õpetamist	doc_213943984993_item	2283691	et	4	main
kõigepealt	doc_213943984993_item	2283692	et	3	main
head	doc_213943984993_item	2283693	et	4	main
võimalust	doc_213943984993_item	2283694	et	3	main
teadmiste	doc_213943984993_item	2283695	et	4	main
saamiseks	doc_213943984993_item	2283696	et	4	main
julgustavat	doc_213943984993_item	2283698	et	4	main
ja	doc_213943984993_item	2283699	et	3	main
hooleka	doc_213943984993_item	2283700	et	4	main
ning	doc_213943984993_item	2283697	et	3	main
õppejõudude	doc_213943984993_item	2283701	et	3	main
tööd	doc_213943984993_item	2283702	et	4	main
et	doc_213943984993_item	2283703	et	3	main
hea	doc_213943984993_item	2283708	et	4	main
jaoks	doc_213943984993_item	2283715	et	4	main
teha	doc_213943984993_item	2283717	et	3	main
mina	doc_213943984993_item	2283718	et	4	main
ise	doc_213943984993_item	2283719	et	4	main
mingeid	doc_213943984993_item	2283722	et	3	main
minu	doc_213943984993_item	2283725	et	3	main
tahan	doc_213943984993_item	2283728	et	3	main
antaks	doc_213943984993_item	2283732	et	3	main
et	doc_213943984993_item	2283747	et	3	main
sama	doc_213943984993_item	2283748	et	4	main
teised	doc_213943984993_item	2283752	et	4	main
loodan	doc_213943984993_item	2283757	et	3	main
ka	doc_213943984993_item	2283762	et	3	main
ka	doc_213943984993_item	2283768	et	3	main
eesnimi	doc_213943984993_item	2283774	et	3	main
miks	doc_213943984994_item	2283776	et	4	main
ausalt	doc_213943984994_item	2283781	et	4	main
öeldes	doc_213943984994_item	2283782	et	3	main
minu	doc_213943984994_item	2283783	et	3	main
on	doc_213943984994_item	2283785	et	4	main
minu	doc_213943984994_item	2283793	et	3	main
ei	doc_213943984994_item	2283795	et	4	main
rohkem	doc_213943984994_item	2283808	et	4	main
pärast	doc_213943984994_item	2283809	et	4	main
lapsepõlvest	doc_213943984994_item	2283813	et	4	main
saada	doc_213943984994_item	2283826	et	4	main
mida	doc_213943984994_item	2283838	et	4	main
ja	doc_213943984994_item	2283846	et	3	main
fantaasia	doc_213943984994_item	2283853	et	4	main
mõttes	doc_213943984994_item	2283862	et	3	main
inimesi	doc_213943984994_item	2283872	et	4	main
nad	doc_213943984994_item	2283876	et	3	main
nendel	doc_213943984994_item	2283881	et	4	main
oleks	doc_213943984994_item	2283882	et	3	main
mitte	doc_213943984994_item	2283883	et	3	main
kirjand	doc_213943984994_item	2283917	et	3	main
väga	doc_213943984994_item	2283919	et	3	main
väljendada	doc_213943984994_item	2283931	et	3	main
jne	doc_213943984994_item	2283941	et	4	main
keeles	doc_213943984994_item	2283942	et	4	main
ma	doc_213943984994_item	2283943	et	3	main
tahan	doc_213943984994_item	2283944	et	3	main
teada	doc_213943984994_item	2283945	et	3	main
palju	doc_213943984994_item	2283951	et	4	main
teadmisi	doc_213943984994_item	2283952	et	4	main
kultuurist	doc_213943984994_item	2283955	et	3	main
iga	doc_213943984994_item	2283960	et	4	main
õppejõud	doc_213943984994_item	2283961	et	4	main
ja	doc_213943984994_item	2283964	et	3	main
palju	doc_213943984994_item	2283972	et	4	main
kunagi	doc_213943984994_item	2283983	et	3	main
eriala	doc_213943984995_item	2284023	et	4	main
2	doc_213943984995_item	2284024	et	2	main
sellel	doc_213943984995_item	2284028	et	4	main
ülikoolist	doc_213943984995_item	2284032	et	4	main
ma	doc_213943984995_item	2284035	et	3	main
valisin	doc_213943984995_item	2284036	et	3	main
eriala	doc_213943984995_item	2284038	et	4	main
jõuda	doc_213943984995_item	2284063	et	3	main
aastat	doc_213943984995_item	2284069	et	3	main
läksin	doc_213943984995_item	2284076	et	3	main
meeletu	doc_213943984995_item	2284082	et	4	main
hakkama	doc_213943984995_item	2284090	et	3	main
teagi	doc_213943984995_item	2284100	et	4	main
saada	doc_213943984995_item	2284105	et	4	main
ma	doc_213943984995_item	2284108	et	3	main
oma	doc_213943984995_item	2284110	et	4	main
tahan	doc_213943984995_item	2284112	et	3	main
asjadest	doc_213943984995_item	2284117	et	3	main
ma	doc_213943984995_item	2284121	et	3	main
õppida	doc_213943984995_item	2284123	et	3	main
lai	doc_213943984995_item	2284129	et	3	main
silmaringi	doc_213943984995_item	2284140	et	4	main
võib	doc_213943984995_item	2284141	et	3	main
hakkan	doc_213943984995_item	2284146	et	3	main
vaatama	doc_213943984995_item	2284147	et	3	main
hoopis	doc_213943984995_item	2284149	et	3	main
teistmoodi	doc_213943984995_item	2284150	et	3	main
mul	doc_213943984995_item	2284151	et	3	main
nii	doc_213943984995_item	2284155	et	3	main
igasuguseid	doc_213943984995_item	2284157	et	3	main
eriala	doc_213943984993_item	2283726	et	4	main
kohta	doc_213943984993_item	2283727	et	4	main
mida	doc_213943984993_item	2283736	et	4	main
olen	doc_213943984993_item	2283745	et	3	main
tahavad	doc_213943984993_item	2283750	et	3	main
ka	doc_213943984993_item	2283751	et	3	main
seda	doc_213943984993_item	2283758	et	3	main
ainust	doc_213943984993_item	2283759	et	4	main
saab	doc_213943984993_item	2283761	et	3	main
meie	doc_213943984993_item	2283765	et	4	main
saame	doc_213943984993_item	2283767	et	4	main
hakkama	doc_213943984993_item	2283770	et	3	main
edu	doc_213943984993_item	2283771	et	4	main
eriala	doc_213943984994_item	2283780	et	4	main
sisseastumine	doc_213943984994_item	2283794	et	3	main
sisse	doc_213943984994_item	2283799	et	4	main
meeldib	doc_213943984994_item	2283805	et	3	main
teatri	doc_213943984994_item	2283812	et	3	main
ja	doc_213943984994_item	2283819	et	3	main
kuid	doc_213943984994_item	2283802	et	4	main
aga	doc_213943984994_item	2283803	et	3	main
ajakirjandus	doc_213943984994_item	2283804	et	3	main
muusikat	doc_213943984994_item	2283810	et	3	main
ma	doc_213943984994_item	2283814	et	3	main
kirjanduse	doc_213943984994_item	2283817	et	3	main
palju	doc_213943984994_item	2283821	et	4	main
ma	doc_213943984994_item	2283823	et	3	main
ka	doc_213943984994_item	2283825	et	3	main
kirjanikuks	doc_213943984994_item	2283827	et	3	main
palju	doc_213943984994_item	2283834	et	4	main
ma	doc_213943984994_item	2283839	et	3	main
et	doc_213943984994_item	2283841	et	3	main
teaksid	doc_213943984994_item	2283845	et	4	main
et	doc_213943984994_item	2283858	et	3	main
öelda	doc_213943984994_item	2283868	et	4	main
tahan	doc_213943984994_item	2283874	et	3	main
see	doc_213943984994_item	2283916	et	3	main
raamatuid	doc_213943984994_item	2283822	et	3	main
tahaks	doc_213943984994_item	2283824	et	3	main
või	doc_213943984994_item	2283828	et	4	main
on	doc_213943984994_item	2283833	et	4	main
tahaks	doc_213943984994_item	2283840	et	3	main
teised	doc_213943984994_item	2283842	et	4	main
saaksid	doc_213943984994_item	2283847	et	4	main
aga	doc_213943984994_item	2283849	et	3	main
poolt	doc_213943984994_item	2283851	et	4	main
minu	doc_213943984994_item	2283852	et	3	main
suur	doc_213943984994_item	2283857	et	3	main
kirjutada	doc_213943984994_item	2283859	et	3	main
tõeliselt	doc_213943984994_item	2283870	et	4	main
paremaks	doc_213943984994_item	2283879	et	4	main
ainult	doc_213943984994_item	2283884	et	4	main
võimas	doc_213943984994_item	2283885	et	4	main
aru	doc_213943984994_item	2283886	et	4	main
ka	doc_213943984994_item	2283888	et	3	main
puhas	doc_213943984994_item	2283889	et	3	main
ja	doc_213943984994_item	2283890	et	3	main
vaid	doc_213943984994_item	2283887	et	3	main
lahke	doc_213943984994_item	2283891	et	4	main
süda	doc_213943984994_item	2283892	et	3	main
ning	doc_213943984994_item	2283893	et	3	main
täisväärtuslik	doc_213943984994_item	2283894	et	3	main
hingeelu	doc_213943984994_item	2283895	et	4	main
mida	doc_213943984994_item	2283896	et	4	main
ootan	doc_213943984994_item	2283897	et	3	main
õppimisest	doc_213943984994_item	2283898	et	4	main
sellel	doc_213943984994_item	2283899	et	4	main
erialal	doc_213943984994_item	2283900	et	3	main
ja	doc_213943984994_item	2283901	et	3	main
tallinna	doc_213943984994_item	2283902	et	4	main
ülikoolis	doc_213943984994_item	2283903	et	4	main
ma	doc_213943984994_item	2283904	et	3	main
sain	doc_213943984994_item	2283905	et	3	main
vähe	doc_213943984994_item	2283906	et	3	main
punkti	doc_213943984994_item	2283907	et	4	main
kirjanduse	doc_213943984994_item	2283908	et	3	main
ees	doc_213943984994_item	2283909	et	4	main
65	doc_213943984994_item	2283910	et	2	main
ma	doc_213943984994_item	2283912	et	3	main
ise	doc_213943984994_item	2283913	et	4	main
arvasin	doc_213943984994_item	2283914	et	3	main
kuid	doc_213943984994_item	2283911	et	4	main
hea	doc_213943984994_item	2283920	et	4	main
õpetakse	doc_213943984994_item	2283928	et	4	main
ja	doc_213943984994_item	2283932	et	3	main
ainult	doc_213943984994_item	2283934	et	4	main
vaid	doc_213943984994_item	2283936	et	3	main
palju	doc_213943984994_item	2283946	et	4	main
ajaloost	doc_213943984994_item	2283953	et	4	main
poliitikast	doc_213943984994_item	2283956	et	4	main
ma	doc_213943984994_item	2283957	et	3	main
ootan	doc_213943984994_item	2283958	et	3	main
et	doc_213943984994_item	2283959	et	3	main
huvitav	doc_213943984994_item	2283965	et	4	main
loodan	doc_213943984994_item	2283968	et	3	main
leian	doc_213943984994_item	2283970	et	3	main
mõnusaks	doc_213943984994_item	2283980	et	4	main
ootan	doc_213943984994_item	2283981	et	3	main
ootan	doc_213943984995_item	2284026	et	3	main
küsimus	doc_213943984995_item	2284040	et	4	main
öeldes	doc_213943984995_item	2284042	et	3	main
ma	doc_213943984995_item	2284045	et	3	main
targad	doc_213943984995_item	2284054	et	3	main
nende	doc_213943984995_item	2284056	et	4	main
hirmsasti	doc_213943984995_item	2284060	et	3	main
koolist	doc_213943984995_item	2284073	et	4	main
eesti	doc_213943984995_item	2284077	et	4	main
oli	doc_213943984995_item	2284081	et	3	main
suur	doc_213943984995_item	2284086	et	3	main
ma	doc_213943984995_item	2284101	et	3	main
kelleks	doc_213943984995_item	2284102	et	4	main
ma	doc_213943984995_item	2284103	et	3	main
elust	doc_213943984995_item	2284111	et	3	main
ajakirjandus	doc_213943984995_item	2284113	et	3	main
see	doc_213943984994_item	2283922	et	3	main
meeldis	doc_213943984994_item	2283923	et	3	main
et	doc_213943984994_item	2283925	et	3	main
mind	doc_213943984994_item	2283927	et	4	main
iseenda	doc_213943984994_item	2283929	et	3	main
mitte	doc_213943984994_item	2283933	et	3	main
ka	doc_213943984994_item	2283937	et	3	main
ka	doc_213943984994_item	2283949	et	3	main
saada	doc_213943984994_item	2283950	et	4	main
samuti	doc_213943984994_item	2283966	et	3	main
et	doc_213943984994_item	2283969	et	3	main
saab	doc_213943984994_item	2283977	et	3	main
ja	doc_213943984994_item	2283979	et	3	main
et	doc_213943984994_item	2283982	et	3	main
artikkel	doc_213943984994_item	2283985	et	3	main
või	doc_213943984994_item	2283986	et	4	main
luuletus	doc_213943984994_item	2283987	et	4	main
ilmub	doc_213943984994_item	2283988	et	3	main
mingi	doc_213943984994_item	2283989	et	4	main
ajakirjas	doc_213943984994_item	2283990	et	3	main
või	doc_213943984994_item	2283991	et	4	main
ajalehes	doc_213943984994_item	2283992	et	3	main
juhtub	doc_213943984994_item	2283993	et	3	main
ju	doc_213943984994_item	2283994	et	3	main
niimoodi	doc_213943984994_item	2283995	et	3	main
et	doc_213943984994_item	2283996	et	3	main
esimene	doc_213943984994_item	2283997	et	3	main
kogemus	doc_213943984994_item	2283998	et	3	main
tuleb	doc_213943984994_item	2283999	et	3	main
ülikooli	doc_213943984994_item	2284001	et	4	main
veel	doc_213943984994_item	2284000	et	4	main
ajal	doc_213943984994_item	2284002	et	4	main
aga	doc_213943984994_item	2284003	et	3	main
see	doc_213943984994_item	2284004	et	3	main
on	doc_213943984994_item	2284005	et	4	main
veel	doc_213943984994_item	2284006	et	4	main
unistus	doc_213943984994_item	2284007	et	4	main
kõigepealt	doc_213943984994_item	2284008	et	3	main
ma	doc_213943984994_item	2284009	et	3	main
ootan	doc_213943984994_item	2284010	et	3	main
et	doc_213943984994_item	2284011	et	3	main
minu	doc_213943984994_item	2284012	et	3	main
humanitaarteadmised	doc_213943984994_item	2284013	et	3	main
suureneksid	doc_213943984994_item	2284014	et	4	main
ja	doc_213943984994_item	2284015	et	3	main
paraneksid	doc_213943984994_item	2284016	et	4	main
miks	doc_213943984995_item	2284019	et	4	main
valisin	doc_213943984995_item	2284021	et	3	main
õppimisest	doc_213943984995_item	2284027	et	4	main
ja	doc_213943984995_item	2284030	et	3	main
tallinna	doc_213943984995_item	2284031	et	4	main
1	doc_213943984995_item	2284033	et	2	main
ausalt	doc_213943984995_item	2284041	et	4	main
ei	doc_213943984995_item	2284043	et	4	main
oskagi	doc_213943984995_item	2284044	et	4	main
mulle	doc_213943984995_item	2284048	et	4	main
alati	doc_213943984995_item	2284050	et	4	main
meeldinud	doc_213943984995_item	2284051	et	4	main
hulka	doc_213943984995_item	2284057	et	4	main
tahan	doc_213943984995_item	2284058	et	3	main
kuuluda	doc_213943984995_item	2284059	et	4	main
sammu	doc_213943984995_item	2284067	et	4	main
tulin	doc_213943984995_item	2284071	et	3	main
kooli	doc_213943984995_item	2284078	et	4	main
algus	doc_213943984995_item	2284080	et	4	main
raske	doc_213943984995_item	2284083	et	4	main
tekkis	doc_213943984995_item	2284085	et	3	main
sain	doc_213943984995_item	2284089	et	3	main
inimene	doc_213943984995_item	2284092	et	3	main
nagu	doc_213943984995_item	2284095	et	3	main
kirjutasin	doc_213943984995_item	2284098	et	3	main
või	doc_213943984995_item	2284106	et	4	main
üldse	doc_213943984995_item	2284109	et	3	main
on	doc_213943984995_item	2284114	et	4	main
inimesele	doc_213943984995_item	2284132	et	3	main
palju	doc_213943984995_item	2284134	et	4	main
juurde	doc_213943984995_item	2284136	et	4	main
aasta	doc_213943984995_item	2284144	et	4	main
pärast	doc_213943984995_item	2284145	et	4	main
on	doc_213943984995_item	2284152	et	4	main
alati	doc_213943984995_item	2284153	et	4	main
peas	doc_213943984995_item	2284159	et	4	main
juhtud	doc_213943984995_item	2284168	et	3	main
ma	doc_213943984995_item	2284170	et	3	main
mida	doc_213943984995_item	2284203	et	4	main
ma	doc_213943984995_item	2284204	et	3	main
loodan	doc_213943984995_item	2284209	et	3	main
et	doc_213943984995_item	2284219	et	3	main
minu	doc_213943984995_item	2284230	et	3	main
väga	doc_213943984995_item	2284234	et	3	main
osav	doc_213943984995_item	2284244	et	3	main
ajakirjanik	doc_213943984995_item	2284247	et	3	main
lendab	doc_213943984995_item	2284258	et	3	main
et	doc_213943984995_item	2284272	et	3	main
oma	doc_213943984995_item	2284274	et	4	main
on	doc_213943984995_item	2284289	et	4	main
kogenud	doc_213943984995_item	2284294	et	4	main
ühendasin	doc_213943984995_item	2284322	et	3	main
esitatud	doc_213943984995_item	2284324	et	4	main
neid	doc_213943984995_item	2284333	et	4	main
millest	doc_213943984995_item	2284337	et	3	main
ülikooli	doc_213943984995_item	2284348	et	4	main
ka	doc_213943984995_item	2284349	et	3	main
ta	doc_213943984995_item	2284351	et	4	main
ajakirjas	doc_213943984995_item	2284353	et	3	main
väga	doc_213943984995_item	2284355	et	3	main
töötab	doc_213943984995_item	2284359	et	3	main
mina	doc_213943984995_item	2284361	et	4	main
nii	doc_213943984995_item	2284370	et	3	main
üks	doc_213943984995_item	2284379	et	3	main
olen	doc_213943984995_item	2284383	et	3	main
saamise	doc_213943984995_item	2284422	et	4	main
päev	doc_213943984995_item	2284423	et	3	main
aeg	doc_213943984995_item	2284424	et	3	main
enda	doc_213943984995_item	2284430	et	4	main
eriala	doc_213943984996_item	2284449	et	4	main
ootan	doc_213943984996_item	2284452	et	3	main
endale	doc_213943984996_item	2284464	et	4	main
olla	doc_213943984996_item	2284471	et	3	main
kedagi	doc_213943984996_item	2284473	et	4	main
üldse	doc_213943984996_item	2284480	et	3	main
tahaksin	doc_213943984996_item	2284484	et	3	main
mina	doc_213943984996_item	2284499	et	4	main
oli	doc_213943984996_item	2284524	et	3	main
meedia	doc_213943984996_item	2284527	et	4	main
ja	doc_213943984996_item	2284540	et	3	main
teema	doc_213943984996_item	2284544	et	4	main
rolli	doc_213943984996_item	2284547	et	4	main
selle	doc_213943984995_item	2284022	et	4	main
erialal	doc_213943984995_item	2284029	et	3	main
selle	doc_213943984995_item	2284037	et	4	main
hea	doc_213943984995_item	2284039	et	4	main
vastata	doc_213943984995_item	2284047	et	4	main
inteligentsed	doc_213943984995_item	2284052	et	4	main
selleni	doc_213943984995_item	2284062	et	3	main
väga	doc_213943984995_item	2284065	et	3	main
tagasi	doc_213943984995_item	2284070	et	3	main
ja	doc_213943984995_item	2284075	et	3	main
ja	doc_213943984995_item	2284084	et	3	main
paanika	doc_213943984995_item	2284087	et	4	main
aga	doc_213943984995_item	2284088	et	3	main
vist	doc_213943984995_item	2284091	et	4	main
peab	doc_213943984995_item	2284093	et	4	main
ma	doc_213943984995_item	2284096	et	3	main
tahan	doc_213943984995_item	2284104	et	3	main
paljudest	doc_213943984995_item	2284116	et	3	main
ja	doc_213943984995_item	2284118	et	3	main
valdkondadest	doc_213943984995_item	2284119	et	3	main
mida	doc_213943984995_item	2284120	et	4	main
on	doc_213943984995_item	2284127	et	4	main
väga	doc_213943984995_item	2284128	et	3	main
avab	doc_213943984995_item	2284137	et	3	main
olnud	doc_213943984995_item	2284154	et	4	main
mõtteid	doc_213943984995_item	2284158	et	3	main
milliseid	doc_213943984995_item	2284160	et	3	main
jagada	doc_213943984995_item	2284163	et	3	main
tihti	doc_213943984995_item	2284167	et	3	main
noppida	doc_213943984995_item	2284195	et	3	main
ka	doc_213943984995_item	2284198	et	3	main
tähtsama	doc_213943984995_item	2284200	et	4	main
et	doc_213943984995_item	2284210	et	3	main
ajakirjandus	doc_213943984995_item	2284212	et	3	main
mulle	doc_213943984995_item	2284220	et	4	main
midagi	doc_213943984995_item	2284221	et	4	main
ma	doc_213943984995_item	2284224	et	3	main
selle	doc_213943984995_item	2284227	et	4	main
oskuse	doc_213943984995_item	2284228	et	3	main
võib	doc_213943984995_item	2284237	et	3	main
inimeste	doc_213943984995_item	2284239	et	3	main
et	doc_213943984995_item	2284243	et	3	main
sõnal	doc_213943984995_item	2284256	et	3	main
meie	doc_213943984995_item	2284259	et	4	main
valisin	doc_213943984995_item	2284268	et	3	main
ka	doc_213943984995_item	2284270	et	3	main
paljud	doc_213943984995_item	2284280	et	3	main
inimesed	doc_213943984995_item	2284281	et	3	main
ei	doc_213943984995_item	2284283	et	4	main
säili	doc_213943984995_item	2284284	et	4	main
väga	doc_213943984995_item	2284285	et	3	main
näinud	doc_213943984995_item	2284291	et	4	main
oma	doc_213943984995_item	2284295	et	4	main
kaks	doc_213943984995_item	2284323	et	3	main
sellepärast	doc_213943984995_item	2284326	et	3	main
ma	doc_213943984995_item	2284327	et	3	main
ajakirjanduse	doc_213943984995_item	2284329	et	3	main
ma	doc_213943984995_item	2284338	et	3	main
palju	doc_213943984995_item	2284356	et	4	main
olla	doc_213943984995_item	2284369	et	3	main
nutikas	doc_213943984995_item	2284371	et	4	main
huvitav	doc_213943984995_item	2284373	et	4	main
see	doc_213943984995_item	2284376	et	3	main
on	doc_213943984995_item	2284377	et	4	main
ka	doc_213943984995_item	2284378	et	3	main
põhjus	doc_213943984995_item	2284380	et	4	main
mis	doc_213943984995_item	2284426	et	4	main
kõigest	doc_213943984995_item	2284428	et	4	main
kõike	doc_213943984995_item	2284434	et	4	main
ps	doc_213943984995_item	2284438	et	4	main
vabandan	doc_213943984995_item	2284439	et	3	main
essee	doc_213943984996_item	2284443	et	4	main
selle	doc_213943984996_item	2284448	et	4	main
tallinna	doc_213943984996_item	2284457	et	4	main
juba	doc_213943984996_item	2284460	et	3	main
ja	doc_213943984996_item	2284466	et	3	main
õpetajana	doc_213943984996_item	2284476	et	4	main
aga	doc_213943984996_item	2284477	et	3	main
köitnud	doc_213943984996_item	2284482	et	4	main
ja	doc_213943984996_item	2284498	et	3	main
mida	doc_213943984995_item	2284025	et	4	main
miks	doc_213943984995_item	2284034	et	4	main
hetkel	doc_213943984995_item	2284046	et	4	main
on	doc_213943984995_item	2284049	et	4	main
ja	doc_213943984995_item	2284053	et	3	main
inimesed	doc_213943984995_item	2284055	et	3	main
et	doc_213943984995_item	2284061	et	3	main
tegin	doc_213943984995_item	2284064	et	3	main
aruka	doc_213943984995_item	2284066	et	3	main
kolm	doc_213943984995_item	2284068	et	3	main
vene	doc_213943984995_item	2284072	et	4	main
ära	doc_213943984995_item	2284074	et	4	main
muidugi	doc_213943984995_item	2284079	et	4	main
arenema	doc_213943984995_item	2284094	et	3	main
juba	doc_213943984995_item	2284097	et	3	main
ei	doc_213943984995_item	2284099	et	4	main
mida	doc_213943984995_item	2284107	et	4	main
üks	doc_213943984995_item	2284115	et	3	main
minu	doc_213943984995_item	2284124	et	3	main
see	doc_213943984995_item	2284126	et	3	main
teadus	doc_213943984995_item	2284130	et	4	main
annab	doc_213943984995_item	2284131	et	3	main
väga	doc_213943984995_item	2284133	et	3	main
tedmisi	doc_213943984995_item	2284135	et	4	main
kolme	doc_213943984995_item	2284143	et	4	main
palju	doc_213943984995_item	2284156	et	4	main
et	doc_213943984995_item	2284169	et	3	main
oma	doc_213943984995_item	2284196	et	4	main
momenti	doc_213943984995_item	2284201	et	4	main
sellest	doc_213943984995_item	2284202	et	4	main
väga	doc_213943984995_item	2284208	et	3	main
selle	doc_213943984995_item	2284215	et	4	main
oskuse	doc_213943984995_item	2284216	et	3	main
omandada	doc_213943984995_item	2284229	et	3	main
mõjutada	doc_213943984995_item	2284238	et	3	main
elu	doc_213943984995_item	2284240	et	4	main
mõtlen	doc_213943984995_item	2284242	et	3	main
võib	doc_213943984995_item	2284248	et	3	main
vabalt	doc_213943984995_item	2284250	et	4	main
mis	doc_213943984995_item	2284257	et	4	main
on	doc_213943984995_item	2284261	et	4	main
väga	doc_213943984995_item	2284262	et	3	main
osata	doc_213943984995_item	2284273	et	4	main
kasutada	doc_213943984995_item	2284277	et	3	main
ajakirjanikud	doc_213943984995_item	2284278	et	3	main
neid	doc_213943984995_item	2284282	et	4	main
huvitavad	doc_213943984995_item	2284286	et	4	main
inimesed	doc_213943984995_item	2284287	et	3	main
nad	doc_213943984995_item	2284288	et	3	main
ja	doc_213943984995_item	2284293	et	3	main
et	doc_213943984995_item	2284330	et	3	main
olen	doc_213943984995_item	2284339	et	3	main
juba	doc_213943984995_item	2284340	et	3	main
sõbranna	doc_213943984995_item	2284344	et	4	main
kunagi	doc_213943984995_item	2284345	et	3	main
lõpetas	doc_213943984995_item	2284346	et	3	main
moskvas	doc_213943984995_item	2284347	et	4	main
ta	doc_213943984995_item	2284358	et	4	main
olen	doc_213943984995_item	2284363	et	3	main
vaimustanud	doc_213943984995_item	2284364	et	4	main
inimene	doc_213943984995_item	2284367	et	3	main
ja	doc_213943984995_item	2284372	et	3	main
võib	doc_213943984995_item	2284374	et	3	main
miks	doc_213943984995_item	2284381	et	4	main
ma	doc_213943984995_item	2284432	et	3	main
mis	doc_213943984995_item	2284435	et	4	main
valisin	doc_213943984996_item	2284447	et	3	main
mida	doc_213943984996_item	2284451	et	4	main
õppimisest	doc_213943984996_item	2284453	et	4	main
erialal	doc_213943984996_item	2284455	et	3	main
soobiv	doc_213943984996_item	2284465	et	4	main
sest	doc_213943984996_item	2284483	et	4	main
lapsega	doc_213943984996_item	2284485	et	3	main
olla	doc_213943984996_item	2284487	et	3	main
olin	doc_213943984996_item	2284489	et	3	main
ema	doc_213943984996_item	2284493	et	4	main
ennustas	doc_213943984996_item	2284494	et	3	main
ajakirjanikuks	doc_213943984996_item	2284496	et	3	main
kui	doc_213943984996_item	2284503	et	3	main
kursustele	doc_213943984996_item	2284521	et	3	main
teema	doc_213943984996_item	2284523	et	4	main
seal	doc_213943984996_item	2284529	et	4	main
tahaksin	doc_213943984995_item	2284122	et	3	main
arust	doc_213943984995_item	2284125	et	4	main
ja	doc_213943984995_item	2284138	et	3	main
laieneb	doc_213943984995_item	2284139	et	3	main
olla	doc_213943984995_item	2284142	et	3	main
maailmale	doc_213943984995_item	2284148	et	4	main
teistega	doc_213943984995_item	2284164	et	4	main
aga	doc_213943984995_item	2284165	et	3	main
väga	doc_213943984995_item	2284166	et	3	main
ei	doc_213943984995_item	2284171	et	4	main
oska	doc_213943984995_item	2284172	et	4	main
oma	doc_213943984995_item	2284173	et	4	main
mõtteid	doc_213943984995_item	2284174	et	3	main
väljendada	doc_213943984995_item	2284175	et	3	main
või	doc_213943984995_item	2284176	et	4	main
ilusti	doc_213943984995_item	2284177	et	3	main
paberile	doc_213943984995_item	2284178	et	3	main
panna	doc_213943984995_item	2284179	et	4	main
just	doc_213943984995_item	2284180	et	3	main
nii	doc_213943984995_item	2284181	et	3	main
nagu	doc_213943984995_item	2284182	et	3	main
ma	doc_213943984995_item	2284183	et	3	main
mõtlen	doc_213943984995_item	2284184	et	3	main
arvan	doc_213943984995_item	2284185	et	3	main
et	doc_213943984995_item	2284186	et	3	main
see	doc_213943984995_item	2284187	et	3	main
on	doc_213943984995_item	2284188	et	4	main
väga	doc_213943984995_item	2284189	et	3	main
raske	doc_213943984995_item	2284190	et	4	main
ma	doc_213943984995_item	2284191	et	3	main
ei	doc_213943984995_item	2284192	et	4	main
oska	doc_213943984995_item	2284193	et	4	main
välja	doc_213943984995_item	2284194	et	4	main
ma	doc_213943984995_item	2284161	et	3	main
tahaksin	doc_213943984995_item	2284162	et	3	main
ma	doc_213943984995_item	2284207	et	3	main
just	doc_213943984995_item	2284211	et	3	main
mulle	doc_213943984995_item	2284214	et	4	main
isegi	doc_213943984995_item	2284217	et	4	main
mitte	doc_213943984995_item	2284218	et	3	main
ajust	doc_213943984995_item	2284197	et	4	main
kõige	doc_213943984995_item	2284199	et	4	main
tahan	doc_213943984995_item	2284205	et	3	main
ööelda	doc_213943984995_item	2284206	et	4	main
annab	doc_213943984995_item	2284213	et	3	main
aga	doc_213943984995_item	2284223	et	3	main
ise	doc_213943984995_item	2284225	et	4	main
jaoks	doc_213943984995_item	2284231	et	4	main
on	doc_213943984995_item	2284233	et	4	main
tähtis	doc_213943984995_item	2284235	et	4	main
ma	doc_213943984995_item	2284241	et	3	main
tark	doc_213943984995_item	2284246	et	3	main
inimestega	doc_213943984995_item	2284251	et	3	main
ja	doc_213943984995_item	2284252	et	3	main
mängida	doc_213943984995_item	2284255	et	3	main
et	doc_213943984995_item	2284267	et	3	main
õigesti	doc_213943984995_item	2284276	et	3	main
kuulnud	doc_213943984995_item	2284292	et	4	main
antakse	doc_213943984995_item	2284222	et	3	main
suudan	doc_213943984995_item	2284226	et	3	main
see	doc_213943984995_item	2284232	et	3	main
ajakirjandus	doc_213943984995_item	2284236	et	3	main
ja	doc_213943984995_item	2284245	et	3	main
väga	doc_213943984995_item	2284249	et	3	main
nende	doc_213943984995_item	2284253	et	4	main
eludega	doc_213943984995_item	2284254	et	3	main
suust	doc_213943984995_item	2284260	et	3	main
tugev	doc_213943984995_item	2284263	et	4	main
jõud	doc_213943984995_item	2284264	et	4	main
ma	doc_213943984995_item	2284265	et	3	main
arvan	doc_213943984995_item	2284266	et	3	main
ajakirjanduse	doc_213943984995_item	2284269	et	3	main
selleks	doc_213943984995_item	2284271	et	4	main
sõna	doc_213943984995_item	2284275	et	4	main
kuigi	doc_213943984995_item	2284279	et	3	main
palju	doc_213943984995_item	2284290	et	4	main
elus	doc_213943984995_item	2284296	et	4	main
ma	doc_213943984995_item	2284297	et	3	main
juba	doc_213943984995_item	2284298	et	3	main
mainisin	doc_213943984995_item	2284299	et	3	main
et	doc_213943984995_item	2284300	et	3	main
tahan	doc_213943984995_item	2284301	et	3	main
kuulud	doc_213943984995_item	2284302	et	4	main
tarkade	doc_213943984995_item	2284303	et	3	main
inimeste	doc_213943984995_item	2284304	et	3	main
hulka	doc_213943984995_item	2284305	et	4	main
loodan	doc_213943984995_item	2284306	et	3	main
et	doc_213943984995_item	2284307	et	3	main
ajakirjandus	doc_213943984995_item	2284308	et	3	main
on	doc_213943984995_item	2284309	et	4	main
õige	doc_213943984995_item	2284310	et	4	main
teadus	doc_213943984995_item	2284311	et	4	main
selleni	doc_213943984995_item	2284312	et	3	main
jõuda	doc_213943984995_item	2284313	et	3	main
jällegi	doc_213943984995_item	2284314	et	4	main
ei	doc_213943984995_item	2284315	et	4	main
oska	doc_213943984995_item	2284316	et	4	main
ma	doc_213943984995_item	2284317	et	3	main
oma	doc_213943984995_item	2284318	et	4	main
mõtteid	doc_213943984995_item	2284319	et	3	main
koonduda	doc_213943984995_item	2284320	et	3	main
ja	doc_213943984995_item	2284321	et	3	main
küsimust	doc_213943984995_item	2284325	et	4	main
saada	doc_213943984995_item	2284331	et	4	main
just	doc_213943984995_item	2284332	et	3	main
teadmisi	doc_213943984995_item	2284334	et	4	main
ja	doc_213943984995_item	2284335	et	3	main
minu	doc_213943984995_item	2284342	et	3	main
ajakirjanduse	doc_213943984995_item	2284350	et	3	main
nüüd	doc_213943984995_item	2284357	et	4	main
saatkonnas	doc_213943984995_item	2284360	et	4	main
lihtsalt	doc_213943984995_item	2284362	et	4	main
temast	doc_213943984995_item	2284365	et	3	main
et	doc_213943984995_item	2284366	et	3	main
valisingi	doc_213943984995_item	2284328	et	3	main
oskusi	doc_213943984995_item	2284336	et	3	main
kirjutanud	doc_213943984995_item	2284341	et	4	main
ema	doc_213943984995_item	2284343	et	4	main
töötas	doc_213943984995_item	2284352	et	3	main
reisis	doc_213943984995_item	2284354	et	4	main
võib	doc_213943984995_item	2284368	et	3	main
olla	doc_213943984995_item	2284375	et	3	main
ma	doc_213943984995_item	2284382	et	3	main
siin	doc_213943984995_item	2284384	et	4	main
2	doc_213943984995_item	2284385	et	2	main
mida	doc_213943984995_item	2284386	et	4	main
ma	doc_213943984995_item	2284387	et	3	main
ootan	doc_213943984995_item	2284388	et	3	main
tallinna	doc_213943984995_item	2284389	et	4	main
ülikoolist	doc_213943984995_item	2284390	et	4	main
ootan	doc_213943984995_item	2284391	et	3	main
et	doc_213943984995_item	2284392	et	3	main
sellest	doc_213943984995_item	2284393	et	4	main
majast	doc_213943984995_item	2284394	et	4	main
saaks	doc_213943984995_item	2284395	et	3	main
mu	doc_213943984995_item	2284396	et	3	main
kolmeks	doc_213943984995_item	2284398	et	4	main
aastaks	doc_213943984995_item	2284399	et	4	main
kodu	doc_213943984995_item	2284397	et	4	main
või	doc_213943984995_item	2284400	et	4	main
isegi	doc_213943984995_item	2284401	et	4	main
palju	doc_213943984995_item	2284402	et	4	main
rohkem	doc_213943984995_item	2284403	et	4	main
loodan	doc_213943984995_item	2284404	et	3	main
et	doc_213943984995_item	2284405	et	3	main
ma	doc_213943984995_item	2284406	et	3	main
ei	doc_213943984995_item	2284407	et	4	main
pea	doc_213943984995_item	2284408	et	4	main
tulema	doc_213943984995_item	2284409	et	4	main
siia	doc_213943984995_item	2284410	et	4	main
nagu	doc_213943984995_item	2284411	et	3	main
sunnitööle	doc_213943984995_item	2284412	et	3	main
aga	doc_213943984995_item	2284413	et	3	main
et	doc_213943984995_item	2284414	et	3	main
iga	doc_213943984995_item	2284415	et	4	main
päeg	doc_213943984995_item	2284416	et	4	main
oleks	doc_213943984995_item	2284417	et	3	main
minu	doc_213943984995_item	2284418	et	3	main
jaoks	doc_213943984995_item	2284419	et	4	main
uute	doc_213943984995_item	2284420	et	3	main
teadmiste	doc_213943984995_item	2284421	et	4	main
sellest	doc_213943984995_item	2284427	et	4	main
saab	doc_213943984995_item	2284429	et	3	main
poolest	doc_213943984995_item	2284431	et	4	main
sõltub	doc_213943984995_item	2284437	et	3	main
oma	doc_213943984995_item	2284440	et	4	main
käekirja	doc_213943984995_item	2284441	et	4	main
pärast	doc_213943984995_item	2284442	et	4	main
sellel	doc_213943984996_item	2284454	et	4	main
ülikoolis	doc_213943984996_item	2284458	et	4	main
lemmik	doc_213943984996_item	2284467	et	3	main
kedagi	doc_213943984996_item	2284469	et	4	main
arstina	doc_213943984996_item	2284472	et	3	main
töötama	doc_213943984996_item	2284474	et	3	main
ei	doc_213943984996_item	2284481	et	4	main
nii	doc_213943984996_item	2284490	et	3	main
et	doc_213943984996_item	2284492	et	3	main
saad	doc_213943984996_item	2284495	et	4	main
see	doc_213943984996_item	2284504	et	3	main
ennustamine	doc_213943984996_item	2284505	et	4	main
mind	doc_213943984996_item	2284507	et	4	main
juba	doc_213943984996_item	2284508	et	3	main
unistusele	doc_213943984996_item	2284509	et	4	main
viis	doc_213943984996_item	2284506	et	4	main
aga	doc_213943984996_item	2284510	et	3	main
viisin	doc_213943984996_item	2284511	et	3	main
selle	doc_213943984996_item	2284512	et	4	main
ellu	doc_213943984996_item	2284513	et	4	main
ainult	doc_213943984996_item	2284514	et	4	main
aasta	doc_213943984996_item	2284515	et	4	main
tagasi	doc_213943984996_item	2284516	et	3	main
registreerusin	doc_213943984996_item	2284518	et	3	main
kui	doc_213943984996_item	2284517	et	3	main
tallinna	doc_213943984996_item	2284519	et	4	main
ülikooli	doc_213943984996_item	2284520	et	4	main
näitab	doc_213943984995_item	2284425	et	3	main
teen	doc_213943984995_item	2284433	et	3	main
minust	doc_213943984995_item	2284436	et	3	main
1	doc_213943984996_item	2284444	et	2	main
miks	doc_213943984996_item	2284445	et	4	main
ma	doc_213943984996_item	2284446	et	3	main
2	doc_213943984996_item	2284450	et	2	main
ja	doc_213943984996_item	2284456	et	3	main
1	doc_213943984996_item	2284459	et	2	main
lapsepõlvest	doc_213943984996_item	2284461	et	4	main
inimene	doc_213943984996_item	2284462	et	3	main
otsib	doc_213943984996_item	2284463	et	3	main
elukutset	doc_213943984996_item	2284468	et	3	main
tahab	doc_213943984996_item	2284470	et	3	main
koolis	doc_213943984996_item	2284475	et	4	main
mind	doc_213943984996_item	2284478	et	4	main
see	doc_213943984996_item	2284479	et	3	main
alatiseks	doc_213943984996_item	2284486	et	4	main
kahjuks	doc_213943984996_item	2284488	et	4	main
aktiivne	doc_213943984996_item	2284491	et	3	main
siis	doc_213943984996_item	2284497	et	3	main
ei	doc_213943984996_item	2284501	et	4	main
märganud	doc_213943984996_item	2284502	et	4	main
minu	doc_213943984996_item	2284530	et	3	main
õpetamine	doc_213943984996_item	2284537	et	4	main
esimest	doc_213943984996_item	2284546	et	4	main
on	doc_213943984996_item	2284550	et	4	main
arst	doc_213943984996_item	2284564	et	3	main
nagu	doc_213943984996_item	2284565	et	3	main
aitab	doc_213943984996_item	2284567	et	3	main
ta	doc_213943984996_item	2284569	et	4	main
tõele	doc_213943984996_item	2284573	et	4	main
uurib	doc_213943984996_item	2284577	et	3	main
võimuks	doc_213943984996_item	2284586	et	4	main
vastutusrikkas	doc_213943984996_item	2284599	et	4	main
ja	doc_213943984996_item	2284601	et	3	main
imetleda	doc_213943984996_item	2284604	et	3	main
nagu	doc_213943984996_item	2284607	et	3	main
ja	doc_213943984996_item	2284609	et	3	main
ei	doc_213943984996_item	2284611	et	4	main
sellele	doc_213943984996_item	2284613	et	4	main
seista	doc_213943984996_item	2284615	et	4	main
sellel	doc_213943984996_item	2284621	et	4	main
eelkõige	doc_213943984996_item	2284626	et	3	main
ootan	doc_213943984996_item	2284632	et	3	main
õpetada	doc_213943984996_item	2284648	et	3	main
teisest	doc_213943984996_item	2284650	et	4	main
kõiki	doc_213943984996_item	2284655	et	4	main
omada	doc_213943984996_item	2284657	et	3	main
inimestele	doc_213943984996_item	2284659	et	3	main
tööga	doc_213943984996_item	2284661	et	3	main
saada	doc_213943984996_item	2284663	et	4	main
midagi	doc_213943984996_item	2284664	et	4	main
ning	doc_213943984996_item	2284669	et	3	main
ülikooli	doc_213943984996_item	2284673	et	4	main
teha	doc_213943984996_item	2284681	et	3	main
terve	doc_213943984996_item	2284683	et	4	main
sellelt	doc_213943984996_item	2284685	et	4	main
ise	doc_213943984996_item	2284500	et	4	main
mille	doc_213943984996_item	2284522	et	3	main
just	doc_213943984996_item	2284525	et	3	main
kasvas	doc_213943984996_item	2284533	et	3	main
muidugi	doc_213943984996_item	2284541	et	4	main
kursuste	doc_213943984996_item	2284543	et	3	main
see	doc_213943984996_item	2284549	et	3	main
seisneb	doc_213943984996_item	2284559	et	3	main
selles	doc_213943984996_item	2284560	et	4	main
et	doc_213943984996_item	2284561	et	3	main
õpetaja	doc_213943984996_item	2284566	et	4	main
inimestele	doc_213943984996_item	2284568	et	3	main
suunab	doc_213943984996_item	2284572	et	3	main
on	doc_213943984996_item	2284579	et	4	main
rahvas	doc_213943984996_item	2284582	et	4	main
see	doc_213943984996_item	2284590	et	3	main
see	doc_213943984996_item	2284602	et	3	main
on	doc_213943984996_item	2284606	et	4	main
ahvatlus	doc_213943984996_item	2284608	et	4	main
vastu	doc_213943984996_item	2284614	et	3	main
2	doc_213943984996_item	2284616	et	2	main
erialal	doc_213943984996_item	2284622	et	3	main
tulevikus	doc_213943984996_item	2284634	et	4	main
teha	doc_213943984996_item	2284636	et	3	main
omal	doc_213943984996_item	2284640	et	3	main
inimesi	doc_213943984996_item	2284647	et	4	main
et	doc_213943984996_item	2284671	et	3	main
saan	doc_213943984996_item	2284677	et	4	main
otsustanud	doc_213943984996_item	2284689	et	4	main
mida	doc_213943984997_item	2284722	et	4	main
sellel	doc_213943984997_item	2284725	et	4	main
erialal	doc_213943984997_item	2284726	et	3	main
ja	doc_213943984997_item	2284727	et	3	main
ajakirjanduse	doc_213943984997_item	2284732	et	3	main
kui	doc_213943984997_item	2284735	et	3	main
kaheksandas	doc_213943984997_item	2284738	et	3	main
seega	doc_213943984997_item	2284740	et	4	main
mingi	doc_213943984997_item	2284750	et	4	main
artikkli	doc_213943984997_item	2284751	et	4	main
oli	doc_213943984997_item	2284753	et	3	main
hakkasin	doc_213943984997_item	2284760	et	3	main
ma	doc_213943984997_item	2284767	et	3	main
äitäh	doc_213943984997_item	2284769	et	4	main
selle	doc_213943984997_item	2284771	et	4	main
kus	doc_213943984997_item	2284773	et	3	main
kuna	doc_213943984997_item	2284777	et	3	main
meie	doc_213943984997_item	2284779	et	4	main
elus	doc_213943984997_item	2284780	et	4	main
seegi	doc_213943984997_item	2284784	et	4	main
toimus	doc_213943984997_item	2284787	et	3	main
paar	doc_213943984997_item	2284791	et	3	main
juba	doc_213943984997_item	2284796	et	3	main
otsust	doc_213943984997_item	2284799	et	4	main
teise	doc_213943984997_item	2284807	et	4	main
proovima	doc_213943984997_item	2284811	et	3	main
näha	doc_213943984997_item	2284815	et	3	main
siin	doc_213943984997_item	2284818	et	4	main
suurt	doc_213943984997_item	2284822	et	3	main
mängis	doc_213943984997_item	2284824	et	3	main
kui	doc_213943984997_item	2284833	et	3	main
väike	doc_213943984997_item	2284836	et	4	main
et	doc_213943984997_item	2284849	et	3	main
et	doc_213943984997_item	2284872	et	3	main
ma	doc_213943984997_item	2284876	et	3	main
loodan	doc_213943984997_item	2284881	et	3	main
et	doc_213943984997_item	2284882	et	3	main
minna	doc_213943984997_item	2284890	et	3	main
eriala	doc_213943984998_item	2284916	et	4	main
erialal	doc_213943984998_item	2284921	et	3	main
tallinna	doc_213943984998_item	2284923	et	4	main
1	doc_213943984998_item	2284925	et	2	main
valisin	doc_213943984998_item	2284928	et	3	main
eriala	doc_213943984998_item	2284930	et	4	main
küsimus	doc_213943984998_item	2284935	et	4	main
teha	doc_213943984998_item	2284937	et	3	main
puhata	doc_213943984998_item	2284946	et	4	main
siis	doc_213943984998_item	2284967	et	3	main
valida	doc_213943984998_item	2284969	et	3	main
kavatsed	doc_213943984998_item	2284972	et	3	main
või	doc_213943984998_item	2285002	et	4	main
viis	doc_213943984998_item	2285003	et	4	main
tagasi	doc_213943984998_item	2285005	et	3	main
venekeelne	doc_213943984996_item	2284526	et	3	main
ajakirjandus	doc_213943984996_item	2284528	et	3	main
lapsepõlvene	doc_213943984996_item	2284531	et	4	main
unistus	doc_213943984996_item	2284532	et	4	main
ülipõnev	doc_213943984996_item	2284542	et	3	main
ajalooline	doc_213943984996_item	2284551	et	4	main
erialale	doc_213943984996_item	2284553	et	3	main
tee	doc_213943984996_item	2284552	et	4	main
aga	doc_213943984996_item	2284554	et	3	main
põhine	doc_213943984996_item	2284555	et	4	main
ja	doc_213943984996_item	2284556	et	3	main
tõeline	doc_213943984996_item	2284557	et	4	main
harrastuseni	doc_213943984996_item	2284534	et	4	main
ning	doc_213943984996_item	2284535	et	3	main
köidav	doc_213943984996_item	2284536	et	4	main
heameelsed	doc_213943984996_item	2284538	et	3	main
kursustekaaslased	doc_213943984996_item	2284539	et	3	main
mängisid	doc_213943984996_item	2284545	et	4	main
ajakirjanik	doc_213943984996_item	2284562	et	3	main
ja	doc_213943984996_item	2284576	et	3	main
tal	doc_213943984996_item	2284578	et	3	main
isegi	doc_213943984996_item	2284581	et	4	main
ajakirjandust	doc_213943984996_item	2284583	et	3	main
nimetatakse	doc_213943984996_item	2284584	et	3	main
arvates	doc_213943984996_item	2284593	et	4	main
vallatum	doc_213943984996_item	2284595	et	4	main
ja	doc_213943984996_item	2284596	et	3	main
mina	doc_213943984996_item	2284610	et	4	main
ma	doc_213943984996_item	2284618	et	3	main
õppimisest	doc_213943984996_item	2284620	et	4	main
ja	doc_213943984996_item	2284623	et	3	main
nagu	doc_213943984996_item	2284627	et	3	main
iga	doc_213943984996_item	2284628	et	4	main
ajakirjanikuks	doc_213943984996_item	2284629	et	3	main
üliõpilane	doc_213943984996_item	2284631	et	3	main
spetsialistina	doc_213943984996_item	2284639	et	3	main
võib	doc_213943984996_item	2284642	et	3	main
et	doc_213943984996_item	2284644	et	3	main
teisi	doc_213943984996_item	2284646	et	4	main
küljest	doc_213943984996_item	2284651	et	4	main
tahaks	doc_213943984996_item	2284652	et	3	main
teada	doc_213943984996_item	2284653	et	3	main
ajakirjanduses	doc_213943984996_item	2284654	et	3	main
võimalust	doc_213943984996_item	2284658	et	3	main
aidata	doc_213943984996_item	2284662	et	4	main
ajakirjanik	doc_213943984996_item	2284668	et	3	main
ma	doc_213943984996_item	2284678	et	3	main
momendilt	doc_213943984996_item	2284686	et	3	main
kui	doc_213943984996_item	2284687	et	3	main
olin	doc_213943984996_item	2284688	et	3	main
vastu	doc_213943984997_item	2284733	et	3	main
klassis	doc_213943984997_item	2284739	et	3	main
aastasena	doc_213943984997_item	2284742	et	4	main
ilusasti	doc_213943984997_item	2284757	et	3	main
kirjutama	doc_213943984997_item	2284762	et	3	main
kogemusele	doc_213943984997_item	2284766	et	3	main
peangi	doc_213943984997_item	2284768	et	4	main
ütlema	doc_213943984997_item	2284770	et	3	main
ma	doc_213943984997_item	2284774	et	3	main
spontaanselt	doc_213943984997_item	2284782	et	4	main
ja	doc_213943984997_item	2284789	et	3	main
peal	doc_213943984997_item	2284794	et	4	main
minema	doc_213943984997_item	2284805	et	3	main
kuskile	doc_213943984997_item	2284806	et	4	main
oma	doc_213943984997_item	2284809	et	4	main
võib	doc_213943984997_item	2284819	et	3	main
rolli	doc_213943984997_item	2284823	et	4	main
et	doc_213943984997_item	2284827	et	3	main
isa	doc_213943984997_item	2284829	et	4	main
ajakirjanik	doc_213943984997_item	2284831	et	3	main
olin	doc_213943984997_item	2284835	et	3	main
ta	doc_213943984997_item	2284837	et	4	main
andis	doc_213943984997_item	2284838	et	3	main
kirjutamise	doc_213943984997_item	2284845	et	4	main
lihtsalt	doc_213943984997_item	2284851	et	4	main
meeldib	doc_213943984997_item	2284852	et	3	main
kirjutada	doc_213943984997_item	2284853	et	3	main
ja	doc_213943984997_item	2284854	et	3	main
sellel	doc_213943984997_item	2284874	et	4	main
lõpetan	doc_213943984997_item	2284884	et	3	main
ajakirjanikuna	doc_213943984997_item	2284893	et	3	main
millegi	doc_213943984997_item	2284895	et	4	main
ma	doc_213943984997_item	2284897	et	3	main
arvan	doc_213943984997_item	2284898	et	3	main
et	doc_213943984997_item	2284899	et	3	main
see	doc_213943984997_item	2284900	et	3	main
saab	doc_213943984997_item	2284901	et	3	main
teoks	doc_213943984997_item	2284902	et	4	main
üleüldse	doc_213943984997_item	2284905	et	3	main
elame	doc_213943984997_item	2284909	et	3	main
essee	doc_213943984998_item	2284911	et	4	main
ja	doc_213943984998_item	2284922	et	3	main
ülikoolis	doc_213943984998_item	2284924	et	4	main
kuid	doc_213943984996_item	2284548	et	4	main
põhjus	doc_213943984996_item	2284558	et	4	main
loob	doc_213943984996_item	2284570	et	3	main
ja	doc_213943984996_item	2284571	et	3	main
võim	doc_213943984996_item	2284580	et	3	main
minu	doc_213943984996_item	2284592	et	3	main
kõige	doc_213943984996_item	2284594	et	4	main
samal	doc_213943984996_item	2284597	et	3	main
see	doc_213943984996_item	2284605	et	3	main
ootan	doc_213943984996_item	2284619	et	3	main
tallinna	doc_213943984996_item	2284624	et	4	main
õppiv	doc_213943984996_item	2284630	et	4	main
võimalust	doc_213943984996_item	2284633	et	3	main
olla	doc_213943984996_item	2284637	et	3	main
alal	doc_213943984996_item	2284641	et	4	main
olla	doc_213943984996_item	2284643	et	3	main
edasi	doc_213943984996_item	2284645	et	3	main
üksikasju	doc_213943984996_item	2284656	et	3	main
enam	doc_213943984996_item	2284665	et	4	main
kui	doc_213943984996_item	2284666	et	3	main
lihtne	doc_213943984996_item	2284667	et	3	main
ma	doc_213943984996_item	2284676	et	3	main
seda	doc_213943984996_item	2284680	et	3	main
tekkis	doc_213943984997_item	2284734	et	3	main
huvi	doc_213943984997_item	2284743	et	4	main
tekkis	doc_213943984997_item	2284744	et	3	main
kuidagi	doc_213943984997_item	2284745	et	3	main
spontaanselt	doc_213943984997_item	2284746	et	4	main
ajalehest	doc_213943984997_item	2284749	et	4	main
ja	doc_213943984997_item	2284759	et	3	main
ise	doc_213943984997_item	2284761	et	4	main
vist	doc_213943984997_item	2284763	et	4	main
selle	doc_213943984997_item	2284764	et	4	main
praegu	doc_213943984997_item	2284775	et	3	main
otsus	doc_213943984997_item	2284786	et	3	main
kiiresti	doc_213943984997_item	2284788	et	3	main
vaikselt	doc_213943984997_item	2284790	et	4	main
sõna	doc_213943984997_item	2284792	et	4	main
ootan	doc_213943984997_item	2284798	et	3	main
võetud	doc_213943984997_item	2284802	et	4	main
õnne	doc_213943984997_item	2284810	et	4	main
nägu	doc_213943984997_item	2284812	et	4	main
võite	doc_213943984997_item	2284814	et	4	main
ma	doc_213943984997_item	2284816	et	3	main
olen	doc_213943984997_item	2284817	et	3	main
nagu	doc_213943984996_item	2284563	et	3	main
ta	doc_213943984996_item	2284574	et	4	main
teab	doc_213943984996_item	2284575	et	3	main
neljaks	doc_213943984996_item	2284585	et	4	main
aga	doc_213943984996_item	2284587	et	3	main
neljast	doc_213943984996_item	2284588	et	4	main
võimust	doc_213943984996_item	2284589	et	4	main
on	doc_213943984996_item	2284591	et	4	main
ajal	doc_213943984996_item	2284598	et	4	main
võim	doc_213943984996_item	2284600	et	3	main
paneb	doc_213943984996_item	2284603	et	3	main
saa	doc_213943984996_item	2284612	et	4	main
mida	doc_213943984996_item	2284617	et	4	main
ülikoolis	doc_213943984996_item	2284625	et	4	main
karjääri	doc_213943984996_item	2284635	et	4	main
hea	doc_213943984996_item	2284638	et	4	main
kuid	doc_213943984996_item	2284649	et	4	main
oma	doc_213943984996_item	2284660	et	4	main
loodan	doc_213943984996_item	2284670	et	3	main
tallinna	doc_213943984996_item	2284672	et	4	main
õppejõudu	doc_213943984996_item	2284674	et	4	main
abiga	doc_213943984996_item	2284675	et	3	main
suudan	doc_213943984996_item	2284679	et	3	main
juba	doc_213943984996_item	2284682	et	3	main
aasta	doc_213943984996_item	2284684	et	4	main
et	doc_213943984996_item	2284690	et	3	main
ajakirjanikuks	doc_213943984996_item	2284691	et	3	main
saan	doc_213943984996_item	2284692	et	4	main
ma	doc_213943984996_item	2284693	et	3	main
olen	doc_213943984996_item	2284694	et	3	main
veendunud	doc_213943984996_item	2284695	et	4	main
et	doc_213943984996_item	2284696	et	3	main
minule	doc_213943984996_item	2284697	et	3	main
tallinna	doc_213943984996_item	2284698	et	4	main
ülikool	doc_213943984996_item	2284699	et	4	main
on	doc_213943984996_item	2284700	et	4	main
ainus	doc_213943984996_item	2284701	et	4	main
ja	doc_213943984996_item	2284702	et	3	main
kordumatu	doc_213943984996_item	2284703	et	4	main
ning	doc_213943984996_item	2284704	et	3	main
siin	doc_213943984996_item	2284705	et	4	main
ma	doc_213943984996_item	2284706	et	3	main
saan	doc_213943984996_item	2284707	et	4	main
oma	doc_213943984996_item	2284708	et	4	main
teadmisi	doc_213943984996_item	2284709	et	4	main
taastada	doc_213943984996_item	2284710	et	3	main
täiustada	doc_213943984996_item	2284711	et	3	main
ja	doc_213943984996_item	2284712	et	3	main
süvendada	doc_213943984996_item	2284713	et	3	main
essee	doc_213943984997_item	2284714	et	4	main
1	doc_213943984997_item	2284715	et	2	main
miks	doc_213943984997_item	2284716	et	4	main
ma	doc_213943984997_item	2284717	et	3	main
valisin	doc_213943984997_item	2284718	et	3	main
selle	doc_213943984997_item	2284719	et	4	main
eriala	doc_213943984997_item	2284720	et	4	main
2	doc_213943984997_item	2284721	et	2	main
1	doc_213943984997_item	2284730	et	2	main
olin	doc_213943984997_item	2284737	et	3	main
lugesin	doc_213943984997_item	2284747	et	3	main
väga	doc_213943984997_item	2284754	et	3	main
ja	doc_213943984997_item	2284756	et	3	main
kirjutatud	doc_213943984997_item	2284758	et	4	main
olen	doc_213943984997_item	2284776	et	3	main
ootan	doc_213943984997_item	2284723	et	3	main
õppimisest	doc_213943984997_item	2284724	et	4	main
tallinna	doc_213943984997_item	2284728	et	4	main
ülikoolis	doc_213943984997_item	2284729	et	4	main
huvi	doc_213943984997_item	2284731	et	4	main
ma	doc_213943984997_item	2284736	et	3	main
viieteist	doc_213943984997_item	2284741	et	4	main
kuskilt	doc_213943984997_item	2284748	et	4	main
mis	doc_213943984997_item	2284752	et	4	main
hästi	doc_213943984997_item	2284755	et	3	main
lapsepõlve	doc_213943984997_item	2284765	et	4	main
eest	doc_213943984997_item	2284772	et	4	main
siis	doc_213943984997_item	2284783	et	3	main
minu	doc_213943984997_item	2284785	et	3	main
paberi	doc_213943984997_item	2284793	et	3	main
ma	doc_213943984997_item	2284797	et	3	main
ma	doc_213943984997_item	2284801	et	3	main
pean	doc_213943984997_item	2284804	et	4	main
te	doc_213943984997_item	2284813	et	4	main
ka	doc_213943984997_item	2284825	et	3	main
nö	doc_213943984997_item	2284840	et	4	main
vastu	doc_213943984997_item	2284846	et	3	main
mind	doc_213943984997_item	2284868	et	4	main
ootan	doc_213943984997_item	2284877	et	3	main
oma	doc_213943984997_item	2284885	et	4	main
õppingud	doc_213943984997_item	2284886	et	4	main
ma	doc_213943984997_item	2284888	et	3	main
ja	doc_213943984997_item	2284891	et	3	main
oodata	doc_213943984997_item	2284908	et	4	main
pärast	doc_213943984998_item	2284938	et	4	main
teenida	doc_213943984998_item	2284951	et	3	main
ka	doc_213943984998_item	2284962	et	3	main
tuleb	doc_213943984998_item	2284968	et	3	main
eriala	doc_213943984998_item	2284970	et	4	main
ja	doc_213943984998_item	2284974	et	3	main
lapsepõlve	doc_213943984998_item	2285010	et	4	main
oli	doc_213943984998_item	2285015	et	3	main
ja	doc_213943984998_item	2285016	et	3	main
lemmikajakirjanikud	doc_213943984998_item	2285020	et	3	main
lemmikajalehed	doc_213943984998_item	2285022	et	3	main
aeg	doc_213943984998_item	2285027	et	3	main
pole	doc_213943984998_item	2285029	et	3	main
hea	doc_213943984998_item	2285031	et	4	main
huvitavam	doc_213943984998_item	2285037	et	4	main
pärast	doc_213943984998_item	2285051	et	4	main
saad	doc_213943984998_item	2285054	et	4	main
juba	doc_213943984998_item	2285057	et	3	main
kahtlema	doc_213943984998_item	2285063	et	3	main
kui	doc_213943984998_item	2285072	et	3	main
et	doc_213943984998_item	2285079	et	3	main
väga	doc_213943984998_item	2285116	et	3	main
kirjutada	doc_213943984998_item	2285118	et	3	main
see	doc_213943984998_item	2285124	et	3	main
mulle	doc_213943984998_item	2285126	et	4	main
infot	doc_213943984998_item	2285131	et	3	main
aru	doc_213943984998_item	2285136	et	4	main
töötamises	doc_213943984998_item	2285138	et	4	main
ole	doc_213943984998_item	2285141	et	4	main
ei	doc_213943984998_item	2285147	et	4	main
mind	doc_213943984998_item	2285149	et	4	main
2	doc_213943984998_item	2285154	et	2	main
ülikooli	doc_213943984998_item	2285166	et	4	main
selleparast	doc_213943984998_item	2285167	et	3	main
eriala	doc_213943984998_item	2285172	et	4	main
õppetamisest	doc_213943984998_item	2285179	et	4	main
saa	doc_213943984998_item	2285225	et	4	main
1	doc_213943984999_item	2285229	et	2	main
ma	doc_213943984999_item	2285231	et	3	main
1	doc_213943984999_item	2285244	et	2	main
ajakirjandus	doc_213943984999_item	2285249	et	3	main
ajakirjandus	doc_213943984999_item	2285254	et	3	main
selle	doc_213943984999_item	2285262	et	4	main
et	doc_213943984999_item	2285264	et	3	main
perspektiivset	doc_213943984999_item	2285268	et	3	main
juba	doc_213943984999_item	2285276	et	3	main
ma	doc_213943984999_item	2285282	et	3	main
meeldib	doc_213943984999_item	2285321	et	3	main
eriala	doc_213943984999_item	2285328	et	4	main
tahaks	doc_213943984999_item	2285339	et	3	main
valiksin	doc_213943984999_item	2285343	et	3	main
varem	doc_213943984999_item	2285354	et	4	main
oli	doc_213943984999_item	2285355	et	3	main
ülikool	doc_213943984999_item	2285358	et	4	main
ja	doc_213943984999_item	2285366	et	3	main
huvitas	doc_213943984999_item	2285370	et	3	main
ja	doc_213943984999_item	2285372	et	3	main
otsustasin	doc_213943984999_item	2285374	et	3	main
tahaksin	doc_213943984999_item	2285376	et	3	main
kõik	doc_213943984997_item	2284778	et	4	main
toimub	doc_213943984997_item	2284781	et	3	main
ja	doc_213943984997_item	2284795	et	3	main
olen	doc_213943984997_item	2284800	et	3	main
või	doc_213943984997_item	2284803	et	4	main
kohta	doc_213943984997_item	2284808	et	4	main
olla	doc_213943984997_item	2284820	et	3	main
et	doc_213943984997_item	2284821	et	3	main
see	doc_213943984997_item	2284826	et	3	main
ja	doc_213943984997_item	2284832	et	3	main
ma	doc_213943984997_item	2284834	et	3	main
mulle	doc_213943984997_item	2284839	et	4	main
armastuse	doc_213943984997_item	2284842	et	4	main
lugemise	doc_213943984997_item	2284843	et	4	main
ja	doc_213943984997_item	2284844	et	3	main
kokkuvõtteks	doc_213943984997_item	2284847	et	3	main
sõnul	doc_213943984997_item	2284857	et	3	main
arvan	doc_213943984997_item	2284871	et	3	main
õppimisest	doc_213943984997_item	2284873	et	4	main
sõnavara	doc_213943984997_item	2284879	et	4	main
ja	doc_213943984997_item	2284894	et	3	main
aga	doc_213943984997_item	2284903	et	3	main
võib	doc_213943984997_item	2284907	et	3	main
näeme	doc_213943984997_item	2284910	et	3	main
miks	doc_213943984998_item	2284912	et	4	main
ma	doc_213943984998_item	2284913	et	3	main
valisin	doc_213943984998_item	2284914	et	3	main
selle	doc_213943984998_item	2284915	et	4	main
minu	doc_213943984997_item	2284828	et	3	main
oli	doc_213943984997_item	2284830	et	3	main
üle	doc_213943984997_item	2284841	et	3	main
ütleksin	doc_213943984997_item	2284848	et	3	main
mulle	doc_213943984997_item	2284850	et	4	main
minu	doc_213943984997_item	2284855	et	3	main
õppetajate	doc_213943984997_item	2284856	et	4	main
mul	doc_213943984997_item	2284858	et	3	main
tuleb	doc_213943984997_item	2284859	et	3	main
see	doc_213943984997_item	2284860	et	3	main
hästi	doc_213943984997_item	2284861	et	3	main
kuigi	doc_213943984997_item	2284863	et	3	main
mõnikord	doc_213943984997_item	2284864	et	3	main
minu	doc_213943984997_item	2284865	et	3	main
gramaatika	doc_213943984997_item	2284866	et	4	main
välja	doc_213943984997_item	2284862	et	4	main
veab	doc_213943984997_item	2284867	et	3	main
alt	doc_213943984997_item	2284869	et	4	main
ma	doc_213943984997_item	2284870	et	3	main
erialal	doc_213943984997_item	2284875	et	3	main
oma	doc_213943984997_item	2284878	et	4	main
täiendamist	doc_213943984997_item	2284880	et	4	main
kui	doc_213943984997_item	2284883	et	3	main
siis	doc_213943984997_item	2284887	et	3	main
saan	doc_213943984997_item	2284889	et	4	main
töötada	doc_213943984997_item	2284892	et	3	main
pärast	doc_213943984997_item	2284896	et	4	main
mida	doc_213943984997_item	2284904	et	4	main
inimene	doc_213943984997_item	2284906	et	3	main
mida	doc_213943984998_item	2284917	et	4	main
ootan	doc_213943984998_item	2284918	et	3	main
õppimisest	doc_213943984998_item	2284919	et	4	main
sellel	doc_213943984998_item	2284920	et	4	main
on	doc_213943984998_item	2284932	et	4	main
kooli	doc_213943984998_item	2284939	et	4	main
tööle	doc_213943984998_item	2284949	et	3	main
edasi	doc_213943984998_item	2284961	et	3	main
astuda	doc_213943984998_item	2284964	et	3	main
siiamani	doc_213943984998_item	2285019	et	4	main
ja	doc_213943984998_item	2285021	et	3	main
neid	doc_213943984998_item	2285023	et	4	main
ma	doc_213943984998_item	2285024	et	3	main
see	doc_213943984998_item	2285028	et	3	main
eriti	doc_213943984998_item	2285030	et	3	main
kui	doc_213943984998_item	2285038	et	3	main
mingi	doc_213943984998_item	2285040	et	4	main
põnevat	doc_213943984998_item	2285041	et	3	main
kooliaeg	doc_213943984998_item	2285049	et	3	main
ajakirjanikuks	doc_213943984998_item	2285055	et	3	main
hakkas	doc_213943984998_item	2285058	et	3	main
hakkasin	doc_213943984998_item	2285062	et	3	main
oma	doc_213943984998_item	2285064	et	4	main
ei	doc_213943984998_item	2285067	et	4	main
kindel	doc_213943984998_item	2285071	et	3	main
praegu	doc_213943984998_item	2285074	et	3	main
on	doc_213943984998_item	2285077	et	4	main
rõõm	doc_213943984998_item	2285078	et	3	main
oli	doc_213943984998_item	2285115	et	3	main
intervjeerida	doc_213943984998_item	2285120	et	4	main
ja	doc_213943984998_item	2285123	et	3	main
minu	doc_213943984998_item	2285127	et	3	main
arvates	doc_213943984998_item	2285128	et	4	main
inimestele	doc_213943984998_item	2285130	et	3	main
on	doc_213943984998_item	2285132	et	4	main
ma	doc_213943984998_item	2285134	et	3	main
eriti	doc_213943984998_item	2285146	et	3	main
puudu	doc_213943984998_item	2285148	et	4	main
ma	doc_213943984998_item	2285150	et	3	main
mida	doc_213943984998_item	2285155	et	4	main
ja	doc_213943984998_item	2285160	et	3	main
siin	doc_213943984998_item	2285169	et	4	main
mis	doc_213943984998_item	2285173	et	4	main
mind	doc_213943984998_item	2285175	et	4	main
palju	doc_213943984998_item	2285187	et	4	main
mida	doc_213943984998_item	2285221	et	4	main
miks	doc_213943984999_item	2285230	et	4	main
ootan	doc_213943984999_item	2285237	et	3	main
õppimisest	doc_213943984999_item	2285238	et	4	main
ja	doc_213943984999_item	2285241	et	3	main
et	doc_213943984999_item	2285248	et	3	main
huvitab	doc_213943984999_item	2285251	et	3	main
valiksin	doc_213943984999_item	2285261	et	3	main
eriala	doc_213943984999_item	2285263	et	4	main
mõtlema	doc_213943984999_item	2285273	et	3	main
saada	doc_213943984999_item	2285275	et	4	main
kelleks	doc_213943984999_item	2285281	et	4	main
selle	doc_213943984998_item	2284929	et	4	main
see	doc_213943984998_item	2284931	et	3	main
mõned	doc_213943984998_item	2284941	et	3	main
üks	doc_213943984998_item	2284943	et	3	main
paar	doc_213943984998_item	2284945	et	3	main
et	doc_213943984998_item	2284950	et	3	main
raha	doc_213943984998_item	2284952	et	4	main
peagi	doc_213943984998_item	2284954	et	4	main
õppida	doc_213943984998_item	2284963	et	3	main
mingi	doc_213943984998_item	2284965	et	4	main
see	doc_213943984998_item	2284975	et	3	main
on	doc_213943984998_item	2284976	et	4	main
juba	doc_213943984998_item	2284977	et	3	main
saia	doc_213943984998_item	2284978	et	4	main
korda	doc_213943984998_item	2284979	et	4	main
raskem	doc_213943984998_item	2284980	et	4	main
on	doc_213943984998_item	2284981	et	4	main
vaja	doc_213943984998_item	2284982	et	4	main
ise	doc_213943984998_item	2284983	et	4	main
ennaga	doc_213943984998_item	2284984	et	4	main
kokku	doc_213943984998_item	2284985	et	3	main
lepida	doc_213943984998_item	2284986	et	4	main
sa	doc_213943984998_item	2284988	et	3	main
tahad	doc_213943984998_item	2284989	et	3	main
praeguses	doc_213943984998_item	2284990	et	3	main
mida	doc_213943984998_item	2284987	et	4	main
ja	doc_213943984998_item	2284991	et	3	main
olevikus	doc_213943984998_item	2284992	et	3	main
elus	doc_213943984998_item	2284993	et	4	main
mina	doc_213943984998_item	2284994	et	4	main
aga	doc_213943984998_item	2284995	et	3	main
sain	doc_213943984998_item	2284996	et	3	main
aru	doc_213943984998_item	2284997	et	4	main
mida	doc_213943984998_item	2284998	et	4	main
ma	doc_213943984998_item	2284999	et	3	main
tahan	doc_213943984998_item	2285000	et	3	main
neli	doc_213943984998_item	2285001	et	3	main
miks	doc_213943984998_item	2284926	et	4	main
ma	doc_213943984998_item	2284927	et	3	main
küll	doc_213943984998_item	2284933	et	4	main
suur	doc_213943984998_item	2284934	et	3	main
mida	doc_213943984998_item	2284936	et	4	main
lõppetamist	doc_213943984998_item	2284940	et	4	main
valivad	doc_213943984998_item	2284942	et	4	main
või	doc_213943984998_item	2284944	et	4	main
või	doc_213943984998_item	2284947	et	4	main
minna	doc_213943984998_item	2284948	et	3	main
aga	doc_213943984998_item	2284953	et	3	main
kõik	doc_213943984998_item	2284955	et	4	main
need	doc_213943984998_item	2284956	et	3	main
noormehed	doc_213943984998_item	2284957	et	3	main
ja	doc_213943984998_item	2284958	et	3	main
neiud	doc_213943984998_item	2284959	et	4	main
otsustavad	doc_213943984998_item	2284960	et	4	main
ülikooli	doc_213943984998_item	2284966	et	4	main
kus	doc_213943984998_item	2284971	et	3	main
õppida	doc_213943984998_item	2284973	et	3	main
aastat	doc_213943984998_item	2285004	et	3	main
saada	doc_213943984998_item	2285006	et	4	main
ajakirjanikuks	doc_213943984998_item	2285007	et	3	main
oli	doc_213943984998_item	2285008	et	3	main
mu	doc_213943984998_item	2285009	et	3	main
uni	doc_213943984998_item	2285011	et	3	main
ja	doc_213943984998_item	2285012	et	3	main
unistus	doc_213943984998_item	2285013	et	4	main
mul	doc_213943984998_item	2285014	et	3	main
ka	doc_213943984998_item	2285018	et	3	main
aga	doc_213943984998_item	2285032	et	3	main
oli	doc_213943984998_item	2285036	et	3	main
näiteks	doc_213943984998_item	2285039	et	4	main
raamatut	doc_213943984998_item	2285042	et	3	main
lihtsalt	doc_213943984998_item	2285044	et	4	main
juba	doc_213943984998_item	2285047	et	3	main
aga	doc_213943984998_item	2285061	et	3	main
valikus	doc_213943984998_item	2285065	et	3	main
olnud	doc_213943984998_item	2285068	et	4	main
tekste	doc_213943984998_item	2285122	et	3	main
hüvasti	doc_213943984998_item	2285133	et	3	main
ajakirjanikuna	doc_213943984998_item	2285139	et	3	main
ei	doc_213943984998_item	2285140	et	4	main
see	doc_213943984998_item	2285145	et	3	main
ajakirjanikuks	doc_213943984998_item	2285153	et	3	main
õppimisest	doc_213943984998_item	2285157	et	4	main
erialal	doc_213943984998_item	2285159	et	3	main
ülikoolis	doc_213943984998_item	2285162	et	4	main
see	doc_213943984998_item	2285171	et	3	main
huvitab	doc_213943984998_item	2285174	et	3	main
minu	doc_213943984998_item	2285176	et	3	main
ei	doc_213943984998_item	2285177	et	4	main
ma	doc_213943984998_item	2285182	et	3	main
praegu	doc_213943984998_item	2285186	et	3	main
ootan	doc_213943984998_item	2285222	et	3	main
öelda	doc_213943984998_item	2285227	et	4	main
valiksin	doc_213943984999_item	2285232	et	3	main
2	doc_213943984999_item	2285235	et	2	main
tahan	doc_213943984999_item	2285246	et	3	main
väga	doc_213943984999_item	2285250	et	3	main
tänapäeval	doc_213943984999_item	2285253	et	3	main
on	doc_213943984999_item	2285255	et	4	main
väga	doc_213943984999_item	2285256	et	3	main
populaarne	doc_213943984999_item	2285257	et	3	main
ja	doc_213943984999_item	2285258	et	3	main
perspektiivne	doc_213943984999_item	2285259	et	3	main
huvitavat	doc_213943984999_item	2285266	et	4	main
praegu	doc_213943984999_item	2285270	et	3	main
valima	doc_213943984999_item	2285280	et	3	main
tahan	doc_213943984999_item	2285283	et	3	main
olin	doc_213943984999_item	2285287	et	3	main
meedia	doc_213943984999_item	2285323	et	4	main
selle	doc_213943984999_item	2285327	et	4	main
ma	doc_213943984999_item	2285342	et	3	main
ja	doc_213943984999_item	2285346	et	3	main
ajakirjandus	doc_213943984999_item	2285348	et	3	main
tallinna	doc_213943984999_item	2285356	et	4	main
ülikoolist	doc_213943984999_item	2285367	et	4	main
ülikoolis	doc_213943984999_item	2285380	et	4	main
ma	doc_213943984999_item	2285381	et	3	main
arvan	doc_213943984999_item	2285382	et	3	main
et	doc_213943984999_item	2285383	et	3	main
olin	doc_213943984999_item	2285396	et	3	main
õppida	doc_213943984999_item	2285422	et	3	main
tallinna	doc_213943984999_item	2285423	et	4	main
et	doc_213943984999_item	2285428	et	3	main
kõik	doc_213943984999_item	2285429	et	4	main
selle	doc_213943985000_item	2285438	et	4	main
eriala	doc_213943985000_item	2285439	et	4	main
2	doc_213943985000_item	2285440	et	2	main
ülikoolis	doc_213943985000_item	2285448	et	4	main
mulle	doc_213943985000_item	2285454	et	4	main
väga	doc_213943985000_item	2285455	et	3	main
ma	doc_213943985000_item	2285462	et	3	main
see	doc_213943985000_item	2285465	et	3	main
põnev	doc_213943985000_item	2285476	et	3	main
ma	doc_213943985000_item	2285478	et	3	main
inimene	doc_213943985000_item	2285481	et	3	main
tahab	doc_213943985000_item	2285483	et	3	main
ja	doc_213943985000_item	2285486	et	3	main
töökohta	doc_213943985000_item	2285523	et	4	main
on	doc_213943985000_item	2285525	et	4	main
tutvuseid	doc_213943985000_item	2285528	et	3	main
ma	doc_213943985000_item	2285529	et	3	main
on	doc_213943984998_item	2285017	et	4	main
lugesin	doc_213943984998_item	2285025	et	3	main
lugeda	doc_213943984998_item	2285033	et	3	main
millal	doc_213943984998_item	2285046	et	3	main
lõppeb	doc_213943984998_item	2285048	et	3	main
et	doc_213943984998_item	2285050	et	3	main
kooliaeg	doc_213943984998_item	2285056	et	3	main
lõppetada	doc_213943984998_item	2285059	et	4	main
mina	doc_213943984998_item	2285060	et	4	main
mina	doc_213943984998_item	2285066	et	4	main
nii	doc_213943984998_item	2285070	et	3	main
lapsepõlves	doc_213943984998_item	2285073	et	4	main
aga	doc_213943984998_item	2285075	et	3	main
mul	doc_213943984998_item	2285076	et	3	main
sel	doc_213943984998_item	2285080	et	3	main
kogu	doc_213943984998_item	2285026	et	4	main
ajalehte	doc_213943984998_item	2285034	et	4	main
mul	doc_213943984998_item	2285035	et	3	main
ma	doc_213943984998_item	2285043	et	3	main
ootasin	doc_213943984998_item	2285045	et	3	main
õppida	doc_213943984998_item	2285052	et	3	main
ja	doc_213943984998_item	2285053	et	3	main
juba	doc_213943984998_item	2285069	et	3	main
raskel	doc_213943984998_item	2285081	et	3	main
ajal	doc_213943984998_item	2285082	et	4	main
ma	doc_213943984998_item	2285083	et	3	main
sain	doc_213943984998_item	2285084	et	3	main
teada	doc_213943984998_item	2285085	et	3	main
tallina	doc_213943984998_item	2285086	et	3	main
ülikoolis	doc_213943984998_item	2285087	et	4	main
toimuvad	doc_213943984998_item	2285088	et	4	main
ajakirjaniku	doc_213943984998_item	2285089	et	3	main
kursused	doc_213943984998_item	2285090	et	3	main
ma	doc_213943984998_item	2285091	et	3	main
registreerisin	doc_213943984998_item	2285092	et	3	main
enda	doc_213943984998_item	2285093	et	4	main
ja	doc_213943984998_item	2285094	et	3	main
hakkasin	doc_213943984998_item	2285095	et	3	main
käima	doc_213943984998_item	2285096	et	4	main
nendel	doc_213943984998_item	2285097	et	4	main
kursustel	doc_213943984998_item	2285098	et	3	main
ja	doc_213943984998_item	2285099	et	3	main
varsti	doc_213943984998_item	2285100	et	3	main
oli	doc_213943984998_item	2285101	et	3	main
juba	doc_213943984998_item	2285102	et	3	main
saiaprotsendiliselt	doc_213943984998_item	2285103	et	4	main
kindel	doc_213943984998_item	2285104	et	3	main
et	doc_213943984998_item	2285105	et	3	main
ajakirjandus	doc_213943984998_item	2285106	et	3	main
on	doc_213943984998_item	2285107	et	4	main
see	doc_213943984998_item	2285108	et	3	main
asi	doc_213943984998_item	2285109	et	4	main
mis	doc_213943984998_item	2285110	et	4	main
on	doc_213943984998_item	2285111	et	4	main
mul	doc_213943984998_item	2285112	et	3	main
vaja	doc_213943984998_item	2285113	et	4	main
see	doc_213943984998_item	2285114	et	3	main
huvitav	doc_213943984998_item	2285117	et	4	main
artikleid	doc_213943984998_item	2285119	et	3	main
meeldis	doc_213943984998_item	2285125	et	3	main
tuua	doc_213943984998_item	2285129	et	3	main
saan	doc_213943984998_item	2285135	et	4	main
palju	doc_213943984998_item	2285142	et	4	main
tahan	doc_213943984998_item	2285151	et	3	main
tallinna	doc_213943984998_item	2285161	et	4	main
mina	doc_213943984998_item	2285163	et	4	main
astusin	doc_213943984998_item	2285164	et	3	main
tallinna	doc_213943984998_item	2285165	et	4	main
on	doc_213943984998_item	2285170	et	4	main
kerget	doc_213943984998_item	2285180	et	4	main
arvan	doc_213943984998_item	2285183	et	3	main
tuleb	doc_213943984998_item	2285185	et	3	main
koostada	doc_213943984998_item	2285121	et	3	main
et	doc_213943984998_item	2285137	et	3	main
puhkust	doc_213943984998_item	2285143	et	4	main
aga	doc_213943984998_item	2285144	et	3	main
saada	doc_213943984998_item	2285152	et	4	main
ootan	doc_213943984998_item	2285156	et	3	main
sellel	doc_213943984998_item	2285158	et	4	main
et	doc_213943984998_item	2285168	et	3	main
oota	doc_213943984998_item	2285178	et	4	main
elut	doc_213943984998_item	2285181	et	4	main
et	doc_213943984998_item	2285184	et	3	main
töötada	doc_213943984998_item	2285188	et	3	main
ainult	doc_213943984998_item	2285189	et	4	main
viib	doc_213943984998_item	2285191	et	3	main
õppimine	doc_213943984998_item	2285190	et	4	main
heale	doc_213943984998_item	2285192	et	3	main
ja	doc_213943984998_item	2285193	et	3	main
huvitavale	doc_213943984998_item	2285194	et	4	main
tööle	doc_213943984998_item	2285195	et	3	main
mina	doc_213943984998_item	2285196	et	4	main
aga	doc_213943984998_item	2285197	et	3	main
ootan	doc_213943984998_item	2285198	et	3	main
et	doc_213943984998_item	2285199	et	3	main
tallinna	doc_213943984998_item	2285200	et	4	main
ülikoolis	doc_213943984998_item	2285201	et	4	main
toimuvad	doc_213943984998_item	2285202	et	4	main
ka	doc_213943984998_item	2285203	et	3	main
huvitavad	doc_213943984998_item	2285204	et	4	main
üritused	doc_213943984998_item	2285205	et	4	main
kus	doc_213943984998_item	2285206	et	3	main
saab	doc_213943984998_item	2285207	et	3	main
ka	doc_213943984998_item	2285208	et	3	main
võtta	doc_213943984998_item	2285209	et	3	main
osa	doc_213943984998_item	2285210	et	4	main
ma	doc_213943984998_item	2285211	et	3	main
arvan	doc_213943984998_item	2285212	et	3	main
et	doc_213943984998_item	2285213	et	3	main
ülikooli	doc_213943984998_item	2285214	et	4	main
ei	doc_213943984998_item	2285216	et	4	main
elu	doc_213943984998_item	2285215	et	4	main
ole	doc_213943984998_item	2285217	et	4	main
sarnane	doc_213943984998_item	2285218	et	4	main
kooli	doc_213943984998_item	2285219	et	4	main
eluga	doc_213943984998_item	2285220	et	3	main
veel	doc_213943984998_item	2285223	et	4	main
ei	doc_213943984998_item	2285224	et	4	main
praegu	doc_213943984998_item	2285226	et	3	main
selle	doc_213943984999_item	2285233	et	4	main
erialal	doc_213943984999_item	2285240	et	3	main
essee	doc_213943984999_item	2285228	et	4	main
eriala	doc_213943984999_item	2285234	et	4	main
mida	doc_213943984999_item	2285236	et	4	main
sellel	doc_213943984999_item	2285239	et	4	main
öelda	doc_213943984999_item	2285247	et	4	main
ma	doc_213943984999_item	2285260	et	3	main
saada	doc_213943984999_item	2285265	et	4	main
inimesed	doc_213943984999_item	2285271	et	3	main
kelleks	doc_213943984999_item	2285274	et	4	main
lapsepõlvest	doc_213943984999_item	2285277	et	4	main
ma	doc_213943984999_item	2285278	et	3	main
6	doc_213943984999_item	2285288	et	2	main
kui	doc_213943984999_item	2285285	et	3	main
klassis	doc_213943984999_item	2285289	et	3	main
õppinud	doc_213943984999_item	2285290	et	4	main
ma	doc_213943984999_item	2285291	et	3	main
tahtsin	doc_213943984999_item	2285292	et	3	main
olla	doc_213943984999_item	2285293	et	3	main
floristiks	doc_213943984999_item	2285294	et	4	main
õpetajaks	doc_213943984999_item	2285295	et	4	main
juristiks	doc_213943984999_item	2285296	et	3	main
aga	doc_213943984999_item	2285297	et	3	main
see	doc_213943984999_item	2285298	et	3	main
oli	doc_213943984999_item	2285299	et	3	main
lapse	doc_213943984999_item	2285301	et	4	main
unistused	doc_213943984999_item	2285302	et	4	main
ainult	doc_213943984999_item	2285300	et	4	main
pärast	doc_213943984999_item	2285303	et	4	main
9	doc_213943984999_item	2285304	et	2	main
klassi	doc_213943984999_item	2285305	et	4	main
ma	doc_213943984999_item	2285306	et	3	main
hakasin	doc_213943984999_item	2285307	et	4	main
tõsiselt	doc_213943984999_item	2285308	et	4	main
mõtlema	doc_213943984999_item	2285309	et	3	main
milline	doc_213943984999_item	2285310	et	3	main
elukutse	doc_213943984999_item	2285311	et	4	main
valida	doc_213943984999_item	2285312	et	3	main
ma	doc_213943984999_item	2285313	et	3	main
olen	doc_213943984999_item	2285314	et	3	main
väga	doc_213943984999_item	2285315	et	3	main
aktiine	doc_213943984999_item	2285316	et	4	main
heatahtlik	doc_213943984999_item	2285317	et	3	main
ja	doc_213943984999_item	2285319	et	3	main
mulle	doc_213943984999_item	2285320	et	4	main
inimene	doc_213943984999_item	2285318	et	3	main
ma	doc_213943984999_item	2285325	et	3	main
ma	doc_213943984999_item	2285334	et	3	main
ülikooli	doc_213943984999_item	2285336	et	4	main
kus	doc_213943984999_item	2285337	et	3	main
tallinna	doc_213943984999_item	2285242	et	4	main
ülikoolis	doc_213943984999_item	2285243	et	4	main
kõigepealt	doc_213943984999_item	2285245	et	3	main
mind	doc_213943984999_item	2285252	et	4	main
ja	doc_213943984999_item	2285267	et	3	main
elukutset	doc_213943984999_item	2285269	et	3	main
hakavad	doc_213943984999_item	2285272	et	4	main
hakasin	doc_213943984999_item	2285279	et	4	main
saada	doc_213943984999_item	2285284	et	4	main
ma	doc_213943984999_item	2285286	et	3	main
venekeelne	doc_213943984999_item	2285322	et	3	main
valiksin	doc_213943984999_item	2285326	et	3	main
2	doc_213943984999_item	2285329	et	2	main
kui	doc_213943984999_item	2285330	et	3	main
ma	doc_213943984999_item	2285331	et	3	main
õppisin	doc_213943984999_item	2285332	et	3	main
koolis	doc_213943984999_item	2285333	et	4	main
valiksin	doc_213943984999_item	2285335	et	3	main
kõrgharidust	doc_213943984999_item	2285341	et	4	main
eriala	doc_213943984999_item	2285347	et	4	main
ema	doc_213943984999_item	2285350	et	4	main
tallinna	doc_213943984999_item	2285352	et	4	main
ülikooli	doc_213943984999_item	2285353	et	4	main
ema	doc_213943984999_item	2285359	et	4	main
rääkis	doc_213943984999_item	2285362	et	3	main
õppimisest	doc_213943984999_item	2285365	et	4	main
mind	doc_213943984999_item	2285371	et	4	main
ma	doc_213943984999_item	2285373	et	3	main
sulle	doc_213943984999_item	2285387	et	3	main
sa	doc_213943984999_item	2285391	et	3	main
augustil	doc_213943984999_item	2285394	et	3	main
olid	doc_213943984999_item	2285401	et	4	main
ma	doc_213943984999_item	2285403	et	3	main
sellest	doc_213943984999_item	2285405	et	4	main
huvitavaid	doc_213943984999_item	2285407	et	4	main
muljeid	doc_213943984999_item	2285408	et	3	main
palju	doc_213943984999_item	2285411	et	4	main
inimestega	doc_213943984999_item	2285413	et	3	main
meeldib	doc_213943984999_item	2285421	et	3	main
ma	doc_213943984999_item	2285426	et	3	main
ainult	doc_213943984999_item	2285431	et	4	main
parem	doc_213943984999_item	2285432	et	4	main
mida	doc_213943985000_item	2285441	et	4	main
ootan	doc_213943985000_item	2285442	et	3	main
õpimisest	doc_213943985000_item	2285443	et	4	main
valisin	doc_213943985000_item	2285450	et	3	main
selle	doc_213943985000_item	2285451	et	4	main
eriala	doc_213943985000_item	2285452	et	4	main
sest	doc_213943985000_item	2285453	et	4	main
raamatuid	doc_213943985000_item	2285458	et	3	main
mõtlen	doc_213943985000_item	2285463	et	3	main
eriala	doc_213943985000_item	2285466	et	4	main
laiendab	doc_213943985000_item	2285468	et	3	main
ajakirjandus	doc_213943985000_item	2285470	et	3	main
minu	doc_213943985000_item	2285471	et	3	main
arvamusest	doc_213943985000_item	2285472	et	4	main
ja	doc_213943985000_item	2285475	et	3	main
olen	doc_213943985000_item	2285479	et	3	main
kriitiserin	doc_213943985000_item	2285493	et	4	main
ja	doc_213943985000_item	2285521	et	3	main
siis	doc_213943985000_item	2285541	et	3	main
ma	doc_213943985000_item	2285545	et	3	main
mina	doc_213943985000_item	2285548	et	4	main
siin	doc_213943985000_item	2285550	et	4	main
õppida	doc_213943985000_item	2285551	et	3	main
ajakirjandus	doc_213943985000_item	2285552	et	3	main
on	doc_213943985000_item	2285553	et	4	main
on	doc_213943985000_item	2285557	et	4	main
aega	doc_213943985000_item	2285565	et	4	main
edasi	doc_213943985000_item	2285570	et	3	main
sellepärast	doc_213943984999_item	2285324	et	3	main
saada	doc_213943984999_item	2285340	et	4	main
tallinna	doc_213943984999_item	2285344	et	4	main
lõpetas	doc_213943984999_item	2285351	et	3	main
väga	doc_213943984999_item	2285360	et	3	main
mulle	doc_213943984999_item	2285363	et	4	main
oma	doc_213943984999_item	2285364	et	4	main
ainult	doc_213943984999_item	2285378	et	4	main
et	doc_213943984999_item	2285386	et	3	main
õppesid	doc_213943984999_item	2285392	et	4	main
pärast	doc_213943984999_item	2285400	et	4	main
palju	doc_213943984999_item	2285406	et	4	main
ma	doc_213943984999_item	2285409	et	3	main
väga	doc_213943984999_item	2285418	et	3	main
rahul	doc_213943984999_item	2285419	et	4	main
mulle	doc_213943984999_item	2285420	et	4	main
ülikoolis	doc_213943984999_item	2285424	et	4	main
miks	doc_213943985000_item	2285435	et	4	main
ma	doc_213943985000_item	2285436	et	3	main
valisin	doc_213943985000_item	2285437	et	3	main
sellel	doc_213943985000_item	2285444	et	4	main
meeldib	doc_213943985000_item	2285456	et	3	main
kirjandeid	doc_213943985000_item	2285461	et	3	main
on	doc_213943985000_item	2285473	et	4	main
kellel	doc_213943985000_item	2285487	et	4	main
mingid	doc_213943985000_item	2285494	et	4	main
ka	doc_213943985000_item	2285526	et	3	main
et	doc_213943985000_item	2285531	et	3	main
siin	doc_213943985000_item	2285533	et	4	main
ole	doc_213943985000_item	2285535	et	4	main
lihtne	doc_213943985000_item	2285536	et	3	main
aga	doc_213943985000_item	2285537	et	3	main
mulle	doc_213943985000_item	2285555	et	4	main
elu	doc_213943985000_item	2285556	et	4	main
1	doc_213943985002_item	2285705	et	2	main
miks	doc_213943985002_item	2285706	et	4	main
valisin	doc_213943985002_item	2285708	et	3	main
elada	doc_213943985002_item	2285726	et	3	main
ajakirjanikke	doc_213943985002_item	2285730	et	3	main
elusuhtumisega	doc_213943985002_item	2285740	et	4	main
tunnen	doc_213943985002_item	2285743	et	3	main
kõike	doc_213943985002_item	2285745	et	4	main
vastu	doc_213943985002_item	2285746	et	3	main
läbi	doc_213943985002_item	2285763	et	4	main
inimestega	doc_213943985002_item	2285764	et	3	main
paar	doc_213943985002_item	2285771	et	3	main
seal	doc_213943985002_item	2285802	et	4	main
minu	doc_213943985002_item	2285810	et	3	main
seda	doc_213943985002_item	2285812	et	3	main
ma	doc_213943984999_item	2285338	et	3	main
ülikooli	doc_213943984999_item	2285345	et	4	main
minu	doc_213943984999_item	2285349	et	3	main
pedagoogika	doc_213943984999_item	2285357	et	4	main
palju	doc_213943984999_item	2285361	et	4	main
see	doc_213943984999_item	2285368	et	3	main
väga	doc_213943984999_item	2285369	et	3	main
et	doc_213943984999_item	2285375	et	3	main
õppida	doc_213943984999_item	2285377	et	3	main
sellises	doc_213943984999_item	2285379	et	4	main
väga	doc_213943984999_item	2285384	et	3	main
koht	doc_213943984999_item	2285389	et	3	main
29	doc_213943984999_item	2285393	et	2	main
ma	doc_213943984999_item	2285395	et	3	main
tallinna	doc_213943984999_item	2285397	et	4	main
avaaktusel	doc_213943984999_item	2285399	et	3	main
infotunned	doc_213943984999_item	2285402	et	4	main
tutvustasin	doc_213943984999_item	2285410	et	3	main
praegu	doc_213943984999_item	2285415	et	3	main
ma	doc_213943984999_item	2285416	et	3	main
loodan	doc_213943984999_item	2285427	et	3	main
oleks	doc_213943984999_item	2285430	et	3	main
mina	doc_213943985000_item	2285449	et	4	main
ja	doc_213943985000_item	2285459	et	3	main
et	doc_213943985000_item	2285464	et	3	main
huvitav	doc_213943985000_item	2285474	et	4	main
see	doc_213943985000_item	2285480	et	3	main
on	doc_213943985000_item	2285488	et	4	main
oma	doc_213943985000_item	2285489	et	4	main
maailmavaade	doc_213943985000_item	2285490	et	3	main
mõnikord	doc_213943985000_item	2285491	et	3	main
tähtis	doc_213943984999_item	2285385	et	4	main
meeldib	doc_213943984999_item	2285388	et	3	main
kus	doc_213943984999_item	2285390	et	3	main
ülikooli	doc_213943984999_item	2285398	et	4	main
sain	doc_213943984999_item	2285404	et	3	main
uue	doc_213943984999_item	2285412	et	3	main
üldiselt	doc_213943984999_item	2285414	et	4	main
olen	doc_213943984999_item	2285417	et	3	main
ja	doc_213943984999_item	2285425	et	3	main
essee	doc_213943985000_item	2285433	et	4	main
1	doc_213943985000_item	2285434	et	2	main
erialal	doc_213943985000_item	2285445	et	3	main
ja	doc_213943985000_item	2285446	et	3	main
tallinna	doc_213943985000_item	2285447	et	4	main
lugeda	doc_213943985000_item	2285457	et	3	main
kirjutada	doc_213943985000_item	2285460	et	3	main
väga	doc_213943985000_item	2285467	et	3	main
silmaringi	doc_213943985000_item	2285469	et	4	main
töö	doc_213943985000_item	2285477	et	4	main
kes	doc_213943985000_item	2285482	et	4	main
palju	doc_213943985000_item	2285484	et	4	main
teada	doc_213943985000_item	2285485	et	3	main
mina	doc_213943985000_item	2285492	et	4	main
asjad	doc_213943985000_item	2285495	et	3	main
ja	doc_213943985000_item	2285496	et	3	main
teemad	doc_213943985000_item	2285497	et	3	main
ühesõnaga	doc_213943985000_item	2285498	et	3	main
armastan	doc_213943985000_item	2285500	et	3	main
tõde	doc_213943985000_item	2285501	et	4	main
leidmist	doc_213943985000_item	2285502	et	4	main
ja	doc_213943985000_item	2285503	et	3	main
südant	doc_213943985000_item	2285504	et	3	main
mina	doc_213943985000_item	2285499	et	4	main
puistata	doc_213943985000_item	2285505	et	4	main
ootan	doc_213943985000_item	2285507	et	3	main
õpimisest	doc_213943985000_item	2285508	et	4	main
mida	doc_213943985000_item	2285506	et	4	main
sellel	doc_213943985000_item	2285509	et	4	main
erialal	doc_213943985000_item	2285510	et	3	main
ja	doc_213943985000_item	2285511	et	3	main
tallinna	doc_213943985000_item	2285512	et	4	main
ülikoolis	doc_213943985000_item	2285513	et	4	main
ma	doc_213943985000_item	2285514	et	3	main
arvan	doc_213943985000_item	2285515	et	3	main
et	doc_213943985000_item	2285516	et	3	main
ma	doc_213943985000_item	2285517	et	3	main
ootan	doc_213943985000_item	2285518	et	3	main
kõigepealt	doc_213943985000_item	2285519	et	3	main
kõrgharidust	doc_213943985000_item	2285520	et	4	main
tähtsad	doc_213943985000_item	2285524	et	3	main
kui	doc_213943985000_item	2285538	et	3	main
kindlasti	doc_213943985000_item	2285542	et	3	main
võib	doc_213943985000_item	2285544	et	3	main
loodan	doc_213943985000_item	2285546	et	3	main
huvitav	doc_213943985000_item	2285554	et	4	main
lühike	doc_213943985000_item	2285558	et	4	main
ei	doc_213943985000_item	2285561	et	4	main
ja	doc_213943985000_item	2285569	et	3	main
huvitava	doc_213943985000_item	2285522	et	4	main
uued	doc_213943985000_item	2285527	et	3	main
arvan	doc_213943985000_item	2285530	et	3	main
tahab	doc_213943985000_item	2285540	et	3	main
ja	doc_213943985000_item	2285559	et	3	main
raiskata	doc_213943985000_item	2285564	et	4	main
mina	doc_213943985000_item	2285566	et	4	main
tahan	doc_213943985000_item	2285567	et	3	main
õppida	doc_213943985000_item	2285568	et	3	main
arendama	doc_213943985000_item	2285571	et	3	main
õppida	doc_213943985000_item	2285532	et	3	main
ei	doc_213943985000_item	2285534	et	4	main
inimene	doc_213943985000_item	2285539	et	3	main
kõik	doc_213943985000_item	2285543	et	4	main
et	doc_213943985000_item	2285547	et	3	main
saan	doc_213943985000_item	2285549	et	4	main
ma	doc_213943985000_item	2285560	et	3	main
taha	doc_213943985000_item	2285562	et	4	main
lihtsalt	doc_213943985000_item	2285563	et	4	main
essee	doc_213943985002_item	2285704	et	4	main
aga	doc_213943985002_item	2285729	et	3	main
eluviis	doc_213943985002_item	2285731	et	3	main
mina	doc_213943985002_item	2285736	et	4	main
olen	doc_213943985002_item	2285737	et	3	main
inimene	doc_213943985002_item	2285741	et	3	main
saab	doc_213943985002_item	2285761	et	3	main
aga	doc_213943985002_item	2285770	et	3	main
pärast	doc_213943985002_item	2285773	et	4	main
saatejuhina	doc_213943985002_item	2285808	et	3	main
unistus	doc_213943985002_item	2285811	et	4	main
kasulik	doc_213943985002_item	2285816	et	3	main
ma	doc_213943985002_item	2285818	et	3	main
see	doc_213943985002_item	2285821	et	3	main
minu	doc_213943985002_item	2285824	et	3	main
töös	doc_213943985002_item	2285826	et	3	main
mulle	doc_213943985002_item	2285835	et	4	main
ajalehte	doc_213943985002_item	2285837	et	4	main
ainult	doc_213943985002_item	2285850	et	4	main
vaid	doc_213943985002_item	2285852	et	3	main
ka	doc_213943985002_item	2285863	et	3	main
kõik	doc_213943985002_item	2285878	et	4	main
ülikoolis	doc_213943985002_item	2285883	et	4	main
mina	doc_213943985002_item	2285887	et	4	main
võin	doc_213943985002_item	2285888	et	3	main
seda	doc_213943985002_item	2285889	et	3	main
otselt	doc_213943985002_item	2285890	et	3	main
oma	doc_213943985002_item	2285891	et	4	main
rakendada	doc_213943985002_item	2285894	et	3	main
tööd	doc_213943985002_item	2285904	et	4	main
ma	doc_213943985002_item	2285906	et	3	main
keele	doc_213943985002_item	2285926	et	4	main
suhtlemisvõimalusi	doc_213943985002_item	2285927	et	3	main
ida-viirumaal	doc_213943985002_item	2285928	et	4	main
ja	doc_213943985002_item	2285929	et	3	main
keelt	doc_213943985002_item	2285935	et	4	main
aastat	doc_213943985002_item	2285938	et	3	main
ja	doc_213943985002_item	2285947	et	3	main
end	doc_213943985002_item	2285949	et	4	main
mis	doc_213943985002_item	2285959	et	4	main
olen	doc_213943985002_item	2285964	et	3	main
et	doc_213943985002_item	2285966	et	3	main
tahab	doc_213943985002_item	2285968	et	3	main
taha	doc_213943985002_item	2285973	et	4	main
põhjusi	doc_213943985002_item	2285974	et	3	main
essee	doc_213943985003_item	2285975	et	4	main
miks	doc_213943985003_item	2285977	et	4	main
ja	doc_213943985003_item	2285988	et	3	main
artikleid	doc_213943985003_item	2286014	et	3	main
молодёжь	doc_213943985003_item	2286019	et	2	main
nagu	doc_213943985003_item	2286021	et	3	main
mina	doc_213943985003_item	2286029	et	4	main
asjad	doc_213943985003_item	2286037	et	3	main
intervjuud	doc_213943985003_item	2286039	et	4	main
ma	doc_213943985002_item	2285707	et	3	main
eriala	doc_213943985002_item	2285710	et	4	main
2	doc_213943985002_item	2285711	et	2	main
mida	doc_213943985002_item	2285712	et	4	main
ootan	doc_213943985002_item	2285713	et	3	main
õppimisest	doc_213943985002_item	2285714	et	4	main
sellel	doc_213943985002_item	2285715	et	4	main
erialal	doc_213943985002_item	2285716	et	3	main
ja	doc_213943985002_item	2285717	et	3	main
tallinna	doc_213943985002_item	2285718	et	4	main
ülikoolis	doc_213943985002_item	2285719	et	4	main
1	doc_213943985002_item	2285720	et	2	main
osa	doc_213943985002_item	2285722	et	4	main
otselt	doc_213943985002_item	2285733	et	3	main
seotud	doc_213943985002_item	2285734	et	4	main
suhtlemisega	doc_213943985002_item	2285735	et	4	main
ma	doc_213943985002_item	2285742	et	3	main
huvi	doc_213943985002_item	2285744	et	4	main
ja	doc_213943985002_item	2285747	et	3	main
arvan	doc_213943985002_item	2285748	et	3	main
et	doc_213943985002_item	2285749	et	3	main
olen	doc_213943985002_item	2285750	et	3	main
sobiv	doc_213943985002_item	2285751	et	4	main
erialale	doc_213943985002_item	2285754	et	3	main
elus	doc_213943985002_item	2285756	et	4	main
inimene	doc_213943985002_item	2285760	et	3	main
vastu	doc_213943985002_item	2285769	et	3	main
saab	doc_213943985002_item	2285774	et	3	main
aru	doc_213943985002_item	2285804	et	4	main
et	doc_213943985002_item	2285806	et	3	main
töötamine	doc_213943985002_item	2285807	et	4	main
ja	doc_213943985002_item	2285817	et	3	main
tulevikku	doc_213943985002_item	2285825	et	4	main
ja	doc_213943985002_item	2285827	et	3	main
eelkõige	doc_213943985002_item	2285828	et	3	main
kellele	doc_213943985002_item	2285846	et	4	main
meeldib	doc_213943985002_item	2285847	et	3	main
politikutega	doc_213943985002_item	2285854	et	4	main
olen	doc_213943985002_item	2285859	et	3	main
ja	doc_213943985002_item	2285864	et	3	main
ma	doc_213943985002_item	2285880	et	3	main
hea	doc_213943985002_item	2285903	et	4	main
seejärel	doc_213943985002_item	2285905	et	3	main
keelt	doc_213943985002_item	2285910	et	4	main
ole	doc_213943985002_item	2285924	et	4	main
õpin	doc_213943985002_item	2285933	et	3	main
sellepärast	doc_213943985002_item	2285939	et	3	main
kõik	doc_213943985002_item	2285942	et	4	main
aktiivne	doc_213943985002_item	2285946	et	3	main
kasulikuna	doc_213943985002_item	2285950	et	3	main
tõesti	doc_213943985002_item	2285953	et	3	main
võib	doc_213943985002_item	2285960	et	3	main
ma	doc_213943985002_item	2285963	et	3	main
mina	doc_213943985003_item	2286009	et	4	main
эстонии	doc_213943985003_item	2286020	et	2	main
meeldis	doc_213943985003_item	2286025	et	3	main
selle	doc_213943985002_item	2285709	et	4	main
suurem	doc_213943985002_item	2285721	et	4	main
inimest	doc_213943985002_item	2285723	et	3	main
ei	doc_213943985002_item	2285724	et	4	main
saa	doc_213943985002_item	2285725	et	4	main
ilma	doc_213943985002_item	2285727	et	4	main
positiivne	doc_213943985002_item	2285739	et	3	main
selle	doc_213943985002_item	2285753	et	4	main
hästi	doc_213943985002_item	2285762	et	3	main
ja	doc_213943985002_item	2285765	et	3	main
huvi	doc_213943985002_item	2285767	et	4	main
aasta	doc_213943985002_item	2285772	et	4	main
on	doc_213943985002_item	2285809	et	4	main
on	doc_213943985002_item	2285814	et	4	main
väga	doc_213943985002_item	2285815	et	3	main
et	doc_213943985002_item	2285820	et	3	main
aidata	doc_213943985002_item	2285823	et	4	main
mulle	doc_213943985002_item	2285839	et	4	main
meeldivad	doc_213943985002_item	2285840	et	4	main
inimesed	doc_213943985002_item	2285841	et	3	main
uudishimulik	doc_213943985002_item	2285861	et	3	main
pärast	doc_213943985002_item	2285865	et	4	main
selle	doc_213943985002_item	2285868	et	4	main
venekeelne	doc_213943985002_item	2285870	et	3	main
tallinna	doc_213943985002_item	2285882	et	4	main
töös	doc_213943985002_item	2285893	et	3	main
ootan	doc_213943985002_item	2285896	et	3	main
leida	doc_213943985002_item	2285902	et	3	main
eesti	doc_213943985002_item	2285909	et	4	main
ülikooliõpilastega	doc_213943985002_item	2285921	et	4	main
selle	doc_213943985002_item	2285931	et	4	main
mina	doc_213943985002_item	2285932	et	4	main
ainult	doc_213943985002_item	2285936	et	4	main
tahaksin	doc_213943985002_item	2285940	et	3	main
siin	doc_213943985002_item	2285943	et	4	main
tunda	doc_213943985002_item	2285948	et	3	main
mul	doc_213943985002_item	2285951	et	3	main
teab	doc_213943985002_item	2285958	et	3	main
kindel	doc_213943985002_item	2285965	et	3	main
võimalusi	doc_213943985002_item	2285970	et	3	main
1	doc_213943985003_item	2285976	et	2	main
palju	doc_213943985003_item	2286012	et	4	main
erinevaid	doc_213943985003_item	2286013	et	4	main
pakkuti	doc_213943985003_item	2286016	et	4	main
ajalehes	doc_213943985003_item	2286018	et	3	main
väliskorrespondend	doc_213943985003_item	2286022	et	4	main
see	doc_213943985003_item	2286023	et	3	main
suhelda	doc_213943985003_item	2286031	et	4	main
erinevad	doc_213943985003_item	2286035	et	4	main
võta	doc_213943985003_item	2286038	et	4	main
oli	doc_213943985003_item	2286040	et	3	main
kaks	doc_213943985003_item	2286047	et	3	main
toimetaja	doc_213943985003_item	2286054	et	4	main
oli	doc_213943985003_item	2286056	et	3	main
oli	doc_213943985003_item	2286062	et	3	main
kirjutada	doc_213943985003_item	2286072	et	3	main
artiklid	doc_213943985003_item	2286074	et	3	main
radio	doc_213943985003_item	2286079	et	4	main
teen	doc_213943985003_item	2286081	et	3	main
süžeetid	doc_213943985003_item	2286083	et	2	main
mul	doc_213943985003_item	2286091	et	3	main
juba	doc_213943985003_item	2286093	et	3	main
ja	doc_213943985003_item	2286096	et	3	main
otsustada	doc_213943985003_item	2286123	et	3	main
mina	doc_213943985003_item	2286131	et	4	main
see	doc_213943985003_item	2286141	et	3	main
suhtlemiseta	doc_213943985002_item	2285728	et	4	main
on	doc_213943985002_item	2285732	et	4	main
aktiivne	doc_213943985002_item	2285738	et	3	main
kandidaat	doc_213943985002_item	2285752	et	3	main
on	doc_213943985002_item	2285755	et	4	main
ikka	doc_213943985002_item	2285757	et	4	main
nii	doc_213943985002_item	2285758	et	3	main
et	doc_213943985002_item	2285759	et	3	main
tunneb	doc_213943985002_item	2285766	et	3	main
kõike	doc_213943985002_item	2285768	et	4	main
aru	doc_213943985002_item	2285775	et	4	main
et	doc_213943985002_item	2285776	et	3	main
ajakirjandus	doc_213943985002_item	2285777	et	3	main
ole	doc_213943985002_item	2285779	et	4	main
ei	doc_213943985002_item	2285778	et	4	main
tema	doc_213943985002_item	2285780	et	4	main
valdkond	doc_213943985002_item	2285781	et	3	main
vaid	doc_213943985002_item	2285782	et	3	main
mul	doc_213943985002_item	2285783	et	3	main
ei	doc_213943985002_item	2285784	et	4	main
või	doc_213943985002_item	2285785	et	4	main
olla	doc_213943985002_item	2285786	et	3	main
seda	doc_213943985002_item	2285787	et	3	main
probleemi	doc_213943985002_item	2285788	et	4	main
sellepärast	doc_213943985002_item	2285789	et	3	main
et	doc_213943985002_item	2285790	et	3	main
ma	doc_213943985002_item	2285791	et	3	main
töötasin	doc_213943985002_item	2285793	et	3	main
juba	doc_213943985002_item	2285792	et	3	main
eesti	doc_213943985002_item	2285794	et	4	main
raadiol	doc_213943985002_item	2285795	et	3	main
proectis	doc_213943985002_item	2285796	et	4	main
koos	doc_213943985002_item	2285797	et	4	main
erinevatel	doc_213943985002_item	2285798	et	4	main
lainetel	doc_213943985002_item	2285799	et	3	main
aasta	doc_213943985002_item	2285800	et	4	main
jooksul	doc_213943985002_item	2285801	et	4	main
ma	doc_213943985002_item	2285803	et	3	main
saanud	doc_213943985002_item	2285805	et	4	main
kogemus	doc_213943985002_item	2285813	et	3	main
arvan	doc_213943985002_item	2285819	et	3	main
võib	doc_213943985002_item	2285822	et	3	main
lõpetuseks	doc_213943985002_item	2285831	et	4	main
õelda	doc_213943985002_item	2285833	et	4	main
kes	doc_213943985002_item	2285842	et	4	main
kiirustavad	doc_213943985002_item	2285843	et	4	main
suhelda	doc_213943985002_item	2285848	et	4	main
sportsmenitega	doc_213943985002_item	2285855	et	4	main
muusikantitega	doc_213943985002_item	2285857	et	4	main
seda	doc_213943985002_item	2285866	et	3	main
valisin	doc_213943985002_item	2285867	et	3	main
meedia	doc_213943985002_item	2285871	et	4	main
2	doc_213943985002_item	2285872	et	2	main
teadmised	doc_213943985002_item	2285879	et	4	main
kasulikud	doc_213943985002_item	2285885	et	3	main
tulevikku	doc_213943985002_item	2285892	et	4	main
ma	doc_213943985002_item	2285895	et	3	main
et	doc_213943985002_item	2285897	et	3	main
siin	doc_213943985002_item	2285899	et	4	main
mind	doc_213943985002_item	2285901	et	4	main
teada	doc_213943985002_item	2285908	et	3	main
tallinna	doc_213943985002_item	2285911	et	4	main
tahan	doc_213943985002_item	2285832	et	3	main
õppimises	doc_213943985002_item	2285829	et	4	main
praegu	doc_213943985002_item	2285830	et	3	main
et	doc_213943985002_item	2285834	et	3	main
meeldib	doc_213943985002_item	2285836	et	3	main
paber	doc_213943985002_item	2285838	et	3	main
alati	doc_213943985002_item	2285844	et	4	main
kuhugi	doc_213943985002_item	2285845	et	4	main
mitte	doc_213943985002_item	2285849	et	3	main
sõbradega	doc_213943985002_item	2285851	et	4	main
ka	doc_213943985002_item	2285853	et	3	main
ja	doc_213943985002_item	2285856	et	3	main
ma	doc_213943985002_item	2285858	et	3	main
niisugune	doc_213943985002_item	2285860	et	3	main
inimene	doc_213943985002_item	2285862	et	3	main
eriala	doc_213943985002_item	2285869	et	4	main
kõige	doc_213943985002_item	2285873	et	4	main
pealt	doc_213943985002_item	2285874	et	4	main
ma	doc_213943985002_item	2285875	et	3	main
loodan	doc_213943985002_item	2285876	et	3	main
et	doc_213943985002_item	2285877	et	3	main
saan	doc_213943985002_item	2285881	et	4	main
on	doc_213943985002_item	2285884	et	4	main
ja	doc_213943985002_item	2285886	et	3	main
õppimine	doc_213943985002_item	2285898	et	4	main
aitab	doc_213943985002_item	2285900	et	3	main
loodan	doc_213943985002_item	2285907	et	3	main
ülikoolis	doc_213943985002_item	2285912	et	4	main
mitte	doc_213943985002_item	2285913	et	3	main
ainult	doc_213943985002_item	2285914	et	4	main
auditooriumis	doc_213943985002_item	2285915	et	3	main
õppetajate	doc_213943985002_item	2285916	et	4	main
tänu	doc_213943985002_item	2285917	et	4	main
vaid	doc_213943985002_item	2285918	et	3	main
ka	doc_213943985002_item	2285919	et	3	main
suheldes	doc_213943985002_item	2285920	et	3	main
ei	doc_213943985002_item	2285923	et	4	main
peale	doc_213943985002_item	2285930	et	4	main
teha	doc_213943985002_item	2285941	et	3	main
on	doc_213943985002_item	2285952	et	4	main
suur	doc_213943985002_item	2285954	et	3	main
plaanid	doc_213943985002_item	2285955	et	4	main
vaid	doc_213943985002_item	2285956	et	3	main
kes	doc_213943985002_item	2285957	et	4	main
aga	doc_213943985002_item	2285962	et	3	main
otsib	doc_213943985002_item	2285969	et	3	main
kes	doc_213943985002_item	2285971	et	4	main
ei	doc_213943985002_item	2285972	et	4	main
väga	doc_213943985003_item	2286027	et	3	main
sest	doc_213943985003_item	2286028	et	4	main
huvitavad	doc_213943985003_item	2286036	et	4	main
väga	doc_213943985003_item	2286042	et	3	main
see	doc_213943985003_item	2286060	et	3	main
jätkasin	doc_213943985003_item	2286071	et	3	main
erinevad	doc_213943985003_item	2286073	et	4	main
erinevad	doc_213943985003_item	2286082	et	4	main
ja	doc_213943985003_item	2286084	et	3	main
on	doc_213943985003_item	2286092	et	4	main
väike	doc_213943985003_item	2286094	et	4	main
loodan	doc_213943985003_item	2286098	et	3	main
mul	doc_213943985002_item	2285922	et	3	main
eesti	doc_213943985002_item	2285925	et	4	main
eesti	doc_213943985002_item	2285934	et	4	main
3	doc_213943985002_item	2285937	et	2	main
tahaksin	doc_213943985002_item	2285944	et	3	main
olla	doc_213943985002_item	2285945	et	3	main
juhtuda	doc_213943985002_item	2285961	et	3	main
kes	doc_213943985002_item	2285967	et	4	main
ma	doc_213943985003_item	2285978	et	3	main
valisin	doc_213943985003_item	2285979	et	3	main
selle	doc_213943985003_item	2285980	et	4	main
eriala	doc_213943985003_item	2285981	et	4	main
2	doc_213943985003_item	2285982	et	2	main
mida	doc_213943985003_item	2285983	et	4	main
ootan	doc_213943985003_item	2285984	et	3	main
õppimisest	doc_213943985003_item	2285985	et	4	main
sellel	doc_213943985003_item	2285986	et	4	main
erialal	doc_213943985003_item	2285987	et	3	main
tallinna	doc_213943985003_item	2285989	et	4	main
ülikoolist	doc_213943985003_item	2285990	et	4	main
1	doc_213943985003_item	2285991	et	2	main
ma	doc_213943985003_item	2285992	et	3	main
otsustasin	doc_213943985003_item	2285993	et	3	main
et	doc_213943985003_item	2285994	et	3	main
ma	doc_213943985003_item	2285995	et	3	main
lähen	doc_213943985003_item	2285996	et	3	main
õppima	doc_213943985003_item	2285997	et	3	main
ajakirjandus	doc_213943985003_item	2285998	et	3	main
juba	doc_213943985003_item	2285999	et	3	main
mitu	doc_213943985003_item	2286000	et	4	main
aastat	doc_213943985003_item	2286001	et	3	main
tagasi	doc_213943985003_item	2286002	et	3	main
see	doc_213943985003_item	2286003	et	3	main
oli	doc_213943985003_item	2286004	et	3	main
seitsmendas	doc_213943985003_item	2286005	et	3	main
1999	doc_213943985003_item	2286007	et	2	main
klassis	doc_213943985003_item	2286006	et	3	main
aastal	doc_213943985003_item	2286008	et	3	main
hakkan	doc_213943985003_item	2286010	et	3	main
kirjutama	doc_213943985003_item	2286011	et	3	main
mulle	doc_213943985003_item	2286015	et	4	main
töötada	doc_213943985003_item	2286017	et	3	main
idee	doc_213943985003_item	2286024	et	4	main
armastan	doc_213943985003_item	2286030	et	3	main
inimestega	doc_213943985003_item	2286032	et	3	main
kirjutada	doc_213943985003_item	2286034	et	3	main
ka	doc_213943985003_item	2286041	et	3	main
siis	doc_213943985003_item	2286044	et	3	main
töötasin	doc_213943985003_item	2286046	et	3	main
reporter	doc_213943985003_item	2286052	et	3	main
ja	doc_213943985003_item	2286053	et	3	main
see	doc_213943985003_item	2286055	et	3	main
noorte	doc_213943985003_item	2286057	et	3	main
xxx	doc_213943985003_item	2286059	et	4	main
ma	doc_213943985003_item	2286070	et	3	main
ajalehesse	doc_213943985003_item	2286075	et	3	main
töötan	doc_213943985003_item	2286078	et	3	main
neljas	doc_213943985003_item	2286080	et	4	main
arvan	doc_213943985003_item	2286089	et	3	main
kogemus	doc_213943985003_item	2286095	et	3	main
ma	doc_213943985003_item	2286097	et	3	main
minu	doc_213943985003_item	2286101	et	3	main
aitavad	doc_213943985003_item	2286103	et	4	main
teadmised	doc_213943985003_item	2286102	et	4	main
mulle	doc_213943985003_item	2286104	et	4	main
hästi	doc_213943985003_item	2286105	et	3	main
orinteeruda	doc_213943985003_item	2286106	et	4	main
teoorias	doc_213943985003_item	2286107	et	3	main
sest	doc_213943985003_item	2286108	et	4	main
väike	doc_213943985003_item	2286109	et	4	main
praktika	doc_213943985003_item	2286110	et	4	main
mul	doc_213943985003_item	2286111	et	3	main
on	doc_213943985003_item	2286112	et	4	main
juba	doc_213943985003_item	2286113	et	3	main
veel	doc_213943985003_item	2286114	et	4	main
ma	doc_213943985003_item	2286115	et	3	main
käisin	doc_213943985003_item	2286116	et	3	main
videostuudios	doc_213943985003_item	2286117	et	3	main
ja	doc_213943985003_item	2286118	et	3	main
see	doc_213943985003_item	2286119	et	3	main
ka	doc_213943985003_item	2286120	et	3	main
et	doc_213943985003_item	2286124	et	3	main
saada	doc_213943985003_item	2286128	et	4	main
ajakirjanikuks	doc_213943985003_item	2286129	et	3	main
ja	doc_213943985003_item	2286146	et	3	main
et	doc_213943985003_item	2286149	et	3	main
millised	doc_213943985003_item	2286157	et	3	main
tahan	doc_213943985003_item	2286162	et	3	main
keelt	doc_213943985003_item	2286166	et	4	main
kui	doc_213943985003_item	2286173	et	3	main
ülikooli	doc_213943985003_item	2286176	et	4	main
ma	doc_213943985003_item	2286177	et	3	main
töötama	doc_213943985003_item	2286179	et	3	main
proovida	doc_213943985003_item	2286184	et	3	main
artikleid	doc_213943985003_item	2286187	et	3	main
et	doc_213943985003_item	2286191	et	3	main
valik	doc_213943985003_item	2286193	et	3	main
essee	doc_213943985004_item	2286206	et	4	main
ma	doc_213943985004_item	2286232	et	3	main
mille	doc_213943985004_item	2286240	et	3	main
eest	doc_213943985004_item	2286241	et	4	main
unistus	doc_213943985004_item	2286248	et	4	main
maailmas	doc_213943985004_item	2286252	et	3	main
ja	doc_213943985004_item	2286254	et	3	main
mulle	doc_213943985003_item	2286026	et	4	main
ja	doc_213943985003_item	2286033	et	3	main
eesti	doc_213943985003_item	2286049	et	4	main
nagu	doc_213943985003_item	2286051	et	3	main
saade	doc_213943985003_item	2286058	et	4	main
saade	doc_213943985003_item	2286061	et	4	main
keeles	doc_213943985003_item	2286064	et	4	main
ja	doc_213943985003_item	2286076	et	3	main
muidugi	doc_213943985003_item	2286085	et	4	main
intervjuut	doc_213943985003_item	2286087	et	4	main
et	doc_213943985003_item	2286090	et	3	main
et	doc_213943985003_item	2286099	et	3	main
ma	doc_213943985003_item	2286125	et	3	main
tahan	doc_213943985003_item	2286127	et	3	main
2	doc_213943985003_item	2286130	et	2	main
tahan	doc_213943985003_item	2286132	et	3	main
või	doc_213943985003_item	2286139	et	4	main
välismaal	doc_213943985003_item	2286140	et	4	main
ma	doc_213943985003_item	2286147	et	3	main
õppida	doc_213943985003_item	2286154	et	3	main
ained	doc_213943985003_item	2286156	et	3	main
aitavad	doc_213943985003_item	2286158	et	4	main
veel	doc_213943985003_item	2286161	et	4	main
hakkan	doc_213943985003_item	2286178	et	3	main
kirjutada	doc_213943985003_item	2286185	et	3	main
õige	doc_213943985003_item	2286195	et	4	main
ülikool	doc_213943985003_item	2286198	et	4	main
õppimisest	doc_213943985004_item	2286216	et	4	main
sündinud	doc_213943985004_item	2286224	et	4	main
oma	doc_213943985004_item	2286230	et	4	main
et	doc_213943985004_item	2286234	et	3	main
on	doc_213943985004_item	2286236	et	4	main
ma	doc_213943985004_item	2286242	et	3	main
saan	doc_213943985004_item	2286243	et	4	main
lapsepõlvest	doc_213943985004_item	2286245	et	4	main
oli	doc_213943985004_item	2286247	et	3	main
kergem	doc_213943985004_item	2286255	et	4	main
ajakirjandus	doc_213943985004_item	2286259	et	3	main
juba	doc_213943985004_item	2286284	et	3	main
ma	doc_213943985004_item	2286286	et	3	main
väga	doc_213943985004_item	2286297	et	3	main
asjad	doc_213943985004_item	2286299	et	3	main
aga	doc_213943985004_item	2286300	et	3	main
väga	doc_213943985004_item	2286305	et	3	main
meie	doc_213943985004_item	2286308	et	4	main
kõik	doc_213943985004_item	2286314	et	4	main
on	doc_213943985004_item	2286318	et	4	main
kõik	doc_213943985004_item	2286322	et	4	main
saavad	doc_213943985004_item	2286324	et	4	main
linnas	doc_213943985004_item	2286327	et	4	main
on	doc_213943985004_item	2286328	et	4	main
mida	doc_213943985004_item	2286329	et	4	main
muutunud	doc_213943985004_item	2286330	et	4	main
veel	doc_213943985004_item	2286333	et	4	main
klassil	doc_213943985004_item	2286338	et	3	main
et	doc_213943985004_item	2286340	et	3	main
arstina	doc_213943985004_item	2286344	et	3	main
aru	doc_213943985004_item	2286348	et	4	main
mulle	doc_213943985004_item	2286350	et	4	main
kirjutada	doc_213943985004_item	2286353	et	3	main
palju	doc_213943985004_item	2286373	et	4	main
mulle	doc_213943985004_item	2286377	et	4	main
meeldib	doc_213943985004_item	2286378	et	3	main
selline	doc_213943985004_item	2286379	et	4	main
ja	doc_213943985004_item	2286386	et	3	main
asju	doc_213943985004_item	2286392	et	3	main
sõbrad	doc_213943985004_item	2286395	et	3	main
tore	doc_213943985003_item	2286043	et	3	main
ma	doc_213943985003_item	2286045	et	3	main
aastad	doc_213943985003_item	2286048	et	3	main
televiisionil	doc_213943985003_item	2286050	et	4	main
kahes	doc_213943985003_item	2286063	et	4	main
eesti	doc_213943985003_item	2286065	et	4	main
ja	doc_213943985003_item	2286066	et	3	main
vene	doc_213943985003_item	2286067	et	4	main
aga	doc_213943985003_item	2286068	et	3	main
praegu	doc_213943985003_item	2286069	et	3	main
veel	doc_213943985003_item	2286077	et	4	main
võtan	doc_213943985003_item	2286086	et	3	main
ma	doc_213943985003_item	2286088	et	3	main
tulevikus	doc_213943985003_item	2286100	et	4	main
aitab	doc_213943985003_item	2286121	et	3	main
tõesti	doc_213943985003_item	2286126	et	3	main
tallinna	doc_213943985003_item	2286150	et	4	main
mind	doc_213943985003_item	2286159	et	4	main
tulevikus	doc_213943985003_item	2286160	et	4	main
ma	doc_213943985003_item	2286174	et	3	main
ma	doc_213943985003_item	2286182	et	3	main
ka	doc_213943985003_item	2286186	et	3	main
keeles	doc_213943985003_item	2286189	et	4	main
minu	doc_213943985003_item	2286192	et	3	main
tallinna	doc_213943985003_item	2286197	et	4	main
ja	doc_213943985003_item	2286203	et	3	main
valisin	doc_213943985004_item	2286210	et	3	main
2	doc_213943985004_item	2286213	et	2	main
ootan	doc_213943985004_item	2286215	et	3	main
olen	doc_213943985004_item	2286223	et	3	main
tallinnas	doc_213943985004_item	2286225	et	4	main
ja	doc_213943985004_item	2286226	et	3	main
elan	doc_213943985004_item	2286227	et	3	main
siin	doc_213943985004_item	2286228	et	4	main
elu	doc_213943985004_item	2286250	et	4	main
ma	doc_213943985004_item	2286256	et	3	main
on	doc_213943985004_item	2286283	et	4	main
on	doc_213943985004_item	2286290	et	4	main
ajakirjanikud	doc_213943985004_item	2286292	et	3	main
professionaalselt	doc_213943985004_item	2286294	et	4	main
ja	doc_213943985004_item	2286295	et	3	main
need	doc_213943985004_item	2286303	et	3	main
kergem	doc_213943985004_item	2286307	et	4	main
kui	doc_213943985004_item	2286313	et	3	main
ja	doc_213943985004_item	2286316	et	3	main
siis	doc_213943985004_item	2286321	et	3	main
inimesed	doc_213943985004_item	2286323	et	3	main
midagi	doc_213943985004_item	2286332	et	4	main
kümnendal	doc_213943985004_item	2286337	et	3	main
arvasin	doc_213943985004_item	2286339	et	3	main
aga	doc_213943985004_item	2286345	et	3	main
on	doc_213943985004_item	2286355	et	4	main
meil	doc_213943985004_item	2286356	et	4	main
ajaleht	doc_213943985004_item	2286358	et	3	main
sellel	doc_213943985004_item	2286359	et	4	main
ajalehel	doc_213943985004_item	2286360	et	3	main
oli	doc_213943985004_item	2286361	et	3	main
ja	doc_213943985004_item	2286368	et	3	main
asjad	doc_213943985004_item	2286370	et	3	main
artikleid	doc_213943985004_item	2286374	et	3	main
rohkem	doc_213943985004_item	2286382	et	4	main
esiteks	doc_213943985004_item	2286393	et	3	main
ma	doc_213943985004_item	2286424	et	3	main
ülikooli	doc_213943985004_item	2286427	et	4	main
on	doc_213943985004_item	2286429	et	4	main
huuvitavaid	doc_213943985004_item	2286431	et	4	main
essee	doc_213943985005_item	2286432	et	4	main
1	doc_213943985005_item	2286433	et	2	main
miks	doc_213943985005_item	2286434	et	4	main
ma	doc_213943985005_item	2286435	et	3	main
2	doc_213943985005_item	2286439	et	2	main
õppimisest	doc_213943985005_item	2286442	et	4	main
t	doc_213943985005_item	2286446	et	4	main
ülikoolis	doc_213943985005_item	2286447	et	4	main
laps	doc_213943985005_item	2286452	et	4	main
mõtlesin	doc_213943985005_item	2286458	et	3	main
saama	doc_213943985005_item	2286469	et	4	main
meeldis	doc_213943985005_item	2286478	et	3	main
ja	doc_213943985005_item	2286480	et	3	main
õppetajana	doc_213943985005_item	2286488	et	4	main
teadsin	doc_213943985005_item	2286489	et	3	main
et	doc_213943985005_item	2286490	et	3	main
mulle	doc_213943985003_item	2286122	et	4	main
saada	doc_213943985003_item	2286133	et	4	main
heaks	doc_213943985003_item	2286134	et	4	main
ajakirjanikuks	doc_213943985003_item	2286135	et	3	main
ja	doc_213943985003_item	2286136	et	3	main
töötada	doc_213943985003_item	2286137	et	3	main
eestis	doc_213943985003_item	2286138	et	3	main
väga	doc_213943985003_item	2286145	et	3	main
ülikoolis	doc_213943985003_item	2286151	et	4	main
saan	doc_213943985003_item	2286153	et	4	main
kõik	doc_213943985003_item	2286155	et	4	main
hästi	doc_213943985003_item	2286163	et	3	main
eesti	doc_213943985003_item	2286165	et	4	main
sest	doc_213943985003_item	2286167	et	4	main
mulle	doc_213943985003_item	2286168	et	4	main
tundub	doc_213943985003_item	2286169	et	3	main
et	doc_213943985003_item	2286170	et	3	main
esimesed	doc_213943985003_item	2286171	et	3	main
aastad	doc_213943985003_item	2286172	et	3	main
lõpetan	doc_213943985003_item	2286175	et	3	main
aga	doc_213943985003_item	2286181	et	3	main
tahan	doc_213943985003_item	2286183	et	3	main
eesti	doc_213943985003_item	2286188	et	4	main
loodan	doc_213943985003_item	2286190	et	3	main
oli	doc_213943985003_item	2286194	et	3	main
ja	doc_213943985003_item	2286196	et	3	main
realiseerida	doc_213943985003_item	2286200	et	3	main
minu	doc_213943985003_item	2286201	et	3	main
unistus	doc_213943985003_item	2286205	et	4	main
miks	doc_213943985004_item	2286208	et	4	main
selle	doc_213943985004_item	2286211	et	4	main
eriala	doc_213943985004_item	2286212	et	4	main
mida	doc_213943985004_item	2286214	et	4	main
sellel	doc_213943985004_item	2286217	et	4	main
eriallal	doc_213943985004_item	2286218	et	4	main
ja	doc_213943985004_item	2286219	et	3	main
tallinna	doc_213943985004_item	2286220	et	4	main
eriala	doc_213943985003_item	2286142	et	4	main
huvitab	doc_213943985003_item	2286143	et	3	main
mind	doc_213943985003_item	2286144	et	4	main
loodan	doc_213943985003_item	2286148	et	3	main
ma	doc_213943985003_item	2286152	et	3	main
õppida	doc_213943985003_item	2286164	et	3	main
eestis	doc_213943985003_item	2286180	et	3	main
aitab	doc_213943985003_item	2286199	et	3	main
plaanid	doc_213943985003_item	2286202	et	4	main
minu	doc_213943985003_item	2286204	et	3	main
1	doc_213943985004_item	2286207	et	2	main
ma	doc_213943985004_item	2286209	et	3	main
ülikoolis	doc_213943985004_item	2286221	et	4	main
kõik	doc_213943985004_item	2286229	et	4	main
tean	doc_213943985004_item	2286233	et	3	main
siin	doc_213943985004_item	2286235	et	4	main
palju	doc_213943985004_item	2286237	et	4	main
huvitavaid	doc_213943985004_item	2286238	et	4	main
asju	doc_213943985004_item	2286239	et	3	main
kirjutada	doc_213943985004_item	2286244	et	3	main
mull	doc_213943985004_item	2286246	et	3	main
huvitavam	doc_213943985004_item	2286253	et	4	main
miks	doc_213943985004_item	2286273	et	4	main
kirjutab	doc_213943985004_item	2286280	et	3	main
huvitav	doc_213943985004_item	2286285	et	4	main
arvan	doc_213943985004_item	2286287	et	3	main
kirjutavad	doc_213943985004_item	2286296	et	4	main
huvitavad	doc_213943985004_item	2286298	et	4	main
minu	doc_213943985004_item	2286301	et	3	main
vähe	doc_213943985004_item	2286306	et	3	main
ajakurjandus	doc_213943985004_item	2286310	et	4	main
uudised	doc_213943985004_item	2286315	et	3	main
sündmused	doc_213943985004_item	2286317	et	3	main
omal	doc_213943985004_item	2286319	et	3	main
ma	doc_213943985004_item	2286335	et	3	main
olin	doc_213943985004_item	2286336	et	3	main
ma	doc_213943985004_item	2286341	et	3	main
olla	doc_213943985004_item	2286343	et	3	main
artiklid	doc_213943985004_item	2286367	et	3	main
muud	doc_213943985004_item	2286369	et	4	main
intervjuud	doc_213943985004_item	2286376	et	4	main
kõige	doc_213943985004_item	2286381	et	4	main
õppimisest	doc_213943985004_item	2286383	et	4	main
ülikoolis	doc_213943985004_item	2286388	et	4	main
ootan	doc_213943985004_item	2286390	et	3	main
uued	doc_213943985004_item	2286394	et	3	main
ka	doc_213943985004_item	2286422	et	3	main
et	doc_213943985004_item	2286426	et	3	main
valisin	doc_213943985005_item	2286436	et	3	main
sellel	doc_213943985005_item	2286443	et	4	main
ja	doc_213943985005_item	2286445	et	3	main
tahtsin	doc_213943985005_item	2286454	et	3	main
ajakirjanikkuna	doc_213943985005_item	2286456	et	4	main
saada	doc_213943985005_item	2286462	et	4	main
ainult	doc_213943985005_item	2286463	et	4	main
mõtlesin	doc_213943985005_item	2286468	et	3	main
moodi	doc_213943985005_item	2286470	et	4	main
mulle	doc_213943985005_item	2286471	et	4	main
väga	doc_213943985005_item	2286472	et	3	main
meeldis	doc_213943985005_item	2286473	et	3	main
lugeda	doc_213943985005_item	2286475	et	3	main
uudised	doc_213943985005_item	2286479	et	3	main
lõpetasin	doc_213943985005_item	2286484	et	3	main
tallinna	doc_213943985005_item	2286494	et	4	main
ülikoolis	doc_213943985005_item	2286495	et	4	main
erialad	doc_213943985005_item	2286502	et	3	main
vaadata	doc_213943985005_item	2286511	et	4	main
et	doc_213943985005_item	2286514	et	3	main
mõtlesin	doc_213943985005_item	2286527	et	3	main
väga	doc_213943985005_item	2286537	et	3	main
ja	doc_213943985005_item	2286539	et	3	main
nõutav	doc_213943985005_item	2286542	et	4	main
punktide	doc_213943985005_item	2286543	et	3	main
et	doc_213943985005_item	2286548	et	3	main
see	doc_213943985005_item	2286558	et	3	main
huvitav	doc_213943985005_item	2286563	et	4	main
ma	doc_213943985005_item	2286566	et	3	main
tallinna	doc_213943985005_item	2286570	et	4	main
valisin	doc_213943985006_item	2286576	et	3	main
selle	doc_213943985006_item	2286577	et	4	main
ootan	doc_213943985006_item	2286581	et	3	main
tü	doc_213943985006_item	2286585	et	4	main
ma	doc_213943985004_item	2286222	et	3	main
elu	doc_213943985004_item	2286231	et	4	main
teha	doc_213943985004_item	2286249	et	3	main
minu	doc_213943985004_item	2286251	et	3	main
arvan	doc_213943985004_item	2286257	et	3	main
et	doc_213943985004_item	2286258	et	3	main
on	doc_213943985004_item	2286260	et	4	main
selline	doc_213943985004_item	2286261	et	4	main
asi	doc_213943985004_item	2286262	et	4	main
mis	doc_213943985004_item	2286263	et	4	main
saab	doc_213943985004_item	2286264	et	3	main
teha	doc_213943985004_item	2286265	et	3	main
meie	doc_213943985004_item	2286266	et	4	main
elu	doc_213943985004_item	2286267	et	4	main
huvitavam	doc_213943985004_item	2286268	et	4	main
ja	doc_213943985004_item	2286269	et	3	main
kergem	doc_213943985004_item	2286270	et	4	main
ma	doc_213943985004_item	2286271	et	3	main
selletan	doc_213943985004_item	2286272	et	4	main
ma	doc_213943985004_item	2286274	et	3	main
arvan	doc_213943985004_item	2286275	et	3	main
niimoodi	doc_213943985004_item	2286276	et	3	main
kui	doc_213943985004_item	2286277	et	3	main
ajakirjanik	doc_213943985004_item	2286279	et	3	main
midagi	doc_213943985004_item	2286281	et	4	main
see	doc_213943985004_item	2286282	et	3	main
et	doc_213943985004_item	2286288	et	3	main
kõik	doc_213943985004_item	2286291	et	4	main
on	doc_213943985004_item	2286304	et	4	main
teha	doc_213943985004_item	2286312	et	3	main
ajal	doc_213943985004_item	2286320	et	4	main
või	doc_213943985004_item	2286331	et	4	main
hiljem	doc_213943985004_item	2286346	et	3	main
sain	doc_213943985004_item	2286347	et	3	main
koolis	doc_213943985004_item	2286354	et	4	main
intervjuud	doc_213943985004_item	2286366	et	4	main
ma	doc_213943985004_item	2286371	et	3	main
ja	doc_213943985004_item	2286375	et	3	main
eriala	doc_213943985004_item	2286380	et	4	main
erialal	doc_213943985004_item	2286385	et	3	main
palju	doc_213943985004_item	2286391	et	4	main
psühholoogia	doc_213943985004_item	2286423	et	4	main
mida	doc_213943985005_item	2286440	et	4	main
ootan	doc_213943985005_item	2286441	et	3	main
erialal	doc_213943985005_item	2286444	et	3	main
väike	doc_213943985005_item	2286451	et	4	main
saada	doc_213943985005_item	2286455	et	4	main
aga	doc_213943985005_item	2286457	et	3	main
moskvas	doc_213943985005_item	2286464	et	4	main
millal	doc_213943985005_item	2286465	et	3	main
õpin	doc_213943985005_item	2286466	et	3	main
ajalehti	doc_213943985005_item	2286474	et	4	main
tahtsin	doc_213943985005_item	2286486	et	3	main
natuke	doc_213943985005_item	2286496	et	4	main
hiljem	doc_213943985005_item	2286497	et	3	main
teada	doc_213943985005_item	2286500	et	3	main
on	doc_213943985005_item	2286503	et	4	main
tallinna	doc_213943985005_item	2286504	et	4	main
ülikoolis	doc_213943985005_item	2286505	et	4	main
ma	doc_213943985005_item	2286512	et	3	main
on	doc_213943985005_item	2286516	et	4	main
momendis	doc_213943985005_item	2286521	et	3	main
lähen	doc_213943985005_item	2286530	et	3	main
2	doc_213943985005_item	2286545	et	2	main
ootan	doc_213943985005_item	2286547	et	3	main
tallinna	doc_213943985005_item	2286549	et	4	main
et	doc_213943985005_item	2286557	et	3	main
protsess	doc_213943985005_item	2286564	et	3	main
aga	doc_213943985005_item	2286565	et	3	main
saada	doc_213943985005_item	2286568	et	4	main
mida	doc_213943985006_item	2286580	et	4	main
erialal	doc_213943985006_item	2286584	et	3	main
arvan	doc_213943985006_item	2286588	et	3	main
on	doc_213943985006_item	2286591	et	4	main
meie	doc_213943985006_item	2286597	et	4	main
hea	doc_213943985004_item	2286278	et	4	main
eestis	doc_213943985004_item	2286289	et	3	main
on	doc_213943985004_item	2286293	et	4	main
arvates	doc_213943985004_item	2286302	et	4	main
elu	doc_213943985004_item	2286309	et	4	main
saab	doc_213943985004_item	2286311	et	3	main
teada	doc_213943985004_item	2286325	et	3	main
et	doc_213943985004_item	2286326	et	3	main
kui	doc_213943985004_item	2286334	et	3	main
tahan	doc_213943985004_item	2286342	et	3	main
et	doc_213943985004_item	2286349	et	3	main
meeldid	doc_213943985004_item	2286351	et	3	main
väga	doc_213943985004_item	2286352	et	3	main
oma	doc_213943985004_item	2286357	et	4	main
kümme	doc_213943985004_item	2286362	et	3	main
lehte	doc_213943985004_item	2286363	et	4	main
seal	doc_213943985004_item	2286364	et	4	main
oli	doc_213943985004_item	2286365	et	3	main
kirjutasin	doc_213943985004_item	2286372	et	3	main
selles	doc_213943985004_item	2286384	et	4	main
tallinna	doc_213943985004_item	2286387	et	4	main
ma	doc_213943985004_item	2286389	et	3	main
ja	doc_213943985004_item	2286396	et	3	main
suhted	doc_213943985004_item	2286397	et	3	main
mis	doc_213943985004_item	2286398	et	4	main
saavad	doc_213943985004_item	2286399	et	4	main
hiljem	doc_213943985004_item	2286400	et	3	main
aitada	doc_213943985004_item	2286401	et	4	main
teiseks	doc_213943985004_item	2286402	et	4	main
ma	doc_213943985004_item	2286403	et	3	main
tahan	doc_213943985004_item	2286404	et	3	main
teada	doc_213943985004_item	2286405	et	3	main
kõik	doc_213943985004_item	2286406	et	4	main
oma	doc_213943985004_item	2286407	et	4	main
erialal	doc_213943985004_item	2286408	et	3	main
ajakirjanduses	doc_213943985004_item	2286409	et	3	main
on	doc_213943985004_item	2286410	et	4	main
vaja	doc_213943985004_item	2286411	et	4	main
mitte	doc_213943985004_item	2286412	et	3	main
ainult	doc_213943985004_item	2286413	et	4	main
kirjutada	doc_213943985004_item	2286414	et	3	main
vaja	doc_213943985004_item	2286416	et	4	main
on	doc_213943985004_item	2286415	et	4	main
ka	doc_213943985004_item	2286417	et	3	main
teada	doc_213943985004_item	2286418	et	3	main
ajalugu	doc_213943985004_item	2286419	et	4	main
võib	doc_213943985004_item	2286420	et	3	main
olla	doc_213943985004_item	2286421	et	3	main
aastat	doc_213943985004_item	2286428	et	3	main
kõige	doc_213943985004_item	2286430	et	4	main
eriala	doc_213943985005_item	2286438	et	4	main
millal	doc_213943985005_item	2286448	et	3	main
mina	doc_213943985005_item	2286449	et	4	main
ma	doc_213943985005_item	2286453	et	3	main
võib	doc_213943985005_item	2286461	et	3	main
vaadata	doc_213943985005_item	2286477	et	4	main
sport	doc_213943985005_item	2286481	et	3	main
ma	doc_213943985005_item	2286483	et	3	main
kooli	doc_213943985005_item	2286485	et	4	main
ajalugu	doc_213943985005_item	2286487	et	4	main
õppetajana	doc_213943985005_item	2286491	et	4	main
võib	doc_213943985005_item	2286492	et	3	main
mina	doc_213943985005_item	2286498	et	4	main
mis	doc_213943985005_item	2286501	et	4	main
arvan	doc_213943985004_item	2286425	et	3	main
selle	doc_213943985005_item	2286437	et	4	main
olin	doc_213943985005_item	2286450	et	3	main
et	doc_213943985005_item	2286459	et	3	main
ajakirjanikkuna	doc_213943985005_item	2286460	et	4	main
koolis	doc_213943985005_item	2286467	et	4	main
telerit	doc_213943985005_item	2286476	et	3	main
millal	doc_213943985005_item	2286482	et	3	main
tulin	doc_213943985005_item	2286509	et	3	main
ajakirjanduse	doc_213943985005_item	2286518	et	3	main
õpima	doc_213943985005_item	2286519	et	4	main
selles	doc_213943985005_item	2286520	et	4	main
olin	doc_213943985005_item	2286523	et	3	main
muidugi	doc_213943985005_item	2286529	et	4	main
ajakirjanduse	doc_213943985005_item	2286531	et	3	main
eksamid	doc_213943985005_item	2286535	et	3	main
mul	doc_213943985005_item	2286540	et	3	main
arv	doc_213943985005_item	2286544	et	3	main
erialas	doc_213943985005_item	2286555	et	3	main
on	doc_213943985005_item	2286559	et	4	main
raske	doc_213943985005_item	2286561	et	4	main
miks	doc_213943985006_item	2286574	et	4	main
2	doc_213943985006_item	2286579	et	2	main
väga	doc_213943985006_item	2286592	et	3	main
teada	doc_213943985006_item	2286594	et	3	main
mis	doc_213943985006_item	2286595	et	4	main
toimub	doc_213943985006_item	2286596	et	3	main
uuega	doc_213943985006_item	2286631	et	3	main
unistused	doc_213943985006_item	2286645	et	4	main
inimesele	doc_213943985006_item	2286650	et	3	main
ma	doc_213943985006_item	2286662	et	3	main
otsustus	doc_213943985006_item	2286665	et	4	main
tallinna	doc_213943985006_item	2286666	et	4	main
tudengitele	doc_213943985006_item	2286671	et	3	main
suur	doc_213943985006_item	2286673	et	3	main
hariduse	doc_213943985006_item	2286678	et	3	main
valisin	doc_213943985006_item	2286681	et	3	main
ootan	doc_213943985006_item	2286687	et	3	main
valisin	doc_213943985007_item	2286695	et	3	main
2	doc_213943985007_item	2286698	et	2	main
vastused	doc_213943985007_item	2286706	et	3	main
ajakirjandus	doc_213943985007_item	2286708	et	3	main
tähtis	doc_213943985007_item	2286711	et	4	main
on	doc_213943985007_item	2286716	et	4	main
saada	doc_213943985005_item	2286493	et	4	main
tahtsin	doc_213943985005_item	2286499	et	3	main
veel	doc_213943985005_item	2286506	et	4	main
nägin	doc_213943985005_item	2286513	et	3	main
väga	doc_213943985005_item	2286524	et	3	main
õnnelik	doc_213943985005_item	2286525	et	3	main
õnneks	doc_213943985005_item	2286533	et	4	main
läksid	doc_213943985005_item	2286536	et	4	main
hea	doc_213943985005_item	2286538	et	4	main
oli	doc_213943985005_item	2286541	et	3	main
selles	doc_213943985005_item	2286554	et	4	main
arvan	doc_213943985005_item	2286556	et	3	main
ja	doc_213943985005_item	2286562	et	3	main
eriala	doc_213943985006_item	2286578	et	4	main
õppimisest	doc_213943985006_item	2286582	et	4	main
on	doc_213943985006_item	2286622	et	4	main
sul	doc_213943985006_item	2286638	et	3	main
ja	doc_213943985006_item	2286644	et	3	main
sa	doc_213943985006_item	2286647	et	3	main
aidata	doc_213943985006_item	2286649	et	4	main
siis	doc_213943985006_item	2286651	et	3	main
pakub	doc_213943985006_item	2286668	et	3	main
oma	doc_213943985006_item	2286669	et	4	main
ja	doc_213943985006_item	2286675	et	3	main
kujundamiseks	doc_213943985006_item	2286679	et	4	main
ma	doc_213943985006_item	2286686	et	3	main
teadmised	doc_213943985006_item	2286689	et	4	main
ma	doc_213943985007_item	2286694	et	3	main
eriala	doc_213943985007_item	2286697	et	4	main
mida	doc_213943985007_item	2286699	et	4	main
ootan	doc_213943985007_item	2286700	et	3	main
õppimisest	doc_213943985007_item	2286701	et	4	main
asi	doc_213943985007_item	2286712	et	4	main
suur	doc_213943985007_item	2286718	et	3	main
selleta	doc_213943985007_item	2286721	et	3	main
või	doc_213943985007_item	2286728	et	4	main
maailmas	doc_213943985007_item	2286738	et	3	main
inimestel	doc_213943985007_item	2286742	et	3	main
ole	doc_213943985007_item	2286744	et	4	main
nii	doc_213943985007_item	2286746	et	3	main
või	doc_213943985007_item	2286751	et	4	main
nende	doc_213943985007_item	2286753	et	4	main
inimene	doc_213943985007_item	2286770	et	3	main
ajalehti	doc_213943985007_item	2286776	et	4	main
kuulama	doc_213943985007_item	2286777	et	3	main
ja	doc_213943985007_item	2286788	et	3	main
kui	doc_213943985007_item	2286790	et	3	main
bensiin	doc_213943985007_item	2286793	et	3	main
vastusi	doc_213943985007_item	2286806	et	4	main
lugeda	doc_213943985007_item	2286810	et	3	main
pärast	doc_213943985007_item	2286825	et	4	main
osaleda	doc_213943985007_item	2286826	et	3	main
soovin	doc_213943985007_item	2286830	et	3	main
teha	doc_213943985007_item	2286851	et	3	main
millest	doc_213943985007_item	2286854	et	3	main
meid	doc_213943985007_item	2286875	et	4	main
asjad	doc_213943985007_item	2286877	et	3	main
sõbralik	doc_213943985007_item	2286885	et	3	main
peavad	doc_213943985007_item	2286899	et	4	main
oleme	doc_213943985007_item	2286907	et	3	main
perekond	doc_213943985007_item	2286910	et	3	main
pärast	doc_213943985007_item	2286912	et	4	main
lektoorid	doc_213943985007_item	2286915	et	4	main
informaatsion	doc_213943985007_item	2286921	et	4	main
mulle	doc_213943985007_item	2286927	et	4	main
on	doc_213943985007_item	2286931	et	4	main
minu	doc_213943985007_item	2286933	et	3	main
hetkel	doc_213943985007_item	2286935	et	4	main
kui	doc_213943985005_item	2286507	et	3	main
ma	doc_213943985005_item	2286508	et	3	main
seda	doc_213943985005_item	2286510	et	3	main
ülikoolis	doc_213943985005_item	2286515	et	4	main
võimalus	doc_213943985005_item	2286517	et	3	main
mina	doc_213943985005_item	2286522	et	4	main
ja	doc_213943985005_item	2286526	et	3	main
et	doc_213943985005_item	2286528	et	3	main
õpima	doc_213943985005_item	2286532	et	4	main
mul	doc_213943985005_item	2286534	et	3	main
ma	doc_213943985005_item	2286546	et	3	main
ülikool	doc_213943985005_item	2286550	et	4	main
annab	doc_213943985005_item	2286551	et	3	main
mulle	doc_213943985005_item	2286552	et	4	main
teadusi	doc_213943985005_item	2286553	et	3	main
väga	doc_213943985005_item	2286560	et	3	main
tahan	doc_213943985005_item	2286567	et	3	main
teadusi	doc_213943985005_item	2286569	et	3	main
ülikoolist	doc_213943985005_item	2286571	et	4	main
essee	doc_213943985006_item	2286572	et	4	main
1	doc_213943985006_item	2286573	et	2	main
ma	doc_213943985006_item	2286575	et	3	main
sellel	doc_213943985006_item	2286583	et	4	main
1	doc_213943985006_item	2286586	et	2	main
ma	doc_213943985006_item	2286587	et	3	main
maailmas	doc_213943985006_item	2286598	et	3	main
ajakirjanikud	doc_213943985006_item	2286599	et	3	main
see	doc_213943985006_item	2286600	et	3	main
on	doc_213943985006_item	2286601	et	4	main
väga	doc_213943985006_item	2286602	et	3	main
tarkad	doc_213943985006_item	2286603	et	4	main
edukad	doc_213943985006_item	2286604	et	3	main
inimesed	doc_213943985006_item	2286605	et	3	main
nendele	doc_213943985006_item	2286606	et	4	main
on	doc_213943985006_item	2286607	et	4	main
avatud	doc_213943985006_item	2286608	et	4	main
kõik	doc_213943985006_item	2286609	et	4	main
uksed	doc_213943985006_item	2286610	et	3	main
et	doc_213943985006_item	2286611	et	3	main
laiendada	doc_213943985006_item	2286612	et	3	main
oma	doc_213943985006_item	2286613	et	4	main
silmaringi	doc_213943985006_item	2286614	et	4	main
miks	doc_213943985006_item	2286615	et	4	main
ma	doc_213943985006_item	2286616	et	3	main
valisin	doc_213943985006_item	2286617	et	3	main
selle	doc_213943985006_item	2286618	et	4	main
eriala	doc_213943985006_item	2286619	et	4	main
esimesena	doc_213943985006_item	2286620	et	3	main
ja	doc_213943985006_item	2286627	et	3	main
iga	doc_213943985006_item	2286629	et	4	main
reisida	doc_213943985006_item	2286636	et	3	main
võimalused	doc_213943985006_item	2286643	et	3	main
nõuga	doc_213943985006_item	2286659	et	3	main
tulemusele	doc_213943985006_item	2286670	et	3	main
väga	doc_213943985006_item	2286672	et	3	main
valik	doc_213943985006_item	2286674	et	3	main
filoloogia	doc_213943985006_item	2286683	et	4	main
1	doc_213943985007_item	2286692	et	2	main
sellel	doc_213943985007_item	2286702	et	4	main
erialal	doc_213943985007_item	2286703	et	3	main
meie	doc_213943985007_item	2286713	et	4	main
osa	doc_213943985007_item	2286719	et	4	main
ilma	doc_213943985007_item	2286720	et	4	main
mis	doc_213943985007_item	2286725	et	4	main
et	doc_213943985006_item	2286589	et	3	main
tänapäeval	doc_213943985006_item	2286590	et	3	main
oluline	doc_213943985006_item	2286593	et	4	main
see	doc_213943985006_item	2286621	et	3	main
väga	doc_213943985006_item	2286623	et	3	main
sa	doc_213943985006_item	2286625	et	3	main
suhtled	doc_213943985006_item	2286626	et	3	main
tutvustad	doc_213943985006_item	2286628	et	3	main
on	doc_213943985006_item	2286634	et	4	main
võimalik	doc_213943985006_item	2286635	et	3	main
teisena	doc_213943985006_item	2286637	et	4	main
on	doc_213943985006_item	2286639	et	4	main
realiseerida	doc_213943985006_item	2286641	et	3	main
näiteks	doc_213943985006_item	2286646	et	4	main
tahad	doc_213943985006_item	2286648	et	3	main
arvamuses	doc_213943985006_item	2286661	et	3	main
õiget	doc_213943985006_item	2286664	et	3	main
ülikool	doc_213943985006_item	2286667	et	4	main
oma	doc_213943985006_item	2286677	et	4	main
slaavi	doc_213943985006_item	2286682	et	3	main
osakond	doc_213943985006_item	2286684	et	3	main
õppimisest	doc_213943985006_item	2286685	et	4	main
uued	doc_213943985006_item	2286688	et	3	main
miks	doc_213943985007_item	2286693	et	4	main
selle	doc_213943985007_item	2286696	et	4	main
tü	doc_213943985007_item	2286705	et	4	main
1	doc_213943985007_item	2286707	et	2	main
on	doc_213943985007_item	2286709	et	4	main
ajal	doc_213943985007_item	2286714	et	4	main
üks	doc_213943985007_item	2286717	et	3	main
ei	doc_213943985007_item	2286723	et	4	main
juhtus	doc_213943985007_item	2286726	et	3	main
aega	doc_213943985007_item	2286740	et	4	main
kui	doc_213943985007_item	2286748	et	3	main
raadiot	doc_213943985007_item	2286750	et	3	main
telerit	doc_213943985007_item	2286752	et	3	main
elu	doc_213943985007_item	2286754	et	4	main
tänapäevane	doc_213943985007_item	2286769	et	4	main
lugema	doc_213943985007_item	2286775	et	4	main
vaatama	doc_213943985007_item	2286780	et	3	main
elada	doc_213943985007_item	2286787	et	3	main
küsimustele	doc_213943985007_item	2286803	et	4	main
ajalehti	doc_213943985007_item	2286811	et	4	main
ka	doc_213943985007_item	2286815	et	3	main
huvitav	doc_213943985006_item	2286624	et	4	main
päev	doc_213943985006_item	2286630	et	3	main
inimesega	doc_213943985006_item	2286632	et	3	main
sul	doc_213943985006_item	2286633	et	3	main
võimalus	doc_213943985006_item	2286640	et	3	main
oma	doc_213943985006_item	2286642	et	4	main
sa	doc_213943985006_item	2286652	et	3	main
võid	doc_213943985006_item	2286653	et	4	main
kirjutada	doc_213943985006_item	2286654	et	3	main
ajalehes	doc_213943985006_item	2286655	et	3	main
artiklid	doc_213943985006_item	2286657	et	3	main
mingeit	doc_213943985006_item	2286656	et	4	main
oma	doc_213943985006_item	2286658	et	4	main
minu	doc_213943985006_item	2286660	et	3	main
tegesin	doc_213943985006_item	2286663	et	4	main
võimalus	doc_213943985006_item	2286676	et	3	main
ma	doc_213943985006_item	2286680	et	3	main
tuttavad	doc_213943985006_item	2286690	et	4	main
essee	doc_213943985007_item	2286691	et	4	main
ja	doc_213943985007_item	2286704	et	3	main
väga	doc_213943985007_item	2286710	et	3	main
see	doc_213943985007_item	2286715	et	3	main
me	doc_213943985007_item	2286722	et	4	main
informatsiooni	doc_213943985007_item	2286732	et	4	main
millised	doc_213943985007_item	2286733	et	3	main
sündmused	doc_213943985007_item	2286734	et	3	main
tagasi	doc_213943985007_item	2286741	et	3	main
olnud	doc_213943985007_item	2286745	et	4	main
ajalehti	doc_213943985007_item	2286747	et	4	main
arvan	doc_213943985007_item	2286767	et	3	main
noor	doc_213943985007_item	2286771	et	3	main
vana	doc_213943985007_item	2286773	et	4	main
ja	doc_213943985007_item	2286779	et	3	main
uudisi	doc_213943985007_item	2286781	et	4	main
ta	doc_213943985007_item	2286783	et	4	main
võtab	doc_213943985007_item	2286784	et	3	main
võiks	doc_213943985007_item	2286796	et	4	main
homme	doc_213943985007_item	2286798	et	3	main
ja	doc_213943985007_item	2286800	et	3	main
palju	doc_213943985007_item	2286801	et	4	main
teistele	doc_213943985007_item	2286802	et	4	main
mulle	doc_213943985007_item	2286808	et	4	main
kui	doc_213943985007_item	2286813	et	3	main
ma	doc_213943985007_item	2286829	et	3	main
teha	doc_213943985007_item	2286831	et	3	main
on	doc_213943985007_item	2286837	et	4	main
ma	doc_213943985007_item	2286840	et	3	main
osa	doc_213943985007_item	2286842	et	4	main
elust	doc_213943985007_item	2286844	et	3	main
ja	doc_213943985007_item	2286845	et	3	main
kirjutada	doc_213943985007_item	2286848	et	3	main
inimesed	doc_213943985007_item	2286855	et	3	main
2	doc_213943985007_item	2286858	et	2	main
teavad	doc_213943985007_item	2286880	et	3	main
et	doc_213943985007_item	2286882	et	3	main
rühm	doc_213943985007_item	2286886	et	3	main
on	doc_213943985007_item	2286889	et	4	main
probleem	doc_213943985007_item	2286890	et	3	main
et	doc_213943985007_item	2286905	et	3	main
üksmeelne	doc_213943985007_item	2286909	et	3	main
ja	doc_213943985007_item	2286911	et	3	main
meie	doc_213943985007_item	2286920	et	4	main
saa	doc_213943985007_item	2286724	et	4	main
euroopas	doc_213943985007_item	2286727	et	3	main
kultuuri	doc_213943985007_item	2286735	et	4	main
politiiline	doc_213943985007_item	2286736	et	4	main
ei	doc_213943985007_item	2286743	et	4	main
ka	doc_213943985007_item	2286749	et	3	main
lihtne	doc_213943985007_item	2286756	et	3	main
nad	doc_213943985007_item	2286757	et	3	main
ei	doc_213943985007_item	2286758	et	4	main
huvitanud	doc_213943985007_item	2286760	et	4	main
ole	doc_213943985007_item	2286759	et	4	main
sündmusesse	doc_213943985007_item	2286761	et	4	main
mis	doc_213943985007_item	2286762	et	4	main
olid	doc_213943985007_item	2286763	et	4	main
olnud	doc_213943985007_item	2286764	et	4	main
maailmas	doc_213943985007_item	2286765	et	3	main
ma	doc_213943985007_item	2286766	et	3	main
meil	doc_213943985007_item	2286729	et	4	main
ei	doc_213943985007_item	2286730	et	4	main
ole	doc_213943985007_item	2286731	et	4	main
toimuvad	doc_213943985007_item	2286737	et	4	main
palju	doc_213943985007_item	2286739	et	4	main
oli	doc_213943985007_item	2286755	et	3	main
nendest	doc_213943985007_item	2286782	et	4	main
informatsioon	doc_213943985007_item	2286785	et	3	main
palju	doc_213943985007_item	2286791	et	4	main
milline	doc_213943985007_item	2286794	et	3	main
me	doc_213943985007_item	2286804	et	4	main
ajalehtedest	doc_213943985007_item	2286807	et	4	main
meeldib	doc_213943985007_item	2286809	et	3	main
vene	doc_213943985007_item	2286817	et	4	main
kanaalid	doc_213943985007_item	2286823	et	4	main
et	doc_213943985007_item	2286824	et	3	main
diskussioonisse	doc_213943985007_item	2286827	et	3	main
rääkida	doc_213943985007_item	2286833	et	3	main
mis	doc_213943985007_item	2286835	et	4	main
olen	doc_213943985007_item	2286841	et	3	main
elust	doc_213943985007_item	2286850	et	3	main
huvi	doc_213943985007_item	2286857	et	4	main
õpetaksid	doc_213943985007_item	2286874	et	4	main
kõik	doc_213943985007_item	2286876	et	4	main
hea	doc_213943985007_item	2286884	et	4	main
rääkime	doc_213943985007_item	2286891	et	4	main
sellest	doc_213943985007_item	2286892	et	4	main
inimised	doc_213943985007_item	2286893	et	4	main
nii	doc_213943985007_item	2286894	et	3	main
lektoorid	doc_213943985007_item	2286895	et	4	main
kui	doc_213943985007_item	2286896	et	3	main
olema	doc_213943985007_item	2286900	et	4	main
avatud	doc_213943985007_item	2286901	et	4	main
sõbralik	doc_213943985007_item	2286902	et	3	main
ma	doc_213943985007_item	2286903	et	3	main
soovin	doc_213943985007_item	2286904	et	3	main
mis	doc_213943985007_item	2286922	et	4	main
tööks	doc_213943985007_item	2286926	et	3	main
miks	doc_213943985009_item	2287028	et	4	main
erialal	doc_213943985009_item	2287039	et	3	main
ja	doc_213943985009_item	2287040	et	3	main
tü	doc_213943985009_item	2287041	et	4	main
1	doc_213943985009_item	2287042	et	2	main
miks	doc_213943985009_item	2287043	et	4	main
ma	doc_213943985009_item	2287044	et	3	main
valisin	doc_213943985009_item	2287045	et	3	main
ülikool	doc_213943985009_item	2287058	et	4	main
tahan	doc_213943985009_item	2287066	et	3	main
uudiseid	doc_213943985009_item	2287069	et	3	main
neli	doc_213943985009_item	2287097	et	3	main
otsustasin	doc_213943985009_item	2287101	et	3	main
elukutse	doc_213943985009_item	2287106	et	4	main
jaoks	doc_213943985009_item	2287108	et	4	main
asjade	doc_213943985009_item	2287123	et	3	main
loodan	doc_213943985009_item	2287127	et	3	main
mul	doc_213943985009_item	2287129	et	3	main
ja	doc_213943985009_item	2287134	et	3	main
alati	doc_213943985009_item	2287148	et	4	main
kõik	doc_213943985009_item	2287150	et	4	main
kõik	doc_213943985009_item	2287152	et	4	main
teada	doc_213943985009_item	2287155	et	3	main
rääkida	doc_213943985009_item	2287158	et	3	main
teatatakse	doc_213943985009_item	2287167	et	3	main
mulle	doc_213943985009_item	2287178	et	4	main
on	doc_213943985009_item	2287223	et	4	main
et	doc_213943985009_item	2287226	et	3	main
et	doc_213943985007_item	2286768	et	3	main
või	doc_213943985007_item	2286772	et	4	main
peab	doc_213943985007_item	2286774	et	4	main
raadiot	doc_213943985007_item	2286778	et	3	main
et	doc_213943985007_item	2286786	et	3	main
töötada	doc_213943985007_item	2286789	et	3	main
maksab	doc_213943985007_item	2286792	et	3	main
ilm	doc_213943985007_item	2286795	et	3	main
olla	doc_213943985007_item	2286797	et	3	main
sellele	doc_213943985007_item	2286799	et	4	main
otsime	doc_213943985007_item	2286805	et	4	main
niisugused	doc_213943985007_item	2286812	et	3	main
postimees	doc_213943985007_item	2286814	et	4	main
armastan	doc_213943985007_item	2286816	et	3	main
pressa	doc_213943985007_item	2286818	et	4	main
vaatan	doc_213943985007_item	2286819	et	3	main
telerit	doc_213943985007_item	2286820	et	3	main
etv	doc_213943985007_item	2286821	et	4	main
sõpradega	doc_213943985007_item	2286828	et	3	main
tõttu	doc_213943985007_item	2286834	et	4	main
tänapäeval	doc_213943985007_item	2286836	et	3	main
väga	doc_213943985007_item	2286838	et	3	main
meiest	doc_213943985007_item	2286843	et	4	main
kavatsen	doc_213943985007_item	2286847	et	3	main
programmi	doc_213943985007_item	2286852	et	4	main
meiele	doc_213943985007_item	2286872	et	4	main
et	doc_213943985007_item	2286873	et	3	main
nad	doc_213943985007_item	2286879	et	3	main
olla	doc_213943985007_item	2286883	et	3	main
üliõpilased	doc_213943985007_item	2286898	et	3	main
nagu	doc_213943985007_item	2286908	et	3	main
on	doc_213943985007_item	2286917	et	4	main
targem	doc_213943985007_item	2286918	et	4	main
annavad	doc_213943985007_item	2286919	et	3	main
mõtted	doc_213943985007_item	2286934	et	3	main
1	doc_213943985009_item	2287027	et	2	main
valisin	doc_213943985009_item	2287030	et	3	main
mida	doc_213943985009_item	2287034	et	4	main
ma	doc_213943985009_item	2287035	et	3	main
eriala	doc_213943985009_item	2287047	et	4	main
ülikoolis	doc_213943985009_item	2287053	et	4	main
miks	doc_213943985009_item	2287054	et	4	main
ma	doc_213943985009_item	2287055	et	3	main
valisin	doc_213943985009_item	2287056	et	3	main
ma	doc_213943985009_item	2287061	et	3	main
armastan	doc_213943985009_item	2287063	et	3	main
kõik	doc_213943985009_item	2287068	et	4	main
õige	doc_213943985009_item	2287092	et	4	main
juba	doc_213943985009_item	2287096	et	3	main
et	doc_213943985009_item	2287102	et	3	main
olla	doc_213943985009_item	2287115	et	3	main
oskama	doc_213943985009_item	2287118	et	3	main
ja	doc_213943985009_item	2287121	et	3	main
objektivselt	doc_213943985009_item	2287125	et	4	main
kõik	doc_213943985009_item	2287131	et	4	main
ma	doc_213943985009_item	2287135	et	3	main
maailmas	doc_213943985009_item	2287144	et	3	main
toimub	doc_213943985009_item	2287145	et	3	main
mulle	doc_213943985009_item	2287146	et	4	main
ma	doc_213943985009_item	2287153	et	3	main
minu	doc_213943985009_item	2287163	et	3	main
loodan	doc_213943985009_item	2287170	et	3	main
ülikool	doc_213943985009_item	2287176	et	4	main
tallinna	doc_213943985009_item	2287207	et	4	main
ma	doc_213943985009_item	2287210	et	3	main
tööpakkumised	doc_213943985009_item	2287214	et	3	main
inimesega	doc_213943985009_item	2287220	et	3	main
jaoks	doc_213943985009_item	2287222	et	4	main
väga	doc_213943985009_item	2287224	et	3	main
on	doc_213943985009_item	2287228	et	4	main
tutvused	doc_213943985009_item	2287230	et	3	main
vene	doc_213943985007_item	2286822	et	4	main
uudisi	doc_213943985007_item	2286832	et	4	main
oluline	doc_213943985007_item	2286839	et	4	main
ma	doc_213943985007_item	2286846	et	3	main
sellest	doc_213943985007_item	2286849	et	4	main
probleemidest	doc_213943985007_item	2286853	et	3	main
tunnevad	doc_213943985007_item	2286856	et	3	main
see	doc_213943985007_item	2286859	et	3	main
on	doc_213943985007_item	2286860	et	4	main
raske	doc_213943985007_item	2286861	et	4	main
küsimus	doc_213943985007_item	2286862	et	4	main
mulle	doc_213943985007_item	2286863	et	4	main
meeldib	doc_213943985007_item	2286864	et	3	main
ülikool	doc_213943985007_item	2286865	et	4	main
loomulikult	doc_213943985007_item	2286866	et	4	main
soovin	doc_213943985007_item	2286867	et	3	main
et	doc_213943985007_item	2286868	et	3	main
lektoorid	doc_213943985007_item	2286869	et	4	main
oleksid	doc_213943985007_item	2286870	et	4	main
tähelepanelikud	doc_213943985007_item	2286871	et	4	main
mis	doc_213943985007_item	2286878	et	4	main
soovin	doc_213943985007_item	2286881	et	3	main
kui	doc_213943985007_item	2286887	et	3	main
meil	doc_213943985007_item	2286888	et	4	main
ka	doc_213943985007_item	2286897	et	3	main
me	doc_213943985007_item	2286906	et	4	main
töötame	doc_213943985007_item	2286913	et	3	main
koos	doc_213943985007_item	2286914	et	4	main
nad	doc_213943985007_item	2286916	et	3	main
on	doc_213943985007_item	2286923	et	4	main
tundub	doc_213943985007_item	2286928	et	3	main
vaja	doc_213943985007_item	2286924	et	4	main
tulevaks	doc_213943985007_item	2286925	et	4	main
et	doc_213943985007_item	2286929	et	3	main
see	doc_213943985007_item	2286930	et	3	main
kõik	doc_213943985007_item	2286932	et	4	main
ma	doc_213943985009_item	2287029	et	3	main
ma	doc_213943985009_item	2287049	et	3	main
õppida	doc_213943985009_item	2287051	et	3	main
kirjutada	doc_213943985009_item	2287064	et	3	main
ma	doc_213943985009_item	2287100	et	3	main
minu	doc_213943985009_item	2287105	et	3	main
et	doc_213943985009_item	2287109	et	3	main
on	doc_213943985009_item	2287112	et	4	main
need	doc_213943985009_item	2287132	et	3	main
saada	doc_213943985009_item	2287137	et	4	main
eriala	doc_213943985009_item	2287139	et	4	main
mind	doc_213943985009_item	2287140	et	4	main
kõik	doc_213943985009_item	2287142	et	4	main
mis	doc_213943985009_item	2287143	et	4	main
suust	doc_213943985009_item	2287164	et	3	main
ka	doc_213943985009_item	2287166	et	3	main
see	doc_213943985009_item	2287172	et	3	main
ja	doc_213943985009_item	2287174	et	3	main
tööturul	doc_213943985009_item	2287212	et	3	main
et	doc_213943985009_item	2287216	et	3	main
mul	doc_213943985009_item	2287227	et	3	main
tuhande	doc_213943985011_item	2287360	et	3	main
tollel	doc_213943985011_item	2287365	et	4	main
elasid	doc_213943985011_item	2287367	et	4	main
isa	doc_213943985011_item	2287372	et	4	main
juba	doc_213943985011_item	2287382	et	3	main
lasteaeda	doc_213943985011_item	2287385	et	4	main
pärast	doc_213943985011_item	2287389	et	4	main
said	doc_213943985011_item	2287392	et	4	main
sinna	doc_213943985011_item	2287397	et	3	main
ja	doc_213943985011_item	2287403	et	3	main
siis	doc_213943985011_item	2287411	et	3	main
kaheksaastasena	doc_213943985011_item	2287412	et	4	main
peale	doc_213943985011_item	2287421	et	4	main
kooli	doc_213943985011_item	2287426	et	4	main
vastas	doc_213943985011_item	2287427	et	4	main
kümme	doc_213943985011_item	2287429	et	3	main
ei	doc_213943985011_item	2287435	et	4	main
kuni	doc_213943985011_item	2287439	et	3	main
raamatud	doc_213943985011_item	2287441	et	4	main
läbi	doc_213943985011_item	2287443	et	4	main
juba	doc_213943985011_item	2287445	et	3	main
ei	doc_213943985011_item	2287454	et	4	main
nii	doc_213943985011_item	2287461	et	3	main
eas	doc_213943985011_item	2287463	et	3	main
moment	doc_213943985011_item	2287519	et	3	main
laiskus	doc_213943985011_item	2287523	et	4	main
minul	doc_213943985011_item	2287525	et	3	main
pere	doc_213943985011_item	2287528	et	4	main
ikka	doc_213943985011_item	2287533	et	4	main
laiskus	doc_213943985011_item	2287538	et	4	main
asjad	doc_213943985011_item	2287544	et	3	main
mul	doc_213943985011_item	2287546	et	3	main
viitsimise	doc_213943985011_item	2287554	et	4	main
selle	doc_213943985009_item	2287031	et	4	main
eriala	doc_213943985009_item	2287032	et	4	main
ootan	doc_213943985009_item	2287036	et	3	main
selle	doc_213943985009_item	2287046	et	4	main
tallinna	doc_213943985009_item	2287057	et	4	main
ja	doc_213943985009_item	2287059	et	3	main
ajakirjandus	doc_213943985009_item	2287060	et	3	main
väga	doc_213943985009_item	2287062	et	3	main
teada	doc_213943985009_item	2287067	et	3	main
esimesena	doc_213943985009_item	2287070	et	3	main
valida	doc_213943985009_item	2287093	et	3	main
ajakirjanik	doc_213943985009_item	2287103	et	3	main
selle	doc_213943985009_item	2287107	et	4	main
olla	doc_213943985009_item	2287110	et	3	main
tähtis	doc_213943985009_item	2287114	et	4	main
korrektne	doc_213943985009_item	2287117	et	3	main
essee	doc_213943985009_item	2287026	et	4	main
2	doc_213943985009_item	2287033	et	2	main
õppimises	doc_213943985009_item	2287037	et	4	main
sellel	doc_213943985009_item	2287038	et	4	main
täna	doc_213943985009_item	2287048	et	4	main
alustan	doc_213943985009_item	2287050	et	3	main
tallinna	doc_213943985009_item	2287052	et	4	main
alati	doc_213943985009_item	2287065	et	4	main
meeldib	doc_213943985009_item	2287071	et	3	main
mulle	doc_213943985009_item	2287072	et	4	main
ka	doc_213943985009_item	2287073	et	3	main
tutvuda	doc_213943985009_item	2287074	et	3	main
uue	doc_213943985009_item	2287075	et	3	main
inimestega	doc_213943985009_item	2287076	et	3	main
ma	doc_213943985009_item	2287077	et	3	main
mõtlen	doc_213943985009_item	2287078	et	3	main
et	doc_213943985009_item	2287079	et	3	main
see	doc_213943985009_item	2287080	et	3	main
soobib	doc_213943985009_item	2287082	et	4	main
mulle	doc_213943985009_item	2287083	et	4	main
eriala	doc_213943985009_item	2287081	et	4	main
hästi	doc_213943985009_item	2287084	et	3	main
iga	doc_213943985009_item	2287085	et	4	main
noort	doc_213943985009_item	2287086	et	3	main
inimeste	doc_213943985009_item	2287087	et	3	main
jaoks	doc_213943985009_item	2287088	et	4	main
on	doc_213943985009_item	2287089	et	4	main
väga	doc_213943985009_item	2287090	et	3	main
tahtis	doc_213943985009_item	2287091	et	3	main
oma	doc_213943985009_item	2287094	et	4	main
kutse	doc_213943985009_item	2287095	et	4	main
aastaid	doc_213943985009_item	2287098	et	4	main
tagasi	doc_213943985009_item	2287099	et	3	main
on	doc_213943985009_item	2287104	et	4	main
ajakirjanikuks	doc_213943985009_item	2287111	et	3	main
väga	doc_213943985009_item	2287113	et	3	main
uudishimuliku	doc_213943985009_item	2287116	et	3	main
hästi	doc_213943985009_item	2287119	et	3	main
suhelda	doc_213943985009_item	2287120	et	4	main
paljude	doc_213943985009_item	2287122	et	3	main
on	doc_213943985009_item	2287130	et	4	main
iseloomujooned	doc_213943985009_item	2287133	et	3	main
meeldib	doc_213943985009_item	2287147	et	3	main
tahan	doc_213943985009_item	2287154	et	3	main
pärast	doc_213943985009_item	2287157	et	4	main
sellest	doc_213943985009_item	2287159	et	4	main
ma	doc_213943985009_item	2287160	et	3	main
tahan	doc_213943985009_item	2287161	et	3	main
et	doc_213943985009_item	2287162	et	3	main
uudised	doc_213943985009_item	2287168	et	3	main
ma	doc_213943985009_item	2287169	et	3	main
eriala	doc_213943985009_item	2287173	et	4	main
tallinna	doc_213943985009_item	2287175	et	4	main
minu	doc_213943985009_item	2287179	et	3	main
head	doc_213943985009_item	2287213	et	4	main
loodan	doc_213943985009_item	2287215	et	3	main
siin	doc_213943985009_item	2287218	et	4	main
palju	doc_213943985009_item	2287229	et	4	main
sõbrad	doc_213943985009_item	2287232	et	3	main
olen	doc_213943985011_item	2287357	et	3	main
üheksasaja	doc_213943985011_item	2287361	et	4	main
aastal	doc_213943985011_item	2287364	et	3	main
ajal	doc_213943985011_item	2287366	et	4	main
mu	doc_213943985011_item	2287368	et	3	main
juures	doc_213943985011_item	2287374	et	4	main
aasta	doc_213943985011_item	2287388	et	4	main
lasnamäele	doc_213943985011_item	2287395	et	3	main
olid	doc_213943985011_item	2287405	et	4	main
raamatud	doc_213943985011_item	2287407	et	4	main
kodus	doc_213943985011_item	2287408	et	4	main
hakkasin	doc_213943985011_item	2287413	et	3	main
käisin	doc_213943985011_item	2287417	et	3	main
tulles	doc_213943985011_item	2287434	et	4	main
teinud	doc_213943985011_item	2287436	et	4	main
loetud	doc_213943985011_item	2287444	et	4	main
lapsena	doc_213943985011_item	2287446	et	3	main
olla	doc_213943985011_item	2287449	et	3	main
eriti	doc_213943985011_item	2287457	et	3	main
sõpru	doc_213943985011_item	2287459	et	3	main
ole	doc_213943985011_item	2287465	et	4	main
halvem	doc_213943985011_item	2287471	et	4	main
minu	doc_213943985011_item	2287473	et	3	main
soovinud	doc_213943985011_item	2287476	et	4	main
imelikuks	doc_213943985011_item	2287510	et	3	main
pärast	doc_213943985011_item	2287512	et	4	main
teine	doc_213943985011_item	2287517	et	3	main
juba	doc_213943985011_item	2287527	et	3	main
ja	doc_213943985011_item	2287529	et	3	main
oma	doc_213943985011_item	2287530	et	4	main
kodu	doc_213943985011_item	2287531	et	4	main
saab	doc_213943985011_item	2287539	et	3	main
vaadata	doc_213943985009_item	2287124	et	4	main
ma	doc_213943985009_item	2287126	et	3	main
et	doc_213943985009_item	2287128	et	3	main
võin	doc_213943985009_item	2287136	et	3	main
see	doc_213943985009_item	2287138	et	3	main
huvitab	doc_213943985009_item	2287141	et	3	main
teada	doc_213943985009_item	2287149	et	3	main
maailmauudised	doc_213943985009_item	2287151	et	3	main
ja	doc_213943985009_item	2287156	et	3	main
teised	doc_213943985009_item	2287165	et	4	main
et	doc_213943985009_item	2287171	et	3	main
aitavad	doc_213943985009_item	2287177	et	4	main
uni	doc_213943985009_item	2287180	et	3	main
teha	doc_213943985009_item	2287181	et	3	main
reaalsus	doc_213943985009_item	2287182	et	4	main
2	doc_213943985009_item	2287183	et	2	main
mida	doc_213943985009_item	2287184	et	4	main
ma	doc_213943985009_item	2287185	et	3	main
ootan	doc_213943985009_item	2287186	et	3	main
õppimises	doc_213943985009_item	2287187	et	4	main
sellel	doc_213943985009_item	2287188	et	4	main
erialal	doc_213943985009_item	2287189	et	3	main
ja	doc_213943985009_item	2287190	et	3	main
tü	doc_213943985009_item	2287191	et	4	main
ma	doc_213943985009_item	2287192	et	3	main
loodan	doc_213943985009_item	2287193	et	3	main
et	doc_213943985009_item	2287194	et	3	main
see	doc_213943985009_item	2287195	et	3	main
eriala	doc_213943985009_item	2287196	et	4	main
aitab	doc_213943985009_item	2287197	et	3	main
mulle	doc_213943985009_item	2287198	et	4	main
rohkem	doc_213943985009_item	2287199	et	4	main
aru	doc_213943985009_item	2287200	et	4	main
saada	doc_213943985009_item	2287201	et	4	main
maailm	doc_213943985009_item	2287202	et	3	main
ja	doc_213943985009_item	2287203	et	3	main
tema	doc_213943985009_item	2287204	et	4	main
probleemid	doc_213943985009_item	2287205	et	3	main
ja	doc_213943985009_item	2287206	et	3	main
ülikooli	doc_213943985009_item	2287208	et	4	main
abil	doc_213943985009_item	2287209	et	4	main
saan	doc_213943985009_item	2287211	et	4	main
tutvun	doc_213943985009_item	2287217	et	3	main
uue	doc_213943985009_item	2287219	et	3	main
minu	doc_213943985009_item	2287221	et	3	main
tahtis	doc_213943985009_item	2287225	et	3	main
ja	doc_213943985009_item	2287231	et	3	main
sündinud	doc_213943985011_item	2287358	et	4	main
seitsmekümne	doc_213943985011_item	2287362	et	4	main
vanemad	doc_213943985011_item	2287369	et	4	main
koplis	doc_213943985011_item	2287370	et	3	main
minu	doc_213943985011_item	2287371	et	3	main
ja	doc_213943985011_item	2287376	et	3	main
töötasid	doc_213943985011_item	2287378	et	4	main
hommikust	doc_213943985011_item	2287379	et	4	main
õhtuni	doc_213943985011_item	2287380	et	3	main
ning	doc_213943985011_item	2287381	et	3	main
pidin	doc_213943985011_item	2287384	et	3	main
minema	doc_213943985011_item	2287386	et	3	main
vanemad	doc_213943985011_item	2287391	et	4	main
korteri	doc_213943985011_item	2287394	et	3	main
lapsepõlvest	doc_213943985011_item	2287399	et	4	main
armastasin	doc_213943985011_item	2287401	et	3	main
varsti	doc_213943985011_item	2287404	et	3	main
kõik	doc_213943985011_item	2287406	et	4	main
loetud	doc_213943985011_item	2287410	et	4	main
iga	doc_213943985011_item	2287419	et	4	main
asus	doc_213943985011_item	2287424	et	4	main
viisteist	doc_213943985011_item	2287430	et	4	main
raamatut	doc_213943985011_item	2287431	et	3	main
koju	doc_213943985011_item	2287433	et	3	main
midagi	doc_213943985011_item	2287438	et	4	main
võib	doc_213943985011_item	2287450	et	3	main
olnud	doc_213943985011_item	2287455	et	4	main
ei	doc_213943985011_item	2287464	et	4	main
tervitav	doc_213943985011_item	2287466	et	4	main
see	doc_213943985011_item	2287467	et	3	main
vist	doc_213943985011_item	2287469	et	4	main
moment	doc_213943985011_item	2287472	et	3	main
ei	doc_213943985011_item	2287475	et	4	main
inimestega	doc_213943985011_item	2287477	et	3	main
tihedat	doc_213943985011_item	2287478	et	3	main
alles	doc_213943985011_item	2287511	et	3	main
kooli	doc_213943985011_item	2287513	et	4	main
lõpetamist	doc_213943985011_item	2287514	et	4	main
muutusin	doc_213943985011_item	2287515	et	3	main
seltskondlikuks	doc_213943985011_item	2287516	et	3	main
tuleb	doc_213943985011_item	2287532	et	3	main
see	doc_213943985011_item	2287552	et	3	main
kohusetunne	doc_213943985011_item	2287558	et	3	main
edasi	doc_213943985011_item	2287564	et	3	main
ma	doc_213943985011_item	2287568	et	3	main
aastat	doc_213943985011_item	2287592	et	3	main
abiga	doc_213943985011_item	2287594	et	3	main
eesti	doc_213943985011_item	2287623	et	4	main
rahul	doc_213943985011_item	2287633	et	4	main
miski	doc_213943985011_item	2287635	et	4	main
mul	doc_213943985011_item	2287641	et	3	main
õppimisest	doc_213943985011_item	2287643	et	4	main
pankrotti	doc_213943985011_item	2287648	et	4	main
oma	doc_213943985011_item	2287657	et	4	main
ühe	doc_213943985011_item	2287669	et	4	main
numbri	doc_213943985011_item	2287672	et	3	main
et	doc_213943985011_item	2287674	et	3	main
tööle	doc_213943985011_item	2287679	et	3	main
ruttasin	doc_213943985011_item	2287686	et	3	main
juba	doc_213943985011_item	2287690	et	3	main
essee	doc_213943985011_item	2287356	et	4	main
viiendal	doc_213943985011_item	2287363	et	3	main
ema	doc_213943985011_item	2287375	et	4	main
isa	doc_213943985011_item	2287377	et	4	main
pooleteistaastasena	doc_213943985011_item	2287383	et	4	main
kolme	doc_213943985011_item	2287387	et	4	main
ja	doc_213943985011_item	2287396	et	3	main
saadik	doc_213943985011_item	2287400	et	4	main
lugeda	doc_213943985011_item	2287402	et	3	main
läbi	doc_213943985011_item	2287409	et	4	main
kohalikus	doc_213943985011_item	2287414	et	4	main
tallinnas	doc_213943985011_item	2287359	et	4	main
vanemate	doc_213943985011_item	2287373	et	4	main
minu	doc_213943985011_item	2287390	et	3	main
uue	doc_213943985011_item	2287393	et	3	main
kolisimegi	doc_213943985011_item	2287398	et	3	main
raamatukogus	doc_213943985011_item	2287415	et	4	main
käima	doc_213943985011_item	2287416	et	4	main
peaaegu	doc_213943985011_item	2287418	et	3	main
päev	doc_213943985011_item	2287420	et	3	main
raamatukogu	doc_213943985011_item	2287423	et	4	main
võtsin	doc_213943985011_item	2287428	et	3	main
ja	doc_213943985011_item	2287432	et	3	main
muud	doc_213943985011_item	2287437	et	4	main
armastasin	doc_213943985011_item	2287447	et	3	main
omaette	doc_213943985011_item	2287448	et	3	main
just	doc_213943985011_item	2287452	et	3	main
palju	doc_213943985011_item	2287458	et	4	main
varases	doc_213943985011_item	2287462	et	4	main
on	doc_213943985011_item	2287468	et	4	main
elus	doc_213943985011_item	2287474	et	4	main
negatiivne	doc_213943985011_item	2287518	et	3	main
minu	doc_213943985011_item	2287521	et	3	main
kooli	doc_213943985011_item	2287422	et	4	main
täpselt	doc_213943985011_item	2287425	et	4	main
kõik	doc_213943985011_item	2287440	et	4	main
olid	doc_213943985011_item	2287442	et	4	main
olla	doc_213943985011_item	2287451	et	3	main
sellepärast	doc_213943985011_item	2287453	et	3	main
mul	doc_213943985011_item	2287456	et	3	main
omapärasus	doc_213943985011_item	2287460	et	4	main
kõige	doc_213943985011_item	2287470	et	4	main
suhtlemist	doc_213943985011_item	2287479	et	4	main
kuid	doc_213943985011_item	2287480	et	4	main
see	doc_213943985011_item	2287481	et	3	main
on	doc_213943985011_item	2287482	et	4	main
ju	doc_213943985011_item	2287483	et	3	main
paratamatu	doc_213943985011_item	2287484	et	4	main
niisiis	doc_213943985011_item	2287485	et	3	main
ei	doc_213943985011_item	2287486	et	4	main
osanud	doc_213943985011_item	2287487	et	4	main
ma	doc_213943985011_item	2287488	et	3	main
selle	doc_213943985011_item	2287489	et	4	main
kohta	doc_213943985011_item	2287490	et	4	main
midagi	doc_213943985011_item	2287491	et	4	main
ette	doc_213943985011_item	2287492	et	4	main
võtta	doc_213943985011_item	2287493	et	3	main
et	doc_213943985011_item	2287494	et	3	main
olukorda	doc_213943985011_item	2287495	et	4	main
paremaks	doc_213943985011_item	2287496	et	4	main
muuta	doc_213943985011_item	2287497	et	4	main
eriti	doc_213943985011_item	2287498	et	3	main
kooliajal	doc_213943985011_item	2287499	et	3	main
oli	doc_213943985011_item	2287500	et	3	main
väga	doc_213943985011_item	2287501	et	3	main
palju	doc_213943985011_item	2287502	et	4	main
seljataga	doc_213943985011_item	2287503	et	3	main
rääkimist	doc_213943985011_item	2287504	et	4	main
kuna	doc_213943985011_item	2287505	et	3	main
klassikaaslased	doc_213943985011_item	2287506	et	3	main
pidasid	doc_213943985011_item	2287507	et	4	main
mind	doc_213943985011_item	2287508	et	4	main
üsna	doc_213943985011_item	2287509	et	3	main
on	doc_213943985011_item	2287520	et	4	main
on	doc_213943985011_item	2287526	et	4	main
kõvasti	doc_213943985011_item	2287535	et	3	main
pingutada	doc_213943985011_item	2287536	et	3	main
võitu	doc_213943985011_item	2287540	et	4	main
tavaliselt	doc_213943985011_item	2287541	et	4	main
alustatud	doc_213943985011_item	2287543	et	4	main
mitte	doc_213943985011_item	2287553	et	3	main
tuleb	doc_213943985011_item	2287556	et	3	main
kooli	doc_213943985011_item	2287560	et	4	main
minna	doc_213943985011_item	2287566	et	3	main
olnud	doc_213943985011_item	2287570	et	4	main
sain	doc_213943985011_item	2287595	et	3	main
uue	doc_213943985011_item	2287596	et	3	main
erialale	doc_213943985011_item	2287626	et	3	main
kuid	doc_213943985011_item	2287634	et	4	main
ole	doc_213943985011_item	2287637	et	4	main
läks	doc_213943985011_item	2287647	et	3	main
olin	doc_213943985011_item	2287649	et	3	main
meeleheites	doc_213943985011_item	2287651	et	3	main
päevad	doc_213943985011_item	2287654	et	3	main
kodus	doc_213943985011_item	2287656	et	4	main
mõttetes	doc_213943985011_item	2287658	et	4	main
kuni	doc_213943985011_item	2287659	et	3	main
öeldes	doc_213943985011_item	2287673	et	3	main
mind	doc_213943985011_item	2287683	et	4	main
kutsuti	doc_213943985011_item	2287684	et	3	main
kohe	doc_213943985011_item	2287687	et	4	main
päeva	doc_213943985011_item	2287692	et	4	main
mulle	doc_213943985011_item	2287741	et	4	main
väga	doc_213943985011_item	2287742	et	3	main
saanud	doc_213943985011_item	2287744	et	4	main
ja	doc_213943985011_item	2287745	et	3	main
ei	doc_213943985011_item	2287747	et	4	main
inimesi	doc_213943985011_item	2287753	et	4	main
seal	doc_213943985011_item	2287756	et	4	main
sidet	doc_213943985011_item	2287763	et	4	main
iirimaa	doc_213943985011_item	2287765	et	4	main
kolm	doc_213943985011_item	2287769	et	3	main
aastat	doc_213943985011_item	2287770	et	3	main
möödas	doc_213943985011_item	2287771	et	3	main
kuna	doc_213943985011_item	2287777	et	3	main
järele	doc_213943985011_item	2287781	et	4	main
elu	doc_213943985011_item	2287786	et	4	main
mõtted	doc_213943985011_item	2287787	et	3	main
ülikoolis	doc_213943985011_item	2287797	et	4	main
ning	doc_213943985011_item	2287800	et	3	main
elust	doc_213943985011_item	2287802	et	3	main
seotud	doc_213943985013_item	2287952	et	4	main
kahtlemata	doc_213943985013_item	2287955	et	4	main
kuid	doc_213943985013_item	2287957	et	4	main
üle	doc_213943985013_item	2287962	et	3	main
on	doc_213943985013_item	2287967	et	4	main
maa	doc_213943985013_item	2287984	et	4	main
kaasasündinud	doc_213943985011_item	2287522	et	4	main
kuna	doc_213943985011_item	2287524	et	3	main
päris	doc_213943985011_item	2287534	et	4	main
muidu	doc_213943985011_item	2287537	et	3	main
kuid	doc_213943985011_item	2287548	et	4	main
praegu	doc_213943985011_item	2287549	et	3	main
kui	doc_213943985011_item	2287550	et	3	main
lõpetamist	doc_213943985011_item	2287561	et	4	main
tahtsin	doc_213943985011_item	2287562	et	3	main
õppima	doc_213943985011_item	2287565	et	3	main
kuid	doc_213943985011_item	2287567	et	4	main
kindel	doc_213943985011_item	2287571	et	3	main
mida	doc_213943985011_item	2287572	et	4	main
täpselt	doc_213943985011_item	2287573	et	4	main
ja	doc_213943985011_item	2287574	et	3	main
milleks	doc_213943985011_item	2287575	et	4	main
sellepärast	doc_213943985011_item	2287576	et	3	main
kukkusin	doc_213943985011_item	2287577	et	3	main
vastuvõtueksamitel	doc_213943985011_item	2287578	et	3	main
läbi	doc_213943985011_item	2287579	et	4	main
peale	doc_213943985011_item	2287580	et	4	main
seda	doc_213943985011_item	2287581	et	3	main
töötasin	doc_213943985011_item	2287582	et	3	main
rootsis	doc_213943985011_item	2287583	et	3	main
lapsehoidjana	doc_213943985011_item	2287584	et	3	main
kuid	doc_213943985011_item	2287585	et	4	main
väga	doc_213943985011_item	2287586	et	3	main
lühikest	doc_213943985011_item	2287587	et	4	main
nii	doc_213943985011_item	2287589	et	3	main
möödus	doc_213943985011_item	2287590	et	3	main
aega	doc_213943985011_item	2287588	et	4	main
kaks	doc_213943985011_item	2287591	et	3	main
kõik	doc_213943985011_item	2287542	et	4	main
jäävad	doc_213943985011_item	2287545	et	4	main
lõpetamata	doc_213943985011_item	2287547	et	4	main
tekkib	doc_213943985011_item	2287551	et	3	main
appi	doc_213943985011_item	2287557	et	4	main
pärast	doc_213943985011_item	2287559	et	4	main
ülikooli	doc_213943985011_item	2287563	et	4	main
ema	doc_213943985011_item	2287593	et	4	main
laeva	doc_213943985011_item	2287598	et	4	main
kõige	doc_213943985011_item	2287609	et	4	main
samal	doc_213943985011_item	2287617	et	3	main
ajal	doc_213943985011_item	2287618	et	4	main
astusin	doc_213943985011_item	2287619	et	3	main
ma	doc_213943985011_item	2287620	et	3	main
pedagoogikaülikooli	doc_213943985011_item	2287621	et	4	main
võõrkeelena	doc_213943985011_item	2287625	et	3	main
kulges	doc_213943985011_item	2287628	et	3	main
olin	doc_213943985011_item	2287630	et	3	main
ei	doc_213943985011_item	2287636	et	4	main
maailmas	doc_213943985011_item	2287639	et	3	main
laevafirma	doc_213943985011_item	2287646	et	4	main
istusin	doc_213943985011_item	2287653	et	3	main
ühel	doc_213943985011_item	2287660	et	3	main
oma	doc_213943985011_item	2287664	et	4	main
kes	doc_213943985011_item	2287666	et	4	main
andis	doc_213943985011_item	2287667	et	3	main
mulle	doc_213943985011_item	2287668	et	4	main
selle	doc_213943985011_item	2287675	et	4	main
iirimaale	doc_213943985011_item	2287678	et	4	main
ja	doc_213943985011_item	2287682	et	3	main
ja	doc_213943985011_item	2287689	et	3	main
pärast	doc_213943985011_item	2287693	et	4	main
väga	doc_213943985011_item	2287724	et	3	main
seal	doc_213943985011_item	2287729	et	4	main
unusta	doc_213943985011_item	2287748	et	4	main
kunagi	doc_213943985011_item	2287750	et	3	main
neid	doc_213943985011_item	2287752	et	4	main
sain	doc_213943985011_item	2287755	et	3	main
ka	doc_213943985011_item	2287761	et	3	main
praegu	doc_213943985011_item	2287762	et	3	main
hirmsasti	doc_213943985011_item	2287779	et	3	main
nüüd	doc_213943985011_item	2287782	et	4	main
mul	doc_213943985011_item	2287784	et	3	main
inimene	doc_213943985011_item	2287793	et	3	main
olen	doc_213943985011_item	2287794	et	3	main
õpin	doc_213943985011_item	2287798	et	3	main
tunnen	doc_213943985011_item	2287801	et	3	main
hetk	doc_213943985011_item	2287555	et	3	main
ei	doc_213943985011_item	2287569	et	4	main
töökoha	doc_213943985011_item	2287597	et	4	main
peal	doc_213943985011_item	2287599	et	4	main
eesti	doc_213943985011_item	2287602	et	4	main
rootsi	doc_213943985011_item	2287603	et	4	main
vahel	doc_213943985011_item	2287604	et	4	main
mis	doc_213943985011_item	2287612	et	4	main
mul	doc_213943985011_item	2287613	et	3	main
on	doc_213943985011_item	2287614	et	4	main
elus	doc_213943985011_item	2287615	et	4	main
olnud	doc_213943985011_item	2287616	et	4	main
sisse	doc_213943985011_item	2287622	et	4	main
sujuvalt	doc_213943985011_item	2287629	et	4	main
siin	doc_213943985011_item	2287638	et	4	main
kõrini	doc_213943985011_item	2287644	et	4	main
meie	doc_213943985011_item	2287645	et	4	main
äärmises	doc_213943985011_item	2287650	et	3	main
muidkui	doc_213943985011_item	2287652	et	4	main
nägin	doc_213943985011_item	2287662	et	3	main
tuttava	doc_213943985011_item	2287665	et	4	main
firma	doc_213943985011_item	2287670	et	4	main
kaudu	doc_213943985011_item	2287676	et	3	main
helistasin	doc_213943985011_item	2287680	et	3	main
vestlusele	doc_213943985011_item	2287685	et	3	main
sinna	doc_213943985011_item	2287688	et	3	main
ka	doc_213943985011_item	2287722	et	3	main
minu	doc_213943985011_item	2287726	et	3	main
jaoks	doc_213943985011_item	2287727	et	4	main
on	doc_213943985011_item	2287728	et	4	main
seda	doc_213943985011_item	2287731	et	3	main
on	doc_213943985011_item	2287732	et	4	main
see	doc_213943985011_item	2287738	et	3	main
lähedaseks	doc_213943985011_item	2287743	et	3	main
ja	doc_213943985011_item	2287758	et	3	main
sellest	doc_213943985011_item	2287764	et	4	main
on	doc_213943985011_item	2287767	et	4	main
vaid	doc_213943985011_item	2287768	et	3	main
mulle	doc_213943985011_item	2287772	et	4	main
tundub	doc_213943985011_item	2287774	et	3	main
et	doc_213943985011_item	2287775	et	3	main
kümme	doc_213943985011_item	2287776	et	3	main
ja	doc_213943985011_item	2287788	et	3	main
olen	doc_213943985011_item	2287790	et	3	main
uus	doc_213943985011_item	2287792	et	3	main
uuesti	doc_213943985011_item	2287795	et	3	main
kas	doc_213943985013_item	2287940	et	3	main
on	doc_213943985013_item	2287950	et	4	main
väga	doc_213943985013_item	2287968	et	3	main
arusaamisel	doc_213943985013_item	2287971	et	4	main
aitab	doc_213943985013_item	2287974	et	3	main
et	doc_213943985013_item	2287982	et	3	main
erinevaid	doc_213943985013_item	2287992	et	4	main
tele	doc_213943985013_item	2288000	et	4	main
keeleoskus	doc_213943985013_item	2288004	et	3	main
tee	doc_213943985013_item	2288007	et	4	main
mis	doc_213943985011_item	2287600	et	4	main
käis	doc_213943985011_item	2287601	et	4	main
seda	doc_213943985011_item	2287605	et	3	main
tööd	doc_213943985011_item	2287606	et	4	main
võiksin	doc_213943985011_item	2287607	et	3	main
nimetada	doc_213943985011_item	2287608	et	3	main
paremaks	doc_213943985011_item	2287610	et	4	main
tööks	doc_213943985011_item	2287611	et	3	main
keele	doc_213943985011_item	2287624	et	4	main
elu	doc_213943985011_item	2287627	et	4	main
endaga	doc_213943985011_item	2287631	et	4	main
väga	doc_213943985011_item	2287632	et	3	main
püsiv	doc_213943985011_item	2287640	et	4	main
sai	doc_213943985011_item	2287642	et	4	main
läbi	doc_213943985011_item	2287655	et	4	main
päeval	doc_213943985011_item	2287661	et	3	main
linnas	doc_213943985011_item	2287663	et	4	main
telefoni	doc_213943985011_item	2287671	et	4	main
saab	doc_213943985011_item	2287677	et	3	main
sinna	doc_213943985011_item	2287681	et	3	main
mõne	doc_213943985011_item	2287691	et	3	main
ära	doc_213943985011_item	2287695	et	4	main
pidin	doc_213943985011_item	2287694	et	3	main
sõitma	doc_213943985011_item	2287696	et	3	main
see	doc_213943985011_item	2287697	et	3	main
oli	doc_213943985011_item	2287698	et	3	main
väga	doc_213943985011_item	2287699	et	3	main
aga	doc_213943985011_item	2287701	et	3	main
see	doc_213943985011_item	2287702	et	3	main
oli	doc_213943985011_item	2287703	et	3	main
juba	doc_213943985011_item	2287704	et	3	main
midagi	doc_213943985011_item	2287705	et	4	main
ootamatu	doc_213943985011_item	2287700	et	4	main
nii	doc_213943985011_item	2287706	et	3	main
läksingi	doc_213943985011_item	2287707	et	3	main
ja	doc_213943985011_item	2287708	et	3	main
jäin	doc_213943985011_item	2287709	et	3	main
iirimaale	doc_213943985011_item	2287710	et	4	main
terveks	doc_213943985011_item	2287711	et	4	main
aastaks	doc_213943985011_item	2287712	et	4	main
või	doc_213943985011_item	2287713	et	4	main
isegi	doc_213943985011_item	2287714	et	4	main
natuke	doc_213943985011_item	2287715	et	4	main
kauemaks	doc_213943985011_item	2287716	et	3	main
iirimaale	doc_213943985011_item	2287717	et	4	main
minek	doc_213943985011_item	2287718	et	3	main
jääb	doc_213943985011_item	2287719	et	3	main
minu	doc_213943985011_item	2287720	et	3	main
jaoks	doc_213943985011_item	2287721	et	4	main
võluatmosfäär	doc_213943985011_item	2287730	et	3	main
raske	doc_213943985011_item	2287733	et	4	main
kirjeldada	doc_213943985011_item	2287734	et	3	main
lihtsalt	doc_213943985011_item	2287735	et	4	main
tunnen	doc_213943985011_item	2287736	et	3	main
maa	doc_213943985011_item	2287739	et	4	main
on	doc_213943985011_item	2287740	et	4	main
ma	doc_213943985011_item	2287746	et	3	main
iirimaad	doc_213943985011_item	2287749	et	4	main
tuttavaks	doc_213943985011_item	2287757	et	4	main
kellega	doc_213943985011_item	2287759	et	3	main
ajast	doc_213943985011_item	2287766	et	4	main
aga	doc_213943985011_item	2287773	et	3	main
igatsen	doc_213943985011_item	2287778	et	3	main
siin	doc_213943985011_item	2287796	et	4	main
tänapäevani	doc_213943985011_item	2287723	et	3	main
tähtsaks	doc_213943985011_item	2287725	et	4	main
et	doc_213943985011_item	2287737	et	3	main
eriti	doc_213943985011_item	2287751	et	3	main
kellega	doc_213943985011_item	2287754	et	3	main
pean	doc_213943985011_item	2287760	et	4	main
selle	doc_213943985011_item	2287780	et	4	main
on	doc_213943985011_item	2287783	et	4	main
uus	doc_213943985011_item	2287785	et	3	main
plaanid	doc_213943985011_item	2287789	et	4	main
lausa	doc_213943985011_item	2287791	et	4	main
idakeeli	doc_213943985011_item	2287799	et	3	main
rõõmu	doc_213943985011_item	2287803	et	4	main
essee	doc_213943985013_item	2287939	et	4	main
omavahel	doc_213943985013_item	2287951	et	3	main
tähtsustada	doc_213943985013_item	2287963	et	3	main
teise	doc_213943985013_item	2287964	et	4	main
keeleoskus	doc_213943985013_item	2287966	et	3	main
kultuuri	doc_213943985013_item	2287970	et	4	main
hea	doc_213943985013_item	2287972	et	4	main
paremini	doc_213943985013_item	2287975	et	4	main
õppida	doc_213943985013_item	2287981	et	3	main
veel	doc_213943985013_item	2287986	et	4	main
kultuuri	doc_213943985013_item	2287996	et	4	main
kohta	doc_213943985013_item	2287997	et	4	main
ent	doc_213943985013_item	2288002	et	3	main
selgeks	doc_213943985013_item	2288012	et	3	main
kultuuriparadoks	doc_213943985013_item	2288017	et	4	main
vigu	doc_213943985013_item	2288022	et	3	main
siis	doc_213943985013_item	2288025	et	3	main
pööra	doc_213943985013_item	2288035	et	4	main
tähelepanu	doc_213943985013_item	2288037	et	4	main
ja	doc_213943985013_item	2288039	et	3	main
seda	doc_213943985013_item	2288041	et	3	main
ja	doc_213943985013_item	2288051	et	3	main
oma	doc_213943985013_item	2288055	et	4	main
siis	doc_213943985013_item	2288060	et	3	main
peetakse	doc_213943985013_item	2288061	et	3	main
seda	doc_213943985013_item	2288062	et	3	main
teoreetilisi	doc_213943985013_item	2288071	et	3	main
eestlastel	doc_213943985013_item	2288103	et	4	main
tšehhidel	doc_213943985013_item	2288105	et	2	main
aga	doc_213943985013_item	2288109	et	3	main
tšehhid	doc_213943985013_item	2288112	et	2	main
erinev	doc_213943985013_item	2288119	et	4	main
kultuuriterritoorium	doc_213943985013_item	2288120	et	3	main
on	doc_213943985013_item	2288123	et	4	main
väärtushinnangud	doc_213943985013_item	2288136	et	3	main
erinevusest	doc_213943985013_item	2288144	et	4	main
keel	doc_213943985013_item	2287941	et	4	main
ja	doc_213943985013_item	2287942	et	3	main
kultuur	doc_213943985013_item	2287943	et	3	main
on	doc_213943985013_item	2287944	et	4	main
on	doc_213943985013_item	2287954	et	4	main
maksa	doc_213943985013_item	2287961	et	4	main
maa	doc_213943985013_item	2287965	et	4	main
teise	doc_213943985013_item	2287976	et	4	main
maa	doc_213943985013_item	2287977	et	4	main
kultuuri	doc_213943985013_item	2287985	et	4	main
raamatud	doc_213943985013_item	2287993	et	4	main
selle	doc_213943985013_item	2287994	et	4	main
ning	doc_213943985013_item	2287998	et	3	main
vaadata	doc_213943985013_item	2287999	et	4	main
olemas	doc_213943985013_item	2288016	et	4	main
seotud	doc_213943985013_item	2287945	et	4	main
kas	doc_213943985013_item	2287946	et	3	main
keel	doc_213943985013_item	2287947	et	4	main
ja	doc_213943985013_item	2287948	et	3	main
kultuur	doc_213943985013_item	2287949	et	3	main
nad	doc_213943985013_item	2287953	et	3	main
seotud	doc_213943985013_item	2287956	et	4	main
seda	doc_213943985013_item	2287958	et	3	main
seost	doc_213943985013_item	2287959	et	3	main
ei	doc_213943985013_item	2287960	et	4	main
tähtis	doc_213943985013_item	2287969	et	4	main
keeleoskus	doc_213943985013_item	2287973	et	3	main
kultuuri	doc_213943985013_item	2287978	et	4	main
mõista	doc_213943985013_item	2287979	et	4	main
ja	doc_213943985013_item	2287980	et	3	main
teise	doc_213943985013_item	2287983	et	4	main
aru	doc_213943985013_item	2287988	et	4	main
maa	doc_213943985013_item	2287995	et	4	main
saateid	doc_213943985013_item	2288001	et	3	main
hea	doc_213943985013_item	2288003	et	4	main
veel	doc_213943985013_item	2288005	et	4	main
ei	doc_213943985013_item	2288006	et	4	main
kõnekäitumist	doc_213943985013_item	2288010	et	3	main
selle	doc_213943985013_item	2288013	et	4	main
tõestamiseks	doc_213943985013_item	2288014	et	4	main
kui	doc_213943985013_item	2288019	et	3	main
ei	doc_213943985013_item	2288034	et	4	main
püüab	doc_213943985013_item	2288040	et	3	main
kui	doc_213943985013_item	2288045	et	3	main
võõrkeele	doc_213943985013_item	2288049	et	4	main
sõnavara	doc_213943985013_item	2288052	et	4	main
käitub	doc_213943985013_item	2288054	et	3	main
maa	doc_213943985013_item	2288056	et	4	main
kultuuri	doc_213943985013_item	2288057	et	4	main
järgi	doc_213943985013_item	2288059	et	4	main
lange	doc_213943985013_item	2288099	et	4	main
alati	doc_213943985013_item	2288100	et	4	main
on	doc_213943985013_item	2288107	et	4	main
teine	doc_213943985013_item	2288121	et	3	main
paremini	doc_213943985013_item	2287987	et	4	main
saada	doc_213943985013_item	2287989	et	4	main
võib	doc_213943985013_item	2287990	et	3	main
lugeda	doc_213943985013_item	2287991	et	3	main
kultuuri	doc_213943985013_item	2288008	et	4	main
ja	doc_213943985013_item	2288009	et	3	main
on	doc_213943985013_item	2288015	et	4	main
näiteks	doc_213943985013_item	2288018	et	4	main
vestluspartner	doc_213943985013_item	2288027	et	3	main
mõistab	doc_213943985013_item	2288028	et	3	main
et	doc_213943985013_item	2288029	et	3	main
on	doc_213943985013_item	2288031	et	4	main
välismaalasega	doc_213943985013_item	2288032	et	3	main
ning	doc_213943985013_item	2288033	et	3	main
grammatikat	doc_213943985013_item	2288050	et	3	main
normide	doc_213943985013_item	2288058	et	3	main
puuduseks	doc_213943985013_item	2288064	et	4	main
teadmisi	doc_213943985013_item	2288072	et	4	main
ei	doc_213943985013_item	2288098	et	4	main
ja	doc_213943985013_item	2288104	et	3	main
väärtushinnangud	doc_213943985013_item	2288106	et	3	main
eestlased	doc_213943985013_item	2288110	et	3	main
venelastel	doc_213943985013_item	2288126	et	4	main
elavad	doc_213943985013_item	2288128	et	4	main
ja	doc_213943985013_item	2288130	et	3	main
venelastel	doc_213943985013_item	2288131	et	4	main
kes	doc_213943985013_item	2288132	et	4	main
elavad	doc_213943985013_item	2288133	et	4	main
eestimaal	doc_213943985013_item	2288134	et	4	main
lääne	doc_213943985016_item	2288388	et	4	main
ja	doc_213943985016_item	2288389	et	3	main
ida	doc_213943985016_item	2288390	et	4	main
kultuuris	doc_213943985016_item	2288421	et	3	main
olemas	doc_213943985016_item	2288423	et	4	main
polegi	doc_213943985016_item	2288432	et	3	main
hoopis	doc_213943985016_item	2288437	et	3	main
mõtteviis	doc_213943985016_item	2288440	et	3	main
kõigepealt	doc_213943985016_item	2288448	et	3	main
tava-	doc_213943985016_item	2288449	et	4	main
absoluutselt	doc_213943985013_item	2288011	et	4	main
kõneleja	doc_213943985013_item	2288020	et	4	main
teeb	doc_213943985013_item	2288021	et	3	main
sellele	doc_213943985013_item	2288038	et	4	main
mitte	doc_213943985013_item	2288042	et	3	main
märgata	doc_213943985013_item	2288043	et	4	main
aga	doc_213943985013_item	2288044	et	3	main
kõneleja	doc_213943985013_item	2288046	et	4	main
valdab	doc_213943985013_item	2288048	et	3	main
ja	doc_213943985013_item	2288053	et	3	main
isikuomaseks	doc_213943985013_item	2288063	et	4	main
teist	doc_213943985013_item	2288066	et	4	main
mõista	doc_213943985013_item	2288068	et	4	main
on	doc_213943985013_item	2288069	et	4	main
kokku	doc_213943985013_item	2288101	et	3	main
näiteks	doc_213943985013_item	2288102	et	4	main
samad	doc_213943985013_item	2288108	et	3	main
ja	doc_213943985013_item	2288111	et	3	main
erinevaid	doc_213943985013_item	2288114	et	4	main
keeli	doc_213943985013_item	2288115	et	4	main
ja	doc_213943985013_item	2288116	et	3	main
neil	doc_213943985013_item	2288117	et	4	main
on	doc_213943985013_item	2288118	et	4	main
näide	doc_213943985013_item	2288122	et	3	main
et	doc_213943985013_item	2288125	et	3	main
kes	doc_213943985013_item	2288127	et	4	main
venemaal	doc_213943985013_item	2288129	et	4	main
on	doc_213943985013_item	2288135	et	4	main
erinevad	doc_213943985013_item	2288137	et	4	main
nii	doc_213943985013_item	2288138	et	3	main
võime	doc_213943985013_item	2288139	et	4	main
rääkida	doc_213943985013_item	2288140	et	3	main
ja	doc_213943985013_item	2288142	et	3	main
kultuuriterritooriumi	doc_213943985013_item	2288143	et	4	main
on	doc_213943985016_item	2288429	et	4	main
ja	doc_213943985016_item	2288431	et	3	main
mõtteviis	doc_213943985016_item	2288435	et	3	main
ida	doc_213943985016_item	2288439	et	4	main
võimalusi	doc_213943985016_item	2288443	et	3	main
see	doc_213943985016_item	2288445	et	3	main
seotud	doc_213943985016_item	2288447	et	4	main
ja	doc_213943985016_item	2288450	et	3	main
siis	doc_213943985016_item	2288456	et	3	main
ka	doc_213943985016_item	2288471	et	3	main
võõrkeele	doc_213943985013_item	2288023	et	4	main
grammatikas	doc_213943985013_item	2288024	et	3	main
tema	doc_213943985013_item	2288026	et	4	main
tegemist	doc_213943985013_item	2288030	et	4	main
erilist	doc_213943985013_item	2288036	et	4	main
hästi	doc_213943985013_item	2288047	et	3	main
et	doc_213943985013_item	2288065	et	3	main
kultuuri	doc_213943985013_item	2288067	et	4	main
vaja	doc_213943985013_item	2288070	et	4	main
ning	doc_213943985013_item	2288073	et	3	main
ka	doc_213943985013_item	2288074	et	3	main
praktikat	doc_213943985013_item	2288075	et	3	main
selleks	doc_213943985013_item	2288076	et	4	main
on	doc_213943985013_item	2288077	et	4	main
vaja	doc_213943985013_item	2288078	et	4	main
suhelda	doc_213943985013_item	2288079	et	4	main
erinevate	doc_213943985013_item	2288080	et	4	main
inimestega	doc_213943985013_item	2288081	et	3	main
sest	doc_213943985013_item	2288082	et	4	main
iga	doc_213943985013_item	2288083	et	4	main
inimeselt	doc_213943985013_item	2288084	et	3	main
võib	doc_213943985013_item	2288085	et	3	main
saada	doc_213943985013_item	2288086	et	4	main
uusi	doc_213943985013_item	2288087	et	3	main
teadmisi	doc_213943985013_item	2288088	et	4	main
keel	doc_213943985013_item	2288089	et	4	main
ja	doc_213943985013_item	2288090	et	3	main
kultuur	doc_213943985013_item	2288091	et	3	main
seotud	doc_213943985013_item	2288093	et	4	main
on	doc_213943985013_item	2288092	et	4	main
kuid	doc_213943985013_item	2288094	et	4	main
keel	doc_213943985013_item	2288095	et	4	main
ja	doc_213943985013_item	2288096	et	3	main
kultuuriterritoorium	doc_213943985013_item	2288097	et	3	main
kõnelevad	doc_213943985013_item	2288113	et	4	main
selline	doc_213943985013_item	2288124	et	4	main
keele	doc_213943985013_item	2288141	et	4	main
essee	doc_213943985016_item	2288387	et	4	main
mõtteviis	doc_213943985016_item	2288391	et	3	main
ning	doc_213943985016_item	2288392	et	3	main
kommunikatsioon	doc_213943985016_item	2288393	et	3	main
juba	doc_213943985016_item	2288394	et	3	main
ammu	doc_213943985016_item	2288395	et	4	main
on	doc_213943985016_item	2288396	et	4	main
teatud	doc_213943985016_item	2288397	et	4	main
et	doc_213943985016_item	2288398	et	3	main
kultuur	doc_213943985016_item	2288399	et	3	main
mõjutab	doc_213943985016_item	2288400	et	3	main
kui	doc_213943985016_item	2288402	et	3	main
inimestele	doc_213943985016_item	2288401	et	3	main
vaatame	doc_213943985016_item	2288403	et	3	main
nüüd	doc_213943985016_item	2288404	et	4	main
lääne	doc_213943985016_item	2288405	et	4	main
ja	doc_213943985016_item	2288406	et	3	main
ida	doc_213943985016_item	2288407	et	4	main
mõtteviisi	doc_213943985016_item	2288408	et	4	main
on	doc_213943985016_item	2288409	et	4	main
selge	doc_213943985016_item	2288410	et	4	main
et	doc_213943985016_item	2288411	et	3	main
on	doc_213943985016_item	2288412	et	4	main
olemas	doc_213943985016_item	2288413	et	4	main
seletavad	doc_213943985016_item	2288414	et	4	main
teooriad	doc_213943985016_item	2288415	et	3	main
mis	doc_213943985016_item	2288416	et	4	main
mõjutavad	doc_213943985016_item	2288417	et	4	main
inimestele	doc_213943985016_item	2288418	et	3	main
ka	doc_213943985016_item	2288419	et	3	main
lääne	doc_213943985016_item	2288420	et	4	main
on	doc_213943985016_item	2288422	et	4	main
absoluutne	doc_213943985016_item	2288424	et	3	main
tõde	doc_213943985016_item	2288425	et	4	main
mis	doc_213943985016_item	2288426	et	4	main
see	doc_213943985016_item	2288428	et	3	main
nii	doc_213943985016_item	2288430	et	3	main
ida	doc_213943985016_item	2288434	et	4	main
teistsugune	doc_213943985016_item	2288438	et	3	main
annab	doc_213943985016_item	2288441	et	3	main
teistmoodi	doc_213943985016_item	2288433	et	3	main
kui	doc_213943985016_item	2288452	et	3	main
ole	doc_213943985016_item	2288459	et	4	main
a	doc_213943985016_item	2288464	et	4	main
on	doc_213943985016_item	2288465	et	4	main
olema	doc_213943985016_item	2288470	et	4	main
jah	doc_213943985016_item	2288476	et	3	main
peab	doc_213943985016_item	2288515	et	4	main
kultuuri	doc_213943985016_item	2288519	et	4	main
tihtipeale	doc_213943985016_item	2288524	et	3	main
3	doc_213943985016_item	2288526	et	2	main
eitada	doc_213943985016_item	2288528	et	3	main
püüda	doc_213943985016_item	2288532	et	3	main
mõista	doc_213943985016_item	2288539	et	4	main
kultuuri	doc_213943985016_item	2288541	et	4	main
teistest	doc_213943985016_item	2288553	et	4	main
väärtustada	doc_213943985016_item	2288555	et	3	main
neid	doc_213943985016_item	2288558	et	4	main
oma	doc_213943985019_item	2288787	et	4	main
eluvaldkond	doc_213943985019_item	2288792	et	3	main
lääne	doc_213943985019_item	2288798	et	4	main
talumise	doc_213943985019_item	2288804	et	4	main
usutakse	doc_213943985019_item	2288812	et	4	main
olemas	doc_213943985019_item	2288815	et	4	main
jätab	doc_213943985019_item	2288821	et	3	main
lahtiseks	doc_213943985019_item	2288824	et	4	main
sügav	doc_213943985019_item	2288825	et	4	main
veelahe	doc_213943985019_item	2288827	et	4	main
eraldab	doc_213943985019_item	2288828	et	3	main
usundid	doc_213943985019_item	2288832	et	3	main
i	doc_213943985019_item	2288836	et	4	main
lääne	doc_213943985020_item	2288841	et	4	main
ei	doc_213943985020_item	2288848	et	4	main
meie	doc_213943985020_item	2288852	et	4	main
igapäevatoiminguid	doc_213943985020_item	2288853	et	3	main
ka	doc_213943985020_item	2288855	et	3	main
oma	doc_213943985020_item	2288859	et	4	main
kultuurides	doc_213943985020_item	2288863	et	3	main
on	doc_213943985020_item	2288866	et	4	main
tõde	doc_213943985020_item	2288869	et	4	main
lääne	doc_213943985020_item	2288870	et	4	main
usundid	doc_213943985020_item	2288871	et	3	main
tõe	doc_213943985020_item	2288874	et	4	main
milleni	doc_213943985020_item	2288876	et	3	main
tõeliselt	doc_213943985020_item	2288879	et	4	main
ida	doc_213943985020_item	2288894	et	4	main
erinevad	doc_213943985020_item	2288897	et	4	main
mõtteviisid	doc_213943985020_item	2288898	et	3	main
on	doc_213943985020_item	2288899	et	4	main
väärtustatakse	doc_213943985016_item	2288427	et	3	main
on	doc_213943985016_item	2288436	et	4	main
rohkem	doc_213943985016_item	2288442	et	4	main
on	doc_213943985016_item	2288446	et	4	main
ei	doc_213943985016_item	2288458	et	4	main
vastupidi	doc_213943985016_item	2288462	et	3	main
tõde	doc_213943985016_item	2288466	et	4	main
siis	doc_213943985016_item	2288467	et	3	main
b	doc_213943985016_item	2288468	et	4	main
nii	doc_213943985016_item	2288478	et	3	main
ei	doc_213943985016_item	2288479	et	4	main
jah	doc_213943985016_item	2288481	et	3	main
mitte	doc_213943985016_item	2288482	et	3	main
ei	doc_213943985016_item	2288483	et	4	main
mitte	doc_213943985016_item	2288484	et	3	main
jah	doc_213943985016_item	2288485	et	3	main
veel	doc_213943985016_item	2288486	et	4	main
mõtteviis	doc_213943985016_item	2288487	et	3	main
enesearendamiseks	doc_213943985016_item	2288488	et	3	main
on	doc_213943985016_item	2288489	et	4	main
konfutsiaanlik	doc_213943985016_item	2288490	et	4	main
dünaamika	doc_213943985016_item	2288491	et	4	main
mis	doc_213943985016_item	2288492	et	4	main
tähendab	doc_213943985016_item	2288493	et	3	main
lühema	doc_213943985016_item	2288494	et	4	main
või	doc_213943985016_item	2288495	et	4	main
pikema	doc_213943985016_item	2288496	et	4	main
aja	doc_213943985016_item	2288497	et	4	main
orienteerimist	doc_213943985016_item	2288498	et	4	main
on	doc_213943985016_item	2288499	et	4	main
olemas	doc_213943985016_item	2288500	et	4	main
ka	doc_213943985016_item	2288501	et	3	main
positiivsed	doc_213943985016_item	2288502	et	3	main
küljed	doc_213943985016_item	2288503	et	3	main
nii	doc_213943985016_item	2288504	et	3	main
lääne	doc_213943985016_item	2288505	et	4	main
kui	doc_213943985016_item	2288506	et	3	main
ka	doc_213943985016_item	2288507	et	3	main
ida	doc_213943985016_item	2288508	et	4	main
mõtteviisis	doc_213943985016_item	2288509	et	3	main
et	doc_213943985016_item	2288510	et	3	main
saavutada	doc_213943985016_item	2288511	et	3	main
enesearendamiseks	doc_213943985016_item	2288444	et	3	main
rituaaliga	doc_213943985016_item	2288451	et	3	main
on	doc_213943985016_item	2288454	et	4	main
tõde	doc_213943985016_item	2288460	et	4	main
peab	doc_213943985016_item	2288469	et	4	main
mõtteviisis	doc_213943985016_item	2288473	et	3	main
ei	doc_213943985016_item	2288477	et	4	main
kui	doc_213943985016_item	2288480	et	3	main
edu	doc_213943985016_item	2288512	et	4	main
austama	doc_213943985016_item	2288517	et	3	main
mis	doc_213943985016_item	2288523	et	4	main
kultuuri	doc_213943985016_item	2288530	et	4	main
vaid	doc_213943985016_item	2288531	et	3	main
teada	doc_213943985016_item	2288534	et	3	main
nendest	doc_213943985016_item	2288536	et	4	main
5	doc_213943985016_item	2288542	et	2	main
väärtustada	doc_213943985016_item	2288543	et	3	main
hädavajalikud	doc_213943985016_item	2288548	et	3	main
teada	doc_213943985016_item	2288551	et	3	main
austada	doc_213943985016_item	2288557	et	3	main
niimoodi	doc_213943985016_item	2288560	et	3	main
olla	doc_213943985016_item	2288564	et	3	main
mida	doc_213943985019_item	2288785	et	4	main
seletamiseks	doc_213943985019_item	2288789	et	4	main
kultuuri	doc_213943985019_item	2288794	et	4	main
tõusis	doc_213943985019_item	2288801	et	4	main
kultuurides	doc_213943985019_item	2288811	et	3	main
a	doc_213943985016_item	2288453	et	4	main
tõde	doc_213943985016_item	2288455	et	4	main
b	doc_213943985016_item	2288457	et	4	main
või	doc_213943985016_item	2288461	et	4	main
kui	doc_213943985016_item	2288463	et	3	main
ida	doc_213943985016_item	2288472	et	4	main
olemas	doc_213943985016_item	2288475	et	4	main
inimene	doc_213943985016_item	2288514	et	3	main
2	doc_213943985016_item	2288520	et	2	main
hoiduda	doc_213943985016_item	2288521	et	3	main
4	doc_213943985016_item	2288537	et	2	main
teisi	doc_213943985016_item	2288540	et	4	main
tingimused	doc_213943985016_item	2288546	et	3	main
kultuuridest	doc_213943985016_item	2288554	et	3	main
ja	doc_213943985016_item	2288556	et	3	main
on	doc_213943985016_item	2288474	et	4	main
1	doc_213943985016_item	2288516	et	2	main
kultuuris	doc_213943985016_item	2288513	et	3	main
teisi	doc_213943985016_item	2288518	et	4	main
segavad	doc_213943985016_item	2288525	et	4	main
teisi	doc_213943985016_item	2288529	et	4	main
õppida	doc_213943985016_item	2288538	et	3	main
neid	doc_213943985016_item	2288544	et	4	main
on	doc_213943985016_item	2288547	et	4	main
et	doc_213943985016_item	2288549	et	3	main
saada	doc_213943985016_item	2288552	et	4	main
inimene	doc_213943985016_item	2288561	et	3	main
võib	doc_213943985016_item	2288562	et	3	main
kultuuris	doc_213943985016_item	2288565	et	3	main
stereotüüpidest	doc_213943985016_item	2288522	et	3	main
mitte	doc_213943985016_item	2288527	et	3	main
rohkem	doc_213943985016_item	2288533	et	4	main
saada	doc_213943985016_item	2288535	et	4	main
need	doc_213943985016_item	2288545	et	3	main
rohkem	doc_213943985016_item	2288550	et	4	main
ainult	doc_213943985016_item	2288559	et	4	main
edukas	doc_213943985016_item	2288563	et	4	main
arendame	doc_213943985019_item	2288786	et	3	main
väljas	doc_213943985019_item	2288797	et	4	main
ebakindluse	doc_213943985019_item	2288803	et	4	main
probleem	doc_213943985019_item	2288805	et	3	main
pühenduvad	doc_213943985019_item	2288807	et	4	main
essee	doc_213943985019_item	2288778	et	4	main
kultuur	doc_213943985019_item	2288779	et	3	main
ei	doc_213943985019_item	2288780	et	4	main
mõjuta	doc_213943985019_item	2288781	et	4	main
ainult	doc_213943985019_item	2288782	et	4	main
igapäevatoimingud	doc_213943985019_item	2288783	et	3	main
vaid	doc_213943985019_item	2288784	et	3	main
mitte	doc_213943985019_item	2288790	et	3	main
küsitlusest	doc_213943985019_item	2288800	et	4	main
tõe	doc_213943985019_item	2288808	et	4	main
otsimisele	doc_213943985019_item	2288809	et	4	main
on	doc_213943985019_item	2288814	et	4	main
tõde	doc_213943985019_item	2288817	et	4	main
konfutsiaanlik	doc_213943985019_item	2288818	et	4	main
küsimuse	doc_213943985019_item	2288822	et	4	main
tõest	doc_213943985019_item	2288823	et	4	main
pakuvad	doc_213943985019_item	2288837	et	3	main
ja	doc_213943985020_item	2288842	et	3	main
mõtteviis	doc_213943985020_item	2288844	et	3	main
mõjuta	doc_213943985020_item	2288849	et	4	main
teooriaid	doc_213943985020_item	2288856	et	3	main
usutakse	doc_213943985020_item	2288864	et	4	main
vaid	doc_213943985020_item	2288878	et	3	main
siis	doc_213943985020_item	2288881	et	3	main
erinevaid	doc_213943985020_item	2288887	et	4	main
enesearendamisvõimalusi	doc_213943985020_item	2288888	et	4	main
lääne	doc_213943985020_item	2288889	et	4	main
mõtteviis	doc_213943985020_item	2288890	et	3	main
mõtteviis	doc_213943985020_item	2288895	et	3	main
seotud	doc_213943985020_item	2288900	et	4	main
väärtusest	doc_213943985020_item	2288909	et	4	main
uskumusest	doc_213943985020_item	2288911	et	4	main
elutavasid	doc_213943985020_item	2288918	et	3	main
suhtlemine	doc_213943985020_item	2288934	et	4	main
oleks	doc_213943985020_item	2288935	et	3	main
tolerantne	doc_213943985020_item	2288946	et	3	main
ja	doc_213943985020_item	2288948	et	3	main
hoidakse	doc_213943985020_item	2288951	et	4	main
kas	doc_213943985022_item	2289058	et	3	main
kultuur	doc_213943985022_item	2289061	et	3	main
ei	doc_213943985022_item	2289068	et	4	main
inglise	doc_213943985022_item	2289096	et	4	main
keelt	doc_213943985022_item	2289097	et	4	main
see	doc_213943985022_item	2289098	et	3	main
mul	doc_213943985022_item	2289105	et	3	main
on	doc_213943985022_item	2289111	et	4	main
loomulikult	doc_213943985022_item	2289118	et	4	main
võin	doc_213943985022_item	2289127	et	3	main
on	doc_213943985022_item	2289138	et	4	main
üks	doc_213943985022_item	2289139	et	3	main
aga	doc_213943985022_item	2289146	et	3	main
ole	doc_213943985022_item	2289149	et	4	main
siis	doc_213943985022_item	2289151	et	3	main
keeleoskused	doc_213943985022_item	2289153	et	3	main
on	doc_213943985022_item	2289154	et	4	main
tühjad	doc_213943985022_item	2289155	et	3	main
areneb	doc_213943985022_item	2289159	et	3	main
inimene	doc_213943985022_item	2289161	et	3	main
arenema	doc_213943985022_item	2289163	et	3	main
alati	doc_213943985022_item	2289230	et	4	main
seda	doc_213943985022_item	2289232	et	3	main
kõik	doc_213943985022_item	2289234	et	4	main
näiteks	doc_213943985022_item	2289235	et	4	main
tegude	doc_213943985019_item	2288788	et	3	main
ükski	doc_213943985019_item	2288791	et	4	main
pole	doc_213943985019_item	2288793	et	3	main
mõju	doc_213943985019_item	2288795	et	4	main
alt	doc_213943985019_item	2288796	et	4	main
mõtteviisile	doc_213943985019_item	2288799	et	3	main
esile	doc_213943985019_item	2288802	et	3	main
kultuurid	doc_213943985019_item	2288806	et	3	main
et	doc_213943985019_item	2288813	et	3	main
aja	doc_213943985019_item	2288819	et	4	main
ja	doc_213943985019_item	2288830	et	3	main
l	doc_213943985019_item	2288833	et	4	main
erinevaid	doc_213943985019_item	2288838	et	4	main
mitte	doc_213943985020_item	2288850	et	3	main
ainult	doc_213943985020_item	2288851	et	4	main
mida	doc_213943985020_item	2288857	et	4	main
tegude	doc_213943985020_item	2288860	et	3	main
sellise	doc_213943985020_item	2288873	et	4	main
olemasolul	doc_213943985020_item	2288875	et	3	main
jõuavad	doc_213943985020_item	2288877	et	4	main
usklikud	doc_213943985020_item	2288880	et	3	main
on	doc_213943985020_item	2288891	et	4	main
on	doc_213943985020_item	2288905	et	4	main
iga	doc_213943985020_item	2288912	et	4	main
oma	doc_213943985020_item	2288915	et	4	main
ja	doc_213943985020_item	2288917	et	3	main
näiteks	doc_213943985020_item	2288919	et	4	main
mõtteviis	doc_213943985020_item	2288921	et	3	main
et	doc_213943985020_item	2288930	et	3	main
austada	doc_213943985020_item	2288941	et	3	main
teist	doc_213943985020_item	2288942	et	4	main
kultuuri	doc_213943985020_item	2288943	et	4	main
olla	doc_213943985020_item	2288945	et	3	main
ja	doc_213943985020_item	2288950	et	3	main
on	doc_213943985022_item	2289056	et	4	main
ja	doc_213943985022_item	2289060	et	3	main
seotud	doc_213943985022_item	2289063	et	4	main
kahtlemata	doc_213943985022_item	2289064	et	4	main
jah	doc_213943985022_item	2289065	et	3	main
aga	doc_213943985022_item	2289066	et	3	main
me	doc_213943985022_item	2289067	et	4	main
saa	doc_213943985022_item	2289069	et	4	main
tähenda	doc_213943985022_item	2289100	et	4	main
harjumused	doc_213943985022_item	2289109	et	4	main
isamaa	doc_213943985022_item	2289115	et	4	main
on	doc_213943985022_item	2289116	et	4	main
head	doc_213943985022_item	2289119	et	4	main
ise	doc_213943985022_item	2289128	et	4	main
ja	doc_213943985022_item	2289131	et	3	main
mul	doc_213943985022_item	2289147	et	3	main
kui	doc_213943985022_item	2289165	et	3	main
see	doc_213943985022_item	2289170	et	3	main
on	doc_213943985022_item	2289175	et	4	main
võimalusi	doc_213943985022_item	2289177	et	3	main
maailma	doc_213943985022_item	2289178	et	4	main
mida	doc_213943985022_item	2289180	et	4	main
suheldakse	doc_213943985022_item	2289183	et	3	main
multikultuuriline	doc_213943985022_item	2289239	et	4	main
kujutage	doc_213943985022_item	2289249	et	3	main
kultuuri	doc_213943985022_item	2289258	et	4	main
võrreldes	doc_213943985022_item	2289259	et	3	main
erinevatest	doc_213943985022_item	2289280	et	4	main
keskkonnale	doc_213943985022_item	2289287	et	3	main
eesti	doc_213943985022_item	2289288	et	4	main
vene	doc_213943985022_item	2289291	et	4	main
elada	doc_213943985022_item	2289298	et	3	main
elavad	doc_213943985022_item	2289305	et	4	main
loomulikult	doc_213943985022_item	2289314	et	4	main
võime	doc_213943985022_item	2289315	et	4	main
nendes	doc_213943985019_item	2288810	et	4	main
absoluutne	doc_213943985019_item	2288816	et	3	main
orientatsioon	doc_213943985019_item	2288820	et	3	main
l	doc_213943985019_item	2288829	et	4	main
essee	doc_213943985020_item	2288840	et	4	main
ida	doc_213943985020_item	2288843	et	4	main
ning	doc_213943985020_item	2288845	et	3	main
kultuur	doc_213943985020_item	2288847	et	3	main
arendame	doc_213943985020_item	2288858	et	3	main
seletamiseks	doc_213943985020_item	2288861	et	4	main
ida	doc_213943985020_item	2288882	et	4	main
pakuvad	doc_213943985020_item	2288884	et	3	main
inimesele	doc_213943985020_item	2288885	et	3	main
analüüsivaks	doc_213943985020_item	2288893	et	4	main
sünteesivaks	doc_213943985020_item	2288896	et	4	main
käitumine	doc_213943985020_item	2288904	et	4	main
filosoofiline	doc_213943985019_item	2288826	et	4	main
i	doc_213943985019_item	2288831	et	4	main
tõde	doc_213943985019_item	2288834	et	4	main
olemasolu	doc_213943985019_item	2288835	et	4	main
enesearendamisvõimalusi	doc_213943985019_item	2288839	et	4	main
kommunikatsioon	doc_213943985020_item	2288846	et	3	main
vaid	doc_213943985020_item	2288854	et	3	main
läänes	doc_213943985020_item	2288862	et	4	main
et	doc_213943985020_item	2288865	et	3	main
olemas	doc_213943985020_item	2288867	et	4	main
absoluutne	doc_213943985020_item	2288868	et	3	main
põhinevad	doc_213943985020_item	2288872	et	4	main
usundid	doc_213943985020_item	2288883	et	3	main
pigem	doc_213943985020_item	2288886	et	3	main
pigem	doc_213943985020_item	2288892	et	3	main
erineva	doc_213943985020_item	2288901	et	4	main
käitumisega	doc_213943985020_item	2288902	et	4	main
kultuurisest	doc_213943985020_item	2288907	et	4	main
kultuur	doc_213943985020_item	2288913	et	3	main
rituaalid	doc_213943985020_item	2288916	et	3	main
lääne	doc_213943985020_item	2288920	et	4	main
konfliktne	doc_213943985020_item	2288924	et	4	main
agressivne	doc_213943985020_item	2288926	et	4	main
meie	doc_213943985020_item	2288931	et	4	main
ja	doc_213943985020_item	2288933	et	3	main
mõnus	doc_213943985020_item	2288936	et	4	main
ja	doc_213943985020_item	2288937	et	3	main
sõbralik	doc_213943985020_item	2288938	et	3	main
me	doc_213943985020_item	2288939	et	4	main
peame	doc_213943985020_item	2288940	et	4	main
kannatlik	doc_213943985020_item	2288949	et	3	main
stereotüüpidest	doc_213943985020_item	2288952	et	3	main
iga	doc_213943985020_item	2288903	et	4	main
mõjutanud	doc_213943985020_item	2288906	et	4	main
enesestmõistetavuset	doc_213943985020_item	2288908	et	4	main
ja	doc_213943985020_item	2288910	et	3	main
on	doc_213943985020_item	2288914	et	4	main
on	doc_213943985020_item	2288922	et	4	main
pigem	doc_213943985020_item	2288923	et	3	main
ja	doc_213943985020_item	2288925	et	3	main
me	doc_213943985020_item	2288928	et	4	main
tahame	doc_213943985020_item	2288929	et	3	main
kommunikatsioon	doc_213943985020_item	2288932	et	3	main
visa	doc_213943985020_item	2288947	et	4	main
seotud	doc_213943985022_item	2289057	et	4	main
ma	doc_213943985022_item	2289102	et	3	main
inglismaalane	doc_213943985022_item	2289104	et	3	main
ole	doc_213943985022_item	2289107	et	4	main
olemas	doc_213943985022_item	2289112	et	4	main
kellel	doc_213943985022_item	2289114	et	4	main
parema	doc_213943985022_item	2289122	et	4	main
ma	doc_213943985022_item	2289126	et	3	main
näiteks	doc_213943985022_item	2289141	et	4	main
tean	doc_213943985022_item	2289144	et	3	main
igal	doc_213943985022_item	2289156	et	3	main
inimene	doc_213943985022_item	2289166	et	3	main
sest	doc_213943985022_item	2289173	et	4	main
rohkem	doc_213943985022_item	2289176	et	4	main
inimestega	doc_213943985022_item	2289182	et	3	main
tingitud	doc_213943985022_item	2289188	et	4	main
jooni	doc_213943985022_item	2289189	et	4	main
kui	doc_213943985020_item	2288927	et	3	main
esindajad	doc_213943985020_item	2288944	et	4	main
keel	doc_213943985022_item	2289059	et	4	main
rääkida	doc_213943985022_item	2289070	et	3	main
et	doc_213943985022_item	2289071	et	3	main
nad	doc_213943985022_item	2289072	et	3	main
on	doc_213943985022_item	2289073	et	4	main
sarnased	doc_213943985022_item	2289074	et	4	main
nendel	doc_213943985022_item	2289075	et	4	main
on	doc_213943985022_item	2289076	et	4	main
palju	doc_213943985022_item	2289077	et	4	main
erinevusi	doc_213943985022_item	2289078	et	4	main
kui	doc_213943985022_item	2289079	et	3	main
me	doc_213943985022_item	2289080	et	4	main
valdame	doc_213943985022_item	2289081	et	3	main
keelt	doc_213943985022_item	2289082	et	4	main
see	doc_213943985022_item	2289083	et	3	main
ei	doc_213943985022_item	2289084	et	4	main
tähenda	doc_213943985022_item	2289085	et	4	main
et	doc_213943985022_item	2289086	et	3	main
me	doc_213943985022_item	2289087	et	4	main
teame	doc_213943985022_item	2289088	et	3	main
kultuuri	doc_213943985022_item	2289089	et	4	main
ja	doc_213943985022_item	2289090	et	3	main
traditsioone	doc_213943985022_item	2289091	et	3	main
näiteks	doc_213943985022_item	2289092	et	4	main
kui	doc_213943985022_item	2289093	et	3	main
ma	doc_213943985022_item	2289094	et	3	main
oskan	doc_213943985022_item	2289095	et	3	main
essee	doc_213943985022_item	2289051	et	4	main
kas	doc_213943985022_item	2289052	et	3	main
keel	doc_213943985022_item	2289053	et	4	main
ja	doc_213943985022_item	2289054	et	3	main
kultuur	doc_213943985022_item	2289055	et	3	main
on	doc_213943985022_item	2289062	et	4	main
ei	doc_213943985022_item	2289099	et	4	main
millised	doc_213943985022_item	2289110	et	3	main
suurbritania	doc_213943985022_item	2289117	et	4	main
et	doc_213943985022_item	2289101	et	3	main
olen	doc_213943985022_item	2289103	et	3	main
ei	doc_213943985022_item	2289106	et	4	main
niisugused	doc_213943985022_item	2289108	et	3	main
inimestel	doc_213943985022_item	2289113	et	3	main
oskused	doc_213943985022_item	2289120	et	3	main
avavad	doc_213943985022_item	2289121	et	4	main
võimaluse	doc_213943985022_item	2289123	et	3	main
kultuuri	doc_213943985022_item	2289125	et	4	main
tundma	doc_213943985022_item	2289133	et	3	main
kultuuri	doc_213943985022_item	2289135	et	4	main
veel	doc_213943985022_item	2289137	et	4	main
asi	doc_213943985022_item	2289140	et	4	main
ma	doc_213943985022_item	2289143	et	3	main
keelt	doc_213943985022_item	2289145	et	4	main
minu	doc_213943985022_item	2289152	et	3	main
päeval	doc_213943985022_item	2289157	et	3	main
keel	doc_213943985022_item	2289158	et	4	main
peab	doc_213943985022_item	2289162	et	4	main
temaga	doc_213943985022_item	2289164	et	3	main
mõne	doc_213943985022_item	2289168	et	3	main
temal	doc_213943985022_item	2289174	et	3	main
tunda	doc_213943985022_item	2289179	et	3	main
kergemini	doc_213943985022_item	2289185	et	4	main
kultuurist	doc_213943985022_item	2289187	et	3	main
iseloom	doc_213943985022_item	2289222	et	3	main
kultuurile	doc_213943985022_item	2289224	et	3	main
ja	doc_213943985022_item	2289226	et	3	main
ei	doc_213943985022_item	2289228	et	4	main
lange	doc_213943985022_item	2289229	et	4	main
kokku	doc_213943985022_item	2289231	et	3	main
ameerika	doc_213943985022_item	2289236	et	3	main
riik	doc_213943985022_item	2289241	et	3	main
umbes	doc_213943985022_item	2289245	et	4	main
inimestel	doc_213943985022_item	2289252	et	3	main
samad	doc_213943985022_item	2289275	et	3	main
räägivad	doc_213943985022_item	2289279	et	3	main
soome-ugri	doc_213943985022_item	2289289	et	3	main
aga	doc_213943985022_item	2289290	et	3	main
kõige	doc_213943985022_item	2289294	et	4	main
õppima	doc_213943985022_item	2289297	et	3	main
kes	doc_213943985022_item	2289307	et	4	main
teha	doc_213943985022_item	2289316	et	3	main
riik	doc_213943985022_item	2289318	et	3	main
kolmekeelne	doc_213943985022_item	2289321	et	3	main
sel	doc_213943985022_item	2289328	et	3	main
harjuma	doc_213943985022_item	2289336	et	3	main
kui	doc_213943985022_item	2289342	et	3	main
tema	doc_213943985022_item	2289350	et	4	main
haritud	doc_213943985022_item	2289352	et	4	main
essee	doc_213943985023_item	2289359	et	4	main
kas	doc_213943985023_item	2289360	et	3	main
ja	doc_213943985023_item	2289362	et	3	main
on	doc_213943985023_item	2289364	et	4	main
seotud	doc_213943985023_item	2289365	et	4	main
kultuur	doc_213943985023_item	2289368	et	3	main
kahtlemata	doc_213943985023_item	2289370	et	4	main
hea	doc_213943985023_item	2289372	et	4	main
keeleoskusega	doc_213943985023_item	2289373	et	3	main
me	doc_213943985023_item	2289374	et	4	main
keel	doc_213943985023_item	2289380	et	4	main
meile	doc_213943985023_item	2289382	et	4	main
aktiivselt	doc_213943985023_item	2289423	et	4	main
keel	doc_213943985023_item	2289425	et	4	main
keel	doc_213943985023_item	2289436	et	4	main
tea	doc_213943985023_item	2289447	et	4	main
venemaal	doc_213943985023_item	2289461	et	4	main
rääkida	doc_213943985023_item	2289463	et	3	main
prantslastest	doc_213943985023_item	2289470	et	3	main
oma	doc_213943985023_item	2289472	et	4	main
kui	doc_213943985023_item	2289478	et	3	main
on	doc_213943985023_item	2289482	et	4	main
sugukeel	doc_213943985023_item	2289494	et	4	main
üks	doc_213943985023_item	2289500	et	3	main
tatarstanis	doc_213943985023_item	2289505	et	4	main
on	doc_213943985023_item	2289508	et	4	main
tundma	doc_213943985022_item	2289124	et	3	main
minna	doc_213943985022_item	2289129	et	3	main
välismaale	doc_213943985022_item	2289130	et	4	main
seal	doc_213943985022_item	2289132	et	4	main
teiste	doc_213943985022_item	2289134	et	4	main
aga	doc_213943985022_item	2289136	et	3	main
kui	doc_213943985022_item	2289142	et	3	main
ei	doc_213943985022_item	2289148	et	4	main
praktikat	doc_213943985022_item	2289150	et	3	main
ja	doc_213943985022_item	2289160	et	3	main
valdab	doc_213943985022_item	2289167	et	3	main
keeli	doc_213943985022_item	2289169	et	4	main
on	doc_213943985022_item	2289171	et	4	main
tore	doc_213943985022_item	2289172	et	3	main
erinevamate	doc_213943985022_item	2289181	et	4	main
seda	doc_213943985022_item	2289184	et	3	main
märgatakse	doc_213943985022_item	2289186	et	3	main
näiteks	doc_213943985022_item	2289190	et	4	main
eestimaal	doc_213943985022_item	2289191	et	4	main
ma	doc_213943985022_item	2289192	et	3	main
suhtlen	doc_213943985022_item	2289193	et	3	main
nii	doc_213943985022_item	2289194	et	3	main
eestlastele	doc_213943985022_item	2289195	et	4	main
kui	doc_213943985022_item	2289196	et	3	main
ka	doc_213943985022_item	2289197	et	3	main
venelastele	doc_213943985022_item	2289198	et	4	main
ja	doc_213943985022_item	2289199	et	3	main
ma	doc_213943985022_item	2289200	et	3	main
näen	doc_213943985022_item	2289201	et	3	main
et	doc_213943985022_item	2289202	et	3	main
on	doc_213943985022_item	2289203	et	4	main
olemas	doc_213943985022_item	2289204	et	4	main
palju	doc_213943985022_item	2289205	et	4	main
erinevusi	doc_213943985022_item	2289206	et	4	main
eestlased	doc_213943985022_item	2289207	et	3	main
on	doc_213943985022_item	2289208	et	4	main
aeglasemad	doc_213943985022_item	2289209	et	4	main
kannatlikud	doc_213943985022_item	2289210	et	3	main
aga	doc_213943985022_item	2289211	et	3	main
venelased	doc_213943985022_item	2289212	et	3	main
avalikkud	doc_213943985022_item	2289213	et	4	main
liiga	doc_213943985022_item	2289214	et	4	main
kiirevad	doc_213943985022_item	2289215	et	4	main
see	doc_213943985022_item	2289216	et	3	main
on	doc_213943985022_item	2289217	et	4	main
ju	doc_213943985022_item	2289218	et	3	main
iseloomu	doc_213943985022_item	2289219	et	4	main
erinevused	doc_213943985022_item	2289220	et	4	main
aga	doc_213943985022_item	2289221	et	3	main
mõjub	doc_213943985022_item	2289223	et	3	main
keel	doc_213943985022_item	2289225	et	4	main
kultuuriterritorium	doc_213943985022_item	2289227	et	4	main
multicultural	doc_213943985022_item	2289240	et	4	main
väikel	doc_213943985022_item	2289242	et	4	main
eestimal	doc_213943985022_item	2289243	et	4	main
on	doc_213943985022_item	2289244	et	4	main
ette	doc_213943985022_item	2289250	et	4	main
aga	doc_213943985022_item	2289251	et	3	main
on	doc_213943985022_item	2289253	et	4	main
hea	doc_213943985022_item	2289255	et	4	main
kultuuride	doc_213943985022_item	2289260	et	3	main
ajalugu	doc_213943985022_item	2289261	et	4	main
võime	doc_213943985022_item	2289262	et	4	main
nende	doc_213943985022_item	2289264	et	4	main
rääkida	doc_213943985022_item	2289263	et	3	main
sarnasust	doc_213943985022_item	2289265	et	4	main
ja	doc_213943985022_item	2289266	et	3	main
erinevust	doc_213943985022_item	2289267	et	4	main
näiteks	doc_213943985022_item	2289268	et	4	main
eestlastel	doc_213943985022_item	2289269	et	4	main
ja	doc_213943985022_item	2289270	et	3	main
tšehhidel	doc_213943985022_item	2289271	et	2	main
teavad	doc_213943985022_item	2289233	et	3	main
on	doc_213943985022_item	2289238	et	4	main
olemas	doc_213943985022_item	2289254	et	4	main
võimalus	doc_213943985022_item	2289256	et	3	main
uurida	doc_213943985022_item	2289257	et	3	main
on	doc_213943985022_item	2289272	et	4	main
ja	doc_213943985022_item	2289274	et	3	main
aga	doc_213943985022_item	2289277	et	3	main
slaavi	doc_213943985022_item	2289292	et	3	main
teise	doc_213943985022_item	2289300	et	4	main
paljudel	doc_213943985022_item	2289303	et	3	main
riikil	doc_213943985022_item	2289304	et	4	main
tea	doc_213943985022_item	2289309	et	4	main
probleem	doc_213943985022_item	2289313	et	3	main
aga	doc_213943985022_item	2289322	et	3	main
ei	doc_213943985022_item	2289324	et	4	main
peab	doc_213943985022_item	2289335	et	4	main
teiste	doc_213943985022_item	2289339	et	4	main
ta	doc_213943985022_item	2289345	et	4	main
et	doc_213943985022_item	2289349	et	3	main
on	doc_213943985022_item	2289351	et	4	main
kes	doc_213943985022_item	2289354	et	4	main
kultuuri	doc_213943985022_item	2289358	et	4	main
keel	doc_213943985023_item	2289361	et	4	main
kultuur	doc_213943985023_item	2289363	et	3	main
keel	doc_213943985023_item	2289366	et	4	main
ja	doc_213943985023_item	2289367	et	3	main
on	doc_213943985023_item	2289369	et	4	main
selle	doc_213943985023_item	2289377	et	4	main
tahame	doc_213943985023_item	2289390	et	3	main
kui	doc_213943985023_item	2289421	et	3	main
lange	doc_213943985023_item	2289430	et	4	main
on	doc_213943985023_item	2289437	et	4	main
venelaste	doc_213943985023_item	2289442	et	4	main
olla	doc_213943985023_item	2289449	et	3	main
on	doc_213943985023_item	2289450	et	4	main
erinevused	doc_213943985023_item	2289452	et	4	main
aga	doc_213943985023_item	2289453	et	3	main
ka	doc_213943985023_item	2289460	et	3	main
näiteks	doc_213943985023_item	2289464	et	4	main
kaua	doc_213943985023_item	2289465	et	3	main
eestis	doc_213943985023_item	2289466	et	3	main
elavatest	doc_213943985023_item	2289467	et	4	main
nende	doc_213943985023_item	2289479	et	4	main
on	doc_213943985023_item	2289488	et	4	main
teistsugune	doc_213943985023_item	2289489	et	3	main
keele	doc_213943985023_item	2289496	et	4	main
nende	doc_213943985023_item	2289511	et	4	main
oma	doc_213943985023_item	2289512	et	4	main
paganausk	doc_213943985023_item	2289513	et	3	main
kui	doc_213943985023_item	2289514	et	3	main
ning	doc_213943985024_item	2289527	et	3	main
on	doc_213943985024_item	2289555	et	4	main
loogikast	doc_213943985024_item	2289557	et	4	main
ei	doc_213943985024_item	2289563	et	4	main
tööta	doc_213943985024_item	2289568	et	4	main
a	doc_213943985024_item	2289573	et	4	main
ei	doc_213943985024_item	2289574	et	4	main
läänemast	doc_213943985024_item	2289581	et	3	main
idamast	doc_213943985024_item	2289583	et	3	main
aga	doc_213943985024_item	2289590	et	3	main
meie	doc_213943985024_item	2289593	et	4	main
mõtteviis	doc_213943985025_item	2289599	et	3	main
kultuur	doc_213943985025_item	2289602	et	3	main
meie	doc_213943985025_item	2289607	et	4	main
igapäevatoiminguid	doc_213943985025_item	2289608	et	3	main
tõe	doc_213943985025_item	2289639	et	4	main
ida	doc_213943985025_item	2289645	et	4	main
kultuur	doc_213943985025_item	2289667	et	3	main
erinevad	doc_213943985025_item	2289678	et	4	main
ida	doc_213943985025_item	2289682	et	4	main
kultuur	doc_213943985026_item	2289691	et	3	main
keel	doc_213943985026_item	2289694	et	4	main
hea	doc_213943985026_item	2289700	et	4	main
keeloskusega	doc_213943985026_item	2289701	et	3	main
saaks	doc_213943985026_item	2289702	et	3	main
on	doc_213943985026_item	2289709	et	4	main
tihti	doc_213943985026_item	2289713	et	3	main
ühendriigid	doc_213943985022_item	2289237	et	3	main
106	doc_213943985022_item	2289246	et	2	main
erinevad	doc_213943985022_item	2289247	et	4	main
kultuuriesindajad	doc_213943985022_item	2289248	et	3	main
ühed	doc_213943985022_item	2289273	et	3	main
keeltest	doc_213943985022_item	2289281	et	4	main
keeled	doc_213943985022_item	2289283	et	3	main
kuuluvad	doc_213943985022_item	2289284	et	4	main
erinevatele	doc_213943985022_item	2289286	et	4	main
keel	doc_213943985022_item	2289293	et	4	main
tänapäeval	doc_213943985022_item	2289296	et	3	main
kultuuri	doc_213943985022_item	2289301	et	4	main
sees	doc_213943985022_item	2289302	et	4	main
on	doc_213943985022_item	2289312	et	4	main
või	doc_213943985022_item	2289319	et	4	main
isegi	doc_213943985022_item	2289320	et	4	main
inimesed	doc_213943985022_item	2289323	et	3	main
näiteks	doc_213943985022_item	2289331	et	4	main
keele	doc_213943985022_item	2289338	et	4	main
kultuuriga	doc_213943985022_item	2289340	et	4	main
aga	doc_213943985022_item	2289341	et	3	main
ta	doc_213943985022_item	2289343	et	4	main
harjub	doc_213943985022_item	2289344	et	3	main
keelt	doc_213943985022_item	2289356	et	4	main
teada	doc_213943985023_item	2289376	et	3	main
maa	doc_213943985023_item	2289378	et	4	main
avab	doc_213943985023_item	2289381	et	3	main
kultuuri	doc_213943985023_item	2289384	et	4	main
rääkida	doc_213943985023_item	2289386	et	3	main
suhelda	doc_213943985023_item	2289424	et	4	main
ja	doc_213943985023_item	2289426	et	3	main
territoorium	doc_213943985023_item	2289428	et	3	main
eriti	doc_213943985023_item	2289431	et	3	main
kokku	doc_213943985023_item	2289432	et	3	main
eestis	doc_213943985023_item	2289433	et	3	main
erinev	doc_213943985023_item	2289438	et	4	main
keel	doc_213943985023_item	2289443	et	4	main
sellest	doc_213943985023_item	2289444	et	4	main
ma	doc_213943985023_item	2289445	et	3	main
vene	doc_213943985023_item	2289454	et	4	main
on	doc_213943985023_item	2289456	et	4	main
samasugune	doc_213943985023_item	2289457	et	3	main
japanlastest	doc_213943985023_item	2289468	et	4	main
ei	doc_213943985023_item	2289476	et	4	main
nende	doc_213943985023_item	2289490	et	4	main
keel	doc_213943985023_item	2289491	et	4	main
ei	doc_213943985023_item	2289492	et	4	main
jaoks	doc_213943985023_item	2289497	et	4	main
keelest	doc_213943985023_item	2289502	et	4	main
udmurdidel	doc_213943985023_item	2289507	et	4	main
olemas	doc_213943985023_item	2289509	et	4	main
venemaal	doc_213943985023_item	2289515	et	4	main
kommunikatsioon	doc_213943985024_item	2289528	et	3	main
kultuur	doc_213943985024_item	2289529	et	3	main
ainult	doc_213943985024_item	2289533	et	4	main
kuidas	doc_213943985024_item	2289537	et	3	main
kuidas	doc_213943985024_item	2289540	et	3	main
erinevases	doc_213943985024_item	2289556	et	4	main
et	doc_213943985024_item	2289560	et	3	main
b	doc_213943985024_item	2289566	et	4	main
arvan	doc_213943985024_item	2289570	et	3	main
võib	doc_213943985024_item	2289579	et	3	main
ja	doc_213943985024_item	2289582	et	3	main
erinevus	doc_213943985024_item	2289585	et	4	main
kultuur	doc_213943985024_item	2289591	et	3	main
ning	doc_213943985025_item	2289600	et	3	main
mõjuta	doc_213943985025_item	2289604	et	4	main
ainult	doc_213943985025_item	2289606	et	4	main
inimestel	doc_213943985025_item	2289625	et	3	main
elavad	doc_213943985025_item	2289627	et	4	main
läänes	doc_213943985025_item	2289628	et	4	main
on	doc_213943985025_item	2289629	et	4	main
arendamiseks	doc_213943985025_item	2289635	et	4	main
usundid	doc_213943985025_item	2289636	et	3	main
põhinevad	doc_213943985025_item	2289637	et	4	main
selleni	doc_213943985025_item	2289638	et	3	main
jõuvad	doc_213943985025_item	2289642	et	4	main
nagu	doc_213943985025_item	2289650	et	3	main
ida	doc_213943985025_item	2289675	et	4	main
mõtteviisid	doc_213943985025_item	2289676	et	3	main
maailma	doc_213943985025_item	2289685	et	4	main
väärtused	doc_213943985022_item	2289276	et	3	main
nad	doc_213943985022_item	2289278	et	3	main
need	doc_213943985022_item	2289282	et	3	main
ka	doc_213943985022_item	2289285	et	3	main
olulisem	doc_213943985022_item	2289295	et	4	main
võõrkeelsena	doc_213943985022_item	2289299	et	3	main
inimesed	doc_213943985022_item	2289306	et	3	main
ei	doc_213943985022_item	2289308	et	4	main
riigikeelt	doc_213943985022_item	2289310	et	4	main
see	doc_213943985022_item	2289311	et	3	main
kahekeelne	doc_213943985022_item	2289317	et	3	main
tea	doc_213943985022_item	2289325	et	4	main
riigikeelt	doc_213943985022_item	2289326	et	4	main
isegi	doc_213943985022_item	2289327	et	4	main
kaks	doc_213943985022_item	2289332	et	3	main
välismaalane	doc_213943985022_item	2289334	et	3	main
võib	doc_213943985022_item	2289346	et	3	main
teab	doc_213943985022_item	2289355	et	3	main
teist	doc_213943985023_item	2289383	et	4	main
võib	doc_213943985023_item	2289385	et	3	main
kui	doc_213943985023_item	2289388	et	3	main
keelt	doc_213943985023_item	2289391	et	4	main
õppida	doc_213943985023_item	2289392	et	3	main
ka	doc_213943985023_item	2289422	et	3	main
elavate	doc_213943985023_item	2289434	et	4	main
venelaste	doc_213943985023_item	2289435	et	4	main
venemaal	doc_213943985023_item	2289440	et	4	main
ei	doc_213943985023_item	2289446	et	4	main
parem	doc_213943985023_item	2289462	et	4	main
või	doc_213943985023_item	2289469	et	4	main
muutu	doc_213943985023_item	2289477	et	4	main
eriline	doc_213943985023_item	2289484	et	4	main
sellepärast	doc_213943985023_item	2289485	et	3	main
nende	doc_213943985023_item	2289486	et	4	main
kultuur	doc_213943985023_item	2289487	et	3	main
ole	doc_213943985023_item	2289493	et	4	main
veel	doc_213943985023_item	2289499	et	4	main
märk	doc_213943985023_item	2289501	et	3	main
tänapäevani	doc_213943985023_item	2289510	et	3	main
mõtteviis	doc_213943985024_item	2289526	et	3	main
meie	doc_213943985024_item	2289534	et	4	main
viisi	doc_213943985024_item	2289536	et	4	main
elame	doc_213943985024_item	2289539	et	3	main
sureme	doc_213943985024_item	2289541	et	3	main
õpime	doc_213943985024_item	2289542	et	3	main
me	doc_213943985024_item	2289544	et	4	main
läänemast	doc_213943985024_item	2289546	et	3	main
idamast	doc_213943985024_item	2289548	et	3	main
mõtlevad	doc_213943985024_item	2289550	et	4	main
erinev	doc_213943985024_item	2289552	et	4	main
probleemid	doc_213943985024_item	2289553	et	3	main
sisaldus	doc_213943985024_item	2289554	et	4	main
a	doc_213943985024_item	2289562	et	4	main
b	doc_213943985024_item	2289577	et	4	main
elavad	doc_213943985024_item	2289584	et	4	main
sellepärast	doc_213943985024_item	2289586	et	3	main
kultuuri	doc_213943985024_item	2289587	et	4	main
sillmaringi	doc_213943985024_item	2289594	et	4	main
ida	doc_213943985025_item	2289598	et	4	main
ei	doc_213943985025_item	2289603	et	4	main
oluline	doc_213943985025_item	2289630	et	4	main
kuidas	doc_213943985025_item	2289631	et	3	main
leida	doc_213943985025_item	2289632	et	3	main
enda	doc_213943985025_item	2289634	et	4	main
milleni	doc_213943985025_item	2289641	et	3	main
kuid	doc_213943985025_item	2289644	et	4	main
on	doc_213943985025_item	2289647	et	4	main
samasugune	doc_213943985025_item	2289649	et	3	main
lääne	doc_213943985025_item	2289651	et	4	main
inimestel	doc_213943985025_item	2289653	et	3	main
aranenud	doc_213943985025_item	2289666	et	4	main
see	doc_213943985025_item	2289669	et	3	main
lääne	doc_213943985025_item	2289673	et	4	main
ja	doc_213943985025_item	2289674	et	3	main
lääne	doc_213943985025_item	2289680	et	4	main
ja	doc_213943985026_item	2289690	et	3	main
seotud	doc_213943985026_item	2289693	et	4	main
ja	doc_213943985026_item	2289695	et	3	main
kultuur	doc_213943985026_item	2289696	et	3	main
on	doc_213943985026_item	2289697	et	4	main
maa	doc_213943985026_item	2289705	et	4	main
automaatselt	doc_213943985026_item	2289716	et	4	main
see	doc_213943985026_item	2289720	et	3	main
on	doc_213943985026_item	2289721	et	4	main
kui	doc_213943985026_item	2289723	et	3	main
ta	doc_213943985026_item	2289730	et	4	main
võib	doc_213943985026_item	2289731	et	3	main
olla	doc_213943985026_item	2289732	et	3	main
ei	doc_213943985026_item	2289733	et	4	main
aru	doc_213943985026_item	2289747	et	4	main
ta	doc_213943985026_item	2289749	et	4	main
annab	doc_213943985026_item	2289755	et	3	main
juhul	doc_213943985022_item	2289329	et	3	main
kanadas	doc_213943985022_item	2289330	et	4	main
riigikeelt	doc_213943985022_item	2289333	et	4	main
teiste	doc_213943985022_item	2289337	et	4	main
julgelt	doc_213943985022_item	2289347	et	4	main
rääkida	doc_213943985022_item	2289348	et	3	main
inimene	doc_213943985022_item	2289353	et	3	main
ja	doc_213943985022_item	2289357	et	3	main
seotud	doc_213943985023_item	2289371	et	4	main
võime	doc_213943985023_item	2289375	et	4	main
kultuurist	doc_213943985023_item	2289379	et	3	main
et	doc_213943985023_item	2289387	et	3	main
me	doc_213943985023_item	2289389	et	4	main
on	doc_213943985023_item	2289393	et	4	main
vaja	doc_213943985023_item	2289394	et	4	main
rohkem	doc_213943985023_item	2289395	et	4	main
teada	doc_213943985023_item	2289396	et	3	main
kultuurist	doc_213943985023_item	2289397	et	3	main
ja	doc_213943985023_item	2289398	et	3	main
tagurpidi	doc_213943985023_item	2289399	et	3	main
kui	doc_213943985023_item	2289400	et	3	main
me	doc_213943985023_item	2289401	et	4	main
tahame	doc_213943985023_item	2289402	et	3	main
kultuurist	doc_213943985023_item	2289403	et	3	main
teada	doc_213943985023_item	2289404	et	3	main
siis	doc_213943985023_item	2289405	et	3	main
on	doc_213943985023_item	2289406	et	4	main
vaja	doc_213943985023_item	2289407	et	4	main
keelt	doc_213943985023_item	2289408	et	4	main
õppida	doc_213943985023_item	2289409	et	3	main
kui	doc_213943985023_item	2289410	et	3	main
õpime	doc_213943985023_item	2289411	et	3	main
keelt	doc_213943985023_item	2289412	et	4	main
või	doc_213943985023_item	2289413	et	4	main
kultuuri	doc_213943985023_item	2289414	et	4	main
on	doc_213943985023_item	2289415	et	4	main
vaja	doc_213943985023_item	2289416	et	4	main
koguda	doc_213943985023_item	2289417	et	3	main
nii	doc_213943985023_item	2289418	et	3	main
teoreetilisi	doc_213943985023_item	2289419	et	3	main
teadmisi	doc_213943985023_item	2289420	et	4	main
kultuur	doc_213943985023_item	2289427	et	3	main
ei	doc_213943985023_item	2289429	et	4	main
kui	doc_213943985023_item	2289439	et	3	main
elavate	doc_213943985023_item	2289441	et	4	main
võib	doc_213943985023_item	2289448	et	3	main
olemas	doc_213943985023_item	2289451	et	4	main
kultuur	doc_213943985023_item	2289455	et	3	main
eestis	doc_213943985023_item	2289458	et	3	main
ja	doc_213943985023_item	2289459	et	3	main
kelle	doc_213943985023_item	2289471	et	4	main
ema	doc_213943985023_item	2289473	et	4	main
keel	doc_213943985023_item	2289474	et	4	main
üldse	doc_213943985023_item	2289475	et	3	main
eesti	doc_213943985023_item	2289480	et	4	main
keel	doc_213943985023_item	2289481	et	4	main
tõesti	doc_213943985023_item	2289483	et	3	main
eesti	doc_213943985023_item	2289495	et	4	main
ja	doc_213943985023_item	2289498	et	3	main
ja	doc_213943985023_item	2289503	et	3	main
kultuurist	doc_213943985023_item	2289504	et	3	main
elavate	doc_213943985023_item	2289506	et	4	main
elavate	doc_213943985023_item	2289516	et	4	main
udmurdidel	doc_213943985023_item	2289517	et	4	main
seda	doc_213943985023_item	2289518	et	3	main
praegu	doc_213943985023_item	2289519	et	3	main
ei	doc_213943985023_item	2289520	et	4	main
ole	doc_213943985023_item	2289521	et	4	main
lääne	doc_213943985024_item	2289523	et	4	main
ida	doc_213943985024_item	2289525	et	4	main
mõjuta	doc_213943985024_item	2289531	et	4	main
igapäevatoiminguid	doc_213943985024_item	2289535	et	3	main
me	doc_213943985024_item	2289538	et	4	main
kuidas	doc_213943985024_item	2289543	et	3	main
juhime	doc_213943985024_item	2289545	et	3	main
ja	doc_213943985024_item	2289547	et	3	main
on	doc_213943985024_item	2289551	et	4	main
läänemast	doc_213943985024_item	2289558	et	3	main
kui	doc_213943985024_item	2289561	et	3	main
selle	doc_213943985024_item	2289565	et	4	main
selle	doc_213943985024_item	2289576	et	4	main
raske	doc_213943985024_item	2289588	et	4	main
laiendab	doc_213943985024_item	2289592	et	3	main
ja	doc_213943985025_item	2289597	et	3	main
mitte	doc_213943985025_item	2289605	et	3	main
essee	doc_213943985024_item	2289522	et	4	main
ja	doc_213943985024_item	2289524	et	3	main
ei	doc_213943985024_item	2289530	et	4	main
mitte	doc_213943985024_item	2289532	et	3	main
arvavad	doc_213943985024_item	2289549	et	4	main
arvan	doc_213943985024_item	2289559	et	3	main
tööta	doc_213943985024_item	2289564	et	4	main
ei	doc_213943985024_item	2289567	et	4	main
idamast	doc_213943985024_item	2289569	et	3	main
et	doc_213943985024_item	2289571	et	3	main
kui	doc_213943985024_item	2289572	et	3	main
tööta	doc_213943985024_item	2289575	et	4	main
töötab	doc_213943985024_item	2289578	et	3	main
tegelema	doc_213943985024_item	2289580	et	3	main
tegeleb	doc_213943985024_item	2289589	et	3	main
essee	doc_213943985025_item	2289595	et	4	main
lääne	doc_213943985025_item	2289596	et	4	main
kommunikatsioon	doc_213943985025_item	2289601	et	3	main
vaid	doc_213943985025_item	2289609	et	3	main
see	doc_213943985025_item	2289610	et	3	main
mõjutab	doc_213943985025_item	2289611	et	3	main
ka	doc_213943985025_item	2289612	et	3	main
teooriaid	doc_213943985025_item	2289613	et	3	main
mida	doc_213943985025_item	2289614	et	4	main
arendame	doc_213943985025_item	2289615	et	3	main
oma	doc_213943985025_item	2289616	et	4	main
tegude	doc_213943985025_item	2289617	et	3	main
seletamiseks	doc_213943985025_item	2289618	et	4	main
lääne	doc_213943985025_item	2289619	et	4	main
mõtteviisil	doc_213943985025_item	2289620	et	3	main
on	doc_213943985025_item	2289621	et	4	main
absoluutne	doc_213943985025_item	2289623	et	3	main
tõde	doc_213943985025_item	2289624	et	4	main
kes	doc_213943985025_item	2289626	et	4	main
uskulikud	doc_213943985025_item	2289643	et	4	main
mõtteviis	doc_213943985025_item	2289646	et	3	main
siin	doc_213943985025_item	2289652	et	4	main
hästi	doc_213943985025_item	2289665	et	3	main
traditsioonid	doc_213943985025_item	2289668	et	3	main
on	doc_213943985025_item	2289670	et	4	main
et	doc_213943985025_item	2289672	et	3	main
sest	doc_213943985025_item	2289679	et	4	main
pooled	doc_213943985025_item	2289686	et	3	main
kas	doc_213943985026_item	2289688	et	3	main
õppida	doc_213943985026_item	2289704	et	3	main
inimesel	doc_213943985026_item	2289708	et	3	main
ta	doc_213943985026_item	2289715	et	4	main
kui	doc_213943985026_item	2289719	et	3	main
on	doc_213943985026_item	2289725	et	4	main
nõrgaid	doc_213943985026_item	2289726	et	4	main
saa	doc_213943985026_item	2289734	et	4	main
aru	doc_213943985026_item	2289735	et	4	main
vestluspartneri	doc_213943985026_item	2289736	et	3	main
veatega	doc_213943985026_item	2289743	et	4	main
saab	doc_213943985026_item	2289745	et	3	main
mitte	doc_213943985026_item	2289760	et	3	main
grammatika	doc_213943985026_item	2289762	et	4	main
ja	doc_213943985026_item	2289764	et	3	main
sõltub	doc_213943985026_item	2289768	et	3	main
et	doc_213943985026_item	2289781	et	3	main
tšehhi	doc_213943985026_item	2289790	et	2	main
õppimisel	doc_213943985026_item	2289801	et	4	main
võõrkeelega	doc_213943985026_item	2289822	et	3	main
kui	doc_213943985026_item	2289830	et	3	main
aga	doc_213943985026_item	2289833	et	3	main
ei	doc_213943985026_item	2289836	et	4	main
keeli	doc_213943985026_item	2289838	et	4	main
hästi	doc_213943985026_item	2289839	et	3	main
selgeks	doc_213943985026_item	2289840	et	3	main
asjad	doc_213943985026_item	2289847	et	3	main
olemas	doc_213943985025_item	2289622	et	4	main
viis	doc_213943985025_item	2289633	et	4	main
olemasolul	doc_213943985025_item	2289640	et	3	main
pole	doc_213943985025_item	2289648	et	3	main
teised	doc_213943985025_item	2289654	et	4	main
eesmärgid	doc_213943985025_item	2289655	et	3	main
nad	doc_213943985025_item	2289656	et	3	main
ei	doc_213943985025_item	2289657	et	4	main
leia	doc_213943985025_item	2289658	et	4	main
viis	doc_213943985025_item	2289659	et	4	main
enda	doc_213943985025_item	2289660	et	4	main
arendamiseks	doc_213943985025_item	2289661	et	4	main
sest	doc_213943985025_item	2289662	et	4	main
idapooles	doc_213943985025_item	2289663	et	4	main
on	doc_213943985025_item	2289664	et	4	main
loomulikult	doc_213943985025_item	2289671	et	4	main
on	doc_213943985025_item	2289677	et	4	main
ja	doc_213943985025_item	2289681	et	3	main
on	doc_213943985025_item	2289683	et	4	main
erinevad	doc_213943985025_item	2289684	et	4	main
on	doc_213943985026_item	2289692	et	4	main
kahtlemata	doc_213943985026_item	2289698	et	4	main
kultuuri	doc_213943985026_item	2289706	et	4	main
kui	doc_213943985026_item	2289707	et	3	main
hea	doc_213943985026_item	2289710	et	4	main
keeleoskus	doc_213943985026_item	2289711	et	3	main
siis	doc_213943985026_item	2289712	et	3	main
räägib	doc_213943985026_item	2289714	et	3	main
eriti	doc_213943985026_item	2289718	et	3	main
sõnumi	doc_213943985026_item	2289737	et	3	main
võõramaalne	doc_213943985026_item	2289740	et	4	main
grammatika	doc_213943985026_item	2289742	et	4	main
kõneleja	doc_213943985026_item	2289744	et	4	main
riikist	doc_213943985026_item	2289752	et	4	main
tihti	doc_213943985026_item	2289753	et	3	main
kuid	doc_213943985026_item	2289759	et	4	main
vead	doc_213943985026_item	2289763	et	4	main
kiire	doc_213943985026_item	2289765	et	4	main
ja	doc_213943985026_item	2289774	et	3	main
millest	doc_213943985026_item	2289775	et	3	main
selles	doc_213943985026_item	2289780	et	4	main
näiteks	doc_213943985026_item	2289786	et	4	main
või	doc_213943985026_item	2289791	et	4	main
keeled	doc_213943985026_item	2289793	et	3	main
suhtlemine	doc_213943985026_item	2289821	et	4	main
on	doc_213943985026_item	2289823	et	4	main
kultuur	doc_213943985026_item	2289832	et	3	main
vallata	doc_213943985026_item	2289841	et	4	main
kultuur	doc_213943985026_item	2289842	et	3	main
eraldamatud	doc_213943985026_item	2289846	et	4	main
essee	doc_213943985026_item	2289687	et	4	main
keel	doc_213943985026_item	2289689	et	4	main
seotud	doc_213943985026_item	2289699	et	4	main
parem	doc_213943985026_item	2289703	et	4	main
selgeks	doc_213943985026_item	2289717	et	3	main
emakeel	doc_213943985026_item	2289722	et	4	main
siis	doc_213943985026_item	2289728	et	3	main
raskem	doc_213943985026_item	2289729	et	4	main
mõtet	doc_213943985026_item	2289738	et	3	main
rääkib	doc_213943985026_item	2289741	et	4	main
kohe	doc_213943985026_item	2289746	et	4	main
et	doc_213943985026_item	2289748	et	3	main
teisest	doc_213943985026_item	2289751	et	4	main
kõneleja	doc_213943985026_item	2289754	et	4	main
räägid	doc_213943985026_item	2289773	et	4	main
tahad	doc_213943985026_item	2289776	et	3	main
õppida	doc_213943985026_item	2289777	et	3	main
on	doc_213943985026_item	2289782	et	4	main
pered	doc_213943985026_item	2289784	et	3	main
õppida	doc_213943985026_item	2289789	et	3	main
soome	doc_213943985026_item	2289792	et	3	main
raskusi	doc_213943985026_item	2289798	et	4	main
eesti	doc_213943985026_item	2289799	et	4	main
keele	doc_213943985026_item	2289800	et	4	main
väga	doc_213943985026_item	2289824	et	3	main
oluline	doc_213943985026_item	2289825	et	4	main
suheldes	doc_213943985026_item	2289826	et	3	main
nii	doc_213943985026_item	2289828	et	3	main
keel	doc_213943985026_item	2289829	et	4	main
ka	doc_213943985026_item	2289831	et	3	main
oskuseta	doc_213943985026_item	2289835	et	3	main
suhtlus	doc_213943985026_item	2289844	et	3	main
inimesel	doc_213943985026_item	2289724	et	3	main
teadmisi	doc_213943985026_item	2289727	et	4	main
kui	doc_213943985026_item	2289739	et	3	main
tuli	doc_213943985026_item	2289750	et	4	main
andeks	doc_213943985026_item	2289756	et	3	main
õppimine	doc_213943985026_item	2289767	et	4	main
keelt	doc_213943985026_item	2289770	et	4	main
sa	doc_213943985026_item	2289771	et	3	main
ise	doc_213943985026_item	2289772	et	4	main
on	doc_213943985026_item	2289779	et	4	main
keele	doc_213943985026_item	2289783	et	4	main
gruppid	doc_213943985026_item	2289785	et	4	main
kergemini	doc_213943985026_item	2289788	et	4	main
kuid	doc_213943985026_item	2289794	et	4	main
venelastel	doc_213943985026_item	2289795	et	4	main
tihti	doc_213943985026_item	2289796	et	3	main
tekkivad	doc_213943985026_item	2289797	et	4	main
et	doc_213943985026_item	2289802	et	3	main
keeli	doc_213943985026_item	2289804	et	4	main
on	doc_213943985026_item	2289806	et	4	main
vaja	doc_213943985026_item	2289807	et	4	main
erinevate	doc_213943985026_item	2289808	et	4	main
inimestega	doc_213943985026_item	2289809	et	3	main
suhelda	doc_213943985026_item	2289810	et	4	main
siis	doc_213943985026_item	2289811	et	3	main
kergemini	doc_213943985026_item	2289812	et	4	main
on	doc_213943985026_item	2289813	et	4	main
keele	doc_213943985026_item	2289814	et	4	main
arusamine	doc_213943985026_item	2289815	et	4	main
kui	doc_213943985026_item	2289816	et	3	main
räägitakse	doc_213943985026_item	2289817	et	3	main
allati	doc_213943985026_item	2289818	et	3	main
ühe	doc_213943985026_item	2289819	et	4	main
inimesega	doc_213943985026_item	2289820	et	3	main
veade	doc_213943985026_item	2289757	et	4	main
tõttu	doc_213943985026_item	2289758	et	4	main
alati	doc_213943985026_item	2289761	et	4	main
keele	doc_213943985026_item	2289766	et	4	main
mille	doc_213943985026_item	2289769	et	3	main
asi	doc_213943985026_item	2289778	et	4	main
eestlastele	doc_213943985026_item	2289787	et	4	main
parem	doc_213943985026_item	2289803	et	4	main
vallata	doc_213943985026_item	2289805	et	4	main
õpetakse	doc_213943985026_item	2289827	et	4	main
kultuuri	doc_213943985026_item	2289834	et	4	main
saa	doc_213943985026_item	2289837	et	4	main
ja	doc_213943985026_item	2289843	et	3	main
on	doc_213943985026_item	2289845	et	4	main
miks	doc_213943985031_item	2290449	et	4	main
ma	doc_213943985031_item	2290450	et	3	main
sellel	doc_213943985031_item	2290457	et	4	main
erialal	doc_213943985031_item	2290458	et	3	main
ma	doc_213943985031_item	2290471	et	3	main
palju	doc_213943985031_item	2290473	et	4	main
loesin	doc_213943985031_item	2290477	et	4	main
mulle	doc_213943985031_item	2290481	et	4	main
eperekonnanimi	doc_213943985031_item	2290487	et	4	main
et	doc_213943985031_item	2290498	et	3	main
väga	doc_213943985031_item	2290499	et	3	main
dots	doc_213943985031_item	2290502	et	4	main
inimest	doc_213943985031_item	2290507	et	3	main
õppinud	doc_213943985031_item	2290514	et	4	main
seda	doc_213943985031_item	2290518	et	3	main
huvitav	doc_213943985031_item	2290519	et	4	main
mis	doc_213943985031_item	2290523	et	4	main
veel	doc_213943985031_item	2290524	et	4	main
õppeda	doc_213943985031_item	2290528	et	4	main
essee	doc_213943985032_item	2290530	et	4	main
2	doc_213943985032_item	2290537	et	2	main
mida	doc_213943985032_item	2290538	et	4	main
ootan	doc_213943985032_item	2290539	et	3	main
õppimisest	doc_213943985032_item	2290540	et	4	main
on	doc_213943985032_item	2290547	et	4	main
inimesed	doc_213943985032_item	2290548	et	3	main
kellele	doc_213943985032_item	2290549	et	4	main
teosed	doc_213943985032_item	2290552	et	3	main
juhtus	doc_213943985032_item	2290557	et	3	main
valisin	doc_213943985031_item	2290451	et	3	main
saada	doc_213943985031_item	2290468	et	4	main
palju	doc_213943985031_item	2290478	et	4	main
järgmine	doc_213943985031_item	2290485	et	3	main
mulle	doc_213943985031_item	2290492	et	4	main
hea	doc_213943985031_item	2290500	et	4	main
lektorit	doc_213943985031_item	2290501	et	3	main
väga	doc_213943985031_item	2290505	et	3	main
eliala	doc_213943985031_item	2290516	et	4	main
eriala	doc_213943985031_item	2290453	et	4	main
õppimisest	doc_213943985031_item	2290456	et	4	main
ootan	doc_213943985031_item	2290472	et	3	main
ajalehed	doc_213943985031_item	2290479	et	3	main
kirjuta	doc_213943985031_item	2290484	et	4	main
tallinna	doc_213943985031_item	2290494	et	4	main
ülikool	doc_213943985031_item	2290495	et	4	main
selle	doc_213943985031_item	2290496	et	4	main
pärast	doc_213943985031_item	2290497	et	4	main
väga	doc_213943985031_item	2290504	et	3	main
hea	doc_213943985031_item	2290506	et	4	main
perekonnanimi	doc_213943985031_item	2290510	et	3	main
klassisõper	doc_213943985031_item	2290512	et	4	main
temale	doc_213943985031_item	2290517	et	3	main
ma	doc_213943985031_item	2290526	et	3	main
tahan	doc_213943985031_item	2290527	et	3	main
ma	doc_213943985032_item	2290533	et	3	main
selle	doc_213943985032_item	2290535	et	4	main
meeldib	doc_213943985032_item	2290550	et	3	main
kirjutada	doc_213943985032_item	2290551	et	3	main
maailmas	doc_213943985032_item	2290558	et	3	main
inimestele	doc_213943985032_item	2290561	et	3	main
uus	doc_213943985032_item	2290564	et	3	main
ja	doc_213943985032_item	2290566	et	3	main
võib	doc_213943985032_item	2290571	et	3	main
mina	doc_213943985032_item	2290575	et	4	main
et	doc_213943985032_item	2290577	et	3	main
palju	doc_213943985032_item	2290585	et	4	main
näiteks	doc_213943985032_item	2290587	et	4	main
kellelt	doc_213943985032_item	2290590	et	4	main
tööta	doc_213943985032_item	2290597	et	4	main
sellel	doc_213943985032_item	2290600	et	4	main
probleemil	doc_213943985032_item	2290601	et	3	main
õige	doc_213943985032_item	2290602	et	4	main
võib	doc_213943985032_item	2290603	et	3	main
olla	doc_213943985032_item	2290604	et	3	main
sulle	doc_213943985032_item	2290607	et	3	main
veel	doc_213943985032_item	2290609	et	4	main
on	doc_213943985032_item	2290611	et	4	main
ajakirjandusena	doc_213943985032_item	2290615	et	3	main
juutustas	doc_213943985032_item	2290617	et	4	main
et	doc_213943985032_item	2290619	et	3	main
essee	doc_213943985031_item	2290448	et	4	main
mida	doc_213943985031_item	2290454	et	4	main
ja	doc_213943985031_item	2290459	et	3	main
tallinna	doc_213943985031_item	2290460	et	4	main
1	doc_213943985031_item	2290462	et	2	main
ülikoolis	doc_213943985031_item	2290461	et	4	main
mulle	doc_213943985031_item	2290463	et	4	main
meeldib	doc_213943985031_item	2290464	et	3	main
ajakirjandus	doc_213943985031_item	2290465	et	3	main
ma	doc_213943985031_item	2290466	et	3	main
selle	doc_213943985031_item	2290452	et	4	main
ootan	doc_213943985031_item	2290455	et	3	main
2	doc_213943985031_item	2290470	et	2	main
kuidas	doc_213943985031_item	2290483	et	3	main
ajakirjanikud	doc_213943985031_item	2290486	et	3	main
ja	doc_213943985031_item	2290490	et	3	main
ajakirjaniku	doc_213943985031_item	2290515	et	3	main
1	doc_213943985032_item	2290531	et	2	main
miks	doc_213943985032_item	2290532	et	4	main
valisin	doc_213943985032_item	2290534	et	3	main
eriala	doc_213943985032_item	2290536	et	4	main
ülikoolist	doc_213943985032_item	2290545	et	4	main
maailmas	doc_213943985032_item	2290546	et	3	main
on	doc_213943985032_item	2290556	et	4	main
midagi	doc_213943985032_item	2290563	et	4	main
teatada	doc_213943985032_item	2290565	et	3	main
olla	doc_213943985032_item	2290572	et	3	main
mulle	doc_213943985032_item	2290578	et	4	main
elus	doc_213943985032_item	2290583	et	4	main
on	doc_213943985032_item	2290584	et	4	main
lapsed	doc_213943985032_item	2290589	et	3	main
kellegi	doc_213943985032_item	2290591	et	4	main
ei	doc_213943985032_item	2290592	et	4	main
mõtle	doc_213943985032_item	2290593	et	4	main
kui	doc_213943985032_item	2290598	et	3	main
vaata	doc_213943985032_item	2290599	et	4	main
ajakirjandus	doc_213943985032_item	2290605	et	3	main
töötab	doc_213943985032_item	2290614	et	3	main
hea	doc_213943985032_item	2290622	et	4	main
töötab	doc_213943985032_item	2290628	et	3	main
tööta	doc_213943985032_item	2290632	et	4	main
suhtelda	doc_213943985032_item	2290644	et	4	main
saab	doc_213943985032_item	2290651	et	3	main
ajakirjandusena	doc_213943985032_item	2290652	et	3	main
ja	doc_213943985032_item	2290658	et	3	main
see	doc_213943985032_item	2290659	et	3	main
tahan	doc_213943985032_item	2290664	et	3	main
loetud	doc_213943985032_item	2290674	et	4	main
ja	doc_213943985032_item	2290675	et	3	main
see	doc_213943985032_item	2290684	et	3	main
on	doc_213943985032_item	2290685	et	4	main
ma	doc_213943985032_item	2290691	et	3	main
jutustused	doc_213943985032_item	2290702	et	4	main
õppimine	doc_213943985032_item	2290707	et	4	main
see	doc_213943985032_item	2290716	et	3	main
minu	doc_213943985032_item	2290718	et	3	main
ei	doc_213943985032_item	2290723	et	4	main
minu	doc_213943985032_item	2290732	et	3	main
teen	doc_213943985032_item	2290746	et	3	main
õppin	doc_213943985032_item	2290748	et	4	main
tahan	doc_213943985031_item	2290467	et	3	main
ajakirjaniku	doc_213943985031_item	2290469	et	3	main
huvitavad	doc_213943985031_item	2290474	et	4	main
tunnid	doc_213943985031_item	2290475	et	3	main
ma	doc_213943985031_item	2290476	et	3	main
ja	doc_213943985031_item	2290480	et	3	main
meeldib	doc_213943985031_item	2290482	et	3	main
eperekonnanimi	doc_213943985031_item	2290488	et	4	main
eperekonnanimi	doc_213943985031_item	2290489	et	4	main
eperekonnanimi	doc_213943985031_item	2290491	et	4	main
meeldib	doc_213943985031_item	2290493	et	3	main
ja	doc_213943985031_item	2290503	et	3	main
rektor	doc_213943985031_item	2290508	et	3	main
eesnimi	doc_213943985031_item	2290509	et	3	main
minu	doc_213943985031_item	2290511	et	3	main
ka	doc_213943985031_item	2290513	et	3	main
ma	doc_213943985031_item	2290520	et	3	main
ei	doc_213943985031_item	2290521	et	4	main
siin	doc_213943985031_item	2290529	et	4	main
erialal	doc_213943985032_item	2290542	et	3	main
jutustused	doc_213943985032_item	2290553	et	4	main
või	doc_213943985032_item	2290559	et	4	main
palju	doc_213943985032_item	2290567	et	4	main
teise	doc_213943985032_item	2290568	et	4	main
inimestega	doc_213943985032_item	2290569	et	3	main
on	doc_213943985032_item	2290574	et	4	main
meeldib	doc_213943985032_item	2290579	et	3	main
kes	doc_213943985032_item	2290595	et	4	main
mul	doc_213943985032_item	2290610	et	3	main
sõber	doc_213943985032_item	2290612	et	3	main
sõbralikud	doc_213943985032_item	2290624	et	3	main
on	doc_213943985032_item	2290630	et	4	main
sellel	doc_213943985032_item	2290635	et	4	main
meldib	doc_213943985032_item	2290643	et	4	main
või	doc_213943985032_item	2290649	et	4	main
ta	doc_213943985032_item	2290653	et	4	main
et	doc_213943985032_item	2290665	et	3	main
on	doc_213943985032_item	2290673	et	4	main
minu	doc_213943985032_item	2290679	et	3	main
nad	doc_213943985032_item	2290681	et	3	main
et	doc_213943985032_item	2290693	et	3	main
aitab	doc_213943985032_item	2290695	et	3	main
väikesed	doc_213943985032_item	2290701	et	4	main
ma	doc_213943985032_item	2290704	et	3	main
ootan	doc_213943985032_item	2290705	et	3	main
et	doc_213943985032_item	2290706	et	3	main
siis	doc_213943985032_item	2290708	et	3	main
on	doc_213943985032_item	2290717	et	4	main
keegi	doc_213943985032_item	2290722	et	4	main
vasta	doc_213943985032_item	2290724	et	4	main
ei	doc_213943985032_item	2290727	et	4	main
ja	doc_213943985032_item	2290734	et	3	main
tahan	doc_213943985032_item	2290741	et	3	main
õppin	doc_213943985032_item	2290749	et	4	main
ja	doc_213943985032_item	2290750	et	3	main
veel	doc_213943985032_item	2290751	et	4	main
1	doc_213943985034_item	2290889	et	2	main
ma	doc_213943985034_item	2290891	et	3	main
ajakirjaniku	doc_213943985034_item	2290906	et	3	main
sellepärast	doc_213943985034_item	2290908	et	3	main
meelest	doc_213943985034_item	2290911	et	4	main
tea	doc_213943985031_item	2290522	et	4	main
kirjuta	doc_213943985031_item	2290525	et	4	main
sellel	doc_213943985032_item	2290541	et	4	main
ja	doc_213943985032_item	2290543	et	3	main
tallinna	doc_213943985032_item	2290544	et	4	main
midagi	doc_213943985032_item	2290554	et	4	main
mis	doc_213943985032_item	2290555	et	4	main
suhelda	doc_213943985032_item	2290570	et	4	main
kõik	doc_213943985032_item	2290581	et	4	main
meie	doc_213943985032_item	2290582	et	4	main
probleemid	doc_213943985032_item	2290586	et	3	main
sõjad	doc_213943985032_item	2290588	et	3	main
elavad	doc_213943985032_item	2290596	et	4	main
kes	doc_213943985032_item	2290613	et	4	main
ta	doc_213943985032_item	2290616	et	4	main
palju	doc_213943985032_item	2290618	et	4	main
ta	doc_213943985032_item	2290627	et	4	main
huvitav	doc_213943985032_item	2290631	et	4	main
sellel	doc_213943985032_item	2290633	et	4	main
erialal	doc_213943985032_item	2290634	et	3	main
kui	doc_213943985032_item	2290646	et	3	main
naine	doc_213943985032_item	2290650	et	3	main
ühiskonnas	doc_213943985032_item	2290657	et	4	main
ka	doc_213943985032_item	2290660	et	3	main
mulle	doc_213943985032_item	2290662	et	4	main
inimesed	doc_213943985032_item	2290666	et	3	main
mina	doc_213943985032_item	2290669	et	4	main
kui	doc_213943985032_item	2290671	et	3	main
tema	doc_213943985032_item	2290676	et	4	main
mõtlesid	doc_213943985032_item	2290682	et	4	main
hea	doc_213943985032_item	2290686	et	4	main
ja	doc_213943985032_item	2290688	et	3	main
ootan	doc_213943985032_item	2290692	et	3	main
ajakirjandus	doc_213943985032_item	2290694	et	3	main
mulle	doc_213943985032_item	2290696	et	4	main
õige	doc_213943985032_item	2290698	et	4	main
mulle	doc_213943985032_item	2290710	et	4	main
arvan	doc_213943985032_item	2290714	et	3	main
eriala	doc_213943985032_item	2290719	et	4	main
mitte	doc_213943985032_item	2290721	et	3	main
sõbrad	doc_213943985032_item	2290733	et	3	main
ma	doc_213943985032_item	2290740	et	3	main
sellel	doc_213943985032_item	2290743	et	4	main
erialal	doc_213943985032_item	2290744	et	3	main
ma	doc_213943985032_item	2290745	et	3	main
õppin	doc_213943985032_item	2290753	et	4	main
essee	doc_213943985034_item	2290888	et	4	main
valisin	doc_213943985034_item	2290892	et	3	main
mida	doc_213943985034_item	2290896	et	4	main
eriala	doc_213943985034_item	2290907	et	4	main
on	doc_213943985034_item	2290913	et	4	main
võib	doc_213943985034_item	2290917	et	3	main
miks	doc_213943985034_item	2290930	et	4	main
mina	doc_213943985034_item	2290931	et	4	main
mida	doc_213943985034_item	2290934	et	4	main
hakkan	doc_213943985034_item	2290935	et	3	main
lõpetan	doc_213943985034_item	2290938	et	3	main
suvel	doc_213943985034_item	2290946	et	3	main
mina	doc_213943985034_item	2290957	et	4	main
mida	doc_213943985034_item	2290961	et	4	main
valida	doc_213943985034_item	2290962	et	3	main
et	doc_213943985034_item	2290964	et	3	main
sõltub	doc_213943985034_item	2290967	et	3	main
tallinna	doc_213943985034_item	2290973	et	4	main
paremaks	doc_213943985034_item	2290979	et	4	main
olen	doc_213943985034_item	2291024	et	3	main
sain	doc_213943985034_item	2291028	et	3	main
õppekohta	doc_213943985034_item	2291030	et	4	main
midugi	doc_213943985034_item	2291031	et	4	main
saada	doc_213943985034_item	2291034	et	4	main
tähtsam	doc_213943985034_item	2291039	et	4	main
miski	doc_213943985034_item	2291047	et	4	main
tähtsamat	doc_213943985034_item	2291048	et	4	main
riigis	doc_213943985032_item	2290560	et	3	main
meeldib	doc_213943985032_item	2290562	et	3	main
see	doc_213943985032_item	2290573	et	3	main
sest	doc_213943985032_item	2290576	et	4	main
see	doc_213943985032_item	2290580	et	3	main
inimesed	doc_213943985032_item	2290594	et	3	main
aitab	doc_213943985032_item	2290606	et	3	main
elada	doc_213943985032_item	2290608	et	3	main
tal	doc_213943985032_item	2290620	et	3	main
on	doc_213943985032_item	2290621	et	4	main
töö	doc_213943985032_item	2290623	et	4	main
inimesed	doc_213943985032_item	2290625	et	3	main
kellega	doc_213943985032_item	2290626	et	3	main
palju	doc_213943985032_item	2290639	et	4	main
sõbrad	doc_213943985032_item	2290640	et	3	main
ja	doc_213943985032_item	2290641	et	3	main
inimestega	doc_213943985032_item	2290645	et	3	main
mees	doc_213943985032_item	2290648	et	4	main
soobiv	doc_213943985032_item	2290661	et	4	main
saada	doc_213943985032_item	2290668	et	4	main
ja	doc_213943985032_item	2290670	et	3	main
jutustus	doc_213943985032_item	2290672	et	4	main
all	doc_213943985032_item	2290677	et	3	main
nime	doc_213943985032_item	2290680	et	4	main
hea	doc_213943985032_item	2290689	et	4	main
ajakirjandusena	doc_213943985032_item	2290690	et	3	main
kirjutada	doc_213943985032_item	2290697	et	3	main
ja	doc_213943985032_item	2290700	et	3	main
aitab	doc_213943985032_item	2290709	et	3	main
tööga	doc_213943985032_item	2290711	et	3	main
ma	doc_213943985032_item	2290713	et	3	main
ja	doc_213943985032_item	2290720	et	3	main
mulle	doc_213943985032_item	2290725	et	4	main
see	doc_213943985032_item	2290726	et	3	main
sest	doc_213943985032_item	2290730	et	4	main
kõik	doc_213943985032_item	2290731	et	4	main
minu	doc_213943985032_item	2290736	et	3	main
teavad	doc_213943985032_item	2290738	et	3	main
kõik	doc_213943985032_item	2290747	et	4	main
eriala	doc_213943985034_item	2290894	et	4	main
2	doc_213943985034_item	2290895	et	2	main
ja	doc_213943985034_item	2290901	et	3	main
tü	doc_213943985034_item	2290902	et	4	main
1	doc_213943985034_item	2290903	et	2	main
valisin	doc_213943985034_item	2290905	et	3	main
väga	doc_213943985034_item	2290914	et	3	main
huvitav	doc_213943985034_item	2290915	et	4	main
tean	doc_213943985034_item	2290922	et	3	main
või	doc_213943985034_item	2290925	et	4	main
ei	doc_213943985034_item	2290927	et	4	main
saa	doc_213943985034_item	2290928	et	4	main
rääkida	doc_213943985034_item	2290929	et	3	main
sellel	doc_213943985034_item	2290940	et	4	main
erialal	doc_213943985034_item	2290941	et	3	main
ärijuhtimise	doc_213943985034_item	2290948	et	3	main
ja	doc_213943985034_item	2290950	et	3	main
see	doc_213943985032_item	2290629	et	3	main
inimesel	doc_213943985032_item	2290636	et	3	main
on	doc_213943985032_item	2290637	et	4	main
ka	doc_213943985032_item	2290638	et	3	main
mulle	doc_213943985032_item	2290642	et	4	main
inimene	doc_213943985032_item	2290647	et	3	main
veedab	doc_213943985032_item	2290654	et	3	main
palju	doc_213943985032_item	2290655	et	4	main
aega	doc_213943985032_item	2290656	et	4	main
ma	doc_213943985032_item	2290663	et	3	main
teavad	doc_213943985032_item	2290667	et	3	main
on	doc_213943985032_item	2290678	et	4	main
ah	doc_213943985032_item	2290683	et	3	main
inimene	doc_213943985032_item	2290687	et	3	main
suured	doc_213943985032_item	2290699	et	3	main
ülikoolist	doc_213943985032_item	2290703	et	4	main
praegu	doc_213943985032_item	2290712	et	3	main
et	doc_213943985032_item	2290715	et	3	main
soobi	doc_213943985032_item	2290728	et	3	main
talle	doc_213943985032_item	2290729	et	4	main
vanemad	doc_213943985032_item	2290735	et	4	main
pere	doc_213943985032_item	2290737	et	4	main
kui	doc_213943985032_item	2290739	et	3	main
õppida	doc_213943985032_item	2290742	et	3	main
kord	doc_213943985032_item	2290752	et	4	main
ma	doc_213943985034_item	2290904	et	3	main
see	doc_213943985034_item	2290912	et	3	main
ja	doc_213943985034_item	2290916	et	3	main
mina	doc_213943985034_item	2290919	et	4	main
miks	doc_213943985034_item	2290890	et	4	main
selle	doc_213943985034_item	2290893	et	4	main
ootan	doc_213943985034_item	2290897	et	3	main
õppimisest	doc_213943985034_item	2290898	et	4	main
sellel	doc_213943985034_item	2290899	et	4	main
erialal	doc_213943985034_item	2290900	et	3	main
et	doc_213943985034_item	2290909	et	3	main
minu	doc_213943985034_item	2290910	et	3	main
palju	doc_213943985034_item	2290921	et	4	main
ajakirjaniku	doc_213943985034_item	2290923	et	3	main
ülikooli	doc_213943985034_item	2290953	et	4	main
väga	doc_213943985034_item	2290959	et	3	main
palju	doc_213943985034_item	2290960	et	4	main
sest	doc_213943985034_item	2290963	et	4	main
elu	doc_213943985034_item	2290969	et	4	main
minu	doc_213943985034_item	2290985	et	3	main
õppemaja	doc_213943985034_item	2291021	et	4	main
ma	doc_213943985034_item	2291023	et	3	main
mina	doc_213943985034_item	2291032	et	4	main
minu	doc_213943985034_item	2291036	et	3	main
aidati	doc_213943985034_item	2291062	et	3	main
aga	doc_213943985034_item	2291081	et	3	main
õppima	doc_213943985034_item	2291084	et	3	main
elama	doc_213943985034_item	2291086	et	3	main
olla	doc_213943985034_item	2290918	et	3	main
pole	doc_213943985034_item	2290920	et	3	main
tööst	doc_213943985034_item	2290924	et	3	main
isegi	doc_213943985034_item	2290926	et	4	main
valisin	doc_213943985034_item	2290932	et	3	main
ning	doc_213943985034_item	2290933	et	3	main
kui	doc_213943985034_item	2290937	et	3	main
dokumendid	doc_213943985034_item	2290947	et	3	main
erialale	doc_213943985034_item	2290949	et	3	main
mõtlesin	doc_213943985034_item	2290958	et	3	main
otsustusest	doc_213943985034_item	2290966	et	4	main
minu	doc_213943985034_item	2290968	et	3	main
mina	doc_213943985034_item	2290970	et	4	main
otsustasin	doc_213943985034_item	2290971	et	3	main
kui	doc_213943985034_item	2290981	et	3	main
nõus	doc_213943985034_item	2291026	et	4	main
siin	doc_213943985034_item	2291029	et	4	main
kõige	doc_213943985034_item	2291038	et	4	main
inimesel	doc_213943985034_item	2291041	et	3	main
õppida	doc_213943985034_item	2291044	et	3	main
midagi	doc_213943985034_item	2291046	et	4	main
alati	doc_213943985034_item	2291058	et	4	main
leida	doc_213943985034_item	2291059	et	3	main
ja	doc_213943985034_item	2291063	et	3	main
kohtumiseid	doc_213943985034_item	2291080	et	4	main
hakkan	doc_213943985034_item	2291083	et	3	main
tegema	doc_213943985034_item	2290936	et	3	main
ülikooli	doc_213943985034_item	2290939	et	4	main
veel	doc_213943985034_item	2290942	et	4	main
ma	doc_213943985034_item	2290943	et	3	main
andsin	doc_213943985034_item	2290944	et	3	main
sellel	doc_213943985034_item	2290945	et	4	main
sain	doc_213943985034_item	2290951	et	3	main
sellel	doc_213943985034_item	2290955	et	4	main
ajal	doc_213943985034_item	2290956	et	4	main
ülikoolis	doc_213943985034_item	2290974	et	4	main
ajakirjanikuks	doc_213943985034_item	2290975	et	3	main
võin	doc_213943985034_item	2290977	et	3	main
saada	doc_213943985034_item	2290978	et	4	main
see	doc_213943985034_item	2290983	et	3	main
2	doc_213943985034_item	2290988	et	2	main
mida	doc_213943985034_item	2290989	et	4	main
ma	doc_213943985034_item	2290990	et	3	main
saan	doc_213943985034_item	2290991	et	4	main
ootama	doc_213943985034_item	2290992	et	3	main
kui	doc_213943985034_item	2290993	et	3	main
mina	doc_213943985034_item	2290994	et	4	main
lõpetan	doc_213943985034_item	2290995	et	3	main
tallinna	doc_213943985034_item	2290996	et	4	main
ülikooli	doc_213943985034_item	2290997	et	4	main
ajakirjaniku	doc_213943985034_item	2290998	et	3	main
erialal	doc_213943985034_item	2290999	et	3	main
mina	doc_213943985034_item	2291000	et	4	main
muidugi	doc_213943985034_item	2291001	et	4	main
saan	doc_213943985034_item	2291002	et	4	main
hea	doc_213943985034_item	2291003	et	4	main
haridust	doc_213943985034_item	2291004	et	4	main
minu	doc_213943985034_item	2291005	et	3	main
eesti	doc_213943985034_item	2291006	et	4	main
keel	doc_213943985034_item	2291007	et	4	main
näiteks	doc_213943985034_item	2291008	et	4	main
alustab	doc_213943985034_item	2291009	et	3	main
rõõmustada	doc_213943985034_item	2291010	et	3	main
mind	doc_213943985034_item	2291011	et	4	main
mitte	doc_213943985034_item	2291012	et	3	main
nagu	doc_213943985034_item	2291013	et	3	main
täna	doc_213943985034_item	2291014	et	4	main
tallinna	doc_213943985034_item	2291015	et	4	main
ülikool	doc_213943985034_item	2291016	et	4	main
minu	doc_213943985034_item	2291017	et	3	main
meelest	doc_213943985034_item	2291018	et	4	main
on	doc_213943985034_item	2291019	et	4	main
tugev	doc_213943985034_item	2291020	et	4	main
teisesse	doc_213943985034_item	2290952	et	4	main
ka	doc_213943985034_item	2290954	et	3	main
sellest	doc_213943985034_item	2290965	et	4	main
et	doc_213943985034_item	2290972	et	3	main
õppimises	doc_213943985034_item	2290976	et	4	main
spetsialistiks	doc_213943985034_item	2290980	et	3	main
ärijuhtimiseks	doc_213943985034_item	2290982	et	3	main
on	doc_213943985034_item	2290984	et	4	main
valiku	doc_213943985034_item	2290986	et	3	main
põhjus	doc_213943985034_item	2290987	et	4	main
et	doc_213943985034_item	2291027	et	3	main
tahan	doc_213943985034_item	2291033	et	3	main
arvamust	doc_213943985034_item	2291037	et	3	main
oleks	doc_213943985034_item	2291042	et	3	main
kõik	doc_213943985034_item	2291054	et	4	main
tänavad	doc_213943985034_item	2291055	et	4	main
ülikoolist	doc_213943985034_item	2291066	et	4	main
uued	doc_213943985034_item	2291078	et	3	main
ja	doc_213943985034_item	2291085	et	3	main
ning	doc_213943985034_item	2291022	et	3	main
väga	doc_213943985034_item	2291025	et	3	main
spetsialistiks	doc_213943985034_item	2291035	et	3	main
et	doc_213943985034_item	2291040	et	3	main
желание	doc_213943985034_item	2291043	et	2	main
ja	doc_213943985034_item	2291045	et	3	main
siis	doc_213943985034_item	2291050	et	3	main
temal	doc_213943985034_item	2291051	et	3	main
on	doc_213943985034_item	2291052	et	4	main
avatud	doc_213943985034_item	2291053	et	4	main
teine	doc_213943985034_item	2291064	et	3	main
tallinna	doc_213943985034_item	2291065	et	4	main
mina	doc_213943985034_item	2291067	et	4	main
ootan	doc_213943985034_item	2291068	et	3	main
seda	doc_213943985034_item	2291069	et	3	main
et	doc_213943985034_item	2291070	et	3	main
siin	doc_213943985034_item	2291071	et	4	main
inimesi	doc_213943985034_item	2291077	et	4	main
rõõmsalt	doc_213943985034_item	2291087	et	4	main
teha	doc_213943985034_item	2291049	et	3	main
ta	doc_213943985034_item	2291056	et	4	main
võib	doc_213943985034_item	2291057	et	3	main
abi	doc_213943985034_item	2291060	et	4	main
teda	doc_213943985034_item	2291061	et	4	main
saan	doc_213943985034_item	2291072	et	4	main
otsida	doc_213943985034_item	2291073	et	4	main
ja	doc_213943985034_item	2291074	et	3	main
leida	doc_213943985034_item	2291075	et	3	main
häid	doc_213943985034_item	2291076	et	3	main
tervislikud	doc_213943985034_item	2291079	et	3	main
nüüd	doc_213943985034_item	2291082	et	4	main
miks	doc_213943985037_item	2291361	et	4	main
ma	doc_213943985037_item	2291362	et	3	main
valisin	doc_213943985037_item	2291363	et	3	main
tallinna	doc_213943985037_item	2291373	et	4	main
1	doc_213943985037_item	2291375	et	2	main
on	doc_213943985037_item	2291383	et	4	main
vene	doc_213943985037_item	2291384	et	4	main
aasta	doc_213943985037_item	2291387	et	4	main
ma	doc_213943985037_item	2291388	et	3	main
õppisin	doc_213943985037_item	2291389	et	3	main
et	doc_213943985037_item	2291402	et	3	main
ei	doc_213943985037_item	2291404	et	4	main
eesti	doc_213943985037_item	2291406	et	4	main
keelt	doc_213943985037_item	2291407	et	4	main
minu	doc_213943985037_item	2291411	et	3	main
vene	doc_213943985037_item	2291413	et	4	main
teine	doc_213943985037_item	2291415	et	3	main
ja	doc_213943985037_item	2291443	et	3	main
mul	doc_213943985037_item	2291444	et	3	main
vaja	doc_213943985037_item	2291446	et	4	main
ülikoolist	doc_213943985037_item	2291374	et	4	main
õppimine	doc_213943985037_item	2291382	et	4	main
üks	doc_213943985037_item	2291386	et	3	main
keeles	doc_213943985037_item	2291391	et	4	main
aru	doc_213943985037_item	2291394	et	4	main
et	doc_213943985037_item	2291395	et	3	main
palju	doc_213943985037_item	2291396	et	4	main
huvitavat	doc_213943985037_item	2291397	et	4	main
asju	doc_213943985037_item	2291398	et	3	main
on	doc_213943985037_item	2291399	et	4	main
arusaamatu	doc_213943985037_item	2291400	et	4	main
emakeelt	doc_213943985037_item	2291412	et	4	main
keel	doc_213943985037_item	2291414	et	4	main
et	doc_213943985037_item	2291421	et	3	main
väga	doc_213943985037_item	2291423	et	3	main
vaatasin	doc_213943985037_item	2291427	et	3	main
huvitavad	doc_213943985037_item	2291436	et	4	main
tean	doc_213943985037_item	2291438	et	3	main
eestis	doc_213943985037_item	2291442	et	3	main
on	doc_213943985037_item	2291445	et	4	main
teada	doc_213943985037_item	2291447	et	3	main
et	doc_213943985037_item	2291453	et	3	main
x	doc_213943985037_item	2291466	et	4	main
mulle	doc_213943985037_item	2291471	et	4	main
ma	doc_213943985037_item	2291473	et	3	main
olema	doc_213943985037_item	2291478	et	4	main
ja	doc_213943985037_item	2291519	et	3	main
huvitav	doc_213943985037_item	2291522	et	4	main
mina	doc_213943985037_item	2291533	et	4	main
artikleid	doc_213943985037_item	2291536	et	3	main
muud	doc_213943985037_item	2291539	et	4	main
peab	doc_213943985037_item	2291542	et	4	main
oskama	doc_213943985037_item	2291543	et	3	main
ajakirjanik	doc_213943985037_item	2291544	et	3	main
ma	doc_213943985037_item	2291545	et	3	main
tööd	doc_213943985037_item	2291550	et	4	main
mul	doc_213943985037_item	2291552	et	3	main
et	doc_213943985037_item	2291558	et	3	main
tallinna	doc_213943985037_item	2291559	et	4	main
mulle	doc_213943985037_item	2291562	et	4	main
pärast	doc_213943985037_item	2291563	et	4	main
kahjuks	doc_213943985037_item	2291572	et	4	main
ja	doc_213943985037_item	2291577	et	3	main
ma	doc_213943985037_item	2291584	et	3	main
eesti	doc_213943985037_item	2291588	et	4	main
kolme	doc_213943985037_item	2291590	et	4	main
paremaks	doc_213943985037_item	2291594	et	4	main
veel	doc_213943985037_item	2291595	et	4	main
essee	doc_213943985037_item	2291359	et	4	main
sellel	doc_213943985037_item	2291370	et	4	main
erialal	doc_213943985037_item	2291371	et	3	main
ja	doc_213943985037_item	2291372	et	3	main
ajakirjandus	doc_213943985037_item	2291379	et	3	main
eesti	doc_213943985037_item	2291390	et	4	main
sain	doc_213943985037_item	2291393	et	3	main
sest	doc_213943985037_item	2291401	et	4	main
nagu	doc_213943985037_item	2291410	et	3	main
on	doc_213943985037_item	2291419	et	4	main
mulle	doc_213943985037_item	2291422	et	4	main
ja	doc_213943985037_item	2291429	et	3	main
et	doc_213943985037_item	2291431	et	3	main
ma	doc_213943985037_item	2291440	et	3	main
aga	doc_213943985037_item	2291449	et	3	main
ma	doc_213943985037_item	2291451	et	3	main
paremini	doc_213943985037_item	2291455	et	4	main
mina	doc_213943985037_item	2291457	et	4	main
õppisin	doc_213943985037_item	2291458	et	3	main
juured	doc_213943985037_item	2291465	et	3	main
igav	doc_213943985037_item	2291470	et	3	main
kahjuks	doc_213943985037_item	2291472	et	4	main
arvasin	doc_213943985037_item	2291474	et	3	main
palju	doc_213943985037_item	2291517	et	4	main
sõbraid	doc_213943985037_item	2291518	et	4	main
koos	doc_213943985037_item	2291526	et	4	main
lõpuks	doc_213943985037_item	2291529	et	4	main
ma	doc_213943985037_item	2291530	et	3	main
usun	doc_213943985037_item	2291546	et	3	main
ma	doc_213943985037_item	2291548	et	3	main
on	doc_213943985037_item	2291553	et	4	main
aitab	doc_213943985037_item	2291561	et	3	main
suvit	doc_213943985037_item	2291570	et	4	main
ei	doc_213943985037_item	2291574	et	4	main
muutma	doc_213943985037_item	2291582	et	3	main
ootan	doc_213943985037_item	2291585	et	3	main
mina	doc_213943985037_item	2291622	et	4	main
mida	doc_213943985038_item	2291635	et	4	main
nii	doc_213943985038_item	2291642	et	3	main
see	doc_213943985038_item	2291649	et	3	main
võimalus	doc_213943985038_item	2291651	et	3	main
ma	doc_213943985038_item	2291662	et	3	main
et	doc_213943985038_item	2291664	et	3	main
eriala	doc_213943985038_item	2291666	et	4	main
valisin	doc_213943985038_item	2291669	et	3	main
kõige	doc_213943985038_item	2291677	et	4	main
see	doc_213943985038_item	2291681	et	3	main
emakeelest	doc_213943985038_item	2291689	et	4	main
oma	doc_213943985038_item	2291700	et	4	main
saan	doc_213943985038_item	2291703	et	4	main
huvitavaks	doc_213943985038_item	2291706	et	4	main
rohkem	doc_213943985038_item	2291710	et	4	main
1	doc_213943985037_item	2291360	et	2	main
selle	doc_213943985037_item	2291364	et	4	main
eriala	doc_213943985037_item	2291365	et	4	main
2	doc_213943985037_item	2291366	et	2	main
et	doc_213943985037_item	2291381	et	3	main
ma	doc_213943985037_item	2291403	et	3	main
valda	doc_213943985037_item	2291405	et	4	main
põhiline	doc_213943985037_item	2291417	et	3	main
põhjus	doc_213943985037_item	2291418	et	4	main
see	doc_213943985037_item	2291420	et	3	main
mida	doc_213943985037_item	2291367	et	4	main
ootan	doc_213943985037_item	2291368	et	3	main
õppimisest	doc_213943985037_item	2291369	et	4	main
ma	doc_213943985037_item	2291376	et	3	main
valisin	doc_213943985037_item	2291377	et	3	main
eriala	doc_213943985037_item	2291378	et	4	main
sellepärast	doc_213943985037_item	2291380	et	3	main
keeles	doc_213943985037_item	2291385	et	4	main
ja	doc_213943985037_item	2291392	et	3	main
nii	doc_213943985037_item	2291408	et	3	main
hästi	doc_213943985037_item	2291409	et	3	main
ja	doc_213943985037_item	2291416	et	3	main
huvitav	doc_213943985037_item	2291424	et	4	main
ma	doc_213943985037_item	2291426	et	3	main
veendusin	doc_213943985037_item	2291430	et	3	main
kursusid	doc_213943985037_item	2291432	et	4	main
kasulikud	doc_213943985037_item	2291434	et	3	main
et	doc_213943985037_item	2291439	et	3	main
ükskõik	doc_213943985037_item	2291450	et	3	main
arvan	doc_213943985037_item	2291452	et	3	main
õppida	doc_213943985037_item	2291454	et	3	main
kogu	doc_213943985037_item	2291462	et	4	main
oli	doc_213943985037_item	2291468	et	3	main
õppeprogramm	doc_213943985037_item	2291476	et	3	main
huvitam	doc_213943985037_item	2291479	et	4	main
oli	doc_213943985037_item	2291481	et	3	main
leian	doc_213943985037_item	2291516	et	3	main
on	doc_213943985037_item	2291521	et	4	main
õppida	doc_213943985037_item	2291523	et	3	main
aastat	doc_213943985037_item	2291525	et	3	main
rühmaga	doc_213943985037_item	2291528	et	3	main
loodan	doc_213943985037_item	2291531	et	3	main
leian	doc_213943985037_item	2291549	et	3	main
loodan	doc_213943985037_item	2291557	et	3	main
ootan	doc_213943985037_item	2291568	et	3	main
ülikoolist	doc_213943985037_item	2291576	et	4	main
dekaanil	doc_213943985037_item	2291578	et	3	main
ei	doc_213943985037_item	2291579	et	4	main
ole	doc_213943985037_item	2291580	et	4	main
võimalust	doc_213943985037_item	2291581	et	3	main
kalendarit	doc_213943985037_item	2291583	et	4	main
keel	doc_213943985037_item	2291589	et	4	main
aasta	doc_213943985037_item	2291591	et	4	main
pärast	doc_213943985037_item	2291592	et	4	main
saab	doc_213943985037_item	2291593	et	3	main
ajakirjandus	doc_213943985037_item	2291425	et	3	main
õppeprogramm	doc_213943985037_item	2291428	et	3	main
on	doc_213943985037_item	2291433	et	4	main
ja	doc_213943985037_item	2291435	et	3	main
ma	doc_213943985037_item	2291437	et	3	main
elan	doc_213943985037_item	2291441	et	3	main
riigikeel	doc_213943985037_item	2291448	et	4	main
matemaatika	doc_213943985037_item	2291459	et	4	main
ja	doc_213943985037_item	2291461	et	3	main
aeg	doc_213943985037_item	2291463	et	3	main
st	doc_213943985037_item	2291467	et	3	main
peab	doc_213943985037_item	2291477	et	4	main
et	doc_213943985037_item	2291483	et	3	main
ma	doc_213943985037_item	2291484	et	3	main
läksin	doc_213943985037_item	2291485	et	3	main
õppida	doc_213943985037_item	2291486	et	3	main
matemaatikat	doc_213943985037_item	2291487	et	3	main
2	doc_213943985037_item	2291488	et	2	main
esimesena	doc_213943985037_item	2291489	et	3	main
õppimisest	doc_213943985037_item	2291490	et	4	main
ma	doc_213943985037_item	2291491	et	3	main
ootan	doc_213943985037_item	2291492	et	3	main
teadmist	doc_213943985037_item	2291493	et	4	main
ma	doc_213943985037_item	2291494	et	3	main
tahan	doc_213943985037_item	2291495	et	3	main
õppida	doc_213943985037_item	2291496	et	3	main
ja	doc_213943985037_item	2291497	et	3	main
ma	doc_213943985037_item	2291498	et	3	main
loodan	doc_213943985037_item	2291499	et	3	main
võin	doc_213943985037_item	2291500	et	3	main
siin	doc_213943985037_item	2291502	et	4	main
lõppuni	doc_213943985037_item	2291503	et	3	main
usun	doc_213943985037_item	2291504	et	3	main
õppida	doc_213943985037_item	2291501	et	3	main
et	doc_213943985037_item	2291505	et	3	main
lektorid	doc_213943985037_item	2291506	et	3	main
annavad	doc_213943985037_item	2291507	et	3	main
mulle	doc_213943985037_item	2291508	et	4	main
omad	doc_213943985037_item	2291509	et	4	main
teadmised	doc_213943985037_item	2291510	et	4	main
teisena	doc_213943985037_item	2291511	et	4	main
ma	doc_213943985037_item	2291512	et	3	main
ootan	doc_213943985037_item	2291513	et	3	main
et	doc_213943985037_item	2291514	et	3	main
emakeeles	doc_213943985037_item	2291456	et	4	main
erialas	doc_213943985037_item	2291460	et	3	main
lahendada	doc_213943985037_item	2291464	et	3	main
väga	doc_213943985037_item	2291469	et	3	main
et	doc_213943985037_item	2291475	et	3	main
see	doc_213943985037_item	2291480	et	3	main
põhjus	doc_213943985037_item	2291482	et	4	main
siin	doc_213943985037_item	2291515	et	4	main
mulle	doc_213943985037_item	2291520	et	4	main
kolm	doc_213943985037_item	2291524	et	3	main
oma	doc_213943985037_item	2291527	et	4	main
oskan	doc_213943985037_item	2291534	et	3	main
mis	doc_213943985037_item	2291541	et	4	main
et	doc_213943985037_item	2291547	et	3	main
võimalus	doc_213943985037_item	2291554	et	3	main
ajakirjanikuna	doc_213943985037_item	2291556	et	3	main
ülikool	doc_213943985037_item	2291560	et	4	main
uut	doc_213943985037_item	2291569	et	3	main
aga	doc_213943985037_item	2291571	et	3	main
kehti	doc_213943985037_item	2291575	et	4	main
minu	doc_213943985037_item	2291587	et	3	main
lõpetan	doc_213943985037_item	2291624	et	3	main
õppeaastat	doc_213943985037_item	2291627	et	3	main
miks	doc_213943985038_item	2291630	et	4	main
ma	doc_213943985038_item	2291631	et	3	main
ootan	doc_213943985038_item	2291636	et	3	main
tänapäeval	doc_213943985038_item	2291639	et	3	main
on	doc_213943985038_item	2291641	et	4	main
palju	doc_213943985038_item	2291643	et	4	main
et	doc_213943985038_item	2291652	et	3	main
ja	doc_213943985038_item	2291673	et	3	main
kultuurist	doc_213943985038_item	2291691	et	3	main
et	doc_213943985038_item	2291694	et	3	main
tahaksin	doc_213943985038_item	2291708	et	3	main
inglise	doc_213943985038_item	2291712	et	4	main
saan	doc_213943985038_item	2291718	et	4	main
täieslikult	doc_213943985038_item	2291721	et	4	main
meeldib	doc_213943985038_item	2291723	et	3	main
on	doc_213943985038_item	2291728	et	4	main
põhjus	doc_213943985038_item	2291730	et	4	main
endale	doc_213943985038_item	2291734	et	4	main
vene	doc_213943985038_item	2291737	et	4	main
siis	doc_213943985038_item	2291745	et	3	main
õigesti	doc_213943985038_item	2291750	et	3	main
sellest	doc_213943985038_item	2291755	et	4	main
nad	doc_213943985038_item	2291759	et	3	main
väga	doc_213943985038_item	2291775	et	3	main
huvi	doc_213943985038_item	2291780	et	4	main
aine	doc_213943985038_item	2291783	et	4	main
teadmisi	doc_213943985038_item	2291794	et	4	main
hästi	doc_213943985038_item	2291803	et	3	main
sõpru	doc_213943985038_item	2291809	et	3	main
teadmisi	doc_213943985038_item	2291813	et	4	main
et	doc_213943985037_item	2291532	et	3	main
kirjutada	doc_213943985037_item	2291535	et	3	main
ja	doc_213943985037_item	2291537	et	3	main
teha	doc_213943985037_item	2291538	et	3	main
asjad	doc_213943985037_item	2291540	et	3	main
kus	doc_213943985037_item	2291551	et	3	main
töötada	doc_213943985037_item	2291555	et	3	main
leida	doc_213943985037_item	2291564	et	3	main
tööd	doc_213943985037_item	2291565	et	4	main
ka	doc_213943985037_item	2291566	et	3	main
ma	doc_213943985037_item	2291567	et	3	main
see	doc_213943985037_item	2291573	et	3	main
et	doc_213943985037_item	2291586	et	3	main
ma	doc_213943985037_item	2291596	et	3	main
ootan	doc_213943985037_item	2291597	et	3	main
ülikoolist	doc_213943985037_item	2291598	et	4	main
stipeendijat	doc_213943985037_item	2291599	et	4	main
aga	doc_213943985037_item	2291600	et	3	main
see	doc_213943985037_item	2291601	et	3	main
sõltub	doc_213943985037_item	2291602	et	3	main
minu	doc_213943985037_item	2291603	et	3	main
hinnadest	doc_213943985037_item	2291604	et	4	main
vaatan	doc_213943985037_item	2291605	et	3	main
aknas	doc_213943985037_item	2291606	et	3	main
ja	doc_213943985037_item	2291607	et	3	main
ootan	doc_213943985037_item	2291608	et	3	main
uut	doc_213943985037_item	2291609	et	3	main
huvitav	doc_213943985037_item	2291611	et	4	main
hoonet	doc_213943985037_item	2291610	et	4	main
vaadata	doc_213943985037_item	2291612	et	4	main
uued	doc_213943985037_item	2291613	et	3	main
auditooriumid	doc_213943985037_item	2291614	et	3	main
uus	doc_213943985037_item	2291615	et	3	main
mööbel	doc_213943985037_item	2291616	et	3	main
kõik	doc_213943985037_item	2291617	et	4	main
lähevad	doc_213943985037_item	2291618	et	3	main
klassist	doc_213943985037_item	2291619	et	3	main
ära	doc_213943985037_item	2291620	et	4	main
ka	doc_213943985037_item	2291623	et	3	main
valisin	doc_213943985038_item	2291632	et	3	main
õppimisest	doc_213943985038_item	2291637	et	4	main
ning	doc_213943985038_item	2291646	et	3	main
noortele	doc_213943985038_item	2291647	et	3	main
see	doc_213943985038_item	2291665	et	3	main
mis	doc_213943985038_item	2291667	et	4	main
endale	doc_213943985038_item	2291670	et	4	main
sobib	doc_213943985038_item	2291671	et	3	main
mulle	doc_213943985038_item	2291672	et	4	main
võib	doc_213943985038_item	2291674	et	3	main
mind	doc_213943985038_item	2291679	et	4	main
et	doc_213943985038_item	2291682	et	3	main
maade	doc_213943985038_item	2291690	et	3	main
ma	doc_213943985038_item	2291696	et	3	main
heaks	doc_213943985038_item	2291698	et	4	main
ka	doc_213943985038_item	2291709	et	3	main
õppida	doc_213943985038_item	2291711	et	3	main
ja	doc_213943985038_item	2291713	et	3	main
head	doc_213943985037_item	2291625	et	4	main
uut	doc_213943985037_item	2291626	et	3	main
selle	doc_213943985038_item	2291633	et	4	main
ülikoolis	doc_213943985038_item	2291638	et	4	main
maailmas	doc_213943985038_item	2291640	et	3	main
inimestele	doc_213943985038_item	2291648	et	3	main
annab	doc_213943985038_item	2291650	et	3	main
endale	doc_213943985038_item	2291654	et	4	main
nimelt	doc_213943985038_item	2291655	et	4	main
seda	doc_213943985038_item	2291656	et	3	main
mis	doc_213943985038_item	2291657	et	4	main
neid	doc_213943985038_item	2291658	et	4	main
kõige	doc_213943985038_item	2291659	et	4	main
rohkem	doc_213943985038_item	2291660	et	4	main
huvitab	doc_213943985038_item	2291661	et	3	main
siis	doc_213943985037_item	2291621	et	3	main
kõigile	doc_213943985037_item	2291628	et	4	main
essee	doc_213943985038_item	2291629	et	4	main
eriala	doc_213943985038_item	2291634	et	4	main
huvitavaid	doc_213943985038_item	2291644	et	4	main
elukutse	doc_213943985038_item	2291645	et	4	main
valida	doc_213943985038_item	2291653	et	3	main
ma	doc_213943985038_item	2291668	et	3	main
sobib	doc_213943985038_item	2291676	et	3	main
ajaloost	doc_213943985038_item	2291692	et	4	main
loodan	doc_213943985038_item	2291693	et	3	main
inimeseks	doc_213943985038_item	2291707	et	3	main
et	doc_213943985038_item	2291717	et	3	main
neid	doc_213943985038_item	2291720	et	4	main
mulle	doc_213943985038_item	2291722	et	4	main
miks	doc_213943985038_item	2291731	et	4	main
ma	doc_213943985038_item	2291732	et	3	main
keel	doc_213943985038_item	2291738	et	4	main
nagu	doc_213943985038_item	2291739	et	3	main
võõrkeel	doc_213943985038_item	2291740	et	4	main
kui	doc_213943985038_item	2291741	et	3	main
saan	doc_213943985038_item	2291743	et	4	main
pealt	doc_213943985038_item	2291747	et	4	main
inimestega	doc_213943985038_item	2291752	et	3	main
sõltub	doc_213943985038_item	2291756	et	3	main
mind	doc_213943985038_item	2291760	et	4	main
et	doc_213943985038_item	2291764	et	3	main
õpetati	doc_213943985038_item	2291766	et	3	main
täpselt	doc_213943985038_item	2291769	et	4	main
et	doc_213943985038_item	2291770	et	3	main
on	doc_213943985038_item	2291772	et	4	main
ka	doc_213943985038_item	2291781	et	3	main
nagu	doc_213943985038_item	2291784	et	3	main
ma	doc_213943985038_item	2291789	et	3	main
selle	doc_213943985038_item	2291796	et	4	main
ja	doc_213943985038_item	2291810	et	3	main
ma	doc_213943985038_item	2291821	et	3	main
arvan	doc_213943985038_item	2291663	et	3	main
olla	doc_213943985038_item	2291675	et	3	main
rohkem	doc_213943985038_item	2291678	et	4	main
huvitab	doc_213943985038_item	2291680	et	3	main
nüüd	doc_213943985038_item	2291683	et	4	main
ma	doc_213943985038_item	2291684	et	3	main
saan	doc_213943985038_item	2291685	et	4	main
rohkem	doc_213943985038_item	2291686	et	4	main
teada	doc_213943985038_item	2291687	et	3	main
oma	doc_213943985038_item	2291688	et	4	main
tulevikul	doc_213943985038_item	2291695	et	4	main
saan	doc_213943985038_item	2291697	et	4	main
spetsialistiks	doc_213943985038_item	2291699	et	3	main
erialas	doc_213943985038_item	2291701	et	3	main
ning	doc_213943985038_item	2291702	et	3	main
haritud	doc_213943985038_item	2291704	et	4	main
ja	doc_213943985038_item	2291705	et	3	main
keelt	doc_213943985038_item	2291715	et	4	main
loodan	doc_213943985038_item	2291716	et	3	main
teine	doc_213943985038_item	2291729	et	3	main
eriala	doc_213943985038_item	2291736	et	4	main
ma	doc_213943985038_item	2291742	et	3	main
õpetajaks	doc_213943985038_item	2291744	et	4	main
peaksin	doc_213943985038_item	2291749	et	4	main
suheldada	doc_213943985038_item	2291751	et	4	main
saavad	doc_213943985038_item	2291758	et	4	main
aru	doc_213943985038_item	2291762	et	4	main
mind	doc_213943985038_item	2291765	et	4	main
see	doc_213943985038_item	2291771	et	3	main
selline	doc_213943985038_item	2291782	et	4	main
psühholoogia	doc_213943985038_item	2291785	et	4	main
ülikoolis	doc_213943985038_item	2291788	et	4	main
saan	doc_213943985038_item	2291790	et	4	main
uusi	doc_213943985038_item	2291791	et	3	main
ja	doc_213943985038_item	2291792	et	3	main
tähtsaid	doc_213943985038_item	2291793	et	3	main
kohta	doc_213943985038_item	2291797	et	4	main
loodan	doc_213943985038_item	2291798	et	3	main
et	doc_213943985038_item	2291799	et	3	main
minu	doc_213943985038_item	2291800	et	3	main
ülikoolielu	doc_213943985038_item	2291801	et	4	main
et	doc_213943985038_item	2291804	et	3	main
saan	doc_213943985038_item	2291811	et	4	main
palju	doc_213943985038_item	2291812	et	4	main
ning	doc_213943985038_item	2291814	et	3	main
ei	doc_213943985038_item	2291822	et	4	main
et	doc_213943985038_item	2291824	et	3	main
valisin	doc_213943985038_item	2291825	et	3	main
eesti	doc_213943985038_item	2291714	et	4	main
omandada	doc_213943985038_item	2291719	et	3	main
ning	doc_213943985038_item	2291726	et	3	main
valisin	doc_213943985038_item	2291733	et	3	main
kõige	doc_213943985038_item	2291746	et	4	main
arvan	doc_213943985038_item	2291753	et	3	main
et	doc_213943985038_item	2291754	et	3	main
hästi	doc_213943985038_item	2291761	et	3	main
tahan	doc_213943985038_item	2291763	et	3	main
jaoks	doc_213943985038_item	2291774	et	4	main
eriala	doc_213943985038_item	2291777	et	4	main
et	doc_213943985038_item	2291787	et	3	main
ka	doc_213943985038_item	2291795	et	3	main
läheb	doc_213943985038_item	2291802	et	3	main
ülikoolist	doc_213943985038_item	2291807	et	4	main
hea	doc_213943985038_item	2291816	et	4	main
eksinud	doc_213943985038_item	2291823	et	4	main
nimelt	doc_213943985038_item	2291826	et	4	main
suheldada	doc_213943985038_item	2291724	et	4	main
inimestega	doc_213943985038_item	2291725	et	3	main
see	doc_213943985038_item	2291727	et	3	main
selle	doc_213943985038_item	2291735	et	4	main
ma	doc_213943985038_item	2291748	et	3	main
kas	doc_213943985038_item	2291757	et	3	main
õpetada	doc_213943985038_item	2291767	et	3	main
tean	doc_213943985038_item	2291768	et	3	main
minu	doc_213943985038_item	2291773	et	3	main
huvitav	doc_213943985038_item	2291776	et	4	main
mulle	doc_213943985038_item	2291778	et	4	main
pakkub	doc_213943985038_item	2291779	et	4	main
ootan	doc_213943985038_item	2291786	et	3	main
ma	doc_213943985038_item	2291805	et	3	main
leian	doc_213943985038_item	2291806	et	3	main
uusi	doc_213943985038_item	2291808	et	3	main
saan	doc_213943985038_item	2291815	et	4	main
elu	doc_213943985038_item	2291817	et	4	main
kogemuse	doc_213943985038_item	2291818	et	3	main
arvan	doc_213943985038_item	2291819	et	3	main
et	doc_213943985038_item	2291820	et	3	main
selle	doc_213943985038_item	2291827	et	4	main
eriala	doc_213943985038_item	2291828	et	4	main
1	doc_213943985041_item	2292180	et	2	main
miks	doc_213943985041_item	2292181	et	4	main
2	doc_213943985041_item	2292186	et	2	main
tulevikust	doc_213943985041_item	2292200	et	4	main
esialgu	doc_213943985041_item	2292209	et	3	main
lugenud	doc_213943985041_item	2292211	et	4	main
jutustusi	doc_213943985041_item	2292213	et	4	main
maailmakirjandus	doc_213943985041_item	2292224	et	3	main
mulle	doc_213943985041_item	2292230	et	4	main
meeldis	doc_213943985041_item	2292231	et	3	main
kirjutada	doc_213943985041_item	2292232	et	3	main
ja	doc_213943985041_item	2292234	et	3	main
tegin	doc_213943985041_item	2292235	et	3	main
meelsasti	doc_213943985041_item	2292237	et	3	main
ei	doc_213943985041_item	2292239	et	4	main
võib	doc_213943985041_item	2292244	et	3	main
see	doc_213943985041_item	2292246	et	3	main
ma	doc_213943985041_item	2292251	et	3	main
ma	doc_213943985041_item	2292268	et	3	main
tulengi	doc_213943985041_item	2292269	et	3	main
siia	doc_213943985041_item	2292270	et	4	main
õppima	doc_213943985041_item	2292271	et	3	main
muidugi	doc_213943985041_item	2292273	et	4	main
hea	doc_213943985041_item	2292277	et	4	main
valisin	doc_213943985042_item	2292317	et	3	main
selle	doc_213943985041_item	2292184	et	4	main
ja	doc_213943985041_item	2292192	et	3	main
olen	doc_213943985041_item	2292205	et	3	main
ka	doc_213943985041_item	2292228	et	3	main
seda	doc_213943985041_item	2292236	et	3	main
kes	doc_213943985041_item	2292242	et	4	main
olla	doc_213943985041_item	2292245	et	3	main
minu	doc_213943985041_item	2292248	et	3	main
minna	doc_213943985041_item	2292257	et	3	main
kuna	doc_213943985041_item	2292259	et	3	main
saab	doc_213943985041_item	2292261	et	3	main
kirjanikuks	doc_213943985041_item	2292262	et	3	main
teie	doc_213943985041_item	2292264	et	4	main
meie	doc_213943985041_item	2292265	et	4	main
tallinna	doc_213943985041_item	2292266	et	4	main
ülikoolis	doc_213943985041_item	2292267	et	4	main
siin	doc_213943985041_item	2292276	et	4	main
miks	doc_213943985042_item	2292315	et	4	main
2	doc_213943985042_item	2292320	et	2	main
ma	doc_213943985042_item	2292322	et	3	main
tallinna	doc_213943985042_item	2292330	et	4	main
ma	doc_213943985042_item	2292340	et	3	main
ära	doc_213943985042_item	2292348	et	4	main
tuli	doc_213943985042_item	2292350	et	4	main
mitte	doc_213943985042_item	2292359	et	3	main
ma	doc_213943985042_item	2292365	et	3	main
oma	doc_213943985042_item	2292368	et	4	main
magistritööst	doc_213943985042_item	2292370	et	3	main
kahjuks	doc_213943985042_item	2292371	et	4	main
võib	doc_213943985042_item	2292377	et	3	main
valida	doc_213943985042_item	2292393	et	3	main
ma	doc_213943985042_item	2292400	et	3	main
ikka	doc_213943985042_item	2292401	et	4	main
õppida	doc_213943985042_item	2292403	et	3	main
ja	doc_213943985042_item	2292405	et	3	main
täis	doc_213943985042_item	2292407	et	4	main
ainult	doc_213943985042_item	2292411	et	4	main
võiksin	doc_213943985042_item	2292421	et	3	main
keel	doc_213943985042_item	2292429	et	4	main
võõrkeelena	doc_213943985042_item	2292430	et	3	main
miks	doc_213943985042_item	2292438	et	4	main
tegelikult	doc_213943985042_item	2292441	et	4	main
koolis	doc_213943985042_item	2292443	et	4	main
kuidagi	doc_213943985042_item	2292458	et	3	main
hirmus	doc_213943985042_item	2292461	et	4	main
praegu	doc_213943985042_item	2292462	et	3	main
tööle	doc_213943985042_item	2292469	et	3	main
vene	doc_213943985042_item	2292474	et	4	main
eesti	doc_213943985042_item	2292477	et	4	main
raskem	doc_213943985042_item	2292483	et	4	main
on	doc_213943985042_item	2292489	et	4	main
vene	doc_213943985042_item	2292491	et	4	main
ma	doc_213943985042_item	2292493	et	3	main
või	doc_213943985042_item	2292504	et	4	main
väga	doc_213943985042_item	2292509	et	3	main
tahaks	doc_213943985042_item	2292516	et	3	main
aidata	doc_213943985042_item	2292518	et	4	main
ilu	doc_213943985042_item	2292522	et	4	main
essee	doc_213943985041_item	2292179	et	4	main
eriala	doc_213943985041_item	2292185	et	4	main
õppimisest	doc_213943985041_item	2292189	et	4	main
erialal	doc_213943985041_item	2292191	et	3	main
elukutsest	doc_213943985041_item	2292201	et	4	main
ja	doc_213943985041_item	2292202	et	3	main
alati	doc_213943985041_item	2292203	et	4	main
palju	doc_213943985041_item	2292206	et	4	main
olen	doc_213943985041_item	2292210	et	3	main
muinasjutte	doc_213943985041_item	2292212	et	3	main
huvitas	doc_213943985041_item	2292221	et	3	main
teaduskirjandus	doc_213943985041_item	2292223	et	3	main
nii	doc_213943985041_item	2292226	et	3	main
edasi	doc_213943985041_item	2292227	et	3	main
täpselt	doc_213943985041_item	2292238	et	4	main
aga	doc_213943985041_item	2292241	et	3	main
2	doc_213943985041_item	2292250	et	2	main
kaua	doc_213943985041_item	2292253	et	3	main
kuhu	doc_213943985041_item	2292255	et	3	main
saan	doc_213943985041_item	2292275	et	4	main
selle	doc_213943985042_item	2292318	et	4	main
lõpetasin	doc_213943985042_item	2292328	et	3	main
eriala	doc_213943985042_item	2292335	et	4	main
ja	doc_213943985042_item	2292336	et	3	main
ikka	doc_213943985042_item	2292341	et	4	main
lihtsalt	doc_213943985042_item	2292347	et	4	main
miks	doc_213943985042_item	2292358	et	4	main
pidin	doc_213943985042_item	2292366	et	3	main
kohale	doc_213943985042_item	2292373	et	4	main
olla	doc_213943985042_item	2292378	et	3	main
rõõmuks	doc_213943985042_item	2292379	et	3	main
mulle	doc_213943985042_item	2292381	et	4	main
eriala	doc_213943985042_item	2292383	et	4	main
ei	doc_213943985042_item	2292384	et	4	main
ma	doc_213943985042_item	2292387	et	3	main
programmi	doc_213943985042_item	2292390	et	4	main
järgi	doc_213943985042_item	2292391	et	4	main
sain	doc_213943985042_item	2292392	et	3	main
ja	doc_213943985042_item	2292398	et	3	main
valida	doc_213943985042_item	2292422	et	3	main
eriala	doc_213943985042_item	2292424	et	4	main
ja	doc_213943985042_item	2292426	et	3	main
päevõppe	doc_213943985042_item	2292427	et	4	main
vene	doc_213943985042_item	2292428	et	4	main
praegu	doc_213943985042_item	2292436	et	3	main
eriala	doc_213943985042_item	2292440	et	4	main
keel	doc_213943985042_item	2292447	et	4	main
vene	doc_213943985042_item	2292448	et	4	main
õpetada	doc_213943985042_item	2292472	et	3	main
kooli	doc_213943985042_item	2292475	et	4	main
töötada	doc_213943985042_item	2292484	et	3	main
emakeel	doc_213943985042_item	2292488	et	4	main
ja	doc_213943985042_item	2292495	et	3	main
meie	doc_213943985042_item	2292497	et	4	main
noored	doc_213943985042_item	2292499	et	3	main
vene	doc_213943985042_item	2292506	et	4	main
keelt	doc_213943985042_item	2292507	et	4	main
kui	doc_213943985042_item	2292512	et	3	main
võib	doc_213943985042_item	2292513	et	3	main
öelda	doc_213943985042_item	2292515	et	4	main
neid	doc_213943985042_item	2292517	et	4	main
keele	doc_213943985042_item	2292521	et	4	main
koputada	doc_213943985042_item	2292523	et	3	main
nende	doc_213943985042_item	2292524	et	4	main
südamesse	doc_213943985042_item	2292525	et	4	main
olla	doc_213943985042_item	2292530	et	3	main
sõbrad	doc_213943985042_item	2292533	et	3	main
oleksid	doc_213943985042_item	2292538	et	4	main
on	doc_213943985042_item	2292575	et	4	main
mida	doc_213943985041_item	2292187	et	4	main
tlus	doc_213943985041_item	2292193	et	4	main
lapsepõlvest	doc_213943985041_item	2292195	et	4	main
ma	doc_213943985041_item	2292197	et	3	main
lugenud	doc_213943985041_item	2292207	et	4	main
igasuguseid	doc_213943985041_item	2292215	et	3	main
väikesi	doc_213943985041_item	2292216	et	4	main
vanemates	doc_213943985041_item	2292218	et	4	main
raamatuid	doc_213943985041_item	2292217	et	3	main
klassides	doc_213943985041_item	2292219	et	3	main
mind	doc_213943985041_item	2292220	et	4	main
ma	doc_213943985041_item	2292182	et	3	main
valisin	doc_213943985041_item	2292183	et	3	main
ootan	doc_213943985041_item	2292188	et	3	main
sellel	doc_213943985041_item	2292190	et	4	main
1	doc_213943985041_item	2292194	et	2	main
saadik	doc_213943985041_item	2292196	et	4	main
olen	doc_213943985041_item	2292198	et	3	main
mõelnud	doc_213943985041_item	2292199	et	4	main
ma	doc_213943985041_item	2292204	et	3	main
loomulikult	doc_213943985041_item	2292208	et	4	main
ja	doc_213943985041_item	2292214	et	3	main
ilukirjandus	doc_213943985041_item	2292222	et	3	main
koolis	doc_213943985041_item	2292229	et	4	main
ütle	doc_213943985041_item	2292240	et	4	main
on	doc_213943985041_item	2292247	et	4	main
kutsumus	doc_213943985041_item	2292249	et	3	main
olen	doc_213943985041_item	2292252	et	3	main
mõelnud	doc_213943985041_item	2292254	et	4	main
ja	doc_213943985041_item	2292258	et	3	main
tallinnas	doc_213943985041_item	2292260	et	4	main
loodan	doc_213943985041_item	2292272	et	3	main
et	doc_213943985041_item	2292274	et	3	main
hariduse	doc_213943985041_item	2292278	et	3	main
eriala	doc_213943985042_item	2292319	et	4	main
ootan	doc_213943985042_item	2292323	et	3	main
ülikoolis	doc_213943985042_item	2292325	et	4	main
see	doc_213943985042_item	2292332	et	3	main
aasta	doc_213943985042_item	2292333	et	4	main
klassiõpetaja	doc_213943985042_item	2292334	et	4	main
sain	doc_213943985042_item	2292337	et	3	main
teadsin	doc_213943985042_item	2292339	et	3	main
ei	doc_213943985042_item	2292343	et	4	main
siit	doc_213943985042_item	2292345	et	3	main
mitte	doc_213943985042_item	2292354	et	3	main
magistriõppe	doc_213943985042_item	2292355	et	4	main
tõesti	doc_213943985042_item	2292357	et	3	main
tasuta	doc_213943985042_item	2292372	et	4	main
ei	doc_213943985042_item	2292375	et	4	main
meeldinud	doc_213943985042_item	2292385	et	4	main
ainult	doc_213943985042_item	2292394	et	4	main
kasvatusteadused	doc_213943985042_item	2292399	et	3	main
tahtsin	doc_213943985042_item	2292402	et	3	main
eripedagoogikat	doc_213943985042_item	2292404	et	3	main
päevõppet	doc_213943985042_item	2292406	et	4	main
koormusega	doc_213943985042_item	2292408	et	3	main
ja	doc_213943985041_item	2292225	et	3	main
kirjandeid	doc_213943985041_item	2292233	et	3	main
teab	doc_213943985041_item	2292243	et	3	main
õppima	doc_213943985041_item	2292256	et	3	main
õppida	doc_213943985041_item	2292263	et	3	main
ja	doc_213943985041_item	2292279	et	3	main
hakkan	doc_213943985041_item	2292280	et	3	main
töötama	doc_213943985041_item	2292281	et	3	main
oma	doc_213943985041_item	2292282	et	4	main
erialal	doc_213943985041_item	2292283	et	3	main
sest	doc_213943985041_item	2292284	et	4	main
arvan	doc_213943985041_item	2292285	et	3	main
et	doc_213943985041_item	2292286	et	3	main
sellel	doc_213943985041_item	2292287	et	4	main
alal	doc_213943985041_item	2292288	et	4	main
minu	doc_213943985041_item	2292289	et	3	main
võimalused	doc_213943985041_item	2292290	et	3	main
pole	doc_213943985041_item	2292291	et	3	main
nii	doc_213943985041_item	2292292	et	3	main
halvad	doc_213943985041_item	2292293	et	4	main
veel	doc_213943985041_item	2292294	et	4	main
ootan	doc_213943985041_item	2292295	et	3	main
oma	doc_213943985041_item	2292296	et	4	main
uutest	doc_213943985041_item	2292297	et	3	main
õppetajatest	doc_213943985041_item	2292298	et	4	main
suuremat	doc_213943985041_item	2292299	et	4	main
professionaalset	doc_213943985041_item	2292300	et	3	main
taset	doc_213943985041_item	2292301	et	3	main
kui	doc_213943985041_item	2292302	et	3	main
koolis	doc_213943985041_item	2292303	et	4	main
ja	doc_213943985041_item	2292304	et	3	main
üldse	doc_213943985041_item	2292305	et	3	main
öeldakse	doc_213943985041_item	2292306	et	3	main
tudengi	doc_213943985041_item	2292307	et	3	main
aastat	doc_213943985041_item	2292308	et	3	main
on	doc_213943985041_item	2292309	et	4	main
aastat	doc_213943985041_item	2292311	et	3	main
parimad	doc_213943985041_item	2292310	et	4	main
elus	doc_213943985041_item	2292312	et	4	main
1	doc_213943985042_item	2292314	et	2	main
essee	doc_213943985042_item	2292313	et	4	main
ma	doc_213943985042_item	2292316	et	3	main
mida	doc_213943985042_item	2292321	et	4	main
ma	doc_213943985042_item	2292329	et	3	main
pedagoogikaülikooli	doc_213943985042_item	2292331	et	4	main
diplomi	doc_213943985042_item	2292338	et	3	main
et	doc_213943985042_item	2292342	et	3	main
nii	doc_213943985042_item	2292346	et	3	main
minna	doc_213943985042_item	2292349	et	3	main
mõte	doc_213943985042_item	2292351	et	3	main
alguses	doc_213943985042_item	2292361	et	4	main
oli	doc_213943985042_item	2292362	et	3	main
kus	doc_213943985042_item	2292364	et	3	main
rääkida	doc_213943985042_item	2292367	et	3	main
saanud	doc_213943985042_item	2292376	et	4	main
tegelikult	doc_213943985042_item	2292380	et	4	main
kuna	doc_213943985042_item	2292386	et	3	main
vana	doc_213943985042_item	2292389	et	4	main
2	doc_213943985042_item	2292395	et	2	main
andragoogika	doc_213943985042_item	2292397	et	4	main
aga	doc_213943985042_item	2292409	et	3	main
sain	doc_213943985042_item	2292410	et	3	main
2	doc_213943985042_item	2292423	et	2	main
valisin	doc_213943985042_item	2292431	et	3	main
teise	doc_213943985042_item	2292433	et	4	main
olen	doc_213943985042_item	2292435	et	3	main
ajalugu	doc_213943985042_item	2292449	et	4	main
vene	doc_213943985042_item	2292450	et	4	main
julgenud	doc_213943985042_item	2292460	et	4	main
ilmus	doc_213943985042_item	2292463	et	4	main
keelt	doc_213943985042_item	2292471	et	4	main
kooli	doc_213943985042_item	2292478	et	4	main
vist	doc_213943985042_item	2292479	et	4	main
on	doc_213943985042_item	2292480	et	4	main
võõras	doc_213943985042_item	2292486	et	4	main
praegu	doc_213943985042_item	2292496	et	3	main
elus	doc_213943985042_item	2292498	et	4	main
eestlased	doc_213943985042_item	2292500	et	3	main
ei	doc_213943985042_item	2292501	et	4	main
kas	doc_213943985042_item	2292503	et	3	main
üldse	doc_213943985042_item	2292505	et	3	main
väga	doc_213943985042_item	2292510	et	3	main
näidata	doc_213943985042_item	2292519	et	4	main
vene	doc_213943985042_item	2292520	et	4	main
seal	doc_213943985042_item	2292532	et	4	main
head	doc_213943985042_item	2292534	et	4	main
tuttavad	doc_213943985042_item	2292535	et	4	main
ka	doc_213943985042_item	2292539	et	3	main
lastele	doc_213943985042_item	2292543	et	4	main
et	doc_213943985042_item	2292545	et	3	main
sõprus	doc_213943985042_item	2292547	et	3	main
saanud	doc_213943985042_item	2292555	et	4	main
ühes	doc_213943985042_item	2292571	et	4	main
klassis	doc_213943985042_item	2292572	et	3	main
kindlasti	doc_213943985042_item	2292573	et	3	main
mida	doc_213943985042_item	2292580	et	4	main
ootan	doc_213943985042_item	2292582	et	3	main
ma	doc_213943985042_item	2292584	et	3	main
raske	doc_213943985042_item	2292587	et	4	main
oli	doc_213943985042_item	2292589	et	3	main
nii	doc_213943985042_item	2292590	et	3	main
palju	doc_213943985042_item	2292591	et	4	main
mõtteid	doc_213943985042_item	2292592	et	3	main
ootan	doc_213943985042_item	2292601	et	3	main
mõelnud	doc_213943985042_item	2292604	et	4	main
mõelda	doc_213943985042_item	2292610	et	4	main
õpin	doc_213943985042_item	2292620	et	3	main
tunnen	doc_213943985042_item	2292622	et	3	main
proov	doc_213943985042_item	2292634	et	3	main
praegu	doc_213943985042_item	2292636	et	3	main
on	doc_213943985042_item	2292637	et	4	main
tahtsin	doc_213943985042_item	2292645	et	3	main
saaks	doc_213943985042_item	2292650	et	3	main
mis	doc_213943985042_item	2292653	et	4	main
tehtud	doc_213943985042_item	2292662	et	4	main
aega	doc_213943985042_item	2292666	et	4	main
ülikooli	doc_213943985042_item	2292667	et	4	main
ju	doc_213943985042_item	2292672	et	3	main
laps	doc_213943985042_item	2292677	et	4	main
võin	doc_213943985042_item	2292707	et	3	main
saavutada	doc_213943985042_item	2292708	et	3	main
kõike	doc_213943985042_item	2292710	et	4	main
kõike	doc_213943985042_item	2292711	et	4	main
õppimisest	doc_213943985042_item	2292324	et	4	main
1	doc_213943985042_item	2292326	et	2	main
tegelikult	doc_213943985042_item	2292327	et	4	main
tahaks	doc_213943985042_item	2292344	et	3	main
pähe	doc_213943985042_item	2292352	et	4	main
miks	doc_213943985042_item	2292353	et	4	main
õppida	doc_213943985042_item	2292356	et	3	main
juuli	doc_213943985042_item	2292360	et	4	main
vestlus	doc_213943985042_item	2292363	et	3	main
tulevikust	doc_213943985042_item	2292369	et	4	main
ma	doc_213943985042_item	2292374	et	3	main
see	doc_213943985042_item	2292382	et	3	main
õppisin	doc_213943985042_item	2292388	et	3	main
võimalust	doc_213943985042_item	2292396	et	3	main
tasuliselt	doc_213943985042_item	2292412	et	4	main
tsükkelõppet	doc_213943985042_item	2292413	et	4	main
ja	doc_213943985042_item	2292414	et	3	main
ei	doc_213943985042_item	2292415	et	4	main
meeldinud	doc_213943985042_item	2292416	et	4	main
eriala	doc_213943985042_item	2292417	et	4	main
kuna	doc_213943985042_item	2292418	et	3	main
ülikooli	doc_213943985042_item	2292419	et	4	main
astumisel	doc_213943985042_item	2292420	et	4	main
ja	doc_213943985042_item	2292434	et	3	main
rõõmus	doc_213943985042_item	2292437	et	4	main
mulle	doc_213943985042_item	2292445	et	4	main
vene	doc_213943985042_item	2292446	et	4	main
ei	doc_213943985042_item	2292459	et	4	main
võimalus	doc_213943985042_item	2292465	et	3	main
et	doc_213943985042_item	2292466	et	3	main
tulevikus	doc_213943985042_item	2292467	et	4	main
mina	doc_213943985042_item	2292468	et	4	main
mitte	doc_213943985042_item	2292473	et	3	main
koolis	doc_213943985042_item	2292485	et	4	main
teine	doc_213943985042_item	2292490	et	3	main
aga	doc_213943985042_item	2292492	et	3	main
vähe	doc_213943985042_item	2292511	et	3	main
nii	doc_213943985042_item	2292514	et	3	main
magistriõppe	doc_213943985042_item	2292425	et	4	main
lõpuks	doc_213943985042_item	2292432	et	4	main
see	doc_213943985042_item	2292439	et	3	main
juba	doc_213943985042_item	2292442	et	3	main
meeldis	doc_213943985042_item	2292444	et	3	main
kirjandus	doc_213943985042_item	2292451	et	3	main
aga	doc_213943985042_item	2292452	et	3	main
vene	doc_213943985042_item	2292453	et	4	main
kooli	doc_213943985042_item	2292454	et	4	main
õpetada	doc_213943985042_item	2292455	et	3	main
seda	doc_213943985042_item	2292456	et	3	main
ainet	doc_213943985042_item	2292457	et	3	main
selline	doc_213943985042_item	2292464	et	4	main
vene	doc_213943985042_item	2292470	et	4	main
vaid	doc_213943985042_item	2292476	et	3	main
see	doc_213943985042_item	2292481	et	3	main
veel	doc_213943985042_item	2292482	et	4	main
koolis	doc_213943985042_item	2292487	et	4	main
tahan	doc_213943985042_item	2292494	et	3	main
valda	doc_213943985042_item	2292502	et	4	main
või	doc_213943985042_item	2292508	et	4	main
miks	doc_213943985042_item	2292526	et	4	main
mitte	doc_213943985042_item	2292527	et	3	main
võib	doc_213943985042_item	2292529	et	3	main
minu	doc_213943985042_item	2292542	et	3	main
venelaste	doc_213943985042_item	2292548	et	4	main
ja	doc_213943985042_item	2292549	et	3	main
eestlaste	doc_213943985042_item	2292550	et	4	main
vahel	doc_213943985042_item	2292551	et	4	main
võib	doc_213943985042_item	2292552	et	3	main
saab	doc_213943985042_item	2292574	et	3	main
küsimus	doc_213943985042_item	2292588	et	4	main
kuhugi	doc_213943985042_item	2292595	et	4	main
ära	doc_213943985042_item	2292596	et	4	main
või	doc_213943985042_item	2292608	et	4	main
peas	doc_213943985042_item	2292611	et	4	main
lihtsalt	doc_213943985042_item	2292615	et	4	main
proovida	doc_213943985042_item	2292528	et	3	main
tekkivad	doc_213943985042_item	2292531	et	4	main
sõbrad	doc_213943985042_item	2292541	et	3	main
oleks	doc_213943985042_item	2292546	et	3	main
olen	doc_213943985042_item	2292556	et	3	main
kindel	doc_213943985042_item	2292557	et	3	main
et	doc_213943985042_item	2292558	et	3	main
tuleb	doc_213943985042_item	2292559	et	3	main
kindlasti	doc_213943985042_item	2292560	et	3	main
midagi	doc_213943985042_item	2292561	et	4	main
välja	doc_213943985042_item	2292562	et	4	main
kõik	doc_213943985042_item	2292563	et	4	main
vist	doc_213943985042_item	2292564	et	4	main
ei	doc_213943985042_item	2292565	et	4	main
saa	doc_213943985042_item	2292566	et	4	main
muuta	doc_213943985042_item	2292567	et	4	main
aga	doc_213943985042_item	2292568	et	3	main
kelle	doc_213943985042_item	2292536	et	4	main
lapsed	doc_213943985042_item	2292537	et	3	main
head	doc_213943985042_item	2292540	et	4	main
tahaks	doc_213943985042_item	2292544	et	3	main
olla	doc_213943985042_item	2292553	et	3	main
ei	doc_213943985042_item	2292554	et	4	main
lihtsalt	doc_213943985042_item	2292577	et	4	main
tehta	doc_213943985042_item	2292578	et	3	main
ma	doc_213943985042_item	2292581	et	3	main
lendasid	doc_213943985042_item	2292594	et	4	main
kõik	doc_213943985042_item	2292597	et	4	main
mis	doc_213943985042_item	2292598	et	4	main
võimalik	doc_213943985042_item	2292599	et	3	main
seda	doc_213943985042_item	2292600	et	3	main
praegu	doc_213943985042_item	2292602	et	3	main
raske	doc_213943985042_item	2292609	et	4	main
ja	doc_213943985042_item	2292612	et	3	main
on	doc_213943985042_item	2292614	et	4	main
rõõmus	doc_213943985042_item	2292616	et	4	main
ja	doc_213943985042_item	2292617	et	3	main
miks	doc_213943985042_item	2292625	et	4	main
ma	doc_213943985042_item	2292626	et	3	main
õppisin	doc_213943985042_item	2292628	et	3	main
vist	doc_213943985042_item	2292635	et	4	main
see	doc_213943985042_item	2292638	et	3	main
ja	doc_213943985042_item	2292646	et	3	main
ootan	doc_213943985042_item	2292648	et	3	main
oleks	doc_213943985042_item	2292659	et	3	main
ajaks	doc_213943985042_item	2292661	et	4	main
ootan	doc_213943985042_item	2292663	et	3	main
jaoks	doc_213943985042_item	2292670	et	4	main
nii	doc_213943985042_item	2292673	et	3	main
ühes	doc_213943985042_item	2292569	et	4	main
koolis	doc_213943985042_item	2292570	et	4	main
vaja	doc_213943985042_item	2292576	et	4	main
2	doc_213943985042_item	2292579	et	2	main
mida	doc_213943985042_item	2292583	et	4	main
kõik	doc_213943985042_item	2292593	et	4	main
ei	doc_213943985042_item	2292603	et	4	main
üldse	doc_213943985042_item	2292605	et	3	main
selle	doc_213943985042_item	2292606	et	4	main
peale	doc_213943985042_item	2292607	et	4	main
õnne	doc_213943985042_item	2292618	et	4	main
tõsiselt	doc_213943985042_item	2292639	et	4	main
mõeldud	doc_213943985042_item	2292640	et	4	main
ma	doc_213943985042_item	2292643	et	3	main
ootan	doc_213943985042_item	2292647	et	3	main
kõik	doc_213943985042_item	2292657	et	4	main
jaoks	doc_213943985042_item	2292668	et	4	main
õppimise	doc_213943985042_item	2292669	et	4	main
õppida	doc_213943985042_item	2292675	et	3	main
lihtsalt	doc_213943985042_item	2292714	et	4	main
ootan	doc_213943985042_item	2292717	et	3	main
oleks	doc_213943985042_item	2292719	et	3	main
õppimise	doc_213943985042_item	2292722	et	4	main
jaoks	doc_213943985042_item	2292723	et	4	main
ka	doc_213943985042_item	2292733	et	3	main
24	doc_213943985042_item	2292748	et	2	main
h	doc_213943985042_item	2292749	et	4	main
või	doc_213943985042_item	2292752	et	4	main
loodan	doc_213943985042_item	2292757	et	3	main
jõuan	doc_213943985042_item	2292759	et	3	main
teha	doc_213943985042_item	2292761	et	3	main
pean	doc_213943985042_item	2292763	et	4	main
ma	doc_213943985043_item	2292766	et	3	main
valisin	doc_213943985043_item	2292767	et	3	main
inimene	doc_213943985043_item	2292805	et	3	main
see	doc_213943985043_item	2292806	et	3	main
tunne	doc_213943985043_item	2292812	et	4	main
ise	doc_213943985043_item	2292813	et	4	main
emakeelt	doc_213943985043_item	2292815	et	4	main
see	doc_213943985043_item	2292816	et	3	main
ootan	doc_213943985042_item	2292585	et	3	main
nii	doc_213943985042_item	2292586	et	3	main
südames	doc_213943985042_item	2292613	et	3	main
et	doc_213943985042_item	2292619	et	3	main
huvitav	doc_213943985042_item	2292621	et	4	main
ennast	doc_213943985042_item	2292623	et	4	main
esmakursuslasena	doc_213943985042_item	2292624	et	3	main
on	doc_213943985042_item	2292631	et	4	main
teine	doc_213943985042_item	2292632	et	3	main
mida	doc_213943985042_item	2292642	et	4	main
tõesti	doc_213943985042_item	2292644	et	3	main
kogu	doc_213943985042_item	2292651	et	4	main
aeg	doc_213943985042_item	2292652	et	3	main
vaja	doc_213943985042_item	2292654	et	4	main
olla	doc_213943985042_item	2292655	et	3	main
ülikoolis	doc_213943985042_item	2292656	et	4	main
õigeks	doc_213943985042_item	2292660	et	3	main
nagu	doc_213943985042_item	2292676	et	3	main
et	doc_213943985042_item	2292706	et	3	main
ja	doc_213943985042_item	2292716	et	3	main
kõike	doc_213943985042_item	2292725	et	4	main
teda	doc_213943985042_item	2292736	et	4	main
arendada	doc_213943985042_item	2292737	et	3	main
mängida	doc_213943985042_item	2292738	et	3	main
temaga	doc_213943985042_item	2292739	et	3	main
jalutada	doc_213943985042_item	2292740	et	3	main
võib	doc_213943985042_item	2292741	et	3	main
rohkem	doc_213943985042_item	2292753	et	4	main
miks	doc_213943985043_item	2292765	et	4	main
selle	doc_213943985043_item	2292768	et	4	main
eriala	doc_213943985043_item	2292769	et	4	main
ootan	doc_213943985043_item	2292771	et	3	main
üks	doc_213943985043_item	2292803	et	3	main
kes	doc_213943985043_item	2292807	et	4	main
tunne	doc_213943985043_item	2292809	et	4	main
ka	doc_213943985043_item	2292829	et	3	main
ma	doc_213943985043_item	2292832	et	3	main
inimene	doc_213943985043_item	2292836	et	3	main
on	doc_213943985043_item	2292839	et	4	main
keeliteadmised	doc_213943985043_item	2292851	et	4	main
tulevikus	doc_213943985043_item	2292858	et	4	main
saada	doc_213943985043_item	2292861	et	4	main
annab	doc_213943985043_item	2292879	et	3	main
õppimine	doc_213943985043_item	2292890	et	4	main
ülikoolis	doc_213943985043_item	2292891	et	4	main
silmaringi	doc_213943985043_item	2292893	et	4	main
tudengil	doc_213943985043_item	2292894	et	3	main
on	doc_213943985043_item	2292895	et	4	main
võimalus	doc_213943985043_item	2292896	et	3	main
välismaale	doc_213943985043_item	2292898	et	4	main
võivad	doc_213943985043_item	2292901	et	4	main
uurida	doc_213943985043_item	2292902	et	3	main
uut	doc_213943985043_item	2292903	et	3	main
on	doc_213943985043_item	2292911	et	4	main
võimalus	doc_213943985043_item	2292913	et	3	main
tähtsam	doc_213943985043_item	2292921	et	4	main
jaoks	doc_213943985043_item	2292923	et	4	main
on	doc_213943985043_item	2292924	et	4	main
plaanerida	doc_213943985043_item	2292936	et	4	main
hea	doc_213943985043_item	2292941	et	4	main
kus	doc_213943985043_item	2292943	et	3	main
võib	doc_213943985043_item	2292944	et	3	main
teenida	doc_213943985043_item	2292945	et	3	main
aga	doc_213943985043_item	2292956	et	3	main
essee	doc_213943985044_item	2292961	et	4	main
missugune	doc_213943985044_item	2292980	et	3	main
elu	doc_213943985044_item	2292981	et	4	main
oleks	doc_213943985044_item	2292989	et	3	main
ja	doc_213943985044_item	2292991	et	3	main
meeldib	doc_213943985044_item	2293023	et	3	main
et	doc_213943985044_item	2293031	et	3	main
õpetajaks	doc_213943985044_item	2293036	et	4	main
lasteajas	doc_213943985044_item	2293040	et	3	main
et	doc_213943985044_item	2293042	et	3	main
erialas	doc_213943985044_item	2293059	et	3	main
õppimine	doc_213943985044_item	2293064	et	4	main
oleks	doc_213943985044_item	2293067	et	3	main
huvitav	doc_213943985044_item	2293068	et	4	main
mitte	doc_213943985044_item	2293069	et	3	main
raske	doc_213943985044_item	2293071	et	4	main
tõsine	doc_213943985044_item	2293073	et	4	main
sõbralikud	doc_213943985044_item	2293085	et	3	main
ju	doc_213943985042_item	2292627	et	3	main
ennem	doc_213943985042_item	2292629	et	4	main
see	doc_213943985042_item	2292630	et	3	main
teine	doc_213943985042_item	2292633	et	3	main
samm	doc_213943985042_item	2292641	et	3	main
et	doc_213943985042_item	2292649	et	3	main
kodutööd	doc_213943985042_item	2292658	et	4	main
et	doc_213943985042_item	2292664	et	3	main
oleks	doc_213943985042_item	2292665	et	3	main
ma	doc_213943985042_item	2292671	et	3	main
tahan	doc_213943985042_item	2292674	et	3	main
kes	doc_213943985042_item	2292678	et	4	main
läheb	doc_213943985042_item	2292679	et	3	main
esimese	doc_213943985042_item	2292680	et	3	main
naljakas	doc_213943985042_item	2292682	et	4	main
klassi	doc_213943985042_item	2292681	et	4	main
küll	doc_213943985042_item	2292684	et	4	main
tunneb	doc_213943985042_item	2292683	et	3	main
et	doc_213943985042_item	2292685	et	3	main
rumalusi	doc_213943985042_item	2292686	et	4	main
kirjutan	doc_213943985042_item	2292687	et	3	main
näen	doc_213943985042_item	2292688	et	3	main
et	doc_213943985042_item	2292689	et	3	main
teised	doc_213943985042_item	2292690	et	4	main
nii	doc_213943985042_item	2292691	et	3	main
hoolikalt	doc_213943985042_item	2292692	et	4	main
tõsise	doc_213943985042_item	2292693	et	4	main
näoga	doc_213943985042_item	2292694	et	3	main
midagi	doc_213943985042_item	2292695	et	4	main
kirjutavad	doc_213943985042_item	2292696	et	4	main
ma	doc_213943985042_item	2292697	et	3	main
ootan	doc_213943985042_item	2292698	et	3	main
häid	doc_213943985042_item	2292699	et	3	main
hinneid	doc_213943985042_item	2292700	et	4	main
et	doc_213943985042_item	2292701	et	3	main
sessi	doc_213943985042_item	2292702	et	4	main
saan	doc_213943985042_item	2292703	et	4	main
ilusasti	doc_213943985042_item	2292704	et	3	main
läbi	doc_213943985042_item	2292705	et	4	main
kõike	doc_213943985042_item	2292709	et	4	main
õppida	doc_213943985042_item	2292728	et	3	main
ja	doc_213943985042_item	2292729	et	3	main
väikse	doc_213943985042_item	2292731	et	4	main
aega	doc_213943985042_item	2292734	et	4	main
olla	doc_213943985042_item	2292742	et	3	main
päevi	doc_213943985042_item	2292744	et	4	main
miks	doc_213943985042_item	2292745	et	4	main
mitte	doc_213943985042_item	2292746	et	3	main
mitte	doc_213943985042_item	2292747	et	3	main
siis	doc_213943985042_item	2292754	et	3	main
jõuame	doc_213943985042_item	2292755	et	3	main
et	doc_213943985042_item	2292758	et	3	main
essee	doc_213943985043_item	2292764	et	4	main
mida	doc_213943985043_item	2292770	et	4	main
keeli	doc_213943985043_item	2292799	et	4	main
ei	doc_213943985043_item	2292811	et	4	main
oma	doc_213943985043_item	2292814	et	4	main
tõttu	doc_213943985043_item	2292817	et	4	main
mul	doc_213943985043_item	2292818	et	3	main
on	doc_213943985043_item	2292819	et	4	main
väga	doc_213943985043_item	2292820	et	3	main
hea	doc_213943985043_item	2292821	et	4	main
et	doc_213943985043_item	2292823	et	3	main
õppida	doc_213943985043_item	2292824	et	3	main
mitte	doc_213943985043_item	2292825	et	3	main
ainult	doc_213943985043_item	2292826	et	4	main
emakeelt	doc_213943985043_item	2292827	et	4	main
samuti	doc_213943985043_item	2292831	et	3	main
seltsiv	doc_213943985043_item	2292835	et	4	main
mul	doc_213943985043_item	2292838	et	3	main
suur	doc_213943985043_item	2292840	et	3	main
suhelda	doc_213943985043_item	2292843	et	4	main
aitavad	doc_213943985043_item	2292852	et	4	main
hea	doc_213943985043_item	2292854	et	4	main
võib	doc_213943985043_item	2292856	et	3	main
olla	doc_213943985043_item	2292857	et	3	main
tahaksin	doc_213943985043_item	2292860	et	3	main
õpetajaks	doc_213943985043_item	2292862	et	4	main
et	doc_213943985043_item	2292881	et	3	main
samuti	doc_213943985043_item	2292889	et	3	main
suurendab	doc_213943985043_item	2292892	et	3	main
parendada	doc_213943985043_item	2292906	et	3	main
muidugi	doc_213943985043_item	2292909	et	4	main
see	doc_213943985043_item	2292910	et	3	main
tuttavaid	doc_213943985043_item	2292917	et	3	main
ikkagi	doc_213943985043_item	2292919	et	4	main
minu	doc_213943985043_item	2292922	et	3	main
on	doc_213943985043_item	2292928	et	4	main
sul	doc_213943985043_item	2292931	et	3	main
lihtne	doc_213943985043_item	2292939	et	3	main
et	doc_213943985043_item	2292949	et	3	main
on	doc_213943985043_item	2292951	et	4	main
mitte	doc_213943985043_item	2292952	et	3	main
ja	doc_213943985043_item	2292958	et	3	main
ka	doc_213943985043_item	2292960	et	3	main
1	doc_213943985044_item	2292962	et	2	main
eriala	doc_213943985044_item	2292967	et	4	main
2	doc_213943985044_item	2292968	et	2	main
mida	doc_213943985044_item	2292969	et	4	main
ootan	doc_213943985044_item	2292970	et	3	main
pärast	doc_213943985044_item	2292975	et	4	main
lõpetamist	doc_213943985044_item	2292976	et	4	main
kooli	doc_213943985044_item	2292977	et	4	main
kelleks	doc_213943985044_item	2292985	et	4	main
ma	doc_213943985044_item	2292994	et	3	main
meeldivad	doc_213943985044_item	2293021	et	4	main
nendega	doc_213943985044_item	2293025	et	4	main
pärast	doc_213943985044_item	2293026	et	4	main
mõttest	doc_213943985044_item	2293028	et	4	main
saadsin	doc_213943985044_item	2293029	et	4	main
aru	doc_213943985044_item	2293030	et	4	main
parem	doc_213943985044_item	2293033	et	4	main
tahaksin	doc_213943985044_item	2293038	et	3	main
töötada	doc_213943985044_item	2293039	et	3	main
arvan	doc_213943985044_item	2293041	et	3	main
et	doc_213943985044_item	2293049	et	3	main
palju	doc_213943985044_item	2293057	et	4	main
oskusi	doc_213943985044_item	2293058	et	3	main
ma	doc_213943985044_item	2293060	et	3	main
väga	doc_213943985044_item	2293070	et	3	main
siin	doc_213943985044_item	2293080	et	4	main
aga	doc_213943985042_item	2292712	et	3	main
praegu	doc_213943985042_item	2292713	et	3	main
tahan	doc_213943985042_item	2292715	et	3	main
et	doc_213943985042_item	2292718	et	3	main
rohkem	doc_213943985042_item	2292720	et	4	main
teha	doc_213943985042_item	2292727	et	3	main
oma	doc_213943985042_item	2292730	et	4	main
tütrega	doc_213943985042_item	2292732	et	3	main
vaid	doc_213943985042_item	2292750	et	3	main
kõike	doc_213943985042_item	2292760	et	4	main
jõuan	doc_213943985042_item	2292762	et	3	main
tundub	doc_213943985043_item	2292804	et	3	main
võõrkeelt	doc_213943985043_item	2292810	et	4	main
kui	doc_213943985043_item	2292828	et	3	main
võõrkeeled	doc_213943985043_item	2292830	et	3	main
olen	doc_213943985043_item	2292833	et	3	main
inimestega	doc_213943985043_item	2292844	et	3	main
muud	doc_213943985043_item	2292847	et	4	main
leida	doc_213943985043_item	2292853	et	3	main
töökohta	doc_213943985043_item	2292855	et	4	main
ma	doc_213943985043_item	2292859	et	3	main
õppida	doc_213943985043_item	2292882	et	3	main
tahan	doc_213943985043_item	2292888	et	3	main
keeliteadmiseid	doc_213943985043_item	2292907	et	4	main
hea	doc_213943985043_item	2292912	et	4	main
aga	doc_213943985043_item	2292918	et	3	main
kui	doc_213943985043_item	2292926	et	3	main
kõrgharidus	doc_213943985043_item	2292929	et	3	main
siis	doc_213943985043_item	2292930	et	3	main
oma	doc_213943985043_item	2292937	et	4	main
raha	doc_213943985043_item	2292947	et	4	main
õppimine	doc_213943985043_item	2292950	et	4	main
väga	doc_213943985043_item	2292954	et	3	main
huvitav	doc_213943985043_item	2292957	et	4	main
põnev	doc_213943985043_item	2292959	et	3	main
iga	doc_213943985044_item	2292973	et	4	main
inimene	doc_213943985044_item	2292974	et	3	main
ta	doc_213943985044_item	2292982	et	4	main
tahab	doc_213943985044_item	2292983	et	3	main
saan	doc_213943985044_item	2293035	et	4	main
sellepärast	doc_213943985044_item	2293048	et	3	main
ülikool	doc_213943985044_item	2293051	et	4	main
mulle	doc_213943985044_item	2293053	et	4	main
et	doc_213943985044_item	2293063	et	3	main
tallinna	doc_213943985044_item	2293065	et	4	main
on	doc_213943985044_item	2293081	et	4	main
ja	doc_213943985044_item	2293084	et	3	main
praegu	doc_213943985044_item	2293086	et	3	main
kõik	doc_213943985044_item	2293091	et	4	main
tudengid	doc_213943985044_item	2293092	et	3	main
lektorid	doc_213943985044_item	2293094	et	3	main
tea	doc_213943985044_item	2293097	et	4	main
mis	doc_213943985044_item	2293098	et	4	main
kõik	doc_213943985044_item	2293110	et	4	main
näiteks	doc_213943985044_item	2293115	et	4	main
tööd	doc_213943985044_item	2293117	et	4	main
ja	doc_213943985044_item	2293118	et	3	main
loengud	doc_213943985044_item	2293119	et	3	main
kuulata	doc_213943985044_item	2293120	et	4	main
aega	doc_213943985042_item	2292721	et	4	main
et	doc_213943985042_item	2292724	et	3	main
jõuaks	doc_213943985042_item	2292726	et	3	main
veeta	doc_213943985042_item	2292735	et	4	main
pikendame	doc_213943985042_item	2292743	et	3	main
30	doc_213943985042_item	2292751	et	2	main
nali	doc_213943985042_item	2292756	et	3	main
õppimisest	doc_213943985043_item	2292772	et	4	main
ülikoolis	doc_213943985043_item	2292773	et	4	main
tahaksin	doc_213943985043_item	2292776	et	3	main
ma	doc_213943985043_item	2292775	et	3	main
kõigipealt	doc_213943985043_item	2292774	et	4	main
saada	doc_213943985043_item	2292777	et	4	main
hea	doc_213943985043_item	2292778	et	4	main
haridust	doc_213943985043_item	2292779	et	4	main
et	doc_213943985043_item	2292781	et	3	main
arvan	doc_213943985043_item	2292780	et	3	main
ülikool	doc_213943985043_item	2292783	et	4	main
tallinna	doc_213943985043_item	2292782	et	4	main
võib	doc_213943985043_item	2292784	et	3	main
aidata	doc_213943985043_item	2292785	et	4	main
mind	doc_213943985043_item	2292786	et	4	main
selles	doc_213943985043_item	2292787	et	4	main
miks	doc_213943985043_item	2292788	et	4	main
ma	doc_213943985043_item	2292789	et	3	main
valisin	doc_213943985043_item	2292790	et	3	main
filoloogilist	doc_213943985043_item	2292791	et	4	main
eriala	doc_213943985043_item	2292792	et	4	main
meeldib	doc_213943985043_item	2292794	et	3	main
uurida	doc_213943985043_item	2292795	et	3	main
ja	doc_213943985043_item	2292796	et	3	main
mulle	doc_213943985043_item	2292793	et	4	main
õppida	doc_213943985043_item	2292797	et	3	main
erinevaid	doc_213943985043_item	2292798	et	4	main
ja	doc_213943985043_item	2292800	et	3	main
kuidas	doc_213943985043_item	2292801	et	3	main
ööldas	doc_213943985043_item	2292802	et	4	main
ei	doc_213943985043_item	2292808	et	4	main
meel	doc_213943985043_item	2292822	et	4	main
väga	doc_213943985043_item	2292834	et	3	main
et	doc_213943985043_item	2292842	et	3	main
nii	doc_213943985043_item	2292883	et	3	main
keeli	doc_213943985043_item	2292885	et	4	main
ma	doc_213943985043_item	2292887	et	3	main
reisida	doc_213943985043_item	2292897	et	3	main
kus	doc_213943985043_item	2292899	et	3	main
nad	doc_213943985043_item	2292900	et	3	main
kuulturi	doc_213943985043_item	2292904	et	3	main
ja	doc_213943985043_item	2292908	et	3	main
leida	doc_213943985043_item	2292915	et	3	main
kõige	doc_213943985043_item	2292920	et	4	main
sul	doc_213943985043_item	2292927	et	3	main
et	doc_213943985043_item	2292935	et	3	main
elu	doc_213943985043_item	2292938	et	4	main
leida	doc_213943985043_item	2292940	et	3	main
piisavalt	doc_213943985043_item	2292946	et	4	main
ainult	doc_213943985043_item	2292953	et	4	main
raske	doc_213943985043_item	2292955	et	4	main
miks	doc_213943985044_item	2292963	et	4	main
ma	doc_213943985044_item	2292964	et	3	main
valisin	doc_213943985044_item	2292965	et	3	main
selle	doc_213943985044_item	2292966	et	4	main
peab	doc_213943985044_item	2292978	et	4	main
valima	doc_213943985044_item	2292979	et	3	main
saada	doc_213943985044_item	2292986	et	4	main
et	doc_213943985044_item	2292987	et	3	main
palju	doc_213943985044_item	2292996	et	4	main
minu	doc_213943985044_item	2293027	et	3	main
oleks	doc_213943985044_item	2293032	et	3	main
et	doc_213943985044_item	2293034	et	3	main
ülikool	doc_213943985044_item	2293044	et	4	main
annab	doc_213943985044_item	2293052	et	3	main
kõrgharidust	doc_213943985044_item	2293054	et	4	main
ja	doc_213943985044_item	2293055	et	3	main
teisena	doc_213943985044_item	2293056	et	4	main
ootan	doc_213943985044_item	2293062	et	3	main
ülikoolis	doc_213943985044_item	2293066	et	4	main
inimesed	doc_213943985044_item	2293079	et	3	main
meeldib	doc_213943985044_item	2293090	et	3	main
inimesed	doc_213943985044_item	2293093	et	3	main
aga	doc_213943985044_item	2293095	et	3	main
ja	doc_213943985044_item	2293108	et	3	main
nõus	doc_213943985044_item	2293122	et	4	main
mis	doc_213943985044_item	2293135	et	4	main
saan	doc_213943985044_item	2293143	et	4	main
miks	doc_213943985045_item	2293152	et	4	main
ootan	doc_213943985045_item	2293159	et	3	main
õppimisest	doc_213943985045_item	2293160	et	4	main
ülikoolis	doc_213943985045_item	2293161	et	4	main
1	doc_213943985045_item	2293162	et	2	main
põhjusi	doc_213943985045_item	2293163	et	3	main
mitu	doc_213943985045_item	2293170	et	4	main
kogu	doc_213943985045_item	2293177	et	4	main
ta	doc_213943985045_item	2293179	et	4	main
oli	doc_213943985045_item	2293180	et	3	main
minu	doc_213943985045_item	2293181	et	3	main
jaoks	doc_213943985045_item	2293182	et	4	main
peab	doc_213943985045_item	2293185	et	4	main
alati	doc_213943985045_item	2293191	et	4	main
mitte	doc_213943985045_item	2293204	et	3	main
hea	doc_213943985045_item	2293210	et	4	main
vene	doc_213943985045_item	2293219	et	4	main
ja	doc_213943985043_item	2292837	et	3	main
soov	doc_213943985043_item	2292841	et	3	main
kes	doc_213943985043_item	2292845	et	4	main
valvavad	doc_213943985043_item	2292846	et	4	main
keelt	doc_213943985043_item	2292848	et	4	main
arvan	doc_213943985043_item	2292849	et	3	main
et	doc_213943985043_item	2292850	et	3	main
sest	doc_213943985043_item	2292863	et	4	main
minu	doc_213943985043_item	2292864	et	3	main
eriala	doc_213943985043_item	2292865	et	4	main
annab	doc_213943985043_item	2292866	et	3	main
võimalust	doc_213943985043_item	2292867	et	3	main
töötada	doc_213943985043_item	2292868	et	3	main
õpetajaks	doc_213943985043_item	2292869	et	4	main
esmakordselt	doc_213943985043_item	2292870	et	4	main
ma	doc_213943985043_item	2292871	et	3	main
ootan	doc_213943985043_item	2292872	et	3	main
õppimisest	doc_213943985043_item	2292873	et	4	main
arendama	doc_213943985043_item	2292875	et	3	main
oma	doc_213943985043_item	2292876	et	4	main
ülikoolis	doc_213943985043_item	2292874	et	4	main
teadmisi	doc_213943985043_item	2292877	et	4	main
ülikool	doc_213943985043_item	2292878	et	4	main
võimalusi	doc_213943985043_item	2292880	et	3	main
palju	doc_213943985043_item	2292884	et	4	main
mida	doc_213943985043_item	2292886	et	4	main
traditsioonid	doc_213943985043_item	2292905	et	3	main
et	doc_213943985043_item	2292914	et	3	main
uut	doc_213943985043_item	2292916	et	3	main
haridus	doc_213943985043_item	2292925	et	3	main
on	doc_213943985043_item	2292932	et	4	main
rohkem	doc_213943985043_item	2292933	et	4	main
võimalusi	doc_213943985043_item	2292934	et	3	main
tööd	doc_213943985043_item	2292942	et	4	main
loodan	doc_213943985043_item	2292948	et	3	main
õppimisest	doc_213943985044_item	2292971	et	4	main
ülikoolis	doc_213943985044_item	2292972	et	4	main
ja	doc_213943985044_item	2292984	et	3	main
elu	doc_213943985044_item	2292988	et	4	main
huvitav	doc_213943985044_item	2292990	et	4	main
hea	doc_213943985044_item	2292992	et	4	main
koolis	doc_213943985044_item	2292993	et	4	main
mõtlesin	doc_213943985044_item	2292995	et	3	main
minu	doc_213943985044_item	2292997	et	3	main
tulevikust	doc_213943985044_item	2292998	et	4	main
ja	doc_213943985044_item	2292999	et	3	main
kus	doc_213943985044_item	2293000	et	3	main
mul	doc_213943985044_item	2293001	et	3	main
oleks	doc_213943985044_item	2293002	et	3	main
parem	doc_213943985044_item	2293003	et	4	main
õppida	doc_213943985044_item	2293004	et	3	main
ja	doc_213943985044_item	2293005	et	3	main
kellena	doc_213943985044_item	2293006	et	3	main
minu	doc_213943985044_item	2293007	et	3	main
sõbrad	doc_213943985044_item	2293008	et	3	main
rääkivad	doc_213943985044_item	2293009	et	4	main
et	doc_213943985044_item	2293010	et	3	main
mina	doc_213943985044_item	2293011	et	4	main
olen	doc_213943985044_item	2293012	et	3	main
väga	doc_213943985044_item	2293013	et	3	main
aus	doc_213943985044_item	2293014	et	4	main
tagasihoidlik	doc_213943985044_item	2293015	et	3	main
ja	doc_213943985044_item	2293016	et	3	main
sõbralik	doc_213943985044_item	2293017	et	3	main
inimene	doc_213943985044_item	2293018	et	3	main
veel	doc_213943985044_item	2293019	et	4	main
mulle	doc_213943985044_item	2293020	et	4	main
lapsed	doc_213943985044_item	2293022	et	3	main
mängida	doc_213943985044_item	2293024	et	3	main
rohkem	doc_213943985044_item	2293037	et	4	main
tallinna	doc_213943985044_item	2293043	et	4	main
on	doc_213943985044_item	2293045	et	4	main
õige	doc_213943985044_item	2293046	et	4	main
valik	doc_213943985044_item	2293047	et	3	main
esimesena	doc_213943985044_item	2293050	et	3	main
valisin	doc_213943985044_item	2293061	et	3	main
vaid	doc_213943985044_item	2293072	et	3	main
veel	doc_213943985044_item	2293074	et	4	main
ootan	doc_213943985044_item	2293075	et	3	main
et	doc_213943985044_item	2293076	et	3	main
õpetajad	doc_213943985044_item	2293077	et	4	main
ja	doc_213943985044_item	2293078	et	3	main
arusaadavad	doc_213943985044_item	2293082	et	3	main
mulle	doc_213943985044_item	2293089	et	4	main
olema	doc_213943985044_item	2293106	et	4	main
teha	doc_213943985044_item	2293114	et	3	main
olen	doc_213943985044_item	2293121	et	3	main
raske	doc_213943985044_item	2293133	et	4	main
on	doc_213943985044_item	2293138	et	4	main
ma	doc_213943985044_item	2293142	et	3	main
eriala	doc_213943985045_item	2293156	et	4	main
mida	doc_213943985045_item	2293158	et	4	main
ma	doc_213943985045_item	2293165	et	3	main
ema	doc_213943985045_item	2293173	et	4	main
näidiseks	doc_213943985045_item	2293183	et	3	main
milline	doc_213943985045_item	2293184	et	3	main
teiseks	doc_213943985045_item	2293189	et	4	main
ema	doc_213943985045_item	2293207	et	4	main
kindel	doc_213943985045_item	2293217	et	3	main
keel	doc_213943985045_item	2293220	et	4	main
keel	doc_213943985045_item	2293226	et	4	main
on	doc_213943985045_item	2293230	et	4	main
on	doc_213943985045_item	2293244	et	4	main
õppimis	doc_213943985045_item	2293266	et	4	main
hindamisviis	doc_213943985045_item	2293269	et	3	main
ja	doc_213943985045_item	2293272	et	3	main
sai	doc_213943985045_item	2293278	et	4	main
mõni	doc_213943985045_item	2293282	et	3	main
pärast	doc_213943985045_item	2293284	et	4	main
mida	doc_213943985045_item	2293293	et	4	main
kui	doc_213943985045_item	2293296	et	3	main
huvi	doc_213943985045_item	2293315	et	4	main
ja	doc_213943985045_item	2293317	et	3	main
et	doc_213943985045_item	2293326	et	3	main
emakeele	doc_213943985045_item	2293328	et	4	main
mingi	doc_213943985045_item	2293331	et	4	main
teine	doc_213943985045_item	2293332	et	3	main
ka	doc_213943985045_item	2293348	et	3	main
minu	doc_213943985045_item	2293355	et	3	main
pluss	doc_213943985045_item	2293360	et	3	main
valiku	doc_213943985045_item	2293362	et	3	main
parem	doc_213943985045_item	2293387	et	4	main
õppejõudude	doc_213943985045_item	2293402	et	3	main
oleks	doc_213943985045_item	2293404	et	3	main
ilma	doc_213943985045_item	2293418	et	4	main
abita	doc_213943985045_item	2293419	et	3	main
arvestades	doc_213943985045_item	2293420	et	3	main
mitte	doc_213943985045_item	2293429	et	3	main
oleksid	doc_213943985045_item	2293438	et	4	main
õppimine	doc_213943985045_item	2293443	et	4	main
elule	doc_213943985045_item	2293448	et	3	main
peavad	doc_213943985045_item	2293454	et	4	main
õpetajad	doc_213943985045_item	2293477	et	4	main
aitasid	doc_213943985045_item	2293480	et	4	main
lõpuks	doc_213943985045_item	2293485	et	4	main
tahaks	doc_213943985045_item	2293486	et	3	main
öelda	doc_213943985045_item	2293487	et	4	main
õppimisest	doc_213943985045_item	2293489	et	4	main
ülikoolis	doc_213943985045_item	2293490	et	4	main
kõige	doc_213943985045_item	2293491	et	4	main
mis	doc_213943985045_item	2293498	et	4	main
hea	doc_213943985045_item	2293505	et	4	main
1	doc_213943985046_item	2293510	et	2	main
õppimist	doc_213943985046_item	2293521	et	4	main
töölt	doc_213943985046_item	2293525	et	3	main
alati	doc_213943985046_item	2293528	et	4	main
igasuguseid	doc_213943985046_item	2293532	et	3	main
nende	doc_213943985046_item	2293535	et	4	main
ajast	doc_213943985046_item	2293537	et	4	main
millal	doc_213943985046_item	2293538	et	3	main
mulle	doc_213943985046_item	2293545	et	4	main
targad	doc_213943985044_item	2293083	et	3	main
ülikoolis	doc_213943985044_item	2293088	et	4	main
mind	doc_213943985044_item	2293099	et	4	main
edasi	doc_213943985044_item	2293101	et	3	main
ma	doc_213943985044_item	2293102	et	3	main
et	doc_213943985044_item	2293104	et	3	main
tegema	doc_213943985044_item	2293109	et	3	main
mis	doc_213943985044_item	2293111	et	4	main
kodu	doc_213943985044_item	2293116	et	4	main
ülikoolis	doc_213943985044_item	2293124	et	4	main
palju	doc_213943985044_item	2293127	et	4	main
teha	doc_213943985044_item	2293136	et	3	main
lõpetada	doc_213943985044_item	2293147	et	3	main
edukalt	doc_213943985044_item	2293149	et	4	main
essee	doc_213943985045_item	2293150	et	4	main
1	doc_213943985045_item	2293151	et	2	main
ma	doc_213943985045_item	2293153	et	3	main
valisin	doc_213943985045_item	2293154	et	3	main
miks	doc_213943985045_item	2293164	et	4	main
selle	doc_213943985045_item	2293167	et	4	main
erialat	doc_213943985045_item	2293168	et	4	main
füloolog	doc_213943985045_item	2293176	et	4	main
elu	doc_213943985045_item	2293178	et	4	main
olema	doc_213943985045_item	2293186	et	4	main
mind	doc_213943985045_item	2293190	et	4	main
huvitas	doc_213943985045_item	2293192	et	3	main
minu	doc_213943985045_item	2293193	et	3	main
emakeel	doc_213943985045_item	2293194	et	4	main
lugesin	doc_213943985045_item	2293203	et	3	main
sest	doc_213943985045_item	2293206	et	4	main
alati	doc_213943985045_item	2293208	et	4	main
andis	doc_213943985045_item	2293209	et	3	main
olen	doc_213943985045_item	2293216	et	3	main
on	doc_213943985045_item	2293221	et	4	main
huvitav	doc_213943985045_item	2293225	et	4	main
arvestades	doc_213943985045_item	2293227	et	3	main
et	doc_213943985045_item	2293228	et	3	main
omandada	doc_213943985045_item	2293235	et	3	main
mind	doc_213943985045_item	2293251	et	4	main
valikut	doc_213943985045_item	2293252	et	3	main
aastat	doc_213943985045_item	2293255	et	3	main
õppisin	doc_213943985045_item	2293258	et	3	main
õpingut	doc_213943985045_item	2293262	et	3	main
sest	doc_213943985045_item	2293263	et	4	main
polnud	doc_213943985045_item	2293264	et	3	main
rahul	doc_213943985045_item	2293265	et	4	main
ebaadekvaatne	doc_213943985045_item	2293271	et	3	main
eriala	doc_213943985045_item	2293273	et	4	main
ebameeldivaks	doc_213943985045_item	2293281	et	3	main
siis	doc_213943985045_item	2293295	et	3	main
võin	doc_213943985045_item	2293303	et	3	main
tundsin	doc_213943985045_item	2293314	et	3	main
võimalused	doc_213943985045_item	2293324	et	3	main
eriala	doc_213943985045_item	2293333	et	4	main
sain	doc_213943985045_item	2293341	et	3	main
õppida	doc_213943985045_item	2293349	et	3	main
ja	doc_213943985045_item	2293351	et	3	main
jaoks	doc_213943985045_item	2293356	et	4	main
oli	doc_213943985045_item	2293358	et	3	main
kõik	doc_213943985045_item	2293384	et	4	main
et	doc_213943985045_item	2293407	et	3	main
sest	doc_213943985045_item	2293412	et	4	main
raske	doc_213943985045_item	2293414	et	4	main
alustada	doc_213943985045_item	2293415	et	3	main
on	doc_213943985045_item	2293423	et	4	main
inimesed	doc_213943985045_item	2293426	et	3	main
et	doc_213943985045_item	2293435	et	3	main
saavutused	doc_213943985045_item	2293437	et	4	main
positiivsed	doc_213943985045_item	2293440	et	3	main
teiste	doc_213943985045_item	2293449	et	4	main
minu	doc_213943985045_item	2293451	et	3	main
üliõpilased	doc_213943985045_item	2293453	et	3	main
saada	doc_213943985045_item	2293466	et	4	main
oma	doc_213943985045_item	2293494	et	4	main
essee	doc_213943985046_item	2293509	et	4	main
1	doc_213943985046_item	2293526	et	2	main
väga	doc_213943985046_item	2293529	et	3	main
elasid	doc_213943985046_item	2293540	et	4	main
võimaluse	doc_213943985046_item	2293546	et	3	main
vene	doc_213943985046_item	2293558	et	4	main
huvitav	doc_213943985046_item	2293578	et	4	main
19	doc_213943985046_item	2293586	et	2	main
siin	doc_213943985044_item	2293087	et	4	main
ei	doc_213943985044_item	2293096	et	4	main
ootab	doc_213943985044_item	2293100	et	3	main
tean	doc_213943985044_item	2293103	et	3	main
pean	doc_213943985044_item	2293105	et	4	main
töökas	doc_213943985044_item	2293107	et	4	main
on	doc_213943985044_item	2293112	et	4	main
vaja	doc_213943985044_item	2293113	et	4	main
et	doc_213943985044_item	2293123	et	3	main
vaja	doc_213943985044_item	2293126	et	4	main
õppida	doc_213943985044_item	2293128	et	3	main
ja	doc_213943985044_item	2293129	et	3	main
see	doc_213943985044_item	2293130	et	3	main
on	doc_213943985044_item	2293131	et	4	main
aga	doc_213943985044_item	2293134	et	3	main
elu	doc_213943985044_item	2293137	et	4	main
nii	doc_213943985044_item	2293139	et	3	main
loodan	doc_213943985044_item	2293140	et	3	main
et	doc_213943985044_item	2293141	et	3	main
ülikooli	doc_213943985044_item	2293148	et	4	main
selle	doc_213943985045_item	2293155	et	4	main
on	doc_213943985045_item	2293169	et	4	main
minu	doc_213943985045_item	2293172	et	3	main
haritud	doc_213943985045_item	2293187	et	4	main
kooliajal	doc_213943985045_item	2293198	et	3	main
huvitatud	doc_213943985045_item	2293200	et	4	main
aga	doc_213943985045_item	2293202	et	3	main
nõud	doc_213943985045_item	2293211	et	3	main
on	doc_213943985045_item	2293213	et	4	main
parem	doc_213943985045_item	2293214	et	4	main
lugeda	doc_213943985045_item	2293215	et	3	main
väga	doc_213943985045_item	2293222	et	3	main
raske	doc_213943985045_item	2293223	et	4	main
minu	doc_213943985045_item	2293231	et	3	main
ka	doc_213943985045_item	2293234	et	3	main
kui	doc_213943985045_item	2293239	et	3	main
aitas	doc_213943985045_item	2293250	et	3	main
paar	doc_213943985045_item	2293254	et	3	main
juba	doc_213943985045_item	2293257	et	3	main
ülikoolis	doc_213943985045_item	2293259	et	4	main
aga	doc_213943985045_item	2293260	et	3	main
protsessist	doc_213943985045_item	2293267	et	3	main
õpejõudu	doc_213943985045_item	2293268	et	4	main
oli	doc_213943985045_item	2293270	et	3	main
millesse	doc_213943985045_item	2293274	et	3	main
tundsin	doc_213943985045_item	2293275	et	3	main
minu	doc_213943985045_item	2293279	et	3	main
teha	doc_213943985045_item	2293291	et	3	main
otsust	doc_213943985045_item	2293292	et	4	main
see	doc_213943985045_item	2293297	et	3	main
enam	doc_213943985045_item	2293300	et	4	main
ei	doc_213943985045_item	2293301	et	4	main
et	doc_213943985045_item	2293305	et	3	main
sel	doc_213943985045_item	2293306	et	3	main
korral	doc_213943985045_item	2293307	et	4	main
valik	doc_213943985045_item	2293308	et	3	main
oli	doc_213943985045_item	2293309	et	3	main
üsna	doc_213943985045_item	2293310	et	3	main
eriala	doc_213943985045_item	2293321	et	4	main
kõik	doc_213943985045_item	2293323	et	4	main
omandada	doc_213943985045_item	2293327	et	3	main
parem	doc_213943985045_item	2293329	et	4	main
teada	doc_213943985045_item	2293342	et	3	main
selle	doc_213943985045_item	2293344	et	4	main
kaudu	doc_213943985045_item	2293346	et	3	main
teiste	doc_213943985045_item	2293352	et	4	main
riikide	doc_213943985045_item	2293353	et	3	main
oma	doc_213943985045_item	2293361	et	4	main
tegemisel	doc_213943985045_item	2293363	et	4	main
läheb	doc_213943985045_item	2293386	et	3	main
kui	doc_213943985045_item	2293388	et	3	main
eelmisel	doc_213943985045_item	2293389	et	3	main
hea	doc_213943985045_item	2293400	et	4	main
loodan	doc_213943985045_item	2293406	et	3	main
elu	doc_213943985045_item	2293417	et	4	main
on	doc_213943985044_item	2293125	et	4	main
väga	doc_213943985044_item	2293132	et	3	main
siin	doc_213943985044_item	2293144	et	4	main
õppida	doc_213943985044_item	2293145	et	3	main
ja	doc_213943985044_item	2293146	et	3	main
2	doc_213943985045_item	2293157	et	2	main
valisin	doc_213943985045_item	2293166	et	3	main
esiteks	doc_213943985045_item	2293171	et	3	main
on	doc_213943985045_item	2293174	et	4	main
vene	doc_213943985045_item	2293175	et	4	main
inimene	doc_213943985045_item	2293188	et	3	main
tema	doc_213943985045_item	2293195	et	4	main
pärisolek	doc_213943985045_item	2293196	et	3	main
juba	doc_213943985045_item	2293197	et	3	main
olin	doc_213943985045_item	2293199	et	3	main
lugemisest	doc_213943985045_item	2293201	et	4	main
kõik	doc_213943985045_item	2293205	et	4	main
mida	doc_213943985045_item	2293212	et	4	main
et	doc_213943985045_item	2293218	et	3	main
ja	doc_213943985045_item	2293224	et	3	main
see	doc_213943985045_item	2293229	et	3	main
emakeel	doc_213943985045_item	2293232	et	4	main
tahaks	doc_213943985045_item	2293233	et	3	main
teda	doc_213943985045_item	2293236	et	4	main
nii	doc_213943985045_item	2293237	et	3	main
on	doc_213943985045_item	2293240	et	4	main
võimalik	doc_213943985045_item	2293241	et	3	main
arvan	doc_213943985045_item	2293242	et	3	main
et	doc_213943985045_item	2293243	et	3	main
ka	doc_213943985045_item	2293245	et	3	main
üks	doc_213943985045_item	2293246	et	3	main
tähtis	doc_213943985045_item	2293247	et	4	main
põhjus	doc_213943985045_item	2293248	et	4	main
jätsin	doc_213943985045_item	2293261	et	3	main
huvi	doc_213943985045_item	2293276	et	4	main
alguses	doc_213943985045_item	2293277	et	4	main
aeg	doc_213943985045_item	2293285	et	3	main
juba	doc_213943985045_item	2293286	et	3	main
ja	doc_213943985045_item	2293288	et	3	main
vaja	doc_213943985045_item	2293290	et	4	main
õppida	doc_213943985045_item	2293294	et	3	main
huvita	doc_213943985045_item	2293302	et	4	main
öelda	doc_213943985045_item	2293304	et	4	main
sest	doc_213943985045_item	2293312	et	4	main
võõr-	doc_213943985045_item	2293316	et	4	main
hästi	doc_213943985045_item	2293238	et	3	main
mis	doc_213943985045_item	2293249	et	4	main
teha	doc_213943985045_item	2293253	et	3	main
tagasi	doc_213943985045_item	2293256	et	3	main
jaoks	doc_213943985045_item	2293280	et	4	main
aja	doc_213943985045_item	2293283	et	4	main
möödus	doc_213943985045_item	2293287	et	3	main
oli	doc_213943985045_item	2293289	et	3	main
eriala	doc_213943985045_item	2293298	et	4	main
mind	doc_213943985045_item	2293299	et	4	main
lihtne	doc_213943985045_item	2293311	et	3	main
alati	doc_213943985045_item	2293313	et	4	main
emakeele	doc_213943985045_item	2293318	et	4	main
vastu	doc_213943985045_item	2293319	et	3	main
see	doc_213943985045_item	2293320	et	3	main
annab	doc_213943985045_item	2293322	et	3	main
kui	doc_213943985045_item	2293330	et	3	main
nagu	doc_213943985045_item	2293334	et	3	main
tunnen	doc_213943985045_item	2293336	et	3	main
huvi	doc_213943985045_item	2293337	et	4	main
ajaloo	doc_213943985045_item	2293338	et	4	main
vastu	doc_213943985045_item	2293339	et	3	main
et	doc_213943985045_item	2293343	et	3	main
eriala	doc_213943985045_item	2293345	et	4	main
ajalugu	doc_213943985045_item	2293354	et	4	main
see	doc_213943985045_item	2293357	et	3	main
et	doc_213943985045_item	2293383	et	3	main
mul	doc_213943985045_item	2293385	et	3	main
korral	doc_213943985045_item	2293390	et	4	main
teiseks	doc_213943985045_item	2293391	et	4	main
tahan	doc_213943985045_item	2293392	et	3	main
saavutada	doc_213943985045_item	2293393	et	3	main
mul	doc_213943985045_item	2293408	et	3	main
uued	doc_213943985045_item	2293410	et	3	main
tulid	doc_213943985045_item	2293427	et	4	main
puhkamiseks	doc_213943985045_item	2293431	et	4	main
ainult	doc_213943985045_item	2293439	et	4	main
mind	doc_213943985045_item	2293446	et	4	main
võimalike	doc_213943985045_item	2293458	et	4	main
elu	doc_213943985045_item	2293460	et	4	main
targemaks	doc_213943985045_item	2293467	et	4	main
sest	doc_213943985045_item	2293468	et	4	main
otsused	doc_213943985045_item	2293470	et	3	main
pead	doc_213943985045_item	2293471	et	4	main
ise	doc_213943985045_item	2293472	et	4	main
tegema	doc_213943985045_item	2293473	et	3	main
võrreldes	doc_213943985045_item	2293474	et	3	main
kooliaega	doc_213943985045_item	2293475	et	4	main
oskasid	doc_213943985045_item	2293484	et	4	main
eriala	doc_213943985045_item	2293495	et	4	main
häid	doc_213943985045_item	2293496	et	3	main
oma	doc_213943985045_item	2293500	et	4	main
tuleviku	doc_213943985045_item	2293501	et	4	main
võimalik	doc_213943985045_item	2293508	et	3	main
meeldis	doc_213943985046_item	2293530	et	3	main
mõelda	doc_213943985046_item	2293534	et	4	main
autoritest	doc_213943985046_item	2293536	et	4	main
väga	doc_213943985046_item	2293577	et	3	main
teada	doc_213943985046_item	2293581	et	3	main
elasid	doc_213943985046_item	2293584	et	4	main
näiteks	doc_213943985046_item	2293585	et	4	main
mida	doc_213943985046_item	2293588	et	4	main
nad	doc_213943985046_item	2293589	et	3	main
ka	doc_213943985046_item	2293602	et	3	main
astusin	doc_213943985046_item	2293606	et	3	main
nagu	doc_213943985046_item	2293608	et	3	main
õpilane	doc_213943985046_item	2293610	et	3	main
oleks	doc_213943985046_item	2293613	et	3	main
valiks	doc_213943985046_item	2293620	et	3	main
seal	doc_213943985046_item	2293626	et	4	main
nüüd	doc_213943985046_item	2293629	et	4	main
õnnelik	doc_213943985046_item	2293631	et	3	main
et	doc_213943985046_item	2293632	et	3	main
mul	doc_213943985046_item	2293633	et	3	main
on	doc_213943985046_item	2293634	et	4	main
võimalus	doc_213943985046_item	2293635	et	3	main
vene	doc_213943985046_item	2293637	et	4	main
mingid	doc_213943985046_item	2293652	et	4	main
keelest	doc_213943985046_item	2293656	et	4	main
selleks	doc_213943985045_item	2293325	et	4	main
mina	doc_213943985045_item	2293335	et	4	main
ka	doc_213943985045_item	2293340	et	3	main
saan	doc_213943985045_item	2293347	et	4	main
venemaa	doc_213943985045_item	2293350	et	4	main
suur	doc_213943985045_item	2293359	et	3	main
2	doc_213943985045_item	2293364	et	2	main
on	doc_213943985045_item	2293365	et	4	main
alati	doc_213943985045_item	2293366	et	4	main
raske	doc_213943985045_item	2293367	et	4	main
öelda	doc_213943985045_item	2293368	et	4	main
mida	doc_213943985045_item	2293369	et	4	main
inimene	doc_213943985045_item	2293370	et	3	main
ootab	doc_213943985045_item	2293371	et	3	main
kui	doc_213943985045_item	2293372	et	3	main
ta	doc_213943985045_item	2293373	et	4	main
saabub	doc_213943985045_item	2293374	et	3	main
mingi	doc_213943985045_item	2293375	et	4	main
uue	doc_213943985045_item	2293376	et	3	main
kollektiivi	doc_213943985045_item	2293378	et	4	main
jne	doc_213943985045_item	2293379	et	4	main
esiteks	doc_213943985045_item	2293380	et	3	main
kohale	doc_213943985045_item	2293377	et	4	main
mina	doc_213943985045_item	2293381	et	4	main
ootan	doc_213943985045_item	2293382	et	3	main
kõike	doc_213943985045_item	2293394	et	4	main
mis	doc_213943985045_item	2293395	et	4	main
on	doc_213943985045_item	2293396	et	4	main
planeeritud	doc_213943985045_item	2293397	et	4	main
ka	doc_213943985045_item	2293398	et	3	main
oleks	doc_213943985045_item	2293399	et	3	main
kui	doc_213943985045_item	2293401	et	3	main
hindamisviis	doc_213943985045_item	2293403	et	3	main
objektiivne	doc_213943985045_item	2293405	et	3	main
ilmuvad	doc_213943985045_item	2293409	et	4	main
sõbrad	doc_213943985045_item	2293411	et	3	main
on	doc_213943985045_item	2293413	et	4	main
uue	doc_213943985045_item	2293416	et	3	main
et	doc_213943985045_item	2293421	et	3	main
koht	doc_213943985045_item	2293424	et	3	main
õppimiseks	doc_213943985045_item	2293428	et	4	main
aga	doc_213943985045_item	2293430	et	3	main
teen	doc_213943985045_item	2293432	et	3	main
selleks	doc_213943985045_item	2293434	et	4	main
ootan	doc_213943985045_item	2293441	et	3	main
vaadata	doc_213943985045_item	2293447	et	4	main
vaatenurgast	doc_213943985045_item	2293452	et	4	main
ise	doc_213943985045_item	2293455	et	4	main
teha	doc_213943985045_item	2293456	et	3	main
kõike	doc_213943985045_item	2293457	et	4	main
et	doc_213943985045_item	2293459	et	3	main
ülikoolis	doc_213943985045_item	2293461	et	4	main
kui	doc_213943985045_item	2293476	et	3	main
rohkem	doc_213943985045_item	2293492	et	4	main
omandamist	doc_213943985045_item	2293497	et	4	main
elus	doc_213943985045_item	2293502	et	4	main
elada	doc_213943985045_item	2293503	et	3	main
nii	doc_213943985045_item	2293504	et	3	main
mida	doc_213943985046_item	2293522	et	4	main
ma	doc_213943985046_item	2293523	et	3	main
ootan	doc_213943985046_item	2293524	et	3	main
lugeda	doc_213943985046_item	2293531	et	3	main
raamatuid	doc_213943985046_item	2293533	et	3	main
vene	doc_213943985046_item	2293541	et	4	main
filoloogia	doc_213943985046_item	2293542	et	4	main
eriala	doc_213943985046_item	2293543	et	4	main
andis	doc_213943985046_item	2293544	et	3	main
biograafiaga	doc_213943985046_item	2293549	et	3	main
saada	doc_213943985046_item	2293574	et	4	main
sellele	doc_213943985046_item	2293599	et	4	main
erialale	doc_213943985046_item	2293600	et	3	main
siia	doc_213943985046_item	2293607	et	4	main
mui	doc_213943985046_item	2293612	et	4	main
eraala	doc_213943985046_item	2293622	et	4	main
sest	doc_213943985046_item	2293623	et	4	main
aga	doc_213943985046_item	2293627	et	3	main
2	doc_213943985046_item	2293640	et	2	main
et	doc_213943985046_item	2293649	et	3	main
teadmised	doc_213943985046_item	2293653	et	4	main
kultuurist	doc_213943985046_item	2293658	et	3	main
loodan	doc_213943985046_item	2293660	et	3	main
informatsiooni	doc_213943985046_item	2293669	et	4	main
mind	doc_213943985046_item	2293672	et	4	main
õpetaja	doc_213943985046_item	2293675	et	4	main
mingis	doc_213943985046_item	2293682	et	4	main
tähtis	doc_213943985046_item	2293688	et	4	main
kool	doc_213943985046_item	2293691	et	4	main
mina	doc_213943985046_item	2293728	et	4	main
mitte	doc_213943985046_item	2293730	et	3	main
1	doc_213943985047_item	2293738	et	2	main
ootan	doc_213943985047_item	2293746	et	3	main
selle	doc_213943985047_item	2293755	et	4	main
väga	doc_213943985047_item	2293762	et	3	main
selle	doc_213943985047_item	2293770	et	4	main
annab	doc_213943985047_item	2293775	et	3	main
tahan	doc_213943985047_item	2293777	et	3	main
silmaring	doc_213943985047_item	2293779	et	3	main
aga	doc_213943985047_item	2293781	et	3	main
mõjus	doc_213943985047_item	2293784	et	4	main
see	doc_213943985047_item	2293786	et	3	main
keel	doc_213943985047_item	2293790	et	4	main
ei	doc_213943985047_item	2293791	et	4	main
ülikool	doc_213943985045_item	2293422	et	4	main
kuhu	doc_213943985045_item	2293425	et	3	main
kõik	doc_213943985045_item	2293433	et	4	main
minu	doc_213943985045_item	2293436	et	3	main
et	doc_213943985045_item	2293442	et	3	main
ülikoolis	doc_213943985045_item	2293444	et	4	main
aitab	doc_213943985045_item	2293445	et	3	main
silmadega	doc_213943985045_item	2293450	et	3	main
oli	doc_213943985045_item	2293462	et	3	main
huvitav	doc_213943985045_item	2293463	et	4	main
ülikool	doc_213943985045_item	2293464	et	4	main
aitab	doc_213943985045_item	2293465	et	3	main
kõik	doc_213943985045_item	2293469	et	4	main
või	doc_213943985045_item	2293478	et	4	main
vanemad	doc_213943985045_item	2293479	et	4	main
nii	doc_213943985045_item	2293481	et	3	main
palju	doc_213943985045_item	2293482	et	4	main
kui	doc_213943985045_item	2293483	et	3	main
et	doc_213943985045_item	2293488	et	3	main
ootan	doc_213943985045_item	2293493	et	3	main
aidaks	doc_213943985045_item	2293499	et	3	main
kui	doc_213943985045_item	2293506	et	3	main
on	doc_213943985045_item	2293507	et	4	main
miks	doc_213943985046_item	2293511	et	4	main
ma	doc_213943985046_item	2293512	et	3	main
valisin	doc_213943985046_item	2293513	et	3	main
selle	doc_213943985046_item	2293514	et	4	main
eriala	doc_213943985046_item	2293515	et	4	main
2	doc_213943985046_item	2293516	et	2	main
mida	doc_213943985046_item	2293517	et	4	main
ma	doc_213943985046_item	2293518	et	3	main
ootan	doc_213943985046_item	2293519	et	3	main
pärast	doc_213943985046_item	2293520	et	4	main
mul	doc_213943985046_item	2293527	et	3	main
autorid	doc_213943985046_item	2293539	et	3	main
tutvuda	doc_213943985046_item	2293547	et	3	main
vene	doc_213943985046_item	2293551	et	4	main
ka	doc_213943985046_item	2293555	et	3	main
võimalust	doc_213943985046_item	2293556	et	3	main
tutvuda	doc_213943985046_item	2293557	et	3	main
võrrelda	doc_213943985046_item	2293560	et	4	main
seda	doc_213943985046_item	2293561	et	3	main
teiste	doc_213943985046_item	2293562	et	4	main
maade	doc_213943985046_item	2293563	et	3	main
kultuuriga	doc_213943985046_item	2293564	et	4	main
tihti	doc_213943985046_item	2293565	et	3	main
kui	doc_213943985046_item	2293566	et	3	main
sa	doc_213943985046_item	2293567	et	3	main
tead	doc_213943985046_item	2293568	et	4	main
midagi	doc_213943985046_item	2293569	et	4	main
kultuurist	doc_213943985046_item	2293570	et	3	main
on	doc_213943985046_item	2293571	et	4	main
kergem	doc_213943985046_item	2293572	et	4	main
aru	doc_213943985046_item	2293573	et	4	main
autorite	doc_213943985046_item	2293548	et	3	main
teostega	doc_213943985046_item	2293550	et	3	main
filoloogia	doc_213943985046_item	2293552	et	4	main
eriala	doc_213943985046_item	2293553	et	4	main
annab	doc_213943985046_item	2293554	et	3	main
kultuuriga	doc_213943985046_item	2293559	et	4	main
teoseid	doc_213943985046_item	2293576	et	3	main
üldse	doc_213943985046_item	2293580	et	3	main
kuidas	doc_213943985046_item	2293582	et	3	main
nende	doc_213943985046_item	2293595	et	4	main
riietus	doc_213943985046_item	2293596	et	4	main
suureks	doc_213943985046_item	2293597	et	4	main
plussiks	doc_213943985046_item	2293598	et	4	main
see	doc_213943985046_item	2293603	et	3	main
ma	doc_213943985046_item	2293605	et	3	main
re	doc_213943985046_item	2293609	et	4	main
kui	doc_213943985046_item	2293611	et	3	main
võimalus	doc_213943985046_item	2293614	et	3	main
eest	doc_213943985046_item	2293616	et	4	main
õppida	doc_213943985046_item	2293625	et	3	main
õppida	doc_213943985046_item	2293636	et	3	main
praegu	doc_213943985046_item	2293641	et	3	main
vene	doc_213943985046_item	2293644	et	4	main
mul	doc_213943985046_item	2293650	et	3	main
ja	doc_213943985046_item	2293657	et	3	main
ma	doc_213943985046_item	2293659	et	3	main
kaks	doc_213943985046_item	2293662	et	3	main
annavad	doc_213943985046_item	2293665	et	3	main
veel	doc_213943985046_item	2293667	et	4	main
uut	doc_213943985046_item	2293668	et	3	main
leida	doc_213943985046_item	2293679	et	3	main
et	doc_213943985046_item	2293721	et	3	main
ainult	doc_213943985046_item	2293731	et	4	main
nende	doc_213943985046_item	2293735	et	4	main
essee	doc_213943985047_item	2293737	et	4	main
miks	doc_213943985047_item	2293739	et	4	main
ma	doc_213943985047_item	2293740	et	3	main
valisin	doc_213943985047_item	2293741	et	3	main
selle	doc_213943985047_item	2293751	et	4	main
vene	doc_213943985047_item	2293760	et	4	main
ja	doc_213943985047_item	2293763	et	3	main
tahan	doc_213943985047_item	2293765	et	3	main
rohkem	doc_213943985047_item	2293767	et	4	main
ja	doc_213943985047_item	2293769	et	3	main
igasugune	doc_213943985047_item	2293773	et	3	main
üldteadmisi	doc_213943985047_item	2293776	et	3	main
oma	doc_213943985047_item	2293778	et	4	main
rikkendada	doc_213943985047_item	2293780	et	4	main
minu	doc_213943985047_item	2293788	et	3	main
sellest	doc_213943985047_item	2293824	et	4	main
mõelnud	doc_213943985047_item	2293826	et	4	main
ja	doc_213943985047_item	2293827	et	3	main
ka	doc_213943985047_item	2293835	et	3	main
praegu	doc_213943985047_item	2293840	et	3	main
tulevatest	doc_213943985047_item	2293846	et	4	main
on	doc_213943985047_item	2293853	et	4	main
õppimist	doc_213943985047_item	2293859	et	4	main
on	doc_213943985047_item	2293873	et	4	main
ma	doc_213943985047_item	2293880	et	3	main
täiskasvanutega	doc_213943985047_item	2293883	et	3	main
õppitada	doc_213943985047_item	2293884	et	4	main
keel	doc_213943985047_item	2293886	et	4	main
aga	doc_213943985047_item	2293888	et	3	main
arendada	doc_213943985047_item	2293907	et	3	main
et	doc_213943985047_item	2293922	et	3	main
veel	doc_213943985047_item	2293924	et	4	main
oma	doc_213943985047_item	2293927	et	4	main
leida	doc_213943985047_item	2293934	et	3	main
minu	doc_213943985047_item	2293940	et	3	main
kirjanduse	doc_213943985046_item	2293575	et	3	main
on	doc_213943985046_item	2293579	et	4	main
inimesed	doc_213943985046_item	2293583	et	3	main
millega	doc_213943985046_item	2293591	et	3	main
tegelesid	doc_213943985046_item	2293592	et	4	main
missugune	doc_213943985046_item	2293593	et	3	main
oli	doc_213943985046_item	2293594	et	3	main
et	doc_213943985046_item	2293604	et	3	main
hariduse	doc_213943985046_item	2293615	et	3	main
maksta	doc_213943985046_item	2293617	et	4	main
siis	doc_213943985046_item	2293618	et	3	main
sajandil	doc_213943985046_item	2293587	et	3	main
lugesid	doc_213943985046_item	2293590	et	4	main
oli	doc_213943985046_item	2293601	et	3	main
ma	doc_213943985046_item	2293619	et	3	main
psühholoogia	doc_213943985046_item	2293621	et	4	main
filoloogiat	doc_213943985046_item	2293638	et	3	main
ma	doc_213943985046_item	2293642	et	3	main
filoloogia	doc_213943985046_item	2293645	et	4	main
magistratuuris	doc_213943985046_item	2293647	et	4	main
nii	doc_213943985046_item	2293648	et	3	main
aastat	doc_213943985046_item	2293663	et	3	main
mulle	doc_213943985046_item	2293666	et	4	main
olla	doc_213943985046_item	2293673	et	3	main
tahaks	doc_213943985046_item	2293678	et	3	main
töökohta	doc_213943985046_item	2293681	et	4	main
koolis	doc_213943985046_item	2293683	et	4	main
missugune	doc_213943985046_item	2293689	et	3	main
head	doc_213943985046_item	2293724	et	4	main
suhted	doc_213943985046_item	2293725	et	3	main
õpetaja	doc_213943985046_item	2293733	et	4	main
selle	doc_213943985047_item	2293742	et	4	main
töölt	doc_213943985047_item	2293748	et	3	main
eriala	doc_213943985047_item	2293752	et	4	main
kirjandus	doc_213943985047_item	2293761	et	3	main
sellest	doc_213943985047_item	2293766	et	4	main
teada	doc_213943985047_item	2293768	et	3	main
et	doc_213943985047_item	2293772	et	3	main
et	doc_213943985047_item	2293787	et	3	main
väga	doc_213943985047_item	2293793	et	3	main
ja	doc_213943985047_item	2293795	et	3	main
tagasi	doc_213943985047_item	2293822	et	3	main
sain	doc_213943985047_item	2293830	et	3	main
tasuta	doc_213943985047_item	2293831	et	4	main
ja	doc_213943985047_item	2293833	et	3	main
palju	doc_213943985047_item	2293844	et	4	main
pärast	doc_213943985047_item	2293849	et	4	main
vaja	doc_213943985047_item	2293854	et	4	main
pärast	doc_213943985047_item	2293858	et	4	main
ei	doc_213943985047_item	2293866	et	4	main
kooli	doc_213943985047_item	2293871	et	4	main
vaja	doc_213943985047_item	2293892	et	4	main
töö	doc_213943985047_item	2293900	et	4	main
sind	doc_213943985047_item	2293906	et	4	main
mul	doc_213943985047_item	2293923	et	3	main
aeg	doc_213943985047_item	2293926	et	3	main
tahan	doc_213943985047_item	2293933	et	3	main
võta	doc_213943985047_item	2293938	et	4	main
1	doc_213943985049_item	2294146	et	2	main
õpimisest	doc_213943985049_item	2294156	et	4	main
alustan	doc_213943985049_item	2294159	et	3	main
keel	doc_213943985049_item	2294211	et	4	main
võõrkeelena	doc_213943985049_item	2294212	et	3	main
telekommunikatsioon	doc_213943985049_item	2294219	et	3	main
ülikoolis	doc_213943985049_item	2294221	et	4	main
mõtlesin	doc_213943985049_item	2294236	et	3	main
kaua	doc_213943985049_item	2294238	et	3	main
telekommunikatsioon	doc_213943985049_item	2294243	et	3	main
tuleviku	doc_213943985049_item	2294245	et	4	main
unistasin	doc_213943985046_item	2293624	et	3	main
olen	doc_213943985046_item	2293628	et	3	main
väga	doc_213943985046_item	2293630	et	3	main
tasuta	doc_213943985046_item	2293639	et	4	main
õpin	doc_213943985046_item	2293643	et	3	main
eriala	doc_213943985046_item	2293646	et	4	main
on	doc_213943985046_item	2293651	et	4	main
vene	doc_213943985046_item	2293654	et	4	main
kirjandusest	doc_213943985046_item	2293655	et	4	main
et	doc_213943985046_item	2293661	et	3	main
aitab	doc_213943985046_item	2293671	et	3	main
hea	doc_213943985046_item	2293674	et	4	main
mulle	doc_213943985046_item	2293685	et	4	main
ei	doc_213943985046_item	2293686	et	4	main
see	doc_213943985046_item	2293690	et	3	main
on	doc_213943985046_item	2293692	et	4	main
kus	doc_213943985046_item	2293693	et	3	main
ta	doc_213943985046_item	2293694	et	4	main
asub	doc_213943985046_item	2293695	et	3	main
kõigepealt	doc_213943985046_item	2293696	et	3	main
ma	doc_213943985046_item	2293697	et	3	main
tahaks	doc_213943985046_item	2293698	et	3	main
et	doc_213943985046_item	2293699	et	3	main
oleksin	doc_213943985046_item	2293700	et	3	main
õpetaja	doc_213943985046_item	2293702	et	4	main
kes	doc_213943985046_item	2293703	et	4	main
hästi	doc_213943985046_item	2293704	et	3	main
teab	doc_213943985046_item	2293705	et	3	main
oma	doc_213943985046_item	2293706	et	4	main
ainet	doc_213943985046_item	2293707	et	3	main
niisugune	doc_213943985046_item	2293701	et	3	main
kes	doc_213943985046_item	2293708	et	4	main
teab	doc_213943985046_item	2293709	et	3	main
haridussüsteemist	doc_213943985046_item	2293710	et	4	main
ja	doc_213943985046_item	2293711	et	3	main
mis	doc_213943985046_item	2293712	et	4	main
üldse	doc_213943985046_item	2293713	et	3	main
toimub	doc_213943985046_item	2293714	et	3	main
maailmas	doc_213943985046_item	2293715	et	3	main
oma	doc_213943985046_item	2293716	et	4	main
töölt	doc_213943985046_item	2293717	et	3	main
ma	doc_213943985046_item	2293718	et	3	main
ootan	doc_213943985046_item	2293719	et	3	main
seda	doc_213943985046_item	2293720	et	3	main
mul	doc_213943985046_item	2293722	et	3	main
lastega	doc_213943985046_item	2293726	et	3	main
et	doc_213943985046_item	2293727	et	3	main
oleks	doc_213943985046_item	2293729	et	3	main
sõber	doc_213943985046_item	2293736	et	3	main
1mina	doc_213943985047_item	2293749	et	4	main
kõige	doc_213943985047_item	2293753	et	4	main
et	doc_213943985047_item	2293757	et	3	main
ma	doc_213943985047_item	2293764	et	3	main
magistratuuris	doc_213943985046_item	2293664	et	4	main
mis	doc_213943985046_item	2293670	et	4	main
pärast	doc_213943985046_item	2293676	et	4	main
õppimist	doc_213943985046_item	2293677	et	4	main
endale	doc_213943985046_item	2293680	et	4	main
praegu	doc_213943985046_item	2293684	et	3	main
ole	doc_213943985046_item	2293687	et	4	main
oleksid	doc_213943985046_item	2293723	et	4	main
nende	doc_213943985046_item	2293732	et	4	main
vaid	doc_213943985046_item	2293734	et	3	main
eriala	doc_213943985047_item	2293743	et	4	main
2	doc_213943985047_item	2293744	et	2	main
mida	doc_213943985047_item	2293745	et	4	main
tulevatest	doc_213943985047_item	2293747	et	4	main
valisin	doc_213943985047_item	2293750	et	3	main
pealt	doc_213943985047_item	2293754	et	4	main
pärast	doc_213943985047_item	2293756	et	4	main
mulle	doc_213943985047_item	2293758	et	4	main
meeldib	doc_213943985047_item	2293759	et	3	main
filoloogia	doc_213943985047_item	2293774	et	4	main
valikusse	doc_213943985047_item	2293783	et	4	main
ka	doc_213943985047_item	2293785	et	3	main
eesti	doc_213943985047_item	2293789	et	4	main
hea	doc_213943985047_item	2293794	et	4	main
vene	doc_213943985047_item	2293796	et	4	main
filoloogias	doc_213943985047_item	2293797	et	3	main
palju	doc_213943985047_item	2293798	et	4	main
ained	doc_213943985047_item	2293799	et	3	main
on	doc_213943985047_item	2293800	et	4	main
vene	doc_213943985047_item	2293801	et	4	main
keeles	doc_213943985047_item	2293802	et	4	main
nüüd	doc_213943985047_item	2293803	et	4	main
ma	doc_213943985047_item	2293804	et	3	main
mõistan	doc_213943985047_item	2293805	et	3	main
et	doc_213943985047_item	2293806	et	3	main
võib	doc_213943985047_item	2293807	et	3	main
olla	doc_213943985047_item	2293808	et	3	main
oleks	doc_213943985047_item	2293809	et	3	main
parem	doc_213943985047_item	2293810	et	4	main
võta	doc_213943985047_item	2293811	et	4	main
selle	doc_213943985047_item	2293812	et	4	main
eriala	doc_213943985047_item	2293813	et	4	main
kus	doc_213943985047_item	2293814	et	3	main
saaks	doc_213943985047_item	2293815	et	3	main
õppida	doc_213943985047_item	2293816	et	3	main
eesti	doc_213943985047_item	2293817	et	4	main
keeles	doc_213943985047_item	2293818	et	4	main
aga	doc_213943985047_item	2293819	et	3	main
kolm	doc_213943985047_item	2293820	et	3	main
ma	doc_213943985047_item	2293823	et	3	main
ei	doc_213943985047_item	2293825	et	4	main
veel	doc_213943985047_item	2293828	et	4	main
oma	doc_213943985047_item	2293837	et	4	main
ma	doc_213943985047_item	2293841	et	3	main
ei	doc_213943985047_item	2293842	et	4	main
tööst	doc_213943985047_item	2293847	et	3	main
selle	doc_213943985047_item	2293848	et	4	main
et	doc_213943985047_item	2293850	et	3	main
kõige	doc_213943985047_item	2293851	et	4	main
õppimine	doc_213943985047_item	2293855	et	4	main
saada	doc_213943985047_item	2293862	et	4	main
mõtle	doc_213943985047_item	2293867	et	4	main
töötada	doc_213943985047_item	2293870	et	3	main
raske	doc_213943985047_item	2293875	et	4	main
pärast	doc_213943985047_item	2293771	et	4	main
minu	doc_213943985047_item	2293782	et	3	main
ole	doc_213943985047_item	2293792	et	4	main
aastad	doc_213943985047_item	2293821	et	3	main
mängis	doc_213943985047_item	2293836	et	3	main
2	doc_213943985047_item	2293839	et	2	main
oma	doc_213943985047_item	2293845	et	4	main
pealt	doc_213943985047_item	2293852	et	4	main
lõppetada	doc_213943985047_item	2293856	et	4	main
ma	doc_213943985047_item	2293860	et	3	main
huvitavat	doc_213943985047_item	2293863	et	4	main
tööd	doc_213943985047_item	2293864	et	4	main
ma	doc_213943985047_item	2293865	et	3	main
see	doc_213943985047_item	2293872	et	3	main
lastega	doc_213943985047_item	2293877	et	3	main
siis	doc_213943985047_item	2293889	et	3	main
koolitusi	doc_213943985047_item	2293894	et	4	main
läbi	doc_213943985047_item	2293895	et	4	main
meeles	doc_213943985047_item	2293898	et	3	main
igasugune	doc_213943985047_item	2293899	et	3	main
peab	doc_213943985047_item	2293901	et	4	main
olema	doc_213943985047_item	2293902	et	4	main
huvitav	doc_213943985047_item	2293903	et	4	main
see	doc_213943985047_item	2293904	et	3	main
tahaksin	doc_213943985047_item	2293921	et	3	main
oleks	doc_213943985047_item	2293925	et	3	main
perekonnaga	doc_213943985047_item	2293928	et	4	main
koduasju	doc_213943985047_item	2293931	et	3	main
töö	doc_213943985047_item	2293935	et	4	main
ei	doc_213943985047_item	2293937	et	4	main
aeg	doc_213943985047_item	2293941	et	3	main
essee	doc_213943985049_item	2294145	et	4	main
eriala	doc_213943985049_item	2294151	et	4	main
ma	doc_213943985049_item	2294154	et	3	main
ootan	doc_213943985049_item	2294155	et	3	main
1	doc_213943985049_item	2294158	et	2	main
sõpradele	doc_213943985049_item	2294172	et	3	main
oma	doc_213943985049_item	2294173	et	4	main
valik	doc_213943985049_item	2294203	et	3	main
vene	doc_213943985049_item	2294210	et	4	main
eesti	doc_213943985049_item	2294213	et	4	main
võõrkeelena	doc_213943985049_item	2294215	et	3	main
tartu	doc_213943985049_item	2294216	et	4	main
tehnika	doc_213943985049_item	2294220	et	4	main
sisse	doc_213943985049_item	2294224	et	4	main
kõigesse	doc_213943985049_item	2294225	et	4	main
mainitud	doc_213943985049_item	2294226	et	4	main
väga	doc_213943985049_item	2294237	et	3	main
ja	doc_213943985049_item	2294239	et	3	main
et	doc_213943985049_item	2294242	et	3	main
elukutse	doc_213943985049_item	2294246	et	4	main
perspektiivne	doc_213943985049_item	2294249	et	3	main
nii	doc_213943985049_item	2294251	et	3	main
hakkasin	doc_213943985049_item	2294255	et	3	main
üldse	doc_213943985049_item	2294261	et	3	main
ma	doc_213943985047_item	2293829	et	3	main
koha	doc_213943985047_item	2293832	et	4	main
see	doc_213943985047_item	2293834	et	3	main
rolli	doc_213943985047_item	2293838	et	4	main
mõtle	doc_213943985047_item	2293843	et	4	main
aga	doc_213943985047_item	2293857	et	3	main
tahan	doc_213943985047_item	2293861	et	3	main
et	doc_213943985047_item	2293868	et	3	main
lähen	doc_213943985047_item	2293869	et	3	main
väga	doc_213943985047_item	2293874	et	3	main
töötada	doc_213943985047_item	2293876	et	3	main
olla	doc_213943985047_item	2293879	et	3	main
töötaga	doc_213943985047_item	2293882	et	4	main
vene	doc_213943985047_item	2293885	et	4	main
võõrkeelena	doc_213943985047_item	2293887	et	3	main
mul	doc_213943985047_item	2293890	et	3	main
minna	doc_213943985047_item	2293896	et	3	main
minu	doc_213943985047_item	2293897	et	3	main
peab	doc_213943985047_item	2293905	et	4	main
see	doc_213943985047_item	2293908	et	3	main
ei	doc_213943985047_item	2293909	et	4	main
pea	doc_213943985047_item	2293910	et	4	main
olema	doc_213943985047_item	2293911	et	4	main
rutiin	doc_213943985047_item	2293912	et	3	main
mida	doc_213943985047_item	2293913	et	4	main
sa	doc_213943985047_item	2293914	et	3	main
teed	doc_213943985047_item	2293915	et	4	main
nagu	doc_213943985047_item	2293916	et	3	main
robot	doc_213943985047_item	2293917	et	3	main
ja	doc_213943985047_item	2293918	et	3	main
veel	doc_213943985047_item	2293919	et	4	main
ma	doc_213943985047_item	2293920	et	3	main
võib	doc_213943985047_item	2293878	et	3	main
tahaksin	doc_213943985047_item	2293881	et	3	main
on	doc_213943985047_item	2293891	et	4	main
veel	doc_213943985047_item	2293893	et	4	main
veeta	doc_213943985047_item	2293929	et	4	main
kogu	doc_213943985047_item	2293939	et	4	main
miks	doc_213943985049_item	2294147	et	4	main
selle	doc_213943985049_item	2294150	et	4	main
ülikoolist	doc_213943985049_item	2294157	et	4	main
sellest	doc_213943985049_item	2294160	et	4	main
et	doc_213943985049_item	2294161	et	3	main
lapsepõlvest	doc_213943985049_item	2294162	et	4	main
huvi	doc_213943985049_item	2294164	et	4	main
mille	doc_213943985049_item	2294204	et	3	main
ikka	doc_213943985049_item	2294206	et	4	main
niisugused	doc_213943985049_item	2294208	et	3	main
igasuguseid	doc_213943985047_item	2293930	et	3	main
teha	doc_213943985047_item	2293932	et	3	main
mis	doc_213943985047_item	2293936	et	4	main
ma	doc_213943985049_item	2294148	et	3	main
tundsin	doc_213943985049_item	2294163	et	3	main
lugemise	doc_213943985049_item	2294165	et	4	main
vastu	doc_213943985049_item	2294166	et	3	main
väikesena	doc_213943985049_item	2294167	et	4	main
lugesin	doc_213943985049_item	2294168	et	3	main
kõigele	doc_213943985049_item	2294169	et	4	main
mänguasjadele	doc_213943985049_item	2294174	et	3	main
erialad	doc_213943985049_item	2294209	et	3	main
ülikoolis	doc_213943985049_item	2294217	et	4	main
ja	doc_213943985049_item	2294218	et	3	main
neist	doc_213943985049_item	2294234	et	4	main
on	doc_213943985049_item	2294248	et	4	main
edasi	doc_213943985049_item	2294252	et	3	main
kui	doc_213943985049_item	2294254	et	3	main
aru	doc_213943985049_item	2294258	et	4	main
see	doc_213943985049_item	2294260	et	3	main
füüsika	doc_213943985049_item	2294266	et	4	main
valisin	doc_213943985049_item	2294149	et	3	main
2	doc_213943985049_item	2294152	et	2	main
mida	doc_213943985049_item	2294153	et	4	main
vanematele	doc_213943985049_item	2294170	et	4	main
lasteaias	doc_213943985049_item	2294171	et	4	main
koolis	doc_213943985049_item	2294175	et	4	main
kirjanduse	doc_213943985049_item	2294176	et	3	main
tund	doc_213943985049_item	2294177	et	3	main
oli	doc_213943985049_item	2294178	et	3	main
minu	doc_213943985049_item	2294179	et	3	main
lemmik	doc_213943985049_item	2294181	et	3	main
ja	doc_213943985049_item	2294182	et	3	main
pärast	doc_213943985049_item	2294183	et	4	main
kõige	doc_213943985049_item	2294180	et	4	main
kooli	doc_213943985049_item	2294184	et	4	main
lõpetamist	doc_213943985049_item	2294185	et	4	main
teadsin	doc_213943985049_item	2294186	et	3	main
et	doc_213943985049_item	2294187	et	3	main
tahan	doc_213943985049_item	2294188	et	3	main
õppida	doc_213943985049_item	2294189	et	3	main
humanitaarainet	doc_213943985049_item	2294191	et	3	main
just	doc_213943985049_item	2294190	et	3	main
aga	doc_213943985049_item	2294192	et	3	main
kui	doc_213943985049_item	2294193	et	3	main
tuli	doc_213943985049_item	2294194	et	4	main
aeg	doc_213943985049_item	2294195	et	3	main
sisseastumise	doc_213943985049_item	2294196	et	3	main
eksamite	doc_213943985049_item	2294197	et	3	main
sooritamiseks	doc_213943985049_item	2294198	et	4	main
siis	doc_213943985049_item	2294199	et	3	main
oli	doc_213943985049_item	2294200	et	3	main
väga	doc_213943985049_item	2294201	et	3	main
raske	doc_213943985049_item	2294202	et	4	main
valida	doc_213943985049_item	2294205	et	3	main
valisin	doc_213943985049_item	2294207	et	3	main
keel	doc_213943985049_item	2294214	et	4	main
astusin	doc_213943985049_item	2294223	et	3	main
siis	doc_213943985049_item	2294228	et	3	main
raskem	doc_213943985049_item	2294230	et	4	main
oli	doc_213943985049_item	2294231	et	3	main
otsustada	doc_213943985049_item	2294232	et	3	main
ja	doc_213943985049_item	2294250	et	3	main
sain	doc_213943985049_item	2294257	et	3	main
meeldi	doc_213943985049_item	2294263	et	4	main
mulle	doc_213943985049_item	2294264	et	4	main
lugesin	doc_213943985049_item	2294269	et	3	main
ahmatova	doc_213943985049_item	2294271	et	4	main
luuletusi	doc_213943985049_item	2294272	et	4	main
all	doc_213943985049_item	2294276	et	3	main
see	doc_213943985049_item	2294278	et	3	main
kaks	doc_213943985049_item	2294281	et	3	main
ei	doc_213943985049_item	2294286	et	4	main
kahe	doc_213943985049_item	2294293	et	3	main
jooksul	doc_213943985049_item	2294295	et	4	main
sain	doc_213943985049_item	2294296	et	3	main
vaja	doc_213943985049_item	2294301	et	4	main
mitte	doc_213943985049_item	2294306	et	3	main
aga	doc_213943985049_item	2294310	et	3	main
tallinna	doc_213943985049_item	2294321	et	4	main
siis	doc_213943985049_item	2294323	et	3	main
selle	doc_213943985049_item	2294334	et	4	main
ülikooli	doc_213943985049_item	2294335	et	4	main
ja	doc_213943985049_item	2294337	et	3	main
olema	doc_213943985049_item	2294342	et	4	main
kõrghariduse	doc_213943985049_item	2294348	et	3	main
tähtis	doc_213943985049_item	2294352	et	4	main
see	doc_213943985049_item	2294353	et	3	main
aitab	doc_213943985049_item	2294354	et	3	main
tööd	doc_213943985049_item	2294356	et	4	main
loodan	doc_213943985049_item	2294369	et	3	main
see	doc_213943985049_item	2294377	et	3	main
tahan	doc_213943985049_item	2294382	et	3	main
see	doc_213943985049_item	2294390	et	3	main
need	doc_213943985049_item	2294422	et	3	main
nii	doc_213943985049_item	2294430	et	3	main
saada	doc_213943985049_item	2294436	et	4	main
mitte	doc_213943985049_item	2294439	et	3	main
sest	doc_213943985049_item	2294449	et	4	main
huvitav	doc_213943985049_item	2294468	et	4	main
loen	doc_213943985049_item	2294477	et	3	main
ja	doc_213943985049_item	2294482	et	3	main
keelele	doc_213943985049_item	2294486	et	4	main
andes	doc_213943985049_item	2294487	et	4	main
ootan	doc_213943985049_item	2294496	et	3	main
seda	doc_213943985049_item	2294498	et	3	main
saan	doc_213943985049_item	2294500	et	4	main
minu	doc_213943985049_item	2294505	et	3	main
leida	doc_213943985049_item	2294511	et	3	main
mis	doc_213943985049_item	2294513	et	4	main
meeldib	doc_213943985049_item	2294514	et	3	main
kui	doc_213943985049_item	2294222	et	3	main
ülikoolidesse	doc_213943985049_item	2294227	et	3	main
veel	doc_213943985049_item	2294229	et	4	main
mille	doc_213943985049_item	2294233	et	3	main
valida	doc_213943985049_item	2294235	et	3	main
jõudsin	doc_213943985049_item	2294240	et	3	main
tulemuseni	doc_213943985049_item	2294241	et	3	main
on	doc_213943985049_item	2294244	et	4	main
aga	doc_213943985049_item	2294253	et	3	main
näiteks	doc_213943985049_item	2294265	et	4	main
oli	doc_213943985049_item	2294280	et	3	main
aastat	doc_213943985049_item	2294282	et	3	main
tagasi	doc_213943985049_item	2294283	et	3	main
arva	doc_213943985049_item	2294287	et	4	main
aru	doc_213943985049_item	2294297	et	4	main
on	doc_213943985049_item	2294300	et	4	main
mis	doc_213943985049_item	2294308	et	4	main
ei	doc_213943985049_item	2294312	et	4	main
huvi	doc_213943985049_item	2294314	et	4	main
mille	doc_213943985049_item	2294326	et	3	main
dokumente	doc_213943985049_item	2294329	et	3	main
praegu	doc_213943985049_item	2294333	et	3	main
tuleviku	doc_213943985049_item	2294339	et	4	main
tänapäevases	doc_213943985049_item	2294346	et	4	main
väga	doc_213943985049_item	2294351	et	3	main
on	doc_213943985049_item	2294363	et	4	main
esimene	doc_213943985049_item	2294364	et	3	main
kraadi	doc_213943985049_item	2294376	et	4	main
oma	doc_213943985049_item	2294384	et	4	main
ajalugu	doc_213943985049_item	2294428	et	4	main
edasi	doc_213943985049_item	2294431	et	3	main
veel	doc_213943985049_item	2294433	et	4	main
tõlkjaks	doc_213943985049_item	2294437	et	3	main
alati	doc_213943985049_item	2294447	et	4	main
lugeda	doc_213943985049_item	2294452	et	3	main
ka	doc_213943985049_item	2294453	et	3	main
võõrkeeles	doc_213943985049_item	2294455	et	4	main
aitab	doc_213943985049_item	2294457	et	3	main
minu	doc_213943985049_item	2294461	et	3	main
meelest	doc_213943985049_item	2294462	et	4	main
tõlkjana	doc_213943985049_item	2294463	et	3	main
ainult	doc_213943985049_item	2294467	et	4	main
vaid	doc_213943985049_item	2294471	et	3	main
selle	doc_213943985049_item	2294484	et	4	main
teisele	doc_213943985049_item	2294485	et	4	main
sellega	doc_213943985049_item	2294488	et	3	main
võimalust	doc_213943985049_item	2294489	et	3	main
teistele	doc_213943985049_item	2294490	et	4	main
inimisele	doc_213943985049_item	2294491	et	4	main
õpimisest	doc_213943985049_item	2294494	et	4	main
kõrgharidust	doc_213943985049_item	2294501	et	4	main
teha	doc_213943985049_item	2294523	et	3	main
mis	doc_213943985049_item	2294525	et	4	main
kasulik	doc_213943985049_item	2294527	et	3	main
ka	doc_213943985049_item	2294528	et	3	main
essee	doc_213943985050_item	2294530	et	4	main
õppimisest	doc_213943985050_item	2294540	et	4	main
ma	doc_213943985050_item	2294543	et	3	main
et	doc_213943985050_item	2294550	et	3	main
keel	doc_213943985050_item	2294552	et	4	main
võõrkeelena	doc_213943985050_item	2294553	et	3	main
ja	doc_213943985050_item	2294556	et	3	main
soovivad	doc_213943985050_item	2294564	et	4	main
tahavad	doc_213943985050_item	2294578	et	3	main
jaoks	doc_213943985050_item	2294586	et	4	main
ainult	doc_213943985050_item	2294593	et	4	main
keel	doc_213943985050_item	2294600	et	4	main
mul	doc_213943985050_item	2294602	et	3	main
laiendab	doc_213943985050_item	2294612	et	3	main
võimalus	doc_213943985050_item	2294615	et	3	main
palju	doc_213943985050_item	2294620	et	4	main
selle	doc_213943985050_item	2294628	et	4	main
erialaga	doc_213943985050_item	2294629	et	3	main
minu	doc_213943985050_item	2294635	et	3	main
aga	doc_213943985050_item	2294644	et	3	main
inimestele	doc_213943985050_item	2294656	et	3	main
kõrgharidus	doc_213943985050_item	2294659	et	3	main
ei	doc_213943985050_item	2294661	et	4	main
kaasaaeglased	doc_213943985050_item	2294669	et	3	main
et	doc_213943985050_item	2294680	et	3	main
huvitatud	doc_213943985050_item	2294689	et	4	main
tal	doc_213943985050_item	2294692	et	3	main
võimalus	doc_213943985050_item	2294694	et	3	main
rääkides	doc_213943985051_item	2294721	et	4	main
see	doc_213943985049_item	2294247	et	3	main
õppida	doc_213943985049_item	2294256	et	3	main
et	doc_213943985049_item	2294259	et	3	main
ei	doc_213943985049_item	2294262	et	4	main
ma	doc_213943985049_item	2294268	et	3	main
hoides	doc_213943985049_item	2294273	et	4	main
pingi	doc_213943985049_item	2294275	et	4	main
kõik	doc_213943985049_item	2294277	et	4	main
et	doc_213943985049_item	2294288	et	3	main
oli	doc_213943985049_item	2294290	et	3	main
aasta	doc_213943985049_item	2294294	et	4	main
seda	doc_213943985049_item	2294302	et	3	main
üldse	doc_213943985049_item	2294311	et	3	main
tulin	doc_213943985049_item	2294320	et	3	main
ülikooli	doc_213943985049_item	2294322	et	4	main
teadsin	doc_213943985049_item	2294324	et	3	main
minu	doc_213943985049_item	2294338	et	3	main
omandamine	doc_213943985049_item	2294349	et	4	main
leida	doc_213943985049_item	2294355	et	3	main
tunned	doc_213943985049_item	2294358	et	3	main
enesekindlustatud	doc_213943985049_item	2294360	et	3	main
ülikoolisse	doc_213943985049_item	2294361	et	4	main
sisseastumine	doc_213943985049_item	2294362	et	3	main
samm	doc_213943985049_item	2294365	et	3	main
eesmärk	doc_213943985049_item	2294379	et	3	main
saavutada	doc_213943985049_item	2294383	et	3	main
ootan	doc_213943985049_item	2294386	et	3	main
et	doc_213943985049_item	2294389	et	3	main
kirjandus	doc_213943985049_item	2294427	et	3	main
et	doc_213943985049_item	2294434	et	3	main
vaid	doc_213943985049_item	2294438	et	3	main
õpetajaks	doc_213943985049_item	2294440	et	4	main
leida	doc_213943985049_item	2294443	et	3	main
mulle	doc_213943985049_item	2294450	et	4	main
kirjandust	doc_213943985049_item	2294454	et	3	main
õppida	doc_213943985049_item	2294458	et	3	main
mitte	doc_213943985049_item	2294466	et	3	main
näiteks	doc_213943985049_item	2294476	et	4	main
mingit	doc_213943985049_item	2294478	et	3	main
raamatut	doc_213943985049_item	2294480	et	3	main
tõlgin	doc_213943985049_item	2294483	et	3	main
et	doc_213943985049_item	2294499	et	3	main
tööd	doc_213943985049_item	2294512	et	4	main
mis	doc_213943985049_item	2294515	et	4	main
tasutud	doc_213943985049_item	2294518	et	4	main
pakub	doc_213943985049_item	2294520	et	3	main
karjääri	doc_213943985049_item	2294522	et	4	main
ja	doc_213943985049_item	2294524	et	3	main
selle	doc_213943985050_item	2294535	et	4	main
eriala	doc_213943985050_item	2294536	et	4	main
1	doc_213943985050_item	2294542	et	2	main
tea	doc_213943985050_item	2294545	et	4	main
on	doc_213943985050_item	2294554	et	4	main
perspektiivne	doc_213943985050_item	2294555	et	3	main
näiteks	doc_213943985050_item	2294560	et	4	main
palju	doc_213943985050_item	2294572	et	4	main
inimesi	doc_213943985050_item	2294573	et	4	main
välismaalt	doc_213943985050_item	2294574	et	3	main
tulevad	doc_213943985050_item	2294575	et	4	main
eestisse	doc_213943985050_item	2294576	et	4	main
ja	doc_213943985050_item	2294577	et	3	main
vene	doc_213943985050_item	2294580	et	4	main
keelt	doc_213943985050_item	2294581	et	4	main
õppida	doc_213943985050_item	2294582	et	3	main
ma	doc_213943985050_item	2294589	et	3	main
või	doc_213943985050_item	2294595	et	4	main
oleks	doc_213943985050_item	2294603	et	3	main
välismaale	doc_213943985050_item	2294606	et	4	main
et	doc_213943985050_item	2294609	et	3	main
silmaringi	doc_213943985050_item	2294613	et	4	main
keeli	doc_213943985050_item	2294621	et	4	main
maailma	doc_213943985050_item	2294623	et	4	main
vaatada	doc_213943985050_item	2294624	et	4	main
ma	doc_213943985050_item	2294625	et	3	main
olen	doc_213943985050_item	2294626	et	3	main
jaoks	doc_213943985050_item	2294636	et	4	main
ma	doc_213943985050_item	2294638	et	3	main
praegu	doc_213943985050_item	2294643	et	3	main
mulle	doc_213943985050_item	2294645	et	4	main
on	doc_213943985050_item	2294650	et	4	main
suurepärane	doc_213943985050_item	2294653	et	4	main
ülikool	doc_213943985050_item	2294654	et	4	main
loengutel	doc_213943985049_item	2294267	et	4	main
a	doc_213943985049_item	2294270	et	4	main
raamatut	doc_213943985049_item	2294274	et	3	main
lugu	doc_213943985049_item	2294279	et	4	main
aga	doc_213943985049_item	2294284	et	3	main
aja	doc_213943985049_item	2294291	et	4	main
õppida	doc_213943985049_item	2294299	et	3	main
mis	doc_213943985049_item	2294303	et	4	main
vaid	doc_213943985049_item	2294305	et	3	main
seda	doc_213943985049_item	2294307	et	3	main
paku	doc_213943985049_item	2294313	et	4	main
ja	doc_213943985049_item	2294315	et	3	main
kui	doc_213943985049_item	2294316	et	3	main
sellel	doc_213943985049_item	2294317	et	4	main
suvel	doc_213943985049_item	2294318	et	3	main
ma	doc_213943985049_item	2294319	et	3	main
täpselt	doc_213943985049_item	2294325	et	4	main
oma	doc_213943985049_item	2294328	et	4	main
ära	doc_213943985049_item	2294330	et	4	main
tudeng	doc_213943985049_item	2294336	et	3	main
paistab	doc_213943985049_item	2294341	et	3	main
päris	doc_213943985049_item	2294343	et	4	main
huvitav	doc_213943985049_item	2294344	et	4	main
2	doc_213943985049_item	2294345	et	2	main
millega	doc_213943985049_item	2294357	et	3	main
end	doc_213943985049_item	2294359	et	4	main
pika	doc_213943985049_item	2294366	et	4	main
pärast	doc_213943985049_item	2294371	et	4	main
ongi	doc_213943985049_item	2294378	et	4	main
ma	doc_213943985049_item	2294381	et	3	main
õpimisest	doc_213943985049_item	2294385	et	4	main
kõigepealt	doc_213943985049_item	2294387	et	3	main
seda	doc_213943985049_item	2294388	et	3	main
on	doc_213943985049_item	2294391	et	4	main
huvitav	doc_213943985049_item	2294392	et	4	main
tean	doc_213943985049_item	2294393	et	3	main
et	doc_213943985049_item	2294394	et	3	main
minu	doc_213943985049_item	2294395	et	3	main
jaoks	doc_213943985049_item	2294396	et	4	main
huvi	doc_213943985049_item	2294421	et	4	main
maailma	doc_213943985049_item	2294426	et	4	main
võimalus	doc_213943985049_item	2294435	et	3	main
aitab	doc_213943985049_item	2294441	et	3	main
mul	doc_213943985049_item	2294442	et	3	main
tööd	doc_213943985049_item	2294444	et	4	main
millest	doc_213943985049_item	2294445	et	3	main
ma	doc_213943985049_item	2294446	et	3	main
unistasin	doc_213943985049_item	2294448	et	3	main
sõnu	doc_213943985049_item	2294460	et	4	main
on	doc_213943985049_item	2294465	et	4	main
suurepärast	doc_213943985049_item	2294479	et	4	main
võõrkeeles	doc_213943985049_item	2294481	et	4	main
ülikoolis	doc_213943985049_item	2294495	et	4	main
kõigepealt	doc_213943985049_item	2294497	et	3	main
on	doc_213943985049_item	2294503	et	4	main
jaoks	doc_213943985049_item	2294506	et	4	main
ja	doc_213943985049_item	2294507	et	3	main
aitab	doc_213943985049_item	2294509	et	3	main
on	doc_213943985049_item	2294516	et	4	main
ja	doc_213943985049_item	2294519	et	3	main
1	doc_213943985050_item	2294531	et	2	main
miks	doc_213943985050_item	2294532	et	4	main
ma	doc_213943985050_item	2294533	et	3	main
2	doc_213943985050_item	2294537	et	2	main
mida	doc_213943985050_item	2294538	et	4	main
ei	doc_213943985050_item	2294544	et	4	main
täpselt	doc_213943985050_item	2294546	et	4	main
tänapäeval	doc_213943985050_item	2294559	et	3	main
eesti	doc_213943985050_item	2294561	et	4	main
keel	doc_213943985050_item	2294566	et	4	main
on	doc_213943985050_item	2294569	et	4	main
esiteks	doc_213943985050_item	2294570	et	3	main
teiseks	doc_213943985050_item	2294571	et	4	main
ka	doc_213943985050_item	2294579	et	3	main
huvitav	doc_213943985050_item	2294587	et	4	main
kui	doc_213943985050_item	2294588	et	3	main
vene	doc_213943985050_item	2294594	et	4	main
eesti	doc_213943985050_item	2294596	et	4	main
aga	doc_213943985050_item	2294598	et	3	main
inglise	doc_213943985050_item	2294599	et	4	main
sõida	doc_213943985050_item	2294605	et	4	main
ma	doc_213943985050_item	2294607	et	3	main
see	doc_213943985050_item	2294610	et	3	main
ma	doc_213943985049_item	2294285	et	3	main
see	doc_213943985049_item	2294289	et	3	main
raiskamine	doc_213943985049_item	2294292	et	4	main
et	doc_213943985049_item	2294298	et	3	main
meeldib	doc_213943985049_item	2294304	et	3	main
perspektiivne	doc_213943985049_item	2294309	et	3	main
erialale	doc_213943985049_item	2294327	et	3	main
anda	doc_213943985049_item	2294331	et	3	main
olen	doc_213943985049_item	2294332	et	3	main
töö	doc_213943985049_item	2294340	et	4	main
ühiskonnas	doc_213943985049_item	2294347	et	4	main
on	doc_213943985049_item	2294350	et	4	main
haridusteel	doc_213943985049_item	2294367	et	3	main
ma	doc_213943985049_item	2294368	et	3	main
et	doc_213943985049_item	2294370	et	3	main
viis	doc_213943985049_item	2294372	et	4	main
aastat	doc_213943985049_item	2294373	et	3	main
saan	doc_213943985049_item	2294374	et	4	main
magistri	doc_213943985049_item	2294375	et	3	main
mida	doc_213943985049_item	2294380	et	4	main
see	doc_213943985049_item	2294397	et	3	main
on	doc_213943985049_item	2294398	et	4	main
kõige	doc_213943985049_item	2294399	et	4	main
tähtsam	doc_213943985049_item	2294400	et	4	main
ja	doc_213943985049_item	2294401	et	3	main
ma	doc_213943985049_item	2294402	et	3	main
arvan	doc_213943985049_item	2294403	et	3	main
et	doc_213943985049_item	2294404	et	3	main
vene	doc_213943985049_item	2294405	et	4	main
keel	doc_213943985049_item	2294406	et	4	main
võõrkeelena	doc_213943985049_item	2294407	et	3	main
on	doc_213943985049_item	2294408	et	4	main
päris	doc_213943985049_item	2294409	et	4	main
huvitav	doc_213943985049_item	2294410	et	4	main
eriala	doc_213943985049_item	2294411	et	4	main
sest	doc_213943985049_item	2294412	et	4	main
siin	doc_213943985049_item	2294413	et	4	main
õpetakse	doc_213943985049_item	2294414	et	4	main
ainet	doc_213943985049_item	2294415	et	3	main
mille	doc_213943985049_item	2294416	et	3	main
vastu	doc_213943985049_item	2294417	et	3	main
ma	doc_213943985049_item	2294418	et	3	main
alati	doc_213943985049_item	2294419	et	4	main
tundsin	doc_213943985049_item	2294420	et	3	main
on	doc_213943985049_item	2294423	et	4	main
vene	doc_213943985049_item	2294424	et	4	main
ja	doc_213943985049_item	2294425	et	3	main
ja	doc_213943985049_item	2294429	et	3	main
ootan	doc_213943985049_item	2294432	et	3	main
meeldib	doc_213943985049_item	2294451	et	3	main
see	doc_213943985049_item	2294456	et	3	main
uut	doc_213943985049_item	2294459	et	3	main
töötamine	doc_213943985049_item	2294464	et	4	main
minu	doc_213943985049_item	2294469	et	3	main
jaoks	doc_213943985049_item	2294470	et	4	main
on	doc_213943985049_item	2294472	et	4	main
kasulik	doc_213943985049_item	2294473	et	3	main
ka	doc_213943985049_item	2294474	et	3	main
teistele	doc_213943985049_item	2294475	et	4	main
lugeda	doc_213943985049_item	2294492	et	3	main
niisiis	doc_213943985049_item	2294493	et	3	main
mis	doc_213943985049_item	2294502	et	4	main
huvitav	doc_213943985049_item	2294504	et	4	main
see	doc_213943985049_item	2294508	et	3	main
mul	doc_213943985049_item	2294510	et	3	main
hästi	doc_213943985049_item	2294517	et	3	main
ootan	doc_213943985050_item	2294539	et	3	main
vene	doc_213943985050_item	2294551	et	4	main
eriala	doc_213943985050_item	2294558	et	4	main
õpilased	doc_213943985050_item	2294563	et	3	main
vene	doc_213943985050_item	2294565	et	4	main
õppida	doc_213943985050_item	2294567	et	3	main
see	doc_213943985050_item	2294568	et	3	main
on	doc_213943985050_item	2294584	et	4	main
nende	doc_213943985050_item	2294585	et	4	main
hästi	doc_213943985050_item	2294591	et	3	main
võimalus	doc_213943985050_item	2294604	et	3	main
arvan	doc_213943985050_item	2294608	et	3	main
eriala	doc_213943985050_item	2294611	et	4	main
on	doc_213943985050_item	2294633	et	4	main
oska	doc_213943985050_item	2294640	et	4	main
täiesti	doc_213943985050_item	2294641	et	3	main
öelda	doc_213943985050_item	2294642	et	4	main
õppimine	doc_213943985050_item	2294648	et	4	main
annab	doc_213943985050_item	2294655	et	3	main
absoluutselt	doc_213943985050_item	2294663	et	4	main
mulle	doc_213943985050_item	2294666	et	4	main
saada	doc_213943985050_item	2294672	et	4	main
kõrgharidust	doc_213943985050_item	2294673	et	4	main
aga	doc_213943985050_item	2294674	et	3	main
võtma	doc_213943985050_item	2294684	et	3	main
sellel	doc_213943985050_item	2294690	et	4	main
juhul	doc_213943985050_item	2294691	et	3	main
on	doc_213943985050_item	2294693	et	4	main
tarvis	doc_213943985051_item	2294733	et	3	main
kui	doc_213943985051_item	2294735	et	3	main
üttelda	doc_213943985051_item	2294743	et	4	main
müüjale	doc_213943985051_item	2294744	et	4	main
tahab	doc_213943985051_item	2294747	et	3	main
eesti	doc_213943985051_item	2294767	et	4	main
ka	doc_213943985051_item	2294772	et	3	main
oma	doc_213943985051_item	2294783	et	4	main
oma	doc_213943985051_item	2294787	et	4	main
essee	doc_213943985052_item	2294794	et	4	main
ma	doc_213943985052_item	2294796	et	3	main
tänapäeval	doc_213943985052_item	2294828	et	3	main
on	doc_213943985052_item	2294830	et	4	main
ja	doc_213943985052_item	2294834	et	3	main
mis	doc_213943985052_item	2294847	et	4	main
eriala	doc_213943985052_item	2294853	et	4	main
ma	doc_213943985052_item	2294854	et	3	main
valisin	doc_213943985052_item	2294855	et	3	main
selle	doc_213943985052_item	2294856	et	4	main
kõigepealt	doc_213943985052_item	2294858	et	3	main
sest	doc_213943985052_item	2294859	et	4	main
millelegi	doc_213943985052_item	2294862	et	4	main
võimalust	doc_213943985049_item	2294521	et	3	main
on	doc_213943985049_item	2294526	et	4	main
teistele	doc_213943985049_item	2294529	et	4	main
valisin	doc_213943985050_item	2294534	et	3	main
ülikoolis	doc_213943985050_item	2294541	et	4	main
aga	doc_213943985050_item	2294547	et	3	main
mulle	doc_213943985050_item	2294548	et	4	main
tundub	doc_213943985050_item	2294549	et	3	main
kasulik	doc_213943985050_item	2294557	et	3	main
koolides	doc_213943985050_item	2294562	et	3	main
see	doc_213943985050_item	2294583	et	3	main
teaksin	doc_213943985050_item	2294590	et	3	main
mitte	doc_213943985050_item	2294592	et	3	main
keel	doc_213943985050_item	2294597	et	4	main
ka	doc_213943985050_item	2294601	et	3	main
on	doc_213943985050_item	2294614	et	4	main
suhelda	doc_213943985050_item	2294616	et	4	main
inimestega	doc_213943985050_item	2294618	et	3	main
ja	doc_213943985050_item	2294622	et	3	main
huvitanud	doc_213943985050_item	2294627	et	4	main
2	doc_213943985050_item	2294630	et	2	main
see	doc_213943985050_item	2294631	et	3	main
küsimus	doc_213943985050_item	2294632	et	4	main
raske	doc_213943985050_item	2294634	et	4	main
et	doc_213943985050_item	2294647	et	3	main
ja	doc_213943985050_item	2294652	et	3	main
ma	doc_213943985050_item	2294660	et	3	main
ole	doc_213943985050_item	2294662	et	4	main
tundub	doc_213943985050_item	2294667	et	3	main
inimesed	doc_213943985050_item	2294670	et	3	main
inimesest	doc_213943985050_item	2294677	et	3	main
mõtlen	doc_213943985050_item	2294679	et	3	main
iga	doc_213943985050_item	2294681	et	4	main
eriala	doc_213943985050_item	2294685	et	4	main
ta	doc_213943985050_item	2294687	et	4	main
on	doc_213943985050_item	2294688	et	4	main
saada	doc_213943985050_item	2294695	et	4	main
hea	doc_213943985050_item	2294696	et	4	main
spetsialistiks	doc_213943985050_item	2294697	et	3	main
ma	doc_213943985050_item	2294698	et	3	main
loodan	doc_213943985050_item	2294699	et	3	main
teen	doc_213943985051_item	2294724	et	3	main
teada	doc_213943985051_item	2294734	et	3	main
inimene	doc_213943985051_item	2294736	et	3	main
elada	doc_213943985051_item	2294738	et	3	main
ta	doc_213943985051_item	2294746	et	4	main
osta	doc_213943985051_item	2294748	et	4	main
lihtsalt	doc_213943985051_item	2294750	et	4	main
lugeda	doc_213943985051_item	2294766	et	3	main
on	doc_213943985051_item	2294771	et	4	main
muidugi	doc_213943985051_item	2294776	et	4	main
see	doc_213943985051_item	2294777	et	3	main
eriala	doc_213943985051_item	2294778	et	4	main
võib	doc_213943985051_item	2294779	et	3	main
suhelda	doc_213943985051_item	2294786	et	4	main
eestlased	doc_213943985051_item	2294793	et	3	main
sest	doc_213943985052_item	2294822	et	4	main
vajalik	doc_213943985052_item	2294826	et	3	main
see	doc_213943985052_item	2294829	et	3	main
kogu	doc_213943985052_item	2294831	et	4	main
oleks	doc_213943985052_item	2294836	et	3	main
valdada	doc_213943985052_item	2294839	et	4	main
tõlkijaks	doc_213943985052_item	2294846	et	4	main
huvitav	doc_213943985052_item	2294852	et	4	main
eriala	doc_213943985052_item	2294857	et	4	main
veel	doc_213943985052_item	2294863	et	4	main
tunne	doc_213943985052_item	2294866	et	4	main
tulevikku	doc_213943985052_item	2294872	et	4	main
erinevate	doc_213943985050_item	2294617	et	4	main
õppida	doc_213943985050_item	2294619	et	3	main
sest	doc_213943985050_item	2294637	et	4	main
ei	doc_213943985050_item	2294639	et	4	main
tundub	doc_213943985050_item	2294646	et	3	main
ülikoolis	doc_213943985050_item	2294649	et	4	main
kasulik	doc_213943985050_item	2294651	et	3	main
ja	doc_213943985050_item	2294658	et	3	main
aga	doc_213943985050_item	2294665	et	3	main
et	doc_213943985050_item	2294668	et	3	main
palju	doc_213943985050_item	2294675	et	4	main
sõltub	doc_213943985050_item	2294676	et	3	main
peab	doc_213943985050_item	2294683	et	4	main
millega	doc_213943985050_item	2294686	et	3	main
ma	doc_213943985050_item	2294701	et	3	main
tegin	doc_213943985050_item	2294702	et	3	main
õige	doc_213943985050_item	2294703	et	4	main
valik	doc_213943985050_item	2294704	et	3	main
essee	doc_213943985051_item	2294705	et	4	main
miks	doc_213943985051_item	2294706	et	4	main
ma	doc_213943985051_item	2294707	et	3	main
valisin	doc_213943985051_item	2294708	et	3	main
seda	doc_213943985051_item	2294709	et	3	main
eriala	doc_213943985051_item	2294710	et	4	main
tahaksin	doc_213943985051_item	2294711	et	3	main
parandada	doc_213943985051_item	2294712	et	3	main
oma	doc_213943985051_item	2294713	et	4	main
eesti	doc_213943985051_item	2294714	et	4	main
keele	doc_213943985051_item	2294715	et	4	main
oskusi	doc_213943985051_item	2294716	et	3	main
sest	doc_213943985051_item	2294717	et	4	main
märkasin	doc_213943985051_item	2294718	et	3	main
viimati	doc_213943985051_item	2294719	et	3	main
et	doc_213943985051_item	2294720	et	3	main
seda	doc_213943985051_item	2294722	et	3	main
palju	doc_213943985051_item	2294725	et	4	main
kui	doc_213943985051_item	2294731	et	3	main
mida	doc_213943985051_item	2294745	et	4	main
või	doc_213943985051_item	2294749	et	4	main
õppimises	doc_213943985051_item	2294762	et	4	main
sest	doc_213943985051_item	2294763	et	4	main
keeles	doc_213943985051_item	2294768	et	4	main
aidama	doc_213943985051_item	2294780	et	4	main
mind	doc_213943985051_item	2294781	et	4	main
palju	doc_213943985051_item	2294790	et	4	main
see	doc_213943985052_item	2294823	et	3	main
on	doc_213943985052_item	2294824	et	4	main
keel	doc_213943985052_item	2294827	et	4	main
ma	doc_213943985052_item	2294835	et	3	main
vabalt	doc_213943985052_item	2294838	et	4	main
kaasaegne	doc_213943985052_item	2294849	et	3	main
huvi	doc_213943985052_item	2294864	et	4	main
ei	doc_213943985052_item	2294865	et	4	main
selles	doc_213943985052_item	2294867	et	4	main
erialas	doc_213943985052_item	2294868	et	3	main
ma	doc_213943985052_item	2294869	et	3	main
näen	doc_213943985052_item	2294870	et	3	main
oma	doc_213943985052_item	2294871	et	4	main
teadmised	doc_213943985050_item	2294657	et	4	main
veendunud	doc_213943985050_item	2294664	et	4	main
soovivad	doc_213943985050_item	2294671	et	4	main
ma	doc_213943985050_item	2294678	et	3	main
inimene	doc_213943985050_item	2294682	et	3	main
et	doc_213943985050_item	2294700	et	3	main
nii	doc_213943985051_item	2294732	et	3	main
õppida	doc_213943985051_item	2294740	et	3	main
vähemalt	doc_213943985051_item	2294742	et	4	main
see	doc_213943985051_item	2294756	et	3	main
aidata	doc_213943985051_item	2294758	et	4	main
tuleb	doc_213943985051_item	2294764	et	3	main
ning	doc_213943985051_item	2294769	et	3	main
keeles	doc_213943985051_item	2294774	et	4	main
arenema	doc_213943985051_item	2294782	et	3	main
et	doc_213943985051_item	2294785	et	3	main
sest	doc_213943985051_item	2294789	et	4	main
miks	doc_213943985052_item	2294795	et	4	main
valisin	doc_213943985052_item	2294797	et	3	main
selle	doc_213943985052_item	2294798	et	4	main
eriala	doc_213943985052_item	2294799	et	4	main
ma	doc_213943985052_item	2294800	et	3	main
valisin	doc_213943985052_item	2294801	et	3	main
inglise	doc_213943985052_item	2294802	et	4	main
keele	doc_213943985052_item	2294803	et	4	main
filoloogiat	doc_213943985052_item	2294804	et	3	main
sest	doc_213943985052_item	2294805	et	4	main
et	doc_213943985052_item	2294806	et	3	main
inglise	doc_213943985052_item	2294807	et	4	main
keel	doc_213943985052_item	2294808	et	4	main
oli	doc_213943985052_item	2294809	et	3	main
alati	doc_213943985052_item	2294810	et	4	main
minu	doc_213943985052_item	2294811	et	3	main
lemmik	doc_213943985052_item	2294812	et	3	main
tund	doc_213943985052_item	2294813	et	3	main
koolis	doc_213943985052_item	2294814	et	4	main
ma	doc_213943985052_item	2294815	et	3	main
väga	doc_213943985052_item	2294816	et	3	main
tahtsin	doc_213943985052_item	2294817	et	3	main
veel	doc_213943985052_item	2294818	et	4	main
inglise	doc_213943985052_item	2294819	et	4	main
keelt	doc_213943985052_item	2294820	et	4	main
keeles	doc_213943985051_item	2294723	et	4	main
vigu	doc_213943985051_item	2294726	et	3	main
eesti	doc_213943985051_item	2294727	et	4	main
keel	doc_213943985051_item	2294728	et	4	main
on	doc_213943985051_item	2294729	et	4	main
nii	doc_213943985051_item	2294730	et	3	main
tahab	doc_213943985051_item	2294737	et	3	main
ja	doc_213943985051_item	2294739	et	3	main
eestis	doc_213943985051_item	2294741	et	3	main
konsulteerida	doc_213943985051_item	2294751	et	3	main
on	doc_213943985051_item	2294752	et	4	main
alati	doc_213943985051_item	2294753	et	4	main
vajalik	doc_213943985051_item	2294754	et	3	main
samuti	doc_213943985051_item	2294755	et	3	main
võib	doc_213943985051_item	2294757	et	3	main
mind	doc_213943985051_item	2294759	et	4	main
oma	doc_213943985051_item	2294760	et	4	main
tulevikus	doc_213943985051_item	2294761	et	4	main
palju	doc_213943985051_item	2294765	et	4	main
õppematerjalid	doc_213943985051_item	2294770	et	3	main
selles	doc_213943985051_item	2294773	et	4	main
ja	doc_213943985051_item	2294775	et	3	main
oskusi	doc_213943985051_item	2294784	et	3	main
kaaskursustega	doc_213943985051_item	2294788	et	3	main
neist	doc_213943985051_item	2294791	et	4	main
on	doc_213943985051_item	2294792	et	4	main
õppida	doc_213943985052_item	2294821	et	3	main
keel	doc_213943985052_item	2294833	et	4	main
et	doc_213943985052_item	2294843	et	3	main
saada	doc_213943985052_item	2294845	et	4	main
väga	doc_213943985052_item	2294851	et	3	main
et	doc_213943985052_item	2294860	et	3	main
väga	doc_213943985052_item	2294825	et	3	main
maailma	doc_213943985052_item	2294832	et	4	main
õnnelik	doc_213943985052_item	2294837	et	3	main
inglise	doc_213943985052_item	2294840	et	4	main
keelt	doc_213943985052_item	2294841	et	4	main
arvan	doc_213943985052_item	2294842	et	3	main
võin	doc_213943985052_item	2294844	et	3	main
on	doc_213943985052_item	2294848	et	4	main
ja	doc_213943985052_item	2294850	et	3	main
ma	doc_213943985052_item	2294861	et	3	main
lapsena	doc_213943985057_item	2295427	et	3	main
ma	doc_213943985057_item	2295428	et	3	main
saada	doc_213943985057_item	2295430	et	4	main
ma	doc_213943985057_item	2295434	et	3	main
gümnaasiumisse	doc_213943985057_item	2295436	et	3	main
leidma	doc_213943985057_item	2295445	et	3	main
palju	doc_213943985057_item	2295447	et	4	main
infot	doc_213943985057_item	2295448	et	3	main
harjutus	doc_213943985057_item	2295418	et	4	main
tee	doc_213943985057_item	2295419	et	4	main
pärast	doc_213943985057_item	2295433	et	4	main
eelmisel	doc_213943985057_item	2295437	et	3	main
sõtsin	doc_213943985057_item	2295440	et	4	main
ülikooli	doc_213943985057_item	2295442	et	4	main
kabinetis	doc_213943985057_item	2295453	et	3	main
leidsin	doc_213943985057_item	2295456	et	3	main
erialast	doc_213943985057_item	2295458	et	4	main
tallinna	doc_213943985057_item	2295459	et	4	main
ajakirjandus	doc_213943985057_item	2295463	et	3	main
inimesega	doc_213943985057_item	2295472	et	3	main
õppida	doc_213943985057_item	2295509	et	3	main
ülikoolis	doc_213943985057_item	2295511	et	4	main
tean	doc_213943985057_item	2295516	et	3	main
kohad	doc_213943985057_item	2295525	et	4	main
kirjalik	doc_213943985059_item	2295658	et	3	main
oma	doc_213943985059_item	2295660	et	4	main
eriala	doc_213943985059_item	2295661	et	4	main
valiku	doc_213943985059_item	2295662	et	3	main
ajakirjanduse	doc_213943985059_item	2295676	et	3	main
korrektorina	doc_213943985059_item	2295702	et	3	main
ma	doc_213943985060_item	2295711	et	3	main
erialad	doc_213943985060_item	2295720	et	3	main
suhete	doc_213943985060_item	2295731	et	3	main
populaarsed	doc_213943985060_item	2295740	et	3	main
et	doc_213943985060_item	2295742	et	3	main
aktuaalsed	doc_213943985060_item	2295745	et	3	main
tee	doc_213943985061_item	2295752	et	4	main
kirjalik	doc_213943985061_item	2295753	et	3	main
kokkuvõte	doc_213943985061_item	2295754	et	3	main
oma	doc_213943985061_item	2295755	et	4	main
algas	doc_213943985061_item	2295759	et	3	main
mina	doc_213943985061_item	2295762	et	4	main
õpin	doc_213943985061_item	2295764	et	3	main
kuhu	doc_213943985061_item	2295773	et	3	main
mina	doc_213943985061_item	2295783	et	4	main
kirjalik	doc_213943985057_item	2295420	et	3	main
kokkuvõte	doc_213943985057_item	2295421	et	3	main
tahtsin	doc_213943985057_item	2295429	et	3	main
selle	doc_213943985057_item	2295432	et	4	main
aastal	doc_213943985057_item	2295438	et	3	main
tallinna	doc_213943985057_item	2295441	et	4	main
maksimaalne	doc_213943985057_item	2295446	et	3	main
ma	doc_213943985057_item	2295449	et	3	main
ülikooli	doc_213943985057_item	2295460	et	4	main
alati	doc_213943985057_item	2295464	et	4	main
minule	doc_213943985057_item	2295466	et	3	main
kõigepealt	doc_213943985057_item	2295467	et	3	main
see	doc_213943985057_item	2295468	et	3	main
on	doc_213943985057_item	2295469	et	4	main
töö	doc_213943985057_item	2295471	et	4	main
saan	doc_213943985057_item	2295508	et	4	main
tallinna	doc_213943985057_item	2295510	et	4	main
juba	doc_213943985057_item	2295515	et	3	main
ja	doc_213943985057_item	2295528	et	3	main
kirjanikuna	doc_213943985059_item	2295703	et	3	main
harjutus	doc_213943985060_item	2295705	et	4	main
tee	doc_213943985060_item	2295706	et	4	main
tabelit	doc_213943985060_item	2295707	et	3	main
kasutades	doc_213943985060_item	2295708	et	3	main
kõige	doc_213943985060_item	2295718	et	4	main
psühholog	doc_213943985060_item	2295726	et	4	main
agent	doc_213943985060_item	2295728	et	3	main
ma	doc_213943985060_item	2295733	et	3	main
arvan	doc_213943985060_item	2295734	et	3	main
et	doc_213943985060_item	2295735	et	3	main
moodsad	doc_213943985060_item	2295746	et	3	main
toovad	doc_213943985060_item	2295748	et	4	main
valiku	doc_213943985061_item	2295757	et	3	main
ning	doc_213943985061_item	2295761	et	3	main
tallinna	doc_213943985061_item	2295765	et	4	main
ajakirjaniku	doc_213943985061_item	2295767	et	3	main
erialal	doc_213943985061_item	2295768	et	3	main
mina	doc_213943985061_item	2295769	et	4	main
mul	doc_213943985061_item	2295777	et	3	main
plaan	doc_213943985061_item	2295781	et	3	main
eriala	doc_213943985057_item	2295423	et	4	main
kohta	doc_213943985057_item	2295425	et	4	main
veel	doc_213943985057_item	2295426	et	4	main
astusin	doc_213943985057_item	2295435	et	3	main
ma	doc_213943985057_item	2295439	et	3	main
üritasin	doc_213943985057_item	2295444	et	3	main
koduleheküljal	doc_213943985057_item	2295461	et	4	main
meeldis	doc_213943985057_item	2295465	et	3	main
eriala	doc_213943985057_item	2295475	et	4	main
ma	doc_213943985057_item	2295514	et	3	main
on	doc_213943985057_item	2295518	et	4	main
töökohad	doc_213943985057_item	2295519	et	4	main
kus	doc_213943985057_item	2295520	et	3	main
ma	doc_213943985057_item	2295521	et	3	main
kohta	doc_213943985059_item	2295663	et	4	main
antud	doc_213943985059_item	2295664	et	4	main
eriala	doc_213943985059_item	2295677	et	4	main
mulle	doc_213943985059_item	2295679	et	4	main
tahaksin	doc_213943985060_item	2295712	et	3	main
aastal	doc_213943985060_item	2295716	et	3	main
niisugused	doc_213943985060_item	2295722	et	3	main
reklaami	doc_213943985060_item	2295727	et	4	main
rahvusvaheliste	doc_213943985060_item	2295730	et	4	main
eriala	doc_213943985060_item	2295732	et	4	main
need	doc_213943985060_item	2295736	et	3	main
on	doc_213943985060_item	2295738	et	4	main
need	doc_213943985060_item	2295743	et	3	main
ja	doc_213943985060_item	2295747	et	3	main
raha	doc_213943985060_item	2295750	et	4	main
harjutus	doc_213943985061_item	2295751	et	4	main
september	doc_213943985061_item	2295760	et	3	main
mõtlesin	doc_213943985061_item	2295770	et	3	main
mitu	doc_213943985061_item	2295771	et	4	main
minna	doc_213943985061_item	2295776	et	3	main
oleks	doc_213943985061_item	2295778	et	3	main
terve	doc_213943985061_item	2295780	et	4	main
et	doc_213943985061_item	2295782	et	3	main
õpin	doc_213943985061_item	2295786	et	3	main
erialal	doc_213943985061_item	2295788	et	3	main
läheb	doc_213943985061_item	2295790	et	3	main
ja	doc_213943985061_item	2295794	et	3	main
gümnaasiumi	doc_213943985061_item	2295795	et	4	main
mina	doc_213943985061_item	2295797	et	4	main
muutaksin	doc_213943985061_item	2295798	et	4	main
otsustasin	doc_213943985061_item	2295802	et	3	main
jätkata	doc_213943985061_item	2295806	et	4	main
selgus	doc_213943985061_item	2295825	et	4	main
oli	doc_213943985061_item	2295828	et	3	main
õppetasid	doc_213943985061_item	2295832	et	4	main
sain	doc_213943985061_item	2295840	et	3	main
viis	doc_213943985061_item	2295842	et	4	main
pall	doc_213943985061_item	2295845	et	3	main
klassis	doc_213943985061_item	2295847	et	3	main
dokumendid	doc_213943985061_item	2295855	et	3	main
ajakirjaniku	doc_213943985061_item	2295858	et	3	main
selle	doc_213943985061_item	2295861	et	4	main
mina	doc_213943985061_item	2295864	et	4	main
oma	doc_213943985057_item	2295422	et	4	main
valiku	doc_213943985057_item	2295424	et	3	main
ajakirjanikuks	doc_213943985057_item	2295431	et	3	main
ja	doc_213943985057_item	2295443	et	3	main
konsulteerisin	doc_213943985057_item	2295450	et	3	main
vastuvõtt	doc_213943985057_item	2295452	et	3	main
pärast	doc_213943985057_item	2295454	et	4	main
infot	doc_213943985057_item	2295457	et	3	main
interneetis	doc_213943985057_item	2295462	et	4	main
seda	doc_213943985057_item	2295474	et	3	main
minu	doc_213943985057_item	2295477	et	3	main
siht	doc_213943985057_item	2295479	et	3	main
silme	doc_213943985057_item	2295480	et	4	main
eest	doc_213943985057_item	2295481	et	4	main
tausttegur	doc_213943985057_item	2295482	et	3	main
mis	doc_213943985057_item	2295483	et	4	main
mõjutab	doc_213943985057_item	2295484	et	3	main
minu	doc_213943985057_item	2295485	et	3	main
valikul	doc_213943985057_item	2295486	et	3	main
on	doc_213943985057_item	2295487	et	4	main
minu	doc_213943985057_item	2295488	et	3	main
venna	doc_213943985057_item	2295489	et	3	main
valik	doc_213943985057_item	2295490	et	3	main
ta	doc_213943985057_item	2295491	et	4	main
on	doc_213943985057_item	2295492	et	4	main
ajakirjanik	doc_213943985057_item	2295493	et	3	main
ma	doc_213943985057_item	2295494	et	3	main
lootan	doc_213943985057_item	2295495	et	4	main
et	doc_213943985057_item	2295496	et	3	main
mul	doc_213943985057_item	2295497	et	3	main
on	doc_213943985057_item	2295498	et	4	main
ka	doc_213943985057_item	2295499	et	3	main
piisavalt	doc_213943985057_item	2295500	et	4	main
jõudu	doc_213943985057_item	2295501	et	4	main
ajakirjaniku	doc_213943985057_item	2295502	et	3	main
kujumise	doc_213943985057_item	2295503	et	4	main
jaoks	doc_213943985057_item	2295504	et	4	main
seda	doc_213943985057_item	2295505	et	3	main
eriala	doc_213943985057_item	2295506	et	4	main
ma	doc_213943985057_item	2295507	et	3	main
sekretääriga	doc_213943985057_item	2295451	et	4	main
ma	doc_213943985057_item	2295455	et	3	main
huvitav	doc_213943985057_item	2295470	et	4	main
suhtlemine	doc_213943985057_item	2295473	et	4	main
on	doc_213943985057_item	2295476	et	4	main
selge	doc_213943985057_item	2295478	et	4	main
filoloogia	doc_213943985057_item	2295512	et	4	main
töötada	doc_213943985057_item	2295523	et	3	main
raadio-	doc_213943985057_item	2295527	et	4	main
osakonnas	doc_213943985057_item	2295513	et	4	main
millised	doc_213943985057_item	2295517	et	3	main
sooviksin	doc_213943985057_item	2295522	et	3	main
need	doc_213943985057_item	2295524	et	3	main
on	doc_213943985057_item	2295526	et	4	main
telekommunikatsioonid	doc_213943985057_item	2295529	et	3	main
tee	doc_213943985059_item	2295657	et	4	main
kokkuvõte	doc_213943985059_item	2295659	et	3	main
ma	doc_213943985059_item	2295674	et	3	main
valisin	doc_213943985059_item	2295675	et	3	main
pressiesindajana	doc_213943985059_item	2295704	et	3	main
kokkuvõtteks	doc_213943985060_item	2295710	et	3	main
öelda	doc_213943985060_item	2295713	et	4	main
sellel	doc_213943985060_item	2295715	et	4	main
harjutus	doc_213943985059_item	2295656	et	4	main
eriala	doc_213943985059_item	2295665	et	4	main
kohta	doc_213943985059_item	2295666	et	4	main
sain	doc_213943985059_item	2295667	et	3	main
infot	doc_213943985059_item	2295668	et	3	main
internetist	doc_213943985059_item	2295669	et	4	main
ajalehtedest	doc_213943985059_item	2295670	et	4	main
ülikoolist	doc_213943985059_item	2295671	et	4	main
sõpradelt	doc_213943985059_item	2295672	et	3	main
tuttavatelt	doc_213943985059_item	2295673	et	3	main
sest	doc_213943985059_item	2295678	et	4	main
meeldib	doc_213943985059_item	2295680	et	3	main
kirjutada	doc_213943985059_item	2295681	et	3	main
ajakirjandus	doc_213943985059_item	2295682	et	3	main
on	doc_213943985059_item	2295683	et	4	main
väga	doc_213943985059_item	2295684	et	3	main
moodne	doc_213943985059_item	2295685	et	3	main
populaarne	doc_213943985059_item	2295686	et	3	main
huvitav	doc_213943985059_item	2295687	et	4	main
vaheldusrikkas	doc_213943985059_item	2295689	et	4	main
ajakirjanikuks	doc_213943985059_item	2295690	et	3	main
saab	doc_213943985059_item	2295691	et	3	main
õppida	doc_213943985059_item	2295692	et	3	main
tallinna	doc_213943985059_item	2295693	et	4	main
ülikoolis	doc_213943985059_item	2295694	et	4	main
põnev	doc_213943985059_item	2295688	et	3	main
ja	doc_213943985059_item	2295695	et	3	main
tartu	doc_213943985059_item	2295696	et	4	main
ülikoolis	doc_213943985059_item	2295697	et	4	main
ajakirjanikud	doc_213943985059_item	2295698	et	3	main
saavad	doc_213943985059_item	2295699	et	4	main
töötada	doc_213943985059_item	2295700	et	3	main
toimetajana	doc_213943985059_item	2295701	et	4	main
kokkuvõte	doc_213943985060_item	2295709	et	3	main
et	doc_213943985060_item	2295714	et	3	main
on	doc_213943985060_item	2295717	et	4	main
populaarsed	doc_213943985060_item	2295719	et	3	main
on	doc_213943985060_item	2295721	et	4	main
infotehnoolog	doc_213943985060_item	2295723	et	4	main
ehitaja	doc_213943985060_item	2295724	et	4	main
ärijuhataja	doc_213943985060_item	2295725	et	4	main
erialad	doc_213943985060_item	2295737	et	3	main
nii	doc_213943985060_item	2295739	et	3	main
sellepärast	doc_213943985060_item	2295741	et	3	main
on	doc_213943985060_item	2295744	et	4	main
kohta	doc_213943985061_item	2295758	et	4	main
õppima	doc_213943985061_item	2295775	et	3	main
juba	doc_213943985061_item	2295779	et	3	main
aeg	doc_213943985061_item	2295791	et	3	main
et	doc_213943985061_item	2295801	et	3	main
ning	doc_213943985061_item	2295805	et	3	main
õpingut	doc_213943985061_item	2295807	et	3	main
oma	doc_213943985061_item	2295822	et	4	main
kirjandid	doc_213943985061_item	2295823	et	3	main
ta	doc_213943985061_item	2295831	et	4	main
kaheksakümmend	doc_213943985061_item	2295841	et	4	main
filoloogia	doc_213943985061_item	2295856	et	4	main
erialal	doc_213943985061_item	2295859	et	3	main
hakkasin	doc_213943985061_item	2295865	et	3	main
ainult	doc_213943985061_item	2295867	et	4	main
septembris	doc_213943985061_item	2295868	et	3	main
kui	doc_213943985061_item	2295869	et	3	main
kui	doc_213943985061_item	2295872	et	3	main
seda	doc_213943985061_item	2295879	et	3	main
võib	doc_213943985061_item	2295886	et	3	main
minu	doc_213943985061_item	2295890	et	3	main
soovitus	doc_213943985061_item	2295897	et	4	main
kohta	doc_213943985062_item	2295930	et	4	main
internetist	doc_213943985062_item	2295936	et	4	main
ma	doc_213943985062_item	2295939	et	3	main
selle	doc_213943985062_item	2295941	et	4	main
ajakirjandus	doc_213943985062_item	2295947	et	3	main
meeldib	doc_213943985062_item	2295949	et	3	main
veel	doc_213943985062_item	2295958	et	4	main
on	doc_213943985062_item	2295959	et	4	main
hea	doc_213943985062_item	2295960	et	4	main
keeled	doc_213943985062_item	2295964	et	3	main
töötasid	doc_213943985062_item	2295975	et	4	main
ta	doc_213943985063_item	2296014	et	4	main
räägis	doc_213943985063_item	2296015	et	3	main
infot	doc_213943985063_item	2296024	et	3	main
ja	doc_213943985063_item	2296026	et	3	main
sellest	doc_213943985063_item	2296028	et	4	main
fakte	doc_213943985063_item	2296031	et	3	main
valisin	doc_213943985063_item	2296034	et	3	main
vaadata	doc_213943985063_item	2296042	et	4	main
lugesin	doc_213943985063_item	2296043	et	3	main
palju	doc_213943985063_item	2296044	et	4	main
raamatuid	doc_213943985063_item	2296045	et	3	main
koolis	doc_213943985063_item	2296046	et	4	main
meil	doc_213943985063_item	2296047	et	4	main
oli	doc_213943985063_item	2296048	et	3	main
oma	doc_213943985063_item	2296049	et	4	main
vaike	doc_213943985063_item	2296050	et	3	main
kuhu	doc_213943985063_item	2296052	et	3	main
väga	doc_213943985063_item	2296054	et	3	main
jaoks	doc_213943985063_item	2296065	et	4	main
eestis	doc_213943985063_item	2296068	et	3	main
sellepärast	doc_213943985063_item	2296083	et	3	main
eestikeelne	doc_213943985063_item	2296087	et	3	main
ja	doc_213943985063_item	2296089	et	3	main
jaoks	doc_213943985063_item	2296091	et	4	main
raske	doc_213943985063_item	2296095	et	4	main
keeles	doc_213943985063_item	2296098	et	4	main
lahe	doc_213943985063_item	2296104	et	4	main
et	doc_213943985063_item	2296113	et	3	main
ei	doc_213943985063_item	2296115	et	4	main
ja	doc_213943985060_item	2295729	et	3	main
palju	doc_213943985060_item	2295749	et	4	main
eriala	doc_213943985061_item	2295756	et	4	main
juba	doc_213943985061_item	2295763	et	3	main
ülikoolis	doc_213943985061_item	2295766	et	4	main
aastat	doc_213943985061_item	2295772	et	3	main
tahaksin	doc_213943985061_item	2295774	et	3	main
palju	doc_213943985061_item	2295800	et	4	main
eestis	doc_213943985061_item	2295803	et	3	main
saada	doc_213943985061_item	2295808	et	4	main
siin	doc_213943985061_item	2295809	et	4	main
minule	doc_213943985061_item	2295810	et	3	main
alati	doc_213943985061_item	2295811	et	4	main
meeldis	doc_213943985061_item	2295812	et	3	main
kui	doc_213943985061_item	2295813	et	3	main
minu	doc_213943985061_item	2295814	et	3	main
ajakirjanduse	doc_213943985061_item	2295815	et	3	main
õpetaja	doc_213943985061_item	2295816	et	4	main
räägis	doc_213943985061_item	2295817	et	3	main
kirjutas	doc_213943985061_item	2295818	et	3	main
ja	doc_213943985061_item	2295819	et	3	main
aitas	doc_213943985061_item	2295820	et	3	main
et	doc_213943985061_item	2295826	et	3	main
ajakirjanikuks	doc_213943985061_item	2295829	et	3	main
niimoodi	doc_213943985061_item	2295833	et	3	main
et	doc_213943985061_item	2295835	et	3	main
kirjutasin	doc_213943985061_item	2295837	et	3	main
lõppukirjandit	doc_213943985061_item	2295838	et	4	main
ja	doc_213943985061_item	2295839	et	3	main
minu	doc_213943985061_item	2295846	et	3	main
arvates	doc_213943985061_item	2295849	et	4	main
ning	doc_213943985061_item	2295851	et	3	main
mind	doc_213943985061_item	2295853	et	4	main
fakulteetis	doc_213943985061_item	2295857	et	4	main
eriala	doc_213943985061_item	2295862	et	4	main
mina	doc_213943985061_item	2295874	et	4	main
saan	doc_213943985061_item	2295878	et	4	main
rääkida	doc_213943985061_item	2295887	et	3	main
inimene	doc_213943985061_item	2295894	et	3	main
on	doc_213943985061_item	2295896	et	4	main
eriti	doc_213943985061_item	2295898	et	3	main
tee	doc_213943985062_item	2295924	et	4	main
kokkuvõte	doc_213943985062_item	2295926	et	3	main
oma	doc_213943985062_item	2295927	et	4	main
eriala	doc_213943985062_item	2295928	et	4	main
leheküljest	doc_213943985062_item	2295937	et	4	main
meeldib	doc_213943985062_item	2295946	et	3	main
mulle	doc_213943985062_item	2295948	et	4	main
midagi	doc_213943985062_item	2295954	et	4	main
õppima	doc_213943985062_item	2295962	et	3	main
tallinna	doc_213943985062_item	2295965	et	4	main
minu	doc_213943985062_item	2295970	et	3	main
isa	doc_213943985062_item	2295977	et	4	main
ka	doc_213943985062_item	2295980	et	3	main
palju	doc_213943985063_item	2296017	et	4	main
asju	doc_213943985063_item	2296019	et	3	main
sõidan	doc_213943985061_item	2295784	et	3	main
peterburis	doc_213943985061_item	2295789	et	4	main
muutuvad	doc_213943985061_item	2295792	et	4	main
lõpuks	doc_213943985061_item	2295796	et	4	main
jääda	doc_213943985061_item	2295804	et	4	main
meid	doc_213943985061_item	2295821	et	4	main
kirjutada	doc_213943985061_item	2295824	et	3	main
ta	doc_213943985061_item	2295827	et	4	main
mina	doc_213943985061_item	2295836	et	4	main
palli	doc_213943985061_item	2295843	et	4	main
вдохновило	doc_213943985061_item	2295852	et	2	main
anda	doc_213943985061_item	2295854	et	3	main
erialast	doc_213943985061_item	2295876	et	4	main
mulle	doc_213943985061_item	2295881	et	4	main
meeldib	doc_213943985061_item	2295882	et	3	main
siin	doc_213943985061_item	2295883	et	4	main
õppida	doc_213943985061_item	2295884	et	3	main
mida	doc_213943985061_item	2295885	et	4	main
töökohade	doc_213943985061_item	2295888	et	3	main
arvamust	doc_213943985061_item	2295891	et	3	main
ja	doc_213943985061_item	2295785	et	3	main
psühholoogia	doc_213943985061_item	2295787	et	4	main
soovitused	doc_213943985061_item	2295793	et	4	main
nii	doc_213943985061_item	2295799	et	3	main
mind	doc_213943985061_item	2295830	et	4	main
välja	doc_213943985061_item	2295834	et	4	main
kõrgem	doc_213943985061_item	2295844	et	4	main
minu	doc_213943985061_item	2295848	et	3	main
see	doc_213943985061_item	2295850	et	3	main
infot	doc_213943985061_item	2295860	et	3	main
kohta	doc_213943985061_item	2295863	et	4	main
õppida	doc_213943985061_item	2295871	et	3	main
ajakirjaniku	doc_213943985061_item	2295875	et	3	main
töökohta	doc_213943985061_item	2295892	et	4	main
kellel	doc_213943985061_item	2295895	et	4	main
kavatsus	doc_213943985061_item	2295899	et	4	main
töötada	doc_213943985061_item	2295900	et	3	main
selle	doc_213943985061_item	2295901	et	4	main
erialal	doc_213943985061_item	2295902	et	3	main
kes	doc_213943985061_item	2295903	et	4	main
õpis	doc_213943985061_item	2295904	et	3	main
välja	doc_213943985061_item	2295905	et	4	main
ja	doc_213943985061_item	2295906	et	3	main
nüüd	doc_213943985061_item	2295907	et	4	main
tahab	doc_213943985061_item	2295908	et	3	main
spetsialistiks	doc_213943985061_item	2295909	et	3	main
kui	doc_213943985061_item	2295911	et	3	main
inimene	doc_213943985061_item	2295912	et	3	main
tahab	doc_213943985061_item	2295913	et	3	main
töötada	doc_213943985061_item	2295914	et	3	main
saada	doc_213943985061_item	2295910	et	4	main
ta	doc_213943985061_item	2295915	et	4	main
leidab	doc_213943985061_item	2295917	et	4	main
alati	doc_213943985061_item	2295916	et	4	main
töökohta	doc_213943985061_item	2295918	et	4	main
see	doc_213943985061_item	2295919	et	3	main
on	doc_213943985061_item	2295920	et	4	main
minu	doc_213943985061_item	2295921	et	3	main
harjutus	doc_213943985062_item	2295923	et	4	main
kirjalik	doc_213943985062_item	2295925	et	3	main
ma	doc_213943985062_item	2295931	et	3	main
kohta	doc_213943985062_item	2295934	et	4	main
valisin	doc_213943985062_item	2295940	et	3	main
sest	doc_213943985062_item	2295943	et	4	main
uue	doc_213943985062_item	2295955	et	3	main
ja	doc_213943985062_item	2295956	et	3	main
teised	doc_213943985062_item	2295963	et	4	main
õpivad	doc_213943985062_item	2295967	et	3	main
töötab	doc_213943985062_item	2295978	et	3	main
paljudes	doc_213943985062_item	2295981	et	3	main
pärast	doc_213943985063_item	2296020	et	4	main
ma	doc_213943985063_item	2296033	et	3	main
seda	doc_213943985063_item	2296035	et	3	main
ajaleht	doc_213943985063_item	2296051	et	3	main
tundub	doc_213943985063_item	2296059	et	3	main
seda	doc_213943985063_item	2296066	et	3	main
ülikoolis	doc_213943985063_item	2296072	et	4	main
tartu	doc_213943985063_item	2296073	et	4	main
ülikoolis	doc_213943985063_item	2296074	et	4	main
ja	doc_213943985063_item	2296075	et	3	main
tallinna	doc_213943985063_item	2296076	et	4	main
miks	doc_213943985063_item	2296078	et	4	main
ma	doc_213943985063_item	2296079	et	3	main
tartus	doc_213943985063_item	2296085	et	3	main
oleks	doc_213943985063_item	2296093	et	3	main
leidma	doc_213943985061_item	2295866	et	3	main
tuli	doc_213943985061_item	2295870	et	4	main
rohkem	doc_213943985061_item	2295873	et	4	main
teada	doc_213943985061_item	2295877	et	3	main
enam	doc_213943985061_item	2295880	et	4	main
kohta	doc_213943985061_item	2295889	et	4	main
leidab	doc_213943985061_item	2295893	et	4	main
eludeviis	doc_213943985061_item	2295922	et	3	main
leidsin	doc_213943985062_item	2295932	et	3	main
infot	doc_213943985062_item	2295935	et	3	main
eriala	doc_213943985062_item	2295942	et	4	main
et	doc_213943985062_item	2295944	et	3	main
erinevastega	doc_213943985062_item	2295951	et	4	main
inimesega	doc_213943985062_item	2295952	et	3	main
huvitav	doc_213943985062_item	2295957	et	4	main
ajakirjandusele	doc_213943985062_item	2295968	et	3	main
aga	doc_213943985062_item	2295976	et	3	main
praegu	doc_213943985062_item	2295979	et	3	main
ajakirjanikuna	doc_213943985063_item	2296013	et	3	main
mulle	doc_213943985063_item	2296016	et	4	main
seda	doc_213943985063_item	2296021	et	3	main
ise	doc_213943985063_item	2296023	et	4	main
erialast	doc_213943985063_item	2296029	et	4	main
eriala	doc_213943985063_item	2296036	et	4	main
koguaeg	doc_213943985063_item	2296037	et	3	main
lapsepõlvest	doc_213943985063_item	2296038	et	4	main
ajakirjandus	doc_213943985063_item	2296061	et	3	main
sobib	doc_213943985063_item	2296063	et	3	main
on	doc_213943985063_item	2296069	et	4	main
ainult	doc_213943985063_item	2296070	et	4	main
kahes	doc_213943985063_item	2296071	et	4	main
ülikoolis	doc_213943985063_item	2296077	et	4	main
et	doc_213943985063_item	2296084	et	3	main
liiga	doc_213943985063_item	2296094	et	4	main
eesti	doc_213943985063_item	2296097	et	4	main
tallinn	doc_213943985063_item	2296099	et	4	main
on	doc_213943985063_item	2296100	et	4	main
pealinn	doc_213943985063_item	2296101	et	3	main
ja	doc_213943985063_item	2296102	et	3	main
ma	doc_213943985063_item	2296107	et	3	main
võivad	doc_213943985063_item	2296121	et	4	main
inimestega	doc_213943985063_item	2296136	et	3	main
sooviks	doc_213943985063_item	2296146	et	4	main
ja	doc_213943985063_item	2296149	et	3	main
suvi	doc_213943985064_item	2296159	et	3	main
kõikidel	doc_213943985064_item	2296161	et	4	main
ja	doc_213943985064_item	2296163	et	3	main
algas	doc_213943985064_item	2296167	et	3	main
olime	doc_213943985064_item	2296177	et	3	main
elasime	doc_213943985064_item	2296180	et	3	main
õpetajadega	doc_213943985064_item	2296187	et	4	main
seal	doc_213943985064_item	2296189	et	4	main
iga	doc_213943985064_item	2296193	et	4	main
veesport	doc_213943985064_item	2296199	et	3	main
maastikumäng	doc_213943985064_item	2296203	et	3	main
valiku	doc_213943985062_item	2295929	et	3	main
eriala	doc_213943985062_item	2295933	et	4	main
tlü	doc_213943985062_item	2295938	et	4	main
mulle	doc_213943985062_item	2295945	et	4	main
suhelda	doc_213943985062_item	2295950	et	4	main
teada	doc_213943985062_item	2295953	et	3	main
võimalus	doc_213943985062_item	2295961	et	3	main
ülikoolis	doc_213943985062_item	2295966	et	4	main
isa	doc_213943985062_item	2295969	et	4	main
abikaasa	doc_213943985062_item	2295971	et	4	main
ja	doc_213943985062_item	2295972	et	3	main
abikaasa	doc_213943985062_item	2295973	et	4	main
ka	doc_213943985062_item	2295974	et	3	main
ajalehedes	doc_213943985062_item	2295982	et	4	main
ja	doc_213943985062_item	2295983	et	3	main
mul	doc_213943985062_item	2295984	et	3	main
on	doc_213943985062_item	2295985	et	4	main
võimalus	doc_213943985062_item	2295986	et	3	main
leida	doc_213943985062_item	2295987	et	3	main
tööl	doc_213943985062_item	2295988	et	3	main
tutvumisele	doc_213943985062_item	2295989	et	4	main
harjutus	doc_213943985063_item	2295990	et	4	main
tee	doc_213943985063_item	2295991	et	4	main
kirjalik	doc_213943985063_item	2295992	et	3	main
kokkuvõte	doc_213943985063_item	2295993	et	3	main
oma	doc_213943985063_item	2295994	et	4	main
eriala	doc_213943985063_item	2295995	et	4	main
valiku	doc_213943985063_item	2295996	et	3	main
kohta	doc_213943985063_item	2295997	et	4	main
esimest	doc_213943985063_item	2295998	et	4	main
korda	doc_213943985063_item	2295999	et	4	main
kuulsin	doc_213943985063_item	2296000	et	3	main
et	doc_213943985063_item	2296001	et	3	main
on	doc_213943985063_item	2296002	et	4	main
selline	doc_213943985063_item	2296003	et	4	main
eriala	doc_213943985063_item	2296004	et	4	main
nagu	doc_213943985063_item	2296005	et	3	main
ajakirjanik	doc_213943985063_item	2296006	et	3	main
oma	doc_213943985063_item	2296007	et	4	main
sõbraannast	doc_213943985063_item	2296008	et	4	main
tema	doc_213943985063_item	2296009	et	4	main
õde	doc_213943985063_item	2296010	et	4	main
töötab	doc_213943985063_item	2296011	et	3	main
moskvas	doc_213943985063_item	2296012	et	4	main
huvitavaid	doc_213943985063_item	2296018	et	4	main
hakkasin	doc_213943985063_item	2296022	et	3	main
leidma	doc_213943985063_item	2296025	et	3	main
leidsisin	doc_213943985063_item	2296027	et	3	main
ma	doc_213943985063_item	2296053	et	3	main
kirjutasin	doc_213943985063_item	2296056	et	3	main
mulle	doc_213943985063_item	2296058	et	4	main
et	doc_213943985063_item	2296060	et	3	main
hästi	doc_213943985063_item	2296062	et	3	main
tü	doc_213943985063_item	2296081	et	4	main
on	doc_213943985063_item	2296086	et	4	main
õppida	doc_213943985063_item	2296096	et	3	main
praegu	doc_213943985063_item	2296106	et	3	main
õpin	doc_213943985063_item	2296109	et	3	main
ja	doc_213943985063_item	2296111	et	3	main
ma	doc_213943985063_item	2296114	et	3	main
töötada	doc_213943985063_item	2296122	et	3	main
tv	doc_213943985063_item	2296123	et	4	main
s	doc_213943985063_item	2296124	et	4	main
ajalehes	doc_213943985063_item	2296125	et	3	main
elu	doc_213943985063_item	2296131	et	4	main
nad	doc_213943985063_item	2296132	et	3	main
koguaeg	doc_213943985063_item	2296133	et	3	main
teiste	doc_213943985063_item	2296135	et	4	main
ajalehes	doc_213943985063_item	2296148	et	3	main
on	doc_213943985063_item	2296153	et	4	main
tudengidel	doc_213943985064_item	2296164	et	4	main
lõpetas	doc_213943985064_item	2296170	et	3	main
koos	doc_213943985064_item	2296173	et	4	main
rühmaga	doc_213943985064_item	2296175	et	3	main
palju	doc_213943985064_item	2296190	et	4	main
meil	doc_213943985064_item	2296195	et	4	main
olid	doc_213943985064_item	2296196	et	4	main
arvestused	doc_213943985064_item	2296197	et	4	main
näiteks	doc_213943985064_item	2296198	et	4	main
ja	doc_213943985064_item	2296202	et	3	main
minu	doc_213943985064_item	2296204	et	3	main
minu	doc_213943985064_item	2296221	et	3	main
oli	doc_213943985064_item	2296228	et	3	main
või	doc_213943985064_item	2296236	et	4	main
on	doc_213943985064_item	2296250	et	4	main
venemal	doc_213943985064_item	2296259	et	4	main
tagasi	doc_213943985064_item	2296264	et	3	main
minu	doc_213943985065_item	2296277	et	3	main
turvafirmas	doc_213943985065_item	2296288	et	3	main
firma	doc_213943985065_item	2296290	et	4	main
otepääl	doc_213943985065_item	2296305	et	4	main
on	doc_213943985065_item	2296307	et	4	main
terve	doc_213943985065_item	2296316	et	4	main
ja	doc_213943985065_item	2296322	et	3	main
aega	doc_213943985065_item	2296324	et	4	main
augustis	doc_213943985065_item	2296339	et	3	main
terve	doc_213943985065_item	2296342	et	4	main
elavad	doc_213943985065_item	2296348	et	4	main
vanaisaga	doc_213943985065_item	2296352	et	3	main
olin	doc_213943985065_item	2296366	et	3	main
võtsime	doc_213943985065_item	2296384	et	3	main
sellel	doc_213943985065_item	2296416	et	4	main
väike	doc_213943985065_item	2296424	et	4	main
ema	doc_213943985065_item	2296426	et	4	main
talle	doc_213943985065_item	2296428	et	4	main
teda	doc_213943985065_item	2296432	et	4	main
eesnimi	doc_213943985065_item	2296435	et	3	main
ja	doc_213943985065_item	2296443	et	3	main
minu	doc_213943985065_item	2296450	et	3	main
koera	doc_213943985065_item	2296451	et	4	main
on	doc_213943985065_item	2296459	et	4	main
kümme	doc_213943985065_item	2296464	et	3	main
vana	doc_213943985065_item	2296466	et	4	main
annab	doc_213943985065_item	2296477	et	3	main
on	doc_213943985065_item	2296493	et	4	main
et	doc_213943985065_item	2296496	et	3	main
aga	doc_213943985066_item	2296530	et	3	main
pidin	doc_213943985066_item	2296531	et	3	main
mõned	doc_213943985066_item	2296533	et	3	main
ja	doc_213943985066_item	2296538	et	3	main
vähem	doc_213943985066_item	2296539	et	4	main
ülemusele	doc_213943985066_item	2296541	et	4	main
mida	doc_213943985066_item	2296543	et	4	main
ma	doc_213943985066_item	2296544	et	3	main
ka	doc_213943985066_item	2296545	et	3	main
tegin	doc_213943985066_item	2296546	et	3	main
palju	doc_213943985063_item	2296030	et	4	main
miks	doc_213943985063_item	2296032	et	4	main
mulle	doc_213943985063_item	2296039	et	4	main
meeldis	doc_213943985063_item	2296040	et	3	main
uudiseid	doc_213943985063_item	2296041	et	3	main
tihti	doc_213943985063_item	2296055	et	3	main
artikleid	doc_213943985063_item	2296057	et	3	main
minu	doc_213943985063_item	2296064	et	3	main
eriala	doc_213943985063_item	2296067	et	4	main
valisin	doc_213943985063_item	2296080	et	3	main
ainult	doc_213943985063_item	2296082	et	4	main
meedia	doc_213943985063_item	2296088	et	4	main
minu	doc_213943985063_item	2296090	et	3	main
see	doc_213943985063_item	2296092	et	3	main
siin	doc_213943985063_item	2296103	et	4	main
juba	doc_213943985063_item	2296108	et	3	main
ole	doc_213943985063_item	2296116	et	4	main
eksinud	doc_213943985063_item	2296117	et	4	main
valikuks	doc_213943985063_item	2296119	et	4	main
oma	doc_213943985063_item	2296118	et	4	main
ajakirjanikud	doc_213943985063_item	2296120	et	3	main
nendel	doc_213943985063_item	2296127	et	4	main
suhtlevad	doc_213943985063_item	2296134	et	4	main
teavad	doc_213943985063_item	2296140	et	3	main
mis	doc_213943985063_item	2296142	et	4	main
toimub	doc_213943985063_item	2296143	et	3	main
riigis	doc_213943985063_item	2296144	et	3	main
ma	doc_213943985063_item	2296145	et	3	main
töötada	doc_213943985063_item	2296147	et	3	main
kirjutada	doc_213943985063_item	2296150	et	3	main
huvitav	doc_213943985063_item	2296155	et	4	main
teema	doc_213943985063_item	2296156	et	4	main
essee	doc_213943985064_item	2296157	et	4	main
minu	doc_213943985064_item	2296158	et	3	main
nagu	doc_213943985064_item	2296160	et	3	main
õpilastel	doc_213943985064_item	2296162	et	4	main
suvi	doc_213943985064_item	2296166	et	3	main
augustil	doc_213943985064_item	2296171	et	3	main
juunil	doc_213943985064_item	2296172	et	3	main
seal	doc_213943985064_item	2296179	et	4	main
nädal	doc_213943985064_item	2296182	et	3	main
oma	doc_213943985064_item	2296184	et	4	main
klassivennadega	doc_213943985064_item	2296185	et	4	main
tegime	doc_213943985064_item	2296188	et	3	main
asju	doc_213943985064_item	2296192	et	3	main
jalgpall	doc_213943985064_item	2296201	et	3	main
oli	doc_213943985064_item	2296208	et	3	main
pärast	doc_213943985064_item	2296210	et	4	main
laager	doc_213943985064_item	2296223	et	3	main
laager	doc_213943985064_item	2296225	et	3	main
laager	doc_213943985064_item	2296227	et	3	main
palju	doc_213943985064_item	2296233	et	4	main
trenni	doc_213943985064_item	2296234	et	4	main
aga	doc_213943985064_item	2296240	et	3	main
mulle	doc_213943985064_item	2296242	et	4	main
juulil	doc_213943985064_item	2296257	et	3	main
käisin	doc_213943985064_item	2296266	et	3	main
essee	doc_213943985065_item	2296274	et	4	main
suvi	doc_213943985065_item	2296278	et	3	main
mul	doc_213943985065_item	2296294	et	3	main
veetma	doc_213943985065_item	2296300	et	3	main
baas	doc_213943985065_item	2296309	et	3	main
tallinna	doc_213943985065_item	2296314	et	4	main
nädalat	doc_213943985065_item	2296318	et	3	main
tulin	doc_213943985065_item	2296328	et	3	main
tallinasse	doc_213943985065_item	2296330	et	4	main
käisin	doc_213943985065_item	2296332	et	3	main
ma	doc_213943985065_item	2296340	et	3	main
perega	doc_213943985065_item	2296343	et	3	main
olime	doc_213943985065_item	2296344	et	3	main
vanaema	doc_213943985065_item	2296350	et	4	main
sest	doc_213943985065_item	2296359	et	4	main
nad	doc_213943985065_item	2296360	et	3	main
saime	doc_213943985065_item	2296364	et	3	main
väga	doc_213943985065_item	2296367	et	3	main
vanaisaga	doc_213943985065_item	2296370	et	3	main
jões	doc_213943985065_item	2296372	et	3	main
elada	doc_213943985063_item	2296105	et	3	main
ajakirjanikuks	doc_213943985063_item	2296110	et	3	main
mõtlen	doc_213943985063_item	2296112	et	3	main
raadiol	doc_213943985063_item	2296126	et	3	main
on	doc_213943985063_item	2296128	et	4	main
huvitav	doc_213943985063_item	2296130	et	4	main
artikleid	doc_213943985063_item	2296138	et	3	main
poliitikast	doc_213943985063_item	2296151	et	4	main
päris	doc_213943985063_item	2296154	et	4	main
juunil	doc_213943985064_item	2296168	et	3	main
oma	doc_213943985064_item	2296174	et	4	main
koos	doc_213943985064_item	2296183	et	4	main
ja	doc_213943985064_item	2296186	et	3	main
päev	doc_213943985064_item	2296194	et	3	main
korvpall	doc_213943985064_item	2296200	et	3	main
jaoks	doc_213943985064_item	2296205	et	4	main
huvitavam	doc_213943985064_item	2296207	et	4	main
taekwondo	doc_213943985064_item	2296224	et	4	main
see	doc_213943985064_item	2296226	et	3	main
pääris	doc_213943985064_item	2296229	et	4	main
see	doc_213943985064_item	2296241	et	3	main
järve	doc_213943985064_item	2296256	et	4	main
ja	doc_213943985064_item	2296261	et	3	main
koju	doc_213943985064_item	2296265	et	3	main
stromkas	doc_213943985064_item	2296267	et	4	main
elan	doc_213943985064_item	2296269	et	3	main
juures	doc_213943985064_item	2296271	et	4	main
suvi	doc_213943985065_item	2296276	et	3	main
algas	doc_213943985065_item	2296279	et	3	main
ma	doc_213943985065_item	2296281	et	3	main
umbes	doc_213943985065_item	2296283	et	4	main
kuu	doc_213943985065_item	2296285	et	4	main
ma	doc_213943985065_item	2296286	et	3	main
töötan	doc_213943985065_item	2296287	et	3	main
täpselt	doc_213943985065_item	2296289	et	4	main
nimi	doc_213943985065_item	2296291	et	3	main
puhke	doc_213943985065_item	2296308	et	4	main
puhkavad	doc_213943985065_item	2296311	et	4	main
suplesin	doc_213943985065_item	2296320	et	3	main
maha	doc_213943985065_item	2296325	et	4	main
hästi	doc_213943985065_item	2296326	et	3	main
trennis	doc_213943985065_item	2296333	et	3	main
tegelen	doc_213943985065_item	2296337	et	3	main
seal	doc_213943985065_item	2296347	et	4	main
minu	doc_213943985065_item	2296349	et	3	main
ei	doc_213943985065_item	2296354	et	4	main
neid	doc_213943985065_item	2296356	et	4	main
koos	doc_213943985065_item	2296369	et	4	main
püüdsime	doc_213943985065_item	2296374	et	3	main
püüdsin	doc_213943985065_item	2296377	et	3	main
haug	doc_213943985065_item	2296379	et	3	main
kust	doc_213943985065_item	2296383	et	4	main
seinad	doc_213943985065_item	2296385	et	3	main
vend	doc_213943985065_item	2296425	et	3	main
andis	doc_213943985065_item	2296427	et	3	main
ja	doc_213943985065_item	2296430	et	3	main
ta	doc_213943985065_item	2296436	et	4	main
aga	doc_213943985065_item	2296440	et	3	main
sööb	doc_213943985065_item	2296442	et	3	main
kogu	doc_213943985065_item	2296445	et	4	main
veel	doc_213943985065_item	2296447	et	4	main
tihti	doc_213943985065_item	2296455	et	3	main
jalutasime	doc_213943985065_item	2296456	et	3	main
koos	doc_213943985065_item	2296457	et	4	main
ta	doc_213943985065_item	2296462	et	4	main
hundikoer	doc_213943985065_item	2296467	et	3	main
kukkun	doc_213943985065_item	2296472	et	4	main
ja	doc_213943985065_item	2296475	et	3	main
mulle	doc_213943985065_item	2296478	et	4	main
võin	doc_213943985065_item	2296480	et	3	main
et	doc_213943985065_item	2296482	et	3	main
suvel	doc_213943985065_item	2296484	et	3	main
kui	doc_213943985065_item	2296489	et	3	main
ja	doc_213943985065_item	2296491	et	3	main
väga	doc_213943985065_item	2296494	et	3	main
essee	doc_213943985066_item	2296499	et	4	main
mu	doc_213943985066_item	2296500	et	3	main
ja	doc_213943985066_item	2296524	et	3	main
lõpetama	doc_213943985066_item	2296532	et	4	main
arendusprojektid	doc_213943985066_item	2296534	et	3	main
oma	doc_213943985066_item	2296540	et	4	main
soov	doc_213943985066_item	2296552	et	3	main
väga	doc_213943985063_item	2296129	et	3	main
kirjutavad	doc_213943985063_item	2296137	et	4	main
reisivad	doc_213943985063_item	2296139	et	4	main
kõik	doc_213943985063_item	2296141	et	4	main
see	doc_213943985063_item	2296152	et	3	main
minu	doc_213943985064_item	2296165	et	3	main
ja	doc_213943985064_item	2296169	et	3	main
me	doc_213943985064_item	2296176	et	4	main
otepääs	doc_213943985064_item	2296178	et	4	main
1	doc_213943985064_item	2296181	et	2	main
huvitavaid	doc_213943985064_item	2296191	et	4	main
kõige	doc_213943985064_item	2296206	et	4	main
maastikumäng	doc_213943985064_item	2296209	et	3	main
seda	doc_213943985064_item	2296211	et	3	main
laagrit	doc_213943985064_item	2296212	et	3	main
sõitsin	doc_213943985064_item	2296214	et	3	main
ma	doc_213943985064_item	2296213	et	3	main
oma	doc_213943985064_item	2296215	et	4	main
treeneriga	doc_213943985064_item	2296216	et	3	main
kurtnasse	doc_213943985064_item	2296217	et	4	main
mul	doc_213943985064_item	2296219	et	3	main
seal	doc_213943985064_item	2296218	et	4	main
oli	doc_213943985064_item	2296220	et	3	main
teine	doc_213943985064_item	2296222	et	3	main
3	doc_213943985064_item	2296235	et	2	main
4	doc_213943985064_item	2296237	et	2	main
korda	doc_213943985064_item	2296238	et	4	main
meeldis	doc_213943985064_item	2296243	et	3	main
palju	doc_213943985064_item	2296255	et	4	main
augustis	doc_213943985064_item	2296262	et	3	main
teda	doc_213943985064_item	2296270	et	4	main
ja	doc_213943985064_item	2296272	et	3	main
puhkasin	doc_213943985064_item	2296273	et	3	main
juunist	doc_213943985065_item	2296280	et	3	main
töötasin	doc_213943985065_item	2296282	et	3	main
kogu	doc_213943985065_item	2296284	et	4	main
xxx	doc_213943985065_item	2296293	et	4	main
oli	doc_213943985065_item	2296295	et	3	main
raha	doc_213943985065_item	2296297	et	4	main
et	doc_213943985065_item	2296299	et	3	main
hästi	doc_213943985065_item	2296302	et	3	main
olin	doc_213943985065_item	2296304	et	3	main
seal	doc_213943985065_item	2296306	et	4	main
pedast	doc_213943985065_item	2296313	et	4	main
kaks	doc_213943985065_item	2296317	et	3	main
ma	doc_213943985065_item	2296319	et	3	main
päevatasin	doc_213943985065_item	2296321	et	4	main
võtsin	doc_213943985065_item	2296323	et	3	main
tagasi	doc_213943985065_item	2296329	et	3	main
päev	doc_213943985065_item	2296335	et	3	main
judoga	doc_213943985065_item	2296338	et	4	main
sõitnud	doc_213943985065_item	2296345	et	4	main
elasid	doc_213943985065_item	2296361	et	4	main
ameerikas	doc_213943985065_item	2296362	et	4	main
kui	doc_213943985065_item	2296363	et	3	main
lõbus	doc_213943985065_item	2296368	et	4	main
käisime	doc_213943985065_item	2296371	et	3	main
käisime	doc_213943985065_item	2296382	et	3	main
väga	doc_213943985065_item	2296419	et	3	main
meeldiv	doc_213943985065_item	2296420	et	4	main
minu	doc_213943985065_item	2296423	et	3	main
nimi	doc_213943985065_item	2296433	et	3	main
ainult	doc_213943985065_item	2296441	et	4	main
magab	doc_213943985065_item	2296444	et	3	main
ta	doc_213943985065_item	2296458	et	4	main
kui	doc_213943985065_item	2296470	et	3	main
ma	doc_213943985065_item	2296471	et	3	main
erinevaid	doc_213943985065_item	2296473	et	4	main
lõõgastasin	doc_213943985065_item	2296488	et	3	main
mis	doc_213943985065_item	2296492	et	4	main
tähtis	doc_213943985065_item	2296495	et	4	main
tahan	doc_213943985065_item	2296497	et	3	main
raske	doc_213943985064_item	2296230	et	4	main
sest	doc_213943985064_item	2296231	et	4	main
oli	doc_213943985064_item	2296232	et	3	main
päevas	doc_213943985064_item	2296239	et	3	main
sest	doc_213943985064_item	2296244	et	4	main
ilm	doc_213943985064_item	2296245	et	3	main
oli	doc_213943985064_item	2296246	et	3	main
hea	doc_213943985064_item	2296247	et	4	main
loodus	doc_213943985064_item	2296248	et	4	main
seal	doc_213943985064_item	2296249	et	4	main
suurepärane	doc_213943985064_item	2296251	et	4	main
sest	doc_213943985064_item	2296252	et	4	main
seal	doc_213943985064_item	2296253	et	4	main
on	doc_213943985064_item	2296254	et	4	main
olin	doc_213943985064_item	2296258	et	3	main
sõpradega	doc_213943985064_item	2296260	et	3	main
tulin	doc_213943985064_item	2296263	et	3	main
sest	doc_213943985064_item	2296268	et	4	main
minu	doc_213943985065_item	2296275	et	3	main
on	doc_213943985065_item	2296292	et	4	main
vaja	doc_213943985065_item	2296296	et	4	main
selleks	doc_213943985065_item	2296298	et	4	main
suvi	doc_213943985065_item	2296301	et	3	main
juulis	doc_213943985065_item	2296303	et	3	main
kus	doc_213943985065_item	2296310	et	3	main
tudengid	doc_213943985065_item	2296312	et	3	main
ülikool	doc_213943985065_item	2296315	et	4	main
pärast	doc_213943985065_item	2296327	et	4	main
kus	doc_213943985065_item	2296331	et	3	main
iga	doc_213943985065_item	2296334	et	4	main
ma	doc_213943985065_item	2296336	et	3	main
koos	doc_213943985065_item	2296341	et	4	main
leedusse	doc_213943985065_item	2296346	et	4	main
koos	doc_213943985065_item	2296351	et	4	main
ma	doc_213943985065_item	2296353	et	3	main
näginud	doc_213943985065_item	2296355	et	4	main
kaks	doc_213943985065_item	2296357	et	3	main
aastat	doc_213943985065_item	2296358	et	3	main
kokku	doc_213943985065_item	2296365	et	3	main
kus	doc_213943985065_item	2296373	et	3	main
ka	doc_213943985065_item	2296376	et	3	main
suur	doc_213943985065_item	2296378	et	3	main
metsas	doc_213943985065_item	2296381	et	3	main
ja	doc_213943985065_item	2296386	et	3	main
marjud	doc_213943985065_item	2296387	et	4	main
külas	doc_213943985065_item	2296388	et	3	main
olin	doc_213943985065_item	2296389	et	3	main
kolm	doc_213943985065_item	2296390	et	3	main
nädalat	doc_213943985065_item	2296391	et	3	main
ja	doc_213943985065_item	2296392	et	3	main
seejärel	doc_213943985065_item	2296393	et	3	main
tulin	doc_213943985065_item	2296394	et	3	main
tagasi	doc_213943985065_item	2296395	et	3	main
tallinnasse	doc_213943985065_item	2296396	et	3	main
kodus	doc_213943985065_item	2296397	et	4	main
lugesin	doc_213943985065_item	2296398	et	3	main
raamatud	doc_213943985065_item	2296399	et	4	main
ja	doc_213943985065_item	2296400	et	3	main
vaatasin	doc_213943985065_item	2296401	et	3	main
telerit	doc_213943985065_item	2296402	et	3	main
oli	doc_213943985065_item	2296404	et	3	main
kui	doc_213943985065_item	2296403	et	3	main
aeg	doc_213943985065_item	2296406	et	3	main
vaba	doc_213943985065_item	2296405	et	4	main
siis	doc_213943985065_item	2296407	et	3	main
jalutasin	doc_213943985065_item	2296408	et	3	main
koeraga	doc_213943985065_item	2296409	et	3	main
korda	doc_213943985065_item	2296411	et	4	main
olin	doc_213943985065_item	2296412	et	3	main
mittu	doc_213943985065_item	2296410	et	4	main
kinnos	doc_213943985065_item	2296413	et	4	main
ja	doc_213943985065_item	2296414	et	3	main
teatris	doc_213943985065_item	2296415	et	3	main
suvel	doc_213943985065_item	2296417	et	3	main
kala	doc_213943985065_item	2296375	et	4	main
vanaemaga	doc_213943985065_item	2296380	et	3	main
oli	doc_213943985065_item	2296418	et	3	main
sündis	doc_213943985065_item	2296422	et	3	main
on	doc_213943985065_item	2296434	et	4	main
ei	doc_213943985065_item	2296438	et	4	main
rägi	doc_213943985065_item	2296439	et	4	main
aeg	doc_213943985065_item	2296446	et	3	main
kohta	doc_213943985065_item	2296452	et	4	main
suvel	doc_213943985065_item	2296453	et	3	main
me	doc_213943985065_item	2296454	et	4	main
suur	doc_213943985065_item	2296460	et	3	main
astat	doc_213943985065_item	2296465	et	4	main
talle	doc_213943985065_item	2296468	et	4	main
meeldib	doc_213943985065_item	2296469	et	3	main
ta	doc_213943985065_item	2296476	et	4	main
tohin	doc_213943985065_item	2296490	et	3	main
suvi	doc_213943985066_item	2296501	et	3	main
peale	doc_213943985066_item	2296502	et	4	main
kõiki	doc_213943985066_item	2296503	et	4	main
sooritatud	doc_213943985066_item	2296504	et	4	main
eksameid	doc_213943985066_item	2296505	et	3	main
võiks	doc_213943985066_item	2296506	et	4	main
puhata	doc_213943985066_item	2296507	et	4	main
arvasin	doc_213943985066_item	2296508	et	3	main
mina	doc_213943985066_item	2296509	et	4	main
kuid	doc_213943985066_item	2296510	et	4	main
puhkus	doc_213943985066_item	2296511	et	3	main
tööl	doc_213943985066_item	2296512	et	3	main
õnnestus	doc_213943985066_item	2296513	et	4	main
saada	doc_213943985066_item	2296514	et	4	main
alles	doc_213943985066_item	2296515	et	3	main
juuli	doc_213943985066_item	2296516	et	4	main
lõpp	doc_213943985066_item	2296517	et	3	main
augusti	doc_213943985066_item	2296518	et	3	main
algus	doc_213943985066_item	2296519	et	4	main
ülemus	doc_213943985066_item	2296520	et	4	main
soovis	doc_213943985066_item	2296521	et	4	main
minna	doc_213943985066_item	2296523	et	3	main
nautida	doc_213943985066_item	2296525	et	3	main
täiega	doc_213943985066_item	2296527	et	3	main
hoidma	doc_213943985066_item	2296535	et	3	main
oli	doc_213943985066_item	2296550	et	3	main
arendaja	doc_213943985066_item	2296558	et	4	main
vajadusel	doc_213943985066_item	2296568	et	3	main
töö	doc_213943985066_item	2296571	et	4	main
pakub	doc_213943985066_item	2296580	et	3	main
minna	doc_213943985066_item	2296585	et	3	main
meri	doc_213943985066_item	2296587	et	3	main
külma	doc_213943985066_item	2296595	et	4	main
ei	doc_213943985066_item	2296598	et	4	main
karda	doc_213943985066_item	2296599	et	4	main
sünnipäev	doc_213943985065_item	2296421	et	3	main
nimi	doc_213943985065_item	2296429	et	3	main
praegu	doc_213943985065_item	2296431	et	3	main
ultse	doc_213943985065_item	2296437	et	4	main
võin	doc_213943985065_item	2296448	et	3	main
ütelda	doc_213943985065_item	2296449	et	4	main
pois	doc_213943985065_item	2296461	et	3	main
on	doc_213943985065_item	2296463	et	4	main
asjad	doc_213943985065_item	2296474	et	3	main
tagasi	doc_213943985065_item	2296479	et	3	main
ütelda	doc_213943985065_item	2296481	et	4	main
veetsin	doc_213943985065_item	2296483	et	3	main
aega	doc_213943985065_item	2296485	et	4	main
hästi	doc_213943985065_item	2296486	et	3	main
ma	doc_213943985065_item	2296487	et	3	main
rinnaga	doc_213943985066_item	2296528	et	3	main
mina	doc_213943985066_item	2296529	et	4	main
korras	doc_213943985066_item	2296537	et	4	main
helistada	doc_213943985066_item	2296542	et	3	main
paar	doc_213943985066_item	2296548	et	3	main
kange	doc_213943985066_item	2296551	et	4	main
olen	doc_213943985066_item	2296556	et	3	main
hoida	doc_213943985066_item	2296563	et	3	main
hea	doc_213943985066_item	2296581	et	4	main
ja	doc_213943985066_item	2296582	et	3	main
ilm	doc_213943985066_item	2296584	et	3	main
randa	doc_213943985066_item	2296586	et	4	main
ei	doc_213943985066_item	2296589	et	4	main
päikeseline	doc_213943985066_item	2296622	et	3	main
suurepärased	doc_213943985066_item	2296625	et	4	main
nõval	doc_213943985066_item	2296627	et	3	main
joal	doc_213943985066_item	2296629	et	3	main
augusti	doc_213943985066_item	2296634	et	3	main
järves	doc_213943985066_item	2296646	et	4	main
peletavad	doc_213943985066_item	2296656	et	4	main
et	doc_213943985066_item	2296657	et	3	main
ootan	doc_213943985066_item	2296663	et	3	main
suvet	doc_213943985066_item	2296666	et	4	main
neljameetrilise	doc_213943985066_item	2296672	et	4	main
purje	doc_213943985066_item	2296673	et	4	main
essee	doc_213943985067_item	2296675	et	4	main
kuu	doc_213943985067_item	2296685	et	4	main
ei	doc_213943985067_item	2296694	et	4	main
mõnikord	doc_213943985067_item	2296698	et	3	main
sõbradega	doc_213943985067_item	2296702	et	4	main
sõida	doc_213943985067_item	2296704	et	4	main
kui	doc_213943985067_item	2296706	et	3	main
tore	doc_213943985067_item	2296737	et	3	main
oli	doc_213943985067_item	2296740	et	3	main
seal	doc_213943985067_item	2296743	et	4	main
meeldis	doc_213943985067_item	2296749	et	3	main
ei	doc_213943985067_item	2296753	et	4	main
oma	doc_213943985067_item	2296755	et	4	main
arvates	doc_213943985068_item	2296763	et	4	main
paljud	doc_213943985068_item	2296765	et	3	main
ei	doc_213943985068_item	2296767	et	4	main
turvalised	doc_213943985068_item	2296769	et	4	main
on	doc_213943985068_item	2296774	et	4	main
suured	doc_213943985068_item	2296775	et	3	main
lohakad	doc_213943985068_item	2296808	et	3	main
palk	doc_213943985068_item	2296810	et	3	main
taha	doc_213943985068_item	2296816	et	4	main
tekkida	doc_213943985068_item	2296821	et	3	main
vägivalda	doc_213943985068_item	2296833	et	4	main
peavad	doc_213943985068_item	2296839	et	4	main
16	doc_213943985068_item	2296844	et	2	main
arvates	doc_213943985068_item	2296847	et	4	main
on	doc_213943985068_item	2296850	et	4	main
lasteaias	doc_213943985068_item	2296856	et	4	main
territoorium	doc_213943985068_item	2296861	et	3	main
alale	doc_213943985068_item	2296869	et	4	main
olla	doc_213943985068_item	2296881	et	3	main
lastele	doc_213943985068_item	2296883	et	4	main
tööle	doc_213943985068_item	2296890	et	3	main
kasvatajatel	doc_213943985068_item	2296898	et	4	main
laste	doc_213943985069_item	2296921	et	4	main
et	doc_213943985069_item	2296932	et	3	main
miks	doc_213943985069_item	2296947	et	4	main
suitsukonisid	doc_213943985069_item	2296954	et	3	main
toimuvad	doc_213943985069_item	2296956	et	4	main
lasteaedades	doc_213943985069_item	2296958	et	3	main
kuid	doc_213943985069_item	2296959	et	4	main
õppida	doc_213943985065_item	2296498	et	3	main
ise	doc_213943985066_item	2296522	et	4	main
suvi	doc_213943985066_item	2296526	et	3	main
süsteemid	doc_213943985066_item	2296536	et	3	main
vaid	doc_213943985066_item	2296547	et	3	main
korda	doc_213943985066_item	2296549	et	4	main
temaga	doc_213943985066_item	2296554	et	3	main
ja	doc_213943985066_item	2296559	et	3	main
suhteliselt	doc_213943985066_item	2296572	et	4	main
igav	doc_213943985066_item	2296575	et	3	main
päikeseline	doc_213943985066_item	2296583	et	3	main
eestis	doc_213943985066_item	2296588	et	3	main
vett	doc_213943985066_item	2296596	et	3	main
ma	doc_213943985066_item	2296597	et	3	main
jooksul	doc_213943985066_item	2296601	et	4	main
sai	doc_213943985066_item	2296602	et	4	main
käidud	doc_213943985066_item	2296603	et	4	main
võrku	doc_213943985066_item	2296604	et	4	main
pettang	doc_213943985066_item	2296605	et	4	main
ja	doc_213943985066_item	2296606	et	3	main
freesbe	doc_213943985066_item	2296607	et	4	main
lendav	doc_213943985066_item	2296608	et	4	main
taldrik	doc_213943985066_item	2296609	et	3	main
mängimas	doc_213943985066_item	2296610	et	3	main
kolme	doc_213943985066_item	2296611	et	4	main
kuu	doc_213943985066_item	2296612	et	4	main
jooksul	doc_213943985066_item	2296613	et	4	main
ei	doc_213943985066_item	2296614	et	4	main
ole	doc_213943985066_item	2296615	et	4	main
kordagi	doc_213943985066_item	2296616	et	4	main
käinud	doc_213943985066_item	2296617	et	4	main
välismaal	doc_213943985066_item	2296618	et	4	main
soojad	doc_213943985066_item	2296619	et	3	main
ilmad	doc_213943985066_item	2296620	et	3	main
ja	doc_213943985066_item	2296621	et	3	main
ilm	doc_213943985066_item	2296623	et	3	main
nädalavahetused	doc_213943985066_item	2296626	et	4	main
olen	doc_213943985066_item	2296636	et	3	main
windsurfing	doc_213943985066_item	2296642	et	4	main
kõvad	doc_213943985066_item	2296654	et	3	main
lained	doc_213943985066_item	2296655	et	3	main
vesi	doc_213943985066_item	2296660	et	4	main
muutub	doc_213943985066_item	2296661	et	3	main
ma	doc_213943985066_item	2296668	et	3	main
suvi	doc_213943985067_item	2296677	et	3	main
minu	doc_213943985067_item	2296678	et	3	main
suvi	doc_213943985067_item	2296679	et	3	main
üks	doc_213943985067_item	2296683	et	3	main
raske	doc_213943985067_item	2296687	et	4	main
ma	doc_213943985067_item	2296689	et	3	main
minu	doc_213943985067_item	2296692	et	3	main
merile	doc_213943985067_item	2296705	et	4	main
mina	doc_213943985067_item	2296710	et	4	main
sugulastele	doc_213943985067_item	2296712	et	4	main
seal	doc_213943985067_item	2296714	et	4	main
päike	doc_213943985067_item	2296731	et	3	main
mäede	doc_213943985067_item	2296733	et	4	main
ainult	doc_213943985067_item	2296738	et	4	main
külm	doc_213943985067_item	2296741	et	3	main
pisiasjadele	doc_213943985067_item	2296757	et	3	main
mitteturvaline	doc_213943985068_item	2296759	et	4	main
tõestamine	doc_213943985068_item	2296761	et	4	main
tänapäeval	doc_213943985068_item	2296764	et	3	main
paljud	doc_213943985068_item	2296772	et	3	main
võtta	doc_213943985066_item	2296553	et	3	main
ühendust	doc_213943985066_item	2296555	et	4	main
tarkvara	doc_213943985066_item	2296557	et	4	main
töökohustused	doc_213943985066_item	2296561	et	3	main
korras	doc_213943985066_item	2296565	et	4	main
arendustööd	doc_213943985066_item	2296566	et	4	main
erilahenduse	doc_213943985066_item	2296569	et	3	main
huvitav	doc_213943985066_item	2296573	et	4	main
ei	doc_213943985066_item	2296576	et	4	main
hakka	doc_213943985066_item	2296577	et	4	main
õhtul	doc_213943985066_item	2296578	et	3	main
aga	doc_213943985066_item	2296579	et	3	main
ole	doc_213943985066_item	2296590	et	4	main
just	doc_213943985066_item	2296591	et	3	main
eriti	doc_213943985066_item	2296592	et	3	main
soe	doc_213943985066_item	2296593	et	4	main
aga	doc_213943985066_item	2296594	et	3	main
suveperioodi	doc_213943985066_item	2296600	et	4	main
räpinas	doc_213943985066_item	2296630	et	4	main
mujal	doc_213943985066_item	2296632	et	3	main
avastanud	doc_213943985066_item	2296637	et	4	main
enda	doc_213943985066_item	2296638	et	4	main
purjelauaga	doc_213943985066_item	2296643	et	3	main
avameres	doc_213943985066_item	2296649	et	3	main
sügise	doc_213943985066_item	2296651	et	3	main
ja	doc_213943985066_item	2296653	et	3	main
sügis	doc_213943985066_item	2296659	et	3	main
külmemaks	doc_213943985066_item	2296662	et	4	main
järgmist	doc_213943985066_item	2296665	et	3	main
millal	doc_213943985066_item	2296667	et	3	main
nautida	doc_213943985066_item	2296670	et	3	main
oli	doc_213943985067_item	2296680	et	3	main
esimine	doc_213943985067_item	2296684	et	4	main
oli	doc_213943985067_item	2296686	et	3	main
töö	doc_213943985067_item	2296693	et	4	main
seganud	doc_213943985067_item	2296695	et	4	main
mulle	doc_213943985067_item	2296696	et	4	main
teenisin	doc_213943985067_item	2296708	et	3	main
lähen	doc_213943985067_item	2296711	et	3	main
valgemeri	doc_213943985067_item	2296722	et	3	main
loodus	doc_213943985067_item	2296724	et	4	main
on	doc_213943985067_item	2296725	et	4	main
väga	doc_213943985067_item	2296726	et	3	main
особенно	doc_213943985067_item	2296728	et	2	main
õhtuti	doc_213943985067_item	2296729	et	3	main
kui	doc_213943985067_item	2296730	et	3	main
läheb	doc_213943985067_item	2296732	et	3	main
oli	doc_213943985067_item	2296736	et	3	main
ilm	doc_213943985067_item	2296739	et	3	main
palju	doc_213943985067_item	2296745	et	4	main
ühesõnaga	doc_213943985067_item	2296747	et	3	main
suvi	doc_213943985067_item	2296751	et	3	main
harjutus	doc_213943985068_item	2296758	et	4	main
lasteaiad	doc_213943985068_item	2296766	et	4	main
lasteaiad	doc_213943985068_item	2296773	et	4	main
lasteaias	doc_213943985068_item	2296806	et	4	main
ja	doc_213943985068_item	2296813	et	3	main
võivad	doc_213943985068_item	2296820	et	4	main
probleemid	doc_213943985068_item	2296823	et	3	main
trauma	doc_213943985068_item	2296826	et	4	main
või	doc_213943985068_item	2296827	et	4	main
tänapäeva	doc_213943985068_item	2296829	et	4	main
ja	doc_213943985068_item	2296837	et	3	main
suurimaks	doc_213943985068_item	2296841	et	4	main
nähtus	doc_213943985068_item	2296852	et	4	main
vandalism	doc_213943985068_item	2296854	et	3	main
süütamine	doc_213943985068_item	2296855	et	4	main
lasteaia	doc_213943985068_item	2296858	et	4	main
ebaturvalisena	doc_213943985068_item	2296859	et	4	main
ei	doc_213943985068_item	2296862	et	4	main
kasutatud	doc_213943985068_item	2296870	et	4	main
süstlaid	doc_213943985068_item	2296871	et	3	main
täis	doc_213943985068_item	2296878	et	4	main
võiks	doc_213943985068_item	2296880	et	4	main
ja	doc_213943985068_item	2296897	et	3	main
jaoks	doc_213943985069_item	2296922	et	4	main
kogemuse	doc_213943985069_item	2296927	et	3	main
võiksid	doc_213943985069_item	2296934	et	4	main
turvalisem	doc_213943985069_item	2296935	et	4	main
olla	doc_213943985069_item	2296936	et	3	main
räägitakse	doc_213943985069_item	2296937	et	3	main
mu	doc_213943985066_item	2296560	et	3	main
on	doc_213943985066_item	2296562	et	4	main
süsteemid	doc_213943985066_item	2296564	et	3	main
projektid	doc_213943985066_item	2296567	et	3	main
leidmine	doc_213943985066_item	2296570	et	4	main
ja	doc_213943985066_item	2296574	et	3	main
moodustas	doc_213943985066_item	2296624	et	3	main
eestis	doc_213943985066_item	2296633	et	3	main
jaoks	doc_213943985066_item	2296639	et	4	main
uus	doc_213943985066_item	2296640	et	3	main
spordiala	doc_213943985066_item	2296641	et	4	main
sõita	doc_213943985066_item	2296645	et	3	main
ja	doc_213943985066_item	2296647	et	3	main
väga	doc_213943985066_item	2296664	et	3	main
saaks	doc_213943985066_item	2296669	et	3	main
all	doc_213943985066_item	2296674	et	3	main
minu	doc_213943985067_item	2296676	et	3	main
ainult	doc_213943985067_item	2296682	et	4	main
aga	doc_213943985067_item	2296691	et	3	main
ka	doc_213943985067_item	2296699	et	3	main
kohtuda	doc_213943985067_item	2296701	et	3	main
raha	doc_213943985067_item	2296709	et	4	main
mina	doc_213943985067_item	2296715	et	4	main
elavad	doc_213943985067_item	2296721	et	4	main
juures	doc_213943985067_item	2296723	et	4	main
kõik	doc_213943985067_item	2296735	et	4	main
ja	doc_213943985067_item	2296742	et	3	main
mulle	doc_213943985067_item	2296748	et	4	main
minu	doc_213943985067_item	2296750	et	3	main
tahelepanu	doc_213943985067_item	2296756	et	4	main
lasteaed	doc_213943985068_item	2296760	et	3	main
minu	doc_213943985068_item	2296762	et	3	main
et	doc_213943985068_item	2296771	et	3	main
on	doc_213943985068_item	2296807	et	4	main
sest	doc_213943985068_item	2296809	et	4	main
on	doc_213943985068_item	2296811	et	4	main
väike	doc_213943985068_item	2296812	et	4	main
ei	doc_213943985068_item	2296815	et	4	main
töötada	doc_213943985068_item	2296817	et	3	main
suured	doc_213943985068_item	2296822	et	3	main
vägivald	doc_213943985068_item	2296828	et	3	main
uuringutes	doc_213943985068_item	2296834	et	3	main
osalevad	doc_213943985068_item	2296835	et	4	main
vastanute	doc_213943985068_item	2296846	et	4	main
vägivald	doc_213943985068_item	2296849	et	3	main
teevad	doc_213943985068_item	2296857	et	3	main
lasteaia	doc_213943985068_item	2296867	et	4	main
maa	doc_213943985068_item	2296868	et	4	main
ja	doc_213943985068_item	2296872	et	3	main
mõned	doc_213943985068_item	2296874	et	3	main
kahjulik	doc_213943985068_item	2296882	et	3	main
käivad	doc_213943985068_item	2296885	et	4	main
lasteaias	doc_213943985068_item	2296886	et	4	main
haigestunud	doc_213943985068_item	2296887	et	4	main
kasvatajad	doc_213943985068_item	2296888	et	4	main
haigestunud	doc_213943985068_item	2296891	et	4	main
lasteaia	doc_213943985068_item	2296892	et	4	main
vähendab	doc_213943985068_item	2296894	et	3	main
infopuudus	doc_213943985068_item	2296895	et	3	main
vanematel	doc_213943985068_item	2296896	et	4	main
kuid	doc_213943985069_item	2296923	et	4	main
ja	doc_213943985069_item	2296928	et	3	main
kinnised	doc_213943985069_item	2296941	et	4	main
on	doc_213943985069_item	2296944	et	4	main
siis	doc_213943985069_item	2296946	et	3	main
mitte	doc_213943985069_item	2296960	et	3	main
teada	doc_213943985069_item	2296967	et	3	main
personal	doc_213943985069_item	2296969	et	3	main
oskulikumaks	doc_213943985069_item	2296971	et	4	main
olla	doc_213943985069_item	2296972	et	3	main
peab	doc_213943985069_item	2296974	et	4	main
lastega	doc_213943985069_item	2296977	et	3	main
vanemad	doc_213943985069_item	2297021	et	4	main
võtavad	doc_213943985069_item	2297028	et	3	main
vastu	doc_213943985069_item	2297030	et	3	main
juulis	doc_213943985070_item	2297046	et	3	main
nagu	doc_213943985070_item	2297048	et	3	main
soje	doc_213943985070_item	2297051	et	4	main
soja	doc_213943985070_item	2297065	et	4	main
mul	doc_213943985070_item	2297067	et	3	main
pitergoff	doc_213943985070_item	2297083	et	4	main
suvi	doc_213943985070_item	2297087	et	3	main
keila	doc_213943985066_item	2296628	et	4	main
ja	doc_213943985066_item	2296631	et	3	main
kuus	doc_213943985066_item	2296635	et	4	main
saab	doc_213943985066_item	2296644	et	3	main
ka	doc_213943985066_item	2296648	et	3	main
kahjuks	doc_213943985066_item	2296650	et	4	main
tuuled	doc_213943985066_item	2296652	et	3	main
tuleb	doc_213943985066_item	2296658	et	3	main
elu	doc_213943985066_item	2296671	et	4	main
suurepärane	doc_213943985067_item	2296681	et	4	main
sest	doc_213943985067_item	2296688	et	4	main
töötasin	doc_213943985067_item	2296690	et	3	main
puhkuda	doc_213943985067_item	2296697	et	4	main
näiteks	doc_213943985067_item	2296700	et	4	main
ja	doc_213943985067_item	2296703	et	3	main
ma	doc_213943985067_item	2296707	et	3	main
venemaale	doc_213943985067_item	2296713	et	4	main
veetsin	doc_213943985067_item	2296716	et	3	main
aega	doc_213943985067_item	2296717	et	4	main
väga	doc_213943985067_item	2296718	et	3	main
hästi	doc_213943985067_item	2296719	et	3	main
nad	doc_213943985067_item	2296720	et	3	main
ilus	doc_213943985067_item	2296727	et	4	main
taga	doc_213943985067_item	2296734	et	4	main
olid	doc_213943985067_item	2296744	et	4	main
sääske	doc_213943985067_item	2296746	et	4	main
kui	doc_213943985067_item	2296752	et	3	main
pööra	doc_213943985067_item	2296754	et	4	main
ole	doc_213943985068_item	2296768	et	4	main
sellepärast	doc_213943985068_item	2296770	et	3	main
sest	doc_213943985068_item	2296776	et	4	main
lapsi	doc_213943985068_item	2296777	et	4	main
meie	doc_213943985068_item	2296778	et	4	main
riigis	doc_213943985068_item	2296779	et	3	main
on	doc_213943985068_item	2296780	et	4	main
palju	doc_213943985068_item	2296781	et	4	main
aga	doc_213943985068_item	2296782	et	3	main
lasteaedu	doc_213943985068_item	2296783	et	3	main
on	doc_213943985068_item	2296784	et	4	main
vähe	doc_213943985068_item	2296785	et	3	main
suures	doc_213943985068_item	2296786	et	3	main
lasteaias	doc_213943985068_item	2296787	et	4	main
on	doc_213943985068_item	2296788	et	4	main
rohkem	doc_213943985068_item	2296789	et	4	main
vägivalda	doc_213943985068_item	2296790	et	4	main
sest	doc_213943985068_item	2296791	et	4	main
et	doc_213943985068_item	2296792	et	3	main
lapsi	doc_213943985068_item	2296793	et	4	main
on	doc_213943985068_item	2296794	et	4	main
palju	doc_213943985068_item	2296795	et	4	main
ja	doc_213943985068_item	2296796	et	3	main
kasvatajad	doc_213943985068_item	2296797	et	4	main
ei	doc_213943985068_item	2296798	et	4	main
juua	doc_213943985068_item	2296799	et	3	main
kõike	doc_213943985068_item	2296800	et	4	main
nende	doc_213943985068_item	2296801	et	4	main
eest	doc_213943985068_item	2296802	et	4	main
hoolitseda	doc_213943985068_item	2296803	et	3	main
mõned	doc_213943985068_item	2296804	et	3	main
kasvatajad	doc_213943985068_item	2296805	et	4	main
nad	doc_213943985068_item	2296814	et	3	main
selle	doc_213943985068_item	2296818	et	4	main
tõttu	doc_213943985068_item	2296819	et	4	main
näiteks	doc_213943985068_item	2296824	et	4	main
lapse	doc_213943985068_item	2296825	et	4	main
on	doc_213943985068_item	2296831	et	4	main
palju	doc_213943985068_item	2296832	et	4	main
lapsevanemad	doc_213943985068_item	2296836	et	4	main
lastevaheline	doc_213943985068_item	2296848	et	4	main
ole	doc_213943985068_item	2296863	et	4	main
narkomaanid	doc_213943985068_item	2296865	et	3	main
suitsukonisid	doc_213943985068_item	2296873	et	3	main
on	doc_213943985068_item	2296876	et	4	main
mis	doc_213943985068_item	2296879	et	4	main
lapsed	doc_213943985068_item	2296884	et	3	main
tulevad	doc_213943985068_item	2296889	et	4	main
lasteaias	doc_213943985068_item	2296830	et	4	main
töötajad	doc_213943985068_item	2296838	et	4	main
vägivalda	doc_213943985068_item	2296840	et	4	main
probleemiks	doc_213943985068_item	2296842	et	4	main
lasteaias	doc_213943985068_item	2296843	et	4	main
personalist	doc_213943985068_item	2296845	et	4	main
igapäevane	doc_213943985068_item	2296851	et	4	main
vargused	doc_213943985068_item	2296853	et	3	main
lasteaia	doc_213943985068_item	2296860	et	4	main
turvaline	doc_213943985068_item	2296864	et	4	main
jätavad	doc_213943985068_item	2296866	et	3	main
lasteaiad	doc_213943985068_item	2296875	et	4	main
prügi	doc_213943985068_item	2296877	et	4	main
turvalisuse	doc_213943985068_item	2296893	et	4	main
nende	doc_213943985068_item	2296899	et	4	main
teadmiste	doc_213943985068_item	2296900	et	4	main
vähesus	doc_213943985068_item	2296901	et	4	main
ükskõiksus	doc_213943985068_item	2296902	et	4	main
ja	doc_213943985068_item	2296903	et	3	main
ebaoskus	doc_213943985068_item	2296904	et	3	main
situatsioonidele	doc_213943985068_item	2296905	et	3	main
reageerima	doc_213943985068_item	2296906	et	3	main
harjutus	doc_213943985069_item	2296907	et	4	main
mitteturvaline	doc_213943985069_item	2296908	et	4	main
lasteaed	doc_213943985069_item	2296909	et	3	main
paljud	doc_213943985069_item	2296911	et	3	main
tõestamine	doc_213943985069_item	2296910	et	4	main
vanemad	doc_213943985069_item	2296912	et	4	main
arvavad	doc_213943985069_item	2296913	et	4	main
et	doc_213943985069_item	2296914	et	3	main
lasteaed	doc_213943985069_item	2296915	et	3	main
on	doc_213943985069_item	2296916	et	4	main
üsna	doc_213943985069_item	2296917	et	3	main
turvaline	doc_213943985069_item	2296918	et	4	main
koht	doc_213943985069_item	2296919	et	3	main
nende	doc_213943985069_item	2296920	et	4	main
oma	doc_213943985069_item	2296925	et	4	main
loetu	doc_213943985069_item	2296929	et	4	main
põhjal	doc_213943985069_item	2296930	et	4	main
arvan	doc_213943985069_item	2296931	et	3	main
alal	doc_213943985069_item	2296949	et	4	main
süstlaid	doc_213943985069_item	2296952	et	3	main
tihti	doc_213943985069_item	2296955	et	3	main
vanemad	doc_213943985069_item	2296964	et	4	main
töötajatel	doc_213943985069_item	2296973	et	4	main
neile	doc_213943985069_item	2296979	et	4	main
meeldima	doc_213943985069_item	2296982	et	3	main
niimoodi	doc_213943985069_item	2296985	et	3	main
reageering	doc_213943985069_item	2297020	et	3	main
lasteaeda	doc_213943985069_item	2297025	et	4	main
ja	doc_213943985069_item	2297026	et	3	main
lasteaiatöötajad	doc_213943985069_item	2297027	et	3	main
pärit	doc_213943985070_item	2297040	et	3	main
ja	doc_213943985070_item	2297052	et	3	main
oli	doc_213943985070_item	2297059	et	3	main
surepärane	doc_213943985070_item	2297060	et	4	main
tekkis	doc_213943985070_item	2297068	et	3	main
uued	doc_213943985070_item	2297069	et	3	main
mina	doc_213943985069_item	2296924	et	4	main
teadmiste	doc_213943985069_item	2296926	et	4	main
lasteaiad	doc_213943985069_item	2296933	et	4	main
kui	doc_213943985069_item	2296942	et	3	main
lasteaia	doc_213943985069_item	2296948	et	4	main
leida	doc_213943985069_item	2296951	et	3	main
ja	doc_213943985069_item	2296953	et	3	main
vargused	doc_213943985069_item	2296957	et	3	main
sellest	doc_213943985069_item	2296966	et	4	main
politseisse	doc_213943985069_item	2296968	et	3	main
võiks	doc_213943985069_item	2296970	et	4	main
olema	doc_213943985069_item	2296975	et	4	main
see	doc_213943985069_item	2296981	et	3	main
mitte	doc_213943985069_item	2296984	et	3	main
et	doc_213943985069_item	2296986	et	3	main
nad	doc_213943985069_item	2296987	et	3	main
töötavad	doc_213943985069_item	2296988	et	4	main
et	doc_213943985069_item	2296990	et	3	main
raha	doc_213943985069_item	2296991	et	4	main
ainult	doc_213943985069_item	2296989	et	4	main
saada	doc_213943985069_item	2296992	et	4	main
tekkivad	doc_213943985069_item	2296993	et	4	main
lasteomavahelised	doc_213943985069_item	2296994	et	4	main
konfliktid	doc_213943985069_item	2296995	et	3	main
lapsed	doc_213943985069_item	2296996	et	3	main
kasutavad	doc_213943985069_item	2296997	et	4	main
vägivalda	doc_213943985069_item	2296998	et	4	main
teine	doc_213943985069_item	2296999	et	3	main
teisega	doc_213943985069_item	2297000	et	4	main
lapsevanemad	doc_213943985069_item	2297002	et	4	main
suhtlemises	doc_213943985069_item	2297001	et	4	main
ei	doc_213943985069_item	2297003	et	4	main
sekku	doc_213943985069_item	2297004	et	4	main
lasteaia	doc_213943985069_item	2297005	et	4	main
kuid	doc_213943985069_item	2297007	et	4	main
lapsed	doc_213943985069_item	2297008	et	3	main
ootavad	doc_213943985069_item	2297009	et	4	main
seda	doc_213943985069_item	2297010	et	3	main
probleeme	doc_213943985069_item	2297006	et	3	main
sest	doc_213943985069_item	2297011	et	4	main
neile	doc_213943985069_item	2297012	et	4	main
on	doc_213943985069_item	2297013	et	4	main
vaja	doc_213943985069_item	2297014	et	4	main
ettekujutus	doc_213943985069_item	2297015	et	4	main
et	doc_213943985069_item	2297016	et	3	main
igale	doc_213943985069_item	2297017	et	3	main
teole	doc_213943985069_item	2297018	et	4	main
lasteaiade	doc_213943985069_item	2296938	et	3	main
territoriumid	doc_213943985069_item	2296939	et	4	main
on	doc_213943985069_item	2296940	et	4	main
see	doc_213943985069_item	2296943	et	3	main
nii	doc_213943985069_item	2296945	et	3	main
võib	doc_213943985069_item	2296950	et	3	main
või	doc_213943985069_item	2296963	et	4	main
tahe	doc_213943985069_item	2296976	et	4	main
peab	doc_213943985069_item	2296980	et	4	main
aga	doc_213943985069_item	2296983	et	3	main
viivad	doc_213943985069_item	2297022	et	4	main
haigestatud	doc_213943985069_item	2297023	et	4	main
lapsi	doc_213943985069_item	2297024	et	4	main
ta	doc_213943985069_item	2297029	et	4	main
teised	doc_213943985069_item	2297031	et	4	main
lapsed	doc_213943985069_item	2297032	et	3	main
võivad	doc_213943985069_item	2297033	et	4	main
olen	doc_213943985070_item	2297039	et	3	main
sest	doc_213943985070_item	2297042	et	4	main
krasnojarskis	doc_213943985070_item	2297044	et	4	main
ilm	doc_213943985070_item	2297045	et	3	main
väga	doc_213943985070_item	2297050	et	3	main
baikali	doc_213943985070_item	2297055	et	4	main
päike	doc_213943985070_item	2297061	et	3	main
värske	doc_213943985070_item	2297062	et	4	main
ja	doc_213943985070_item	2297064	et	3	main
tagasi	doc_213943985070_item	2297075	et	3	main
siis	doc_213943985070_item	2297077	et	3	main
väga	doc_213943985070_item	2297089	et	3	main
on	doc_213943985070_item	2297097	et	4	main
huvitavam	doc_213943985070_item	2297098	et	4	main
ja	doc_213943985070_item	2297099	et	3	main
sojem	doc_213943985070_item	2297100	et	4	main
mõtlen	doc_213943985070_item	2297101	et	3	main
kõik	doc_213943985069_item	2296961	et	4	main
lasteaiatöötajad	doc_213943985069_item	2296962	et	3	main
annavad	doc_213943985069_item	2296965	et	3	main
töötada	doc_213943985069_item	2296978	et	3	main
järgneb	doc_213943985069_item	2297019	et	3	main
ka	doc_213943985069_item	2297034	et	3	main
haigestuda	doc_213943985069_item	2297035	et	3	main
tere	doc_213943985070_item	2297037	et	3	main
tere	doc_213943985070_item	2297038	et	3	main
sibirist	doc_213943985070_item	2297041	et	3	main
sõidsin	doc_213943985070_item	2297043	et	4	main
oli	doc_213943985070_item	2297047	et	3	main
sõidsime	doc_213943985070_item	2297054	et	4	main
järvi	doc_213943985070_item	2297056	et	4	main
veet	doc_213943985070_item	2297066	et	4	main
sõbrad	doc_213943985070_item	2297070	et	3	main
kui	doc_213943985070_item	2297073	et	3	main
sõidsin	doc_213943985070_item	2297074	et	4	main
eestis	doc_213943985070_item	2297076	et	3	main
peterburis	doc_213943985070_item	2297079	et	4	main
ja	doc_213943985070_item	2297084	et	3	main
see	doc_213943985070_item	2297086	et	3	main
väga	doc_213943985070_item	2297090	et	3	main
ma	doc_213943985070_item	2297093	et	3	main
harjutus	doc_213943985072_item	2297230	et	4	main
mõned	doc_213943985072_item	2297239	et	3	main
filme	doc_213943985072_item	2297241	et	3	main
sõpra	doc_213943985072_item	2297244	et	4	main
sest	doc_213943985072_item	2297245	et	4	main
tahtsin	doc_213943985072_item	2297246	et	3	main
mõnesid	doc_213943985072_item	2297248	et	3	main
uusid	doc_213943985072_item	2297249	et	4	main
et	doc_213943985072_item	2297255	et	3	main
koos	doc_213943985072_item	2297256	et	4	main
mõned	doc_213943985072_item	2297257	et	3	main
koos	doc_213943985072_item	2297264	et	4	main
mõned	doc_213943985072_item	2297265	et	3	main
raamatud	doc_213943985072_item	2297266	et	4	main
1	doc_213943985072_item	2297269	et	2	main
mõned	doc_213943985072_item	2297272	et	3	main
oli	doc_213943985072_item	2297322	et	3	main
hiilis	doc_213943985072_item	2297326	et	3	main
meie	doc_213943985072_item	2297327	et	4	main
järel	doc_213943985072_item	2297335	et	4	main
areneda	doc_213943985072_item	2297345	et	3	main
hakka	doc_213943985072_item	2297351	et	4	main
elama	doc_213943985072_item	2297352	et	3	main
ja	doc_213943985072_item	2297353	et	3	main
1	doc_213943985072_item	2297355	et	2	main
pidin	doc_213943985072_item	2297357	et	3	main
pidin	doc_213943985072_item	2297362	et	3	main
sõpra	doc_213943985072_item	2297375	et	4	main
sest	doc_213943985072_item	2297376	et	4	main
tahtsin	doc_213943985072_item	2297377	et	3	main
temaga	doc_213943985072_item	2297378	et	3	main
ja	doc_213943985072_item	2297384	et	3	main
1	doc_213943985072_item	2297392	et	2	main
ma	doc_213943985072_item	2297396	et	3	main
raha	doc_213943985072_item	2297412	et	4	main
1	doc_213943985072_item	2297417	et	2	main
tantsiga	doc_213943985072_item	2297434	et	3	main
tantsuga	doc_213943985072_item	2297436	et	3	main
kingitus	doc_213943985072_item	2297444	et	4	main
meie	doc_213943985072_item	2297445	et	4	main
essee	doc_213943985070_item	2297036	et	4	main
ahjus	doc_213943985070_item	2297049	et	3	main
me	doc_213943985070_item	2297053	et	4	main
juures	doc_213943985070_item	2297057	et	4	main
kõik	doc_213943985070_item	2297058	et	4	main
lõhn	doc_213943985070_item	2297063	et	3	main
tuttavad	doc_213943985070_item	2297072	et	4	main
olin	doc_213943985070_item	2297078	et	3	main
veel	doc_213943985070_item	2297080	et	4	main
hermitag	doc_213943985070_item	2297085	et	4	main
oli	doc_213943985070_item	2297088	et	3	main
et	doc_213943985070_item	2297102	et	3	main
suvi	doc_213943985070_item	2297103	et	3	main
alati	doc_213943985070_item	2297104	et	4	main
on	doc_213943985070_item	2297105	et	4	main
ja	doc_213943985070_item	2297107	et	3	main
ilus	doc_213943985070_item	2297106	et	4	main
huvitav	doc_213943985070_item	2297108	et	4	main
kõikile	doc_213943985070_item	2297109	et	4	main
kõike	doc_213943985070_item	2297110	et	4	main
ilusat	doc_213943985070_item	2297111	et	3	main
temale	doc_213943985072_item	2297238	et	3	main
temale	doc_213943985072_item	2297247	et	3	main
sõpra	doc_213943985072_item	2297254	et	4	main
läbi	doc_213943985072_item	2297259	et	4	main
läbi	doc_213943985072_item	2297267	et	4	main
küsida	doc_213943985072_item	2297271	et	3	main
tahan	doc_213943985072_item	2297274	et	3	main
1	doc_213943985072_item	2297278	et	2	main
ja	doc_213943985070_item	2297071	et	3	main
seal	doc_213943985070_item	2297081	et	4	main
kaisin	doc_213943985070_item	2297082	et	4	main
ja	doc_213943985070_item	2297092	et	3	main
jargmine	doc_213943985070_item	2297096	et	4	main
huvitav	doc_213943985070_item	2297091	et	4	main
ootan	doc_213943985070_item	2297094	et	3	main
et	doc_213943985070_item	2297095	et	3	main
sõpra	doc_213943985072_item	2297235	et	4	main
1	doc_213943985072_item	2297252	et	2	main
vaadata	doc_213943985072_item	2297260	et	4	main
ootasin	doc_213943985072_item	2297261	et	3	main
asju	doc_213943985072_item	2297273	et	3	main
küsida	doc_213943985072_item	2297275	et	3	main
mul	doc_213943985072_item	2297282	et	3	main
oli	doc_213943985072_item	2297285	et	3	main
kursusetöö	doc_213943985072_item	2297320	et	4	main
nagu	doc_213943985072_item	2297324	et	3	main
nagu	doc_213943985072_item	2297331	et	3	main
hakka	doc_213943985072_item	2297342	et	4	main
ei	doc_213943985072_item	2297347	et	4	main
arenema	doc_213943985072_item	2297358	et	3	main
oma	doc_213943985072_item	2297359	et	4	main
suhtlemisoskust	doc_213943985072_item	2297360	et	3	main
rääkida	doc_213943985072_item	2297372	et	3	main
koolist	doc_213943985072_item	2297379	et	4	main
telefonil	doc_213943985072_item	2297386	et	3	main
ja	doc_213943985072_item	2297389	et	3	main
rääkisin	doc_213943985072_item	2297390	et	3	main
telefoniga	doc_213943985072_item	2297391	et	4	main
nagu	doc_213943985072_item	2297395	et	3	main
ei	doc_213943985072_item	2297397	et	4	main
talle	doc_213943985072_item	2297399	et	4	main
ma	doc_213943985072_item	2297403	et	3	main
oleks	doc_213943985072_item	2297405	et	3	main
võtab	doc_213943985072_item	2297415	et	3	main
parandage	doc_213943985072_item	2297231	et	3	main
kui	doc_213943985072_item	2297236	et	3	main
tahtsin	doc_213943985072_item	2297237	et	3	main
näidata	doc_213943985072_item	2297242	et	4	main
näidata	doc_213943985072_item	2297251	et	4	main
ootasin	doc_213943985072_item	2297253	et	3	main
sõpra	doc_213943985072_item	2297262	et	4	main
tahan	doc_213943985072_item	2297270	et	3	main
asju	doc_213943985072_item	2297277	et	3	main
tunne	doc_213943985072_item	2297280	et	4	main
on	doc_213943985072_item	2297283	et	4	main
palavik	doc_213943985072_item	2297284	et	3	main
oli	doc_213943985072_item	2297329	et	3	main
tunne	doc_213943985072_item	2297330	et	4	main
keegi	doc_213943985072_item	2297333	et	4	main
tööta	doc_213943985072_item	2297339	et	4	main
see	doc_213943985072_item	2297340	et	3	main
ei	doc_213943985072_item	2297341	et	4	main
sest	doc_213943985072_item	2297361	et	4	main
oma	doc_213943985072_item	2297364	et	4	main
ootasin	doc_213943985072_item	2297367	et	3	main
sest	doc_213943985072_item	2297369	et	4	main
tahaksin	doc_213943985072_item	2297370	et	3	main
temaga	doc_213943985072_item	2297371	et	3	main
1	doc_213943985072_item	2297381	et	2	main
kirjutasin	doc_213943985072_item	2297382	et	3	main
tunne	doc_213943985072_item	2297394	et	4	main
tunne	doc_213943985072_item	2297401	et	4	main
nagu	doc_213943985072_item	2297402	et	3	main
ta	doc_213943985072_item	2297414	et	4	main
sa	doc_213943985072_item	2297418	et	3	main
keegi	doc_213943985072_item	2297421	et	4	main
leidma	doc_213943985072_item	2297427	et	3	main
kellegi	doc_213943985072_item	2297428	et	4	main
kes	doc_213943985072_item	2297440	et	4	main
sõpra	doc_213943985072_item	2297448	et	4	main
kes	doc_213943985072_item	2297449	et	4	main
pidi	doc_213943985072_item	2297450	et	4	main
kas	doc_213943985072_item	2297457	et	3	main
meeldib	doc_213943985072_item	2297459	et	3	main
kas	doc_213943985072_item	2297464	et	3	main
talle	doc_213943985072_item	2297465	et	4	main
minu	doc_213943985072_item	2297467	et	3	main
kino	doc_213943985072_item	2297469	et	4	main
minna	doc_213943985072_item	2297470	et	3	main
oli	doc_213943985072_item	2297490	et	3	main
korjama	doc_213943985072_item	2297492	et	3	main
oli	doc_213943985072_item	2297494	et	3	main
meile	doc_213943985072_item	2297504	et	4	main
1700	doc_213943985072_item	2297508	et	2	main
saada	doc_213943985072_item	2297521	et	4	main
huvitavat	doc_213943985072_item	2297531	et	4	main
laulumäng	doc_213943985072_item	2297532	et	3	main
1	doc_213943985072_item	2297535	et	2	main
näidatakse	doc_213943985072_item	2297541	et	3	main
saa	doc_213943985072_item	2297544	et	4	main
kellelegi	doc_213943985072_item	2297552	et	4	main
seda	doc_213943985072_item	2297553	et	3	main
1	doc_213943985072_item	2297555	et	2	main
mõlemate	doc_213943985072_item	2297557	et	3	main
mõlema	doc_213943985072_item	2297564	et	3	main
marju	doc_213943985072_item	2297566	et	3	main
muusiumisse	doc_213943985072_item	2297573	et	4	main
kunstniku	doc_213943985072_item	2297575	et	3	main
minna	doc_213943985072_item	2297579	et	3	main
näitust	doc_213943985072_item	2297583	et	4	main
ootasin	doc_213943985072_item	2297586	et	3	main
1	doc_213943985072_item	2297627	et	2	main
ma	doc_213943985072_item	2297629	et	3	main
vead	doc_213943985072_item	2297232	et	4	main
1	doc_213943985072_item	2297233	et	2	main
ootasin	doc_213943985072_item	2297234	et	3	main
uued	doc_213943985072_item	2297240	et	3	main
ootasin	doc_213943985072_item	2297243	et	3	main
filme	doc_213943985072_item	2297250	et	3	main
raamatuid	doc_213943985072_item	2297258	et	3	main
et	doc_213943985072_item	2297263	et	3	main
vaadata	doc_213943985072_item	2297268	et	4	main
mõnesid	doc_213943985072_item	2297276	et	3	main
oli	doc_213943985072_item	2297279	et	3	main
nagu	doc_213943985072_item	2297281	et	3	main
tunne	doc_213943985072_item	2297286	et	4	main
nagu	doc_213943985072_item	2297287	et	3	main
mul	doc_213943985072_item	2297288	et	3	main
oleks	doc_213943985072_item	2297289	et	3	main
palavik	doc_213943985072_item	2297290	et	3	main
1	doc_213943985072_item	2297291	et	2	main
esiteks	doc_213943985072_item	2297292	et	3	main
peaks	doc_213943985072_item	2297293	et	4	main
mõtlema	doc_213943985072_item	2297294	et	3	main
ja	doc_213943985072_item	2297295	et	3	main
siis	doc_213943985072_item	2297296	et	3	main
öelda	doc_213943985072_item	2297297	et	4	main
esiteks	doc_213943985072_item	2297298	et	3	main
peaks	doc_213943985072_item	2297299	et	4	main
ja	doc_213943985072_item	2297301	et	3	main
mõtlema	doc_213943985072_item	2297300	et	3	main
siis	doc_213943985072_item	2297302	et	3	main
ütlema	doc_213943985072_item	2297303	et	3	main
1	doc_213943985072_item	2297304	et	2	main
läksin	doc_213943985072_item	2297305	et	3	main
koju	doc_213943985072_item	2297306	et	3	main
et	doc_213943985072_item	2297307	et	3	main
trükkida	doc_213943985072_item	2297308	et	3	main
lõpuni	doc_213943985072_item	2297309	et	3	main
oma	doc_213943985072_item	2297310	et	4	main
esimest	doc_213943985072_item	2297311	et	4	main
kursusetööd	doc_213943985072_item	2297312	et	4	main
läksin	doc_213943985072_item	2297313	et	3	main
koju	doc_213943985072_item	2297314	et	3	main
et	doc_213943985072_item	2297315	et	3	main
trükkida	doc_213943985072_item	2297316	et	3	main
lõpuni	doc_213943985072_item	2297317	et	3	main
oma	doc_213943985072_item	2297318	et	4	main
esimene	doc_213943985072_item	2297319	et	3	main
1	doc_213943985072_item	2297321	et	2	main
keegi	doc_213943985072_item	2297325	et	4	main
järel	doc_213943985072_item	2297328	et	4	main
hiiliks	doc_213943985072_item	2297332	et	3	main
elada	doc_213943985072_item	2297343	et	3	main
arenema	doc_213943985072_item	2297354	et	3	main
sest	doc_213943985072_item	2297356	et	4	main
suhtlemisoskust	doc_213943985072_item	2297365	et	3	main
sõpra	doc_213943985072_item	2297368	et	4	main
koolist	doc_213943985072_item	2297373	et	4	main
konspekti	doc_213943985072_item	2297388	et	4	main
meeldinud	doc_213943985072_item	2297398	et	4	main
oli	doc_213943985072_item	2297400	et	3	main
1	doc_213943985072_item	2297408	et	2	main
ta	doc_213943985072_item	2297410	et	4	main
võttab	doc_213943985072_item	2297411	et	4	main
teist	doc_213943985072_item	2297422	et	4	main
kes	doc_213943985072_item	2297423	et	4	main
tõestab	doc_213943985072_item	2297424	et	3	main
sa	doc_213943985072_item	2297425	et	3	main
tõestab	doc_213943985072_item	2297431	et	3	main
tegelesin	doc_213943985072_item	2297433	et	3	main
tegelesin	doc_213943985072_item	2297435	et	3	main
ootasin	doc_213943985072_item	2297438	et	3	main
pakkumine	doc_213943985072_item	2297468	et	4	main
1	doc_213943985072_item	2297471	et	2	main
pime	doc_213943985072_item	2297488	et	3	main
võimatu	doc_213943985072_item	2297499	et	4	main
tahaksid	doc_213943985072_item	2297519	et	4	main
1	doc_213943985072_item	2297522	et	2	main
luba	doc_213943985072_item	2297523	et	4	main
huvitavat	doc_213943985072_item	2297525	et	4	main
laulumängut	doc_213943985072_item	2297526	et	4	main
kaasa	doc_213943985072_item	2297527	et	4	main
võtta	doc_213943985072_item	2297528	et	3	main
luba	doc_213943985072_item	2297529	et	4	main
kaasa	doc_213943985072_item	2297533	et	4	main
võtta	doc_213943985072_item	2297534	et	3	main
ei	doc_213943985072_item	2297543	et	4	main
mitte	doc_213943985072_item	2297545	et	3	main
ei	doc_213943985072_item	2297549	et	4	main
hakkasin	doc_213943985072_item	2297556	et	3	main
kätega	doc_213943985072_item	2297558	et	3	main
ja	doc_213943985072_item	2297560	et	3	main
ja	doc_213943985072_item	2297567	et	3	main
1	doc_213943985072_item	2297570	et	2	main
minna	doc_213943985072_item	2297572	et	3	main
näituse	doc_213943985072_item	2297576	et	3	main
1	doc_213943985072_item	2297585	et	2	main
minu	doc_213943985072_item	2297633	et	3	main
läksid	doc_213943985072_item	2297635	et	4	main
ja	doc_213943985072_item	2297637	et	3	main
hinne	doc_213943985072_item	2297661	et	3	main
ei	doc_213943985072_item	2297662	et	4	main
mõju	doc_213943985072_item	2297663	et	4	main
et	doc_213943985072_item	2297666	et	3	main
temaga	doc_213943985072_item	2297672	et	3	main
kinno	doc_213943985072_item	2297674	et	3	main
linna	doc_213943985072_item	2297679	et	4	main
sõbradega	doc_213943985072_item	2297681	et	4	main
minna	doc_213943985072_item	2297683	et	3	main
sõpradega	doc_213943985072_item	2297686	et	3	main
ta	doc_213943985072_item	2297688	et	4	main
1	doc_213943985072_item	2297696	et	2	main
minu	doc_213943985072_item	2297699	et	3	main
lubas	doc_213943985072_item	2297702	et	3	main
oma	doc_213943985072_item	2297710	et	4	main
andis	doc_213943985072_item	2297712	et	3	main
nagu	doc_213943985072_item	2297719	et	3	main
minuga	doc_213943985072_item	2297723	et	3	main
juba	doc_213943985072_item	2297730	et	3	main
suitsetatakse	doc_213943985072_item	2297739	et	3	main
hakata	doc_213943985072_item	2297750	et	4	main
oli	doc_213943985072_item	2297752	et	3	main
mind	doc_213943985072_item	2297757	et	4	main
teha	doc_213943985072_item	2297762	et	3	main
mind	doc_213943985072_item	2297769	et	4	main
teavitada	doc_213943985072_item	2297770	et	4	main
kahtles	doc_213943985072_item	2297778	et	3	main
olen	doc_213943985073_item	2297781	et	3	main
sündinud	doc_213943985073_item	2297782	et	4	main
tunne	doc_213943985072_item	2297323	et	4	main
meie	doc_213943985072_item	2297334	et	4	main
1	doc_213943985072_item	2297336	et	2	main
kes	doc_213943985072_item	2297337	et	4	main
ei	doc_213943985072_item	2297338	et	4	main
ja	doc_213943985072_item	2297344	et	3	main
kes	doc_213943985072_item	2297346	et	4	main
tööta	doc_213943985072_item	2297348	et	4	main
see	doc_213943985072_item	2297349	et	3	main
ei	doc_213943985072_item	2297350	et	4	main
arendama	doc_213943985072_item	2297363	et	3	main
1	doc_213943985072_item	2297366	et	2	main
ootasin	doc_213943985072_item	2297374	et	3	main
rääkida	doc_213943985072_item	2297380	et	3	main
konspekti	doc_213943985072_item	2297383	et	4	main
rääkisin	doc_213943985072_item	2297385	et	3	main
kirjutasin	doc_213943985072_item	2297387	et	3	main
oli	doc_213943985072_item	2297393	et	3	main
ei	doc_213943985072_item	2297404	et	4	main
meeldinud	doc_213943985072_item	2297406	et	4	main
talle	doc_213943985072_item	2297407	et	4	main
kus	doc_213943985072_item	2297409	et	3	main
kust	doc_213943985072_item	2297413	et	4	main
raha	doc_213943985072_item	2297416	et	4	main
pead	doc_213943985072_item	2297419	et	4	main
leidma	doc_213943985072_item	2297420	et	3	main
pead	doc_213943985072_item	2297426	et	4	main
kaasa	doc_213943985072_item	2297443	et	4	main
talle	doc_213943985072_item	2297458	et	4	main
oli	doc_213943985072_item	2297472	et	3	main
mul	doc_213943985072_item	2297475	et	3	main
pime	doc_213943985072_item	2297496	et	3	main
mitte	doc_213943985072_item	2297505	et	3	main
helista	doc_213943985072_item	2297509	et	4	main
mitte	doc_213943985072_item	2297511	et	3	main
hiljem	doc_213943985072_item	2297512	et	3	main
1700	doc_213943985072_item	2297514	et	2	main
tahaksid	doc_213943985072_item	2297516	et	4	main
õmblejana	doc_213943985072_item	2297517	et	4	main
üht	doc_213943985072_item	2297530	et	3	main
filmi	doc_213943985072_item	2297537	et	4	main
rääkima	doc_213943985072_item	2297548	et	3	main
saa	doc_213943985072_item	2297550	et	4	main
mitte	doc_213943985072_item	2297551	et	3	main
seene	doc_213943985072_item	2297561	et	3	main
hakkasin	doc_213943985072_item	2297563	et	3	main
korjama	doc_213943985072_item	2297569	et	3	main
eesti	doc_213943985072_item	2297574	et	4	main
eesti	doc_213943985072_item	2297581	et	4	main
vaatama	doc_213943985072_item	2297584	et	3	main
teise	doc_213943985072_item	2297429	et	4	main
kes	doc_213943985072_item	2297430	et	4	main
1	doc_213943985072_item	2297432	et	2	main
1	doc_213943985072_item	2297437	et	2	main
sõpra	doc_213943985072_item	2297439	et	4	main
pidi	doc_213943985072_item	2297441	et	4	main
tuua	doc_213943985072_item	2297442	et	3	main
tooma	doc_213943985072_item	2297451	et	3	main
kaasa	doc_213943985072_item	2297452	et	4	main
kingituse	doc_213943985072_item	2297453	et	4	main
meie	doc_213943985072_item	2297454	et	4	main
sõbrale	doc_213943985072_item	2297455	et	3	main
1	doc_213943985072_item	2297456	et	2	main
sõbrale	doc_213943985072_item	2297446	et	3	main
ootasin	doc_213943985072_item	2297447	et	3	main
pakkumine	doc_213943985072_item	2297461	et	4	main
minna	doc_213943985072_item	2297463	et	3	main
meeldib	doc_213943985072_item	2297466	et	3	main
nagu	doc_213943985072_item	2297474	et	3	main
riietust	doc_213943985072_item	2297477	et	4	main
tunne	doc_213943985072_item	2297479	et	4	main
mul	doc_213943985072_item	2297481	et	3	main
oleks	doc_213943985072_item	2297483	et	3	main
riietust	doc_213943985072_item	2297484	et	4	main
1	doc_213943985072_item	2297485	et	2	main
oli	doc_213943985072_item	2297486	et	3	main
juba	doc_213943985072_item	2297487	et	3	main
ebavõimalik	doc_213943985072_item	2297491	et	3	main
oli	doc_213943985072_item	2297498	et	3	main
marju	doc_213943985072_item	2297500	et	3	main
1	doc_213943985072_item	2297502	et	2	main
helista	doc_213943985072_item	2297503	et	4	main
hilisem	doc_213943985072_item	2297506	et	4	main
meile	doc_213943985072_item	2297510	et	4	main
kui	doc_213943985072_item	2297513	et	3	main
1	doc_213943985072_item	2297515	et	2	main
õmblejaks	doc_213943985072_item	2297520	et	4	main
üht	doc_213943985072_item	2297524	et	3	main
filmi	doc_213943985072_item	2297540	et	4	main
1	doc_213943985072_item	2297542	et	2	main
kellelegi	doc_213943985072_item	2297546	et	4	main
rääkida	doc_213943985072_item	2297554	et	3	main
marju	doc_213943985072_item	2297559	et	3	main
käega	doc_213943985072_item	2297565	et	3	main
seeni	doc_213943985072_item	2297568	et	3	main
sõpra	doc_213943985072_item	2297587	et	4	main
kui	doc_213943985072_item	2297628	et	3	main
lõpuks	doc_213943985072_item	2297630	et	4	main
metsa	doc_213943985072_item	2297631	et	4	main
jõudsin	doc_213943985072_item	2297632	et	3	main
ära	doc_213943985072_item	2297636	et	4	main
sõbrad	doc_213943985072_item	2297647	et	3	main
tulemusele	doc_213943985072_item	2297664	et	3	main
pidime	doc_213943985072_item	2297677	et	3	main
aidata	doc_213943985072_item	2297691	et	4	main
nõustus	doc_213943985072_item	2297693	et	4	main
tagastada	doc_213943985072_item	2297701	et	3	main
mulle	doc_213943985072_item	2297713	et	4	main
1	doc_213943985072_item	2297716	et	2	main
tunne	doc_213943985072_item	2297718	et	4	main
see	doc_213943985072_item	2297720	et	3	main
oli	doc_213943985072_item	2297721	et	3	main
siin	doc_213943985072_item	2297738	et	4	main
1	doc_213943985072_item	2297740	et	2	main
oma	doc_213943985072_item	2297747	et	4	main
ajama	doc_213943985072_item	2297749	et	4	main
teavitada	doc_213943985072_item	2297758	et	4	main
tohi	doc_213943985072_item	2297760	et	4	main
tunne	doc_213943985072_item	2297764	et	4	main
tema	doc_213943985072_item	2297777	et	4	main
õpisin	doc_213943985073_item	2297788	et	4	main
koolis	doc_213943985073_item	2297789	et	4	main
alla	doc_213943985073_item	2297821	et	3	main
kuigi	doc_213943985073_item	2297823	et	3	main
sooritasin	doc_213943985073_item	2297831	et	3	main
kooli	doc_213943985073_item	2297837	et	4	main
öelda	doc_213943985073_item	2297843	et	4	main
et	doc_213943985073_item	2297844	et	3	main
ema	doc_213943985073_item	2297861	et	4	main
arvuti	doc_213943985073_item	2297864	et	4	main
koera	doc_213943985073_item	2297872	et	4	main
on	doc_213943985073_item	2297881	et	4	main
päris	doc_213943985073_item	2297890	et	4	main
tallinnas	doc_213943985074_item	2297898	et	4	main
minu	doc_213943985072_item	2297460	et	3	main
kinos	doc_213943985072_item	2297462	et	3	main
tunne	doc_213943985072_item	2297473	et	4	main
polnud	doc_213943985072_item	2297476	et	3	main
oli	doc_213943985072_item	2297478	et	3	main
nagu	doc_213943985072_item	2297480	et	3	main
ei	doc_213943985072_item	2297482	et	4	main
ja	doc_213943985072_item	2297489	et	3	main
marju	doc_213943985072_item	2297493	et	3	main
juba	doc_213943985072_item	2297495	et	3	main
ja	doc_213943985072_item	2297497	et	3	main
korjata	doc_213943985072_item	2297501	et	4	main
kui	doc_213943985072_item	2297507	et	3	main
saada	doc_213943985072_item	2297518	et	4	main
uut	doc_213943985072_item	2297536	et	3	main
näidetakse	doc_213943985072_item	2297538	et	4	main
uut	doc_213943985072_item	2297539	et	3	main
seda	doc_213943985072_item	2297547	et	3	main
korjama	doc_213943985072_item	2297562	et	3	main
et	doc_213943985072_item	2297571	et	3	main
vaadata	doc_213943985072_item	2297577	et	4	main
et	doc_213943985072_item	2297578	et	3	main
muuseumisse	doc_213943985072_item	2297580	et	3	main
kunstniku	doc_213943985072_item	2297582	et	3	main
sest	doc_213943985072_item	2297588	et	4	main
tahaksin	doc_213943985072_item	2297589	et	3	main
mille	doc_213943985072_item	2297591	et	3	main
vaadata	doc_213943985072_item	2297590	et	4	main
auto	doc_213943985072_item	2297592	et	4	main
ta	doc_213943985072_item	2297593	et	4	main
ostis	doc_213943985072_item	2297594	et	4	main
kahe	doc_213943985072_item	2297596	et	3	main
endale	doc_213943985072_item	2297595	et	4	main
päeva	doc_213943985072_item	2297597	et	4	main
tagasi	doc_213943985072_item	2297598	et	3	main
ootasin	doc_213943985072_item	2297599	et	3	main
sõpra	doc_213943985072_item	2297600	et	4	main
tahtsin	doc_213943985072_item	2297602	et	3	main
sest	doc_213943985072_item	2297601	et	4	main
vaadata	doc_213943985072_item	2297603	et	4	main
millise	doc_213943985072_item	2297604	et	3	main
auto	doc_213943985072_item	2297605	et	4	main
ta	doc_213943985072_item	2297606	et	4	main
ostis	doc_213943985072_item	2297607	et	4	main
endale	doc_213943985072_item	2297608	et	4	main
kaks	doc_213943985072_item	2297609	et	3	main
päeva	doc_213943985072_item	2297610	et	4	main
tagasi	doc_213943985072_item	2297611	et	3	main
1	doc_213943985072_item	2297612	et	2	main
muutus	doc_213943985072_item	2297613	et	4	main
oma	doc_213943985072_item	2297614	et	4	main
tunniplaani	doc_213943985072_item	2297615	et	4	main
ja	doc_213943985072_item	2297616	et	3	main
kaotas	doc_213943985072_item	2297617	et	3	main
minu	doc_213943985072_item	2297618	et	3	main
numbrit	doc_213943985072_item	2297619	et	3	main
muutis	doc_213943985072_item	2297620	et	3	main
oma	doc_213943985072_item	2297621	et	4	main
lõpuks	doc_213943985072_item	2297643	et	4	main
metsa	doc_213943985072_item	2297644	et	4	main
jõudsin	doc_213943985072_item	2297645	et	3	main
minu	doc_213943985072_item	2297646	et	3	main
ei	doc_213943985072_item	2297657	et	4	main
mõju	doc_213943985072_item	2297658	et	4	main
tunniplaani	doc_213943985072_item	2297622	et	4	main
ja	doc_213943985072_item	2297623	et	3	main
kaotas	doc_213943985072_item	2297624	et	3	main
minu	doc_213943985072_item	2297625	et	3	main
numbri	doc_213943985072_item	2297626	et	3	main
seal	doc_213943985072_item	2297639	et	4	main
kui	doc_213943985072_item	2297641	et	3	main
seisin	doc_213943985072_item	2297651	et	3	main
seal	doc_213943985072_item	2297652	et	4	main
üksi	doc_213943985072_item	2297653	et	4	main
1	doc_213943985072_item	2297654	et	2	main
see	doc_213943985072_item	2297655	et	3	main
sõbrad	doc_213943985072_item	2297634	et	3	main
seisasin	doc_213943985072_item	2297638	et	4	main
üksi	doc_213943985072_item	2297640	et	4	main
ma	doc_213943985072_item	2297642	et	3	main
läinud	doc_213943985072_item	2297648	et	4	main
ära	doc_213943985072_item	2297649	et	4	main
ja	doc_213943985072_item	2297650	et	3	main
see	doc_213943985072_item	2297660	et	3	main
temaga	doc_213943985072_item	2297667	et	3	main
kinno	doc_213943985072_item	2297670	et	3	main
1	doc_213943985072_item	2297676	et	2	main
pidime	doc_213943985072_item	2297682	et	3	main
nõustus	doc_213943985072_item	2297689	et	4	main
lubas	doc_213943985072_item	2297697	et	3	main
raamatu	doc_213943985072_item	2297705	et	4	main
1	doc_213943985072_item	2297707	et	2	main
oma	doc_213943985072_item	2297714	et	4	main
oli	doc_213943985072_item	2297717	et	3	main
oli	doc_213943985072_item	2297725	et	3	main
nagu	doc_213943985072_item	2297727	et	3	main
see	doc_213943985072_item	2297728	et	3	main
juhtunud	doc_213943985072_item	2297732	et	4	main
kas	doc_213943985072_item	2297734	et	3	main
siin	doc_213943985072_item	2297735	et	4	main
suitsetakse	doc_213943985072_item	2297736	et	3	main
oma	doc_213943985072_item	2297742	et	4	main
ajama	doc_213943985072_item	2297744	et	4	main
et	doc_213943985072_item	2297746	et	3	main
tahtsis	doc_213943985072_item	2297756	et	4	main
seda	doc_213943985072_item	2297761	et	3	main
oli	doc_213943985072_item	2297763	et	3	main
keegi	doc_213943985072_item	2297767	et	4	main
tahtnud	doc_213943985072_item	2297768	et	4	main
seda	doc_213943985072_item	2297773	et	3	main
1	doc_213943985072_item	2297775	et	2	main
essee	doc_213943985073_item	2297780	et	4	main
lasteaias	doc_213943985073_item	2297786	et	4	main
raskused	doc_213943985073_item	2297827	et	4	main
õpimisega	doc_213943985073_item	2297828	et	4	main
ma	doc_213943985073_item	2297830	et	3	main
eksamid	doc_213943985073_item	2297832	et	3	main
astusin	doc_213943985073_item	2297840	et	3	main
nagu	doc_213943985073_item	2297850	et	3	main
sündmus	doc_213943985073_item	2297857	et	3	main
et	doc_213943985073_item	2297860	et	3	main
mulle	doc_213943985073_item	2297863	et	4	main
millest	doc_213943985073_item	2297865	et	3	main
olen	doc_213943985073_item	2297866	et	3	main
kaua	doc_213943985073_item	2297867	et	3	main
unistanud	doc_213943985073_item	2297868	et	4	main
kes	doc_213943985073_item	2297873	et	4	main
oli	doc_213943985073_item	2297874	et	3	main
sellel	doc_213943985073_item	2297875	et	4	main
talvel	doc_213943985073_item	2297876	et	4	main
väga	doc_213943985073_item	2297877	et	3	main
öelda	doc_213943985073_item	2297887	et	4	main
elan	doc_213943985073_item	2297889	et	3	main
essee	doc_213943985074_item	2297892	et	4	main
pealinnas	doc_213943985074_item	2297897	et	4	main
juhtus	doc_213943985074_item	2297923	et	3	main
rohkem	doc_213943985074_item	2297932	et	4	main
tansiõpimise	doc_213943985074_item	2297935	et	4	main
ma	doc_213943985074_item	2297945	et	3	main
väga	doc_213943985074_item	2297954	et	3	main
inglise	doc_213943985074_item	2297965	et	4	main
keele	doc_213943985074_item	2297966	et	4	main
otsustasin	doc_213943985074_item	2297975	et	3	main
astuda	doc_213943985074_item	2297978	et	3	main
oli	doc_213943985074_item	2297981	et	3	main
sisseastumise	doc_213943985074_item	2297992	et	3	main
andis	doc_213943985074_item	2298001	et	3	main
juba	doc_213943985074_item	2298010	et	3	main
mulle	doc_213943985074_item	2298026	et	4	main
see	doc_213943985074_item	2298046	et	3	main
et	doc_213943985074_item	2298051	et	3	main
mina	doc_213943985074_item	2298061	et	4	main
kaheksasateistkümnes	doc_213943985074_item	2298064	et	4	main
kui	doc_213943985074_item	2298066	et	3	main
tenin	doc_213943985074_item	2298073	et	4	main
kõik	doc_213943985074_item	2298088	et	4	main
hästi	doc_213943985074_item	2298089	et	3	main
oma	doc_213943985074_item	2298095	et	4	main
hind	doc_213943985072_item	2297656	et	3	main
1	doc_213943985072_item	2297665	et	2	main
minna	doc_213943985072_item	2297678	et	3	main
linna	doc_213943985072_item	2297684	et	4	main
kohtuma	doc_213943985072_item	2297685	et	3	main
1	doc_213943985072_item	2297687	et	2	main
ta	doc_213943985072_item	2297692	et	4	main
mulle	doc_213943985072_item	2297698	et	4	main
raamatut	doc_213943985072_item	2297700	et	3	main
mulle	doc_213943985072_item	2297703	et	4	main
minu	doc_213943985072_item	2297704	et	3	main
tagastada	doc_213943985072_item	2297706	et	3	main
andis	doc_213943985072_item	2297708	et	3	main
tulemusele	doc_213943985072_item	2297659	et	3	main
koos	doc_213943985072_item	2297668	et	4	main
minema	doc_213943985072_item	2297669	et	3	main
et	doc_213943985072_item	2297671	et	3	main
koos	doc_213943985072_item	2297673	et	4	main
minna	doc_213943985072_item	2297675	et	3	main
kohtama	doc_213943985072_item	2297680	et	3	main
mind	doc_213943985072_item	2297690	et	4	main
mind	doc_213943985072_item	2297694	et	4	main
aitama	doc_213943985072_item	2297695	et	3	main
mulle	doc_213943985072_item	2297709	et	4	main
telefoninumbrit	doc_213943985072_item	2297711	et	3	main
telefoninumbri	doc_213943985072_item	2297715	et	3	main
juhtunud	doc_213943985072_item	2297724	et	4	main
kas	doc_213943985072_item	2297737	et	3	main
asju	doc_213943985072_item	2297748	et	3	main
1	doc_213943985072_item	2297751	et	2	main
tunne	doc_213943985072_item	2297753	et	4	main
nagu	doc_213943985072_item	2297754	et	3	main
et	doc_213943985072_item	2297759	et	3	main
nagu	doc_213943985072_item	2297765	et	3	main
et	doc_213943985072_item	2297771	et	3	main
tohi	doc_213943985072_item	2297772	et	4	main
teha	doc_213943985072_item	2297774	et	3	main
kahtles	doc_213943985072_item	2297776	et	3	main
siin	doc_213943985073_item	2297784	et	4	main
juba	doc_213943985073_item	2297825	et	3	main
ehkki	doc_213943985073_item	2297829	et	3	main
väga	doc_213943985073_item	2297833	et	3	main
ja	doc_213943985073_item	2297835	et	3	main
ma	doc_213943985073_item	2297839	et	3	main
ülikooli	doc_213943985073_item	2297841	et	4	main
sain	doc_213943985073_item	2297845	et	3	main
just	doc_213943985073_item	2297847	et	3	main
üks	doc_213943985073_item	2297855	et	3	main
positiivne	doc_213943985073_item	2297856	et	3	main
on	doc_213943985073_item	2297858	et	4	main
see	doc_213943985073_item	2297859	et	3	main
sain	doc_213943985073_item	2297870	et	3	main
nüüd	doc_213943985073_item	2297880	et	4	main
et	doc_213943985073_item	2297888	et	3	main
eesti	doc_213943985074_item	2297896	et	4	main
kuna	doc_213943985074_item	2297922	et	3	main
üks	doc_213943985074_item	2297924	et	3	main
et	doc_213943985074_item	2297927	et	3	main
emal	doc_213943985074_item	2297929	et	3	main
ei	doc_213943985074_item	2297930	et	4	main
olnud	doc_213943985074_item	2297931	et	4	main
maksta	doc_213943985074_item	2297937	et	4	main
sellega	doc_213943985074_item	2297941	et	3	main
palju	doc_213943985074_item	2297951	et	4	main
ja	doc_213943985074_item	2297957	et	3	main
arvates	doc_213943985074_item	2297959	et	4	main
aitas	doc_213943985074_item	2297961	et	3	main
riigieksam	doc_213943985074_item	2297967	et	3	main
hästi	doc_213943985074_item	2297968	et	3	main
sooritada	doc_213943985074_item	2297969	et	3	main
olin	doc_213943985074_item	2297972	et	3	main
ebaõnnestus	doc_213943985074_item	2297982	et	4	main
oli	doc_213943985074_item	2297984	et	3	main
kuigi	doc_213943985074_item	2297987	et	3	main
hoolsasti	doc_213943985074_item	2297990	et	3	main
eksamideks	doc_213943985074_item	2297993	et	4	main
kahetsen	doc_213943985074_item	2297995	et	3	main
kuna	doc_213943985074_item	2297998	et	3	main
ärikoolis	doc_213943985074_item	2298000	et	4	main
sain	doc_213943985074_item	2298011	et	3	main
ma	doc_213943985074_item	2298021	et	3	main
tegelemine	doc_213943985074_item	2298025	et	4	main
väga	doc_213943985074_item	2298027	et	3	main
ma	doc_213943985074_item	2298030	et	3	main
aru	doc_213943985074_item	2298032	et	4	main
ma	doc_213943985074_item	2298034	et	3	main
tahan	doc_213943985074_item	2298035	et	3	main
mu	doc_213943985074_item	2298042	et	3	main
unistuseks	doc_213943985074_item	2298043	et	4	main
juba	doc_213943985074_item	2298053	et	3	main
ole	doc_213943985074_item	2298055	et	4	main
juhtugi	doc_213943985074_item	2298060	et	4	main
veel	doc_213943985074_item	2298062	et	4	main
natuke	doc_213943985074_item	2298074	et	4	main
teenin	doc_213943985074_item	2298079	et	3	main
juba	doc_213943985072_item	2297722	et	3	main
tunne	doc_213943985072_item	2297726	et	4	main
oleks	doc_213943985072_item	2297729	et	3	main
minuga	doc_213943985072_item	2297731	et	3	main
1	doc_213943985072_item	2297733	et	2	main
et	doc_213943985072_item	2297741	et	3	main
asjadega	doc_213943985072_item	2297743	et	3	main
hakkata	doc_213943985072_item	2297745	et	4	main
keegi	doc_213943985072_item	2297755	et	4	main
oleks	doc_213943985072_item	2297766	et	3	main
temas	doc_213943985072_item	2297779	et	3	main
kui	doc_213943985073_item	2297790	et	3	main
ma	doc_213943985073_item	2297791	et	3	main
olin	doc_213943985073_item	2297792	et	3	main
õpisin	doc_213943985073_item	2297793	et	4	main
kümnendas	doc_213943985073_item	2297794	et	3	main
klassis	doc_213943985073_item	2297795	et	3	main
siis	doc_213943985073_item	2297796	et	3	main
suri	doc_213943985073_item	2297797	et	3	main
minu	doc_213943985073_item	2297798	et	3	main
vanaema	doc_213943985073_item	2297799	et	4	main
ma	doc_213943985073_item	2297800	et	3	main
muutusin	doc_213943985073_item	2297801	et	3	main
päris	doc_213943985073_item	2297802	et	4	main
pikaks	doc_213943985073_item	2297803	et	4	main
ajaks	doc_213943985073_item	2297804	et	4	main
väga	doc_213943985073_item	2297805	et	3	main
kurvaks	doc_213943985073_item	2297806	et	3	main
ja	doc_213943985073_item	2297807	et	3	main
viitsinud	doc_213943985073_item	2297809	et	4	main
enam	doc_213943985073_item	2297810	et	4	main
ei	doc_213943985073_item	2297808	et	4	main
midagi	doc_213943985073_item	2297811	et	4	main
teha	doc_213943985073_item	2297812	et	3	main
hiljem	doc_213943985073_item	2297813	et	3	main
ma	doc_213943985073_item	2297814	et	3	main
sain	doc_213943985073_item	2297815	et	3	main
aru	doc_213943985073_item	2297816	et	4	main
et	doc_213943985073_item	2297817	et	3	main
ikkagi	doc_213943985073_item	2297818	et	4	main
ei	doc_213943985073_item	2297819	et	4	main
tohi	doc_213943985073_item	2297820	et	4	main
hakkasid	doc_213943985073_item	2297826	et	4	main
hästi	doc_213943985073_item	2297834	et	3	main
lõpetasin	doc_213943985073_item	2297836	et	3	main
sellel	doc_213943985073_item	2297848	et	4	main
olin	doc_213943985073_item	2297851	et	3	main
unistanud	doc_213943985073_item	2297853	et	4	main
veel	doc_213943985073_item	2297854	et	4	main
veel	doc_213943985073_item	2297869	et	4	main
kuid	doc_213943985073_item	2297879	et	4	main
juba	doc_213943985073_item	2297883	et	3	main
julgelt	doc_213943985073_item	2297886	et	4	main
tallinnas	doc_213943985073_item	2297783	et	4	main
käisin	doc_213943985073_item	2297785	et	3	main
ja	doc_213943985073_item	2297787	et	3	main
anda	doc_213943985073_item	2297822	et	3	main
mul	doc_213943985073_item	2297824	et	3	main
siin	doc_213943985073_item	2297838	et	4	main
tahan	doc_213943985073_item	2297842	et	3	main
õpida	doc_213943985073_item	2297846	et	4	main
erialal	doc_213943985073_item	2297849	et	3	main
alati	doc_213943985073_item	2297852	et	4	main
ostis	doc_213943985073_item	2297862	et	4	main
endale	doc_213943985073_item	2297871	et	4	main
haige	doc_213943985073_item	2297878	et	4	main
ta	doc_213943985073_item	2297882	et	4	main
paranenud	doc_213943985073_item	2297884	et	4	main
saan	doc_213943985073_item	2297885	et	4	main
hästi	doc_213943985073_item	2297891	et	3	main
ja	doc_213943985074_item	2297899	et	3	main
sellepärast	doc_213943985074_item	2297900	et	3	main
mu	doc_213943985074_item	2297901	et	3	main
on	doc_213943985074_item	2297903	et	4	main
elu	doc_213943985074_item	2297902	et	4	main
väja	doc_213943985074_item	2297904	et	4	main
mitmekesine	doc_213943985074_item	2297905	et	4	main
saadik	doc_213943985074_item	2297906	et	4	main
kuue	doc_213943985074_item	2297907	et	4	main
ma	doc_213943985074_item	2297909	et	3	main
aastast	doc_213943985074_item	2297908	et	4	main
tegelesin	doc_213943985074_item	2297910	et	3	main
peale	doc_213943985074_item	2297911	et	4	main
oma	doc_213943985074_item	2297912	et	4	main
õpimist	doc_213943985074_item	2297913	et	4	main
tansiga	doc_213943985074_item	2297914	et	4	main
kooriga	doc_213943985074_item	2297915	et	4	main
kõrvpalliga	doc_213943985074_item	2297916	et	4	main
keele	doc_213943985074_item	2297917	et	4	main
õpimisega	doc_213943985074_item	2297918	et	4	main
nii	doc_213943985074_item	2297920	et	3	main
ja	doc_213943985074_item	2297919	et	3	main
edasi	doc_213943985074_item	2297921	et	3	main
nii	doc_213943985074_item	2297926	et	3	main
mu	doc_213943985074_item	2297928	et	3	main
ma	doc_213943985074_item	2297939	et	3	main
minu	doc_213943985074_item	2297958	et	3	main
eesti	doc_213943985074_item	2297963	et	4	main
ja	doc_213943985074_item	2297964	et	3	main
aastane	doc_213943985074_item	2297974	et	4	main
nii	doc_213943985074_item	2297983	et	3	main
valmistusin	doc_213943985074_item	2297991	et	3	main
siiamanii	doc_213943985074_item	2297997	et	4	main
näidata	doc_213943985074_item	2298006	et	4	main
pärast	doc_213943985074_item	2298007	et	4	main
kui	doc_213943985074_item	2298008	et	3	main
ma	doc_213943985074_item	2297893	et	3	main
olen	doc_213943985074_item	2297894	et	3	main
sündinud	doc_213943985074_item	2297895	et	4	main
kord	doc_213943985074_item	2297925	et	4	main
raha	doc_213943985074_item	2297933	et	4	main
mu	doc_213943985074_item	2297934	et	3	main
eest	doc_213943985074_item	2297936	et	4	main
ehkki	doc_213943985074_item	2297943	et	3	main
aastaid	doc_213943985074_item	2297952	et	4	main
see	doc_213943985074_item	2297953	et	3	main
meeldis	doc_213943985074_item	2297955	et	3	main
mind	doc_213943985074_item	2297962	et	4	main
ma	doc_213943985074_item	2297971	et	3	main
ma	doc_213943985074_item	2297976	et	3	main
proov	doc_213943985074_item	2297980	et	3	main
proov	doc_213943985074_item	2297986	et	3	main
ma	doc_213943985074_item	2297988	et	3	main
mina	doc_213943985074_item	2297994	et	4	main
sellest	doc_213943985074_item	2297996	et	4	main
õpimise	doc_213943985074_item	2297999	et	4	main
mulle	doc_213943985074_item	2298002	et	4	main
rohkem	doc_213943985074_item	2298003	et	4	main
võimalusi	doc_213943985074_item	2298004	et	3	main
kuueteistkümne	doc_213943985074_item	2298012	et	4	main
aastaseks	doc_213943985074_item	2298013	et	4	main
meeldib	doc_213943985074_item	2298028	et	3	main
siis	doc_213943985074_item	2298029	et	3	main
sain	doc_213943985074_item	2298031	et	3	main
tallinna	doc_213943985074_item	2298037	et	4	main
ülikooli	doc_213943985074_item	2298039	et	4	main
see	doc_213943985074_item	2298040	et	3	main
sai	doc_213943985074_item	2298041	et	4	main
sellel	doc_213943985074_item	2298044	et	4	main
ma	doc_213943985074_item	2298052	et	3	main
endale	doc_213943985074_item	2298068	et	4	main
mcdonalsis	doc_213943985074_item	2298070	et	4	main
praegu	doc_213943985074_item	2298071	et	3	main
ma	doc_213943985074_item	2298072	et	3	main
oma	doc_213943985074_item	2298075	et	4	main
aga	doc_213943985074_item	2298077	et	3	main
ja	doc_213943985074_item	2298080	et	3	main
vanemate	doc_213943985074_item	2298083	et	4	main
oli	doc_213943985074_item	2298087	et	3	main
päeval	doc_213943985074_item	2298092	et	3	main
mina	doc_213943985074_item	2298094	et	4	main
armastus	doc_213943985074_item	2298108	et	4	main
ema	doc_213943985076_item	2298277	et	4	main
et	doc_213943985076_item	2298325	et	3	main
tema	doc_213943985076_item	2298330	et	4	main
metsa	doc_213943985076_item	2298346	et	4	main
vihane	doc_213943985076_item	2298348	et	4	main
teda	doc_213943985076_item	2298353	et	4	main
ja	doc_213943985074_item	2297938	et	3	main
katkestasin	doc_213943985074_item	2297940	et	3	main
tegelda	doc_213943985074_item	2297942	et	4	main
seda	doc_213943985074_item	2297944	et	3	main
õpisin	doc_213943985074_item	2297946	et	4	main
keeli	doc_213943985074_item	2297947	et	4	main
inglise	doc_213943985074_item	2297948	et	4	main
ja	doc_213943985074_item	2297949	et	3	main
eesti	doc_213943985074_item	2297950	et	4	main
mulle	doc_213943985074_item	2297956	et	4	main
see	doc_213943985074_item	2297960	et	3	main
kui	doc_213943985074_item	2297970	et	3	main
kuueteistkümne	doc_213943985074_item	2297973	et	4	main
lapseärikooli	doc_213943985074_item	2297977	et	4	main
see	doc_213943985074_item	2297979	et	3	main
teinegi	doc_213943985074_item	2297985	et	3	main
väga	doc_213943985074_item	2297989	et	3	main
end	doc_213943985074_item	2298005	et	4	main
ma	doc_213943985074_item	2298009	et	3	main
hakkasin	doc_213943985074_item	2298014	et	3	main
ma	doc_213943985074_item	2298015	et	3	main
ajakirjandusega	doc_213943985074_item	2298016	et	3	main
tegelema	doc_213943985074_item	2298017	et	3	main
ühe	doc_213943985074_item	2298018	et	4	main
kuu	doc_213943985074_item	2298019	et	4	main
pärast	doc_213943985074_item	2298020	et	4	main
et	doc_213943985074_item	2298023	et	3	main
unistus	doc_213943985074_item	2298047	et	4	main
käi	doc_213943985074_item	2298048	et	4	main
elul	doc_213943985074_item	2298049	et	3	main
olgugi	doc_213943985074_item	2298050	et	4	main
klassis	doc_213943985074_item	2298065	et	3	main
leidsin	doc_213943985074_item	2298067	et	3	main
raha	doc_213943985074_item	2298076	et	4	main
ikkagi	doc_213943985074_item	2298078	et	4	main
ei	doc_213943985074_item	2298081	et	4	main
küsi	doc_213943985074_item	2298082	et	4	main
elus	doc_213943985074_item	2298086	et	4	main
armastust	doc_213943985074_item	2298096	et	4	main
palju	doc_213943985074_item	2298099	et	4	main
sain	doc_213943985074_item	2298104	et	3	main
et	doc_213943985074_item	2298106	et	3	main
veel	doc_213943985074_item	2298111	et	4	main
paremaks	doc_213943985074_item	2298121	et	4	main
märkasin	doc_213943985074_item	2298022	et	3	main
see	doc_213943985074_item	2298024	et	3	main
et	doc_213943985074_item	2298033	et	3	main
astuda	doc_213943985074_item	2298036	et	3	main
pedagoogika	doc_213943985074_item	2298038	et	4	main
aastal	doc_213943985074_item	2298045	et	3	main
ei	doc_213943985074_item	2298054	et	4	main
seda	doc_213943985074_item	2298056	et	3	main
palju	doc_213943985074_item	2298057	et	4	main
ootanud	doc_213943985074_item	2298058	et	4	main
aga	doc_213943985074_item	2298059	et	3	main
õpisin	doc_213943985074_item	2298063	et	4	main
töid	doc_213943985074_item	2298069	et	3	main
käest	doc_213943985074_item	2298084	et	4	main
ühel	doc_213943985074_item	2298091	et	3	main
kaotasin	doc_213943985074_item	2298093	et	3	main
nutsin	doc_213943985074_item	2298098	et	4	main
ja	doc_213943985074_item	2298102	et	3	main
aru	doc_213943985074_item	2298105	et	4	main
ja	doc_213943985074_item	2298113	et	3	main
vaja	doc_213943985074_item	2298115	et	4	main
ainult	doc_213943985074_item	2298116	et	4	main
loota	doc_213943985074_item	2298117	et	4	main
et	doc_213943985074_item	2298118	et	3	main
kõik	doc_213943985074_item	2298119	et	4	main
muutub	doc_213943985074_item	2298120	et	3	main
punamütsike	doc_213943985076_item	2298276	et	4	main
armastas	doc_213943985076_item	2298278	et	3	main
punamütsikest	doc_213943985076_item	2298279	et	4	main
väga	doc_213943985076_item	2298280	et	3	main
ja	doc_213943985076_item	2298281	et	3	main
mu	doc_213943985074_item	2298085	et	3	main
kuid	doc_213943985074_item	2298090	et	4	main
ma	doc_213943985074_item	2298097	et	3	main
tõeline	doc_213943985074_item	2298107	et	4	main
tulevikus	doc_213943985074_item	2298112	et	4	main
on	doc_213943985074_item	2298114	et	4	main
paar	doc_213943985074_item	2298100	et	3	main
päeva	doc_213943985074_item	2298101	et	4	main
siis	doc_213943985074_item	2298103	et	3	main
ootab	doc_213943985074_item	2298109	et	3	main
mind	doc_213943985074_item	2298110	et	4	main
ümberjutustus	doc_213943985076_item	2298275	et	3	main
ei	doc_213943985076_item	2298282	et	4	main
lubanud	doc_213943985076_item	2298283	et	4	main
temale	doc_213943985076_item	2298284	et	3	main
pöörata	doc_213943985076_item	2298322	et	4	main
kardis	doc_213943985076_item	2298323	et	3	main
ta	doc_213943985076_item	2298324	et	4	main
metsa	doc_213943985076_item	2298286	et	4	main
minna	doc_213943985076_item	2298287	et	3	main
aga	doc_213943985076_item	2298288	et	3	main
seekord	doc_213943985076_item	2298289	et	3	main
kui	doc_213943985076_item	2298290	et	3	main
ta	doc_213943985076_item	2298291	et	4	main
oli	doc_213943985076_item	2298292	et	3	main
väga	doc_213943985076_item	2298293	et	3	main
väsinud	doc_213943985076_item	2298294	et	4	main
tuletas	doc_213943985076_item	2298295	et	3	main
ta	doc_213943985076_item	2298296	et	4	main
meelde	doc_213943985076_item	2298297	et	3	main
et	doc_213943985076_item	2298298	et	3	main
vana	doc_213943985076_item	2298300	et	4	main
emake	doc_213943985076_item	2298301	et	4	main
tema	doc_213943985076_item	2298299	et	4	main
on	doc_213943985076_item	2298302	et	4	main
ilma	doc_213943985076_item	2298304	et	4	main
kodus	doc_213943985076_item	2298303	et	4	main
toitu	doc_213943985076_item	2298305	et	4	main
pole	doc_213943985076_item	2298306	et	3	main
midagi	doc_213943985076_item	2298307	et	4	main
parata	doc_213943985076_item	2298308	et	3	main
pidi	doc_213943985076_item	2298309	et	4	main
ta	doc_213943985076_item	2298310	et	4	main
lapsekest	doc_213943985076_item	2298312	et	4	main
oma	doc_213943985076_item	2298311	et	4	main
saata	doc_213943985076_item	2298313	et	3	main
aga	doc_213943985076_item	2298314	et	3	main
hoiatas	doc_213943985076_item	2298315	et	3	main
ta	doc_213943985076_item	2298316	et	4	main
punamütsikest	doc_213943985076_item	2298317	et	4	main
metsas	doc_213943985076_item	2298318	et	3	main
mitte	doc_213943985076_item	2298319	et	3	main
rada	doc_213943985076_item	2298320	et	4	main
vihane	doc_213943985076_item	2298326	et	4	main
hall	doc_213943985076_item	2298327	et	4	main
punamütsike	doc_213943985076_item	2298334	et	4	main
üle	doc_213943985076_item	2298338	et	3	main
astus	doc_213943985076_item	2298344	et	3	main
üksinda	doc_213943985076_item	2298285	et	4	main
pealt	doc_213943985076_item	2298321	et	4	main
ta	doc_213943985076_item	2298345	et	4	main
kohtas	doc_213943985076_item	2298356	et	3	main
teda	doc_213943985076_item	2298357	et	4	main
et	doc_213943985076_item	2298362	et	3	main
koguda	doc_213943985076_item	2298365	et	3	main
ta	doc_213943985076_item	2298367	et	4	main
kuhu	doc_213943985076_item	2298374	et	3	main
tuua	doc_213943985076_item	2298381	et	3	main
halle	doc_213943985076_item	2298391	et	4	main
tema	doc_213943985076_item	2298397	et	4	main
vastas	doc_213943985076_item	2298398	et	4	main
ütles	doc_213943985076_item	2298400	et	3	main
hunt	doc_213943985076_item	2298402	et	3	main
tean	doc_213943985076_item	2298403	et	3	main
mina	doc_213943985076_item	2298404	et	4	main
kus	doc_213943985076_item	2298405	et	3	main
siin	doc_213943985076_item	2298410	et	4	main
aga	doc_213943985076_item	2298424	et	3	main
sõi	doc_213943985076_item	2298431	et	3	main
tema	doc_213943985076_item	2298436	et	4	main
ootas	doc_213943985076_item	2298439	et	3	main
kui	doc_213943985076_item	2298441	et	3	main
tuli	doc_213943985076_item	2298443	et	4	main
tahaks	doc_213943985076_item	2298444	et	3	main
ta	doc_213943985076_item	2298445	et	4	main
oma	doc_213943985076_item	2298446	et	4	main
tervitada	doc_213943985076_item	2298448	et	3	main
ei	doc_213943985076_item	2298450	et	4	main
suured	doc_213943985076_item	2298462	et	3	main
et	doc_213943985076_item	2298465	et	3	main
aga	doc_213943985076_item	2298473	et	3	main
silmad	doc_213943985076_item	2298476	et	4	main
on	doc_213943985076_item	2298477	et	4	main
suured	doc_213943985076_item	2298479	et	3	main
vihane	doc_213943985076_item	2298490	et	4	main
ta	doc_213943985076_item	2298522	et	4	main
kõik	doc_213943985076_item	2298524	et	4	main
ja	doc_213943985076_item	2298527	et	3	main
hakkas	doc_213943985076_item	2298528	et	3	main
imetlema	doc_213943985076_item	2298530	et	3	main
ja	doc_213943985076_item	2298533	et	3	main
hakkas	doc_213943985076_item	2298546	et	3	main
ta	doc_213943985076_item	2298559	et	4	main
ütle	doc_213943985076_item	2298567	et	4	main
vihane	doc_213943985076_item	2298569	et	4	main
sisaldab	doc_213943985076_item	2298574	et	3	main
ähvarda	doc_213943985076_item	2298576	et	4	main
hundi	doc_213943985076_item	2298604	et	3	main
läksid	doc_213943985076_item	2298615	et	4	main
ja	doc_213943985076_item	2298622	et	3	main
tema	doc_213943985076_item	2298623	et	4	main
vanaema	doc_213943985076_item	2298624	et	4	main
ja	doc_213943985076_item	2298625	et	3	main
harjutus	doc_213943985077_item	2298632	et	4	main
oma	doc_213943985077_item	2298633	et	4	main
elukohta	doc_213943985077_item	2298634	et	4	main
tutvustav	doc_213943985077_item	2298635	et	4	main
on	doc_213943985077_item	2298645	et	4	main
mugav	doc_213943985077_item	2298647	et	3	main
sissepääses	doc_213943985077_item	2298653	et	4	main
ust	doc_213943985077_item	2298656	et	4	main
lukustatud	doc_213943985077_item	2298660	et	4	main
värvitatud	doc_213943985077_item	2298673	et	4	main
trepikoda	doc_213943985077_item	2298676	et	4	main
lukustatud	doc_213943985077_item	2298678	et	4	main
koputavad	doc_213943985077_item	2298686	et	4	main
akna	doc_213943985077_item	2298688	et	3	main
see	doc_213943985077_item	2298689	et	3	main
sissepääs	doc_213943985077_item	2298692	et	3	main
kohtade	doc_213943985078_item	2298727	et	3	main
siin	doc_213943985078_item	2298732	et	4	main
kullalt	doc_213943985078_item	2298734	et	3	main
odavad	doc_213943985078_item	2298735	et	3	main
rahul	doc_213943985078_item	2298742	et	4	main
on	doc_213943985078_item	2298748	et	4	main
juures	doc_213943985078_item	2298750	et	4	main
mõnusa	doc_213943985078_item	2298762	et	3	main
7	doc_213943985078_item	2298764	et	2	main
on	doc_213943985078_item	2298766	et	4	main
hunt	doc_213943985076_item	2298328	et	3	main
ründab	doc_213943985076_item	2298329	et	3	main
tütrakele	doc_213943985076_item	2298331	et	4	main
siis	doc_213943985076_item	2298332	et	3	main
põlla	doc_213943985076_item	2298335	et	4	main
üle	doc_213943985076_item	2298336	et	3	main
läks	doc_213943985076_item	2298333	et	3	main
silla	doc_213943985076_item	2298337	et	3	main
jälle	doc_213943985076_item	2298340	et	3	main
üle	doc_213943985076_item	2298342	et	3	main
hall	doc_213943985076_item	2298349	et	4	main
hunt	doc_213943985076_item	2298350	et	3	main
oli	doc_213943985076_item	2298351	et	3	main
juba	doc_213943985076_item	2298352	et	3	main
lille	doc_213943985076_item	2298364	et	4	main
kohtas	doc_213943985076_item	2298366	et	3	main
tema	doc_213943985076_item	2298370	et	4	main
punamütsike	doc_213943985076_item	2298376	et	4	main
mis	doc_213943985076_item	2298384	et	4	main
on	doc_213943985076_item	2298385	et	4	main
su	doc_213943985076_item	2298386	et	3	main
käes	doc_213943985076_item	2298387	et	4	main
küsis	doc_213943985076_item	2298388	et	3	main
mutikele	doc_213943985076_item	2298395	et	4	main
kaval	doc_213943985076_item	2298401	et	4	main
lilled	doc_213943985076_item	2298409	et	3	main
tee	doc_213943985076_item	2298414	et	4	main
ja	doc_213943985076_item	2298416	et	3	main
tema	doc_213943985076_item	2298418	et	4	main
eelistas	doc_213943985076_item	2298420	et	3	main
ta	doc_213943985076_item	2298421	et	4	main
vanaema	doc_213943985076_item	2298429	et	4	main
ära	doc_213943985076_item	2298433	et	4	main
ronis	doc_213943985076_item	2298435	et	4	main
vanaema	doc_213943985076_item	2298447	et	4	main
aga	doc_213943985076_item	2298449	et	3	main
paremini	doc_213943985076_item	2298467	et	4	main
kuulda	doc_213943985076_item	2298468	et	4	main
ütles	doc_213943985076_item	2298469	et	3	main
vaene	doc_213943985076_item	2298481	et	4	main
kui	doc_213943985076_item	2298535	et	3	main
kui	doc_213943985076_item	2298540	et	3	main
tark	doc_213943985076_item	2298541	et	3	main
möödanud	doc_213943985076_item	2298556	et	4	main
sisse	doc_213943985076_item	2298564	et	4	main
ja	doc_213943985076_item	2298565	et	3	main
hüüdis	doc_213943985076_item	2298566	et	3	main
mida	doc_213943985076_item	2298571	et	4	main
ja	doc_213943985076_item	2298614	et	3	main
rõõmsalt	doc_213943985076_item	2298631	et	4	main
see	doc_213943985077_item	2298644	et	3	main
ja	doc_213943985077_item	2298657	et	3	main
sissepääs	doc_213943985077_item	2298670	et	3	main
inimesed	doc_213943985077_item	2298685	et	3	main
väga	doc_213943985077_item	2298690	et	3	main
3	doc_213943985078_item	2298722	et	2	main
teiste	doc_213943985078_item	2298726	et	4	main
ees	doc_213943985078_item	2298728	et	4	main
on	doc_213943985078_item	2298729	et	4	main
see	doc_213943985078_item	2298730	et	3	main
et	doc_213943985078_item	2298731	et	3	main
ülimalt	doc_213943985078_item	2298741	et	4	main
5	doc_213943985078_item	2298745	et	2	main
et	doc_213943985078_item	2298752	et	3	main
on	doc_213943985078_item	2298754	et	4	main
nurgad	doc_213943985078_item	2298758	et	3	main
on	doc_213943985078_item	2298772	et	4	main
ja	doc_213943985078_item	2298775	et	3	main
palju	doc_213943985078_item	2298782	et	4	main
rahvast	doc_213943985078_item	2298783	et	4	main
11	doc_213943985078_item	2298791	et	2	main
võib	doc_213943985078_item	2298793	et	3	main
võib	doc_213943985078_item	2298800	et	3	main
ümberkorraldamist	doc_213943985078_item	2298809	et	3	main
xxx	doc_213943985079_item	2298818	et	4	main
ja	doc_213943985076_item	2298339	et	3	main
põlla	doc_213943985076_item	2298341	et	4	main
ja	doc_213943985076_item	2298343	et	3	main
ta	doc_213943985076_item	2298355	et	4	main
kõrvale	doc_213943985076_item	2298361	et	4	main
ta	doc_213943985076_item	2298369	et	4	main
korvakest	doc_213943985076_item	2298371	et	3	main
ja	doc_213943985076_item	2298372	et	3	main
minek	doc_213943985076_item	2298375	et	3	main
et	doc_213943985076_item	2298379	et	3	main
jälle	doc_213943985076_item	2298389	et	3	main
ilusamad	doc_213943985076_item	2298408	et	4	main
mine	doc_213943985076_item	2298412	et	3	main
aga	doc_213943985076_item	2298347	et	3	main
niipea	doc_213943985076_item	2298358	et	3	main
punamütsike	doc_213943985076_item	2298359	et	4	main
vanaemale	doc_213943985076_item	2298363	et	3	main
küsis	doc_213943985076_item	2298373	et	3	main
juurde	doc_213943985076_item	2298378	et	4	main
toitu	doc_213943985076_item	2298380	et	4	main
hunt	doc_213943985076_item	2298392	et	3	main
oma	doc_213943985076_item	2298394	et	4	main
palju	doc_213943985076_item	2298407	et	4	main
see	doc_213943985076_item	2298413	et	3	main
peale	doc_213943985076_item	2298415	et	4	main
hunti	doc_213943985076_item	2298419	et	4	main
sellel	doc_213943985076_item	2298426	et	4	main
voodisse	doc_213943985076_item	2298437	et	3	main
saanud	doc_213943985076_item	2298451	et	4	main
nii	doc_213943985076_item	2298461	et	3	main
hall	doc_213943985076_item	2298471	et	4	main
miks	doc_213943985076_item	2298474	et	4	main
sinu	doc_213943985076_item	2298475	et	3	main
kõik	doc_213943985076_item	2298483	et	4	main
sellele	doc_213943985076_item	2298484	et	4	main
sind	doc_213943985076_item	2298486	et	4	main
sõi	doc_213943985076_item	2298521	et	3	main
ka	doc_213943985076_item	2298523	et	3	main
toitu	doc_213943985076_item	2298525	et	4	main
korvist	doc_213943985076_item	2298526	et	3	main
iseenda	doc_213943985076_item	2298529	et	3	main
kadestama	doc_213943985076_item	2298531	et	3	main
sa	doc_213943985076_item	2298542	et	3	main
ajal	doc_213943985076_item	2298550	et	4	main
hundi	doc_213943985076_item	2298560	et	3	main
su	doc_213943985076_item	2298572	et	3	main
ära	doc_213943985076_item	2298575	et	4	main
mind	doc_213943985076_item	2298577	et	4	main
inimene	doc_213943985076_item	2298578	et	3	main
tapis	doc_213943985076_item	2298603	et	3	main
ta	doc_213943985076_item	2298605	et	4	main
kirvest	doc_213943985076_item	2298608	et	4	main
et	doc_213943985076_item	2298609	et	3	main
lahti	doc_213943985076_item	2298612	et	4	main
välja	doc_213943985076_item	2298617	et	4	main
terved	doc_213943985076_item	2298620	et	4	main
punamütsike	doc_213943985076_item	2298621	et	4	main
kõik	doc_213943985076_item	2298626	et	4	main
senist	doc_213943985076_item	2298628	et	3	main
hästi	doc_213943985076_item	2298629	et	3	main
tekst	doc_213943985077_item	2298636	et	3	main
esimesel	doc_213943985077_item	2298641	et	3	main
ja	doc_213943985077_item	2298643	et	3	main
transportimiseks	doc_213943985077_item	2298649	et	4	main
trepikoda	doc_213943985077_item	2298650	et	4	main
on	doc_213943985077_item	2298659	et	4	main
on	doc_213943985077_item	2298662	et	4	main
kõrged	doc_213943985077_item	2298664	et	3	main
hiljuti	doc_213943985077_item	2298672	et	4	main
on	doc_213943985077_item	2298677	et	4	main
aga	doc_213943985077_item	2298679	et	3	main
ei	doc_213943985077_item	2298681	et	4	main
ja	doc_213943985077_item	2298683	et	3	main
värvitatud	doc_213943985077_item	2298694	et	4	main
prisma	doc_213943985078_item	2298723	et	4	main
ma	doc_213943985078_item	2298739	et	3	main
kauba	doc_213943985078_item	2298743	et	3	main
eriti	doc_213943985078_item	2298746	et	3	main
naudin	doc_213943985078_item	2298761	et	3	main
mittevajalikud	doc_213943985078_item	2298776	et	3	main
9	doc_213943985078_item	2298779	et	2	main
pisut	doc_213943985078_item	2298780	et	3	main
10	doc_213943985078_item	2298784	et	2	main
pettumuse	doc_213943985078_item	2298792	et	4	main
pankomaat	doc_213943985078_item	2298797	et	4	main
tarbijaid	doc_213943985078_item	2298799	et	4	main
suur	doc_213943985078_item	2298802	et	3	main
13	doc_213943985078_item	2298806	et	2	main
vajaks	doc_213943985078_item	2298808	et	4	main
elu	doc_213943985079_item	2298814	et	4	main
ma	doc_213943985079_item	2298815	et	3	main
ainukene	doc_213943985079_item	2298824	et	4	main
laps	doc_213943985079_item	2298825	et	4	main
mul	doc_213943985079_item	2298827	et	3	main
ega	doc_213943985079_item	2298830	et	3	main
ootanud	doc_213943985076_item	2298354	et	4	main
kaldus	doc_213943985076_item	2298360	et	4	main
nuusutas	doc_213943985076_item	2298368	et	3	main
vanaema	doc_213943985076_item	2298377	et	4	main
vastas	doc_213943985076_item	2298382	et	4	main
lapseke	doc_213943985076_item	2298383	et	4	main
vihane	doc_213943985076_item	2298390	et	4	main
lilled	doc_213943985076_item	2298393	et	3	main
oli	doc_213943985076_item	2298396	et	3	main
ah	doc_213943985076_item	2298399	et	3	main
on	doc_213943985076_item	2298406	et	4	main
lähedal	doc_213943985076_item	2298411	et	4	main
uskus	doc_213943985076_item	2298417	et	3	main
tundmatut	doc_213943985076_item	2298422	et	4	main
teed	doc_213943985076_item	2298423	et	4	main
hunt	doc_213943985076_item	2298425	et	3	main
ja	doc_213943985076_item	2298434	et	3	main
ja	doc_213943985076_item	2298438	et	3	main
teda	doc_213943985076_item	2298452	et	4	main
küsis	doc_213943985076_item	2298454	et	3	main
mutike	doc_213943985076_item	2298456	et	4	main
sellele	doc_213943985076_item	2298464	et	4	main
sind	doc_213943985076_item	2298466	et	4	main
nii	doc_213943985076_item	2298478	et	3	main
lapseke	doc_213943985076_item	2298482	et	4	main
ajal	doc_213943985076_item	2298427	et	4	main
jooksis	doc_213943985076_item	2298428	et	4	main
juurde	doc_213943985076_item	2298430	et	4	main
ta	doc_213943985076_item	2298432	et	4	main
punamütsikest	doc_213943985076_item	2298440	et	4	main
punamütsike	doc_213943985076_item	2298442	et	4	main
tunda	doc_213943985076_item	2298453	et	3	main
teda	doc_213943985076_item	2298455	et	4	main
miks	doc_213943985076_item	2298457	et	4	main
on	doc_213943985076_item	2298458	et	4	main
sinu	doc_213943985076_item	2298459	et	3	main
kõrvad	doc_213943985076_item	2298460	et	3	main
kõik	doc_213943985076_item	2298463	et	4	main
kaval	doc_213943985076_item	2298470	et	4	main
hunt	doc_213943985076_item	2298472	et	3	main
küsis	doc_213943985076_item	2298480	et	3	main
et	doc_213943985076_item	2298485	et	3	main
paremini	doc_213943985076_item	2298487	et	4	main
näha	doc_213943985076_item	2298488	et	3	main
ütles	doc_213943985076_item	2298489	et	3	main
hall	doc_213943985076_item	2298491	et	4	main
hunt	doc_213943985076_item	2298492	et	3	main
aga	doc_213943985076_item	2298493	et	3	main
miks	doc_213943985076_item	2298494	et	4	main
su	doc_213943985076_item	2298495	et	3	main
hambad	doc_213943985076_item	2298496	et	3	main
on	doc_213943985076_item	2298497	et	4	main
nii	doc_213943985076_item	2298498	et	3	main
suured	doc_213943985076_item	2298499	et	3	main
ütles	doc_213943985076_item	2298500	et	3	main
lapseke	doc_213943985076_item	2298501	et	4	main
ja	doc_213943985076_item	2298502	et	3	main
läks	doc_213943985076_item	2298503	et	3	main
lähedale	doc_213943985076_item	2298504	et	4	main
et	doc_213943985076_item	2298505	et	3	main
suudelda	doc_213943985076_item	2298506	et	4	main
oma	doc_213943985076_item	2298507	et	4	main
vanaemat	doc_213943985076_item	2298508	et	4	main
ja	doc_213943985076_item	2298510	et	3	main
lõpuks	doc_213943985076_item	2298509	et	4	main
kohutav	doc_213943985076_item	2298511	et	4	main
hall	doc_213943985076_item	2298512	et	4	main
hunt	doc_213943985076_item	2298513	et	3	main
hüppas	doc_213943985076_item	2298514	et	3	main
voodi	doc_213943985076_item	2298515	et	4	main
välja	doc_213943985076_item	2298516	et	4	main
ja	doc_213943985076_item	2298517	et	3	main
sõi	doc_213943985076_item	2298518	et	3	main
tudrukut	doc_213943985076_item	2298519	et	4	main
ära	doc_213943985076_item	2298520	et	4	main
kallistama	doc_213943985076_item	2298532	et	3	main
hunt	doc_213943985076_item	2298537	et	3	main
oled	doc_213943985076_item	2298539	et	3	main
kiitma	doc_213943985076_item	2298534	et	3	main
kaval	doc_213943985076_item	2298536	et	4	main
sa	doc_213943985076_item	2298538	et	3	main
oled	doc_213943985076_item	2298543	et	3	main
heameelest	doc_213943985076_item	2298545	et	4	main
ulguma	doc_213943985076_item	2298548	et	3	main
sellel	doc_213943985076_item	2298549	et	4	main
oli	doc_213943985076_item	2298551	et	3	main
üks	doc_213943985076_item	2298552	et	3	main
puuraiuja	doc_213943985076_item	2298553	et	4	main
vanaema	doc_213943985076_item	2298554	et	4	main
ja	doc_213943985076_item	2298557	et	3	main
kuulis	doc_213943985076_item	2298558	et	4	main
laula	doc_213943985076_item	2298561	et	4	main
ta	doc_213943985076_item	2298563	et	4	main
kõht	doc_213943985076_item	2298573	et	3	main
muidu	doc_213943985076_item	2298579	et	3	main
oled	doc_213943985076_item	2298580	et	3	main
sina	doc_213943985076_item	2298581	et	4	main
mu	doc_213943985076_item	2298582	et	3	main
kõhu	doc_213943985076_item	2298583	et	3	main
sees	doc_213943985076_item	2298584	et	4	main
punamütsikese	doc_213943985076_item	2298585	et	4	main
ja	doc_213943985076_item	2298586	et	3	main
vanaemaga	doc_213943985076_item	2298587	et	3	main
koos	doc_213943985076_item	2298588	et	4	main
siis	doc_213943985076_item	2298589	et	3	main
sai	doc_213943985076_item	2298590	et	4	main
kõik	doc_213943985076_item	2298592	et	4	main
puuraiuja	doc_213943985076_item	2298591	et	4	main
ära	doc_213943985076_item	2298593	et	4	main
ta	doc_213943985076_item	2298594	et	4	main
läks	doc_213943985076_item	2298595	et	3	main
hundi	doc_213943985076_item	2298596	et	3	main
lähedale	doc_213943985076_item	2298597	et	4	main
tõmbas	doc_213943985076_item	2298598	et	3	main
oma	doc_213943985076_item	2298599	et	4	main
kirvese	doc_213943985076_item	2298600	et	4	main
ära	doc_213943985076_item	2298601	et	4	main
ja	doc_213943985076_item	2298602	et	3	main
ja	doc_213943985076_item	2298544	et	3	main
ta	doc_213943985076_item	2298547	et	4	main
koju	doc_213943985076_item	2298555	et	3	main
jooksis	doc_213943985076_item	2298562	et	4	main
paha	doc_213943985076_item	2298568	et	4	main
hunt	doc_213943985076_item	2298570	et	3	main
oma	doc_213943985076_item	2298607	et	4	main
kõhu	doc_213943985076_item	2298611	et	3	main
harutada	doc_213943985076_item	2298613	et	3	main
elasid	doc_213943985076_item	2298627	et	4	main
ja	doc_213943985076_item	2298630	et	3	main
positiivsed	doc_213943985077_item	2298637	et	3	main
korter	doc_213943985077_item	2298639	et	3	main
eriti	doc_213943985077_item	2298646	et	3	main
mööbli	doc_213943985077_item	2298648	et	3	main
maast	doc_213943985077_item	2298663	et	3	main
tehtud	doc_213943985077_item	2298666	et	4	main
tellidest	doc_213943985077_item	2298667	et	4	main
mitte	doc_213943985077_item	2298668	et	3	main
plokkidest	doc_213943985077_item	2298669	et	3	main
on	doc_213943985077_item	2298671	et	4	main
küljed	doc_213943985077_item	2298675	et	3	main
ole	doc_213943985077_item	2298682	et	4	main
aga	doc_213943985077_item	2298695	et	3	main
värv	doc_213943985077_item	2298696	et	3	main
on	doc_213943985077_item	2298697	et	4	main
juures	doc_213943985078_item	2298721	et	4	main
peamine	doc_213943985078_item	2298724	et	3	main
eelis	doc_213943985078_item	2298725	et	3	main
hinnad	doc_213943985078_item	2298737	et	3	main
meeldiv	doc_213943985078_item	2298747	et	4	main
prisma	doc_213943985078_item	2298749	et	4	main
firmade	doc_213943985078_item	2298757	et	3	main
ma	doc_213943985078_item	2298760	et	3	main
kohvikuga	doc_213943985078_item	2298763	et	3	main
tasemel	doc_213943985078_item	2298768	et	3	main
kaupluse	doc_213943985078_item	2298770	et	3	main
kolm	doc_213943985078_item	2298773	et	3	main
kallid	doc_213943985078_item	2298774	et	3	main
kliendikaart	doc_213943985078_item	2298785	et	4	main
ei	doc_213943985078_item	2298786	et	4	main
võimalda	doc_213943985078_item	2298787	et	4	main
katki	doc_213943985078_item	2298795	et	4	main
läinud	doc_213943985078_item	2298796	et	4	main
12	doc_213943985078_item	2298798	et	2	main
ehmatada	doc_213943985078_item	2298801	et	3	main
olen	doc_213943985079_item	2298816	et	3	main
keset	doc_213943985079_item	2298819	et	4	main
vanemate	doc_213943985079_item	2298823	et	4	main
jäin	doc_213943985079_item	2298841	et	3	main
aga	doc_213943985079_item	2298851	et	3	main
peaaegu	doc_213943985079_item	2298855	et	3	main
kaubanduskooli	doc_213943985079_item	2298862	et	4	main
sekretärina	doc_213943985079_item	2298865	et	3	main
klaverit	doc_213943985079_item	2298872	et	3	main
palunud	doc_213943985079_item	2298875	et	4	main
ja	doc_213943985079_item	2298876	et	3	main
minna	doc_213943985079_item	2298889	et	3	main
kuulub	doc_213943985079_item	2298893	et	3	main
veel	doc_213943985079_item	2298906	et	4	main
kuni	doc_213943985079_item	2298915	et	3	main
mind	doc_213943985079_item	2298921	et	4	main
tegelda	doc_213943985079_item	2298926	et	4	main
keskkooli	doc_213943985079_item	2298930	et	4	main
ära	doc_213943985079_item	2298931	et	4	main
otsustasin	doc_213943985079_item	2298933	et	3	main
xxx	doc_213943985079_item	2298935	et	4	main
läbisin	doc_213943985079_item	2298940	et	3	main
loodusrikase	doc_213943985079_item	2298945	et	4	main
see	doc_213943985079_item	2298947	et	3	main
sügis	doc_213943985079_item	2298957	et	3	main
elasin	doc_213943985079_item	2298961	et	3	main
suuremas	doc_213943985079_item	2298987	et	4	main
seal	doc_213943985079_item	2298991	et	4	main
huvitav	doc_213943985079_item	2298995	et	4	main
oli	doc_213943985079_item	2298999	et	3	main
oli	doc_213943985079_item	2299005	et	3	main
peterburisse	doc_213943985079_item	2299023	et	4	main
vahetusõpilaseks	doc_213943985079_item	2299024	et	3	main
meeltis	doc_213943985079_item	2299028	et	4	main
nädalad	doc_213943985079_item	2299042	et	3	main
juurde	doc_213943985079_item	2299051	et	4	main
kasutas	doc_213943985076_item	2298606	et	3	main
hundi	doc_213943985076_item	2298610	et	3	main
sellest	doc_213943985076_item	2298616	et	4	main
elus	doc_213943985076_item	2298618	et	4	main
ja	doc_213943985076_item	2298619	et	3	main
küljed	doc_213943985077_item	2298638	et	3	main
asub	doc_213943985077_item	2298640	et	3	main
korrusel	doc_213943985077_item	2298642	et	3	main
on	doc_213943985077_item	2298651	et	4	main
lukustatud	doc_213943985077_item	2298652	et	4	main
on	doc_213943985077_item	2298654	et	4	main
kaks	doc_213943985077_item	2298655	et	3	main
mõlemad	doc_213943985077_item	2298658	et	3	main
aknad	doc_213943985077_item	2298661	et	3	main
maja	doc_213943985077_item	2298665	et	4	main
negatiivsed	doc_213943985077_item	2298674	et	3	main
domofooni	doc_213943985077_item	2298680	et	4	main
kõik	doc_213943985077_item	2298684	et	4	main
meie	doc_213943985077_item	2298687	et	4	main
ärritab	doc_213943985077_item	2298691	et	3	main
on	doc_213943985077_item	2298693	et	4	main
hirmus	doc_213943985077_item	2298698	et	4	main
kahjuks	doc_213943985077_item	2298699	et	4	main
ei	doc_213943985077_item	2298700	et	4	main
ole	doc_213943985077_item	2298701	et	4	main
rõdu	doc_213943985077_item	2298702	et	4	main
harjutus	doc_213943985078_item	2298703	et	4	main
1	doc_213943985078_item	2298704	et	2	main
kaupluse	doc_213943985078_item	2298705	et	3	main
suureks	doc_213943985078_item	2298706	et	4	main
plussiks	doc_213943985078_item	2298707	et	4	main
on	doc_213943985078_item	2298708	et	4	main
normaalsed	doc_213943985078_item	2298709	et	3	main
hinnad	doc_213943985078_item	2298710	et	3	main
2	doc_213943985078_item	2298711	et	2	main
ma	doc_213943985078_item	2298712	et	3	main
eelistan	doc_213943985078_item	2298713	et	3	main
prisma	doc_213943985078_item	2298714	et	4	main
sellepärast	doc_213943985078_item	2298715	et	3	main
et	doc_213943985078_item	2298716	et	3	main
ta	doc_213943985078_item	2298717	et	4	main
on	doc_213943985078_item	2298718	et	4	main
minu	doc_213943985078_item	2298719	et	3	main
kodu	doc_213943985078_item	2298720	et	4	main
on	doc_213943985078_item	2298733	et	4	main
madalad	doc_213943985078_item	2298736	et	3	main
4	doc_213943985078_item	2298738	et	2	main
olen	doc_213943985078_item	2298740	et	3	main
kvaliteediga	doc_213943985078_item	2298744	et	3	main
see	doc_213943985078_item	2298751	et	3	main
seal	doc_213943985078_item	2298753	et	4	main
veel	doc_213943985078_item	2298755	et	4	main
mitu	doc_213943985078_item	2298756	et	4	main
6	doc_213943985078_item	2298759	et	2	main
teenindamine	doc_213943985078_item	2298765	et	4	main
heal	doc_213943985078_item	2298767	et	3	main
riide	doc_213943985078_item	2298777	et	4	main
osakonda	doc_213943985078_item	2298778	et	4	main
hinda	doc_213943985078_item	2298788	et	4	main
järjekord	doc_213943985078_item	2298803	et	3	main
õhtuti	doc_213943985078_item	2298805	et	3	main
kindlasti	doc_213943985078_item	2298807	et	3	main
essee	doc_213943985079_item	2298812	et	4	main
õdesid	doc_213943985079_item	2298829	et	3	main
mina	doc_213943985079_item	2298840	et	4	main
emaga	doc_213943985079_item	2298843	et	3	main
meil	doc_213943985079_item	2298845	et	4	main
emaga	doc_213943985079_item	2298847	et	3	main
väga	doc_213943985079_item	2298848	et	3	main
hea	doc_213943985079_item	2298849	et	4	main
suhe	doc_213943985079_item	2298850	et	3	main
tunne	doc_213943985079_item	2298857	et	4	main
käinud	doc_213943985079_item	2298861	et	4	main
töötab	doc_213943985079_item	2298864	et	3	main
olin	doc_213943985079_item	2298868	et	3	main
aastane	doc_213943985079_item	2298870	et	4	main
mängima	doc_213943985079_item	2298873	et	3	main
minna	doc_213943985079_item	2298880	et	3	main
õppima	doc_213943985079_item	2298883	et	3	main
lõpuks	doc_213943985079_item	2298885	et	4	main
ikka	doc_213943985079_item	2298899	et	4	main
mängida	doc_213943985079_item	2298903	et	3	main
hakkasin	doc_213943985079_item	2298905	et	3	main
tava	doc_213943985079_item	2298912	et	4	main
huvitanud	doc_213943985079_item	2298924	et	4	main
keelt	doc_213943985079_item	2298938	et	4	main
elasin	doc_213943985079_item	2298954	et	3	main
see	doc_213943985079_item	2298956	et	3	main
kõik	doc_213943985079_item	2298965	et	4	main
talvel	doc_213943985079_item	2298990	et	4	main
aga	doc_213943985079_item	2298997	et	3	main
lugu	doc_213943985079_item	2299001	et	4	main
täis	doc_213943985079_item	2299006	et	4	main
alguses	doc_213943985079_item	2299009	et	4	main
juures	doc_213943985079_item	2299019	et	4	main
sügisel	doc_213943985079_item	2299020	et	3	main
linna	doc_213943985079_item	2299031	et	4	main
mõtlesin	doc_213943985079_item	2299033	et	3	main
et	doc_213943985079_item	2299034	et	3	main
taha	doc_213943985079_item	2299036	et	4	main
sealt	doc_213943985079_item	2299037	et	4	main
elasin	doc_213943985079_item	2299043	et	3	main
mul	doc_213943985079_item	2299052	et	3	main
oma	doc_213943985079_item	2299054	et	4	main
tuba	doc_213943985079_item	2299056	et	4	main
ise	doc_213943985079_item	2299060	et	4	main
venemaal	doc_213943985079_item	2299065	et	4	main
ajal	doc_213943985079_item	2299091	et	4	main
osta	doc_213943985079_item	2299098	et	4	main
õunu	doc_213943985079_item	2299101	et	3	main
jalutada	doc_213943985079_item	2299107	et	3	main
lihtsalt	doc_213943985079_item	2299114	et	4	main
sõbradega	doc_213943985079_item	2299117	et	4	main
on	doc_213943985079_item	2299122	et	4	main
mu	doc_213943985079_item	2299124	et	3	main
elus	doc_213943985079_item	2299125	et	4	main
aeg	doc_213943985079_item	2299131	et	3	main
kuut	doc_213943985079_item	2299148	et	4	main
assistent	doc_213943985079_item	2299152	et	3	main
tegelikult	doc_213943985079_item	2299154	et	4	main
töötasin	doc_213943985079_item	2299159	et	3	main
käisin	doc_213943985079_item	2299163	et	3	main
või	doc_213943985079_item	2299174	et	4	main
kanaali	doc_213943985079_item	2299175	et	4	main
lammaste	doc_213943985079_item	2299177	et	3	main
häid	doc_213943985079_item	2299183	et	3	main
inglismaal	doc_213943985079_item	2299186	et	4	main
olnud	doc_213943985079_item	2299188	et	4	main
hakkasin	doc_213943985079_item	2299222	et	3	main
8	doc_213943985078_item	2298769	et	2	main
puuduseks	doc_213943985078_item	2298771	et	4	main
häirib	doc_213943985078_item	2298781	et	3	main
allapoole	doc_213943985078_item	2298789	et	3	main
laskumine	doc_213943985078_item	2298790	et	4	main
valmistada	doc_213943985078_item	2298794	et	3	main
reede	doc_213943985078_item	2298804	et	4	main
lillede	doc_213943985078_item	2298810	et	4	main
kauplus	doc_213943985078_item	2298811	et	3	main
minu	doc_213943985079_item	2298813	et	3	main
sündinud	doc_213943985079_item	2298817	et	4	main
soome	doc_213943985079_item	2298820	et	3	main
olen	doc_213943985079_item	2298821	et	3	main
sest	doc_213943985079_item	2298826	et	4	main
pole	doc_213943985079_item	2298828	et	3	main
lahku	doc_213943985079_item	2298834	et	4	main
kui	doc_213943985079_item	2298835	et	3	main
ma	doc_213943985079_item	2298836	et	3	main
kolmeaastane	doc_213943985079_item	2298838	et	4	main
sellepärast	doc_213943985079_item	2298844	et	3	main
ma	doc_213943985079_item	2298854	et	3	main
ei	doc_213943985079_item	2298856	et	4	main
mu	doc_213943985079_item	2298858	et	3	main
ema	doc_213943985079_item	2298859	et	4	main
ja	doc_213943985079_item	2298863	et	3	main
saaksin	doc_213943985079_item	2298879	et	3	main
klaverit	doc_213943985079_item	2298882	et	3	main
olin	doc_213943985079_item	2298890	et	3	main
tänu	doc_213943985079_item	2298896	et	4	main
kuna	doc_213943985079_item	2298897	et	3	main
mulle	doc_213943985079_item	2298898	et	4	main
kaheteistaastasena	doc_213943985079_item	2298904	et	4	main
mängima	doc_213943985079_item	2298908	et	3	main
käisin	doc_213943985079_item	2298910	et	3	main
oma	doc_213943985079_item	2298822	et	4	main
olin	doc_213943985079_item	2298837	et	3	main
ja	doc_213943985079_item	2298839	et	3	main
ongi	doc_213943985079_item	2298846	et	4	main
isa	doc_213943985079_item	2298853	et	4	main
ma	doc_213943985079_item	2298867	et	3	main
et	doc_213943985079_item	2298878	et	3	main
mulle	doc_213943985079_item	2298888	et	4	main
suur	doc_213943985079_item	2298895	et	3	main
flööti	doc_213943985079_item	2298907	et	4	main
muusikakoolis	doc_213943985079_item	2298911	et	4	main
kooli	doc_213943985079_item	2298913	et	4	main
lisaks	doc_213943985079_item	2298914	et	4	main
olgugi	doc_213943985079_item	2298918	et	4	main
lõppuni	doc_213943985079_item	2298917	et	3	main
et	doc_213943985079_item	2298919	et	3	main
vahepeale	doc_213943985079_item	2298920	et	3	main
muusikaga	doc_213943985079_item	2298925	et	3	main
2000	doc_213943985079_item	2298928	et	2	main
ja	doc_213943985079_item	2298932	et	3	main
ülikooli	doc_213943985079_item	2298936	et	4	main
vene	doc_213943985079_item	2298937	et	4	main
ja	doc_213943985079_item	2298942	et	3	main
kolisin	doc_213943985079_item	2298943	et	3	main
oli	doc_213943985079_item	2298958	et	3	main
sest	doc_213943985079_item	2298960	et	4	main
jaoks	doc_213943985079_item	2298968	et	4	main
harjunud	doc_213943985079_item	2298986	et	4	main
linnas	doc_213943985079_item	2298988	et	4	main
elama	doc_213943985079_item	2298989	et	3	main
teha	doc_213943985079_item	2298996	et	3	main
teine	doc_213943985079_item	2299000	et	3	main
linnast	doc_213943985079_item	2299012	et	4	main
vendi	doc_213943985079_item	2298831	et	4	main
vanemad	doc_213943985079_item	2298832	et	4	main
läksid	doc_213943985079_item	2298833	et	4	main
kahekesi	doc_213943985079_item	2298842	et	3	main
oma	doc_213943985079_item	2298852	et	4	main
on	doc_213943985079_item	2298860	et	4	main
kui	doc_213943985079_item	2298866	et	3	main
kaheksa	doc_213943985079_item	2298869	et	4	main
hakkasin	doc_213943985079_item	2298871	et	3	main
olin	doc_213943985079_item	2298874	et	3	main
kerjanud	doc_213943985079_item	2298877	et	4	main
muusikakooli	doc_213943985079_item	2298881	et	4	main
ja	doc_213943985079_item	2298884	et	3	main
ema	doc_213943985079_item	2298886	et	4	main
laskis	doc_213943985079_item	2298887	et	4	main
üliõnnelik	doc_213943985079_item	2298891	et	3	main
sellest	doc_213943985079_item	2298892	et	4	main
emale	doc_213943985079_item	2298894	et	3	main
veel	doc_213943985079_item	2298900	et	4	main
meeldib	doc_213943985079_item	2298901	et	3	main
klaverit	doc_213943985079_item	2298902	et	3	main
ja	doc_213943985079_item	2298909	et	3	main
keskkooli	doc_213943985079_item	2298916	et	4	main
üldse	doc_213943985079_item	2298922	et	3	main
minna	doc_213943985079_item	2298934	et	3	main
xxx	doc_213943985079_item	2298944	et	4	main
meelega	doc_213943985079_item	2298946	et	4	main
esimene	doc_213943985079_item	2298949	et	3	main
minu	doc_213943985079_item	2298951	et	3	main
kui	doc_213943985079_item	2298953	et	3	main
üksi	doc_213943985079_item	2298955	et	4	main
minu	doc_213943985079_item	2298967	et	3	main
midagi	doc_213943985079_item	2298994	et	4	main
suvi	doc_213943985079_item	2298998	et	3	main
suvel	doc_213943985079_item	2299003	et	3	main
turiste	doc_213943985079_item	2299007	et	3	main
ära	doc_213943985079_item	2299013	et	4	main
ja	doc_213943985079_item	2299014	et	3	main
elasin	doc_213943985079_item	2299015	et	3	main
selle	doc_213943985079_item	2299016	et	4	main
läksin	doc_213943985079_item	2299021	et	3	main
peterburis	doc_213943985079_item	2299025	et	4	main
minnagi	doc_213943985079_item	2299039	et	3	main
esimesed	doc_213943985079_item	2299040	et	3	main
kolisin	doc_213943985079_item	2299047	et	3	main
ühe	doc_213943985079_item	2299048	et	4	main
vana	doc_213943985079_item	2299049	et	4	main
väike	doc_213943985079_item	2299055	et	4	main
ja	doc_213943985079_item	2299057	et	3	main
köögis	doc_213943985079_item	2299058	et	3	main
tegin	doc_213943985079_item	2299059	et	3	main
sõidu	doc_213943985079_item	2299090	et	3	main
võib	doc_213943985079_item	2299118	et	3	main
mu	doc_213943985079_item	2299149	et	3	main
keedasin	doc_213943985079_item	2299166	et	4	main
kohvi	doc_213943985079_item	2299167	et	4	main
käisin	doc_213943985079_item	2299169	et	3	main
peenarel	doc_213943985079_item	2299176	et	4	main
töökaaslased	doc_213943985079_item	2299179	et	3	main
oli	doc_213943985079_item	2299180	et	3	main
aga	doc_213943985079_item	2299182	et	3	main
sõpru	doc_213943985079_item	2299184	et	3	main
ei	doc_213943985079_item	2298923	et	4	main
aastal	doc_213943985079_item	2298927	et	3	main
lõpetasin	doc_213943985079_item	2298929	et	3	main
õppima	doc_213943985079_item	2298939	et	3	main
vastuvõtueksami	doc_213943985079_item	2298941	et	3	main
oli	doc_213943985079_item	2298948	et	3	main
kord	doc_213943985079_item	2298950	et	4	main
elus	doc_213943985079_item	2298952	et	4	main
raske	doc_213943985079_item	2298959	et	4	main
võõrases	doc_213943985079_item	2298962	et	4	main
linnas	doc_213943985079_item	2298963	et	4	main
ja	doc_213943985079_item	2298964	et	3	main
oli	doc_213943985079_item	2298966	et	3	main
uut	doc_213943985079_item	2298969	et	3	main
õnneks	doc_213943985079_item	2298970	et	4	main
sain	doc_213943985079_item	2298971	et	3	main
tuttavaks	doc_213943985079_item	2298972	et	4	main
toredate	doc_213943985079_item	2298973	et	3	main
inimestega	doc_213943985079_item	2298974	et	3	main
ja	doc_213943985079_item	2298975	et	3	main
mulle	doc_213943985079_item	2298976	et	4	main
meeldis	doc_213943985079_item	2298977	et	3	main
õppida	doc_213943985079_item	2298978	et	3	main
linn	doc_213943985079_item	2298979	et	3	main
mulle	doc_213943985079_item	2298980	et	4	main
eriti	doc_213943985079_item	2298981	et	3	main
ei	doc_213943985079_item	2298982	et	4	main
meeldinud	doc_213943985079_item	2298983	et	4	main
sest	doc_213943985079_item	2298984	et	4	main
olin	doc_213943985079_item	2298985	et	3	main
ei	doc_213943985079_item	2298992	et	4	main
olnud	doc_213943985079_item	2298993	et	4	main
sest	doc_213943985079_item	2299002	et	4	main
linn	doc_213943985079_item	2299004	et	3	main
suve	doc_213943985079_item	2299008	et	4	main
ikkagi	doc_213943985079_item	2299010	et	4	main
kolisin	doc_213943985079_item	2299011	et	3	main
suve	doc_213943985079_item	2299017	et	4	main
ema	doc_213943985079_item	2299018	et	4	main
venemaale	doc_213943985079_item	2299022	et	4	main
väga	doc_213943985079_item	2299027	et	3	main
seda	doc_213943985079_item	2299030	et	3	main
ei	doc_213943985079_item	2299035	et	4	main
ära	doc_213943985079_item	2299038	et	4	main
ühiselamus	doc_213943985079_item	2299044	et	4	main
aga	doc_213943985079_item	2299045	et	3	main
süüa	doc_213943985079_item	2299062	et	3	main
ajalehte	doc_213943985079_item	2299089	et	4	main
ka	doc_213943985079_item	2299094	et	3	main
turul	doc_213943985079_item	2299096	et	3	main
lõunamaalaste	doc_213943985079_item	2299102	et	4	main
müüjade	doc_213943985079_item	2299103	et	4	main
mulle	doc_213943985079_item	2299105	et	4	main
käia	doc_213943985079_item	2299109	et	4	main
teateris	doc_213943985079_item	2299111	et	3	main
kontsertedel	doc_213943985079_item	2299112	et	4	main
või	doc_213943985079_item	2299113	et	4	main
aasta	doc_213943985079_item	2299121	et	4	main
elasin	doc_213943985079_item	2299132	et	3	main
venemaal	doc_213943985079_item	2299133	et	4	main
ja	doc_213943985079_item	2299136	et	3	main
peale	doc_213943985079_item	2299138	et	4	main
seda	doc_213943985079_item	2299139	et	3	main
läksin	doc_213943985079_item	2299140	et	3	main
tegin	doc_213943985079_item	2299155	et	3	main
asja	doc_213943985079_item	2299157	et	4	main
arvutis	doc_213943985079_item	2299160	et	4	main
vahepeale	doc_213943985079_item	2299161	et	3	main
poes	doc_213943985079_item	2299164	et	3	main
teid	doc_213943985079_item	2299173	et	4	main
mul	doc_213943985079_item	2299185	et	3	main
ei	doc_213943985079_item	2299187	et	4	main
soomes	doc_213943985079_item	2299226	et	4	main
on	doc_213943985079_item	2299227	et	4	main
raske	doc_213943985079_item	2299228	et	4	main
endale	doc_213943985079_item	2299230	et	4	main
aga	doc_213943985079_item	2299232	et	3	main
kaks	doc_213943985079_item	2299240	et	3	main
tallinnas	doc_213943985079_item	2299259	et	4	main
ja	doc_213943985079_item	2299260	et	3	main
elangi	doc_213943985079_item	2299268	et	3	main
pedagoogika	doc_213943985079_item	2299275	et	4	main
keelt	doc_213943985079_item	2299278	et	4	main
lõpuni	doc_213943985079_item	2299284	et	3	main
kirjuta	doc_213943985080_item	2299287	et	4	main
lünka	doc_213943985080_item	2299288	et	4	main
sulgudes	doc_213943985080_item	2299289	et	4	main
olev	doc_213943985080_item	2299290	et	4	main
käib	doc_213943985080_item	2299296	et	3	main
eest	doc_213943985080_item	2299303	et	4	main
pangakaartiga	doc_213943985080_item	2299305	et	4	main
kodus	doc_213943985080_item	2299306	et	4	main
koristab	doc_213943985080_item	2299308	et	3	main
ja	doc_213943985080_item	2299310	et	3	main
toas	doc_213943985080_item	2299314	et	3	main
väikevend	doc_213943985080_item	2299321	et	3	main
tema	doc_213943985080_item	2299328	et	4	main
teid	doc_213943985080_item	2299329	et	4	main
on	doc_213943985080_item	2299334	et	4	main
minu	doc_213943985080_item	2299335	et	3	main
isa	doc_213943985080_item	2299336	et	4	main
täida	doc_213943985080_item	2299344	et	4	main
sobiva	doc_213943985080_item	2299346	et	4	main
ma-	doc_213943985080_item	2299348	et	3	main
seda	doc_213943985080_item	2299360	et	3	main
vaja	doc_213943985080_item	2299367	et	4	main
läheme	doc_213943985080_item	2299370	et	3	main
vanaema	doc_213943985080_item	2299372	et	4	main
rääkima	doc_213943985080_item	2299417	et	3	main
käima	doc_213943985080_item	2299419	et	4	main
reisil	doc_213943985080_item	2299428	et	3	main
uus	doc_213943985080_item	2299430	et	3	main
mulle	doc_213943985079_item	2299026	et	4	main
armustasin	doc_213943985079_item	2299029	et	3	main
ja	doc_213943985079_item	2299032	et	3	main
kolm	doc_213943985079_item	2299041	et	3	main
siis	doc_213943985079_item	2299046	et	3	main
naise	doc_213943985079_item	2299050	et	3	main
mõned	doc_213943985079_item	2299063	et	3	main
oli	doc_213943985079_item	2299066	et	3	main
kummalised	doc_213943985079_item	2299067	et	3	main
minu	doc_213943985079_item	2299068	et	3	main
jaoks	doc_213943985079_item	2299069	et	4	main
aga	doc_213943985079_item	2299070	et	3	main
siiski	doc_213943985079_item	2299071	et	4	main
vene	doc_213943985079_item	2299072	et	4	main
eluviis	doc_213943985079_item	2299073	et	3	main
ja	doc_213943985079_item	2299074	et	3	main
kultuur	doc_213943985079_item	2299075	et	3	main
mulle	doc_213943985079_item	2299076	et	4	main
meeldis	doc_213943985079_item	2299077	et	3	main
mulle	doc_213943985079_item	2299078	et	4	main
meeldis	doc_213943985079_item	2299079	et	3	main
metrooga	doc_213943985079_item	2299080	et	3	main
sõita	doc_213943985079_item	2299081	et	3	main
vaatada	doc_213943985079_item	2299082	et	4	main
metroojaama	doc_213943985079_item	2299083	et	4	main
eskalaatoris	doc_213943985079_item	2299084	et	3	main
ning	doc_213943985079_item	2299086	et	3	main
oli	doc_213943985079_item	2299053	et	3	main
endale	doc_213943985079_item	2299061	et	4	main
asjad	doc_213943985079_item	2299064	et	3	main
inimesi	doc_213943985079_item	2299085	et	4	main
lugeda	doc_213943985079_item	2299087	et	3	main
metroos	doc_213943985079_item	2299088	et	3	main
meeldis	doc_213943985079_item	2299093	et	3	main
käia	doc_213943985079_item	2299095	et	4	main
meeldis	doc_213943985079_item	2299106	et	3	main
mariinski	doc_213943985079_item	2299110	et	4	main
istuda	doc_213943985079_item	2299115	et	3	main
olla	doc_213943985079_item	2299119	et	3	main
mulle	doc_213943985079_item	2299092	et	4	main
ja	doc_213943985079_item	2299097	et	3	main
hapukurke	doc_213943985079_item	2299099	et	3	main
ja	doc_213943985079_item	2299100	et	3	main
juurest	doc_213943985079_item	2299104	et	4	main
nevskil	doc_213943985079_item	2299108	et	4	main
kohvikus	doc_213943985079_item	2299116	et	3	main
peterburi	doc_213943985079_item	2299120	et	4	main
siiamaani	doc_213943985079_item	2299126	et	3	main
kõige	doc_213943985079_item	2299127	et	4	main
õnnelikum	doc_213943985079_item	2299128	et	4	main
ja	doc_213943985079_item	2299129	et	3	main
muretum	doc_213943985079_item	2299130	et	4	main
tiitel	doc_213943985079_item	2299150	et	3	main
oli	doc_213943985079_item	2299151	et	3	main
koristasin	doc_213943985079_item	2299162	et	3	main
või	doc_213943985079_item	2299165	et	4	main
hulgas	doc_213943985079_item	2299178	et	4	main
sõbralikud	doc_213943985079_item	2299181	et	3	main
mõnikord	doc_213943985079_item	2299190	et	3	main
ja	doc_213943985079_item	2299221	et	3	main
ka	doc_213943985079_item	2299223	et	3	main
leida	doc_213943985079_item	2299229	et	3	main
büroodes	doc_213943985079_item	2299236	et	3	main
linnas	doc_213943985079_item	2299243	et	4	main
lähen	doc_213943985079_item	2299248	et	3	main
vanemad	doc_213943985079_item	2299257	et	4	main
elasid	doc_213943985079_item	2299258	et	4	main
toa	doc_213943985079_item	2299264	et	3	main
üürile	doc_213943985079_item	2299265	et	3	main
praegu	doc_213943985079_item	2299267	et	3	main
nende	doc_213943985079_item	2299269	et	4	main
lasnamäel	doc_213943985079_item	2299271	et	3	main
ja	doc_213943985079_item	2299272	et	3	main
vene	doc_213943985079_item	2299277	et	4	main
kevadsemestri	doc_213943985079_item	2299283	et	3	main
ema	doc_213943985080_item	2299295	et	4	main
hoolitseb	doc_213943985080_item	2299315	et	3	main
ka	doc_213943985080_item	2299325	et	3	main
kui	doc_213943985080_item	2299330	et	3	main
käib	doc_213943985080_item	2299337	et	3	main
komandeering	doc_213943985080_item	2299339	et	3	main
või	doc_213943985080_item	2299349	et	4	main
infinitiivi	doc_213943985080_item	2299351	et	4	main
vormis	doc_213943985080_item	2299352	et	4	main
kas	doc_213943985080_item	2299353	et	3	main
peaks	doc_213943985080_item	2299361	et	4	main
sinu	doc_213943985080_item	2299362	et	3	main
tohi	doc_213943985080_item	2299376	et	4	main
käima	doc_213943985080_item	2299377	et	4	main
minema	doc_213943985080_item	2299415	et	3	main
lugema	doc_213943985080_item	2299418	et	4	main
nägin	doc_213943985080_item	2299427	et	3	main
maa	doc_213943985080_item	2299431	et	4	main
maad	doc_213943985080_item	2299433	et	4	main
ääres	doc_213943985080_item	2299435	et	4	main
oli	doc_213943985080_item	2299436	et	3	main
linn	doc_213943985080_item	2299443	et	3	main
metsad	doc_213943985080_item	2299444	et	3	main
4	doc_213943985080_item	2299459	et	2	main
pane	doc_213943985080_item	2299460	et	4	main
olevad	doc_213943985080_item	2299462	et	4	main
sõnad	doc_213943985080_item	2299463	et	4	main
ainsuse	doc_213943985080_item	2299464	et	4	main
õpetaja	doc_213943985080_item	2299469	et	4	main
endise	doc_213943985080_item	2299470	et	3	main
õpetaja	doc_213943985080_item	2299471	et	4	main
liigse	doc_213943985080_item	2299506	et	3	main
5	doc_213943985080_item	2299508	et	2	main
sõpra	doc_213943985080_item	2299515	et	4	main
külla	doc_213943985080_item	2299516	et	4	main
ostan	doc_213943985080_item	2299517	et	3	main
tordi	doc_213943985080_item	2299519	et	3	main
olnud	doc_213943985079_item	2299123	et	4	main
üheksa	doc_213943985079_item	2299134	et	4	main
kuud	doc_213943985079_item	2299135	et	4	main
ruttu	doc_213943985079_item	2299137	et	4	main
inglismaale	doc_213943985079_item	2299141	et	4	main
tööle	doc_213943985079_item	2299142	et	3	main
töötasin	doc_213943985079_item	2299143	et	3	main
seal	doc_213943985079_item	2299144	et	4	main
väikeses	doc_213943985079_item	2299145	et	4	main
külas	doc_213943985079_item	2299146	et	3	main
kaks	doc_213943985079_item	2299147	et	3	main
aga	doc_213943985079_item	2299153	et	3	main
igasuguseid	doc_213943985079_item	2299156	et	3	main
vahepeale	doc_213943985079_item	2299158	et	3	main
õhtuti	doc_213943985079_item	2299168	et	3	main
jooksmas	doc_213943985079_item	2299170	et	3	main
mööda	doc_213943985079_item	2299171	et	4	main
kitsaid	doc_213943985079_item	2299172	et	3	main
ja	doc_213943985079_item	2299189	et	3	main
tundsin	doc_213943985079_item	2299191	et	3	main
end	doc_213943985079_item	2299192	et	4	main
ning	doc_213943985079_item	2299194	et	3	main
kurvastasin	doc_213943985079_item	2299195	et	3	main
natuke	doc_213943985079_item	2299196	et	4	main
selle	doc_213943985079_item	2299197	et	4	main
üksikuks	doc_213943985079_item	2299193	et	4	main
aasta	doc_213943985079_item	2299198	et	4	main
augustis	doc_213943985079_item	2299199	et	3	main
tulin	doc_213943985079_item	2299200	et	3	main
tagasi	doc_213943985079_item	2299201	et	3	main
soome	doc_213943985079_item	2299202	et	3	main
ja	doc_213943985079_item	2299203	et	3	main
kolisin	doc_213943985079_item	2299204	et	3	main
xxx	doc_213943985079_item	2299205	et	4	main
jätkasin	doc_213943985079_item	2299206	et	3	main
oma	doc_213943985079_item	2299207	et	4	main
õpinguid	doc_213943985079_item	2299208	et	3	main
seal	doc_213943985079_item	2299209	et	4	main
linnas	doc_213943985079_item	2299210	et	4	main
mulle	doc_213943985079_item	2299211	et	4	main
väga	doc_213943985079_item	2299212	et	3	main
meeldis	doc_213943985079_item	2299213	et	3	main
elada	doc_213943985079_item	2299214	et	3	main
ning	doc_213943985079_item	2299215	et	3	main
õppida	doc_213943985079_item	2299216	et	3	main
leidsin	doc_213943985079_item	2299217	et	3	main
sõpru	doc_213943985079_item	2299218	et	3	main
ja	doc_213943985079_item	2299219	et	3	main
harrastusi	doc_213943985079_item	2299220	et	4	main
tööl	doc_213943985079_item	2299224	et	3	main
tööd	doc_213943985079_item	2299231	et	4	main
mina	doc_213943985079_item	2299233	et	4	main
aga	doc_213943985079_item	2299244	et	3	main
käima	doc_213943985079_item	2299225	et	4	main
hakkasin	doc_213943985079_item	2299234	et	3	main
korda	doc_213943985079_item	2299238	et	4	main
tallinnasse	doc_213943985079_item	2299249	et	3	main
linnas	doc_213943985079_item	2299251	et	4	main
mulle	doc_213943985079_item	2299263	et	4	main
anda	doc_213943985079_item	2299266	et	3	main
tallinna	doc_213943985079_item	2299274	et	4	main
ning	doc_213943985079_item	2299279	et	3	main
ja	doc_213943985080_item	2299300	et	3	main
ostude	doc_213943985080_item	2299302	et	3	main
pangakaart	doc_213943985080_item	2299304	et	4	main
toad	doc_213943985080_item	2299311	et	3	main
eest	doc_213943985080_item	2299318	et	4	main
aitab	doc_213943985080_item	2299319	et	3	main
väikevenda	doc_213943985080_item	2299322	et	4	main
teha	doc_213943985080_item	2299323	et	3	main
abistan	doc_213943985080_item	2299327	et	3	main
mina	doc_213943985080_item	2299331	et	4	main
mul	doc_213943985080_item	2299332	et	3	main
aega	doc_213943985080_item	2299333	et	4	main
komandeering	doc_213943985080_item	2299341	et	3	main
välismaalase	doc_213943985080_item	2299342	et	3	main
da-	doc_213943985080_item	2299350	et	4	main
te	doc_213943985080_item	2299354	et	4	main
mulle	doc_213943985080_item	2299356	et	4	main
postkontorisse	doc_213943985080_item	2299368	et	3	main
ei	doc_213943985080_item	2299375	et	4	main
tahan	doc_213943985080_item	2299379	et	3	main
hilinema	doc_213943985080_item	2299412	et	3	main
tegema	doc_213943985080_item	2299414	et	3	main
tulema	doc_213943985080_item	2299416	et	4	main
osastavasse	doc_213943985080_item	2299426	et	4	main
uued	doc_213943985080_item	2299432	et	3	main
jõgi	doc_213943985080_item	2299438	et	3	main
ja	doc_213943985080_item	2299441	et	3	main
sulgudes	doc_213943985080_item	2299461	et	4	main
oma	doc_213943985080_item	2299467	et	4	main
kas	doc_213943985080_item	2299474	et	3	main
ma	doc_213943985080_item	2299512	et	3	main
ja	doc_213943985080_item	2299520	et	3	main
ise	doc_213943985080_item	2299522	et	4	main
keedan	doc_213943985080_item	2299524	et	3	main
pean	doc_213943985080_item	2299544	et	4	main
tee	doc_213943985080_item	2299546	et	4	main
keetma	doc_213943985080_item	2299547	et	3	main
kuulame	doc_213943985080_item	2299555	et	4	main
ma	doc_213943985080_item	2299557	et	3	main
ja	doc_213943985080_item	2299565	et	3	main
tegisin	doc_213943985080_item	2299566	et	4	main
ise	doc_213943985080_item	2299567	et	4	main
joonud	doc_213943985080_item	2299575	et	4	main
jääs	doc_213943985080_item	2299579	et	3	main
hiljaks	doc_213943985080_item	2299580	et	3	main
tee	doc_213943985080_item	2299582	et	4	main
uue	doc_213943985080_item	2299590	et	3	main
ta	doc_213943985080_item	2299594	et	4	main
head	doc_213943985080_item	2299597	et	4	main
lünka	doc_213943985081_item	2299605	et	4	main
sulgudes	doc_213943985081_item	2299606	et	4	main
ja	doc_213943985081_item	2299630	et	3	main
lillide	doc_213943985081_item	2299634	et	3	main
väikevend	doc_213943985081_item	2299638	et	3	main
teha	doc_213943985081_item	2299640	et	3	main
koolitööd	doc_213943985081_item	2299641	et	4	main
on	doc_213943985081_item	2299651	et	4	main
minu	doc_213943985081_item	2299652	et	3	main
isa	doc_213943985081_item	2299653	et	4	main
komandeering	doc_213943985081_item	2299656	et	3	main
lüngad	doc_213943985081_item	2299662	et	3	main
ma-	doc_213943985081_item	2299665	et	3	main
hilineda	doc_213943985081_item	2299694	et	3	main
ma	doc_213943985081_item	2299703	et	3	main
eesti	doc_213943985081_item	2299705	et	4	main
hästi	doc_213943985081_item	2299707	et	3	main
sul	doc_213943985081_item	2299709	et	3	main
kohe	doc_213943985081_item	2299711	et	4	main
minna	doc_213943985081_item	2299714	et	3	main
täna	doc_213943985081_item	2299722	et	4	main
teha	doc_213943985081_item	2299724	et	3	main
järgmisi	doc_213943985081_item	2299726	et	3	main
vaatama	doc_213943985081_item	2299728	et	3	main
koristama	doc_213943985079_item	2299235	et	3	main
paar	doc_213943985079_item	2299237	et	3	main
nädalas	doc_213943985079_item	2299239	et	3	main
aastat	doc_213943985079_item	2299241	et	3	main
otsustasin	doc_213943985079_item	2299246	et	3	main
vahetusõpilaseeks	doc_213943985079_item	2299250	et	3	main
eesti	doc_213943985079_item	2299254	et	4	main
tüdrukuga	doc_213943985079_item	2299255	et	3	main
kelle	doc_213943985079_item	2299256	et	4	main
olid	doc_213943985079_item	2299261	et	4	main
nõus	doc_213943985079_item	2299262	et	4	main
juures	doc_213943985079_item	2299270	et	4	main
õpin	doc_213943985079_item	2299273	et	3	main
harjutus	doc_213943985080_item	2299285	et	4	main
sõna	doc_213943985080_item	2299291	et	4	main
õiges	doc_213943985080_item	2299292	et	3	main
vormis	doc_213943985080_item	2299293	et	4	main
mu	doc_213943985080_item	2299294	et	3	main
maksimarket	doc_213943985080_item	2299298	et	4	main
maksimarketis	doc_213943985080_item	2299299	et	4	main
köök	doc_213943985080_item	2299309	et	3	main
köögis	doc_213943985080_item	2299312	et	3	main
lilled	doc_213943985080_item	2299316	et	3	main
elasin	doc_213943985079_item	2299242	et	3	main
siis	doc_213943985079_item	2299245	et	3	main
et	doc_213943985079_item	2299247	et	3	main
sain	doc_213943985079_item	2299252	et	3	main
tuttavaks	doc_213943985079_item	2299253	et	4	main
ülikoolis	doc_213943985079_item	2299276	et	4	main
eesti	doc_213943985079_item	2299280	et	4	main
keelt	doc_213943985079_item	2299281	et	4	main
kuni	doc_213943985079_item	2299282	et	3	main
1	doc_213943985080_item	2299286	et	2	main
sageli	doc_213943985080_item	2299297	et	3	main
maksab	doc_213943985080_item	2299301	et	3	main
ta	doc_213943985080_item	2299307	et	4	main
ja	doc_213943985080_item	2299313	et	3	main
lillede	doc_213943985080_item	2299317	et	4	main
minu	doc_213943985080_item	2299320	et	3	main
mina	doc_213943985080_item	2299326	et	4	main
lüngad	doc_213943985080_item	2299345	et	3	main
saate	doc_213943985080_item	2299355	et	4	main
appi	doc_213943985080_item	2299357	et	4	main
asemel	doc_213943985080_item	2299363	et	4	main
vaadata	doc_213943985080_item	2299364	et	4	main
mul	doc_213943985080_item	2299365	et	3	main
on	doc_213943985080_item	2299366	et	4	main
tundi	doc_213943985080_item	2299374	et	4	main
tegusõnu	doc_213943985080_item	2299410	et	3	main
3	doc_213943985080_item	2299420	et	2	main
koolitööd	doc_213943985080_item	2299324	et	4	main
tihti	doc_213943985080_item	2299338	et	3	main
välismaa	doc_213943985080_item	2299340	et	4	main
2	doc_213943985080_item	2299343	et	2	main
tegusõnaga	doc_213943985080_item	2299347	et	3	main
olla	doc_213943985080_item	2299358	et	3	main
kes	doc_213943985080_item	2299359	et	4	main
minna	doc_213943985080_item	2299369	et	3	main
õhtul	doc_213943985080_item	2299371	et	3	main
lugeda	doc_213943985080_item	2299373	et	3	main
ma	doc_213943985080_item	2299378	et	3	main
veel	doc_213943985080_item	2299380	et	4	main
natuke	doc_213943985080_item	2299381	et	4	main
üleval	doc_213943985080_item	2299382	et	4	main
minema	doc_213943985080_item	2299383	et	3	main
ja	doc_213943985080_item	2299384	et	3	main
vaadata	doc_213943985080_item	2299385	et	4	main
ma	doc_213943985080_item	2299386	et	3	main
õpin	doc_213943985080_item	2299387	et	3	main
eesti	doc_213943985080_item	2299388	et	4	main
keelt	doc_213943985080_item	2299389	et	4	main
hästi	doc_213943985080_item	2299390	et	3	main
rääkida	doc_213943985080_item	2299391	et	3	main
sul	doc_213943985080_item	2299392	et	3	main
tuleb	doc_213943985080_item	2299393	et	3	main
kohe	doc_213943985080_item	2299394	et	4	main
poes	doc_213943985080_item	2299395	et	3	main
ära	doc_213943985080_item	2299396	et	4	main
sest	doc_213943985080_item	2299398	et	4	main
hilinema	doc_213943985080_item	2299397	et	3	main
varsti	doc_213943985080_item	2299399	et	3	main
see	doc_213943985080_item	2299400	et	3	main
suletakse	doc_213943985080_item	2299401	et	4	main
mida	doc_213943985080_item	2299402	et	4	main
sa	doc_213943985080_item	2299403	et	3	main
kavatsed	doc_213943985080_item	2299404	et	3	main
täna	doc_213943985080_item	2299405	et	4	main
õhtul	doc_213943985080_item	2299406	et	3	main
tegema	doc_213943985080_item	2299407	et	3	main
kasuta	doc_213943985080_item	2299408	et	4	main
järgmisi	doc_213943985080_item	2299409	et	3	main
vaatama	doc_213943985080_item	2299411	et	3	main
olema	doc_213943985080_item	2299413	et	4	main
pane	doc_213943985080_item	2299421	et	4	main
olevad	doc_213943985080_item	2299423	et	4	main
sõnad	doc_213943985080_item	2299424	et	4	main
mitmuse	doc_213943985080_item	2299425	et	3	main
palju	doc_213943985080_item	2299429	et	4	main
vana	doc_213943985080_item	2299442	et	4	main
jõgid	doc_213943985080_item	2299445	et	4	main
mägid	doc_213943985080_item	2299447	et	4	main
linnad	doc_213943985080_item	2299450	et	3	main
võõras	doc_213943985080_item	2299455	et	4	main
keel	doc_213943985080_item	2299456	et	4	main
osastavasse	doc_213943985080_item	2299465	et	4	main
kohtasin	doc_213943985080_item	2299466	et	3	main
endine	doc_213943985080_item	2299468	et	3	main
te	doc_213943985080_item	2299475	et	4	main
olevik	doc_213943985080_item	2299510	et	3	main
oma	doc_213943985080_item	2299514	et	4	main
võileibu	doc_213943985080_item	2299523	et	3	main
ka	doc_213943985080_item	2299525	et	3	main
teed	doc_213943985080_item	2299526	et	4	main
joo	doc_213943985080_item	2299530	et	4	main
uue	doc_213943985080_item	2299545	et	3	main
aga	doc_213943985080_item	2299548	et	3	main
ta	doc_213943985080_item	2299549	et	4	main
hilisõhtuni	doc_213943985080_item	2299556	et	3	main
oma	doc_213943985080_item	2299559	et	4	main
võileibu	doc_213943985080_item	2299568	et	3	main
teed	doc_213943985080_item	2299571	et	4	main
tee	doc_213943985080_item	2299591	et	4	main
mida	doc_213943985080_item	2299599	et	4	main
vormis	doc_213943985081_item	2299610	et	4	main
mu	doc_213943985081_item	2299611	et	3	main
ema	doc_213943985081_item	2299612	et	4	main
sulgudes	doc_213943985080_item	2299422	et	4	main
tee	doc_213943985080_item	2299434	et	4	main
ja	doc_213943985080_item	2299448	et	3	main
hea	doc_213943985080_item	2299451	et	4	main
oleks	doc_213943985080_item	2299452	et	3	main
osata	doc_213943985080_item	2299453	et	4	main
ka	doc_213943985080_item	2299454	et	3	main
keeled	doc_213943985080_item	2299458	et	3	main
ja	doc_213943985080_item	2299472	et	3	main
tunnete	doc_213943985080_item	2299476	et	4	main
veel	doc_213943985080_item	2299477	et	4	main
see	doc_213943985080_item	2299478	et	3	main
poiss	doc_213943985080_item	2299479	et	3	main
seda	doc_213943985080_item	2299480	et	3	main
poisi	doc_213943985080_item	2299481	et	3	main
vaatas	doc_213943985080_item	2299483	et	3	main
mina	doc_213943985080_item	2299484	et	4	main
mind	doc_213943985080_item	2299485	et	4	main
õpetaja	doc_213943985080_item	2299482	et	4	main
ja	doc_213943985080_item	2299486	et	3	main
naeratas	doc_213943985080_item	2299487	et	3	main
ma	doc_213943985080_item	2299488	et	3	main
ei	doc_213943985080_item	2299489	et	4	main
mäleta	doc_213943985080_item	2299490	et	4	main
küll	doc_213943985080_item	2299491	et	4	main
sinu	doc_213943985080_item	2299492	et	3	main
nimi	doc_213943985080_item	2299493	et	3	main
sinu	doc_213943985080_item	2299494	et	3	main
nimi	doc_213943985080_item	2299495	et	3	main
aga	doc_213943985080_item	2299496	et	3	main
mäletan	doc_213943985080_item	2299497	et	3	main
sinu	doc_213943985080_item	2299498	et	3	main
halb	doc_213943985080_item	2299499	et	3	main
käekiri	doc_213943985080_item	2299500	et	3	main
halb	doc_213943985080_item	2299501	et	3	main
käekirja	doc_213943985080_item	2299502	et	4	main
ja	doc_213943985080_item	2299503	et	3	main
liigne	doc_213943985080_item	2299504	et	3	main
mets	doc_213943985080_item	2299437	et	3	main
järv	doc_213943985080_item	2299439	et	3	main
mägi	doc_213943985080_item	2299440	et	3	main
järvid	doc_213943985080_item	2299446	et	3	main
vanad	doc_213943985080_item	2299449	et	3	main
võõrased	doc_213943985080_item	2299457	et	4	main
küsisin	doc_213943985080_item	2299473	et	3	main
lobisemise	doc_213943985080_item	2299507	et	4	main
asenda	doc_213943985080_item	2299509	et	4	main
minevikuga	doc_213943985080_item	2299511	et	3	main
ootan	doc_213943985080_item	2299513	et	3	main
kohvikust	doc_213943985080_item	2299518	et	4	main
sõber	doc_213943985080_item	2299528	et	3	main
ta	doc_213943985080_item	2299541	et	4	main
lõpuks	doc_213943985080_item	2299542	et	4	main
tuleb	doc_213943985080_item	2299543	et	3	main
toob	doc_213943985080_item	2299550	et	3	main
ootasin	doc_213943985080_item	2299558	et	3	main
keedasin	doc_213943985080_item	2299569	et	4	main
kohvi	doc_213943985080_item	2299576	et	4	main
ta	doc_213943985080_item	2299578	et	4	main
ja	doc_213943985080_item	2299581	et	3	main
jahtus	doc_213943985080_item	2299583	et	3	main
ära	doc_213943985080_item	2299584	et	4	main
toos	doc_213943985080_item	2299595	et	3	main
kuulasime	doc_213943985080_item	2299600	et	3	main
hilisõhtuni	doc_213943985080_item	2299601	et	3	main
olev	doc_213943985081_item	2299607	et	4	main
sõna	doc_213943985081_item	2299608	et	4	main
köök	doc_213943985081_item	2299626	et	3	main
ja	doc_213943985081_item	2299627	et	3	main
lilled	doc_213943985081_item	2299633	et	3	main
ka	doc_213943985081_item	2299642	et	3	main
täida	doc_213943985081_item	2299661	et	4	main
või	doc_213943985081_item	2299666	et	4	main
vaja	doc_213943985081_item	2299684	et	4	main
postkontorisse	doc_213943985081_item	2299685	et	3	main
õhtul	doc_213943985081_item	2299688	et	3	main
ma	doc_213943985081_item	2299695	et	3	main
tahan	doc_213943985081_item	2299696	et	3	main
ja	doc_213943985081_item	2299701	et	3	main
keelt	doc_213943985081_item	2299706	et	4	main
lobisemine	doc_213943985080_item	2299505	et	4	main
teen	doc_213943985080_item	2299521	et	3	main
ei	doc_213943985080_item	2299529	et	4	main
kohvi	doc_213943985080_item	2299531	et	4	main
ta	doc_213943985080_item	2299533	et	4	main
jääb	doc_213943985080_item	2299534	et	3	main
hiljaks	doc_213943985080_item	2299535	et	3	main
ja	doc_213943985080_item	2299536	et	3	main
jahtub	doc_213943985080_item	2299538	et	3	main
ära	doc_213943985080_item	2299539	et	4	main
kui	doc_213943985080_item	2299540	et	3	main
kaasa	doc_213943985080_item	2299551	et	4	main
head	doc_213943985080_item	2299552	et	4	main
muusikat	doc_213943985080_item	2299553	et	3	main
mida	doc_213943985080_item	2299554	et	4	main
külla	doc_213943985080_item	2299561	et	4	main
ostasin	doc_213943985080_item	2299562	et	4	main
kohvikust	doc_213943985080_item	2299563	et	4	main
tordi	doc_213943985080_item	2299564	et	3	main
kahjuks	doc_213943985080_item	2299577	et	4	main
aga	doc_213943985080_item	2299593	et	3	main
harjutus	doc_213943985081_item	2299602	et	4	main
pangakaart	doc_213943985081_item	2299621	et	4	main
kodus	doc_213943985081_item	2299623	et	4	main
toad	doc_213943985081_item	2299628	et	3	main
toad	doc_213943985081_item	2299631	et	3	main
minu	doc_213943985081_item	2299637	et	3	main
mina	doc_213943985081_item	2299643	et	4	main
kui	doc_213943985081_item	2299647	et	3	main
aega	doc_213943985081_item	2299650	et	4	main
välismaale	doc_213943985081_item	2299659	et	4	main
minna	doc_213943985081_item	2299686	et	3	main
vanaema	doc_213943985081_item	2299689	et	4	main
külastama	doc_213943985081_item	2299690	et	3	main
tundi	doc_213943985081_item	2299691	et	4	main
ei	doc_213943985081_item	2299692	et	4	main
veel	doc_213943985081_item	2299697	et	4	main
natuke	doc_213943985081_item	2299698	et	4	main
õpin	doc_213943985081_item	2299704	et	3	main
olema	doc_213943985081_item	2299730	et	4	main
minema	doc_213943985081_item	2299732	et	3	main
tulema	doc_213943985081_item	2299733	et	4	main
lugema	doc_213943985081_item	2299735	et	4	main
sulgudes	doc_213943985081_item	2299739	et	4	main
uus	doc_213943985081_item	2299747	et	3	main
maa	doc_213943985081_item	2299748	et	4	main
oli	doc_213943985081_item	2299753	et	3	main
mägi	doc_213943985081_item	2299757	et	3	main
vana	doc_213943985081_item	2299759	et	4	main
osastavasse	doc_213943985081_item	2299781	et	4	main
te	doc_213943985081_item	2299791	et	4	main
õpetaja	doc_213943985081_item	2299798	et	4	main
küll	doc_213943985081_item	2299807	et	4	main
sinu	doc_213943985081_item	2299808	et	3	main
nimi	doc_213943985081_item	2299809	et	3	main
halba	doc_213943985081_item	2299817	et	4	main
ja	doc_213943985081_item	2299819	et	3	main
asenda	doc_213943985081_item	2299825	et	4	main
kohvikust	doc_213943985081_item	2299834	et	4	main
ja	doc_213943985081_item	2299836	et	3	main
ise	doc_213943985081_item	2299838	et	4	main
sest	doc_213943985081_item	2299843	et	4	main
joo	doc_213943985081_item	2299846	et	4	main
kohvi	doc_213943985081_item	2299847	et	4	main
kahjuks	doc_213943985081_item	2299848	et	4	main
ära	doc_213943985081_item	2299855	et	4	main
pean	doc_213943985081_item	2299860	et	4	main
tee	doc_213943985081_item	2299862	et	4	main
külla	doc_213943985081_item	2299877	et	4	main
kuulasime	doc_213943985081_item	2299916	et	3	main
hilisõhtuni	doc_213943985081_item	2299917	et	3	main
1	doc_213943985082_item	2299919	et	2	main
kirjuta	doc_213943985082_item	2299920	et	4	main
lünka	doc_213943985082_item	2299921	et	4	main
maksimarketis	doc_213943985082_item	2299932	et	4	main
ostude	doc_213943985082_item	2299935	et	3	main
koristab	doc_213943985082_item	2299941	et	3	main
köök	doc_213943985082_item	2299942	et	3	main
ja	doc_213943985082_item	2299943	et	3	main
hoolitseb	doc_213943985082_item	2299948	et	3	main
ka	doc_213943985082_item	2299958	et	3	main
kui	doc_213943985082_item	2299963	et	3	main
sest	doc_213943985080_item	2299527	et	4	main
kahjuks	doc_213943985080_item	2299532	et	4	main
tee	doc_213943985080_item	2299537	et	4	main
sõpra	doc_213943985080_item	2299560	et	4	main
ka	doc_213943985080_item	2299570	et	3	main
sest	doc_213943985080_item	2299572	et	4	main
sõber	doc_213943985080_item	2299573	et	3	main
ei	doc_213943985080_item	2299574	et	4	main
kui	doc_213943985080_item	2299585	et	3	main
ta	doc_213943985080_item	2299586	et	4	main
lõpuks	doc_213943985080_item	2299587	et	4	main
tules	doc_213943985080_item	2299588	et	3	main
peasin	doc_213943985080_item	2299589	et	4	main
keetnud	doc_213943985080_item	2299592	et	4	main
kaasa	doc_213943985080_item	2299596	et	4	main
muusikat	doc_213943985080_item	2299598	et	3	main
1	doc_213943985081_item	2299603	et	2	main
kirjuta	doc_213943985081_item	2299604	et	4	main
õiges	doc_213943985081_item	2299609	et	3	main
käib	doc_213943985081_item	2299613	et	3	main
sageli	doc_213943985081_item	2299614	et	3	main
maksimarket	doc_213943985081_item	2299615	et	4	main
maksimarketis	doc_213943985081_item	2299616	et	4	main
ja	doc_213943985081_item	2299617	et	3	main
maksab	doc_213943985081_item	2299618	et	3	main
ostude	doc_213943985081_item	2299619	et	3	main
eest	doc_213943985081_item	2299620	et	4	main
pangakaartiga	doc_213943985081_item	2299622	et	4	main
ta	doc_213943985081_item	2299624	et	4	main
köögi	doc_213943985081_item	2299629	et	3	main
tema	doc_213943985081_item	2299645	et	4	main
tihti	doc_213943985081_item	2299655	et	3	main
välismaa	doc_213943985081_item	2299657	et	4	main
komandeeringusse	doc_213943985081_item	2299658	et	3	main
da-	doc_213943985081_item	2299667	et	4	main
läheme	doc_213943985081_item	2299687	et	3	main
tohi	doc_213943985081_item	2299693	et	4	main
käia	doc_213943985081_item	2299700	et	4	main
räägida	doc_213943985081_item	2299708	et	4	main
poes	doc_213943985081_item	2299712	et	3	main
sest	doc_213943985081_item	2299715	et	4	main
varsti	doc_213943985081_item	2299716	et	3	main
see	doc_213943985081_item	2299717	et	3	main
suletakse	doc_213943985081_item	2299718	et	4	main
mida	doc_213943985081_item	2299719	et	4	main
sa	doc_213943985081_item	2299720	et	3	main
kavatsed	doc_213943985081_item	2299721	et	3	main
õhtul	doc_213943985081_item	2299723	et	3	main
rääkima	doc_213943985081_item	2299734	et	3	main
olevad	doc_213943985081_item	2299740	et	4	main
maale	doc_213943985081_item	2299750	et	4	main
olevad	doc_213943985081_item	2299778	et	4	main
sõnad	doc_213943985081_item	2299779	et	4	main
õpetaja	doc_213943985081_item	2299785	et	4	main
endise	doc_213943985081_item	2299786	et	3	main
õpetajaga	doc_213943985081_item	2299787	et	4	main
ja	doc_213943985081_item	2299788	et	3	main
küsisin	doc_213943985081_item	2299789	et	3	main
veel	doc_213943985081_item	2299793	et	4	main
poissi	doc_213943985081_item	2299797	et	4	main
vaatas	doc_213943985081_item	2299799	et	3	main
ma	doc_213943985081_item	2299804	et	3	main
mäleta	doc_213943985081_item	2299806	et	4	main
mäletan	doc_213943985081_item	2299813	et	3	main
liigse	doc_213943985081_item	2299822	et	3	main
ma	doc_213943985081_item	2299828	et	3	main
oma	doc_213943985081_item	2299830	et	4	main
tordi	doc_213943985081_item	2299835	et	3	main
keedan	doc_213943985081_item	2299840	et	3	main
ei	doc_213943985081_item	2299845	et	4	main
tee	doc_213943985081_item	2299853	et	4	main
ta	doc_213943985081_item	2299857	et	4	main
ta	doc_213943985081_item	2299865	et	4	main
head	doc_213943985081_item	2299868	et	4	main
koristab	doc_213943985081_item	2299625	et	3	main
hoolitseb	doc_213943985081_item	2299632	et	3	main
eest	doc_213943985081_item	2299635	et	4	main
aitab	doc_213943985081_item	2299636	et	3	main
väikevenna	doc_213943985081_item	2299639	et	3	main
abistan	doc_213943985081_item	2299644	et	3	main
teda	doc_213943985081_item	2299646	et	4	main
mina	doc_213943985081_item	2299648	et	4	main
mul	doc_213943985081_item	2299649	et	3	main
käib	doc_213943985081_item	2299654	et	3	main
2	doc_213943985081_item	2299660	et	2	main
sobiva	doc_213943985081_item	2299663	et	4	main
tegusõnaga	doc_213943985081_item	2299664	et	3	main
infinitiivi	doc_213943985081_item	2299668	et	4	main
vormis	doc_213943985081_item	2299669	et	4	main
kas	doc_213943985081_item	2299670	et	3	main
te	doc_213943985081_item	2299671	et	4	main
saate	doc_213943985081_item	2299672	et	4	main
mulle	doc_213943985081_item	2299673	et	4	main
appi	doc_213943985081_item	2299674	et	4	main
anda	doc_213943985081_item	2299675	et	3	main
kes	doc_213943985081_item	2299676	et	4	main
seda	doc_213943985081_item	2299677	et	3	main
peaks	doc_213943985081_item	2299678	et	4	main
sinu	doc_213943985081_item	2299679	et	3	main
asemel	doc_213943985081_item	2299680	et	4	main
tegema	doc_213943985081_item	2299681	et	3	main
mul	doc_213943985081_item	2299682	et	3	main
on	doc_213943985081_item	2299683	et	4	main
üleval	doc_213943985081_item	2299699	et	4	main
vaadata	doc_213943985081_item	2299702	et	4	main
tuleb	doc_213943985081_item	2299710	et	3	main
ära	doc_213943985081_item	2299713	et	4	main
kasuta	doc_213943985081_item	2299725	et	4	main
tegusõnu	doc_213943985081_item	2299727	et	3	main
hilinema	doc_213943985081_item	2299729	et	3	main
sõnad	doc_213943985081_item	2299741	et	4	main
mitmuse	doc_213943985081_item	2299742	et	3	main
uue	doc_213943985081_item	2299749	et	3	main
mets	doc_213943985081_item	2299754	et	3	main
tunnete	doc_213943985081_item	2299792	et	4	main
seda	doc_213943985081_item	2299796	et	3	main
mina	doc_213943985081_item	2299800	et	4	main
minul	doc_213943985081_item	2299801	et	3	main
ja	doc_213943985081_item	2299802	et	3	main
naeratas	doc_213943985081_item	2299803	et	3	main
nimi	doc_213943985081_item	2299811	et	3	main
sinu	doc_213943985081_item	2299814	et	3	main
käekiri	doc_213943985081_item	2299816	et	3	main
tegema	doc_213943985081_item	2299731	et	3	main
osastavasse	doc_213943985081_item	2299743	et	4	main
nägin	doc_213943985081_item	2299744	et	3	main
reisil	doc_213943985081_item	2299745	et	3	main
palju	doc_213943985081_item	2299746	et	4	main
ääres	doc_213943985081_item	2299752	et	4	main
metsad	doc_213943985081_item	2299761	et	3	main
jõed	doc_213943985081_item	2299762	et	3	main
järved	doc_213943985081_item	2299763	et	3	main
mäed	doc_213943985081_item	2299764	et	3	main
vanad	doc_213943985081_item	2299765	et	3	main
linnad	doc_213943985081_item	2299766	et	3	main
hea	doc_213943985081_item	2299767	et	4	main
oleks	doc_213943985081_item	2299768	et	3	main
osata	doc_213943985081_item	2299769	et	4	main
ka	doc_213943985081_item	2299770	et	3	main
võõras	doc_213943985081_item	2299771	et	4	main
keel	doc_213943985081_item	2299772	et	4	main
võõrad	doc_213943985081_item	2299773	et	3	main
keeled	doc_213943985081_item	2299774	et	3	main
4	doc_213943985081_item	2299775	et	2	main
pane	doc_213943985081_item	2299776	et	4	main
käima	doc_213943985081_item	2299736	et	4	main
3	doc_213943985081_item	2299737	et	2	main
pane	doc_213943985081_item	2299738	et	4	main
tee	doc_213943985081_item	2299751	et	4	main
jõgi	doc_213943985081_item	2299755	et	3	main
järv	doc_213943985081_item	2299756	et	3	main
ja	doc_213943985081_item	2299758	et	3	main
linn	doc_213943985081_item	2299760	et	3	main
ainsuse	doc_213943985081_item	2299780	et	4	main
kas	doc_213943985081_item	2299790	et	3	main
see	doc_213943985081_item	2299794	et	3	main
sinu	doc_213943985081_item	2299810	et	3	main
käekiri	doc_213943985081_item	2299818	et	3	main
liigne	doc_213943985081_item	2299820	et	3	main
lobisemine	doc_213943985081_item	2299823	et	4	main
minevikuga	doc_213943985081_item	2299827	et	3	main
külla	doc_213943985081_item	2299832	et	4	main
ostan	doc_213943985081_item	2299833	et	3	main
ka	doc_213943985081_item	2299841	et	3	main
ta	doc_213943985081_item	2299849	et	4	main
hiljaks	doc_213943985081_item	2299851	et	3	main
ja	doc_213943985081_item	2299852	et	3	main
jahtub	doc_213943985081_item	2299854	et	3	main
toob	doc_213943985081_item	2299866	et	3	main
kaasa	doc_213943985081_item	2299867	et	4	main
muusikat	doc_213943985081_item	2299869	et	3	main
mida	doc_213943985081_item	2299870	et	4	main
kuulame	doc_213943985081_item	2299871	et	4	main
ma	doc_213943985081_item	2299873	et	3	main
tegin	doc_213943985081_item	2299882	et	3	main
ema	doc_213943985082_item	2299928	et	4	main
käib	doc_213943985082_item	2299929	et	3	main
eest	doc_213943985082_item	2299936	et	4	main
kodus	doc_213943985082_item	2299939	et	4	main
tupu	doc_213943985082_item	2299947	et	4	main
mina	doc_213943985082_item	2299959	et	4	main
tema	doc_213943985082_item	2299961	et	4	main
käib	doc_213943985082_item	2299970	et	3	main
tihti	doc_213943985082_item	2299971	et	3	main
välismaa	doc_213943985082_item	2299973	et	4	main
või	doc_213943985082_item	2299982	et	4	main
infinitiivi	doc_213943985082_item	2299984	et	4	main
vormis	doc_213943985082_item	2299985	et	4	main
kas	doc_213943985082_item	2299986	et	3	main
te	doc_213943985082_item	2299987	et	4	main
kes	doc_213943985082_item	2299992	et	4	main
minna	doc_213943985082_item	2300002	et	3	main
rääkima	doc_213943985082_item	2300024	et	3	main
kohe	doc_213943985082_item	2300027	et	4	main
ära	doc_213943985082_item	2300029	et	4	main
sest	doc_213943985082_item	2300031	et	4	main
suletakse	doc_213943985082_item	2300034	et	4	main
tegema	doc_213943985082_item	2300047	et	3	main
tulema	doc_213943985082_item	2300049	et	4	main
reisil	doc_213943985082_item	2300061	et	3	main
uuid	doc_213943985082_item	2300065	et	4	main
oli	doc_213943985082_item	2300069	et	3	main
ja	doc_213943985082_item	2300074	et	3	main
võõras	doc_213943985082_item	2300087	et	4	main
aga	doc_213943985082_item	2300128	et	3	main
käekiri	doc_213943985082_item	2300132	et	3	main
käekiri	doc_213943985082_item	2300134	et	3	main
lobisemine	doc_213943985082_item	2300137	et	4	main
minevikuga	doc_213943985082_item	2300143	et	3	main
ostan	doc_213943985082_item	2300149	et	3	main
keedan	doc_213943985082_item	2300156	et	3	main
joo	doc_213943985082_item	2300162	et	4	main
ja	doc_213943985082_item	2300168	et	3	main
tee	doc_213943985082_item	2300214	et	4	main
tuli	doc_213943985082_item	2300220	et	4	main
uue	doc_213943985082_item	2300222	et	3	main
ta	doc_213943985082_item	2300226	et	4	main
kaas	doc_213943985082_item	2300228	et	3	main
1	doc_213943985083_item	2300235	et	2	main
pangakaart	doc_213943985083_item	2300253	et	4	main
kodus	doc_213943985083_item	2300255	et	4	main
ta	doc_213943985083_item	2300256	et	4	main
toad	doc_213943985083_item	2300263	et	3	main
koolitööd	doc_213943985083_item	2300273	et	4	main
mina	doc_213943985083_item	2300275	et	4	main
käib	doc_213943985083_item	2300286	et	3	main
tihti	doc_213943985083_item	2300287	et	3	main
sulgudes	doc_213943985081_item	2299777	et	4	main
kohtasin	doc_213943985081_item	2299782	et	3	main
oma	doc_213943985081_item	2299783	et	4	main
endine	doc_213943985081_item	2299784	et	3	main
poiss	doc_213943985081_item	2299795	et	3	main
ei	doc_213943985081_item	2299805	et	4	main
aga	doc_213943985081_item	2299812	et	3	main
halb	doc_213943985081_item	2299815	et	3	main
lobisemine	doc_213943985081_item	2299821	et	4	main
ootan	doc_213943985081_item	2299829	et	3	main
teen	doc_213943985081_item	2299837	et	3	main
võileibu	doc_213943985081_item	2299839	et	3	main
teed	doc_213943985081_item	2299842	et	4	main
kui	doc_213943985081_item	2299856	et	3	main
aga	doc_213943985081_item	2299864	et	3	main
ootasin	doc_213943985081_item	2299874	et	3	main
ja	doc_213943985081_item	2299881	et	3	main
harjutus	doc_213943985082_item	2299918	et	4	main
vormis	doc_213943985082_item	2299926	et	4	main
ja	doc_213943985082_item	2299933	et	3	main
pangakaardiga	doc_213943985082_item	2299938	et	3	main
ta	doc_213943985082_item	2299940	et	4	main
lillede	doc_213943985082_item	2299950	et	4	main
abistan	doc_213943985082_item	2299960	et	3	main
mina	doc_213943985082_item	2299964	et	4	main
minu	doc_213943985082_item	2299968	et	3	main
2	doc_213943985082_item	2299976	et	2	main
täida	doc_213943985082_item	2299977	et	4	main
lüngad	doc_213943985082_item	2299978	et	3	main
saate	doc_213943985082_item	2299988	et	4	main
seda	doc_213943985082_item	2299993	et	3	main
eesti	doc_213943985082_item	2300021	et	4	main
varsti	doc_213943985082_item	2300032	et	3	main
kavatsed	doc_213943985082_item	2300037	et	3	main
tegusõnu	doc_213943985082_item	2300043	et	3	main
olema	doc_213943985082_item	2300046	et	4	main
rääkima	doc_213943985082_item	2300050	et	3	main
sulgudes	doc_213943985082_item	2300055	et	4	main
olevad	doc_213943985082_item	2300056	et	4	main
sõnad	doc_213943985082_item	2300057	et	4	main
mitmuse	doc_213943985082_item	2300058	et	3	main
palju	doc_213943985082_item	2300062	et	4	main
mägi	doc_213943985082_item	2300073	et	3	main
metsi	doc_213943985082_item	2300077	et	4	main
järveid	doc_213943985082_item	2300078	et	4	main
mägi	doc_213943985082_item	2300079	et	3	main
oleks	doc_213943985082_item	2300084	et	3	main
ka	doc_213943985082_item	2300086	et	3	main
nimi	doc_213943985082_item	2300127	et	3	main
halba	doc_213943985082_item	2300133	et	4	main
ja	doc_213943985082_item	2300135	et	3	main
liigne	doc_213943985082_item	2300136	et	3	main
liigset	doc_213943985082_item	2300138	et	3	main
lobisemist	doc_213943985082_item	2300139	et	4	main
sõpra	doc_213943985082_item	2300147	et	4	main
tordi	doc_213943985082_item	2300151	et	3	main
ka	doc_213943985082_item	2300157	et	3	main
hiljaks	doc_213943985082_item	2300167	et	3	main
ära	doc_213943985082_item	2300171	et	4	main
ta	doc_213943985082_item	2300173	et	4	main
ei	doc_213943985082_item	2300206	et	4	main
kahjuks	doc_213943985082_item	2300209	et	4	main
ta	doc_213943985082_item	2300210	et	4	main
kui	doc_213943985082_item	2300217	et	3	main
lõpuks	doc_213943985082_item	2300219	et	4	main
5	doc_213943985081_item	2299824	et	2	main
olevik	doc_213943985081_item	2299826	et	3	main
sõpra	doc_213943985081_item	2299831	et	4	main
sõber	doc_213943985081_item	2299844	et	3	main
jääb	doc_213943985081_item	2299850	et	3	main
lõpuks	doc_213943985081_item	2299858	et	4	main
tuleb	doc_213943985081_item	2299859	et	3	main
uue	doc_213943985081_item	2299861	et	3	main
keetma	doc_213943985081_item	2299863	et	3	main
hilisõhtuni	doc_213943985081_item	2299872	et	3	main
oma	doc_213943985081_item	2299875	et	4	main
sõpra	doc_213943985081_item	2299876	et	4	main
ise	doc_213943985081_item	2299883	et	4	main
võileibu	doc_213943985081_item	2299884	et	3	main
keedasin	doc_213943985081_item	2299885	et	4	main
ka	doc_213943985081_item	2299886	et	3	main
teed	doc_213943985081_item	2299887	et	4	main
sest	doc_213943985081_item	2299888	et	4	main
sõber	doc_213943985081_item	2299889	et	3	main
ei	doc_213943985081_item	2299890	et	4	main
joo	doc_213943985081_item	2299891	et	4	main
kohvi	doc_213943985081_item	2299892	et	4	main
kahjuks	doc_213943985081_item	2299893	et	4	main
ta	doc_213943985081_item	2299894	et	4	main
jäi	doc_213943985081_item	2299895	et	3	main
hiljaks	doc_213943985081_item	2299896	et	3	main
ja	doc_213943985081_item	2299897	et	3	main
tee	doc_213943985081_item	2299898	et	4	main
jahtus	doc_213943985081_item	2299899	et	3	main
ära	doc_213943985081_item	2299900	et	4	main
kui	doc_213943985081_item	2299901	et	3	main
ta	doc_213943985081_item	2299902	et	4	main
lõpuks	doc_213943985081_item	2299903	et	4	main
tuli	doc_213943985081_item	2299904	et	4	main
peaksin	doc_213943985081_item	2299905	et	4	main
uue	doc_213943985081_item	2299906	et	3	main
tee	doc_213943985081_item	2299907	et	4	main
keetma	doc_213943985081_item	2299908	et	3	main
aga	doc_213943985081_item	2299909	et	3	main
ta	doc_213943985081_item	2299910	et	4	main
tõi	doc_213943985081_item	2299911	et	3	main
kaasa	doc_213943985081_item	2299912	et	4	main
head	doc_213943985081_item	2299913	et	4	main
muusikat	doc_213943985081_item	2299914	et	3	main
mida	doc_213943985081_item	2299915	et	4	main
ostsin	doc_213943985081_item	2299878	et	3	main
kohvikust	doc_213943985081_item	2299879	et	4	main
tordi	doc_213943985081_item	2299880	et	3	main
õiges	doc_213943985082_item	2299925	et	3	main
mu	doc_213943985082_item	2299927	et	3	main
sageli	doc_213943985082_item	2299930	et	3	main
maksab	doc_213943985082_item	2299934	et	3	main
pangakaart	doc_213943985082_item	2299937	et	4	main
toad	doc_213943985082_item	2299944	et	3	main
ja	doc_213943985082_item	2299946	et	3	main
väikevenda	doc_213943985082_item	2299955	et	4	main
teha	doc_213943985082_item	2299956	et	3	main
on	doc_213943985082_item	2299967	et	4	main
ma-	doc_213943985082_item	2299981	et	3	main
peaks	doc_213943985082_item	2299994	et	4	main
lugema	doc_213943985082_item	2299997	et	4	main
postkontorisse	doc_213943985082_item	2300001	et	3	main
hästi	doc_213943985082_item	2300023	et	3	main
tuleb	doc_213943985082_item	2300026	et	3	main
poes	doc_213943985082_item	2300028	et	3	main
mida	doc_213943985082_item	2300035	et	4	main
3	doc_213943985082_item	2300053	et	2	main
nägin	doc_213943985082_item	2300060	et	3	main
maa	doc_213943985082_item	2300064	et	4	main
maasid	doc_213943985082_item	2300066	et	3	main
järv	doc_213943985082_item	2300072	et	3	main
linn	doc_213943985082_item	2300076	et	3	main
ja	doc_213943985082_item	2300080	et	3	main
osata	doc_213943985082_item	2300085	et	4	main
sulgudes	doc_213943985082_item	2299922	et	4	main
olev	doc_213943985082_item	2299923	et	4	main
sõna	doc_213943985082_item	2299924	et	4	main
maksimarket	doc_213943985082_item	2299931	et	4	main
kööki	doc_213943985082_item	2299945	et	4	main
lilled	doc_213943985082_item	2299949	et	3	main
eest	doc_213943985082_item	2299951	et	4	main
aitab	doc_213943985082_item	2299952	et	3	main
minu	doc_213943985082_item	2299953	et	3	main
väikevend	doc_213943985082_item	2299954	et	3	main
koolitööd	doc_213943985082_item	2299957	et	4	main
temale	doc_213943985082_item	2299962	et	3	main
aega	doc_213943985082_item	2299966	et	4	main
sobiva	doc_213943985082_item	2299979	et	4	main
sinu	doc_213943985082_item	2299995	et	3	main
mul	doc_213943985082_item	2299998	et	3	main
läheme	doc_213943985082_item	2300003	et	3	main
õhtul	doc_213943985082_item	2300004	et	3	main
vanaema	doc_213943985082_item	2300005	et	4	main
vaatama	doc_213943985082_item	2300006	et	3	main
tundi	doc_213943985082_item	2300007	et	4	main
ei	doc_213943985082_item	2300008	et	4	main
hilineda	doc_213943985082_item	2300010	et	3	main
ma	doc_213943985082_item	2300011	et	3	main
tohi	doc_213943985082_item	2300009	et	4	main
tahan	doc_213943985082_item	2300012	et	3	main
veel	doc_213943985082_item	2300013	et	4	main
üleval	doc_213943985082_item	2300015	et	4	main
olla	doc_213943985082_item	2300016	et	3	main
natuke	doc_213943985082_item	2300014	et	4	main
ja	doc_213943985082_item	2300017	et	3	main
tulla	doc_213943985082_item	2300018	et	3	main
ma	doc_213943985082_item	2300019	et	3	main
õpin	doc_213943985082_item	2300020	et	3	main
sul	doc_213943985082_item	2300025	et	3	main
sa	doc_213943985082_item	2300036	et	3	main
täna	doc_213943985082_item	2300038	et	4	main
tegema	doc_213943985082_item	2300040	et	3	main
järgmisi	doc_213943985082_item	2300042	et	3	main
hilinema	doc_213943985082_item	2300045	et	3	main
minema	doc_213943985082_item	2300048	et	3	main
käima	doc_213943985082_item	2300052	et	4	main
osastavasse	doc_213943985082_item	2300059	et	4	main
mets	doc_213943985082_item	2300070	et	3	main
hea	doc_213943985082_item	2300083	et	4	main
mäleta	doc_213943985082_item	2300122	et	4	main
sinu	doc_213943985082_item	2300130	et	3	main
ootan	doc_213943985082_item	2300145	et	3	main
kohvikust	doc_213943985082_item	2300150	et	4	main
teen	doc_213943985082_item	2300153	et	3	main
võileibu	doc_213943985082_item	2300155	et	3	main
teed	doc_213943985082_item	2300158	et	4	main
sest	doc_213943985082_item	2300159	et	4	main
sõber	doc_213943985082_item	2300160	et	3	main
jääb	doc_213943985082_item	2300166	et	3	main
jäi	doc_213943985082_item	2300211	et	3	main
ta	doc_213943985082_item	2300218	et	4	main
pidin	doc_213943985082_item	2300221	et	3	main
mida	doc_213943985082_item	2300231	et	4	main
kuulasime	doc_213943985082_item	2300232	et	3	main
harjutus	doc_213943985083_item	2300234	et	4	main
koristab	doc_213943985083_item	2300257	et	3	main
lillede	doc_213943985083_item	2300266	et	4	main
tema	doc_213943985083_item	2300277	et	4	main
mull	doc_213943985082_item	2299965	et	3	main
isa	doc_213943985082_item	2299969	et	4	main
komandeering	doc_213943985082_item	2299972	et	3	main
komandeeringus	doc_213943985082_item	2299974	et	3	main
välismaal	doc_213943985082_item	2299975	et	4	main
tegusõnaga	doc_213943985082_item	2299980	et	3	main
da-	doc_213943985082_item	2299983	et	4	main
mulle	doc_213943985082_item	2299989	et	4	main
appi	doc_213943985082_item	2299990	et	4	main
teha	doc_213943985082_item	2299991	et	3	main
asemel	doc_213943985082_item	2299996	et	4	main
on	doc_213943985082_item	2299999	et	4	main
vaja	doc_213943985082_item	2300000	et	4	main
keelt	doc_213943985082_item	2300022	et	4	main
käia	doc_213943985082_item	2300030	et	4	main
see	doc_213943985082_item	2300033	et	3	main
õhtul	doc_213943985082_item	2300039	et	3	main
kasuta	doc_213943985082_item	2300041	et	4	main
vaatama	doc_213943985082_item	2300044	et	3	main
lugema	doc_213943985082_item	2300051	et	4	main
pane	doc_213943985082_item	2300054	et	4	main
uus	doc_213943985082_item	2300063	et	3	main
tee	doc_213943985082_item	2300067	et	4	main
ääres	doc_213943985082_item	2300068	et	4	main
jõgi	doc_213943985082_item	2300071	et	3	main
vana	doc_213943985082_item	2300075	et	4	main
vanu	doc_213943985082_item	2300081	et	4	main
linnu	doc_213943985082_item	2300082	et	4	main
keel	doc_213943985082_item	2300088	et	4	main
võõraseid	doc_213943985082_item	2300089	et	4	main
keeleid	doc_213943985082_item	2300090	et	4	main
4	doc_213943985082_item	2300091	et	2	main
pane	doc_213943985082_item	2300092	et	4	main
sulgudes	doc_213943985082_item	2300093	et	4	main
olevad	doc_213943985082_item	2300094	et	4	main
sõnad	doc_213943985082_item	2300095	et	4	main
ainsuse	doc_213943985082_item	2300096	et	4	main
osastavasse	doc_213943985082_item	2300097	et	4	main
kohtasin	doc_213943985082_item	2300098	et	3	main
oma	doc_213943985082_item	2300099	et	4	main
endine	doc_213943985082_item	2300100	et	3	main
õpetaja	doc_213943985082_item	2300101	et	4	main
endist	doc_213943985082_item	2300102	et	4	main
õpetajat	doc_213943985082_item	2300103	et	4	main
ja	doc_213943985082_item	2300104	et	3	main
küsisin	doc_213943985082_item	2300105	et	3	main
kas	doc_213943985082_item	2300106	et	3	main
te	doc_213943985082_item	2300107	et	4	main
tunnete	doc_213943985082_item	2300108	et	4	main
veel	doc_213943985082_item	2300109	et	4	main
see	doc_213943985082_item	2300110	et	3	main
poiss	doc_213943985082_item	2300111	et	3	main
seda	doc_213943985082_item	2300112	et	3	main
poissi	doc_213943985082_item	2300113	et	4	main
vaatas	doc_213943985082_item	2300115	et	3	main
mina	doc_213943985082_item	2300116	et	4	main
mind	doc_213943985082_item	2300117	et	4	main
õpetaja	doc_213943985082_item	2300114	et	4	main
ja	doc_213943985082_item	2300118	et	3	main
naeratas	doc_213943985082_item	2300119	et	3	main
ma	doc_213943985082_item	2300120	et	3	main
ei	doc_213943985082_item	2300121	et	4	main
küll	doc_213943985082_item	2300123	et	4	main
sinu	doc_213943985082_item	2300124	et	3	main
5	doc_213943985082_item	2300140	et	2	main
olevik	doc_213943985082_item	2300142	et	3	main
ma	doc_213943985082_item	2300144	et	3	main
külla	doc_213943985082_item	2300148	et	4	main
ja	doc_213943985082_item	2300152	et	3	main
ta	doc_213943985082_item	2300165	et	4	main
kui	doc_213943985082_item	2300172	et	3	main
lõpuks	doc_213943985082_item	2300174	et	4	main
tuleb	doc_213943985082_item	2300175	et	3	main
pean	doc_213943985082_item	2300176	et	4	main
uue	doc_213943985082_item	2300177	et	3	main
tee	doc_213943985082_item	2300178	et	4	main
keetma	doc_213943985082_item	2300179	et	3	main
aga	doc_213943985082_item	2300180	et	3	main
ta	doc_213943985082_item	2300181	et	4	main
toob	doc_213943985082_item	2300182	et	3	main
kaasa	doc_213943985082_item	2300183	et	4	main
head	doc_213943985082_item	2300184	et	4	main
muusikat	doc_213943985082_item	2300185	et	3	main
mida	doc_213943985082_item	2300186	et	4	main
kuulame	doc_213943985082_item	2300187	et	4	main
hilisõhtuni	doc_213943985082_item	2300188	et	3	main
ma	doc_213943985082_item	2300189	et	3	main
ootasin	doc_213943985082_item	2300190	et	3	main
oma	doc_213943985082_item	2300191	et	4	main
sõpra	doc_213943985082_item	2300192	et	4	main
ostsin	doc_213943985082_item	2300194	et	3	main
külla	doc_213943985082_item	2300193	et	4	main
kohvikust	doc_213943985082_item	2300195	et	4	main
tordi	doc_213943985082_item	2300196	et	3	main
ja	doc_213943985082_item	2300197	et	3	main
tegin	doc_213943985082_item	2300198	et	3	main
ise	doc_213943985082_item	2300199	et	4	main
võileivad	doc_213943985082_item	2300200	et	3	main
keedsin	doc_213943985082_item	2300201	et	4	main
ka	doc_213943985082_item	2300202	et	3	main
nimi	doc_213943985082_item	2300125	et	3	main
sinu	doc_213943985082_item	2300126	et	3	main
mäletan	doc_213943985082_item	2300129	et	3	main
halb	doc_213943985082_item	2300131	et	3	main
asenda	doc_213943985082_item	2300141	et	4	main
oma	doc_213943985082_item	2300146	et	4	main
ise	doc_213943985082_item	2300154	et	4	main
ei	doc_213943985082_item	2300161	et	4	main
kohvi	doc_213943985082_item	2300163	et	4	main
kahjuks	doc_213943985082_item	2300164	et	4	main
tee	doc_213943985082_item	2300169	et	4	main
jahtub	doc_213943985082_item	2300170	et	3	main
sest	doc_213943985082_item	2300204	et	4	main
sõber	doc_213943985082_item	2300205	et	3	main
joonud	doc_213943985082_item	2300207	et	4	main
kohvi	doc_213943985082_item	2300208	et	4	main
hiljaks	doc_213943985082_item	2300212	et	3	main
ära	doc_213943985082_item	2300216	et	4	main
keetma	doc_213943985082_item	2300224	et	3	main
hilisõhtuni	doc_213943985082_item	2300233	et	3	main
sõna	doc_213943985083_item	2300240	et	4	main
õiges	doc_213943985083_item	2300241	et	3	main
vormis	doc_213943985083_item	2300242	et	4	main
köök	doc_213943985083_item	2300258	et	3	main
köögi	doc_213943985083_item	2300261	et	3	main
hoolitseb	doc_213943985083_item	2300264	et	3	main
eest	doc_213943985083_item	2300267	et	4	main
aitab	doc_213943985083_item	2300268	et	3	main
minu	doc_213943985083_item	2300269	et	3	main
väikevend	doc_213943985083_item	2300270	et	3	main
väikevenda	doc_213943985083_item	2300271	et	4	main
teha	doc_213943985083_item	2300272	et	3	main
ka	doc_213943985083_item	2300274	et	3	main
abistan	doc_213943985083_item	2300276	et	3	main
on	doc_213943985083_item	2300283	et	4	main
välismaal	doc_213943985083_item	2300291	et	4	main
ma-	doc_213943985083_item	2300297	et	3	main
saate	doc_213943985083_item	2300304	et	4	main
sinu	doc_213943985083_item	2300311	et	3	main
on	doc_213943985083_item	2300315	et	4	main
ei	doc_213943985083_item	2300324	et	4	main
tohi	doc_213943985083_item	2300325	et	4	main
hästi	doc_213943985083_item	2300339	et	3	main
pane	doc_213943985083_item	2300371	et	4	main
sulgudes	doc_213943985083_item	2300372	et	4	main
osastavasse	doc_213943985083_item	2300376	et	4	main
uus	doc_213943985083_item	2300380	et	3	main
tee	doc_213943985083_item	2300384	et	4	main
ääres	doc_213943985083_item	2300385	et	4	main
oli	doc_213943985083_item	2300386	et	3	main
mets	doc_213943985083_item	2300387	et	3	main
jõgi	doc_213943985083_item	2300388	et	3	main
ja	doc_213943985083_item	2300391	et	3	main
linn	doc_213943985083_item	2300393	et	3	main
mäed	doc_213943985083_item	2300397	et	3	main
ja	doc_213943985083_item	2300422	et	3	main
õpetaja	doc_213943985083_item	2300432	et	4	main
ma	doc_213943985083_item	2300438	et	3	main
liigne	doc_213943985083_item	2300454	et	3	main
liigse	doc_213943985083_item	2300456	et	3	main
5	doc_213943985083_item	2300458	et	2	main
asenda	doc_213943985083_item	2300459	et	4	main
olevik	doc_213943985083_item	2300460	et	3	main
ma	doc_213943985083_item	2300462	et	3	main
teen	doc_213943985083_item	2300471	et	3	main
võileibu	doc_213943985083_item	2300473	et	3	main
joo	doc_213943985083_item	2300480	et	4	main
tuleb	doc_213943985083_item	2300493	et	3	main
ta	doc_213943985083_item	2300499	et	4	main
kuulame	doc_213943985083_item	2300505	et	4	main
ootasin	doc_213943985083_item	2300508	et	3	main
kohvikust	doc_213943985083_item	2300513	et	4	main
võileibu	doc_213943985083_item	2300518	et	3	main
ei	doc_213943985083_item	2300524	et	4	main
ta	doc_213943985083_item	2300536	et	4	main
head	doc_213943985083_item	2300547	et	4	main
hilisõhtuni	doc_213943985083_item	2300551	et	3	main
lünka	doc_213943985084_item	2300555	et	4	main
sageli	doc_213943985084_item	2300564	et	3	main
toad	doc_213943985084_item	2300578	et	3	main
lilled	doc_213943985084_item	2300583	et	3	main
eest	doc_213943985084_item	2300585	et	4	main
tee	doc_213943985082_item	2300203	et	4	main
ja	doc_213943985082_item	2300213	et	3	main
jahtus	doc_213943985082_item	2300215	et	3	main
tee	doc_213943985082_item	2300223	et	4	main
tõi	doc_213943985082_item	2300227	et	3	main
hea	doc_213943985082_item	2300229	et	4	main
muusika	doc_213943985082_item	2300230	et	4	main
kirjuta	doc_213943985083_item	2300236	et	4	main
lünka	doc_213943985083_item	2300237	et	4	main
sulgudes	doc_213943985083_item	2300238	et	4	main
mu	doc_213943985083_item	2300243	et	3	main
ema	doc_213943985083_item	2300244	et	4	main
käib	doc_213943985083_item	2300245	et	3	main
sageli	doc_213943985083_item	2300246	et	3	main
pangakaardiga	doc_213943985083_item	2300254	et	3	main
toad	doc_213943985083_item	2300260	et	3	main
ja	doc_213943985083_item	2300262	et	3	main
kui	doc_213943985083_item	2300279	et	3	main
mul	doc_213943985083_item	2300281	et	3	main
täida	doc_213943985083_item	2300293	et	4	main
sobiva	doc_213943985083_item	2300295	et	4	main
infinitiivi	doc_213943985083_item	2300300	et	4	main
peaks	doc_213943985083_item	2300310	et	4	main
postkontorisse	doc_213943985083_item	2300317	et	3	main
tahan	doc_213943985083_item	2300328	et	3	main
natuke	doc_213943985083_item	2300330	et	4	main
ja	doc_213943985083_item	2300333	et	3	main
ma	doc_213943985083_item	2300335	et	3	main
sul	doc_213943985083_item	2300341	et	3	main
kasuta	doc_213943985083_item	2300358	et	4	main
järgmisi	doc_213943985083_item	2300359	et	3	main
tegusõnu	doc_213943985083_item	2300360	et	3	main
vaatama	doc_213943985083_item	2300361	et	3	main
käima	doc_213943985083_item	2300369	et	4	main
reisil	doc_213943985083_item	2300378	et	3	main
palju	doc_213943985083_item	2300379	et	4	main
maa	doc_213943985083_item	2300381	et	4	main
uusi	doc_213943985083_item	2300382	et	3	main
mägi	doc_213943985083_item	2300390	et	3	main
vana	doc_213943985083_item	2300392	et	4	main
keel	doc_213943985083_item	2300406	et	4	main
te	doc_213943985083_item	2300425	et	4	main
tunnete	doc_213943985083_item	2300426	et	4	main
see	doc_213943985083_item	2300428	et	3	main
poiss	doc_213943985083_item	2300429	et	3	main
poisi	doc_213943985083_item	2300431	et	3	main
naeratas	doc_213943985083_item	2300437	et	3	main
su	doc_213943985083_item	2300444	et	3	main
halb	doc_213943985083_item	2300449	et	3	main
käekiri	doc_213943985083_item	2300452	et	3	main
oma	doc_213943985083_item	2300464	et	4	main
tordi	doc_213943985083_item	2300469	et	3	main
keedan	doc_213943985083_item	2300474	et	3	main
ta	doc_213943985083_item	2300491	et	4	main
tee	doc_213943985083_item	2300496	et	4	main
head	doc_213943985083_item	2300502	et	4	main
ma	doc_213943985083_item	2300507	et	3	main
oma	doc_213943985083_item	2300509	et	4	main
tordi	doc_213943985083_item	2300514	et	3	main
ise	doc_213943985083_item	2300517	et	4	main
keedsin	doc_213943985083_item	2300519	et	4	main
ka	doc_213943985083_item	2300520	et	3	main
teed	doc_213943985083_item	2300521	et	4	main
tee	doc_213943985083_item	2300541	et	4	main
harjutus	doc_213943985084_item	2300552	et	4	main
käib	doc_213943985084_item	2300563	et	3	main
ja	doc_213943985084_item	2300567	et	3	main
hoolitseb	doc_213943985084_item	2300582	et	3	main
aitab	doc_213943985084_item	2300586	et	3	main
te	doc_213943985084_item	2300621	et	4	main
asemel	doc_213943985084_item	2300630	et	4	main
räägida	doc_213943985084_item	2300644	et	4	main
tuleb	doc_213943985084_item	2300660	et	3	main
suletakse	doc_213943985084_item	2300668	et	4	main
kavatsed	doc_213943985084_item	2300671	et	3	main
minema	doc_213943985084_item	2300682	et	3	main
rääkima	doc_213943985084_item	2300684	et	3	main
käima	doc_213943985084_item	2300686	et	4	main
sõnad	doc_213943985084_item	2300691	et	4	main
palju	doc_213943985084_item	2300696	et	4	main
uus	doc_213943985084_item	2300697	et	3	main
maa	doc_213943985084_item	2300698	et	4	main
aga	doc_213943985082_item	2300225	et	3	main
olev	doc_213943985083_item	2300239	et	4	main
maksimarket	doc_213943985083_item	2300247	et	4	main
maksimarketis	doc_213943985083_item	2300248	et	4	main
ja	doc_213943985083_item	2300249	et	3	main
maksab	doc_213943985083_item	2300250	et	3	main
ostude	doc_213943985083_item	2300251	et	3	main
eest	doc_213943985083_item	2300252	et	4	main
ja	doc_213943985083_item	2300259	et	3	main
lilled	doc_213943985083_item	2300265	et	3	main
teda	doc_213943985083_item	2300278	et	4	main
aega	doc_213943985083_item	2300282	et	4	main
minu	doc_213943985083_item	2300284	et	3	main
isa	doc_213943985083_item	2300285	et	4	main
välismaa	doc_213943985083_item	2300289	et	4	main
tegusõnaga	doc_213943985083_item	2300296	et	3	main
vormis	doc_213943985083_item	2300301	et	4	main
kas	doc_213943985083_item	2300302	et	3	main
seda	doc_213943985083_item	2300309	et	3	main
asemel	doc_213943985083_item	2300312	et	4	main
tegema	doc_213943985083_item	2300313	et	3	main
läheme	doc_213943985083_item	2300319	et	3	main
õhtul	doc_213943985083_item	2300320	et	3	main
vanaema	doc_213943985083_item	2300321	et	4	main
tundi	doc_213943985083_item	2300323	et	4	main
eesti	doc_213943985083_item	2300337	et	4	main
hilinema	doc_213943985083_item	2300362	et	3	main
tulema	doc_213943985083_item	2300366	et	4	main
olevad	doc_213943985083_item	2300373	et	4	main
sõnad	doc_213943985083_item	2300374	et	4	main
metsad	doc_213943985083_item	2300394	et	3	main
vaatas	doc_213943985083_item	2300433	et	3	main
ja	doc_213943985083_item	2300436	et	3	main
ei	doc_213943985083_item	2300439	et	4	main
mäleta	doc_213943985083_item	2300440	et	4	main
käekiri	doc_213943985083_item	2300450	et	3	main
ootan	doc_213943985083_item	2300463	et	3	main
ja	doc_213943985083_item	2300470	et	3	main
teed	doc_213943985083_item	2300476	et	4	main
ei	doc_213943985083_item	2300479	et	4	main
kohvi	doc_213943985083_item	2300481	et	4	main
ta	doc_213943985083_item	2300483	et	4	main
jääb	doc_213943985083_item	2300484	et	3	main
tee	doc_213943985083_item	2300487	et	4	main
ära	doc_213943985083_item	2300489	et	4	main
uue	doc_213943985083_item	2300495	et	3	main
mida	doc_213943985083_item	2300504	et	4	main
ostsin	doc_213943985083_item	2300512	et	3	main
tegin	doc_213943985083_item	2300516	et	3	main
joonud	doc_213943985083_item	2300525	et	4	main
kahjuks	doc_213943985083_item	2300527	et	4	main
jahtus	doc_213943985083_item	2300533	et	3	main
ära	doc_213943985083_item	2300534	et	4	main
kui	doc_213943985083_item	2300535	et	3	main
uue	doc_213943985083_item	2300540	et	3	main
muusikat	doc_213943985083_item	2300548	et	3	main
mida	doc_213943985083_item	2300549	et	4	main
kirjuta	doc_213943985084_item	2300554	et	4	main
sulgudes	doc_213943985084_item	2300556	et	4	main
maksimarket	doc_213943985084_item	2300565	et	4	main
eest	doc_213943985084_item	2300570	et	4	main
ja	doc_213943985084_item	2300580	et	3	main
mina	doc_213943985083_item	2300280	et	4	main
2	doc_213943985083_item	2300292	et	2	main
da-	doc_213943985083_item	2300299	et	4	main
kes	doc_213943985083_item	2300308	et	4	main
vaja	doc_213943985083_item	2300316	et	4	main
komandeering	doc_213943985083_item	2300288	et	3	main
komandeeringus	doc_213943985083_item	2300290	et	3	main
lüngad	doc_213943985083_item	2300294	et	3	main
või	doc_213943985083_item	2300298	et	4	main
te	doc_213943985083_item	2300303	et	4	main
mulle	doc_213943985083_item	2300305	et	4	main
appi	doc_213943985083_item	2300306	et	4	main
tulla	doc_213943985083_item	2300307	et	3	main
mul	doc_213943985083_item	2300314	et	3	main
minna	doc_213943985083_item	2300318	et	3	main
vaatama	doc_213943985083_item	2300322	et	3	main
veel	doc_213943985083_item	2300329	et	4	main
üleval	doc_213943985083_item	2300331	et	4	main
olla	doc_213943985083_item	2300332	et	3	main
lugeda	doc_213943985083_item	2300334	et	3	main
rääkida	doc_213943985083_item	2300340	et	3	main
kohe	doc_213943985083_item	2300343	et	4	main
ära	doc_213943985083_item	2300345	et	4	main
käia	doc_213943985083_item	2300346	et	4	main
sest	doc_213943985083_item	2300347	et	4	main
varsti	doc_213943985083_item	2300348	et	3	main
see	doc_213943985083_item	2300349	et	3	main
suletakse	doc_213943985083_item	2300350	et	4	main
täna	doc_213943985083_item	2300354	et	4	main
õhtul	doc_213943985083_item	2300355	et	3	main
lugeda	doc_213943985083_item	2300356	et	3	main
vaadata	doc_213943985083_item	2300357	et	4	main
olema	doc_213943985083_item	2300363	et	4	main
tegema	doc_213943985083_item	2300364	et	3	main
minema	doc_213943985083_item	2300365	et	3	main
rääkima	doc_213943985083_item	2300367	et	3	main
nägin	doc_213943985083_item	2300377	et	3	main
maad	doc_213943985083_item	2300383	et	4	main
järved	doc_213943985083_item	2300396	et	3	main
õpetajaga	doc_213943985083_item	2300421	et	4	main
küsisin	doc_213943985083_item	2300423	et	3	main
mina	doc_213943985083_item	2300434	et	4	main
mind	doc_213943985083_item	2300435	et	4	main
küll	doc_213943985083_item	2300441	et	4	main
sinu	doc_213943985083_item	2300442	et	3	main
ja	doc_213943985083_item	2300453	et	3	main
minevikuga	doc_213943985083_item	2300461	et	3	main
kohvikust	doc_213943985083_item	2300468	et	4	main
sest	doc_213943985083_item	2300477	et	4	main
sõber	doc_213943985083_item	2300478	et	3	main
hiljaks	doc_213943985083_item	2300485	et	3	main
ja	doc_213943985083_item	2300486	et	3	main
jahtub	doc_213943985083_item	2300488	et	3	main
kui	doc_213943985083_item	2300490	et	3	main
pean	doc_213943985083_item	2300494	et	4	main
keetma	doc_213943985083_item	2300497	et	3	main
kaasa	doc_213943985083_item	2300501	et	4	main
muusikat	doc_213943985083_item	2300503	et	3	main
ja	doc_213943985083_item	2300515	et	3	main
sõber	doc_213943985083_item	2300523	et	3	main
kohvi	doc_213943985083_item	2300526	et	4	main
ta	doc_213943985083_item	2300528	et	4	main
jäänud	doc_213943985083_item	2300529	et	4	main
hiljaks	doc_213943985083_item	2300530	et	3	main
ja	doc_213943985083_item	2300531	et	3	main
tee	doc_213943985083_item	2300532	et	4	main
tuli	doc_213943985083_item	2300538	et	4	main
pidin	doc_213943985083_item	2300539	et	3	main
aga	doc_213943985083_item	2300543	et	3	main
ta	doc_213943985083_item	2300544	et	4	main
tõi	doc_213943985083_item	2300545	et	3	main
kaasa	doc_213943985083_item	2300546	et	4	main
1	doc_213943985084_item	2300553	et	2	main
maksimarketis	doc_213943985084_item	2300566	et	4	main
maksab	doc_213943985084_item	2300568	et	3	main
pangakaart	doc_213943985084_item	2300571	et	4	main
pangakaardiga	doc_213943985084_item	2300572	et	3	main
ta	doc_213943985084_item	2300574	et	4	main
köök	doc_213943985084_item	2300576	et	3	main
köögis	doc_213943985084_item	2300579	et	3	main
lillede	doc_213943985084_item	2300584	et	4	main
mulle	doc_213943985084_item	2300623	et	4	main
on	doc_213943985084_item	2300633	et	4	main
tohi	doc_213943985084_item	2300643	et	4	main
veel	doc_213943985084_item	2300647	et	4	main
üleval	doc_213943985084_item	2300649	et	4	main
vaadata	doc_213943985084_item	2300650	et	4	main
hilineda	doc_213943985083_item	2300326	et	3	main
ma	doc_213943985083_item	2300327	et	3	main
õpin	doc_213943985083_item	2300336	et	3	main
keelt	doc_213943985083_item	2300338	et	4	main
tuleb	doc_213943985083_item	2300342	et	3	main
poes	doc_213943985083_item	2300344	et	3	main
mida	doc_213943985083_item	2300351	et	4	main
sa	doc_213943985083_item	2300352	et	3	main
kavatsed	doc_213943985083_item	2300353	et	3	main
lugema	doc_213943985083_item	2300368	et	4	main
3	doc_213943985083_item	2300370	et	2	main
mitmuse	doc_213943985083_item	2300375	et	3	main
järv	doc_213943985083_item	2300389	et	3	main
jõed	doc_213943985083_item	2300395	et	3	main
ja	doc_213943985083_item	2300398	et	3	main
vanad	doc_213943985083_item	2300399	et	3	main
linnad	doc_213943985083_item	2300400	et	3	main
hea	doc_213943985083_item	2300401	et	4	main
oleks	doc_213943985083_item	2300402	et	3	main
osata	doc_213943985083_item	2300403	et	4	main
ka	doc_213943985083_item	2300404	et	3	main
võõras	doc_213943985083_item	2300405	et	4	main
võõra	doc_213943985083_item	2300407	et	3	main
keeli	doc_213943985083_item	2300408	et	4	main
4	doc_213943985083_item	2300409	et	2	main
pane	doc_213943985083_item	2300410	et	4	main
sulgudes	doc_213943985083_item	2300411	et	4	main
olevad	doc_213943985083_item	2300412	et	4	main
sõnad	doc_213943985083_item	2300413	et	4	main
ainsuse	doc_213943985083_item	2300414	et	4	main
osastavasse	doc_213943985083_item	2300415	et	4	main
kohtasin	doc_213943985083_item	2300416	et	3	main
oma	doc_213943985083_item	2300417	et	4	main
endine	doc_213943985083_item	2300418	et	3	main
õpetaja	doc_213943985083_item	2300419	et	4	main
endise	doc_213943985083_item	2300420	et	3	main
kas	doc_213943985083_item	2300424	et	3	main
veel	doc_213943985083_item	2300427	et	4	main
seda	doc_213943985083_item	2300430	et	3	main
nimi	doc_213943985083_item	2300443	et	3	main
nime	doc_213943985083_item	2300445	et	4	main
aga	doc_213943985083_item	2300446	et	3	main
mäletan	doc_213943985083_item	2300447	et	3	main
sinu	doc_213943985083_item	2300448	et	3	main
halb	doc_213943985083_item	2300451	et	3	main
lobisemine	doc_213943985083_item	2300455	et	4	main
lobisemine	doc_213943985083_item	2300457	et	4	main
sõpra	doc_213943985083_item	2300465	et	4	main
külla	doc_213943985083_item	2300466	et	4	main
ostan	doc_213943985083_item	2300467	et	3	main
ise	doc_213943985083_item	2300472	et	4	main
ka	doc_213943985083_item	2300475	et	3	main
kahjuks	doc_213943985083_item	2300482	et	4	main
lõpuks	doc_213943985083_item	2300492	et	4	main
aga	doc_213943985083_item	2300498	et	3	main
toob	doc_213943985083_item	2300500	et	3	main
hilisõhtuni	doc_213943985083_item	2300506	et	3	main
sõpra	doc_213943985083_item	2300510	et	4	main
külla	doc_213943985083_item	2300511	et	4	main
sest	doc_213943985083_item	2300522	et	4	main
lõpuks	doc_213943985083_item	2300537	et	4	main
keetma	doc_213943985083_item	2300542	et	3	main
kuulasime	doc_213943985083_item	2300550	et	3	main
olev	doc_213943985084_item	2300557	et	4	main
sõna	doc_213943985084_item	2300558	et	4	main
õiges	doc_213943985084_item	2300559	et	3	main
vormis	doc_213943985084_item	2300560	et	4	main
mu	doc_213943985084_item	2300561	et	3	main
ema	doc_213943985084_item	2300562	et	4	main
ostude	doc_213943985084_item	2300569	et	3	main
kodus	doc_213943985084_item	2300573	et	4	main
koristab	doc_213943985084_item	2300575	et	3	main
ja	doc_213943985084_item	2300577	et	3	main
toas	doc_213943985084_item	2300581	et	3	main
minu	doc_213943985084_item	2300587	et	3	main
väikevend	doc_213943985084_item	2300588	et	3	main
väikevennale	doc_213943985084_item	2300589	et	3	main
teha	doc_213943985084_item	2300590	et	3	main
koolitööd	doc_213943985084_item	2300591	et	4	main
ka	doc_213943985084_item	2300592	et	3	main
mina	doc_213943985084_item	2300593	et	4	main
abistan	doc_213943985084_item	2300594	et	3	main
tema	doc_213943985084_item	2300595	et	4	main
temale	doc_213943985084_item	2300596	et	3	main
kui	doc_213943985084_item	2300597	et	3	main
mina	doc_213943985084_item	2300598	et	4	main
mul	doc_213943985084_item	2300599	et	3	main
aega	doc_213943985084_item	2300600	et	4	main
on	doc_213943985084_item	2300601	et	4	main
minu	doc_213943985084_item	2300602	et	3	main
isa	doc_213943985084_item	2300603	et	4	main
käib	doc_213943985084_item	2300604	et	3	main
tihti	doc_213943985084_item	2300605	et	3	main
komandeering	doc_213943985084_item	2300606	et	3	main
välismaa	doc_213943985084_item	2300607	et	4	main
komandeering	doc_213943985084_item	2300608	et	3	main
välismaal	doc_213943985084_item	2300609	et	4	main
2	doc_213943985084_item	2300610	et	2	main
täida	doc_213943985084_item	2300611	et	4	main
lüngad	doc_213943985084_item	2300612	et	3	main
sobiva	doc_213943985084_item	2300613	et	4	main
tegusõnaga	doc_213943985084_item	2300614	et	3	main
ma-	doc_213943985084_item	2300615	et	3	main
või	doc_213943985084_item	2300616	et	4	main
da-	doc_213943985084_item	2300617	et	4	main
infinitiivi	doc_213943985084_item	2300618	et	4	main
vormis	doc_213943985084_item	2300619	et	4	main
kas	doc_213943985084_item	2300620	et	3	main
teha	doc_213943985084_item	2300625	et	3	main
seda	doc_213943985084_item	2300627	et	3	main
olla	doc_213943985084_item	2300631	et	3	main
tulla	doc_213943985084_item	2300640	et	3	main
ei	doc_213943985084_item	2300642	et	4	main
sul	doc_213943985084_item	2300659	et	3	main
kohe	doc_213943985084_item	2300661	et	4	main
mida	doc_213943985084_item	2300669	et	4	main
täna	doc_213943985084_item	2300672	et	4	main
õhtul	doc_213943985084_item	2300673	et	3	main
hilineda	doc_213943985084_item	2300674	et	3	main
tegusõnu	doc_213943985084_item	2300677	et	3	main
tegema	doc_213943985084_item	2300681	et	3	main
lugema	doc_213943985084_item	2300685	et	4	main
osastavasse	doc_213943985084_item	2300693	et	4	main
reisil	doc_213943985084_item	2300695	et	3	main
ääres	doc_213943985084_item	2300702	et	4	main
oli	doc_213943985084_item	2300703	et	3	main
jõed	doc_213943985084_item	2300712	et	3	main
mäed	doc_213943985084_item	2300714	et	3	main
vana	doc_213943985084_item	2300716	et	4	main
pane	doc_213943985084_item	2300727	et	4	main
mina	doc_213943985084_item	2300751	et	4	main
käekiri	doc_213943985084_item	2300769	et	3	main
lobisemine	doc_213943985084_item	2300772	et	4	main
lobisemine	doc_213943985084_item	2300774	et	4	main
minevikuga	doc_213943985084_item	2300778	et	3	main
oma	doc_213943985084_item	2300781	et	4	main
oma	doc_213943985084_item	2300826	et	4	main
kahjuks	doc_213943985084_item	2300844	et	4	main
jäi	doc_213943985084_item	2300846	et	3	main
tegi	doc_213943985084_item	2300849	et	4	main
ta	doc_213943985084_item	2300853	et	4	main
keetma	doc_213943985084_item	2300858	et	3	main
ta	doc_213943985084_item	2300860	et	4	main
sulgudes	doc_213943985085_item	2300872	et	4	main
maksimarkis	doc_213943985085_item	2300882	et	4	main
ta	doc_213943985085_item	2300890	et	4	main
koristab	doc_213943985085_item	2300891	et	3	main
lille	doc_213943985085_item	2300900	et	4	main
appi	doc_213943985084_item	2300624	et	4	main
saate	doc_213943985084_item	2300622	et	4	main
mul	doc_213943985084_item	2300632	et	3	main
vaja	doc_213943985084_item	2300634	et	4	main
vanaema	doc_213943985084_item	2300639	et	4	main
tahan	doc_213943985084_item	2300646	et	3	main
räägida	doc_213943985084_item	2300652	et	4	main
õpin	doc_213943985084_item	2300654	et	3	main
keelt	doc_213943985084_item	2300656	et	4	main
hästi	doc_213943985084_item	2300657	et	3	main
see	doc_213943985084_item	2300667	et	3	main
järgmisi	doc_213943985084_item	2300676	et	3	main
hilinema	doc_213943985084_item	2300679	et	3	main
3	doc_213943985084_item	2300687	et	2	main
pane	doc_213943985084_item	2300688	et	4	main
mitmuse	doc_213943985084_item	2300692	et	3	main
nägin	doc_213943985084_item	2300694	et	3	main
maad	doc_213943985084_item	2300700	et	4	main
mets	doc_213943985084_item	2300704	et	3	main
järv	doc_213943985084_item	2300706	et	3	main
vana	doc_213943985084_item	2300709	et	4	main
metsad	doc_213943985084_item	2300711	et	3	main
kes	doc_213943985084_item	2300626	et	4	main
peaks	doc_213943985084_item	2300628	et	4	main
sinu	doc_213943985084_item	2300629	et	3	main
postkontorisse	doc_213943985084_item	2300635	et	3	main
minna	doc_213943985084_item	2300636	et	3	main
läheme	doc_213943985084_item	2300637	et	3	main
õhtul	doc_213943985084_item	2300638	et	3	main
tundi	doc_213943985084_item	2300641	et	4	main
ma	doc_213943985084_item	2300645	et	3	main
natuke	doc_213943985084_item	2300648	et	4	main
ma	doc_213943985084_item	2300653	et	3	main
ära	doc_213943985084_item	2300663	et	4	main
sa	doc_213943985084_item	2300670	et	3	main
olema	doc_213943985084_item	2300680	et	4	main
sulgudes	doc_213943985084_item	2300689	et	4	main
jõgi	doc_213943985084_item	2300705	et	3	main
mägi	doc_213943985084_item	2300707	et	3	main
olevad	doc_213943985084_item	2300729	et	4	main
ainsuse	doc_213943985084_item	2300731	et	4	main
endise	doc_213943985084_item	2300737	et	3	main
te	doc_213943985084_item	2300742	et	4	main
vaatas	doc_213943985084_item	2300750	et	3	main
naeratas	doc_213943985084_item	2300754	et	3	main
küll	doc_213943985084_item	2300758	et	4	main
sinu	doc_213943985084_item	2300759	et	3	main
sinu	doc_213943985084_item	2300765	et	3	main
ja	doc_213943985084_item	2300770	et	3	main
ma	doc_213943985084_item	2300779	et	3	main
mida	doc_213943985084_item	2300821	et	4	main
hilisõhtuni	doc_213943985084_item	2300823	et	3	main
ka	doc_213943985084_item	2300837	et	3	main
teed	doc_213943985084_item	2300838	et	4	main
sest	doc_213943985084_item	2300839	et	4	main
sõber	doc_213943985084_item	2300840	et	3	main
kui	doc_213943985084_item	2300852	et	3	main
aga	doc_213943985084_item	2300859	et	3	main
tõi	doc_213943985084_item	2300861	et	3	main
1	doc_213943985085_item	2300869	et	2	main
käib	doc_213943985085_item	2300879	et	3	main
ostude	doc_213943985085_item	2300885	et	3	main
pangakaart	doc_213943985085_item	2300887	et	4	main
ja	doc_213943985085_item	2300896	et	3	main
lilled	doc_213943985085_item	2300899	et	3	main
tihti	doc_213943985085_item	2300921	et	3	main
2	doc_213943985085_item	2300926	et	2	main
lüngad	doc_213943985085_item	2300928	et	3	main
vormis	doc_213943985085_item	2300935	et	4	main
kas	doc_213943985085_item	2300936	et	3	main
saate	doc_213943985085_item	2300938	et	4	main
mulle	doc_213943985085_item	2300939	et	4	main
on	doc_213943985085_item	2300949	et	4	main
õhtul	doc_213943985085_item	2300954	et	3	main
tundi	doc_213943985085_item	2300957	et	4	main
hilinema	doc_213943985085_item	2300995	et	3	main
tulema	doc_213943985085_item	2300999	et	4	main
3	doc_213943985085_item	2301003	et	2	main
nägin	doc_213943985085_item	2301010	et	3	main
majja	doc_213943985085_item	2301016	et	3	main
vana	doc_213943985085_item	2301025	et	4	main
metsi	doc_213943985085_item	2301028	et	4	main
võõras	doc_213943985085_item	2301038	et	4	main
keelesid	doc_213943985085_item	2301041	et	4	main
4	doc_213943985085_item	2301042	et	2	main
õpetaja	doc_213943985085_item	2301052	et	4	main
küsisin	doc_213943985085_item	2301056	et	3	main
te	doc_213943985085_item	2301058	et	4	main
veel	doc_213943985085_item	2301060	et	4	main
see	doc_213943985085_item	2301061	et	3	main
poiss	doc_213943985085_item	2301062	et	3	main
seda	doc_213943985085_item	2301063	et	3	main
poissi	doc_213943985085_item	2301064	et	4	main
mina	doc_213943985085_item	2301067	et	4	main
mind	doc_213943985085_item	2301068	et	4	main
ja	doc_213943985085_item	2301069	et	3	main
naeratas	doc_213943985085_item	2301070	et	3	main
sind	doc_213943985085_item	2301077	et	4	main
aga	doc_213943985085_item	2301079	et	3	main
käekiri	doc_213943985085_item	2301083	et	3	main
liigset	doc_213943985085_item	2301089	et	3	main
olevik	doc_213943985085_item	2301093	et	3	main
ma	doc_213943985085_item	2301095	et	3	main
kohvikust	doc_213943985085_item	2301101	et	4	main
teen	doc_213943985085_item	2301104	et	3	main
ja	doc_213943985084_item	2300651	et	3	main
eesti	doc_213943985084_item	2300655	et	4	main
lugeda	doc_213943985084_item	2300658	et	3	main
poes	doc_213943985084_item	2300662	et	3	main
käia	doc_213943985084_item	2300664	et	4	main
sest	doc_213943985084_item	2300665	et	4	main
varsti	doc_213943985084_item	2300666	et	3	main
kasuta	doc_213943985084_item	2300675	et	4	main
vaatama	doc_213943985084_item	2300678	et	3	main
tulema	doc_213943985084_item	2300683	et	4	main
olevad	doc_213943985084_item	2300690	et	4	main
tee	doc_213943985084_item	2300701	et	4	main
linn	doc_213943985084_item	2300710	et	3	main
järvid	doc_213943985084_item	2300713	et	3	main
ja	doc_213943985084_item	2300715	et	3	main
linnad	doc_213943985084_item	2300717	et	3	main
võõras	doc_213943985084_item	2300722	et	4	main
keel	doc_213943985084_item	2300723	et	4	main
võõredes	doc_213943985084_item	2300724	et	3	main
keeles	doc_213943985084_item	2300725	et	4	main
oma	doc_213943985084_item	2300734	et	4	main
tunnete	doc_213943985084_item	2300743	et	4	main
veel	doc_213943985084_item	2300744	et	4	main
see	doc_213943985084_item	2300745	et	3	main
poiss	doc_213943985084_item	2300746	et	3	main
seda	doc_213943985084_item	2300747	et	3	main
mäleta	doc_213943985084_item	2300757	et	4	main
nimi	doc_213943985084_item	2300760	et	3	main
nime	doc_213943985084_item	2300762	et	4	main
aga	doc_213943985084_item	2300763	et	3	main
mäletan	doc_213943985084_item	2300764	et	3	main
halb	doc_213943985084_item	2300766	et	3	main
toob	doc_213943985084_item	2300817	et	3	main
head	doc_213943985084_item	2300819	et	4	main
muusikat	doc_213943985084_item	2300820	et	3	main
kuulame	doc_213943985084_item	2300822	et	4	main
ise	doc_213943985084_item	2300834	et	4	main
ei	doc_213943985084_item	2300841	et	4	main
jahtub	doc_213943985084_item	2300850	et	3	main
tee	doc_213943985084_item	2300857	et	4	main
head	doc_213943985084_item	2300863	et	4	main
kuulsime	doc_213943985084_item	2300866	et	3	main
kirjuta	doc_213943985085_item	2300870	et	4	main
sõna	doc_213943985085_item	2300874	et	4	main
mu	doc_213943985085_item	2300877	et	3	main
ema	doc_213943985085_item	2300878	et	4	main
sageli	doc_213943985085_item	2300880	et	3	main
kodus	doc_213943985085_item	2300889	et	4	main
ja	doc_213943985085_item	2300893	et	3	main
hoolitseb	doc_213943985085_item	2300898	et	3	main
komandeering	doc_213943985085_item	2300922	et	3	main
tegusõnaga	doc_213943985085_item	2300930	et	3	main
appi	doc_213943985085_item	2300940	et	4	main
tulla	doc_213943985085_item	2300941	et	3	main
kes	doc_213943985085_item	2300942	et	4	main
vaja	doc_213943985085_item	2300950	et	4	main
käia	doc_213943985085_item	2300952	et	4	main
ma	doc_213943985085_item	2300961	et	3	main
sest	doc_213943985085_item	2300981	et	4	main
see	doc_213943985085_item	2300983	et	3	main
kavatsed	doc_213943985085_item	2300987	et	3	main
õhtul	doc_213943985085_item	2300989	et	3	main
kasuta	doc_213943985085_item	2300991	et	4	main
vaatama	doc_213943985085_item	2300994	et	3	main
käima	doc_213943985085_item	2301002	et	4	main
osastavasse	doc_213943985085_item	2301009	et	4	main
reisil	doc_213943985085_item	2301011	et	3	main
uus	doc_213943985085_item	2301013	et	3	main
jõgi	doc_213943985085_item	2301021	et	3	main
palju	doc_213943985085_item	2301027	et	4	main
jõge	doc_213943985085_item	2301029	et	3	main
linnu	doc_213943985085_item	2301033	et	4	main
oleks	doc_213943985085_item	2301035	et	3	main
olevad	doc_213943985085_item	2301045	et	4	main
ja	doc_213943985085_item	2301055	et	3	main
kas	doc_213943985085_item	2301057	et	3	main
vaatas	doc_213943985085_item	2301066	et	3	main
küll	doc_213943985085_item	2301074	et	4	main
lobisemine	doc_213943985085_item	2301088	et	4	main
ootan	doc_213943985085_item	2301096	et	3	main
sest	doc_213943985085_item	2301110	et	4	main
sõber	doc_213943985085_item	2301111	et	3	main
uud	doc_213943985084_item	2300699	et	4	main
ja	doc_213943985084_item	2300708	et	3	main
hea	doc_213943985084_item	2300718	et	4	main
oleks	doc_213943985084_item	2300719	et	3	main
osata	doc_213943985084_item	2300720	et	4	main
sõnad	doc_213943985084_item	2300730	et	4	main
osastavasse	doc_213943985084_item	2300732	et	4	main
õpetaja	doc_213943985084_item	2300736	et	4	main
poisi	doc_213943985084_item	2300748	et	3	main
ja	doc_213943985084_item	2300753	et	3	main
ma	doc_213943985084_item	2300755	et	3	main
sinu	doc_213943985084_item	2300761	et	3	main
käekiri	doc_213943985084_item	2300767	et	3	main
5	doc_213943985084_item	2300775	et	2	main
asenda	doc_213943985084_item	2300776	et	4	main
olevik	doc_213943985084_item	2300777	et	3	main
ootan	doc_213943985084_item	2300780	et	3	main
pean	doc_213943985084_item	2300811	et	4	main
uue	doc_213943985084_item	2300812	et	3	main
tee	doc_213943985084_item	2300813	et	4	main
keetma	doc_213943985084_item	2300814	et	3	main
ta	doc_213943985084_item	2300816	et	4	main
ootasin	doc_213943985084_item	2300825	et	3	main
sõpra	doc_213943985084_item	2300827	et	4	main
ostasin	doc_213943985084_item	2300829	et	4	main
kohvikust	doc_213943985084_item	2300830	et	4	main
tordi	doc_213943985084_item	2300831	et	3	main
ja	doc_213943985084_item	2300832	et	3	main
keedasin	doc_213943985084_item	2300836	et	4	main
kohvi	doc_213943985084_item	2300843	et	4	main
hiljaks	doc_213943985084_item	2300847	et	3	main
ära	doc_213943985084_item	2300851	et	4	main
lõpuks	doc_213943985084_item	2300854	et	4	main
pidin	doc_213943985084_item	2300855	et	3	main
uue	doc_213943985084_item	2300856	et	3	main
kaasa	doc_213943985084_item	2300862	et	4	main
mida	doc_213943985084_item	2300865	et	4	main
hilisõhtuni	doc_213943985084_item	2300867	et	3	main
harjutus	doc_213943985085_item	2300868	et	4	main
olev	doc_213943985085_item	2300873	et	4	main
vormis	doc_213943985085_item	2300876	et	4	main
maksab	doc_213943985085_item	2300884	et	3	main
kööki	doc_213943985085_item	2300895	et	4	main
välismaa	doc_213943985085_item	2300923	et	4	main
sobiva	doc_213943985085_item	2300929	et	4	main
või	doc_213943985085_item	2300932	et	4	main
infinitiivi	doc_213943985085_item	2300934	et	4	main
seda	doc_213943985085_item	2300943	et	3	main
peaks	doc_213943985085_item	2300944	et	4	main
asemel	doc_213943985085_item	2300946	et	4	main
läheme	doc_213943985085_item	2300953	et	3	main
vanaema	doc_213943985085_item	2300955	et	4	main
tohi	doc_213943985085_item	2300959	et	4	main
mida	doc_213943985085_item	2300985	et	4	main
sa	doc_213943985085_item	2300986	et	3	main
täna	doc_213943985085_item	2300988	et	4	main
tegema	doc_213943985085_item	2300997	et	3	main
minema	doc_213943985085_item	2300998	et	3	main
pane	doc_213943985085_item	2301004	et	4	main
olevad	doc_213943985085_item	2301006	et	4	main
maa	doc_213943985085_item	2301014	et	4	main
mets	doc_213943985085_item	2301020	et	3	main
järv	doc_213943985085_item	2301022	et	3	main
linn	doc_213943985085_item	2301026	et	3	main
järve	doc_213943985085_item	2301030	et	4	main
ja	doc_213943985085_item	2301032	et	3	main
hea	doc_213943985085_item	2301034	et	4	main
osata	doc_213943985085_item	2301036	et	4	main
ka	doc_213943985085_item	2301037	et	3	main
keel	doc_213943985085_item	2301039	et	4	main
võõrasid	doc_213943985085_item	2301040	et	4	main
sõnad	doc_213943985085_item	2301046	et	4	main
ainsuse	doc_213943985085_item	2301047	et	4	main
osastavasse	doc_213943985085_item	2301048	et	4	main
kohtasin	doc_213943985085_item	2301049	et	3	main
oma	doc_213943985085_item	2301050	et	4	main
endine	doc_213943985085_item	2301051	et	3	main
tunnete	doc_213943985085_item	2301059	et	4	main
ma	doc_213943985085_item	2301071	et	3	main
nimi	doc_213943985085_item	2301076	et	3	main
mäletan	doc_213943985085_item	2301080	et	3	main
sinu	doc_213943985085_item	2301081	et	3	main
ka	doc_213943985084_item	2300721	et	3	main
4	doc_213943985084_item	2300726	et	2	main
sulgudes	doc_213943985084_item	2300728	et	4	main
kohtasin	doc_213943985084_item	2300733	et	3	main
endine	doc_213943985084_item	2300735	et	3	main
õpetajaga	doc_213943985084_item	2300738	et	4	main
ja	doc_213943985084_item	2300739	et	3	main
küsisin	doc_213943985084_item	2300740	et	3	main
kas	doc_213943985084_item	2300741	et	3	main
õpetaja	doc_213943985084_item	2300749	et	4	main
mind	doc_213943985084_item	2300752	et	4	main
ei	doc_213943985084_item	2300756	et	4	main
halba	doc_213943985084_item	2300768	et	4	main
liigne	doc_213943985084_item	2300771	et	3	main
liigse	doc_213943985084_item	2300773	et	3	main
külla	doc_213943985084_item	2300783	et	4	main
sõpra	doc_213943985084_item	2300782	et	4	main
ostan	doc_213943985084_item	2300784	et	3	main
kohvikust	doc_213943985084_item	2300785	et	4	main
tordi	doc_213943985084_item	2300786	et	3	main
ja	doc_213943985084_item	2300787	et	3	main
teen	doc_213943985084_item	2300788	et	3	main
ise	doc_213943985084_item	2300789	et	4	main
keedan	doc_213943985084_item	2300791	et	3	main
ka	doc_213943985084_item	2300792	et	3	main
teed	doc_213943985084_item	2300793	et	4	main
võileibu	doc_213943985084_item	2300790	et	3	main
sest	doc_213943985084_item	2300794	et	4	main
sõber	doc_213943985084_item	2300795	et	3	main
ei	doc_213943985084_item	2300796	et	4	main
joo	doc_213943985084_item	2300797	et	4	main
kohvi	doc_213943985084_item	2300798	et	4	main
kahjuks	doc_213943985084_item	2300799	et	4	main
ta	doc_213943985084_item	2300800	et	4	main
jääb	doc_213943985084_item	2300801	et	3	main
hiljaks	doc_213943985084_item	2300802	et	3	main
ja	doc_213943985084_item	2300803	et	3	main
jahtub	doc_213943985084_item	2300805	et	3	main
tee	doc_213943985084_item	2300804	et	4	main
ära	doc_213943985084_item	2300806	et	4	main
kui	doc_213943985084_item	2300807	et	3	main
ta	doc_213943985084_item	2300808	et	4	main
lõpuks	doc_213943985084_item	2300809	et	4	main
tuleb	doc_213943985084_item	2300810	et	3	main
aga	doc_213943985084_item	2300815	et	3	main
kaasa	doc_213943985084_item	2300818	et	4	main
ma	doc_213943985084_item	2300824	et	3	main
küllas	doc_213943985084_item	2300828	et	3	main
tegin	doc_213943985084_item	2300833	et	3	main
võileibu	doc_213943985084_item	2300835	et	3	main
joonud	doc_213943985084_item	2300842	et	4	main
ta	doc_213943985084_item	2300845	et	4	main
ja	doc_213943985084_item	2300848	et	3	main
muusikat	doc_213943985084_item	2300864	et	3	main
lünka	doc_213943985085_item	2300871	et	4	main
õiges	doc_213943985085_item	2300875	et	3	main
maksimarket	doc_213943985085_item	2300881	et	4	main
ja	doc_213943985085_item	2300883	et	3	main
eest	doc_213943985085_item	2300886	et	4	main
pangakaartiga	doc_213943985085_item	2300888	et	4	main
köök	doc_213943985085_item	2300892	et	3	main
toad	doc_213943985085_item	2300894	et	3	main
tubaid	doc_213943985085_item	2300897	et	4	main
eest	doc_213943985085_item	2300901	et	4	main
aitab	doc_213943985085_item	2300902	et	3	main
minu	doc_213943985085_item	2300903	et	3	main
väikevend	doc_213943985085_item	2300904	et	3	main
väikevendale	doc_213943985085_item	2300905	et	4	main
teha	doc_213943985085_item	2300906	et	3	main
koolitööd	doc_213943985085_item	2300907	et	4	main
ka	doc_213943985085_item	2300908	et	3	main
mina	doc_213943985085_item	2300909	et	4	main
abistan	doc_213943985085_item	2300910	et	3	main
tema	doc_213943985085_item	2300911	et	4	main
talle	doc_213943985085_item	2300912	et	4	main
kui	doc_213943985085_item	2300913	et	3	main
mina	doc_213943985085_item	2300914	et	4	main
mul	doc_213943985085_item	2300915	et	3	main
aega	doc_213943985085_item	2300916	et	4	main
on	doc_213943985085_item	2300917	et	4	main
minu	doc_213943985085_item	2300918	et	3	main
isa	doc_213943985085_item	2300919	et	4	main
käib	doc_213943985085_item	2300920	et	3	main
komandeeringus	doc_213943985085_item	2300924	et	3	main
välismaal	doc_213943985085_item	2300925	et	4	main
ma-	doc_213943985085_item	2300931	et	3	main
da-	doc_213943985085_item	2300933	et	4	main
te	doc_213943985085_item	2300937	et	4	main
sinu	doc_213943985085_item	2300945	et	3	main
mul	doc_213943985085_item	2300948	et	3	main
ei	doc_213943985085_item	2300958	et	4	main
minna	doc_213943985085_item	2300980	et	3	main
varsti	doc_213943985085_item	2300982	et	3	main
olema	doc_213943985085_item	2300996	et	4	main
lugema	doc_213943985085_item	2301001	et	4	main
palju	doc_213943985085_item	2301012	et	4	main
tee	doc_213943985085_item	2301017	et	4	main
oli	doc_213943985085_item	2301019	et	3	main
täida	doc_213943985085_item	2300927	et	4	main
tegema	doc_213943985085_item	2300947	et	3	main
postkontorisse	doc_213943985085_item	2300951	et	3	main
vaatama	doc_213943985085_item	2300956	et	3	main
hilineda	doc_213943985085_item	2300960	et	3	main
tahan	doc_213943985085_item	2300962	et	3	main
veel	doc_213943985085_item	2300963	et	4	main
natuke	doc_213943985085_item	2300964	et	4	main
olla	doc_213943985085_item	2300966	et	3	main
ja	doc_213943985085_item	2300967	et	3	main
üleval	doc_213943985085_item	2300965	et	4	main
lugeda	doc_213943985085_item	2300968	et	3	main
ma	doc_213943985085_item	2300969	et	3	main
õpin	doc_213943985085_item	2300970	et	3	main
eesti	doc_213943985085_item	2300971	et	4	main
keelt	doc_213943985085_item	2300972	et	4	main
hästi	doc_213943985085_item	2300973	et	3	main
rääkima	doc_213943985085_item	2300974	et	3	main
sul	doc_213943985085_item	2300975	et	3	main
tuleb	doc_213943985085_item	2300976	et	3	main
kohe	doc_213943985085_item	2300977	et	4	main
poes	doc_213943985085_item	2300978	et	3	main
ära	doc_213943985085_item	2300979	et	4	main
suletakse	doc_213943985085_item	2300984	et	4	main
teha	doc_213943985085_item	2300990	et	3	main
järgmisi	doc_213943985085_item	2300992	et	3	main
tegusõnu	doc_213943985085_item	2300993	et	3	main
rääkima	doc_213943985085_item	2301000	et	3	main
sulgudes	doc_213943985085_item	2301005	et	4	main
sõnad	doc_213943985085_item	2301007	et	4	main
mitmuse	doc_213943985085_item	2301008	et	3	main
uusi	doc_213943985085_item	2301015	et	3	main
ääres	doc_213943985085_item	2301018	et	4	main
mägi	doc_213943985085_item	2301023	et	3	main
ja	doc_213943985085_item	2301024	et	3	main
mäkke	doc_213943985085_item	2301031	et	3	main
õpetajad	doc_213943985085_item	2301054	et	4	main
õpetaja	doc_213943985085_item	2301065	et	4	main
ei	doc_213943985085_item	2301072	et	4	main
sinu	doc_213943985085_item	2301075	et	3	main
käekirjat	doc_213943985085_item	2301085	et	4	main
liigne	doc_213943985085_item	2301087	et	3	main
lobisemist	doc_213943985085_item	2301090	et	4	main
oma	doc_213943985085_item	2301097	et	4	main
külla	doc_213943985085_item	2301099	et	4	main
ostan	doc_213943985085_item	2301100	et	3	main
tordi	doc_213943985085_item	2301102	et	3	main
ise	doc_213943985085_item	2301105	et	4	main
ka	doc_213943985085_item	2301108	et	3	main
ei	doc_213943985085_item	2301112	et	4	main
pane	doc_213943985085_item	2301043	et	4	main
sulgudes	doc_213943985085_item	2301044	et	4	main
endist	doc_213943985085_item	2301053	et	4	main
mäleta	doc_213943985085_item	2301073	et	4	main
nimet	doc_213943985085_item	2301078	et	4	main
halb	doc_213943985085_item	2301082	et	3	main
halba	doc_213943985085_item	2301084	et	4	main
5	doc_213943985085_item	2301091	et	2	main
minevikuga	doc_213943985085_item	2301094	et	3	main
ja	doc_213943985085_item	2301103	et	3	main
võileibu	doc_213943985085_item	2301106	et	3	main
joo	doc_213943985085_item	2301113	et	4	main
kohvi	doc_213943985085_item	2301114	et	4	main
kahjuks	doc_213943985085_item	2301115	et	4	main
ta	doc_213943985085_item	2301116	et	4	main
jääb	doc_213943985085_item	2301117	et	3	main
hiljaks	doc_213943985085_item	2301118	et	3	main
ja	doc_213943985085_item	2301119	et	3	main
tee	doc_213943985085_item	2301120	et	4	main
tee	doc_213943985085_item	2301129	et	4	main
toob	doc_213943985085_item	2301133	et	3	main
ma	doc_213943985085_item	2301140	et	3	main
ja	doc_213943985085_item	2301148	et	3	main
sõber	doc_213943985085_item	2301156	et	3	main
kahjuks	doc_213943985085_item	2301160	et	4	main
ja	doc_213943985085_item	2301164	et	3	main
ta	doc_213943985085_item	2301169	et	4	main
lõpuks	doc_213943985085_item	2301170	et	4	main
sajand	doc_214589672701_item	2301208	et	3	main
ja	doc_213943985085_item	2301086	et	3	main
asenda	doc_213943985085_item	2301092	et	4	main
sõpra	doc_213943985085_item	2301098	et	4	main
teed	doc_213943985085_item	2301109	et	4	main
kui	doc_213943985085_item	2301123	et	3	main
ta	doc_213943985085_item	2301124	et	4	main
head	doc_213943985085_item	2301135	et	4	main
muusikat	doc_213943985085_item	2301136	et	3	main
mida	doc_213943985085_item	2301137	et	4	main
kuulame	doc_213943985085_item	2301138	et	4	main
hilisõhtuni	doc_213943985085_item	2301139	et	3	main
võileibu	doc_213943985085_item	2301151	et	3	main
kohvi	doc_213943985085_item	2301159	et	4	main
hiljaks	doc_213943985085_item	2301163	et	3	main
tuli	doc_213943985085_item	2301171	et	4	main
pidin	doc_213943985085_item	2301172	et	3	main
uue	doc_213943985085_item	2301173	et	3	main
tee	doc_213943985085_item	2301174	et	4	main
tagasi	doc_214589672701_item	2301209	et	3	main
ei	doc_214589672701_item	2301210	et	4	main
võimalik	doc_214589672701_item	2301217	et	3	main
teisele	doc_214589672701_item	2301221	et	4	main
paarkümmend	doc_214589672701_item	2301223	et	4	main
arvuti	doc_214589672701_item	2301227	et	4	main
luksus	doc_214589672701_item	2301229	et	4	main
ning	doc_214589672701_item	2301244	et	3	main
toit	doc_214589672701_item	2301259	et	3	main
aga	doc_214589672701_item	2301263	et	3	main
inimene	doc_214589672701_item	2301266	et	3	main
kui	doc_214589672701_item	2301291	et	3	main
on	doc_214589672701_item	2301296	et	4	main
lapsuke	doc_214589672701_item	2301299	et	4	main
armastust	doc_214589672701_item	2301302	et	4	main
elu	doc_214589672701_item	2301303	et	4	main
veeta	doc_214589672701_item	2301310	et	4	main
et	doc_214589672701_item	2301312	et	3	main
armastusromaanideta	doc_214589672701_item	2301320	et	3	main
ning	doc_214589672701_item	2301321	et	3	main
on	doc_214589672701_item	2301324	et	4	main
pisaraid	doc_214589672701_item	2301325	et	3	main
valatud	doc_214589672701_item	2301326	et	4	main
filme	doc_214589672701_item	2301327	et	3	main
head	doc_214589672701_item	2301338	et	4	main
ei	doc_214589672701_item	2301342	et	4	main
arvan	doc_214589672701_item	2301346	et	3	main
keedan	doc_213943985085_item	2301107	et	3	main
ära	doc_213943985085_item	2301122	et	4	main
lõpuks	doc_213943985085_item	2301125	et	4	main
tuleb	doc_213943985085_item	2301126	et	3	main
oma	doc_213943985085_item	2301142	et	4	main
külla	doc_213943985085_item	2301144	et	4	main
kohvikust	doc_213943985085_item	2301146	et	4	main
teegin	doc_213943985085_item	2301149	et	4	main
ise	doc_213943985085_item	2301150	et	4	main
keetsin	doc_213943985085_item	2301152	et	3	main
ka	doc_213943985085_item	2301153	et	3	main
teed	doc_213943985085_item	2301154	et	4	main
sest	doc_213943985085_item	2301155	et	4	main
ära	doc_213943985085_item	2301167	et	4	main
keetma	doc_213943985085_item	2301175	et	3	main
paljud	doc_214589672701_item	2301212	et	3	main
ette	doc_214589672701_item	2301214	et	4	main
on	doc_214589672701_item	2301216	et	4	main
ühelt	doc_214589672701_item	2301219	et	3	main
alles	doc_214589672701_item	2301222	et	3	main
aastat	doc_214589672701_item	2301224	et	3	main
tagasi	doc_214589672701_item	2301225	et	3	main
tänapäevaks	doc_214589672701_item	2301236	et	3	main
kõik	doc_214589672701_item	2301238	et	4	main
need	doc_214589672701_item	2301239	et	3	main
nagu	doc_214589672701_item	2301241	et	3	main
ette	doc_214589672701_item	2301250	et	4	main
aga	doc_214589672701_item	2301252	et	3	main
tõesti	doc_214589672701_item	2301254	et	3	main
ja	doc_214589672701_item	2301260	et	3	main
ilma	doc_214589672701_item	2301294	et	4	main
ta	doc_214589672701_item	2301297	et	4	main
ilma	doc_214589672701_item	2301304	et	4	main
armastuseta	doc_214589672701_item	2301305	et	4	main
inimesi	doc_214589672701_item	2301314	et	4	main
kujuta	doc_214589672701_item	2301316	et	4	main
elu	doc_214589672701_item	2301318	et	4	main
ei	doc_214589672701_item	2301335	et	4	main
too	doc_214589672701_item	2301336	et	4	main
armastus	doc_214589672701_item	2301337	et	4	main
öelda	doc_214589672701_item	2301345	et	4	main
armastus	doc_214589672701_item	2301348	et	4	main
kao	doc_214589672701_item	2301350	et	4	main
maailmast	doc_214589672701_item	2301352	et	4	main
laused	doc_214589672703_item	2301493	et	3	main
ümbritseva	doc_214589672703_item	2301495	et	4	main
ohud	doc_214589672703_item	2301497	et	3	main
ei	doc_214589672703_item	2301501	et	4	main
ei	doc_214589672703_item	2301514	et	4	main
mida	doc_214589672703_item	2301526	et	4	main
võimsam	doc_214589672703_item	2301527	et	4	main
on	doc_214589672703_item	2301528	et	4	main
auto	doc_214589672703_item	2301529	et	4	main
rikub	doc_214589672703_item	2301532	et	3	main
see	doc_214589672703_item	2301533	et	3	main
selle	doc_214589672703_item	2301535	et	4	main
ei	doc_214589672703_item	2301539	et	4	main
mõtle	doc_214589672703_item	2301540	et	4	main
lapsevanemad	doc_214589672703_item	2301541	et	4	main
minek	doc_214589672703_item	2301550	et	3	main
ei	doc_214589672703_item	2301559	et	4	main
ja	doc_214589672703_item	2301583	et	3	main
ohud	doc_214589672703_item	2301584	et	3	main
tänapäevainimene	doc_214589672704_item	2301595	et	3	main
elada	doc_214589672704_item	2301596	et	3	main
palju	doc_214589672704_item	2301599	et	4	main
on	doc_214589672704_item	2301600	et	4	main
mida	doc_214589672704_item	2301604	et	4	main
luksusi	doc_214589672704_item	2301609	et	3	main
ta	doc_213943985085_item	2301132	et	4	main
ootasin	doc_213943985085_item	2301141	et	3	main
ostsin	doc_213943985085_item	2301145	et	3	main
tordi	doc_213943985085_item	2301147	et	3	main
ei	doc_213943985085_item	2301157	et	4	main
aga	doc_213943985085_item	2301176	et	3	main
ta	doc_213943985085_item	2301177	et	4	main
toob	doc_213943985085_item	2301178	et	3	main
kaasa	doc_213943985085_item	2301179	et	4	main
head	doc_213943985085_item	2301180	et	4	main
muusikat	doc_213943985085_item	2301181	et	3	main
mida	doc_213943985085_item	2301182	et	4	main
kuulsime	doc_213943985085_item	2301183	et	3	main
hilisõhtuni	doc_213943985085_item	2301184	et	3	main
milleta	doc_214589672701_item	2301185	et	3	main
tänapäeval	doc_214589672701_item	2301186	et	3	main
elada	doc_214589672701_item	2301187	et	3	main
ei	doc_214589672701_item	2301188	et	4	main
saa	doc_214589672701_item	2301189	et	4	main
milleta	doc_214589672701_item	2301190	et	3	main
tänapäeval	doc_214589672701_item	2301191	et	3	main
elada	doc_214589672701_item	2301192	et	3	main
ei	doc_214589672701_item	2301193	et	4	main
saa	doc_214589672701_item	2301194	et	4	main
alles	doc_214589672701_item	2301195	et	3	main
rohkem	doc_214589672701_item	2301196	et	4	main
kui	doc_214589672701_item	2301197	et	3	main
600	doc_214589672701_item	2301198	et	2	main
tagasi	doc_214589672701_item	2301200	et	3	main
suri	doc_214589672701_item	2301201	et	3	main
sadu	doc_214589672701_item	2301202	et	4	main
tuhandeid	doc_214589672701_item	2301203	et	3	main
aastat	doc_214589672701_item	2301199	et	3	main
inimesi	doc_214589672701_item	2301204	et	4	main
katku	doc_214589672701_item	2301205	et	4	main
küüsi	doc_214589672701_item	2301206	et	4	main
alles	doc_214589672701_item	2301207	et	3	main
jahtub	doc_213943985085_item	2301121	et	3	main
pean	doc_213943985085_item	2301127	et	4	main
uue	doc_213943985085_item	2301128	et	3	main
keetma	doc_213943985085_item	2301130	et	3	main
aga	doc_213943985085_item	2301131	et	3	main
kaasa	doc_213943985085_item	2301134	et	4	main
sõpra	doc_213943985085_item	2301143	et	4	main
joonud	doc_213943985085_item	2301158	et	4	main
ta	doc_213943985085_item	2301161	et	4	main
jäi	doc_213943985085_item	2301162	et	3	main
tegi	doc_213943985085_item	2301165	et	4	main
jahtub	doc_213943985085_item	2301166	et	3	main
kui	doc_213943985085_item	2301168	et	3	main
lennata	doc_214589672701_item	2301218	et	4	main
mandrilt	doc_214589672701_item	2301220	et	4	main
inimesed	doc_214589672701_item	2301232	et	3	main
said	doc_214589672701_item	2301235	et	4	main
iseenesest	doc_214589672701_item	2301242	et	4	main
saa	doc_214589672701_item	2301257	et	4	main
on	doc_214589672701_item	2301258	et	4	main
et	doc_214589672701_item	2301265	et	3	main
pea	doc_214589672701_item	2301288	et	4	main
sünnib	doc_214589672701_item	2301295	et	3	main
on	doc_214589672701_item	2301306	et	4	main
kui	doc_214589672701_item	2301307	et	3	main
puu	doc_214589672701_item	2301308	et	4	main
enamus	doc_214589672701_item	2301313	et	4	main
ette	doc_214589672701_item	2301317	et	4	main
ilma	doc_214589672701_item	2301319	et	4	main
kujutanud	doc_214589672701_item	2301211	et	4	main
inimesed	doc_214589672701_item	2301213	et	3	main
et	doc_214589672701_item	2301215	et	3	main
oli	doc_214589672701_item	2301226	et	3	main
suur	doc_214589672701_item	2301228	et	3	main
mida	doc_214589672701_item	2301230	et	4	main
vähesed	doc_214589672701_item	2301231	et	3	main
omada	doc_214589672701_item	2301234	et	3	main
on	doc_214589672701_item	2301237	et	4	main
leiutised	doc_214589672701_item	2301240	et	3	main
nendeta	doc_214589672701_item	2301246	et	4	main
kujuta	doc_214589672701_item	2301248	et	4	main
elu	doc_214589672701_item	2301249	et	4	main
inimene	doc_214589672701_item	2301253	et	3	main
ei	doc_214589672701_item	2301256	et	4	main
mina	doc_214589672701_item	2301262	et	4	main
arvan	doc_214589672701_item	2301264	et	3	main
võimatu	doc_214589672701_item	2301289	et	4	main
elada	doc_214589672701_item	2301290	et	3	main
siia	doc_214589672701_item	2301293	et	4	main
ilma	doc_214589672701_item	2301309	et	4	main
ei	doc_214589672701_item	2301315	et	4	main
palju	doc_214589672701_item	2301323	et	4	main
aga	doc_214589672701_item	2301332	et	3	main
mõistet	doc_214589672701_item	2301341	et	3	main
keegi	doc_214589672701_item	2301344	et	4	main
et	doc_214589672701_item	2301347	et	3	main
ei	doc_214589672701_item	2301349	et	4	main
siit	doc_214589672701_item	2301351	et	3	main
kunagi	doc_214589672701_item	2301353	et	3	main
maailma	doc_214589672703_item	2301496	et	4	main
võlud	doc_214589672703_item	2301499	et	4	main
maailmakodanikud	doc_214589672703_item	2301503	et	3	main
meid	doc_214589672703_item	2301505	et	4	main
ning	doc_214589672703_item	2301508	et	3	main
puhkevatest	doc_214589672703_item	2301511	et	4	main
selleks	doc_214589672703_item	2301513	et	4	main
ole	doc_214589672703_item	2301515	et	4	main
valmis	doc_214589672703_item	2301516	et	4	main
aga	doc_214589672703_item	2301517	et	3	main
mitte	doc_214589672703_item	2301518	et	3	main
tõsiasja	doc_214589672703_item	2301524	et	4	main
et	doc_214589672703_item	2301525	et	3	main
loodust	doc_214589672703_item	2301534	et	4	main
eseme	doc_214589672703_item	2301536	et	3	main
ostmisel	doc_214589672703_item	2301537	et	4	main
lastele	doc_214589672703_item	2301538	et	4	main
sellele	doc_214589672703_item	2301543	et	4	main
et	doc_214589672703_item	2301544	et	3	main
oma	doc_214589672703_item	2301561	et	4	main
tohiks	doc_214589672703_item	2301577	et	3	main
ei	doc_214589672704_item	2301590	et	4	main
saaks	doc_214589672704_item	2301591	et	3	main
laused	doc_214589672704_item	2301593	et	3	main
ei	doc_214589672704_item	2301597	et	4	main
saaks	doc_214589672704_item	2301598	et	3	main
teemal	doc_214589672704_item	2301602	et	3	main
eestis	doc_214589672701_item	2301233	et	3	main
mõistetavad	doc_214589672701_item	2301243	et	4	main
ilma	doc_214589672701_item	2301245	et	4	main
ei	doc_214589672701_item	2301247	et	4	main
milleta	doc_214589672701_item	2301251	et	3	main
elada	doc_214589672701_item	2301255	et	3	main
vesi	doc_214589672701_item	2301261	et	4	main
ei	doc_214589672701_item	2301267	et	4	main
saa	doc_214589672701_item	2301268	et	4	main
elada	doc_214589672701_item	2301269	et	3	main
ilma	doc_214589672701_item	2301270	et	4	main
armastuseta	doc_214589672701_item	2301271	et	4	main
hoolimata	doc_214589672701_item	2301272	et	4	main
ajast	doc_214589672701_item	2301273	et	4	main
kohast	doc_214589672701_item	2301274	et	4	main
rahvusest	doc_214589672701_item	2301275	et	4	main
või	doc_214589672701_item	2301276	et	4	main
vanusest	doc_214589672701_item	2301277	et	4	main
on	doc_214589672701_item	2301278	et	4	main
armastus	doc_214589672701_item	2301279	et	4	main
inimese	doc_214589672701_item	2301280	et	4	main
jaoks	doc_214589672701_item	2301281	et	4	main
üks	doc_214589672701_item	2301282	et	3	main
olulisemaid	doc_214589672701_item	2301283	et	4	main
tundeid	doc_214589672701_item	2301284	et	3	main
milleta	doc_214589672701_item	2301285	et	3	main
on	doc_214589672701_item	2301286	et	4	main
raske	doc_214589672701_item	2301287	et	4	main
inimene	doc_214589672701_item	2301292	et	3	main
süütu	doc_214589672701_item	2301298	et	4	main
kes	doc_214589672701_item	2301300	et	4	main
vajab	doc_214589672701_item	2301301	et	3	main
arvan	doc_214589672701_item	2301311	et	3	main
kui	doc_214589672701_item	2301322	et	3	main
vaadates	doc_214589672701_item	2301328	et	3	main
armastust	doc_214589672701_item	2301330	et	4	main
alati	doc_214589672701_item	2301334	et	4	main
kindlat	doc_214589672701_item	2301339	et	3	main
valemit	doc_214589672701_item	2301340	et	3	main
oska	doc_214589672701_item	2301343	et	4	main
inimest	doc_214589672703_item	2301487	et	3	main
ümbritseva	doc_214589672703_item	2301488	et	4	main
ohud	doc_214589672703_item	2301490	et	3	main
ja	doc_214589672703_item	2301491	et	3	main
ja	doc_214589672703_item	2301498	et	3	main
ümbritsevatest	doc_214589672703_item	2301506	et	4	main
nende	doc_214589672703_item	2301509	et	4	main
vallandudes	doc_214589672703_item	2301510	et	3	main
kus	doc_214589672701_item	2301329	et	3	main
tõotatakse	doc_214589672701_item	2301331	et	3	main
mitte	doc_214589672701_item	2301333	et	3	main
inimest	doc_214589672703_item	2301494	et	3	main
tihtipeale	doc_214589672703_item	2301500	et	3	main
hädaohtudest	doc_214589672703_item	2301507	et	3	main
keegi	doc_214589672703_item	2301520	et	4	main
tunnista	doc_214589672703_item	2301522	et	4	main
seda	doc_214589672703_item	2301530	et	3	main
aga	doc_214589672703_item	2301542	et	3	main
tekitab	doc_214589672703_item	2301546	et	3	main
kaasa	doc_214589672703_item	2301549	et	4	main
süütu	doc_214589672703_item	2301555	et	4	main
tütarlapse	doc_214589672703_item	2301556	et	4	main
vägistamisega	doc_214589672703_item	2301557	et	4	main
astuda	doc_214589672703_item	2301579	et	3	main
maailma	doc_214589672703_item	2301581	et	4	main
võlud	doc_214589672703_item	2301582	et	4	main
milleta	doc_214589672704_item	2301587	et	3	main
milleta	doc_214589672704_item	2301594	et	3	main
arutletud	doc_214589672704_item	2301601	et	4	main
maailmakodanikud	doc_214589672704_item	2301606	et	3	main
on	doc_214589672704_item	2301615	et	4	main
ei	doc_214589672704_item	2301628	et	4	main
siis	doc_214589672704_item	2301630	et	3	main
ka	doc_214589672704_item	2301631	et	3	main
kõik	doc_214589672704_item	2301648	et	4	main
elektrile	doc_214589672704_item	2301653	et	3	main
kõrgepinge	doc_214589672704_item	2301656	et	4	main
kujutaks	doc_214589672704_item	2301664	et	4	main
elektrita	doc_214589672704_item	2301665	et	3	main
saaks	doc_214589672704_item	2301667	et	3	main
vaadata	doc_214589672704_item	2301669	et	4	main
raadiot	doc_214589672704_item	2301670	et	3	main
oleks	doc_214589672704_item	2301681	et	3	main
pinevuseta	doc_214589672704_item	2301685	et	4	main
praegusaeg	doc_214589672704_item	2301687	et	3	main
kiviaja	doc_214589672704_item	2301689	et	3	main
ühel	doc_214589672704_item	2301697	et	3	main
ei	doc_214589672704_item	2301701	et	4	main
kraanist	doc_214589672704_item	2301726	et	3	main
enam	doc_214589672704_item	2301727	et	4	main
vett	doc_214589672704_item	2301729	et	3	main
ei	doc_214589672704_item	2301730	et	4	main
inimesed	doc_214589672704_item	2301737	et	3	main
ja	doc_214589672704_item	2301739	et	3	main
b	doc_214589672704_item	2301745	et	4	main
kaasaja	doc_214589672704_item	2301750	et	4	main
seda	doc_214589672704_item	2301774	et	3	main
kõrvalt	doc_214589672704_item	2301778	et	4	main
puudulik	doc_214589672704_item	2301790	et	3	main
ja	doc_214589672704_item	2301791	et	3	main
pakisaatmine	doc_214589672704_item	2301794	et	3	main
öelda	doc_214589672704_item	2301802	et	4	main
ilma	doc_214589672704_item	2301804	et	4	main
kanalisatsioon	doc_214589672704_item	2301809	et	3	main
transpordivahendid	doc_214589672704_item	2301811	et	3	main
või	doc_214589672704_item	2301816	et	4	main
ole	doc_214589672704_item	2301823	et	4	main
õnnelikud	doc_214589672704_item	2301827	et	3	main
et	doc_214589672704_item	2301830	et	3	main
21	doc_214589672704_item	2301833	et	2	main
sajandis	doc_214589672704_item	2301834	et	3	main
inimene	doc_214589672705_item	2301840	et	3	main
ei	doc_214589672705_item	2301842	et	4	main
saaks	doc_214589672705_item	2301851	et	3	main
ei	doc_214589672705_item	2301854	et	4	main
me	doc_214589672705_item	2301856	et	4	main
eest	doc_214589672705_item	2301863	et	4	main
oleksid	doc_214589672705_item	2301866	et	4	main
aparaadid	doc_214589672705_item	2301868	et	3	main
maailma	doc_214589672703_item	2301489	et	4	main
võlud	doc_214589672703_item	2301492	et	4	main
ole	doc_214589672703_item	2301502	et	4	main
teadlikud	doc_214589672703_item	2301504	et	3	main
katastroofidest	doc_214589672703_item	2301512	et	3	main
keegi	doc_214589672703_item	2301519	et	4	main
ei	doc_214589672703_item	2301521	et	4	main
endale	doc_214589672703_item	2301523	et	4	main
kahjulikke	doc_214589672703_item	2301547	et	3	main
90-protsendil	doc_214589672703_item	2301551	et	3	main
suuda	doc_214589672703_item	2301560	et	4	main
üle	doc_214589672703_item	2301578	et	3	main
mitmekülgse	doc_214589672703_item	2301580	et	3	main
lõputud	doc_214589672703_item	2301586	et	4	main
elada	doc_214589672704_item	2301589	et	3	main
eestlaste	doc_214589672704_item	2301592	et	4	main
kui	doc_214589672704_item	2301607	et	3	main
mulle	doc_214589672704_item	2301616	et	4	main
üritan	doc_214589672704_item	2301619	et	3	main
vastuse	doc_214589672704_item	2301621	et	3	main
elada	doc_214589672704_item	2301624	et	3	main
koolis	doc_214589672704_item	2301632	et	4	main
sest	doc_214589672704_item	2301633	et	4	main
lap-topi	doc_214589672704_item	2301642	et	4	main
arvesse	doc_214589672704_item	2301644	et	4	main
inimesed	doc_214589672704_item	2301659	et	3	main
kuulata	doc_214589672704_item	2301671	et	4	main
surfata	doc_214589672704_item	2301676	et	4	main
taaskord	doc_214589672704_item	2301688	et	3	main
selle	doc_214589672704_item	2301691	et	4	main
hetkel	doc_214589672704_item	2301698	et	4	main
ole	doc_214589672704_item	2301702	et	4	main
toimubki	doc_214589672704_item	2301704	et	3	main
eluiga	doc_214589672704_item	2301721	et	4	main
hetke	doc_214589672704_item	2301724	et	4	main
sooja	doc_214589672704_item	2301728	et	4	main
tule	doc_214589672704_item	2301731	et	4	main
arvamusel	doc_214589672704_item	2301733	et	3	main
ilma	doc_214589672704_item	2301735	et	4	main
lohakamad	doc_214589672704_item	2301738	et	4	main
reisimine	doc_214589672704_item	2301741	et	4	main
väga	doc_214589672704_item	2301747	et	3	main
hobuseid	doc_214589672704_item	2301754	et	4	main
oma	doc_214589672704_item	2301756	et	4	main
kuna	doc_214589672704_item	2301765	et	3	main
reisimine	doc_214589672704_item	2301767	et	4	main
palju	doc_214589672704_item	2301769	et	4	main
saaks	doc_214589672704_item	2301780	et	3	main
nad	doc_214589672704_item	2301781	et	3	main
ega	doc_214589672704_item	2301784	et	3	main
oleks	doc_214589672704_item	2301796	et	3	main
ning	doc_214589672704_item	2301798	et	3	main
luksusteta	doc_214589672704_item	2301806	et	4	main
inimesed	doc_214589672704_item	2301813	et	3	main
isegi	doc_214589672704_item	2301817	et	4	main
kiviajas	doc_214589672704_item	2301818	et	3	main
rohkem	doc_214589672703_item	2301531	et	4	main
mobiiltelefon	doc_214589672703_item	2301545	et	3	main
magnetlaineid	doc_214589672703_item	2301548	et	4	main
juhtudest	doc_214589672703_item	2301552	et	3	main
lõpeb	doc_214589672703_item	2301553	et	4	main
aga	doc_214589672703_item	2301554	et	3	main
noored	doc_214589672703_item	2301558	et	3	main
tegude	doc_214589672703_item	2301562	et	3	main
eest	doc_214589672703_item	2301563	et	4	main
vastutada	doc_214589672703_item	2301564	et	3	main
ning	doc_214589672703_item	2301565	et	3	main
käituvad	doc_214589672703_item	2301566	et	4	main
hetke	doc_214589672703_item	2301567	et	4	main
ajendil	doc_214589672703_item	2301568	et	3	main
selle	doc_214589672703_item	2301569	et	4	main
pärast	doc_214589672703_item	2301570	et	4	main
on	doc_214589672703_item	2301571	et	4	main
neile	doc_214589672703_item	2301572	et	4	main
kehtestatud	doc_214589672703_item	2301573	et	4	main
piirid	doc_214589672703_item	2301574	et	3	main
millest	doc_214589672703_item	2301575	et	3	main
ei	doc_214589672703_item	2301576	et	4	main
on	doc_214589672703_item	2301585	et	4	main
tänapäevainimene	doc_214589672704_item	2301588	et	3	main
et	doc_214589672704_item	2301603	et	3	main
teeksid	doc_214589672704_item	2301605	et	4	main
neid	doc_214589672704_item	2301608	et	4	main
ei	doc_214589672704_item	2301610	et	4	main
oleks	doc_214589672704_item	2301611	et	3	main
antud	doc_214589672704_item	2301612	et	4	main
päevakohane	doc_214589672704_item	2301613	et	4	main
teema	doc_214589672704_item	2301614	et	4	main
tänapäevainimene	doc_214589672704_item	2301623	et	3	main
tõenäoliselt	doc_214589672704_item	2301627	et	4	main
ja	doc_214589672704_item	2301635	et	3	main
õpilasel	doc_214589672704_item	2301636	et	3	main
on	doc_214589672704_item	2301637	et	4	main
pidev	doc_214589672704_item	2301638	et	3	main
otseühendus	doc_214589672704_item	2301639	et	3	main
läbi	doc_214589672704_item	2301640	et	4	main
pisikese	doc_214589672704_item	2301641	et	4	main
aga	doc_214589672704_item	2301645	et	3	main
tänu	doc_214589672704_item	2301652	et	4	main
on	doc_214589672704_item	2301654	et	4	main
hoopis	doc_214589672704_item	2301655	et	3	main
see	doc_214589672704_item	2301657	et	3	main
telekat	doc_214589672704_item	2301668	et	3	main
rääkida	doc_214589672704_item	2301673	et	3	main
enamusele	doc_214589672704_item	2301682	et	4	main
oleks	doc_214589672704_item	2301686	et	3	main
öelda	doc_214589672704_item	2301694	et	4	main
kui	doc_214589672704_item	2301696	et	3	main
enam	doc_214589672704_item	2301699	et	4	main
siis	doc_214589672704_item	2301703	et	3	main
või	doc_214589672704_item	2301723	et	4	main
minu	doc_214589672704_item	2301732	et	3	main
raske	doc_214589672704_item	2301748	et	4	main
kasutades	doc_214589672704_item	2301752	et	3	main
saaks	doc_214589672704_item	2301772	et	3	main
endale	doc_214589672704_item	2301775	et	4	main
lubada	doc_214589672704_item	2301776	et	3	main
ei	doc_214589672704_item	2301779	et	4	main
tööl	doc_214589672704_item	2301782	et	3	main
riskantne	doc_214589672704_item	2301797	et	3	main
nüüdisaegsete	doc_214589672704_item	2301805	et	4	main
nagu	doc_214589672704_item	2301807	et	3	main
arvan	doc_214589672704_item	2301819	et	3	main
et	doc_214589672704_item	2301820	et	3	main
inimesed	doc_214589672704_item	2301821	et	3	main
nad	doc_214589672704_item	2301828	et	3	main
tänapäeva	doc_214589672705_item	2301839	et	4	main
elada	doc_214589672705_item	2301849	et	3	main
silmi	doc_214589672705_item	2301853	et	4	main
ilma	doc_214589672705_item	2301857	et	4	main
kõik	doc_214589672705_item	2301860	et	4	main
ja	doc_214589672705_item	2301873	et	3	main
töövahend	doc_214589672705_item	2301881	et	3	main
aladel	doc_214589672705_item	2301883	et	3	main
asendamatu	doc_214589672705_item	2301892	et	4	main
me	doc_214589672705_item	2301893	et	4	main
nii	doc_214589672705_item	2301895	et	3	main
harjunud	doc_214589672705_item	2301896	et	4	main
ei	doc_214589672705_item	2301905	et	4	main
ainult	doc_214589672705_item	2301916	et	4	main
huvipakkuv	doc_214589672704_item	2301617	et	3	main
ning	doc_214589672704_item	2301618	et	3	main
anda	doc_214589672704_item	2301620	et	3	main
küsimuselemilleta	doc_214589672704_item	2301622	et	4	main
ei	doc_214589672704_item	2301625	et	4	main
õpetajal	doc_214589672704_item	2301634	et	4	main
võttes	doc_214589672704_item	2301643	et	4	main
seda	doc_214589672704_item	2301646	et	3	main
mugavused	doc_214589672704_item	2301649	et	4	main
milleta	doc_214589672704_item	2301658	et	3	main
oma	doc_214589672704_item	2301660	et	4	main
ette	doc_214589672704_item	2301662	et	4	main
ei	doc_214589672704_item	2301666	et	4	main
telefoniga	doc_214589672704_item	2301672	et	4	main
internetis	doc_214589672704_item	2301675	et	4	main
elu	doc_214589672704_item	2301677	et	4	main
ilma	doc_214589672704_item	2301678	et	4	main
nende	doc_214589672704_item	2301679	et	4	main
tingimusteta	doc_214589672704_item	2301680	et	3	main
tasemel	doc_214589672704_item	2301690	et	3	main
järelduseks	doc_214589672704_item	2301692	et	4	main
mil	doc_214589672704_item	2301725	et	4	main
a	doc_214589672704_item	2301743	et	4	main
punkti	doc_214589672704_item	2301744	et	4	main
oleks	doc_214589672704_item	2301746	et	3	main
hobusega	doc_214589672704_item	2301766	et	4	main
võtaks	doc_214589672704_item	2301768	et	3	main
aega	doc_214589672704_item	2301770	et	4	main
ei	doc_214589672704_item	2301771	et	4	main
rännakute	doc_214589672704_item	2301777	et	3	main
käia	doc_214589672704_item	2301783	et	4	main
leiba	doc_214589672704_item	2301785	et	4	main
teenida	doc_214589672704_item	2301786	et	3	main
samuti	doc_214589672704_item	2301787	et	3	main
oleks	doc_214589672704_item	2301788	et	3	main
aeglane	doc_214589672704_item	2301792	et	3	main
postitõllaga	doc_214589672704_item	2301795	et	3	main
lõpetuseks	doc_214589672704_item	2301800	et	4	main
ja	doc_214589672704_item	2301810	et	3	main
keskajas	doc_214589672704_item	2301815	et	3	main
ei	doc_214589672704_item	2301822	et	4	main
on	doc_214589672704_item	2301829	et	4	main
mugavustega	doc_214589672704_item	2301837	et	4	main
milleta	doc_214589672705_item	2301846	et	3	main
inimene	doc_214589672705_item	2301848	et	3	main
isegi	doc_214589672705_item	2301852	et	4	main
oska	doc_214589672705_item	2301855	et	4	main
et	doc_214589672705_item	2301864	et	3	main
jala	doc_214589672705_item	2301870	et	4	main
ei	doc_214589672705_item	2301871	et	4	main
vett	doc_214589672705_item	2301874	et	3	main
asendamatu	doc_214589672705_item	2301880	et	4	main
erinevatel	doc_214589672705_item	2301882	et	4	main
oma	doc_214589672705_item	2301884	et	4	main
ja	doc_214589672705_item	2301886	et	3	main
ka	doc_214589672705_item	2301887	et	3	main
kogumiseks	doc_214589672705_item	2301889	et	4	main
enam	doc_214589672705_item	2301900	et	4	main
teistmoodi	doc_214589672705_item	2301901	et	3	main
hakkama	doc_214589672705_item	2301902	et	3	main
saada	doc_214589672705_item	2301903	et	4	main
masinad	doc_214589672705_item	2301904	et	3	main
mitte	doc_214589672705_item	2301908	et	3	main
ei	doc_214589672705_item	2301922	et	4	main
katastroofid	doc_214589672706_item	2301927	et	3	main
eestlaste	doc_214589672706_item	2301930	et	4	main
on	doc_214589672706_item	2301944	et	4	main
mõtlema	doc_214589672706_item	2301949	et	3	main
ümber	doc_214589672706_item	2301951	et	3	main
oma	doc_214589672706_item	2301953	et	4	main
ja	doc_214589672706_item	2301955	et	3	main
kuid	doc_214589672706_item	2301957	et	4	main
mitte	doc_214589672706_item	2301959	et	3	main
saaks	doc_214589672707_item	2301965	et	3	main
laused	doc_214589672707_item	2301967	et	3	main
tänapäeval	doc_214589672707_item	2301969	et	3	main
elada	doc_214589672707_item	2301970	et	3	main
saaks	doc_214589672707_item	2301972	et	3	main
mugavaks	doc_214589672707_item	2301978	et	3	main
et	doc_214589672707_item	2301981	et	3	main
kujutagi	doc_214589672707_item	2301984	et	4	main
ette	doc_214589672707_item	2301985	et	4	main
saaks	doc_214589672704_item	2301626	et	3	main
pea	doc_214589672704_item	2301629	et	4	main
et	doc_214589672704_item	2301647	et	3	main
toimivad	doc_214589672704_item	2301650	et	4	main
vaid	doc_214589672704_item	2301651	et	3	main
elu	doc_214589672704_item	2301661	et	4	main
ei	doc_214589672704_item	2301663	et	4	main
ega	doc_214589672704_item	2301674	et	3	main
kohutav	doc_214589672704_item	2301683	et	4	main
ilma	doc_214589672704_item	2301684	et	4	main
võib	doc_214589672704_item	2301693	et	3	main
et	doc_214589672704_item	2301695	et	3	main
kõrgepinget	doc_214589672704_item	2301700	et	3	main
tsivilisatsiooni	doc_214589672704_item	2301705	et	4	main
kokkuvarisemine	doc_214589672704_item	2301706	et	3	main
ilma	doc_214589672704_item	2301707	et	4	main
poleks	doc_214589672704_item	2301709	et	3	main
ka	doc_214589672704_item	2301710	et	3	main
pinevuseta	doc_214589672704_item	2301708	et	4	main
kanalisatsiooni	doc_214589672704_item	2301711	et	4	main
ning	doc_214589672704_item	2301712	et	3	main
elu	doc_214589672704_item	2301713	et	4	main
oleks	doc_214589672704_item	2301714	et	3	main
väga	doc_214589672704_item	2301715	et	3	main
närvesööv	doc_214589672704_item	2301716	et	3	main
elanikud	doc_214589672704_item	2301717	et	3	main
ei	doc_214589672704_item	2301718	et	4	main
kujutakski	doc_214589672704_item	2301719	et	4	main
ette	doc_214589672704_item	2301720	et	4	main
kuivkäimlaga	doc_214589672704_item	2301722	et	3	main
oleks	doc_214589672704_item	2301734	et	3	main
veevärgita	doc_214589672704_item	2301736	et	3	main
mustemad	doc_214589672704_item	2301740	et	4	main
punktist	doc_214589672704_item	2301742	et	4	main
ilma	doc_214589672704_item	2301749	et	4	main
transpordivahenditeta	doc_214589672704_item	2301751	et	3	main
vaid	doc_214589672704_item	2301753	et	3	main
ja	doc_214589672704_item	2301755	et	3	main
jalgu	doc_214589672704_item	2301757	et	4	main
oleksid	doc_214589672704_item	2301758	et	4	main
veel	doc_214589672704_item	2301759	et	4	main
paljud	doc_214589672704_item	2301760	et	3	main
saared	doc_214589672704_item	2301761	et	3	main
ja	doc_214589672704_item	2301762	et	3	main
maaalad	doc_214589672704_item	2301763	et	3	main
avastamata	doc_214589672704_item	2301764	et	4	main
lihtinimesed	doc_214589672704_item	2301773	et	3	main
kaubavahetus	doc_214589672704_item	2301789	et	4	main
sest	doc_214589672704_item	2301793	et	4	main
ebaturvaline	doc_214589672704_item	2301799	et	4	main
võin	doc_214589672704_item	2301801	et	3	main
et	doc_214589672704_item	2301803	et	3	main
elekter	doc_214589672704_item	2301808	et	3	main
oleksid	doc_214589672704_item	2301812	et	4	main
taas	doc_214589672704_item	2301814	et	3	main
saanud	doc_214589672704_item	2301825	et	4	main
kui	doc_214589672704_item	2301826	et	3	main
milleta	doc_214589672705_item	2301838	et	3	main
elada	doc_214589672705_item	2301841	et	3	main
saaks	doc_214589672705_item	2301843	et	3	main
eestlaste	doc_214589672705_item	2301844	et	4	main
laused	doc_214589672705_item	2301845	et	3	main
tehnikata	doc_214589672705_item	2301858	et	3	main
pesta	doc_214589672705_item	2301859	et	4	main
hoolitsevad	doc_214589672705_item	2301861	et	4	main
selle	doc_214589672705_item	2301862	et	4	main
käi	doc_214589672705_item	2301872	et	4	main
ei	doc_214589672705_item	2301875	et	4	main
on	doc_214589672705_item	2301878	et	4	main
ainult	doc_214589672705_item	2301909	et	4	main
vaid	doc_214589672705_item	2301911	et	3	main
loota	doc_214589672705_item	2301917	et	4	main
et	doc_214589672705_item	2301918	et	3	main
kätetöö	doc_214589672705_item	2301921	et	4	main
hakkaks	doc_214589672705_item	2301923	et	3	main
eest	doc_214589672705_item	2301925	et	4	main
inimesed	doc_214589672706_item	2301935	et	3	main
tihti	doc_214589672706_item	2301936	et	3	main
oska	doc_214589672706_item	2301938	et	4	main
antud	doc_214589672706_item	2301943	et	4	main
sündmused	doc_214589672706_item	2301946	et	3	main
inimesed	doc_214589672706_item	2301948	et	3	main
milleta	doc_214589672707_item	2301961	et	3	main
ei	doc_214589672707_item	2301971	et	4	main
tänapäevamaailm	doc_214589672707_item	2301973	et	3	main
teistsugusena	doc_214589672707_item	2301988	et	3	main
ilma	doc_214589672707_item	2302002	et	4	main
televiisorita	doc_214589672707_item	2302003	et	3	main
esikohal	doc_214589672707_item	2302016	et	4	main
ja	doc_214589672707_item	2302017	et	3	main
aru	doc_214589672704_item	2301824	et	4	main
elavad	doc_214589672704_item	2301831	et	4	main
just	doc_214589672704_item	2301832	et	3	main
koos	doc_214589672704_item	2301835	et	4	main
kõikide	doc_214589672704_item	2301836	et	4	main
tänapäeva	doc_214589672705_item	2301847	et	4	main
ei	doc_214589672705_item	2301850	et	4	main
majapidamises	doc_214589672705_item	2301865	et	3	main
vajalikud	doc_214589672705_item	2301867	et	3	main
põhimõttel	doc_214589672705_item	2301869	et	3	main
arvuti	doc_214589672705_item	2301877	et	4	main
on	doc_214589672705_item	2301890	et	4	main
ja	doc_214589672705_item	2301897	et	3	main
enam	doc_214589672705_item	2301907	et	4	main
meie	doc_214589672705_item	2301910	et	4	main
meil	doc_214589672705_item	2301913	et	4	main
elada	doc_214589672705_item	2301914	et	3	main
jääb	doc_214589672705_item	2301915	et	3	main
meie	doc_214589672705_item	2301919	et	4	main
oma	doc_214589672705_item	2301920	et	4	main
laused	doc_214589672706_item	2301931	et	3	main
katastroofid	doc_214589672706_item	2301932	et	3	main
panevad	doc_214589672706_item	2301933	et	4	main
mõtlema	doc_214589672706_item	2301934	et	3	main
neile	doc_214589672706_item	2301942	et	4	main
panevad	doc_214589672706_item	2301947	et	4	main
eesmärgid	doc_214589672706_item	2301954	et	3	main
vajadused	doc_214589672706_item	2301956	et	3	main
kauaks	doc_214589672706_item	2301960	et	3	main
elada	doc_214589672707_item	2301963	et	3	main
on	doc_214589672707_item	2301974	et	4	main
inimestele	doc_214589672707_item	2301976	et	3	main
ja	doc_214589672707_item	2301979	et	3	main
oma	doc_214589672707_item	2301986	et	4	main
ka	doc_214589672707_item	2302006	et	3	main
juba	doc_214589672707_item	2302008	et	3	main
aega	doc_214589672707_item	2302010	et	4	main
sellised	doc_214589672707_item	2302012	et	4	main
asjad	doc_214589672707_item	2302013	et	3	main
meie	doc_214589672707_item	2302014	et	4	main
enam	doc_214589672707_item	2302020	et	4	main
suuda	doc_214589672707_item	2302023	et	4	main
oska	doc_214589672707_item	2302025	et	4	main
ei	doc_214589672707_item	2302027	et	4	main
kuna	doc_214589672707_item	2302033	et	3	main
juba	doc_214589672707_item	2302036	et	3	main
harjunud	doc_214589672707_item	2302038	et	4	main
selle	doc_214589672707_item	2302039	et	4	main
ettekujutada	doc_214589672707_item	2302047	et	4	main
tehnoloogiata	doc_214589672707_item	2302049	et	3	main
paar	doc_214589672707_item	2302057	et	3	main
need	doc_214589672707_item	2302075	et	3	main
meie	doc_214589672707_item	2302082	et	4	main
kõik	doc_214589672707_item	2302092	et	4	main
need	doc_214589672707_item	2302093	et	3	main
võib	doc_214589672707_item	2302106	et	3	main
inimesed	doc_214589672707_item	2302108	et	3	main
muuta	doc_214589672707_item	2302110	et	4	main
kui	doc_214589672707_item	2302118	et	3	main
saab	doc_214589672707_item	2302119	et	3	main
palju	doc_214589672707_item	2302121	et	4	main
sõita	doc_214589672707_item	2302125	et	3	main
suudavad	doc_214589672707_item	2302131	et	3	main
või	doc_214589672707_item	2302135	et	4	main
ei	doc_214589672707_item	2302139	et	4	main
rahalisiressursse	doc_214589672707_item	2302141	et	4	main
selliste	doc_214589672707_item	2302142	et	4	main
asjade	doc_214589672707_item	2302143	et	3	main
ostmiseks	doc_214589672707_item	2302144	et	4	main
ja	doc_214589672707_item	2302145	et	3	main
nad	doc_214589672707_item	2302146	et	3	main
liigselt	doc_214589672707_item	2302155	et	4	main
ja	doc_214589672708_item	2302172	et	3	main
võlud	doc_214589672708_item	2302179	et	4	main
ja	doc_214589672708_item	2302188	et	3	main
inimene	doc_214589672708_item	2302199	et	3	main
see	doc_214589672708_item	2302212	et	3	main
õnnestunud	doc_214589672708_item	2302215	et	4	main
niimoodi	doc_214589672708_item	2302216	et	3	main
võimalik	doc_214589672708_item	2302223	et	3	main
joo	doc_214589672705_item	2301876	et	4	main
tänapäeval	doc_214589672705_item	2301879	et	3	main
lõbuks	doc_214589672705_item	2301885	et	3	main
teadmiste	doc_214589672705_item	2301888	et	4	main
internet	doc_214589672705_item	2301891	et	4	main
oleme	doc_214589672705_item	2301894	et	3	main
ei	doc_214589672705_item	2301898	et	4	main
oskagi	doc_214589672705_item	2301899	et	4	main
ole	doc_214589672705_item	2301906	et	4	main
aitavad	doc_214589672705_item	2301912	et	4	main
mõtlema	doc_214589672705_item	2301926	et	3	main
mõtlema	doc_214589672706_item	2301929	et	3	main
ei	doc_214589672706_item	2301937	et	4	main
hinnata	doc_214589672706_item	2301939	et	4	main
seda	doc_214589672706_item	2301940	et	3	main
mis	doc_214589672706_item	2301941	et	4	main
ja	doc_214589672706_item	2301950	et	3	main
hindama	doc_214589672706_item	2301952	et	3	main
seda	doc_214589672706_item	2301958	et	3	main
milleta	doc_214589672707_item	2301968	et	3	main
muudetud	doc_214589672707_item	2301975	et	4	main
modernses	doc_214589672707_item	2301989	et	3	main
keegi	doc_214589672707_item	2301996	et	4	main
oam	doc_214589672707_item	2301997	et	4	main
elu	doc_214589672707_item	2301998	et	4	main
tehnoloogiata	doc_214589672707_item	2302001	et	3	main
mobiiltelefonita	doc_214589672707_item	2302004	et	3	main
autota	doc_214589672707_item	2302007	et	3	main
elus	doc_214589672707_item	2302015	et	4	main
palju	doc_214589672707_item	2302026	et	4	main
mobiiltelefonita	doc_214589672707_item	2302032	et	3	main
on	doc_214589672707_item	2302035	et	4	main
ka	doc_214589672707_item	2302044	et	3	main
juba	doc_214589672707_item	2302078	et	3	main
elust	doc_214589672707_item	2302084	et	3	main
elada	doc_214589672707_item	2302089	et	3	main
nendeta	doc_214589672707_item	2302090	et	4	main
on	doc_214589672707_item	2302095	et	4	main
see	doc_214589672707_item	2302105	et	3	main
keegi	doc_214589672707_item	2302113	et	4	main
ei	doc_214589672707_item	2302115	et	4	main
kõnni	doc_214589672707_item	2302116	et	4	main
trepist	doc_214589672707_item	2302117	et	3	main
ja	doc_214589672707_item	2302123	et	3	main
meie	doc_214589672705_item	2301924	et	4	main
panevad	doc_214589672706_item	2301928	et	4	main
sellised	doc_214589672706_item	2301945	et	4	main
tänapäeval	doc_214589672707_item	2301962	et	3	main
ei	doc_214589672707_item	2301964	et	4	main
eestlaste	doc_214589672707_item	2301966	et	4	main
niivõrd	doc_214589672707_item	2301977	et	3	main
tehnoloogiliseks	doc_214589672707_item	2301980	et	4	main
inimesed	doc_214589672707_item	2301982	et	3	main
ei	doc_214589672707_item	2301983	et	4	main
nagu	doc_214589672707_item	2301991	et	3	main
elame	doc_214589672707_item	2301993	et	3	main
ette	doc_214589672707_item	2301999	et	4	main
ega	doc_214589672707_item	2302005	et	3	main
pikemat	doc_214589672707_item	2302009	et	4	main
on	doc_214589672707_item	2302011	et	4	main
milleta	doc_214589672707_item	2302018	et	3	main
ei	doc_214589672707_item	2302022	et	4	main
ega	doc_214589672707_item	2302024	et	3	main
nii	doc_214589672707_item	2302037	et	3	main
oma	doc_214589672707_item	2302045	et	4	main
küll	doc_214589672707_item	2302051	et	4	main
suudan	doc_214589672707_item	2302052	et	3	main
vaatamata	doc_214589672707_item	2302055	et	4	main
asjad	doc_214589672707_item	2302076	et	3	main
suure	doc_214589672707_item	2302080	et	3	main
meil	doc_214589672707_item	2302085	et	4	main
olegi	doc_214589672707_item	2302087	et	4	main
mõeldud	doc_214589672707_item	2302097	et	4	main
elu	doc_214589672707_item	2302101	et	4	main
lihtsamaks	doc_214589672707_item	2302102	et	4	main
ega	doc_214589672707_item	2302112	et	3	main
ju	doc_214589672707_item	2302114	et	3	main
elada	doc_214589672707_item	2302132	et	3	main
olegi	doc_214589672707_item	2302140	et	4	main
ennast	doc_214589672707_item	2302154	et	4	main
eestlaste	doc_214589672708_item	2302174	et	4	main
ümbritseb	doc_214589672708_item	2302185	et	3	main
puutu	doc_214589672708_item	2302195	et	4	main
sellega	doc_214589672708_item	2302198	et	3	main
püüdnud	doc_214589672708_item	2302202	et	4	main
loodust	doc_214589672708_item	2302203	et	4	main
vallutada	doc_214589672708_item	2302204	et	3	main
aga	doc_214589672708_item	2302226	et	3	main
saanud	doc_214589672708_item	2302235	et	4	main
ei	doc_214589672708_item	2302238	et	4	main
täielikult	doc_214589672708_item	2302240	et	4	main
usaldada	doc_214589672708_item	2302241	et	3	main
meie	doc_214589672708_item	2302251	et	4	main
me	doc_214589672708_item	2302254	et	4	main
palju	doc_214589672708_item	2302267	et	4	main
inimesi	doc_214589672708_item	2302269	et	4	main
elavadki	doc_214589672708_item	2302271	et	4	main
teisi	doc_214589672708_item	2302272	et	4	main
pettes	doc_214589672708_item	2302273	et	4	main
kõik	doc_214589672708_item	2302279	et	4	main
mida	doc_214589672708_item	2302322	et	4	main
maailmas	doc_214589672708_item	2302323	et	3	main
leidub	doc_214589672708_item	2302324	et	3	main
kontrolltöö	doc_224629419611_item	2302325	et	4	main
kultuur	doc_224629419611_item	2302328	et	3	main
ii	doc_224629419611_item	2302331	et	4	main
ülikool	doc_224629419611_item	2302338	et	4	main
koduloomi	doc_224629419611_item	2302347	et	4	main
aega	doc_224629419611_item	2302357	et	4	main
teosed	doc_224629419611_item	2302364	et	3	main
oli	doc_224629419611_item	2302372	et	3	main
folklorist	doc_224629419611_item	2302374	et	4	main
näitlejad	doc_224629419611_item	2302385	et	4	main
d	doc_224629419611_item	2302388	et	4	main
olulised	doc_224629419611_item	2302397	et	4	main
muutused	doc_224629419611_item	2302398	et	4	main
kultuurielus	doc_224629419611_item	2302400	et	4	main
nõukogulike	doc_224629419611_item	2302404	et	3	main
kultuurimudelite	doc_224629419611_item	2302405	et	3	main
alusel	doc_224629419611_item	2302406	et	4	main
lääne-euroopaga	doc_224629419611_item	2302411	et	3	main
venemaaga	doc_224629419611_item	2302413	et	3	main
oli	doc_224629419611_item	2302417	et	3	main
populaarseks	doc_224629419611_item	2302418	et	4	main
põhjamaade	doc_224629419611_item	2302422	et	3	main
ühiskultuuri	doc_224629419611_item	2302423	et	4	main
elu	doc_214589672707_item	2301987	et	4	main
maailmas	doc_214589672707_item	2301990	et	3	main
me	doc_214589672707_item	2301992	et	4	main
ei	doc_214589672707_item	2301994	et	4	main
kujuta	doc_214589672707_item	2301995	et	4	main
ilma	doc_214589672707_item	2302000	et	4	main
inimesed	doc_214589672707_item	2302019	et	3	main
elada	doc_214589672707_item	2302021	et	3	main
suuda	doc_214589672707_item	2302028	et	4	main
päevagi	doc_214589672707_item	2302029	et	4	main
vastupidada	doc_214589672707_item	2302030	et	4	main
nad	doc_214589672707_item	2302034	et	3	main
oska	doc_214589672707_item	2302043	et	4	main
olla	doc_214589672707_item	2302053	et	3	main
televiisorit	doc_214589672707_item	2302054	et	3	main
ilma	doc_214589672707_item	2302071	et	4	main
selliste	doc_214589672707_item	2302072	et	4	main
asjadeta	doc_214589672707_item	2302073	et	3	main
kuna	doc_214589672707_item	2302074	et	3	main
nii	doc_214589672707_item	2302079	et	3	main
osa	doc_214589672707_item	2302081	et	4	main
sest	doc_214589672707_item	2302091	et	4	main
välja	doc_214589672707_item	2302096	et	4	main
et	doc_214589672707_item	2302099	et	3	main
paljud	doc_214589672707_item	2302107	et	3	main
laisaks	doc_214589672707_item	2302109	et	4	main
liftiga	doc_214589672707_item	2302120	et	3	main
kes	doc_214589672707_item	2302130	et	4	main
ilma	doc_214589672707_item	2302133	et	4	main
materjaalsete	doc_214589672707_item	2302156	et	4	main
ja	doc_214589672707_item	2302158	et	3	main
võlud	doc_214589672708_item	2302171	et	4	main
ohud	doc_214589672708_item	2302173	et	3	main
laused	doc_214589672708_item	2302175	et	3	main
inimest	doc_214589672708_item	2302176	et	3	main
ja	doc_214589672708_item	2302183	et	3	main
kõikjal	doc_214589672708_item	2302187	et	3	main
on	doc_214589672708_item	2302189	et	4	main
kunagi	doc_214589672708_item	2302196	et	3	main
ronides	doc_214589672708_item	2302205	et	4	main
kõrgustesse	doc_214589672708_item	2302206	et	4	main
ja	doc_214589672708_item	2302207	et	3	main
aga	doc_214589672708_item	2302211	et	3	main
pole	doc_214589672708_item	2302213	et	3	main
on	doc_214589672708_item	2302217	et	4	main
aru	doc_214589672708_item	2302219	et	4	main
et	doc_214589672708_item	2302221	et	3	main
oma	doc_214589672708_item	2302231	et	4	main
jooksul	doc_214589672708_item	2302233	et	4	main
nii	doc_214589672708_item	2302246	et	3	main
et	doc_214589672708_item	2302247	et	3	main
petab	doc_214589672708_item	2302250	et	3	main
siiski	doc_214589672708_item	2302258	et	4	main
sest	doc_214589672708_item	2302264	et	4	main
ja	doc_214589672708_item	2302274	et	3	main
haiget	doc_214589672708_item	2302276	et	3	main
oleme	doc_214589672708_item	2302280	et	3	main
käitume	doc_214589672708_item	2302283	et	3	main
teiste	doc_214589672708_item	2302289	et	4	main
ilma	doc_214589672707_item	2302031	et	4	main
mugavusega	doc_214589672707_item	2302040	et	4	main
mina	doc_214589672707_item	2302041	et	4	main
ei	doc_214589672707_item	2302042	et	4	main
elu	doc_214589672707_item	2302046	et	4	main
ilma	doc_214589672707_item	2302048	et	4	main
ma	doc_214589672707_item	2302050	et	3	main
või	doc_214589672707_item	2302056	et	4	main
päeva	doc_214589672707_item	2302058	et	4	main
telefoniga	doc_214589672707_item	2302059	et	4	main
rääkimata	doc_214589672707_item	2302060	et	4	main
kuid	doc_214589672707_item	2302061	et	4	main
seda	doc_214589672707_item	2302062	et	3	main
ainult	doc_214589672707_item	2302063	et	4	main
hädavajalikul	doc_214589672707_item	2302064	et	3	main
juhul	doc_214589672707_item	2302065	et	3	main
tänapäevainimesed	doc_214589672707_item	2302066	et	3	main
ei	doc_214589672707_item	2302067	et	4	main
suuda	doc_214589672707_item	2302068	et	4	main
lihtsalt	doc_214589672707_item	2302069	et	4	main
elada	doc_214589672707_item	2302070	et	3	main
moodustavad	doc_214589672707_item	2302077	et	4	main
igapäeva	doc_214589672707_item	2302083	et	4	main
ei	doc_214589672707_item	2302086	et	4	main
vaja	doc_214589672707_item	2302088	et	4	main
asjad	doc_214589672707_item	2302094	et	3	main
selleks	doc_214589672707_item	2302098	et	4	main
meie	doc_214589672707_item	2302100	et	4	main
muuta	doc_214589672707_item	2302103	et	4	main
kuigi	doc_214589672707_item	2302104	et	3	main
sest	doc_214589672707_item	2302111	et	4	main
kindlasti	doc_214589672707_item	2302127	et	3	main
mobiiltelefonita	doc_214589672707_item	2302134	et	3	main
paljudel	doc_214589672707_item	2302137	et	3	main
lihtsalt	doc_214589672707_item	2302147	et	4	main
peavad	doc_214589672707_item	2302148	et	4	main
hakkama	doc_214589672707_item	2302149	et	3	main
saama	doc_214589672707_item	2302150	et	4	main
ilma	doc_214589672707_item	2302151	et	4	main
nad	doc_214589672707_item	2302152	et	3	main
seovad	doc_214589672707_item	2302153	et	3	main
fauna	doc_214589672708_item	2302184	et	4	main
võimatu	doc_214589672708_item	2302190	et	4	main
elada	doc_214589672708_item	2302191	et	3	main
nii	doc_214589672708_item	2302192	et	3	main
et	doc_214589672708_item	2302193	et	3	main
ei	doc_214589672708_item	2302194	et	4	main
kokku	doc_214589672708_item	2302197	et	3	main
alati	doc_214589672708_item	2302201	et	4	main
ookeane	doc_214589672708_item	2302209	et	3	main
on	doc_214589672708_item	2302222	et	4	main
võita	doc_214589672708_item	2302227	et	4	main
aru	doc_214589672708_item	2302234	et	4	main
sest	doc_214589672708_item	2302242	et	4	main
kunagi	doc_214589672708_item	2302243	et	3	main
juhtub	doc_214589672708_item	2302244	et	3	main
inimene	doc_214589672708_item	2302249	et	3	main
usaldust	doc_214589672708_item	2302252	et	4	main
ei	doc_214589672708_item	2302259	et	4	main
saa	doc_214589672708_item	2302260	et	4	main
on	doc_214589672708_item	2302266	et	4	main
tehes	doc_214589672708_item	2302277	et	3	main
unikaalsed	doc_214589672708_item	2302281	et	3	main
erinevalt	doc_214589672708_item	2302284	et	4	main
inimeste	doc_214589672708_item	2302290	et	3	main
sõja	doc_224629419611_item	2302334	et	3	main
ajal	doc_224629419611_item	2302335	et	4	main
tartu	doc_224629419611_item	2302337	et	4	main
raske	doc_224629419611_item	2302356	et	4	main
smuul	doc_224629419611_item	2302359	et	4	main
kuulub	doc_224629419611_item	2302360	et	3	main
sotsialistide	doc_224629419611_item	2302361	et	3	main
hulka	doc_224629419611_item	2302362	et	4	main
teoseid	doc_224629419611_item	2302369	et	3	main
ernesaks	doc_224629419611_item	2302381	et	4	main
vaarandi	doc_224629419611_item	2302389	et	4	main
e	doc_224629419611_item	2302390	et	4	main
muutunud	doc_224629419611_item	2302419	et	4	main
tunnetamine	doc_224629419611_item	2302421	et	4	main
aastatesse	doc_224629419611_item	2302432	et	4	main
ja	doc_224629419611_item	2302434	et	3	main
natsistid	doc_224629419611_item	2302436	et	4	main
nõukogude	doc_224629419611_item	2302449	et	3	main
looming	doc_224629419611_item	2302456	et	3	main
seoti	doc_224629419611_item	2302458	et	3	main
sotsialistlik	doc_224629419611_item	2302465	et	3	main
pidi	doc_224629419611_item	2302468	et	4	main
koondunud	doc_224629419611_item	2302503	et	4	main
esto	doc_224629419611_item	2302505	et	4	main
1972a	doc_224629419611_item	2302510	et	4	main
ja	doc_224629419611_item	2302512	et	3	main
tegutseb	doc_224629419611_item	2302514	et	3	main
kiiremini	doc_214589672707_item	2302122	et	4	main
mugavamalt	doc_214589672707_item	2302124	et	4	main
veel	doc_214589672707_item	2302126	et	4	main
on	doc_214589672707_item	2302128	et	4	main
inimesi	doc_214589672707_item	2302129	et	4	main
televiisorita	doc_214589672707_item	2302136	et	3	main
inimestel	doc_214589672707_item	2302138	et	3	main
asjadega	doc_214589672707_item	2302157	et	3	main
hiljem	doc_214589672707_item	2302159	et	3	main
on	doc_214589672707_item	2302160	et	4	main
saamatud	doc_214589672707_item	2302161	et	4	main
eluga	doc_214589672707_item	2302163	et	3	main
hakkama	doc_214589672707_item	2302164	et	3	main
oma	doc_214589672707_item	2302162	et	4	main
saama	doc_214589672707_item	2302165	et	4	main
asjadeta	doc_214589672707_item	2302167	et	3	main
nende	doc_214589672707_item	2302166	et	4	main
inimest	doc_214589672708_item	2302168	et	3	main
ümbritseva	doc_214589672708_item	2302169	et	4	main
maailma	doc_214589672708_item	2302170	et	4	main
ümbritseva	doc_214589672708_item	2302177	et	4	main
maailma	doc_214589672708_item	2302178	et	4	main
ja	doc_214589672708_item	2302180	et	3	main
ohud	doc_214589672708_item	2302181	et	3	main
floora	doc_214589672708_item	2302182	et	4	main
meid	doc_214589672708_item	2302186	et	4	main
on	doc_214589672708_item	2302200	et	4	main
püüdes	doc_214589672708_item	2302208	et	4	main
ületada	doc_214589672708_item	2302210	et	3	main
alati	doc_214589672708_item	2302214	et	4	main
inimesed	doc_214589672708_item	2302218	et	3	main
saanud	doc_214589672708_item	2302220	et	4	main
mitte	doc_214589672708_item	2302228	et	3	main
elu	doc_214589672708_item	2302232	et	4	main
et	doc_214589672708_item	2302236	et	3	main
ikka	doc_214589672708_item	2302245	et	4	main
saame	doc_214589672708_item	2302255	et	4	main
haiget	doc_214589672708_item	2302256	et	3	main
kuid	doc_214589672708_item	2302257	et	4	main
ennast	doc_214589672708_item	2302261	et	4	main
täielikult	doc_214589672708_item	2302262	et	4	main
avada	doc_214589672708_item	2302263	et	3	main
halbu	doc_214589672708_item	2302268	et	3	main
neile	doc_214589672708_item	2302275	et	4	main
seega	doc_214589672708_item	2302285	et	4	main
on	doc_214589672708_item	2302286	et	4	main
võimatu	doc_214589672708_item	2302287	et	4	main
eest	doc_214589672708_item	2302291	et	4	main
täielikult	doc_214589672708_item	2302292	et	4	main
kaitsta	doc_214589672708_item	2302293	et	4	main
elu	doc_214589672708_item	2302294	et	4	main
ei	doc_214589672708_item	2302295	et	4	main
ole	doc_214589672708_item	2302296	et	4	main
ainult	doc_214589672708_item	2302297	et	4	main
valu	doc_214589672708_item	2302298	et	4	main
ja	doc_214589672708_item	2302299	et	3	main
kannatused	doc_214589672708_item	2302300	et	4	main
rahvasuugi	doc_214589672708_item	2302301	et	4	main
ütleb	doc_214589672708_item	2302302	et	3	main
et	doc_214589672708_item	2302303	et	3	main
ilma	doc_214589672708_item	2302304	et	4	main
halvata	doc_214589672708_item	2302305	et	4	main
ei	doc_214589672708_item	2302306	et	4	main
ole	doc_214589672708_item	2302307	et	4	main
ka	doc_214589672708_item	2302308	et	3	main
kui	doc_214589672708_item	2302310	et	3	main
ei	doc_214589672708_item	2302311	et	4	main
oleks	doc_214589672708_item	2302312	et	3	main
head	doc_214589672708_item	2302309	et	4	main
ohte	doc_214589672708_item	2302313	et	4	main
ja	doc_214589672708_item	2302314	et	3	main
kurjust	doc_214589672708_item	2302315	et	4	main
ei	doc_214589672708_item	2302316	et	4	main
oskaks	doc_214589672708_item	2302317	et	3	main
me	doc_214589672708_item	2302318	et	4	main
väärtustada	doc_214589672708_item	2302319	et	3	main
kõike	doc_214589672708_item	2302320	et	4	main
3	doc_224629419611_item	2302326	et	2	main
tagalas	doc_224629419611_item	2302330	et	3	main
sel	doc_224629419611_item	2302345	et	3	main
ajal	doc_224629419611_item	2302346	et	4	main
ja	doc_224629419611_item	2302348	et	3	main
linde	doc_224629419611_item	2302349	et	4	main
smuul	doc_224629419611_item	2302351	et	4	main
lea	doc_224629419611_item	2302353	et	4	main
loodusega	doc_214589672708_item	2302224	et	4	main
võidelda	doc_214589672708_item	2302225	et	4	main
ma	doc_214589672708_item	2302229	et	3	main
olen	doc_214589672708_item	2302230	et	3	main
kedagi	doc_214589672708_item	2302237	et	4	main
saa	doc_214589672708_item	2302239	et	4	main
see	doc_214589672708_item	2302248	et	3	main
ja	doc_214589672708_item	2302253	et	3	main
maailmas	doc_214589672708_item	2302265	et	3	main
kes	doc_214589672708_item	2302270	et	4	main
me	doc_214589672708_item	2302278	et	4	main
ja	doc_214589672708_item	2302282	et	3	main
ennast	doc_214589672708_item	2302288	et	4	main
head	doc_214589672708_item	2302321	et	4	main
nõukogude	doc_224629419611_item	2302329	et	3	main
tegutseb	doc_224629419611_item	2302336	et	3	main
kasvatasid	doc_224629419611_item	2302344	et	4	main
juhan	doc_224629419611_item	2302350	et	3	main
seda	doc_224629419611_item	2302355	et	3	main
j	doc_224629419611_item	2302358	et	4	main
gustav	doc_224629419611_item	2302380	et	4	main
derigent	doc_224629419611_item	2302383	et	4	main
kapp	doc_224629419611_item	2302387	et	3	main
hiir	doc_224629419611_item	2302391	et	4	main
riigipööre	doc_224629419611_item	2302394	et	4	main
pannes	doc_224629419611_item	2302401	et	4	main
selle	doc_224629419611_item	2302402	et	4	main
arenema	doc_224629419611_item	2302403	et	3	main
192030	doc_224629419611_item	2302407	et	2	main
aastatel	doc_224629419611_item	2302408	et	4	main
kontakteeruda	doc_224629419611_item	2302410	et	4	main
enda	doc_224629419611_item	2302420	et	4	main
eesti	doc_224629419611_item	2302327	et	4	main
ms	doc_224629419611_item	2302332	et	4	main
ajal	doc_224629419611_item	2302333	et	4	main
väga	doc_224629419611_item	2302339	et	3	main
paljud	doc_224629419611_item	2302340	et	3	main
kirjanikud	doc_224629419611_item	2302341	et	3	main
vaikivad	doc_224629419611_item	2302342	et	4	main
eestlased	doc_224629419611_item	2302343	et	3	main
raamatus	doc_224629419611_item	2302352	et	4	main
kajastub	doc_224629419611_item	2302354	et	3	main
tema	doc_224629419611_item	2302363	et	4	main
mingil	doc_224629419611_item	2302365	et	4	main
määral	doc_224629419611_item	2302366	et	3	main
meenutavad	doc_224629419611_item	2302367	et	4	main
religioosseid	doc_224629419611_item	2302368	et	3	main
loorits	doc_224629419611_item	2302371	et	4	main
rahvaluule	doc_224629419611_item	2302376	et	4	main
arhiivi	doc_224629419611_item	2302377	et	4	main
tuntud	doc_224629419611_item	2302384	et	4	main
e	doc_224629419611_item	2302386	et	4	main
1940	doc_224629419611_item	2302392	et	2	main
aasta	doc_224629419611_item	2302393	et	4	main
tõi	doc_224629419611_item	2302395	et	3	main
eestlaste	doc_224629419611_item	2302399	et	4	main
ja	doc_224629419611_item	2302412	et	3	main
osana	doc_224629419611_item	2302424	et	3	main
kandjana	doc_224629419611_item	2302428	et	4	main
mahuvad	doc_224629419611_item	2302430	et	3	main
sõjameeleolud	doc_224629419611_item	2302433	et	3	main
keelasid	doc_224629419611_item	2302437	et	4	main
teisi	doc_224629419611_item	2302438	et	4	main
kultuuri	doc_224629419611_item	2302439	et	4	main
juudi	doc_224629419611_item	2302440	et	3	main
vene	doc_224629419611_item	2302441	et	4	main
vastu	doc_224629419611_item	2302447	et	3	main
okupatsiooni	doc_224629419611_item	2302450	et	4	main
aastast	doc_224629419611_item	2302452	et	4	main
hakkab	doc_224629419611_item	2302453	et	3	main
ilmuma	doc_224629419611_item	2302454	et	3	main
kirjanikutele	doc_224629419611_item	2302457	et	4	main
nõukogude	doc_224629419611_item	2302460	et	3	main
oli	doc_224629419611_item	2302464	et	3	main
siia	doc_224629419611_item	2302501	et	4	main
eksiilkirjanikud	doc_224629419611_item	2302504	et	3	main
ja	doc_224629419611_item	2302508	et	3	main
torontos	doc_224629419611_item	2302511	et	4	main
ainult	doc_224629419611_item	2302515	et	4	main
võetakse	doc_224629419611_item	2302519	et	3	main
tohi	doc_224629419611_item	2302525	et	4	main
1950ndatel	doc_224629419611_item	2302536	et	4	main
mis	doc_224629419611_item	2302541	et	4	main
poole	doc_224629419611_item	2302545	et	4	main
1940ndatel	doc_224629419611_item	2302546	et	4	main
olid	doc_224629419611_item	2302549	et	4	main
kirjanduses	doc_224629419611_item	2302554	et	3	main
natsionalismiga	doc_224629419611_item	2302561	et	3	main
kirjandusele	doc_224629419611_item	2302563	et	3	main
olla	doc_224629419611_item	2302570	et	3	main
tulevik	doc_224629419611_item	2302580	et	3	main
kõige	doc_224629419611_item	2302581	et	4	main
sellele	doc_224629419611_item	2302582	et	4	main
oli	doc_224629419611_item	2302586	et	3	main
tantsuansambel	doc_224629419611_item	2302598	et	3	main
ernesaksa	doc_224629419611_item	2302606	et	4	main
oskar	doc_224629419611_item	2302370	et	4	main
eesti	doc_224629419611_item	2302373	et	4	main
eesti	doc_224629419611_item	2302375	et	4	main
esimene	doc_224629419611_item	2302378	et	3	main
direktor	doc_224629419611_item	2302379	et	3	main
helilooja	doc_224629419611_item	2302382	et	4	main
kaasa	doc_224629419611_item	2302396	et	4	main
püüti	doc_224629419611_item	2302409	et	3	main
eesti	doc_224629419611_item	2302414	et	4	main
vabariigi	doc_224629419611_item	2302415	et	3	main
päevil	doc_224629419611_item	2302416	et	4	main
samuti	doc_224629419611_item	2302425	et	3	main
nendesse	doc_224629419611_item	2302431	et	4	main
prantsuse	doc_224629419611_item	2302442	et	3	main
toimusid	doc_224629419611_item	2302443	et	4	main
repressioonid	doc_224629419611_item	2302444	et	3	main
pärast	doc_224629419611_item	2302448	et	4	main
ajakiri	doc_224629419611_item	2302455	et	3	main
mudeli	doc_224629419611_item	2302461	et	3	main
kirjandusstiil	doc_224629419611_item	2302463	et	3	main
olid	doc_224629419611_item	2302502	et	4	main
korraldas	doc_224629419611_item	2302506	et	3	main
5	doc_224629419611_item	2302516	et	2	main
1946a	doc_224629419611_item	2302518	et	4	main
vastu	doc_224629419611_item	2302520	et	3	main
et	doc_224629419611_item	2302522	et	3	main
ei	doc_224629419611_item	2302524	et	4	main
mängida	doc_224629419611_item	2302526	et	3	main
ka	doc_224629419611_item	2302532	et	3	main
nõukogude	doc_224629419611_item	2302537	et	3	main
iseloomustab	doc_224629419611_item	2302539	et	4	main
satiir	doc_224629419611_item	2302540	et	3	main
suunatud	doc_224629419611_item	2302543	et	4	main
lääne	doc_224629419611_item	2302544	et	4	main
tiraazid	doc_224629419611_item	2302548	et	4	main
tollases	doc_224629419611_item	2302553	et	3	main
oli	doc_224629419611_item	2302555	et	3	main
imperialismiga	doc_224629419611_item	2302558	et	3	main
eestis	doc_224629419611_item	2302564	et	3	main
konfliktuseteooria	doc_224629419611_item	2302567	et	4	main
hea	doc_224629419611_item	2302571	et	4	main
parema	doc_224629419611_item	2302574	et	4	main
oli	doc_224629419611_item	2302577	et	3	main
nn	doc_224629419611_item	2302578	et	4	main
helge	doc_224629419611_item	2302579	et	4	main
paha	doc_224629419611_item	2302584	et	4	main
laulu-	doc_224629419611_item	2302596	et	4	main
põldroosi	doc_224629419611_item	2302600	et	4	main
meeskoor	doc_224629419611_item	2302604	et	4	main
sümfoonia-	doc_224629419611_item	2302608	et	4	main
sagrits	doc_224629419611_item	2302629	et	4	main
tagalaperioodi	doc_224629419611_item	2302638	et	4	main
loomeliitude	doc_224629419611_item	2302641	et	4	main
jegorjevski	doc_224629419611_item	2302643	et	4	main
kirjandus	doc_224629419612_item	2302650	et	3	main
aastatel	doc_224629419612_item	2302652	et	4	main
pleenum	doc_224629419612_item	2302660	et	3	main
korrale	doc_224629419612_item	2302668	et	3	main
kaadriametnikega	doc_224629419612_item	2302670	et	3	main
niivõrd	doc_224629419612_item	2302675	et	3	main
põhjalik	doc_224629419612_item	2302676	et	3	main
peaaegu	doc_224629419612_item	2302678	et	3	main
ilmunud	doc_224629419612_item	2302680	et	4	main
enam	doc_224629419612_item	2302681	et	4	main
raamatuhävitamine	doc_224629419612_item	2302686	et	3	main
oli	doc_224629419612_item	2302690	et	3	main
1953	doc_224629419612_item	2302692	et	2	main
sulaperiood	doc_224629419612_item	2302694	et	3	main
kirjandus	doc_224629419612_item	2302701	et	3	main
eksiilkirjandus	doc_224629419612_item	2302703	et	3	main
eesti	doc_224629419612_item	2302705	et	4	main
kirjandus	doc_224629419612_item	2302706	et	3	main
kuni	doc_224629419612_item	2302707	et	3	main
kirjanduses	doc_224629419612_item	2302711	et	3	main
oli	doc_224629419612_item	2302725	et	3	main
põhiliselt	doc_224629419612_item	2302731	et	4	main
hakkasid	doc_224629419612_item	2302739	et	4	main
ilmuma	doc_224629419612_item	2302740	et	3	main
nagu	doc_224629419612_item	2302743	et	3	main
vasar	doc_224629419612_item	2302745	et	3	main
kultuuri	doc_224629419611_item	2302427	et	4	main
rahvaste	doc_224629419611_item	2302446	et	4	main
1945	doc_224629419611_item	2302451	et	2	main
parteine	doc_224629419611_item	2302470	et	4	main
ideeline	doc_224629419611_item	2302471	et	4	main
rahvalik	doc_224629419611_item	2302472	et	3	main
kirjandusžanrid	doc_224629419611_item	2302474	et	2	main
peamised	doc_224629419611_item	2302473	et	3	main
olid	doc_224629419611_item	2302475	et	4	main
valdavalt	doc_224629419611_item	2302476	et	4	main
poeem	doc_224629419611_item	2302477	et	3	main
ja	doc_224629419611_item	2302478	et	3	main
draama	doc_224629419611_item	2302479	et	4	main
ainult	doc_224629419611_item	2302480	et	4	main
2	doc_224629419611_item	2302481	et	2	main
kirjanikut	doc_224629419611_item	2302482	et	4	main
olid	doc_224629419611_item	2302483	et	4	main
lubatud	doc_224629419611_item	2302484	et	4	main
nõukogude	doc_224629419611_item	2302485	et	3	main
ajal	doc_224629419611_item	2302486	et	4	main
l	doc_224629419611_item	2302487	et	4	main
koidula	doc_224629419611_item	2302488	et	4	main
ja	doc_224629419611_item	2302489	et	3	main
fr	doc_224629419611_item	2302490	et	4	main
kreutzwald	doc_224629419611_item	2302492	et	4	main
r	doc_224629419611_item	2302491	et	4	main
nad	doc_224629419611_item	2302493	et	3	main
olid	doc_224629419611_item	2302494	et	4	main
kooliprogrammi	doc_224629419611_item	2302495	et	4	main
sees	doc_224629419611_item	2302496	et	4	main
eesti	doc_224629419611_item	2302497	et	4	main
soome-ugri	doc_224629419611_item	2302426	et	3	main
ennekõike	doc_224629419611_item	2302429	et	3	main
purustused	doc_224629419611_item	2302435	et	4	main
teiste	doc_224629419611_item	2302445	et	4	main
nn	doc_224629419611_item	2302459	et	4	main
ainuke	doc_224629419611_item	2302462	et	4	main
realism	doc_224629419611_item	2302466	et	3	main
kirjandus	doc_224629419611_item	2302467	et	3	main
olema	doc_224629419611_item	2302469	et	4	main
ülemaailmne	doc_224629419611_item	2302498	et	3	main
kirjanduse	doc_224629419611_item	2302499	et	3	main
kanadas	doc_224629419611_item	2302513	et	4	main
teatrit	doc_224629419611_item	2302517	et	3	main
otsus	doc_224629419611_item	2302521	et	3	main
lavamängudes	doc_224629419611_item	2302523	et	3	main
oli	doc_224629419611_item	2302531	et	3	main
näitekirjanikutest	doc_224629419611_item	2302533	et	3	main
tähtsaks	doc_224629419611_item	2302551	et	4	main
kodaniku	doc_224629419611_item	2302557	et	3	main
nõukogude	doc_224629419611_item	2302562	et	3	main
võis	doc_224629419611_item	2302569	et	4	main
väga	doc_224629419611_item	2302587	et	3	main
kunstiansamblite	doc_224629419611_item	2302589	et	3	main
sega-	doc_224629419611_item	2302602	et	4	main
ja	doc_224629419611_item	2302603	et	3	main
g	doc_224629419611_item	2302605	et	4	main
raud	doc_224629419611_item	2302621	et	3	main
hint	doc_224629419611_item	2302623	et	4	main
jt	doc_224629419611_item	2302624	et	4	main
kunstnikke	doc_224629419611_item	2302625	et	3	main
jt	doc_224629419611_item	2302632	et	4	main
e	doc_224629419611_item	2302634	et	4	main
organiseerimine	doc_224629419611_item	2302642	et	4	main
õppekombinaadi	doc_224629419611_item	2302645	et	3	main
2	doc_224629419612_item	2302648	et	2	main
nõiajahti	doc_224629419612_item	2302664	et	4	main
oli	doc_224629419612_item	2302674	et	3	main
ei	doc_224629419612_item	2302679	et	4	main
toimub	doc_224629419612_item	2302684	et	3	main
eesti	doc_224629419612_item	2302696	et	4	main
jagunes	doc_224629419612_item	2302698	et	3	main
2	doc_224629419612_item	2302702	et	2	main
käsumajandus	doc_224629419612_item	2302714	et	3	main
töölised	doc_224629419612_item	2302719	et	3	main
oli	doc_224629419612_item	2302721	et	3	main
tsentsuur	doc_224629419612_item	2302727	et	4	main
keelest	doc_224629419612_item	2302734	et	4	main
kirjanik	doc_224629419612_item	2302752	et	3	main
nn	doc_224629419612_item	2302760	et	4	main
realism	doc_224629419612_item	2302767	et	3	main
oli	doc_224629419612_item	2302775	et	3	main
selts	doc_224629419611_item	2302500	et	3	main
laulu-	doc_224629419611_item	2302507	et	4	main
kultuuripeod	doc_224629419611_item	2302509	et	4	main
oswald	doc_224629419611_item	2302529	et	4	main
üks	doc_224629419611_item	2302534	et	3	main
populaarseim	doc_224629419611_item	2302535	et	4	main
väikesed	doc_224629419611_item	2302550	et	4	main
võitlus	doc_224629419611_item	2302556	et	3	main
kodaniku	doc_224629419611_item	2302560	et	3	main
iseloomulik	doc_224629419611_item	2302566	et	3	main
konflikt	doc_224629419611_item	2302568	et	3	main
veel	doc_224629419611_item	2302573	et	4	main
vahel	doc_224629419611_item	2302575	et	4	main
kujutamisobjektiks	doc_224629419611_item	2302576	et	3	main
kapitalism	doc_224629419611_item	2302585	et	3	main
erka	doc_224629419611_item	2302592	et	4	main
kuulus	doc_224629419611_item	2302595	et	4	main
juhtimisel	doc_224629419611_item	2302607	et	4	main
adamson	doc_224629419611_item	2302626	et	4	main
eric	doc_224629419611_item	2302627	et	4	main
okas	doc_224629419611_item	2302631	et	3	main
eesti	doc_224629419611_item	2302644	et	4	main
kontrolltöö	doc_224629419612_item	2302647	et	4	main
1950ndatel	doc_224629419612_item	2302651	et	4	main
1950	doc_224629419612_item	2302653	et	2	main
aasta	doc_224629419612_item	2302654	et	4	main
nn	doc_224629419612_item	2302663	et	4	main
erialaspetsialistid	doc_224629419612_item	2302666	et	3	main
uudiskirjandus	doc_224629419612_item	2302683	et	3	main
raamatukogudes	doc_224629419612_item	2302687	et	3	main
kuni	doc_224629419612_item	2302691	et	3	main
ani	doc_224629419612_item	2302693	et	4	main
1953-1960	doc_224629419612_item	2302695	et	2	main
kirjandus	doc_224629419612_item	2302697	et	3	main
1	doc_224629419612_item	2302699	et	2	main
kontroll	doc_224629419612_item	2302713	et	3	main
partei	doc_224629419612_item	2302723	et	4	main
ilmusid	doc_224629419612_item	2302730	et	4	main
vene	doc_224629419612_item	2302733	et	4	main
kirjandust	doc_224629419612_item	2302736	et	3	main
viisnurk	doc_224629419612_item	2302747	et	3	main
nõukogude	doc_224629419612_item	2302750	et	3	main
nõukogude	doc_224629419612_item	2302761	et	3	main
oli	doc_224629419612_item	2302765	et	3	main
sotsialistlik	doc_224629419612_item	2302766	et	3	main
pidi	doc_224629419612_item	2302769	et	4	main
žanrid	doc_224629419612_item	2302781	et	2	main
deboora	doc_224629419612_item	2302817	et	4	main
tooming	doc_224629419611_item	2302530	et	4	main
lääne	doc_224629419611_item	2302527	et	4	main
näidendeid	doc_224629419611_item	2302528	et	3	main
kirjandust	doc_224629419611_item	2302538	et	3	main
oli	doc_224629419611_item	2302542	et	3	main
kirjanduse	doc_224629419611_item	2302547	et	3	main
teemaks	doc_224629419611_item	2302552	et	4	main
ja	doc_224629419611_item	2302559	et	3	main
oli	doc_224629419611_item	2302565	et	3	main
ja	doc_224629419611_item	2302572	et	3	main
vastandus	doc_224629419611_item	2302583	et	4	main
oluline	doc_224629419611_item	2302588	et	4	main
moodustamise	doc_224629419611_item	2302590	et	4	main
fakt	doc_224629419611_item	2302591	et	3	main
250-liikmelisse	doc_224629419611_item	2302593	et	4	main
kollektiivi	doc_224629419611_item	2302594	et	4	main
ja	doc_224629419611_item	2302597	et	3	main
p	doc_224629419611_item	2302599	et	4	main
juhtimisel	doc_224629419611_item	2302601	et	4	main
ja	doc_224629419611_item	2302609	et	3	main
džässiorkester	doc_224629419611_item	2302610	et	2	main
draamakollektiiv	doc_224629419611_item	2302611	et	3	main
tagalas	doc_224629419611_item	2302612	et	3	main
töötas	doc_224629419611_item	2302613	et	3	main
arvukalt	doc_224629419611_item	2302614	et	4	main
kirjanikke	doc_224629419611_item	2302615	et	3	main
j	doc_224629419611_item	2302616	et	4	main
barbarus	doc_224629419611_item	2302617	et	4	main
j	doc_224629419611_item	2302618	et	4	main
semper	doc_224629419611_item	2302619	et	4	main
m	doc_224629419611_item	2302620	et	4	main
a	doc_224629419611_item	2302622	et	4	main
h	doc_224629419611_item	2302636	et	4	main
kuulub	doc_224629419611_item	2302639	et	3	main
tegevus	doc_224629419611_item	2302646	et	4	main
märtsis	doc_224629419612_item	2302655	et	3	main
toimus	doc_224629419612_item	2302656	et	3	main
ekbp	doc_224629419612_item	2302657	et	4	main
keskkomitee	doc_224629419612_item	2302658	et	4	main
viii	doc_224629419612_item	2302659	et	4	main
sellega	doc_224629419612_item	2302661	et	3	main
uuele	doc_224629419612_item	2302667	et	3	main
ustavate	doc_224629419612_item	2302669	et	4	main
puhastus	doc_224629419612_item	2302671	et	4	main
liidus	doc_224629419612_item	2302673	et	4	main
et	doc_224629419612_item	2302677	et	3	main
eesti	doc_224629419612_item	2302682	et	4	main
stalinismi	doc_224629419612_item	2302688	et	4	main
periood	doc_224629419612_item	2302689	et	3	main
e	doc_224629419612_item	2302704	et	4	main
aastani	doc_224629419612_item	2302709	et	3	main
valitses	doc_224629419612_item	2302712	et	3	main
täitsid	doc_224629419612_item	2302716	et	4	main
nagu	doc_224629419612_item	2302718	et	3	main
kirjandus	doc_224629419612_item	2302720	et	3	main
allutatud	doc_224629419612_item	2302722	et	4	main
tõlked	doc_224629419612_item	2302732	et	3	main
sellised	doc_224629419612_item	2302741	et	4	main
ajalehed	doc_224629419612_item	2302742	et	3	main
sirp	doc_224629419612_item	2302744	et	3	main
ajakirjad	doc_224629419612_item	2302746	et	3	main
keelatud	doc_224629419612_item	2302756	et	4	main
autoriks	doc_224629419612_item	2302757	et	3	main
kirjanikutele	doc_224629419612_item	2302758	et	4	main
e	doc_224629419612_item	2302777	et	4	main
valdavalt	doc_224629419612_item	2302783	et	4	main
poeem	doc_224629419612_item	2302784	et	3	main
ja	doc_224629419612_item	2302785	et	3	main
draama	doc_224629419612_item	2302786	et	4	main
a	doc_224629419612_item	2302815	et	4	main
varrandi	doc_224629419612_item	2302818	et	4	main
r	doc_224629419611_item	2302628	et	4	main
e	doc_224629419611_item	2302630	et	4	main
heliloojaid	doc_224629419611_item	2302633	et	3	main
kapp	doc_224629419611_item	2302635	et	3	main
lepnurm	doc_224629419611_item	2302637	et	4	main
ka	doc_224629419611_item	2302640	et	3	main
eesti	doc_224629419612_item	2302649	et	4	main
seostati	doc_224629419612_item	2302662	et	3	main
asendati	doc_224629419612_item	2302665	et	3	main
kirjanike	doc_224629419612_item	2302672	et	3	main
ulatuslik	doc_224629419612_item	2302685	et	3	main
nõukogude	doc_224629419612_item	2302700	et	3	main
1953	doc_224629419612_item	2302708	et	2	main
nõukogude	doc_224629419612_item	2302710	et	3	main
kirjanikud	doc_224629419612_item	2302715	et	3	main
plaani	doc_224629419612_item	2302717	et	4	main
kontrollile	doc_224629419612_item	2302724	et	3	main
tugev	doc_224629419612_item	2302726	et	4	main
stalinismi	doc_224629419612_item	2302728	et	4	main
ajal	doc_224629419612_item	2302729	et	4	main
võõrkeelset	doc_224629419612_item	2302735	et	3	main
ei	doc_224629419612_item	2302737	et	4	main
ilmunud	doc_224629419612_item	2302738	et	4	main
johannes	doc_224629419612_item	2302748	et	4	main
semper	doc_224629419612_item	2302749	et	4	main
aja	doc_224629419612_item	2302751	et	4	main
alguses	doc_224629419612_item	2302753	et	4	main
oli	doc_224629419612_item	2302754	et	3	main
semper	doc_224629419612_item	2302755	et	4	main
seoti	doc_224629419612_item	2302759	et	3	main
ainuke	doc_224629419612_item	2302763	et	4	main
rituaalseks	doc_224629419612_item	2302776	et	3	main
stalini	doc_224629419612_item	2302778	et	4	main
peamised	doc_224629419612_item	2302780	et	3	main
olid	doc_224629419612_item	2302782	et	4	main
poeetidest	doc_224629419612_item	2302787	et	3	main
domineeris	doc_224629419612_item	2302788	et	3	main
juhan	doc_224629419612_item	2302789	et	3	main
smuul	doc_224629419612_item	2302790	et	4	main
draamakirjanikest	doc_224629419612_item	2302791	et	3	main
august	doc_224629419612_item	2302792	et	4	main
jakobson	doc_224629419612_item	2302793	et	4	main
romaane	doc_224629419612_item	2302794	et	3	main
praktiliselt	doc_224629419612_item	2302795	et	4	main
ilmunud	doc_224629419612_item	2302797	et	4	main
ei	doc_224629419612_item	2302796	et	4	main
oli	doc_224629419612_item	2302798	et	3	main
lubatud	doc_224629419612_item	2302799	et	4	main
nõukogude	doc_224629419612_item	2302800	et	3	main
ajal	doc_224629419612_item	2302801	et	4	main
ainult	doc_224629419612_item	2302802	et	4	main
2	doc_224629419612_item	2302803	et	2	main
kirjanikku	doc_224629419612_item	2302804	et	4	main
l	doc_224629419612_item	2302805	et	4	main
koidula	doc_224629419612_item	2302806	et	4	main
ja	doc_224629419612_item	2302807	et	3	main
fr	doc_224629419612_item	2302808	et	4	main
r	doc_224629419612_item	2302809	et	4	main
kreutzwald	doc_224629419612_item	2302810	et	4	main
need	doc_224629419612_item	2302811	et	3	main
olid	doc_224629419612_item	2302812	et	4	main
kooliprogrammis	doc_224629419612_item	2302813	et	3	main
1975	doc_224629419612_item	2302814	et	2	main
mudeli	doc_224629419612_item	2302762	et	3	main
kirjandusstiil	doc_224629419612_item	2302764	et	3	main
kirjandus	doc_224629419612_item	2302768	et	3	main
olema	doc_224629419612_item	2302770	et	4	main
ideeline	doc_224629419612_item	2302771	et	4	main
parteine	doc_224629419612_item	2302772	et	4	main
rahvalik	doc_224629419612_item	2302773	et	3	main
kirjandus	doc_224629419612_item	2302774	et	3	main
keskseks	doc_224629419612_item	2302779	et	4	main
ilmub	doc_224629419612_item	2302816	et	3	main
luulekogu	doc_224629419612_item	2302819	et	4	main
lihtsad	doc_224629419612_item	2302820	et	3	main
asjad	doc_224629419612_item	2302821	et	3	main
sajandil	doc_252287432501_item	2303666	et	3	main
1	doc_252287432501_item	2303671	et	2	main
katkestatud	doc_252287432501_item	2303675	et	4	main
katoliku	doc_252287432501_item	2303680	et	3	main
territooriumi	doc_252287432501_item	2303692	et	4	main
ja	doc_252287432501_item	2303699	et	3	main
keskosa	doc_252287432501_item	2303700	et	4	main
mee	doc_252287432501_item	2303706	et	3	main
kuulus	doc_252287432501_item	2303712	et	4	main
ja	doc_252287432501_item	2303718	et	3	main
suuremad	doc_252287432501_item	2303724	et	4	main
linnad	doc_252287432501_item	2303725	et	3	main
olid	doc_252287432501_item	2303727	et	4	main
inimest	doc_252287432501_item	2303741	et	3	main
selle	doc_252287432501_item	2303743	et	4	main
ka	doc_252287432501_item	2303745	et	3	main
linnad	doc_252287432501_item	2303750	et	3	main
nagu	doc_252287432501_item	2303756	et	3	main
iga	doc_252287432501_item	2303773	et	4	main
linnakodanike	doc_252287432501_item	2303778	et	3	main
kas	doc_252287432501_item	2303783	et	3	main
seal	doc_252287432501_item	2303792	et	4	main
nadu	doc_252287432501_item	2303825	et	4	main
ii	doc_252287432501_item	2303826	et	4	main
eesti	doc_252287432501_item	2303834	et	4	main
oli	doc_252287432501_item	2303835	et	3	main
alguses	doc_252287432501_item	2303678	et	4	main
võtab	doc_252287432501_item	2303682	et	3	main
ristisõda	doc_252287432501_item	2303686	et	4	main
väga	doc_252287432501_item	2303688	et	3	main
ühiskonnakorraldusele	doc_252287432501_item	2303690	et	3	main
neljaks	doc_252287432501_item	2303695	et	4	main
tähtsam	doc_252287432501_item	2303705	et	4	main
taanile	doc_252287432501_item	2303713	et	4	main
piiskopkonnale	doc_252287432501_item	2303717	et	3	main
viirumaa	doc_252287432501_item	2303720	et	4	main
tartu	doc_252287432501_item	2303721	et	4	main
kõige	doc_252287432501_item	2303723	et	4	main
tallinn	doc_252287432501_item	2303728	et	4	main
tuh	doc_252287432501_item	2303740	et	4	main
olid	doc_252287432501_item	2303744	et	4	main
ja	doc_252287432501_item	2303747	et	3	main
need	doc_252287432501_item	2303749	et	3	main
hansa	doc_252287432501_item	2303751	et	4	main
liidus	doc_252287432501_item	2303752	et	4	main
seadustega	doc_252287432501_item	2303760	et	3	main
magistraati	doc_252287432501_item	2303770	et	4	main
ülesanned	doc_252287432501_item	2303776	et	4	main
2	doc_252287432501_item	2303667	et	2	main
mida	doc_252287432501_item	2303668	et	4	main
tähendab	doc_252287432501_item	2303669	et	3	main
reformatsioon	doc_252287432501_item	2303670	et	3	main
ühiskonnakorraldus	doc_252287432501_item	2303673	et	3	main
saj	doc_252287432501_item	2303677	et	4	main
võimu	doc_252287432501_item	2303683	et	4	main
eesti	doc_252287432501_item	2303689	et	4	main
omaette	doc_252287432501_item	2303696	et	3	main
rannik	doc_252287432501_item	2303711	et	3	main
eesti	doc_252287432501_item	2303715	et	4	main
lõuna	doc_252287432501_item	2303719	et	4	main
tollajal	doc_252287432501_item	2303726	et	4	main
tartu	doc_252287432501_item	2303730	et	4	main
umbes	doc_252287432501_item	2303733	et	4	main
7-8	doc_252287432501_item	2303734	et	2	main
5-6	doc_252287432501_item	2303739	et	2	main
uus-pärnu	doc_252287432501_item	2303748	et	4	main
oma	doc_252287432501_item	2303759	et	4	main
magistraat	doc_252287432501_item	2303769	et	3	main
valimised	doc_252287432501_item	2303771	et	4	main
maksustamine	doc_252287432501_item	2303779	et	4	main
otsustamine	doc_252287432501_item	2303782	et	4	main
võimuesindajad	doc_252287432501_item	2303822	et	3	main
iga	doc_252287432501_item	2303838	et	4	main
kihelkonnal	doc_252287432501_item	2303839	et	3	main
kombed	doc_252287432501_item	2303842	et	3	main
usupuhastus	doc_252287432501_item	2303847	et	3	main
tähendus	doc_255175075422_item	2303870	et	4	main
800-1050	doc_255175075422_item	2303873	et	2	main
oli	doc_255175075422_item	2303882	et	3	main
hõbe	doc_255175075422_item	2303883	et	3	main
hobune	doc_255175075422_item	2303893	et	4	main
juba	doc_255175075422_item	2303895	et	3	main
kauplemine	doc_255175075422_item	2303901	et	4	main
palju	doc_255175075422_item	2303920	et	4	main
tekkis	doc_255175075422_item	2303925	et	3	main
ääres	doc_255175075422_item	2303927	et	4	main
slaavi	doc_255175075422_item	2303928	et	3	main
asustus	doc_255175075422_item	2303929	et	4	main
konflikte	doc_255175075422_item	2303935	et	3	main
kohapeal	doc_255175075422_item	2303938	et	3	main
jaroslav	doc_255175075422_item	2303940	et	4	main
et	doc_255175075422_item	2303946	et	3	main
maksu	doc_255175075422_item	2303951	et	4	main
põllumajandusega	doc_255175075422_item	2303964	et	3	main
toodi	doc_255175075422_item	2303975	et	4	main
oli	doc_255175075422_item	2304021	et	3	main
kasutusele	doc_255175075422_item	2304028	et	4	main
süsteem	doc_255175075422_item	2304031	et	3	main
eesti	doc_255175075422_item	2304044	et	4	main
paljud	doc_255175075422_item	2304046	et	3	main
2	doc_255175075422_item	2304048	et	2	main
kiviaeg	doc_255175075422_item	2304057	et	3	main
pronksiaeg	doc_255175075422_item	2304058	et	3	main
kui	doc_263021865803_item	2304060	et	3	main
kajastuvad	doc_263021865803_item	2304062	et	4	main
kõik	doc_263021865803_item	2304078	et	4	main
eestit	doc_263021865803_item	2304079	et	3	main
vallutada	doc_263021865803_item	2304080	et	3	main
nagu	doc_263021865803_item	2304081	et	3	main
liit	doc_263021865803_item	2304084	et	3	main
võimalus	doc_263021865803_item	2304091	et	3	main
13	doc_252287432501_item	2303676	et	2	main
kui	doc_252287432501_item	2303679	et	3	main
kirik	doc_252287432501_item	2303681	et	3	main
enda	doc_252287432501_item	2303684	et	4	main
kätte	doc_252287432501_item	2303685	et	4	main
eesti	doc_252287432501_item	2303691	et	4	main
hakati	doc_252287432501_item	2303693	et	3	main
lõuna	doc_252287432501_item	2303698	et	4	main
kuulus	doc_252287432501_item	2303701	et	4	main
liivi	doc_252287432501_item	2303702	et	4	main
ordule	doc_252287432501_item	2303703	et	3	main
ordumeister	doc_252287432501_item	2303710	et	3	main
saare-lääne	doc_252287432501_item	2303714	et	4	main
piiskopkonnale	doc_252287432501_item	2303722	et	3	main
ja	doc_252287432501_item	2303729	et	3	main
elas	doc_252287432501_item	2303732	et	3	main
tuhat	doc_252287432501_item	2303735	et	4	main
inimest	doc_252287432501_item	2303736	et	3	main
aga	doc_252287432501_item	2303737	et	3	main
tartus	doc_252287432501_item	2303738	et	3	main
iga	doc_252287432501_item	2303753	et	4	main
linn	doc_252287432501_item	2303754	et	3	main
oli	doc_252287432501_item	2303755	et	3	main
omavalitsuse	doc_252287432501_item	2303757	et	3	main
ja	doc_252287432501_item	2303761	et	3	main
kõrgeim	doc_252287432501_item	2303763	et	4	main
linnavalitsuse	doc_252287432501_item	2303764	et	3	main
toimusid	doc_252287432501_item	2303772	et	4	main
olid	doc_252287432501_item	2303777	et	4	main
kohtu	doc_252287432501_item	2303780	et	4	main
pidamine	doc_252287432501_item	2303781	et	4	main
keda	doc_252287432501_item	2303785	et	4	main
gildisse	doc_252287432501_item	2303791	et	3	main
kultuurilugu	doc_252287432501_item	2303659	et	4	main
1	doc_252287432501_item	2303660	et	2	main
mõjud	doc_252287432501_item	2303662	et	4	main
ristiusustamise	doc_252287432501_item	2303661	et	3	main
eesti	doc_252287432501_item	2303663	et	4	main
ühiskonnakorraldusele	doc_252287432501_item	2303664	et	3	main
1316	doc_252287432501_item	2303665	et	2	main
iseseisev	doc_252287432501_item	2303672	et	3	main
oli	doc_252287432501_item	2303674	et	3	main
mõjus	doc_252287432501_item	2303687	et	4	main
jagama	doc_252287432501_item	2303694	et	3	main
piirkondadeks	doc_252287432501_item	2303697	et	3	main
kõige	doc_252287432501_item	2303704	et	4	main
mees	doc_252287432501_item	2303707	et	4	main
seal	doc_252287432501_item	2303708	et	4	main
oli	doc_252287432501_item	2303709	et	3	main
saare-lääne	doc_252287432501_item	2303716	et	4	main
tallinnas	doc_252287432501_item	2303731	et	4	main
peale	doc_252287432501_item	2303742	et	4	main
viljandi	doc_252287432501_item	2303746	et	4	main
punkt	doc_252287432501_item	2303758	et	4	main
valitsusega	doc_252287432501_item	2303762	et	4	main
koht	doc_252287432501_item	2303765	et	3	main
oli	doc_252287432501_item	2303766	et	3	main
road	doc_252287432501_item	2303767	et	4	main
ja	doc_252287432501_item	2303768	et	3	main
aasta	doc_252287432501_item	2303774	et	4	main
tema	doc_252287432501_item	2303775	et	4	main
ja	doc_252287432501_item	2303784	et	3	main
linna	doc_252287432501_item	2303787	et	4	main
linnaelanikud	doc_252287432501_item	2303789	et	3	main
koos	doc_252287432501_item	2303793	et	4	main
töötasid	doc_252287432501_item	2303794	et	4	main
kaupmehed	doc_252287432501_item	2303795	et	3	main
või	doc_252287432501_item	2303796	et	4	main
käsitöölised	doc_252287432501_item	2303797	et	3	main
peale	doc_252287432501_item	2303798	et	4	main
selle	doc_252287432501_item	2303799	et	4	main
inimesed	doc_252287432501_item	2303800	et	3	main
olid	doc_252287432501_item	2303801	et	4	main
organiseeritud	doc_252287432501_item	2303802	et	4	main
kokku	doc_252287432501_item	2303803	et	3	main
tsunftis	doc_252287432501_item	2303804	et	3	main
seal	doc_252287432501_item	2303805	et	4	main
olid	doc_252287432501_item	2303806	et	4	main
nt	doc_252287432501_item	2303807	et	4	main
käsitöölised	doc_252287432501_item	2303808	et	3	main
pagarad	doc_252287432501_item	2303809	et	4	main
linnaselavad	doc_252287432501_item	2303810	et	4	main
eestlased	doc_252287432501_item	2303811	et	3	main
olid	doc_252287432501_item	2303812	et	4	main
põhiliselt	doc_252287432501_item	2303813	et	4	main
lihtkäistöölised	doc_252287432501_item	2303814	et	4	main
aga	doc_252287432501_item	2303815	et	3	main
sakslased	doc_252287432501_item	2303816	et	3	main
olid	doc_252287432501_item	2303817	et	4	main
käsitöömeistrid	doc_252287432501_item	2303818	et	3	main
kaupmehed	doc_252287432501_item	2303819	et	3	main
ja	doc_252287432501_item	2303820	et	3	main
kirik	doc_252287432501_item	2303823	et	3	main
võim	doc_252287432501_item	2303827	et	3	main
see	doc_252287432501_item	2303828	et	3	main
maa	doc_252287432501_item	2303831	et	4	main
administratiivse	doc_252287432501_item	2303832	et	3	main
oli	doc_252287432501_item	2303840	et	3	main
ja	doc_252287432501_item	2303843	et	3	main
korruptsiooniga	doc_252287432501_item	2303849	et	3	main
vastus	doc_255175075422_item	2303861	et	3	main
eesti	doc_255175075422_item	2303865	et	4	main
2	doc_255175075422_item	2303867	et	2	main
võtta	doc_252287432501_item	2303786	et	3	main
elama	doc_252287432501_item	2303788	et	3	main
koondasid	doc_252287432501_item	2303790	et	4	main
muidugi	doc_252287432501_item	2303821	et	4	main
ümber	doc_252287432501_item	2303830	et	3	main
korralduse	doc_252287432501_item	2303833	et	4	main
jagatud	doc_252287432501_item	2303836	et	4	main
kirikukihelkondadeks	doc_252287432501_item	2303837	et	3	main
omaette	doc_252287432501_item	2303841	et	3	main
reformatsioon	doc_252287432501_item	2303846	et	3	main
jumalasõna	doc_252287432501_item	2303850	et	4	main
küsimusele	doc_255175075422_item	2303862	et	4	main
viikingiaeg	doc_255175075422_item	2303864	et	3	main
viikingiaeg	doc_255175075422_item	2303872	et	3	main
väärtuslikum	doc_255175075422_item	2303880	et	4	main
hõbedas	doc_255175075422_item	2303884	et	3	main
loomade	doc_255175075422_item	2303886	et	4	main
kallim	doc_255175075422_item	2303891	et	4	main
koduloomi	doc_255175075422_item	2303894	et	4	main
oli	doc_255175075422_item	2303906	et	3	main
ka	doc_255175075422_item	2303919	et	3	main
röövimisi	doc_255175075422_item	2303921	et	4	main
konflikte	doc_255175075422_item	2303923	et	3	main
ajaga	doc_255175075422_item	2303930	et	3	main
ka	doc_255175075422_item	2303934	et	3	main
tänapäevase	doc_255175075422_item	2303936	et	4	main
asutasid	doc_255175075422_item	2303939	et	4	main
jurjevi	doc_255175075422_item	2303943	et	4	main
tahtsid	doc_255175075422_item	2303945	et	4	main
siinseid	doc_255175075422_item	2303947	et	3	main
asukaid	doc_255175075422_item	2303948	et	4	main
ka	doc_255175075422_item	2303950	et	3	main
palju	doc_255175075422_item	2303961	et	4	main
tööriistad	doc_255175075422_item	2303965	et	3	main
juba	doc_255175075422_item	2303967	et	3	main
siia	doc_255175075422_item	2303974	et	4	main
levima	doc_255175075422_item	2303978	et	3	main
jutustati	doc_255175075422_item	2303982	et	3	main
sellest	doc_255175075422_item	2303983	et	4	main
oli	doc_252287432501_item	2303824	et	3	main
korraldas	doc_252287432501_item	2303829	et	3	main
murred	doc_252287432501_item	2303845	et	4	main
tilkima	doc_252287432501_item	2303852	et	4	main
ema	doc_252287432501_item	2303853	et	4	main
keelde	doc_252287432501_item	2303854	et	4	main
jumalateenistus	doc_252287432501_item	2303855	et	3	main
viidi	doc_252287432501_item	2303856	et	4	main
läbi	doc_252287432501_item	2303857	et	4	main
ka	doc_252287432501_item	2303858	et	3	main
ema	doc_252287432501_item	2303859	et	4	main
keeles	doc_252287432501_item	2303860	et	4	main
kultuur	doc_252287432501_item	2303844	et	3	main
võitlus	doc_252287432501_item	2303848	et	3	main
hakati	doc_252287432501_item	2303851	et	3	main
territooriumil	doc_255175075422_item	2303866	et	3	main
mõiste	doc_255175075422_item	2303868	et	4	main
muinasaeg	doc_255175075422_item	2303869	et	3	main
skandinaavia	doc_255175075422_item	2303875	et	4	main
tol	doc_255175075422_item	2303877	et	3	main
kõige	doc_255175075422_item	2303879	et	4	main
metall	doc_255175075422_item	2303881	et	3	main
arvutati	doc_255175075422_item	2303885	et	4	main
oli	doc_255175075422_item	2303892	et	3	main
kasutati	doc_255175075422_item	2303896	et	4	main
palju	doc_255175075422_item	2303897	et	4	main
rohkem	doc_255175075422_item	2303898	et	4	main
intensiivne	doc_255175075422_item	2303900	et	3	main
müüdi	doc_255175075422_item	2303902	et	4	main
karusnahku	doc_255175075422_item	2303903	et	3	main
1	doc_255175075422_item	2303863	et	2	main
muistsete	doc_255175075422_item	2303874	et	3	main
retked	doc_255175075422_item	2303876	et	3	main
hinde	doc_255175075422_item	2303889	et	4	main
toimub	doc_255175075422_item	2303899	et	3	main
juba	doc_255175075422_item	2303907	et	3	main
võimalik	doc_255175075422_item	2303908	et	3	main
välismaariideid	doc_255175075422_item	2303910	et	3	main
kujunevad	doc_255175075422_item	2303912	et	4	main
maa	doc_255175075422_item	2303914	et	4	main
hakkatakse	doc_255175075422_item	2303915	et	4	main
pärandama	doc_255175075422_item	2303916	et	3	main
aga	doc_255175075422_item	2303917	et	3	main
sõjalisi	doc_255175075422_item	2303922	et	4	main
9-10s	doc_255175075422_item	2303924	et	3	main
peipsi	doc_255175075422_item	2303926	et	4	main
slaavlastega	doc_255175075422_item	2303932	et	3	main
käsitööga	doc_255175075422_item	2303962	et	3	main
kirved	doc_255175075422_item	2303971	et	3	main
potikedrad	doc_255175075422_item	2303976	et	3	main
laulud	doc_255175075422_item	2303980	et	3	main
ka	doc_255175075422_item	2304023	et	3	main
ja	doc_255175075422_item	2304025	et	3	main
tuli	doc_255175075422_item	2304027	et	4	main
uus	doc_255175075422_item	2304029	et	3	main
kaalu	doc_255175075422_item	2304030	et	4	main
seetõttu	doc_255175075422_item	2304039	et	3	main
öölda	doc_255175075422_item	2304041	et	4	main
mis	doc_255175075422_item	2304051	et	4	main
areng	doc_255175075422_item	2304056	et	3	main
teada	doc_263021865803_item	2304082	et	3	main
80-ndate	doc_263021865803_item	2304087	et	4	main
saada	doc_263021865803_item	2304092	et	4	main
riigiks	doc_263021865803_item	2304094	et	3	main
eesti	doc_263021865803_item	2304096	et	4	main
näide	doc_263021865803_item	2304100	et	3	main
sai	doc_263021865803_item	2304104	et	4	main
igaveseks	doc_263021865803_item	2304120	et	4	main
parem	doc_263021865803_item	2304122	et	4	main
sest	doc_263021865803_item	2304128	et	4	main
siis	doc_263021865803_item	2304133	et	3	main
oma	doc_263021865803_item	2304137	et	4	main
näidata	doc_263021865803_item	2304141	et	4	main
ka	doc_263021865803_item	2304142	et	3	main
oma	doc_263021865803_item	2304143	et	4	main
võimalusi	doc_263021865803_item	2304145	et	3	main
ja	doc_263021865803_item	2304146	et	3	main
tahtmisi	doc_263021865803_item	2304147	et	4	main
vägagi	doc_263021865803_item	2304153	et	3	main
sündmusi	doc_263021865803_item	2304157	et	3	main
sest	doc_263021865803_item	2304158	et	4	main
teletorn	doc_263021865803_item	2304159	et	3	main
ajad	doc_263021865803_item	2304184	et	4	main
sügava	doc_263021865803_item	2304188	et	4	main
inimesed	doc_263021865803_item	2304193	et	3	main
saada	doc_263021865803_item	2304203	et	4	main
vabaks	doc_263021865803_item	2304204	et	3	main
et	doc_263021865803_item	2304205	et	3	main
teha	doc_263021865803_item	2304206	et	3	main
otsusi	doc_263021865803_item	2304208	et	4	main
õnneks	doc_263021865803_item	2304221	et	4	main
sama	doc_263021865803_item	2304232	et	4	main
mis	doc_263021865803_item	2304233	et	4	main
et	doc_263021865803_item	2304253	et	3	main
ja	doc_263021865803_item	2304256	et	3	main
välja	doc_263021865803_item	2304258	et	4	main
teletorn	doc_263021865803_item	2304273	et	3	main
seisma	doc_263021865803_item	2304275	et	3	main
need	doc_263021865803_item	2304277	et	3	main
kaitsesid	doc_263021865803_item	2304279	et	4	main
seista	doc_263021865803_item	2304317	et	4	main
nn	doc_263021865803_item	2304321	et	4	main
olukorras	doc_263021865803_item	2304323	et	3	main
ka	doc_263021865803_item	2304325	et	3	main
ei	doc_263021865803_item	2304334	et	4	main
ikkagi	doc_263021865803_item	2304336	et	4	main
õudsam	doc_263021865803_item	2304346	et	4	main
sest	doc_263021865803_item	2304349	et	4	main
ja	doc_263021865803_item	2304358	et	3	main
nüüd	doc_263021865803_item	2304359	et	4	main
mõistavad	doc_263021865803_item	2304360	et	3	main
hukka	doc_263021865803_item	2304361	et	4	main
1	doc_255175075422_item	2303871	et	2	main
ajal	doc_255175075422_item	2303878	et	4	main
ja	doc_255175075422_item	2303887	et	3	main
asjade	doc_255175075422_item	2303888	et	3	main
kõige	doc_255175075422_item	2303890	et	4	main
mett	doc_255175075422_item	2303904	et	4	main
orje	doc_255175075422_item	2303905	et	3	main
saada	doc_255175075422_item	2303909	et	4	main
1	doc_255175075422_item	2303911	et	2	main
mõisad	doc_255175075422_item	2303913	et	3	main
oli	doc_255175075422_item	2303918	et	3	main
hakkasid	doc_255175075422_item	2303931	et	4	main
tekkima	doc_255175075422_item	2303933	et	3	main
tark	doc_255175075422_item	2303941	et	3	main
nad	doc_255175075422_item	2303942	et	3	main
slaavlased	doc_255175075422_item	2303944	et	3	main
neile	doc_255175075422_item	2303949	et	4	main
maksaksid	doc_255175075422_item	2303952	et	4	main
ilmselt	doc_255175075422_item	2303954	et	4	main
ei	doc_255175075422_item	2303955	et	4	main
meeldinud	doc_255175075422_item	2303956	et	4	main
kohaliku	doc_255175075422_item	2303957	et	3	main
rahvusele	doc_255175075422_item	2303958	et	3	main
inimesed	doc_255175075422_item	2303959	et	3	main
tegelesid	doc_255175075422_item	2303960	et	4	main
olid	doc_255175075422_item	2303966	et	4	main
paremad	doc_255175075422_item	2303968	et	4	main
mugavamad	doc_255175075422_item	2303970	et	4	main
saagid	doc_255175075422_item	2303972	et	3	main
hakkasid	doc_255175075422_item	2303977	et	4	main
loodesega	doc_255175075422_item	2304024	et	4	main
on	doc_255175075422_item	2304034	et	4	main
läbi	doc_255175075422_item	2304043	et	4	main
läksid	doc_255175075422_item	2304045	et	4	main
muinasaeg	doc_255175075422_item	2304049	et	3	main
viimane	doc_263021865803_item	2304086	et	3	main
lõpus	doc_263021865803_item	2304088	et	4	main
iseseisvaks	doc_263021865803_item	2304093	et	3	main
lugu	doc_263021865803_item	2304098	et	4	main
see	doc_263021865803_item	2304106	et	3	main
tartu	doc_255175075422_item	2303937	et	4	main
mis	doc_255175075422_item	2303953	et	4	main
ja	doc_255175075422_item	2303963	et	3	main
ja	doc_255175075422_item	2303969	et	3	main
ader	doc_255175075422_item	2303973	et	3	main
saagid-	doc_255175075422_item	2303979	et	3	main
kus	doc_255175075422_item	2303981	et	3	main
ümber	doc_255175075422_item	2303985	et	3	main
toimus	doc_255175075422_item	2303986	et	3	main
mis	doc_255175075422_item	2303984	et	4	main
sõjadest	doc_255175075422_item	2303987	et	4	main
ja	doc_255175075422_item	2303988	et	3	main
jne	doc_255175075422_item	2303989	et	4	main
hiljemal	doc_255175075422_item	2303990	et	4	main
ajal	doc_255175075422_item	2303991	et	4	main
levis	doc_255175075422_item	2303992	et	4	main
ka	doc_255175075422_item	2303993	et	3	main
sõnaraamat	doc_255175075422_item	2303994	et	3	main
väga	doc_255175075422_item	2303995	et	3	main
tähtsaksedeks	doc_255175075422_item	2303996	et	4	main
inimese	doc_255175075422_item	2303998	et	4	main
matused	doc_255175075422_item	2303999	et	3	main
juba	doc_255175075422_item	2304000	et	3	main
olid	doc_255175075422_item	2304001	et	4	main
said	doc_255175075422_item	2303997	et	4	main
kalmed	doc_255175075422_item	2304002	et	3	main
inimesed	doc_255175075422_item	2304003	et	3	main
uskusid	doc_255175075422_item	2304004	et	4	main
et	doc_255175075422_item	2304005	et	3	main
loodusel	doc_255175075422_item	2304006	et	4	main
on	doc_255175075422_item	2304007	et	4	main
eriline	doc_255175075422_item	2304008	et	4	main
võim	doc_255175075422_item	2304009	et	3	main
olid	doc_255175075422_item	2304010	et	4	main
pühad	doc_255175075422_item	2304011	et	3	main
puud	doc_255175075422_item	2304012	et	4	main
allikad	doc_255175075422_item	2304013	et	3	main
ja	doc_255175075422_item	2304014	et	3	main
jne	doc_255175075422_item	2304015	et	4	main
tekkisid	doc_255175075422_item	2304016	et	4	main
praeguste	doc_255175075422_item	2304017	et	3	main
maakundade	doc_255175075422_item	2304018	et	4	main
piirid	doc_255175075422_item	2304019	et	3	main
see	doc_255175075422_item	2304020	et	3	main
seotud	doc_255175075422_item	2304022	et	4	main
1	doc_255175075422_item	2304032	et	2	main
eestis	doc_255175075422_item	2304033	et	3	main
võib	doc_255175075422_item	2304040	et	3	main
et	doc_255175075422_item	2304042	et	3	main
kaubateed	doc_255175075422_item	2304047	et	4	main
oli	doc_255175075422_item	2304052	et	3	main
ekr	doc_255175075422_item	2304053	et	4	main
inimese	doc_255175075422_item	2304054	et	4	main
algne	doc_255175075422_item	2304055	et	3	main
hästi	doc_263021865803_item	2304061	et	3	main
selles	doc_263021865803_item	2304063	et	4	main
filmis	doc_263021865803_item	2304064	et	4	main
eesti	doc_263021865803_item	2304065	et	4	main
taasiseseisvumas	doc_263021865803_item	2304066	et	3	main
sündmused	doc_263021865803_item	2304067	et	3	main
nagu	doc_263021865803_item	2304068	et	3	main
teada	doc_263021865803_item	2304069	et	3	main
eesti	doc_263021865803_item	2304070	et	4	main
on	doc_263021865803_item	2304071	et	4	main
väike	doc_263021865803_item	2304072	et	4	main
riik	doc_263021865803_item	2304073	et	3	main
ja	doc_263021865803_item	2304074	et	3	main
erinevatel	doc_263021865803_item	2304075	et	4	main
aegadel	doc_263021865803_item	2304076	et	3	main
kliimaga	doc_255175075422_item	2304026	et	3	main
leitud	doc_255175075422_item	2304035	et	4	main
palju	doc_255175075422_item	2304036	et	4	main
võõramaiseid	doc_255175075422_item	2304037	et	4	main
münte	doc_255175075422_item	2304038	et	3	main
kõik	doc_255175075422_item	2304050	et	4	main
essee	doc_263021865803_item	2304059	et	4	main
tuli	doc_263021865803_item	2304090	et	4	main
film	doc_263021865803_item	2304095	et	3	main
teletorni	doc_263021865803_item	2304097	et	4	main
eesti	doc_263021865803_item	2304103	et	4	main
kajastab	doc_263021865803_item	2304108	et	3	main
eesti	doc_263021865803_item	2304114	et	4	main
jaoks	doc_263021865803_item	2304115	et	4	main
sest	doc_263021865803_item	2304116	et	4	main
nad	doc_263021865803_item	2304117	et	3	main
muutsid	doc_263021865803_item	2304118	et	4	main
iseseisvaks	doc_263021865803_item	2304127	et	3	main
ei	doc_263021865803_item	2304131	et	4	main
tal	doc_263021865803_item	2304136	et	3	main
oskusi	doc_263021865803_item	2304144	et	3	main
et	doc_263021865803_item	2304150	et	3	main
see	doc_263021865803_item	2304151	et	3	main
paljude	doc_263021865803_item	2304181	et	3	main
paljud	doc_263021865803_item	2304192	et	3	main
nad	doc_263021865803_item	2304201	et	3	main
nad	doc_263021865803_item	2304220	et	3	main
paha	doc_263021865803_item	2304225	et	4	main
inimesed	doc_263021865803_item	2304226	et	3	main
moskvas	doc_263021865803_item	2304236	et	4	main
kartes	doc_263021865803_item	2304251	et	3	main
ka	doc_263021865803_item	2304261	et	3	main
jooksul	doc_263021865803_item	2304264	et	4	main
tallinnas	doc_263021865803_item	2304265	et	4	main
toompeal	doc_263021865803_item	2304266	et	3	main
võeti	doc_263021865803_item	2304267	et	3	main
said	doc_263021865803_item	2304281	et	4	main
tahtsid	doc_263021865803_item	2304077	et	4	main
nõukogude	doc_263021865803_item	2304083	et	3	main
oli	doc_263021865803_item	2304085	et	3	main
eestlastel	doc_263021865803_item	2304089	et	4	main
ongi	doc_263021865803_item	2304099	et	4	main
iseseisvaks	doc_263021865803_item	2304105	et	3	main
film	doc_263021865803_item	2304107	et	3	main
mis	doc_263021865803_item	2304111	et	4	main
olid	doc_263021865803_item	2304112	et	4	main
tähtsad	doc_263021865803_item	2304113	et	3	main
ta	doc_263021865803_item	2304119	et	4	main
sai	doc_263021865803_item	2304126	et	4	main
ei	doc_263021865803_item	2304134	et	4	main
neid	doc_263021865803_item	2304156	et	4	main
oli	doc_263021865803_item	2304160	et	3	main
tähtis	doc_263021865803_item	2304161	et	4	main
sihtpunkt	doc_263021865803_item	2304162	et	3	main
rasked	doc_263021865803_item	2304183	et	3	main
sest	doc_263021865803_item	2304185	et	4	main
säilitasid	doc_263021865803_item	2304186	et	4	main
veel	doc_263021865803_item	2304187	et	4	main
olid	doc_263021865803_item	2304194	et	4	main
inimestel	doc_263021865803_item	2304198	et	3	main
üle	doc_263021865803_item	2304200	et	3	main
soovinud	doc_263021865803_item	2304214	et	4	main
midagi	doc_263021865803_item	2304224	et	4	main
näiteks	doc_263021865803_item	2304235	et	4	main
inimesed	doc_263021865803_item	2304242	et	3	main
midagi	doc_263021865803_item	2304244	et	4	main
suletakse	doc_263021865803_item	2304254	et	4	main
nende	doc_263021865803_item	2304262	et	4	main
vastu	doc_263021865803_item	2304268	et	3	main
deklaratsiooni	doc_263021865803_item	2304270	et	4	main
lõpuks	doc_263021865803_item	2304272	et	4	main
jäi	doc_263021865803_item	2304274	et	3	main
ja	doc_263021865803_item	2304276	et	3	main
raske	doc_263021865803_item	2304327	et	4	main
et	doc_263021865803_item	2304339	et	3	main
valitses	doc_263021865803_item	2304341	et	3	main
ta	doc_263021865803_item	2304344	et	4	main
kui	doc_263021865803_item	2304347	et	3	main
pärast	doc_263021865803_item	2304351	et	4	main
nii	doc_263021865803_item	2304353	et	3	main
palju	doc_263021865803_item	2304354	et	4	main
süütuid	doc_263021865803_item	2304355	et	4	main
öölaulupidudeja	doc_263021865804_item	2304385	et	4	main
1	doc_263021865804_item	2304399	et	2	main
jkaplinski	doc_263021865804_item	2304401	et	4	main
ajaloolisi	doc_263021865804_item	2304406	et	4	main
näitekunsti	doc_263021865804_item	2304410	et	4	main
oli	doc_263021865804_item	2304415	et	3	main
arrak	doc_263021865804_item	2304418	et	3	main
muusik	doc_263021865804_item	2304422	et	3	main
ja	doc_263021865804_item	2304433	et	3	main
alla	doc_263021865804_item	2304435	et	3	main
ei	doc_263021865804_item	2304436	et	4	main
tulnud	doc_263021865804_item	2304443	et	4	main
asi	doc_263021865804_item	2304447	et	4	main
oma	doc_263021865804_item	2304461	et	4	main
ja	doc_263021865804_item	2304469	et	3	main
suutnud	doc_263021865804_item	2304473	et	4	main
ulevalt	doc_263021865804_item	2304477	et	4	main
80	doc_263021865804_item	2304479	et	2	main
tuli	doc_263021865804_item	2304481	et	4	main
lind	doc_263021865804_item	2304491	et	3	main
lill	doc_263021865804_item	2304494	et	3	main
must	doc_263021865804_item	2304498	et	4	main
rahvas	doc_263021865804_item	2304511	et	4	main
on	doc_263021865804_item	2304512	et	4	main
see	doc_263021865804_item	2304521	et	3	main
minu	doc_263021865804_item	2304524	et	3	main
koos	doc_263021865804_item	2304532	et	4	main
vastu	doc_263021865804_item	2304535	et	3	main
põhimõte	doc_263021865804_item	2304540	et	3	main
laulval	doc_263021865804_item	2304543	et	4	main
juhtugu	doc_263021865804_item	2304549	et	3	main
juhtub	doc_263021865804_item	2304551	et	3	main
oli	doc_263021865804_item	2304559	et	3	main
on	doc_263021865804_item	2304567	et	4	main
3	doc_263021865804_item	2304569	et	2	main
arvas	doc_263021865804_item	2304606	et	3	main
situatsiooniga	doc_263021865804_item	2304611	et	3	main
sellest	doc_263021865803_item	2304101	et	4	main
kuidas	doc_263021865803_item	2304102	et	3	main
neid	doc_263021865803_item	2304109	et	4	main
sündmusi	doc_263021865803_item	2304110	et	3	main
ongi	doc_263021865803_item	2304121	et	4	main
see	doc_263021865803_item	2304123	et	3	main
muidu	doc_263021865803_item	2304129	et	3	main
kui	doc_263021865803_item	2304130	et	3	main
vaatlemisi	doc_263021865803_item	2304138	et	4	main
laiendada	doc_263021865803_item	2304139	et	3	main
mulle	doc_263021865803_item	2304148	et	4	main
film	doc_263021865803_item	2304152	et	3	main
hästi	doc_263021865803_item	2304154	et	3	main
kajastab	doc_263021865803_item	2304155	et	3	main
masenduses	doc_263021865803_item	2304195	et	4	main
saigi	doc_263021865803_item	2304197	et	4	main
kannatus	doc_263021865803_item	2304199	et	4	main
tahtsid	doc_263021865803_item	2304202	et	4	main
iseseisvaid	doc_263021865803_item	2304207	et	3	main
seda	doc_263021865803_item	2304210	et	3	main
teada	doc_263021865803_item	2304212	et	3	main
et	doc_263021865803_item	2304124	et	3	main
eesti	doc_263021865803_item	2304125	et	4	main
oleks	doc_263021865803_item	2304132	et	3	main
oleks	doc_263021865803_item	2304135	et	3	main
ja	doc_263021865803_item	2304140	et	3	main
tundub	doc_263021865803_item	2304149	et	3	main
eestis	doc_263021865803_item	2304163	et	3	main
tema	doc_263021865803_item	2304164	et	4	main
kaudu	doc_263021865803_item	2304165	et	3	main
teised	doc_263021865803_item	2304167	et	4	main
riigid	doc_263021865803_item	2304168	et	3	main
saaksid	doc_263021865803_item	2304169	et	4	main
kõik	doc_263021865803_item	2304166	et	4	main
teada	doc_263021865803_item	2304170	et	3	main
mis	doc_263021865803_item	2304171	et	4	main
toimub	doc_263021865803_item	2304172	et	3	main
eestis	doc_263021865803_item	2304173	et	3	main
aga	doc_263021865803_item	2304174	et	3	main
moskva	doc_263021865803_item	2304175	et	4	main
seda	doc_263021865803_item	2304176	et	3	main
eitahtnud	doc_263021865803_item	2304177	et	3	main
80-ndate	doc_263021865803_item	2304178	et	4	main
lõpud	doc_263021865803_item	2304179	et	3	main
olid	doc_263021865803_item	2304180	et	4	main
jaoks	doc_263021865803_item	2304182	et	4	main
kriisi	doc_263021865803_item	2304189	et	4	main
tagajärjed	doc_263021865803_item	2304190	et	3	main
ja	doc_263021865803_item	2304191	et	3	main
nii	doc_263021865803_item	2304196	et	3	main
moskva	doc_263021865803_item	2304209	et	4	main
nagu	doc_263021865803_item	2304211	et	3	main
ei	doc_263021865803_item	2304213	et	4	main
isegi	doc_263021865803_item	2304215	et	4	main
saatis	doc_263021865803_item	2304216	et	3	main
tanke	doc_263021865803_item	2304217	et	3	main
tallinnasse	doc_263021865803_item	2304218	et	3	main
aga	doc_263021865803_item	2304219	et	3	main
ei	doc_263021865803_item	2304222	et	4	main
teinud	doc_263021865803_item	2304223	et	4	main
kartsid	doc_263021865803_item	2304227	et	4	main
et	doc_263021865803_item	2304229	et	3	main
toimub	doc_263021865803_item	2304231	et	3	main
ja	doc_263021865803_item	2304237	et	3	main
kus	doc_263021865803_item	2304239	et	3	main
kannatada	doc_263021865803_item	2304241	et	3	main
õnneks	doc_263021865803_item	2304243	et	4	main
ei	doc_263021865803_item	2304245	et	4	main
juhtunud	doc_263021865803_item	2304246	et	4	main
mõned	doc_263021865803_item	2304247	et	3	main
isegi	doc_263021865803_item	2304248	et	4	main
sõitsid	doc_263021865803_item	2304249	et	4	main
välismaale	doc_263021865803_item	2304250	et	4	main
enam	doc_263021865803_item	2304257	et	4	main
sündmuste	doc_263021865803_item	2304263	et	3	main
iseseisvus	doc_263021865803_item	2304269	et	4	main
lõppude	doc_263021865803_item	2304271	et	4	main
kes	doc_263021865803_item	2304278	et	4	main
teda	doc_263021865803_item	2304280	et	4	main
eest	doc_263021865803_item	2304320	et	4	main
minu	doc_263021865803_item	2304328	et	3	main
jaoks	doc_263021865803_item	2304329	et	4	main
see	doc_263021865803_item	2304330	et	3	main
mõned	doc_263021865803_item	2304332	et	3	main
seda	doc_263021865803_item	2304338	et	3	main
oli	doc_263021865803_item	2304343	et	3	main
palju	doc_263021865803_item	2304345	et	4	main
sai	doc_263021865803_item	2304352	et	4	main
surma	doc_263021865803_item	2304357	et	4	main
selle	doc_263021865803_item	2304363	et	4	main
sisu	doc_263021865804_item	2304398	et	4	main
rummo	doc_263021865804_item	2304400	et	4	main
munt	doc_263021865804_item	2304402	et	4	main
vluik	doc_263021865804_item	2304403	et	4	main
eesti	doc_263021865804_item	2304404	et	4	main
kirjanikud	doc_263021865804_item	2304405	et	3	main
vpanso	doc_263021865804_item	2304412	et	4	main
seda	doc_263021865803_item	2304228	et	3	main
nendega	doc_263021865803_item	2304230	et	4	main
juhtus	doc_263021865803_item	2304234	et	3	main
vilniuses	doc_263021865803_item	2304238	et	4	main
said	doc_263021865803_item	2304240	et	4	main
seda	doc_263021865803_item	2304252	et	3	main
piire	doc_263021865803_item	2304255	et	4	main
ei	doc_263021865803_item	2304259	et	4	main
saa	doc_263021865803_item	2304260	et	4	main
kangelasteks	doc_263021865803_item	2304282	et	4	main
need	doc_263021865803_item	2304283	et	3	main
sündmused	doc_263021865803_item	2304284	et	3	main
on	doc_263021865803_item	2304285	et	4	main
tõelised	doc_263021865803_item	2304286	et	4	main
ja	doc_263021865803_item	2304287	et	3	main
nad	doc_263021865803_item	2304288	et	3	main
jäävad	doc_263021865803_item	2304289	et	4	main
alati	doc_263021865803_item	2304290	et	4	main
inimeste	doc_263021865803_item	2304291	et	3	main
mälus	doc_263021865803_item	2304292	et	4	main
see	doc_263021865803_item	2304293	et	3	main
film	doc_263021865803_item	2304294	et	3	main
on	doc_263021865803_item	2304295	et	4	main
väga	doc_263021865803_item	2304296	et	3	main
hea	doc_263021865803_item	2304297	et	4	main
näide	doc_263021865803_item	2304298	et	3	main
lastele	doc_263021865803_item	2304299	et	4	main
kes	doc_263021865803_item	2304300	et	4	main
sündisid	doc_263021865803_item	2304301	et	4	main
pärast	doc_263021865803_item	2304302	et	4	main
neid	doc_263021865803_item	2304303	et	4	main
sündmusi	doc_263021865803_item	2304304	et	3	main
sest	doc_263021865803_item	2304305	et	4	main
nad	doc_263021865803_item	2304306	et	3	main
saavad	doc_263021865803_item	2304307	et	4	main
olla	doc_263021865803_item	2304308	et	3	main
uhked	doc_263021865803_item	2304309	et	4	main
oma	doc_263021865803_item	2304310	et	4	main
kodumaa	doc_263021865803_item	2304311	et	4	main
eest	doc_263021865803_item	2304312	et	4	main
et	doc_263021865803_item	2304313	et	3	main
ta	doc_263021865803_item	2304314	et	4	main
oli	doc_263021865803_item	2304315	et	3	main
julge	doc_263021865803_item	2304316	et	4	main
oma	doc_263021865803_item	2304318	et	4	main
õiguste	doc_263021865803_item	2304319	et	4	main
sõjaväelises	doc_263021865803_item	2304322	et	4	main
et	doc_263021865803_item	2304331	et	3	main
eestlased	doc_263021865803_item	2304333	et	3	main
märgata	doc_263021865803_item	2304337	et	4	main
kui	doc_263021865803_item	2304340	et	3	main
hitler	doc_263021865803_item	2304342	et	4	main
teised	doc_263021865803_item	2304348	et	4	main
eest	doc_263021865803_item	2304364	et	4	main
laulva	doc_263021865804_item	2304386	et	4	main
perestroika	doc_263021865804_item	2304393	et	4	main
ja	doc_263021865804_item	2304394	et	3	main
glasnostj	doc_263021865804_item	2304395	et	4	main
tähendus	doc_263021865804_item	2304396	et	4	main
jkross	doc_263021865804_item	2304409	et	4	main
arendas	doc_263021865804_item	2304411	et	3	main
realism	doc_263021865804_item	2304417	et	3	main
larin	doc_263021865804_item	2304420	et	3	main
alal	doc_263021865804_item	2304423	et	4	main
oli	doc_263021865804_item	2304426	et	3	main
kõige	doc_263021865804_item	2304428	et	4	main
populaarsem	doc_263021865804_item	2304429	et	4	main
kuid	doc_263021865804_item	2304430	et	4	main
uued	doc_263021865804_item	2304440	et	3	main
sisse	doc_263021865804_item	2304442	et	4	main
ja	doc_263021865804_item	2304444	et	3	main
kogu	doc_263021865804_item	2304445	et	4	main
see	doc_263021865804_item	2304446	et	3	main
keele	doc_263021865804_item	2304465	et	4	main
õigused	doc_263021865804_item	2304466	et	4	main
olid	doc_263021865804_item	2304467	et	4	main
suhu	doc_263021865804_item	2304483	et	3	main
pealegi	doc_263021865804_item	2304486	et	4	main
valitud	doc_263021865804_item	2304488	et	4	main
eesti	doc_263021865804_item	2304489	et	4	main
ees	doc_263021865804_item	2304502	et	4	main
korraldati	doc_263021865804_item	2304503	et	3	main
tuldi	doc_263021865804_item	2304504	et	3	main
kokku	doc_263021865804_item	2304505	et	3	main
öölaulupidu	doc_263021865804_item	2304506	et	4	main
tavaliselt	doc_263021865804_item	2304507	et	4	main
lipp	doc_263021865804_item	2304519	et	3	main
nagu	doc_263021865804_item	2304530	et	3	main
igasugusele	doc_263021865804_item	2304537	et	3	main
hoiab	doc_263021865804_item	2304547	et	3	main
sündmus	doc_263021865804_item	2304553	et	3	main
et	doc_263021865804_item	2304562	et	3	main
on	doc_263021865804_item	2304564	et	4	main
koos	doc_263021865804_item	2304568	et	4	main
gorbatshov	doc_263021865804_item	2304571	et	4	main
võimule	doc_263021865804_item	2304573	et	3	main
tema	doc_263021865804_item	2304575	et	4	main
gorbatshov	doc_263021865804_item	2304605	et	4	main
uued	doc_263021865804_item	2304608	et	3	main
põhiliseks	doc_263021865804_item	2304617	et	3	main
ja	doc_263021865804_item	2304620	et	3	main
olukorra	doc_263021865804_item	2304622	et	3	main
sõna	doc_263021865804_item	2304630	et	4	main
tähendabki	doc_263021865804_item	2304631	et	3	main
sama	doc_263021865804_item	2304636	et	4	main
õnnestunud	doc_263021865804_item	2304646	et	4	main
hukkamõistmine	doc_263021865804_item	2304650	et	3	main
üritas	doc_263021865804_item	2304652	et	3	main
oli	doc_263021865805_item	2304703	et	3	main
seisukord	doc_263021865805_item	2304706	et	3	main
ainuke	doc_263021865805_item	2304710	et	4	main
kirjeldada	doc_263021865805_item	2304714	et	3	main
ei	doc_263021865805_item	2304719	et	4	main
selline	doc_263021865805_item	2304729	et	4	main
tunne	doc_263021865805_item	2304730	et	4	main
ekraanilt	doc_263021865805_item	2304732	et	3	main
silmad	doc_263021865805_item	2304734	et	4	main
samas	doc_263021865805_item	2304742	et	4	main
hoidsid	doc_263021865805_item	2304744	et	4	main
kokku	doc_263021865805_item	2304745	et	3	main
tugev	doc_263021865805_item	2304751	et	4	main
et	doc_263021865805_item	2304752	et	3	main
vägedele	doc_263021865805_item	2304758	et	3	main
see	doc_263021865805_item	2304766	et	3	main
nende	doc_263021865805_item	2304771	et	4	main
on	doc_263021865803_item	2304324	et	4	main
väga	doc_263021865803_item	2304326	et	3	main
taha	doc_263021865803_item	2304335	et	4	main
tema	doc_263021865803_item	2304350	et	4	main
inimesi	doc_263021865803_item	2304356	et	4	main
venelasi	doc_263021865803_item	2304362	et	3	main
et	doc_263021865803_item	2304365	et	3	main
nende	doc_263021865803_item	2304366	et	4	main
käes	doc_263021865803_item	2304367	et	4	main
oli	doc_263021865803_item	2304368	et	3	main
võim	doc_263021865803_item	2304369	et	3	main
mis	doc_263021865803_item	2304370	et	4	main
oli	doc_263021865803_item	2304371	et	3	main
nende	doc_263021865803_item	2304372	et	4	main
arvamusel	doc_263021865803_item	2304373	et	3	main
kõige	doc_263021865803_item	2304374	et	4	main
hirmsam	doc_263021865803_item	2304375	et	4	main
kontrolltöö	doc_263021865804_item	2304376	et	4	main
1	doc_263021865804_item	2304377	et	2	main
iseloomustage	doc_263021865804_item	2304378	et	4	main
19701980	doc_263021865804_item	2304379	et	2	main
a-te	doc_263021865804_item	2304380	et	3	main
eesti	doc_263021865804_item	2304381	et	4	main
kultuurielu	doc_263021865804_item	2304382	et	4	main
2	doc_263021865804_item	2304383	et	2	main
nn	doc_263021865804_item	2304384	et	4	main
revolutsiooni	doc_263021865804_item	2304387	et	4	main
osa	doc_263021865804_item	2304388	et	4	main
eesti	doc_263021865804_item	2304389	et	4	main
taasiseseisvumisel	doc_263021865804_item	2304390	et	3	main
3	doc_263021865804_item	2304391	et	2	main
ja	doc_263021865804_item	2304397	et	3	main
kirjutas	doc_263021865804_item	2304408	et	3	main
akesküla	doc_263021865804_item	2304419	et	4	main
ka	doc_263021865804_item	2304431	et	3	main
järvi	doc_263021865804_item	2304434	et	4	main
olid	doc_263021865804_item	2304439	et	4	main
natuke	doc_263021865804_item	2304449	et	4	main
vabamaks	doc_263021865804_item	2304450	et	4	main
teoseid	doc_263021865804_item	2304462	et	3	main
2	doc_263021865804_item	2304463	et	2	main
ahistatud	doc_263021865804_item	2304468	et	4	main
vabaduse	doc_263021865804_item	2304484	et	4	main
olid	doc_263021865804_item	2304487	et	4	main
ka	doc_263021865804_item	2304496	et	3	main
valge	doc_263021865804_item	2304499	et	4	main
seisis	doc_263021865804_item	2304500	et	4	main
silme	doc_263021865804_item	2304501	et	4	main
koos	doc_263021865804_item	2304513	et	4	main
ja	doc_263021865804_item	2304514	et	3	main
lehvib	doc_263021865804_item	2304515	et	3	main
mitte	doc_263021865804_item	2304516	et	3	main
sõnade	doc_263021865804_item	2304392	et	3	main
romaane	doc_263021865804_item	2304407	et	3	main
põhiliseks	doc_263021865804_item	2304413	et	3	main
loomevoluks	doc_263021865804_item	2304414	et	4	main
sotsialistlik	doc_263021865804_item	2304416	et	3	main
väliseestlased	doc_263021865804_item	2304421	et	3	main
tegutsesid	doc_263021865804_item	2304424	et	4	main
pärt	doc_263021865804_item	2304432	et	4	main
nimed	doc_263021865804_item	2304441	et	3	main
muutus	doc_263021865804_item	2304448	et	4	main
korrigeerisid	doc_263021865804_item	2304459	et	4	main
eesti	doc_263021865804_item	2304470	et	4	main
rahvus	doc_263021865804_item	2304490	et	3	main
ja	doc_263021865804_item	2304492	et	3	main
ja	doc_263021865804_item	2304495	et	3	main
just	doc_263021865804_item	2304508	et	3	main
siis	doc_263021865804_item	2304509	et	3	main
kui	doc_263021865804_item	2304510	et	3	main
värvi	doc_263021865804_item	2304518	et	4	main
see	doc_263021865804_item	2304522	et	3	main
tõene	doc_263021865804_item	2304523	et	4	main
jaoks	doc_263021865804_item	2304525	et	4	main
liidab	doc_263021865804_item	2304527	et	3	main
inimesi	doc_263021865804_item	2304528	et	4	main
kergem	doc_263021865804_item	2304534	et	4	main
ka	doc_263021865804_item	2304542	et	3	main
revolutsioonil	doc_263021865804_item	2304544	et	3	main
rahvas	doc_263021865804_item	2304546	et	4	main
kokku	doc_263021865804_item	2304548	et	3	main
mis	doc_263021865804_item	2304550	et	4	main
samm	doc_263021865804_item	2304556	et	3	main
üliolulinerahvas	doc_263021865804_item	2304560	et	4	main
kui	doc_263021865804_item	2304565	et	3	main
kui	doc_263021865804_item	2304570	et	3	main
tuli	doc_263021865804_item	2304572	et	4	main
perestroikat	doc_263021865804_item	2304616	et	4	main
paranemine	doc_263021865804_item	2304623	et	4	main
muutmine	doc_263021865804_item	2304628	et	4	main
see	doc_263021865804_item	2304629	et	3	main
sula	doc_263021865804_item	2304638	et	4	main
ajal	doc_263021865804_item	2304639	et	4	main
vist	doc_263021865804_item	2304644	et	4	main
ei	doc_263021865804_item	2304645	et	4	main
gorbatshov	doc_263021865804_item	2304651	et	4	main
aga	doc_263021865804_item	2304653	et	3	main
nö	doc_263021865804_item	2304662	et	4	main
seda	doc_263021865804_item	2304664	et	3	main
oli	doc_263021865804_item	2304667	et	3	main
kokku	doc_263021865804_item	2304671	et	3	main
paanika	doc_263021865805_item	2304709	et	4	main
saab	doc_263021865805_item	2304713	et	3	main
toimunut	doc_263021865805_item	2304715	et	4	main
mitte	doc_263021865805_item	2304717	et	3	main
ees	doc_263021865805_item	2304724	et	4	main
filmi	doc_263021865805_item	2304726	et	4	main
tabas	doc_263021865805_item	2304728	et	4	main
mis	doc_263021865805_item	2304735	et	4	main
kaotasid	doc_263021865805_item	2304736	et	4	main
lootuse	doc_263021865805_item	2304737	et	4	main
iseseisvana	doc_263021865805_item	2304741	et	3	main
ja	doc_263021865805_item	2304746	et	3	main
vastu	doc_263021865805_item	2304755	et	3	main
sidekanalit	doc_263021865805_item	2304762	et	3	main
ja	doc_263021865805_item	2304765	et	3	main
peades	doc_263021865805_item	2304772	et	3	main
olid	doc_263021865805_item	2304773	et	4	main
veel	doc_263021865805_item	2304775	et	4	main
sõjaväe	doc_263021865805_item	2304781	et	3	main
meeleavaldused	doc_263021865805_item	2304820	et	3	main
nende	doc_263021865805_item	2304827	et	4	main
augustu	doc_263021865805_item	2304829	et	4	main
see	doc_263021865805_item	2304833	et	3	main
on	doc_263021865805_item	2304834	et	4	main
rahvus	doc_263021865805_item	2304837	et	3	main
eesti	doc_264166611934_item	2304841	et	4	main
fek	doc_264166611934_item	2304843	et	4	main
mida	doc_264166611934_item	2304845	et	4	main
eesti	doc_264166611934_item	2304853	et	4	main
kes	doc_264166611934_item	2304856	et	4	main
10	doc_264166611934_item	2304880	et	2	main
maa-aadlikud	doc_264166611934_item	2304881	et	3	main
talupoeg	doc_264166611934_item	2304882	et	3	main
vtormis	doc_263021865804_item	2304425	et	4	main
nendest	doc_263021865804_item	2304427	et	4	main
andnud	doc_263021865804_item	2304437	et	4	main
vilminduses	doc_263021865804_item	2304438	et	4	main
kuigi	doc_263021865804_item	2304451	et	3	main
tsensuur	doc_263021865804_item	2304452	et	3	main
säilis	doc_263021865804_item	2304453	et	4	main
ja	doc_263021865804_item	2304454	et	3	main
ka	doc_263021865804_item	2304455	et	3	main
kirjanikud	doc_263021865804_item	2304456	et	3	main
tegelesid	doc_263021865804_item	2304457	et	4	main
enesetsensuuriga	doc_263021865804_item	2304458	et	3	main
kohandasid	doc_263021865804_item	2304460	et	4	main
eesti	doc_263021865804_item	2304464	et	4	main
eestlased	doc_263021865804_item	2304471	et	3	main
ei	doc_263021865804_item	2304472	et	4	main
enam	doc_263021865804_item	2304474	et	4	main
seda	doc_263021865804_item	2304475	et	3	main
survet	doc_263021865804_item	2304476	et	3	main
kannatada	doc_263021865804_item	2304478	et	3	main
tel	doc_263021865804_item	2304480	et	4	main
jälle	doc_263021865804_item	2304482	et	3	main
maik	doc_263021865804_item	2304485	et	3	main
rahvus	doc_263021865804_item	2304493	et	3	main
sini	doc_263021865804_item	2304497	et	3	main
punast	doc_263021865804_item	2304517	et	4	main
vaid	doc_263021865804_item	2304520	et	3	main
see	doc_263021865804_item	2304526	et	3	main
on	doc_263021865804_item	2304533	et	4	main
sama	doc_263021865804_item	2304539	et	4	main
oli	doc_263021865804_item	2304541	et	3	main
see	doc_263021865804_item	2304552	et	3	main
oli	doc_263021865804_item	2304554	et	3	main
mis	doc_263021865804_item	2304557	et	4	main
lähenemiseks	doc_263021865804_item	2304558	et	4	main
näitas	doc_263021865804_item	2304561	et	3	main
võim	doc_263021865804_item	2304563	et	3	main
reformid	doc_263021865804_item	2304609	et	4	main
oli	doc_263021865804_item	2304618	et	3	main
ja	doc_263021865804_item	2304529	et	3	main
teada	doc_263021865804_item	2304531	et	3	main
panna	doc_263021865804_item	2304536	et	4	main
ideoloogiale	doc_263021865804_item	2304538	et	3	main
eesti	doc_263021865804_item	2304545	et	4	main
põhimõtteliselt	doc_263021865804_item	2304555	et	4	main
kõik	doc_263021865804_item	2304566	et	4	main
siis	doc_263021865804_item	2304574	et	3	main
arvas	doc_263021865804_item	2304576	et	3	main
et	doc_263021865804_item	2304577	et	3	main
olukorra	doc_263021865804_item	2304578	et	3	main
tuleb	doc_263021865804_item	2304579	et	3	main
kuidagi	doc_263021865804_item	2304580	et	3	main
parandada	doc_263021865804_item	2304581	et	3	main
ja	doc_263021865804_item	2304582	et	3	main
tekkinud	doc_263021865804_item	2304583	et	4	main
kriisist	doc_263021865804_item	2304584	et	3	main
ja	doc_263021865804_item	2304585	et	3	main
pidevast	doc_263021865804_item	2304586	et	3	main
olude	doc_263021865804_item	2304587	et	3	main
halvenemisest	doc_263021865804_item	2304588	et	4	main
tuleb	doc_263021865804_item	2304589	et	3	main
kuidagi	doc_263021865804_item	2304590	et	3	main
valja	doc_263021865804_item	2304591	et	3	main
astuda	doc_263021865804_item	2304592	et	3	main
ka	doc_263021865804_item	2304593	et	3	main
r	doc_263021865804_item	2304594	et	4	main
reigani	doc_263021865804_item	2304595	et	4	main
ja	doc_263021865804_item	2304596	et	3	main
m	doc_263021865804_item	2304597	et	4	main
plaan	doc_263021865804_item	2304599	et	3	main
tetsheri	doc_263021865804_item	2304598	et	4	main
nl	doc_263021865804_item	2304600	et	4	main
hävitada	doc_263021865804_item	2304601	et	3	main
kiirendas	doc_263021865804_item	2304602	et	3	main
otsuse	doc_263021865804_item	2304603	et	3	main
võtmist	doc_263021865804_item	2304604	et	4	main
et	doc_263021865804_item	2304607	et	3	main
aitavad	doc_263021865804_item	2304610	et	4	main
käivitas	doc_263021865804_item	2304615	et	3	main
viis	doc_263021865804_item	2304624	et	4	main
vana	doc_263021865804_item	2304626	et	4	main
korra	doc_263021865804_item	2304627	et	4	main
just	doc_263021865804_item	2304632	et	3	main
mis	doc_263021865804_item	2304637	et	4	main
alustas	doc_263021865804_item	2304640	et	3	main
lõpuni	doc_263021865804_item	2304643	et	3	main
panna	doc_263021865804_item	2304654	et	4	main
kõike	doc_263021865804_item	2304656	et	4	main
avalikustama	doc_263021865804_item	2304657	et	3	main
hakkama	doc_263021865804_item	2304661	et	3	main
rihma	doc_263021865804_item	2304665	et	4	main
moskvas	doc_263021865805_item	2304702	et	4	main
riigipööre	doc_263021865805_item	2304708	et	4	main
sõna	doc_263021865805_item	2304711	et	4	main
mis	doc_263021865805_item	2304721	et	4	main
mis	doc_263021865805_item	2304723	et	4	main
vaatavad	doc_263021865805_item	2304733	et	4	main
oma	doc_263021865805_item	2304739	et	4	main
see	doc_263021865805_item	2304747	et	3	main
oli	doc_263021865805_item	2304749	et	3	main
niivõrd	doc_263021865805_item	2304750	et	3	main
nad	doc_263021865805_item	2304753	et	3	main
baltikumis	doc_263021865805_item	2304763	et	4	main
teletorni	doc_263021865805_item	2304764	et	4	main
juures	doc_263021865805_item	2304769	et	4	main
värsked	doc_263021865805_item	2304776	et	4	main
nii	doc_263021865805_item	2304823	et	3	main
jooksul	doc_263021865805_item	2304831	et	4	main
riik	doc_263021865805_item	2304835	et	3	main
keel	doc_263021865805_item	2304838	et	4	main
2	doc_264166611934_item	2304849	et	2	main
tegeles	doc_264166611934_item	2304851	et	3	main
ja	doc_264166611934_item	2304855	et	3	main
sinna	doc_264166611934_item	2304857	et	3	main
tsaar	doc_264166611934_item	2304866	et	3	main
baltisaksa	doc_264166611934_item	2304869	et	4	main
tol	doc_264166611934_item	2304873	et	3	main
pärisori	doc_264166611934_item	2304885	et	4	main
talupoegade	doc_264166611934_item	2304898	et	3	main
võis	doc_264166611934_item	2304927	et	4	main
üpris	doc_264166611934_item	2304931	et	3	main
kui	doc_264166611934_item	2304936	et	3	main
üles	doc_264166611934_item	2304939	et	3	main
põletati	doc_264166611934_item	2304941	et	3	main
andma	doc_264166611934_item	2304950	et	3	main
inimese	doc_264166611934_item	2304966	et	4	main
säilitas	doc_264166611934_item	2304986	et	3	main
mis	doc_264166611934_item	2304989	et	4	main
tegi	doc_264166611934_item	2304999	et	4	main
siinsed	doc_264166611934_item	2305002	et	3	main
keelt	doc_264166611934_item	2305008	et	4	main
talupoegade	doc_264166611934_item	2305009	et	3	main
protest	doc_264166611934_item	2305010	et	3	main
omandas	doc_264166611934_item	2305011	et	3	main
e	doc_264166611934_item	2305019	et	4	main
ees	doc_264166611934_item	2305026	et	4	main
on	doc_264166611934_item	2305027	et	4	main
tähendas	doc_264166611934_item	2305032	et	3	main
piinadest	doc_264166611934_item	2305034	et	3	main
kaudu	doc_264166611934_item	2305047	et	3	main
liikmeks	doc_264166611934_item	2305053	et	3	main
haridust	doc_264166611934_item	2305070	et	4	main
vajalikkusest	doc_264166611934_item	2305104	et	4	main
korralda	doc_264166611934_item	2305112	et	4	main
nn	doc_264166611934_item	2305113	et	4	main
kalevipoja	doc_264166611934_item	2305114	et	4	main
õhtuid	doc_264166611934_item	2305115	et	3	main
kui	doc_264166611934_item	2305116	et	3	main
toime	doc_263021865804_item	2304612	et	4	main
tulla	doc_263021865804_item	2304613	et	3	main
ja	doc_263021865804_item	2304614	et	3	main
elatustase	doc_263021865804_item	2304619	et	3	main
majandusliku	doc_263021865804_item	2304621	et	3	main
aga	doc_263021865804_item	2304625	et	3	main
seda	doc_263021865804_item	2304633	et	3	main
oli	doc_263021865804_item	2304635	et	3	main
seda	doc_263021865804_item	2304647	et	3	main
teha	doc_263021865804_item	2304648	et	3	main
millega	doc_263021865804_item	2304666	et	3	main
kõik	doc_263021865804_item	2304668	et	4	main
tugevasti	doc_263021865804_item	2304670	et	3	main
surutud	doc_263021865804_item	2304672	et	4	main
hästi	doc_263021865805_item	2304675	et	3	main
siis	doc_263021865805_item	2304700	et	3	main
kuulutatud	doc_263021865805_item	2304704	et	4	main
erakorraline	doc_263021865805_item	2304705	et	4	main
sõjaväeline	doc_263021865805_item	2304707	et	4	main
millega	doc_263021865805_item	2304712	et	3	main
teadnud	doc_263021865805_item	2304720	et	4	main
glasnostj	doc_263021865804_item	2304634	et	4	main
nhrushov	doc_263021865804_item	2304641	et	4	main
kui	doc_263021865804_item	2304642	et	3	main
isikukultuse	doc_263021865804_item	2304649	et	3	main
nüüd	doc_263021865804_item	2304655	et	4	main
ja	doc_263021865804_item	2304658	et	3	main
asjadest	doc_263021865804_item	2304659	et	3	main
rääkima	doc_263021865804_item	2304660	et	3	main
lõtvestas	doc_263021865804_item	2304663	et	4	main
nii	doc_263021865804_item	2304669	et	3	main
essee	doc_263021865805_item	2304673	et	4	main
kui	doc_263021865805_item	2304674	et	3	main
kajastuvad	doc_263021865805_item	2304676	et	4	main
selles	doc_263021865805_item	2304677	et	4	main
taasiseseisvumissündmused	doc_263021865805_item	2304680	et	3	main
filmis	doc_263021865805_item	2304678	et	4	main
kui	doc_263021865805_item	2304681	et	3	main
inimesi	doc_263021865805_item	2304682	et	4	main
puudutab	doc_263021865805_item	2304683	et	3	main
eesti	doc_263021865805_item	2304679	et	4	main
midagi	doc_263021865805_item	2304684	et	4	main
midagi	doc_263021865805_item	2304686	et	4	main
mis	doc_263021865805_item	2304687	et	4	main
seni	doc_263021865805_item	2304688	et	3	main
erakordset	doc_263021865805_item	2304685	et	3	main
tundmatu	doc_263021865805_item	2304689	et	4	main
võõras	doc_263021865805_item	2304690	et	4	main
oli	doc_263021865805_item	2304691	et	3	main
siis	doc_263021865805_item	2304692	et	3	main
esimene	doc_263021865805_item	2304693	et	3	main
asi	doc_263021865805_item	2304694	et	4	main
sattutakse	doc_263021865805_item	2304695	et	3	main
paanikasse	doc_263021865805_item	2304696	et	4	main
samamoodi	doc_263021865805_item	2304697	et	3	main
oli	doc_263021865805_item	2304698	et	3	main
ka	doc_263021865805_item	2304699	et	3	main
kui	doc_263021865805_item	2304701	et	3	main
estis	doc_263021865805_item	2304716	et	4	main
keegi	doc_263021865805_item	2304718	et	4	main
ootamas	doc_263021865805_item	2304725	et	3	main
vaadates	doc_263021865805_item	2304727	et	3	main
nagu	doc_263021865805_item	2304731	et	3	main
riiki	doc_263021865805_item	2304740	et	4	main
panna	doc_263021865805_item	2304756	et	4	main
ja	doc_263021865805_item	2304759	et	3	main
ainukest	doc_263021865805_item	2304761	et	4	main
kõik	doc_263021865805_item	2304767	et	4	main
vilniuse	doc_263021865805_item	2304777	et	4	main
ja	doc_263021865805_item	2304780	et	3	main
kuid	doc_263021865805_item	2304815	et	4	main
tugevam	doc_263021865805_item	2304817	et	4	main
olid	doc_263021865805_item	2304821	et	4	main
mõndagi	doc_263021865805_item	2304824	et	4	main
kontrolltöö	doc_264166611934_item	2304840	et	4	main
selts	doc_264166611934_item	2304854	et	3	main
1	doc_264166611934_item	2304859	et	2	main
talupojad	doc_264166611934_item	2304860	et	4	main
satuvad	doc_264166611934_item	2304861	et	3	main
2	doc_264166611934_item	2304862	et	2	main
alla	doc_264166611934_item	2304864	et	3	main
ja	doc_264166611934_item	2304867	et	3	main
talurahvas	doc_264166611934_item	2304878	et	4	main
oli	doc_264166611934_item	2304883	et	3	main
oli	doc_264166611934_item	2304888	et	3	main
pärisorjus	doc_264166611934_item	2304889	et	3	main
raames	doc_264166611934_item	2304894	et	4	main
pärisorjus	doc_264166611934_item	2304895	et	3	main
isegi	doc_264166611934_item	2304896	et	4	main
tugevnes	doc_264166611934_item	2304897	et	3	main
saab	doc_263021865805_item	2304722	et	3	main
säilitada	doc_263021865805_item	2304738	et	3	main
inimesed	doc_263021865805_item	2304743	et	3	main
jõud	doc_263021865805_item	2304748	et	4	main
suutsid	doc_263021865805_item	2304754	et	4	main
vene	doc_263021865805_item	2304757	et	4	main
päästa	doc_263021865805_item	2304760	et	4	main
selle	doc_263021865805_item	2304768	et	4	main
et	doc_263021865805_item	2304770	et	3	main
ja	doc_263021865805_item	2304779	et	3	main
verised	doc_263021865805_item	2304782	et	4	main
kokkupõrked	doc_263021865805_item	2304783	et	3	main
see	doc_263021865805_item	2304784	et	3	main
mis	doc_263021865805_item	2304785	et	4	main
üritab	doc_263021865805_item	2304786	et	3	main
lahutada	doc_263021865805_item	2304787	et	3	main
see	doc_263021865805_item	2304788	et	3	main
teeb	doc_263021865805_item	2304789	et	3	main
ka	doc_263021865805_item	2304790	et	3	main
tugevamaks	doc_263021865805_item	2304791	et	4	main
klassikaline	doc_263021865805_item	2304792	et	4	main
muusika	doc_263021865805_item	2304793	et	4	main
ei	doc_263021865805_item	2304794	et	4	main
tähenda	doc_263021865805_item	2304795	et	4	main
kunagi	doc_263021865805_item	2304796	et	3	main
head	doc_263021865805_item	2304797	et	4	main
kui	doc_263021865805_item	2304798	et	3	main
vaatamata	doc_263021865805_item	2304799	et	4	main
kõigele	doc_263021865805_item	2304800	et	4	main
eesti	doc_263021865805_item	2304801	et	4	main
rahvas	doc_263021865805_item	2304802	et	4	main
säilitas	doc_263021865805_item	2304803	et	3	main
iseseisvuse	doc_263021865805_item	2304804	et	4	main
ja	doc_263021865805_item	2304805	et	3	main
see	doc_263021865805_item	2304806	et	3	main
oli	doc_263021865805_item	2304807	et	3	main
sama	doc_263021865805_item	2304808	et	4	main
riik	doc_263021865805_item	2304809	et	3	main
mis	doc_263021865805_item	2304810	et	4	main
ta	doc_263021865805_item	2304811	et	4	main
oli	doc_263021865805_item	2304812	et	3	main
enne	doc_263021865805_item	2304813	et	4	main
putshi	doc_263021865805_item	2304814	et	4	main
keerlenud	doc_263021865805_item	2304774	et	4	main
rahva	doc_263021865805_item	2304778	et	3	main
veel	doc_263021865805_item	2304816	et	4	main
endale	doc_263021865805_item	2304822	et	4	main
saanud	doc_263021865805_item	2304825	et	4	main
võitnud	doc_263021865805_item	2304826	et	4	main
mis	doc_263021865805_item	2304832	et	4	main
identiteet	doc_263021865805_item	2304836	et	4	main
kontrolltöö	doc_264166611934_item	2304839	et	4	main
kultuuriloost	doc_264166611934_item	2304842	et	4	main
1	doc_264166611934_item	2304844	et	2	main
tähendab	doc_264166611934_item	2304846	et	3	main
balti	doc_264166611934_item	2304847	et	3	main
erikord	doc_264166611934_item	2304848	et	3	main
millega	doc_264166611934_item	2304850	et	3	main
kuulusid	doc_264166611934_item	2304858	et	4	main
kohalikud	doc_264166611934_item	2304868	et	3	main
umbes	doc_264166611934_item	2304871	et	4	main
maal	doc_264166611934_item	2304879	et	4	main
veel	doc_264166611934_item	2304884	et	4	main
kaotatud	doc_264166611934_item	2304891	et	4	main
balti	doc_264166611934_item	2304892	et	3	main
ihunuhtlust	doc_264166611934_item	2304929	et	3	main
tihti	doc_264166611934_item	2304932	et	3	main
talupojad	doc_264166611934_item	2304934	et	4	main
nähtavale	doc_264166611934_item	2304943	et	4	main
selle	doc_264166611934_item	2304952	et	4	main
vabastada	doc_264166611934_item	2304955	et	3	main
kristlikust	doc_264166611934_item	2304957	et	4	main
oli	doc_264166611934_item	2304959	et	3	main
mõistus	doc_264166611934_item	2304967	et	4	main
rootsi	doc_264166611934_item	2304991	et	4	main
ajast	doc_264166611934_item	2304992	et	4	main
ja	doc_264166611934_item	2304998	et	3	main
inimesed	doc_264166611934_item	2305003	et	3	main
ära	doc_264166611934_item	2305006	et	4	main
ka	doc_264166611934_item	2305012	et	3	main
vormi	doc_264166611934_item	2305014	et	4	main
vennastekoguduslikud	doc_264166611934_item	2305020	et	4	main
et	doc_264166611934_item	2305024	et	3	main
vabanemist	doc_264166611934_item	2305035	et	4	main
said	doc_264166611934_item	2305048	et	4	main
vennastekoguduse	doc_264166611934_item	2305052	et	3	main
muusikat	doc_264166611934_item	2305059	et	3	main
pidi	doc_264166611934_item	2305064	et	4	main
lausa	doc_264166611934_item	2305068	et	4	main
paljud	doc_264166611934_item	2305071	et	3	main
jutlustajad	doc_264166611934_item	2305072	et	4	main
õhutasid	doc_264166611934_item	2305073	et	4	main
talupoegi	doc_264166611934_item	2305074	et	4	main
mässama	doc_264166611934_item	2305075	et	3	main
mõisnikke	doc_264166611934_item	2305076	et	3	main
nuhtlema	doc_264166611934_item	2305078	et	3	main
hakati	doc_264166611934_item	2305101	et	3	main
eepose	doc_264166611934_item	2305103	et	3	main
tõlkis	doc_264166611934_item	2305106	et	3	main
poleks	doc_264166611934_item	2305118	et	3	main
oleks	doc_264166611934_item	2305121	et	3	main
kokkupanija	doc_264166611934_item	2305125	et	4	main
kontrolltöö	doc_264166611935_item	2305132	et	4	main
sinna	doc_264166611935_item	2305148	et	3	main
erikord	doc_264166611935_item	2305152	et	3	main
elas	doc_264166611935_item	2305161	et	3	main
10	doc_264166611935_item	2305165	et	2	main
kord	doc_264166611935_item	2305176	et	4	main
oli	doc_264166611935_item	2305179	et	3	main
see	doc_264166611935_item	2305184	et	3	main
tugevnes	doc_264166611935_item	2305185	et	3	main
oli	doc_264166611935_item	2305187	et	3	main
kuid	doc_264166611935_item	2305195	et	4	main
jäid	doc_264166611935_item	2305197	et	4	main
kodukari	doc_264166611935_item	2305201	et	4	main
eesti	doc_263021865805_item	2304818	et	4	main
rahva	doc_263021865805_item	2304819	et	3	main
kolme	doc_263021865805_item	2304828	et	4	main
päeva	doc_263021865805_item	2304830	et	4	main
õpetatud	doc_264166611934_item	2304852	et	4	main
isanda	doc_264166611934_item	2304863	et	3	main
vene	doc_264166611934_item	2304865	et	4	main
aadlikud	doc_264166611934_item	2304870	et	3	main
90	doc_264166611934_item	2304872	et	2	main
ajal	doc_264166611934_item	2304874	et	4	main
elavatest	doc_264166611934_item	2304875	et	4	main
inimestest	doc_264166611934_item	2304876	et	3	main
oli	doc_264166611934_item	2304877	et	3	main
kuigi	doc_264166611934_item	2304886	et	3	main
ammu	doc_264166611934_item	2304890	et	4	main
erikorra	doc_264166611934_item	2304893	et	3	main
muuta	doc_264166611934_item	2304901	et	4	main
mõisnike	doc_264166611934_item	2304902	et	3	main
omandiks	doc_264166611934_item	2304903	et	3	main
neid	doc_264166611934_item	2304904	et	4	main
talupoegi	doc_264166611934_item	2304905	et	4	main
kes	doc_264166611934_item	2304906	et	4	main
varem	doc_264166611934_item	2304907	et	4	main
olid	doc_264166611934_item	2304908	et	4	main
vabad	doc_264166611934_item	2304909	et	3	main
või	doc_264166611934_item	2304910	et	4	main
poolvabad	doc_264166611934_item	2304911	et	3	main
muudeti	doc_264166611934_item	2304912	et	3	main
ka	doc_264166611934_item	2304913	et	3	main
pärisorjadeks	doc_264166611934_item	2304914	et	3	main
hiljem	doc_264166611934_item	2304915	et	3	main
otsustati	doc_264166611934_item	2304916	et	3	main
et	doc_264166611934_item	2304917	et	3	main
rootsi	doc_264166611934_item	2304918	et	4	main
aegsed	doc_264166611934_item	2304919	et	3	main
seadused	doc_264166611934_item	2304920	et	3	main
mõisnik	doc_264166611934_item	2304926	et	3	main
talupoegadele	doc_264166611934_item	2304928	et	3	main
põgenesid	doc_264166611934_item	2304933	et	4	main
välja	doc_264166611934_item	2304949	et	4	main
oli	doc_264166611934_item	2304954	et	3	main
valgustusaeg	doc_264166611934_item	2304961	et	3	main
et	doc_264166611934_item	2304965	et	3	main
suudab	doc_264166611934_item	2304968	et	3	main
privileegid	doc_264166611934_item	2304988	et	3	main
maakeele	doc_264166611934_item	2304997	et	4	main
et	doc_264166611934_item	2305001	et	3	main
ei	doc_264166611934_item	2305004	et	4	main
õpiks	doc_264166611934_item	2305005	et	4	main
vaated	doc_264166611934_item	2305021	et	3	main
uskusid	doc_264166611934_item	2305023	et	4	main
võrdsed	doc_264166611934_item	2305029	et	3	main
surm	doc_264166611934_item	2305031	et	3	main
maisetest	doc_264166611934_item	2305033	et	4	main
hernhuutlaste	doc_264166611934_item	2305046	et	3	main
jumalasõnaraamatuid	doc_264166611934_item	2305050	et	3	main
oma	doc_264166611934_item	2305061	et	4	main
kõrgemat	doc_264166611934_item	2305069	et	4	main
faehlmann	doc_264166611934_item	2305105	et	4	main
ära	doc_264166611934_item	2305119	et	4	main
kuulus	doc_264166611934_item	2305127	et	4	main
eesti	doc_264166611935_item	2305133	et	4	main
kultuuriloost	doc_264166611935_item	2305134	et	4	main
euroopas	doc_264166611934_item	2304887	et	3	main
vara	doc_264166611934_item	2304899	et	4	main
püüti	doc_264166611934_item	2304900	et	3	main
jäävad	doc_264166611934_item	2304921	et	4	main
säilis	doc_264166611934_item	2304923	et	4	main
kodukari	doc_264166611934_item	2304924	et	4	main
õigus	doc_264166611934_item	2304925	et	4	main
venemaale	doc_264166611934_item	2304935	et	4	main
talupoeg	doc_264166611934_item	2304938	et	3	main
leiti	doc_264166611934_item	2304940	et	3	main
1571	doc_264166611934_item	2304946	et	2	main
mõte	doc_264166611934_item	2304953	et	3	main
dogmaatikast	doc_264166611934_item	2304958	et	4	main
inglismaa	doc_264166611934_item	2304962	et	4	main
arvati	doc_264166611934_item	2304964	et	4	main
talupoegade	doc_264166611934_item	2304987	et	3	main
baltisaksa	doc_264166611934_item	2304993	et	4	main
mõisnik	doc_264166611934_item	2304994	et	3	main
õppis	doc_264166611934_item	2304995	et	3	main
ära	doc_264166611934_item	2304996	et	4	main
saksa	doc_264166611934_item	2305007	et	4	main
usulise	doc_264166611934_item	2305013	et	4	main
levisid	doc_264166611934_item	2305016	et	4	main
püsima	doc_264166611934_item	2304922	et	3	main
jagada	doc_264166611934_item	2304930	et	3	main
põgenenud	doc_264166611934_item	2304937	et	4	main
talle	doc_264166611934_item	2304942	et	4	main
kohale	doc_264166611934_item	2304944	et	4	main
häbimärk	doc_264166611934_item	2304945	et	3	main
a	doc_264166611934_item	2304947	et	4	main
hakati	doc_264166611934_item	2304948	et	3	main
entsüklopeediat	doc_264166611934_item	2304951	et	3	main
inimesed	doc_264166611934_item	2304956	et	3	main
alanud	doc_264166611934_item	2304960	et	4	main
prantsusmaa	doc_264166611934_item	2304963	et	4	main
lahendada	doc_264166611934_item	2304969	et	3	main
probleemid	doc_264166611934_item	2304971	et	3	main
kõik	doc_264166611934_item	2304970	et	4	main
need	doc_264166611934_item	2304972	et	3	main
ideed	doc_264166611934_item	2304973	et	4	main
jõudsid	doc_264166611934_item	2304974	et	4	main
siia	doc_264166611934_item	2304975	et	4	main
umbes	doc_264166611934_item	2304976	et	4	main
100-aastase	doc_264166611934_item	2304977	et	4	main
hilinemisega	doc_264166611934_item	2304978	et	4	main
balti	doc_264166611934_item	2304979	et	3	main
erikord	doc_264166611934_item	2304980	et	3	main
päästis	doc_264166611934_item	2304981	et	3	main
eesti	doc_264166611934_item	2304982	et	4	main
keele	doc_264166611934_item	2304983	et	4	main
peeter	doc_264166611934_item	2304984	et	3	main
i	doc_264166611934_item	2304985	et	4	main
olid	doc_264166611934_item	2304990	et	4	main
kõik	doc_264166611934_item	2305000	et	4	main
1730-1740	doc_264166611934_item	2305015	et	2	main
eestisse	doc_264166611934_item	2305017	et	4	main
hernhuutlikud	doc_264166611934_item	2305018	et	3	main
paradiisi	doc_264166611934_item	2305037	et	4	main
vara	doc_264166611934_item	2305041	et	4	main
talupojad	doc_264166611934_item	2305049	et	4	main
et	doc_264166611934_item	2305051	et	3	main
saada	doc_264166611934_item	2305054	et	4	main
pidi	doc_264166611934_item	2305055	et	4	main
oskama	doc_264166611934_item	2305056	et	3	main
lugeda	doc_264166611934_item	2305057	et	3	main
kirjutada	doc_264166611934_item	2305058	et	3	main
mõtetest	doc_264166611934_item	2305062	et	3	main
tänapäeva	doc_264166611934_item	2305066	et	4	main
saksa	doc_264166611934_item	2305109	et	4	main
surnud	doc_264166611934_item	2305120	et	4	main
temast	doc_264166611934_item	2305122	et	3	main
ões-i	doc_264166611934_item	2305126	et	4	main
veel	doc_264166611934_item	2305128	et	4	main
selts	doc_264166611935_item	2305145	et	3	main
1	doc_264166611935_item	2305150	et	2	main
ja	doc_264166611935_item	2305164	et	3	main
oli	doc_264166611935_item	2305169	et	3	main
pärisori	doc_264166611935_item	2305171	et	4	main
euroopas	doc_264166611935_item	2305172	et	3	main
juba	doc_264166611935_item	2305174	et	3	main
mõisniku	doc_264166611935_item	2305188	et	3	main
omandiks	doc_264166611935_item	2305190	et	3	main
siiski	doc_264166611935_item	2305196	et	4	main
pärisorjadeks	doc_264166611935_item	2305198	et	3	main
mõisnikul	doc_264166611935_item	2305199	et	3	main
võis	doc_264166611935_item	2305204	et	4	main
pärisorja	doc_264166611935_item	2305208	et	4	main
sest	doc_264166611935_item	2305222	et	4	main
ei	doc_264166611935_item	2305225	et	4	main
tahtnud	doc_264166611935_item	2305226	et	4	main
talurahva	doc_264166611935_item	2305243	et	3	main
venestuspoliitikat	doc_264166611935_item	2305258	et	3	main
oli	doc_264166611935_item	2305265	et	3	main
1839	doc_264166611935_item	2305268	et	2	main
aastal	doc_264166611935_item	2305269	et	3	main
tähtsamaks	doc_264166611935_item	2305270	et	4	main
keele	doc_264166611935_item	2305281	et	4	main
lõunaeesti	doc_264166611935_item	2305289	et	3	main
aabitsaid	doc_264166611935_item	2305291	et	3	main
ilmalikku	doc_264166611935_item	2305294	et	4	main
kirjandust	doc_264166611935_item	2305295	et	3	main
tegutsesid	doc_264166611935_item	2305298	et	4	main
ka	doc_264166611935_item	2305299	et	3	main
jakob	doc_264166611935_item	2305300	et	4	main
ja	doc_264166611935_item	2305305	et	3	main
seltsi	doc_264166611935_item	2305307	et	4	main
faehlmann	doc_264166611935_item	2305309	et	4	main
jakob	doc_264166611935_item	2305325	et	4	main
oli	doc_264166611935_item	2305327	et	3	main
vanglasse	doc_264166611935_item	2305349	et	4	main
sattumisest	doc_264166611935_item	2305350	et	4	main
mängis	doc_264166611935_item	2305362	et	3	main
eesti	doc_264166611935_item	2305365	et	4	main
peamised	doc_268694804105_item	2305374	et	3	main
erinevused	doc_268694804105_item	2305375	et	4	main
ev	doc_268694804105_item	2305376	et	4	main
ja	doc_268694804105_item	2305380	et	3	main
hrustshovi	doc_268694804105_item	2305390	et	4	main
1	doc_268694804105_item	2305392	et	2	main
ev	doc_268694804105_item	2305393	et	4	main
ei	doc_268694804105_item	2305406	et	4	main
tähendab	doc_268694804105_item	2305409	et	3	main
ei	doc_268694804105_item	2305411	et	4	main
kuidas	doc_268694804105_item	2305419	et	3	main
seltsidesse	doc_268694804105_item	2305427	et	3	main
represeeriti	doc_268694804105_item	2305438	et	4	main
keelne	doc_268694804105_item	2305440	et	3	main
vene	doc_268694804105_item	2305443	et	4	main
kui	doc_268694804105_item	2305445	et	3	main
24021918	doc_268694804105_item	2305447	et	2	main
aastal	doc_268694804105_item	2305448	et	3	main
100-liikmeline	doc_268694804105_item	2305455	et	4	main
ning	doc_268694804105_item	2305457	et	3	main
nad	doc_264166611934_item	2305022	et	3	main
jumala	doc_264166611934_item	2305025	et	3	main
kõik	doc_264166611934_item	2305028	et	4	main
inimese	doc_264166611934_item	2305030	et	4	main
pääsemist	doc_264166611934_item	2305036	et	4	main
mõisnikud	doc_264166611934_item	2305038	et	3	main
hakkasid	doc_264166611934_item	2305039	et	4	main
oma	doc_264166611934_item	2305040	et	4	main
jagama	doc_264166611934_item	2305042	et	3	main
et	doc_264166611934_item	2305043	et	3	main
pääseda	doc_264166611934_item	2305044	et	3	main
paradiisi	doc_264166611934_item	2305045	et	4	main
kirjutada	doc_264166611934_item	2305060	et	3	main
tunnetest	doc_264166611934_item	2305063	et	3	main
omama	doc_264166611934_item	2305065	et	4	main
mõistes	doc_264166611934_item	2305067	et	4	main
röövima	doc_264166611934_item	2305077	et	4	main
1õpetatud	doc_264166611934_item	2305079	et	4	main
eesti	doc_264166611934_item	2305080	et	4	main
selts	doc_264166611934_item	2305081	et	3	main
alustas	doc_264166611934_item	2305082	et	3	main
oma	doc_264166611934_item	2305083	et	4	main
tegevust	doc_264166611934_item	2305084	et	4	main
1838	doc_264166611934_item	2305085	et	2	main
aastal	doc_264166611934_item	2305086	et	3	main
tartu	doc_264166611934_item	2305087	et	4	main
ülikooli	doc_264166611934_item	2305088	et	4	main
juures	doc_264166611934_item	2305089	et	4	main
koosolekud	doc_264166611934_item	2305090	et	3	main
toimusid	doc_264166611934_item	2305091	et	4	main
ja	doc_264166611934_item	2305092	et	3	main
toimuvad	doc_264166611934_item	2305093	et	4	main
nüüdki	doc_264166611934_item	2305094	et	4	main
iga	doc_264166611934_item	2305095	et	4	main
kuu	doc_264166611934_item	2305096	et	4	main
viimasel	doc_264166611934_item	2305097	et	3	main
kolmapäeval	doc_264166611934_item	2305098	et	3	main
faehlmanni	doc_264166611934_item	2305099	et	4	main
eestvedamisel	doc_264166611934_item	2305100	et	3	main
arutama	doc_264166611934_item	2305102	et	3	main
eestikeelsed	doc_264166611934_item	2305107	et	3	main
muistendid	doc_264166611934_item	2305108	et	3	main
keelde	doc_264166611934_item	2305110	et	4	main
ning	doc_264166611934_item	2305111	et	3	main
faehlmann	doc_264166611934_item	2305117	et	4	main
kalevipoja	doc_264166611934_item	2305124	et	4	main
jakob	doc_264166611934_item	2305129	et	4	main
hurt	doc_264166611934_item	2305130	et	3	main
kontrolltöö	doc_264166611935_item	2305131	et	4	main
2	doc_264166611935_item	2305140	et	2	main
tegeles	doc_264166611935_item	2305142	et	3	main
eesti	doc_264166611935_item	2305144	et	4	main
kuulusid	doc_264166611935_item	2305149	et	4	main
peeter	doc_264166611935_item	2305154	et	3	main
maa	doc_264166611935_item	2305166	et	4	main
täielik	doc_264166611935_item	2305170	et	3	main
valitses	doc_264166611935_item	2305173	et	3	main
kapitalistlik	doc_264166611935_item	2305175	et	3	main
mõned	doc_264166611935_item	2305191	et	3	main
isegi	doc_264166611935_item	2305205	et	4	main
balti	doc_264166611935_item	2305209	et	3	main
keele	doc_264166611935_item	2305221	et	4	main
sakslastest	doc_264166611935_item	2305223	et	3	main
mõisnikud	doc_264166611935_item	2305224	et	3	main
saksastuks	doc_264166611935_item	2305229	et	3	main
ei	doc_264166611935_item	2305231	et	4	main
õppida	doc_264166611935_item	2305234	et	3	main
ning	doc_264166611935_item	2305235	et	3	main
saab	doc_264166611935_item	2305245	et	3	main
ei	doc_264166611935_item	2305251	et	4	main
ellu	doc_264166611935_item	2305259	et	4	main
eesti	doc_264166611935_item	2305263	et	4	main
loodud	doc_264166611935_item	2305266	et	4	main
tartus	doc_264166611935_item	2305267	et	3	main
r	doc_264166611935_item	2305274	et	4	main
tegeles	doc_264166611935_item	2305279	et	3	main
andis	doc_264166611935_item	2305287	et	3	main
ja	doc_264166611935_item	2305292	et	3	main
ajal	doc_264166611935_item	2305297	et	4	main
r	doc_264166611935_item	2305303	et	4	main
jannsen	doc_264166611935_item	2305306	et	4	main
tema	doc_264166611935_item	2305321	et	4	main
postimees	doc_264166611935_item	2305339	et	4	main
oli	doc_264166611935_item	2305341	et	3	main
nagu	doc_264166611935_item	2305343	et	3	main
saatmise	doc_264166611935_item	2305352	et	4	main
1	doc_268694804105_item	2305371	et	2	main
ühiskonnakorralduses	doc_268694804105_item	2305379	et	3	main
mida	doc_268694804105_item	2305383	et	4	main
erinevused	doc_268694804105_item	2305397	et	4	main
ühiskonnakorralduses	doc_268694804105_item	2305398	et	3	main
et	doc_268694804105_item	2305401	et	3	main
eesti	doc_268694804105_item	2305402	et	4	main
ajal	doc_268694804105_item	2305404	et	4	main
riigikorraldust	doc_268694804105_item	2305408	et	3	main
ei	doc_268694804105_item	2305414	et	4	main
käsklusi	doc_268694804105_item	2305416	et	3	main
saanud	doc_264166611934_item	2305123	et	4	main
kes	doc_264166611935_item	2305147	et	4	main
tähendab	doc_264166611935_item	2305153	et	3	main
i	doc_264166611935_item	2305155	et	4	main
rootsi	doc_264166611935_item	2305157	et	4	main
aadlike	doc_264166611935_item	2305158	et	4	main
talurahvast	doc_264166611935_item	2305163	et	4	main
ja	doc_264166611935_item	2305177	et	3	main
pärisorjus	doc_264166611935_item	2305178	et	3	main
ammu	doc_264166611935_item	2305180	et	4	main
kadunud	doc_264166611935_item	2305181	et	4	main
aga	doc_264166611935_item	2305182	et	3	main
eestis	doc_264166611935_item	2305183	et	3	main
talupoeg	doc_264166611935_item	2305186	et	3	main
talupojad	doc_264166611935_item	2305192	et	4	main
olid	doc_264166611935_item	2305193	et	4	main
poolvabad	doc_264166611935_item	2305194	et	3	main
oli	doc_264166611935_item	2305200	et	3	main
tappa	doc_264166611935_item	2305206	et	4	main
erikorra	doc_264166611935_item	2305210	et	3	main
haridus	doc_264166611935_item	2305212	et	3	main
oli	doc_264166611935_item	2305213	et	3	main
saksakeelne	doc_264166611935_item	2305214	et	3	main
võib	doc_264166611935_item	2305215	et	3	main
öelda	doc_264166611935_item	2305216	et	4	main
et	doc_264166611935_item	2305217	et	3	main
see	doc_264166611935_item	2305218	et	3	main
päästis	doc_264166611935_item	2305219	et	3	main
eesti	doc_264166611935_item	2305220	et	4	main
et	doc_264166611935_item	2305227	et	3	main
talurahvas	doc_264166611935_item	2305228	et	4	main
kartsid	doc_264166611935_item	2305241	et	4	main
protest	doc_264166611935_item	2305244	et	3	main
aleksander	doc_264166611935_item	2305249	et	4	main
hakkas	doc_264166611935_item	2305257	et	3	main
viima	doc_264166611935_item	2305260	et	3	main
faehlmann	doc_264166611935_item	2305275	et	4	main
õpetatud	doc_264166611935_item	2305276	et	4	main
eesti	doc_264166611935_item	2305280	et	4	main
korraldas	doc_264166611935_item	2305283	et	3	main
eestikeelseid	doc_264166611935_item	2305284	et	3	main
trükimisi	doc_264166611935_item	2305285	et	4	main
keeles	doc_264166611935_item	2305290	et	4	main
seltsi	doc_264166611935_item	2305296	et	4	main
kreutzwald	doc_264166611935_item	2305304	et	4	main
1	doc_264166611935_item	2305135	et	2	main
mida	doc_264166611935_item	2305136	et	4	main
tähendab	doc_264166611935_item	2305137	et	3	main
balti	doc_264166611935_item	2305138	et	3	main
erikord	doc_264166611935_item	2305139	et	3	main
millega	doc_264166611935_item	2305141	et	3	main
õpetatud	doc_264166611935_item	2305143	et	4	main
ja	doc_264166611935_item	2305146	et	3	main
balti	doc_264166611935_item	2305151	et	3	main
ja	doc_264166611935_item	2305156	et	3	main
võimu	doc_264166611935_item	2305159	et	4	main
maal	doc_264166611935_item	2305160	et	4	main
90	doc_264166611935_item	2305162	et	2	main
aadlikke	doc_264166611935_item	2305167	et	3	main
talupoeg	doc_264166611935_item	2305168	et	3	main
täielikuks	doc_264166611935_item	2305189	et	3	main
õigus	doc_264166611935_item	2305202	et	4	main
ta	doc_264166611935_item	2305203	et	4	main
oma	doc_264166611935_item	2305207	et	4	main
ajal	doc_264166611935_item	2305211	et	4	main
nad	doc_264166611935_item	2305230	et	3	main
andnud	doc_264166611935_item	2305232	et	4	main
võimaluse	doc_264166611935_item	2305233	et	3	main
talurahvas	doc_264166611935_item	2305237	et	4	main
jäi	doc_264166611935_item	2305238	et	3	main
mõisnikud	doc_264166611935_item	2305240	et	3	main
et	doc_264166611935_item	2305242	et	3	main
vormi	doc_264166611935_item	2305247	et	4	main
keiser	doc_264166611935_item	2305248	et	3	main
esimene	doc_264166611935_item	2305250	et	3	main
olnud	doc_264166611935_item	2305252	et	4	main
rahul	doc_264166611935_item	2305253	et	4	main
balti	doc_264166611935_item	2305254	et	3	main
2	doc_264166611935_item	2305261	et	2	main
õpetatud	doc_264166611935_item	2305262	et	4	main
selts	doc_264166611935_item	2305264	et	3	main
uurimisega	doc_264166611935_item	2305282	et	4	main
välja	doc_264166611935_item	2305288	et	4	main
muid	doc_264166611935_item	2305293	et	4	main
hurt	doc_264166611935_item	2305301	et	3	main
f	doc_264166611935_item	2305302	et	4	main
tööd	doc_264166611935_item	2305322	et	4	main
teatud	doc_264166611935_item	2305328	et	4	main
sai	doc_264166611935_item	2305331	et	4	main
välja	doc_264166611935_item	2305337	et	4	main
ja	doc_264166611935_item	2305340	et	3	main
kaaslasi	doc_264166611935_item	2305348	et	3	main
palvekirju	doc_264166611935_item	2305351	et	4	main
eest	doc_264166611935_item	2305353	et	4	main
toimus	doc_264166611935_item	2305356	et	3	main
i	doc_264166611935_item	2305358	et	4	main
õpetatud	doc_264166611935_item	2305360	et	4	main
seltsi	doc_264166611935_item	2305361	et	4	main
tooge	doc_268694804105_item	2305372	et	3	main
välja	doc_268694804105_item	2305373	et	4	main
majanduses	doc_268694804105_item	2305381	et	4	main
kultuuriajaloos	doc_268694804105_item	2305387	et	4	main
kõneldakse	doc_268694804105_item	2305388	et	3	main
nn	doc_268694804105_item	2305389	et	4	main
sulast	doc_268694804105_item	2305391	et	4	main
ja	doc_268694804105_item	2305394	et	3	main
peamised	doc_268694804105_item	2305396	et	3	main
seisnesid	doc_268694804105_item	2305399	et	4	main
selles	doc_268694804105_item	2305400	et	4	main
keegi	doc_268694804105_item	2305405	et	4	main
keegi	doc_268694804105_item	2305410	et	4	main
andnud	doc_268694804105_item	2305412	et	4	main
käsklusi	doc_268694804105_item	2305413	et	3	main
nt	doc_268694804105_item	2305417	et	4	main
tuleb	doc_268694804105_item	2305420	et	3	main
ei	doc_268694804105_item	2305422	et	4	main
keelanud	doc_268694804105_item	2305423	et	4	main
inimeste	doc_268694804105_item	2305424	et	3	main
oma	doc_268694804105_item	2305450	et	4	main
moodustati	doc_268694804105_item	2305453	et	3	main
liikmed	doc_268694804105_item	2305471	et	3	main
seaduse	doc_268694804105_item	2305481	et	3	main
koolis	doc_268694804105_item	2305486	et	4	main
saksa	doc_268694804105_item	2305493	et	4	main
algkoolid	doc_268694804105_item	2305497	et	3	main
ensv	doc_268694804105_item	2305499	et	4	main
eesti	doc_268694804105_item	2305501	et	4	main
sellepärast	doc_264166611935_item	2305236	et	3	main
eestikeelseks	doc_264166611935_item	2305239	et	4	main
suulise	doc_264166611935_item	2305246	et	4	main
erikorraga	doc_264166611935_item	2305255	et	3	main
ning	doc_264166611935_item	2305256	et	3	main
tegelaseks	doc_264166611935_item	2305271	et	3	main
oli	doc_264166611935_item	2305272	et	3	main
f	doc_264166611935_item	2305273	et	4	main
eesti	doc_264166611935_item	2305277	et	4	main
selts	doc_264166611935_item	2305278	et	3	main
see	doc_264166611935_item	2305286	et	3	main
liider	doc_264166611935_item	2305308	et	3	main
hakkas	doc_264166611935_item	2305310	et	3	main
koostama	doc_264166611935_item	2305311	et	3	main
eesti	doc_264166611935_item	2305312	et	4	main
rahvuseepose	doc_264166611935_item	2305313	et	3	main
kalevipoeg	doc_264166611935_item	2305314	et	3	main
kasutades	doc_264166611935_item	2305315	et	3	main
teiste	doc_264166611935_item	2305316	et	4	main
liikmete	doc_264166611935_item	2305317	et	3	main
poolt	doc_264166611935_item	2305318	et	4	main
kogutud	doc_264166611935_item	2305319	et	4	main
materjale	doc_264166611935_item	2305320	et	3	main
jätkas	doc_264166611935_item	2305323	et	3	main
hurt	doc_264166611935_item	2305326	et	3	main
andis	doc_264166611935_item	2305336	et	3	main
tema	doc_264166611935_item	2305354	et	4	main
üldlaulupidu	doc_264166611935_item	2305359	et	4	main
rolli	doc_264166611935_item	2305364	et	4	main
ja	doc_268694804105_item	2305377	et	3	main
ensv	doc_268694804105_item	2305395	et	4	main
moskvast	doc_268694804105_item	2305418	et	4	main
kuulevust	doc_268694804105_item	2305425	et	4	main
mingitesse	doc_268694804105_item	2305426	et	3	main
ajal	doc_268694804105_item	2305434	et	4	main
palju	doc_268694804105_item	2305435	et	4	main
inimesi	doc_268694804105_item	2305436	et	4	main
haritlasi	doc_268694804105_item	2305437	et	3	main
haridus	doc_268694804105_item	2305441	et	3	main
ev	doc_268694804105_item	2305446	et	4	main
iseseisvuse	doc_268694804105_item	2305451	et	4	main
esimene	doc_268694804105_item	2305458	et	3	main
eesti	doc_268694804105_item	2305464	et	4	main
võisid	doc_268694804105_item	2305468	et	4	main
20	doc_268694804105_item	2305473	et	2	main
keeles	doc_268694804105_item	2305495	et	4	main
erinevus	doc_268694804105_item	2305512	et	4	main
tohtinud	doc_268694804105_item	2305521	et	4	main
paljud	doc_268694804105_item	2305530	et	3	main
hävitatud	doc_268694804105_item	2305535	et	4	main
suunatud	doc_268694804105_item	2305540	et	4	main
rootsi	doc_268694804105_item	2305544	et	4	main
uued	doc_268694804105_item	2305546	et	3	main
ja	doc_268694804105_item	2305553	et	3	main
1922	doc_268694804105_item	2305556	et	2	main
eestis	doc_268694804105_item	2305559	et	3	main
märgatav	doc_268694804105_item	2305561	et	4	main
brutotoodangu	doc_268694804105_item	2305563	et	3	main
majanduse	doc_268694804105_item	2305568	et	4	main
evs	doc_268694804105_item	2305570	et	4	main
majanduskasv	doc_268694804105_item	2305576	et	3	main
oli	doc_268694804105_item	2305577	et	3	main
metallitööstusega	doc_268694804105_item	2305582	et	3	main
kreutzwald	doc_264166611935_item	2305324	et	4	main
keeleteadlane	doc_264166611935_item	2305329	et	3	main
ning	doc_264166611935_item	2305330	et	3	main
aleksandrikooli	doc_264166611935_item	2305332	et	4	main
liikumise	doc_264166611935_item	2305333	et	4	main
liideriks	doc_264166611935_item	2305334	et	4	main
jannsen	doc_264166611935_item	2305335	et	4	main
ajalehte	doc_264166611935_item	2305338	et	4	main
tuntud	doc_264166611935_item	2305342	et	4	main
postipapa	doc_264166611935_item	2305344	et	4	main
ta	doc_264166611935_item	2305345	et	4	main
päästis	doc_264166611935_item	2305346	et	3	main
köleri	doc_264166611935_item	2305347	et	4	main
algatusel	doc_264166611935_item	2305355	et	4	main
tartus	doc_264166611935_item	2305357	et	3	main
suurt	doc_264166611935_item	2305363	et	3	main
keele	doc_264166611935_item	2305366	et	4	main
uurimises	doc_264166611935_item	2305367	et	4	main
ja	doc_264166611935_item	2305368	et	3	main
arendamises	doc_264166611935_item	2305369	et	4	main
kontrolltöö	doc_268694804105_item	2305370	et	4	main
ensv	doc_268694804105_item	2305378	et	4	main
2	doc_268694804105_item	2305382	et	2	main
mõeldakse	doc_268694804105_item	2305384	et	3	main
kui	doc_268694804105_item	2305385	et	3	main
ensv	doc_268694804105_item	2305386	et	4	main
vabariigi	doc_268694804105_item	2305403	et	3	main
kontrollinud	doc_268694804105_item	2305407	et	4	main
andnud	doc_268694804105_item	2305415	et	4	main
elada	doc_268694804105_item	2305421	et	3	main
astumist	doc_268694804105_item	2305428	et	4	main
muidugi	doc_268694804105_item	2305430	et	4	main
seltside	doc_268694804105_item	2305431	et	3	main
tegutsemist	doc_268694804105_item	2305432	et	4	main
eesti	doc_268694804105_item	2305439	et	4	main
sai	doc_268694804105_item	2305449	et	4	main
siis	doc_268694804105_item	2305452	et	3	main
eestis	doc_268694804105_item	2305454	et	3	main
riigikogu	doc_268694804105_item	2305456	et	4	main
valitsuse	doc_268694804105_item	2305465	et	4	main
alates	doc_268694804105_item	2305472	et	3	main
autonoomia	doc_268694804105_item	2305480	et	4	main
pisirahvas	doc_268694804105_item	2305482	et	4	main
vene	doc_268694804105_item	2305492	et	4	main
õppeasutused	doc_268694804105_item	2305496	et	4	main
ei	doc_268694804105_item	2305520	et	4	main
kuuluda	doc_268694804105_item	2305522	et	4	main
paljudesse	doc_268694804105_item	2305523	et	3	main
seltsidesse	doc_268694804105_item	2305524	et	3	main
isegi	doc_268694804105_item	2305525	et	4	main
või	doc_268694804105_item	2305534	et	4	main
majanduselu	doc_268694804105_item	2305538	et	4	main
leidmisele	doc_268694804105_item	2305543	et	4	main
siidikoevabrik	doc_268694804105_item	2305554	et	3	main
kuni	doc_268694804105_item	2305557	et	3	main
sellega	doc_268694804105_item	2305565	et	3	main
paranemine	doc_268694804105_item	2305569	et	4	main
evs	doc_268694804105_item	2305571	et	4	main
toimus	doc_268694804105_item	2305572	et	3	main
suur	doc_268694804105_item	2305575	et	3	main
seotud	doc_268694804105_item	2305578	et	4	main
veel	doc_268694804105_item	2305579	et	4	main
võeti	doc_268694804105_item	2305622	et	3	main
ev	doc_268694804105_item	2305629	et	4	main
teatreid	doc_268694804105_item	2305634	et	3	main
ajalehti	doc_268694804105_item	2305636	et	4	main
hävitati	doc_268694804105_item	2305642	et	3	main
püüti	doc_268694804105_item	2305646	et	3	main
suruda	doc_268694804105_item	2305648	et	3	main
ja	doc_268694804105_item	2305662	et	3	main
tundub	doc_268694804105_item	2305668	et	3	main
ev	doc_268694804105_item	2305670	et	4	main
oli	doc_268694804105_item	2305672	et	3	main
nii	doc_268694804105_item	2305675	et	3	main
tööstuses	doc_268694804105_item	2305676	et	3	main
kui	doc_268694804105_item	2305677	et	3	main
põllumajanduses	doc_268694804105_item	2305679	et	3	main
perioodiga	doc_268694804105_item	2305682	et	3	main
mõeldakse	doc_268694804105_item	2305691	et	3	main
muutuma	doc_268694804105_item	2305695	et	4	main
stalini-aegne	doc_268694804105_item	2305698	et	3	main
eksistentsiaalne	doc_268694804105_item	2305699	et	4	main
hirm	doc_268694804105_item	2305700	et	3	main
kultuuriga	doc_268694804105_item	2305706	et	4	main
ega	doc_268694804105_item	2305429	et	3	main
ensv	doc_268694804105_item	2305433	et	4	main
muutus	doc_268694804105_item	2305442	et	4	main
keelseks	doc_268694804105_item	2305444	et	4	main
riigivanem	doc_268694804105_item	2305459	et	4	main
oli	doc_268694804105_item	2305460	et	3	main
ühiskonnakorraldus	doc_268694804105_item	2305462	et	3	main
käes	doc_268694804105_item	2305466	et	4	main
valida	doc_268694804105_item	2305469	et	3	main
riigikogu	doc_268694804105_item	2305470	et	4	main
aastast	doc_268694804105_item	2305474	et	4	main
isegi	doc_268694804105_item	2305475	et	4	main
1925a	doc_268694804105_item	2305476	et	4	main
vähemusrahvaste	doc_268694804105_item	2305479	et	4	main
sai	doc_268694804105_item	2305483	et	4	main
valida	doc_268694804105_item	2305484	et	3	main
milles	doc_268694804105_item	2305485	et	3	main
gümnaasiumid	doc_268694804105_item	2305498	et	3	main
ajal	doc_268694804105_item	2305500	et	4	main
koosseisu	doc_268694804105_item	2305504	et	4	main
pidi	doc_268694804105_item	2305506	et	4	main
moskvale	doc_268694804105_item	2305509	et	4	main
kpäts	doc_268694804105_item	2305461	et	4	main
oli	doc_268694804105_item	2305463	et	3	main
kodanikud	doc_268694804105_item	2305467	et	3	main
võeti	doc_268694804105_item	2305477	et	3	main
vastu	doc_268694804105_item	2305478	et	3	main
käia	doc_268694804105_item	2305487	et	4	main
tähendab	doc_268694804105_item	2305488	et	3	main
sel	doc_268694804105_item	2305489	et	3	main
ajal	doc_268694804105_item	2305490	et	4	main
olid	doc_268694804105_item	2305491	et	4	main
rootsi	doc_268694804105_item	2305494	et	4	main
nsv	doc_268694804105_item	2305503	et	4	main
peamine	doc_268694804105_item	2305511	et	3	main
et	doc_268694804105_item	2305513	et	3	main
ei	doc_268694804105_item	2305515	et	4	main
iseseisev	doc_268694804105_item	2305517	et	3	main
ühiskonnakorralduses	doc_268694804105_item	2305518	et	3	main
inimesed	doc_268694804105_item	2305519	et	3	main
nimetused	doc_268694804105_item	2305527	et	4	main
olid	doc_268694804105_item	2305528	et	4	main
muudetud	doc_268694804105_item	2305529	et	4	main
ev	doc_268694804105_item	2305536	et	4	main
oli	doc_268694804105_item	2305539	et	3	main
välisturgude	doc_268694804105_item	2305542	et	3	main
soome	doc_268694804105_item	2305545	et	3	main
1924	doc_268694804105_item	2305558	et	2	main
oli	doc_268694804105_item	2305560	et	3	main
ka	doc_268694804105_item	2305567	et	3	main
rahareform	doc_268694804105_item	2305573	et	3	main
1928a	doc_268694804105_item	2305574	et	4	main
ja	doc_268694804105_item	2305581	et	3	main
oli	doc_268694804105_item	2305632	et	3	main
keelati	doc_268694804105_item	2305640	et	4	main
või	doc_268694804105_item	2305641	et	4	main
alla	doc_268694804105_item	2305647	et	3	main
all	doc_268694804105_item	2305666	et	3	main
ensv	doc_268694804105_item	2305685	et	4	main
kultuuriajaloos	doc_268694804105_item	2305686	et	4	main
sulast	doc_268694804105_item	2305690	et	4	main
elu	doc_268694804105_item	2305693	et	4	main
paremaks	doc_268694804105_item	2305696	et	4	main
kadus	doc_268694804105_item	2305697	et	3	main
elavnes	doc_268694804105_item	2305707	et	3	main
elu	doc_268694804105_item	2305709	et	4	main
60ndatel	doc_268694804105_item	2305726	et	4	main
taastati	doc_268694804105_item	2305728	et	4	main
loomismeetod	doc_27046690325_item	2305901	et	3	main
avaldub	doc_27046690325_item	2305904	et	3	main
valgus	doc_27046690325_item	2305906	et	4	main
1	doc_27046690325_item	2305908	et	2	main
kuulus	doc_268694804105_item	2305502	et	4	main
ja	doc_268694804105_item	2305505	et	3	main
alluma	doc_268694804105_item	2305507	et	3	main
ühiskonnakorralduses	doc_268694804105_item	2305508	et	3	main
tähendab	doc_268694804105_item	2305510	et	3	main
eesti	doc_268694804105_item	2305514	et	4	main
olnud	doc_268694804105_item	2305516	et	4	main
ajakirjade	doc_268694804105_item	2305526	et	3	main
kas	doc_268694804105_item	2305532	et	3	main
peamine	doc_268694804105_item	2305537	et	3	main
uute	doc_268694804105_item	2305541	et	3	main
tööstusharud	doc_268694804105_item	2305550	et	3	main
suka-	doc_268694804105_item	2305552	et	3	main
alates	doc_268694804105_item	2305555	et	3	main
kahekordistamine	doc_268694804105_item	2305564	et	3	main
kaasnes	doc_268694804105_item	2305566	et	3	main
põlevkivitööstuse	doc_268694804105_item	2305580	et	3	main
ev	doc_268694804105_item	2305583	et	4	main
küüditamine	doc_268694804105_item	2305627	et	4	main
ajal	doc_268694804105_item	2305630	et	4	main
palju	doc_268694804105_item	2305633	et	4	main
seltse	doc_268694804105_item	2305635	et	3	main
ajal	doc_268694804105_item	2305645	et	4	main
kuid	doc_268694804105_item	2305650	et	4	main
peamine	doc_268694804105_item	2305652	et	3	main
erinevus	doc_268694804105_item	2305653	et	4	main
selles	doc_268694804105_item	2305658	et	4	main
ensvs	doc_268694804105_item	2305659	et	4	main
pidid	doc_268694804105_item	2305660	et	4	main
inimesed	doc_268694804105_item	2305661	et	3	main
et	doc_268694804105_item	2305669	et	3	main
ka	doc_268694804105_item	2305678	et	3	main
ensv	doc_268694804105_item	2305681	et	4	main
kui	doc_268694804105_item	2305684	et	3	main
nn	doc_268694804105_item	2305688	et	4	main
et	doc_268694804105_item	2305692	et	3	main
hakkas	doc_268694804105_item	2305694	et	3	main
taastus	doc_268694804105_item	2305702	et	4	main
eesti	doc_268694804105_item	2305705	et	4	main
võib	doc_268694804105_item	2305721	et	3	main
aastal	doc_268694804105_item	2305727	et	3	main
enam	doc_268694804105_item	2305732	et	4	main
olnud	doc_268694804105_item	2305734	et	4	main
nii	doc_268694804105_item	2305735	et	3	main
varem	doc_268694804105_item	2305739	et	4	main
kui	doc_27046690325_item	2305900	et	3	main
venemaal	doc_27046690325_item	2305913	et	4	main
sotsiaalsed	doc_27046690325_item	2305914	et	3	main
rahvuslikud	doc_27046690325_item	2305917	et	3	main
19	doc_27046690325_item	2305920	et	2	main
eestis	doc_27046690325_item	2305924	et	3	main
baltikumis	doc_27046690325_item	2305938	et	4	main
tekkima	doc_27046690325_item	2305940	et	3	main
oli	doc_27046690325_item	2305944	et	3	main
raamatud	doc_268694804105_item	2305531	et	4	main
keelatud	doc_268694804105_item	2305533	et	4	main
vene	doc_268694804105_item	2305547	et	4	main
vana	doc_268694804105_item	2305548	et	4	main
turgpeamised	doc_268694804105_item	2305549	et	4	main
laevaehitus	doc_268694804105_item	2305551	et	4	main
suurtööstuse	doc_268694804105_item	2305562	et	3	main
perioodil	doc_268694804105_item	2305584	et	3	main
rajati	doc_268694804105_item	2305585	et	3	main
uusi	doc_268694804105_item	2305587	et	3	main
ettevõtteid	doc_268694804105_item	2305588	et	3	main
ensv	doc_268694804105_item	2305589	et	4	main
palju	doc_268694804105_item	2305586	et	4	main
oli	doc_268694804105_item	2305590	et	3	main
eesti	doc_268694804105_item	2305591	et	4	main
tihedam	doc_268694804105_item	2305592	et	4	main
integreerumine	doc_268694804105_item	2305593	et	4	main
nsv	doc_268694804105_item	2305594	et	4	main
liidu	doc_268694804105_item	2305595	et	3	main
majandussüsteemi	doc_268694804105_item	2305596	et	4	main
hakati	doc_268694804105_item	2305597	et	3	main
rajama	doc_268694804105_item	2305598	et	3	main
uusi	doc_268694804105_item	2305599	et	3	main
kaevandusi	doc_268694804105_item	2305600	et	4	main
ja	doc_268694804105_item	2305601	et	3	main
töölisasulaid	doc_268694804105_item	2305602	et	4	main
industriaalsed	doc_268694804105_item	2305603	et	3	main
harud	doc_268694804105_item	2305604	et	3	main
nagu	doc_268694804105_item	2305605	et	3	main
tööstus	doc_268694804105_item	2305606	et	3	main
transport	doc_268694804105_item	2305607	et	3	main
ehitus	doc_268694804105_item	2305608	et	4	main
jne	doc_268694804105_item	2305609	et	4	main
rahvamajanduses	doc_268694804105_item	2305611	et	3	main
juhtiva	doc_268694804105_item	2305612	et	4	main
said	doc_268694804105_item	2305610	et	4	main
koha	doc_268694804105_item	2305613	et	4	main
põllumajanduses	doc_268694804105_item	2305614	et	3	main
toimus	doc_268694804105_item	2305615	et	3	main
suur	doc_268694804105_item	2305616	et	3	main
muutus	doc_268694804105_item	2305617	et	4	main
1947	doc_268694804105_item	2305618	et	2	main
hakati	doc_268694804105_item	2305619	et	3	main
looma	doc_268694804105_item	2305620	et	4	main
kolhoose	doc_268694804105_item	2305621	et	3	main
maa	doc_268694804105_item	2305624	et	4	main
siberisse	doc_268694804105_item	2305628	et	4	main
ajal	doc_268694804105_item	2305639	et	4	main
ensv	doc_268694804105_item	2305644	et	4	main
kultuurielu	doc_268694804105_item	2305649	et	4	main
muidugi	doc_268694804105_item	2305651	et	4	main
vabaduses	doc_268694804105_item	2305654	et	4	main
suurem	doc_268694804105_item	2305655	et	4	main
erinevus	doc_268694804105_item	2305656	et	4	main
on	doc_268694804105_item	2305657	et	4	main
riigikorraldus	doc_268694804105_item	2305663	et	3	main
mulle	doc_268694804105_item	2305667	et	4	main
ajal	doc_268694804105_item	2305671	et	4	main
suur	doc_268694804105_item	2305673	et	3	main
majanduskasv	doc_268694804105_item	2305674	et	3	main
2	doc_268694804105_item	2305683	et	2	main
side	doc_268694804105_item	2305703	et	4	main
varasema	doc_268694804105_item	2305704	et	4	main
ühiskondliku	doc_268694804105_item	2305708	et	3	main
avatus	doc_268694804105_item	2305710	et	4	main
kirjade	doc_268694804105_item	2305711	et	3	main
vahetus	doc_268694804105_item	2305712	et	4	main
laulupeol	doc_268694804105_item	2305713	et	4	main
lauldi	doc_268694804105_item	2305714	et	3	main
hümni	doc_268694804105_item	2305715	et	4	main
mu	doc_268694804105_item	2305716	et	3	main
arm	doc_268694804105_item	2305718	et	3	main
isamaa	doc_268694804105_item	2305717	et	4	main
seda	doc_268694804105_item	2305719	et	3	main
aega	doc_268694804105_item	2305720	et	4	main
kultuuri	doc_268694804105_item	2305723	et	4	main
taaselustumiseks	doc_268694804105_item	2305724	et	4	main
kontakt	doc_268694804105_item	2305729	et	3	main
palju	doc_268694804105_item	2305736	et	4	main
nagu	doc_268694804105_item	2305738	et	3	main
kuidas	doc_27046690325_item	2305902	et	3	main
filmis	doc_27046690325_item	2305905	et	4	main
koordis	doc_27046690325_item	2305907	et	4	main
20	doc_27046690325_item	2305909	et	2	main
haaras	doc_27046690325_item	2305931	et	4	main
üldstreigid	doc_27046690325_item	2305941	et	3	main
haripunkt	doc_27046690325_item	2305943	et	3	main
kui	doc_27046690325_item	2305948	et	3	main
suurendas	doc_27046690325_item	2305952	et	3	main
ära	doc_268694804105_item	2305623	et	4	main
talud	doc_268694804105_item	2305625	et	4	main
1941a	doc_268694804105_item	2305626	et	4	main
ühiskonnakorralduses	doc_268694804105_item	2305631	et	3	main
mida	doc_268694804105_item	2305637	et	4	main
ensv	doc_268694804105_item	2305638	et	4	main
eestis	doc_268694804105_item	2305643	et	3	main
moskva	doc_268694804105_item	2305664	et	4	main
kontrolli	doc_268694804105_item	2305665	et	4	main
võrreldes	doc_268694804105_item	2305680	et	3	main
kõneldakse	doc_268694804105_item	2305687	et	3	main
hrustsovi	doc_268694804105_item	2305689	et	4	main
kultuurielus	doc_268694804105_item	2305701	et	4	main
vaimueluga	doc_268694804105_item	2305731	et	3	main
keelatud	doc_268694804105_item	2305737	et	4	main
realism	doc_27046690325_item	2305899	et	3	main
see	doc_27046690325_item	2305903	et	3	main
sajandi	doc_27046690325_item	2305910	et	3	main
sotsiaaldemokraatlikud	doc_27046690325_item	2305925	et	3	main
pärast	doc_27046690325_item	2305927	et	4	main
hakkasid	doc_27046690325_item	2305939	et	4	main
rahutuste	doc_27046690325_item	2305942	et	4	main
1905	doc_27046690325_item	2305945	et	2	main
oktoobris	doc_27046690325_item	2305947	et	3	main
mässumeelsuse	doc_27046690325_item	2305950	et	4	main
kus	doc_27046690325_item	2305962	et	3	main
1905	doc_27046690325_item	2305966	et	2	main
tase	doc_27046690325_item	2305975	et	3	main
madalaks	doc_27046690325_item	2305978	et	3	main
ukaas	doc_27046690325_item	2305981	et	3	main
2	doc_27046690325_item	2305992	et	2	main
põllumajanduslikkel	doc_27046690325_item	2306000	et	4	main
pidada	doc_268694804105_item	2305722	et	4	main
isegi	doc_268694804105_item	2305725	et	4	main
euroopa	doc_268694804105_item	2305730	et	4	main
ei	doc_268694804105_item	2305733	et	4	main
kontrolltöö	doc_27046690325_item	2305873	et	4	main
1	doc_27046690325_item	2305874	et	2	main
hinda	doc_27046690325_item	2305875	et	4	main
1905	doc_27046690325_item	2305876	et	2	main
aasta	doc_27046690325_item	2305877	et	4	main
sündmuste	doc_27046690325_item	2305878	et	3	main
tähtsust	doc_27046690325_item	2305879	et	4	main
eesti	doc_27046690325_item	2305880	et	4	main
ajaloos	doc_27046690325_item	2305881	et	4	main
2	doc_27046690325_item	2305882	et	2	main
iseloomusta	doc_27046690325_item	2305883	et	4	main
rahvusteaduste	doc_27046690325_item	2305884	et	3	main
arengut	doc_27046690325_item	2305885	et	3	main
ew-s	doc_27046690325_item	2305886	et	3	main
tuntumaid	doc_27046690325_item	2305888	et	4	main
teadlasi	doc_27046690325_item	2305889	et	3	main
ja	doc_27046690325_item	2305890	et	3	main
nende	doc_27046690325_item	2305891	et	4	main
uurimissuundi	doc_27046690325_item	2305892	et	4	main
või	doc_27046690325_item	2305893	et	4	main
nimeta	doc_27046690325_item	2305887	et	4	main
töid	doc_27046690325_item	2305894	et	3	main
3	doc_27046690325_item	2305895	et	2	main
missugune	doc_27046690325_item	2305896	et	3	main
on	doc_27046690325_item	2305897	et	4	main
sotsialistlikku	doc_27046690325_item	2305898	et	4	main
alguseks	doc_27046690325_item	2305911	et	4	main
poliitilised	doc_27046690325_item	2305915	et	3	main
juba	doc_27046690325_item	2305919	et	3	main
saj	doc_27046690325_item	2305921	et	4	main
levisid	doc_27046690325_item	2305923	et	4	main
ideed	doc_27046690325_item	2305926	et	4	main
rahumeelsete	doc_27046690325_item	2305928	et	3	main
demonstrantide	doc_27046690325_item	2305929	et	3	main
tulistamist	doc_27046690325_item	2305930	et	4	main
rahulolematuselaine	doc_27046690325_item	2305934	et	4	main
aastal	doc_27046690325_item	2305946	et	3	main
koos	doc_27046690325_item	2305949	et	4	main
vabadusi	doc_27046690325_item	2305965	et	4	main
aastal	doc_27046690325_item	2305967	et	3	main
suurenes	doc_27046690325_item	2305969	et	4	main
väga	doc_27046690325_item	2305970	et	3	main
kiiresti	doc_27046690325_item	2305971	et	3	main
kuid	doc_27046690325_item	2305972	et	4	main
väga	doc_27046690325_item	2305977	et	3	main
tsaari	doc_27046690325_item	2305980	et	4	main
usuvabaduse	doc_27046690325_item	2305982	et	4	main
mõisate	doc_27046690325_item	2305990	et	3	main
saada	doc_27046690325_item	2305995	et	4	main
kui	doc_27046690325_item	2306001	et	3	main
teaduspublikatsioonide	doc_27046690325_item	2306022	et	3	main
1920	doc_27046690325_item	2306024	et	2	main
ooper	doc_27046690325_item	2306036	et	3	main
balett	doc_27046690325_item	2306039	et	4	main
konservatooriumi	doc_27046690325_item	2306041	et	4	main
lavakunstikool	doc_27046690325_item	2306044	et	4	main
eesti	doc_27046690325_item	2306045	et	4	main
gsuits	doc_27046690325_item	2306049	et	4	main
tamperwe	doc_27046690325_item	2306053	et	4	main
loorits	doc_27046690325_item	2306054	et	4	main
3	doc_27046690325_item	2306067	et	2	main
võim	doc_27046690325_item	2306069	et	3	main
stalinismi	doc_27046690325_item	2306082	et	4	main
hävitada	doc_27046690325_item	2306088	et	3	main
palju	doc_27046690325_item	2306100	et	4	main
teised	doc_27046690325_item	2306109	et	4	main
astusid	doc_27046690325_item	2306110	et	4	main
hirmuga	doc_27046690325_item	2306111	et	3	main
kolhoosidesse	doc_27046690325_item	2306112	et	3	main
sotsialistlik	doc_27046690325_item	2306119	et	3	main
teravnesid	doc_27046690325_item	2305912	et	4	main
ning	doc_27046690325_item	2305916	et	3	main
vastuolud	doc_27046690325_item	2305918	et	3	main
lõpul	doc_27046690325_item	2305922	et	3	main
kogu	doc_27046690325_item	2305932	et	4	main
maad	doc_27046690325_item	2305933	et	4	main
mis	doc_27046690325_item	2305935	et	4	main
väljendas	doc_27046690325_item	2305936	et	3	main
eriti	doc_27046690325_item	2305937	et	3	main
levikuga	doc_27046690325_item	2305951	et	3	main
suunatud	doc_27046690325_item	2305957	et	4	main
abinõusid	doc_27046690325_item	2305958	et	3	main
avaldati	doc_27046690325_item	2305959	et	3	main
ka	doc_27046690325_item	2305960	et	3	main
tsarimanifest	doc_27046690325_item	2305961	et	4	main
demokraatlikud	doc_27046690325_item	2305988	et	3	main
oli	doc_27046690325_item	2305994	et	3	main
kõrgemat	doc_27046690325_item	2305996	et	4	main
haridust	doc_27046690325_item	2305997	et	4	main
nii	doc_27046690325_item	2305998	et	3	main
tehnilistel	doc_27046690325_item	2305999	et	3	main
ka	doc_27046690325_item	2306002	et	3	main
humanitaaraladel	doc_27046690325_item	2306003	et	3	main
1922	doc_27046690325_item	2306004	et	2	main
eesti	doc_27046690325_item	2306005	et	4	main
kirjanikkude	doc_27046690325_item	2306006	et	3	main
liit	doc_27046690325_item	2306007	et	3	main
eesti	doc_27046690325_item	2306009	et	4	main
1924	doc_27046690325_item	2306008	et	2	main
akadeemiline	doc_27046690325_item	2306010	et	3	main
helikunsti	doc_27046690325_item	2306011	et	4	main
selts	doc_27046690325_item	2306012	et	3	main
eesti	doc_27046690325_item	2306013	et	4	main
teadustegevuse	doc_27046690325_item	2306014	et	4	main
tegelik	doc_27046690325_item	2306015	et	3	main
ajalugu	doc_27046690325_item	2306016	et	4	main
algas	doc_27046690325_item	2306017	et	3	main
1930	doc_27046690325_item	2306018	et	2	main
algas	doc_27046690325_item	2306019	et	3	main
ka	doc_27046690325_item	2306020	et	3	main
keel	doc_27046690325_item	2306028	et	4	main
mägiste	doc_27046690325_item	2306030	et	4	main
operett	doc_27046690325_item	2306037	et	3	main
1938	doc_27046690325_item	2306040	et	2	main
riiklik	doc_27046690325_item	2306043	et	3	main
august	doc_27046690325_item	2306047	et	4	main
ekp	doc_27046690325_item	2306070	et	4	main
käes	doc_27046690325_item	2306071	et	4	main
sageneb	doc_27046690325_item	2306072	et	3	main
vanu	doc_27046690325_item	2306076	et	4	main
ühismälu	doc_27046690325_item	2306086	et	4	main
rahvuslik	doc_27046690325_item	2306092	et	3	main
filmis	doc_27046690325_item	2306094	et	4	main
1949	doc_27046690325_item	2306097	et	2	main
räägib	doc_27046690325_item	2306098	et	3	main
olid	doc_27046690325_item	2306106	et	4	main
kui	doc_27046690325_item	2306121	et	3	main
realism	doc_27046690325_item	2306125	et	3	main
linnaproletariaadi	doc_27046690325_item	2306127	et	3	main
kirjutamine	doc_278690626899_item	2306141	et	4	main
kirjutage	doc_278690626899_item	2306142	et	3	main
on	doc_278690626899_item	2306182	et	4	main
harrastav	doc_278690626899_item	2306184	et	4	main
oma	doc_278690626899_item	2306190	et	4	main
aspekte	doc_278690626899_item	2306198	et	3	main
ajalugu	doc_278690626899_item	2306205	et	4	main
ka	doc_27046690325_item	2305953	et	3	main
selle	doc_27046690325_item	2305955	et	4	main
lubati	doc_27046690325_item	2305963	et	3	main
demokratlikke	doc_27046690325_item	2305964	et	4	main
töölisklass	doc_27046690325_item	2305968	et	3	main
jäi	doc_27046690325_item	2305976	et	3	main
1905	doc_27046690325_item	2305979	et	2	main
valimised	doc_27046690325_item	2305989	et	4	main
võimalik	doc_27046690325_item	2305993	et	3	main
eesti	doc_27046690325_item	2306021	et	4	main
ajalugu	doc_27046690325_item	2306023	et	4	main
rahvusteaduste	doc_27046690325_item	2306025	et	3	main
juurde	doc_27046690325_item	2306042	et	4	main
eesti	doc_27046690325_item	2306050	et	4	main
anderson	doc_27046690325_item	2306052	et	4	main
osa	doc_27046690325_item	2306066	et	4	main
ässitatakse	doc_27046690325_item	2306078	et	3	main
inimesi	doc_27046690325_item	2306079	et	4	main
kustutada	doc_27046690325_item	2306084	et	3	main
sundida	doc_27046690325_item	2306090	et	4	main
vaikima	doc_27046690325_item	2306091	et	4	main
küüditatud	doc_27046690325_item	2306107	et	4	main
siberisse	doc_27046690325_item	2306108	et	4	main
kohtadel	doc_27046690325_item	2306114	et	3	main
laulupidude	doc_27046690325_item	2306116	et	4	main
kunstiloome	doc_27046690325_item	2306122	et	4	main
sotsialistlik	doc_27046690325_item	2306124	et	3	main
klassivõitlus	doc_27046690325_item	2306126	et	3	main
juhtiw	doc_27046690325_item	2306128	et	4	main
roll	doc_27046690325_item	2306129	et	3	main
vene	doc_27046690325_item	2306130	et	4	main
progressiivne	doc_27046690325_item	2306132	et	3	main
keele	doc_278690626899_item	2306139	et	4	main
300	doc_278690626899_item	2306151	et	2	main
analüüsiv	doc_278690626899_item	2306158	et	4	main
näidetega	doc_278690626899_item	2306171	et	3	main
kultuur	doc_278690626899_item	2306181	et	3	main
ka	doc_278690626899_item	2306185	et	3	main
minevik	doc_278690626899_item	2306191	et	3	main
seletada	doc_278690626899_item	2306194	et	3	main
palju	doc_278690626899_item	2306196	et	4	main
loomulikult	doc_278690626899_item	2306199	et	4	main
eesti	doc_278690626899_item	2306200	et	4	main
rahvalauludeski	doc_278690626899_item	2306201	et	3	main
kajastub	doc_278690626899_item	2306202	et	3	main
rahva	doc_278690626899_item	2306204	et	3	main
nendest	doc_278690626899_item	2306208	et	4	main
kes	doc_278690626899_item	2306210	et	4	main
nad	doc_278690626899_item	2306211	et	3	main
tsarivalitsus	doc_27046690325_item	2305954	et	4	main
vastu	doc_27046690325_item	2305956	et	3	main
inimeste	doc_27046690325_item	2305973	et	3	main
kindlustatuse	doc_27046690325_item	2305974	et	4	main
kohta	doc_27046690325_item	2305983	et	4	main
võitlus	doc_27046690325_item	2305984	et	3	main
usuõpetuse	doc_27046690325_item	2305985	et	3	main
vastu	doc_27046690325_item	2305986	et	3	main
koolides	doc_27046690325_item	2305987	et	3	main
põletamine	doc_27046690325_item	2305991	et	4	main
viljelemine	doc_27046690325_item	2306026	et	4	main
saareste	doc_27046690325_item	2306029	et	4	main
keeleuuendaja	doc_27046690325_item	2306031	et	4	main
annist	doc_27046690325_item	2306048	et	3	main
rahvaluule	doc_27046690325_item	2306051	et	4	main
1940	doc_27046690325_item	2306068	et	2	main
üksteise	doc_27046690325_item	2306080	et	4	main
vastu	doc_27046690325_item	2306081	et	3	main
eesmärk	doc_27046690325_item	2306083	et	3	main
rahva	doc_27046690325_item	2306085	et	3	main
kultuurimälu	doc_27046690325_item	2306087	et	4	main
või	doc_27046690325_item	2306089	et	4	main
intelligents	doc_27046690325_item	2306093	et	3	main
valgus	doc_27046690325_item	2306095	et	4	main
ajal	doc_27046690325_item	2306103	et	4	main
millal	doc_27046690325_item	2306104	et	3	main
iseseisvapõllumehed	doc_27046690325_item	2306105	et	4	main
traditsioonide	doc_27046690325_item	2306117	et	3	main
realism	doc_27046690325_item	2306120	et	3	main
rahva	doc_27046690325_item	2306131	et	3	main
test	doc_278690626899_item	2306140	et	3	main
laulurahva	doc_278690626899_item	2306148	et	3	main
pikkus	doc_278690626899_item	2306150	et	4	main
sõna	doc_278690626899_item	2306153	et	4	main
ja	doc_278690626899_item	2306159	et	3	main
iga	doc_278690626899_item	2306179	et	4	main
et	doc_278690626899_item	2306187	et	3	main
on	doc_278690626899_item	2306189	et	4	main
võib	doc_278690626899_item	2306193	et	3	main
selle	doc_278690626899_item	2306203	et	4	main
on	doc_278690626899_item	2306212	et	4	main
eesti	doc_27046690325_item	2306027	et	4	main
johannes	doc_27046690325_item	2306032	et	4	main
aavik	doc_27046690325_item	2306033	et	4	main
sõnalavastusele	doc_27046690325_item	2306034	et	3	main
lisaks	doc_27046690325_item	2306035	et	4	main
ja	doc_27046690325_item	2306038	et	3	main
kirjanduslugu	doc_27046690325_item	2306046	et	4	main
muinasteadused	doc_27046690325_item	2306055	et	3	main
kunstiajalugu	doc_27046690325_item	2306056	et	4	main
eesti	doc_27046690325_item	2306057	et	4	main
ajalugu	doc_27046690325_item	2306058	et	4	main
1926	doc_27046690325_item	2306059	et	2	main
ilmub	doc_27046690325_item	2306060	et	3	main
tammsaare	doc_27046690325_item	2306061	et	3	main
tõde	doc_27046690325_item	2306062	et	4	main
ja	doc_27046690325_item	2306063	et	3	main
õigus	doc_27046690325_item	2306064	et	4	main
i	doc_27046690325_item	2306065	et	4	main
pealekaebamine	doc_27046690325_item	2306073	et	3	main
õiendatakse	doc_27046690325_item	2306074	et	3	main
avalikult	doc_27046690325_item	2306075	et	4	main
arveid	doc_27046690325_item	2306077	et	3	main
koordis	doc_27046690325_item	2306096	et	4	main
meile	doc_27046690325_item	2306099	et	4	main
majandusest	doc_27046690325_item	2306101	et	4	main
tol	doc_27046690325_item	2306102	et	3	main
juhtivatel	doc_27046690325_item	2306113	et	4	main
kultuur	doc_27046690325_item	2306115	et	3	main
taastamine	doc_27046690325_item	2306118	et	4	main
meetod	doc_27046690325_item	2306123	et	3	main
essee	doc_278690626899_item	2306134	et	4	main
keele	doc_278690626899_item	2306136	et	4	main
kui	doc_278690626899_item	2306137	et	3	main
teise	doc_278690626899_item	2306138	et	4	main
mis	doc_278690626899_item	2306145	et	4	main
teeb	doc_278690626899_item	2306146	et	3	main
eestlastest	doc_278690626899_item	2306147	et	4	main
essee	doc_278690626899_item	2306154	et	4	main
esineb	doc_278690626899_item	2306173	et	3	main
palju	doc_278690626899_item	2306175	et	4	main
erinevaid	doc_278690626899_item	2306176	et	4	main
rahvusi	doc_278690626899_item	2306177	et	3	main
omamoodi	doc_278690626899_item	2306183	et	3	main
sellepärast	doc_278690626899_item	2306186	et	3	main
mis	doc_278690626899_item	2306192	et	4	main
teeb	doc_278690626899_item	2306207	et	3	main
laulurahva	doc_278690626899_item	2306213	et	3	main
roll	doc_27046690325_item	2306133	et	3	main
eesti	doc_278690626899_item	2306135	et	4	main
essee	doc_278690626899_item	2306143	et	4	main
teemal	doc_278690626899_item	2306144	et	3	main
essee	doc_278690626899_item	2306149	et	4	main
350	doc_278690626899_item	2306152	et	2	main
peab	doc_278690626899_item	2306155	et	4	main
olema	doc_278690626899_item	2306156	et	4	main
arutlev	doc_278690626899_item	2306157	et	4	main
üldistav	doc_278690626899_item	2306160	et	4	main
tuginema	doc_278690626899_item	2306161	et	3	main
loengus	doc_278690626899_item	2306162	et	3	main
ja	doc_278690626899_item	2306163	et	3	main
lugemistekstis	doc_278690626899_item	2306164	et	3	main
esitatud	doc_278690626899_item	2306165	et	4	main
faktidele	doc_278690626899_item	2306166	et	3	main
väiteid	doc_278690626899_item	2306167	et	4	main
on	doc_278690626899_item	2306168	et	4	main
illustreerida	doc_278690626899_item	2306170	et	3	main
soovitatav	doc_278690626899_item	2306169	et	4	main
maailmas	doc_278690626899_item	2306172	et	3	main
piisavalt	doc_278690626899_item	2306174	et	4	main
ja	doc_278690626899_item	2306178	et	3	main
konkreetne	doc_278690626899_item	2306180	et	3	main
tal	doc_278690626899_item	2306188	et	3	main
meile	doc_278690626899_item	2306195	et	4	main
arusaamatuid	doc_278690626899_item	2306197	et	4	main
mis	doc_278690626899_item	2306206	et	4	main
neid	doc_278690626899_item	2306209	et	4	main
kui	doc_278690626904_item	2306797	et	3	main
keele	doc_278690626904_item	2306799	et	4	main
test	doc_278690626904_item	2306800	et	3	main
kirjutamine	doc_278690626904_item	2306801	et	4	main
laulurahva	doc_278690626904_item	2306808	et	3	main
pikkus	doc_278690626904_item	2306810	et	4	main
üldistav	doc_278690626904_item	2306820	et	4	main
loengus	doc_278690626904_item	2306822	et	3	main
laulmine	doc_278690626904_item	2306840	et	4	main
tegevus	doc_278690626904_item	2306849	et	4	main
oluline	doc_278690626904_item	2306854	et	4	main
eesti	doc_278690626904_item	2306856	et	4	main
töötades	doc_278690626904_item	2306862	et	3	main
tihti	doc_278690626904_item	2306879	et	3	main
mehed	doc_278690626904_item	2306881	et	3	main
keele	doc_278690626904_item	2306796	et	4	main
teise	doc_278690626904_item	2306798	et	4	main
teemal	doc_278690626904_item	2306804	et	3	main
300	doc_278690626904_item	2306811	et	2	main
peab	doc_278690626904_item	2306815	et	4	main
olema	doc_278690626904_item	2306816	et	4	main
analüüsiv	doc_278690626904_item	2306818	et	4	main
lugemistekstis	doc_278690626904_item	2306824	et	3	main
väiteid	doc_278690626904_item	2306827	et	4	main
ja	doc_278690626904_item	2306835	et	3	main
on	doc_278690626904_item	2306837	et	4	main
on	doc_278690626904_item	2306842	et	4	main
laulmine	doc_278690626904_item	2306850	et	4	main
on	doc_278690626904_item	2306852	et	4	main
last	doc_278690626904_item	2306863	et	4	main
laulnud	doc_278690626904_item	2306867	et	4	main
lastega	doc_278690626904_item	2306869	et	3	main
muidugi	doc_278690626904_item	2306871	et	4	main
on	doc_278690626904_item	2306873	et	4	main
sest	doc_278690626904_item	2306880	et	4	main
peavad	doc_278690626904_item	2306882	et	4	main
peavad	doc_278690626904_item	2306887	et	4	main
rahast	doc_278690626904_item	2306889	et	4	main
väga	doc_278690626904_item	2306894	et	3	main
mis	doc_278690626904_item	2306805	et	4	main
teeb	doc_278690626904_item	2306806	et	3	main
350	doc_278690626904_item	2306812	et	2	main
tuginema	doc_278690626904_item	2306821	et	3	main
näidetega	doc_278690626904_item	2306831	et	3	main
olulised	doc_278690626904_item	2306839	et	4	main
emotsionaalne	doc_278690626904_item	2306843	et	3	main
ka	doc_278690626904_item	2306847	et	3	main
väga	doc_278690626904_item	2306853	et	3	main
asi	doc_278690626904_item	2306855	et	4	main
kultuuris	doc_278690626904_item	2306857	et	3	main
lauldi	doc_278690626904_item	2306858	et	3	main
kooriga	doc_278690626904_item	2306859	et	4	main
on	doc_278690626904_item	2306866	et	4	main
laulnud	doc_278690626904_item	2306875	et	4	main
aga	doc_278690626904_item	2306876	et	3	main
töötama	doc_278690626904_item	2306883	et	3	main
väga	doc_278690626904_item	2306884	et	3	main
ja	doc_278690626904_item	2306890	et	3	main
eestlased	doc_278690626904_item	2306893	et	3	main
oma	doc_278690626904_item	2306921	et	4	main
see	doc_278690626904_item	2306925	et	3	main
tore	doc_278690626904_item	2306928	et	3	main
laulurahv	doc_278690626904_item	2306942	et	4	main
nad	doc_278690626904_item	2306944	et	3	main
asi	doc_278690626904_item	2306955	et	4	main
kõik	doc_278690626904_item	2306959	et	4	main
muusikat	doc_278690626904_item	2306969	et	3	main
nad	doc_278690626904_item	2306975	et	3	main
võimalik	doc_278690626904_item	2306981	et	3	main
võin	doc_278690626904_item	2306986	et	3	main
et	doc_278690626904_item	2306988	et	3	main
eestlased	doc_278690626904_item	2306989	et	3	main
keele	doc_278690626905_item	2306995	et	4	main
kui	doc_278690626905_item	2306996	et	3	main
teise	doc_278690626905_item	2306997	et	4	main
teemal	doc_278690626905_item	2307003	et	3	main
eestlastest	doc_278690626905_item	2307006	et	4	main
lugemistekstis	doc_278690626905_item	2307023	et	3	main
väiteid	doc_278690626905_item	2307026	et	4	main
soovitatav	doc_278690626905_item	2307028	et	4	main
illustreerida	doc_278690626905_item	2307029	et	3	main
essee	doc_278690626904_item	2306794	et	4	main
essee	doc_278690626904_item	2306803	et	4	main
essee	doc_278690626904_item	2306809	et	4	main
arutlev	doc_278690626904_item	2306817	et	4	main
eesti	doc_278690626904_item	2306795	et	4	main
kirjutage	doc_278690626904_item	2306802	et	3	main
eestlastest	doc_278690626904_item	2306807	et	4	main
sõna	doc_278690626904_item	2306813	et	4	main
essee	doc_278690626904_item	2306814	et	4	main
ja	doc_278690626904_item	2306819	et	3	main
ja	doc_278690626904_item	2306823	et	3	main
soovitatav	doc_278690626904_item	2306829	et	4	main
kultuuris	doc_278690626904_item	2306833	et	3	main
see	doc_278690626904_item	2306841	et	3	main
esteetiline	doc_278690626904_item	2306845	et	3	main
sotsiaalne	doc_278690626904_item	2306848	et	3	main
see	doc_278690626904_item	2306851	et	3	main
üksi	doc_278690626904_item	2306861	et	4	main
kiigutades	doc_278690626904_item	2306864	et	3	main
tegeldes	doc_278690626904_item	2306870	et	3	main
mehed	doc_278690626904_item	2306872	et	3	main
ka	doc_278690626904_item	2306874	et	3	main
pole	doc_278690626904_item	2306877	et	3	main
mehed	doc_278690626904_item	2306886	et	3	main
oma	doc_278690626904_item	2306891	et	4	main
armastavad	doc_278690626904_item	2306895	et	4	main
väga	doc_278690626904_item	2306927	et	3	main
samuti	doc_278690626904_item	2306929	et	3	main
on	doc_278690626904_item	2306941	et	4	main
sest	doc_278690626904_item	2306943	et	4	main
ei	doc_278690626904_item	2306945	et	4	main
saa	doc_278690626904_item	2306946	et	4	main
oluline	doc_278690626904_item	2306954	et	4	main
ka	doc_278690626904_item	2306966	et	3	main
ka	doc_278690626904_item	2306971	et	3	main
osalevad	doc_278690626904_item	2306976	et	4	main
ma	doc_278690626904_item	2306985	et	3	main
ütelda	doc_278690626904_item	2306987	et	4	main
see	doc_278690626904_item	2306990	et	3	main
laulurahv	doc_278690626904_item	2306992	et	4	main
essee	doc_278690626905_item	2306993	et	4	main
essee	doc_278690626905_item	2307002	et	4	main
faktidele	doc_278690626905_item	2307025	et	3	main
emotsionaalne	doc_278690626905_item	2307038	et	3	main
see	doc_278690626905_item	2307040	et	3	main
vanast	doc_278690626905_item	2307044	et	3	main
kui	doc_278690626905_item	2307060	et	3	main
ajal	doc_278690626905_item	2307062	et	4	main
ma	doc_278690626905_item	2307063	et	3	main
kulturile	doc_278690626905_item	2307072	et	4	main
rahvalaul	doc_278690626905_item	2307075	et	4	main
oli	doc_278690626905_item	2307108	et	3	main
on	doc_278690626905_item	2307113	et	4	main
nii	doc_278690626905_item	2307114	et	3	main
palju	doc_278690626905_item	2307115	et	4	main
go	doc_278690626905_item	2307123	et	4	main
live	doc_278690626905_item	2307124	et	4	main
summer	doc_278690626905_item	2307126	et	3	main
veedavad	doc_278690626905_item	2307134	et	3	main
aeg	doc_278690626905_item	2307136	et	3	main
perega	doc_278690626905_item	2307138	et	3	main
kokkuvõtteks	doc_278690626905_item	2307141	et	3	main
elu	doc_278690626905_item	2307150	et	4	main
eesti	doc_278690626905_item	2307153	et	4	main
rahvas	doc_278690626905_item	2307154	et	4	main
tahab	doc_278690626905_item	2307155	et	3	main
elada	doc_278690626905_item	2307156	et	3	main
hästi	doc_278690626905_item	2307157	et	3	main
ise	doc_278690626905_item	2307159	et	4	main
eestlastest	doc_278690626905_item	2307162	et	4	main
laulurahva	doc_278690626905_item	2307163	et	3	main
esitatud	doc_278690626904_item	2306825	et	4	main
faktidele	doc_278690626904_item	2306826	et	3	main
on	doc_278690626904_item	2306828	et	4	main
illustreerida	doc_278690626904_item	2306830	et	3	main
eesti	doc_278690626904_item	2306832	et	4	main
tants	doc_278690626904_item	2306834	et	3	main
laul	doc_278690626904_item	2306836	et	4	main
väga	doc_278690626904_item	2306838	et	3	main
ja	doc_278690626904_item	2306844	et	3	main
ning	doc_278690626904_item	2306846	et	3	main
kahekesi	doc_278690626904_item	2306860	et	3	main
põhiliselt	doc_278690626904_item	2306865	et	4	main
naised	doc_278690626904_item	2306868	et	3	main
nii	doc_278690626904_item	2306878	et	3	main
palju	doc_278690626904_item	2306885	et	4	main
mõtlema	doc_278690626904_item	2306888	et	3	main
perest	doc_278690626904_item	2306892	et	4	main
kaasa	doc_278690626904_item	2306896	et	4	main
laulda	doc_278690626904_item	2306897	et	4	main
kogedes	doc_278690626904_item	2306898	et	4	main
seda	doc_278690626904_item	2306899	et	3	main
ülendavat	doc_278690626904_item	2306900	et	4	main
tunnet	doc_278690626904_item	2306901	et	3	main
näiteks	doc_278690626904_item	2306902	et	4	main
varem	doc_278690626904_item	2306903	et	4	main
lapsed	doc_278690626904_item	2306904	et	3	main
väga	doc_278690626904_item	2306905	et	3	main
tihti	doc_278690626904_item	2306906	et	3	main
lauldid	doc_278690626904_item	2306907	et	4	main
oma	doc_278690626904_item	2306909	et	4	main
perega	doc_278690626904_item	2306910	et	3	main
sõbradega	doc_278690626904_item	2306911	et	4	main
ja	doc_278690626904_item	2306912	et	3	main
koos	doc_278690626904_item	2306908	et	4	main
tuttavadega	doc_278690626904_item	2306913	et	3	main
sest	doc_278690626904_item	2306914	et	4	main
laul	doc_278690626904_item	2306915	et	4	main
aitab	doc_278690626904_item	2306916	et	3	main
näita	doc_278690626904_item	2306917	et	4	main
eestis	doc_278690626904_item	2306919	et	3	main
on	doc_278690626904_item	2306920	et	4	main
tunneid	doc_278690626904_item	2306918	et	4	main
ja	doc_278690626904_item	2306924	et	3	main
on	doc_278690626904_item	2306931	et	4	main
palju	doc_278690626904_item	2306933	et	4	main
instrumente	doc_278690626904_item	2306935	et	3	main
näiteks	doc_278690626904_item	2306936	et	4	main
bojaan	doc_278690626904_item	2306937	et	4	main
kannel	doc_278690626904_item	2306938	et	4	main
elada	doc_278690626904_item	2306947	et	3	main
muusika	doc_278690626904_item	2306956	et	4	main
nad	doc_278690626904_item	2306970	et	3	main
armastavad	doc_278690626904_item	2306973	et	4	main
kus	doc_278690626904_item	2306979	et	3	main
on	doc_278690626904_item	2306991	et	4	main
mis	doc_278690626905_item	2307004	et	4	main
loengus	doc_278690626905_item	2307021	et	3	main
on	doc_278690626904_item	2306926	et	4	main
väga	doc_278690626904_item	2306932	et	3	main
muusikaalseid	doc_278690626904_item	2306934	et	4	main
see	doc_278690626904_item	2306940	et	3	main
muusika	doc_278690626904_item	2306949	et	4	main
eestlaste	doc_278690626904_item	2306950	et	4	main
on	doc_278690626904_item	2306952	et	4	main
väga	doc_278690626904_item	2306953	et	3	main
väga	doc_278690626904_item	2306967	et	3	main
väga	doc_278690626904_item	2306972	et	3	main
erinevates	doc_278690626904_item	2306977	et	4	main
projektides	doc_278690626904_item	2306978	et	3	main
keele	doc_278690626905_item	2306998	et	4	main
test	doc_278690626905_item	2306999	et	3	main
essee	doc_278690626905_item	2307008	et	4	main
laulurahva	doc_278690626905_item	2307007	et	3	main
pikkus	doc_278690626905_item	2307009	et	4	main
300	doc_278690626905_item	2307010	et	2	main
350	doc_278690626905_item	2307011	et	2	main
sõna	doc_278690626905_item	2307012	et	4	main
essee	doc_278690626905_item	2307013	et	4	main
peab	doc_278690626905_item	2307014	et	4	main
olema	doc_278690626905_item	2307015	et	4	main
arutlev	doc_278690626905_item	2307016	et	4	main
analüüsiv	doc_278690626905_item	2307017	et	4	main
ja	doc_278690626905_item	2307018	et	3	main
üldistav	doc_278690626905_item	2307019	et	4	main
tuginema	doc_278690626905_item	2307020	et	3	main
ja	doc_278690626905_item	2307022	et	3	main
see	doc_278690626905_item	2307034	et	3	main
on	doc_278690626905_item	2307035	et	4	main
esteetiline	doc_278690626905_item	2307036	et	3	main
tegevus	doc_278690626905_item	2307039	et	4	main
nii	doc_278690626905_item	2307058	et	3	main
eesti	doc_278690626905_item	2307067	et	4	main
esindab	doc_278690626905_item	2307070	et	3	main
koorilaulu	doc_278690626905_item	2307106	et	4	main
festivaale	doc_278690626905_item	2307116	et	4	main
mis	doc_278690626905_item	2307117	et	4	main
toimub	doc_278690626905_item	2307118	et	3	main
nagu	doc_278690626905_item	2307121	et	3	main
laulupidu	doc_278690626905_item	2307127	et	4	main
elada	doc_278690626905_item	2307147	et	3	main
ja	doc_278690626905_item	2307148	et	3	main
paremini	doc_278690626905_item	2307151	et	4	main
aga	doc_278690626905_item	2307152	et	3	main
teeb	doc_278690626905_item	2307161	et	3	main
muusika	doc_278690626904_item	2306922	et	4	main
stiil	doc_278690626904_item	2306923	et	3	main
eestis	doc_278690626904_item	2306930	et	3	main
eestlased	doc_278690626904_item	2306939	et	3	main
muusikata	doc_278690626904_item	2306948	et	3	main
jaoks	doc_278690626904_item	2306951	et	4	main
see	doc_278690626904_item	2306957	et	3	main
on	doc_278690626904_item	2306958	et	4	main
muusika	doc_278690626904_item	2306960	et	4	main
aitab	doc_278690626904_item	2306961	et	3	main
inimestel	doc_278690626904_item	2306962	et	3	main
elada	doc_278690626904_item	2306963	et	3	main
tänapäeva	doc_278690626904_item	2306964	et	4	main
eestlased	doc_278690626904_item	2306965	et	3	main
armastavad	doc_278690626904_item	2306968	et	4	main
laulda	doc_278690626904_item	2306974	et	4	main
on	doc_278690626904_item	2306980	et	4	main
laulda	doc_278690626904_item	2306982	et	4	main
ja	doc_278690626904_item	2306983	et	3	main
sellepärast	doc_278690626904_item	2306984	et	3	main
eesti	doc_278690626905_item	2306994	et	4	main
kirjutamine	doc_278690626905_item	2307000	et	4	main
kirjutage	doc_278690626905_item	2307001	et	3	main
teeb	doc_278690626905_item	2307005	et	3	main
esitatud	doc_278690626905_item	2307024	et	4	main
on	doc_278690626905_item	2307027	et	4	main
näidetega	doc_278690626905_item	2307030	et	3	main
on	doc_278690626905_item	2307032	et	4	main
kultuurinähtus	doc_278690626905_item	2307033	et	4	main
tegevus	doc_278690626905_item	2307041	et	4	main
ringis	doc_278690626905_item	2307050	et	4	main
töötades	doc_278690626905_item	2307051	et	3	main
laul	doc_278690626905_item	2307052	et	4	main
ja	doc_278690626905_item	2307053	et	3	main
tants	doc_278690626905_item	2307054	et	3	main
olivad	doc_278690626905_item	2307055	et	4	main
et	doc_278690626905_item	2307066	et	3	main
laulutraditsiooni	doc_278690626905_item	2307069	et	4	main
mis	doc_278690626905_item	2307076	et	4	main
kujunenud	doc_278690626905_item	2307078	et	4	main
enam	doc_278690626905_item	2307079	et	4	main
kui	doc_278690626905_item	2307080	et	3	main
tuhat	doc_278690626905_item	2307081	et	4	main
aastat	doc_278690626905_item	2307082	et	3	main
tagasi	doc_278690626905_item	2307083	et	3	main
vanal	doc_278690626905_item	2307084	et	3	main
ajal	doc_278690626905_item	2307085	et	4	main
laul	doc_278690626905_item	2307086	et	4	main
on	doc_278690626905_item	2307087	et	4	main
saatnud	doc_278690626905_item	2307088	et	4	main
eestlasi	doc_278690626905_item	2307089	et	3	main
nii	doc_278690626905_item	2307090	et	3	main
tööd	doc_278690626905_item	2307091	et	4	main
tehes	doc_278690626905_item	2307092	et	3	main
kui	doc_278690626905_item	2307093	et	3	main
ka	doc_278690626905_item	2307094	et	3	main
pidutsedes	doc_278690626905_item	2307095	et	3	main
ristiusuga	doc_278690626905_item	2307096	et	3	main
hakkas	doc_278690626905_item	2307097	et	3	main
kirikulaulmine	doc_278690626905_item	2307098	et	3	main
veel	doc_278690626905_item	2307099	et	4	main
lauldi	doc_278690626905_item	2307100	et	3	main
külakoolis	doc_278690626905_item	2307101	et	4	main
laulmine	doc_278690626905_item	2307031	et	4	main
võttas	doc_278690626905_item	2307042	et	4	main
algust	doc_278690626905_item	2307043	et	4	main
ajast	doc_278690626905_item	2307045	et	4	main
eestlased	doc_278690626905_item	2307046	et	3	main
lauldasid	doc_278690626905_item	2307047	et	4	main
üksi	doc_278690626905_item	2307048	et	4	main
eestlastega	doc_278690626905_item	2307057	et	4	main
halval	doc_278690626905_item	2307059	et	3	main
heal	doc_278690626905_item	2307061	et	3	main
kuulsin	doc_278690626905_item	2307064	et	3	main
vanemat	doc_278690626905_item	2307068	et	4	main
läänemeresoome	doc_278690626905_item	2307071	et	3	main
iseloomulik	doc_278690626905_item	2307073	et	3	main
on	doc_278690626905_item	2307077	et	4	main
lapsed	doc_278690626905_item	2307102	et	3	main
saksa	doc_278690626905_item	2307104	et	4	main
mitmehäälset	doc_278690626905_item	2307105	et	3	main
varem	doc_278690626905_item	2307109	et	4	main
praegu	doc_278690626905_item	2307111	et	3	main
aastal	doc_278690626905_item	2307120	et	3	main
ultra	doc_278690626905_item	2307122	et	4	main
inimesed	doc_278690626905_item	2307130	et	3	main
et	doc_278690626905_item	2307144	et	3	main
siis	doc_278690626905_item	2307158	et	3	main
ja	doc_278690626905_item	2307037	et	3	main
kooris	doc_278690626905_item	2307049	et	4	main
koos	doc_278690626905_item	2307056	et	4	main
raadiosaatest	doc_278690626905_item	2307065	et	4	main
regivärsiline	doc_278690626905_item	2307074	et	4	main
õpetasid	doc_278690626905_item	2307103	et	4	main
aga	doc_278690626905_item	2307110	et	3	main
igal	doc_278690626905_item	2307119	et	3	main
õli	doc_278690626905_item	2307125	et	4	main
seal	doc_278690626905_item	2307129	et	4	main
ja	doc_278690626905_item	2307133	et	3	main
koos	doc_278690626905_item	2307137	et	4	main
sõpradega	doc_278690626905_item	2307140	et	3	main
öelda	doc_278690626905_item	2307143	et	4	main
laul	doc_278690626905_item	2307145	et	4	main
aitab	doc_278690626905_item	2307146	et	3	main
teeb	doc_278690626905_item	2307149	et	3	main
see	doc_278690626905_item	2307107	et	3	main
eestis	doc_278690626905_item	2307112	et	3	main
laulupeos	doc_278690626905_item	2307128	et	4	main
lauldavad	doc_278690626905_item	2307131	et	4	main
tantsivad	doc_278690626905_item	2307132	et	4	main
oma	doc_278690626905_item	2307135	et	4	main
ja	doc_278690626905_item	2307139	et	3	main
tahan	doc_278690626905_item	2307142	et	3	main
laul	doc_278690626905_item	2307160	et	4	main
essee	doc_278690626907_item	2307432	et	4	main
keele	doc_278690626907_item	2307437	et	4	main
essee	doc_278690626907_item	2307441	et	4	main
mis	doc_278690626907_item	2307443	et	4	main
essee	doc_278690626907_item	2307447	et	4	main
essee	doc_278690626907_item	2307452	et	4	main
olema	doc_278690626907_item	2307454	et	4	main
analüüsiv	doc_278690626907_item	2307456	et	4	main
on	doc_278690626907_item	2307466	et	4	main
sõbralikum	doc_278690626907_item	2307477	et	4	main
pikkus	doc_278690626908_item	2307528	et	4	main
essee	doc_278690626908_item	2307532	et	4	main
peab	doc_278690626908_item	2307533	et	4	main
lugemistekstis	doc_278690626908_item	2307542	et	3	main
faktidele	doc_278690626908_item	2307544	et	3	main
on	doc_278690626908_item	2307546	et	4	main
soovitatav	doc_278690626908_item	2307547	et	4	main
illustreerida	doc_278690626908_item	2307548	et	3	main
näidetega	doc_278690626908_item	2307549	et	3	main
mis	doc_278690626908_item	2307550	et	4	main
arvan	doc_278690626908_item	2307561	et	3	main
et	doc_278690626908_item	2307563	et	3	main
mis	doc_278690626908_item	2307574	et	4	main
ma	doc_278690626908_item	2307582	et	3	main
alati	doc_278690626908_item	2307591	et	4	main
tants	doc_278690626908_item	2307599	et	3	main
eesti	doc_278690626908_item	2307602	et	4	main
suuliselt	doc_278690626908_item	2307621	et	4	main
eestlastel	doc_278690626908_item	2307624	et	4	main
stiili	doc_278690626908_item	2307627	et	4	main
väga	doc_278690626908_item	2307630	et	3	main
sest	doc_278690626908_item	2307632	et	4	main
rahvalaul	doc_278690626908_item	2307633	et	4	main
tants	doc_278690626908_item	2307635	et	3	main
ei	doc_278690626908_item	2307638	et	4	main
seda	doc_278690626908_item	2307642	et	3	main
1869	doc_278690626908_item	2307649	et	2	main
5	doc_278690626908_item	2307659	et	2	main
võimaluse	doc_278690626908_item	2307666	et	3	main
toimumisse	doc_278690626908_item	2307673	et	4	main
protesti	doc_278690626908_item	2307686	et	4	main
liikumine	doc_278690626908_item	2307687	et	4	main
et	doc_278690626908_item	2307690	et	3	main
huvita	doc_278690626908_item	2307694	et	4	main
rock	doc_278690626908_item	2307700	et	4	main
muusikat	doc_278690626908_item	2307703	et	3	main
meeldib	doc_278690626908_item	2307713	et	3	main
saavad	doc_278690626908_item	2307718	et	4	main
rahvatantsi	doc_278690626908_item	2307720	et	4	main
või	doc_278690626908_item	2307721	et	4	main
inimesed	doc_278690626908_item	2307728	et	3	main
ja	doc_278690626908_item	2307731	et	3	main
inimesed	doc_278690626908_item	2307735	et	3	main
eesti	doc_278690626907_item	2307433	et	4	main
kirjutage	doc_278690626907_item	2307440	et	3	main
eestlastest	doc_278690626907_item	2307445	et	4	main
300	doc_278690626907_item	2307449	et	2	main
sõna	doc_278690626907_item	2307451	et	4	main
peab	doc_278690626907_item	2307453	et	4	main
ja	doc_278690626907_item	2307457	et	3	main
esitatud	doc_278690626907_item	2307463	et	4	main
soovitatav	doc_278690626907_item	2307467	et	4	main
et	doc_278690626907_item	2307471	et	3	main
laul	doc_278690626907_item	2307478	et	4	main
vanal	doc_278690626907_item	2307480	et	3	main
kirjutage	doc_278690626908_item	2307520	et	3	main
essee	doc_278690626908_item	2307527	et	4	main
sõna	doc_278690626908_item	2307531	et	4	main
analüüsiv	doc_278690626908_item	2307536	et	4	main
ja	doc_278690626908_item	2307537	et	3	main
üldistav	doc_278690626908_item	2307538	et	4	main
tuginema	doc_278690626908_item	2307539	et	3	main
loengus	doc_278690626908_item	2307540	et	3	main
esitatud	doc_278690626908_item	2307543	et	4	main
väiteid	doc_278690626908_item	2307545	et	4	main
eestlastest	doc_278690626908_item	2307552	et	4	main
nii	doc_278690626908_item	2307562	et	3	main
laul	doc_278690626908_item	2307564	et	4	main
nendega	doc_278690626908_item	2307568	et	4	main
ajal	doc_278690626908_item	2307570	et	4	main
need	doc_278690626908_item	2307571	et	3	main
olid	doc_278690626908_item	2307572	et	4	main
asjad	doc_278690626908_item	2307573	et	3	main
ajal	doc_278690626908_item	2307581	et	4	main
laul	doc_278690626908_item	2307585	et	4	main
teeb	doc_278690626908_item	2307586	et	3	main
sest	doc_278690626908_item	2307589	et	4	main
laulavad	doc_278690626908_item	2307592	et	4	main
laulu	doc_278690626908_item	2307593	et	4	main
nad	doc_278690626908_item	2307595	et	3	main
töötasid	doc_278690626908_item	2307596	et	4	main
laul	doc_278690626908_item	2307597	et	4	main
rahvaslikku	doc_278690626908_item	2307626	et	4	main
ja	doc_278690626908_item	2307634	et	3	main
kultuuri	doc_278690626908_item	2307641	et	4	main
laulupidul	doc_278690626908_item	2307645	et	3	main
oli	doc_278690626908_item	2307648	et	3	main
56	doc_278690626908_item	2307661	et	2	main
üksina	doc_278690626908_item	2307670	et	3	main
jätnud	doc_278690626908_item	2307676	et	4	main
olud	doc_278690626908_item	2307679	et	3	main
ei	doc_278690626908_item	2307693	et	4	main
ja	doc_278690626908_item	2307697	et	3	main
kuulavad	doc_278690626908_item	2307699	et	4	main
palju	doc_278690626908_item	2307707	et	4	main
käia	doc_278690626908_item	2307714	et	4	main
nad	doc_278690626908_item	2307717	et	3	main
kirjutamine	doc_278690626907_item	2307439	et	4	main
teeb	doc_278690626907_item	2307444	et	3	main
laulurahva	doc_278690626907_item	2307446	et	3	main
näidetega	doc_278690626907_item	2307469	et	3	main
arvan	doc_278690626907_item	2307470	et	3	main
teeb	doc_278690626907_item	2307473	et	3	main
ühineb	doc_278690626907_item	2307479	et	3	main
eestlaste	doc_278690626907_item	2307482	et	4	main
kui	doc_278690626908_item	2307515	et	3	main
teise	doc_278690626908_item	2307516	et	4	main
keele	doc_278690626908_item	2307517	et	4	main
test	doc_278690626908_item	2307518	et	3	main
kirjutamine	doc_278690626908_item	2307519	et	4	main
essee	doc_278690626908_item	2307521	et	4	main
eestlastest	doc_278690626908_item	2307525	et	4	main
arutlev	doc_278690626908_item	2307535	et	4	main
laulurahva	doc_278690626908_item	2307553	et	3	main
eestlastest	doc_278690626908_item	2307558	et	4	main
laulurahva	doc_278690626908_item	2307559	et	3	main
ma	doc_278690626908_item	2307560	et	3	main
olid	doc_278690626908_item	2307567	et	4	main
laulmisega	doc_278690626908_item	2307594	et	4	main
on	doc_278690626908_item	2307601	et	4	main
1920	doc_278690626908_item	2307622	et	2	main
see	doc_278690626908_item	2307628	et	3	main
on	doc_278690626908_item	2307629	et	4	main
oluline	doc_278690626908_item	2307631	et	4	main
annab	doc_278690626908_item	2307636	et	3	main
võimaluse	doc_278690626908_item	2307637	et	3	main
määleta	doc_278690626908_item	2307639	et	4	main
puhkpilliorkestrit	doc_278690626908_item	2307660	et	3	main
mängijaga	doc_278690626908_item	2307662	et	4	main
laulupidude	doc_278690626908_item	2307672	et	4	main
jälje	doc_278690626908_item	2307675	et	3	main
saab	doc_278690626908_item	2307681	et	3	main
et	doc_278690626908_item	2307683	et	3	main
laulupidu	doc_278690626908_item	2307684	et	4	main
oli	doc_278690626908_item	2307685	et	3	main
tantsi	doc_278690626908_item	2307696	et	4	main
nad	doc_278690626908_item	2307705	et	3	main
laulupeol	doc_278690626908_item	2307715	et	4	main
kuulata	doc_278690626908_item	2307722	et	4	main
et	doc_278690626908_item	2307726	et	3	main
et	doc_278690626908_item	2307743	et	3	main
peab	doc_278690626908_item	2307745	et	4	main
määleta	doc_278690626908_item	2307751	et	4	main
keele	doc_278690626909_item	2307758	et	4	main
pikkus	doc_278690626909_item	2307772	et	4	main
peab	doc_278690626909_item	2307777	et	4	main
arutlev	doc_278690626909_item	2307779	et	4	main
esitatud	doc_278690626909_item	2307787	et	4	main
väiteid	doc_278690626909_item	2307789	et	4	main
on	doc_278690626909_item	2307790	et	4	main
muusika	doc_278690626909_item	2307797	et	4	main
parim	doc_278690626909_item	2307799	et	4	main
ja	doc_278690626909_item	2307801	et	3	main
tänapäeval	doc_278690626909_item	2307802	et	3	main
kujunes	doc_278690626909_item	2307806	et	3	main
rahvalaul	doc_278690626909_item	2307808	et	4	main
tagasi	doc_278690626909_item	2307811	et	3	main
laulu	doc_278690626909_item	2307818	et	4	main
aga	doc_278690626909_item	2307819	et	3	main
koorilaulud	doc_278690626909_item	2307822	et	3	main
hea	doc_278690626909_item	2307824	et	4	main
laulud	doc_278690626909_item	2307829	et	3	main
tulemust	doc_278690626909_item	2307841	et	4	main
jaoks	doc_278690626909_item	2307844	et	4	main
test	doc_278690626907_item	2307438	et	3	main
350	doc_278690626907_item	2307450	et	2	main
arutlev	doc_278690626907_item	2307455	et	4	main
üldistav	doc_278690626907_item	2307458	et	4	main
tuginema	doc_278690626907_item	2307459	et	3	main
loengus	doc_278690626907_item	2307460	et	3	main
ja	doc_278690626907_item	2307461	et	3	main
lugemistekstis	doc_278690626907_item	2307462	et	3	main
väiteid	doc_278690626907_item	2307465	et	4	main
laulmine	doc_278690626907_item	2307472	et	4	main
ajal	doc_278690626907_item	2307481	et	4	main
oli	doc_278690626907_item	2307484	et	3	main
väga	doc_278690626907_item	2307485	et	3	main
oluline	doc_278690626907_item	2307486	et	4	main
töötada	doc_278690626907_item	2307487	et	3	main
palju	doc_278690626907_item	2307488	et	4	main
et	doc_278690626907_item	2307489	et	3	main
neil	doc_278690626907_item	2307490	et	4	main
oli	doc_278690626907_item	2307491	et	3	main
rahad	doc_278690626907_item	2307492	et	4	main
ja	doc_278690626907_item	2307493	et	3	main
leib	doc_278690626907_item	2307494	et	3	main
eestlased	doc_278690626907_item	2307495	et	3	main
laulsid	doc_278690626907_item	2307496	et	4	main
töötades	doc_278690626907_item	2307497	et	3	main
last	doc_278690626907_item	2307498	et	4	main
kiigutades	doc_278690626907_item	2307499	et	3	main
peodel	doc_278690626907_item	2307500	et	3	main
need	doc_278690626907_item	2307501	et	3	main
laulud	doc_278690626907_item	2307502	et	3	main
on	doc_278690626907_item	2307503	et	4	main
välja	doc_278690626907_item	2307504	et	4	main
kujunenud	doc_278690626907_item	2307505	et	4	main
saksa	doc_278690626907_item	2307506	et	4	main
rootsi	doc_278690626907_item	2307507	et	4	main
soome	doc_278690626907_item	2307508	et	3	main
slaavi	doc_278690626907_item	2307509	et	3	main
muusika	doc_278690626907_item	2307510	et	4	main
mõjul	doc_278690626907_item	2307511	et	4	main
essee	doc_278690626908_item	2307512	et	4	main
eesti	doc_278690626908_item	2307513	et	4	main
keele	doc_278690626908_item	2307514	et	4	main
keele	doc_278690626907_item	2307434	et	4	main
kui	doc_278690626907_item	2307435	et	3	main
teise	doc_278690626907_item	2307436	et	4	main
teemal	doc_278690626907_item	2307442	et	3	main
pikkus	doc_278690626907_item	2307448	et	4	main
faktidele	doc_278690626907_item	2307464	et	3	main
illustreerida	doc_278690626907_item	2307468	et	3	main
meid	doc_278690626907_item	2307474	et	4	main
parem	doc_278690626907_item	2307475	et	4	main
avalikum	doc_278690626907_item	2307476	et	4	main
jaoks	doc_278690626907_item	2307483	et	4	main
teemal	doc_278690626908_item	2307522	et	3	main
mis	doc_278690626908_item	2307523	et	4	main
teeb	doc_278690626908_item	2307524	et	3	main
laulurahva	doc_278690626908_item	2307526	et	3	main
300	doc_278690626908_item	2307529	et	2	main
tants	doc_278690626908_item	2307566	et	3	main
kõikides	doc_278690626908_item	2307569	et	4	main
arvan	doc_278690626908_item	2307583	et	3	main
eestlastest	doc_278690626908_item	2307587	et	4	main
laulurahva	doc_278690626908_item	2307588	et	3	main
nad	doc_278690626908_item	2307590	et	3	main
see	doc_278690626908_item	2307600	et	3	main
on	doc_278690626908_item	2307625	et	4	main
saab	doc_278690626908_item	2307643	et	3	main
näha	doc_278690626908_item	2307644	et	3	main
eesimene	doc_278690626908_item	2307646	et	4	main
laulupidu	doc_278690626908_item	2307647	et	4	main
see	doc_278690626908_item	2307663	et	3	main
annab	doc_278690626908_item	2307665	et	3	main
tunneb	doc_278690626908_item	2307667	et	3	main
mitte	doc_278690626908_item	2307669	et	3	main
on	doc_278690626908_item	2307674	et	4	main
poliitilised	doc_278690626908_item	2307678	et	3	main
ma	doc_278690626908_item	2307688	et	3	main
arvan	doc_278690626908_item	2307689	et	3	main
noored	doc_278690626908_item	2307691	et	3	main
rahvamuusikat	doc_278690626908_item	2307695	et	3	main
või	doc_278690626908_item	2307701	et	4	main
vaid	doc_278690626908_item	2307704	et	3	main
kultuurist	doc_278690626908_item	2307709	et	3	main
ajaloost	doc_278690626908_item	2307711	et	4	main
nendele	doc_278690626908_item	2307712	et	4	main
näha	doc_278690626908_item	2307719	et	3	main
350	doc_278690626908_item	2307530	et	2	main
olema	doc_278690626908_item	2307534	et	4	main
ja	doc_278690626908_item	2307541	et	3	main
teeb	doc_278690626908_item	2307551	et	3	main
laul	doc_278690626908_item	2307554	et	4	main
ja	doc_278690626908_item	2307555	et	3	main
tants	doc_278690626908_item	2307556	et	3	main
teevad	doc_278690626908_item	2307557	et	3	main
ja	doc_278690626908_item	2307565	et	3	main
oli	doc_278690626908_item	2307575	et	3	main
eestlastega	doc_278690626908_item	2307576	et	4	main
nii	doc_278690626908_item	2307577	et	3	main
halval	doc_278690626908_item	2307578	et	3	main
kui	doc_278690626908_item	2307579	et	3	main
heal	doc_278690626908_item	2307580	et	3	main
et	doc_278690626908_item	2307584	et	3	main
ja	doc_278690626908_item	2307598	et	3	main
kultuur	doc_278690626908_item	2307603	et	3	main
aga	doc_278690626908_item	2307604	et	3	main
eestlased	doc_278690626908_item	2307605	et	3	main
armastavad	doc_278690626908_item	2307606	et	4	main
oma	doc_278690626908_item	2307607	et	4	main
kultuuri	doc_278690626908_item	2307608	et	4	main
palju	doc_278690626908_item	2307609	et	4	main
aastat	doc_278690626908_item	2307610	et	3	main
tagasi	doc_278690626908_item	2307611	et	3	main
nad	doc_278690626908_item	2307612	et	3	main
laulsid	doc_278690626908_item	2307613	et	4	main
ilma	doc_278690626908_item	2307614	et	4	main
muusikata	doc_278690626908_item	2307615	et	3	main
need	doc_278690626908_item	2307616	et	3	main
lauled	doc_278690626908_item	2307617	et	4	main
pärandati	doc_278690626908_item	2307618	et	4	main
põlvest	doc_278690626908_item	2307619	et	4	main
põlve	doc_278690626908_item	2307620	et	4	main
aastal	doc_278690626908_item	2307623	et	3	main
oma	doc_278690626908_item	2307640	et	4	main
aastal	doc_278690626908_item	2307650	et	3	main
tartus	doc_278690626908_item	2307651	et	3	main
kus	doc_278690626908_item	2307652	et	3	main
osales	doc_278690626908_item	2307653	et	3	main
46	doc_278690626908_item	2307654	et	2	main
meeskoori	doc_278690626908_item	2307655	et	4	main
822	doc_278690626908_item	2307656	et	2	main
lauljaga	doc_278690626908_item	2307657	et	4	main
ja	doc_278690626908_item	2307658	et	3	main
pidu	doc_278690626908_item	2307664	et	4	main
end	doc_278690626908_item	2307668	et	4	main
kahjuks	doc_278690626908_item	2307671	et	4	main
valitsenud	doc_278690626908_item	2307677	et	4	main
aga	doc_278690626908_item	2307680	et	3	main
öelda	doc_278690626908_item	2307682	et	4	main
inimesed	doc_278690626908_item	2307692	et	3	main
nad	doc_278690626908_item	2307698	et	3	main
pop	doc_278690626908_item	2307702	et	4	main
teavad	doc_278690626908_item	2307706	et	3	main
eesti	doc_278690626908_item	2307708	et	4	main
ja	doc_278690626908_item	2307710	et	3	main
kus	doc_278690626908_item	2307716	et	3	main
rahvalaulu	doc_278690626908_item	2307723	et	4	main
laula	doc_278690626908_item	2307730	et	4	main
ei	doc_278690626908_item	2307732	et	4	main
tantsida	doc_278690626908_item	2307733	et	3	main
siis	doc_278690626908_item	2307734	et	3	main
kultuuri	doc_278690626908_item	2307739	et	4	main
midagi	doc_278690626908_item	2307747	et	4	main
ajaloost	doc_278690626908_item	2307755	et	4	main
essee	doc_278690626909_item	2307771	et	4	main
300	doc_278690626909_item	2307773	et	2	main
loengus	doc_278690626909_item	2307784	et	3	main
lugemistekstis	doc_278690626909_item	2307786	et	3	main
ajal	doc_278690626909_item	2307795	et	4	main
on	doc_278690626909_item	2307803	et	4	main
mõtlen	doc_278690626908_item	2307725	et	3	main
ja	doc_278690626908_item	2307740	et	3	main
ma	doc_278690626908_item	2307741	et	3	main
arvan	doc_278690626908_item	2307742	et	3	main
võimaluse	doc_278690626908_item	2307750	et	3	main
oma	doc_278690626908_item	2307752	et	4	main
kultuurist	doc_278690626908_item	2307753	et	3	main
ja	doc_278690626908_item	2307754	et	3	main
kui	doc_278690626909_item	2307759	et	3	main
teise	doc_278690626909_item	2307760	et	4	main
keele	doc_278690626909_item	2307761	et	4	main
test	doc_278690626909_item	2307762	et	3	main
kirjutamine	doc_278690626909_item	2307763	et	4	main
kirjutage	doc_278690626909_item	2307764	et	3	main
essee	doc_278690626909_item	2307765	et	4	main
teemal	doc_278690626909_item	2307766	et	3	main
mis	doc_278690626909_item	2307767	et	4	main
teeb	doc_278690626909_item	2307768	et	3	main
eestlastest	doc_278690626909_item	2307769	et	4	main
ma	doc_278690626908_item	2307724	et	3	main
kui	doc_278690626908_item	2307727	et	3	main
ei	doc_278690626908_item	2307729	et	4	main
määletaks	doc_278690626908_item	2307737	et	4	main
rahvastel	doc_278690626908_item	2307744	et	4	main
annab	doc_278690626908_item	2307749	et	3	main
eesti	doc_278690626909_item	2307757	et	4	main
essee	doc_278690626909_item	2307776	et	4	main
üldistav	doc_278690626909_item	2307782	et	4	main
tuginema	doc_278690626909_item	2307783	et	3	main
ja	doc_278690626909_item	2307785	et	3	main
eestlastele	doc_278690626909_item	2307796	et	4	main
sõber	doc_278690626909_item	2307800	et	3	main
eestis	doc_278690626909_item	2307805	et	3	main
koorimuusika	doc_278690626909_item	2307815	et	4	main
eeslaulja	doc_278690626909_item	2307816	et	4	main
viib	doc_278690626909_item	2307817	et	3	main
kordab	doc_278690626909_item	2307821	et	3	main
oli	doc_278690626909_item	2307823	et	3	main
oma	doc_278690626909_item	2307832	et	4	main
tööd	doc_278690626909_item	2307833	et	4	main
teha	doc_278690626909_item	2307836	et	3	main
saada	doc_278690626909_item	2307842	et	4	main
v	doc_278690626909_item	2307853	et	4	main
rajas	doc_278690626909_item	2307855	et	4	main
niisugune	doc_278690626909_item	2307861	et	3	main
oli	doc_278690626909_item	2307865	et	3	main
nõukogudeajal	doc_278690626909_item	2307869	et	3	main
korraldamisega	doc_278690626909_item	2307873	et	4	main
aga	doc_278690626909_item	2307874	et	3	main
kohtuda	doc_278690626909_item	2307903	et	3	main
aega	doc_278690626909_item	2307905	et	4	main
lõbusalt	doc_278690626909_item	2307906	et	4	main
on	doc_278690626909_item	2307913	et	4	main
laulupidu	doc_278690626909_item	2307919	et	4	main
vanemad	doc_278690626909_item	2307920	et	4	main
tavalise	doc_278690626909_item	2307924	et	4	main
jaoks	doc_278690626909_item	2307926	et	4	main
kuulsin	doc_278690626909_item	2307935	et	3	main
et	doc_278690626909_item	2307936	et	3	main
praegu	doc_278690626909_item	2307937	et	3	main
on	doc_278690626909_item	2307938	et	4	main
võin	doc_278690626909_item	2307949	et	3	main
et	doc_278690626909_item	2307955	et	3	main
muusikata	doc_278690626909_item	2307977	et	3	main
suur	doc_278690626909_item	2307979	et	3	main
teeb	doc_278690626909_item	2307981	et	3	main
eesti	doc_278690626910_item	2308003	et	4	main
essee	doc_278690626910_item	2308011	et	4	main
pikkus	doc_278690626910_item	2308018	et	4	main
sõna	doc_278690626910_item	2308021	et	4	main
analüüsiv	doc_278690626910_item	2308026	et	4	main
ja	doc_278690626910_item	2308027	et	3	main
üldistav	doc_278690626910_item	2308028	et	4	main
lugemistekstis	doc_278690626910_item	2308032	et	3	main
ajalugu	doc_278690626910_item	2308046	et	4	main
näiteks	doc_278690626910_item	2308073	et	4	main
loengust	doc_278690626910_item	2308074	et	4	main
nimetatakse	doc_278690626910_item	2308082	et	3	main
rahvalauluks	doc_278690626910_item	2308084	et	4	main
huvitav	doc_278690626910_item	2308086	et	4	main
et	doc_278690626910_item	2308089	et	3	main
muusika	doc_278690626910_item	2308091	et	4	main
koosneb	doc_278690626910_item	2308093	et	3	main
väga	doc_278690626910_item	2308099	et	3	main
kuulata	doc_278690626910_item	2308101	et	4	main
kuidas	doc_278690626910_item	2308102	et	3	main
organiseeritsid	doc_278690626910_item	2308103	et	4	main
erinevad	doc_278690626910_item	2308104	et	4	main
last	doc_278690626910_item	2308113	et	4	main
rahva	doc_278690626910_item	2308117	et	3	main
esimene	doc_278690626910_item	2308137	et	3	main
laulupidu	doc_278690626910_item	2308139	et	4	main
tartus	doc_278690626910_item	2308141	et	3	main
mille	doc_278690626910_item	2308142	et	3	main
korraldamise	doc_278690626910_item	2308143	et	4	main
tuli	doc_278690626910_item	2308147	et	4	main
sellest	doc_278690626910_item	2308159	et	4	main
alguse	doc_278690626910_item	2308161	et	3	main
kõik	doc_278690626910_item	2308165	et	4	main
kasulikud	doc_278690626910_item	2308169	et	3	main
ei	doc_278690626908_item	2307736	et	4	main
oma	doc_278690626908_item	2307738	et	4	main
olema	doc_278690626908_item	2307746	et	4	main
mis	doc_278690626908_item	2307748	et	4	main
essee	doc_278690626909_item	2307756	et	4	main
laulurahva	doc_278690626909_item	2307770	et	3	main
sõna	doc_278690626909_item	2307775	et	4	main
olema	doc_278690626909_item	2307778	et	4	main
analüüsiv	doc_278690626909_item	2307780	et	4	main
ja	doc_278690626909_item	2307781	et	3	main
illustreerida	doc_278690626909_item	2307792	et	3	main
näidetega	doc_278690626909_item	2307793	et	3	main
oli	doc_278690626909_item	2307798	et	3	main
oli	doc_278690626909_item	2307813	et	3	main
rohkem	doc_278690626909_item	2307814	et	4	main
koor	doc_278690626909_item	2307820	et	4	main
põllutööajal	doc_278690626909_item	2307825	et	3	main
meeles	doc_278690626909_item	2307828	et	3	main
aitasid	doc_278690626909_item	2307830	et	4	main
eestlastel	doc_278690626909_item	2307831	et	4	main
ja	doc_278690626909_item	2307837	et	3	main
tõttu	doc_278690626909_item	2307839	et	4	main
aastal	doc_278690626909_item	2307851	et	3	main
laulupidu	doc_278690626909_item	2307858	et	4	main
eestis	doc_278690626909_item	2307864	et	3	main
eurovision	doc_278690626909_item	2307867	et	4	main
tänapäeval	doc_278690626909_item	2307868	et	3	main
tekkisid	doc_278690626909_item	2307870	et	4	main
püha	doc_278690626909_item	2307872	et	4	main
oma	doc_278690626909_item	2307904	et	4	main
veeta	doc_278690626909_item	2307907	et	4	main
laulurahva	doc_278690626909_item	2307915	et	3	main
on	doc_278690626909_item	2307918	et	4	main
eestlase	doc_278690626909_item	2307925	et	3	main
rahvas	doc_278690626909_item	2307929	et	4	main
väga	doc_278690626909_item	2307939	et	3	main
et	doc_278690626909_item	2307951	et	3	main
see	doc_278690626909_item	2307966	et	3	main
tähendab	doc_278690626909_item	2307967	et	3	main
nad	doc_278690626909_item	2307969	et	3	main
keele	doc_278690626910_item	2308004	et	4	main
teemal	doc_278690626910_item	2308012	et	3	main
350	doc_278690626909_item	2307774	et	2	main
faktidele	doc_278690626909_item	2307788	et	3	main
soovitatav	doc_278690626909_item	2307791	et	4	main
vanal	doc_278690626909_item	2307794	et	3	main
samuti	doc_278690626909_item	2307804	et	3	main
esimene	doc_278690626909_item	2307807	et	3	main
tuhat	doc_278690626909_item	2307809	et	4	main
aastat	doc_278690626909_item	2307810	et	3	main
see	doc_278690626909_item	2307812	et	3	main
laulda	doc_278690626909_item	2307826	et	4	main
parim	doc_278690626909_item	2307840	et	4	main
eestlaste	doc_278690626909_item	2307843	et	4	main
muusika	doc_278690626909_item	2307845	et	4	main
oli	doc_278690626909_item	2307846	et	3	main
nii	doc_278690626909_item	2307847	et	3	main
tähtis	doc_278690626909_item	2307848	et	4	main
et	doc_278690626909_item	2307849	et	3	main
hämmardav	doc_278690626909_item	2307862	et	4	main
sündmus	doc_278690626909_item	2307863	et	3	main
nagu	doc_278690626909_item	2307866	et	3	main
nad	doc_278690626909_item	2307917	et	3	main
minu	doc_278690626909_item	2307827	et	3	main
lõbuse	doc_278690626909_item	2307834	et	3	main
tujuga	doc_278690626909_item	2307835	et	3	main
see	doc_278690626909_item	2307838	et	3	main
1869	doc_278690626909_item	2307850	et	2	main
esimese	doc_278690626909_item	2307856	et	3	main
tol	doc_278690626909_item	2307859	et	3	main
ajal	doc_278690626909_item	2307860	et	4	main
probleemid	doc_278690626909_item	2307871	et	3	main
inimeste	doc_278690626909_item	2307875	et	3	main
soov	doc_278690626909_item	2307876	et	3	main
ja	doc_278690626909_item	2307877	et	3	main
tahtmine	doc_278690626909_item	2307878	et	4	main
muusikaga	doc_278690626909_item	2307879	et	3	main
kontaktis	doc_278690626909_item	2307880	et	3	main
olla	doc_278690626909_item	2307881	et	3	main
palusid	doc_278690626909_item	2307882	et	4	main
püha	doc_278690626909_item	2307883	et	4	main
uuesti	doc_278690626909_item	2307884	et	3	main
korralikult	doc_278690626909_item	2307885	et	4	main
ja	doc_278690626909_item	2307886	et	3	main
täielikult	doc_278690626909_item	2307887	et	4	main
veeta	doc_278690626909_item	2307888	et	4	main
ja	doc_278690626909_item	2307889	et	3	main
võin	doc_278690626909_item	2307891	et	3	main
korraldada	doc_278690626909_item	2307890	et	3	main
oletada	doc_278690626909_item	2307892	et	3	main
et	doc_278690626909_item	2307893	et	3	main
laulupüha	doc_278690626909_item	2307894	et	4	main
on	doc_278690626909_item	2307895	et	4	main
nagu	doc_278690626909_item	2307896	et	3	main
vaimupüha	doc_278690626909_item	2307897	et	4	main
sest	doc_278690626909_item	2307898	et	4	main
ta	doc_278690626909_item	2307899	et	4	main
võimaldab	doc_278690626909_item	2307900	et	3	main
inimestele	doc_278690626909_item	2307901	et	3	main
koos	doc_278690626909_item	2307902	et	4	main
j	doc_278690626909_item	2307852	et	4	main
jannsen	doc_278690626909_item	2307854	et	4	main
ülemailma	doc_278690626909_item	2307857	et	4	main
ja	doc_278690626909_item	2307908	et	3	main
saada	doc_278690626909_item	2307911	et	4	main
eestlased	doc_278690626909_item	2307912	et	3	main
vaieldamatu	doc_278690626909_item	2307914	et	4	main
ja	doc_278690626909_item	2307921	et	3	main
seostub	doc_278690626909_item	2307927	et	3	main
sõnadega	doc_278690626909_item	2307928	et	3	main
laul	doc_278690626909_item	2307931	et	4	main
kohe	doc_278690626909_item	2307932	et	4	main
oletada	doc_278690626909_item	2307950	et	3	main
muusikaga	doc_278690626909_item	2307956	et	3	main
hingama	doc_278690626909_item	2307976	et	3	main
kui	doc_278690626910_item	2308005	et	3	main
teeb	doc_278690626910_item	2308014	et	3	main
300	doc_278690626910_item	2308019	et	2	main
ja	doc_278690626910_item	2308031	et	3	main
on	doc_278690626910_item	2308036	et	4	main
eestis	doc_278690626910_item	2308040	et	3	main
nende	doc_278690626910_item	2308052	et	4	main
eesti	doc_278690626910_item	2308054	et	4	main
on	doc_278690626910_item	2308056	et	4	main
väga	doc_278690626910_item	2308057	et	3	main
huvitav	doc_278690626910_item	2308058	et	4	main
eriti	doc_278690626910_item	2308059	et	3	main
rahvalaulu	doc_278690626910_item	2308081	et	4	main
mitmes	doc_278690626910_item	2308094	et	4	main
tants	doc_278690626910_item	2308097	et	3	main
lauldi	doc_278690626910_item	2308109	et	3	main
töötades	doc_278690626910_item	2308112	et	3	main
kiigutades	doc_278690626910_item	2308114	et	3	main
minevik	doc_278690626910_item	2308118	et	3	main
on	doc_278690626910_item	2308120	et	4	main
ka	doc_278690626910_item	2308121	et	3	main
et	doc_278690626910_item	2308132	et	3	main
tähtsusega	doc_278690626910_item	2308134	et	4	main
1869	doc_278690626910_item	2308140	et	2	main
j	doc_278690626910_item	2308151	et	4	main
jannseniga	doc_278690626910_item	2308153	et	4	main
ühtlasi	doc_278690626910_item	2308154	et	4	main
sai	doc_278690626910_item	2308155	et	4	main
suursündmus	doc_278690626910_item	2308158	et	3	main
laulupidude	doc_278690626910_item	2308162	et	4	main
need	doc_278690626910_item	2308164	et	3	main
faktid	doc_278690626910_item	2308166	et	3	main
väga	doc_278690626910_item	2308168	et	3	main
huvitavad	doc_278690626910_item	2308171	et	4	main
eriti	doc_278690626910_item	2308176	et	3	main
laulupidude	doc_278690626910_item	2308181	et	4	main
lõpetamised	doc_278690626910_item	2308182	et	4	main
eeldused	doc_278690626910_item	2308222	et	4	main
tekkeks	doc_278690626910_item	2308226	et	3	main
rahvalaul	doc_278690626910_item	2308233	et	4	main
ja	doc_278690626910_item	2308237	et	3	main
sündmusi	doc_278690626910_item	2308261	et	3	main
nagu	doc_278690626910_item	2308273	et	3	main
riplim	doc_278690626910_item	2308276	et	4	main
laulsid	doc_278690626910_item	2308284	et	4	main
eriti	doc_278690626910_item	2308285	et	3	main
naised	doc_278690626910_item	2308286	et	3	main
meestel	doc_278690626910_item	2308287	et	4	main
väga	doc_278690626910_item	2308328	et	3	main
folkloorirühmi	doc_278690626910_item	2308336	et	4	main
väga	doc_278690626910_item	2308342	et	3	main
keele	doc_278690626910_item	2308352	et	4	main
seda	doc_278690626910_item	2308357	et	3	main
ta	doc_278690626910_item	2308359	et	4	main
ja	doc_278690626910_item	2308367	et	3	main
rahvalaulu	doc_278690626910_item	2308376	et	4	main
mõtlen	doc_278690626910_item	2308380	et	3	main
on	doc_278690626910_item	2308395	et	4	main
on	doc_278690626910_item	2308405	et	4	main
hea	doc_278690626910_item	2308416	et	4	main
eestis	doc_278690626910_item	2308418	et	3	main
muidugi	doc_278690626909_item	2307909	et	4	main
sõbralikuks	doc_278690626909_item	2307910	et	3	main
sest	doc_278690626909_item	2307916	et	4	main
et	doc_278690626909_item	2307923	et	3	main
ka	doc_278690626909_item	2307933	et	3	main
laulupidu	doc_278690626909_item	2307934	et	4	main
võtavad	doc_278690626909_item	2307945	et	3	main
osa	doc_278690626909_item	2307946	et	4	main
noor	doc_278690626909_item	2307947	et	3	main
inimesed	doc_278690626909_item	2307948	et	3	main
on	doc_278690626909_item	2307953	et	4	main
sündinud	doc_278690626909_item	2307954	et	4	main
muusikasse	doc_278690626909_item	2307962	et	4	main
veres	doc_278690626909_item	2307965	et	3	main
ei	doc_278690626909_item	2307970	et	4	main
see	doc_278690626909_item	2307978	et	3	main
teise	doc_278690626910_item	2308006	et	4	main
mis	doc_278690626910_item	2308013	et	4	main
eestlastest	doc_278690626910_item	2308015	et	4	main
essee	doc_278690626910_item	2308017	et	4	main
350	doc_278690626910_item	2308020	et	2	main
tuginema	doc_278690626910_item	2308029	et	3	main
väiteid	doc_278690626910_item	2308035	et	4	main
illustreerida	doc_278690626910_item	2308038	et	3	main
näidetega	doc_278690626910_item	2308039	et	3	main
teistedes	doc_278690626910_item	2308042	et	3	main
riikides	doc_278690626910_item	2308043	et	3	main
omad	doc_278690626910_item	2308045	et	4	main
sündmused	doc_278690626910_item	2308047	et	3	main
traditsioonid	doc_278690626910_item	2308048	et	3	main
oma	doc_278690626910_item	2308049	et	4	main
ühiskond	doc_278690626910_item	2308050	et	3	main
faktid	doc_278690626910_item	2308072	et	3	main
vanemat	doc_278690626910_item	2308080	et	4	main
see	doc_278690626910_item	2308088	et	3	main
eesti	doc_278690626910_item	2308090	et	4	main
folkloor	doc_278690626910_item	2308092	et	4	main
laul	doc_278690626910_item	2308096	et	4	main
kasulik	doc_278690626910_item	2308100	et	3	main
vanad	doc_278690626910_item	2308105	et	3	main
aegadel	doc_278690626910_item	2308108	et	3	main
tutvumine	doc_278690626910_item	2308123	et	4	main
ajaloo	doc_278690626910_item	2308126	et	4	main
oli	doc_278690626910_item	2308128	et	3	main
see	doc_278690626910_item	2308131	et	3	main
ajaloolise	doc_278690626910_item	2308133	et	4	main
sündmuseks	doc_278690626910_item	2308135	et	3	main
ülemaaline	doc_278690626910_item	2308138	et	4	main
idee	doc_278690626910_item	2308144	et	4	main
ja	doc_278690626910_item	2308145	et	3	main
vanemuise	doc_278690626910_item	2308148	et	4	main
eesotsas	doc_278690626910_item	2308150	et	4	main
muusikaline	doc_278690626910_item	2308157	et	4	main
sai	doc_278690626910_item	2308160	et	4	main
on	doc_278690626910_item	2308167	et	4	main
ja	doc_278690626910_item	2308170	et	3	main
kui	doc_278690626910_item	2308183	et	3	main
ja	doc_278690626910_item	2308187	et	3	main
rahvalaulu	doc_278690626910_item	2308225	et	4	main
erinev	doc_278690626910_item	2308230	et	4	main
ta	doc_278690626910_item	2308234	et	4	main
laululehed	doc_278690626910_item	2308248	et	3	main
salmialbumid	doc_278690626910_item	2308250	et	3	main
trükitult	doc_278690626910_item	2308252	et	4	main
ma	doc_278690626910_item	2308253	et	3	main
muidugi	doc_278690626910_item	2308254	et	4	main
ei	doc_278690626910_item	2308255	et	4	main
saa	doc_278690626910_item	2308256	et	4	main
kirjeldada	doc_278690626910_item	2308257	et	3	main
öeldi	doc_278690626910_item	2308275	et	3	main
uued	doc_278690626910_item	2308277	et	3	main
võimalus	doc_278690626910_item	2308290	et	3	main
pulmades	doc_278690626910_item	2308292	et	3	main
et	doc_278690626910_item	2308295	et	3	main
väga	doc_278690626910_item	2308333	et	3	main
näiteks	doc_278690626910_item	2308337	et	4	main
eesti	doc_278690626910_item	2308351	et	4	main
põhimõteliselt	doc_278690626910_item	2308369	et	4	main
meile	doc_278690626910_item	2308375	et	4	main
tänapäeval	doc_278690626910_item	2308378	et	3	main
eestis	doc_278690626910_item	2308381	et	3	main
sest	doc_278690626909_item	2307922	et	4	main
ja	doc_278690626909_item	2307930	et	3	main
palju	doc_278690626909_item	2307940	et	4	main
folkloori	doc_278690626909_item	2307941	et	4	main
näitusi	doc_278690626909_item	2307942	et	3	main
ja	doc_278690626909_item	2307943	et	3	main
seal	doc_278690626909_item	2307944	et	4	main
eestlased	doc_278690626909_item	2307952	et	3	main
ja	doc_278690626909_item	2307957	et	3	main
kultuuriga	doc_278690626909_item	2307958	et	4	main
kaasa	doc_278690626909_item	2307959	et	4	main
töötama	doc_278690626909_item	2307960	et	3	main
armastus	doc_278690626909_item	2307961	et	4	main
on	doc_278690626909_item	2307963	et	4	main
nende	doc_278690626909_item	2307964	et	4	main
et	doc_278690626909_item	2307968	et	3	main
saa	doc_278690626909_item	2307971	et	4	main
lihtsalt	doc_278690626909_item	2307972	et	4	main
elada	doc_278690626909_item	2307973	et	3	main
ja	doc_278690626909_item	2307974	et	3	main
õhu	doc_278690626909_item	2307975	et	3	main
eestlastest	doc_278690626909_item	2307982	et	4	main
laulurahva	doc_278690626909_item	2307983	et	3	main
armastus	doc_278690626909_item	2307980	et	4	main
eestlase	doc_278690626909_item	2307984	et	3	main
minevik	doc_278690626909_item	2307985	et	3	main
ja	doc_278690626909_item	2307986	et	3	main
tänapäev	doc_278690626909_item	2307987	et	3	main
on	doc_278690626909_item	2307988	et	4	main
muusikaga	doc_278690626909_item	2307990	et	3	main
nad	doc_278690626909_item	2307991	et	3	main
on	doc_278690626909_item	2307992	et	4	main
seotud	doc_278690626909_item	2307989	et	4	main
koos	doc_278690626909_item	2307993	et	4	main
iga	doc_278690626909_item	2307994	et	4	main
situatsioonis	doc_278690626909_item	2307995	et	3	main
ja	doc_278690626909_item	2307996	et	3	main
tulevikus	doc_278690626909_item	2307997	et	4	main
peavad	doc_278690626909_item	2307998	et	4	main
koos	doc_278690626909_item	2307999	et	4	main
olla	doc_278690626909_item	2308000	et	3	main
ka	doc_278690626909_item	2308001	et	3	main
essee	doc_278690626910_item	2308002	et	4	main
keele	doc_278690626910_item	2308007	et	4	main
test	doc_278690626910_item	2308008	et	3	main
kirjutamine	doc_278690626910_item	2308009	et	4	main
kirjutage	doc_278690626910_item	2308010	et	3	main
laulurahva	doc_278690626910_item	2308016	et	3	main
loengus	doc_278690626910_item	2308030	et	3	main
faktidele	doc_278690626910_item	2308034	et	3	main
nagu	doc_278690626910_item	2308041	et	3	main
huvialad	doc_278690626910_item	2308053	et	3	main
erinevad	doc_278690626910_item	2308071	et	4	main
sain	doc_278690626910_item	2308076	et	3	main
teada	doc_278690626910_item	2308077	et	3	main
et	doc_278690626910_item	2308078	et	3	main
üksi	doc_278690626910_item	2308110	et	4	main
rahvalauluga	doc_278690626910_item	2308122	et	4	main
pisut	doc_278690626910_item	2308124	et	3	main
nagu	doc_278690626910_item	2308125	et	3	main
uurimine	doc_278690626910_item	2308127	et	4	main
huvitav	doc_278690626910_item	2308129	et	4	main
teada	doc_278690626910_item	2308130	et	3	main
traditsioon	doc_278690626910_item	2308163	et	3	main
lugesin	doc_278690626910_item	2308174	et	3	main
et	doc_278690626910_item	2308175	et	3	main
said	doc_278690626910_item	2308178	et	4	main
vallandusid	doc_278690626910_item	2308184	et	4	main
kõlas	doc_278690626910_item	2308188	et	4	main
rahvalaul	doc_278690626910_item	2308228	et	4	main
kui	doc_278690626910_item	2308231	et	3	main
värsimõõdult	doc_278690626910_item	2308236	et	3	main
autor	doc_278690626910_item	2308238	et	3	main
teada	doc_278690626910_item	2308240	et	3	main
on	doc_278690626910_item	2308242	et	4	main
tema	doc_278690626910_item	2308243	et	4	main
ja	doc_278690626910_item	2308249	et	3	main
rahvalaulu	doc_278690626910_item	2308260	et	4	main
erinevad	doc_278690626910_item	2308278	et	4	main
öeldi	doc_278690626910_item	2308281	et	3	main
regilaulu	doc_278690626910_item	2308283	et	4	main
oli	doc_278690626910_item	2308288	et	3	main
ka	doc_278690626910_item	2308289	et	3	main
arvan	doc_278690626910_item	2308294	et	3	main
viimastel	doc_278690626910_item	2308296	et	3	main
näidata	doc_278690626910_item	2308321	et	4	main
et	doc_278690626910_item	2308323	et	3	main
erinevaid	doc_278690626910_item	2308335	et	4	main
lõuna	doc_278690626910_item	2308338	et	4	main
on	doc_278690626910_item	2308340	et	4	main
hea	doc_278690626910_item	2308343	et	4	main
rühm	doc_278690626910_item	2308344	et	3	main
kes	doc_278690626910_item	2308345	et	4	main
laulab	doc_278690626910_item	2308346	et	3	main
setu	doc_278690626910_item	2308347	et	4	main
keel	doc_278690626910_item	2308353	et	4	main
ka	doc_278690626910_item	2308355	et	3	main
keeli	doc_278690626910_item	2308358	et	4	main
on	doc_278690626910_item	2308360	et	4	main
minu	doc_278690626910_item	2308361	et	3	main
jaoks	doc_278690626910_item	2308362	et	4	main
kõik	doc_278690626910_item	2308370	et	4	main
tänasepäeva	doc_278690626910_item	2308371	et	4	main
püüavad	doc_278690626910_item	2308373	et	3	main
palju	doc_278690626910_item	2308383	et	4	main
folkloori	doc_278690626910_item	2308385	et	4	main
see	doc_278690626910_item	2308386	et	3	main
jaoks	doc_278690626910_item	2308394	et	4	main
praegu	doc_278690626910_item	2308406	et	3	main
kiire	doc_278690626910_item	2308408	et	4	main
raske	doc_278690626910_item	2308410	et	4	main
elu	doc_278690626910_item	2308411	et	4	main
ja	doc_278690626910_item	2308412	et	3	main
see	doc_278690626910_item	2308413	et	3	main
on	doc_278690626910_item	2308414	et	4	main
väga	doc_278690626910_item	2308415	et	3	main
ilmuvad	doc_278690626910_item	2308423	et	4	main
kui	doc_278690626910_item	2308426	et	3	main
vana	doc_278690626910_item	2308429	et	4	main
uurima	doc_278690626910_item	2308438	et	3	main
fakte	doc_278690626910_item	2308440	et	3	main
ühes	doc_278690626910_item	2308448	et	4	main
ansamblis	doc_278690626910_item	2308449	et	3	main
essee	doc_278690626910_item	2308022	et	4	main
peab	doc_278690626910_item	2308023	et	4	main
olema	doc_278690626910_item	2308024	et	4	main
arutlev	doc_278690626910_item	2308025	et	4	main
esitatud	doc_278690626910_item	2308033	et	4	main
soovitatav	doc_278690626910_item	2308037	et	4	main
on	doc_278690626910_item	2308044	et	4	main
ja	doc_278690626910_item	2308051	et	3	main
ajalugu	doc_278690626910_item	2308055	et	4	main
mulle	doc_278690626910_item	2308060	et	4	main
meeldib	doc_278690626910_item	2308061	et	3	main
see	doc_278690626910_item	2308062	et	3	main
et	doc_278690626910_item	2308063	et	3	main
kuidas	doc_278690626910_item	2308064	et	3	main
ilmus	doc_278690626910_item	2308065	et	4	main
meie	doc_278690626910_item	2308066	et	4	main
rahvalaul	doc_278690626910_item	2308067	et	4	main
teda	doc_278690626910_item	2308068	et	4	main
sündmused	doc_278690626910_item	2308069	et	3	main
ja	doc_278690626910_item	2308070	et	3	main
ma	doc_278690626910_item	2308075	et	3	main
eesti	doc_278690626910_item	2308079	et	4	main
regivärsiliseks	doc_278690626910_item	2308083	et	4	main
veel	doc_278690626910_item	2308085	et	4	main
oli	doc_278690626910_item	2308087	et	3	main
osas	doc_278690626910_item	2308095	et	4	main
oli	doc_278690626910_item	2308098	et	3	main
rahvalaulupeod	doc_278690626910_item	2308106	et	4	main
vanadel	doc_278690626910_item	2308107	et	3	main
olles	doc_278690626910_item	2308111	et	3	main
rahvalauludes	doc_278690626910_item	2308115	et	3	main
kajastub	doc_278690626910_item	2308116	et	3	main
mistõttu	doc_278690626910_item	2308119	et	3	main
kujunes	doc_278690626910_item	2308136	et	3	main
teostus	doc_278690626910_item	2308146	et	4	main
seltsist	doc_278690626910_item	2308149	et	4	main
v	doc_278690626910_item	2308152	et	4	main
sellest	doc_278690626910_item	2308156	et	4	main
seltsist	doc_278690626910_item	2308172	et	4	main
meeliülendavaiks	doc_278690626910_item	2308177	et	3	main
tunded	doc_278690626910_item	2308186	et	3	main
gustav	doc_278690626910_item	2308189	et	4	main
ernesaksa	doc_278690626910_item	2308190	et	4	main
hingestatud	doc_278690626910_item	2308191	et	4	main
isamaalaul	doc_278690626910_item	2308192	et	4	main
mu	doc_278690626910_item	2308193	et	3	main
on	doc_278690626910_item	2308195	et	4	main
minu	doc_278690626910_item	2308196	et	3	main
isamaa	doc_278690626910_item	2308194	et	4	main
arm	doc_278690626910_item	2308197	et	3	main
siit	doc_278690626910_item	2308198	et	3	main
kujunesid	doc_278690626910_item	2308199	et	4	main
nõukogudeaegsed	doc_278690626910_item	2308200	et	3	main
laulupeod	doc_278690626910_item	2308201	et	4	main
omamoodi	doc_278690626910_item	2308202	et	3	main
rahvusliku	doc_278690626910_item	2308203	et	3	main
identiteedi	doc_278690626910_item	2308204	et	4	main
oli	doc_278690626910_item	2308206	et	3	main
veel	doc_278690626910_item	2308207	et	4	main
üks	doc_278690626910_item	2308208	et	3	main
hoidjaiks	doc_278690626910_item	2308205	et	4	main
väga	doc_278690626910_item	2308209	et	3	main
huvitav	doc_278690626910_item	2308210	et	4	main
sündmus	doc_278690626910_item	2308211	et	3	main
et	doc_278690626910_item	2308212	et	3	main
vanema	doc_278690626910_item	2308213	et	4	main
ja	doc_278690626910_item	2308214	et	3	main
euroopast	doc_278690626910_item	2308215	et	3	main
laenatud	doc_278690626910_item	2308216	et	4	main
laulutraditsiooni	doc_278690626910_item	2308217	et	4	main
koosmõju	doc_278690626910_item	2308218	et	4	main
lõi	doc_278690626910_item	2308219	et	4	main
19	doc_278690626910_item	2308220	et	2	main
sajandil	doc_278690626910_item	2308221	et	3	main
riimilise	doc_278690626910_item	2308224	et	4	main
on	doc_278690626910_item	2308229	et	4	main
regivärsiline	doc_278690626910_item	2308232	et	4	main
on	doc_278690626910_item	2308239	et	4	main
või	doc_278690626910_item	2308241	et	4	main
ülestähendus	doc_278690626910_item	2308247	et	3	main
kõiki	doc_278690626910_item	2308258	et	4	main
aga	doc_278690626910_item	2308262	et	3	main
ma	doc_278690626910_item	2308264	et	3	main
ma	doc_278690626910_item	2308173	et	3	main
nõukogude	doc_278690626910_item	2308179	et	3	main
ajal	doc_278690626910_item	2308180	et	4	main
rahvuslikud	doc_278690626910_item	2308185	et	3	main
uue	doc_278690626910_item	2308223	et	3	main
riimiline	doc_278690626910_item	2308227	et	4	main
on	doc_278690626910_item	2308235	et	4	main
isik	doc_278690626910_item	2308244	et	3	main
tuvastatav	doc_278690626910_item	2308245	et	4	main
kirjalik	doc_278690626910_item	2308246	et	3	main
levisid	doc_278690626910_item	2308251	et	4	main
neid	doc_278690626910_item	2308259	et	4	main
tõsiselt	doc_278690626910_item	2308263	et	4	main
olen	doc_278690626910_item	2308265	et	3	main
palju	doc_278690626910_item	2308267	et	4	main
uusi	doc_278690626910_item	2308268	et	3	main
asju	doc_278690626910_item	2308269	et	3	main
uus	doc_278690626910_item	2308270	et	3	main
rahvalaul	doc_278690626910_item	2308271	et	4	main
iseloomustab	doc_278690626910_item	2308272	et	4	main
loengus	doc_278690626910_item	2308274	et	3	main
nagu	doc_278690626910_item	2308280	et	3	main
ma	doc_278690626910_item	2308293	et	3	main
aastatel	doc_278690626910_item	2308297	et	4	main
inimesed	doc_278690626910_item	2308298	et	3	main
hakkavad	doc_278690626910_item	2308299	et	4	main
rohkem	doc_278690626910_item	2308300	et	4	main
rahvalaulu	doc_278690626910_item	2308301	et	4	main
laulda	doc_278690626910_item	2308302	et	4	main
see	doc_278690626910_item	2308303	et	3	main
vahva	doc_278690626910_item	2308305	et	4	main
19	doc_278690626910_item	2308306	et	2	main
on	doc_278690626910_item	2308304	et	4	main
saj	doc_278690626910_item	2308307	et	4	main
hakkati	doc_278690626910_item	2308308	et	3	main
kasutama	doc_278690626910_item	2308309	et	3	main
muusikainstrumente	doc_278690626910_item	2308310	et	3	main
tänasepäeval	doc_278690626910_item	2308311	et	4	main
heelilojad	doc_278690626910_item	2308312	et	4	main
ka	doc_278690626910_item	2308313	et	3	main
püüavad	doc_278690626910_item	2308314	et	3	main
kasutada	doc_278690626910_item	2308315	et	3	main
rahvusliku	doc_278690626910_item	2308316	et	3	main
muusika	doc_278690626910_item	2308317	et	4	main
stiilit	doc_278690626910_item	2308318	et	4	main
nad	doc_278690626910_item	2308319	et	3	main
tahavad	doc_278690626910_item	2308320	et	3	main
teadnud	doc_278690626910_item	2308266	et	4	main
žaanrid	doc_278690626910_item	2308279	et	2	main
et	doc_278690626910_item	2308282	et	3	main
laulda	doc_278690626910_item	2308291	et	4	main
muusika	doc_278690626910_item	2308325	et	4	main
traditsioonid	doc_278690626910_item	2308326	et	3	main
on	doc_278690626910_item	2308327	et	4	main
eestis	doc_278690626910_item	2308331	et	3	main
on	doc_278690626910_item	2308332	et	4	main
palju	doc_278690626910_item	2308334	et	4	main
vanim	doc_278690626910_item	2308350	et	3	main
ma	doc_278690626910_item	2308354	et	3	main
ilus	doc_278690626910_item	2308366	et	4	main
esitada	doc_278690626910_item	2308374	et	3	main
on	doc_278690626910_item	2308382	et	4	main
nende	doc_278690626910_item	2308393	et	4	main
lauldes	doc_278690626910_item	2308400	et	3	main
lõõgastuvad	doc_278690626910_item	2308402	et	4	main
meil	doc_278690626910_item	2308404	et	4	main
väga	doc_278690626910_item	2308407	et	3	main
ja	doc_278690626910_item	2308409	et	3	main
et	doc_278690626910_item	2308417	et	3	main
ilmuvad	doc_278690626910_item	2308421	et	4	main
rühmad	doc_278690626910_item	2308425	et	4	main
laulatakse	doc_278690626910_item	2308427	et	4	main
rohkem	doc_278690626910_item	2308433	et	4	main
tegelema	doc_278690626910_item	2308434	et	3	main
kui	doc_278690626910_item	2308441	et	3	main
gümnaasiumis	doc_278690626910_item	2308444	et	3	main
ka	doc_278690626910_item	2308446	et	3	main
kus	doc_278690626910_item	2308450	et	3	main
esinesime	doc_278690626910_item	2308451	et	3	main
ka	doc_278690626910_item	2308452	et	3	main
meile	doc_278690626910_item	2308322	et	4	main
vanad	doc_278690626910_item	2308324	et	3	main
ilusad	doc_278690626910_item	2308329	et	3	main
meie	doc_278690626910_item	2308330	et	4	main
eestis	doc_278690626910_item	2308339	et	3	main
üks	doc_278690626910_item	2308341	et	3	main
see	doc_278690626910_item	2308348	et	3	main
on	doc_278690626910_item	2308349	et	4	main
kuulsin	doc_278690626910_item	2308356	et	3	main
raske	doc_278690626910_item	2308363	et	4	main
aga	doc_278690626910_item	2308364	et	3	main
väga	doc_278690626910_item	2308365	et	3	main
huvitav	doc_278690626910_item	2308368	et	4	main
ansamblid	doc_278690626910_item	2308372	et	3	main
stiil	doc_278690626910_item	2308377	et	3	main
ma	doc_278690626910_item	2308379	et	3	main
huvitav	doc_278690626910_item	2308397	et	4	main
ja	doc_278690626910_item	2308398	et	3	main
nad	doc_278690626910_item	2308401	et	3	main
puhkavad	doc_278690626910_item	2308403	et	4	main
erinevates	doc_278690626910_item	2308419	et	4	main
lindades	doc_278690626910_item	2308420	et	4	main
erinevad	doc_278690626910_item	2308424	et	4	main
rahvalaulu	doc_278690626910_item	2308430	et	4	main
inimesed	doc_278690626910_item	2308431	et	3	main
hakkavad	doc_278690626910_item	2308432	et	4	main
erinevaid	doc_278690626910_item	2308439	et	4	main
erineva	doc_278690626910_item	2308384	et	4	main
on	doc_278690626910_item	2308387	et	4	main
tore	doc_278690626910_item	2308388	et	3	main
inimesed	doc_278690626910_item	2308389	et	3	main
võivad	doc_278690626910_item	2308390	et	4	main
leida	doc_278690626910_item	2308391	et	3	main
mida	doc_278690626910_item	2308392	et	4	main
väga	doc_278690626910_item	2308396	et	3	main
kasulik	doc_278690626910_item	2308399	et	3	main
eesti	doc_278690626910_item	2308435	et	4	main
ajalooga	doc_278690626910_item	2308436	et	4	main
ja	doc_278690626910_item	2308437	et	3	main
käisin	doc_278690626910_item	2308443	et	3	main
ma	doc_278690626910_item	2308445	et	3	main
laulsin	doc_278690626910_item	2308447	et	3	main
eesti	doc_278690626910_item	2308453	et	4	main
rahvalauludega	doc_278690626910_item	2308454	et	3	main
ja	doc_278690626910_item	2308422	et	3	main
eesti	doc_278690626910_item	2308428	et	4	main
ma	doc_278690626910_item	2308442	et	3	main
keele	doc_278690626912_item	2308801	et	4	main
essee	doc_278690626912_item	2308805	et	4	main
teeb	doc_278690626912_item	2308808	et	3	main
laulurahva	doc_278690626912_item	2308810	et	3	main
essee	doc_278690626912_item	2308816	et	4	main
ja	doc_278690626912_item	2308821	et	3	main
faktidele	doc_278690626912_item	2308828	et	3	main
on	doc_278690626912_item	2308830	et	4	main
laulupidu	doc_278690626912_item	2308834	et	4	main
pidu	doc_278690626912_item	2308840	et	4	main
järgneb	doc_278690626912_item	2308847	et	3	main
tallinnas	doc_278690626912_item	2308850	et	4	main
ma	doc_278690626912_item	2308851	et	3	main
laulupidu	doc_278690626912_item	2308876	et	4	main
kohtuvad	doc_278690626912_item	2308880	et	4	main
tuttavad	doc_278690626912_item	2308883	et	4	main
teised	doc_278690626912_item	2308902	et	4	main
võivad	doc_278690626912_item	2308908	et	4	main
ja	doc_278690626912_item	2308911	et	3	main
palju	doc_278690626912_item	2308918	et	4	main
test	doc_278690626912_item	2308802	et	3	main
300	doc_278690626912_item	2308813	et	2	main
peab	doc_278690626912_item	2308817	et	4	main
arutlev	doc_278690626912_item	2308819	et	4	main
analüüsiv	doc_278690626912_item	2308820	et	4	main
kirjutage	doc_278690626912_item	2308804	et	3	main
mis	doc_278690626912_item	2308807	et	4	main
eestlastest	doc_278690626912_item	2308809	et	4	main
350	doc_278690626912_item	2308814	et	2	main
ja	doc_278690626912_item	2308825	et	3	main
põnev	doc_278690626912_item	2308839	et	3	main
tähestab	doc_278690626912_item	2308842	et	4	main
aastast	doc_278690626912_item	2308845	et	4	main
tähestada	doc_278690626912_item	2308848	et	4	main
võtan	doc_278690626912_item	2308852	et	3	main
ise	doc_278690626912_item	2308854	et	4	main
sellest	doc_278690626912_item	2308855	et	4	main
proovin	doc_278690626912_item	2308873	et	3	main
üritus	doc_278690626912_item	2308878	et	4	main
ja	doc_278690626912_item	2308901	et	3	main
kes	doc_278690626912_item	2308904	et	4	main
et	doc_278690626912_item	2308906	et	3	main
näidata	doc_278690626912_item	2308912	et	4	main
ja	doc_278690626912_item	2308917	et	3	main
kui	doc_278690626912_item	2308923	et	3	main
folkloor	doc_278690626912_item	2308928	et	4	main
tähendab	doc_278690626912_item	2308936	et	3	main
iga	doc_278690626912_item	2308938	et	4	main
võib	doc_278690626912_item	2308940	et	3	main
on	doc_278690626912_item	2308945	et	4	main
aktiivne	doc_278690626912_item	2308952	et	3	main
ole	doc_278690626912_item	2308962	et	4	main
kas	doc_278690626912_item	2308965	et	3	main
korraldajad	doc_278690626912_item	2308974	et	4	main
mõtlesid	doc_278690626912_item	2308976	et	4	main
ma	doc_278690626912_item	2308979	et	3	main
erinevad	doc_278690626912_item	2308985	et	4	main
näiteks	doc_278690626912_item	2308986	et	4	main
inimene	doc_278690626912_item	2308991	et	3	main
kombed	doc_278690626912_item	2309002	et	3	main
palju	doc_278690626912_item	2309005	et	4	main
ja	doc_278690626912_item	2309023	et	3	main
näitavad	doc_278690626912_item	2309027	et	4	main
ja	doc_278690626912_item	2309030	et	3	main
tehtud	doc_278690626912_item	2309031	et	4	main
saada	doc_278690626912_item	2309039	et	4	main
miks	doc_278690626912_item	2309040	et	4	main
koori	doc_278690626912_item	2309052	et	4	main
kirjutamine	doc_278690626912_item	2308803	et	4	main
essee	doc_278690626912_item	2308811	et	4	main
pikkus	doc_278690626912_item	2308812	et	4	main
tuginema	doc_278690626912_item	2308823	et	3	main
mis	doc_278690626912_item	2308841	et	4	main
ja	doc_278690626912_item	2308846	et	3	main
üritusest	doc_278690626912_item	2308856	et	4	main
ja	doc_278690626912_item	2308857	et	3	main
ja	doc_278690626912_item	2308870	et	3	main
nüüd	doc_278690626912_item	2308871	et	4	main
ma	doc_278690626912_item	2308872	et	3	main
laval	doc_278690626912_item	2308895	et	3	main
on	doc_278690626912_item	2308914	et	4	main
hääl	doc_278690626912_item	2308916	et	3	main
eesti	doc_278690626912_item	2308927	et	4	main
lauljast	doc_278690626912_item	2308930	et	4	main
ja	doc_278690626912_item	2308932	et	3	main
see	doc_278690626912_item	2308935	et	3	main
et	doc_278690626912_item	2308937	et	3	main
osaleda	doc_278690626912_item	2308941	et	3	main
on	doc_278690626912_item	2308951	et	4	main
elus	doc_278690626912_item	2308954	et	4	main
ja	doc_278690626912_item	2308955	et	3	main
vaja	doc_278690626912_item	2308963	et	4	main
kõige	doc_278690626912_item	2308977	et	4	main
on	doc_278690626912_item	2308981	et	4	main
sest	doc_278690626912_item	2308983	et	4	main
oma	doc_278690626912_item	2308999	et	4	main
traditsiooned	doc_278690626912_item	2309000	et	4	main
ja	doc_278690626912_item	2309003	et	3	main
kuidas	doc_278690626912_item	2309021	et	3	main
taga	doc_278690626912_item	2309033	et	4	main
töö	doc_278690626912_item	2309034	et	4	main
ja	doc_278690626912_item	2309035	et	3	main
laulupeol	doc_278690626912_item	2309041	et	4	main
sõidavad	doc_278690626912_item	2309042	et	3	main
inimesed	doc_278690626912_item	2309043	et	3	main
kasvab	doc_278690626912_item	2309051	et	3	main
on	doc_278690626912_item	2309061	et	4	main
niisugune	doc_278690626912_item	2309062	et	3	main
oma	doc_278690626912_item	2309074	et	4	main
annab	doc_278690626912_item	2309082	et	3	main
laulupeol	doc_278690626912_item	2309095	et	4	main
on	doc_278690626912_item	2309100	et	4	main
meelest	doc_278690626912_item	2309104	et	4	main
meie	doc_278690626912_item	2309108	et	4	main
et	doc_278690626912_item	2309116	et	3	main
osavõtjad	doc_278690626912_item	2309119	et	3	main
alla	doc_278690626912_item	2309123	et	3	main
ja	doc_278690626912_item	2309127	et	3	main
võin	doc_278690626912_item	2309133	et	3	main
päeval	doc_278690626912_item	2309136	et	3	main
kindel	doc_278690626912_item	2309150	et	3	main
väsinud	doc_278690626912_item	2309155	et	4	main
see	doc_278690626912_item	2309157	et	3	main
aeg	doc_278690626912_item	2309158	et	3	main
sa	doc_278690626912_item	2309159	et	3	main
kui	doc_278690626912_item	2309163	et	3	main
reaalne	doc_278690626912_item	2309170	et	3	main
tuttvuda	doc_278690626912_item	2309172	et	4	main
inimestega	doc_278690626912_item	2309174	et	3	main
suhelda	doc_278690626912_item	2309176	et	4	main
ainult	doc_278690626912_item	2309178	et	4	main
keeles	doc_278690626912_item	2309186	et	4	main
mina	doc_278690626912_item	2309188	et	4	main
rahul	doc_278690626912_item	2309190	et	4	main
essee	doc_278690626912_item	2308796	et	4	main
eesti	doc_278690626912_item	2308797	et	4	main
keele	doc_278690626912_item	2308798	et	4	main
kui	doc_278690626912_item	2308799	et	3	main
teise	doc_278690626912_item	2308800	et	4	main
teemal	doc_278690626912_item	2308806	et	3	main
sõna	doc_278690626912_item	2308815	et	4	main
olema	doc_278690626912_item	2308818	et	4	main
loengus	doc_278690626912_item	2308824	et	3	main
lugemistekstis	doc_278690626912_item	2308826	et	3	main
illustreerida	doc_278690626912_item	2308832	et	3	main
näidetega	doc_278690626912_item	2308833	et	3	main
see	doc_278690626912_item	2308835	et	3	main
on	doc_278690626912_item	2308836	et	4	main
suur	doc_278690626912_item	2308837	et	3	main
1869	doc_278690626912_item	2308844	et	2	main
tõestada	doc_278690626912_item	2308875	et	3	main
on	doc_278690626912_item	2308877	et	4	main
kus	doc_278690626912_item	2308879	et	3	main
sugulased	doc_278690626912_item	2308882	et	3	main
ja	doc_278690626912_item	2308884	et	3	main
palju	doc_278690626912_item	2308885	et	4	main
turiste	doc_278690626912_item	2308886	et	3	main
kes	doc_278690626912_item	2308887	et	4	main
ka	doc_278690626912_item	2308888	et	3	main
tahavad	doc_278690626912_item	2308889	et	3	main
koguvad	doc_278690626912_item	2308897	et	4	main
kõik	doc_278690626912_item	2308898	et	4	main
lauljad	doc_278690626912_item	2308899	et	4	main
koorid	doc_278690626912_item	2308900	et	4	main
kellel	doc_278690626912_item	2308913	et	4	main
oskusi	doc_278690626912_item	2308919	et	3	main
mitte	doc_278690626912_item	2308920	et	3	main
ainult	doc_278690626912_item	2308921	et	4	main
tuntud	doc_278690626912_item	2308926	et	4	main
kui	doc_278690626912_item	2308943	et	3	main
selle	doc_278690626912_item	2308956	et	4	main
mitte	doc_278690626912_item	2308971	et	3	main
arvan	doc_278690626912_item	2308980	et	3	main
venemaa	doc_278690626912_item	2308987	et	4	main
tantsudest	doc_278690626912_item	2308988	et	3	main
iga	doc_278690626912_item	2308990	et	4	main
laps	doc_278690626912_item	2308993	et	4	main
teab	doc_278690626912_item	2308994	et	3	main
et	doc_278690626912_item	2308995	et	3	main
igas	doc_278690626912_item	2308996	et	3	main
riigis	doc_278690626912_item	2308997	et	3	main
kõikidest	doc_278690626912_item	2309025	et	4	main
riigidest	doc_278690626912_item	2309026	et	4	main
oma	doc_278690626912_item	2309028	et	4	main
oskusi	doc_278690626912_item	2309029	et	3	main
ja	doc_278690626912_item	2309044	et	3	main
kasvab	doc_278690626912_item	2309047	et	3	main
aasta	doc_278690626912_item	2309049	et	4	main
on	doc_278690626912_item	2309066	et	4	main
jaoks	doc_278690626912_item	2309070	et	4	main
ei	doc_278690626912_item	2309072	et	4	main
leinud	doc_278690626912_item	2309073	et	4	main
midagi	doc_278690626912_item	2309079	et	4	main
võimalusi	doc_278690626912_item	2309084	et	3	main
instrument	doc_278690626912_item	2309102	et	3	main
muusika	doc_278690626912_item	2309109	et	4	main
lauludega	doc_278690626912_item	2309111	et	3	main
mulle	doc_278690626912_item	2309114	et	4	main
et	doc_278690626912_item	2309122	et	3	main
kirjutada	doc_278690626912_item	2309124	et	3	main
rahvus	doc_278690626912_item	2309126	et	3	main
ütelda	doc_278690626912_item	2309134	et	4	main
kui	doc_278690626912_item	2309137	et	3	main
ma	doc_278690626912_item	2309148	et	3	main
et	doc_278690626912_item	2309151	et	3	main
sest	doc_278690626912_item	2309156	et	4	main
üldistav	doc_278690626912_item	2308822	et	4	main
esitatud	doc_278690626912_item	2308827	et	4	main
väiteid	doc_278690626912_item	2308829	et	4	main
soovitatav	doc_278690626912_item	2308831	et	4	main
ja	doc_278690626912_item	2308838	et	3	main
juba	doc_278690626912_item	2308843	et	3	main
tänapäeval	doc_278690626912_item	2308849	et	3	main
osa	doc_278690626912_item	2308853	et	4	main
ma	doc_278690626912_item	2308858	et	3	main
võin	doc_278690626912_item	2308859	et	3	main
ütelda	doc_278690626912_item	2308860	et	4	main
et	doc_278690626912_item	2308861	et	3	main
see	doc_278690626912_item	2308862	et	3	main
pidu	doc_278690626912_item	2308863	et	4	main
erineb	doc_278690626912_item	2308864	et	3	main
pidudest	doc_278690626912_item	2308865	et	4	main
mida	doc_278690626912_item	2308866	et	4	main
me	doc_278690626912_item	2308867	et	4	main
tähistame	doc_278690626912_item	2308868	et	3	main
kodust	doc_278690626912_item	2308869	et	4	main
seda	doc_278690626912_item	2308874	et	3	main
sõbrad	doc_278690626912_item	2308881	et	3	main
vaadata	doc_278690626912_item	2308890	et	4	main
mis	doc_278690626912_item	2308891	et	4	main
toimub	doc_278690626912_item	2308892	et	3	main
tallinna	doc_278690626912_item	2308893	et	4	main
laulupeo	doc_278690626912_item	2308894	et	4	main
siin	doc_278690626912_item	2308896	et	4	main
inimesed	doc_278690626912_item	2308903	et	3	main
teavad	doc_278690626912_item	2308905	et	3	main
nad	doc_278690626912_item	2308907	et	3	main
ennast	doc_278690626912_item	2308909	et	4	main
esitada	doc_278690626912_item	2308910	et	3	main
hea	doc_278690626912_item	2308915	et	4	main
muusikas	doc_278690626912_item	2308922	et	3	main
on	doc_278690626912_item	2308925	et	4	main
pillemängudest	doc_278690626912_item	2308931	et	4	main
tal	doc_278690626912_item	2308944	et	3	main
tuju	doc_278690626912_item	2308947	et	4	main
ja	doc_278690626912_item	2308948	et	3	main
kui	doc_278690626912_item	2308949	et	3	main
ta	doc_278690626912_item	2308950	et	4	main
jaoks	doc_278690626912_item	2308957	et	4	main
et	doc_278690626912_item	2308958	et	3	main
tulla	doc_278690626912_item	2308959	et	3	main
laulupeole	doc_278690626912_item	2308960	et	4	main
või	doc_278690626912_item	2308970	et	4	main
sest	doc_278690626912_item	2308972	et	4	main
sellest	doc_278690626912_item	2308973	et	4	main
juba	doc_278690626912_item	2308975	et	3	main
erinevaid	doc_278690626912_item	2309006	et	4	main
lauljad	doc_278690626912_item	2309024	et	4	main
aasta	doc_278690626912_item	2309032	et	4	main
iga	doc_278690626912_item	2309048	et	4	main
kui	doc_278690626912_item	2309050	et	3	main
traditsioon	doc_278690626912_item	2309063	et	3	main
hea	doc_278690626912_item	2309067	et	4	main
hobbi	doc_278690626912_item	2309075	et	4	main
veel	doc_278690626912_item	2309076	et	4	main
sest	doc_278690626912_item	2309080	et	4	main
ta	doc_278690626912_item	2309087	et	4	main
seotud	doc_278690626912_item	2309089	et	4	main
instrumendiga	doc_278690626912_item	2309090	et	3	main
sest	doc_278690626912_item	2309098	et	4	main
millest	doc_278690626912_item	2309105	et	3	main
eestis	doc_278690626912_item	2309107	et	3	main
tantsidega	doc_278690626912_item	2309110	et	3	main
jne	doc_278690626912_item	2309112	et	4	main
sellele	doc_278690626912_item	2309117	et	4	main
panevad	doc_278690626912_item	2309120	et	4	main
rahvariided	doc_278690626912_item	2309121	et	3	main
ilus	doc_278690626912_item	2309128	et	4	main
oma	doc_278690626912_item	2309129	et	4	main
üldses	doc_278690626912_item	2309131	et	4	main
ma	doc_278690626912_item	2309132	et	3	main
toimub	doc_278690626912_item	2309138	et	3	main
pidu	doc_278690626912_item	2309140	et	4	main
mängida	doc_278690626912_item	2309144	et	3	main
olen	doc_278690626912_item	2309149	et	3	main
on	doc_278690626912_item	2309169	et	4	main
rootsi-	doc_278690626912_item	2309183	et	4	main
meil	doc_278690626912_item	2308924	et	4	main
koosneb	doc_278690626912_item	2308929	et	3	main
tantsudest	doc_278690626912_item	2308933	et	3	main
aga	doc_278690626912_item	2308934	et	3	main
inimene	doc_278690626912_item	2308939	et	3	main
ainult	doc_278690626912_item	2308942	et	4	main
hea	doc_278690626912_item	2308946	et	4	main
inimene	doc_278690626912_item	2308953	et	3	main
ei	doc_278690626912_item	2308961	et	4	main
mõelda	doc_278690626912_item	2308964	et	4	main
asub	doc_278690626912_item	2308966	et	3	main
sina	doc_278690626912_item	2308967	et	4	main
sulle	doc_278690626912_item	2308968	et	3	main
kohta	doc_278690626912_item	2308969	et	4	main
huvitavam	doc_278690626912_item	2308978	et	4	main
tantsud	doc_278690626912_item	2308982	et	3	main
nad	doc_278690626912_item	2308984	et	3	main
miks	doc_278690626912_item	2308989	et	4	main
ja	doc_278690626912_item	2308992	et	3	main
on	doc_278690626912_item	2308998	et	4	main
ja	doc_278690626912_item	2309001	et	3	main
ka	doc_278690626912_item	2309004	et	3	main
stiileid	doc_278690626912_item	2309007	et	4	main
muusikas	doc_278690626912_item	2309008	et	3	main
ja	doc_278690626912_item	2309009	et	3	main
tantsus	doc_278690626912_item	2309010	et	3	main
selle	doc_278690626912_item	2309011	et	4	main
pärast	doc_278690626912_item	2309012	et	4	main
mulle	doc_278690626912_item	2309013	et	4	main
tundub	doc_278690626912_item	2309014	et	3	main
et	doc_278690626912_item	2309015	et	3	main
inimestele	doc_278690626912_item	2309016	et	3	main
on	doc_278690626912_item	2309017	et	4	main
huvitav	doc_278690626912_item	2309018	et	4	main
vaadata	doc_278690626912_item	2309019	et	4	main
sellele	doc_278690626912_item	2309020	et	4	main
koorid	doc_278690626912_item	2309022	et	4	main
kohe	doc_278690626912_item	2309036	et	4	main
võib	doc_278690626912_item	2309037	et	3	main
aru	doc_278690626912_item	2309038	et	4	main
nende	doc_278690626912_item	2309045	et	4	main
arv	doc_278690626912_item	2309046	et	3	main
ja	doc_278690626912_item	2309053	et	3	main
lauljate	doc_278690626912_item	2309054	et	4	main
arv	doc_278690626912_item	2309055	et	3	main
mulle	doc_278690626912_item	2309056	et	4	main
meeldib	doc_278690626912_item	2309057	et	3	main
et	doc_278690626912_item	2309058	et	3	main
meie	doc_278690626912_item	2309059	et	4	main
eestis	doc_278690626912_item	2309060	et	3	main
sest	doc_278690626912_item	2309064	et	4	main
veel	doc_278690626912_item	2309078	et	4	main
muusika	doc_278690626912_item	2309081	et	4	main
nii	doc_278690626912_item	2309085	et	3	main
on	doc_278690626912_item	2309088	et	4	main
aga	doc_278690626912_item	2309091	et	3	main
kõige	doc_278690626912_item	2309092	et	4	main
populaarne	doc_278690626912_item	2309093	et	3	main
instrument	doc_278690626912_item	2309094	et	3	main
see	doc_278690626912_item	2309099	et	3	main
ka	doc_278690626912_item	2309113	et	3	main
meeldib	doc_278690626912_item	2309115	et	3	main
riigi	doc_278690626912_item	2309130	et	3	main
puhata	doc_278690626912_item	2309143	et	4	main
sa	doc_278690626912_item	2309152	et	3	main
sõpradega	doc_278690626912_item	2309161	et	3	main
ei	doc_278690626912_item	2309166	et	4	main
see	doc_278690626912_item	2309168	et	3	main
saksa-	doc_278690626912_item	2309184	et	4	main
jne	doc_278690626912_item	2309187	et	4	main
see	doc_278690626912_item	2309065	et	3	main
näitus	doc_278690626912_item	2309068	et	3	main
inimeste	doc_278690626912_item	2309069	et	3	main
kes	doc_278690626912_item	2309071	et	4	main
või	doc_278690626912_item	2309077	et	4	main
palju	doc_278690626912_item	2309083	et	4	main
kui	doc_278690626912_item	2309086	et	3	main
on	doc_278690626912_item	2309096	et	4	main
kannel	doc_278690626912_item	2309097	et	4	main
esimene	doc_278690626912_item	2309101	et	3	main
minu	doc_278690626912_item	2309103	et	3	main
hakkas	doc_278690626912_item	2309106	et	3	main
peole	doc_278690626912_item	2309118	et	4	main
oma	doc_278690626912_item	2309125	et	4	main
et	doc_278690626912_item	2309135	et	3	main
see	doc_278690626912_item	2309139	et	3	main
sa	doc_278690626912_item	2309141	et	3	main
võib	doc_278690626912_item	2309142	et	3	main
tantsida	doc_278690626912_item	2309145	et	3	main
laulda	doc_278690626912_item	2309146	et	4	main
ja	doc_278690626912_item	2309147	et	3	main
ei	doc_278690626912_item	2309153	et	4	main
hakka	doc_278690626912_item	2309154	et	4	main
sul	doc_278690626912_item	2309164	et	3	main
neid	doc_278690626912_item	2309165	et	4	main
ole	doc_278690626912_item	2309167	et	4	main
inglise	doc_278690626912_item	2309185	et	4	main
et	doc_278690626912_item	2309191	et	3	main
elan	doc_278690626912_item	2309192	et	3	main
eestis	doc_278690626912_item	2309193	et	3	main
sest	doc_278690626912_item	2309194	et	4	main
see	doc_278690626912_item	2309195	et	3	main
riik	doc_278690626912_item	2309196	et	3	main
juba	doc_278690626912_item	2309197	et	3	main
tuntud	doc_278690626912_item	2309198	et	4	main
muidugi	doc_278690626912_item	2309199	et	4	main
see	doc_278690626912_item	2309201	et	3	main
kõik	doc_278690626912_item	2309200	et	4	main
on	doc_278690626912_item	2309202	et	4	main
suur	doc_278690626912_item	2309203	et	3	main
tänu	doc_278690626912_item	2309204	et	4	main
laulupeole	doc_278690626912_item	2309205	et	4	main
ehkki	doc_278690626912_item	2309206	et	3	main
mitte	doc_278690626912_item	2309207	et	3	main
ainult	doc_278690626912_item	2309208	et	4	main
aga	doc_278690626912_item	2309209	et	3	main
praegu	doc_278690626912_item	2309210	et	3	main
ka	doc_278690626912_item	2309211	et	3	main
mitte	doc_278690626912_item	2309212	et	3	main
sellest	doc_278690626912_item	2309213	et	4	main
veedad	doc_278690626912_item	2309160	et	3	main
aga	doc_278690626912_item	2309162	et	3	main
võimalus	doc_278690626912_item	2309171	et	3	main
uue	doc_278690626912_item	2309173	et	3	main
ja	doc_278690626912_item	2309175	et	3	main
mitte	doc_278690626912_item	2309177	et	3	main
emakeeles	doc_278690626912_item	2309179	et	4	main
aga	doc_278690626912_item	2309180	et	3	main
ka	doc_278690626912_item	2309181	et	3	main
soome-	doc_278690626912_item	2309182	et	3	main
olen	doc_278690626912_item	2309189	et	3	main
keele	doc_278690626916_item	2309831	et	4	main
kui	doc_278690626916_item	2309832	et	3	main
teise	doc_278690626916_item	2309833	et	4	main
eestlastest	doc_278690626916_item	2309842	et	4	main
350	doc_278690626916_item	2309847	et	2	main
üldistav	doc_278690626916_item	2309855	et	4	main
tuginema	doc_278690626916_item	2309856	et	3	main
loengus	doc_278690626916_item	2309857	et	3	main
ja	doc_278690626916_item	2309858	et	3	main
väiteid	doc_278690626916_item	2309862	et	4	main
järel	doc_278690626916_item	2309870	et	4	main
koguneb	doc_278690626916_item	2309871	et	3	main
üle	doc_278690626916_item	2309873	et	3	main
tuhande	doc_278690626916_item	2309875	et	3	main
kõigist	doc_278690626916_item	2309877	et	4	main
maa	doc_278690626916_item	2309879	et	4	main
tantsupidu	doc_278690626916_item	2309885	et	4	main
on	doc_278690626916_item	2309886	et	4	main
puhkpilliorkestrit	doc_278690626916_item	2309922	et	3	main
on	doc_278690626916_item	2309924	et	4	main
muutunud	doc_278690626916_item	2309928	et	4	main
vanal	doc_278690626916_item	2309931	et	3	main
keele	doc_278690626916_item	2309834	et	4	main
test	doc_278690626916_item	2309835	et	3	main
kirjutamine	doc_278690626916_item	2309836	et	4	main
essee	doc_278690626916_item	2309844	et	4	main
sõna	doc_278690626916_item	2309848	et	4	main
peab	doc_278690626916_item	2309850	et	4	main
on	doc_278690626916_item	2309863	et	4	main
soovitatav	doc_278690626916_item	2309864	et	4	main
iga	doc_278690626916_item	2309867	et	4	main
viie	doc_278690626916_item	2309868	et	3	main
aasta	doc_278690626916_item	2309869	et	4	main
inimesi	doc_278690626916_item	2309876	et	4	main
sümbol	doc_278690626916_item	2309891	et	3	main
rahvas	doc_278690626916_item	2309934	et	4	main
laulupidu	doc_278690626916_item	2309940	et	4	main
kooriga	doc_278690626916_item	2309956	et	4	main
laulda	doc_278690626916_item	2309971	et	4	main
kõik	doc_278690626916_item	2309972	et	4	main
see	doc_278690626916_item	2309973	et	3	main
minule	doc_278690626916_item	2309975	et	3	main
ja	doc_278690626916_item	2309985	et	3	main
sama	doc_278690626916_item	2309986	et	4	main
viisi	doc_278690626916_item	2309987	et	4	main
laulud	doc_278690626916_item	2309990	et	3	main
kujunenud	doc_278690626916_item	2309994	et	4	main
sümboliteks	doc_278690626916_item	2309996	et	3	main
ja	doc_278690626916_item	2310001	et	3	main
tantsutraditsioonidele	doc_278690626916_item	2310023	et	3	main
laulu	doc_278690626916_item	2310026	et	4	main
tantsupeod	doc_278690626916_item	2310028	et	4	main
see	doc_278690626916_item	2310035	et	3	main
noored	doc_278690626916_item	2310047	et	3	main
vanad	doc_278690626916_item	2310049	et	3	main
on	doc_278690626916_item	2310054	et	4	main
kultuuri	doc_278690626916_item	2310057	et	4	main
seejärel	doc_278690626916_item	2310059	et	3	main
teevad	doc_278690626916_item	2310064	et	3	main
et	doc_278690626916_item	2310072	et	3	main
mis	doc_278690626916_item	2309840	et	4	main
teeb	doc_278690626916_item	2309841	et	3	main
laulurahva	doc_278690626916_item	2309843	et	3	main
analüüsiv	doc_278690626916_item	2309853	et	4	main
ja	doc_278690626916_item	2309854	et	3	main
esitatud	doc_278690626916_item	2309860	et	4	main
näidetega	doc_278690626916_item	2309866	et	3	main
nurkadest	doc_278690626916_item	2309880	et	3	main
miks	doc_278690626916_item	2309881	et	4	main
laulu-	doc_278690626916_item	2309883	et	4	main
ja	doc_278690626916_item	2309884	et	3	main
kurustest	doc_278690626916_item	2309894	et	4	main
pikkus	doc_278690626916_item	2309845	et	4	main
essee	doc_278690626916_item	2309849	et	4	main
olema	doc_278690626916_item	2309851	et	4	main
lugemistekstis	doc_278690626916_item	2309859	et	3	main
tallinnasse	doc_278690626916_item	2309872	et	3	main
saja	doc_278690626916_item	2309874	et	4	main
meie	doc_278690626916_item	2309878	et	4	main
sest	doc_278690626916_item	2309882	et	4	main
meie	doc_278690626916_item	2309887	et	4	main
järjepidavuse	doc_278690626916_item	2309890	et	4	main
eesti	doc_278690626916_item	2309892	et	4	main
ikkagi	doc_278690626916_item	2309925	et	4	main
ajal	doc_278690626916_item	2309932	et	4	main
kohe	doc_278690626916_item	2309938	et	4	main
laulupidu	doc_278690626916_item	2309939	et	4	main
on	doc_278690626916_item	2309943	et	4	main
kuhu	doc_278690626916_item	2309946	et	3	main
oma	doc_278690626916_item	2309955	et	4	main
ka	doc_278690626916_item	2309961	et	3	main
ise	doc_278690626916_item	2309962	et	4	main
see	doc_278690626916_item	2309964	et	3	main
oli	doc_278690626916_item	2309965	et	3	main
väga	doc_278690626916_item	2309966	et	3	main
põnev	doc_278690626916_item	2309967	et	3	main
koos	doc_278690626916_item	2309970	et	4	main
tunnet	doc_278690626916_item	2309977	et	3	main
lauldes	doc_278690626916_item	2309988	et	3	main
need	doc_278690626916_item	2309989	et	3	main
võitnud	doc_278690626916_item	2310003	et	4	main
kuuluvad	doc_278690626916_item	2310007	et	4	main
suulise	doc_278690626916_item	2310011	et	4	main
nimekirja	doc_278690626916_item	2310013	et	4	main
et	doc_278690626916_item	2310015	et	3	main
meie	doc_278690626916_item	2310030	et	4	main
kõigepealt	doc_278690626916_item	2310037	et	3	main
see	doc_278690626916_item	2310038	et	3	main
üheneb	doc_278690626916_item	2310041	et	4	main
osa	doc_278690626916_item	2310055	et	4	main
öelda	doc_278690626916_item	2310061	et	4	main
et	doc_278690626916_item	2310062	et	3	main
laulupeod	doc_278690626916_item	2310063	et	4	main
laulmine	doc_278690626916_item	2310067	et	4	main
tähelepanuväärne	doc_278690626916_item	2310069	et	3	main
arvan	doc_278690626916_item	2310071	et	3	main
väga	doc_278690626916_item	2310077	et	3	main
teeb	doc_278690626918_item	2310279	et	3	main
essee	doc_278690626918_item	2310287	et	4	main
essee	doc_278690626916_item	2309829	et	4	main
eesti	doc_278690626916_item	2309830	et	4	main
kirjutage	doc_278690626916_item	2309837	et	3	main
essee	doc_278690626916_item	2309838	et	4	main
teemal	doc_278690626916_item	2309839	et	3	main
300	doc_278690626916_item	2309846	et	2	main
arutlev	doc_278690626916_item	2309852	et	4	main
faktidele	doc_278690626916_item	2309861	et	3	main
illustreerida	doc_278690626916_item	2309865	et	3	main
ühtehoidmise	doc_278690626916_item	2309888	et	3	main
ja	doc_278690626916_item	2309889	et	3	main
ajaloo	doc_278690626916_item	2309893	et	4	main
mäletan	doc_278690626916_item	2309895	et	3	main
et	doc_278690626916_item	2309896	et	3	main
esimene	doc_278690626916_item	2309897	et	3	main
ülemaali	doc_278690626916_item	2309898	et	4	main
laulupeo	doc_278690626916_item	2309899	et	4	main
korraldamise	doc_278690626916_item	2309900	et	4	main
idee	doc_278690626916_item	2309901	et	4	main
ja	doc_278690626916_item	2309902	et	3	main
teostus	doc_278690626916_item	2309903	et	4	main
tuli	doc_278690626916_item	2309904	et	4	main
tartust	doc_278690626916_item	2309905	et	3	main
vanemuise	doc_278690626916_item	2309906	et	4	main
seltsist	doc_278690626916_item	2309907	et	4	main
eesotsas	doc_278690626916_item	2309908	et	4	main
johann	doc_278690626916_item	2309909	et	4	main
voldemar	doc_278690626916_item	2309910	et	4	main
jannseniga	doc_278690626916_item	2309911	et	4	main
suvel	doc_278690626916_item	2309912	et	3	main
1869	doc_278690626916_item	2309913	et	2	main
kogunesid	doc_278690626916_item	2309914	et	4	main
46	doc_278690626916_item	2309916	et	2	main
tartusse	doc_278690626916_item	2309915	et	3	main
822	doc_278690626916_item	2309918	et	2	main
ja	doc_278690626916_item	2309920	et	3	main
meeskoori	doc_278690626916_item	2309917	et	4	main
lauljaga	doc_278690626916_item	2309919	et	4	main
5	doc_278690626916_item	2309921	et	2	main
palju	doc_278690626916_item	2309926	et	4	main
aga	doc_278690626916_item	2309929	et	3	main
nagu	doc_278690626916_item	2309930	et	3	main
laul	doc_278690626916_item	2309936	et	4	main
tähendavad	doc_278690626916_item	2309937	et	4	main
minule	doc_278690626916_item	2309941	et	3	main
pidu	doc_278690626916_item	2309945	et	4	main
tullakse	doc_278690626916_item	2309947	et	3	main
selles	doc_278690626916_item	2309957	et	4	main
peos	doc_278690626916_item	2309958	et	4	main
andis	doc_278690626916_item	2309974	et	3	main
tekib	doc_278690626916_item	2309979	et	3	main
teistega	doc_278690626916_item	2309981	et	4	main
samu	doc_278690626916_item	2309983	et	3	main
aja	doc_278690626916_item	2309993	et	4	main
praegu	doc_278690626916_item	2309923	et	3	main
aastadega	doc_278690626916_item	2309927	et	4	main
sõnad	doc_278690626916_item	2309933	et	4	main
ja	doc_278690626916_item	2309935	et	3	main
kõigepealt	doc_278690626916_item	2309944	et	3	main
koos	doc_278690626916_item	2309948	et	4	main
perega	doc_278690626916_item	2309949	et	3	main
aga	doc_278690626916_item	2309950	et	3	main
mitu	doc_278690626916_item	2309951	et	4	main
aastat	doc_278690626916_item	2309952	et	3	main
tagasi	doc_278690626916_item	2309953	et	3	main
olin	doc_278690626916_item	2309954	et	3	main
see	doc_278690626916_item	2309942	et	3	main
võtnud	doc_278690626916_item	2309960	et	4	main
saime	doc_278690626916_item	2309969	et	3	main
ülendavat	doc_278690626916_item	2309976	et	4	main
üheskoos	doc_278690626916_item	2309982	et	3	main
läbi	doc_278690626916_item	2309992	et	4	main
rahvuslikeks	doc_278690626916_item	2309995	et	3	main
üldlaulu	doc_278690626916_item	2310000	et	4	main
laialdase	doc_278690626916_item	2310004	et	3	main
tähelepanu	doc_278690626916_item	2310005	et	4	main
ja	doc_278690626916_item	2310010	et	3	main
pärandi	doc_278690626916_item	2310012	et	3	main
on	doc_278690626916_item	2310017	et	4	main
suur	doc_278690626916_item	2310018	et	3	main
tunnustus	doc_278690626916_item	2310019	et	4	main
meie	doc_278690626916_item	2310020	et	4	main
minu	doc_278690626916_item	2310024	et	3	main
elus	doc_278690626916_item	2310031	et	4	main
asi	doc_278690626916_item	2310039	et	4	main
koos	doc_278690626916_item	2310052	et	4	main
eestlast	doc_278690626916_item	2310065	et	4	main
on	doc_278690626916_item	2310076	et	4	main
osa	doc_278690626916_item	2309959	et	4	main
tegelikult	doc_278690626916_item	2309963	et	4	main
et	doc_278690626916_item	2309968	et	3	main
mis	doc_278690626916_item	2309978	et	4	main
tuhande	doc_278690626916_item	2309980	et	3	main
sõnu	doc_278690626916_item	2309984	et	4	main
on	doc_278690626916_item	2309991	et	4	main
tänaseks	doc_278690626916_item	2309997	et	4	main
on	doc_278690626916_item	2309998	et	4	main
ja	doc_278690626916_item	2310006	et	3	main
vaimse	doc_278690626916_item	2310009	et	3	main
arvan	doc_278690626916_item	2310014	et	3	main
see	doc_278690626916_item	2310016	et	3	main
eesti	doc_278690626916_item	2309999	et	4	main
tantsupeod	doc_278690626916_item	2310002	et	4	main
unesco	doc_278690626916_item	2310008	et	4	main
laulu	doc_278690626916_item	2310021	et	4	main
mängivad	doc_278690626916_item	2310029	et	4	main
see	doc_278690626916_item	2310043	et	3	main
pidu	doc_278690626916_item	2310045	et	4	main
inimesed	doc_278690626916_item	2310050	et	3	main
see	doc_278690626916_item	2310053	et	3	main
on	doc_278690626916_item	2310068	et	4	main
kultuurinähtus	doc_278690626916_item	2310070	et	4	main
kultuurinähtus	doc_278690626916_item	2310073	et	4	main
meie	doc_278690626916_item	2310074	et	4	main
riigis	doc_278690626916_item	2310075	et	3	main
keele	doc_278690626918_item	2310269	et	4	main
kui	doc_278690626918_item	2310270	et	3	main
teise	doc_278690626918_item	2310271	et	4	main
eestlastest	doc_278690626918_item	2310280	et	4	main
essee	doc_278690626918_item	2310282	et	4	main
see	doc_278690626918_item	2310321	et	3	main
estlased	doc_278690626918_item	2310324	et	4	main
laulda	doc_278690626918_item	2310331	et	4	main
tehes	doc_278690626918_item	2310337	et	3	main
lauldi	doc_278690626918_item	2310339	et	3	main
aga	doc_278690626918_item	2310341	et	3	main
kohtusid	doc_278690626918_item	2310344	et	4	main
kus	doc_278690626918_item	2310348	et	3	main
nad	doc_278690626918_item	2310349	et	3	main
teame	doc_278690626918_item	2310356	et	3	main
neil	doc_278690626918_item	2310375	et	4	main
ja	doc_278690626918_item	2310392	et	3	main
eesotsas	doc_278690626918_item	2310397	et	4	main
eestis	doc_278690626918_item	2310401	et	3	main
ja	doc_278690626918_item	2310426	et	3	main
pealesunnitud	doc_278690626918_item	2310430	et	4	main
eestlaste	doc_278690626918_item	2310433	et	4	main
looming	doc_278690626918_item	2310434	et	3	main
koostab	doc_278690626918_item	2310435	et	3	main
laulavad	doc_278690626918_item	2310443	et	4	main
loodusest	doc_278690626918_item	2310444	et	4	main
kuid	doc_278690626918_item	2310453	et	4	main
nende	doc_278690626918_item	2310458	et	4	main
nendest	doc_278690626918_item	2310461	et	4	main
tallinna	doc_278690626918_item	2310469	et	4	main
lauluväljakule	doc_278690626918_item	2310470	et	3	main
aastat	doc_278690626918_item	2310475	et	3	main
ja	doc_278690626916_item	2310022	et	3	main
arvamusel	doc_278690626916_item	2310025	et	3	main
ja	doc_278690626916_item	2310027	et	3	main
väga	doc_278690626916_item	2310032	et	3	main
tähtsa	doc_278690626916_item	2310033	et	3	main
rolli	doc_278690626916_item	2310034	et	4	main
on	doc_278690626916_item	2310036	et	4	main
mis	doc_278690626916_item	2310040	et	4	main
inimest	doc_278690626916_item	2310042	et	3	main
on	doc_278690626916_item	2310044	et	4	main
kus	doc_278690626916_item	2310046	et	3	main
ja	doc_278690626916_item	2310048	et	3	main
on	doc_278690626916_item	2310051	et	4	main
meie	doc_278690626916_item	2310056	et	4	main
ajaloost	doc_278690626916_item	2310058	et	4	main
saan	doc_278690626916_item	2310060	et	4	main
laulurahva	doc_278690626916_item	2310066	et	3	main
suur	doc_278690626916_item	2310078	et	3	main
essee	doc_278690626918_item	2310267	et	4	main
kirjutamine	doc_278690626918_item	2310274	et	4	main
kirjutage	doc_278690626918_item	2310275	et	3	main
laulurahva	doc_278690626918_item	2310281	et	3	main
pikkus	doc_278690626918_item	2310283	et	4	main
300	doc_278690626918_item	2310284	et	2	main
350	doc_278690626918_item	2310285	et	2	main
peab	doc_278690626918_item	2310288	et	4	main
et	doc_278690626918_item	2310323	et	3	main
väga	doc_278690626918_item	2310326	et	3	main
tööd	doc_278690626918_item	2310336	et	4	main
õhtul	doc_278690626918_item	2310342	et	3	main
ja	doc_278690626918_item	2310345	et	3	main
suheldasid	doc_278690626918_item	2310352	et	4	main
omavahel	doc_278690626918_item	2310353	et	3	main
juba	doc_278690626918_item	2310355	et	3	main
et	doc_278690626918_item	2310357	et	3	main
laul	doc_278690626918_item	2310359	et	4	main
tekkis	doc_278690626918_item	2310360	et	3	main
kirikust	doc_278690626918_item	2310361	et	4	main
18	doc_278690626918_item	2310362	et	2	main
võimalus	doc_278690626918_item	2310377	et	3	main
1869	doc_278690626918_item	2310386	et	2	main
korraldamise	doc_278690626918_item	2310390	et	4	main
tuli	doc_278690626918_item	2310394	et	4	main
jannseniga	doc_278690626918_item	2310400	et	4	main
tekkis	doc_278690626918_item	2310406	et	3	main
repertuaari	doc_278690626918_item	2310421	et	4	main
kehtestati	doc_278690626918_item	2310423	et	3	main
reeglid	doc_278690626918_item	2310425	et	3	main
eepostest	doc_278690626918_item	2310440	et	3	main
ja	doc_278690626918_item	2310445	et	3	main
nendes	doc_278690626918_item	2310447	et	4	main
on	doc_278690626918_item	2310449	et	4	main
meeleolu	doc_278690626918_item	2310457	et	4	main
lauljad	doc_278690626918_item	2310468	et	4	main
keele	doc_278690626918_item	2310272	et	4	main
test	doc_278690626918_item	2310273	et	3	main
essee	doc_278690626918_item	2310276	et	4	main
teemal	doc_278690626918_item	2310277	et	3	main
olema	doc_278690626918_item	2310289	et	4	main
ja	doc_278690626918_item	2310292	et	3	main
hetk	doc_278690626918_item	2310322	et	3	main
sõbralik	doc_278690626918_item	2310327	et	3	main
ammu	doc_278690626918_item	2310333	et	4	main
nad	doc_278690626918_item	2310343	et	3	main
me	doc_278690626918_item	2310354	et	4	main
kus	doc_278690626918_item	2310374	et	3	main
ajaloolise	doc_278690626918_item	2310379	et	4	main
idee	doc_278690626918_item	2310391	et	4	main
olid	doc_278690626918_item	2310405	et	4	main
eesti	doc_278690626918_item	2310268	et	4	main
mis	doc_278690626918_item	2310278	et	4	main
sõna	doc_278690626918_item	2310286	et	4	main
arutlev	doc_278690626918_item	2310290	et	4	main
analüüsiv	doc_278690626918_item	2310291	et	4	main
üldistav	doc_278690626918_item	2310293	et	4	main
tuginema	doc_278690626918_item	2310294	et	3	main
loengus	doc_278690626918_item	2310295	et	3	main
ja	doc_278690626918_item	2310296	et	3	main
lugemistekstis	doc_278690626918_item	2310297	et	3	main
esitatud	doc_278690626918_item	2310298	et	4	main
faktidele	doc_278690626918_item	2310299	et	3	main
väiteid	doc_278690626918_item	2310300	et	4	main
on	doc_278690626918_item	2310301	et	4	main
soovitatav	doc_278690626918_item	2310302	et	4	main
illustreerida	doc_278690626918_item	2310303	et	3	main
näidetega	doc_278690626918_item	2310304	et	3	main
eestlased	doc_278690626918_item	2310306	et	3	main
maailmas	doc_278690626918_item	2310305	et	3	main
on	doc_278690626918_item	2310307	et	4	main
tuntud	doc_278690626918_item	2310308	et	4	main
nagu	doc_278690626918_item	2310309	et	3	main
laulurahva	doc_278690626918_item	2310310	et	3	main
kuid	doc_278690626918_item	2310311	et	4	main
mis	doc_278690626918_item	2310312	et	4	main
teeb	doc_278690626918_item	2310313	et	3	main
eestlastest	doc_278690626918_item	2310314	et	4	main
laulurahva	doc_278690626918_item	2310315	et	3	main
ma	doc_278690626918_item	2310316	et	3	main
arvan	doc_278690626918_item	2310317	et	3	main
et	doc_278690626918_item	2310318	et	3	main
väga	doc_278690626918_item	2310319	et	3	main
oluline	doc_278690626918_item	2310320	et	4	main
rahvus	doc_278690626918_item	2310328	et	3	main
nad	doc_278690626918_item	2310329	et	3	main
juba	doc_278690626918_item	2310332	et	3	main
mehed	doc_278690626918_item	2310338	et	3	main
korraldasid	doc_278690626918_item	2310346	et	4	main
laulsid	doc_278690626918_item	2310350	et	4	main
kuid	doc_278690626918_item	2310364	et	4	main
see	doc_278690626918_item	2310365	et	3	main
juhtus	doc_278690626918_item	2310366	et	3	main
helilooja	doc_278690626918_item	2310368	et	4	main
on	doc_278690626918_item	2310325	et	4	main
hakkati	doc_278690626918_item	2310330	et	3	main
naised	doc_278690626918_item	2310334	et	3	main
lauldi	doc_278690626918_item	2310335	et	3	main
põllul	doc_278690626918_item	2310340	et	3	main
üritused	doc_278690626918_item	2310347	et	4	main
tantsisid	doc_278690626918_item	2310351	et	4	main
eesti	doc_278690626918_item	2310358	et	4	main
sajandil	doc_278690626918_item	2310363	et	3	main
koos	doc_278690626918_item	2310367	et	4	main
oli	doc_278690626918_item	2310376	et	3	main
esineda	doc_278690626918_item	2310378	et	3	main
tähtsusega	doc_278690626918_item	2310380	et	4	main
sündmuseks	doc_278690626918_item	2310381	et	3	main
kujunes	doc_278690626918_item	2310382	et	3	main
esimene	doc_278690626918_item	2310383	et	3	main
ülemaaline	doc_278690626918_item	2310384	et	4	main
laulupidu	doc_278690626918_item	2310385	et	4	main
aastal	doc_278690626918_item	2310387	et	3	main
tartus	doc_278690626918_item	2310388	et	3	main
teostus	doc_278690626918_item	2310393	et	4	main
seltsist	doc_278690626918_item	2310396	et	4	main
johann	doc_278690626918_item	2310398	et	4	main
voldemar	doc_278690626918_item	2310399	et	4	main
koori	doc_278690626918_item	2310403	et	4	main
algusel	doc_278690626918_item	2310404	et	4	main
meeskoorid	doc_278690626918_item	2310408	et	4	main
aga	doc_278690626918_item	2310409	et	3	main
hiljem	doc_278690626918_item	2310410	et	3	main
tekkisid	doc_278690626918_item	2310411	et	4	main
naiskoorid	doc_278690626918_item	2310412	et	3	main
1933	doc_278690626918_item	2310413	et	2	main
aastal	doc_278690626918_item	2310414	et	3	main
ja	doc_278690626918_item	2310415	et	3	main
lastekoorid	doc_278690626918_item	2310416	et	3	main
1947	doc_278690626918_item	2310417	et	2	main
aastal	doc_278690626918_item	2310418	et	3	main
kahjuks	doc_278690626918_item	2310419	et	4	main
nõukogudeajal	doc_278690626918_item	2310420	et	3	main
tuli	doc_278690626918_item	2310428	et	4	main
folkloorist	doc_278690626918_item	2310436	et	4	main
ja	doc_278690626918_item	2310439	et	3	main
nad	doc_278690626918_item	2310441	et	3	main
momente	doc_278690626918_item	2310452	et	3	main
on	doc_278690626918_item	2310455	et	4	main
võimsus	doc_278690626918_item	2310459	et	4	main
laulurahva	doc_278690626918_item	2310462	et	3	main
aasta	doc_278690626918_item	2310464	et	4	main
juulis	doc_278690626918_item	2310465	et	3	main
laulupeole	doc_278690626918_item	2310471	et	4	main
et	doc_278690626918_item	2310472	et	3	main
abiga	doc_278690626918_item	2310369	et	3	main
eestlased	doc_278690626918_item	2310370	et	3	main
hakkasid	doc_278690626918_item	2310371	et	4	main
avanema	doc_278690626918_item	2310372	et	3	main
teatreid	doc_278690626918_item	2310373	et	3	main
mille	doc_278690626918_item	2310389	et	3	main
vanemuise	doc_278690626918_item	2310395	et	4	main
palju	doc_278690626918_item	2310402	et	4	main
ainult	doc_278690626918_item	2310407	et	4	main
osas	doc_278690626918_item	2310422	et	4	main
ranged	doc_278690626918_item	2310424	et	3	main
legentidest	doc_278690626918_item	2310438	et	4	main
palju	doc_278690626918_item	2310442	et	4	main
loomingutes	doc_278690626918_item	2310448	et	3	main
palju	doc_278690626918_item	2310450	et	4	main
rõõmsaid	doc_278690626918_item	2310451	et	3	main
1994	doc_278690626918_item	2310463	et	2	main
kogunesid	doc_278690626918_item	2310466	et	4	main
125	doc_278690626918_item	2310474	et	2	main
essee	doc_278690626920_item	2310730	et	4	main
test	doc_278690626920_item	2310736	et	3	main
essee	doc_278690626920_item	2310739	et	4	main
mis	doc_278690626920_item	2310741	et	4	main
arutlev	doc_278690626920_item	2310753	et	4	main
esitatud	doc_278690626920_item	2310761	et	4	main
faktidele	doc_278690626920_item	2310762	et	3	main
inimene	doc_278690626920_item	2310769	et	3	main
eestlasi	doc_278690626920_item	2310778	et	3	main
kultuuriga	doc_278690626920_item	2310780	et	4	main
laulupeol	doc_278690626920_item	2310821	et	4	main
ta	doc_278690626920_item	2310823	et	4	main
mäletab	doc_278690626920_item	2310824	et	3	main
ja	doc_278690626920_item	2310830	et	3	main
on	doc_278690626920_item	2310832	et	4	main
tähtis	doc_278690626920_item	2310834	et	4	main
seda	doc_278690626920_item	2310838	et	3	main
oma	doc_278690626920_item	2310842	et	4	main
laulupidu	doc_278690626920_item	2310847	et	4	main
laulud	doc_278690626920_item	2310851	et	3	main
rahvariietusega	doc_278690626920_item	2310859	et	3	main
elas	doc_278690626920_item	2310868	et	3	main
nii	doc_278690626920_item	2310871	et	3	main
juulis	doc_278690626920_item	2310881	et	3	main
erinevad	doc_278690626920_item	2310895	et	4	main
tuntused	doc_278690626920_item	2310896	et	4	main
peab	doc_278690626920_item	2310902	et	4	main
olla	doc_278690626920_item	2310909	et	3	main
laulurahva	doc_278690626920_item	2310911	et	3	main
laulda	doc_278690626918_item	2310427	et	4	main
palju	doc_278690626918_item	2310429	et	4	main
propagandistlikke	doc_278690626918_item	2310431	et	3	main
laule	doc_278690626918_item	2310432	et	4	main
muinasjuttudest	doc_278690626918_item	2310437	et	3	main
elust	doc_278690626918_item	2310446	et	3	main
ka	doc_278690626918_item	2310454	et	3	main
trageediline	doc_278690626918_item	2310456	et	4	main
teeb	doc_278690626918_item	2310460	et	3	main
tuhanded	doc_278690626918_item	2310467	et	3	main
tähistada	doc_278690626918_item	2310473	et	3	main
kestnud	doc_278690626918_item	2310476	et	4	main
laulupidude	doc_278690626918_item	2310477	et	4	main
traditsiooni	doc_278690626918_item	2310478	et	4	main
sel	doc_278690626918_item	2310479	et	3	main
suvel	doc_278690626918_item	2310480	et	3	main
korraldati	doc_278690626918_item	2310481	et	3	main
eesti	doc_278690626918_item	2310482	et	4	main
kahekümne	doc_278690626918_item	2310484	et	4	main
üldlaulupidu	doc_278690626918_item	2310483	et	4	main
teist	doc_278690626918_item	2310485	et	4	main
korda	doc_278690626918_item	2310486	et	4	main
ja	doc_278690626918_item	2310487	et	3	main
sedapuhku	doc_278690626918_item	2310488	et	3	main
erakorraliselt	doc_278690626918_item	2310489	et	4	main
kahes	doc_278690626918_item	2310490	et	4	main
linnas	doc_278690626918_item	2310491	et	4	main
tartus	doc_278690626918_item	2310492	et	3	main
ja	doc_278690626918_item	2310493	et	3	main
tallinnas	doc_278690626918_item	2310494	et	4	main
kui	doc_278690626920_item	2310733	et	3	main
kirjutamine	doc_278690626920_item	2310737	et	4	main
eestlastest	doc_278690626920_item	2310743	et	4	main
laulurahva	doc_278690626920_item	2310744	et	3	main
essee	doc_278690626920_item	2310745	et	4	main
pikkus	doc_278690626920_item	2310746	et	4	main
analüüsiv	doc_278690626920_item	2310754	et	4	main
ja	doc_278690626920_item	2310759	et	3	main
iga	doc_278690626920_item	2310768	et	4	main
oma	doc_278690626920_item	2310772	et	4	main
saab	doc_278690626920_item	2310776	et	3	main
võimalused	doc_278690626920_item	2310817	et	3	main
inimene	doc_278690626920_item	2310819	et	3	main
keele	doc_278690626920_item	2310735	et	4	main
teemal	doc_278690626920_item	2310740	et	3	main
teeb	doc_278690626920_item	2310742	et	3	main
essee	doc_278690626920_item	2310750	et	4	main
üldistav	doc_278690626920_item	2310756	et	4	main
lugemistekstis	doc_278690626920_item	2310760	et	3	main
väiteid	doc_278690626920_item	2310763	et	4	main
soovitatav	doc_278690626920_item	2310765	et	4	main
illustreerida	doc_278690626920_item	2310766	et	3	main
näidetega	doc_278690626920_item	2310767	et	3	main
teada	doc_278690626920_item	2310771	et	3	main
laulutraditsioon	doc_278690626920_item	2310775	et	3	main
oma	doc_278690626920_item	2310779	et	4	main
kui	doc_278690626920_item	2310781	et	3	main
kui	doc_278690626920_item	2310818	et	3	main
käib	doc_278690626920_item	2310820	et	3	main
kui	doc_278690626920_item	2310835	et	3	main
oma	doc_278690626920_item	2310844	et	4	main
natsionaalne	doc_278690626920_item	2310845	et	3	main
koos	doc_278690626920_item	2310876	et	4	main
abiga	doc_278690626920_item	2310878	et	3	main
lauljad	doc_278690626920_item	2310883	et	4	main
laulupeole	doc_278690626920_item	2310886	et	4	main
et	doc_278690626920_item	2310888	et	3	main
125	doc_278690626920_item	2310890	et	2	main
et	doc_278690626920_item	2310906	et	3	main
tahab	doc_278690626920_item	2310908	et	3	main
kui	doc_278690626921_item	2310915	et	3	main
kirjutamine	doc_278690626921_item	2310919	et	4	main
eesti	doc_278690626920_item	2310731	et	4	main
keele	doc_278690626920_item	2310732	et	4	main
kirjutage	doc_278690626920_item	2310738	et	3	main
300	doc_278690626920_item	2310747	et	2	main
350	doc_278690626920_item	2310748	et	2	main
sõna	doc_278690626920_item	2310749	et	4	main
ja	doc_278690626920_item	2310755	et	3	main
loengus	doc_278690626920_item	2310758	et	3	main
saab	doc_278690626920_item	2310770	et	3	main
eesti	doc_278690626920_item	2310774	et	4	main
tutvuda	doc_278690626920_item	2310777	et	3	main
oma	doc_278690626920_item	2310825	et	4	main
ja	doc_278690626920_item	2310828	et	3	main
väga	doc_278690626920_item	2310833	et	3	main
peab	doc_278690626920_item	2310840	et	4	main
ainult	doc_278690626920_item	2310850	et	4	main
peol	doc_278690626920_item	2310856	et	4	main
tutvub	doc_278690626920_item	2310858	et	3	main
laulude	doc_278690626920_item	2310860	et	3	main
abiga	doc_278690626920_item	2310862	et	3	main
inimene	doc_278690626920_item	2310864	et	3	main
paljum	doc_278690626920_item	2310866	et	4	main
teda	doc_278690626920_item	2310869	et	4	main
laulupeo	doc_278690626920_item	2310877	et	4	main
1994	doc_278690626920_item	2310879	et	2	main
aasta	doc_278690626920_item	2310880	et	4	main
kogunesid	doc_278690626920_item	2310887	et	4	main
kestnud	doc_278690626920_item	2310892	et	4	main
laulupidude	doc_278690626920_item	2310893	et	4	main
laulurahva	doc_278690626920_item	2310899	et	3	main
aga	doc_278690626920_item	2310900	et	3	main
teama	doc_278690626920_item	2310903	et	4	main
oma	doc_278690626920_item	2310904	et	4	main
ta	doc_278690626920_item	2310907	et	4	main
essee	doc_278690626921_item	2310912	et	4	main
teise	doc_278690626921_item	2310916	et	4	main
teemal	doc_278690626921_item	2310922	et	3	main
lugemistekstis	doc_278690626921_item	2310942	et	3	main
illustreerida	doc_278690626921_item	2310948	et	3	main
teeb	doc_278690626921_item	2310951	et	3	main
laulupidu	doc_278690626921_item	2310970	et	4	main
algas	doc_278690626921_item	2310971	et	3	main
kord	doc_278690626921_item	2310979	et	4	main
aastas	doc_278690626921_item	2310981	et	3	main
ka	doc_278690626921_item	2310983	et	3	main
rahvapidu	doc_278690626921_item	2310985	et	4	main
väga	doc_278690626921_item	2310995	et	3	main
kirjutage	doc_278690626922_item	2311006	et	3	main
teemal	doc_278690626922_item	2311008	et	3	main
teeb	doc_278690626922_item	2311010	et	3	main
essee	doc_278690626922_item	2311013	et	4	main
teise	doc_278690626920_item	2310734	et	4	main
peab	doc_278690626920_item	2310751	et	4	main
olema	doc_278690626920_item	2310752	et	4	main
tuginema	doc_278690626920_item	2310757	et	3	main
on	doc_278690626920_item	2310764	et	4	main
rahvakultuuri	doc_278690626920_item	2310773	et	4	main
ta	doc_278690626920_item	2310782	et	4	main
teab	doc_278690626920_item	2310783	et	3	main
midagi	doc_278690626920_item	2310784	et	4	main
oma	doc_278690626920_item	2310785	et	4	main
rahvakultuurist	doc_278690626920_item	2310786	et	3	main
siis	doc_278690626920_item	2310787	et	3	main
võib	doc_278690626920_item	2310788	et	3	main
olla	doc_278690626920_item	2310789	et	3	main
tahab	doc_278690626920_item	2310791	et	3	main
edasi	doc_278690626920_item	2310792	et	3	main
areneda	doc_278690626920_item	2310793	et	3	main
oma	doc_278690626920_item	2310794	et	4	main
ta	doc_278690626920_item	2310790	et	4	main
teadmised	doc_278690626920_item	2310795	et	4	main
osal	doc_278690626920_item	2310797	et	3	main
laulurahvas	doc_278690626920_item	2310798	et	4	main
on	doc_278690626920_item	2310799	et	4	main
ka	doc_278690626920_item	2310800	et	3	main
sellel	doc_278690626920_item	2310796	et	4	main
niisugune	doc_278690626920_item	2310801	et	3	main
teevad	doc_278690626920_item	2310803	et	3	main
eestlastest	doc_278690626920_item	2310804	et	4	main
laulupeod	doc_278690626920_item	2310802	et	4	main
laulurahva	doc_278690626920_item	2310805	et	3	main
laulupidadel	doc_278690626920_item	2310806	et	4	main
nad	doc_278690626920_item	2310807	et	3	main
tutvuvad	doc_278690626920_item	2310808	et	4	main
oma	doc_278690626920_item	2310809	et	4	main
rahvakultuuriga	doc_278690626920_item	2310810	et	4	main
rahva	doc_278690626920_item	2310811	et	3	main
laulmine	doc_278690626920_item	2310812	et	4	main
saab	doc_278690626920_item	2310813	et	3	main
suureneda	doc_278690626920_item	2310814	et	3	main
oma	doc_278690626920_item	2310815	et	4	main
kultuuri	doc_278690626920_item	2310816	et	4	main
siis	doc_278690626920_item	2310822	et	3	main
vanemate	doc_278690626920_item	2310826	et	4	main
kultuur	doc_278690626920_item	2310829	et	3	main
inimene	doc_278690626920_item	2310836	et	3	main
ta	doc_278690626920_item	2310839	et	4	main
teama	doc_278690626920_item	2310841	et	4	main
ajaloo	doc_278690626920_item	2310846	et	4	main
ole	doc_278690626920_item	2310849	et	4	main
laulmine	doc_278690626920_item	2310852	et	4	main
tähelepanuväärne	doc_278690626920_item	2310854	et	3	main
on	doc_278690626920_item	2310853	et	4	main
kultuurinähtus	doc_278690626920_item	2310855	et	4	main
traditsioonid	doc_278690626920_item	2310827	et	3	main
see	doc_278690626920_item	2310831	et	3	main
mäletab	doc_278690626920_item	2310837	et	3	main
ajaloo	doc_278690626920_item	2310843	et	4	main
ei	doc_278690626920_item	2310848	et	4	main
saab	doc_278690626920_item	2310863	et	3	main
teada	doc_278690626920_item	2310865	et	3	main
palju	doc_278690626920_item	2310872	et	4	main
eestlasid	doc_278690626920_item	2310873	et	4	main
tuhanded	doc_278690626920_item	2310882	et	3	main
traditsiooni	doc_278690626920_item	2310894	et	4	main
eestlastest	doc_278690626920_item	2310898	et	4	main
rahvakultuuri	doc_278690626920_item	2310905	et	4	main
keele	doc_278690626921_item	2310914	et	4	main
mis	doc_278690626921_item	2310923	et	4	main
laulurahva	doc_278690626921_item	2310926	et	3	main
pikkus	doc_278690626921_item	2310928	et	4	main
350	doc_278690626921_item	2310930	et	2	main
sõna	doc_278690626921_item	2310931	et	4	main
essee	doc_278690626921_item	2310932	et	4	main
analüüsiv	doc_278690626921_item	2310936	et	4	main
ja	doc_278690626921_item	2310937	et	3	main
esitatud	doc_278690626921_item	2310943	et	4	main
väiteid	doc_278690626921_item	2310945	et	4	main
mis	doc_278690626921_item	2310950	et	4	main
on	doc_278690626921_item	2310955	et	4	main
sugusastega	doc_278690626921_item	2310992	et	4	main
on	doc_278690626921_item	2310994	et	4	main
rõõmus	doc_278690626921_item	2310996	et	4	main
keele	doc_278690626922_item	2311000	et	4	main
teise	doc_278690626922_item	2311002	et	4	main
keele	doc_278690626922_item	2311003	et	4	main
test	doc_278690626922_item	2311004	et	3	main
kirjutamine	doc_278690626922_item	2311005	et	4	main
mis	doc_278690626922_item	2311009	et	4	main
350	doc_278690626922_item	2311016	et	2	main
arutlev	doc_278690626922_item	2311021	et	4	main
ja	doc_278690626922_item	2311023	et	3	main
illustreerida	doc_278690626922_item	2311034	et	3	main
näidetega	doc_278690626922_item	2311035	et	3	main
sulle	doc_278690626922_item	2311049	et	3	main
sotsiaalne	doc_278690626922_item	2311062	et	3	main
kujunenud	doc_278690626922_item	2311075	et	4	main
enam	doc_278690626922_item	2311076	et	4	main
lisaks	doc_278690626922_item	2311081	et	4	main
rahvapidu	doc_278690626922_item	2311086	et	4	main
kuhu	doc_278690626922_item	2311087	et	3	main
väga	doc_278690626922_item	2311096	et	3	main
tähtis	doc_278690626922_item	2311097	et	4	main
üsna	doc_278690626922_item	2311098	et	3	main
identiteeditunne	doc_278690626922_item	2311102	et	3	main
kultuur	doc_278690626922_item	2311104	et	3	main
mis	doc_278690626922_item	2311107	et	4	main
algselt	doc_278690626922_item	2311108	et	4	main
ta	doc_278690626920_item	2310857	et	4	main
iseloomu	doc_278690626920_item	2310861	et	4	main
kuidas	doc_278690626920_item	2310867	et	3	main
põlvkond	doc_278690626920_item	2310870	et	3	main
saadsid	doc_278690626920_item	2310874	et	4	main
olla	doc_278690626920_item	2310875	et	3	main
tallinna	doc_278690626920_item	2310884	et	4	main
lauluväljakule	doc_278690626920_item	2310885	et	3	main
tähistada	doc_278690626920_item	2310889	et	3	main
aastat	doc_278690626920_item	2310891	et	3	main
teedsid	doc_278690626920_item	2310897	et	4	main
eestlane	doc_278690626920_item	2310901	et	3	main
edasi	doc_278690626920_item	2310910	et	3	main
keele	doc_278690626921_item	2310917	et	4	main
test	doc_278690626921_item	2310918	et	3	main
eestlastest	doc_278690626921_item	2310925	et	4	main
peab	doc_278690626921_item	2310933	et	4	main
olema	doc_278690626921_item	2310934	et	4	main
üldistav	doc_278690626921_item	2310938	et	4	main
loengus	doc_278690626921_item	2310940	et	3	main
soovitatav	doc_278690626921_item	2310947	et	4	main
eestlastest	doc_278690626921_item	2310952	et	4	main
laulupidu	doc_278690626921_item	2310976	et	4	main
vies	doc_278690626921_item	2310980	et	4	main
sõpradega	doc_278690626921_item	2310990	et	3	main
perega	doc_278690626921_item	2310991	et	3	main
eestlased	doc_278690626921_item	2310993	et	3	main
eesti	doc_278690626922_item	2310999	et	4	main
kui	doc_278690626922_item	2311001	et	3	main
eestlastest	doc_278690626922_item	2311011	et	4	main
laulurahva	doc_278690626922_item	2311012	et	3	main
essee	doc_278690626922_item	2311018	et	4	main
olema	doc_278690626922_item	2311020	et	4	main
faktidele	doc_278690626922_item	2311030	et	3	main
on	doc_278690626922_item	2311032	et	4	main
soovitatav	doc_278690626922_item	2311033	et	4	main
mis	doc_278690626922_item	2311036	et	4	main
raske	doc_278690626922_item	2311043	et	4	main
küsimus	doc_278690626922_item	2311044	et	4	main
aga	doc_278690626922_item	2311045	et	3	main
ma	doc_278690626922_item	2311046	et	3	main
on	doc_278690626922_item	2311056	et	4	main
väljendusvahed	doc_278690626922_item	2311059	et	3	main
kultuurile	doc_278690626922_item	2311069	et	3	main
aastat	doc_278690626922_item	2311079	et	3	main
koos	doc_278690626922_item	2311089	et	4	main
perega	doc_278690626922_item	2311090	et	3	main
rahvuslik	doc_278690626922_item	2311101	et	3	main
rajatud	doc_278690626922_item	2311105	et	4	main
mida	doc_278690626922_item	2311112	et	4	main
on	doc_278690626922_item	2311113	et	4	main
eesmärgi	doc_278690626922_item	2311116	et	4	main
eesti	doc_278690626921_item	2310913	et	4	main
kirjutage	doc_278690626921_item	2310920	et	3	main
essee	doc_278690626921_item	2310921	et	4	main
300	doc_278690626921_item	2310929	et	2	main
arutlev	doc_278690626921_item	2310935	et	4	main
ja	doc_278690626921_item	2310941	et	3	main
on	doc_278690626921_item	2310946	et	4	main
laulurahva	doc_278690626921_item	2310953	et	3	main
üks	doc_278690626921_item	2310978	et	3	main
laulupidu	doc_278690626921_item	2310982	et	4	main
suur	doc_278690626921_item	2310984	et	3	main
seal	doc_278690626921_item	2310986	et	4	main
saab	doc_278690626921_item	2310987	et	3	main
tulla	doc_278690626921_item	2310988	et	3	main
koos	doc_278690626921_item	2310989	et	4	main
rahvast	doc_278690626921_item	2310997	et	4	main
sõna	doc_278690626922_item	2311017	et	4	main
peab	doc_278690626922_item	2311019	et	4	main
väiteid	doc_278690626922_item	2311031	et	4	main
laulurahva	doc_278690626922_item	2311039	et	3	main
see	doc_278690626922_item	2311040	et	3	main
väga	doc_278690626922_item	2311042	et	3	main
anna	doc_278690626922_item	2311048	et	4	main
vastu	doc_278690626922_item	2311050	et	3	main
kultuurinähtus	doc_278690626922_item	2311054	et	4	main
emotsionaalne	doc_278690626922_item	2311058	et	3	main
läänemeresoome	doc_278690626922_item	2311068	et	3	main
regivärsiline	doc_278690626922_item	2311071	et	4	main
mis	doc_278690626922_item	2311073	et	4	main
on	doc_278690626922_item	2311074	et	4	main
tuhat	doc_278690626922_item	2311078	et	4	main
on	doc_278690626922_item	2311082	et	4	main
mis	doc_278690626922_item	2311094	et	4	main
on	doc_278690626922_item	2311095	et	4	main
sageli	doc_278690626922_item	2311099	et	3	main
rakendatud	doc_278690626922_item	2311114	et	4	main
saavutamiseks	doc_278690626922_item	2311117	et	4	main
teeb	doc_278690626921_item	2310924	et	3	main
essee	doc_278690626921_item	2310927	et	4	main
tuginema	doc_278690626921_item	2310939	et	3	main
faktidele	doc_278690626921_item	2310944	et	3	main
näidetega	doc_278690626921_item	2310949	et	3	main
laul	doc_278690626921_item	2310954	et	4	main
esteetiline	doc_278690626921_item	2310956	et	3	main
ja	doc_278690626921_item	2310957	et	3	main
sotsiaalne	doc_278690626921_item	2310958	et	3	main
tegevus	doc_278690626921_item	2310959	et	4	main
vanal	doc_278690626921_item	2310960	et	3	main
ajal	doc_278690626921_item	2310961	et	4	main
laul	doc_278690626921_item	2310962	et	4	main
aitab	doc_278690626921_item	2310963	et	3	main
hea	doc_278690626921_item	2310964	et	4	main
ja	doc_278690626921_item	2310965	et	3	main
kiire	doc_278690626921_item	2310966	et	4	main
tööt	doc_278690626921_item	2310967	et	4	main
teha	doc_278690626921_item	2310968	et	3	main
esimene	doc_278690626921_item	2310969	et	3	main
1869	doc_278690626921_item	2310972	et	2	main
aastal	doc_278690626921_item	2310973	et	3	main
tartus	doc_278690626921_item	2310974	et	3	main
nüüd	doc_278690626921_item	2310975	et	4	main
toimub	doc_278690626921_item	2310977	et	3	main
essee	doc_278690626922_item	2310998	et	4	main
essee	doc_278690626922_item	2311007	et	4	main
pikkus	doc_278690626922_item	2311014	et	4	main
300	doc_278690626922_item	2311015	et	2	main
analüüsiv	doc_278690626922_item	2311022	et	4	main
loengus	doc_278690626922_item	2311026	et	3	main
lugemistekstis	doc_278690626922_item	2311028	et	3	main
eestlastest	doc_278690626922_item	2311038	et	4	main
võin	doc_278690626922_item	2311047	et	3	main
laulmine	doc_278690626922_item	2311051	et	4	main
tähelepanuväärne	doc_278690626922_item	2311053	et	3	main
see	doc_278690626922_item	2311055	et	3	main
ka	doc_278690626922_item	2311061	et	3	main
eesti	doc_278690626922_item	2311064	et	4	main
vanemat	doc_278690626922_item	2311065	et	4	main
rahvalaul	doc_278690626922_item	2311072	et	4	main
kui	doc_278690626922_item	2311077	et	3	main
tullakse	doc_278690626922_item	2311088	et	3	main
lootuses	doc_278690626922_item	2311091	et	4	main
on	doc_278690626922_item	2311100	et	4	main
ja	doc_278690626922_item	2311103	et	3	main
üldistav	doc_278690626922_item	2311024	et	4	main
tuginema	doc_278690626922_item	2311025	et	3	main
ja	doc_278690626922_item	2311027	et	3	main
esitatud	doc_278690626922_item	2311029	et	4	main
teeb	doc_278690626922_item	2311037	et	3	main
on	doc_278690626922_item	2311041	et	4	main
on	doc_278690626922_item	2311052	et	4	main
väga	doc_278690626922_item	2311057	et	3	main
aga	doc_278690626922_item	2311060	et	3	main
tegevus	doc_278690626922_item	2311063	et	4	main
laulutraditsiooni	doc_278690626922_item	2311066	et	4	main
esindab	doc_278690626922_item	2311067	et	3	main
iseloomulik	doc_278690626922_item	2311070	et	3	main
tagasi	doc_278690626922_item	2311080	et	3	main
laulupidu	doc_278690626922_item	2311083	et	4	main
ka	doc_278690626922_item	2311084	et	3	main
suur	doc_278690626922_item	2311085	et	3	main
kohata	doc_278690626922_item	2311092	et	4	main
sõpru	doc_278690626922_item	2311093	et	3	main
sümbolitele	doc_278690626922_item	2311106	et	3	main
pärinevad	doc_278690626922_item	2311109	et	4	main
folkloorist	doc_278690626922_item	2311110	et	4	main
ning	doc_278690626922_item	2311111	et	3	main
kindla	doc_278690626922_item	2311115	et	3	main
essee	doc_278690626930_item	2312150	et	4	main
laulurahva	doc_278690626930_item	2312155	et	3	main
lugemistekstis	doc_278690626930_item	2312171	et	3	main
soovitatav	doc_278690626930_item	2312176	et	4	main
näidetega	doc_278690626930_item	2312178	et	3	main
arvan	doc_278690626930_item	2312180	et	3	main
väga	doc_278690626930_item	2312217	et	3	main
essee	doc_278690626930_item	2312141	et	4	main
keele	doc_278690626930_item	2312143	et	4	main
teemal	doc_278690626930_item	2312151	et	3	main
essee	doc_278690626930_item	2312161	et	4	main
peab	doc_278690626930_item	2312162	et	4	main
olema	doc_278690626930_item	2312163	et	4	main
tuginema	doc_278690626930_item	2312168	et	3	main
sest	doc_278690626930_item	2312212	et	4	main
laulavad	doc_278690626930_item	2312214	et	4	main
väga	doc_278690626930_item	2312215	et	3	main
tegid	doc_278690626930_item	2312220	et	4	main
käsitöö	doc_278690626930_item	2312222	et	4	main
laulupidu	doc_278690626930_item	2312224	et	4	main
mida	doc_278690626930_item	2312240	et	4	main
oskavad	doc_278690626930_item	2312241	et	4	main
vabariigi	doc_278690626930_item	2312247	et	3	main
muutusid	doc_278690626930_item	2312253	et	4	main
1947	doc_278690626930_item	2312264	et	2	main
toimunud	doc_278690626930_item	2312266	et	4	main
üldlaulupeost	doc_278690626930_item	2312268	et	4	main
olid	doc_278690626930_item	2312269	et	4	main
tähistati	doc_278690626930_item	2312297	et	4	main
üldlaulupidude	doc_278690626930_item	2312299	et	4	main
hoidjaiks	doc_278690626930_item	2312308	et	4	main
nn	doc_278690626930_item	2312318	et	4	main
eelmisest	doc_278690626930_item	2312329	et	3	main
pärit	doc_278690626930_item	2312331	et	3	main
1994	doc_278690626930_item	2312334	et	2	main
teise	doc_278690626930_item	2312145	et	4	main
test	doc_278690626930_item	2312147	et	3	main
mis	doc_278690626930_item	2312152	et	4	main
essee	doc_278690626930_item	2312156	et	4	main
pikkus	doc_278690626930_item	2312157	et	4	main
300	doc_278690626930_item	2312158	et	2	main
350	doc_278690626930_item	2312159	et	2	main
arutlev	doc_278690626930_item	2312164	et	4	main
ja	doc_278690626930_item	2312170	et	3	main
esitatud	doc_278690626930_item	2312172	et	4	main
väiteid	doc_278690626930_item	2312174	et	4	main
on	doc_278690626930_item	2312175	et	4	main
seda	doc_278690626930_item	2312219	et	3	main
naised	doc_278690626930_item	2312221	et	3	main
üüritus	doc_278690626930_item	2312229	et	4	main
eestlasteks	doc_278690626930_item	2312230	et	4	main
sest	doc_278690626930_item	2312231	et	4	main
oma	doc_278690626930_item	2312236	et	4	main
oskusi	doc_278690626930_item	2312237	et	3	main
ja	doc_278690626930_item	2312238	et	3	main
vaadata	doc_278690626930_item	2312239	et	4	main
eesti	doc_278690626930_item	2312246	et	4	main
aastal	doc_278690626930_item	2312250	et	3	main
vabadussõda	doc_278690626930_item	2312252	et	4	main
laulupeod	doc_278690626930_item	2312254	et	4	main
muusika	doc_278690626930_item	2312255	et	4	main
kadriorus	doc_278690626930_item	2312259	et	3	main
aastal	doc_278690626930_item	2312296	et	3	main
100	doc_278690626930_item	2312300	et	2	main
kujunesid	doc_278690626930_item	2312304	et	4	main
identiteedi	doc_278690626930_item	2312307	et	4	main
samuti	doc_278690626930_item	2312309	et	3	main
sisaldas	doc_278690626930_item	2312310	et	3	main
1980ndate	doc_278690626930_item	2312311	et	4	main
lõpus	doc_278690626930_item	2312312	et	4	main
alanud	doc_278690626930_item	2312313	et	4	main
teise	doc_278690626930_item	2312319	et	4	main
regilaulu	doc_278690626930_item	2312325	et	4	main
esindas	doc_278690626930_item	2312328	et	3	main
isamaalisi	doc_278690626930_item	2312332	et	4	main
laulupeole	doc_278690626930_item	2312342	et	4	main
eesti	doc_278690626930_item	2312353	et	4	main
kahekümne	doc_278690626930_item	2312355	et	4	main
teist	doc_278690626930_item	2312356	et	4	main
tartus	doc_278690626930_item	2312363	et	3	main
põhimõtteliselt	doc_278690626930_item	2312375	et	4	main
sama	doc_278690626930_item	2312376	et	4	main
seepärast	doc_278690626930_item	2312377	et	3	main
teeb	doc_278690626930_item	2312153	et	3	main
eestlastest	doc_278690626930_item	2312154	et	4	main
analüüsiv	doc_278690626930_item	2312165	et	4	main
ja	doc_278690626930_item	2312166	et	3	main
loengus	doc_278690626930_item	2312169	et	3	main
faktidele	doc_278690626930_item	2312173	et	3	main
et	doc_278690626930_item	2312181	et	3	main
nad	doc_278690626930_item	2312213	et	3	main
ammu	doc_278690626930_item	2312216	et	4	main
eesti	doc_278690626930_item	2312142	et	4	main
kui	doc_278690626930_item	2312144	et	3	main
keele	doc_278690626930_item	2312146	et	4	main
kirjutamine	doc_278690626930_item	2312148	et	4	main
kirjutage	doc_278690626930_item	2312149	et	3	main
sõna	doc_278690626930_item	2312160	et	4	main
üldistav	doc_278690626930_item	2312167	et	4	main
illustreerida	doc_278690626930_item	2312177	et	3	main
ma	doc_278690626930_item	2312179	et	3	main
eestlased	doc_278690626930_item	2312182	et	3	main
on	doc_278690626930_item	2312183	et	4	main
laulurahva	doc_278690626930_item	2312184	et	3	main
sest	doc_278690626930_item	2312185	et	4	main
esimene	doc_278690626930_item	2312186	et	3	main
laulupidu	doc_278690626930_item	2312187	et	4	main
toimus	doc_278690626930_item	2312188	et	3	main
eestis	doc_278690626930_item	2312189	et	3	main
1869	doc_278690626930_item	2312191	et	2	main
tartus	doc_278690626930_item	2312190	et	3	main
aastal	doc_278690626930_item	2312192	et	3	main
ja	doc_278690626930_item	2312193	et	3	main
sellel	doc_278690626930_item	2312194	et	4	main
laulupeol	doc_278690626930_item	2312195	et	4	main
oli	doc_278690626930_item	2312196	et	3	main
palju	doc_278690626930_item	2312197	et	4	main
koore	doc_278690626930_item	2312198	et	4	main
tantsijaid	doc_278690626930_item	2312199	et	4	main
ja	doc_278690626930_item	2312200	et	3	main
kuulastajaid	doc_278690626930_item	2312201	et	4	main
see	doc_278690626930_item	2312202	et	3	main
sai	doc_278690626930_item	2312203	et	4	main
aluse	doc_278690626930_item	2312204	et	4	main
laulupidude	doc_278690626930_item	2312205	et	4	main
traditsiooniks	doc_278690626930_item	2312206	et	3	main
eestlased	doc_278690626930_item	2312207	et	3	main
ka	doc_278690626930_item	2312209	et	3	main
on	doc_278690626930_item	2312208	et	4	main
väga	doc_278690626930_item	2312210	et	3	main
musikaalseid	doc_278690626930_item	2312211	et	3	main
tihti	doc_278690626930_item	2312218	et	3	main
tähtis	doc_278690626930_item	2312228	et	4	main
võivad	doc_278690626930_item	2312234	et	4	main
pärast	doc_278690626930_item	2312245	et	4	main
1918	doc_278690626930_item	2312249	et	2	main
mis	doc_278690626930_item	2312257	et	4	main
praegusel	doc_278690626930_item	2312260	et	3	main
aastal	doc_278690626930_item	2312265	et	3	main
xii	doc_278690626930_item	2312267	et	4	main
aastapäeva	doc_278690626930_item	2312301	et	4	main
repertuaar	doc_278690626930_item	2312321	et	3	main
tugines	doc_278690626930_item	2312324	et	3	main
traditsioonile	doc_278690626930_item	2312326	et	3	main
lauljad	doc_278690626930_item	2312339	et	4	main
tallinna	doc_278690626930_item	2312340	et	4	main
lauluväljakule	doc_278690626930_item	2312341	et	3	main
aastat	doc_278690626930_item	2312346	et	3	main
kestnud	doc_278690626930_item	2312347	et	4	main
suvel	doc_278690626930_item	2312351	et	3	main
korda	doc_278690626930_item	2312357	et	4	main
ja	doc_278690626930_item	2312358	et	3	main
linnas	doc_278690626930_item	2312362	et	4	main
käsitleda	doc_278690626930_item	2312380	et	3	main
peab	doc_278690626931_item	2312422	et	4	main
loengus	doc_278690626931_item	2312429	et	3	main
näidetega	doc_278690626931_item	2312438	et	3	main
kõik	doc_278690626931_item	2312449	et	4	main
näitavad	doc_278690626931_item	2312452	et	4	main
on	doc_278690626931_item	2312456	et	4	main
töötasid	doc_278690626931_item	2312465	et	4	main
laulsid	doc_278690626931_item	2312474	et	4	main
eesti	doc_278690626931_item	2312493	et	4	main
rahvalaule	doc_278690626931_item	2312508	et	4	main
näiteks	doc_278690626931_item	2312509	et	4	main
mu	doc_278690626931_item	2312510	et	3	main
isamaa	doc_278690626931_item	2312511	et	4	main
ka	doc_278690626931_item	2312519	et	3	main
koored	doc_278690626931_item	2312528	et	3	main
1933	doc_278690626931_item	2312532	et	2	main
aastal	doc_278690626931_item	2312533	et	3	main
lisandusid	doc_278690626931_item	2312534	et	4	main
populaarsed	doc_278690626931_item	2312560	et	3	main
ka	doc_278690626931_item	2312585	et	3	main
rahvad	doc_278690626931_item	2312587	et	3	main
edasi	doc_278690626931_item	2312592	et	3	main
muusika	doc_278690626931_item	2312598	et	4	main
räp	doc_278690626931_item	2312605	et	4	main
kõik	doc_278690626931_item	2312607	et	4	main
nad	doc_278690626931_item	2312608	et	3	main
on	doc_278690626931_item	2312609	et	4	main
väga	doc_278690626931_item	2312610	et	3	main
populaarsed	doc_278690626931_item	2312611	et	3	main
tean	doc_278690626931_item	2312615	et	3	main
väga	doc_278690626930_item	2312227	et	3	main
suurüritusteks	doc_278690626930_item	2312256	et	3	main
1928	doc_278690626930_item	2312262	et	2	main
pidustused	doc_278690626930_item	2312270	et	3	main
nõukogude	doc_278690626930_item	2312271	et	3	main
tingimustes	doc_278690626930_item	2312273	et	3	main
kommunistliku	doc_278690626930_item	2312274	et	3	main
korra	doc_278690626930_item	2312272	et	4	main
partei	doc_278690626930_item	2312275	et	4	main
ja	doc_278690626930_item	2312276	et	3	main
valitsuse	doc_278690626930_item	2312277	et	4	main
range	doc_278690626930_item	2312278	et	4	main
kontrolli	doc_278690626930_item	2312279	et	4	main
ja	doc_278690626930_item	2312280	et	3	main
suunamise	doc_278690626930_item	2312281	et	4	main
all	doc_278690626930_item	2312282	et	3	main
repertuaari	doc_278690626930_item	2312283	et	4	main
osas	doc_278690626930_item	2312284	et	4	main
kehtestati	doc_278690626930_item	2312285	et	3	main
ranged	doc_278690626930_item	2312286	et	3	main
reeglid	doc_278690626930_item	2312287	et	3	main
ja	doc_278690626930_item	2312288	et	3	main
laulda	doc_278690626930_item	2312289	et	4	main
tuli	doc_278690626930_item	2312290	et	4	main
palju	doc_278690626930_item	2312291	et	4	main
pealesunnitud	doc_278690626930_item	2312292	et	4	main
propagandistlikke	doc_278690626930_item	2312293	et	3	main
laule	doc_278690626930_item	2312294	et	4	main
1969	doc_278690626930_item	2312295	et	2	main
tehes	doc_278690626930_item	2312223	et	3	main
see	doc_278690626930_item	2312225	et	3	main
on	doc_278690626930_item	2312226	et	4	main
seal	doc_278690626930_item	2312232	et	4	main
nad	doc_278690626930_item	2312233	et	3	main
näidata	doc_278690626930_item	2312235	et	4	main
nende	doc_278690626930_item	2312242	et	4	main
välismaalseid	doc_278690626930_item	2312243	et	4	main
külastajaid	doc_278690626930_item	2312244	et	4	main
loomist	doc_278690626930_item	2312248	et	4	main
ja	doc_278690626930_item	2312251	et	3	main
toimusid	doc_278690626930_item	2312258	et	4	main
lauluväljakul	doc_278690626930_item	2312261	et	3	main
alates	doc_278690626930_item	2312263	et	3	main
viinud	doc_278690626930_item	2312317	et	4	main
juubelilaulupeoga	doc_278690626930_item	2312298	et	4	main
nõukogudeaegsed	doc_278690626930_item	2312302	et	3	main
laulupeod	doc_278690626930_item	2312303	et	4	main
omamoodi	doc_278690626930_item	2312305	et	3	main
rahvusliku	doc_278690626930_item	2312306	et	3	main
ja	doc_278690626930_item	2312314	et	3	main
eesti	doc_278690626930_item	2312315	et	4	main
taasiseseisvumiseni	doc_278690626930_item	2312316	et	3	main
ärkamisaja	doc_278690626930_item	2312320	et	3	main
mis	doc_278690626930_item	2312323	et	4	main
või	doc_278690626930_item	2312327	et	4	main
sajandist	doc_278690626930_item	2312330	et	3	main
laule	doc_278690626930_item	2312333	et	4	main
aasta	doc_278690626930_item	2312335	et	4	main
juulis	doc_278690626930_item	2312336	et	3	main
kogunesid	doc_278690626930_item	2312337	et	4	main
et	doc_278690626930_item	2312343	et	3	main
ja	doc_278690626930_item	2312364	et	3	main
tallinnas	doc_278690626930_item	2312365	et	4	main
peo	doc_278690626930_item	2312367	et	4	main
ülesehitus	doc_278690626930_item	2312368	et	4	main
ja	doc_278690626930_item	2312369	et	3	main
sisu	doc_278690626930_item	2312370	et	4	main
oli	doc_278690626930_item	2312371	et	3	main
seotud	doc_278690626930_item	2312373	et	4	main
neid	doc_278690626930_item	2312379	et	4	main
peo	doc_278690626930_item	2312382	et	4	main
kahe	doc_278690626930_item	2312383	et	3	main
võib	doc_278690626930_item	2312386	et	3	main
ja	doc_278690626931_item	2312430	et	3	main
esitatud	doc_278690626931_item	2312432	et	4	main
faktidele	doc_278690626931_item	2312433	et	3	main
on	doc_278690626931_item	2312435	et	4	main
soovitatav	doc_278690626931_item	2312436	et	4	main
laulupeod	doc_278690626931_item	2312443	et	4	main
ja	doc_278690626931_item	2312445	et	3	main
erinevad	doc_278690626931_item	2312447	et	4	main
et	doc_278690626931_item	2312453	et	3	main
põllus	doc_278690626931_item	2312466	et	3	main
igal	doc_278690626931_item	2312476	et	3	main
eesti	doc_278690626931_item	2312485	et	4	main
kultuuris	doc_278690626931_item	2312486	et	3	main
on	doc_278690626931_item	2312487	et	4	main
hakkas	doc_278690626931_item	2312495	et	3	main
ja	doc_278690626931_item	2312515	et	3	main
kus	doc_278690626931_item	2312521	et	3	main
meeste	doc_278690626931_item	2312527	et	4	main
või	doc_278690626931_item	2312529	et	4	main
lastekoored	doc_278690626931_item	2312530	et	3	main
näiteks	doc_278690626931_item	2312531	et	4	main
tahan	doc_278690626931_item	2312538	et	3	main
ka	doc_278690626931_item	2312540	et	3	main
et	doc_278690626931_item	2312541	et	3	main
osavõtjate	doc_278690626931_item	2312545	et	3	main
ja	doc_278690626931_item	2312555	et	3	main
eesti	doc_278690626931_item	2312561	et	4	main
nii	doc_278690626931_item	2312582	et	3	main
noorte	doc_278690626931_item	2312597	et	3	main
nii	doc_278690626931_item	2312600	et	3	main
rock	doc_278690626931_item	2312602	et	4	main
kui	doc_278690626931_item	2312603	et	3	main
ka	doc_278690626931_item	2312604	et	3	main
gruppi	doc_278690626931_item	2312606	et	4	main
hulgas	doc_278690626931_item	2312614	et	4	main
ninja	doc_278690626931_item	2312618	et	4	main
grupp	doc_278690626931_item	2312623	et	3	main
et	doc_278690626931_item	2312634	et	3	main
eestlased	doc_278690626931_item	2312635	et	3	main
noored	doc_278690626931_item	2312645	et	3	main
laulda	doc_278690626931_item	2312655	et	4	main
ja	doc_278690626931_item	2312656	et	3	main
muusikat	doc_278690626930_item	2312322	et	3	main
tuhanded	doc_278690626930_item	2312338	et	3	main
125	doc_278690626930_item	2312345	et	2	main
laulupidude	doc_278690626930_item	2312348	et	4	main
traditsiooni	doc_278690626930_item	2312349	et	4	main
tol	doc_278690626930_item	2312350	et	3	main
korraldati	doc_278690626930_item	2312352	et	3	main
üldlaulupidu	doc_278690626930_item	2312354	et	4	main
erakorraliselt	doc_278690626930_item	2312360	et	4	main
omavahel	doc_278690626930_item	2312372	et	3	main
ja	doc_278690626930_item	2312374	et	3	main
ja	doc_278690626930_item	2312385	et	3	main
öelda	doc_278690626930_item	2312387	et	4	main
et	doc_278690626930_item	2312388	et	3	main
eestlased	doc_278690626930_item	2312389	et	3	main
on	doc_278690626930_item	2312390	et	4	main
laulurahva	doc_278690626930_item	2312391	et	3	main
sest	doc_278690626930_item	2312392	et	4	main
nendel	doc_278690626930_item	2312393	et	4	main
on	doc_278690626930_item	2312394	et	4	main
nii	doc_278690626930_item	2312395	et	3	main
kaua	doc_278690626930_item	2312396	et	3	main
see	doc_278690626930_item	2312398	et	3	main
laulupidude	doc_278690626930_item	2312399	et	4	main
elad	doc_278690626930_item	2312397	et	3	main
traditsioon	doc_278690626930_item	2312400	et	3	main
essee	doc_278690626931_item	2312401	et	4	main
eesti	doc_278690626931_item	2312402	et	4	main
keele	doc_278690626931_item	2312403	et	4	main
teise	doc_278690626931_item	2312405	et	4	main
keele	doc_278690626931_item	2312406	et	4	main
test	doc_278690626931_item	2312407	et	3	main
kui	doc_278690626931_item	2312404	et	3	main
kirjutamine	doc_278690626931_item	2312408	et	4	main
kirjutage	doc_278690626931_item	2312409	et	3	main
essee	doc_278690626931_item	2312410	et	4	main
teemal	doc_278690626931_item	2312411	et	3	main
mis	doc_278690626931_item	2312412	et	4	main
teeb	doc_278690626931_item	2312413	et	3	main
eestlastest	doc_278690626931_item	2312414	et	4	main
laulurahva	doc_278690626931_item	2312415	et	3	main
essee	doc_278690626931_item	2312416	et	4	main
300	doc_278690626931_item	2312418	et	2	main
pikkus	doc_278690626931_item	2312417	et	4	main
350	doc_278690626931_item	2312419	et	2	main
sõna	doc_278690626931_item	2312420	et	4	main
arutlev	doc_278690626931_item	2312424	et	4	main
üldistav	doc_278690626931_item	2312427	et	4	main
tähistada	doc_278690626930_item	2312344	et	3	main
sedapuhku	doc_278690626930_item	2312359	et	3	main
kahes	doc_278690626930_item	2312361	et	4	main
mõlema	doc_278690626930_item	2312366	et	3	main
võib	doc_278690626930_item	2312378	et	3	main
ühe	doc_278690626930_item	2312381	et	4	main
osana	doc_278690626930_item	2312384	et	3	main
essee	doc_278690626931_item	2312421	et	4	main
olema	doc_278690626931_item	2312423	et	4	main
analüüsiv	doc_278690626931_item	2312425	et	4	main
ja	doc_278690626931_item	2312426	et	3	main
väiteid	doc_278690626931_item	2312434	et	4	main
eestis	doc_278690626931_item	2312440	et	3	main
need	doc_278690626931_item	2312450	et	3	main
eesti	doc_278690626931_item	2312454	et	4	main
rahvas	doc_278690626931_item	2312455	et	4	main
laulurahvas	doc_278690626931_item	2312457	et	4	main
juba	doc_278690626931_item	2312458	et	3	main
ammu	doc_278690626931_item	2312459	et	4	main
muistsed	doc_278690626931_item	2312460	et	3	main
eestlased	doc_278690626931_item	2312461	et	3	main
laulsid	doc_278690626931_item	2312462	et	4	main
kui	doc_278690626931_item	2312463	et	3	main
nad	doc_278690626931_item	2312464	et	3	main
või	doc_278690626931_item	2312467	et	4	main
kodus	doc_278690626931_item	2312468	et	4	main
ka	doc_278690626931_item	2312475	et	3	main
nad	doc_278690626931_item	2312478	et	3	main
laulda	doc_278690626931_item	2312480	et	4	main
laulu	doc_278690626931_item	2312482	et	4	main
sest	doc_278690626931_item	2312483	et	4	main
et	doc_278690626931_item	2312484	et	3	main
saama	doc_278690626931_item	2312497	et	4	main
et	doc_278690626931_item	2312498	et	3	main
võib	doc_278690626931_item	2312500	et	3	main
elada	doc_278690626931_item	2312502	et	3	main
siis	doc_278690626931_item	2312503	et	3	main
inimesed	doc_278690626931_item	2312504	et	3	main
arm	doc_278690626931_item	2312514	et	3	main
lugemistekstis	doc_278690626931_item	2312431	et	3	main
tänapäeval	doc_278690626931_item	2312439	et	3	main
mitmesuguseid	doc_278690626931_item	2312442	et	3	main
tuginema	doc_278690626931_item	2312428	et	3	main
illustreerida	doc_278690626931_item	2312437	et	3	main
korraldatakse	doc_278690626931_item	2312441	et	3	main
laulufestivalid	doc_278690626931_item	2312444	et	3	main
lihtsalt	doc_278690626931_item	2312446	et	4	main
kui	doc_278690626931_item	2312469	et	3	main
olid	doc_278690626931_item	2312470	et	4	main
nad	doc_278690626931_item	2312473	et	3	main
rahvad	doc_278690626931_item	2312494	et	3	main
iseseisvalt	doc_278690626931_item	2312501	et	4	main
minu	doc_278690626931_item	2312513	et	3	main
edasi	doc_278690626931_item	2312517	et	3	main
laulupeod	doc_278690626931_item	2312520	et	4	main
mitmesugused	doc_278690626931_item	2312523	et	3	main
koored	doc_278690626931_item	2312526	et	3	main
ka	doc_278690626931_item	2312536	et	3	main
öelda	doc_278690626931_item	2312539	et	4	main
igal	doc_278690626931_item	2312542	et	3	main
suurenes	doc_278690626931_item	2312547	et	4	main
suurenes	doc_278690626931_item	2312549	et	4	main
laulupeod	doc_278690626931_item	2312553	et	4	main
olid	doc_278690626931_item	2312554	et	4	main
ka	doc_278690626931_item	2312557	et	3	main
on	doc_278690626931_item	2312558	et	4	main
rahvaste	doc_278690626931_item	2312562	et	4	main
kui	doc_278690626931_item	2312584	et	3	main
venelased	doc_278690626931_item	2312588	et	3	main
nii	doc_278690626931_item	2312591	et	3	main
palju	doc_278690626931_item	2312596	et	4	main
noorte	doc_278690626931_item	2312613	et	3	main
populaarne	doc_278690626931_item	2312621	et	3	main
on	doc_278690626931_item	2312631	et	4	main
ka	doc_278690626931_item	2312644	et	3	main
et	doc_278690626931_item	2312648	et	3	main
lauluga	doc_278690626931_item	2312659	et	4	main
kontserdid	doc_278690626931_item	2312448	et	3	main
üüritused	doc_278690626931_item	2312451	et	4	main
rahvapeod	doc_278690626931_item	2312471	et	4	main
siis	doc_278690626931_item	2312472	et	3	main
nädalal	doc_278690626931_item	2312477	et	3	main
võiksid	doc_278690626931_item	2312479	et	4	main
mitmesuguseid	doc_278690626931_item	2312481	et	3	main
neid	doc_278690626931_item	2312488	et	4	main
väga	doc_278690626931_item	2312489	et	3	main
palju	doc_278690626931_item	2312490	et	4	main
veel	doc_278690626931_item	2312491	et	4	main
kui	doc_278690626931_item	2312492	et	3	main
aru	doc_278690626931_item	2312496	et	4	main
ta	doc_278690626931_item	2312499	et	4	main
hakkasid	doc_278690626931_item	2312505	et	4	main
välja	doc_278690626931_item	2312506	et	4	main
mõelda	doc_278690626931_item	2312507	et	4	main
on	doc_278690626931_item	2312512	et	4	main
nii	doc_278690626931_item	2312516	et	3	main
korraldati	doc_278690626931_item	2312518	et	3	main
esinesid	doc_278690626931_item	2312522	et	4	main
koored	doc_278690626931_item	2312524	et	3	main
naiskoorid	doc_278690626931_item	2312537	et	3	main
aastal	doc_278690626931_item	2312543	et	3	main
ja	doc_278690626931_item	2312548	et	3	main
see	doc_278690626931_item	2312550	et	3	main
tähendab	doc_278690626931_item	2312551	et	3	main
et	doc_278690626931_item	2312552	et	3	main
väga	doc_278690626931_item	2312559	et	3	main
on	doc_278690626931_item	2312595	et	4	main
gruppi	doc_278690626931_item	2312599	et	4	main
pop	doc_278690626931_item	2312601	et	4	main
eest	doc_278690626931_item	2312612	et	4	main
vanilla	doc_278690626931_item	2312617	et	4	main
on	doc_278690626931_item	2312619	et	4	main
eesti	doc_278690626931_item	2312629	et	4	main
sellepärast	doc_278690626931_item	2312633	et	3	main
laulsid	doc_278690626931_item	2312636	et	4	main
ja	doc_278690626931_item	2312638	et	3	main
ja	doc_278690626931_item	2312646	et	3	main
loodan	doc_278690626931_item	2312647	et	3	main
armastavad	doc_278690626931_item	2312654	et	4	main
naiste	doc_278690626931_item	2312525	et	3	main
osavõtjana	doc_278690626931_item	2312535	et	3	main
laulupidude	doc_278690626931_item	2312544	et	4	main
arv	doc_278690626931_item	2312546	et	3	main
praegu	doc_278690626931_item	2312556	et	3	main
hulgas	doc_278690626931_item	2312563	et	4	main
tänapäeval	doc_278690626931_item	2312564	et	3	main
ka	doc_278690626931_item	2312565	et	3	main
on	doc_278690626931_item	2312566	et	4	main
olemas	doc_278690626931_item	2312567	et	4	main
mitmekesised	doc_278690626931_item	2312568	et	4	main
laulupeod	doc_278690626931_item	2312569	et	4	main
näiteks	doc_278690626931_item	2312570	et	4	main
laulupidu	doc_278690626931_item	2312571	et	4	main
mis	doc_278690626931_item	2312572	et	4	main
toimub	doc_278690626931_item	2312573	et	3	main
suvel	doc_278690626931_item	2312574	et	3	main
tallinnas	doc_278690626931_item	2312575	et	4	main
ja	doc_278690626931_item	2312576	et	3	main
kus	doc_278690626931_item	2312577	et	3	main
kogunes	doc_278690626931_item	2312578	et	3	main
väga	doc_278690626931_item	2312579	et	3	main
palju	doc_278690626931_item	2312580	et	4	main
rahva	doc_278690626931_item	2312581	et	3	main
eestlased	doc_278690626931_item	2312583	et	3	main
teised	doc_278690626931_item	2312586	et	4	main
valgevenelased	doc_278690626931_item	2312589	et	3	main
ja	doc_278690626931_item	2312590	et	3	main
veel	doc_278690626931_item	2312593	et	4	main
eestis	doc_278690626931_item	2312594	et	3	main
et	doc_278690626931_item	2312616	et	3	main
väga	doc_278690626931_item	2312620	et	3	main
rock	doc_278690626931_item	2312622	et	4	main
euroopas	doc_278690626931_item	2312624	et	3	main
tahan	doc_278690626931_item	2312626	et	3	main
rahvas	doc_278690626931_item	2312630	et	4	main
alati	doc_278690626931_item	2312637	et	4	main
laulsid	doc_278690626931_item	2312639	et	4	main
kõik	doc_278690626931_item	2312640	et	4	main
nii	doc_278690626931_item	2312641	et	3	main
kui	doc_278690626931_item	2312643	et	3	main
eestlased	doc_278690626931_item	2312653	et	3	main
elavad	doc_278690626931_item	2312657	et	4	main
kokkuvõttes	doc_278690626931_item	2312625	et	3	main
öelda	doc_278690626931_item	2312627	et	4	main
et	doc_278690626931_item	2312628	et	3	main
laulurahvas	doc_278690626931_item	2312632	et	4	main
vanad	doc_278690626931_item	2312642	et	3	main
maailmas	doc_278690626931_item	2312649	et	3	main
teavad	doc_278690626931_item	2312651	et	3	main
inimesed	doc_278690626931_item	2312650	et	3	main
et	doc_278690626931_item	2312652	et	3	main
koos	doc_278690626931_item	2312658	et	4	main
test	doc_278690626940_item	2314180	et	3	main
kirjutage	doc_278690626940_item	2314182	et	3	main
teemal	doc_278690626940_item	2314184	et	3	main
pikk	doc_278690626940_item	2314215	et	4	main
ei	doc_278690626940_item	2314222	et	4	main
soomad	doc_278690626940_item	2314229	et	4	main
ajalugu	doc_278690626940_item	2314232	et	4	main
tansid	doc_278690626940_item	2314241	et	4	main
me	doc_278690626940_item	2314242	et	4	main
folkloorist	doc_278690626940_item	2314247	et	4	main
et	doc_278690626940_item	2314250	et	3	main
ja	doc_278690626940_item	2314259	et	3	main
igal	doc_278690626940_item	2314263	et	3	main
kuidas	doc_278690626940_item	2314270	et	3	main
või	doc_278690626940_item	2314275	et	4	main
ka	doc_278690626940_item	2314281	et	3	main
rahvad	doc_278690626940_item	2314283	et	3	main
kõik	doc_278690626940_item	2314285	et	4	main
muusika	doc_278690626940_item	2314294	et	4	main
me	doc_278690626940_item	2314296	et	4	main
eesti	doc_278690626940_item	2314298	et	4	main
rohkem	doc_278690626940_item	2314327	et	4	main
lauldatakse	doc_278690626940_item	2314337	et	4	main
oli	doc_278690626940_item	2314343	et	3	main
et	doc_278690626940_item	2314350	et	3	main
ajaloost	doc_278690626940_item	2314355	et	4	main
eeslaulja	doc_278690626940_item	2314358	et	4	main
eeslaulja	doc_278690626940_item	2314361	et	4	main
koor	doc_278690626940_item	2314364	et	4	main
koordus	doc_278690626940_item	2314365	et	3	main
eesti	doc_278690626940_item	2314366	et	4	main
kannel	doc_278690626940_item	2314370	et	4	main
saame	doc_278690626940_item	2314373	et	4	main
võib	doc_278690626940_item	2314375	et	3	main
rahvalaulul	doc_278690626940_item	2314378	et	3	main
ma	doc_278690626940_item	2314379	et	3	main
et	doc_278690626940_item	2314381	et	3	main
erinevad	doc_278690626940_item	2314385	et	4	main
kuni	doc_278690626940_item	2314427	et	3	main
kakskümmendani	doc_278690626940_item	2314428	et	4	main
on	doc_278690626940_item	2314430	et	4	main
rohkem	doc_278690626940_item	2314438	et	4	main
praegu	doc_278690626940_item	2314441	et	3	main
erinevaid	doc_278690626940_item	2314443	et	4	main
trükki	doc_278690626940_item	2314444	et	4	main
praegu	doc_278690626940_item	2314445	et	3	main
ka	doc_278690626940_item	2314458	et	3	main
me	doc_278690626940_item	2314480	et	4	main
võime	doc_278690626940_item	2314481	et	4	main
näidata	doc_278690626940_item	2314486	et	4	main
ja	doc_278690626940_item	2314493	et	3	main
on	doc_278690626940_item	2314512	et	4	main
essee	doc_278690626940_item	2314174	et	4	main
eesti	doc_278690626940_item	2314175	et	4	main
kui	doc_278690626940_item	2314177	et	3	main
teise	doc_278690626940_item	2314178	et	4	main
väga	doc_278690626940_item	2314218	et	3	main
vabalt	doc_278690626940_item	2314224	et	4	main
oli	doc_278690626940_item	2314227	et	3	main
erinevad	doc_278690626940_item	2314236	et	4	main
jutustused	doc_278690626940_item	2314237	et	4	main
ja	doc_278690626940_item	2314240	et	3	main
teada	doc_278690626940_item	2314244	et	3	main
keele	doc_278690626940_item	2314179	et	4	main
ajalugu	doc_278690626940_item	2314217	et	4	main
palju	doc_278690626940_item	2314219	et	4	main
eestimaa	doc_278690626940_item	2314221	et	4	main
saksad	doc_278690626940_item	2314228	et	3	main
vened	doc_278690626940_item	2314230	et	3	main
meile	doc_278690626940_item	2314234	et	4	main
teid	doc_278690626940_item	2314235	et	4	main
teie	doc_278690626940_item	2314245	et	4	main
tean	doc_278690626940_item	2314249	et	3	main
rahvuslaulud	doc_278690626940_item	2314258	et	3	main
rahvus	doc_278690626940_item	2314260	et	3	main
üldse	doc_278690626940_item	2314262	et	3	main
vanad	doc_278690626940_item	2314277	et	3	main
muinastud	doc_278690626940_item	2314278	et	4	main
ja	doc_278690626940_item	2314280	et	3	main
ja	doc_278690626940_item	2314291	et	3	main
laulame	doc_278690626940_item	2314297	et	4	main
ja	doc_278690626940_item	2314301	et	3	main
naised	doc_278690626940_item	2314328	et	3	main
ka	doc_278690626940_item	2314332	et	3	main
kõik	doc_278690626940_item	2314336	et	4	main
sind	doc_278690626940_item	2314339	et	4	main
kirikused	doc_278690626940_item	2314346	et	3	main
igal	doc_278690626940_item	2314351	et	3	main
regilaulud	doc_278690626940_item	2314356	et	3	main
vana	doc_278690626940_item	2314367	et	4	main
muusika	doc_278690626940_item	2314368	et	4	main
on	doc_278690626940_item	2314384	et	4	main
kirjutamine	doc_278690626940_item	2314181	et	4	main
essee	doc_278690626940_item	2314183	et	4	main
mis	doc_278690626940_item	2314185	et	4	main
teeb	doc_278690626940_item	2314186	et	3	main
eestlastest	doc_278690626940_item	2314187	et	4	main
laulurahva	doc_278690626940_item	2314188	et	3	main
essee	doc_278690626940_item	2314189	et	4	main
pikkus	doc_278690626940_item	2314190	et	4	main
300	doc_278690626940_item	2314191	et	2	main
350	doc_278690626940_item	2314192	et	2	main
sõna	doc_278690626940_item	2314193	et	4	main
essee	doc_278690626940_item	2314194	et	4	main
peab	doc_278690626940_item	2314195	et	4	main
olema	doc_278690626940_item	2314196	et	4	main
arutlev	doc_278690626940_item	2314197	et	4	main
analüüsiv	doc_278690626940_item	2314198	et	4	main
ja	doc_278690626940_item	2314199	et	3	main
üldistav	doc_278690626940_item	2314200	et	4	main
tuginema	doc_278690626940_item	2314201	et	3	main
loengus	doc_278690626940_item	2314202	et	3	main
ja	doc_278690626940_item	2314203	et	3	main
lugemistekstis	doc_278690626940_item	2314204	et	3	main
esitatud	doc_278690626940_item	2314205	et	4	main
faktidele	doc_278690626940_item	2314206	et	3	main
väiteid	doc_278690626940_item	2314207	et	4	main
on	doc_278690626940_item	2314208	et	4	main
soovitatav	doc_278690626940_item	2314209	et	4	main
illustreerida	doc_278690626940_item	2314210	et	3	main
näidetega	doc_278690626940_item	2314211	et	3	main
eestlastel	doc_278690626940_item	2314212	et	4	main
on	doc_278690626940_item	2314213	et	4	main
suur	doc_278690626940_item	2314214	et	3	main
keele	doc_278690626940_item	2314176	et	4	main
aega	doc_278690626940_item	2314220	et	4	main
ole	doc_278690626940_item	2314223	et	4	main
eestil	doc_278690626940_item	2314226	et	3	main
saame	doc_278690626940_item	2314243	et	4	main
väga	doc_278690626940_item	2314252	et	3	main
tantsid	doc_278690626940_item	2314261	et	4	main
laulavad	doc_278690626940_item	2314272	et	4	main
laulud	doc_278690626940_item	2314274	et	3	main
jutustused	doc_278690626940_item	2314279	et	4	main
vanad	doc_278690626940_item	2314282	et	3	main
tansid	doc_278690626940_item	2314292	et	4	main
tundil	doc_278690626940_item	2314295	et	4	main
laulud	doc_278690626940_item	2314300	et	3	main
rahvus	doc_278690626940_item	2314216	et	3	main
maa	doc_278690626940_item	2314225	et	4	main
tema	doc_278690626940_item	2314231	et	4	main
näitab	doc_278690626940_item	2314233	et	3	main
muinasjutud	doc_278690626940_item	2314238	et	3	main
laulud	doc_278690626940_item	2314239	et	3	main
armastavad	doc_278690626940_item	2314253	et	4	main
ja	doc_278690626940_item	2314255	et	3	main
neid	doc_278690626940_item	2314257	et	4	main
ja	doc_278690626940_item	2314268	et	3	main
nad	doc_278690626940_item	2314271	et	3	main
vanad	doc_278690626940_item	2314273	et	3	main
tansid	doc_278690626940_item	2314284	et	4	main
me	doc_278690626940_item	2314286	et	4	main
koolis	doc_278690626940_item	2314293	et	4	main
õpetasime	doc_278690626940_item	2314302	et	3	main
vanad	doc_278690626940_item	2314303	et	3	main
tansid	doc_278690626940_item	2314304	et	4	main
minu	doc_278690626940_item	2314305	et	3	main
muusika	doc_278690626940_item	2314306	et	4	main
õpetaja	doc_278690626940_item	2314307	et	4	main
jutustas	doc_278690626940_item	2314308	et	3	main
meile	doc_278690626940_item	2314309	et	4	main
et	doc_278690626940_item	2314310	et	3	main
eesti	doc_278690626940_item	2314311	et	4	main
on	doc_278690626940_item	2314312	et	4	main
oma	doc_278690626940_item	2314313	et	4	main
rahva	doc_278690626940_item	2314314	et	3	main
laulud	doc_278690626940_item	2314315	et	3	main
ja	doc_278690626940_item	2314316	et	3	main
me	doc_278690626940_item	2314317	et	4	main
kuulame	doc_278690626940_item	2314318	et	4	main
neid	doc_278690626940_item	2314319	et	4	main
mulle	doc_278690626940_item	2314320	et	4	main
kõige	doc_278690626940_item	2314321	et	4	main
regi	doc_278690626940_item	2314323	et	4	main
laulavad	doc_278690626940_item	2314326	et	4	main
on	doc_278690626940_item	2314331	et	4	main
laulavad	doc_278690626940_item	2314333	et	4	main
seda	doc_278690626940_item	2314334	et	3	main
lauludes	doc_278690626940_item	2314335	et	3	main
üheksandil	doc_278690626940_item	2314341	et	4	main
väga	doc_278690626940_item	2314344	et	3	main
laulused	doc_278690626940_item	2314347	et	4	main
rääkida	doc_278690626940_item	2314349	et	3	main
laulul	doc_278690626940_item	2314353	et	3	main
ja	doc_278690626940_item	2314359	et	3	main
koor	doc_278690626940_item	2314360	et	4	main
ja	doc_278690626940_item	2314363	et	3	main
me	doc_278690626940_item	2314372	et	4	main
kuulama	doc_278690626940_item	2314374	et	3	main
igal	doc_278690626940_item	2314377	et	3	main
rahvalaulud	doc_278690626940_item	2314383	et	3	main
mõjub	doc_278690626940_item	2314421	et	3	main
ja	doc_278690626940_item	2314423	et	3	main
teised	doc_278690626940_item	2314424	et	4	main
rahvus	doc_278690626940_item	2314425	et	3	main
üheksal	doc_278690626940_item	2314426	et	3	main
kirjutavad	doc_278690626940_item	2314434	et	4	main
muusikat	doc_278690626940_item	2314436	et	3	main
oli	doc_278690626940_item	2314439	et	3	main
rohkem	doc_278690626940_item	2314442	et	4	main
on	doc_278690626940_item	2314457	et	4	main
erinev	doc_278690626940_item	2314478	et	4	main
ajagu	doc_278690626940_item	2314246	et	3	main
ma	doc_278690626940_item	2314248	et	3	main
eestlased	doc_278690626940_item	2314251	et	3	main
lauda	doc_278690626940_item	2314254	et	4	main
tansida	doc_278690626940_item	2314256	et	4	main
pidusel	doc_278690626940_item	2314264	et	4	main
me	doc_278690626940_item	2314265	et	4	main
võime	doc_278690626940_item	2314266	et	4	main
nägema	doc_278690626940_item	2314267	et	3	main
kuulama	doc_278690626940_item	2314269	et	3	main
jutustavad	doc_278690626940_item	2314276	et	4	main
teame	doc_278690626940_item	2314287	et	3	main
vanad	doc_278690626940_item	2314288	et	3	main
laulud	doc_278690626940_item	2314289	et	3	main
muinasjutud	doc_278690626940_item	2314290	et	3	main
vanad	doc_278690626940_item	2314299	et	3	main
laulud	doc_278690626940_item	2314324	et	3	main
seda	doc_278690626940_item	2314325	et	3	main
aga	doc_278690626940_item	2314329	et	3	main
ning	doc_278690626940_item	2314338	et	3	main
mind	doc_278690626940_item	2314340	et	4	main
populaarsed	doc_278690626940_item	2314345	et	3	main
või	doc_278690626940_item	2314348	et	4	main
rahvus	doc_278690626940_item	2314352	et	3	main
seda	doc_278690626940_item	2314371	et	3	main
olla	doc_278690626940_item	2314376	et	3	main
eestil	doc_278690626940_item	2314387	et	3	main
vene	doc_278690626940_item	2314422	et	4	main
palju	doc_278690626940_item	2314448	et	4	main
muusika	doc_278690626940_item	2314450	et	4	main
rokk	doc_278690626940_item	2314451	et	3	main
muusika	doc_278690626940_item	2314452	et	4	main
rap	doc_278690626940_item	2314453	et	4	main
ja	doc_278690626940_item	2314454	et	3	main
ja	doc_278690626940_item	2314485	et	3	main
mis	doc_278690626940_item	2314489	et	4	main
folkloor	doc_278690626940_item	2314492	et	4	main
õnnek	doc_278690626940_item	2314495	et	4	main
inimesed	doc_278690626940_item	2314497	et	3	main
ajalugu	doc_278690626940_item	2314500	et	4	main
ma	doc_278690626940_item	2314503	et	3	main
et	doc_278690626940_item	2314506	et	3	main
on	doc_278690626940_item	2314508	et	4	main
meeldinud	doc_278690626940_item	2314322	et	4	main
mehed	doc_278690626940_item	2314330	et	3	main
sajandil	doc_278690626940_item	2314342	et	3	main
laldakse	doc_278690626940_item	2314354	et	4	main
laulavad	doc_278690626940_item	2314357	et	4	main
algab	doc_278690626940_item	2314362	et	3	main
instrument	doc_278690626940_item	2314369	et	3	main
tean	doc_278690626940_item	2314380	et	3	main
eestis	doc_278690626940_item	2314382	et	3	main
lõuna	doc_278690626940_item	2314386	et	4	main
on	doc_278690626940_item	2314388	et	4	main
oma	doc_278690626940_item	2314389	et	4	main
põhi	doc_278690626940_item	2314390	et	3	main
eestil	doc_278690626940_item	2314391	et	3	main
on	doc_278690626940_item	2314392	et	4	main
ka	doc_278690626940_item	2314393	et	3	main
oma	doc_278690626940_item	2314394	et	4	main
ja	doc_278690626940_item	2314395	et	3	main
nii	doc_278690626940_item	2314396	et	3	main
edasi	doc_278690626940_item	2314397	et	3	main
veel	doc_278690626940_item	2314398	et	4	main
eestis	doc_278690626940_item	2314399	et	3	main
setul	doc_278690626940_item	2314400	et	3	main
vanalaulud	doc_278690626940_item	2314401	et	3	main
laulab	doc_278690626940_item	2314402	et	3	main
kui	doc_278690626940_item	2314403	et	3	main
mehed	doc_278690626940_item	2314404	et	3	main
kui	doc_278690626940_item	2314405	et	3	main
ka	doc_278690626940_item	2314406	et	3	main
aga	doc_278690626940_item	2314408	et	3	main
naised	doc_278690626940_item	2314407	et	3	main
kihnul	doc_278690626940_item	2314409	et	3	main
on	doc_278690626940_item	2314410	et	4	main
vastupidi	doc_278690626940_item	2314411	et	3	main
rohkem	doc_278690626940_item	2314412	et	4	main
naised	doc_278690626940_item	2314413	et	3	main
tänapäevaajal	doc_278690626940_item	2314414	et	3	main
rahvus	doc_278690626940_item	2314415	et	3	main
muusika	doc_278690626940_item	2314416	et	4	main
erinev	doc_278690626940_item	2314417	et	4	main
kui	doc_278690626940_item	2314418	et	3	main
pärast	doc_278690626940_item	2314419	et	4	main
seda	doc_278690626940_item	2314420	et	3	main
palju	doc_278690626940_item	2314431	et	4	main
kes	doc_278690626940_item	2314433	et	4	main
rahvus	doc_278690626940_item	2314435	et	3	main
pärast	doc_278690626940_item	2314437	et	4	main
väga	doc_278690626940_item	2314447	et	3	main
teised	doc_278690626940_item	2314455	et	4	main
sajandil	doc_278690626940_item	2314429	et	3	main
eriloojad	doc_278690626940_item	2314432	et	3	main
vokaal	doc_278690626940_item	2314440	et	3	main
on	doc_278690626940_item	2314446	et	4	main
pop	doc_278690626940_item	2314449	et	4	main
aga	doc_278690626940_item	2314456	et	3	main
rahvus	doc_278690626940_item	2314459	et	3	main
gruppid	doc_278690626940_item	2314460	et	4	main
laulavad	doc_278690626940_item	2314462	et	4	main
kes	doc_278690626940_item	2314461	et	4	main
rahvus	doc_278690626940_item	2314463	et	3	main
laulud	doc_278690626940_item	2314464	et	3	main
laulusel	doc_278690626940_item	2314465	et	4	main
mõjub	doc_278690626940_item	2314466	et	3	main
poliitika	doc_278690626940_item	2314467	et	4	main
linn	doc_278690626940_item	2314468	et	3	main
uudised	doc_278690626940_item	2314469	et	3	main
kõik	doc_278690626940_item	2314470	et	4	main
ja	doc_278690626940_item	2314471	et	3	main
praegu	doc_278690626940_item	2314472	et	3	main
on	doc_278690626940_item	2314473	et	4	main
rahvus	doc_278690626940_item	2314474	et	3	main
aga	doc_278690626940_item	2314476	et	3	main
teine	doc_278690626940_item	2314477	et	3	main
suvel	doc_278690626940_item	2314483	et	3	main
on	doc_278690626940_item	2314491	et	4	main
olen	doc_278690626940_item	2314494	et	3	main
neid	doc_278690626940_item	2314499	et	4	main
vaned	doc_278690626940_item	2314515	et	4	main
muusika	doc_278690626940_item	2314475	et	4	main
sõida	doc_278690626940_item	2314482	et	4	main
muusikat	doc_278690626940_item	2314488	et	3	main
põhiteema	doc_278690626940_item	2314490	et	4	main
et	doc_278690626940_item	2314496	et	3	main
mäletavad	doc_278690626940_item	2314498	et	4	main
tapsustada	doc_278690626940_item	2314505	et	4	main
eestlased	doc_278690626940_item	2314507	et	3	main
laulurahva	doc_278690626940_item	2314509	et	3	main
ja	doc_278690626940_item	2314510	et	3	main
ebamäletavad	doc_278690626940_item	2314513	et	3	main
täna	doc_278690626940_item	2314479	et	4	main
viljandisse	doc_278690626940_item	2314484	et	4	main
kuulata	doc_278690626940_item	2314487	et	4	main
ja	doc_278690626940_item	2314501	et	3	main
lõpetamiseks	doc_278690626940_item	2314502	et	4	main
võin	doc_278690626940_item	2314504	et	3	main
nad	doc_278690626940_item	2314511	et	3	main
nende	doc_278690626940_item	2314514	et	4	main
test	doc_278690626945_item	2315434	et	3	main
teemal	doc_278690626945_item	2315438	et	3	main
eestlastest	doc_278690626945_item	2315441	et	4	main
350	doc_278690626945_item	2315446	et	2	main
olema	doc_278690626945_item	2315450	et	4	main
on	doc_278690626945_item	2315462	et	4	main
soovitatav	doc_278690626945_item	2315463	et	4	main
illustreerida	doc_278690626945_item	2315464	et	3	main
laulurahva	doc_278690626945_item	2315469	et	3	main
kellega	doc_278690626945_item	2315506	et	3	main
kirikus	doc_278690626945_item	2315520	et	3	main
tol	doc_278690626945_item	2315521	et	3	main
ja	doc_278690626945_item	2315526	et	3	main
ilmusid	doc_278690626945_item	2315530	et	4	main
stiili	doc_278690626945_item	2315535	et	4	main
eesti	doc_278690626945_item	2315429	et	4	main
kui	doc_278690626945_item	2315431	et	3	main
kirjutage	doc_278690626945_item	2315436	et	3	main
mis	doc_278690626945_item	2315439	et	4	main
teeb	doc_278690626945_item	2315440	et	3	main
laulurahva	doc_278690626945_item	2315442	et	3	main
arutlev	doc_278690626945_item	2315451	et	4	main
üldistav	doc_278690626945_item	2315454	et	4	main
ja	doc_278690626945_item	2315457	et	3	main
näidetega	doc_278690626945_item	2315465	et	3	main
mis	doc_278690626945_item	2315466	et	4	main
laulmine	doc_278690626945_item	2315470	et	4	main
emotsionaalne	doc_278690626945_item	2315474	et	3	main
naised	doc_278690626945_item	2315477	et	3	main
ja	doc_278690626945_item	2315509	et	3	main
kirjutamine	doc_278690626945_item	2315435	et	4	main
essee	doc_278690626945_item	2315437	et	4	main
essee	doc_278690626945_item	2315443	et	4	main
sõna	doc_278690626945_item	2315447	et	4	main
ja	doc_278690626945_item	2315453	et	3	main
loengus	doc_278690626945_item	2315456	et	3	main
esitatud	doc_278690626945_item	2315459	et	4	main
ajal	doc_278690626945_item	2315473	et	4	main
varem	doc_278690626945_item	2315476	et	4	main
oled	doc_278690626945_item	2315508	et	3	main
19	doc_278690626945_item	2315528	et	2	main
hakkavad	doc_278690626945_item	2315533	et	4	main
neid	doc_278690626945_item	2315537	et	4	main
sajandi	doc_278690626945_item	2315545	et	3	main
seotud	doc_278690626945_item	2315548	et	4	main
hakkati	doc_278690626945_item	2315552	et	3	main
ajal	doc_278690626945_item	2315558	et	4	main
keele	doc_278690626945_item	2315433	et	4	main
300	doc_278690626945_item	2315445	et	2	main
essee	doc_278690626945_item	2315448	et	4	main
teeb	doc_278690626945_item	2315467	et	3	main
oli	doc_278690626945_item	2315471	et	3	main
väljendusvahed	doc_278690626945_item	2315475	et	3	main
laulsid	doc_278690626945_item	2315478	et	4	main
sa	doc_278690626945_item	2315507	et	3	main
sa	doc_278690626945_item	2315511	et	3	main
laulude	doc_278690626945_item	2315519	et	3	main
ajal	doc_278690626945_item	2315522	et	4	main
viltspilli	doc_278690626945_item	2315525	et	4	main
kannelit	doc_278690626945_item	2315527	et	4	main
sajandil	doc_278690626945_item	2315529	et	3	main
kes	doc_278690626945_item	2315532	et	4	main
ilmub	doc_278690626945_item	2315542	et	3	main
folkloori	doc_278690626945_item	2315551	et	4	main
aastal	doc_278690626945_item	2315564	et	3	main
lastekoorid	doc_278690626945_item	2315568	et	3	main
tähistati	doc_278690626945_item	2315579	et	4	main
võtasid	doc_278690626945_item	2315584	et	4	main
näiteks	doc_278690626945_item	2315589	et	4	main
populaarsed	doc_278690626945_item	2315601	et	3	main
eestlaste	doc_278690626945_item	2315606	et	4	main
essee	doc_278690626945_item	2315428	et	4	main
keele	doc_278690626945_item	2315430	et	4	main
teise	doc_278690626945_item	2315432	et	4	main
pikkus	doc_278690626945_item	2315444	et	4	main
peab	doc_278690626945_item	2315449	et	4	main
analüüsiv	doc_278690626945_item	2315452	et	4	main
tuginema	doc_278690626945_item	2315455	et	3	main
lugemistekstis	doc_278690626945_item	2315458	et	3	main
faktidele	doc_278690626945_item	2315460	et	3	main
väiteid	doc_278690626945_item	2315461	et	4	main
eestastest	doc_278690626945_item	2315468	et	4	main
igal	doc_278690626945_item	2315472	et	3	main
rohkem	doc_278690626945_item	2315479	et	4	main
kui	doc_278690626945_item	2315480	et	3	main
mehed	doc_278690626945_item	2315481	et	3	main
sellepärast	doc_278690626945_item	2315482	et	3	main
et	doc_278690626945_item	2315483	et	3	main
mehed	doc_278690626945_item	2315484	et	3	main
käisid	doc_278690626945_item	2315485	et	4	main
merel	doc_278690626945_item	2315486	et	3	main
aga	doc_278690626945_item	2315487	et	3	main
kui	doc_278690626945_item	2315488	et	3	main
nad	doc_278690626945_item	2315489	et	3	main
hakkasid	doc_278690626945_item	2315490	et	4	main
laulma	doc_278690626945_item	2315491	et	3	main
siis	doc_278690626945_item	2315492	et	3	main
see	doc_278690626945_item	2315493	et	3	main
toimus	doc_278690626945_item	2315494	et	3	main
pulmal	doc_278690626945_item	2315495	et	3	main
jutustasid	doc_278690626945_item	2315497	et	4	main
muinasjuttu	doc_278690626945_item	2315498	et	4	main
naised	doc_278690626945_item	2315496	et	3	main
oma	doc_278690626945_item	2315499	et	4	main
lastele	doc_278690626945_item	2315500	et	4	main
kes	doc_278690626945_item	2315501	et	4	main
mida	doc_278690626945_item	2315502	et	4	main
laulis	doc_278690626945_item	2315503	et	4	main
sõltus	doc_278690626945_item	2315504	et	4	main
sellest	doc_278690626945_item	2315505	et	4	main
miks	doc_278690626945_item	2315510	et	4	main
selles	doc_278690626945_item	2315512	et	4	main
kohas	doc_278690626945_item	2315513	et	4	main
18	doc_278690626945_item	2315514	et	2	main
sajandil	doc_278690626945_item	2315515	et	3	main
hakkati	doc_278690626945_item	2315516	et	3	main
laulma	doc_278690626945_item	2315517	et	3	main
vaimulike	doc_278690626945_item	2315518	et	3	main
hakkati	doc_278690626945_item	2315523	et	3	main
heliloojad	doc_278690626945_item	2315531	et	3	main
muusika	doc_278690626945_item	2315538	et	4	main
kasutati	doc_278690626945_item	2315539	et	4	main
filmides	doc_278690626945_item	2315540	et	4	main
19	doc_278690626945_item	2315544	et	2	main
rahvamuusika	doc_278690626945_item	2315554	et	4	main
sellel	doc_278690626945_item	2315557	et	4	main
1933	doc_278690626945_item	2315563	et	2	main
lisama	doc_278690626945_item	2315566	et	3	main
poistekoorid	doc_278690626945_item	2315569	et	3	main
palju	doc_278690626945_item	2315572	et	4	main
lauljaid	doc_278690626945_item	2315573	et	4	main
ja	doc_278690626945_item	2315581	et	3	main
palju	doc_278690626945_item	2315586	et	4	main
orkestreid	doc_278690626945_item	2315587	et	3	main
naiskoorid	doc_278690626945_item	2315590	et	3	main
olid	doc_278690626945_item	2315599	et	4	main
juba	doc_278690626945_item	2315600	et	3	main
hulgas	doc_278690626945_item	2315607	et	4	main
me	doc_278690626945_item	2315611	et	4	main
kasutama	doc_278690626945_item	2315524	et	3	main
muusika	doc_278690626945_item	2315534	et	4	main
hiljem	doc_278690626945_item	2315541	et	3	main
ärkamisega	doc_278690626945_item	2315549	et	4	main
levima	doc_278690626945_item	2315553	et	3	main
tantsu	doc_278690626945_item	2315556	et	4	main
rahvamuusika	doc_278690626945_item	2315559	et	4	main
stabiliseeritud	doc_278690626945_item	2315561	et	4	main
aasta	doc_278690626945_item	2315571	et	4	main
kogunesid	doc_278690626945_item	2315574	et	4	main
lauluväljakule	doc_278690626945_item	2315576	et	3	main
tartus	doc_278690626945_item	2315580	et	3	main
seal	doc_278690626945_item	2315583	et	4	main
osa	doc_278690626945_item	2315585	et	4	main
lastekoorid	doc_278690626945_item	2315592	et	3	main
need	doc_278690626945_item	2315594	et	3	main
laulsid	doc_278690626945_item	2315596	et	4	main
laulu	doc_278690626945_item	2315597	et	4	main
mis	doc_278690626945_item	2315598	et	4	main
on	doc_278690626945_item	2315605	et	4	main
nagu	doc_278690626945_item	2315610	et	3	main
võime	doc_278690626945_item	2315612	et	4	main
näha	doc_278690626945_item	2315613	et	3	main
laul	doc_278690626945_item	2315614	et	4	main
on	doc_278690626945_item	2315615	et	4	main
väga	doc_278690626945_item	2315616	et	3	main
tähtis	doc_278690626945_item	2315617	et	4	main
eestlaste	doc_278690626945_item	2315618	et	4	main
jaoks	doc_278690626945_item	2315619	et	4	main
kõik	doc_278690626945_item	2315620	et	4	main
põhjused	doc_278690626945_item	2315622	et	3	main
näitavad	doc_278690626945_item	2315626	et	4	main
meile	doc_278690626945_item	2315627	et	4	main
teha	doc_278690626945_item	2315536	et	3	main
folkloor	doc_278690626945_item	2315543	et	4	main
muusika	doc_278690626945_item	2315546	et	4	main
on	doc_278690626945_item	2315547	et	4	main
pärast	doc_278690626945_item	2315550	et	4	main
esitama	doc_278690626945_item	2315555	et	3	main
oli	doc_278690626945_item	2315560	et	3	main
alates	doc_278690626945_item	2315562	et	3	main
tallinna	doc_278690626945_item	2315575	et	4	main
tallinnas	doc_278690626945_item	2315582	et	4	main
kooreid	doc_278690626945_item	2315588	et	4	main
kõige	doc_278690626945_item	2315608	et	4	main
tähtsam	doc_278690626945_item	2315609	et	4	main
mida	doc_278690626945_item	2315623	et	4	main
tõi	doc_278690626945_item	2315625	et	3	main
laulurahva	doc_278690626945_item	2315631	et	3	main
hakkati	doc_278690626945_item	2315565	et	3	main
naiskoorid	doc_278690626945_item	2315567	et	3	main
1994	doc_278690626945_item	2315570	et	2	main
laulupeole	doc_278690626945_item	2315577	et	4	main
üldlaulupidu	doc_278690626945_item	2315578	et	4	main
meeskoorid	doc_278690626945_item	2315591	et	4	main
poistekoorid	doc_278690626945_item	2315593	et	3	main
koorid	doc_278690626945_item	2315595	et	4	main
sada	doc_278690626945_item	2315602	et	4	main
aastat	doc_278690626945_item	2315603	et	3	main
koorilaul	doc_278690626945_item	2315604	et	4	main
need	doc_278690626945_item	2315621	et	3	main
ma	doc_278690626945_item	2315624	et	3	main
mis	doc_278690626945_item	2315628	et	4	main
teise	doc_278690626947_item	2315950	et	4	main
mis	doc_278690626947_item	2315957	et	4	main
lugemistekstis	doc_278690626947_item	2315976	et	3	main
soovitatav	doc_278690626947_item	2315981	et	4	main
illustreerida	doc_278690626947_item	2315982	et	3	main
näidetega	doc_278690626947_item	2315983	et	3	main
mis	doc_278690626947_item	2315984	et	4	main
on	doc_278690626947_item	2315990	et	4	main
ajadest	doc_278690626947_item	2315992	et	4	main
palju	doc_278690626947_item	2316029	et	4	main
ajad	doc_278690626947_item	2316040	et	4	main
säiletanud	doc_278690626947_item	2316049	et	4	main
me	doc_278690626947_item	2316053	et	4	main
vanemad	doc_278690626947_item	2316064	et	4	main
laulud	doc_278690626947_item	2316065	et	3	main
alustada	doc_278690626947_item	2316066	et	3	main
üle	doc_278690626947_item	2316082	et	3	main
kodutööd	doc_278690626947_item	2316085	et	4	main
lihtsalt	doc_278690626947_item	2316092	et	4	main
teeb	doc_278690626945_item	2315629	et	3	main
eestlastest	doc_278690626945_item	2315630	et	4	main
essee	doc_278690626947_item	2315946	et	4	main
essee	doc_278690626947_item	2315961	et	4	main
350	doc_278690626947_item	2315964	et	2	main
essee	doc_278690626947_item	2315966	et	4	main
peab	doc_278690626947_item	2315967	et	4	main
esitatud	doc_278690626947_item	2315977	et	4	main
eestlastest	doc_278690626947_item	2315986	et	4	main
eesti	doc_278690626947_item	2315988	et	4	main
ja	doc_278690626947_item	2315995	et	3	main
tantsimise	doc_278690626947_item	2316001	et	4	main
essee	doc_278690626947_item	2315955	et	4	main
teemal	doc_278690626947_item	2315956	et	3	main
teeb	doc_278690626947_item	2315958	et	3	main
pikkus	doc_278690626947_item	2315962	et	4	main
sõna	doc_278690626947_item	2315965	et	4	main
arutlev	doc_278690626947_item	2315969	et	4	main
faktidele	doc_278690626947_item	2315978	et	3	main
teeb	doc_278690626947_item	2315985	et	3	main
rahvas	doc_278690626947_item	2315989	et	4	main
eesti	doc_278690626947_item	2315997	et	4	main
laulmise	doc_278690626947_item	2315999	et	4	main
elasid	doc_278690626947_item	2316025	et	4	main
kui	doc_278690626947_item	2316041	et	3	main
vägi	doc_278690626947_item	2316047	et	3	main
hästi	doc_278690626947_item	2316048	et	3	main
et	doc_278690626947_item	2316050	et	3	main
need	doc_278690626947_item	2316062	et	3	main
teha	doc_278690626947_item	2316086	et	3	main
eesmärgil	doc_278690626947_item	2316089	et	3	main
sel	doc_278690626947_item	2316096	et	3	main
laulud	doc_278690626947_item	2316098	et	3	main
lihtsad	doc_278690626947_item	2316100	et	3	main
on	doc_278690626947_item	2316110	et	4	main
põhjus	doc_278690626947_item	2316112	et	4	main
laulurahvas	doc_278690626947_item	2316116	et	4	main
asi	doc_278690626947_item	2316117	et	4	main
vanasti	doc_278690626947_item	2316121	et	3	main
seetõttu	doc_278690626947_item	2316125	et	3	main
jaoks	doc_278690626947_item	2316132	et	4	main
suhtlemisviis	doc_278690626947_item	2316134	et	3	main
millesse	doc_278690626947_item	2316136	et	3	main
enamik	doc_278690626947_item	2316140	et	3	main
vanast	doc_278690626947_item	2316145	et	3	main
venekeeles	doc_278690626947_item	2316147	et	4	main
väljend	doc_278690626947_item	2316149	et	3	main
ehitada	doc_278690626947_item	2316152	et	3	main
sama	doc_278690626947_item	2316160	et	4	main
eesmärgi	doc_278690626947_item	2316161	et	4	main
teine	doc_278690626947_item	2316163	et	3	main
19	doc_278690626947_item	2316174	et	2	main
toimuma	doc_278690626947_item	2316206	et	3	main
laulupeod	doc_278690626947_item	2316207	et	4	main
eesmärgiks	doc_278690626947_item	2316208	et	3	main
oli	doc_278690626947_item	2316209	et	3	main
tunda	doc_278690626947_item	2316211	et	3	main
seda	doc_278690626947_item	2316216	et	3	main
näidata	doc_278690626947_item	2316218	et	4	main
sel	doc_278690626947_item	2316223	et	3	main
vormeeris	doc_278690626947_item	2316225	et	4	main
tõeline	doc_278690626947_item	2316226	et	4	main
eesti	doc_278690626947_item	2316227	et	4	main
et	doc_278690626947_item	2316237	et	3	main
rahvalaulul	doc_278690626947_item	2316248	et	3	main
on	doc_278690626947_item	2316249	et	4	main
eesti	doc_278690626947_item	2315947	et	4	main
keele	doc_278690626947_item	2315948	et	4	main
kui	doc_278690626947_item	2315949	et	3	main
kirjutage	doc_278690626947_item	2315954	et	3	main
laulurahva	doc_278690626947_item	2315960	et	3	main
300	doc_278690626947_item	2315963	et	2	main
olema	doc_278690626947_item	2315968	et	4	main
analüüsiv	doc_278690626947_item	2315970	et	4	main
ja	doc_278690626947_item	2315971	et	3	main
ja	doc_278690626947_item	2315975	et	3	main
laulurahva	doc_278690626947_item	2315987	et	3	main
vanadest	doc_278690626947_item	2315991	et	3	main
tuntud	doc_278690626947_item	2315993	et	4	main
rahva	doc_278690626947_item	2315998	et	3	main
ja	doc_278690626947_item	2316000	et	3	main
ajalugu	doc_278690626947_item	2316002	et	4	main
sai	doc_278690626947_item	2316003	et	4	main
oma	doc_278690626947_item	2316004	et	4	main
alguse	doc_278690626947_item	2316005	et	3	main
rohkem	doc_278690626947_item	2316006	et	4	main
kui	doc_278690626947_item	2316007	et	3	main
tuhat	doc_278690626947_item	2316008	et	4	main
aastat	doc_278690626947_item	2316009	et	3	main
tagasi	doc_278690626947_item	2316010	et	3	main
ajaloolised	doc_278690626947_item	2316011	et	4	main
allikad	doc_278690626947_item	2316012	et	3	main
ja	doc_278690626947_item	2316013	et	3	main
mitmesugused	doc_278690626947_item	2316014	et	3	main
dokumendid	doc_278690626947_item	2316015	et	3	main
näitavad	doc_278690626947_item	2316016	et	4	main
et	doc_278690626947_item	2316017	et	3	main
juba	doc_278690626947_item	2316018	et	3	main
muistsed	doc_278690626947_item	2316019	et	3	main
eestlased	doc_278690626947_item	2316020	et	3	main
on	doc_278690626947_item	2316031	et	4	main
eestlaste	doc_278690626947_item	2316032	et	4	main
vanad	doc_278690626947_item	2316039	et	3	main
ka	doc_278690626947_item	2316042	et	3	main
eesti	doc_278690626947_item	2316044	et	4	main
võime	doc_278690626947_item	2316054	et	4	main
miks	doc_278690626947_item	2316056	et	4	main
inimesed	doc_278690626947_item	2316057	et	3	main
tuleb	doc_278690626947_item	2316067	et	3	main
vaatama	doc_278690626947_item	2316083	et	3	main
selle	doc_278690626947_item	2316088	et	4	main
et	doc_278690626947_item	2316090	et	3	main
olnud	doc_278690626947_item	2316094	et	4	main
olid	doc_278690626947_item	2316099	et	4	main
ja	doc_278690626947_item	2316101	et	3	main
isegi	doc_278690626947_item	2316102	et	4	main
aga	doc_278690626947_item	2316104	et	3	main
rahvalaulmisele	doc_278690626947_item	2316109	et	3	main
eestlastest	doc_278690626947_item	2316114	et	4	main
sai	doc_278690626947_item	2316115	et	4	main
keele	doc_278690626947_item	2315951	et	4	main
test	doc_278690626947_item	2315952	et	3	main
kirjutamine	doc_278690626947_item	2315953	et	4	main
eestlastest	doc_278690626947_item	2315959	et	4	main
üldistav	doc_278690626947_item	2315972	et	4	main
tuginema	doc_278690626947_item	2315973	et	3	main
loengus	doc_278690626947_item	2315974	et	3	main
väiteid	doc_278690626947_item	2315979	et	4	main
on	doc_278690626947_item	2315980	et	4	main
laulurahvana	doc_278690626947_item	2315994	et	3	main
tõesti	doc_278690626947_item	2315996	et	3	main
mis	doc_278690626947_item	2316021	et	4	main
end	doc_278690626947_item	2316023	et	4	main
nende	doc_278690626947_item	2316026	et	4	main
lauldes	doc_278690626947_item	2316028	et	3	main
laulmine	doc_278690626947_item	2316030	et	4	main
nii	doc_278690626947_item	2316038	et	3	main
uuemad	doc_278690626947_item	2316043	et	4	main
tänapäeval	doc_278690626947_item	2316052	et	3	main
olid	doc_278690626947_item	2316061	et	4	main
ja	doc_278690626947_item	2316084	et	3	main
neil	doc_278690626947_item	2316091	et	4	main
alguse	doc_278690626947_item	2316108	et	3	main
selles	doc_278690626947_item	2316119	et	4	main
nimetati	doc_278690626947_item	2316022	et	4	main
maarahvas	doc_278690626947_item	2316024	et	4	main
ellu	doc_278690626947_item	2316027	et	4	main
ajaloos	doc_278690626947_item	2316033	et	4	main
eriline	doc_278690626947_item	2316034	et	4	main
märk	doc_278690626947_item	2316035	et	3	main
mis	doc_278690626947_item	2316036	et	4	main
puudutab	doc_278690626947_item	2316037	et	3	main
laulutraditsioon	doc_278690626947_item	2316045	et	3	main
on	doc_278690626947_item	2316046	et	4	main
isegi	doc_278690626947_item	2316051	et	4	main
öelda	doc_278690626947_item	2316055	et	4	main
laulsid	doc_278690626947_item	2316058	et	4	main
ja	doc_278690626947_item	2316059	et	3	main
millised	doc_278690626947_item	2316060	et	3	main
kõige	doc_278690626947_item	2316063	et	4	main
sellest	doc_278690626947_item	2316068	et	4	main
et	doc_278690626947_item	2316069	et	3	main
lauldi	doc_278690626947_item	2316070	et	3	main
kõigepealt	doc_278690626947_item	2316071	et	3	main
tavalist	doc_278690626947_item	2316072	et	4	main
tööd	doc_278690626947_item	2316073	et	4	main
tegemises	doc_278690626947_item	2316074	et	4	main
näiteks	doc_278690626947_item	2316075	et	4	main
naised	doc_278690626947_item	2316076	et	3	main
kes	doc_278690626947_item	2316077	et	4	main
on	doc_278690626947_item	2316078	et	4	main
koju	doc_278690626947_item	2316079	et	3	main
jäänud	doc_278690626947_item	2316080	et	4	main
lapse	doc_278690626947_item	2316081	et	4	main
laulsid	doc_278690626947_item	2316087	et	4	main
ei	doc_278690626947_item	2316093	et	4	main
igav	doc_278690626947_item	2316095	et	3	main
primitiivsed	doc_278690626947_item	2316103	et	3	main
need	doc_278690626947_item	2316106	et	3	main
miks	doc_278690626947_item	2316113	et	4	main
on	doc_278690626947_item	2316118	et	4	main
olid	doc_278690626947_item	2316123	et	4	main
ja	doc_278690626947_item	2316127	et	3	main
nagu	doc_278690626947_item	2316133	et	3	main
sellega	doc_278690626947_item	2316135	et	3	main
on	doc_278690626947_item	2316148	et	4	main
tundub	doc_278690626947_item	2316156	et	3	main
uuem	doc_278690626947_item	2316166	et	4	main
väga	doc_278690626947_item	2316171	et	3	main
ajal	doc_278690626947_item	2316097	et	4	main
just	doc_278690626947_item	2316105	et	3	main
andsid	doc_278690626947_item	2316107	et	4	main
veel	doc_278690626947_item	2316111	et	4	main
paganad	doc_278690626947_item	2316124	et	3	main
laul	doc_278690626947_item	2316126	et	4	main
tants	doc_278690626947_item	2316128	et	3	main
võiks	doc_278690626947_item	2316129	et	4	main
olla	doc_278690626947_item	2316130	et	3	main
nende	doc_278690626947_item	2316131	et	4	main
aga	doc_278690626947_item	2316139	et	3	main
pärineb	doc_278690626947_item	2316144	et	3	main
olmest	doc_278690626947_item	2316146	et	4	main
laulsid	doc_278690626947_item	2316159	et	4	main
asi	doc_278690626947_item	2316164	et	4	main
eestlaste	doc_278690626947_item	2316168	et	4	main
ristimine	doc_278690626947_item	2316169	et	4	main
18	doc_278690626947_item	2316173	et	2	main
juba	doc_278690626947_item	2316210	et	3	main
ennast	doc_278690626947_item	2316212	et	4	main
rahvana	doc_278690626947_item	2316214	et	3	main
mulle	doc_278690626947_item	2316219	et	4	main
rahvalaule	doc_278690626947_item	2316228	et	4	main
laulurahvast	doc_278690626947_item	2316240	et	4	main
tänapäeval	doc_278690626947_item	2316247	et	3	main
osa	doc_278690626947_item	2316254	et	4	main
see	doc_278690626947_item	2316256	et	3	main
on	doc_278690626947_item	2316257	et	4	main
jaoks	doc_278690626947_item	2316265	et	4	main
ja	doc_278690626947_item	2316270	et	3	main
eestlased	doc_278690626947_item	2316273	et	3	main
jätasid	doc_278690626947_item	2316275	et	4	main
heliloojad	doc_278690626947_item	2316279	et	3	main
laulurahva	doc_278690626948_item	2316322	et	3	main
ja	doc_278690626948_item	2316333	et	3	main
emad	doc_278690626948_item	2316352	et	3	main
lastele	doc_278690626948_item	2316355	et	4	main
emad	doc_278690626948_item	2316364	et	3	main
lastele	doc_278690626948_item	2316368	et	4	main
oma	doc_278690626948_item	2316374	et	4	main
rahvalaul	doc_278690626948_item	2316377	et	4	main
veel	doc_278690626948_item	2316394	et	4	main
pillideta	doc_278690626948_item	2316422	et	3	main
suuline	doc_278690626948_item	2316423	et	4	main
laul	doc_278690626948_item	2316426	et	4	main
lauldes	doc_278690626948_item	2316431	et	3	main
kirjutati	doc_278690626948_item	2316433	et	3	main
rahvalaulul	doc_278690626948_item	2316443	et	3	main
põhiosat	doc_278690626948_item	2316446	et	4	main
olemas	doc_278690626948_item	2316447	et	4	main
väljendada	doc_278690626948_item	2316460	et	3	main
ja	doc_278690626948_item	2316465	et	3	main
meeskoorid	doc_278690626948_item	2316468	et	4	main
toimus	doc_278690626948_item	2316472	et	3	main
mitte	doc_278690626948_item	2316480	et	3	main
ühtegi	doc_278690626948_item	2316481	et	4	main
aastal	doc_278690626948_item	2316487	et	3	main
osana	doc_278690626948_item	2316525	et	3	main
kõige	doc_278690626948_item	2316531	et	4	main
eesti	doc_278690626948_item	2316535	et	4	main
bajaani	doc_278690626948_item	2316545	et	4	main
rahvalaul	doc_278690626948_item	2316547	et	4	main
seotud	doc_278690626948_item	2316557	et	4	main
et	doc_278690626947_item	2316120	et	3	main
uskusid	doc_278690626947_item	2316138	et	4	main
mitmus	doc_278690626947_item	2316141	et	3	main
laul	doc_278690626947_item	2316151	et	4	main
ja	doc_278690626947_item	2316153	et	3	main
elada	doc_278690626947_item	2316154	et	3	main
abistab	doc_278690626947_item	2316155	et	3	main
eestlased	doc_278690626947_item	2316158	et	3	main
nimel	doc_278690626947_item	2316162	et	3	main
on	doc_278690626947_item	2316165	et	4	main
rahvalaul	doc_278690626947_item	2316167	et	4	main
mõjutas	doc_278690626947_item	2316170	et	3	main
sajand	doc_278690626947_item	2316175	et	3	main
ühtse	doc_278690626947_item	2316213	et	3	main
ja	doc_278690626947_item	2316215	et	3	main
teistele	doc_278690626947_item	2316217	et	4	main
et	doc_278690626947_item	2316221	et	3	main
laulupeod	doc_278690626947_item	2316230	et	4	main
toimuvad	doc_278690626947_item	2316231	et	4	main
tänapäeviti	doc_278690626947_item	2316233	et	4	main
see	doc_278690626947_item	2316234	et	3	main
eestlased	doc_278690626947_item	2316238	et	3	main
on	doc_278690626947_item	2316239	et	4	main
sest	doc_278690626947_item	2316241	et	4	main
nad	doc_278690626947_item	2316242	et	3	main
traditsioone	doc_278690626947_item	2316246	et	3	main
ju	doc_278690626947_item	2316253	et	3	main
vääri	doc_278690626947_item	2316262	et	4	main
on	doc_278690626947_item	2316266	et	4	main
lauljad	doc_278690626947_item	2316281	et	4	main
eestlastest	doc_278690626948_item	2316321	et	4	main
essee	doc_278690626948_item	2316323	et	4	main
pikkus	doc_278690626948_item	2316324	et	4	main
350	doc_278690626948_item	2316326	et	2	main
loengus	doc_278690626948_item	2316336	et	3	main
esitatud	doc_278690626948_item	2316339	et	4	main
väiteid	doc_278690626948_item	2316341	et	4	main
laulis	doc_278690626948_item	2316348	et	4	main
vanasti	doc_278690626948_item	2316349	et	3	main
omavahel	doc_278690626948_item	2316358	et	3	main
mängimas	doc_278690626948_item	2316359	et	3	main
jätsid	doc_278690626948_item	2316366	et	4	main
oma	doc_278690626948_item	2316367	et	4	main
lastele	doc_278690626948_item	2316375	et	4	main
koosneb	doc_278690626948_item	2316378	et	3	main
rahvalaul	doc_278690626948_item	2316384	et	4	main
on	doc_278690626948_item	2316386	et	4	main
tänapäeval	doc_278690626948_item	2316387	et	3	main
põhiliselt	doc_278690626948_item	2316388	et	4	main
kadunud	doc_278690626948_item	2316389	et	4	main
aga	doc_278690626948_item	2316390	et	3	main
leida	doc_278690626948_item	2316393	et	3	main
ilma	doc_278690626948_item	2316421	et	4	main
riimiline	doc_278690626948_item	2316425	et	4	main
kasutatud	doc_278690626948_item	2316428	et	4	main
salme	doc_278690626948_item	2316430	et	4	main
hiljem	doc_278690626948_item	2316435	et	3	main
et	doc_278690626948_item	2316437	et	3	main
on	doc_278690626948_item	2316444	et	4	main
laul	doc_278690626948_item	2316448	et	4	main
seotud	doc_278690626948_item	2316455	et	4	main
võib	doc_278690626948_item	2316458	et	3	main
tegelesid	doc_278690626948_item	2316466	et	4	main
mis	doc_278690626948_item	2316471	et	4	main
tartus	doc_278690626948_item	2316475	et	3	main
meeskoori	doc_278690626948_item	2316478	et	4	main
1933	doc_278690626948_item	2316486	et	2	main
laulupeost	doc_278690626948_item	2316490	et	4	main
suursündmus	doc_278690626948_item	2316492	et	3	main
üks	doc_278690626948_item	2316522	et	3	main
laulupidu	doc_278690626948_item	2316527	et	4	main
ka	doc_278690626948_item	2316529	et	3	main
tänapäeval	doc_278690626948_item	2316530	et	3	main
eestis	doc_278690626948_item	2316534	et	3	main
lähedamatest	doc_278690626948_item	2316542	et	4	main
populaarne	doc_278690626948_item	2316550	et	3	main
ja	doc_278690626948_item	2316559	et	3	main
sa	doc_278690626948_item	2316562	et	3	main
maarahvas	doc_278690626947_item	2316122	et	4	main
nad	doc_278690626947_item	2316137	et	3	main
eesti	doc_278690626947_item	2316142	et	4	main
rahvalauludest	doc_278690626947_item	2316143	et	3	main
meil	doc_278690626947_item	2316150	et	4	main
et	doc_278690626947_item	2316157	et	3	main
rahvalaule	doc_278690626947_item	2316172	et	4	main
oli	doc_278690626947_item	2316176	et	3	main
tähtis	doc_278690626947_item	2316177	et	4	main
aeg	doc_278690626947_item	2316178	et	3	main
rahvalaul	doc_278690626947_item	2316179	et	4	main
hakkas	doc_278690626947_item	2316180	et	3	main
arendada	doc_278690626947_item	2316181	et	3	main
koos	doc_278690626947_item	2316182	et	4	main
uue	doc_278690626947_item	2316183	et	3	main
uskuga	doc_278690626947_item	2316184	et	4	main
lõpuks	doc_278690626947_item	2316185	et	4	main
ilmusid	doc_278690626947_item	2316186	et	4	main
ka	doc_278690626947_item	2316187	et	3	main
muusikainstrumentid	doc_278690626947_item	2316188	et	4	main
aga	doc_278690626947_item	2316189	et	3	main
koorilaulmine	doc_278690626947_item	2316190	et	3	main
sai	doc_278690626947_item	2316191	et	4	main
ja	doc_278690626947_item	2316193	et	3	main
mitmekülgne	doc_278690626947_item	2316192	et	3	main
variatiivne	doc_278690626947_item	2316194	et	4	main
ma	doc_278690626947_item	2316195	et	3	main
arvan	doc_278690626947_item	2316196	et	3	main
et	doc_278690626947_item	2316197	et	3	main
kõige	doc_278690626947_item	2316198	et	4	main
olulisem	doc_278690626947_item	2316199	et	4	main
rolli	doc_278690626947_item	2316200	et	4	main
mängis	doc_278690626947_item	2316201	et	3	main
rahvaärkamine	doc_278690626947_item	2316202	et	3	main
sel	doc_278690626947_item	2316203	et	3	main
ajal	doc_278690626947_item	2316204	et	4	main
hakkasid	doc_278690626947_item	2316205	et	4	main
tundub	doc_278690626947_item	2316220	et	3	main
ajal	doc_278690626947_item	2316224	et	4	main
traditsioon	doc_278690626947_item	2316229	et	3	main
räägib	doc_278690626947_item	2316235	et	3	main
säilitasid	doc_278690626947_item	2316243	et	4	main
oma	doc_278690626947_item	2316244	et	4	main
on	doc_278690626947_item	2316252	et	4	main
paljud	doc_278690626947_item	2316259	et	3	main
seda	doc_278690626947_item	2316263	et	3	main
laulupeod	doc_278690626947_item	2316267	et	4	main
praegu	doc_278690626947_item	2316272	et	3	main
isegi	doc_278690626947_item	2316277	et	4	main
ja	doc_278690626947_item	2316280	et	3	main
kasutavad	doc_278690626947_item	2316282	et	4	main
oma	doc_278690626947_item	2316283	et	4	main
loominguses	doc_278690626947_item	2316284	et	4	main
300	doc_278690626948_item	2316325	et	2	main
arutlev	doc_278690626948_item	2316331	et	4	main
analüüsiv	doc_278690626948_item	2316332	et	4	main
tuginema	doc_278690626948_item	2316335	et	3	main
eestimaa	doc_278690626948_item	2316346	et	4	main
laulsid	doc_278690626948_item	2316353	et	4	main
lapsed	doc_278690626948_item	2316356	et	3	main
suuliselt	doc_278690626948_item	2316365	et	4	main
laulud	doc_278690626948_item	2316369	et	3	main
jne	doc_278690626948_item	2316376	et	4	main
osast	doc_278690626948_item	2316380	et	4	main
regilaul	doc_278690626948_item	2316381	et	4	main
ja	doc_278690626948_item	2316382	et	3	main
ainult	doc_278690626948_item	2316424	et	4	main
levikule	doc_278690626948_item	2316441	et	3	main
ja	doc_278690626948_item	2316450	et	3	main
need	doc_278690626948_item	2316452	et	3	main
väga	doc_278690626948_item	2316454	et	3	main
eestis	doc_278690626948_item	2316461	et	3	main
mehed	doc_278690626948_item	2316464	et	3	main
ainult	doc_278690626948_item	2316467	et	4	main
46	doc_278690626948_item	2316477	et	2	main
lisandusid	doc_278690626948_item	2316488	et	4	main
nagu	doc_278690626948_item	2316521	et	3	main
pidu	doc_278690626948_item	2316523	et	4	main
üleeestiline	doc_278690626948_item	2316526	et	4	main
tähelepanuväärtsem	doc_278690626948_item	2316532	et	4	main
venemaalt	doc_278690626948_item	2316544	et	3	main
on	doc_278690626948_item	2316548	et	4	main
väga	doc_278690626948_item	2316549	et	3	main
rahvamuusikaga	doc_278690626948_item	2316558	et	3	main
laula	doc_278690626948_item	2316561	et	4	main
just	doc_278690626947_item	2316222	et	3	main
ka	doc_278690626947_item	2316232	et	3	main
sellest	doc_278690626947_item	2316236	et	4	main
laulurahva	doc_278690626947_item	2316245	et	3	main
eritähtsus	doc_278690626947_item	2316250	et	4	main
aga	doc_278690626947_item	2316260	et	3	main
paljude	doc_278690626947_item	2316264	et	3	main
ei	doc_278690626947_item	2316274	et	4	main
laulmist	doc_278690626947_item	2316276	et	4	main
uuemad	doc_278690626947_item	2316278	et	4	main
motiive	doc_278690626947_item	2316286	et	3	main
vana	doc_278690626947_item	2316287	et	4	main
laul	doc_278690626947_item	2316288	et	4	main
on	doc_278690626947_item	2316289	et	4	main
nende	doc_278690626947_item	2316290	et	4	main
jaoks	doc_278690626947_item	2316291	et	4	main
nagu	doc_278690626947_item	2316292	et	3	main
põhi	doc_278690626947_item	2316293	et	3	main
laulmine	doc_278690626947_item	2316294	et	4	main
on	doc_278690626947_item	2316295	et	4	main
tähtis	doc_278690626947_item	2316296	et	4	main
kultuuriosa	doc_278690626947_item	2316297	et	4	main
laulurahva	doc_278690626947_item	2316298	et	3	main
eestlastest	doc_278690626947_item	2316299	et	4	main
teeb	doc_278690626947_item	2316300	et	3	main
nende	doc_278690626947_item	2316301	et	4	main
huvi	doc_278690626947_item	2316302	et	4	main
minekusse	doc_278690626947_item	2316303	et	3	main
ja	doc_278690626947_item	2316304	et	3	main
oma	doc_278690626947_item	2316305	et	4	main
ajaloo	doc_278690626947_item	2316306	et	4	main
austamine	doc_278690626947_item	2316307	et	4	main
essee	doc_278690626948_item	2316308	et	4	main
eesti	doc_278690626948_item	2316309	et	4	main
keele	doc_278690626948_item	2316310	et	4	main
kui	doc_278690626948_item	2316311	et	3	main
teise	doc_278690626948_item	2316312	et	4	main
keele	doc_278690626948_item	2316313	et	4	main
test	doc_278690626948_item	2316314	et	3	main
kirjutamine	doc_278690626948_item	2316315	et	4	main
kirjutage	doc_278690626948_item	2316316	et	3	main
essee	doc_278690626948_item	2316317	et	4	main
teemal	doc_278690626948_item	2316318	et	3	main
mis	doc_278690626948_item	2316319	et	4	main
teeb	doc_278690626948_item	2316320	et	3	main
sõna	doc_278690626948_item	2316327	et	4	main
essee	doc_278690626948_item	2316328	et	4	main
üldistav	doc_278690626948_item	2316334	et	4	main
ja	doc_278690626948_item	2316337	et	3	main
see	doc_278690626947_item	2316251	et	3	main
ajaloost	doc_278690626947_item	2316255	et	4	main
mälu	doc_278690626947_item	2316258	et	4	main
ei	doc_278690626947_item	2316261	et	4	main
nagu	doc_278690626947_item	2316268	et	3	main
kultuuri-	doc_278690626947_item	2316269	et	4	main
harrastusüritused	doc_278690626947_item	2316271	et	3	main
vanu	doc_278690626947_item	2316285	et	4	main
peab	doc_278690626948_item	2316329	et	4	main
olema	doc_278690626948_item	2316330	et	4	main
lugemistekstis	doc_278690626948_item	2316338	et	3	main
faktidele	doc_278690626948_item	2316340	et	3	main
on	doc_278690626948_item	2316342	et	4	main
soovitatav	doc_278690626948_item	2316343	et	4	main
illustreerida	doc_278690626948_item	2316344	et	3	main
näidetega	doc_278690626948_item	2316345	et	3	main
praegu	doc_278690626948_item	2316351	et	3	main
oma	doc_278690626948_item	2316354	et	4	main
laulsid	doc_278690626948_item	2316361	et	4	main
tegemises	doc_278690626948_item	2316363	et	4	main
et	doc_278690626948_item	2316371	et	3	main
juba	doc_278690626948_item	2316373	et	3	main
2	doc_278690626948_item	2316379	et	2	main
regilaul	doc_278690626948_item	2316385	et	4	main
võib	doc_278690626948_item	2316392	et	3	main
setumaal	doc_278690626948_item	2316395	et	4	main
kihnus	doc_278690626948_item	2316396	et	3	main
laulsid	doc_278690626948_item	2316397	et	4	main
naised	doc_278690626948_item	2316398	et	3	main
sest	doc_278690626948_item	2316399	et	4	main
mehed	doc_278690626948_item	2316400	et	3	main
olid	doc_278690626948_item	2316401	et	4	main
meres	doc_278690626948_item	2316402	et	3	main
käimas	doc_278690626948_item	2316403	et	4	main
või	doc_278690626948_item	2316404	et	4	main
kuhugi	doc_278690626948_item	2316405	et	4	main
veel	doc_278690626948_item	2316406	et	4	main
aga	doc_278690626948_item	2316408	et	3	main
käimas	doc_278690626948_item	2316407	et	4	main
naised	doc_278690626948_item	2316409	et	3	main
pidid	doc_278690626948_item	2316410	et	4	main
kodutööd	doc_278690626948_item	2316411	et	4	main
tegema	doc_278690626948_item	2316412	et	3	main
lastega	doc_278690626948_item	2316413	et	3	main
istuda	doc_278690626948_item	2316414	et	3	main
käsitööd	doc_278690626948_item	2316415	et	4	main
või	doc_278690626948_item	2316416	et	4	main
toitu	doc_278690626948_item	2316417	et	4	main
tegema	doc_278690626948_item	2316418	et	3	main
regilaul	doc_278690626948_item	2316419	et	4	main
on	doc_278690626948_item	2316420	et	4	main
kirikutes	doc_278690626948_item	2316429	et	4	main
laulud	doc_278690626948_item	2316432	et	3	main
trükiti	doc_278690626948_item	2316436	et	3	main
saaks	doc_278690626948_item	2316439	et	3	main
viia	doc_278690626948_item	2316442	et	3	main
3	doc_278690626948_item	2316445	et	2	main
omavahel	doc_278690626948_item	2316456	et	3	main
ennast	doc_278690626948_item	2316459	et	4	main
laulsid	doc_278690626948_item	2316463	et	4	main
esimesel	doc_278690626948_item	2316469	et	3	main
1896	doc_278690626948_item	2316473	et	2	main
suurendamist	doc_278690626948_item	2316485	et	4	main
naiskoorid	doc_278690626948_item	2316489	et	3	main
alati	doc_278690626948_item	2316347	et	4	main
ja	doc_278690626948_item	2316350	et	3	main
laulsid	doc_278690626948_item	2316357	et	4	main
mehed	doc_278690626948_item	2316360	et	3	main
töö	doc_278690626948_item	2316362	et	4	main
vanasti	doc_278690626948_item	2316370	et	3	main
need	doc_278690626948_item	2316372	et	3	main
riimiline	doc_278690626948_item	2316383	et	4	main
seda	doc_278690626948_item	2316391	et	3	main
oli	doc_278690626948_item	2316427	et	3	main
ümber	doc_278690626948_item	2316434	et	3	main
neid	doc_278690626948_item	2316438	et	4	main
laiemale	doc_278690626948_item	2316440	et	4	main
pillimäng	doc_278690626948_item	2316449	et	3	main
tants	doc_278690626948_item	2316451	et	3	main
on	doc_278690626948_item	2316453	et	4	main
lauluteel	doc_278690626948_item	2316457	et	3	main
vanasti	doc_278690626948_item	2316462	et	3	main
laulupeol	doc_278690626948_item	2316470	et	4	main
aastal	doc_278690626948_item	2316474	et	3	main
esindas	doc_278690626948_item	2316476	et	3	main
ja	doc_278690626948_item	2316479	et	3	main
naist	doc_278690626948_item	2316482	et	3	main
pärast	doc_278690626948_item	2316483	et	4	main
peo	doc_278690626948_item	2316484	et	4	main
rahvasele	doc_278690626948_item	2316493	et	4	main
sai	doc_278690626948_item	2316491	et	4	main
alates	doc_278690626948_item	2316494	et	3	main
kuuendast	doc_278690626948_item	2316495	et	3	main
peost	doc_278690626948_item	2316496	et	4	main
laulupidu	doc_278690626948_item	2316497	et	4	main
kolis	doc_278690626948_item	2316498	et	4	main
tallinnasse	doc_278690626948_item	2316499	et	3	main
1994	doc_278690626948_item	2316500	et	2	main
aasta	doc_278690626948_item	2316501	et	4	main
juulis	doc_278690626948_item	2316502	et	3	main
toimus	doc_278690626948_item	2316503	et	3	main
toppelt	doc_278690626948_item	2316504	et	4	main
laulupidu	doc_278690626948_item	2316505	et	4	main
sest	doc_278690626948_item	2316506	et	4	main
et	doc_278690626948_item	2316507	et	3	main
toimus	doc_278690626948_item	2316508	et	3	main
125	doc_278690626948_item	2316509	et	2	main
laulupidu	doc_278690626948_item	2316510	et	4	main
kahes	doc_278690626948_item	2316511	et	4	main
linnas	doc_278690626948_item	2316512	et	4	main
tallinnas	doc_278690626948_item	2316513	et	4	main
ja	doc_278690626948_item	2316514	et	3	main
tartus	doc_278690626948_item	2316515	et	3	main
see	doc_278690626948_item	2316516	et	3	main
oli	doc_278690626948_item	2316517	et	3	main
nii	doc_278690626948_item	2316518	et	3	main
seotud	doc_278690626948_item	2316519	et	4	main
omavahel	doc_278690626948_item	2316520	et	3	main
on	doc_278690626948_item	2316528	et	4	main
praegusel	doc_278690626948_item	2316537	et	3	main
rahvastest	doc_278690626948_item	2316543	et	4	main
mängimise	doc_278690626948_item	2316546	et	4	main
meil	doc_278690626948_item	2316551	et	4	main
toimuvad	doc_278690626948_item	2316553	et	4	main
rahvafestivalid	doc_278690626948_item	2316554	et	3	main
mitmesugused	doc_278690626948_item	2316555	et	3	main
üritused	doc_278690626948_item	2316556	et	4	main
kahe	doc_278690626948_item	2316524	et	3	main
sündmus	doc_278690626948_item	2316533	et	3	main
rahvalaul	doc_278690626948_item	2316536	et	4	main
ajal	doc_278690626948_item	2316538	et	4	main
sai	doc_278690626948_item	2316539	et	4	main
suure	doc_278690626948_item	2316540	et	3	main
mõju	doc_278690626948_item	2316541	et	4	main
tihti	doc_278690626948_item	2316552	et	3	main
tantsiga	doc_278690626948_item	2316560	et	3	main
ka	doc_278690626948_item	2316563	et	3	main
essee	doc_278690626954_item	2317650	et	4	main
essee	doc_278690626954_item	2317656	et	4	main
sõna	doc_278690626954_item	2317660	et	4	main
peab	doc_278690626954_item	2317662	et	4	main
ja	doc_278690626954_item	2317666	et	3	main
üldistav	doc_278690626954_item	2317667	et	4	main
tuginema	doc_278690626954_item	2317668	et	3	main
loengus	doc_278690626954_item	2317669	et	3	main
ja	doc_278690626954_item	2317670	et	3	main
soovitatav	doc_278690626954_item	2317676	et	4	main
näidetega	doc_278690626954_item	2317678	et	3	main
on	doc_278690626954_item	2317680	et	4	main
laulurahvas	doc_278690626954_item	2317682	et	4	main
kui	doc_278690626954_item	2317727	et	3	main
ainult	doc_278690626954_item	2317738	et	4	main
vokalselt	doc_278690626954_item	2317739	et	4	main
ei	doc_278690626954_item	2317743	et	4	main
õigus	doc_278690626954_item	2317745	et	4	main
et	doc_278690626954_item	2317756	et	3	main
ka	doc_278690626954_item	2317758	et	3	main
laulud	doc_278690626954_item	2317760	et	3	main
lauldi	doc_278690626954_item	2317766	et	3	main
tähtis	doc_278690626954_item	2317770	et	4	main
on	doc_278690626954_item	2317775	et	4	main
laulupidu	doc_278690626954_item	2317778	et	4	main
kirjutage	doc_278690626954_item	2317649	et	3	main
mis	doc_278690626954_item	2317652	et	4	main
teeb	doc_278690626954_item	2317653	et	3	main
essee	doc_278690626954_item	2317641	et	4	main
keele	doc_278690626954_item	2317646	et	4	main
test	doc_278690626954_item	2317647	et	3	main
kirjutamine	doc_278690626954_item	2317648	et	4	main
pikkus	doc_278690626954_item	2317657	et	4	main
arutlev	doc_278690626954_item	2317664	et	4	main
analüüsiv	doc_278690626954_item	2317665	et	4	main
väiteid	doc_278690626954_item	2317674	et	4	main
illustreerida	doc_278690626954_item	2317677	et	3	main
eestlastes	doc_278690626954_item	2317720	et	4	main
näiste	doc_278690626954_item	2317725	et	4	main
vanal	doc_278690626954_item	2317735	et	3	main
lauldi	doc_278690626954_item	2317737	et	3	main
muusikata	doc_278690626954_item	2317741	et	3	main
mehed	doc_278690626954_item	2317757	et	3	main
lauldid	doc_278690626954_item	2317759	et	4	main
elu	doc_278690626954_item	2317764	et	4	main
kirukus	doc_278690626954_item	2317768	et	4	main
osa	doc_278690626954_item	2317771	et	4	main
traditsioniks	doc_278690626954_item	2317785	et	4	main
laulurahva	doc_278690626954_item	2317789	et	3	main
nii	doc_278690626954_item	2317799	et	3	main
inimese	doc_278690626954_item	2317801	et	4	main
ilmusid	doc_278690626954_item	2317821	et	4	main
laulu	doc_278690626954_item	2317823	et	4	main
ka	doc_278690626954_item	2317834	et	3	main
rahva	doc_278690626954_item	2317842	et	3	main
ja	doc_278690626954_item	2317851	et	3	main
elu	doc_278690626954_item	2317854	et	4	main
ka	doc_278690626954_item	2317895	et	3	main
keel	doc_278690626954_item	2317897	et	4	main
on	doc_278690626954_item	2317898	et	4	main
väga	doc_278690626954_item	2317899	et	3	main
ütelda	doc_278690626954_item	2317906	et	4	main
see	doc_278690626954_item	2317917	et	3	main
et	doc_278690626954_item	2317918	et	3	main
hoianevad	doc_278690626954_item	2317920	et	4	main
seotud	doc_278690626954_item	2317925	et	4	main
on	doc_278690626954_item	2317937	et	4	main
maailmas	doc_278690626954_item	2317947	et	3	main
teised	doc_278690626954_item	2317949	et	4	main
ja	doc_278690626954_item	2317951	et	3	main
rahvad	doc_278690626954_item	2317953	et	3	main
teaksid	doc_278690626954_item	2317954	et	4	main
näha	doc_278690626954_item	2317959	et	3	main
laulurahvas	doc_278690626954_item	2317963	et	4	main
võib	doc_278690626954_item	2317966	et	3	main
kui	doc_278690626954_item	2317644	et	3	main
teemal	doc_278690626954_item	2317651	et	3	main
eestlastest	doc_278690626954_item	2317654	et	4	main
350	doc_278690626954_item	2317659	et	2	main
on	doc_278690626954_item	2317675	et	4	main
jaoks	doc_278690626954_item	2317726	et	4	main
võiksid	doc_278690626954_item	2317729	et	4	main
ilma	doc_278690626954_item	2317740	et	4	main
ma	doc_278690626954_item	2317753	et	3	main
teada	doc_278690626954_item	2317755	et	3	main
eestirahva	doc_278690626954_item	2317763	et	3	main
osa	doc_278690626954_item	2317765	et	4	main
kultuuri	doc_278690626954_item	2317773	et	4	main
rahva	doc_278690626954_item	2317787	et	3	main
nende	doc_278690626954_item	2317794	et	4	main
osaks	doc_278690626954_item	2317798	et	3	main
iga	doc_278690626954_item	2317800	et	4	main
tänapäeva	doc_278690626954_item	2317831	et	4	main
ansamblit	doc_278690626954_item	2317836	et	3	main
laulud	doc_278690626954_item	2317843	et	3	main
ei	doc_278690626954_item	2317845	et	4	main
annab	doc_278690626954_item	2317852	et	3	main
see	doc_278690626954_item	2317855	et	3	main
lauldese	doc_278690626954_item	2317856	et	4	main
rahvalaul	doc_278690626954_item	2317857	et	4	main
nii	doc_278690626954_item	2317858	et	3	main
populäärne	doc_278690626954_item	2317859	et	4	main
huvitav	doc_278690626954_item	2317915	et	4	main
eesti	doc_278690626954_item	2317642	et	4	main
keele	doc_278690626954_item	2317643	et	4	main
teise	doc_278690626954_item	2317645	et	4	main
300	doc_278690626954_item	2317658	et	2	main
esitatud	doc_278690626954_item	2317672	et	4	main
eestlased	doc_278690626954_item	2317679	et	3	main
väga	doc_278690626954_item	2317681	et	3	main
ja	doc_278690626954_item	2317684	et	3	main
tantsid	doc_278690626954_item	2317685	et	4	main
koostavad	doc_278690626954_item	2317686	et	4	main
suur	doc_278690626954_item	2317687	et	3	main
osa	doc_278690626954_item	2317688	et	4	main
neie	doc_278690626954_item	2317689	et	4	main
kulturis	doc_278690626954_item	2317690	et	4	main
vanal	doc_278690626954_item	2317691	et	3	main
ajal	doc_278690626954_item	2317692	et	4	main
eestlased	doc_278690626954_item	2317693	et	3	main
võisid	doc_278690626954_item	2317694	et	4	main
laulda	doc_278690626954_item	2317695	et	4	main
peol	doc_278690626954_item	2317697	et	4	main
tööl	doc_278690626954_item	2317696	et	3	main
nagu	doc_278690626954_item	2317699	et	3	main
ja	doc_278690626954_item	2317698	et	3	main
mina	doc_278690626954_item	2317700	et	4	main
saaksin	doc_278690626954_item	2317701	et	3	main
teada	doc_278690626954_item	2317702	et	3	main
mõne	doc_278690626954_item	2317703	et	3	main
aega	doc_278690626954_item	2317704	et	4	main
tagasi	doc_278690626954_item	2317705	et	3	main
nad	doc_278690626954_item	2317706	et	3	main
ikka	doc_278690626954_item	2317707	et	4	main
suheldasida	doc_278690626954_item	2317708	et	4	main
ja	doc_278690626954_item	2317709	et	3	main
võiksid	doc_278690626954_item	2317710	et	4	main
muinasjuttu	doc_278690626954_item	2317711	et	4	main
räägida	doc_278690626954_item	2317712	et	4	main
lauldes	doc_278690626954_item	2317713	et	3	main
mis	doc_278690626954_item	2317714	et	4	main
on	doc_278690626954_item	2317715	et	4	main
väga	doc_278690626954_item	2317716	et	3	main
huvitav	doc_278690626954_item	2317717	et	4	main
minu	doc_278690626954_item	2317718	et	3	main
laulurahva	doc_278690626954_item	2317655	et	3	main
essee	doc_278690626954_item	2317661	et	4	main
olema	doc_278690626954_item	2317663	et	4	main
lugemistekstis	doc_278690626954_item	2317671	et	3	main
faktidele	doc_278690626954_item	2317673	et	3	main
laulud	doc_278690626954_item	2317683	et	3	main
arvates	doc_278690626954_item	2317719	et	4	main
ka	doc_278690626954_item	2317722	et	3	main
ainult	doc_278690626954_item	2317724	et	4	main
käia	doc_278690626954_item	2317730	et	4	main
et	doc_278690626954_item	2317731	et	3	main
tantsida	doc_278690626954_item	2317734	et	3	main
ajal	doc_278690626954_item	2317736	et	4	main
aga	doc_278690626954_item	2317742	et	3	main
et	doc_278690626954_item	2317746	et	3	main
ainult	doc_278690626954_item	2317747	et	4	main
naised	doc_278690626954_item	2317748	et	3	main
laulsid	doc_278690626954_item	2317749	et	4	main
nagu	doc_278690626954_item	2317750	et	3	main
ma	doc_278690626954_item	2317751	et	3	main
mõtlesin	doc_278690626954_item	2317752	et	3	main
alati	doc_278690626954_item	2317761	et	4	main
ka	doc_278690626954_item	2317767	et	3	main
elus	doc_278690626954_item	2317774	et	4	main
esimene	doc_278690626954_item	2317777	et	3	main
oli	doc_278690626954_item	2317779	et	3	main
aastal	doc_278690626954_item	2317781	et	3	main
ta	doc_278690626954_item	2317783	et	4	main
sai	doc_278690626954_item	2317784	et	4	main
et	doc_278690626954_item	2317791	et	3	main
olnud	doc_278690626954_item	2317793	et	4	main
jaoks	doc_278690626954_item	2317795	et	4	main
nii	doc_278690626954_item	2317796	et	3	main
suur	doc_278690626954_item	2317797	et	3	main
olnud	doc_278690626954_item	2317721	et	4	main
peod	doc_278690626954_item	2317723	et	4	main
nad	doc_278690626954_item	2317728	et	3	main
laulda	doc_278690626954_item	2317732	et	4	main
ja	doc_278690626954_item	2317733	et	3	main
ole	doc_278690626954_item	2317744	et	4	main
saanud	doc_278690626954_item	2317754	et	4	main
olnud	doc_278690626954_item	2317762	et	4	main
väga	doc_278690626954_item	2317769	et	3	main
eesti	doc_278690626954_item	2317772	et	4	main
laulupidu	doc_278690626954_item	2317776	et	4	main
tartus	doc_278690626954_item	2317782	et	3	main
teeb	doc_278690626954_item	2317788	et	3	main
laulud	doc_278690626954_item	2317792	et	3	main
elus	doc_278690626954_item	2317802	et	4	main
kui	doc_278690626954_item	2317803	et	3	main
ka	doc_278690626954_item	2317804	et	3	main
ajaloo	doc_278690626954_item	2317805	et	4	main
ja	doc_278690626954_item	2317806	et	3	main
rahva	doc_278690626954_item	2317807	et	3	main
elus	doc_278690626954_item	2317808	et	4	main
rahvad	doc_278690626954_item	2317810	et	3	main
ka	doc_278690626954_item	2317811	et	3	main
teised	doc_278690626954_item	2317809	et	4	main
mõjusid	doc_278690626954_item	2317812	et	4	main
eesti	doc_278690626954_item	2317813	et	4	main
muusikat	doc_278690626954_item	2317814	et	3	main
eestlased	doc_278690626954_item	2317815	et	3	main
algasid	doc_278690626954_item	2317816	et	4	main
kasutama	doc_278690626954_item	2317817	et	3	main
uued	doc_278690626954_item	2317818	et	3	main
muusika	doc_278690626954_item	2317819	et	4	main
instrumentid	doc_278690626954_item	2317820	et	4	main
uued	doc_278690626954_item	2317822	et	3	main
žaanrid	doc_278690626954_item	2317824	et	2	main
aga	doc_278690626954_item	2317825	et	3	main
on	doc_278690626954_item	2317827	et	4	main
muusikat	doc_278690626954_item	2317832	et	3	main
nad	doc_278690626954_item	2317837	et	3	main
arhividest	doc_278690626954_item	2317840	et	4	main
uus	doc_278690626954_item	2317853	et	3	main
siin	doc_278690626954_item	2317860	et	4	main
kui	doc_278690626954_item	2317861	et	3	main
ka	doc_278690626954_item	2317862	et	3	main
tänapäeva	doc_278690626954_item	2317863	et	4	main
muusika	doc_278690626954_item	2317864	et	4	main
tallinnas	doc_278690626954_item	2317865	et	4	main
esitavad	doc_278690626954_item	2317866	et	4	main
väga	doc_278690626954_item	2317867	et	3	main
saan	doc_278690626954_item	2317905	et	4	main
see	doc_278690626954_item	2317909	et	3	main
ja	doc_278690626954_item	2317914	et	3	main
eestlased	doc_278690626954_item	2317919	et	3	main
traditsionid	doc_278690626954_item	2317922	et	4	main
ja	doc_278690626954_item	2317927	et	3	main
aitab	doc_278690626954_item	2317929	et	3	main
võimalust	doc_278690626954_item	2317931	et	3	main
see	doc_278690626954_item	2317933	et	3	main
inimestega	doc_278690626954_item	2317934	et	3	main
midagi	doc_278690626954_item	2317941	et	4	main
oma	doc_278690626954_item	2317944	et	4	main
eestlased	doc_278690626954_item	2317960	et	3	main
tõesti	doc_278690626954_item	2317962	et	3	main
1869	doc_278690626954_item	2317780	et	2	main
eesti	doc_278690626954_item	2317786	et	4	main
see	doc_278690626954_item	2317790	et	3	main
eestis	doc_278690626954_item	2317826	et	3	main
milled	doc_278690626954_item	2317829	et	4	main
mängivad	doc_278690626954_item	2317830	et	4	main
ikka	doc_278690626954_item	2317838	et	4	main
otsivad	doc_278690626954_item	2317839	et	4	main
vana	doc_278690626954_item	2317841	et	4	main
mis	doc_278690626954_item	2317844	et	4	main
anna	doc_278690626954_item	2317846	et	4	main
unustada	doc_278690626954_item	2317847	et	3	main
eesti	doc_278690626954_item	2317848	et	4	main
kultuur	doc_278690626954_item	2317849	et	3	main
palju	doc_278690626954_item	2317868	et	4	main
ilus	doc_278690626954_item	2317900	et	4	main
keel	doc_278690626954_item	2317901	et	4	main
laulde	doc_278690626954_item	2317902	et	4	main
jaoks	doc_278690626954_item	2317903	et	4	main
ma	doc_278690626954_item	2317904	et	3	main
kõik	doc_278690626954_item	2317908	et	4	main
teeb	doc_278690626954_item	2317910	et	3	main
on	doc_278690626954_item	2317916	et	4	main
mis	doc_278690626954_item	2317924	et	4	main
ta	doc_278690626954_item	2317936	et	4	main
teha	doc_278690626954_item	2317940	et	3	main
et	doc_278690626954_item	2317942	et	3	main
ütelda	doc_278690626954_item	2317943	et	4	main
võib	doc_278690626954_item	2317957	et	3	main
on	doc_278690626954_item	2317961	et	4	main
kolektiivid	doc_278690626954_item	2317828	et	4	main
kui	doc_278690626954_item	2317833	et	3	main
folkloor	doc_278690626954_item	2317835	et	4	main
traditsionides	doc_278690626954_item	2317850	et	4	main
kollektiive	doc_278690626954_item	2317869	et	3	main
rahvalaulaga	doc_278690626954_item	2317870	et	4	main
seda	doc_278690626954_item	2317871	et	3	main
võib	doc_278690626954_item	2317872	et	3	main
näha	doc_278690626954_item	2317873	et	3	main
suvel	doc_278690626954_item	2317874	et	3	main
väga	doc_278690626954_item	2317875	et	3	main
hästi	doc_278690626954_item	2317876	et	3	main
ma	doc_278690626954_item	2317877	et	3	main
arvan	doc_278690626954_item	2317878	et	3	main
et	doc_278690626954_item	2317879	et	3	main
eestis	doc_278690626954_item	2317880	et	3	main
on	doc_278690626954_item	2317881	et	4	main
väga	doc_278690626954_item	2317882	et	3	main
huvitava	doc_278690626954_item	2317884	et	4	main
palju	doc_278690626954_item	2317883	et	4	main
ansamblid	doc_278690626954_item	2317885	et	3	main
mitte	doc_278690626954_item	2317886	et	3	main
ainult	doc_278690626954_item	2317887	et	4	main
rahvaansamblid	doc_278690626954_item	2317888	et	3	main
aga	doc_278690626954_item	2317889	et	3	main
need	doc_278690626954_item	2317890	et	3	main
kes	doc_278690626954_item	2317891	et	4	main
mängiva	doc_278690626954_item	2317892	et	4	main
tänapäeva	doc_278690626954_item	2317893	et	4	main
muusikat	doc_278690626954_item	2317894	et	3	main
eesti	doc_278690626954_item	2317896	et	4	main
et	doc_278690626954_item	2317907	et	3	main
eesti	doc_278690626954_item	2317911	et	4	main
rahva	doc_278690626954_item	2317912	et	3	main
laulurahva	doc_278690626954_item	2317913	et	3	main
tantsidega	doc_278690626954_item	2317928	et	3	main
inimestele	doc_278690626954_item	2317930	et	3	main
me	doc_278690626954_item	2317938	et	4	main
sõnu	doc_278690626954_item	2317945	et	4	main
seda	doc_278690626954_item	2317946	et	3	main
inimesed	doc_278690626954_item	2317950	et	3	main
teised	doc_278690626954_item	2317952	et	4	main
eesti	doc_278690626954_item	2317955	et	4	main
kultuuris	doc_278690626954_item	2317956	et	3	main
ja	doc_278690626954_item	2317964	et	3	main
oma	doc_278690626954_item	2317921	et	4	main
kõik	doc_278690626954_item	2317923	et	4	main
lauldega	doc_278690626954_item	2317926	et	4	main
olla	doc_278690626954_item	2317932	et	3	main
kes	doc_278690626954_item	2317935	et	4	main
vajame	doc_278690626954_item	2317939	et	3	main
et	doc_278690626954_item	2317948	et	3	main
seda	doc_278690626954_item	2317958	et	3	main
see	doc_278690626954_item	2317965	et	3	main
leia	doc_278690626954_item	2317967	et	4	main
ajaloos	doc_278690626954_item	2317968	et	4	main
keele	doc_278690626959_item	2319074	et	4	main
eestlastest	doc_278690626959_item	2319082	et	4	main
loengus	doc_278690626959_item	2319097	et	3	main
ühendada	doc_278690626959_item	2319116	et	3	main
tantsida	doc_278690626959_item	2319120	et	3	main
ühendab	doc_278690626959_item	2319127	et	3	main
eesti	doc_278690626959_item	2319070	et	4	main
laulurahva	doc_278690626959_item	2319083	et	3	main
300	doc_278690626959_item	2319086	et	2	main
arutlev	doc_278690626959_item	2319092	et	4	main
tuginema	doc_278690626959_item	2319096	et	3	main
estlased	doc_278690626959_item	2319107	et	4	main
väga	doc_278690626959_item	2319109	et	3	main
väga	doc_278690626959_item	2319123	et	3	main
ja	doc_278690626959_item	2319125	et	3	main
enam	doc_278690626959_item	2319129	et	4	main
tagasi	doc_278690626959_item	2319133	et	3	main
tähelepanuväärne	doc_278690626959_item	2319138	et	3	main
kultuurinähtus	doc_278690626959_item	2319139	et	4	main
see	doc_278690626959_item	2319141	et	3	main
tulevik	doc_278690626959_item	2319148	et	3	main
jaoks	doc_278690626959_item	2319155	et	4	main
eestirahva	doc_278690626959_item	2319156	et	3	main
muusikas	doc_278690626959_item	2319157	et	3	main
oluline	doc_278690626959_item	2319160	et	4	main
see	doc_278690626959_item	2319166	et	3	main
rahvapidu	doc_278690626959_item	2319168	et	4	main
lootuses	doc_278690626959_item	2319173	et	4	main
tuttavaid	doc_278690626959_item	2319178	et	3	main
lauluvad	doc_278690626959_item	2319184	et	4	main
on	doc_278690626959_item	2319222	et	4	main
ka	doc_278690626959_item	2319227	et	3	main
tegevus	doc_278690626959_item	2319229	et	4	main
ma	doc_278690626959_item	2319237	et	3	main
on	doc_278690626959_item	2319238	et	4	main
elan	doc_278690626959_item	2319241	et	3	main
aastat	doc_278690626959_item	2319245	et	3	main
meeldib	doc_278690626959_item	2319249	et	3	main
kultuur	doc_278690626959_item	2319251	et	3	main
laulupeost	doc_278690626959_item	2319254	et	4	main
meeldib	doc_278690626959_item	2319259	et	3	main
minu	doc_278690626959_item	2319265	et	3	main
laulupeost	doc_278690626959_item	2319269	et	4	main
oma	doc_278690626959_item	2319270	et	4	main
perega	doc_278690626959_item	2319271	et	3	main
minu	doc_278690626959_item	2319272	et	3	main
eesti	doc_278690626959_item	2319278	et	4	main
teise	doc_278690626959_item	2319073	et	4	main
kirjutamine	doc_278690626959_item	2319076	et	4	main
essee	doc_278690626959_item	2319078	et	4	main
teemal	doc_278690626959_item	2319079	et	3	main
mis	doc_278690626959_item	2319080	et	4	main
teeb	doc_278690626959_item	2319081	et	3	main
sõna	doc_278690626959_item	2319088	et	4	main
essee	doc_278690626959_item	2319089	et	4	main
analüüsiv	doc_278690626959_item	2319093	et	4	main
faktidele	doc_278690626959_item	2319101	et	3	main
soovitatav	doc_278690626959_item	2319104	et	4	main
illustreerida	doc_278690626959_item	2319105	et	3	main
ja	doc_278690626959_item	2319119	et	3	main
see	doc_278690626959_item	2319121	et	3	main
see	doc_278690626959_item	2319126	et	3	main
tuhad	doc_278690626959_item	2319131	et	3	main
ja	doc_278690626959_item	2319147	et	3	main
see	doc_278690626959_item	2319150	et	3	main
tähtsad	doc_278690626959_item	2319153	et	3	main
on	doc_278690626959_item	2319167	et	4	main
kuhu	doc_278690626959_item	2319169	et	3	main
tullakse	doc_278690626959_item	2319170	et	3	main
oma	doc_278690626959_item	2319182	et	4	main
see	doc_278690626959_item	2319221	et	3	main
aga	doc_278690626959_item	2319226	et	3	main
sotsiaalne	doc_278690626959_item	2319228	et	3	main
vanal	doc_278690626959_item	2319230	et	3	main
ajal	doc_278690626959_item	2319231	et	4	main
juba	doc_278690626959_item	2319243	et	3	main
mulle	doc_278690626959_item	2319247	et	4	main
ma	doc_278690626959_item	2319252	et	3	main
mulle	doc_278690626959_item	2319258	et	4	main
oluline	doc_278690626959_item	2319264	et	4	main
ma	doc_278690626959_item	2319267	et	3	main
ka	doc_278690626959_item	2319274	et	3	main
et	doc_278690626959_item	2319282	et	3	main
estlased	doc_278690626959_item	2319283	et	4	main
kõige	doc_278690626959_item	2319284	et	4	main
lõbusam	doc_278690626959_item	2319285	et	4	main
ja	doc_278690626959_item	2319286	et	3	main
musikalne	doc_278690626959_item	2319287	et	4	main
keele	doc_278690626959_item	2319071	et	4	main
test	doc_278690626959_item	2319075	et	3	main
kirjutage	doc_278690626959_item	2319077	et	3	main
peab	doc_278690626959_item	2319090	et	4	main
olema	doc_278690626959_item	2319091	et	4	main
üldistav	doc_278690626959_item	2319095	et	4	main
lugemistekstis	doc_278690626959_item	2319099	et	3	main
esitatud	doc_278690626959_item	2319100	et	4	main
väiteid	doc_278690626959_item	2319102	et	4	main
on	doc_278690626959_item	2319103	et	4	main
on	doc_278690626959_item	2319108	et	4	main
ja	doc_278690626959_item	2319117	et	3	main
on	doc_278690626959_item	2319122	et	4	main
huvitav	doc_278690626959_item	2319124	et	4	main
rahvus	doc_278690626959_item	2319128	et	3	main
aastad	doc_278690626959_item	2319132	et	3	main
kujunenud	doc_278690626959_item	2319134	et	4	main
laulmine	doc_278690626959_item	2319136	et	4	main
on	doc_278690626959_item	2319137	et	4	main
rahvalauludes	doc_278690626959_item	2319140	et	3	main
on	doc_278690626959_item	2319142	et	4	main
minevik	doc_278690626959_item	2319145	et	3	main
väga	doc_278690626959_item	2319152	et	3	main
rahva	doc_278690626959_item	2319154	et	3	main
on	doc_278690626959_item	2319162	et	4	main
väga	doc_278690626959_item	2319163	et	3	main
suur	doc_278690626959_item	2319164	et	3	main
koos	doc_278690626959_item	2319171	et	4	main
keeles	doc_278690626959_item	2319183	et	4	main
väga	doc_278690626959_item	2319223	et	3	main
väljendusvahed	doc_278690626959_item	2319225	et	3	main
saatis	doc_278690626959_item	2319232	et	3	main
laul	doc_278690626959_item	2319233	et	4	main
hällist	doc_278690626959_item	2319235	et	4	main
hauani	doc_278690626959_item	2319236	et	3	main
eestis	doc_278690626959_item	2319242	et	3	main
19	doc_278690626959_item	2319244	et	2	main
ja	doc_278690626959_item	2319246	et	3	main
väga	doc_278690626959_item	2319248	et	3	main
eesti	doc_278690626959_item	2319250	et	4	main
olen	doc_278690626959_item	2319253	et	3	main
3	doc_278690626959_item	2319255	et	2	main
korda	doc_278690626959_item	2319256	et	4	main
see	doc_278690626959_item	2319261	et	3	main
vanemad	doc_278690626959_item	2319273	et	4	main
meeldivad	doc_278690626959_item	2319275	et	4	main
uurimine	doc_278690626959_item	2319324	et	4	main
läänemeresoome	doc_278690626959_item	2319331	et	3	main
essee	doc_278690626959_item	2319069	et	4	main
kui	doc_278690626959_item	2319072	et	3	main
essee	doc_278690626959_item	2319084	et	4	main
pikkus	doc_278690626959_item	2319085	et	4	main
350	doc_278690626959_item	2319087	et	2	main
ja	doc_278690626959_item	2319094	et	3	main
ja	doc_278690626959_item	2319098	et	3	main
näidetega	doc_278690626959_item	2319106	et	3	main
lõbus	doc_278690626959_item	2319110	et	4	main
ja	doc_278690626959_item	2319111	et	3	main
laulurahva	doc_278690626959_item	2319112	et	3	main
nad	doc_278690626959_item	2319113	et	3	main
väga	doc_278690626959_item	2319114	et	3	main
meldivad	doc_278690626959_item	2319115	et	4	main
laulda	doc_278690626959_item	2319118	et	4	main
kui	doc_278690626959_item	2319130	et	3	main
olevik	doc_278690626959_item	2319146	et	3	main
on	doc_278690626959_item	2319151	et	4	main
väga	doc_278690626959_item	2319159	et	3	main
laulupidu	doc_278690626959_item	2319161	et	4	main
perega	doc_278690626959_item	2319172	et	3	main
estlased	doc_278690626959_item	2319180	et	4	main
rägivad	doc_278690626959_item	2319181	et	4	main
oma	doc_278690626959_item	2319185	et	4	main
folkloor	doc_278690626959_item	2319186	et	4	main
tansivad	doc_278690626959_item	2319187	et	4	main
oma	doc_278690626959_item	2319188	et	4	main
rahvatansid	doc_278690626959_item	2319189	et	4	main
estlased	doc_278690626959_item	2319190	et	4	main
on	doc_278690626959_item	2319191	et	4	main
väga	doc_278690626959_item	2319192	et	3	main
inimsõbralik	doc_278690626959_item	2319193	et	3	main
ja	doc_278690626959_item	2319194	et	3	main
korralik	doc_278690626959_item	2319195	et	3	main
rahv	doc_278690626959_item	2319196	et	4	main
eesti	doc_278690626959_item	2319197	et	4	main
laulud	doc_278690626959_item	2319198	et	3	main
on	doc_278690626959_item	2319199	et	4	main
läbi	doc_278690626959_item	2319200	et	4	main
aja	doc_278690626959_item	2319201	et	4	main
kujunenud	doc_278690626959_item	2319202	et	4	main
rahvuslikeks	doc_278690626959_item	2319203	et	3	main
sümboliteks	doc_278690626959_item	2319204	et	3	main
praegusel	doc_278690626959_item	2319205	et	3	main
ajal	doc_278690626959_item	2319206	et	4	main
laulupidu	doc_278690626959_item	2319207	et	4	main
on	doc_278690626959_item	2319208	et	4	main
kõige	doc_278690626959_item	2319209	et	4	main
tähelepanuväärsem	doc_278690626959_item	2319210	et	4	main
ja	doc_278690626959_item	2319211	et	3	main
massilisem	doc_278690626959_item	2319212	et	4	main
rahvusluse	doc_278690626959_item	2319213	et	4	main
manifestatsioon	doc_278690626959_item	2319214	et	3	main
eestis	doc_278690626959_item	2319215	et	3	main
mulle	doc_278690626959_item	2319216	et	4	main
väga	doc_278690626959_item	2319217	et	3	main
meeldib	doc_278690626959_item	2319218	et	3	main
see	doc_278690626959_item	2319219	et	3	main
pidu	doc_278690626959_item	2319220	et	4	main
emotsionalne	doc_278690626959_item	2319224	et	4	main
rahvalaul	doc_278690626959_item	2319135	et	4	main
eesti	doc_278690626959_item	2319143	et	4	main
rahva	doc_278690626959_item	2319144	et	3	main
ja	doc_278690626959_item	2319149	et	3	main
on	doc_278690626959_item	2319158	et	4	main
pidu	doc_278690626959_item	2319165	et	4	main
kohata	doc_278690626959_item	2319174	et	4	main
sõpru	doc_278690626959_item	2319175	et	3	main
sugulasi	doc_278690626959_item	2319176	et	3	main
ja	doc_278690626959_item	2319177	et	3	main
siin	doc_278690626959_item	2319179	et	4	main
eestlane	doc_278690626959_item	2319234	et	3	main
aga	doc_278690626959_item	2319240	et	3	main
see	doc_278690626959_item	2319260	et	3	main
on	doc_278690626959_item	2319262	et	4	main
rahv	doc_278690626959_item	2319288	et	4	main
väga	doc_278690626959_item	2319291	et	3	main
tore	doc_278690626959_item	2319292	et	3	main
kui	doc_278690626959_item	2319293	et	3	main
inimesed	doc_278690626959_item	2319294	et	3	main
laulavad	doc_278690626959_item	2319295	et	4	main
tansivad	doc_278690626959_item	2319297	et	4	main
koos	doc_278690626959_item	2319298	et	4	main
ja	doc_278690626959_item	2319296	et	3	main
muusika	doc_278690626959_item	2319299	et	4	main
ning	doc_278690626959_item	2319300	et	3	main
lauluharrastusega	doc_278690626959_item	2319301	et	3	main
on	doc_278690626959_item	2319302	et	4	main
seotud	doc_278690626959_item	2319303	et	4	main
tihedalt	doc_278690626959_item	2319304	et	4	main
ka	doc_278690626959_item	2319305	et	3	main
eestlaste	doc_278690626959_item	2319306	et	4	main
rahvuslik	doc_278690626959_item	2319307	et	3	main
ärkamine	doc_278690626959_item	2319308	et	4	main
19	doc_278690626959_item	2319309	et	2	main
sajandi	doc_278690626959_item	2319310	et	3	main
lõpupoole	doc_278690626959_item	2319311	et	4	main
rahvalauludes	doc_278690626959_item	2319312	et	3	main
kajastub	doc_278690626959_item	2319313	et	3	main
rahva	doc_278690626959_item	2319314	et	3	main
minevik	doc_278690626959_item	2319315	et	3	main
mistõttu	doc_278690626959_item	2319316	et	3	main
ka	doc_278690626959_item	2319318	et	3	main
rahvalauluga	doc_278690626959_item	2319319	et	4	main
tutvumine	doc_278690626959_item	2319320	et	4	main
on	doc_278690626959_item	2319317	et	4	main
ajaloo	doc_278690626959_item	2319323	et	4	main
esindab	doc_278690626959_item	2319330	et	3	main
kultuurile	doc_278690626959_item	2319332	et	3	main
regivärsiline	doc_278690626959_item	2319334	et	4	main
ukrainlane	doc_278690626959_item	2319239	et	3	main
ja	doc_278690626959_item	2319257	et	3	main
väga	doc_278690626959_item	2319263	et	3	main
jaoks	doc_278690626959_item	2319266	et	4	main
käisin	doc_278690626959_item	2319268	et	3	main
laulupidu	doc_278690626959_item	2319276	et	4	main
ja	doc_278690626959_item	2319277	et	3	main
see	doc_278690626959_item	2319289	et	3	main
pisut	doc_278690626959_item	2319321	et	3	main
väga	doc_278690626959_item	2319326	et	3	main
ma	doc_278690626959_item	2319336	et	3	main
arvan	doc_278690626959_item	2319337	et	3	main
see	doc_278690626959_item	2319339	et	3	main
inimsõbralik	doc_278690626959_item	2319344	et	3	main
kultuur	doc_278690626959_item	2319279	et	3	main
nad	doc_278690626959_item	2319280	et	3	main
rägivad	doc_278690626959_item	2319281	et	4	main
on	doc_278690626959_item	2319290	et	4	main
nagu	doc_278690626959_item	2319322	et	3	main
see	doc_278690626959_item	2319325	et	3	main
traditsioon	doc_278690626959_item	2319328	et	3	main
rahvalaul	doc_278690626959_item	2319335	et	4	main
väga	doc_278690626959_item	2319341	et	3	main
ja	doc_278690626959_item	2319343	et	3	main
huvitav	doc_278690626959_item	2319327	et	4	main
mis	doc_278690626959_item	2319329	et	4	main
iseloomulik	doc_278690626959_item	2319333	et	3	main
et	doc_278690626959_item	2319338	et	3	main
on	doc_278690626959_item	2319340	et	4	main
huvitav	doc_278690626959_item	2319342	et	4	main
e-post	doc_284706151123_item	2321444	et	3	main
saatmist	doc_284706151123_item	2321446	et	4	main
failide	doc_284706151123_item	2321448	et	3	main
uudised	doc_284706151123_item	2321451	et	3	main
rämpsposti	doc_284706151123_item	2321453	et	4	main
on	doc_284706151123_item	2321457	et	4	main
oma	doc_284706151123_item	2321467	et	4	main
salvestamist	doc_284706151123_item	2321472	et	4	main
ei	doc_284706151123_item	2321477	et	4	main
vaja	doc_284706151123_item	2321479	et	4	main
valmis	doc_284706151123_item	2321480	et	4	main
serveril	doc_284706151123_item	2321485	et	4	main
25	doc_284706151123_item	2321490	et	2	main
võimalik	doc_284706151123_item	2321493	et	3	main
võid	doc_284706151124_item	2321522	et	4	main
olla	doc_284706151124_item	2321523	et	3	main
saab	doc_284706151124_item	2321527	et	3	main
õigeaegselt	doc_284706151124_item	2321528	et	4	main
väga	doc_284706151124_item	2321532	et	3	main
hästi	doc_284706151124_item	2321533	et	3	main
otsingu-mootoreid	doc_284706151124_item	2321534	et	3	main
saab	doc_284706151124_item	2321546	et	3	main
minu	doc_284706151125_item	2321563	et	3	main
pakkuvad	doc_284706151125_item	2321570	et	4	main
linnas	doc_284706151125_item	2321595	et	4	main
lugeda	doc_284706151125_item	2321602	et	3	main
lisateenused	doc_284706151125_item	2321604	et	3	main
rannailm	doc_284706151125_item	2321610	et	3	main
spordiuudised	doc_284706151125_item	2321618	et	3	main
küsitlus	doc_284706151125_item	2321624	et	4	main
3	doc_284706151126_item	2321632	et	2	main
teha	doc_284706151126_item	2321637	et	3	main
html	doc_284706151126_item	2321642	et	4	main
eest	doc_284706151126_item	2321646	et	4	main
võite	doc_284706151126_item	2321666	et	4	main
kerge	doc_284706151126_item	2321670	et	4	main
disain	doc_284706151126_item	2321671	et	3	main
ja	doc_284706151126_item	2321672	et	3	main
kerge	doc_284706151126_item	2321673	et	4	main
eest	doc_284706151126_item	2321677	et	4	main
taha	doc_284706151126_item	2321693	et	4	main
võtta	doc_284706151126_item	2321695	et	3	main
e-postee	doc_284706151123_item	2321438	et	4	main
tasuta	doc_284706151123_item	2321443	et	4	main
värsked	doc_284706151123_item	2321450	et	4	main
meelelahutust	doc_284706151123_item	2321452	et	4	main
e-posti	doc_284706151123_item	2321460	et	4	main
programm	doc_284706151123_item	2321461	et	3	main
kasutaja	doc_284706151123_item	2321463	et	4	main
võib	doc_284706151123_item	2321464	et	3	main
ainult	doc_284706151123_item	2321473	et	4	main
ole	doc_284706151123_item	2321478	et	4	main
minu	doc_284706151123_item	2321484	et	3	main
eekkuus	doc_284706151123_item	2321491	et	4	main
kasutades	doc_284706151124_item	2321521	et	3	main
kindel	doc_284706151124_item	2321524	et	3	main
kõik	doc_284706151124_item	2321526	et	4	main
leenaee	doc_284706151124_item	2321536	et	4	main
võid	doc_284706151124_item	2321538	et	4	main
oma	doc_284706151124_item	2321540	et	4	main
unistuste	doc_284706151124_item	2321541	et	4	main
sinu	doc_284706151124_item	2321543	et	3	main
lehekülje	doc_284706151124_item	2321544	et	3	main
aadrissiks	doc_284706151124_item	2321545	et	4	main
pakub	doc_284706151124_item	2321558	et	3	main
jututoad	doc_284706151124_item	2321559	et	3	main
nimi	doc_284706151125_item	2321565	et	3	main
serveril	doc_284706151125_item	2321569	et	4	main
meie	doc_284706151125_item	2321594	et	4	main
päeva	doc_284706151125_item	2321596	et	4	main
pildil	doc_284706151125_item	2321599	et	3	main
või	doc_284706151125_item	2321601	et	4	main
serveril	doc_284706151125_item	2321605	et	4	main
on	doc_284706151125_item	2321613	et	4	main
reklaam	doc_284706151125_item	2321619	et	3	main
on	doc_284706151123_item	2321437	et	4	main
me	doc_284706151123_item	2321441	et	4	main
aadressiraamatud	doc_284706151123_item	2321447	et	4	main
säilitamist	doc_284706151123_item	2321449	et	4	main
serveril	doc_284706151123_item	2321456	et	4	main
leida	doc_284706151123_item	2321459	et	3	main
iga	doc_284706151123_item	2321462	et	4	main
väljasaatmine	doc_284706151123_item	2321466	et	3	main
pärast	doc_284706151123_item	2321469	et	4	main
vaja	doc_284706151123_item	2321474	et	4	main
käivitada	doc_284706151123_item	2321476	et	3	main
seda	doc_284706151123_item	2321482	et	3	main
mitmed	doc_284706151123_item	2321487	et	4	main
lisad	doc_284706151123_item	2321489	et	4	main
otsingu-võimalus	doc_284706151124_item	2321531	et	3	main
kasutajana	doc_284706151124_item	2321537	et	4	main
luua	doc_284706151124_item	2321539	et	4	main
wwwleenaeesinukasutajanimi	doc_284706151124_item	2321547	et	4	main
on	doc_284706151124_item	2321550	et	4	main
häälpost	doc_284706151124_item	2321561	et	4	main
prognoos	doc_284706151125_item	2321597	et	3	main
ühe	doc_284706151125_item	2321607	et	4	main
nädala	doc_284706151125_item	2321608	et	3	main
prognoos	doc_284706151125_item	2321609	et	3	main
ka	doc_284706151125_item	2321611	et	3	main
majandus	doc_284706151125_item	2321616	et	4	main
naiteleht	doc_284706151125_item	2321617	et	4	main
mis	doc_284706151126_item	2321639	et	4	main
vastu	doc_284706151126_item	2321641	et	3	main
php	doc_284706151126_item	2321643	et	4	main
võtab	doc_284706151126_item	2321647	et	3	main
vastu	doc_284706151126_item	2321648	et	3	main
1	doc_284706151126_item	2321652	et	2	main
spamifiltriga	doc_284706151126_item	2321654	et	4	main
märgitud	doc_284706151126_item	2321661	et	4	main
samuti	doc_284706151126_item	2321664	et	3	main
märgid	doc_284706151126_item	2321668	et	4	main
lisa	doc_284706151126_item	2321675	et	4	main
võite	doc_284706151126_item	2321679	et	4	main
ei	doc_284706151126_item	2321692	et	4	main
mailid	doc_284706151126_item	2321696	et	4	main
neist	doc_284706151126_item	2321697	et	4	main
ülevaade	doc_284706151127_item	2321698	et	3	main
postiteenistus	doc_284706151127_item	2321701	et	3	main
üks	doc_284706151127_item	2321703	et	3	main
portaalidest	doc_284706151127_item	2321706	et	3	main
interneti	doc_284706151127_item	2321708	et	4	main
sunee	doc_284706151127_item	2321711	et	4	main
miljoni	doc_284706151127_item	2321715	et	3	main
kõige	doc_284706151127_item	2321718	et	4	main
ülevaade	doc_284706151123_item	2321432	et	3	main
e-postee	doc_284706151123_item	2321433	et	4	main
minu	doc_284706151123_item	2321434	et	3	main
nimi	doc_284706151123_item	2321436	et	3	main
filtrid	doc_284706151123_item	2321454	et	4	main
võimalik	doc_284706151123_item	2321458	et	3	main
leida	doc_284706151123_item	2321465	et	3	main
on	doc_284706151123_item	2321486	et	4	main
on	doc_284706151123_item	2321492	et	4	main
osta	doc_284706151123_item	2321494	et	4	main
serveri	doc_284706151123_item	2321435	et	4	main
oma	doc_284706151123_item	2321439	et	4	main
kasutajatele	doc_284706151123_item	2321440	et	4	main
pakkume	doc_284706151123_item	2321442	et	4	main
sms-ide	doc_284706151123_item	2321445	et	3	main
minu	doc_284706151123_item	2321455	et	3	main
peamenüüs	doc_284706151123_item	2321468	et	3	main
oma	doc_284706151123_item	2321470	et	4	main
arvutile	doc_284706151123_item	2321471	et	4	main
seda	doc_284706151123_item	2321475	et	3	main
ehitama	doc_284706151123_item	2321481	et	4	main
ka	doc_284706151123_item	2321483	et	3	main
tasulised	doc_284706151123_item	2321488	et	4	main
serveriruumi	doc_284706151123_item	2321495	et	4	main
oma	doc_284706151123_item	2321496	et	4	main
koduleheküljele	doc_284706151123_item	2321497	et	3	main
serveriruumi	doc_284706151123_item	2321498	et	4	main
maht	doc_284706151123_item	2321499	et	3	main
on	doc_284706151123_item	2321500	et	4	main
50	doc_284706151123_item	2321501	et	2	main
mb	doc_284706151123_item	2321502	et	4	main
ülevaade	doc_284706151124_item	2321503	et	3	main
wwwleenaee	doc_284706151124_item	2321504	et	4	main
leenaee	doc_284706151124_item	2321505	et	4	main
pakub	doc_284706151124_item	2321506	et	3	main
järgmised	doc_284706151124_item	2321507	et	3	main
e-teenused	doc_284706151124_item	2321508	et	3	main
postkast	doc_284706151124_item	2321509	et	3	main
ennast	doc_284706151124_item	2321511	et	4	main
viiruste	doc_284706151124_item	2321512	et	4	main
ja	doc_284706151124_item	2321513	et	3	main
spämmi	doc_284706151124_item	2321514	et	4	main
kaitsta	doc_284706151124_item	2321510	et	4	main
eest	doc_284706151124_item	2321515	et	4	main
maht	doc_284706151124_item	2321516	et	3	main
mb	doc_284706151124_item	2321518	et	4	main
100	doc_284706151124_item	2321517	et	2	main
kalender-meeldetuletaja	doc_284706151124_item	2321519	et	4	main
kalendrit	doc_284706151124_item	2321520	et	3	main
et	doc_284706151124_item	2321525	et	3	main
koduleht	doc_284706151124_item	2321535	et	3	main
jaoks	doc_284706151124_item	2321549	et	4	main
leheküljel	doc_284706151124_item	2321551	et	3	main
ruumi	doc_284706151124_item	2321552	et	4	main
wwwleenazee	doc_284706151125_item	2321567	et	4	main
standardvarustused	doc_284706151125_item	2321568	et	3	main
päevauudised	doc_284706151125_item	2321571	et	3	main
nädala	doc_284706151125_item	2321592	et	3	main
näha	doc_284706151125_item	2321600	et	3	main
ekraanist	doc_284706151125_item	2321603	et	3	main
erinevad	doc_284706151125_item	2321614	et	4	main
arhiiv	doc_284706151125_item	2321621	et	3	main
server	doc_284706151126_item	2321627	et	4	main
pakkub	doc_284706151126_item	2321628	et	4	main
teile	doc_284706151126_item	2321629	et	4	main
kalender	doc_284706151126_item	2321631	et	3	main
tehtud	doc_284706151124_item	2321529	et	4	main
adressiraamat	doc_284706151124_item	2321530	et	4	main
kodulehekülje	doc_284706151124_item	2321542	et	3	main
failide	doc_284706151124_item	2321548	et	3	main
100	doc_284706151124_item	2321553	et	2	main
mb	doc_284706151124_item	2321554	et	4	main
aga	doc_284706151124_item	2321555	et	3	main
ka	doc_284706151124_item	2321556	et	3	main
leenaee	doc_284706151124_item	2321557	et	4	main
foorumid	doc_284706151124_item	2321560	et	3	main
ülevaade	doc_284706151125_item	2321562	et	3	main
e-post	doc_284706151125_item	2321564	et	3	main
on	doc_284706151125_item	2321566	et	4	main
suhtlemine	doc_284706151125_item	2321572	et	4	main
teine	doc_284706151125_item	2321573	et	3	main
inimene	doc_284706151125_item	2321574	et	3	main
teiste	doc_284706151125_item	2321575	et	4	main
inimestega	doc_284706151125_item	2321576	et	3	main
võib	doc_284706151125_item	2321577	et	3	main
teha	doc_284706151125_item	2321578	et	3	main
oma	doc_284706151125_item	2321579	et	4	main
koduleht	doc_284706151125_item	2321580	et	3	main
postkast	doc_284706151125_item	2321581	et	3	main
on	doc_284706151125_item	2321583	et	4	main
kus	doc_284706151125_item	2321582	et	3	main
adressiautomaatne	doc_284706151125_item	2321584	et	4	main
välja	doc_284706151125_item	2321585	et	4	main
loogimine	doc_284706151125_item	2321586	et	4	main
kui	doc_284706151125_item	2321587	et	3	main
tahate	doc_284706151125_item	2321588	et	3	main
melelahutus	doc_284706151125_item	2321589	et	4	main
on	doc_284706151125_item	2321590	et	4	main
kaks	doc_284706151125_item	2321591	et	3	main
edasi	doc_284706151125_item	2321593	et	3	main
võib	doc_284706151125_item	2321598	et	3	main
on	doc_284706151125_item	2321606	et	4	main
veel	doc_284706151125_item	2321612	et	4	main
uudised	doc_284706151125_item	2321615	et	3	main
uudiste	doc_284706151125_item	2321620	et	3	main
ülevaade	doc_284706151126_item	2321625	et	3	main
meie	doc_284706151126_item	2321626	et	4	main
võttab	doc_284706151126_item	2321640	et	4	main
lisa	doc_284706151126_item	2321644	et	4	main
post	doc_284706151126_item	2321650	et	3	main
prügikastiga	doc_284706151126_item	2321656	et	4	main
algab	doc_284706151126_item	2321658	et	3	main
puhkepäevad	doc_284706151126_item	2321660	et	3	main
tasu	doc_284706151126_item	2321676	et	4	main
kasutada	doc_284706151126_item	2321680	et	3	main
video	doc_284706151126_item	2321683	et	4	main
sõnumid	doc_284706151126_item	2321684	et	3	main
kui	doc_284706151126_item	2321690	et	3	main
kui	doc_284706151127_item	2321713	et	3	main
internet-võimalus	doc_284706151127_item	2321721	et	3	main
üle	doc_284706151127_item	2321723	et	3	main
käib	doc_284706151127_item	2321724	et	3	main
miljoni	doc_284706151127_item	2321731	et	3	main
kasutajatele	doc_284706151127_item	2321744	et	4	main
veel	doc_284706151127_item	2321756	et	4	main
me	doc_284706151127_item	2321757	et	4	main
häälpost	doc_284706151127_item	2321759	et	4	main
otsingu	doc_284706151127_item	2321764	et	3	main
samuti	doc_284706151127_item	2321766	et	3	main
on	doc_284706151127_item	2321779	et	4	main
sinus	doc_284706151127_item	2321781	et	3	main
essee	doc_284706151128_item	2321783	et	4	main
me	doc_284706151128_item	2321786	et	4	main
koolis	doc_284706151128_item	2321789	et	4	main
sel	doc_284706151128_item	2321790	et	3	main
me	doc_284706151128_item	2321792	et	4	main
ajal	doc_284706151128_item	2321796	et	4	main
alustasin	doc_284706151128_item	2321801	et	3	main
kinnos	doc_284706151128_item	2321821	et	4	main
praegu	doc_284706151128_item	2321823	et	3	main
koos	doc_284706151128_item	2321825	et	4	main
me	doc_284706151128_item	2321826	et	4	main
elame	doc_284706151128_item	2321827	et	3	main
me	doc_284706151128_item	2321832	et	4	main
kasvatame	doc_284706151128_item	2321834	et	3	main
last	doc_284706151128_item	2321835	et	4	main
ta	doc_284706151128_item	2321836	et	4	main
arusaadav	doc_284706151128_item	2321839	et	4	main
inimene	doc_284706151128_item	2321843	et	3	main
teame	doc_284706151129_item	2321853	et	3	main
hästi	doc_284706151129_item	2321857	et	3	main
sõnaga	doc_284706151129_item	2321863	et	3	main
ei	doc_284706151129_item	2321867	et	4	main
keemiatooteid	doc_284706151129_item	2321896	et	4	main
oma	doc_284706151129_item	2321906	et	4	main
töö	doc_284706151129_item	2321916	et	4	main
töö	doc_284706151129_item	2321932	et	4	main
see	doc_284706151129_item	2321933	et	3	main
ei	doc_284706151129_item	2321935	et	4	main
teda	doc_284706151129_item	2321954	et	4	main
ükskõik	doc_284706151129_item	2321955	et	3	main
jatkavad	doc_284706151129_item	2321956	et	4	main
lihtsalt	doc_284706151129_item	2321958	et	4	main
see	doc_284706151129_item	2321959	et	3	main
pärast	doc_284706151129_item	2321960	et	4	main
et	doc_284706151129_item	2321961	et	3	main
on	doc_284706151129_item	2321977	et	4	main
see	doc_284706151129_item	2321984	et	3	main
parem	doc_284706151129_item	2321986	et	4	main
vahendid	doc_284706151129_item	2321987	et	3	main
tootja	doc_284706151129_item	2321988	et	4	main
teha	doc_284706151129_item	2321991	et	3	main
sellest	doc_284706151129_item	2321993	et	4	main
on	doc_284706151129_item	2321994	et	4	main
probleem	doc_284706151129_item	2321995	et	3	main
forum	doc_284706151125_item	2321622	et	4	main
tänane	doc_284706151125_item	2321623	et	3	main
postkast	doc_284706151126_item	2321630	et	3	main
gb	doc_284706151126_item	2321633	et	4	main
kohta	doc_284706151126_item	2321635	et	4	main
koduleht	doc_284706151126_item	2321638	et	3	main
tasu	doc_284706151126_item	2321645	et	4	main
java	doc_284706151126_item	2321649	et	4	main
kast	doc_284706151126_item	2321651	et	3	main
punasega	doc_284706151126_item	2321662	et	4	main
kasutama	doc_284706151126_item	2321674	et	3	main
mail	doc_284706151126_item	2321688	et	4	main
adreseid	doc_284706151126_item	2321689	et	4	main
wwwsunee	doc_284706151127_item	2321702	et	4	main
eesti	doc_284706151127_item	2321707	et	4	main
kiirem	doc_284706151127_item	2321719	et	4	main
eesti	doc_284706151127_item	2321720	et	4	main
postkasti	doc_284706151127_item	2321722	et	4	main
kirjad	doc_284706151127_item	2321732	et	4	main
juhtiv	doc_284706151127_item	2321735	et	4	main
mitte	doc_284706151127_item	2321737	et	3	main
posti	doc_284706151127_item	2321739	et	4	main
postikast	doc_284706151127_item	2321745	et	3	main
kaitsega	doc_284706151127_item	2321748	et	3	main
ja	doc_284706151127_item	2321750	et	3	main
ja	doc_284706151127_item	2321753	et	3	main
kalender	doc_284706151127_item	2321760	et	3	main
see	doc_284706151127_item	2321768	et	3	main
helistada	doc_284706151127_item	2321774	et	3	main
kaudu	doc_284706151127_item	2321776	et	3	main
nägime	doc_284706151128_item	2321787	et	3	main
klassis	doc_284706151128_item	2321799	et	3	main
vestlust	doc_284706151128_item	2321802	et	3	main
serveri	doc_284706151126_item	2321634	et	4	main
võimalus	doc_284706151126_item	2321636	et	3	main
gb-ga	doc_284706151126_item	2321653	et	3	main
ja	doc_284706151126_item	2321655	et	3	main
kalender	doc_284706151126_item	2321657	et	3	main
esmaspäevast	doc_284706151126_item	2321659	et	4	main
värviga	doc_284706151126_item	2321663	et	4	main
te	doc_284706151126_item	2321665	et	4	main
teha	doc_284706151126_item	2321667	et	3	main
ja	doc_284706151126_item	2321669	et	3	main
te	doc_284706151126_item	2321678	et	4	main
häälipost	doc_284706151126_item	2321681	et	4	main
ja	doc_284706151126_item	2321682	et	3	main
te	doc_284706151126_item	2321685	et	4	main
võite	doc_284706151126_item	2321686	et	4	main
plokerida	doc_284706151126_item	2321687	et	4	main
te	doc_284706151126_item	2321691	et	4	main
vastu	doc_284706151126_item	2321694	et	3	main
wwwsunee	doc_284706151127_item	2321699	et	4	main
rahva	doc_284706151127_item	2321700	et	3	main
kõige	doc_284706151127_item	2321704	et	4	main
igapäevane	doc_284706151127_item	2321709	et	4	main
3	doc_284706151127_item	2321714	et	2	main
kasutajaid	doc_284706151127_item	2321716	et	4	main
sunee	doc_284706151127_item	2321717	et	4	main
läbi	doc_284706151127_item	2321725	et	4	main
päev	doc_284706151127_item	2321727	et	3	main
rohkem	doc_284706151127_item	2321728	et	4	main
kui	doc_284706151127_item	2321729	et	3	main
25	doc_284706151127_item	2321730	et	2	main
suuruse	doc_284706151127_item	2321747	et	4	main
rämpspostist	doc_284706151127_item	2321749	et	4	main
n	doc_284706151127_item	2321754	et	4	main
koduleht	doc_284706151127_item	2321761	et	3	main
ja	doc_284706151127_item	2321771	et	3	main
võimalus	doc_284706151127_item	2321773	et	3	main
interneti	doc_284706151127_item	2321775	et	4	main
majas	doc_284706151127_item	2321782	et	3	main
esimest	doc_284706151128_item	2321784	et	4	main
korda	doc_284706151128_item	2321785	et	4	main
õpisime	doc_284706151128_item	2321794	et	4	main
istus	doc_284706151128_item	2321798	et	4	main
koos	doc_284706151128_item	2321828	et	4	main
kohtume	doc_284706151128_item	2321830	et	3	main
on	doc_284706151128_item	2321837	et	4	main
loodusele	doc_284706151129_item	2321849	et	4	main
ohtlikud	doc_284706151129_item	2321850	et	3	main
väga	doc_284706151129_item	2321856	et	3	main
ühe	doc_284706151129_item	2321862	et	4	main
ilma	doc_284706151129_item	2321864	et	4	main
lihtsalt	doc_284706151129_item	2321897	et	4	main
ei	doc_284706151129_item	2321898	et	4	main
tea	doc_284706151129_item	2321899	et	4	main
nad	doc_284706151129_item	2321904	et	3	main
firmas	doc_284706151129_item	2321907	et	3	main
milline	doc_284706151129_item	2321918	et	3	main
teeb	doc_284706151129_item	2321919	et	3	main
suurematest	doc_284706151127_item	2321705	et	4	main
auditoorium	doc_284706151127_item	2321710	et	3	main
rohkem	doc_284706151127_item	2321712	et	4	main
iga	doc_284706151127_item	2321726	et	4	main
sunee	doc_284706151127_item	2321733	et	4	main
tasuliste	doc_284706151127_item	2321738	et	4	main
viirustest	doc_284706151127_item	2321751	et	4	main
tõlkjaga	doc_284706151127_item	2321752	et	3	main
e	doc_284706151127_item	2321755	et	4	main
pakkume	doc_284706151127_item	2321758	et	4	main
foorumid	doc_284706151127_item	2321762	et	3	main
võimalus	doc_284706151127_item	2321765	et	3	main
sunifon	doc_284706151127_item	2321767	et	4	main
moodne	doc_284706151127_item	2321770	et	3	main
wwwsunee	doc_284706151127_item	2321777	et	4	main
päike	doc_284706151127_item	2321780	et	3	main
koos	doc_284706151128_item	2321793	et	4	main
tema	doc_284706151128_item	2321797	et	4	main
koos	doc_284706151128_item	2321833	et	4	main
lõbus	doc_284706151128_item	2321838	et	4	main
meie	doc_284706151129_item	2321851	et	4	main
et	doc_284706151129_item	2321854	et	3	main
puhastavad	doc_284706151129_item	2321858	et	4	main
keemiatootest	doc_284706151129_item	2321865	et	4	main
saa	doc_284706151129_item	2321868	et	4	main
teadlased	doc_284706151129_item	2321892	et	3	main
toimet	doc_284706151129_item	2321903	et	3	main
seda	doc_284706151129_item	2321909	et	3	main
est	doc_284706151129_item	2321917	et	4	main
aga	doc_284706151129_item	2321921	et	3	main
kõrval	doc_284706151129_item	2321923	et	4	main
leidsimine	doc_284706151129_item	2321925	et	4	main
on	doc_284706151129_item	2321926	et	4	main
juba	doc_284706151129_item	2321927	et	3	main
raske	doc_284706151129_item	2321929	et	4	main
võivad	doc_284706151129_item	2321942	et	4	main
olla	doc_284706151129_item	2321943	et	3	main
ja	doc_284706151129_item	2321945	et	3	main
kasutama	doc_284706151129_item	2321957	et	3	main
seisukord	doc_284706151129_item	2321968	et	3	main
on	doc_284706151129_item	2321969	et	4	main
ka	doc_284706151129_item	2321970	et	3	main
meditsiinis	doc_284706151129_item	2321971	et	3	main
ja	doc_284706151129_item	2321972	et	3	main
näiteks	doc_284706151129_item	2321975	et	4	main
ebaeffektivne	doc_284706151129_item	2321978	et	4	main
reklaam	doc_284706151129_item	2321980	et	3	main
on	doc_284706151129_item	2321985	et	4	main
laeneb	doc_284706151127_item	2321734	et	4	main
positsiooni	doc_284706151127_item	2321736	et	4	main
teeninduste	doc_284706151127_item	2321740	et	4	main
seas	doc_284706151127_item	2321741	et	4	main
võimaldame	doc_284706151127_item	2321742	et	3	main
oma	doc_284706151127_item	2321743	et	4	main
piiritu	doc_284706151127_item	2321746	et	4	main
aadressiraamat	doc_284706151127_item	2321763	et	4	main
on	doc_284706151127_item	2321769	et	4	main
tasuta	doc_284706151127_item	2321772	et	4	main
see	doc_284706151127_item	2321778	et	3	main
teineteist	doc_284706151128_item	2321788	et	4	main
ajal	doc_284706151128_item	2321791	et	4	main
sel	doc_284706151128_item	2321795	et	3	main
mina	doc_284706151128_item	2321800	et	4	main
me	doc_284706151128_item	2321803	et	4	main
rääkisime	doc_284706151128_item	2321804	et	3	main
kontroolltöö	doc_284706151128_item	2321805	et	4	main
hinnatest	doc_284706151128_item	2321806	et	3	main
ta	doc_284706151128_item	2321807	et	4	main
on	doc_284706151128_item	2321808	et	4	main
huvitav	doc_284706151128_item	2321809	et	4	main
inimene	doc_284706151128_item	2321810	et	3	main
peale	doc_284706151128_item	2321811	et	4	main
õpimist	doc_284706151128_item	2321812	et	4	main
ta	doc_284706151128_item	2321813	et	4	main
saatis	doc_284706151128_item	2321814	et	3	main
mind	doc_284706151128_item	2321815	et	4	main
koduni	doc_284706151128_item	2321816	et	3	main
me	doc_284706151128_item	2321817	et	4	main
jalutasime	doc_284706151128_item	2321818	et	3	main
koos	doc_284706151128_item	2321819	et	4	main
käisime	doc_284706151128_item	2321820	et	3	main
elame	doc_284706151128_item	2321824	et	3	main
ja	doc_284706151128_item	2321829	et	3	main
igapäev	doc_284706151128_item	2321831	et	3	main
ja	doc_284706151128_item	2321840	et	3	main
on	doc_284706151129_item	2321846	et	4	main
tervisele	doc_284706151129_item	2321847	et	3	main
ja	doc_284706151129_item	2321848	et	3	main
keemiatooted	doc_284706151129_item	2321855	et	3	main
surepäraselt	doc_284706151129_item	2321860	et	4	main
me	doc_284706151129_item	2321866	et	4	main
reklaam	doc_284706151129_item	2321891	et	3	main
oma	doc_284706151129_item	2321900	et	4	main
keemiatoode	doc_284706151129_item	2321901	et	3	main
töötavad	doc_284706151129_item	2321905	et	4	main
ja	doc_284706151129_item	2321908	et	3	main
firma	doc_284706151129_item	2321910	et	4	main
maksab	doc_284706151129_item	2321911	et	3	main
temale	doc_284706151129_item	2321912	et	3	main
raha	doc_284706151129_item	2321913	et	4	main
ainult	doc_284706151129_item	2321914	et	4	main
kasu	doc_284706151129_item	2321920	et	4	main
keemiatoode	doc_284706151129_item	2321922	et	3	main
pikk	doc_284706151129_item	2321931	et	4	main
töö	doc_284706151129_item	2321934	et	4	main
tee	doc_284706151129_item	2321936	et	4	main
kasu	doc_284706151129_item	2321937	et	4	main
sellepärast	doc_284706151129_item	2321938	et	3	main
kõik	doc_284706151129_item	2321939	et	4	main
on	doc_284706151129_item	2321952	et	4	main
ohtlik	doc_284706151129_item	2321953	et	3	main
ja	doc_284706151129_item	2321965	et	3	main
mõjus	doc_284706151129_item	2321966	et	4	main
aga	doc_284706151128_item	2321822	et	3	main
lihtsalt	doc_284706151128_item	2321841	et	4	main
hea	doc_284706151128_item	2321842	et	4	main
essee	doc_284706151129_item	2321844	et	4	main
keemiatooted	doc_284706151129_item	2321845	et	3	main
kõik	doc_284706151129_item	2321852	et	4	main
pesu	doc_284706151129_item	2321859	et	4	main
ravivad	doc_284706151129_item	2321861	et	4	main
kodus	doc_284706151129_item	2321869	et	4	main
mitte	doc_284706151129_item	2321870	et	3	main
midagi	doc_284706151129_item	2321871	et	4	main
teha	doc_284706151129_item	2321872	et	3	main
aga	doc_284706151129_item	2321873	et	3	main
mina	doc_284706151129_item	2321874	et	4	main
arvan	doc_284706151129_item	2321875	et	3	main
et	doc_284706151129_item	2321876	et	3	main
see	doc_284706151129_item	2321877	et	3	main
on	doc_284706151129_item	2321878	et	4	main
vale	doc_284706151129_item	2321879	et	4	main
mina	doc_284706151129_item	2321880	et	4	main
arvan	doc_284706151129_item	2321881	et	3	main
et	doc_284706151129_item	2321882	et	3	main
suurem	doc_284706151129_item	2321883	et	4	main
osast	doc_284706151129_item	2321884	et	4	main
infost	doc_284706151129_item	2321885	et	3	main
mida	doc_284706151129_item	2321886	et	4	main
meie	doc_284706151129_item	2321887	et	4	main
teame	doc_284706151129_item	2321888	et	3	main
keemiatootest	doc_284706151129_item	2321889	et	4	main
on	doc_284706151129_item	2321890	et	4	main
milleseid	doc_284706151129_item	2321893	et	4	main
leiavad	doc_284706151129_item	2321894	et	3	main
uut	doc_284706151129_item	2321895	et	3	main
kõrval	doc_284706151129_item	2321902	et	4	main
selle	doc_284706151129_item	2321915	et	4	main
toimet	doc_284706151129_item	2321924	et	3	main
teine	doc_284706151129_item	2321928	et	3	main
keemia	doc_284706151129_item	2321940	et	4	main
tooted	doc_284706151129_item	2321941	et	3	main
ohtlik	doc_284706151129_item	2321944	et	3	main
mõnikord	doc_284706151129_item	2321974	et	3	main
rohu	doc_284706151129_item	2321976	et	4	main
teistmoodi	doc_284706151129_item	2321982	et	3	main
valetab	doc_284706151129_item	2321989	et	3	main
raha	doc_284706151129_item	2321992	et	4	main
ja	doc_284706151129_item	2321930	et	3	main
isegi	doc_284706151129_item	2321946	et	4	main
kui	doc_284706151129_item	2321947	et	3	main
teavad	doc_284706151129_item	2321948	et	3	main
et	doc_284706151129_item	2321949	et	3	main
keemia	doc_284706151129_item	2321950	et	4	main
toote	doc_284706151129_item	2321951	et	4	main
ta	doc_284706151129_item	2321962	et	4	main
on	doc_284706151129_item	2321963	et	4	main
odav	doc_284706151129_item	2321964	et	3	main
toitumises	doc_284706151129_item	2321973	et	4	main
aga	doc_284706151129_item	2321979	et	3	main
räägib	doc_284706151129_item	2321981	et	3	main
võimalikult	doc_284706151132_item	2322473	et	4	main
heledates	doc_284706151132_item	2322478	et	3	main
selline	doc_284706151129_item	2321967	et	4	main
et	doc_284706151129_item	2321983	et	3	main
et	doc_284706151129_item	2321990	et	3	main
nõuannet	doc_284706151132_item	2322471	et	4	main
kasutada	doc_284706151132_item	2322475	et	3	main
laed	doc_284706151132_item	2322482	et	4	main
valgustus	doc_284706151132_item	2322485	et	4	main
on	doc_284706151132_item	2322488	et	4	main
kaldteedel	doc_284706151132_item	2322492	et	3	main
kus	doc_284706151132_item	2322496	et	3	main
inimesed	doc_284706151132_item	2322499	et	3	main
heleduste	doc_284706151132_item	2322506	et	4	main
ei	doc_284706151132_item	2322521	et	4	main
töötaja	doc_284706151132_item	2322523	et	4	main
6	doc_284706151132_item	2322525	et	2	main
valgusallikad	doc_284706151132_item	2322527	et	3	main
eemaldada	doc_284706151132_item	2322534	et	3	main
5	doc_284706151132_item	2322538	et	2	main
ergonoomilise	doc_284706151132_item	2322539	et	4	main
1	doc_284706151132_item	2322542	et	2	main
kindlustada	doc_284706151132_item	2322545	et	3	main
töötasapinna	doc_284706151132_item	2322555	et	3	main
hea	doc_284706151132_item	2322560	et	4	main
2	doc_284706151132_item	2322562	et	2	main
arvutitöökoha	doc_284706151132_item	2322567	et	4	main
töötajad	doc_284706151132_item	2322569	et	4	main
töökoha	doc_284706151132_item	2322574	et	4	main
kuvari	doc_284706151132_item	2322576	et	3	main
et	doc_284706151132_item	2322619	et	3	main
töötamiskoha	doc_284706151132_item	2322624	et	4	main
soovitused	doc_284706151132_item	2322628	et	4	main
128	doc_284706151132_item	2322630	et	2	main
ergonoomilisest	doc_284706151132_item	2322631	et	4	main
tervise	doc_284706151132_item	2322640	et	3	main
on	doc_284706151132_item	2322645	et	4	main
lahendusi	doc_284706151132_item	2322650	et	4	main
saab	doc_284706151132_item	2322652	et	3	main
valdkondades	doc_284706151132_item	2322655	et	3	main
kergesti	doc_284706151132_item	2322661	et	3	main
wwwsekretaree	doc_284706151132_item	2322670	et	4	main
ja	doc_284706151132_item	2322693	et	3	main
väsimist	doc_284706151132_item	2322700	et	4	main
kuiva	doc_284706151132_item	2322702	et	4	main
silma	doc_284706151132_item	2322703	et	4	main
on	doc_284706151132_item	2322719	et	4	main
ja	doc_284706151132_item	2322723	et	3	main
1	doc_284706151132_item	2322468	et	2	main
2	doc_284706151132_item	2322477	et	2	main
seinad	doc_284706151132_item	2322480	et	3	main
3	doc_284706151132_item	2322486	et	2	main
treppidel	doc_284706151132_item	2322491	et	3	main
ja	doc_284706151132_item	2322493	et	3	main
viibida	doc_284706151132_item	2322498	et	3	main
4	doc_284706151132_item	2322500	et	2	main
töökoha	doc_284706151132_item	2322508	et	4	main
valgustamisel	doc_284706151132_item	2322509	et	4	main
5	doc_284706151132_item	2322510	et	2	main
on	doc_284706151132_item	2322512	et	4	main
täpsust	doc_284706151132_item	2322514	et	4	main
nõudvaks	doc_284706151132_item	2322515	et	4	main
tööks	doc_284706151132_item	2322516	et	3	main
tuleb	doc_284706151132_item	2322517	et	3	main
veenduda	doc_284706151132_item	2322518	et	3	main
et	doc_284706151132_item	2322519	et	3	main
kohtvalgustus	doc_284706151132_item	2322520	et	4	main
nägemisvälja	doc_284706151132_item	2322524	et	4	main
panna	doc_284706151132_item	2322530	et	4	main
soovitav	doc_284706151132_item	2322543	et	4	main
joonel	doc_284706151132_item	2322550	et	4	main
sobiva	doc_284706151132_item	2322554	et	4	main
ühel	doc_284706151132_item	2322557	et	3	main
sellist	doc_284706151132_item	2322566	et	4	main
ja	doc_284706151132_item	2322577	et	3	main
töötajaid	doc_284706151132_item	2322617	et	4	main
nad	doc_284706151132_item	2322620	et	3	main
kujundust	doc_284706151132_item	2322625	et	4	main
ergonoomilised	doc_284706151132_item	2322627	et	4	main
koosneva	doc_284706151132_item	2322633	et	4	main
väljaande	doc_284706151132_item	2322634	et	4	main
eesmärgiks	doc_284706151132_item	2322635	et	3	main
on	doc_284706151132_item	2322636	et	4	main
anda	doc_284706151132_item	2322637	et	3	main
töötingimuste	doc_284706151132_item	2322642	et	3	main
lihtsaid	doc_284706151132_item	2322646	et	3	main
käsiraamatus	doc_284706151132_item	2322656	et	4	main
ergoonomika	doc_284706151132_item	2322658	et	4	main
aitab	doc_284706151132_item	2322660	et	3	main
eva-maria	doc_284706151132_item	2322668	et	4	main
reimers	doc_284706151132_item	2322669	et	4	main
ja	doc_284706151132_item	2322701	et	3	main
kipitavad	doc_284706151132_item	2322706	et	4	main
sageli	doc_284706151132_item	2322708	et	3	main
silm	doc_284706151132_item	2322710	et	3	main
turjalihased	doc_284706151132_item	2322718	et	4	main
lihased	doc_284706151132_item	2322735	et	4	main
palju	doc_284706151132_item	2322745	et	4	main
ülekoormushaigusi	doc_284706151132_item	2322747	et	4	main
eriti	doc_284706151132_item	2322750	et	3	main
heledad	doc_284706151132_item	2322755	et	3	main
suuremaks	doc_284706151132_item	2322760	et	4	main
peegeldab	doc_284706151132_item	2322764	et	3	main
arvestada	doc_284706151132_item	2322774	et	3	main
sooga	doc_284706151132_item	2322778	et	4	main
töökeskkonnaspetsialist	doc_284706151132_item	2322780	et	3	main
alal	doc_284706151132_item	2322783	et	4	main
pädev	doc_284706151132_item	2322784	et	3	main
täitma	doc_284706151132_item	2322796	et	3	main
töötervishoidu-	doc_284706151132_item	2322797	et	4	main
juhend	doc_284706151132_item	2322467	et	3	main
valgustusega	doc_284706151132_item	2322470	et	4	main
rohkem	doc_284706151132_item	2322474	et	4	main
päevavalgust	doc_284706151132_item	2322476	et	4	main
ruumi	doc_284706151132_item	2322484	et	4	main
koridorides	doc_284706151132_item	2322490	et	3	main
kõikides	doc_284706151132_item	2322494	et	4	main
vältida	doc_284706151132_item	2322503	et	3	main
6	doc_284706151132_item	2322469	et	2	main
1	doc_284706151132_item	2322472	et	2	main
värvitoonides	doc_284706151132_item	2322479	et	3	main
ja	doc_284706151132_item	2322481	et	3	main
soovitav	doc_284706151132_item	2322501	et	4	main
nägemisväljas	doc_284706151132_item	2322504	et	3	main
kohtvalgustid	doc_284706151132_item	2322511	et	3	main
kitsendaks	doc_284706151132_item	2322522	et	3	main
paigutada	doc_284706151132_item	2322526	et	3	main
ümber	doc_284706151132_item	2322528	et	3	main
katted	doc_284706151132_item	2322532	et	3	main
nõuannet	doc_284706151132_item	2322541	et	4	main
on	doc_284706151132_item	2322544	et	4	main
sobiva	doc_284706151132_item	2322546	et	4	main
istekoha	doc_284706151132_item	2322547	et	4	main
kõrguse	doc_284706151132_item	2322548	et	4	main
alumise	doc_284706151132_item	2322552	et	3	main
kõrguse	doc_284706151132_item	2322556	et	4	main
küünarnukkidega	doc_284706151132_item	2322559	et	3	main
vahekord	doc_284706151132_item	2322561	et	3	main
soovitav	doc_284706151132_item	2322563	et	4	main
kasutada	doc_284706151132_item	2322565	et	3	main
kohandamine	doc_284706151132_item	2322575	et	4	main
parandavad	doc_284706151132_item	2322483	et	4	main
valgustus	doc_284706151132_item	2322487	et	4	main
vajalik	doc_284706151132_item	2322489	et	3	main
kohtades	doc_284706151132_item	2322495	et	3	main
võivad	doc_284706151132_item	2322497	et	4	main
on	doc_284706151132_item	2322502	et	4	main
suuri	doc_284706151132_item	2322505	et	3	main
erinevusi	doc_284706151132_item	2322507	et	4	main
sobivad	doc_284706151132_item	2322513	et	4	main
või	doc_284706151132_item	2322529	et	4	main
pimestavat	doc_284706151132_item	2322535	et	4	main
töökoha	doc_284706151132_item	2322540	et	4	main
põlvekedra	doc_284706151132_item	2322551	et	3	main
mida	doc_284706151132_item	2322568	et	4	main
saavad	doc_284706151132_item	2322570	et	4	main
enda	doc_284706151132_item	2322571	et	4	main
järgi	doc_284706151132_item	2322572	et	4	main
sobivasse	doc_284706151132_item	2322579	et	4	main
vastavalt	doc_284706151132_item	2322581	et	4	main
silmade	doc_284706151132_item	2322583	et	3	main
ja	doc_284706151132_item	2322584	et	3	main
oma	doc_284706151132_item	2322623	et	4	main
abi	doc_284706151132_item	2322638	et	4	main
parandamiseks	doc_284706151132_item	2322643	et	4	main
praktilisi	doc_284706151132_item	2322647	et	3	main
olev	doc_284706151132_item	2322657	et	4	main
ülekoormus	doc_284706151132_item	2322695	et	3	main
kurdetakse	doc_284706151132_item	2322697	et	3	main
silmade	doc_284706151132_item	2322699	et	3	main
sindroomi	doc_284706151132_item	2322704	et	4	main
silmad	doc_284706151132_item	2322705	et	4	main
selja-	doc_284706151132_item	2322716	et	3	main
pinges	doc_284706151132_item	2322722	et	4	main
kui	doc_284706151132_item	2322725	et	3	main
töötaja	doc_284706151132_item	2322728	et	4	main
küljel	doc_284706151132_item	2322730	et	3	main
kätel	doc_284706151132_item	2322749	et	3	main
liigutaval	doc_284706151132_item	2322752	et	4	main
valguse	doc_284706151132_item	2322765	et	4	main
ning	doc_284706151132_item	2322767	et	3	main
töötajate	doc_284706151132_item	2322775	et	4	main
või	doc_284706151132_item	2322786	et	4	main
on	doc_284706151132_item	2322794	et	4	main
nendele	doc_284706151132_item	2322531	et	4	main
et	doc_284706151132_item	2322533	et	3	main
valgust	doc_284706151132_item	2322536	et	4	main
1	doc_284706151132_item	2322537	et	2	main
ühel	doc_284706151132_item	2322549	et	3	main
servaga	doc_284706151132_item	2322553	et	3	main
joonel	doc_284706151132_item	2322558	et	4	main
on	doc_284706151132_item	2322564	et	4	main
kohandada	doc_284706151132_item	2322573	et	3	main
klaviatuuri	doc_284706151132_item	2322578	et	4	main
asendisse	doc_284706151132_item	2322580	et	3	main
käte	doc_284706151132_item	2322585	et	3	main
kõrgusele	doc_284706151132_item	2322586	et	4	main
vähendab	doc_284706151132_item	2322587	et	3	main
töötaja	doc_284706151132_item	2322582	et	4	main
töötaja	doc_284706151132_item	2322588	et	4	main
kehaasendi	doc_284706151132_item	2322589	et	3	main
pinget	doc_284706151132_item	2322590	et	3	main
3	doc_284706151132_item	2322591	et	2	main
soovitav	doc_284706151132_item	2322592	et	4	main
on	doc_284706151132_item	2322593	et	4	main
regulaarselt	doc_284706151132_item	2322594	et	4	main
korraldada	doc_284706151132_item	2322595	et	3	main
arvutiga	doc_284706151132_item	2322596	et	4	main
töötavatele	doc_284706151132_item	2322597	et	4	main
töötajatele	doc_284706151132_item	2322598	et	4	main
silmade	doc_284706151132_item	2322599	et	3	main
kontrolli	doc_284706151132_item	2322600	et	4	main
ning	doc_284706151132_item	2322601	et	3	main
kasutada	doc_284706151132_item	2322602	et	3	main
sobivaid	doc_284706151132_item	2322603	et	4	main
prille	doc_284706151132_item	2322604	et	3	main
4	doc_284706151132_item	2322605	et	2	main
vajalik	doc_284706151132_item	2322606	et	3	main
on	doc_284706151132_item	2322607	et	4	main
korraldada	doc_284706151132_item	2322608	et	3	main
arvutiga	doc_284706151132_item	2322609	et	4	main
töötavatele	doc_284706151132_item	2322610	et	4	main
inimestele	doc_284706151132_item	2322611	et	3	main
kaasaegset	doc_284706151132_item	2322612	et	3	main
koolitus	doc_284706151132_item	2322613	et	4	main
5	doc_284706151132_item	2322614	et	2	main
tuleb	doc_284706151132_item	2322615	et	3	main
julgustada	doc_284706151132_item	2322616	et	3	main
selleks	doc_284706151132_item	2322618	et	4	main
ise	doc_284706151132_item	2322621	et	4	main
soovitusest	doc_284706151132_item	2322632	et	4	main
ohutuse	doc_284706151132_item	2322639	et	4	main
ja	doc_284706151132_item	2322648	et	3	main
odavaid	doc_284706151132_item	2322649	et	3	main
rakendada	doc_284706151132_item	2322653	et	3	main
küsimustik	doc_284706151132_item	2322659	et	3	main
hinnata	doc_284706151132_item	2322662	et	4	main
ergonoomilisust	doc_284706151132_item	2322664	et	4	main
töökoha	doc_284706151132_item	2322666	et	4	main
ergonoomika	doc_284706151132_item	2322667	et	4	main
silmade	doc_284706151132_item	2322694	et	3	main
tihti	doc_284706151132_item	2322696	et	3	main
ka	doc_284706151132_item	2322698	et	3	main
peab	doc_284706151132_item	2322709	et	4	main
arvutiga	doc_284706151132_item	2322711	et	4	main
töötades	doc_284706151132_item	2322712	et	3	main
olema	doc_284706151132_item	2322713	et	4	main
liialt	doc_284706151132_item	2322714	et	4	main
kontoritöötajail	doc_284706151132_item	2322720	et	3	main
sageli	doc_284706151132_item	2322721	et	3	main
arvutitöökoht	doc_284706151132_item	2322726	et	3	main
eri	doc_284706151132_item	2322733	et	4	main
tööd	doc_284706151132_item	2322738	et	4	main
ka	doc_284706151132_item	2322748	et	3	main
valge	doc_284706151132_item	2322762	et	4	main
alla	doc_284706151132_item	2322766	et	3	main
teeb	doc_284706151132_item	2322768	et	3	main
näiliselt	doc_284706151132_item	2322770	et	4	main
värvivalikul	doc_284706151132_item	2322772	et	3	main
töökeskkonna	doc_284706151132_item	2322782	et	3	main
insener	doc_284706151132_item	2322785	et	3	main
töökeskkonnaõpetust	doc_284706151132_item	2322788	et	3	main
saanud	doc_284706151132_item	2322789	et	4	main
parandaksid	doc_284706151132_item	2322622	et	4	main
1	doc_284706151132_item	2322626	et	2	main
selle	doc_284706151132_item	2322629	et	4	main
ja	doc_284706151132_item	2322641	et	3	main
siin	doc_284706151132_item	2322644	et	4	main
mida	doc_284706151132_item	2322651	et	4	main
mitmesugustes	doc_284706151132_item	2322654	et	3	main
töökohtade	doc_284706151132_item	2322663	et	3	main
1	doc_284706151132_item	2322665	et	2	main
väike	doc_284706151132_item	2322671	et	4	main
teejuht	doc_284706151132_item	2322672	et	3	main
ergonoomika-	doc_284706151132_item	2322673	et	4	main
ja	doc_284706151132_item	2322674	et	3	main
ohutusalase	doc_284706151132_item	2322675	et	4	main
teabe	doc_284706151132_item	2322676	et	3	main
otsimiseks	doc_284706151132_item	2322677	et	4	main
virve	doc_284706151132_item	2322679	et	4	main
internetis	doc_284706151132_item	2322678	et	4	main
siirak	doc_284706151132_item	2322680	et	4	main
wwwtturaamatee	doc_284706151132_item	2322681	et	4	main
1	doc_284706151132_item	2322682	et	2	main
katrin	doc_284706151132_item	2322683	et	4	main
martinsoni	doc_284706151132_item	2322684	et	4	main
sõnul	doc_284706151132_item	2322685	et	3	main
on	doc_284706151132_item	2322686	et	4	main
kontoritöös	doc_284706151132_item	2322687	et	3	main
peamine	doc_284706151132_item	2322688	et	3	main
probleeme	doc_284706151132_item	2322689	et	3	main
sundasend	doc_284706151132_item	2322690	et	3	main
selja	doc_284706151132_item	2322691	et	3	main
käte	doc_284706151132_item	2322692	et	3	main
väsivad	doc_284706151132_item	2322707	et	4	main
avatud	doc_284706151132_item	2322715	et	4	main
ja	doc_284706151132_item	2322717	et	3	main
erineva	doc_284706151132_item	2322736	et	4	main
tõenäosust	doc_284706151132_item	2322744	et	3	main
esineb	doc_284706151132_item	2322746	et	3	main
arvutihiirt	doc_284706151132_item	2322751	et	3	main
seinte	doc_284706151132_item	2322754	et	3	main
toonid	doc_284706151132_item	2322757	et	4	main
ja	doc_284706151132_item	2322761	et	3	main
ja	doc_284706151132_item	2322777	et	3	main
on	doc_284706151132_item	2322781	et	4	main
muu	doc_284706151132_item	2322787	et	4	main
spetsialist	doc_284706151132_item	2322790	et	3	main
ettevõttes	doc_284706151132_item	2322791	et	3	main
tööandja	doc_284706151132_item	2322793	et	4	main
ja	doc_284706151132_item	2322798	et	3	main
tööohutusalaseid	doc_284706151132_item	2322799	et	4	main
1	doc_284706151132_item	2322801	et	2	main
ülesandeid	doc_284706151132_item	2322800	et	3	main
sain	doc_284706151132_item	2322802	et	3	main
40	doc_284706151132_item	2322804	et	2	main
kokku	doc_284706151132_item	2322803	et	3	main
punkti	doc_284706151132_item	2322805	et	4	main
1	doc_284706151132_item	2322806	et	2	main
pc	doc_284706151132_item	2322807	et	4	main
world	doc_284706151132_item	2322808	et	4	main
praktiline	doc_284706151132_item	2322809	et	3	main
arvutikasutaja	doc_284706151132_item	2322810	et	4	main
valusad	doc_284706151132_item	2322724	et	3	main
asetseb	doc_284706151132_item	2322727	et	3	main
ühel	doc_284706151132_item	2322729	et	3	main
siis	doc_284706151132_item	2322731	et	3	main
teevad	doc_284706151132_item	2322732	et	3	main
kehapoolte	doc_284706151132_item	2322734	et	4	main
pingega	doc_284706151132_item	2322737	et	3	main
mis	doc_284706151132_item	2322739	et	4	main
suurendab	doc_284706151132_item	2322740	et	3	main
valude	doc_284706151132_item	2322741	et	3	main
ja	doc_284706151132_item	2322742	et	3	main
ülekoormushaiguste	doc_284706151132_item	2322743	et	4	main
käel	doc_284706151132_item	2322753	et	3	main
soojad	doc_284706151132_item	2322756	et	3	main
muudavad	doc_284706151132_item	2322758	et	4	main
ruumi	doc_284706151132_item	2322759	et	4	main
lagi	doc_284706151132_item	2322763	et	4	main
ruumi	doc_284706151132_item	2322769	et	4	main
kõrgemaks	doc_284706151132_item	2322771	et	4	main
tuleb	doc_284706151132_item	2322773	et	3	main
vanuse	doc_284706151132_item	2322776	et	4	main
1	doc_284706151132_item	2322779	et	2	main
keda	doc_284706151132_item	2322792	et	4	main
volitanud	doc_284706151132_item	2322795	et	4	main
eks	doc_284706151134_item	2323221	et	3	main
meesterahvas	doc_284706151134_item	2323231	et	4	main
siis	doc_284706151134_item	2323237	et	3	main
1	doc_284706151134_item	2323247	et	2	main
1	doc_284706151134_item	2323251	et	2	main
2	doc_284706151134_item	2323254	et	2	main
kodukotled	doc_284706151134_item	2323260	et	4	main
kuumad	doc_284706151134_item	2323277	et	4	main
joogid	doc_284706151134_item	2323282	et	4	main
se	doc_284706151135_item	2323295	et	4	main
kolm	doc_284706151135_item	2323302	et	3	main
ja	doc_284706151135_item	2323305	et	3	main
võileivad	doc_284706151135_item	2323309	et	3	main
heeringa	doc_284706151135_item	2323312	et	3	main
oli	doc_284706151135_item	2323314	et	3	main
kohvivahukoorega	doc_284706151135_item	2323320	et	3	main
mina	doc_284706151135_item	2323323	et	4	main
minu	doc_284706151135_item	2323325	et	3	main
eriti	doc_284706151135_item	2323327	et	3	main
maitsev	doc_284706151135_item	2323328	et	4	main
oli	doc_284706151135_item	2323329	et	3	main
see	doc_284706151135_item	2323330	et	3	main
õde	doc_284706151136_item	2323345	et	4	main
onud	doc_284706151136_item	2323348	et	3	main
magustoitu	doc_284706151136_item	2323363	et	4	main
restoranis	doc_284706151134_item	2323188	et	3	main
ma	doc_284706151134_item	2323242	et	3	main
salatid	doc_284706151134_item	2323248	et	3	main
krabisalat	doc_284706151134_item	2323250	et	3	main
supid	doc_284706151134_item	2323252	et	3	main
šnitsel	doc_284706151134_item	2323259	et	2	main
lõhe	doc_284706151134_item	2323261	et	4	main
kohv	doc_284706151134_item	2323279	et	3	main
tee	doc_284706151134_item	2323280	et	4	main
mahl	doc_284706151134_item	2323283	et	3	main
1	doc_284706151134_item	2323286	et	2	main
pidu	doc_284706151135_item	2323296	et	4	main
oli	doc_284706151135_item	2323297	et	3	main
sõime	doc_284706151135_item	2323308	et	4	main
veel	doc_284706151135_item	2323313	et	4	main
valmistas	doc_284706151135_item	2323322	et	3	main
ei	doc_284706151135_item	2323332	et	4	main
oli	doc_284706151135_item	2323333	et	3	main
baaris	doc_284706151136_item	2323341	et	3	main
olid	doc_284706151136_item	2323343	et	4	main
mina	doc_284706151136_item	2323344	et	4	main
võileivad	doc_284706151136_item	2323357	et	3	main
ja	doc_284706151136_item	2323361	et	3	main
essee	doc_284706151137_item	2323372	et	4	main
pidu	doc_284706151137_item	2323378	et	4	main
umbes	doc_284706151137_item	2323389	et	4	main
inimesi	doc_284706151137_item	2323391	et	4	main
käin	doc_284706151134_item	2323187	et	3	main
väga	doc_284706151134_item	2323189	et	3	main
harva	doc_284706151134_item	2323190	et	4	main
oma	doc_284706151134_item	2323191	et	4	main
kodulinnas	doc_284706151134_item	2323192	et	4	main
on	doc_284706151134_item	2323193	et	4	main
väga	doc_284706151134_item	2323194	et	3	main
vähe	doc_284706151134_item	2323195	et	3	main
haid	doc_284706151134_item	2323196	et	4	main
restorane	doc_284706151134_item	2323197	et	3	main
ma	doc_284706151134_item	2323198	et	3	main
olen	doc_284706151134_item	2323199	et	3	main
käinud	doc_284706151134_item	2323200	et	4	main
leo	doc_284706151134_item	2323201	et	4	main
baaris	doc_284706151134_item	2323202	et	3	main
privadis	doc_284706151134_item	2323203	et	4	main
pubis	doc_284706151134_item	2323204	et	4	main
fregat	doc_284706151134_item	2323205	et	4	main
restoranis	doc_284706151134_item	2323206	et	3	main
ja	doc_284706151134_item	2323207	et	3	main
kalevi	doc_284706151134_item	2323208	et	3	main
kohvikus	doc_284706151134_item	2323209	et	3	main
ma	doc_284706151134_item	2323210	et	3	main
läheksin	doc_284706151134_item	2323211	et	3	main
sinna	doc_284706151134_item	2323212	et	3	main
oma	doc_284706151134_item	2323213	et	4	main
hea	doc_284706151134_item	2323214	et	4	main
sõbraga	doc_284706151134_item	2323215	et	3	main
ma	doc_284706151134_item	2323216	et	3	main
ei	doc_284706151134_item	2323217	et	4	main
läheks	doc_284706151134_item	2323218	et	3	main
sinna	doc_284706151134_item	2323219	et	3	main
oma	doc_284706151134_item	2323220	et	4	main
abikaasaga	doc_284706151134_item	2323222	et	3	main
ma	doc_284706151134_item	2323224	et	3	main
mehega	doc_284706151134_item	2323227	et	3	main
ma	doc_284706151134_item	2323233	et	3	main
väljas	doc_284706151134_item	2323235	et	4	main
maksa	doc_284706151134_item	2323238	et	4	main
igaüks	doc_284706151134_item	2323239	et	3	main
essee	doc_284706151134_item	2323185	et	4	main
ma	doc_284706151134_item	2323186	et	3	main
käin	doc_284706151134_item	2323225	et	3	main
siis	doc_284706151134_item	2323228	et	3	main
maksab	doc_284706151134_item	2323230	et	3	main
käin	doc_284706151134_item	2323234	et	3	main
eest	doc_284706151134_item	2323241	et	4	main
kirjutan	doc_284706151134_item	2323243	et	3	main
baari	doc_284706151134_item	2323245	et	4	main
menüüst	doc_284706151134_item	2323246	et	3	main
seljanka	doc_284706151134_item	2323253	et	4	main
prantsuse	doc_284706151134_item	2323257	et	3	main
kakao	doc_284706151134_item	2323281	et	4	main
mineraalvesi	doc_284706151134_item	2323284	et	4	main
õlu	doc_284706151134_item	2323293	et	3	main
kohal	doc_284706151135_item	2323300	et	4	main
minu	doc_284706151135_item	2323303	et	3	main
minu	doc_284706151135_item	2323306	et	3	main
juustuga	doc_284706151135_item	2323310	et	3	main
aramiskoolaga	doc_284706151135_item	2323318	et	4	main
lauas	doc_284706151135_item	2323334	et	3	main
ema	doc_284706151136_item	2323347	et	4	main
isa	doc_284706151136_item	2323350	et	4	main
kana	doc_284706151136_item	2323359	et	4	main
see	doc_284706151137_item	2323373	et	3	main
oli	doc_284706151137_item	2323374	et	3	main
18-aastane	doc_284706151137_item	2323383	et	4	main
mul	doc_284706151137_item	2323385	et	3	main
võibolla	doc_284706151137_item	2323423	et	4	main
minu	doc_284706151138_item	2323437	et	3	main
oli	doc_284706151138_item	2323444	et	3	main
sõber	doc_284706151138_item	2323446	et	3	main
puuviljad	doc_284706151138_item	2323459	et	3	main
oli	doc_284706151138_item	2323460	et	3	main
banaanikastmega	doc_284706151138_item	2323466	et	3	main
oli	doc_284706151138_item	2323470	et	3	main
maitsev	doc_284706151138_item	2323471	et	4	main
veini	doc_284706151138_item	2323475	et	4	main
krevettiga	doc_284706151138_item	2323483	et	4	main
kohal	doc_284706151139_item	2323495	et	4	main
abikaasa	doc_284706151139_item	2323502	et	4	main
me	doc_284706151139_item	2323505	et	4	main
salatid	doc_284706151139_item	2323507	et	3	main
liha	doc_284706151139_item	2323509	et	4	main
koos	doc_284706151139_item	2323510	et	4	main
ja	doc_284706151139_item	2323517	et	3	main
šampaani	doc_284706151139_item	2323521	et	2	main
mehed	doc_284706151139_item	2323523	et	3	main
ole	doc_284706151139_item	2323528	et	4	main
kõik	doc_284706151139_item	2323532	et	4	main
kaupluses	doc_284706151139_item	2323533	et	3	main
oli	doc_284706151139_item	2323536	et	3	main
tort	doc_284706151139_item	2323538	et	3	main
oli	doc_284706151140_item	2323544	et	3	main
oli	doc_284706151140_item	2323548	et	3	main
rootsi	doc_284706151140_item	2323550	et	4	main
toit	doc_284706151140_item	2323556	et	3	main
eriti	doc_284706151140_item	2323568	et	3	main
ploomimoosidega	doc_284706151140_item	2323571	et	3	main
siis	doc_284706151141_item	2323574	et	3	main
oli	doc_284706151141_item	2323612	et	3	main
ja	doc_284706151141_item	2323616	et	3	main
mulle	doc_284706151141_item	2323619	et	4	main
kõik	doc_284706151141_item	2323621	et	4	main
ise	doc_284706151141_item	2323626	et	4	main
ma	doc_284706151142_item	2323628	et	3	main
käin	doc_284706151142_item	2323629	et	3	main
käin	doc_284706151142_item	2323639	et	3	main
me	doc_284706151142_item	2323643	et	4	main
kohvi	doc_284706151142_item	2323647	et	4	main
seal	doc_284706151143_item	2323696	et	4	main
oli	doc_284706151143_item	2323698	et	3	main
ja	doc_284706151143_item	2323701	et	3	main
ja	doc_284706151143_item	2323711	et	3	main
joogid	doc_284706151143_item	2323715	et	4	main
pizz	doc_284706151143_item	2323722	et	4	main
ja	doc_284706151143_item	2323732	et	3	main
jäätis	doc_284706151143_item	2323736	et	3	main
kui	doc_284706151134_item	2323223	et	3	main
väljas	doc_284706151134_item	2323226	et	4	main
tavaliselt	doc_284706151134_item	2323229	et	4	main
kui	doc_284706151134_item	2323232	et	3	main
sõbrannaga	doc_284706151134_item	2323236	et	3	main
kartilisalat	doc_284706151134_item	2323249	et	4	main
praend	doc_284706151134_item	2323255	et	4	main
liha	doc_284706151134_item	2323256	et	4	main
moodi	doc_284706151134_item	2323258	et	4	main
1	doc_284706151134_item	2323262	et	2	main
lisandid	doc_284706151134_item	2323263	et	3	main
frikartul	doc_284706151134_item	2323264	et	4	main
keedukartul	doc_284706151134_item	2323265	et	3	main
riis	doc_284706151134_item	2323266	et	3	main
1	doc_284706151134_item	2323267	et	2	main
magustoid	doc_284706151134_item	2323268	et	4	main
jäätis	doc_284706151134_item	2323269	et	3	main
jogurti-	doc_284706151134_item	2323270	et	3	main
puvilja	doc_284706151134_item	2323272	et	4	main
ja	doc_284706151134_item	2323271	et	3	main
salat	doc_284706151134_item	2323273	et	3	main
1	doc_284706151134_item	2323275	et	2	main
koogid	doc_284706151134_item	2323274	et	4	main
joogid	doc_284706151134_item	2323276	et	4	main
iseenda	doc_284706151134_item	2323240	et	3	main
leo	doc_284706151134_item	2323244	et	4	main
limonaadid	doc_284706151134_item	2323285	et	3	main
joogid	doc_284706151134_item	2323288	et	4	main
viski	doc_284706151134_item	2323290	et	4	main
koktelid	doc_284706151134_item	2323292	et	4	main
essee	doc_284706151135_item	2323294	et	4	main
kodus	doc_284706151135_item	2323299	et	4	main
oli	doc_284706151135_item	2323301	et	3	main
sõbrad	doc_284706151135_item	2323304	et	3	main
ja	doc_284706151135_item	2323311	et	3	main
juurviljad	doc_284706151135_item	2323315	et	3	main
jõime	doc_284706151135_item	2323317	et	3	main
ja	doc_284706151135_item	2323319	et	3	main
toidud	doc_284706151135_item	2323321	et	3	main
ja	doc_284706151135_item	2323324	et	3	main
sõbranna	doc_284706151135_item	2323326	et	4	main
mis	doc_284706151135_item	2323331	et	4	main
essee	doc_284706151136_item	2323335	et	4	main
laupäeval	doc_284706151136_item	2323336	et	3	main
käisin	doc_284706151136_item	2323338	et	3	main
sünnipäevas	doc_284706151136_item	2323340	et	3	main
me	doc_284706151136_item	2323352	et	4	main
sõime	doc_284706151136_item	2323353	et	4	main
kartulisalati	doc_284706151136_item	2323354	et	3	main
krõpsusalat	doc_284706151136_item	2323355	et	4	main
rosolje	doc_284706151136_item	2323356	et	4	main
prae	doc_284706151136_item	2323358	et	4	main
kohv	doc_284706151136_item	2323366	et	3	main
krõpsusalat	doc_284706151136_item	2323371	et	4	main
minu	doc_284706151137_item	2323375	et	3	main
ja	doc_284706151137_item	2323377	et	3	main
toimus	doc_284706151137_item	2323379	et	3	main
ma	doc_284706151137_item	2323381	et	3	main
olin	doc_284706151137_item	2323382	et	3	main
ja	doc_284706151137_item	2323384	et	3	main
palju	doc_284706151137_item	2323387	et	4	main
sõime	doc_284706151137_item	2323393	et	4	main
eskalopp	doc_284706151137_item	2323395	et	3	main
maitsev	doc_284706151137_item	2323434	et	4	main
narva	doc_284706151138_item	2323439	et	4	main
huvitav	doc_284706151138_item	2323441	et	4	main
toimus	doc_284706151138_item	2323443	et	3	main
tema	doc_284706151138_item	2323447	et	4	main
sõber	doc_284706151138_item	2323448	et	3	main
mina	doc_284706151138_item	2323450	et	4	main
me	doc_284706151138_item	2323455	et	4	main
sõime	doc_284706151138_item	2323456	et	4	main
huvitav	doc_284706151138_item	2323462	et	4	main
virsik	doc_284706151138_item	2323464	et	3	main
krevettiga	doc_284706151138_item	2323465	et	4	main
jõime	doc_284706151138_item	2323473	et	3	main
kokk	doc_284706151138_item	2323476	et	3	main
töötas	doc_284706151138_item	2323478	et	3	main
seda	doc_284706151139_item	2323486	et	3	main
toimub	doc_284706151139_item	2323488	et	3	main
korteris	doc_284706151139_item	2323490	et	3	main
oli	doc_284706151139_item	2323492	et	3	main
sünnipäev	doc_284706151139_item	2323494	et	3	main
minu	doc_284706151139_item	2323497	et	3	main
sõbranna	doc_284706151139_item	2323500	et	4	main
sõime	doc_284706151139_item	2323506	et	4	main
olnud	doc_284706151139_item	2323513	et	4	main
väga	doc_284706151139_item	2323514	et	3	main
veini	doc_284706151139_item	2323525	et	4	main
ostsin	doc_284706151139_item	2323531	et	3	main
suur	doc_284706151139_item	2323537	et	3	main
palju	doc_284706151140_item	2323545	et	4	main
erinev	doc_284706151140_item	2323555	et	4	main
ainult	doc_284706151140_item	2323559	et	4	main
jõin	doc_284706151140_item	2323562	et	3	main
valmistas	doc_284706151140_item	2323566	et	3	main
essee	doc_284706151141_item	2323573	et	4	main
erinevad	doc_284706151141_item	2323617	et	4	main
toidud	doc_284706151141_item	2323622	et	3	main
teen	doc_284706151141_item	2323625	et	3	main
käime	doc_284706151142_item	2323634	et	4	main
vaid	doc_284706151142_item	2323635	et	3	main
pidulikel	doc_284706151142_item	2323636	et	3	main
juhtudel	doc_284706151142_item	2323637	et	3	main
baris	doc_284706151142_item	2323641	et	4	main
salatid	doc_284706151142_item	2323645	et	3	main
joogid	doc_284706151134_item	2323278	et	4	main
alkohoolsed	doc_284706151134_item	2323287	et	3	main
konjak	doc_284706151134_item	2323289	et	3	main
viinad	doc_284706151134_item	2323291	et	3	main
minu	doc_284706151135_item	2323298	et	3	main
me	doc_284706151135_item	2323307	et	4	main
me	doc_284706151135_item	2323316	et	4	main
ma	doc_284706151136_item	2323337	et	3	main
isa	doc_284706151136_item	2323339	et	4	main
kohal	doc_284706151136_item	2323342	et	4	main
õepoeg	doc_284706151136_item	2323346	et	3	main
ja	doc_284706151136_item	2323349	et	3	main
sõbrad	doc_284706151136_item	2323351	et	3	main
kartuliga	doc_284706151136_item	2323360	et	3	main
palju	doc_284706151136_item	2323362	et	4	main
valge	doc_284706151136_item	2323364	et	4	main
vein	doc_284706151136_item	2323365	et	3	main
me	doc_284706151136_item	2323368	et	4	main
tellime	doc_284706151136_item	2323369	et	3	main
restoranis	doc_284706151136_item	2323370	et	3	main
sünnipäev	doc_284706151137_item	2323376	et	3	main
evestis	doc_284706151137_item	2323380	et	4	main
oli	doc_284706151137_item	2323386	et	3	main
20-kümne	doc_284706151137_item	2323390	et	4	main
juustuga	doc_284706151137_item	2323396	et	3	main
ja	doc_284706151137_item	2323397	et	3	main
friikartulidega	doc_284706151137_item	2323398	et	4	main
napoleoni	doc_284706151137_item	2323399	et	4	main
tort	doc_284706151137_item	2323400	et	3	main
erinevad	doc_284706151137_item	2323401	et	4	main
vorstid	doc_284706151137_item	2323402	et	3	main
ja	doc_284706151137_item	2323403	et	3	main
singid	doc_284706151137_item	2323404	et	3	main
ja	doc_284706151137_item	2323405	et	3	main
jäätis	doc_284706151137_item	2323406	et	3	main
puuviljadega	doc_284706151137_item	2323407	et	3	main
me	doc_284706151137_item	2323408	et	4	main
jõime	doc_284706151137_item	2323409	et	3	main
jeam	doc_284706151137_item	2323410	et	4	main
beami	doc_284706151137_item	2323411	et	4	main
kolaga	doc_284706151137_item	2323412	et	3	main
ja	doc_284706151137_item	2323413	et	3	main
mahlad	doc_284706151137_item	2323414	et	3	main
valmistasid	doc_284706151137_item	2323416	et	4	main
toidud	doc_284706151137_item	2323415	et	3	main
koogid	doc_284706151137_item	2323417	et	4	main
restoranist	doc_284706151137_item	2323418	et	3	main
eriti	doc_284706151137_item	2323419	et	3	main
mulle	doc_284706151137_item	2323420	et	4	main
õunamahl	doc_284706151136_item	2323367	et	3	main
sõpru	doc_284706151137_item	2323388	et	3	main
me	doc_284706151137_item	2323392	et	4	main
kraabisalat	doc_284706151137_item	2323394	et	4	main
meeldis	doc_284706151137_item	2323421	et	3	main
on	doc_284706151137_item	2323427	et	4	main
ja	doc_284706151138_item	2323451	et	3	main
vee	doc_284706151138_item	2323452	et	3	main
üks	doc_284706151138_item	2323453	et	3	main
sõbranna	doc_284706151138_item	2323454	et	4	main
krabid	doc_284706151138_item	2323458	et	3	main
väga	doc_284706151138_item	2323461	et	3	main
väga	doc_284706151138_item	2323468	et	3	main
meeldis	doc_284706151138_item	2323469	et	3	main
valge	doc_284706151138_item	2323474	et	4	main
essee	doc_284706151139_item	2323485	et	4	main
minu	doc_284706151139_item	2323493	et	3	main
vanemad	doc_284706151139_item	2323498	et	4	main
praetud	doc_284706151139_item	2323508	et	4	main
kartuliga	doc_284706151139_item	2323512	et	3	main
maitsev	doc_284706151139_item	2323515	et	4	main
tort	doc_284706151139_item	2323516	et	3	main
joovad	doc_284706151139_item	2323524	et	4	main
palju	doc_284706151139_item	2323529	et	4	main
ma	doc_284706151139_item	2323530	et	3	main
eriti	doc_284706151139_item	2323534	et	3	main
inimesi	doc_284706151140_item	2323546	et	4	main
sõin	doc_284706151140_item	2323558	et	3	main
jäätis	doc_284706151140_item	2323560	et	3	main
ja	doc_284706151140_item	2323561	et	3	main
ainult	doc_284706151140_item	2323563	et	4	main
oli	doc_284706151140_item	2323570	et	3	main
kui	doc_284706151141_item	2323575	et	3	main
veel	doc_284706151141_item	2323577	et	4	main
elasin	doc_284706151141_item	2323578	et	3	main
tartus	doc_284706151141_item	2323579	et	3	main
mahlad	doc_284706151141_item	2323618	et	3	main
meeldivad	doc_284706151141_item	2323620	et	4	main
mis	doc_284706151141_item	2323623	et	4	main
ma	doc_284706151141_item	2323624	et	3	main
ei	doc_284706151142_item	2323631	et	4	main
ma	doc_284706151142_item	2323638	et	3	main
telime	doc_284706151142_item	2323644	et	4	main
kus	doc_284706151142_item	2323657	et	3	main
muusika	doc_284706151142_item	2323666	et	4	main
hinnad	doc_284706151142_item	2323667	et	3	main
on	doc_284706151142_item	2323668	et	4	main
mõõdukad	doc_284706151142_item	2323669	et	3	main
menüüs	doc_284706151142_item	2323670	et	3	main
piza	doc_284706151143_item	2323699	et	4	main
suur	doc_284706151143_item	2323700	et	3	main
sing	doc_284706151143_item	2323710	et	4	main
õlu	doc_284706151143_item	2323716	et	3	main
tee	doc_284706151143_item	2323725	et	4	main
maasika	doc_284706151143_item	2323738	et	3	main
mahl	doc_284706151143_item	2323750	et	3	main
essee	doc_284706151144_item	2323758	et	4	main
ma	doc_284706151144_item	2323759	et	3	main
harva	doc_284706151144_item	2323761	et	4	main
restoranis	doc_284706151144_item	2323762	et	3	main
aga	doc_284706151144_item	2323763	et	3	main
vanaemaga	doc_284706151144_item	2323781	et	3	main
käi	doc_284706151144_item	2323783	et	4	main
maksab	doc_284706151144_item	2323790	et	3	main
mina	doc_284706151145_item	2323821	et	4	main
harva	doc_284706151145_item	2323825	et	4	main
ma	doc_284706151145_item	2323827	et	3	main
käinud	doc_284706151145_item	2323834	et	4	main
baaris	doc_284706151145_item	2323838	et	3	main
tore	doc_284706151145_item	2323845	et	3	main
või	doc_284706151145_item	2323850	et	4	main
toidu	doc_284706151145_item	2323863	et	3	main
mina	doc_284706151145_item	2323865	et	4	main
restoraanis	doc_284706151145_item	2323867	et	4	main
kus	doc_284706151145_item	2323868	et	3	main
praetud	doc_284706151145_item	2323876	et	4	main
karamellikastmega	doc_284706151145_item	2323878	et	3	main
ei	doc_284706151146_item	2323891	et	4	main
praegu	doc_284706151146_item	2323897	et	3	main
ãµpin	doc_284706151146_item	2323899	et	4	main
meil	doc_284706151146_item	2323902	et	4	main
seal	doc_284706151146_item	2323904	et	4	main
sellepärast	doc_284706151137_item	2323424	et	3	main
et	doc_284706151137_item	2323425	et	3	main
lemmik	doc_284706151137_item	2323429	et	3	main
ja	doc_284706151137_item	2323431	et	3	main
väga	doc_284706151137_item	2323433	et	3	main
sõbra	doc_284706151138_item	2323438	et	3	main
tallinnast	doc_284706151138_item	2323449	et	3	main
kala	doc_284706151138_item	2323457	et	4	main
kes	doc_284706151138_item	2323477	et	4	main
restoraanis	doc_284706151138_item	2323479	et	4	main
valmistas	doc_284706151138_item	2323480	et	3	main
toidud	doc_284706151138_item	2323481	et	3	main
virsik	doc_284706151138_item	2323482	et	3	main
banaanikastmega	doc_284706151138_item	2323484	et	3	main
see	doc_284706151139_item	2323491	et	3	main
olnud	doc_284706151139_item	2323496	et	4	main
sõbrad	doc_284706151139_item	2323504	et	3	main
komvikuid	doc_284706151139_item	2323518	et	4	main
me	doc_284706151139_item	2323519	et	4	main
jõime	doc_284706151139_item	2323520	et	3	main
martini	doc_284706151139_item	2323522	et	4	main
ei	doc_284706151139_item	2323527	et	4	main
seal	doc_284706151140_item	2323543	et	4	main
ma	doc_284706151140_item	2323557	et	3	main
peakokk	doc_284706151140_item	2323565	et	3	main
maitsev	doc_284706151140_item	2323569	et	4	main
seal	doc_284706151141_item	2323581	et	4	main
joogideks	doc_284706151141_item	2323611	et	3	main
lihtsalt	doc_284706151141_item	2323613	et	4	main
juustueskalop	doc_284706151137_item	2323422	et	4	main
see	doc_284706151137_item	2323426	et	3	main
minu	doc_284706151137_item	2323428	et	3	main
toit	doc_284706151137_item	2323430	et	3	main
oli	doc_284706151137_item	2323432	et	3	main
tehtud	doc_284706151137_item	2323435	et	4	main
essee	doc_284706151138_item	2323436	et	4	main
hottellis	doc_284706151138_item	2323440	et	4	main
pidu	doc_284706151138_item	2323442	et	4	main
minu	doc_284706151138_item	2323445	et	3	main
roog	doc_284706151138_item	2323463	et	3	main
mulle	doc_284706151138_item	2323467	et	4	main
me	doc_284706151138_item	2323472	et	4	main
pidu	doc_284706151139_item	2323487	et	4	main
minu	doc_284706151139_item	2323489	et	3	main
parim	doc_284706151139_item	2323499	et	4	main
minu	doc_284706151139_item	2323501	et	3	main
ja	doc_284706151139_item	2323503	et	3	main
keedetud	doc_284706151139_item	2323511	et	4	main
aega	doc_284706151139_item	2323526	et	4	main
maitsev	doc_284706151139_item	2323535	et	4	main
essee	doc_284706151140_item	2323539	et	4	main
see	doc_284706151140_item	2323540	et	3	main
oli	doc_284706151140_item	2323541	et	3	main
laevades	doc_284706151140_item	2323542	et	3	main
seal	doc_284706151140_item	2323547	et	4	main
šveitsilaud	doc_284706151140_item	2323549	et	2	main
laud	doc_284706151140_item	2323551	et	4	main
see	doc_284706151140_item	2323552	et	3	main
oli	doc_284706151140_item	2323553	et	3	main
väga	doc_284706151140_item	2323554	et	3	main
mahl	doc_284706151140_item	2323564	et	3	main
toidu	doc_284706151140_item	2323567	et	3	main
jaätis	doc_284706151140_item	2323572	et	4	main
ma	doc_284706151141_item	2323576	et	3	main
toimus	doc_284706151141_item	2323580	et	3	main
üks	doc_284706151141_item	2323582	et	3	main
huvitav	doc_284706151141_item	2323583	et	4	main
pidu	doc_284706151141_item	2323584	et	4	main
me	doc_284706151141_item	2323585	et	4	main
korraldasime	doc_284706151141_item	2323586	et	3	main
selle	doc_284706151141_item	2323587	et	4	main
peo	doc_284706151141_item	2323588	et	4	main
ise	doc_284706151141_item	2323589	et	4	main
koos	doc_284706151141_item	2323590	et	4	main
oma	doc_284706151141_item	2323591	et	4	main
mehega	doc_284706151141_item	2323592	et	3	main
me	doc_284706151141_item	2323593	et	4	main
kutsusime	doc_284706151141_item	2323594	et	3	main
palju	doc_284706151141_item	2323595	et	4	main
sõpru	doc_284706151141_item	2323596	et	3	main
külla	doc_284706151141_item	2323597	et	4	main
hakkasime	doc_284706151141_item	2323599	et	3	main
toidu	doc_284706151141_item	2323600	et	3	main
ja	doc_284706151141_item	2323598	et	3	main
valmistama	doc_284706151141_item	2323601	et	3	main
meil	doc_284706151141_item	2323602	et	4	main
oli	doc_284706151141_item	2323603	et	3	main
pakkuda	doc_284706151141_item	2323604	et	3	main
ulukiliha	doc_284706151141_item	2323605	et	4	main
kastmes	doc_284706151141_item	2323606	et	3	main
kanaliha	doc_284706151141_item	2323607	et	4	main
ananassiga	doc_284706151141_item	2323608	et	3	main
sealiha	doc_284706151141_item	2323609	et	4	main
küüslauguga	doc_284706151141_item	2323610	et	3	main
tee	doc_284706151141_item	2323614	et	4	main
kohv	doc_284706151141_item	2323615	et	3	main
essee	doc_284706151142_item	2323627	et	4	main
restoranis	doc_284706151142_item	2323630	et	3	main
tihti	doc_284706151142_item	2323632	et	3	main
sõbradega	doc_284706151142_item	2323640	et	4	main
kohvikus	doc_284706151142_item	2323642	et	3	main
tass	doc_284706151142_item	2323646	et	3	main
ja	doc_284706151142_item	2323648	et	3	main
mitmeid	doc_284706151142_item	2323649	et	4	main
ja	doc_284706151142_item	2323651	et	3	main
jäätis	doc_284706151142_item	2323652	et	3	main
veel	doc_284706151142_item	2323653	et	4	main
käime	doc_284706151143_item	2323693	et	4	main
väike	doc_284706151143_item	2323702	et	4	main
erinevaid	doc_284706151143_item	2323705	et	4	main
tomatid	doc_284706151143_item	2323708	et	3	main
palju	doc_284706151143_item	2323712	et	4	main
ja	doc_284706151143_item	2323718	et	3	main
džinn	doc_284706151143_item	2323721	et	2	main
kohv	doc_284706151143_item	2323724	et	3	main
limonaad	doc_284706151143_item	2323726	et	3	main
mahlad	doc_284706151143_item	2323727	et	3	main
tomati	doc_284706151143_item	2323728	et	3	main
apelsini	doc_284706151143_item	2323729	et	4	main
magus	doc_284706151143_item	2323734	et	3	main
vanili	doc_284706151143_item	2323737	et	4	main
ja	doc_284706151143_item	2323739	et	3	main
ja	doc_284706151143_item	2323751	et	3	main
kodulinnas	doc_284706151144_item	2323770	et	4	main
restoreni	doc_284706151144_item	2323774	et	4	main
toidu	doc_284706151144_item	2323794	et	3	main
eelistan	doc_284706151145_item	2323828	et	3	main
süüa	doc_284706151145_item	2323830	et	3	main
söömas	doc_284706151145_item	2323847	et	4	main
ei	doc_284706151145_item	2323854	et	4	main
taha	doc_284706151145_item	2323855	et	4	main
väljas	doc_284706151145_item	2323856	et	4	main
söömas	doc_284706151145_item	2323857	et	4	main
maksan	doc_284706151145_item	2323861	et	3	main
sellised	doc_284706151145_item	2323870	et	4	main
menüüd	doc_284706151145_item	2323871	et	4	main
praetud	doc_284706151145_item	2323872	et	4	main
küslaugu	doc_284706151145_item	2323874	et	4	main
sõin	doc_284706151145_item	2323882	et	3	main
restoranis	doc_284706151146_item	2323893	et	3	main
kohvikus	doc_284706151146_item	2323896	et	3	main
kohvikud	doc_284706151146_item	2323918	et	3	main
seal	doc_284706151146_item	2323922	et	4	main
koos	doc_284706151146_item	2323925	et	4	main
sãµpratega	doc_284706151146_item	2323926	et	4	main
kãia	doc_284706151146_item	2323929	et	4	main
ei	doc_284706151146_item	2323935	et	4	main
inimestega	doc_284706151146_item	2323944	et	3	main
ja	doc_284706151146_item	2323946	et	3	main
enda	doc_284706151146_item	2323951	et	4	main
seal	doc_284706151146_item	2323958	et	4	main
ja	doc_284706151146_item	2323964	et	3	main
ja	doc_284706151146_item	2323970	et	3	main
ja	doc_284706151146_item	2323980	et	3	main
veel	doc_284706151146_item	2323983	et	4	main
salatid	doc_284706151146_item	2323986	et	3	main
ja	doc_284706151146_item	2323989	et	3	main
oktoobril	doc_284706151147_item	2323997	et	3	main
koju	doc_284706151147_item	2324028	et	3	main
homme	doc_284706151147_item	2324037	et	3	main
me	doc_284706151147_item	2324040	et	4	main
kohtusime	doc_284706151147_item	2324041	et	4	main
korda	doc_284706151147_item	2324044	et	4	main
kohtu	doc_284706151147_item	2324053	et	4	main
oli	doc_284706151147_item	2324056	et	3	main
meldib	doc_284706151147_item	2324058	et	4	main
aga	doc_284706151147_item	2324060	et	3	main
olla	doc_284706151147_item	2324062	et	3	main
me	doc_284706151147_item	2324064	et	4	main
kokku	doc_284706151147_item	2324067	et	3	main
kodulinna	doc_284706151148_item	2324069	et	4	main
õpin	doc_284706151148_item	2324080	et	3	main
ma	doc_284706151148_item	2324089	et	3	main
lõunad	doc_284706151148_item	2324091	et	3	main
linnas	doc_284706151148_item	2324093	et	4	main
me	doc_284706151142_item	2323633	et	4	main
veini	doc_284706151142_item	2323654	et	4	main
meeldiv	doc_284706151142_item	2323655	et	4	main
restoran	doc_284706151142_item	2323656	et	3	main
ilus	doc_284706151142_item	2323658	et	4	main
interjöör	doc_284706151142_item	2323659	et	3	main
head	doc_284706151142_item	2323660	et	4	main
toidud	doc_284706151142_item	2323661	et	3	main
viisakas	doc_284706151142_item	2323662	et	4	main
teenindamine	doc_284706151142_item	2323663	et	4	main
ja	doc_284706151142_item	2323664	et	3	main
mõnus	doc_284706151142_item	2323665	et	4	main
on	doc_284706151142_item	2323671	et	4	main
supid	doc_284706151142_item	2323672	et	3	main
kana	doc_284706151142_item	2323673	et	4	main
kala	doc_284706151142_item	2323674	et	4	main
lisandid	doc_284706151142_item	2323675	et	3	main
magustoidud	doc_284706151142_item	2323676	et	3	main
joogid	doc_284706151142_item	2323677	et	4	main
veel	doc_284706151142_item	2323678	et	4	main
veini	doc_284706151142_item	2323679	et	4	main
essee	doc_284706151143_item	2323680	et	4	main
ma	doc_284706151143_item	2323681	et	3	main
käin	doc_284706151143_item	2323682	et	3	main
ei	doc_284706151143_item	2323683	et	4	main
tihti	doc_284706151143_item	2323684	et	3	main
baaris	doc_284706151143_item	2323685	et	3	main
või	doc_284706151143_item	2323686	et	4	main
restoranis	doc_284706151143_item	2323687	et	3	main
mõnikord	doc_284706151143_item	2323688	et	3	main
oma	doc_284706151143_item	2323690	et	4	main
koos	doc_284706151143_item	2323689	et	4	main
sõpraga	doc_284706151143_item	2323691	et	4	main
magustoite	doc_284706151142_item	2323650	et	4	main
petri	doc_284706151143_item	2323694	et	4	main
menüüd	doc_284706151143_item	2323697	et	4	main
palju	doc_284706151143_item	2323704	et	4	main
lisandeid	doc_284706151143_item	2323706	et	3	main
seenid	doc_284706151143_item	2323707	et	4	main
ananasid	doc_284706151143_item	2323709	et	4	main
punane	doc_284706151143_item	2323717	et	4	main
veinid	doc_284706151143_item	2323720	et	3	main
teined	doc_284706151143_item	2323733	et	4	main
toidud	doc_284706151143_item	2323735	et	3	main
piza	doc_284706151143_item	2323745	et	4	main
ananasiga	doc_284706151143_item	2323748	et	4	main
tomati	doc_284706151143_item	2323749	et	3	main
igaüks	doc_284706151143_item	2323754	et	3	main
maksa	doc_284706151143_item	2323755	et	4	main
eest	doc_284706151143_item	2323757	et	4	main
käin	doc_284706151144_item	2323760	et	3	main
külastan	doc_284706151144_item	2323772	et	3	main
hiina	doc_284706151144_item	2323775	et	3	main
käime	doc_284706151144_item	2323777	et	4	main
söömas	doc_284706151144_item	2323780	et	4	main
söömas	doc_284706151144_item	2323788	et	4	main
noormees	doc_284706151144_item	2323789	et	4	main
käin	doc_284706151145_item	2323822	et	3	main
väga	doc_284706151145_item	2323824	et	3	main
rikka	doc_284706151145_item	2323841	et	4	main
väljas	doc_284706151145_item	2323846	et	4	main
ebakultuurne	doc_284706151145_item	2323849	et	3	main
ebameeldivu	doc_284706151145_item	2323851	et	4	main
ise	doc_284706151145_item	2323860	et	4	main
eest	doc_284706151145_item	2323864	et	4	main
olin	doc_284706151145_item	2323866	et	3	main
krevettid	doc_284706151145_item	2323873	et	4	main
kastmega	doc_284706151145_item	2323875	et	3	main
restoranis	doc_284706151145_item	2323880	et	3	main
part	doc_284706151145_item	2323884	et	4	main
kodulinna	doc_284706151146_item	2323888	et	4	main
sããgikohad	doc_284706151146_item	2323889	et	4	main
baaris	doc_284706151146_item	2323894	et	3	main
on	doc_284706151146_item	2323903	et	4	main
sããn	doc_284706151146_item	2323909	et	4	main
on	doc_284706151146_item	2323913	et	4	main
mitu	doc_284706151146_item	2323917	et	4	main
koos	doc_284706151146_item	2323931	et	4	main
vãljas	doc_284706151146_item	2323938	et	4	main
koos	doc_284706151146_item	2323940	et	4	main
maksab	doc_284706151146_item	2323949	et	3	main
asub	doc_284706151146_item	2323956	et	3	main
meeldib	doc_284706151146_item	2323975	et	3	main
loomaliha	doc_284706151146_item	2323978	et	4	main
vãµib	doc_284706151146_item	2323984	et	4	main
jooke	doc_284706151146_item	2323987	et	3	main
essee	doc_284706151147_item	2323991	et	4	main
internetis	doc_284706151147_item	2323998	et	4	main
ilus	doc_284706151147_item	2324022	et	4	main
ja	doc_284706151147_item	2324023	et	3	main
saatsin	doc_284706151147_item	2324026	et	3	main
tema	doc_284706151147_item	2324027	et	4	main
me	doc_284706151147_item	2324030	et	4	main
et	doc_284706151147_item	2324033	et	3	main
õhtul	doc_284706151147_item	2324038	et	3	main
pargis	doc_284706151147_item	2324047	et	3	main
paegu	doc_284706151147_item	2324049	et	4	main
inimene	doc_284706151147_item	2324059	et	3	main
veel	doc_284706151147_item	2324065	et	4	main
ei	doc_284706151148_item	2324072	et	4	main
käi	doc_284706151148_item	2324073	et	4	main
baaris	doc_284706151148_item	2324075	et	3	main
ja	doc_284706151148_item	2324076	et	3	main
praegu	doc_284706151148_item	2324078	et	3	main
ja	doc_284706151148_item	2324082	et	3	main
on	doc_284706151148_item	2324084	et	4	main
kus	doc_284706151148_item	2324088	et	3	main
meie	doc_284706151148_item	2324092	et	4	main
sõpratega	doc_284706151148_item	2324107	et	4	main
käia	doc_284706151148_item	2324110	et	4	main
ma	doc_284706151148_item	2324115	et	3	main
taha	doc_284706151148_item	2324117	et	4	main
või	doc_284706151148_item	2324123	et	4	main
kohvikus	doc_284706151148_item	2324126	et	3	main
igaüks	doc_284706151148_item	2324129	et	3	main
me	doc_284706151143_item	2323692	et	4	main
pizas	doc_284706151143_item	2323695	et	4	main
ja	doc_284706151143_item	2323703	et	3	main
teined	doc_284706151143_item	2323713	et	4	main
alkohoolsed	doc_284706151143_item	2323714	et	3	main
valge	doc_284706151143_item	2323719	et	4	main
joogid	doc_284706151143_item	2323723	et	4	main
õuna	doc_284706151143_item	2323730	et	4	main
vinamarja	doc_284706151143_item	2323731	et	4	main
tavaline	doc_284706151143_item	2323741	et	4	main
ja	doc_284706151143_item	2323747	et	3	main
jäätis	doc_284706151143_item	2323753	et	3	main
iseenda	doc_284706151143_item	2323756	et	3	main
külastan	doc_284706151144_item	2323765	et	3	main
korda	doc_284706151144_item	2323767	et	4	main
kuus	doc_284706151144_item	2323768	et	4	main
oma	doc_284706151144_item	2323769	et	4	main
sageli	doc_284706151144_item	2323773	et	3	main
sõbrannadega	doc_284706151144_item	2323776	et	3	main
sageli	doc_284706151144_item	2323778	et	3	main
kohvikus	doc_284706151144_item	2323779	et	3	main
ei	doc_284706151144_item	2323782	et	4	main
ma	doc_284706151144_item	2323784	et	3	main
hiina	doc_284706151144_item	2323797	et	3	main
restoraanis	doc_284706151144_item	2323798	et	4	main
pakkutakse	doc_284706151144_item	2323799	et	4	main
huvutavaid	doc_284706151144_item	2323800	et	4	main
menüüd	doc_284706151144_item	2323801	et	4	main
mulle	doc_284706151144_item	2323802	et	4	main
meeldis	doc_284706151144_item	2323803	et	3	main
kõige	doc_284706151144_item	2323804	et	4	main
rohkem	doc_284706151144_item	2323805	et	4	main
roogi	doc_284706151144_item	2323807	et	4	main
üks	doc_284706151144_item	2323806	et	3	main
ananasid	doc_284706151144_item	2323808	et	4	main
punases	doc_284706151144_item	2323809	et	4	main
taines	doc_284706151144_item	2323810	et	4	main
koos	doc_284706151144_item	2323811	et	4	main
jäätise	doc_284706151144_item	2323812	et	3	main
ja	doc_284706151144_item	2323813	et	3	main
puuviljadega	doc_284706151144_item	2323814	et	3	main
kohvikus	doc_284706151144_item	2323815	et	3	main
meeldis	doc_284706151144_item	2323816	et	3	main
värviline	doc_284706151144_item	2323817	et	4	main
jäätis	doc_284706151144_item	2323818	et	3	main
krõpsudega	doc_284706151144_item	2323819	et	3	main
essee	doc_284706151145_item	2323820	et	4	main
šokolaadi	doc_284706151143_item	2323740	et	2	main
me	doc_284706151143_item	2323742	et	4	main
tellime	doc_284706151143_item	2323743	et	3	main
suur	doc_284706151143_item	2323744	et	3	main
singiga	doc_284706151143_item	2323746	et	3	main
pärast	doc_284706151143_item	2323752	et	4	main
baari	doc_284706151144_item	2323764	et	4	main
3	doc_284706151144_item	2323766	et	2	main
tallinnas	doc_284706151144_item	2323771	et	4	main
tavaliselt	doc_284706151144_item	2323785	et	4	main
kunagi	doc_284706151144_item	2323786	et	3	main
väljas	doc_284706151144_item	2323787	et	4	main
alati	doc_284706151144_item	2323791	et	4	main
meie	doc_284706151144_item	2323792	et	4	main
mõlema	doc_284706151144_item	2323793	et	3	main
eest	doc_284706151144_item	2323795	et	4	main
ühes	doc_284706151144_item	2323796	et	4	main
restoranis	doc_284706151145_item	2323823	et	3	main
sellepärast	doc_284706151145_item	2323826	et	3	main
kodus	doc_284706151145_item	2323829	et	4	main
mõnikord	doc_284706151145_item	2323835	et	3	main
premier	doc_284706151145_item	2323836	et	4	main
või	doc_284706151145_item	2323840	et	4	main
mehega	doc_284706151145_item	2323842	et	3	main
koos	doc_284706151145_item	2323843	et	4	main
käia	doc_284706151145_item	2323848	et	4	main
tavaliselt	doc_284706151145_item	2323862	et	4	main
kãi	doc_284706151146_item	2323892	et	4	main
ja	doc_284706151146_item	2323895	et	3	main
ma	doc_284706151146_item	2323898	et	3	main
ma	doc_284706151146_item	2323908	et	3	main
meie	doc_284706151146_item	2323911	et	4	main
ja	doc_284706151146_item	2323916	et	3	main
korda	doc_284706151146_item	2323924	et	4	main
meeldib	doc_284706151146_item	2323928	et	3	main
kohvikus	doc_284706151146_item	2323930	et	3	main
oma	doc_284706151146_item	2323932	et	4	main
kursusekaaslastega	doc_284706151146_item	2323933	et	4	main
ebameeldivate	doc_284706151146_item	2323943	et	3	main
baaris	doc_284706151146_item	2323947	et	3	main
toolid	doc_284706151146_item	2323963	et	3	main
on	doc_284706151146_item	2323968	et	4	main
vãga	doc_284706151146_item	2323971	et	4	main
nãiteks	doc_284706151146_item	2323973	et	4	main
makaronidega	doc_284706151146_item	2323979	et	3	main
saiakesi	doc_284706151146_item	2323990	et	4	main
kohtusime	doc_284706151147_item	2323993	et	4	main
ma	doc_284706151147_item	2324025	et	3	main
ma	doc_284706151147_item	2324034	et	3	main
temale	doc_284706151147_item	2324036	et	3	main
paar	doc_284706151147_item	2324043	et	3	main
ja	doc_284706151147_item	2324045	et	3	main
kaisime	doc_284706151147_item	2324046	et	4	main
enam	doc_284706151147_item	2324051	et	4	main
same	doc_284706151147_item	2324066	et	4	main
essee	doc_284706151148_item	2324068	et	4	main
söögikohad	doc_284706151148_item	2324070	et	4	main
ma	doc_284706151148_item	2324071	et	3	main
kohvikus	doc_284706151148_item	2324077	et	3	main
söön	doc_284706151148_item	2324090	et	3	main
kohvikud	doc_284706151148_item	2324099	et	3	main
käinud	doc_284706151148_item	2324102	et	4	main
kursusekaaslastega	doc_284706151148_item	2324114	et	4	main
ise	doc_284706151148_item	2324131	et	4	main
eest	doc_284706151148_item	2324133	et	4	main
meie	doc_284706151148_item	2324134	et	4	main
kutsehariduskeskuse	doc_284706151148_item	2324135	et	3	main
näiteks	doc_284706151148_item	2324154	et	4	main
seljanka	doc_284706151148_item	2324157	et	4	main
essee	doc_284706151149_item	2324172	et	4	main
üsna	doc_284706151149_item	2324178	et	3	main
söömas	doc_284706151149_item	2324212	et	4	main
ma	doc_284706151149_item	2324213	et	3	main
ei	doc_284706151149_item	2324214	et	4	main
koos	doc_284706151149_item	2324220	et	4	main
tavaliselt	doc_284706151149_item	2324221	et	4	main
sõber	doc_284706151149_item	2324231	et	3	main
tavaline	doc_284706151149_item	2324232	et	4	main
supid	doc_284706151149_item	2324237	et	3	main
salatid	doc_284706151149_item	2324239	et	3	main
supid	doc_284706151149_item	2324244	et	3	main
on	doc_284706151149_item	2324245	et	4	main
siiski	doc_284706151145_item	2323831	et	4	main
mina	doc_284706151145_item	2323832	et	4	main
olen	doc_284706151145_item	2323833	et	3	main
wiroonia	doc_284706151145_item	2323837	et	4	main
sõbrannaga	doc_284706151145_item	2323839	et	3	main
on	doc_284706151145_item	2323844	et	4	main
inimesega	doc_284706151145_item	2323852	et	3	main
ma	doc_284706151145_item	2323853	et	3	main
käia	doc_284706151145_item	2323858	et	4	main
mina	doc_284706151145_item	2323859	et	4	main
olid	doc_284706151145_item	2323869	et	4	main
banaanid	doc_284706151145_item	2323877	et	3	main
hiina	doc_284706151145_item	2323879	et	3	main
mina	doc_284706151145_item	2323881	et	4	main
ükskord	doc_284706151145_item	2323883	et	3	main
maguskastmega	doc_284706151145_item	2323885	et	3	main
uus	doc_284706151146_item	2323886	et	3	main
dokument	doc_284706151146_item	2323887	et	3	main
ma	doc_284706151146_item	2323890	et	3	main
kutsehariduskeskuses	doc_284706151146_item	2323900	et	4	main
ja	doc_284706151146_item	2323901	et	3	main
kus	doc_284706151146_item	2323907	et	3	main
lãµunad	doc_284706151146_item	2323910	et	4	main
âžtrilobitâ	doc_284706151146_item	2323915	et	2	main
ma	doc_284706151146_item	2323919	et	3	main
olen	doc_284706151146_item	2323920	et	3	main
kãinud	doc_284706151146_item	2323921	et	4	main
mity	doc_284706151146_item	2323923	et	4	main
taha	doc_284706151146_item	2323936	et	4	main
sããmas	doc_284706151146_item	2323939	et	4	main
vãµi	doc_284706151146_item	2323942	et	4	main
kohvikus	doc_284706151146_item	2323945	et	3	main
keldrikorrusel	doc_284706151146_item	2323957	et	3	main
toit	doc_284706151146_item	2323967	et	3	main
mulle	doc_284706151146_item	2323974	et	4	main
maitsva	doc_284706151146_item	2323981	et	4	main
tellida	doc_284706151146_item	2323985	et	3	main
me	doc_284706151147_item	2323992	et	4	main
esimest	doc_284706151147_item	2323994	et	4	main
korda	doc_284706151147_item	2323995	et	4	main
esimesel	doc_284706151147_item	2323996	et	3	main
sõbralik	doc_284706151147_item	2324024	et	3	main
ja	doc_284706151147_item	2324029	et	3	main
leppisime	doc_284706151147_item	2324031	et	3	main
kokku	doc_284706151147_item	2324032	et	3	main
veel	doc_284706151147_item	2324042	et	4	main
ei	doc_284706151147_item	2324052	et	4	main
ta	doc_284706151147_item	2324055	et	4	main
pärast	doc_284706151147_item	2324063	et	4	main
kutsehariduskeskuses	doc_284706151148_item	2324081	et	4	main
on	doc_284706151148_item	2324094	et	4	main
restoran	doc_284706151148_item	2324095	et	3	main
ja	doc_284706151148_item	2324097	et	3	main
mitu	doc_284706151148_item	2324098	et	4	main
olen	doc_284706151148_item	2324101	et	3	main
seal	doc_284706151148_item	2324103	et	4	main
mity	doc_284706151148_item	2324104	et	4	main
meeldib	doc_284706151148_item	2324109	et	3	main
kohvikus	doc_284706151148_item	2324111	et	3	main
ei	doc_284706151148_item	2324116	et	4	main
võõrastega	doc_284706151148_item	2324122	et	4	main
maksab	doc_284706151148_item	2324130	et	3	main
enda	doc_284706151148_item	2324132	et	4	main
asub	doc_284706151148_item	2324137	et	3	main
mugavad	doc_284706151148_item	2324141	et	3	main
ja	doc_284706151148_item	2324143	et	3	main
meeldiv	doc_284706151148_item	2324146	et	4	main
mulle	doc_284706151148_item	2324155	et	4	main
praetud	doc_284706151148_item	2324158	et	4	main
loomaliha	doc_284706151148_item	2324159	et	4	main
makaronidega	doc_284706151148_item	2324160	et	3	main
ja	doc_284706151148_item	2324161	et	3	main
maitsva	doc_284706151148_item	2324162	et	4	main
käin	doc_284706151149_item	2324174	et	3	main
kohvikusse	doc_284706151149_item	2324177	et	4	main
tihti	doc_284706151149_item	2324179	et	3	main
käja	doc_284706151149_item	2324211	et	4	main
taha	doc_284706151149_item	2324215	et	4	main
toidu	doc_284706151149_item	2324223	et	3	main
minu	doc_284706151149_item	2324225	et	3	main
mugav	doc_284706151146_item	2323905	et	3	main
baar	doc_284706151146_item	2323906	et	3	main
linnas	doc_284706151146_item	2323912	et	4	main
restoran	doc_284706151146_item	2323914	et	3	main
mulle	doc_284706151146_item	2323927	et	4	main
ma	doc_284706151146_item	2323934	et	3	main
kãia	doc_284706151146_item	2323937	et	4	main
vãµãµrastega	doc_284706151146_item	2323941	et	4	main
igaã¼ks	doc_284706151146_item	2323948	et	2	main
ise	doc_284706151146_item	2323950	et	4	main
eest	doc_284706151146_item	2323952	et	4	main
meie	doc_284706151146_item	2323953	et	4	main
kutsehariduskeskuse	doc_284706151146_item	2323954	et	3	main
baar	doc_284706151146_item	2323955	et	3	main
on	doc_284706151146_item	2323959	et	4	main
mugavad	doc_284706151146_item	2323960	et	3	main
lauad	doc_284706151146_item	2323961	et	3	main
ja	doc_284706151146_item	2323962	et	3	main
meeldiv	doc_284706151146_item	2323965	et	4	main
interjããr	doc_284706151146_item	2323966	et	4	main
kodune	doc_284706151146_item	2323969	et	4	main
maitsev	doc_284706151146_item	2323972	et	4	main
seljanka	doc_284706151146_item	2323976	et	4	main
praetud	doc_284706151146_item	2323977	et	4	main
kastmega	doc_284706151146_item	2323982	et	3	main
pirukaid	doc_284706151146_item	2323988	et	3	main
sel	doc_284706151147_item	2323999	et	3	main
ajal	doc_284706151147_item	2324000	et	4	main
ma	doc_284706151147_item	2324001	et	3	main
õppisin	doc_284706151147_item	2324002	et	3	main
tehnikumis	doc_284706151147_item	2324003	et	3	main
tema	doc_284706151147_item	2324004	et	4	main
õppis	doc_284706151147_item	2324005	et	3	main
tallinnas	doc_284706151147_item	2324006	et	4	main
vestlust	doc_284706151147_item	2324008	et	3	main
pedagoogikaülikoolis	doc_284706151147_item	2324007	et	4	main
alustasin	doc_284706151147_item	2324009	et	3	main
mina	doc_284706151147_item	2324010	et	4	main
me	doc_284706151147_item	2324011	et	4	main
vestlesime	doc_284706151147_item	2324012	et	3	main
oma	doc_284706151147_item	2324013	et	4	main
kolliasjadest	doc_284706151147_item	2324014	et	4	main
ta	doc_284706151147_item	2324015	et	4	main
jattis	doc_284706151147_item	2324016	et	4	main
mulle	doc_284706151147_item	2324017	et	4	main
väga	doc_284706151147_item	2324018	et	3	main
heamulje	doc_284706151147_item	2324019	et	4	main
ta	doc_284706151147_item	2324020	et	4	main
oli	doc_284706151147_item	2324021	et	3	main
helistan	doc_284706151147_item	2324035	et	3	main
hiljem	doc_284706151147_item	2324039	et	3	main
jalutamas	doc_284706151147_item	2324048	et	3	main
me	doc_284706151147_item	2324050	et	4	main
kuigi	doc_284706151147_item	2324054	et	3	main
väga	doc_284706151147_item	2324057	et	3	main
võib	doc_284706151147_item	2324061	et	3	main
restoranis	doc_284706151148_item	2324074	et	3	main
ma	doc_284706151148_item	2324079	et	3	main
meil	doc_284706151148_item	2324083	et	4	main
seal	doc_284706151148_item	2324085	et	4	main
mugav	doc_284706151148_item	2324086	et	3	main
baar	doc_284706151148_item	2324087	et	3	main
ma	doc_284706151148_item	2324100	et	3	main
koos	doc_284706151148_item	2324106	et	4	main
mulle	doc_284706151148_item	2324108	et	4	main
oma	doc_284706151148_item	2324113	et	4	main
käia	doc_284706151148_item	2324118	et	4	main
väljas	doc_284706151148_item	2324119	et	4	main
söömas	doc_284706151148_item	2324120	et	4	main
trilobit	doc_284706151148_item	2324096	et	4	main
korda	doc_284706151148_item	2324105	et	4	main
koos	doc_284706151148_item	2324112	et	4	main
koos	doc_284706151148_item	2324121	et	4	main
baar	doc_284706151148_item	2324136	et	3	main
toit	doc_284706151148_item	2324148	et	3	main
tellida	doc_284706151148_item	2324166	et	3	main
pirukaid	doc_284706151148_item	2324169	et	3	main
maksab	doc_284706151149_item	2324222	et	3	main
eest	doc_284706151149_item	2324224	et	4	main
sisaldab	doc_284706151149_item	2324235	et	3	main
tavaliselt	doc_284706151149_item	2324243	et	4	main
hernesupp	doc_284706151149_item	2324249	et	3	main
kievi	doc_284706151149_item	2324252	et	4	main
kala	doc_284706151149_item	2324254	et	4	main
on	doc_284706151149_item	2324259	et	4	main
kartul	doc_284706151149_item	2324261	et	3	main
frii	doc_284706151149_item	2324262	et	4	main
püree	doc_284706151149_item	2324264	et	4	main
ja	doc_284706151149_item	2324265	et	3	main
salatid	doc_284706151149_item	2324267	et	3	main
joogid	doc_284706151149_item	2324284	et	4	main
ebameeldivate	doc_284706151148_item	2324124	et	3	main
inimestega	doc_284706151148_item	2324125	et	3	main
ja	doc_284706151148_item	2324127	et	3	main
baaris	doc_284706151148_item	2324128	et	3	main
keldrikorrusel	doc_284706151148_item	2324138	et	3	main
on	doc_284706151148_item	2324140	et	4	main
lauad	doc_284706151148_item	2324142	et	3	main
ja	doc_284706151148_item	2324145	et	3	main
väga	doc_284706151148_item	2324152	et	3	main
maitsev	doc_284706151148_item	2324153	et	4	main
veel	doc_284706151148_item	2324164	et	4	main
salatid	doc_284706151148_item	2324167	et	3	main
ja	doc_284706151148_item	2324170	et	3	main
baarisse	doc_284706151149_item	2324175	et	3	main
ma	doc_284706151149_item	2324180	et	3	main
olen	doc_284706151149_item	2324181	et	3	main
käinud	doc_284706151149_item	2324182	et	4	main
leo	doc_284706151149_item	2324183	et	4	main
moonika	doc_284706151149_item	2324184	et	4	main
ja	doc_284706151149_item	2324185	et	3	main
neptuni	doc_284706151149_item	2324186	et	4	main
baarisse	doc_284706151149_item	2324187	et	3	main
mikro	doc_284706151149_item	2324188	et	4	main
kohvikusse	doc_284706151149_item	2324189	et	4	main
ja	doc_284706151149_item	2324190	et	3	main
alexi	doc_284706151149_item	2324191	et	4	main
alla	doc_284706151149_item	2324192	et	3	main
väljas	doc_284706151149_item	2324194	et	4	main
sööklasse	doc_284706151149_item	2324193	et	4	main
käja	doc_284706151149_item	2324195	et	4	main
söömas	doc_284706151149_item	2324196	et	4	main
on	doc_284706151149_item	2324197	et	4	main
tore	doc_284706151149_item	2324198	et	3	main
oma	doc_284706151149_item	2324199	et	4	main
sõbradega	doc_284706151149_item	2324200	et	4	main
ja	doc_284706151149_item	2324201	et	3	main
oma	doc_284706151149_item	2324202	et	4	main
perega	doc_284706151149_item	2324203	et	3	main
aga	doc_284706151149_item	2324204	et	3	main
eriti	doc_284706151149_item	2324205	et	3	main
tore	doc_284706151149_item	2324206	et	3	main
seal	doc_284706151148_item	2324139	et	4	main
toolid	doc_284706151148_item	2324144	et	3	main
interjöör	doc_284706151148_item	2324147	et	3	main
on	doc_284706151148_item	2324149	et	4	main
kodune	doc_284706151148_item	2324150	et	4	main
ja	doc_284706151148_item	2324151	et	3	main
meeldib	doc_284706151148_item	2324156	et	3	main
kastmega	doc_284706151148_item	2324163	et	3	main
võib	doc_284706151148_item	2324165	et	3	main
jooke	doc_284706151148_item	2324168	et	3	main
saiakesi	doc_284706151148_item	2324171	et	4	main
ma	doc_284706151149_item	2324173	et	3	main
ja	doc_284706151149_item	2324176	et	3	main
oma	doc_284706151149_item	2324208	et	4	main
poisiga	doc_284706151149_item	2324209	et	3	main
väljas	doc_284706151149_item	2324210	et	4	main
inimesega	doc_284706151149_item	2324217	et	3	main
pahasoovijaga	doc_284706151149_item	2324219	et	3	main
hea	doc_284706151149_item	2324230	et	4	main
menüü	doc_284706151149_item	2324233	et	4	main
kohvikus	doc_284706151149_item	2324234	et	3	main
praed	doc_284706151149_item	2324236	et	4	main
joogid	doc_284706151149_item	2324242	et	4	main
seljanka	doc_284706151149_item	2324246	et	4	main
uhha	doc_284706151149_item	2324247	et	4	main
ja	doc_284706151149_item	2324248	et	3	main
on	doc_284706151149_item	2324268	et	4	main
porgandi	doc_284706151149_item	2324276	et	3	main
tortid	doc_284706151149_item	2324283	et	4	main
ja	doc_284706151149_item	2324289	et	3	main
koos	doc_284706151149_item	2324207	et	4	main
võõrasega	doc_284706151149_item	2324216	et	4	main
ja	doc_284706151149_item	2324218	et	3	main
ja	doc_284706151149_item	2324241	et	3	main
on	doc_284706151149_item	2324251	et	4	main
kotlett	doc_284706151149_item	2324253	et	4	main
pealinna	doc_284706151149_item	2324271	et	4	main
magustoidud	doc_284706151149_item	2324278	et	3	main
puuvilja	doc_284706151149_item	2324280	et	4	main
jäätis	doc_284706151149_item	2324281	et	3	main
ja	doc_284706151149_item	2324282	et	3	main
kohv	doc_284706151149_item	2324288	et	3	main
noor	doc_284706151149_item	2324226	et	3	main
mees	doc_284706151149_item	2324227	et	4	main
või	doc_284706151149_item	2324228	et	4	main
minu	doc_284706151149_item	2324229	et	3	main
lisandid	doc_284706151149_item	2324238	et	3	main
magustoidud	doc_284706151149_item	2324240	et	3	main
praed	doc_284706151149_item	2324250	et	4	main
prantsuse	doc_284706151149_item	2324256	et	3	main
lisandid	doc_284706151149_item	2324258	et	3	main
ahju	doc_284706151149_item	2324260	et	4	main
karul	doc_284706151149_item	2324263	et	3	main
kartuli-singi	doc_284706151149_item	2324269	et	3	main
salat	doc_284706151149_item	2324270	et	3	main
salat	doc_284706151149_item	2324272	et	3	main
salat	doc_284706151149_item	2324274	et	3	main
on	doc_284706151149_item	2324279	et	4	main
õlu	doc_284706151149_item	2324287	et	3	main
tee	doc_284706151149_item	2324290	et	4	main
ja	doc_284706151149_item	2324255	et	3	main
liha	doc_284706151149_item	2324257	et	4	main
makaroonid	doc_284706151149_item	2324266	et	4	main
kapsa	doc_284706151149_item	2324273	et	4	main
ja	doc_284706151149_item	2324275	et	3	main
salat	doc_284706151149_item	2324277	et	3	main
on	doc_284706151149_item	2324285	et	4	main
mahlad	doc_284706151149_item	2324286	et	3	main
et	doc_286998102756_item	2327222	et	3	main
naisi	doc_286998102756_item	2327224	et	3	main
on	doc_286998102756_item	2327226	et	4	main
mehed	doc_286998102756_item	2327231	et	3	main
ajakirjades	doc_286998102756_item	2327233	et	3	main
võib	doc_286998102756_item	2327238	et	3	main
nad	doc_286998102756_item	2327242	et	3	main
natukesi	doc_286998102756_item	2327244	et	4	main
vanemaid	doc_286998102756_item	2327245	et	4	main
rõhutatakse	doc_286998102756_item	2327247	et	3	main
teemu	doc_286998102756_item	2327249	et	4	main
on	doc_286998102756_item	2327255	et	4	main
arvatakse	doc_286998102756_item	2327221	et	3	main
soeng	doc_286998102756_item	2327229	et	3	main
kirjutatakse	doc_286998102756_item	2327234	et	3	main
majapidamist	doc_286998102756_item	2327236	et	3	main
kui	doc_286998102756_item	2327241	et	3	main
teenindavad	doc_286998102756_item	2327243	et	4	main
erinevatele	doc_286998102756_item	2327251	et	4	main
tarbijatele	doc_286998102756_item	2327252	et	4	main
on	doc_286998102756_item	2327259	et	4	main
artikkel	doc_286998102756_item	2327263	et	3	main
et	doc_286998102756_item	2327269	et	3	main
ei	doc_286998102756_item	2327271	et	4	main
tavaliselt	doc_286998102756_item	2327279	et	4	main
töökohades	doc_286998102756_item	2327315	et	3	main
on	doc_286998102756_item	2327319	et	4	main
on	doc_286998102756_item	2327328	et	4	main
kuidas	doc_286998102756_item	2327329	et	3	main
mehele	doc_286998102756_item	2327334	et	3	main
kõige	doc_286998102756_item	2327336	et	4	main
meeste	doc_286998102756_item	2327339	et	4	main
kokkuvõte	doc_286998102756_item	2327343	et	3	main
oli	doc_286998102756_item	2327349	et	3	main
tahtsin	doc_286998102756_item	2327360	et	3	main
on	doc_286998102756_item	2327370	et	4	main
aga	doc_286998102756_item	2327374	et	3	main
ja	doc_286998102756_item	2327377	et	3	main
temal	doc_286998102756_item	2327381	et	3	main
meeldib	doc_286998102756_item	2327385	et	3	main
sõber	doc_286998102756_item	2327393	et	3	main
palju	doc_286998102756_item	2327397	et	4	main
ja	doc_286998102756_item	2327399	et	3	main
meeldivad	doc_286998102756_item	2327402	et	4	main
kasutab	doc_286998102756_item	2327408	et	3	main
meik	doc_286998102756_item	2327228	et	3	main
ja	doc_286998102756_item	2327230	et	3	main
mõned	doc_286998102756_item	2327232	et	3	main
ja	doc_286998102756_item	2327237	et	3	main
lastekasvatusest	doc_286998102756_item	2327240	et	4	main
vastavalt	doc_286998102756_item	2327250	et	4	main
samad	doc_286998102756_item	2327257	et	3	main
tavaliselt	doc_286998102756_item	2327258	et	4	main
üks	doc_286998102756_item	2327262	et	3	main
pinnapealne	doc_286998102756_item	2327276	et	3	main
see	doc_286998102756_item	2327278	et	3	main
naised	doc_286998102756_item	2327317	et	3	main
essee	doc_286998102756_item	2327213	et	4	main
naisteajakirjades	doc_286998102756_item	2327214	et	3	main
tavaliselt	doc_286998102756_item	2327215	et	4	main
kirjutatakse	doc_286998102756_item	2327216	et	3	main
lihtsadest	doc_286998102756_item	2327217	et	4	main
teemadest	doc_286998102756_item	2327218	et	3	main
asjadest	doc_286998102756_item	2327219	et	3	main
millest	doc_286998102756_item	2327220	et	3	main
huvitavad	doc_286998102756_item	2327223	et	4	main
need	doc_286998102756_item	2327225	et	3	main
mood	doc_286998102756_item	2327227	et	3	main
naisi	doc_286998102756_item	2327246	et	3	main
aga	doc_286998102756_item	2327253	et	3	main
ka	doc_286998102756_item	2327261	et	3	main
raskest	doc_286998102756_item	2327267	et	3	main
teemast	doc_286998102756_item	2327268	et	4	main
ajakiri	doc_286998102756_item	2327270	et	3	main
on	doc_286998102756_item	2327280	et	4	main
mulle	doc_286998102756_item	2327281	et	4	main
tundub	doc_286998102756_item	2327282	et	3	main
et	doc_286998102756_item	2327283	et	3	main
tüüpilised	doc_286998102756_item	2327284	et	3	main
meesteajakirjad	doc_286998102756_item	2327285	et	3	main
on	doc_286998102756_item	2327286	et	4	main
väga	doc_286998102756_item	2327287	et	3	main
sarnased	doc_286998102756_item	2327288	et	4	main
naisteajakirjadega	doc_286998102756_item	2327289	et	3	main
nad	doc_286998102756_item	2327290	et	3	main
on	doc_286998102756_item	2327291	et	4	main
ka	doc_286998102756_item	2327292	et	3	main
väga	doc_286998102756_item	2327293	et	3	main
pinnapealsed	doc_286998102756_item	2327294	et	3	main
ja	doc_286998102756_item	2327295	et	3	main
ei	doc_286998102756_item	2327296	et	4	main
kirjuta	doc_286998102756_item	2327297	et	4	main
mitte	doc_286998102756_item	2327298	et	3	main
millest	doc_286998102756_item	2327299	et	3	main
teemad	doc_286998102756_item	2327300	et	3	main
on	doc_286998102756_item	2327301	et	4	main
erinevad	doc_286998102756_item	2327302	et	4	main
nendest	doc_286998102756_item	2327303	et	4	main
nagu	doc_286998102756_item	2327304	et	3	main
autod	doc_286998102756_item	2327305	et	3	main
töö	doc_286998102756_item	2327306	et	4	main
sest	doc_286998102756_item	2327307	et	4	main
mehed	doc_286998102756_item	2327308	et	3	main
töötavad	doc_286998102756_item	2327309	et	4	main
alati	doc_286998102756_item	2327310	et	4	main
olulises	doc_286998102756_item	2327311	et	4	main
vastutavates	doc_286998102756_item	2327312	et	4	main
ja	doc_286998102756_item	2327313	et	3	main
ka	doc_286998102756_item	2327235	et	3	main
olla	doc_286998102756_item	2327239	et	3	main
erinevaid	doc_286998102756_item	2327248	et	4	main
teemad	doc_286998102756_item	2327254	et	3	main
alati	doc_286998102756_item	2327256	et	4	main
ühest	doc_286998102756_item	2327264	et	4	main
näe	doc_286998102756_item	2327272	et	4	main
täielikult	doc_286998102756_item	2327275	et	4	main
mis	doc_286998102756_item	2327277	et	4	main
kohta	doc_286998102756_item	2327327	et	4	main
peaks	doc_286998102756_item	2327331	et	4	main
naisteajakirjades	doc_286998102756_item	2327342	et	3	main
esimene	doc_286998102756_item	2327344	et	3	main
ma	doc_286998102756_item	2327347	et	3	main
lugesin	doc_286998102756_item	2327348	et	3	main
kaupersega	doc_286998102756_item	2327352	et	4	main
läti	doc_286998102756_item	2327355	et	4	main
ansambli	doc_286998102756_item	2327356	et	3	main
brainstormi	doc_286998102756_item	2327357	et	4	main
seda	doc_286998102756_item	2327361	et	3	main
sest	doc_286998102756_item	2327363	et	4	main
tundub	doc_286998102756_item	2327365	et	3	main
et	doc_286998102756_item	2327366	et	3	main
tema	doc_286998102756_item	2327367	et	4	main
ja	doc_286998102756_item	2327368	et	3	main
mitte	doc_286998102756_item	2327375	et	3	main
siin	doc_286998102756_item	2327376	et	4	main
muusika	doc_286998102756_item	2327387	et	4	main
lätist	doc_286998102756_item	2327394	et	4	main
ka	doc_286998102756_item	2327405	et	3	main
mehi	doc_286998102756_item	2327419	et	3	main
neid	doc_286998102756_item	2327421	et	4	main
veel	doc_286998102756_item	2327423	et	4	main
tahavad	doc_286998102756_item	2327425	et	3	main
see	doc_286998102756_item	2327430	et	3	main
eriti	doc_286998102756_item	2327435	et	3	main
sellisi	doc_286998102756_item	2327438	et	4	main
nad	doc_286998102756_item	2327440	et	3	main
oli	doc_286998102756_item	2327445	et	3	main
laulja	doc_286998102756_item	2327449	et	4	main
on	doc_286998102756_item	2327467	et	4	main
tähtsam	doc_286998102756_item	2327471	et	4	main
oli	doc_286998102756_item	2327473	et	3	main
kõige	doc_286998102756_item	2327478	et	4	main
rõivaese	doc_286998102756_item	2327480	et	3	main
minu	doc_286998102756_item	2327482	et	3	main
terve	doc_286998102756_item	2327484	et	4	main
intervjuu	doc_286998102756_item	2327485	et	4	main
ainult	doc_286998102756_item	2327495	et	4	main
esimene	doc_286998102756_item	2327529	et	3	main
emailsari	doc_286998102756_item	2327537	et	4	main
jõulupidu	doc_286998102756_item	2327538	et	4	main
mida	doc_286998102756_item	2327540	et	4	main
poliitikaalse	doc_286998102756_item	2327546	et	4	main
peale	doc_286998102756_item	2327548	et	4	main
rühma	doc_286998102756_item	2327554	et	4	main
õigse	doc_286998102756_item	2327569	et	4	main
meeldivaks	doc_286998102756_item	2327577	et	4	main
essee	doc_286998102757_item	2327579	et	4	main
ma	doc_286998102757_item	2327580	et	3	main
olen	doc_286998102757_item	2327581	et	3	main
eesti	doc_286998102757_item	2327582	et	4	main
naise	doc_286998102757_item	2327583	et	3	main
lehe	doc_286998102757_item	2327584	et	3	main
inimestest	doc_286998102757_item	2327590	et	3	main
peab	doc_286998102757_item	2327594	et	4	main
kui	doc_286998102757_item	2327601	et	3	main
tahab	doc_286998102757_item	2327602	et	3	main
missugune	doc_286998102757_item	2327605	et	3	main
naiselehed	doc_286998102757_item	2327612	et	3	main
mind	doc_286998102757_item	2327616	et	4	main
see	doc_286998102757_item	2327618	et	3	main
on	doc_286998102757_item	2327619	et	4	main
asjades	doc_286998102757_item	2327628	et	3	main
huvitatud	doc_286998102757_item	2327629	et	4	main
arvan	doc_286998102757_item	2327632	et	3	main
on	doc_286998102757_item	2327633	et	4	main
nendes	doc_286998102757_item	2327639	et	4	main
ja	doc_286998102757_item	2327649	et	3	main
riiet	doc_286998102757_item	2327651	et	3	main
panema	doc_286998102757_item	2327653	et	3	main
poliitiklastest	doc_286998102757_item	2327674	et	4	main
ajakirjas	doc_286998102756_item	2327260	et	3	main
tõsisest	doc_286998102756_item	2327265	et	4	main
ja	doc_286998102756_item	2327266	et	3	main
välja	doc_286998102756_item	2327273	et	4	main
nagu	doc_286998102756_item	2327274	et	3	main
naine	doc_286998102756_item	2327330	et	3	main
ka	doc_286998102756_item	2327341	et	3	main
artikkel	doc_286998102756_item	2327345	et	3	main
intervjuu	doc_286998102756_item	2327350	et	4	main
on	doc_286998102756_item	2327354	et	4	main
mulle	doc_286998102756_item	2327364	et	4	main
kuulsamad	doc_286998102756_item	2327372	et	4	main
ma	doc_286998102756_item	2327378	et	3	main
rohkem	doc_286998102756_item	2327380	et	4	main
ka	doc_286998102756_item	2327383	et	3	main
hea	doc_286998102756_item	2327392	et	4	main
intervjuus	doc_286998102756_item	2327395	et	3	main
vähe	doc_286998102756_item	2327418	et	3	main
ehkki	doc_286998102756_item	2327428	et	3	main
kui	doc_286998102756_item	2327436	et	3	main
loetakse	doc_286998102756_item	2327437	et	3	main
ajakirju	doc_286998102756_item	2327439	et	4	main
väga	doc_286998102756_item	2327446	et	3	main
kui	doc_286998102756_item	2327448	et	3	main
ütles	doc_286998102756_item	2327450	et	3	main
et	doc_286998102756_item	2327451	et	3	main
tal	doc_286998102756_item	2327452	et	3	main
ei	doc_286998102756_item	2327453	et	4	main
taktikat	doc_286998102756_item	2327457	et	3	main
ta	doc_286998102756_item	2327460	et	4	main
naine	doc_286998102756_item	2327468	et	3	main
et	doc_286998102756_item	2327474	et	3	main
oma	doc_286998102756_item	2327477	et	4	main
veider	doc_286998102756_item	2327488	et	3	main
küsimused	doc_286998102756_item	2327489	et	4	main
olnud	doc_286998102756_item	2327491	et	4	main
ka	doc_286998102756_item	2327522	et	3	main
seal	doc_286998102756_item	2327535	et	4	main
väljamõeldud	doc_286998102756_item	2327536	et	4	main
olid	doc_286998102756_item	2327544	et	4	main
nagu	doc_286998102756_item	2327557	et	3	main
see	doc_286998102756_item	2327562	et	3	main
võimalik	doc_286998102756_item	2327564	et	3	main
teine	doc_286998102756_item	2327566	et	3	main
neid	doc_286998102756_item	2327574	et	4	main
lugenud	doc_286998102757_item	2327585	et	4	main
naistele	doc_286998102757_item	2327588	et	3	main
hästi	doc_286998102757_item	2327595	et	3	main
ja	doc_286998102757_item	2327609	et	3	main
need	doc_286998102757_item	2327611	et	3	main
minu	doc_286998102757_item	2327621	et	3	main
ma	doc_286998102757_item	2327624	et	3	main
ole	doc_286998102757_item	2327626	et	4	main
paljudes	doc_286998102757_item	2327627	et	3	main
kirjutatud	doc_286998102757_item	2327634	et	4	main
ja	doc_286998102757_item	2327637	et	3	main
ei	doc_286998102757_item	2327641	et	4	main
kui	doc_286998102757_item	2327654	et	3	main
mida	doc_286998102757_item	2327671	et	4	main
aga	doc_286998102757_item	2327675	et	3	main
meeste	doc_286998102757_item	2327678	et	4	main
nende	doc_286998102757_item	2327682	et	4	main
midagi	doc_286998102757_item	2327686	et	4	main
naiste	doc_286998102757_item	2327689	et	3	main
meeste	doc_286998102757_item	2327691	et	4	main
palju	doc_286998102757_item	2327694	et	4	main
reklaame	doc_286998102757_item	2327695	et	3	main
aga	doc_286998102757_item	2327696	et	3	main
pole	doc_286998102757_item	2327697	et	3	main
meestele	doc_286998102757_item	2327709	et	4	main
spordiasjad	doc_286998102757_item	2327713	et	3	main
mehedki	doc_286998102757_item	2327715	et	3	main
häbinägu	doc_286998102757_item	2327721	et	4	main
nii	doc_286998102757_item	2327727	et	3	main
olla	doc_286998102757_item	2327730	et	3	main
kord	doc_286998102757_item	2327733	et	4	main
sõitis	doc_286998102757_item	2327735	et	3	main
käitumisega	doc_286998102757_item	2327740	et	4	main
tahtis	doc_286998102757_item	2327741	et	3	main
miks	doc_286998102757_item	2327749	et	4	main
saab	doc_286998102757_item	2327757	et	3	main
sõpraga	doc_286998102757_item	2327770	et	4	main
pingelistes	doc_286998102756_item	2327314	et	4	main
ja	doc_286998102756_item	2327316	et	3	main
sarnane	doc_286998102756_item	2327318	et	4	main
ka	doc_286998102756_item	2327320	et	3	main
see	doc_286998102756_item	2327321	et	3	main
kõige	doc_286998102756_item	2327323	et	4	main
käituma	doc_286998102756_item	2327332	et	3	main
et	doc_286998102756_item	2327333	et	3	main
parem	doc_286998102756_item	2327337	et	4	main
nii	doc_286998102756_item	2327338	et	3	main
kes	doc_286998102756_item	2327353	et	4	main
laulja	doc_286998102756_item	2327358	et	4	main
lugeda	doc_286998102756_item	2327362	et	3	main
brainstorm	doc_286998102756_item	2327369	et	4	main
baltiriigides	doc_286998102756_item	2327373	et	4	main
tahtsin	doc_286998102756_item	2327379	et	3	main
teada	doc_286998102756_item	2327382	et	3	main
nende	doc_286998102756_item	2327386	et	4	main
ja	doc_286998102756_item	2327388	et	3	main
üks	doc_286998102756_item	2327391	et	3	main
räägiti	doc_286998102756_item	2327396	et	3	main
moest	doc_286998102756_item	2327398	et	4	main
riideid	doc_286998102756_item	2327401	et	3	main
renarsile	doc_286998102756_item	2327403	et	4	main
küsiti	doc_286998102756_item	2327404	et	3	main
ta	doc_286998102756_item	2327407	et	4	main
kosmeetikat	doc_286998102756_item	2327409	et	3	main
ma	doc_286998102756_item	2327411	et	3	main
pidin	doc_286998102756_item	2327412	et	3	main
väga	doc_286998102756_item	2327413	et	3	main
on	doc_286998102756_item	2327431	et	4	main
täna	doc_286998102756_item	2327432	et	4	main
ka	doc_286998102756_item	2327442	et	3	main
naistest	doc_286998102756_item	2327443	et	4	main
kasutada	doc_286998102756_item	2327458	et	3	main
võita	doc_286998102756_item	2327462	et	4	main
naiste	doc_286998102756_item	2327463	et	3	main
ja	doc_286998102756_item	2327469	et	3	main
renars	doc_286998102756_item	2327475	et	4	main
otsis	doc_286998102756_item	2327476	et	4	main
oli	doc_286998102756_item	2327486	et	3	main
väga	doc_286998102756_item	2327487	et	3	main
olid	doc_286998102756_item	2327494	et	4	main
juhuslikult	doc_286998102756_item	2327496	et	4	main
küsimused	doc_286998102756_item	2327498	et	4	main
ilmus	doc_286998102756_item	2327521	et	4	main
eestis	doc_286998102756_item	2327523	et	3	main
kevadel	doc_286998102756_item	2327524	et	4	main
kokkuvõte	doc_286998102756_item	2327525	et	3	main
saadeti	doc_286998102756_item	2327541	et	3	main
emailid	doc_286998102756_item	2327543	et	4	main
korrekstuse	doc_286998102756_item	2327547	et	4	main
või	doc_286998102756_item	2327559	et	4	main
aga	doc_286998102756_item	2327561	et	3	main
polnud	doc_286998102756_item	2327563	et	3	main
artikli	doc_286998102756_item	2327565	et	3	main
osa	doc_286998102756_item	2327567	et	4	main
büroojõulupeosest	doc_286998102756_item	2327570	et	4	main
mida	doc_286998102756_item	2327572	et	4	main
ja	doc_286998102756_item	2327576	et	3	main
selles	doc_286998102757_item	2327586	et	4	main
kirjutatakse	doc_286998102757_item	2327587	et	3	main
peab	doc_286998102757_item	2327599	et	4	main
vaja	doc_286998102757_item	2327608	et	4	main
nii	doc_286998102757_item	2327610	et	3	main
eriti	doc_286998102757_item	2327613	et	3	main
huvita	doc_286998102757_item	2327615	et	4	main
aga	doc_286998102757_item	2327617	et	3	main
viga	doc_286998102757_item	2327622	et	4	main
naistest	doc_286998102757_item	2327635	et	4	main
autodest	doc_286998102757_item	2327636	et	3	main
ole	doc_286998102757_item	2327642	et	4	main
võib	doc_286998102757_item	2327657	et	3	main
peab	doc_286998102757_item	2327672	et	4	main
et	doc_286998102757_item	2327677	et	3	main
ja	doc_286998102757_item	2327684	et	3	main
sama	doc_286998102757_item	2327698	et	4	main
aga	doc_286998102757_item	2327708	et	3	main
alkohol	doc_286998102757_item	2327711	et	3	main
tahavad	doc_286998102757_item	2327716	et	3	main
välja	doc_286998102757_item	2327718	et	4	main
artikel	doc_286998102757_item	2327720	et	4	main
et	doc_286998102756_item	2327322	et	3	main
tähtsam	doc_286998102756_item	2327324	et	4	main
naiste-meeste	doc_286998102756_item	2327325	et	4	main
suhete	doc_286998102756_item	2327326	et	3	main
oleks	doc_286998102756_item	2327335	et	3	main
kui	doc_286998102756_item	2327340	et	3	main
mida	doc_286998102756_item	2327346	et	4	main
renars	doc_286998102756_item	2327351	et	4	main
ma	doc_286998102756_item	2327359	et	3	main
päris	doc_286998102756_item	2327371	et	4	main
mulle	doc_286998102756_item	2327384	et	4	main
mul	doc_286998102756_item	2327389	et	3	main
on	doc_286998102756_item	2327390	et	4	main
milliseid	doc_286998102756_item	2327400	et	3	main
kas	doc_286998102756_item	2327406	et	3	main
huvitaks	doc_286998102756_item	2327414	et	4	main
kasutavad	doc_286998102756_item	2327420	et	4	main
ja	doc_286998102756_item	2327422	et	3	main
vähem	doc_286998102756_item	2327424	et	4	main
täielik	doc_286998102756_item	2327433	et	3	main
armas	doc_286998102756_item	2327447	et	3	main
südant	doc_286998102756_item	2327464	et	3	main
kõige	doc_286998102756_item	2327470	et	4	main
artiklis	doc_286998102756_item	2327472	et	3	main
ungaris	doc_286998102756_item	2327481	et	4	main
meelest	doc_286998102756_item	2327483	et	4	main
seotud	doc_286998102756_item	2327493	et	4	main
teise	doc_286998102756_item	2327527	et	4	main
oli	doc_286998102756_item	2327531	et	3	main
päris	doc_286998102756_item	2327532	et	4	main
naljakas	doc_286998102756_item	2327533	et	4	main
olid	doc_286998102756_item	2327534	et	4	main
sest	doc_286998102756_item	2327549	et	4	main
iga	doc_286998102756_item	2327550	et	4	main
email	doc_286998102756_item	2327551	et	3	main
proovis	doc_286998102756_item	2327552	et	4	main
soovi	doc_286998102756_item	2327555	et	4	main
moslemid	doc_286998102756_item	2327558	et	3	main
taimetoitlased	doc_286998102756_item	2327560	et	3	main
ja	doc_286998102756_item	2327571	et	3	main
kuulsatest	doc_286998102757_item	2327589	et	3	main
sellest	doc_286998102757_item	2327591	et	4	main
naine	doc_286998102757_item	2327593	et	3	main
välja	doc_286998102757_item	2327596	et	4	main
nägema	doc_286998102757_item	2327597	et	3	main
mida	doc_286998102757_item	2327598	et	4	main
soeng	doc_286998102757_item	2327606	et	3	main
ei	doc_286998102757_item	2327614	et	4	main
mida	doc_286998102756_item	2327410	et	4	main
mulle	doc_286998102756_item	2327415	et	4	main
tundub	doc_286998102756_item	2327416	et	3	main
et	doc_286998102756_item	2327417	et	3	main
sellest	doc_286998102756_item	2327426	et	4	main
rääkida	doc_286998102756_item	2327427	et	3	main
kui	doc_286998102756_item	2327429	et	3	main
normaalne	doc_286998102756_item	2327434	et	3	main
räägisid	doc_286998102756_item	2327441	et	4	main
ja	doc_286998102756_item	2327444	et	3	main
ole	doc_286998102756_item	2327454	et	4	main
vaja	doc_286998102756_item	2327455	et	4	main
mingisugust	doc_286998102756_item	2327456	et	3	main
kui	doc_286998102756_item	2327459	et	3	main
tahab	doc_286998102756_item	2327461	et	3	main
sest	doc_286998102756_item	2327465	et	4	main
tal	doc_286998102756_item	2327466	et	3	main
pöörane	doc_286998102756_item	2327479	et	4	main
ei	doc_286998102756_item	2327490	et	4	main
üksteisega	doc_286998102756_item	2327492	et	3	main
valitud	doc_286998102756_item	2327497	et	4	main
mulle	doc_286998102756_item	2327499	et	4	main
tundub	doc_286998102756_item	2327500	et	3	main
kolmveerand	doc_286998102756_item	2327501	et	4	main
nendest	doc_286998102756_item	2327502	et	4	main
oli	doc_286998102756_item	2327503	et	3	main
ja	doc_286998102756_item	2327505	et	3	main
mitte	doc_286998102756_item	2327506	et	3	main
moest	doc_286998102756_item	2327504	et	4	main
ainult	doc_286998102756_item	2327507	et	4	main
üks	doc_286998102756_item	2327508	et	3	main
oli	doc_286998102756_item	2327509	et	3	main
ansambli	doc_286998102756_item	2327510	et	3	main
uuelt	doc_286998102756_item	2327511	et	4	main
plaadilt	doc_286998102756_item	2327512	et	3	main
mis	doc_286998102756_item	2327513	et	4	main
ma	doc_286998102756_item	2327514	et	3	main
arvasin	doc_286998102756_item	2327515	et	3	main
on	doc_286998102756_item	2327516	et	4	main
tema	doc_286998102756_item	2327517	et	4	main
jaoks	doc_286998102756_item	2327518	et	4	main
tähtsam	doc_286998102756_item	2327519	et	4	main
ja	doc_286998102756_item	2327520	et	3	main
2	doc_286998102756_item	2327526	et	2	main
artikli	doc_286998102756_item	2327528	et	3	main
osa	doc_286998102756_item	2327530	et	4	main
organiseermisest	doc_286998102756_item	2327539	et	4	main
personaliosakonnast	doc_286998102756_item	2327542	et	4	main
nali	doc_286998102756_item	2327545	et	3	main
ühe	doc_286998102756_item	2327553	et	4	main
täita	doc_286998102756_item	2327556	et	4	main
oli	doc_286998102756_item	2327568	et	3	main
proovitakse	doc_286998102756_item	2327573	et	4	main
huvitavamaks	doc_286998102756_item	2327575	et	4	main
muuta	doc_286998102756_item	2327578	et	4	main
kuidas	doc_286998102757_item	2327592	et	3	main
sööma	doc_286998102757_item	2327600	et	4	main
ilus	doc_286998102757_item	2327603	et	4	main
olla	doc_286998102757_item	2327604	et	3	main
on	doc_286998102757_item	2327607	et	4	main
vist	doc_286998102757_item	2327620	et	4	main
et	doc_286998102757_item	2327623	et	3	main
ei	doc_286998102757_item	2327625	et	4	main
lehtes	doc_286998102757_item	2327631	et	3	main
peaks	doc_286998102757_item	2327645	et	4	main
õhtul	doc_286998102757_item	2327646	et	3	main
tegema	doc_286998102757_item	2327648	et	3	main
mis	doc_286998102757_item	2327650	et	4	main
pidutsema	doc_286998102757_item	2327656	et	3	main
olla	doc_286998102757_item	2327658	et	3	main
teadma	doc_286998102757_item	2327673	et	3	main
perest	doc_286998102757_item	2327683	et	4	main
nii	doc_286998102757_item	2327688	et	3	main
ja	doc_286998102757_item	2327690	et	3	main
reklaamitakse	doc_286998102757_item	2327701	et	4	main
kreemid	doc_286998102757_item	2327703	et	3	main
parfüüm	doc_286998102757_item	2327705	et	3	main
teised	doc_286998102757_item	2327707	et	4	main
sest	doc_286998102757_item	2327714	et	4	main
hästi	doc_286998102757_item	2327717	et	3	main
ees	doc_286998102757_item	2327722	et	4	main
piinlik	doc_286998102757_item	2327728	et	3	main
kes	doc_286998102757_item	2327739	et	4	main
endale	doc_286998102757_item	2327742	et	4	main
tähelepanu	doc_286998102757_item	2327743	et	4	main
äratada	doc_286998102757_item	2327744	et	3	main
kirjanik	doc_286998102757_item	2327745	et	3	main
ei	doc_286998102757_item	2327746	et	4	main
nii	doc_286998102757_item	2327751	et	3	main
käituma	doc_286998102757_item	2327752	et	3	main
proovida	doc_286998102757_item	2327761	et	3	main
kui	doc_286998102757_item	2327763	et	3	main
välismaal	doc_286998102757_item	2327765	et	4	main
sõitis	doc_286998102757_item	2327766	et	3	main
bussis	doc_286998102757_item	2327767	et	3	main
ja	doc_286998102757_item	2327768	et	3	main
rääkis	doc_286998102757_item	2327769	et	3	main
ja	doc_286998102757_item	2327776	et	3	main
mille	doc_286998102757_item	2327780	et	3	main
nad	doc_286998102757_item	2327782	et	3	main
aga	doc_286998102757_item	2327791	et	3	main
nad	doc_286998102757_item	2327796	et	3	main
oleme	doc_286998102757_item	2327821	et	3	main
piinlik	doc_286998102757_item	2327829	et	3	main
eest	doc_286998102757_item	2327840	et	4	main
ladin	doc_286998102757_item	2327846	et	3	main
artiklit	doc_286998102757_item	2327848	et	3	main
võtis	doc_286998102757_item	2327850	et	3	main
ja	doc_286998102757_item	2327860	et	3	main
carmen	doc_286998102757_item	2327861	et	4	main
oli	doc_286998102757_item	2327862	et	3	main
inimene	doc_286998102757_item	2327873	et	3	main
elasid	doc_286998102757_item	2327875	et	4	main
oligi	doc_286998102757_item	2327878	et	3	main
õigus	doc_286998102757_item	2327880	et	4	main
kodus	doc_286998102757_item	2327881	et	4	main
aga	doc_286998102757_item	2327882	et	3	main
see	doc_286998102757_item	2327883	et	3	main
hakkas	doc_286998102757_item	2327884	et	3	main
muutuma	doc_286998102757_item	2327885	et	4	main
et	doc_286998102757_item	2327888	et	3	main
moderni	doc_286998102757_item	2327891	et	4	main
ühiskond	doc_286998102757_item	2327892	et	3	main
ja	doc_286998102757_item	2327896	et	3	main
meeste	doc_286998102757_item	2327630	et	4	main
sportidest	doc_286998102757_item	2327638	et	3	main
kindlasti	doc_286998102757_item	2327640	et	3	main
et	doc_286998102757_item	2327643	et	3	main
mida	doc_286998102757_item	2327644	et	4	main
süüa	doc_286998102757_item	2327647	et	3	main
selga	doc_286998102757_item	2327652	et	4	main
läheb	doc_286998102757_item	2327655	et	3	main
et	doc_286998102757_item	2327659	et	3	main
sama	doc_286998102757_item	2327660	et	4	main
nendes	doc_286998102757_item	2327661	et	4	main
et	doc_286998102757_item	2327662	et	3	main
mõlemates	doc_286998102757_item	2327663	et	3	main
on	doc_286998102757_item	2327664	et	4	main
kirjutatud	doc_286998102757_item	2327665	et	4	main
et	doc_286998102757_item	2327666	et	3	main
kuhu	doc_286998102757_item	2327667	et	3	main
tasub	doc_286998102757_item	2327668	et	3	main
minna	doc_286998102757_item	2327669	et	3	main
suvel	doc_286998102757_item	2327670	et	3	main
arvan	doc_286998102757_item	2327676	et	3	main
koerast	doc_286998102757_item	2327685	et	4	main
lehtesi	doc_286998102757_item	2327692	et	4	main
on	doc_286998102757_item	2327693	et	4	main
naistele	doc_286998102757_item	2327700	et	3	main
juuksevärv	doc_286998102757_item	2327704	et	3	main
näha	doc_286998102757_item	2327719	et	3	main
lehtes	doc_286998102757_item	2327679	et	3	main
ei	doc_286998102757_item	2327680	et	4	main
ole	doc_286998102757_item	2327681	et	4	main
või	doc_286998102757_item	2327687	et	4	main
värki	doc_286998102757_item	2327699	et	4	main
silmakompress	doc_286998102757_item	2327702	et	4	main
ja	doc_286998102757_item	2327706	et	3	main
auto	doc_286998102757_item	2327710	et	4	main
ja	doc_286998102757_item	2327712	et	3	main
kui	doc_286998102757_item	2327731	et	3	main
seal	doc_286998102757_item	2327737	et	4	main
mees	doc_286998102757_item	2327738	et	4	main
peab	doc_286998102757_item	2327750	et	4	main
keegi	doc_286998102757_item	2327754	et	4	main
normaalselt	doc_286998102757_item	2327760	et	4	main
oma	doc_286998102757_item	2327771	et	4	main
keelt	doc_286998102757_item	2327772	et	4	main
küsis	doc_286998102757_item	2327778	et	3	main
keeles	doc_286998102757_item	2327781	et	4	main
rääkivad	doc_286998102757_item	2327783	et	4	main
kuulnud	doc_286998102757_item	2327789	et	4	main
ilus	doc_286998102757_item	2327795	et	4	main
vastutust	doc_286998102757_item	2327834	et	4	main
teiste	doc_286998102757_item	2327838	et	4	main
elu	doc_286998102757_item	2327841	et	4	main
vennanaisena	doc_286998102757_item	2327843	et	3	main
carmen	doc_286998102757_item	2327844	et	4	main
kirjutas	doc_286998102757_item	2327847	et	3	main
keda	doc_286998102757_item	2327849	et	4	main
ladin	doc_286998102757_item	2327854	et	3	main
ta	doc_286998102757_item	2327856	et	4	main
kõike	doc_286998102757_item	2327859	et	4	main
et	doc_286998102757_item	2327868	et	3	main
on	doc_286998102757_item	2327870	et	4	main
maailma	doc_286998102757_item	2327871	et	4	main
rohkem	doc_286998102757_item	2327895	et	4	main
otsustas	doc_286998102757_item	2327932	et	3	main
on	doc_286998102757_item	2327947	et	4	main
naiivne	doc_286998102757_item	2327949	et	3	main
rumal	doc_286998102757_item	2327951	et	3	main
palju	doc_286998102757_item	2327955	et	4	main
inimene	doc_286998102757_item	2327961	et	3	main
armsad	doc_286998102757_item	2327971	et	3	main
ja	doc_286998102757_item	2327972	et	3	main
ma	doc_286998102757_item	2327980	et	3	main
inimesi	doc_286998102757_item	2327985	et	4	main
räägib	doc_286998102757_item	2327724	et	3	main
mõnikord	doc_286998102757_item	2327726	et	3	main
eestlane	doc_286998102757_item	2327729	et	3	main
saa	doc_286998102757_item	2327747	et	4	main
kui	doc_286998102757_item	2327753	et	3	main
tähelepanu	doc_286998102757_item	2327756	et	4	main
ka	doc_286998102757_item	2327759	et	3	main
näiteks	doc_286998102757_item	2327762	et	4	main
ta	doc_286998102757_item	2327764	et	4	main
kuulis	doc_286998102757_item	2327775	et	4	main
ole	doc_286998102757_item	2327787	et	4	main
veel	doc_286998102757_item	2327788	et	4	main
on	doc_286998102757_item	2327793	et	4	main
käitusid	doc_286998102757_item	2327797	et	4	main
täiesti	doc_286998102757_item	2327798	et	3	main
normaalselt	doc_286998102757_item	2327799	et	4	main
ometigi	doc_286998102757_item	2327800	et	4	main
said	doc_286998102757_item	2327801	et	4	main
tähelepanu	doc_286998102757_item	2327802	et	4	main
ja	doc_286998102757_item	2327803	et	3	main
nad	doc_286998102757_item	2327804	et	3	main
olid	doc_286998102757_item	2327805	et	4	main
väga	doc_286998102757_item	2327806	et	3	main
uhked	doc_286998102757_item	2327807	et	4	main
eestlase	doc_286998102757_item	2327808	et	3	main
olemise	doc_286998102757_item	2327809	et	4	main
pärast	doc_286998102757_item	2327810	et	4	main
ma	doc_286998102757_item	2327811	et	3	main
arvan	doc_286998102757_item	2327812	et	3	main
et	doc_286998102757_item	2327813	et	3	main
tõesti	doc_286998102757_item	2327814	et	3	main
peab	doc_286998102757_item	2327815	et	4	main
olema	doc_286998102757_item	2327817	et	4	main
uhke	doc_286998102757_item	2327816	et	4	main
et	doc_286998102757_item	2327818	et	3	main
oleme	doc_286998102757_item	2327819	et	3	main
kes	doc_286998102757_item	2327820	et	4	main
kahjuks	doc_286998102757_item	2327822	et	4	main
palju	doc_286998102757_item	2327824	et	4	main
käitumise	doc_286998102757_item	2327839	et	4	main
osama	doc_286998102757_item	2327842	et	4	main
yeslam	doc_286998102757_item	2327852	et	4	main
bin	doc_286998102757_item	2327853	et	4	main
saudi-araabiast	doc_286998102757_item	2327855	et	3	main
lubas	doc_286998102757_item	2327857	et	3	main
naisele	doc_286998102757_item	2327858	et	3	main
et	doc_286998102757_item	2327866	et	3	main
nad	doc_286998102757_item	2327874	et	3	main
saudi-araabias	doc_286998102757_item	2327876	et	4	main
carmenil	doc_286998102757_item	2327877	et	4	main
paistas	doc_286998102757_item	2327886	et	4	main
nii	doc_286998102757_item	2327887	et	3	main
saudi-araabiast	doc_286998102757_item	2327889	et	3	main
tuli	doc_286998102757_item	2327890	et	4	main
päeval	doc_286998102757_item	2327894	et	3	main
hakkasid	doc_286998102757_item	2327921	et	4	main
carmeni	doc_286998102757_item	2327923	et	4	main
carmen	doc_286998102757_item	2327931	et	4	main
naine	doc_286998102757_item	2327723	et	3	main
et	doc_286998102757_item	2327725	et	3	main
ta	doc_286998102757_item	2327732	et	4	main
lennukis	doc_286998102757_item	2327734	et	3	main
oli	doc_286998102757_item	2327736	et	3	main
aru	doc_286998102757_item	2327748	et	4	main
tahab	doc_286998102757_item	2327755	et	3	main
seda	doc_286998102757_item	2327758	et	3	main
varsti	doc_286998102757_item	2327777	et	3	main
sest	doc_286998102757_item	2327784	et	4	main
ta	doc_286998102757_item	2327785	et	4	main
enne	doc_286998102757_item	2327790	et	4	main
küll	doc_286998102757_item	2327828	et	4	main
me	doc_286998102757_item	2327831	et	4	main
ei	doc_286998102757_item	2327832	et	4	main
saa	doc_286998102757_item	2327833	et	4	main
enda	doc_286998102757_item	2327835	et	4	main
peale	doc_286998102757_item	2327836	et	4	main
bin	doc_286998102757_item	2327845	et	4	main
naiseks	doc_286998102757_item	2327851	et	3	main
temasse	doc_286998102757_item	2327863	et	3	main
armunud	doc_286998102757_item	2327865	et	4	main
mees	doc_286998102757_item	2327869	et	4	main
igal	doc_286998102757_item	2327893	et	3	main
päeval	doc_286998102757_item	2327928	et	3	main
see	doc_286998102757_item	2327934	et	3	main
aga	doc_286998102757_item	2327936	et	3	main
nüüd	doc_286998102757_item	2327943	et	4	main
ta	doc_286998102757_item	2327944	et	4	main
nii	doc_286998102757_item	2327954	et	3	main
küll	doc_286998102757_item	2327958	et	4	main
arvab	doc_286998102757_item	2327962	et	3	main
aga	doc_286998102757_item	2327974	et	3	main
tunda	doc_286998102757_item	2327986	et	3	main
üks	doc_286998102757_item	2327773	et	3	main
mees	doc_286998102757_item	2327774	et	4	main
et	doc_286998102757_item	2327779	et	3	main
ei	doc_286998102757_item	2327786	et	4	main
see	doc_286998102757_item	2327792	et	3	main
nii	doc_286998102757_item	2327794	et	3	main
on	doc_286998102757_item	2327823	et	4	main
olukorrasid	doc_286998102757_item	2327825	et	4	main
kuna	doc_286998102757_item	2327826	et	3	main
on	doc_286998102757_item	2327827	et	4	main
aga	doc_286998102757_item	2327830	et	3	main
võtta	doc_286998102757_item	2327837	et	3	main
nii	doc_286998102757_item	2327864	et	3	main
uskus	doc_286998102757_item	2327867	et	3	main
parim	doc_286998102757_item	2327872	et	4	main
alguses	doc_286998102757_item	2327879	et	4	main
rohkem	doc_286998102757_item	2327897	et	4	main
naisi	doc_286998102757_item	2327898	et	3	main
läks	doc_286998102757_item	2327899	et	3	main
kodunt	doc_286998102757_item	2327900	et	3	main
ilma	doc_286998102757_item	2327901	et	4	main
rätikuta	doc_286998102757_item	2327902	et	3	main
ära	doc_286998102757_item	2327903	et	4	main
aga	doc_286998102757_item	2327904	et	3	main
iraanis	doc_286998102757_item	2327905	et	4	main
võeti	doc_286998102757_item	2327906	et	3	main
seadus	doc_286998102757_item	2327907	et	4	main
vastu	doc_286998102757_item	2327908	et	3	main
et	doc_286998102757_item	2327909	et	3	main
naise	doc_286998102757_item	2327910	et	3	main
kes	doc_286998102757_item	2327911	et	4	main
on	doc_286998102757_item	2327912	et	4	main
meikitud	doc_286998102757_item	2327913	et	4	main
saab	doc_286998102757_item	2327914	et	3	main
ta	doc_286998102757_item	2327915	et	4	main
näkku	doc_286998102757_item	2327916	et	3	main
hapet	doc_286998102757_item	2327917	et	3	main
viskama	doc_286998102757_item	2327918	et	3	main
saudi-araabiast	doc_286998102757_item	2327919	et	3	main
ni	doc_286998102757_item	2327920	et	4	main
mees	doc_286998102757_item	2327924	et	4	main
ka	doc_286998102757_item	2327925	et	3	main
jäi	doc_286998102757_item	2327926	et	3	main
igal	doc_286998102757_item	2327927	et	3	main
kurjaks	doc_286998102757_item	2327929	et	4	main
oli	doc_286998102757_item	2327935	et	3	main
väga	doc_286998102757_item	2327948	et	3	main
et	doc_286998102757_item	2327956	et	3	main
on	doc_286998102757_item	2327957	et	4	main
teistest	doc_286998102757_item	2327963	et	4	main
algusel	doc_286998102757_item	2327964	et	4	main
head	doc_286998102757_item	2327966	et	4	main
arvab	doc_286998102757_item	2327967	et	3	main
et	doc_286998102757_item	2327968	et	3	main
teised	doc_286998102757_item	2327969	et	4	main
on	doc_286998102757_item	2327970	et	4	main
ei	doc_286998102757_item	2327981	et	4	main
käituma	doc_286998102757_item	2327922	et	3	main
lõpuks	doc_286998102757_item	2327930	et	4	main
lahutada	doc_286998102757_item	2327933	et	3	main
raske	doc_286998102757_item	2327937	et	4	main
lõpuks	doc_286998102757_item	2327939	et	4	main
ometi	doc_286998102757_item	2327940	et	3	main
ta	doc_286998102757_item	2327941	et	4	main
võitis	doc_286998102757_item	2327942	et	3	main
teab	doc_286998102757_item	2327945	et	3	main
kommenteeriks	doc_286998102757_item	2327953	et	3	main
ni	doc_286998102757_item	2327959	et	4	main
heatahtlikud	doc_286998102757_item	2327973	et	3	main
saab	doc_286998102757_item	2327977	et	3	main
töö	doc_286998102757_item	2327938	et	4	main
et	doc_286998102757_item	2327946	et	3	main
ja	doc_286998102757_item	2327950	et	3	main
naine	doc_286998102757_item	2327952	et	3	main
et	doc_286998102757_item	2327960	et	3	main
midagi	doc_286998102757_item	2327965	et	4	main
nii	doc_286998102757_item	2327975	et	3	main
sageli	doc_286998102757_item	2327976	et	3	main
selguks	doc_286998102757_item	2327978	et	4	main
et	doc_286998102757_item	2327979	et	3	main
oska	doc_286998102757_item	2327982	et	4	main
hästi	doc_286998102757_item	2327983	et	3	main
teisi	doc_286998102757_item	2327984	et	4	main
õppimine	doc_292273046169_item	2329066	et	4	main
teema	doc_292273046169_item	2329072	et	4	main
sellepärast	doc_292273046169_item	2329073	et	3	main
et	doc_292273046169_item	2329074	et	3	main
mulle	doc_292273046169_item	2329077	et	4	main
ja	doc_292273046169_item	2329079	et	3	main
kooliõpetajaks	doc_292273046169_item	2329086	et	3	main
vaja	doc_292273046169_item	2329099	et	4	main
jaoks	doc_292273046169_item	2329105	et	4	main
mulle	doc_292273046169_item	2329119	et	4	main
väga	doc_292273046169_item	2329121	et	3	main
palju	doc_292273046169_item	2329126	et	4	main
sellest	doc_292273046169_item	2329128	et	4	main
millised	doc_292273046169_item	2329133	et	3	main
neid	doc_292273046169_item	2329140	et	4	main
on	doc_292273046169_item	2329149	et	4	main
õppimiseks	doc_292273046169_item	2329160	et	4	main
minu	doc_292273046169_item	2329161	et	3	main
tööeesmärgiks	doc_292273046169_item	2329162	et	3	main
ma	doc_292273046169_item	2329192	et	3	main
esile	doc_292273046169_item	2329194	et	3	main
riigiõppekava	doc_292273046169_item	2329195	et	4	main
selleks	doc_292273046169_item	2329196	et	4	main
et	doc_292273046169_item	2329197	et	3	main
mu	doc_292273046169_item	2329199	et	3	main
lütseumi	doc_292273046169_item	2329206	et	4	main
aga	doc_292273046169_item	2329210	et	3	main
ja	doc_292273046169_item	2329219	et	3	main
avaldan	doc_292273046169_item	2329220	et	3	main
paremaks	doc_292273046169_item	2329228	et	4	main
kvalitatiivsed	doc_292273046169_item	2329236	et	3	main
samas	doc_292273046169_item	2329238	et	4	main
peab	doc_292273046170_item	2329249	et	4	main
teadma	doc_292273046170_item	2329250	et	3	main
või	doc_292273046170_item	2329260	et	4	main
valitud	doc_292273046170_item	2329261	et	4	main
maa	doc_292273046170_item	2329263	et	4	main
seda	doc_292273046170_item	2329269	et	3	main
kultuuri	doc_292273046170_item	2329273	et	4	main
on	doc_292273046170_item	2329275	et	4	main
andnud	doc_292273046170_item	2329276	et	4	main
väga	doc_292273046170_item	2329277	et	3	main
olen	doc_292273046169_item	2329060	et	3	main
eesti	doc_292273046169_item	2329062	et	4	main
rahvuspärimuse	doc_292273046169_item	2329063	et	3	main
selle	doc_292273046169_item	2329071	et	4	main
huvi	doc_292273046169_item	2329078	et	4	main
õppekavas	doc_292273046169_item	2329090	et	3	main
kultuuriõpe	doc_292273046169_item	2329093	et	3	main
ja	doc_292273046169_item	2329095	et	3	main
on	doc_292273046169_item	2329098	et	4	main
väga	doc_292273046169_item	2329106	et	3	main
selles	doc_292273046169_item	2329115	et	4	main
integratsioonist	doc_292273046169_item	2329127	et	3	main
see	doc_292273046169_item	2329130	et	3	main
protsess	doc_292273046169_item	2329131	et	3	main
on	doc_292273046169_item	2329134	et	4	main
kuidas	doc_292273046169_item	2329143	et	3	main
probleemid	doc_292273046169_item	2329145	et	3	main
tööhüpoteesiks	doc_292273046169_item	2329148	et	4	main
näidata	doc_292273046169_item	2329150	et	4	main
see	doc_292273046169_item	2329151	et	3	main
et	doc_292273046169_item	2329152	et	3	main
riigiõppekavas	doc_292273046169_item	2329153	et	3	main
on	doc_292273046169_item	2329154	et	4	main
tähelepanu	doc_292273046169_item	2329157	et	4	main
välja	doc_292273046169_item	2329164	et	4	main
selgitada	doc_292273046169_item	2329165	et	3	main
mis	doc_292273046169_item	2329187	et	4	main
tõestada	doc_292273046169_item	2329198	et	3	main
kooliõppekava	doc_292273046169_item	2329209	et	4	main
ainult	doc_292273046169_item	2329211	et	4	main
mis	doc_292273046169_item	2329213	et	4	main
ja	doc_292273046169_item	2329224	et	3	main
nende	doc_292273046169_item	2329225	et	4	main
meetodid	doc_292273046169_item	2329226	et	3	main
arusaamiseks	doc_292273046169_item	2329231	et	4	main
uuringus	doc_292273046169_item	2329233	et	3	main
iga	doc_292273046170_item	2329246	et	4	main
enda	doc_292273046170_item	2329253	et	4	main
keele	doc_292273046170_item	2329259	et	4	main
praegune	doc_292273046170_item	2329265	et	3	main
õppekava	doc_292273046170_item	2329266	et	4	main
venekeelses	doc_292273046169_item	2329067	et	3	main
koolisma	doc_292273046169_item	2329068	et	4	main
olen	doc_292273046169_item	2329069	et	3	main
valinud	doc_292273046169_item	2329070	et	4	main
kavatsen	doc_292273046169_item	2329081	et	3	main
minu	doc_292273046169_item	2329089	et	3	main
on	doc_292273046169_item	2329091	et	4	main
koolis	doc_292273046169_item	2329100	et	4	main
kultuuri	doc_292273046169_item	2329101	et	4	main
õpetada	doc_292273046169_item	2329102	et	3	main
on	doc_292273046169_item	2329103	et	4	main
mu	doc_292273046169_item	2329104	et	3	main
teada	doc_292273046169_item	2329108	et	3	main
kultuuriõppimisega	doc_292273046169_item	2329111	et	3	main
olukord	doc_292273046169_item	2329114	et	3	main
valdkonnassee	doc_292273046169_item	2329116	et	4	main
teema	doc_292273046169_item	2329117	et	4	main
tundub	doc_292273046169_item	2329118	et	3	main
räägitakse	doc_292273046169_item	2329125	et	3	main
sellega	doc_292273046169_item	2329135	et	3	main
seonduvad	doc_292273046169_item	2329136	et	4	main
probleemid	doc_292273046169_item	2329137	et	3	main
ma	doc_292273046169_item	2329184	et	3	main
korraldan	doc_292273046169_item	2329185	et	3	main
teste	doc_292273046169_item	2329186	et	3	main
õppeedukust	doc_292273046169_item	2329190	et	4	main
keele	doc_292273046169_item	2329208	et	4	main
õpetajatega	doc_292273046169_item	2329218	et	4	main
seminaritöö	doc_292273046169_item	2329056	et	4	main
oma	doc_292273046169_item	2329057	et	4	main
ma	doc_292273046169_item	2329080	et	3	main
ülikooli	doc_292273046169_item	2329083	et	4	main
hakkama	doc_292273046169_item	2329085	et	3	main
kuna	doc_292273046169_item	2329088	et	3	main
ka	doc_292273046169_item	2329092	et	3	main
olnud	doc_292273046169_item	2329094	et	4	main
mis	doc_292273046169_item	2329109	et	4	main
on	doc_292273046169_item	2329113	et	4	main
seminaritööteemaks	doc_292273046169_item	2329058	et	4	main
ma	doc_292273046169_item	2329059	et	3	main
valinud	doc_292273046169_item	2329061	et	4	main
õpetamine	doc_292273046169_item	2329064	et	4	main
ja	doc_292273046169_item	2329065	et	3	main
ta	doc_292273046169_item	2329075	et	4	main
pakub	doc_292273046169_item	2329076	et	3	main
peale	doc_292273046169_item	2329082	et	4	main
lõpetamist	doc_292273046169_item	2329084	et	4	main
ning	doc_292273046169_item	2329087	et	3	main
samas	doc_292273046169_item	2329096	et	4	main
mul	doc_292273046169_item	2329097	et	3	main
oluline	doc_292273046169_item	2329107	et	4	main
toimub	doc_292273046169_item	2329110	et	3	main
milline	doc_292273046169_item	2329112	et	3	main
olevat	doc_292273046169_item	2329120	et	4	main
kuna	doc_292273046169_item	2329123	et	3	main
lahendada	doc_292273046169_item	2329141	et	3	main
minu	doc_292273046169_item	2329147	et	3	main
vähe	doc_292273046169_item	2329156	et	3	main
on	doc_292273046169_item	2329163	et	4	main
mida	doc_292273046169_item	2329166	et	4	main
lapsed	doc_292273046169_item	2329167	et	3	main
õpilaste	doc_292273046169_item	2329189	et	4	main
toon	doc_292273046169_item	2329193	et	4	main
tallinna	doc_292273046169_item	2329203	et	4	main
õismäe	doc_292273046169_item	2329204	et	3	main
vene	doc_292273046169_item	2329205	et	4	main
seda	doc_292273046169_item	2329212	et	3	main
puudutab	doc_292273046169_item	2329214	et	3	main
kultuuriloo	doc_292273046169_item	2329215	et	4	main
õpetamist	doc_292273046169_item	2329216	et	4	main
vestlen	doc_292273046169_item	2329217	et	3	main
arvamust	doc_292273046169_item	2329222	et	3	main
kultuuri	doc_292273046169_item	2329227	et	4	main
oma	doc_292273046169_item	2329232	et	4	main
ma	doc_292273046169_item	2329239	et	3	main
haritud	doc_292273046170_item	2329247	et	4	main
inimene	doc_292273046170_item	2329248	et	3	main
nii	doc_292273046170_item	2329252	et	3	main
rahvapärimust	doc_292273046170_item	2329255	et	4	main
oluliseks	doc_292273046170_item	2329270	et	4	main
ja	doc_292273046170_item	2329285	et	3	main
valdamine	doc_292273046170_item	2329286	et	4	main
kui	doc_292273046170_item	2329291	et	3	main
vabalt	doc_292273046170_item	2329293	et	4	main
inimene	doc_292273046170_item	2329295	et	3	main
ei	doc_292273046170_item	2329296	et	4	main
õppimiseks	doc_292273046170_item	2329309	et	4	main
aktuaalne	doc_292273046169_item	2329122	et	3	main
tänapäeval	doc_292273046169_item	2329124	et	3	main
kuidas	doc_292273046169_item	2329129	et	3	main
toimub	doc_292273046169_item	2329132	et	3	main
kuidas	doc_292273046169_item	2329138	et	3	main
saaks	doc_292273046169_item	2329139	et	3	main
ja	doc_292273046169_item	2329142	et	3	main
need	doc_292273046169_item	2329144	et	3	main
tekivad	doc_292273046169_item	2329146	et	3	main
väga	doc_292273046169_item	2329155	et	3	main
pööratud	doc_292273046169_item	2329158	et	4	main
kultuuri	doc_292273046169_item	2329159	et	4	main
teavad	doc_292273046169_item	2329168	et	3	main
eesti	doc_292273046169_item	2329169	et	4	main
kultuurist	doc_292273046169_item	2329170	et	3	main
mida	doc_292273046169_item	2329171	et	4	main
lapsed	doc_292273046169_item	2329172	et	3	main
õppida	doc_292273046169_item	2329174	et	3	main
sooviksid	doc_292273046169_item	2329173	et	4	main
millega	doc_292273046169_item	2329175	et	3	main
on	doc_292273046169_item	2329176	et	4	main
neil	doc_292273046169_item	2329177	et	4	main
raskusi	doc_292273046169_item	2329178	et	4	main
selleks	doc_292273046169_item	2329179	et	4	main
et	doc_292273046169_item	2329180	et	3	main
oma	doc_292273046169_item	2329181	et	4	main
tööhüpoteesi	doc_292273046169_item	2329182	et	4	main
kaitsta	doc_292273046169_item	2329183	et	4	main
näitavad	doc_292273046169_item	2329188	et	4	main
samas	doc_292273046169_item	2329191	et	4	main
hüpoteesi	doc_292273046169_item	2329200	et	4	main
toon	doc_292273046169_item	2329201	et	4	main
esile	doc_292273046169_item	2329202	et	3	main
eesti	doc_292273046169_item	2329207	et	4	main
nende	doc_292273046169_item	2329221	et	4	main
õppekavast	doc_292273046169_item	2329223	et	4	main
õppimiseks	doc_292273046169_item	2329229	et	4	main
ja	doc_292273046169_item	2329230	et	3	main
kasutan	doc_292273046169_item	2329235	et	3	main
kasutan	doc_292273046169_item	2329240	et	3	main
mõnda	doc_292273046169_item	2329241	et	4	main
interneti-	doc_292273046169_item	2329242	et	4	main
ja	doc_292273046169_item	2329243	et	3	main
maa	doc_292273046170_item	2329254	et	4	main
rahvapärimust	doc_292273046170_item	2329264	et	4	main
ja	doc_292273046170_item	2329272	et	3	main
õppimiseks	doc_292273046170_item	2329274	et	4	main
eesti	doc_292273046170_item	2329282	et	4	main
keele	doc_292273046170_item	2329283	et	4	main
kuidagi	doc_292273046170_item	2329289	et	3	main
selliste	doc_292273046170_item	2329302	et	4	main
tundide	doc_292273046170_item	2329303	et	3	main
rahvapärimuse	doc_292273046170_item	2329308	et	3	main
lühiülevaade	doc_292273046170_item	2329313	et	3	main
saa	doc_292273046170_item	2329323	et	4	main
peab	doc_292273046170_item	2329329	et	4	main
sisu	doc_292273046170_item	2329337	et	4	main
aga	doc_292273046170_item	2329338	et	3	main
et	doc_292273046170_item	2329341	et	3	main
mitte	doc_292273046170_item	2329355	et	3	main
õpetatava	doc_292273046170_item	2329356	et	4	main
tutvustamine	doc_292273046170_item	2329360	et	4	main
on	doc_292273046170_item	2329369	et	4	main
sellest	doc_292273046170_item	2329374	et	4	main
ainult	doc_292273046170_item	2329378	et	4	main
need	doc_292273046170_item	2329379	et	3	main
osad	doc_292273046170_item	2329380	et	3	main
puudutavad	doc_292273046170_item	2329382	et	4	main
kultuuriloo	doc_292273046170_item	2329383	et	4	main
edaspidi	doc_292273046170_item	2329390	et	3	main
riiklik	doc_292273046170_item	2329391	et	3	main
määrab	doc_292273046170_item	2329393	et	3	main
edaspidi	doc_292273046170_item	2329398	et	3	main
alused	doc_292273046170_item	2329410	et	4	main
koostamise	doc_292273046170_item	2329424	et	4	main
tööhüpoteesi	doc_292273046171_item	2329432	et	4	main
tõestamiseks	doc_292273046171_item	2329433	et	4	main
ma	doc_292273046171_item	2329434	et	3	main
korraldasin	doc_292273046171_item	2329435	et	3	main
seega	doc_292273046171_item	2329439	et	4	main
said	doc_292273046171_item	2329441	et	4	main
kirjutada	doc_292273046171_item	2329443	et	3	main
nad	doc_292273046171_item	2329445	et	3	main
vabalt	doc_292273046171_item	2329454	et	4	main
ole	doc_292273046171_item	2329462	et	4	main
vaja	doc_292273046171_item	2329468	et	4	main
ja	doc_292273046171_item	2329492	et	3	main
oli	doc_292273046171_item	2329494	et	3	main
32	doc_292273046171_item	2329506	et	2	main
küsimiseks	doc_292273046171_item	2329509	et	4	main
eesti	doc_292273046171_item	2329519	et	4	main
lippuhümni	doc_292273046171_item	2329520	et	4	main
ma	doc_292273046169_item	2329234	et	3	main
meetodid	doc_292273046169_item	2329237	et	3	main
kirjanduseallikad	doc_292273046169_item	2329244	et	3	main
seminaritöö	doc_292273046170_item	2329245	et	4	main
rahvapärimust	doc_292273046170_item	2329251	et	4	main
kuid	doc_292273046170_item	2329256	et	4	main
ka	doc_292273046170_item	2329257	et	3	main
õpetatava	doc_292273046170_item	2329258	et	4	main
elamiseks	doc_292273046170_item	2329262	et	4	main
pea	doc_292273046170_item	2329268	et	4	main
aega	doc_292273046170_item	2329279	et	4	main
peetakse	doc_292273046170_item	2329281	et	3	main
on	doc_292273046170_item	2329288	et	4	main
oska	doc_292273046170_item	2329297	et	4	main
anda	doc_292273046170_item	2329311	et	3	main
vaid	doc_292273046170_item	2329312	et	3	main
loomulikult	doc_292273046170_item	2329315	et	4	main
pole	doc_292273046170_item	2329317	et	3	main
samas	doc_292273046170_item	2329319	et	4	main
vene	doc_292273046170_item	2329320	et	4	main
ei	doc_292273046170_item	2329322	et	4	main
ise	doc_292273046170_item	2329334	et	4	main
muutma	doc_292273046170_item	2329335	et	3	main
õppekava	doc_292273046170_item	2329336	et	4	main
praegu	doc_292273046170_item	2329342	et	3	main
ei	doc_292273046170_item	2329344	et	4	main
lootagi	doc_292273046170_item	2329346	et	4	main
sest	doc_292273046170_item	2329347	et	4	main
kultuuriga	doc_292273046170_item	2329359	et	4	main
ei	doc_292273046170_item	2329363	et	4	main
see	doc_292273046170_item	2329368	et	3	main
õppekavast	doc_292273046170_item	2329375	et	4	main
õppimist	doc_292273046170_item	2329384	et	4	main
riiklik	doc_292273046170_item	2329388	et	3	main
õppekava	doc_292273046170_item	2329392	et	4	main
põhikooli	doc_292273046170_item	2329395	et	4	main
omandatavad	doc_292273046170_item	2329407	et	4	main
õppeained	doc_292273046170_item	2329412	et	3	main
põhimõtted	doc_292273046170_item	2329425	et	3	main
kooli	doc_292273046170_item	2329427	et	4	main
seisundist	doc_292273046170_item	2329429	et	3	main
seminaritöö	doc_292273046171_item	2329430	et	4	main
anonüümne	doc_292273046171_item	2329438	et	3	main
mida	doc_292273046171_item	2329444	et	4	main
see	doc_292273046171_item	2329459	et	3	main
hindeline	doc_292273046171_item	2329463	et	4	main
ole	doc_292273046171_item	2329467	et	4	main
kokku	doc_292273046171_item	2329502	et	3	main
esimeseks	doc_292273046171_item	2329508	et	3	main
oli	doc_292273046171_item	2329510	et	3	main
on	doc_292273046171_item	2329512	et	4	main
vastusteks	doc_292273046171_item	2329516	et	4	main
ja	doc_292273046171_item	2329521	et	3	main
mul	doc_292273046171_item	2329546	et	3	main
eraldi	doc_292273046171_item	2329547	et	4	main
eesti	doc_292273046171_item	2329553	et	4	main
johan	doc_292273046171_item	2329563	et	4	main
8	doc_292273046171_item	2329574	et	2	main
9	doc_292273046171_item	2329589	et	2	main
õpilast	doc_292273046171_item	2329590	et	4	main
koidula	doc_292273046171_item	2329601	et	4	main
ainult	doc_292273046171_item	2329603	et	4	main
üks	doc_292273046171_item	2329604	et	3	main
õpilaneselline	doc_292273046171_item	2329605	et	4	main
tulemus	doc_292273046171_item	2329606	et	3	main
põhjustatud	doc_292273046171_item	2329609	et	4	main
on	doc_292273046171_item	2329613	et	4	main
koidulat	doc_292273046171_item	2329616	et	4	main
ei	doc_292273046171_item	2329617	et	4	main
küsimused	doc_292273046171_item	2329628	et	4	main
puudutasid	doc_292273046171_item	2329630	et	4	main
rahvuslidu	doc_292273046171_item	2329632	et	4	main
õiged	doc_292273046171_item	2329637	et	3	main
õpilast	doc_292273046171_item	2329641	et	4	main
suutnud	doc_292273046171_item	2329643	et	4	main
mis	doc_292273046171_item	2329645	et	4	main
arv	doc_292273046171_item	2329650	et	3	main
õigeid	doc_292273046171_item	2329651	et	3	main
rahvussümbolid	doc_292273046171_item	2329658	et	3	main
hakatakse	doc_292273046171_item	2329659	et	3	main
ei	doc_292273046171_item	2329689	et	4	main
ole	doc_292273046171_item	2329690	et	4	main
muudküsimus	doc_292273046171_item	2329694	et	3	main
ole	doc_292273046171_item	2329701	et	4	main
selge	doc_292273046171_item	2329702	et	4	main
ei	doc_292273046170_item	2329267	et	4	main
rahvapärimuse	doc_292273046170_item	2329271	et	3	main
oluliseks	doc_292273046170_item	2329280	et	4	main
aga	doc_292273046170_item	2329287	et	3	main
keelt	doc_292273046170_item	2329292	et	4	main
valdav	doc_292273046170_item	2329294	et	4	main
selle	doc_292273046170_item	2329300	et	4	main
rahvapärimusest	doc_292273046170_item	2329301	et	4	main
saab	doc_292273046170_item	2329310	et	3	main
see	doc_292273046170_item	2329316	et	3	main
piisav	doc_292273046170_item	2329318	et	4	main
õppekavas	doc_292273046170_item	2329325	et	3	main
see	doc_292273046170_item	2329327	et	3	main
tulema	doc_292273046170_item	2329330	et	4	main
haridusministeeriumilt	doc_292273046170_item	2329331	et	3	main
kes	doc_292273046170_item	2329332	et	4	main
ma	doc_292273046170_item	2329339	et	3	main
oluliseks	doc_292273046170_item	2329348	et	4	main
valdamine	doc_292273046170_item	2329354	et	4	main
kultuuriloo	doc_292273046170_item	2329361	et	4	main
õppekava	doc_292273046170_item	2329367	et	4	main
ja	doc_292273046170_item	2329373	et	3	main
ma	doc_292273046170_item	2329376	et	3	main
valisin	doc_292273046170_item	2329377	et	3	main
põhikooli	doc_292273046170_item	2329385	et	4	main
ja	doc_292273046170_item	2329386	et	3	main
kool	doc_292273046170_item	2329399	et	4	main
ja	doc_292273046170_item	2329401	et	3	main
pädevused	doc_292273046170_item	2329408	et	4	main
kohustuslikud	doc_292273046170_item	2329411	et	3	main
tunnijaotusplaani	doc_292273046170_item	2329414	et	4	main
kooliastmete	doc_292273046170_item	2329416	et	3	main
kooli	doc_292273046170_item	2329418	et	4	main
vähe	doc_292273046170_item	2329278	et	3	main
õppimine	doc_292273046170_item	2329284	et	4	main
kummaline	doc_292273046170_item	2329290	et	3	main
midagi	doc_292273046170_item	2329298	et	4	main
öelda	doc_292273046170_item	2329299	et	4	main
jooksul	doc_292273046170_item	2329304	et	4	main
mis	doc_292273046170_item	2329305	et	4	main
on	doc_292273046170_item	2329306	et	4	main
määratletud	doc_292273046170_item	2329307	et	4	main
kuigi	doc_292273046170_item	2329314	et	3	main
koolid	doc_292273046170_item	2329321	et	3	main
peaks	doc_292273046170_item	2329333	et	4	main
arvan	doc_292273046170_item	2329340	et	3	main
maksa	doc_292273046170_item	2329345	et	4	main
rahva	doc_292273046170_item	2329358	et	3	main
jaoks	doc_292273046170_item	2329362	et	4	main
ole	doc_292273046170_item	2329364	et	4	main
eraldi	doc_292273046170_item	2329365	et	4	main
koostatud	doc_292273046170_item	2329366	et	4	main
keele	doc_292273046170_item	2329371	et	4	main
gümnaasiumi	doc_292273046170_item	2329387	et	4	main
kindlaks	doc_292273046170_item	2329394	et	3	main
ja	doc_292273046170_item	2329396	et	3	main
riikliku	doc_292273046170_item	2329404	et	3	main
õppekorralduse	doc_292273046170_item	2329409	et	3	main
ja	doc_292273046170_item	2329423	et	3	main
olenemata	doc_292273046170_item	2329426	et	4	main
õiguslikust	doc_292273046170_item	2329428	et	4	main
oli	doc_292273046171_item	2329437	et	3	main
ausalt	doc_292273046171_item	2329442	et	4	main
mida	doc_292273046171_item	2329448	et	4	main
ei	doc_292273046171_item	2329449	et	4	main
tühja	doc_292273046171_item	2329455	et	4	main
kohta	doc_292273046171_item	2329456	et	4	main
jätta	doc_292273046171_item	2329457	et	3	main
kuna	doc_292273046171_item	2329458	et	3	main
küsimustest	doc_292273046171_item	2329491	et	4	main
teine	doc_292273046171_item	2329493	et	3	main
küsitud	doc_292273046171_item	2329505	et	4	main
selliseid	doc_292273046171_item	2329524	et	4	main
kirjutasid	doc_292273046171_item	2329526	et	4	main
5	doc_292273046171_item	2329528	et	2	main
inimest	doc_292273046171_item	2329529	et	3	main
6	doc_292273046171_item	2329531	et	2	main
ei	doc_292273046171_item	2329532	et	4	main
teadnud	doc_292273046171_item	2329533	et	4	main
üldse	doc_292273046171_item	2329534	et	3	main
küsimusedteiseks	doc_292273046171_item	2329548	et	4	main
küsimuseks	doc_292273046171_item	2329549	et	4	main
hümni	doc_292273046171_item	2329554	et	4	main
olid	doc_292273046171_item	2329558	et	4	main
jakob	doc_292273046171_item	2329560	et	4	main
hurt	doc_292273046171_item	2329561	et	3	main
jakobson	doc_292273046171_item	2329562	et	4	main
puudu	doc_292273046171_item	2329569	et	4	main
oli	doc_292273046171_item	2329570	et	3	main
ka	doc_292273046171_item	2329571	et	3	main
kirjutanud	doc_292273046171_item	2329578	et	4	main
kirjutasid	doc_292273046171_item	2329585	et	4	main
johan	doc_292273046171_item	2329586	et	4	main
voldemar	doc_292273046171_item	2329587	et	4	main
jansen	doc_292273046171_item	2329588	et	4	main
hümni	doc_292273046171_item	2329592	et	4	main
frederik	doc_292273046171_item	2329596	et	4	main
võib	doc_292273046171_item	2329607	et	3	main
pacius	doc_292273046171_item	2329612	et	4	main
helilooja	doc_292273046171_item	2329614	et	4	main
mainitud	doc_292273046171_item	2329618	et	4	main
ta	doc_292273046171_item	2329623	et	4	main
jannseni	doc_292273046171_item	2329625	et	4	main
puu	doc_292273046171_item	2329634	et	4	main
ainult	doc_292273046171_item	2329639	et	4	main
rahvuspuu	doc_292273046171_item	2329647	et	4	main
põhjustatud	doc_292273046171_item	2329654	et	4	main
1klassist	doc_292273046171_item	2329662	et	3	main
mitte	doc_292273046171_item	2329692	et	3	main
päris	doc_292273046171_item	2329697	et	4	main
probleemeõpilastel	doc_292273046171_item	2329699	et	4	main
ei	doc_292273046171_item	2329700	et	4	main
peetakse	doc_292273046171_item	2329712	et	3	main
osanud	doc_292273046171_item	2329716	et	4	main
midagi	doc_292273046170_item	2329324	et	4	main
muuta	doc_292273046170_item	2329326	et	4	main
initsiatiiv	doc_292273046170_item	2329328	et	3	main
seda	doc_292273046170_item	2329343	et	3	main
punktiks	doc_292273046170_item	2329349	et	4	main
peetakse	doc_292273046170_item	2329350	et	3	main
keele	doc_292273046170_item	2329351	et	4	main
õppimine	doc_292273046170_item	2329352	et	4	main
ja	doc_292273046170_item	2329353	et	3	main
keele	doc_292273046170_item	2329357	et	4	main
eesti	doc_292273046170_item	2329370	et	4	main
õppekavas	doc_292273046170_item	2329372	et	3	main
mis	doc_292273046170_item	2329381	et	4	main
õppekava	doc_292273046170_item	2329389	et	4	main
gümnaasiumi	doc_292273046170_item	2329397	et	4	main
õppe-	doc_292273046170_item	2329400	et	4	main
kasvatustegevuse	doc_292273046170_item	2329402	et	4	main
eesmärgid	doc_292273046170_item	2329403	et	3	main
õppekava	doc_292273046170_item	2329405	et	4	main
põhimõtted	doc_292273046170_item	2329406	et	3	main
ja	doc_292273046170_item	2329413	et	3	main
nõuded	doc_292273046170_item	2329415	et	3	main
ja	doc_292273046170_item	2329417	et	3	main
lõpetamiseks	doc_292273046170_item	2329419	et	4	main
ning	doc_292273046170_item	2329420	et	3	main
kooliõppekava	doc_292273046170_item	2329421	et	4	main
testidtest	doc_292273046171_item	2329436	et	4	main
ning	doc_292273046171_item	2329447	et	3	main
siis	doc_292273046171_item	2329452	et	3	main
võiksid	doc_292273046171_item	2329453	et	4	main
töö	doc_292273046171_item	2329460	et	4	main
siis	doc_292273046171_item	2329465	et	3	main
ei	doc_292273046171_item	2329466	et	4	main
11	doc_292273046171_item	2329495	et	2	main
jaoks	doc_292273046171_item	2329497	et	4	main
küsimutest	doc_292273046171_item	2329501	et	3	main
läbi	doc_292273046171_item	2329504	et	4	main
ma	doc_292273046171_item	2329517	et	3	main
ootasin	doc_292273046171_item	2329518	et	3	main
vastuseid	doc_292273046171_item	2329525	et	3	main
kirjutaja	doc_292273046171_item	2329556	et	4	main
mainitud	doc_292273046171_item	2329559	et	4	main
paljudel	doc_292273046171_item	2329566	et	3	main
ning	doc_292273046171_item	2329573	et	3	main
32st	doc_292273046171_item	2329576	et	3	main
sõnade	doc_292273046171_item	2329593	et	3	main
oli	doc_292273046171_item	2329595	et	3	main
pacius	doc_292273046171_item	2329597	et	4	main
ja	doc_292273046171_item	2329598	et	3	main
õiget	doc_292273046171_item	2329599	et	3	main
vastust-lydia	doc_292273046171_item	2329600	et	4	main
olla	doc_292273046171_item	2329608	et	3	main
arvati	doc_292273046171_item	2329621	et	4	main
juhendamise	doc_292273046171_item	2329626	et	4	main
mis	doc_292273046171_item	2329629	et	4	main
eesti	doc_292273046171_item	2329631	et	4	main
olid	doc_292273046171_item	2329635	et	4	main
kõikidel	doc_292273046171_item	2329636	et	4	main
on	doc_292273046171_item	2329646	et	4	main
suur	doc_292273046171_item	2329649	et	3	main
vastuseid	doc_292273046171_item	2329652	et	3	main
sellega	doc_292273046171_item	2329655	et	3	main
õppima	doc_292273046171_item	2329660	et	3	main
aasta	doc_292273046171_item	2329665	et	4	main
korratakse	doc_292273046171_item	2329666	et	4	main
oodanud	doc_292273046171_item	2329691	et	4	main
kus	doc_292273046171_item	2329705	et	3	main
esimene	doc_292273046171_item	2329707	et	3	main
seda	doc_292273046171_item	2329711	et	3	main
ei	doc_292273046171_item	2329715	et	4	main
vastust	doc_292273046171_item	2329719	et	4	main
oli	doc_292273046171_item	2329720	et	3	main
peal	doc_292273046171_item	2329728	et	4	main
esimeneoli	doc_292273046171_item	2329730	et	4	main
jannsenpaljud	doc_292273046171_item	2329732	et	4	main
põhjuseks	doc_292273046171_item	2329753	et	3	main
laulupidu	doc_292273046171_item	2329758	et	4	main
ja	doc_292273046171_item	2329765	et	3	main
24	doc_292273046171_item	2329800	et	2	main
väga	doc_292273046171_item	2329806	et	3	main
rahvuseepose	doc_292273046171_item	2329813	et	3	main
väga	doc_292273046171_item	2329815	et	3	main
teadsid	doc_292273046171_item	2329817	et	4	main
õiget	doc_292273046171_item	2329818	et	3	main
vastustoli	doc_292273046171_item	2329819	et	4	main
ka	doc_292273046171_item	2329820	et	3	main
ei	doc_292273046171_item	2329827	et	4	main
räägitakse	doc_292273046171_item	2329834	et	3	main
elus	doc_292273046171_item	2329839	et	4	main
põhjustas	doc_292273046171_item	2329842	et	3	main
ülesehituse	doc_292273046170_item	2329422	et	3	main
oma	doc_292273046171_item	2329431	et	4	main
õpilased	doc_292273046171_item	2329440	et	3	main
teavad	doc_292273046171_item	2329446	et	3	main
olnud	doc_292273046171_item	2329450	et	4	main
teadnud	doc_292273046171_item	2329451	et	4	main
ei	doc_292273046171_item	2329461	et	4	main
harjutus	doc_292273046171_item	2329464	et	4	main
pingutada	doc_292273046171_item	2329469	et	3	main
ning	doc_292273046171_item	2329470	et	3	main
maha	doc_292273046171_item	2329471	et	4	main
kirjutada	doc_292273046171_item	2329472	et	3	main
selleks	doc_292273046171_item	2329473	et	4	main
et	doc_292273046171_item	2329474	et	3	main
saavutada	doc_292273046171_item	2329475	et	3	main
häid	doc_292273046171_item	2329476	et	3	main
tulemusi	doc_292273046171_item	2329477	et	4	main
mul	doc_292273046171_item	2329478	et	3	main
oli	doc_292273046171_item	2329479	et	3	main
2	doc_292273046171_item	2329481	et	2	main
tehtud	doc_292273046171_item	2329480	et	4	main
testivarianti	doc_292273046171_item	2329482	et	4	main
esimene	doc_292273046171_item	2329483	et	3	main
oli	doc_292273046171_item	2329484	et	3	main
7	doc_292273046171_item	2329485	et	2	main
klassi	doc_292273046171_item	2329486	et	4	main
jaoks	doc_292273046171_item	2329487	et	4	main
ja	doc_292273046171_item	2329488	et	3	main
koosnes	doc_292273046171_item	2329489	et	3	main
18	doc_292273046171_item	2329490	et	2	main
klassi	doc_292273046171_item	2329496	et	4	main
ja	doc_292273046171_item	2329498	et	3	main
koosnes	doc_292273046171_item	2329499	et	3	main
28	doc_292273046171_item	2329500	et	2	main
oli	doc_292273046171_item	2329503	et	3	main
õpilast	doc_292273046171_item	2329507	et	4	main
millised	doc_292273046171_item	2329511	et	3	main
eesti	doc_292273046171_item	2329513	et	4	main
riigisümbolid	doc_292273046171_item	2329514	et	3	main
ning	doc_292273046171_item	2329515	et	3	main
ja	doc_292273046171_item	2329523	et	3	main
vastust	doc_292273046171_item	2329535	et	4	main
ja	doc_292273046171_item	2329536	et	3	main
aga	doc_292273046171_item	2329543	et	3	main
selleks	doc_292273046171_item	2329544	et	4	main
oli	doc_292273046171_item	2329545	et	3	main
on	doc_292273046171_item	2329552	et	4	main
vastusteks	doc_292273046171_item	2329557	et	4	main
voldemarperekonnanimi	doc_292273046171_item	2329564	et	4	main
oli	doc_292273046171_item	2329565	et	3	main
inimestel	doc_292273046171_item	2329567	et	3	main
lihtsalt	doc_292273046171_item	2329568	et	4	main
inimest	doc_292273046171_item	2329575	et	3	main
ei	doc_292273046171_item	2329577	et	4	main
mitte	doc_292273046171_item	2329579	et	3	main
midagi	doc_292273046171_item	2329580	et	4	main
vastuseks	doc_292273046171_item	2329581	et	4	main
ning	doc_292273046171_item	2329582	et	3	main
11	doc_292273046171_item	2329583	et	2	main
inimest	doc_292273046171_item	2329584	et	3	main
autor	doc_292273046171_item	2329594	et	3	main
kirjutas	doc_292273046171_item	2329602	et	3	main
et	doc_292273046171_item	2329611	et	3	main
ja	doc_292273046171_item	2329615	et	3	main
sellepärast	doc_292273046171_item	2329619	et	3	main
vapi	doc_292273046171_item	2329522	et	3	main
ainult	doc_292273046171_item	2329527	et	4	main
32st	doc_292273046171_item	2329530	et	3	main
ülejäänud	doc_292273046171_item	2329537	et	4	main
hakkkasid	doc_292273046171_item	2329538	et	4	main
kirjutama	doc_292273046171_item	2329539	et	3	main
kes	doc_292273046171_item	2329540	et	4	main
on	doc_292273046171_item	2329541	et	4	main
rahvuslindlillkivi	doc_292273046171_item	2329542	et	4	main
oli	doc_292273046171_item	2329550	et	3	main
kes	doc_292273046171_item	2329551	et	4	main
sõnade	doc_292273046171_item	2329555	et	3	main
frederik	doc_292273046171_item	2329572	et	4	main
arvasidet	doc_292273046171_item	2329591	et	4	main
sellega	doc_292273046171_item	2329610	et	3	main
et	doc_292273046171_item	2329620	et	3	main
et	doc_292273046171_item	2329622	et	3	main
töötas	doc_292273046171_item	2329624	et	3	main
lilli	doc_292273046171_item	2329633	et	4	main
vastused	doc_292273046171_item	2329638	et	3	main
et	doc_292273046171_item	2329657	et	3	main
alates	doc_292273046171_item	2329661	et	3	main
ja	doc_292273046171_item	2329663	et	3	main
õiged	doc_292273046171_item	2329684	et	3	main
midagi	doc_292273046171_item	2329693	et	4	main
mitte	doc_292273046171_item	2329713	et	3	main
anda	doc_292273046171_item	2329717	et	3	main
täpset	doc_292273046171_item	2329718	et	3	main
all	doc_292273046171_item	2329627	et	3	main
2	doc_292273046171_item	2329640	et	2	main
ei	doc_292273046171_item	2329642	et	4	main
kirjutada	doc_292273046171_item	2329644	et	3	main
selline	doc_292273046171_item	2329648	et	4	main
oli	doc_292273046171_item	2329653	et	3	main
et	doc_292273046171_item	2329656	et	3	main
iga	doc_292273046171_item	2329664	et	4	main
samas	doc_292273046171_item	2329667	et	4	main
need	doc_292273046171_item	2329668	et	3	main
sümbolid	doc_292273046171_item	2329669	et	3	main
on	doc_292273046171_item	2329670	et	4	main
kirjas	doc_292273046171_item	2329671	et	4	main
paljude	doc_292273046171_item	2329672	et	3	main
eesti	doc_292273046171_item	2329673	et	4	main
keele	doc_292273046171_item	2329674	et	4	main
õpikute	doc_292273046171_item	2329675	et	3	main
esikaaneteloli	doc_292273046171_item	2329676	et	4	main
ka	doc_292273046171_item	2329677	et	3	main
küsimus	doc_292273046171_item	2329678	et	4	main
presidendist	doc_292273046171_item	2329680	et	4	main
ning	doc_292273046171_item	2329681	et	3	main
eesti	doc_292273046171_item	2329679	et	4	main
kõik	doc_292273046171_item	2329682	et	4	main
andsid	doc_292273046171_item	2329683	et	4	main
vastused	doc_292273046171_item	2329685	et	3	main
ausalt	doc_292273046171_item	2329686	et	4	main
öeldes	doc_292273046171_item	2329687	et	3	main
ma	doc_292273046171_item	2329688	et	3	main
laulupeost	doc_292273046171_item	2329695	et	4	main
tekitas	doc_292273046171_item	2329696	et	3	main
palju	doc_292273046171_item	2329698	et	4	main
millal	doc_292273046171_item	2329703	et	3	main
oli	doc_292273046171_item	2329706	et	3	main
keegi	doc_292273046171_item	2329714	et	4	main
laulavad	doc_292273046171_item	2329726	et	4	main
oli	doc_292273046171_item	2329735	et	3	main
laulupidu10	doc_292273046171_item	2329737	et	4	main
esimene	doc_292273046171_item	2329751	et	3	main
et	doc_292273046171_item	2329757	et	3	main
see	doc_292273046171_item	2329762	et	3	main
toimub	doc_292273046171_item	2329763	et	3	main
olid	doc_292273046171_item	2329803	et	4	main
raske	doc_292273046171_item	2329807	et	4	main
paljud	doc_292273046171_item	2329816	et	3	main
ja	doc_292273046171_item	2329704	et	3	main
laulupidu	doc_292273046171_item	2329708	et	4	main
kui	doc_292273046171_item	2329709	et	3	main
tihti	doc_292273046171_item	2329710	et	3	main
palju	doc_292273046171_item	2329722	et	4	main
rahvuslaulelaua	doc_292273046171_item	2329727	et	4	main
esimene	doc_292273046171_item	2329736	et	3	main
2	doc_292273046171_item	2329745	et	2	main
inimest	doc_292273046171_item	2329746	et	3	main
maininud	doc_292273046171_item	2329748	et	4	main
millal	doc_292273046171_item	2329749	et	3	main
see	doc_292273046171_item	2329756	et	3	main
korraldatakse	doc_292273046171_item	2329759	et	3	main
midagi	doc_292273046171_item	2329770	et	4	main
korraldada	doc_292273046171_item	2329771	et	3	main
et	doc_292273046171_item	2329772	et	3	main
õpilastele	doc_292273046171_item	2329773	et	4	main
ja	doc_292273046171_item	2329799	et	3	main
vastused	doc_292273046171_item	2329802	et	3	main
sellisedseda	doc_292273046171_item	2329804	et	4	main
on	doc_292273046171_item	2329805	et	4	main
küsimus	doc_292273046171_item	2329810	et	4	main
eesti	doc_292273046171_item	2329812	et	4	main
nimet	doc_292273046171_item	2329814	et	4	main
õpilast	doc_292273046171_item	2329826	et	4	main
palju	doc_292273046171_item	2329835	et	4	main
ning	doc_292273046171_item	2329840	et	3	main
vastuse	doc_292273046171_item	2329843	et	3	main
on	doc_292273046171_item	2329845	et	4	main
raske	doc_292273046171_item	2329846	et	4	main
rahvuslaule	doc_292273046171_item	2329855	et	4	main
küsitlenust	doc_292273046171_item	2329857	et	4	main
kirjutasid	doc_292273046171_item	2329869	et	4	main
ülejäänud	doc_292273046171_item	2329870	et	4	main
tuleb	doc_292273046171_item	2329877	et	3	main
rahvamõistatusi	doc_292273046171_item	2329920	et	3	main
vanasõnu	doc_292273046171_item	2329922	et	3	main
tulemus	doc_292273046171_item	2329924	et	3	main
küsimusele	doc_292273046171_item	2329934	et	4	main
aga	doc_292273046171_item	2329935	et	3	main
vanasõnu	doc_292273046171_item	2329936	et	3	main
tihti	doc_292273046171_item	2329937	et	3	main
läheb	doc_292273046171_item	2329938	et	3	main
vaja	doc_292273046171_item	2329939	et	4	main
vaja	doc_292273046171_item	2329944	et	4	main
õpetada	doc_292273046171_item	2329948	et	3	main
kasutamise	doc_292273046171_item	2329950	et	4	main
abil	doc_292273046171_item	2329951	et	4	main
tund	doc_292273046171_item	2329965	et	3	main
parandada	doc_292273046171_item	2329971	et	3	main
osanud	doc_292273046171_item	2330002	et	4	main
muisete	doc_292273046171_item	2330013	et	4	main
vastuseid	doc_292273046171_item	2330017	et	3	main
väga	doc_292273046171_item	2330023	et	3	main
rahvakalendristnimelt	doc_292273046171_item	2330029	et	4	main
vastlapäevajärgnev	doc_292273046171_item	2330042	et	3	main
vastlad	doc_292273046171_item	2330053	et	3	main
palju	doc_292273046171_item	2330059	et	4	main
järgmises	doc_292273046171_item	2330079	et	3	main
niit	doc_292273046171_item	2330108	et	4	main
koidulat	doc_292273046171_item	2330113	et	4	main
smuul	doc_292273046171_item	2330115	et	4	main
astrid	doc_292273046171_item	2330125	et	3	main
tobiasoli	doc_292273046171_item	2330129	et	4	main
see	doc_292273046171_item	2330132	et	3	main
üks	doc_292273046171_item	2330135	et	3	main
kirjutatakse	doc_292273046171_item	2330144	et	3	main
kes	doc_292273046171_item	2330160	et	4	main
midagieelviimaseks	doc_292273046171_item	2330164	et	3	main
oli	doc_292273046171_item	2330166	et	3	main
nimetasid	doc_292273046171_item	2330174	et	4	main
ainult	doc_292273046171_item	2330175	et	4	main
ja	doc_292273046171_item	2330179	et	3	main
näiteks	doc_292273046171_item	2330186	et	4	main
ei	doc_292273046171_item	2330188	et	4	main
ole	doc_292273046171_item	2330189	et	4	main
juttugi	doc_292273046171_item	2330190	et	4	main
ainult	doc_292273046171_item	2330191	et	4	main
õpilane	doc_292273046171_item	2330193	et	3	main
kuna	doc_292273046171_item	2330230	et	3	main
on	doc_292273046171_item	2330232	et	4	main
pakutud	doc_292273046171_item	2329721	et	4	main
vastuseidseal	doc_292273046171_item	2329724	et	4	main
inimesed	doc_292273046171_item	2329725	et	3	main
teadsid	doc_292273046171_item	2329733	et	4	main
selle	doc_292273046171_item	2329752	et	4	main
olla	doc_292273046171_item	2329755	et	3	main
harva	doc_292273046171_item	2329761	et	4	main
suvevaheajal	doc_292273046171_item	2329764	et	3	main
sel	doc_292273046171_item	2329766	et	3	main
ei	doc_292273046171_item	2329768	et	4	main
sellest	doc_292273046171_item	2329774	et	4	main
lähimalt	doc_292273046171_item	2329775	et	4	main
rääkidantminna	doc_292273046171_item	2329776	et	4	main
koos	doc_292273046171_item	2329777	et	4	main
laulupeolesee	doc_292273046171_item	2329778	et	4	main
mis	doc_292273046171_item	2329779	et	4	main
puudutab	doc_292273046171_item	2329780	et	3	main
iseseisvuspäeva	doc_292273046171_item	2329781	et	4	main
paljud	doc_292273046171_item	2329782	et	3	main
andsid	doc_292273046171_item	2329783	et	4	main
õiget	doc_292273046171_item	2329784	et	3	main
vastustseega	doc_292273046171_item	2329785	et	4	main
26	doc_292273046171_item	2329786	et	2	main
õpilast	doc_292273046171_item	2329787	et	4	main
4	doc_292273046171_item	2329788	et	2	main
ei	doc_292273046171_item	2329789	et	4	main
olnud	doc_292273046171_item	2329790	et	4	main
midagi	doc_292273046171_item	2329791	et	4	main
kirjutanud	doc_292273046171_item	2329792	et	4	main
ja	doc_292273046171_item	2329793	et	3	main
2	doc_292273046171_item	2329794	et	2	main
andsid	doc_292273046171_item	2329795	et	4	main
kummalist	doc_292273046171_item	2329796	et	3	main
vastust16	doc_292273046171_item	2329797	et	4	main
absurdseid	doc_292273046171_item	2329723	et	3	main
oli	doc_292273046171_item	2329729	et	3	main
voldemar	doc_292273046171_item	2329731	et	4	main
kus	doc_292273046171_item	2329734	et	3	main
õpilast	doc_292273046171_item	2329738	et	4	main
teavad	doc_292273046171_item	2329739	et	3	main
kui	doc_292273046171_item	2329740	et	3	main
tihti	doc_292273046171_item	2329741	et	3	main
seda	doc_292273046171_item	2329742	et	3	main
peetakse	doc_292273046171_item	2329743	et	3	main
ja	doc_292273046171_item	2329744	et	3	main
on	doc_292273046171_item	2329747	et	4	main
oli	doc_292273046171_item	2329750	et	3	main
võib	doc_292273046171_item	2329754	et	3	main
väga	doc_292273046171_item	2329760	et	3	main
perioodil	doc_292273046171_item	2329767	et	3	main
saa	doc_292273046171_item	2329769	et	4	main
veebruar	doc_292273046171_item	2329798	et	3	main
arvata	doc_292273046171_item	2329808	et	4	main
puudutas	doc_292273046171_item	2329811	et	3	main
vastuseks	doc_292273046171_item	2329821	et	4	main
ning	doc_292273046171_item	2329824	et	3	main
koolis	doc_292273046171_item	2329836	et	4	main
mis	doc_292273046171_item	2329841	et	4	main
eesti	doc_292273046171_item	2329854	et	4	main
ei	doc_292273046171_item	2329858	et	4	main
kirjutanud	doc_292273046171_item	2329859	et	4	main
vastuseidselle	doc_292273046171_item	2329874	et	4	main
õppekava	doc_292273046171_item	2329880	et	4	main
mõned	doc_292273046171_item	2329916	et	3	main
detsembermiks	doc_292273046171_item	2329801	et	4	main
järgmine	doc_292273046171_item	2329809	et	3	main
pakutud	doc_292273046171_item	2329822	et	4	main
vastatakalevipoja	doc_292273046171_item	2329829	et	4	main
õpitakse	doc_292273046171_item	2329831	et	4	main
sellest	doc_292273046171_item	2329833	et	4	main
igapäeva	doc_292273046171_item	2329838	et	4	main
välja	doc_292273046171_item	2329847	et	4	main
selgitadasamas	doc_292273046171_item	2329848	et	4	main
ma	doc_292273046171_item	2329849	et	3	main
küsisin	doc_292273046171_item	2329850	et	3	main
13	doc_292273046171_item	2329856	et	2	main
13	doc_292273046171_item	2329862	et	2	main
eesti	doc_292273046171_item	2329864	et	4	main
rahvuslauluks	doc_292273046171_item	2329866	et	4	main
ja	doc_292273046171_item	2329867	et	3	main
pakusid	doc_292273046171_item	2329871	et	4	main
alusel	doc_292273046171_item	2329876	et	4	main
kindlasti	doc_292273046171_item	2329878	et	3	main
sellekset	doc_292273046171_item	2329884	et	4	main
oli	doc_292273046171_item	2329913	et	3	main
vanasõnadega	doc_292273046171_item	2329915	et	3	main
segamini	doc_292273046171_item	2329919	et	4	main
seega	doc_292273046171_item	2329923	et	4	main
selline	doc_292273046171_item	2329926	et	4	main
vastanud	doc_292273046171_item	2329932	et	4	main
sellele	doc_292273046171_item	2329933	et	4	main
igapäevases	doc_292273046171_item	2329940	et	4	main
kommenteerida	doc_292273046171_item	2329946	et	3	main
kõnema	doc_292273046171_item	2329956	et	4	main
et	doc_292273046171_item	2329958	et	3	main
saaks	doc_292273046171_item	2329960	et	3	main
kas	doc_292273046171_item	2329962	et	3	main
samas	doc_292273046171_item	2329972	et	4	main
mitte	doc_292273046171_item	2329999	et	3	main
küsisin	doc_292273046171_item	2330010	et	3	main
jumalate	doc_292273046171_item	2330014	et	3	main
sain	doc_292273046171_item	2330018	et	3	main
olid	doc_292273046171_item	2330022	et	4	main
rahvakalendripäevi	doc_292273046171_item	2330033	et	4	main
peamised	doc_292273046171_item	2330050	et	3	main
jaanipäev	doc_292273046171_item	2330054	et	3	main
tähistatkse	doc_292273046171_item	2330057	et	4	main
pühadest	doc_292273046171_item	2330062	et	3	main
ka	doc_292273046171_item	2330065	et	3	main
et	doc_292273046171_item	2330067	et	3	main
näidatakse	doc_292273046171_item	2330077	et	3	main
traditsioonid	doc_292273046171_item	2330078	et	3	main
peamiselt	doc_292273046171_item	2330102	et	4	main
lasteleoli	doc_292273046171_item	2330104	et	4	main
mainitud	doc_292273046171_item	2330105	et	4	main
ka	doc_292273046171_item	2330106	et	3	main
inimest	doc_292273046171_item	2330110	et	3	main
aga	doc_292273046171_item	2330116	et	3	main
mingil	doc_292273046171_item	2330117	et	4	main
eesti	doc_292273046171_item	2330119	et	4	main
kirjanikke	doc_292273046171_item	2330120	et	3	main
hulka	doc_292273046171_item	2330121	et	4	main
lingren	doc_292273046171_item	2330126	et	4	main
rudolph	doc_292273046171_item	2330128	et	4	main
ka	doc_292273046171_item	2330130	et	3	main
kummaline	doc_292273046171_item	2330131	et	3	main
et	doc_292273046171_item	2330133	et	3	main
olutsu	doc_292273046171_item	2330138	et	4	main
kuigi	doc_292273046171_item	2330139	et	3	main
teosed	doc_292273046171_item	2330141	et	3	main
koolis	doc_292273046171_item	2330143	et	4	main
selle	doc_292273046171_item	2330149	et	4	main
siiski	doc_292273046171_item	2330156	et	4	main
2	doc_292273046171_item	2330158	et	2	main
õpilast	doc_292273046171_item	2330159	et	4	main
eesti	doc_292273046171_item	2330168	et	4	main
näitlejad	doc_292273046171_item	2330171	et	4	main
olevaid	doc_292273046171_item	2330177	et	4	main
estonia	doc_292273046171_item	2330182	et	4	main
vene	doc_292273046171_item	2330184	et	4	main
nimetas	doc_292273046171_item	2330194	et	3	main
kalev	doc_292273046171_item	2329823	et	3	main
6	doc_292273046171_item	2329825	et	2	main
osanud	doc_292273046171_item	2329828	et	4	main
eepost	doc_292273046171_item	2329830	et	3	main
5klassis	doc_292273046171_item	2329832	et	3	main
ja	doc_292273046171_item	2329837	et	3	main
puudumist	doc_292273046171_item	2329844	et	4	main
küsimisepalusin	doc_292273046171_item	2329852	et	4	main
mitte	doc_292273046171_item	2329860	et	3	main
pidas	doc_292273046171_item	2329863	et	3	main
hümni	doc_292273046171_item	2329865	et	4	main
niigi	doc_292273046171_item	2329868	et	4	main
mitmesuguseid	doc_292273046171_item	2329872	et	3	main
tulemuse	doc_292273046171_item	2329875	et	3	main
muutuda	doc_292273046171_item	2329879	et	3	main
lisada	doc_292273046171_item	2329881	et	3	main
sinna	doc_292273046171_item	2329882	et	3	main
audiomaterjale	doc_292273046171_item	2329883	et	3	main
õpilased	doc_292273046171_item	2329885	et	3	main
saaksid	doc_292273046171_item	2329886	et	4	main
endale	doc_292273046171_item	2329887	et	4	main
ette	doc_292273046171_item	2329888	et	4	main
kujutleda	doc_292273046171_item	2329889	et	3	main
mis	doc_292273046171_item	2329890	et	4	main
see	doc_292273046171_item	2329891	et	3	main
rahvuslaul	doc_292273046171_item	2329892	et	4	main
üldse	doc_292273046171_item	2329893	et	3	main
on	doc_292273046171_item	2329894	et	4	main
samas	doc_292273046171_item	2329895	et	4	main
lapsi	doc_292273046171_item	2329896	et	4	main
ei	doc_292273046171_item	2329897	et	4	main
huvita	doc_292273046171_item	2329898	et	4	main
rahvuslaulud	doc_292273046171_item	2329899	et	3	main
ka	doc_292273046171_item	2329900	et	3	main
sellepärast	doc_292273046171_item	2329901	et	3	main
et	doc_292273046171_item	2329902	et	3	main
seal	doc_292273046171_item	2329903	et	4	main
on	doc_292273046171_item	2329904	et	4	main
kasutatud	doc_292273046171_item	2329905	et	4	main
vana	doc_292273046171_item	2329906	et	4	main
sõnavara	doc_292273046171_item	2329907	et	4	main
millest	doc_292273046171_item	2329908	et	3	main
õpilased	doc_292273046171_item	2329909	et	3	main
aru	doc_292273046171_item	2329910	et	4	main
ei	doc_292273046171_item	2329911	et	4	main
saasama	doc_292273046171_item	2329912	et	4	main
raskeid	doc_292273046171_item	2329851	et	3	main
nimetada	doc_292273046171_item	2329853	et	3	main
midagi	doc_292273046171_item	2329861	et	4	main
õigeid	doc_292273046171_item	2329873	et	3	main
eesti	doc_292273046171_item	2329914	et	4	main
õpilased	doc_292273046171_item	2329917	et	3	main
ja	doc_292273046171_item	2329921	et	3	main
oli	doc_292273046171_item	2329925	et	3	main
õpilane	doc_292273046171_item	2329930	et	3	main
või	doc_292273046171_item	2329947	et	4	main
rikastada	doc_292273046171_item	2329955	et	3	main
pühendada	doc_292273046171_item	2329961	et	3	main
või	doc_292273046171_item	2329963	et	4	main
üks	doc_292273046171_item	2329964	et	3	main
õppeaasta	doc_292273046171_item	2329966	et	4	main
jooksul	doc_292273046171_item	2329967	et	4	main
sellekset	doc_292273046171_item	2329968	et	4	main
küsimusega	doc_292273046171_item	2329997	et	4	main
seega	doc_292273046171_item	2329998	et	4	main
ma	doc_292273046171_item	2330009	et	3	main
väga	doc_292273046171_item	2330019	et	3	main
ajasid	doc_292273046171_item	2329918	et	4	main
mitte	doc_292273046171_item	2329928	et	3	main
ükski	doc_292273046171_item	2329929	et	4	main
ei	doc_292273046171_item	2329931	et	4	main
midagi	doc_292273046171_item	2329945	et	4	main
vanasõna	doc_292273046171_item	2329949	et	4	main
aitab	doc_292273046171_item	2329954	et	3	main
olukorda	doc_292273046171_item	2329970	et	4	main
ei	doc_292273046171_item	2330001	et	4	main
teadmine	doc_292273046171_item	2330004	et	4	main
tasemeltestis	doc_292273046171_item	2330008	et	4	main
ka	doc_292273046171_item	2330011	et	3	main
nimesid	doc_292273046171_item	2330015	et	3	main
erinevaid	doc_292273046171_item	2330020	et	4	main
küsimused	doc_292273046171_item	2330027	et	4	main
missuguseid	doc_292273046171_item	2330032	et	3	main
teavadkõige	doc_292273046171_item	2330035	et	4	main
teati	doc_292273046171_item	2330037	et	3	main
jõulud	doc_292273046171_item	2330038	et	3	main
jaanipäeva	doc_292273046171_item	2330039	et	4	main
suurt	doc_292273046171_item	2330040	et	3	main
reedet	doc_292273046171_item	2330041	et	3	main
küsimus	doc_292273046171_item	2330043	et	4	main
kõlas	doc_292273046171_item	2330044	et	4	main
tähistavad	doc_292273046171_item	2330049	et	4	main
mardi-ja	doc_292273046171_item	2330055	et	3	main
kadripäevperedes	doc_292273046171_item	2330056	et	3	main
üpris	doc_292273046171_item	2330058	et	3	main
pühasid	doc_292273046171_item	2330060	et	3	main
teadmised	doc_292273046171_item	2330061	et	4	main
ellen	doc_292273046171_item	2330107	et	4	main
sattunud	doc_292273046171_item	2330123	et	4	main
ja	doc_292273046171_item	2330127	et	3	main
ainult	doc_292273046171_item	2330134	et	4	main
teiste	doc_292273046171_item	2330147	et	4	main
oli	doc_292273046171_item	2330152	et	3	main
palju	doc_292273046171_item	2330154	et	4	main
leidus	doc_292273046171_item	2330157	et	4	main
ei	doc_292273046171_item	2330161	et	4	main
küsimuseks	doc_292273046171_item	2330165	et	4	main
nimetada	doc_292273046171_item	2330167	et	3	main
tuntumad	doc_292273046171_item	2330169	et	4	main
teatrid	doc_292273046171_item	2330170	et	3	main
tallinnas	doc_292273046171_item	2330176	et	4	main
ainult	doc_292273046171_item	2330180	et	4	main
ja	doc_292273046171_item	2330183	et	3	main
teadmised	doc_292273046171_item	2330224	et	4	main
eesti	doc_292273046171_item	2330225	et	4	main
seega	doc_292273046171_item	2330227	et	4	main
ka	doc_292273046171_item	2330228	et	3	main
see	doc_292273046171_item	2330231	et	3	main
õppekavas	doc_292273046171_item	2330239	et	3	main
on	doc_292273046171_item	2330240	et	4	main
jäätnud	doc_292273046171_item	2330244	et	4	main
kultuuriõppimiseksviimane	doc_292273046171_item	2330245	et	3	main
küsimus	doc_292273046171_item	2330246	et	4	main
oli	doc_292273046171_item	2330254	et	3	main
ja	doc_292273046171_item	2330269	et	3	main
4	doc_292273046171_item	2330270	et	2	main
ainult	doc_292273046171_item	2330272	et	4	main
originaalne	doc_292273046171_item	2330278	et	3	main
kindel	doc_292273046171_item	2330284	et	3	main
vastused	doc_292273046171_item	2330288	et	3	main
teadmised	doc_292273046171_item	2330297	et	4	main
on	doc_292273046171_item	2330299	et	4	main
tasemelnõrgad	doc_292273046171_item	2330301	et	4	main
lavastused	doc_292273046171_item	2330305	et	4	main
rohkem	doc_292273046171_item	2330321	et	4	main
pöörata	doc_292273046171_item	2330323	et	4	main
tahaksid	doc_292273046171_item	2330331	et	4	main
rohkem	doc_292273046171_item	2330332	et	4	main
teada	doc_292273046171_item	2330333	et	3	main
tetritest	doc_292273046171_item	2330334	et	4	main
kirjandusest	doc_292273046171_item	2330337	et	4	main
just	doc_292273046171_item	2330338	et	3	main
mainisid	doc_292273046171_item	2330357	et	4	main
rahvapärimuse	doc_292273046171_item	2330361	et	3	main
samuti	doc_292273046172_item	2330376	et	3	main
kokku	doc_292273046172_item	2330379	et	3	main
28	doc_292273046172_item	2330383	et	2	main
palju	doc_292273046172_item	2330420	et	4	main
et	doc_292273046171_item	2329927	et	3	main
elus	doc_292273046171_item	2329941	et	4	main
kui	doc_292273046171_item	2329942	et	3	main
on	doc_292273046171_item	2329943	et	4	main
samas	doc_292273046171_item	2329952	et	4	main
see	doc_292273046171_item	2329953	et	3	main
arvan	doc_292273046171_item	2329957	et	3	main
õppekavas	doc_292273046171_item	2329959	et	3	main
sellist	doc_292273046171_item	2329969	et	4	main
tuleb	doc_292273046171_item	2329973	et	3	main
enne	doc_292273046171_item	2329974	et	4	main
õppeteksti	doc_292273046171_item	2329975	et	4	main
lisada	doc_292273046171_item	2329976	et	3	main
vanasõnu	doc_292273046171_item	2329977	et	3	main
mis	doc_292273046171_item	2329978	et	4	main
selle	doc_292273046171_item	2329979	et	4	main
teksti	doc_292273046171_item	2329980	et	4	main
sisuga	doc_292273046171_item	2329981	et	3	main
hästi	doc_292273046171_item	2329982	et	3	main
omavahel	doc_292273046171_item	2329983	et	3	main
sobiksid	doc_292273046171_item	2329984	et	4	main
järgmiseks	doc_292273046171_item	2329985	et	3	main
küsimuseks	doc_292273046171_item	2329986	et	4	main
oli	doc_292273046171_item	2329987	et	3	main
vastata	doc_292273046171_item	2329988	et	4	main
mõistatustele	doc_292273046171_item	2329989	et	4	main
ja	doc_292273046171_item	2329990	et	3	main
tulemus	doc_292273046171_item	2329991	et	3	main
oli	doc_292273046171_item	2329992	et	3	main
peaaegu	doc_292273046171_item	2329993	et	3	main
sama	doc_292273046171_item	2329994	et	4	main
kui	doc_292273046171_item	2329995	et	3	main
eelneva	doc_292273046171_item	2329996	et	4	main
keegi	doc_292273046171_item	2330000	et	4	main
vastatarahvatarkuste	doc_292273046171_item	2330003	et	4	main
on	doc_292273046171_item	2330005	et	4	main
väga	doc_292273046171_item	2330006	et	3	main
nõrgal	doc_292273046171_item	2330007	et	3	main
eesti	doc_292273046171_item	2330012	et	4	main
ja	doc_292273046171_item	2330016	et	3	main
mõned	doc_292273046171_item	2330021	et	3	main
naljakad	doc_292273046171_item	2330024	et	3	main
näiteks	doc_292273046171_item	2330025	et	4	main
olid	doc_292273046171_item	2330028	et	4	main
palusin	doc_292273046171_item	2330030	et	3	main
õpilased	doc_292273046171_item	2330048	et	3	main
olidjõulud	doc_292273046171_item	2330052	et	4	main
on	doc_292273046171_item	2330063	et	4	main
sellepärast	doc_292273046171_item	2330066	et	3	main
väikestele	doc_292273046171_item	2330103	et	4	main
paar	doc_292273046171_item	2330109	et	3	main
ka	doc_292273046171_item	2330124	et	3	main
õpilane	doc_292273046171_item	2330136	et	3	main
sellest	doc_292273046171_item	2330145	et	4	main
küsimustega	doc_292273046171_item	2330148	et	4	main
küsimusele	doc_292273046171_item	2330150	et	4	main
vastanud	doc_292273046171_item	2330163	et	4	main
lavastusedpaljud	doc_292273046171_item	2330172	et	4	main
õpilased99	doc_292273046171_item	2330173	et	3	main
tuntumaidteater	doc_292273046171_item	2330181	et	4	main
teater	doc_292273046171_item	2330185	et	3	main
vanalinnastuudiost	doc_292273046171_item	2330187	et	3	main
üks	doc_292273046171_item	2330192	et	3	main
vanemuineteatri	doc_292273046171_item	2330195	et	4	main
hulka	doc_292273046171_item	2330196	et	4	main
on	doc_292273046171_item	2330222	et	4	main
kultuurist	doc_292273046171_item	2330229	et	3	main
veelkord	doc_292273046171_item	2330236	et	3	main
väga	doc_292273046171_item	2330241	et	3	main
kultuuritegelased	doc_292273046171_item	2330249	et	3	main
et	doc_292273046171_item	2330256	et	3	main
kirjutanud	doc_292273046171_item	2330262	et	4	main
mainisid	doc_292273046171_item	2330271	et	4	main
oli	doc_292273046171_item	2330275	et	3	main
olin	doc_292273046171_item	2330283	et	3	main
kultuurist	doc_292273046171_item	2330298	et	3	main
madalal	doc_292273046171_item	2330300	et	4	main
kohad	doc_292273046171_item	2330302	et	4	main
õppekavas	doc_292273046171_item	2330303	et	3	main
kirjanikest	doc_292273046171_item	2330336	et	3	main
mis	doc_292273046171_item	2330341	et	4	main
pakkunud	doc_292273046171_item	2330343	et	4	main
neile	doc_292273046171_item	2330345	et	4	main
olid	doc_292273046171_item	2330346	et	4	main
rahvuslaulud	doc_292273046171_item	2330347	et	3	main
kuna	doc_292273046171_item	2330348	et	3	main
sealolev	doc_292273046171_item	2330349	et	3	main
keel	doc_292273046171_item	2330350	et	4	main
raskelt	doc_292273046171_item	2330353	et	4	main
arvates	doc_292273046171_item	2330360	et	4	main
on	doc_292273046171_item	2330363	et	4	main
rohkem	doc_292273046171_item	2330367	et	4	main
tegeldakse	doc_292273046171_item	2330368	et	3	main
oli	doc_292273046172_item	2330375	et	3	main
30	doc_292273046172_item	2330380	et	2	main
esimesed	doc_292273046172_item	2330384	et	3	main
õigestiseega	doc_292273046172_item	2330428	et	4	main
ei	doc_292273046172_item	2330434	et	4	main
on	doc_292273046172_item	2330441	et	4	main
riigi	doc_292273046172_item	2330442	et	3	main
7klassiga	doc_292273046172_item	2330445	et	3	main
õigesti	doc_292273046172_item	2330456	et	3	main
olid	doc_292273046172_item	2330474	et	4	main
küsimusele	doc_292273046172_item	2330489	et	4	main
vastasid	doc_292273046172_item	2330490	et	4	main
õigesti	doc_292273046172_item	2330491	et	3	main
peaaegu	doc_292273046172_item	2330492	et	3	main
õigesti	doc_292273046172_item	2330502	et	3	main
rahvuspuudaga	doc_292273046172_item	2330510	et	3	main
kuna	doc_292273046172_item	2330517	et	3	main
kalevipoegjeesuslydiajärgmised	doc_292273046171_item	2330026	et	4	main
kirjutada	doc_292273046171_item	2330031	et	3	main
nad	doc_292273046171_item	2330034	et	3	main
rohkem	doc_292273046171_item	2330036	et	4	main
nii	doc_292273046171_item	2330045	et	3	main
milliseid	doc_292273046171_item	2330046	et	3	main
rahvuspidusid	doc_292273046171_item	2330047	et	4	main
vastused	doc_292273046171_item	2330051	et	3	main
põhjalikud	doc_292273046171_item	2330064	et	3	main
nendest	doc_292273046171_item	2330068	et	4	main
koolis	doc_292273046171_item	2330069	et	4	main
räägitakse	doc_292273046171_item	2330070	et	3	main
palju	doc_292273046171_item	2330071	et	4	main
korraldatakse	doc_292273046171_item	2330072	et	3	main
nende	doc_292273046171_item	2330073	et	4	main
peode	doc_292273046171_item	2330074	et	3	main
tähistamine	doc_292273046171_item	2330075	et	4	main
ja	doc_292273046171_item	2330076	et	3	main
küsimuses	doc_292273046171_item	2330080	et	4	main
oli	doc_292273046171_item	2330081	et	3	main
vaja	doc_292273046171_item	2330082	et	4	main
nimetada	doc_292273046171_item	2330083	et	3	main
eesti	doc_292273046171_item	2330084	et	4	main
kirjanikkevastuseid	doc_292273046171_item	2330085	et	4	main
oli	doc_292273046171_item	2330086	et	3	main
palju	doc_292273046171_item	2330087	et	4	main
ja	doc_292273046171_item	2330088	et	3	main
kõige	doc_292273046171_item	2330089	et	4	main
rohkem	doc_292273046171_item	2330090	et	4	main
nimetati	doc_292273046171_item	2330091	et	4	main
eno	doc_292273046171_item	2330092	et	4	main
see	doc_292273046171_item	2330094	et	3	main
oli	doc_292273046171_item	2330095	et	3	main
kuidagi	doc_292273046171_item	2330096	et	3	main
imelik	doc_292273046171_item	2330097	et	3	main
kuna	doc_292273046171_item	2330098	et	3	main
see	doc_292273046171_item	2330099	et	3	main
kirjanik	doc_292273046171_item	2330100	et	3	main
kirjutas	doc_292273046171_item	2330101	et	3	main
rauda	doc_292273046171_item	2330093	et	4	main
mainisid	doc_292273046171_item	2330111	et	4	main
lydia	doc_292273046171_item	2330112	et	4	main
tammsaarevilde	doc_292273046171_item	2330114	et	4	main
põhjusel	doc_292273046171_item	2330118	et	3	main
oli	doc_292273046171_item	2330122	et	3	main
nimetas	doc_292273046171_item	2330137	et	3	main
tema	doc_292273046171_item	2330140	et	4	main
õpetatakse	doc_292273046171_item	2330142	et	3	main
kirjandeidvõrreldes	doc_292273046171_item	2330146	et	4	main
vastajaid	doc_292273046171_item	2330151	et	4	main
üpris	doc_292273046171_item	2330153	et	3	main
aga	doc_292273046171_item	2330155	et	3	main
olnud	doc_292273046171_item	2330162	et	4	main
teatreid	doc_292273046171_item	2330178	et	3	main
ka	doc_292273046171_item	2330197	et	3	main
õpilaste	doc_292273046171_item	2330198	et	4	main
arvates	doc_292273046171_item	2330199	et	4	main
kuulusid	doc_292273046171_item	2330200	et	4	main
coca-cola	doc_292273046171_item	2330201	et	4	main
plaza	doc_292273046171_item	2330202	et	4	main
kino	doc_292273046171_item	2330203	et	4	main
kosmos	doc_292273046171_item	2330204	et	3	main
ja	doc_292273046171_item	2330205	et	3	main
sõpruslavastusi	doc_292273046171_item	2330206	et	3	main
teadis	doc_292273046171_item	2330207	et	4	main
ainult	doc_292273046171_item	2330208	et	4	main
1	doc_292273046171_item	2330209	et	2	main
õpilane	doc_292273046171_item	2330210	et	3	main
32st	doc_292273046171_item	2330211	et	3	main
ei	doc_292273046171_item	2330213	et	4	main
ole	doc_292273046171_item	2330214	et	4	main
näitlejaid	doc_292273046171_item	2330212	et	4	main
mitte	doc_292273046171_item	2330215	et	3	main
keegi	doc_292273046171_item	2330216	et	4	main
kirjutanudneed	doc_292273046171_item	2330217	et	4	main
tulemused	doc_292273046171_item	2330218	et	3	main
näitavad	doc_292273046171_item	2330219	et	4	main
kui	doc_292273046171_item	2330220	et	3	main
viletsad	doc_292273046171_item	2330221	et	3	main
laste	doc_292273046171_item	2330223	et	4	main
kultuuri	doc_292273046171_item	2330233	et	4	main
et	doc_292273046171_item	2330238	et	3	main
vähe	doc_292273046171_item	2330242	et	3	main
aega	doc_292273046171_item	2330243	et	4	main
on	doc_292273046171_item	2330250	et	4	main
eesti	doc_292273046171_item	2330251	et	4	main
rahakupüüridel	doc_292273046171_item	2330252	et	3	main
tulemus	doc_292273046171_item	2330253	et	3	main
pool	doc_292273046171_item	2330263	et	4	main
15	doc_292273046171_item	2330265	et	2	main
andsid	doc_292273046171_item	2330266	et	4	main
täieliku	doc_292273046171_item	2330267	et	3	main
ülevaade	doc_292273046171_item	2330268	et	3	main
ka	doc_292273046171_item	2330276	et	3	main
küsimust	doc_292273046171_item	2330280	et	4	main
saan	doc_292273046171_item	2330286	et	4	main
et	doc_292273046171_item	2330295	et	3	main
onteater	doc_292273046171_item	2330304	et	4	main
sajandisee	doc_292273046171_item	2330340	et	4	main
huvi	doc_292273046171_item	2330344	et	4	main
väga	doc_292273046171_item	2330352	et	3	main
nad	doc_292273046171_item	2330356	et	3	main
teatrielust	doc_292273046171_item	2330226	et	3	main
lahendamata	doc_292273046171_item	2330234	et	4	main
osasee	doc_292273046171_item	2330235	et	4	main
kõlas	doc_292273046171_item	2330247	et	4	main
15	doc_292273046171_item	2330257	et	2	main
ei	doc_292273046171_item	2330259	et	4	main
midagi	doc_292273046171_item	2330261	et	4	main
koidulat	doc_292273046171_item	2330274	et	4	main
üks	doc_292273046171_item	2330277	et	3	main
ma	doc_292273046171_item	2330282	et	3	main
sain	doc_292273046171_item	2330292	et	3	main
teada	doc_292273046171_item	2330293	et	3	main
õpilaste	doc_292273046171_item	2330296	et	4	main
näitlejad	doc_292273046171_item	2330306	et	4	main
kirjanduseesti	doc_292273046171_item	2330307	et	4	main
kirjanikud	doc_292273046171_item	2330308	et	3	main
laulupidu	doc_292273046171_item	2330309	et	4	main
ja	doc_292273046171_item	2330310	et	3	main
sellega	doc_292273046171_item	2330311	et	3	main
seonduvad	doc_292273046171_item	2330312	et	4	main
traditsioonid	doc_292273046171_item	2330313	et	3	main
eesti	doc_292273046171_item	2330314	et	4	main
vanasõnad	doc_292273046171_item	2330315	et	3	main
muistendid	doc_292273046171_item	2330316	et	3	main
tarkused	doc_292273046171_item	2330317	et	4	main
rahvuslaulud-sellele	doc_292273046171_item	2330318	et	4	main
kõigile	doc_292273046171_item	2330319	et	4	main
tuleb	doc_292273046171_item	2330320	et	3	main
vesteldes	doc_292273046171_item	2330327	et	3	main
selgus	doc_292273046171_item	2330328	et	4	main
et	doc_292273046171_item	2330329	et	3	main
nad	doc_292273046171_item	2330330	et	3	main
20	doc_292273046171_item	2330339	et	2	main
arusaadav	doc_292273046171_item	2330354	et	4	main
nende	doc_292273046171_item	2330359	et	4	main
korraldatav	doc_292273046172_item	2330373	et	4	main
õpilastküsimusi	doc_292273046172_item	2330381	et	4	main
eesti	doc_292273046172_item	2330418	et	4	main
tõestab	doc_292273046171_item	2330237	et	3	main
niimillised	doc_292273046171_item	2330248	et	4	main
selline	doc_292273046171_item	2330255	et	4	main
õpilast	doc_292273046171_item	2330258	et	4	main
ole	doc_292273046171_item	2330260	et	4	main
küsitletust	doc_292273046171_item	2330264	et	4	main
lydia	doc_292273046171_item	2330273	et	4	main
vastuskalevipoegsellist	doc_292273046171_item	2330279	et	4	main
küsides	doc_292273046171_item	2330281	et	3	main
et	doc_292273046171_item	2330285	et	3	main
konkreetsed	doc_292273046171_item	2330287	et	3	main
teksti	doc_292273046171_item	2330289	et	4	main
analüüsides	doc_292273046171_item	2330290	et	4	main
ma	doc_292273046171_item	2330291	et	3	main
et	doc_292273046171_item	2330294	et	3	main
tähelepanu	doc_292273046171_item	2330322	et	4	main
uue	doc_292273046171_item	2330324	et	3	main
õppekava	doc_292273046171_item	2330325	et	4	main
koostamiselõpilastega	doc_292273046171_item	2330326	et	4	main
muuseumidest	doc_292273046171_item	2330335	et	3	main
ei	doc_292273046171_item	2330342	et	4	main
on	doc_292273046171_item	2330351	et	4	main
samas	doc_292273046171_item	2330355	et	4	main
õpetamisele	doc_292273046171_item	2330362	et	4	main
pööratud	doc_292273046171_item	2330364	et	4	main
vähe	doc_292273046171_item	2330365	et	3	main
tähelepanu	doc_292273046171_item	2330366	et	4	main
klassis	doc_292273046172_item	2330372	et	3	main
test	doc_292273046172_item	2330374	et	3	main
oli	doc_292273046172_item	2330382	et	3	main
18	doc_292273046172_item	2330385	et	2	main
samas	doc_292273046172_item	2330387	et	4	main
nagu	doc_292273046172_item	2330388	et	3	main
7klassi	doc_292273046172_item	2330389	et	4	main
testis	doc_292273046172_item	2330390	et	4	main
niimodi	doc_292273046172_item	2330391	et	4	main
ma	doc_292273046172_item	2330392	et	3	main
tegin	doc_292273046172_item	2330393	et	3	main
sellepärast	doc_292273046172_item	2330394	et	3	main
et	doc_292273046172_item	2330395	et	3	main
tahtsin	doc_292273046172_item	2330396	et	3	main
kontrollida	doc_292273046172_item	2330397	et	4	main
ja	doc_292273046172_item	2330398	et	3	main
võrrelda	doc_292273046172_item	2330399	et	4	main
teadmisi	doc_292273046172_item	2330400	et	4	main
kuivõrd	doc_292273046172_item	2330401	et	3	main
nad	doc_292273046172_item	2330402	et	3	main
on	doc_292273046172_item	2330403	et	4	main
paranenud	doc_292273046172_item	2330404	et	4	main
arenenud	doc_292273046172_item	2330405	et	4	main
või	doc_292273046172_item	2330406	et	4	main
hoopiski	doc_292273046172_item	2330407	et	3	main
vastupiditestisse	doc_292273046172_item	2330408	et	3	main
ma	doc_292273046172_item	2330409	et	3	main
lisasin	doc_292273046172_item	2330410	et	3	main
juurde	doc_292273046172_item	2330411	et	4	main
10	doc_292273046172_item	2330412	et	2	main
küsimust	doc_292273046172_item	2330413	et	4	main
esimeseks	doc_292273046172_item	2330414	et	3	main
küsimuseks	doc_292273046172_item	2330415	et	4	main
oli	doc_292273046172_item	2330416	et	3	main
nimetada	doc_292273046172_item	2330417	et	3	main
et	doc_292273046171_item	2330358	et	3	main
keelestruktuuridega	doc_292273046171_item	2330369	et	3	main
seminaritöö	doc_292273046172_item	2330370	et	4	main
selles	doc_292273046172_item	2330371	et	4	main
anonüümnetestis	doc_292273046172_item	2330377	et	4	main
osalesid	doc_292273046172_item	2330378	et	4	main
olid	doc_292273046172_item	2330386	et	4	main
õpilased	doc_292273046172_item	2330421	et	3	main
eesti	doc_292273046172_item	2330423	et	4	main
16ainult	doc_292273046172_item	2330425	et	4	main
ole	doc_292273046172_item	2330435	et	4	main
rahvasümbolid	doc_292273046172_item	2330438	et	3	main
võrreldes	doc_292273046172_item	2330444	et	3	main
oli	doc_292273046172_item	2330458	et	3	main
võrreldes	doc_292273046172_item	2330461	et	3	main
selle	doc_292273046172_item	2330463	et	4	main
küsimuse	doc_292273046172_item	2330464	et	4	main
oskajate	doc_292273046172_item	2330465	et	4	main
aga	doc_292273046172_item	2330475	et	3	main
johann	doc_292273046172_item	2330479	et	4	main
jannsenjärgmised	doc_292273046172_item	2330481	et	4	main
küsimused	doc_292273046172_item	2330482	et	4	main
ja	doc_292273046172_item	2330486	et	3	main
rahvuslillest	doc_292273046172_item	2330487	et	4	main
sellele	doc_292273046172_item	2330488	et	4	main
õpilased	doc_292273046172_item	2330494	et	3	main
rahuslilleks	doc_292273046172_item	2330498	et	4	main
sinililleeesti	doc_292273046172_item	2330499	et	4	main
õpilased	doc_292273046172_item	2330504	et	3	main
nendele	doc_292273046172_item	2330511	et	4	main
küsimus	doc_292273046172_item	2330522	et	4	main
oli	doc_292273046172_item	2330523	et	3	main
paranenud	doc_292273046172_item	2330529	et	4	main
õigesti	doc_292273046172_item	2330538	et	3	main
et	doc_292273046172_item	2330548	et	3	main
laulupidu	doc_292273046172_item	2330550	et	4	main
tartus	doc_292273046172_item	2330552	et	3	main
35-tunniline	doc_292273046172_item	2330565	et	4	main
kursus	doc_292273046172_item	2330566	et	3	main
vastasid	doc_292273046172_item	2330571	et	4	main
kõik	doc_292273046172_item	2330579	et	4	main
on	doc_292273046172_item	2330588	et	4	main
palju	doc_292273046172_item	2330591	et	4	main
variante	doc_292273046172_item	2330593	et	3	main
16	doc_292273046172_item	2330597	et	2	main
õpilast14	doc_292273046172_item	2330598	et	4	main
ei	doc_292273046172_item	2330599	et	4	main
oli	doc_292273046172_item	2330603	et	3	main
piir	doc_292273046172_item	2330622	et	3	main
küsimuses	doc_292273046172_item	2330636	et	4	main
oli	doc_292273046172_item	2330637	et	3	main
nimesidvalesti	doc_292273046172_item	2330643	et	4	main
mitu	doc_292273046172_item	2330657	et	4	main
on	doc_292273046172_item	2330681	et	4	main
õpilased	doc_292273046172_item	2330682	et	3	main
palju	doc_292273046172_item	2330683	et	4	main
kes	doc_292273046172_item	2330689	et	4	main
antud	doc_292273046172_item	2330695	et	4	main
kirjutada	doc_292273046172_item	2330697	et	3	main
2	doc_292273046172_item	2330703	et	2	main
küsimustele	doc_292273046172_item	2330708	et	4	main
ei	doc_292273046172_item	2330720	et	4	main
ühtele	doc_292273046172_item	2330724	et	3	main
teadmisteskaal	doc_292273046172_item	2330728	et	4	main
kõrgem	doc_292273046172_item	2330731	et	4	main
jõuludemadepäevmind	doc_292273046172_item	2330749	et	4	main
selline	doc_292273046172_item	2330752	et	4	main
et	doc_292273046172_item	2330754	et	3	main
milliseid	doc_292273046172_item	2330755	et	3	main
päevi	doc_292273046172_item	2330756	et	4	main
õpilased	doc_292273046172_item	2330757	et	3	main
kolmandal	doc_292273046172_item	2330766	et	3	main
mardi-ja	doc_292273046172_item	2330768	et	3	main
kirjanikkeainult	doc_292273046172_item	2330775	et	4	main
oli	doc_292273046172_item	2330787	et	3	main
nii	doc_292273046172_item	2330792	et	3	main
kirjanikke	doc_292273046172_item	2330794	et	3	main
spetsiaalses	doc_292273046172_item	2330804	et	3	main
on	doc_292273046172_item	2330811	et	4	main
küsimuses	doc_292273046172_item	2330814	et	4	main
riigisümboleid	doc_292273046172_item	2330419	et	3	main
nimetasid	doc_292273046172_item	2330422	et	4	main
rahvuslindulilli-kivekokku	doc_292273046172_item	2330424	et	4	main
kirjutasid	doc_292273046172_item	2330429	et	4	main
vapulippu	doc_292273046172_item	2330431	et	4	main
selgemis	doc_292273046172_item	2330436	et	4	main
on	doc_292273046172_item	2330437	et	4	main
sümbolid	doc_292273046172_item	2330443	et	3	main
vastajate	doc_292273046172_item	2330447	et	4	main
hümni	doc_292273046172_item	2330453	et	4	main
sõnadeautori	doc_292273046172_item	2330454	et	3	main
2	doc_292273046172_item	2330459	et	2	main
arv	doc_292273046172_item	2330466	et	3	main
suurendas	doc_292273046172_item	2330467	et	3	main
ühe	doc_292273046172_item	2330469	et	4	main
inimese	doc_292273046172_item	2330470	et	4	main
võrra	doc_292273046172_item	2330471	et	3	main
kindladet	doc_292273046172_item	2330476	et	4	main
olid	doc_292273046172_item	2330483	et	4	main
eesti	doc_292273046172_item	2330484	et	4	main
rahvuslinnust	doc_292273046172_item	2330485	et	4	main
aga	doc_292273046172_item	2330496	et	3	main
nimetasid	doc_292273046172_item	2330501	et	4	main
eesti	doc_292273046172_item	2330509	et	4	main
vastuseid	doc_292273046172_item	2330513	et	3	main
teadma	doc_292273046172_item	2330515	et	3	main
need	doc_292273046172_item	2330518	et	3	main
baasteadmised	doc_292273046172_item	2330520	et	3	main
kultuuristseitsmes	doc_292273046172_item	2330521	et	4	main
on	doc_292273046172_item	2330527	et	4	main
kirjutasid	doc_292273046172_item	2330537	et	4	main
see	doc_292273046172_item	2330540	et	3	main
iga	doc_292273046172_item	2330542	et	4	main
kõik	doc_292273046172_item	2330546	et	4	main
eesti	doc_292273046172_item	2330567	et	4	main
aga	doc_292273046172_item	2330584	et	3	main
olukord	doc_292273046172_item	2330585	et	3	main
7klassiga	doc_292273046172_item	2330587	et	3	main
õigesti	doc_292273046172_item	2330595	et	3	main
kirjutanud	doc_292273046172_item	2330602	et	4	main
naljakaid	doc_292273046172_item	2330605	et	4	main
eesti	doc_292273046172_item	2330625	et	4	main
vahel	doc_292273046172_item	2330627	et	4	main
hümnijärgmises	doc_292273046172_item	2330635	et	3	main
oli	doc_292273046172_item	2330645	et	3	main
kui	doc_292273046172_item	2330647	et	3	main
ole	doc_292273046172_item	2330676	et	4	main
midagi	doc_292273046172_item	2330677	et	4	main
juurde	doc_292273046172_item	2330684	et	4	main
õppinudkõike	doc_292273046172_item	2330685	et	4	main
meeskolmeteiskümnendas	doc_292273046172_item	2330691	et	4	main
küsimuses	doc_292273046172_item	2330692	et	4	main
oli	doc_292273046172_item	2330693	et	3	main
õigeid	doc_292273046172_item	2330698	et	3	main
mõistatustoli	doc_292273046172_item	2330702	et	4	main
õpilastkes	doc_292273046172_item	2330704	et	4	main
on	doc_292273046172_item	2330705	et	4	main
vastanud	doc_292273046172_item	2330706	et	4	main
õpilast	doc_292273046172_item	2330710	et	4	main
7	doc_292273046172_item	2330714	et	2	main
ühe	doc_292273046172_item	2330716	et	4	main
ole	doc_292273046172_item	2330721	et	4	main
palju	doc_292273046172_item	2330730	et	4	main
küsimuse	doc_292273046172_item	2330735	et	4	main
populaarsemad	doc_292273046172_item	2330746	et	4	main
ka	doc_292273046172_item	2330751	et	3	main
tähistavad	doc_292273046172_item	2330758	et	4	main
küsimusel	doc_292273046172_item	2330770	et	4	main
eesti	doc_292273046172_item	2330774	et	4	main
2	doc_292273046172_item	2330776	et	2	main
õpilast	doc_292273046172_item	2330777	et	4	main
ei	doc_292273046172_item	2330778	et	4	main
28	doc_292273046172_item	2330783	et	2	main
pakkusid	doc_292273046172_item	2330784	et	4	main
ka	doc_292273046172_item	2330788	et	3	main
kui	doc_292273046172_item	2330795	et	3	main
kirjanikkekuna	doc_292273046172_item	2330798	et	4	main
teema	doc_292273046172_item	2330800	et	4	main
kultuuriprogrammis	doc_292273046172_item	2330805	et	3	main
väga	doc_292273046172_item	2330812	et	3	main
vastasid	doc_292273046172_item	2330427	et	4	main
eesti	doc_292273046172_item	2330430	et	4	main
ja	doc_292273046172_item	2330432	et	3	main
hümniõpilastel	doc_292273046172_item	2330433	et	4	main
mis	doc_292273046172_item	2330440	et	4	main
oli	doc_292273046172_item	2330446	et	3	main
arv	doc_292273046172_item	2330448	et	3	main
suurenenudteine	doc_292273046172_item	2330449	et	4	main
14	doc_292273046172_item	2330426	et	2	main
ja	doc_292273046172_item	2330439	et	3	main
vastajaid	doc_292273046172_item	2330457	et	4	main
seega	doc_292273046172_item	2330460	et	4	main
7klassiga	doc_292273046172_item	2330462	et	3	main
ainult	doc_292273046172_item	2330468	et	4	main
on	doc_292273046172_item	2330478	et	4	main
voldemar	doc_292273046172_item	2330480	et	4	main
2	doc_292273046172_item	2330495	et	2	main
pakkusid	doc_292273046172_item	2330497	et	4	main
presidenti	doc_292273046172_item	2330500	et	4	main
nimetasid	doc_292273046172_item	2330507	et	4	main
õigesti	doc_292273046172_item	2330508	et	3	main
küsimustele	doc_292273046172_item	2330512	et	4	main
kõik	doc_292273046172_item	2330516	et	4	main
on	doc_292273046172_item	2330519	et	4	main
teadmised	doc_292273046172_item	2330526	et	4	main
25	doc_292273046172_item	2330530	et	2	main
kirjutasid	doc_292273046172_item	2330533	et	4	main
et	doc_292273046172_item	2330539	et	3	main
toimub	doc_292273046172_item	2330541	et	3	main
vastasid	doc_292273046172_item	2330547	et	4	main
toimus	doc_292273046172_item	2330551	et	3	main
arvan	doc_292273046172_item	2330554	et	3	main
vastanute	doc_292273046172_item	2330557	et	4	main
arv	doc_292273046172_item	2330558	et	3	main
suurenes	doc_292273046172_item	2330559	et	4	main
ka	doc_292273046172_item	2330560	et	3	main
sellepärast	doc_292273046172_item	2330561	et	3	main
et	doc_292273046172_item	2330562	et	3	main
11klassis	doc_292273046172_item	2330563	et	3	main
on	doc_292273046172_item	2330564	et	4	main
küsimusele	doc_292273046172_item	2330569	et	4	main
kõik	doc_292273046172_item	2330572	et	4	main
õpilased	doc_292273046172_item	2330573	et	3	main
raskusi	doc_292273046172_item	2330583	et	4	main
paranenudoli	doc_292273046172_item	2330589	et	4	main
õigeid	doc_292273046172_item	2330592	et	3	main
ja	doc_292273046172_item	2330594	et	3	main
midagi	doc_292273046172_item	2330601	et	4	main
küsimus	doc_292273046172_item	2330450	et	4	main
puudutas	doc_292273046172_item	2330451	et	3	main
eesti	doc_292273046172_item	2330452	et	4	main
ja	doc_292273046172_item	2330455	et	3	main
23	doc_292273046172_item	2330472	et	2	main
õpilast	doc_292273046172_item	2330473	et	4	main
sõnadeautor	doc_292273046172_item	2330477	et	3	main
kõik	doc_292273046172_item	2330493	et	4	main
kõik	doc_292273046172_item	2330503	et	4	main
samas	doc_292273046172_item	2330505	et	4	main
kõik	doc_292273046172_item	2330506	et	4	main
peavad	doc_292273046172_item	2330514	et	4	main
märgatavalt	doc_292273046172_item	2330528	et	4	main
õpilast	doc_292273046172_item	2330532	et	4	main
õigesti	doc_292273046172_item	2330534	et	3	main
aasta	doc_292273046172_item	2330535	et	4	main
18	doc_292273046172_item	2330536	et	2	main
aastat	doc_292273046172_item	2330544	et	3	main
esimene	doc_292273046172_item	2330549	et	3	main
õigesti	doc_292273046172_item	2330556	et	3	main
kultuuristjärgmisele	doc_292273046172_item	2330568	et	4	main
õigestirahvuslauludega	doc_292273046172_item	2330580	et	4	main
esinesid	doc_292273046172_item	2330581	et	4	main
ka	doc_292273046172_item	2330582	et	3	main
nimetatud	doc_292273046172_item	2330590	et	4	main
vastasid	doc_292273046172_item	2330596	et	4	main
ka	doc_292273046172_item	2330604	et	3	main
selge	doc_292273046172_item	2330621	et	4	main
keegi	doc_292273046172_item	2330630	et	4	main
ei	doc_292273046172_item	2330631	et	4	main
eesti	doc_292273046172_item	2330634	et	4	main
vastanuid	doc_292273046172_item	2330644	et	4	main
klassst16	doc_292273046172_item	2330649	et	4	main
inimest	doc_292273046172_item	2330650	et	3	main
ning	doc_292273046172_item	2330651	et	3	main
varianteaga	doc_292273046172_item	2330658	et	4	main
ei	doc_292273046172_item	2330675	et	4	main
mõistatusele	doc_292273046172_item	2330696	et	4	main
3	doc_292273046172_item	2330701	et	2	main
vastasid	doc_292273046172_item	2330711	et	4	main
mõistatusele	doc_292273046172_item	2330713	et	4	main
laulupeost7klassiga	doc_292273046172_item	2330524	et	4	main
võrreldes	doc_292273046172_item	2330525	et	3	main
30st	doc_292273046172_item	2330531	et	3	main
5	doc_292273046172_item	2330543	et	2	main
ja	doc_292273046172_item	2330545	et	3	main
ma	doc_292273046172_item	2330553	et	3	main
et	doc_292273046172_item	2330555	et	3	main
iseseisvuspäevast	doc_292273046172_item	2330570	et	4	main
õigesti	doc_292273046172_item	2330574	et	3	main
rahvuseepose	doc_292273046172_item	2330575	et	3	main
nimi	doc_292273046172_item	2330576	et	3	main
kirjutasid	doc_292273046172_item	2330577	et	4	main
ka	doc_292273046172_item	2330578	et	3	main
võrreldes	doc_292273046172_item	2330586	et	3	main
olnud	doc_292273046172_item	2330600	et	4	main
vastuseid	doc_292273046172_item	2330606	et	3	main
nteesti	doc_292273046172_item	2330607	et	4	main
rahvuslauluks	doc_292273046172_item	2330608	et	4	main
osutus	doc_292273046172_item	2330609	et	4	main
räpp	doc_292273046172_item	2330610	et	3	main
laulme	doc_292273046172_item	2330611	et	4	main
pappi	doc_292273046172_item	2330612	et	4	main
ei	doc_292273046172_item	2330613	et	4	main
saa	doc_292273046172_item	2330614	et	4	main
samas	doc_292273046172_item	2330615	et	4	main
tahaks	doc_292273046172_item	2330616	et	3	main
mainida	doc_292273046172_item	2330617	et	3	main
et	doc_292273046172_item	2330618	et	3	main
õpilastel	doc_292273046172_item	2330619	et	4	main
on	doc_292273046172_item	2330620	et	4	main
rahvuslaulude	doc_292273046172_item	2330623	et	3	main
hümni	doc_292273046172_item	2330626	et	4	main
nimelt	doc_292273046172_item	2330628	et	4	main
mitte	doc_292273046172_item	2330629	et	3	main
kirjutanud	doc_292273046172_item	2330633	et	4	main
jumalate	doc_292273046172_item	2330642	et	3	main
rohkem	doc_292273046172_item	2330646	et	4	main
pool	doc_292273046172_item	2330648	et	4	main
õigesti	doc_292273046172_item	2330652	et	3	main
vastasid	doc_292273046172_item	2330653	et	4	main
14	doc_292273046172_item	2330654	et	2	main
enamus	doc_292273046172_item	2330659	et	4	main
vastas	doc_292273046172_item	2330660	et	4	main
kirjutanud	doc_292273046172_item	2330678	et	4	main
võrreldes	doc_292273046172_item	2330679	et	3	main
7klassiga	doc_292273046172_item	2330680	et	3	main
vaja	doc_292273046172_item	2330694	et	4	main
kokku	doc_292273046172_item	2330700	et	3	main
kõigidele	doc_292273046172_item	2330707	et	4	main
kahele	doc_292273046172_item	2330712	et	4	main
kui	doc_292273046172_item	2330732	et	3	main
rahvakalendri	doc_292273046172_item	2330736	et	3	main
erinevaid	doc_292273046172_item	2330743	et	4	main
päevi	doc_292273046172_item	2330744	et	4	main
jaanipäev	doc_292273046172_item	2330748	et	3	main
kadripäevviieteistkümnendal	doc_292273046172_item	2330769	et	4	main
vastusevariante	doc_292273046172_item	2330786	et	4	main
kaasaegseid	doc_292273046172_item	2330797	et	3	main
selline	doc_292273046172_item	2330799	et	4	main
on	doc_292273046172_item	2330801	et	4	main
11	doc_292273046172_item	2330802	et	2	main
klassi	doc_292273046172_item	2330803	et	4	main
näha	doc_292273046172_item	2330808	et	3	main
headjärgmises	doc_292273046172_item	2330813	et	3	main
oli	doc_292273046172_item	2330815	et	3	main
ja	doc_292273046172_item	2330624	et	3	main
ole	doc_292273046172_item	2330632	et	4	main
vaja	doc_292273046172_item	2330638	et	4	main
nimetada	doc_292273046172_item	2330639	et	3	main
eesti	doc_292273046172_item	2330640	et	4	main
muistsete	doc_292273046172_item	2330641	et	3	main
õpilastnad	doc_292273046172_item	2330655	et	4	main
pakusid	doc_292273046172_item	2330656	et	4	main
vanaisajärgmise	doc_292273046172_item	2330661	et	3	main
küsimuse	doc_292273046172_item	2330662	et	4	main
ülesanne	doc_292273046172_item	2330663	et	4	main
oli	doc_292273046172_item	2330664	et	3	main
nimetada	doc_292273046172_item	2330665	et	3	main
eesti	doc_292273046172_item	2330666	et	4	main
vanasõnu	doc_292273046172_item	2330667	et	3	main
selle	doc_292273046172_item	2330668	et	4	main
ülesannega	doc_292273046172_item	2330669	et	4	main
said	doc_292273046172_item	2330670	et	4	main
hakkama18	doc_292273046172_item	2330671	et	3	main
õpilast60	doc_292273046172_item	2330672	et	4	main
ning	doc_292273046172_item	2330673	et	3	main
12	doc_292273046172_item	2330674	et	2	main
levinum	doc_292273046172_item	2330686	et	4	main
vastus	doc_292273046172_item	2330687	et	3	main
oli	doc_292273046172_item	2330688	et	3	main
eessee	doc_292273046172_item	2330690	et	4	main
vastuseidoli	doc_292273046172_item	2330699	et	4	main
8	doc_292273046172_item	2330709	et	2	main
kirjutasid	doc_292273046172_item	2330715	et	4	main
vastuse	doc_292273046172_item	2330717	et	3	main
ja	doc_292273046172_item	2330718	et	3	main
13	doc_292273046172_item	2330719	et	2	main
mitte	doc_292273046172_item	2330723	et	3	main
on	doc_292273046172_item	2330729	et	4	main
kõige	doc_292273046172_item	2330745	et	4	main
huvitas	doc_292273046172_item	2330750	et	3	main
vastused	doc_292273046172_item	2330759	et	3	main
kohal	doc_292273046172_item	2330767	et	4	main
vaja	doc_292273046172_item	2330772	et	4	main
ole	doc_292273046172_item	2330779	et	4	main
erinevaid	doc_292273046172_item	2330785	et	4	main
mõnus	doc_292273046172_item	2330789	et	4	main
nimetati	doc_292273046172_item	2330791	et	4	main
19sajandi	doc_292273046172_item	2330793	et	3	main
me	doc_292273046172_item	2330806	et	4	main
tulemused	doc_292273046172_item	2330810	et	3	main
vastanud	doc_292273046172_item	2330722	et	4	main
küsimusele	doc_292273046172_item	2330725	et	4	main
seega	doc_292273046172_item	2330726	et	4	main
11klassi	doc_292273046172_item	2330727	et	4	main
seitsmendal	doc_292273046172_item	2330733	et	3	main
klassiljärgmise	doc_292273046172_item	2330734	et	4	main
päeva	doc_292273046172_item	2330737	et	4	main
tundmisest	doc_292273046172_item	2330738	et	4	main
oli	doc_292273046172_item	2330739	et	3	main
nimetatud	doc_292273046172_item	2330740	et	4	main
hästi	doc_292273046172_item	2330741	et	3	main
palju	doc_292273046172_item	2330742	et	4	main
olid	doc_292273046172_item	2330747	et	4	main
asi	doc_292273046172_item	2330753	et	4	main
olid	doc_292273046172_item	2330760	et	4	main
sellisedesimene	doc_292273046172_item	2330761	et	4	main
on	doc_292273046172_item	2330762	et	4	main
jaanipäevsiis	doc_292273046172_item	2330763	et	4	main
jõulud	doc_292273046172_item	2330764	et	3	main
ning	doc_292273046172_item	2330765	et	3	main
oli	doc_292273046172_item	2330771	et	3	main
nimetada	doc_292273046172_item	2330773	et	3	main
midagi	doc_292273046172_item	2330780	et	4	main
vastanus	doc_292273046172_item	2330781	et	4	main
ülejäänud	doc_292273046172_item	2330782	et	4	main
et	doc_292273046172_item	2330790	et	3	main
ka	doc_292273046172_item	2330796	et	3	main
võime	doc_292273046172_item	2330807	et	4	main
et	doc_292273046172_item	2330809	et	3	main
vaja	doc_292273046172_item	2330816	et	4	main
nimetada	doc_292273046172_item	2330817	et	3	main
tuntumad	doc_292273046172_item	2330818	et	4	main
palju	doc_292273046172_item	2330824	et	4	main
ainult	doc_292273046172_item	2330832	et	4	main
ning	doc_292273046172_item	2330835	et	3	main
ei	doc_292273046172_item	2330842	et	4	main
konkreetsed	doc_292273046172_item	2330857	et	3	main
vastuseid	doc_292273046172_item	2330858	et	3	main
kohta	doc_292273046172_item	2330867	et	4	main
koostajast	doc_292273046172_item	2330911	et	4	main
ole	doc_292273046172_item	2330915	et	4	main
eesti	doc_292273046172_item	2330819	et	4	main
teatreid	doc_292273046172_item	2330820	et	3	main
mainitud	doc_292273046172_item	2330823	et	4	main
näitlejäid	doc_292273046172_item	2330830	et	4	main
mainisid	doc_292273046172_item	2330831	et	4	main
teatriteadmised	doc_292273046172_item	2330841	et	3	main
vaja	doc_292273046172_item	2330847	et	4	main
päris	doc_292273046172_item	2330855	et	4	main
palju	doc_292273046172_item	2330856	et	4	main
aga	doc_292273046172_item	2330859	et	3	main
kirjutanudjärgnevas	doc_292273046172_item	2330864	et	4	main
olid	doc_292273046172_item	2330868	et	4	main
mõned	doc_292273046172_item	2330872	et	3	main
küsinutest15	doc_292273046172_item	2330905	et	4	main
inimest	doc_292273046172_item	2330906	et	3	main
eesti	doc_292273046172_item	2330907	et	4	main
aabitsast	doc_292273046172_item	2330908	et	4	main
mitte	doc_292273046172_item	2330912	et	3	main
ei	doc_292273046172_item	2330914	et	4	main
teada	doc_292273046172_item	2330919	et	3	main
kirjanikke	doc_292273046172_item	2330924	et	3	main
nimetada	doc_292273046172_item	2330927	et	3	main
erinevaid	doc_292273046172_item	2330930	et	4	main
suhteliselt	doc_292273046172_item	2330941	et	4	main
oma	doc_292273046172_item	2330947	et	4	main
vastuseid	doc_292273046172_item	2330950	et	3	main
aga	doc_292273046172_item	2330953	et	3	main
ei	doc_292273046172_item	2330957	et	4	main
ole	doc_292273046172_item	2330958	et	4	main
23	doc_292273046172_item	2330966	et	2	main
oli	doc_292273046172_item	2330977	et	3	main
balti	doc_292273046172_item	2330978	et	3	main
suunatud	doc_292273046172_item	2331017	et	4	main
riigieksamile	doc_292273046172_item	2331018	et	3	main
on	doc_292273046172_item	2331024	et	4	main
eesti	doc_292273046172_item	2331025	et	4	main
teater	doc_292273046172_item	2331026	et	3	main
aabits	doc_292273046172_item	2331029	et	3	main
eesti	doc_292273046172_item	2331034	et	4	main
kaasaaegne	doc_292273046172_item	2331038	et	3	main
kirjanduskasettpõlvkondtugevad	doc_292273046172_item	2331040	et	4	main
kohad	doc_292273046172_item	2331041	et	4	main
ja	doc_292273046172_item	2331050	et	3	main
kokkuvõte	doc_292273046173_item	2331054	et	3	main
testide	doc_292273046173_item	2331056	et	3	main
õpetajatega	doc_292273046173_item	2331059	et	4	main
määratud	doc_292273046173_item	2331069	et	4	main
ja	doc_292273046173_item	2331094	et	3	main
mis	doc_292273046173_item	2331095	et	4	main
öeldakse	doc_292273046173_item	2331103	et	3	main
arvavad	doc_292273046173_item	2331110	et	4	main
mitmesugusid	doc_292273046173_item	2331129	et	3	main
et	doc_292273046173_item	2331135	et	3	main
oleks	doc_292273046173_item	2331137	et	3	main
rahva	doc_292273046173_item	2331142	et	3	main
ajaloo	doc_292273046173_item	2331152	et	4	main
laulupidu	doc_292273046173_item	2331165	et	4	main
oli	doc_292273046173_item	2331166	et	3	main
ja	doc_292273046173_item	2331167	et	3	main
aga	doc_292273046173_item	2331171	et	3	main
mõtlema	doc_292273046173_item	2331175	et	3	main
et	doc_292273046173_item	2331177	et	3	main
koolilõpetajad	doc_292273046173_item	2331178	et	3	main
oleksid	doc_292273046173_item	2331179	et	4	main
haritud	doc_292273046173_item	2331181	et	4	main
teatreid	doc_292273046172_item	2330825	et	3	main
aga	doc_292273046172_item	2330826	et	3	main
6	doc_292273046172_item	2330833	et	2	main
inimest	doc_292273046172_item	2330834	et	3	main
ole	doc_292273046172_item	2330843	et	4	main
oli	doc_292273046172_item	2330846	et	3	main
nimetada	doc_292273046172_item	2330848	et	3	main
kultuuritegelasi	doc_292273046172_item	2330849	et	3	main
on	doc_292273046172_item	2330851	et	4	main
7	doc_292273046172_item	2330860	et	2	main
kõik	doc_292273046172_item	2330869	et	4	main
õiged	doc_292273046172_item	2330870	et	3	main
aga	doc_292273046172_item	2330873	et	3	main
koidulast	doc_292273046172_item	2330878	et	4	main
olid	doc_292273046172_item	2330879	et	4	main
õigesti	doc_292273046172_item	2330880	et	3	main
vastajaid	doc_292273046172_item	2330881	et	4	main
vähem	doc_292273046172_item	2330882	et	4	main
27	doc_292273046172_item	2330883	et	2	main
30	doc_292273046172_item	2330884	et	2	main
strahvatansu	doc_292273046172_item	2330885	et	4	main
teadsid	doc_292273046172_item	2330886	et	4	main
18	doc_292273046172_item	2330887	et	2	main
õpilast	doc_292273046172_item	2330888	et	4	main
60	doc_292273046172_item	2330889	et	2	main
esimest	doc_292273046172_item	2330890	et	4	main
eesti	doc_292273046172_item	2330891	et	4	main
ajalehe	doc_292273046172_item	2330892	et	3	main
mainisid	doc_292273046172_item	2330894	et	4	main
nime	doc_292273046172_item	2330893	et	4	main
24	doc_292273046172_item	2330895	et	2	main
õpilast	doc_292273046172_item	2330896	et	4	main
ning	doc_292273046172_item	2330897	et	3	main
eesti	doc_292273046172_item	2330898	et	4	main
rahvusärkamisaega	doc_292273046172_item	2330899	et	4	main
algust	doc_292273046172_item	2330900	et	4	main
nimetasid	doc_292273046172_item	2330901	et	4	main
õigesti	doc_292273046172_item	2330902	et	3	main
vaid	doc_292273046172_item	2330903	et	3	main
näitlejaid	doc_292273046172_item	2330821	et	4	main
tallinnas	doc_292273046172_item	2330828	et	4	main
asuvaid	doc_292273046172_item	2330829	et	4	main
lavastusi	doc_292273046172_item	2330836	et	4	main
kirjutasid	doc_292273046172_item	2330837	et	4	main
6	doc_292273046172_item	2330838	et	2	main
eriti	doc_292273046172_item	2330844	et	3	main
paranenudveel	doc_292273046172_item	2330845	et	4	main
kes	doc_292273046172_item	2330850	et	4	main
õpilast	doc_292273046172_item	2330861	et	4	main
eluaastaidlydia	doc_292273046172_item	2330877	et	4	main
ja	doc_292273046172_item	2330909	et	3	main
ma	doc_292273046172_item	2330917	et	3	main
õpilased	doc_292273046172_item	2330925	et	3	main
pakkusid	doc_292273046172_item	2330929	et	4	main
variante	doc_292273046172_item	2330931	et	3	main
küsimus	doc_292273046172_item	2330939	et	4	main
oli	doc_292273046172_item	2330940	et	3	main
vaja	doc_292273046172_item	2330945	et	4	main
kirjutada	doc_292273046172_item	2330946	et	3	main
oli	doc_292273046172_item	2330951	et	3	main
mitte	doc_292273046172_item	2330954	et	3	main
õiget	doc_292273046172_item	2330956	et	3	main
olnudveel	doc_292273046172_item	2330959	et	4	main
õpilaste	doc_292273046172_item	2330962	et	4	main
teadmisest	doc_292273046172_item	2330963	et	4	main
nimetasid	doc_292273046172_item	2330968	et	4	main
ülejäänud	doc_292273046172_item	2330971	et	4	main
küsimus	doc_292273046172_item	2330976	et	4	main
ja	doc_292273046172_item	2330980	et	3	main
st	doc_292273046172_item	2331019	et	3	main
lavastusioli	doc_292273046172_item	2330822	et	4	main
peamiselt	doc_292273046172_item	2330827	et	4	main
inimest	doc_292273046172_item	2330839	et	3	main
seega	doc_292273046172_item	2330840	et	4	main
eesti	doc_292273046172_item	2330852	et	4	main
rahakupüüridel	doc_292273046172_item	2330853	et	3	main
olid	doc_292273046172_item	2330854	et	4	main
pole	doc_292273046172_item	2330862	et	3	main
midagi	doc_292273046172_item	2330863	et	4	main
küsimuses	doc_292273046172_item	2330865	et	4	main
kreutzwaldi	doc_292273046172_item	2330866	et	4	main
vastused	doc_292273046172_item	2330871	et	3	main
isegi	doc_292273046172_item	2330874	et	4	main
nimetasid	doc_292273046172_item	2330875	et	4	main
tema	doc_292273046172_item	2330876	et	4	main
keegi	doc_292273046172_item	2330913	et	4	main
tahtsin	doc_292273046172_item	2330918	et	3	main
et	doc_292273046172_item	2330920	et	3	main
milliseid	doc_292273046172_item	2330921	et	3	main
eesti	doc_292273046172_item	2330923	et	4	main
14	doc_292273046172_item	2330928	et	2	main
16	doc_292273046172_item	2330932	et	2	main
mitte	doc_292273046172_item	2330936	et	3	main
midagi	doc_292273046172_item	2330937	et	4	main
kirjutanudjärgmine	doc_292273046172_item	2330938	et	4	main
nimelt	doc_292273046172_item	2330943	et	4	main
oli	doc_292273046172_item	2330944	et	3	main
kasettpõlvkonnast	doc_292273046172_item	2330949	et	4	main
filme	doc_292273046172_item	2330970	et	3	main
aga	doc_292273046172_item	2330973	et	3	main
ei	doc_292273046172_item	2330974	et	4	main
vastanudviimane	doc_292273046172_item	2330975	et	4	main
kõik	doc_292273046172_item	2331014	et	4	main
keeleõppimisele	doc_292273046172_item	2331020	et	3	main
nõrgad	doc_292273046172_item	2331021	et	3	main
kultuuriteadmises	doc_292273046172_item	2331023	et	3	main
iseseisvuselebalti	doc_292273046172_item	2331035	et	4	main
ning	doc_292273046172_item	2331037	et	3	main
vastamineteadmised	doc_292273046172_item	2331047	et	4	main
kultuuritegelastestkoidulakreutzwaldeesti	doc_292273046172_item	2331048	et	4	main
tantsust	doc_292273046172_item	2331052	et	3	main
peale	doc_292273046173_item	2331055	et	4	main
vestlemist	doc_292273046173_item	2331060	et	4	main
õpilastele	doc_292273046173_item	2331097	et	4	main
silm	doc_292273046173_item	2331106	et	3	main
kuningassamas	doc_292273046173_item	2331108	et	4	main
praktikal	doc_292273046173_item	2331120	et	3	main
ise	doc_292273046173_item	2331127	et	4	main
pidustusi	doc_292273046173_item	2331130	et	3	main
välja	doc_292273046173_item	2331132	et	4	main
kergem	doc_292273046173_item	2331138	et	4	main
aru	doc_292273046173_item	2331139	et	4	main
saada	doc_292273046173_item	2331140	et	4	main
järgi	doc_292273046173_item	2331147	et	4	main
pole	doc_292273046173_item	2331148	et	3	main
õppimiseks	doc_292273046173_item	2331153	et	4	main
me	doc_292273046173_item	2331155	et	4	main
selliseid	doc_292273046173_item	2331157	et	4	main
tulemusi	doc_292273046173_item	2331158	et	4	main
õpilased	doc_292273046173_item	2331160	et	3	main
peavad	doc_292273046173_item	2331172	et	4	main
mõistatusi	doc_292273046173_item	2331230	et	4	main
teemadele	doc_292273046173_item	2331241	et	3	main
ning	doc_292273046173_item	2331242	et	3	main
õpetatakse	doc_292273046173_item	2331244	et	3	main
kirjanikke	doc_292273046173_item	2331247	et	3	main
kaudselt	doc_292273046173_item	2331251	et	4	main
ning	doc_292273046173_item	2331261	et	3	main
raamatute	doc_292273046173_item	2331266	et	3	main
ka	doc_292273046173_item	2331269	et	3	main
keeleõppimisele	doc_292273046173_item	2331281	et	3	main
kontrollitakse	doc_292273046173_item	2331287	et	4	main
mitte	doc_292273046173_item	2331289	et	3	main
ning	doc_292273046173_item	2331291	et	3	main
olukorda	doc_292273046173_item	2331303	et	4	main
eesti	doc_292273046173_item	2331308	et	4	main
kuna	doc_292273046173_item	2331314	et	3	main
korrata	doc_292273046173_item	2331321	et	4	main
vanasamas	doc_292273046173_item	2331323	et	4	main
õpetajad	doc_292273046173_item	2331324	et	4	main
pool	doc_292273046172_item	2330904	et	4	main
selle	doc_292273046172_item	2330910	et	4	main
nimetanudsamas	doc_292273046172_item	2330916	et	4	main
kaasaegseid	doc_292273046172_item	2330922	et	3	main
ei	doc_292273046172_item	2330934	et	4	main
ole	doc_292273046172_item	2330935	et	4	main
raske	doc_292273046172_item	2330942	et	4	main
absurdseid	doc_292273046172_item	2330952	et	3	main
ühtki	doc_292273046172_item	2330955	et	4	main
eesti	doc_292273046172_item	2330964	et	4	main
filmidest	doc_292273046172_item	2330965	et	3	main
mitmesuguseid	doc_292273046172_item	2330969	et	3	main
on	doc_292273046172_item	2331016	et	4	main
viisid	doc_292273046172_item	2331033	et	4	main
eesti	doc_292273046172_item	2331039	et	4	main
eesti	doc_292273046172_item	2331044	et	4	main
vanasõnade	doc_292273046172_item	2331045	et	3	main
teadminemõistatustele	doc_292273046172_item	2331046	et	4	main
eesti	doc_292273046172_item	2331051	et	4	main
analüüsimist	doc_292273046173_item	2331057	et	4	main
ma	doc_292273046173_item	2331061	et	3	main
tulin	doc_292273046173_item	2331062	et	3	main
et	doc_292273046173_item	2331064	et	3	main
eesti	doc_292273046173_item	2331066	et	4	main
nagu	doc_292273046173_item	2331102	et	3	main
oma	doc_292273046173_item	2331105	et	4	main
on	doc_292273046173_item	2331107	et	4	main
et	doc_292273046173_item	2331111	et	3	main
väga	doc_292273046173_item	2331114	et	3	main
aega	doc_292273046173_item	2331116	et	4	main
oma	doc_292273046173_item	2331122	et	4	main
ning	doc_292273046173_item	2331124	et	3	main
koolid	doc_292273046173_item	2331125	et	3	main
selleks	doc_292273046173_item	2331134	et	4	main
lastel	doc_292273046173_item	2331136	et	4	main
näiteks	doc_292273046173_item	2331144	et	4	main
eesti	doc_292273046173_item	2331151	et	4	main
et	doc_292273046173_item	2331159	et	3	main
kui	doc_292273046173_item	2331168	et	3	main
peetaksekoolid	doc_292273046173_item	2331170	et	4	main
midagi	doc_292273046173_item	2331176	et	4	main
ikka	doc_292273046173_item	2331180	et	4	main
seega	doc_292273046173_item	2331183	et	4	main
seda	doc_292273046173_item	2331220	et	3	main
mis	doc_292273046173_item	2331221	et	4	main
juba	doc_292273046173_item	2331223	et	3	main
õpivad	doc_292273046173_item	2331227	et	3	main
tundma	doc_292273046173_item	2331228	et	3	main
läbivatele	doc_292273046173_item	2331240	et	4	main
õpetatakse	doc_292273046173_item	2331249	et	3	main
on	doc_292273046173_item	2331254	et	4	main
aegaõpetajad	doc_292273046173_item	2331257	et	3	main
peavad	doc_292273046173_item	2331258	et	4	main
koostööd	doc_292273046173_item	2331260	et	4	main
eesti	doc_292273046173_item	2331262	et	4	main
keele	doc_292273046173_item	2331263	et	4	main
tunnis	doc_292273046173_item	2331264	et	3	main
tunnisloetakse	doc_292273046173_item	2331271	et	4	main
ainuld	doc_292273046173_item	2331272	et	4	main
on	doc_292273046173_item	2331279	et	4	main
kus	doc_292273046173_item	2331286	et	3	main
35-tunniline	doc_292273046173_item	2331306	et	4	main
oskavad	doc_292273046172_item	2330926	et	4	main
aga	doc_292273046172_item	2330933	et	3	main
teadmisi	doc_292273046172_item	2330948	et	4	main
ma	doc_292273046172_item	2330960	et	3	main
küsisin	doc_292273046172_item	2330961	et	3	main
õpilast76	doc_292273046172_item	2330967	et	4	main
7	doc_292273046172_item	2330972	et	2	main
ketist	doc_292273046172_item	2330979	et	3	main
ma	doc_292273046172_item	2330981	et	3	main
palusin	doc_292273046172_item	2330982	et	3	main
kirjutada	doc_292273046172_item	2330983	et	3	main
oma	doc_292273046172_item	2330984	et	4	main
teadmisi	doc_292273046172_item	2330985	et	4	main
tollast	doc_292273046172_item	2330986	et	3	main
ajast	doc_292273046172_item	2330987	et	4	main
tulemused	doc_292273046172_item	2330988	et	3	main
olid	doc_292273046172_item	2330989	et	4	main
järgmised13	doc_292273046172_item	2330990	et	3	main
ole	doc_292273046172_item	2330992	et	4	main
ei	doc_292273046172_item	2330991	et	4	main
midagi	doc_292273046172_item	2330993	et	4	main
kirjutanud16	doc_292273046172_item	2330994	et	4	main
kirjutasid	doc_292273046172_item	2330995	et	4	main
ainult	doc_292273046172_item	2330996	et	4	main
kuupäeva	doc_292273046172_item	2330997	et	4	main
ja	doc_292273046172_item	2330998	et	3	main
ainult	doc_292273046172_item	2330999	et	4	main
4	doc_292273046172_item	2331000	et	2	main
kirjutasid	doc_292273046172_item	2331001	et	4	main
lisaandmed	doc_292273046172_item	2331002	et	3	main
üldiselt	doc_292273046172_item	2331003	et	4	main
on	doc_292273046172_item	2331004	et	4	main
teadmised	doc_292273046172_item	2331005	et	4	main
kultuuriloost	doc_292273046172_item	2331006	et	4	main
11klassi	doc_292273046172_item	2331007	et	4	main
jaoks	doc_292273046172_item	2331008	et	4	main
keskmisest	doc_292273046172_item	2331009	et	3	main
madalamal	doc_292273046172_item	2331010	et	4	main
tasandilkuna	doc_292273046172_item	2331011	et	4	main
sel	doc_292273046172_item	2331012	et	3	main
õppeastmel	doc_292273046172_item	2331013	et	3	main
tähelepanu	doc_292273046172_item	2331015	et	4	main
kohad	doc_292273046172_item	2331022	et	4	main
sündmused	doc_292273046172_item	2331031	et	3	main
on	doc_292273046172_item	2331042	et	4	main
aga	doc_292273046172_item	2331043	et	3	main
ajalehest	doc_292273046172_item	2331049	et	4	main
ja	doc_292273046173_item	2331058	et	3	main
järeldusele	doc_292273046173_item	2331063	et	4	main
õppekavas	doc_292273046173_item	2331065	et	3	main
kultuurile	doc_292273046173_item	2331067	et	3	main
pakub	doc_292273046173_item	2331096	et	3	main
et	doc_292273046173_item	2331104	et	3	main
õppekavas	doc_292273046173_item	2331112	et	3	main
vähe	doc_292273046173_item	2331115	et	3	main
jäetud	doc_292273046173_item	2331117	et	4	main
selleks	doc_292273046173_item	2331118	et	4	main
et	doc_292273046173_item	2331119	et	3	main
eesti	doc_292273046172_item	2331027	et	4	main
esimene	doc_292273046172_item	2331028	et	3	main
ning	doc_292273046172_item	2331030	et	3	main
mis	doc_292273046172_item	2331032	et	4	main
kett	doc_292273046172_item	2331036	et	4	main
seminaritöö	doc_292273046173_item	2331053	et	4	main
õppimiseks	doc_292273046173_item	2331068	et	4	main
aeg	doc_292273046173_item	2331070	et	3	main
on	doc_292273046173_item	2331071	et	4	main
väga	doc_292273046173_item	2331072	et	3	main
õpetajate	doc_292273046173_item	2331074	et	4	main
arvates	doc_292273046173_item	2331075	et	4	main
lühike	doc_292273046173_item	2331073	et	4	main
ei	doc_292273046173_item	2331076	et	4	main
piisa	doc_292273046173_item	2331077	et	4	main
õppekavas	doc_292273046173_item	2331078	et	3	main
tunde	doc_292273046173_item	2331079	et	4	main
selleks	doc_292273046173_item	2331080	et	4	main
et	doc_292273046173_item	2331081	et	3	main
õpetada	doc_292273046173_item	2331082	et	3	main
põhjalikult	doc_292273046173_item	2331083	et	4	main
kultuuri	doc_292273046173_item	2331084	et	4	main
ei	doc_292273046173_item	2331085	et	4	main
piisavalt	doc_292273046173_item	2331087	et	4	main
ole	doc_292273046173_item	2331086	et	4	main
audio	doc_292273046173_item	2331088	et	4	main
ja	doc_292273046173_item	2331089	et	3	main
videomaterjali	doc_292273046173_item	2331090	et	4	main
mida	doc_292273046173_item	2331091	et	4	main
võiks	doc_292273046173_item	2331092	et	4	main
näidata	doc_292273046173_item	2331093	et	4	main
rohkem	doc_292273046173_item	2331098	et	4	main
huvi	doc_292273046173_item	2331099	et	4	main
kui	doc_292273046173_item	2331100	et	3	main
õpikud	doc_292273046173_item	2331101	et	3	main
õpetajad	doc_292273046173_item	2331109	et	4	main
on	doc_292273046173_item	2331113	et	4	main
rakendada	doc_292273046173_item	2331121	et	3	main
teadmisi	doc_292273046173_item	2331123	et	4	main
peavad	doc_292273046173_item	2331126	et	4	main
mõtlema	doc_292273046173_item	2331133	et	3	main
eesti	doc_292273046173_item	2331141	et	4	main
aega	doc_292273046173_item	2331149	et	4	main
ei	doc_292273046173_item	2331161	et	4	main
tea	doc_292273046173_item	2331162	et	4	main
millal	doc_292273046173_item	2331163	et	3	main
see	doc_292273046173_item	2331164	et	3	main
tihti	doc_292273046173_item	2331169	et	3	main
välja	doc_292273046173_item	2331174	et	4	main
viiendas	doc_292273046173_item	2331184	et	3	main
vanasõnu	doc_292273046173_item	2331229	et	3	main
rahvapärimust	doc_292273046173_item	2331243	et	4	main
väga	doc_292273046173_item	2331250	et	3	main
tutvutud	doc_292273046173_item	2331265	et	4	main
ning	doc_292273046173_item	2331275	et	3	main
suunatud	doc_292273046173_item	2331280	et	4	main
on	doc_292273046173_item	2331284	et	4	main
õpetajad	doc_292273046173_item	2331292	et	4	main
näitama	doc_292273046173_item	2331294	et	3	main
parimaid	doc_292273046173_item	2331295	et	4	main
samuti	doc_292273046173_item	2331297	et	3	main
tähelepanu	doc_292273046173_item	2331299	et	4	main
on	doc_292273046173_item	2331300	et	4	main
peaks	doc_292273046173_item	2331304	et	4	main
aga	doc_292273046173_item	2331310	et	3	main
teatritesüldiselt	doc_292273046173_item	2331333	et	4	main
ei	doc_292273046173_item	2331335	et	4	main
mitte	doc_292273046173_item	2331349	et	3	main
piisav	doc_292273046173_item	2331358	et	4	main
ei	doc_292273046173_item	2331371	et	4	main
tasemel	doc_292273046173_item	2331374	et	3	main
nad	doc_292273046173_item	2331376	et	3	main
selline	doc_292273046173_item	2331380	et	4	main
oskavad	doc_292273046173_item	2331390	et	4	main
keelt	doc_292273046173_item	2331420	et	4	main
alles	doc_292273046173_item	2331421	et	3	main
mingit	doc_292273046173_item	2331427	et	3	main
vabandust	doc_292273046173_item	2331428	et	4	main
neid	doc_292273046173_item	2331437	et	4	main
nende	doc_292273046173_item	2331442	et	4	main
eesti	doc_292273046173_item	2331444	et	4	main
saab	doc_292273046173_item	2331451	et	3	main
kasutada	doc_292273046173_item	2331452	et	3	main
sellest	doc_292273046173_item	2331472	et	4	main
muutused	doc_292273046173_item	2331482	et	4	main
termin	doc_292273046173_item	2331487	et	3	main
juba	doc_292273046173_item	2331489	et	3	main
arvamustega	doc_292273046173_item	2331495	et	3	main
oma	doc_292273046173_item	2331498	et	4	main
on	doc_292273046173_item	2331507	et	4	main
töötan	doc_292273046174_item	2331514	et	3	main
on	doc_292273046174_item	2331517	et	4	main
on	doc_292273046174_item	2331521	et	4	main
juulis	doc_292273046174_item	2331523	et	3	main
juurde	doc_292273046174_item	2331542	et	4	main
emaga	doc_292273046174_item	2331552	et	3	main
suvi	doc_292273046174_item	2331560	et	3	main
mina	doc_292273046174_item	2331563	et	4	main
sinna	doc_292273046174_item	2331568	et	3	main
tagasi	doc_292273046174_item	2331570	et	3	main
käin	doc_292273046174_item	2331573	et	3	main
ära	doc_292273046174_item	2331580	et	4	main
ümber	doc_292273046174_item	2331581	et	3	main
ja	doc_292273046174_item	2331589	et	3	main
suvel	doc_292273046174_item	2331593	et	3	main
päevitan	doc_292273046174_item	2331595	et	3	main
hästi	doc_292273046174_item	2331597	et	3	main
töötan	doc_292273046174_item	2331600	et	3	main
kahju	doc_292273046174_item	2331603	et	4	main
et	doc_292273046174_item	2331604	et	3	main
korraldama	doc_292273046173_item	2331128	et	3	main
ja	doc_292273046173_item	2331131	et	3	main
kultuurist	doc_292273046173_item	2331143	et	3	main
5klassi	doc_292273046173_item	2331145	et	4	main
riigiõppekava	doc_292273046173_item	2331146	et	4	main
jäetud	doc_292273046173_item	2331150	et	4	main
seega	doc_292273046173_item	2331154	et	4	main
saame	doc_292273046173_item	2331156	et	4	main
ise	doc_292273046173_item	2331173	et	4	main
inimesed	doc_292273046173_item	2331182	et	3	main
klassis	doc_292273046173_item	2331185	et	3	main
on	doc_292273046173_item	2331186	et	4	main
eesti	doc_292273046173_item	2331187	et	4	main
ajaloo	doc_292273046173_item	2331188	et	4	main
kursus	doc_292273046173_item	2331189	et	3	main
ning	doc_292273046173_item	2331190	et	3	main
tallinna	doc_292273046173_item	2331191	et	4	main
õismäe	doc_292273046173_item	2331192	et	3	main
vene	doc_292273046173_item	2331193	et	4	main
lütseumis	doc_292273046173_item	2331194	et	3	main
on	doc_292273046173_item	2331195	et	4	main
5	doc_292273046173_item	2331196	et	2	main
klassi	doc_292273046173_item	2331197	et	4	main
ajalootunnid	doc_292273046173_item	2331198	et	3	main
eesti	doc_292273046173_item	2331199	et	4	main
keeles	doc_292273046173_item	2331200	et	4	main
ja	doc_292273046173_item	2331201	et	3	main
et	doc_292273046173_item	2331202	et	3	main
õpilased	doc_292273046173_item	2331203	et	3	main
saaksid	doc_292273046173_item	2331204	et	4	main
paremaid	doc_292273046173_item	2331205	et	4	main
teadmisi	doc_292273046173_item	2331206	et	4	main
on	doc_292273046173_item	2331207	et	4	main
klass	doc_292273046173_item	2331208	et	3	main
2	doc_292273046173_item	2331209	et	2	main
rühmaks	doc_292273046173_item	2331210	et	4	main
jagatud	doc_292273046173_item	2331211	et	4	main
kuna	doc_292273046173_item	2331212	et	3	main
ei	doc_292273046173_item	2331213	et	4	main
ole	doc_292273046173_item	2331214	et	4	main
süstemmatiliselt	doc_292273046173_item	2331215	et	4	main
kultuuriõppimist	doc_292273046173_item	2331216	et	3	main
õpilased	doc_292273046173_item	2331217	et	3	main
sageli	doc_292273046173_item	2331218	et	3	main
unustavad	doc_292273046173_item	2331219	et	4	main
omandasid	doc_292273046173_item	2331222	et	4	main
algklassides	doc_292273046173_item	2331224	et	3	main
6klassis	doc_292273046173_item	2331225	et	3	main
kuid	doc_292273046173_item	2331232	et	4	main
on	doc_292273046173_item	2331234	et	4	main
mööda	doc_292273046173_item	2331245	et	4	main
minnes	doc_292273046173_item	2331246	et	3	main
tegema	doc_292273046173_item	2331259	et	3	main
tegelastega	doc_292273046173_item	2331267	et	3	main
emakeele	doc_292273046173_item	2331270	et	4	main
katkendeid	doc_292273046173_item	2331273	et	3	main
raamatutest	doc_292273046173_item	2331274	et	4	main
kuna	doc_292273046173_item	2331282	et	3	main
ees	doc_292273046173_item	2331283	et	4	main
põhikoolieksam	doc_292273046173_item	2331285	et	3	main
pööratud	doc_292273046173_item	2331301	et	4	main
riigieksamile	doc_292273046173_item	2331302	et	3	main
kultuurist	doc_292273046173_item	2331309	et	3	main
on	doc_292273046173_item	2331312	et	4	main
vähe	doc_292273046173_item	2331313	et	3	main
kursusel	doc_292273046173_item	2331316	et	3	main
tuleb	doc_292273046173_item	2331317	et	3	main
peale	doc_292273046173_item	2331318	et	4	main
uut	doc_292273046173_item	2331319	et	3	main
materjali	doc_292273046173_item	2331320	et	4	main
kirjanikke	doc_292273046173_item	2331328	et	3	main
käiakse	doc_292273046173_item	2331330	et	3	main
rahul	doc_292273046173_item	2331337	et	4	main
uus	doc_292273046173_item	2331343	et	3	main
õpilaste	doc_292273046173_item	2331352	et	4	main
arvates	doc_292273046173_item	2331353	et	4	main
tahaksid	doc_292273046173_item	2331361	et	4	main
teadmised	doc_292273046173_item	2331369	et	4	main
vestelda	doc_292273046173_item	2331385	et	4	main
eesti	doc_292273046173_item	2331391	et	4	main
midagi	doc_292273046173_item	2331397	et	4	main
keeleõppimine	doc_292273046173_item	2331409	et	3	main
keele	doc_292273046173_item	2331411	et	4	main
on	doc_292273046173_item	2331413	et	4	main
ebapiisavad	doc_292273046173_item	2331414	et	3	main
saab	doc_292273046173_item	2331415	et	3	main
seda	doc_292273046173_item	2331416	et	3	main
põhjendada	doc_292273046173_item	2331417	et	3	main
sellega	doc_292273046173_item	2331418	et	3	main
et	doc_292273046173_item	2331419	et	3	main
õpilased	doc_292273046173_item	2331226	et	3	main
kõnekäände	doc_292273046173_item	2331231	et	4	main
ikkagi	doc_292273046173_item	2331233	et	4	main
suurem	doc_292273046173_item	2331235	et	4	main
rõhk	doc_292273046173_item	2331236	et	3	main
pandud	doc_292273046173_item	2331237	et	4	main
grammatikale	doc_292273046173_item	2331238	et	3	main
ja	doc_292273046173_item	2331239	et	3	main
loomingust	doc_292273046173_item	2331248	et	3	main
kuna	doc_292273046173_item	2331252	et	3	main
sellele	doc_292273046173_item	2331253	et	4	main
väga	doc_292273046173_item	2331255	et	3	main
vähe	doc_292273046173_item	2331256	et	3	main
tutvutakse	doc_292273046173_item	2331268	et	3	main
terve	doc_292273046173_item	2331276	et	4	main
9klassi	doc_292273046173_item	2331277	et	4	main
õppeaeg	doc_292273046173_item	2331278	et	3	main
grammatikat	doc_292273046173_item	2331288	et	3	main
rahvapärimuseteadmisi	doc_292273046173_item	2331290	et	4	main
peavad	doc_292273046173_item	2331293	et	4	main
tulemusigümnaasiumiastmes	doc_292273046173_item	2331296	et	3	main
kõik	doc_292273046173_item	2331298	et	4	main
parandama	doc_292273046173_item	2331305	et	3	main
kurss	doc_292273046173_item	2331307	et	3	main
seda	doc_292273046173_item	2331311	et	3	main
sel	doc_292273046173_item	2331315	et	3	main
ka	doc_292273046173_item	2331322	et	3	main
ekskursioonidel	doc_292273046173_item	2331331	et	3	main
praeguse	doc_292273046173_item	2331338	et	3	main
ja	doc_292273046173_item	2331340	et	3	main
et	doc_292273046173_item	2331342	et	3	main
õppekava	doc_292273046173_item	2331344	et	4	main
annab	doc_292273046173_item	2331345	et	3	main
neile	doc_292273046173_item	2331346	et	4	main
ainult	doc_292273046173_item	2331350	et	4	main
keeleõppimiseks	doc_292273046173_item	2331351	et	3	main
paljud	doc_292273046173_item	2331359	et	3	main
arvates	doc_292273046173_item	2331367	et	4	main
nende	doc_292273046173_item	2331368	et	4	main
kõrgel	doc_292273046173_item	2331373	et	4	main
tekib	doc_292273046173_item	2331379	et	3	main
situatsioon	doc_292273046173_item	2331381	et	3	main
et	doc_292273046173_item	2331382	et	3	main
neil	doc_292273046173_item	2331383	et	4	main
tuleb	doc_292273046173_item	2331384	et	3	main
nad	doc_292273046173_item	2331389	et	3	main
keelt	doc_292273046173_item	2331392	et	4	main
ei	doc_292273046173_item	2331394	et	4	main
oska	doc_292273046173_item	2331395	et	4	main
mitte	doc_292273046173_item	2331396	et	3	main
leidaõpilastega	doc_292273046173_item	2331429	et	4	main
vesteldes	doc_292273046173_item	2331430	et	3	main
ma	doc_292273046173_item	2331431	et	3	main
sain	doc_292273046173_item	2331432	et	3	main
teada	doc_292273046173_item	2331433	et	3	main
huvitavad	doc_292273046173_item	2331438	et	4	main
looming	doc_292273046173_item	2331443	et	3	main
filmid	doc_292273046173_item	2331445	et	4	main
eesti	doc_292273046173_item	2331446	et	4	main
vanasõnad	doc_292273046173_item	2331447	et	3	main
ja	doc_292273046173_item	2331448	et	3	main
tihti	doc_292273046173_item	2331466	et	3	main
kasutatakse	doc_292273046173_item	2331467	et	3	main
ausalt	doc_292273046173_item	2331468	et	4	main
öeldes	doc_292273046173_item	2331469	et	3	main
sain	doc_292273046173_item	2331471	et	3	main
loodameet	doc_292273046173_item	2331478	et	4	main
lastele	doc_292273046173_item	2331484	et	4	main
järeldustega	doc_292273046173_item	2331492	et	4	main
testideanalüüsidega	doc_292273046173_item	2331493	et	4	main
ma	doc_292273046173_item	2331496	et	3	main
et	doc_292273046173_item	2331502	et	3	main
õppimiseks	doc_292273046173_item	2331504	et	4	main
jäetud	doc_292273046173_item	2331509	et	4	main
ma	doc_292273046174_item	2331513	et	3	main
kutsuvad	doc_292273046173_item	2331325	et	4	main
eesti	doc_292273046173_item	2331327	et	4	main
näitlejaid	doc_292273046173_item	2331329	et	4	main
õpetajad	doc_292273046173_item	2331334	et	4	main
õppekavaga	doc_292273046173_item	2331339	et	3	main
loodavad	doc_292273046173_item	2331341	et	4	main
rohkem	doc_292273046173_item	2331347	et	4	main
võimalusi	doc_292273046173_item	2331348	et	3	main
kultuuriõppimine	doc_292273046173_item	2331356	et	3	main
pole	doc_292273046173_item	2331357	et	3	main
õpilased	doc_292273046173_item	2331360	et	3	main
rohkem	doc_292273046173_item	2331362	et	4	main
õppida	doc_292273046173_item	2331363	et	3	main
kultuuri	doc_292273046173_item	2331364	et	4	main
kuna	doc_292273046173_item	2331365	et	3	main
nende	doc_292273046173_item	2331366	et	4	main
ole	doc_292273046173_item	2331372	et	4	main
ja	doc_292273046173_item	2331375	et	3	main
kardavad	doc_292273046173_item	2331377	et	4	main
samas	doc_292273046173_item	2331388	et	4	main
aga	doc_292273046173_item	2331393	et	3	main
nende	doc_292273046173_item	2331401	et	4	main
arvates	doc_292273046173_item	2331402	et	4	main
kultuuriteadmine	doc_292273046173_item	2331403	et	3	main
on	doc_292273046173_item	2331404	et	4	main
samal	doc_292273046173_item	2331405	et	3	main
tähtsal	doc_292273046173_item	2331406	et	3	main
tasemel	doc_292273046173_item	2331407	et	3	main
kui	doc_292273046173_item	2331408	et	3	main
saa	doc_292273046173_item	2331426	et	4	main
eesti	doc_292273046173_item	2331440	et	4	main
mida	doc_292273046173_item	2331450	et	4	main
terminkasettpõlvkond	doc_292273046173_item	2331463	et	4	main
terminist	doc_292273046173_item	2331473	et	3	main
teada	doc_292273046173_item	2331474	et	3	main
ainult	doc_292273046173_item	2331475	et	4	main
järgmises	doc_292273046173_item	2331479	et	3	main
tulevad	doc_292273046173_item	2331481	et	4	main
ning	doc_292273046173_item	2331483	et	3	main
töös	doc_292273046173_item	2331499	et	3	main
ja	doc_292273046173_item	2331505	et	3	main
õpetamiseks	doc_292273046173_item	2331506	et	4	main
vähe	doc_292273046173_item	2331510	et	3	main
tavaliselt	doc_292273046174_item	2331519	et	4	main
see	doc_292273046174_item	2331520	et	3	main
suvel	doc_292273046174_item	2331522	et	3	main
ma	doc_292273046174_item	2331527	et	3	main
käisin	doc_292273046174_item	2331528	et	3	main
juures	doc_292273046174_item	2331530	et	4	main
tuli	doc_292273046174_item	2331540	et	4	main
mul	doc_292273046174_item	2331544	et	3	main
terve	doc_292273046174_item	2331559	et	4	main
päev	doc_292273046174_item	2331567	et	3	main
palju	doc_292273046174_item	2331587	et	4	main
meldib	doc_292273046174_item	2331592	et	4	main
ma	doc_292273046174_item	2331594	et	3	main
väga	doc_292273046174_item	2331596	et	3	main
ma	doc_292273046174_item	2331599	et	3	main
mööda	doc_292273046174_item	2331608	et	4	main
et	doc_292273046175_item	2331634	et	3	main
rägivad	doc_292273046175_item	2331648	et	4	main
armastab	doc_292273046175_item	2331651	et	3	main
tal	doc_292273046175_item	2331662	et	3	main
ta	doc_292273046175_item	2331666	et	4	main
õpib	doc_292273046175_item	2331667	et	3	main
lastepsühholoogiat	doc_292273046175_item	2331668	et	3	main
ew	doc_292273046176_item	2331674	et	4	main
milliseid	doc_292273046176_item	2331677	et	3	main
tõi	doc_292273046176_item	2331679	et	3	main
tähendas	doc_292273046176_item	2331686	et	3	main
aasta	doc_292273046176_item	2331694	et	4	main
albumit	doc_292273046176_item	2331722	et	3	main
oli	doc_292273046176_item	2331725	et	3	main
eesti	doc_292273046176_item	2331727	et	4	main
vabariigi	doc_292273046176_item	2331728	et	3	main
haridustingimused	doc_292273046176_item	2331738	et	3	main
tekis	doc_292273046176_item	2331739	et	3	main
inimesi	doc_292273046176_item	2331745	et	4	main
munderi	doc_292273046176_item	2331760	et	3	main
raamatuid	doc_292273046176_item	2331770	et	3	main
ilmusid	doc_292273046176_item	2331771	et	4	main
kooli	doc_292273046173_item	2331326	et	4	main
näitustel	doc_292273046173_item	2331332	et	4	main
ole	doc_292273046173_item	2331336	et	4	main
on	doc_292273046173_item	2331354	et	4	main
samuti	doc_292273046173_item	2331355	et	3	main
kultuuris	doc_292273046173_item	2331370	et	3	main
et	doc_292273046173_item	2331378	et	3	main
eesti	doc_292273046173_item	2331386	et	4	main
kultuurist	doc_292273046173_item	2331387	et	3	main
öelda	doc_292273046173_item	2331398	et	4	main
kultuurist	doc_292273046173_item	2331399	et	3	main
samuti	doc_292273046173_item	2331400	et	3	main
kui	doc_292273046173_item	2331410	et	3	main
teadmised	doc_292273046173_item	2331412	et	4	main
kuid	doc_292273046173_item	2331423	et	4	main
kultuuriteadmistepuudulikkusele	doc_292273046173_item	2331424	et	4	main
ei	doc_292273046173_item	2331425	et	4	main
et	doc_292273046173_item	2331434	et	3	main
rohkem	doc_292273046173_item	2331436	et	4	main
kirjanikud	doc_292273046173_item	2331441	et	3	main
ma	doc_292273046173_item	2331470	et	3	main
ülikoolis	doc_292273046173_item	2331476	et	4	main
õppekavas	doc_292273046173_item	2331480	et	3	main
saab	doc_292273046173_item	2331485	et	3	main
arusaadavaks	doc_292273046173_item	2331488	et	4	main
selliste	doc_292273046173_item	2331491	et	4	main
hüpoteesi	doc_292273046173_item	2331501	et	4	main
riigiõõpekavas	doc_292273046173_item	2331508	et	4	main
varem	doc_292273046174_item	2331526	et	4	main
lahedal	doc_292273046174_item	2331535	et	3	main
sellel	doc_292273046174_item	2331536	et	4	main
astal	doc_292273046174_item	2331537	et	4	main
minu	doc_292273046174_item	2331538	et	3	main
ema	doc_292273046174_item	2331539	et	4	main
suvila	doc_292273046174_item	2331546	et	4	main
narvast	doc_292273046174_item	2331551	et	4	main
elab	doc_292273046174_item	2331558	et	3	main
sõidan	doc_292273046174_item	2331564	et	3	main
vesi	doc_292273046174_item	2331577	et	4	main
võttab	doc_292273046174_item	2331578	et	4	main
väsimust	doc_292273046174_item	2331579	et	4	main
seal	doc_292273046174_item	2331585	et	4	main
on	doc_292273046174_item	2331586	et	4	main
mulle	doc_292273046174_item	2331591	et	4	main
sest	doc_292273046174_item	2331598	et	4	main
päikese	doc_292273046174_item	2331601	et	4	main
all	doc_292273046174_item	2331602	et	3	main
suvi	doc_292273046174_item	2331605	et	3	main
töid	doc_292273046175_item	2331627	et	3	main
koolis	doc_292273046175_item	2331630	et	4	main
heameelega	doc_292273046175_item	2331631	et	3	main
maitseaine	doc_292273046175_item	2331639	et	4	main
selle	doc_292273046175_item	2331646	et	4	main
laise	doc_292273046175_item	2331647	et	4	main
koolilastel	doc_292273046175_item	2331656	et	4	main
veel	doc_292273046175_item	2331658	et	4	main
sõbrad	doc_292273046175_item	2331661	et	3	main
kirjanduselu	doc_292273046176_item	2331675	et	4	main
mida	doc_292273046176_item	2331685	et	4	main
maailmasõda	doc_292273046176_item	2331688	et	4	main
1	doc_292273046176_item	2331691	et	2	main
pärast	doc_292273046176_item	2331692	et	4	main
1905	doc_292273046176_item	2331693	et	2	main
arenema	doc_292273046176_item	2331699	et	3	main
see	doc_292273046176_item	2331724	et	3	main
enne	doc_292273046176_item	2331726	et	4	main
iseseisvust	doc_292273046176_item	2331729	et	4	main
aga	doc_292273046176_item	2331730	et	3	main
seda	doc_292273046176_item	2331732	et	3	main
iseseisvust	doc_292273046176_item	2331736	et	4	main
haritlaskond	doc_292273046176_item	2331740	et	3	main
ilmus	doc_292273046176_item	2331742	et	4	main
ja	doc_292273046176_item	2331752	et	3	main
väga	doc_292273046176_item	2331754	et	3	main
populaarne	doc_292273046176_item	2331755	et	3	main
oli	doc_292273046176_item	2331756	et	3	main
ka	doc_292273046176_item	2331757	et	3	main
luule	doc_292273046176_item	2331758	et	4	main
ka	doc_292273046176_item	2331772	et	3	main
ajaloos	doc_292273046176_item	2331779	et	4	main
millal	doc_292273046176_item	2331780	et	3	main
õppitakse	doc_292273046173_item	2331422	et	4	main
kõige	doc_292273046173_item	2331435	et	4	main
kaasaaegsed	doc_292273046173_item	2331439	et	3	main
mõistatused	doc_292273046173_item	2331449	et	4	main
igas	doc_292273046173_item	2331453	et	3	main
situatsioonis	doc_292273046173_item	2331454	et	3	main
ja	doc_292273046173_item	2331455	et	3	main
rikastada	doc_292273046173_item	2331456	et	3	main
oma	doc_292273046173_item	2331457	et	4	main
kõne	doc_292273046173_item	2331458	et	4	main
sams	doc_292273046173_item	2331459	et	4	main
neid	doc_292273046173_item	2331460	et	4	main
huvitas	doc_292273046173_item	2331461	et	3	main
selline	doc_292273046173_item	2331462	et	4	main
mida	doc_292273046173_item	2331464	et	4	main
päris	doc_292273046173_item	2331465	et	4	main
aga	doc_292273046173_item	2331477	et	3	main
see	doc_292273046173_item	2331486	et	3	main
koolis	doc_292273046173_item	2331490	et	4	main
õpetajate	doc_292273046173_item	2331494	et	4	main
tõestasin	doc_292273046173_item	2331497	et	3	main
pandnud	doc_292273046173_item	2331500	et	4	main
rahvuspärimuse	doc_292273046173_item	2331503	et	3	main
aega	doc_292273046173_item	2331511	et	4	main
kiri	doc_292273046174_item	2331512	et	3	main
koolis	doc_292273046174_item	2331515	et	4	main
mul	doc_292273046174_item	2331516	et	3	main
suvipuhkeajag	doc_292273046174_item	2331518	et	4	main
ja	doc_292273046174_item	2331524	et	3	main
elama	doc_292273046174_item	2331543	et	3	main
on	doc_292273046174_item	2331545	et	4	main
ta	doc_292273046174_item	2331547	et	4	main
11	doc_292273046174_item	2331549	et	2	main
km	doc_292273046174_item	2331550	et	4	main
ema	doc_292273046174_item	2331557	et	4	main
aga	doc_292273046174_item	2331562	et	3	main
iga	doc_292273046174_item	2331566	et	4	main
ma	doc_292273046174_item	2331572	et	3	main
ujuma	doc_292273046174_item	2331574	et	3	main
karjaaris	doc_292273046174_item	2331576	et	4	main
suvila	doc_292273046174_item	2331582	et	4	main
tööd	doc_292273046174_item	2331588	et	4	main
läheb	doc_292273046174_item	2331606	et	3	main
ta	doc_292273046175_item	2331632	et	4	main
töö	doc_292273046175_item	2331635	et	4	main
ainult	doc_292273046175_item	2331637	et	4	main
on	doc_292273046175_item	2331657	et	4	main
on	doc_292273046175_item	2331663	et	4	main
haridus	doc_292273046175_item	2331665	et	3	main
ainemetoodikat	doc_292273046175_item	2331669	et	3	main
pedagoogikat	doc_292273046175_item	2331670	et	3	main
kontrolltöö	doc_292273046176_item	2331671	et	4	main
1	doc_292273046176_item	2331672	et	2	main
pärastsõjajärgne	doc_292273046176_item	2331680	et	3	main
3	doc_292273046176_item	2331684	et	2	main
ilmus	doc_292273046176_item	2331700	et	4	main
eesti	doc_292273046176_item	2331703	et	4	main
kui	doc_292273046176_item	2331733	et	3	main
sai	doc_292273046176_item	2331735	et	4	main
palju	doc_292273046176_item	2331743	et	4	main
nt	doc_292273046176_item	2331759	et	4	main
looming	doc_292273046176_item	2331761	et	3	main
arenema	doc_292273046176_item	2331763	et	3	main
proosa	doc_292273046176_item	2331765	et	4	main
välja	doc_292273046176_item	2331767	et	4	main
sõnastikud	doc_292273046176_item	2331773	et	3	main
eesti	doc_292273046176_item	2331778	et	4	main
hävitama	doc_292273046176_item	2331787	et	4	main
meeldinud	doc_292273046176_item	2331792	et	4	main
ja	doc_292273046176_item	2331794	et	3	main
pärastsõjajärgne	doc_292273046176_item	2331798	et	3	main
tõi	doc_292273046176_item	2331800	et	3	main
kaasa	doc_292273046176_item	2331801	et	4	main
palju	doc_292273046176_item	2331802	et	4	main
talupoegadet	doc_292273046176_item	2331807	et	4	main
ületasid	doc_292273046176_item	2331813	et	4	main
sovhoose	doc_292273046176_item	2331819	et	3	main
massiline	doc_292273046176_item	2331821	et	4	main
kus	doc_292273046176_item	2331823	et	3	main
küüditatuid	doc_292273046176_item	2331824	et	4	main
vanad	doc_292273046176_item	2331830	et	3	main
seda	doc_292273046176_item	2331838	et	3	main
liituma	doc_292273046176_item	2331842	et	4	main
mitu	doc_292273046176_item	2331851	et	4	main
ise	doc_292273046176_item	2331861	et	4	main
otsustada	doc_292273046176_item	2331862	et	3	main
seda	doc_292273046176_item	2331874	et	3	main
ei	doc_292273046176_item	2331876	et	4	main
ii	doc_292273046176_item	2331878	et	4	main
pärast	doc_292273046176_item	2331880	et	4	main
veerandi	doc_292273046176_item	2331892	et	4	main
oma	doc_292273046176_item	2331893	et	4	main
elanikust	doc_292273046176_item	2331894	et	3	main
toimus	doc_292273046176_item	2331895	et	3	main
augustis	doc_292273046174_item	2331525	et	3	main
ema	doc_292273046174_item	2331529	et	4	main
minu	doc_292273046174_item	2331531	et	3	main
ema	doc_292273046174_item	2331532	et	4	main
elas	doc_292273046174_item	2331533	et	3	main
moskva	doc_292273046174_item	2331534	et	4	main
minu	doc_292273046174_item	2331541	et	3	main
asub	doc_292273046174_item	2331548	et	3	main
koos	doc_292273046174_item	2331553	et	4	main
me	doc_292273046174_item	2331554	et	4	main
puhkasime	doc_292273046174_item	2331555	et	3	main
suvilas	doc_292273046174_item	2331556	et	3	main
seal	doc_292273046174_item	2331561	et	4	main
jalgrataga	doc_292273046174_item	2331565	et	4	main
ja	doc_292273046174_item	2331569	et	3	main
õhtuti	doc_292273046174_item	2331571	et	3	main
kadastiku	doc_292273046174_item	2331575	et	3	main
on	doc_292273046174_item	2331583	et	4	main
aed	doc_292273046174_item	2331584	et	3	main
see	doc_292273046174_item	2331590	et	3	main
ruttu	doc_292273046174_item	2331607	et	4	main
ja	doc_292273046174_item	2331609	et	3	main
käin	doc_292273046174_item	2331611	et	3	main
mina	doc_292273046174_item	2331610	et	4	main
suvilas	doc_292273046174_item	2331612	et	3	main
ainult	doc_292273046174_item	2331613	et	4	main
puhkepäeviti	doc_292273046174_item	2331614	et	4	main
kiri	doc_292273046175_item	2331615	et	3	main
ma	doc_292273046175_item	2331616	et	3	main
arvan	doc_292273046175_item	2331617	et	3	main
et	doc_292273046175_item	2331618	et	3	main
inimesest	doc_292273046175_item	2331619	et	3	main
võib	doc_292273046175_item	2331620	et	3	main
saada	doc_292273046175_item	2331621	et	4	main
kui	doc_292273046175_item	2331623	et	3	main
käib	doc_292273046175_item	2331629	et	3	main
aga	doc_292273046175_item	2331640	et	3	main
ei	doc_292273046175_item	2331642	et	4	main
ole	doc_292273046175_item	2331643	et	4	main
põhi	doc_292273046175_item	2331644	et	3	main
toiduaine	doc_292273046175_item	2331645	et	4	main
hivid	doc_292273046175_item	2331659	et	4	main
pedagoogiline	doc_292273046175_item	2331664	et	4	main
2	doc_292273046176_item	2331676	et	2	main
kaasa	doc_292273046176_item	2331682	et	4	main
külaühiskonda	doc_292273046176_item	2331683	et	4	main
ii	doc_292273046176_item	2331687	et	4	main
eestlaste	doc_292273046176_item	2331689	et	4	main
jaoks	doc_292273046176_item	2331690	et	4	main
kirjanduselu	doc_292273046176_item	2331697	et	4	main
hakkas	doc_292273046176_item	2331698	et	3	main
samanimelist	doc_292273046176_item	2331721	et	4	main
aga	doc_292273046176_item	2331723	et	3	main
paranesid	doc_292273046176_item	2331737	et	4	main
haritud	doc_292273046176_item	2331744	et	4	main
ahtammsaare	doc_292273046176_item	2331749	et	4	main
tõde	doc_292273046176_item	2331751	et	4	main
hakkas	doc_292273046176_item	2331762	et	3	main
ka	doc_292273046176_item	2331764	et	3	main
trükiti	doc_292273046176_item	2331766	et	3	main
ja	doc_292273046176_item	2331774	et	3	main
oli	doc_292273046176_item	2331776	et	3	main
ei	doc_292273046176_item	2331791	et	4	main
enamlastele	doc_292273046176_item	2331793	et	4	main
võeti	doc_292273046176_item	2331808	et	3	main
maad	doc_292273046176_item	2331810	et	4	main
hakkas	doc_292273046176_item	2331820	et	3	main
olid	doc_292273046176_item	2331825	et	4	main
naised	doc_292273046176_item	2331828	et	3	main
maad	doc_292273046176_item	2331835	et	4	main
hakati	doc_292273046176_item	2331840	et	3	main
õpetaja	doc_292273046175_item	2331622	et	4	main
talle	doc_292273046175_item	2331624	et	4	main
meeldib	doc_292273046175_item	2331625	et	3	main
oma	doc_292273046175_item	2331626	et	4	main
ta	doc_292273046175_item	2331628	et	4	main
mäletab	doc_292273046175_item	2331633	et	3	main
on	doc_292273046175_item	2331636	et	4	main
elu	doc_292273046175_item	2331638	et	4	main
töö	doc_292273046175_item	2331641	et	4	main
prantlased	doc_292273046175_item	2331649	et	4	main
ta	doc_292273046175_item	2331650	et	4	main
end	doc_292273046175_item	2331652	et	4	main
ta	doc_292273046175_item	2331653	et	4	main
mäletab	doc_292273046175_item	2331654	et	3	main
et	doc_292273046175_item	2331655	et	3	main
hobbies	doc_292273046175_item	2331660	et	4	main
iseloomustage	doc_292273046176_item	2331673	et	4	main
muudatusi	doc_292273046176_item	2331678	et	3	main
kollektiviseerimine	doc_292273046176_item	2331681	et	4	main
revolutsioonist	doc_292273046176_item	2331695	et	3	main
eesti	doc_292273046176_item	2331696	et	4	main
kirjandusorganisatsioon	doc_292273046176_item	2331701	et	3	main
noor	doc_292273046176_item	2331702	et	3	main
selle	doc_292273046176_item	2331704	et	4	main
liikmeteks	doc_292273046176_item	2331705	et	3	main
olid	doc_292273046176_item	2331706	et	4	main
gustav	doc_292273046176_item	2331707	et	4	main
suits	doc_292273046176_item	2331708	et	3	main
frtuglas	doc_292273046176_item	2331709	et	4	main
jaavik	doc_292273046176_item	2331710	et	4	main
jt	doc_292273046176_item	2331711	et	4	main
nad	doc_292273046176_item	2331712	et	3	main
tahtsid	doc_292273046176_item	2331713	et	4	main
tutvustada	doc_292273046176_item	2331714	et	3	main
rahvast	doc_292273046176_item	2331715	et	4	main
euroopas	doc_292273046176_item	2331716	et	3	main
toimuvatega	doc_292273046176_item	2331717	et	4	main
nad	doc_292273046176_item	2331718	et	3	main
andsid	doc_292273046176_item	2331719	et	4	main
välja	doc_292273046176_item	2331720	et	4	main
pärast	doc_292273046176_item	2331731	et	4	main
eesti	doc_292273046176_item	2331734	et	4	main
ja	doc_292273046176_item	2331741	et	3	main
väga	doc_292273046176_item	2331746	et	3	main
populaarseks	doc_292273046176_item	2331747	et	4	main
sai	doc_292273046176_item	2331748	et	4	main
romaan	doc_292273046176_item	2331750	et	3	main
õigus	doc_292273046176_item	2331753	et	4	main
väga	doc_292273046176_item	2331768	et	3	main
palju	doc_292273046176_item	2331769	et	4	main
aeg	doc_292273046176_item	2331777	et	3	main
siin	doc_292273046176_item	2331781	et	4	main
oli	doc_292273046176_item	2331782	et	3	main
vene	doc_292273046176_item	2331783	et	4	main
raamatud	doc_292273046176_item	2331789	et	4	main
ajalehed	doc_292273046176_item	2331796	et	3	main
kollektiviseerimine	doc_292273046176_item	2331799	et	4	main
kui	doc_292273046176_item	2331811	et	3	main
küüditamine	doc_292273046176_item	2331822	et	4	main
lapsed	doc_292273046176_item	2331827	et	3	main
niisugusel	doc_292273046176_item	2331832	et	3	main
ja	doc_292273046176_item	2331839	et	3	main
juurde	doc_292273046176_item	2331844	et	4	main
jaoks	doc_292273046176_item	2331850	et	4	main
rahvas	doc_292273046176_item	2331858	et	4	main
oli	doc_292273046176_item	2331859	et	3	main
oma	doc_292273046176_item	2331863	et	4	main
vabad	doc_292273046176_item	2331868	et	3	main
talud	doc_292273046176_item	2331872	et	4	main
maad	doc_292273046176_item	2331873	et	4	main
nendel	doc_292273046176_item	2331875	et	4	main
eesti	doc_292273046176_item	2331881	et	4	main
eesti	doc_292273046176_item	2331890	et	4	main
eestit	doc_301901115683_item	2331934	et	3	main
vabariigiks	doc_301901115683_item	2331937	et	3	main
arenema	doc_301901115683_item	2331943	et	3	main
väga	doc_301901115683_item	2331948	et	3	main
rahvuskirjandus	doc_301901115683_item	2331952	et	3	main
eesti	doc_301901115683_item	2331954	et	4	main
oli	doc_301901115683_item	2331957	et	3	main
ka	doc_301901115683_item	2331972	et	3	main
ja	doc_301901115683_item	2331975	et	3	main
tugevkülg	doc_301901115683_item	2332007	et	4	main
dokumentalistika	doc_301901115683_item	2332010	et	4	main
eestlastele	doc_301901115683_item	2332011	et	4	main
väga	doc_301901115683_item	2332012	et	3	main
arenes	doc_301901115683_item	2332019	et	3	main
eesti	doc_301901115683_item	2332025	et	4	main
tü	doc_301901115683_item	2332032	et	4	main
keele	doc_301901115683_item	2332036	et	4	main
keele	doc_301901115683_item	2332044	et	4	main
ilmub	doc_301901115683_item	2332045	et	3	main
a	doc_301901115683_item	2332050	et	4	main
keele	doc_301901115683_item	2332054	et	4	main
muusikad	doc_301901115683_item	2332066	et	3	main
raadio	doc_301901115683_item	2332068	et	4	main
kultuurielu	doc_301901115683_item	2332101	et	4	main
edukalt	doc_301901115683_item	2332107	et	4	main
kogu	doc_301901115683_item	2332108	et	4	main
kirikut	doc_301901115683_item	2332116	et	3	main
perekonna	doc_301901115683_item	2332123	et	4	main
said	doc_301901115683_item	2332130	et	4	main
populaarseteks	doc_301901115683_item	2332131	et	4	main
on	doc_301901115683_item	2332144	et	4	main
kirjanikke	doc_301901115683_item	2332147	et	3	main
paljud	doc_301901115683_item	2332159	et	3	main
olid	doc_301901115683_item	2332161	et	4	main
oli	doc_301901115683_item	2332209	et	3	main
maavaraks	doc_301901115683_item	2332210	et	3	main
sündmusi	doc_301901115683_item	2332222	et	3	main
kiik	doc_301901115683_item	2332224	et	3	main
tondiöömaja	doc_301901115683_item	2332225	et	4	main
aeg	doc_301901115683_item	2332227	et	3	main
keelatud	doc_301901115683_item	2332229	et	4	main
oli	doc_301901115683_item	2332242	et	3	main
jõukamaid	doc_301901115683_item	2332245	et	4	main
talupoegi	doc_301901115683_item	2332246	et	4	main
see	doc_301901115683_item	2332247	et	3	main
oli	doc_301901115683_item	2332248	et	3	main
seotud	doc_301901115683_item	2332249	et	4	main
sellega	doc_301901115683_item	2332250	et	3	main
et	doc_301901115683_item	2332251	et	3	main
tehtud	doc_301901115683_item	2332265	et	4	main
ilmus	doc_301901115683_item	2332270	et	4	main
nagu	doc_301901115683_item	2332273	et	3	main
puhas	doc_301901115683_item	2332274	et	3	main
kasvatati	doc_301901115683_item	2332309	et	3	main
kodumaale	doc_301901115683_item	2332315	et	4	main
teadusraamatud	doc_292273046176_item	2331775	et	4	main
valitsus	doc_292273046176_item	2331784	et	4	main
ja	doc_292273046176_item	2331785	et	3	main
hakati	doc_292273046176_item	2331786	et	3	main
eesti	doc_292273046176_item	2331788	et	4	main
muudatusi	doc_292273046176_item	2331803	et	3	main
pärast	doc_292273046176_item	2331804	et	4	main
sõja	doc_292273046176_item	2331805	et	3	main
eesti	doc_292273046176_item	2331806	et	4	main
ülejäänud	doc_292273046176_item	2331816	et	4	main
maal	doc_292273046176_item	2331817	et	4	main
tehti	doc_292273046176_item	2331818	et	3	main
vabastati	doc_292273046176_item	2331834	et	3	main
inimesed	doc_292273046176_item	2331836	et	3	main
kartsid	doc_292273046176_item	2331837	et	4	main
vaqbatahtlikult	doc_292273046176_item	2331841	et	4	main
teine	doc_292273046176_item	2331846	et	3	main
maailmasõda	doc_292273046176_item	2331847	et	4	main
valitsuse	doc_292273046176_item	2331855	et	4	main
all	doc_292273046176_item	2331856	et	3	main
eesti	doc_292273046176_item	2331857	et	4	main
nad	doc_292273046176_item	2331865	et	3	main
omama	doc_292273046176_item	2331870	et	4	main
olnud	doc_292273046176_item	2331877	et	4	main
kultuur	doc_292273046176_item	2331884	et	3	main
mis	doc_292273046176_item	2331790	et	4	main
sulgeda	doc_292273046176_item	2331795	et	3	main
2	doc_292273046176_item	2331797	et	2	main
ära	doc_292273046176_item	2331809	et	4	main
nad	doc_292273046176_item	2331812	et	3	main
30	doc_292273046176_item	2331814	et	2	main
ha	doc_292273046176_item	2331815	et	4	main
enamasti	doc_292273046176_item	2331826	et	4	main
ja	doc_292273046176_item	2331829	et	3	main
inimesed	doc_292273046176_item	2331831	et	3	main
moel	doc_292273046176_item	2331833	et	4	main
kolhoosi	doc_292273046176_item	2331843	et	4	main
aastat	doc_292273046176_item	2331852	et	3	main
nõukogude	doc_292273046176_item	2331853	et	3	main
liidu	doc_292273046176_item	2331854	et	3	main
tahtsid	doc_292273046176_item	2331866	et	4	main
olla	doc_292273046176_item	2331867	et	3	main
ja	doc_292273046176_item	2331869	et	3	main
oma	doc_292273046176_item	2331871	et	4	main
majandus	doc_292273046176_item	2331882	et	4	main
arenenud	doc_292273046176_item	2331886	et	4	main
kaotas	doc_292273046176_item	2331891	et	3	main
massiline	doc_292273046176_item	2331896	et	4	main
küüditamine	doc_292273046176_item	2331897	et	4	main
eesti	doc_292273046176_item	2331898	et	4	main
oli	doc_292273046176_item	2331899	et	3	main
üks	doc_292273046176_item	2331900	et	3	main
sellest	doc_292273046176_item	2331901	et	4	main
maast	doc_292273046176_item	2331902	et	3	main
kes	doc_292273046176_item	2331903	et	4	main
raskesti	doc_292273046176_item	2331905	et	3	main
olid	doc_292273046176_item	2331904	et	4	main
laostanud	doc_292273046176_item	2331906	et	4	main
ii	doc_292273046176_item	2331907	et	4	main
maailmasõjal	doc_292273046176_item	2331908	et	3	main
ja	doc_292273046176_item	2331909	et	3	main
kellel	doc_292273046176_item	2331910	et	4	main
olid	doc_292273046176_item	2331911	et	4	main
suured	doc_292273046176_item	2331912	et	3	main
raskused	doc_292273046176_item	2331913	et	4	main
ja	doc_292273046176_item	2331914	et	3	main
kannatused	doc_292273046176_item	2331915	et	4	main
kontrolltöö	doc_301901115683_item	2331916	et	4	main
1	doc_301901115683_item	2331917	et	2	main
võrrelge	doc_301901115683_item	2331918	et	3	main
ev	doc_301901115683_item	2331919	et	4	main
aegsest	doc_301901115683_item	2331920	et	3	main
ensv	doc_301901115683_item	2331922	et	4	main
2	doc_301901115683_item	2331925	et	2	main
sotsialistlik	doc_301901115683_item	2331926	et	3	main
realism	doc_301901115683_item	2331927	et	3	main
kui	doc_301901115683_item	2331928	et	3	main
1918	doc_301901115683_item	2331932	et	2	main
tartu	doc_301901115683_item	2331944	et	4	main
sai	doc_301901115683_item	2331946	et	4	main
uus	doc_301901115683_item	2331958	et	3	main
siia	doc_301901115683_item	2331962	et	4	main
sellised	doc_301901115683_item	2331964	et	4	main
teemad	doc_301901115683_item	2331965	et	3	main
nagu	doc_301901115683_item	2331966	et	3	main
eesti	doc_301901115683_item	2331967	et	4	main
etnograafia	doc_301901115683_item	2331968	et	4	main
rahvaluule	doc_301901115683_item	2331970	et	4	main
3	doc_292273046176_item	2331845	et	2	main
tähendas	doc_292273046176_item	2331848	et	3	main
eestlaste	doc_292273046176_item	2331849	et	4	main
harjunud	doc_292273046176_item	2331860	et	4	main
saatuse	doc_292273046176_item	2331864	et	3	main
maailmasõja	doc_292273046176_item	2331879	et	3	main
ja	doc_292273046176_item	2331883	et	3	main
ei	doc_292273046176_item	2331885	et	4	main
maad	doc_292273046176_item	2331887	et	4	main
olid	doc_292273046176_item	2331888	et	4	main
laostunud	doc_292273046176_item	2331889	et	4	main
kui	doc_301901115683_item	2331931	et	3	main
hakkas	doc_301901115683_item	2331942	et	3	main
tähtsal	doc_301901115683_item	2331949	et	3	main
ja	doc_301901115683_item	2331953	et	3	main
keel	doc_301901115683_item	2331955	et	4	main
see	doc_301901115683_item	2331956	et	3	main
juurdusid	doc_301901115683_item	2331963	et	4	main
ja	doc_301901115683_item	2331969	et	3	main
huvitusid	doc_301901115683_item	2331971	et	4	main
eesti	doc_301901115683_item	2331973	et	4	main
see	doc_301901115683_item	2332016	et	3	main
kiiresti	doc_301901115683_item	2332018	et	3	main
1	doc_301901115683_item	2331930	et	2	main
aastal	doc_301901115683_item	2331933	et	3	main
eesti	doc_301901115683_item	2331936	et	4	main
kultuurielu	doc_301901115683_item	2331938	et	4	main
ülikool	doc_301901115683_item	2331945	et	4	main
oli	doc_301901115683_item	2331951	et	3	main
teema	doc_301901115683_item	2331959	et	4	main
algul	doc_301901115683_item	2331977	et	4	main
probleemiks	doc_301901115683_item	2331978	et	4	main
oli	doc_301901115683_item	2331979	et	3	main
see	doc_301901115683_item	2331980	et	3	main
et	doc_301901115683_item	2331981	et	3	main
jätkunud	doc_301901115683_item	2331982	et	4	main
oma	doc_301901115683_item	2331983	et	4	main
teadlasi	doc_301901115683_item	2331984	et	3	main
seetõttu	doc_301901115683_item	2331985	et	3	main
kustuti	doc_301901115683_item	2331986	et	4	main
välismaalt	doc_301901115683_item	2331987	et	3	main
oli	doc_301901115683_item	2331989	et	3	main
haridus	doc_301901115683_item	2331988	et	3	main
ka	doc_301901115683_item	2331990	et	3	main
väga	doc_301901115683_item	2331991	et	3	main
tasemel	doc_301901115683_item	2331993	et	3	main
kõrgel	doc_301901115683_item	2331992	et	4	main
isegi	doc_301901115683_item	2331994	et	4	main
euroopaga	doc_301901115683_item	2331995	et	3	main
võrreldes	doc_301901115683_item	2331996	et	3	main
tavaliselt	doc_301901115683_item	2331997	et	4	main
kes	doc_301901115683_item	2331999	et	4	main
kõik	doc_301901115683_item	2331998	et	4	main
õppisid	doc_301901115683_item	2332000	et	4	main
jätkasid	doc_301901115683_item	2332001	et	4	main
õppimist	doc_301901115683_item	2332002	et	4	main
kõrgkoolideni	doc_301901115683_item	2332003	et	3	main
arenes	doc_301901115683_item	2332004	et	3	main
muusika	doc_301901115683_item	2332005	et	4	main
eesti	doc_301901115683_item	2332006	et	4	main
ja	doc_301901115683_item	2331921	et	3	main
pärastsõjajärgset	doc_301901115683_item	2331923	et	3	main
kultuurielu	doc_301901115683_item	2331924	et	4	main
kirjandusvool	doc_301901115683_item	2331929	et	4	main
tunnistati	doc_301901115683_item	2331935	et	4	main
hakkas	doc_301901115683_item	2331939	et	3	main
arenema	doc_301901115683_item	2331940	et	3	main
rahvusteadus	doc_301901115683_item	2331941	et	4	main
teadustekeskuseks	doc_301901115683_item	2331947	et	4	main
kohal	doc_301901115683_item	2331950	et	4	main
natuke	doc_301901115683_item	2331960	et	4	main
hiljem	doc_301901115683_item	2331961	et	3	main
ajaloost	doc_301901115683_item	2331976	et	4	main
meeldis	doc_301901115683_item	2332013	et	3	main
püüdsid	doc_301901115683_item	2332021	et	4	main
stiile	doc_301901115683_item	2332024	et	3	main
pidas	doc_301901115683_item	2332034	et	3	main
avatakse	doc_301901115683_item	2332047	et	4	main
saareste	doc_301901115683_item	2332051	et	4	main
kaardistas	doc_301901115683_item	2332057	et	3	main
nt	doc_301901115683_item	2332061	et	4	main
kuulata	doc_301901115683_item	2332064	et	4	main
klassikalist	doc_301901115683_item	2332065	et	4	main
arene	doc_301901115683_item	2332103	et	4	main
enam	doc_301901115683_item	2332104	et	4	main
vähemalt	doc_301901115683_item	2332105	et	4	main
toimuvad	doc_301901115683_item	2332110	et	4	main
kultuurielu	doc_301901115683_item	2332114	et	4	main
lahutatakse	doc_301901115683_item	2332117	et	3	main
arheoloogiast	doc_301901115683_item	2331974	et	3	main
oli	doc_301901115683_item	2332009	et	3	main
käia	doc_301901115683_item	2332015	et	4	main
väga	doc_301901115683_item	2332017	et	3	main
jälgida	doc_301901115683_item	2332022	et	3	main
euroopa	doc_301901115683_item	2332023	et	4	main
keel	doc_301901115683_item	2332026	et	4	main
arenes	doc_301901115683_item	2332028	et	3	main
i	doc_301901115683_item	2332031	et	4	main
lektor	doc_301901115683_item	2332033	et	3	main
murdeid	doc_301901115683_item	2332040	et	3	main
tendentse	doc_301901115683_item	2332042	et	3	main
raamatukogud	doc_301901115683_item	2332049	et	3	main
murrete	doc_301901115683_item	2332055	et	3	main
ilmub	doc_301901115683_item	2332076	et	3	main
ja	doc_301901115683_item	2332078	et	3	main
ei	doc_301901115683_item	2332102	et	4	main
mis	doc_301901115683_item	2332112	et	4	main
seetõttu	doc_301901115683_item	2332119	et	3	main
on	doc_301901115683_item	2332121	et	4	main
kalendripäevi	doc_301901115683_item	2332127	et	4	main
tekkisid	doc_301901115683_item	2332133	et	4	main
tavad	doc_301901115683_item	2332135	et	3	main
trükivabaduse	doc_301901115683_item	2332140	et	4	main
visatud	doc_301901115683_item	2332145	et	4	main
seltsidest	doc_301901115683_item	2332148	et	3	main
lugu	doc_301901115683_item	2332150	et	4	main
oli	doc_301901115683_item	2332151	et	3	main
teiste	doc_301901115683_item	2332154	et	4	main
paljusid	doc_301901115683_item	2332156	et	3	main
represseeriti	doc_301901115683_item	2332158	et	3	main
raamatud	doc_301901115683_item	2332160	et	4	main
keelatud	doc_301901115683_item	2332162	et	4	main
ja	doc_301901115683_item	2332163	et	3	main
toimus	doc_301901115683_item	2332164	et	3	main
likvideeriti	doc_301901115683_item	2332171	et	3	main
toodeti	doc_301901115683_item	2332197	et	3	main
see	doc_301901115683_item	2332200	et	3	main
jaoks	doc_301901115683_item	2332207	et	4	main
tolleaegseid	doc_301901115683_item	2332221	et	3	main
m	doc_301901115683_item	2332223	et	4	main
kolhoosid	doc_301901115683_item	2332231	et	3	main
sohvoosid	doc_301901115683_item	2332233	et	4	main
arvati	doc_301901115683_item	2332235	et	4	main
et	doc_301901115683_item	2332236	et	3	main
sinna	doc_301901115683_item	2332237	et	3	main
koonduvad	doc_301901115683_item	2332238	et	4	main
vaesemad	doc_301901115683_item	2332239	et	4	main
järjekordset	doc_301901115683_item	2332254	et	3	main
see	doc_301901115683_item	2332256	et	3	main
2526	doc_301901115683_item	2332259	et	2	main
oli	doc_301901115683_item	2332264	et	3	main
inimest	doc_301901115683_item	2332268	et	3	main
nähtus	doc_301901115683_item	2332272	et	4	main
inimestest	doc_301901115683_item	2332308	et	3	main
kirjandusteostes	doc_301901115683_item	2332317	et	3	main
inimeste	doc_301901115683_item	2332326	et	3	main
range	doc_301901115683_item	2332330	et	4	main
ka	doc_301901115683_item	2332335	et	3	main
oli	doc_301901115683_item	2332341	et	3	main
keele	doc_301901115683_item	2332343	et	4	main
aegsest	doc_301901115684_item	2332349	et	3	main
2	doc_301901115684_item	2332354	et	2	main
realism	doc_301901115684_item	2332356	et	3	main
1	doc_301901115684_item	2332359	et	2	main
tähtsal	doc_301901115684_item	2332378	et	3	main
ja	doc_301901115684_item	2332382	et	3	main
uus	doc_301901115684_item	2332387	et	3	main
teema	doc_301901115684_item	2332388	et	4	main
nagu	doc_301901115684_item	2332395	et	3	main
arheoloogiast	doc_301901115684_item	2332403	et	3	main
see	doc_301901115684_item	2332409	et	3	main
jätkunud	doc_301901115684_item	2332411	et	4	main
isegi	doc_301901115684_item	2332423	et	4	main
tavaliselt	doc_301901115684_item	2332426	et	4	main
kõik	doc_301901115684_item	2332427	et	4	main
filmikunstis	doc_301901115684_item	2332437	et	3	main
dokumentalistika	doc_301901115684_item	2332439	et	4	main
väga	doc_301901115684_item	2332441	et	3	main
käia	doc_301901115684_item	2332444	et	4	main
eesti	doc_301901115684_item	2332454	et	4	main
filmikunstis	doc_301901115683_item	2332008	et	3	main
kinodes	doc_301901115683_item	2332014	et	3	main
arhitektuuris	doc_301901115683_item	2332020	et	3	main
j	doc_301901115683_item	2332029	et	4	main
jõgever	doc_301901115683_item	2332030	et	4	main
eesti	doc_301901115683_item	2332035	et	4	main
uurima	doc_301901115683_item	2332039	et	3	main
folkloor	doc_301901115683_item	2332046	et	4	main
avalikud	doc_301901115683_item	2332048	et	3	main
eesti	doc_301901115683_item	2332053	et	4	main
saab	doc_301901115683_item	2332069	et	3	main
jalgratas	doc_301901115683_item	2332074	et	3	main
eestis	doc_301901115683_item	2332075	et	3	main
nii	doc_301901115683_item	2332106	et	3	main
repressioonid	doc_301901115683_item	2332111	et	3	main
pidurdavad	doc_301901115683_item	2332113	et	4	main
kasvu	doc_301901115683_item	2332115	et	4	main
riigist	doc_301901115683_item	2332118	et	3	main
formaalseteks	doc_301901115683_item	2332126	et	4	main
tähistatakse	doc_301901115683_item	2332128	et	3	main
massiliselt	doc_301901115683_item	2332129	et	4	main
uued	doc_301901115683_item	2332134	et	3	main
kõik	doc_301901115683_item	2332167	et	4	main
oli	doc_301901115683_item	2332201	et	3	main
põlevkivi	doc_301901115683_item	2332208	et	4	main
kirjandus	doc_301901115683_item	2332218	et	3	main
peegeldasid	doc_301901115683_item	2332220	et	4	main
mõni	doc_301901115683_item	2332226	et	3	main
ilmusid	doc_301901115683_item	2332230	et	4	main
algul	doc_301901115683_item	2332234	et	4	main
inimesed	doc_301901115683_item	2332240	et	3	main
palju	doc_301901115683_item	2332243	et	4	main
nad	doc_301901115683_item	2332252	et	3	main
küüdiatmist	doc_301901115683_item	2332255	et	4	main
aastal	doc_301901115683_item	2332262	et	3	main
hariduses	doc_301901115683_item	2332269	et	3	main
oli	doc_301901115683_item	2332305	et	3	main
kamuniste	doc_301901115683_item	2332310	et	4	main
oleksid	doc_301901115683_item	2332312	et	4	main
truu	doc_301901115683_item	2332313	et	4	main
oma	doc_301901115683_item	2332314	et	4	main
oli	doc_301901115683_item	2332318	et	3	main
ka	doc_301901115683_item	2332027	et	3	main
loenguid	doc_301901115683_item	2332037	et	4	main
hakatakse	doc_301901115683_item	2332038	et	3	main
erinevaid	doc_301901115683_item	2332041	et	4	main
eesti	doc_301901115683_item	2332043	et	4	main
koostas	doc_301901115683_item	2332052	et	4	main
atlase	doc_301901115683_item	2332056	et	3	main
maale	doc_301901115683_item	2332058	et	4	main
jõuab	doc_301901115683_item	2332059	et	3	main
ettevõtteid	doc_301901115683_item	2332060	et	3	main
on	doc_301901115683_item	2332062	et	4	main
võimalik	doc_301901115683_item	2332063	et	3	main
grammafoonis	doc_301901115683_item	2332067	et	4	main
populaarseks	doc_301901115683_item	2332070	et	4	main
uueks	doc_301901115683_item	2332071	et	3	main
liikumisvahendiks	doc_301901115683_item	2332072	et	3	main
saab	doc_301901115683_item	2332073	et	3	main
balett	doc_301901115683_item	2332077	et	4	main
ooper	doc_301901115683_item	2332079	et	3	main
see	doc_301901115683_item	2332080	et	3	main
on	doc_301901115683_item	2332081	et	4	main
väga	doc_301901115683_item	2332082	et	3	main
primitiivne	doc_301901115683_item	2332083	et	3	main
kuid	doc_301901115683_item	2332084	et	4	main
juba	doc_301901115683_item	2332086	et	3	main
on	doc_301901115683_item	2332085	et	4	main
olemas	doc_301901115683_item	2332087	et	4	main
esimene	doc_301901115683_item	2332088	et	3	main
samm	doc_301901115683_item	2332089	et	3	main
eestima	doc_301901115683_item	2332090	et	4	main
õitses	doc_301901115683_item	2332091	et	4	main
ja	doc_301901115683_item	2332092	et	3	main
oli	doc_301901115683_item	2332093	et	3	main
tõesti	doc_301901115683_item	2332094	et	3	main
üks	doc_301901115683_item	2332095	et	3	main
kena	doc_301901115683_item	2332096	et	4	main
euroopa	doc_301901115683_item	2332097	et	4	main
riik	doc_301901115683_item	2332098	et	3	main
ensv	doc_301901115683_item	2332099	et	4	main
pärastsõjajärgne	doc_301901115683_item	2332100	et	3	main
aeg	doc_301901115683_item	2332109	et	3	main
riigis	doc_301901115683_item	2332120	et	3	main
usuvabadus	doc_301901115683_item	2332122	et	4	main
muudeti	doc_301901115683_item	2332125	et	3	main
suvepäevad	doc_301901115683_item	2332132	et	3	main
on	doc_301901115683_item	2332137	et	4	main
ja	doc_301901115683_item	2332139	et	3	main
piiramine	doc_301901115683_item	2332141	et	4	main
paljud	doc_301901115683_item	2332142	et	3	main
kirjanikud	doc_301901115683_item	2332143	et	3	main
sama	doc_301901115683_item	2332149	et	4	main
neist	doc_301901115683_item	2332157	et	4	main
nende	doc_301901115683_item	2332165	et	4	main
eesti	doc_301901115683_item	2332168	et	4	main
vabariigi	doc_301901115683_item	2332169	et	3	main
monumendid	doc_301901115683_item	2332170	et	3	main
tõlgendas	doc_301901115683_item	2332196	et	3	main
elektroonikat	doc_301901115683_item	2332198	et	3	main
aga	doc_301901115683_item	2332199	et	3	main
rohkem	doc_301901115683_item	2332202	et	4	main
jaoks	doc_301901115683_item	2332204	et	4	main
sõja	doc_301901115683_item	2332206	et	3	main
mille	doc_301901115683_item	2332211	et	3	main
huvitas	doc_301901115683_item	2332213	et	3	main
moskvat	doc_301901115683_item	2332215	et	4	main
eestit	doc_301901115683_item	2332217	et	3	main
teod	doc_301901115683_item	2332219	et	4	main
rituaalid	doc_301901115683_item	2332124	et	3	main
riigis	doc_301901115683_item	2332136	et	3	main
sõna	doc_301901115683_item	2332138	et	4	main
välja	doc_301901115683_item	2332146	et	4	main
kunstniketega	doc_301901115683_item	2332152	et	4	main
ja	doc_301901115683_item	2332153	et	3	main
kultuuritegelastega	doc_301901115683_item	2332155	et	3	main
hävitamine	doc_301901115683_item	2332166	et	4	main
sellega	doc_301901115683_item	2332172	et	3	main
taheti	doc_301901115683_item	2332173	et	3	main
võimalikult	doc_301901115683_item	2332174	et	4	main
täielikum	doc_301901115683_item	2332175	et	4	main
kustutada	doc_301901115683_item	2332176	et	3	main
rahva	doc_301901115683_item	2332177	et	3	main
mälu	doc_301901115683_item	2332178	et	4	main
arenes	doc_301901115683_item	2332180	et	3	main
sellega	doc_301901115683_item	2332181	et	3	main
folkloor	doc_301901115683_item	2332179	et	4	main
kuhu	doc_301901115683_item	2332182	et	3	main
pandi	doc_301901115683_item	2332183	et	4	main
mingi	doc_301901115683_item	2332184	et	4	main
monument	doc_301901115683_item	2332185	et	3	main
ja	doc_301901115683_item	2332186	et	3	main
milline	doc_301901115683_item	2332187	et	3	main
kristlikke	doc_301901115683_item	2332188	et	3	main
sümboleid	doc_301901115683_item	2332189	et	3	main
võeti	doc_301901115683_item	2332190	et	3	main
vastu	doc_301901115683_item	2332191	et	3	main
nii	doc_301901115683_item	2332192	et	3	main
nagu	doc_301901115683_item	2332193	et	3	main
partei	doc_301901115683_item	2332194	et	4	main
neid	doc_301901115683_item	2332195	et	4	main
nõukogude	doc_301901115683_item	2332203	et	3	main
ehk	doc_301901115683_item	2332205	et	3	main
töötlemine	doc_301901115683_item	2332212	et	4	main
rohkem	doc_301901115683_item	2332214	et	4	main
kui	doc_301901115683_item	2332216	et	3	main
oli	doc_301901115683_item	2332228	et	3	main
ja	doc_301901115683_item	2332232	et	3	main
kuid	doc_301901115683_item	2332241	et	4	main
ka	doc_301901115683_item	2332244	et	3	main
ikkagi	doc_301901115683_item	2332257	et	4	main
toimus	doc_301901115683_item	2332258	et	3	main
1941	doc_301901115683_item	2332261	et	2	main
30000	doc_301901115683_item	2332267	et	2	main
selline	doc_301901115683_item	2332271	et	4	main
samasugune	doc_301901115683_item	2332306	et	3	main
joon	doc_301901115683_item	2332320	et	4	main
see	doc_301901115683_item	2332323	et	3	main
eesmärk	doc_301901115683_item	2332325	et	3	main
ev	doc_301901115684_item	2332348	et	4	main
pärastsõjajärgset	doc_301901115684_item	2332352	et	3	main
kohal	doc_301901115684_item	2332379	et	4	main
rahvuskirjandus	doc_301901115684_item	2332381	et	3	main
oli	doc_301901115684_item	2332386	et	3	main
rahvaluule	doc_301901115684_item	2332399	et	4	main
huvitusid	doc_301901115684_item	2332400	et	4	main
ka	doc_301901115684_item	2332401	et	3	main
eesti	doc_301901115684_item	2332402	et	4	main
algul	doc_301901115684_item	2332406	et	4	main
oli	doc_301901115684_item	2332408	et	3	main
kartsid	doc_301901115683_item	2332253	et	4	main
märtsil	doc_301901115683_item	2332260	et	3	main
norm	doc_301901115683_item	2332263	et	3	main
represseeriti	doc_301901115683_item	2332266	et	3	main
ankeet	doc_301901115683_item	2332275	et	3	main
ei	doc_301901115683_item	2332276	et	4	main
tohtinud	doc_301901115683_item	2332277	et	4	main
olla	doc_301901115683_item	2332278	et	3	main
sugulasi	doc_301901115683_item	2332279	et	3	main
eks	doc_301901115683_item	2332280	et	3	main
oleksid	doc_301901115683_item	2332281	et	4	main
soetud	doc_301901115683_item	2332282	et	4	main
valitsusega	doc_301901115683_item	2332283	et	4	main
kultuuriga	doc_301901115683_item	2332284	et	4	main
inimesed	doc_301901115683_item	2332285	et	3	main
sorteeriti	doc_301901115683_item	2332286	et	3	main
päritolu	doc_301901115683_item	2332287	et	4	main
järgi	doc_301901115683_item	2332288	et	4	main
metsavennad	doc_301901115683_item	2332289	et	3	main
muutusid	doc_301901115683_item	2332290	et	4	main
eriti	doc_301901115683_item	2332291	et	3	main
agressiivsemateks	doc_301901115683_item	2332292	et	4	main
partei	doc_301901115683_item	2332293	et	4	main
dikteeris	doc_301901115683_item	2332294	et	3	main
majandust	doc_301901115683_item	2332295	et	4	main
ja	doc_301901115683_item	2332296	et	3	main
kultuurielu	doc_301901115683_item	2332297	et	4	main
2	doc_301901115683_item	2332298	et	2	main
sotsialistlik	doc_301901115683_item	2332299	et	3	main
realism	doc_301901115683_item	2332300	et	3	main
kui	doc_301901115683_item	2332301	et	3	main
kirjandusvool	doc_301901115683_item	2332302	et	4	main
kõik	doc_301901115683_item	2332303	et	4	main
kirjandus	doc_301901115683_item	2332304	et	3	main
tüükiline	doc_301901115683_item	2332307	et	4	main
kes	doc_301901115683_item	2332311	et	4	main
üks	doc_301901115683_item	2332319	et	3	main
inimestest	doc_301901115683_item	2332321	et	3	main
elu	doc_301901115683_item	2332327	et	4	main
riigi	doc_301901115683_item	2332329	et	3	main
kontrolli	doc_301901115683_item	2332331	et	4	main
all	doc_301901115683_item	2332332	et	3	main
eestimaal	doc_301901115683_item	2332333	et	4	main
oli	doc_301901115683_item	2332334	et	3	main
õppeprogrammis	doc_301901115683_item	2332340	et	3	main
ensv	doc_301901115684_item	2332351	et	4	main
kirjandusvool	doc_301901115684_item	2332358	et	4	main
sai	doc_301901115684_item	2332375	et	4	main
teadustekeskuseks	doc_301901115684_item	2332376	et	4	main
eesti	doc_301901115684_item	2332383	et	4	main
natuke	doc_301901115684_item	2332389	et	4	main
etnograafia	doc_301901115684_item	2332397	et	4	main
ja	doc_301901115684_item	2332398	et	3	main
ja	doc_301901115684_item	2332404	et	3	main
jätkasid	doc_301901115684_item	2332430	et	4	main
eesti	doc_301901115684_item	2332435	et	4	main
oli	doc_301901115684_item	2332438	et	3	main
eestlastele	doc_301901115684_item	2332440	et	4	main
meeldis	doc_301901115684_item	2332442	et	3	main
stiile	doc_301901115684_item	2332453	et	3	main
ka	doc_301901115684_item	2332456	et	3	main
arenes	doc_301901115684_item	2332457	et	3	main
eesti	doc_301901115684_item	2332472	et	4	main
uueks	doc_301901115684_item	2332500	et	3	main
saab	doc_301901115684_item	2332502	et	3	main
eestis	doc_301901115684_item	2332504	et	3	main
väga	doc_301901115684_item	2332511	et	3	main
on	doc_301901115684_item	2332514	et	4	main
olemas	doc_301901115684_item	2332516	et	4	main
samm	doc_301901115684_item	2332518	et	3	main
oli	doc_301901115684_item	2332522	et	3	main
üks	doc_301901115684_item	2332524	et	3	main
euroopa	doc_301901115684_item	2332526	et	4	main
riik	doc_301901115684_item	2332527	et	3	main
edukalt	doc_301901115684_item	2332536	et	4	main
kogu	doc_301901115684_item	2332537	et	4	main
aeg	doc_301901115684_item	2332538	et	3	main
repressioonid	doc_301901115684_item	2332540	et	3	main
kasvu	doc_301901115684_item	2332544	et	4	main
riigist	doc_301901115684_item	2332547	et	3	main
populaarseteks	doc_301901115684_item	2332560	et	4	main
nende	doc_301901115684_item	2332594	et	4	main
monumendid	doc_301901115684_item	2332599	et	3	main
folkloor	doc_301901115684_item	2332608	et	4	main
kuhu	doc_301901115684_item	2332611	et	3	main
kõikides	doc_301901115683_item	2332316	et	4	main
kommunistideks	doc_301901115683_item	2332322	et	3	main
oli	doc_301901115683_item	2332328	et	3	main
mitu	doc_301901115683_item	2332336	et	4	main
esindajaid	doc_301901115683_item	2332339	et	4	main
vene	doc_301901115683_item	2332342	et	4	main
suurendamine	doc_301901115683_item	2332344	et	4	main
kontrolltöö	doc_301901115684_item	2332345	et	4	main
1	doc_301901115684_item	2332346	et	2	main
kultuurielu	doc_301901115684_item	2332353	et	4	main
kui	doc_301901115684_item	2332357	et	3	main
väga	doc_301901115684_item	2332377	et	3	main
keel	doc_301901115684_item	2332384	et	4	main
hiljem	doc_301901115684_item	2332390	et	3	main
siia	doc_301901115684_item	2332391	et	4	main
juurdusid	doc_301901115684_item	2332392	et	4	main
sellised	doc_301901115684_item	2332393	et	4	main
eesti	doc_301901115684_item	2332396	et	4	main
et	doc_301901115684_item	2332410	et	3	main
oma	doc_301901115684_item	2332412	et	4	main
teadlasi	doc_301901115684_item	2332413	et	3	main
seetõttu	doc_301901115684_item	2332414	et	3	main
kustuti	doc_301901115684_item	2332415	et	4	main
välismaalt	doc_301901115684_item	2332416	et	3	main
haridus	doc_301901115684_item	2332417	et	3	main
oli	doc_301901115684_item	2332418	et	3	main
ka	doc_301901115684_item	2332419	et	3	main
väga	doc_301901115684_item	2332420	et	3	main
tasemel	doc_301901115684_item	2332422	et	3	main
õppisid	doc_301901115684_item	2332429	et	4	main
tugevkülg	doc_301901115684_item	2332436	et	4	main
kiiresti	doc_301901115684_item	2332447	et	3	main
arhitektuuris	doc_301901115684_item	2332449	et	3	main
jälgida	doc_301901115684_item	2332451	et	3	main
eesti	doc_301901115684_item	2332464	et	4	main
populaarseks	doc_301901115684_item	2332499	et	4	main
liikumisvahendiks	doc_301901115684_item	2332501	et	3	main
jalgratas	doc_301901115684_item	2332503	et	3	main
balett	doc_301901115684_item	2332506	et	4	main
ooper	doc_301901115684_item	2332508	et	3	main
oli	doc_301901115683_item	2332324	et	3	main
selle	doc_301901115683_item	2332337	et	4	main
voolu	doc_301901115683_item	2332338	et	4	main
võrrelge	doc_301901115684_item	2332347	et	3	main
ja	doc_301901115684_item	2332350	et	3	main
sotsialistlik	doc_301901115684_item	2332355	et	3	main
kui	doc_301901115684_item	2332360	et	3	main
1918	doc_301901115684_item	2332361	et	2	main
aastal	doc_301901115684_item	2332362	et	3	main
eestit	doc_301901115684_item	2332363	et	3	main
eesti	doc_301901115684_item	2332365	et	4	main
tunnistati	doc_301901115684_item	2332364	et	4	main
vabariigiks	doc_301901115684_item	2332366	et	3	main
kultuurielu	doc_301901115684_item	2332367	et	4	main
hakkas	doc_301901115684_item	2332368	et	3	main
arenema	doc_301901115684_item	2332369	et	3	main
rahvusteadus	doc_301901115684_item	2332370	et	4	main
hakkas	doc_301901115684_item	2332371	et	3	main
arenema	doc_301901115684_item	2332372	et	3	main
tartu	doc_301901115684_item	2332373	et	4	main
ülikool	doc_301901115684_item	2332374	et	4	main
oli	doc_301901115684_item	2332380	et	3	main
see	doc_301901115684_item	2332385	et	3	main
teemad	doc_301901115684_item	2332394	et	3	main
ajaloost	doc_301901115684_item	2332405	et	4	main
probleemiks	doc_301901115684_item	2332407	et	4	main
kõrgel	doc_301901115684_item	2332421	et	4	main
euroopaga	doc_301901115684_item	2332424	et	3	main
võrreldes	doc_301901115684_item	2332425	et	3	main
muusika	doc_301901115684_item	2332434	et	4	main
püüdsid	doc_301901115684_item	2332450	et	4	main
euroopa	doc_301901115684_item	2332452	et	4	main
j	doc_301901115684_item	2332458	et	4	main
keele	doc_301901115684_item	2332465	et	4	main
loenguid	doc_301901115684_item	2332466	et	4	main
hakatakse	doc_301901115684_item	2332467	et	3	main
uurima	doc_301901115684_item	2332468	et	3	main
murdeid	doc_301901115684_item	2332469	et	3	main
kuulata	doc_301901115684_item	2332493	et	4	main
ilmub	doc_301901115684_item	2332505	et	3	main
on	doc_301901115684_item	2332510	et	4	main
õitses	doc_301901115684_item	2332520	et	4	main
ja	doc_301901115684_item	2332521	et	3	main
vähemalt	doc_301901115684_item	2332534	et	4	main
nii	doc_301901115684_item	2332535	et	3	main
pidurdavad	doc_301901115684_item	2332542	et	4	main
kirikut	doc_301901115684_item	2332545	et	3	main
riigis	doc_301901115684_item	2332549	et	3	main
kalendripäevi	doc_301901115684_item	2332556	et	4	main
ja	doc_301901115684_item	2332582	et	3	main
keelatud	doc_301901115684_item	2332591	et	4	main
ja	doc_301901115684_item	2332592	et	3	main
toimus	doc_301901115684_item	2332593	et	3	main
kõik	doc_301901115684_item	2332596	et	4	main
likvideeriti	doc_301901115684_item	2332600	et	3	main
võimalikult	doc_301901115684_item	2332603	et	4	main
sellega	doc_301901115684_item	2332610	et	3	main
partei	doc_301901115684_item	2332623	et	4	main
oli	doc_301901115684_item	2332630	et	3	main
töötlemine	doc_301901115684_item	2332641	et	4	main
teod	doc_301901115684_item	2332648	et	4	main
sündmusi	doc_301901115684_item	2332651	et	3	main
ja	doc_301901115684_item	2332661	et	3	main
arvati	doc_301901115684_item	2332664	et	4	main
seotud	doc_301901115684_item	2332678	et	4	main
sellega	doc_301901115684_item	2332679	et	3	main
küüdiatmist	doc_301901115684_item	2332684	et	4	main
ikkagi	doc_301901115684_item	2332686	et	4	main
olla	doc_301901115684_item	2332707	et	3	main
soetud	doc_301901115684_item	2332711	et	4	main
valitsusega	doc_301901115684_item	2332712	et	4	main
kes	doc_301901115684_item	2332428	et	4	main
õppimist	doc_301901115684_item	2332431	et	4	main
kõrgkoolideni	doc_301901115684_item	2332432	et	3	main
arenes	doc_301901115684_item	2332433	et	3	main
kinodes	doc_301901115684_item	2332443	et	3	main
see	doc_301901115684_item	2332445	et	3	main
väga	doc_301901115684_item	2332446	et	3	main
arenes	doc_301901115684_item	2332448	et	3	main
keel	doc_301901115684_item	2332455	et	4	main
jõgever	doc_301901115684_item	2332459	et	4	main
i	doc_301901115684_item	2332460	et	4	main
tü	doc_301901115684_item	2332461	et	4	main
lektor	doc_301901115684_item	2332462	et	3	main
pidas	doc_301901115684_item	2332463	et	3	main
keele	doc_301901115684_item	2332473	et	4	main
ilmub	doc_301901115684_item	2332474	et	3	main
folkloor	doc_301901115684_item	2332475	et	4	main
avatakse	doc_301901115684_item	2332476	et	4	main
avalikud	doc_301901115684_item	2332477	et	3	main
raamatukogud	doc_301901115684_item	2332478	et	3	main
saareste	doc_301901115684_item	2332480	et	4	main
a	doc_301901115684_item	2332479	et	4	main
koostas	doc_301901115684_item	2332481	et	4	main
eesti	doc_301901115684_item	2332482	et	4	main
keele	doc_301901115684_item	2332483	et	4	main
murrete	doc_301901115684_item	2332484	et	3	main
atlase	doc_301901115684_item	2332485	et	3	main
kaardistas	doc_301901115684_item	2332486	et	3	main
maale	doc_301901115684_item	2332487	et	4	main
jõuab	doc_301901115684_item	2332488	et	3	main
ettevõtteid	doc_301901115684_item	2332489	et	3	main
nt	doc_301901115684_item	2332490	et	4	main
on	doc_301901115684_item	2332491	et	4	main
erinevaid	doc_301901115684_item	2332470	et	4	main
tendentse	doc_301901115684_item	2332471	et	3	main
võimalik	doc_301901115684_item	2332492	et	3	main
muusikad	doc_301901115684_item	2332495	et	3	main
primitiivne	doc_301901115684_item	2332512	et	3	main
juba	doc_301901115684_item	2332515	et	3	main
esimene	doc_301901115684_item	2332517	et	3	main
tõesti	doc_301901115684_item	2332523	et	3	main
toimuvad	doc_301901115684_item	2332539	et	4	main
perekonna	doc_301901115684_item	2332552	et	4	main
rituaalid	doc_301901115684_item	2332553	et	3	main
muudeti	doc_301901115684_item	2332554	et	3	main
massiliselt	doc_301901115684_item	2332558	et	4	main
suvepäevad	doc_301901115684_item	2332561	et	3	main
lugu	doc_301901115684_item	2332579	et	4	main
raamatud	doc_301901115684_item	2332589	et	4	main
vabariigi	doc_301901115684_item	2332598	et	3	main
sellega	doc_301901115684_item	2332601	et	3	main
arenes	doc_301901115684_item	2332609	et	3	main
pandi	doc_301901115684_item	2332612	et	4	main
milline	doc_301901115684_item	2332616	et	3	main
võeti	doc_301901115684_item	2332619	et	3	main
toodeti	doc_301901115684_item	2332626	et	3	main
aga	doc_301901115684_item	2332628	et	3	main
rohkem	doc_301901115684_item	2332631	et	4	main
kui	doc_301901115684_item	2332645	et	3	main
oli	doc_301901115684_item	2332657	et	3	main
sohvoosid	doc_301901115684_item	2332662	et	4	main
vaesemad	doc_301901115684_item	2332668	et	4	main
inimesed	doc_301901115684_item	2332669	et	3	main
oli	doc_301901115684_item	2332671	et	3	main
nad	doc_301901115684_item	2332681	et	3	main
toimus	doc_301901115684_item	2332687	et	3	main
nähtus	doc_301901115684_item	2332701	et	4	main
nagu	doc_301901115684_item	2332702	et	3	main
puhas	doc_301901115684_item	2332703	et	3	main
ei	doc_301901115684_item	2332705	et	4	main
päritolu	doc_301901115684_item	2332716	et	4	main
kultuurielu	doc_301901115684_item	2332726	et	4	main
kes	doc_301901115684_item	2332740	et	4	main
oleksid	doc_301901115684_item	2332741	et	4	main
kirjandusteostes	doc_301901115684_item	2332746	et	3	main
inimestest	doc_301901115684_item	2332750	et	3	main
mitu	doc_301901115684_item	2332765	et	4	main
vene	doc_301901115684_item	2332771	et	4	main
keele	doc_301901115684_item	2332772	et	4	main
tooge	doc_301901115685_item	2332776	et	3	main
erinevused	doc_301901115685_item	2332779	et	4	main
ja	doc_301901115685_item	2332781	et	3	main
ühiskonnakorralduses	doc_301901115685_item	2332783	et	3	main
ja	doc_301901115685_item	2332784	et	3	main
riigikogu	doc_301901115685_item	2332804	et	4	main
toimusid	doc_301901115685_item	2332807	et	4	main
saavutused	doc_301901115685_item	2332809	et	4	main
näiteks	doc_301901115685_item	2332810	et	4	main
avamine	doc_301901115685_item	2332815	et	4	main
inimesed	doc_301901115685_item	2332820	et	3	main
tegutsesid	doc_301901115685_item	2332831	et	4	main
pärit	doc_301901115685_item	2332839	et	3	main
arendasid	doc_301901115685_item	2332841	et	4	main
eestikeel	doc_301901115685_item	2332845	et	4	main
mitmed	doc_301901115685_item	2332855	et	4	main
ka	doc_301901115685_item	2332896	et	3	main
missugust	doc_301901115685_item	2332901	et	3	main
palka	doc_301901115685_item	2332902	et	4	main
maksta	doc_301901115685_item	2332903	et	4	main
ja	doc_301901115685_item	2332904	et	3	main
tööle	doc_301901115685_item	2332906	et	3	main
eesotsas	doc_301901115685_item	2332914	et	4	main
ülemnõukogu	doc_301901115685_item	2332916	et	4	main
toimus	doc_301901115685_item	2332920	et	3	main
rasketööstus	doc_301901115685_item	2332928	et	3	main
10000	doc_301901115685_item	2332938	et	2	main
siberisse	doc_301901115685_item	2332941	et	4	main
kuskohas	doc_301901115685_item	2332942	et	4	main
seega	doc_301901115685_item	2332948	et	4	main
oli	doc_301901115685_item	2332957	et	3	main
tsentraliseeritud	doc_301901115685_item	2332961	et	4	main
moskvasse	doc_301901115685_item	2332962	et	4	main
ei	doc_301901115685_item	2332963	et	4	main
käinud	doc_301901115685_item	2332972	et	4	main
klassikalist	doc_301901115684_item	2332494	et	4	main
grammafoonis	doc_301901115684_item	2332496	et	4	main
raadio	doc_301901115684_item	2332497	et	4	main
saab	doc_301901115684_item	2332498	et	3	main
ja	doc_301901115684_item	2332507	et	3	main
see	doc_301901115684_item	2332509	et	3	main
kuid	doc_301901115684_item	2332513	et	4	main
eestima	doc_301901115684_item	2332519	et	4	main
kultuurielu	doc_301901115684_item	2332530	et	4	main
arene	doc_301901115684_item	2332532	et	4	main
enam	doc_301901115684_item	2332533	et	4	main
mis	doc_301901115684_item	2332541	et	4	main
lahutatakse	doc_301901115684_item	2332546	et	3	main
seetõttu	doc_301901115684_item	2332548	et	3	main
on	doc_301901115684_item	2332550	et	4	main
usuvabadus	doc_301901115684_item	2332551	et	4	main
tähistatakse	doc_301901115684_item	2332557	et	3	main
seltsidest	doc_301901115684_item	2332577	et	3	main
oli	doc_301901115684_item	2332580	et	3	main
olid	doc_301901115684_item	2332590	et	4	main
eesti	doc_301901115684_item	2332597	et	4	main
taheti	doc_301901115684_item	2332602	et	3	main
mingi	doc_301901115684_item	2332613	et	4	main
monument	doc_301901115684_item	2332614	et	3	main
kristlikke	doc_301901115684_item	2332617	et	3	main
vastu	doc_301901115684_item	2332620	et	3	main
nii	doc_301901115684_item	2332621	et	3	main
elektroonikat	doc_301901115684_item	2332627	et	3	main
põlevkivi	doc_301901115684_item	2332637	et	4	main
oli	doc_301901115684_item	2332638	et	3	main
moskvat	doc_301901115684_item	2332644	et	4	main
kirjandus	doc_301901115684_item	2332647	et	3	main
tolleaegseid	doc_301901115684_item	2332650	et	3	main
m	doc_301901115684_item	2332652	et	4	main
kiik	doc_301901115684_item	2332653	et	3	main
tondiöömaja	doc_301901115684_item	2332654	et	4	main
mõni	doc_301901115684_item	2332655	et	3	main
keelatud	doc_301901115684_item	2332658	et	4	main
ilmusid	doc_301901115684_item	2332659	et	4	main
koonduvad	doc_301901115684_item	2332667	et	4	main
kuid	doc_301901115684_item	2332670	et	4	main
ka	doc_301901115684_item	2332673	et	3	main
järjekordset	doc_301901115684_item	2332683	et	3	main
see	doc_301901115684_item	2332685	et	3	main
2526	doc_301901115684_item	2332688	et	2	main
norm	doc_301901115684_item	2332692	et	3	main
represseeriti	doc_301901115684_item	2332695	et	3	main
ilmus	doc_301901115684_item	2332699	et	4	main
selline	doc_301901115684_item	2332700	et	4	main
eks	doc_301901115684_item	2332709	et	3	main
inimesed	doc_301901115684_item	2332714	et	3	main
partei	doc_301901115684_item	2332722	et	4	main
sotsialistlik	doc_301901115684_item	2332728	et	3	main
oli	doc_301901115684_item	2332734	et	3	main
truu	doc_301901115684_item	2332742	et	4	main
oli	doc_301901115684_item	2332747	et	3	main
eesmärk	doc_301901115684_item	2332754	et	3	main
elu	doc_301901115684_item	2332756	et	4	main
riigi	doc_301901115684_item	2332758	et	3	main
kontrolli	doc_301901115684_item	2332760	et	4	main
all	doc_301901115684_item	2332761	et	3	main
eestimaal	doc_301901115684_item	2332762	et	4	main
ka	doc_301901115684_item	2332764	et	3	main
esindajaid	doc_301901115684_item	2332768	et	4	main
1	doc_301901115685_item	2332775	et	2	main
peamised	doc_301901115685_item	2332778	et	3	main
ev	doc_301901115685_item	2332780	et	4	main
majanduses	doc_301901115685_item	2332785	et	4	main
sulast	doc_301901115685_item	2332795	et	4	main
1	doc_301901115685_item	2332796	et	2	main
ev	doc_301901115685_item	2332797	et	4	main
valitsus	doc_301901115685_item	2332805	et	4	main
seltside	doc_301901115685_item	2332812	et	3	main
haridus	doc_301901115685_item	2332816	et	3	main
said	doc_301901115685_item	2332821	et	4	main
kõrgema	doc_301901115685_item	2332823	et	4	main
sel	doc_301901115685_item	2332825	et	3	main
oli	doc_301901115685_item	2332828	et	3	main
sai	doc_301901115685_item	2332846	et	4	main
õppimise	doc_301901115685_item	2332847	et	4	main
keeleks	doc_301901115685_item	2332848	et	4	main
kena	doc_301901115684_item	2332525	et	4	main
ensv	doc_301901115684_item	2332528	et	4	main
pärastsõjajärgne	doc_301901115684_item	2332529	et	3	main
ei	doc_301901115684_item	2332531	et	4	main
kultuurielu	doc_301901115684_item	2332543	et	4	main
formaalseteks	doc_301901115684_item	2332555	et	4	main
said	doc_301901115684_item	2332559	et	4	main
tekkisid	doc_301901115684_item	2332562	et	4	main
uued	doc_301901115684_item	2332563	et	3	main
tavad	doc_301901115684_item	2332564	et	3	main
riigis	doc_301901115684_item	2332565	et	3	main
on	doc_301901115684_item	2332566	et	4	main
sõna	doc_301901115684_item	2332567	et	4	main
ja	doc_301901115684_item	2332568	et	3	main
trükivabaduse	doc_301901115684_item	2332569	et	4	main
piiramine	doc_301901115684_item	2332570	et	4	main
paljud	doc_301901115684_item	2332571	et	3	main
kirjanikud	doc_301901115684_item	2332572	et	3	main
visatud	doc_301901115684_item	2332574	et	4	main
on	doc_301901115684_item	2332573	et	4	main
välja	doc_301901115684_item	2332575	et	4	main
kirjanikke	doc_301901115684_item	2332576	et	3	main
sama	doc_301901115684_item	2332578	et	4	main
kunstniketega	doc_301901115684_item	2332581	et	4	main
teiste	doc_301901115684_item	2332583	et	4	main
kultuuritegelastega	doc_301901115684_item	2332584	et	3	main
paljusid	doc_301901115684_item	2332585	et	3	main
neist	doc_301901115684_item	2332586	et	4	main
represseeriti	doc_301901115684_item	2332587	et	3	main
paljud	doc_301901115684_item	2332588	et	3	main
hävitamine	doc_301901115684_item	2332595	et	4	main
täielikum	doc_301901115684_item	2332604	et	4	main
kustutada	doc_301901115684_item	2332605	et	3	main
rahva	doc_301901115684_item	2332606	et	3	main
mälu	doc_301901115684_item	2332607	et	4	main
ja	doc_301901115684_item	2332615	et	3	main
sümboleid	doc_301901115684_item	2332618	et	3	main
tõlgendas	doc_301901115684_item	2332625	et	3	main
jaoks	doc_301901115684_item	2332633	et	4	main
rohkem	doc_301901115684_item	2332643	et	4	main
eestit	doc_301901115684_item	2332646	et	3	main
aeg	doc_301901115684_item	2332656	et	3	main
algul	doc_301901115684_item	2332663	et	4	main
sinna	doc_301901115684_item	2332666	et	3	main
palju	doc_301901115684_item	2332672	et	4	main
jõukamaid	doc_301901115684_item	2332674	et	4	main
talupoegi	doc_301901115684_item	2332675	et	4	main
oli	doc_301901115684_item	2332677	et	3	main
et	doc_301901115684_item	2332680	et	3	main
märtsil	doc_301901115684_item	2332689	et	3	main
aastal	doc_301901115684_item	2332691	et	3	main
oli	doc_301901115684_item	2332693	et	3	main
inimest	doc_301901115684_item	2332697	et	3	main
ankeet	doc_301901115684_item	2332704	et	3	main
tohtinud	doc_301901115684_item	2332706	et	4	main
sorteeriti	doc_301901115684_item	2332715	et	3	main
järgi	doc_301901115684_item	2332717	et	4	main
metsavennad	doc_301901115684_item	2332718	et	3	main
muutusid	doc_301901115684_item	2332719	et	4	main
eriti	doc_301901115684_item	2332720	et	3	main
ja	doc_301901115684_item	2332725	et	3	main
2	doc_301901115684_item	2332727	et	2	main
kirjandusvool	doc_301901115684_item	2332731	et	4	main
kirjandus	doc_301901115684_item	2332733	et	3	main
joon	doc_301901115684_item	2332749	et	4	main
oli	doc_301901115684_item	2332763	et	3	main
välja	doc_301901115685_item	2332777	et	4	main
mida	doc_301901115685_item	2332787	et	4	main
kui	doc_301901115685_item	2332789	et	3	main
ja	doc_301901115685_item	2332803	et	3	main
ülikoolide	doc_301901115685_item	2332814	et	3	main
paljud	doc_301901115685_item	2332819	et	3	main
ka	doc_301901115685_item	2332822	et	3	main
hariduse	doc_301901115685_item	2332824	et	3	main
kus	doc_301901115685_item	2332830	et	3	main
haritlased	doc_301901115685_item	2332833	et	3	main
palju	doc_301901115685_item	2332842	et	4	main
1919	doc_301901115685_item	2332844	et	2	main
tü	doc_301901115685_item	2332849	et	4	main
nagu	doc_301901115685_item	2332857	et	3	main
ariste	doc_301901115685_item	2332859	et	4	main
mark	doc_301901115685_item	2332861	et	3	main
saavutuseks	doc_301901115685_item	2332863	et	4	main
kõrgele	doc_301901115685_item	2332870	et	4	main
kui	doc_301901115685_item	2332895	et	3	main
keda	doc_301901115685_item	2332905	et	4	main
partei	doc_301901115685_item	2332908	et	4	main
ja	doc_301901115685_item	2332911	et	3	main
riigistamine	doc_301901115685_item	2332923	et	4	main
18	doc_301901115685_item	2332943	et	2	main
häid	doc_301901115685_item	2332967	et	3	main
pole	doc_301901115685_item	2332970	et	3	main
võimalusi	doc_301901115685_item	2332976	et	3	main
ajal	doc_301901115685_item	2332981	et	4	main
eestlasi	doc_301901115685_item	2332985	et	3	main
kes	doc_301901115685_item	2332988	et	4	main
e	doc_301901115685_item	2333028	et	4	main
ajal	doc_301901115685_item	2333031	et	4	main
ajal	doc_301901115685_item	2333033	et	4	main
pidi	doc_301901115685_item	2333048	et	4	main
tegema	doc_301901115685_item	2333049	et	3	main
eest	doc_301901115685_item	2333052	et	4	main
teadlasi	doc_301901115685_item	2333060	et	3	main
nagu	doc_301901115684_item	2332622	et	3	main
neid	doc_301901115684_item	2332624	et	4	main
see	doc_301901115684_item	2332629	et	3	main
nõukogude	doc_301901115684_item	2332632	et	3	main
ehk	doc_301901115684_item	2332634	et	3	main
sõja	doc_301901115684_item	2332635	et	3	main
jaoks	doc_301901115684_item	2332636	et	4	main
maavaraks	doc_301901115684_item	2332639	et	3	main
mille	doc_301901115684_item	2332640	et	3	main
huvitas	doc_301901115684_item	2332642	et	3	main
peegeldasid	doc_301901115684_item	2332649	et	4	main
kolhoosid	doc_301901115684_item	2332660	et	3	main
et	doc_301901115684_item	2332665	et	3	main
see	doc_301901115684_item	2332676	et	3	main
kartsid	doc_301901115684_item	2332682	et	4	main
1941	doc_301901115684_item	2332690	et	2	main
tehtud	doc_301901115684_item	2332694	et	4	main
30000	doc_301901115684_item	2332696	et	2	main
hariduses	doc_301901115684_item	2332698	et	3	main
sugulasi	doc_301901115684_item	2332708	et	3	main
oleksid	doc_301901115684_item	2332710	et	4	main
kultuuriga	doc_301901115684_item	2332713	et	4	main
agressiivsemateks	doc_301901115684_item	2332721	et	4	main
majandust	doc_301901115684_item	2332724	et	4	main
kui	doc_301901115684_item	2332730	et	3	main
kodumaale	doc_301901115684_item	2332744	et	4	main
kõikides	doc_301901115684_item	2332745	et	4	main
see	doc_301901115684_item	2332752	et	3	main
selle	doc_301901115684_item	2332766	et	4	main
oli	doc_301901115684_item	2332770	et	3	main
kontrolltöö	doc_301901115685_item	2332774	et	4	main
2	doc_301901115685_item	2332786	et	2	main
mõeldakse	doc_301901115685_item	2332788	et	3	main
kultuuriajaloos	doc_301901115685_item	2332791	et	4	main
kõneldakse	doc_301901115685_item	2332792	et	3	main
ajal	doc_301901115685_item	2332798	et	4	main
riigi	doc_301901115685_item	2332799	et	3	main
eesotsas	doc_301901115685_item	2332800	et	4	main
president	doc_301901115685_item	2332802	et	3	main
erinevate	doc_301901115685_item	2332811	et	4	main
väärtuslikuks	doc_301901115685_item	2332818	et	3	main
dikteeris	doc_301901115684_item	2332723	et	3	main
realism	doc_301901115684_item	2332729	et	3	main
kõik	doc_301901115684_item	2332732	et	4	main
samasugune	doc_301901115684_item	2332735	et	3	main
tüükiline	doc_301901115684_item	2332736	et	4	main
inimestest	doc_301901115684_item	2332737	et	3	main
kasvatati	doc_301901115684_item	2332738	et	3	main
kamuniste	doc_301901115684_item	2332739	et	4	main
oma	doc_301901115684_item	2332743	et	4	main
üks	doc_301901115684_item	2332748	et	3	main
kommunistideks	doc_301901115684_item	2332751	et	3	main
oli	doc_301901115684_item	2332753	et	3	main
inimeste	doc_301901115684_item	2332755	et	3	main
oli	doc_301901115684_item	2332757	et	3	main
range	doc_301901115684_item	2332759	et	4	main
voolu	doc_301901115684_item	2332767	et	4	main
õppeprogrammis	doc_301901115684_item	2332769	et	3	main
suurendamine	doc_301901115684_item	2332773	et	4	main
ensv	doc_301901115685_item	2332782	et	4	main
ensv	doc_301901115685_item	2332790	et	4	main
nn	doc_301901115685_item	2332793	et	4	main
hrustshovi	doc_301901115685_item	2332794	et	4	main
oli	doc_301901115685_item	2332801	et	3	main
kultuurielust	doc_301901115685_item	2332806	et	3	main
paljud	doc_301901115685_item	2332808	et	3	main
loomine	doc_301901115685_item	2332813	et	4	main
sai	doc_301901115685_item	2332817	et	4	main
ajal	doc_301901115685_item	2332826	et	4	main
paljud	doc_301901115685_item	2332832	et	3	main
kui	doc_301901115685_item	2332836	et	3	main
eestist	doc_301901115685_item	2332838	et	3	main
nad	doc_301901115685_item	2332840	et	3	main
valdkondi	doc_301901115685_item	2332843	et	4	main
läbi	doc_301901115685_item	2332854	et	4	main
veski	doc_301901115685_item	2332858	et	4	main
oli	doc_301901115685_item	2332864	et	3	main
viimine	doc_301901115685_item	2332869	et	4	main
kultuurielu	doc_301901115685_item	2332894	et	4	main
kommunistlik	doc_301901115685_item	2332898	et	3	main
otsustas	doc_301901115685_item	2332900	et	3	main
võtta	doc_301901115685_item	2332907	et	3	main
vahendid	doc_301901115685_item	2332910	et	3	main
on	doc_301901115685_item	2332915	et	4	main
natsionaliseerimine	doc_301901115685_item	2332921	et	4	main
1941	doc_301901115685_item	2332934	et	2	main
lapsed	doc_301901115685_item	2332945	et	3	main
vanurid	doc_301901115685_item	2332947	et	3	main
kokkuvõteks	doc_301901115685_item	2332949	et	3	main
peamiseks	doc_301901115685_item	2332950	et	3	main
erinevuseks	doc_301901115685_item	2332951	et	4	main
ajal	doc_301901115685_item	2332953	et	4	main
plaanimajanduse	doc_301901115685_item	2332954	et	3	main
teostamine	doc_301901115685_item	2332955	et	4	main
sest	doc_301901115685_item	2332959	et	4	main
teha	doc_301901115685_item	2332966	et	3	main
otsuseid	doc_301901115685_item	2332968	et	3	main
kohal	doc_301901115685_item	2332971	et	4	main
ja	doc_301901115685_item	2332973	et	3	main
situatsiooni	doc_301901115685_item	2332974	et	4	main
ja	doc_301901115685_item	2332975	et	3	main
on	doc_301901115685_item	2332982	et	4	main
ajal	doc_301901115685_item	2332995	et	4	main
natsionaliseeriti	doc_301901115685_item	2333029	et	3	main
astuda	doc_301901115685_item	2333038	et	3	main
kuskohas	doc_301901115685_item	2333040	et	4	main
oma	doc_301901115685_item	2333043	et	4	main
loomad	doc_301901115685_item	2333044	et	3	main
kõigile	doc_301901115685_item	2333045	et	4	main
kasutamiseks	doc_301901115685_item	2333046	et	4	main
ja	doc_301901115685_item	2333047	et	3	main
ja	doc_301901115685_item	2333059	et	3	main
saadeti	doc_301901115685_item	2333063	et	3	main
ensv	doc_301901115685_item	2333065	et	4	main
2	doc_301901115685_item	2333068	et	2	main
suurt	doc_301901115685_item	2333069	et	3	main
küüditamist	doc_301901115685_item	2333070	et	4	main
vanurid	doc_301901115685_item	2333077	et	3	main
paljud	doc_301901115685_item	2333097	et	3	main
rootsisse	doc_301901115685_item	2333101	et	3	main
ankeet	doc_301901115685_item	2333113	et	3	main
2	doc_301901115685_item	2333122	et	2	main
üheks	doc_301901115685_item	2333133	et	3	main
kirik	doc_301901115685_item	2333141	et	3	main
lahutati	doc_301901115685_item	2333142	et	3	main
ning	doc_301901115685_item	2333144	et	3	main
riigile	doc_301901115685_item	2333152	et	3	main
kirikud	doc_301901115685_item	2333155	et	3	main
homo	doc_301901115685_item	2333167	et	4	main
tähistatakse	doc_301901115685_item	2333181	et	3	main
said	doc_301901115685_item	2333217	et	4	main
kodumaale	doc_301901115685_item	2333219	et	4	main
raamatukogu	doc_301901115685_item	2333224	et	4	main
eesti	doc_301901115685_item	2332827	et	4	main
riik	doc_301901115685_item	2332829	et	3	main
nii	doc_301901115685_item	2332834	et	3	main
välismaalt	doc_301901115685_item	2332835	et	3	main
ka	doc_301901115685_item	2332837	et	3	main
eesti	doc_301901115685_item	2332850	et	4	main
keele	doc_301901115685_item	2332851	et	4	main
uurimist	doc_301901115685_item	2332852	et	4	main
haritlased	doc_301901115685_item	2332856	et	3	main
rahvateaduse	doc_301901115685_item	2332868	et	3	main
tasemele	doc_301901115685_item	2332871	et	3	main
emakeele	doc_301901115685_item	2332872	et	4	main
arendamine	doc_301901115685_item	2332873	et	4	main
ja	doc_301901115685_item	2332874	et	3	main
entsüklopeedia	doc_301901115685_item	2332875	et	4	main
ilmumine	doc_301901115685_item	2332876	et	4	main
ühiskondlikud	doc_301901115685_item	2332877	et	3	main
organisatsioonid	doc_301901115685_item	2332878	et	3	main
olid	doc_301901115685_item	2332879	et	4	main
tol	doc_301901115685_item	2332880	et	3	main
väga	doc_301901115685_item	2332882	et	3	main
ajal	doc_301901115685_item	2332881	et	4	main
erinevad	doc_301901115685_item	2332883	et	4	main
nt	doc_301901115685_item	2332884	et	4	main
kaitseliit	doc_301901115685_item	2332885	et	3	main
tuletõrjujate	doc_301901115685_item	2332886	et	3	main
selts	doc_301901115685_item	2332887	et	3	main
jne	doc_301901115685_item	2332888	et	4	main
ensv	doc_301901115685_item	2332889	et	4	main
ajal	doc_301901115685_item	2332890	et	4	main
poliitika	doc_301901115685_item	2332891	et	4	main
reguleeris	doc_301901115685_item	2332892	et	3	main
viisid	doc_301901115685_item	2332853	et	4	main
mägiste	doc_301901115685_item	2332860	et	4	main
ev	doc_301901115685_item	2332862	et	4	main
eesti	doc_301901115685_item	2332865	et	4	main
kultuuri	doc_301901115685_item	2332866	et	4	main
ja	doc_301901115685_item	2332867	et	3	main
majandust	doc_301901115685_item	2332897	et	4	main
valis	doc_301901115685_item	2332909	et	3	main
suunda	doc_301901115685_item	2332912	et	4	main
ehk	doc_301901115685_item	2332922	et	3	main
sisse	doc_301901115685_item	2332925	et	4	main
eriti	doc_301901115685_item	2332929	et	3	main
toodang	doc_301901115685_item	2332931	et	3	main
suur	doc_301901115685_item	2332936	et	3	main
viiakse	doc_301901115685_item	2332940	et	3	main
ensv	doc_301901115685_item	2332952	et	4	main
kui	doc_301901115685_item	2332969	et	3	main
ensv	doc_301901115685_item	2332980	et	4	main
on	doc_301901115685_item	2332986	et	4	main
ensv	doc_301901115685_item	2333030	et	4	main
50	doc_301901115685_item	2333034	et	2	main
vaja	doc_301901115685_item	2333037	et	4	main
palka	doc_301901115685_item	2333055	et	4	main
paljud	doc_301901115685_item	2333056	et	3	main
inimestest	doc_301901115685_item	2333072	et	3	main
ka	doc_301901115685_item	2333074	et	3	main
elama	doc_301901115685_item	2333084	et	3	main
tuhanded	doc_301901115685_item	2333087	et	3	main
ensv	doc_301901115685_item	2333095	et	4	main
valge	doc_301901115685_item	2333112	et	4	main
hruštšovi	doc_301901115685_item	2333123	et	2	main
niisugune	doc_301901115685_item	2333126	et	3	main
süsteemiga	doc_301901115685_item	2333132	et	3	main
see	doc_301901115685_item	2333145	et	3	main
usuvabadust	doc_301901115685_item	2333147	et	4	main
maad	doc_301901115685_item	2333150	et	4	main
riigistati	doc_301901115685_item	2333153	et	3	main
pidid	doc_301901115685_item	2333156	et	4	main
ise	doc_301901115685_item	2333157	et	4	main
elama	doc_301901115685_item	2333158	et	3	main
nii	doc_301901115685_item	2333159	et	3	main
inimesi	doc_301901115685_item	2333163	et	4	main
hakatakse	doc_301901115685_item	2333165	et	3	main
tegutses	doc_301901115685_item	2333170	et	3	main
partei	doc_301901115685_item	2333174	et	4	main
kultuuri	doc_301901115685_item	2333175	et	4	main
tähistama	doc_301901115685_item	2333177	et	3	main
võimaluse	doc_301901115685_item	2333218	et	3	main
tagasi	doc_301901115685_item	2333220	et	3	main
paljud	doc_301901115685_item	2333225	et	3	main
nii	doc_301901115685_item	2332893	et	3	main
partei	doc_301901115685_item	2332899	et	4	main
riigi	doc_301901115685_item	2332913	et	3	main
ja	doc_301901115685_item	2332917	et	3	main
j	doc_301901115685_item	2332918	et	4	main
vers-barbarus	doc_301901115685_item	2332919	et	4	main
seatakse	doc_301901115685_item	2332924	et	4	main
plaanimajandus	doc_301901115685_item	2332926	et	3	main
arenes	doc_301901115685_item	2332927	et	3	main
sõjatehnika	doc_301901115685_item	2332930	et	4	main
14	doc_301901115685_item	2332932	et	2	main
juuni	doc_301901115685_item	2332933	et	4	main
esimene	doc_301901115685_item	2332935	et	3	main
küüditamine	doc_301901115685_item	2332937	et	4	main
inimest	doc_301901115685_item	2332939	et	3	main
olid	doc_301901115685_item	2332944	et	4	main
ja	doc_301901115685_item	2332946	et	3	main
majandus	doc_301901115685_item	2332956	et	4	main
ebaeffektiivne	doc_301901115685_item	2332958	et	4	main
oli	doc_301901115685_item	2332960	et	3	main
ole	doc_301901115685_item	2332964	et	4	main
võimalik	doc_301901115685_item	2332965	et	3	main
kontrollinud	doc_301901115685_item	2332977	et	4	main
eesotsas	doc_301901115685_item	2332979	et	4	main
vähe	doc_301901115685_item	2332987	et	3	main
teavad	doc_301901115685_item	2332989	et	3	main
kultuurielus	doc_301901115685_item	2332996	et	4	main
toimusid	doc_301901115685_item	2332997	et	4	main
erinevused	doc_301901115685_item	2332998	et	4	main
sest	doc_301901115685_item	2332999	et	4	main
kõik	doc_301901115685_item	2333000	et	4	main
ev	doc_301901115685_item	2333001	et	4	main
statujad	doc_301901115685_item	2333002	et	4	main
likvideeriti	doc_301901115685_item	2333003	et	3	main
haridust	doc_301901115685_item	2333004	et	4	main
anti	doc_301901115685_item	2333005	et	3	main
vene	doc_301901115685_item	2333006	et	4	main
keeles	doc_301901115685_item	2333007	et	4	main
ainsaks	doc_301901115685_item	2333008	et	3	main
riigikeeleks	doc_301901115685_item	2333009	et	4	main
sai	doc_301901115685_item	2333010	et	4	main
vene	doc_301901115685_item	2333011	et	4	main
keel	doc_301901115685_item	2333012	et	4	main
kultuuri	doc_301901115685_item	2333013	et	4	main
seltse	doc_301901115685_item	2333014	et	3	main
likvideeriti	doc_301901115685_item	2333015	et	3	main
paljud	doc_301901115685_item	2333016	et	3	main
neist	doc_301901115685_item	2333017	et	4	main
nt	doc_301901115685_item	2333018	et	4	main
ões	doc_301901115685_item	2333019	et	4	main
toimus	doc_301901115685_item	2333020	et	3	main
riigi	doc_301901115685_item	2332978	et	3	main
paljud	doc_301901115685_item	2332983	et	3	main
muurahvased	doc_301901115685_item	2332984	et	4	main
mis	doc_301901115685_item	2332990	et	4	main
riigis	doc_301901115685_item	2332991	et	3	main
hästi	doc_301901115685_item	2332992	et	3	main
toimub	doc_301901115685_item	2332993	et	3	main
ensv	doc_301901115685_item	2332994	et	4	main
venestamine	doc_301901115685_item	2333021	et	4	main
ja	doc_301901115685_item	2333023	et	3	main
isegi	doc_301901115685_item	2333025	et	4	main
riigistati	doc_301901115685_item	2333027	et	3	main
ensv	doc_301901115685_item	2333032	et	4	main
aastatel	doc_301901115685_item	2333035	et	4	main
oli	doc_301901115685_item	2333036	et	3	main
annas	doc_301901115685_item	2333042	et	3	main
päevaplaani	doc_301901115685_item	2333050	et	4	main
kultuuri	doc_301901115685_item	2333057	et	4	main
tegelased	doc_301901115685_item	2333058	et	3	main
olid	doc_301901115685_item	2333073	et	4	main
lapsed	doc_301901115685_item	2333075	et	3	main
ajal	doc_301901115685_item	2333096	et	4	main
kontaktid	doc_301901115685_item	2333104	et	3	main
olid	doc_301901115685_item	2333106	et	4	main
keelatud	doc_301901115685_item	2333107	et	4	main
ensv	doc_301901115685_item	2333108	et	4	main
sula	doc_301901115685_item	2333124	et	4	main
nähtus	doc_301901115685_item	2333127	et	4	main
sellele	doc_301901115685_item	2333135	et	4	main
nad	doc_301901115685_item	2333161	et	3	main
riigis	doc_301901115685_item	2333169	et	3	main
eesti	doc_301901115685_item	2333172	et	4	main
peosid	doc_301901115685_item	2333179	et	3	main
rikkalikult	doc_301901115685_item	2333180	et	4	main
sünnipäevi	doc_301901115685_item	2333182	et	4	main
maad	doc_301901115685_item	2333022	et	4	main
vara	doc_301901115685_item	2333024	et	4	main
loomaid	doc_301901115685_item	2333026	et	4	main
kolhoosidesse	doc_301901115685_item	2333039	et	3	main
rahvas	doc_301901115685_item	2333041	et	4	main
mille	doc_301901115685_item	2333051	et	3	main
sai	doc_301901115685_item	2333053	et	4	main
toitu	doc_301901115685_item	2333054	et	4	main
ning	doc_301901115685_item	2333061	et	3	main
paljud	doc_301901115685_item	2333071	et	3	main
ja	doc_301901115685_item	2333076	et	3	main
siberisse	doc_301901115685_item	2333080	et	4	main
töötama	doc_301901115685_item	2333086	et	3	main
said	doc_301901115685_item	2333088	et	4	main
surma	doc_301901115685_item	2333090	et	4	main
olnud	doc_301901115685_item	2333094	et	4	main
kanadasse	doc_301901115685_item	2333100	et	4	main
jne	doc_301901115685_item	2333103	et	4	main
nendega	doc_301901115685_item	2333105	et	4	main
millega	doc_301901115685_item	2333114	et	3	main
kontrolliti	doc_301901115685_item	2333115	et	3	main
sinu	doc_301901115685_item	2333116	et	3	main
elu	doc_301901115685_item	2333117	et	4	main
ja	doc_301901115685_item	2333118	et	3	main
suhted	doc_301901115685_item	2333119	et	3	main
kontaktid	doc_301901115685_item	2333120	et	3	main
teistega	doc_301901115685_item	2333121	et	4	main
mida	doc_301901115685_item	2333128	et	4	main
võib	doc_301901115685_item	2333129	et	3	main
nimetada	doc_301901115685_item	2333130	et	3	main
said	doc_301901115685_item	2333136	et	4	main
a	doc_301901115685_item	2333138	et	4	main
sündmused	doc_301901115685_item	2333139	et	3	main
ungaris	doc_301901115685_item	2333140	et	4	main
riigist	doc_301901115685_item	2333143	et	3	main
tähendas	doc_301901115685_item	2333146	et	3	main
kõik	doc_301901115685_item	2333148	et	4	main
kuidas	doc_301901115685_item	2333160	et	3	main
ensv-s	doc_301901115685_item	2333164	et	3	main
soveticus	doc_301901115685_item	2333168	et	4	main
ekp	doc_301901115685_item	2333171	et	4	main
kommunistlik	doc_301901115685_item	2333173	et	3	main
uusi	doc_301901115685_item	2333178	et	3	main
nad	doc_301901115685_item	2333216	et	3	main
loomingu	doc_301901115685_item	2333223	et	3	main
autorid	doc_301901115685_item	2333227	et	3	main
rummo	doc_301901115685_item	2333229	et	4	main
haritlasi	doc_301901115685_item	2333062	et	3	main
siberisse	doc_301901115685_item	2333064	et	4	main
ajal	doc_301901115685_item	2333066	et	4	main
toimus	doc_301901115685_item	2333067	et	3	main
neid	doc_301901115685_item	2333078	et	4	main
viidi	doc_301901115685_item	2333079	et	4	main
kus	doc_301901115685_item	2333081	et	3	main
nad	doc_301901115685_item	2333082	et	3	main
pidid	doc_301901115685_item	2333083	et	4	main
ja	doc_301901115685_item	2333085	et	3	main
seal	doc_301901115685_item	2333089	et	4	main
sest	doc_301901115685_item	2333091	et	4	main
toitu	doc_301901115685_item	2333092	et	4	main
ei	doc_301901115685_item	2333093	et	4	main
läksid	doc_301901115685_item	2333098	et	4	main
elama	doc_301901115685_item	2333099	et	3	main
soomesse	doc_301901115685_item	2333102	et	3	main
ajal	doc_301901115685_item	2333109	et	4	main
oli	doc_301901115685_item	2333110	et	3	main
nn	doc_301901115685_item	2333111	et	4	main
toimub	doc_301901115685_item	2333125	et	3	main
kohanemiseks	doc_301901115685_item	2333131	et	4	main
põhjuseks	doc_301901115685_item	2333134	et	3	main
1956	doc_301901115685_item	2333137	et	2	main
riigi	doc_301901115685_item	2333149	et	3	main
võeti	doc_301901115685_item	2333151	et	3	main
ning	doc_301901115685_item	2333154	et	3	main
saavad	doc_301901115685_item	2333162	et	4	main
nimetama	doc_301901115685_item	2333166	et	3	main
hakatakse	doc_301901115685_item	2333176	et	3	main
laulupeosid	doc_301901115685_item	2333183	et	3	main
tehakse	doc_301901115685_item	2333184	et	3	main
majandus	doc_301901115685_item	2333185	et	4	main
ei	doc_301901115685_item	2333186	et	4	main
ole	doc_301901115685_item	2333187	et	4	main
enam	doc_301901115685_item	2333188	et	4	main
nii	doc_301901115685_item	2333189	et	3	main
tsentraliseeritud	doc_301901115685_item	2333190	et	4	main
energetika	doc_301901115685_item	2333191	et	4	main
tööstuse	doc_301901115685_item	2333192	et	3	main
areng	doc_301901115685_item	2333193	et	3	main
majandus	doc_301901115685_item	2333194	et	4	main
kasvas	doc_301901115685_item	2333195	et	3	main
peaaegu	doc_301901115685_item	2333196	et	3	main
2	doc_301901115685_item	2333197	et	2	main
korda	doc_301901115685_item	2333198	et	4	main
mõistati	doc_301901115685_item	2333199	et	4	main
stalini	doc_301901115685_item	2333201	et	4	main
kõik	doc_301901115685_item	2333200	et	4	main
tegevust	doc_301901115685_item	2333202	et	4	main
ja	doc_301901115685_item	2333203	et	3	main
teda	doc_301901115685_item	2333204	et	4	main
tegid	doc_301901115685_item	2333205	et	4	main
üheks	doc_301901115685_item	2333206	et	3	main
mitte	doc_301901115685_item	2333208	et	3	main
süütjaks	doc_301901115685_item	2333207	et	4	main
režiimi	doc_301901115685_item	2333209	et	2	main
vaid	doc_301901115685_item	2333210	et	3	main
isikut	doc_301901115685_item	2333211	et	3	main
paljud	doc_301901115685_item	2333212	et	3	main
eestlased	doc_301901115685_item	2333213	et	3	main
rehabiliteeriti	doc_301901115685_item	2333214	et	3	main
st	doc_301901115685_item	2333215	et	3	main
pöörduma	doc_301901115685_item	2333221	et	3	main
uued	doc_301901115685_item	2333226	et	3	main
avati	doc_301901115685_item	2333222	et	3	main
traat	doc_301901115685_item	2333228	et	3	main
jne	doc_301901115685_item	2333230	et	4	main
kr	doc_323408915250_item	2333821	et	4	main
et	doc_323408915250_item	2333832	et	3	main
metalliaeg	doc_323408915250_item	2333807	et	3	main
on	doc_323408915250_item	2333830	et	4	main
on	doc_323408915250_item	2333844	et	4	main
saaremaalt	doc_323408915250_item	2333846	et	4	main
hakkavad	doc_323408915250_item	2333861	et	4	main
ja	doc_323408915250_item	2333873	et	3	main
lõuna	doc_323408915250_item	2333874	et	4	main
hakati	doc_323408915250_item	2333876	et	3	main
on	doc_323408915250_item	2333888	et	4	main
tööriistad	doc_323408915250_item	2333892	et	3	main
saada	doc_323408915250_item	2333905	et	4	main
saaki	doc_323408915250_item	2333907	et	4	main
osati	doc_323408915250_item	2333908	et	3	main
ka	doc_323408915250_item	2333909	et	3	main
20	doc_323408915250_item	2333918	et	2	main
varane	doc_323408915250_item	2333806	et	4	main
5	doc_323408915250_item	2333822	et	2	main
pronks	doc_323408915250_item	2333825	et	3	main
kasutati	doc_323408915250_item	2333828	et	4	main
eestisse	doc_323408915250_item	2333833	et	4	main
jõudnud	doc_323408915250_item	2333835	et	4	main
1	doc_323408915250_item	2333837	et	2	main
leitud	doc_323408915250_item	2333845	et	4	main
kohapeal	doc_323408915250_item	2333849	et	3	main
ja	doc_323408915250_item	2333859	et	3	main
hulgas	doc_323408915250_item	2333865	et	4	main
ka	doc_323408915250_item	2333866	et	3	main
leitud	doc_323408915250_item	2333871	et	4	main
kasvatama	doc_323408915250_item	2333877	et	4	main
sigu	doc_323408915250_item	2333879	et	3	main
hobuseid	doc_323408915250_item	2333881	et	4	main
tehtud	doc_323408915250_item	2333889	et	4	main
on	doc_323408915250_item	2333893	et	4	main
koristati	doc_323408915250_item	2333896	et	3	main
sellel	doc_323408915250_item	2333898	et	4	main
et	doc_323408915250_item	2333904	et	3	main
paremat	doc_323408915250_item	2333906	et	4	main
jahvatada	doc_323408915250_item	2333912	et	3	main
nad	doc_323408915250_item	2333913	et	3	main
kasutusel	doc_323408915250_item	2333915	et	4	main
hakati	doc_323408915250_item	2333922	et	3	main
lina	doc_323408915250_item	2333924	et	4	main
väga	doc_323408915250_item	2333931	et	3	main
tekstiilileiud	doc_323408915250_item	2333933	et	3	main
leitud	doc_323408915250_item	2333935	et	4	main
ja	doc_323408915250_item	2333936	et	3	main
tööriistu	doc_323408915250_item	2333937	et	3	main
on	doc_323408915250_item	2333943	et	4	main
pronksigi	doc_323408915250_item	2333963	et	4	main
1-5	doc_323408915250_item	2333966	et	2	main
saj	doc_323408915250_item	2333967	et	4	main
kalmete	doc_323408915250_item	2333968	et	3	main
põhjal	doc_323408915250_item	2333969	et	4	main
eristuvad	doc_323408915250_item	2333970	et	4	main
põhja-eesti	doc_323408915250_item	2333976	et	4	main
lääne	doc_323408915250_item	2333979	et	4	main
ja	doc_323408915250_item	2333981	et	3	main
piirkonnad	doc_323408915250_item	2333984	et	4	main
oli	doc_323408915250_item	2333985	et	3	main
ka	doc_323408915250_item	2333986	et	3	main
jaanitule	doc_323408915250_item	2333987	et	4	main
tegemiskombed	doc_323408915250_item	2333988	et	3	main
keskmine	doc_323408915250_item	2333989	et	3	main
rahvaste	doc_323408915250_item	2333996	et	4	main
see	doc_323408915250_item	2333999	et	3	main
oli	doc_323408915250_item	2334000	et	3	main
aeg	doc_323408915250_item	2334002	et	3	main
inimeste	doc_323408915250_item	2334007	et	3	main
tekib	doc_323408915250_item	2334010	et	3	main
skandinaaviaga	doc_323408915250_item	2334011	et	4	main
kivikalmed	doc_323408915250_item	2334012	et	3	main
maetud	doc_323408915250_item	2334019	et	4	main
maa	doc_323408915250_item	2334020	et	4	main
vaid	doc_323408915250_item	2334022	et	3	main
pandi	doc_323408915250_item	2334023	et	4	main
inimesed	doc_323408915250_item	2334026	et	3	main
ehteid	doc_323408915250_item	2334036	et	3	main
peitsid	doc_323408915250_item	2334038	et	4	main
kontrolltöö	doc_323408915250_item	2333804	et	4	main
1	doc_323408915250_item	2333805	et	2	main
eesti	doc_323408915250_item	2333808	et	4	main
territooriumil	doc_323408915250_item	2333809	et	3	main
2	doc_323408915250_item	2333810	et	2	main
mõiste	doc_323408915250_item	2333811	et	4	main
animism	doc_323408915250_item	2333812	et	3	main
tähendus	doc_323408915250_item	2333813	et	4	main
1	doc_323408915250_item	2333814	et	2	main
1	doc_323408915250_item	2333815	et	2	main
pronksiaeg	doc_323408915250_item	2333816	et	3	main
ii	doc_323408915250_item	2333817	et	4	main
aasttuh	doc_323408915250_item	2333818	et	4	main
keskel	doc_323408915250_item	2333819	et	3	main
e	doc_323408915250_item	2333820	et	4	main
saj	doc_323408915250_item	2333823	et	4	main
vask	doc_323408915250_item	2333826	et	3	main
tina	doc_323408915250_item	2333827	et	4	main
lähis-idas	doc_323408915250_item	2333829	et	3	main
on	doc_323408915250_item	2333834	et	4	main
2	doc_323408915250_item	2333840	et	2	main
pronksesemed	doc_323408915250_item	2333843	et	3	main
õpiti	doc_323408915250_item	2333848	et	3	main
tegelema	doc_323408915250_item	2333862	et	3	main
seal	doc_323408915250_item	2333864	et	4	main
lääne	doc_323408915250_item	2333872	et	4	main
söömine	doc_323408915250_item	2333883	et	4	main
kivist	doc_323408915250_item	2333890	et	4	main
sellega	doc_323408915250_item	2333895	et	3	main
vilja	doc_323408915250_item	2333897	et	4	main
on	doc_323408915250_item	2333899	et	4	main
maagiline	doc_323408915250_item	2333900	et	4	main
ja	doc_323408915250_item	2333917	et	3	main
on	doc_323408915250_item	2333947	et	4	main
egiptlaste	doc_323408915250_item	2333949	et	3	main
haualt	doc_323408915250_item	2333950	et	3	main
1300a	doc_323408915250_item	2333951	et	4	main
ekr	doc_323408915250_item	2333952	et	4	main
nagu	doc_323408915250_item	2333962	et	3	main
rauaaeg	doc_323408915250_item	2333965	et	3	main
ja	doc_323408915250_item	2333978	et	3	main
saarte	doc_323408915250_item	2333982	et	3	main
rauaaeg	doc_323408915250_item	2333990	et	3	main
suureks	doc_323408915250_item	2333995	et	4	main
rändamise	doc_323408915250_item	2333997	et	4	main
konflikte	doc_323408915250_item	2334006	et	3	main
konflikt	doc_323408915250_item	2334009	et	3	main
on	doc_323408915250_item	2334013	et	4	main
leitud	doc_323408915250_item	2334014	et	4	main
ka	doc_323408915250_item	2334015	et	3	main
eestist	doc_323408915250_item	2334016	et	3	main
sisse	doc_323408915250_item	2334021	et	4	main
kividega	doc_323408915250_item	2334024	et	3	main
surnutele	doc_323408915250_item	2334030	et	4	main
inimesed	doc_323408915250_item	2334037	et	3	main
oma	doc_323408915250_item	2334039	et	4	main
varanduse	doc_323408915250_item	2334040	et	3	main
vargad	doc_323408915250_item	2334044	et	3	main
hakkavad	doc_323408915250_item	2334058	et	4	main
oli	doc_323408915250_item	2334064	et	3	main
pealikuks	doc_323408915250_item	2334067	et	4	main
kõige	doc_323408915250_item	2334069	et	4	main
hakkati	doc_323408915250_item	2334071	et	3	main
sõna	doc_323408915250_item	2334073	et	4	main
kuningas	doc_323408915250_item	2334074	et	4	main
tegelema	doc_323408915250_item	2334084	et	3	main
veekogude	doc_323408915250_item	2334088	et	3	main
kasutusele	doc_323408915250_item	2334090	et	4	main
tulevad	doc_323408915250_item	2334091	et	4	main
sirp	doc_323408915250_item	2334092	et	3	main
vikat	doc_323408915250_item	2334093	et	3	main
ekr	doc_323408915250_item	2333824	et	4	main
arvatud	doc_323408915250_item	2333831	et	4	main
siis	doc_323408915250_item	2333847	et	3	main
pronksi	doc_323408915250_item	2333850	et	4	main
töötlema	doc_323408915250_item	2333851	et	3	main
vanim	doc_323408915250_item	2333852	et	3	main
pronksiaeg	doc_323408915250_item	2333853	et	3	main
iia	doc_323408915250_item	2333854	et	4	main
e	doc_323408915250_item	2333855	et	4	main
kr	doc_323408915250_item	2333856	et	4	main
kivist	doc_323408915250_item	2333858	et	4	main
pronks	doc_323408915250_item	2333836	et	3	main
valgast	doc_323408915250_item	2333838	et	3	main
ja	doc_323408915250_item	2333839	et	3	main
skandinaaviast	doc_323408915250_item	2333841	et	3	main
esimesed	doc_323408915250_item	2333842	et	3	main
valmistati	doc_323408915250_item	2333857	et	4	main
põllumajandusega	doc_323408915250_item	2333863	et	3	main
loomade	doc_323408915250_item	2333867	et	4	main
kasvatus	doc_323408915250_item	2333868	et	4	main
asulaid	doc_323408915250_item	2333869	et	4	main
eestis	doc_323408915250_item	2333875	et	3	main
veiseid	doc_323408915250_item	2333878	et	3	main
ja	doc_323408915250_item	2333880	et	3	main
hobuseliha	doc_323408915250_item	2333882	et	4	main
keelati	doc_323408915250_item	2333884	et	4	main
sirp	doc_323408915250_item	2333894	et	3	main
tähendus	doc_323408915250_item	2333901	et	4	main
leiti	doc_323408915250_item	2333902	et	3	main
teravilja	doc_323408915250_item	2333910	et	4	main
jahuks	doc_323408915250_item	2333911	et	3	main
olid	doc_323408915250_item	2333914	et	4	main
19	doc_323408915250_item	2333916	et	2	main
alguses	doc_323408915250_item	2333920	et	4	main
kultuuriainetest	doc_323408915250_item	2333921	et	4	main
jaoks	doc_323408915250_item	2333926	et	4	main
on	doc_323408915250_item	2333927	et	4	main
sünvoolne	doc_323408915250_item	2333930	et	4	main
viitavad	doc_323408915250_item	2333939	et	4	main
2	doc_323408915250_item	2333945	et	2	main
rauda	doc_323408915250_item	2333960	et	4	main
kesk-	doc_323408915250_item	2333974	et	3	main
pkr	doc_323408915250_item	2333993	et	4	main
ei	doc_323408915250_item	2334018	et	4	main
eest	doc_323408915250_item	2334029	et	4	main
maeti	doc_323408915250_item	2334055	et	3	main
tekkima	doc_323408915250_item	2334059	et	3	main
suured	doc_323408915250_item	2334060	et	3	main
igas	doc_323408915250_item	2334062	et	3	main
sai	doc_323408915250_item	2334068	et	4	main
noorem	doc_323408915250_item	2334075	et	4	main
kirves	doc_323408915250_item	2334094	et	4	main
ei	doc_323408915250_item	2334129	et	4	main
linnakultuur	doc_323408915250_item	2334135	et	3	main
tol	doc_323408915250_item	2334144	et	3	main
arvasid	doc_323408915250_item	2334147	et	4	main
hing	doc_323408915250_item	2334152	et	3	main
2	doc_323408915251_item	2334168	et	2	main
1	doc_323408915251_item	2334172	et	2	main
ii	doc_323408915251_item	2334177	et	4	main
atekr	doc_323408915251_item	2334178	et	4	main
ja	doc_323408915251_item	2334182	et	3	main
kohtas	doc_323408915251_item	2334192	et	3	main
veel	doc_323408915251_item	2334208	et	4	main
poolel	doc_323408915251_item	2334222	et	4	main
oli	doc_323408915251_item	2334231	et	3	main
kasvatati	doc_323408915251_item	2334233	et	3	main
hobuseid	doc_323408915251_item	2334239	et	4	main
veoloomadena	doc_323408915251_item	2334243	et	3	main
ajaloos	doc_323408915251_item	2334254	et	4	main
anastavalt	doc_323408915251_item	2334258	et	4	main
eluvaldkondades	doc_323408915251_item	2334266	et	3	main
omavahelised	doc_323408915251_item	2334272	et	4	main
vaated	doc_323408915251_item	2334275	et	3	main
uut	doc_323408915251_item	2334282	et	3	main
saaremaal	doc_323408915251_item	2334322	et	4	main
ja	doc_323408915251_item	2334328	et	3	main
kujunes	doc_323408915251_item	2334329	et	3	main
nn	doc_323408915251_item	2334330	et	4	main
patriarhaalne	doc_323408915251_item	2334331	et	3	main
kõigepealt	doc_323408915251_item	2334335	et	3	main
kirst	doc_323408915251_item	2334348	et	3	main
sängitati	doc_323408915251_item	2334350	et	3	main
on	doc_323408915251_item	2334355	et	4	main
veelinde	doc_323408915251_item	2334378	et	4	main
inimesi	doc_323408915251_item	2334380	et	4	main
seotud	doc_323408915251_item	2334384	et	4	main
mille	doc_323408915251_item	2334387	et	3	main
võis	doc_323408915251_item	2334392	et	4	main
inimesi	doc_323408915251_item	2334393	et	4	main
ja	doc_323408915251_item	2334407	et	3	main
vägi	doc_323408915251_item	2334408	et	3	main
luust	doc_323408915250_item	2333860	et	4	main
on	doc_323408915250_item	2333870	et	4	main
ära	doc_323408915250_item	2333885	et	4	main
maaharimisvahend	doc_323408915250_item	2333886	et	3	main
kõblas	doc_323408915250_item	2333887	et	3	main
levinud	doc_323408915250_item	2333891	et	4	main
veekogudes	doc_323408915250_item	2333903	et	3	main
saj	doc_323408915250_item	2333919	et	4	main
kasvatama	doc_323408915250_item	2333923	et	4	main
eestlaste	doc_323408915250_item	2333925	et	4	main
vanad	doc_323408915250_item	2333932	et	3	main
on	doc_323408915250_item	2333934	et	4	main
mis	doc_323408915250_item	2333938	et	4	main
linu	doc_323408915250_item	2333942	et	4	main
raud	doc_323408915250_item	2333946	et	3	main
nii	doc_323408915250_item	2333961	et	3	main
vanem	doc_323408915250_item	2333964	et	4	main
rauaajal	doc_323408915250_item	2333972	et	3	main
selgesti	doc_323408915250_item	2333973	et	3	main
lõuna-	doc_323408915250_item	2333977	et	4	main
eesti	doc_323408915250_item	2333980	et	4	main
suured	doc_323408915250_item	2333983	et	3	main
5-8	doc_323408915250_item	2333991	et	2	main
peetakse	doc_323408915250_item	2333994	et	3	main
ajaks	doc_323408915250_item	2333998	et	4	main
rahutu	doc_323408915250_item	2334001	et	4	main
rohkem	doc_323408915250_item	2334004	et	4	main
inimesi	doc_323408915250_item	2334017	et	4	main
ümber	doc_323408915250_item	2334025	et	3	main
hoolitsesid	doc_323408915250_item	2334027	et	4	main
et	doc_323408915250_item	2334043	et	3	main
ei	doc_323408915250_item	2334045	et	4	main
asulad	doc_323408915250_item	2334061	et	3	main
oma	doc_323408915250_item	2334065	et	4	main
rikkam	doc_323408915250_item	2334070	et	4	main
kasutama	doc_323408915250_item	2334072	et	3	main
rohkem	doc_323408915250_item	2334083	et	4	main
asulad	doc_323408915250_item	2334086	et	3	main
majanduslik	doc_323408915250_item	2334095	et	3	main
hakkavad	doc_323408915250_item	2334123	et	4	main
võõrast	doc_323408915250_item	2334125	et	4	main
jõudu	doc_323408915250_item	2334126	et	4	main
aga	doc_323408915250_item	2334127	et	3	main
aga	doc_323408915250_item	2334136	et	3	main
ei	doc_323408915250_item	2334138	et	4	main
2	doc_323408915250_item	2334140	et	2	main
inimesed	doc_323408915250_item	2334146	et	3	main
et	doc_323408915250_item	2334148	et	3	main
kõikidel	doc_323408915250_item	2334149	et	4	main
lilledel	doc_323408915250_item	2334157	et	4	main
kõikidel	doc_323408915250_item	2334159	et	4	main
territooriumil	doc_323408915251_item	2334167	et	3	main
animism	doc_323408915251_item	2334170	et	3	main
varane	doc_323408915251_item	2334183	et	4	main
esimesel	doc_323408915251_item	2334190	et	3	main
pronksesemeid	doc_323408915251_item	2334193	et	3	main
uus	doc_323408915251_item	2334205	et	3	main
vähe	doc_323408915251_item	2334209	et	3	main
majandusele	doc_323408915251_item	2334211	et	4	main
teisel	doc_323408915251_item	2334221	et	4	main
levima	doc_323408915251_item	2334226	et	3	main
lambaid	doc_323408915251_item	2334236	et	3	main
kasutati	doc_323408915251_item	2334241	et	4	main
toimus	doc_323408915251_item	2334256	et	3	main
muutus	doc_323408915251_item	2334267	et	4	main
maailma	doc_323408915251_item	2334280	et	4	main
varasel	doc_323408915251_item	2334287	et	4	main
matmiskombed	doc_323408915251_item	2334337	et	3	main
animism	doc_323408915251_item	2334354	et	3	main
kujutasid	doc_323408915251_item	2334373	et	4	main
aidata	doc_323408915251_item	2334394	et	4	main
elaval	doc_323408915251_item	2334400	et	4	main
peab	doc_323408915251_item	2334404	et	4	main
see	doc_323408915250_item	2333928	et	3	main
väga	doc_323408915250_item	2333929	et	3	main
sellele	doc_323408915250_item	2333940	et	4	main
et	doc_323408915250_item	2333941	et	3	main
tehtud	doc_323408915250_item	2333944	et	4	main
leitud	doc_323408915250_item	2333948	et	4	main
hakati	doc_323408915250_item	2333953	et	3	main
looduslikult	doc_323408915250_item	2333954	et	4	main
rauda	doc_323408915250_item	2333955	et	4	main
sulatama	doc_323408915250_item	2333956	et	4	main
esialgu	doc_323408915250_item	2333957	et	3	main
toodi	doc_323408915250_item	2333958	et	4	main
skandinaaviast	doc_323408915250_item	2333959	et	3	main
rooma	doc_323408915250_item	2333971	et	4	main
ja	doc_323408915250_item	2333975	et	3	main
saj	doc_323408915250_item	2333992	et	4	main
oli	doc_323408915250_item	2334003	et	3	main
sõdu	doc_323408915250_item	2334005	et	3	main
vahel	doc_323408915250_item	2334008	et	4	main
surnute	doc_323408915250_item	2334028	et	4	main
pandi	doc_323408915250_item	2334031	et	4	main
ka	doc_323408915250_item	2334032	et	3	main
asju	doc_323408915250_item	2334033	et	3	main
kaasa	doc_323408915250_item	2334034	et	4	main
tööriistu	doc_323408915250_item	2334035	et	3	main
alla	doc_323408915250_item	2334042	et	3	main
neid	doc_323408915250_item	2334047	et	4	main
kätte	doc_323408915250_item	2334048	et	4	main
pidasid	doc_323408915250_item	2334050	et	4	main
matusi	doc_323408915250_item	2334053	et	4	main
lõuna-eestis	doc_323408915250_item	2334054	et	3	main
inimesi	doc_323408915250_item	2334056	et	4	main
pealik	doc_323408915250_item	2334066	et	4	main
rauaaeg	doc_323408915250_item	2334076	et	3	main
9-13	doc_323408915250_item	2334077	et	2	main
saj	doc_323408915250_item	2334078	et	4	main
p	doc_323408915250_item	2334079	et	4	main
kr	doc_323408915250_item	2334080	et	4	main
inimesed	doc_323408915250_item	2334081	et	3	main
maaharimisega	doc_323408915250_item	2334085	et	3	main
olukord	doc_323408915250_item	2334096	et	3	main
inimestel	doc_323408915250_item	2334097	et	3	main
tõuseb	doc_323408915250_item	2334098	et	3	main
toitu	doc_323408915250_item	2334099	et	4	main
jääb	doc_323408915250_item	2334100	et	3	main
üle	doc_323408915250_item	2334101	et	3	main
inimesed	doc_323408915250_item	2334102	et	3	main
kauplevad	doc_323408915250_item	2334103	et	4	main
oma	doc_323408915250_item	2334104	et	4	main
viljaga	doc_323408915250_item	2334105	et	3	main
tuleb	doc_323408915250_item	2334106	et	3	main
kasutusele	doc_323408915250_item	2334107	et	4	main
käsitöö	doc_323408915250_item	2334108	et	4	main
meisterdamine	doc_323408915250_item	2334109	et	4	main
kaubandus	doc_323408915250_item	2334110	et	3	main
maad	doc_323408915250_item	2334111	et	4	main
pärandati	doc_323408915250_item	2334112	et	4	main
oma	doc_323408915250_item	2334113	et	4	main
lähimatele	doc_323408915250_item	2334114	et	4	main
sugulastele	doc_323408915250_item	2334115	et	4	main
isa	doc_323408915250_item	2334116	et	4	main
pojale	doc_323408915250_item	2334117	et	4	main
hakkavad	doc_323408915250_item	2334118	et	4	main
tekkima	doc_323408915250_item	2334119	et	3	main
mõisad	doc_323408915250_item	2334120	et	3	main
ja	doc_323408915250_item	2334121	et	3	main
teki	doc_323408915250_item	2334130	et	4	main
teistes	doc_323408915250_item	2334131	et	4	main
hakkas	doc_323408915250_item	2334133	et	3	main
tekkinud	doc_323408915250_item	2334139	et	4	main
mõiste	doc_323408915250_item	2334141	et	4	main
animism	doc_323408915250_item	2334142	et	3	main
tähendus	doc_323408915250_item	2334143	et	4	main
näiteks	doc_323408915250_item	2334153	et	4	main
rohul	doc_323408915250_item	2334155	et	4	main
maa	doc_323408915250_item	2334041	et	4	main
saaks	doc_323408915250_item	2334046	et	3	main
rootslased	doc_323408915250_item	2334049	et	3	main
kõige	doc_323408915250_item	2334051	et	4	main
rikkamaid	doc_323408915250_item	2334052	et	4	main
liivakääpadesse	doc_323408915250_item	2334057	et	4	main
külas	doc_323408915250_item	2334063	et	3	main
hakkasid	doc_323408915250_item	2334082	et	4	main
koonduvad	doc_323408915250_item	2334087	et	4	main
äärde	doc_323408915250_item	2334089	et	4	main
tekkima	doc_323408915250_item	2334134	et	3	main
eestis	doc_323408915250_item	2334137	et	3	main
asjadel	doc_323408915250_item	2334150	et	3	main
neil	doc_323408915250_item	2334158	et	4	main
on	doc_323408915250_item	2334160	et	4	main
hing	doc_323408915250_item	2334161	et	3	main
kontrolltöö	doc_323408915251_item	2334162	et	4	main
1	doc_323408915251_item	2334163	et	2	main
eesti	doc_323408915251_item	2334166	et	4	main
tähendus	doc_323408915251_item	2334171	et	4	main
kuuluvad	doc_323408915251_item	2334175	et	4	main
ekr	doc_323408915251_item	2334181	et	4	main
v	doc_323408915251_item	2334185	et	4	main
ekr-	doc_323408915251_item	2334187	et	4	main
ajaarvamisevahetus	doc_323408915251_item	2334188	et	4	main
pronksiaja	doc_323408915251_item	2334189	et	3	main
harva	doc_323408915251_item	2334195	et	4	main
ja	doc_323408915251_item	2334196	et	3	main
nende	doc_323408915251_item	2334197	et	4	main
seas	doc_323408915251_item	2334198	et	4	main
siis	doc_323408915251_item	2334204	et	3	main
tänu	doc_323408915251_item	2334223	et	4	main
kõige	doc_323408915251_item	2334228	et	4	main
veiseid	doc_323408915251_item	2334234	et	3	main
kitsi	doc_323408915251_item	2334237	et	4	main
pronksi	doc_323408915251_item	2334247	et	4	main
sulama	doc_323408915251_item	2334248	et	4	main
sest	doc_323408915251_item	2334255	et	4	main
tõi	doc_323408915251_item	2334262	et	3	main
kõigis	doc_323408915251_item	2334265	et	4	main
sotsiaalne	doc_323408915251_item	2334269	et	3	main
struktuur	doc_323408915251_item	2334270	et	3	main
uskulised	doc_323408915251_item	2334274	et	4	main
tekkisid	doc_323408915251_item	2334281	et	4	main
tüüpi	doc_323408915251_item	2334283	et	4	main
inimesed	doc_323408915250_item	2334122	et	3	main
kasutama	doc_323408915250_item	2334124	et	3	main
riiki	doc_323408915250_item	2334128	et	4	main
linnades	doc_323408915250_item	2334132	et	3	main
ajal	doc_323408915250_item	2334145	et	4	main
on	doc_323408915250_item	2334151	et	4	main
puudel	doc_323408915250_item	2334154	et	4	main
metalliaeg	doc_323408915251_item	2334165	et	3	main
varasele	doc_323408915251_item	2334173	et	4	main
metalliajale	doc_323408915251_item	2334174	et	3	main
pronksiaeg	doc_323408915251_item	2334176	et	3	main
v	doc_323408915251_item	2334179	et	4	main
saj	doc_323408915251_item	2334180	et	4	main
poolel	doc_323408915251_item	2334191	et	4	main
domineerisid	doc_323408915251_item	2334199	et	4	main
kirved	doc_323408915251_item	2334200	et	3	main
ja	doc_323408915251_item	2334201	et	3	main
odaotsad	doc_323408915251_item	2334202	et	3	main
ja	doc_323408915251_item	2334203	et	3	main
materjal	doc_323408915251_item	2334206	et	3	main
ühiskondliku	doc_323408915251_item	2334218	et	3	main
seisundit	doc_323408915251_item	2334219	et	3	main
pronksiaja	doc_323408915251_item	2334220	et	3	main
elatusala	doc_323408915251_item	2334230	et	4	main
sigu	doc_323408915251_item	2334235	et	3	main
ja	doc_323408915251_item	2334238	et	3	main
ka	doc_323408915251_item	2334242	et	3	main
hakati	doc_323408915251_item	2334244	et	3	main
ise	doc_323408915251_item	2334246	et	4	main
varasel	doc_323408915251_item	2334249	et	4	main
rauaajal	doc_323408915251_item	2334250	et	3	main
oli	doc_323408915251_item	2334251	et	3	main
suur	doc_323408915251_item	2334252	et	3	main
viljelusmajandusele	doc_323408915251_item	2334260	et	3	main
see	doc_323408915251_item	2334261	et	3	main
kaasa	doc_323408915251_item	2334263	et	4	main
ühiskondlik	doc_323408915251_item	2334268	et	3	main
inimeste	doc_323408915251_item	2334271	et	3	main
suhted	doc_323408915251_item	2334273	et	3	main
ja	doc_323408915251_item	2334276	et	3	main
suhtumine	doc_323408915251_item	2334278	et	4	main
asulad	doc_323408915251_item	2334284	et	3	main
hooned	doc_323408915251_item	2334286	et	4	main
roll	doc_323408915251_item	2334326	et	3	main
suurpere	doc_323408915251_item	2334332	et	4	main
hakati	doc_323408915251_item	2334338	et	3	main
kivikirstkalmed	doc_323408915251_item	2334340	et	4	main
kiviring	doc_323408915251_item	2334344	et	3	main
mille	doc_323408915251_item	2334345	et	3	main
oli	doc_323408915251_item	2334347	et	3	main
keskele	doc_323408915251_item	2334349	et	3	main
tavaliselt	doc_323408915251_item	2334351	et	4	main
põtru	doc_323408915251_item	2334377	et	3	main
või	doc_323408915251_item	2334379	et	4	main
olla	doc_323408915251_item	2334383	et	3	main
kujutelmadega	doc_323408915251_item	2334386	et	3	main
järgi	doc_323408915251_item	2334388	et	4	main
olendite	doc_323408915251_item	2334390	et	3	main
hing	doc_323408915251_item	2334391	et	3	main
ohustada	doc_323408915251_item	2334396	et	3	main
samuti	doc_323408915251_item	2334397	et	3	main
et	doc_323408915251_item	2334399	et	3	main
olema	doc_323408915251_item	2334405	et	4	main
hing	doc_323408915251_item	2334406	et	3	main
majadel	doc_323408915250_item	2334156	et	3	main
varane	doc_323408915251_item	2334164	et	4	main
mõiste	doc_323408915251_item	2334169	et	4	main
rauaaeg	doc_323408915251_item	2334184	et	3	main
saj	doc_323408915251_item	2334186	et	4	main
veel	doc_323408915251_item	2334194	et	4	main
avaldas	doc_323408915251_item	2334207	et	3	main
mõju	doc_323408915251_item	2334210	et	4	main
see	doc_323408915251_item	2334212	et	3	main
domineeris	doc_323408915251_item	2334213	et	3	main
rohkem	doc_323408915251_item	2334214	et	4	main
omaniku	doc_323408915251_item	2334215	et	3	main
rikkust	doc_323408915251_item	2334216	et	3	main
ja	doc_323408915251_item	2334217	et	3	main
metallkirvestele	doc_323408915251_item	2334224	et	4	main
hakkas	doc_323408915251_item	2334225	et	3	main
alepõllundus	doc_323408915251_item	2334227	et	3	main
tähtsam	doc_323408915251_item	2334229	et	4	main
koduloomapidamine	doc_323408915251_item	2334232	et	3	main
mida	doc_323408915251_item	2334240	et	4	main
ka	doc_323408915251_item	2334245	et	3	main
tähtsus	doc_323408915251_item	2334253	et	4	main
üleminek	doc_323408915251_item	2334257	et	3	main
majanduselt	doc_323408915251_item	2334259	et	4	main
muutusi	doc_323408915251_item	2334264	et	4	main
üldine	doc_323408915251_item	2334277	et	4	main
ümbritsevasse	doc_323408915251_item	2334279	et	4	main
ja	doc_323408915251_item	2334285	et	3	main
rauaajal	doc_323408915251_item	2334288	et	3	main
kasvatati	doc_323408915251_item	2334289	et	3	main
peamiselt	doc_323408915251_item	2334290	et	4	main
odra	doc_323408915251_item	2334291	et	3	main
nisu	doc_323408915251_item	2334292	et	4	main
hirssi	doc_323408915251_item	2334293	et	4	main
lina	doc_323408915251_item	2334294	et	4	main
ja	doc_323408915251_item	2334295	et	3	main
kanapit	doc_323408915251_item	2334296	et	4	main
tol	doc_323408915251_item	2334297	et	3	main
ajal	doc_323408915251_item	2334298	et	4	main
kari	doc_323408915251_item	2334299	et	4	main
ja	doc_323408915251_item	2334300	et	3	main
pronksesemeid	doc_323408915251_item	2334301	et	3	main
oli	doc_323408915251_item	2334302	et	3	main
tõelised	doc_323408915251_item	2334303	et	4	main
varandused	doc_323408915251_item	2334304	et	3	main
ja	doc_323408915251_item	2334305	et	3	main
siis	doc_323408915251_item	2334306	et	3	main
nende	doc_323408915251_item	2334307	et	4	main
kaitsmiseks	doc_323408915251_item	2334308	et	4	main
ehitati	doc_323408915251_item	2334309	et	3	main
kindlustatud	doc_323408915251_item	2334310	et	4	main
asulaid	doc_323408915251_item	2334311	et	4	main
eestis	doc_323408915251_item	2334312	et	3	main
oli	doc_323408915251_item	2334313	et	3	main
neid	doc_323408915251_item	2334314	et	4	main
kõige	doc_323408915251_item	2334315	et	4	main
rohkem	doc_323408915251_item	2334316	et	4	main
rannikul	doc_323408915251_item	2334317	et	3	main
tuntud	doc_323408915251_item	2334318	et	4	main
on	doc_323408915251_item	2334319	et	4	main
asva	doc_323408915251_item	2334320	et	4	main
asula	doc_323408915251_item	2334321	et	4	main
sellest	doc_323408915251_item	2334333	et	4	main
kõnelevad	doc_323408915251_item	2334334	et	4	main
meest	doc_323408915251_item	2334352	et	4	main
muinasuskumustega	doc_323408915251_item	2334357	et	3	main
tol	doc_323408915251_item	2334358	et	3	main
ajal	doc_323408915251_item	2334359	et	4	main
oli	doc_323408915251_item	2334360	et	3	main
kombeks	doc_323408915251_item	2334361	et	4	main
kanda	doc_323408915251_item	2334362	et	4	main
kaelas	doc_323408915251_item	2334363	et	4	main
või	doc_323408915251_item	2334364	et	4	main
riiete	doc_323408915251_item	2334365	et	3	main
küljes	doc_323408915251_item	2334366	et	4	main
luuplaadist	doc_323408915251_item	2334367	et	3	main
või	doc_323408915251_item	2334368	et	4	main
merevaigust	doc_323408915251_item	2334369	et	4	main
väikesi	doc_323408915251_item	2334370	et	4	main
samuti	doc_323408915251_item	2334323	et	3	main
kasvas	doc_323408915251_item	2334324	et	3	main
mehe	doc_323408915251_item	2334325	et	3	main
ühiskonnas	doc_323408915251_item	2334327	et	4	main
uued	doc_323408915251_item	2334336	et	3	main
ehitama	doc_323408915251_item	2334339	et	4	main
see	doc_323408915251_item	2334341	et	3	main
oli	doc_323408915251_item	2334342	et	3	main
suur	doc_323408915251_item	2334343	et	3	main
keskel	doc_323408915251_item	2334346	et	3	main
2	doc_323408915251_item	2334353	et	2	main
seotud	doc_323408915251_item	2334356	et	4	main
millesed	doc_323408915251_item	2334372	et	4	main
karusid	doc_323408915251_item	2334374	et	3	main
sigu	doc_323408915251_item	2334376	et	3	main
see	doc_323408915251_item	2334381	et	3	main
võib	doc_323408915251_item	2334382	et	3	main
või	doc_323408915251_item	2334395	et	4	main
arvati	doc_323408915251_item	2334398	et	4	main
loodusel	doc_323408915251_item	2334403	et	4	main
kontrolltöö	doc_326260187481_item	2334485	et	4	main
kujutatud	doc_326260187481_item	2334522	et	4	main
eesti	doc_326260187481_item	2334523	et	4	main
1860	doc_326260187481_item	2334527	et	2	main
vanemuine	doc_326260187481_item	2334529	et	4	main
ja	doc_326260187481_item	2334531	et	3	main
kriis	doc_326260187481_item	2334544	et	3	main
selts	doc_326260187481_item	2334548	et	3	main
tegid	doc_326260187481_item	2334556	et	4	main
ja	doc_326260187481_item	2334561	et	3	main
toimusid	doc_326260187481_item	2334566	et	4	main
näidendid	doc_326260187481_item	2334567	et	3	main
peaülesanneks	doc_326260187481_item	2334572	et	3	main
vanemuise	doc_326260187481_item	2334584	et	4	main
seltsi	doc_326260187481_item	2334585	et	4	main
tegutsemise	doc_326260187481_item	2334586	et	4	main
oli	doc_326260187481_item	2334588	et	3	main
arendamisega	doc_326260187481_item	2334629	et	4	main
vanemuise	doc_326260187481_item	2334640	et	4	main
ja	doc_326260187481_item	2334650	et	3	main
seega	doc_326260187481_item	2334652	et	4	main
minevikust	doc_326260187481_item	2334656	et	3	main
merkel	doc_326260187481_item	2334658	et	4	main
eesti	doc_326260187481_item	2334665	et	4	main
armastama	doc_326260187481_item	2334667	et	3	main
olid	doc_326260187481_item	2334669	et	4	main
parandamise	doc_326260187481_item	2334672	et	4	main
tegelesid	doc_326260187481_item	2334675	et	4	main
nad	doc_326260187481_item	2334687	et	3	main
saada	doc_326260187481_item	2334694	et	4	main
estofilid	doc_326260187481_item	2334705	et	4	main
tuleb	doc_326260187481_item	2334709	et	3	main
tartu	doc_326260187481_item	2334711	et	4	main
välja	doc_326260187481_item	2334721	et	4	main
võib	doc_326260187481_item	2334732	et	3	main
pärandada	doc_326260187481_item	2334733	et	3	main
ei	doc_326260187481_item	2334741	et	4	main
talupojad	doc_326260187481_item	2334754	et	4	main
oli	doc_326260187481_item	2334779	et	3	main
nendele	doc_326260187481_item	2334785	et	4	main
vaid	doc_326260187481_item	2334791	et	3	main
estofiilid	doc_326260187481_item	2334802	et	3	main
eesti	doc_326260187481_item	2334806	et	4	main
olukorra	doc_326260187481_item	2334808	et	3	main
parandamiseks	doc_326260187481_item	2334809	et	4	main
kuid	doc_326260187481_item	2334823	et	4	main
ei	doc_326260187481_item	2334827	et	4	main
või	doc_326260187481_item	2334839	et	4	main
natukene	doc_326260187481_item	2334845	et	4	main
suur	doc_326260187481_item	2334859	et	3	main
kujukesi	doc_323408915251_item	2334371	et	4	main
kopraid	doc_323408915251_item	2334375	et	4	main
animistlike	doc_323408915251_item	2334385	et	3	main
vastavate	doc_323408915251_item	2334389	et	4	main
ja	doc_323408915251_item	2334401	et	3	main
elutul	doc_323408915251_item	2334402	et	4	main
kultuuriloost	doc_326260187481_item	2334488	et	4	main
peal	doc_326260187481_item	2334526	et	4	main
tantsuselts	doc_326260187481_item	2334532	et	3	main
ta	doc_326260187481_item	2334533	et	4	main
oli	doc_326260187481_item	2334534	et	3	main
selle	doc_326260187481_item	2334535	et	4	main
seltsi	doc_326260187481_item	2334536	et	4	main
aktiivne	doc_326260187481_item	2334537	et	3	main
19	doc_326260187481_item	2334539	et	2	main
rahvusliku	doc_326260187481_item	2334542	et	3	main
vanemuine	doc_326260187481_item	2334547	et	4	main
eesti	doc_326260187481_item	2334550	et	4	main
kultuuritegelased	doc_326260187481_item	2334562	et	3	main
seltsis	doc_326260187481_item	2334564	et	4	main
vanemuine	doc_326260187481_item	2334570	et	4	main
et	doc_326260187481_item	2334575	et	3	main
eesti	doc_326260187481_item	2334633	et	4	main
ja	doc_326260187481_item	2334635	et	3	main
ilu	doc_326260187481_item	2334639	et	4	main
rahvas	doc_326260187481_item	2334644	et	4	main
kirjanikest	doc_326260187481_item	2334649	et	3	main
peetri	doc_326260187481_item	2334661	et	3	main
olid	doc_326260187481_item	2334662	et	4	main
eesti	doc_326260187481_item	2334670	et	4	main
eluolu	doc_326260187481_item	2334671	et	4	main
ja	doc_326260187481_item	2334679	et	3	main
anda	doc_326260187481_item	2334689	et	3	main
palve	doc_326260187481_item	2334699	et	4	main
et	doc_326260187481_item	2334708	et	3	main
taasavada	doc_326260187481_item	2334710	et	3	main
ülikool	doc_326260187481_item	2334712	et	4	main
1802a	doc_326260187481_item	2334713	et	4	main
avatakse	doc_326260187481_item	2334714	et	4	main
uuesti	doc_326260187481_item	2334715	et	3	main
1802	doc_326260187481_item	2334722	et	2	main
määrus	doc_326260187481_item	2334725	et	3	main
igaüks	doc_326260187481_item	2334726	et	3	main
talupojal	doc_326260187481_item	2334727	et	4	main
on	doc_326260187481_item	2334728	et	4	main
mida	doc_326260187481_item	2334731	et	4	main
ja	doc_326260187481_item	2334734	et	3	main
korras	doc_326260187481_item	2334739	et	4	main
tõsta	doc_326260187481_item	2334746	et	4	main
välja	doc_326260187481_item	2334747	et	4	main
vallakohused	doc_326260187481_item	2334752	et	3	main
pärisorjuse	doc_326260187481_item	2334768	et	3	main
likvideerimine	doc_326260187481_item	2334769	et	4	main
eestimaal	doc_326260187481_item	2334770	et	4	main
ja	doc_326260187481_item	2334771	et	3	main
a	doc_326260187481_item	2334773	et	4	main
liivimaal	doc_326260187481_item	2334774	et	4	main
talupojad	doc_326260187481_item	2334775	et	4	main
talupoegi	doc_326260187481_item	2334782	et	4	main
kuid	doc_326260187481_item	2334784	et	4	main
olnud	doc_326260187481_item	2334788	et	4	main
ja	doc_326260187481_item	2334790	et	3	main
suure	doc_326260187481_item	2334804	et	3	main
eluteed	doc_326260187481_item	2334820	et	4	main
kontrolltöö	doc_326260187481_item	2334486	et	4	main
ärkamisaja	doc_326260187481_item	2334491	et	3	main
kultuuritegelane	doc_326260187481_item	2334492	et	3	main
on	doc_326260187481_item	2334493	et	4	main
kujutatud	doc_326260187481_item	2334494	et	4	main
eesti	doc_326260187481_item	2334495	et	4	main
10-kroonise	doc_326260187481_item	2334496	et	4	main
rahatähe	doc_326260187481_item	2334497	et	3	main
peal	doc_326260187481_item	2334498	et	4	main
mida	doc_326260187481_item	2334499	et	4	main
te	doc_326260187481_item	2334500	et	4	main
tema	doc_326260187481_item	2334501	et	4	main
tegevusest	doc_326260187481_item	2334502	et	4	main
teate	doc_326260187481_item	2334503	et	4	main
2	doc_326260187481_item	2334504	et	2	main
kes	doc_326260187481_item	2334505	et	4	main
olid	doc_326260187481_item	2334506	et	4	main
estofiilid	doc_326260187481_item	2334507	et	3	main
ja	doc_326260187481_item	2334508	et	3	main
milline	doc_326260187481_item	2334509	et	3	main
oli	doc_326260187481_item	2334510	et	3	main
nende	doc_326260187481_item	2334511	et	4	main
panus	doc_326260187481_item	2334512	et	4	main
eesti	doc_326260187481_item	2334513	et	4	main
kultuurilukku	doc_326260187481_item	2334514	et	4	main
1	doc_326260187481_item	2334515	et	2	main
j	doc_326260187481_item	2334516	et	4	main
hurt	doc_326260187481_item	2334517	et	3	main
õpib	doc_326260187481_item	2334518	et	3	main
tü	doc_326260187481_item	2334519	et	4	main
pastoriks	doc_326260187481_item	2334520	et	3	main
a	doc_326260187481_item	2334528	et	4	main
juht	doc_326260187481_item	2334538	et	3	main
saj	doc_326260187481_item	2334540	et	4	main
lõpuaastad	doc_326260187481_item	2334541	et	3	main
jacobson	doc_326260187481_item	2334545	et	4	main
laulu	doc_326260187481_item	2334551	et	4	main
ja	doc_326260187481_item	2334552	et	3	main
eesti	doc_326260187481_item	2334487	et	4	main
1	doc_326260187481_item	2334489	et	2	main
milline	doc_326260187481_item	2334490	et	3	main
rahatähe	doc_326260187481_item	2334525	et	3	main
laulu	doc_326260187481_item	2334530	et	4	main
hurt	doc_326260187481_item	2334546	et	3	main
tegutses	doc_326260187481_item	2334549	et	3	main
koostööd	doc_326260187481_item	2334557	et	4	main
paljud	doc_326260187481_item	2334558	et	3	main
eesti	doc_326260187481_item	2334559	et	4	main
vanemuine	doc_326260187481_item	2334563	et	4	main
esmakordselt	doc_326260187481_item	2334565	et	4	main
eesti	doc_326260187481_item	2334568	et	4	main
oli	doc_326260187481_item	2334573	et	3	main
keeles	doc_326260187481_item	2334578	et	4	main
on	doc_326260187481_item	2334579	et	4	main
teoseid	doc_326260187481_item	2334582	et	3	main
luua	doc_326260187481_item	2334583	et	4	main
võimineesmakordselt	doc_326260187481_item	2334591	et	4	main
laulu-	doc_326260187481_item	2334623	et	4	main
eesti	doc_326260187481_item	2334627	et	4	main
kultuuri	doc_326260187481_item	2334628	et	4	main
kaastegijad	doc_326260187481_item	2334630	et	3	main
sai	doc_326260187481_item	2334645	et	4	main
paremini	doc_326260187481_item	2334646	et	4	main
ka	doc_326260187481_item	2334653	et	3	main
oma	doc_326260187481_item	2334654	et	4	main
2	doc_326260187481_item	2334657	et	2	main
ja	doc_326260187481_item	2334659	et	3	main
esto	doc_326260187481_item	2334664	et	4	main
filo	doc_326260187481_item	2334666	et	4	main
estofiilid	doc_326260187481_item	2334668	et	3	main
huvilised	doc_326260187481_item	2334673	et	4	main
olukorra	doc_326260187481_item	2334677	et	3	main
tahtsid	doc_326260187481_item	2334688	et	4	main
haridust	doc_326260187481_item	2334693	et	4	main
kirjutavad	doc_326260187481_item	2334695	et	4	main
talupoegade	doc_326260187481_item	2334696	et	3	main
seisundi	doc_326260187481_item	2334697	et	3	main
parandamiseks	doc_326260187481_item	2334698	et	4	main
merkel	doc_326260187481_item	2334700	et	4	main
ja	doc_326260187481_item	2334701	et	3	main
saadavad	doc_326260187481_item	2334702	et	4	main
seda	doc_326260187481_item	2334703	et	3	main
tsaarile	doc_326260187481_item	2334704	et	3	main
on	doc_326260187481_item	2334521	et	4	main
10-kroonise	doc_326260187481_item	2334524	et	4	main
liikumise	doc_326260187481_item	2334543	et	4	main
seltsi	doc_326260187481_item	2334571	et	4	main
ka	doc_326260187481_item	2334576	et	3	main
eesti	doc_326260187481_item	2334577	et	4	main
võimalik	doc_326260187481_item	2334580	et	3	main
silmapaistvaid	doc_326260187481_item	2334581	et	3	main
laulupeo	doc_326260187481_item	2334590	et	4	main
see	doc_326260187481_item	2334592	et	3	main
toimus	doc_326260187481_item	2334593	et	3	main
tartus	doc_326260187481_item	2334594	et	3	main
eellaulupidu	doc_326260187481_item	2334595	et	4	main
ja	doc_326260187481_item	2334596	et	3	main
1867	doc_326260187481_item	2334597	et	2	main
a	doc_326260187481_item	2334598	et	4	main
toimus	doc_326260187481_item	2334599	et	3	main
i	doc_326260187481_item	2334600	et	4	main
laulupidu	doc_326260187481_item	2334601	et	4	main
tallinnas	doc_326260187481_item	2334602	et	4	main
seal	doc_326260187481_item	2334603	et	4	main
pidas	doc_326260187481_item	2334604	et	3	main
kõnet	doc_326260187481_item	2334605	et	3	main
jannesen	doc_326260187481_item	2334606	et	4	main
ja	doc_326260187481_item	2334607	et	3	main
jakobson	doc_326260187481_item	2334608	et	4	main
mängiti	doc_326260187481_item	2334609	et	3	main
erinevaid	doc_326260187481_item	2334610	et	4	main
laulu	doc_326260187481_item	2334611	et	4	main
näiteks	doc_326260187481_item	2334612	et	4	main
l	doc_326260187481_item	2334613	et	4	main
koidula	doc_326260187481_item	2334614	et	4	main
esmakordselt	doc_326260187481_item	2334615	et	4	main
laulupeos	doc_326260187481_item	2334616	et	4	main
lauldi	doc_326260187481_item	2334617	et	3	main
eesti	doc_326260187481_item	2334618	et	4	main
tänapäevane	doc_326260187481_item	2334619	et	4	main
hümn	doc_326260187481_item	2334620	et	3	main
tantsu	doc_326260187481_item	2334553	et	4	main
arendamisega	doc_326260187481_item	2334554	et	4	main
sellega	doc_326260187481_item	2334555	et	3	main
huvilised	doc_326260187481_item	2334560	et	4	main
keeles	doc_326260187481_item	2334569	et	4	main
näidata	doc_326260187481_item	2334574	et	4	main
tagajärjeks	doc_326260187481_item	2334587	et	3	main
esimese	doc_326260187481_item	2334589	et	3	main
kokkuvõtteks	doc_326260187481_item	2334621	et	3	main
ja	doc_326260187481_item	2334624	et	3	main
tantsuselts	doc_326260187481_item	2334625	et	3	main
tegeles	doc_326260187481_item	2334626	et	3	main
näidata	doc_326260187481_item	2334632	et	4	main
keele	doc_326260187481_item	2334634	et	4	main
kultuuri	doc_326260187481_item	2334636	et	4	main
omapärasust	doc_326260187481_item	2334637	et	4	main
ja	doc_326260187481_item	2334638	et	3	main
eesti	doc_326260187481_item	2334643	et	4	main
oma	doc_326260187481_item	2334648	et	4	main
kultuurist	doc_326260187481_item	2334655	et	3	main
j	doc_326260187481_item	2334660	et	4	main
talupoegade	doc_326260187481_item	2334676	et	3	main
tegevuse	doc_326260187481_item	2334681	et	4	main
talupoegadele	doc_326260187481_item	2334690	et	3	main
selles	doc_326260187481_item	2334707	et	4	main
õigus	doc_326260187481_item	2334729	et	4	main
vallasvarale	doc_326260187481_item	2334730	et	3	main
on	doc_326260187481_item	2334738	et	4	main
saa	doc_326260187481_item	2334742	et	4	main
talupoega	doc_326260187481_item	2334743	et	4	main
tema	doc_326260187481_item	2334744	et	4	main
majast	doc_326260187481_item	2334745	et	4	main
ära	doc_326260187481_item	2334749	et	4	main
raetakse	doc_326260187481_item	2334751	et	3	main
1816	doc_326260187481_item	2334766	et	2	main
a	doc_326260187481_item	2334767	et	4	main
said	doc_326260187481_item	2334776	et	4	main
et	doc_326260187481_item	2334781	et	3	main
vabastati	doc_326260187481_item	2334783	et	3	main
endale	doc_326260187481_item	2334797	et	4	main
andsid	doc_326260187481_item	2334803	et	4	main
talupoja	doc_326260187481_item	2334807	et	4	main
tänu	doc_326260187481_item	2334810	et	4	main
õigus	doc_326260187481_item	2334817	et	4	main
vabalt	doc_326260187481_item	2334822	et	4	main
ja	doc_326260187481_item	2334833	et	3	main
selle	doc_326260187481_item	2334835	et	4	main
eest	doc_326260187481_item	2334836	et	4	main
ainult	doc_326260187481_item	2334844	et	4	main
nad	doc_326260187481_item	2334848	et	3	main
jaoks	doc_326260187481_item	2334851	et	4	main
olid	doc_326260187481_item	2334855	et	4	main
oli	doc_326260187481_item	2334858	et	3	main
kes	doc_326260187482_item	2334864	et	4	main
esimese	doc_326260187482_item	2334881	et	3	main
tegelased	doc_326260187482_item	2334884	et	3	main
johann	doc_326260187482_item	2334886	et	4	main
algatusel	doc_326260187482_item	2334891	et	4	main
perno	doc_326260187482_item	2334894	et	4	main
postimees	doc_326260187482_item	2334895	et	4	main
kelle	doc_326260187482_item	2334904	et	4	main
tegutses	doc_326260187482_item	2334906	et	3	main
patriootide	doc_326260187482_item	2334908	et	3	main
peterburi	doc_326260187482_item	2334910	et	4	main
keisrile	doc_326260187482_item	2334922	et	3	main
teatavaks	doc_326260187482_item	2334923	et	4	main
nõudmised	doc_326260187482_item	2334944	et	4	main
hariduse	doc_326260187482_item	2334946	et	3	main
aladel	doc_326260187482_item	2334949	et	3	main
see	doc_326260187482_item	2334951	et	3	main
rahvaliikumise	doc_326260187482_item	2334960	et	3	main
ajaloos	doc_326260187482_item	2334961	et	4	main
1843-1886	doc_326260187482_item	2334966	et	2	main
al	doc_326260187482_item	2334968	et	4	main
tahet	doc_326260187482_item	2334980	et	3	main
võib	doc_326260187482_item	2334983	et	3	main
et	doc_326260187482_item	2334987	et	3	main
1865	doc_326260187482_item	2334996	et	2	main
vanemuise	doc_326260187482_item	2335005	et	4	main
algatusel	doc_326260187482_item	2335018	et	4	main
vanemuine	doc_326260187481_item	2334622	et	4	main
tähtsid	doc_326260187481_item	2334631	et	4	main
seltsi	doc_326260187481_item	2334641	et	4	main
abil	doc_326260187481_item	2334642	et	4	main
teada	doc_326260187481_item	2334647	et	3	main
luuletajast	doc_326260187481_item	2334651	et	4	main
estofiilid	doc_326260187481_item	2334663	et	3	main
estofilid	doc_326260187481_item	2334674	et	4	main
parandamisega	doc_326260187481_item	2334678	et	4	main
nende	doc_326260187481_item	2334680	et	4	main
tulemusena	doc_326260187481_item	2334682	et	3	main
võime	doc_326260187481_item	2334683	et	4	main
pidada	doc_326260187481_item	2334684	et	4	main
pärisorjuse	doc_326260187481_item	2334685	et	3	main
likvideerimist	doc_326260187481_item	2334686	et	4	main
võimalust	doc_326260187481_item	2334691	et	3	main
ka	doc_326260187481_item	2334692	et	3	main
настаивать	doc_326260187481_item	2334706	et	2	main
tü	doc_326260187481_item	2334716	et	4	main
nende	doc_326260187481_item	2334717	et	4	main
tegevuse	doc_326260187481_item	2334718	et	4	main
tulemusena	doc_326260187481_item	2334719	et	3	main
ilmub	doc_326260187481_item	2334720	et	3	main
müüa	doc_326260187481_item	2334735	et	3	main
majapidamine	doc_326260187481_item	2334737	et	3	main
siis	doc_326260187481_item	2334740	et	3	main
sundida	doc_326260187481_item	2334748	et	4	main
minema	doc_326260187481_item	2334750	et	3	main
perekonnanimesid	doc_326260187481_item	2334777	et	3	main
ei	doc_326260187481_item	2334787	et	4	main
elukoha	doc_326260187481_item	2334798	et	4	main
vabalt	doc_326260187481_item	2334799	et	4	main
valida	doc_326260187481_item	2334800	et	3	main
kokkuvõtteks	doc_326260187481_item	2334801	et	3	main
vabaks	doc_326260187481_item	2334814	et	3	main
päris	doc_326260187481_item	2334825	et	4	main
niimoodi	doc_326260187481_item	2334826	et	3	main
olnud	doc_326260187481_item	2334828	et	4	main
talupojad	doc_326260187481_item	2334829	et	4	main
tööga	doc_326260187481_item	2334838	et	3	main
oli	doc_326260187481_item	2334842	et	3	main
töötasid	doc_326260187481_item	2334849	et	4	main
orjad	doc_326260187481_item	2334856	et	4	main
rent	doc_326260187481_item	2334857	et	3	main
kontrolltöö	doc_326260187482_item	2334860	et	4	main
olid	doc_326260187482_item	2334865	et	4	main
rahvusliku	doc_326260187482_item	2334868	et	3	main
tegelased	doc_326260187482_item	2334870	et	3	main
eestlaste	doc_326260187482_item	2334877	et	4	main
hariduselu	doc_326260187482_item	2334878	et	4	main
voldemar	doc_326260187482_item	2334887	et	4	main
jannsen	doc_326260187482_item	2334888	et	4	main
mis	doc_326260187482_item	2334896	et	4	main
juhatamisel	doc_326260187482_item	2334905	et	4	main
peterburi	doc_326260187482_item	2334907	et	4	main
a	doc_326260187481_item	2334723	et	4	main
talupoegade	doc_326260187481_item	2334724	et	3	main
kui	doc_326260187481_item	2334736	et	3	main
kuhu	doc_326260187481_item	2334753	et	3	main
tulid	doc_326260187481_item	2334755	et	4	main
oma	doc_326260187481_item	2334756	et	4	main
nendel	doc_326260187481_item	2334758	et	4	main
oli	doc_326260187481_item	2334759	et	3	main
õigus	doc_326260187481_item	2334760	et	4	main
kaebustega	doc_326260187481_item	2334757	et	3	main
mõisnike	doc_326260187481_item	2334761	et	3	main
tegevused	doc_326260187481_item	2334762	et	4	main
опротестовать	doc_326260187481_item	2334763	et	2	main
läbi	doc_326260187481_item	2334764	et	4	main
vaadata	doc_326260187481_item	2334765	et	4	main
1819	doc_326260187481_item	2334772	et	2	main
negatiivne	doc_326260187481_item	2334778	et	3	main
see	doc_326260187481_item	2334780	et	3	main
maad	doc_326260187481_item	2334786	et	4	main
antud	doc_326260187481_item	2334789	et	4	main
alates	doc_326260187481_item	2334792	et	3	main
1832a	doc_326260187481_item	2334793	et	4	main
anti	doc_326260187481_item	2334794	et	3	main
talupoegadele	doc_326260187481_item	2334795	et	3	main
õiguse	doc_326260187481_item	2334796	et	4	main
panuse	doc_326260187481_item	2334805	et	3	main
nendele	doc_326260187481_item	2334811	et	4	main
talupoeg	doc_326260187481_item	2334812	et	3	main
sai	doc_326260187481_item	2334813	et	4	main
tal	doc_326260187481_item	2334815	et	3	main
oli	doc_326260187481_item	2334816	et	3	main
endale	doc_326260187481_item	2334818	et	4	main
oma	doc_326260187481_item	2334819	et	4	main
valida	doc_326260187481_item	2334821	et	3	main
pidid	doc_326260187481_item	2334830	et	4	main
oma	doc_326260187481_item	2334837	et	4	main
parem	doc_326260187481_item	2334846	et	4	main
ajal	doc_326260187481_item	2334853	et	4	main
eesti	doc_326260187482_item	2334862	et	4	main
esimese	doc_326260187482_item	2334867	et	3	main
ärkamisaja	doc_326260187482_item	2334869	et	3	main
meelest	doc_326260187482_item	2334872	et	4	main
edendamisse	doc_326260187482_item	2334879	et	4	main
ärkamisaja	doc_326260187482_item	2334883	et	3	main
on	doc_326260187482_item	2334885	et	4	main
hakkas	doc_326260187482_item	2334892	et	3	main
olukorrast	doc_326260187482_item	2334927	et	4	main
j	doc_326260187482_item	2334929	et	4	main
vennad	doc_326260187482_item	2334931	et	3	main
petersonid	doc_326260187482_item	2334932	et	4	main
kirjutasid	doc_326260187482_item	2334933	et	4	main
palvekirja	doc_326260187482_item	2334934	et	4	main
sisn	doc_326260187482_item	2334935	et	4	main
olid	doc_326260187482_item	2334942	et	4	main
lisandid	doc_326260187482_item	2334943	et	3	main
liikus	doc_326260187482_item	2334952	et	3	main
oli	doc_326260187482_item	2334956	et	3	main
koidula	doc_326260187482_item	2334965	et	4	main
kes	doc_326260187482_item	2334967	et	4	main
iseteadvust	doc_326260187482_item	2334978	et	4	main
üldlaulupeo	doc_326260187482_item	2335002	et	4	main
liikumise	doc_326260187482_item	2335014	et	4	main
tema	doc_326260187482_item	2335017	et	4	main
eest	doc_326260187482_item	2335029	et	4	main
carl	doc_326260187482_item	2335030	et	4	main
robert	doc_326260187482_item	2335031	et	4	main
rahvusliku	doc_326260187482_item	2335038	et	3	main
hurti	doc_326260187482_item	2335045	et	4	main
f	doc_326260187482_item	2335054	et	4	main
eepost	doc_326260187482_item	2335067	et	3	main
ilmus	doc_326260187482_item	2335070	et	4	main
kogu	doc_326260187482_item	2335078	et	4	main
liivimaat	doc_326260187482_item	2335079	et	3	main
ja	doc_326260187482_item	2335080	et	3	main
liikumise	doc_326260187482_item	2335096	et	4	main
kontrolltöö	doc_326260187483_item	2335121	et	4	main
kultuuriloost	doc_326260187483_item	2335124	et	4	main
13	doc_326260187483_item	2335141	et	2	main
linnadeks	doc_326260187483_item	2335153	et	3	main
linnadega	doc_326260187483_item	2335164	et	3	main
olid	doc_326260187483_item	2335167	et	4	main
ja	doc_326260187483_item	2335169	et	3	main
uus-pärnu	doc_326260187483_item	2335170	et	4	main
peetaxe	doc_326260187483_item	2335201	et	4	main
tuli	doc_326260187483_item	2335204	et	4	main
relvakonflikte	doc_326260187483_item	2335207	et	3	main
toitu	doc_326260187483_item	2335215	et	4	main
saj	doc_326260187483_item	2335217	et	4	main
asus	doc_326260187483_item	2335218	et	4	main
kaupmeestest	doc_326260187483_item	2335221	et	4	main
see	doc_326260187483_item	2335227	et	3	main
henrik	doc_326260187483_item	2335240	et	4	main
1205a	doc_326260187483_item	2335245	et	4	main
kroonika	doc_326260187483_item	2335253	et	4	main
seal	doc_326260187483_item	2335260	et	4	main
on	doc_326260187483_item	2335269	et	4	main
see	doc_326260187481_item	2334824	et	3	main
maad	doc_326260187481_item	2334831	et	4	main
rentima	doc_326260187481_item	2334832	et	3	main
maksta	doc_326260187481_item	2334834	et	4	main
saagiga	doc_326260187481_item	2334840	et	4	main
see	doc_326260187481_item	2334841	et	3	main
vaid	doc_326260187481_item	2334843	et	3	main
kui	doc_326260187481_item	2334847	et	3	main
mõisniku	doc_326260187481_item	2334850	et	3	main
sel	doc_326260187481_item	2334852	et	3	main
kui	doc_326260187481_item	2334854	et	3	main
kontrolltöö	doc_326260187482_item	2334861	et	4	main
liikumise	doc_326260187482_item	2334875	et	4	main
rahvusliku	doc_326260187482_item	2334882	et	3	main
paari	doc_326260187482_item	2334898	et	4	main
aastaga	doc_326260187482_item	2334899	et	3	main
leheks	doc_326260187482_item	2334901	et	3	main
köler	doc_326260187482_item	2334903	et	4	main
grupp	doc_326260187482_item	2334909	et	3	main
patriootide	doc_326260187482_item	2334911	et	3	main
j	doc_326260187482_item	2334913	et	4	main
köleri	doc_326260187482_item	2334914	et	4	main
kontaktidest	doc_326260187482_item	2334915	et	3	main
isamaaga	doc_326260187482_item	2334916	et	3	main
sai	doc_326260187482_item	2334917	et	4	main
alguse	doc_326260187482_item	2334918	et	3	main
palvekirjade	doc_326260187482_item	2334919	et	3	main
saatmine	doc_326260187482_item	2334920	et	4	main
teha	doc_326260187482_item	2334924	et	3	main
rahva	doc_326260187482_item	2334925	et	3	main
adamson	doc_326260187482_item	2334937	et	4	main
sai	doc_326260187482_item	2334953	et	4	main
löögi	doc_326260187482_item	2334955	et	4	main
see	doc_326260187482_item	2334957	et	3	main
ikkagi	doc_326260187482_item	2334958	et	4	main
lydia	doc_326260187482_item	2334964	et	4	main
1864	doc_326260187482_item	2334969	et	2	main
oma	doc_326260187482_item	2334972	et	4	main
isamaalaule	doc_326260187482_item	2334974	et	4	main
võidelda	doc_326260187482_item	2334981	et	4	main
lisada	doc_326260187482_item	2334984	et	3	main
veel	doc_326260187482_item	2334985	et	4	main
mänguselts	doc_326260187482_item	2334994	et	3	main
1869a	doc_326260187482_item	2335004	et	4	main
seltsis	doc_326260187482_item	2335006	et	4	main
pids	doc_326260187482_item	2335007	et	4	main
oma	doc_326260187482_item	2335008	et	4	main
kuulsa	doc_326260187482_item	2335009	et	3	main
esimese	doc_326260187482_item	2335010	et	3	main
andekamaid	doc_326260187482_item	2335013	et	4	main
tegelasi	doc_326260187482_item	2335015	et	3	main
ilmus	doc_326260187482_item	2335019	et	4	main
ka	doc_326260187482_item	2335020	et	3	main
ajaleht	doc_326260187482_item	2335021	et	3	main
õigusi	doc_326260187482_item	2335036	et	4	main
eesti	doc_326260187482_item	2335037	et	4	main
võib	doc_326260187482_item	2335041	et	3	main
jakob	doc_326260187482_item	2335044	et	4	main
ja	doc_326260187482_item	2335057	et	3	main
koostasid	doc_326260187482_item	2335066	et	4	main
1730	doc_326260187482_item	2335076	et	2	main
a	doc_326260187482_item	2335077	et	4	main
haaras	doc_326260187482_item	2335082	et	4	main
sellele	doc_326260187482_item	2335088	et	4	main
eesti	doc_326260187482_item	2335091	et	4	main
harituimateist	doc_326260187482_item	2335093	et	4	main
eest	doc_326260187482_item	2335099	et	4	main
elanike	doc_326260187483_item	2335138	et	3	main
eestimaal	doc_326260187483_item	2335143	et	4	main
eestlaste	doc_326260187483_item	2335146	et	4	main
arv	doc_326260187483_item	2335147	et	3	main
tähtsamatex	doc_326260187483_item	2335152	et	4	main
tallinn	doc_326260187483_item	2335155	et	4	main
kultuuriloost	doc_326260187482_item	2334863	et	4	main
tähtsamad	doc_326260187482_item	2334866	et	4	main
sinu	doc_326260187482_item	2334871	et	3	main
miks	doc_326260187482_item	2334873	et	4	main
vennastekoguduse	doc_326260187482_item	2334874	et	3	main
panus	doc_326260187482_item	2334876	et	4	main
tähtsamad	doc_326260187482_item	2334880	et	4	main
1819-1890	doc_326260187482_item	2334889	et	2	main
kelle	doc_326260187482_item	2334890	et	4	main
ilmuma	doc_326260187482_item	2334893	et	3	main
sai	doc_326260187482_item	2334897	et	4	main
ülipopulaarseks	doc_326260187482_item	2334900	et	4	main
johan	doc_326260187482_item	2334902	et	4	main
eeskätt	doc_326260187482_item	2334912	et	3	main
eesmärgiga	doc_326260187482_item	2334921	et	3	main
raskest	doc_326260187482_item	2334926	et	3	main
jaan	doc_326260187482_item	2334936	et	3	main
ja	doc_326260187482_item	2334938	et	3	main
märt	doc_326260187482_item	2334939	et	4	main
jakobsoni	doc_326260187482_item	2334940	et	4	main
poolt	doc_326260187482_item	2334941	et	4	main
kiriku	doc_326260187482_item	2334948	et	3	main
tütar	doc_326260187482_item	2334963	et	3	main
tõstis	doc_326260187482_item	2334976	et	4	main
eestlaste	doc_326260187482_item	2334977	et	4	main
ja	doc_326260187482_item	2334979	et	3	main
jannsenist	doc_326260187482_item	2334982	et	4	main
asustatud	doc_326260187482_item	2334991	et	4	main
laulu-	doc_326260187482_item	2334992	et	4	main
ja	doc_326260187482_item	2334993	et	3	main
a	doc_326260187482_item	2334997	et	4	main
mille	doc_326260187482_item	2334998	et	3	main
oli	doc_326260187482_item	2335000	et	3	main
üks	doc_326260187482_item	2335012	et	3	main
1878a	doc_326260187482_item	2335023	et	4	main
jakobson	doc_326260187482_item	2335032	et	4	main
liikumise	doc_326260187482_item	2335039	et	4	main
ka	doc_326260187482_item	2335043	et	3	main
kes	doc_326260187482_item	2335046	et	4	main
eetilise	doc_326260187482_item	2335049	et	3	main
moraali	doc_326260187482_item	2335050	et	4	main
eelkõige	doc_326260187482_item	2335051	et	3	main
pooldaja	doc_326260187482_item	2335053	et	4	main
rahvaluulet	doc_326260187482_item	2335064	et	3	main
mis	doc_326260187482_item	2335069	et	4	main
tõstis	doc_326260187482_item	2335073	et	4	main
eestlaste	doc_326260187482_item	2335074	et	4	main
iseteadvust	doc_326260187482_item	2335075	et	4	main
eestimaat	doc_326260187482_item	2335081	et	3	main
liikumine	doc_326260187482_item	2335084	et	4	main
tänu	doc_326260187482_item	2335086	et	4	main
liikmed	doc_326260187482_item	2335097	et	3	main
selle	doc_326260187482_item	2335098	et	4	main
kontrolltöö	doc_326260187483_item	2335122	et	4	main
eesti	doc_326260187483_item	2335123	et	4	main
muinasusundi	doc_326260187483_item	2335128	et	3	main
eestlaste	doc_326260187483_item	2335130	et	4	main
arv	doc_326260187483_item	2335139	et	3	main
olid	doc_326260187483_item	2335154	et	4	main
tartu	doc_326260187483_item	2335157	et	4	main
lõpuks	doc_326260187483_item	2335159	et	4	main
tegemist	doc_326260187483_item	2335161	et	4	main
väiksematex	doc_326260187483_item	2335165	et	4	main
linnad	doc_326260187483_item	2335173	et	3	main
jõukamaks	doc_326260187483_item	2335202	et	4	main
ümber	doc_326260187483_item	2335222	et	3	main
gotlandi	doc_326260187483_item	2335224	et	4	main
saarele	doc_326260187483_item	2335225	et	3	main
esimest	doc_326260187483_item	2335237	et	4	main
osa	doc_326260187483_item	2335248	et	4	main
eestlaste	doc_326260187483_item	2335249	et	4	main
eesti	doc_326260187483_item	2335258	et	4	main
i	doc_326260187483_item	2335267	et	4	main
korda	doc_326260187483_item	2335268	et	4	main
kohta	doc_326260187483_item	2335273	et	4	main
esemete	doc_326260187483_item	2335280	et	3	main
pühadex	doc_326260187483_item	2335281	et	4	main
ühiskonda	doc_326260187483_item	2335290	et	4	main
pidid	doc_326260187483_item	2335328	et	4	main
kirikus	doc_326260187483_item	2335330	et	3	main
ristima	doc_326260187483_item	2335336	et	4	main
salakoosolekul	doc_326260187482_item	2334928	et	3	main
köler	doc_326260187482_item	2334930	et	4	main
keele	doc_326260187482_item	2334945	et	4	main
ja	doc_326260187482_item	2334947	et	3	main
kuigi	doc_326260187482_item	2334950	et	3	main
tugeva	doc_326260187482_item	2334954	et	4	main
tähtis	doc_326260187482_item	2334959	et	4	main
jannseni	doc_326260187482_item	2334962	et	4	main
a	doc_326260187482_item	2334970	et	4	main
kirjutas	doc_326260187482_item	2334971	et	3	main
esimesi	doc_326260187482_item	2334973	et	4	main
mis	doc_326260187482_item	2334975	et	4	main
seda	doc_326260187482_item	2334986	et	3	main
tema	doc_326260187482_item	2334988	et	4	main
algatusel	doc_326260187482_item	2334989	et	4	main
oli	doc_326260187482_item	2334990	et	3	main
vanemuine	doc_326260187482_item	2334995	et	4	main
tagajärjeks	doc_326260187482_item	2334999	et	3	main
i	doc_326260187482_item	2335001	et	4	main
toimumine	doc_326260187482_item	2335003	et	4	main
isamaakõne	doc_326260187482_item	2335011	et	4	main
jakobson	doc_326260187482_item	2335016	et	4	main
mis	doc_326260187482_item	2335024	et	4	main
juhiks	doc_326260187482_item	2335040	et	4	main
hariduse	doc_326260187482_item	2335052	et	3	main
hulga	doc_326260187482_item	2335063	et	4	main
ja	doc_326260187482_item	2335065	et	3	main
ilmselt	doc_326260187482_item	2335085	et	4	main
just	doc_326260187482_item	2335087	et	3	main
oli	doc_326260187482_item	2335090	et	3	main
rahval	doc_326260187482_item	2335102	et	3	main
sakala	doc_326260187482_item	2335022	et	4	main
võitles	doc_326260187482_item	2335025	et	3	main
oma	doc_326260187482_item	2335026	et	4	main
rahva	doc_326260187482_item	2335027	et	3	main
õiguste	doc_326260187482_item	2335028	et	4	main
nõudis	doc_326260187482_item	2335033	et	3	main
eestlastele	doc_326260187482_item	2335034	et	4	main
võrdseid	doc_326260187482_item	2335035	et	3	main
pidada	doc_326260187482_item	2335042	et	4	main
kes	doc_326260187482_item	2335047	et	4	main
oli	doc_326260187482_item	2335048	et	3	main
r	doc_326260187482_item	2335055	et	4	main
faehlmann	doc_326260187482_item	2335056	et	4	main
fr	doc_326260187482_item	2335058	et	4	main
kreutzwald	doc_326260187482_item	2335059	et	4	main
kes	doc_326260187482_item	2335060	et	4	main
kogusid	doc_326260187482_item	2335061	et	4	main
suure	doc_326260187482_item	2335062	et	3	main
kalevipoeg	doc_326260187482_item	2335068	et	3	main
1862a	doc_326260187482_item	2335071	et	4	main
ja	doc_326260187482_item	2335072	et	3	main
vennastekoguduse	doc_326260187482_item	2335083	et	3	main
liikumisele	doc_326260187482_item	2335089	et	4	main
üks	doc_326260187482_item	2335092	et	3	main
territooriumitest	doc_326260187482_item	2335094	et	3	main
selle	doc_326260187482_item	2335095	et	4	main
et	doc_326260187482_item	2335100	et	3	main
igal	doc_326260187482_item	2335101	et	3	main
oleks	doc_326260187482_item	2335103	et	3	main
võimalus	doc_326260187482_item	2335104	et	3	main
oma	doc_326260187482_item	2335105	et	4	main
kultuuri	doc_326260187482_item	2335106	et	4	main
luua	doc_326260187482_item	2335107	et	4	main
nemad	doc_326260187482_item	2335108	et	3	main
olid	doc_326260187482_item	2335109	et	4	main
ka	doc_326260187482_item	2335110	et	3	main
need	doc_326260187482_item	2335111	et	3	main
kes	doc_326260187482_item	2335112	et	4	main
väitsid	doc_326260187482_item	2335113	et	4	main
et	doc_326260187482_item	2335114	et	3	main
kõik	doc_326260187482_item	2335115	et	4	main
inimesed	doc_326260187482_item	2335116	et	3	main
on	doc_326260187482_item	2335117	et	4	main
jumala	doc_326260187482_item	2335118	et	3	main
ees	doc_326260187482_item	2335119	et	4	main
võrdsed	doc_326260187482_item	2335120	et	3	main
mis	doc_326260187483_item	2335126	et	4	main
säilimist	doc_326260187483_item	2335129	et	4	main
2	doc_326260187483_item	2335132	et	2	main
oli	doc_326260187483_item	2335140	et	3	main
saj	doc_326260187483_item	2335142	et	4	main
ca	doc_326260187483_item	2335144	et	4	main
200000	doc_326260187483_item	2335145	et	2	main
keskaja	doc_326260187483_item	2335158	et	3	main
oli	doc_326260187483_item	2335160	et	3	main
aga	doc_326260187483_item	2335162	et	3	main
suurte	doc_326260187483_item	2335163	et	3	main
seda	doc_326260187483_item	2335199	et	3	main
linnadevahelisi	doc_326260187483_item	2335206	et	4	main
talupojad	doc_326260187483_item	2335210	et	4	main
neilt	doc_326260187483_item	2335212	et	4	main
nõuti	doc_326260187483_item	2335213	et	3	main
osa	doc_326260187483_item	2335219	et	4	main
ja	doc_326260187483_item	2335226	et	3	main
1	doc_326260187483_item	2335125	et	2	main
soodustas	doc_326260187483_item	2335127	et	3	main
juures	doc_326260187483_item	2335131	et	4	main
mis	doc_326260187483_item	2335133	et	4	main
oli	doc_326260187483_item	2335134	et	3	main
hansa	doc_326260187483_item	2335135	et	4	main
liit	doc_326260187483_item	2335136	et	3	main
2	doc_326260187483_item	2335137	et	2	main
ei	doc_326260187483_item	2335148	et	4	main
ole	doc_326260187483_item	2335149	et	4	main
eraldi	doc_326260187483_item	2335150	et	4	main
teada	doc_326260187483_item	2335151	et	3	main
ja	doc_326260187483_item	2335156	et	3	main
viljandi	doc_326260187483_item	2335168	et	4	main
kuulusid	doc_326260187483_item	2335174	et	4	main
hansa	doc_326260187483_item	2335175	et	4	main
liitu	doc_326260187483_item	2335176	et	4	main
hansa	doc_326260187483_item	2335177	et	4	main
liit	doc_326260187483_item	2335178	et	3	main
oli	doc_326260187483_item	2335179	et	3	main
kaubanduslinnade	doc_326260187483_item	2335180	et	3	main
liit	doc_326260187483_item	2335181	et	3	main
riia	doc_326260187483_item	2335182	et	4	main
oli	doc_326260187483_item	2335183	et	3	main
tähtis	doc_326260187483_item	2335184	et	4	main
kaubanduskeskus	doc_326260187483_item	2335185	et	3	main
kunagine	doc_326260187483_item	2335186	et	3	main
l-e	doc_326260187483_item	2335187	et	3	main
keskus	doc_326260187483_item	2335188	et	3	main
hästi	doc_326260187483_item	2335189	et	3	main
elasid	doc_326260187483_item	2335190	et	4	main
linlased	doc_326260187483_item	2335191	et	3	main
maaadel	doc_326260187483_item	2335193	et	4	main
ja	doc_326260187483_item	2335192	et	3	main
talupojad	doc_326260187483_item	2335194	et	4	main
linnadex	doc_326260187483_item	2335166	et	4	main
kõik	doc_326260187483_item	2335171	et	4	main
need	doc_326260187483_item	2335172	et	3	main
ette	doc_326260187483_item	2335205	et	4	main
kus	doc_326260187483_item	2335208	et	3	main
sest	doc_326260187483_item	2335211	et	4	main
palju	doc_326260187483_item	2335214	et	4	main
lübecki	doc_326260187483_item	2335220	et	4	main
ei	doc_326260187483_item	2335195	et	4	main
olnud	doc_326260187483_item	2335196	et	4	main
veel	doc_326260187483_item	2335197	et	4	main
pärisorjastatud	doc_326260187483_item	2335198	et	4	main
perioodi	doc_326260187483_item	2335200	et	4	main
vahest	doc_326260187483_item	2335203	et	4	main
kannatasid	doc_326260187483_item	2335209	et	4	main
12	doc_326260187483_item	2335216	et	2	main
liidu	doc_326260187483_item	2335230	et	3	main
1	doc_326260187483_item	2335232	et	2	main
henriku	doc_326260187483_item	2335233	et	4	main
korda	doc_326260187483_item	2335238	et	4	main
misjonär	doc_326260187483_item	2335242	et	3	main
levitas	doc_326260187483_item	2335244	et	3	main
võttis	doc_326260187483_item	2335247	et	3	main
ristimisest	doc_326260187483_item	2335250	et	4	main
mis	doc_326260187483_item	2335254	et	4	main
tähtsax	doc_326260187483_item	2335256	et	4	main
on	doc_326260187483_item	2335261	et	4	main
ära	doc_326260187483_item	2335262	et	4	main
toodud	doc_326260187483_item	2335263	et	4	main
kirja	doc_326260187483_item	2335270	et	4	main
eestlaste	doc_326260187483_item	2335275	et	4	main
keskaja	doc_326260187483_item	2335289	et	3	main
selle	doc_326260187483_item	2335321	et	4	main
pidi	doc_326260187483_item	2335335	et	4	main
ja	doc_326260187483_item	2335337	et	3	main
eest	doc_326260187483_item	2335344	et	4	main
maxe	doc_326260187483_item	2335346	et	4	main
eestlased	doc_326260187483_item	2335349	et	3	main
vastu	doc_326260187483_item	2335358	et	3	main
kontrolltöö	doc_326260187484_item	2335372	et	4	main
1	doc_326260187484_item	2335375	et	2	main
mis	doc_326260187484_item	2335376	et	4	main
soodustas	doc_326260187484_item	2335377	et	3	main
muinasusundi	doc_326260187484_item	2335378	et	3	main
mis	doc_326260187484_item	2335383	et	4	main
oli	doc_326260187484_item	2335384	et	3	main
hansa	doc_326260187484_item	2335385	et	4	main
n-ö	doc_326260187484_item	2335432	et	4	main
katolikud	doc_326260187484_item	2335442	et	4	main
tavad	doc_326260187484_item	2335448	et	3	main
ja	doc_326260187484_item	2335453	et	3	main
ajapikku	doc_326260187484_item	2335456	et	3	main
hakati	doc_326260187484_item	2335459	et	3	main
pühapäevased	doc_326260187484_item	2335464	et	4	main
hakkasid	doc_326260187484_item	2335466	et	4	main
keeles	doc_326260187484_item	2335468	et	4	main
saaksid	doc_326260187484_item	2335475	et	4	main
saadeti	doc_326260187484_item	2335476	et	3	main
küladesse	doc_326260187484_item	2335477	et	3	main
aastastele	doc_326260187484_item	2335481	et	4	main
piiblit	doc_326260187484_item	2335486	et	3	main
isa	doc_326260187484_item	2335488	et	4	main
palvet	doc_326260187484_item	2335489	et	3	main
käsku	doc_326260187484_item	2335491	et	4	main
külas	doc_326260187484_item	2335493	et	3	main
ka	doc_326260187484_item	2335522	et	3	main
pulck	doc_326260187484_item	2335525	et	4	main
kõrge	doc_326260187484_item	2335532	et	4	main
1509	doc_326260187484_item	2335534	et	2	main
aastal	doc_326260187484_item	2335535	et	3	main
võetakse	doc_326260187484_item	2335536	et	3	main
ja	doc_326260187484_item	2335542	et	3	main
saab	doc_326260187484_item	2335543	et	3	main
2põhja	doc_326260187484_item	2335546	et	4	main
maade	doc_326260187484_item	2335550	et	3	main
hansa	doc_326260187484_item	2335553	et	4	main
kuhu	doc_326260187484_item	2335555	et	3	main
kuulusid	doc_326260187484_item	2335556	et	4	main
12	doc_326260187484_item	2335558	et	2	main
hansa	doc_326260187484_item	2335600	et	4	main
lübecki	doc_326260187484_item	2335605	et	4	main
olid	doc_326260187484_item	2335607	et	4	main
hansapäevad	doc_326260187484_item	2335609	et	3	main
otsustati	doc_326260187484_item	2335611	et	3	main
mida	doc_333816885024_item	2335620	et	4	main
on	doc_333816885024_item	2335624	et	4	main
ma	doc_333816885024_item	2335629	et	3	main
minu	doc_333816885024_item	2335632	et	3	main
ja	doc_333816885024_item	2335640	et	3	main
veos	doc_333816885024_item	2335644	et	4	main
visbyru	doc_326260187483_item	2335223	et	4	main
oli	doc_326260187483_item	2335228	et	3	main
hansa	doc_326260187483_item	2335229	et	4	main
1740a	doc_326260187483_item	2335239	et	4	main
ristiusku	doc_326260187483_item	2335246	et	4	main
koostas	doc_326260187483_item	2335252	et	4	main
on	doc_326260187483_item	2335255	et	4	main
mälestisex	doc_326260187483_item	2335257	et	4	main
eesti	doc_326260187483_item	2335264	et	4	main
keelseid	doc_326260187483_item	2335265	et	3	main
väljendeid	doc_326260187483_item	2335266	et	3	main
matmiskombed	doc_326260187483_item	2335276	et	3	main
muude	doc_326260187483_item	2335279	et	4	main
eestlased	doc_326260187483_item	2335284	et	3	main
sattunud	doc_326260187483_item	2335286	et	4	main
viikingiaja	doc_326260187483_item	2335287	et	3	main
ühiskonnast	doc_326260187483_item	2335288	et	4	main
oli	doc_326260187483_item	2335292	et	3	main
euroopaga	doc_326260187483_item	2335296	et	3	main
sealt	doc_326260187483_item	2335297	et	4	main
hakkasid	doc_326260187483_item	2335298	et	4	main
side	doc_326260187483_item	2335295	et	4	main
siia	doc_326260187483_item	2335299	et	4	main
ulatuma	doc_326260187483_item	2335300	et	4	main
uued	doc_326260187483_item	2335301	et	3	main
kombed	doc_326260187483_item	2335302	et	3	main
tavad	doc_326260187483_item	2335303	et	3	main
ühiskondlik	doc_326260187483_item	2335304	et	3	main
kord	doc_326260187483_item	2335305	et	4	main
mentaliteet	doc_326260187483_item	2335306	et	3	main
katoliku	doc_326260187483_item	2335307	et	3	main
kirik	doc_326260187483_item	2335308	et	3	main
kehtestas	doc_326260187483_item	2335309	et	3	main
siin	doc_326260187483_item	2335310	et	4	main
talupoegadelt	doc_326260187483_item	2335312	et	3	main
hakati	doc_326260187483_item	2335313	et	3	main
nõudma	doc_326260187483_item	2335314	et	3	main
kümnist	doc_326260187483_item	2335315	et	3	main
tekkisid	doc_326260187483_item	2335316	et	4	main
ülemvõimu	doc_326260187483_item	2335311	et	4	main
uued	doc_326260187483_item	2335317	et	3	main
kloostrid	doc_326260187483_item	2335318	et	3	main
kirikud	doc_326260187483_item	2335319	et	3	main
jne	doc_326260187483_item	2335320	et	4	main
nõudma	doc_326260187483_item	2335326	et	3	main
lapsi	doc_326260187483_item	2335334	et	4	main
surnuid	doc_326260187483_item	2335338	et	4	main
pühitsetud	doc_326260187483_item	2335340	et	4	main
võeti	doc_326260187483_item	2335357	et	3	main
kõik	doc_326260187483_item	2335360	et	4	main
jäi	doc_326260187483_item	2335364	et	3	main
muutumatux	doc_326260187483_item	2335365	et	4	main
kultuuriloost	doc_326260187484_item	2335374	et	4	main
ka	doc_326260187484_item	2335421	et	3	main
austamise	doc_326260187484_item	2335425	et	4	main
aluseks	doc_326260187483_item	2335231	et	4	main
liivimaa	doc_326260187483_item	2335234	et	4	main
kroonika	doc_326260187483_item	2335235	et	4	main
trükiti	doc_326260187483_item	2335236	et	3	main
oli	doc_326260187483_item	2335241	et	3	main
kes	doc_326260187483_item	2335243	et	4	main
tema	doc_326260187483_item	2335251	et	4	main
kultuurist	doc_326260187483_item	2335259	et	3	main
pandud	doc_326260187483_item	2335271	et	4	main
muinasusundi	doc_326260187483_item	2335272	et	3	main
teateid	doc_326260187483_item	2335274	et	3	main
pidamine	doc_326260187483_item	2335282	et	4	main
olid	doc_326260187483_item	2335285	et	4	main
väga	doc_326260187483_item	2335293	et	3	main
puude	doc_326260187483_item	2335277	et	4	main
ja	doc_326260187483_item	2335278	et	3	main
kui	doc_326260187483_item	2335283	et	3	main
siis	doc_326260187483_item	2335291	et	3	main
tihe	doc_326260187483_item	2335294	et	3	main
eest	doc_326260187483_item	2335322	et	4	main
hakkasid	doc_326260187483_item	2335323	et	4	main
maahärrad	doc_326260187483_item	2335324	et	3	main
maxe	doc_326260187483_item	2335325	et	4	main
pühitsetud	doc_326260187483_item	2335331	et	4	main
keelati	doc_326260187483_item	2335332	et	4	main
mitmenaisepidamine	doc_326260187483_item	2335333	et	3	main
matma	doc_326260187483_item	2335339	et	3	main
maale	doc_326260187483_item	2335341	et	4	main
et	doc_326260187483_item	2335348	et	3	main
uus	doc_326260187483_item	2335356	et	3	main
mis	doc_326260187483_item	2335361	et	4	main
puutus	doc_326260187483_item	2335362	et	4	main
põllumajandusse	doc_326260187483_item	2335363	et	3	main
kontrolltöö	doc_326260187484_item	2335371	et	4	main
katoliku	doc_326260187484_item	2335387	et	3	main
õnnistamine	doc_326260187484_item	2335423	et	4	main
polnud	doc_326260187484_item	2335427	et	3	main
neil	doc_326260187484_item	2335428	et	4	main
eestlaste	doc_326260187484_item	2335430	et	4	main
usund	doc_326260187484_item	2335431	et	3	main
säilitati	doc_326260187484_item	2335435	et	3	main
uskumused	doc_326260187484_item	2335445	et	3	main
kiriklikud	doc_326260187484_item	2335447	et	4	main
maagiaga	doc_326260187484_item	2335450	et	3	main
olema	doc_326260187484_item	2335469	et	4	main
et	doc_326260187484_item	2335470	et	3	main
lastele	doc_326260187484_item	2335482	et	4	main
talupoeg	doc_326260187484_item	2335495	et	3	main
kes	doc_326260187484_item	2335497	et	4	main
ristida	doc_326260187484_item	2335499	et	4	main
abielud	doc_326260187483_item	2335327	et	3	main
olema	doc_326260187483_item	2335329	et	4	main
ürituste	doc_326260187483_item	2335343	et	4	main
ajaks	doc_326260187483_item	2335352	et	4	main
juurde	doc_326260187483_item	2335355	et	4	main
visalt	doc_326260187483_item	2335359	et	4	main
talupojad	doc_326260187483_item	2335367	et	4	main
uusi	doc_326260187483_item	2335369	et	3	main
eesti	doc_326260187484_item	2335373	et	4	main
juures	doc_326260187484_item	2335381	et	4	main
2	doc_326260187484_item	2335382	et	2	main
kirik	doc_326260187484_item	2335388	et	3	main
teeb	doc_326260187484_item	2335389	et	3	main
sunniviisiliselt	doc_326260187484_item	2335390	et	4	main
talupoegadest	doc_326260187484_item	2335391	et	3	main
oma	doc_326260187484_item	2335392	et	4	main
kogukondlased	doc_326260187484_item	2335393	et	3	main
eestlased	doc_326260187484_item	2335394	et	3	main
säilitasid	doc_326260187484_item	2335395	et	4	main
aga	doc_326260187484_item	2335396	et	3	main
oma	doc_326260187484_item	2335397	et	4	main
kombed	doc_326260187484_item	2335398	et	3	main
ja	doc_326260187484_item	2335399	et	3	main
tavad	doc_326260187484_item	2335400	et	3	main
osad	doc_326260187484_item	2335401	et	3	main
neist	doc_326260187484_item	2335402	et	4	main
säilisid	doc_326260187484_item	2335403	et	4	main
1718	doc_326260187484_item	2335404	et	2	main
19	doc_326260187484_item	2335406	et	2	main
isegi	doc_326260187484_item	2335405	et	4	main
sajni	doc_326260187484_item	2335407	et	4	main
eestlased	doc_326260187484_item	2335408	et	3	main
omandasid	doc_326260187484_item	2335409	et	4	main
katoliku	doc_326260187484_item	2335410	et	3	main
kiriku	doc_326260187484_item	2335411	et	3	main
välisid	doc_326260187484_item	2335412	et	4	main
kombed	doc_326260187484_item	2335413	et	3	main
kirikus	doc_326260187484_item	2335414	et	3	main
pühakute	doc_326260187484_item	2335416	et	3	main
käimine	doc_326260187484_item	2335415	et	4	main
säilmete	doc_326260187484_item	2335417	et	3	main
austamine	doc_326260187484_item	2335418	et	4	main
talupoegadele	doc_326260187484_item	2335419	et	3	main
meeldis	doc_326260187484_item	2335420	et	3	main
selliste	doc_326260187483_item	2335342	et	4	main
võeti	doc_326260187483_item	2335345	et	3	main
nii	doc_326260187483_item	2335347	et	3	main
jäid	doc_326260187483_item	2335350	et	4	main
pikaks	doc_326260187483_item	2335351	et	4	main
vanade	doc_326260187483_item	2335353	et	3	main
kommete	doc_326260187483_item	2335354	et	4	main
sajanditex	doc_326260187483_item	2335366	et	4	main
õppisid	doc_326260187483_item	2335368	et	4	main
käsitöövõtteid	doc_326260187483_item	2335370	et	3	main
säilimist	doc_326260187484_item	2335379	et	4	main
eestlaste	doc_326260187484_item	2335380	et	4	main
liit	doc_326260187484_item	2335386	et	3	main
külakatoliiklus	doc_326260187484_item	2335433	et	4	main
st	doc_326260187484_item	2335434	et	3	main
ja	doc_326260187484_item	2335438	et	3	main
need	doc_326260187484_item	2335455	et	3	main
üha	doc_326260187484_item	2335460	et	3	main
eesti	doc_326260187484_item	2335467	et	4	main
paremini	doc_326260187484_item	2335472	et	4	main
umbes	doc_326260187484_item	2335479	et	4	main
õpetama	doc_326260187484_item	2335484	et	3	main
meie	doc_326260187484_item	2335487	et	4	main
sai	doc_326260187484_item	2335498	et	4	main
nt	doc_326260187484_item	2335500	et	4	main
vaimulik	doc_326260187484_item	2335533	et	3	main
vastu	doc_326260187484_item	2335537	et	3	main
notarina	doc_326260187484_item	2335545	et	3	main
saksamaa	doc_326260187484_item	2335547	et	4	main
ning	doc_326260187484_item	2335548	et	3	main
linna	doc_326260187484_item	2335560	et	4	main
linnad	doc_326260187484_item	2335563	et	3	main
saksa	doc_326260187484_item	2335565	et	4	main
keelati	doc_326260187484_item	2335587	et	4	main
kauplemine	doc_326260187484_item	2335588	et	4	main
sisemaal	doc_326260187484_item	2335589	et	4	main
polotski	doc_326260187484_item	2335595	et	4	main
nimetada	doc_326260187484_item	2335604	et	3	main
mida	doc_326260187484_item	2335613	et	4	main
essee	doc_333816885024_item	2335615	et	4	main
pühitsemine	doc_326260187484_item	2335422	et	4	main
pühakute	doc_326260187484_item	2335424	et	3	main
vastu	doc_326260187484_item	2335426	et	3	main
oma	doc_326260187484_item	2335436	et	4	main
üle	doc_326260187484_item	2335440	et	3	main
kombed	doc_326260187484_item	2335444	et	3	main
seostati	doc_326260187484_item	2335449	et	3	main
naisetõmbamine	doc_326260187484_item	2335454	et	3	main
kui	doc_326260187484_item	2335463	et	3	main
usust	doc_326260187484_item	2335471	et	3	main
talupojad	doc_326260187484_item	2335473	et	4	main
aru	doc_326260187484_item	2335474	et	4	main
11	doc_326260187484_item	2335480	et	2	main
elementaarselt	doc_326260187484_item	2335485	et	4	main
välja	doc_326260187484_item	2335496	et	4	main
haiget	doc_326260187484_item	2335504	et	3	main
ja	doc_326260187484_item	2335506	et	3	main
tõenäoliselt	doc_326260187484_item	2335507	et	4	main
varsti	doc_326260187484_item	2335508	et	3	main
suri	doc_326260187484_item	2335509	et	3	main
et	doc_326260187484_item	2335510	et	3	main
ta	doc_326260187484_item	2335511	et	4	main
siis	doc_326260187484_item	2335512	et	3	main
kristlikult	doc_326260187484_item	2335513	et	4	main
matta	doc_326260187484_item	2335514	et	3	main
mitmed	doc_326260187484_item	2335515	et	4	main
eestlased	doc_326260187484_item	2335516	et	3	main
said	doc_326260187484_item	2335517	et	4	main
tööd	doc_326260187484_item	2335518	et	4	main
kirikus	doc_326260187484_item	2335519	et	3	main
peamiselt	doc_326260187484_item	2335520	et	4	main
esimene	doc_326260187484_item	2335527	et	3	main
ülikooli	doc_326260187484_item	2335539	et	4	main
eestisse	doc_326260187484_item	2335541	et	4	main
kaubalinnu	doc_326260187484_item	2335551	et	4	main
liivimaa	doc_326260187484_item	2335559	et	4	main
orduriiri	doc_326260187484_item	2335562	et	4	main
vilniuse	doc_326260187484_item	2335592	et	4	main
kaupmehed	doc_326260187484_item	2335596	et	3	main
pealinnaks	doc_326260187484_item	2335602	et	4	main
müüavisi	doc_326260187484_item	2335614	et	4	main
olen	doc_333816885024_item	2335617	et	3	main
ja	doc_333816885024_item	2335619	et	3	main
palju	doc_333816885024_item	2335625	et	4	main
euroopas	doc_333816885024_item	2335634	et	3	main
itaalia	doc_333816885024_item	2335639	et	4	main
koos	doc_333816885024_item	2335647	et	4	main
olen	doc_333816885024_item	2335649	et	3	main
itaalia	doc_333816885024_item	2335651	et	4	main
puuviljud	doc_333816885024_item	2335691	et	4	main
kustutavad	doc_333816885024_item	2335693	et	4	main
sellel	doc_333816885024_item	2335698	et	4	main
itaalias	doc_333816885024_item	2335700	et	4	main
on	doc_333816885024_item	2335701	et	4	main
palju	doc_333816885024_item	2335702	et	4	main
need	doc_333816885024_item	2335710	et	3	main
väga	doc_333816885024_item	2335722	et	3	main
san	doc_333816885024_item	2335724	et	4	main
peakirik	doc_333816885024_item	2335726	et	3	main
väljak	doc_333816885024_item	2335728	et	3	main
toitsin	doc_333816885024_item	2335734	et	3	main
tuvisid	doc_333816885024_item	2335735	et	3	main
on	doc_333816885024_item	2335742	et	4	main
väna	doc_333816885024_item	2335743	et	4	main
kunstnikud	doc_333816885024_item	2335749	et	3	main
mikkel	doc_333816885024_item	2335753	et	4	main
midagi	doc_326260187484_item	2335429	et	4	main
usk	doc_326260187484_item	2335437	et	3	main
võeti	doc_326260187484_item	2335439	et	3	main
ka	doc_326260187484_item	2335441	et	3	main
tavad	doc_326260187484_item	2335443	et	3	main
paljud	doc_326260187484_item	2335446	et	3	main
säilisid	doc_326260187484_item	2335451	et	4	main
veritasu	doc_326260187484_item	2335452	et	4	main
hääbusid	doc_326260187484_item	2335457	et	4	main
jutlustel	doc_326260187484_item	2335458	et	3	main
rohkem	doc_326260187484_item	2335461	et	4	main
käima	doc_326260187484_item	2335462	et	4	main
jutlused	doc_326260187484_item	2335465	et	3	main
rändmungad	doc_326260187484_item	2335478	et	3	main
hakati	doc_326260187484_item	2335483	et	3	main
10	doc_326260187484_item	2335490	et	2	main
õpetati	doc_326260187484_item	2335492	et	3	main
üks	doc_326260187484_item	2335494	et	3	main
sündinud	doc_326260187484_item	2335501	et	4	main
lapsi	doc_326260187484_item	2335502	et	4	main
kes	doc_326260187484_item	2335503	et	4	main
olid	doc_326260187484_item	2335505	et	4	main
rändmunkadena	doc_326260187484_item	2335523	et	3	main
johan	doc_326260187484_item	2335524	et	4	main
teadaolevalt	doc_326260187484_item	2335526	et	4	main
talupojast	doc_326260187484_item	2335528	et	4	main
eestlane	doc_326260187484_item	2335529	et	3	main
kellest	doc_326260187484_item	2335530	et	4	main
rostocki	doc_326260187484_item	2335538	et	4	main
tuleb	doc_326260187484_item	2335540	et	3	main
tööd	doc_326260187484_item	2335544	et	4	main
ühendas	doc_326260187484_item	2335552	et	3	main
ka	doc_326260187484_item	2335557	et	3	main
ning	doc_326260187484_item	2335590	et	3	main
jõekaubandus	doc_326260187484_item	2335591	et	3	main
ja	doc_326260187484_item	2335594	et	3	main
taotlesid	doc_326260187484_item	2335597	et	4	main
osasaamist	doc_326260187484_item	2335599	et	4	main
liitu	doc_326260187484_item	2335601	et	4	main
samuti	doc_326260187484_item	2335606	et	3	main
ka	doc_326260187484_item	2335608	et	3	main
kus	doc_326260187484_item	2335610	et	3	main
kes	doc_326260187484_item	2335612	et	4	main
käinud	doc_333816885024_item	2335618	et	4	main
näinud	doc_333816885024_item	2335622	et	4	main
kohti	doc_333816885024_item	2335627	et	4	main
käia	doc_333816885024_item	2335631	et	4	main
eelmisel	doc_333816885024_item	2335641	et	3	main
käinud	doc_333816885024_item	2335650	et	4	main
huvitavad	doc_333816885024_item	2335659	et	4	main
majad	doc_333816885024_item	2335662	et	3	main
õhutemperatuur	doc_333816885024_item	2335676	et	3	main
olid	doc_333816885024_item	2335687	et	4	main
värsked	doc_333816885024_item	2335688	et	4	main
ja	doc_333816885024_item	2335689	et	3	main
kliimal	doc_333816885024_item	2335699	et	3	main
kuulsad	doc_333816885024_item	2335705	et	3	main
arhitektuuri	doc_333816885024_item	2335707	et	4	main
ja	doc_333816885024_item	2335708	et	3	main
ajaloost	doc_333816885024_item	2335709	et	4	main
lido	doc_333816885024_item	2335714	et	4	main
verona	doc_333816885024_item	2335716	et	4	main
ja	doc_333816885024_item	2335717	et	3	main
edasi	doc_333816885024_item	2335719	et	3	main
on	doc_333816885024_item	2335721	et	4	main
ilus	doc_333816885024_item	2335723	et	4	main
marko	doc_333816885024_item	2335725	et	4	main
seal	doc_333816885024_item	2335731	et	4	main
ikkagi	doc_333816885024_item	2335733	et	4	main
ajalooline	doc_333816885024_item	2335744	et	4	main
seal	doc_333816885024_item	2335746	et	4	main
leonardo	doc_333816885024_item	2335755	et	4	main
vinci	doc_333816885024_item	2335757	et	4	main
see	doc_333816885024_item	2335758	et	3	main
meeldinud	doc_333816885024_item	2335764	et	4	main
lido	doc_333816885024_item	2335765	et	4	main
diezolo	doc_333816885024_item	2335766	et	4	main
on	doc_333816885024_item	2335767	et	4	main
kurordilinn	doc_333816885024_item	2335768	et	4	main
seal	doc_333816885024_item	2335769	et	4	main
mere	doc_333816885024_item	2335776	et	3	main
tõlkidena	doc_326260187484_item	2335521	et	3	main
sai	doc_326260187484_item	2335531	et	4	main
läänemere	doc_326260187484_item	2335549	et	3	main
liit	doc_326260187484_item	2335554	et	3	main
ja	doc_326260187484_item	2335561	et	3	main
preisimaal	doc_326260187484_item	2335564	et	4	main
ordu	doc_326260187484_item	2335566	et	4	main
oli	doc_326260187484_item	2335567	et	3	main
ise	doc_326260187484_item	2335568	et	4	main
suurkaupmeheks	doc_326260187484_item	2335569	et	3	main
kogu	doc_326260187484_item	2335570	et	4	main
läänemere	doc_326260187484_item	2335571	et	3	main
kaubandus	doc_326260187484_item	2335572	et	3	main
oli	doc_326260187484_item	2335573	et	3	main
hansa	doc_326260187484_item	2335574	et	4	main
kontrolli	doc_326260187484_item	2335575	et	4	main
all	doc_326260187484_item	2335576	et	3	main
rootsi	doc_326260187484_item	2335578	et	4	main
ja	doc_326260187484_item	2335579	et	3	main
taani	doc_326260187484_item	2335577	et	4	main
teiste	doc_326260187484_item	2335580	et	4	main
maade	doc_326260187484_item	2335581	et	3	main
konkurents	doc_326260187484_item	2335582	et	3	main
suudeti	doc_326260187484_item	2335583	et	3	main
vaos	doc_326260187484_item	2335584	et	3	main
hoida	doc_326260187484_item	2335585	et	3	main
hansakaupmeestel	doc_326260187484_item	2335586	et	4	main
kaunase	doc_326260187484_item	2335593	et	4	main
tuludest	doc_326260187484_item	2335598	et	3	main
võib	doc_326260187484_item	2335603	et	3	main
kus	doc_333816885024_item	2335616	et	3	main
olen	doc_333816885024_item	2335621	et	3	main
meeles	doc_333816885024_item	2335633	et	3	main
kõige	doc_333816885024_item	2335635	et	4	main
toredam	doc_333816885024_item	2335636	et	4	main
on	doc_333816885024_item	2335638	et	4	main
mul	doc_333816885024_item	2335643	et	3	main
maa	doc_333816885024_item	2335655	et	4	main
kus	doc_333816885024_item	2335656	et	3	main
mälestussambad	doc_333816885024_item	2335660	et	4	main
magusad	doc_333816885024_item	2335690	et	3	main
see	doc_333816885024_item	2335695	et	3	main
oma	doc_333816885024_item	2335706	et	4	main
venetsia	doc_333816885024_item	2335713	et	4	main
diezolo	doc_333816885024_item	2335715	et	4	main
ja	doc_333816885024_item	2335727	et	3	main
ma	doc_333816885024_item	2335729	et	3	main
olin	doc_333816885024_item	2335730	et	3	main
ja	doc_333816885024_item	2335732	et	3	main
me	doc_333816885024_item	2335738	et	4	main
sõitsime	doc_333816885024_item	2335740	et	3	main
rooma	doc_333816885024_item	2335741	et	4	main
ja	doc_333816885024_item	2335750	et	3	main
andželo	doc_333816885024_item	2335754	et	2	main
rohkem	doc_333816885024_item	2335763	et	4	main
päevitasime	doc_333816885024_item	2335778	et	3	main
verona	doc_333816885024_item	2335781	et	4	main
see	doc_333816885024_item	2335783	et	3	main
roomeo	doc_333816885024_item	2335784	et	4	main
linn	doc_333816885024_item	2335791	et	3	main
kord	doc_333816885024_item	2335831	et	4	main
mailmas	doc_333816885024_item	2335623	et	4	main
huvitavaid	doc_333816885024_item	2335626	et	4	main
kus	doc_333816885024_item	2335628	et	3	main
tahaksin	doc_333816885024_item	2335630	et	3	main
maa	doc_333816885024_item	2335637	et	4	main
suvel	doc_333816885024_item	2335642	et	3	main
ja	doc_333816885024_item	2335645	et	3	main
on	doc_333816885024_item	2335652	et	4	main
väga	doc_333816885024_item	2335653	et	3	main
ilus	doc_333816885024_item	2335654	et	4	main
väga	doc_333816885024_item	2335658	et	3	main
ja	doc_333816885024_item	2335663	et	3	main
loodus	doc_333816885024_item	2335664	et	4	main
itaalia	doc_333816885024_item	2335665	et	4	main
loodus	doc_333816885024_item	2335666	et	4	main
on	doc_333816885024_item	2335667	et	4	main
eerineb	doc_333816885024_item	2335668	et	4	main
meie	doc_333816885024_item	2335669	et	4	main
loodust	doc_333816885024_item	2335670	et	4	main
ilmad	doc_333816885024_item	2335671	et	3	main
on	doc_333816885024_item	2335672	et	4	main
soemad	doc_333816885024_item	2335673	et	4	main
kui	doc_333816885024_item	2335674	et	3	main
meie	doc_333816885024_item	2335675	et	4	main
ma	doc_333816885024_item	2335646	et	3	main
perega	doc_333816885024_item	2335648	et	3	main
on	doc_333816885024_item	2335657	et	4	main
muuseumid	doc_333816885024_item	2335661	et	3	main
võib	doc_333816885024_item	2335677	et	3	main
seal	doc_333816885024_item	2335679	et	4	main
vajalik	doc_333816885024_item	2335697	et	3	main
millised	doc_333816885024_item	2335704	et	3	main
rooma	doc_333816885024_item	2335712	et	4	main
olla	doc_333816885024_item	2335678	et	3	main
on	doc_333816885024_item	2335680	et	4	main
väga	doc_333816885024_item	2335681	et	3	main
palju	doc_333816885024_item	2335682	et	4	main
puuvilju	doc_333816885024_item	2335683	et	3	main
ja	doc_333816885024_item	2335684	et	3	main
juurvilju	doc_333816885024_item	2335685	et	3	main
nad	doc_333816885024_item	2335686	et	3	main
hästi	doc_333816885024_item	2335692	et	3	main
jaanu	doc_333816885024_item	2335694	et	4	main
on	doc_333816885024_item	2335696	et	4	main
linnu	doc_333816885024_item	2335703	et	4	main
on	doc_333816885024_item	2335711	et	4	main
nii	doc_333816885024_item	2335718	et	3	main
venetsias	doc_333816885024_item	2335720	et	4	main
veel	doc_333816885024_item	2335736	et	4	main
pealinn	doc_333816885024_item	2335745	et	3	main
kuulsamad	doc_333816885024_item	2335748	et	4	main
skulpterid	doc_333816885024_item	2335751	et	4	main
hotellis	doc_333816885024_item	2335772	et	3	main
adriaatika	doc_333816885024_item	2335775	et	4	main
ja	doc_333816885024_item	2335785	et	3	main
julia	doc_333816885024_item	2335786	et	4	main
linn	doc_333816885024_item	2335787	et	3	main
on	doc_333816885024_item	2335793	et	4	main
ma	doc_333816885024_item	2335828	et	3	main
tahaksin	doc_333816885024_item	2335829	et	3	main
essee	doc_333816885026_item	2335977	et	4	main
parimaks	doc_333816885026_item	2335988	et	4	main
veetmise	doc_333816885026_item	2335990	et	4	main
lõõgastuda	doc_333816885026_item	2335999	et	3	main
taastada	doc_333816885026_item	2336001	et	3	main
puhata	doc_333816885026_item	2336010	et	4	main
on	doc_333816885026_item	2336013	et	4	main
viimase	doc_333816885026_item	2336030	et	3	main
ratsutada	doc_333816885026_item	2336042	et	3	main
see	doc_333816885026_item	2336048	et	3	main
külje	doc_333816885026_item	2336056	et	3	main
talule	doc_333816885026_item	2336058	et	3	main
mis	doc_333816885026_item	2336082	et	4	main
pehme	doc_333816885026_item	2336102	et	4	main
voodiga	doc_333816885026_item	2336108	et	3	main
ja	doc_333816885026_item	2336111	et	3	main
on	doc_333816885026_item	2336114	et	4	main
kokku	doc_333816885026_item	2336116	et	3	main
puhkemaja	doc_333816885026_item	2336118	et	4	main
puhkajate	doc_333816885026_item	2336119	et	4	main
kasutuses	doc_333816885026_item	2336120	et	4	main
seal	doc_333816885024_item	2335737	et	4	main
gondelega	doc_333816885024_item	2335739	et	4	main
tegelisid	doc_333816885024_item	2335747	et	4	main
nagu	doc_333816885024_item	2335752	et	3	main
mulle	doc_333816885024_item	2335761	et	4	main
kõige	doc_333816885024_item	2335762	et	4	main
elasime	doc_333816885024_item	2335771	et	3	main
ääres	doc_333816885024_item	2335777	et	4	main
ja	doc_333816885024_item	2335779	et	3	main
on	doc_333816885024_item	2335789	et	4	main
väga	doc_333816885024_item	2335794	et	3	main
palju	doc_333816885024_item	2335795	et	4	main
nad	doc_333816885024_item	2335797	et	3	main
pood	doc_333816885024_item	2335796	et	4	main
on	doc_333816885024_item	2335798	et	4	main
kallis	doc_333816885024_item	2335799	et	4	main
aga	doc_333816885024_item	2335800	et	3	main
ikkagi	doc_333816885024_item	2335801	et	4	main
väga	doc_333816885024_item	2335802	et	3	main
ilusad	doc_333816885024_item	2335803	et	3	main
ma	doc_333816885024_item	2335804	et	3	main
olin	doc_333816885024_item	2335805	et	3	main
näinud	doc_333816885024_item	2335806	et	4	main
julia	doc_333816885024_item	2335807	et	4	main
rõdu	doc_333816885024_item	2335808	et	4	main
see	doc_333816885024_item	2335809	et	3	main
on	doc_333816885024_item	2335810	et	4	main
tavaline	doc_333816885024_item	2335811	et	4	main
ja	doc_333816885024_item	2335812	et	3	main
praegu	doc_333816885024_item	2335813	et	3	main
sellel	doc_333816885024_item	2335814	et	4	main
majal	doc_333816885024_item	2335815	et	3	main
elab	doc_333816885024_item	2335816	et	3	main
üks	doc_333816885024_item	2335817	et	3	main
perekond	doc_333816885024_item	2335818	et	3	main
linn	doc_333816885024_item	2335819	et	3	main
puudub	doc_333816885024_item	2335820	et	3	main
da	doc_333816885024_item	2335756	et	4	main
linn	doc_333816885024_item	2335759	et	3	main
on	doc_333816885024_item	2335760	et	4	main
me	doc_333816885024_item	2335770	et	4	main
me	doc_333816885024_item	2335773	et	4	main
puhkasime	doc_333816885024_item	2335774	et	3	main
suplesime	doc_333816885024_item	2335780	et	3	main
on	doc_333816885024_item	2335782	et	4	main
see	doc_333816885024_item	2335788	et	3	main
seal	doc_333816885024_item	2335792	et	4	main
rohelises	doc_333816885024_item	2335821	et	4	main
meeldis	doc_333816885024_item	2335824	et	3	main
seal	doc_333816885024_item	2335825	et	4	main
nüüd	doc_333816885024_item	2335827	et	4	main
kus	doc_333816885026_item	2335978	et	3	main
olen	doc_333816885026_item	2335983	et	3	main
minu	doc_333816885026_item	2335985	et	3	main
vaba	doc_333816885026_item	2335989	et	4	main
viisiks	doc_333816885026_item	2335991	et	4	main
aktiivne	doc_333816885026_item	2335992	et	3	main
aktiivne	doc_333816885026_item	2335994	et	3	main
ennesetunnet	doc_333816885026_item	2335997	et	4	main
puhkajaid	doc_333816885026_item	2336016	et	4	main
meelitab	doc_333816885026_item	2336017	et	3	main
looduses	doc_333816885026_item	2336019	et	4	main
samuti	doc_333816885026_item	2336024	et	3	main
saab	doc_333816885026_item	2336025	et	3	main
ka	doc_333816885026_item	2336027	et	3	main
saanud	doc_333816885026_item	2336034	et	4	main
lisaks	doc_333816885026_item	2336037	et	4	main
hobusega	doc_333816885026_item	2336041	et	4	main
suvel	doc_333816885026_item	2336044	et	3	main
hobusetalu	doc_333816885026_item	2336050	et	4	main
asub	doc_333816885026_item	2336052	et	3	main
kuulub	doc_333816885026_item	2336059	et	3	main
ilus	doc_333816885026_item	2336061	et	4	main
seonduvad	doc_333816885026_item	2336083	et	4	main
hobustega	doc_333816885026_item	2336084	et	4	main
ratsustada	doc_333816885026_item	2336086	et	4	main
kolessiga	doc_333816885026_item	2336088	et	4	main
loodusesse	doc_333816885026_item	2336092	et	4	main
elasime	doc_333816885026_item	2336094	et	3	main
telefoniga	doc_333816885026_item	2336106	et	4	main
terass	doc_333816885026_item	2336110	et	4	main
ööbimiseks	doc_333816885026_item	2336113	et	4	main
talus	doc_333816885026_item	2336115	et	4	main
10	doc_333816885026_item	2336117	et	2	main
paadid	doc_333816885026_item	2336125	et	3	main
inimesed	doc_333816885026_item	2336154	et	3	main
tunne	doc_333816885026_item	2336158	et	4	main
millised	doc_333816885026_item	2336164	et	3	main
on	doc_333816885026_item	2336166	et	4	main
kodumaal	doc_333816885026_item	2336167	et	4	main
rohkem	doc_333816885026_item	2336174	et	4	main
pealinna	doc_333816885026_item	2336178	et	4	main
ka	doc_333816885026_item	2336191	et	3	main
horisondini	doc_333816885026_item	2336194	et	3	main
sadelevad	doc_333816885026_item	2336197	et	4	main
armastuse	doc_333816885024_item	2335790	et	4	main
mulle	doc_333816885024_item	2335822	et	4	main
sinna	doc_333816885024_item	2335832	et	3	main
minna	doc_333816885024_item	2335833	et	3	main
käinud	doc_333816885026_item	2335981	et	4	main
arvates	doc_333816885026_item	2335986	et	4	main
puhkus	doc_333816885026_item	2335995	et	3	main
eestis	doc_333816885026_item	2336003	et	3	main
palju	doc_333816885026_item	2336005	et	4	main
kohti	doc_333816885026_item	2336006	et	4	main
kus	doc_333816885026_item	2336007	et	3	main
saab	doc_333816885026_item	2336008	et	3	main
aktiivselt	doc_333816885026_item	2336009	et	4	main
väga	doc_333816885024_item	2335823	et	3	main
ja	doc_333816885024_item	2335826	et	3	main
veel	doc_333816885024_item	2335830	et	4	main
ma	doc_333816885026_item	2335979	et	3	main
mida	doc_333816885026_item	2335982	et	4	main
näinud	doc_333816885026_item	2335984	et	4	main
on	doc_333816885026_item	2335987	et	4	main
tõõstad	doc_333816885026_item	2335996	et	4	main
ja	doc_333816885026_item	2336000	et	3	main
energiavarusid	doc_333816885026_item	2336002	et	3	main
on	doc_333816885026_item	2336004	et	4	main
üha	doc_333816885026_item	2336011	et	3	main
muutumas	doc_333816885026_item	2336014	et	4	main
taluturism	doc_333816885026_item	2336015	et	3	main
võimalus	doc_333816885026_item	2336018	et	3	main
ja	doc_333816885026_item	2336022	et	3	main
talus	doc_333816885026_item	2336026	et	4	main
talutööd	doc_333816885026_item	2336028	et	4	main
aja	doc_333816885026_item	2336031	et	4	main
on	doc_333816885026_item	2336033	et	4	main
hobusetalud	doc_333816885026_item	2336035	et	3	main
kus	doc_333816885026_item	2336036	et	3	main
puhkamisele	doc_333816885026_item	2336038	et	4	main
saab	doc_333816885026_item	2336039	et	3	main
ma	doc_333816885026_item	2336045	et	3	main
turismitalus	doc_333816885026_item	2336047	et	3	main
looduskaunil	doc_333816885026_item	2336053	et	4	main
sõita	doc_333816885026_item	2336087	et	3	main
puitmajas	doc_333816885026_item	2336095	et	3	main
on	doc_333816885026_item	2336097	et	4	main
sisustusega	doc_333816885026_item	2336099	et	4	main
elutuba	doc_333816885026_item	2336101	et	4	main
mööbli	doc_333816885026_item	2336103	et	3	main
teleri-	doc_333816885026_item	2336104	et	3	main
on	doc_333816885026_item	2336121	et	4	main
grillkoht	doc_333816885026_item	2336124	et	3	main
reisides	doc_333816885026_item	2336138	et	4	main
eestimaa	doc_333816885026_item	2336139	et	4	main
on	doc_333816885026_item	2336140	et	4	main
tegelekult	doc_333816885026_item	2336141	et	4	main
väga	doc_333816885026_item	2336142	et	3	main
ilus	doc_333816885026_item	2336143	et	4	main
ja	doc_333816885026_item	2336144	et	3	main
siin	doc_333816885026_item	2336145	et	4	main
miks	doc_333816885026_item	2336153	et	4	main
infovaegus	doc_333816885026_item	2336161	et	3	main
tema	doc_333816885026_item	2336175	et	4	main
keskaegne	doc_333816885026_item	2336177	et	3	main
tallinn	doc_333816885026_item	2336180	et	4	main
euroopas	doc_333816885026_item	2336188	et	3	main
mis	doc_333816885026_item	2336203	et	4	main
olen	doc_333816885026_item	2335980	et	3	main
puhkus	doc_333816885026_item	2335993	et	3	main
aitab	doc_333816885026_item	2335998	et	3	main
popularsumaks	doc_333816885026_item	2336012	et	4	main
viibida	doc_333816885026_item	2336020	et	3	main
kalastada	doc_333816885026_item	2336021	et	3	main
telkida	doc_333816885026_item	2336023	et	4	main
teha	doc_333816885026_item	2336029	et	3	main
lemmikuteks	doc_333816885026_item	2336032	et	4	main
sel	doc_333816885026_item	2336043	et	3	main
puhkasin	doc_333816885026_item	2336046	et	3	main
mis	doc_333816885026_item	2336051	et	4	main
viljandi	doc_333816885026_item	2336055	et	4	main
ka	doc_333816885026_item	2336060	et	3	main
talu	doc_333816885026_item	2336076	et	4	main
minna	doc_333816885026_item	2336090	et	3	main
me	doc_333816885026_item	2336093	et	4	main
kus	doc_333816885026_item	2336096	et	3	main
kahe	doc_333816885026_item	2336107	et	3	main
oli	doc_333816885026_item	2336129	et	3	main
ilu	doc_333816885026_item	2336156	et	4	main
just	doc_333816885026_item	2336160	et	3	main
teadmatus	doc_333816885026_item	2336163	et	4	main
võimalused	doc_333816885026_item	2336165	et	3	main
kõige	doc_333816885026_item	2336173	et	4	main
tallinna	doc_333816885026_item	2336179	et	4	main
on	doc_333816885026_item	2336181	et	4	main
üks	doc_333816885026_item	2336182	et	3	main
ilusad	doc_333816885026_item	2336189	et	3	main
eesti	doc_333816885026_item	2336193	et	4	main
ulatuvad	doc_333816885026_item	2336195	et	4	main
ja	doc_333816885026_item	2336200	et	3	main
mustvee	doc_333816885026_item	2336226	et	3	main
rand	doc_333816885026_item	2336228	et	3	main
rahulikult	doc_333816885026_item	2336239	et	4	main
ei	doc_333816885026_item	2336243	et	4	main
tuleb	doc_333816885026_item	2336245	et	3	main
telk	doc_333816885026_item	2336246	et	3	main
kaasa	doc_333816885026_item	2336247	et	4	main
võtta	doc_333816885026_item	2336248	et	3	main
üleüldse	doc_333816885026_item	2336255	et	3	main
soovitav	doc_333816885026_item	2336257	et	4	main
ja	doc_333816885026_item	2336274	et	3	main
on	doc_333816885026_item	2336278	et	4	main
nädala	doc_333816885026_item	2336304	et	3	main
siis	doc_333816885026_item	2336307	et	3	main
siis	doc_333816885026_item	2336315	et	3	main
ma	doc_333816885026_item	2336317	et	3	main
see	doc_333816885026_item	2336319	et	3	main
pakub	doc_333816885026_item	2336325	et	3	main
seda	doc_333816885026_item	2336329	et	3	main
reisi	doc_333816885026_item	2336331	et	4	main
võtta	doc_333816885026_item	2336333	et	3	main
korralikult	doc_333816885026_item	2336352	et	4	main
kulgeb	doc_333816885026_item	2336356	et	3	main
ma	doc_333816885026_item	2336360	et	3	main
näinud	doc_333816885027_item	2336374	et	4	main
olin	doc_333816885027_item	2336377	et	3	main
on	doc_333816885027_item	2336382	et	4	main
väga	doc_333816885027_item	2336384	et	3	main
vedada	doc_333816885027_item	2336430	et	3	main
käisime	doc_333816885027_item	2336431	et	3	main
ujulasse	doc_333816885027_item	2336433	et	4	main
kus	doc_333816885027_item	2336436	et	3	main
kantoni	doc_333816885027_item	2336444	et	3	main
linnad	doc_333816885027_item	2336448	et	3	main
päeval	doc_333816885027_item	2336461	et	3	main
vaatama	doc_333816885027_item	2336463	et	3	main
mediina	doc_333816885027_item	2336465	et	4	main
kus	doc_333816885027_item	2336470	et	3	main
ja	doc_333816885027_item	2336474	et	3	main
nende	doc_333816885027_item	2336479	et	4	main
seal	doc_333816885027_item	2336483	et	4	main
avatud	doc_333816885027_item	2336484	et	4	main
laat	doc_333816885027_item	2336485	et	3	main
endale	doc_333816885027_item	2336488	et	4	main
ka	doc_333816885026_item	2336040	et	3	main
oli	doc_333816885026_item	2336049	et	3	main
maastikul	doc_333816885026_item	2336054	et	4	main
lähistel	doc_333816885026_item	2336057	et	4	main
lehtmets	doc_333816885026_item	2336062	et	3	main
ja	doc_333816885026_item	2336063	et	3	main
ujumis	doc_333816885026_item	2336064	et	3	main
kaunis	doc_333816885026_item	2336066	et	4	main
järv	doc_333816885026_item	2336067	et	3	main
kohaga	doc_333816885026_item	2336065	et	4	main
mina	doc_333816885026_item	2336068	et	4	main
veetsin	doc_333816885026_item	2336069	et	3	main
koos	doc_333816885026_item	2336070	et	4	main
sõbradega	doc_333816885026_item	2336071	et	4	main
hobusetalus	doc_333816885026_item	2336072	et	3	main
meeldiva	doc_333816885026_item	2336073	et	4	main
nädalavahetuse	doc_333816885026_item	2336074	et	4	main
see	doc_333816885026_item	2336075	et	3	main
pakub	doc_333816885026_item	2336077	et	3	main
aktiivselt	doc_333816885026_item	2336078	et	4	main
puhkuseks	doc_333816885026_item	2336079	et	4	main
kõikvõimalikke	doc_333816885026_item	2336080	et	3	main
teenuseid	doc_333816885026_item	2336081	et	3	main
saab	doc_333816885026_item	2336085	et	3	main
või	doc_333816885026_item	2336089	et	4	main
ratsamatkale	doc_333816885026_item	2336091	et	3	main
vajalik	doc_333816885026_item	2336098	et	3	main
miniköög	doc_333816885026_item	2336100	et	4	main
ja	doc_333816885026_item	2336105	et	3	main
magamistuba	doc_333816885026_item	2336109	et	4	main
dussiruum	doc_333816885026_item	2336112	et	4	main
lõikeplats	doc_333816885026_item	2336123	et	3	main
kalapüügivahendid	doc_333816885026_item	2336127	et	3	main
veeta	doc_333816885026_item	2336132	et	4	main
vaadata	doc_333816885026_item	2336149	et	4	main
ja	doc_333816885026_item	2336150	et	3	main
üheks	doc_333816885026_item	2336151	et	3	main
põhjuseks	doc_333816885026_item	2336152	et	3	main
tuntakse	doc_333816885026_item	2336172	et	3	main
salapärase	doc_333816885026_item	2336176	et	4	main
paremini	doc_333816885026_item	2336184	et	4	main
säilinud	doc_333816885026_item	2336185	et	4	main
keskaegne	doc_333816885026_item	2336186	et	3	main
linn	doc_333816885026_item	2336187	et	3	main
lõuna	doc_333816885026_item	2336192	et	4	main
künkad	doc_333816885026_item	2336196	et	3	main
metsad	doc_333816885026_item	2336202	et	3	main
suurepäraseid	doc_333816885026_item	2336206	et	4	main
matkamiseks	doc_333816885026_item	2336208	et	4	main
sõitmiseks	doc_333816885026_item	2336210	et	4	main
ääres	doc_333816885026_item	2336221	et	4	main
kallaste	doc_333816885026_item	2336225	et	4	main
jumalik	doc_333816885026_item	2336227	et	3	main
imepuhas	doc_333816885026_item	2336231	et	3	main
seal	doc_333816885026_item	2336235	et	4	main
saab	doc_333816885026_item	2336238	et	3	main
tuleb	doc_333816885026_item	2336250	et	3	main
võibolla	doc_333816885026_item	2336251	et	4	main
on	doc_333816885026_item	2336256	et	4	main
et	doc_333816885026_item	2336299	et	3	main
peipsi	doc_333816885026_item	2336305	et	4	main
käin	doc_333816885026_item	2336308	et	3	main
kui	doc_333816885026_item	2336311	et	3	main
võimalus	doc_333816885026_item	2336314	et	3	main
sõidaks	doc_333816885026_item	2336316	et	3	main
on	doc_333816885026_item	2336321	et	4	main
unustamatuid	doc_333816885026_item	2336327	et	4	main
väga	doc_333816885026_item	2336334	et	3	main
võib	doc_333816885026_item	2336338	et	3	main
olla	doc_333816885026_item	2336339	et	3	main
seotud	doc_333816885026_item	2336340	et	4	main
mõningate	doc_333816885026_item	2336341	et	3	main
ikkagi	doc_333816885026_item	2336343	et	4	main
eksootiline	doc_333816885026_item	2336344	et	3	main
arvan	doc_333816885026_item	2336348	et	3	main
kui	doc_333816885026_item	2336350	et	3	main
aafrikas	doc_333816885026_item	2336362	et	4	main
iseeladseid	doc_333816885026_item	2336365	et	4	main
mulle	doc_333816885027_item	2336383	et	4	main
tore	doc_333816885026_item	2336130	et	3	main
saun	doc_333816885026_item	2336122	et	3	main
ja	doc_333816885026_item	2336126	et	3	main
õhtuti	doc_333816885026_item	2336128	et	3	main
aega	doc_333816885026_item	2336131	et	4	main
lõkkeplatsil	doc_333816885026_item	2336133	et	3	main
aktiivselt	doc_333816885026_item	2336134	et	4	main
saab	doc_333816885026_item	2336135	et	3	main
puhata	doc_333816885026_item	2336136	et	4	main
ka	doc_333816885026_item	2336137	et	3	main
on	doc_333816885026_item	2336146	et	4	main
nii	doc_333816885026_item	2336147	et	3	main
palju	doc_333816885026_item	2336148	et	4	main
seda	doc_333816885026_item	2336155	et	3	main
ei	doc_333816885026_item	2336157	et	4	main
on	doc_333816885026_item	2336159	et	4	main
ning	doc_333816885026_item	2336162	et	3	main
puhkamiseks	doc_333816885026_item	2336168	et	4	main
ja	doc_333816885026_item	2336169	et	3	main
reisimiseks	doc_333816885026_item	2336170	et	4	main
eestit	doc_333816885026_item	2336171	et	3	main
kõige	doc_333816885026_item	2336183	et	4	main
on	doc_333816885026_item	2336190	et	4	main
ojad	doc_333816885026_item	2336198	et	3	main
pakuvad	doc_333816885026_item	2336204	et	3	main
ratsutamiseks	doc_333816885026_item	2336211	et	4	main
veespordi	doc_333816885026_item	2336212	et	3	main
harrastamiseks	doc_333816885026_item	2336213	et	4	main
tekkimiseks	doc_333816885026_item	2336214	et	4	main
ja	doc_333816885026_item	2336215	et	3	main
kalastamiseks	doc_333816885026_item	2336216	et	4	main
ning	doc_333816885026_item	2336217	et	3	main
talvel	doc_333816885026_item	2336218	et	4	main
suusatamiseks	doc_333816885026_item	2336219	et	4	main
peipsi	doc_333816885026_item	2336220	et	4	main
järved	doc_333816885026_item	2336199	et	3	main
paksud	doc_333816885026_item	2336201	et	3	main
suvel	doc_333816885026_item	2336205	et	3	main
võimalusi	doc_333816885026_item	2336207	et	3	main
on	doc_333816885026_item	2336222	et	4	main
omamoodi	doc_333816885026_item	2336223	et	3	main
eksootika	doc_333816885026_item	2336224	et	4	main
ja	doc_333816885026_item	2336230	et	3	main
vesi	doc_333816885026_item	2336232	et	4	main
on	doc_333816885026_item	2336234	et	4	main
vähe	doc_333816885026_item	2336236	et	3	main
ja	doc_333816885026_item	2336237	et	3	main
hotelli	doc_333816885026_item	2336241	et	4	main
ole	doc_333816885026_item	2336244	et	4	main
lõkkel	doc_333816885026_item	2336254	et	3	main
huvitavate	doc_333816885026_item	2336275	et	4	main
inimestega	doc_333816885026_item	2336276	et	3	main
taha	doc_333816885026_item	2336283	et	4	main
maadele	doc_333816885026_item	2336285	et	4	main
ja	doc_333816885026_item	2336286	et	3	main
suurtesse	doc_333816885026_item	2336287	et	3	main
linnadesse	doc_333816885026_item	2336288	et	3	main
mina	doc_333816885026_item	2336297	et	4	main
sel	doc_333816885026_item	2336300	et	3	main
ühe	doc_333816885026_item	2336303	et	4	main
ääres	doc_333816885026_item	2336306	et	4	main
suurel	doc_333816885026_item	2336309	et	3	main
oleks	doc_333816885026_item	2336313	et	3	main
aafrikasse	doc_333816885026_item	2336318	et	4	main
kuid	doc_333816885026_item	2336324	et	4	main
vahejuhtumitega	doc_333816885026_item	2336342	et	3	main
lõunamaa	doc_333816885026_item	2336345	et	4	main
kuid	doc_333816885026_item	2336346	et	4	main
siis	doc_333816885026_item	2336355	et	3	main
reis	doc_333816885026_item	2336357	et	4	main
ja	doc_333816885026_item	2336359	et	3	main
saan	doc_333816885026_item	2336361	et	4	main
essee	doc_333816885027_item	2336367	et	4	main
olin	doc_333816885027_item	2336369	et	3	main
käinud	doc_333816885027_item	2336370	et	4	main
ja	doc_333816885027_item	2336371	et	3	main
ma	doc_333816885027_item	2336378	et	3	main
see	doc_333816885027_item	2336380	et	3	main
meeldinud	doc_333816885027_item	2336385	et	4	main
see	doc_333816885027_item	2336423	et	3	main
aega	doc_333816885027_item	2336429	et	4	main
saab	doc_333816885027_item	2336437	et	3	main
ja	doc_333816885027_item	2336441	et	3	main
loodusega	doc_333816885027_item	2336451	et	4	main
keskmine	doc_333816885027_item	2336452	et	3	main
temperatuur	doc_333816885027_item	2336453	et	3	main
umbes	doc_333816885027_item	2336455	et	4	main
kraadi	doc_333816885027_item	2336457	et	4	main
läksin	doc_333816885027_item	2336462	et	3	main
mediinat	doc_333816885027_item	2336464	et	4	main
vanalinn	doc_333816885027_item	2336469	et	3	main
inimesed	doc_333816885027_item	2336473	et	3	main
asub	doc_333816885027_item	2336476	et	3	main
ja	doc_333816885027_item	2336478	et	3	main
on	doc_333816885027_item	2336482	et	4	main
kus	doc_333816885027_item	2336486	et	3	main
mis	doc_333816885027_item	2336493	et	4	main
on	doc_333816885027_item	2336494	et	4	main
sulle	doc_333816885027_item	2336495	et	3	main
mulle	doc_333816885027_item	2336499	et	4	main
kogu	doc_333816885027_item	2336515	et	4	main
meeldis	doc_333816885027_item	2336522	et	3	main
puutusime	doc_333816885027_item	2336526	et	3	main
seal	doc_333816885027_item	2336538	et	4	main
tuneesiast	doc_333816885027_item	2336544	et	4	main
leiab	doc_333816885027_item	2336545	et	3	main
halli	doc_333816885027_item	2336549	et	4	main
viia	doc_333816885027_item	2336552	et	3	main
olgu	doc_333816885027_item	2336553	et	3	main
siis	doc_333816885027_item	2336555	et	3	main
müstiline	doc_333816885027_item	2336566	et	3	main
aura	doc_333816885027_item	2336567	et	4	main
soovin	doc_333816885027_item	2336573	et	3	main
üks	doc_333816885027_item	2336575	et	3	main
sõita	doc_333816885027_item	2336578	et	3	main
tuneesiasse	doc_333816885027_item	2336579	et	4	main
ja	doc_333816885027_item	2336580	et	3	main
jalgrattaga	doc_333816885026_item	2336209	et	3	main
kauksis	doc_333816885026_item	2336229	et	4	main
süüa	doc_333816885026_item	2336249	et	3	main
ise	doc_333816885026_item	2336253	et	4	main
omapäraste	doc_333816885026_item	2336273	et	4	main
soojadele	doc_333816885026_item	2336284	et	3	main
pealegi	doc_333816885026_item	2336289	et	4	main
on	doc_333816885026_item	2336290	et	4	main
kasulik	doc_333816885026_item	2336291	et	3	main
kui	doc_333816885026_item	2336292	et	3	main
me	doc_333816885026_item	2336293	et	4	main
õpime	doc_333816885026_item	2336294	et	3	main
kodumaad	doc_333816885026_item	2336295	et	4	main
tundma	doc_333816885026_item	2336296	et	3	main
arvan	doc_333816885026_item	2336298	et	3	main
suvel	doc_333816885026_item	2336301	et	3	main
võõraid	doc_333816885026_item	2336233	et	3	main
puhata	doc_333816885026_item	2336240	et	4	main
seal	doc_333816885026_item	2336242	et	4	main
teha	doc_333816885026_item	2336252	et	3	main
kõik	doc_333816885026_item	2336258	et	4	main
vajalik	doc_333816885026_item	2336259	et	3	main
kaasa	doc_333816885026_item	2336260	et	4	main
võtta	doc_333816885026_item	2336261	et	3	main
seal	doc_333816885026_item	2336262	et	4	main
saad	doc_333816885026_item	2336263	et	4	main
ujuda	doc_333816885026_item	2336264	et	3	main
puhtas	doc_333816885026_item	2336265	et	3	main
vees	doc_333816885026_item	2336266	et	3	main
ja	doc_333816885026_item	2336267	et	3	main
päevitada	doc_333816885026_item	2336268	et	3	main
puhtal	doc_333816885026_item	2336269	et	3	main
rannal	doc_333816885026_item	2336270	et	3	main
saad	doc_333816885026_item	2336271	et	4	main
suhelda	doc_333816885026_item	2336272	et	4	main
see	doc_333816885026_item	2336277	et	3	main
muidugi	doc_333816885026_item	2336279	et	4	main
puhkusekoht	doc_333816885026_item	2336280	et	3	main
ma	doc_333816885026_item	2336281	et	3	main
ei	doc_333816885026_item	2336282	et	4	main
veedan	doc_333816885026_item	2336302	et	3	main
munamäel	doc_333816885026_item	2336310	et	3	main
mul	doc_333816885026_item	2336312	et	3	main
reis	doc_333816885026_item	2336320	et	4	main
kallis	doc_333816885026_item	2336323	et	4	main
elamusi	doc_333816885026_item	2336328	et	3	main
kauget	doc_333816885026_item	2336330	et	3	main
ette	doc_333816885026_item	2336332	et	4	main
hirmsalt	doc_333816885026_item	2336335	et	4	main
kuna	doc_333816885026_item	2336336	et	3	main
see	doc_333816885026_item	2336337	et	3	main
et	doc_333816885026_item	2336349	et	3	main
kõik	doc_333816885026_item	2336351	et	4	main
läbi	doc_333816885026_item	2336353	et	4	main
viibides	doc_333816885026_item	2336363	et	3	main
mida	doc_333816885027_item	2336372	et	4	main
olin	doc_333816885027_item	2336373	et	3	main
eelmisel	doc_333816885027_item	2336375	et	3	main
tuneesias	doc_333816885027_item	2336379	et	4	main
me	doc_333816885027_item	2336386	et	4	main
soussest	doc_333816885027_item	2336422	et	4	main
hea	doc_333816885027_item	2336426	et	4	main
et	doc_333816885027_item	2336428	et	3	main
el	doc_333816885027_item	2336443	et	4	main
väga	doc_333816885027_item	2336446	et	3	main
oli	doc_333816885027_item	2336454	et	3	main
kolmandal	doc_333816885027_item	2336460	et	3	main
nägu	doc_333816885027_item	2336467	et	4	main
kus	doc_333816885027_item	2336475	et	3	main
pühapäevadeni	doc_333816885027_item	2336481	et	3	main
saab	doc_333816885027_item	2336487	et	3	main
kõik	doc_333816885027_item	2336492	et	4	main
meeldis	doc_333816885027_item	2336498	et	3	main
oli	doc_333816885027_item	2336508	et	3	main
päris	doc_333816885027_item	2336513	et	4	main
ekskursioon	doc_333816885027_item	2336516	et	3	main
kaamelis	doc_333816885027_item	2336518	et	3	main
mulle	doc_333816885027_item	2336520	et	4	main
väga	doc_333816885027_item	2336521	et	3	main
ja	doc_333816885027_item	2336530	et	3	main
soolajärv	doc_333816885027_item	2336537	et	3	main
sahara	doc_333816885027_item	2336543	et	4	main
igaüks	doc_333816885027_item	2336546	et	3	main
kaasa	doc_333816885027_item	2336551	et	4	main
lesides	doc_333816885027_item	2336558	et	3	main
kuldpruun	doc_333816885027_item	2336560	et	3	main
jume	doc_333816885027_item	2336561	et	4	main
muljed	doc_333816885027_item	2336562	et	3	main
külastamisest	doc_333816885027_item	2336564	et	4	main
sahara	doc_333816885027_item	2336565	et	4	main
araabia	doc_333816885027_item	2336569	et	4	main
mediina	doc_333816885027_item	2336570	et	4	main
elus	doc_333816885027_item	2336577	et	4	main
vaatamisväärsusi	doc_333816885028_item	2336626	et	4	main
me	doc_333816885028_item	2336627	et	4	main
sõitsime	doc_333816885028_item	2336628	et	3	main
süüa	doc_333816885028_item	2336637	et	3	main
midagi	doc_333816885028_item	2336640	et	4	main
hommikul	doc_333816885028_item	2336663	et	3	main
ma	doc_333816885028_item	2336676	et	3	main
poolas	doc_333816885028_item	2336722	et	4	main
leedus	doc_333816885028_item	2336723	et	4	main
päev	doc_333816885028_item	2336725	et	3	main
see	doc_333816885028_item	2336729	et	3	main
väga	doc_333816885028_item	2336731	et	3	main
kallis	doc_333816885028_item	2336734	et	4	main
linn	doc_333816885028_item	2336735	et	3	main
me	doc_333816885028_item	2336736	et	4	main
külastasime	doc_333816885028_item	2336737	et	3	main
sante	doc_333816885028_item	2336738	et	3	main
ja	doc_333816885028_item	2336743	et	3	main
me	doc_333816885028_item	2336749	et	4	main
päeval	doc_333816885028_item	2336753	et	3	main
roomas	doc_333816885028_item	2336759	et	4	main
väga	doc_333816885028_item	2336771	et	3	main
münti	doc_333816885028_item	2336783	et	4	main
veel	doc_333816885028_item	2336785	et	4	main
muidugi	doc_333816885026_item	2336322	et	4	main
kindlasti	doc_333816885026_item	2336326	et	3	main
mina	doc_333816885026_item	2336347	et	4	main
mõelda	doc_333816885026_item	2336354	et	4	main
hästi	doc_333816885026_item	2336358	et	3	main
palju	doc_333816885026_item	2336364	et	4	main
elamusi	doc_333816885026_item	2336366	et	3	main
kus	doc_333816885027_item	2336368	et	3	main
aastal	doc_333816885027_item	2336376	et	3	main
reis	doc_333816885027_item	2336381	et	4	main
elasime	doc_333816885027_item	2336387	et	3	main
sousse	doc_333816885027_item	2336388	et	4	main
linnas	doc_333816885027_item	2336389	et	4	main
ja	doc_333816885027_item	2336390	et	3	main
sousse	doc_333816885027_item	2336391	et	4	main
palace	doc_333816885027_item	2336392	et	4	main
hotellis	doc_333816885027_item	2336393	et	3	main
mind	doc_333816885027_item	2336394	et	4	main
huvitaks	doc_333816885027_item	2336395	et	4	main
nende	doc_333816885027_item	2336396	et	4	main
päriselu	doc_333816885027_item	2336397	et	4	main
loodus	doc_333816885027_item	2336398	et	4	main
ja	doc_333816885027_item	2336399	et	3	main
ajalugu	doc_333816885027_item	2336400	et	4	main
tuneesias	doc_333816885027_item	2336401	et	4	main
olin	doc_333816885027_item	2336402	et	3	main
käinud	doc_333816885027_item	2336403	et	4	main
sahaaras	doc_333816885027_item	2336404	et	4	main
mediinas	doc_333816885027_item	2336405	et	4	main
port	doc_333816885027_item	2336406	et	4	main
el	doc_333816885027_item	2336407	et	4	main
kantonis	doc_333816885027_item	2336408	et	3	main
ja	doc_333816885027_item	2336409	et	3	main
palju	doc_333816885027_item	2336410	et	4	main
teistes	doc_333816885027_item	2336411	et	4	main
kohtades	doc_333816885027_item	2336412	et	3	main
port	doc_333816885027_item	2336413	et	4	main
el	doc_333816885027_item	2336414	et	4	main
kantoni	doc_333816885027_item	2336415	et	3	main
on	doc_333816885027_item	2336416	et	4	main
väga	doc_333816885027_item	2336417	et	3	main
huvitav	doc_333816885027_item	2336418	et	4	main
koht	doc_333816885027_item	2336419	et	3	main
mis	doc_333816885027_item	2336420	et	4	main
asub	doc_333816885027_item	2336421	et	3	main
on	doc_333816885027_item	2336424	et	4	main
kesklinna	doc_333816885027_item	2336434	et	4	main
võtta	doc_333816885027_item	2336438	et	3	main
väga	doc_333816885027_item	2336425	et	3	main
koht	doc_333816885027_item	2336427	et	3	main
seal	doc_333816885027_item	2336432	et	4	main
sadamasse	doc_333816885027_item	2336435	et	4	main
ekskursioonid	doc_333816885027_item	2336439	et	3	main
port	doc_333816885027_item	2336442	et	4	main
sousse	doc_333816885027_item	2336440	et	4	main
koos	doc_333816885027_item	2336449	et	4	main
nende	doc_333816885027_item	2336450	et	4	main
augusti	doc_333816885027_item	2336458	et	3	main
on	doc_333816885027_item	2336466	et	4	main
kesklinnas	doc_333816885027_item	2336468	et	4	main
rohkem	doc_333816885027_item	2336501	et	4	main
telgis	doc_333816885027_item	2336509	et	3	main
kuid	doc_333816885027_item	2336510	et	4	main
külm	doc_333816885027_item	2336514	et	3	main
oli	doc_333816885027_item	2336517	et	3	main
mineviku	doc_333816885027_item	2336529	et	3	main
traditsioonidega	doc_333816885027_item	2336531	et	3	main
tuntuim	doc_333816885027_item	2336536	et	4	main
kus	doc_333816885027_item	2336539	et	3	main
soolajärv	doc_333816885027_item	2336541	et	3	main
hingesooiendavat	doc_333816885027_item	2336547	et	4	main
mida	doc_333816885027_item	2336548	et	4	main
liivarandadel	doc_333816885027_item	2336557	et	3	main
saadud	doc_333816885027_item	2336559	et	4	main
vaatamisväärsuste	doc_333816885027_item	2336563	et	4	main
igale	doc_333816885027_item	2336571	et	3	main
kord	doc_333816885027_item	2336576	et	4	main
on	doc_333816885027_item	2336445	et	4	main
ilusad	doc_333816885027_item	2336447	et	3	main
35	doc_333816885027_item	2336456	et	2	main
kuus	doc_333816885027_item	2336459	et	4	main
elavad	doc_333816885027_item	2336471	et	4	main
vaesed	doc_333816885027_item	2336472	et	4	main
turg	doc_333816885027_item	2336477	et	3	main
kirik	doc_333816885027_item	2336480	et	3	main
osta	doc_333816885027_item	2336491	et	4	main
saharas	doc_333816885027_item	2336497	et	4	main
kõige	doc_333816885027_item	2336500	et	4	main
sest	doc_333816885027_item	2336502	et	4	main
käisime	doc_333816885027_item	2336503	et	3	main
seal	doc_333816885027_item	2336504	et	4	main
kahe	doc_333816885027_item	2336505	et	3	main
päevale	doc_333816885027_item	2336506	et	4	main
oli	doc_333816885027_item	2336512	et	3	main
valida	doc_333816885027_item	2336489	et	3	main
ja	doc_333816885027_item	2336490	et	3	main
vaja	doc_333816885027_item	2336496	et	4	main
ööbimine	doc_333816885027_item	2336507	et	4	main
öösel	doc_333816885027_item	2336511	et	4	main
mis	doc_333816885027_item	2336519	et	4	main
teel	doc_333816885027_item	2336523	et	4	main
kõrbesse	doc_333816885027_item	2336525	et	4	main
kokku	doc_333816885027_item	2336527	et	3	main
chott	doc_333816885027_item	2336532	et	4	main
pjeridi	doc_333816885027_item	2336534	et	4	main
algab	doc_333816885027_item	2336542	et	3	main
see	doc_333816885027_item	2336554	et	3	main
kaunitel	doc_333816885027_item	2336556	et	3	main
või	doc_333816885027_item	2336568	et	4	main
ma	doc_333816885027_item	2336574	et	3	main
kõike	doc_333816885027_item	2336582	et	4	main
me	doc_333816885028_item	2336634	et	4	main
katki	doc_333816885028_item	2336650	et	4	main
oksendasid	doc_333816885028_item	2336652	et	4	main
kartsid	doc_333816885028_item	2336654	et	4	main
ja	doc_333816885028_item	2336655	et	3	main
oli	doc_333816885028_item	2336665	et	3	main
ilus	doc_333816885028_item	2336667	et	4	main
kõik	doc_333816885028_item	2336669	et	4	main
inimesed	doc_333816885028_item	2336670	et	3	main
rõõmustusid	doc_333816885028_item	2336671	et	4	main
et	doc_333816885028_item	2336672	et	3	main
kõik	doc_333816885028_item	2336673	et	4	main
on	doc_333816885028_item	2336674	et	4	main
ei	doc_333816885028_item	2336677	et	4	main
mõned	doc_333816885028_item	2336707	et	3	main
alati	doc_333816885028_item	2336714	et	4	main
me	doc_333816885028_item	2336717	et	4	main
erinevates	doc_333816885028_item	2336719	et	4	main
hotellides	doc_333816885028_item	2336720	et	3	main
näiteks	doc_333816885028_item	2336721	et	4	main
oli	doc_333816885028_item	2336727	et	3	main
krotshi	doc_333816885028_item	2336739	et	4	main
sõitsime	doc_333816885028_item	2336750	et	3	main
väga	doc_333816885028_item	2336761	et	3	main
olid	doc_333816885028_item	2336765	et	4	main
linn	doc_333816885028_item	2336770	et	3	main
palju	doc_333816885028_item	2336772	et	4	main
kõige	doc_333816885028_item	2336774	et	4	main
mulle	doc_333816885028_item	2336776	et	4	main
viskasid	doc_333816885028_item	2336782	et	4	main
olin	doc_333816885028_item	2336791	et	3	main
mark	doc_333816885028_item	2336796	et	3	main
me	doc_333816885028_item	2336800	et	4	main
fotosid	doc_333816885028_item	2336821	et	3	main
see	doc_333816885028_item	2336825	et	3	main
ma	doc_333816885028_item	2336830	et	3	main
seda	doc_333816885028_item	2336839	et	3	main
pöörduda	doc_333816885028_item	2336843	et	3	main
soovin	doc_333816885028_item	2336846	et	3	main
näinud	doc_333816885029_item	2336858	et	4	main
on	doc_333816885029_item	2336867	et	4	main
vana	doc_333816885029_item	2336893	et	4	main
väike	doc_333816885029_item	2336904	et	4	main
mul	doc_333816885029_item	2336914	et	3	main
kui	doc_333816885029_item	2336920	et	3	main
ma	doc_333816885029_item	2336921	et	3	main
väike	doc_333816885029_item	2336923	et	4	main
reisime	doc_333816885029_item	2336925	et	3	main
aga	doc_333816885029_item	2336930	et	3	main
igas	doc_333816885029_item	2336931	et	3	main
head	doc_333816885029_item	2336938	et	4	main
aga	doc_333816885029_item	2336940	et	3	main
sõbrannaga	doc_333816885029_item	2336959	et	3	main
olime	doc_333816885029_item	2336964	et	3	main
all	doc_333816885029_item	2336966	et	3	main
rohkem	doc_333816885029_item	2337007	et	4	main
saatsime	doc_333816885029_item	2337010	et	3	main
liiga	doc_333816885029_item	2337028	et	4	main
endast	doc_333816885029_item	2337034	et	4	main
viimasel	doc_333816885029_item	2337036	et	3	main
õhtul	doc_333816885029_item	2337037	et	3	main
ja	doc_333816885029_item	2337041	et	3	main
tantsisime	doc_333816885029_item	2337042	et	3	main
pärast	doc_333816885029_item	2337044	et	4	main
reisimist	doc_333816885029_item	2337045	et	4	main
sahara	doc_333816885027_item	2336524	et	4	main
tuneesia	doc_333816885027_item	2336528	et	4	main
el	doc_333816885027_item	2336533	et	4	main
on	doc_333816885027_item	2336535	et	4	main
lõppeb	doc_333816885027_item	2336540	et	3	main
argipäeva	doc_333816885027_item	2336550	et	4	main
inimestele	doc_333816885027_item	2336572	et	3	main
olin	doc_333816885027_item	2336586	et	3	main
näinud	doc_333816885027_item	2336587	et	4	main
essee	doc_333816885028_item	2336588	et	4	main
kus	doc_333816885028_item	2336589	et	3	main
olen	doc_333816885028_item	2336590	et	3	main
käinud	doc_333816885028_item	2336591	et	4	main
mida	doc_333816885028_item	2336593	et	4	main
ja	doc_333816885028_item	2336592	et	3	main
olen	doc_333816885028_item	2336594	et	3	main
näinud	doc_333816885028_item	2336595	et	4	main
reisimine	doc_333816885028_item	2336596	et	4	main
on	doc_333816885028_item	2336597	et	4	main
väga	doc_333816885028_item	2336598	et	3	main
populaarne	doc_333816885028_item	2336599	et	3	main
meie	doc_333816885028_item	2336600	et	4	main
ajas	doc_333816885028_item	2336601	et	4	main
mina	doc_333816885028_item	2336602	et	4	main
väga	doc_333816885028_item	2336603	et	3	main
armastan	doc_333816885028_item	2336604	et	3	main
reisida	doc_333816885028_item	2336605	et	3	main
ja	doc_333816885028_item	2336606	et	3	main
olin	doc_333816885028_item	2336607	et	3	main
külastanud	doc_333816885028_item	2336608	et	4	main
palju	doc_333816885028_item	2336609	et	4	main
kauneid	doc_333816885028_item	2336610	et	3	main
kohti	doc_333816885028_item	2336611	et	4	main
sellel	doc_333816885028_item	2336612	et	4	main
aastal	doc_333816885028_item	2336613	et	3	main
ma	doc_333816885028_item	2336614	et	3	main
olin	doc_333816885028_item	2336615	et	3	main
rootsis	doc_333816885028_item	2336616	et	3	main
see	doc_333816885028_item	2336618	et	3	main
oli	doc_333816885028_item	2336619	et	3	main
väga	doc_333816885028_item	2336620	et	3	main
stokholmis	doc_333816885028_item	2336617	et	4	main
huvitav	doc_333816885028_item	2336621	et	4	main
me	doc_333816885028_item	2336623	et	4	main
vaatasime	doc_333816885028_item	2336624	et	3	main
palju	doc_333816885028_item	2336625	et	4	main
ei	doc_333816885028_item	2336635	et	4	main
vaadata	doc_333816885027_item	2336581	et	4	main
seda	doc_333816885027_item	2336583	et	3	main
mida	doc_333816885027_item	2336584	et	4	main
ma	doc_333816885027_item	2336585	et	3	main
praamiga	doc_333816885028_item	2336629	et	4	main
ja	doc_333816885028_item	2336630	et	3	main
algas	doc_333816885028_item	2336632	et	3	main
praam	doc_333816885028_item	2336644	et	3	main
pidevalt	doc_333816885028_item	2336645	et	4	main
inimesed	doc_333816885028_item	2336651	et	3	main
nutsid	doc_333816885028_item	2336656	et	4	main
pärast	doc_333816885028_item	2336657	et	4	main
kaks	doc_333816885028_item	2336658	et	3	main
ilm	doc_333816885028_item	2336664	et	3	main
unusta	doc_333816885028_item	2336678	et	4	main
aga	doc_333816885028_item	2336706	et	3	main
ei	doc_333816885028_item	2336709	et	4	main
me	doc_333816885028_item	2336713	et	4	main
esimene	doc_333816885028_item	2336724	et	3	main
florentsias	doc_333816885028_item	2336728	et	4	main
ja	doc_333816885028_item	2336733	et	3	main
medichi	doc_333816885028_item	2336741	et	4	main
kapelli	doc_333816885028_item	2336742	et	4	main
kohti	doc_333816885028_item	2336746	et	4	main
ii	doc_333816885028_item	2336757	et	4	main
sünnipaev	doc_333816885028_item	2336758	et	4	main
palju	doc_333816885028_item	2336762	et	4	main
vatikanis	doc_333816885028_item	2336764	et	4	main
room	doc_333816885028_item	2336767	et	3	main
inimesed	doc_333816885028_item	2336781	et	3	main
veel	doc_333816885028_item	2336789	et	4	main
ma	doc_333816885028_item	2336790	et	3	main
reis	doc_333816885028_item	2336622	et	4	main
õhtul	doc_333816885028_item	2336631	et	3	main
torm	doc_333816885028_item	2336633	et	3	main
saanud	doc_333816885028_item	2336636	et	4	main
seisa	doc_333816885028_item	2336638	et	4	main
mitte	doc_333816885028_item	2336639	et	3	main
teha	doc_333816885028_item	2336641	et	3	main
sellepärast	doc_333816885028_item	2336642	et	3	main
et	doc_333816885028_item	2336643	et	3	main
olid	doc_333816885028_item	2336649	et	4	main
kõik	doc_333816885028_item	2336660	et	4	main
läks	doc_333816885028_item	2336661	et	3	main
läbi	doc_333816885028_item	2336662	et	4	main
tasane	doc_333816885028_item	2336668	et	4	main
seda	doc_333816885028_item	2336679	et	3	main
reisi	doc_333816885028_item	2336680	et	4	main
sellepärast	doc_333816885028_item	2336681	et	3	main
et	doc_333816885028_item	2336682	et	3	main
esmakordselt	doc_333816885028_item	2336683	et	4	main
oma	doc_333816885028_item	2336684	et	4	main
elus	doc_333816885028_item	2336685	et	4	main
ma	doc_333816885028_item	2336686	et	3	main
nii	doc_333816885028_item	2336687	et	3	main
kõvasti	doc_333816885028_item	2336688	et	3	main
kartsin	doc_333816885028_item	2336689	et	3	main
kõige	doc_333816885028_item	2336690	et	4	main
huvitavam	doc_333816885028_item	2336691	et	4	main
reis	doc_333816885028_item	2336692	et	4	main
oli	doc_333816885028_item	2336693	et	3	main
ma	doc_333816885028_item	2336695	et	3	main
koos	doc_333816885028_item	2336696	et	4	main
emaga	doc_333816885028_item	2336697	et	3	main
itaalias	doc_333816885028_item	2336694	et	4	main
sõitsime	doc_333816885028_item	2336698	et	3	main
bussiga	doc_333816885028_item	2336699	et	3	main
bussi	doc_333816885028_item	2336700	et	4	main
sõit	doc_333816885028_item	2336701	et	3	main
ei	doc_333816885028_item	2336702	et	4	main
olnud	doc_333816885028_item	2336703	et	4	main
väga	doc_333816885028_item	2336704	et	3	main
kõikus	doc_333816885028_item	2336646	et	3	main
kõik	doc_333816885028_item	2336647	et	4	main
taldrikud	doc_333816885028_item	2336648	et	3	main
mõned	doc_333816885028_item	2336653	et	3	main
tundi	doc_333816885028_item	2336659	et	4	main
väga	doc_333816885028_item	2336666	et	3	main
hästi	doc_333816885028_item	2336675	et	3	main
väsitav	doc_333816885028_item	2336705	et	4	main
inimesed	doc_333816885028_item	2336708	et	3	main
saanud	doc_333816885028_item	2336710	et	4	main
istuda	doc_333816885028_item	2336711	et	3	main
sellepärast	doc_333816885028_item	2336712	et	3	main
peatusi	doc_333816885028_item	2336716	et	4	main
itaalias	doc_333816885028_item	2336726	et	4	main
on	doc_333816885028_item	2336730	et	4	main
kiriku	doc_333816885028_item	2336740	et	3	main
huvitavaid	doc_333816885028_item	2336745	et	4	main
päeval	doc_333816885028_item	2336748	et	3	main
oli	doc_333816885028_item	2336754	et	3	main
oli	doc_333816885028_item	2336760	et	3	main
ajakirjanike	doc_333816885028_item	2336763	et	3	main
kirikumessad	doc_333816885028_item	2336766	et	4	main
imetlusväärne	doc_333816885028_item	2336769	et	3	main
monumente	doc_333816885028_item	2336773	et	3	main
rohkem	doc_333816885028_item	2336775	et	4	main
kõik	doc_333816885028_item	2336780	et	4	main
navona	doc_333816885028_item	2336792	et	4	main
platsis	doc_333816885028_item	2336793	et	3	main
viimasel	doc_333816885028_item	2336798	et	3	main
vaatan	doc_333816885028_item	2336831	et	3	main
meenutan	doc_333816885028_item	2336838	et	3	main
ja	doc_333816885028_item	2336841	et	3	main
essee	doc_333816885029_item	2336850	et	4	main
olen	doc_333816885029_item	2336857	et	3	main
on	doc_333816885029_item	2336860	et	4	main
olin	doc_333816885029_item	2336903	et	3	main
paistab	doc_333816885029_item	2336906	et	3	main
nii	doc_333816885029_item	2336908	et	3	main
lapsepõlvest	doc_333816885029_item	2336913	et	4	main
ainult	doc_333816885029_item	2336916	et	4	main
oma	doc_333816885029_item	2336941	et	4	main
lapsepõlves	doc_333816885029_item	2336942	et	4	main
ma	doc_333816885029_item	2336943	et	3	main
need	doc_333816885029_item	2336946	et	3	main
riigid	doc_333816885029_item	2336947	et	3	main
mulle	doc_333816885029_item	2336948	et	4	main
kõikjal	doc_333816885029_item	2336950	et	3	main
prantsusmaale	doc_333816885029_item	2336962	et	4	main
teised	doc_333816885029_item	2336972	et	4	main
koolivaheajal	doc_333816885029_item	2336998	et	3	main
me	doc_333816885029_item	2337009	et	4	main
tornis	doc_333816885029_item	2337016	et	3	main
muuseumis	doc_333816885029_item	2337018	et	3	main
palju	doc_333816885029_item	2337029	et	4	main
istusime	doc_333816885029_item	2337039	et	3	main
ma	doc_333816885029_item	2337055	et	3	main
sõita	doc_333816885029_item	2337058	et	3	main
aga	doc_333816885029_item	2337060	et	3	main
võimalus	doc_333816885029_item	2337073	et	3	main
reisida	doc_333816885029_item	2337074	et	3	main
leida	doc_333816885029_item	2337088	et	3	main
välismaal	doc_333816885029_item	2337090	et	4	main
minetage	doc_333816885029_item	2337092	et	3	main
võimalust	doc_333816885029_item	2337093	et	3	main
kus	doc_333816885030_item	2337095	et	3	main
tulid	doc_333816885030_item	2337122	et	4	main
lätist	doc_333816885030_item	2337127	et	4	main
ukrainlased	doc_333816885030_item	2337133	et	3	main
rahvatantsu	doc_333816885030_item	2337139	et	4	main
laadal	doc_333816885030_item	2337140	et	3	main
mett	doc_333816885030_item	2337142	et	4	main
asju	doc_333816885030_item	2337146	et	3	main
teist	doc_333816885030_item	2337155	et	4	main
ilusad	doc_333816885030_item	2337165	et	3	main
oskavad	doc_333816885030_item	2337172	et	4	main
ja	doc_333816885030_item	2337174	et	3	main
tantsisid	doc_333816885030_item	2337186	et	4	main
tegime	doc_333816885028_item	2336715	et	3	main
ööbisime	doc_333816885028_item	2336718	et	3	main
ilus	doc_333816885028_item	2336732	et	4	main
muud	doc_333816885028_item	2336744	et	4	main
järgmisel	doc_333816885028_item	2336747	et	3	main
roomasse	doc_333816885028_item	2336751	et	4	main
sellel	doc_333816885028_item	2336752	et	4	main
ioann	doc_333816885028_item	2336755	et	4	main
pavel	doc_333816885028_item	2336756	et	4	main
on	doc_333816885028_item	2336768	et	4	main
meeldis	doc_333816885028_item	2336777	et	3	main
trevi	doc_333816885028_item	2336778	et	4	main
fontään	doc_333816885028_item	2336779	et	3	main
et	doc_333816885028_item	2336784	et	3	main
kord	doc_333816885028_item	2336786	et	4	main
koliseisis	doc_333816885028_item	2336794	et	3	main
sõitsime	doc_333816885028_item	2336801	et	3	main
paadiga	doc_333816885028_item	2336802	et	3	main
veneetsias	doc_333816885028_item	2336803	et	4	main
sõitsime	doc_333816885028_item	2336805	et	3	main
gondeliga	doc_333816885028_item	2336806	et	3	main
me	doc_333816885028_item	2336804	et	4	main
külastasime	doc_333816885028_item	2336807	et	3	main
vabriku	doc_333816885028_item	2336808	et	3	main
kus	doc_333816885028_item	2336809	et	3	main
tehakse	doc_333816885028_item	2336810	et	3	main
veneetsiani	doc_333816885028_item	2336811	et	4	main
maski	doc_333816885028_item	2336812	et	4	main
olime	doc_333816885028_item	2336813	et	3	main
san	doc_333816885028_item	2336814	et	4	main
marko	doc_333816885028_item	2336815	et	4	main
platsis	doc_333816885028_item	2336816	et	3	main
ostsime	doc_333816885028_item	2336817	et	3	main
palju	doc_333816885028_item	2336818	et	4	main
tegime	doc_333816885028_item	2336820	et	3	main
suveniire	doc_333816885028_item	2336819	et	3	main
huvitavate	doc_333816885028_item	2336823	et	4	main
reis	doc_333816885028_item	2336826	et	4	main
unustamatu	doc_333816885028_item	2336828	et	4	main
alati	doc_333816885028_item	2336837	et	4	main
reisi	doc_333816885028_item	2336840	et	4	main
tahan	doc_333816885028_item	2336842	et	3	main
ma	doc_333816885028_item	2336845	et	3	main
käinud	doc_333816885029_item	2336854	et	4	main
nii	doc_333816885029_item	2336861	et	3	main
huvitavaid	doc_333816885029_item	2336863	et	4	main
aastat	doc_333816885029_item	2336892	et	3	main
oma	doc_333816885029_item	2336896	et	4	main
ja	doc_333816885029_item	2336898	et	3	main
sest	doc_333816885029_item	2336900	et	4	main
et	doc_333816885029_item	2336901	et	3	main
kõik	doc_333816885029_item	2336905	et	4	main
nii	doc_333816885029_item	2336911	et	3	main
reisimisest	doc_333816885029_item	2336919	et	4	main
olin	doc_333816885029_item	2336922	et	3	main
oma	doc_333816885029_item	2336926	et	4	main
ja	doc_333816885029_item	2336936	et	3	main
ei	doc_333816885029_item	2336944	et	4	main
eralda	doc_333816885029_item	2336945	et	4	main
palju	doc_333816885029_item	2336956	et	4	main
hiljem	doc_333816885029_item	2336957	et	3	main
oma	doc_333816885029_item	2336958	et	4	main
reisis	doc_333816885029_item	2336968	et	4	main
olla	doc_333816885028_item	2336787	et	3	main
itaalias	doc_333816885028_item	2336788	et	4	main
püha	doc_333816885028_item	2336795	et	4	main
katedraalis	doc_333816885028_item	2336797	et	3	main
päeval	doc_333816885028_item	2336799	et	3	main
oli	doc_333816885028_item	2336827	et	3	main
kui	doc_333816885028_item	2336829	et	3	main
ja	doc_333816885028_item	2336833	et	3	main
itaalia	doc_333816885028_item	2336835	et	4	main
kus	doc_333816885029_item	2336851	et	3	main
ma	doc_333816885029_item	2336852	et	3	main
olen	doc_333816885029_item	2336853	et	3	main
ja	doc_333816885029_item	2336855	et	3	main
palju	doc_333816885029_item	2336862	et	4	main
asju	doc_333816885029_item	2336864	et	3	main
igas	doc_333816885029_item	2336865	et	3	main
riigis	doc_333816885029_item	2336866	et	3	main
ime	doc_333816885029_item	2336869	et	4	main
paljud	doc_333816885029_item	2336870	et	3	main
seitse	doc_333816885029_item	2336891	et	3	main
taanilinnas	doc_333816885029_item	2336895	et	4	main
vennaga	doc_333816885029_item	2336899	et	3	main
ma	doc_333816885029_item	2336902	et	3	main
suur	doc_333816885029_item	2336909	et	3	main
ilus	doc_333816885029_item	2336912	et	4	main
on	doc_333816885029_item	2336915	et	4	main
head	doc_333816885029_item	2336917	et	4	main
muljed	doc_333816885029_item	2336918	et	3	main
tutvusime	doc_333816885028_item	2336822	et	4	main
inimestega	doc_333816885028_item	2336824	et	3	main
telerit	doc_333816885028_item	2336832	et	3	main
näen	doc_333816885028_item	2336834	et	3	main
siis	doc_333816885028_item	2336836	et	3	main
tagasi	doc_333816885028_item	2336844	et	3	main
kõigile	doc_333816885028_item	2336847	et	4	main
külastada	doc_333816885028_item	2336848	et	3	main
itaalia	doc_333816885028_item	2336849	et	4	main
mis	doc_333816885029_item	2336856	et	4	main
maailmas	doc_333816885029_item	2336859	et	3	main
oma	doc_333816885029_item	2336868	et	4	main
inimesed	doc_333816885029_item	2336871	et	3	main
armastavad	doc_333816885029_item	2336872	et	4	main
reisida	doc_333816885029_item	2336873	et	3	main
mina	doc_333816885029_item	2336874	et	4	main
ka	doc_333816885029_item	2336875	et	3	main
ma	doc_333816885029_item	2336876	et	3	main
olen	doc_333816885029_item	2336877	et	3	main
üheksateistkümne	doc_333816885029_item	2336879	et	4	main
ainult	doc_333816885029_item	2336878	et	4	main
aastane	doc_333816885029_item	2336880	et	4	main
neiu	doc_333816885029_item	2336881	et	4	main
aga	doc_333816885029_item	2336882	et	3	main
olin	doc_333816885029_item	2336883	et	3	main
juba	doc_333816885029_item	2336884	et	3	main
paljudes	doc_333816885029_item	2336885	et	3	main
riikides	doc_333816885029_item	2336886	et	3	main
kui	doc_333816885029_item	2336887	et	3	main
ma	doc_333816885029_item	2336888	et	3	main
olin	doc_333816885029_item	2336889	et	3	main
umbes	doc_333816885029_item	2336890	et	4	main
olin	doc_333816885029_item	2336894	et	3	main
vanematega	doc_333816885029_item	2336897	et	4	main
mulle	doc_333816885029_item	2336907	et	4	main
ja	doc_333816885029_item	2336910	et	3	main
vanematega	doc_333816885029_item	2336927	et	4	main
väga	doc_333816885029_item	2336928	et	3	main
meeldis	doc_333816885029_item	2336934	et	3	main
see	doc_333816885029_item	2336952	et	3	main
sõltu	doc_333816885029_item	2336954	et	4	main
riikidest	doc_333816885029_item	2336955	et	3	main
me	doc_333816885029_item	2336960	et	4	main
me	doc_333816885029_item	2336963	et	4	main
mõju	doc_333816885029_item	2336965	et	4	main
külastasime	doc_333816885029_item	2336970	et	3	main
reisisime	doc_333816885029_item	2336997	et	3	main
meie	doc_333816885029_item	2337000	et	4	main
kestas	doc_333816885029_item	2337002	et	4	main
umbes	doc_333816885029_item	2337003	et	4	main
kümme	doc_333816885029_item	2337004	et	3	main
päeva	doc_333816885029_item	2337005	et	4	main
jalutasime	doc_333816885029_item	2337019	et	3	main
ka	doc_333816885029_item	2337023	et	3	main
turiste	doc_333816885029_item	2337030	et	3	main
need	doc_333816885029_item	2337032	et	3	main
restoranis	doc_333816885029_item	2337040	et	3	main
rahvatantsu	doc_333816885029_item	2337043	et	4	main
lõpetamist	doc_333816885029_item	2337054	et	4	main
tänapäeval	doc_333816885029_item	2337070	et	3	main
ka	doc_333816885029_item	2337080	et	3	main
väga	doc_333816885029_item	2337081	et	3	main
palju	doc_333816885029_item	2337082	et	4	main
mis	doc_333816885029_item	2337086	et	4	main
mida	doc_333816885030_item	2337099	et	4	main
inimesi	doc_333816885030_item	2337121	et	4	main
tantsisid	doc_333816885030_item	2337138	et	4	main
merevaiku	doc_333816885030_item	2337144	et	4	main
käsitöölisi	doc_333816885030_item	2337145	et	3	main
ilus	doc_333816885030_item	2337150	et	4	main
oli	doc_333816885030_item	2337152	et	3	main
huvitav	doc_333816885030_item	2337153	et	4	main
oli	doc_333816885030_item	2337158	et	3	main
miss	doc_333816885030_item	2337160	et	3	main
kõik	doc_333816885030_item	2337162	et	4	main
tüdrukud	doc_333816885030_item	2337163	et	3	main
nad	doc_333816885030_item	2337166	et	3	main
mida	doc_333816885030_item	2337170	et	4	main
teha	doc_333816885030_item	2337173	et	3	main
kõikidel	doc_333816885030_item	2337189	et	4	main
kus	doc_333816885031_item	2337221	et	3	main
võimalus	doc_333816885031_item	2337230	et	3	main
soovivad	doc_333816885031_item	2337235	et	4	main
need	doc_333816885031_item	2337241	et	3	main
suurem	doc_333816885031_item	2337243	et	4	main
osa	doc_333816885031_item	2337244	et	4	main
nõukogude	doc_333816885031_item	2337248	et	3	main
ka	doc_333816885031_item	2337252	et	3	main
tunnevad	doc_333816885031_item	2337255	et	3	main
ma	doc_333816885031_item	2337258	et	3	main
ise	doc_333816885031_item	2337259	et	4	main
olnud	doc_333816885031_item	2337261	et	4	main
ja	doc_333816885031_item	2337272	et	3	main
eluviis	doc_333816885031_item	2337281	et	3	main
seal	doc_333816885031_item	2337290	et	4	main
inimesed	doc_333816885031_item	2337292	et	3	main
paljudest	doc_333816885031_item	2337293	et	3	main
sain	doc_333816885031_item	2337296	et	3	main
teistega	doc_333816885031_item	2337302	et	4	main
natsiooni	doc_333816885031_item	2337304	et	4	main
ei	doc_333816885031_item	2337306	et	4	main
maast	doc_333816885031_item	2337321	et	3	main
kus	doc_333816885031_item	2337328	et	3	main
olnud	doc_333816885031_item	2337331	et	4	main
helsinkis	doc_333816885031_item	2337332	et	4	main
loomaaijad	doc_333816885031_item	2337340	et	4	main
sest	doc_333816885031_item	2337344	et	4	main
elavad	doc_333816885031_item	2337358	et	4	main
kahjuks	doc_333816885031_item	2337371	et	4	main
suur	doc_333816885031_item	2337382	et	3	main
peab	doc_333816885031_item	2337387	et	4	main
sõitma	doc_333816885031_item	2337392	et	3	main
näiteks	doc_333816885031_item	2337399	et	4	main
ma	doc_333816885031_item	2337402	et	3	main
me	doc_333816885029_item	2336924	et	4	main
palju	doc_333816885029_item	2336929	et	4	main
riikis	doc_333816885029_item	2336932	et	4	main
mulle	doc_333816885029_item	2336933	et	4	main
kõik	doc_333816885029_item	2336935	et	4	main
olid	doc_333816885029_item	2336937	et	4	main
muljed	doc_333816885029_item	2336939	et	3	main
meeldis	doc_333816885029_item	2336949	et	3	main
ja	doc_333816885029_item	2336951	et	3	main
ei	doc_333816885029_item	2336953	et	4	main
sõitsime	doc_333816885029_item	2336961	et	3	main
selles	doc_333816885029_item	2336967	et	4	main
ka	doc_333816885029_item	2336971	et	3	main
nagu	doc_333816885029_item	2336974	et	3	main
saksamaa	doc_333816885029_item	2336976	et	4	main
läti	doc_333816885029_item	2336977	et	4	main
holland	doc_333816885029_item	2336975	et	4	main
leedu	doc_333816885029_item	2336978	et	4	main
belgia	doc_333816885029_item	2336979	et	4	main
tšehhimaa	doc_333816885029_item	2336980	et	2	main
auster	doc_333816885029_item	2336981	et	3	main
koos	doc_333816885029_item	2336983	et	4	main
šveits	doc_333816885029_item	2336982	et	2	main
minu	doc_333816885029_item	2336984	et	3	main
me	doc_333816885029_item	2336986	et	4	main
oleme	doc_333816885029_item	2336987	et	3	main
seikluseotsijad	doc_333816885029_item	2336988	et	4	main
ja	doc_333816885029_item	2336989	et	3	main
igas	doc_333816885029_item	2336990	et	3	main
sõbrannaga	doc_333816885029_item	2336985	et	3	main
linnas	doc_333816885029_item	2336991	et	4	main
meil	doc_333816885029_item	2336992	et	4	main
olid	doc_333816885029_item	2336993	et	4	main
lugusid	doc_333816885029_item	2336995	et	3	main
me	doc_333816885029_item	2336996	et	4	main
erinevad	doc_333816885029_item	2336994	et	4	main
me	doc_333816885029_item	2336969	et	4	main
riigid	doc_333816885029_item	2336973	et	3	main
ja	doc_333816885029_item	2336999	et	3	main
reis	doc_333816885029_item	2337001	et	4	main
aega	doc_333816885029_item	2337008	et	4	main
prantsusmaal	doc_333816885029_item	2337011	et	4	main
seal	doc_333816885029_item	2337012	et	4	main
me	doc_333816885029_item	2337013	et	4	main
olime	doc_333816885029_item	2337014	et	3	main
eifeli	doc_333816885029_item	2337015	et	4	main
luvri	doc_333816885029_item	2337017	et	4	main
öösel	doc_333816885029_item	2337020	et	4	main
disney	doc_333816885029_item	2337024	et	4	main
kesklinnas	doc_333816885029_item	2337026	et	4	main
tegid	doc_333816885029_item	2337033	et	4	main
pilti	doc_333816885029_item	2337035	et	4	main
me	doc_333816885029_item	2337046	et	4	main
rääkisime	doc_333816885029_item	2337047	et	3	main
lõbusaid	doc_333816885029_item	2337048	et	3	main
lugesid	doc_333816885029_item	2337049	et	4	main
veel	doc_333816885029_item	2337057	et	4	main
kuhugile	doc_333816885029_item	2337059	et	4	main
ei	doc_333816885029_item	2337062	et	4	main
täpselt	doc_333816885029_item	2337064	et	4	main
kuhu	doc_333816885029_item	2337065	et	3	main
ma	doc_333816885029_item	2337066	et	3	main
tahan	doc_333816885029_item	2337067	et	3	main
noortel	doc_333816885029_item	2337068	et	3	main
suurepärane	doc_333816885029_item	2337072	et	4	main
või	doc_333816885029_item	2337075	et	4	main
välismaal	doc_333816885029_item	2337077	et	4	main
näiteks	doc_333816885029_item	2337084	et	4	main
tööd	doc_333816885029_item	2337089	et	4	main
ärge	doc_333816885029_item	2337091	et	3	main
olen	doc_333816885030_item	2337096	et	3	main
külalised	doc_333816885030_item	2337125	et	4	main
laval	doc_333816885030_item	2337135	et	3	main
müüati	doc_333816885030_item	2337141	et	4	main
oli	doc_333816885030_item	2337148	et	3	main
ja	doc_333816885030_item	2337151	et	3	main
kultuuri	doc_333816885030_item	2337156	et	4	main
nad	doc_333816885030_item	2337171	et	3	main
osalemise	doc_333816885030_item	2337175	et	4	main
nendel	doc_333816885030_item	2337177	et	4	main
häid	doc_333816885030_item	2337180	et	3	main
ja	doc_333816885030_item	2337188	et	3	main
hea	doc_333816885030_item	2337191	et	4	main
praegu	doc_333816885031_item	2337227	et	3	main
eriti	doc_333816885031_item	2337236	et	3	main
saavad	doc_333816885031_item	2337239	et	4	main
kes	doc_333816885031_item	2337242	et	4	main
elasid	doc_333816885031_item	2337247	et	4	main
aga	doc_333816885031_item	2337250	et	3	main
venemaal	doc_333816885031_item	2337264	et	4	main
inimestega	doc_333816885031_item	2337277	et	3	main
ja	doc_333816885031_item	2337280	et	3	main
tundmatu	doc_333816885031_item	2337285	et	4	main
mulle	doc_333816885031_item	2337286	et	4	main
eriti	doc_333816885031_item	2337287	et	3	main
meeldis	doc_333816885031_item	2337288	et	3	main
riikidest	doc_333816885031_item	2337294	et	3	main
ja	doc_333816885031_item	2337301	et	3	main
kõige	doc_333816885029_item	2337006	et	4	main
ja	doc_333816885029_item	2337021	et	3	main
olime	doc_333816885029_item	2337022	et	3	main
pargis	doc_333816885029_item	2337025	et	3	main
on	doc_333816885029_item	2337027	et	4	main
kõik	doc_333816885029_item	2337031	et	4	main
me	doc_333816885029_item	2337038	et	4	main
oma	doc_333816885029_item	2337050	et	4	main
sõpradele	doc_333816885029_item	2337051	et	3	main
pärast	doc_333816885029_item	2337052	et	4	main
tahan	doc_333816885029_item	2337056	et	3	main
tea	doc_333816885029_item	2337063	et	4	main
inimestel	doc_333816885029_item	2337069	et	3	main
töötada	doc_333816885029_item	2337076	et	3	main
meil	doc_333816885029_item	2337078	et	4	main
on	doc_333816885029_item	2337079	et	4	main
aitab	doc_333816885029_item	2337087	et	3	main
näinud	doc_333816885030_item	2337101	et	4	main
septembris	doc_333816885030_item	2337102	et	3	main
maardu	doc_333816885030_item	2337103	et	4	main
linnas	doc_333816885030_item	2337104	et	4	main
oli	doc_333816885030_item	2337105	et	3	main
suur	doc_333816885030_item	2337106	et	3	main
laat	doc_333816885030_item	2337107	et	3	main
ja	doc_333816885030_item	2337108	et	3	main
mina	doc_333816885030_item	2337109	et	4	main
olen	doc_333816885030_item	2337110	et	3	main
sellel	doc_333816885030_item	2337112	et	4	main
käinud	doc_333816885030_item	2337111	et	4	main
laadal	doc_333816885030_item	2337113	et	3	main
oli	doc_333816885030_item	2337114	et	3	main
väga	doc_333816885030_item	2337115	et	3	main
huvitav	doc_333816885030_item	2337116	et	4	main
ja	doc_333816885030_item	2337117	et	3	main
lõbusalt	doc_333816885030_item	2337118	et	4	main
väga	doc_333816885030_item	2337119	et	3	main
palju	doc_333816885030_item	2337120	et	4	main
tulid	doc_333816885030_item	2337124	et	4	main
väga	doc_333816885030_item	2337149	et	3	main
veel	doc_333816885030_item	2337157	et	4	main
konkurss	doc_333816885030_item	2337159	et	3	main
ilu	doc_333816885030_item	2337169	et	4	main
eest	doc_333816885030_item	2337176	et	4	main
väga	doc_333816885030_item	2337179	et	3	main
laulsid	doc_333816885030_item	2337187	et	4	main
oli	doc_333816885030_item	2337190	et	3	main
peo	doc_333816885030_item	2337193	et	4	main
mida	doc_333816885031_item	2337224	et	4	main
reisida	doc_333816885031_item	2337231	et	3	main
kuhu	doc_333816885031_item	2337232	et	3	main
hästi	doc_333816885031_item	2337237	et	3	main
tunda	doc_333816885031_item	2337240	et	3	main
elust	doc_333816885031_item	2337246	et	3	main
olen	doc_333816885031_item	2337260	et	3	main
lätis	doc_333816885031_item	2337266	et	4	main
kohti	doc_333816885031_item	2337275	et	4	main
on	doc_333816885031_item	2337282	et	4	main
jaoks	doc_333816885031_item	2337284	et	4	main
elavad	doc_333816885031_item	2337291	et	4	main
ma	doc_333816885031_item	2337295	et	3	main
suhelda	doc_333816885031_item	2337297	et	4	main
araablastega	doc_333816885031_item	2337298	et	4	main
sakslastega	doc_333816885031_item	2337300	et	3	main
kelle	doc_333816885031_item	2337303	et	4	main
ülikooli	doc_333816885029_item	2337053	et	4	main
praegu	doc_333816885029_item	2337061	et	3	main
on	doc_333816885029_item	2337071	et	4	main
organisatsioone	doc_333816885029_item	2337083	et	3	main
unesko	doc_333816885029_item	2337085	et	4	main
essee	doc_333816885030_item	2337094	et	4	main
käinud	doc_333816885030_item	2337097	et	4	main
ja	doc_333816885030_item	2337098	et	3	main
olen	doc_333816885030_item	2337100	et	3	main
laadal	doc_333816885030_item	2337123	et	3	main
ukrainast	doc_333816885030_item	2337126	et	4	main
leedust	doc_333816885030_item	2337128	et	4	main
eestist	doc_333816885030_item	2337129	et	3	main
ja	doc_333816885030_item	2337130	et	3	main
eesti	doc_333816885030_item	2337131	et	4	main
linnadest	doc_333816885030_item	2337132	et	3	main
esinesid	doc_333816885030_item	2337134	et	4	main
laulsid	doc_333816885030_item	2337136	et	4	main
rahvalaule	doc_333816885030_item	2337137	et	4	main
komme	doc_333816885030_item	2337143	et	4	main
kõik	doc_333816885030_item	2337147	et	4	main
vaadata	doc_333816885030_item	2337154	et	4	main
maardu	doc_333816885030_item	2337161	et	4	main
oli	doc_333816885030_item	2337164	et	3	main
näitasid	doc_333816885030_item	2337167	et	4	main
oma	doc_333816885030_item	2337168	et	4	main
kingiti	doc_333816885030_item	2337178	et	3	main
kingitusi	doc_333816885030_item	2337181	et	4	main
õhtul	doc_333816885030_item	2337182	et	3	main
oli	doc_333816885030_item	2337183	et	3	main
kontsert	doc_333816885030_item	2337184	et	3	main
inimesed	doc_333816885030_item	2337185	et	3	main
tuju	doc_333816885030_item	2337192	et	4	main
lõpuks	doc_333816885030_item	2337194	et	4	main
oli	doc_333816885030_item	2337195	et	3	main
väga	doc_333816885030_item	2337196	et	3	main
ilus	doc_333816885030_item	2337197	et	4	main
ja	doc_333816885030_item	2337198	et	3	main
põnev	doc_333816885030_item	2337199	et	3	main
ilutulestik	doc_333816885030_item	2337200	et	3	main
ja	doc_333816885030_item	2337201	et	3	main
veel	doc_333816885030_item	2337202	et	4	main
tuline	doc_333816885030_item	2337204	et	4	main
oli	doc_333816885030_item	2337203	et	3	main
show	doc_333816885030_item	2337205	et	4	main
ma	doc_333816885030_item	2337206	et	3	main
olen	doc_333816885030_item	2337207	et	3	main
puhanud	doc_333816885030_item	2337208	et	4	main
väga	doc_333816885030_item	2337209	et	3	main
tore	doc_333816885030_item	2337210	et	3	main
kõik	doc_333816885030_item	2337211	et	4	main
mulle	doc_333816885030_item	2337212	et	4	main
meeldis	doc_333816885030_item	2337213	et	3	main
ja	doc_333816885030_item	2337214	et	3	main
mina	doc_333816885030_item	2337215	et	4	main
meenutasin	doc_333816885030_item	2337216	et	3	main
seda	doc_333816885030_item	2337217	et	3	main
päeva	doc_333816885030_item	2337218	et	4	main
kauaks	doc_333816885030_item	2337219	et	3	main
essee	doc_333816885031_item	2337220	et	4	main
olen	doc_333816885031_item	2337222	et	3	main
käinud	doc_333816885031_item	2337223	et	4	main
olen	doc_333816885031_item	2337225	et	3	main
näinud	doc_333816885031_item	2337226	et	4	main
inimestel	doc_333816885031_item	2337228	et	3	main
ainult	doc_333816885031_item	2337234	et	4	main
oma	doc_333816885031_item	2337245	et	4	main
paljud	doc_333816885031_item	2337253	et	3	main
selles	doc_333816885031_item	2337256	et	4	main
positiivsust	doc_333816885031_item	2337257	et	4	main
inglismaal	doc_333816885031_item	2337262	et	4	main
leedus	doc_333816885031_item	2337267	et	4	main
mulle	doc_333816885031_item	2337268	et	4	main
üldse	doc_333816885031_item	2337269	et	3	main
meeldib	doc_333816885031_item	2337270	et	3	main
reisida	doc_333816885031_item	2337271	et	3	main
uusi	doc_333816885031_item	2337274	et	3	main
kohtuda	doc_333816885031_item	2337276	et	3	main
kelle	doc_333816885031_item	2337278	et	4	main
kultuur	doc_333816885031_item	2337279	et	3	main
londonis	doc_333816885031_item	2337289	et	4	main
ameeriklastega	doc_333816885031_item	2337299	et	3	main
teagi	doc_333816885031_item	2337307	et	4	main
enda	doc_333816885031_item	2337308	et	4	main
jaoks	doc_333816885031_item	2337309	et	4	main
ma	doc_333816885031_item	2337310	et	3	main
sain	doc_333816885031_item	2337311	et	3	main
teada	doc_333816885031_item	2337312	et	3	main
palju	doc_333816885031_item	2337313	et	4	main
asju	doc_333816885031_item	2337314	et	3	main
ukrainas	doc_333816885031_item	2337315	et	4	main
elavad	doc_333816885031_item	2337316	et	4	main
minu	doc_333816885031_item	2337317	et	3	main
sugulased	doc_333816885031_item	2337318	et	3	main
seepärast	doc_333816885031_item	2337319	et	3	main
sellest	doc_333816885031_item	2337320	et	4	main
natuke	doc_333816885031_item	2337324	et	4	main
teistest	doc_333816885031_item	2337327	et	4	main
sellised	doc_333816885031_item	2337343	et	4	main
seal	doc_333816885031_item	2337345	et	4	main
ei	doc_333816885031_item	2337347	et	4	main
ole	doc_333816885031_item	2337348	et	4	main
tehtud	doc_333816885031_item	2337349	et	4	main
betoonist	doc_333816885031_item	2337350	et	3	main
kus	doc_333816885031_item	2337351	et	3	main
loom	doc_333816885031_item	2337352	et	3	main
peaaegu	doc_333816885031_item	2337359	et	3	main
viisidest	doc_333816885031_item	2337370	et	3	main
on	doc_333816885031_item	2337374	et	4	main
see	doc_333816885031_item	2337380	et	3	main
üks	doc_333816885031_item	2337388	et	3	main
essee	doc_333816885032_item	2337414	et	4	main
kus	doc_333816885032_item	2337415	et	3	main
elus	doc_333816885032_item	2337433	et	4	main
italia	doc_333816885032_item	2337434	et	4	main
väga	doc_333816885032_item	2337436	et	3	main
kus	doc_333816885032_item	2337439	et	3	main
elavad	doc_333816885032_item	2337440	et	4	main
ilusad	doc_333816885032_item	2337441	et	3	main
tal	doc_333816885032_item	2337448	et	3	main
ajalugu	doc_333816885032_item	2337451	et	4	main
on	doc_333816885032_item	2337453	et	4	main
populaarne	doc_333816885032_item	2337454	et	3	main
viimasel	doc_333816885032_item	2337455	et	3	main
ajal	doc_333816885032_item	2337456	et	4	main
näinud	doc_333816885032_item	2337470	et	4	main
käinud	doc_333816885032_item	2337475	et	4	main
mulle	doc_333816885032_item	2337511	et	4	main
meeldinud	doc_333816885032_item	2337513	et	4	main
mulle	doc_333816885032_item	2337515	et	4	main
tundub	doc_333816885032_item	2337516	et	3	main
kindlasti	doc_333816885032_item	2337519	et	3	main
on	doc_333816885031_item	2337229	et	4	main
nad	doc_333816885031_item	2337233	et	3	main
seda	doc_333816885031_item	2337238	et	3	main
ajal	doc_333816885031_item	2337249	et	4	main
muidugi	doc_333816885031_item	2337251	et	4	main
noored	doc_333816885031_item	2337254	et	3	main
soomes	doc_333816885031_item	2337263	et	4	main
ukrainas	doc_333816885031_item	2337265	et	4	main
näha	doc_333816885031_item	2337273	et	3	main
minu	doc_333816885031_item	2337283	et	3	main
ma	doc_333816885031_item	2337322	et	3	main
olema	doc_333816885031_item	2337342	et	4	main
nagu	doc_333816885031_item	2337355	et	3	main
minu	doc_333816885031_item	2337362	et	3	main
reisimine	doc_333816885031_item	2337364	et	4	main
selle	doc_333816885031_item	2337372	et	4	main
on	doc_333816885031_item	2337381	et	4	main
aga	doc_333816885031_item	2337384	et	3	main
inimene	doc_333816885031_item	2337386	et	3	main
välismaa	doc_333816885031_item	2337398	et	4	main
eestis	doc_333816885031_item	2337406	et	3	main
huvitav	doc_333816885031_item	2337413	et	4	main
aastal	doc_333816885032_item	2337422	et	3	main
italias	doc_333816885032_item	2337426	et	4	main
minu	doc_333816885032_item	2337432	et	3	main
on	doc_333816885032_item	2337444	et	4	main
vana	doc_333816885032_item	2337446	et	4	main
tänapäeval	doc_333816885032_item	2337459	et	3	main
italias	doc_333816885032_item	2337467	et	4	main
palju	doc_333816885032_item	2337471	et	4	main
vaatamisväärtusi	doc_333816885032_item	2337472	et	3	main
ma	doc_333816885032_item	2337473	et	3	main
ma	doc_333816885031_item	2337305	et	3	main
tean	doc_333816885031_item	2337323	et	3	main
kui	doc_333816885031_item	2337326	et	3	main
ma	doc_333816885031_item	2337329	et	3	main
peaksid	doc_333816885031_item	2337341	et	4	main
tunneb	doc_333816885031_item	2337353	et	3	main
end	doc_333816885031_item	2337354	et	4	main
loomad	doc_333816885031_item	2337357	et	3	main
tingimuses	doc_333816885031_item	2337361	et	3	main
meelest	doc_333816885031_item	2337363	et	4	main
on	doc_333816885031_item	2337365	et	4	main
üks	doc_333816885031_item	2337366	et	3	main
kõige	doc_333816885031_item	2337367	et	4	main
parimatest	doc_333816885031_item	2337368	et	4	main
jaoks	doc_333816885031_item	2337373	et	4	main
vaja	doc_333816885031_item	2337375	et	4	main
raha	doc_333816885031_item	2337376	et	4	main
ja	doc_333816885031_item	2337377	et	3	main
ikkagi	doc_333816885031_item	2337385	et	4	main
kord	doc_333816885031_item	2337389	et	4	main
see	doc_333816885031_item	2337393	et	3	main
ei	doc_333816885031_item	2337394	et	4	main
pea	doc_333816885031_item	2337395	et	4	main
kindlasti	doc_333816885031_item	2337396	et	3	main
olema	doc_333816885031_item	2337397	et	4	main
suvi	doc_333816885031_item	2337401	et	3	main
ööbimine	doc_333816885031_item	2337407	et	4	main
jõe	doc_333816885031_item	2337409	et	3	main
olen	doc_333816885032_item	2337416	et	3	main
ma	doc_333816885032_item	2337423	et	3	main
see	doc_333816885032_item	2337427	et	3	main
reis	doc_333816885032_item	2337431	et	4	main
on	doc_333816885032_item	2337435	et	4	main
ilus	doc_333816885032_item	2337437	et	4	main
riik	doc_333816885032_item	2337438	et	3	main
rooma	doc_333816885032_item	2337443	et	4	main
on	doc_333816885032_item	2337449	et	4	main
kogu	doc_333816885032_item	2337457	et	4	main
barokko	doc_333816885032_item	2337460	et	4	main
on	doc_333816885032_item	2337461	et	4	main
väga	doc_333816885032_item	2337462	et	3	main
modne	doc_333816885032_item	2337463	et	4	main
nagu	doc_333816885032_item	2337464	et	3	main
hi-tech	doc_333816885032_item	2337465	et	4	main
ja	doc_333816885032_item	2337477	et	3	main
käin	doc_333816885032_item	2337520	et	3	main
veel	doc_333816885032_item	2337522	et	4	main
me	doc_333816885033_item	2337536	et	4	main
seda	doc_333816885033_item	2337539	et	3	main
meid	doc_333816885033_item	2337542	et	4	main
oli	doc_333816885033_item	2337543	et	3	main
viis	doc_333816885033_item	2337544	et	4	main
inimest	doc_333816885033_item	2337545	et	3	main
ja	doc_333816885033_item	2337546	et	3	main
me	doc_333816885033_item	2337547	et	4	main
jurmalas	doc_333816885033_item	2337554	et	4	main
kuiv	doc_333816885033_item	2337561	et	3	main
esimesel	doc_333816885033_item	2337565	et	3	main
ta	doc_333816885033_item	2337592	et	4	main
pärast	doc_333816885033_item	2337597	et	4	main
me	doc_333816885033_item	2337598	et	4	main
kahekohalises	doc_333816885033_item	2337601	et	4	main
läksime	doc_333816885033_item	2337610	et	3	main
väga	doc_333816885033_item	2337617	et	3	main
kolm	doc_333816885033_item	2337622	et	3	main
platsil	doc_333816885033_item	2337625	et	3	main
oma	doc_333816885033_item	2337627	et	4	main
punane	doc_333816885033_item	2337629	et	4	main
me	doc_333816885033_item	2337641	et	4	main
me	doc_333816885033_item	2337645	et	4	main
mitte	doc_333816885033_item	2337647	et	3	main
linna	doc_333816885033_item	2337649	et	4	main
akvaparki	doc_333816885033_item	2337653	et	4	main
kõige	doc_333816885033_item	2337656	et	4	main
suurem	doc_333816885033_item	2337657	et	4	main
ja	doc_333816885033_item	2337677	et	3	main
õluklaasid	doc_333816885033_item	2337689	et	4	main
ilus	doc_333816885034_item	2337721	et	4	main
inimesed	doc_333816885034_item	2337728	et	3	main
elavad	doc_333816885034_item	2337730	et	4	main
eestis	doc_333816885034_item	2337731	et	3	main
ei	doc_333816885034_item	2337732	et	4	main
kaunimad	doc_333816885034_item	2337743	et	4	main
rohkem	doc_333816885031_item	2337325	et	4	main
olen	doc_333816885031_item	2337330	et	3	main
mulle	doc_333816885031_item	2337333	et	4	main
meeldis	doc_333816885031_item	2337334	et	3	main
nende	doc_333816885031_item	2337335	et	4	main
loomaaed	doc_333816885031_item	2337336	et	3	main
minu	doc_333816885031_item	2337337	et	3	main
meelest	doc_333816885031_item	2337338	et	4	main
kõik	doc_333816885031_item	2337339	et	4	main
loomapuur	doc_333816885031_item	2337346	et	3	main
vanglas	doc_333816885031_item	2337356	et	3	main
looduslikus	doc_333816885031_item	2337360	et	4	main
ajaveetmise	doc_333816885031_item	2337369	et	3	main
päris	doc_333816885031_item	2337378	et	4	main
tihti	doc_333816885031_item	2337379	et	3	main
summa	doc_333816885031_item	2337383	et	4	main
aastas	doc_333816885031_item	2337390	et	3	main
kuhugi	doc_333816885031_item	2337391	et	4	main
eelmine	doc_333816885031_item	2337400	et	3	main
käisin	doc_333816885031_item	2337403	et	3	main
lõuna	doc_333816885031_item	2337405	et	4	main
telkides	doc_333816885031_item	2337408	et	4	main
ääres	doc_333816885031_item	2337410	et	4	main
on	doc_333816885031_item	2337411	et	4	main
väga	doc_333816885031_item	2337412	et	3	main
olen	doc_333816885032_item	2337419	et	3	main
näinud	doc_333816885032_item	2337420	et	4	main
matkamas	doc_333816885031_item	2337404	et	3	main
käinud	doc_333816885032_item	2337417	et	4	main
mida	doc_333816885032_item	2337418	et	4	main
olen	doc_333816885032_item	2337424	et	3	main
kõige	doc_333816885032_item	2337429	et	4	main
huvitav	doc_333816885032_item	2337430	et	4	main
väga	doc_333816885032_item	2337445	et	3	main
linn	doc_333816885032_item	2337447	et	3	main
maailmas	doc_333816885032_item	2337458	et	3	main
sisseinterjeeris	doc_333816885032_item	2337466	et	4	main
olen	doc_333816885032_item	2337469	et	3	main
olen	doc_333816885032_item	2337474	et	3	main
muuseumis	doc_333816885032_item	2337476	et	3	main
rohkem	doc_333816885032_item	2337510	et	4	main
et	doc_333816885032_item	2337517	et	3	main
essee	doc_333816885033_item	2337523	et	4	main
kutsunud	doc_333816885033_item	2337534	et	4	main
sünnipäevale	doc_333816885033_item	2337535	et	4	main
tähistama	doc_333816885033_item	2337538	et	3	main
läksime	doc_333816885033_item	2337548	et	3	main
bussiga	doc_333816885033_item	2337549	et	3	main
lätisse	doc_333816885033_item	2337550	et	4	main
täpsemalt	doc_333816885033_item	2337551	et	4	main
kogu	doc_333816885033_item	2337558	et	4	main
oli	doc_333816885033_item	2337560	et	3	main
soe	doc_333816885033_item	2337563	et	4	main
kallis	doc_333816885033_item	2337595	et	4	main
oma	doc_333816885033_item	2337607	et	4	main
asjad	doc_333816885033_item	2337608	et	3	main
ja	doc_333816885033_item	2337609	et	3	main
suur	doc_333816885033_item	2337618	et	3	main
oli	doc_333816885033_item	2337621	et	3	main
raekojaplats	doc_333816885033_item	2337630	et	3	main
trance	doc_333816885033_item	2337633	et	4	main
platsid	doc_333816885033_item	2337634	et	3	main
bussiga	doc_333816885033_item	2337643	et	3	main
otsustasime	doc_333816885033_item	2337646	et	3	main
vaid	doc_333816885033_item	2337651	et	3	main
ja	doc_333816885033_item	2337664	et	3	main
minna	doc_333816885033_item	2337674	et	3	main
koju	doc_333816885033_item	2337676	et	3	main
ostsime	doc_333816885033_item	2337681	et	3	main
eelmisel	doc_333816885032_item	2337421	et	3	main
käinud	doc_333816885032_item	2337425	et	4	main
oli	doc_333816885032_item	2337428	et	3	main
inimesed	doc_333816885032_item	2337442	et	3	main
oma	doc_333816885032_item	2337450	et	4	main
mis	doc_333816885032_item	2337452	et	4	main
ma	doc_333816885032_item	2337468	et	3	main
näituses	doc_333816885032_item	2337478	et	4	main
see	doc_333816885032_item	2337479	et	3	main
väga	doc_333816885032_item	2337480	et	3	main
huvitav	doc_333816885032_item	2337481	et	4	main
ja	doc_333816885032_item	2337482	et	3	main
kasulik	doc_333816885032_item	2337483	et	3	main
minu	doc_333816885032_item	2337484	et	3	main
jaoks	doc_333816885032_item	2337485	et	4	main
ma	doc_333816885032_item	2337486	et	3	main
olen	doc_333816885032_item	2337487	et	3	main
kindel	doc_333816885032_item	2337488	et	3	main
et	doc_333816885032_item	2337489	et	3	main
kõige	doc_333816885032_item	2337490	et	4	main
huvitav	doc_333816885032_item	2337491	et	4	main
italias	doc_333816885032_item	2337492	et	4	main
on	doc_333816885032_item	2337493	et	4	main
öö	doc_333816885032_item	2337494	et	4	main
elu	doc_333816885032_item	2337495	et	4	main
italiased	doc_333816885032_item	2337496	et	4	main
on	doc_333816885032_item	2337497	et	4	main
sõbralikud	doc_333816885032_item	2337498	et	3	main
ja	doc_333816885032_item	2337499	et	3	main
suhtlemises	doc_333816885032_item	2337500	et	4	main
väga	doc_333816885032_item	2337501	et	3	main
hea	doc_333816885032_item	2337502	et	4	main
sõbrad	doc_333816885032_item	2337503	et	3	main
ma	doc_333816885032_item	2337504	et	3	main
olen	doc_333816885032_item	2337505	et	3	main
tutvunud	doc_333816885032_item	2337506	et	4	main
palju	doc_333816885032_item	2337507	et	4	main
inimesi	doc_333816885032_item	2337508	et	4	main
kõige	doc_333816885032_item	2337509	et	4	main
olen	doc_333816885032_item	2337512	et	3	main
moe-show	doc_333816885032_item	2337514	et	4	main
ma	doc_333816885032_item	2337518	et	3	main
kus	doc_333816885033_item	2337524	et	3	main
ja	doc_333816885033_item	2337527	et	3	main
riias	doc_333816885033_item	2337552	et	4	main
ilm	doc_333816885033_item	2337555	et	3	main
me	doc_333816885033_item	2337567	et	4	main
ledos	doc_333816885033_item	2337569	et	4	main
see	doc_333816885033_item	2337570	et	3	main
hostellis	doc_333816885033_item	2337591	et	4	main
olime	doc_333816885033_item	2337599	et	3	main
edasi	doc_333816885033_item	2337611	et	3	main
olen	doc_333816885033_item	2337525	et	3	main
mida	doc_333816885033_item	2337528	et	4	main
olen	doc_333816885033_item	2337529	et	3	main
augustis	doc_333816885033_item	2337531	et	3	main
ma	doc_333816885033_item	2337532	et	3	main
olen	doc_333816885033_item	2337533	et	3	main
ja	doc_333816885033_item	2337553	et	3	main
meid	doc_333816885033_item	2337556	et	4	main
aeg	doc_333816885033_item	2337559	et	3	main
ilm	doc_333816885033_item	2337564	et	3	main
päival	doc_333816885033_item	2337566	et	4	main
käisime	doc_333816885033_item	2337568	et	3	main
on	doc_333816885033_item	2337571	et	4	main
meelerõõmu	doc_333816885033_item	2337572	et	4	main
perekompleks	doc_333816885033_item	2337573	et	3	main
me	doc_333816885033_item	2337574	et	4	main
proovisime	doc_333816885033_item	2337575	et	3	main
kõik	doc_333816885033_item	2337576	et	4	main
läti	doc_333816885033_item	2337577	et	4	main
köögi	doc_333816885033_item	2337578	et	3	main
praed	doc_333816885033_item	2337579	et	4	main
sel	doc_333816885033_item	2337580	et	3	main
järel	doc_333816885033_item	2337581	et	4	main
me	doc_333816885033_item	2337582	et	4	main
läksime	doc_333816885033_item	2337583	et	3	main
rolluisutama	doc_333816885033_item	2337584	et	4	main
ja	doc_333816885033_item	2337585	et	3	main
igasugused	doc_333816885033_item	2337586	et	3	main
teise	doc_333816885033_item	2337587	et	4	main
atraktsioone	doc_333816885033_item	2337588	et	3	main
me	doc_333816885033_item	2337589	et	4	main
peatusime	doc_333816885033_item	2337590	et	4	main
italias	doc_333816885032_item	2337521	et	4	main
käinud	doc_333816885033_item	2337526	et	4	main
näinud	doc_333816885033_item	2337530	et	4	main
otsustasime	doc_333816885033_item	2337537	et	3	main
päeva	doc_333816885033_item	2337540	et	4	main
reisil	doc_333816885033_item	2337541	et	3	main
rõõmustas	doc_333816885033_item	2337557	et	3	main
ja	doc_333816885033_item	2337562	et	3	main
väga	doc_333816885033_item	2337594	et	3	main
see	doc_333816885033_item	2337596	et	3	main
toas	doc_333816885033_item	2337602	et	3	main
me	doc_333816885033_item	2337604	et	4	main
pidutsema	doc_333816885033_item	2337612	et	3	main
klub	doc_333816885033_item	2337615	et	4	main
seal	doc_333816885033_item	2337620	et	4	main
nimi	doc_333816885033_item	2337628	et	3	main
rnb	doc_333816885033_item	2337631	et	4	main
ja	doc_333816885033_item	2337632	et	3	main
järgmisel	doc_333816885033_item	2337639	et	3	main
jõime	doc_333816885033_item	2337665	et	3	main
ja	doc_333816885033_item	2337667	et	3	main
õhtul	doc_333816885033_item	2337671	et	3	main
seda	doc_333816885033_item	2337679	et	3	main
me	doc_333816885033_item	2337680	et	4	main
suveniirid	doc_333816885033_item	2337682	et	3	main
mis	doc_333816885033_item	2337684	et	4	main
kleebitakse	doc_333816885033_item	2337685	et	3	main
külmkappi	doc_333816885033_item	2337686	et	4	main
loodus	doc_333816885034_item	2337722	et	4	main
teised	doc_333816885034_item	2337727	et	4	main
kes	doc_333816885034_item	2337729	et	4	main
sest	doc_333816885034_item	2337738	et	4	main
meil	doc_333816885034_item	2337739	et	4	main
eestis	doc_333816885034_item	2337740	et	3	main
võime	doc_333816885034_item	2337747	et	4	main
ja	doc_333816885034_item	2337749	et	3	main
vaadata	doc_333816885034_item	2337753	et	4	main
olen	doc_333816885034_item	2337755	et	3	main
kus	doc_333816885034_item	2337779	et	3	main
seale	doc_333816885034_item	2337787	et	3	main
paistab	doc_333816885034_item	2337794	et	3	main
te	doc_333816885034_item	2337800	et	4	main
ka	doc_333816885034_item	2337803	et	3	main
on	doc_333816885034_item	2337806	et	4	main
pargi	doc_333816885034_item	2337807	et	4	main
park	doc_333816885034_item	2337819	et	3	main
on	doc_333816885034_item	2337821	et	4	main
vaade	doc_333816885034_item	2337823	et	3	main
suvel	doc_333816885034_item	2337824	et	3	main
pealinn	doc_333816885034_item	2337831	et	3	main
tallinn	doc_333816885034_item	2337832	et	4	main
et	doc_333816885034_item	2337837	et	3	main
vanalinna	doc_333816885034_item	2337839	et	4	main
väga	doc_333816885034_item	2337850	et	3	main
ekskursile	doc_333816885034_item	2337860	et	4	main
armastan	doc_333816885034_item	2337863	et	3	main
siin	doc_333816885034_item	2337865	et	4	main
välismaalased	doc_333816885034_item	2337877	et	3	main
oli	doc_333816885033_item	2337593	et	3	main
viiekesi	doc_333816885033_item	2337600	et	3	main
seal	doc_333816885033_item	2337603	et	4	main
jäätsime	doc_333816885033_item	2337605	et	4	main
kõik	doc_333816885033_item	2337606	et	4	main
ööklubi	doc_333816885033_item	2337613	et	4	main
larocca	doc_333816885033_item	2337614	et	4	main
oli	doc_333816885033_item	2337616	et	3	main
ja	doc_333816885033_item	2337619	et	3	main
tantsuplatsi	doc_333816885033_item	2337623	et	4	main
oli	doc_333816885033_item	2337636	et	3	main
huvitav	doc_333816885033_item	2337638	et	4	main
päeval	doc_333816885033_item	2337640	et	3	main
jurmalasse	doc_333816885033_item	2337644	et	4	main
minna	doc_333816885033_item	2337648	et	3	main
vaatama	doc_333816885033_item	2337650	et	3	main
baltikas	doc_333816885033_item	2337658	et	4	main
seal	doc_333816885033_item	2337659	et	4	main
me	doc_333816885033_item	2337660	et	4	main
proovisime	doc_333816885033_item	2337661	et	3	main
igasugused	doc_333816885033_item	2337662	et	3	main
jäätise-	doc_333816885033_item	2337666	et	3	main
alkoholtsed	doc_333816885033_item	2337668	et	4	main
sel	doc_333816885033_item	2337670	et	3	main
me	doc_333816885033_item	2337672	et	4	main
pidime	doc_333816885033_item	2337673	et	3	main
tagasi	doc_333816885033_item	2337675	et	3	main
läti	doc_333816885033_item	2337687	et	4	main
plakaadid	doc_333816885033_item	2337688	et	4	main
ja	doc_333816885034_item	2337726	et	3	main
pea	doc_333816885034_item	2337733	et	4	main
on	doc_333816885034_item	2337741	et	4	main
me	doc_333816885034_item	2337746	et	4	main
võime	doc_333816885034_item	2337752	et	4	main
linnule	doc_333816885034_item	2337759	et	4	main
park	doc_333816885034_item	2337778	et	3	main
arvates	doc_333816885034_item	2337786	et	4	main
sest	doc_333816885034_item	2337791	et	4	main
ja	doc_333816885034_item	2337795	et	3	main
minna	doc_333816885034_item	2337802	et	3	main
rannale	doc_333816885034_item	2337804	et	3	main
seal	doc_333816885034_item	2337814	et	4	main
loss	doc_333816885034_item	2337816	et	3	main
kaunis	doc_333816885034_item	2337818	et	4	main
kaunis	doc_333816885034_item	2337822	et	4	main
ja	doc_333816885034_item	2337825	et	3	main
sügisel	doc_333816885034_item	2337826	et	3	main
meil	doc_333816885034_item	2337827	et	4	main
on	doc_333816885034_item	2337828	et	4	main
turistid	doc_333816885034_item	2337834	et	3	main
ka	doc_333816885034_item	2337849	et	3	main
seal	doc_333816885034_item	2337853	et	4	main
palju	doc_333816885034_item	2337867	et	4	main
igal	doc_333816885033_item	2337624	et	3	main
oli	doc_333816885033_item	2337626	et	3	main
kõigil	doc_333816885033_item	2337635	et	4	main
väga	doc_333816885033_item	2337637	et	3	main
sõitsime	doc_333816885033_item	2337642	et	3	main
minna	doc_333816885033_item	2337652	et	3	main
mis	doc_333816885033_item	2337654	et	4	main
on	doc_333816885033_item	2337655	et	4	main
atraktsioone	doc_333816885033_item	2337663	et	3	main
kokteilid	doc_333816885033_item	2337669	et	3	main
enne	doc_333816885033_item	2337678	et	4	main
magniitid	doc_333816885033_item	2337683	et	4	main
reis	doc_333816885033_item	2337690	et	4	main
kõigile	doc_333816885033_item	2337691	et	4	main
meeldis	doc_333816885033_item	2337692	et	3	main
ja	doc_333816885033_item	2337693	et	3	main
kõik	doc_333816885033_item	2337694	et	4	main
tahaksid	doc_333816885033_item	2337695	et	4	main
veel	doc_333816885033_item	2337696	et	4	main
korda	doc_333816885033_item	2337697	et	4	main
tagasi	doc_333816885033_item	2337698	et	3	main
minna	doc_333816885033_item	2337699	et	3	main
essee	doc_333816885034_item	2337700	et	4	main
kus	doc_333816885034_item	2337701	et	3	main
olen	doc_333816885034_item	2337702	et	3	main
käinud	doc_333816885034_item	2337703	et	4	main
ja	doc_333816885034_item	2337704	et	3	main
mida	doc_333816885034_item	2337705	et	4	main
olen	doc_333816885034_item	2337706	et	3	main
näinud	doc_333816885034_item	2337707	et	4	main
meie	doc_333816885034_item	2337708	et	4	main
eestimaa	doc_333816885034_item	2337709	et	4	main
on	doc_333816885034_item	2337710	et	4	main
kaunis	doc_333816885034_item	2337711	et	4	main
maa	doc_333816885034_item	2337712	et	4	main
siin	doc_333816885034_item	2337713	et	4	main
on	doc_333816885034_item	2337714	et	4	main
huvitavaid	doc_333816885034_item	2337716	et	4	main
palju	doc_333816885034_item	2337715	et	4	main
kohti	doc_333816885034_item	2337717	et	4	main
linnu	doc_333816885034_item	2337718	et	4	main
meil	doc_333816885034_item	2337719	et	4	main
on	doc_333816885034_item	2337720	et	4	main
ja	doc_333816885034_item	2337723	et	3	main
eestlased	doc_333816885034_item	2337725	et	3	main
sõitma	doc_333816885034_item	2337734	et	3	main
teisele	doc_333816885034_item	2337736	et	4	main
maale	doc_333816885034_item	2337737	et	4	main
kuhu	doc_333816885034_item	2337745	et	3	main
ma	doc_333816885034_item	2337754	et	3	main
tulla	doc_333816885034_item	2337789	et	3	main
maastik	doc_333816885034_item	2337724	et	3	main
kusagile	doc_333816885034_item	2337735	et	3	main
omad	doc_333816885034_item	2337742	et	4	main
minna	doc_333816885034_item	2337748	et	3	main
mida	doc_333816885034_item	2337750	et	4	main
paljudele	doc_333816885034_item	2337757	et	3	main
olen	doc_333816885034_item	2337761	et	3	main
pärit	doc_333816885034_item	2337762	et	3	main
ida	doc_333816885034_item	2337763	et	4	main
virumaalt	doc_333816885034_item	2337764	et	3	main
kus	doc_333816885034_item	2337765	et	3	main
on	doc_333816885034_item	2337766	et	4	main
ontika	doc_333816885034_item	2337767	et	4	main
juga	doc_333816885034_item	2337768	et	4	main
seal	doc_333816885034_item	2337769	et	4	main
on	doc_333816885034_item	2337770	et	4	main
kaunis	doc_333816885034_item	2337771	et	4	main
merele	doc_333816885034_item	2337773	et	3	main
ontika	doc_333816885034_item	2337774	et	4	main
vaade	doc_333816885034_item	2337772	et	3	main
kõrval	doc_333816885034_item	2337775	et	4	main
on	doc_333816885034_item	2337776	et	4	main
toila	doc_333816885034_item	2337777	et	4	main
kohad	doc_333816885034_item	2337744	et	4	main
me	doc_333816885034_item	2337751	et	4	main
käinud	doc_333816885034_item	2337756	et	4	main
kohtadele	doc_333816885034_item	2337758	et	3	main
ma	doc_333816885034_item	2337760	et	3	main
on	doc_333816885034_item	2337780	et	4	main
ja	doc_333816885034_item	2337783	et	3	main
minu	doc_333816885034_item	2337785	et	3	main
parem	doc_333816885034_item	2337788	et	4	main
suvel	doc_333816885034_item	2337790	et	3	main
suvel	doc_333816885034_item	2337792	et	3	main
päike	doc_333816885034_item	2337793	et	3	main
on	doc_333816885034_item	2337796	et	4	main
rohelised	doc_333816885034_item	2337797	et	4	main
taimed	doc_333816885034_item	2337798	et	3	main
mis	doc_333816885034_item	2337805	et	4	main
räpinasse	doc_333816885034_item	2337813	et	4	main
on	doc_333816885034_item	2337815	et	4	main
ja	doc_333816885034_item	2337817	et	3	main
seal	doc_333816885034_item	2337820	et	4	main
imelik	doc_333816885034_item	2337781	et	3	main
park	doc_333816885034_item	2337782	et	3	main
allee	doc_333816885034_item	2337784	et	4	main
võite	doc_333816885034_item	2337801	et	4	main
kõrval	doc_333816885034_item	2337808	et	4	main
veel	doc_333816885034_item	2337809	et	4	main
kaunis	doc_333816885034_item	2337830	et	4	main
sinna	doc_333816885034_item	2337836	et	3	main
vanu	doc_333816885034_item	2337843	et	4	main
hooned	doc_333816885034_item	2337844	et	4	main
ilus	doc_333816885034_item	2337851	et	4	main
ma	doc_333816885034_item	2337861	et	3	main
eestit	doc_333816885034_item	2337864	et	3	main
mida	doc_344825459481_item	2338141	et	4	main
kuulete	doc_344825459481_item	2338153	et	4	main
eesti	doc_344825459481_item	2338154	et	4	main
kultuur	doc_344825459481_item	2338155	et	3	main
1	doc_344825459481_item	2338156	et	2	main
kui	doc_344825459481_item	2338157	et	3	main
või	doc_344825459481_item	2338170	et	4	main
inimene	doc_344825459481_item	2338177	et	3	main
ne	doc_344825459481_item	2338182	et	4	main
et	doc_344825459481_item	2338184	et	3	main
algab	doc_344825459481_item	2338186	et	3	main
ise	doc_344825459481_item	2338188	et	4	main
rahvakultuur	doc_344825459481_item	2338196	et	3	main
tuntuvad	doc_344825459481_item	2338200	et	4	main
eesti	doc_344825459481_item	2338201	et	4	main
kirjanikud	doc_344825459481_item	2338202	et	3	main
eestlased	doc_344825459481_item	2338209	et	3	main
ma	doc_344825459481_item	2338221	et	3	main
assemeleerimine	doc_344825459481_item	2338225	et	4	main
kaotab	doc_344825459481_item	2338229	et	3	main
on	doc_345282884525_item	2338233	et	4	main
baruto	doc_345282884525_item	2338234	et	4	main
ta	doc_345282884525_item	2338235	et	4	main
töötab	doc_345282884525_item	2338247	et	3	main
elab	doc_345282884525_item	2338249	et	3	main
ta	doc_345282884525_item	2338251	et	4	main
ta	doc_345282884525_item	2338257	et	4	main
eesti	doc_345282884525_item	2338260	et	4	main
vaga	doc_345282884525_item	2338267	et	4	main
suur	doc_345282884525_item	2338268	et	3	main
majja	doc_345282884525_item	2338269	et	3	main
baruto	doc_345282884525_item	2338286	et	4	main
ka	doc_345282884525_item	2338288	et	3	main
vaga	doc_345282884525_item	2338289	et	4	main
isa	doc_345282884525_item	2338297	et	4	main
baruto	doc_345282884525_item	2338298	et	4	main
elab	doc_345282884525_item	2338299	et	3	main
tallinnas	doc_345282884525_item	2338300	et	4	main
aga	doc_345282884525_item	2338301	et	3	main
oskab	doc_345282884525_item	2338308	et	3	main
suvel	doc_333816885034_item	2337799	et	3	main
ma	doc_333816885034_item	2337810	et	3	main
olin	doc_333816885034_item	2337811	et	3	main
käima	doc_333816885034_item	2337812	et	4	main
lähevad	doc_333816885034_item	2337835	et	3	main
vaadata	doc_333816885034_item	2337838	et	4	main
kus	doc_333816885034_item	2337840	et	3	main
ja	doc_333816885034_item	2337845	et	3	main
tänavaid	doc_333816885034_item	2337846	et	4	main
narva	doc_333816885034_item	2337847	et	4	main
linn	doc_333816885034_item	2337852	et	3	main
on	doc_333816885034_item	2337854	et	4	main
vana	doc_333816885034_item	2337855	et	4	main
loss	doc_333816885034_item	2337856	et	3	main
kuhu	doc_333816885034_item	2337857	et	3	main
võite	doc_333816885034_item	2337858	et	4	main
minna	doc_333816885034_item	2337859	et	3	main
väga	doc_333816885034_item	2337862	et	3	main
vaatamisväärsusi	doc_333816885034_item	2337868	et	4	main
mida	doc_333816885034_item	2337869	et	4	main
ka	doc_333816885034_item	2337829	et	3	main
kõik	doc_333816885034_item	2337833	et	4	main
on	doc_333816885034_item	2337841	et	4	main
palju	doc_333816885034_item	2337842	et	4	main
on	doc_333816885034_item	2337848	et	4	main
on	doc_333816885034_item	2337866	et	4	main
võivad	doc_333816885034_item	2337870	et	4	main
vaada	doc_333816885034_item	2337871	et	4	main
mitte	doc_333816885034_item	2337872	et	3	main
ainult	doc_333816885034_item	2337873	et	4	main
eestlased	doc_333816885034_item	2337874	et	3	main
vaid	doc_333816885034_item	2337875	et	3	main
ka	doc_333816885034_item	2337876	et	3	main
küsimusele	doc_344825459481_item	2338139	et	4	main
tunnete	doc_344825459481_item	2338144	et	4	main
kuulete	doc_344825459481_item	2338146	et	4	main
kuulen	doc_344825459481_item	2338158	et	3	main
hakkan	doc_344825459481_item	2338162	et	3	main
kas	doc_344825459481_item	2338164	et	3	main
kuidas	doc_344825459481_item	2338175	et	3	main
2	doc_344825459481_item	2338192	et	2	main
kultuur	doc_344825459481_item	2338194	et	3	main
rahvalooming	doc_344825459481_item	2338197	et	3	main
1	doc_344825459481_item	2338140	et	2	main
mõtlete	doc_344825459481_item	2338143	et	3	main
kui	doc_344825459481_item	2338145	et	3	main
sõna	doc_344825459481_item	2338159	et	4	main
kultuur	doc_344825459481_item	2338160	et	3	main
peab	doc_344825459481_item	2338178	et	4	main
ja	doc_344825459481_item	2338181	et	3	main
arvan	doc_344825459481_item	2338183	et	3	main
väike	doc_344825459481_item	2338211	et	4	main
euroopa	doc_344825459481_item	2338218	et	4	main
liidu	doc_344825459481_item	2338219	et	3	main
te	doc_344825459481_item	2338142	et	4	main
mõtlema	doc_344825459481_item	2338163	et	3	main
ise	doc_344825459481_item	2338166	et	4	main
kultuurne	doc_344825459481_item	2338168	et	3	main
inimene	doc_344825459481_item	2338169	et	3	main
ei	doc_344825459481_item	2338171	et	4	main
mulle	doc_344825459481_item	2338172	et	4	main
tuleb	doc_344825459481_item	2338173	et	3	main
meelde	doc_344825459481_item	2338174	et	3	main
end	doc_344825459481_item	2338179	et	4	main
käituma	doc_344825459481_item	2338180	et	3	main
inimestest	doc_344825459481_item	2338187	et	3	main
püüan	doc_344825459481_item	2338189	et	3	main
eesti	doc_344825459481_item	2338193	et	4	main
tähendab	doc_344825459481_item	2338195	et	3	main
meelde	doc_344825459481_item	2338199	et	3	main
luuletajad	doc_344825459481_item	2338203	et	4	main
peame	doc_344825459481_item	2338204	et	4	main
hoidma	doc_344825459481_item	2338205	et	3	main
rahvas	doc_344825459481_item	2338212	et	4	main
on	doc_344825459481_item	2338214	et	4	main
arvamus	doc_344825459481_item	2338216	et	3	main
kardan	doc_344825459481_item	2338222	et	4	main
pildi	doc_345282884525_item	2338230	et	4	main
see	doc_345282884525_item	2338232	et	3	main
rakishi	doc_345282884525_item	2338244	et	4	main
on	doc_345282884525_item	2338252	et	4	main
kakskummend	doc_345282884525_item	2338253	et	4	main
ja	doc_345282884525_item	2338262	et	3	main
on	doc_345282884525_item	2338272	et	4	main
noor	doc_345282884525_item	2338280	et	3	main
suur	doc_345282884525_item	2338290	et	3	main
ta	doc_345282884525_item	2338291	et	4	main
kontrolltöö	doc_346862720676_item	2338311	et	4	main
tähtsamad	doc_346862720676_item	2338323	et	4	main
viljandi	doc_346862720676_item	2338328	et	4	main
olid	doc_346862720676_item	2338341	et	4	main
linnas	doc_346862720676_item	2338344	et	4	main
elasid	doc_346862720676_item	2338345	et	4	main
sakslased	doc_346862720676_item	2338346	et	3	main
tubakat	doc_346862720676_item	2338352	et	3	main
välja	doc_346862720676_item	2338357	et	4	main
vina	doc_346862720676_item	2338360	et	4	main
raekoda	doc_346862720676_item	2338367	et	4	main
raekojas	doc_346862720676_item	2338370	et	3	main
istungeid	doc_346862720676_item	2338372	et	3	main
mõni	doc_346862720676_item	2338379	et	3	main
tähtsad	doc_346862720676_item	2338385	et	3	main
toomekirikute	doc_346862720676_item	2338387	et	4	main
olid	doc_346862720676_item	2338389	et	4	main
antsid	doc_346862720676_item	2338393	et	4	main
õpetasid	doc_346862720676_item	2338395	et	4	main
lugema	doc_346862720676_item	2338396	et	4	main
läbiviidi	doc_346862720676_item	2338421	et	3	main
töid	doc_346862720676_item	2338436	et	3	main
käsitööliste	doc_346862720676_item	2338442	et	4	main
madalam	doc_346862720676_item	2338446	et	4	main
sakslaste	doc_346862720676_item	2338477	et	3	main
venemaalt	doc_346862720676_item	2338486	et	3	main
kasulikus	doc_346862720676_item	2338490	et	4	main
vahel	doc_346862720676_item	2338499	et	4	main
karusnahke	doc_346862720676_item	2338503	et	3	main
baltasar	doc_346862720676_item	2338518	et	4	main
kiriku	doc_346862720676_item	2338532	et	3	main
see	doc_346862720676_item	2338536	et	3	main
kiriku	doc_346862720676_item	2338539	et	3	main
1535	doc_346862720676_item	2338563	et	2	main
2	doc_346862720676_item	2338565	et	2	main
rahaga	doc_346862720676_item	2338582	et	4	main
vastus	doc_344825459481_item	2338138	et	3	main
sõna	doc_344825459481_item	2338147	et	4	main
2	doc_344825459481_item	2338149	et	2	main
kultuur	doc_344825459481_item	2338148	et	3	main
mida	doc_344825459481_item	2338150	et	4	main
tunnete	doc_344825459481_item	2338151	et	4	main
kui	doc_344825459481_item	2338152	et	3	main
siis	doc_344825459481_item	2338161	et	3	main
ma	doc_344825459481_item	2338165	et	3	main
olen	doc_344825459481_item	2338167	et	3	main
kultuurne	doc_344825459481_item	2338176	et	3	main
kultuur	doc_344825459481_item	2338185	et	3	main
olema	doc_344825459481_item	2338190	et	4	main
kultuurseks	doc_344825459481_item	2338191	et	4	main
tulevad	doc_344825459481_item	2338198	et	4	main
eesti	doc_344825459481_item	2338206	et	4	main
kultuur	doc_344825459481_item	2338207	et	3	main
on	doc_344825459481_item	2338210	et	4	main
mu	doc_344825459481_item	2338215	et	3	main
aga	doc_344825459481_item	2338220	et	3	main
ja	doc_344825459481_item	2338226	et	3	main
kirjeldus	doc_345282884525_item	2338231	et	4	main
on	doc_345282884525_item	2338239	et	4	main
sundinud	doc_345282884525_item	2338240	et	4	main
tallinnas	doc_345282884525_item	2338241	et	4	main
ta	doc_345282884525_item	2338242	et	4	main
ta	doc_345282884525_item	2338246	et	4	main
ja	doc_345282884525_item	2338248	et	3	main
astaat	doc_345282884525_item	2338255	et	4	main
keelt	doc_345282884525_item	2338261	et	4	main
jaapani	doc_345282884525_item	2338263	et	4	main
keelt	doc_345282884525_item	2338264	et	4	main
ta	doc_345282884525_item	2338265	et	4	main
elab	doc_345282884525_item	2338266	et	3	main
tokyo	doc_345282884525_item	2338271	et	4	main
ja	doc_345282884525_item	2338279	et	3	main
linn	doc_345282884525_item	2338281	et	3	main
kesk	doc_345282884525_item	2338284	et	3	main
on	doc_345282884525_item	2338292	et	4	main
praegu	doc_345282884525_item	2338293	et	3	main
yokozuna	doc_345282884525_item	2338294	et	4	main
sumo	doc_345282884525_item	2338296	et	4	main
keelt	doc_345282884525_item	2338310	et	4	main
tallinn	doc_346862720676_item	2338325	et	4	main
võru	doc_346862720676_item	2338330	et	4	main
omasid	doc_346862720676_item	2338334	et	4	main
lübecki	doc_346862720676_item	2338335	et	4	main
õigust	doc_346862720676_item	2338336	et	4	main
tallinn	doc_346862720676_item	2338337	et	4	main
ühingus	doc_346862720676_item	2338343	et	3	main
eestimaale	doc_346862720676_item	2338350	et	4	main
toodi	doc_346862720676_item	2338351	et	4	main
vürtse	doc_346862720676_item	2338353	et	3	main
linnas	doc_346862720676_item	2338364	et	4	main
kirikud	doc_346862720676_item	2338366	et	3	main
kaitsemüürid	doc_346862720676_item	2338369	et	3	main
täitsid	doc_346862720676_item	2338381	et	4	main
olid	doc_346862720676_item	2338384	et	4	main
hariduskeskused	doc_346862720676_item	2338386	et	3	main
juures	doc_346862720676_item	2338388	et	4	main
toomekirikute	doc_346862720676_item	2338397	et	4	main
korraga	doc_346862720676_item	2338411	et	4	main
linnas	doc_346862720676_item	2338426	et	4	main
levinud	doc_346862720676_item	2338427	et	4	main
töö	doc_346862720676_item	2338443	et	4	main
oli	doc_346862720676_item	2338445	et	3	main
käsitöölistel	doc_346862720676_item	2338447	et	4	main
olid	doc_346862720676_item	2338448	et	4	main
see	doc_346862720676_item	2338455	et	3	main
kõige	doc_346862720676_item	2338463	et	4	main
olid	doc_346862720676_item	2338466	et	4	main
keraamika	doc_346862720676_item	2338467	et	4	main
ehtevalmistamine	doc_346862720676_item	2338470	et	3	main
käes	doc_346862720676_item	2338478	et	4	main
oli	doc_346862720676_item	2338480	et	3	main
isegi	doc_346862720676_item	2338481	et	4	main
tänav	doc_346862720676_item	2338482	et	4	main
kus	doc_346862720676_item	2338483	et	3	main
oli	doc_346862720676_item	2338488	et	3	main
eestimaa	doc_346862720676_item	2338493	et	4	main
venemaalt	doc_346862720676_item	2338500	et	3	main
aga	doc_346862720676_item	2338504	et	3	main
sisse	doc_346862720676_item	2338505	et	4	main
soola	doc_346862720676_item	2338507	et	4	main
tubakat	doc_346862720676_item	2338508	et	3	main
kõige	doc_346862720676_item	2338513	et	4	main
tähtsamas	doc_346862720676_item	2338514	et	4	main
nimed	doc_346862720676_item	2338515	et	3	main
oli	doc_346862720676_item	2338525	et	3	main
sest	doc_344825459481_item	2338208	et	4	main
see	doc_344825459481_item	2338213	et	3	main
astusime	doc_344825459481_item	2338217	et	3	main
et	doc_344825459481_item	2338223	et	3	main
keel	doc_344825459481_item	2338228	et	4	main
jaapanis	doc_345282884525_item	2338250	et	4	main
vana	doc_345282884525_item	2338256	et	4	main
räägib	doc_345282884525_item	2338258	et	3	main
hästi	doc_345282884525_item	2338259	et	3	main
tokyos	doc_345282884525_item	2338270	et	4	main
pealinn	doc_345282884525_item	2338274	et	3	main
tokyo	doc_345282884525_item	2338275	et	4	main
asub	doc_345282884525_item	2338283	et	3	main
tšempion	doc_345282884525_item	2338295	et	2	main
berliinis	doc_345282884525_item	2338305	et	4	main
1	doc_346862720676_item	2338312	et	2	main
keskaegne	doc_346862720676_item	2338313	et	3	main
eestimaal	doc_346862720676_item	2338321	et	4	main
tartu	doc_346862720676_item	2338326	et	4	main
pärnu	doc_346862720676_item	2338329	et	4	main
paldiski	doc_346862720676_item	2338331	et	4	main
need	doc_346862720676_item	2338332	et	3	main
viljandi	doc_346862720676_item	2338339	et	4	main
tegelesid	doc_346862720676_item	2338348	et	4	main
kaubandusega	doc_346862720676_item	2338349	et	3	main
aga	doc_346862720676_item	2338356	et	3	main
viidi	doc_346862720676_item	2338358	et	4	main
terist	doc_346862720676_item	2338359	et	3	main
tähtsamad	doc_346862720676_item	2338361	et	4	main
ehitised	doc_346862720676_item	2338362	et	3	main
kes	doc_346862720676_item	2338374	et	4	main
kord	doc_346862720676_item	2338380	et	4	main
koolid	doc_346862720676_item	2338391	et	3	main
haridust	doc_346862720676_item	2338394	et	4	main
elasid	doc_346862720676_item	2338399	et	4	main
uhkemaid	doc_346862720676_item	2338422	et	4	main
messe	doc_346862720676_item	2338423	et	3	main
laiali	doc_346862720676_item	2338429	et	3	main
olid	doc_346862720676_item	2338431	et	4	main
siiski	doc_346862720676_item	2338438	et	4	main
kvaliteet	doc_346862720676_item	2338444	et	3	main
tähtsamad	doc_346862720676_item	2338464	et	4	main
käsitöölised	doc_346862720676_item	2338465	et	3	main
relvavalmistamine	doc_346862720676_item	2338469	et	3	main
pärast	doc_346862720676_item	2338471	et	4	main
muud	doc_346862720676_item	2338473	et	4	main
kaubandus	doc_346862720676_item	2338474	et	3	main
oli	doc_346862720676_item	2338475	et	3	main
elasid	doc_346862720676_item	2338484	et	4	main
euroopa	doc_346862720676_item	2338496	et	4	main
ja	doc_346862720676_item	2338497	et	3	main
venemaa	doc_346862720676_item	2338498	et	4	main
toodi	doc_346862720676_item	2338506	et	4	main
ja	doc_346862720676_item	2338509	et	3	main
ne	doc_346862720676_item	2338510	et	4	main
kunstis	doc_346862720676_item	2338511	et	3	main
notke	doc_346862720676_item	2338517	et	4	main
tuleb	doc_344825459481_item	2338224	et	3	main
eesti	doc_344825459481_item	2338227	et	4	main
on	doc_345282884525_item	2338236	et	4	main
eestlane	doc_345282884525_item	2338237	et	3	main
ta	doc_345282884525_item	2338238	et	4	main
on	doc_345282884525_item	2338243	et	4	main
sumo	doc_345282884525_item	2338245	et	4	main
kolm	doc_345282884525_item	2338254	et	3	main
jaapani	doc_345282884525_item	2338273	et	4	main
on	doc_345282884525_item	2338276	et	4	main
vaga	doc_345282884525_item	2338277	et	4	main
suur	doc_345282884525_item	2338278	et	3	main
tokyo	doc_345282884525_item	2338282	et	4	main
japaanamaal	doc_345282884525_item	2338285	et	4	main
on	doc_345282884525_item	2338287	et	4	main
ema	doc_345282884525_item	2338302	et	4	main
praegu	doc_345282884525_item	2338303	et	3	main
elab	doc_345282884525_item	2338304	et	3	main
ema	doc_345282884525_item	2338306	et	4	main
baruto	doc_345282884525_item	2338307	et	4	main
linnakultuur	doc_346862720676_item	2338314	et	3	main
2	doc_346862720676_item	2338315	et	2	main
mida	doc_346862720676_item	2338316	et	4	main
tähendab	doc_346862720676_item	2338317	et	3	main
pärisorjus	doc_346862720676_item	2338318	et	3	main
1	doc_346862720676_item	2338319	et	2	main
keskajal	doc_346862720676_item	2338320	et	3	main
narva	doc_346862720676_item	2338327	et	4	main
tartu	doc_346862720676_item	2338338	et	4	main
soola	doc_346862720676_item	2338354	et	4	main
olid	doc_346862720676_item	2338365	et	4	main
pidasid	doc_346862720676_item	2338371	et	4	main
raehärrad	doc_346862720676_item	2338373	et	3	main
tegelesid	doc_346862720676_item	2338375	et	4	main
linnaga	doc_346862720676_item	2338376	et	3	main
seotud	doc_346862720676_item	2338377	et	4	main
kohtufunktisoone	doc_346862720676_item	2338382	et	4	main
kirikud	doc_346862720676_item	2338383	et	3	main
mis	doc_346862720676_item	2338392	et	4	main
oli	doc_346862720676_item	2338425	et	3	main
saksa	doc_345282884525_item	2338309	et	4	main
olid	doc_346862720676_item	2338322	et	4	main
linnad	doc_346862720676_item	2338324	et	3	main
linnad	doc_346862720676_item	2338333	et	3	main
pärnu	doc_346862720676_item	2338340	et	4	main
hansa	doc_346862720676_item	2338342	et	4	main
kes	doc_346862720676_item	2338347	et	4	main
heeringat	doc_346862720676_item	2338355	et	3	main
keskaegses	doc_346862720676_item	2338363	et	3	main
ja	doc_346862720676_item	2338368	et	3	main
küsimustega	doc_346862720676_item	2338378	et	4	main
esimesed	doc_346862720676_item	2338390	et	3	main
juures	doc_346862720676_item	2338398	et	4	main
toomehärrad	doc_346862720676_item	2338400	et	3	main
vaimulikud	doc_346862720676_item	2338401	et	3	main
kes	doc_346862720676_item	2338402	et	4	main
kuulusid	doc_346862720676_item	2338403	et	4	main
kapiituli	doc_346862720676_item	2338404	et	4	main
nad	doc_346862720676_item	2338405	et	3	main
võisid	doc_346862720676_item	2338406	et	4	main
olla	doc_346862720676_item	2338407	et	3	main
toomehäärana	doc_346862720676_item	2338408	et	4	main
mitmes	doc_346862720676_item	2338409	et	4	main
toomekirikus	doc_346862720676_item	2338410	et	3	main
toomekirikute	doc_346862720676_item	2338412	et	4	main
erinevus	doc_346862720676_item	2338413	et	4	main
oli	doc_346862720676_item	2338414	et	3	main
selles	doc_346862720676_item	2338415	et	4	main
et	doc_346862720676_item	2338416	et	3	main
siin	doc_346862720676_item	2338417	et	4	main
elasid	doc_346862720676_item	2338418	et	4	main
kõrgemad	doc_346862720676_item	2338419	et	4	main
vaimulikud	doc_346862720676_item	2338420	et	3	main
käsitöö	doc_346862720676_item	2338424	et	4	main
sakslased	doc_346862720676_item	2338439	et	3	main
oma	doc_346862720676_item	2338449	et	4	main
ühingud	doc_346862720676_item	2338450	et	3	main
meistriks	doc_346862720676_item	2338451	et	3	main
võiks	doc_346862720676_item	2338452	et	4	main
õppepoisid	doc_346862720676_item	2338461	et	4	main
naine	doc_346862720676_item	2338462	et	3	main
täuslikult	doc_346862720676_item	2338476	et	4	main
tallinnas	doc_346862720676_item	2338479	et	4	main
eestimaa	doc_346862720676_item	2338487	et	4	main
läbi	doc_346862720676_item	2338492	et	4	main
toimus	doc_346862720676_item	2338494	et	3	main
kauplemine	doc_346862720676_item	2338495	et	4	main
viidi	doc_346862720676_item	2338501	et	4	main
pernkt	doc_346862720676_item	2338516	et	4	main
notke	doc_346862720676_item	2338524	et	4	main
altareid	doc_346862720676_item	2338533	et	3	main
baltasar	doc_346862720676_item	2338534	et	4	main
kroonikakirjanik	doc_346862720676_item	2338538	et	3	main
pärisorjus	doc_346862720676_item	2338566	et	3	main
maksma	doc_346862720676_item	2338575	et	3	main
kümnendik	doc_346862720676_item	2338577	et	3	main
osa	doc_346862720676_item	2338581	et	4	main
maa	doc_346862720676_item	2338591	et	4	main
kuulusid	doc_346862720676_item	2338594	et	4	main
kontrolltöö	doc_346862720677_item	2338599	et	4	main
mõjud	doc_346862720677_item	2338602	et	4	main
ühiskonnakorraldusele	doc_346862720677_item	2338604	et	3	main
hästi	doc_346862720676_item	2338428	et	3	main
tallinnas	doc_346862720676_item	2338430	et	4	main
oma	doc_346862720676_item	2338432	et	4	main
meistrid	doc_346862720676_item	2338433	et	3	main
aga	doc_346862720676_item	2338434	et	3	main
peenemaid	doc_346862720676_item	2338435	et	4	main
tegid	doc_346862720676_item	2338437	et	4	main
sest	doc_346862720676_item	2338440	et	4	main
kohalikude	doc_346862720676_item	2338441	et	3	main
saada	doc_346862720676_item	2338453	et	4	main
ainult	doc_346862720676_item	2338454	et	4	main
käsitööline	doc_346862720676_item	2338456	et	4	main
kellel	doc_346862720676_item	2338457	et	4	main
oli	doc_346862720676_item	2338458	et	3	main
paras	doc_346862720676_item	2338459	et	3	main
varandus	doc_346862720676_item	2338460	et	3	main
valmistamine	doc_346862720676_item	2338468	et	4	main
kõik	doc_346862720676_item	2338472	et	4	main
kaupmehed	doc_346862720676_item	2338485	et	3	main
väga	doc_346862720676_item	2338489	et	3	main
geograafiaasetuses	doc_346862720676_item	2338491	et	4	main
välja	doc_346862720676_item	2338502	et	4	main
olid	doc_346862720676_item	2338512	et	4	main
russov	doc_346862720676_item	2338519	et	4	main
koel	doc_346862720676_item	2338520	et	3	main
ja	doc_346862720676_item	2338521	et	3	main
benkt	doc_346862720676_item	2338523	et	4	main
tuntud	doc_346862720676_item	2338526	et	4	main
ta	doc_346862720676_item	2338530	et	4	main
oli	doc_346862720676_item	2338537	et	3	main
juures	doc_346862720676_item	2338540	et	4	main
baltimaad	doc_346862720676_item	2338544	et	4	main
javandrat	doc_346862720676_item	2338548	et	4	main
tuntud	doc_346862720676_item	2338550	et	4	main
ja	doc_346862720676_item	2338560	et	3	main
vandrati	doc_346862720676_item	2338561	et	4	main
pidid	doc_346862720676_item	2338574	et	4	main
makse	doc_346862720676_item	2338576	et	4	main
tootedega	doc_346862720676_item	2338579	et	4	main
elukohavahetamine	doc_346862720676_item	2338589	et	3	main
elamu	doc_346862720676_item	2338593	et	4	main
tööriistad	doc_346862720676_item	2338596	et	3	main
talupojale	doc_346862720676_item	2338598	et	4	main
ristiusustamise	doc_346862720677_item	2338601	et	3	main
sajandils	doc_346862720677_item	2338606	et	4	main
riigiks	doc_346862720677_item	2338616	et	3	main
kogus	doc_346862720677_item	2338620	et	4	main
ka	doc_346862720677_item	2338626	et	3	main
inimese	doc_346862720677_item	2338639	et	4	main
martin	doc_346862720677_item	2338651	et	4	main
oma	doc_346862720677_item	2338654	et	4	main
sellest	doc_346862720677_item	2338660	et	4	main
kirikusüsteemi	doc_346862720677_item	2338664	et	4	main
muutma	doc_346862720677_item	2338666	et	3	main
tavad	doc_346862720677_item	2338681	et	3	main
17	doc_346862720677_item	2338686	et	2	main
võeti	doc_346862720677_item	2338724	et	3	main
ka	doc_346862720677_item	2338726	et	3	main
11-aastatastele	doc_346862720677_item	2338732	et	4	main
hakati	doc_346862720677_item	2338734	et	3	main
elementaarselt	doc_346862720677_item	2338736	et	4	main
käsku	doc_346862720677_item	2338743	et	4	main
näiteks	doc_346862720677_item	2338753	et	4	main
kui	doc_346862720677_item	2338754	et	3	main
sündis	doc_346862720677_item	2338755	et	3	main
kes	doc_346862720677_item	2338757	et	4	main
suure	doc_346862720677_item	2338758	et	3	main
suri	doc_346862720677_item	2338761	et	3	main
tööd	doc_346862720677_item	2338776	et	4	main
ja	doc_346862720677_item	2338822	et	3	main
kabelid	doc_346862720677_item	2338823	et	3	main
peakirik	doc_346862720677_item	2338821	et	3	main
selline	doc_346862720677_item	2338824	et	4	main
ka	doc_346862720677_item	2338830	et	3	main
kõige	doc_346862720677_item	2338835	et	4	main
tartu	doc_346862720677_item	2338839	et	4	main
hakkasid	doc_346862720677_item	2338841	et	4	main
hansaliitu	doc_346862720677_item	2338843	et	4	main
tähendas	doc_346862720677_item	2338845	et	3	main
vandrat	doc_346862720676_item	2338522	et	4	main
surmatantsu	doc_346862720676_item	2338528	et	4	main
russov	doc_346862720676_item	2338535	et	4	main
periodil	doc_346862720676_item	2338545	et	4	main
1573	doc_346862720676_item	2338546	et	2	main
oma	doc_346862720676_item	2338527	et	4	main
kaudu	doc_346862720676_item	2338529	et	3	main
kaunistas	doc_346862720676_item	2338531	et	3	main
tema	doc_346862720676_item	2338541	et	4	main
tööd	doc_346862720676_item	2338542	et	4	main
vaadeldavad	doc_346862720676_item	2338543	et	4	main
järgi	doc_346862720676_item	2338552	et	4	main
esimene	doc_346862720676_item	2338553	et	3	main
raamat	doc_346862720676_item	2338554	et	3	main
ilmus	doc_346862720676_item	2338555	et	4	main
1525	doc_346862720676_item	2338556	et	2	main
aastal	doc_346862720676_item	2338557	et	3	main
saksamaal	doc_346862720676_item	2338558	et	4	main
koeli	doc_346862720676_item	2338559	et	4	main
olid	doc_346862720676_item	2338568	et	4	main
täiesti	doc_346862720676_item	2338569	et	3	main
sõltuvad	doc_346862720676_item	2338570	et	4	main
oma	doc_346862720676_item	2338571	et	4	main
mõisnikustelt	doc_346862720676_item	2338572	et	4	main
oma	doc_346862720676_item	2338578	et	4	main
pärast	doc_346862720676_item	2338580	et	4	main
talupoja	doc_346862720676_item	2338590	et	4	main
mõisnikule	doc_346862720676_item	2338595	et	3	main
kuulusid	doc_346862720676_item	2338597	et	4	main
eesti	doc_346862720677_item	2338603	et	4	main
1316	doc_346862720677_item	2338605	et	2	main
2	doc_346862720677_item	2338607	et	2	main
2	doc_346862720677_item	2338611	et	2	main
reformatsioon	doc_346862720677_item	2338612	et	3	main
riigis	doc_346862720677_item	2338617	et	3	main
ilmalikustunud	doc_346862720677_item	2338619	et	4	main
rohkem	doc_346862720677_item	2338635	et	4	main
tähelepanu	doc_346862720677_item	2338636	et	4	main
rikastumisele	doc_346862720677_item	2338637	et	4	main
oli	doc_346862720677_item	2338642	et	3	main
seda	doc_346862720677_item	2338648	et	3	main
muuta	doc_346862720677_item	2338650	et	4	main
kiriku	doc_346862720677_item	2338657	et	3	main
ning	doc_346862720677_item	2338659	et	3	main
alguse	doc_346862720677_item	2338663	et	3	main
katoliku	doc_346862720677_item	2338668	et	3	main
isegi	doc_346862720677_item	2338685	et	4	main
üle	doc_346862720677_item	2338725	et	3	main
uskumused	doc_346862720677_item	2338730	et	3	main
lapsetele	doc_346862720677_item	2338733	et	3	main
õpetama	doc_346862720677_item	2338735	et	3	main
meie	doc_346862720677_item	2338738	et	4	main
isa	doc_346862720677_item	2338739	et	4	main
palvet	doc_346862720677_item	2338740	et	3	main
ja	doc_346862720677_item	2338741	et	3	main
sai	doc_346862720677_item	2338751	et	4	main
ristida	doc_346862720677_item	2338752	et	4	main
tõenäosusega	doc_346862720677_item	2338759	et	3	main
varsti	doc_346862720677_item	2338760	et	3	main
ristida	doc_346862720677_item	2338767	et	4	main
et	doc_346862720677_item	2338768	et	3	main
ühel	doc_346862720677_item	2338781	et	3	main
kus	doc_346862720677_item	2338818	et	3	main
koel	doc_346862720676_item	2338547	et	3	main
olid	doc_346862720676_item	2338549	et	4	main
katekismuse	doc_346862720676_item	2338551	et	3	main
katekismus	doc_346862720676_item	2338562	et	3	main
a	doc_346862720676_item	2338564	et	4	main
talupojad	doc_346862720676_item	2338567	et	4	main
nad	doc_346862720676_item	2338573	et	3	main
tegema	doc_346862720676_item	2338583	et	3	main
talus	doc_346862720676_item	2338585	et	4	main
neil	doc_346862720676_item	2338586	et	4	main
oli	doc_346862720676_item	2338587	et	3	main
1	doc_346862720677_item	2338600	et	2	main
oli	doc_346862720677_item	2338614	et	3	main
oli	doc_346862720677_item	2338618	et	3	main
tööd	doc_346862720676_item	2338584	et	4	main
keelatud	doc_346862720676_item	2338588	et	4	main
ja	doc_346862720676_item	2338592	et	3	main
muutunud	doc_346862720677_item	2338615	et	4	main
makse	doc_346862720677_item	2338621	et	4	main
õige	doc_346862720677_item	2338631	et	4	main
jumal	doc_346862720677_item	2338641	et	3	main
muutunud	doc_346862720677_item	2338643	et	4	main
ja	doc_346862720677_item	2338645	et	3	main
ning	doc_346862720677_item	2338647	et	3	main
luther	doc_346862720677_item	2338652	et	4	main
reformatsioon	doc_346862720677_item	2338662	et	3	main
hakati	doc_346862720677_item	2338665	et	3	main
tegi	doc_346862720677_item	2338670	et	4	main
talupoegadest	doc_346862720677_item	2338671	et	3	main
kogukondlased	doc_346862720677_item	2338674	et	3	main
aga	doc_346862720677_item	2338676	et	3	main
säilisid	doc_346862720677_item	2338684	et	4	main
sajandini	doc_346862720677_item	2338688	et	3	main
usk	doc_346862720677_item	2338722	et	3	main
tavad	doc_346862720677_item	2338728	et	3	main
igas	doc_346862720677_item	2338744	et	3	main
talupoeg	doc_346862720677_item	2338749	et	3	main
õpetatud	doc_346862720677_item	2338764	et	4	main
talupoeg	doc_346862720677_item	2338765	et	3	main
ta	doc_346862720677_item	2338766	et	4	main
tõlkida	doc_346862720677_item	2338779	et	3	main
oli	doc_346862720677_item	2338819	et	3	main
mida	doc_346862720677_item	2338608	et	4	main
tähendab	doc_346862720677_item	2338609	et	3	main
reformatsioon	doc_346862720677_item	2338610	et	3	main
kirik	doc_346862720677_item	2338613	et	3	main
martin	doc_346862720677_item	2338624	et	4	main
teiste	doc_346862720677_item	2338627	et	4	main
polnud	doc_346862720677_item	2338629	et	3	main
hingeelule	doc_346862720677_item	2338640	et	3	main
kurjaks	doc_346862720677_item	2338644	et	4	main
julmaks	doc_346862720677_item	2338646	et	3	main
tuli	doc_346862720677_item	2338649	et	4	main
naelutas	doc_346862720677_item	2338653	et	3	main
teesi	doc_346862720677_item	2338656	et	4	main
uksele	doc_346862720677_item	2338658	et	3	main
1	doc_346862720677_item	2338667	et	2	main
oma	doc_346862720677_item	2338673	et	4	main
säilitasid	doc_346862720677_item	2338677	et	4	main
oma	doc_346862720677_item	2338678	et	4	main
kombed	doc_346862720677_item	2338679	et	3	main
ja	doc_346862720677_item	2338680	et	3	main
osad	doc_346862720677_item	2338682	et	3	main
ja	doc_346862720677_item	2338622	et	3	main
valitses	doc_346862720677_item	2338623	et	3	main
lutheri	doc_346862720677_item	2338625	et	4	main
meelest	doc_346862720677_item	2338628	et	4	main
see	doc_346862720677_item	2338630	et	3	main
et	doc_346862720677_item	2338632	et	3	main
kirik	doc_346862720677_item	2338633	et	3	main
pööras	doc_346862720677_item	2338634	et	4	main
kui	doc_346862720677_item	2338638	et	3	main
10	doc_346862720677_item	2338655	et	2	main
sai	doc_346862720677_item	2338661	et	4	main
kirik	doc_346862720677_item	2338669	et	3	main
sunniviisiliselt	doc_346862720677_item	2338672	et	4	main
eestlased	doc_346862720677_item	2338675	et	3	main
neist	doc_346862720677_item	2338683	et	4	main
18	doc_346862720677_item	2338687	et	2	main
eestlased	doc_346862720677_item	2338689	et	3	main
omandasid	doc_346862720677_item	2338690	et	4	main
katoliku	doc_346862720677_item	2338691	et	3	main
kiriku	doc_346862720677_item	2338692	et	3	main
välised	doc_346862720677_item	2338693	et	4	main
kombed	doc_346862720677_item	2338694	et	3	main
kirikuskäimine	doc_346862720677_item	2338695	et	4	main
pühakute	doc_346862720677_item	2338696	et	3	main
säilmete	doc_346862720677_item	2338697	et	3	main
austamine	doc_346862720677_item	2338698	et	4	main
talupoegadele	doc_346862720677_item	2338700	et	3	main
reliikvia	doc_346862720677_item	2338699	et	4	main
meeldis	doc_346862720677_item	2338701	et	3	main
ka	doc_346862720677_item	2338702	et	3	main
pühitsemine	doc_346862720677_item	2338703	et	4	main
ja	doc_346862720677_item	2338704	et	3	main
õnnistamine	doc_346862720677_item	2338705	et	4	main
pühakute	doc_346862720677_item	2338706	et	3	main
austamise	doc_346862720677_item	2338707	et	4	main
vastu	doc_346862720677_item	2338708	et	3	main
polnud	doc_346862720677_item	2338709	et	3	main
neil	doc_346862720677_item	2338710	et	4	main
midagi	doc_346862720677_item	2338711	et	4	main
eestlaste	doc_346862720677_item	2338712	et	4	main
usundit	doc_346862720677_item	2338713	et	3	main
hakati	doc_346862720677_item	2338714	et	3	main
nimetama	doc_346862720677_item	2338715	et	3	main
n-ö	doc_346862720677_item	2338716	et	4	main
külakatoliikluseks	doc_346862720677_item	2338717	et	4	main
kuna	doc_346862720677_item	2338718	et	3	main
säilitati	doc_346862720677_item	2338719	et	3	main
osalt	doc_346862720677_item	2338720	et	4	main
ja	doc_346862720677_item	2338723	et	3	main
katoliiklikud	doc_346862720677_item	2338727	et	3	main
kombed	doc_346862720677_item	2338729	et	3	main
piiblit	doc_346862720677_item	2338737	et	3	main
õpetati	doc_346862720677_item	2338746	et	3	main
üks	doc_346862720677_item	2338748	et	3	main
kirikute	doc_346862720677_item	2338777	et	4	main
territooriumil	doc_346862720677_item	2338782	et	3	main
kihelkonnas	doc_346862720677_item	2338783	et	3	main
kujunesid	doc_346862720677_item	2338784	et	4	main
välja	doc_346862720677_item	2338785	et	4	main
oma	doc_346862720677_item	2338786	et	4	main
keelemurre	doc_346862720677_item	2338787	et	4	main
rahvariided	doc_346862720677_item	2338788	et	3	main
folkloor	doc_346862720677_item	2338789	et	4	main
selline	doc_346862720677_item	2338790	et	4	main
olukord	doc_346862720677_item	2338791	et	3	main
jäi	doc_346862720677_item	2338792	et	3	main
püsima	doc_346862720677_item	2338793	et	3	main
19	doc_346862720677_item	2338794	et	2	main
saj	doc_346862720677_item	2338795	et	4	main
pooleni	doc_346862720677_item	2338797	et	3	main
15	doc_346862720677_item	2338798	et	2	main
teise	doc_346862720677_item	2338796	et	4	main
saj	doc_346862720677_item	2338799	et	4	main
hakkasid	doc_346862720677_item	2338800	et	4	main
rändmungad	doc_346862720677_item	2338801	et	3	main
beginid	doc_346862720677_item	2338802	et	4	main
rajama	doc_346862720677_item	2338803	et	3	main
esimesi	doc_346862720677_item	2338804	et	4	main
avalikku	doc_346862720677_item	2338805	et	4	main
1434	doc_346862720677_item	2338807	et	2	main
haiglaid	doc_346862720677_item	2338806	et	3	main
avati	doc_346862720677_item	2338808	et	3	main
kiriku	doc_346862720677_item	2338810	et	3	main
oleviste	doc_346862720677_item	2338809	et	4	main
juures	doc_346862720677_item	2338811	et	4	main
esimene	doc_346862720677_item	2338812	et	3	main
kool	doc_346862720677_item	2338813	et	4	main
lihtrahvale	doc_346862720677_item	2338814	et	3	main
kirikukihelkonnad	doc_346862720677_item	2338816	et	3	main
territoorium	doc_346862720677_item	2338817	et	3	main
oma	doc_346862720677_item	2338721	et	4	main
umbes	doc_346862720677_item	2338731	et	4	main
kümmet	doc_346862720677_item	2338742	et	4	main
külas	doc_346862720677_item	2338745	et	3	main
välja	doc_346862720677_item	2338747	et	4	main
kes	doc_346862720677_item	2338750	et	4	main
laps	doc_346862720677_item	2338756	et	4	main
võis	doc_346862720677_item	2338762	et	4	main
too	doc_346862720677_item	2338763	et	4	main
last	doc_346862720677_item	2338769	et	4	main
saaks	doc_346862720677_item	2338770	et	3	main
kristlikult	doc_346862720677_item	2338771	et	4	main
matta	doc_346862720677_item	2338772	et	3	main
mitmed	doc_346862720677_item	2338773	et	4	main
eestlased	doc_346862720677_item	2338774	et	3	main
said	doc_346862720677_item	2338775	et	4	main
juures	doc_346862720677_item	2338778	et	4	main
rängmunbadena	doc_346862720677_item	2338780	et	4	main
loodi	doc_346862720677_item	2338815	et	4	main
üks	doc_346862720677_item	2338820	et	3	main
jaotus	doc_346862720677_item	2338825	et	4	main
jäi	doc_346862720677_item	2338826	et	3	main
ajaks	doc_346862720677_item	2338829	et	4	main
maakondadena	doc_346862720677_item	2338831	et	3	main
kerkisid	doc_346862720677_item	2338833	et	4	main
linnad	doc_346862720677_item	2338834	et	3	main
ja	doc_346862720677_item	2338838	et	3	main
kuuluma	doc_346862720677_item	2338842	et	3	main
teistes	doc_346862720677_item	2338849	et	4	main
riikides	doc_346862720677_item	2338850	et	3	main
toodi	doc_346862720677_item	2338851	et	4	main
ja	doc_346862720677_item	2338854	et	3	main
tunnustust	doc_346862720677_item	2338860	et	4	main
leidnud	doc_346862720677_item	2338861	et	4	main
hansa	doc_346862720677_item	2338863	et	4	main
tartu	doc_346862720677_item	2338867	et	4	main
viljandi	doc_346862720677_item	2338868	et	4	main
feodaalkord	doc_346862720677_item	2338872	et	4	main
harjutud	doc_346862720677_item	2338875	et	4	main
vormiga	doc_346862720677_item	2338877	et	4	main
kirjakunsti	doc_346862720677_item	2338878	et	4	main
ei	doc_346862720677_item	2338882	et	4	main
käigus	doc_346862720677_item	2338885	et	4	main
tutvusid	doc_346862720677_item	2338886	et	4	main
siinsed	doc_346862720677_item	2338887	et	3	main
lähemalt	doc_346862720677_item	2338890	et	4	main
varem	doc_346862720677_item	2338891	et	4	main
või	doc_346862720677_item	2338895	et	4	main
kaasnes	doc_346862720677_item	2338899	et	3	main
teke	doc_346862720677_item	2338901	et	3	main
levik	doc_346862720677_item	2338904	et	3	main
käigus	doc_346862720677_item	2338912	et	4	main
aastal	doc_346862720677_item	2338917	et	3	main
kõigilt	doc_346862720677_item	2338920	et	4	main
sissetulekutelt	doc_346862720677_item	2338921	et	3	main
üldisemalt	doc_346862720677_item	2338928	et	4	main
läks	doc_346862720677_item	2338929	et	3	main
polnud	doc_346862720677_item	2338935	et	3	main
talupojal	doc_346862720677_item	2338937	et	4	main
ühiskonnaelu	doc_346862720677_item	2338938	et	4	main
läks	doc_346862720677_item	2338948	et	3	main
talupojad	doc_346862720677_item	2338954	et	4	main
ja	doc_346862720677_item	2338959	et	3	main
pidamist	doc_346862720677_item	2338962	et	4	main
mitte	doc_346862720677_item	2338965	et	3	main
pidama	doc_346862720677_item	2338975	et	4	main
kuidas	doc_346862720677_item	2338988	et	3	main
vaatamata	doc_346862720677_item	2339002	et	4	main
suhteliselt	doc_346862720677_item	2339004	et	4	main
hästi	doc_346862720677_item	2339005	et	3	main
mis	doc_346862720677_item	2339008	et	4	main
püsima	doc_346862720677_item	2338827	et	3	main
pikaks	doc_346862720677_item	2338828	et	4	main
tallinn	doc_346862720677_item	2338837	et	4	main
pealt	doc_346862720677_item	2338836	et	4	main
see	doc_346862720677_item	2338844	et	3	main
kauplemist	doc_346862720677_item	2338846	et	4	main
linnadega	doc_346862720677_item	2338848	et	3	main
peamiselt	doc_346862720677_item	2338852	et	4	main
viidi	doc_346862720677_item	2338855	et	4	main
igal	doc_346862720677_item	2338857	et	3	main
rukist	doc_346862720677_item	2338862	et	3	main
liitu	doc_346862720677_item	2338864	et	4	main
ja	doc_346862720677_item	2338869	et	3	main
pärnu	doc_346862720677_item	2338870	et	4	main
kehtestati	doc_346862720677_item	2338871	et	3	main
oldi	doc_346862720677_item	2338874	et	3	main
siin	doc_346862720677_item	2338879	et	4	main
palju	doc_346862720677_item	2338881	et	4	main
tuntud	doc_346862720677_item	2338883	et	4	main
ristiusustamise	doc_346862720677_item	2338884	et	3	main
inimesed	doc_346862720677_item	2338888	et	3	main
sellega	doc_346862720677_item	2338889	et	3	main
sageli	doc_346862720677_item	2338893	et	3	main
hajakülad	doc_346862720677_item	2338897	et	3	main
linnade	doc_346862720677_item	2338900	et	3	main
ehk	doc_346862720677_item	2338902	et	3	main
olid	doc_346862720677_item	2338906	et	4	main
iseenda	doc_346862720677_item	2338907	et	3	main
peremehed	doc_346862720677_item	2338908	et	3	main
varem	doc_346862720677_item	2338909	et	4	main
ristiusustamise	doc_346862720677_item	2338911	et	3	main
talupoegadelt	doc_346862720677_item	2338914	et	3	main
nõudma	doc_346862720677_item	2338915	et	3	main
tuli	doc_346862720677_item	2338922	et	4	main
ja	doc_346862720677_item	2338926	et	3	main
kätte	doc_346862720677_item	2338931	et	4	main
alates	doc_346862720677_item	2338932	et	3	main
matsil	doc_346862720677_item	2338936	et	4	main
sakste	doc_346862720677_item	2338949	et	3	main
talupoegadelt	doc_346862720677_item	2338955	et	3	main
nõuti	doc_346862720677_item	2338956	et	3	main
kiriklikku	doc_346862720677_item	2338957	et	4	main
ühe	doc_346862720677_item	2338960	et	4	main
surnute	doc_346862720677_item	2338963	et	4	main
matmist	doc_346862720677_item	2338964	et	4	main
põletamist	doc_346862720677_item	2338966	et	4	main
laste	doc_346862720677_item	2338967	et	4	main
uued	doc_346862720677_item	2338976	et	3	main
teostas	doc_346862720677_item	2338985	et	3	main
ristiusu	doc_346862720677_item	2338990	et	3	main
täitsid	doc_346862720677_item	2338992	et	4	main
tulemas	doc_346862720677_item	2339009	et	4	main
kontrolltöö	doc_346862720678_item	2339013	et	4	main
rahvusliku	doc_346862720678_item	2339019	et	3	main
tegelased	doc_346862720678_item	2339021	et	3	main
2	doc_346862720678_item	2339025	et	2	main
1730-1740	doc_346862720678_item	2339038	et	2	main
on	doc_346862720678_item	2339049	et	4	main
jumala	doc_346862720678_item	2339050	et	3	main
eestlastel	doc_346862720678_item	2339058	et	4	main
oskama	doc_346862720678_item	2339072	et	3	main
mis	doc_346862720677_item	2338840	et	4	main
enamasti	doc_346862720677_item	2338856	et	4	main
maailmas	doc_346862720677_item	2338859	et	3	main
kuulusid	doc_346862720677_item	2338865	et	4	main
tallinn	doc_346862720677_item	2338866	et	4	main
varem	doc_346862720677_item	2338873	et	4	main
sugukondliku	doc_346862720677_item	2338876	et	3	main
eestisse	doc_346862720677_item	2338832	et	4	main
teiste	doc_346862720677_item	2338847	et	4	main
soola	doc_346862720677_item	2338853	et	4	main
pool	doc_346862720677_item	2338858	et	4	main
varem	doc_346862720677_item	2338880	et	4	main
külad	doc_346862720677_item	2338892	et	3	main
ristiusustamisega	doc_346862720677_item	2338898	et	3	main
hakati	doc_346862720677_item	2338913	et	3	main
igal	doc_346862720677_item	2338916	et	3	main
110	doc_346862720677_item	2338919	et	2	main
anda	doc_346862720677_item	2338923	et	3	main
kaubandus	doc_346862720677_item	2338925	et	3	main
majandus	doc_346862720677_item	2338927	et	4	main
sakste	doc_346862720677_item	2338930	et	3	main
13	doc_346862720677_item	2338933	et	2	main
korraldamisesse	doc_346862720677_item	2338939	et	4	main
asja	doc_346862720677_item	2338940	et	4	main
ta	doc_346862720677_item	2338941	et	4	main
jäi	doc_346862720677_item	2338942	et	3	main
talurahvaks	doc_346862720677_item	2338943	et	3	main
sakste	doc_346862720677_item	2338944	et	3	main
sakste	doc_346862720677_item	2338945	et	3	main
tööriistaks	doc_346862720677_item	2338946	et	4	main
tegelesid	doc_346862720677_item	2338953	et	4	main
naise	doc_346862720677_item	2338961	et	3	main
ei	doc_346862720677_item	2338971	et	4	main
kinni	doc_346862720677_item	2338974	et	3	main
ja	doc_346862720677_item	2338978	et	3	main
omaks	doc_346862720677_item	2338981	et	4	main
mööda	doc_346862720677_item	2338983	et	4	main
kirik	doc_346862720677_item	2338984	et	3	main
kohalikud	doc_346862720677_item	2338989	et	3	main
nõudeid	doc_346862720677_item	2338991	et	3	main
mõistsid	doc_346862720677_item	2338995	et	4	main
linnavõimude	doc_346862720677_item	2338996	et	3	main
olid	doc_346862720677_item	2338998	et	4	main
kuid	doc_346862720677_item	2339000	et	4	main
sellele	doc_346862720677_item	2339001	et	4	main
sellega	doc_346862720677_item	2339007	et	3	main
pärisorjuslik	doc_346862720677_item	2339011	et	3	main
kord	doc_346862720677_item	2339012	et	4	main
olid	doc_346862720677_item	2338896	et	4	main
talupojad	doc_346862720677_item	2338905	et	4	main
puudusid	doc_346862720677_item	2338894	et	4	main
linnakultuuri	doc_346862720677_item	2338903	et	4	main
kuid	doc_346862720677_item	2338910	et	4	main
kümnist	doc_346862720677_item	2338918	et	3	main
kirikule	doc_346862720677_item	2338924	et	3	main
sal-st	doc_346862720677_item	2338934	et	3	main
käsitöö	doc_346862720677_item	2338947	et	4	main
kätte	doc_346862720677_item	2338950	et	4	main
samas	doc_346862720677_item	2338951	et	4	main
põllumajandusega	doc_346862720677_item	2338952	et	3	main
abielu	doc_346862720677_item	2338958	et	4	main
ristimist	doc_346862720677_item	2338968	et	4	main
neist	doc_346862720677_item	2338969	et	4	main
nõuetest	doc_346862720677_item	2338970	et	4	main
hakatud	doc_346862720677_item	2338972	et	4	main
kohe	doc_346862720677_item	2338973	et	4	main
kombed	doc_346862720677_item	2338977	et	3	main
harjumused	doc_346862720677_item	2338979	et	4	main
visitatsioone	doc_346862720677_item	2338986	et	3	main
ja	doc_346862720677_item	2338993	et	3	main
vahel	doc_346862720677_item	2338997	et	4	main
sõjad	doc_346862720677_item	2338999	et	3	main
võrreldes	doc_346862720677_item	2339006	et	3	main
1	doc_346862720678_item	2339014	et	2	main
ärkamisaja	doc_346862720678_item	2339020	et	3	main
sinu	doc_346862720678_item	2339022	et	3	main
edendamisse	doc_346862720678_item	2339031	et	4	main
nad	doc_346862720678_item	2339040	et	3	main
nn	doc_346862720678_item	2339042	et	4	main
nemad	doc_346862720678_item	2339044	et	3	main
olukorda	doc_346862720678_item	2339056	et	4	main
olnud	doc_346862720678_item	2339060	et	4	main
haritud	doc_346862720678_item	2339071	et	4	main
ümberjutustada	doc_346862720678_item	2339074	et	4	main
kirja	doc_346862720678_item	2339077	et	4	main
vennastekoguduse	doc_346862720678_item	2339082	et	3	main
liikumisele	doc_346862720678_item	2339083	et	4	main
kõige	doc_346862720678_item	2339088	et	4	main
impeeriumi	doc_346862720678_item	2339091	et	4	main
1	doc_346862720678_item	2339093	et	2	main
kõige	doc_346862720678_item	2339094	et	4	main
tähtsamad	doc_346862720678_item	2339095	et	4	main
esimese	doc_346862720678_item	2339096	et	3	main
rahvusliku	doc_346862720678_item	2339097	et	3	main
soove	doc_346862720678_item	2339107	et	3	main
sõnastada	doc_346862720678_item	2339110	et	3	main
neid	doc_346862720678_item	2339113	et	4	main
1857a	doc_346862720678_item	2339121	et	4	main
hakkas	doc_346862720678_item	2339122	et	3	main
rahvas	doc_346862720678_item	2339136	et	4	main
väärtustada	doc_346862720678_item	2339141	et	3	main
võitis	doc_346862720678_item	2339145	et	3	main
vastu	doc_346862720678_item	2339147	et	3	main
sai	doc_346862720678_item	2339149	et	4	main
populaarseks	doc_346862720678_item	2339150	et	4	main
tasemel	doc_346862720678_item	2339156	et	3	main
muusika	doc_346862720678_item	2339160	et	4	main
korraldas	doc_346862720678_item	2339162	et	3	main
hakkas	doc_346862720678_item	2339169	et	3	main
ringikesi	doc_346862720678_item	2339171	et	4	main
võrus	doc_346862720678_item	2339173	et	3	main
sellel	doc_346862720678_item	2339176	et	4	main
alal	doc_346862720678_item	2339177	et	4	main
kreutzwald	doc_346862720678_item	2339181	et	4	main
oli	doc_346862720678_item	2339184	et	3	main
tähtis	doc_346862720678_item	2339189	et	4	main
maalikunstnik	doc_346862720678_item	2339193	et	3	main
köler	doc_346862720678_item	2339195	et	4	main
kes	doc_346862720678_item	2339196	et	4	main
oli	doc_346862720678_item	2339197	et	3	main
eesotsas	doc_346862720678_item	2339201	et	4	main
õnnestunud	doc_346862720678_item	2339210	et	4	main
kõige	doc_346862720678_item	2339227	et	4	main
tagastamist	doc_346862720678_item	2339234	et	4	main
eesti	doc_346862720678_item	2339235	et	4	main
rahvale	doc_346862720678_item	2339236	et	3	main
c	doc_346862720678_item	2339237	et	4	main
r	doc_346862720678_item	2339238	et	4	main
kooliraamatute	doc_346862720678_item	2339243	et	3	main
kirjutistega	doc_346862720678_item	2339246	et	3	main
võeti	doc_346862720677_item	2338980	et	3	main
aega	doc_346862720677_item	2338982	et	4	main
kontrollis	doc_346862720677_item	2338987	et	4	main
usku	doc_346862720677_item	2338994	et	4	main
elati	doc_346862720677_item	2339003	et	3	main
kes	doc_346862720678_item	2339015	et	4	main
esimese	doc_346862720678_item	2339018	et	3	main
miks	doc_346862720678_item	2339024	et	4	main
liikumise	doc_346862720678_item	2339027	et	4	main
tegutses	doc_346862720678_item	2339035	et	3	main
eesti	doc_346862720678_item	2339036	et	4	main
territooriumil	doc_346862720678_item	2339037	et	3	main
ees	doc_346862720678_item	2339051	et	4	main
võrdsed	doc_346862720678_item	2339052	et	3	main
ja	doc_346862720678_item	2339053	et	3	main
kus	doc_346862720678_item	2339057	et	3	main
ei	doc_346862720678_item	2339059	et	4	main
peaaigu	doc_346862720678_item	2339061	et	4	main
mitte	doc_346862720678_item	2339062	et	3	main
mingeid	doc_346862720678_item	2339063	et	3	main
õigusi	doc_346862720678_item	2339064	et	4	main
oma	doc_346862720678_item	2339065	et	4	main
maal	doc_346862720678_item	2339066	et	4	main
oli	doc_346862720677_item	2339010	et	3	main
olid	doc_346862720678_item	2339016	et	4	main
tähtsamad	doc_346862720678_item	2339017	et	4	main
meelest	doc_346862720678_item	2339023	et	4	main
vennaskoguduse	doc_346862720678_item	2339026	et	3	main
panus	doc_346862720678_item	2339028	et	4	main
eestlaste	doc_346862720678_item	2339029	et	4	main
haridusalu	doc_346862720678_item	2339030	et	4	main
2	doc_346862720678_item	2339032	et	2	main
vennastekoguduse	doc_346862720678_item	2339033	et	3	main
liikumine	doc_346862720678_item	2339034	et	4	main
aastatel	doc_346862720678_item	2339039	et	4	main
olin	doc_346862720678_item	2339041	et	3	main
hernhuutlased	doc_346862720678_item	2339043	et	3	main
arvasid	doc_346862720678_item	2339045	et	4	main
et	doc_346862720678_item	2339046	et	3	main
kõik	doc_346862720678_item	2339047	et	4	main
inimesed	doc_346862720678_item	2339048	et	3	main
püüdsid	doc_346862720678_item	2339054	et	4	main
muuta	doc_346862720678_item	2339055	et	4	main
lugeda	doc_346862720678_item	2339073	et	3	main
lugu	doc_346862720678_item	2339076	et	4	main
laulda	doc_346862720678_item	2339079	et	4	main
tänu	doc_346862720678_item	2339081	et	4	main
olid	doc_346862720678_item	2339087	et	4	main
ärkamisaja	doc_346862720678_item	2339098	et	3	main
kes	doc_346862720678_item	2339104	et	4	main
püüdsid	doc_346862720678_item	2339105	et	4	main
rahva	doc_346862720678_item	2339106	et	3	main
ja	doc_346862720678_item	2339108	et	3	main
kes	doc_346862720678_item	2339120	et	4	main
esimeses	doc_346862720678_item	2339129	et	3	main
ajalehes	doc_346862720678_item	2339130	et	3	main
kirjutas	doc_346862720678_item	2339131	et	3	main
ta	doc_346862720678_item	2339132	et	4	main
tere	doc_346862720678_item	2339133	et	3	main
armas	doc_346862720678_item	2339134	et	3	main
eesti	doc_346862720678_item	2339135	et	4	main
ta	doc_346862720678_item	2339139	et	4	main
püüdis	doc_346862720678_item	2339140	et	3	main
ümberrahvastamise	doc_346862720678_item	2339146	et	3	main
ta	doc_346862720678_item	2339148	et	4	main
enda	doc_346862720678_item	2339155	et	4	main
orkestride	doc_346862720678_item	2339159	et	4	main
1869	doc_346862720678_item	2339165	et	2	main
kes	doc_346862720678_item	2339182	et	4	main
oli	doc_346862720678_item	2339191	et	3	main
j	doc_346862720678_item	2339194	et	4	main
grupi	doc_346862720678_item	2339200	et	3	main
ta	doc_346862720678_item	2339202	et	4	main
palvekirjade	doc_346862720678_item	2339205	et	3	main
akstsioonile	doc_346862720678_item	2339207	et	4	main
tuntuim	doc_346862720678_item	2339217	et	4	main
j	doc_346862720678_item	2339219	et	4	main
liikumise	doc_346862720678_item	2339223	et	4	main
liider	doc_346862720678_item	2339224	et	3	main
ja	doc_346862720678_item	2339225	et	3	main
pidas	doc_346862720678_item	2339226	et	3	main
olulisemaks	doc_346862720678_item	2339228	et	4	main
rahva	doc_346862720678_item	2339229	et	3	main
tuntud	doc_346862720678_item	2339241	et	4	main
oma	doc_346862720678_item	2339242	et	4	main
teravate	doc_346862720678_item	2339245	et	3	main
väga	doc_346862720678_item	2339247	et	3	main
koguduse	doc_346862720678_item	2339067	et	3	main
liige	doc_346862720678_item	2339068	et	4	main
pidi	doc_346862720678_item	2339069	et	4	main
olema	doc_346862720678_item	2339070	et	4	main
haritud	doc_346862720678_item	2339089	et	4	main
meelest	doc_346862720678_item	2339101	et	4	main
ja	doc_346862720678_item	2339111	et	3	main
jannsen	doc_346862720678_item	2339119	et	4	main
andma	doc_346862720678_item	2339124	et	3	main
ajalehte	doc_346862720678_item	2339125	et	4	main
oma	doc_346862720678_item	2339128	et	4	main
eesti	doc_346862720678_item	2339142	et	4	main
rahvust	doc_346862720678_item	2339143	et	3	main
ja	doc_346862720678_item	2339144	et	3	main
tema	doc_346862720678_item	2339154	et	4	main
kooride	doc_346862720678_item	2339158	et	3	main
i	doc_346862720678_item	2339163	et	4	main
dr	doc_346862720678_item	2339178	et	4	main
f	doc_346862720678_item	2339179	et	4	main
ja	doc_346862720678_item	2339192	et	3	main
aktsioon	doc_346862720678_item	2339208	et	3	main
ei	doc_346862720678_item	2339209	et	4	main
aga	doc_346862720678_item	2339211	et	3	main
rahvusliikumise	doc_346862720678_item	2339213	et	3	main
sihe	doc_346862720678_item	2339214	et	4	main
panna	doc_346862720678_item	2339078	et	4	main
mängida	doc_346862720678_item	2339080	et	3	main
eestimaa	doc_346862720678_item	2339084	et	4	main
ja	doc_346862720678_item	2339085	et	3	main
minu	doc_346862720678_item	2339100	et	3	main
olid	doc_346862720678_item	2339102	et	4	main
need	doc_346862720678_item	2339103	et	3	main
arenda	doc_346862720678_item	2339112	et	4	main
üks	doc_346862720678_item	2339114	et	3	main
oli	doc_346862720678_item	2339116	et	3	main
j	doc_346862720678_item	2339117	et	4	main
oma	doc_346862720678_item	2339075	et	4	main
liivimaa	doc_346862720678_item	2339086	et	4	main
vene	doc_346862720678_item	2339090	et	4	main
osad	doc_346862720678_item	2339092	et	3	main
teelased	doc_346862720678_item	2339099	et	3	main
mõtteid	doc_346862720678_item	2339109	et	3	main
neid	doc_346862720678_item	2339115	et	4	main
v	doc_346862720678_item	2339118	et	4	main
välja	doc_346862720678_item	2339123	et	4	main
perno	doc_346862720678_item	2339126	et	4	main
postimees	doc_346862720678_item	2339127	et	4	main
oma	doc_346862720678_item	2339137	et	4	main
tööga	doc_346862720678_item	2339138	et	3	main
sest	doc_346862720678_item	2339151	et	4	main
lähenes	doc_346862720678_item	2339152	et	3	main
rahvale	doc_346862720678_item	2339153	et	3	main
asutas	doc_346862720678_item	2339157	et	3	main
seltsi	doc_346862720678_item	2339161	et	4	main
üldlaulupidu	doc_346862720678_item	2339164	et	4	main
a	doc_346862720678_item	2339166	et	4	main
a	doc_346862720678_item	2339168	et	4	main
tekkima	doc_346862720678_item	2339172	et	3	main
tegutses	doc_346862720678_item	2339175	et	3	main
r	doc_346862720678_item	2339180	et	4	main
kultuuri	doc_346862720678_item	2339186	et	4	main
ärkamisaja	doc_346862720678_item	2339188	et	3	main
peterburi	doc_346862720678_item	2339198	et	4	main
patriotide	doc_346862720678_item	2339199	et	4	main
pani	doc_346862720678_item	2339203	et	4	main
märatles	doc_346862720678_item	2339212	et	4	main
ja	doc_346862720678_item	2339215	et	3	main
keeleteadlane	doc_346862720678_item	2339218	et	3	main
hurt	doc_346862720678_item	2339220	et	3	main
oli	doc_346862720678_item	2339221	et	3	main
aleksandrikooli	doc_346862720678_item	2339222	et	4	main
ja	doc_346862720678_item	2339244	et	3	main
tähtsad	doc_346862720678_item	2339248	et	3	main
olid	doc_346862720678_item	2339251	et	4	main
1860	doc_346862720678_item	2339167	et	2	main
rahvuslaste	doc_346862720678_item	2339170	et	4	main
aktiivselt	doc_346862720678_item	2339174	et	4	main
iseenesest	doc_346862720678_item	2339183	et	4	main
nagu	doc_346862720678_item	2339185	et	3	main
keskus	doc_346862720678_item	2339187	et	3	main
tegelane	doc_346862720678_item	2339190	et	3	main
aluse	doc_346862720678_item	2339204	et	4	main
saatmise	doc_346862720678_item	2339206	et	4	main
eesmärke	doc_346862720678_item	2339216	et	4	main
vaimuvara	doc_346862720678_item	2339230	et	4	main
rahvaluule	doc_346862720678_item	2339231	et	4	main
ja	doc_346862720678_item	2339232	et	3	main
ajaloo	doc_346862720678_item	2339233	et	4	main
jakobson	doc_346862720678_item	2339239	et	4	main
oli	doc_346862720678_item	2339240	et	3	main
sellel	doc_346862720678_item	2339249	et	4	main
ka	doc_346862720678_item	2339252	et	3	main
isamaa	doc_346862720678_item	2339255	et	4	main
laulud	doc_346862720678_item	2339256	et	3	main
ajal	doc_346862720678_item	2339250	et	4	main
lidia	doc_346862720678_item	2339253	et	4	main
koidula	doc_346862720678_item	2339254	et	4	main
eesti	doc_366216787875_item	2340743	et	4	main
teeb	doc_366216787875_item	2340754	et	3	main
essee	doc_366216787875_item	2340757	et	4	main
pikkus	doc_366216787875_item	2340758	et	4	main
300	doc_366216787875_item	2340759	et	2	main
analüüsiv	doc_366216787875_item	2340766	et	4	main
mina	doc_366216787875_item	2340780	et	4	main
pannud	doc_366216787875_item	2340788	et	4	main
on	doc_366216787875_item	2340792	et	4	main
rahvas	doc_366216787875_item	2340796	et	4	main
eestlaste	doc_366216787875_item	2340798	et	4	main
keskel	doc_366216787875_item	2340799	et	3	main
alati	doc_366216787875_item	2340800	et	4	main
kuulen	doc_366216787875_item	2340801	et	3	main
nii	doc_366216787875_item	2340803	et	3	main
ka	doc_366216787875_item	2340806	et	3	main
ja	doc_366216787875_item	2340809	et	3	main
alati	doc_366216787875_item	2340820	et	4	main
kaasa	doc_366216787875_item	2340821	et	4	main
pidupäeval	doc_366216787875_item	2340831	et	3	main
kurvade	doc_366216787875_item	2340834	et	4	main
elu	doc_366216787875_item	2340842	et	4	main
tähtis	doc_366216787875_item	2340855	et	4	main
tuleb	doc_366216787875_item	2340859	et	3	main
ajast	doc_366216787875_item	2340862	et	4	main
peatu	doc_366216787875_item	2340866	et	4	main
seda	doc_366216787875_item	2340868	et	3	main
põlvest	doc_366216787875_item	2340870	et	4	main
vaid	doc_366216787875_item	2340921	et	3	main
väga	doc_366216787875_item	2340929	et	3	main
ja	doc_366216787875_item	2340931	et	3	main
ja	doc_366216787875_item	2340937	et	3	main
eesti	doc_366216787875_item	2340940	et	4	main
vaid	doc_366216787875_item	2340945	et	3	main
kui	doc_366216787875_item	2340745	et	3	main
peab	doc_366216787875_item	2340763	et	4	main
arutlev	doc_366216787875_item	2340765	et	4	main
ja	doc_366216787875_item	2340767	et	3	main
tuginema	doc_366216787875_item	2340769	et	3	main
loengus	doc_366216787875_item	2340770	et	3	main
ja	doc_366216787875_item	2340771	et	3	main
lugemistekstis	doc_366216787875_item	2340772	et	3	main
esitatud	doc_366216787875_item	2340773	et	4	main
faktidele	doc_366216787875_item	2340774	et	3	main
väiteid	doc_366216787875_item	2340775	et	4	main
soovitatav	doc_366216787875_item	2340777	et	4	main
teise	doc_366216787875_item	2340782	et	4	main
olen	doc_366216787875_item	2340785	et	3	main
et	doc_366216787875_item	2340789	et	3	main
tõesti	doc_366216787875_item	2340793	et	3	main
laulmist	doc_366216787875_item	2340802	et	4	main
kui	doc_366216787875_item	2340805	et	3	main
noorte	doc_366216787875_item	2340807	et	3	main
eestimaa	doc_366216787875_item	2340813	et	4	main
ajalooline	doc_366216787875_item	2340814	et	4	main
näitab	doc_366216787875_item	2340816	et	3	main
eesti	doc_366216787875_item	2340823	et	4	main
aegadel	doc_366216787875_item	2340835	et	3	main
on	doc_366216787875_item	2340839	et	4	main
eestlaste	doc_366216787875_item	2340840	et	4	main
on	doc_366216787875_item	2340845	et	4	main
rahvalaul	doc_366216787875_item	2340858	et	4	main
väga	doc_366216787875_item	2340860	et	3	main
ei	doc_366216787875_item	2340865	et	4	main
suhtumine	doc_366216787875_item	2340873	et	4	main
näitab	doc_366216787875_item	2340875	et	3	main
laule	doc_366216787875_item	2340882	et	4	main
ja	doc_366216787875_item	2340883	et	3	main
essee	doc_366216787875_item	2340742	et	4	main
mis	doc_366216787875_item	2340753	et	4	main
sõna	doc_366216787875_item	2340761	et	4	main
kultuuri	doc_366216787875_item	2340783	et	4	main
inimene	doc_366216787875_item	2340784	et	3	main
tähele	doc_366216787875_item	2340787	et	3	main
inimesed	doc_366216787875_item	2340791	et	3	main
täiskasvanute	doc_366216787875_item	2340804	et	3	main
inimestelt	doc_366216787875_item	2340808	et	3	main
see	doc_366216787875_item	2340810	et	3	main
et	doc_366216787875_item	2340817	et	3	main
laul	doc_366216787875_item	2340818	et	4	main
käinud	doc_366216787875_item	2340822	et	4	main
teise	doc_366216787875_item	2340746	et	4	main
keele	doc_366216787875_item	2340747	et	4	main
kirjutamine	doc_366216787875_item	2340749	et	4	main
kirjutage	doc_366216787875_item	2340750	et	3	main
essee	doc_366216787875_item	2340751	et	4	main
teemal	doc_366216787875_item	2340752	et	3	main
350	doc_366216787875_item	2340760	et	2	main
olema	doc_366216787875_item	2340764	et	4	main
üldistav	doc_366216787875_item	2340768	et	4	main
illustreerida	doc_366216787875_item	2340778	et	3	main
näidetega	doc_366216787875_item	2340779	et	3	main
alati	doc_366216787875_item	2340786	et	4	main
laulev	doc_366216787875_item	2340795	et	4	main
elades	doc_366216787875_item	2340797	et	4	main
on	doc_366216787875_item	2340811	et	4	main
on	doc_366216787875_item	2340819	et	4	main
keele	doc_366216787875_item	2340744	et	4	main
test	doc_366216787875_item	2340748	et	3	main
eestlastest	doc_366216787875_item	2340755	et	4	main
laulurahva	doc_366216787875_item	2340756	et	3	main
essee	doc_366216787875_item	2340762	et	4	main
on	doc_366216787875_item	2340776	et	4	main
kui	doc_366216787875_item	2340781	et	3	main
eesti	doc_366216787875_item	2340790	et	4	main
väga	doc_366216787875_item	2340794	et	3	main
imetlusväärne	doc_366216787875_item	2340812	et	3	main
taust	doc_366216787875_item	2340815	et	4	main
inimeste	doc_366216787875_item	2340824	et	3	main
töötegemisel	doc_366216787875_item	2340826	et	3	main
ajal	doc_366216787875_item	2340828	et	4	main
ja	doc_366216787875_item	2340829	et	3	main
argipäevaelus	doc_366216787875_item	2340832	et	4	main
ja	doc_366216787875_item	2340833	et	3	main
aga	doc_366216787875_item	2340843	et	3	main
elu	doc_366216787875_item	2340844	et	4	main
on	doc_366216787875_item	2340854	et	4	main
kaugest	doc_366216787875_item	2340861	et	3	main
vaid	doc_366216787875_item	2340867	et	3	main
põlve	doc_366216787875_item	2340871	et	4	main
rahvalaulu	doc_366216787875_item	2340874	et	4	main
jõuga	doc_366216787875_item	2340920	et	3	main
lauluga	doc_366216787875_item	2340922	et	4	main
eestlased	doc_366216787875_item	2340923	et	3	main
rahulikke	doc_366216787875_item	2340930	et	4	main
rahvalaule	doc_366216787875_item	2340933	et	4	main
ei	doc_366216787875_item	2340942	et	4	main
mis	doc_366216787875_item	2340954	et	4	main
on	doc_366216787875_item	2340955	et	4	main
lauldud	doc_366216787875_item	2340956	et	4	main
vanu	doc_366216787875_item	2340965	et	4	main
rahvapille	doc_366216787875_item	2340966	et	3	main
on	doc_366216787875_item	2340973	et	4	main
on	doc_366216787875_item	2340980	et	4	main
kindlasti	doc_366216787875_item	2340988	et	3	main
rahvalaul	doc_366216787875_item	2340989	et	4	main
saa	doc_366216787875_item	2340991	et	4	main
ka	doc_366216787875_item	2340992	et	3	main
paigal	doc_366216787875_item	2340993	et	4	main
vaid	doc_366216787875_item	2340994	et	3	main
hea	doc_366216787875_item	2341021	et	4	main
rahvale	doc_366216787875_item	2341031	et	3	main
laulmine	doc_366216787875_item	2341034	et	4	main
see	doc_366216787875_item	2341039	et	3	main
identiteet	doc_366216787875_item	2341043	et	4	main
et	doc_366216787875_item	2341051	et	3	main
praegu	doc_366216787875_item	2341057	et	3	main
stiilid	doc_366216787875_item	2341061	et	4	main
lauldakse	doc_366216787875_item	2341063	et	3	main
mitmehäälselt	doc_366216787875_item	2341067	et	4	main
et	doc_366216787875_item	2341069	et	3	main
ainult	doc_366216787875_item	2341076	et	4	main
eluga	doc_366216787875_item	2340825	et	3	main
tundub	doc_366216787875_item	2340836	et	3	main
ilma	doc_366216787875_item	2340848	et	4	main
lauluta	doc_366216787875_item	2340849	et	3	main
midagi	doc_366216787875_item	2340850	et	4	main
ei	doc_366216787875_item	2340851	et	4	main
tehta	doc_366216787875_item	2340852	et	3	main
et	doc_366216787875_item	2340857	et	3	main
see	doc_366216787875_item	2340864	et	3	main
armastab	doc_366216787875_item	2340880	et	3	main
rahva	doc_366216787875_item	2340885	et	3	main
ajaloolist	doc_366216787875_item	2340886	et	4	main
mälu	doc_366216787875_item	2340887	et	4	main
rahvalaulu	doc_366216787875_item	2340888	et	4	main
kaudu	doc_366216787875_item	2340889	et	3	main
saab	doc_366216787875_item	2340890	et	3	main
näha	doc_366216787875_item	2340891	et	3	main
kuidas	doc_366216787875_item	2340892	et	3	main
ühel	doc_366216787875_item	2340893	et	3	main
või	doc_366216787875_item	2340894	et	4	main
teisel	doc_366216787875_item	2340895	et	4	main
ajalooperioodil	doc_366216787875_item	2340896	et	3	main
elas	doc_366216787875_item	2340897	et	3	main
eesti	doc_366216787875_item	2340898	et	4	main
rahvas	doc_366216787875_item	2340899	et	4	main
mis	doc_366216787875_item	2340900	et	4	main
sündmused	doc_366216787875_item	2340901	et	3	main
toimisid	doc_366216787875_item	2340902	et	4	main
ja	doc_366216787875_item	2340903	et	3	main
kuidas	doc_366216787875_item	2340904	et	3	main
ta	doc_366216787875_item	2340905	et	4	main
ennast	doc_366216787875_item	2340906	et	4	main
tunnes	doc_366216787875_item	2340907	et	3	main
näiteks	doc_366216787875_item	2340908	et	4	main
nõukogude	doc_366216787875_item	2340909	et	3	main
ajal	doc_366216787875_item	2340910	et	4	main
inimesed	doc_366216787875_item	2340912	et	3	main
näitasid	doc_366216787875_item	2340913	et	4	main
oma	doc_366216787875_item	2340914	et	4	main
eesti	doc_366216787875_item	2340911	et	4	main
poliitilist	doc_366216787875_item	2340915	et	3	main
protesti	doc_366216787875_item	2340916	et	4	main
mitte	doc_366216787875_item	2340917	et	3	main
relvaga	doc_366216787875_item	2340918	et	3	main
ega	doc_366216787875_item	2340919	et	3	main
mängu	doc_366216787875_item	2340827	et	4	main
tansimisel	doc_366216787875_item	2340830	et	4	main
et	doc_366216787875_item	2340837	et	3	main
laul	doc_366216787875_item	2340838	et	4	main
jaoks	doc_366216787875_item	2340841	et	4	main
laul	doc_366216787875_item	2340846	et	4	main
kuna	doc_366216787875_item	2340847	et	3	main
sellejuures	doc_366216787875_item	2340853	et	3	main
see	doc_366216787875_item	2340856	et	3	main
ja	doc_366216787875_item	2340863	et	3	main
antakse	doc_366216787875_item	2340869	et	3	main
taoline	doc_366216787875_item	2340872	et	3	main
seda	doc_366216787875_item	2340876	et	3	main
et	doc_366216787875_item	2340877	et	3	main
eesti	doc_366216787875_item	2340878	et	4	main
rahvas	doc_366216787875_item	2340879	et	4	main
oma	doc_366216787875_item	2340881	et	4	main
hoiab	doc_366216787875_item	2340884	et	3	main
rahulik	doc_366216787875_item	2340925	et	3	main
loonud	doc_366216787875_item	2340928	et	4	main
näha	doc_366216787875_item	2340938	et	3	main
ole	doc_366216787875_item	2340943	et	4	main
liigub	doc_366216787875_item	2340947	et	3	main
inimeste	doc_366216787875_item	2340949	et	3	main
teadavad	doc_366216787875_item	2340952	et	4	main
1000	doc_366216787875_item	2340957	et	2	main
oskavad	doc_366216787875_item	2340962	et	4	main
neid	doc_366216787875_item	2340964	et	4	main
oskavad	doc_366216787875_item	2340968	et	4	main
rahvatantsu	doc_366216787875_item	2340970	et	4	main
leitavad	doc_366216787875_item	2340974	et	4	main
ja	doc_366216787875_item	2340978	et	3	main
tore	doc_366216787875_item	2340981	et	3	main
eriti	doc_366216787875_item	2340983	et	3	main
noori	doc_366216787875_item	2340984	et	3	main
inimesi	doc_366216787875_item	2340985	et	4	main
laulmas	doc_366216787875_item	2340986	et	3	main
areneb	doc_366216787875_item	2340995	et	3	main
uued	doc_366216787875_item	2340997	et	3	main
suunad	doc_366216787875_item	2340999	et	4	main
mõjutavad	doc_366216787875_item	2341003	et	4	main
ongi	doc_366216787875_item	2341028	et	4	main
on	doc_366216787875_item	2341037	et	4	main
on	doc_366216787875_item	2341040	et	4	main
mis	doc_366216787875_item	2341044	et	4	main
neid	doc_366216787875_item	2341046	et	4	main
on	doc_366216787875_item	2341049	et	4	main
eesti	doc_366216787875_item	2341052	et	4	main
rahvalaul	doc_366216787875_item	2341053	et	4	main
on	doc_366216787875_item	2341054	et	4	main
ühehäälne	doc_366216787875_item	2341055	et	3	main
kuid	doc_366216787875_item	2341056	et	4	main
kooriga	doc_366216787875_item	2341065	et	4	main
et	doc_366216787875_item	2341072	et	3	main
mitte	doc_366216787875_item	2341075	et	3	main
tänapäeva	doc_366216787875_item	2341081	et	4	main
aastat	doc_366216787875_item	2341123	et	3	main
kui	doc_366216787875_item	2340924	et	3	main
oli	doc_366216787875_item	2340927	et	3	main
hingestatud	doc_366216787875_item	2340932	et	4	main
tänapäeval	doc_366216787875_item	2340934	et	3	main
rahvalaul	doc_366216787875_item	2340941	et	4	main
aastat	doc_366216787875_item	2340958	et	3	main
mängida	doc_366216787875_item	2340963	et	3	main
kanalitel	doc_366216787875_item	2340976	et	3	main
üldlaulupeodel	doc_366216787875_item	2340987	et	3	main
erinevad	doc_366216787875_item	2341001	et	4	main
seda	doc_366216787875_item	2341004	et	3	main
sellest	doc_366216787875_item	2341006	et	4	main
ja	doc_366216787875_item	2341005	et	3	main
tulevad	doc_366216787875_item	2341007	et	4	main
uued	doc_366216787875_item	2341008	et	3	main
vanad	doc_366216787875_item	2341009	et	3	main
rahvalaulud	doc_366216787875_item	2341010	et	3	main
kui	doc_366216787875_item	2341011	et	3	main
nii	doc_366216787875_item	2341012	et	3	main
saab	doc_366216787875_item	2341013	et	3	main
õelda	doc_366216787875_item	2341014	et	4	main
ma	doc_366216787875_item	2341015	et	3	main
arvan	doc_366216787875_item	2341016	et	3	main
et	doc_366216787875_item	2341017	et	3	main
ka	doc_366216787875_item	2341018	et	3	main
see	doc_366216787875_item	2341019	et	3	main
on	doc_366216787875_item	2341020	et	4	main
kuna	doc_366216787875_item	2341022	et	3	main
see	doc_366216787875_item	2341023	et	3	main
et	doc_366216787875_item	2341025	et	3	main
eesti	doc_366216787875_item	2341026	et	4	main
on	doc_366216787875_item	2341032	et	4	main
iseloomulik	doc_366216787875_item	2341033	et	3	main
eestimaa	doc_366216787875_item	2341041	et	4	main
teada	doc_366216787875_item	2341050	et	3	main
püütakse	doc_366216787875_item	2341058	et	3	main
näiteks	doc_366216787875_item	2341062	et	4	main
saab	doc_366216787875_item	2341070	et	3	main
ei	doc_366216787875_item	2341077	et	4	main
teist	doc_366216787875_item	2341079	et	4	main
poolt	doc_366216787875_item	2341083	et	4	main
rahvas	doc_366216787875_item	2340926	et	4	main
on	doc_366216787875_item	2340935	et	4	main
kuulda	doc_366216787875_item	2340936	et	4	main
et	doc_366216787875_item	2340939	et	3	main
surnud	doc_366216787875_item	2340944	et	4	main
see	doc_366216787875_item	2340946	et	3	main
noorte	doc_366216787875_item	2340948	et	3	main
seas	doc_366216787875_item	2340950	et	4	main
noored	doc_366216787875_item	2340951	et	3	main
laule	doc_366216787875_item	2340953	et	4	main
tagasi	doc_366216787875_item	2340959	et	3	main
ja	doc_366216787875_item	2340967	et	3	main
ka	doc_366216787875_item	2340969	et	3	main
tõestusi	doc_366216787875_item	2340971	et	4	main
sellele	doc_366216787875_item	2340972	et	4	main
ei	doc_366216787875_item	2340990	et	4	main
kuna	doc_366216787875_item	2340996	et	3	main
muusika	doc_366216787875_item	2340998	et	4	main
ja	doc_366216787875_item	2341000	et	3	main
nad	doc_366216787875_item	2340960	et	3	main
ka	doc_366216787875_item	2340961	et	3	main
tv	doc_366216787875_item	2340975	et	4	main
raadiosaatetel	doc_366216787875_item	2340977	et	3	main
kindlasti	doc_366216787875_item	2340979	et	3	main
kuulda	doc_366216787875_item	2340982	et	4	main
kultuurid	doc_366216787875_item	2341002	et	3	main
näitab	doc_366216787875_item	2341024	et	3	main
ja	doc_366216787875_item	2341035	et	3	main
hea	doc_366216787875_item	2341038	et	4	main
eristab	doc_366216787875_item	2341045	et	3	main
teistest	doc_366216787875_item	2341047	et	4	main
maadest	doc_366216787875_item	2341048	et	4	main
luua	doc_366216787875_item	2341059	et	4	main
ja	doc_366216787875_item	2341066	et	3	main
loota	doc_366216787875_item	2341071	et	4	main
rahvalaul	doc_366216787875_item	2341074	et	4	main
saa	doc_366216787875_item	2341078	et	4	main
kultuuri	doc_366216787875_item	2341082	et	4	main
see	doc_366216787875_item	2341120	et	3	main
rahvas	doc_366216787875_item	2341027	et	4	main
laulurahvas	doc_366216787875_item	2341029	et	4	main
eesti	doc_366216787875_item	2341030	et	4	main
see	doc_366216787875_item	2341036	et	3	main
rahva	doc_366216787875_item	2341042	et	3	main
uued	doc_366216787875_item	2341060	et	3	main
rahvalaule	doc_366216787875_item	2341064	et	4	main
nii	doc_366216787875_item	2341068	et	3	main
eesti	doc_366216787875_item	2341073	et	4	main
värvingud	doc_366216787875_item	2341080	et	3	main
vaid	doc_366216787875_item	2341084	et	3	main
ka	doc_366216787875_item	2341085	et	3	main
säilitab	doc_366216787875_item	2341086	et	3	main
1000	doc_366216787875_item	2341087	et	2	main
aastase	doc_366216787875_item	2341088	et	4	main
eesti	doc_366216787875_item	2341089	et	4	main
rahvalaulu	doc_366216787875_item	2341090	et	4	main
selle	doc_366216787875_item	2341092	et	4	main
põhituuma	doc_366216787875_item	2341091	et	4	main
olemust	doc_366216787875_item	2341093	et	3	main
muistset	doc_366216787875_item	2341094	et	3	main
hinge	doc_366216787875_item	2341095	et	4	main
ja	doc_366216787875_item	2341096	et	3	main
eripärasust	doc_366216787875_item	2341097	et	4	main
kokkuvõtvalt	doc_366216787875_item	2341098	et	4	main
tuleb	doc_366216787875_item	2341099	et	3	main
õelda	doc_366216787875_item	2341100	et	4	main
eesti	doc_366216787875_item	2341102	et	4	main
et	doc_366216787875_item	2341101	et	3	main
rahvas	doc_366216787875_item	2341103	et	4	main
on	doc_366216787875_item	2341104	et	4	main
laulurahvas	doc_366216787875_item	2341105	et	4	main
kuna	doc_366216787875_item	2341106	et	3	main
suutis	doc_366216787875_item	2341107	et	3	main
läbi	doc_366216787875_item	2341108	et	4	main
kõiki	doc_366216787875_item	2341109	et	4	main
aegade	doc_366216787875_item	2341110	et	3	main
ja	doc_366216787875_item	2341111	et	3	main
raskuste	doc_366216787875_item	2341112	et	4	main
vältel	doc_366216787875_item	2341113	et	4	main
hoida	doc_366216787875_item	2341114	et	3	main
oma	doc_366216787875_item	2341115	et	4	main
eestimaa	doc_366216787875_item	2341116	et	4	main
laulu	doc_366216787875_item	2341117	et	4	main
nagu	doc_366216787875_item	2341119	et	3	main
nii	doc_366216787875_item	2341118	et	3	main
kõlas	doc_366216787875_item	2341121	et	4	main
1000	doc_366216787875_item	2341122	et	2	main
tagasi	doc_366216787875_item	2341124	et	3	main
teemal	doc_366216787879_item	2341935	et	3	main
mis	doc_366216787879_item	2341936	et	4	main
teeb	doc_366216787879_item	2341937	et	3	main
laulurahva	doc_366216787879_item	2341939	et	3	main
essee	doc_366216787879_item	2341945	et	4	main
peab	doc_366216787879_item	2341946	et	4	main
on	doc_366216787879_item	2341959	et	4	main
näidetega	doc_366216787879_item	2341962	et	3	main
on	doc_366216787879_item	2341964	et	4	main
läbi	doc_366216787879_item	2341970	et	4	main
aegade	doc_366216787879_item	2341971	et	3	main
oluline	doc_366216787879_item	2342001	et	4	main
kokkupuutumis	doc_366216787879_item	2342004	et	4	main
rahva	doc_366216787879_item	2342005	et	3	main
on	doc_366216787879_item	2342011	et	4	main
eestlast	doc_366216787879_item	2342018	et	4	main
hällist	doc_366216787879_item	2342019	et	4	main
iga	doc_366216787879_item	2342021	et	4	main
kaasa	doc_366216787879_item	2342024	et	4	main
saadetud	doc_366216787879_item	2342025	et	4	main
kajastas	doc_366216787879_item	2342028	et	3	main
tähtsust	doc_366216787879_item	2342032	et	4	main
laulude	doc_366216787879_item	2342033	et	3	main
ongi	doc_366216787879_item	2342035	et	4	main
aru	doc_366216787879_item	2342044	et	4	main
eestlaste	doc_366216787879_item	2342046	et	4	main
keele	doc_366216787879_item	2341930	et	4	main
olema	doc_366216787879_item	2341947	et	4	main
üldistav	doc_366216787879_item	2341951	et	4	main
ja	doc_366216787879_item	2341954	et	3	main
soovitatav	doc_366216787879_item	2341960	et	4	main
illustreerida	doc_366216787879_item	2341961	et	3	main
laulmine	doc_366216787879_item	2341963	et	4	main
olulisemaid	doc_366216787879_item	2341967	et	4	main
tähendas	doc_366216787879_item	2342003	et	3	main
südamega	doc_366216787879_item	2342006	et	3	main
üle	doc_366216787879_item	2342012	et	3	main
laul	doc_366216787879_item	2342027	et	4	main
sündmuse	doc_366216787879_item	2342029	et	3	main
eesti	doc_366216787879_item	2342036	et	4	main
vaadeldes	doc_366216787879_item	2342042	et	3	main
saada	doc_366216787879_item	2342045	et	4	main
vanemad	doc_366216787879_item	2342051	et	4	main
on	doc_366216787879_item	2342053	et	4	main
laulud	doc_366216787879_item	2342055	et	3	main
need	doc_366216787879_item	2342056	et	3	main
on	doc_366216787879_item	2342057	et	4	main
lapsele	doc_366216787879_item	2342106	et	4	main
eesmärgiks	doc_366216787879_item	2342110	et	3	main
ajal	doc_366216787879_item	2342112	et	4	main
endast	doc_366216787879_item	2342114	et	4	main
eesti	doc_366216787879_item	2341926	et	4	main
test	doc_366216787879_item	2341931	et	3	main
kirjutamine	doc_366216787879_item	2341932	et	4	main
kirjutage	doc_366216787879_item	2341933	et	3	main
essee	doc_366216787879_item	2341940	et	4	main
arutlev	doc_366216787879_item	2341948	et	4	main
esitatud	doc_366216787879_item	2341956	et	4	main
faktidele	doc_366216787879_item	2341957	et	3	main
väiteid	doc_366216787879_item	2341958	et	4	main
üks	doc_366216787879_item	2341966	et	3	main
1000	doc_366216787879_item	2342013	et	2	main
hauani	doc_366216787879_item	2342020	et	3	main
keele	doc_366216787879_item	2341927	et	4	main
kui	doc_366216787879_item	2341928	et	3	main
teise	doc_366216787879_item	2341929	et	4	main
eestlastest	doc_366216787879_item	2341938	et	4	main
sõna	doc_366216787879_item	2341944	et	4	main
ja	doc_366216787879_item	2341950	et	3	main
tuginema	doc_366216787879_item	2341952	et	3	main
loengus	doc_366216787879_item	2341953	et	3	main
lugemistekstis	doc_366216787879_item	2341955	et	3	main
tegevusi	doc_366216787879_item	2341969	et	4	main
laulmine	doc_366216787879_item	2341972	et	4	main
ja	doc_366216787879_item	2341973	et	3	main
eesti	doc_366216787879_item	2342008	et	4	main
laulude	doc_366216787879_item	2342009	et	3	main
ajalugu	doc_366216787879_item	2342010	et	4	main
vana	doc_366216787879_item	2342015	et	4	main
laul	doc_366216787879_item	2342016	et	4	main
sündmus	doc_366216787879_item	2342022	et	3	main
ning	doc_366216787879_item	2342031	et	3	main
rahvuse	doc_366216787879_item	2342037	et	3	main
laulude	doc_366216787879_item	2342040	et	3	main
kõige	doc_366216787879_item	2342050	et	4	main
laulud	doc_366216787879_item	2342059	et	3	main
alati	doc_366216787879_item	2342063	et	4	main
silbil	doc_366216787879_item	2342065	et	3	main
inimene	doc_366216787879_item	2342070	et	3	main
andis	doc_366216787879_item	2342105	et	3	main
laulu	doc_366216787879_item	2342109	et	4	main
märku	doc_366216787879_item	2342115	et	4	main
ajal	doc_366216787879_item	2342119	et	4	main
abil	doc_366216787879_item	2342121	et	4	main
karjapoisid	doc_366216787879_item	2342123	et	4	main
lauldi	doc_366216787879_item	2342127	et	3	main
kui	doc_366216787879_item	2342130	et	3	main
rohkem	doc_366216787879_item	2342137	et	4	main
võrreldes	doc_366216787879_item	2342139	et	3	main
laulmine	doc_366216787879_item	2342143	et	4	main
oli	doc_366216787879_item	2342144	et	3	main
pigem	doc_366216787879_item	2342145	et	3	main
nukruv	doc_366216787879_item	2342146	et	4	main
oli	doc_366216787879_item	2342162	et	3	main
tempo	doc_366216787879_item	2342167	et	4	main
laul	doc_366216787879_item	2342175	et	4	main
oli	doc_366216787879_item	2342176	et	3	main
koor	doc_366216787879_item	2342183	et	4	main
aga	doc_366216787879_item	2342198	et	3	main
muutusid	doc_366216787879_item	2342201	et	4	main
ei	doc_366216787879_item	2342213	et	4	main
koos	doc_366216787879_item	2342222	et	4	main
igasugused	doc_366216787879_item	2342225	et	3	main
kirikukoorid	doc_366216787879_item	2342228	et	3	main
selle	doc_366216787879_item	2342234	et	4	main
levikuga	doc_366216787879_item	2342237	et	3	main
puhpilliorkestrite	doc_366216787879_item	2342240	et	4	main
teiste	doc_366216787879_item	2342244	et	4	main
kohtades	doc_366216787879_item	2342249	et	3	main
sajandil	doc_366216787879_item	2342251	et	3	main
rahvalaulud	doc_366216787879_item	2342258	et	3	main
tempo	doc_366216787879_item	2342264	et	4	main
polnud	doc_366216787879_item	2342298	et	3	main
tsaari	doc_366216787879_item	2342305	et	4	main
essee	doc_366216787879_item	2341925	et	4	main
essee	doc_366216787879_item	2341934	et	4	main
pikkus	doc_366216787879_item	2341941	et	4	main
300	doc_366216787879_item	2341942	et	2	main
350	doc_366216787879_item	2341943	et	2	main
analüüsiv	doc_366216787879_item	2341949	et	4	main
olnud	doc_366216787879_item	2341965	et	4	main
ajalooliseid	doc_366216787879_item	2341968	et	4	main
pakkus	doc_366216787879_item	2341975	et	3	main
esteetilist	doc_366216787879_item	2341976	et	3	main
tantsimine	doc_366216787879_item	2341974	et	4	main
naudingu	doc_366216787879_item	2341977	et	3	main
rõõmustas	doc_366216787879_item	2341978	et	3	main
toetas	doc_366216787879_item	2341979	et	3	main
rahustas	doc_366216787879_item	2341980	et	3	main
aitas	doc_366216787879_item	2341981	et	3	main
tööl	doc_366216787879_item	2341982	et	3	main
ja	doc_366216787879_item	2341983	et	3	main
igapäevases	doc_366216787879_item	2341984	et	4	main
elus	doc_366216787879_item	2341985	et	4	main
hoidis	doc_366216787879_item	2341986	et	4	main
rahvatraditsioonid	doc_366216787879_item	2341987	et	3	main
ning	doc_366216787879_item	2341988	et	3	main
edastas	doc_366216787879_item	2341989	et	3	main
ajalugu	doc_366216787879_item	2341990	et	4	main
ning	doc_366216787879_item	2341991	et	3	main
rahvatraditsioonid	doc_366216787879_item	2341992	et	3	main
tulevikku	doc_366216787879_item	2341993	et	4	main
eestlaste	doc_366216787879_item	2341994	et	4	main
jaoks	doc_366216787879_item	2341995	et	4	main
laulmine	doc_366216787879_item	2341996	et	4	main
on	doc_366216787879_item	2341997	et	4	main
olnud	doc_366216787879_item	2341998	et	4	main
alati	doc_366216787879_item	2341999	et	4	main
väga	doc_366216787879_item	2342000	et	3	main
ning	doc_366216787879_item	2342002	et	3	main
ajalooga	doc_366216787879_item	2342007	et	4	main
aastat	doc_366216787879_item	2342014	et	3	main
saatis	doc_366216787879_item	2342017	et	3	main
lauluga	doc_366216787879_item	2342026	et	4	main
meeleolu	doc_366216787879_item	2342030	et	4	main
ajalugu	doc_366216787879_item	2342034	et	4	main
eesti	doc_366216787879_item	2342039	et	4	main
arengu	doc_366216787879_item	2342041	et	3	main
saame	doc_366216787879_item	2342043	et	4	main
rahvalaulud	doc_366216787879_item	2342052	et	3	main
oli	doc_366216787879_item	2342062	et	3	main
esimesel	doc_366216787879_item	2342064	et	3	main
emalaulud	doc_366216787879_item	2342066	et	3	main
esimesed	doc_366216787879_item	2342068	et	3	main
last	doc_366216787879_item	2342101	et	4	main
mis	doc_366216787879_item	2342104	et	4	main
edastasid	doc_366216787879_item	2342122	et	4	main
eestis	doc_366216787879_item	2342126	et	3	main
aga	doc_366216787879_item	2342132	et	3	main
levinud	doc_366216787879_item	2342138	et	4	main
saatis	doc_366216787879_item	2342148	et	3	main
laulmine	doc_366216787879_item	2342152	et	4	main
aga	doc_366216787879_item	2342153	et	3	main
esindatud	doc_366216787879_item	2342155	et	4	main
sündmuste	doc_366216787879_item	2342157	et	3	main
kui	doc_366216787879_item	2342164	et	3	main
regivärsiline	doc_366216787879_item	2342174	et	4	main
lauldud	doc_366216787879_item	2342177	et	4	main
lisandus	doc_366216787879_item	2342181	et	4	main
laulmine	doc_366216787879_item	2342193	et	4	main
aeg	doc_366216787879_item	2342197	et	3	main
ka	doc_366216787879_item	2342202	et	3	main
rahvalaulud	doc_366216787879_item	2342204	et	3	main
tihti	doc_366216787879_item	2342208	et	3	main
saanud	doc_366216787879_item	2342214	et	4	main
kas	doc_366216787879_item	2342227	et	3	main
koorid	doc_366216787879_item	2342231	et	4	main
kiruku	doc_366216787879_item	2342235	et	4	main
rahvamuusikat	doc_366216787879_item	2342242	et	3	main
rahvuste	doc_366216787879_item	2342245	et	3	main
üldise	doc_366216787879_item	2342253	et	3	main
ilmusid	doc_366216787879_item	2342256	et	4	main
lõpuriim	doc_366216787879_item	2342262	et	3	main
kiirem	doc_366216787879_item	2342263	et	4	main
ning	doc_366216787879_item	2342265	et	3	main
mitmekesisus	doc_366216787879_item	2342266	et	4	main
olnud	doc_366216787879_item	2342304	et	4	main
ning	doc_366216787879_item	2342307	et	3	main
ajal	doc_366216787879_item	2342309	et	4	main
läbi	doc_366216787879_item	2342311	et	4	main
tõttu	doc_366216787879_item	2342317	et	4	main
näitamine	doc_366216787879_item	2342322	et	4	main
ei	doc_366216787879_item	2342323	et	4	main
olnud	doc_366216787879_item	2342324	et	4	main
siiski	doc_366216787879_item	2342329	et	4	main
läinud	doc_366216787879_item	2342343	et	4	main
jälgides	doc_366216787879_item	2342346	et	4	main
võime	doc_366216787879_item	2342347	et	4	main
aga	doc_366216787879_item	2342356	et	3	main
aastate	doc_366216787879_item	2342361	et	3	main
muutunud	doc_366216787879_item	2342365	et	4	main
eestlaste	doc_366216787879_item	2342366	et	4	main
hulgas	doc_366216787879_item	2342367	et	4	main
massiharrastuseks	doc_366216787879_item	2342368	et	3	main
mis	doc_366216787879_item	2342369	et	4	main
peoga	doc_366216787879_item	2342377	et	4	main
sündmusi	doc_366216787879_item	2342386	et	3	main
elus	doc_366216787879_item	2342388	et	4	main
samas	doc_366216787879_item	2342389	et	4	main
võib	doc_366216787879_item	2342390	et	3	main
ka	doc_366216787879_item	2342391	et	3	main
see	doc_366216787879_item	2342392	et	3	main
ning	doc_366216787879_item	2342424	et	3	main
selle	doc_366216787879_item	2342425	et	4	main
inimesed	doc_366216787879_item	2342434	et	3	main
rahvalaulu	doc_366216787879_item	2342439	et	4	main
kajastavad	doc_366216787879_item	2342445	et	4	main
on	doc_366216787879_item	2342448	et	4	main
oli	doc_366216787879_item	2342023	et	3	main
ajalugu	doc_366216787879_item	2342038	et	4	main
ajaloost	doc_366216787879_item	2342049	et	4	main
regivärsilised	doc_366216787879_item	2342054	et	4	main
kui	doc_366216787879_item	2342060	et	3	main
mida	doc_366216787879_item	2342069	et	4	main
kuuleb	doc_366216787879_item	2342071	et	3	main
ning	doc_366216787879_item	2342072	et	3	main
seetõttu	doc_366216787879_item	2342073	et	3	main
nende	doc_366216787879_item	2342074	et	4	main
sisu	doc_366216787879_item	2342075	et	4	main
tempo	doc_366216787879_item	2342076	et	4	main
ning	doc_366216787879_item	2342077	et	3	main
tuju	doc_366216787879_item	2342078	et	4	main
peab	doc_366216787879_item	2342079	et	4	main
kajastama	doc_366216787879_item	2342080	et	3	main
rahuolu	doc_366216787879_item	2342081	et	4	main
armastust	doc_366216787879_item	2342082	et	4	main
ning	doc_366216787879_item	2342083	et	3	main
kindluse	doc_366216787879_item	2342084	et	4	main
tunnet	doc_366216787879_item	2342085	et	3	main
vanasti	doc_366216787879_item	2342086	et	3	main
lauldi	doc_366216787879_item	2342087	et	3	main
emad	doc_366216787879_item	2342088	et	3	main
lapsele	doc_366216787879_item	2342089	et	4	main
laulud	doc_366216787879_item	2342090	et	3	main
rinnaga	doc_366216787879_item	2342091	et	3	main
toites	doc_366216787879_item	2342092	et	4	main
kiigutade	doc_366216787879_item	2342093	et	4	main
ning	doc_366216787879_item	2342094	et	3	main
rahustades	doc_366216787879_item	2342095	et	3	main
nende	doc_366216787879_item	2342096	et	4	main
hingest	doc_366216787879_item	2342047	et	4	main
elust	doc_366216787879_item	2342048	et	3	main
arhailised	doc_366216787879_item	2342058	et	3	main
riim	doc_366216787879_item	2342061	et	3	main
on	doc_366216787879_item	2342067	et	4	main
kiideti	doc_366216787879_item	2342102	et	3	main
armastati	doc_366216787879_item	2342103	et	3	main
muud	doc_366216787879_item	2342108	et	4	main
vanal	doc_366216787879_item	2342111	et	3	main
andmine	doc_366216787879_item	2342116	et	4	main
karjas	doc_366216787879_item	2342117	et	3	main
laulu	doc_366216787879_item	2342120	et	4	main
üksteisele	doc_366216787879_item	2342124	et	3	main
mehed	doc_366216787879_item	2342129	et	3	main
naised	doc_366216787879_item	2342131	et	3	main
naiste	doc_366216787879_item	2342133	et	3	main
oli	doc_366216787879_item	2342135	et	3	main
meeste	doc_366216787879_item	2342140	et	4	main
meeste	doc_366216787879_item	2342151	et	4	main
ritooriliste	doc_366216787879_item	2342156	et	4	main
vanade	doc_366216787879_item	2342159	et	3	main
rahvalaulude	doc_366216787879_item	2342166	et	3	main
isegi	doc_366216787879_item	2342168	et	4	main
jooksul	doc_366216787879_item	2342170	et	4	main
peeti	doc_366216787879_item	2342171	et	4	main
alati	doc_366216787879_item	2342178	et	4	main
eeslauljaga	doc_366216787879_item	2342179	et	3	main
vahest	doc_366216787879_item	2342180	et	4	main
eeslaulja	doc_366216787879_item	2342186	et	4	main
regivärsiliste	doc_366216787879_item	2342189	et	4	main
on	doc_366216787879_item	2342192	et	4	main
ilma	doc_366216787879_item	2342194	et	4	main
oli	doc_366216787879_item	2342207	et	3	main
all	doc_366216787879_item	2342212	et	3	main
laulmise	doc_366216787879_item	2342236	et	4	main
kaasnes	doc_366216787879_item	2342238	et	3	main
ka	doc_366216787879_item	2342239	et	3	main
mõjusid	doc_366216787879_item	2342243	et	4	main
traditsioonid	doc_366216787879_item	2342246	et	3	main
levikuga	doc_366216787879_item	2342255	et	3	main
kerge	doc_366216787879_item	2342303	et	4	main
sai	doc_366216787879_item	2342313	et	4	main
kuukaks	doc_366216787879_item	2342314	et	3	main
et	doc_366216787879_item	2342318	et	3	main
vaid	doc_366216787879_item	2342338	et	3	main
näha	doc_366216787879_item	2342348	et	3	main
meeskooride	doc_366216787879_item	2342351	et	4	main
ka	doc_366216787879_item	2342353	et	3	main
hiljem	doc_366216787879_item	2342355	et	3	main
lastekoorid	doc_366216787879_item	2342357	et	3	main
jooksul	doc_366216787879_item	2342362	et	4	main
iga	doc_366216787879_item	2342376	et	4	main
eestiline	doc_366216787879_item	2342379	et	3	main
laulupidu	doc_366216787879_item	2342380	et	4	main
ka	doc_366216787879_item	2342382	et	3	main
tänapäeval	doc_366216787879_item	2342383	et	3	main
protestida	doc_366216787879_item	2342427	et	3	main
võimu	doc_366216787879_item	2342429	et	4	main
revolutsiooni	doc_366216787879_item	2342432	et	4	main
ajal	doc_366216787879_item	2342433	et	4	main
toetades	doc_366216787879_item	2342437	et	3	main
rahva	doc_366216787879_item	2342443	et	3	main
igal	doc_366216787879_item	2342446	et	3	main
läbi	doc_366216787879_item	2342449	et	4	main
viidud	doc_366216787879_item	2342450	et	4	main
kaota	doc_366216787879_item	2342457	et	4	main
huvi	doc_366216787879_item	2342461	et	4	main
näha	doc_366216787879_item	2342469	et	3	main
rahvalaulude	doc_366216787879_item	2342482	et	3	main
iga	doc_366216787879_item	2342488	et	4	main
toob	doc_366216787879_item	2342490	et	3	main
ning	doc_366216787879_item	2342494	et	3	main
annabgi	doc_366216787879_item	2342496	et	4	main
neile	doc_366216787879_item	2342497	et	4	main
kui	doc_366216787880_item	2342504	et	3	main
test	doc_366216787880_item	2342507	et	3	main
ja	doc_366216787880_item	2342526	et	3	main
tuginema	doc_366216787880_item	2342528	et	3	main
lugemistekstis	doc_366216787880_item	2342531	et	3	main
on	doc_366216787880_item	2342540	et	4	main
olnud	doc_366216787880_item	2342541	et	4	main
sisu	doc_366216787879_item	2342097	et	4	main
oli	doc_366216787879_item	2342098	et	3	main
väga	doc_366216787879_item	2342099	et	3	main
armastusrohke	doc_366216787879_item	2342100	et	4	main
turvatunnet	doc_366216787879_item	2342107	et	3	main
oli	doc_366216787879_item	2342113	et	3	main
käimise	doc_366216787879_item	2342118	et	4	main
sõnumit	doc_366216787879_item	2342125	et	3	main
nii	doc_366216787879_item	2342128	et	3	main
ikkagi	doc_366216787879_item	2342136	et	4	main
see	doc_366216787879_item	2342147	et	3	main
igapäevast	doc_366216787879_item	2342149	et	4	main
laulude	doc_366216787879_item	2342160	et	3	main
tantsimise	doc_366216787879_item	2342169	et	4	main
rütmi	doc_366216787879_item	2342173	et	4	main
mis	doc_366216787879_item	2342184	et	4	main
kordas	doc_366216787879_item	2342185	et	3	main
sõnumit	doc_366216787879_item	2342187	et	3	main
üks	doc_366216787879_item	2342188	et	3	main
laulude	doc_366216787879_item	2342190	et	3	main
saateta	doc_366216787879_item	2342196	et	3	main
ning	doc_366216787879_item	2342200	et	3	main
eesti	doc_366216787879_item	2342203	et	4	main
kuna	doc_366216787879_item	2342205	et	3	main
mõju	doc_366216787879_item	2342211	et	4	main
ilmusid	doc_366216787879_item	2342221	et	4	main
kirikumuusika	doc_366216787879_item	2342223	et	4	main
leviga	doc_366216787879_item	2342224	et	3	main
koorid	doc_366216787879_item	2342226	et	4	main
väljaspool	doc_366216787879_item	2342232	et	3	main
eriti	doc_366216787879_item	2342247	et	3	main
piiripealsetes	doc_366216787879_item	2342248	et	4	main
19	doc_366216787879_item	2342250	et	2	main
koos	doc_366216787879_item	2342252	et	4	main
riimilised	doc_366216787879_item	2342257	et	4	main
on	doc_366216787879_item	2342261	et	4	main
laule	doc_366216787879_item	2342268	et	4	main
tihtipeale	doc_366216787879_item	2342269	et	3	main
lauldi	doc_366216787879_item	2342270	et	3	main
pillisaatega	doc_366216787879_item	2342271	et	3	main
kõik	doc_366216787879_item	2342272	et	4	main
see	doc_366216787879_item	2342299	et	3	main
rõõmus	doc_366216787879_item	2342301	et	4	main
ning	doc_366216787879_item	2342302	et	3	main
just	doc_366216787879_item	2342315	et	3	main
valitsejate	doc_366216787879_item	2342327	et	4	main
vaatamata	doc_366216787879_item	2342330	et	4	main
on	doc_366216787879_item	2342332	et	4	main
laulupeo	doc_366216787879_item	2342333	et	4	main
traditsioon	doc_366216787879_item	2342334	et	3	main
mitte	doc_366216787879_item	2342335	et	3	main
üldlaulupidade	doc_366216787879_item	2342344	et	4	main
ajaloo	doc_366216787879_item	2342345	et	4	main
lisandusid	doc_366216787879_item	2342350	et	4	main
traditsioonile	doc_366216787879_item	2342352	et	3	main
naiskoorid	doc_366216787879_item	2342354	et	3	main
poistekoorid	doc_366216787879_item	2342359	et	3	main
toob	doc_366216787879_item	2342370	et	3	main
ellu	doc_366216787879_item	2342373	et	4	main
ning	doc_366216787879_item	2342374	et	3	main
kaasneb	doc_366216787879_item	2342375	et	3	main
on	doc_366216787879_item	2342381	et	4	main
kultuurses	doc_366216787879_item	2342387	et	3	main
olla	doc_366216787879_item	2342393	et	3	main
abil	doc_366216787879_item	2342426	et	4	main
öölaulupeol	doc_366216787879_item	2342436	et	4	main
eesti	doc_366216787879_item	2342442	et	4	main
ei	doc_366216787879_item	2342456	et	4	main
ka	doc_366216787879_item	2342460	et	3	main
mis	doc_366216787879_item	2342472	et	4	main
huvitavaks	doc_366216787879_item	2342474	et	4	main
et	doc_366216787879_item	2342481	et	3	main
aga	doc_366216787879_item	2342487	et	3	main
voimalust	doc_366216787879_item	2342498	et	4	main
essee	doc_366216787880_item	2342501	et	4	main
teise	doc_366216787880_item	2342505	et	4	main
esitatud	doc_366216787880_item	2342532	et	4	main
aitab	doc_366216787880_item	2342548	et	3	main
väljendada	doc_366216787880_item	2342552	et	3	main
eestlasi	doc_366216787880_item	2342558	et	3	main
laulu	doc_366216787880_item	2342571	et	4	main
laulmine	doc_366216787879_item	2342134	et	4	main
omaga	doc_366216787879_item	2342141	et	3	main
naiste	doc_366216787879_item	2342142	et	3	main
elu	doc_366216787879_item	2342150	et	4	main
oli	doc_366216787879_item	2342154	et	3	main
ajal	doc_366216787879_item	2342158	et	4	main
rütm	doc_366216787879_item	2342161	et	3	main
aeglasem	doc_366216787879_item	2342163	et	4	main
tänapäeva	doc_366216787879_item	2342165	et	4	main
aeglasemat	doc_366216787879_item	2342172	et	4	main
ka	doc_366216787879_item	2342182	et	3	main
tunnuseks	doc_366216787879_item	2342191	et	3	main
pilli	doc_366216787879_item	2342195	et	4	main
möödus	doc_366216787879_item	2342199	et	3	main
eesti	doc_366216787879_item	2342206	et	4	main
teiste	doc_366216787879_item	2342209	et	4	main
rahvuste	doc_366216787879_item	2342210	et	3	main
see	doc_366216787879_item	2342215	et	3	main
mitte	doc_366216787879_item	2342216	et	3	main
kajastuda	doc_366216787879_item	2342217	et	3	main
ka	doc_366216787879_item	2342218	et	3	main
rahvamuusikas	doc_366216787879_item	2342219	et	3	main
alguses	doc_366216787879_item	2342220	et	4	main
või	doc_366216787879_item	2342229	et	4	main
ka	doc_366216787879_item	2342230	et	3	main
kiriku	doc_366216787879_item	2342233	et	3	main
asutamine	doc_366216787879_item	2342241	et	4	main
kirjaoskuse	doc_366216787879_item	2342254	et	3	main
mille	doc_366216787879_item	2342259	et	3	main
tunnuseks	doc_366216787879_item	2342260	et	3	main
neid	doc_366216787879_item	2342267	et	4	main
sündmused	doc_366216787879_item	2342274	et	3	main
koos	doc_366216787879_item	2342275	et	4	main
need	doc_366216787879_item	2342273	et	3	main
teiste	doc_366216787879_item	2342276	et	4	main
teguritega	doc_366216787879_item	2342277	et	3	main
tähendasid	doc_366216787879_item	2342278	et	4	main
eestlaste	doc_366216787879_item	2342279	et	4	main
rahvuslikku	doc_366216787879_item	2342280	et	4	main
ärkamist	doc_366216787879_item	2342281	et	4	main
19	doc_366216787879_item	2342282	et	2	main
sajandi	doc_366216787879_item	2342283	et	3	main
lõpus	doc_366216787879_item	2342284	et	4	main
ärkamise	doc_366216787879_item	2342285	et	4	main
tulemuseks	doc_366216787879_item	2342286	et	3	main
laulude	doc_366216787879_item	2342287	et	3	main
ajaloos	doc_366216787879_item	2342288	et	4	main
on	doc_366216787879_item	2342289	et	4	main
ülemaalise	doc_366216787879_item	2342290	et	4	main
laulupeo	doc_366216787879_item	2342291	et	4	main
ilmumine	doc_366216787879_item	2342292	et	4	main
laulupidade	doc_366216787879_item	2342293	et	4	main
traditsioon	doc_366216787879_item	2342294	et	3	main
oli	doc_366216787879_item	2342295	et	3	main
pikk	doc_366216787879_item	2342296	et	4	main
aga	doc_366216787879_item	2342297	et	3	main
alati	doc_366216787879_item	2342300	et	4	main
venemaa	doc_366216787879_item	2342306	et	4	main
laulupidade	doc_366216787879_item	2342310	et	4	main
viimine	doc_366216787879_item	2342312	et	4	main
selle	doc_366216787879_item	2342316	et	4	main
rahvusliku	doc_366216787879_item	2342319	et	3	main
nõukogude	doc_366216787879_item	2342308	et	3	main
identiteedi	doc_366216787879_item	2342320	et	4	main
heaks	doc_366216787879_item	2342325	et	4	main
kiidetud	doc_366216787879_item	2342326	et	4	main
ainult	doc_366216787879_item	2342336	et	4	main
säilinud	doc_366216787879_item	2342337	et	4	main
kuidas	doc_366216787879_item	2342349	et	3	main
nende	doc_366216787879_item	2342360	et	4	main
on	doc_366216787879_item	2342364	et	4	main
rõõmu	doc_366216787879_item	2342371	et	4	main
igapäevasse	doc_366216787879_item	2342372	et	4	main
üks	doc_366216787879_item	2342384	et	3	main
kus	doc_366216787879_item	2342395	et	3	main
rahvuse	doc_366216787879_item	2342421	et	3	main
identiteedi	doc_366216787879_item	2342423	et	4	main
üld	doc_366216787879_item	2342428	et	4	main
vastu	doc_366216787879_item	2342430	et	3	main
laulva	doc_366216787879_item	2342431	et	4	main
seisid	doc_366216787879_item	2342435	et	4	main
üksteise	doc_366216787879_item	2342438	et	4	main
abil	doc_366216787879_item	2342440	et	4	main
tänapäeval	doc_366216787879_item	2342441	et	3	main
raadios	doc_366216787879_item	2342454	et	3	main
laulu	doc_366216787879_item	2342464	et	4	main
vastu	doc_366216787879_item	2342465	et	3	main
seda	doc_366216787879_item	2342466	et	3	main
me	doc_366216787879_item	2342467	et	4	main
võime	doc_366216787879_item	2342468	et	4	main
eurovisioonil	doc_366216787879_item	2342471	et	3	main
sündmuseks	doc_366216787879_item	2342475	et	3	main
traditsioonid	doc_366216787879_item	2342483	et	3	main
on	doc_366216787879_item	2342484	et	4	main
eesti	doc_366216787880_item	2342502	et	4	main
kirjutage	doc_366216787880_item	2342509	et	3	main
faktidele	doc_366216787880_item	2342533	et	3	main
on	doc_366216787880_item	2342535	et	4	main
soovitatav	doc_366216787880_item	2342536	et	4	main
illustreerida	doc_366216787880_item	2342537	et	3	main
näidetega	doc_366216787880_item	2342538	et	3	main
laul	doc_366216787880_item	2342539	et	4	main
ja	doc_366216787880_item	2342551	et	3	main
aeg	doc_366216787880_item	2342560	et	3	main
laul	doc_366216787880_item	2342562	et	4	main
esialgu	doc_366216787880_item	2342563	et	3	main
lauldi	doc_366216787880_item	2342564	et	3	main
kõike	doc_366216787880_item	2342565	et	4	main
mida	doc_366216787880_item	2342566	et	4	main
tehti	doc_366216787880_item	2342567	et	3	main
karjamaal	doc_366216787880_item	2342576	et	4	main
algul	doc_366216787880_item	2342613	et	4	main
kirikus	doc_366216787880_item	2342614	et	3	main
ja	doc_366216787880_item	2342615	et	3	main
koorilaulu	doc_366216787880_item	2342620	et	4	main
levikuga	doc_366216787880_item	2342621	et	3	main
puhkpilliorkestrite	doc_366216787880_item	2342624	et	3	main
mis	doc_366216787880_item	2342626	et	4	main
ka	doc_366216787880_item	2342628	et	3	main
venelased	doc_366216787880_item	2342639	et	3	main
ja	doc_366216787880_item	2342641	et	3	main
paljud	doc_366216787880_item	2342642	et	3	main
kaasa	doc_366216787880_item	2342648	et	4	main
trükkima	doc_366216787880_item	2342662	et	3	main
laul	doc_366216787880_item	2342667	et	4	main
üks	doc_366216787880_item	2342669	et	3	main
rahva	doc_366216787880_item	2342671	et	3	main
rahvuslik	doc_366216787880_item	2342672	et	3	main
tunnustamise	doc_366216787880_item	2342679	et	4	main
väljendasid	doc_366216787880_item	2342686	et	4	main
uhkust	doc_366216787880_item	2342688	et	4	main
välja	doc_366216787879_item	2342321	et	4	main
poolt	doc_366216787879_item	2342328	et	4	main
raskustele	doc_366216787879_item	2342331	et	4	main
ka	doc_366216787879_item	2342339	et	3	main
kasvanud	doc_366216787879_item	2342340	et	4	main
ning	doc_366216787879_item	2342341	et	3	main
õitsema	doc_366216787879_item	2342342	et	3	main
ning	doc_366216787879_item	2342358	et	3	main
koorilaul	doc_366216787879_item	2342363	et	4	main
üli	doc_366216787879_item	2342378	et	4	main
oodatavamaid	doc_366216787879_item	2342385	et	4	main
perepidu	doc_366216787879_item	2342394	et	4	main
käiakse	doc_366216787879_item	2342396	et	3	main
kõik	doc_366216787879_item	2342397	et	4	main
koos	doc_366216787879_item	2342398	et	4	main
lootes	doc_366216787879_item	2342399	et	4	main
tuttavaid	doc_366216787879_item	2342400	et	3	main
näha	doc_366216787879_item	2342401	et	3	main
ning	doc_366216787879_item	2342402	et	3	main
nautida	doc_366216787879_item	2342403	et	3	main
laulmist	doc_366216787879_item	2342404	et	4	main
sajandi	doc_366216787879_item	2342406	et	3	main
lõpus	doc_366216787879_item	2342407	et	4	main
20	doc_366216787879_item	2342405	et	2	main
ilmusid	doc_366216787879_item	2342408	et	4	main
rahvuslikud	doc_366216787879_item	2342409	et	3	main
ning	doc_366216787879_item	2342410	et	3	main
folklöör	doc_366216787879_item	2342411	et	4	main
ansamblid	doc_366216787879_item	2342412	et	3	main
näiteks	doc_366216787879_item	2342413	et	4	main
leigarid	doc_366216787879_item	2342414	et	4	main
nõukogu	doc_366216787879_item	2342415	et	4	main
ansamblite	doc_366216787879_item	2342417	et	3	main
ajal	doc_366216787879_item	2342416	et	4	main
abil	doc_366216787879_item	2342418	et	4	main
püüdsid	doc_366216787879_item	2342419	et	4	main
säilitada	doc_366216787879_item	2342420	et	3	main
enesehinnanguid	doc_366216787879_item	2342422	et	3	main
laulutraditsioonid	doc_366216787879_item	2342444	et	3	main
pool	doc_366216787879_item	2342447	et	4	main
mitmekesised	doc_366216787879_item	2342451	et	4	main
konkursid	doc_366216787879_item	2342452	et	3	main
samas	doc_366216787879_item	2342455	et	4	main
rahvas	doc_366216787879_item	2342459	et	4	main
teiste	doc_366216787879_item	2342462	et	4	main
rahvade	doc_366216787879_item	2342463	et	4	main
kasvõi	doc_366216787879_item	2342470	et	3	main
kokkuvõttes	doc_366216787879_item	2342478	et	3	main
võime	doc_366216787879_item	2342479	et	4	main
oelda	doc_366216787879_item	2342480	et	4	main
vanad	doc_366216787879_item	2342486	et	3	main
aasta	doc_366216787879_item	2342489	et	4	main
nooremaks	doc_366216787879_item	2342499	et	4	main
keele	doc_366216787880_item	2342503	et	4	main
kirjutamine	doc_366216787880_item	2342508	et	4	main
eestlastest	doc_366216787880_item	2342514	et	4	main
laulurahva	doc_366216787880_item	2342515	et	3	main
essee	doc_366216787880_item	2342516	et	4	main
pikkus	doc_366216787880_item	2342517	et	4	main
300	doc_366216787880_item	2342518	et	2	main
350	doc_366216787880_item	2342519	et	2	main
sõna	doc_366216787880_item	2342520	et	4	main
televisioonis	doc_366216787879_item	2342453	et	4	main
eesti	doc_366216787879_item	2342458	et	4	main
sai	doc_366216787879_item	2342473	et	4	main
kultuurses	doc_366216787879_item	2342476	et	3	main
elus	doc_366216787879_item	2342477	et	4	main
väga	doc_366216787879_item	2342485	et	3	main
neile	doc_366216787879_item	2342491	et	4	main
uue	doc_366216787879_item	2342492	et	3	main
külje	doc_366216787879_item	2342493	et	3	main
see	doc_366216787879_item	2342495	et	3	main
jääda	doc_366216787879_item	2342500	et	4	main
keele	doc_366216787880_item	2342506	et	4	main
essee	doc_366216787880_item	2342510	et	4	main
teemal	doc_366216787880_item	2342511	et	3	main
mis	doc_366216787880_item	2342512	et	4	main
teeb	doc_366216787880_item	2342513	et	3	main
essee	doc_366216787880_item	2342521	et	4	main
olema	doc_366216787880_item	2342523	et	4	main
üldistav	doc_366216787880_item	2342527	et	4	main
ja	doc_366216787880_item	2342530	et	3	main
väiteid	doc_366216787880_item	2342534	et	4	main
teha	doc_366216787880_item	2342549	et	3	main
oma	doc_366216787880_item	2342553	et	4	main
nii	doc_366216787880_item	2342555	et	3	main
ka	doc_366216787880_item	2342557	et	3	main
saatnud	doc_366216787880_item	2342561	et	4	main
tegevus	doc_366216787880_item	2342569	et	4	main
põllul	doc_366216787880_item	2342573	et	3	main
suuliselt	doc_366216787880_item	2342606	et	4	main
vaimulike	doc_366216787880_item	2342609	et	3	main
laulmine	doc_366216787880_item	2342611	et	4	main
pärast	doc_366216787880_item	2342616	et	4	main
väljaspoolt	doc_366216787880_item	2342618	et	4	main
kaasnes	doc_366216787880_item	2342622	et	3	main
piduõhtutel	doc_366216787880_item	2342630	et	3	main
laiemale	doc_366216787880_item	2342650	et	4	main
hakati	doc_366216787880_item	2342652	et	3	main
ja	doc_366216787880_item	2342654	et	3	main
algul	doc_366216787880_item	2342656	et	4	main
kirjutama	doc_366216787880_item	2342659	et	3	main
ka	doc_366216787880_item	2342661	et	3	main
näitab	doc_366216787880_item	2342665	et	3	main
eesti	doc_366216787880_item	2342670	et	4	main
identiteet	doc_366216787880_item	2342673	et	4	main
tsari	doc_366216787880_item	2342681	et	4	main
eesti	doc_366216787880_item	2342683	et	4	main
vabariigi	doc_366216787880_item	2342684	et	3	main
ja	doc_366216787880_item	2342689	et	3	main
oma	doc_366216787880_item	2342702	et	4	main
koos	doc_366216787880_item	2342722	et	4	main
ja	doc_366216787880_item	2342724	et	3	main
sõnad	doc_366216787880_item	2342726	et	4	main
kaasa	doc_366216787880_item	2342730	et	4	main
sul	doc_366216787880_item	2342733	et	3	main
sellist	doc_366216787880_item	2342744	et	4	main
esine	doc_366216787880_item	2342748	et	4	main
traditsioon	doc_366216787880_item	2342752	et	3	main
lapsed	doc_366216787880_item	2342757	et	3	main
muusika	doc_366216787880_item	2342762	et	4	main
ja	doc_366216787880_item	2342771	et	3	main
kestab	doc_366216787880_item	2342775	et	4	main
näha	doc_366216787880_item	2342777	et	3	main
väga	doc_366216787880_item	2342784	et	3	main
palju	doc_366216787880_item	2342785	et	4	main
noori	doc_366216787880_item	2342786	et	3	main
inimesi	doc_366216787880_item	2342787	et	4	main
on	doc_366216787880_item	2342790	et	4	main
oskusi	doc_366216787880_item	2342801	et	3	main
ja	doc_366216787880_item	2342803	et	3	main
mujal	doc_366216787880_item	2342805	et	3	main
keele	doc_366216787881_item	2342831	et	4	main
kui	doc_366216787881_item	2342832	et	3	main
teise	doc_366216787881_item	2342833	et	4	main
mis	doc_366216787881_item	2342840	et	4	main
pikkus	doc_366216787881_item	2342845	et	4	main
essee	doc_366216787881_item	2342849	et	4	main
üldistav	doc_366216787881_item	2342855	et	4	main
ja	doc_366216787881_item	2342858	et	3	main
on	doc_366216787881_item	2342863	et	4	main
illustreerida	doc_366216787881_item	2342865	et	3	main
näidetega	doc_366216787881_item	2342866	et	3	main
eestlased	doc_366216787881_item	2342867	et	3	main
peab	doc_366216787880_item	2342522	et	4	main
arutlev	doc_366216787880_item	2342524	et	4	main
analüüsiv	doc_366216787880_item	2342525	et	4	main
loengus	doc_366216787880_item	2342529	et	3	main
eluosana	doc_366216787880_item	2342543	et	3	main
juba	doc_366216787880_item	2342544	et	3	main
tööd	doc_366216787880_item	2342550	et	4	main
kogu	doc_366216787880_item	2342559	et	4	main
käis	doc_366216787880_item	2342570	et	4	main
saatel	doc_366216787880_item	2342572	et	4	main
käsitööd	doc_366216787880_item	2342577	et	4	main
tehes	doc_366216787880_item	2342578	et	3	main
ja	doc_366216787880_item	2342579	et	3	main
lapsi	doc_366216787880_item	2342580	et	4	main
kussütades	doc_366216787880_item	2342581	et	4	main
pulmi	doc_366216787880_item	2342582	et	4	main
pidades	doc_366216787880_item	2342583	et	3	main
ja	doc_366216787880_item	2342584	et	3	main
matuseid	doc_366216787880_item	2342585	et	3	main
samuti	doc_366216787880_item	2342586	et	3	main
püüti	doc_366216787880_item	2342587	et	3	main
jäljendada	doc_366216787880_item	2342588	et	3	main
ja	doc_366216787880_item	2342590	et	3	main
lindude	doc_366216787880_item	2342591	et	4	main
loomade	doc_366216787880_item	2342589	et	4	main
hääli	doc_366216787880_item	2342592	et	4	main
sel	doc_366216787880_item	2342593	et	3	main
ajal	doc_366216787880_item	2342594	et	4	main
laulud	doc_366216787880_item	2342595	et	3	main
olid	doc_366216787880_item	2342596	et	4	main
aeglased	doc_366216787880_item	2342597	et	3	main
neid	doc_366216787880_item	2342598	et	4	main
lauldi	doc_366216787880_item	2342599	et	3	main
ka	doc_366216787880_item	2342600	et	3	main
mitmekesi	doc_366216787880_item	2342601	et	3	main
neid	doc_366216787880_item	2342602	et	4	main
pärandati	doc_366216787880_item	2342603	et	4	main
põlvest	doc_366216787880_item	2342604	et	4	main
inimese	doc_366216787880_item	2342542	et	4	main
tuhandeid	doc_366216787880_item	2342545	et	3	main
aastaid	doc_366216787880_item	2342546	et	4	main
laul	doc_366216787880_item	2342547	et	4	main
emotsioone	doc_366216787880_item	2342554	et	3	main
on	doc_366216787880_item	2342556	et	4	main
kogu	doc_366216787880_item	2342568	et	4	main
ristiusuga	doc_366216787880_item	2342607	et	3	main
ka	doc_366216787880_item	2342617	et	3	main
kirikut	doc_366216787880_item	2342619	et	3	main
aidas	doc_366216787880_item	2342574	et	3	main
metsas	doc_366216787880_item	2342575	et	3	main
kaasnes	doc_366216787880_item	2342608	et	3	main
mängisid	doc_366216787880_item	2342629	et	4	main
kirjaoskus	doc_366216787880_item	2342646	et	3	main
laulude	doc_366216787880_item	2342649	et	3	main
laulikuid	doc_366216787880_item	2342653	et	3	main
käsitsi	doc_366216787880_item	2342657	et	3	main
hiljem	doc_366216787880_item	2342660	et	3	main
kõik	doc_366216787880_item	2342664	et	4	main
et	doc_366216787880_item	2342666	et	3	main
on	doc_366216787880_item	2342668	et	4	main
ajal	doc_366216787880_item	2342682	et	4	main
vene	doc_366216787880_item	2342691	et	4	main
kutsuvad	doc_366216787880_item	2342727	et	4	main
pisar	doc_366216787880_item	2342728	et	3	main
häält	doc_366216787880_item	2342736	et	3	main
need	doc_366216787880_item	2342738	et	3	main
teevad	doc_366216787880_item	2342740	et	3	main
laulu	doc_366216787880_item	2342745	et	4	main
ei	doc_366216787880_item	2342747	et	4	main
teistel	doc_366216787880_item	2342749	et	4	main
õpivad	doc_366216787880_item	2342758	et	3	main
laule	doc_366216787880_item	2342760	et	4	main
laulutraditsioon	doc_366216787880_item	2342774	et	3	main
just	doc_366216787880_item	2342778	et	3	main
uhke	doc_366216787880_item	2342791	et	4	main
demonstreerimas	doc_366216787880_item	2342799	et	3	main
kus	doc_366216787880_item	2342807	et	3	main
põlve	doc_366216787880_item	2342605	et	4	main
laulude	doc_366216787880_item	2342610	et	3	main
kooris	doc_366216787880_item	2342612	et	4	main
ka	doc_366216787880_item	2342623	et	3	main
tekkimine	doc_366216787880_item	2342625	et	4	main
hiljem	doc_366216787880_item	2342627	et	3	main
laulutraditsiooni	doc_366216787880_item	2342634	et	4	main
mõjutasid	doc_366216787880_item	2342635	et	4	main
ka	doc_366216787880_item	2342636	et	3	main
naabrid	doc_366216787880_item	2342637	et	3	main
näiteks	doc_366216787880_item	2342638	et	4	main
aitas	doc_366216787880_item	2342647	et	3	main
see	doc_366216787880_item	2342663	et	3	main
laulu	doc_366216787880_item	2342674	et	4	main
kaudu	doc_366216787880_item	2342675	et	3	main
eestlased	doc_366216787880_item	2342676	et	3	main
võitlesid	doc_366216787880_item	2342677	et	4	main
oma	doc_366216787880_item	2342678	et	4	main
ajal	doc_366216787880_item	2342685	et	4	main
rahva	doc_366216787880_item	2342687	et	3	main
laulu	doc_366216787880_item	2342725	et	4	main
silmis	doc_366216787880_item	2342729	et	4	main
laulu	doc_366216787880_item	2342735	et	4	main
laulupeod	doc_366216787880_item	2342739	et	4	main
traditsiooni	doc_366216787880_item	2342746	et	4	main
rahvastel	doc_366216787880_item	2342750	et	4	main
see	doc_366216787880_item	2342751	et	3	main
tänapäeva	doc_366216787880_item	2342756	et	4	main
koolis	doc_366216787880_item	2342761	et	4	main
neid	doc_366216787880_item	2342764	et	4	main
kuulda	doc_366216787880_item	2342766	et	4	main
ka	doc_366216787880_item	2342767	et	3	main
raadiost	doc_366216787880_item	2342768	et	3	main
oma	doc_366216787880_item	2342792	et	4	main
üle	doc_366216787880_item	2342795	et	3	main
oma	doc_366216787880_item	2342800	et	4	main
festivaalidel	doc_366216787880_item	2342802	et	4	main
konkursitel	doc_366216787880_item	2342804	et	4	main
tunnustust	doc_366216787880_item	2342812	et	4	main
essee	doc_366216787881_item	2342829	et	4	main
eesti	doc_366216787881_item	2342830	et	4	main
laulurahva	doc_366216787881_item	2342843	et	3	main
tuginema	doc_366216787881_item	2342856	et	3	main
faktidele	doc_366216787881_item	2342861	et	3	main
väiteid	doc_366216787881_item	2342862	et	4	main
soovitatav	doc_366216787881_item	2342864	et	4	main
aastat	doc_366216787881_item	2342901	et	3	main
nad	doc_366216787881_item	2342906	et	3	main
tegid	doc_366216787881_item	2342910	et	4	main
lauluga	doc_366216787881_item	2342913	et	4	main
kokku	doc_366216787881_item	2342915	et	3	main
loomi	doc_366216787881_item	2342916	et	4	main
kui	doc_366216787881_item	2342917	et	3	main
käidi	doc_366216787881_item	2342918	et	3	main
karjades	doc_366216787881_item	2342919	et	3	main
kui	doc_366216787881_item	2342920	et	3	main
kui	doc_366216787881_item	2342923	et	3	main
pulme	doc_366216787881_item	2342925	et	3	main
teisi	doc_366216787881_item	2342927	et	4	main
inimesed	doc_366216787881_item	2342930	et	3	main
nad	doc_366216787881_item	2342938	et	3	main
oma	doc_366216787881_item	2342940	et	4	main
kultuuri	doc_366216787881_item	2342941	et	4	main
põlvest	doc_366216787881_item	2342948	et	4	main
suuliselt	doc_366216787881_item	2342950	et	4	main
eestimaal	doc_366216787881_item	2342951	et	4	main
1869	doc_366216787881_item	2342952	et	2	main
unikaalne	doc_366216787881_item	2342956	et	3	main
kultuuridest	doc_366216787881_item	2342970	et	3	main
kokku	doc_366216787881_item	2342979	et	3	main
ei	doc_366216787881_item	2342987	et	4	main
hoida	doc_366216787881_item	2342991	et	3	main
tantsivad	doc_366216787881_item	2342995	et	4	main
kuulajad	doc_366216787881_item	2342996	et	4	main
laulavad	doc_366216787881_item	2342997	et	4	main
jne	doc_366216787881_item	2343021	et	4	main
laulavad	doc_366216787881_item	2343023	et	4	main
laulud	doc_366216787881_item	2343036	et	3	main
kultuurist	doc_366216787881_item	2343058	et	3	main
ja	doc_366216787881_item	2343059	et	3	main
teada	doc_366216787881_item	2343061	et	3	main
tantsu	doc_366216787880_item	2342631	et	4	main
saateks	doc_366216787880_item	2342632	et	3	main
eestlaste	doc_366216787880_item	2342633	et	4	main
sakslased	doc_366216787880_item	2342640	et	3	main
teised	doc_366216787880_item	2342643	et	4	main
ki	doc_366216787880_item	2342644	et	4	main
üldine	doc_366216787880_item	2342645	et	4	main
levikule	doc_366216787880_item	2342651	et	3	main
salmikuid	doc_366216787880_item	2342655	et	4	main
ümber	doc_366216787880_item	2342658	et	3	main
eest	doc_366216787880_item	2342680	et	4	main
vabadust	doc_366216787880_item	2342690	et	4	main
ajal	doc_366216787880_item	2342692	et	4	main
oli	doc_366216787880_item	2342693	et	3	main
võimalus	doc_366216787880_item	2342694	et	3	main
jalle	doc_366216787880_item	2342695	et	4	main
saada	doc_366216787880_item	2342696	et	4	main
kokku	doc_366216787880_item	2342697	et	3	main
üldlaulupeo	doc_366216787880_item	2342698	et	4	main
ajal	doc_366216787880_item	2342699	et	4	main
et	doc_366216787880_item	2342700	et	3	main
väljendada	doc_366216787880_item	2342701	et	3	main
kokkukuuluvust	doc_366216787880_item	2342703	et	4	main
ja	doc_366216787880_item	2342704	et	3	main
isamaa	doc_366216787880_item	2342705	et	4	main
armastust	doc_366216787880_item	2342706	et	4	main
ma	doc_366216787880_item	2342707	et	3	main
määletan	doc_366216787880_item	2342708	et	4	main
ise	doc_366216787880_item	2342709	et	4	main
tallinna	doc_366216787880_item	2342710	et	4	main
lauluväljakul	doc_366216787880_item	2342711	et	3	main
laulupidu	doc_366216787880_item	2342712	et	4	main
see	doc_366216787880_item	2342713	et	3	main
oli	doc_366216787880_item	2342714	et	3	main
tunne	doc_366216787880_item	2342716	et	4	main
võimas	doc_366216787880_item	2342715	et	4	main
kui	doc_366216787880_item	2342717	et	3	main
kuuled	doc_366216787880_item	2342718	et	3	main
nii	doc_366216787880_item	2342719	et	3	main
palju	doc_366216787880_item	2342720	et	4	main
inimeesi	doc_366216787880_item	2342721	et	4	main
laulmas	doc_366216787880_item	2342723	et	3	main
laulma	doc_366216787880_item	2342731	et	3	main
just	doc_366216787880_item	2342737	et	3	main
laulurahva	doc_366216787880_item	2342743	et	3	main
kestab	doc_366216787880_item	2342753	et	4	main
aastasse	doc_366216787880_item	2342755	et	4	main
rahva	doc_366216787880_item	2342759	et	3	main
ja	doc_366216787880_item	2342769	et	3	main
eestirahva	doc_366216787880_item	2342773	et	3	main
on	doc_366216787880_item	2342776	et	4	main
üldlaulu	doc_366216787880_item	2342779	et	4	main
pidudel	doc_366216787880_item	2342780	et	4	main
kuigi	doc_366216787880_item	2342732	et	3	main
poole	doc_366216787880_item	2342734	et	4	main
ki	doc_366216787880_item	2342741	et	4	main
eestlastest	doc_366216787880_item	2342742	et	4	main
aastast	doc_366216787880_item	2342754	et	4	main
tundides	doc_366216787880_item	2342763	et	3	main
on	doc_366216787880_item	2342765	et	4	main
televisioonist	doc_366216787880_item	2342770	et	4	main
et	doc_366216787880_item	2342772	et	3	main
teeb	doc_366216787880_item	2342782	et	3	main
rahvas	doc_366216787880_item	2342789	et	4	main
traditsiooni	doc_366216787880_item	2342794	et	4	main
nende	doc_366216787880_item	2342796	et	4	main
esindajad	doc_366216787880_item	2342797	et	4	main
kaivad	doc_366216787880_item	2342798	et	4	main
on	doc_366216787880_item	2342808	et	4	main
saavutanud	doc_366216787880_item	2342810	et	4	main
suurt	doc_366216787880_item	2342811	et	3	main
kokku	doc_366216787880_item	2342813	et	3	main
võtteks	doc_366216787880_item	2342814	et	3	main
võib	doc_366216787880_item	2342815	et	3	main
öölda	doc_366216787880_item	2342816	et	4	main
et	doc_366216787880_item	2342817	et	3	main
eestlased	doc_366216787880_item	2342818	et	3	main
on	doc_366216787880_item	2342819	et	4	main
tõesti	doc_366216787880_item	2342820	et	3	main
tuginedes	doc_366216787880_item	2342822	et	3	main
traditsioonidele	doc_366216787880_item	2342824	et	3	main
see	doc_366216787880_item	2342825	et	3	main
eestlastest	doc_366216787881_item	2342842	et	4	main
300	doc_366216787881_item	2342846	et	2	main
loengus	doc_366216787881_item	2342857	et	3	main
ajaloole	doc_366216787881_item	2342896	et	4	main
tagasi	doc_366216787881_item	2342902	et	3	main
hakkasid	doc_366216787881_item	2342904	et	4	main
last	doc_366216787881_item	2342922	et	4	main
ja	doc_366216787881_item	2342926	et	3	main
sündmusi	doc_366216787881_item	2342928	et	3	main
ennem	doc_366216787881_item	2342929	et	4	main
sündis	doc_366216787881_item	2342955	et	3	main
laulupidu	doc_366216787881_item	2342959	et	4	main
see	doc_366216787881_item	2342971	et	3	main
vanad	doc_366216787881_item	2342977	et	3	main
oma	doc_366216787881_item	2342983	et	4	main
isegi	doc_366216787881_item	2342985	et	4	main
vihm	doc_366216787881_item	2342986	et	3	main
laulavad	doc_366216787881_item	2342993	et	4	main
kus	doc_366216787880_item	2342781	et	3	main
kaasa	doc_366216787880_item	2342783	et	4	main
eesti	doc_366216787880_item	2342788	et	4	main
laulu	doc_366216787880_item	2342793	et	4	main
maailmas	doc_366216787880_item	2342806	et	3	main
ka	doc_366216787880_item	2342809	et	3	main
laulurahvas	doc_366216787880_item	2342821	et	4	main
oma	doc_366216787880_item	2342823	et	4	main
on	doc_366216787880_item	2342826	et	4	main
eesti	doc_366216787880_item	2342827	et	4	main
keele	doc_366216787881_item	2342834	et	4	main
teeb	doc_366216787881_item	2342841	et	3	main
essee	doc_366216787881_item	2342844	et	4	main
350	doc_366216787881_item	2342847	et	2	main
sõna	doc_366216787881_item	2342848	et	4	main
analüüsiv	doc_366216787881_item	2342853	et	4	main
ja	doc_366216787881_item	2342854	et	3	main
esitatud	doc_366216787881_item	2342860	et	4	main
rohkem	doc_366216787881_item	2342898	et	4	main
tuhad	doc_366216787881_item	2342900	et	3	main
eestlased	doc_366216787881_item	2342903	et	3	main
laulma	doc_366216787881_item	2342905	et	3	main
hüüdi	doc_366216787881_item	2342914	et	4	main
elasid	doc_366216787881_item	2342931	et	4	main
ajaloo	doc_366216787881_item	2342942	et	4	main
muinasjutte	doc_366216787881_item	2342943	et	3	main
muistendeid	doc_366216787881_item	2342945	et	3	main
laulude	doc_366216787881_item	2342946	et	3	main
tartus	doc_366216787881_item	2342954	et	3	main
see	doc_366216787881_item	2342958	et	3	main
ühendab	doc_366216787881_item	2342960	et	3	main
teistest	doc_366216787881_item	2342969	et	4	main
ja	doc_366216787881_item	2342976	et	3	main
tulevad	doc_366216787881_item	2342978	et	4	main
ajalugu	doc_366216787881_item	2342984	et	4	main
kodus	doc_366216787881_item	2342990	et	4	main
ühed	doc_366216787881_item	2342992	et	3	main
teise	doc_366216787881_item	2343027	et	4	main
ja	doc_366216787881_item	2343029	et	3	main
puutuvad	doc_366216787881_item	2343037	et	4	main
koos	doc_366216787881_item	2343038	et	4	main
ajaga	doc_366216787881_item	2343039	et	3	main
noored	doc_366216787881_item	2343040	et	3	main
tunnevad	doc_366216787881_item	2343042	et	3	main
meie	doc_366216787881_item	2343057	et	4	main
ajaloost	doc_366216787881_item	2343060	et	4	main
laulurahvas	doc_366216787881_item	2343070	et	4	main
ja	doc_366216787881_item	2343079	et	3	main
nimi	doc_366216787881_item	2343086	et	3	main
otse	doc_366216787881_item	2343095	et	4	main
tema	doc_366216787881_item	2343101	et	4	main
on	doc_366216787881_item	2343103	et	4	main
paljudesse	doc_366216787881_item	2343105	et	3	main
inimesed	doc_366216787881_item	2343117	et	3	main
eestlaste	doc_366216787881_item	2343128	et	4	main
ja	doc_366216787881_item	2343130	et	3	main
minevik	doc_366216787881_item	2343138	et	3	main
üleval	doc_366216787881_item	2343145	et	4	main
toodud	doc_366216787881_item	2343146	et	4	main
faktid	doc_366216787881_item	2343147	et	3	main
nokia	doc_366216787880_item	2342828	et	4	main
test	doc_366216787881_item	2342835	et	3	main
kirjutamine	doc_366216787881_item	2342836	et	4	main
kirjutage	doc_366216787881_item	2342837	et	3	main
essee	doc_366216787881_item	2342838	et	4	main
teemal	doc_366216787881_item	2342839	et	3	main
peab	doc_366216787881_item	2342850	et	4	main
olema	doc_366216787881_item	2342851	et	4	main
arutlev	doc_366216787881_item	2342852	et	4	main
lugemistekstis	doc_366216787881_item	2342859	et	3	main
laulurahvas	doc_366216787881_item	2342873	et	4	main
sellest	doc_366216787881_item	2342874	et	4	main
on	doc_366216787881_item	2342875	et	4	main
palju	doc_366216787881_item	2342876	et	4	main
kirjutatud	doc_366216787881_item	2342877	et	4	main
ajalehtedes	doc_366216787881_item	2342878	et	4	main
ajakirjades	doc_366216787881_item	2342879	et	3	main
ja	doc_366216787881_item	2342880	et	3	main
sellest	doc_366216787881_item	2342881	et	4	main
on	doc_366216787881_item	2342882	et	4	main
palju	doc_366216787881_item	2342883	et	4	main
räägitud	doc_366216787881_item	2342884	et	4	main
aga	doc_366216787881_item	2342885	et	3	main
mis	doc_366216787881_item	2342886	et	4	main
teeb	doc_366216787881_item	2342887	et	3	main
eestlastest	doc_366216787881_item	2342888	et	4	main
et	doc_366216787881_item	2342890	et	3	main
laulurahvast	doc_366216787881_item	2342889	et	4	main
vastata	doc_366216787881_item	2342891	et	4	main
sellele	doc_366216787881_item	2342892	et	4	main
küsimustele	doc_366216787881_item	2342893	et	4	main
peame	doc_366216787881_item	2342894	et	4	main
meie	doc_366216787881_item	2342895	et	4	main
on	doc_366216787881_item	2342868	et	4	main
sajande	doc_366216787881_item	2342869	et	4	main
aastate	doc_366216787881_item	2342870	et	3	main
jooksul	doc_366216787881_item	2342871	et	4	main
olnud	doc_366216787881_item	2342872	et	4	main
pöörduma	doc_366216787881_item	2342897	et	3	main
kui	doc_366216787881_item	2342899	et	3	main
laulsid	doc_366216787881_item	2342907	et	4	main
kiiguti	doc_366216787881_item	2342921	et	3	main
peeti	doc_366216787881_item	2342924	et	4	main
maal	doc_366216787881_item	2342932	et	4	main
ja	doc_366216787881_item	2342933	et	3	main
peaaegu	doc_366216787881_item	2342934	et	3	main
ei	doc_366216787881_item	2342935	et	4	main
oskanud	doc_366216787881_item	2342936	et	4	main
kirjutada	doc_366216787881_item	2342937	et	3	main
ja	doc_366216787881_item	2342944	et	3	main
kaudu	doc_366216787881_item	2342947	et	3	main
põlve	doc_366216787881_item	2342949	et	4	main
pidu	doc_366216787881_item	2342973	et	4	main
noored	doc_366216787881_item	2342975	et	3	main
laulavad	doc_366216787881_item	2342980	et	4	main
tuletavad	doc_366216787881_item	2342981	et	4	main
inimesi	doc_366216787881_item	2342989	et	4	main
kaasa	doc_366216787881_item	2342998	et	4	main
inimesed	doc_366216787881_item	2343022	et	3	main
ja	doc_366216787881_item	2343024	et	3	main
saavad	doc_366216787881_item	2343025	et	4	main
rohkem	doc_366216787881_item	2343031	et	4	main
inimesed	doc_366216787881_item	2343041	et	3	main
laulu	doc_366216787881_item	2343047	et	4	main
on	doc_366216787881_item	2343071	et	4	main
välismaal	doc_366216787881_item	2343074	et	4	main
toormise	doc_366216787881_item	2343085	et	4	main
esimene	doc_366216787881_item	2343089	et	3	main
iga	doc_366216787881_item	2343099	et	4	main
nimi	doc_366216787881_item	2343102	et	3	main
õpikutesse	doc_366216787881_item	2343106	et	3	main
veski	doc_366216787881_item	2343108	et	4	main
kes	doc_366216787881_item	2343109	et	4	main
esineb	doc_366216787881_item	2343110	et	3	main
ka	doc_366216787881_item	2343111	et	3	main
välismaal	doc_366216787881_item	2343112	et	4	main
ja	doc_366216787881_item	2343113	et	3	main
tema	doc_366216787881_item	2343114	et	4	main
on	doc_366216787881_item	2343123	et	4	main
kultuurinähtis	doc_366216787881_item	2343125	et	4	main
emotsionaalne	doc_366216787881_item	2343131	et	3	main
tegevus	doc_366216787881_item	2343134	et	4	main
on	doc_366216787881_item	2343151	et	4	main
kui	doc_366216787881_item	2342908	et	3	main
nad	doc_366216787881_item	2342909	et	3	main
tööd	doc_366216787881_item	2342911	et	4	main
näiteks	doc_366216787881_item	2342912	et	4	main
säilitasid	doc_366216787881_item	2342939	et	4	main
aastal	doc_366216787881_item	2342953	et	3	main
laulupidu	doc_366216787881_item	2342957	et	4	main
inimesi	doc_366216787881_item	2342961	et	4	main
mitte	doc_366216787881_item	2342962	et	3	main
ainult	doc_366216787881_item	2342963	et	4	main
eestlasi	doc_366216787881_item	2342964	et	3	main
ka	doc_366216787881_item	2342965	et	3	main
inimesi	doc_366216787881_item	2342966	et	4	main
teistest	doc_366216787881_item	2342967	et	4	main
riigidest	doc_366216787881_item	2342968	et	4	main
on	doc_366216787881_item	2342972	et	4	main
millal	doc_366216787881_item	2342974	et	3	main
meelde	doc_366216787881_item	2342982	et	3	main
saa	doc_366216787881_item	2342988	et	4	main
ja	doc_366216787881_item	2342994	et	3	main
tähtis	doc_366216787881_item	2342999	et	4	main
on	doc_366216787881_item	2343000	et	4	main
see	doc_366216787881_item	2343001	et	3	main
et	doc_366216787881_item	2343002	et	3	main
laulud	doc_366216787881_item	2343003	et	3	main
puutuvad	doc_366216787881_item	2343004	et	4	main
ka	doc_366216787881_item	2343005	et	3	main
koosajaga	doc_366216787881_item	2343006	et	3	main
inimesed	doc_366216787881_item	2343007	et	3	main
suhtlevad	doc_366216787881_item	2343008	et	4	main
teiste	doc_366216787881_item	2343009	et	4	main
kultuuridega	doc_366216787881_item	2343010	et	3	main
omavahel	doc_366216787881_item	2343011	et	3	main
igasugustel	doc_366216787881_item	2343012	et	3	main
konkursidel	doc_366216787881_item	2343013	et	4	main
saavad	doc_366216787881_item	2343014	et	4	main
kokku	doc_366216787881_item	2343015	et	3	main
lauljad	doc_366216787881_item	2343016	et	4	main
eestist	doc_366216787881_item	2343017	et	3	main
soomest	doc_366216787881_item	2343018	et	3	main
venemaalt	doc_366216787881_item	2343019	et	3	main
lätist	doc_366216787881_item	2343020	et	4	main
teine	doc_366216787881_item	2343026	et	3	main
vaatamata	doc_366216787881_item	2343033	et	4	main
sellele	doc_366216787881_item	2343034	et	4	main
et	doc_366216787881_item	2343035	et	3	main
huvi	doc_366216787881_item	2343044	et	4	main
rahvusmuusika	doc_366216787881_item	2343045	et	4	main
ja	doc_366216787881_item	2343046	et	3	main
teised	doc_366216787881_item	2343054	et	4	main
saavad	doc_366216787881_item	2343056	et	4	main
veel	doc_366216787881_item	2343064	et	4	main
üks	doc_366216787881_item	2343065	et	3	main
eestlased	doc_366216787881_item	2343068	et	3	main
on	doc_366216787881_item	2343075	et	4	main
lauljad	doc_366216787881_item	2343078	et	4	main
seotud	doc_366216787881_item	2343081	et	4	main
inimesed	doc_366216787881_item	2343082	et	3	main
inimene	doc_366216787881_item	2343088	et	3	main
koori	doc_366216787881_item	2343092	et	4	main
georg	doc_366216787881_item	2343094	et	4	main
eestlane	doc_366216787881_item	2343100	et	3	main
armastavad	doc_366216787881_item	2343116	et	4	main
kultuurist	doc_366216787881_item	2343028	et	3	main
ajaloost	doc_366216787881_item	2343030	et	4	main
teada	doc_366216787881_item	2343032	et	3	main
suurt	doc_366216787881_item	2343043	et	3	main
vastu	doc_366216787881_item	2343048	et	3	main
see	doc_366216787881_item	2343049	et	3	main
näitab	doc_366216787881_item	2343050	et	3	main
seda	doc_366216787881_item	2343051	et	3	main
ka	doc_366216787881_item	2343053	et	3	main
et	doc_366216787881_item	2343052	et	3	main
põlvkonnad	doc_366216787881_item	2343055	et	4	main
argument	doc_366216787881_item	2343066	et	3	main
on	doc_366216787881_item	2343069	et	4	main
et	doc_366216787881_item	2343073	et	3	main
tundavad	doc_366216787881_item	2343076	et	4	main
laulmisega	doc_366216787881_item	2343080	et	4	main
näiteks	doc_366216787881_item	2343083	et	4	main
veljo	doc_366216787881_item	2343084	et	4	main
see	doc_366216787881_item	2343087	et	3	main
rahvalaule	doc_366216787881_item	2343091	et	4	main
lauluses	doc_366216787881_item	2343093	et	4	main
peaaegu	doc_366216787881_item	2343098	et	3	main
kokkuvõttes	doc_366216787881_item	2343118	et	3	main
rahvalaulude	doc_366216787881_item	2343062	et	3	main
kaudu	doc_366216787881_item	2343063	et	3	main
et	doc_366216787881_item	2343067	et	3	main
see	doc_366216787881_item	2343072	et	3	main
meie	doc_366216787881_item	2343077	et	4	main
kasutas	doc_366216787881_item	2343090	et	3	main
laule	doc_366216787881_item	2343096	et	4	main
teab	doc_366216787881_item	2343097	et	3	main
kirjutatud	doc_366216787881_item	2343104	et	4	main
anne	doc_366216787881_item	2343107	et	4	main
laule	doc_366216787881_item	2343115	et	4	main
öelda	doc_366216787881_item	2343120	et	4	main
on	doc_366216787881_item	2343127	et	4	main
sotsiaalne	doc_366216787881_item	2343133	et	3	main
kajastub	doc_366216787881_item	2343136	et	3	main
laulamine	doc_366216787881_item	2343139	et	4	main
on	doc_366216787881_item	2343140	et	4	main
pisut	doc_366216787881_item	2343141	et	3	main
nagu	doc_366216787881_item	2343142	et	3	main
ajaloo	doc_366216787881_item	2343143	et	4	main
uurimine	doc_366216787881_item	2343144	et	4	main
et	doc_366216787881_item	2343149	et	3	main
esitatud	doc_366216787883_item	2343521	et	4	main
väiteid	doc_366216787883_item	2343523	et	4	main
on	doc_366216787883_item	2343524	et	4	main
tahaks	doc_366216787881_item	2343119	et	3	main
laulmine	doc_366216787881_item	2343122	et	4	main
väljendusvahend	doc_366216787881_item	2343132	et	3	main
lauludes	doc_366216787881_item	2343135	et	3	main
rahva	doc_366216787881_item	2343137	et	3	main
eestlased	doc_366216787881_item	2343150	et	3	main
et	doc_366216787881_item	2343121	et	3	main
tähelepanuväärne	doc_366216787881_item	2343124	et	3	main
see	doc_366216787881_item	2343126	et	3	main
esteetiline	doc_366216787881_item	2343129	et	3	main
tõendavad	doc_366216787881_item	2343148	et	4	main
laulurahvas	doc_366216787881_item	2343152	et	4	main
tullakse	doc_366216787883_item	2343533	et	3	main
perega	doc_366216787883_item	2343535	et	3	main
kokku	doc_366216787883_item	2343547	et	3	main
pealtvaataja	doc_366216787883_item	2343553	et	4	main
kuulaja	doc_366216787883_item	2343556	et	4	main
tegelikult	doc_366216787883_item	2343558	et	4	main
kaasa	doc_366216787883_item	2343560	et	4	main
laulda	doc_366216787883_item	2343561	et	4	main
kogedes	doc_366216787883_item	2343562	et	4	main
seda	doc_366216787883_item	2343563	et	3	main
tuhandete	doc_366216787883_item	2343568	et	3	main
üheskoos	doc_366216787883_item	2343570	et	3	main
laulud	doc_366216787883_item	2343577	et	3	main
aja	doc_366216787883_item	2343580	et	4	main
minevik	doc_366216787883_item	2343587	et	3	main
nagu	doc_366216787883_item	2343594	et	3	main
eesti	doc_366216787883_item	2343597	et	4	main
laulutraditsiooni	doc_366216787883_item	2343599	et	4	main
esindab	doc_366216787883_item	2343600	et	3	main
läänemeresoome	doc_366216787883_item	2343601	et	3	main
kultuurile	doc_366216787883_item	2343602	et	3	main
iseloomulik	doc_366216787883_item	2343603	et	3	main
regivärsiline	doc_366216787883_item	2343604	et	4	main
tagasi	doc_366216787883_item	2343613	et	3	main
laulude	doc_366216787883_item	2343616	et	3	main
kirikus	doc_366216787883_item	2343618	et	3	main
on	doc_366216787883_item	2343529	et	4	main
suur	doc_366216787883_item	2343530	et	3	main
rahvapidu	doc_366216787883_item	2343531	et	4	main
kuhu	doc_366216787883_item	2343532	et	3	main
elamust	doc_366216787883_item	2343554	et	4	main
ootab	doc_366216787883_item	2343555	et	3	main
ülendavat	doc_366216787883_item	2343564	et	4	main
tunnet	doc_366216787883_item	2343565	et	3	main
sõnu	doc_366216787883_item	2343572	et	4	main
lauldes	doc_366216787883_item	2343575	et	3	main
uurimine	doc_366216787883_item	2343596	et	4	main
ristiusuga	doc_366216787883_item	2343614	et	3	main
ja	doc_366216787883_item	2343622	et	3	main
koorilaulu	doc_366216787883_item	2343630	et	4	main
ja	doc_366216787883_item	2343632	et	3	main
koosmõju	doc_366216787883_item	2343636	et	4	main
eeldused	doc_366216787883_item	2343640	et	4	main
laulud	doc_366216787883_item	2343646	et	3	main
muusika	doc_366216787883_item	2343658	et	4	main
ülemaaline	doc_366216787883_item	2343661	et	4	main
oma	doc_366216787883_item	2343673	et	4	main
1933	doc_366216787883_item	2343690	et	2	main
lisandusid	doc_366216787883_item	2343692	et	4	main
1947	doc_366216787883_item	2343694	et	2	main
lastekoorid	doc_366216787883_item	2343697	et	3	main
poistekoorid	doc_366216787883_item	2343701	et	3	main
aastapäeva	doc_366216787883_item	2343708	et	4	main
hulgas	doc_366216787883_item	2343712	et	4	main
seepärast	doc_366216787883_item	2343715	et	3	main
sõnadega	doc_366216787883_item	2343723	et	3	main
ja	doc_366216787883_item	2343725	et	3	main
laulupidu	doc_366216787883_item	2343728	et	4	main
tähelepanuväärsem	doc_366216787883_item	2343737	et	4	main
on	doc_366216787883_item	2343746	et	4	main
on	doc_366216787883_item	2343750	et	4	main
koorilaulu	doc_366216787883_item	2343751	et	4	main
traditsioon	doc_366216787883_item	2343752	et	3	main
tuhanded	doc_366216787883_item	2343769	et	3	main
lauljad	doc_366216787883_item	2343770	et	4	main
laulupidude	doc_366216787883_item	2343779	et	4	main
traditsiooni	doc_366216787883_item	2343780	et	4	main
suvel	doc_366216787883_item	2343781	et	3	main
linnas	doc_366216787883_item	2343789	et	4	main
mõlema	doc_366216787883_item	2343793	et	3	main
oli	doc_366216787883_item	2343798	et	3	main
neid	doc_366216787883_item	2343806	et	4	main
käsitleda	doc_366216787883_item	2343807	et	3	main
ühe	doc_366216787883_item	2343808	et	4	main
umbes	doc_366216787883_item	2343814	et	4	main
essee	doc_366216787883_item	2343490	et	4	main
eesti	doc_366216787883_item	2343491	et	4	main
keele	doc_366216787883_item	2343492	et	4	main
kui	doc_366216787883_item	2343493	et	3	main
teise	doc_366216787883_item	2343494	et	4	main
keele	doc_366216787883_item	2343495	et	4	main
test	doc_366216787883_item	2343496	et	3	main
kirjutamine	doc_366216787883_item	2343497	et	4	main
kirjutage	doc_366216787883_item	2343498	et	3	main
essee	doc_366216787883_item	2343499	et	4	main
teemal	doc_366216787883_item	2343500	et	3	main
mis	doc_366216787883_item	2343501	et	4	main
teeb	doc_366216787883_item	2343502	et	3	main
laulurahva	doc_366216787883_item	2343504	et	3	main
essee	doc_366216787883_item	2343505	et	4	main
eestlastest	doc_366216787883_item	2343503	et	4	main
pikkus	doc_366216787883_item	2343506	et	4	main
300	doc_366216787883_item	2343507	et	2	main
350	doc_366216787883_item	2343508	et	2	main
sõna	doc_366216787883_item	2343509	et	4	main
essee	doc_366216787883_item	2343510	et	4	main
peab	doc_366216787883_item	2343511	et	4	main
olema	doc_366216787883_item	2343512	et	4	main
arutlev	doc_366216787883_item	2343513	et	4	main
analüüsiv	doc_366216787883_item	2343514	et	4	main
ja	doc_366216787883_item	2343515	et	3	main
üldistav	doc_366216787883_item	2343516	et	4	main
tuginema	doc_366216787883_item	2343517	et	3	main
loengus	doc_366216787883_item	2343518	et	3	main
ja	doc_366216787883_item	2343519	et	3	main
lugemistekstis	doc_366216787883_item	2343520	et	3	main
faktidele	doc_366216787883_item	2343522	et	3	main
sõpru	doc_366216787883_item	2343538	et	3	main
sugulasi	doc_366216787883_item	2343539	et	3	main
ja	doc_366216787883_item	2343540	et	3	main
tuttavaid	doc_366216787883_item	2343541	et	3	main
laulupidu	doc_366216787883_item	2343528	et	4	main
koos	doc_366216787883_item	2343534	et	4	main
on	doc_366216787883_item	2343543	et	4	main
kogu	doc_366216787883_item	2343545	et	4	main
maailma	doc_366216787883_item	2343546	et	4	main
soovitatav	doc_366216787883_item	2343525	et	4	main
illustreerida	doc_366216787883_item	2343526	et	3	main
näidetega	doc_366216787883_item	2343527	et	3	main
lootuses	doc_366216787883_item	2343536	et	4	main
kohata	doc_366216787883_item	2343537	et	4	main
üle	doc_366216787883_item	2343544	et	3	main
publikule	doc_366216787883_item	2343551	et	3	main
mis	doc_366216787883_item	2343566	et	4	main
viisi	doc_366216787883_item	2343574	et	4	main
on	doc_366216787883_item	2343578	et	4	main
rahvalauluga	doc_366216787883_item	2343591	et	4	main
pisut	doc_366216787883_item	2343593	et	3	main
on	doc_366216787883_item	2343607	et	4	main
aastat	doc_366216787883_item	2343612	et	3	main
kaasnes	doc_366216787883_item	2343615	et	3	main
külakoolid	doc_366216787883_item	2343623	et	3	main
laulutraditsiooni	doc_366216787883_item	2343635	et	4	main
19	doc_366216787883_item	2343638	et	2	main
aga	doc_366216787883_item	2343652	et	3	main
ka	doc_366216787883_item	2343653	et	3	main
rootsi	doc_366216787883_item	2343654	et	4	main
mõjul	doc_366216787883_item	2343659	et	4	main
laulupidu	doc_366216787883_item	2343662	et	4	main
oli	doc_366216787883_item	2343663	et	3	main
1869	doc_366216787883_item	2343664	et	2	main
aastal	doc_366216787883_item	2343665	et	3	main
tartus	doc_366216787883_item	2343666	et	3	main
seitse	doc_366216787883_item	2343667	et	3	main
esimest	doc_366216787883_item	2343668	et	4	main
üldlaulupidu	doc_366216787883_item	2343669	et	4	main
tsaristliku	doc_366216787883_item	2343677	et	3	main
venemaa	doc_366216787883_item	2343678	et	4	main
tartust	doc_366216787883_item	2343680	et	3	main
alguse	doc_366216787883_item	2343681	et	3	main
saanud	doc_366216787883_item	2343682	et	4	main
traditsioon	doc_366216787883_item	2343683	et	3	main
kandus	doc_366216787883_item	2343684	et	3	main
alates	doc_366216787883_item	2343685	et	3	main
tallinnas	doc_366216787883_item	2343689	et	4	main
1960	doc_366216787883_item	2343698	et	2	main
1969	doc_366216787883_item	2343702	et	2	main
aastal	doc_366216787883_item	2343703	et	3	main
tähistati	doc_366216787883_item	2343704	et	4	main
juubelilaulupeoga	doc_366216787883_item	2343705	et	4	main
on	doc_366216787883_item	2343710	et	4	main
loomulik	doc_366216787883_item	2343717	et	3	main
kes	doc_366216787883_item	2343542	et	4	main
sõitnud	doc_366216787883_item	2343548	et	4	main
laulupidu	doc_366216787883_item	2343549	et	4	main
pakub	doc_366216787883_item	2343550	et	3	main
osakond	doc_366216787883_item	2343557	et	3	main
võimalust	doc_366216787883_item	2343559	et	3	main
tekib	doc_366216787883_item	2343567	et	3	main
samu	doc_366216787883_item	2343571	et	3	main
need	doc_366216787883_item	2343576	et	3	main
sümboliteks	doc_366216787883_item	2343583	et	3	main
rahvalauludes	doc_366216787883_item	2343584	et	3	main
kajastab	doc_366216787883_item	2343585	et	3	main
mistõttu	doc_366216787883_item	2343588	et	3	main
ajaloo	doc_366216787883_item	2343595	et	4	main
vanemat	doc_366216787883_item	2343598	et	4	main
kujunenud	doc_366216787883_item	2343608	et	4	main
enam	doc_366216787883_item	2343609	et	4	main
kui	doc_366216787883_item	2343610	et	3	main
sajandil	doc_366216787883_item	2343620	et	3	main
põhiliselt	doc_366216787883_item	2343625	et	4	main
järgivad	doc_366216787883_item	2343628	et	4	main
mitmehäälset	doc_366216787883_item	2343629	et	3	main
venemaa	doc_366216787883_item	2343631	et	4	main
uue	doc_366216787883_item	2343641	et	3	main
tekkeks	doc_366216787883_item	2343644	et	3	main
esimene	doc_366216787883_item	2343660	et	3	main
tunnustamise	doc_366216787883_item	2343674	et	4	main
1896	doc_366216787883_item	2343688	et	2	main
aastal	doc_366216787883_item	2343691	et	3	main
tulid	doc_366216787883_item	2343696	et	4	main
lisandusid	doc_366216787883_item	2343700	et	4	main
üldlaulupidude	doc_366216787883_item	2343706	et	4	main
eestlase	doc_366216787883_item	2343711	et	3	main
massiharrastuseks	doc_366216787883_item	2343714	et	3	main
tavalise	doc_366216787883_item	2343719	et	4	main
eestlase	doc_366216787883_item	2343720	et	3	main
seostub	doc_366216787883_item	2343722	et	3	main
eestiline	doc_366216787883_item	2343730	et	3	main
on	doc_366216787883_item	2343732	et	4	main
ka	doc_366216787883_item	2343733	et	3	main
praegusel	doc_366216787883_item	2343734	et	3	main
kuigi	doc_366216787883_item	2343742	et	3	main
pikka	doc_366216787883_item	2343754	et	4	main
laulupeole	doc_366216787883_item	2343773	et	4	main
et	doc_366216787883_item	2343774	et	3	main
tähistada	doc_366216787883_item	2343775	et	3	main
aastad	doc_366216787883_item	2343777	et	3	main
üldlaulupidu	doc_366216787883_item	2343784	et	4	main
kahekümne	doc_366216787883_item	2343785	et	4	main
korda	doc_366216787883_item	2343787	et	4	main
tallinnas	doc_366216787883_item	2343792	et	4	main
omavahel	doc_366216787883_item	2343799	et	3	main
ja	doc_366216787883_item	2343801	et	3	main
sama	doc_366216787883_item	2343803	et	4	main
seepärast	doc_366216787883_item	2343804	et	3	main
võib	doc_366216787883_item	2343805	et	3	main
kuusteist	doc_366216787883_item	2343815	et	4	main
lauljat	doc_366216787883_item	2343817	et	4	main
kuulajale	doc_366216787883_item	2343821	et	4	main
tuhat	doc_366216787883_item	2343826	et	4	main
pealtvaatajale	doc_366216787883_item	2343830	et	3	main
aastal	doc_366216787883_item	2343832	et	3	main
laulu	doc_366216787883_item	2343834	et	4	main
ja	doc_366216787883_item	2343835	et	3	main
kõigepealt	doc_366216787883_item	2343552	et	3	main
teistega	doc_366216787883_item	2343569	et	4	main
sama	doc_366216787883_item	2343573	et	4	main
läbi	doc_366216787883_item	2343579	et	4	main
kujunenud	doc_366216787883_item	2343581	et	4	main
rahvaslikeks	doc_366216787883_item	2343582	et	4	main
rahva	doc_366216787883_item	2343586	et	3	main
on	doc_366216787883_item	2343589	et	4	main
ka	doc_366216787883_item	2343590	et	3	main
tutvumine	doc_366216787883_item	2343592	et	4	main
rahvalaul	doc_366216787883_item	2343605	et	4	main
mis	doc_366216787883_item	2343606	et	4	main
tuhat	doc_366216787883_item	2343611	et	4	main
laulmine	doc_366216787883_item	2343617	et	4	main
18	doc_366216787883_item	2343619	et	2	main
kirik	doc_366216787883_item	2343621	et	3	main
euroopast	doc_366216787883_item	2343633	et	3	main
riimilise	doc_366216787883_item	2343642	et	4	main
kujunenud	doc_366216787883_item	2343648	et	4	main
europa	doc_366216787883_item	2343649	et	4	main
soome	doc_366216787883_item	2343655	et	3	main
slaavi	doc_366216787883_item	2343657	et	3	main
mil	doc_366216787883_item	2343670	et	4	main
eest	doc_366216787883_item	2343675	et	4	main
kuuendast	doc_366216787883_item	2343686	et	3	main
naiskoorid	doc_366216787883_item	2343693	et	3	main
aastal	doc_366216787883_item	2343699	et	3	main
koorilaul	doc_366216787883_item	2343709	et	4	main
kujunenud	doc_366216787883_item	2343713	et	4	main
on	doc_366216787883_item	2343716	et	4	main
jaoks	doc_366216787883_item	2343721	et	4	main
rahvas	doc_366216787883_item	2343724	et	4	main
laul	doc_366216787883_item	2343726	et	4	main
ka	doc_366216787883_item	2343727	et	3	main
üle	doc_366216787883_item	2343729	et	3	main
laulupidu	doc_366216787883_item	2343731	et	4	main
ajal	doc_366216787883_item	2343735	et	4	main
kõige	doc_366216787883_item	2343736	et	4	main
selle	doc_366216787883_item	2343743	et	4	main
professionaalse	doc_366216787883_item	2343748	et	3	main
heliloominguga	doc_366216787883_item	2343749	et	3	main
kestnud	doc_366216787883_item	2343778	et	4	main
eesti	doc_366216787883_item	2343783	et	4	main
tartus	doc_366216787883_item	2343790	et	3	main
ja	doc_366216787883_item	2343791	et	3	main
peo	doc_366216787883_item	2343794	et	4	main
ülesehitus	doc_366216787883_item	2343795	et	4	main
peo	doc_366216787883_item	2343809	et	4	main
kahe	doc_366216787883_item	2343810	et	3	main
osana	doc_366216787883_item	2343811	et	3	main
tartus	doc_366216787883_item	2343812	et	3	main
tuhat	doc_366216787883_item	2343816	et	4	main
seitsekümmend	doc_366216787883_item	2343819	et	4	main
õpetasid	doc_366216787883_item	2343624	et	4	main
saksa	doc_366216787883_item	2343626	et	4	main
eeskuju	doc_366216787883_item	2343627	et	4	main
laenatud	doc_366216787883_item	2343634	et	4	main
lõi	doc_366216787883_item	2343637	et	4	main
sajandil	doc_366216787883_item	2343639	et	3	main
rahvalaulu	doc_366216787883_item	2343643	et	4	main
need	doc_366216787883_item	2343645	et	3	main
on	doc_366216787883_item	2343647	et	4	main
muusika	doc_366216787883_item	2343650	et	4	main
saksa	doc_366216787883_item	2343651	et	4	main
ja	doc_366216787883_item	2343656	et	3	main
eestlased	doc_366216787883_item	2343671	et	3	main
võitlesid	doc_366216787883_item	2343672	et	4	main
korraldati	doc_366216787883_item	2343676	et	3	main
koosseisus	doc_366216787883_item	2343679	et	4	main
peost	doc_366216787883_item	2343687	et	4	main
aastal	doc_366216787883_item	2343695	et	3	main
100	doc_366216787883_item	2343707	et	2	main
et	doc_366216787883_item	2343718	et	3	main
rahvusluse	doc_366216787883_item	2343739	et	4	main
manifestatsioon	doc_366216787883_item	2343740	et	3	main
eestis	doc_366216787883_item	2343741	et	3	main
repertuaar	doc_366216787883_item	2343745	et	3	main
seotud	doc_366216787883_item	2343747	et	4	main
mõjutanud	doc_366216787883_item	2343753	et	4	main
125	doc_366216787883_item	2343776	et	2	main
erakorraldati	doc_366216787883_item	2343782	et	4	main
sisu	doc_366216787883_item	2343797	et	4	main
seotud	doc_366216787883_item	2343800	et	4	main
põhimõttelised	doc_366216787883_item	2343802	et	4	main
laulis	doc_366216787883_item	2343813	et	4	main
viis	doc_366216787883_item	2343825	et	4	main
esinejat	doc_366216787883_item	2343827	et	4	main
massilisem	doc_366216787883_item	2343738	et	4	main
peo	doc_366216787883_item	2343744	et	4	main
aega	doc_366216787883_item	2343755	et	4	main
eestlaste	doc_366216787883_item	2343756	et	4	main
muusika	doc_366216787883_item	2343757	et	4	main
taju	doc_366216787883_item	2343758	et	4	main
ja	doc_366216787883_item	2343759	et	3	main
suuliselt	doc_366216787883_item	2343760	et	4	main
laulupärimust	doc_366216787883_item	2343761	et	4	main
eestlane	doc_366216787883_item	2343762	et	3	main
on	doc_366216787883_item	2343763	et	4	main
1994	doc_366216787883_item	2343765	et	2	main
laulurahva	doc_366216787883_item	2343764	et	3	main
aasta	doc_366216787883_item	2343766	et	4	main
juulis	doc_366216787883_item	2343767	et	3	main
kogunesid	doc_366216787883_item	2343768	et	4	main
tallinna	doc_366216787883_item	2343771	et	4	main
lauluväljakule	doc_366216787883_item	2343772	et	3	main
teist	doc_366216787883_item	2343786	et	4	main
kahes	doc_366216787883_item	2343788	et	4	main
ja	doc_366216787883_item	2343796	et	3	main
ja	doc_366216787883_item	2343818	et	3	main
tuhat	doc_366216787883_item	2343820	et	4	main
2005	doc_366216787883_item	2343831	et	2	main
mis	doc_366216787885_item	2344064	et	4	main
essee	doc_366216787885_item	2344068	et	4	main
sõna	doc_366216787885_item	2344072	et	4	main
peab	doc_366216787885_item	2344074	et	4	main
olema	doc_366216787885_item	2344075	et	4	main
arutlev	doc_366216787885_item	2344076	et	4	main
analüüsiv	doc_366216787885_item	2344077	et	4	main
ja	doc_366216787885_item	2344078	et	3	main
tuginema	doc_366216787885_item	2344080	et	3	main
loengus	doc_366216787885_item	2344081	et	3	main
ja	doc_366216787885_item	2344082	et	3	main
lugemistekstis	doc_366216787885_item	2344083	et	3	main
koolis	doc_366216787885_item	2344121	et	4	main
laulavad	doc_366216787885_item	2344123	et	4	main
kooris	doc_366216787885_item	2344124	et	4	main
ka	doc_366216787885_item	2344131	et	3	main
rahvalaul	doc_366216787885_item	2344141	et	4	main
kui	doc_366216787885_item	2344146	et	3	main
aastat	doc_366216787885_item	2344148	et	3	main
palju	doc_366216787885_item	2344157	et	4	main
lauluvad	doc_366216787885_item	2344158	et	4	main
kirikus	doc_366216787885_item	2344159	et	3	main
austamine	doc_366216787885_item	2344166	et	4	main
rohkem	doc_366216787885_item	2344169	et	4	main
kui	doc_366216787885_item	2344178	et	3	main
kirikukooris	doc_366216787885_item	2344182	et	4	main
naised	doc_366216787885_item	2344184	et	3	main
varem	doc_366216787885_item	2344188	et	4	main
kirjalik	doc_366216787885_item	2344192	et	3	main
tuhat	doc_366216787883_item	2343829	et	4	main
oli	doc_366216787883_item	2343833	et	3	main
tallinnas	doc_366216787883_item	2343822	et	4	main
laulis	doc_366216787883_item	2343823	et	4	main
kakskummend	doc_366216787883_item	2343824	et	4	main
sada	doc_366216787883_item	2343828	et	4	main
tantsurahvapidu	doc_366216787883_item	2343836	et	4	main
keele	doc_366216787885_item	2344058	et	4	main
test	doc_366216787885_item	2344059	et	3	main
laulurahva	doc_366216787885_item	2344067	et	3	main
väiteid	doc_366216787885_item	2344086	et	4	main
aga	doc_366216787885_item	2344130	et	3	main
vanemat	doc_366216787885_item	2344134	et	4	main
esindab	doc_366216787885_item	2344136	et	3	main
kultuurile	doc_366216787885_item	2344138	et	3	main
mis	doc_366216787885_item	2344142	et	4	main
enam	doc_366216787885_item	2344145	et	4	main
tuhat	doc_366216787885_item	2344147	et	4	main
lauldud	doc_366216787885_item	2344150	et	4	main
üksi	doc_366216787885_item	2344151	et	4	main
kahekesi	doc_366216787885_item	2344152	et	3	main
koorilaulu	doc_366216787885_item	2344162	et	4	main
laulsid	doc_366216787885_item	2344168	et	4	main
mängivad	doc_366216787885_item	2344172	et	4	main
pärast	doc_366216787885_item	2344174	et	4	main
lauluvad	doc_366216787885_item	2344175	et	4	main
rahvalaulu	doc_366216787885_item	2344190	et	4	main
iseloomustab	doc_366216787885_item	2344191	et	4	main
seotud	doc_366216787885_item	2344206	et	4	main
aastal	doc_366216787885_item	2344226	et	3	main
suursündmus	doc_366216787885_item	2344229	et	3	main
järgnevate	doc_366216787885_item	2344233	et	4	main
eesti	doc_366216787885_item	2344237	et	4	main
laste	doc_366216787885_item	2344253	et	4	main
suurenes	doc_366216787885_item	2344256	et	4	main
arv	doc_366216787885_item	2344258	et	3	main
000	doc_366216787885_item	2344262	et	2	main
pillimängijani	doc_366216787885_item	2344265	et	3	main
tallinnas	doc_366216787885_item	2344272	et	4	main
ja	doc_366216787885_item	2344273	et	3	main
tartus	doc_366216787885_item	2344274	et	3	main
25	doc_366216787885_item	2344280	et	2	main
esinejat	doc_366216787885_item	2344282	et	4	main
pealtvaatajale	doc_366216787885_item	2344285	et	3	main
seepärast	doc_366216787885_item	2344292	et	3	main
et	doc_366216787885_item	2344295	et	3	main
eestlase	doc_366216787885_item	2344297	et	3	main
teise	doc_366216787885_item	2344057	et	4	main
eestlastest	doc_366216787885_item	2344066	et	4	main
300	doc_366216787885_item	2344070	et	2	main
üldistav	doc_366216787885_item	2344079	et	4	main
esitatud	doc_366216787885_item	2344084	et	4	main
illustreerida	doc_366216787885_item	2344089	et	3	main
laul	doc_366216787885_item	2344091	et	4	main
ja	doc_366216787885_item	2344128	et	3	main
sotsiaalsed	doc_366216787885_item	2344132	et	3	main
eesti	doc_366216787885_item	2344133	et	4	main
laulutraditsiooni	doc_366216787885_item	2344135	et	4	main
läänemeresoome	doc_366216787885_item	2344137	et	3	main
on	doc_366216787885_item	2344143	et	4	main
tagasi	doc_366216787885_item	2344149	et	3	main
ilma	doc_366216787885_item	2344156	et	4	main
praegu	doc_366216787885_item	2344161	et	3	main
puhkpilliorkestrik	doc_366216787885_item	2344165	et	4	main
enam	doc_366216787885_item	2344167	et	4	main
pille	doc_366216787885_item	2344173	et	3	main
naised	doc_366216787885_item	2344179	et	3	main
mehed	doc_366216787885_item	2344181	et	3	main
nad	doc_366216787885_item	2344185	et	3	main
parem	doc_366216787885_item	2344187	et	4	main
laululehed	doc_366216787885_item	2344194	et	3	main
essee	doc_366216787885_item	2344053	et	4	main
keele	doc_366216787885_item	2344055	et	4	main
kui	doc_366216787885_item	2344056	et	3	main
teeb	doc_366216787885_item	2344065	et	3	main
faktidele	doc_366216787885_item	2344085	et	3	main
regivärsiline	doc_366216787885_item	2344140	et	4	main
kooriga	doc_366216787885_item	2344153	et	4	main
eeslauljaga	doc_366216787885_item	2344154	et	3	main
ja	doc_366216787885_item	2344155	et	3	main
kaasnes	doc_366216787885_item	2344163	et	3	main
mehed	doc_366216787885_item	2344171	et	3	main
mängivad	doc_366216787885_item	2344177	et	4	main
siis	doc_366216787885_item	2344180	et	3	main
uuema	doc_366216787885_item	2344189	et	4	main
ülestähendus	doc_366216787885_item	2344193	et	3	main
ja	doc_366216787885_item	2344195	et	3	main
levisid	doc_366216787885_item	2344197	et	4	main
trükitult	doc_366216787885_item	2344198	et	4	main
aga	doc_366216787885_item	2344199	et	3	main
laulikuid	doc_366216787885_item	2344200	et	3	main
käsitsi	doc_366216787885_item	2344203	et	3	main
tihedalt	doc_366216787885_item	2344207	et	4	main
laulupidu	doc_366216787885_item	2344222	et	4	main
tartus	doc_366216787885_item	2344224	et	3	main
muusikaline	doc_366216787885_item	2344228	et	4	main
aluse	doc_366216787885_item	2344232	et	4	main
muutusid	doc_366216787885_item	2344242	et	4	main
laulupeod	doc_366216787885_item	2344243	et	4	main
1933	doc_366216787885_item	2344246	et	2	main
aastal	doc_366216787885_item	2344247	et	3	main
lisandusid	doc_366216787885_item	2344248	et	4	main
aga	doc_366216787885_item	2344251	et	3	main
25	doc_366216787885_item	2344259	et	2	main
ja	doc_366216787885_item	2344264	et	3	main
praegu	doc_366216787885_item	2344266	et	3	main
traditsioonid	doc_366216787885_item	2344269	et	3	main
nad	doc_366216787885_item	2344270	et	3	main
toimuvad	doc_366216787885_item	2344271	et	4	main
000	doc_366216787885_item	2344281	et	2	main
eestlaste	doc_366216787885_item	2344288	et	4	main
sõnadega	doc_366216787885_item	2344300	et	3	main
professionaalse	doc_366216787885_item	2344312	et	3	main
heliloominguga	doc_366216787885_item	2344313	et	3	main
eesti	doc_366216787885_item	2344054	et	4	main
kirjutamine	doc_366216787885_item	2344060	et	4	main
kirjutage	doc_366216787885_item	2344061	et	3	main
essee	doc_366216787885_item	2344062	et	4	main
teemal	doc_366216787885_item	2344063	et	3	main
pikkus	doc_366216787885_item	2344069	et	4	main
350	doc_366216787885_item	2344071	et	2	main
essee	doc_366216787885_item	2344073	et	4	main
on	doc_366216787885_item	2344087	et	4	main
soovitatav	doc_366216787885_item	2344088	et	4	main
näidetega	doc_366216787885_item	2344090	et	3	main
on	doc_366216787885_item	2344092	et	4	main
hing	doc_366216787885_item	2344093	et	3	main
juba	doc_366216787885_item	2344094	et	3	main
pisikesed	doc_366216787885_item	2344095	et	4	main
lapsed	doc_366216787885_item	2344096	et	3	main
kuulavad	doc_366216787885_item	2344097	et	4	main
mida	doc_366216787885_item	2344098	et	4	main
laulab	doc_366216787885_item	2344099	et	3	main
oma	doc_366216787885_item	2344100	et	4	main
ema	doc_366216787885_item	2344101	et	4	main
emalaulud	doc_366216787885_item	2344102	et	3	main
on	doc_366216787885_item	2344103	et	4	main
õrnad	doc_366216787885_item	2344104	et	3	main
kenad	doc_366216787885_item	2344105	et	3	main
ja	doc_366216787885_item	2344106	et	3	main
emotsionaalsed	doc_366216787885_item	2344107	et	3	main
lasteaias	doc_366216787885_item	2344108	et	4	main
laulavad	doc_366216787885_item	2344109	et	4	main
kõikjadel	doc_366216787885_item	2344110	et	4	main
muusikatunnis	doc_366216787885_item	2344111	et	3	main
õues	doc_366216787885_item	2344112	et	4	main
rühmades	doc_366216787885_item	2344113	et	3	main
peos	doc_366216787885_item	2344114	et	4	main
lapsed	doc_366216787885_item	2344115	et	3	main
armastavad	doc_366216787885_item	2344116	et	4	main
laulda	doc_366216787885_item	2344117	et	4	main
tantsida	doc_366216787885_item	2344118	et	3	main
mängida	doc_366216787885_item	2344119	et	3	main
pillides	doc_366216787885_item	2344120	et	4	main
lapsed	doc_366216787885_item	2344122	et	3	main
rahvalaulud	doc_366216787885_item	2344125	et	3	main
on	doc_366216787885_item	2344126	et	4	main
esteetilised	doc_366216787885_item	2344127	et	3	main
emotsionalsed	doc_366216787885_item	2344129	et	4	main
iseloomulik	doc_366216787885_item	2344139	et	3	main
kujunenud	doc_366216787885_item	2344144	et	4	main
aga	doc_366216787885_item	2344160	et	3	main
ka	doc_366216787885_item	2344164	et	3	main
naised	doc_366216787885_item	2344170	et	3	main
ja	doc_366216787885_item	2344176	et	3	main
rohkem	doc_366216787885_item	2344183	et	4	main
lauluvad	doc_366216787885_item	2344186	et	4	main
kirjutati	doc_366216787885_item	2344201	et	3	main
muusika	doc_366216787885_item	2344204	et	4	main
on	doc_366216787885_item	2344205	et	4	main
rahvuslik	doc_366216787885_item	2344209	et	3	main
ärkamine	doc_366216787885_item	2344210	et	4	main
19	doc_366216787885_item	2344211	et	2	main
sajandi	doc_366216787885_item	2344212	et	3	main
lõpupoole	doc_366216787885_item	2344213	et	4	main
baltisaksa	doc_366216787885_item	2344214	et	4	main
kooride	doc_366216787885_item	2344215	et	3	main
eeskujul	doc_366216787885_item	2344216	et	3	main
toimusid	doc_366216787885_item	2344217	et	4	main
näiteks	doc_366216787885_item	2344218	et	4	main
jõhvi	doc_366216787885_item	2344219	et	4	main
põlvas	doc_366216787885_item	2344220	et	4	main
esimene	doc_366216787885_item	2344221	et	3	main
kujunes	doc_366216787885_item	2344223	et	3	main
korraldamisele	doc_366216787885_item	2344235	et	4	main
pärast	doc_366216787885_item	2344236	et	4	main
vabariigi	doc_366216787885_item	2344238	et	3	main
loomist	doc_366216787885_item	2344239	et	4	main
1918	doc_366216787885_item	2344240	et	2	main
aastal	doc_366216787885_item	2344241	et	3	main
ka	doc_366216787885_item	2344249	et	3	main
naiskoorid	doc_366216787885_item	2344250	et	3	main
poistekoorid	doc_366216787885_item	2344255	et	3	main
laulja	doc_366216787885_item	2344263	et	4	main
laulupeod	doc_366216787885_item	2344267	et	4	main
1994	doc_366216787885_item	2344275	et	2	main
aastal	doc_366216787885_item	2344276	et	3	main
tallinna	doc_366216787885_item	2344277	et	4	main
kogunesid	doc_366216787885_item	2344279	et	4	main
100	doc_366216787885_item	2344283	et	2	main
hulgas	doc_366216787885_item	2344289	et	4	main
loomulik	doc_366216787885_item	2344294	et	3	main
tavalise	doc_366216787885_item	2344296	et	4	main
jaoks	doc_366216787885_item	2344298	et	4	main
ka	doc_366216787885_item	2344307	et	3	main
repertuaar	doc_366216787885_item	2344310	et	3	main
väga	doc_366216787885_item	2344314	et	3	main
laulupidu	doc_366216787885_item	2344316	et	4	main
salmialbumid	doc_366216787885_item	2344196	et	3	main
ümber	doc_366216787885_item	2344202	et	3	main
eestlaste	doc_366216787885_item	2344208	et	4	main
1869	doc_366216787885_item	2344225	et	2	main
pani	doc_366216787885_item	2344231	et	4	main
muusika	doc_366216787885_item	2344244	et	4	main
suurüritusteks	doc_366216787885_item	2344245	et	3	main
ja	doc_366216787885_item	2344254	et	3	main
osavõtjate	doc_366216787885_item	2344257	et	3	main
30	doc_366216787885_item	2344261	et	2	main
on	doc_366216787885_item	2344268	et	4	main
lauluväljal	doc_366216787885_item	2344278	et	3	main
massiharrastuseks	doc_366216787885_item	2344291	et	3	main
on	doc_366216787885_item	2344293	et	4	main
seostub	doc_366216787885_item	2344299	et	3	main
laul	doc_366216787885_item	2344301	et	4	main
praegusel	doc_366216787885_item	2344306	et	3	main
koos	doc_366216787885_item	2344322	et	4	main
aja	doc_366216787885_item	2344333	et	4	main
kujunenud	doc_366216787885_item	2344334	et	4	main
rahvuslikeks	doc_366216787885_item	2344335	et	3	main
sümboliteks	doc_366216787885_item	2344336	et	3	main
sai	doc_366216787885_item	2344227	et	4	main
mis	doc_366216787885_item	2344230	et	4	main
üldlaulupidude	doc_366216787885_item	2344234	et	4	main
pärast	doc_366216787885_item	2344252	et	4	main
000	doc_366216787885_item	2344260	et	2	main
000	doc_366216787885_item	2344284	et	2	main
koorilaul	doc_366216787885_item	2344286	et	4	main
on	doc_366216787885_item	2344287	et	4	main
kujunenud	doc_366216787885_item	2344290	et	4	main
ja	doc_366216787885_item	2344302	et	3	main
rahvas	doc_366216787885_item	2344303	et	4	main
eestlased	doc_366216787885_item	2344304	et	3	main
rahvasluse	doc_366216787885_item	2344308	et	4	main
on	doc_366216787885_item	2344317	et	4	main
suur	doc_366216787885_item	2344318	et	3	main
rahvapidu	doc_366216787885_item	2344319	et	4	main
kuhu	doc_366216787885_item	2344320	et	3	main
tullakse	doc_366216787885_item	2344321	et	3	main
mina	doc_366216787885_item	2344326	et	4	main
mõtlen	doc_366216787885_item	2344327	et	3	main
et	doc_366216787885_item	2344328	et	3	main
laulud	doc_366216787885_item	2344330	et	3	main
läbi	doc_366216787885_item	2344332	et	4	main
kirjutamine	doc_366216787887_item	2344542	et	4	main
kirjutage	doc_366216787887_item	2344543	et	3	main
essee	doc_366216787887_item	2344555	et	4	main
üldistav	doc_366216787887_item	2344561	et	4	main
tuginema	doc_366216787887_item	2344562	et	3	main
lugemistekstis	doc_366216787887_item	2344565	et	3	main
eesti	doc_366216787887_item	2344573	et	4	main
on	doc_366216787887_item	2344575	et	4	main
vanast	doc_366216787887_item	2344577	et	3	main
sellega	doc_366216787887_item	2344583	et	3	main
kindlasti	doc_366216787887_item	2344588	et	3	main
jaoks	doc_366216787887_item	2344636	et	4	main
uhkus	doc_366216787887_item	2344643	et	4	main
et	doc_366216787887_item	2344644	et	3	main
sellest	doc_366216787887_item	2344650	et	4	main
kelle	doc_366216787887_item	2344667	et	4	main
eesti	doc_366216787887_item	2344671	et	4	main
oli	doc_366216787887_item	2344679	et	3	main
laulupidude	doc_366216787887_item	2344685	et	4	main
traditsioon	doc_366216787887_item	2344686	et	3	main
ise	doc_366216787887_item	2344687	et	4	main
ütleb	doc_366216787887_item	2344691	et	3	main
rahv	doc_366216787887_item	2344698	et	4	main
mul	doc_366216787887_item	2344699	et	3	main
kuidas	doc_366216787887_item	2344704	et	3	main
lauluvad	doc_366216787885_item	2344305	et	4	main
peo	doc_366216787885_item	2344309	et	4	main
on	doc_366216787885_item	2344311	et	4	main
oluline	doc_366216787885_item	2344315	et	4	main
lastega	doc_366216787885_item	2344323	et	3	main
sugulastega	doc_366216787885_item	2344325	et	4	main
eesti	doc_366216787885_item	2344329	et	4	main
eesti	doc_366216787887_item	2344536	et	4	main
kui	doc_366216787887_item	2344538	et	3	main
keele	doc_366216787887_item	2344540	et	4	main
test	doc_366216787887_item	2344541	et	3	main
eestlastest	doc_366216787887_item	2344548	et	4	main
laulurahva	doc_366216787887_item	2344549	et	3	main
essee	doc_366216787887_item	2344550	et	4	main
pikkus	doc_366216787887_item	2344551	et	4	main
ja	doc_366216787887_item	2344564	et	3	main
esitatud	doc_366216787887_item	2344566	et	4	main
illustreerida	doc_366216787887_item	2344571	et	3	main
rahvale	doc_366216787887_item	2344581	et	3	main
ma	doc_366216787887_item	2344586	et	3	main
öelda	doc_366216787887_item	2344589	et	4	main
eestlaste	doc_366216787887_item	2344635	et	4	main
eestlased	doc_366216787887_item	2344637	et	3	main
hakkasid	doc_366216787887_item	2344638	et	4	main
uskuma	doc_366216787887_item	2344639	et	3	main
on	doc_366216787887_item	2344646	et	4	main
koos	doc_366216787887_item	2344647	et	4	main
rahvusliku	doc_366216787887_item	2344654	et	3	main
nad	doc_366216787887_item	2344663	et	3	main
laulsid	doc_366216787887_item	2344664	et	4	main
rahvus	doc_366216787887_item	2344665	et	3	main
sõbraga	doc_366216787885_item	2344324	et	3	main
on	doc_366216787885_item	2344331	et	4	main
essee	doc_366216787887_item	2344535	et	4	main
essee	doc_366216787887_item	2344544	et	4	main
300	doc_366216787887_item	2344552	et	2	main
peab	doc_366216787887_item	2344556	et	4	main
arutlev	doc_366216787887_item	2344558	et	4	main
analüüsiv	doc_366216787887_item	2344559	et	4	main
ja	doc_366216787887_item	2344560	et	3	main
faktidele	doc_366216787887_item	2344567	et	3	main
väiteid	doc_366216787887_item	2344568	et	4	main
näidetega	doc_366216787887_item	2344572	et	3	main
laulurahvakultuur	doc_366216787887_item	2344574	et	3	main
juba	doc_366216787887_item	2344576	et	3	main
sest	doc_366216787887_item	2344582	et	4	main
võin	doc_366216787887_item	2344587	et	3	main
laulupidu	doc_366216787887_item	2344629	et	4	main
tartus	doc_366216787887_item	2344630	et	3	main
tad	doc_366216787887_item	2344645	et	4	main
koos	doc_366216787887_item	2344649	et	4	main
kujunes	doc_366216787887_item	2344652	et	3	main
on	doc_366216787887_item	2344658	et	4	main
gümni	doc_366216787887_item	2344666	et	4	main
nad	doc_366216787887_item	2344675	et	3	main
pidusid	doc_366216787887_item	2344677	et	4	main
sai	doc_366216787887_item	2344683	et	4	main
alguse	doc_366216787887_item	2344684	et	3	main
eesti	doc_366216787887_item	2344689	et	4	main
vanadel	doc_366216787887_item	2344706	et	3	main
ajadel	doc_366216787887_item	2344707	et	4	main
ja	doc_366216787887_item	2344711	et	3	main
keele	doc_366216787887_item	2344537	et	4	main
teise	doc_366216787887_item	2344539	et	4	main
mis	doc_366216787887_item	2344546	et	4	main
350	doc_366216787887_item	2344553	et	2	main
on	doc_366216787887_item	2344569	et	4	main
eesti	doc_366216787887_item	2344580	et	4	main
nad	doc_366216787887_item	2344584	et	3	main
et	doc_366216787887_item	2344590	et	3	main
jaoks	doc_366216787887_item	2344621	et	4	main
mehe	doc_366216787887_item	2344623	et	3	main
jaoks	doc_366216787887_item	2344624	et	4	main
aastal	doc_366216787887_item	2344626	et	3	main
toimus	doc_366216787887_item	2344627	et	3	main
esimene	doc_366216787887_item	2344628	et	3	main
oli	doc_366216787887_item	2344632	et	3	main
pidu	doc_366216787887_item	2344634	et	4	main
tuli	doc_366216787887_item	2344642	et	4	main
kõik	doc_366216787887_item	2344648	et	4	main
minu	doc_366216787887_item	2344659	et	3	main
arust	doc_366216787887_item	2344660	et	4	main
väga	doc_366216787887_item	2344661	et	3	main
tähtis	doc_366216787887_item	2344662	et	4	main
autor	doc_366216787887_item	2344668	et	3	main
tuntud	doc_366216787887_item	2344670	et	4	main
kõigidel	doc_366216787887_item	2344678	et	4	main
rahvale	doc_366216787887_item	2344690	et	3	main
nad	doc_366216787887_item	2344693	et	3	main
poolest	doc_366216787887_item	2344696	et	4	main
eriline	doc_366216787887_item	2344697	et	4	main
sellest	doc_366216787887_item	2344703	et	4	main
mul	doc_366216787887_item	2344712	et	3	main
öelda	doc_366216787887_item	2344725	et	4	main
väga	doc_366216787887_item	2344729	et	3	main
üks	doc_366216787887_item	2344731	et	3	main
südamest	doc_366216787887_item	2344740	et	4	main
inimesed	doc_366216787887_item	2344743	et	3	main
tänapäevadel	doc_366216787887_item	2344746	et	3	main
seda	doc_366216787887_item	2344750	et	3	main
kogu	doc_366216787887_item	2344753	et	4	main
eestlased	doc_366216787887_item	2344759	et	3	main
rahvakultuuri	doc_366216787887_item	2344768	et	4	main
ainult	doc_366216787887_item	2344773	et	4	main
see	doc_366216787887_item	2344780	et	3	main
hea	doc_366216787887_item	2344782	et	4	main
noored	doc_366216787887_item	2344784	et	3	main
uhked	doc_366216787887_item	2344790	et	4	main
selle	doc_366216787887_item	2344791	et	4	main
vastu	doc_366216787887_item	2344792	et	3	main
mul	doc_366216787887_item	2344793	et	3	main
siis	doc_366216787887_item	2344804	et	3	main
kuidas	doc_366216787887_item	2344821	et	3	main
aastat	doc_366216787887_item	2344827	et	3	main
tagasi	doc_366216787887_item	2344828	et	3	main
peod	doc_366216787887_item	2344831	et	4	main
oma	doc_366216787887_item	2344832	et	4	main
lauludega	doc_366216787887_item	2344833	et	3	main
see	doc_366216787887_item	2344834	et	3	main
on	doc_366216787887_item	2344835	et	4	main
nende	doc_366216787887_item	2344840	et	4	main
rahvadel	doc_366216787887_item	2344845	et	4	main
laulud	doc_366216787887_item	2344849	et	3	main
sümbolid	doc_366216787887_item	2344850	et	3	main
ja	doc_366216787887_item	2344851	et	3	main
seda	doc_366216787887_item	2344852	et	3	main
125	doc_366216787887_item	2344860	et	2	main
peo	doc_366216787887_item	2344903	et	4	main
südamest	doc_366216787887_item	2344917	et	4	main
mis	doc_366216787887_item	2344918	et	4	main
eesti	doc_366216787888_item	2344923	et	4	main
teise	doc_366216787888_item	2344926	et	4	main
teemal	doc_366216787888_item	2344932	et	3	main
peab	doc_366216787888_item	2344943	et	4	main
olema	doc_366216787888_item	2344944	et	4	main
loengus	doc_366216787888_item	2344950	et	3	main
teemal	doc_366216787887_item	2344545	et	3	main
teeb	doc_366216787887_item	2344547	et	3	main
sõna	doc_366216787887_item	2344554	et	4	main
olema	doc_366216787887_item	2344557	et	4	main
loengus	doc_366216787887_item	2344563	et	3	main
soovitatav	doc_366216787887_item	2344570	et	4	main
ajast	doc_366216787887_item	2344578	et	4	main
tähtis	doc_366216787887_item	2344579	et	4	main
elavad	doc_366216787887_item	2344585	et	4	main
eestlased	doc_366216787887_item	2344591	et	3	main
on	doc_366216787887_item	2344592	et	4	main
inimesed	doc_366216787887_item	2344593	et	3	main
kes	doc_366216787887_item	2344594	et	4	main
on	doc_366216787887_item	2344595	et	4	main
uhked	doc_366216787887_item	2344596	et	4	main
oma	doc_366216787887_item	2344597	et	4	main
riigist	doc_366216787887_item	2344598	et	3	main
nad	doc_366216787887_item	2344599	et	3	main
võivad	doc_366216787887_item	2344600	et	4	main
laulda	doc_366216787887_item	2344601	et	4	main
emakeeles	doc_366216787887_item	2344602	et	4	main
oma	doc_366216787887_item	2344603	et	4	main
rahvamaal	doc_366216787887_item	2344604	et	4	main
vanal	doc_366216787887_item	2344605	et	3	main
ajal	doc_366216787887_item	2344606	et	4	main
saatis	doc_366216787887_item	2344607	et	3	main
laul	doc_366216787887_item	2344608	et	4	main
eestlast	doc_366216787887_item	2344609	et	4	main
hällist	doc_366216787887_item	2344610	et	4	main
hauani	doc_366216787887_item	2344611	et	3	main
lauldi	doc_366216787887_item	2344612	et	3	main
väga	doc_366216787887_item	2344613	et	3	main
palju	doc_366216787887_item	2344614	et	4	main
lauldi	doc_366216787887_item	2344615	et	3	main
üksi	doc_366216787887_item	2344616	et	4	main
olles	doc_366216787887_item	2344617	et	3	main
töötades	doc_366216787887_item	2344618	et	3	main
lauldi	doc_366216787887_item	2344619	et	3	main
laste	doc_366216787887_item	2344620	et	4	main
oma	doc_366216787887_item	2344622	et	4	main
1869	doc_366216787887_item	2344625	et	2	main
see	doc_366216787887_item	2344631	et	3	main
suur	doc_366216787887_item	2344633	et	3	main
endasse	doc_366216787887_item	2344640	et	4	main
neil	doc_366216787887_item	2344641	et	4	main
laulupeost	doc_366216787887_item	2344651	et	4	main
eestlaste	doc_366216787887_item	2344653	et	4	main
liikumise	doc_366216787887_item	2344655	et	4	main
kõrghetk	doc_366216787887_item	2344656	et	3	main
mis	doc_366216787887_item	2344657	et	4	main
on	doc_366216787887_item	2344669	et	4	main
lidia	doc_366216787887_item	2344673	et	4	main
lihtsalt	doc_366216787887_item	2344676	et	4	main
tuju	doc_366216787887_item	2344681	et	4	main
sellest	doc_366216787887_item	2344682	et	4	main
et	doc_366216787887_item	2344692	et	3	main
on	doc_366216787887_item	2344694	et	4	main
tuli	doc_366216787887_item	2344700	et	4	main
suur	doc_366216787887_item	2344701	et	3	main
laulsid	doc_366216787887_item	2344705	et	4	main
kuidas	doc_366216787887_item	2344708	et	3	main
elasid	doc_366216787887_item	2344710	et	4	main
võimalus	doc_366216787887_item	2344714	et	3	main
sellest	doc_366216787887_item	2344715	et	4	main
teada	doc_366216787887_item	2344716	et	3	main
saada	doc_366216787887_item	2344717	et	4	main
vaatasin	doc_366216787887_item	2344718	et	3	main
aulas	doc_366216787887_item	2344719	et	4	main
väga	doc_366216787887_item	2344720	et	3	main
kõik	doc_366216787887_item	2344741	et	4	main
laulavad	doc_366216787887_item	2344747	et	4	main
teevad	doc_366216787887_item	2344749	et	3	main
võib	doc_366216787887_item	2344756	et	3	main
laulurahvas	doc_366216787887_item	2344761	et	4	main
vastu	doc_366216787887_item	2344769	et	3	main
noored	doc_366216787887_item	2344778	et	3	main
kultuuri	doc_366216787887_item	2344787	et	4	main
ja	doc_366216787887_item	2344788	et	3	main
on	doc_366216787887_item	2344789	et	4	main
eestlane	doc_366216787887_item	2344796	et	3	main
ja	doc_366216787887_item	2344797	et	3	main
tihti	doc_366216787887_item	2344798	et	3	main
tulen	doc_366216787887_item	2344801	et	3	main
koos	doc_366216787887_item	2344823	et	4	main
ja	doc_366216787887_item	2344829	et	3	main
kultuur	doc_366216787887_item	2344837	et	3	main
jaoks	doc_366216787887_item	2344841	et	4	main
saa	doc_366216787887_item	2344854	et	4	main
tähistati	doc_366216787887_item	2344859	et	4	main
kestnud	doc_366216787887_item	2344862	et	4	main
traditsiooni	doc_366216787887_item	2344864	et	4	main
selle	doc_366216787887_item	2344865	et	4	main
ja	doc_366216787887_item	2344871	et	3	main
elab	doc_366216787887_item	2344905	et	3	main
hakkab	doc_366216787887_item	2344907	et	3	main
tähistavad	doc_366216787887_item	2344910	et	4	main
peosid	doc_366216787887_item	2344912	et	3	main
kõik	doc_366216787887_item	2344913	et	4	main
on	doc_366216787887_item	2344919	et	4	main
test	doc_366216787888_item	2344928	et	3	main
teeb	doc_366216787888_item	2344934	et	3	main
pikkus	doc_366216787888_item	2344938	et	4	main
350	doc_366216787888_item	2344940	et	2	main
sõna	doc_366216787888_item	2344941	et	4	main
analüüsiv	doc_366216787888_item	2344946	et	4	main
ja	doc_366216787888_item	2344947	et	3	main
soovitatav	doc_366216787888_item	2344957	et	4	main
illustreerida	doc_366216787888_item	2344958	et	3	main
näidetega	doc_366216787888_item	2344959	et	3	main
väga	doc_366216787888_item	2344966	et	3	main
palju	doc_366216787888_item	2344967	et	4	main
asjad	doc_366216787888_item	2344994	et	3	main
rahvalauludes	doc_366216787888_item	2344997	et	3	main
näha	doc_366216787888_item	2344999	et	3	main
poetess	doc_366216787887_item	2344672	et	3	main
koidula	doc_366216787887_item	2344674	et	4	main
hea	doc_366216787887_item	2344680	et	4	main
endast	doc_366216787887_item	2344688	et	4	main
natuke	doc_366216787887_item	2344695	et	4	main
huvi	doc_366216787887_item	2344702	et	4	main
vanad	doc_366216787887_item	2344721	et	3	main
ja	doc_366216787887_item	2344723	et	3	main
see	doc_366216787887_item	2344727	et	3	main
neiu	doc_366216787887_item	2344732	et	4	main
laulis	doc_366216787887_item	2344733	et	4	main
nii	doc_366216787887_item	2344734	et	3	main
rahulikult	doc_366216787887_item	2344735	et	4	main
kogu	doc_366216787887_item	2344739	et	4	main
laulsid	doc_366216787887_item	2344744	et	4	main
nad	doc_366216787887_item	2344748	et	3	main
oma	doc_366216787887_item	2344751	et	4	main
hingamisest	doc_366216787887_item	2344752	et	4	main
et	doc_366216787887_item	2344758	et	3	main
on	doc_366216787887_item	2344764	et	4	main
väga	doc_366216787887_item	2344765	et	3	main
tähtis	doc_366216787887_item	2344766	et	4	main
et	doc_366216787887_item	2344767	et	3	main
meie	doc_366216787887_item	2344774	et	4	main
vanemad	doc_366216787887_item	2344775	et	4	main
ja	doc_366216787887_item	2344776	et	3	main
ka	doc_366216787887_item	2344777	et	3	main
kui	doc_366216787887_item	2344799	et	3	main
tema	doc_366216787887_item	2344802	et	4	main
juurde	doc_366216787887_item	2344803	et	4	main
inimesed	doc_366216787887_item	2344709	et	3	main
tuli	doc_366216787887_item	2344713	et	4	main
videolõiged	doc_366216787887_item	2344722	et	4	main
võin	doc_366216787887_item	2344724	et	3	main
et	doc_366216787887_item	2344726	et	3	main
oli	doc_366216787887_item	2344728	et	3	main
ja	doc_366216787887_item	2344736	et	3	main
tundus	doc_366216787887_item	2344737	et	3	main
et	doc_366216787887_item	2344738	et	3	main
on	doc_366216787887_item	2344760	et	4	main
minu	doc_366216787887_item	2344762	et	3	main
huvi	doc_366216787887_item	2344771	et	4	main
on	doc_366216787887_item	2344781	et	4	main
oma	doc_366216787887_item	2344786	et	4	main
ta	doc_366216787887_item	2344805	et	4	main
laulab	doc_366216787887_item	2344806	et	3	main
lihtsalt	doc_366216787887_item	2344807	et	4	main
laulab	doc_366216787887_item	2344808	et	3	main
nad	doc_366216787887_item	2344822	et	3	main
10	doc_366216787887_item	2344825	et	2	main
väga	doc_366216787887_item	2344842	et	3	main
igal	doc_366216787887_item	2344844	et	3	main
on	doc_366216787887_item	2344846	et	4	main
oma	doc_366216787887_item	2344847	et	4	main
traditsioonid	doc_366216787887_item	2344848	et	3	main
aastal	doc_366216787887_item	2344858	et	3	main
kahes	doc_366216787887_item	2344868	et	4	main
linnas	doc_366216787887_item	2344869	et	4	main
tartus	doc_366216787887_item	2344870	et	3	main
tallinnas	doc_366216787887_item	2344872	et	4	main
et	doc_366216787887_item	2344901	et	3	main
kogu	doc_366216787887_item	2344916	et	4	main
huvitav	doc_366216787887_item	2344730	et	4	main
mis	doc_366216787887_item	2344742	et	4	main
ja	doc_366216787887_item	2344745	et	3	main
südamest	doc_366216787887_item	2344754	et	4	main
millest	doc_366216787887_item	2344755	et	3	main
öelda	doc_366216787887_item	2344757	et	4	main
arust	doc_366216787887_item	2344763	et	4	main
tunnevad	doc_366216787887_item	2344770	et	3	main
mitte	doc_366216787887_item	2344772	et	3	main
inimesed	doc_366216787887_item	2344779	et	3	main
kui	doc_366216787887_item	2344783	et	3	main
tunnevad	doc_366216787887_item	2344785	et	3	main
on	doc_366216787887_item	2344794	et	4	main
vanaema	doc_366216787887_item	2344795	et	4	main
ma	doc_366216787887_item	2344800	et	3	main
algusest	doc_366216787887_item	2344809	et	4	main
ma	doc_366216787887_item	2344810	et	3	main
ei	doc_366216787887_item	2344811	et	4	main
saanud	doc_366216787887_item	2344812	et	4	main
sellest	doc_366216787887_item	2344813	et	4	main
aru	doc_366216787887_item	2344814	et	4	main
nüüd	doc_366216787887_item	2344815	et	4	main
ma	doc_366216787887_item	2344816	et	3	main
saan	doc_366216787887_item	2344817	et	4	main
ta	doc_366216787887_item	2344818	et	4	main
rääkis	doc_366216787887_item	2344819	et	3	main
mulle	doc_366216787887_item	2344820	et	4	main
kogunesid	doc_366216787887_item	2344824	et	4	main
tähistasid	doc_366216787887_item	2344830	et	4	main
tähtis	doc_366216787887_item	2344843	et	4	main
ei	doc_366216787887_item	2344853	et	4	main
keegi	doc_366216787887_item	2344855	et	4	main
muuta	doc_366216787887_item	2344856	et	4	main
1994	doc_366216787887_item	2344857	et	2	main
pidu	doc_366216787887_item	2344866	et	4	main
korraldati	doc_366216787887_item	2344867	et	3	main
kultuur	doc_366216787887_item	2344904	et	3	main
ja	doc_366216787887_item	2344906	et	3	main
inimesed	doc_366216787887_item	2344909	et	3	main
oma	doc_366216787887_item	2344911	et	4	main
koos	doc_366216787887_item	2344914	et	4	main
ja	doc_366216787887_item	2344915	et	3	main
tore	doc_366216787887_item	2344921	et	3	main
essee	doc_366216787888_item	2344931	et	4	main
mis	doc_366216787888_item	2344933	et	4	main
essee	doc_366216787888_item	2344937	et	4	main
300	doc_366216787888_item	2344939	et	2	main
arutlev	doc_366216787888_item	2344945	et	4	main
ajal	doc_366216787888_item	2344961	et	4	main
eestlaste	doc_366216787888_item	2344962	et	4	main
jaoks	doc_366216787888_item	2344963	et	4	main
muud	doc_366216787888_item	2344993	et	4	main
võib	doc_366216787888_item	2344998	et	3	main
minevik	doc_366216787888_item	2345001	et	3	main
eesti	doc_366216787888_item	2345008	et	4	main
mis	doc_366216787888_item	2345014	et	4	main
teeb	doc_366216787888_item	2345015	et	3	main
eestlastest	doc_366216787888_item	2345016	et	4	main
laulu	doc_366216787888_item	2345021	et	4	main
juba	doc_366216787888_item	2345023	et	3	main
ülemaaline	doc_366216787888_item	2345029	et	4	main
1869	doc_366216787888_item	2345031	et	2	main
tartus	doc_366216787888_item	2345032	et	3	main
idee	doc_366216787888_item	2345033	et	4	main
oli	doc_366216787888_item	2345035	et	3	main
sai	doc_366216787888_item	2345046	et	4	main
traditsioonid	doc_366216787888_item	2345051	et	3	main
meie	doc_366216787888_item	2345055	et	4	main
tartu	doc_366216787888_item	2345061	et	4	main
19	doc_366216787888_item	2345063	et	2	main
jüübelilaulupidude	doc_366216787888_item	2345072	et	4	main
20	doc_366216787887_item	2344826	et	2	main
eestlast	doc_366216787887_item	2344836	et	4	main
mis	doc_366216787887_item	2344838	et	4	main
on	doc_366216787887_item	2344839	et	4	main
aastat	doc_366216787887_item	2344861	et	3	main
laulupidude	doc_366216787887_item	2344863	et	4	main
te	doc_366216787887_item	2344873	et	4	main
võite	doc_366216787887_item	2344874	et	4	main
kujuneda	doc_366216787887_item	2344875	et	3	main
mis	doc_366216787887_item	2344876	et	4	main
päev	doc_366216787887_item	2344877	et	3	main
see	doc_366216787887_item	2344878	et	3	main
oli	doc_366216787887_item	2344879	et	3	main
see	doc_366216787887_item	2344880	et	3	main
oli	doc_366216787887_item	2344881	et	3	main
kõige	doc_366216787887_item	2344882	et	4	main
eestlaste	doc_366216787887_item	2344883	et	4	main
jaoks	doc_366216787887_item	2344884	et	4	main
suur	doc_366216787887_item	2344885	et	3	main
sündmus	doc_366216787887_item	2344886	et	3	main
mis	doc_366216787887_item	2344887	et	4	main
on	doc_366216787887_item	2344888	et	4	main
ajaloos	doc_366216787887_item	2344889	et	4	main
mida	doc_366216787887_item	2344890	et	4	main
hakkavad	doc_366216787887_item	2344891	et	4	main
mäletama	doc_366216787887_item	2344892	et	3	main
palju	doc_366216787887_item	2344893	et	4	main
aastaid	doc_366216787887_item	2344894	et	4	main
kõigest	doc_366216787887_item	2344895	et	4	main
sellest	doc_366216787887_item	2344896	et	4	main
ma	doc_366216787887_item	2344897	et	3	main
võin	doc_366216787887_item	2344898	et	3	main
kindlasti	doc_366216787887_item	2344899	et	3	main
öelda	doc_366216787887_item	2344900	et	4	main
eesti	doc_366216787887_item	2344902	et	4	main
elama	doc_366216787887_item	2344908	et	3	main
väga	doc_366216787887_item	2344920	et	3	main
essee	doc_366216787888_item	2344922	et	4	main
keele	doc_366216787888_item	2344924	et	4	main
kui	doc_366216787888_item	2344925	et	3	main
kirjutage	doc_366216787888_item	2344930	et	3	main
eestlastest	doc_366216787888_item	2344935	et	4	main
tuginema	doc_366216787888_item	2344949	et	3	main
vanal	doc_366216787888_item	2344960	et	3	main
elas	doc_366216787888_item	2344970	et	3	main
teha	doc_366216787888_item	2344995	et	3	main
arus	doc_366216787888_item	2345011	et	4	main
suur	doc_366216787888_item	2345012	et	3	main
meie	doc_366216787888_item	2345020	et	4	main
laulupidu	doc_366216787888_item	2345030	et	4	main
vanemuise	doc_366216787888_item	2345042	et	4	main
korraldamisele	doc_366216787888_item	2345050	et	4	main
siamaani	doc_366216787888_item	2345054	et	4	main
eesti	doc_366216787888_item	2345056	et	4	main
lõppus	doc_366216787888_item	2345065	et	4	main
tallinnas	doc_366216787888_item	2345070	et	4	main
sel	doc_366216787888_item	2345075	et	3	main
tähtsat	doc_366216787888_item	2345078	et	3	main
mu	doc_366216787888_item	2345080	et	3	main
arm	doc_366216787888_item	2345084	et	3	main
tehti	doc_366216787888_item	2345087	et	3	main
meeldib	doc_366216787888_item	2345091	et	3	main
isegi	doc_366216787888_item	2345093	et	4	main
paremat	doc_366216787888_item	2345127	et	4	main
eesti	doc_366216787888_item	2345132	et	4	main
lastega	doc_366216787888_item	2345145	et	3	main
näha	doc_366216787888_item	2345149	et	3	main
ilmuda	doc_366216787888_item	2345162	et	3	main
vanaajal	doc_366216787888_item	2345164	et	3	main
levinud	doc_366216787888_item	2345168	et	4	main
lauldakse	doc_366216787888_item	2345172	et	3	main
hakatakse	doc_366216787888_item	2345176	et	3	main
huvi	doc_366216787888_item	2345180	et	4	main
et	doc_366216787888_item	2345207	et	3	main
tantsida	doc_366216787888_item	2345211	et	3	main
laulda	doc_366216787888_item	2345213	et	4	main
selle	doc_366216787888_item	2345214	et	4	main
eestlastest	doc_366216787888_item	2345220	et	4	main
vanad	doc_366216787888_item	2345223	et	3	main
ja	doc_366216787888_item	2345225	et	3	main
teised	doc_366216787888_item	2345227	et	4	main
on	doc_366216787888_item	2345234	et	4	main
mis	doc_366216787888_item	2345239	et	4	main
ilu	doc_366216787888_item	2345241	et	4	main
tahmist	doc_366216787888_item	2345243	et	4	main
jääda	doc_366216787888_item	2345244	et	4	main
sinna	doc_366216787888_item	2345245	et	3	main
igaveseks	doc_366216787888_item	2345246	et	4	main
neid	doc_366216787888_item	2345254	et	4	main
lastele	doc_366216787888_item	2345256	et	4	main
keele	doc_366216787888_item	2344927	et	4	main
kirjutamine	doc_366216787888_item	2344929	et	4	main
laulurahva	doc_366216787888_item	2344936	et	3	main
essee	doc_366216787888_item	2344942	et	4	main
üldistav	doc_366216787888_item	2344948	et	4	main
ja	doc_366216787888_item	2344951	et	3	main
lugemistekstis	doc_366216787888_item	2344952	et	3	main
faktidele	doc_366216787888_item	2344954	et	3	main
väiteid	doc_366216787888_item	2344955	et	4	main
elu	doc_366216787888_item	2344968	et	4	main
see	doc_366216787888_item	2344971	et	3	main
ehk	doc_366216787888_item	2344973	et	3	main
laulmine	doc_366216787888_item	2344974	et	4	main
laul	doc_366216787888_item	2344972	et	4	main
inimeste	doc_366216787888_item	2344975	et	3	main
sees	doc_366216787888_item	2344976	et	4	main
võib	doc_366216787888_item	2344977	et	3	main
öelda	doc_366216787888_item	2344978	et	4	main
hinges	doc_366216787888_item	2344979	et	4	main
laul	doc_366216787888_item	2344980	et	4	main
saatis	doc_366216787888_item	2344981	et	3	main
teda	doc_366216787888_item	2344982	et	4	main
sündisest	doc_366216787888_item	2344983	et	4	main
surmani	doc_366216787888_item	2344984	et	3	main
koos	doc_366216787888_item	2344985	et	4	main
laulaga	doc_366216787888_item	2344986	et	4	main
eestlased	doc_366216787888_item	2344987	et	3	main
võibid	doc_366216787888_item	2344988	et	4	main
töötada	doc_366216787888_item	2344989	et	3	main
last	doc_366216787888_item	2344990	et	4	main
liigutada	doc_366216787888_item	2344991	et	3	main
ja	doc_366216787888_item	2344992	et	3	main
esitatud	doc_366216787888_item	2344953	et	4	main
on	doc_366216787888_item	2344956	et	4	main
laul	doc_366216787888_item	2344964	et	4	main
tähendas	doc_366216787888_item	2344965	et	3	main
jooksul	doc_366216787888_item	2344969	et	4	main
panus	doc_366216787888_item	2345013	et	4	main
laulurahva	doc_366216787888_item	2345017	et	3	main
see	doc_366216787888_item	2345018	et	3	main
19	doc_366216787888_item	2345024	et	2	main
eestlased	doc_366216787888_item	2345026	et	3	main
korraldasid	doc_366216787888_item	2345027	et	4	main
j	doc_366216787888_item	2345036	et	4	main
v	doc_366216787888_item	2345037	et	4	main
jannsen	doc_366216787888_item	2345038	et	4	main
ise	doc_366216787888_item	2345039	et	4	main
seltsist	doc_366216787888_item	2345043	et	4	main
näitavad	doc_366216787888_item	2345052	et	4	main
rahvamuusikat	doc_366216787888_item	2345057	et	3	main
sajandi	doc_366216787888_item	2345064	et	3	main
tähistati	doc_366216787888_item	2345071	et	4	main
100	doc_366216787888_item	2345073	et	2	main
isamaalaulu	doc_366216787888_item	2345079	et	4	main
isamaa	doc_366216787888_item	2345081	et	4	main
eesti	doc_366216787888_item	2345088	et	4	main
hümniks	doc_366216787888_item	2345089	et	3	main
oma	doc_366216787888_item	2345121	et	4	main
meie	doc_366216787888_item	2345128	et	4	main
iga	doc_366216787888_item	2345135	et	4	main
iga	doc_366216787888_item	2345138	et	4	main
väikestest	doc_366216787888_item	2345139	et	4	main
nurgadest	doc_366216787888_item	2345140	et	4	main
eestist	doc_366216787888_item	2345141	et	3	main
tullakse	doc_366216787888_item	2345142	et	3	main
pered	doc_366216787888_item	2345143	et	3	main
koos	doc_366216787888_item	2345144	et	4	main
et	doc_366216787888_item	2345148	et	3	main
selle	doc_366216787888_item	2345158	et	4	main
tunne	doc_366216787888_item	2345159	et	4	main
tantsitakse	doc_366216787888_item	2345170	et	3	main
nii	doc_366216787888_item	2345205	et	3	main
seto	doc_366216787888_item	2345218	et	4	main
laulurahva	doc_366216787888_item	2345221	et	3	main
inimesed	doc_366216787888_item	2345224	et	3	main
rahvaluulega	doc_366216787888_item	2345231	et	3	main
jääme	doc_366216787888_item	2345247	et	4	main
tava	doc_366216787888_item	2345251	et	4	main
eesti	doc_366216787890_item	2345345	et	4	main
kui	doc_366216787890_item	2345347	et	3	main
teise	doc_366216787890_item	2345348	et	4	main
300	doc_366216787890_item	2345361	et	2	main
faktidele	doc_366216787890_item	2345376	et	3	main
aastaid	doc_366216787890_item	2345384	et	4	main
tagasi	doc_366216787890_item	2345385	et	3	main
oli	doc_366216787890_item	2345386	et	3	main
laulmine	doc_366216787890_item	2345387	et	4	main
eestis	doc_366216787890_item	2345388	et	3	main
väga	doc_366216787890_item	2345389	et	3	main
töötades	doc_366216787890_item	2345392	et	3	main
kiigutades	doc_366216787890_item	2345395	et	3	main
väga	doc_366216787890_item	2345399	et	3	main
laulasid	doc_366216787890_item	2345402	et	4	main
laulas	doc_366216787890_item	2345417	et	4	main
laule	doc_366216787890_item	2345422	et	4	main
on	doc_366216787890_item	2345428	et	4	main
kust	doc_366216787890_item	2345432	et	4	main
saavad	doc_366216787890_item	2345434	et	4	main
kuulata	doc_366216787890_item	2345435	et	4	main
rahvalaule	doc_366216787890_item	2345436	et	4	main
eesti	doc_366216787888_item	2344996	et	4	main
rahva	doc_366216787888_item	2345000	et	3	main
päris	doc_366216787888_item	2345006	et	4	main
palju	doc_366216787888_item	2345007	et	4	main
minu	doc_366216787888_item	2345010	et	3	main
traditsioonid	doc_366216787888_item	2345022	et	3	main
tegija	doc_366216787888_item	2345034	et	4	main
ta	doc_366216787888_item	2345040	et	4	main
oli	doc_366216787888_item	2345041	et	3	main
sündmusest	doc_366216787888_item	2345045	et	4	main
järgnevate	doc_366216787888_item	2345048	et	4	main
meile	doc_366216787888_item	2345053	et	4	main
ning	doc_366216787888_item	2345058	et	3	main
peale	doc_366216787888_item	2345060	et	4	main
suursündmust	doc_366216787888_item	2345062	et	3	main
1896	doc_366216787888_item	2345066	et	2	main
hakkavad	doc_366216787888_item	2345068	et	4	main
korraldama	doc_366216787888_item	2345069	et	3	main
aastapäeva	doc_366216787888_item	2345074	et	4	main
pärast	doc_366216787888_item	2345086	et	4	main
eestlastele	doc_366216787888_item	2345090	et	4	main
mis	doc_366216787888_item	2345002	et	4	main
võib	doc_366216787888_item	2345003	et	3	main
öelda	doc_366216787888_item	2345004	et	4	main
meile	doc_366216787888_item	2345005	et	4	main
ajaloost	doc_366216787888_item	2345009	et	4	main
on	doc_366216787888_item	2345019	et	4	main
sajandil	doc_366216787888_item	2345025	et	3	main
esimese	doc_366216787888_item	2345028	et	3	main
sellest	doc_366216787888_item	2345044	et	4	main
aluse	doc_366216787888_item	2345047	et	4	main
üldlaulupidude	doc_366216787888_item	2345049	et	4	main
tavad	doc_366216787888_item	2345059	et	3	main
laulupeod	doc_366216787888_item	2345067	et	4	main
minu	doc_366216787888_item	2345083	et	3	main
laulda	doc_366216787888_item	2345092	et	4	main
vanasti	doc_366216787888_item	2345094	et	3	main
oli	doc_366216787888_item	2345095	et	3	main
loodud	doc_366216787888_item	2345096	et	4	main
emalaul	doc_366216787888_item	2345097	et	4	main
selline	doc_366216787888_item	2345098	et	4	main
laul	doc_366216787888_item	2345099	et	4	main
oli	doc_366216787888_item	2345100	et	3	main
rohkem	doc_366216787888_item	2345101	et	4	main
pühendatud	doc_366216787888_item	2345102	et	4	main
väikestele	doc_366216787888_item	2345103	et	4	main
lastele	doc_366216787888_item	2345104	et	4	main
emade	doc_366216787888_item	2345105	et	3	main
poolt	doc_366216787888_item	2345106	et	4	main
laulda	doc_366216787888_item	2345107	et	4	main
oli	doc_366216787888_item	2345108	et	3	main
vaja	doc_366216787888_item	2345109	et	4	main
aeglaselt	doc_366216787888_item	2345110	et	4	main
ja	doc_366216787888_item	2345111	et	3	main
rütmi	doc_366216787888_item	2345112	et	4	main
järgi	doc_366216787888_item	2345113	et	4	main
väike	doc_366216787888_item	2345114	et	4	main
laps	doc_366216787888_item	2345115	et	4	main
hakkas	doc_366216787888_item	2345116	et	3	main
magada	doc_366216787888_item	2345117	et	3	main
iga	doc_366216787888_item	2345118	et	4	main
ema	doc_366216787888_item	2345119	et	4	main
armastab	doc_366216787888_item	2345120	et	3	main
last	doc_366216787888_item	2345122	et	4	main
ja	doc_366216787888_item	2345123	et	3	main
maailmas	doc_366216787888_item	2345130	et	3	main
ehk	doc_366216787888_item	2345131	et	3	main
riigis	doc_366216787888_item	2345133	et	3	main
tulevad	doc_366216787888_item	2345146	et	4	main
ilusat	doc_366216787888_item	2345151	et	3	main
kõik	doc_366216787888_item	2345154	et	4	main
järgi	doc_366216787888_item	2345160	et	4	main
pulmadel	doc_366216787888_item	2345166	et	3	main
koos	doc_366216787888_item	2345209	et	4	main
väike	doc_366216787888_item	2345215	et	4	main
rahvus	doc_366216787888_item	2345216	et	3	main
kõik	doc_366216787888_item	2345226	et	4	main
ning	doc_366216787888_item	2345232	et	3	main
traditsioon	doc_366216787888_item	2345238	et	3	main
meeles	doc_366216787888_item	2345248	et	3	main
laulupidu	doc_366216787888_item	2345076	et	4	main
sai	doc_366216787888_item	2345077	et	4	main
on	doc_366216787888_item	2345082	et	4	main
mis	doc_366216787888_item	2345085	et	4	main
kaasaegse	doc_366216787888_item	2345129	et	3	main
korraldatakse	doc_366216787888_item	2345134	et	3	main
pidudele	doc_366216787888_item	2345147	et	4	main
seda	doc_366216787888_item	2345150	et	3	main
ja	doc_366216787888_item	2345171	et	3	main
vanu	doc_366216787888_item	2345173	et	4	main
meenutada	doc_366216787888_item	2345177	et	3	main
vanaaja	doc_366216787888_item	2345178	et	3	main
lähedal	doc_366216787888_item	2345206	et	4	main
nendega	doc_366216787888_item	2345210	et	4	main
ja	doc_366216787888_item	2345212	et	3	main
teebki	doc_366216787888_item	2345219	et	3	main
püüab	doc_366216787888_item	2345124	et	3	main
luua	doc_366216787888_item	2345125	et	4	main
kõige	doc_366216787888_item	2345126	et	4	main
aasta	doc_366216787888_item	2345136	et	4	main
laulupidusid	doc_366216787888_item	2345137	et	4	main
korraldust	doc_366216787888_item	2345152	et	4	main
nad	doc_366216787888_item	2345153	et	3	main
laulavad	doc_366216787888_item	2345155	et	4	main
kaasa	doc_366216787888_item	2345156	et	4	main
ja	doc_366216787888_item	2345157	et	3	main
võib	doc_366216787888_item	2345161	et	3	main
hetkeks	doc_366216787888_item	2345163	et	4	main
eesti	doc_366216787888_item	2345165	et	4	main
on	doc_366216787888_item	2345167	et	4	main
rahvalaulud	doc_366216787888_item	2345169	et	3	main
laulu	doc_366216787888_item	2345174	et	4	main
ning	doc_366216787888_item	2345175	et	3	main
suur	doc_366216787888_item	2345179	et	3	main
pakkub	doc_366216787888_item	2345181	et	4	main
seto	doc_366216787888_item	2345182	et	4	main
maailm	doc_366216787888_item	2345183	et	3	main
õnneks	doc_366216787888_item	2345184	et	4	main
mina	doc_366216787888_item	2345185	et	4	main
sain	doc_366216787888_item	2345186	et	3	main
näha	doc_366216787888_item	2345187	et	3	main
väikse	doc_366216787888_item	2345188	et	4	main
lauluväljakul	doc_366216787888_item	2345189	et	3	main
nende	doc_366216787888_item	2345190	et	4	main
kontsert	doc_366216787888_item	2345191	et	3	main
see	doc_366216787888_item	2345192	et	3	main
oli	doc_366216787888_item	2345193	et	3	main
värskas	doc_366216787888_item	2345194	et	4	main
mina	doc_366216787888_item	2345195	et	4	main
olin	doc_366216787888_item	2345196	et	3	main
vapustanud	doc_366216787888_item	2345197	et	4	main
nende	doc_366216787888_item	2345198	et	4	main
tegevusest	doc_366216787888_item	2345199	et	4	main
selle	doc_366216787888_item	2345200	et	4	main
pärast	doc_366216787888_item	2345201	et	4	main
ma	doc_366216787888_item	2345202	et	3	main
jälgisin	doc_366216787888_item	2345203	et	3	main
neid	doc_366216787888_item	2345204	et	4	main
tahaksin	doc_366216787888_item	2345208	et	3	main
nagu	doc_366216787888_item	2345217	et	3	main
need	doc_366216787888_item	2345222	et	3	main
kes	doc_366216787888_item	2345228	et	4	main
rahvatantsiga	doc_366216787888_item	2345233	et	3	main
suur	doc_366216787888_item	2345236	et	3	main
ja	doc_366216787888_item	2345242	et	3	main
rahva	doc_366216787888_item	2345250	et	3	main
ja	doc_366216787888_item	2345252	et	3	main
meie	doc_366216787888_item	2345255	et	4	main
test	doc_366216787890_item	2345350	et	3	main
pikkus	doc_366216787890_item	2345360	et	4	main
peab	doc_366216787890_item	2345365	et	4	main
olema	doc_366216787890_item	2345366	et	4	main
arutlev	doc_366216787890_item	2345367	et	4	main
üldistav	doc_366216787890_item	2345370	et	4	main
tuginema	doc_366216787890_item	2345371	et	3	main
loengus	doc_366216787890_item	2345372	et	3	main
ja	doc_366216787890_item	2345373	et	3	main
lugemistekstis	doc_366216787890_item	2345374	et	3	main
esitatud	doc_366216787890_item	2345375	et	4	main
väiteid	doc_366216787890_item	2345377	et	4	main
eesti	doc_366216787890_item	2345396	et	4	main
ta	doc_366216787890_item	2345416	et	4	main
mulle	doc_366216787890_item	2345418	et	4	main
nüüd	doc_366216787890_item	2345420	et	4	main
tegelevad	doc_366216787888_item	2345229	et	4	main
rahvalauluga	doc_366216787888_item	2345230	et	4	main
eesti	doc_366216787888_item	2345235	et	4	main
rahva	doc_366216787888_item	2345237	et	3	main
näitab	doc_366216787888_item	2345240	et	3	main
kõike	doc_366216787888_item	2345249	et	4	main
õppetame	doc_366216787888_item	2345253	et	4	main
kirjutamine	doc_366216787890_item	2345351	et	4	main
kirjutage	doc_366216787890_item	2345352	et	3	main
essee	doc_366216787890_item	2345353	et	4	main
teemal	doc_366216787890_item	2345354	et	3	main
mis	doc_366216787890_item	2345355	et	4	main
teeb	doc_366216787890_item	2345356	et	3	main
eestlastest	doc_366216787890_item	2345357	et	4	main
350	doc_366216787890_item	2345362	et	2	main
essee	doc_366216787890_item	2345364	et	4	main
ja	doc_366216787890_item	2345369	et	3	main
on	doc_366216787890_item	2345378	et	4	main
palju	doc_366216787890_item	2345383	et	4	main
laulutraditsioonid	doc_366216787890_item	2345397	et	3	main
vanad	doc_366216787890_item	2345400	et	3	main
suureks	doc_366216787890_item	2345408	et	4	main
hakkasid	doc_366216787890_item	2345409	et	4	main
ise	doc_366216787890_item	2345410	et	4	main
laulma	doc_366216787890_item	2345411	et	3	main
mäletan	doc_366216787890_item	2345412	et	3	main
oma	doc_366216787890_item	2345413	et	4	main
lastele	doc_366216787890_item	2345424	et	4	main
eestis	doc_366216787890_item	2345427	et	3	main
minu	doc_366216787890_item	2345437	et	3	main
meeles	doc_366216787890_item	2345438	et	3	main
see	doc_366216787890_item	2345439	et	3	main
meie	doc_366216787890_item	2345441	et	4	main
laulmine	doc_366216787890_item	2345449	et	4	main
tihti	doc_366216787890_item	2345453	et	3	main
ja	doc_366216787890_item	2345459	et	3	main
populaarsed	doc_366216787890_item	2345464	et	3	main
palju	doc_366216787890_item	2345490	et	4	main
akadeemia	doc_366216787890_item	2345499	et	4	main
kus	doc_366216787890_item	2345500	et	3	main
võib	doc_366216787890_item	2345501	et	3	main
rahvalaule	doc_366216787890_item	2345503	et	4	main
heleloojad	doc_366216787890_item	2345510	et	3	main
on	doc_366216787890_item	2345512	et	4	main
ainult	doc_366216787890_item	2345515	et	4	main
väid	doc_366216787890_item	2345517	et	4	main
välismaal	doc_366216787890_item	2345519	et	4	main
keele	doc_366216787890_item	2345349	et	4	main
laulurahva	doc_366216787890_item	2345358	et	3	main
analüüsiv	doc_366216787890_item	2345368	et	4	main
soovitatav	doc_366216787890_item	2345379	et	4	main
juba	doc_366216787890_item	2345382	et	3	main
on	doc_366216787890_item	2345398	et	4	main
oma	doc_366216787890_item	2345403	et	4	main
lastele	doc_366216787890_item	2345404	et	4	main
kui	doc_366216787890_item	2345405	et	3	main
lapsed	doc_366216787890_item	2345406	et	3	main
kasvasid	doc_366216787890_item	2345407	et	4	main
vanaema	doc_366216787890_item	2345414	et	4	main
sama	doc_366216787890_item	2345421	et	4	main
praegu	doc_366216787890_item	2345426	et	3	main
inimesed	doc_366216787890_item	2345433	et	3	main
eestlastele	doc_366216787890_item	2345451	et	4	main
elada	doc_366216787890_item	2345452	et	3	main
inimesed	doc_366216787890_item	2345454	et	3	main
lihtsalt	doc_366216787890_item	2345460	et	4	main
väga	doc_366216787890_item	2345463	et	3	main
on	doc_366216787890_item	2345466	et	4	main
emalaulud	doc_366216787890_item	2345467	et	3	main
on	doc_366216787890_item	2345488	et	4	main
oma	doc_366216787890_item	2345492	et	4	main
areneda	doc_366216787890_item	2345494	et	3	main
on	doc_366216787890_item	2345496	et	4	main
olemas	doc_366216787890_item	2345497	et	4	main
kunstikultuuri	doc_366216787890_item	2345498	et	4	main
laulda	doc_366216787890_item	2345504	et	4	main
ka	doc_366216787890_item	2345508	et	3	main
mitte	doc_366216787890_item	2345514	et	3	main
stiilid	doc_366216787890_item	2345526	et	4	main
koraalilaulud	doc_366216787890_item	2345528	et	4	main
toimub	doc_366216787890_item	2345535	et	3	main
pida	doc_366216787890_item	2345546	et	4	main
massilisem	doc_366216787890_item	2345552	et	4	main
meie	doc_366216787890_item	2345567	et	4	main
essee	doc_366216787890_item	2345344	et	4	main
keele	doc_366216787890_item	2345346	et	4	main
essee	doc_366216787890_item	2345359	et	4	main
sõna	doc_366216787890_item	2345363	et	4	main
illustreerida	doc_366216787890_item	2345380	et	3	main
näidetega	doc_366216787890_item	2345381	et	3	main
oluline	doc_366216787890_item	2345390	et	4	main
lauldi	doc_366216787890_item	2345391	et	3	main
pidudel	doc_366216787890_item	2345393	et	4	main
last	doc_366216787890_item	2345394	et	4	main
emad	doc_366216787890_item	2345401	et	3	main
kui	doc_366216787890_item	2345415	et	3	main
võin	doc_366216787890_item	2345419	et	3	main
oma	doc_366216787890_item	2345423	et	4	main
olemas	doc_366216787890_item	2345429	et	4	main
töörütmi	doc_366216787890_item	2345457	et	4	main
ka	doc_366216787890_item	2345489	et	3	main
võimalusi	doc_366216787890_item	2345491	et	3	main
ka	doc_366216787890_item	2345502	et	3	main
riikidest	doc_366216787890_item	2345521	et	3	main
eestisse	doc_366216787890_item	2345523	et	4	main
väga	doc_366216787890_item	2345529	et	3	main
kogu	doc_366216787890_item	2345539	et	4	main
eestist	doc_366216787890_item	2345540	et	3	main
tulevad	doc_366216787890_item	2345541	et	4	main
kõige	doc_366216787890_item	2345551	et	4	main
tähelepanuväärsem	doc_366216787890_item	2345554	et	4	main
manifestatsioon	doc_366216787890_item	2345555	et	3	main
lihtsamaks	doc_366216787890_item	2345569	et	4	main
aitab	doc_366216787890_item	2345570	et	3	main
lahendama	doc_366216787890_item	2345571	et	3	main
probleemi	doc_366216787890_item	2345572	et	4	main
mitte	doc_366216787890_item	2345573	et	3	main
nutma	doc_366216787890_item	2345574	et	3	main
kurb	doc_366216787890_item	2345576	et	3	main
laulda	doc_366216787890_item	2345425	et	4	main
ka	doc_366216787890_item	2345430	et	3	main
laulusaated	doc_366216787890_item	2345431	et	3	main
vanemate	doc_366216787890_item	2345445	et	4	main
ja	doc_366216787890_item	2345446	et	3	main
vanavanemate	doc_366216787890_item	2345447	et	4	main
kultuur	doc_366216787890_item	2345448	et	3	main
et	doc_366216787890_item	2345456	et	3	main
hoida	doc_366216787890_item	2345458	et	3	main
vormis	doc_366216787890_item	2345461	et	4	main
olla	doc_366216787890_item	2345462	et	3	main
eestis	doc_366216787890_item	2345465	et	3	main
rohkem	doc_366216787890_item	2345469	et	4	main
naised	doc_366216787890_item	2345470	et	3	main
isegi	doc_366216787890_item	2345471	et	4	main
kurbelaule	doc_366216787890_item	2345472	et	4	main
mulle	doc_366216787890_item	2345473	et	4	main
näiteks	doc_366216787890_item	2345474	et	4	main
meeldib	doc_366216787890_item	2345475	et	3	main
laulda	doc_366216787890_item	2345476	et	4	main
oma	doc_366216787890_item	2345477	et	4	main
sõpradega	doc_366216787890_item	2345478	et	3	main
lihtsalt	doc_366216787890_item	2345479	et	4	main
jalutamas	doc_366216787890_item	2345480	et	3	main
minu	doc_366216787890_item	2345481	et	3	main
vanemad	doc_366216787890_item	2345482	et	4	main
laulavad	doc_366216787890_item	2345483	et	4	main
pidudel	doc_366216787890_item	2345484	et	4	main
laua	doc_366216787890_item	2345485	et	3	main
taga	doc_366216787890_item	2345486	et	4	main
aitab	doc_366216787890_item	2345440	et	3	main
lastele	doc_366216787890_item	2345442	et	4	main
tundma	doc_366216787890_item	2345443	et	3	main
nende	doc_366216787890_item	2345444	et	4	main
aitab	doc_366216787890_item	2345450	et	3	main
laulavad	doc_366216787890_item	2345455	et	4	main
laulavad	doc_366216787890_item	2345468	et	4	main
lauluoskusi	doc_366216787890_item	2345493	et	3	main
eestist	doc_366216787890_item	2345505	et	3	main
tuntuvad	doc_366216787890_item	2345513	et	4	main
ka	doc_366216787890_item	2345518	et	3	main
teistest	doc_366216787890_item	2345520	et	4	main
ka	doc_366216787890_item	2345524	et	3	main
ka	doc_366216787890_item	2345532	et	3	main
mis	doc_366216787890_item	2345534	et	4	main
tallinnas	doc_366216787890_item	2345536	et	4	main
laulupeol	doc_366216787890_item	2345537	et	4	main
inimesed	doc_366216787890_item	2345538	et	3	main
see	doc_366216787890_item	2345548	et	3	main
laulmine	doc_366216787890_item	2345565	et	4	main
on	doc_366216787890_item	2345577	et	4	main
eestis	doc_366216787890_item	2345487	et	3	main
meil	doc_366216787890_item	2345495	et	4	main
on	doc_366216787890_item	2345506	et	4	main
pärit	doc_366216787890_item	2345507	et	3	main
palju	doc_366216787890_item	2345509	et	4	main
kes	doc_366216787890_item	2345511	et	4	main
eestis	doc_366216787890_item	2345516	et	3	main
tulid	doc_366216787890_item	2345522	et	4	main
tundub	doc_366216787890_item	2345530	et	3	main
on	doc_366216787890_item	2345549	et	4	main
praegu	doc_366216787890_item	2345550	et	3	main
ja	doc_366216787890_item	2345553	et	3	main
laulurahvasena	doc_366216787890_item	2345563	et	4	main
kui	doc_366216787890_item	2345575	et	3	main
erinevad	doc_366216787890_item	2345525	et	4	main
kirikulaulud	doc_366216787890_item	2345527	et	3	main
eestis	doc_366216787890_item	2345531	et	3	main
laulupidu	doc_366216787890_item	2345533	et	4	main
tallinnasse	doc_366216787890_item	2345542	et	3	main
et	doc_366216787890_item	2345543	et	3	main
nautida	doc_366216787890_item	2345544	et	3	main
seda	doc_366216787890_item	2345545	et	3	main
sest	doc_366216787890_item	2345547	et	4	main
eestis	doc_366216787890_item	2345556	et	3	main
minu	doc_366216787890_item	2345557	et	3	main
meeles	doc_366216787890_item	2345558	et	3	main
eestlased	doc_366216787890_item	2345559	et	3	main
olid	doc_366216787890_item	2345560	et	4	main
ja	doc_366216787890_item	2345561	et	3	main
jäävad	doc_366216787890_item	2345562	et	4	main
sest	doc_366216787890_item	2345564	et	4	main
teeb	doc_366216787890_item	2345566	et	3	main
elu	doc_366216787890_item	2345568	et	4	main
keele	doc_366216787893_item	2346055	et	4	main
mis	doc_366216787893_item	2346064	et	4	main
sõna	doc_366216787893_item	2346072	et	4	main
loengus	doc_366216787893_item	2346081	et	3	main
esitatud	doc_366216787893_item	2346084	et	4	main
faktidele	doc_366216787893_item	2346085	et	3	main
väiteid	doc_366216787893_item	2346086	et	4	main
on	doc_366216787893_item	2346087	et	4	main
mis	doc_366216787893_item	2346091	et	4	main
hästi	doc_366216787893_item	2346096	et	3	main
et	doc_366216787893_item	2346098	et	3	main
võib	doc_366216787893_item	2346107	et	3	main
töö	doc_366216787893_item	2346112	et	4	main
oma	doc_366216787893_item	2346122	et	4	main
siis	doc_366216787893_item	2346130	et	3	main
sajandi	doc_366216787893_item	2346142	et	3	main
laulutraditsioon	doc_366216787893_item	2346146	et	3	main
muutunud	doc_366216787893_item	2346149	et	4	main
esimesed	doc_366216787893_item	2346150	et	3	main
laulud	doc_366216787893_item	2346151	et	3	main
pärandati	doc_366216787893_item	2346152	et	4	main
suuliselt	doc_366216787893_item	2346153	et	4	main
laulud	doc_366216787893_item	2346154	et	3	main
elus	doc_366216787893_item	2346192	et	4	main
endast	doc_366216787893_item	2346195	et	4	main
rahvatantsu	doc_366216787893_item	2346205	et	4	main
ja	doc_366216787893_item	2346206	et	3	main
laulu	doc_366216787893_item	2346207	et	4	main
austab	doc_366216787893_item	2346208	et	3	main
nii	doc_366216787893_item	2346227	et	3	main
kui	doc_366216787893_item	2346243	et	3	main
rahvale	doc_366216787893_item	2346245	et	3	main
neid	doc_366216787893_item	2346260	et	4	main
rahvalaul	doc_366216787893_item	2346271	et	4	main
hästi	doc_366216787893_item	2346277	et	3	main
lõpus	doc_366216787893_item	2346291	et	4	main
tahan	doc_366216787893_item	2346292	et	3	main
et	doc_366216787893_item	2346294	et	3	main
300	doc_366216787893_item	2346070	et	2	main
peab	doc_366216787893_item	2346074	et	4	main
arutlev	doc_366216787893_item	2346076	et	4	main
analüüsiv	doc_366216787893_item	2346077	et	4	main
ja	doc_366216787893_item	2346078	et	3	main
teeb	doc_366216787893_item	2346092	et	3	main
mis	doc_366216787893_item	2346103	et	4	main
teeb	doc_366216787893_item	2346104	et	3	main
nendest	doc_366216787893_item	2346105	et	4	main
laulurahva	doc_366216787893_item	2346106	et	3	main
eestlane	doc_366216787893_item	2346119	et	3	main
oma	doc_366216787893_item	2346124	et	4	main
rahva	doc_366216787893_item	2346125	et	3	main
ajalugu	doc_366216787893_item	2346128	et	4	main
ta	doc_366216787893_item	2346132	et	4	main
väga	doc_366216787893_item	2346139	et	3	main
vana	doc_366216787893_item	2346140	et	4	main
selle	doc_366216787893_item	2346143	et	4	main
on	doc_366216787893_item	2346147	et	4	main
kaasnesid	doc_366216787893_item	2346158	et	4	main
plaksud	doc_366216787893_item	2346160	et	4	main
ilma	doc_366216787893_item	2346161	et	4	main
palju	doc_366216787893_item	2346193	et	4	main
et	doc_366216787893_item	2346197	et	3	main
hea	doc_366216787893_item	2346199	et	4	main
kui	doc_366216787893_item	2346200	et	3	main
inimene	doc_366216787893_item	2346201	et	3	main
teab	doc_366216787893_item	2346202	et	3	main
oma	doc_366216787893_item	2346217	et	4	main
keelt	doc_366216787893_item	2346218	et	4	main
sest	doc_366216787893_item	2346222	et	4	main
see	doc_366216787893_item	2346224	et	3	main
olnud	doc_366216787893_item	2346226	et	4	main
laulud	doc_366216787893_item	2346234	et	3	main
aitavad	doc_366216787893_item	2346235	et	4	main
abistavad	doc_366216787893_item	2346238	et	4	main
kas	doc_366216787893_item	2346239	et	3	main
rõõmus	doc_366216787893_item	2346242	et	4	main
kogu	doc_366216787893_item	2346261	et	4	main
annab	doc_366216787893_item	2346263	et	3	main
keele	doc_366216787893_item	2346058	et	4	main
teeb	doc_366216787893_item	2346065	et	3	main
350	doc_366216787893_item	2346071	et	2	main
üldistav	doc_366216787893_item	2346079	et	4	main
tuginema	doc_366216787893_item	2346080	et	3	main
lugemistekstis	doc_366216787893_item	2346083	et	3	main
näidetega	doc_366216787893_item	2346090	et	3	main
laulurahva	doc_366216787893_item	2346094	et	3	main
on	doc_366216787893_item	2346100	et	4	main
olla	doc_366216787893_item	2346108	et	3	main
elurõõm	doc_366216787893_item	2346111	et	3	main
teeb	doc_366216787893_item	2346113	et	3	main
tantsu	doc_366216787893_item	2346115	et	4	main
ja	doc_366216787893_item	2346116	et	3	main
laulurahva	doc_366216787893_item	2346117	et	3	main
peab	doc_366216787893_item	2346120	et	4	main
teadma	doc_366216787893_item	2346121	et	3	main
juured	doc_366216787893_item	2346123	et	3	main
alles	doc_366216787893_item	2346129	et	3	main
saada	doc_366216787893_item	2346133	et	4	main
laulurahvade	doc_366216787893_item	2346134	et	4	main
hulka	doc_366216787893_item	2346135	et	4	main
eesti	doc_366216787893_item	2346136	et	4	main
laulutraditsioon	doc_366216787893_item	2346137	et	3	main
mittu	doc_366216787893_item	2346141	et	4	main
jooksul	doc_366216787893_item	2346145	et	4	main
esinesid	doc_366216787893_item	2346155	et	4	main
ringis	doc_366216787893_item	2346156	et	4	main
neid	doc_366216787893_item	2346157	et	4	main
aga	doc_366216787893_item	2346164	et	3	main
ehitatud	doc_366216787893_item	2346166	et	4	main
oma	doc_366216787893_item	2346203	et	4	main
oma	doc_366216787893_item	2346209	et	4	main
on	doc_366216787893_item	2346212	et	4	main
inimesed	doc_366216787893_item	2346214	et	3	main
kes	doc_366216787893_item	2346215	et	4	main
armastavad	doc_366216787893_item	2346216	et	4	main
kui	doc_366216787893_item	2346223	et	3	main
siis	doc_366216787893_item	2346228	et	3	main
ära	doc_366216787893_item	2346230	et	4	main
rahvalaul	doc_366216787893_item	2346232	et	4	main
ja	doc_366216787893_item	2346237	et	3	main
mingi	doc_366216787893_item	2346252	et	4	main
rahvalaul	doc_366216787893_item	2346258	et	4	main
tähendab	doc_366216787893_item	2346273	et	3	main
eestlaste	doc_366216787893_item	2346274	et	4	main
jaoks	doc_366216787893_item	2346275	et	4	main
õnnelikkuks	doc_366216787893_item	2346283	et	4	main
öelda	doc_366216787893_item	2346293	et	4	main
tõeline	doc_366216787893_item	2346299	et	4	main
kui	doc_366216787893_item	2346056	et	3	main
kirjutamine	doc_366216787893_item	2346060	et	4	main
kirjutage	doc_366216787893_item	2346061	et	3	main
essee	doc_366216787893_item	2346062	et	4	main
teemal	doc_366216787893_item	2346063	et	3	main
eestlastest	doc_366216787893_item	2346066	et	4	main
laulurahva	doc_366216787893_item	2346067	et	3	main
olema	doc_366216787893_item	2346075	et	4	main
ja	doc_366216787893_item	2346082	et	3	main
illustreerida	doc_366216787893_item	2346089	et	3	main
eestlastest	doc_366216787893_item	2346093	et	4	main
on	doc_366216787893_item	2346095	et	4	main
teada	doc_366216787893_item	2346097	et	3	main
eestlased	doc_366216787893_item	2346099	et	3	main
aga	doc_366216787893_item	2346102	et	3	main
armastus	doc_366216787893_item	2346109	et	4	main
tõeline	doc_366216787893_item	2346118	et	4	main
essee	doc_366216787893_item	2346053	et	4	main
eesti	doc_366216787893_item	2346054	et	4	main
teise	doc_366216787893_item	2346057	et	4	main
test	doc_366216787893_item	2346059	et	3	main
essee	doc_366216787893_item	2346068	et	4	main
pikkus	doc_366216787893_item	2346069	et	4	main
essee	doc_366216787893_item	2346073	et	4	main
soovitatav	doc_366216787893_item	2346088	et	4	main
laulurahvas	doc_366216787893_item	2346101	et	4	main
usu	doc_366216787893_item	2346110	et	4	main
eestlastest	doc_366216787893_item	2346114	et	4	main
minevikku	doc_366216787893_item	2346126	et	4	main
ja	doc_366216787893_item	2346127	et	3	main
on	doc_366216787893_item	2346138	et	4	main
aja	doc_366216787893_item	2346144	et	4	main
natuke	doc_366216787893_item	2346148	et	4	main
pillideta	doc_366216787893_item	2346162	et	3	main
söltub	doc_366216787893_item	2346194	et	4	main
arvan	doc_366216787893_item	2346196	et	3	main
juured	doc_366216787893_item	2346204	et	3	main
eestlased	doc_366216787893_item	2346211	et	3	main
need	doc_366216787893_item	2346213	et	3	main
maa	doc_366216787893_item	2346219	et	4	main
ja	doc_366216787893_item	2346220	et	3	main
kadus	doc_366216787893_item	2346229	et	3	main
neid	doc_366216787893_item	2346236	et	4	main
häädas	doc_366216787893_item	2346240	et	4	main
pidu	doc_366216787893_item	2346253	et	4	main
ja	doc_366216787893_item	2346254	et	3	main
õnn	doc_366216787893_item	2346255	et	3	main
ka	doc_366216787893_item	2346256	et	3	main
laulab	doc_366216787893_item	2346257	et	3	main
luua	doc_366216787893_item	2346270	et	4	main
et	doc_366216787893_item	2346276	et	3	main
väga	doc_366216787893_item	2346285	et	3	main
teada	doc_366216787893_item	2346287	et	3	main
uurimine	doc_366216787893_item	2346296	et	4	main
aus	doc_366216787893_item	2346298	et	4	main
armastus	doc_366216787893_item	2346300	et	4	main
faktidele	doc_366216787895_item	2346622	et	3	main
vanemat	doc_366216787895_item	2346629	et	4	main
enam	doc_366216787895_item	2346640	et	4	main
tagasi	doc_366216787895_item	2346644	et	3	main
eesti	doc_366216787895_item	2346645	et	4	main
folkloori	doc_366216787895_item	2346658	et	4	main
rühmi	doc_366216787895_item	2346659	et	4	main
see	doc_366216787895_item	2346660	et	3	main
võib	doc_366216787893_item	2346131	et	3	main
jalapõrutused	doc_366216787893_item	2346159	et	3	main
nüüd	doc_366216787893_item	2346163	et	4	main
on	doc_366216787893_item	2346165	et	4	main
lauluväljak	doc_366216787893_item	2346167	et	3	main
laulu	doc_366216787893_item	2346168	et	4	main
kaasneb	doc_366216787893_item	2346169	et	3	main
muusika	doc_366216787893_item	2346170	et	4	main
palju	doc_366216787893_item	2346171	et	4	main
aastad	doc_366216787893_item	2346172	et	3	main
on	doc_366216787893_item	2346173	et	4	main
läbi	doc_366216787893_item	2346174	et	4	main
aga	doc_366216787893_item	2346175	et	3	main
rahvalaul	doc_366216787893_item	2346176	et	4	main
veel	doc_366216787893_item	2346177	et	4	main
elab	doc_366216787893_item	2346178	et	3	main
eestlaste	doc_366216787893_item	2346179	et	4	main
südames	doc_366216787893_item	2346180	et	3	main
nad	doc_366216787893_item	2346181	et	3	main
ei	doc_366216787893_item	2346182	et	4	main
unustanud	doc_366216787893_item	2346183	et	4	main
traditsioone	doc_366216787893_item	2346185	et	3	main
on	doc_366216787893_item	2346186	et	4	main
olemas	doc_366216787893_item	2346187	et	4	main
naiste-	doc_366216787893_item	2346188	et	3	main
laste-	doc_366216787893_item	2346189	et	4	main
oma	doc_366216787893_item	2346184	et	4	main
meestekoorid	doc_366216787893_item	2346190	et	3	main
tänapäevase	doc_366216787893_item	2346191	et	4	main
on	doc_366216787893_item	2346198	et	4	main
maa	doc_366216787893_item	2346210	et	4	main
traditsioone	doc_366216787893_item	2346221	et	3	main
ei	doc_366216787893_item	2346225	et	4	main
nende	doc_366216787893_item	2346231	et	4	main
nende	doc_366216787893_item	2346233	et	4	main
või	doc_366216787893_item	2346241	et	4	main
eesti	doc_366216787893_item	2346244	et	4	main
on	doc_366216787893_item	2346246	et	4	main
halb	doc_366216787893_item	2346247	et	3	main
ta	doc_366216787893_item	2346248	et	4	main
laulab	doc_366216787893_item	2346249	et	3	main
kui	doc_366216787893_item	2346250	et	3	main
on	doc_366216787893_item	2346251	et	4	main
viib	doc_366216787893_item	2346259	et	3	main
elu	doc_366216787893_item	2346262	et	4	main
hoogu	doc_366216787893_item	2346264	et	4	main
tahtejõudu	doc_366216787893_item	2346266	et	4	main
et	doc_366216787893_item	2346267	et	3	main
elus	doc_366216787893_item	2346268	et	4	main
hästi	doc_366216787893_item	2346269	et	3	main
elus	doc_366216787893_item	2346278	et	4	main
ja	doc_366216787893_item	2346280	et	3	main
ennast	doc_366216787893_item	2346282	et	4	main
ajaloo	doc_366216787893_item	2346295	et	4	main
elurõõm	doc_366216787893_item	2346301	et	3	main
teeb	doc_366216787893_item	2346302	et	3	main
eestlastest	doc_366216787893_item	2346303	et	4	main
laulurahva	doc_366216787893_item	2346304	et	3	main
ja	doc_366216787893_item	2346305	et	3	main
see	doc_366216787893_item	2346306	et	3	main
on	doc_366216787893_item	2346307	et	4	main
suur	doc_366216787893_item	2346308	et	3	main
õnn	doc_366216787893_item	2346309	et	3	main
et	doc_366216787893_item	2346310	et	3	main
nii	doc_366216787893_item	2346311	et	3	main
on	doc_366216787893_item	2346312	et	4	main
ja	doc_366216787893_item	2346265	et	3	main
palju	doc_366216787893_item	2346272	et	4	main
jõuda	doc_366216787893_item	2346279	et	3	main
tunda	doc_366216787893_item	2346281	et	3	main
on	doc_366216787893_item	2346284	et	4	main
tähtis	doc_366216787893_item	2346286	et	4	main
oma	doc_366216787893_item	2346288	et	4	main
rahva	doc_366216787893_item	2346289	et	3	main
traditsioonid	doc_366216787893_item	2346290	et	3	main
usu	doc_366216787893_item	2346297	et	4	main
väiteid	doc_366216787895_item	2346623	et	4	main
illustreerida	doc_366216787895_item	2346626	et	3	main
regivärsiline	doc_366216787895_item	2346635	et	4	main
kui	doc_366216787895_item	2346641	et	3	main
aastat	doc_366216787895_item	2346643	et	3	main
rahva	doc_366216787895_item	2346652	et	3	main
muusika	doc_366216787895_item	2346653	et	4	main
on	doc_366216787895_item	2346665	et	4	main
olen	doc_366216787895_item	2346668	et	3	main
ma	doc_366216787895_item	2346671	et	3	main
siis	doc_366216787895_item	2346703	et	3	main
ei	doc_366216787895_item	2346709	et	4	main
tantsida	doc_366216787895_item	2346711	et	3	main
vanem	doc_366216787895_item	2346718	et	4	main
riik	doc_366216787895_item	2346725	et	3	main
võib	doc_366216787895_item	2346727	et	3	main
eestlased	doc_366216787895_item	2346737	et	3	main
elavad	doc_366216787895_item	2346739	et	4	main
ka	doc_366216787895_item	2346741	et	3	main
traditsioonid	doc_366216787895_item	2346743	et	3	main
palju	doc_366216787895_item	2346745	et	4	main
esitatud	doc_366216787895_item	2346621	et	4	main
eesti	doc_366216787895_item	2346628	et	4	main
laulutraditsioon	doc_366216787895_item	2346630	et	3	main
esindab	doc_366216787895_item	2346631	et	3	main
läänemeresoome	doc_366216787895_item	2346632	et	3	main
kujunenud	doc_366216787895_item	2346639	et	4	main
tuhat	doc_366216787895_item	2346642	et	4	main
on	doc_366216787895_item	2346647	et	4	main
iseloomulikud	doc_366216787895_item	2346648	et	3	main
rahva	doc_366216787895_item	2346649	et	3	main
et	doc_366216787895_item	2346663	et	3	main
säilitakse	doc_366216787895_item	2346666	et	3	main
võin	doc_366216787895_item	2346672	et	3	main
laulavad	doc_366216787895_item	2346706	et	4	main
nad	doc_366216787895_item	2346708	et	3	main
eestis	doc_366216787895_item	2346715	et	3	main
nii	doc_366216787895_item	2346717	et	3	main
laulupeod	doc_366216787895_item	2346721	et	4	main
ja	doc_366216787895_item	2346726	et	3	main
ned	doc_366216787895_item	2346735	et	4	main
kaitsvad	doc_366216787895_item	2346742	et	4	main
loodustega	doc_366216787895_item	2346748	et	4	main
laulu	doc_366216787895_item	2346756	et	4	main
nautis	doc_366216787895_item	2346774	et	3	main
laulupidu	doc_366216787895_item	2346777	et	4	main
soovin	doc_366216787895_item	2346782	et	3	main
natukene	doc_366216787895_item	2346795	et	4	main
puhkem	doc_366216787895_item	2346796	et	4	main
eesti	doc_366216787895_item	2346591	et	4	main
essee	doc_366216787895_item	2346590	et	4	main
keele	doc_366216787895_item	2346592	et	4	main
kui	doc_366216787895_item	2346593	et	3	main
teise	doc_366216787895_item	2346594	et	4	main
keele	doc_366216787895_item	2346595	et	4	main
test	doc_366216787895_item	2346596	et	3	main
kirjutamine	doc_366216787895_item	2346597	et	4	main
kirjutage	doc_366216787895_item	2346598	et	3	main
essee	doc_366216787895_item	2346599	et	4	main
teemal	doc_366216787895_item	2346600	et	3	main
mis	doc_366216787895_item	2346601	et	4	main
teeb	doc_366216787895_item	2346602	et	3	main
laulurahva	doc_366216787895_item	2346604	et	3	main
eestlastest	doc_366216787895_item	2346603	et	4	main
essee	doc_366216787895_item	2346605	et	4	main
300	doc_366216787895_item	2346607	et	2	main
350	doc_366216787895_item	2346608	et	2	main
pikkus	doc_366216787895_item	2346606	et	4	main
sõna	doc_366216787895_item	2346609	et	4	main
essee	doc_366216787895_item	2346610	et	4	main
peab	doc_366216787895_item	2346611	et	4	main
olema	doc_366216787895_item	2346612	et	4	main
arutlev	doc_366216787895_item	2346613	et	4	main
analüüsiv	doc_366216787895_item	2346614	et	4	main
ja	doc_366216787895_item	2346615	et	3	main
üldistav	doc_366216787895_item	2346616	et	4	main
tuginema	doc_366216787895_item	2346617	et	3	main
loengus	doc_366216787895_item	2346618	et	3	main
ja	doc_366216787895_item	2346619	et	3	main
lugemistekstis	doc_366216787895_item	2346620	et	3	main
soovitatav	doc_366216787895_item	2346625	et	4	main
on	doc_366216787895_item	2346624	et	4	main
näidetega	doc_366216787895_item	2346627	et	3	main
kultuurile	doc_366216787895_item	2346633	et	3	main
mis	doc_366216787895_item	2346637	et	4	main
laulu	doc_366216787895_item	2346650	et	4	main
tantsu	doc_366216787895_item	2346651	et	4	main
meil	doc_366216787895_item	2346662	et	4	main
eestlastest	doc_366216787895_item	2346674	et	4	main
laulurahva	doc_366216787895_item	2346675	et	3	main
ainult	doc_366216787895_item	2346676	et	4	main
sellest	doc_366216787895_item	2346677	et	4	main
et	doc_366216787895_item	2346678	et	3	main
minu	doc_366216787895_item	2346679	et	3	main
arvatest	doc_366216787895_item	2346680	et	3	main
nende	doc_366216787895_item	2346681	et	4	main
laud	doc_366216787895_item	2346682	et	4	main
nende	doc_366216787895_item	2346684	et	4	main
eluviis	doc_366216787895_item	2346685	et	3	main
võib	doc_366216787895_item	2346686	et	3	main
olla	doc_366216787895_item	2346687	et	3	main
kujunevad	doc_366216787895_item	2346683	et	4	main
see	doc_366216787895_item	2346688	et	3	main
arvamus	doc_366216787895_item	2346689	et	3	main
ei	doc_366216787895_item	2346690	et	4	main
ole	doc_366216787895_item	2346691	et	4	main
õige	doc_366216787895_item	2346692	et	4	main
aga	doc_366216787895_item	2346693	et	3	main
ma	doc_366216787895_item	2346694	et	3	main
arvan	doc_366216787895_item	2346695	et	3	main
et	doc_366216787895_item	2346696	et	3	main
laulupeod	doc_366216787895_item	2346697	et	4	main
koosnevad	doc_366216787895_item	2346698	et	4	main
eestirahva	doc_366216787895_item	2346699	et	3	main
kui	doc_366216787895_item	2346700	et	3	main
alustab	doc_366216787895_item	2346702	et	3	main
iseloomulik	doc_366216787895_item	2346634	et	3	main
rahvalaul	doc_366216787895_item	2346636	et	4	main
on	doc_366216787895_item	2346638	et	4	main
rahval	doc_366216787895_item	2346646	et	3	main
mängu	doc_366216787895_item	2346654	et	4	main
praegu	doc_366216787895_item	2346655	et	3	main
on	doc_366216787895_item	2346656	et	4	main
palju	doc_366216787895_item	2346657	et	4	main
traditsioonid	doc_366216787895_item	2346664	et	3	main
ma	doc_366216787895_item	2346667	et	3	main
kindel	doc_366216787895_item	2346669	et	3	main
nimetada	doc_366216787895_item	2346673	et	3	main
inimesed	doc_366216787895_item	2346704	et	3	main
ainult	doc_366216787895_item	2346714	et	4	main
eesti	doc_366216787895_item	2346722	et	4	main
olla	doc_366216787895_item	2346728	et	3	main
saaremal	doc_366216787895_item	2346740	et	3	main
saatavad	doc_366216787895_item	2346755	et	3	main
olen	doc_366216787895_item	2346758	et	3	main
et	doc_366216787895_item	2346760	et	3	main
koosneb	doc_366216787895_item	2346762	et	3	main
mõtlen	doc_366216787895_item	2346763	et	3	main
et	doc_366216787895_item	2346764	et	3	main
lauluväljak	doc_366216787895_item	2346765	et	3	main
võib	doc_366216787895_item	2346766	et	3	main
et	doc_366216787895_item	2346775	et	3	main
eestlased	doc_366216787895_item	2346776	et	3	main
ajal	doc_366216787895_item	2346778	et	4	main
vabastavad	doc_366216787895_item	2346779	et	4	main
et	doc_366216787895_item	2346783	et	3	main
tulevikus	doc_366216787895_item	2346787	et	4	main
ja	doc_366216787895_item	2346789	et	3	main
mailm	doc_366216787895_item	2346794	et	4	main
ütleb	doc_366216787895_item	2346661	et	3	main
et	doc_366216787895_item	2346670	et	3	main
koos	doc_366216787895_item	2346705	et	4	main
traditsiion	doc_366216787895_item	2346719	et	4	main
nagu	doc_366216787895_item	2346720	et	3	main
siin	doc_366216787895_item	2346730	et	4	main
on	doc_366216787895_item	2346731	et	4	main
väga	doc_366216787895_item	2346732	et	3	main
sõbralikud	doc_366216787895_item	2346733	et	3	main
elanikud	doc_366216787895_item	2346734	et	3	main
elanikud	doc_366216787895_item	2346736	et	3	main
kes	doc_366216787895_item	2346738	et	4	main
suhtlevad	doc_366216787895_item	2346746	et	4	main
loomadega	doc_366216787895_item	2346747	et	3	main
tegivad	doc_366216787895_item	2346751	et	4	main
mis	doc_366216787895_item	2346753	et	4	main
nimetada	doc_366216787895_item	2346767	et	3	main
mind	doc_366216787895_item	2346773	et	4	main
saad	doc_366216787895_item	2346786	et	4	main
võib	doc_366216787895_item	2346790	et	3	main
300	doc_366216787897_item	2347084	et	2	main
sõna	doc_366216787897_item	2347086	et	4	main
on	doc_366216787897_item	2347101	et	4	main
me	doc_366216787897_item	2347105	et	4	main
on	doc_366216787897_item	2347112	et	4	main
mitte	doc_366216787897_item	2347121	et	3	main
kohal	doc_366216787897_item	2347123	et	4	main
sest	doc_366216787897_item	2347129	et	4	main
laulmine	doc_366216787897_item	2347137	et	4	main
on	doc_366216787897_item	2347138	et	4	main
rahvalaulu	doc_366216787897_item	2347159	et	4	main
ei	doc_366216787897_item	2347164	et	4	main
näiteks	doc_366216787897_item	2347204	et	4	main
ja	doc_366216787897_item	2347209	et	3	main
ringis	doc_366216787897_item	2347214	et	4	main
laulsid	doc_366216787897_item	2347215	et	4	main
naiskoorid	doc_366216787897_item	2347224	et	3	main
meil	doc_366216787897_item	2347227	et	4	main
me	doc_366216787897_item	2347232	et	4	main
saame	doc_366216787897_item	2347233	et	4	main
kuulata	doc_366216787897_item	2347234	et	4	main
lõuna-eestis	doc_366216787897_item	2347235	et	3	main
või	doc_366216787897_item	2347236	et	4	main
kihnu	doc_366216787897_item	2347237	et	4	main
saarel	doc_366216787897_item	2347238	et	3	main
öelda	doc_366216787897_item	2347241	et	4	main
vanemad	doc_366216787897_item	2347255	et	4	main
teavad	doc_366216787897_item	2347258	et	3	main
muutub	doc_366216787897_item	2347263	et	3	main
meil	doc_366216787897_item	2347265	et	4	main
on	doc_366216787897_item	2347266	et	4	main
laulda	doc_366216787897_item	2347314	et	4	main
laulurahva	doc_366216787897_item	2347323	et	3	main
pidu	doc_366216787895_item	2346701	et	4	main
tantsivad	doc_366216787895_item	2346707	et	4	main
või	doc_366216787895_item	2346710	et	4	main
rahvariide	doc_366216787895_item	2346712	et	4	main
vaba	doc_366216787895_item	2346713	et	4	main
on	doc_366216787895_item	2346716	et	4	main
on	doc_366216787895_item	2346723	et	4	main
väike	doc_366216787895_item	2346724	et	4	main
selles	doc_366216787895_item	2346729	et	4	main
lapsed	doc_366216787895_item	2346744	et	3	main
ja	doc_366216787895_item	2346749	et	3	main
isegi	doc_366216787895_item	2346750	et	4	main
luletusi	doc_366216787895_item	2346752	et	4	main
vabaduse	doc_366216787895_item	2346768	et	4	main
väljak	doc_366216787895_item	2346769	et	3	main
selle	doc_366216787895_item	2346770	et	4	main
pärast	doc_366216787895_item	2346771	et	4	main
ma	doc_366216787895_item	2346781	et	3	main
kõik	doc_366216787895_item	2346784	et	4	main
see	doc_366216787895_item	2346792	et	3	main
ja	doc_366216787895_item	2346797	et	3	main
lõbusam	doc_366216787895_item	2346798	et	4	main
aga	doc_366216787895_item	2346799	et	3	main
rahva	doc_366216787895_item	2346800	et	3	main
õnnelikum	doc_366216787895_item	2346801	et	4	main
lisaks	doc_366216787895_item	2346802	et	4	main
laulupidu	doc_366216787895_item	2346803	et	4	main
suur	doc_366216787895_item	2346804	et	3	main
rahvapidu	doc_366216787895_item	2346805	et	4	main
kuhu	doc_366216787895_item	2346806	et	3	main
tullakse	doc_366216787895_item	2346807	et	3	main
koos	doc_366216787895_item	2346808	et	4	main
perega	doc_366216787895_item	2346809	et	3	main
lootusest	doc_366216787895_item	2346810	et	4	main
kohata	doc_366216787895_item	2346811	et	4	main
sõpru	doc_366216787895_item	2346812	et	3	main
sugulasi	doc_366216787895_item	2346813	et	3	main
ja	doc_366216787895_item	2346814	et	3	main
tuttavaid	doc_366216787895_item	2346815	et	3	main
pärast	doc_366216787895_item	2346754	et	4	main
ma	doc_366216787895_item	2346757	et	3	main
kindel	doc_366216787895_item	2346759	et	3	main
laul	doc_366216787895_item	2346761	et	4	main
et	doc_366216787895_item	2346772	et	3	main
jutust	doc_366216787895_item	2346780	et	3	main
rahvad	doc_366216787895_item	2346785	et	3	main
laulurahvad	doc_366216787895_item	2346788	et	3	main
olla	doc_366216787895_item	2346791	et	3	main
teeb	doc_366216787895_item	2346793	et	3	main
pikkus	doc_366216787897_item	2347083	et	4	main
350	doc_366216787897_item	2347085	et	2	main
arutlev	doc_366216787897_item	2347090	et	4	main
soovitatav	doc_366216787897_item	2347102	et	4	main
näidetega	doc_366216787897_item	2347104	et	3	main
eestlased	doc_366216787897_item	2347111	et	3	main
viimasel	doc_366216787897_item	2347122	et	3	main
tegevus	doc_366216787897_item	2347126	et	4	main
ühendab	doc_366216787897_item	2347127	et	3	main
meid	doc_366216787897_item	2347128	et	4	main
sotsiaalne	doc_366216787897_item	2347132	et	3	main
ja	doc_366216787897_item	2347133	et	3	main
tegevus	doc_366216787897_item	2347135	et	4	main
vana	doc_366216787897_item	2347141	et	4	main
klassis	doc_366216787897_item	2347151	et	3	main
eestis	doc_366216787897_item	2347153	et	3	main
suur	doc_366216787897_item	2347155	et	3	main
et	doc_366216787897_item	2347166	et	3	main
üks	doc_366216787897_item	2347203	et	3	main
eeslaulja	doc_366216787897_item	2347208	et	4	main
lauldi	doc_366216787897_item	2347211	et	3	main
olid	doc_366216787897_item	2347223	et	4	main
on	doc_366216787897_item	2347226	et	4	main
natuke	doc_366216787897_item	2347228	et	4	main
teistmoodi	doc_366216787897_item	2347229	et	3	main
regilaulu	doc_366216787897_item	2347230	et	4	main
üldiselt	doc_366216787897_item	2347243	et	4	main
on	doc_366216787897_item	2347245	et	4	main
ja	doc_366216787897_item	2347256	et	3	main
vanaemad	doc_366216787897_item	2347257	et	3	main
üks	doc_366216787897_item	2347267	et	3	main
populaarsed	doc_366216787897_item	2347306	et	3	main
ja	doc_366216787897_item	2347307	et	3	main
noored	doc_366216787897_item	2347308	et	3	main
ansamblid	doc_366216787897_item	2347309	et	3	main
soov	doc_366216787897_item	2347313	et	3	main
see	doc_366216787897_item	2347315	et	3	main
väga	doc_366216787897_item	2347317	et	3	main
kui	doc_366216787897_item	2347324	et	3	main
eestist	doc_366216787897_item	2347327	et	3	main
meelde	doc_366216787897_item	2347332	et	3	main
rahvariideid	doc_366216787897_item	2347335	et	3	main
keele	doc_366216787898_item	2347354	et	4	main
kui	doc_366216787898_item	2347355	et	3	main
teise	doc_366216787898_item	2347356	et	4	main
peab	doc_366216787898_item	2347373	et	4	main
loengus	doc_366216787898_item	2347380	et	3	main
esitatud	doc_366216787898_item	2347383	et	4	main
väiteid	doc_366216787898_item	2347385	et	4	main
on	doc_366216787898_item	2347386	et	4	main
on	doc_366216787898_item	2347391	et	4	main
töötab	doc_366216787898_item	2347433	et	3	main
eestis	doc_366216787898_item	2347445	et	3	main
esimene	doc_366216787898_item	2347456	et	3	main
eestlastele	doc_366216787898_item	2347484	et	4	main
oli	doc_366216787898_item	2347485	et	3	main
laulurahva	doc_366216787897_item	2347081	et	3	main
essee	doc_366216787897_item	2347082	et	4	main
essee	doc_366216787897_item	2347087	et	4	main
illustreerida	doc_366216787897_item	2347103	et	3	main
eestis	doc_366216787897_item	2347107	et	3	main
laulu	doc_366216787897_item	2347113	et	4	main
rahvas	doc_366216787897_item	2347114	et	4	main
olen	doc_366216787897_item	2347115	et	3	main
kindel	doc_366216787897_item	2347116	et	3	main
et	doc_366216787897_item	2347117	et	3	main
meil	doc_366216787897_item	2347119	et	4	main
on	doc_366216787897_item	2347120	et	4	main
essee	doc_366216787897_item	2347067	et	4	main
eesti	doc_366216787897_item	2347068	et	4	main
keele	doc_366216787897_item	2347069	et	4	main
kui	doc_366216787897_item	2347070	et	3	main
teise	doc_366216787897_item	2347071	et	4	main
test	doc_366216787897_item	2347073	et	3	main
kirjutamine	doc_366216787897_item	2347074	et	4	main
keele	doc_366216787897_item	2347072	et	4	main
kirjutage	doc_366216787897_item	2347075	et	3	main
essee	doc_366216787897_item	2347076	et	4	main
teemal	doc_366216787897_item	2347077	et	3	main
mis	doc_366216787897_item	2347078	et	4	main
teeb	doc_366216787897_item	2347079	et	3	main
eestlastest	doc_366216787897_item	2347080	et	4	main
peab	doc_366216787897_item	2347088	et	4	main
analüüsiv	doc_366216787897_item	2347091	et	4	main
üldistav	doc_366216787897_item	2347093	et	4	main
me	doc_366216787897_item	2347108	et	4	main
et	doc_366216787897_item	2347110	et	3	main
tegelikult	doc_366216787897_item	2347124	et	4	main
see	doc_366216787897_item	2347125	et	3	main
meil	doc_366216787897_item	2347139	et	4	main
eestis	doc_366216787897_item	2347140	et	3	main
traditsioon	doc_366216787897_item	2347142	et	3	main
kõik	doc_366216787897_item	2347143	et	4	main
teavad	doc_366216787897_item	2347144	et	3	main
seda	doc_366216787897_item	2347145	et	3	main
näiteks	doc_366216787897_item	2347146	et	4	main
mina	doc_366216787897_item	2347147	et	4	main
juba	doc_366216787897_item	2347148	et	3	main
esimeses	doc_366216787897_item	2347150	et	3	main
on	doc_366216787897_item	2347154	et	4	main
laulsime	doc_366216787897_item	2347158	et	3	main
kuid	doc_366216787897_item	2347162	et	4	main
me	doc_366216787897_item	2347163	et	4	main
tuleb	doc_366216787897_item	2347169	et	3	main
ajast	doc_366216787897_item	2347172	et	4	main
ka	doc_366216787897_item	2347207	et	3	main
palju	doc_366216787897_item	2347212	et	4	main
tuhande	doc_366216787897_item	2347218	et	3	main
aastal	doc_366216787897_item	2347222	et	3	main
et	doc_366216787897_item	2347242	et	3	main
meil	doc_366216787897_item	2347244	et	4	main
sama	doc_366216787897_item	2347246	et	4	main
laulutraditsioon	doc_366216787897_item	2347247	et	3	main
rõõmustab	doc_366216787897_item	2347248	et	3	main
see	doc_366216787897_item	2347249	et	3	main
et	doc_366216787897_item	2347250	et	3	main
me	doc_366216787897_item	2347251	et	4	main
teame	doc_366216787897_item	2347252	et	3	main
seda	doc_366216787897_item	2347253	et	3	main
meie	doc_366216787897_item	2347254	et	4	main
aja	doc_366216787897_item	2347260	et	4	main
laulda	doc_366216787897_item	2347273	et	4	main
ühendab	doc_366216787897_item	2347276	et	3	main
on	doc_366216787897_item	2347311	et	4	main
kohe	doc_366216787897_item	2347329	et	4	main
peo	doc_366216787897_item	2347337	et	4	main
on	doc_366216787897_item	2347339	et	4	main
ajaloo	doc_366216787897_item	2347341	et	4	main
uurimine	doc_366216787897_item	2347342	et	4	main
essee	doc_366216787898_item	2347352	et	4	main
eesti	doc_366216787898_item	2347353	et	4	main
kirjutage	doc_366216787898_item	2347360	et	3	main
teemal	doc_366216787898_item	2347362	et	3	main
essee	doc_366216787898_item	2347367	et	4	main
300	doc_366216787898_item	2347369	et	2	main
sõna	doc_366216787898_item	2347371	et	4	main
arutlev	doc_366216787898_item	2347375	et	4	main
ja	doc_366216787898_item	2347381	et	3	main
soovitatav	doc_366216787898_item	2347387	et	4	main
illustreerida	doc_366216787898_item	2347388	et	3	main
näidetega	doc_366216787898_item	2347389	et	3	main
eesti	doc_366216787898_item	2347422	et	4	main
heal	doc_366216787898_item	2347426	et	3	main
kui	doc_366216787898_item	2347428	et	3	main
halval	doc_366216787898_item	2347430	et	3	main
laulab	doc_366216787898_item	2347431	et	3	main
saatis	doc_366216787898_item	2347439	et	3	main
eestlast	doc_366216787898_item	2347441	et	4	main
hällist	doc_366216787898_item	2347442	et	4	main
hauani	doc_366216787898_item	2347443	et	3	main
kui	doc_366216787898_item	2347444	et	3	main
toimub	doc_366216787898_item	2347446	et	3	main
laulavad	doc_366216787898_item	2347450	et	4	main
esimese	doc_366216787898_item	2347452	et	3	main
ärkamise	doc_366216787898_item	2347453	et	4	main
laulupidu	doc_366216787898_item	2347457	et	4	main
tartu	doc_366216787898_item	2347460	et	4	main
olema	doc_366216787897_item	2347089	et	4	main
ja	doc_366216787897_item	2347092	et	3	main
tuginema	doc_366216787897_item	2347094	et	3	main
loengus	doc_366216787897_item	2347095	et	3	main
ja	doc_366216787897_item	2347096	et	3	main
lugemistekstis	doc_366216787897_item	2347097	et	3	main
esitatud	doc_366216787897_item	2347098	et	4	main
faktidele	doc_366216787897_item	2347099	et	3	main
väiteid	doc_366216787897_item	2347100	et	4	main
elame	doc_366216787897_item	2347106	et	3	main
teame	doc_366216787897_item	2347109	et	3	main
laulmine	doc_366216787897_item	2347118	et	4	main
see	doc_366216787897_item	2347130	et	3	main
esteetiline	doc_366216787897_item	2347134	et	3	main
tegelikult	doc_366216787897_item	2347136	et	4	main
me	doc_366216787897_item	2347157	et	4	main
ja	doc_366216787897_item	2347160	et	3	main
tantsisime	doc_366216787897_item	2347161	et	3	main
tegevus	doc_366216787897_item	2347168	et	4	main
vanast	doc_366216787897_item	2347171	et	3	main
oli	doc_366216787897_item	2347206	et	3	main
liikumisega	doc_366216787897_item	2347213	et	4	main
naised	doc_366216787897_item	2347216	et	3	main
üheksasaja	doc_366216787897_item	2347219	et	4	main
kuuekümne	doc_366216787897_item	2347220	et	4	main
on	doc_366216787897_item	2347131	et	4	main
kuulsin	doc_366216787897_item	2347149	et	3	main
et	doc_366216787897_item	2347152	et	3	main
laulutraditsioon	doc_366216787897_item	2347156	et	3	main
teadnud	doc_366216787897_item	2347165	et	4	main
see	doc_366216787897_item	2347167	et	3	main
juba	doc_366216787897_item	2347170	et	3	main
juba	doc_366216787897_item	2347173	et	3	main
kaheteistkümnendal	doc_366216787897_item	2347174	et	4	main
sajandil	doc_366216787897_item	2347175	et	3	main
hakkas	doc_366216787897_item	2347176	et	3	main
laulmine	doc_366216787897_item	2347177	et	4	main
levima	doc_366216787897_item	2347178	et	3	main
kirikut	doc_366216787897_item	2347180	et	3	main
väljaspool	doc_366216787897_item	2347179	et	3	main
vanast	doc_366216787897_item	2347181	et	3	main
ajast	doc_366216787897_item	2347182	et	4	main
on	doc_366216787897_item	2347183	et	4	main
sailinud	doc_366216787897_item	2347184	et	4	main
laulu	doc_366216787897_item	2347185	et	4	main
ja	doc_366216787897_item	2347186	et	3	main
suulise	doc_366216787897_item	2347187	et	4	main
loomingu	doc_366216787897_item	2347188	et	3	main
traditsioonid	doc_366216787897_item	2347189	et	3	main
põlvkonnast	doc_366216787897_item	2347190	et	4	main
põlvkonda	doc_366216787897_item	2347191	et	4	main
muidugi	doc_366216787897_item	2347192	et	4	main
vanasti	doc_366216787897_item	2347193	et	3	main
olid	doc_366216787897_item	2347194	et	4	main
teised	doc_366216787897_item	2347195	et	4	main
peod	doc_366216787897_item	2347196	et	4	main
ja	doc_366216787897_item	2347197	et	3	main
laulmine	doc_366216787897_item	2347198	et	4	main
kuid	doc_366216787897_item	2347199	et	4	main
mõte	doc_366216787897_item	2347200	et	3	main
oli	doc_366216787897_item	2347201	et	3	main
alati	doc_366216787897_item	2347202	et	4	main
varem	doc_366216787897_item	2347205	et	4	main
koor	doc_366216787897_item	2347210	et	4	main
juba	doc_366216787897_item	2347217	et	3	main
üheksandal	doc_366216787897_item	2347221	et	3	main
võin	doc_366216787897_item	2347240	et	3	main
seda	doc_366216787897_item	2347259	et	3	main
kõik	doc_366216787897_item	2347262	et	4	main
kuid	doc_366216787897_item	2347264	et	4	main
esineda	doc_366216787897_item	2347275	et	3	main
alati	doc_366216787897_item	2347312	et	4	main
on	doc_366216787897_item	2347316	et	4	main
me	doc_366216787897_item	2347325	et	4	main
räägime	doc_366216787897_item	2347326	et	3	main
ta	doc_366216787897_item	2347328	et	4	main
tuletab	doc_366216787897_item	2347330	et	3	main
meile	doc_366216787897_item	2347331	et	4	main
tahaks	doc_366216787897_item	2347343	et	3	main
et	doc_366216787897_item	2347344	et	3	main
lapsed	doc_366216787897_item	2347346	et	3	main
ka	doc_366216787897_item	2347347	et	3	main
osa	doc_366216787897_item	2347349	et	4	main
keele	doc_366216787898_item	2347357	et	4	main
eestlastest	doc_366216787898_item	2347365	et	4	main
laulurahva	doc_366216787898_item	2347366	et	3	main
essee	doc_366216787898_item	2347372	et	4	main
üldistav	doc_366216787898_item	2347378	et	4	main
faktidele	doc_366216787898_item	2347384	et	3	main
vana	doc_366216787898_item	2347392	et	4	main
rahvadel	doc_366216787898_item	2347395	et	4	main
kui	doc_366216787898_item	2347435	et	3	main
midagi	doc_366216787898_item	2347447	et	4	main
näiteks	doc_366216787898_item	2347451	et	4	main
ajal	doc_366216787898_item	2347454	et	4	main
linnas	doc_366216787898_item	2347461	et	4	main
peos	doc_366216787898_item	2347464	et	4	main
osales	doc_366216787898_item	2347465	et	3	main
46	doc_366216787898_item	2347466	et	2	main
meestekoori	doc_366216787898_item	2347467	et	4	main
lauljaga	doc_366216787898_item	2347469	et	4	main
puhkepilliorkestri	doc_366216787898_item	2347472	et	3	main
vene	doc_366216787898_item	2347490	et	4	main
rahvalaul	doc_366216787898_item	2347502	et	4	main
ja	doc_366216787898_item	2347509	et	3	main
ärkamisaeg	doc_366216787898_item	2347518	et	3	main
tänapäeval	doc_366216787897_item	2347225	et	3	main
näiteks	doc_366216787897_item	2347231	et	4	main
ma	doc_366216787897_item	2347239	et	3	main
jooksul	doc_366216787897_item	2347261	et	4	main
idee	doc_366216787897_item	2347268	et	4	main
üks	doc_366216787897_item	2347269	et	3	main
traditsioon	doc_366216787897_item	2347270	et	3	main
ja	doc_366216787897_item	2347271	et	3	main
soov	doc_366216787897_item	2347272	et	3	main
ning	doc_366216787897_item	2347274	et	3	main
meid	doc_366216787897_item	2347277	et	4	main
tänapäeval	doc_366216787897_item	2347278	et	3	main
meie	doc_366216787897_item	2347279	et	4	main
traditsioon	doc_366216787897_item	2347280	et	3	main
seisneb	doc_366216787897_item	2347281	et	3	main
selles	doc_366216787897_item	2347282	et	4	main
et	doc_366216787897_item	2347283	et	3	main
oleme	doc_366216787897_item	2347285	et	3	main
me	doc_366216787897_item	2347284	et	4	main
kindel	doc_366216787897_item	2347286	et	3	main
et	doc_366216787897_item	2347287	et	3	main
saame	doc_366216787897_item	2347288	et	4	main
rahvapeole	doc_366216787897_item	2347289	et	4	main
minna	doc_366216787897_item	2347290	et	3	main
kuhu	doc_366216787897_item	2347291	et	3	main
tullakse	doc_366216787897_item	2347292	et	3	main
koos	doc_366216787897_item	2347293	et	4	main
perega	doc_366216787897_item	2347294	et	3	main
lootuses	doc_366216787897_item	2347295	et	4	main
kohata	doc_366216787897_item	2347296	et	4	main
sõpru	doc_366216787897_item	2347297	et	3	main
sugulasi	doc_366216787897_item	2347298	et	3	main
ükskõik	doc_366216787897_item	2347299	et	3	main
et	doc_366216787897_item	2347300	et	3	main
tänapäeval	doc_366216787897_item	2347301	et	3	main
meil	doc_366216787897_item	2347302	et	4	main
on	doc_366216787897_item	2347303	et	4	main
juba	doc_366216787897_item	2347304	et	3	main
teised	doc_366216787897_item	2347305	et	4	main
meil	doc_366216787897_item	2347310	et	4	main
oluline	doc_366216787897_item	2347318	et	4	main
see	doc_366216787897_item	2347319	et	3	main
nimelt	doc_366216787897_item	2347320	et	4	main
teeb	doc_366216787897_item	2347321	et	3	main
eestlastest	doc_366216787897_item	2347322	et	4	main
laulutraditsiooni	doc_366216787897_item	2347334	et	4	main
see	doc_366216787897_item	2347338	et	3	main
nagu	doc_366216787897_item	2347340	et	3	main
selles	doc_366216787897_item	2347350	et	4	main
traditsioonis	doc_366216787897_item	2347351	et	3	main
kirjutamine	doc_366216787898_item	2347359	et	4	main
essee	doc_366216787898_item	2347361	et	4	main
mis	doc_366216787898_item	2347363	et	4	main
teeb	doc_366216787898_item	2347364	et	3	main
olema	doc_366216787898_item	2347374	et	4	main
analüüsiv	doc_366216787898_item	2347376	et	4	main
tuginema	doc_366216787898_item	2347379	et	3	main
lugemistekstis	doc_366216787898_item	2347382	et	3	main
traditsioon	doc_366216787898_item	2347393	et	3	main
esteetiline	doc_366216787898_item	2347398	et	3	main
ja	doc_366216787898_item	2347399	et	3	main
emotsionaalne	doc_366216787898_item	2347400	et	3	main
väljendusvahend	doc_366216787898_item	2347401	et	3	main
aga	doc_366216787898_item	2347402	et	3	main
ka	doc_366216787898_item	2347403	et	3	main
sotsialne	doc_366216787898_item	2347404	et	4	main
tegevus	doc_366216787898_item	2347405	et	4	main
loomulikult	doc_366216787898_item	2347406	et	4	main
laul	doc_366216787898_item	2347407	et	4	main
on	doc_366216787898_item	2347408	et	4	main
ka	doc_366216787898_item	2347409	et	3	main
rahvuslik	doc_366216787898_item	2347410	et	3	main
identiteeditunne	doc_366216787898_item	2347411	et	3	main
ja	doc_366216787898_item	2347412	et	3	main
sümbol	doc_366216787898_item	2347414	et	3	main
kultuuri	doc_366216787898_item	2347413	et	4	main
arvan	doc_366216787898_item	2347415	et	3	main
et	doc_366216787898_item	2347416	et	3	main
eestlastel	doc_366216787898_item	2347417	et	4	main
laulutradtsioon	doc_366216787898_item	2347418	et	4	main
on	doc_366216787898_item	2347419	et	4	main
väga	doc_366216787898_item	2347420	et	3	main
laulu	doc_366216787897_item	2347333	et	4	main
ja	doc_366216787897_item	2347336	et	3	main
meie	doc_366216787897_item	2347345	et	4	main
võtavad	doc_366216787897_item	2347348	et	3	main
test	doc_366216787898_item	2347358	et	3	main
pikkus	doc_366216787898_item	2347368	et	4	main
350	doc_366216787898_item	2347370	et	2	main
ja	doc_366216787898_item	2347377	et	3	main
laul	doc_366216787898_item	2347390	et	4	main
paljudel	doc_366216787898_item	2347394	et	3	main
laulmine	doc_366216787898_item	2347396	et	4	main
on	doc_366216787898_item	2347397	et	4	main
ajal	doc_366216787898_item	2347427	et	4	main
ja	doc_366216787898_item	2347434	et	3	main
vanal	doc_366216787898_item	2347437	et	3	main
tähtis	doc_366216787898_item	2347448	et	4	main
toimus	doc_366216787898_item	2347455	et	3	main
kujunes	doc_366216787898_item	2347474	et	3	main
ajal	doc_366216787898_item	2347483	et	4	main
rääkida	doc_366216787898_item	2347489	et	3	main
eesti	doc_366216787898_item	2347492	et	4	main
eesti	doc_366216787898_item	2347494	et	4	main
kes	doc_366216787898_item	2347506	et	4	main
rahvalaul	doc_366216787898_item	2347525	et	4	main
näitavad	doc_366216787898_item	2347528	et	4	main
laulupeod	doc_366216787898_item	2347529	et	4	main
kuhu	doc_366216787898_item	2347530	et	3	main
perega	doc_366216787898_item	2347534	et	3	main
sõbraga	doc_366216787898_item	2347536	et	3	main
laulupidu	doc_366216787898_item	2347539	et	4	main
meie	doc_366216787898_item	2347541	et	4	main
ajal	doc_366216787898_item	2347542	et	4	main
see	doc_366216787898_item	2347549	et	3	main
eestlased	doc_366216787898_item	2347552	et	3	main
oluline	doc_366216787898_item	2347421	et	4	main
rahvas	doc_366216787898_item	2347423	et	4	main
laulab	doc_366216787898_item	2347424	et	3	main
nii	doc_366216787898_item	2347425	et	3	main
ka	doc_366216787898_item	2347429	et	3	main
kui	doc_366216787898_item	2347432	et	3	main
puhkab	doc_366216787898_item	2347436	et	3	main
ajal	doc_366216787898_item	2347438	et	4	main
laul	doc_366216787898_item	2347440	et	4	main
inimesed	doc_366216787898_item	2347449	et	3	main
see	doc_366216787898_item	2347458	et	3	main
oli	doc_366216787898_item	2347459	et	3	main
822	doc_366216787898_item	2347468	et	2	main
5	doc_366216787898_item	2347471	et	2	main
sellest	doc_366216787898_item	2347473	et	4	main
tsari	doc_366216787898_item	2347479	et	4	main
ajal	doc_366216787898_item	2347480	et	4	main
ja	doc_366216787898_item	2347481	et	3	main
nsv	doc_366216787898_item	2347482	et	4	main
vaja	doc_366216787898_item	2347488	et	4	main
traditsioonid	doc_366216787898_item	2347495	et	3	main
tappama	doc_366216787898_item	2347500	et	4	main
eestlastele	doc_366216787898_item	2347504	et	4	main
nad	doc_366216787898_item	2347507	et	3	main
laulavrevolutsiion	doc_366216787898_item	2347521	et	4	main
tulevad	doc_366216787898_item	2347532	et	4	main
küll	doc_366216787898_item	2347553	et	4	main
keele	doc_366216787900_item	2347769	et	4	main
on	doc_366216787900_item	2347801	et	4	main
rahvas	doc_366216787900_item	2347806	et	4	main
mängisid	doc_366216787900_item	2347813	et	4	main
aastal	doc_366216787898_item	2347462	et	3	main
1869	doc_366216787898_item	2347463	et	2	main
ja	doc_366216787898_item	2347470	et	3	main
eestlaste	doc_366216787898_item	2347475	et	4	main
rahvusliku	doc_366216787898_item	2347476	et	3	main
liikumise	doc_366216787898_item	2347477	et	4	main
kõrghetk	doc_366216787898_item	2347478	et	3	main
keeles	doc_366216787898_item	2347491	et	4	main
rahvatunne	doc_366216787898_item	2347493	et	3	main
kõik	doc_366216787898_item	2347496	et	4	main
need	doc_366216787898_item	2347497	et	3	main
asju	doc_366216787898_item	2347498	et	3	main
tahti	doc_366216787898_item	2347499	et	4	main
mäletada	doc_366216787898_item	2347505	et	3	main
aastal	doc_366216787898_item	2347514	et	3	main
tuli	doc_366216787898_item	2347516	et	4	main
teine	doc_366216787898_item	2347517	et	3	main
ajal	doc_366216787898_item	2347523	et	4	main
inimesed	doc_366216787898_item	2347531	et	3	main
eestiline	doc_366216787898_item	2347538	et	3	main
kõige	doc_366216787898_item	2347543	et	4	main
tähelepanuväärsem	doc_366216787898_item	2347544	et	4	main
rahvusluse	doc_366216787898_item	2347545	et	4	main
kui	doc_366216787900_item	2347770	et	3	main
soovitatav	doc_366216787900_item	2347802	et	4	main
illustreerida	doc_366216787900_item	2347803	et	3	main
oli	doc_366216787900_item	2347808	et	3	main
musikaalne	doc_366216787900_item	2347810	et	3	main
laulsid	doc_366216787900_item	2347812	et	4	main
pilli	doc_366216787900_item	2347814	et	4	main
tantsisid	doc_366216787900_item	2347815	et	4	main
rasket	doc_366216787900_item	2347816	et	3	main
keskaegseid	doc_366216787900_item	2347822	et	3	main
ka	doc_366216787900_item	2347834	et	3	main
oli	doc_366216787900_item	2347843	et	3	main
olnud	doc_366216787900_item	2347852	et	4	main
mehed	doc_366216787900_item	2347853	et	3	main
olid	doc_366216787900_item	2347854	et	4	main
meres	doc_366216787900_item	2347855	et	3	main
naised	doc_366216787900_item	2347856	et	3	main
kodus	doc_366216787900_item	2347857	et	4	main
õhtudel	doc_366216787900_item	2347863	et	4	main
isadest	doc_366216787900_item	2347870	et	3	main
sõltus	doc_366216787900_item	2347881	et	4	main
raske	doc_366216787898_item	2347486	et	4	main
oli	doc_366216787898_item	2347487	et	3	main
ainult	doc_366216787898_item	2347501	et	4	main
aitas	doc_366216787898_item	2347503	et	3	main
on	doc_366216787898_item	2347508	et	4	main
ei	doc_366216787898_item	2347510	et	4	main
unusta	doc_366216787898_item	2347511	et	4	main
oma	doc_366216787898_item	2347512	et	4	main
kultuuri	doc_366216787898_item	2347513	et	4	main
1980	doc_366216787898_item	2347515	et	2	main
pärast	doc_366216787898_item	2347519	et	4	main
toimus	doc_366216787898_item	2347520	et	3	main
meie	doc_366216787898_item	2347522	et	4	main
populaarne	doc_366216787898_item	2347526	et	3	main
see	doc_366216787898_item	2347527	et	3	main
lastega	doc_366216787898_item	2347535	et	3	main
et	doc_366216787898_item	2347551	et	3	main
teise	doc_366216787900_item	2347771	et	4	main
lugemistekstis	doc_366216787900_item	2347797	et	3	main
eesti	doc_366216787900_item	2347805	et	4	main
väga	doc_366216787900_item	2347809	et	3	main
on	doc_366216787900_item	2347825	et	4	main
kirikudes	doc_366216787900_item	2347835	et	4	main
aga	doc_366216787900_item	2347836	et	3	main
te	doc_366216787900_item	2347837	et	4	main
võite	doc_366216787900_item	2347838	et	4	main
küsida	doc_366216787900_item	2347839	et	3	main
elu	doc_366216787900_item	2347846	et	4	main
asi	doc_366216787900_item	2347847	et	4	main
nendel	doc_366216787900_item	2347862	et	4	main
kes	doc_366216787900_item	2347865	et	4	main
kõik	doc_366216787900_item	2347880	et	4	main
laulab	doc_366216787900_item	2347884	et	3	main
miks	doc_366216787900_item	2347886	et	4	main
väga	doc_366216787900_item	2347888	et	3	main
kaasnes	doc_366216787900_item	2347892	et	3	main
oli	doc_366216787900_item	2347896	et	3	main
kasutada	doc_366216787900_item	2347927	et	3	main
tundsid	doc_366216787900_item	2347937	et	4	main
et	doc_366216787900_item	2347939	et	3	main
teha	doc_366216787900_item	2347942	et	3	main
juba	doc_366216787900_item	2347948	et	3	main
ühiskond	doc_366216787900_item	2347950	et	3	main
kõik	doc_366216787900_item	2347952	et	4	main
veel	doc_366216787900_item	2347954	et	4	main
palju	doc_366216787900_item	2347961	et	4	main
on	doc_366216787898_item	2347524	et	4	main
koos	doc_366216787898_item	2347533	et	4	main
üle	doc_366216787898_item	2347537	et	3	main
on	doc_366216787898_item	2347540	et	4	main
manifestatsioon	doc_366216787898_item	2347546	et	3	main
eestis	doc_366216787898_item	2347547	et	3	main
kõik	doc_366216787898_item	2347548	et	4	main
näitab	doc_366216787898_item	2347550	et	3	main
saab	doc_366216787898_item	2347554	et	3	main
nimetada	doc_366216787898_item	2347555	et	3	main
laulurahvaks	doc_366216787898_item	2347556	et	3	main
essee	doc_366216787900_item	2347767	et	4	main
ja	doc_366216787900_item	2347796	et	3	main
näidetega	doc_366216787900_item	2347804	et	3	main
nad	doc_366216787900_item	2347811	et	3	main
tänapäevani	doc_366216787900_item	2347819	et	3	main
arkiividest	doc_366216787900_item	2347821	et	4	main
laule	doc_366216787900_item	2347823	et	4	main
juba	doc_366216787900_item	2347826	et	3	main
rahvalaule	doc_366216787900_item	2347833	et	4	main
eestlastel	doc_366216787900_item	2347842	et	4	main
on	doc_366216787900_item	2347848	et	4	main
selles	doc_366216787900_item	2347849	et	4	main
et	doc_366216787900_item	2347850	et	3	main
ei	doc_366216787900_item	2347851	et	4	main
teab	doc_366216787900_item	2347866	et	3	main
kes	doc_366216787900_item	2347871	et	4	main
olid	doc_366216787900_item	2347872	et	4	main
kusagil	doc_366216787900_item	2347873	et	3	main
ei	doc_366216787900_item	2347878	et	4	main
tihti	doc_366216787900_item	2347889	et	3	main
ka	doc_366216787900_item	2347893	et	3	main
laulja	doc_366216787900_item	2347901	et	4	main
pool	doc_366216787900_item	2347925	et	4	main
instrumenditega	doc_366216787900_item	2347929	et	4	main
mis	doc_366216787900_item	2347943	et	4	main
see	doc_366216787900_item	2347946	et	3	main
kord	doc_366216787900_item	2347955	et	4	main
laulda	doc_366216787900_item	2347960	et	4	main
laule	doc_366216787900_item	2347963	et	4	main
reeglid	doc_366216787900_item	2347967	et	3	main
nende	doc_366216787900_item	2347977	et	4	main
teadnud	doc_366216787900_item	2347985	et	4	main
oli	doc_366216787900_item	2347987	et	3	main
laulupeod	doc_366216787900_item	2347990	et	4	main
eesti	doc_366216787900_item	2347768	et	4	main
keele	doc_366216787900_item	2347772	et	4	main
test	doc_366216787900_item	2347773	et	3	main
kirjutamine	doc_366216787900_item	2347774	et	4	main
kirjutage	doc_366216787900_item	2347775	et	3	main
essee	doc_366216787900_item	2347776	et	4	main
teemal	doc_366216787900_item	2347777	et	3	main
mis	doc_366216787900_item	2347778	et	4	main
teeb	doc_366216787900_item	2347779	et	3	main
eestlastest	doc_366216787900_item	2347780	et	4	main
laulurahva	doc_366216787900_item	2347781	et	3	main
essee	doc_366216787900_item	2347782	et	4	main
pikkus	doc_366216787900_item	2347783	et	4	main
300	doc_366216787900_item	2347784	et	2	main
350	doc_366216787900_item	2347785	et	2	main
essee	doc_366216787900_item	2347787	et	4	main
sõna	doc_366216787900_item	2347786	et	4	main
peab	doc_366216787900_item	2347788	et	4	main
olema	doc_366216787900_item	2347789	et	4	main
arutlev	doc_366216787900_item	2347790	et	4	main
analüüsiv	doc_366216787900_item	2347791	et	4	main
ja	doc_366216787900_item	2347792	et	3	main
üldistav	doc_366216787900_item	2347793	et	4	main
tuginema	doc_366216787900_item	2347794	et	3	main
loengus	doc_366216787900_item	2347795	et	3	main
esitatud	doc_366216787900_item	2347798	et	4	main
faktidele	doc_366216787900_item	2347799	et	3	main
väiteid	doc_366216787900_item	2347800	et	4	main
alati	doc_366216787900_item	2347807	et	4	main
tööpäeva	doc_366216787900_item	2347817	et	4	main
leiatakse	doc_366216787900_item	2347820	et	4	main
mis	doc_366216787900_item	2347824	et	4	main
unustatud	doc_366216787900_item	2347829	et	4	main
kaheksateistkümnest	doc_366216787900_item	2347830	et	3	main
sajandist	doc_366216787900_item	2347831	et	3	main
lauldi	doc_366216787900_item	2347832	et	3	main
nii	doc_366216787900_item	2347844	et	3	main
laule	doc_366216787900_item	2347864	et	4	main
olla	doc_366216787900_item	2347868	et	3	main
kaugel	doc_366216787900_item	2347874	et	4	main
kes	doc_366216787900_item	2347883	et	4	main
koor	doc_366216787900_item	2347894	et	4	main
üheksateistkümnenda	doc_366216787900_item	2347922	et	4	main
sajandi	doc_366216787900_item	2347923	et	3	main
nad	doc_366216787900_item	2347944	et	3	main
soovivad	doc_366216787900_item	2347945	et	4	main
teine	doc_366216787900_item	2347949	et	3	main
nõukogudeliidu	doc_366216787900_item	2347956	et	3	main
ajal	doc_366216787900_item	2347957	et	4	main
propagandistlikke	doc_366216787900_item	2347962	et	3	main
aga	doc_366216787900_item	2347968	et	3	main
rahvalaul	doc_366216787900_item	2347970	et	4	main
nagu	doc_366216787900_item	2347972	et	3	main
ei	doc_366216787900_item	2347975	et	4	main
elu	doc_366216787900_item	2347978	et	4	main
tavalise	doc_366216787900_item	2347993	et	4	main
eestlase	doc_366216787900_item	2347994	et	3	main
seotud	doc_366216787900_item	2348000	et	4	main
pärast	doc_366216787900_item	2347818	et	4	main
ammu	doc_366216787900_item	2347827	et	4	main
kahjuks	doc_366216787900_item	2347828	et	4	main
miks	doc_366216787900_item	2347840	et	4	main
kas	doc_366216787900_item	2347841	et	3	main
lihtne	doc_366216787900_item	2347845	et	3	main
kasvatasid	doc_366216787900_item	2347858	et	4	main
lapsi	doc_366216787900_item	2347859	et	4	main
ja	doc_366216787900_item	2347860	et	3	main
laulsid	doc_366216787900_item	2347861	et	4	main
võib	doc_366216787900_item	2347867	et	3	main
nende	doc_366216787900_item	2347869	et	4	main
oma	doc_366216787900_item	2347875	et	4	main
kodust	doc_366216787900_item	2347876	et	4	main
laulustiile	doc_366216787900_item	2347877	et	3	main
olnud	doc_366216787900_item	2347879	et	4	main
situatsioonist	doc_366216787900_item	2347882	et	3	main
millal	doc_366216787900_item	2347885	et	3	main
jne	doc_366216787900_item	2347887	et	4	main
laulja	doc_366216787900_item	2347890	et	4	main
see	doc_366216787900_item	2347895	et	3	main
välja	doc_366216787900_item	2347897	et	4	main
sellest	doc_366216787900_item	2347899	et	4	main
et	doc_366216787900_item	2347900	et	3	main
saaks	doc_366216787900_item	2347902	et	3	main
mõelda	doc_366216787900_item	2347903	et	4	main
mis	doc_366216787900_item	2347904	et	4	main
edasi	doc_366216787900_item	2347905	et	3	main
regilaule	doc_366216787900_item	2347906	et	4	main
laulsid	doc_366216787900_item	2347907	et	4	main
ainult	doc_366216787900_item	2347908	et	4	main
naised	doc_366216787900_item	2347909	et	3	main
ilma	doc_366216787900_item	2347910	et	4	main
muusika	doc_366216787900_item	2347911	et	4	main
instrumendita	doc_366216787900_item	2347912	et	3	main
aga	doc_366216787900_item	2347913	et	3	main
näiteks	doc_366216787900_item	2347914	et	4	main
saartel	doc_366216787900_item	2347915	et	3	main
traditsiooniliselt	doc_366216787900_item	2347916	et	4	main
mehed	doc_366216787900_item	2347918	et	3	main
ainult	doc_366216787900_item	2347917	et	4	main
olid	doc_366216787900_item	2347919	et	4	main
lubatud	doc_366216787900_item	2347920	et	4	main
laulmisega	doc_366216787900_item	2347891	et	4	main
mõeltud	doc_366216787900_item	2347898	et	4	main
teisel	doc_366216787900_item	2347924	et	4	main
lubatakse	doc_366216787900_item	2347926	et	4	main
ajal	doc_366216787900_item	2347931	et	4	main
see	doc_366216787900_item	2347932	et	3	main
vabadust	doc_366216787900_item	2347938	et	4	main
rääkida	doc_366216787900_item	2347940	et	3	main
muutus	doc_366216787900_item	2347953	et	4	main
tuli	doc_366216787900_item	2347959	et	4	main
repertuaaris	doc_366216787900_item	2347964	et	3	main
oli	doc_366216787900_item	2347971	et	3	main
ei	doc_366216787900_item	2347984	et	4	main
kuidas	doc_366216787900_item	2347986	et	3	main
üks	doc_366216787900_item	2347988	et	3	main
laulmiseks	doc_366216787900_item	2347921	et	4	main
muusika	doc_366216787900_item	2347928	et	4	main
laulmise	doc_366216787900_item	2347930	et	4	main
oli	doc_366216787900_item	2347933	et	3	main
rahvusärkamisaeg	doc_366216787900_item	2347934	et	3	main
millal	doc_366216787900_item	2347935	et	3	main
inimesed	doc_366216787900_item	2347936	et	3	main
ja	doc_366216787900_item	2347941	et	3	main
oli	doc_366216787900_item	2347947	et	3	main
muidugi	doc_366216787900_item	2347951	et	4	main
millal	doc_366216787900_item	2347958	et	3	main
meeldinud	doc_366216787900_item	2347976	et	4	main
nad	doc_366216787900_item	2347979	et	3	main
väljaminek	doc_366216787900_item	2347989	et	3	main
jaoks	doc_366216787900_item	2347995	et	4	main
laul	doc_366216787900_item	2347996	et	4	main
kehtestati	doc_366216787900_item	2347965	et	3	main
ranged	doc_366216787900_item	2347966	et	3	main
1960-ndes	doc_366216787900_item	2347969	et	4	main
vastutus	doc_366216787900_item	2347973	et	4	main
inimestel	doc_366216787900_item	2347974	et	3	main
tahtsid	doc_366216787900_item	2347980	et	4	main
midagi	doc_366216787900_item	2347981	et	4	main
muutuda	doc_366216787900_item	2347982	et	3	main
aga	doc_366216787900_item	2347983	et	3	main
meie	doc_366216787900_item	2347991	et	4	main
ajal	doc_366216787900_item	2347992	et	4	main
ja	doc_366216787900_item	2347997	et	3	main
rahvas	doc_366216787900_item	2347998	et	4	main
on	doc_366216787900_item	2347999	et	4	main
kui	doc_366216787904_item	2348677	et	3	main
kirjutage	doc_366216787904_item	2348682	et	3	main
essee	doc_366216787904_item	2348683	et	4	main
laulurahva	doc_366216787904_item	2348688	et	3	main
350	doc_366216787904_item	2348692	et	2	main
peab	doc_366216787904_item	2348695	et	4	main
arutlev	doc_366216787904_item	2348697	et	4	main
analüüsiv	doc_366216787904_item	2348698	et	4	main
test	doc_366216787904_item	2348680	et	3	main
kirjutamine	doc_366216787904_item	2348681	et	4	main
eestlastest	doc_366216787904_item	2348687	et	4	main
essee	doc_366216787904_item	2348694	et	4	main
olema	doc_366216787904_item	2348696	et	4	main
loengus	doc_366216787904_item	2348702	et	3	main
esitatud	doc_366216787904_item	2348705	et	4	main
kõigepealt	doc_366216787904_item	2348716	et	3	main
väljendub	doc_366216787904_item	2348721	et	3	main
koos	doc_366216787904_item	2348726	et	4	main
lauluga	doc_366216787904_item	2348727	et	4	main
eestlased	doc_366216787904_item	2348742	et	3	main
nad	doc_366216787904_item	2348746	et	3	main
säilitada	doc_366216787904_item	2348748	et	3	main
kultuur	doc_366216787904_item	2348752	et	3	main
edaspidi	doc_366216787904_item	2348753	et	3	main
vaatamata	doc_366216787904_item	2348754	et	4	main
kui	doc_366216787904_item	2348755	et	3	main
keeruline	doc_366216787904_item	2348756	et	4	main
aeg	doc_366216787904_item	2348757	et	3	main
valitseb	doc_366216787904_item	2348758	et	3	main
ja	doc_366216787904_item	2348760	et	3	main
tsaari	doc_366216787904_item	2348761	et	4	main
pöördusid	doc_366216787904_item	2348769	et	4	main
vaimu	doc_366216787904_item	2348776	et	4	main
elu	doc_366216787904_item	2348778	et	4	main
nõudnud	doc_366216787904_item	2348782	et	4	main
hea	doc_366216787904_item	2348793	et	4	main
ainult	doc_366216787904_item	2348799	et	4	main
teise	doc_366216787904_item	2348678	et	4	main
keele	doc_366216787904_item	2348679	et	4	main
essee	doc_366216787904_item	2348689	et	4	main
sõna	doc_366216787904_item	2348693	et	4	main
on	doc_366216787904_item	2348708	et	4	main
soovitatav	doc_366216787904_item	2348709	et	4	main
illustreerida	doc_366216787904_item	2348710	et	3	main
näidetega	doc_366216787904_item	2348711	et	3	main
laulurahva	doc_366216787904_item	2348715	et	3	main
öelda	doc_366216787904_item	2348718	et	4	main
laul	doc_366216787904_item	2348720	et	4	main
inimeste	doc_366216787904_item	2348722	et	3	main
iseloomu	doc_366216787904_item	2348723	et	4	main
peab	doc_366216787904_item	2348728	et	4	main
rahvas	doc_366216787904_item	2348729	et	4	main
teemal	doc_366216787904_item	2348684	et	3	main
mis	doc_366216787904_item	2348685	et	4	main
pikkus	doc_366216787904_item	2348690	et	4	main
üldistav	doc_366216787904_item	2348700	et	4	main
tuginema	doc_366216787904_item	2348701	et	3	main
lugemistekstis	doc_366216787904_item	2348704	et	3	main
väiteid	doc_366216787904_item	2348707	et	4	main
eestlastest	doc_366216787904_item	2348714	et	4	main
tahaks	doc_366216787904_item	2348717	et	3	main
et	doc_366216787904_item	2348734	et	3	main
kergemaks	doc_366216787904_item	2348737	et	4	main
võib	doc_366216787904_item	2348740	et	3	main
nõukogude	doc_366216787904_item	2348759	et	3	main
eesti	doc_366216787904_item	2348767	et	4	main
rahvas	doc_366216787904_item	2348768	et	4	main
et	doc_366216787904_item	2348773	et	3	main
rahvalaulupeod	doc_366216787904_item	2348783	et	4	main
et	doc_366216787904_item	2348786	et	3	main
vabatahtlik	doc_366216787904_item	2348788	et	3	main
motivation	doc_366216787904_item	2348791	et	4	main
huvi	doc_366216787904_item	2348796	et	4	main
muidugi	doc_366216787904_item	2348797	et	4	main
mitte	doc_366216787904_item	2348798	et	3	main
ka	doc_366216787904_item	2348826	et	3	main
erinevaid	doc_366216787904_item	2348834	et	4	main
eesti	doc_366216787904_item	2348842	et	4	main
ja	doc_366216787904_item	2348847	et	3	main
essee	doc_366216787904_item	2348674	et	4	main
eesti	doc_366216787904_item	2348675	et	4	main
keele	doc_366216787904_item	2348676	et	4	main
teeb	doc_366216787904_item	2348686	et	3	main
300	doc_366216787904_item	2348691	et	2	main
ja	doc_366216787904_item	2348703	et	3	main
mis	doc_366216787904_item	2348712	et	4	main
et	doc_366216787904_item	2348719	et	3	main
ja	doc_366216787904_item	2348724	et	3	main
laulurahvas	doc_366216787904_item	2348744	et	4	main
püüavad	doc_366216787904_item	2348747	et	3	main
ning	doc_366216787904_item	2348749	et	3	main
oma	doc_366216787904_item	2348751	et	4	main
venemaa	doc_366216787904_item	2348762	et	4	main
ajal	doc_366216787904_item	2348763	et	4	main
oma	doc_366216787904_item	2348770	et	4	main
oma	doc_366216787904_item	2348775	et	4	main
keegi	doc_366216787904_item	2348779	et	4	main
ju	doc_366216787904_item	2348780	et	3	main
ei	doc_366216787904_item	2348781	et	4	main
rahvalaulu	doc_366216787904_item	2348795	et	4	main
oma	doc_366216787904_item	2348828	et	4	main
eestlased	doc_366216787904_item	2348832	et	3	main
üritusi	doc_366216787904_item	2348838	et	4	main
rahvas	doc_366216787904_item	2348843	et	4	main
väga	doc_366216787904_item	2348845	et	3	main
nimetada	doc_366216787904_item	2348853	et	3	main
ja	doc_366216787904_item	2348699	et	3	main
faktidele	doc_366216787904_item	2348706	et	3	main
teeb	doc_366216787904_item	2348713	et	3	main
muljeid	doc_366216787904_item	2348725	et	3	main
nii	doc_366216787904_item	2348733	et	3	main
elu	doc_366216787904_item	2348735	et	4	main
on	doc_366216787904_item	2348743	et	4	main
poole	doc_366216787904_item	2348772	et	4	main
taastada	doc_366216787904_item	2348774	et	3	main
korraldada	doc_366216787904_item	2348784	et	3	main
tunne	doc_366216787904_item	2348789	et	4	main
vanal	doc_366216787904_item	2348800	et	3	main
ajal	doc_366216787904_item	2348801	et	4	main
inimesed	doc_366216787904_item	2348802	et	3	main
tahtsid	doc_366216787904_item	2348803	et	4	main
oma	doc_366216787904_item	2348804	et	4	main
kultuuri	doc_366216787904_item	2348805	et	4	main
säilitada	doc_366216787904_item	2348806	et	3	main
näiteks	doc_366216787904_item	2348807	et	4	main
praeguses	doc_366216787904_item	2348808	et	3	main
elus	doc_366216787904_item	2348809	et	4	main
rahvalaul	doc_366216787904_item	2348810	et	4	main
on	doc_366216787904_item	2348811	et	4	main
väga	doc_366216787904_item	2348812	et	3	main
populaarne	doc_366216787904_item	2348813	et	3	main
laulmine	doc_366216787904_item	2348814	et	4	main
mitmekülgne	doc_366216787904_item	2348816	et	3	main
on	doc_366216787904_item	2348815	et	4	main
eesti	doc_366216787904_item	2348817	et	4	main
heliloojad	doc_366216787904_item	2348818	et	3	main
on	doc_366216787904_item	2348819	et	4	main
tuntud	doc_366216787904_item	2348820	et	4	main
üle	doc_366216787904_item	2348821	et	3	main
ja	doc_366216787904_item	2348823	et	3	main
püüavad	doc_366216787904_item	2348825	et	3	main
hoida	doc_366216787904_item	2348827	et	3	main
armuga	doc_366216787904_item	2348831	et	3	main
selle	doc_366216787904_item	2348839	et	4	main
nimelt	doc_366216787904_item	2348840	et	4	main
et	doc_366216787904_item	2348841	et	3	main
sihikindel	doc_366216787904_item	2348846	et	3	main
seepärast	doc_366216787904_item	2348850	et	3	main
laulurahvastena	doc_366216787904_item	2348854	et	4	main
elama	doc_366216787904_item	2348730	et	3	main
ja	doc_366216787904_item	2348731	et	3	main
ongi	doc_366216787904_item	2348732	et	4	main
tuleb	doc_366216787904_item	2348736	et	3	main
ja	doc_366216787904_item	2348738	et	3	main
lõbusamaks	doc_366216787904_item	2348739	et	4	main
olla	doc_366216787904_item	2348741	et	3	main
sest	doc_366216787904_item	2348745	et	4	main
levida	doc_366216787904_item	2348750	et	3	main
organiseerisid	doc_366216787904_item	2348764	et	4	main
inimesed	doc_366216787904_item	2348765	et	3	main
rahvalaulupidusid	doc_366216787904_item	2348766	et	4	main
kultuuri	doc_366216787904_item	2348771	et	4	main
ja	doc_366216787904_item	2348777	et	3	main
arvan	doc_366216787904_item	2348785	et	3	main
just	doc_366216787904_item	2348787	et	3	main
ja	doc_366216787904_item	2348790	et	3	main
on	doc_366216787904_item	2348792	et	4	main
eestlaste	doc_366216787904_item	2348794	et	4	main
korralikult	doc_366216787904_item	2348830	et	4	main
korraldavad	doc_366216787904_item	2348833	et	4	main
festivaale	doc_366216787904_item	2348835	et	4	main
ja	doc_366216787904_item	2348836	et	3	main
folkloori	doc_366216787904_item	2348837	et	4	main
korralik	doc_366216787904_item	2348848	et	3	main
just	doc_366216787904_item	2348849	et	3	main
eestlasi	doc_366216787904_item	2348851	et	3	main
maailma	doc_366216787904_item	2348822	et	4	main
nad	doc_366216787904_item	2348824	et	3	main
kultuuri	doc_366216787904_item	2348829	et	4	main
on	doc_366216787904_item	2348844	et	4	main
võib	doc_366216787904_item	2348852	et	3	main
kultuur	doc_368487548147_item	2350602	et	3	main
vanim	doc_368487548147_item	2350611	et	3	main
asula	doc_368487548147_item	2350612	et	4	main
ääres	doc_368487548147_item	2350615	et	4	main
kiviaeg	doc_368487548147_item	2350621	et	3	main
ekr	doc_368487548147_item	2350629	et	4	main
korjamisega	doc_368487548147_item	2350636	et	4	main
seene	doc_368487548147_item	2350638	et	3	main
juurikaid	doc_368487548147_item	2350641	et	4	main
algeliseid	doc_368487548147_item	2350650	et	4	main
karusloomi	doc_368487548147_item	2350654	et	4	main
peamiselt	doc_368487548147_item	2350657	et	4	main
torkeodadega	doc_368487548147_item	2350660	et	3	main
on	doc_368487548147_item	2350662	et	4	main
luust	doc_368487548147_item	2350692	et	4	main
arvatavasti	doc_368487548147_item	2350702	et	3	main
olid	doc_368487548147_item	2350703	et	4	main
säilinud	doc_368487548147_item	2350712	et	4	main
kaetud	doc_368487548147_item	2350715	et	4	main
1	doc_368487548147_item	2350595	et	2	main
kiviaeg	doc_368487548147_item	2350596	et	3	main
eesti	doc_368487548147_item	2350597	et	4	main
territooriumil	doc_368487548147_item	2350598	et	3	main
mõiste	doc_368487548147_item	2350600	et	4	main
tähendus	doc_368487548147_item	2350603	et	4	main
paleoliitikum	doc_368487548147_item	2350607	et	3	main
saj	doc_368487548147_item	2350618	et	4	main
ekr	doc_368487548147_item	2350619	et	4	main
keskmine	doc_368487548147_item	2350620	et	3	main
arheoloogiline	doc_368487548147_item	2350601	et	4	main
kiviaeg	doc_368487548147_item	2350604	et	3	main
kiviaeg	doc_368487548147_item	2350606	et	3	main
saj	doc_368487548147_item	2350609	et	4	main
ekr	doc_368487548147_item	2350610	et	4	main
pullis	doc_368487548147_item	2350616	et	4	main
lõpp	doc_368487548147_item	2350625	et	3	main
korjati	doc_368487548147_item	2350637	et	3	main
kasutati	doc_368487548147_item	2350645	et	4	main
ahingut	doc_368487548147_item	2350647	et	3	main
õngekonksuid	doc_368487548147_item	2350648	et	4	main
küttimiseks	doc_368487548147_item	2350656	et	4	main
et	doc_368487548147_item	2350664	et	3	main
tulekivist	doc_368487548147_item	2350699	et	4	main
neid	doc_368487548147_item	2350709	et	4	main
on	doc_368487548147_item	2350710	et	4	main
vähe	doc_368487548147_item	2350711	et	3	main
on	doc_368487548147_item	2350725	et	4	main
balti	doc_368487548147_item	2350728	et	3	main
olid	doc_368487548147_item	2350734	et	4	main
st	doc_368487548147_item	2350738	et	3	main
elupaiga	doc_368487548147_item	2350750	et	4	main
metsas	doc_368487548147_item	2350762	et	3	main
kasutati	doc_368487548147_item	2350767	et	4	main
välja	doc_368487548147_item	2350773	et	4	main
kultuur	doc_368487548147_item	2350775	et	3	main
kiviajal	doc_368487548147_item	2350804	et	3	main
kultuuris	doc_368487548147_item	2350811	et	3	main
segati	doc_368487548147_item	2350817	et	3	main
taimi	doc_368487548147_item	2350822	et	4	main
kaunistatud	doc_368487548147_item	2350824	et	4	main
välja	doc_368487548147_item	2350833	et	4	main
neoliitikumis	doc_368487548147_item	2350834	et	3	main
sõjakirviste	doc_368487548147_item	2350843	et	4	main
pärast	doc_368487548147_item	2350848	et	4	main
baltimaade	doc_368487548147_item	2350850	et	3	main
territooriumile	doc_368487548147_item	2350851	et	3	main
sängitati	doc_368487548147_item	2350852	et	3	main
kaasa	doc_368487548147_item	2350856	et	4	main
pandi	doc_368487548147_item	2350857	et	4	main
mis	doc_368487548147_item	2350861	et	4	main
võiks	doc_368487548147_item	2350863	et	4	main
olla	doc_368487548147_item	2350864	et	3	main
kasulik	doc_368487548147_item	2350865	et	3	main
teispoolses	doc_368487548147_item	2350866	et	3	main
mõnikord	doc_368487548147_item	2350875	et	3	main
pandi	doc_368487548147_item	2350876	et	4	main
kaasa	doc_368487548147_item	2350878	et	4	main
raviva	doc_368487548147_item	2350881	et	4	main
toie	doc_368487548147_item	2350882	et	4	main
annotatsioon	doc_384045275263_item	2351016	et	3	main
raamat	doc_384045275263_item	2351018	et	3	main
kontrolltöö	doc_368487548147_item	2350594	et	4	main
vanem	doc_368487548147_item	2350605	et	4	main
viii	doc_368487548147_item	2350608	et	4	main
leitud	doc_368487548147_item	2350613	et	4	main
presoliitikum	doc_368487548147_item	2350622	et	4	main
aastatuhande	doc_368487548147_item	2350624	et	4	main
keskpaik	doc_368487548147_item	2350628	et	3	main
tegelesid	doc_368487548147_item	2350631	et	4	main
küttimise	doc_368487548147_item	2350632	et	4	main
ja	doc_368487548147_item	2350642	et	3	main
ja	doc_368487548147_item	2350649	et	3	main
viske-	doc_368487548147_item	2350658	et	3	main
kobrasteküttimiseks	doc_368487548147_item	2350667	et	4	main
ja	doc_368487548147_item	2350700	et	3	main
kvartsist	doc_368487548147_item	2350701	et	4	main
esemed	doc_368487548147_item	2350705	et	3	main
aga	doc_368487548147_item	2350707	et	3	main
kahjuks	doc_368487548147_item	2350708	et	4	main
nahaga	doc_368487548147_item	2350716	et	3	main
kuid	doc_368487548147_item	2350718	et	4	main
ka	doc_368487548147_item	2350719	et	3	main
mätastega	doc_368487548147_item	2350720	et	3	main
endale	doc_368487548147_item	2350731	et	4	main
kus	doc_368487548147_item	2350733	et	3	main
kui	doc_368487548147_item	2350742	et	3	main
uue	doc_368487548147_item	2350749	et	3	main
peamiselt	doc_368487548147_item	2350756	et	4	main
ääres	doc_368487548147_item	2350758	et	4	main
kuna	doc_368487548147_item	2350759	et	3	main
sel	doc_368487548147_item	2350760	et	3	main
väga	doc_368487548147_item	2350764	et	3	main
puid	doc_368487548147_item	2350766	et	3	main
ka	doc_368487548147_item	2350768	et	3	main
liiklusteedena	doc_368487548147_item	2350770	et	3	main
esemed	doc_368487548147_item	2350776	et	3	main
oli	doc_368487548147_item	2350805	et	3	main
valmistati	doc_368487548147_item	2350812	et	4	main
sisse	doc_368487548147_item	2350816	et	4	main
teokarpe	doc_368487548147_item	2350818	et	4	main
ja	doc_368487548147_item	2350820	et	3	main
keraamika	doc_368487548147_item	2350826	et	4	main
ekr	doc_368487548147_item	2350830	et	4	main
selle	doc_368487548147_item	2350838	et	4	main
kultuuri	doc_368487548147_item	2350839	et	4	main
tööriist	doc_368487548147_item	2350858	et	3	main
ja	doc_368487548147_item	2350873	et	3	main
ka	doc_368487548147_item	2350879	et	3	main
2	doc_368487548147_item	2350599	et	2	main
pärnu	doc_368487548147_item	2350614	et	4	main
viii	doc_368487548147_item	2350617	et	4	main
viii	doc_368487548147_item	2350623	et	4	main
aastatuhande	doc_368487548147_item	2350627	et	4	main
inimesed	doc_368487548147_item	2350630	et	3	main
kalapüügi	doc_368487548147_item	2350633	et	4	main
ja	doc_368487548147_item	2350634	et	3	main
loodusandide	doc_368487548147_item	2350635	et	3	main
söödavaid	doc_368487548147_item	2350640	et	4	main
marju	doc_368487548147_item	2350643	et	3	main
kütiti	doc_368487548147_item	2350652	et	3	main
ja	doc_368487548147_item	2350655	et	3	main
kuid	doc_368487548147_item	2350661	et	4	main
teada	doc_368487548147_item	2350663	et	3	main
hülje-	doc_368487548147_item	2350665	et	4	main
ja	doc_368487548147_item	2350666	et	3	main
savist	doc_368487548147_item	2350693	et	4	main
ja	doc_368487548147_item	2350694	et	3	main
kivist	doc_368487548147_item	2350695	et	4	main
kuid	doc_368487548147_item	2350696	et	4	main
leidub	doc_368487548147_item	2350697	et	3	main
ka	doc_368487548147_item	2350704	et	3	main
puust	doc_368487548147_item	2350706	et	4	main
püstkojad	doc_368487548147_item	2350713	et	3	main
okastega	doc_368487548147_item	2350717	et	3	main
iv	doc_368487548147_item	2350626	et	4	main
pähkleid	doc_368487548147_item	2350639	et	3	main
kalapüügiks	doc_368487548147_item	2350644	et	3	main
luust	doc_368487548147_item	2350646	et	4	main
võrguid	doc_368487548147_item	2350651	et	4	main
põtru	doc_368487548147_item	2350653	et	3	main
ja	doc_368487548147_item	2350659	et	3	main
olid	doc_368487548147_item	2350668	et	4	main
harpuunid	doc_368487548147_item	2350669	et	4	main
elati	doc_368487548147_item	2350670	et	3	main
20-40	doc_368487548147_item	2350671	et	2	main
liikmestes	doc_368487548147_item	2350672	et	4	main
kogukondades	doc_368487548147_item	2350673	et	3	main
püstkodades	doc_368487548147_item	2350675	et	3	main
koonusekujulistes	doc_368487548147_item	2350674	et	4	main
mille	doc_368487548147_item	2350676	et	3	main
keskel	doc_368487548147_item	2350677	et	3	main
asus	doc_368487548147_item	2350678	et	4	main
mis	doc_368487548147_item	2350680	et	4	main
kolle	doc_368487548147_item	2350679	et	4	main
andis	doc_368487548147_item	2350681	et	3	main
soojust	doc_368487548147_item	2350682	et	4	main
ja	doc_368487548147_item	2350683	et	3	main
valgust	doc_368487548147_item	2350684	et	4	main
samuti	doc_368487548147_item	2350685	et	3	main
küpsetati	doc_368487548147_item	2350686	et	3	main
söögi	doc_368487548147_item	2350687	et	4	main
töö-	doc_368487548147_item	2350688	et	4	main
a	doc_368487548147_item	2350689	et	4	main
tarberiistad	doc_368487548147_item	2350690	et	3	main
olid	doc_368487548147_item	2350691	et	4	main
samuti	doc_368487548147_item	2350698	et	3	main
olid	doc_368487548147_item	2350714	et	4	main
talveti	doc_368487548147_item	2350721	et	4	main
oleks	doc_368487548147_item	2350723	et	3	main
elamiseks	doc_368487548147_item	2350737	et	4	main
rohkem	doc_368487548147_item	2350739	et	4	main
kuid	doc_368487548147_item	2350741	et	4	main
said	doc_368487548147_item	2350744	et	4	main
nad	doc_368487548147_item	2350747	et	3	main
otsisid	doc_368487548147_item	2350748	et	4	main
et	doc_368487548147_item	2350753	et	3	main
elasid	doc_368487548147_item	2350755	et	4	main
veekogude	doc_368487548147_item	2350757	et	3	main
oli	doc_368487548147_item	2350763	et	3	main
kivilihvimine	doc_368487548147_item	2350803	et	3	main
välja	doc_368487548147_item	2350806	et	4	main
narva	doc_368487548147_item	2350810	et	4	main
savist	doc_368487548147_item	2350814	et	4	main
iv	doc_368487548147_item	2350827	et	4	main
e	doc_368487548147_item	2350835	et	4	main
kirviste	doc_368487548147_item	2350847	et	4	main
surnud	doc_368487548147_item	2350849	et	4	main
külili	doc_368487548147_item	2350853	et	3	main
või	doc_368487548147_item	2350854	et	4	main
kägiras	doc_368487548147_item	2350855	et	4	main
ka	doc_368487548147_item	2350869	et	3	main
ehteid	doc_368487548147_item	2350871	et	3	main
sunutele	doc_368487548147_item	2350877	et	4	main
merevaik	doc_368487548147_item	2350880	et	3	main
puhul	doc_368487548147_item	2350883	et	4	main
päikesekivi	doc_368487548147_item	2350884	et	4	main
on	doc_384045275263_item	2351019	et	4	main
spetsialiseeritud	doc_384045275263_item	2351021	et	4	main
peipsi	doc_384045275263_item	2351023	et	4	main
750	doc_384045275263_item	2351035	et	2	main
ja	doc_384045275263_item	2351043	et	3	main
rahvajutud	doc_384045275263_item	2351047	et	3	main
olulist	doc_384045275263_item	2351051	et	4	main
elanike	doc_384045275263_item	2351054	et	3	main
ja	doc_384045275263_item	2351059	et	3	main
laulud	doc_384045275263_item	2351061	et	3	main
rahvalaulud	doc_384045275263_item	2351064	et	3	main
muinasjutud	doc_384045275263_item	2351067	et	3	main
mitte-muinasjutuslik	doc_384045275263_item	2351068	et	4	main
vanasõnad	doc_384045275263_item	2351070	et	3	main
mõistatused	doc_384045275263_item	2351071	et	4	main
kohal	doc_384045275263_item	2351075	et	4	main
küla	doc_384045275263_item	2351082	et	4	main
on	doc_384045275263_item	2351086	et	4	main
etnoloogidele	doc_384045275263_item	2351093	et	3	main
üliõpilastele	doc_384045275263_item	2351095	et	4	main
et	doc_368487548147_item	2350722	et	3	main
teada	doc_368487548147_item	2350726	et	3	main
et	doc_368487548147_item	2350727	et	3	main
hõimud	doc_368487548147_item	2350729	et	4	main
parimad	doc_368487548147_item	2350735	et	4	main
otsa	doc_368487548147_item	2350745	et	4	main
siid	doc_368487548147_item	2350746	et	3	main
on	doc_368487548147_item	2350751	et	4	main
tihedalt	doc_368487548147_item	2350765	et	4	main
veekogusid	doc_368487548147_item	2350769	et	4	main
kiviajal	doc_368487548147_item	2350771	et	3	main
tehti	doc_368487548147_item	2350777	et	3	main
veel	doc_368487548147_item	2350778	et	4	main
luust	doc_368487548147_item	2350779	et	4	main
ja	doc_368487548147_item	2350780	et	3	main
sarvidest	doc_368487548147_item	2350781	et	3	main
tulekiviesemed	doc_368487548147_item	2350782	et	3	main
eestis	doc_368487548147_item	2350783	et	3	main
oli	doc_368487548147_item	2350784	et	3	main
suhteliselt	doc_368487548147_item	2350785	et	4	main
vähe	doc_368487548147_item	2350786	et	3	main
sellepärast	doc_368487548147_item	2350787	et	3	main
kasutati	doc_368487548147_item	2350788	et	4	main
kvartsi	doc_368487548147_item	2350789	et	4	main
kiviajal	doc_368487548147_item	2350790	et	3	main
leidub	doc_368487548147_item	2350791	et	3	main
juba	doc_368487548147_item	2350792	et	3	main
lihvitud	doc_368487548147_item	2350793	et	4	main
tööriistu	doc_368487548147_item	2350794	et	3	main
ka	doc_368487548147_item	2350797	et	3	main
kivimetest	doc_368487548147_item	2350795	et	4	main
uued	doc_368487548147_item	2350798	et	3	main
valmistamisvõtted	doc_368487548147_item	2350799	et	3	main
olid	doc_368487548147_item	2350796	et	4	main
puurimine	doc_368487548147_item	2350800	et	4	main
saagimine	doc_368487548147_item	2350801	et	4	main
ja	doc_368487548147_item	2350802	et	3	main
soojem	doc_368487548147_item	2350724	et	3	main
otsisid	doc_368487548147_item	2350730	et	4	main
kohti	doc_368487548147_item	2350732	et	4	main
tingimused	doc_368487548147_item	2350736	et	3	main
loodusande	doc_368487548147_item	2350740	et	4	main
loodusressursid	doc_368487548147_item	2350743	et	3	main
tead	doc_368487548147_item	2350752	et	4	main
inimesed	doc_368487548147_item	2350754	et	3	main
ajal	doc_368487548147_item	2350761	et	4	main
kujuneb	doc_368487548147_item	2350772	et	3	main
kunda	doc_368487548147_item	2350774	et	4	main
kujunenud	doc_368487548147_item	2350807	et	4	main
narva	doc_368487548147_item	2350808	et	4	main
kultuur	doc_368487548147_item	2350809	et	3	main
keraamikat	doc_368487548147_item	2350813	et	3	main
kivipuru	doc_368487548147_item	2350819	et	4	main
mille	doc_368487548147_item	2350815	et	3	main
isegi	doc_368487548147_item	2350821	et	4	main
kammkeraamika	doc_368487548147_item	2350823	et	4	main
kammivajutustega	doc_368487548147_item	2350825	et	4	main
lõpul	doc_368487548147_item	2350829	et	3	main
nöörkeraamika	doc_368487548147_item	2350831	et	4	main
kujunes	doc_368487548147_item	2350832	et	3	main
kiviajas	doc_368487548147_item	2350837	et	3	main
ka	doc_368487548147_item	2350841	et	3	main
kultuuriks	doc_368487548147_item	2350844	et	4	main
meenutavate	doc_368487548147_item	2350846	et	4	main
tarbeese	doc_368487548147_item	2350860	et	3	main
arvati	doc_368487548147_item	2350862	et	4	main
elus	doc_368487548147_item	2350867	et	4	main
loomahambaid	doc_368487548147_item	2350872	et	3	main
kihvu	doc_368487548147_item	2350874	et	3	main
käesolev	doc_384045275263_item	2351017	et	3	main
esimene	doc_384045275263_item	2351020	et	3	main
pandud	doc_384045275263_item	2351029	et	4	main
aastatel	doc_384045275263_item	2351030	et	4	main
raamat	doc_384045275263_item	2351032	et	3	main
teksti	doc_384045275263_item	2351036	et	4	main
gruppeeritult	doc_384045275263_item	2351037	et	4	main
värsid	doc_384045275263_item	2351041	et	3	main
mis	doc_384045275263_item	2351049	et	4	main
mängis	doc_384045275263_item	2351050	et	3	main
kujunemisel	doc_384045275263_item	2351057	et	4	main
tšastuškad	doc_384045275263_item	2351066	et	2	main
nõiasõnad	doc_384045275263_item	2351079	et	3	main
posijatest	doc_384045275263_item	2351083	et	4	main
on	doc_384045275263_item	2351090	et	4	main
kõigile	doc_384045275263_item	2351098	et	4	main
pärimuskultuuri	doc_384045275263_item	2351100	et	4	main
huvilistele	doc_384045275263_item	2351101	et	4	main
põhjusel	doc_384045275264_item	2351122	et	3	main
oli	doc_384045275264_item	2351124	et	3	main
nad	doc_384045275264_item	2351132	et	3	main
kohalike	doc_384045275264_item	2351135	et	4	main
meisterlikuse	doc_384045275264_item	2351148	et	4	main
ehitusmeistrid	doc_384045275264_item	2351151	et	3	main
spetsialiseerusid	doc_384045275264_item	2351154	et	4	main
müüritöödel	doc_384045275264_item	2351156	et	3	main
taludes	doc_384045275264_item	2351160	et	4	main
mõisates	doc_384045275264_item	2351162	et	3	main
ehitusmeistrite	doc_384045275264_item	2351165	et	3	main
kätetöö	doc_384045275264_item	2351166	et	4	main
eesti	doc_384045275264_item	2351174	et	4	main
linnades	doc_384045275264_item	2351175	et	3	main
on	doc_384045275264_item	2351176	et	4	main
ehitatud	doc_384045275264_item	2351177	et	4	main
olid	doc_384045275264_item	2351195	et	4	main
kasvatasid	doc_384045275264_item	2351200	et	4	main
tsigurit	doc_384045275264_item	2351202	et	4	main
sibulat	doc_384045275264_item	2351204	et	3	main
ja	doc_384045275264_item	2351206	et	3	main
alguseni	doc_384045275264_item	2351229	et	3	main
töö	doc_384045275264_item	2351233	et	4	main
tasuti	doc_384045275264_item	2351235	et	3	main
lastele	doc_384045275264_item	2351236	et	4	main
aastatuhandete	doc_368487548147_item	2350828	et	4	main
noorimas	doc_368487548147_item	2350836	et	4	main
nimetatakse	doc_368487548147_item	2350840	et	3	main
vene-lik	doc_368487548147_item	2350842	et	4	main
paati	doc_368487548147_item	2350845	et	4	main
või	doc_368487548147_item	2350859	et	4	main
leidub	doc_368487548147_item	2350868	et	3	main
kalmetest	doc_368487548147_item	2350870	et	3	main
2	doc_368487548147_item	2350885	et	2	main
arheoloogiline	doc_368487548147_item	2350886	et	4	main
kultuur	doc_368487548147_item	2350887	et	3	main
teatud	doc_368487548147_item	2350888	et	4	main
inimgrupile	doc_368487548147_item	2350889	et	3	main
iseloomulik	doc_368487548147_item	2350890	et	3	main
kultuur	doc_368487548147_item	2350891	et	3	main
mis	doc_368487548147_item	2350892	et	4	main
kujuneb	doc_368487548147_item	2350893	et	3	main
välja	doc_368487548147_item	2350894	et	4	main
arheoloogilise	doc_368487548147_item	2350895	et	4	main
uurimistöö	doc_368487548147_item	2350896	et	4	main
käigus	doc_368487548147_item	2350897	et	4	main
mis	doc_368487548147_item	2350898	et	4	main
annab	doc_368487548147_item	2350899	et	3	main
meile	doc_368487548147_item	2350900	et	4	main
teadmisi	doc_368487548147_item	2350901	et	4	main
et	doc_368487548147_item	2350902	et	3	main
igal	doc_368487548147_item	2350903	et	3	main
leiul	doc_368487548147_item	2350905	et	3	main
arheoloogilisel	doc_368487548147_item	2350904	et	4	main
on	doc_368487548147_item	2350906	et	4	main
sarnased	doc_368487548147_item	2350907	et	4	main
muistised	doc_368487548147_item	2350908	et	3	main
territoorium	doc_368487548147_item	2350909	et	3	main
ja	doc_368487548147_item	2350910	et	3	main
ajajärk	doc_368487548147_item	2350911	et	3	main
sisaldab	doc_384045275263_item	2351033	et	3	main
printsiibil	doc_384045275263_item	2351039	et	3	main
roll	doc_384045275263_item	2351052	et	3	main
majandustegevuse	doc_384045275263_item	2351055	et	4	main
eripära	doc_384045275263_item	2351056	et	4	main
humoristliku	doc_384045275263_item	2351062	et	3	main
olulisel	doc_384045275263_item	2351074	et	4	main
pärimused	doc_384045275263_item	2351077	et	4	main
ja	doc_384045275263_item	2351080	et	3	main
filoloogidele	doc_384045275263_item	2351092	et	3	main
tõlge	doc_384045275264_item	2351102	et	3	main
põllumaad	doc_384045275264_item	2351123	et	4	main
tingimustega	doc_384045275264_item	2351136	et	3	main
majandusharusid	doc_384045275264_item	2351141	et	3	main
mehed	doc_384045275264_item	2351142	et	3	main
paljud	doc_384045275264_item	2351157	et	3	main
ümbruskonna	doc_384045275264_item	2351159	et	4	main
ja	doc_384045275264_item	2351161	et	3	main
ka	doc_384045275264_item	2351167	et	3	main
ehitustöödel	doc_384045275264_item	2351182	et	3	main
pihkvas	doc_384045275264_item	2351184	et	4	main
petrogradis	doc_384045275264_item	2351186	et	4	main
müügiks	doc_384045275264_item	2351201	et	3	main
poisid	doc_384045275264_item	2351222	et	4	main
tüdrukud	doc_384045275264_item	2351224	et	3	main
eest	doc_384045275264_item	2351234	et	4	main
ja	doc_384045275264_item	2351240	et	3	main
siiski	doc_384045275264_item	2351243	et	4	main
põhiliseks	doc_384045275264_item	2351245	et	3	main
majandustegevuse	doc_384045275264_item	2351246	et	4	main
kümneid	doc_384045275264_item	2351258	et	4	main
igas	doc_384045275264_item	2351260	et	3	main
peredes	doc_384045275264_item	2351275	et	3	main
järvele	doc_384045275264_item	2351276	et	4	main
naised	doc_384045275264_item	2351279	et	3	main
põlvest	doc_384045275264_item	2351285	et	4	main
lihvisid	doc_384045275264_item	2351287	et	4	main
vanausulised	doc_384045275264_item	2351288	et	4	main
jääaluse	doc_384045275264_item	2351289	et	4	main
püügi	doc_384045275264_item	2351290	et	4	main
ja	doc_384045275264_item	2351292	et	3	main
ja	doc_384045275264_item	2351300	et	3	main
kohalikud	doc_384045275264_item	2351306	et	3	main
liikumise	doc_384045275264_item	2351316	et	4	main
aasta	doc_384045275264_item	2351331	et	4	main
folklooriekspeditsiooni	doc_384045275264_item	2351332	et	4	main
kljavin	doc_384045275264_item	2351339	et	4	main
aljoksin	doc_384045275264_item	2351342	et	4	main
saveli	doc_384045275264_item	2351343	et	4	main
poljakov	doc_384045275264_item	2351345	et	4	main
teised	doc_384045275264_item	2351347	et	4	main
alistades	doc_384045275264_item	2351350	et	3	main
kohalikud	doc_384045275264_item	2351356	et	3	main
talveteed	doc_384045275264_item	2351371	et	4	main
kuuseokstest	doc_384045275264_item	2351372	et	3	main
tehtud	doc_384045275264_item	2351373	et	4	main
mis	doc_384045275264_item	2351375	et	4	main
lube	doc_384045275264_item	2351388	et	3	main
vaimukalt	doc_384045275264_item	2351421	et	4	main
võistlusi	doc_384045275264_item	2351430	et	3	main
mis	doc_384045275264_item	2351438	et	4	main
aitavad	doc_384045275264_item	2351439	et	4	main
saagile	doc_384045275264_item	2351451	et	3	main
käisid	doc_384045275264_item	2351453	et	4	main
peipsi	doc_384045275264_item	2351458	et	4	main
lääneranniku	doc_384045275263_item	2351024	et	3	main
vene	doc_384045275263_item	2351025	et	4	main
vanausuliste	doc_384045275263_item	2351026	et	4	main
folklooriväljaanne	doc_384045275263_item	2351027	et	4	main
kirja	doc_384045275263_item	2351028	et	4	main
ligi	doc_384045275263_item	2351034	et	3	main
etiketi	doc_384045275263_item	2351045	et	4	main
perekombestikuluule	doc_384045275263_item	2351060	et	4	main
proosa	doc_384045275263_item	2351069	et	4	main
on	doc_384045275263_item	2351076	et	4	main
kõik	doc_384045275263_item	2351084	et	4	main
tekstid	doc_384045275263_item	2351085	et	3	main
publitseeritud	doc_384045275263_item	2351087	et	4	main
mõeldud	doc_384045275263_item	2351091	et	4	main
hummanitaarteaduste	doc_384045275263_item	2351094	et	4	main
hektarit	doc_384045275264_item	2351129	et	3	main
peeti	doc_384045275264_item	2351130	et	4	main
normiks	doc_384045275264_item	2351131	et	4	main
kohanema	doc_384045275264_item	2351134	et	3	main
ja	doc_384045275264_item	2351138	et	3	main
mittetraditsioonilisi	doc_384045275264_item	2351140	et	4	main
eesti	doc_384045275264_item	2351145	et	4	main
ja	doc_384045275264_item	2351147	et	3	main
hinnatud	doc_384045275264_item	2351150	et	4	main
ja	doc_384045275264_item	2351152	et	3	main
põhiliselt	doc_384045275264_item	2351155	et	4	main
vanausulistest	doc_384045275264_item	2351164	et	4	main
ametihooneid	doc_384045275264_item	2351169	et	4	main
tegelesid	doc_384045275264_item	2351189	et	4	main
läbi	doc_384045275264_item	2351191	et	4	main
aegade	doc_384045275264_item	2351192	et	3	main
vanausuliste	doc_384045275264_item	2351193	et	4	main
naised	doc_384045275264_item	2351194	et	3	main
kodumajanduses	doc_384045275264_item	2351197	et	3	main
köögivilju	doc_384045275264_item	2351208	et	3	main
nii	doc_384045275264_item	2351221	et	3	main
kui	doc_384045275264_item	2351223	et	3	main
töötasid	doc_384045275264_item	2351230	et	4	main
muude	doc_384045275264_item	2351241	et	4	main
vanausuliste	doc_384045275264_item	2351252	et	4	main
laiuvad	doc_384045275264_item	2351254	et	4	main
peipsi	doc_384045275264_item	2351255	et	4	main
mööda	doc_384045275264_item	2351257	et	4	main
kalasaak	doc_384045275264_item	2351281	et	3	main
kuudel	doc_384045275264_item	2351284	et	4	main
võtteid	doc_384045275264_item	2351291	et	3	main
iseka	doc_384045275264_item	2351298	et	3	main
ilma	doc_384045275264_item	2351299	et	4	main
peipsi	doc_384045275264_item	2351301	et	4	main
inimesed	doc_384045275264_item	2351307	et	3	main
sõltus	doc_384045275264_item	2351321	et	4	main
mis	doc_384045275264_item	2351323	et	4	main
oli	doc_384045275264_item	2351324	et	3	main
parajasti	doc_384045275264_item	2351325	et	3	main
2006	doc_384045275264_item	2351330	et	2	main
liikmetele	doc_384045275264_item	2351333	et	3	main
rääkisid	doc_384045275264_item	2351334	et	4	main
põhjalikult	doc_384045275264_item	2351336	et	4	main
ivan	doc_384045275264_item	2351337	et	4	main
grigorjevitš	doc_384045275264_item	2351341	et	2	main
fjodorovitš	doc_384045275264_item	2351344	et	2	main
ja	doc_384045275264_item	2351346	et	3	main
kutselised	doc_384045275264_item	2351348	et	4	main
peipsi	doc_384045275264_item	2351351	et	4	main
järve	doc_384045275264_item	2351352	et	4	main
elanikud	doc_384045275264_item	2351357	et	3	main
leidlikust	doc_384045275264_item	2351359	et	4	main
oskust	doc_384045275264_item	2351361	et	3	main
lumme	doc_384045275264_item	2351367	et	4	main
teaduslik	doc_384045275263_item	2351022	et	3	main
19302006	doc_384045275263_item	2351031	et	2	main
žanri-temaatilisel	doc_384045275263_item	2351038	et	2	main
vaimulikud	doc_384045275263_item	2351040	et	3	main
religioosse	doc_384045275263_item	2351042	et	3	main
olme-perekondliku	doc_384045275263_item	2351044	et	3	main
reeglid	doc_384045275263_item	2351046	et	3	main
kalapüügist	doc_384045275263_item	2351048	et	3	main
kohalike	doc_384045275263_item	2351053	et	4	main
kalendri-	doc_384045275263_item	2351058	et	3	main
sisuga	doc_384045275263_item	2351063	et	3	main
ehk	doc_384045275263_item	2351065	et	3	main
laste	doc_384045275263_item	2351072	et	4	main
folkloor	doc_384045275263_item	2351073	et	4	main
lausumised	doc_384045275263_item	2351078	et	4	main
jutustused	doc_384045275263_item	2351081	et	4	main
esmakordselt	doc_384045275263_item	2351088	et	4	main
kogumik	doc_384045275263_item	2351089	et	3	main
õpetajatele	doc_384045275263_item	2351096	et	4	main
ja	doc_384045275263_item	2351097	et	3	main
rahva	doc_384045275263_item	2351099	et	3	main
преданья	doc_384045275264_item	2351103	et	2	main
старины	doc_384045275264_item	2351104	et	2	main
глубокой	doc_384045275264_item	2351105	et	2	main
vana	doc_384045275264_item	2351106	et	4	main
halli	doc_384045275264_item	2351107	et	4	main
aja	doc_384045275264_item	2351108	et	4	main
muistendid	doc_384045275264_item	2351109	et	3	main
peipsimaa	doc_384045275264_item	2351110	et	4	main
vanausuliste	doc_384045275264_item	2351111	et	4	main
folklooritraditsioon	doc_384045275264_item	2351112	et	3	main
saabudes	doc_384045275264_item	2351113	et	3	main
venemaalt	doc_384045275264_item	2351114	et	3	main
asusid	doc_384045275264_item	2351115	et	4	main
elama	doc_384045275264_item	2351117	et	3	main
vanausulised	doc_384045275264_item	2351116	et	4	main
juba	doc_384045275264_item	2351118	et	3	main
asustatud	doc_384045275264_item	2351119	et	4	main
maadel	doc_384045275264_item	2351120	et	4	main
sellel	doc_384045275264_item	2351121	et	4	main
neil	doc_384045275264_item	2351125	et	4	main
olid	doc_384045275264_item	2351143	et	4	main
üle	doc_384045275264_item	2351144	et	3	main
töökuse	doc_384045275264_item	2351146	et	4	main
majandusdushooned	doc_384045275264_item	2351158	et	4	main
tallinnas	doc_384045275264_item	2351171	et	4	main
ja	doc_384045275264_item	2351172	et	3	main
teistes	doc_384045275264_item	2351173	et	4	main
käidi	doc_384045275264_item	2351181	et	3	main
ka	doc_384045275264_item	2351183	et	3	main
mehed	doc_384045275264_item	2351188	et	3	main
kaubandusega	doc_384045275264_item	2351190	et	3	main
hõivatud	doc_384045275264_item	2351196	et	4	main
aiandusega	doc_384045275264_item	2351199	et	3	main
hiljem	doc_384045275264_item	2351203	et	3	main
kurke	doc_384045275264_item	2351205	et	3	main
muid	doc_384045275264_item	2351207	et	4	main
suve	doc_384045275264_item	2351225	et	4	main
läbi	doc_384045275264_item	2351226	et	4	main
kuni	doc_384045275264_item	2351227	et	3	main
sügise	doc_384045275264_item	2351228	et	3	main
kartuli	doc_384045275264_item	2351239	et	3	main
väga	doc_384045275264_item	2351126	et	3	main
vähe	doc_384045275264_item	2351127	et	3	main
pool	doc_384045275264_item	2351128	et	4	main
pidid	doc_384045275264_item	2351133	et	4	main
omandama	doc_384045275264_item	2351137	et	3	main
arendama	doc_384045275264_item	2351139	et	3	main
pärast	doc_384045275264_item	2351149	et	4	main
pottseppad	doc_384045275264_item	2351153	et	4	main
on	doc_384045275264_item	2351163	et	4	main
palju	doc_384045275264_item	2351168	et	4	main
tartus	doc_384045275264_item	2351170	et	3	main
nende	doc_384045275264_item	2351178	et	4	main
kätega	doc_384045275264_item	2351179	et	3	main
tsaariajal	doc_384045275264_item	2351180	et	3	main
novgorodis	doc_384045275264_item	2351185	et	4	main
rikkamad	doc_384045275264_item	2351187	et	4	main
tegelesid	doc_384045275264_item	2351198	et	4	main
esimese	doc_384045275264_item	2351209	et	3	main
vabariigi	doc_384045275264_item	2351210	et	3	main
ajal	doc_384045275264_item	2351211	et	4	main
vanausuliste	doc_384045275264_item	2351212	et	4	main
lapsed	doc_384045275264_item	2351213	et	3	main
juba	doc_384045275264_item	2351214	et	3	main
7-8	doc_384045275264_item	2351215	et	2	main
eluaastast	doc_384045275264_item	2351216	et	4	main
käisid	doc_384045275264_item	2351217	et	4	main
tööl	doc_384045275264_item	2351218	et	3	main
eesti	doc_384045275264_item	2351219	et	4	main
taludes	doc_384045275264_item	2351220	et	4	main
lapsed	doc_384045275264_item	2351231	et	3	main
põllutöödel	doc_384045275264_item	2351232	et	3	main
teravilja	doc_384045275264_item	2351238	et	4	main
põllumajandussaadustega	doc_384045275264_item	2351242	et	3	main
vanausuluste	doc_384045275264_item	2351244	et	4	main
oli	doc_384045275264_item	2351248	et	3	main
aegadest	doc_384045275264_item	2351250	et	3	main
kallast	doc_384045275264_item	2351256	et	4	main
kilomeetreid	doc_384045275264_item	2351259	et	4	main
külas	doc_384045275264_item	2351261	et	3	main
oli	doc_384045275264_item	2351262	et	3	main
mitu	doc_384045275264_item	2351263	et	4	main
kalastusriartelli	doc_384045275264_item	2351264	et	4	main
enne	doc_384045275264_item	2351265	et	4	main
teist	doc_384045275264_item	2351266	et	4	main
maailmasõda	doc_384045275264_item	2351267	et	4	main
kalapüügiga	doc_384045275264_item	2351268	et	3	main
tegelesid	doc_384045275264_item	2351269	et	4	main
peaaegu	doc_384045275264_item	2351270	et	3	main
kõik	doc_384045275264_item	2351271	et	4	main
liha	doc_384045275264_item	2351237	et	4	main
alaks	doc_384045275264_item	2351247	et	3	main
täisealised	doc_384045275264_item	2351272	et	4	main
vaesetes	doc_384045275264_item	2351274	et	4	main
ka	doc_384045275264_item	2351278	et	3	main
oli	doc_384045275264_item	2351282	et	3	main
põlve	doc_384045275264_item	2351286	et	4	main
kalapüügiriistu	doc_384045275264_item	2351295	et	3	main
mida	doc_384045275264_item	2351305	et	4	main
kalapüügiriistade	doc_384045275264_item	2351319	et	3	main
püügi	doc_384045275264_item	2351326	et	4	main
objektiks	doc_384045275264_item	2351327	et	3	main
loginovitš	doc_384045275264_item	2351338	et	2	main
kalamehed	doc_384045275264_item	2351349	et	3	main
ilmutasid	doc_384045275264_item	2351355	et	4	main
olid	doc_384045275264_item	2351364	et	4	main
idakalda	doc_384045275264_item	2351365	et	3	main
suunas	doc_384045275264_item	2351366	et	4	main
teetähistega	doc_384045275264_item	2351374	et	4	main
ja	doc_384045275264_item	2351378	et	3	main
kasutati	doc_384045275264_item	2351383	et	4	main
peale	doc_384045275264_item	2351385	et	4	main
nimetati	doc_384045275264_item	2351422	et	4	main
karakatitsadeks	doc_384045275264_item	2351423	et	4	main
peipsimaal	doc_384045275264_item	2351427	et	4	main
karakatitsate	doc_384045275264_item	2351429	et	4	main
kus	doc_384045275264_item	2351431	et	3	main
hinnatakse	doc_384045275264_item	2351432	et	4	main
sõiduomadusi	doc_384045275264_item	2351437	et	4	main
ja	doc_384045275264_item	2351444	et	3	main
peipsi	doc_384045275264_item	2351448	et	4	main
paatidel	doc_384045275264_item	2351463	et	3	main
tagasiteel	doc_384045275264_item	2351469	et	3	main
osteti	doc_384045275264_item	2351470	et	3	main
ikka	doc_384045275264_item	2351480	et	4	main
ka	doc_384045275264_item	2351487	et	3	main
ebaõnn	doc_384045275264_item	2351491	et	3	main
käsikääs	doc_384045275264_item	2351493	et	4	main
päeval	doc_384045275264_item	2351522	et	3	main
järvele	doc_384045275264_item	2351524	et	4	main
ei	doc_384045275264_item	2351525	et	4	main
ka	doc_384045275264_item	2351538	et	3	main
vältida	doc_384045275264_item	2351540	et	3	main
inimesest	doc_384045275264_item	2351551	et	3	main
tagasi	doc_384045275264_item	2351555	et	3	main
kui	doc_384045275264_item	2351558	et	3	main
õnne	doc_384045275264_item	2351560	et	4	main
tule	doc_384045275264_item	2351562	et	4	main
kalale	doc_384045275264_item	2351563	et	3	main
tuleb	doc_384045275264_item	2351564	et	3	main
järvel	doc_384045275264_item	2351574	et	4	main
meenutada	doc_384045275264_item	2351577	et	3	main
jäävad	doc_384045275264_item	2351580	et	4	main
tühjaks	doc_384045275264_item	2351581	et	3	main
ei	doc_384045275264_item	2351582	et	4	main
tugeva	doc_384045275264_item	2351586	et	4	main
all	doc_384045275264_item	2351594	et	3	main
järvele	doc_384045275264_item	2351609	et	4	main
on	doc_384045275264_item	2351611	et	4	main
к	doc_384045275264_item	2351617	et	2	main
м	doc_384045275264_item	2351624	et	2	main
jt	doc_384045275264_item	2351627	et	4	main
ebasoodsam	doc_384045275264_item	2351629	et	4	main
tuul	doc_384045275264_item	2351630	et	3	main
on	doc_384045275264_item	2351631	et	4	main
lääs	doc_384045275264_item	2351632	et	3	main
see	doc_384045275264_item	2351634	et	3	main
imestama	doc_384045275264_item	2351640	et	3	main
et	doc_384045275264_item	2351641	et	3	main
ole	doc_384045275264_item	2351651	et	4	main
peremehest	doc_384045275264_item	2351660	et	4	main
ka	doc_384045275264_item	2351663	et	3	main
siis	doc_384045275264_item	2351665	et	3	main
selesse	doc_384045275264_item	2351667	et	4	main
väljamõeldisse	doc_384045275264_item	2351669	et	3	main
üldjuhul	doc_384045275264_item	2351674	et	3	main
populaarsemad	doc_384045275264_item	2351691	et	4	main
järves	doc_384045275264_item	2351700	et	4	main
ja	doc_384045275264_item	2351701	et	3	main
tiheda	doc_384045275264_item	2351702	et	3	main
jões	doc_384045275264_item	2351703	et	3	main
ammustest	doc_384045275264_item	2351249	et	4	main
kalapüük	doc_384045275264_item	2351251	et	3	main
külad	doc_384045275264_item	2351253	et	3	main
talve	doc_384045275264_item	2351283	et	4	main
oskusi	doc_384045275264_item	2351293	et	3	main
ja	doc_384045275264_item	2351296	et	3	main
salapärase	doc_384045275264_item	2351303	et	4	main
loomuga	doc_384045275264_item	2351304	et	3	main
aupaklikult	doc_384045275264_item	2351308	et	4	main
mereks	doc_384045275264_item	2351310	et	3	main
artellide	doc_384045275264_item	2351311	et	3	main
ja	doc_384045275264_item	2351312	et	3	main
nende	doc_384045275264_item	2351313	et	4	main
lülide	doc_384045275264_item	2351314	et	3	main
suurus	doc_384045275264_item	2351315	et	4	main
valik	doc_384045275264_item	2351320	et	3	main
kalaliigist	doc_384045275264_item	2351322	et	3	main
sellest	doc_384045275264_item	2351329	et	4	main
dementi	doc_384045275264_item	2351340	et	4	main
imestamapanevat	doc_384045275264_item	2351358	et	3	main
igast	doc_384045275264_item	2351362	et	3	main
suunda	doc_384045275264_item	2351377	et	4	main
vahemaad	doc_384045275264_item	2351380	et	4	main
jälaste	doc_384045275264_item	2351384	et	4	main
majakesi	doc_384045275264_item	2351387	et	4	main
ka	doc_384045275264_item	2351424	et	3	main
isetehtud	doc_384045275264_item	2351433	et	3	main
ja	doc_384045275264_item	2351436	et	3	main
murde	doc_384045275264_item	2351445	et	4	main
kui	doc_384045275264_item	2351447	et	3	main
kalamehed	doc_384045275264_item	2351454	et	3	main
tsaariajal	doc_384045275264_item	2351456	et	3	main
artellid	doc_384045275264_item	2351460	et	3	main
kalapüügiks	doc_384045275264_item	2351461	et	3	main
kala	doc_384045275264_item	2351466	et	4	main
peterburist	doc_384045275264_item	2351471	et	4	main
linnakaupu	doc_384045275264_item	2351474	et	3	main
aastaajast	doc_384045275264_item	2351476	et	4	main
seotud	doc_384045275264_item	2351482	et	4	main
ja	doc_384045275264_item	2351490	et	3	main
käivad	doc_384045275264_item	2351492	et	4	main
ehk	doc_384045275264_item	2351494	et	3	main
õigsust	doc_384045275264_item	2351536	et	3	main
kohtumist	doc_384045275264_item	2351544	et	4	main
eelistades	doc_384045275264_item	2351545	et	3	main
hiilida	doc_384045275264_item	2351547	et	3	main
või	doc_384045275264_item	2351552	et	4	main
riijuta	doc_384045275264_item	2351569	et	4	main
kalale	doc_384045275264_item	2351571	et	3	main
keelatud	doc_384045275264_item	2351576	et	4	main
jänest	doc_384045275264_item	2351578	et	3	main
paat	doc_384045275264_item	2351595	et	3	main
tuultelegi	doc_384045275264_item	2351610	et	3	main
omistatud	doc_384045275264_item	2351612	et	4	main
erilised	doc_384045275264_item	2351613	et	4	main
nimed	doc_384045275264_item	2351614	et	3	main
mehed	doc_384045275264_item	2351273	et	3	main
käisid	doc_384045275264_item	2351277	et	4	main
rikkam	doc_384045275264_item	2351280	et	4	main
täiustades	doc_384045275264_item	2351294	et	3	main
kohanedes	doc_384045275264_item	2351297	et	3	main
järve	doc_384045275264_item	2351302	et	4	main
nimetavad	doc_384045275264_item	2351309	et	4	main
marsruut	doc_384045275264_item	2351317	et	3	main
ja	doc_384045275264_item	2351318	et	3	main
kõigist	doc_384045275264_item	2351328	et	4	main
väga	doc_384045275264_item	2351335	et	3	main
jää	doc_384045275264_item	2351353	et	4	main
välju	doc_384045275264_item	2351354	et	4	main
ja	doc_384045275264_item	2351360	et	3	main
külast	doc_384045275264_item	2351363	et	4	main
sissetallatud	doc_384045275264_item	2351368	et	4	main
mitme	doc_384045275264_item	2351369	et	4	main
näitasid	doc_384045275264_item	2351376	et	4	main
püügiks	doc_384045275264_item	2351382	et	3	main
kevadeti	doc_384045275264_item	2351392	et	4	main
aga	doc_384045275264_item	2351393	et	3	main
müüdi	doc_384045275264_item	2351394	et	4	main
need	doc_384045275264_item	2351395	et	3	main
tarbetuse	doc_384045275264_item	2351396	et	4	main
hobuseid	doc_384045275264_item	2351391	et	4	main
tõttu	doc_384045275264_item	2351397	et	4	main
maaharijatele	doc_384045275264_item	2351398	et	4	main
mootorite	doc_384045275264_item	2351400	et	3	main
ajastu	doc_384045275264_item	2351401	et	4	main
saabumisel	doc_384045275264_item	2351402	et	4	main
maha	doc_384045275264_item	2351399	et	4	main
hakati	doc_384045275264_item	2351403	et	3	main
jääaluseks	doc_384045275264_item	2351404	et	4	main
kalapüügiks	doc_384045275264_item	2351405	et	3	main
ehitama	doc_384045275264_item	2351406	et	4	main
omapäraseid	doc_384045275264_item	2351407	et	4	main
sõidukeid	doc_384045275264_item	2351408	et	3	main
asetades	doc_384045275264_item	2351409	et	3	main
mootorrattaid	doc_384045275264_item	2351410	et	3	main
ja	doc_384045275264_item	2351411	et	3	main
autosid	doc_384045275264_item	2351412	et	3	main
suure	doc_384045275264_item	2351413	et	3	main
traktori	doc_384045275264_item	2351414	et	3	main
või	doc_384045275264_item	2351415	et	4	main
lennuki	doc_384045275264_item	2351416	et	3	main
ratastega	doc_384045275264_item	2351417	et	3	main
kanderaamistikule	doc_384045275264_item	2351418	et	4	main
neid	doc_384045275264_item	2351419	et	4	main
sõidukeid	doc_384045275264_item	2351420	et	3	main
korraldatakse	doc_384045275264_item	2351426	et	3	main
lõbusaid	doc_384045275264_item	2351428	et	3	main
sõidukite	doc_384045275264_item	2351434	et	3	main
disaini	doc_384045275264_item	2351435	et	4	main
ületada	doc_384045275264_item	2351440	et	3	main
suviti	doc_384045275264_item	2351446	et	3	main
oli	doc_384045275264_item	2351450	et	3	main
vaesem	doc_384045275264_item	2351452	et	4	main
käisid	doc_384045275264_item	2351457	et	4	main
kalurite	doc_384045275264_item	2351459	et	3	main
vajalikke	doc_384045275264_item	2351473	et	3	main
kilomeetripikkused	doc_384045275264_item	2351370	et	4	main
kilomeetrites	doc_384045275264_item	2351379	et	4	main
mitmepäevapikkuseks	doc_384045275264_item	2351381	et	4	main
paigutatud	doc_384045275264_item	2351386	et	4	main
sügiseti	doc_384045275264_item	2351389	et	3	main
osteti	doc_384045275264_item	2351390	et	3	main
tänapäeval	doc_384045275264_item	2351425	et	3	main
tuisanuid	doc_384045275264_item	2351441	et	4	main
lumehangeid	doc_384045275264_item	2351442	et	4	main
jääkuhjatisi	doc_384045275264_item	2351443	et	3	main
järv	doc_384045275264_item	2351449	et	3	main
ulgtöödel	doc_384045275264_item	2351455	et	4	main
laadogal	doc_384045275264_item	2351465	et	4	main
realiseeriti	doc_384045275264_item	2351467	et	3	main
kodumajanduses	doc_384045275264_item	2351472	et	3	main
elu	doc_384045275264_item	2351479	et	4	main
raskuste	doc_384045275264_item	2351483	et	4	main
ja	doc_384045275264_item	2351485	et	3	main
just	doc_384045275264_item	2351495	et	3	main
sellel	doc_384045275264_item	2351496	et	4	main
põhjusel	doc_384045275264_item	2351497	et	3	main
on	doc_384045275264_item	2351498	et	4	main
kalameeste	doc_384045275264_item	2351499	et	4	main
seas	doc_384045275264_item	2351500	et	4	main
väga	doc_384045275264_item	2351502	et	3	main
levinud	doc_384045275264_item	2351501	et	4	main
palju	doc_384045275264_item	2351503	et	4	main
erinevaid	doc_384045275264_item	2351504	et	4	main
enneid	doc_384045275264_item	2351505	et	4	main
ja	doc_384045275264_item	2351506	et	3	main
keelde	doc_384045275264_item	2351507	et	4	main
kõige	doc_384045275264_item	2351508	et	4	main
ohtlikumaks	doc_384045275264_item	2351509	et	4	main
kõuerohkeks	doc_384045275264_item	2351510	et	3	main
ja	doc_384045275264_item	2351511	et	3	main
vihmaseks	doc_384045275264_item	2351512	et	4	main
kalamehed	doc_384045275264_item	2351514	et	3	main
kaasani	doc_384045275264_item	2351515	et	3	main
peavad	doc_384045275264_item	2351513	et	4	main
jumalaema	doc_384045275264_item	2351516	et	4	main
päeva	doc_384045275264_item	2351517	et	4	main
parem	doc_384045275264_item	2351518	et	4	main
on	doc_384045275264_item	2351519	et	4	main
kui	doc_384045275264_item	2351520	et	3	main
varustatud	doc_384045275264_item	2351462	et	4	main
kaugel	doc_384045275264_item	2351464	et	4	main
kohapeal	doc_384045275264_item	2351468	et	3	main
on	doc_384045275264_item	2351477	et	4	main
kaluri	doc_384045275264_item	2351478	et	3	main
olnud	doc_384045275264_item	2351481	et	4	main
ohtude	doc_384045275264_item	2351484	et	3	main
riskidega	doc_384045275264_item	2351486	et	3	main
kaluri	doc_384045275264_item	2351488	et	3	main
sellel	doc_384045275264_item	2351521	et	4	main
kalur	doc_384045275264_item	2351523	et	3	main
hädad	doc_384045275264_item	2351530	et	3	main
ja	doc_384045275264_item	2351531	et	3	main
õnnetused	doc_384045275264_item	2351532	et	4	main
kinnitavad	doc_384045275264_item	2351533	et	4	main
selle	doc_384045275264_item	2351534	et	4	main
ebausu	doc_384045275264_item	2351535	et	3	main
nimetatud	doc_384045275264_item	2351542	et	4	main
mainega	doc_384045275264_item	2351550	et	4	main
nii	doc_384045275264_item	2351559	et	3	main
vaidluste	doc_384045275264_item	2351567	et	3	main
skandaalid	doc_384045275264_item	2351570	et	3	main
tohi	doc_384045275264_item	2351583	et	4	main
vilistada	doc_384045275264_item	2351584	et	3	main
välja	doc_384045275264_item	2351588	et	4	main
võib	doc_384045275264_item	2351596	et	3	main
keerata	doc_384045275264_item	2351598	et	4	main
ka	doc_384045275264_item	2351600	et	3	main
saadavad	doc_384045275264_item	2351605	et	4	main
тепл	doc_384045275264_item	2351618	et	2	main
вый	doc_384045275264_item	2351623	et	2	main
kõige	doc_384045275264_item	2351628	et	4	main
kui	doc_384045275264_item	2351644	et	3	main
ei	doc_384045275264_item	2351650	et	4	main
kuuldi	doc_384045275264_item	2351664	et	4	main
see	doc_384045275264_item	2351672	et	3	main
neid	doc_384045275264_item	2351682	et	4	main
suplemisest	doc_384045275264_item	2351685	et	4	main
bõlitški	doc_384045275264_item	2351694	et	2	main
näkineiud	doc_384045275264_item	2351696	et	4	main
ohtlikuks	doc_384045275264_item	2351715	et	3	main
on	doc_384045275264_item	2351716	et	4	main
sõltumata	doc_384045275264_item	2351475	et	4	main
õnn	doc_384045275264_item	2351489	et	3	main
lähe	doc_384045275264_item	2351526	et	4	main
paljud	doc_384045275264_item	2351527	et	3	main
lähiminevikus	doc_384045275264_item	2351528	et	3	main
juhtunud	doc_384045275264_item	2351529	et	4	main
püütakse	doc_384045275264_item	2351537	et	3	main
kõrvale	doc_384045275264_item	2351548	et	4	main
koju	doc_384045275264_item	2351554	et	3	main
nii	doc_384045275264_item	2351557	et	3	main
ei	doc_384045275264_item	2351561	et	4	main
meeldi	doc_384045275264_item	2351573	et	4	main
tohi	doc_384045275264_item	2351591	et	4	main
hoida	doc_384045275264_item	2351592	et	3	main
koorik	doc_384045275264_item	2351593	et	3	main
maagilisi	doc_384045275264_item	2351602	et	4	main
mis	doc_384045275264_item	2351604	et	4	main
kalameeste	doc_384045275264_item	2351606	et	4	main
artelli	doc_384045275264_item	2351607	et	4	main
väljaminekut	doc_384045275264_item	2351608	et	3	main
и	doc_384045275264_item	2351616	et	2	main
возгл	doc_384045275264_item	2351621	et	2	main
женец	doc_384045275264_item	2351626	et	2	main
potist	doc_384045275264_item	2351636	et	4	main
ära	doc_384045275264_item	2351638	et	4	main
arhiivimaterjalides	doc_384045275264_item	2351643	et	3	main
kirjapanekutes	doc_384045275264_item	2351649	et	3	main
ühtegi	doc_384045275264_item	2351652	et	4	main
ühestki	doc_384045275264_item	2351654	et	4	main
vetevaimust	doc_384045275264_item	2351655	et	4	main
järve	doc_384045275264_item	2351659	et	4	main
hoides	doc_384045275264_item	2351681	et	4	main
viib	doc_384045275264_item	2351688	et	3	main
lühijutukesed	doc_384045275264_item	2351693	et	4	main
mägede	doc_384045275264_item	2351708	et	3	main
kallaste	doc_384045275264_item	2351709	et	4	main
urgudes	doc_384045275264_item	2351710	et	3	main
kohtumist	doc_384045275264_item	2351711	et	4	main
näkineiuga	doc_384045275264_item	2351712	et	4	main
ka	doc_384045275264_item	2351719	et	3	main
folklooris	doc_384045275264_item	2351733	et	4	main
päriolu	doc_384045275264_item	2351738	et	4	main
seostatakse	doc_384045275264_item	2351739	et	3	main
mustas	doc_384045275264_item	2351740	et	4	main
meres	doc_384045275264_item	2351741	et	3	main
uppunud	doc_384045275264_item	2351742	et	4	main
sõdalastaga	doc_384045275264_item	2351744	et	4	main
jälitasid	doc_384045275264_item	2351746	et	4	main
juute	doc_384045275264_item	2351747	et	3	main
ajal	doc_384045275264_item	2351750	et	4	main
läänerannikul	doc_384045275264_item	2351754	et	3	main
levinud	doc_384045275264_item	2351755	et	4	main
pulmakommetes	doc_384045275264_item	2351757	et	4	main
pandi	doc_384045275264_item	2351793	et	4	main
võis	doc_384045275264_item	2351795	et	4	main
olla	doc_384045275264_item	2351796	et	3	main
kas	doc_384045275264_item	2351797	et	3	main
rätik	doc_384045275264_item	2351798	et	3	main
sõrmus	doc_384045275264_item	2351799	et	3	main
või	doc_384045275264_item	2351800	et	4	main
muu	doc_384045275264_item	2351802	et	4	main
valmistasid	doc_384045275264_item	2351811	et	4	main
pruudile	doc_384045275264_item	2351812	et	3	main
paberlilledest	doc_384045275264_item	2351813	et	4	main
pruudile	doc_384045275264_item	2351822	et	3	main
neiu	doc_384045275264_item	2351862	et	4	main
talitusi	doc_384045275264_item	2351869	et	4	main
paljud	doc_384045275264_item	2351871	et	3	main
sarnanevad	doc_384045275264_item	2351873	et	4	main
kubermangu	doc_384045275264_item	2351877	et	4	main
175180	doc_384045275264_item	2351890	et	2	main
372	doc_384045275264_item	2351891	et	2	main
peipsi	doc_384045275264_item	2351892	et	4	main
rannakülades	doc_384045275264_item	2351893	et	3	main
ülistuslaulud	doc_384045275264_item	2351897	et	3	main
esitajate	doc_384045275264_item	2351902	et	4	main
seletab	doc_384045275264_item	2351916	et	3	main
aga	doc_384045275264_item	2351924	et	3	main
kes	doc_384045275264_item	2351925	et	4	main
kas	doc_384045275264_item	2351933	et	3	main
kas	doc_384045275264_item	2351940	et	3	main
tänapäeval	doc_384045275264_item	2351539	et	3	main
nii	doc_384045275264_item	2351541	et	3	main
halba	doc_384045275264_item	2351543	et	4	main
kas	doc_384045275264_item	2351546	et	3	main
halva	doc_384045275264_item	2351549	et	4	main
isegi	doc_384045275264_item	2351553	et	4	main
minna	doc_384045275264_item	2351556	et	3	main
minna	doc_384045275264_item	2351565	et	3	main
rahulikult	doc_384045275264_item	2351566	et	4	main
ja	doc_384045275264_item	2351568	et	3	main
ei	doc_384045275264_item	2351572	et	4	main
on	doc_384045275264_item	2351575	et	4	main
võrgud	doc_384045275264_item	2351579	et	3	main
kutsud	doc_384045275264_item	2351585	et	4	main
tuule	doc_384045275264_item	2351587	et	3	main
leiba	doc_384045275264_item	2351589	et	4	main
ei	doc_384045275264_item	2351590	et	4	main
ümber	doc_384045275264_item	2351597	et	3	main
on	doc_384045275264_item	2351599	et	4	main
erilisi	doc_384045275264_item	2351601	et	4	main
toiminguid	doc_384045275264_item	2351603	et	3	main
мокр	doc_384045275264_item	2351615	et	2	main
я	doc_384045275264_item	2351619	et	2	main
к	doc_384045275264_item	2351620	et	2	main
и	doc_384045275264_item	2351622	et	2	main
запад	doc_384045275264_item	2351633	et	2	main
kala	doc_384045275264_item	2351637	et	4	main
paneb	doc_384045275264_item	2351639	et	3	main
nii	doc_384045275264_item	2351642	et	3	main
lugu	doc_384045275264_item	2351653	et	4	main
või	doc_384045275264_item	2351656	et	4	main
mingist	doc_384045275264_item	2351657	et	4	main
vetevaimust	doc_384045275264_item	2351662	et	4	main
suhtuti	doc_384045275264_item	2351666	et	4	main
kui	doc_384045275264_item	2351668	et	3	main
muinasjutud	doc_384045275264_item	2351670	et	3	main
kõik	doc_384045275264_item	2351673	et	4	main
vetevaimuga	doc_384045275264_item	2351675	et	3	main
emad	doc_384045275264_item	2351677	et	3	main
lapsi	doc_384045275264_item	2351680	et	4	main
liiga	doc_384045275264_item	2351683	et	4	main
on	doc_384045275264_item	2351692	et	4	main
olevat	doc_384045275264_item	2351697	et	4	main
peipsi	doc_384045275264_item	2351699	et	4	main
üks	doc_384045275264_item	2351720	et	3	main
apokriiva	doc_384045275264_item	2351727	et	4	main
vaarao	doc_384045275264_item	2351743	et	4	main
kes	doc_384045275264_item	2351745	et	4	main
474	doc_384045275264_item	2351752	et	2	main
lauludes	doc_384045275264_item	2351758	et	3	main
õigeusuliste	doc_384045275264_item	2351782	et	4	main
küla	doc_384045275264_item	2351784	et	4	main
ese	doc_384045275264_item	2351804	et	3	main
alles	doc_384045275264_item	2351807	et	3	main
pulmi	doc_384045275264_item	2351809	et	4	main
saun	doc_384045275264_item	2351824	et	3	main
е	doc_384045275264_item	2351625	et	2	main
viib	doc_384045275264_item	2351635	et	3	main
ka	doc_384045275264_item	2351645	et	3	main
2006	doc_384045275264_item	2351646	et	2	main
aasta	doc_384045275264_item	2351647	et	4	main
ekspeditsiooni	doc_384045275264_item	2351648	et	4	main
muust	doc_384045275264_item	2351658	et	4	main
kui	doc_384045275264_item	2351661	et	3	main
on	doc_384045275264_item	2351671	et	4	main
hirmutasid	doc_384045275264_item	2351676	et	4	main
oma	doc_384045275264_item	2351678	et	4	main
pahuraid	doc_384045275264_item	2351679	et	4	main
varasest	doc_384045275264_item	2351684	et	4	main
järves	doc_384045275264_item	2351686	et	4	main
vetevaim	doc_384045275264_item	2351687	et	3	main
ära	doc_384045275264_item	2351689	et	4	main
palju	doc_384045275264_item	2351690	et	4	main
näkineidudest	doc_384045275264_item	2351695	et	3	main
elutsevad	doc_384045275264_item	2351698	et	4	main
peetakse	doc_384045275264_item	2351713	et	3	main
väga	doc_384045275264_item	2351714	et	3	main
pandud	doc_384045275264_item	2351718	et	4	main
vaaraost	doc_384045275264_item	2351722	et	4	main
tõug	doc_384045275264_item	2351724	et	3	main
neid	doc_384045275264_item	2351726	et	4	main
süžeedest	doc_384045275264_item	2351728	et	2	main
pärinevaid	doc_384045275264_item	2351729	et	4	main
olendeid	doc_384045275264_item	2351731	et	3	main
esineb	doc_384045275264_item	2351734	et	3	main
eguptusest	doc_384045275264_item	2351748	et	4	main
põgenemise	doc_384045275264_item	2351749	et	4	main
vene	doc_384045275264_item	2351756	et	4	main
materjali	doc_384045275264_item	2351776	et	4	main
palju	doc_384045275264_item	2351777	et	4	main
sarnaseid	doc_384045275264_item	2351778	et	4	main
elemente	doc_384045275264_item	2351779	et	3	main
leidub	doc_384045275264_item	2351780	et	3	main
lubadust	doc_384045275264_item	2351789	et	4	main
see	doc_384045275264_item	2351794	et	3	main
tagastati	doc_384045275264_item	2351806	et	4	main
peale	doc_384045275264_item	2351808	et	4	main
sõbrannad	doc_384045275264_item	2351810	et	3	main
kimbu	doc_384045275264_item	2351814	et	3	main
ja	doc_384045275264_item	2351817	et	3	main
laulsid	doc_384045275264_item	2351834	et	4	main
парна	doc_384045275264_item	2351836	et	2	main
баенка	doc_384045275264_item	2351837	et	2	main
varsti	doc_384045275264_item	2351839	et	3	main
pärast	doc_384045275264_item	2351840	et	4	main
pulmi	doc_384045275264_item	2351841	et	4	main
sõitis	doc_384045275264_item	2351842	et	3	main
ajal	doc_384045275264_item	2351850	et	4	main
pidi	doc_384045275264_item	2351851	et	4	main
väimes	doc_384045275264_item	2351852	et	4	main
sümbolite	doc_384045275264_item	2351853	et	3	main
ausa	doc_384045275264_item	2351861	et	3	main
pihkva	doc_384045275264_item	2351876	et	4	main
нткп	doc_384045275264_item	2351888	et	2	main
populaarsed	doc_384045275264_item	2351896	et	3	main
laulud	doc_384045275264_item	2351900	et	3	main
jää	doc_384045275264_item	2351907	et	4	main
kõigile	doc_384045275264_item	2351909	et	4	main
teistele	doc_384045275264_item	2351910	et	4	main
pulmalauludele	doc_384045275264_item	2351911	et	3	main
kokku	doc_384045275264_item	2351912	et	3	main
ülistuslaulude	doc_384045275264_item	2351913	et	3	main
et	doc_384045275264_item	2351918	et	3	main
järjest	doc_384045275264_item	2351920	et	4	main
pulmapidulisi	doc_384045275264_item	2351922	et	4	main
neid	doc_384045275264_item	2351923	et	4	main
erilise	doc_384045275264_item	2351929	et	4	main
korda	doc_384045275264_item	2351936	et	4	main
vaid	doc_384045275264_item	2351938	et	3	main
süüdistuslaule	doc_384045275264_item	2351946	et	4	main
selles	doc_384045275264_item	2351955	et	4	main
regioonis	doc_384045275264_item	2351956	et	3	main
pulmakommete	doc_384045275264_item	2351961	et	4	main
eripäraks	doc_384045275264_item	2351962	et	3	main
rohkus	doc_384045275264_item	2351966	et	4	main
tulema	doc_384045275264_item	2351969	et	4	main
viinapudeliga	doc_384045275264_item	2351970	et	3	main
ja	doc_384045275264_item	2351971	et	3	main
alustama	doc_384045275264_item	2351972	et	3	main
ootas	doc_384045275264_item	2351982	et	3	main
külarahvas	doc_384045275264_item	2351983	et	4	main
rahaga	doc_384045275264_item	2352022	et	4	main
pidi	doc_384045275264_item	2352023	et	4	main
ka	doc_384045275264_item	2351704	et	3	main
lainete	doc_384045275264_item	2351705	et	3	main
tekitatud	doc_384045275264_item	2351706	et	4	main
punaste	doc_384045275264_item	2351707	et	4	main
kirja	doc_384045275264_item	2351717	et	4	main
legend	doc_384045275264_item	2351721	et	3	main
vaarao	doc_384045275264_item	2351723	et	4	main
mütoloogilisi	doc_384045275264_item	2351730	et	4	main
harva	doc_384045275264_item	2351736	et	4	main
nende	doc_384045275264_item	2351737	et	4	main
см	doc_384045275264_item	2351751	et	2	main
sõbramehe	doc_384045275264_item	2351759	et	3	main
ka	doc_384045275264_item	2351781	et	3	main
nina	doc_384045275264_item	2351783	et	4	main
elanike	doc_384045275264_item	2351785	et	3	main
kinnitades	doc_384045275264_item	2351787	et	3	main
pruut	doc_384045275264_item	2351791	et	3	main
mingi	doc_384045275264_item	2351801	et	4	main
hinnaline	doc_384045275264_item	2351803	et	4	main
lilledega	doc_384045275264_item	2351816	et	4	main
lintidega	doc_384045275264_item	2351818	et	3	main
pisikese	doc_384045275264_item	2351820	et	4	main
kuuse	doc_384045275264_item	2351821	et	4	main
kütmise	doc_384045275264_item	2351825	et	4	main
käigus	doc_384045275264_item	2351826	et	4	main
peigmees	doc_384045275264_item	2351827	et	4	main
valas	doc_384045275264_item	2351828	et	3	main
saunakividele	doc_384045275264_item	2351829	et	3	main
ja	doc_384045275264_item	2351831	et	3	main
vanemate	doc_384045275264_item	2351845	et	4	main
sööma	doc_384045275264_item	2351848	et	4	main
abil	doc_384045275264_item	2351854	et	4	main
kas	doc_384045275264_item	2351857	et	3	main
võttis	doc_384045275264_item	2351859	et	3	main
laulud	doc_384045275264_item	2351872	et	3	main
peipsi	doc_384045275264_item	2351874	et	4	main
põhja	doc_384045275264_item	2351878	et	4	main
kommetega	doc_384045275264_item	2351881	et	4	main
siiski	doc_384045275264_item	2351883	et	4	main
ääretult	doc_384045275264_item	2351895	et	4	main
ülistuslaulude	doc_384045275264_item	2351904	et	3	main
ei	doc_384045275264_item	2351906	et	4	main
alla	doc_384045275264_item	2351908	et	3	main
rohkust	doc_384045275264_item	2351915	et	4	main
ülistati	doc_384045275264_item	2351919	et	3	main
nõus	doc_384045275264_item	2351927	et	4	main
austuse	doc_384045275264_item	2351930	et	4	main
või	doc_384045275264_item	2351934	et	4	main
kodus	doc_384045275264_item	2351943	et	4	main
орильных	doc_384045275264_item	2351948	et	2	main
peigmees	doc_384045275264_item	2351950	et	4	main
naerdi	doc_384045275264_item	2351954	et	3	main
avastatud	doc_384045275264_item	2351959	et	4	main
kohalike	doc_384045275264_item	2351960	et	4	main
pidi	doc_384045275264_item	2351968	et	4	main
peigmehest	doc_384045275264_item	2351978	et	4	main
tee	doc_384045275264_item	2351986	et	4	main
sammul	doc_384045275264_item	2352027	et	4	main
välja	doc_384045275264_item	2352029	et	4	main
pruudi	doc_384045275264_item	2352031	et	3	main
laua	doc_384045275264_item	2352033	et	3	main
eest	doc_384045275264_item	2352041	et	4	main
juhuseid	doc_384045275264_item	2352055	et	3	main
vastu	doc_384045275264_item	2352067	et	3	main
seda	doc_384045275264_item	2352069	et	3	main
siiski	doc_384045275264_item	2352073	et	4	main
see	doc_384045275264_item	2352074	et	3	main
levikut	doc_384045275264_item	2352080	et	3	main
leedus	doc_384045275264_item	2352082	et	4	main
kunagi	doc_384045275264_item	2352092	et	3	main
lääneranniku	doc_384045275264_item	2352097	et	3	main
1930	doc_384045275264_item	2352107	et	2	main
aasta	doc_384045275264_item	2352108	et	4	main
kooliõpilastele	doc_384045275264_item	2352110	et	4	main
inimkalast	doc_384045275264_item	2351725	et	4	main
ida-slaavlaste	doc_384045275264_item	2351732	et	3	main
väga	doc_384045275264_item	2351735	et	3	main
peipsi	doc_384045275264_item	2351753	et	4	main
lausumistes	doc_384045275264_item	2351760	et	4	main
ja	doc_384045275264_item	2351761	et	3	main
maagilistes	doc_384045275264_item	2351762	et	4	main
toimingutes	doc_384045275264_item	2351763	et	3	main
on	doc_384045275264_item	2351764	et	4	main
palju	doc_384045275264_item	2351765	et	4	main
ühist	doc_384045275264_item	2351766	et	3	main
selles	doc_384045275264_item	2351767	et	4	main
võib	doc_384045275264_item	2351768	et	3	main
veenduda	doc_384045275264_item	2351769	et	3	main
kõrvutades	doc_384045275264_item	2351770	et	3	main
erinevates	doc_384045275264_item	2351771	et	4	main
vanausuliste	doc_384045275264_item	2351772	et	4	main
külades	doc_384045275264_item	2351773	et	3	main
kirja	doc_384045275264_item	2351774	et	4	main
pandud	doc_384045275264_item	2351775	et	4	main
pulmakommetes	doc_384045275264_item	2351786	et	4	main
oma	doc_384045275264_item	2351788	et	4	main
andis	doc_384045275264_item	2351790	et	3	main
peighelele	doc_384045275264_item	2351792	et	4	main
mille	doc_384045275264_item	2351805	et	3	main
või	doc_384045275264_item	2351815	et	4	main
ehitud	doc_384045275264_item	2351819	et	4	main
kööti	doc_384045275264_item	2351823	et	4	main
õlut	doc_384045275264_item	2351830	et	3	main
noored	doc_384045275264_item	2351832	et	3	main
noorpaar	doc_384045275264_item	2351843	et	4	main
märku	doc_384045275264_item	2351855	et	4	main
süüdi	doc_384045275264_item	2351864	et	4	main
pulmakomete	doc_384045275264_item	2351866	et	3	main
rida	doc_384045275264_item	2351868	et	4	main
ja	doc_384045275264_item	2351870	et	3	main
idarannikul	doc_384045275264_item	2351875	et	3	main
levinud	doc_384045275264_item	2351880	et	4	main
kuid	doc_384045275264_item	2351882	et	4	main
ei	doc_384045275264_item	2351885	et	4	main
kattu	doc_384045275264_item	2351886	et	4	main
см	doc_384045275264_item	2351887	et	2	main
i	doc_384045275264_item	2351889	et	4	main
on	doc_384045275264_item	2351894	et	4	main
опевальные	doc_384045275264_item	2351898	et	2	main
mõnede	doc_384045275264_item	2351901	et	3	main
arvukus	doc_384045275264_item	2351905	et	4	main
süžeede	doc_384045275264_item	2351914	et	2	main
kõiki	doc_384045275264_item	2351921	et	4	main
maksma	doc_384045275264_item	2351928	et	3	main
eest	doc_384045275264_item	2351931	et	4	main
ülistati	doc_384045275264_item	2351932	et	3	main
kaks-kolm	doc_384045275264_item	2351935	et	3	main
küsimusele	doc_384045275264_item	2351939	et	4	main
on	doc_384045275264_item	2351941	et	4	main
juba	doc_384045275264_item	2351942	et	3	main
к	doc_384045275264_item	2351947	et	2	main
kus	doc_384045275264_item	2351949	et	3	main
on	doc_384045275264_item	2351963	et	4	main
pruudist	doc_384045275264_item	2351975	et	3	main
ja	doc_384045275264_item	2351976	et	3	main
piiras	doc_384045275264_item	2351985	et	4	main
ei	doc_384045275264_item	2351988	et	4	main
lasknud	doc_384045275264_item	2351989	et	4	main
taga	doc_384045275264_item	2352034	et	4	main
eest	doc_384045275264_item	2352043	et	4	main
majas	doc_384045275264_item	2352050	et	3	main
kui	doc_384045275264_item	2352060	et	3	main
pruudi	doc_384045275264_item	2352061	et	3	main
olid	doc_384045275264_item	2352063	et	4	main
vargsi	doc_384045275264_item	2352071	et	3	main
suurt	doc_384045275264_item	2352079	et	3	main
aastal	doc_384045275264_item	2352084	et	3	main
isegi	doc_384045275264_item	2352086	et	4	main
naised	doc_384045275264_item	2352088	et	3	main
pulmadest	doc_384045275264_item	2352095	et	3	main
leia	doc_384045275264_item	2352106	et	4	main
ja	doc_384045275264_item	2352122	et	3	main
küsimusele	doc_384045275264_item	2352125	et	4	main
ligi	doc_384045275264_item	2352127	et	3	main
vastuse	doc_384045275264_item	2352129	et	3	main
oskas	doc_384045275264_item	2352140	et	3	main
teradega	doc_384045275264_item	2352147	et	3	main
meenutati	doc_384045275264_item	2352148	et	3	main
naine	doc_384045275264_item	2352156	et	3	main
teistes	doc_384045275264_item	2352159	et	4	main
kogujad	doc_384045275264_item	2352162	et	4	main
midagi	doc_384045275264_item	2352170	et	4	main
mäletatakse	doc_384045275264_item	2352179	et	3	main
lauldakse	doc_384045275264_item	2352181	et	3	main
on	doc_384045275264_item	2352222	et	4	main
ja	doc_384045275264_item	2352226	et	3	main
kolmanda	doc_384045275264_item	2352229	et	3	main
kes	doc_384045275264_item	2352237	et	4	main
õhtudel	doc_384045275264_item	2352240	et	4	main
teatud	doc_384045275264_item	2352248	et	4	main
haritustase	doc_384045275264_item	2352254	et	4	main
seas	doc_384045275264_item	2352256	et	4	main
õppisid	doc_384045275264_item	2352258	et	4	main
kohalikes	doc_384045275264_item	2352259	et	3	main
koolides	doc_384045275264_item	2352260	et	3	main
raamatute	doc_384045275264_item	2352268	et	3	main
neiud	doc_384045275264_item	2351833	et	4	main
laulu	doc_384045275264_item	2351835	et	4	main
растопляется	doc_384045275264_item	2351838	et	2	main
naise	doc_384045275264_item	2351844	et	3	main
juurde	doc_384045275264_item	2351846	et	4	main
praemuna	doc_384045275264_item	2351847	et	4	main
kostitamise	doc_384045275264_item	2351849	et	4	main
andma	doc_384045275264_item	2351856	et	3	main
ta	doc_384045275264_item	2351858	et	4	main
naiseks	doc_384045275264_item	2351860	et	3	main
või	doc_384045275264_item	2351863	et	4	main
oleva	doc_384045275264_item	2351865	et	4	main
struktuur	doc_384045275264_item	2351867	et	3	main
osas	doc_384045275264_item	2351879	et	4	main
need	doc_384045275264_item	2351884	et	3	main
величальные	doc_384045275264_item	2351899	et	2	main
repertuaaris	doc_384045275264_item	2351903	et	3	main
asjaolu	doc_384045275264_item	2351917	et	4	main
olid	doc_384045275264_item	2351926	et	4	main
piisas	doc_384045275264_item	2351937	et	4	main
vastata	doc_384045275264_item	2351944	et	4	main
eitavalt	doc_384045275264_item	2351945	et	4	main
isamees	doc_384045275264_item	2351952	et	4	main
ei	doc_384045275264_item	2351957	et	4	main
ostu-müügi	doc_384045275264_item	2351964	et	4	main
motiivide	doc_384045275264_item	2351965	et	3	main
abielu	doc_384045275264_item	2351980	et	4	main
ja	doc_384045275264_item	2351987	et	3	main
pulmalisi	doc_384045275264_item	2351990	et	4	main
läbi	doc_384045275264_item	2351991	et	4	main
enne	doc_384045275264_item	2351992	et	4	main
kui	doc_384045275264_item	2351993	et	3	main
noor	doc_384045275264_item	2351994	et	3	main
abielumees	doc_384045275264_item	2351995	et	4	main
ostis	doc_384045275264_item	2351996	et	4	main
end	doc_384045275264_item	2351997	et	4	main
vabaks	doc_384045275264_item	2351998	et	3	main
vabaks	doc_384045275264_item	2351999	et	3	main
vorm	doc_384045275264_item	2352001	et	3	main
ostmise	doc_384045275264_item	2352000	et	4	main
on	doc_384045275264_item	2352002	et	4	main
üpris	doc_384045275264_item	2352003	et	3	main
omapärane	doc_384045275264_item	2352004	et	4	main
lauale	doc_384045275264_item	2352005	et	4	main
pandi	doc_384045275264_item	2352006	et	4	main
tühi	doc_384045275264_item	2352007	et	3	main
pudel	doc_384045275264_item	2352008	et	3	main
mille	doc_384045275264_item	2352009	et	3	main
peigmees	doc_384045275264_item	2352010	et	4	main
pidi	doc_384045275264_item	2352011	et	4	main
väljavahetama	doc_384045275264_item	2352012	et	4	main
täis	doc_384045275264_item	2352013	et	4	main
pudeliga	doc_384045275264_item	2352014	et	3	main
mitte	doc_384045275264_item	2352016	et	3	main
mõistagi	doc_384045275264_item	2352015	et	4	main
mineraalveega	doc_384045275264_item	2352017	et	3	main
peigmees	doc_384045275264_item	2352018	et	4	main
või	doc_384045275264_item	2352019	et	4	main
isamees	doc_384045275264_item	2352020	et	4	main
või	doc_384045275264_item	2351951	et	4	main
välja	doc_384045275264_item	2351953	et	4	main
ole	doc_384045275264_item	2351958	et	4	main
isamees	doc_384045275264_item	2351967	et	4	main
juttu	doc_384045275264_item	2351973	et	4	main
kaubast	doc_384045275264_item	2351974	et	4	main
kaupmehest	doc_384045275264_item	2351977	et	4	main
pärast	doc_384045275264_item	2351979	et	4	main
jumalateenistust	doc_384045275264_item	2351981	et	3	main
noorpaari	doc_384045275264_item	2351984	et	4	main
peigmehe	doc_384045275264_item	2352021	et	3	main
kergitama	doc_384045275264_item	2352025	et	3	main
igal	doc_384045275264_item	2352026	et	3	main
jm	doc_384045275264_item	2352035	et	4	main
pidi	doc_384045275264_item	2352036	et	4	main
ka	doc_384045275264_item	2352037	et	3	main
maksma	doc_384045275264_item	2352038	et	3	main
lahtipunutud	doc_384045275264_item	2352039	et	4	main
patside	doc_384045275264_item	2352040	et	3	main
ülistuslaulude	doc_384045275264_item	2352042	et	3	main
enne	doc_384045275264_item	2352051	et	4	main
teist	doc_384045275264_item	2352052	et	4	main
esines	doc_384045275264_item	2352054	et	3	main
varastasid	doc_384045275264_item	2352058	et	4	main
nimetati	doc_384045275264_item	2352068	et	4	main
ei	doc_384045275264_item	2352076	et	4	main
nii	doc_384045275264_item	2352078	et	3	main
kuulnud	doc_384045275264_item	2352093	et	4	main
kinnitavad	doc_384045275264_item	2352099	et	4	main
mida	doc_384045275264_item	2352101	et	4	main
ei	doc_384045275264_item	2352102	et	4	main
otsi	doc_384045275264_item	2352103	et	4	main
paistab	doc_384045275264_item	2352123	et	3	main
aasta	doc_384045275264_item	2352132	et	4	main
käigus	doc_384045275264_item	2352134	et	4	main
peagi	doc_384045275264_item	2352135	et	4	main
igaüks	doc_384045275264_item	2352136	et	3	main
vestluskaaslane	doc_384045275264_item	2352137	et	3	main
väga	doc_384045275264_item	2352138	et	3	main
talvistepühad	doc_384045275264_item	2352142	et	4	main
ka	doc_384045275264_item	2352149	et	3	main
kelde	doc_384045275264_item	2352151	et	4	main
tingimatta	doc_384045275264_item	2352154	et	4	main
kus	doc_384045275264_item	2352161	et	3	main
avastatud	doc_384045275264_item	2352171	et	4	main
värsse	doc_384045275264_item	2352174	et	3	main
sellele	doc_384045275264_item	2352176	et	4	main
ja	doc_384045275264_item	2352180	et	3	main
midagi	doc_384045275264_item	2352190	et	4	main
peipsi	doc_384045275264_item	2352193	et	4	main
neid	doc_384045275264_item	2352197	et	4	main
ajal	doc_384045275264_item	2352203	et	4	main
kogujad	doc_384045275264_item	2352204	et	4	main
olnud	doc_384045275264_item	2352208	et	4	main
ostma	doc_384045275264_item	2352028	et	3	main
oma	doc_384045275264_item	2352030	et	4	main
koha	doc_384045275264_item	2352032	et	4	main
trepiastme	doc_384045275264_item	2352045	et	3	main
oma	doc_384045275264_item	2352047	et	4	main
pruute	doc_384045275264_item	2352059	et	3	main
vanemad	doc_384045275264_item	2352062	et	4	main
mingil	doc_384045275264_item	2352064	et	4	main
põhjusel	doc_384045275264_item	2352065	et	3	main
abielu	doc_384045275264_item	2352066	et	4	main
kuid	doc_384045275264_item	2352072	et	4	main
kui	doc_384045275264_item	2352081	et	3	main
peipsimaal	doc_384045275264_item	2352089	et	4	main
vargsi	doc_384045275264_item	2352094	et	3	main
folkloorimaterjalid	doc_384045275264_item	2352098	et	3	main
rahvatarkust	doc_384045275264_item	2352100	et	4	main
ei	doc_384045275264_item	2352105	et	4	main
mustvee	doc_384045275264_item	2352109	et	3	main
koostatud	doc_384045275264_item	2352111	et	4	main
küsitlusleht	doc_384045275264_item	2352112	et	3	main
sisaldas	doc_384045275264_item	2352113	et	3	main
küsimust	doc_384045275264_item	2352114	et	4	main
mis	doc_384045275264_item	2352115	et	4	main
juhtub	doc_384045275264_item	2352116	et	3	main
siis	doc_384045275264_item	2352117	et	3	main
kui	doc_384045275264_item	2352118	et	3	main
üheaegselt	doc_384045275264_item	2352119	et	4	main
sajab	doc_384045275264_item	2352120	et	3	main
vihm	doc_384045275264_item	2352121	et	3	main
arianti	doc_384045275264_item	2352130	et	4	main
ekspeditsiooni	doc_384045275264_item	2352133	et	4	main
mida	doc_384045275264_item	2352152	et	4	main
ajal	doc_384045275264_item	2352158	et	4	main
küsimusi	doc_384045275264_item	2352166	et	4	main
ka	doc_384045275264_item	2352169	et	3	main
neid	doc_384045275264_item	2352178	et	4	main
vaid	doc_384045275264_item	2352187	et	3	main
nähtavasti	doc_384045275264_item	2352189	et	3	main
juhtus	doc_384045275264_item	2352192	et	3	main
läänerannikul	doc_384045275264_item	2352194	et	3	main
lihtsalt	doc_384045275264_item	2352198	et	4	main
ei	doc_384045275264_item	2352199	et	4	main
pandud	doc_384045275264_item	2352200	et	4	main
kelle	doc_384045275264_item	2352205	et	4	main
palju	doc_384045275264_item	2352224	et	4	main
peipsimaa	doc_384045275264_item	2352232	et	4	main
vanausulised	doc_384045275264_item	2352233	et	4	main
oma	doc_384045275264_item	2352235	et	4	main
meelt	doc_384045275264_item	2352242	et	4	main
muinasjutte	doc_384045275264_item	2352244	et	3	main
peagi	doc_384045275264_item	2352265	et	4	main
mainida	doc_384045275264_item	2352277	et	3	main
mõju	doc_384045275264_item	2352280	et	4	main
millest	doc_384045275264_item	2352281	et	3	main
esmajoones	doc_384045275264_item	2352282	et	3	main
kannatavad	doc_384045275264_item	2352283	et	4	main
just	doc_384045275264_item	2352284	et	3	main
muinasjutud	doc_384045275264_item	2352285	et	3	main
traditsiooni	doc_384045275264_item	2352295	et	4	main
eripärast	doc_384045275264_item	2352296	et	4	main
ületa	doc_384045275264_item	2352300	et	4	main
samuti	doc_384045275264_item	2352313	et	3	main
papist-armukesest	doc_384045275264_item	2352317	et	4	main
võistlejatest	doc_384045275264_item	2352319	et	4	main
kujutavad	doc_384045275264_item	2352323	et	4	main
ja	doc_384045275264_item	2352326	et	3	main
kohaliku	doc_384045275264_item	2352335	et	3	main
kohalik	doc_384045275264_item	2352338	et	3	main
väljendub	doc_384045275264_item	2352340	et	3	main
olinüleskirjutatud	doc_384045275264_item	2352349	et	4	main
vanausuliste	doc_384045275264_item	2352357	et	4	main
kukrut	doc_384045275264_item	2352024	et	3	main
iga	doc_384045275264_item	2352044	et	4	main
eest	doc_384045275264_item	2352046	et	4	main
tulevase	doc_384045275264_item	2352048	et	4	main
äia	doc_384045275264_item	2352049	et	4	main
maailmasõda	doc_384045275264_item	2352053	et	4	main
kus	doc_384045275264_item	2352056	et	3	main
noormehed	doc_384045275264_item	2352057	et	3	main
pulmad	doc_384045275264_item	2352070	et	3	main
komme	doc_384045275264_item	2352075	et	4	main
saanud	doc_384045275264_item	2352077	et	4	main
2006	doc_384045275264_item	2352083	et	2	main
paljud	doc_384045275264_item	2352085	et	3	main
eakad	doc_384045275264_item	2352087	et	3	main
ei	doc_384045275264_item	2352090	et	4	main
olnud	doc_384045275264_item	2352091	et	4	main
peipsi	doc_384045275264_item	2352096	et	4	main
seda	doc_384045275264_item	2352104	et	3	main
päike	doc_384045275264_item	2352124	et	3	main
2006	doc_384045275264_item	2352131	et	2	main
erinevaid	doc_384045275264_item	2352150	et	4	main
tuli	doc_384045275264_item	2352153	et	4	main
täita	doc_384045275264_item	2352155	et	4	main
raseduse	doc_384045275264_item	2352157	et	4	main
ei	doc_384045275264_item	2352163	et	4	main
esitanud	doc_384045275264_item	2352164	et	4	main
selliseid	doc_384045275264_item	2352165	et	4	main
olnud	doc_384045275264_item	2352168	et	4	main
ka	doc_384045275264_item	2352172	et	3	main
tänapäeval	doc_384045275264_item	2352183	et	3	main
arhiivimaterjalides	doc_384045275264_item	2352185	et	3	main
selletaolist	doc_384045275264_item	2352191	et	3	main
ka	doc_384045275264_item	2352195	et	3	main
kirja	doc_384045275264_item	2352201	et	4	main
ei	doc_384045275264_item	2352207	et	4	main
lihtsam	doc_384045275264_item	2352225	et	4	main
siiski	doc_384045275264_item	2352227	et	4	main
aastatuhande	doc_384045275264_item	2352230	et	4	main
algusel	doc_384045275264_item	2352231	et	4	main
vanaemasi	doc_384045275264_item	2352236	et	4	main
lahutasid	doc_384045275264_item	2352241	et	4	main
pajatades	doc_384045275264_item	2352243	et	3	main
leviku	doc_384045275264_item	2352246	et	3	main
suhteliselt	doc_384045275264_item	2352252	et	4	main
vanausuliste	doc_384045275264_item	2352255	et	4	main
nad	doc_384045275264_item	2352257	et	3	main
6-9	doc_384045275264_item	2352261	et	2	main
haridus	doc_384045275264_item	2352263	et	3	main
au	doc_384045275264_item	2352272	et	4	main
sees	doc_384045275264_item	2352273	et	4	main
tuleb	doc_384045275264_item	2352276	et	3	main
linnakultuuri	doc_384045275264_item	2352279	et	4	main
raske	doc_384045275264_item	2352290	et	4	main
rääkida	doc_384045275264_item	2352291	et	3	main
kindlat	doc_384045275264_item	2352293	et	3	main
ei	doc_384045275264_item	2352299	et	4	main
olustiku	doc_384045275264_item	2352311	et	3	main
laisast	doc_384045275264_item	2352315	et	3	main
leidlikuses	doc_384045275264_item	2352318	et	4	main
ekspeditsiooni	doc_384045275264_item	2352347	et	4	main
palju	doc_384045275264_item	2352351	et	4	main
venemaalt	doc_384045275264_item	2352359	et	3	main
levinud	doc_384045275264_item	2352375	et	4	main
pärimusjutt	doc_384045275264_item	2352376	et	4	main
miks	doc_384045275264_item	2352380	et	4	main
aga	doc_384045275264_item	2352386	et	3	main
oma	doc_384045275264_item	2352390	et	4	main
vene	doc_384045275264_item	2352430	et	4	main
panemas	doc_384045275264_item	2352433	et	3	main
neid	doc_384045275264_item	2352453	et	4	main
2006	doc_384045275264_item	2352457	et	2	main
taevas	doc_384045275264_item	2352468	et	4	main
vanausuliste	doc_384045275264_item	2352475	et	4	main
sisuga	doc_384045275264_item	2352487	et	3	main
paastu	doc_384045275264_item	2352491	et	4	main
kuratlikke	doc_384045275264_item	2352495	et	3	main
neid	doc_384045275264_item	2352501	et	4	main
kui	doc_384045275264_item	2352505	et	3	main
iidse	doc_384045275264_item	2352530	et	3	main
athose	doc_384045275264_item	2352534	et	4	main
hirmus	doc_384045275264_item	2352538	et	4	main
leidus	doc_384045275264_item	2352126	et	4	main
viisteist	doc_384045275264_item	2352128	et	4	main
üksikasjaliselt	doc_384045275264_item	2352139	et	4	main
rääkida	doc_384045275264_item	2352141	et	3	main
e	doc_384045275264_item	2352143	et	4	main
ennustustest	doc_384045275264_item	2352144	et	4	main
kuke	doc_384045275264_item	2352145	et	3	main
ja	doc_384045275264_item	2352146	et	3	main
regioonides	doc_384045275264_item	2352160	et	3	main
ei	doc_384045275264_item	2352167	et	4	main
vaimulikke	doc_384045275264_item	2352173	et	3	main
vaatamatta	doc_384045275264_item	2352175	et	4	main
et	doc_384045275264_item	2352177	et	3	main
ka	doc_384045275264_item	2352182	et	3	main
oli	doc_384045275264_item	2352184	et	3	main
avastatud	doc_384045275264_item	2352186	et	4	main
üks	doc_384045275264_item	2352188	et	3	main
muinasjuttudega	doc_384045275264_item	2352196	et	3	main
õigel	doc_384045275264_item	2352202	et	3	main
seas	doc_384045275264_item	2352206	et	4	main
peaaegu	doc_384045275264_item	2352209	et	3	main
ühtegi	doc_384045275264_item	2352210	et	4	main
professionaalset	doc_384045275264_item	2352211	et	3	main
folkloristi	doc_384045275264_item	2352212	et	4	main
eelistasid	doc_384045275264_item	2352213	et	4	main
üleskirjutada	doc_384045275264_item	2352214	et	4	main
laule	doc_384045275264_item	2352215	et	4	main
neljavärsilisi	doc_384045275264_item	2352216	et	4	main
naljalaule	doc_384045275264_item	2352217	et	4	main
tšastuškasi	doc_384045275264_item	2352218	et	2	main
kirjeldasid	doc_384045275264_item	2352219	et	4	main
tavandeid	doc_384045275264_item	2352220	et	3	main
mis	doc_384045275264_item	2352221	et	4	main
isegi	doc_384045275264_item	2352228	et	4	main
meenutasid	doc_384045275264_item	2352234	et	4	main
kõrge	doc_384045275264_item	2352253	et	4	main
klaasi	doc_384045275264_item	2352262	et	4	main
igaühel	doc_384045275264_item	2352266	et	3	main
ka	doc_384045275264_item	2352267	et	3	main
lugemine	doc_384045275264_item	2352269	et	4	main
vanausulistel	doc_384045275264_item	2352271	et	4	main
ka	doc_384045275264_item	2352278	et	3	main
materjali	doc_384045275264_item	2352286	et	4	main
nappuse	doc_384045275264_item	2352287	et	4	main
suulise	doc_384045275264_item	2352294	et	4	main
süžeed	doc_384045275264_item	2352298	et	2	main
venemaa	doc_384045275264_item	2352302	et	4	main
levinud	doc_384045275264_item	2352304	et	4	main
on	doc_384045275264_item	2352309	et	4	main
luiskajatest	doc_384045275264_item	2352320	et	4	main
mõned	doc_384045275264_item	2352321	et	3	main
võlumuinasjutu	doc_384045275264_item	2352325	et	3	main
tekstides	doc_384045275264_item	2352332	et	3	main
eluolu	doc_384045275264_item	2352336	et	4	main
käigus	doc_384045275264_item	2352348	et	4	main
keeleteadlaste	doc_384045275264_item	2352362	et	3	main
ja	doc_384045275264_item	2352363	et	3	main
artiklitel	doc_384045275264_item	2352365	et	3	main
vanausulised	doc_384045275264_item	2352381	et	4	main
kompaktselt	doc_384045275264_item	2352383	et	4	main
rahvarohketes	doc_384045275264_item	2352384	et	3	main
ju	doc_384045275264_item	2352223	et	3	main
pikkadel	doc_384045275264_item	2352238	et	4	main
talvistel	doc_384045275264_item	2352239	et	4	main
muinasjuttude	doc_384045275264_item	2352245	et	4	main
vähesust	doc_384045275264_item	2352247	et	4	main
määral	doc_384045275264_item	2352249	et	3	main
seletab	doc_384045275264_item	2352250	et	3	main
ka	doc_384045275264_item	2352251	et	3	main
oli	doc_384045275264_item	2352264	et	3	main
on	doc_384045275264_item	2352289	et	4	main
fikseeritud	doc_384045275264_item	2352297	et	4	main
loode	doc_384045275264_item	2352301	et	4	main
kubermangus	doc_384045275264_item	2352303	et	3	main
repertuaari	doc_384045275264_item	2352305	et	4	main
raame	doc_384045275264_item	2352306	et	3	main
säilinud	doc_384045275264_item	2352310	et	4	main
rahvaanekdoodid	doc_384045275264_item	2352314	et	3	main
abielunaisest	doc_384045275264_item	2352316	et	3	main
teosed	doc_384045275264_item	2352322	et	3	main
rahvajutu	doc_384045275264_item	2352328	et	3	main
vahepealse	doc_384045275264_item	2352329	et	3	main
keelelises	doc_384045275264_item	2352342	et	4	main
plaanis	doc_384045275264_item	2352343	et	4	main
pärimusi	doc_384045275264_item	2352344	et	4	main
ja	doc_384045275264_item	2352345	et	3	main
legende	doc_384045275264_item	2352346	et	3	main
oodatust	doc_384045275264_item	2352350	et	4	main
vähem	doc_384045275264_item	2352352	et	4	main
segased	doc_384045275264_item	2352353	et	3	main
ja	doc_384045275264_item	2352354	et	3	main
vastuolulised	doc_384045275264_item	2352355	et	4	main
lood	doc_384045275264_item	2352356	et	4	main
põhinevad	doc_384045275264_item	2352361	et	4	main
ajaloolaste	doc_384045275264_item	2352364	et	4	main
huvi	doc_384045275264_item	2352367	et	4	main
seletab	doc_384045275264_item	2352379	et	3	main
elavad	doc_384045275264_item	2352382	et	4	main
külades	doc_384045275264_item	2352385	et	3	main
eestlane	doc_384045275264_item	2352421	et	3	main
oma	doc_384045275264_item	2352423	et	4	main
elu	doc_384045275264_item	2352424	et	4	main
lõpuni	doc_384045275264_item	2352425	et	3	main
tänades	doc_384045275264_item	2352434	et	3	main
moel	doc_384045275264_item	2352436	et	4	main
oma	doc_384045275264_item	2352438	et	4	main
geneetiliselt	doc_384045275264_item	2352445	et	4	main
piibli	doc_384045275264_item	2352447	et	3	main
kuid	doc_384045275264_item	2352449	et	4	main
vähe	doc_384045275264_item	2352456	et	3	main
õnnestus	doc_384045275264_item	2352459	et	4	main
panna	doc_384045275264_item	2352461	et	4	main
lugu	doc_384045275264_item	2352462	et	4	main
kujutist	doc_384045275264_item	2352471	et	3	main
igapäevaelus	doc_384045275264_item	2352476	et	4	main
endimisi	doc_384045275264_item	2352477	et	4	main
rolli	doc_384045275264_item	2352479	et	4	main
mäletavad	doc_384045275264_item	2352482	et	4	main
religioosse	doc_384045275264_item	2352486	et	3	main
ajal	doc_384045275264_item	2352504	et	4	main
oli	doc_384045275264_item	2352270	et	3	main
siinkohas	doc_384045275264_item	2352274	et	4	main
kindlasti	doc_384045275264_item	2352275	et	3	main
tõttu	doc_384045275264_item	2352288	et	4	main
midagi	doc_384045275264_item	2352292	et	4	main
teistest	doc_384045275264_item	2352307	et	4	main
paremini	doc_384045275264_item	2352308	et	4	main
muinasjutud	doc_384045275264_item	2352312	et	3	main
endast	doc_384045275264_item	2352324	et	4	main
mütoloogilise	doc_384045275264_item	2352327	et	4	main
liigi	doc_384045275264_item	2352330	et	4	main
nendes	doc_384045275264_item	2352331	et	4	main
ei	doc_384045275264_item	2352333	et	4	main
leidu	doc_384045275264_item	2352334	et	4	main
tunnuseid	doc_384045275264_item	2352337	et	3	main
omapära	doc_384045275264_item	2352339	et	4	main
pigem	doc_384045275264_item	2352341	et	3	main
ümberasumisest	doc_384045275264_item	2352358	et	4	main
pigem	doc_384045275264_item	2352360	et	3	main
teatud	doc_384045275264_item	2352366	et	4	main
kohalikust	doc_384045275264_item	2352370	et	4	main
on	doc_384045275264_item	2352374	et	4	main
vaimukalt	doc_384045275264_item	2352378	et	4	main
elavad	doc_384045275264_item	2352388	et	4	main
üksikult	doc_384045275264_item	2352389	et	4	main
taludes	doc_384045275264_item	2352391	et	4	main
lendas	doc_384045275264_item	2352393	et	3	main
taevas	doc_384045275264_item	2352394	et	4	main
ja	doc_384045275264_item	2352395	et	3	main
eestlasi	doc_384045275264_item	2352396	et	3	main
puistas	doc_384045275264_item	2352397	et	3	main
ta	doc_384045275264_item	2352398	et	4	main
ükshaaval	doc_384045275264_item	2352400	et	3	main
kõiki	doc_384045275264_item	2352399	et	4	main
laiali	doc_384045275264_item	2352401	et	3	main
aga	doc_384045275264_item	2352402	et	3	main
vanausulisi	doc_384045275264_item	2352403	et	4	main
viskas	doc_384045275264_item	2352404	et	3	main
alla	doc_384045275264_item	2352405	et	3	main
käputäiega	doc_384045275264_item	2352407	et	3	main
kristlikest	doc_384045275264_item	2352408	et	3	main
lihtsalt	doc_384045275264_item	2352406	et	4	main
tegelaskujudest	doc_384045275264_item	2352409	et	3	main
kõige	doc_384045275264_item	2352410	et	4	main
populaatsem	doc_384045275264_item	2352411	et	4	main
on	doc_384045275264_item	2352412	et	4	main
nikola-imetegija	doc_384045275264_item	2352413	et	4	main
tänapäevalgi	doc_384045275264_item	2352414	et	4	main
levivad	doc_384045275264_item	2352415	et	4	main
jutud	doc_384045275264_item	2352416	et	3	main
kalameeste	doc_384045275264_item	2352417	et	4	main
imelistest	doc_384045275264_item	2352418	et	4	main
päästmistest	doc_384045275264_item	2352419	et	4	main
üks	doc_384045275264_item	2352420	et	3	main
sel	doc_384045275264_item	2352435	et	3	main
pühakut	doc_384045275264_item	2352437	et	3	main
mõnede	doc_384045275264_item	2352442	et	3	main
süžeed	doc_384045275264_item	2352444	et	2	main
pärinevad	doc_384045275264_item	2352446	et	4	main
kohalikus	doc_384045275264_item	2352450	et	4	main
pakub	doc_384045275264_item	2352368	et	3	main
pärimus	doc_384045275264_item	2352369	et	4	main
röövlist	doc_384045275264_item	2352371	et	4	main
vasjkast	doc_384045275264_item	2352372	et	4	main
punasest	doc_384045275264_item	2352373	et	4	main
mis	doc_384045275264_item	2352377	et	4	main
eestlased	doc_384045275264_item	2352387	et	3	main
kurat	doc_384045275264_item	2352392	et	4	main
käinud	doc_384045275264_item	2352426	et	4	main
regulaarselt	doc_384045275264_item	2352427	et	4	main
mikolale	doc_384045275264_item	2352431	et	4	main
küünalt	doc_384045275264_item	2352432	et	3	main
elu	doc_384045275264_item	2352439	et	4	main
päästmise	doc_384045275264_item	2352440	et	4	main
legendide	doc_384045275264_item	2352443	et	3	main
on	doc_384045275264_item	2352452	et	4	main
aastal	doc_384045275264_item	2352458	et	3	main
kirja	doc_384045275264_item	2352460	et	4	main
sõja	doc_384045275264_item	2352465	et	3	main
olevat	doc_384045275264_item	2352467	et	4	main
nähtud	doc_384045275264_item	2352469	et	4	main
risti	doc_384045275264_item	2352470	et	4	main
maailmatunnetus	doc_384045275264_item	2352473	et	3	main
rahvalaule	doc_384045275264_item	2352488	et	4	main
ei	doc_384045275264_item	2352498	et	4	main
tohi	doc_384045275264_item	2352499	et	4	main
lauldakse	doc_384045275264_item	2352500	et	3	main
osa	doc_384045275264_item	2352522	et	4	main
samaarilanna	doc_384045275264_item	2352533	et	4	main
mägi	doc_384045275264_item	2352535	et	3	main
surmatunnist	doc_384045275264_item	2352537	et	4	main
kohus	doc_384045275264_item	2352539	et	4	main
värss	doc_384045275264_item	2352540	et	3	main
samuti	doc_384045275264_item	2352546	et	3	main
vanausulistel	doc_384045275264_item	2352549	et	4	main
teoseid	doc_384045275264_item	2352561	et	3	main
loodud	doc_384045275264_item	2352563	et	4	main
poolt	doc_384045275264_item	2352567	et	4	main
võõras	doc_384045275264_item	2352577	et	4	main
rütmika	doc_384045275264_item	2352578	et	4	main
гора	doc_384045275264_item	2352583	et	2	main
моим	doc_384045275264_item	2352589	et	2	main
всегда	doc_384045275264_item	2352594	et	2	main
над	doc_384045275264_item	2352597	et	2	main
see	doc_384045275264_item	2352602	et	3	main
lausus	doc_384045275264_item	2352604	et	4	main
oma	doc_384045275264_item	2352613	et	4	main
olla	doc_384045275264_item	2352616	et	3	main
samal	doc_384045275264_item	2352622	et	3	main
paljudes	doc_384045275264_item	2352625	et	3	main
tekstides	doc_384045275264_item	2352626	et	3	main
iidseid	doc_384045275264_item	2352628	et	3	main
kujundeid	doc_384045275264_item	2352631	et	3	main
noorest	doc_384045275264_item	2352634	et	3	main
vt	doc_384045275264_item	2352638	et	4	main
põhineb	doc_384045275264_item	2352640	et	3	main
erinevates	doc_384045275264_item	2352644	et	4	main
aeg	doc_384045275264_item	2352646	et	3	main
võlumuinasjutte	doc_384045275264_item	2352651	et	3	main
taevasse	doc_384045275264_item	2352657	et	4	main
paradiisi	doc_384045275264_item	2352673	et	4	main
möödub	doc_384045275264_item	2352679	et	3	main
võetud	doc_384045275264_item	2352713	et	4	main
mujal	doc_384045275264_item	2352721	et	3	main
olevat	doc_384045275264_item	2352422	et	4	main
vanausuliste	doc_384045275264_item	2352428	et	4	main
palvelas	doc_384045275264_item	2352429	et	3	main
eest	doc_384045275264_item	2352441	et	4	main
lugudest	doc_384045275264_item	2352448	et	3	main
suhteliselt	doc_384045275264_item	2352455	et	4	main
religioosne	doc_384045275264_item	2352472	et	3	main
omab	doc_384045275264_item	2352474	et	3	main
neid	doc_384045275264_item	2352489	et	4	main
laule	doc_384045275264_item	2352496	et	4	main
laulda	doc_384045275264_item	2352497	et	4	main
nii	doc_384045275264_item	2352502	et	3	main
ka	doc_384045275264_item	2352506	et	3	main
läänerannikul	doc_384045275264_item	2352509	et	3	main
on	doc_384045275264_item	2352510	et	4	main
säilinud	doc_384045275264_item	2352511	et	4	main
mõned	doc_384045275264_item	2352512	et	3	main
süžeed	doc_384045275264_item	2352513	et	2	main
vanast	doc_384045275264_item	2352514	et	3	main
testamendist	doc_384045275264_item	2352515	et	3	main
ülemaailmsest	doc_384045275264_item	2352516	et	3	main
veeuputusest	doc_384045275264_item	2352517	et	4	main
joosepi	doc_384045275264_item	2352518	et	4	main
nutulaul	doc_384045275264_item	2352519	et	4	main
siiski	doc_384045275264_item	2352520	et	4	main
teoseid	doc_384045275264_item	2352523	et	3	main
evangeeliumi	doc_384045275264_item	2352525	et	4	main
pühakute	doc_384045275264_item	2352527	et	3	main
jutustustel	doc_384045275264_item	2352529	et	4	main
õigeusu	doc_384045275264_item	2352531	et	3	main
jüngritest	doc_384045275264_item	2352532	et	3	main
värss	doc_384045275264_item	2352536	et	3	main
jt	doc_384045275264_item	2352545	et	4	main
osa	doc_384045275264_item	2352560	et	4	main
vaimulike	doc_384045275264_item	2352566	et	3	main
hiljaaegu	doc_384045275264_item	2352569	et	3	main
millele	doc_384045275264_item	2352570	et	3	main
рекла	doc_384045275264_item	2352584	et	2	main
жребием	doc_384045275264_item	2352588	et	2	main
мой	doc_384045275264_item	2352595	et	2	main
сим	doc_384045275264_item	2352599	et	2	main
tsaaritar	doc_384045275264_item	2352605	et	3	main
siit	doc_384045275264_item	2352610	et	3	main
et	doc_384045275264_item	2352615	et	3	main
katteks	doc_384045275264_item	2352618	et	3	main
kuid	doc_384045275264_item	2352621	et	4	main
ajal	doc_384045275264_item	2352623	et	4	main
on	doc_384045275264_item	2352624	et	4	main
motiive	doc_384045275264_item	2352629	et	3	main
et	doc_384045275264_item	2352643	et	3	main
erineva	doc_384045275264_item	2352648	et	4	main
kiirusega	doc_384045275264_item	2352649	et	4	main
rahvajutte	doc_384045275264_item	2352654	et	3	main
inimese	doc_384045275264_item	2352655	et	4	main
kuningriiki	doc_384045275264_item	2352659	et	4	main
jt	doc_384045275264_item	2352662	et	4	main
sattub	doc_384045275264_item	2352670	et	3	main
ajaga	doc_384045275264_item	2352678	et	3	main
peipsi	doc_384045275264_item	2352715	et	4	main
juurdunud	doc_384045275264_item	2352717	et	4	main
lauljad	doc_384045275264_item	2352722	et	4	main
on	doc_384045275264_item	2352730	et	4	main
liikmetele	doc_384045275264_item	2352733	et	3	main
revolutsiooni	doc_384045275264_item	2352743	et	4	main
ka	doc_384045275264_item	2352747	et	3	main
masinakirja-	doc_384045275264_item	2352750	et	4	main
toodud	doc_384045275264_item	2352759	et	4	main
poolt	doc_384045275264_item	2352767	et	4	main
teoste	doc_384045275264_item	2352769	et	3	main
repertuaaris	doc_384045275264_item	2352451	et	3	main
siiski	doc_384045275264_item	2352454	et	4	main
ettekuulutuslikust	doc_384045275264_item	2352463	et	4	main
ilmutusest	doc_384045275264_item	2352464	et	4	main
eel	doc_384045275264_item	2352466	et	4	main
võtme	doc_384045275264_item	2352478	et	3	main
eakamad	doc_384045275264_item	2352480	et	4	main
naised	doc_384045275264_item	2352481	et	3	main
tänaseni	doc_384045275264_item	2352483	et	4	main
vaimulikke	doc_384045275264_item	2352484	et	3	main
värsse	doc_384045275264_item	2352485	et	3	main
lauldakse	doc_384045275264_item	2352490	et	3	main
ajal	doc_384045275264_item	2352492	et	4	main
mil	doc_384045275264_item	2352493	et	4	main
ilmalikke	doc_384045275264_item	2352494	et	3	main
pühade	doc_384045275264_item	2352503	et	3	main
argipäeviti	doc_384045275264_item	2352507	et	3	main
peipsi	doc_384045275264_item	2352508	et	4	main
suurim	doc_384045275264_item	2352521	et	3	main
põhineb	doc_384045275264_item	2352524	et	3	main
loodel	doc_384045275264_item	2352526	et	4	main
elulugudel	doc_384045275264_item	2352528	et	3	main
morozova	doc_384045275264_item	2352544	et	4	main
viitab	doc_384045275264_item	2352571	et	3	main
sõnade	doc_384045275264_item	2352573	et	3	main
süllaabi-tooniline	doc_384045275264_item	2352580	et	4	main
сия	doc_384045275264_item	2352582	et	2	main
будет	doc_384045275264_item	2352587	et	2	main
прострет	doc_384045275264_item	2352591	et	2	main
кров	doc_384045275264_item	2352596	et	2	main
и	doc_384045275264_item	2352600	et	2	main
käe	doc_384045275264_item	2352614	et	3	main
kaitsvaks	doc_384045275264_item	2352617	et	4	main
näiteks	doc_384045275264_item	2352632	et	4	main
mungast	doc_384045275264_item	2352635	et	4	main
süžee	doc_384045275264_item	2352637	et	2	main
23	doc_384045275264_item	2352639	et	2	main
arusaamal	doc_384045275264_item	2352642	et	3	main
maailmades	doc_384045275264_item	2352645	et	3	main
kulgeb	doc_384045275264_item	2352647	et	3	main
mütoloogilisi	doc_384045275264_item	2352653	et	4	main
veealusesse	doc_384045275264_item	2352658	et	4	main
maailma	doc_384045275264_item	2352661	et	4	main
jälitades	doc_384045275264_item	2352663	et	3	main
lindu	doc_384045275264_item	2352665	et	4	main
kolmeks	doc_384045275264_item	2352671	et	4	main
tunniks	doc_384045275264_item	2352672	et	3	main
kolmsada	doc_384045275264_item	2352680	et	4	main
läänerannikul	doc_384045275264_item	2352716	et	3	main
termin	doc_384045275264_item	2352718	et	3	main
vaimulikud	doc_384045275264_item	2352719	et	3	main
tavaliselt	doc_384045275264_item	2352725	et	4	main
lihtsalt	doc_384045275264_item	2352726	et	4	main
aastal	doc_384045275264_item	2352729	et	3	main
vanausulised	doc_384045275264_item	2352731	et	4	main
hulgas	doc_384045275264_item	2352740	et	4	main
mõnede	doc_384045275264_item	2352748	et	3	main
mõne	doc_384045275264_item	2352754	et	3	main
eest	doc_384045275264_item	2352756	et	4	main
ilja	doc_384045275264_item	2352764	et	4	main
ei	doc_384045275264_item	2352772	et	4	main
vaid	doc_384045275264_item	2352776	et	3	main
mõnede	doc_384045275264_item	2352781	et	3	main
moonutamises	doc_384045275264_item	2352787	et	4	main
trüki-	doc_384045275264_item	2352789	et	4	main
ei	doc_384045275264_item	2352793	et	4	main
värsse	doc_384045275264_item	2352796	et	3	main
lauldakse	doc_384045275264_item	2352797	et	3	main
vahel	doc_384045275264_item	2352799	et	4	main
kasutatakse	doc_384045275264_item	2352800	et	3	main
sobivaid	doc_384045275264_item	2352802	et	4	main
viise	doc_384045275264_item	2352805	et	3	main
üks	doc_384045275264_item	2352808	et	3	main
ia	doc_384045275264_item	2352813	et	4	main
huvi	doc_384045275264_item	2352817	et	4	main
vastu	doc_384045275264_item	2352821	et	3	main
enne	doc_384045275264_item	2352832	et	4	main
peipsimaal	doc_384045275264_item	2352835	et	4	main
on	doc_384045275264_item	2352842	et	4	main
luulele	doc_384045275264_item	2352850	et	4	main
kui	doc_384045275264_item	2352547	et	3	main
venemaal	doc_384045275264_item	2352550	et	4	main
kõige	doc_384045275264_item	2352551	et	4	main
populaarsem	doc_384045275264_item	2352552	et	4	main
süžee	doc_384045275264_item	2352553	et	2	main
on	doc_384045275264_item	2352554	et	4	main
anus	doc_384045275264_item	2352555	et	3	main
ema	doc_384045275264_item	2352556	et	4	main
oma	doc_384045275264_item	2352557	et	4	main
lapsukest	doc_384045275264_item	2352558	et	4	main
viimsest	doc_384045275264_item	2352541	et	3	main
ajast	doc_384045275264_item	2352542	et	4	main
bojarinna	doc_384045275264_item	2352543	et	4	main
preestrideta	doc_384045275264_item	2352548	et	4	main
suurim	doc_384045275264_item	2352559	et	3	main
munkade	doc_384045275264_item	2352564	et	3	main
rohkus	doc_384045275264_item	2352574	et	4	main
rahvaluulele	doc_384045275264_item	2352576	et	4	main
ja	doc_384045275264_item	2352579	et	3	main
царица	doc_384045275264_item	2352585	et	2	main
отсель	doc_384045275264_item	2352590	et	2	main
моя	doc_384045275264_item	2352592	et	2	main
местом	doc_384045275264_item	2352598	et	2	main
mägi	doc_384045275264_item	2352603	et	3	main
ta	doc_384045275264_item	2352606	et	4	main
saagu	doc_384045275264_item	2352607	et	3	main
minu	doc_384045275264_item	2352608	et	3	main
saatuseks	doc_384045275264_item	2352609	et	4	main
sirutan	doc_384045275264_item	2352611	et	3	main
siin	doc_384045275264_item	2352619	et	4	main
on	doc_384045275264_item	2352562	et	4	main
ja	doc_384045275264_item	2352565	et	3	main
võrdlemisi	doc_384045275264_item	2352568	et	4	main
kirikuslaavi	doc_384045275264_item	2352572	et	4	main
tekstides	doc_384045275264_item	2352575	et	3	main
värsisüsteem	doc_384045275264_item	2352581	et	3	main
да	doc_384045275264_item	2352586	et	2	main
десница	doc_384045275264_item	2352593	et	2	main
тп	doc_384045275264_item	2352601	et	2	main
ma	doc_384045275264_item	2352612	et	3	main
jn	doc_384045275264_item	2352620	et	4	main
värss	doc_384045275264_item	2352633	et	3	main
võrdle	doc_384045275264_item	2352650	et	4	main
ja	doc_384045275264_item	2352652	et	3	main
antoonius	doc_384045275264_item	2352666	et	4	main
kloostri	doc_384045275264_item	2352668	et	3	main
selle	doc_384045275264_item	2352677	et	4	main
aastat	doc_384045275264_item	2352681	et	3	main
ka	doc_384045275264_item	2352714	et	3	main
värsid	doc_384045275264_item	2352720	et	3	main
ekspeditsiooni	doc_384045275264_item	2352732	et	4	main
näidanud	doc_384045275264_item	2352735	et	4	main
vaimulike	doc_384045275264_item	2352736	et	3	main
värsside	doc_384045275264_item	2352737	et	3	main
nendel	doc_384045275264_item	2352744	et	4	main
allikatel	doc_384045275264_item	2352745	et	4	main
ja	doc_384045275264_item	2352751	et	3	main
mis	doc_384045275264_item	2352753	et	4	main
aasta	doc_384045275264_item	2352755	et	4	main
olid	doc_384045275264_item	2352757	et	4	main
palvelatesse	doc_384045275264_item	2352758	et	4	main
daugavpilsist	doc_384045275264_item	2352761	et	4	main
alekseevitš	doc_384045275264_item	2352765	et	2	main
varieerimine	doc_384045275264_item	2352774	et	4	main
kuna	doc_384045275264_item	2352788	et	3	main
ja	doc_384045275264_item	2352790	et	3	main
kogumikud	doc_384045275264_item	2352792	et	4	main
ole	doc_384045275264_item	2352794	et	4	main
noteeritud	doc_384045275264_item	2352795	et	4	main
ka	doc_384045275264_item	2352807	et	3	main
taaselustus	doc_384045275264_item	2352816	et	4	main
rahva	doc_384045275264_item	2352818	et	3	main
eakad	doc_384045275264_item	2352822	et	3	main
meelde	doc_384045275264_item	2352825	et	3	main
vaimulike	doc_384045275264_item	2352837	et	3	main
uuemat	doc_384045275264_item	2352845	et	4	main
rahvaluulet	doc_384045275264_item	2352846	et	3	main
vanausuliste	doc_384045275264_item	2352849	et	4	main
stilistilisi	doc_384045275264_item	2352854	et	4	main
lapsukese	doc_384045275264_item	2352856	et	4	main
värss	doc_384045275264_item	2352859	et	3	main
erakust	doc_384045275264_item	2352861	et	4	main
algab	doc_384045275264_item	2352867	et	3	main
istutakse	doc_384045275264_item	2352871	et	3	main
metsa	doc_384045275264_item	2352877	et	4	main
varutakse	doc_384045275264_item	2352882	et	4	main
neid	doc_384045275264_item	2352924	et	4	main
jutustas	doc_384045275264_item	2352936	et	3	main
palvelasse	doc_384045275264_item	2352949	et	4	main
sööginõusi	doc_384045275264_item	2352957	et	4	main
ka	doc_384045275264_item	2352973	et	3	main
oma	doc_384045275264_item	2352974	et	4	main
andis	doc_384045275264_item	2352976	et	3	main
paljud	doc_384045275264_item	2352985	et	3	main
maailma	doc_384045275264_item	2352991	et	4	main
kinnitasid	doc_384045275264_item	2352996	et	4	main
paatide	doc_384045275264_item	2352999	et	3	main
ninaossa	doc_384045275264_item	2353000	et	3	main
vetelpäästja	doc_384045275264_item	2353008	et	4	main
eelmise	doc_384045275264_item	2353012	et	3	main
algusel	doc_384045275264_item	2353014	et	4	main
säilinud	doc_384045275264_item	2352627	et	4	main
ja	doc_384045275264_item	2352630	et	3	main
antooniusest	doc_384045275264_item	2352636	et	4	main
arhaailisel	doc_384045275264_item	2352641	et	4	main
rännakust	doc_384045275264_item	2352656	et	3	main
hauatagusesse	doc_384045275264_item	2352660	et	4	main
imelist	doc_384045275264_item	2352664	et	4	main
jätab	doc_384045275264_item	2352667	et	3	main
ja	doc_384045275264_item	2352669	et	3	main
maa	doc_384045275264_item	2352674	et	4	main
peal	doc_384045275264_item	2352675	et	4	main
aga	doc_384045275264_item	2352676	et	3	main
tekstis	doc_384045275264_item	2352682	et	3	main
paradiisi	doc_384045275264_item	2352683	et	4	main
ei	doc_384045275264_item	2352684	et	4	main
mainita	doc_384045275264_item	2352685	et	3	main
kuid	doc_384045275264_item	2352686	et	4	main
paljudes	doc_384045275264_item	2352687	et	3	main
regioonides	doc_384045275264_item	2352688	et	3	main
seda	doc_384045275264_item	2352690	et	3	main
venemaal	doc_384045275264_item	2352689	et	4	main
teost	doc_384045275264_item	2352691	et	4	main
nimetatakse	doc_384045275264_item	2352692	et	3	main
paradiisi	doc_384045275264_item	2352693	et	4	main
linnuke	doc_384045275264_item	2352694	et	4	main
erinevalt	doc_384045275264_item	2352695	et	4	main
lätist	doc_384045275264_item	2352696	et	4	main
ja	doc_384045275264_item	2352697	et	3	main
eriti	doc_384045275264_item	2352698	et	3	main
leedust	doc_384045275264_item	2352699	et	4	main
eesti	doc_384045275264_item	2352700	et	4	main
vanausulistel	doc_384045275264_item	2352701	et	4	main
see	doc_384045275264_item	2352702	et	3	main
žanr	doc_384045275264_item	2352703	et	2	main
elab	doc_384045275264_item	2352704	et	3	main
mitte	doc_384045275264_item	2352705	et	3	main
suulises	doc_384045275264_item	2352706	et	4	main
vaid	doc_384045275264_item	2352707	et	3	main
käsikirjalises	doc_384045275264_item	2352708	et	4	main
traditsioonis	doc_384045275264_item	2352709	et	3	main
raamatutest	doc_384045275264_item	2352710	et	4	main
on	doc_384045275264_item	2352711	et	4	main
nähtavasti	doc_384045275264_item	2352712	et	3	main
nimetavad	doc_384045275264_item	2352723	et	4	main
2006	doc_384045275264_item	2352728	et	2	main
tihti	doc_384045275264_item	2352734	et	3	main
süžeede	doc_384045275264_item	2352749	et	2	main
trükikoopiad	doc_384045275264_item	2352752	et	3	main
lätist	doc_384045275264_item	2352760	et	4	main
muutu	doc_384045275264_item	2352773	et	4	main
väljendub	doc_384045275264_item	2352775	et	3	main
kirikuviisidel	doc_384045275264_item	2352798	et	3	main
neid	doc_384045275264_item	2352724	et	4	main
värssideks	doc_384045275264_item	2352727	et	3	main
trükikogumikke	doc_384045275264_item	2352738	et	4	main
seal	doc_384045275264_item	2352739	et	4	main
trükituid	doc_384045275264_item	2352741	et	4	main
enne	doc_384045275264_item	2352742	et	4	main
põhinevad	doc_384045275264_item	2352746	et	4	main
vaimulik	doc_384045275264_item	2352762	et	3	main
nastavnik	doc_384045275264_item	2352763	et	4	main
žilko	doc_384045275264_item	2352766	et	2	main
koopiates	doc_384045275264_item	2352768	et	3	main
sisu	doc_384045275264_item	2352770	et	4	main
mõnede	doc_384045275264_item	2352777	et	3	main
väljajätmises	doc_384045275264_item	2352779	et	3	main
arusaamatute	doc_384045275264_item	2352782	et	4	main
arhaailste	doc_384045275264_item	2352783	et	4	main
ja	doc_384045275264_item	2352785	et	3	main
käsikirjalised	doc_384045275264_item	2352791	et	4	main
rütmiliselt	doc_384045275264_item	2352801	et	4	main
laulude	doc_384045275264_item	2352804	et	3	main
leidus	doc_384045275264_item	2352806	et	4	main
pärast	doc_384045275264_item	2352812	et	4	main
žilko	doc_384045275264_item	2352814	et	2	main
religioosse	doc_384045275264_item	2352819	et	3	main
luule	doc_384045275264_item	2352820	et	4	main
naised	doc_384045275264_item	2352823	et	3	main
nooruspõlve	doc_384045275264_item	2352827	et	4	main
nooremale	doc_384045275264_item	2352830	et	4	main
maailmasõda	doc_384045275264_item	2352834	et	4	main
viise	doc_384045275264_item	2352839	et	3	main
toodud	doc_384045275264_item	2352843	et	4	main
ka	doc_384045275264_item	2352844	et	3	main
29	doc_384045275264_item	2352858	et	2	main
noorest	doc_384045275264_item	2352860	et	3	main
päev	doc_384045275264_item	2352866	et	3	main
lugemisega	doc_384045275264_item	2352869	et	4	main
minnakse	doc_384045275264_item	2352876	et	3	main
kolmekuningapäeva	doc_384045275264_item	2352880	et	4	main
või	doc_384045275264_item	2352886	et	4	main
mille	doc_384045275264_item	2352890	et	3	main
praktiliselt	doc_384045275264_item	2352771	et	4	main
salmide	doc_384045275264_item	2352778	et	3	main
ja	doc_384045275264_item	2352780	et	3	main
sõnade	doc_384045275264_item	2352784	et	3	main
väljendite	doc_384045275264_item	2352786	et	3	main
lüüriliste	doc_384045275264_item	2352803	et	3	main
ukraina	doc_384045275264_item	2352809	et	4	main
lauluviis	doc_384045275264_item	2352810	et	3	main
kallastes	doc_384045275264_item	2352811	et	4	main
visiiti	doc_384045275264_item	2352815	et	4	main
tuletasid	doc_384045275264_item	2352824	et	4	main
oma	doc_384045275264_item	2352826	et	4	main
ja	doc_384045275264_item	2352828	et	3	main
teist	doc_384045275264_item	2352833	et	4	main
antud	doc_384045275264_item	2352840	et	4	main
kus	doc_384045275264_item	2352847	et	3	main
tüüpilisi	doc_384045275264_item	2352851	et	3	main
motiive	doc_384045275264_item	2352852	et	3	main
nutt	doc_384045275264_item	2352857	et	3	main
30	doc_384045275264_item	2352862	et	2	main
peredes	doc_384045275264_item	2352864	et	3	main
alustatakse	doc_384045275264_item	2352873	et	3	main
tööd	doc_384045275264_item	2352875	et	4	main
ristikujuliselt	doc_384045275264_item	2352887	et	4	main
jääaugust	doc_384045275264_item	2352889	et	4	main
nimetatakse	doc_384045275264_item	2352925	et	3	main
sulased	doc_384045275264_item	2352929	et	3	main
sulased	doc_384045275264_item	2352932	et	3	main
kohalik	doc_384045275264_item	2352934	et	3	main
vanaisa	doc_384045275264_item	2352939	et	4	main
kogudusest	doc_384045275264_item	2352941	et	4	main
välja	doc_384045275264_item	2352942	et	4	main
ainult	doc_384045275264_item	2352943	et	4	main
lõhikuga	doc_384045275264_item	2352953	et	3	main
oma	doc_384045275264_item	2352956	et	4	main
samast	doc_384045275264_item	2352980	et	4	main
uskumused	doc_384045275264_item	2352988	et	3	main
maagilise	doc_384045275264_item	2352992	et	4	main
imetegijale	doc_384045275264_item	2353004	et	3	main
mikola-meeleheadtegija	doc_384045275264_item	2353005	et	4	main
oli	doc_384045275264_item	2353007	et	3	main
maine	doc_384045275264_item	2353009	et	4	main
oli	doc_384045275264_item	2353011	et	3	main
tuua	doc_384045275264_item	2353019	et	3	main
festivalid	doc_384045275264_item	2353029	et	3	main
pidustused	doc_384045275264_item	2353038	et	3	main
tulekahjude	doc_384045275264_item	2353042	et	4	main
vastu	doc_384045275264_item	2353043	et	3	main
et	doc_384045275264_item	2353045	et	3	main
pühetsetud	doc_384045275264_item	2353047	et	4	main
loomi	doc_384045275264_item	2353054	et	4	main
saates	doc_384045275264_item	2353056	et	4	main
uskumused	doc_384045275264_item	2353068	et	3	main
samuti	doc_384045275264_item	2353070	et	3	main
kas	doc_384045275264_item	2353073	et	3	main
see	doc_384045275264_item	2353075	et	3	main
päev	doc_384045275264_item	2353076	et	3	main
lasti	doc_384045275264_item	2353082	et	4	main
päev	doc_384045275264_item	2353084	et	3	main
istutati	doc_384045275264_item	2353087	et	3	main
oli	doc_384045275264_item	2353089	et	3	main
pühade	doc_384045275264_item	2353095	et	3	main
pühapäeviti	doc_384045275264_item	2353098	et	4	main
koera	doc_384045275264_item	2353136	et	4	main
kuradiga	doc_384045275264_item	2353143	et	3	main
maskeeris	doc_384045275264_item	2353150	et	3	main
antud	doc_384045275264_item	2353175	et	4	main
traditsioonilised	doc_384045275264_item	2353176	et	4	main
käitumisreeglid	doc_384045275264_item	2353177	et	3	main
tegude	doc_384045275264_item	2353185	et	3	main
ehitamisele	doc_384045275264_item	2353195	et	4	main
jm	doc_384045275264_item	2353199	et	4	main
eriti	doc_384045275264_item	2353200	et	3	main
populaarsed	doc_384045275264_item	2353201	et	3	main
on	doc_384045275264_item	2353202	et	4	main
ja	doc_384045275264_item	2353210	et	3	main
vanausuliste	doc_384045275264_item	2353218	et	4	main
kristlikud	doc_384045275264_item	2353221	et	3	main
atribuudid	doc_384045275264_item	2353223	et	3	main
rahvalausumiste	doc_384045275264_item	2353228	et	3	main
õpetasid	doc_384045275264_item	2352829	et	4	main
põlvkonnale	doc_384045275264_item	2352831	et	4	main
levinuid	doc_384045275264_item	2352836	et	4	main
värsside	doc_384045275264_item	2352838	et	3	main
kogumikus	doc_384045275264_item	2352841	et	4	main
esineb	doc_384045275264_item	2352848	et	3	main
ja	doc_384045275264_item	2352853	et	3	main
palve	doc_384045275264_item	2352868	et	4	main
raijutud	doc_384045275264_item	2352888	et	4	main
vaimulik	doc_384045275264_item	2352891	et	3	main
nastavnik	doc_384045275264_item	2352892	et	4	main
on	doc_384045275264_item	2352893	et	4	main
eelnevalt	doc_384045275264_item	2352894	et	4	main
sisse	doc_384045275264_item	2352895	et	4	main
õnnistanud	doc_384045275264_item	2352896	et	4	main
vahest	doc_384045275264_item	2352897	et	4	main
neid	doc_384045275264_item	2352898	et	4	main
nimetatakse	doc_384045275264_item	2352899	et	3	main
jordanitek	doc_384045275264_item	2352900	et	4	main
s	doc_384045275264_item	2352901	et	4	main
enne	doc_384045275264_item	2352902	et	4	main
ülestõusmispüha	doc_384045275264_item	2352903	et	4	main
puhtakspestud	doc_384045275264_item	2352904	et	3	main
nõusi	doc_384045275264_item	2352905	et	4	main
suitsutakse	doc_384045275264_item	2352906	et	4	main
viirukiga	doc_384045275264_item	2352907	et	3	main
vanema	doc_384045275264_item	2352908	et	4	main
põlvkonna	doc_384045275264_item	2352909	et	4	main
inimesed	doc_384045275264_item	2352910	et	3	main
eeskätt	doc_384045275264_item	2352911	et	3	main
kiriku	doc_384045275264_item	2352912	et	3	main
korilauljad	doc_384045275264_item	2352913	et	4	main
rangelt	doc_384045275264_item	2352914	et	4	main
järgivad	doc_384045275264_item	2352915	et	4	main
kiriku	doc_384045275264_item	2352916	et	3	main
etiketti	doc_384045275264_item	2352917	et	4	main
mis	doc_384045275264_item	2352918	et	4	main
on	doc_384045275264_item	2352919	et	4	main
eriti	doc_384045275264_item	2352920	et	3	main
siin	doc_384045275264_item	2352923	et	4	main
rabskije	doc_384045275264_item	2352926	et	4	main
tähendab	doc_384045275264_item	2352928	et	3	main
sõnapaarist	doc_384045275264_item	2352930	et	4	main
jumala	doc_384045275264_item	2352931	et	3	main
üks	doc_384045275264_item	2352933	et	3	main
tema	doc_384045275264_item	2352938	et	4	main
heideti	doc_384045275264_item	2352940	et	3	main
moodsas	doc_384045275264_item	2352951	et	3	main
vältimaks	doc_384045275264_item	2352958	et	3	main
peopesast	doc_384045275264_item	2352972	et	4	main
maailmatunnetusega	doc_384045275264_item	2352982	et	3	main
stereotüüpe	doc_384045275264_item	2352855	et	3	main
religioossetes	doc_384045275264_item	2352863	et	3	main
iga	doc_384045275264_item	2352865	et	4	main
palvega	doc_384045275264_item	2352870	et	3	main
söögilauda	doc_384045275264_item	2352872	et	4	main
tõsist	doc_384045275264_item	2352874	et	4	main
või	doc_384045275264_item	2352878	et	4	main
soosse	doc_384045275264_item	2352879	et	4	main
öösel	doc_384045275264_item	2352881	et	4	main
püha	doc_384045275264_item	2352883	et	4	main
vett	doc_384045275264_item	2352884	et	3	main
pühakojas	doc_384045275264_item	2352885	et	3	main
range	doc_384045275264_item	2352921	et	4	main
naisterahvas	doc_384045275264_item	2352935	et	4	main
selle	doc_384045275264_item	2352944	et	4	main
eest	doc_384045275264_item	2352945	et	4	main
et	doc_384045275264_item	2352946	et	3	main
ta	doc_384045275264_item	2352947	et	4	main
tuli	doc_384045275264_item	2352948	et	4	main
märgistasid	doc_384045275264_item	2352955	et	4	main
naisele	doc_384045275264_item	2352975	et	3	main
läbipõimutud	doc_384045275264_item	2352984	et	4	main
rahvatavandid	doc_384045275264_item	2352987	et	3	main
ja	doc_384045275264_item	2352989	et	3	main
ikoone	doc_384045275264_item	2352997	et	3	main
nikolai	doc_384045275264_item	2353003	et	4	main
ulutöödelt	doc_384045275264_item	2353017	et	3	main
sealt	doc_384045275264_item	2353020	et	4	main
ikoone	doc_384045275264_item	2353022	et	3	main
isegi	doc_384045275264_item	2353026	et	4	main
pühaga	doc_384045275264_item	2353034	et	3	main
lõpetati	doc_384045275264_item	2353039	et	3	main
jumalateenistusega	doc_384045275264_item	2353041	et	3	main
pühakojas	doc_384045275264_item	2353046	et	3	main
karjamaale	doc_384045275264_item	2353055	et	4	main
et	doc_384045275264_item	2353057	et	3	main
karjamaale	doc_384045275264_item	2353081	et	4	main
seotud	doc_384045275264_item	2353091	et	4	main
tööd	doc_384045275264_item	2353099	et	4	main
käia	doc_384045275264_item	2353101	et	4	main
saunas	doc_384045275264_item	2353102	et	3	main
peale	doc_384045275264_item	2353103	et	4	main
kõik	doc_384045275264_item	2353110	et	4	main
siis	doc_384045275264_item	2353121	et	3	main
et	doc_384045275264_item	2353127	et	3	main
tohi	doc_384045275264_item	2353135	et	4	main
ämblik	doc_384045275264_item	2353149	et	3	main
võrguga	doc_384045275264_item	2353152	et	3	main
koopa	doc_384045275264_item	2353153	et	3	main
kuhu	doc_384045275264_item	2353154	et	3	main
tagajalitajate	doc_384045275264_item	2353158	et	4	main
eest	doc_384045275264_item	2353159	et	4	main
aga	doc_384045275264_item	2353160	et	3	main
kinnitatakse	doc_384045275264_item	2353179	et	3	main
lugude	doc_384045275264_item	2353180	et	3	main
lahtiütlemine	doc_384045275264_item	2353187	et	3	main
usust	doc_384045275264_item	2353189	et	3	main
ikoonide	doc_384045275264_item	2353190	et	3	main
müük	doc_384045275264_item	2353191	et	3	main
vargus	doc_384045275264_item	2353192	et	3	main
joodikutest	doc_384045275264_item	2353204	et	3	main
kes	doc_384045275264_item	2353205	et	4	main
purjuspäi	doc_384045275264_item	2353206	et	3	main
sattuvad	doc_384045275264_item	2353207	et	4	main
eluohtlikke	doc_384045275264_item	2353214	et	3	main
kultuuris	doc_384045275264_item	2353219	et	3	main
mõisted	doc_384045275264_item	2353222	et	3	main
üldse	doc_384045275264_item	2353238	et	3	main
kirjaliku	doc_384045275264_item	2353249	et	3	main
vastsest	doc_384045275264_item	2353259	et	4	main
surmast	doc_384045275264_item	2353260	et	4	main
neid	doc_384045275264_item	2353265	et	4	main
läinud	doc_384045275264_item	2353270	et	4	main
nõial	doc_384045275264_item	2353274	et	3	main
tondid	doc_384045275264_item	2353275	et	3	main
pöördumisega	doc_384045275264_item	2353288	et	4	main
lindude	doc_384045275264_item	2353292	et	4	main
ussidele	doc_384045275264_item	2353299	et	3	main
rahu	doc_384045275264_item	2353304	et	4	main
kodule	doc_384045275264_item	2353307	et	3	main
emakest-ahju	doc_384045275264_item	2353308	et	4	main
vanausulistel-fedosejevlastel	doc_384045275264_item	2352922	et	4	main
mis	doc_384045275264_item	2352927	et	4	main
et	doc_384045275264_item	2352937	et	3	main
jumalateenistusele	doc_384045275264_item	2352950	et	3	main
mantlis	doc_384045275264_item	2352952	et	3	main
vanausulised	doc_384045275264_item	2352954	et	4	main
et	doc_384045275264_item	2352959	et	3	main
neid	doc_384045275264_item	2352961	et	4	main
ilmalikud	doc_384045275264_item	2352960	et	3	main
ei	doc_384045275264_item	2352962	et	4	main
kasutaks	doc_384045275264_item	2352963	et	4	main
tulles	doc_384045275264_item	2352964	et	4	main
võõraste	doc_384045275264_item	2352965	et	4	main
juurde	doc_384045275264_item	2352966	et	4	main
külla	doc_384045275264_item	2352967	et	4	main
mees	doc_384045275264_item	2352968	et	4	main
jõi	doc_384045275264_item	2352969	et	3	main
vett	doc_384045275264_item	2352970	et	3	main
oma	doc_384045275264_item	2352971	et	4	main
ta	doc_384045275264_item	2352977	et	4	main
juua	doc_384045275264_item	2352978	et	3	main
sealt	doc_384045275264_item	2352979	et	4	main
religioosse	doc_384045275264_item	2352981	et	3	main
vanausuliste	doc_384045275264_item	2352986	et	4	main
ümbritseva	doc_384045275264_item	2352990	et	4	main
mõjutamise	doc_384045275264_item	2352993	et	4	main
kalurid	doc_384045275264_item	2352995	et	3	main
suurte	doc_384045275264_item	2352998	et	3	main
eelistati	doc_384045275264_item	2353001	et	4	main
ikooni	doc_384045275264_item	2353002	et	4	main
kallastes	doc_384045275264_item	2353010	et	4	main
sajandi	doc_384045275264_item	2353013	et	3	main
traditsioon	doc_384045275264_item	2353015	et	3	main
naastes	doc_384045275264_item	2353016	et	4	main
laadogalt	doc_384045275264_item	2353018	et	4	main
vanausuliste	doc_384045275264_item	2353021	et	4	main
ja	doc_384045275264_item	2353023	et	3	main
pühakojale	doc_384045275264_item	2353025	et	3	main
igaastased	doc_384045275264_item	2353027	et	4	main
ajaliselt	doc_384045275264_item	2353031	et	4	main
pühaga	doc_384045275264_item	2353037	et	3	main
usuti	doc_384045275264_item	2353044	et	3	main
tulekahjust	doc_384045275264_item	2353050	et	4	main
kasutati	doc_384045275264_item	2353052	et	4	main
põllu-	doc_384045275264_item	2353062	et	3	main
millal	doc_384045275264_item	2353085	et	3	main
ajal	doc_384045275264_item	2353096	et	4	main
teha	doc_384045275264_item	2353100	et	3	main
risti	doc_384045275264_item	2353123	et	4	main
sellele	doc_384045275264_item	2353124	et	4	main
peale	doc_384045275264_item	2353125	et	4	main
lasta	doc_384045275264_item	2353137	et	4	main
evangeeliumi	doc_384045275264_item	2353139	et	4	main
aegadel	doc_384045275264_item	2353140	et	3	main
sõbrunes	doc_384045275264_item	2353141	et	3	main
koer	doc_384045275264_item	2353142	et	3	main
on	doc_384045275264_item	2353145	et	4	main
tappa	doc_384045275264_item	2353147	et	4	main
kristus-lapsuke	doc_384045275264_item	2353156	et	4	main
tihtipeale	doc_384045275264_item	2353178	et	3	main
abil	doc_384045275264_item	2353181	et	4	main
jumala	doc_384045275264_item	2353182	et	3	main
karistusest	doc_384045275264_item	2353183	et	4	main
kiriku	doc_384045275264_item	2353194	et	3	main
raha	doc_384045275264_item	2353197	et	4	main
vanakurja	doc_384045275264_item	2353208	et	4	main
kätte	doc_384045275264_item	2353209	et	4	main
seavad	doc_384045275264_item	2353212	et	3	main
peipsi	doc_384045275264_item	2353216	et	4	main
on	doc_384045275264_item	2352983	et	4	main
viisid	doc_384045275264_item	2352994	et	4	main
kellel	doc_384045275264_item	2353006	et	4	main
kinkida	doc_384045275264_item	2353024	et	3	main
seotud	doc_384045275264_item	2353032	et	4	main
kodukiriku	doc_384045275264_item	2353033	et	3	main
uinumise	doc_384045275264_item	2353036	et	4	main
päästavad	doc_384045275264_item	2353049	et	4	main
pajuoksi	doc_384045275264_item	2353051	et	4	main
lehmakesed	doc_384045275264_item	2353058	et	4	main
ei	doc_384045275264_item	2353060	et	4	main
jääks	doc_384045275264_item	2353061	et	4	main
ja	doc_384045275264_item	2353063	et	3	main
millal	doc_384045275264_item	2353077	et	3	main
korda	doc_384045275264_item	2353079	et	4	main
või	doc_384045275264_item	2353083	et	4	main
keelatud	doc_384045275264_item	2353093	et	4	main
on	doc_384045275264_item	2353094	et	4	main
päikese	doc_384045275264_item	2353104	et	4	main
loojangut	doc_384045275264_item	2353105	et	3	main
pesed	doc_384045275264_item	2353106	et	3	main
ennast	doc_384045275264_item	2353107	et	4	main
kristuse	doc_384045275264_item	2353108	et	3	main
verega	doc_384045275264_item	2353109	et	3	main
peab	doc_384045275264_item	2353122	et	4	main
öösel	doc_384045275264_item	2353128	et	4	main
neis	doc_384045275264_item	2353129	et	4	main
halvad	doc_384045275264_item	2353130	et	4	main
ämblikut	doc_384045275264_item	2353146	et	4	main
kuna	doc_384045275264_item	2353148	et	3	main
andeks	doc_384045275264_item	2353174	et	3	main
halbade	doc_384045275264_item	2353184	et	3	main
eest	doc_384045275264_item	2353186	et	4	main
oma	doc_384045275264_item	2353188	et	4	main
palvelas	doc_384045275264_item	2353193	et	3	main
mõeldud	doc_384045275264_item	2353196	et	4	main
omistamine	doc_384045275264_item	2353198	et	4	main
vahel	doc_384045275264_item	2353211	et	4	main
olukordadesse	doc_384045275264_item	2353215	et	3	main
on	doc_384045275264_item	2353220	et	4	main
kohalikes	doc_384045275264_item	2353229	et	3	main
kasutatakse	doc_384045275264_item	2353232	et	3	main
nad	doc_384045275264_item	2353237	et	3	main
seotud	doc_384045275264_item	2353246	et	4	main
mõne	doc_384045275264_item	2353257	et	3	main
sugulase	doc_384045275264_item	2353258	et	3	main
palveta	doc_384045275264_item	2353267	et	4	main
on	doc_384045275264_item	2353268	et	4	main
aitab	doc_384045275264_item	2353272	et	3	main
majast	doc_384045275264_item	2353276	et	4	main
kui	doc_384045275264_item	2353279	et	3	main
aastas	doc_384045275264_item	2353282	et	3	main
luulelise	doc_384045275264_item	2353287	et	4	main
vaja	doc_384045275264_item	2353296	et	4	main
ja	doc_384045275264_item	2353300	et	3	main
sooviti	doc_384045275264_item	2353302	et	3	main
olgu	doc_384045275264_item	2353305	et	3	main
teie	doc_384045275264_item	2353306	et	4	main
et	doc_384045275264_item	2353312	et	3	main
kulitš	doc_384045275264_item	2353314	et	2	main
ja	doc_384045275264_item	2353320	et	3	main
tänapäeval	doc_384045275264_item	2353322	et	3	main
levinud	doc_384045275264_item	2353324	et	4	main
uskumus	doc_384045275264_item	2353325	et	3	main
arhailiste	doc_384045275264_item	2353334	et	3	main
on	doc_384045275264_item	2353336	et	4	main
olendeid	doc_384045275264_item	2353343	et	3	main
koheselt	doc_384045275264_item	2353346	et	4	main
vastavad	doc_384045275264_item	2353347	et	4	main
nad	doc_384045275264_item	2353348	et	3	main
oma	doc_384045275264_item	2353349	et	4	main
too	doc_384045275264_item	2353372	et	4	main
vanakuri	doc_384045275264_item	2353374	et	4	main
kätega	doc_384045275264_item	2353415	et	3	main
järgida	doc_384045275264_item	2353423	et	3	main
nimepanemise	doc_384045275264_item	2353425	et	3	main
hoolealust	doc_384045275264_item	2353434	et	4	main
elu	doc_384045275264_item	2353436	et	4	main
inimese	doc_384045275264_item	2353452	et	4	main
kastetakse	doc_384045275264_item	2353477	et	4	main
tohi	doc_384045275264_item	2353479	et	4	main
see	doc_384045275264_item	2353482	et	3	main
tuletõrjeühingu	doc_384045275264_item	2353028	et	3	main
olid	doc_384045275264_item	2353030	et	4	main
jumalaema	doc_384045275264_item	2353035	et	4	main
palvelas	doc_384045275264_item	2353040	et	3	main
pajuoksad	doc_384045275264_item	2353048	et	3	main
ka	doc_384045275264_item	2353053	et	3	main
haigeks	doc_384045275264_item	2353059	et	4	main
aiatöödega	doc_384045275264_item	2353064	et	3	main
seotud	doc_384045275264_item	2353065	et	4	main
tavad	doc_384045275264_item	2353066	et	3	main
ja	doc_384045275264_item	2353067	et	3	main
olid	doc_384045275264_item	2353069	et	4	main
seotud	doc_384045275264_item	2353071	et	4	main
kirikupühadega	doc_384045275264_item	2353072	et	3	main
oli	doc_384045275264_item	2353074	et	3	main
esimest	doc_384045275264_item	2353078	et	4	main
loomi	doc_384045275264_item	2353080	et	4	main
kurke	doc_384045275264_item	2353086	et	3	main
ilmaennustus	doc_384045275264_item	2353088	et	3	main
samuti	doc_384045275264_item	2353090	et	3	main
kirikupühadega	doc_384045275264_item	2353092	et	3	main
ja	doc_384045275264_item	2353097	et	3	main
toidud	doc_384045275264_item	2353111	et	3	main
ja	doc_384045275264_item	2353112	et	3	main
vesi	doc_384045275264_item	2353113	et	4	main
õhtuti	doc_384045275264_item	2353115	et	3	main
peavad	doc_384045275264_item	2353116	et	4	main
anumates	doc_384045275264_item	2353114	et	3	main
kindlasti	doc_384045275264_item	2353117	et	3	main
kaetud	doc_384045275264_item	2353118	et	4	main
olema	doc_384045275264_item	2353119	et	4	main
või	doc_384045275264_item	2353120	et	4	main
lööma	doc_384045275264_item	2353126	et	4	main
ei	doc_384045275264_item	2353131	et	4	main
supleks	doc_384045275264_item	2353132	et	3	main
maija	doc_384045275264_item	2353133	et	4	main
et	doc_384045275264_item	2353134	et	3	main
sest	doc_384045275264_item	2353138	et	4	main
patt	doc_384045275264_item	2353144	et	3	main
oma	doc_384045275264_item	2353151	et	4	main
oli	doc_384045275264_item	2353155	et	3	main
peidetud	doc_384045275264_item	2353157	et	4	main
ussi	doc_384045275264_item	2353161	et	4	main
tapmise	doc_384045275264_item	2353162	et	4	main
eest	doc_384045275264_item	2353163	et	4	main
keda	doc_384045275264_item	2353164	et	4	main
ida-slaavlased	doc_384045275264_item	2353165	et	3	main
traditsioonileselt	doc_384045275264_item	2353166	et	3	main
pidasid	doc_384045275264_item	2353167	et	4	main
kurjuse	doc_384045275264_item	2353168	et	4	main
kehastuseks	doc_384045275264_item	2353169	et	4	main
sai	doc_384045275264_item	2353170	et	4	main
teatud	doc_384045275264_item	2353171	et	4	main
hulk	doc_384045275264_item	2353172	et	3	main
patte	doc_384045275264_item	2353173	et	3	main
jutustused	doc_384045275264_item	2353203	et	4	main
end	doc_384045275264_item	2353213	et	4	main
lääneranniku	doc_384045275264_item	2353217	et	3	main
ja	doc_384045275264_item	2353224	et	3	main
põimunud	doc_384045275264_item	2353226	et	4	main
tihti	doc_384045275264_item	2353231	et	3	main
valemit	doc_384045275264_item	2353234	et	3	main
palvete	doc_384045275264_item	2353239	et	3	main
välja	doc_384045275264_item	2353241	et	4	main
arvatavasti	doc_384045275264_item	2353243	et	3	main
see	doc_384045275264_item	2353245	et	3	main
lausumiste	doc_384045275264_item	2353248	et	4	main
ta	doc_384045275264_item	2353261	et	4	main
kes	doc_384045275264_item	2353266	et	4	main
ta	doc_384045275264_item	2353273	et	4	main
ajada	doc_384045275264_item	2353278	et	3	main
metsloomade	doc_384045275264_item	2353290	et	4	main
ja	doc_384045275264_item	2353291	et	3	main
poole	doc_384045275264_item	2353293	et	4	main
metsaga	doc_384045275264_item	2353294	et	3	main
on	doc_384045275264_item	2353295	et	4	main
isegi	doc_384045275264_item	2353331	et	4	main
võpatab	doc_384045275264_item	2353333	et	3	main
ohtlikke	doc_384045275264_item	2353342	et	3	main
peagi	doc_384045275264_item	2353354	et	4	main
üldse	doc_384045275264_item	2353355	et	3	main
ei	doc_384045275264_item	2353356	et	4	main
inimene	doc_384045275264_item	2353364	et	3	main
või	doc_384045275264_item	2353367	et	4	main
nimetatakse	doc_384045275264_item	2353369	et	3	main
kaval	doc_384045275264_item	2353375	et	4	main
must	doc_384045275264_item	2353376	et	4	main
halb	doc_384045275264_item	2353378	et	3	main
kõige	doc_384045275264_item	2353379	et	4	main
ergsamalt	doc_384045275264_item	2353380	et	4	main
väljendub	doc_384045275264_item	2353381	et	3	main
vaimse	doc_384045275264_item	2353383	et	3	main
ehmatuses	doc_384045275264_item	2353414	et	4	main
jm	doc_384045275264_item	2353418	et	4	main
kujundid	doc_384045275264_item	2353225	et	3	main
paganlikega	doc_384045275264_item	2353227	et	3	main
vahel	doc_384045275264_item	2353235	et	4	main
vahetatud	doc_384045275264_item	2353242	et	4	main
on	doc_384045275264_item	2353244	et	4	main
maagiliste	doc_384045275264_item	2353247	et	4	main
leviga	doc_384045275264_item	2353250	et	3	main
majavaim	doc_384045275264_item	2353251	et	3	main
mitte	doc_384045275264_item	2353252	et	3	main
ainult	doc_384045275264_item	2353253	et	4	main
hoiatab	doc_384045275264_item	2353254	et	3	main
hoolealuseid	doc_384045275264_item	2353256	et	4	main
variantides	doc_384045275264_item	2353230	et	3	main
palvete	doc_384045275264_item	2353233	et	3	main
on	doc_384045275264_item	2353236	et	4	main
vastu	doc_384045275264_item	2353240	et	3	main
oma	doc_384045275264_item	2353255	et	4	main
isegi	doc_384045275264_item	2353262	et	4	main
äratab	doc_384045275264_item	2353263	et	3	main
unest	doc_384045275264_item	2353264	et	3	main
välja	doc_384045275264_item	2353277	et	4	main
esimest	doc_384045275264_item	2353280	et	4	main
korda	doc_384045275264_item	2353281	et	4	main
vestelda	doc_384045275264_item	2353297	et	4	main
isegi	doc_384045275264_item	2353298	et	4	main
heaolu	doc_384045275264_item	2353303	et	4	main
teha	doc_384045275264_item	2353310	et	3	main
nii	doc_384045275264_item	2353311	et	3	main
ja	doc_384045275264_item	2353316	et	3	main
oleks	doc_384045275264_item	2353318	et	3	main
magama	doc_384045275264_item	2353269	et	3	main
ka	doc_384045275264_item	2353271	et	3	main
metsa	doc_384045275264_item	2353283	et	4	main
mindi	doc_384045275264_item	2353284	et	3	main
palvet	doc_384045275264_item	2353285	et	3	main
täiendati	doc_384045275264_item	2353286	et	4	main
puude	doc_384045275264_item	2353289	et	4	main
puukidele	doc_384045275264_item	2353301	et	3	main
leivad	doc_384045275264_item	2353317	et	3	main
on	doc_384045275264_item	2353323	et	4	main
arusaamadega	doc_384045275264_item	2353335	et	3	main
2006	doc_384045275264_item	2353351	et	2	main
kohalikud	doc_384045275264_item	2353360	et	3	main
lahkus	doc_384045275264_item	2353365	et	4	main
vihjamisi	doc_384045275264_item	2353370	et	4	main
tema	doc_384045275264_item	2353371	et	4	main
ketser	doc_384045275264_item	2353377	et	3	main
nägu	doc_384045275264_item	2353416	et	4	main
osas	doc_384045275264_item	2353420	et	4	main
kuna	doc_384045275264_item	2353427	et	3	main
kaitsja-ingel	doc_384045275264_item	2353431	et	3	main
oma	doc_384045275264_item	2353440	et	4	main
kanda	doc_384045275264_item	2353450	et	4	main
vastutuse	doc_384045275264_item	2353451	et	4	main
surnud	doc_384045275264_item	2353460	et	4	main
kolmekordselt	doc_384045275264_item	2353474	et	4	main
muidu	doc_384045275264_item	2353481	et	3	main
surnuks	doc_384045275264_item	2353484	et	4	main
pulmade	doc_384045275264_item	2353486	et	3	main
vanemad	doc_384045275264_item	2353488	et	4	main
noorpaari	doc_384045275264_item	2353490	et	4	main
ikooniga	doc_384045275264_item	2353491	et	4	main
iseloomuga	doc_384045275264_item	2353500	et	3	main
mõned	doc_384045275264_item	2353501	et	3	main
usul	doc_384045275264_item	2353503	et	3	main
esimese	doc_384045275264_item	2353504	et	3	main
vanaaastaõhtul	doc_384045275264_item	2353512	et	3	main
jumalateenistusele	doc_384045275264_item	2353517	et	3	main
minna	doc_384045275264_item	2353518	et	3	main
puhta	doc_384045275264_item	2353519	et	4	main
hingega	doc_384045275264_item	2353520	et	3	main
seas	doc_384045275264_item	2353522	et	4	main
elab	doc_384045275264_item	2353523	et	3	main
tänapäevalgi	doc_384045275264_item	2353524	et	4	main
ta	doc_384045275264_item	2353533	et	4	main
kartma	doc_384045275264_item	2353534	et	3	main
kui	doc_384045275264_item	2353544	et	3	main
teistes	doc_384045275264_item	2353545	et	4	main
asustatud	doc_384045275264_item	2353547	et	4	main
regioonides	doc_384045275264_item	2353549	et	3	main
surnute	doc_384045275264_item	2353558	et	4	main
kombetalitused	doc_384045275264_item	2353560	et	4	main
ka	doc_384045275264_item	2353563	et	3	main
seotud	doc_384045275264_item	2353565	et	4	main
valmis	doc_384045275264_item	2353572	et	4	main
komplekt	doc_384045275264_item	2353574	et	3	main
surija	doc_384045275264_item	2353575	et	4	main
ikoonide	doc_384045275264_item	2353579	et	3	main
kõik	doc_384045275264_item	2353623	et	4	main
et	doc_384045275264_item	2353631	et	3	main
nõudmisega	doc_384045275264_item	2353646	et	4	main
vead	doc_384045275264_item	2353647	et	4	main
vaja	doc_384045275264_item	2353651	et	4	main
lahkunu	doc_384045275264_item	2353653	et	4	main
üldtunnustatud	doc_384045275264_item	2353662	et	3	main
popuraarsed	doc_384045275264_item	2353670	et	4	main
on	doc_384045275264_item	2353671	et	4	main
lood	doc_384045275264_item	2353672	et	4	main
kuidas	doc_384045275264_item	2353673	et	3	main
võtta	doc_384045275264_item	2353678	et	3	main
kalmistult	doc_384045275264_item	2353681	et	3	main
tohi	doc_384045275264_item	2353683	et	4	main
surnuid	doc_384045275264_item	2353695	et	4	main
kaua	doc_384045275264_item	2353697	et	3	main
kuna	doc_384045275264_item	2353699	et	3	main
valavad	doc_384045275264_item	2353701	et	4	main
vanausuliste	doc_384045275264_item	2353706	et	4	main
matuse	doc_384045275264_item	2353707	et	3	main
palju	doc_384045275264_item	2353715	et	4	main
rikkamad	doc_384045275264_item	2353716	et	4	main
paluti	doc_384045275264_item	2353309	et	3	main
lihavõttesaiad	doc_384045275264_item	2353313	et	3	main
id	doc_384045275264_item	2353315	et	4	main
siledad	doc_384045275264_item	2353319	et	3	main
ilusad	doc_384045275264_item	2353321	et	3	main
kui	doc_384045275264_item	2353326	et	3	main
keegi	doc_384045275264_item	2353327	et	4	main
keeld	doc_384045275264_item	2353339	et	3	main
nimetada	doc_384045275264_item	2353341	et	3	main
aasta	doc_384045275264_item	2353352	et	4	main
leidu	doc_384045275264_item	2353357	et	4	main
tegusõna	doc_384045275264_item	2353358	et	4	main
surra	doc_384045275264_item	2353359	et	3	main
inimesed	doc_384045275264_item	2353361	et	3	main
ütelda	doc_384045275264_item	2353363	et	4	main
kuradit	doc_384045275264_item	2353366	et	3	main
paganat	doc_384045275264_item	2353368	et	3	main
puudutada	doc_384045275264_item	2353417	et	3	main
valdavas	doc_384045275264_item	2353419	et	4	main
püütakse	doc_384045275264_item	2353422	et	3	main
lapsele	doc_384045275264_item	2353424	et	4	main
kaitseb	doc_384045275264_item	2353432	et	4	main
paneb	doc_384045275264_item	2353438	et	3	main
tiivad	doc_384045275264_item	2353441	et	3	main
to	doc_384045275264_item	2353443	et	4	main
hakkab	doc_384045275264_item	2353445	et	3	main
võtab	doc_384045275264_item	2353447	et	3	main
ka	doc_384045275264_item	2353448	et	3	main
enda	doc_384045275264_item	2353449	et	4	main
muutub	doc_384045275264_item	2353483	et	3	main
veeks	doc_384045275264_item	2353485	et	3	main
ajal	doc_384045275264_item	2353487	et	4	main
toimingud	doc_384045275264_item	2353497	et	3	main
kaitsva	doc_384045275264_item	2353499	et	4	main
tülis	doc_384045275264_item	2353508	et	4	main
olnud	doc_384045275264_item	2353509	et	4	main
naabrid	doc_384045275264_item	2353510	et	3	main
lepivad	doc_384045275264_item	2353511	et	3	main
ei	doc_384045275264_item	2353531	et	4	main
patuta	doc_384045275264_item	2353539	et	3	main
ja	doc_384045275264_item	2353550	et	3	main
pannakse	doc_384045275264_item	2353571	et	3	main
kirst	doc_384045275264_item	2353581	et	3	main
hauda	doc_384045275264_item	2353583	et	4	main
vanema	doc_384045275264_item	2353585	et	4	main
inimesed	doc_384045275264_item	2353587	et	3	main
mäletavad	doc_384045275264_item	2353588	et	4	main
et	doc_384045275264_item	2353590	et	3	main
vanasti	doc_384045275264_item	2353591	et	3	main
hoolikalt	doc_384045275264_item	2353621	et	4	main
et	doc_384045275264_item	2353636	et	3	main
lahkunu	doc_384045275264_item	2353637	et	4	main
tülitama	doc_384045275264_item	2353639	et	3	main
kas	doc_384045275264_item	2353640	et	3	main
parandada	doc_384045275264_item	2353648	et	3	main
siis	doc_384045275264_item	2353657	et	3	main
need	doc_384045275264_item	2353659	et	3	main
panna	doc_384045275264_item	2353665	et	4	main
pudel	doc_384045275264_item	2353666	et	3	main
jm	doc_384045275264_item	2353669	et	4	main
endaga	doc_384045275264_item	2353676	et	4	main
ligistest	doc_384045275264_item	2353680	et	4	main
võtta	doc_384045275264_item	2353686	et	3	main
ср	doc_384045275264_item	2353689	et	2	main
63112	doc_384045275264_item	2353691	et	2	main
nende	doc_384045275264_item	2353702	et	4	main
surnute	doc_384045275264_item	2353709	et	4	main
kombetalitused	doc_384045275264_item	2353711	et	4	main
pihkva	doc_384045275264_item	2353725	et	4	main
haruldased	doc_384045275264_item	2353728	et	3	main
kirjapanekuid	doc_384045275264_item	2353733	et	3	main
on	doc_384045275264_item	2353735	et	4	main
jõululaupäev	doc_384045275264_item	2353748	et	3	main
kutjad	doc_384045275264_item	2353750	et	4	main
nisuterast	doc_384045275264_item	2353751	et	4	main
valmistatud	doc_384045275264_item	2353752	et	4	main
puder	doc_384045275264_item	2353753	et	3	main
arvavad	doc_384045275264_item	2353764	et	4	main
et	doc_384045275264_item	2353765	et	3	main
kadunud	doc_384045275264_item	2353766	et	4	main
kaitsevad	doc_384045275264_item	2353774	et	4	main
roppude	doc_384045275264_item	2353328	et	4	main
sõnadega	doc_384045275264_item	2353329	et	3	main
sõimab	doc_384045275264_item	2353330	et	3	main
järv	doc_384045275264_item	2353332	et	3	main
seotud	doc_384045275264_item	2353337	et	4	main
varjatud	doc_384045275264_item	2353338	et	4	main
valjusti	doc_384045275264_item	2353340	et	3	main
haigusi	doc_384045275264_item	2353344	et	4	main
jm	doc_384045275264_item	2353345	et	4	main
nimele	doc_384045275264_item	2353350	et	3	main
kirjapanekutes	doc_384045275264_item	2353353	et	3	main
eeslistavad	doc_384045275264_item	2353362	et	4	main
vaenlane	doc_384045275264_item	2353373	et	3	main
rahva	doc_384045275264_item	2353382	et	3	main
kultuuri	doc_384045275264_item	2353384	et	4	main
kihtide	doc_384045275264_item	2353385	et	3	main
vastastikune	doc_384045275264_item	2353386	et	4	main
toime	doc_384045275264_item	2353387	et	4	main
perekonnatavades	doc_384045275264_item	2353388	et	3	main
ääretult	doc_384045275264_item	2353389	et	4	main
rikas	doc_384045275264_item	2353390	et	4	main
naise	doc_384045275264_item	2353392	et	3	main
rasedusajaga	doc_384045275264_item	2353393	et	3	main
on	doc_384045275264_item	2353391	et	4	main
seotud	doc_384045275264_item	2353394	et	4	main
uskumuste	doc_384045275264_item	2353395	et	4	main
ja	doc_384045275264_item	2353396	et	3	main
keelude	doc_384045275264_item	2353397	et	3	main
tsükkel	doc_384045275264_item	2353398	et	3	main
tulevase	doc_384045275264_item	2353399	et	4	main
emale	doc_384045275264_item	2353400	et	3	main
ei	doc_384045275264_item	2353401	et	4	main
tohi	doc_384045275264_item	2353402	et	4	main
milleski	doc_384045275264_item	2353403	et	4	main
ära	doc_384045275264_item	2353404	et	4	main
ütelda	doc_384045275264_item	2353405	et	4	main
tulevane	doc_384045275264_item	2353406	et	3	main
ema	doc_384045275264_item	2353407	et	4	main
peab	doc_384045275264_item	2353408	et	4	main
vältima	doc_384045275264_item	2353409	et	3	main
stressisituatsioone	doc_384045275264_item	2353410	et	3	main
ei	doc_384045275264_item	2353411	et	4	main
tohi	doc_384045275264_item	2353412	et	4	main
ta	doc_384045275264_item	2353413	et	4	main
seadusi	doc_384045275264_item	2353426	et	3	main
on	doc_384045275264_item	2353428	et	4	main
vältel	doc_384045275264_item	2353437	et	4	main
kukuma	doc_384045275264_item	2353444	et	4	main
vahel	doc_384045275264_item	2353446	et	4	main
eest	doc_384045275264_item	2353454	et	4	main
pärinev	doc_384045275264_item	2353456	et	4	main
elavast	doc_384045275264_item	2353458	et	4	main
veest	doc_384045275264_item	2353461	et	4	main
on	doc_384045275264_item	2353462	et	4	main
rudimentses	doc_384045275264_item	2353463	et	4	main
vormis	doc_384045275264_item	2353464	et	4	main
säilinud	doc_384045275264_item	2353465	et	4	main
lapse	doc_384045275264_item	2353466	et	4	main
ristimise	doc_384045275264_item	2353467	et	4	main
talituses	doc_384045275264_item	2353468	et	4	main
vett	doc_384045275264_item	2353469	et	3	main
kuhu	doc_384045275264_item	2353470	et	3	main
ristimise	doc_384045275264_item	2353472	et	4	main
ajal	doc_384045275264_item	2353473	et	4	main
last	doc_384045275264_item	2353471	et	4	main
peredest	doc_384045275264_item	2353421	et	3	main
veendutud	doc_384045275264_item	2353429	et	4	main
et	doc_384045275264_item	2353430	et	3	main
oma	doc_384045275264_item	2353433	et	4	main
terve	doc_384045275264_item	2353435	et	4	main
alla	doc_384045275264_item	2353439	et	3	main
kui	doc_384045275264_item	2353442	et	3	main
väärteo	doc_384045275264_item	2353453	et	4	main
võlumuinasjuttudest	doc_384045275264_item	2353455	et	3	main
arusaam	doc_384045275264_item	2353457	et	3	main
ja	doc_384045275264_item	2353459	et	3	main
sisse	doc_384045275264_item	2353476	et	4	main
õnnistavad	doc_384045275264_item	2353489	et	4	main
on	doc_384045275264_item	2353498	et	4	main
baseeruvad	doc_384045275264_item	2353502	et	4	main
maagiasse	doc_384045275264_item	2353506	et	4	main
uskumus	doc_384045275264_item	2353525	et	3	main
kui	doc_384045275264_item	2353526	et	3	main
ema	doc_384045275264_item	2353527	et	4	main
süles	doc_384045275264_item	2353529	et	3	main
kuradite	doc_384045275264_item	2353535	et	3	main
salasepitsusi	doc_384045275264_item	2353536	et	3	main
neid	doc_384045275264_item	2353537	et	4	main
neitraliseerib	doc_384045275264_item	2353538	et	4	main
vanausulistega	doc_384045275264_item	2353546	et	4	main
kõige	doc_384045275264_item	2353553	et	4	main
ja	doc_384045275264_item	2353557	et	3	main
mütoloogilised	doc_384045275264_item	2353566	et	4	main
muistendid	doc_384045275264_item	2353567	et	3	main
terve	doc_384045275264_item	2353573	et	4	main
pannakse	doc_384045275264_item	2353576	et	3	main
põrandale	doc_384045275264_item	2353577	et	3	main
näoga	doc_384045275264_item	2353578	et	3	main
poole	doc_384045275264_item	2353580	et	4	main
talitused	doc_384045275264_item	2353624	et	4	main
selleni	doc_384045275264_item	2353635	et	3	main
või	doc_384045275264_item	2353642	et	4	main
on	doc_384045275264_item	2353650	et	4	main
täita	doc_384045275264_item	2353652	et	4	main
viimased	doc_384045275264_item	2353654	et	3	main
soovid	doc_384045275264_item	2353655	et	4	main
kui	doc_384045275264_item	2353658	et	3	main
surnud	doc_384045275264_item	2353674	et	4	main
midagi	doc_384045275264_item	2353684	et	4	main
küünlajuppi	doc_384045275264_item	2353688	et	4	main
заветы	doc_384045275264_item	2353690	et	2	main
soovitatav	doc_384045275264_item	2353694	et	4	main
pisarad	doc_384045275264_item	2353700	et	3	main
ja	doc_384045275264_item	2353708	et	3	main
tavandid	doc_384045275264_item	2353713	et	3	main
ja	doc_384045275264_item	2353717	et	3	main
on	doc_384045275264_item	2353721	et	4	main
venemaal	doc_384045275264_item	2353724	et	4	main
täiendavad	doc_384045275264_item	2353732	et	4	main
ja	doc_384045275264_item	2353738	et	3	main
vanausuliste	doc_384045275264_item	2353740	et	4	main
kogukondades	doc_384045275264_item	2353741	et	3	main
kohalikud	doc_384045275264_item	2353742	et	3	main
hästi	doc_384045275264_item	2353745	et	3	main
pannakse	doc_384045275264_item	2353757	et	3	main
matustel	doc_384045275264_item	2353759	et	3	main
omaste	doc_384045275264_item	2353771	et	4	main
elu	doc_384045275264_item	2353773	et	4	main
neid	doc_384045275264_item	2353775	et	4	main
vastumeelsed	doc_384045275264_item	2353785	et	3	main
siis	doc_384045275264_item	2353787	et	3	main
keldrisse	doc_384045275264_item	2353795	et	3	main
maagilist	doc_384045275264_item	2353797	et	4	main
omistati	doc_384045275264_item	2353799	et	3	main
nüüd	doc_384045275264_item	2353822	et	4	main
kuul	doc_384045275264_item	2353824	et	4	main
võta	doc_384045275264_item	2353827	et	4	main
päästa	doc_384045275264_item	2353831	et	4	main
mulla	doc_384045275264_item	2353838	et	4	main
sisse	doc_384045275264_item	2353839	et	4	main
üldreeglina	doc_384045275264_item	2353841	et	3	main
maetakse	doc_384045275264_item	2353842	et	3	main
kalmistu	doc_384045275264_item	2353843	et	4	main
ei	doc_384045275264_item	2353849	et	4	main
soovitatav	doc_384045275264_item	2353851	et	4	main
läbi	doc_384045275264_item	2353853	et	4	main
täielikult	doc_384045275264_item	2353475	et	4	main
et	doc_384045275264_item	2353478	et	3	main
soendada	doc_384045275264_item	2353480	et	3	main
puistavad	doc_384045275264_item	2353492	et	4	main
üle	doc_384045275264_item	2353493	et	3	main
rituaalsed	doc_384045275264_item	2353496	et	3	main
päeva	doc_384045275264_item	2353505	et	4	main
näiteks	doc_384045275264_item	2353507	et	4	main
ära	doc_384045275264_item	2353513	et	4	main
et	doc_384045275264_item	2353515	et	3	main
viljateradega	doc_384045275264_item	2353494	et	3	main
mõned	doc_384045275264_item	2353495	et	3	main
selleks	doc_384045275264_item	2353514	et	4	main
kirikusse	doc_384045275264_item	2353516	et	4	main
vanausuliste	doc_384045275264_item	2353521	et	4	main
pea	doc_384045275264_item	2353532	et	4	main
laps	doc_384045275264_item	2353540	et	4	main
peipsi	doc_384045275264_item	2353541	et	4	main
läänerannikul	doc_384045275264_item	2353542	et	3	main
samuti	doc_384045275264_item	2353543	et	3	main
valgevenes	doc_384045275264_item	2353552	et	3	main
püsivamaks	doc_384045275264_item	2353554	et	4	main
matuse	doc_384045275264_item	2353556	et	3	main
mälestamise	doc_384045275264_item	2353559	et	4	main
tavandid	doc_384045275264_item	2353562	et	3	main
sellega	doc_384045275264_item	2353564	et	3	main
aegsasti	doc_384045275264_item	2353568	et	3	main
suririided	doc_384045275264_item	2353570	et	3	main
lastakse	doc_384045275264_item	2353582	et	3	main
rättidel	doc_384045275264_item	2353584	et	3	main
põlvkonna	doc_384045275264_item	2353586	et	4	main
rääkida	doc_384045275264_item	2353589	et	3	main
oleks	doc_384045275264_item	2353625	et	3	main
vanade	doc_384045275264_item	2353627	et	3	main
järgi	doc_384045275264_item	2353629	et	4	main
viib	doc_384045275264_item	2353634	et	3	main
hakkab	doc_384045275264_item	2353638	et	3	main
ilmsi	doc_384045275264_item	2353643	et	3	main
isegi	doc_384045275264_item	2353656	et	4	main
lähvad	doc_384045275264_item	2353660	et	4	main
lahku	doc_384045275264_item	2353661	et	4	main
kõlbluskaanonitega	doc_384045275264_item	2353663	et	3	main
sigaretid	doc_384045275264_item	2353668	et	3	main
kaasa	doc_384045275264_item	2353677	et	4	main
ei	doc_384045275264_item	2353682	et	4	main
isegi	doc_384045275264_item	2353687	et	4	main
ole	doc_384045275264_item	2353693	et	4	main
taganutta	doc_384045275264_item	2353698	et	4	main
kirstud	doc_384045275264_item	2353703	et	3	main
üle	doc_384045275264_item	2353704	et	3	main
mälestamise	doc_384045275264_item	2353710	et	4	main
ja	doc_384045275264_item	2353712	et	3	main
on	doc_384045275264_item	2353714	et	4	main
idarannikul	doc_384045275264_item	2353723	et	3	main
mõned	doc_384045275264_item	2353727	et	3	main
ja	doc_384045275264_item	2353730	et	3	main
leedu	doc_384045275264_item	2353739	et	4	main
teavad	doc_384045275264_item	2353744	et	3	main
kuid	doc_384045275264_item	2353749	et	4	main
kohalikud	doc_384045275264_item	2353762	et	3	main
vanausulised	doc_384045275264_item	2353763	et	4	main
elavate	doc_384045275264_item	2353770	et	4	main
eest	doc_384045275264_item	2353777	et	4	main
kuid	doc_384045275264_item	2353778	et	4	main
näed	doc_384045275264_item	2353788	et	3	main
erilist	doc_384045275264_item	2353796	et	4	main
ei	doc_384045275264_item	2353826	et	4	main
hammustusest	doc_384045275264_item	2353829	et	4	main
kahjustatud	doc_384045275264_item	2353834	et	4	main
käe	doc_384045275264_item	2353835	et	3	main
kehaga	doc_384045275264_item	2353848	et	3	main
viia	doc_384045275264_item	2353852	et	3	main
kätel	doc_384045275264_item	2353859	et	3	main
ei	doc_384045275264_item	2353868	et	4	main
tohi	doc_384045275264_item	2353869	et	4	main
päikese	doc_384045275264_item	2353873	et	4	main
lahkunu	doc_384045275264_item	2353876	et	4	main
saatma	doc_384045275264_item	2353880	et	3	main
väravad	doc_384045275264_item	2353884	et	3	main
on	doc_384045275264_item	2353888	et	4	main
ootama	doc_384045275264_item	2353894	et	3	main
ilma	doc_384045275264_item	2353899	et	4	main
materjalid	doc_384045275264_item	2353921	et	3	main
tavaliste	doc_384045275264_item	2353923	et	4	main
levikut	doc_384045275264_item	2353925	et	3	main
ka	doc_384045275264_item	2353927	et	3	main
näeb	doc_384045275264_item	2353944	et	3	main
ilmas	doc_384045275264_item	2353955	et	4	main
vaipadega	doc_384045275264_item	2353969	et	3	main
kus	doc_384045275264_item	2353973	et	3	main
ilmas	doc_384045275264_item	2353983	et	4	main
hoiab	doc_384045275264_item	2353528	et	3	main
väikelast	doc_384045275264_item	2353530	et	4	main
baltimaade	doc_384045275264_item	2353548	et	3	main
edela	doc_384045275264_item	2353551	et	3	main
osutusid	doc_384045275264_item	2353555	et	4	main
ja	doc_384045275264_item	2353561	et	3	main
õmmeldakse	doc_384045275264_item	2353569	et	3	main
hauaristid	doc_384045275264_item	2353592	et	4	main
olid	doc_384045275264_item	2353593	et	4	main
ikka	doc_384045275264_item	2353594	et	4	main
puust	doc_384045275264_item	2353595	et	4	main
teises	doc_384045275264_item	2353596	et	4	main
ilmas	doc_384045275264_item	2353597	et	4	main
tuleb	doc_384045275264_item	2353598	et	3	main
igaühel	doc_384045275264_item	2353599	et	3	main
oma	doc_384045275264_item	2353600	et	4	main
risti	doc_384045275264_item	2353601	et	4	main
kanda	doc_384045275264_item	2353602	et	4	main
aegsasti	doc_384045275264_item	2353603	et	3	main
valmistati	doc_384045275264_item	2353604	et	4	main
ette	doc_384045275264_item	2353605	et	4	main
ka	doc_384045275264_item	2353606	et	3	main
kirst	doc_384045275264_item	2353607	et	3	main
täideti	doc_384045275264_item	2353608	et	3	main
see	doc_384045275264_item	2353609	et	3	main
viljateraga	doc_384045275264_item	2353610	et	3	main
veendumuste	doc_384045275264_item	2353611	et	4	main
järgi	doc_384045275264_item	2353612	et	4	main
lahkunu	doc_384045275264_item	2353613	et	4	main
hing	doc_384045275264_item	2353614	et	3	main
nelikümmend	doc_384045275264_item	2353615	et	4	main
päeva	doc_384045275264_item	2353616	et	4	main
nähtamatult	doc_384045275264_item	2353617	et	4	main
hõljub	doc_384045275264_item	2353618	et	3	main
kodukülas	doc_384045275264_item	2353619	et	3	main
jälgides	doc_384045275264_item	2353620	et	4	main
et	doc_384045275264_item	2353622	et	3	main
toimetatud	doc_384045275264_item	2353626	et	4	main
tavade	doc_384045275264_item	2353628	et	3	main
usutakse	doc_384045275264_item	2353630	et	4	main
väikenegi	doc_384045275264_item	2353632	et	4	main
kõrvalekaldumine	doc_384045275264_item	2353633	et	3	main
unes	doc_384045275264_item	2353641	et	3	main
oma	doc_384045275264_item	2353644	et	4	main
ligidasi	doc_384045275264_item	2353645	et	3	main
tingimata	doc_384045275264_item	2353649	et	4	main
kirstu	doc_384045275264_item	2353664	et	4	main
viina	doc_384045275264_item	2353667	et	4	main
püüavad	doc_384045275264_item	2353675	et	3	main
kedagi	doc_384045275264_item	2353679	et	4	main
kaasa	doc_384045275264_item	2353685	et	4	main
ei	doc_384045275264_item	2353692	et	4	main
liiga	doc_384045275264_item	2353696	et	4	main
eesti	doc_384045275264_item	2353705	et	4	main
arhhailisemad	doc_384045275264_item	2353718	et	4	main
kui	doc_384045275264_item	2353719	et	3	main
need	doc_384045275264_item	2353720	et	3	main
uskumused	doc_384045275264_item	2353729	et	3	main
tavandid	doc_384045275264_item	2353731	et	3	main
läti	doc_384045275264_item	2353737	et	4	main
sõna	doc_384045275264_item	2353746	et	4	main
meega	doc_384045275264_item	2353754	et	3	main
siinkandis	doc_384045275264_item	2353755	et	3	main
sugulaste	doc_384045275264_item	2353767	et	4	main
hinged	doc_384045275264_item	2353768	et	3	main
maiset	doc_384045275264_item	2353772	et	4	main
hingedele	doc_384045275264_item	2353784	et	3	main
tuled	doc_384045275264_item	2353786	et	4	main
ise	doc_384045275264_item	2353789	et	4	main
vesi	doc_384045275264_item	2353790	et	4	main
millega	doc_384045275264_item	2353791	et	3	main
surnut	doc_384045275264_item	2353792	et	4	main
jõudu	doc_384045275264_item	2353798	et	4	main
mille	doc_384045275264_item	2353801	et	3	main
abil	doc_384045275264_item	2353802	et	4	main
üksk	doc_384045275264_item	2353823	et	4	main
ussi	doc_384045275264_item	2353828	et	4	main
võib	doc_384045275264_item	2353830	et	3	main
pistes	doc_384045275264_item	2353832	et	4	main
enesetapjaid	doc_384045275264_item	2353840	et	3	main
nurgas	doc_384045275264_item	2353845	et	3	main
üle	doc_384045275264_item	2353860	et	3	main
aia	doc_384045275264_item	2353861	et	4	main
kuna	doc_384045275264_item	2353875	et	3	main
kui	doc_384045275264_item	2353882	et	3	main
surnuaia	doc_384045275264_item	2353883	et	4	main
selle	doc_384045275264_item	2353885	et	4	main
ajaga	doc_384045275264_item	2353886	et	3	main
suletud	doc_384045275264_item	2353887	et	4	main
värava	doc_384045275264_item	2353892	et	3	main
taga	doc_384045275264_item	2353893	et	4	main
muistendites	doc_384045275264_item	2353896	et	3	main
analoogina	doc_384045275264_item	2353900	et	3	main
peipsi	doc_384045275264_item	2353722	et	4	main
kandis	doc_384045275264_item	2353726	et	4	main
mis	doc_384045275264_item	2353734	et	4	main
tehtud	doc_384045275264_item	2353736	et	4	main
elanikud	doc_384045275264_item	2353743	et	3	main
kuteinik	doc_384045275264_item	2353747	et	4	main
lauale	doc_384045275264_item	2353756	et	4	main
ainult	doc_384045275264_item	2353758	et	4	main
ja	doc_384045275264_item	2353760	et	3	main
peietel	doc_384045275264_item	2353761	et	3	main
jälgivad	doc_384045275264_item	2353769	et	4	main
jutud	doc_384045275264_item	2353779	et	3	main
nende	doc_384045275264_item	2353780	et	4	main
hauatagusest	doc_384045275264_item	2353781	et	3	main
elust	doc_384045275264_item	2353782	et	3	main
valati	doc_384045275264_item	2353794	et	3	main
seebile	doc_384045275264_item	2353800	et	3	main
kadunu	doc_384045275264_item	2353803	et	4	main
matusteks	doc_384045275264_item	2353804	et	3	main
ette	doc_384045275264_item	2353805	et	4	main
valmistati	doc_384045275264_item	2353806	et	4	main
teise	doc_384045275264_item	2353807	et	4	main
maailma	doc_384045275264_item	2353808	et	4	main
sõja	doc_384045275264_item	2353809	et	3	main
ajal	doc_384045275264_item	2353810	et	4	main
üks	doc_384045275264_item	2353811	et	3	main
naine	doc_384045275264_item	2353812	et	3	main
sundis	doc_384045275264_item	2353813	et	3	main
oma	doc_384045275264_item	2353814	et	4	main
poega	doc_384045275264_item	2353815	et	4	main
pesta	doc_384045275264_item	2353816	et	4	main
end	doc_384045275264_item	2353817	et	4	main
sellise	doc_384045275264_item	2353818	et	4	main
seebiga	doc_384045275264_item	2353819	et	3	main
veendumuse	doc_384045275264_item	2353820	et	4	main
teda	doc_384045275264_item	2353825	et	4	main
ruttu	doc_384045275264_item	2353833	et	4	main
jala	doc_384045275264_item	2353837	et	4	main
ole	doc_384045275264_item	2353850	et	4	main
enesetapja	doc_384045275264_item	2353863	et	4	main
loojangut	doc_384045275264_item	2353874	et	3	main
sugulasi	doc_384045275264_item	2353879	et	3	main
peab	doc_384045275264_item	2353889	et	4	main
teist	doc_384045275264_item	2353898	et	4	main
pärast	doc_384045275264_item	2353933	et	4	main
õde	doc_384045275264_item	2353943	et	4	main
unes	doc_384045275264_item	2353946	et	3	main
venda	doc_384045275264_item	2353948	et	4	main
arsenid	doc_384045275264_item	2353949	et	4	main
otsimas	doc_384045275264_item	2353950	et	4	main
ja	doc_384045275264_item	2353951	et	3	main
avastab	doc_384045275264_item	2353952	et	3	main
et	doc_384045275264_item	2353953	et	3	main
seal	doc_384045275264_item	2353954	et	4	main
kaetud	doc_384045275264_item	2353971	et	4	main
igal	doc_384045275264_item	2353974	et	3	main
surnud	doc_384045275264_item	2353979	et	4	main
pimedad	doc_384045275264_item	2353984	et	3	main
näevad	doc_384045275264_item	2353985	et	3	main
ja	doc_384045275264_item	2353994	et	3	main
bõliškad	doc_384045275264_item	2353999	et	2	main
tsükklis	doc_384045275264_item	2354000	et	4	main
kadunukest	doc_384045275264_item	2354002	et	4	main
läänerannikul	doc_384045275264_item	2354004	et	3	main
kuju	doc_384045275264_item	2354019	et	4	main
õnnetuste	doc_384045275264_item	2353776	et	4	main
on	doc_384045275264_item	2353783	et	4	main
pesti	doc_384045275264_item	2353793	et	3	main
et	doc_384045275264_item	2353821	et	3	main
või	doc_384045275264_item	2353836	et	4	main
põhjapoolses	doc_384045275264_item	2353844	et	3	main
kirstu	doc_384045275264_item	2353846	et	4	main
enesetapja	doc_384045275264_item	2353847	et	4	main
vanasti	doc_384045275264_item	2353862	et	3	main
ei	doc_384045275264_item	2353865	et	4	main
pandud	doc_384045275264_item	2353866	et	4	main
risti	doc_384045275264_item	2353867	et	4	main
minna	doc_384045275264_item	2353878	et	3	main
ja	doc_384045275264_item	2353881	et	3	main
mütoloogilistes	doc_384045275264_item	2353895	et	4	main
maise	doc_384045275264_item	2353901	et	4	main
ilmaga	doc_384045275264_item	2353902	et	3	main
surnud	doc_384045275264_item	2353903	et	4	main
tegelevad	doc_384045275264_item	2353904	et	4	main
seal	doc_384045275264_item	2353905	et	4	main
sama	doc_384045275264_item	2353906	et	4	main
asjadega	doc_384045275264_item	2353907	et	3	main
mis	doc_384045275264_item	2353908	et	4	main
oma	doc_384045275264_item	2353909	et	4	main
maise	doc_384045275264_item	2353910	et	4	main
elu	doc_384045275264_item	2353911	et	4	main
ajal	doc_384045275264_item	2353912	et	4	main
käivad	doc_384045275264_item	2353913	et	4	main
külla	doc_384045275264_item	2353914	et	4	main
üks	doc_384045275264_item	2353915	et	3	main
teise	doc_384045275264_item	2353916	et	4	main
juurde	doc_384045275264_item	2353917	et	4	main
jm	doc_384045275264_item	2353918	et	4	main
peipsimaal	doc_384045275264_item	2353919	et	4	main
kogutud	doc_384045275264_item	2353920	et	4	main
muistendite	doc_384045275264_item	2353924	et	3	main
inimese	doc_384045275264_item	2353931	et	4	main
staatus	doc_384045275264_item	2353932	et	3	main
surma	doc_384045275264_item	2353934	et	4	main
muutub	doc_384045275264_item	2353935	et	3	main
ennast	doc_384045275264_item	2353945	et	4	main
oma	doc_384045275264_item	2353947	et	4	main
on	doc_384045275264_item	2353956	et	4	main
tema	doc_384045275264_item	2353957	et	4	main
vennast	doc_384045275264_item	2353958	et	4	main
seinad	doc_384045275264_item	2353970	et	3	main
kahhelplaatidega	doc_384045275264_item	2353972	et	3	main
on	doc_384045275264_item	2353981	et	4	main
siis	doc_384045275264_item	2353988	et	3	main
üheagselt	doc_384045275264_item	2353991	et	4	main
paistab	doc_384045275264_item	2353992	et	3	main
väikeste	doc_384045275264_item	2353997	et	4	main
reegioonides	doc_384045275264_item	2354008	et	4	main
süžeed	doc_384045275264_item	2354010	et	2	main
enesetapjatest	doc_384045275264_item	2354011	et	4	main
või	doc_384045275264_item	2354012	et	4	main
siga	doc_384045275264_item	2354041	et	4	main
olend	doc_384045275264_item	2354044	et	3	main
paadis	doc_384045275264_item	2354045	et	3	main
silmadega	doc_384045275264_item	2354047	et	3	main
mees	doc_384045275264_item	2354049	et	4	main
ühe	doc_384045275264_item	2354051	et	4	main
rattaga	doc_384045275264_item	2354052	et	3	main
vankri	doc_384045275264_item	2354053	et	3	main
peal	doc_384045275264_item	2354054	et	4	main
surnuaia	doc_384045275264_item	2353854	et	4	main
värava	doc_384045275264_item	2353855	et	3	main
tavaliselt	doc_384045275264_item	2353856	et	4	main
see	doc_384045275264_item	2353857	et	3	main
tõstetakse	doc_384045275264_item	2353858	et	4	main
hauale	doc_384045275264_item	2353864	et	3	main
käia	doc_384045275264_item	2353870	et	4	main
hauale	doc_384045275264_item	2353871	et	3	main
pärast	doc_384045275264_item	2353872	et	4	main
võib	doc_384045275264_item	2353877	et	3	main
ta	doc_384045275264_item	2353890	et	4	main
hommikuni	doc_384045275264_item	2353891	et	4	main
kujutatakse	doc_384045275264_item	2353897	et	3	main
selliseid	doc_384045275264_item	2353928	et	4	main
muistendeid	doc_384045275264_item	2353929	et	3	main
kus	doc_384045275264_item	2353930	et	3	main
näitlik	doc_384045275264_item	2353936	et	3	main
on	doc_384045275264_item	2353937	et	4	main
üks	doc_384045275264_item	2353942	et	3	main
vürst	doc_384045275264_item	2353960	et	3	main
kes	doc_384045275264_item	2353962	et	4	main
uhkes	doc_384045275264_item	2353966	et	4	main
korteris	doc_384045275264_item	2353967	et	3	main
kahhelplaadil	doc_384045275264_item	2353975	et	3	main
lilleke	doc_384045275264_item	2353977	et	4	main
nad	doc_384045275264_item	2353986	et	3	main
sajab	doc_384045275264_item	2353995	et	3	main
ka	doc_384045275264_item	2354006	et	3	main
kuraditest	doc_384045275264_item	2354013	et	4	main
kes	doc_384045275264_item	2354014	et	4	main
endale	doc_384045275264_item	2354016	et	4	main
kellegi	doc_384045275264_item	2354017	et	4	main
sugulase	doc_384045275264_item	2354018	et	3	main
ja	doc_384045275264_item	2354029	et	3	main
kuradid	doc_384045275264_item	2354032	et	3	main
jälitab	doc_384045275264_item	2354038	et	3	main
punaste	doc_384045275264_item	2354039	et	4	main
viirastub	doc_384045275264_item	2354042	et	3	main
kitsetaoline	doc_384045275264_item	2354043	et	3	main
sabaga	doc_384045275264_item	2354048	et	3	main
sõidab	doc_384045275264_item	2354050	et	3	main
muud	doc_384045275264_item	2354058	et	4	main
temaatilised	doc_384045275264_item	2354059	et	4	main
esitatud	doc_384045275264_item	2354064	et	4	main
ainult	doc_384045275264_item	2354074	et	4	main
kaudselt	doc_384045275264_item	2354075	et	4	main
äranõiutud	doc_384045275264_item	2354084	et	4	main
nõiaraamatute	doc_384045275264_item	2354086	et	3	main
teadmiste	doc_384045275264_item	2354090	et	4	main
inimestele	doc_384045275264_item	2354092	et	3	main
raamistiku	doc_384045275264_item	2354121	et	4	main
repertuaar	doc_384045275264_item	2354126	et	3	main
seal	doc_384045275264_item	2354132	et	4	main
kirjelduses	doc_384045275264_item	2354142	et	4	main
panid	doc_384045275264_item	2354151	et	4	main
alla	doc_384045275264_item	2354153	et	3	main
oma	doc_384045275264_item	2354154	et	4	main
juuksekamme	doc_384045275264_item	2354155	et	3	main
kaeve	doc_384045275264_item	2354157	et	4	main
näha	doc_384045275264_item	2354173	et	3	main
poolt	doc_384045275264_item	2354175	et	4	main
või	doc_384045275264_item	2354183	et	4	main
ka	doc_384045275264_item	2354189	et	3	main
muid	doc_384045275264_item	2354190	et	4	main
viise	doc_384045275264_item	2354192	et	3	main
toovad	doc_384045275264_item	2354229	et	4	main
в	doc_384045275264_item	2354231	et	2	main
иногда	doc_384045275264_item	2354235	et	2	main
маккавея	doc_384045275264_item	2354241	et	2	main
vahest	doc_384045275264_item	2354243	et	4	main
püüdsid	doc_384045275264_item	2354248	et	4	main
lükata	doc_384045275264_item	2354249	et	4	main
lapsi	doc_384045275264_item	2354258	et	4	main
külma	doc_384045275264_item	2354292	et	4	main
kivi	doc_384045275264_item	2354293	et	4	main
visanud	doc_384045275264_item	2354294	et	4	main
pühi	doc_384045275264_item	2354298	et	4	main
peipsimaal	doc_384045275264_item	2354300	et	4	main
ja	doc_384045275264_item	2354302	et	3	main
lõbusalt	doc_384045275264_item	2354303	et	4	main
kodukirikupühadel	doc_384045275264_item	2354304	et	3	main
tõestavad	doc_384045275264_item	2353922	et	4	main
on	doc_384045275264_item	2353926	et	4	main
selle	doc_384045275264_item	2353938	et	4	main
poolest	doc_384045275264_item	2353939	et	4	main
lugu	doc_384045275264_item	2353940	et	4	main
kus	doc_384045275264_item	2353941	et	3	main
saanud	doc_384045275264_item	2353959	et	4	main
aleksandr	doc_384045275264_item	2353961	et	4	main
töötab	doc_384045275264_item	2353963	et	3	main
kuskilgi	doc_384045275264_item	2353964	et	4	main
elab	doc_384045275264_item	2353965	et	3	main
televiisoriga	doc_384045275264_item	2353968	et	3	main
helesinine	doc_384045275264_item	2353976	et	4	main
ristimatta	doc_384045275264_item	2353978	et	4	main
väikelapsed	doc_384045275264_item	2353980	et	3	main
teises	doc_384045275264_item	2353982	et	4	main
ainult	doc_384045275264_item	2353987	et	4	main
maapeal	doc_384045275264_item	2353990	et	3	main
päike	doc_384045275264_item	2353993	et	3	main
vihma	doc_384045275264_item	2353996	et	4	main
peipsi	doc_384045275264_item	2354003	et	4	main
teistes	doc_384045275264_item	2354007	et	4	main
domineerivad	doc_384045275264_item	2354009	et	4	main
vaimu	doc_384045275264_item	2354021	et	4	main
on	doc_384045275264_item	2354023	et	4	main
seotud	doc_384045275264_item	2354024	et	4	main
ka	doc_384045275264_item	2354025	et	3	main
paljud	doc_384045275264_item	2354026	et	3	main
hirmudest	doc_384045275264_item	2354030	et	3	main
teevad	doc_384045275264_item	2354033	et	3	main
veskis	doc_384045275264_item	2354036	et	3	main
inimest	doc_384045275264_item	2354037	et	3	main
silmadega	doc_384045275264_item	2354040	et	3	main
suhteliselt	doc_384045275264_item	2354065	et	4	main
jutte	doc_384045275264_item	2354079	et	3	main
koduloomadest	doc_384045275264_item	2354085	et	3	main
abil	doc_384045275264_item	2354087	et	4	main
saatanlike	doc_384045275264_item	2354089	et	3	main
teinud	doc_384045275264_item	2354095	et	4	main
nõia	doc_384045275264_item	2354096	et	3	main
posijate	doc_384045275264_item	2354123	et	4	main
üpris	doc_384045275264_item	2354129	et	3	main
palju	doc_384045275264_item	2354136	et	4	main
etnograafilisi	doc_384045275264_item	2354138	et	4	main
neiud	doc_384045275264_item	2354145	et	4	main
esimesele	doc_384045275264_item	2354165	et	3	main
kohatud	doc_384045275264_item	2354167	et	4	main
püüti	doc_384045275264_item	2354172	et	3	main
on	doc_384045275264_item	2354185	et	4	main
tulevane	doc_384045275264_item	2354186	et	3	main
usuti	doc_384045275264_item	2354221	et	3	main
siis	doc_384045275264_item	2354223	et	3	main
ja	doc_384045275264_item	2354227	et	3	main
piima	doc_384045275264_item	2354228	et	4	main
день	doc_384045275264_item	2354233	et	2	main
купалу	doc_384045275264_item	2354238	et	2	main
seitsevennapäeval	doc_384045275264_item	2354244	et	3	main
selle	doc_384045275264_item	2354259	et	4	main
mis	doc_384045275264_item	2354261	et	4	main
viitab	doc_384045275264_item	2354263	et	3	main
ära	doc_384045275264_item	2354330	et	4	main
piirissaare	doc_384045275264_item	2354332	et	3	main
petrovki	doc_384045275264_item	2354336	et	4	main
siia	doc_384045275264_item	2354338	et	4	main
kutsimattagi	doc_384045275264_item	2354340	et	4	main
lemmikpüha	doc_384045275264_item	2354343	et	4	main
lõbusa	doc_384045275264_item	2354346	et	3	main
pannkookide	doc_384045275264_item	2354349	et	3	main
ja	doc_384045275264_item	2354352	et	3	main
kindlasti	doc_384045275264_item	2354353	et	3	main
järgi	doc_384045275264_item	2354364	et	4	main
sellel	doc_384045275264_item	2354365	et	4	main
päeval	doc_384045275264_item	2354366	et	3	main
tembud	doc_384045275264_item	2354371	et	3	main
nooruses	doc_384045275264_item	2354379	et	4	main
üle	doc_384045275264_item	2354383	et	3	main
visatud	doc_384045275264_item	2354386	et	4	main
olles	doc_384045275264_item	2354394	et	3	main
kui	doc_384045275264_item	2353989	et	3	main
rahvajuttude	doc_384045275264_item	2353998	et	4	main
rändavatest	doc_384045275264_item	2354001	et	4	main
nagu	doc_384045275264_item	2354005	et	3	main
võtnud	doc_384045275264_item	2354015	et	4	main
kurja	doc_384045275264_item	2354020	et	4	main
vaimudest	doc_384045275264_item	2354028	et	3	main
öösiti	doc_384045275264_item	2354031	et	4	main
mahajäätud	doc_384045275264_item	2354035	et	4	main
põlevate	doc_384045275264_item	2354046	et	4	main
jm	doc_384045275264_item	2354055	et	4	main
mütoloogiliste	doc_384045275264_item	2354056	et	4	main
muistendite	doc_384045275264_item	2354057	et	3	main
gruppid	doc_384045275264_item	2354060	et	4	main
on	doc_384045275264_item	2354061	et	4	main
vähe	doc_384045275264_item	2354066	et	3	main
ainult	doc_384045275264_item	2354067	et	4	main
kaks-kolm	doc_384045275264_item	2354068	et	3	main
inimest	doc_384045275264_item	2354069	et	3	main
rääkisid	doc_384045275264_item	2354070	et	4	main
kuid	doc_384045275264_item	2354072	et	4	main
nemadki	doc_384045275264_item	2354073	et	3	main
on	doc_384045275264_item	2354077	et	4	main
madudest	doc_384045275264_item	2354083	et	3	main
nõidujatest	doc_384045275264_item	2354088	et	4	main
ravitsejate	doc_384045275264_item	2354125	et	4	main
väike	doc_384045275264_item	2354130	et	4	main
ja	doc_384045275264_item	2354131	et	3	main
kalendripühade	doc_384045275264_item	2354141	et	3	main
talsipühade	doc_384045275264_item	2354143	et	4	main
ajal	doc_384045275264_item	2354144	et	4	main
ennustasid	doc_384045275264_item	2354146	et	4	main
teeristmikul	doc_384045275264_item	2354148	et	4	main
rohisid	doc_384045275264_item	2354150	et	4	main
tikkudest	doc_384045275264_item	2354160	et	3	main
küpsetisi	doc_384045275264_item	2354162	et	4	main
anti	doc_384045275264_item	2354164	et	3	main
abielusõrmuses	doc_384045275264_item	2354171	et	3	main
määratu	doc_384045275264_item	2354176	et	4	main
ennustustes	doc_384045275264_item	2354178	et	4	main
mehele	doc_384045275264_item	2354181	et	3	main
väljavalitu	doc_384045275264_item	2354187	et	4	main
jäänipaeva	doc_384045275264_item	2354193	et	4	main
ennustustes	doc_384045275264_item	2354194	et	4	main
on	doc_384045275264_item	2354224	et	4	main
terved	doc_384045275264_item	2354226	et	4	main
ильин	doc_384045275264_item	2354232	et	2	main
или	doc_384045275264_item	2354239	et	2	main
olevipäeval	doc_384045275264_item	2354242	et	3	main
riielnud	doc_384045275264_item	2354257	et	4	main
arvata	doc_384045275264_item	2354268	et	4	main
võib	doc_384045275264_item	2354269	et	3	main
et	doc_384045275264_item	2354270	et	3	main
riietes	doc_384045275264_item	2354271	et	3	main
laialt	doc_384045275264_item	2354276	et	4	main
on	doc_384045275264_item	2354277	et	4	main
levinud	doc_384045275264_item	2354278	et	4	main
uskumus	doc_384045275264_item	2354279	et	3	main
et	doc_384045275264_item	2354280	et	3	main
vetes	doc_384045275264_item	2354284	et	3	main
kuna	doc_384045275264_item	2354288	et	3	main
jumal	doc_384045275264_item	2354289	et	3	main
on	doc_384045275264_item	2354290	et	4	main
aasta	doc_384045275264_item	2354297	et	4	main
kutsuda	doc_384045275264_item	2354309	et	3	main
lõigatud	doc_384045275264_item	2354331	et	4	main
peetripühal	doc_384045275264_item	2354335	et	4	main
noorte	doc_384045275264_item	2354342	et	3	main
maslenitsa	doc_384045275264_item	2354345	et	4	main
karnevali	doc_384045275264_item	2354347	et	4	main
uue	doc_384045275264_item	2354359	et	3	main
aasta	doc_384045275264_item	2354360	et	4	main
olid	doc_384045275264_item	2354367	et	4	main
ja	doc_384045275264_item	2354375	et	3	main
ka	doc_384045275264_item	2354384	et	3	main
oma	doc_384045275264_item	2354391	et	4	main
või	doc_384045275264_item	2354427	et	4	main
kinni	doc_384045275264_item	2354429	et	3	main
ümber	doc_384045275264_item	2354431	et	3	main
jms	doc_384045275264_item	2354443	et	4	main
poisid	doc_384045275264_item	2354456	et	4	main
keldris	doc_384045275264_item	2354462	et	3	main
võisid	doc_384045275264_item	2354465	et	4	main
sängi	doc_384045275264_item	2354483	et	4	main
külge	doc_384045275264_item	2354484	et	4	main
seotud	doc_384045275264_item	2354486	et	4	main
salasepitsustega	doc_384045275264_item	2354022	et	3	main
süžeed	doc_384045275264_item	2354027	et	2	main
tööd	doc_384045275264_item	2354034	et	4	main
folklooris	doc_384045275264_item	2354063	et	4	main
metsavaimust	doc_384045275264_item	2354071	et	4	main
mahukaid	doc_384045275264_item	2354078	et	4	main
nõiutud	doc_384045275264_item	2354080	et	4	main
otsimisest	doc_384045275264_item	2354082	et	4	main
abil	doc_384045275264_item	2354091	et	4	main
hirmsast	doc_384045275264_item	2354097	et	3	main
surmast	doc_384045275264_item	2354098	et	4	main
erandi	doc_384045275264_item	2354099	et	3	main
moodustavad	doc_384045275264_item	2354100	et	4	main
jutud	doc_384045275264_item	2354101	et	3	main
kaetamisest	doc_384045275264_item	2354102	et	4	main
ja	doc_384045275264_item	2354103	et	3	main
posimisest	doc_384045275264_item	2354104	et	4	main
selliseid	doc_384045275264_item	2354105	et	4	main
jutte	doc_384045275264_item	2354106	et	3	main
on	doc_384045275264_item	2354107	et	4	main
üsna	doc_384045275264_item	2354108	et	3	main
palju	doc_384045275264_item	2354109	et	4	main
kuid	doc_384045275264_item	2354110	et	4	main
tekstid	doc_384045275264_item	2354111	et	3	main
on	doc_384045275264_item	2354112	et	4	main
konspektiivsed	doc_384045275264_item	2354113	et	3	main
ja	doc_384045275264_item	2354114	et	3	main
üldjuhul	doc_384045275264_item	2354115	et	3	main
jäävad	doc_384045275264_item	2354116	et	4	main
nad	doc_384045275264_item	2354117	et	3	main
tüüpiliste	doc_384045275264_item	2354118	et	3	main
vene	doc_384045275264_item	2354119	et	4	main
kujutluste	doc_384045275264_item	2354120	et	4	main
on	doc_384045275264_item	2354127	et	4	main
samuti	doc_384045275264_item	2354128	et	3	main
leidub	doc_384045275264_item	2354140	et	3	main
tulevikku	doc_384045275264_item	2354147	et	4	main
ka	doc_384045275264_item	2354156	et	3	main
värskeid	doc_384045275264_item	2354161	et	4	main
kokorasi	doc_384045275264_item	2354163	et	4	main
veeklaasi	doc_384045275264_item	2354169	et	4	main
asetatud	doc_384045275264_item	2354170	et	4	main
lehmad	doc_384045275264_item	2354225	et	3	main
palju	doc_384045275264_item	2354230	et	4	main
на	doc_384045275264_item	2354236	et	2	main
lapsed	doc_384045275264_item	2354247	et	3	main
teine	doc_384045275264_item	2354250	et	3	main
riietatult	doc_384045275264_item	2354252	et	4	main
vette	doc_384045275264_item	2354253	et	3	main
lapsevanemad	doc_384045275264_item	2354254	et	4	main
kunagi	doc_384045275264_item	2354255	et	3	main
ei	doc_384045275264_item	2354256	et	4	main
eest	doc_384045275264_item	2354260	et	4	main
kaudselt	doc_384045275264_item	2354262	et	4	main
selle	doc_384045275264_item	2354264	et	4	main
tava	doc_384045275264_item	2354265	et	4	main
sümboliseeris	doc_384045275264_item	2354273	et	4	main
kohalikus	doc_384045275264_item	2354062	et	4	main
vähe	doc_384045275264_item	2354076	et	3	main
aarete	doc_384045275264_item	2354081	et	3	main
palju	doc_384045275264_item	2354093	et	4	main
halba	doc_384045275264_item	2354094	et	4	main
kohalike	doc_384045275264_item	2354122	et	4	main
ja	doc_384045275264_item	2354124	et	3	main
domineerivad	doc_384045275264_item	2354133	et	4	main
meditsiinilised	doc_384045275264_item	2354134	et	4	main
posimised	doc_384045275264_item	2354135	et	4	main
huvitavaid	doc_384045275264_item	2354137	et	4	main
üksikasju	doc_384045275264_item	2354139	et	3	main
lund	doc_384045275264_item	2354149	et	3	main
padja	doc_384045275264_item	2354152	et	3	main
pirrukestest	doc_384045275264_item	2354158	et	4	main
või	doc_384045275264_item	2354159	et	4	main
tänaval	doc_384045275264_item	2354166	et	4	main
meesterahvale	doc_384045275264_item	2354168	et	3	main
saatuse	doc_384045275264_item	2354174	et	3	main
nägu	doc_384045275264_item	2354177	et	4	main
kes	doc_384045275264_item	2354179	et	4	main
esimene	doc_384045275264_item	2354180	et	3	main
saab	doc_384045275264_item	2354182	et	3	main
kes	doc_384045275264_item	2354184	et	4	main
kasutati	doc_384045275264_item	2354188	et	4	main
maagilisi	doc_384045275264_item	2354191	et	4	main
kasutati	doc_384045275264_item	2354195	et	4	main
rohttaimi	doc_384045275264_item	2354196	et	4	main
ja	doc_384045275264_item	2354197	et	3	main
rukiviljapäid	doc_384045275264_item	2354198	et	4	main
peipsi	doc_384045275264_item	2354199	et	4	main
lõunapoolsetes	doc_384045275264_item	2354200	et	4	main
külades	doc_384045275264_item	2354201	et	3	main
jüripäeval	doc_384045275264_item	2354202	et	3	main
jegorij	doc_384045275264_item	2354203	et	4	main
kevadine	doc_384045275264_item	2354204	et	4	main
naised	doc_384045275264_item	2354205	et	3	main
panid	doc_384045275264_item	2354206	et	4	main
lüpsiku	doc_384045275264_item	2354207	et	3	main
veini	doc_384045275264_item	2354208	et	4	main
või	doc_384045275264_item	2354209	et	4	main
viina	doc_384045275264_item	2354210	et	4	main
sisse	doc_384045275264_item	2354211	et	4	main
likku	doc_384045275264_item	2354212	et	3	main
ja	doc_384045275264_item	2354213	et	3	main
pärast	doc_384045275264_item	2354214	et	4	main
joodi	doc_384045275264_item	2354215	et	4	main
kaks-kolm	doc_384045275264_item	2354216	et	3	main
pitsi	doc_384045275264_item	2354217	et	4	main
seda	doc_384045275264_item	2354218	et	3	main
jooki	doc_384045275264_item	2354219	et	4	main
ära	doc_384045275264_item	2354220	et	4	main
et	doc_384045275264_item	2354222	et	3	main
а	doc_384045275264_item	2354234	et	2	main
ивана	doc_384045275264_item	2354237	et	2	main
на	doc_384045275264_item	2354240	et	2	main
või	doc_384045275264_item	2354245	et	4	main
makkaveipäeval	doc_384045275264_item	2354246	et	4	main
teist	doc_384045275264_item	2354251	et	4	main
rituaalsetele	doc_384045275264_item	2354266	et	3	main
juurtele	doc_384045275264_item	2354267	et	3	main
ujumine	doc_384045275264_item	2354272	et	4	main
lõppu	doc_384045275264_item	2354275	et	4	main
avatud	doc_384045275264_item	2354283	et	4	main
ei	doc_384045275264_item	2354286	et	4	main
vette	doc_384045275264_item	2354291	et	3	main
pühi	doc_384045275264_item	2354295	et	4	main
koju	doc_384045275264_item	2354307	et	3	main
võõraid	doc_384045275264_item	2354311	et	3	main
inimesi	doc_384045275264_item	2354312	et	4	main
kes	doc_384045275264_item	2354313	et	4	main
olid	doc_384045275264_item	2354314	et	4	main
peole	doc_384045275264_item	2354315	et	4	main
tulnud	doc_384045275264_item	2354316	et	4	main
naaberküladest	doc_384045275264_item	2354317	et	3	main
selleks	doc_384045275264_item	2354318	et	4	main
juhuks	doc_384045275264_item	2354319	et	3	main
olid	doc_384045275264_item	2354320	et	4	main
olid	doc_384045275264_item	2354328	et	4	main
suvisel	doc_384045275264_item	2354334	et	4	main
vana	doc_384045275264_item	2354354	et	4	main
algust	doc_384045275264_item	2354361	et	4	main
kalendri	doc_384045275264_item	2354363	et	3	main
naljad	doc_384045275264_item	2354369	et	3	main
ja	doc_384045275264_item	2354370	et	3	main
täiskasvanud	doc_384045275264_item	2354372	et	4	main
naabrite	doc_384045275264_item	2354382	et	3	main
hoovi	doc_384045275264_item	2354392	et	4	main
üle	doc_384045275264_item	2354393	et	3	main
noorte	doc_384045275264_item	2354396	et	3	main
põhuga	doc_384045275264_item	2354426	et	3	main
saanid	doc_384045275264_item	2354436	et	3	main
või	doc_384045275264_item	2354437	et	4	main
tiriti	doc_384045275264_item	2354439	et	3	main
vahel	doc_384045275264_item	2354448	et	4	main
viisid	doc_384045275264_item	2354457	et	4	main
soolahoidistega	doc_384045275264_item	2354464	et	3	main
katusele	doc_384045275264_item	2354468	et	3	main
rahulikku	doc_384045275264_item	2354479	et	4	main
hobune	doc_384045275264_item	2354485	et	4	main
peipsimaal	doc_384045275264_item	2354487	et	4	main
mäletatakse	doc_384045275264_item	2354488	et	3	main
ka	doc_384045275264_item	2354489	et	3	main
maslenitsa	doc_384045275264_item	2354498	et	4	main
ja	doc_384045275264_item	2354502	et	3	main
lahingut	doc_384045275264_item	2354504	et	3	main
suvehooaja	doc_384045275264_item	2354274	et	3	main
pärast	doc_384045275264_item	2354281	et	4	main
olevipäeva	doc_384045275264_item	2354282	et	4	main
ujuda	doc_384045275264_item	2354285	et	3	main
tohi	doc_384045275264_item	2354287	et	4	main
eriti	doc_384045275264_item	2354296	et	3	main
tähistati	doc_384045275264_item	2354299	et	4	main
kärarikkalt	doc_384045275264_item	2354301	et	4	main
külla	doc_384045275264_item	2354308	et	4	main
juba	doc_384045275264_item	2354322	et	3	main
lauad	doc_384045275264_item	2354324	et	3	main
eriti	doc_384045275264_item	2354326	et	3	main
mandrist	doc_384045275264_item	2354329	et	4	main
elanikud	doc_384045275264_item	2354333	et	3	main
külla	doc_384045275264_item	2354339	et	4	main
tulla	doc_384045275264_item	2354341	et	3	main
oli	doc_384045275264_item	2354344	et	3	main
madisepäev	doc_384045275264_item	2354351	et	3	main
uus	doc_384045275264_item	2354355	et	3	main
aasta	doc_384045275264_item	2354356	et	4	main
mil	doc_384045275264_item	2354357	et	4	main
peeti	doc_384045275264_item	2354358	et	4	main
lubatud	doc_384045275264_item	2354368	et	4	main
suhtusid	doc_384045275264_item	2354373	et	4	main
poiste	doc_384045275264_item	2354374	et	3	main
tüdrukute	doc_384045275264_item	2354376	et	4	main
tempudesse	doc_384045275264_item	2354377	et	3	main
sallivalt	doc_384045275264_item	2354378	et	4	main
ju	doc_384045275264_item	2354381	et	3	main
pererahvas	doc_384045275264_item	2354389	et	4	main
kartlikult	doc_384045275264_item	2354390	et	4	main
nääri	doc_384045275264_item	2354398	et	4	main
teivad	doc_384045275264_item	2354421	et	4	main
korstnad	doc_384045275264_item	2354423	et	4	main
topiti	doc_384045275264_item	2354424	et	3	main
kaltsudega	doc_384045275264_item	2354428	et	3	main
küla	doc_384045275264_item	2354440	et	4	main
rituaalsed	doc_384045275264_item	2354445	et	3	main
maja	doc_384045275264_item	2354459	et	4	main
esitrepi	doc_384045275264_item	2354460	et	3	main
viisid	doc_384045275264_item	2354461	et	4	main
tünnid	doc_384045275264_item	2354463	et	3	main
sauna	doc_384045275264_item	2354467	et	4	main
ja	doc_384045275264_item	2354472	et	3	main
und	doc_384045275264_item	2354480	et	4	main
pererahva	doc_384045275264_item	2354482	et	3	main
ehitati	doc_384045275264_item	2354500	et	3	main
mängiti	doc_384045275264_item	2354503	et	3	main
on	doc_384045275264_item	2354523	et	4	main
oletatavasti	doc_384045275264_item	2354524	et	3	main
seotud	doc_384045275264_item	2354525	et	4	main
rituaalsete	doc_384045275264_item	2354526	et	3	main
teistes	doc_384045275264_item	2354543	et	4	main
tee	doc_384045275264_item	2354553	et	4	main
õhtud	doc_384045275264_item	2354554	et	3	main
ülalpool	doc_384045275264_item	2354555	et	3	main
tes	doc_384045275264_item	2354565	et	4	main
ja	doc_384045275264_item	2354566	et	3	main
läikivates	doc_384045275264_item	2354567	et	4	main
marsisid	doc_384045275264_item	2354569	et	4	main
terve	doc_384045275264_item	2354572	et	4	main
lipu	doc_384045275264_item	2354574	et	3	main
tulega	doc_384045275264_item	2354579	et	3	main
osalesid	doc_384045275264_item	2354590	et	4	main
tuletõrjesalkade	doc_384045275264_item	2354597	et	3	main
ja	doc_384045275264_item	2354601	et	3	main
kustutamise	doc_384045275264_item	2354604	et	4	main
tulekahju	doc_384045275264_item	2354618	et	4	main
kohalikus	doc_384045275264_item	2354622	et	4	main
pühakojas	doc_384045275264_item	2354623	et	3	main
enne	doc_384045275264_item	2354637	et	4	main
vene	doc_384045275264_item	2354643	et	4	main
kus	doc_384045275264_item	2354645	et	3	main
rahvarõivaid	doc_384045275264_item	2354647	et	3	main
ülestõusmispüha	doc_384045275264_item	2354657	et	4	main
ja	doc_384045275264_item	2354661	et	3	main
mainitud	doc_384045275264_item	2354667	et	4	main
lood	doc_384045275264_item	2354691	et	4	main
rannad	doc_384045275264_item	2354700	et	3	main
olid	doc_384045275264_item	2354702	et	4	main
konkreetne	doc_384045275264_item	2354705	et	3	main
oli	doc_384045275264_item	2354305	et	3	main
kombeks	doc_384045275264_item	2354306	et	4	main
ka	doc_384045275264_item	2354310	et	3	main
kodudes	doc_384045275264_item	2354321	et	3	main
eelnevalt	doc_384045275264_item	2354323	et	4	main
kaetud	doc_384045275264_item	2354325	et	4	main
külalislahked	doc_384045275264_item	2354327	et	3	main
võis	doc_384045275264_item	2354337	et	4	main
ja	doc_384045275264_item	2354348	et	3	main
söömisega	doc_384045275264_item	2354350	et	4	main
vana	doc_384045275264_item	2354362	et	4	main
sai	doc_384045275264_item	2354380	et	4	main
nalja	doc_384045275264_item	2354385	et	4	main
hommikuti	doc_384045275264_item	2354387	et	4	main
vaatas	doc_384045275264_item	2354388	et	3	main
valmis	doc_384045275264_item	2354395	et	4	main
tempudeks	doc_384045275264_item	2354397	et	3	main
üllatusi	doc_384045275264_item	2354399	et	4	main
oli	doc_384045275264_item	2354400	et	3	main
palju	doc_384045275264_item	2354401	et	4	main
ja	doc_384045275264_item	2354402	et	3	main
väga	doc_384045275264_item	2354403	et	3	main
erisuguseid	doc_384045275264_item	2354404	et	3	main
ka	doc_384045275264_item	2354405	et	3	main
uusi	doc_384045275264_item	2354406	et	3	main
pidevalt	doc_384045275264_item	2354408	et	4	main
tuli	doc_384045275264_item	2354407	et	4	main
juurde	doc_384045275264_item	2354409	et	4	main
samuti	doc_384045275264_item	2354410	et	3	main
kui	doc_384045275264_item	2354411	et	3	main
venemaa	doc_384045275264_item	2354412	et	4	main
põhja	doc_384045275264_item	2354413	et	4	main
ja	doc_384045275264_item	2354414	et	3	main
loode	doc_384045275264_item	2354415	et	4	main
kubermangu	doc_384045275264_item	2354416	et	4	main
mõnedes	doc_384045275264_item	2354417	et	3	main
külades	doc_384045275264_item	2354418	et	3	main
pandi	doc_384045275264_item	2354419	et	4	main
koduustele	doc_384045275264_item	2354420	et	3	main
ette	doc_384045275264_item	2354422	et	4	main
tarad	doc_384045275264_item	2354432	et	3	main
puuriidad	doc_384045275264_item	2354434	et	4	main
paadid	doc_384045275264_item	2354435	et	3	main
otsa	doc_384045275264_item	2354442	et	4	main
märatsemised	doc_384045275264_item	2354446	et	4	main
mis	doc_384045275264_item	2354451	et	4	main
nõudsid	doc_384045275264_item	2354452	et	4	main
ka	doc_384045275264_item	2354453	et	3	main
kollektiivseid	doc_384045275264_item	2354454	et	3	main
pingutusi	doc_384045275264_item	2354455	et	4	main
väiksema	doc_384045275264_item	2354469	et	4	main
korsten	doc_384045275264_item	2354474	et	4	main
kord	doc_384045275264_item	2354476	et	4	main
isegi	doc_384045275264_item	2354478	et	4	main
magava	doc_384045275264_item	2354481	et	4	main
ajal	doc_384045275264_item	2354491	et	4	main
korraldatud	doc_384045275264_item	2354492	et	4	main
see	doc_384045275264_item	2354521	et	3	main
rusikavõitlustega	doc_384045275264_item	2354527	et	3	main
novgorodlaste	doc_384045275264_item	2354529	et	4	main
olid	doc_384045275264_item	2354533	et	4	main
ka	doc_384045275264_item	2354534	et	3	main
öösiti	doc_384045275264_item	2354425	et	4	main
lükati	doc_384045275264_item	2354430	et	4	main
ja	doc_384045275264_item	2354433	et	3	main
väravad	doc_384045275264_item	2354438	et	3	main
teise	doc_384045275264_item	2354441	et	4	main
sedalaadi	doc_384045275264_item	2354444	et	4	main
võtsid	doc_384045275264_item	2354447	et	4	main
ootamatuid	doc_384045275264_item	2354449	et	4	main
vorme	doc_384045275264_item	2354450	et	3	main
ära	doc_384045275264_item	2354458	et	4	main
ka	doc_384045275264_item	2354466	et	3	main
paadi	doc_384045275264_item	2354470	et	3	main
tirida	doc_384045275264_item	2354471	et	3	main
sellega	doc_384045275264_item	2354473	et	3	main
katta	doc_384045275264_item	2354475	et	3	main
oli	doc_384045275264_item	2354477	et	3	main
pühade	doc_384045275264_item	2354490	et	3	main
kuidas	doc_384045275264_item	2354497	et	3	main
lumelinnust	doc_384045275264_item	2354501	et	4	main
ümberpiiramist	doc_384045275264_item	2354506	et	3	main
ja	doc_384045275264_item	2354507	et	3	main
purustamist	doc_384045275264_item	2354509	et	4	main
selle	doc_384045275264_item	2354508	et	4	main
pidupäevadel	doc_384045275264_item	2354510	et	3	main
said	doc_384045275264_item	2354511	et	4	main
naaberküla	doc_384045275264_item	2354512	et	4	main
külade	doc_384045275264_item	2354514	et	3	main
piiril	doc_384045275264_item	2354515	et	3	main
poisid	doc_384045275264_item	2354513	et	4	main
kokku	doc_384045275264_item	2354516	et	3	main
kaklemiseks	doc_384045275264_item	2354517	et	4	main
sein	doc_384045275264_item	2354518	et	3	main
seina	doc_384045275264_item	2354519	et	4	main
vastu	doc_384045275264_item	2354520	et	3	main
iidsete	doc_384045275264_item	2354528	et	3	main
peipsimaa	doc_384045275264_item	2354531	et	4	main
regioonides	doc_384045275264_item	2354544	et	3	main
ajal	doc_384045275264_item	2354546	et	4	main
kiivrites	doc_384045275264_item	2354568	et	3	main
võidu	doc_384045275264_item	2354580	et	4	main
tuletõrjujate	doc_384045275264_item	2354582	et	3	main
pidustustes	doc_384045275264_item	2354589	et	3	main
ametivennad	doc_384045275264_item	2354592	et	3	main
korraldada	doc_384045275264_item	2354596	et	3	main
imiteeriti	doc_384045275264_item	2354599	et	3	main
kiiremini	doc_384045275264_item	2354607	et	4	main
lahti	doc_384045275264_item	2354609	et	4	main
tõmbab	doc_384045275264_item	2354611	et	3	main
käsipumba	doc_384045275264_item	2354615	et	3	main
ja	doc_384045275264_item	2354624	et	3	main
pärast	doc_384045275264_item	2354625	et	4	main
suur	doc_384045275264_item	2354628	et	3	main
milles	doc_384045275264_item	2354630	et	3	main
traditsiooniks	doc_384045275264_item	2354640	et	3	main
viimastel	doc_384045275264_item	2354651	et	3	main
on	doc_384045275264_item	2354653	et	4	main
saanud	doc_384045275264_item	2354654	et	4	main
kuliš	doc_384045275264_item	2354660	et	2	main
konkurss	doc_384045275264_item	2354663	et	3	main
isetehtud	doc_384045275264_item	2354668	et	3	main
kirja	doc_384045275264_item	2354687	et	4	main
vanasti	doc_384045275264_item	2354695	et	3	main
pillirootihniku	doc_384045275264_item	2354701	et	3	main
üks	doc_384045275264_item	2354704	et	3	main
mehe	doc_384045275264_item	2354714	et	3	main
ja	doc_384045275264_item	2354716	et	3	main
teo	doc_384045275264_item	2354717	et	4	main
võistlusmänge	doc_384045275264_item	2354493	et	3	main
mustvees	doc_384045275264_item	2354494	et	3	main
mäletatakse	doc_384045275264_item	2354495	et	3	main
veel	doc_384045275264_item	2354496	et	4	main
ajal	doc_384045275264_item	2354499	et	4	main
linnuse	doc_384045275264_item	2354505	et	3	main
meelismängudega	doc_384045275264_item	2354530	et	3	main
rahval	doc_384045275264_item	2354532	et	3	main
ja	doc_384045275264_item	2354537	et	3	main
millel	doc_384045275264_item	2354539	et	3	main
leidu	doc_384045275264_item	2354541	et	4	main
mainitud	doc_384045275264_item	2354558	et	4	main
tuleturjutate	doc_384045275264_item	2354560	et	4	main
mehed	doc_384045275264_item	2354570	et	3	main
linna	doc_384045275264_item	2354573	et	4	main
mida	doc_384045275264_item	2354576	et	4	main
ehtisid	doc_384045275264_item	2354577	et	4	main
kolonni	doc_384045275264_item	2354583	et	4	main
vaimustusest	doc_384045275264_item	2354585	et	4	main
silmadega	doc_384045275264_item	2354587	et	3	main
ka	doc_384045275264_item	2354591	et	3	main
mustveest	doc_384045275264_item	2354593	et	4	main
traditsiooniks	doc_384045275264_item	2354594	et	3	main
oli	doc_384045275264_item	2354595	et	3	main
võistlusi	doc_384045275264_item	2354598	et	3	main
selle	doc_384045275264_item	2354603	et	4	main
kiiruses	doc_384045275264_item	2354605	et	4	main
rullib	doc_384045275264_item	2354608	et	3	main
vooliku	doc_384045275264_item	2354610	et	3	main
järveni	doc_384045275264_item	2354613	et	3	main
kustutab	doc_384045275264_item	2354617	et	3	main
siis	doc_384045275264_item	2354619	et	3	main
tava	doc_384045275264_item	2354522	et	4	main
ei	doc_384045275264_item	2354540	et	4	main
istjaid	doc_384045275264_item	2354549	et	4	main
oli	doc_384045275264_item	2354556	et	3	main
juba	doc_384045275264_item	2354557	et	3	main
kallaste	doc_384045275264_item	2354559	et	4	main
üle	doc_384045275264_item	2354571	et	3	main
all	doc_384045275264_item	2354575	et	3	main
saatis	doc_384045275264_item	2354584	et	3	main
säravate	doc_384045275264_item	2354586	et	4	main
poistesalk	doc_384045275264_item	2354588	et	3	main
tulekahju	doc_384045275264_item	2354600	et	4	main
kes	doc_384045275264_item	2354606	et	4	main
selle	doc_384045275264_item	2354612	et	4	main
abil	doc_384045275264_item	2354616	et	4	main
peeti	doc_384045275264_item	2354620	et	4	main
jumaleteenistus	doc_384045275264_item	2354621	et	4	main
osales	doc_384045275264_item	2354631	et	3	main
teist	doc_384045275264_item	2354638	et	4	main
tähistada	doc_384045275264_item	2354642	et	3	main
demonstreeriti	doc_384045275264_item	2354646	et	3	main
ja	doc_384045275264_item	2354648	et	3	main
aastatel	doc_384045275264_item	2354652	et	4	main
traditsiooniks	doc_384045275264_item	2354655	et	3	main
koraldada	doc_384045275264_item	2354656	et	4	main
pidusaiade	doc_384045275264_item	2354659	et	3	main
ülalpool	doc_384045275264_item	2354664	et	3	main
juba	doc_384045275264_item	2354666	et	3	main
pandud	doc_384045275264_item	2354688	et	4	main
üht	doc_384045275264_item	2354689	et	3	main
tüüpi	doc_384045275264_item	2354690	et	4	main
peipsi	doc_384045275264_item	2354698	et	4	main
тросты	doc_384045275264_item	2354710	et	2	main
omad	doc_384045275264_item	2354535	et	4	main
peod	doc_384045275264_item	2354536	et	4	main
meelelahutused	doc_384045275264_item	2354538	et	4	main
analooge	doc_384045275264_item	2354542	et	3	main
talvistepühade	doc_384045275264_item	2354545	et	4	main
korraldati	doc_384045275264_item	2354547	et	3	main
külades	doc_384045275264_item	2354548	et	3	main
mis	doc_384045275264_item	2354550	et	4	main
said	doc_384045275264_item	2354551	et	4	main
nime	doc_384045275264_item	2354552	et	4	main
festivali	doc_384045275264_item	2354561	et	4	main
puhkpilliorkestri	doc_384045275264_item	2354562	et	3	main
saatel	doc_384045275264_item	2354563	et	4	main
erirõivas	doc_384045275264_item	2354564	et	4	main
medalid	doc_384045275264_item	2354578	et	3	main
eest	doc_384045275264_item	2354581	et	4	main
võisteldi	doc_384045275264_item	2354602	et	3	main
ja	doc_384045275264_item	2354614	et	3	main
seda	doc_384045275264_item	2354626	et	3	main
algas	doc_384045275264_item	2354627	et	3	main
rahvas	doc_384045275264_item	2354635	et	4	main
mustvees	doc_384045275264_item	2354636	et	3	main
maailmasõda	doc_384045275264_item	2354639	et	4	main
esitati	doc_384045275264_item	2354649	et	4	main
mis	doc_384045275264_item	2354692	et	4	main
pajatasid	doc_384045275264_item	2354693	et	4	main
puhtad	doc_384045275264_item	2354696	et	3	main
järve	doc_384045275264_item	2354699	et	4	main
pilliroopõõsast	doc_384045275264_item	2354709	et	4	main
liivaranda	doc_384045275264_item	2354711	et	4	main
kuid	doc_384045275264_item	2354713	et	4	main
seda	doc_384045275264_item	2354726	et	3	main
pärast	doc_384045275264_item	2354728	et	4	main
pillirootihnikus	doc_384045275264_item	2354737	et	3	main
peamiseks	doc_384045275264_item	2354742	et	3	main
mis	doc_384045275264_item	2354747	et	4	main
näitab	doc_384045275264_item	2354748	et	3	main
peipsiääre	doc_384045275264_item	2354750	et	3	main
pärimuskultuur	doc_384045275264_item	2354757	et	4	main
õppinud	doc_384045275264_item	2354764	et	4	main
keele	doc_384045275264_item	2354792	et	4	main
mõju	doc_384045275264_item	2354793	et	4	main
tunda	doc_384045275264_item	2354794	et	3	main
mõnede	doc_384045275264_item	2354795	et	3	main
sõnade	doc_384045275264_item	2354796	et	3	main
paptistõ	doc_384045275264_item	2354799	et	4	main
abel	doc_384045275264_item	2354802	et	4	main
mõju	doc_384045275264_item	2354809	et	4	main
vanausuliste	doc_384045275264_item	2354810	et	4	main
tagasihoidlikum	doc_384045275264_item	2354814	et	4	main
aastate	doc_384045275264_item	2354816	et	3	main
kokku	doc_384045275264_item	2354818	et	3	main
fikseeritud	doc_384045275264_item	2354823	et	4	main
suure	doc_384045275264_item	2354830	et	3	main
oma	doc_384045275264_item	2354834	et	4	main
hobusest	doc_384045275264_item	2354835	et	4	main
oletatavasti	doc_384045275264_item	2354839	et	3	main
olevat	doc_384045275264_item	2354847	et	4	main
kiri	doc_384045275264_item	2354850	et	3	main
läbi	doc_384045275264_item	2354855	et	4	main
loeb	doc_384045275264_item	2354856	et	3	main
sellel	doc_384045275264_item	2354874	et	4	main
hea	doc_384045275264_item	2354910	et	4	main
kinnitust	doc_384045275264_item	2354923	et	4	main
surma	doc_384045275264_item	2354930	et	4	main
peipsiääre	doc_384045275264_item	2354941	et	3	main
sünnitajat	doc_384045275264_item	2354949	et	4	main
viitab	doc_384045275264_item	2354966	et	3	main
ka	doc_384045275264_item	2354967	et	3	main
kombe	doc_384045275264_item	2354968	et	4	main
nimetus	doc_384045275264_item	2354969	et	4	main
а	doc_384045275264_item	2354971	et	2	main
välistatud	doc_384045275264_item	2354976	et	4	main
põliselanikelt	doc_384045275264_item	2355008	et	3	main
üle	doc_384045275264_item	2355009	et	3	main
ходить	doc_384045275264_item	2355013	et	2	main
е	doc_384045275264_item	2355017	et	2	main
i	doc_384045275264_item	2355019	et	4	main
eesti	doc_384045275264_item	2355026	et	4	main
naine	doc_384045275264_item	2355027	et	3	main
tuntud	doc_384045275264_item	2355030	et	4	main
pidu	doc_384045275264_item	2354629	et	4	main
praktiliselt	doc_384045275264_item	2354632	et	4	main
kõik	doc_384045275264_item	2354633	et	4	main
kallaste	doc_384045275264_item	2354634	et	4	main
oli	doc_384045275264_item	2354641	et	3	main
valgustuspäeva	doc_384045275264_item	2354644	et	4	main
rahvalaule	doc_384045275264_item	2354650	et	4	main
ajal	doc_384045275264_item	2354658	et	4	main
pühademunade	doc_384045275264_item	2354662	et	3	main
oli	doc_384045275264_item	2354665	et	3	main
sõidukite	doc_384045275264_item	2354669	et	3	main
karakatitsate	doc_384045275264_item	2354670	et	4	main
võistlust	doc_384045275264_item	2354671	et	3	main
märgata	doc_384045275264_item	2354672	et	4	main
on	doc_384045275264_item	2354673	et	4	main
tendentsi	doc_384045275264_item	2354674	et	4	main
lõbusate	doc_384045275264_item	2354675	et	3	main
tõsieluloode	doc_384045275264_item	2354676	et	4	main
folkloriseerimises	doc_384045275264_item	2354677	et	3	main
ja	doc_384045275264_item	2354678	et	3	main
kaasaegse	doc_384045275264_item	2354679	et	3	main
rahvaanekdootide	doc_384045275264_item	2354680	et	3	main
tekkes	doc_384045275264_item	2354681	et	3	main
2006	doc_384045275264_item	2354682	et	2	main
aastal	doc_384045275264_item	2354683	et	3	main
sai	doc_384045275264_item	2354684	et	4	main
kolmelt	doc_384045275264_item	2354685	et	4	main
inimeselt	doc_384045275264_item	2354686	et	3	main
kuidas	doc_384045275264_item	2354694	et	3	main
liivased	doc_384045275264_item	2354697	et	4	main
kasvanud	doc_384045275264_item	2354703	et	4	main
mees	doc_384045275264_item	2354706	et	4	main
pidavat	doc_384045275264_item	2354707	et	4	main
kaks-kolm	doc_384045275264_item	2354708	et	3	main
kõik	doc_384045275264_item	2354720	et	4	main
erinevalt	doc_384045275264_item	2354722	et	4	main
detailide	doc_384045275264_item	2354745	et	3	main
vene	doc_384045275264_item	2354751	et	4	main
külades	doc_384045275264_item	2354752	et	3	main
ja	doc_384045275264_item	2354753	et	3	main
ei	doc_384045275264_item	2354755	et	4	main
ei	doc_384045275264_item	2354763	et	4	main
on	doc_384045275264_item	2354790	et	4	main
mitte	doc_384045275264_item	2354800	et	3	main
eesti	doc_384045275264_item	2354807	et	4	main
folkloori	doc_384045275264_item	2354808	et	4	main
tunduvalt	doc_384045275264_item	2354813	et	4	main
läbi	doc_384045275264_item	2354815	et	4	main
kõigis	doc_384045275264_item	2354817	et	4	main
kirja	doc_384045275264_item	2354819	et	4	main
pandud	doc_384045275264_item	2354820	et	4	main
istutanud	doc_384045275264_item	2354712	et	4	main
nime	doc_384045275264_item	2354715	et	4	main
põhjust	doc_384045275264_item	2354718	et	4	main
jutustajad	doc_384045275264_item	2354721	et	4	main
tegi	doc_384045275264_item	2354725	et	4	main
ilu	doc_384045275264_item	2354727	et	4	main
teine	doc_384045275264_item	2354729	et	3	main
aga	doc_384045275264_item	2354730	et	3	main
kirglik	doc_384045275264_item	2354731	et	3	main
tegi	doc_384045275264_item	2354733	et	4	main
seda	doc_384045275264_item	2354734	et	3	main
folkloorisüžee	doc_384045275264_item	2354741	et	2	main
tunnuseks	doc_384045275264_item	2354743	et	3	main
varieerimine	doc_384045275264_item	2354746	et	4	main
et	doc_384045275264_item	2354749	et	3	main
ole	doc_384045275264_item	2354756	et	4	main
vanausulised	doc_384045275264_item	2354765	et	4	main
eesti	doc_384045275264_item	2354766	et	4	main
koolides	doc_384045275264_item	2354767	et	3	main
samuti	doc_384045275264_item	2354789	et	3	main
foneetilises	doc_384045275264_item	2354797	et	3	main
avel	doc_384045275264_item	2354804	et	4	main
on	doc_384045275264_item	2354812	et	4	main
materjalides	doc_384045275264_item	2354821	et	3	main
üks	doc_384045275264_item	2354825	et	3	main
kalevipojast	doc_384045275264_item	2354827	et	4	main
kivi	doc_384045275264_item	2354831	et	4	main
ja	doc_384045275264_item	2354832	et	3	main
sellega	doc_384045275264_item	2354833	et	3	main
keeles	doc_384045275264_item	2354849	et	4	main
kes	doc_384045275264_item	2354852	et	4	main
selle	doc_384045275264_item	2354853	et	4	main
üle	doc_384045275264_item	2354863	et	3	main
uskumus	doc_384045275264_item	2354865	et	3	main
üht	doc_384045275264_item	2354876	et	3	main
ja	doc_384045275264_item	2354877	et	3	main
kuulda	doc_384045275264_item	2354907	et	4	main
veenvam	doc_384045275264_item	2354920	et	4	main
hinna	doc_384045275264_item	2354933	et	3	main
iii	doc_384045275264_item	2354936	et	4	main
ekspeditsiooni	doc_384045275264_item	2354938	et	4	main
korduvalt	doc_384045275264_item	2354943	et	4	main
abielunaistel	doc_384045275264_item	2354947	et	3	main
pirukaid	doc_384045275264_item	2354951	et	3	main
komme	doc_384045275264_item	2354963	et	4	main
millele	doc_384045275264_item	2354964	et	3	main
kaudselt	doc_384045275264_item	2354965	et	4	main
ka	doc_384045275264_item	2354975	et	3	main
kombe	doc_384045275264_item	2355011	et	4	main
ответки	doc_384045275264_item	2355015	et	2	main
ны	doc_384045275264_item	2355020	et	2	main
elanud	doc_384045275264_item	2355025	et	4	main
oli	doc_384045275264_item	2355028	et	3	main
hästi	doc_384045275264_item	2355029	et	3	main
poole	doc_384045275264_item	2355036	et	4	main
meelsasti	doc_384045275264_item	2355037	et	3	main
on	doc_384045275264_item	2355043	et	4	main
kui	doc_384045275264_item	2355054	et	3	main
vastasmõju	doc_384045275264_item	2355089	et	4	main
takistuseks	doc_384045275265_item	2355099	et	4	main
kirja	doc_384045275265_item	2355108	et	4	main
tõsiseks	doc_384045275265_item	2355118	et	4	main
on	doc_384045275265_item	2355120	et	4	main
1	doc_384045275265_item	2355137	et	2	main
muid	doc_384045275265_item	2355144	et	4	main
artiklis	doc_384045275265_item	2355152	et	3	main
tegi	doc_384045275265_item	2355154	et	4	main
või	doc_384045275265_item	2355157	et	4	main
beloussov	doc_384045275265_item	2355163	et	4	main
legendide	doc_384045275265_item	2355187	et	3	main
täieliku	doc_384045275265_item	2355192	et	3	main
täpselt	doc_384045275265_item	2355220	et	4	main
kihti	doc_384045275265_item	2355224	et	4	main
brandt	doc_384045275265_item	2355236	et	4	main
uurisid	doc_384045275265_item	2355237	et	4	main
peipsi	doc_384045275265_item	2355239	et	4	main
erinevaid	doc_384045275265_item	2355251	et	4	main
pulmakombeid	doc_384045275265_item	2355271	et	4	main
rahva	doc_384045275265_item	2355272	et	3	main
antud	doc_384045275265_item	2355284	et	4	main
temalt	doc_384045275265_item	2355290	et	3	main
pakkusid	doc_384045275264_item	2354719	et	4	main
mees	doc_384045275264_item	2354724	et	4	main
jahimees	doc_384045275264_item	2354732	et	4	main
hakkavad	doc_384045275264_item	2354738	et	4	main
pesitsema	doc_384045275264_item	2354740	et	3	main
ongi	doc_384045275264_item	2354744	et	4	main
veel	doc_384045275264_item	2354758	et	4	main
sõna	doc_384045275264_item	2354760	et	4	main
nimetustes	doc_384045275264_item	2354788	et	4	main
jt	doc_384045275264_item	2354805	et	4	main
peletanud	doc_384045275264_item	2354838	et	4	main
eesti	doc_384045275264_item	2354841	et	4	main
ka	doc_384045275264_item	2354843	et	3	main
kuvist	doc_384045275264_item	2354845	et	4	main
kaheteiskümnes	doc_384045275264_item	2354848	et	4	main
kirjutatud	doc_384045275264_item	2354851	et	4	main
lõputu	doc_384045275264_item	2354858	et	4	main
eestlastelt	doc_384045275264_item	2354861	et	4	main
käo	doc_384045275264_item	2354866	et	3	main
kahes	doc_384045275264_item	2354869	et	4	main
variandis	doc_384045275264_item	2354870	et	3	main
just	doc_384045275264_item	2354873	et	3	main
märk	doc_384045275264_item	2354911	et	3	main
kuna	doc_384045275264_item	2354921	et	3	main
tšehhi	doc_384045275264_item	2354924	et	2	main
kägu	doc_384045275264_item	2354926	et	4	main
loojangul	doc_384045275264_item	2354928	et	3	main
ennustab	doc_384045275264_item	2354929	et	3	main
käigus	doc_384045275264_item	2354939	et	4	main
on	doc_384045275264_item	2354940	et	4	main
külastada	doc_384045275264_item	2354948	et	3	main
eestlaste	doc_384045275264_item	2354962	et	4	main
в	doc_384045275264_item	2354970	et	2	main
руши	doc_384045275264_item	2354972	et	2	main
ei	doc_384045275264_item	2354973	et	4	main
et	doc_384045275264_item	2354977	et	3	main
nimetuse	doc_384045275264_item	2355012	et	4	main
адв	doc_384045275264_item	2355016	et	2	main
üks	doc_384045275264_item	2354723	et	3	main
lootuses	doc_384045275264_item	2354735	et	4	main
et	doc_384045275264_item	2354736	et	3	main
pardid	doc_384045275264_item	2354739	et	3	main
linnakestes	doc_384045275264_item	2354754	et	4	main
viimast	doc_384045275264_item	2354759	et	4	main
öelnud	doc_384045275264_item	2354761	et	4	main
üldjuhul	doc_384045275264_item	2354762	et	3	main
kuid	doc_384045275264_item	2354768	et	4	main
eesti	doc_384045275264_item	2354769	et	4	main
keelt	doc_384045275264_item	2354770	et	4	main
ja	doc_384045275264_item	2354771	et	3	main
kultuuri	doc_384045275264_item	2354772	et	4	main
tundsid	doc_384045275264_item	2354773	et	4	main
nad	doc_384045275264_item	2354774	et	3	main
nende	doc_384045275264_item	2354776	et	4	main
hästi	doc_384045275264_item	2354775	et	3	main
kõnekeeles	doc_384045275264_item	2354777	et	4	main
on	doc_384045275264_item	2354778	et	4	main
üpris	doc_384045275264_item	2354779	et	3	main
palju	doc_384045275264_item	2354780	et	4	main
laensõnu	doc_384045275264_item	2354781	et	4	main
eesti	doc_384045275264_item	2354782	et	4	main
keelest	doc_384045275264_item	2354783	et	4	main
eriti	doc_384045275264_item	2354784	et	3	main
tööriistade	doc_384045275264_item	2354785	et	3	main
ja	doc_384045275264_item	2354786	et	3	main
tarbeesemete	doc_384045275264_item	2354787	et	3	main
eesti	doc_384045275264_item	2354791	et	4	main
vormis	doc_384045275264_item	2354798	et	4	main
baptistõ	doc_384045275264_item	2354801	et	4	main
mitte	doc_384045275264_item	2354803	et	3	main
kuid	doc_384045275264_item	2354806	et	4	main
folkloorile	doc_384045275264_item	2354811	et	4	main
on	doc_384045275264_item	2354822	et	4	main
pärimusjutt	doc_384045275264_item	2354826	et	4	main
kes	doc_384045275264_item	2354828	et	4	main
heitnud	doc_384045275264_item	2354829	et	4	main
ära	doc_384045275264_item	2354837	et	4	main
viitab	doc_384045275264_item	2354840	et	3	main
pärimusjutt	doc_384045275264_item	2354844	et	4	main
millele	doc_384045275264_item	2354846	et	3	main
saab	doc_384045275264_item	2354857	et	3	main
aarde	doc_384045275264_item	2354859	et	3	main
võimalik	doc_384045275264_item	2354871	et	3	main
et	doc_384045275264_item	2354872	et	3	main
kukkumine	doc_384045275264_item	2354913	et	4	main
too	doc_384045275264_item	2354915	et	4	main
kasu	doc_384045275264_item	2354916	et	4	main
teine	doc_384045275264_item	2354917	et	3	main
seletus	doc_384045275264_item	2354918	et	4	main
tundub	doc_384045275264_item	2354919	et	3	main
vaid	doc_384045275264_item	2354824	et	3	main
hundi	doc_384045275264_item	2354836	et	3	main
traditsioonile	doc_384045275264_item	2354842	et	3	main
kirja	doc_384045275264_item	2354854	et	4	main
omanikuks	doc_384045275264_item	2354860	et	4	main
on	doc_384045275264_item	2354862	et	4	main
võetud	doc_384045275264_item	2354864	et	4	main
esimesest	doc_384045275264_item	2354867	et	3	main
kukkumisest	doc_384045275264_item	2354868	et	4	main
põhjusel	doc_384045275264_item	2354875	et	3	main
samat	doc_384045275264_item	2354878	et	4	main
fakti	doc_384045275264_item	2354879	et	4	main
erinevad	doc_384045275264_item	2354880	et	4	main
informaatorid	doc_384045275264_item	2354881	et	3	main
interpreteerisit	doc_384045275264_item	2354882	et	4	main
igaüks	doc_384045275264_item	2354883	et	3	main
omamoodi	doc_384045275264_item	2354884	et	3	main
üks	doc_384045275264_item	2354885	et	3	main
oli	doc_384045275264_item	2354886	et	3	main
veendunud	doc_384045275264_item	2354887	et	4	main
et	doc_384045275264_item	2354888	et	3	main
õhtul	doc_384045275264_item	2354889	et	3	main
kägu	doc_384045275264_item	2354890	et	4	main
kukkub	doc_384045275264_item	2354891	et	4	main
õnneks	doc_384045275264_item	2354892	et	4	main
keskpäeval	doc_384045275264_item	2354893	et	3	main
toob	doc_384045275264_item	2354894	et	3	main
materiaalset	doc_384045275264_item	2354895	et	3	main
kahju	doc_384045275264_item	2354896	et	4	main
hommikune	doc_384045275264_item	2354897	et	4	main
kukkumine	doc_384045275264_item	2354898	et	4	main
ei	doc_384045275264_item	2354899	et	4	main
kõlba	doc_384045275264_item	2354900	et	4	main
kuslike	doc_384045275264_item	2354901	et	4	main
teine	doc_384045275264_item	2354902	et	3	main
jutustaja	doc_384045275264_item	2354903	et	4	main
aga	doc_384045275264_item	2354904	et	3	main
arvab	doc_384045275264_item	2354905	et	3	main
et	doc_384045275264_item	2354906	et	3	main
kägu	doc_384045275264_item	2354908	et	4	main
kukkumist	doc_384045275264_item	2354909	et	4	main
õhtune	doc_384045275264_item	2354912	et	4	main
ei	doc_384045275264_item	2354914	et	4	main
õnnetust	doc_384045275264_item	2354931	et	4	main
ja	doc_384045275264_item	2354932	et	3	main
сд	doc_384045275264_item	2354935	et	2	main
39	doc_384045275264_item	2354937	et	2	main
fikseeritud	doc_384045275264_item	2354944	et	4	main
rituaalne	doc_384045275264_item	2354945	et	3	main
tuua	doc_384045275264_item	2354950	et	3	main
ja	doc_384045275264_item	2354952	et	3	main
emale	doc_384045275264_item	2354954	et	3	main
ja	doc_384045275264_item	2354955	et	3	main
vanausulised	doc_384045275264_item	2354957	et	4	main
arvavad	doc_384045275264_item	2354958	et	4	main
et	doc_384045275264_item	2354959	et	3	main
see	doc_384045275264_item	2354960	et	3	main
on	doc_384045275264_item	2354961	et	4	main
selle	doc_384045275264_item	2355010	et	4	main
в	doc_384045275264_item	2355014	et	2	main
an	doc_384045275264_item	2355022	et	4	main
ausuliste	doc_384045275264_item	2355023	et	4	main
ravitsejana	doc_384045275264_item	2355032	et	4	main
ka	doc_384045275264_item	2355039	et	3	main
vanausulised	doc_384045275264_item	2355040	et	4	main
kuid	doc_384045275264_item	2355041	et	4	main
oli	doc_384045275264_item	2355062	et	3	main
piirdu	doc_384045275264_item	2355079	et	4	main
otseste	doc_384045275264_item	2355081	et	3	main
tõlge	doc_384045275265_item	2355090	et	3	main
folkloori	doc_384045275265_item	2355093	et	4	main
võtmisel	doc_384045275265_item	2355101	et	4	main
tekste	doc_384045275265_item	2355107	et	3	main
pandud	doc_384045275265_item	2355109	et	4	main
illustratiivmaterjalina	doc_384045275265_item	2355110	et	4	main
publikatsiooniks	doc_384045275265_item	2355119	et	3	main
leiab	doc_384045275264_item	2354922	et	3	main
parallelides	doc_384045275264_item	2354925	et	4	main
kukkumine	doc_384045275264_item	2354927	et	4	main
tõusu	doc_384045275264_item	2354934	et	4	main
külades	doc_384045275264_item	2354942	et	3	main
komme	doc_384045275264_item	2354946	et	4	main
kingitusi	doc_384045275264_item	2354953	et	4	main
vastsündinule	doc_384045275264_item	2354956	et	3	main
ole	doc_384045275264_item	2354974	et	4	main
analoogiline	doc_384045275264_item	2354978	et	4	main
komme	doc_384045275264_item	2354979	et	4	main
oli	doc_384045275264_item	2354980	et	3	main
juba	doc_384045275264_item	2354981	et	3	main
esiasukatel	doc_384045275264_item	2354982	et	4	main
ja	doc_384045275264_item	2354983	et	3	main
selle	doc_384045275264_item	2354984	et	4	main
olemasolu	doc_384045275264_item	2354985	et	4	main
aitas	doc_384045275264_item	2354986	et	3	main
eestlastel	doc_384045275264_item	2354987	et	4	main
säilitada	doc_384045275264_item	2354988	et	3	main
iidne	doc_384045275264_item	2354989	et	3	main
komme	doc_384045275264_item	2354990	et	4	main
valgevenes	doc_384045275264_item	2354991	et	3	main
vitebski	doc_384045275264_item	2354992	et	4	main
oblastis	doc_384045275264_item	2354993	et	3	main
ritual	doc_384045275264_item	2354995	et	4	main
analoogne	doc_384045275264_item	2354994	et	3	main
on	doc_384045275264_item	2354996	et	4	main
levinud	doc_384045275264_item	2354997	et	4	main
nii	doc_384045275264_item	2354998	et	3	main
valgevene	doc_384045275264_item	2354999	et	4	main
kui	doc_384045275264_item	2355000	et	3	main
vene	doc_384045275264_item	2355001	et	4	main
asulates	doc_384045275264_item	2355002	et	4	main
sealsed	doc_384045275264_item	2355003	et	3	main
vanausulised	doc_384045275264_item	2355004	et	4	main
on	doc_384045275264_item	2355005	et	4	main
samuti	doc_384045275264_item	2355006	et	3	main
võtnud	doc_384045275264_item	2355007	et	4	main
дз	doc_384045275264_item	2355018	et	2	main
v	doc_384045275264_item	2355021	et	4	main
tema	doc_384045275264_item	2355035	et	4	main
rohkem	doc_384045275264_item	2355042	et	4	main
kui	doc_384045275264_item	2355046	et	3	main
nii	doc_384045275264_item	2355052	et	3	main
kaugelt	doc_384045275264_item	2355056	et	4	main
varnja	doc_384045275264_item	2355058	et	4	main
vene	doc_384045275264_item	2355063	et	4	main
folklooriteoste	doc_384045275264_item	2355080	et	3	main
rolli	doc_384045275264_item	2355084	et	4	main
mängib	doc_384045275264_item	2355085	et	3	main
kontekstuaalne	doc_384045275264_item	2355088	et	4	main
vanausuliste	doc_384045275265_item	2355092	et	4	main
väljaannete	doc_384045275265_item	2355094	et	3	main
ilmne	doc_384045275265_item	2355095	et	4	main
nappus	doc_384045275265_item	2355096	et	4	main
on	doc_384045275265_item	2355097	et	4	main
üksikuid	doc_384045275265_item	2355106	et	4	main
tähtsaimaks	doc_384045275265_item	2355114	et	4	main
ainsaks	doc_384045275265_item	2355117	et	3	main
vanausulistelt	doc_384045275265_item	2355142	et	4	main
näinud	doc_384045275265_item	2355149	et	4	main
korvata	doc_384045275265_item	2355159	et	4	main
märkis	doc_384045275265_item	2355184	et	3	main
pärimuste	doc_384045275265_item	2355185	et	4	main
peaaegu	doc_384045275265_item	2355191	et	3	main
rahvaluules	doc_384045275265_item	2355194	et	4	main
ülekaalu	doc_384045275265_item	2355196	et	4	main
196	doc_384045275265_item	2355203	et	2	main
märkida	doc_384045275265_item	2355206	et	4	main
ka	doc_384045275265_item	2355207	et	3	main
kaugema	doc_384045275265_item	2355208	et	4	main
mineviku	doc_384045275265_item	2355209	et	3	main
tööoskusi	doc_384045275265_item	2355215	et	3	main
siiski	doc_384045275265_item	2355218	et	4	main
mitu	doc_384045275265_item	2355222	et	4	main
kultuuris	doc_384045275265_item	2355226	et	3	main
konjaev	doc_384045275265_item	2355228	et	4	main
o	doc_384045275265_item	2355229	et	4	main
gromov	doc_384045275265_item	2355230	et	4	main
ääre	doc_384045275265_item	2355240	et	3	main
folklooritraditsiooni	doc_384045275265_item	2355246	et	4	main
kandjaid	doc_384045275265_item	2355247	et	4	main
kirjeldasid	doc_384045275265_item	2355248	et	4	main
selle	doc_384045275265_item	2355249	et	4	main
tähelepanu	doc_384045275265_item	2355254	et	4	main
väärivad	doc_384045275265_item	2355255	et	4	main
humoristliku	doc_384045275265_item	2355280	et	3	main
on	doc_384045275265_item	2355288	et	4	main
kirja	doc_384045275265_item	2355291	et	4	main
küsitlesid	doc_384045275265_item	2355300	et	4	main
kirjalikult	doc_384045275265_item	2355301	et	4	main
rahvatraditsioonide	doc_384045275265_item	2355304	et	3	main
teaduslikku	doc_384045275265_item	2355312	et	4	main
külas	doc_384045275264_item	2355024	et	3	main
pöördusid	doc_384045275264_item	2355038	et	4	main
käisid	doc_384045275264_item	2355048	et	4	main
naberkülades	doc_384045275264_item	2355053	et	4	main
ka	doc_384045275264_item	2355055	et	3	main
külas	doc_384045275264_item	2355059	et	3	main
avastatud	doc_384045275264_item	2355060	et	4	main
käsikirjas	doc_384045275264_item	2355061	et	3	main
keles	doc_384045275264_item	2355064	et	4	main
kirjutatud	doc_384045275264_item	2355065	et	4	main
tõvesõnad	doc_384045275264_item	2355066	et	3	main
mis	doc_384045275264_item	2355067	et	4	main
olevat	doc_384045275264_item	2355068	et	4	main
kunagi	doc_384045275264_item	2355069	et	3	main
saadud	doc_384045275264_item	2355070	et	4	main
eesti	doc_384045275264_item	2355071	et	4	main
kodust	doc_384045275264_item	2355072	et	4	main
eestlastelt	doc_384045275264_item	2355073	et	4	main
nii	doc_384045275264_item	2355074	et	3	main
et	doc_384045275264_item	2355075	et	3	main
kultuuridevaheline	doc_384045275264_item	2355076	et	4	main
dialoog	doc_384045275264_item	2355077	et	3	main
ei	doc_384045275264_item	2355078	et	4	main
roosi	doc_384045275264_item	2355031	et	4	main
abi	doc_384045275264_item	2355033	et	4	main
saamiseks	doc_384045275264_item	2355034	et	4	main
räägitud	doc_384045275264_item	2355044	et	4	main
juhustest	doc_384045275264_item	2355045	et	3	main
eestlased	doc_384045275264_item	2355047	et	3	main
vanausulistest	doc_384045275264_item	2355049	et	4	main
posijate	doc_384045275264_item	2355050	et	4	main
juurde	doc_384045275264_item	2355051	et	4	main
linnast	doc_384045275264_item	2355057	et	4	main
laenudega	doc_384045275264_item	2355082	et	3	main
tähtsat	doc_384045275264_item	2355083	et	3	main
eesti	doc_384045275265_item	2355091	et	4	main
olnud	doc_384045275265_item	2355098	et	4	main
selle	doc_384045275265_item	2355100	et	4	main
laija	doc_384045275265_item	2355102	et	4	main
teadusringlusesse	doc_384045275265_item	2355103	et	4	main
erandjuhtudel	doc_384045275265_item	2355104	et	3	main
on	doc_384045275265_item	2355105	et	4	main
keele-	doc_384045275265_item	2355111	et	4	main
ja	doc_384045275265_item	2355112	et	3	main
ajaloouuringutes	doc_384045275265_item	2355113	et	3	main
senini	doc_384045275265_item	2355116	et	3	main
aleksandr	doc_384045275265_item	2355121	et	4	main
materjal	doc_384045275265_item	2355123	et	3	main
населения	doc_384045275265_item	2355127	et	2	main
184241	doc_384045275265_item	2355130	et	2	main
pandud	doc_384045275265_item	2355140	et	4	main
peipsimaa	doc_384045275265_item	2355141	et	4	main
folkloori	doc_384045275265_item	2355143	et	4	main
ei	doc_384045275265_item	2355148	et	4	main
sissejuhatavas	doc_384045275265_item	2355151	et	3	main
autor	doc_384045275265_item	2355153	et	3	main
kas	doc_384045275265_item	2355156	et	3	main
osaliselt	doc_384045275265_item	2355158	et	4	main
lünk	doc_384045275265_item	2355161	et	3	main
muu	doc_384045275265_item	2355181	et	4	main
ja	doc_384045275265_item	2355188	et	3	main
kalendritavanditele	doc_384045275265_item	2355199	et	3	main
191	doc_384045275265_item	2355202	et	2	main
kogujaid	doc_384045275265_item	2355210	et	4	main
omamata	doc_384045275265_item	2355212	et	4	main
kogumise	doc_384045275265_item	2355214	et	4	main
suutsid	doc_384045275265_item	2355216	et	4	main
siin	doc_384045275264_item	2355086	et	4	main
ka	doc_384045275264_item	2355087	et	3	main
ja	doc_384045275265_item	2355115	et	3	main
beloussovi	doc_384045275265_item	2355122	et	4	main
kogumikus	doc_384045275265_item	2355124	et	4	main
фольклор	doc_384045275265_item	2355125	et	2	main
фрнп	doc_384045275265_item	2355129	et	2	main
50	doc_384045275265_item	2355134	et	2	main
laulu	doc_384045275265_item	2355135	et	4	main
ja	doc_384045275265_item	2355136	et	3	main
muinasjutu	doc_384045275265_item	2355138	et	3	main
kirja	doc_384045275265_item	2355139	et	4	main
ette	doc_384045275265_item	2355147	et	4	main
see	doc_384045275265_item	2355160	et	3	main
a	doc_384045275265_item	2355162	et	4	main
kirjeldas	doc_384045275265_item	2355164	et	3	main
kaadrist	doc_384045275265_item	2355165	et	3	main
uurija	doc_384045275265_item	2355183	et	4	main
vaimulike	doc_384045275265_item	2355189	et	3	main
puudumise	doc_384045275265_item	2355193	et	4	main
ringtansulaulude	doc_384045275265_item	2355195	et	4	main
seotust	doc_384045275265_item	2355198	et	4	main
183	doc_384045275265_item	2355201	et	2	main
ära	doc_384045275265_item	2355205	et	4	main
folkloori	doc_384045275265_item	2355213	et	4	main
nad	doc_384045275265_item	2355217	et	3	main
üpris	doc_384045275265_item	2355219	et	3	main
fikseerida	doc_384045275265_item	2355221	et	3	main
kronoloogilist	doc_384045275265_item	2355223	et	4	main
rahva	doc_384045275265_item	2355225	et	3	main
f	doc_384045275265_item	2355227	et	4	main
o	doc_384045275265_item	2355233	et	4	main
põhjalikult	doc_384045275265_item	2355238	et	4	main
siin	doc_384045275265_item	2355244	et	4	main
traditsiooni	doc_384045275265_item	2355250	et	4	main
ennustusi	doc_384045275265_item	2355275	et	4	main
ja	doc_384045275265_item	2355278	et	3	main
neljavärsilisi	doc_384045275265_item	2355282	et	4	main
tõeliseks	doc_384045275265_item	2355286	et	4	main
pandud	doc_384045275265_item	2355292	et	4	main
tekstid	doc_384045275265_item	2355293	et	3	main
aasatal	doc_384045275265_item	2355294	et	4	main
õpetajad	doc_384045275265_item	2355299	et	4	main
teemal	doc_384045275265_item	2355305	et	3	main
eelmise	doc_384045275265_item	2355320	et	3	main
sajandi	doc_384045275265_item	2355321	et	3	main
peipsimaa	doc_384045275265_item	2355326	et	4	main
vanausuliste	doc_384045275265_item	2355327	et	4	main
kes	doc_384045275265_item	2355334	et	4	main
m	doc_384045275265_item	2355350	et	4	main
perekonnanimede	doc_384045275265_item	2355354	et	3	main
oletada	doc_384045275265_item	2355357	et	3	main
et	doc_384045275265_item	2355365	et	3	main
aastakümned	doc_384045275265_item	2355367	et	4	main
kogumistöö	doc_384045275265_item	2355369	et	4	main
regioonis	doc_384045275265_item	2355371	et	3	main
vaid	doc_384045275265_item	2355373	et	3	main
korraldatud	doc_384045275265_item	2355385	et	4	main
selle	doc_384045275265_item	2355392	et	4	main
ekspeditsiooni	doc_384045275265_item	2355393	et	4	main
liikmete	doc_384045275265_item	2355394	et	3	main
kolme	doc_384045275265_item	2355396	et	4	main
nädalaga	doc_384045275265_item	2355397	et	3	main
meil	doc_384045275265_item	2355398	et	4	main
mitusada	doc_384045275265_item	2355402	et	4	main
kvaliteetseid	doc_384045275265_item	2355407	et	3	main
mis	doc_384045275265_item	2355409	et	4	main
kirjandusmuuseumisse	doc_384045275265_item	2355413	et	3	main
kogujate	doc_384045275265_item	2355426	et	4	main
välja	doc_384045275265_item	2355428	et	4	main
said	doc_384045275265_item	2355430	et	4	main
religioosne	doc_384045275265_item	2355440	et	3	main
ja	doc_384045275265_item	2355441	et	3	main
etikett	doc_384045275265_item	2355443	et	3	main
olmemaagia	doc_384045275265_item	2355444	et	4	main
on	doc_384045275265_item	2355446	et	4	main
et	doc_384045275265_item	2355448	et	3	main
on	doc_384045275265_item	2355457	et	4	main
русского	doc_384045275265_item	2355126	et	2	main
прибалтики	doc_384045275265_item	2355128	et	2	main
autor	doc_384045275265_item	2355131	et	3	main
on	doc_384045275265_item	2355132	et	4	main
valinud	doc_384045275265_item	2355133	et	4	main
žaanre	doc_384045275265_item	2355145	et	2	main
raamat	doc_384045275265_item	2355146	et	3	main
sisukas	doc_384045275265_item	2355150	et	4	main
katse	doc_384045275265_item	2355155	et	4	main
välja	doc_384045275265_item	2355166	et	4	main
jäänud	doc_384045275265_item	2355167	et	4	main
žaanre	doc_384045275265_item	2355168	et	2	main
rea	doc_384045275265_item	2355169	et	3	main
parameetrite	doc_384045275265_item	2355170	et	4	main
võrdles	doc_384045275265_item	2355172	et	3	main
vanausuliste	doc_384045275265_item	2355173	et	4	main
alusel	doc_384045275265_item	2355171	et	4	main
ja	doc_384045275265_item	2355174	et	3	main
õigeusuliste	doc_384045275265_item	2355175	et	4	main
avastas	doc_384045275265_item	2355177	et	3	main
rida	doc_384045275265_item	2355178	et	4	main
huvipakkuvaid	doc_384045275265_item	2355179	et	3	main
seaduspärasusi	doc_384045275265_item	2355180	et	4	main
folkloori	doc_384045275265_item	2355176	et	4	main
hulgas	doc_384045275265_item	2355182	et	4	main
kristlikke	doc_384045275265_item	2355186	et	3	main
värsside	doc_384045275265_item	2355190	et	3	main
mittetavandilaulude	doc_384045275265_item	2355197	et	4	main
фрнп	doc_384045275265_item	2355200	et	2	main
tuleb	doc_384045275265_item	2355204	et	3	main
tihtipeale	doc_384045275265_item	2355211	et	3	main
v	doc_384045275265_item	2355231	et	4	main
jegorov	doc_384045275265_item	2355232	et	4	main
o	doc_384045275265_item	2355235	et	4	main
vanausuliste	doc_384045275265_item	2355241	et	4	main
külasi	doc_384045275265_item	2355242	et	4	main
avastasid	doc_384045275265_item	2355243	et	4	main
külgi	doc_384045275265_item	2355252	et	4	main
erilist	doc_384045275265_item	2355253	et	4	main
enneid	doc_384045275265_item	2355273	et	4	main
laule	doc_384045275265_item	2355277	et	4	main
sisuga	doc_384045275265_item	2355281	et	3	main
kogumiku	doc_384045275265_item	2355285	et	4	main
1930	doc_384045275265_item	2355295	et	2	main
mustvee	doc_384045275265_item	2355296	et	3	main
vene	doc_384045275265_item	2355297	et	4	main
õpilasi	doc_384045275265_item	2355303	et	3	main
määral	doc_384045275265_item	2355307	et	3	main
küsitluse	doc_384045275265_item	2355309	et	4	main
ka	doc_384045275265_item	2355311	et	3	main
huvi	doc_384045275265_item	2355313	et	4	main
ka	doc_384045275265_item	2355314	et	3	main
on	doc_384045275265_item	2355315	et	4	main
nad	doc_384045275265_item	2355316	et	3	main
kajastatud	doc_384045275265_item	2355317	et	4	main
60ndatel	doc_384045275265_item	2355322	et	4	main
tartu	doc_384045275265_item	2355331	et	4	main
kirja	doc_384045275265_item	2355341	et	4	main
nende	doc_384045275265_item	2355353	et	4	main
järgi	doc_384045275265_item	2355355	et	4	main
nad	doc_384045275265_item	2355359	et	3	main
praktikal	doc_384045275265_item	2355361	et	3	main
oma	doc_384045275265_item	2355362	et	4	main
selles	doc_384045275265_item	2355370	et	4	main
esimehe	doc_384045275265_item	2355380	et	3	main
peipsimaale	doc_384045275265_item	2355387	et	4	main
kogumik	doc_384045275265_item	2355389	et	3	main
poolt	doc_384045275265_item	2355395	et	4	main
panna	doc_384045275265_item	2355401	et	4	main
tunni	doc_384045275265_item	2355406	et	3	main
helisalvestusi	doc_384045275265_item	2355408	et	3	main
saavad	doc_384045275265_item	2355410	et	4	main
üleantud	doc_384045275265_item	2355411	et	4	main
eesti	doc_384045275265_item	2355412	et	4	main
tartus	doc_384045275265_item	2355414	et	3	main
kogumistöö	doc_384045275265_item	2355415	et	4	main
erinevatel	doc_384045275265_item	2355422	et	4	main
põhjustel	doc_384045275265_item	2355423	et	3	main
jäid	doc_384045275265_item	2355424	et	4	main
eelmiste	doc_384045275265_item	2355425	et	3	main
värsid	doc_384045275265_item	2355437	et	3	main
lüürilised	doc_384045275265_item	2355455	et	3	main
kultuur	doc_384045275265_item	2355469	et	3	main
selles	doc_384045275265_item	2355470	et	4	main
elus	doc_384045275265_item	2355480	et	4	main
ja	doc_384045275265_item	2355481	et	3	main
jogener	doc_384045275265_item	2355234	et	4	main
kümneid	doc_384045275265_item	2355245	et	4	main
olga	doc_384045275265_item	2355256	et	4	main
gildebrandti	doc_384045275265_item	2355257	et	4	main
kirjapanekud	doc_384045275265_item	2355258	et	3	main
aastal	doc_384045275265_item	2355259	et	3	main
õnnestus	doc_384045275265_item	2355261	et	4	main
temal	doc_384045275265_item	2355262	et	3	main
1949	doc_384045275265_item	2355260	et	2	main
kohtuda	doc_384045275265_item	2355263	et	3	main
kallastes	doc_384045275265_item	2355264	et	4	main
anna	doc_384045275265_item	2355265	et	4	main
pahhutinaga	doc_384045275265_item	2355266	et	4	main
kes	doc_384045275265_item	2355267	et	4	main
tundis	doc_384045275265_item	2355268	et	3	main
suurepäraselt	doc_384045275265_item	2355269	et	4	main
vanu	doc_384045275265_item	2355270	et	4	main
uskumusi	doc_384045275265_item	2355274	et	4	main
lüürilisi	doc_384045275265_item	2355276	et	3	main
tšastuškasi	doc_384045275265_item	2355279	et	2	main
rahvalaule	doc_384045275265_item	2355283	et	4	main
pärliks	doc_384045275265_item	2355287	et	4	main
just	doc_384045275265_item	2355289	et	3	main
teatud	doc_384045275265_item	2355306	et	4	main
tulemused	doc_384045275265_item	2355310	et	3	main
ülikooli	doc_384045275265_item	2355332	et	4	main
folklooripraktika	doc_384045275265_item	2355337	et	4	main
ventšikova	doc_384045275265_item	2355348	et	2	main
viimased	doc_384045275265_item	2355366	et	3	main
aastal	doc_384045275265_item	2355375	et	3	main
kirja	doc_384045275265_item	2355400	et	4	main
üle	doc_384045275265_item	2355404	et	3	main
mis	doc_384045275265_item	2355421	et	4	main
silmapiirist	doc_384045275265_item	2355427	et	3	main
pandud	doc_384045275265_item	2355432	et	4	main
juhuslikult	doc_384045275265_item	2355435	et	4	main
vaimilikud	doc_384045275265_item	2355436	et	4	main
kristlikud	doc_384045275265_item	2355438	et	3	main
pere	doc_384045275265_item	2355442	et	4	main
kahetsusväärne	doc_384045275265_item	2355445	et	3	main
tõdeda	doc_384045275265_item	2355447	et	3	main
paljud	doc_384045275265_item	2355449	et	3	main
ja	doc_384045275265_item	2355454	et	3	main
kadunud	doc_384045275265_item	2355458	et	4	main
käibivusest	doc_384045275265_item	2355460	et	4	main
siiski	doc_384045275265_item	2355461	et	4	main
kokkuvõtlikult	doc_384045275265_item	2355462	et	4	main
ekspeditsiooni	doc_384045275265_item	2355463	et	4	main
tulemused	doc_384045275265_item	2355464	et	3	main
tõestavad	doc_384045275265_item	2355465	et	4	main
et	doc_384045275265_item	2355466	et	3	main
ka	doc_384045275265_item	2355473	et	3	main
algkooli	doc_384045275265_item	2355298	et	4	main
oma	doc_384045275265_item	2355302	et	4	main
pakuvad	doc_384045275265_item	2355308	et	3	main
antud	doc_384045275265_item	2355318	et	4	main
väljaandes	doc_384045275265_item	2355319	et	3	main
astatel	doc_384045275265_item	2355323	et	4	main
oma	doc_384045275265_item	2355324	et	4	main
panuse	doc_384045275265_item	2355325	et	3	main
folklooritraditsiooni	doc_384045275265_item	2355328	et	4	main
uurimisel	doc_384045275265_item	2355329	et	4	main
üliõpilased	doc_384045275265_item	2355333	et	3	main
pandud	doc_384045275265_item	2355342	et	4	main
materjalidest	doc_384045275265_item	2355343	et	3	main
ja	doc_384045275265_item	2355349	et	3	main
kirjapanekuid	doc_384045275265_item	2355352	et	3	main
kodukandis	doc_384045275265_item	2355363	et	3	main
oli	doc_384045275265_item	2355368	et	3	main
seiskunud	doc_384045275265_item	2355372	et	4	main
2006	doc_384045275265_item	2355374	et	2	main
vanausuliste	doc_384045275265_item	2355377	et	4	main
liidu	doc_384045275265_item	2355379	et	3	main
pavel	doc_384045275265_item	2355381	et	4	main
varunini	doc_384045275265_item	2355382	et	4	main
initsiatiivil	doc_384045275265_item	2355383	et	3	main
sai	doc_384045275265_item	2355384	et	4	main
õnnestus	doc_384045275265_item	2355399	et	4	main
eelistuste	doc_384045275265_item	2355416	et	4	main
hulka	doc_384045275265_item	2355417	et	4	main
kuulusid	doc_384045275265_item	2355418	et	4	main
folkloorižaanrid	doc_384045275265_item	2355420	et	2	main
või	doc_384045275265_item	2355429	et	4	main
kirja	doc_384045275265_item	2355431	et	4	main
legendid	doc_384045275265_item	2355439	et	3	main
laulud	doc_384045275265_item	2355456	et	3	main
elusast	doc_384045275265_item	2355459	et	4	main
vene	doc_384045275265_item	2355467	et	4	main
regioonis	doc_384045275265_item	2355471	et	3	main
tänapäeval	doc_384045275265_item	2355474	et	3	main
tähtsamaid	doc_384045275265_item	2355476	et	4	main
elanike	doc_384045275265_item	2355479	et	3	main
tegid	doc_384045275265_item	2355330	et	4	main
töötasid	doc_384045275265_item	2355335	et	4	main
siin	doc_384045275265_item	2355336	et	4	main
ajal	doc_384045275265_item	2355338	et	4	main
üliõpilaste	doc_384045275265_item	2355339	et	4	main
poolt	doc_384045275265_item	2355340	et	4	main
võib	doc_384045275265_item	2355344	et	3	main
ära	doc_384045275265_item	2355345	et	4	main
märkida	doc_384045275265_item	2355346	et	4	main
i	doc_384045275265_item	2355347	et	4	main
feklistova	doc_384045275265_item	2355351	et	4	main
võib	doc_384045275265_item	2355356	et	3	main
et	doc_384045275265_item	2355358	et	3	main
olid	doc_384045275265_item	2355360	et	4	main
kahetsusväärne	doc_384045275265_item	2355364	et	3	main
eesti	doc_384045275265_item	2355376	et	4	main
koguduste	doc_384045275265_item	2355378	et	4	main
folklooriekspeditsioon	doc_384045275265_item	2355386	et	3	main
antud	doc_384045275265_item	2355388	et	4	main
on	doc_384045275265_item	2355390	et	4	main
koostatud	doc_384045275265_item	2355391	et	4	main
folklooritekste	doc_384045275265_item	2355403	et	3	main
60	doc_384045275265_item	2355405	et	2	main
need	doc_384045275265_item	2355419	et	3	main
teatad	doc_384045275265_item	2355433	et	3	main
määral	doc_384045275265_item	2355434	et	3	main
rahvaluule	doc_384045275265_item	2355450	et	4	main
teosed	doc_384045275265_item	2355451	et	3	main
eeskätt	doc_384045275265_item	2355452	et	3	main
muinasjutud	doc_384045275265_item	2355453	et	3	main
traditsiooniline	doc_384045275265_item	2355468	et	4	main
on	doc_384045275265_item	2355472	et	4	main
üks	doc_384045275265_item	2355475	et	3	main
komponente	doc_384045275265_item	2355477	et	3	main
kohalike	doc_384045275265_item	2355478	et	4	main
väärib	doc_384045275265_item	2355482	et	3	main
edasist	doc_384045275265_item	2355483	et	3	main
autorite	doc_384045275265_item	2355485	et	3	main
uurimist	doc_384045275265_item	2355484	et	4	main
arvamusel	doc_384045275265_item	2355486	et	3	main
jääb	doc_384045275265_item	2355487	et	3	main
läänerannik	doc_384045275265_item	2355489	et	3	main
veel	doc_384045275265_item	2355490	et	4	main
pikki	doc_384045275265_item	2355491	et	4	main
peipsi	doc_384045275265_item	2355488	et	4	main
aastaid	doc_384045275265_item	2355492	et	4	main
õnnistusrikkaks	doc_384045275265_item	2355493	et	4	main
tööpõlluks	doc_384045275265_item	2355494	et	3	main
folklooriuurijatele	doc_384045275265_item	2355495	et	3	main
ja	doc_384045275265_item	2355496	et	3	main
etnoloogidele	doc_384045275265_item	2355497	et	3	main
васильевич	doc_384045275267_item	2355899	et	2	main
on	doc_384045275267_item	2355910	et	4	main
loomingu	doc_384045275267_item	2355917	et	3	main
teosed	doc_384045275267_item	2355919	et	3	main
сергей	doc_384045275267_item	2355898	et	2	main
sergei	doc_384045275267_item	2355901	et	4	main
sergei	doc_384045275267_item	2355907	et	4	main
kasahstan	doc_384045275267_item	2355911	et	4	main
alates	doc_384045275267_item	2355920	et	3	main
aastast	doc_384045275267_item	2355922	et	4	main
ta	doc_384045275267_item	2355926	et	4	main
lukjanenko	doc_384045275267_item	2355932	et	4	main
alguses	doc_384045275267_item	2355934	et	4	main
keeles	doc_384045275267_item	2355938	et	4	main
15	doc_384045275267_item	2355942	et	2	main
ta	doc_384045275267_item	2355952	et	4	main
kosmoses	doc_384045275267_item	2355955	et	3	main
alternatiivsed	doc_384045275267_item	2355958	et	3	main
põhiolemuselt	doc_384045275267_item	2355966	et	3	main
тьма	doc_384045275267_item	2355973	et	2	main
драконов	doc_384045275267_item	2355977	et	2	main
tunduvad	doc_384045275267_item	2355983	et	4	main
sergei	doc_384045275267_item	2355984	et	4	main
lukjanenko	doc_384045275267_item	2355985	et	4	main
teosed	doc_384045275267_item	2355986	et	3	main
ночной	doc_384045275267_item	2356024	et	2	main
alusel	doc_384045275267_item	2356026	et	4	main
populaarset	doc_384045275267_item	2356031	et	3	main
лабиринт	doc_384045275267_item	2356043	et	2	main
ning	doc_384045275267_item	2356048	et	3	main
зеркала	doc_384045275267_item	2356059	et	2	main
teose	doc_384045275267_item	2356063	et	3	main
lähituleviku	doc_384045275267_item	2356068	et	4	main
kübermaailmas	doc_384045275267_item	2356069	et	3	main
on	doc_384045275267_item	2356077	et	4	main
võetud	doc_384045275267_item	2356078	et	4	main
teose	doc_384045275267_item	2356079	et	3	main
2	doc_384045275267_item	2356083	et	2	main
сообщает	doc_384045275267_item	2356086	et	2	main
labürint	doc_384045275267_item	2355896	et	3	main
nn	doc_384045275267_item	2355905	et	4	main
küberpunk	doc_384045275267_item	2355906	et	4	main
päritolumaa	doc_384045275267_item	2355909	et	4	main
kus	doc_384045275267_item	2355912	et	3	main
on	doc_384045275267_item	2355913	et	4	main
kirjutatud	doc_384045275267_item	2355914	et	4	main
ka	doc_384045275267_item	2355915	et	3	main
tema	doc_384045275267_item	2355916	et	4	main
elab	doc_384045275267_item	2355923	et	3	main
töötab	doc_384045275267_item	2355925	et	3	main
vene	doc_384045275267_item	2355937	et	4	main
viimase	doc_384045275267_item	2355941	et	3	main
jooksul	doc_384045275267_item	2355944	et	4	main
saanud	doc_384045275267_item	2355945	et	4	main
üheks	doc_384045275267_item	2355946	et	3	main
tuntumatest	doc_384045275267_item	2355947	et	4	main
mitmed	doc_384045275267_item	2355965	et	4	main
kirjutatud	doc_384045275267_item	2355968	et	4	main
teosed	doc_384045275267_item	2355969	et	3	main
nt	doc_384045275267_item	2355970	et	4	main
время	doc_384045275267_item	2355975	et	2	main
lühijutte	doc_384045275267_item	2356021	et	3	main
tetraloogia	doc_384045275267_item	2356023	et	4	main
kaks	doc_384045275267_item	2356029	et	3	main
ночной	doc_384045275267_item	2356033	et	2	main
selle	doc_384045275267_item	2356036	et	4	main
järg	doc_384045275267_item	2356037	et	3	main
дневной	doc_384045275267_item	2356038	et	2	main
romaan	doc_384045275267_item	2356040	et	3	main
фальшивые	doc_384045275267_item	2356058	et	2	main
suures	doc_384045275267_item	2356066	et	3	main
vaid	doc_384045275267_item	2356070	et	3	main
eksisteerivas	doc_384045275267_item	2356072	et	4	main
peegelduste	doc_384045275267_item	2355895	et	4	main
autor	doc_384045275267_item	2355897	et	3	main
lukjanenko	doc_384045275267_item	2355902	et	4	main
ulme	doc_384045275267_item	2355904	et	4	main
lukjanenko	doc_384045275267_item	2355908	et	4	main
alguspoole	doc_384045275267_item	2355918	et	4	main
ja	doc_384045275267_item	2355924	et	3	main
alustas	doc_384045275267_item	2355930	et	3	main
sergei	doc_384045275267_item	2355931	et	4	main
90date	doc_384045275267_item	2355933	et	4	main
on	doc_384045275267_item	2355940	et	4	main
ulmekirjanikest	doc_384045275267_item	2355949	et	3	main
kirjutabki	doc_384045275267_item	2355951	et	3	main
ulmežanris	doc_384045275267_item	2355953	et	2	main
seiklused	doc_384045275267_item	2355954	et	3	main
arenguvõimalused	doc_384045275267_item	2355959	et	3	main
on	doc_384045275267_item	2355961	et	4	main
и	doc_384045275267_item	2355972	et	2	main
для	doc_384045275267_item	2355976	et	2	main
jt	doc_384045275267_item	2355980	et	4	main
vändatud	doc_384045275267_item	2356028	et	4	main
filmi	doc_384045275267_item	2356032	et	4	main
ja	doc_384045275267_item	2356035	et	3	main
peegelduste	doc_384045275267_item	2356041	et	4	main
aastal	doc_384045275267_item	2356047	et	3	main
on	doc_384045275267_item	2356049	et	4	main
esimene	doc_384045275267_item	2356050	et	3	main
raamat	doc_384045275267_item	2356051	et	3	main
lisaks	doc_384045275267_item	2356054	et	4	main
ja	doc_384045275267_item	2356060	et	3	main
linnas	doc_384045275267_item	2356073	et	4	main
nr	doc_384045275267_item	2356082	et	4	main
программа	doc_384045275267_item	2356087	et	2	main
узорчатым	doc_384045275267_item	2356123	et	2	main
ножнах	doc_384045275267_item	2356128	et	2	main
создал	doc_384045275267_item	2356135	et	2	main
один	doc_384045275267_item	2356141	et	2	main
закавказской	doc_384045275267_item	2356146	et	2	main
программисты	doc_384045275267_item	2356151	et	2	main
этого	doc_384045275267_item	2356156	et	2	main
puu	doc_384045275267_item	2356160	et	4	main
ma	doc_384045275267_item	2356163	et	3	main
ta	doc_384045275267_item	2356168	et	4	main
jaoks	doc_384045275267_item	2356178	et	4	main
puu	doc_384045275267_item	2356181	et	4	main
ja	doc_384045275267_item	2356186	et	3	main
sealt	doc_384045275267_item	2356188	et	4	main
raske	doc_384045275267_item	2356190	et	4	main
originaalteksti	doc_384045275267_item	2356231	et	4	main
отражений	doc_384045275267_item	2356238	et	2	main
on	doc_384045275267_item	2356242	et	4	main
eest	doc_384045275267_item	2356243	et	4	main
otsetõlkena	doc_384045275267_item	2356247	et	3	main
vihjab	doc_384045275267_item	2356249	et	3	main
inimene	doc_384045275267_item	2356255	et	3	main
ja	doc_384045275267_item	2356256	et	3	main
tema	doc_384045275267_item	2356257	et	4	main
mina	doc_384045275267_item	2356258	et	4	main
erinevatele	doc_384045275267_item	2356263	et	4	main
tahkudele	doc_384045275267_item	2356264	et	3	main
nagu	doc_384045275267_item	2356266	et	3	main
peeglite	doc_384045275267_item	2356268	et	3	main
korraga	doc_384045275267_item	2356273	et	4	main
tõlkeanalüüs	doc_384045275267_item	2355891	et	3	main
teos	doc_384045275267_item	2355892	et	4	main
лабиринт	doc_384045275267_item	2355893	et	2	main
отражений	doc_384045275267_item	2355894	et	2	main
лукьяненко	doc_384045275267_item	2355900	et	2	main
žanr	doc_384045275267_item	2355903	et	2	main
1996	doc_384045275267_item	2355921	et	2	main
moskvas	doc_384045275267_item	2355927	et	4	main
oma	doc_384045275267_item	2355928	et	4	main
kirjandustegevust	doc_384045275267_item	2355929	et	4	main
ning	doc_384045275267_item	2355939	et	3	main
aasta	doc_384045275267_item	2355943	et	4	main
inimkonna	doc_384045275267_item	2355956	et	4	main
välja	doc_384045275267_item	2355962	et	4	main
andnud	doc_384045275267_item	2355963	et	4	main
ka	doc_384045275267_item	2355964	et	3	main
мальчик	doc_384045275267_item	2355971	et	2	main
берега	doc_384045275267_item	2355979	et	2	main
keskenduvat	doc_384045275267_item	2355987	et	4	main
seiklustele	doc_384045275267_item	2355988	et	3	main
on	doc_384045275267_item	2355989	et	4	main
tegelikult	doc_384045275267_item	2355990	et	4	main
peateemaks	doc_384045275267_item	2355991	et	4	main
sügavalt	doc_384045275267_item	2355992	et	4	main
inimlikud	doc_384045275267_item	2355993	et	3	main
küsimused	doc_384045275267_item	2355994	et	4	main
moraal	doc_384045275267_item	2355995	et	3	main
ja	doc_384045275267_item	2355996	et	3	main
selle	doc_384045275267_item	2355997	et	4	main
kaks	doc_384045275267_item	2355998	et	3	main
poolt	doc_384045275267_item	2355999	et	4	main
valikuvabadus	doc_384045275267_item	2356000	et	4	main
ja	doc_384045275267_item	2356001	et	3	main
õigus	doc_384045275267_item	2356002	et	4	main
sellele	doc_384045275267_item	2356003	et	4	main
ettemääratus	doc_384045275267_item	2356004	et	4	main
ning	doc_384045275267_item	2356005	et	3	main
saatuse	doc_384045275267_item	2356006	et	3	main
muutmine	doc_384045275267_item	2356007	et	4	main
armastus	doc_384045275267_item	2356008	et	4	main
ja	doc_384045275267_item	2356009	et	3	main
tunnete	doc_384045275267_item	2356010	et	4	main
kadumine	doc_384045275267_item	2356011	et	4	main
sergei	doc_384045275267_item	2356012	et	4	main
lukjanenko	doc_384045275267_item	2356013	et	4	main
loomingusse	doc_384045275267_item	2356014	et	3	main
kuulub	doc_384045275267_item	2356015	et	3	main
33	doc_384045275267_item	2356016	et	2	main
ja	doc_384045275267_item	2356019	et	3	main
pikemat	doc_384045275267_item	2356017	et	4	main
palju	doc_384045275267_item	2356020	et	4	main
tema	doc_384045275267_item	2356022	et	4	main
дозор	doc_384045275267_item	2356025	et	2	main
venemaal	doc_384045275267_item	2356030	et	4	main
kirjutab	doc_384045275267_item	2355935	et	3	main
ta	doc_384045275267_item	2355936	et	4	main
vene	doc_384045275267_item	2355948	et	4	main
peamiselt	doc_384045275267_item	2355950	et	4	main
tulevik	doc_384045275267_item	2355957	et	3	main
kuid	doc_384045275267_item	2355960	et	4	main
fantaasiažanris	doc_384045275267_item	2355967	et	2	main
не	doc_384045275267_item	2355974	et	2	main
холодные	doc_384045275267_item	2355978	et	2	main
kuigi	doc_384045275267_item	2355981	et	3	main
esmapilgul	doc_384045275267_item	2355982	et	4	main
romaani	doc_384045275267_item	2356018	et	4	main
on	doc_384045275267_item	2356027	et	4	main
дозор	doc_384045275267_item	2356034	et	2	main
дозор	doc_384045275267_item	2356039	et	2	main
отражений	doc_384045275267_item	2356044	et	2	main
ilmus	doc_384045275267_item	2356045	et	4	main
veel	doc_384045275267_item	2356057	et	4	main
витражи	doc_384045275267_item	2356062	et	2	main
toimub	doc_384045275267_item	2356065	et	3	main
arvutisimulatsioonis	doc_384045275267_item	2356071	et	3	main
analüüsitud	doc_384045275267_item	2356075	et	4	main
lk	doc_384045275267_item	2356081	et	4	main
я	doc_384045275267_item	2356088	et	2	main
озираюсь	doc_384045275267_item	2356089	et	2	main
ага	doc_384045275267_item	2356090	et	2	main
вот	doc_384045275267_item	2356091	et	2	main
он	doc_384045275267_item	2356092	et	2	main
огромный	doc_384045275267_item	2356093	et	2	main
дуб	doc_384045275267_item	2356094	et	2	main
мерцающий	doc_384045275267_item	2356095	et	2	main
синим	doc_384045275267_item	2356097	et	2	main
колдовским	doc_384045275267_item	2356096	et	2	main
светом	doc_384045275267_item	2356098	et	2	main
мерцающий	doc_384045275267_item	2356099	et	2	main
лишь	doc_384045275267_item	2356100	et	2	main
для	doc_384045275267_item	2356101	et	2	main
меня	doc_384045275267_item	2356102	et	2	main
я	doc_384045275267_item	2356103	et	2	main
подхожу	doc_384045275267_item	2356104	et	2	main
к	doc_384045275267_item	2356105	et	2	main
нему	doc_384045275267_item	2356106	et	2	main
засовываю	doc_384045275267_item	2356107	et	2	main
руку	doc_384045275267_item	2356108	et	2	main
в	doc_384045275267_item	2356109	et	2	main
дупло	doc_384045275267_item	2356110	et	2	main
вынимаю	doc_384045275267_item	2356111	et	2	main
большой	doc_384045275267_item	2356112	et	2	main
сверток	doc_384045275267_item	2356114	et	2	main
переодеваюсь	doc_384045275267_item	2356115	et	2	main
тяжелый	doc_384045275267_item	2356113	et	2	main
в	doc_384045275267_item	2356116	et	2	main
полотняную	doc_384045275267_item	2356117	et	2	main
белую	doc_384045275267_item	2356118	et	2	main
рубаху	doc_384045275267_item	2356119	et	2	main
и	doc_384045275267_item	2356120	et	2	main
подпоясываюсь	doc_384045275267_item	2356122	et	2	main
в	doc_384045275267_item	2356127	et	2	main
labürint	doc_384045275267_item	2356042	et	3	main
1997	doc_384045275267_item	2356046	et	2	main
samanimelise	doc_384045275267_item	2356052	et	4	main
triloogias	doc_384045275267_item	2356053	et	3	main
kuuluvad	doc_384045275267_item	2356055	et	4	main
sinna	doc_384045275267_item	2356056	et	3	main
прозрачные	doc_384045275267_item	2356061	et	2	main
tegevustik	doc_384045275267_item	2356064	et	3	main
osas	doc_384045275267_item	2356067	et	4	main
deeptown	doc_384045275267_item	2356074	et	4	main
lõik	doc_384045275267_item	2356076	et	3	main
светящееся	doc_384045275267_item	2356084	et	2	main
поясом	doc_384045275267_item	2356124	et	2	main
карманах	doc_384045275267_item	2356132	et	2	main
дней	doc_384045275267_item	2356137	et	2	main
компьютеров	doc_384045275267_item	2356143	et	2	main
железной	doc_384045275267_item	2356147	et	2	main
они	doc_384045275267_item	2356152	et	2	main
маленького	doc_384045275267_item	2356157	et	2	main
ringi	doc_384045275267_item	2356165	et	4	main
ongi	doc_384045275267_item	2356169	et	4	main
nõiduslikult	doc_384045275267_item	2356171	et	4	main
helendab	doc_384045275267_item	2356174	et	3	main
ma	doc_384045275267_item	2356179	et	3	main
võtan	doc_384045275267_item	2356187	et	3	main
suure	doc_384045275267_item	2356189	et	3	main
paki	doc_384045275267_item	2356191	et	4	main
1	doc_384045275267_item	2356235	et	2	main
peegelduste	doc_384045275267_item	2356239	et	4	main
toodud	doc_384045275267_item	2356246	et	4	main
ka	doc_384045275267_item	2356261	et	3	main
mis	doc_384045275267_item	2356265	et	4	main
peegelpilt	doc_384045275267_item	2356267	et	3	main
avane	doc_384045275267_item	2356271	et	4	main
kõik	doc_384045275267_item	2356272	et	4	main
kaalutlustel	doc_384045275267_item	2356314	et	4	main
peegelduse	doc_384045275267_item	2356317	et	4	main
kasuks	doc_384045275267_item	2356318	et	4	main
helendav	doc_384045275267_item	2356339	et	4	main
lause	doc_384045275267_item	2356343	et	4	main
on	doc_384045275267_item	2356344	et	4	main
otsetõlge	doc_384045275267_item	2356345	et	3	main
озираюсь	doc_384045275267_item	2356350	et	2	main
3	doc_384045275267_item	2356355	et	2	main
огромный	doc_384045275267_item	2356359	et	2	main
синим	doc_384045275267_item	2356363	et	2	main
hiiglaslik	doc_384045275267_item	2356369	et	3	main
tamm	doc_384045275267_item	2356372	et	3	main
või	doc_384045275267_item	2356382	et	4	main
ole	doc_384045275267_item	2356387	et	4	main
vene	doc_384045275267_item	2356392	et	4	main
eesti	doc_384045275267_item	2356394	et	4	main
nõidust	doc_384045275267_item	2356422	et	3	main
tavaliselt	doc_384045275267_item	2356431	et	4	main
ole	doc_384045275267_item	2356447	et	4	main
lähedalt	doc_384045275267_item	2356449	et	4	main
arvutimängudega	doc_384045275267_item	2356451	et	3	main
ei	doc_384045275267_item	2356455	et	4	main
selline	doc_384045275267_item	2356469	et	4	main
tähendusliku	doc_384045275267_item	2356476	et	3	main
ei	doc_384045275267_item	2356479	et	4	main
дупло	doc_384045275267_item	2356520	et	2	main
сверток	doc_384045275267_item	2356524	et	2	main
lähen	doc_384045275267_item	2356526	et	3	main
juurde	doc_384045275267_item	2356528	et	4	main
lausest	doc_384045275267_item	2356540	et	4	main
к	doc_384045275267_item	2356546	et	2	main
lause	doc_384045275267_item	2356559	et	4	main
и	doc_384045275267_item	2356571	et	2	main
ümber	doc_384045275267_item	2356577	et	3	main
särki	doc_384045275267_item	2356579	et	4	main
ja	doc_384045275267_item	2356580	et	3	main
pükstesse	doc_384045275267_item	2356581	et	3	main
tõlkes	doc_384045275267_item	2356596	et	3	main
täpsustuseks	doc_384045275267_item	2356617	et	4	main
on	doc_384045275267_item	2356620	et	4	main
särgil	doc_384045275267_item	2356631	et	3	main
läheb	doc_384045275267_item	2356633	et	3	main
rahvarõivavööga	doc_384045275267_item	2356640	et	3	main
on	doc_384045275267_item	2356654	et	4	main
algusest	doc_384045275267_item	2356080	et	4	main
дерево	doc_384045275267_item	2356085	et	2	main
короткий	doc_384045275267_item	2356125	et	2	main
несколько	doc_384045275267_item	2356129	et	2	main
тайник	doc_384045275267_item	2356133	et	2	main
назад	doc_384045275267_item	2356138	et	2	main
транспортного	doc_384045275267_item	2356144	et	2	main
там	doc_384045275267_item	2356149	et	2	main
не	doc_384045275267_item	2356154	et	2	main
seal	doc_384045275267_item	2356167	et	4	main
ta	doc_384045275267_item	2356175	et	4	main
pistan	doc_384045275267_item	2356183	et	3	main
õõnde	doc_384045275267_item	2356185	et	3	main
riietun	doc_384045275267_item	2356192	et	3	main
ja	doc_384045275267_item	2356196	et	3	main
tõmban	doc_384045275267_item	2356198	et	3	main
vöö	doc_384045275267_item	2356199	et	4	main
vööle	doc_384045275267_item	2356200	et	3	main
lühike	doc_384045275267_item	2356201	et	4	main
mõõk	doc_384045275267_item	2356202	et	3	main
tupes	doc_384045275267_item	2356203	et	4	main
igasugused	doc_384045275267_item	2356204	et	3	main
asjakesed	doc_384045275267_item	2356205	et	4	main
taskus	doc_384045275267_item	2356206	et	3	main
peidiku	doc_384045275267_item	2356207	et	3	main
tegin	doc_384045275267_item	2356208	et	3	main
paar	doc_384045275267_item	2356209	et	3	main
tagasi	doc_384045275267_item	2356211	et	3	main
päeva	doc_384045275267_item	2356210	et	4	main
kasutades	doc_384045275267_item	2356212	et	3	main
ebaseaduslikult	doc_384045275267_item	2356213	et	4	main
taga-kaukaasia	doc_384045275267_item	2356215	et	4	main
üht	doc_384045275267_item	2356214	et	3	main
raudteede	doc_384045275267_item	2356216	et	3	main
transpordiameti	doc_384045275267_item	2356217	et	3	main
arvutit	doc_384045275267_item	2356218	et	3	main
seal	doc_384045275267_item	2356219	et	4	main
töötavad	doc_384045275267_item	2356220	et	4	main
programmeerijad	doc_384045275267_item	2356222	et	4	main
nad	doc_384045275267_item	2356223	et	3	main
märka	doc_384045275267_item	2356225	et	4	main
pisikest	doc_384045275267_item	2356228	et	4	main
sissetungi	doc_384045275267_item	2356229	et	4	main
i	doc_384045275267_item	2356230	et	4	main
tõlke	doc_384045275267_item	2356233	et	4	main
labürint	doc_384045275267_item	2356240	et	3	main
pealkiri	doc_384045275267_item	2356241	et	3	main
lisaks	doc_384045275267_item	2356251	et	4	main
teoses	doc_384045275267_item	2356253	et	3	main
otsenähtavale	doc_384045275267_item	2356254	et	3	main
labürindis	doc_384045275267_item	2356269	et	3	main
ei	doc_384045275267_item	2356270	et	4	main
ning	doc_384045275267_item	2356274	et	3	main
valiku	doc_384045275267_item	2356316	et	3	main
lause-lauselt	doc_384045275267_item	2356323	et	4	main
1	doc_384045275267_item	2356334	et	2	main
дерево	doc_384045275267_item	2356336	et	2	main
программа	doc_384045275267_item	2356338	et	2	main
vene	doc_384045275267_item	2356346	et	4	main
штаны	doc_384045275267_item	2356121	et	2	main
меч	doc_384045275267_item	2356126	et	2	main
вещичек	doc_384045275267_item	2356130	et	2	main
я	doc_384045275267_item	2356134	et	2	main
незаконно	doc_384045275267_item	2356139	et	2	main
из	doc_384045275267_item	2356142	et	2	main
дороги	doc_384045275267_item	2356148	et	2	main
долго	doc_384045275267_item	2356153	et	2	main
вторжения	doc_384045275267_item	2356158	et	2	main
teatab	doc_384045275267_item	2356161	et	3	main
vaatan	doc_384045275267_item	2356164	et	3	main
helendav	doc_384045275267_item	2356172	et	4	main
ainult	doc_384045275267_item	2356176	et	4	main
minu	doc_384045275267_item	2356177	et	3	main
juurde	doc_384045275267_item	2356182	et	4	main
käe	doc_384045275267_item	2356184	et	3	main
linasesse	doc_384045275267_item	2356194	et	4	main
в	doc_384045275267_item	2356131	et	2	main
пару	doc_384045275267_item	2356136	et	2	main
использовав	doc_384045275267_item	2356140	et	2	main
управления	doc_384045275267_item	2356145	et	2	main
слабые	doc_384045275267_item	2356150	et	2	main
заметят	doc_384045275267_item	2356155	et	2	main
helendav	doc_384045275267_item	2356159	et	4	main
programm	doc_384045275267_item	2356162	et	3	main
ahaa	doc_384045275267_item	2356166	et	3	main
hiiglaslik	doc_384045275267_item	2356170	et	3	main
tamm	doc_384045275267_item	2356173	et	3	main
lähen	doc_384045275267_item	2356180	et	3	main
ümber	doc_384045275267_item	2356193	et	3	main
särki	doc_384045275267_item	2356195	et	4	main
pükstesse	doc_384045275267_item	2356197	et	3	main
nõrgad	doc_384045275267_item	2356221	et	3	main
võrdlus	doc_384045275267_item	2356234	et	3	main
лабиринт	doc_384045275267_item	2356237	et	2	main
keelde	doc_384045275267_item	2356244	et	4	main
üle	doc_384045275267_item	2356245	et	3	main
pealkirjaga	doc_384045275267_item	2356248	et	3	main
peegeldus	doc_384045275267_item	2356259	et	4	main
küberruumis	doc_384045275267_item	2356260	et	3	main
varjab	doc_384045275267_item	2356275	et	3	main
erinevaid	doc_384045275267_item	2356277	et	4	main
lõigu	doc_384045275267_item	2356320	et	4	main
tekst	doc_384045275267_item	2356321	et	3	main
vene	doc_384045275267_item	2356326	et	4	main
puu	doc_384045275267_item	2356340	et	4	main
teatab	doc_384045275267_item	2356341	et	3	main
programm	doc_384045275267_item	2356342	et	3	main
я	doc_384045275267_item	2356349	et	2	main
ringi	doc_384045275267_item	2356353	et	4	main
otsetõlge	doc_384045275267_item	2356354	et	3	main
он	doc_384045275267_item	2356358	et	2	main
мерцающий	doc_384045275267_item	2356361	et	2	main
seal	doc_384045275267_item	2356366	et	4	main
nõiduslikult	doc_384045275267_item	2356370	et	4	main
tõlkija	doc_384045275267_item	2356373	et	4	main
mingil	doc_384045275267_item	2356375	et	4	main
põhjusel	doc_384045275267_item	2356376	et	3	main
otsustanud	doc_384045275267_item	2356377	et	4	main
mõttemuutusel	doc_384045275267_item	2356383	et	4	main
põhjendust	doc_384045275267_item	2356385	et	4	main
ага	doc_384045275267_item	2356388	et	2	main
ahaaa	doc_384045275267_item	2356389	et	4	main
tähistab	doc_384045275267_item	2356390	et	3	main
nii	doc_384045275267_item	2356391	et	3	main
arusaamist	doc_384045275267_item	2356399	et	4	main
autor	doc_384045275267_item	2356435	et	3	main
et	doc_384045275267_item	2356437	et	3	main
on	doc_384045275267_item	2356439	et	4	main
kasuliku	doc_384045275267_item	2356441	et	3	main
et	doc_384045275267_item	2356444	et	3	main
värvuse	doc_384045275267_item	2356465	et	3	main
tähtis	doc_384045275267_item	2356468	et	4	main
küll	doc_384045275267_item	2356472	et	4	main
põhjendatud	doc_384045275267_item	2356473	et	4	main
vajadusega	doc_384045275267_item	2356477	et	3	main
мерцающий	doc_384045275267_item	2356483	et	2	main
vastena	doc_384045275267_item	2356484	et	3	main
тяжелый	doc_384045275267_item	2356523	et	2	main
käe	doc_384045275267_item	2356530	et	3	main
raske	doc_384045275267_item	2356536	et	4	main
on	doc_384045275267_item	2356544	et	4	main
on	doc_384045275267_item	2356558	et	4	main
asemel	doc_384045275267_item	2356561	et	4	main
6	doc_384045275267_item	2356565	et	2	main
в	doc_384045275267_item	2356567	et	2	main
белую	doc_384045275267_item	2356569	et	2	main
riietun	doc_384045275267_item	2356576	et	3	main
vööle	doc_384045275267_item	2356584	et	3	main
suuremad	doc_384045275267_item	2356591	et	4	main
rahvarõivasärg	doc_384045275267_item	2356608	et	3	main
ilmselt	doc_384045275267_item	2356616	et	4	main
kirjatud	doc_384045275267_item	2356629	et	4	main
kaduma	doc_384045275267_item	2356634	et	4	main
et	doc_384045275267_item	2356635	et	3	main
ning	doc_384045275267_item	2356641	et	3	main
seda	doc_384045275267_item	2356643	et	3	main
ei	doc_384045275267_item	2356224	et	4	main
veel	doc_384045275267_item	2356226	et	4	main
kaua	doc_384045275267_item	2356227	et	3	main
ja	doc_384045275267_item	2356232	et	3	main
pealkiri	doc_384045275267_item	2356236	et	3	main
autor	doc_384045275267_item	2356250	et	3	main
antud	doc_384045275267_item	2356252	et	4	main
inimloomuse	doc_384045275267_item	2356262	et	3	main
endas	doc_384045275267_item	2356276	et	4	main
olemusi	doc_384045275267_item	2356278	et	3	main
minasid	doc_384045275267_item	2356279	et	3	main
mis	doc_384045275267_item	2356280	et	4	main
võivad	doc_384045275267_item	2356281	et	4	main
olla	doc_384045275267_item	2356282	et	3	main
vägagi	doc_384045275267_item	2356283	et	3	main
mitmekülgsed	doc_384045275267_item	2356284	et	3	main
ja	doc_384045275267_item	2356285	et	3	main
ka	doc_384045275267_item	2356286	et	3	main
inimesele	doc_384045275267_item	2356287	et	3	main
endale	doc_384045275267_item	2356288	et	4	main
ootamatud	doc_384045275267_item	2356289	et	4	main
л	doc_384045275267_item	2356290	et	2	main
абиринт	doc_384045275267_item	2356291	et	2	main
labürint	doc_384045275267_item	2356292	et	3	main
о	doc_384045275267_item	2356293	et	2	main
тражение	doc_384045275267_item	2356294	et	2	main
peegeldus	doc_384045275267_item	2356295	et	4	main
peegelpilt	doc_384045275267_item	2356296	et	3	main
antud	doc_384045275267_item	2356297	et	4	main
tähenduses	doc_384045275267_item	2356298	et	4	main
on	doc_384045275267_item	2356299	et	4	main
võib	doc_384045275267_item	2356300	et	3	main
eesti	doc_384045275267_item	2356301	et	4	main
keeles	doc_384045275267_item	2356302	et	4	main
lugeda	doc_384045275267_item	2356303	et	3	main
sõna	doc_384045275267_item	2356304	et	4	main
peegelpilt	doc_384045275267_item	2356305	et	3	main
tähenduses	doc_384045275267_item	2356306	et	4	main
võrdseks	doc_384045275267_item	2356307	et	4	main
sõnaga	doc_384045275267_item	2356308	et	3	main
peegeldus	doc_384045275267_item	2356309	et	4	main
tõlkija	doc_384045275267_item	2356310	et	4	main
on	doc_384045275267_item	2356311	et	4	main
ilmselt	doc_384045275267_item	2356312	et	4	main
stilistilistel	doc_384045275267_item	2356313	et	4	main
teinud	doc_384045275267_item	2356315	et	4	main
2	doc_384045275267_item	2356319	et	2	main
võrdlesin	doc_384045275267_item	2356322	et	3	main
sõna-sõnalt	doc_384045275267_item	2356325	et	3	main
keelset	doc_384045275267_item	2356327	et	3	main
originaalteksti	doc_384045275267_item	2356328	et	4	main
ja	doc_384045275267_item	2356329	et	3	main
selle	doc_384045275267_item	2356330	et	4	main
eesti	doc_384045275267_item	2356331	et	4	main
keelset	doc_384045275267_item	2356332	et	3	main
tõlget	doc_384045275267_item	2356333	et	3	main
светящееся	doc_384045275267_item	2356335	et	2	main
сообщает	doc_384045275267_item	2356337	et	2	main
2	doc_384045275267_item	2356348	et	2	main
ongi	doc_384045275267_item	2356368	et	4	main
on	doc_384045275267_item	2356374	et	4	main
põhinevat	doc_384045275267_item	2356384	et	4	main
ei	doc_384045275267_item	2356386	et	4	main
kui	doc_384045275267_item	2356393	et	3	main
maagiat	doc_384045275267_item	2356421	et	3	main
arvutimängudes	doc_384045275267_item	2356423	et	3	main
heade	doc_384045275267_item	2356425	et	3	main
heasoovliku	doc_384045275267_item	2356427	et	3	main
maagia	doc_384045275267_item	2356429	et	4	main
sinine	doc_384045275267_item	2356432	et	4	main
st	doc_384045275267_item	2356434	et	3	main
rõhutab	doc_384045275267_item	2356436	et	3	main
tegemist	doc_384045275267_item	2356438	et	4	main
hea	doc_384045275267_item	2356440	et	4	main
puuga	doc_384045275267_item	2356442	et	3	main
võimalik	doc_384045275267_item	2356443	et	3	main
tal	doc_384045275267_item	2356453	et	3	main
maagilise	doc_384045275267_item	2356463	et	4	main
helenduse	doc_384045275267_item	2356464	et	4	main
ka	doc_384045275267_item	2356478	et	3	main
helendav	doc_384045275267_item	2356481	et	4	main
päris	doc_384045275267_item	2356482	et	4	main
мерцающий	doc_384045275267_item	2356485	et	2	main
kirjeldab	doc_384045275267_item	2356486	et	3	main
värelevat	doc_384045275267_item	2356488	et	4	main
вынимаю	doc_384045275267_item	2356521	et	2	main
õõnde	doc_384045275267_item	2356531	et	3	main
võtan	doc_384045275267_item	2356533	et	3	main
suure	doc_384045275267_item	2356535	et	3	main
нему	doc_384045275267_item	2356547	et	2	main
подпоясываюсь	doc_384045275267_item	2356573	et	2	main
vöö	doc_384045275267_item	2356583	et	4	main
lauses	doc_384045275267_item	2356586	et	3	main
antud	doc_384045275267_item	2356588	et	4	main
lõigus	doc_384045275267_item	2356589	et	3	main
läheb	doc_384045275267_item	2356595	et	3	main
kõige	doc_384045275267_item	2356598	et	4	main
siin	doc_384045275267_item	2356603	et	4	main
rõhutatud	doc_384045275267_item	2356610	et	4	main
et	doc_384045275267_item	2356612	et	3	main
tavaliselt	doc_384045275267_item	2356622	et	4	main
loomuliku	doc_384045275267_item	2356624	et	3	main
punased	doc_384045275267_item	2356628	et	4	main
on	doc_384045275267_item	2356637	et	4	main
et	doc_384045275267_item	2356642	et	3	main
kehastub	doc_384045275267_item	2356660	et	3	main
talupoeg	doc_384045275267_item	2356662	et	3	main
kes	doc_384045275267_item	2356664	et	4	main
saatel	doc_384045275267_item	2356667	et	4	main
seiklema	doc_384045275267_item	2356668	et	3	main
läheb	doc_384045275267_item	2356669	et	3	main
короткий	doc_384045275267_item	2356671	et	2	main
несколько	doc_384045275267_item	2356675	et	2	main
карманах	doc_384045275267_item	2356678	et	2	main
mõned	doc_384045275267_item	2356733	et	3	main
из	doc_384045275267_item	2356748	et	2	main
железной	doc_384045275267_item	2356753	et	2	main
raudteede	doc_384045275267_item	2356764	et	3	main
заметят	doc_384045275267_item	2356780	et	2	main
seal	doc_384045275267_item	2356784	et	4	main
nõrgad	doc_384045275267_item	2356786	et	3	main
on	doc_384045275267_item	2356822	et	4	main
tõlkes	doc_384045275267_item	2356823	et	3	main
programmeerijad	doc_384045275267_item	2356840	et	4	main
ei	doc_384045275267_item	2356841	et	4	main
ja	doc_384045275267_item	2356324	et	3	main
keelest	doc_384045275267_item	2356347	et	4	main
ma	doc_384045275267_item	2356351	et	3	main
вот	doc_384045275267_item	2356357	et	2	main
дуб	doc_384045275267_item	2356360	et	2	main
светом	doc_384045275267_item	2356364	et	2	main
helendav	doc_384045275267_item	2356371	et	4	main
ühendada	doc_384045275267_item	2356378	et	3	main
kaks	doc_384045275267_item	2356379	et	3	main
lauset	doc_384045275267_item	2356380	et	3	main
stilistilist	doc_384045275267_item	2356381	et	4	main
välja	doc_384045275267_item	2356403	et	4	main
jäetud	doc_384045275267_item	2356404	et	4	main
vene	doc_384045275267_item	2356405	et	4	main
keelne	doc_384045275267_item	2356406	et	3	main
sõna	doc_384045275267_item	2356407	et	4	main
синии	doc_384045275267_item	2356408	et	2	main
sinine	doc_384045275267_item	2356409	et	4	main
sergei	doc_384045275267_item	2356410	et	4	main
kui	doc_384045275267_item	2356412	et	3	main
kogenud	doc_384045275267_item	2356413	et	4	main
arvutimängude	doc_384045275267_item	2356414	et	3	main
lukjanenko	doc_384045275267_item	2356411	et	4	main
mängija	doc_384045275267_item	2356415	et	4	main
jaoks	doc_384045275267_item	2356416	et	4	main
tähistab	doc_384045275267_item	2356417	et	3	main
sinine	doc_384045275267_item	2356418	et	4	main
värv	doc_384045275267_item	2356419	et	3	main
ilmselt	doc_384045275267_item	2356420	et	4	main
on	doc_384045275267_item	2356424	et	4	main
kangelaste	doc_384045275267_item	2356426	et	4	main
kasuliku	doc_384045275267_item	2356428	et	3	main
ei	doc_384045275267_item	2356446	et	4	main
ja	doc_384045275267_item	2356459	et	3	main
või	doc_384045275267_item	2356475	et	4	main
midagi	doc_384045275267_item	2356487	et	4	main
vaatan	doc_384045275267_item	2356352	et	3	main
ага	doc_384045275267_item	2356356	et	2	main
колдовским	doc_384045275267_item	2356362	et	2	main
ahaa	doc_384045275267_item	2356365	et	3	main
ta	doc_384045275267_item	2356367	et	4	main
keeles	doc_384045275267_item	2356395	et	4	main
nii	doc_384045275267_item	2356396	et	3	main
tähelepanu	doc_384045275267_item	2356397	et	4	main
kui	doc_384045275267_item	2356398	et	3	main
edasi	doc_384045275267_item	2356400	et	3	main
on	doc_384045275267_item	2356401	et	4	main
lauses	doc_384045275267_item	2356402	et	3	main
värviks	doc_384045275267_item	2356430	et	4	main
sinakasvalge	doc_384045275267_item	2356433	et	4	main
tõlkija	doc_384045275267_item	2356445	et	4	main
nii	doc_384045275267_item	2356448	et	3	main
kursis	doc_384045275267_item	2356450	et	3	main
või	doc_384045275267_item	2356452	et	4	main
lihtsalt	doc_384045275267_item	2356454	et	4	main
tekkinud	doc_384045275267_item	2356456	et	4	main
sellist	doc_384045275267_item	2356457	et	4	main
assotsiatsiooni	doc_384045275267_item	2356458	et	4	main
ta	doc_384045275267_item	2356460	et	4	main
leidis	doc_384045275267_item	2356461	et	4	main
et	doc_384045275267_item	2356462	et	3	main
rõhutamine	doc_384045275267_item	2356466	et	4	main
pole	doc_384045275267_item	2356467	et	3	main
otsus	doc_384045275267_item	2356470	et	3	main
pole	doc_384045275267_item	2356471	et	3	main
keelelise	doc_384045275267_item	2356474	et	4	main
sobi	doc_384045275267_item	2356480	et	4	main
mitte	doc_384045275267_item	2356489	et	3	main
stabiilset	doc_384045275267_item	2356490	et	3	main
helendust	doc_384045275267_item	2356491	et	4	main
мерцающий	doc_384045275267_item	2356493	et	2	main
лишь	doc_384045275267_item	2356494	et	2	main
4	doc_384045275267_item	2356492	et	2	main
для	doc_384045275267_item	2356495	et	2	main
меня	doc_384045275267_item	2356496	et	2	main
helendab	doc_384045275267_item	2356497	et	3	main
ta	doc_384045275267_item	2356498	et	4	main
ainult	doc_384045275267_item	2356499	et	4	main
minu	doc_384045275267_item	2356500	et	3	main
jaoks	doc_384045275267_item	2356501	et	4	main
eesti	doc_384045275267_item	2356502	et	4	main
keeles	doc_384045275267_item	2356503	et	4	main
on	doc_384045275267_item	2356504	et	4	main
lisatud	doc_384045275267_item	2356505	et	4	main
ta	doc_384045275267_item	2356506	et	4	main
rõhutades	doc_384045275267_item	2356507	et	3	main
et	doc_384045275267_item	2356508	et	3	main
mõeldakse	doc_384045275267_item	2356509	et	3	main
kindlasti	doc_384045275267_item	2356510	et	3	main
tamme	doc_384045275267_item	2356511	et	4	main
5	doc_384045275267_item	2356512	et	2	main
я	doc_384045275267_item	2356513	et	2	main
подхожу	doc_384045275267_item	2356514	et	2	main
к	doc_384045275267_item	2356515	et	2	main
нему	doc_384045275267_item	2356516	et	2	main
засовываю	doc_384045275267_item	2356517	et	2	main
руку	doc_384045275267_item	2356518	et	2	main
в	doc_384045275267_item	2356519	et	2	main
ma	doc_384045275267_item	2356525	et	3	main
ja	doc_384045275267_item	2356532	et	3	main
sealt	doc_384045275267_item	2356534	et	4	main
paki	doc_384045275267_item	2356537	et	4	main
suurem	doc_384045275267_item	2356538	et	4	main
kaks	doc_384045275267_item	2356545	et	3	main
asendatud	doc_384045275267_item	2356549	et	4	main
nimisõnaga	doc_384045275267_item	2356550	et	3	main
puu	doc_384045275267_item	2356551	et	4	main
большой	doc_384045275267_item	2356522	et	2	main
puu	doc_384045275267_item	2356527	et	4	main
pistan	doc_384045275267_item	2356529	et	3	main
osa	doc_384045275267_item	2356539	et	4	main
on	doc_384045275267_item	2356541	et	4	main
otsetõlge	doc_384045275267_item	2356542	et	3	main
muutusi	doc_384045275267_item	2356543	et	4	main
on	doc_384045275267_item	2356548	et	4	main
tõlkes	doc_384045275267_item	2356557	et	3	main
штаны	doc_384045275267_item	2356572	et	2	main
поясом	doc_384045275267_item	2356575	et	2	main
linasesse	doc_384045275267_item	2356578	et	4	main
on	doc_384045275267_item	2356587	et	4	main
kõige	doc_384045275267_item	2356590	et	4	main
kaduma	doc_384045275267_item	2356597	et	4	main
rohkem	doc_384045275267_item	2356599	et	4	main
informatsiooni	doc_384045275267_item	2356600	et	4	main
autor	doc_384045275267_item	2356601	et	3	main
kirjeldab	doc_384045275267_item	2356602	et	3	main
talupoeg-kangelast	doc_384045275267_item	2356607	et	4	main
on	doc_384045275267_item	2356611	et	4	main
sest	doc_384045275267_item	2356618	et	4	main
ilmselt	doc_384045275267_item	2356552	et	4	main
teksti	doc_384045275267_item	2356553	et	4	main
parema	doc_384045275267_item	2356554	et	4	main
mõistmise	doc_384045275267_item	2356555	et	4	main
huvides	doc_384045275267_item	2356556	et	3	main
koma	doc_384045275267_item	2356560	et	4	main
ühendatud	doc_384045275267_item	2356562	et	4	main
sidesõnaga	doc_384045275267_item	2356563	et	3	main
ja	doc_384045275267_item	2356564	et	3	main
переодеваюсь	doc_384045275267_item	2356566	et	2	main
полотняную	doc_384045275267_item	2356568	et	2	main
рубаху	doc_384045275267_item	2356570	et	2	main
узорчатым	doc_384045275267_item	2356574	et	2	main
tõmban	doc_384045275267_item	2356582	et	3	main
selles	doc_384045275267_item	2356585	et	4	main
muutused	doc_384045275267_item	2356592	et	4	main
ja	doc_384045275267_item	2356593	et	3	main
siin	doc_384045275267_item	2356594	et	4	main
rõivastusega	doc_384045275267_item	2356604	et	4	main
vene	doc_384045275267_item	2356605	et	4	main
muinasjuttude	doc_384045275267_item	2356606	et	4	main
linane	doc_384045275267_item	2356609	et	4	main
särk	doc_384045275267_item	2356613	et	3	main
on	doc_384045275267_item	2356614	et	4	main
hele	doc_384045275267_item	2356615	et	3	main
muinasjuttudes	doc_384045275267_item	2356619	et	3	main
särgid	doc_384045275267_item	2356621	et	3	main
kas	doc_384045275267_item	2356623	et	3	main
linase	doc_384045275267_item	2356625	et	4	main
värvi	doc_384045275267_item	2356626	et	4	main
vöö	doc_384045275267_item	2356630	et	4	main
tõlkes	doc_384045275267_item	2356632	et	3	main
tegemist	doc_384045275267_item	2356636	et	4	main
just	doc_384045275267_item	2356638	et	3	main
kirjatud	doc_384045275267_item	2356639	et	4	main
särgi	doc_384045275267_item	2356645	et	4	main
eesti	doc_384045275267_item	2356647	et	4	main
keeles	doc_384045275267_item	2356648	et	4	main
läheb	doc_384045275267_item	2356649	et	3	main
kogu	doc_384045275267_item	2356650	et	4	main
muinasjutuhõngulisus	doc_384045275267_item	2356651	et	4	main
ножнах	doc_384045275267_item	2356674	et	2	main
в	doc_384045275267_item	2356677	et	2	main
on	doc_384045275267_item	2356722	et	4	main
valitud	doc_384045275267_item	2356724	et	4	main
parem	doc_384045275267_item	2356728	et	4	main
valik	doc_384045275267_item	2356729	et	3	main
tõlkes	doc_384045275267_item	2356730	et	3	main
oleks	doc_384045275267_item	2356731	et	3	main
olnud	doc_384045275267_item	2356732	et	4	main
назад	doc_384045275267_item	2356744	et	2	main
компьютеров	doc_384045275267_item	2356749	et	2	main
дороги	doc_384045275267_item	2356754	et	2	main
kasutades	doc_384045275267_item	2356760	et	3	main
arvutit	doc_384045275267_item	2356766	et	3	main
praktiliselt	doc_384045275267_item	2356767	et	4	main
muudetud	doc_384045275267_item	2356771	et	4	main
eestipärasemaks	doc_384045275267_item	2356772	et	4	main
там	doc_384045275267_item	2356774	et	2	main
они	doc_384045275267_item	2356777	et	2	main
маленького	doc_384045275267_item	2356782	et	2	main
ära	doc_384045275267_item	2356828	et	4	main
jäetud	doc_384045275267_item	2356829	et	4	main
этого	doc_384045275267_item	2356830	et	2	main
seda	doc_384045275267_item	2356831	et	3	main
vihje	doc_384045275267_item	2356837	et	4	main
võimalik	doc_384045275267_item	2356851	et	3	main
juhtudest	doc_384045275267_item	2356866	et	3	main
kasutab	doc_384045275267_item	2356867	et	3	main
sõna	doc_384045275267_item	2356870	et	4	main
otsest	doc_384045275267_item	2356871	et	4	main
eesti	doc_384045275267_item	2356872	et	4	main
keelset	doc_384045275267_item	2356873	et	3	main
sõna	doc_384045275267_item	2356877	et	4	main
vasteks	doc_384045275267_item	2356880	et	3	main
tähenduste	doc_384045275268_item	2356892	et	4	main
täpsemalt	doc_384045275268_item	2356894	et	4	main
erinevuse	doc_384045275268_item	2356905	et	4	main
vahel	doc_384045275268_item	2356921	et	4	main
antonüümiat	doc_384045275268_item	2356937	et	3	main
või	doc_384045275267_item	2356627	et	4	main
kantakse	doc_384045275267_item	2356644	et	3	main
samas	doc_384045275267_item	2356653	et	4	main
ivaniks	doc_384045275267_item	2356663	et	4	main
mõõk	doc_384045275267_item	2356680	et	3	main
tupes	doc_384045275267_item	2356681	et	4	main
igasugused	doc_384045275267_item	2356682	et	3	main
taskus	doc_384045275267_item	2356684	et	3	main
несколько	doc_384045275267_item	2356685	et	2	main
mõned	doc_384045275267_item	2356686	et	3	main
mõningad	doc_384045275267_item	2356687	et	3	main
eesti	doc_384045275267_item	2356688	et	4	main
asjakesed	doc_384045275267_item	2356683	et	4	main
keelne	doc_384045275267_item	2356689	et	3	main
tõlge	doc_384045275267_item	2356690	et	3	main
igasugused	doc_384045275267_item	2356691	et	3	main
asjakesed	doc_384045275267_item	2356692	et	4	main
püüab	doc_384045275267_item	2356693	et	3	main
rõhutada	doc_384045275267_item	2356694	et	3	main
et	doc_384045275267_item	2356695	et	3	main
tegemist	doc_384045275267_item	2356696	et	4	main
on	doc_384045275267_item	2356697	et	4	main
kõikvõimaliku	doc_384045275267_item	2356698	et	3	main
vajaliku	doc_384045275267_item	2356699	et	3	main
kraamiga	doc_384045275267_item	2356700	et	3	main
jättes	doc_384045275267_item	2356701	et	4	main
lugejale	doc_384045275267_item	2356702	et	4	main
mulje	doc_384045275267_item	2356703	et	4	main
sellest	doc_384045275267_item	2356704	et	4	main
et	doc_384045275267_item	2356705	et	3	main
asjakesi	doc_384045275267_item	2356706	et	4	main
on	doc_384045275267_item	2356707	et	4	main
palju	doc_384045275267_item	2356708	et	4	main
samas	doc_384045275267_item	2356709	et	4	main
väljendab	doc_384045275267_item	2356710	et	3	main
vene	doc_384045275267_item	2356711	et	4	main
несколько	doc_384045275267_item	2356712	et	2	main
seda	doc_384045275267_item	2356713	et	3	main
et	doc_384045275267_item	2356714	et	3	main
tegemist	doc_384045275267_item	2356715	et	4	main
peal	doc_384045275267_item	2356646	et	4	main
kaduma	doc_384045275267_item	2356652	et	4	main
tähtis	doc_384045275267_item	2356656	et	4	main
kuna	doc_384045275267_item	2356657	et	3	main
peakangelane	doc_384045275267_item	2356661	et	3	main
меч	doc_384045275267_item	2356672	et	2	main
вещичек	doc_384045275267_item	2356676	et	2	main
lühike	doc_384045275267_item	2356679	et	4	main
asjakesed	doc_384045275267_item	2356734	et	4	main
või	doc_384045275267_item	2356735	et	4	main
дней	doc_384045275267_item	2356743	et	2	main
один	doc_384045275267_item	2356747	et	2	main
закавказской	doc_384045275267_item	2356752	et	2	main
peidiku	doc_384045275267_item	2356755	et	3	main
päeva	doc_384045275267_item	2356758	et	4	main
программисты	doc_384045275267_item	2356776	et	2	main
этого	doc_384045275267_item	2356781	et	2	main
nad	doc_384045275267_item	2356788	et	3	main
sõna	doc_384045275267_item	2356825	et	4	main
osavusest	doc_384045275267_item	2356839	et	4	main
sissetungi	doc_384045275267_item	2356847	et	4	main
vähemosavat	doc_384045275267_item	2356849	et	3	main
et	doc_384045275267_item	2356852	et	3	main
võrdluse	doc_384045275267_item	2356854	et	3	main
jõudsin	doc_384045275267_item	2356856	et	3	main
enamikul	doc_384045275267_item	2356865	et	3	main
antakse	doc_384045275267_item	2356881	et	3	main
tähendusnüansse	doc_384045275267_item	2356888	et	3	main
referaat	doc_384045275268_item	2356889	et	3	main
ühe	doc_384045275268_item	2356896	et	4	main
tunnusjoone	doc_384045275268_item	2356898	et	3	main
alusel	doc_384045275268_item	2356900	et	4	main
vaid	doc_384045275268_item	2356906	et	3	main
liikme	doc_384045275268_item	2356927	et	3	main
tähendusele	doc_384045275268_item	2356928	et	4	main
suhe	doc_384045275268_item	2356934	et	3	main
võib	doc_384045275268_item	2356936	et	3	main
pidada	doc_384045275268_item	2356938	et	4	main
neid	doc_384045275268_item	2356948	et	4	main
ühe	doc_384045275268_item	2356951	et	4	main
tunnuse	doc_384045275268_item	2356953	et	3	main
alusel	doc_384045275268_item	2356954	et	4	main
näiteks	doc_384045275268_item	2356955	et	4	main
on	doc_384045275268_item	2356956	et	4	main
kuid	doc_384045275268_item	2356961	et	4	main
samas	doc_384045275268_item	2356963	et	4	main
antonüüm	doc_384045275268_item	2356966	et	3	main
põhinevad	doc_384045275268_item	2356975	et	4	main
kuid	doc_384045275268_item	2357023	et	4	main
ka	doc_384045275268_item	2357029	et	3	main
selline	doc_384045275268_item	2357040	et	4	main
on	doc_384045275268_item	2357044	et	4	main
liiki	doc_384045275268_item	2357047	et	4	main
aga	doc_384045275268_item	2357049	et	3	main
teatud	doc_384045275268_item	2357059	et	4	main
on	doc_384045275268_item	2357064	et	4	main
liiki	doc_384045275268_item	2357074	et	4	main
rõivastus	doc_384045275267_item	2356655	et	4	main
edasiseks	doc_384045275267_item	2356658	et	4	main
tegevuseks	doc_384045275267_item	2356659	et	4	main
halli	doc_384045275267_item	2356665	et	4	main
hundi	doc_384045275267_item	2356666	et	3	main
7	doc_384045275267_item	2356670	et	2	main
в	doc_384045275267_item	2356673	et	2	main
vaid	doc_384045275267_item	2356717	et	3	main
paari	doc_384045275267_item	2356718	et	4	main
asjaga	doc_384045275267_item	2356719	et	3	main
mis	doc_384045275267_item	2356720	et	4	main
on	doc_384045275267_item	2356716	et	4	main
järelikult	doc_384045275267_item	2356721	et	3	main
hoolega	doc_384045275267_item	2356723	et	3	main
ja	doc_384045275267_item	2356725	et	3	main
paar	doc_384045275267_item	2356736	et	3	main
asjakest	doc_384045275267_item	2356737	et	4	main
8	doc_384045275267_item	2356738	et	2	main
я	doc_384045275267_item	2356740	et	2	main
пару	doc_384045275267_item	2356742	et	2	main
использовав	doc_384045275267_item	2356746	et	2	main
управления	doc_384045275267_item	2356751	et	2	main
tegin	doc_384045275267_item	2356756	et	3	main
ebaseaduslikult	doc_384045275267_item	2356761	et	4	main
üht	doc_384045275267_item	2356762	et	3	main
taga-kaukaasia	doc_384045275267_item	2356763	et	4	main
sõnajärge	doc_384045275267_item	2356769	et	4	main
on	doc_384045275267_item	2356770	et	4	main
9	doc_384045275267_item	2356773	et	2	main
слабые	doc_384045275267_item	2356775	et	2	main
долго	doc_384045275267_item	2356778	et	2	main
вторжения	doc_384045275267_item	2356783	et	2	main
töötavad	doc_384045275267_item	2356785	et	4	main
programmeerijad	doc_384045275267_item	2356787	et	4	main
mis	doc_384045275267_item	2356832	et	4	main
originaaltekstis	doc_384045275267_item	2356833	et	3	main
annab	doc_384045275267_item	2356834	et	3	main
lugejale	doc_384045275267_item	2356835	et	4	main
peategelase	doc_384045275267_item	2356838	et	3	main
nad	doc_384045275267_item	2356850	et	3	main
märkaksid	doc_384045275267_item	2356853	et	4	main
tulemusena	doc_384045275267_item	2356855	et	3	main
et	doc_384045275267_item	2356858	et	3	main
kus	doc_384045275267_item	2356863	et	3	main
vastet	doc_384045275267_item	2356874	et	3	main
sõnaraamatus	doc_384045275267_item	2356879	et	4	main
ning	doc_384045275267_item	2356882	et	3	main
teise	doc_384045275268_item	2356926	et	4	main
tegelikult	doc_384045275268_item	2356935	et	4	main
ühist	doc_384045275268_item	2356947	et	3	main
mees	doc_384045275268_item	2356957	et	4	main
ja	doc_384045275268_item	2356958	et	3	main
naine	doc_384045275268_item	2356959	et	3	main
võimalik	doc_384045275268_item	2356968	et	3	main
kolme	doc_384045275268_item	2356970	et	4	main
ning	doc_384045275268_item	2356980	et	3	main
keeles	doc_384045275268_item	2357016	et	4	main
on	doc_384045275268_item	2357018	et	4	main
tõlgitud	doc_384045275268_item	2357024	et	4	main
oli	doc_384045275268_item	2357028	et	3	main
suhetegagi	doc_384045275268_item	2357032	et	3	main
antonüümia	doc_384045275268_item	2357034	et	4	main
võiks	doc_384045275268_item	2357036	et	4	main
olla	doc_384045275268_item	2357037	et	3	main
noomenite	doc_384045275268_item	2357038	et	3	main
puhul	doc_384045275268_item	2357039	et	4	main
teatud	doc_384045275268_item	2357046	et	4	main
x	doc_384045275268_item	2357050	et	4	main
on	doc_384045275268_item	2357057	et	4	main
välismaa	doc_384045275268_item	2357063	et	4	main
kodumaa	doc_384045275268_item	2357065	et	4	main
on	doc_384045275268_item	2357066	et	4	main
antonüüm	doc_384045275268_item	2357067	et	3	main
lootusetus	doc_384045275268_item	2357077	et	4	main
ettevõtmiseks	doc_384045275267_item	2356726	et	3	main
vajalikud	doc_384045275267_item	2356727	et	3	main
тайник	doc_384045275267_item	2356739	et	2	main
создал	doc_384045275267_item	2356741	et	2	main
незаконно	doc_384045275267_item	2356745	et	2	main
транспортного	doc_384045275267_item	2356750	et	2	main
paar	doc_384045275267_item	2356757	et	3	main
tagasi	doc_384045275267_item	2356759	et	3	main
transpordiameti	doc_384045275267_item	2356765	et	3	main
otsetõlge	doc_384045275267_item	2356768	et	3	main
не	doc_384045275267_item	2356779	et	2	main
ei	doc_384045275267_item	2356789	et	4	main
märka	doc_384045275267_item	2356790	et	4	main
veel	doc_384045275267_item	2356791	et	4	main
kaua	doc_384045275267_item	2356792	et	3	main
pisikest	doc_384045275267_item	2356793	et	4	main
sissetungi	doc_384045275267_item	2356794	et	4	main
lause	doc_384045275267_item	2356795	et	4	main
esimeses	doc_384045275267_item	2356796	et	3	main
pooles	doc_384045275267_item	2356797	et	4	main
lisatud	doc_384045275267_item	2356799	et	4	main
sõna	doc_384045275267_item	2356800	et	4	main
on	doc_384045275267_item	2356798	et	4	main
töötavad	doc_384045275267_item	2356801	et	4	main
et	doc_384045275267_item	2356802	et	3	main
rõhutada	doc_384045275267_item	2356803	et	3	main
asjasse	doc_384045275267_item	2356804	et	3	main
taga-kaukaasia	doc_384045275267_item	2356805	et	4	main
transpordiameti	doc_384045275267_item	2356806	et	3	main
töötajad	doc_384045275267_item	2356807	et	4	main
puutumist	doc_384045275267_item	2356808	et	4	main
ja	doc_384045275267_item	2356809	et	3	main
võib-olla	doc_384045275267_item	2356810	et	3	main
ka	doc_384045275267_item	2356811	et	3	main
selleks	doc_384045275267_item	2356812	et	4	main
et	doc_384045275267_item	2356813	et	3	main
mitte	doc_384045275267_item	2356814	et	3	main
solvata	doc_384045275267_item	2356815	et	4	main
kõiki	doc_384045275267_item	2356816	et	4	main
taga-kaukaasia	doc_384045275267_item	2356817	et	4	main
programmeerijaid	doc_384045275267_item	2356818	et	4	main
lause	doc_384045275267_item	2356819	et	4	main
teises	doc_384045275267_item	2356820	et	4	main
pooles	doc_384045275267_item	2356821	et	4	main
lisatud	doc_384045275267_item	2356824	et	4	main
veel	doc_384045275267_item	2356826	et	4	main
samas	doc_384045275267_item	2356827	et	4	main
esimese	doc_384045275267_item	2356836	et	3	main
märka	doc_384045275267_item	2356842	et	4	main
just	doc_384045275267_item	2356843	et	3	main
seda	doc_384045275267_item	2356844	et	3	main
st	doc_384045275267_item	2356845	et	3	main
mõnda	doc_384045275267_item	2356848	et	4	main
tõlkija	doc_384045275267_item	2356864	et	4	main
esimene	doc_384045275267_item	2356876	et	3	main
mis	doc_384045275267_item	2356878	et	4	main
proovigi	doc_384045275267_item	2356884	et	4	main
tähenduskomponendi	doc_384045275268_item	2356899	et	3	main
tegelikult	doc_384045275268_item	2356901	et	4	main
polegi	doc_384045275268_item	2356902	et	3	main
sarnasuse	doc_384045275268_item	2356907	et	4	main
mõõt	doc_384045275268_item	2356908	et	3	main
nagu	doc_384045275268_item	2356909	et	3	main
sünonüümiagi	doc_384045275268_item	2356910	et	4	main
antonüümia	doc_384045275268_item	2356911	et	4	main
antonüümia	doc_384045275268_item	2356912	et	4	main
on	doc_384045275268_item	2356913	et	4	main
semantiline	doc_384045275268_item	2356914	et	3	main
suhe	doc_384045275268_item	2356915	et	3	main
mis	doc_384045275268_item	2356916	et	4	main
leksikaalsemantilise	doc_384045275268_item	2356917	et	4	main
paradigma	doc_384045275268_item	2356918	et	4	main
liikmete	doc_384045275268_item	2356919	et	3	main
antonüümide	doc_384045275268_item	2356920	et	3	main
liikme	doc_384045275268_item	2356923	et	3	main
tähendus	doc_384045275268_item	2356924	et	4	main
vastandub	doc_384045275268_item	2356925	et	3	main
sümmeetriline	doc_384045275268_item	2356933	et	3	main
ka	doc_384045275268_item	2356939	et	3	main
vastandatavatel	doc_384045275268_item	2356942	et	4	main
vastandatakse	doc_384045275268_item	2356949	et	3	main
vaid	doc_384045275268_item	2356950	et	3	main
on	doc_384045275268_item	2356962	et	4	main
ka	doc_384045275268_item	2356964	et	3	main
2	doc_384045275268_item	2356976	et	2	main
vastandusel	doc_384045275268_item	2356978	et	4	main
viimane	doc_384045275268_item	2357008	et	3	main
eristatud	doc_384045275268_item	2357013	et	4	main
kahel	doc_384045275268_item	2357019	et	4	main
tehtud	doc_384045275268_item	2357022	et	4	main
nii	doc_384045275268_item	2357026	et	3	main
eelnevate	doc_384045275268_item	2357031	et	4	main
testlause	doc_384045275268_item	2357033	et	4	main
y	doc_384045275268_item	2357043	et	4	main
z-d	doc_384045275268_item	2357048	et	4	main
kodumaa	doc_384045275268_item	2357056	et	4	main
maad	doc_384045275268_item	2357061	et	4	main
aga	doc_384045275268_item	2357076	et	3	main
peategelase	doc_384045275267_item	2356846	et	3	main
järeldusele	doc_384045275267_item	2356857	et	4	main
tegemist	doc_384045275267_item	2356859	et	4	main
on	doc_384045275267_item	2356860	et	4	main
püüdliku	doc_384045275267_item	2356861	et	3	main
otsetõlkega	doc_384045275267_item	2356862	et	3	main
vene	doc_384045275267_item	2356868	et	4	main
keelse	doc_384045275267_item	2356869	et	3	main
nö	doc_384045275267_item	2356875	et	4	main
ei	doc_384045275267_item	2356883	et	4	main
tõlke	doc_384045275267_item	2356885	et	4	main
lugejani	doc_384045275267_item	2356886	et	4	main
tuua	doc_384045275267_item	2356887	et	3	main
antonüümia	doc_384045275268_item	2356890	et	4	main
on	doc_384045275268_item	2356891	et	4	main
vastandlikkus	doc_384045275268_item	2356893	et	4	main
vastandussuhe	doc_384045275268_item	2356895	et	4	main
semantilise	doc_384045275268_item	2356897	et	3	main
antonüümia	doc_384045275268_item	2356903	et	4	main
mitte	doc_384045275268_item	2356904	et	3	main
ühe	doc_384045275268_item	2356922	et	4	main
õim	doc_384045275268_item	2356929	et	4	main
1998	doc_384045275268_item	2356930	et	2	main
antonüümia	doc_384045275268_item	2356931	et	4	main
on	doc_384045275268_item	2356932	et	4	main
kuna	doc_384045275268_item	2356941	et	3	main
sõnadel	doc_384045275268_item	2356943	et	3	main
olema	doc_384045275268_item	2356945	et	4	main
midagi	doc_384045275268_item	2356946	et	4	main
kindla	doc_384045275268_item	2356952	et	3	main
on	doc_384045275268_item	2356967	et	4	main
jagada	doc_384045275268_item	2356969	et	3	main
rühma	doc_384045275268_item	2356971	et	4	main
1	doc_384045275268_item	2356972	et	2	main
relatiivsetel	doc_384045275268_item	2356973	et	3	main
3	doc_384045275268_item	2356981	et	2	main
vektorvastandusel	doc_384045275268_item	2356982	et	4	main
põhinevad	doc_384045275268_item	2356983	et	4	main
antonüümid	doc_384045275268_item	2356984	et	3	main
õim	doc_384045275268_item	2356985	et	4	main
1998	doc_384045275268_item	2356986	et	2	main
ewn-s	doc_384045275268_item	2356987	et	3	main
on	doc_384045275268_item	2356988	et	4	main
antonüümia	doc_384045275268_item	2356989	et	4	main
suhte	doc_384045275268_item	2356990	et	3	main
märgendiks	doc_384045275268_item	2356991	et	3	main
antonym	doc_384045275268_item	2356992	et	4	main
eestikeelne	doc_384045275268_item	2356993	et	3	main
vaste	doc_384045275268_item	2356994	et	4	main
on	doc_384045275268_item	2356996	et	4	main
ning	doc_384045275268_item	2356997	et	3	main
vastand	doc_384045275268_item	2356995	et	4	main
lähiantonüümia	doc_384045275268_item	2356998	et	4	main
märgendiks	doc_384045275268_item	2356999	et	3	main
nearantonym	doc_384045275268_item	2357000	et	4	main
ja	doc_384045275268_item	2357001	et	3	main
xposnearantonym	doc_384045275268_item	2357002	et	4	main
eesti	doc_384045275268_item	2357003	et	4	main
keeles	doc_384045275268_item	2357004	et	4	main
peaaegu	doc_384045275268_item	2357005	et	3	main
vastand	doc_384045275268_item	2357006	et	4	main
on	doc_384045275268_item	2357007	et	4	main
sarnasussuhteks	doc_384045275268_item	2356940	et	4	main
peab	doc_384045275268_item	2356944	et	4	main
inimesed	doc_384045275268_item	2356960	et	3	main
antonüümid	doc_384045275268_item	2356965	et	3	main
vastandustel	doc_384045275268_item	2356974	et	4	main
komplementaarsel	doc_384045275268_item	2356977	et	3	main
põhinevad	doc_384045275268_item	2356979	et	4	main
neist	doc_384045275268_item	2357009	et	4	main
on	doc_384045275268_item	2357010	et	4	main
sõnaliikidevaheliselt	doc_384045275268_item	2357014	et	4	main
viimasel	doc_384045275268_item	2357020	et	3	main
vahet	doc_384045275268_item	2357021	et	3	main
ühtemoodi	doc_384045275268_item	2357025	et	3	main
kõigi	doc_384045275268_item	2357030	et	4	main
jaoks	doc_384045275268_item	2357035	et	4	main
mõlemad	doc_384045275268_item	2357045	et	3	main
antonüüm	doc_384045275268_item	2357053	et	3	main
välismaa	doc_384045275268_item	2357054	et	4	main
ja	doc_384045275268_item	2357055	et	3	main
liiki	doc_384045275268_item	2357060	et	4	main
ja	doc_384045275268_item	2357069	et	3	main
on	doc_384045275268_item	2357071	et	4	main
mõlemad	doc_384045275268_item	2357072	et	3	main
teatud	doc_384045275268_item	2357073	et	4	main
ja	doc_384045275271_item	2357323	et	3	main
on	doc_384045275271_item	2357330	et	4	main
tegevuse	doc_384045275271_item	2357333	et	4	main
eesmärk	doc_384045275271_item	2357334	et	3	main
ja	doc_384045275271_item	2357343	et	3	main
süsteemi	doc_384045275271_item	2357347	et	4	main
efektiivne	doc_384045275271_item	2357356	et	3	main
teadlikkus	doc_384045275271_item	2357360	et	4	main
on	doc_384045275271_item	2357368	et	4	main
korraldamine	doc_384045275271_item	2357371	et	4	main
elluviimise	doc_384045275271_item	2357374	et	3	main
kooskõla	doc_384045275271_item	2357385	et	4	main
jne	doc_384045275271_item	2357390	et	4	main
kui	doc_384045275272_item	2357404	et	3	main
ma	doc_384045275272_item	2357405	et	3	main
kümnendas	doc_384045275272_item	2357407	et	3	main
meie	doc_384045275272_item	2357409	et	4	main
toimus	doc_384045275272_item	2357411	et	3	main
hollandiga	doc_384045275272_item	2357413	et	4	main
ma	doc_384045275272_item	2357414	et	3	main
ka	doc_384045275272_item	2357417	et	3	main
jaanuaris	doc_384045275272_item	2357421	et	3	main
nädala	doc_384045275272_item	2357426	et	3	main
aprillis	doc_384045275272_item	2357428	et	3	main
külas	doc_384045275272_item	2357437	et	3	main
olid	doc_384045275272_item	2357449	et	4	main
tutvusime	doc_384045275272_item	2357461	et	4	main
neide	doc_384045275272_item	2357462	et	3	main
jällegi	doc_384045275268_item	2357011	et	4	main
ewn-s	doc_384045275268_item	2357012	et	3	main
eesti	doc_384045275268_item	2357015	et	4	main
muidugi	doc_384045275268_item	2357017	et	4	main
nagu	doc_384045275268_item	2357027	et	3	main
x	doc_384045275268_item	2357041	et	4	main
ja	doc_384045275268_item	2357042	et	3	main
on	doc_384045275268_item	2357051	et	4	main
y	doc_384045275268_item	2357052	et	4	main
mõlemad	doc_384045275268_item	2357058	et	3	main
aga	doc_384045275268_item	2357062	et	3	main
lootusetus	doc_384045275268_item	2357068	et	4	main
lootus	doc_384045275268_item	2357070	et	4	main
tundedtundmused	doc_384045275268_item	2357075	et	4	main
on	doc_384045275268_item	2357078	et	4	main
lootuse	doc_384045275268_item	2357079	et	4	main
antonüüm	doc_384045275268_item	2357080	et	3	main
keelepoliitika	doc_384045275271_item	2357321	et	4	main
teadusministeeriumi	doc_384045275271_item	2357324	et	4	main
selle	doc_384045275271_item	2357341	et	4	main
arengut	doc_384045275271_item	2357344	et	3	main
kasutamine	doc_384045275271_item	2357357	et	4	main
valdkonnas	doc_384045275271_item	2357367	et	4	main
tulemuslikkuse	doc_384045275271_item	2357376	et	4	main
hindamise	doc_384045275271_item	2357377	et	4	main
arengukavade	doc_384045275271_item	2357379	et	3	main
väljatöötamine	doc_384045275271_item	2357380	et	3	main
ja	doc_384045275271_item	2357383	et	3	main
tagamine	doc_384045275271_item	2357386	et	4	main
korraldamine	doc_384045275271_item	2357389	et	4	main
kus	doc_384045275272_item	2357392	et	3	main
olen	doc_384045275272_item	2357393	et	3	main
aastat	doc_384045275272_item	2357401	et	3	main
käisin	doc_384045275272_item	2357406	et	3	main
osalesin	doc_384045275272_item	2357415	et	3	main
olid	doc_384045275272_item	2357423	et	4	main
pidime	doc_384045275272_item	2357430	et	3	main
jaoks	doc_384045275272_item	2357448	et	4	main
erinevad	doc_384045275272_item	2357451	et	4	main
esimesel	doc_384045275272_item	2357454	et	3	main
koolis	doc_384045275272_item	2357459	et	4	main
ja	doc_384045275272_item	2357460	et	3	main
tunnid	doc_384045275272_item	2357468	et	3	main
neli	doc_384045275272_item	2357474	et	3	main
hollandi	doc_384045275272_item	2357476	et	4	main
muusika	doc_384045275272_item	2357478	et	4	main
van	doc_384045275272_item	2357494	et	4	main
natukene	doc_384045275272_item	2357497	et	4	main
seal	doc_384045275272_item	2357506	et	4	main
kõigepealt	doc_384045275272_item	2357510	et	3	main
rahvusvahelinses	doc_384045275272_item	2357512	et	4	main
neljas	doc_384045275272_item	2357516	et	4	main
see	doc_384045275272_item	2357520	et	3	main
pidi	doc_384045275272_item	2357525	et	4	main
ise	doc_384045275272_item	2357527	et	4	main
huvitavat	doc_384045275272_item	2357529	et	4	main
kõige	doc_384045275272_item	2357530	et	4	main
kirikus	doc_384045275272_item	2357547	et	3	main
referaat	doc_384045275271_item	2357313	et	3	main
sissejuhatus	doc_384045275271_item	2357314	et	4	main
eesti	doc_384045275271_item	2357315	et	4	main
vabariigi	doc_384045275271_item	2357316	et	3	main
valitsuse	doc_384045275271_item	2357317	et	4	main
seaduse	doc_384045275271_item	2357318	et	3	main
kohaselt	doc_384045275271_item	2357319	et	4	main
on	doc_384045275271_item	2357320	et	4	main
haridus-	doc_384045275271_item	2357322	et	3	main
põhimääruse	doc_384045275271_item	2357328	et	3	main
ja	doc_384045275271_item	2357338	et	3	main
efektiivne	doc_384045275271_item	2357339	et	3	main
tagavate	doc_384045275271_item	2357345	et	4	main
korraldamiseks	doc_384045275271_item	2357349	et	4	main
eraldatava	doc_384045275271_item	2357350	et	4	main
raha	doc_384045275271_item	2357351	et	4	main
ning	doc_384045275271_item	2357358	et	3	main
keelepoliitika	doc_384045275271_item	2357366	et	4	main
riigi	doc_384045275271_item	2357378	et	3	main
üleriigiliste	doc_384045275271_item	2357387	et	4	main
ja	doc_384045275272_item	2357396	et	3	main
olen	doc_384045275272_item	2357398	et	3	main
näinud	doc_384045275272_item	2357399	et	4	main
kolm	doc_384045275272_item	2357400	et	3	main
koolis	doc_384045275272_item	2357410	et	4	main
õpilastevahetus	doc_384045275272_item	2357412	et	4	main
tulid	doc_384045275272_item	2357419	et	4	main
valitsemisalas	doc_384045275271_item	2357326	et	3	main
riigi	doc_384045275271_item	2357331	et	3	main
õigusaktide	doc_384045275271_item	2357346	et	3	main
loomine	doc_384045275271_item	2357348	et	4	main
ning	doc_384045275271_item	2357352	et	3	main
vara	doc_384045275271_item	2357353	et	4	main
ning	doc_384045275271_item	2357355	et	3	main
avalikkuse	doc_384045275271_item	2357359	et	4	main
keelepoliitika	doc_384045275271_item	2357361	et	4	main
alal	doc_384045275271_item	2357362	et	4	main
toimuvast	doc_384045275271_item	2357363	et	4	main
ministeeriumi	doc_384045275271_item	2357364	et	4	main
ülesanded	doc_384045275271_item	2357365	et	3	main
keelepoliitika	doc_384045275271_item	2357369	et	4	main
planeerimine	doc_384045275271_item	2357370	et	4	main
ja	doc_384045275271_item	2357372	et	3	main
arendamine	doc_384045275271_item	2357373	et	4	main
ja	doc_384045275271_item	2357375	et	3	main
keelepoliitika	doc_384045275271_item	2357381	et	4	main
valdkondades	doc_384045275271_item	2357382	et	3	main
arengukavadega	doc_384045275271_item	2357388	et	3	main
essee	doc_384045275272_item	2357391	et	4	main
siis	doc_384045275272_item	2357403	et	3	main
klassis	doc_384045275272_item	2357408	et	3	main
juures	doc_384045275272_item	2357425	et	4	main
aega	doc_384045275272_item	2357427	et	4	main
me	doc_384045275272_item	2357429	et	4	main
lendama	doc_384045275272_item	2357431	et	3	main
hollandisse	doc_384045275272_item	2357432	et	4	main
ka	doc_384045275272_item	2357433	et	3	main
nädalaks	doc_384045275272_item	2357434	et	3	main
oli	doc_384045275272_item	2357441	et	3	main
minu	doc_384045275272_item	2357443	et	3	main
päev	doc_384045275272_item	2357446	et	3	main
meie	doc_384045275272_item	2357447	et	4	main
meelelahutused	doc_384045275272_item	2357452	et	4	main
päeval	doc_384045275272_item	2357455	et	3	main
olime	doc_384045275272_item	2357457	et	3	main
nendes	doc_384045275272_item	2357458	et	4	main
me	doc_384045275272_item	2357470	et	4	main
joonistamine	doc_384045275272_item	2357479	et	4	main
tegime	doc_384045275272_item	2357486	et	3	main
pillede	doc_384045275272_item	2357491	et	4	main
pael	doc_384045275272_item	2357492	et	4	main
maale	doc_384045275272_item	2357496	et	4	main
haagasse	doc_384045275272_item	2357505	et	4	main
olime	doc_384045275272_item	2357511	et	3	main
olid	doc_384045275272_item	2357518	et	4	main
et	doc_384045275272_item	2357522	et	3	main
rohkem	doc_384045275272_item	2357531	et	4	main
mulle	doc_384045275272_item	2357532	et	4	main
ilus	doc_384045275272_item	2357543	et	4	main
päeval	doc_384045275272_item	2357549	et	3	main
veekanaleid	doc_384045275272_item	2357556	et	4	main
palju	doc_384045275272_item	2357559	et	4	main
üks	doc_384045275272_item	2357562	et	3	main
seal	doc_384045275272_item	2357571	et	4	main
päeval	doc_384045275272_item	2357575	et	3	main
pilte	doc_384045275272_item	2357584	et	3	main
kogemus	doc_384045275272_item	2357625	et	3	main
olen	doc_384045275272_item	2357626	et	3	main
õnnelik	doc_384045275272_item	2357627	et	3	main
htm	doc_384045275271_item	2357325	et	4	main
htm-i	doc_384045275271_item	2357327	et	4	main
järgi	doc_384045275271_item	2357329	et	4	main
keelepoliitika	doc_384045275271_item	2357332	et	4	main
tagada	doc_384045275271_item	2357335	et	3	main
keelepoliitika	doc_384045275271_item	2357336	et	4	main
sihipärane	doc_384045275271_item	2357337	et	4	main
areng	doc_384045275271_item	2357340	et	3	main
rakendamist	doc_384045275271_item	2357342	et	4	main
sihipärane	doc_384045275271_item	2357354	et	4	main
nende	doc_384045275271_item	2357384	et	4	main
k	doc_384045275272_item	2357394	et	4	main
äinud	doc_384045275272_item	2357395	et	4	main
mida	doc_384045275272_item	2357397	et	4	main
tagasi	doc_384045275272_item	2357402	et	3	main
selles	doc_384045275272_item	2357416	et	4	main
hollandlased	doc_384045275272_item	2357418	et	3	main
eestisse	doc_384045275272_item	2357420	et	4	main
nad	doc_384045275272_item	2357422	et	3	main
mina	doc_384045275272_item	2357435	et	4	main
olin	doc_384045275272_item	2357436	et	3	main
kes	doc_384045275272_item	2357440	et	4	main
juures	doc_384045275272_item	2357444	et	4	main
plaanitud	doc_384045275272_item	2357450	et	4	main
näiteks	doc_384045275272_item	2357453	et	4	main
me	doc_384045275272_item	2357456	et	4	main
ja	doc_384045275272_item	2357469	et	3	main
õppisime	doc_384045275272_item	2357471	et	3	main
oli	doc_384045275272_item	2357473	et	3	main
ja	doc_384045275272_item	2357480	et	3	main
oli	doc_384045275272_item	2357483	et	3	main
huvitav	doc_384045275272_item	2357485	et	4	main
palju	doc_384045275272_item	2357487	et	4	main
eksperimente	doc_384045275272_item	2357488	et	3	main
mängisime	doc_384045275272_item	2357489	et	3	main
erinevate	doc_384045275272_item	2357490	et	4	main
joonistasime	doc_384045275272_item	2357493	et	3	main
keeles	doc_384045275272_item	2357500	et	4	main
päeval	doc_384045275272_item	2357502	et	3	main
me	doc_384045275272_item	2357503	et	4	main
sõitsime	doc_384045275272_item	2357504	et	3	main
ja	doc_384045275272_item	2357515	et	3	main
perepäevad	doc_384045275272_item	2357519	et	3	main
tähendab	doc_384045275272_item	2357521	et	3	main
midagi	doc_384045275272_item	2357528	et	4	main
nagu	doc_384045275272_item	2357537	et	3	main
lille	doc_384045275272_item	2357538	et	4	main
park	doc_384045275272_item	2357539	et	3	main
seal	doc_384045275272_item	2357540	et	4	main
on	doc_384045275272_item	2357541	et	4	main
väga	doc_384045275272_item	2357542	et	3	main
viiendal	doc_384045275272_item	2357548	et	3	main
sõitsime	doc_384045275272_item	2357550	et	3	main
paadiga	doc_384045275272_item	2357554	et	3	main
viimasel	doc_384045275272_item	2357574	et	3	main
seal	doc_384045275272_item	2357580	et	4	main
tihti	doc_384045275272_item	2357585	et	3	main
uuesti	doc_384045275272_item	2357588	et	3	main
mulle	doc_384045275272_item	2357590	et	4	main
väga	doc_384045275272_item	2357621	et	3	main
essee	doc_384045275273_item	2357632	et	4	main
aastal	doc_384045275273_item	2357639	et	3	main
on	doc_384045275273_item	2357658	et	4	main
on	doc_384045275273_item	2357665	et	4	main
soitsivad	doc_384045275273_item	2357671	et	4	main
vaatavad	doc_384045275273_item	2357675	et	4	main
see	doc_384045275273_item	2357676	et	3	main
me	doc_384045275273_item	2357683	et	4	main
me	doc_384045275273_item	2357686	et	4	main
kohti	doc_384045275273_item	2357689	et	4	main
tean	doc_384045275273_item	2357696	et	3	main
palju	doc_384045275273_item	2357700	et	4	main
kohadkus	doc_384045275273_item	2357702	et	4	main
minu	doc_384045275273_item	2357707	et	3	main
sobradega	doc_384045275273_item	2357708	et	4	main
tagasi	doc_384045275273_item	2357711	et	3	main
huvitavad	doc_384045275273_item	2357722	et	4	main
kohadma	doc_384045275273_item	2357723	et	4	main
vaatasime	doc_384045275273_item	2357729	et	3	main
loss	doc_384045275273_item	2357731	et	3	main
see	doc_384045275273_item	2357732	et	3	main
see	doc_384045275273_item	2357739	et	3	main
on	doc_384045275273_item	2357740	et	4	main
ilus	doc_384045275273_item	2357742	et	4	main
piltsellel	doc_384045275273_item	2357743	et	3	main
aastal	doc_384045275273_item	2357744	et	3	main
ma	doc_384045275273_item	2357745	et	3	main
tahan	doc_384045275273_item	2357746	et	3	main
sqitsida	doc_384045275273_item	2357747	et	4	main
hiiumaal	doc_384045275273_item	2357748	et	4	main
meie	doc_384045275272_item	2357424	et	4	main
oma	doc_384045275272_item	2357438	et	4	main
sõbrannal	doc_384045275272_item	2357439	et	3	main
talvel	doc_384045275272_item	2357442	et	4	main
iga	doc_384045275272_item	2357445	et	4	main
kultuuriga	doc_384045275272_item	2357463	et	4	main
sellel	doc_384045275272_item	2357464	et	4	main
päeval	doc_384045275272_item	2357465	et	3	main
meil	doc_384045275272_item	2357466	et	4	main
päev	doc_384045275272_item	2357482	et	3	main
gochi	doc_384045275272_item	2357495	et	4	main
teisel	doc_384045275272_item	2357501	et	4	main
jalutasime	doc_384045275272_item	2357508	et	3	main
ja	doc_384045275272_item	2357509	et	3	main
hollandi	doc_384045275272_item	2357523	et	4	main
näitama	doc_384045275272_item	2357526	et	3	main
meeldis	doc_384045275272_item	2357533	et	3	main
keukenhof	doc_384045275272_item	2357534	et	4	main
see	doc_384045275272_item	2357535	et	3	main
on	doc_384045275272_item	2357536	et	4	main
veel	doc_384045275272_item	2357544	et	4	main
olin	doc_384045275272_item	2357545	et	3	main
utrehti	doc_384045275272_item	2357546	et	4	main
seal	doc_384045275272_item	2357552	et	4	main
mööda	doc_384045275272_item	2357555	et	4	main
ja	doc_384045275272_item	2357561	et	3	main
lossis	doc_384045275272_item	2357565	et	4	main
pankooke	doc_384045275272_item	2357573	et	4	main
ma	doc_384045275272_item	2357581	et	3	main
neid	doc_384045275272_item	2357587	et	4	main
läbi	doc_384045275272_item	2357589	et	4	main
ja	doc_384045275272_item	2357623	et	3	main
unustamatu	doc_384045275272_item	2357624	et	4	main
kus	doc_384045275273_item	2357633	et	3	main
ma	doc_384045275273_item	2357640	et	3	main
sotsin	doc_384045275273_item	2357644	et	4	main
koos	doc_384045275273_item	2357645	et	4	main
meteoriiti	doc_384045275273_item	2357660	et	4	main
tanapaeval	doc_384045275273_item	2357662	et	4	main
on	doc_384045275273_item	2357663	et	4	main
tuntub	doc_384045275273_item	2357667	et	4	main
saaremaal	doc_384045275273_item	2357672	et	4	main
et	doc_384045275273_item	2357673	et	3	main
oleks	doc_384045275273_item	2357674	et	3	main
kui	doc_384045275273_item	2357682	et	3	main
saaremaal	doc_384045275273_item	2357685	et	4	main
kullastasime	doc_384045275273_item	2357687	et	4	main
tuntuvaid	doc_384045275273_item	2357688	et	4	main
toila	doc_384045275273_item	2357693	et	4	main
et	doc_384045275273_item	2357697	et	3	main
koos	doc_384045275273_item	2357706	et	4	main
aastat	doc_384045275273_item	2357710	et	3	main
ta	doc_384045275273_item	2357736	et	4	main
vaga	doc_384045275273_item	2357741	et	4	main
on	doc_384045275273_item	2357753	et	4	main
tahn	doc_384045275273_item	2357757	et	4	main
vaadata	doc_384045275273_item	2357758	et	4	main
see	doc_384045275273_item	2357759	et	3	main
loodan	doc_384045275273_item	2357760	et	3	main
plaanid	doc_384045275273_item	2357763	et	4	main
realiseeruma	doc_384045275273_item	2357764	et	3	main
eelmisel	doc_384045275275_item	2357873	et	3	main
kuul	doc_384045275275_item	2357874	et	4	main
ta	doc_384045275275_item	2357880	et	4	main
saksamaale	doc_384045275275_item	2357883	et	4	main
kolm	doc_384045275275_item	2357891	et	3	main
ma	doc_384045275275_item	2357896	et	3	main
bremeni	doc_384045275275_item	2357899	et	4	main
unustamatu	doc_384045275275_item	2357912	et	4	main
selle	doc_384045275275_item	2357919	et	4	main
oli	doc_384045275272_item	2357467	et	3	main
tunniplaanis	doc_384045275272_item	2357472	et	3	main
õppeainet	doc_384045275272_item	2357475	et	3	main
keel	doc_384045275272_item	2357477	et	4	main
keemia	doc_384045275272_item	2357481	et	4	main
väga	doc_384045275272_item	2357484	et	3	main
rääkisime	doc_384045275272_item	2357498	et	3	main
hollandi	doc_384045275272_item	2357499	et	4	main
palju	doc_384045275272_item	2357507	et	4	main
kohtus	doc_384045275272_item	2357513	et	4	main
kolmas	doc_384045275272_item	2357514	et	3	main
päevad	doc_384045275272_item	2357517	et	3	main
pere	doc_384045275272_item	2357524	et	4	main
seal	doc_384045275272_item	2357557	et	4	main
ekskursioone	doc_384045275272_item	2357560	et	3	main
oli	doc_384045275272_item	2357563	et	3	main
me	doc_384045275272_item	2357566	et	4	main
mängisime	doc_384045275272_item	2357567	et	3	main
bouwlingut	doc_384045275272_item	2357568	et	4	main
ja	doc_384045275272_item	2357569	et	3	main
sõime	doc_384045275272_item	2357570	et	4	main
oli	doc_384045275272_item	2357576	et	3	main
puhul	doc_384045275272_item	2357578	et	4	main
palju	doc_384045275272_item	2357583	et	4	main
meeldib	doc_384045275272_item	2357591	et	3	main
meelde	doc_384045275272_item	2357592	et	3	main
tuletada	doc_384045275272_item	2357593	et	3	main
seda	doc_384045275272_item	2357594	et	3	main
reisi	doc_384045275272_item	2357595	et	4	main
need	doc_384045275272_item	2357596	et	3	main
seitse	doc_384045275272_item	2357597	et	3	main
päeva	doc_384045275272_item	2357598	et	4	main
läksid	doc_384045275272_item	2357599	et	4	main
väga	doc_384045275272_item	2357600	et	3	main
kiiresti	doc_384045275272_item	2357601	et	3	main
mööda	doc_384045275272_item	2357602	et	4	main
oli	doc_384045275272_item	2357603	et	3	main
kahju	doc_384045275272_item	2357604	et	4	main
hollandist	doc_384045275272_item	2357605	et	4	main
arä	doc_384045275272_item	2357606	et	4	main
minna	doc_384045275272_item	2357607	et	3	main
see	doc_384045275272_item	2357608	et	3	main
vahetus	doc_384045275272_item	2357609	et	4	main
oli	doc_384045275272_item	2357610	et	3	main
mõeldud	doc_384045275272_item	2357611	et	4	main
praaktikana	doc_384045275272_item	2357612	et	3	main
inglise	doc_384045275272_item	2357613	et	4	main
keeles	doc_384045275272_item	2357614	et	4	main
ja	doc_384045275272_item	2357615	et	3	main
tutvustusena	doc_384045275272_item	2357616	et	4	main
teise	doc_384045275272_item	2357617	et	4	main
see	doc_384045275272_item	2357619	et	3	main
kultuuriga	doc_384045275272_item	2357618	et	4	main
oli	doc_384045275272_item	2357620	et	3	main
amsterdaammi	doc_384045275272_item	2357551	et	4	main
sõitsime	doc_384045275272_item	2357553	et	3	main
oli	doc_384045275272_item	2357558	et	3	main
lossis	doc_384045275272_item	2357564	et	4	main
suuri	doc_384045275272_item	2357572	et	3	main
meie	doc_384045275272_item	2357577	et	4	main
disco-pidu	doc_384045275272_item	2357579	et	4	main
tegin	doc_384045275272_item	2357582	et	3	main
vaatan	doc_384045275272_item	2357586	et	3	main
et	doc_384045275272_item	2357628	et	3	main
võimaluse	doc_384045275272_item	2357631	et	3	main
ma	doc_384045275273_item	2357634	et	3	main
vaatasin	doc_384045275273_item	2357637	et	3	main
minu	doc_384045275273_item	2357646	et	3	main
saaremaa	doc_384045275273_item	2357648	et	4	main
suureim	doc_384045275273_item	2357650	et	4	main
saar	doc_384045275273_item	2357651	et	3	main
saaremaal	doc_384045275273_item	2357653	et	4	main
on	doc_384045275273_item	2357654	et	4	main
vartsusiseal	doc_384045275273_item	2357657	et	4	main
vaga	doc_384045275273_item	2357666	et	4	main
palju	doc_384045275273_item	2357669	et	4	main
jarv	doc_384045275273_item	2357677	et	4	main
saaremaal	doc_384045275273_item	2357678	et	4	main
on	doc_384045275273_item	2357679	et	4	main
soitsime	doc_384045275273_item	2357684	et	4	main
naiteks	doc_384045275273_item	2357690	et	4	main
ontika	doc_384045275273_item	2357691	et	4	main
ma	doc_384045275273_item	2357695	et	3	main
ilusad	doc_384045275273_item	2357701	et	3	main
tahan	doc_384045275273_item	2357704	et	3	main
ma	doc_384045275273_item	2357712	et	3	main
talvel	doc_384045275273_item	2357734	et	4	main
oli	doc_384045275273_item	2357737	et	3	main
et	doc_384045275273_item	2357751	et	3	main
ma	doc_384045275273_item	2357756	et	3	main
minu	doc_384045275273_item	2357762	et	3	main
huvitav	doc_384045275272_item	2357622	et	4	main
sain	doc_384045275272_item	2357629	et	3	main
ma	doc_384045275273_item	2357636	et	3	main
olin	doc_384045275273_item	2357641	et	3	main
ma	doc_384045275273_item	2357643	et	3	main
sobradega	doc_384045275273_item	2357647	et	4	main
on	doc_384045275273_item	2357649	et	4	main
eestis	doc_384045275273_item	2357652	et	3	main
asub	doc_384045275273_item	2357659	et	3	main
kraatermis	doc_384045275273_item	2357661	et	4	main
talud	doc_384045275273_item	2357681	et	4	main
ja	doc_384045275273_item	2357692	et	3	main
eestis	doc_384045275273_item	2357698	et	3	main
ma	doc_384045275273_item	2357703	et	3	main
soitsin	doc_384045275273_item	2357713	et	4	main
viljandis	doc_384045275273_item	2357714	et	4	main
see	doc_384045275273_item	2357715	et	3	main
vaga	doc_384045275273_item	2357716	et	4	main
ilus	doc_384045275273_item	2357717	et	4	main
linn	doc_384045275273_item	2357718	et	3	main
viljandis	doc_384045275273_item	2357719	et	4	main
on	doc_384045275273_item	2357720	et	4	main
sellise	doc_384045275272_item	2357630	et	4	main
olinmis	doc_384045275273_item	2357635	et	4	main
eelmisel	doc_384045275273_item	2357638	et	3	main
saaremaal	doc_384045275273_item	2357642	et	4	main
palju	doc_384045275273_item	2357655	et	4	main
vaatamis	doc_384045275273_item	2357656	et	4	main
jarvsee	doc_384045275273_item	2357664	et	4	main
koht	doc_384045275273_item	2357668	et	3	main
turistid	doc_384045275273_item	2357670	et	3	main
palju	doc_384045275273_item	2357680	et	4	main
park	doc_384045275273_item	2357694	et	3	main
on	doc_384045275273_item	2357699	et	4	main
soitsida	doc_384045275273_item	2357705	et	4	main
kaks	doc_384045275273_item	2357709	et	3	main
palju	doc_384045275273_item	2357721	et	4	main
ilus	doc_384045275273_item	2357730	et	4	main
oli	doc_384045275273_item	2357733	et	3	main
lumis	doc_384045275273_item	2357738	et	4	main
kuulan	doc_384045275273_item	2357750	et	3	main
sõita	doc_384045275275_item	2357882	et	3	main
saksamaal	doc_384045275275_item	2357884	et	4	main
elavad	doc_384045275275_item	2357885	et	4	main
juba	doc_384045275275_item	2357890	et	3	main
aastat	doc_384045275275_item	2357894	et	3	main
juba	doc_384045275275_item	2357898	et	3	main
minu	doc_384045275275_item	2357901	et	3	main
õega	doc_384045275275_item	2357902	et	3	main
mulle	doc_384045275275_item	2357904	et	4	main
nende	doc_384045275275_item	2357915	et	4	main
kõik	doc_384045275275_item	2357921	et	4	main
uus	doc_384045275275_item	2357923	et	3	main
oli	doc_384045275275_item	2357940	et	3	main
osta	doc_384045275275_item	2357942	et	4	main
ümberistumisega	doc_384045275275_item	2357944	et	3	main
neid	doc_384045275275_item	2357948	et	4	main
kolm	doc_384045275275_item	2357950	et	3	main
5	doc_384045275275_item	2357960	et	2	main
ehk	doc_384045275275_item	2357975	et	3	main
pärast	doc_384045275275_item	2357983	et	4	main
suhtlemine	doc_384045275275_item	2357984	et	4	main
oli	doc_384045275275_item	2357985	et	3	main
raske	doc_384045275275_item	2357986	et	4	main
ja	doc_384045275275_item	2357991	et	3	main
taksojuhile	doc_384045275275_item	2357994	et	3	main
sõta	doc_384045275275_item	2357996	et	4	main
sõitsime	doc_384045275275_item	2358007	et	3	main
ühe	doc_384045275275_item	2358008	et	4	main
nädala	doc_384045275275_item	2358009	et	3	main
esimesed	doc_384045275275_item	2358010	et	3	main
soitsin	doc_384045275273_item	2357724	et	4	main
koos	doc_384045275273_item	2357725	et	4	main
minu	doc_384045275273_item	2357726	et	3	main
vanemad	doc_384045275273_item	2357727	et	4	main
me	doc_384045275273_item	2357728	et	4	main
ja	doc_384045275273_item	2357735	et	3	main
ma	doc_384045275273_item	2357749	et	3	main
hiiumal	doc_384045275273_item	2357752	et	4	main
vaneim	doc_384045275273_item	2357754	et	4	main
tuletorn	doc_384045275273_item	2357755	et	3	main
et	doc_384045275273_item	2357761	et	3	main
minu	doc_384045275275_item	2357875	et	3	main
oli	doc_384045275275_item	2357877	et	3	main
ja	doc_384045275275_item	2357879	et	3	main
otsustas	doc_384045275275_item	2357881	et	3	main
vanaisa	doc_384045275275_item	2357889	et	4	main
kaks	doc_384045275275_item	2357893	et	3	main
lennukiga	doc_384045275275_item	2357909	et	3	main
külla	doc_384045275275_item	2357916	et	4	main
kord	doc_384045275275_item	2357925	et	4	main
me	doc_384045275275_item	2357926	et	4	main
lendasime	doc_384045275275_item	2357927	et	3	main
aluseks	doc_384045275275_item	2357928	et	4	main
meil	doc_384045275275_item	2357939	et	4	main
pileteid	doc_384045275275_item	2357943	et	3	main
rongisse	doc_384045275275_item	2357946	et	4	main
võib	doc_384045275275_item	2357951	et	3	main
sõidab	doc_384045275275_item	2357958	et	3	main
selle	doc_384045275275_item	2357970	et	4	main
mutub	doc_384045275275_item	2357971	et	4	main
mina	doc_384045275275_item	2357976	et	4	main
isa	doc_384045275275_item	2357978	et	4	main
selle	doc_384045275275_item	2357982	et	4	main
võin	doc_384045275275_item	2357992	et	3	main
vaatamata	doc_384045275275_item	2357998	et	4	main
koju	doc_384045275275_item	2358003	et	3	main
seal	doc_384045275275_item	2358022	et	4	main
vaatamas	doc_384045275275_item	2358026	et	3	main
päeval	doc_384045275275_item	2358029	et	3	main
kalu	doc_384045275275_item	2358032	et	4	main
üldse	doc_384045275275_item	2358037	et	3	main
meeldib	doc_384045275275_item	2358039	et	3	main
ja	doc_384045275275_item	2358047	et	3	main
ei	doc_384045275275_item	2358053	et	4	main
kalu	doc_384045275275_item	2358056	et	4	main
oli	doc_384045275275_item	2358058	et	3	main
kahju	doc_384045275275_item	2358060	et	4	main
järgmine	doc_384045275275_item	2358061	et	3	main
päev	doc_384045275275_item	2358062	et	3	main
oli	doc_384045275275_item	2358063	et	3	main
juba	doc_384045275275_item	2358064	et	3	main
vanaema	doc_384045275275_item	2358070	et	4	main
näitas	doc_384045275275_item	2358076	et	3	main
me	doc_384045275275_item	2358079	et	4	main
kesklinn	doc_384045275275_item	2358089	et	3	main
raekojaplatsil	doc_384045275275_item	2358100	et	3	main
palju	doc_384045275275_item	2358103	et	4	main
ühesõnaga	doc_384045275275_item	2358112	et	3	main
ja	doc_384045275275_item	2357888	et	3	main
tagasi	doc_384045275275_item	2357895	et	3	main
koos	doc_384045275275_item	2357900	et	4	main
seal	doc_384045275275_item	2357906	et	4	main
eriti	doc_384045275275_item	2357907	et	3	main
reisida	doc_384045275275_item	2357908	et	3	main
see	doc_384045275275_item	2357910	et	3	main
sõitsin	doc_384045275275_item	2357914	et	3	main
esimene	doc_384045275275_item	2357917	et	3	main
berliini	doc_384045275275_item	2357929	et	4	main
aga	doc_384045275275_item	2357930	et	3	main
pärast	doc_384045275275_item	2357931	et	4	main
rongiga	doc_384045275275_item	2357932	et	4	main
ja	doc_384045275275_item	2357938	et	3	main
teise	doc_384045275275_item	2357945	et	4	main
oli	doc_384045275275_item	2357949	et	3	main
olla	doc_384045275275_item	2357952	et	3	main
on	doc_384045275275_item	2357954	et	4	main
ilma	doc_384045275275_item	2357962	et	4	main
see	doc_384045275275_item	2357964	et	3	main
ja	doc_384045275275_item	2357968	et	3	main
peale	doc_384045275275_item	2357973	et	4	main
ei	doc_384045275275_item	2357979	et	4	main
oska	doc_384045275275_item	2357980	et	4	main
saksakeelt	doc_384045275275_item	2357981	et	4	main
õnneks	doc_384045275275_item	2357987	et	4	main
ma	doc_384045275275_item	2357988	et	3	main
õpisin	doc_384045275275_item	2357989	et	4	main
me	doc_384045275275_item	2358001	et	4	main
see	doc_384045275275_item	2358004	et	3	main
sõitsime	doc_384045275275_item	2358031	et	3	main
vanaemade	doc_384045275275_item	2358035	et	3	main
melle	doc_384045275275_item	2358038	et	4	main
väga	doc_384045275275_item	2358045	et	3	main
kalapüük	doc_384045275275_item	2358048	et	3	main
püüi	doc_384045275275_item	2358054	et	4	main
huvitavam	doc_384045275275_item	2358065	et	4	main
ja	doc_384045275275_item	2358066	et	3	main
minu	doc_384045275275_item	2358072	et	3	main
neiuga	doc_384045275275_item	2358074	et	4	main
jõululinna	doc_384045275275_item	2358078	et	4	main
peakirikut	doc_384045275275_item	2358081	et	3	main
on	doc_384045275275_item	2358090	et	4	main
ja	doc_384045275275_item	2358098	et	3	main
jõulupüha	doc_384045275275_item	2358113	et	4	main
kiiresti	doc_384045275275_item	2358121	et	3	main
tore	doc_384045275275_item	2358133	et	3	main
ja	doc_384045275275_item	2358134	et	3	main
teha	doc_384045275275_item	2358137	et	3	main
riigis	doc_384045275276_item	2358157	et	3	main
riigikeel	doc_384045275276_item	2358162	et	4	main
ei	doc_384045275276_item	2358172	et	4	main
tea	doc_384045275276_item	2358173	et	4	main
eesti	doc_384045275276_item	2358174	et	4	main
teada	doc_384045275276_item	2358179	et	3	main
ka	doc_384045275276_item	2358180	et	3	main
ikkagi	doc_384045275276_item	2358190	et	4	main
ise	doc_384045275276_item	2358197	et	4	main
ülikoolis	doc_384045275276_item	2358201	et	4	main
kallimatest	doc_384045275276_item	2358209	et	4	main
teaduskondadest	doc_384045275276_item	2358210	et	3	main
seepärast	doc_384045275276_item	2358211	et	3	main
praegu	doc_384045275276_item	2358216	et	3	main
ja	doc_384045275276_item	2358219	et	3	main
sellepärast	doc_384045275276_item	2358221	et	3	main
ja	doc_384045275276_item	2358226	et	3	main
aga	doc_384045275276_item	2358236	et	3	main
liiga	doc_384045275276_item	2358239	et	4	main
tean	doc_384045275276_item	2358261	et	3	main
essee	doc_384045275275_item	2357872	et	4	main
isal	doc_384045275275_item	2357876	et	3	main
puhkus	doc_384045275275_item	2357878	et	3	main
minu	doc_384045275275_item	2357886	et	3	main
vanaema	doc_384045275275_item	2357887	et	4	main
aastat	doc_384045275275_item	2357892	et	3	main
sõitsin	doc_384045275275_item	2357897	et	3	main
ja	doc_384045275275_item	2357903	et	3	main
meeldis	doc_384045275275_item	2357905	et	3	main
on	doc_384045275275_item	2357911	et	4	main
isa	doc_384045275275_item	2357913	et	4	main
kord	doc_384045275275_item	2357918	et	4	main
pärast	doc_384045275275_item	2357920	et	4	main
bremeni	doc_384045275275_item	2357933	et	4	main
kiirpilet	doc_384045275275_item	2357934	et	3	main
liiga	doc_384045275275_item	2357936	et	4	main
kallis	doc_384045275275_item	2357937	et	4	main
kokku	doc_384045275275_item	2357947	et	3	main
see	doc_384045275275_item	2357953	et	3	main
tore	doc_384045275275_item	2357955	et	3	main
vaid	doc_384045275275_item	2357956	et	3	main
kui	doc_384045275275_item	2357957	et	3	main
peatusi	doc_384045275275_item	2357963	et	4	main
väsinud	doc_384045275275_item	2357972	et	4	main
ega	doc_384045275275_item	2357977	et	3	main
inglisekeele	doc_384045275275_item	2357990	et	4	main
noh	doc_384045275275_item	2357997	et	3	main
kõkile	doc_384045275275_item	2357999	et	4	main
istusime	doc_384045275275_item	2358024	et	3	main
telerit	doc_384045275275_item	2358027	et	3	main
see	doc_384045275275_item	2358040	et	3	main
ääres	doc_384045275275_item	2358043	et	4	main
külm	doc_384045275275_item	2358046	et	3	main
ka	doc_384045275275_item	2358069	et	3	main
ühe	doc_384045275275_item	2358073	et	4	main
ta	doc_384045275275_item	2358075	et	4	main
küllastasime	doc_384045275275_item	2358080	et	3	main
on	doc_384045275275_item	2358096	et	4	main
girljandid	doc_384045275275_item	2358097	et	4	main
siin	doc_384045275275_item	2358111	et	4	main
tagasi	doc_384045275275_item	2358122	et	3	main
rongiga	doc_384045275275_item	2358126	et	4	main
ilusaid	doc_384045275275_item	2358139	et	3	main
see	doc_384045275275_item	2358142	et	3	main
tahaksin	doc_384045275275_item	2358144	et	3	main
oli	doc_384045275275_item	2358149	et	3	main
õnnelik	doc_384045275275_item	2358150	et	3	main
essee	doc_384045275276_item	2358151	et	4	main
esse	doc_384045275276_item	2358152	et	3	main
kuna	doc_384045275276_item	2358153	et	3	main
teadma	doc_384045275276_item	2358165	et	3	main
võimatu	doc_384045275276_item	2358168	et	4	main
on	doc_384045275276_item	2358177	et	4	main
keele	doc_384045275276_item	2358182	et	4	main
keel	doc_384045275276_item	2358185	et	4	main
vene	doc_384045275276_item	2358187	et	4	main
õpin	doc_384045275276_item	2358198	et	3	main
tallinna	doc_384045275276_item	2358199	et	4	main
kohal	doc_384045275276_item	2358203	et	4	main
kahjuks	doc_384045275276_item	2358205	et	4	main
kõige	doc_384045275276_item	2358208	et	4	main
töötama	doc_384045275276_item	2358214	et	3	main
iga	doc_384045275276_item	2358217	et	4	main
oli	doc_384045275275_item	2357922	et	3	main
see	doc_384045275275_item	2357924	et	3	main
oli	doc_384045275275_item	2357935	et	3	main
vaja	doc_384045275275_item	2357941	et	4	main
kokku	doc_384045275275_item	2357959	et	3	main
tunni	doc_384045275275_item	2357961	et	3	main
on	doc_384045275275_item	2357965	et	4	main
juba	doc_384045275275_item	2357966	et	3	main
edahujutav	doc_384045275275_item	2357967	et	4	main
pärast	doc_384045275275_item	2357969	et	4	main
seda	doc_384045275275_item	2357974	et	3	main
selgitada	doc_384045275275_item	2357993	et	3	main
kuhu	doc_384045275275_item	2357995	et	3	main
lõpuks	doc_384045275275_item	2358000	et	4	main
jõudsime	doc_384045275275_item	2358002	et	3	main
kord	doc_384045275275_item	2358005	et	4	main
me	doc_384045275275_item	2358006	et	4	main
kaks	doc_384045275275_item	2358011	et	3	main
päevad	doc_384045275275_item	2358012	et	3	main
olid	doc_384045275275_item	2358013	et	4	main
igavad	doc_384045275275_item	2358014	et	3	main
sest	doc_384045275275_item	2358015	et	4	main
et	doc_384045275275_item	2358016	et	3	main
me	doc_384045275275_item	2358017	et	4	main
ei	doc_384045275275_item	2358018	et	4	main
teadnud	doc_384045275275_item	2358019	et	4	main
mida	doc_384045275275_item	2358020	et	4	main
me	doc_384045275275_item	2358030	et	4	main
kiud	doc_384045275275_item	2358041	et	4	main
jõe	doc_384045275275_item	2358042	et	3	main
oli	doc_384045275275_item	2358044	et	3	main
sai	doc_384045275275_item	2358049	et	4	main
ebamugavaks	doc_384045275275_item	2358050	et	3	main
lisaks	doc_384045275275_item	2358051	et	4	main
ma	doc_384045275275_item	2358052	et	3	main
ühegi	doc_384045275275_item	2358055	et	4	main
väga	doc_384045275275_item	2358059	et	3	main
mulle	doc_384045275275_item	2358077	et	4	main
vanalinna	doc_384045275275_item	2358082	et	4	main
mittu	doc_384045275275_item	2358084	et	4	main
suurt	doc_384045275275_item	2358085	et	3	main
elanikud	doc_384045275275_item	2358109	et	3	main
kogunesid	doc_384045275275_item	2358110	et	4	main
sõtsime	doc_384045275275_item	2358123	et	4	main
aluseks	doc_384045275275_item	2358125	et	4	main
seejarel	doc_384045275275_item	2358127	et	4	main
lennukiga	doc_384045275275_item	2358128	et	3	main
see	doc_384045275275_item	2358129	et	3	main
kord	doc_384045275275_item	2358130	et	4	main
ilm	doc_384045275275_item	2358131	et	3	main
oli	doc_384045275275_item	2358132	et	3	main
võin	doc_384045275275_item	2358136	et	3	main
nagu	doc_384045275275_item	2358141	et	3	main
me	doc_384045275276_item	2358154	et	4	main
on	doc_384045275276_item	2358161	et	4	main
seda	doc_384045275276_item	2358164	et	3	main
peaaegu	doc_384045275276_item	2358167	et	3	main
leida	doc_384045275276_item	2358169	et	3	main
tööd	doc_384045275276_item	2358170	et	4	main
kui	doc_384045275276_item	2358171	et	3	main
muidugi	doc_384045275276_item	2358176	et	4	main
näiteks	doc_384045275276_item	2358183	et	4	main
keel	doc_384045275276_item	2358192	et	4	main
on	doc_384045275276_item	2358193	et	4	main
esimesel	doc_384045275276_item	2358194	et	3	main
kohal	doc_384045275276_item	2358195	et	4	main
ma	doc_384045275276_item	2358196	et	3	main
tasulisel	doc_384045275276_item	2358202	et	4	main
on	doc_384045275276_item	2358206	et	4	main
üks	doc_384045275276_item	2358207	et	3	main
ma	doc_384045275276_item	2358212	et	3	main
päev	doc_384045275276_item	2358218	et	3	main
käinud	doc_384045275276_item	2358223	et	4	main
teha	doc_384045275275_item	2358021	et	3	main
ja	doc_384045275275_item	2358023	et	3	main
kodus	doc_384045275275_item	2358025	et	4	main
kolmandal	doc_384045275275_item	2358028	et	3	main
püüa	doc_384045275275_item	2358033	et	4	main
koos	doc_384045275275_item	2358034	et	4	main
tuttavaga	doc_384045275275_item	2358036	et	4	main
see	doc_384045275275_item	2358057	et	3	main
kõik	doc_384045275275_item	2358067	et	4	main
teised	doc_384045275275_item	2358068	et	4	main
tutvustas	doc_384045275275_item	2358071	et	3	main
ja	doc_384045275275_item	2358083	et	3	main
kauplust	doc_384045275275_item	2358086	et	4	main
jõululinn	doc_384045275275_item	2358087	et	3	main
eriri	doc_384045275275_item	2358088	et	4	main
erakordselt	doc_384045275275_item	2358091	et	4	main
ilus	doc_384045275275_item	2358092	et	4	main
sell	doc_384045275275_item	2358093	et	3	main
ajal	doc_384045275275_item	2358094	et	4	main
kõikjal	doc_384045275275_item	2358095	et	3	main
jõuluehted	doc_384045275275_item	2358099	et	3	main
on	doc_384045275275_item	2358101	et	4	main
nii	doc_384045275275_item	2358102	et	3	main
inimesi	doc_384045275275_item	2358104	et	4	main
et	doc_384045275275_item	2358105	et	3	main
näikse	doc_384045275275_item	2358106	et	3	main
nagu	doc_384045275275_item	2358107	et	3	main
kõik	doc_384045275275_item	2358108	et	4	main
tuntakse	doc_384045275275_item	2358114	et	3	main
kõikjal	doc_384045275275_item	2358115	et	3	main
niimodi	doc_384045275275_item	2358116	et	4	main
see	doc_384045275275_item	2358117	et	3	main
nädal	doc_384045275275_item	2358118	et	3	main
käis	doc_384045275275_item	2358119	et	4	main
väga	doc_384045275275_item	2358120	et	3	main
ka	doc_384045275275_item	2358124	et	3	main
palju	doc_384045275275_item	2358138	et	4	main
üldse	doc_384045275275_item	2358143	et	3	main
kõik	doc_384045275276_item	2358155	et	4	main
kus	doc_384045275276_item	2358158	et	3	main
keel	doc_384045275276_item	2358160	et	4	main
on	doc_384045275276_item	2358166	et	4	main
vaja	doc_384045275276_item	2358178	et	4	main
inglise	doc_384045275276_item	2358184	et	4	main
eesti	doc_384045275276_item	2358191	et	4	main
pole	doc_384045275276_item	2358231	et	3	main
võtab	doc_384045275276_item	2358238	et	3	main
ma	doc_384045275276_item	2358243	et	3	main
mis	doc_384045275276_item	2358250	et	4	main
ei	doc_384045275276_item	2358251	et	4	main
keda	doc_384045275276_item	2358259	et	4	main
ühendada	doc_384045275276_item	2358263	et	3	main
õpimist	doc_384045275276_item	2358267	et	4	main
muidugi	doc_384045275276_item	2358268	et	4	main
see	doc_384045275276_item	2358269	et	3	main
mitte	doc_384045275276_item	2358276	et	3	main
soovi	doc_384045275276_item	2358283	et	4	main
ja	doc_384045275276_item	2358286	et	3	main
nii	doc_384045275276_item	2358287	et	3	main
sõltuma	doc_384045275276_item	2358289	et	3	main
ei	doc_384045275277_item	2358299	et	4	main
olnud	doc_384045275277_item	2358300	et	4	main
keele	doc_384045275277_item	2358310	et	4	main
teisipäevati	doc_384045275277_item	2358312	et	3	main
1400	doc_384045275277_item	2358314	et	2	main
igas	doc_384045275277_item	2358318	et	3	main
kuid	doc_384045275277_item	2358320	et	4	main
oktobrikuust	doc_384045275277_item	2358322	et	4	main
ma	doc_384045275277_item	2358333	et	3	main
varakult	doc_384045275277_item	2358334	et	4	main
tööle	doc_384045275277_item	2358335	et	3	main
ja	doc_384045275277_item	2358337	et	3	main
tundi	doc_384045275277_item	2358344	et	4	main
ei	doc_384045275277_item	2358353	et	4	main
segada	doc_384045275277_item	2358356	et	3	main
ma	doc_384045275275_item	2358135	et	3	main
fotosid	doc_384045275275_item	2358140	et	3	main
öelda	doc_384045275275_item	2358145	et	4	main
et	doc_384045275275_item	2358146	et	3	main
see	doc_384045275275_item	2358147	et	3	main
reisimine	doc_384045275275_item	2358148	et	4	main
elame	doc_384045275276_item	2358156	et	3	main
eesti	doc_384045275276_item	2358159	et	4	main
peame	doc_384045275276_item	2358163	et	4	main
keelt	doc_384045275276_item	2358175	et	4	main
teisi	doc_384045275276_item	2358181	et	4	main
ja	doc_384045275276_item	2358186	et	3	main
keel	doc_384045275276_item	2358188	et	4	main
kuid	doc_384045275276_item	2358189	et	4	main
tehnika	doc_384045275276_item	2358200	et	4	main
majandusteaduskond	doc_384045275276_item	2358204	et	3	main
pean	doc_384045275276_item	2358213	et	4	main
töötan	doc_384045275276_item	2358215	et	3	main
just	doc_384045275276_item	2358220	et	3	main
eesti	doc_384045275276_item	2358224	et	4	main
teistes	doc_384045275276_item	2358228	et	4	main
mul	doc_384045275276_item	2358230	et	3	main
midagi	doc_384045275276_item	2358232	et	4	main
oma	doc_384045275276_item	2358233	et	4	main
aega	doc_384045275276_item	2358241	et	4	main
endale	doc_384045275276_item	2358246	et	4	main
teist	doc_384045275276_item	2358248	et	4	main
võta	doc_384045275276_item	2358252	et	4	main
nii	doc_384045275276_item	2358253	et	3	main
palju	doc_384045275276_item	2358254	et	4	main
ma	doc_384045275276_item	2358260	et	3	main
tööt	doc_384045275276_item	2358265	et	4	main
veelgi	doc_384045275276_item	2358279	et	4	main
keegi	doc_384045275276_item	2358281	et	4	main
ei	doc_384045275276_item	2358282	et	4	main
olema	doc_384045275276_item	2358285	et	4	main
kõvasti	doc_384045275276_item	2358288	et	3	main
mind	doc_384045275277_item	2358298	et	4	main
eesti	doc_384045275277_item	2358309	et	4	main
tunnid	doc_384045275277_item	2358311	et	3	main
kell	doc_384045275277_item	2358313	et	3	main
käisin	doc_384045275277_item	2358316	et	3	main
pidin	doc_384045275277_item	2358332	et	3	main
minema	doc_384045275277_item	2358336	et	3	main
ei	doc_384045275277_item	2358339	et	4	main
jõudnud	doc_384045275277_item	2358340	et	4	main
tahan	doc_384045275277_item	2358345	et	3	main
pärast	doc_384045275277_item	2358347	et	4	main
et	doc_384045275277_item	2358351	et	3	main
töö	doc_384045275277_item	2358352	et	4	main
ma	doc_384045275277_item	2358359	et	3	main
alla	doc_384045275277_item	2358361	et	3	main
tööl	doc_384045275277_item	2358368	et	3	main
pärast	doc_384045275277_item	2358373	et	4	main
sain	doc_384045275277_item	2358378	et	3	main
oli	doc_384045275277_item	2358387	et	3	main
võtma	doc_384045275277_item	2358428	et	3	main
oma	doc_384045275277_item	2358433	et	4	main
õigsuses	doc_384045275277_item	2358434	et	3	main
ja	doc_384045275277_item	2358435	et	3	main
järgmisel	doc_384045275277_item	2358437	et	3	main
läksin	doc_384045275277_item	2358439	et	3	main
katkestama	doc_384045275277_item	2358443	et	3	main
oli	doc_384045275277_item	2358445	et	3	main
teine	doc_384045275277_item	2358447	et	3	main
ei	doc_384045275277_item	2358451	et	4	main
läksime	doc_384045275277_item	2358458	et	3	main
sõpradega	doc_384045275277_item	2358460	et	3	main
mulle	doc_384045275277_item	2358477	et	4	main
jalalihase	doc_384045275277_item	2358499	et	4	main
ja	doc_384045275277_item	2358501	et	3	main
kaks	doc_384045275277_item	2358503	et	3	main
lamama	doc_384045275277_item	2358506	et	4	main
vabandust	doc_384045275277_item	2358510	et	4	main
loodan	doc_384045275277_item	2358515	et	3	main
selgitused	doc_384045275277_item	2358518	et	4	main
panevad	doc_384045275277_item	2358519	et	4	main
võimalust	doc_384045275277_item	2358528	et	3	main
tundides	doc_384045275277_item	2358530	et	3	main
iga	doc_384045275278_item	2358546	et	4	main
ja	doc_384045275278_item	2358548	et	3	main
minu	doc_384045275278_item	2358555	et	3	main
tegelen	doc_384045275278_item	2358562	et	3	main
huvitav	doc_384045275278_item	2358566	et	4	main
se	doc_384045275278_item	2358573	et	4	main
mulle	doc_384045275278_item	2358574	et	4	main
meeldib	doc_384045275278_item	2358575	et	3	main
seda	doc_384045275278_item	2358594	et	3	main
ei	doc_384045275276_item	2358222	et	4	main
keele	doc_384045275276_item	2358225	et	4	main
tundides	doc_384045275276_item	2358229	et	3	main
palju	doc_384045275276_item	2358240	et	4	main
leida	doc_384045275276_item	2358245	et	3	main
mõnda	doc_384045275276_item	2358247	et	4	main
tööt	doc_384045275276_item	2358249	et	4	main
aega	doc_384045275276_item	2358255	et	4	main
peaaegu	doc_384045275276_item	2358256	et	3	main
kõik	doc_384045275276_item	2358257	et	4	main
tudengid	doc_384045275276_item	2358258	et	3	main
on	doc_384045275276_item	2358270	et	4	main
päris	doc_384045275276_item	2358271	et	4	main
on	doc_384045275276_item	2358278	et	4	main
ülalpeetav	doc_384045275276_item	2358284	et	3	main
oma	doc_384045275276_item	2358290	et	4	main
mida	doc_384045275277_item	2358293	et	4	main
kui	doc_384045275277_item	2358297	et	3	main
tunniplaani	doc_384045275277_item	2358304	et	4	main
j	doc_384045275277_item	2358305	et	4	main
ärgi	doc_384045275277_item	2358306	et	4	main
alates	doc_384045275277_item	2358321	et	3	main
tööd	doc_384045275277_item	2358325	et	4	main
farmaatsiaettevõtes	doc_384045275277_item	2358327	et	3	main
seetõttu	doc_384045275277_item	2358338	et	3	main
eesti	doc_384045275277_item	2358342	et	4	main
puudumise	doc_384045275277_item	2358346	et	4	main
vabandust	doc_384045275277_item	2358348	et	4	main
paluma	doc_384045275277_item	2358349	et	3	main
tean	doc_384045275277_item	2358350	et	3	main
õppimast	doc_384045275277_item	2358355	et	3	main
töölepingule	doc_384045275277_item	2358360	et	4	main
kindel	doc_384045275277_item	2358364	et	3	main
nii	doc_384045275277_item	2358367	et	3	main
ka	doc_384045275277_item	2358371	et	3	main
kuud	doc_384045275277_item	2358375	et	4	main
päevaplaani	doc_384045275277_item	2358377	et	4	main
aru	doc_384045275277_item	2358381	et	4	main
pean	doc_384045275277_item	2358383	et	4	main
mul	doc_384045275277_item	2358386	et	3	main
mõnedes	doc_384045275276_item	2358227	et	3	main
töö	doc_384045275276_item	2358234	et	4	main
vastu	doc_384045275276_item	2358235	et	3	main
see	doc_384045275276_item	2358237	et	3	main
ja	doc_384045275276_item	2358242	et	3	main
tahaks	doc_384045275276_item	2358244	et	3	main
katsuvad	doc_384045275276_item	2358262	et	4	main
töötada	doc_384045275276_item	2358277	et	3	main
raskem	doc_384045275276_item	2358280	et	4	main
essee	doc_384045275277_item	2358292	et	4	main
ma	doc_384045275277_item	2358294	et	3	main
olen	doc_384045275277_item	2358295	et	3	main
eesti	doc_384045275277_item	2358301	et	4	main
meil	doc_384045275277_item	2358308	et	4	main
oma	doc_384045275276_item	2358264	et	4	main
ja	doc_384045275276_item	2358266	et	3	main
raske	doc_384045275276_item	2358272	et	4	main
aga	doc_384045275276_item	2358273	et	3	main
teiseti	doc_384045275276_item	2358274	et	4	main
kui	doc_384045275276_item	2358275	et	3	main
vanematest	doc_384045275276_item	2358291	et	4	main
teinud	doc_384045275277_item	2358296	et	4	main
keele	doc_384045275277_item	2358302	et	4	main
tunnis	doc_384045275277_item	2358303	et	3	main
olid	doc_384045275277_item	2358307	et	4	main
septembris	doc_384045275277_item	2358315	et	3	main
ma	doc_384045275277_item	2358317	et	3	main
tunnis	doc_384045275277_item	2358319	et	3	main
alustasin	doc_384045275277_item	2358323	et	3	main
ma	doc_384045275277_item	2358324	et	3	main
ühes	doc_384045275277_item	2358326	et	4	main
komplekteerijana	doc_384045275277_item	2358329	et	4	main
mõnikord	doc_384045275277_item	2358331	et	3	main
ma	doc_384045275277_item	2358341	et	3	main
või	doc_384045275277_item	2358354	et	4	main
kuid	doc_384045275277_item	2358357	et	4	main
olin	doc_384045275277_item	2358363	et	3	main
käia	doc_384045275277_item	2358369	et	4	main
kaks	doc_384045275277_item	2358374	et	3	main
tööd	doc_384045275277_item	2358384	et	4	main
õppimist	doc_384045275277_item	2358426	et	4	main
ta	doc_384045275277_item	2358430	et	4	main
veenis	doc_384045275277_item	2358431	et	4	main
kontorisse	doc_384045275277_item	2358441	et	3	main
eesti	doc_384045275277_item	2358453	et	4	main
keele	doc_384045275277_item	2358454	et	4	main
parem	doc_384045275277_item	2358485	et	4	main
ma	doc_384045275277_item	2358488	et	3	main
laskuda	doc_384045275277_item	2358494	et	3	main
lõpuks	doc_384045275277_item	2358496	et	4	main
minu	doc_384045275277_item	2358511	et	3	main
ja	doc_384045275277_item	2358514	et	3	main
minu	doc_384045275277_item	2358517	et	3	main
teid	doc_384045275277_item	2358520	et	4	main
mida	doc_384045275278_item	2358533	et	4	main
loengul	doc_384045275278_item	2358538	et	3	main
sel	doc_384045275278_item	2358549	et	3	main
mina	doc_384045275278_item	2358551	et	4	main
töö	doc_384045275278_item	2358556	et	4	main
seotud	doc_384045275278_item	2358558	et	4	main
filmidega	doc_384045275278_item	2358560	et	3	main
olin	doc_384045275278_item	2358578	et	3	main
ja	doc_384045275278_item	2358589	et	3	main
pärast	doc_384045275278_item	2358593	et	4	main
oli	doc_384045275278_item	2358622	et	3	main
sündis	doc_384045275278_item	2358627	et	3	main
saime	doc_384045275278_item	2358641	et	3	main
ammu	doc_384045275278_item	2358645	et	4	main
näinud	doc_384045275278_item	2358647	et	4	main
meie	doc_384045275278_item	2358648	et	4	main
sugulasi	doc_384045275278_item	2358649	et	3	main
lõbus	doc_384045275278_item	2358656	et	4	main
aga	doc_384045275278_item	2358660	et	3	main
minu	doc_384045275278_item	2358672	et	3	main
ja	doc_384045275278_item	2358680	et	3	main
kui	doc_384045275278_item	2358715	et	3	main
õpetus	doc_384045275279_item	2358722	et	4	main
fraseologismidest	doc_384045275279_item	2358723	et	3	main
püsivatest	doc_384045275279_item	2358724	et	4	main
tähendusega	doc_384045275279_item	2358727	et	4	main
fraseoloogilisi	doc_384045275279_item	2358745	et	3	main
väljendeid	doc_384045275279_item	2358746	et	3	main
traditsioonis	doc_384045275279_item	2358754	et	3	main
käibel	doc_384045275279_item	2358756	et	4	main
fraseologism	doc_384045275279_item	2358766	et	3	main
peaasjalikult	doc_384045275279_item	2358769	et	4	main
teesist	doc_384045275279_item	2358779	et	4	main
kujuta	doc_384045275279_item	2358783	et	4	main
väljendeid	doc_384045275279_item	2358786	et	3	main
xxxxxxxxxxx	doc_384045275280_item	2358821	et	4	main
perekonnanimi	doc_384045275280_item	2358823	et	3	main
magistritöö	doc_384045275280_item	2358824	et	4	main
õpilaste	doc_384045275280_item	2358826	et	4	main
keelekümbliskooli	doc_384045275280_item	2358831	et	4	main
magistritöö	doc_384045275280_item	2358840	et	4	main
ravimite	doc_384045275277_item	2358328	et	3	main
kahjuks	doc_384045275277_item	2358330	et	4	main
keele	doc_384045275277_item	2358343	et	4	main
kirjutasin	doc_384045275277_item	2358362	et	3	main
et	doc_384045275277_item	2358365	et	3	main
õppida	doc_384045275277_item	2358372	et	3	main
pingelist	doc_384045275277_item	2358376	et	4	main
ma	doc_384045275277_item	2358379	et	3	main
lõpuks	doc_384045275277_item	2358380	et	4	main
katkestama	doc_384045275277_item	2358385	et	3	main
et	doc_384045275277_item	2358389	et	3	main
ma	doc_384045275277_item	2358390	et	3	main
töötan	doc_384045275277_item	2358391	et	3	main
kahes	doc_384045275277_item	2358392	et	4	main
vahetuses	doc_384045275277_item	2358393	et	4	main
vaatamata	doc_384045275277_item	2358394	et	4	main
sellele	doc_384045275277_item	2358395	et	4	main
et	doc_384045275277_item	2358396	et	3	main
töötasin	doc_384045275277_item	2358397	et	3	main
osakoormusega	doc_384045275277_item	2358398	et	3	main
arvan	doc_384045275277_item	2358399	et	3	main
et	doc_384045275277_item	2358400	et	3	main
selline	doc_384045275277_item	2358401	et	4	main
tunne	doc_384045275277_item	2358402	et	4	main
tekkis	doc_384045275277_item	2358403	et	3	main
sellepärast	doc_384045275277_item	2358404	et	3	main
et	doc_384045275277_item	2358405	et	3	main
mõnikord	doc_384045275277_item	2358406	et	3	main
pidin	doc_384045275277_item	2358407	et	3	main
ületunnitööd	doc_384045275277_item	2358408	et	4	main
tegema	doc_384045275277_item	2358409	et	3	main
minu	doc_384045275277_item	2358410	et	3	main
sõber	doc_384045275277_item	2358411	et	3	main
ütles	doc_384045275277_item	2358412	et	3	main
et	doc_384045275277_item	2358413	et	3	main
kui	doc_384045275277_item	2358414	et	3	main
kõiki	doc_384045275277_item	2358415	et	4	main
poolt-	doc_384045275277_item	2358416	et	4	main
ja	doc_384045275277_item	2358417	et	3	main
vastuargumente	doc_384045275277_item	2358418	et	3	main
arvestama	doc_384045275277_item	2358419	et	3	main
pean	doc_384045275277_item	2358420	et	4	main
ma	doc_384045275277_item	2358421	et	3	main
mina	doc_384045275277_item	2358440	et	4	main
põhjus	doc_384045275277_item	2358448	et	4	main
ma	doc_384045275277_item	2358450	et	3	main
käinud	doc_384045275277_item	2358452	et	4	main
oktoobrikuu	doc_384045275277_item	2358456	et	4	main
puhkama	doc_384045275277_item	2358462	et	3	main
kui	doc_384045275277_item	2358358	et	3	main
jõuan	doc_384045275277_item	2358366	et	3	main
kui	doc_384045275277_item	2358370	et	3	main
et	doc_384045275277_item	2358382	et	3	main
tunne	doc_384045275277_item	2358388	et	4	main
tööd	doc_384045275277_item	2358422	et	4	main
ja	doc_384045275277_item	2358425	et	3	main
juba	doc_384045275277_item	2358436	et	3	main
päeval	doc_384045275277_item	2358438	et	3	main
ka	doc_384045275277_item	2358446	et	3	main
miks	doc_384045275277_item	2358449	et	4	main
tunnis	doc_384045275277_item	2358455	et	3	main
me	doc_384045275277_item	2358459	et	4	main
riigasse	doc_384045275277_item	2358461	et	4	main
atraktsioon	doc_384045275277_item	2358480	et	3	main
mis	doc_384045275277_item	2358481	et	4	main
oli	doc_384045275277_item	2358482	et	3	main
bobisõidu	doc_384045275277_item	2358483	et	4	main
moodi	doc_384045275277_item	2358484	et	4	main
proovinud	doc_384045275277_item	2358490	et	4	main
alla	doc_384045275277_item	2358493	et	3	main
kuna	doc_384045275277_item	2358495	et	3	main
venitasin	doc_384045275277_item	2358498	et	3	main
voodis	doc_384045275277_item	2358505	et	3	main
palun	doc_384045275277_item	2358507	et	3	main
kord	doc_384045275277_item	2358509	et	4	main
pärast	doc_384045275277_item	2358513	et	4	main
tõesti	doc_384045275277_item	2358524	et	3	main
olnud	doc_384045275277_item	2358526	et	4	main
mõnikord	doc_384045275277_item	2358527	et	3	main
essee	doc_384045275278_item	2358532	et	4	main
kui	doc_384045275278_item	2358536	et	3	main
oli	doc_384045275278_item	2358545	et	3	main
kolmapäev	doc_384045275278_item	2358547	et	3	main
päeval	doc_384045275278_item	2358550	et	3	main
tihti	doc_384045275278_item	2358552	et	3	main
montaziga	doc_384045275278_item	2358564	et	4	main
ja	doc_384045275278_item	2358567	et	3	main
ajal	doc_384045275278_item	2358569	et	4	main
raske	doc_384045275278_item	2358570	et	4	main
töö	doc_384045275278_item	2358571	et	4	main
aga	doc_384045275278_item	2358572	et	3	main
huvitanud	doc_384045275278_item	2358579	et	4	main
koosneb	doc_384045275278_item	2358583	et	3	main
video	doc_384045275278_item	2358586	et	4	main
operaator	doc_384045275278_item	2358587	et	3	main
mulle	doc_384045275278_item	2358591	et	4	main
mina	doc_384045275278_item	2358595	et	4	main
ja	doc_384045275278_item	2358624	et	3	main
plaan	doc_384045275278_item	2358629	et	3	main
me	doc_384045275278_item	2358640	et	4	main
ahvi	doc_384045275278_item	2358650	et	4	main
ja	doc_384045275278_item	2358651	et	3	main
otsustaime	doc_384045275278_item	2358652	et	4	main
ja	doc_384045275278_item	2358657	et	3	main
mina	doc_384045275278_item	2358663	et	4	main
teine	doc_384045275278_item	2358667	et	3	main
endises	doc_384045275278_item	2358673	et	3	main
seal	doc_384045275278_item	2358675	et	4	main
oli	doc_384045275278_item	2358676	et	3	main
nn	doc_384045275278_item	2358677	et	4	main
õppealajuhataja	doc_384045275278_item	2358682	et	4	main
puutusin	doc_384045275278_item	2358716	et	3	main
on	doc_384045275279_item	2358721	et	4	main
nimetatakse	doc_384045275279_item	2358739	et	3	main
sõnakõlkse	doc_384045275279_item	2358741	et	3	main
sõnu	doc_384045275279_item	2358744	et	4	main
pigem	doc_384045275279_item	2358763	et	3	main
terminit	doc_384045275279_item	2358765	et	3	main
üsnagi	doc_384045275279_item	2358775	et	3	main
lähtuda	doc_384045275279_item	2358778	et	3	main
et	doc_384045275279_item	2358780	et	3	main
endast	doc_384045275279_item	2358784	et	4	main
tava-	doc_384045275280_item	2358829	et	4	main
ja	doc_384045275280_item	2358830	et	3	main
klassis	doc_384045275280_item	2358833	et	3	main
et	doc_384045275280_item	2358838	et	3	main
on	doc_384045275280_item	2358842	et	4	main
tavakoolis	doc_384045275280_item	2358846	et	4	main
toimub	doc_384045275280_item	2358849	et	3	main
täheldada	doc_384045275280_item	2358858	et	3	main
eesmärkide	doc_384045275280_item	2358861	et	3	main
järele	doc_384045275277_item	2358423	et	4	main
jätma	doc_384045275277_item	2358424	et	3	main
käsile	doc_384045275277_item	2358427	et	4	main
tegelikult	doc_384045275277_item	2358429	et	4	main
mind	doc_384045275277_item	2358432	et	4	main
töölepingut	doc_384045275277_item	2358442	et	3	main
oktoobris	doc_384045275277_item	2358444	et	3	main
alguses	doc_384045275277_item	2358457	et	4	main
esimesel	doc_384045275277_item	2358463	et	3	main
päeval	doc_384045275277_item	2358464	et	3	main
oli	doc_384045275277_item	2358465	et	3	main
kõik	doc_384045275277_item	2358466	et	4	main
suurepärane	doc_384045275277_item	2358467	et	4	main
kuid	doc_384045275277_item	2358468	et	4	main
teisel	doc_384045275277_item	2358469	et	4	main
päeval	doc_384045275277_item	2358470	et	3	main
juhtus	doc_384045275277_item	2358471	et	3	main
õnnetus	doc_384045275277_item	2358472	et	4	main
me	doc_384045275277_item	2358473	et	4	main
läksime	doc_384045275277_item	2358474	et	3	main
lõbustusparki	doc_384045275277_item	2358475	et	4	main
kus	doc_384045275277_item	2358476	et	3	main
meeldis	doc_384045275277_item	2358478	et	3	main
üks	doc_384045275277_item	2358479	et	3	main
oleks	doc_384045275277_item	2358486	et	3	main
ei	doc_384045275277_item	2358489	et	4	main
toost	doc_384045275277_item	2358491	et	3	main
mäest	doc_384045275277_item	2358492	et	3	main
puudumise	doc_384045275277_item	2358512	et	4	main
et	doc_384045275277_item	2358516	et	3	main
uskuma	doc_384045275277_item	2358521	et	3	main
mul	doc_384045275277_item	2358523	et	3	main
ei	doc_384045275277_item	2358525	et	4	main
teie	doc_384045275277_item	2358529	et	4	main
ma	doc_384045275278_item	2358534	et	3	main
meil	doc_384045275278_item	2358544	et	4	main
töötama	doc_384045275278_item	2358554	et	3	main
on	doc_384045275278_item	2358557	et	4	main
video	doc_384045275278_item	2358559	et	4	main
vidio	doc_384045275278_item	2358563	et	4	main
alati	doc_384045275278_item	2358577	et	4	main
filmide	doc_384045275278_item	2358580	et	3	main
millest	doc_384045275278_item	2358582	et	3	main
kasetti	doc_384045275278_item	2358592	et	4	main
kui	doc_384045275277_item	2358487	et	3	main
ma	doc_384045275277_item	2358497	et	3	main
ära	doc_384045275277_item	2358500	et	4	main
pidin	doc_384045275277_item	2358502	et	3	main
nädalat	doc_384045275277_item	2358504	et	3	main
veel	doc_384045275277_item	2358508	et	4	main
et	doc_384045275277_item	2358522	et	3	main
käia	doc_384045275277_item	2358531	et	4	main
tegin	doc_384045275278_item	2358535	et	3	main
puutusin	doc_384045275278_item	2358537	et	3	main
esmakordselt	doc_384045275278_item	2358539	et	4	main
mina	doc_384045275278_item	2358540	et	4	main
t	doc_384045275278_item	2358541	et	4	main
öötasin	doc_384045275278_item	2358542	et	4	main
loeng	doc_384045275278_item	2358543	et	3	main
pidin	doc_384045275278_item	2358553	et	3	main
mina	doc_384045275278_item	2358561	et	4	main
väga	doc_384045275278_item	2358565	et	3	main
samal	doc_384045275278_item	2358568	et	3	main
mina	doc_384045275278_item	2358576	et	4	main
tegevuses	doc_384045275278_item	2358581	et	4	main
minu	doc_384045275278_item	2358584	et	3	main
töö	doc_384045275278_item	2358585	et	4	main
filmistab	doc_384045275278_item	2358588	et	4	main
annab	doc_384045275278_item	2358590	et	3	main
video	doc_384045275278_item	2358597	et	4	main
minu	doc_384045275278_item	2358598	et	3	main
arvutile	doc_384045275278_item	2358599	et	4	main
ja	doc_384045275278_item	2358600	et	3	main
pärast	doc_384045275278_item	2358601	et	4	main
seda	doc_384045275278_item	2358602	et	3	main
töötan	doc_384045275278_item	2358603	et	3	main
sellega	doc_384045275278_item	2358604	et	3	main
ja	doc_384045275278_item	2358605	et	3	main
teen	doc_384045275278_item	2358606	et	3	main
dvd	doc_384045275278_item	2358607	et	4	main
just	doc_384045275278_item	2358608	et	3	main
seda	doc_384045275278_item	2358609	et	3	main
mina	doc_384045275278_item	2358610	et	4	main
tegin	doc_384045275278_item	2358611	et	3	main
kuj	doc_384045275278_item	2358612	et	4	main
puutusin	doc_384045275278_item	2358613	et	3	main
loengust	doc_384045275278_item	2358614	et	4	main
üks	doc_384045275278_item	2358615	et	3	main
kord	doc_384045275278_item	2358616	et	4	main
mina	doc_384045275278_item	2358617	et	4	main
lihtsalt	doc_384045275278_item	2358618	et	4	main
tegin	doc_384045275278_item	2358619	et	3	main
poppi	doc_384045275278_item	2358620	et	4	main
see	doc_384045275278_item	2358621	et	3	main
sõpradega	doc_384045275278_item	2358626	et	3	main
võivad	doc_384045275278_item	2358634	et	4	main
kahekümneaastased	doc_384045275278_item	2358636	et	4	main
üliõppilased	doc_384045275278_item	2358637	et	4	main
muidugi	doc_384045275278_item	2358638	et	4	main
loomaaja	doc_384045275278_item	2358639	et	4	main
aru	doc_384045275278_item	2358642	et	4	main
juba	doc_384045275278_item	2358644	et	3	main
ei	doc_384045275278_item	2358646	et	4	main
oli	doc_384045275278_item	2358655	et	3	main
seepärast	doc_384045275278_item	2358662	et	3	main
minu	doc_384045275278_item	2358681	et	3	main
mida	doc_384045275278_item	2358712	et	4	main
ma	doc_384045275278_item	2358713	et	3	main
tõmban	doc_384045275278_item	2358596	et	3	main
septembris	doc_384045275278_item	2358623	et	3	main
kuidas	doc_384045275278_item	2358630	et	3	main
arvate	doc_384045275278_item	2358632	et	3	main
tulla	doc_384045275278_item	2358635	et	3	main
neid	doc_384045275278_item	2358653	et	4	main
põnev	doc_384045275278_item	2358658	et	3	main
esse	doc_384045275278_item	2358666	et	3	main
tähte	doc_384045275278_item	2358678	et	4	main
kontsert	doc_384045275278_item	2358679	et	3	main
loengutest	doc_384045275278_item	2358717	et	4	main
meil	doc_384045275278_item	2358625	et	4	main
geniaalne	doc_384045275278_item	2358628	et	3	main
te	doc_384045275278_item	2358631	et	4	main
kuhu	doc_384045275278_item	2358633	et	3	main
et	doc_384045275278_item	2358643	et	3	main
vaadata	doc_384045275278_item	2358654	et	4	main
päev	doc_384045275278_item	2358659	et	3	main
pragu	doc_384045275278_item	2358661	et	4	main
pean	doc_384045275278_item	2358664	et	4	main
kirjutama	doc_384045275278_item	2358665	et	3	main
kord	doc_384045275278_item	2358668	et	4	main
mul	doc_384045275278_item	2358669	et	3	main
oli	doc_384045275278_item	2358670	et	3	main
kontsert	doc_384045275278_item	2358671	et	3	main
koolis	doc_384045275278_item	2358674	et	4	main
küsis	doc_384045275278_item	2358683	et	3	main
mind	doc_384045275278_item	2358684	et	4	main
mängida	doc_384045275278_item	2358685	et	3	main
ka-	doc_384045275278_item	2358686	et	3	main
mina	doc_384045275278_item	2358687	et	4	main
mängisin	doc_384045275278_item	2358688	et	3	main
tihti	doc_384045275278_item	2358689	et	3	main
koolis	doc_384045275278_item	2358690	et	4	main
kuj	doc_384045275278_item	2358691	et	4	main
õppisin	doc_384045275278_item	2358692	et	3	main
seal	doc_384045275278_item	2358693	et	4	main
mängin	doc_384045275278_item	2358694	et	3	main
gitari	doc_384045275278_item	2358695	et	4	main
juba	doc_384045275278_item	2358696	et	3	main
kaheksa	doc_384045275278_item	2358697	et	4	main
aastat	doc_384045275278_item	2358698	et	3	main
mul	doc_384045275278_item	2358699	et	3	main
on	doc_384045275278_item	2358700	et	4	main
noorem	doc_384045275278_item	2358701	et	4	main
muusika	doc_384045275278_item	2358702	et	4	main
haridus	doc_384045275278_item	2358703	et	3	main
see	doc_384045275278_item	2358704	et	3	main
on	doc_384045275278_item	2358705	et	4	main
minu	doc_384045275278_item	2358706	et	3	main
aus	doc_384045275278_item	2358707	et	4	main
ja	doc_384045275278_item	2358708	et	3	main
lõbus	doc_384045275278_item	2358709	et	4	main
jutustus	doc_384045275278_item	2358710	et	4	main
sellest	doc_384045275278_item	2358711	et	4	main
tegin	doc_384045275278_item	2358714	et	3	main
sissejuhatus	doc_384045275279_item	2358719	et	4	main
fraseoloogia	doc_384045275279_item	2358720	et	4	main
piltlike	doc_384045275279_item	2358725	et	3	main
iseloomustavad	doc_384045275279_item	2358747	et	4	main
nimetust	doc_384045275279_item	2358758	et	4	main
termin	doc_384045275279_item	2358760	et	3	main
aga	doc_384045275279_item	2358773	et	3	main
olla	doc_384045275279_item	2358774	et	3	main
erinev	doc_384045275279_item	2358776	et	4	main
vanasõnad	doc_384045275279_item	2358781	et	3	main
kõnekäände	doc_384045275279_item	2358788	et	4	main
referaadi	doc_384045275279_item	2358718	et	3	main
sõnaühenditest	doc_384045275279_item	2358728	et	3	main
fraseoloogia	doc_384045275279_item	2358729	et	4	main
all	doc_384045275279_item	2358730	et	3	main
ülekantud	doc_384045275279_item	2358737	et	4	main
tähenduses	doc_384045275279_item	2358738	et	4	main
fraseoloogiaks	doc_384045275279_item	2358740	et	3	main
või	doc_384045275279_item	2358742	et	4	main
katteta	doc_384045275279_item	2358743	et	3	main
püsivus	doc_384045275279_item	2358749	et	4	main
ja	doc_384045275279_item	2358751	et	3	main
eesti	doc_384045275279_item	2358753	et	4	main
on	doc_384045275279_item	2358755	et	4	main
kaks	doc_384045275279_item	2358757	et	3	main
on	doc_384045275279_item	2358762	et	4	main
kõnekeelne	doc_384045275279_item	2358764	et	3	main
aga	doc_384045275279_item	2358767	et	3	main
võib	doc_384045275279_item	2358772	et	3	main
võiksime	doc_384045275279_item	2358777	et	3	main
fraseoloogilisi	doc_384045275279_item	2358785	et	3	main
omandamist	doc_384045275280_item	2358828	et	4	main
6	doc_384045275280_item	2358832	et	2	main
lk	doc_384045275280_item	2358834	et	4	main
kirjutab	doc_384045275280_item	2358836	et	3	main
autor	doc_384045275280_item	2358837	et	3	main
uurida	doc_384045275280_item	2358843	et	3	main
kas	doc_384045275280_item	2358845	et	3	main
keelekümbluskoolis	doc_384045275280_item	2358848	et	4	main
miks	doc_384045275280_item	2358853	et	4	main
töö	doc_384045275280_item	2358860	et	4	main
seisukohalt	doc_384045275280_item	2358870	et	4	main
oma	doc_384045275280_item	2358882	et	4	main
uurin	doc_384045275280_item	2358884	et	3	main
nad	doc_384045275280_item	2358923	et	3	main
töös	doc_384045275280_item	2358927	et	3	main
on	doc_384045275280_item	2358932	et	4	main
tuttavad	doc_384045275280_item	2358933	et	4	main
töö	doc_384045275280_item	2358939	et	4	main
pööran	doc_384045275280_item	2358942	et	3	main
tuletised	doc_384045275280_item	2358950	et	3	main
omandavad	doc_384045275280_item	2358961	et	4	main
õpilased	doc_384045275280_item	2358962	et	3	main
sõnavara	doc_384045275280_item	2358963	et	4	main
tava-	doc_384045275280_item	2358964	et	4	main
ja	doc_384045275280_item	2358965	et	3	main
keelekümbluskoolis	doc_384045275280_item	2358966	et	4	main
kus	doc_384045275280_item	2358967	et	3	main
1	doc_384045275280_item	2358973	et	2	main
4	doc_384045275280_item	2358983	et	2	main
on	doc_384045275280_item	2358988	et	4	main
rida	doc_384045275280_item	2358991	et	4	main
terviklike	doc_384045275279_item	2358726	et	3	main
võidakse	doc_384045275279_item	2358731	et	3	main
mõista	doc_384045275279_item	2358732	et	4	main
ka	doc_384045275279_item	2358733	et	3	main
fraseologismide	doc_384045275279_item	2358734	et	3	main
kokumit	doc_384045275279_item	2358735	et	4	main
ja	doc_384045275279_item	2358736	et	3	main
reprodutseeritavus	doc_384045275279_item	2358748	et	4	main
motiveeritus	doc_384045275279_item	2358750	et	4	main
idiomaatilisus	doc_384045275279_item	2358752	et	4	main
kusjuures	doc_384045275279_item	2358759	et	3	main
kõnekäänd	doc_384045275279_item	2358761	et	3	main
tarvitavad	doc_384045275279_item	2358768	et	4	main
keeleteadlased	doc_384045275279_item	2358770	et	3	main
keeliti	doc_384045275279_item	2358771	et	3	main
ei	doc_384045275279_item	2358782	et	4	main
seevastu	doc_384045275279_item	2358787	et	3	main
e	doc_384045275279_item	2358789	et	4	main
idiomaatilisi	doc_384045275279_item	2358790	et	3	main
väljendeid	doc_384045275279_item	2358791	et	3	main
tuleks	doc_384045275279_item	2358792	et	4	main
kvalifitseerida	doc_384045275279_item	2358793	et	3	main
fraseologismidena	doc_384045275279_item	2358794	et	3	main
oma	doc_384045275279_item	2358795	et	4	main
referaadis	doc_384045275279_item	2358796	et	3	main
käsitlen	doc_384045275279_item	2358797	et	3	main
inimesega	doc_384045275279_item	2358798	et	3	main
seotud	doc_384045275279_item	2358799	et	4	main
eesti	doc_384045275279_item	2358800	et	4	main
keele	doc_384045275279_item	2358801	et	4	main
sõnavara	doc_384045275279_item	2358803	et	4	main
fraseoloogilist	doc_384045275279_item	2358802	et	3	main
uurin	doc_384045275279_item	2358804	et	3	main
anatoomiast	doc_384045275279_item	2358805	et	3	main
tulenevaid	doc_384045275279_item	2358806	et	4	main
sõnaühendeid	doc_384045275279_item	2358807	et	3	main
tõin	doc_384045275279_item	2358808	et	3	main
välja	doc_384045275279_item	2358809	et	4	main
levinumad	doc_384045275279_item	2358810	et	4	main
ja	doc_384045275279_item	2358811	et	3	main
huvitavamad	doc_384045275279_item	2358812	et	4	main
fraseologismid	doc_384045275279_item	2358813	et	3	main
ja	doc_384045275279_item	2358814	et	3	main
kõnekäänud	doc_384045275279_item	2358815	et	3	main
retsensioon	doc_384045275280_item	2358816	et	3	main
retsensioon	doc_384045275280_item	2358817	et	3	main
eesnimi	doc_384045275280_item	2358818	et	3	main
perekonnanimi	doc_384045275280_item	2358819	et	3	main
magistritööle	doc_384045275280_item	2358820	et	3	main
eesnimi	doc_384045275280_item	2358822	et	3	main
sõnavara	doc_384045275280_item	2358827	et	4	main
sõnavara	doc_384045275280_item	2358851	et	4	main
omandamine	doc_384045275280_item	2358852	et	4	main
eraldanud	doc_384045275280_item	2358867	et	4	main
küsimusi	doc_384045275280_item	2358874	et	4	main
9	doc_384045275280_item	2358881	et	2	main
mis	doc_384045275280_item	2358921	et	4	main
praktilises	doc_384045275280_item	2358940	et	3	main
sellele	doc_384045275280_item	2358944	et	4	main
kuidas	doc_384045275280_item	2358960	et	3	main
omandamine	doc_384045275280_item	2358969	et	4	main
toimub	doc_384045275280_item	2358970	et	3	main
paremini	doc_384045275280_item	2358971	et	4	main
eesmärk	doc_384045275280_item	2358987	et	3	main
ja	doc_384045275280_item	2359029	et	3	main
peatükk	doc_384045275280_item	2359033	et	3	main
sellega	doc_384045275280_item	2359040	et	3	main
teine	doc_384045275280_item	2359042	et	3	main
peatükk	doc_384045275280_item	2359044	et	3	main
sõna	doc_384045275280_item	2359046	et	4	main
tutvustab	doc_384045275280_item	2359068	et	3	main
õpetamise	doc_384045275280_item	2359072	et	4	main
valik	doc_384045275280_item	2359088	et	3	main
pole	doc_384045275280_item	2359089	et	3	main
omandamine	doc_384045275280_item	2359096	et	4	main
6	doc_384045275280_item	2359100	et	2	main
õpilaste	doc_384045275280_item	2359102	et	4	main
e	doc_384045275280_item	2359106	et	4	main
uurima	doc_384045275280_item	2359109	et	3	main
viisil	doc_384045275280_item	2359111	et	4	main
õpetatakse	doc_384045275280_item	2359112	et	3	main
uusi	doc_384045275280_item	2359113	et	3	main
sõnu	doc_384045275280_item	2359114	et	4	main
keelekümbluses	doc_384045275280_item	2359115	et	3	main
ja	doc_384045275280_item	2359116	et	3	main
õpilastel	doc_384045275280_item	2359123	et	4	main
jms	doc_384045275280_item	2359125	et	4	main
seda	doc_384045275280_item	2359126	et	3	main
laadi	doc_384045275280_item	2359127	et	4	main
ja	doc_384045275280_item	2359134	et	3	main
termin	doc_384045275280_item	2359136	et	3	main
protsessi	doc_384045275280_item	2359140	et	4	main
hoopis	doc_384045275280_item	2359145	et	3	main
kirjaliku	doc_384045275280_item	2359147	et	3	main
mõlema	doc_384045275280_item	2359154	et	3	main
on	doc_384045275280_item	2359157	et	4	main
omandanud	doc_384045275280_item	2359159	et	4	main
kuidas	doc_384045275280_item	2359185	et	3	main
tavakoolis	doc_384045275280_item	2359191	et	4	main
mis	doc_384045275280_item	2359201	et	4	main
7	doc_384045275280_item	2359205	et	2	main
leiab	doc_384045275280_item	2359207	et	3	main
vahel	doc_384045275280_item	2359221	et	4	main
õppijad	doc_384045275280_item	2359235	et	4	main
eriti	doc_384045275280_item	2359236	et	3	main
teise	doc_384045275280_item	2359237	et	4	main
kontseptsiooni	doc_384045275280_item	2359263	et	4	main
mälus	doc_384045275280_item	2359270	et	4	main
küsitav	doc_384045275280_item	2359282	et	4	main
e	doc_384045275280_item	2359284	et	4	main
paneb	doc_384045275280_item	2359297	et	3	main
kauaks	doc_384045275280_item	2359299	et	3	main
pole	doc_384045275280_item	2359309	et	3	main
ilmselgeid	doc_384045275280_item	2359313	et	3	main
eesmärk	doc_384045275280_item	2359321	et	3	main
seda	doc_384045275280_item	2359323	et	3	main
et	doc_384045275280_item	2359325	et	3	main
pole	doc_384045275280_item	2359329	et	3	main
osas	doc_384045275280_item	2359341	et	4	main
sõnavara	doc_384045275280_item	2359357	et	4	main
meetoditest	doc_384045275280_item	2359359	et	3	main
töös	doc_384045275280_item	2359361	et	3	main
olemas	doc_384045275280_item	2359362	et	4	main
võrdlemine	doc_384045275280_item	2359370	et	4	main
saab	doc_384045275280_item	2359373	et	3	main
omandatud	doc_384045275280_item	2359382	et	4	main
perekonnanimi	doc_384045275280_item	2359399	et	3	main
kaugeleulatuvaid	doc_384045275280_item	2359401	et	3	main
selle	doc_384045275280_item	2359403	et	4	main
käsitleb	doc_384045275280_item	2358825	et	3	main
5	doc_384045275280_item	2358835	et	2	main
käesoleva	doc_384045275280_item	2358839	et	3	main
kus	doc_384045275280_item	2358844	et	3	main
on	doc_384045275280_item	2358854	et	4	main
siinkohal	doc_384045275280_item	2358856	et	3	main
et	doc_384045275280_item	2358859	et	3	main
sõnastamisel	doc_384045275280_item	2358862	et	4	main
magistrant	doc_384045275280_item	2358865	et	4	main
primaarseid	doc_384045275280_item	2358871	et	3	main
eesmärke	doc_384045275280_item	2358879	et	4	main
sõnavara	doc_384045275280_item	2358886	et	4	main
ja	doc_384045275280_item	2358889	et	3	main
tavakooli	doc_384045275280_item	2358890	et	4	main
õpilased	doc_384045275280_item	2358891	et	3	main
14	doc_384045275280_item	2358892	et	2	main
oma	doc_384045275280_item	2358893	et	4	main
töös	doc_384045275280_item	2358894	et	3	main
pööran	doc_384045275280_item	2358895	et	3	main
tähelepanu	doc_384045275280_item	2358896	et	4	main
ka	doc_384045275280_item	2358897	et	3	main
sellele	doc_384045275280_item	2358898	et	4	main
kui	doc_384045275280_item	2358899	et	3	main
hästi	doc_384045275280_item	2358900	et	3	main
oskavad	doc_384045275280_item	2358901	et	4	main
leida	doc_384045275280_item	2358902	et	3	main
õpilased	doc_384045275280_item	2358903	et	3	main
sünonüüme	doc_384045275280_item	2358904	et	3	main
kas	doc_384045275280_item	2358906	et	3	main
ja	doc_384045275280_item	2358905	et	3	main
teavad	doc_384045275280_item	2358907	et	3	main
nad	doc_384045275280_item	2358908	et	3	main
neid	doc_384045275280_item	2358909	et	4	main
üldse	doc_384045275280_item	2358910	et	3	main
15	doc_384045275280_item	2358911	et	2	main
töös	doc_384045275280_item	2358912	et	3	main
kui	doc_384045275280_item	2358914	et	3	main
uurin	doc_384045275280_item	2358913	et	3	main
hästi	doc_384045275280_item	2358915	et	3	main
nad	doc_384045275280_item	2358916	et	3	main
oskavad	doc_384045275280_item	2358917	et	4	main
leida	doc_384045275280_item	2358918	et	3	main
sõnadele	doc_384045275280_item	2358919	et	3	main
antonüüme	doc_384045275280_item	2358920	et	3	main
antonüüme	doc_384045275280_item	2358922	et	3	main
sellele	doc_384045275280_item	2358930	et	4	main
kas	doc_384045275280_item	2358931	et	3	main
oma	doc_384045275280_item	2358938	et	4	main
kas	doc_384045275280_item	2358945	et	3	main
eesmärk	doc_384045275280_item	2358841	et	3	main
või	doc_384045275280_item	2358847	et	4	main
paremini	doc_384045275280_item	2358850	et	4	main
nii	doc_384045275280_item	2358855	et	3	main
tuleb	doc_384045275280_item	2358857	et	3	main
ei	doc_384045275280_item	2358863	et	4	main
ole	doc_384045275280_item	2358864	et	4	main
selgelt	doc_384045275280_item	2358866	et	4	main
oma	doc_384045275280_item	2358868	et	4	main
töö	doc_384045275280_item	2358869	et	4	main
lehekülgedel	doc_384045275280_item	2358880	et	4	main
ja	doc_384045275280_item	2358872	et	3	main
sekundaarseid	doc_384045275280_item	2358873	et	3	main
lugeja	doc_384045275280_item	2358875	et	4	main
kohtab	doc_384045275280_item	2358876	et	3	main
erinevaid	doc_384045275280_item	2358877	et	4	main
magistritöö	doc_384045275280_item	2358878	et	4	main
töös	doc_384045275280_item	2358883	et	3	main
millist	doc_384045275280_item	2358885	et	3	main
valdavad	doc_384045275280_item	2358887	et	4	main
keelekümbluskooli	doc_384045275280_item	2358888	et	4	main
16	doc_384045275280_item	2358925	et	2	main
õpilastele	doc_384045275280_item	2358934	et	4	main
fraseoloogilised	doc_384045275280_item	2358935	et	3	main
17	doc_384045275280_item	2358937	et	2	main
osas	doc_384045275280_item	2358941	et	4	main
liitsõnu	doc_384045275280_item	2358948	et	3	main
kas	doc_384045275280_item	2358951	et	3	main
töö	doc_384045275280_item	2358956	et	4	main
eesmärk	doc_384045275280_item	2358957	et	3	main
36	doc_384045275280_item	2358972	et	2	main
ülesande	doc_384045275280_item	2358986	et	4	main
sissejuhatusest	doc_384045275280_item	2359026	et	4	main
kolmest	doc_384045275280_item	2359030	et	4	main
seletab	doc_384045275280_item	2359034	et	3	main
sõnavara	doc_384045275280_item	2359036	et	4	main
mõiste	doc_384045275280_item	2359037	et	4	main
seonduva	doc_384045275280_item	2359041	et	4	main
magistrant	doc_384045275280_item	2359049	et	4	main
tuua	doc_384045275280_item	2359060	et	3	main
peatükk	doc_384045275280_item	2359062	et	3	main
ülevaate	doc_384045275280_item	2359064	et	4	main
neljandas	doc_384045275280_item	2359066	et	3	main
perekonnanimi	doc_384045275280_item	2359070	et	3	main
ja	doc_384045275280_item	2359074	et	3	main
õpetamisvõtteid	doc_384045275280_item	2359075	et	4	main
iseseisva	doc_384045275280_item	2359079	et	3	main
ega	doc_384045275280_item	2359085	et	3	main
ja	doc_384045275280_item	2359098	et	3	main
klassi	doc_384045275280_item	2359101	et	4	main
hulgas	doc_384045275280_item	2359103	et	4	main
järgi	doc_384045275280_item	2359104	et	4	main
tunnevad	doc_384045275280_item	2358924	et	3	main
oma	doc_384045275280_item	2358926	et	4	main
pööran	doc_384045275280_item	2358928	et	3	main
tähelepanu	doc_384045275280_item	2358929	et	4	main
liitsõnad	doc_384045275280_item	2358936	et	3	main
tähelepanu	doc_384045275280_item	2358943	et	4	main
teavad	doc_384045275280_item	2358947	et	3	main
oskavad	doc_384045275280_item	2358952	et	4	main
moodustada	doc_384045275280_item	2358954	et	3	main
praktilises	doc_384045275280_item	2358975	et	3	main
osas	doc_384045275280_item	2358976	et	4	main
ma	doc_384045275280_item	2358978	et	3	main
uurida	doc_384045275280_item	2358981	et	3	main
71	doc_384045275280_item	2358989	et	2	main
selle	doc_384045275280_item	2358992	et	4	main
ülesande	doc_384045275280_item	2358993	et	4	main
eesmärk	doc_384045275280_item	2358994	et	3	main
on	doc_384045275280_item	2358995	et	4	main
kui	doc_384045275280_item	2358996	et	3	main
aga	doc_384045275280_item	2358997	et	3	main
süveneda	doc_384045275280_item	2358998	et	3	main
viimase	doc_384045275280_item	2358999	et	3	main
kahe	doc_384045275280_item	2359000	et	3	main
osa	doc_384045275280_item	2359001	et	4	main
sisusse	doc_384045275280_item	2359002	et	3	main
ja	doc_384045275280_item	2359003	et	3	main
jälgida	doc_384045275280_item	2359004	et	3	main
valitud	doc_384045275280_item	2359005	et	4	main
esituslaadi	doc_384045275280_item	2359006	et	4	main
siis	doc_384045275280_item	2359007	et	3	main
süveneb	doc_384045275280_item	2359008	et	3	main
veendumus	doc_384045275280_item	2359009	et	4	main
et	doc_384045275280_item	2359010	et	3	main
töös	doc_384045275280_item	2359011	et	3	main
püstitatud	doc_384045275280_item	2359012	et	4	main
eesmärk	doc_384045275280_item	2359013	et	3	main
lk	doc_384045275280_item	2359014	et	4	main
5	doc_384045275280_item	2359015	et	2	main
ei	doc_384045275280_item	2359016	et	4	main
täidetud	doc_384045275280_item	2359018	et	4	main
ning	doc_384045275280_item	2359019	et	3	main
ole	doc_384045275280_item	2359017	et	4	main
sõnastus	doc_384045275280_item	2359020	et	4	main
lisast	doc_384045275280_item	2359031	et	4	main
esimene	doc_384045275280_item	2359032	et	3	main
lahti	doc_384045275280_item	2359035	et	4	main
muu	doc_384045275280_item	2359039	et	4	main
kaheleheküljeline	doc_384045275280_item	2359043	et	4	main
kirjeldab	doc_384045275280_item	2359045	et	3	main
nii	doc_384045275280_item	2359055	et	3	main
peatükina	doc_384045275280_item	2359058	et	3	main
peatükis	doc_384045275280_item	2359067	et	3	main
õpilased	doc_384045275280_item	2358946	et	3	main
ja	doc_384045275280_item	2358949	et	3	main
neid	doc_384045275280_item	2358953	et	4	main
28	doc_384045275280_item	2358955	et	2	main
on	doc_384045275280_item	2358958	et	4	main
uurida	doc_384045275280_item	2358959	et	3	main
sõnavara	doc_384045275280_item	2358968	et	4	main
lõik	doc_384045275280_item	2358974	et	3	main
uurin	doc_384045275280_item	2358977	et	3	main
töös	doc_384045275280_item	2358979	et	3	main
püüan	doc_384045275280_item	2358980	et	3	main
56	doc_384045275280_item	2358982	et	2	main
rida	doc_384045275280_item	2358984	et	4	main
selle	doc_384045275280_item	2358985	et	4	main
1	doc_384045275280_item	2358990	et	2	main
on	doc_384045275280_item	2359021	et	4	main
keeleliselt	doc_384045275280_item	2359022	et	4	main
viiest	doc_384045275280_item	2359027	et	4	main
ja	doc_384045275280_item	2359038	et	3	main
mälus	doc_384045275280_item	2359048	et	4	main
osa	doc_384045275280_item	2359057	et	4	main
välja	doc_384045275280_item	2359059	et	4	main
annab	doc_384045275280_item	2359063	et	3	main
keelekümblusest	doc_384045275280_item	2359065	et	4	main
viies	doc_384045275280_item	2359076	et	4	main
analüüsib	doc_384045275280_item	2359078	et	3	main
tulemusi	doc_384045275280_item	2359081	et	4	main
pealkiri	doc_384045275280_item	2359083	et	3	main
keelekümblus-	doc_384045275280_item	2359097	et	3	main
oleks	doc_384045275280_item	2359105	et	3	main
tavakoolis	doc_384045275280_item	2359117	et	4	main
jäävad	doc_384045275280_item	2359120	et	4	main
uuring	doc_384045275280_item	2359128	et	3	main
on	doc_384045275280_item	2359129	et	4	main
mõeldamatu	doc_384045275280_item	2359130	et	4	main
ilma	doc_384045275280_item	2359131	et	4	main
sõnavara	doc_384045275280_item	2359137	et	4	main
ankeedi	doc_384045275280_item	2359148	et	4	main
abil	doc_384045275280_item	2359149	et	4	main
püütud	doc_384045275280_item	2359151	et	4	main
määrata	doc_384045275280_item	2359152	et	4	main
kas	doc_384045275280_item	2359153	et	3	main
rääkima	doc_384045275280_item	2359183	et	3	main
keele	doc_384045275280_item	2359189	et	4	main
keelekümbluskoolis	doc_384045275280_item	2359193	et	4	main
mis	doc_384045275280_item	2359198	et	4	main
keel	doc_384045275280_item	2359200	et	4	main
mittekorrektne	doc_384045275280_item	2359023	et	3	main
magistritöö	doc_384045275280_item	2359024	et	4	main
koosneb	doc_384045275280_item	2359025	et	3	main
peatükist	doc_384045275280_item	2359028	et	3	main
kohta	doc_384045275280_item	2359047	et	4	main
oleks	doc_384045275280_item	2359050	et	3	main
pidanud	doc_384045275280_item	2359051	et	4	main
kaaluma	doc_384045275280_item	2359052	et	3	main
kas	doc_384045275280_item	2359053	et	3	main
tasub	doc_384045275280_item	2359054	et	3	main
lühikest	doc_384045275280_item	2359056	et	4	main
kolmas	doc_384045275280_item	2359061	et	3	main
e	doc_384045275280_item	2359069	et	4	main
meetodeid	doc_384045275280_item	2359073	et	3	main
uuringu	doc_384045275280_item	2359080	et	3	main
töö	doc_384045275280_item	2359082	et	4	main
struktuur	doc_384045275280_item	2359084	et	3	main
käsitlevate	doc_384045275280_item	2359086	et	4	main
teemade	doc_384045275280_item	2359087	et	4	main
arusaadav	doc_384045275280_item	2359090	et	4	main
sõnavara	doc_384045275280_item	2359095	et	4	main
tavakooli	doc_384045275280_item	2359099	et	4	main
pidanud	doc_384045275280_item	2359108	et	4	main
kui	doc_384045275280_item	2359118	et	3	main
sõnad	doc_384045275280_item	2359122	et	4	main
meelde	doc_384045275280_item	2359124	et	3	main
tundide	doc_384045275280_item	2359132	et	3	main
vaatluste	doc_384045275280_item	2359133	et	3	main
e	doc_384045275280_item	2359141	et	4	main
perekonnanimi	doc_384045275280_item	2359142	et	3	main
uurib	doc_384045275280_item	2359143	et	3	main
kohatu	doc_384045275280_item	2359178	et	4	main
autor	doc_384045275280_item	2359179	et	3	main
kirjutab	doc_384045275280_item	2359180	et	3	main
sellest	doc_384045275280_item	2359184	et	4	main
õpilased	doc_384045275280_item	2359187	et	3	main
teha	doc_384045275280_item	2359197	et	3	main
on	doc_384045275280_item	2359202	et	4	main
lk	doc_384045275280_item	2359204	et	4	main
sõnavara	doc_384045275280_item	2359214	et	4	main
õpetamise	doc_384045275280_item	2359216	et	4	main
mõistete	doc_384045275280_item	2359219	et	3	main
lahtiseletamise	doc_384045275280_item	2359220	et	3	main
e	doc_384045275280_item	2359226	et	4	main
teise	doc_384045275280_item	2359233	et	4	main
keele	doc_384045275280_item	2359234	et	4	main
teooriate	doc_384045275280_item	2359240	et	3	main
võgotski	doc_384045275280_item	2359259	et	4	main
tsooni	doc_384045275280_item	2359262	et	4	main
peatükk	doc_384045275280_item	2359268	et	3	main
ning	doc_384045275280_item	2359274	et	3	main
vajalikkus	doc_384045275280_item	2359276	et	4	main
on	doc_384045275280_item	2359280	et	4	main
perekonnanimi	doc_384045275280_item	2359285	et	3	main
ei	doc_384045275280_item	2359288	et	4	main
kognitiivset	doc_384045275280_item	2359289	et	4	main
laadi	doc_384045275280_item	2359292	et	4	main
peatükk	doc_384045275280_item	2359294	et	3	main
milleks	doc_384045275280_item	2359301	et	4	main
keelekümbluse	doc_384045275280_item	2359302	et	3	main
käsitluste	doc_384045275280_item	2359303	et	4	main
lk	doc_384045275280_item	2359305	et	4	main
mõtet	doc_384045275280_item	2359310	et	3	main
mida	doc_384045275280_item	2359315	et	4	main
teavad	doc_384045275280_item	2359317	et	3	main
nt	doc_384045275280_item	2359318	et	4	main
keelekümbluse	doc_384045275280_item	2359319	et	3	main
ajalugu	doc_384045275280_item	2359320	et	4	main
sõnavara	doc_384045275280_item	2359071	et	4	main
peatükk	doc_384045275280_item	2359077	et	3	main
loogiline	doc_384045275280_item	2359091	et	4	main
ega	doc_384045275280_item	2359092	et	3	main
kohane	doc_384045275280_item	2359093	et	4	main
pealkirja	doc_384045275280_item	2359094	et	4	main
perekonnanimi	doc_384045275280_item	2359107	et	3	main
mil	doc_384045275280_item	2359110	et	4	main
kiiresti	doc_384045275280_item	2359119	et	3	main
need	doc_384045275280_item	2359121	et	3	main
omandamine	doc_384045275280_item	2359138	et	4	main
väljendab	doc_384045275280_item	2359139	et	3	main
resultaati	doc_384045275280_item	2359146	et	4	main
koolitüübi	doc_384045275280_item	2359155	et	3	main
teatud	doc_384045275280_item	2359160	et	4	main
antud	doc_384045275280_item	2359176	et	4	main
kontekstis	doc_384045275280_item	2359177	et	3	main
et	doc_384045275280_item	2359181	et	3	main
omandavad	doc_384045275280_item	2359186	et	4	main
ja	doc_384045275280_item	2359192	et	3	main
on	doc_384045275280_item	2359194	et	4	main
vaja	doc_384045275280_item	2359195	et	4	main
on	doc_384045275280_item	2359199	et	4	main
sõnavara	doc_384045275280_item	2359203	et	4	main
et	doc_384045275280_item	2359208	et	3	main
otseseid	doc_384045275280_item	2359210	et	3	main
ega	doc_384045275280_item	2359211	et	3	main
seoseid	doc_384045275280_item	2359213	et	3	main
ja	doc_384045275280_item	2359217	et	3	main
sünonüümi-antonüümi-fraseologismi	doc_384045275280_item	2359218	et	4	main
peatüki	doc_384045275280_item	2359223	et	3	main
asemel	doc_384045275280_item	2359224	et	4	main
oleks	doc_384045275280_item	2359225	et	3	main
omandamise	doc_384045275280_item	2359239	et	4	main
käsitlused	doc_384045275280_item	2359250	et	4	main
mudel	doc_384045275280_item	2359253	et	3	main
arengu	doc_384045275280_item	2359261	et	3	main
keeleomandamisele	doc_384045275280_item	2359264	et	3	main
sõna	doc_384045275280_item	2359269	et	4	main
liigselt	doc_384045275280_item	2359272	et	4	main
selle	doc_384045275280_item	2359275	et	4	main
teema	doc_384045275280_item	2359277	et	4	main
avamise	doc_384045275280_item	2359278	et	4	main
seisukohalt	doc_384045275280_item	2359279	et	4	main
ülevaade	doc_384045275280_item	2359295	et	3	main
lugeja	doc_384045275280_item	2359298	et	4	main
mõtlema	doc_384045275280_item	2359300	et	3	main
ümber	doc_384045275280_item	2359311	et	3	main
kirjutada	doc_384045275280_item	2359312	et	3	main
töö	doc_384045275280_item	2359327	et	4	main
obligatoorne	doc_384045275280_item	2359331	et	3	main
arvates	doc_384045275280_item	2359333	et	4	main
rahulikult	doc_384045275280_item	2359336	et	4	main
piirduda	doc_384045275280_item	2359337	et	3	main
neljandas	doc_384045275280_item	2359338	et	3	main
ja	doc_384045275280_item	2359339	et	3	main
tooduga	doc_384045275280_item	2359342	et	4	main
põhjalikult	doc_384045275280_item	2359346	et	4	main
kirjeldama	doc_384045275280_item	2359351	et	3	main
neile	doc_384045275280_item	2359375	et	4	main
hinnangu	doc_384045275280_item	2359376	et	3	main
seejärel	doc_384045275280_item	2359377	et	3	main
üle	doc_384045275280_item	2359380	et	3	main
osa	doc_384045275280_item	2359388	et	4	main
küsitav	doc_384045275280_item	2359390	et	4	main
on	doc_384045275280_item	2359391	et	4	main
näha	doc_384045275280_item	2359392	et	3	main
et	doc_384045275280_item	2359393	et	3	main
e	doc_384045275280_item	2359398	et	4	main
järeldusi	doc_384045275280_item	2359402	et	4	main
et	doc_384045275280_item	2359405	et	3	main
paar	doc_384045275280_item	2359406	et	3	main
sõna	doc_384045275280_item	2359412	et	4	main
aga	doc_384045275280_item	2359415	et	3	main
pööra	doc_384045275280_item	2359417	et	4	main
õpilast	doc_384045275280_item	2359426	et	4	main
ja	doc_384045275280_item	2359430	et	3	main
see	doc_384045275280_item	2359434	et	3	main
ja	doc_384045275280_item	2359441	et	3	main
kokkuvõttes	doc_384045275280_item	2359451	et	3	main
valitud	doc_384045275280_item	2359457	et	4	main
lindistusteta	doc_384045275280_item	2359135	et	4	main
aga	doc_384045275280_item	2359144	et	3	main
on	doc_384045275280_item	2359150	et	4	main
õppijad	doc_384045275280_item	2359156	et	4	main
juba	doc_384045275280_item	2359158	et	3	main
liiki	doc_384045275280_item	2359161	et	4	main
sõnad	doc_384045275280_item	2359162	et	4	main
seega	doc_384045275280_item	2359163	et	4	main
ei	doc_384045275280_item	2359164	et	4	main
vasta	doc_384045275280_item	2359165	et	4	main
magistritöö	doc_384045275280_item	2359166	et	4	main
pealkiri	doc_384045275280_item	2359167	et	3	main
magistritöö	doc_384045275280_item	2359168	et	4	main
sisule	doc_384045275280_item	2359169	et	3	main
magistritöö	doc_384045275280_item	2359170	et	4	main
esimene	doc_384045275280_item	2359171	et	3	main
peatükk	doc_384045275280_item	2359172	et	3	main
ülevaade	doc_384045275280_item	2359173	et	3	main
sõnavarast	doc_384045275280_item	2359174	et	4	main
on	doc_384045275280_item	2359175	et	4	main
hakata	doc_384045275280_item	2359182	et	4	main
eesti	doc_384045275280_item	2359188	et	4	main
sõnavara	doc_384045275280_item	2359190	et	4	main
kindlaks	doc_384045275280_item	2359196	et	3	main
retsensent	doc_384045275280_item	2359206	et	3	main
pole	doc_384045275280_item	2359209	et	3	main
kaudseid	doc_384045275280_item	2359212	et	3	main
omandamise	doc_384045275280_item	2359215	et	4	main
perekonnanimi	doc_384045275280_item	2359227	et	3	main
kirjutama	doc_384045275280_item	2359229	et	3	main
kuidas	doc_384045275280_item	2359230	et	3	main
omandavad	doc_384045275280_item	2359231	et	4	main
sõnavara	doc_384045275280_item	2359232	et	4	main
nt	doc_384045275280_item	2359242	et	4	main
muud	doc_384045275280_item	2359248	et	4	main
poststrukturalistlikud	doc_384045275280_item	2359249	et	3	main
monitooringu	doc_384045275280_item	2359252	et	4	main
lähima	doc_384045275280_item	2359260	et	4	main
magistritöö	doc_384045275280_item	2359266	et	4	main
on	doc_384045275280_item	2359271	et	4	main
samuti	doc_384045275280_item	2359281	et	3	main
sest	doc_384045275280_item	2359283	et	4	main
uurimus	doc_384045275280_item	2359286	et	3	main
pole	doc_384045275280_item	2359287	et	3	main
ega	doc_384045275280_item	2359290	et	3	main
psühholingvistilist	doc_384045275280_item	2359291	et	4	main
keelekümblusest	doc_384045275280_item	2359296	et	4	main
avamist	doc_384045275280_item	2359304	et	4	main
2228	doc_384045275280_item	2359306	et	2	main
vaja	doc_384045275280_item	2359307	et	4	main
asju	doc_384045275280_item	2359314	et	3	main
kõik	doc_384045275280_item	2359316	et	4	main
jms	doc_384045275280_item	2359322	et	4	main
seisukohalt	doc_384045275280_item	2359328	et	4	main
ning	doc_384045275280_item	2359350	et	3	main
ülevaade	doc_384045275280_item	2359356	et	3	main
on	doc_384045275280_item	2359360	et	4	main
2	doc_384045275280_item	2359366	et	2	main
sõnavara	doc_384045275280_item	2359367	et	4	main
omandamisprotsesside	doc_384045275280_item	2359368	et	3	main
omavaheline	doc_384045275280_item	2359369	et	4	main
analüüsi	doc_384045275280_item	2359384	et	4	main
analüütiline	doc_384045275280_item	2359387	et	3	main
suhtub	doc_384045275280_item	2359395	et	3	main
tavakooli	doc_384045275280_item	2359396	et	4	main
eelarvamusega	doc_384045275280_item	2359397	et	3	main
samas	doc_384045275280_item	2359414	et	4	main
tavakoolis	doc_384045275280_item	2359422	et	4	main
vene	doc_384045275280_item	2359424	et	4	main
emakeelega	doc_384045275280_item	2359425	et	3	main
teavad	doc_384045275280_item	2359427	et	3	main
keelekümbluskooli	doc_384045275280_item	2359431	et	4	main
õpilastele	doc_384045275280_item	2359432	et	4	main
sõna	doc_384045275280_item	2359435	et	4	main
tundmatu	doc_384045275280_item	2359436	et	4	main
lk	doc_384045275280_item	2359446	et	4	main
analüüs	doc_384045275280_item	2359450	et	3	main
ole	doc_384045275280_item	2359453	et	4	main
ei	doc_384045275280_item	2359467	et	4	main
sõnavara	doc_384045275280_item	2359470	et	4	main
seisukohalt	doc_384045275280_item	2359471	et	4	main
näitajad	doc_384045275280_item	2359472	et	4	main
allikat	doc_384045275280_item	2359482	et	3	main
kahtluse	doc_384045275280_item	2359485	et	4	main
allikate	doc_384045275280_item	2359488	et	3	main
valimi	doc_384045275280_item	2359489	et	4	main
clevedon	doc_384045275280_item	2359528	et	4	main
ltd	doc_384045275280_item	2359534	et	4	main
2005	doc_384045275280_item	2359537	et	2	main
james	doc_384045275280_item	2359544	et	4	main
vocabulary	doc_384045275280_item	2359551	et	4	main
acquisition	doc_384045275280_item	2359552	et	4	main
university	doc_384045275280_item	2359558	et	4	main
cook	doc_384045275280_item	2359562	et	4	main
2001	doc_384045275280_item	2359564	et	2	main
second	doc_384045275280_item	2359565	et	4	main
language	doc_384045275280_item	2359566	et	4	main
learning	doc_384045275280_item	2359567	et	4	main
and	doc_384045275280_item	2359568	et	3	main
introductions	doc_384045275280_item	2359582	et	4	main
selle	doc_384045275280_item	2359222	et	4	main
pidanud	doc_384045275280_item	2359228	et	4	main
keele	doc_384045275280_item	2359238	et	4	main
valguses	doc_384045275280_item	2359241	et	4	main
vivian	doc_384045275280_item	2359243	et	4	main
cooki	doc_384045275280_item	2359244	et	4	main
multikompetentsuse	doc_384045275280_item	2359245	et	4	main
mudel	doc_384045275280_item	2359246	et	3	main
ja	doc_384045275280_item	2359247	et	3	main
krasheni	doc_384045275280_item	2359251	et	4	main
interaktsionistlik	doc_384045275280_item	2359254	et	4	main
uurimissuund	doc_384045275280_item	2359255	et	3	main
mis	doc_384045275280_item	2359256	et	4	main
rakendab	doc_384045275280_item	2359257	et	3	main
lev	doc_384045275280_item	2359258	et	4	main
jms	doc_384045275280_item	2359265	et	4	main
teine	doc_384045275280_item	2359267	et	3	main
napisõnaline	doc_384045275280_item	2359273	et	4	main
kolmas	doc_384045275280_item	2359293	et	3	main
oli	doc_384045275280_item	2359308	et	3	main
enam	doc_384045275280_item	2359324	et	4	main
antud	doc_384045275280_item	2359326	et	4	main
see	doc_384045275280_item	2359330	et	3	main
autor	doc_384045275280_item	2359335	et	3	main
viiendas	doc_384045275280_item	2359340	et	3	main
oleks	doc_384045275280_item	2359344	et	3	main
ja	doc_384045275280_item	2359347	et	3	main
järjekindlalt	doc_384045275280_item	2359348	et	4	main
uurima	doc_384045275280_item	2359349	et	3	main
silmas	doc_384045275280_item	2359353	et	4	main
järgmist	doc_384045275280_item	2359354	et	3	main
kuid	doc_384045275280_item	2359363	et	4	main
vajab	doc_384045275280_item	2359364	et	3	main
täpsustamist	doc_384045275280_item	2359365	et	4	main
mille	doc_384045275280_item	2359371	et	3	main
oleks	doc_384045275280_item	2359378	et	3	main
loomulik	doc_384045275280_item	2359379	et	3	main
minna	doc_384045275280_item	2359381	et	3	main
sõnavara	doc_384045275280_item	2359383	et	4	main
töö	doc_384045275280_item	2359386	et	4	main
tundub	doc_384045275280_item	2359389	et	3	main
keelekümblejat	doc_384045275280_item	2359407	et	3	main
on	doc_384045275280_item	2359408	et	4	main
kasutanud	doc_384045275280_item	2359409	et	4	main
oma	doc_384045275280_item	2359410	et	4	main
vastustes	doc_384045275280_item	2359411	et	4	main
tabel	doc_384045275280_item	2359442	et	3	main
lk	doc_384045275280_item	2359443	et	4	main
näitleja	doc_384045275280_item	2359449	et	4	main
ei	doc_384045275280_item	2359456	et	4	main
nimisõna	doc_384045275280_item	2359464	et	4	main
mittetundmine	doc_384045275280_item	2359466	et	3	main
ole	doc_384045275280_item	2359468	et	4	main
venekeelne	doc_384045275280_item	2359476	et	3	main
ja	doc_384045275280_item	2359479	et	3	main
retsensent	doc_384045275280_item	2359483	et	3	main
bilingual	doc_384045275280_item	2359522	et	4	main
fourth	doc_384045275280_item	2359526	et	4	main
sydney	doc_384045275280_item	2359531	et	4	main
matters	doc_384045275280_item	2359533	et	4	main
baker	doc_384045275280_item	2359535	et	4	main
kakskeelne	doc_384045275280_item	2359538	et	3	main
tartu	doc_384045275280_item	2359540	et	4	main
thomas	doc_384045275280_item	2359546	et	4	main
second	doc_384045275280_item	2359549	et	4	main
v	doc_384045275280_item	2359563	et	4	main
london	doc_384045275280_item	2359573	et	4	main
language	doc_384045275280_item	2359579	et	4	main
acquisition	doc_384045275280_item	2359580	et	4	main
oxford	doc_384045275280_item	2359617	et	4	main
press	doc_384045275280_item	2359619	et	3	main
lubliner	doc_384045275280_item	2359620	et	4	main
retsensendi	doc_384045275280_item	2359332	et	3	main
võinuks	doc_384045275280_item	2359334	et	4	main
mida	doc_384045275280_item	2359343	et	4	main
pidanud	doc_384045275280_item	2359345	et	4	main
pean	doc_384045275280_item	2359352	et	4	main
1	doc_384045275280_item	2359355	et	2	main
õpetamise	doc_384045275280_item	2359358	et	4	main
alusel	doc_384045275280_item	2359372	et	4	main
anda	doc_384045275280_item	2359374	et	3	main
juurde	doc_384045275280_item	2359385	et	4	main
magistrant	doc_384045275280_item	2359394	et	4	main
teeb	doc_384045275280_item	2359400	et	3	main
ei	doc_384045275280_item	2359416	et	4	main
tähelepanu	doc_384045275280_item	2359418	et	4	main
sellele	doc_384045275280_item	2359419	et	4	main
et	doc_384045275280_item	2359420	et	3	main
põhjal	doc_384045275280_item	2359404	et	4	main
konn	doc_384045275280_item	2359413	et	3	main
õppinud	doc_384045275280_item	2359423	et	4	main
sõna	doc_384045275280_item	2359428	et	4	main
oli	doc_384045275280_item	2359433	et	3	main
vt	doc_384045275280_item	2359437	et	4	main
analüüs	doc_384045275280_item	2359438	et	3	main
lk	doc_384045275280_item	2359439	et	4	main
91	doc_384045275280_item	2359440	et	2	main
97	doc_384045275280_item	2359444	et	2	main
samuti	doc_384045275280_item	2359445	et	3	main
82	doc_384045275280_item	2359447	et	2	main
ülesannete	doc_384045275280_item	2359458	et	3	main
ega	doc_384045275280_item	2359459	et	3	main
sõnavaraga	doc_384045275280_item	2359460	et	3	main
nt	doc_384045275280_item	2359461	et	4	main
töökoda	doc_384045275280_item	2359465	et	4	main
õpilase	doc_384045275280_item	2359469	et	3	main
üks	doc_384045275280_item	2359475	et	3	main
kolm	doc_384045275280_item	2359421	et	3	main
metssiga	doc_384045275280_item	2359429	et	4	main
sõna	doc_384045275280_item	2359448	et	4	main
ei	doc_384045275280_item	2359452	et	4	main
retsensent	doc_384045275280_item	2359454	et	3	main
rahul	doc_384045275280_item	2359455	et	4	main
bibliograafias	doc_384045275280_item	2359473	et	3	main
üks	doc_384045275280_item	2359477	et	3	main
ingliskeelne	doc_384045275280_item	2359478	et	3	main
eestikeelset	doc_384045275280_item	2359481	et	3	main
seab	doc_384045275280_item	2359484	et	3	main
alla	doc_384045275280_item	2359486	et	3	main
otstarbekuse	doc_384045275280_item	2359490	et	4	main
magistrikraadile	doc_384045275280_item	2359491	et	3	main
pretendeerivas	doc_384045275280_item	2359492	et	4	main
töös	doc_384045275280_item	2359493	et	3	main
olema	doc_384045275280_item	2359495	et	4	main
soliidne	doc_384045275280_item	2359496	et	3	main
teoreetiline	doc_384045275280_item	2359497	et	3	main
peab	doc_384045275280_item	2359494	et	4	main
taust	doc_384045275280_item	2359498	et	4	main
mis	doc_384045275280_item	2359499	et	4	main
antud	doc_384045275280_item	2359500	et	4	main
töö	doc_384045275280_item	2359501	et	4	main
puhul	doc_384045275280_item	2359502	et	4	main
puudub	doc_384045275280_item	2359503	et	3	main
töö	doc_384045275280_item	2359504	et	4	main
teemaga	doc_384045275280_item	2359505	et	3	main
on	doc_384045275280_item	2359506	et	4	main
otseselt	doc_384045275280_item	2359507	et	4	main
seotud	doc_384045275280_item	2359508	et	4	main
järgmised	doc_384045275280_item	2359509	et	3	main
väljaanded	doc_384045275280_item	2359510	et	3	main
mida	doc_384045275280_item	2359511	et	4	main
e	doc_384045275280_item	2359512	et	4	main
perekonnanimi	doc_384045275280_item	2359513	et	3	main
pole	doc_384045275280_item	2359514	et	3	main
kahjuks	doc_384045275280_item	2359515	et	4	main
kasutanud	doc_384045275280_item	2359516	et	4	main
baker	doc_384045275280_item	2359517	et	4	main
c	doc_384045275280_item	2359518	et	4	main
2006	doc_384045275280_item	2359519	et	2	main
foundations	doc_384045275280_item	2359520	et	4	main
education	doc_384045275280_item	2359523	et	4	main
and	doc_384045275280_item	2359524	et	3	main
coady	doc_384045275280_item	2359543	et	4	main
and	doc_384045275280_item	2359545	et	3	main
1997	doc_384045275280_item	2359548	et	2	main
language	doc_384045275280_item	2359550	et	4	main
a	doc_384045275280_item	2359553	et	4	main
määrsõna	doc_384045275280_item	2359462	et	4	main
kähku	doc_384045275280_item	2359463	et	3	main
on	doc_384045275280_item	2359474	et	4	main
28	doc_384045275280_item	2359480	et	2	main
kasutatud	doc_384045275280_item	2359487	et	4	main
of	doc_384045275280_item	2359521	et	4	main
bilingualism	doc_384045275280_item	2359525	et	4	main
toronto	doc_384045275280_item	2359530	et	4	main
colin	doc_384045275280_item	2359536	et	4	main
laps	doc_384045275280_item	2359539	et	4	main
pedagogy	doc_384045275280_item	2359556	et	4	main
cambridge	doc_384045275280_item	2359557	et	4	main
teaching	doc_384045275280_item	2359570	et	4	main
arnold	doc_384045275280_item	2359574	et	4	main
ellis	doc_384045275280_item	2359575	et	4	main
r	doc_384045275280_item	2359576	et	4	main
2000	doc_384045275280_item	2359577	et	2	main
learned	doc_384045275280_item	2359615	et	4	main
smetana	doc_384045275280_item	2359624	et	4	main
words	doc_384045275280_item	2359628	et	4	main
baltimore	doc_384045275280_item	2359634	et	4	main
h	doc_384045275280_item	2359637	et	4	main
mary	doc_384045275280_item	2359643	et	4	main
eds	doc_384045275280_item	2359646	et	4	main
nature	doc_384045275280_item	2359649	et	4	main
krall	doc_384045275280_item	2359659	et	4	main
renate	doc_384045275280_item	2359660	et	4	main
keelehärm	doc_384045275280_item	2359669	et	3	main
eesti	doc_384045275280_item	2359670	et	4	main
probleemseid	doc_384045275280_item	2359672	et	3	main
piirkondi	doc_384045275280_item	2359673	et	4	main
keel	doc_384045275280_item	2359683	et	4	main
keel	doc_384045275280_item	2359686	et	4	main
muukeelne	doc_384045275280_item	2359688	et	4	main
laps	doc_384045275280_item	2359689	et	4	main
mitteverbaalsed	doc_384045275280_item	2359699	et	3	main
keeleline	doc_384045275280_item	2359702	et	4	main
õppes	doc_384045275280_item	2359706	et	3	main
tpü	doc_384045275280_item	2359708	et	4	main
vene	doc_384045275280_item	2359715	et	4	main
õpilaste	doc_384045275280_item	2359716	et	4	main
keele	doc_384045275280_item	2359718	et	4	main
omandamisele	doc_384045275280_item	2359719	et	4	main
ja	doc_384045275280_item	2359720	et	3	main
edition	doc_384045275280_item	2359527	et	4	main
buffalo	doc_384045275280_item	2359529	et	4	main
multilingual	doc_384045275280_item	2359532	et	3	main
el	doc_384045275280_item	2359541	et	4	main
paradiso	doc_384045275280_item	2359542	et	4	main
huckin	doc_384045275280_item	2359547	et	4	main
for	doc_384045275280_item	2359555	et	4	main
cambridge	doc_384045275280_item	2359559	et	4	main
university	doc_384045275280_item	2359560	et	4	main
press	doc_384045275280_item	2359561	et	3	main
language	doc_384045275280_item	2359569	et	4	main
edition	doc_384045275280_item	2359572	et	4	main
oxford	doc_384045275280_item	2359581	et	4	main
language	doc_384045275280_item	2359584	et	4	main
study	doc_384045275280_item	2359585	et	4	main
oxford	doc_384045275280_item	2359586	et	4	main
oxford	doc_384045275280_item	2359587	et	4	main
university	doc_384045275280_item	2359588	et	4	main
hausenberg	doc_384045275280_item	2359590	et	4	main
anu-reet	doc_384045275280_item	2359591	et	4	main
press	doc_384045275280_item	2359589	et	3	main
tiina	doc_384045275280_item	2359592	et	4	main
kikerpill	doc_384045275280_item	2359593	et	3	main
rõigas	doc_384045275280_item	2359595	et	3	main
maia	doc_384045275280_item	2359594	et	4	main
ülle	doc_384045275280_item	2359596	et	4	main
türk	doc_384045275280_item	2359597	et	4	main
2003	doc_384045275280_item	2359598	et	2	main
keeleoskuse	doc_384045275280_item	2359599	et	3	main
mõõtmine	doc_384045275280_item	2359600	et	4	main
käsiraamat	doc_384045275280_item	2359601	et	3	main
tallinn	doc_384045275280_item	2359602	et	4	main
tea	doc_384045275280_item	2359603	et	4	main
kirjastus	doc_384045275280_item	2359604	et	4	main
lightbown	doc_384045275280_item	2359605	et	4	main
patsy	doc_384045275280_item	2359606	et	4	main
m	doc_384045275280_item	2359607	et	4	main
and	doc_384045275280_item	2359608	et	3	main
spada	doc_384045275280_item	2359609	et	4	main
nina	doc_384045275280_item	2359610	et	4	main
2006	doc_384045275280_item	2359611	et	2	main
how	doc_384045275280_item	2359612	et	4	main
languages	doc_384045275280_item	2359613	et	4	main
are	doc_384045275280_item	2359614	et	3	main
rationale	doc_384045275280_item	2359554	et	4	main
third	doc_384045275280_item	2359571	et	4	main
second	doc_384045275280_item	2359578	et	4	main
to	doc_384045275280_item	2359583	et	4	main
shira	doc_384045275280_item	2359621	et	4	main
linda	doc_384045275280_item	2359623	et	4	main
2005	doc_384045275280_item	2359625	et	2	main
into	doc_384045275280_item	2359627	et	4	main
that	doc_384045275280_item	2359631	et	4	main
md	doc_384045275280_item	2359635	et	4	main
brookes	doc_384045275280_item	2359638	et	4	main
margaret	doc_384045275280_item	2359640	et	4	main
curtis	doc_384045275280_item	2359645	et	4	main
of	doc_384045275280_item	2359650	et	4	main
sõrmus	doc_384045275280_item	2359665	et	3	main
ülle	doc_384045275280_item	2359678	et	4	main
koolis	doc_384045275280_item	2359691	et	4	main
teooria	doc_384045275280_item	2359692	et	4	main
ja	doc_384045275280_item	2359693	et	3	main
praktika	doc_384045275280_item	2359694	et	4	main
tallinn	doc_384045275280_item	2359695	et	4	main
mõju	doc_384045275280_item	2359714	et	4	main
eesti	doc_384045275280_item	2359717	et	4	main
koodivahetus	doc_384045275280_item	2359732	et	4	main
conference	doc_384045275280_item	2359743	et	4	main
krista	doc_384045275280_item	2359751	et	4	main
tallinna	doc_384045275280_item	2359755	et	4	main
estonian	doc_384045275280_item	2359768	et	4	main
philology	doc_384045275280_item	2359769	et	4	main
of	doc_384045275280_item	2359770	et	4	main
tallinn	doc_384045275280_item	2359771	et	4	main
tallinn	doc_384045275280_item	2359776	et	4	main
piirduda	doc_384045275280_item	2359799	et	3	main
eestikeelse	doc_384045275280_item	2359804	et	3	main
magistritöös	doc_384045275280_item	2359806	et	3	main
on	doc_384045275280_item	2359807	et	4	main
kaudviiteid	doc_384045275280_item	2359809	et	4	main
allikatele	doc_384045275280_item	2359811	et	4	main
kirjanduse	doc_384045275280_item	2359814	et	3	main
loetelus	doc_384045275280_item	2359815	et	3	main
7	doc_384045275280_item	2359821	et	2	main
saussure	doc_384045275280_item	2359824	et	4	main
olema	doc_384045275280_item	2359838	et	4	main
kaudviitelised	doc_384045275280_item	2359843	et	4	main
lk	doc_384045275280_item	2359845	et	4	main
2000	doc_384045275280_item	2359850	et	2	main
mart	doc_384045275280_item	2359856	et	3	main
2002	doc_384045275280_item	2359858	et	2	main
puudutab	doc_384045275280_item	2359862	et	3	main
sõnavaral	doc_384045275280_item	2359881	et	3	main
olemaolevad	doc_384045275280_item	2359882	et	4	main
olemasolevad	doc_384045275280_item	2359884	et	3	main
tekstist	doc_384045275280_item	2359896	et	3	main
oluline	doc_384045275280_item	2359900	et	4	main
uute	doc_384045275280_item	2359902	et	3	main
mõtteskeemiga	doc_384045275280_item	2359908	et	3	main
kasutab	doc_384045275280_item	2359910	et	3	main
palju	doc_384045275280_item	2359912	et	4	main
see	doc_384045275280_item	2359916	et	3	main
ise	doc_384045275280_item	2359921	et	4	main
isikuga	doc_384045275280_item	2359929	et	3	main
jääb	doc_384045275280_item	2359931	et	3	main
paremini	doc_384045275280_item	2359933	et	4	main
meelde	doc_384045275280_item	2359934	et	3	main
lk	doc_384045275280_item	2359935	et	4	main
4	doc_384045275280_item	2359936	et	2	main
kasutades	doc_384045275280_item	2359951	et	3	main
tegi	doc_384045275280_item	2359955	et	4	main
teen	doc_384045275280_item	2359956	et	3	main
tehtud	doc_384045275280_item	2359958	et	4	main
sõnast	doc_384045275280_item	2359965	et	4	main
võib	doc_384045275280_item	2359971	et	3	main
seejuures	doc_384045275280_item	2359972	et	3	main
olla	doc_384045275280_item	2359973	et	3	main
muutunud	doc_384045275280_item	2359974	et	4	main
võrreldes	doc_384045275280_item	2359975	et	3	main
tähendusega	doc_384045275280_item	2359979	et	4	main
üldsõnavara	doc_384045275280_item	2359982	et	4	main
markeerimata	doc_384045275280_item	2359985	et	4	main
keelendid	doc_384045275280_item	2359990	et	3	main
11	doc_384045275280_item	2359996	et	2	main
oxford	doc_384045275280_item	2359616	et	4	main
university	doc_384045275280_item	2359618	et	4	main
comprehension	doc_384045275280_item	2359633	et	4	main
e	doc_384045275280_item	2359644	et	4	main
ingrid	doc_384045275280_item	2359658	et	4	main
pajusalu	doc_384045275280_item	2359661	et	4	main
saarso	doc_384045275280_item	2359663	et	4	main
vare	doc_384045275280_item	2359667	et	4	main
keele	doc_384045275280_item	2359671	et	4	main
tallinn	doc_384045275280_item	2359674	et	4	main
rannut	doc_384045275280_item	2359677	et	4	main
varane	doc_384045275280_item	2359680	et	4	main
eesti	doc_384045275280_item	2359682	et	4	main
teine	doc_384045275280_item	2359685	et	3	main
eesti	doc_384045275280_item	2359690	et	4	main
rannut	doc_384045275280_item	2359696	et	4	main
strateegiad	doc_384045275280_item	2359700	et	3	main
kirjastus	doc_384045275280_item	2359709	et	4	main
rannut	doc_384045275280_item	2359710	et	4	main
ülle	doc_384045275280_item	2359711	et	4	main
2005	doc_384045275280_item	2359712	et	2	main
integratsioonile	doc_384045275280_item	2359721	et	3	main
finest	doc_384045275280_item	2359734	et	4	main
the	doc_384045275280_item	2359738	et	4	main
and	doc_384045275280_item	2359741	et	3	main
tallinn	doc_384045275280_item	2359746	et	4	main
may	doc_384045275280_item	2359747	et	4	main
6-7	doc_384045275280_item	2359748	et	2	main
2004	doc_384045275280_item	2359749	et	2	main
sepper	doc_384045275280_item	2359754	et	4	main
231246	doc_384045275280_item	2359779	et	2	main
võiks	doc_384045275280_item	2359783	et	4	main
jätkata	doc_384045275280_item	2359784	et	4	main
ülaltooduga	doc_384045275280_item	2359789	et	3	main
soovib	doc_384045275280_item	2359791	et	3	main
antud	doc_384045275280_item	2359794	et	4	main
valitud	doc_384045275280_item	2359803	et	4	main
kirjandusega	doc_384045275280_item	2359805	et	3	main
lk	doc_384045275280_item	2359820	et	4	main
getting	doc_384045275280_item	2359626	et	4	main
vocabulary	doc_384045275280_item	2359629	et	4	main
instruction	doc_384045275280_item	2359630	et	4	main
mckeown	doc_384045275280_item	2359639	et	4	main
g	doc_384045275280_item	2359641	et	4	main
and	doc_384045275280_item	2359622	et	3	main
strengthens	doc_384045275280_item	2359632	et	4	main
paul	doc_384045275280_item	2359636	et	4	main
1987	doc_384045275280_item	2359647	et	2	main
acquisition	doc_384045275280_item	2359652	et	4	main
nj	doc_384045275280_item	2359654	et	4	main
kirjastus	doc_384045275280_item	2359676	et	4	main
kui	doc_384045275280_item	2359684	et	3	main
ülle	doc_384045275280_item	2359697	et	4	main
2003	doc_384045275280_item	2359698	et	2	main
teise	doc_384045275280_item	2359704	et	4	main
keele	doc_384045275280_item	2359705	et	4	main
tallinn	doc_384045275280_item	2359723	et	4	main
muukeelsete	doc_384045275280_item	2359729	et	4	main
algkoolilaste	doc_384045275280_item	2359730	et	4	main
kohtla-järvel	doc_384045275280_item	2359733	et	4	main
linguistics	doc_384045275280_item	2359735	et	4	main
of	doc_384045275280_item	2359737	et	4	main
linguistics	doc_384045275280_item	2359745	et	4	main
kerge	doc_384045275280_item	2359752	et	4	main
8	doc_384045275280_item	2359773	et	2	main
university	doc_384045275280_item	2359775	et	4	main
kirjanduse	doc_384045275280_item	2359781	et	3	main
teema	doc_384045275280_item	2359795	et	4	main
võõrkeelsetele	doc_384045275280_item	2359810	et	4	main
mida	doc_384045275280_item	2359812	et	4	main
kahjuks	doc_384045275280_item	2359816	et	4	main
leidu	doc_384045275280_item	2359818	et	4	main
nt	doc_384045275280_item	2359819	et	4	main
kõik	doc_384045275280_item	2359836	et	4	main
allikad	doc_384045275280_item	2359837	et	3	main
nimistus	doc_384045275280_item	2359841	et	3	main
esineb	doc_384045275280_item	2359854	et	3	main
rannuti	doc_384045275280_item	2359857	et	4	main
märkuste	doc_384045275280_item	2359860	et	4	main
pealt	doc_384045275280_item	2359878	et	4	main
34	doc_384045275280_item	2359886	et	2	main
on	doc_384045275280_item	2359899	et	4	main
võõrkeele	doc_384045275280_item	2359903	et	4	main
võimalikult	doc_384045275280_item	2359911	et	4	main
aktiivsust	doc_384045275280_item	2359914	et	4	main
mille	doc_384045275280_item	2359918	et	3	main
on	doc_384045275280_item	2359920	et	4	main
seotud	doc_384045275280_item	2359930	et	4	main
kõige	doc_384045275280_item	2359932	et	4	main
pidev	doc_384045275280_item	2359940	et	3	main
protsess	doc_384045275280_item	2359941	et	3	main
sest	doc_384045275280_item	2359942	et	4	main
iga	doc_384045275280_item	2359943	et	4	main
päev	doc_384045275280_item	2359944	et	3	main
x	doc_384045275280_item	2359963	et	4	main
täpsema	doc_384045275280_item	2359978	et	4	main
lk	doc_384045275280_item	2359995	et	4	main
tea	doc_384045275280_item	2360007	et	4	main
pole	doc_384045275280_item	2360014	et	3	main
võõras	doc_384045275280_item	2360019	et	4	main
and	doc_384045275280_item	2359642	et	3	main
the	doc_384045275280_item	2359648	et	4	main
vocabulary	doc_384045275280_item	2359651	et	4	main
hillsdale	doc_384045275280_item	2359653	et	4	main
lea	doc_384045275280_item	2359655	et	4	main
metslang	doc_384045275280_item	2359656	et	3	main
helle	doc_384045275280_item	2359657	et	3	main
kristi	doc_384045275280_item	2359662	et	4	main
elle	doc_384045275280_item	2359664	et	3	main
silvi	doc_384045275280_item	2359666	et	4	main
2003	doc_384045275280_item	2359668	et	2	main
tpü	doc_384045275280_item	2359675	et	4	main
2001	doc_384045275280_item	2359679	et	2	main
keelekümblus	doc_384045275280_item	2359681	et	3	main
ja	doc_384045275280_item	2359687	et	3	main
ja	doc_384045275280_item	2359701	et	3	main
rikastamine	doc_384045275280_item	2359703	et	4	main
tallinn	doc_384045275280_item	2359707	et	4	main
keelekeskkonna	doc_384045275280_item	2359713	et	3	main
tlü	doc_384045275280_item	2359724	et	4	main
zabrodskaja	doc_384045275280_item	2359726	et	4	main
2006	doc_384045275280_item	2359728	et	2	main
proceedings	doc_384045275280_item	2359736	et	4	main
finnish	doc_384045275280_item	2359740	et	4	main
eds	doc_384045275280_item	2359750	et	4	main
ülikooli	doc_384045275280_item	2359756	et	4	main
eesti	doc_384045275280_item	2359757	et	4	main
university	doc_384045275280_item	2359772	et	4	main
tallinn	doc_384045275280_item	2359774	et	4	main
press	doc_384045275280_item	2359778	et	3	main
loetelu	doc_384045275280_item	2359782	et	4	main
kuid	doc_384045275280_item	2359785	et	4	main
piirduda	doc_384045275280_item	2359788	et	3	main
et	doc_384045275280_item	2359793	et	3	main
on	doc_384045275280_item	2359797	et	4	main
mõeldamatu	doc_384045275280_item	2359798	et	4	main
vaid	doc_384045275280_item	2359808	et	3	main
ferdinand	doc_384045275280_item	2359822	et	4	main
soovib	doc_384045275280_item	2359829	et	3	main
magistrikraadile	doc_384045275280_item	2359832	et	3	main
34	doc_384045275280_item	2359846	et	2	main
artikkel	doc_384045275280_item	2359859	et	3	main
lõviosa	doc_384045275280_item	2359861	et	4	main
sõnadel	doc_384045275280_item	2359879	et	3	main
pro	doc_384045275280_item	2359883	et	4	main
hakkavad	doc_384045275280_item	2359889	et	4	main
sõnastuses	doc_384045275280_item	2359893	et	4	main
mis	doc_384045275280_item	2359894	et	4	main
arusaamist	doc_384045275280_item	2359897	et	4	main
et	doc_384045275280_item	2359901	et	3	main
sõnade	doc_384045275280_item	2359904	et	3	main
arvestab	doc_384045275280_item	2359906	et	3	main
õpilane	doc_384045275280_item	2359907	et	3	main
ning	doc_384045275280_item	2359909	et	3	main
temapoolset	doc_384045275280_item	2359913	et	3	main
õpilane	doc_384045275280_item	2359919	et	3	main
eestis	doc_384045275280_item	2359722	et	3	main
kirjastus	doc_384045275280_item	2359725	et	4	main
anastassia	doc_384045275280_item	2359727	et	4	main
vene-eestieesti-vene	doc_384045275280_item	2359731	et	4	main
annual	doc_384045275280_item	2359739	et	4	main
estonian	doc_384045275280_item	2359742	et	4	main
of	doc_384045275280_item	2359744	et	4	main
maria-maren	doc_384045275280_item	2359753	et	4	main
filoloogia	doc_384045275280_item	2359758	et	4	main
osakonna	doc_384045275280_item	2359759	et	4	main
toimetised	doc_384045275280_item	2359760	et	3	main
8	doc_384045275280_item	2359761	et	2	main
publications	doc_384045275280_item	2359762	et	4	main
of	doc_384045275280_item	2359763	et	4	main
the	doc_384045275280_item	2359764	et	4	main
department	doc_384045275280_item	2359765	et	4	main
of	doc_384045275280_item	2359766	et	4	main
the	doc_384045275280_item	2359767	et	4	main
university	doc_384045275280_item	2359777	et	4	main
teemakohase	doc_384045275280_item	2359780	et	4	main
esialgu	doc_384045275280_item	2359786	et	3	main
võiks	doc_384045275280_item	2359787	et	4	main
retsensent	doc_384045275280_item	2359790	et	3	main
rõhutada	doc_384045275280_item	2359792	et	3	main
puhul	doc_384045275280_item	2359796	et	4	main
ainult	doc_384045275280_item	2359800	et	4	main
e	doc_384045275280_item	2359801	et	4	main
perekonnanimi	doc_384045275280_item	2359802	et	3	main
kasutatud	doc_384045275280_item	2359813	et	4	main
ei	doc_384045275280_item	2359817	et	4	main
de	doc_384045275280_item	2359823	et	4	main
12	doc_384045275280_item	2359826	et	2	main
retsensent	doc_384045275280_item	2359828	et	3	main
et	doc_384045275280_item	2359831	et	3	main
pretendeerivas	doc_384045275280_item	2359833	et	4	main
kirjanduse	doc_384045275280_item	2359840	et	3	main
tekstis	doc_384045275280_item	2359844	et	3	main
viidatakse	doc_384045275280_item	2359847	et	4	main
väljaandele	doc_384045275280_item	2359848	et	3	main
rannut	doc_384045275280_item	2359849	et	4	main
kasutatud	doc_384045275280_item	2359851	et	4	main
kirjanduse	doc_384045275280_item	2359852	et	3	main
loetelus	doc_384045275280_item	2359853	et	3	main
haakavad	doc_384045275280_item	2359887	et	3	main
pro	doc_384045275280_item	2359888	et	4	main
jne	doc_384045275280_item	2359890	et	4	main
eksitakse	doc_384045275280_item	2359891	et	4	main
lausete	doc_384045275280_item	2359892	et	4	main
selletõttu	doc_384045275280_item	2359898	et	4	main
õpetamisel	doc_384045275280_item	2359905	et	4	main
sest	doc_384045275280_item	2359915	et	4	main
materjal	doc_384045275280_item	2359917	et	3	main
oma	doc_384045275280_item	2359922	et	4	main
tingimustele	doc_384045275280_item	2359923	et	3	main
enese	doc_384045275280_item	2359928	et	4	main
edastatakse	doc_384045275280_item	2359948	et	3	main
sõnu	doc_384045275280_item	2359950	et	4	main
näiteks	doc_384045275280_item	2359954	et	4	main
tegema	doc_384045275280_item	2359966	et	3	main
7	doc_384045275280_item	2359968	et	2	main
11	doc_384045275280_item	2359981	et	2	main
kui	doc_384045275280_item	2359984	et	3	main
antud	doc_384045275280_item	2359992	et	4	main
ilma	doc_384045275280_item	2359993	et	4	main
lk	doc_384045275280_item	2359999	et	4	main
20	doc_384045275280_item	2360000	et	2	main
3	doc_384045275280_item	2360001	et	2	main
rida	doc_384045275280_item	2360002	et	4	main
tautoloogiat	doc_384045275280_item	2360004	et	3	main
ja	doc_384045275280_item	2360011	et	3	main
siis	doc_384045275280_item	2360013	et	3	main
võõras	doc_384045275280_item	2360016	et	4	main
keeles	doc_384045275280_item	2360017	et	4	main
kõnelda	doc_384045275280_item	2360021	et	4	main
sõnadeta	doc_384045275280_item	2360023	et	3	main
sama	doc_384045275280_item	2360025	et	4	main
võimatu	doc_384045275280_item	2360026	et	4	main
kui	doc_384045275280_item	2360027	et	3	main
pillita	doc_384045275280_item	2360032	et	4	main
rohkesti	doc_384045275280_item	2360040	et	3	main
16	doc_384045275280_item	2360065	et	2	main
18	doc_384045275280_item	2360071	et	2	main
7	doc_384045275280_item	2360077	et	2	main
rida	doc_384045275280_item	2360081	et	4	main
jne	doc_384045275280_item	2360091	et	4	main
on	doc_384045275280_item	2360097	et	4	main
täiesti	doc_384045275280_item	2360098	et	3	main
keele	doc_384045275280_item	2360104	et	4	main
leidub	doc_384045275280_item	2360108	et	3	main
liitnimisõnade	doc_384045275280_item	2360117	et	3	main
ja	doc_384045275280_item	2360118	et	3	main
omadussõnade	doc_384045275280_item	2360119	et	3	main
lk	doc_384045275280_item	2359825	et	4	main
zikejev	doc_384045275280_item	2359827	et	4	main
rõhutada	doc_384045275280_item	2359830	et	3	main
töös	doc_384045275280_item	2359834	et	3	main
peavad	doc_384045275280_item	2359835	et	4	main
kasutatud	doc_384045275280_item	2359839	et	4	main
ka	doc_384045275280_item	2359842	et	3	main
ainult	doc_384045275280_item	2359855	et	4	main
magistritöö	doc_384045275280_item	2359863	et	4	main
keelelist	doc_384045275280_item	2359864	et	4	main
külge	doc_384045275280_item	2359865	et	4	main
leidub	doc_384045275280_item	2359866	et	3	main
rohkesti	doc_384045275280_item	2359867	et	3	main
vigu	doc_384045275280_item	2359868	et	3	main
näpuvigu	doc_384045275280_item	2359869	et	3	main
ja	doc_384045275280_item	2359870	et	3	main
apse	doc_384045275280_item	2359871	et	3	main
lk	doc_384045275280_item	2359872	et	4	main
4	doc_384045275280_item	2359873	et	2	main
keel	doc_384045275280_item	2359875	et	4	main
tugineb	doc_384045275280_item	2359876	et	3	main
kõige	doc_384045275280_item	2359877	et	4	main
iga	doc_384045275280_item	2359874	et	4	main
ja	doc_384045275280_item	2359880	et	3	main
lk	doc_384045275280_item	2359885	et	4	main
segab	doc_384045275280_item	2359895	et	3	main
kõik	doc_384045275280_item	2359926	et	4	main
sõnavara	doc_384045275280_item	2359937	et	4	main
informatsioon	doc_384045275280_item	2359945	et	3	main
lk	doc_384045275280_item	2359952	et	4	main
sõnavormi	doc_384045275280_item	2359961	et	4	main
y	doc_384045275280_item	2359964	et	4	main
lk	doc_384045275280_item	2359967	et	4	main
oskussõna	doc_384045275280_item	2359969	et	4	main
tähendus	doc_384045275280_item	2359970	et	4	main
lk	doc_384045275280_item	2359980	et	4	main
kõige	doc_384045275280_item	2359986	et	4	main
üldisema	doc_384045275280_item	2359987	et	4	main
kasutusega	doc_384045275280_item	2359988	et	4	main
sõnu	doc_384045275280_item	2360008	et	4	main
tähendust	doc_384045275280_item	2360010	et	4	main
ilma	doc_384045275280_item	2360022	et	4	main
näiteks	doc_384045275280_item	2360028	et	4	main
ilma	doc_384045275280_item	2360031	et	4	main
teaduslik	doc_384045275280_item	2360038	et	3	main
10	doc_384045275280_item	2360053	et	2	main
vt	doc_384045275280_item	2360063	et	4	main
lk	doc_384045275280_item	2360064	et	4	main
2	doc_384045275280_item	2360069	et	2	main
ja	doc_384045275280_item	2360076	et	3	main
23	doc_384045275280_item	2360079	et	2	main
4	doc_384045275280_item	2360083	et	2	main
lõik	doc_384045275280_item	2360084	et	3	main
lõik	doc_384045275280_item	2360087	et	3	main
lõik	doc_384045275280_item	2360090	et	3	main
teeb	doc_384045275280_item	2360094	et	3	main
vigu	doc_384045275280_item	2360095	et	3	main
mis	doc_384045275280_item	2360096	et	4	main
eesti	doc_384045275280_item	2360100	et	4	main
kui	doc_384045275280_item	2360102	et	3	main
moodustamine	doc_384045275280_item	2360120	et	4	main
omadussõnade	doc_384045275280_item	2360124	et	3	main
lk	doc_384045275280_item	2360127	et	4	main
magistrant	doc_384045275280_item	2360131	et	4	main
ei	doc_384045275280_item	2360132	et	4	main
saavuta	doc_384045275280_item	2360142	et	4	main
mõeldud	doc_384045275280_item	2360175	et	4	main
ärgitamiseks	doc_384045275280_item	2360177	et	4	main
sissejuhatuses	doc_384045275280_item	2360179	et	4	main
4	doc_384045275280_item	2360181	et	2	main
pikka	doc_384045275280_item	2360188	et	4	main
võõrkeeleõpetuse	doc_384045275280_item	2360190	et	3	main
kõrvale	doc_384045275280_item	2360192	et	4	main
õpetamisele	doc_384045275280_item	2360200	et	4	main
uuringutele	doc_384045275280_item	2360202	et	3	main
vastavalt	doc_384045275280_item	2359924	et	4	main
loonud	doc_384045275280_item	2359925	et	4	main
õpilase	doc_384045275280_item	2359927	et	3	main
omandamine	doc_384045275280_item	2359938	et	4	main
on	doc_384045275280_item	2359939	et	4	main
uueneb	doc_384045275280_item	2359946	et	3	main
seda	doc_384045275280_item	2359947	et	3	main
uusi	doc_384045275280_item	2359949	et	3	main
5	doc_384045275280_item	2359953	et	2	main
tehakse	doc_384045275280_item	2359957	et	3	main
on	doc_384045275280_item	2359959	et	4	main
sõnavormis	doc_384045275280_item	2359960	et	3	main
d	doc_384045275280_item	2359962	et	4	main
tema	doc_384045275280_item	2359976	et	4	main
oskuskeele	doc_384045275280_item	2359977	et	4	main
sõnad	doc_384045275280_item	2359983	et	4	main
neutraalsed	doc_384045275280_item	2359989	et	3	main
on	doc_384045275280_item	2359991	et	4	main
markeerimata	doc_384045275280_item	2359994	et	4	main
on	doc_384045275280_item	2360003	et	4	main
suhelda	doc_384045275280_item	2360018	et	4	main
magistritöö	doc_384045275280_item	2360035	et	4	main
pole	doc_384045275280_item	2360037	et	3	main
küsimusi	doc_384045275280_item	2360043	et	4	main
ja	doc_384045275280_item	2360044	et	3	main
kõnekeelseid	doc_384045275280_item	2360045	et	3	main
sõnavara	doc_384045275280_item	2360051	et	4	main
on	doc_384045275280_item	2360055	et	4	main
eripära	doc_384045275280_item	2360057	et	4	main
üldsõnavaraga	doc_384045275280_item	2360058	et	3	main
võrreldes	doc_384045275280_item	2360059	et	3	main
11	doc_384045275280_item	2360061	et	2	main
jne	doc_384045275280_item	2360062	et	4	main
lõik	doc_384045275280_item	2360067	et	3	main
lõik	doc_384045275280_item	2360073	et	3	main
3	doc_384045275280_item	2360086	et	2	main
16	doc_384045275280_item	2360107	et	2	main
võrdluskeelendeid	doc_384045275280_item	2360110	et	4	main
hulgaliselt	doc_384045275280_item	2360113	et	4	main
lk	doc_384045275280_item	2360115	et	4	main
liitnimisõnade	doc_384045275280_item	2360122	et	3	main
lõik	doc_384045275280_item	2360130	et	3	main
oska	doc_384045275280_item	2360133	et	4	main
kasutada	doc_384045275280_item	2360134	et	3	main
tegumoodi	doc_384045275280_item	2360136	et	4	main
30	doc_384045275280_item	2360138	et	2	main
lõik	doc_384045275280_item	2360144	et	3	main
õpeta	doc_384045275280_item	2360146	et	4	main
ei	doc_384045275280_item	2360160	et	4	main
harjuta	doc_384045275280_item	2360161	et	4	main
82	doc_384045275280_item	2360162	et	2	main
kirjutasid	doc_384045275280_item	2360165	et	4	main
on	doc_384045275280_item	2360174	et	4	main
1	doc_384045275280_item	2360178	et	2	main
olnud	doc_384045275280_item	2360187	et	4	main
pöörati	doc_384045275280_item	2360195	et	3	main
millistele	doc_384045275280_item	2360201	et	3	main
toetudes	doc_384045275280_item	2360203	et	3	main
teinud	doc_384045275280_item	2360205	et	4	main
teie	doc_384045275280_item	2360208	et	4	main
ja	doc_384045275280_item	2360223	et	3	main
edukamaid	doc_384045275280_item	2360224	et	4	main
on	doc_384045275280_item	2360231	et	4	main
teie	doc_384045275280_item	2360234	et	4	main
siis	doc_384045275280_item	2360236	et	3	main
millest	doc_384045275280_item	2360245	et	3	main
järeldused	doc_384045275280_item	2360247	et	4	main
6	doc_384045275280_item	2360250	et	2	main
kohta	doc_384045275280_item	2360258	et	4	main
püstitatud	doc_384045275280_item	2360262	et	4	main
küsimustele	doc_384045275280_item	2360263	et	4	main
leitud	doc_384045275280_item	2360265	et	4	main
4	doc_384045275280_item	2360281	et	2	main
mis	doc_384045275280_item	2360282	et	4	main
on	doc_384045275280_item	2360283	et	4	main
on	doc_384045275280_item	2360288	et	4	main
et	doc_384045275280_item	2360303	et	3	main
esemeid	doc_384045275280_item	2360310	et	3	main
vt	doc_384045275280_item	2359997	et	4	main
ka	doc_384045275280_item	2359998	et	3	main
kui	doc_384045275280_item	2360005	et	3	main
ei	doc_384045275280_item	2360006	et	4	main
nende	doc_384045275280_item	2360009	et	4	main
hääldust	doc_384045275280_item	2360012	et	4	main
võimalik	doc_384045275280_item	2360015	et	3	main
keeles	doc_384045275280_item	2360020	et	4	main
on	doc_384045275280_item	2360024	et	4	main
pillimäng	doc_384045275280_item	2360030	et	3	main
4	doc_384045275280_item	2360034	et	2	main
sest	doc_384045275280_item	2360039	et	4	main
kasutatakse	doc_384045275280_item	2360041	et	3	main
retoorilisi	doc_384045275280_item	2360042	et	3	main
mis	doc_384045275280_item	2360054	et	4	main
oskussõnavara	doc_384045275280_item	2360056	et	4	main
lk	doc_384045275280_item	2360060	et	4	main
3	doc_384045275280_item	2360066	et	2	main
3	doc_384045275280_item	2360072	et	2	main
6	doc_384045275280_item	2360075	et	2	main
lõik	doc_384045275280_item	2360078	et	3	main
25	doc_384045275280_item	2360082	et	2	main
33	doc_384045275280_item	2360088	et	2	main
e	doc_384045275280_item	2360092	et	4	main
perekonnasnimi	doc_384045275280_item	2360093	et	4	main
keele	doc_384045275280_item	2360101	et	4	main
lk	doc_384045275280_item	2360106	et	4	main
hulgaliselt	doc_384045275280_item	2360109	et	4	main
pro	doc_384045275280_item	2360111	et	4	main
leidub	doc_384045275280_item	2360112	et	3	main
moodustamine	doc_384045275280_item	2360125	et	4	main
19	doc_384045275280_item	2360128	et	2	main
rida	doc_384045275280_item	2360140	et	4	main
5	doc_384045275280_item	2360148	et	2	main
ei	doc_384045275280_item	2360150	et	4	main
32	doc_384045275280_item	2360152	et	2	main
viimane	doc_384045275280_item	2360153	et	3	main
lõik	doc_384045275280_item	2360154	et	3	main
ei	doc_384045275280_item	2360155	et	4	main
kasuta	doc_384045275280_item	2360156	et	4	main
34	doc_384045275280_item	2360157	et	2	main
1	doc_384045275280_item	2360158	et	2	main
lõik	doc_384045275280_item	2360159	et	3	main
3	doc_384045275280_item	2360163	et	2	main
kirjutati	doc_384045275280_item	2360171	et	3	main
lk	doc_384045275280_item	2360180	et	4	main
et	doc_384045275280_item	2360183	et	3	main
õpetamine	doc_384045275280_item	2360185	et	4	main
tõrjunud	doc_384045275280_item	2360193	et	4	main
rohkem	doc_384045275280_item	2360194	et	4	main
kommunikatiivsete	doc_384045275280_item	2360198	et	3	main
tuntumaid	doc_384045275280_item	2360222	et	4	main
5	doc_384045275280_item	2360227	et	2	main
3	doc_384045275280_item	2360248	et	2	main
kas	doc_384045275280_item	2360260	et	3	main
küsimustele	doc_384045275280_item	2360268	et	4	main
leida	doc_384045275280_item	2360271	et	3	main
magistritöö	doc_384045275280_item	2360278	et	4	main
osas	doc_384045275280_item	2360280	et	4	main
metoodika	doc_384045275280_item	2360286	et	4	main
lk	doc_384045275280_item	2360297	et	4	main
21	doc_384045275280_item	2360298	et	2	main
väidate	doc_384045275280_item	2360299	et	3	main
jäävad	doc_384045275280_item	2360306	et	4	main
inimest	doc_384045275280_item	2360308	et	3	main
olendeid	doc_384045275280_item	2360311	et	3	main
tähistavad	doc_384045275280_item	2360317	et	4	main
sõnad	doc_384045275280_item	2360318	et	4	main
kõik	doc_384045275280_item	2360319	et	4	main
see	doc_384045275280_item	2360320	et	3	main
talle	doc_384045275280_item	2360326	et	4	main
lähedane	doc_384045275280_item	2360327	et	3	main
kelle	doc_384045275280_item	2360328	et	4	main
tähelepanek	doc_384045275280_item	2360329	et	3	main
puuduvad	doc_384045275280_item	2360338	et	4	main
millest	doc_384045275280_item	2360340	et	3	main
tulenevad	doc_384045275280_item	2360344	et	4	main
teie	doc_384045275280_item	2360347	et	4	main
palju	doc_384045275280_item	2360353	et	4	main
meetodeid	doc_384045275280_item	2360355	et	3	main
vt	doc_384045275280_item	2360356	et	4	main
nimetada	doc_384045275280_item	2360362	et	3	main
mingi	doc_384045275280_item	2360029	et	4	main
lk	doc_384045275280_item	2360033	et	4	main
stiil	doc_384045275280_item	2360036	et	3	main
lihtlauseid	doc_384045275280_item	2360046	et	3	main
kui	doc_384045275280_item	2360047	et	3	main
suur	doc_384045275280_item	2360048	et	3	main
on	doc_384045275280_item	2360049	et	4	main
keele	doc_384045275280_item	2360050	et	4	main
lk	doc_384045275280_item	2360052	et	4	main
17	doc_384045275280_item	2360068	et	2	main
lõik	doc_384045275280_item	2360070	et	3	main
19	doc_384045275280_item	2360074	et	2	main
3	doc_384045275280_item	2360080	et	2	main
30	doc_384045275280_item	2360085	et	2	main
4	doc_384045275280_item	2360089	et	2	main
lubamatud	doc_384045275280_item	2360099	et	4	main
teise	doc_384045275280_item	2360103	et	4	main
tegevõpetajale	doc_384045275280_item	2360105	et	3	main
võrdluskeelendid	doc_384045275280_item	2360114	et	3	main
17	doc_384045275280_item	2360116	et	2	main
pro	doc_384045275280_item	2360121	et	4	main
vt	doc_384045275280_item	2360126	et	4	main
3	doc_384045275280_item	2360129	et	2	main
ei	doc_384045275280_item	2360141	et	4	main
ei	doc_384045275280_item	2360145	et	4	main
31	doc_384045275280_item	2360147	et	2	main
olema	doc_384045275280_item	2360169	et	4	main
verb	doc_384045275280_item	2360170	et	3	main
järgnev	doc_384045275280_item	2360172	et	4	main
väidate	doc_384045275280_item	2360182	et	3	main
sõnavara	doc_384045275280_item	2360184	et	4	main
grammatika	doc_384045275280_item	2360197	et	4	main
olete	doc_384045275280_item	2360204	et	3	main
selle	doc_384045275280_item	2360206	et	4	main
tähelepanek	doc_384045275280_item	2360229	et	3	main
pole	doc_384045275280_item	2360233	et	3	main
seda	doc_384045275280_item	2360238	et	3	main
seletatud	doc_384045275280_item	2360241	et	4	main
tulenevad	doc_384045275280_item	2360246	et	4	main
lk	doc_384045275280_item	2360249	et	4	main
kirjutate	doc_384045275280_item	2360251	et	3	main
räägin	doc_384045275280_item	2360259	et	3	main
kavatsete	doc_384045275280_item	2360269	et	3	main
vastused	doc_384045275280_item	2360270	et	3	main
ei	doc_384045275280_item	2360273	et	4	main
märganud	doc_384045275280_item	2360274	et	4	main
on	doc_384045275280_item	2360291	et	4	main
meetod	doc_384045275280_item	2360292	et	3	main
et	doc_384045275280_item	2360300	et	3	main
teada	doc_384045275280_item	2360302	et	3	main
ümbritsevaid	doc_384045275280_item	2360309	et	4	main
nähtusi	doc_384045275280_item	2360313	et	4	main
konkreetseid	doc_384045275280_item	2360315	et	3	main
on	doc_384045275280_item	2360322	et	4	main
jaoks	doc_384045275280_item	2360324	et	4	main
oluline	doc_384045275280_item	2360325	et	4	main
kui	doc_384045275280_item	2360332	et	3	main
miks	doc_384045275280_item	2360337	et	4	main
kelle	doc_384045275280_item	2360342	et	4	main
meelest	doc_384045275280_item	2360348	et	4	main
keeleõpetamise	doc_384045275280_item	2360351	et	3	main
28	doc_384045275280_item	2360358	et	2	main
anda	doc_384045275280_item	2360364	et	3	main
sõnavara	doc_384045275280_item	2360378	et	4	main
enda	doc_384045275280_item	2360384	et	4	main
omast	doc_384045275280_item	2360392	et	4	main
8	doc_384045275280_item	2360395	et	2	main
35	doc_384045275280_item	2360397	et	2	main
keelekümblusklassis	doc_384045275280_item	2360400	et	4	main
ole	doc_384045275280_item	2360402	et	4	main
sõnavara	doc_384045275280_item	2360403	et	4	main
niisuguseid	doc_384045275280_item	2360405	et	3	main
tõlkeülesanded	doc_384045275280_item	2360421	et	3	main
magistritöö	doc_384045275280_item	2360430	et	4	main
pole	doc_384045275280_item	2360439	et	3	main
soovida	doc_384045275280_item	2360450	et	4	main
olulisi	doc_384045275280_item	2360458	et	4	main
ingliskeelseid	doc_384045275280_item	2360459	et	3	main
pole	doc_384045275280_item	2360463	et	3	main
nõuetele	doc_384045275280_item	2360475	et	4	main
muutusmeelsus	doc_384045275281_item	2360523	et	4	main
ise	doc_384045275281_item	2360530	et	4	main
integratsiooni	doc_384045275281_item	2360532	et	4	main
kommunikatsiooniprogrammi	doc_384045275281_item	2360536	et	4	main
vene	doc_384045275281_item	2360538	et	4	main
õppekeelega	doc_384045275281_item	2360539	et	3	main
eestikeelsele	doc_384045275281_item	2360543	et	3	main
aineõppele	doc_384045275281_item	2360544	et	3	main
ja	doc_384045275280_item	2360123	et	3	main
umbisikulist	doc_384045275280_item	2360135	et	4	main
lk	doc_384045275280_item	2360137	et	4	main
3	doc_384045275280_item	2360139	et	2	main
4	doc_384045275280_item	2360143	et	2	main
lõik	doc_384045275280_item	2360149	et	3	main
kasuta	doc_384045275280_item	2360151	et	4	main
lõik	doc_384045275280_item	2360164	et	3	main
antud	doc_384045275280_item	2360166	et	4	main
kontekstis	doc_384045275280_item	2360167	et	3	main
peaks	doc_384045275280_item	2360168	et	4	main
osa	doc_384045275280_item	2360173	et	4	main
väitluse	doc_384045275280_item	2360176	et	3	main
on	doc_384045275280_item	2360186	et	4	main
aega	doc_384045275280_item	2360189	et	4	main
huviorbiidist	doc_384045275280_item	2360191	et	3	main
tähelepanu	doc_384045275280_item	2360196	et	4	main
oskuste	doc_384045275280_item	2360199	et	3	main
järelduse	doc_384045275280_item	2360207	et	4	main
töös	doc_384045275280_item	2360209	et	3	main
pole	doc_384045275280_item	2360210	et	3	main
ühtegi	doc_384045275280_item	2360211	et	4	main
asjakohast	doc_384045275280_item	2360212	et	4	main
viidet	doc_384045275280_item	2360213	et	3	main
2	doc_384045275280_item	2360214	et	2	main
teie	doc_384045275280_item	2360215	et	4	main
sõnul	doc_384045275280_item	2360216	et	3	main
on	doc_384045275280_item	2360217	et	4	main
kakskeelse	doc_384045275280_item	2360219	et	3	main
keelekümblus	doc_384045275280_item	2360218	et	3	main
õppe	doc_384045275280_item	2360220	et	4	main
üks	doc_384045275280_item	2360221	et	3	main
kui	doc_384045275280_item	2360232	et	3	main
oma	doc_384045275280_item	2360235	et	4	main
eelnevalt	doc_384045275280_item	2360240	et	4	main
ega	doc_384045275280_item	2360242	et	3	main
antud	doc_384045275280_item	2360244	et	4	main
kõikidele	doc_384045275280_item	2360261	et	4	main
retsensent	doc_384045275280_item	2360272	et	3	main
uurimisküsimuse	doc_384045275280_item	2360276	et	3	main
sissejuhatavas	doc_384045275280_item	2360279	et	3	main
mis	doc_384045275280_item	2360287	et	4	main
mis	doc_384045275280_item	2360290	et	4	main
on	doc_384045275280_item	2360301	et	4	main
paremini	doc_384045275280_item	2360305	et	4	main
ja	doc_384045275280_item	2360312	et	3	main
ning	doc_384045275280_item	2360314	et	3	main
tegevusi	doc_384045275280_item	2360316	et	4	main
see	doc_384045275280_item	2360330	et	3	main
on	doc_384045275280_item	2360331	et	4	main
teie	doc_384045275280_item	2360334	et	4	main
siis	doc_384045275280_item	2360336	et	3	main
järeldused	doc_384045275280_item	2360345	et	4	main
praegu	doc_384045275280_item	2360350	et	3	main
metoodikas	doc_384045275280_item	2360352	et	3	main
kas	doc_384045275280_item	2360359	et	3	main
oskate	doc_384045275280_item	2360360	et	3	main
neid	doc_384045275280_item	2360361	et	4	main
tavakooliõppija	doc_384045275280_item	2360391	et	4	main
laiem	doc_384045275280_item	2360393	et	4	main
et	doc_384045275280_item	2360399	et	3	main
on	doc_384045275280_item	2360407	et	4	main
tõlkimisega	doc_384045275280_item	2360409	et	4	main
ainult	doc_384045275280_item	2360412	et	4	main
rikasta	doc_384045275280_item	2360423	et	4	main
keeleõppijate	doc_384045275280_item	2360424	et	3	main
tooge	doc_384045275280_item	2360427	et	3	main
pealkiri	doc_384045275280_item	2360431	et	3	main
vasta	doc_384045275280_item	2360433	et	4	main
vorme	doc_384045275280_item	2360225	et	3	main
lk	doc_384045275280_item	2360226	et	4	main
kelle	doc_384045275280_item	2360228	et	4	main
see	doc_384045275280_item	2360230	et	3	main
miks	doc_384045275280_item	2360237	et	4	main
pole	doc_384045275280_item	2360239	et	3	main
viiteid	doc_384045275280_item	2360243	et	3	main
et	doc_384045275280_item	2360252	et	3	main
kokkuvõttes	doc_384045275280_item	2360253	et	3	main
teen	doc_384045275280_item	2360254	et	3	main
järeldusi	doc_384045275280_item	2360255	et	4	main
käsitletud	doc_384045275280_item	2360256	et	4	main
teema	doc_384045275280_item	2360257	et	4	main
on	doc_384045275280_item	2360264	et	4	main
vastused	doc_384045275280_item	2360266	et	3	main
missugustele	doc_384045275280_item	2360267	et	3	main
ühegi	doc_384045275280_item	2360275	et	4	main
formuleerimist	doc_384045275280_item	2360277	et	4	main
keele	doc_384045275280_item	2360284	et	4	main
õpetamise	doc_384045275280_item	2360285	et	4	main
võte	doc_384045275280_item	2360289	et	3	main
vt	doc_384045275280_item	2360293	et	4	main
lk	doc_384045275280_item	2360294	et	4	main
6	doc_384045275280_item	2360295	et	2	main
5	doc_384045275280_item	2360296	et	2	main
kõige	doc_384045275280_item	2360304	et	4	main
meelde	doc_384045275280_item	2360307	et	3	main
mis	doc_384045275280_item	2360321	et	4	main
inimese	doc_384045275280_item	2360323	et	4	main
ja	doc_384045275280_item	2360341	et	3	main
lk	doc_384045275280_item	2360357	et	4	main
7	doc_384045275280_item	2360365	et	2	main
29	doc_384045275280_item	2360367	et	2	main
vastandlikud	doc_384045275280_item	2360374	et	4	main
arvamused	doc_384045275280_item	2360375	et	3	main
kakskeelsuse	doc_384045275280_item	2360376	et	4	main
ja	doc_384045275280_item	2360377	et	3	main
mis	doc_384045275280_item	2360381	et	4	main
kas	doc_384045275280_item	2360386	et	3	main
keelekümbleja	doc_384045275280_item	2360388	et	4	main
sõnavara	doc_384045275280_item	2360389	et	4	main
nendite	doc_384045275280_item	2360398	et	3	main
harjutustes	doc_384045275280_item	2360404	et	4	main
seotud	doc_384045275280_item	2360408	et	4	main
siin	doc_384045275280_item	2360410	et	4	main
et	doc_384045275280_item	2360429	et	3	main
ei	doc_384045275280_item	2360432	et	4	main
magistritöö	doc_384045275280_item	2360436	et	4	main
eesmärgid	doc_384045275280_item	2360438	et	3	main
selgelt	doc_384045275280_item	2360440	et	4	main
sõnastatud	doc_384045275280_item	2360441	et	4	main
magistritöö	doc_384045275280_item	2360442	et	4	main
ka	doc_384045275280_item	2360443	et	3	main
ja	doc_384045275280_item	2360447	et	3	main
ole	doc_384045275280_item	2360456	et	4	main
kasutatud	doc_384045275280_item	2360457	et	4	main
siis	doc_384045275280_item	2360465	et	3	main
retsensent	doc_384045275280_item	2360467	et	3	main
eesnimi	doc_384045275281_item	2360478	et	3	main
magistritööle	doc_384045275281_item	2360480	et	3	main
magistritöö	doc_384045275281_item	2360483	et	4	main
käsitleb	doc_384045275281_item	2360484	et	3	main
suletus	doc_384045275281_item	2360522	et	4	main
otsekohesussilmakirjalikkus	doc_384045275281_item	2360525	et	4	main
käivitatud	doc_384045275281_item	2360535	et	4	main
teema	doc_384045275281_item	2360550	et	4	main
igati	doc_384045275281_item	2360552	et	3	main
e	doc_384045275281_item	2360554	et	4	main
ja	doc_384045275281_item	2360569	et	3	main
sujuvaks	doc_384045275281_item	2360572	et	4	main
uurimismeetodina	doc_384045275281_item	2360574	et	3	main
koolijuhtide	doc_384045275281_item	2360578	et	3	main
õpilaste	doc_384045275281_item	2360580	et	4	main
ja	doc_384045275281_item	2360581	et	3	main
poolt	doc_384045275281_item	2360587	et	4	main
peatükist	doc_384045275281_item	2360602	et	3	main
kokku	doc_384045275281_item	2360620	et	3	main
ja	doc_384045275281_item	2360632	et	3	main
pealkirjad	doc_384045275281_item	2360635	et	3	main
on	doc_384045275281_item	2360636	et	4	main
vene	doc_384045275281_item	2360640	et	4	main
õppekeelega	doc_384045275281_item	2360641	et	3	main
koolide	doc_384045275281_item	2360642	et	3	main
aineõppele	doc_384045275281_item	2360645	et	3	main
sellest	doc_384045275281_item	2360668	et	4	main
jaguneb	doc_384045275281_item	2360673	et	3	main
neljaks	doc_384045275281_item	2360675	et	4	main
läbi	doc_384045275281_item	2360678	et	4	main
kändude	doc_384045275281_item	2360681	et	3	main
töö	doc_384045275281_item	2360689	et	4	main
mitte	doc_384045275280_item	2360333	et	3	main
oma	doc_384045275280_item	2360335	et	4	main
viited	doc_384045275280_item	2360339	et	3	main
uuringutest	doc_384045275280_item	2360343	et	4	main
6	doc_384045275280_item	2360346	et	2	main
on	doc_384045275280_item	2360349	et	4	main
erinevaid	doc_384045275280_item	2360354	et	4	main
viiteid	doc_384045275280_item	2360363	et	3	main
vare	doc_384045275280_item	2360370	et	4	main
ja	doc_384045275280_item	2360371	et	3	main
kristi	doc_384045275280_item	2360372	et	4	main
saarso	doc_384045275280_item	2360373	et	4	main
kohta	doc_384045275280_item	2360380	et	4	main
arvamus	doc_384045275280_item	2360385	et	3	main
on	doc_384045275280_item	2360390	et	4	main
miks	doc_384045275280_item	2360394	et	4	main
lk	doc_384045275280_item	2360396	et	4	main
mis	doc_384045275280_item	2360406	et	4	main
kasutatakse	doc_384045275280_item	2360411	et	3	main
harjutused	doc_384045275280_item	2360414	et	4	main
mis	doc_384045275280_item	2360415	et	4	main
on	doc_384045275280_item	2360416	et	4	main
seotud	doc_384045275280_item	2360417	et	4	main
sõnavara	doc_384045275280_item	2360418	et	4	main
rikastamisega	doc_384045275280_item	2360419	et	4	main
kas	doc_384045275280_item	2360420	et	3	main
ei	doc_384045275280_item	2360422	et	4	main
miks	doc_384045275280_item	2360426	et	4	main
eesmärk	doc_384045275280_item	2360437	et	3	main
keel	doc_384045275280_item	2360446	et	4	main
stiil	doc_384045275280_item	2360448	et	3	main
osa	doc_384045275280_item	2360453	et	4	main
analüütiline	doc_384045275280_item	2360461	et	3	main
osa	doc_384045275280_item	2360462	et	4	main
et	doc_384045275280_item	2360468	et	3	main
töö	doc_384045275280_item	2360470	et	4	main
ei	doc_384045275280_item	2360471	et	4	main
retsenseeritav	doc_384045275281_item	2360482	et	4	main
aasta	doc_384045275281_item	2360490	et	4	main
1	doc_384045275281_item	2360491	et	2	main
lk	doc_384045275280_item	2360366	et	4	main
toote	doc_384045275280_item	2360368	et	4	main
silvi	doc_384045275280_item	2360369	et	4	main
omandamise	doc_384045275280_item	2360379	et	4	main
on	doc_384045275280_item	2360382	et	4	main
teie	doc_384045275280_item	2360383	et	4	main
iga	doc_384045275280_item	2360387	et	4	main
ei	doc_384045275280_item	2360401	et	4	main
need	doc_384045275280_item	2360413	et	3	main
sõnavara	doc_384045275280_item	2360425	et	4	main
näiteid	doc_384045275280_item	2360428	et	3	main
jätavad	doc_384045275280_item	2360449	et	3	main
töö	doc_384045275280_item	2360451	et	4	main
ei	doc_384045275280_item	2360455	et	4	main
representatiivne	doc_384045275280_item	2360464	et	3	main
leiab	doc_384045275280_item	2360466	et	3	main
antud	doc_384045275280_item	2360469	et	4	main
retsensioon	doc_384045275281_item	2360477	et	3	main
perekonnanimi	doc_384045275281_item	2360479	et	3	main
xxxxxxxxxxxxxxxxxxx	doc_384045275281_item	2360481	et	4	main
olulist	doc_384045275281_item	2360486	et	4	main
nimelt	doc_384045275281_item	2360488	et	4	main
2007	doc_384045275281_item	2360489	et	2	main
septembrist	doc_384045275281_item	2360492	et	3	main
kavandatud	doc_384045275281_item	2360493	et	4	main
eesti	doc_384045275281_item	2360494	et	4	main
vene	doc_384045275281_item	2360495	et	4	main
õppekeelega	doc_384045275281_item	2360496	et	3	main
koolide	doc_384045275281_item	2360497	et	3	main
osalisele	doc_384045275281_item	2360498	et	4	main
eestikeelsele	doc_384045275281_item	2360499	et	3	main
aineõppele	doc_384045275281_item	2360500	et	3	main
ülemineku	doc_384045275281_item	2360501	et	3	main
kommunikatsiooni	doc_384045275281_item	2360502	et	4	main
strateegiliste	doc_384045275281_item	2360503	et	4	main
põhimõtete	doc_384045275281_item	2360504	et	3	main
määratlemisele	doc_384045275281_item	2360505	et	4	main
see	doc_384045275281_item	2360506	et	3	main
on	doc_384045275281_item	2360507	et	4	main
üks	doc_384045275281_item	2360508	et	3	main
teemasid	doc_384045275281_item	2360509	et	3	main
kus	doc_384045275281_item	2360510	et	3	main
puhthariduslike	doc_384045275281_item	2360511	et	3	main
probleemide	doc_384045275281_item	2360512	et	3	main
taustal	doc_384045275281_item	2360513	et	3	main
mängib	doc_384045275281_item	2360514	et	3	main
teatavasti	doc_384045275281_item	2360515	et	3	main
eriti	doc_384045275281_item	2360516	et	3	main
rolli	doc_384045275281_item	2360518	et	4	main
ühiskonnaelu	doc_384045275281_item	2360519	et	4	main
selle	doc_384045275281_item	2360520	et	4	main
tähtsat	doc_384045275281_item	2360517	et	3	main
avatus	doc_384045275281_item	2360521	et	4	main
eesnimi	doc_384045275281_item	2360527	et	3	main
teavitustegevused	doc_384045275281_item	2360537	et	4	main
teavitamine	doc_384045275281_item	2360541	et	4	main
osalisele	doc_384045275281_item	2360542	et	4	main
ülemineku	doc_384045275281_item	2360545	et	3	main
toetamiseks	doc_384045275281_item	2360546	et	4	main
töö	doc_384045275280_item	2360434	et	4	main
sisule	doc_384045275280_item	2360435	et	3	main
ingliskeelse	doc_384045275280_item	2360444	et	3	main
resümee	doc_384045275280_item	2360445	et	4	main
teoreetiline	doc_384045275280_item	2360452	et	3	main
puudub	doc_384045275280_item	2360454	et	3	main
allikaid	doc_384045275280_item	2360460	et	3	main
vasta	doc_384045275280_item	2360472	et	4	main
magistritöödele	doc_384045275280_item	2360473	et	3	main
esitatavatele	doc_384045275280_item	2360474	et	4	main
retsensioon	doc_384045275281_item	2360476	et	3	main
äärmiselt	doc_384045275281_item	2360485	et	4	main
probleemi	doc_384045275281_item	2360487	et	4	main
vaikelulisus	doc_384045275281_item	2360524	et	4	main
et	doc_384045275281_item	2360526	et	3	main
perekonnanimi	doc_384045275281_item	2360528	et	3	main
sihtasutuse	doc_384045275281_item	2360533	et	4	main
poolt	doc_384045275281_item	2360534	et	4	main
koolidele	doc_384045275281_item	2360540	et	3	main
valik	doc_384045275281_item	2360551	et	3	main
kasutatud	doc_384045275281_item	2360576	et	4	main
süvaintervjuusid	doc_384045275281_item	2360577	et	3	main
aineõpetajate	doc_384045275281_item	2360579	et	3	main
emori	doc_384045275281_item	2360586	et	4	main
uuringuid	doc_384045275281_item	2360590	et	3	main
neljast	doc_384045275281_item	2360603	et	4	main
ning	doc_384045275281_item	2360605	et	3	main
mis	doc_384045275281_item	2360607	et	4	main
7	doc_384045275281_item	2360617	et	2	main
nummerdamata	doc_384045275281_item	2360630	et	4	main
magistritöö	doc_384045275281_item	2360634	et	4	main
eestikeelsele	doc_384045275281_item	2360644	et	3	main
kommunikatsioonistrateegia	doc_384045275281_item	2360647	et	4	main
ja	doc_384045275281_item	2360648	et	3	main
vene	doc_384045275281_item	2360649	et	4	main
puhul	doc_384045275281_item	2360661	et	4	main
täiesti	doc_384045275281_item	2360662	et	3	main
lubamatu	doc_384045275281_item	2360663	et	4	main
et	doc_384045275281_item	2360665	et	3	main
töö	doc_384045275281_item	2360666	et	4	main
koosnebki	doc_384045275281_item	2360667	et	3	main
peatükist	doc_384045275281_item	2360671	et	3	main
sissejuhatava	doc_384045275281_item	2360684	et	3	main
iseenesest	doc_384045275281_item	2360722	et	4	main
tekst	doc_384045275281_item	2360728	et	3	main
korraliku	doc_384045275281_item	2360733	et	3	main
või	doc_384045275281_item	2360735	et	4	main
pigem	doc_384045275281_item	2360736	et	3	main
käsilehe	doc_384045275281_item	2360740	et	4	main
mulje	doc_384045275281_item	2360741	et	4	main
loetleb	doc_384045275281_item	2360744	et	3	main
põgusalt	doc_384045275281_item	2360746	et	4	main
lugeja	doc_384045275281_item	2360750	et	4	main
väga	doc_384045275281_item	2360751	et	3	main
raskesse	doc_384045275281_item	2360752	et	3	main
järeldused	doc_384045275281_item	2360756	et	4	main
üldse	doc_384045275281_item	2360758	et	3	main
täiesti	doc_384045275281_item	2360760	et	3	main
kuhupoole	doc_384045275281_item	2360762	et	3	main
ning	doc_384045275281_item	2360765	et	3	main
eesmärgiga	doc_384045275281_item	2360767	et	3	main
rohkeid	doc_384045275281_item	2360769	et	3	main
kommunikatsioonimudeleid	doc_384045275281_item	2360770	et	3	main
kolmandas	doc_384045275281_item	2360774	et	3	main
kahjuks	doc_384045275281_item	2360778	et	4	main
aga	doc_384045275281_item	2360779	et	3	main
artiklitepealkirjad	doc_384045275281_item	2360784	et	4	main
täiesti	doc_384045275281_item	2360785	et	3	main
analüüsida	doc_384045275281_item	2360796	et	3	main
vene-	doc_384045275281_item	2360799	et	4	main
бизнес-план	doc_384045275281_item	2360829	et	2	main
головная	doc_384045275281_item	2360835	et	2	main
omadega	doc_384045275281_item	2360839	et	3	main
koolide	doc_384045275281_item	2360857	et	3	main
suurepärase	doc_384045275281_item	2360867	et	4	main
ettekujutuse	doc_384045275281_item	2360868	et	4	main
ülemineku	doc_384045275281_item	2360874	et	3	main
esitab	doc_384045275281_item	2360880	et	3	main
perekonnanimi	doc_384045275281_item	2360882	et	3	main
on	doc_384045275281_item	2360529	et	4	main
kaasatud	doc_384045275281_item	2360531	et	4	main
25092006	doc_384045275281_item	2360547	et	2	main
on	doc_384045275281_item	2360549	et	4	main
õigustatud	doc_384045275281_item	2360553	et	4	main
magistritöö	doc_384045275281_item	2360556	et	4	main
peamine	doc_384045275281_item	2360557	et	3	main
eesmärk	doc_384045275281_item	2360558	et	3	main
on	doc_384045275281_item	2360559	et	4	main
pakkuda	doc_384045275281_item	2360560	et	3	main
ülemineku	doc_384045275281_item	2360561	et	3	main
kommunikatsioonistrateegia	doc_384045275281_item	2360562	et	4	main
näol	doc_384045275281_item	2360563	et	4	main
ühe	doc_384045275281_item	2360564	et	4	main
võimalikku	doc_384045275281_item	2360565	et	4	main
siis	doc_384045275281_item	2360548	et	3	main
perekonnanimi	doc_384045275281_item	2360555	et	3	main
sihtrühmade	doc_384045275281_item	2360567	et	3	main
ettevalmistamiseks	doc_384045275281_item	2360573	et	3	main
analüüsitakse	doc_384045275281_item	2360583	et	4	main
ka	doc_384045275281_item	2360584	et	3	main
tns	doc_384045275281_item	2360585	et	4	main
esmapilgul	doc_384045275281_item	2360596	et	4	main
sisaldab	doc_384045275281_item	2360608	et	3	main
millest	doc_384045275281_item	2360612	et	3	main
ingliskeelset	doc_384045275281_item	2360618	et	3	main
lähenemise	doc_384045275281_item	2360566	et	4	main
ülemineku	doc_384045275281_item	2360571	et	3	main
on	doc_384045275281_item	2360575	et	4	main
vanematega	doc_384045275281_item	2360582	et	4	main
on	doc_384045275281_item	2360593	et	4	main
väga	doc_384045275281_item	2360594	et	3	main
segane	doc_384045275281_item	2360595	et	3	main
tundub	doc_384045275281_item	2360597	et	3	main
töö	doc_384045275281_item	2360599	et	4	main
neljast	doc_384045275281_item	2360601	et	4	main
bibliograafiast	doc_384045275281_item	2360606	et	4	main
24	doc_384045275281_item	2360610	et	2	main
kolmandik	doc_384045275281_item	2360613	et	3	main
on	doc_384045275281_item	2360614	et	4	main
ingliskeelsed	doc_384045275281_item	2360615	et	3	main
magistritöö	doc_384045275281_item	2360622	et	4	main
väga	doc_384045275281_item	2360624	et	3	main
vähe	doc_384045275281_item	2360625	et	3	main
tutvumisel	doc_384045275281_item	2360627	et	4	main
kogu	doc_384045275281_item	2360633	et	4	main
peaaegu	doc_384045275281_item	2360637	et	3	main
samad	doc_384045275281_item	2360638	et	3	main
vrdl	doc_384045275281_item	2360639	et	4	main
õppekeelega	doc_384045275281_item	2360650	et	3	main
koolide	doc_384045275281_item	2360651	et	3	main
osalisele	doc_384045275281_item	2360652	et	4	main
mis	doc_384045275281_item	2360657	et	4	main
nummerdamata	doc_384045275281_item	2360670	et	4	main
omakorda	doc_384045275281_item	2360674	et	3	main
kivide	doc_384045275281_item	2360679	et	3	main
jõuab	doc_384045275281_item	2360682	et	3	main
lugeja	doc_384045275281_item	2360683	et	4	main
osa	doc_384045275281_item	2360685	et	4	main
sissejuhatavas	doc_384045275281_item	2360686	et	3	main
osas	doc_384045275281_item	2360687	et	4	main
samas	doc_384045275281_item	2360726	et	4	main
ning	doc_384045275281_item	2360731	et	3	main
hea	doc_384045275281_item	2360737	et	4	main
kokkuvõtliku	doc_384045275281_item	2360738	et	3	main
loengu	doc_384045275281_item	2360739	et	3	main
pannes	doc_384045275281_item	2360749	et	4	main
autoripoolsed	doc_384045275281_item	2360755	et	3	main
jääb	doc_384045275281_item	2360759	et	3	main
ja	doc_384045275281_item	2360771	et	3	main
mainimata	doc_384045275281_item	2360780	et	4	main
jättes	doc_384045275281_item	2360781	et	4	main
väga	doc_384045275281_item	2360782	et	3	main
silmatorkava	doc_384045275281_item	2360797	et	3	main
на	doc_384045275281_item	2360821	et	2	main
образование	doc_384045275281_item	2360825	et	2	main
программа	doc_384045275281_item	2360831	et	2	main
боль	doc_384045275281_item	2360836	et	2	main
üllitiste	doc_384045275281_item	2360838	et	4	main
eestikeelset	doc_384045275281_item	2360843	et	3	main
õppekeelega	doc_384045275281_item	2360856	et	3	main
lisa	doc_384045275281_item	2360861	et	4	main
pealkirjade	doc_384045275281_item	2360864	et	3	main
sõnastus	doc_384045275281_item	2360865	et	4	main
annab	doc_384045275281_item	2360866	et	3	main
osalisele	doc_384045275281_item	2360876	et	4	main
analüüsi	doc_384045275281_item	2360885	et	4	main
magistrant	doc_384045275281_item	2360889	et	4	main
esindajate	doc_384045275281_item	2360899	et	4	main
suhtes	doc_384045275281_item	2360902	et	4	main
kaardistada	doc_384045275281_item	2360904	et	3	main
sihtrühmade	doc_384045275281_item	2360905	et	3	main
infovajadused	doc_384045275281_item	2360906	et	3	main
m	doc_384045275281_item	2360907	et	4	main
burlaka	doc_384045275281_item	2360908	et	4	main
olnud	doc_384045275281_item	2360920	et	4	main
informeerimiseks	doc_384045275281_item	2360568	et	4	main
seeläbi	doc_384045275281_item	2360570	et	3	main
läbi	doc_384045275281_item	2360588	et	4	main
viidud	doc_384045275281_item	2360589	et	4	main
magistritöö	doc_384045275281_item	2360591	et	4	main
ülesehitus	doc_384045275281_item	2360592	et	4	main
et	doc_384045275281_item	2360598	et	3	main
koosneb	doc_384045275281_item	2360600	et	3	main
lisast	doc_384045275281_item	2360604	et	4	main
ainult	doc_384045275281_item	2360609	et	4	main
allikat	doc_384045275281_item	2360611	et	3	main
ka	doc_384045275281_item	2360616	et	3	main
allikat	doc_384045275281_item	2360619	et	3	main
selgub	doc_384045275281_item	2360628	et	3	main
et	doc_384045275281_item	2360629	et	3	main
peatüki	doc_384045275281_item	2360631	et	3	main
eestikeelsele	doc_384045275281_item	2360653	et	3	main
aineõppele	doc_384045275281_item	2360654	et	3	main
ülemineku	doc_384045275281_item	2360655	et	3	main
kommunikatsioon	doc_384045275281_item	2360656	et	3	main
on	doc_384045275281_item	2360659	et	4	main
teadustöö	doc_384045275281_item	2360660	et	4	main
ilmneb	doc_384045275281_item	2360664	et	3	main
mis	doc_384045275281_item	2360672	et	4	main
osaks	doc_384045275281_item	2360676	et	3	main
niiviisi	doc_384045275281_item	2360677	et	3	main
ja	doc_384045275281_item	2360680	et	3	main
tutvustatakse	doc_384045275281_item	2360688	et	3	main
jätab	doc_384045275281_item	2360732	et	3	main
e	doc_384045275281_item	2360742	et	4	main
tuntumaid	doc_384045275281_item	2360747	et	4	main
et	doc_384045275281_item	2360754	et	3	main
puuduvad	doc_384045275281_item	2360757	et	4	main
arusaamatuks	doc_384045275281_item	2360761	et	4	main
tahetakse	doc_384045275281_item	2360763	et	4	main
analüüsitakse	doc_384045275281_item	2360776	et	4	main
just	doc_384045275281_item	2360786	et	3	main
vahe	doc_384045275281_item	2360798	et	4	main
eestikeelsete	doc_384045275281_item	2360801	et	4	main
ученье	doc_384045275281_item	2360823	et	2	main
путаный	doc_384045275281_item	2360827	et	2	main
школьная	doc_384045275281_item	2360830	et	2	main
50	doc_384045275281_item	2360842	et	2	main
head	doc_384045275281_item	2360845	et	4	main
saab	doc_384045275281_item	2360847	et	3	main
vt	doc_384045275281_item	2360860	et	4	main
1	doc_384045275281_item	2360862	et	2	main
ainuüksi	doc_384045275281_item	2360863	et	3	main
hoiakutest	doc_384045275281_item	2360871	et	3	main
suhtes	doc_384045275281_item	2360875	et	4	main
eestikeelsele	doc_384045275281_item	2360877	et	3	main
õppele	doc_384045275281_item	2360878	et	3	main
siis	doc_384045275281_item	2360879	et	3	main
e	doc_384045275281_item	2360881	et	4	main
sihtrühmade	doc_384045275281_item	2360883	et	3	main
järgnevana	doc_384045275281_item	2360887	et	4	main
erinevate	doc_384045275281_item	2360897	et	4	main
aineõppega	doc_384045275281_item	2360923	et	3	main
üleminekusse	doc_384045275281_item	2360925	et	3	main
kellel	doc_384045275281_item	2360932	et	4	main
praktika	doc_384045275281_item	2360934	et	4	main
informatsioon	doc_384045275281_item	2360937	et	3	main
praktiliselt	doc_384045275281_item	2360939	et	4	main
küsitletud	doc_384045275281_item	2360941	et	4	main
lisainformatsiooni	doc_384045275281_item	2360943	et	4	main
eesmärke	doc_384045275281_item	2360953	et	4	main
kommunikatsioonistrateegia	doc_384045275281_item	2360965	et	4	main
meenutagem	doc_384045275281_item	2360982	et	3	main
näed	doc_384045275281_item	2360987	et	3	main
laita	doc_384045275281_item	2360988	et	3	main
tule	doc_384045275281_item	2360990	et	4	main
poolt	doc_384045275281_item	2360999	et	4	main
mis	doc_384045275281_item	2361002	et	4	main
tee	doc_384045275281_item	2361006	et	4	main
praktikasse	doc_384045275281_item	2361007	et	4	main
lisades	doc_384045275281_item	2361008	et	4	main
dialoogi	doc_384045275281_item	2361025	et	4	main
kestel	doc_384045275281_item	2361028	et	4	main
1	doc_384045275281_item	2361030	et	2	main
analüüsi	doc_384045275281_item	2361048	et	4	main
on	doc_384045275281_item	2360621	et	4	main
jaoks	doc_384045275281_item	2360623	et	4	main
lähemal	doc_384045275281_item	2360626	et	4	main
osalisele	doc_384045275281_item	2360643	et	4	main
ülemineku	doc_384045275281_item	2360646	et	3	main
aga	doc_384045275281_item	2360658	et	3	main
ühest	doc_384045275281_item	2360669	et	4	main
eesmärki	doc_384045275281_item	2360690	et	4	main
põhjendatakse	doc_384045275281_item	2360691	et	3	main
teema	doc_384045275281_item	2360692	et	4	main
valikut	doc_384045275281_item	2360693	et	3	main
aktuaalsust	doc_384045275281_item	2360694	et	4	main
ja	doc_384045275281_item	2360695	et	3	main
tähtsust	doc_384045275281_item	2360696	et	4	main
esimene	doc_384045275281_item	2360697	et	3	main
osa	doc_384045275281_item	2360698	et	4	main
annab	doc_384045275281_item	2360699	et	3	main
ülevaate	doc_384045275281_item	2360700	et	4	main
ülemineku	doc_384045275281_item	2360701	et	3	main
lähteolukorrast	doc_384045275281_item	2360702	et	4	main
teises	doc_384045275281_item	2360703	et	4	main
osas	doc_384045275281_item	2360704	et	4	main
esitatakse	doc_384045275281_item	2360705	et	3	main
aga	doc_384045275281_item	2360706	et	3	main
selle	doc_384045275281_item	2360707	et	4	main
planeerimislähtekohti	doc_384045275281_item	2360708	et	4	main
neid	doc_384045275281_item	2360709	et	4	main
teemasid	doc_384045275281_item	2360710	et	3	main
käsitledes	doc_384045275281_item	2360711	et	3	main
toetub	doc_384045275281_item	2360712	et	3	main
e	doc_384045275281_item	2360713	et	4	main
perekonnanimi	doc_384045275281_item	2360714	et	3	main
erinevatele	doc_384045275281_item	2360715	et	4	main
kommunikatsiooni	doc_384045275281_item	2360716	et	4	main
teoreetikutele	doc_384045275281_item	2360717	et	3	main
lk	doc_384045275281_item	2360718	et	4	main
9	doc_384045275281_item	2360719	et	2	main
14	doc_384045275281_item	2360720	et	2	main
mis	doc_384045275281_item	2360721	et	4	main
on	doc_384045275281_item	2360723	et	4	main
väga	doc_384045275281_item	2360724	et	3	main
hea	doc_384045275281_item	2360725	et	4	main
referatiivne	doc_384045275281_item	2360730	et	4	main
loengukonspekti	doc_384045275281_item	2360734	et	4	main
perekonnanimi	doc_384045275281_item	2360743	et	3	main
olukorda	doc_384045275281_item	2360753	et	4	main
mis	doc_384045275281_item	2360766	et	4	main
esitatakse	doc_384045275281_item	2360768	et	3	main
joonised	doc_384045275281_item	2360773	et	3	main
on	doc_384045275281_item	2360727	et	4	main
liialt	doc_384045275281_item	2360729	et	4	main
väga	doc_384045275281_item	2360745	et	3	main
kommunikatsioonistrateegiaid	doc_384045275281_item	2360748	et	3	main
jõuda	doc_384045275281_item	2360764	et	3	main
kaks	doc_384045275281_item	2360772	et	3	main
värvikad	doc_384045275281_item	2360783	et	3	main
selles	doc_384045275281_item	2360787	et	4	main
kohas	doc_384045275281_item	2360788	et	4	main
oleks	doc_384045275281_item	2360789	et	3	main
igati	doc_384045275281_item	2360790	et	3	main
ja	doc_384045275281_item	2360792	et	3	main
sobilik	doc_384045275281_item	2360793	et	3	main
esile	doc_384045275281_item	2360794	et	3	main
tõsta	doc_384045275281_item	2360795	et	4	main
pealkirjade	doc_384045275281_item	2360802	et	3	main
sõnastuse	doc_384045275281_item	2360803	et	4	main
vahel	doc_384045275281_item	2360804	et	4	main
võrrelgem	doc_384045275281_item	2360805	et	3	main
venekeelsetes	doc_384045275281_item	2360806	et	4	main
ajalehtedes	doc_384045275281_item	2360807	et	4	main
ilmunute	doc_384045275281_item	2360808	et	4	main
kirjutiste	doc_384045275281_item	2360809	et	3	main
pealkirja	doc_384045275281_item	2360810	et	4	main
чтобы	doc_384045275281_item	2360811	et	2	main
не	doc_384045275281_item	2360812	et	2	main
пришлось	doc_384045275281_item	2360813	et	2	main
приносить	doc_384045275281_item	2360814	et	2	main
жертвы	doc_384045275281_item	2360815	et	2	main
выживание	doc_384045275281_item	2360816	et	2	main
школы	doc_384045275281_item	2360817	et	2	main
будь	doc_384045275281_item	2360818	et	2	main
поучись	doc_384045275281_item	2360820	et	2	main
добр	doc_384045275281_item	2360819	et	2	main
osas	doc_384045275281_item	2360775	et	4	main
meediakajastusi	doc_384045275281_item	2360777	et	3	main
kohane	doc_384045275281_item	2360791	et	4	main
ja	doc_384045275281_item	2360800	et	3	main
свет	doc_384045275281_item	2360824	et	2	main
образовательный	doc_384045275281_item	2360828	et	2	main
галочка	doc_384045275281_item	2360833	et	2	main
остальным	doc_384045275281_item	2360834	et	2	main
vene	doc_384045275281_item	2360840	et	4	main
ainult	doc_384045275281_item	2360849	et	4	main
heas	doc_384045275281_item	2360850	et	3	main
arutasid	doc_384045275281_item	2360854	et	4	main
vene	doc_384045275281_item	2360855	et	4	main
keelekogukonna	doc_384045275281_item	2360870	et	4	main
venekeelsete	doc_384045275281_item	2360872	et	4	main
oli	doc_384045275281_item	2360894	et	3	main
põhjalikult	doc_384045275281_item	2360896	et	4	main
hoiakuid	doc_384045275281_item	2360900	et	3	main
ning	doc_384045275281_item	2360903	et	3	main
õpilased	doc_384045275281_item	2360913	et	3	main
ja	doc_384045275281_item	2360915	et	3	main
kellel	doc_384045275281_item	2360917	et	4	main
kogemusi	doc_384045275281_item	2360921	et	3	main
suhtuvad	doc_384045275281_item	2360924	et	4	main
rahulikumalt	doc_384045275281_item	2360927	et	4	main
need	doc_384045275281_item	2360931	et	3	main
ka	doc_384045275281_item	2360936	et	3	main
saamise	doc_384045275281_item	2360944	et	4	main
lk	doc_384045275281_item	2360946	et	4	main
magistrant	doc_384045275281_item	2360950	et	4	main
ülemineku	doc_384045275281_item	2360951	et	3	main
sihtrühmi	doc_384045275281_item	2360955	et	4	main
sõnumite	doc_384045275281_item	2360958	et	3	main
on	doc_384045275281_item	2360962	et	4	main
magistritöö	doc_384045275281_item	2360968	et	4	main
kokkuvõttes	doc_384045275281_item	2360969	et	3	main
e	doc_384045275281_item	2360971	et	4	main
et	doc_384045275281_item	2360973	et	3	main
üleminekust	doc_384045275281_item	2360976	et	3	main
piisavalt	doc_384045275281_item	2360977	et	4	main
konkreetset	doc_384045275281_item	2360978	et	3	main
infot	doc_384045275281_item	2360979	et	3	main
lk	doc_384045275281_item	2360980	et	4	main
aita	doc_384045275281_item	2360992	et	4	main
jääb	doc_384045275281_item	2360993	et	3	main
ainult	doc_384045275281_item	2360994	et	4	main
pakutud	doc_384045275281_item	2361000	et	4	main
lähtuvad	doc_384045275281_item	2361003	et	4	main
on	doc_384045275281_item	2361023	et	4	main
ärgitajaks	doc_384045275281_item	2361026	et	4	main
mis	doc_384045275281_item	2361031	et	4	main
kommunikatsioonistrateegia	doc_384045275281_item	2361033	et	4	main
seejärel	doc_384045275281_item	2361042	et	3	main
ja	doc_384045275281_item	2361046	et	3	main
aga	doc_384045275281_item	2361053	et	3	main
leheküljel	doc_384045275281_item	2361055	et	3	main
te	doc_384045275281_item	2361061	et	4	main
olevat	doc_384045275281_item	2361065	et	4	main
sihtrühmadest	doc_384045275281_item	2361067	et	3	main
muutustega	doc_384045275281_item	2361108	et	4	main
info	doc_384045275281_item	2361118	et	4	main
tõttu	doc_384045275281_item	2361120	et	4	main
oli	doc_384045275281_item	2361125	et	3	main
nende	doc_384045275281_item	2361126	et	4	main
ülemineku	doc_384045275281_item	2361129	et	3	main
tagajärgede	doc_384045275281_item	2361130	et	3	main
identiteeti	doc_384045275281_item	2361137	et	4	main
oli	doc_384045275281_item	2361145	et	3	main
ida-virumaal	doc_384045275281_item	2361146	et	4	main
mitte-eestlaste	doc_384045275281_item	2361147	et	4	main
hirm	doc_384045275281_item	2361148	et	3	main
et	doc_384045275281_item	2361157	et	3	main
oli	doc_384045275281_item	2361159	et	3	main
18	doc_384045275281_item	2361167	et	2	main
võite	doc_384045275281_item	2361170	et	4	main
keelelist	doc_384045275281_item	2361179	et	4	main
identiteeti	doc_384045275281_item	2361182	et	4	main
midagi	doc_384045275281_item	2361184	et	4	main
ja	doc_384045275281_item	2361191	et	3	main
üleminekut	doc_384045275281_item	2361192	et	3	main
эстонском	doc_384045275281_item	2360822	et	2	main
тьма	doc_384045275281_item	2360826	et	2	main
политикам	doc_384045275281_item	2360832	et	2	main
eestikeelsete	doc_384045275281_item	2360837	et	4	main
koolidesse	doc_384045275281_item	2360841	et	3	main
aineõpetajat	doc_384045275281_item	2360844	et	3	main
haridust	doc_384045275281_item	2360846	et	4	main
anda	doc_384045275281_item	2360848	et	3	main
eesti	doc_384045275281_item	2360851	et	4	main
keeles	doc_384045275281_item	2360852	et	4	main
koolijihid	doc_384045275281_item	2360853	et	4	main
tulevikku	doc_384045275281_item	2360858	et	4	main
jne	doc_384045275281_item	2360859	et	4	main
kahe	doc_384045275281_item	2360869	et	3	main
koolide	doc_384045275281_item	2360873	et	3	main
hoiakute	doc_384045275281_item	2360884	et	3	main
kokkuvõtte	doc_384045275281_item	2360886	et	4	main
tutvustab	doc_384045275281_item	2360888	et	3	main
oma	doc_384045275281_item	2360890	et	4	main
küsitlust	doc_384045275281_item	2360891	et	4	main
eesmärgiks	doc_384045275281_item	2360893	et	3	main
uurida	doc_384045275281_item	2360895	et	3	main
sihtrühmade	doc_384045275281_item	2360898	et	3	main
need	doc_384045275281_item	2360912	et	3	main
vanemad	doc_384045275281_item	2360914	et	4	main
märksa	doc_384045275281_item	2360926	et	3	main
vajadust	doc_384045275281_item	2360945	et	4	main
20	doc_384045275281_item	2360947	et	2	main
lähemalt	doc_384045275281_item	2360948	et	4	main
tutvustab	doc_384045275281_item	2360949	et	3	main
neljas	doc_384045275281_item	2360960	et	4	main
osa	doc_384045275281_item	2360961	et	4	main
rakendamisvõimalustele	doc_384045275281_item	2360966	et	4	main
36	doc_384045275281_item	2360981	et	2	main
ja	doc_384045275281_item	2360991	et	3	main
perekonnanimi	doc_384045275281_item	2360998	et	3	main
strateegi	doc_384045275281_item	2361001	et	4	main
4	doc_384045275281_item	2361010	et	2	main
mille	doc_384045275281_item	2360892	et	3	main
ülemineku	doc_384045275281_item	2360901	et	3	main
uuring	doc_384045275281_item	2360909	et	3	main
näitab	doc_384045275281_item	2360910	et	3	main
et	doc_384045275281_item	2360911	et	3	main
pedagoogid	doc_384045275281_item	2360916	et	3	main
on	doc_384045275281_item	2360918	et	4	main
eelnevalt	doc_384045275281_item	2360919	et	4	main
eestikeelse	doc_384045275281_item	2360922	et	3	main
positiivsemalt	doc_384045275281_item	2360929	et	4	main
rõhutasid	doc_384045275281_item	2360942	et	4	main
kommunikatsiooni	doc_384045275281_item	2360952	et	4	main
ja	doc_384045275281_item	2360956	et	3	main
analüüsib	doc_384045275281_item	2360957	et	3	main
kontseptsiooni	doc_384045275281_item	2360959	et	4	main
pühendatud	doc_384045275281_item	2360963	et	4	main
oma	doc_384045275281_item	2360967	et	4	main
rõhutab	doc_384045275281_item	2360970	et	3	main
perekonnanimi	doc_384045275281_item	2360972	et	3	main
sihtgruppidel	doc_384045275281_item	2360974	et	3	main
eesti	doc_384045275281_item	2360983	et	4	main
kus	doc_384045275281_item	2360985	et	3	main
viga	doc_384045275281_item	2360986	et	4	main
loota	doc_384045275281_item	2360995	et	4	main
et	doc_384045275281_item	2360996	et	3	main
e	doc_384045275281_item	2360997	et	4	main
1	doc_384045275281_item	2361009	et	2	main
mõeldud	doc_384045275281_item	2361024	et	4	main
hakkate	doc_384045275281_item	2361035	et	3	main
sihtrühmade	doc_384045275281_item	2361044	et	3	main
hoiakute	doc_384045275281_item	2361045	et	3	main
sihtrühma	doc_384045275281_item	2361051	et	4	main
nii	doc_384045275281_item	2361059	et	3	main
teadliku	doc_384045275281_item	2361064	et	3	main
ühiskonnas	doc_384045275281_item	2361090	et	4	main
ülemineku	doc_384045275281_item	2361095	et	3	main
avalik	doc_384045275281_item	2361097	et	3	main
seisneb	doc_384045275281_item	2361099	et	3	main
identiteedi	doc_384045275281_item	2361101	et	4	main
ülemineku	doc_384045275281_item	2361115	et	3	main
puuduse	doc_384045275281_item	2361119	et	3	main
kahjustab	doc_384045275281_item	2361135	et	3	main
sellele	doc_384045275281_item	2361156	et	4	main
valdamine	doc_384045275281_item	2361164	et	4	main
mis	doc_384045275281_item	2361172	et	4	main
identiteeti	doc_384045275281_item	2361180	et	4	main
õpilaste	doc_384045275281_item	2361189	et	4	main
identiteeti	doc_384045275281_item	2361190	et	4	main
3	doc_384045275281_item	2361193	et	2	main
19	doc_384045275281_item	2361195	et	2	main
te	doc_384045275281_item	2361197	et	4	main
et	doc_384045275281_item	2361200	et	3	main
iseloomustab	doc_384045275281_item	2361202	et	4	main
eesti	doc_384045275281_item	2361204	et	4	main
selgub	doc_384045275281_item	2361207	et	3	main
maardus	doc_384045275281_item	2361214	et	4	main
te	doc_384045275281_item	2361220	et	4	main
kuidagi	doc_384045275281_item	2361222	et	3	main
olukorda	doc_384045275281_item	2361231	et	4	main
teie	doc_384045275281_item	2361232	et	4	main
uuringu	doc_384045275281_item	2361242	et	3	main
väljaspool	doc_384045275281_item	2361248	et	3	main
vormistus	doc_384045275281_item	2361251	et	4	main
stiil	doc_384045275281_item	2361267	et	3	main
ebaühtlane	doc_384045275281_item	2361269	et	3	main
sõnastus	doc_384045275281_item	2361270	et	4	main
ja	doc_384045275281_item	2361271	et	3	main
lauseehitus	doc_384045275281_item	2361272	et	4	main
ei	doc_384045275281_item	2361276	et	4	main
pwerekonnanimi	doc_384045275281_item	2361300	et	4	main
mis	doc_384045275281_item	2361306	et	4	main
juba	doc_384045275281_item	2361309	et	3	main
perioodidel	doc_384045275281_item	2361318	et	3	main
läbi	doc_384045275281_item	2361319	et	4	main
viidud	doc_384045275281_item	2361320	et	4	main
sihtgruppide	doc_384045275281_item	2361322	et	3	main
uuringud	doc_384045275281_item	2361324	et	3	main
et	doc_384045275281_item	2361326	et	3	main
suurenenud	doc_384045275281_item	2361327	et	4	main
infovajadus	doc_384045275281_item	2361328	et	3	main
ei	doc_384045275281_item	2361329	et	4	main
ja	doc_384045275281_item	2360928	et	3	main
kui	doc_384045275281_item	2360930	et	3	main
vastav	doc_384045275281_item	2360933	et	4	main
ja	doc_384045275281_item	2360935	et	3	main
puudub	doc_384045275281_item	2360938	et	3	main
kõik	doc_384045275281_item	2360940	et	4	main
kirjeldab	doc_384045275281_item	2360954	et	3	main
ülemineku	doc_384045275281_item	2360964	et	3	main
pole	doc_384045275281_item	2360975	et	3	main
vanasõna	doc_384045275281_item	2360984	et	4	main
seal	doc_384045275281_item	2360989	et	4	main
sihtrühmade	doc_384045275281_item	2361004	et	3	main
infovajadustestleiab	doc_384045275281_item	2361005	et	4	main
esitab	doc_384045275281_item	2361011	et	3	main
m	doc_384045275281_item	2361012	et	4	main
burlaka	doc_384045275281_item	2361013	et	4	main
üleminekutemaatiliste	doc_384045275281_item	2361014	et	4	main
artiklite	doc_384045275281_item	2361015	et	3	main
loetelu	doc_384045275281_item	2361016	et	4	main
tutvustab	doc_384045275281_item	2361017	et	3	main
lähemalt	doc_384045275281_item	2361018	et	4	main
sihtrühmade	doc_384045275281_item	2361019	et	3	main
tausta	doc_384045275281_item	2361020	et	4	main
järgnev	doc_384045275281_item	2361021	et	4	main
on	doc_384045275281_item	2361032	et	4	main
sihtrühmadest	doc_384045275281_item	2361034	et	3	main
te	doc_384045275281_item	2361036	et	4	main
juba	doc_384045275281_item	2361038	et	3	main
magistritöö	doc_384045275281_item	2361039	et	4	main
sissejuhatavas	doc_384045275281_item	2361040	et	3	main
osas	doc_384045275281_item	2361041	et	4	main
infovajaduste	doc_384045275281_item	2361047	et	4	main
alles	doc_384045275281_item	2361054	et	3	main
miks	doc_384045275281_item	2361057	et	4	main
kas	doc_384045275281_item	2361060	et	3	main
peate	doc_384045275281_item	2361062	et	4	main
lugejat	doc_384045275281_item	2361063	et	4	main
missugustest	doc_384045275281_item	2361066	et	3	main
käib	doc_384045275281_item	2361068	et	3	main
8	doc_384045275281_item	2361094	et	2	main
sihtgruppide	doc_384045275281_item	2361096	et	3	main
viha	doc_384045275281_item	2361098	et	4	main
tundes	doc_384045275281_item	2361102	et	4	main
haridusvõimaluste	doc_384045275281_item	2361103	et	3	main
suutmatuses	doc_384045275281_item	2361107	et	4	main
ebapiisava	doc_384045275281_item	2361110	et	3	main
osa	doc_384045275281_item	2361022	et	4	main
väitluse	doc_384045275281_item	2361027	et	3	main
küsimus	doc_384045275281_item	2361029	et	4	main
rääkima	doc_384045275281_item	2361037	et	3	main
tutvustate	doc_384045275281_item	2361043	et	3	main
lähemalt	doc_384045275281_item	2361049	et	4	main
tutvustate	doc_384045275281_item	2361050	et	3	main
endi	doc_384045275281_item	2361052	et	4	main
26	doc_384045275281_item	2361056	et	2	main
just	doc_384045275281_item	2361058	et	3	main
2	doc_384045275281_item	2361070	et	2	main
teie	doc_384045275281_item	2361071	et	4	main
töös	doc_384045275281_item	2361072	et	3	main
on	doc_384045275281_item	2361073	et	4	main
läbivalt	doc_384045275281_item	2361074	et	4	main
kasutusel	doc_384045275281_item	2361075	et	4	main
termin	doc_384045275281_item	2361076	et	3	main
identiteet	doc_384045275281_item	2361077	et	4	main
kohalikud	doc_384045275281_item	2361078	et	3	main
mitte-eestlased	doc_384045275281_item	2361079	et	3	main
seostavad	doc_384045275281_item	2361080	et	4	main
sellega	doc_384045275281_item	2361081	et	3	main
üleminekuga	doc_384045275281_item	2361082	et	3	main
x	doc_384045275281_item	2361083	et	4	main
y	doc_384045275281_item	2361084	et	4	main
oma	doc_384045275281_item	2361085	et	4	main
identiteeti	doc_384045275281_item	2361086	et	4	main
rolli	doc_384045275281_item	2361087	et	4	main
ja	doc_384045275281_item	2361088	et	3	main
positsiooni	doc_384045275281_item	2361089	et	4	main
ning	doc_384045275281_item	2361091	et	3	main
jutt	doc_384045275281_item	2361069	et	3	main
tulevikuvaateid	doc_384045275281_item	2361092	et	3	main
ohustatud	doc_384045275281_item	2361100	et	4	main
tunnetamises	doc_384045275281_item	2361105	et	4	main
oskuse	doc_384045275281_item	2361113	et	3	main
ning	doc_384045275281_item	2361114	et	3	main
detailide	doc_384045275281_item	2361116	et	3	main
lk	doc_384045275281_item	2361121	et	4	main
jaoks	doc_384045275281_item	2361127	et	4	main
noorte	doc_384045275281_item	2361136	et	3	main
lk	doc_384045275281_item	2361142	et	4	main
17	doc_384045275281_item	2361143	et	2	main
seega	doc_384045275281_item	2361144	et	4	main
pärast	doc_384045275281_item	2361151	et	4	main
kui	doc_384045275281_item	2361153	et	3	main
tallinnas	doc_384045275281_item	2361154	et	4	main
seas	doc_384045275281_item	2361161	et	4	main
eesti	doc_384045275281_item	2361162	et	4	main
jne	doc_384045275281_item	2361168	et	4	main
muud	doc_384045275281_item	2361185	et	4	main
kuidas	doc_384045275281_item	2361186	et	3	main
seostate	doc_384045275281_item	2361187	et	3	main
leheküljel	doc_384045275281_item	2361194	et	3	main
valim	doc_384045275281_item	2361201	et	4	main
erinevaid	doc_384045275281_item	2361203	et	4	main
uuring	doc_384045275281_item	2361209	et	3	main
sillamäel	doc_384045275281_item	2361215	et	3	main
ja	doc_384045275281_item	2361217	et	3	main
kommenteerida	doc_384045275281_item	2361223	et	3	main
maardu	doc_384045275281_item	2361227	et	4	main
kogu	doc_384045275281_item	2361229	et	4	main
peate	doc_384045275281_item	2361240	et	4	main
ju	doc_384045275281_item	2361246	et	3	main
on	doc_384045275281_item	2361256	et	4	main
pro	doc_384045275281_item	2361264	et	4	main
kantseleilik	doc_384045275281_item	2361275	et	3	main
esimeses	doc_384045275281_item	2361301	et	3	main
seda	doc_384045275281_item	2361305	et	3	main
oli	doc_384045275281_item	2361308	et	3	main
5	doc_384045275281_item	2361316	et	2	main
erinevatel	doc_384045275281_item	2361317	et	4	main
ole	doc_384045275281_item	2361330	et	4	main
seni	doc_384045275281_item	2361331	et	3	main
toimumisest	doc_384045275281_item	2361344	et	4	main
hoiakut	doc_384045275281_item	2361350	et	3	main
9	doc_384045275281_item	2361352	et	2	main
hulgaliselt	doc_384045275281_item	2361360	et	4	main
all	doc_384045275282_item	2361401	et	3	main
keele	doc_384045275282_item	2361403	et	4	main
üks	doc_384045275282_item	2361404	et	3	main
püüan	doc_384045275282_item	2361408	et	3	main
ülevaate	doc_384045275282_item	2361411	et	4	main
osasünonüüm	doc_384045275282_item	2361422	et	3	main
kontekstuaalne	doc_384045275282_item	2361423	et	4	main
sünonüüm	doc_384045275282_item	2361426	et	3	main
leksikaalne	doc_384045275282_item	2361427	et	3	main
ideograafiline	doc_384045275282_item	2361429	et	4	main
keel	doc_384045275282_item	2361436	et	4	main
1	doc_384045275282_item	2361443	et	2	main
kirjalikud	doc_384045275282_item	2361455	et	3	main
allikad	doc_384045275282_item	2361456	et	3	main
kokku	doc_384045275282_item	2361457	et	3	main
7	doc_384045275282_item	2361459	et	2	main
erialat	doc_384045275283_item	2361487	et	4	main
palju	doc_384045275283_item	2361499	et	4	main
esialgu	doc_384045275283_item	2361512	et	3	main
tahtsin	doc_384045275283_item	2361514	et	3	main
eesti	doc_384045275283_item	2361520	et	4	main
kuna	doc_384045275283_item	2361524	et	3	main
õppida	doc_384045275283_item	2361528	et	3	main
minema	doc_384045275283_item	2361533	et	3	main
õppima	doc_384045275283_item	2361537	et	3	main
kahetse	doc_384045275283_item	2361542	et	4	main
sest	doc_384045275283_item	2361543	et	4	main
sõbrannalt	doc_384045275283_item	2361551	et	3	main
ta	doc_384045275283_item	2361553	et	4	main
õpis	doc_384045275283_item	2361554	et	3	main
eesti	doc_384045275283_item	2361555	et	4	main
õppimine	doc_384045275283_item	2361561	et	4	main
õpetajad	doc_384045275283_item	2361568	et	4	main
ise	doc_384045275283_item	2361595	et	4	main
lk	doc_384045275281_item	2361093	et	4	main
piirangute	doc_384045275281_item	2361104	et	3	main
ning	doc_384045275281_item	2361106	et	3	main
kohaneda	doc_384045275281_item	2361109	et	3	main
eesti	doc_384045275281_item	2361111	et	4	main
keele	doc_384045275281_item	2361112	et	4	main
kohta	doc_384045275281_item	2361117	et	4	main
12	doc_384045275281_item	2361122	et	2	main
peamine	doc_384045275281_item	2361123	et	3	main
probleem	doc_384045275281_item	2361124	et	3	main
ees	doc_384045275281_item	2361131	et	4	main
kardeti	doc_384045275281_item	2361132	et	3	main
et	doc_384045275281_item	2361133	et	3	main
identiteedi	doc_384045275281_item	2361149	et	4	main
väiksem	doc_384045275281_item	2361152	et	4	main
vaatamata	doc_384045275281_item	2361155	et	4	main
keele	doc_384045275281_item	2361163	et	4	main
lk	doc_384045275281_item	2361166	et	4	main
silmas	doc_384045275281_item	2361178	et	4	main
või	doc_384045275281_item	2361183	et	4	main
venekeelsete	doc_384045275281_item	2361188	et	4	main
väidate	doc_384045275281_item	2361199	et	3	main
piirkondi	doc_384045275281_item	2361205	et	4	main
et	doc_384045275281_item	2361208	et	3	main
kohtla-järvel	doc_384045275281_item	2361216	et	4	main
seda	doc_384045275281_item	2361221	et	3	main
hirm	doc_384045275281_item	2361128	et	3	main
see	doc_384045275281_item	2361134	et	3	main
ja	doc_384045275281_item	2361138	et	3	main
vene	doc_384045275281_item	2361139	et	4	main
keele	doc_384045275281_item	2361140	et	4	main
tundmist	doc_384045275281_item	2361141	et	4	main
kaotamise	doc_384045275281_item	2361150	et	4	main
tallinnas	doc_384045275281_item	2361158	et	4	main
noorte	doc_384045275281_item	2361160	et	3	main
parem	doc_384045275281_item	2361165	et	4	main
kas	doc_384045275281_item	2361169	et	3	main
täpsustada	doc_384045275281_item	2361171	et	3	main
identiteedist	doc_384045275281_item	2361173	et	4	main
te	doc_384045275281_item	2361174	et	4	main
räägite	doc_384045275281_item	2361175	et	3	main
kas	doc_384045275281_item	2361176	et	3	main
peate	doc_384045275281_item	2361177	et	4	main
etnilist	doc_384045275281_item	2361181	et	3	main
sihtrühmasid	doc_384045275281_item	2361198	et	3	main
on	doc_384045275281_item	2361210	et	4	main
viidud	doc_384045275281_item	2361212	et	4	main
oskate	doc_384045275281_item	2361219	et	3	main
ainuüksi	doc_384045275281_item	2361226	et	3	main
tutvustada	doc_384045275281_item	2361228	et	3	main
te	doc_384045275281_item	2361239	et	4	main
olete	doc_384045275281_item	2361245	et	3	main
temaatiliste	doc_384045275281_item	2361265	et	4	main
teksti	doc_384045275281_item	2361266	et	4	main
on	doc_384045275281_item	2361268	et	4	main
väga	doc_384045275281_item	2361274	et	3	main
peatükis	doc_384045275281_item	2361302	et	3	main
9	doc_384045275281_item	2361304	et	2	main
öeldud	doc_384045275281_item	2361311	et	4	main
vrdl	doc_384045275281_item	2361314	et	4	main
tutvustate	doc_384045275281_item	2361196	et	3	main
samas	doc_384045275281_item	2361206	et	4	main
läbi	doc_384045275281_item	2361211	et	4	main
tallinnas	doc_384045275281_item	2361213	et	4	main
narvas	doc_384045275281_item	2361218	et	4	main
kuidas	doc_384045275281_item	2361224	et	3	main
on	doc_384045275281_item	2361234	et	4	main
oma	doc_384045275281_item	2361241	et	4	main
uurija	doc_384045275281_item	2361247	et	4	main
magistritöö	doc_384045275281_item	2361249	et	4	main
keele-	doc_384045275281_item	2361257	et	4	main
ja	doc_384045275281_item	2361258	et	3	main
näpuvigu	doc_384045275281_item	2361259	et	3	main
nt	doc_384045275281_item	2361260	et	4	main
lk	doc_384045275281_item	2361261	et	4	main
4	doc_384045275281_item	2361262	et	2	main
on	doc_384045275281_item	2361273	et	4	main
lk	doc_384045275281_item	2361303	et	4	main
välja	doc_384045275281_item	2361310	et	4	main
lk	doc_384045275281_item	2361312	et	4	main
5	doc_384045275281_item	2361313	et	2	main
ülemineku	doc_384045275281_item	2361321	et	3	main
määral	doc_384045275281_item	2361333	et	3	main
põhjustanud	doc_384045275281_item	2361340	et	4	main
eksitavaid	doc_384045275281_item	2361341	et	4	main
müüte	doc_384045275281_item	2361345	et	4	main
kriitilist	doc_384045275281_item	2361347	et	3	main
tõrjuvat	doc_384045275281_item	2361349	et	4	main
on	doc_384045275281_item	2361358	et	4	main
müüte	doc_384045275281_item	2361361	et	4	main
napisõnaline	doc_384045275281_item	2361368	et	4	main
konkreetseid	doc_384045275281_item	2361369	et	3	main
uurimistulemuste	doc_384045275281_item	2361371	et	4	main
millest	doc_384045275282_item	2361395	et	3	main
leksikaalsetest	doc_384045275282_item	2361405	et	3	main
ja	doc_384045275282_item	2361415	et	3	main
tsiteerimise	doc_384045275282_item	2361416	et	4	main
võtmesõnad	doc_384045275282_item	2361418	et	3	main
saab	doc_384045275281_item	2361225	et	3	main
harjumaa	doc_384045275281_item	2361230	et	4	main
uuringus	doc_384045275281_item	2361233	et	3	main
puudu	doc_384045275281_item	2361235	et	4	main
tartu	doc_384045275281_item	2361236	et	4	main
4	doc_384045275281_item	2361237	et	2	main
kas	doc_384045275281_item	2361238	et	3	main
tulemusi	doc_384045275281_item	2361243	et	4	main
adekvaatseks	doc_384045275281_item	2361244	et	3	main
tehniline	doc_384045275281_item	2361250	et	3	main
on	doc_384045275281_item	2361252	et	4	main
hea	doc_384045275281_item	2361253	et	4	main
kuigi	doc_384045275281_item	2361254	et	3	main
töös	doc_384045275281_item	2361255	et	3	main
teemaliste	doc_384045275281_item	2361263	et	4	main
raskenda	doc_384045275281_item	2361277	et	4	main
sisust	doc_384045275281_item	2361279	et	4	main
see	doc_384045275281_item	2361278	et	3	main
arusaamist	doc_384045275281_item	2361280	et	4	main
samas	doc_384045275281_item	2361281	et	4	main
oleks	doc_384045275281_item	2361282	et	3	main
magistrant	doc_384045275281_item	2361283	et	4	main
pidanud	doc_384045275281_item	2361284	et	4	main
suhtuma	doc_384045275281_item	2361285	et	3	main
töö	doc_384045275281_item	2361286	et	4	main
keelelisse	doc_384045275281_item	2361287	et	4	main
viimistlusse	doc_384045275281_item	2361288	et	4	main
tõsisemalt	doc_384045275281_item	2361289	et	4	main
ja	doc_384045275281_item	2361290	et	3	main
mõtlema	doc_384045275281_item	2361291	et	3	main
oma	doc_384045275281_item	2361292	et	4	main
mõtete	doc_384045275281_item	2361293	et	3	main
täpsema	doc_384045275281_item	2361294	et	4	main
sõnastuse	doc_384045275281_item	2361295	et	4	main
üle	doc_384045275281_item	2361296	et	3	main
näiteks	doc_384045275281_item	2361297	et	4	main
kordab	doc_384045275281_item	2361298	et	3	main
e	doc_384045275281_item	2361299	et	4	main
sissejuhatuses	doc_384045275281_item	2361307	et	4	main
lk	doc_384045275281_item	2361315	et	4	main
näitavad	doc_384045275281_item	2361325	et	4	main
vajalikul	doc_384045275281_item	2361332	et	3	main
ülemineku	doc_384045275281_item	2361343	et	3	main
ja	doc_384045275281_item	2361348	et	3	main
infopuudus	doc_384045275281_item	2361353	et	3	main
ülemineku	doc_384045275281_item	2361355	et	3	main
tõrjuvat	doc_384045275281_item	2361363	et	4	main
suhtumist	doc_384045275281_item	2361364	et	4	main
ingliskeelne	doc_384045275281_item	2361365	et	3	main
resümee	doc_384045275281_item	2361366	et	4	main
koosneb	doc_384045275282_item	2361396	et	3	main
jaguneb	doc_384045275282_item	2361399	et	3	main
on	doc_384045275282_item	2361402	et	4	main
sünonüümiast	doc_384045275282_item	2361410	et	4	main
sünonüümia	doc_384045275282_item	2361419	et	4	main
ulatub	doc_384045275282_item	2361439	et	3	main
kasutatud	doc_384045275282_item	2361446	et	4	main
2	doc_384045275282_item	2361462	et	2	main
valisin	doc_384045275283_item	2361485	et	3	main
üksendal	doc_384045275283_item	2361489	et	4	main
majandus	doc_384045275283_item	2361491	et	4	main
olen	doc_384045275283_item	2361498	et	3	main
minu	doc_384045275283_item	2361503	et	3	main
on	doc_384045275283_item	2361505	et	4	main
ja	doc_384045275283_item	2361507	et	3	main
ta	doc_384045275283_item	2361508	et	4	main
õpis	doc_384045275283_item	2361509	et	3	main
seda	doc_384045275283_item	2361510	et	3	main
sooritasin	doc_384045275283_item	2361519	et	3	main
keele	doc_384045275283_item	2361521	et	4	main
rahvamajandust	doc_384045275283_item	2361525	et	3	main
võimalik	doc_384045275283_item	2361527	et	3	main
pidin	doc_384045275283_item	2361532	et	3	main
praegu	doc_384045275283_item	2361539	et	3	main
ei	doc_384045275283_item	2361541	et	4	main
oma	doc_384045275283_item	2361550	et	4	main
ikkagi	doc_384045275283_item	2361559	et	4	main
saab	doc_384045275283_item	2361594	et	3	main
oska	doc_384045275283_item	2361601	et	4	main
rohkem	doc_384045275283_item	2361605	et	4	main
koolis	doc_384045275283_item	2361609	et	4	main
tahan	doc_384045275283_item	2361621	et	3	main
asjad	doc_384045275283_item	2361624	et	3	main
huvitav	doc_384045275283_item	2361638	et	4	main
õpis	doc_384045275283_item	2361642	et	3	main
saime	doc_384045275283_item	2361649	et	3	main
sõpradeks	doc_384045275283_item	2361651	et	3	main
hakab	doc_384045275283_item	2361653	et	4	main
otsast	doc_384045275283_item	2361655	et	4	main
teisega	doc_384045275283_item	2361660	et	4	main
algusel	doc_384045275283_item	2361661	et	4	main
oli	doc_384045275283_item	2361663	et	3	main
uskuda	doc_384045275283_item	2361665	et	3	main
ma	doc_384045275283_item	2361667	et	3	main
rohkem	doc_384045275283_item	2361668	et	4	main
koolis	doc_384045275283_item	2361671	et	4	main
klassijuhatajat	doc_384045275283_item	2361676	et	3	main
ja	doc_384045275283_item	2361677	et	3	main
aga	doc_384045275283_item	2361679	et	3	main
ülikoolis	doc_384045275283_item	2361683	et	4	main
praegu	doc_384045275283_item	2361684	et	3	main
on	doc_384045275283_item	2361685	et	4	main
hoiakute	doc_384045275281_item	2361323	et	3	main
ülemineku	doc_384045275281_item	2361334	et	3	main
eestvedajate	doc_384045275281_item	2361335	et	3	main
rahuldatud	doc_384045275281_item	2361337	et	4	main
ning	doc_384045275281_item	2361346	et	3	main
lk	doc_384045275281_item	2361351	et	4	main
ja	doc_384045275281_item	2361354	et	3	main
rakendamise	doc_384045275281_item	2361356	et	4	main
ebaselgus	doc_384045275281_item	2361357	et	4	main
on	doc_384045275281_item	2361367	et	4	main
üldjäreldusi	doc_384045275281_item	2361370	et	3	main
ei	doc_384045275281_item	2361373	et	4	main
leidu	doc_384045275281_item	2361374	et	4	main
kokkuvõtvalt	doc_384045275281_item	2361375	et	4	main
vastab	doc_384045275281_item	2361376	et	3	main
eesnimi	doc_384045275281_item	2361377	et	3	main
perekonnanimi	doc_384045275281_item	2361378	et	3	main
magistritöö	doc_384045275281_item	2361379	et	4	main
magistrikraadile	doc_384045275281_item	2361380	et	3	main
nõuetele	doc_384045275281_item	2361382	et	4	main
esitatavatele	doc_384045275281_item	2361381	et	4	main
ning	doc_384045275281_item	2361383	et	3	main
väärib	doc_384045275281_item	2361384	et	3	main
c	doc_384045275281_item	2361385	et	4	main
head	doc_384045275281_item	2361386	et	4	main
hinnet	doc_384045275281_item	2361387	et	3	main
referaat	doc_384045275282_item	2361388	et	3	main
referaadi	doc_384045275282_item	2361389	et	3	main
eesmärk	doc_384045275282_item	2361390	et	3	main
on	doc_384045275282_item	2361391	et	4	main
selgitada	doc_384045275282_item	2361392	et	3	main
mõistet	doc_384045275282_item	2361393	et	3	main
poolt	doc_384045275281_item	2361336	et	4	main
mis	doc_384045275281_item	2361338	et	4	main
on	doc_384045275281_item	2361339	et	4	main
arusaame	doc_384045275281_item	2361342	et	3	main
põhjustanud	doc_384045275281_item	2361359	et	4	main
ja	doc_384045275281_item	2361362	et	3	main
kohta	doc_384045275281_item	2361372	et	4	main
kuidas	doc_384045275282_item	2361398	et	3	main
vaatluse	doc_384045275282_item	2361400	et	3	main
kategooriatest	doc_384045275282_item	2361406	et	3	main
teel	doc_384045275282_item	2361417	et	4	main
sünonüüm	doc_384045275282_item	2361428	et	3	main
stiilisünonüüm	doc_384045275282_item	2361431	et	3	main
on	doc_384045275282_item	2361434	et	4	main
eesti	doc_384045275282_item	2361435	et	4	main
leheküljeni	doc_384045275282_item	2361441	et	3	main
on	doc_384045275282_item	2361444	et	4	main
kasutasin	doc_384045275282_item	2361458	et	3	main
allikat	doc_384045275282_item	2361460	et	3	main
tipikas	doc_384045275283_item	2361483	et	4	main
klassil	doc_384045275283_item	2361490	et	3	main
mulle	doc_384045275283_item	2361493	et	4	main
emalt	doc_384045275283_item	2361502	et	3	main
ma	doc_384045275283_item	2361513	et	3	main
minna	doc_384045275283_item	2361515	et	3	main
keeles	doc_384045275283_item	2361531	et	4	main
sellest	doc_384045275283_item	2361549	et	4	main
on	doc_384045275283_item	2361558	et	4	main
õppimisest	doc_384045275283_item	2361565	et	4	main
sundivad	doc_384045275283_item	2361569	et	4	main
ei	doc_384045275283_item	2361600	et	4	main
õppida	doc_384045275283_item	2361607	et	3	main
oli	doc_384045275283_item	2361610	et	3	main
on	doc_384045275283_item	2361615	et	4	main
aga	doc_384045275283_item	2361616	et	3	main
oma	doc_384045275283_item	2361617	et	4	main
millised	doc_384045275283_item	2361623	et	3	main
meeldivad	doc_384045275283_item	2361626	et	4	main
koolis	doc_384045275283_item	2361627	et	4	main
ja	doc_384045275283_item	2361628	et	3	main
semester	doc_384045275283_item	2361633	et	3	main
uued	doc_384045275283_item	2361634	et	3	main
on	doc_384045275283_item	2361637	et	4	main
meie	doc_384045275283_item	2361640	et	4	main
kaksteist	doc_384045275283_item	2361643	et	4	main
aastat	doc_384045275283_item	2361644	et	3	main
koos	doc_384045275283_item	2361645	et	4	main
ja	doc_384045275283_item	2361646	et	3	main
teine	doc_384045275283_item	2361659	et	3	main
ei	doc_384045275283_item	2361669	et	4	main
mulle	doc_384045275283_item	2361680	et	4	main
õppida	doc_384045275283_item	2361682	et	3	main
et	doc_384045275283_item	2361690	et	3	main
session	doc_384045275283_item	2361692	et	4	main
ülikool	doc_384045275284_item	2361698	et	4	main
mehaanikainseneriks	doc_384045275284_item	2361723	et	3	main
väga	doc_384045275284_item	2361727	et	3	main
sest	doc_384045275284_item	2361730	et	4	main
ei	doc_384045275284_item	2361738	et	4	main
ole	doc_384045275284_item	2361739	et	4	main
kõrgharidus	doc_384045275284_item	2361740	et	3	main
teil	doc_384045275284_item	2361741	et	4	main
veel	doc_384045275284_item	2361749	et	4	main
ma	doc_384045275284_item	2361750	et	3	main
arvan	doc_384045275284_item	2361751	et	3	main
et	doc_384045275284_item	2361752	et	3	main
eesti	doc_384045275284_item	2361753	et	4	main
avaldab	doc_384045275284_item	2361767	et	3	main
otsida	doc_384045275284_item	2361787	et	4	main
tagastada	doc_384045275284_item	2361793	et	3	main
annab	doc_384045275284_item	2361806	et	3	main
uusi	doc_384045275284_item	2361809	et	3	main
võimalusi	doc_384045275284_item	2361810	et	3	main
aga	doc_384045275284_item	2361818	et	3	main
et	doc_384045275284_item	2361823	et	3	main
aru	doc_384045275284_item	2361832	et	4	main
saama	doc_384045275284_item	2361833	et	4	main
esimesest	doc_384045275284_item	2361834	et	3	main
klassijuhatajat	doc_384045275284_item	2361840	et	3	main
sind	doc_384045275284_item	2361847	et	4	main
teele	doc_384045275284_item	2361849	et	3	main
oma	doc_384045275284_item	2361860	et	4	main
sünonüümia	doc_384045275282_item	2361394	et	4	main
ja	doc_384045275282_item	2361397	et	3	main
sünonüümia	doc_384045275282_item	2361407	et	4	main
anda	doc_384045275282_item	2361409	et	3	main
erinevate	doc_384045275282_item	2361412	et	4	main
keeletundjate	doc_384045275282_item	2361413	et	3	main
refereerimise	doc_384045275282_item	2361414	et	4	main
sünonüüm	doc_384045275282_item	2361420	et	3	main
täissünonüüm	doc_384045275282_item	2361421	et	3	main
grammatiline	doc_384045275282_item	2361425	et	3	main
töö	doc_384045275282_item	2361437	et	4	main
18	doc_384045275282_item	2361440	et	2	main
lisad	doc_384045275282_item	2361445	et	4	main
kirjanduse	doc_384045275282_item	2361447	et	3	main
jäävad	doc_384045275282_item	2361449	et	4	main
nii	doc_384045275282_item	2361450	et	3	main
leheküljed	doc_384045275282_item	2361452	et	3	main
kui	doc_384045275282_item	2361453	et	3	main
ka	doc_384045275282_item	2361454	et	3	main
kus	doc_384045275282_item	2361461	et	3	main
ja	doc_384045275283_item	2361479	et	3	main
ma	doc_384045275283_item	2361480	et	3	main
olen	doc_384045275283_item	2361481	et	3	main
majandusteaduskonna	doc_384045275283_item	2361482	et	4	main
ma	doc_384045275283_item	2361484	et	3	main
pakus	doc_384045275283_item	2361492	et	3	main
huvi	doc_384045275283_item	2361494	et	4	main
sellepärast	doc_384045275283_item	2361495	et	3	main
sellest	doc_384045275283_item	2361501	et	4	main
ema	doc_384045275283_item	2361504	et	4	main
raamatupidaja	doc_384045275283_item	2361506	et	4	main
rahvamajandust	doc_384045275283_item	2361517	et	3	main
sünonüüm	doc_384045275282_item	2361424	et	3	main
sünonüüm	doc_384045275282_item	2361430	et	3	main
töö	doc_384045275282_item	2361432	et	4	main
põhikeeleks	doc_384045275282_item	2361433	et	4	main
maht	doc_384045275282_item	2361438	et	3	main
millest	doc_384045275282_item	2361442	et	3	main
loetellu	doc_384045275282_item	2361448	et	3	main
interneti	doc_384045275282_item	2361451	et	4	main
olid	doc_384045275282_item	2361463	et	4	main
saadud	doc_384045275282_item	2361465	et	4	main
ja	doc_384045275282_item	2361466	et	3	main
internetist	doc_384045275282_item	2361464	et	4	main
ülejäänud	doc_384045275282_item	2361467	et	4	main
olid	doc_384045275282_item	2361468	et	4	main
raamatute	doc_384045275282_item	2361469	et	3	main
väljavõtted	doc_384045275282_item	2361470	et	3	main
essee	doc_384045275283_item	2361471	et	4	main
mina	doc_384045275283_item	2361472	et	4	main
ja	doc_384045275283_item	2361473	et	3	main
ülikool	doc_384045275283_item	2361474	et	4	main
minu	doc_384045275283_item	2361475	et	3	main
nimi	doc_384045275283_item	2361476	et	3	main
on	doc_384045275283_item	2361477	et	4	main
x	doc_384045275283_item	2361478	et	4	main
seda	doc_384045275283_item	2361486	et	3	main
juba	doc_384045275283_item	2361488	et	3	main
et	doc_384045275283_item	2361496	et	3	main
ma	doc_384045275283_item	2361497	et	3	main
kuulnud	doc_384045275283_item	2361500	et	4	main
erialat	doc_384045275283_item	2361511	et	4	main
õppima	doc_384045275283_item	2361516	et	3	main
kuid	doc_384045275283_item	2361518	et	4	main
eksami	doc_384045275283_item	2361522	et	3	main
halvasti	doc_384045275283_item	2361523	et	3	main
on	doc_384045275283_item	2361526	et	4	main
ainult	doc_384045275283_item	2361529	et	4	main
eesti	doc_384045275283_item	2361530	et	4	main
vene	doc_384045275283_item	2361534	et	4	main
aga	doc_384045275283_item	2361538	et	3	main
on	doc_384045275283_item	2361545	et	4	main
raskem	doc_384045275283_item	2361546	et	4	main
õppida	doc_384045275283_item	2361547	et	3	main
tean	doc_384045275283_item	2361548	et	3	main
koolis	doc_384045275283_item	2361556	et	4	main
tal	doc_384045275283_item	2361557	et	3	main
ülikoolis	doc_384045275283_item	2361562	et	4	main
väga	doc_384045275283_item	2361563	et	3	main
erineb	doc_384045275283_item	2361564	et	3	main
koolis	doc_384045275283_item	2361567	et	4	main
kus	doc_384045275283_item	2361603	et	3	main
sest	doc_384045275283_item	2361608	et	4	main
moodi	doc_384045275283_item	2361612	et	4	main
ülikoolis	doc_384045275283_item	2361614	et	4	main
moodi	doc_384045275283_item	2361618	et	4	main
nüüd	doc_384045275283_item	2361620	et	4	main
mulle	doc_384045275283_item	2361625	et	4	main
ülikoolis	doc_384045275283_item	2361630	et	4	main
iga	doc_384045275283_item	2361632	et	4	main
klass	doc_384045275283_item	2361641	et	3	main
peab	doc_384045275283_item	2361657	et	4	main
mul	doc_384045275283_item	2361662	et	3	main
raske	doc_384045275283_item	2361664	et	4	main
õpi	doc_384045275283_item	2361670	et	4	main
igatsesin	doc_384045275283_item	2361674	et	3	main
tähtsam	doc_384045275283_item	2361687	et	4	main
jaoks	doc_384045275283_item	2361689	et	4	main
esimene	doc_384045275283_item	2361691	et	3	main
oleks	doc_384045275283_item	2361693	et	3	main
mina	doc_384045275284_item	2361699	et	4	main
meie	doc_384045275284_item	2361724	et	4	main
elus	doc_384045275284_item	2361725	et	4	main
tähtis	doc_384045275284_item	2361728	et	4	main
see	doc_384045275284_item	2361731	et	3	main
ei	doc_384045275284_item	2361742	et	4	main
on	doc_384045275284_item	2361756	et	4	main
jaoks	doc_384045275284_item	2361771	et	4	main
et	doc_384045275284_item	2361784	et	3	main
endale	doc_384045275284_item	2361788	et	4	main
töökohta	doc_384045275284_item	2361790	et	4	main
stabiilse	doc_384045275284_item	2361794	et	3	main
tulevikus	doc_384045275284_item	2361800	et	4	main
vaesusemata	doc_384045275284_item	2361801	et	3	main
ülikooli	doc_384045275284_item	2361803	et	4	main
oma	doc_384045275284_item	2361815	et	4	main
plaane	doc_384045275284_item	2361816	et	3	main
elus	doc_384045275284_item	2361817	et	4	main
õppimine	doc_384045275284_item	2361824	et	4	main
ülikoolis	doc_384045275284_item	2361836	et	4	main
kes	doc_384045275284_item	2361841	et	4	main
elad	doc_384045275284_item	2361851	et	3	main
elu	doc_384045275284_item	2361853	et	4	main
on	doc_384045275284_item	2361854	et	4	main
aga	doc_384045275284_item	2361859	et	3	main
ülikooli	doc_384045275284_item	2361862	et	4	main
tunniplaani	doc_384045275284_item	2361869	et	4	main
mis	doc_384045275284_item	2361870	et	4	main
sul	doc_384045275284_item	2361871	et	3	main
tudengid	doc_384045275284_item	2361880	et	3	main
jaoks	doc_384045275284_item	2361888	et	4	main
nii	doc_384045275284_item	2361899	et	3	main
inimene	doc_384045275284_item	2361902	et	3	main
endale	doc_384045275284_item	2361905	et	4	main
midagi	doc_384045275284_item	2361906	et	4	main
oma	doc_384045275284_item	2361907	et	4	main
huvist	doc_384045275284_item	2361908	et	3	main
parim	doc_384045275284_item	2361927	et	4	main
gruppi	doc_384045275283_item	2361535	et	4	main
ärindust	doc_384045275283_item	2361536	et	3	main
ma	doc_384045275283_item	2361540	et	3	main
rahvamajanduses	doc_384045275283_item	2361544	et	3	main
kuigi	doc_384045275283_item	2361552	et	3	main
raske	doc_384045275283_item	2361560	et	4	main
koolis	doc_384045275283_item	2361566	et	4	main
sind	doc_384045275283_item	2361570	et	4	main
õppida	doc_384045275283_item	2361571	et	3	main
ülikoolis	doc_384045275283_item	2361572	et	4	main
aga	doc_384045275283_item	2361573	et	3	main
mitte	doc_384045275283_item	2361574	et	3	main
siin	doc_384045275283_item	2361575	et	4	main
sa	doc_384045275283_item	2361576	et	3	main
õpid	doc_384045275283_item	2361577	et	4	main
oma	doc_384045275283_item	2361578	et	4	main
jaoks	doc_384045275283_item	2361579	et	4	main
ülikoolis	doc_384045275283_item	2361580	et	4	main
on	doc_384045275283_item	2361581	et	4	main
rohkem	doc_384045275283_item	2361582	et	4	main
vabaaega	doc_384045275283_item	2361583	et	4	main
sest	doc_384045275283_item	2361584	et	4	main
ei	doc_384045275283_item	2361585	et	4	main
ole	doc_384045275283_item	2361586	et	4	main
igapäevast	doc_384045275283_item	2361587	et	4	main
kodutööd	doc_384045275283_item	2361588	et	4	main
on	doc_384045275283_item	2361590	et	4	main
või	doc_384045275283_item	2361589	et	4	main
seda	doc_384045275283_item	2361591	et	3	main
vähe	doc_384045275283_item	2361592	et	3	main
tudeng	doc_384045275283_item	2361593	et	3	main
jagada	doc_384045275283_item	2361596	et	3	main
oma	doc_384045275283_item	2361597	et	4	main
aega	doc_384045275283_item	2361598	et	4	main
ma	doc_384045275283_item	2361599	et	3	main
mulle	doc_384045275283_item	2361604	et	4	main
hea	doc_384045275283_item	2361613	et	4	main
hea	doc_384045275283_item	2361619	et	4	main
rääkida	doc_384045275283_item	2361622	et	3	main
õppeained	doc_384045275283_item	2361635	et	3	main
see	doc_384045275283_item	2361636	et	3	main
selle	doc_384045275283_item	2361647	et	4	main
kõik	doc_384045275283_item	2361654	et	4	main
peale	doc_384045275283_item	2361656	et	4	main
et	doc_384045275283_item	2361666	et	3	main
ma	doc_384045275283_item	2361672	et	3	main
väga	doc_384045275283_item	2361673	et	3	main
oma	doc_384045275283_item	2361675	et	4	main
klassikaaslasi	doc_384045275283_item	2361678	et	3	main
meeldib	doc_384045275283_item	2361681	et	3	main
kõige	doc_384045275283_item	2361686	et	4	main
tahan	doc_384045275284_item	2361721	et	3	main
on	doc_384045275284_item	2361726	et	4	main
kõrgharidus	doc_384045275284_item	2361729	et	3	main
on	doc_384045275284_item	2361732	et	4	main
väga	doc_384045275284_item	2361733	et	3	main
tähtis	doc_384045275284_item	2361734	et	4	main
tänapäeval	doc_384045275284_item	2361735	et	3	main
kui	doc_384045275284_item	2361736	et	3	main
teil	doc_384045275284_item	2361737	et	4	main
ole	doc_384045275284_item	2361743	et	4	main
palju	doc_384045275284_item	2361744	et	4	main
võimalusi	doc_384045275284_item	2361745	et	3	main
valida	doc_384045275284_item	2361746	et	3	main
oma	doc_384045275284_item	2361747	et	4	main
keele	doc_384045275284_item	2361754	et	4	main
oskus	doc_384045275284_item	2361764	et	3	main
ja	doc_384045275284_item	2361765	et	3	main
tahab	doc_384045275284_item	2361778	et	3	main
pärast	doc_384045275284_item	2361779	et	4	main
oskan	doc_384045275284_item	2361786	et	3	main
hea	doc_384045275284_item	2361789	et	4	main
ja	doc_384045275284_item	2361791	et	3	main
heaolu	doc_384045275284_item	2361796	et	4	main
perele	doc_384045275284_item	2361798	et	3	main
inimesele	doc_384045275284_item	2361807	et	3	main
on	doc_384045275284_item	2361812	et	4	main
kerge	doc_384045275284_item	2361813	et	4	main
realiseerida	doc_384045275284_item	2361814	et	3	main
selgeks	doc_384045275284_item	2361821	et	3	main
on	doc_384045275284_item	2361828	et	4	main
ei	doc_384045275284_item	2361838	et	4	main
ole	doc_384045275284_item	2361839	et	4	main
vaja	doc_384045275284_item	2361855	et	4	main
olla	doc_384045275284_item	2361856	et	3	main
iseseisvuna	doc_384045275284_item	2361857	et	4	main
plussid	doc_384045275284_item	2361861	et	3	main
ise	doc_384045275284_item	2361867	et	4	main
tööl	doc_384045275284_item	2361882	et	3	main
rohkem	doc_384045275284_item	2361885	et	4	main
ülikoolis	doc_384045275284_item	2361890	et	4	main
olemas	doc_384045275284_item	2361892	et	4	main
valikained	doc_384045275284_item	2361893	et	3	main
ja	doc_384045275284_item	2361894	et	3	main
valik	doc_384045275284_item	2361895	et	3	main
on	doc_384045275284_item	2361896	et	4	main
väga	doc_384045275284_item	2361897	et	3	main
miks	doc_384045275284_item	2361909	et	4	main
sest	doc_384045275284_item	2361922	et	4	main
see	doc_384045275284_item	2361923	et	3	main
ei	doc_384045275284_item	2361930	et	4	main
aga	doc_384045275284_item	2361933	et	3	main
ei	doc_384045275284_item	2361941	et	4	main
olnud	doc_384045275284_item	2361942	et	4	main
ma	doc_384045275284_item	2361943	et	3	main
ju	doc_384045275284_item	2361944	et	3	main
tahtsin	doc_384045275284_item	2361945	et	3	main
õppida	doc_384045275284_item	2361946	et	3	main
ainult	doc_384045275284_item	2361947	et	4	main
sõnul	doc_392411160212_item	2361996	et	3	main
on	doc_392411160212_item	2361997	et	4	main
terves	doc_392411160212_item	2361998	et	4	main
maailmas	doc_392411160212_item	2361999	et	3	main
ütelda	doc_384045275283_item	2361602	et	4	main
meeldib	doc_384045275283_item	2361606	et	3	main
oma	doc_384045275283_item	2361611	et	4	main
ülikoolis	doc_384045275283_item	2361629	et	4	main
on	doc_384045275283_item	2361631	et	4	main
koolis	doc_384045275283_item	2361639	et	4	main
ajaga	doc_384045275283_item	2361648	et	3	main
suurteks	doc_384045275283_item	2361650	et	3	main
ülikoolois	doc_384045275283_item	2361652	et	4	main
harjuma	doc_384045275283_item	2361658	et	3	main
minu	doc_384045275283_item	2361688	et	3	main
edukas	doc_384045275283_item	2361694	et	4	main
essee	doc_384045275284_item	2361695	et	4	main
mina	doc_384045275284_item	2361696	et	4	main
ja	doc_384045275284_item	2361697	et	3	main
olen	doc_384045275284_item	2361700	et	3	main
x	doc_384045275284_item	2361701	et	4	main
ma	doc_384045275284_item	2361702	et	3	main
lõpetasin	doc_384045275284_item	2361703	et	3	main
narva	doc_384045275284_item	2361704	et	4	main
kooli	doc_384045275284_item	2361705	et	4	main
selles	doc_384045275284_item	2361706	et	4	main
koolis	doc_384045275284_item	2361707	et	4	main
ma	doc_384045275284_item	2361708	et	3	main
õpisin	doc_384045275284_item	2361709	et	4	main
12	doc_384045275284_item	2361710	et	2	main
aastat	doc_384045275284_item	2361711	et	3	main
ma	doc_384045275284_item	2361713	et	3	main
nüüd	doc_384045275284_item	2361712	et	4	main
astusin	doc_384045275284_item	2361714	et	3	main
tallinna	doc_384045275284_item	2361715	et	4	main
tehnikaülikooli	doc_384045275284_item	2361716	et	4	main
mehaanika	doc_384045275284_item	2361717	et	4	main
teaduskonda	doc_384045275284_item	2361718	et	4	main
tulevikus	doc_384045275284_item	2361719	et	4	main
ma	doc_384045275284_item	2361720	et	3	main
saada	doc_384045275284_item	2361722	et	4	main
töökohta	doc_384045275284_item	2361748	et	4	main
oskus	doc_384045275284_item	2361755	et	3	main
eesti	doc_384045275284_item	2361759	et	4	main
on	doc_384045275284_item	2361761	et	4	main
riigikeel	doc_384045275284_item	2361762	et	4	main
rigikeelte	doc_384045275284_item	2361763	et	4	main
kõrgharidus	doc_384045275284_item	2361766	et	3	main
palju	doc_384045275284_item	2361768	et	4	main
inimeste	doc_384045275284_item	2361770	et	3	main
näiteks	doc_384045275284_item	2361772	et	4	main
inimene	doc_384045275284_item	2361773	et	3	main
võib	doc_384045275284_item	2361774	et	3	main
töötada	doc_384045275284_item	2361775	et	3	main
kus	doc_384045275284_item	2361776	et	3	main
ta	doc_384045275284_item	2361777	et	4	main
ma	doc_384045275284_item	2361785	et	3	main
sisse	doc_384045275284_item	2361804	et	4	main
väga	doc_384045275284_item	2361757	et	3	main
käesolev	doc_384045275284_item	2361758	et	3	main
keel	doc_384045275284_item	2361760	et	4	main
võimalusi	doc_384045275284_item	2361769	et	3	main
ülikooli	doc_384045275284_item	2361780	et	4	main
lõpitamist	doc_384045275284_item	2361781	et	4	main
ma	doc_384045275284_item	2361782	et	3	main
loodan	doc_384045275284_item	2361783	et	3	main
saan	doc_384045275284_item	2361792	et	4	main
materiaalse	doc_384045275284_item	2361795	et	3	main
oma	doc_384045275284_item	2361797	et	4	main
aga	doc_384045275284_item	2361799	et	3	main
vanemust	doc_384045275284_item	2361802	et	4	main
astumine	doc_384045275284_item	2361805	et	4	main
palju	doc_384045275284_item	2361808	et	4	main
inimesel	doc_384045275284_item	2361811	et	3	main
tuleb	doc_384045275284_item	2361819	et	3	main
endale	doc_384045275284_item	2361820	et	4	main
ülikoolis	doc_384045275284_item	2361825	et	4	main
gümnaasiumis	doc_384045275284_item	2361827	et	3	main
erinev	doc_384045275284_item	2361829	et	4	main
seda	doc_384045275284_item	2361830	et	3	main
hakkad	doc_384045275284_item	2361831	et	3	main
sul	doc_384045275284_item	2361837	et	3	main
hakkab	doc_384045275284_item	2361842	et	3	main
aitama	doc_384045275284_item	2361844	et	3	main
panema	doc_384045275284_item	2361846	et	3	main
õigele	doc_384045275284_item	2361848	et	3	main
indale	doc_384045275284_item	2361868	et	4	main
vajalik	doc_384045275284_item	2361872	et	3	main
on	doc_384045275284_item	2361873	et	4	main
see	doc_384045275284_item	2361883	et	3	main
töö	doc_384045275284_item	2361887	et	4	main
samuti	doc_384045275284_item	2361889	et	3	main
et	doc_384045275284_item	2361900	et	3	main
saab	doc_384045275284_item	2361903	et	3	main
just	doc_384045275284_item	2361912	et	3	main
teha	doc_384045275284_item	2361822	et	3	main
ja	doc_384045275284_item	2361826	et	3	main
päevast	doc_384045275284_item	2361835	et	4	main
sulle	doc_384045275284_item	2361843	et	3	main
ja	doc_384045275284_item	2361845	et	3	main
sa	doc_384045275284_item	2361850	et	3	main
oma	doc_384045275284_item	2361852	et	4	main
on	doc_384045275284_item	2361858	et	4	main
sobiv	doc_384045275284_item	2361877	et	4	main
sest	doc_384045275284_item	2361878	et	4	main
paljud	doc_384045275284_item	2361879	et	3	main
annab	doc_384045275284_item	2361884	et	3	main
on	doc_384045275284_item	2361891	et	4	main
valisin	doc_384045275284_item	2361911	et	3	main
selle	doc_384045275284_item	2361913	et	4	main
ametit	doc_384045275284_item	2361914	et	3	main
kui	doc_384045275284_item	2361915	et	3	main
ausalt	doc_384045275284_item	2361916	et	4	main
ma	doc_384045275284_item	2361918	et	3	main
tahtsin	doc_384045275284_item	2361919	et	3	main
öelda	doc_384045275284_item	2361917	et	4	main
astuda	doc_384045275284_item	2361920	et	3	main
ehitusteaduskonda	doc_384045275284_item	2361921	et	4	main
hingele	doc_384045275284_item	2361926	et	4	main
linnugrippi	doc_392411160212_item	2361951	et	4	main
on	doc_392411160212_item	2361954	et	4	main
väike	doc_392411160212_item	2361956	et	4	main
ja	doc_392411160212_item	2361984	et	3	main
on	doc_392411160212_item	2361986	et	4	main
üllar	doc_392411160212_item	2361994	et	4	main
linnugripi	doc_392411160212_item	2362005	et	3	main
tegu	doc_392411160212_item	2362017	et	4	main
üksikute	doc_392411160212_item	2362018	et	4	main
inimesega	doc_392411160212_item	2362019	et	3	main
täpsustas	doc_392411160212_item	2362020	et	3	main
ja	doc_392411160212_item	2362030	et	3	main
valmistuvad	doc_392411160212_item	2362034	et	4	main
pandeemiline	doc_392411160212_item	2362035	et	3	main
viirus	doc_392411160212_item	2362036	et	4	main
pandeemiat	doc_392411160212_item	2362052	et	3	main
tänaseni	doc_392411160212_item	2362057	et	4	main
viirust	doc_392411160212_item	2362063	et	4	main
üle	doc_392411160212_item	2362076	et	3	main
kaasamakaasnema	doc_392411160212_item	2362085	et	4	main
ja	doc_392411160212_item	2362090	et	3	main
oht	doc_392411160212_item	2362093	et	3	main
tekkib	doc_392411160212_item	2362095	et	3	main
ringlusse	doc_392411160212_item	2362098	et	4	main
või	doc_392411160212_item	2362124	et	4	main
mitmes	doc_392411160212_item	2362125	et	4	main
omavahel	doc_392411160212_item	2362126	et	3	main
esinemaesindama	doc_392411160212_item	2362130	et	4	main
ning	doc_392411160212_item	2362135	et	3	main
mitmenädalase	doc_392411160212_item	2362137	et	4	main
ma	doc_392411160213_item	2362143	et	3	main
sõitsin	doc_392411160213_item	2362151	et	3	main
me	doc_392411160213_item	2362182	et	4	main
elame	doc_392411160213_item	2362183	et	3	main
mitte	doc_392411160213_item	2362184	et	3	main
linnas	doc_392411160213_item	2362185	et	4	main
aga	doc_392411160213_item	2362186	et	3	main
maal	doc_392411160213_item	2362187	et	4	main
palju	doc_392411160213_item	2362197	et	4	main
külas	doc_392411160213_item	2362207	et	3	main
ma	doc_392411160213_item	2362212	et	3	main
elus	doc_384045275284_item	2361863	et	4	main
sa	doc_384045275284_item	2361864	et	3	main
saad	doc_384045275284_item	2361865	et	4	main
teha	doc_384045275284_item	2361866	et	3	main
see	doc_384045275284_item	2361874	et	3	main
on	doc_384045275284_item	2361875	et	4	main
väga	doc_384045275284_item	2361876	et	3	main
käivad	doc_384045275284_item	2361881	et	4	main
võimalusi	doc_384045275284_item	2361886	et	3	main
suur	doc_384045275284_item	2361898	et	3	main
iga	doc_384045275284_item	2361901	et	4	main
leida	doc_384045275284_item	2361904	et	3	main
ma	doc_384045275284_item	2361910	et	3	main
minule	doc_384045275284_item	2361925	et	3	main
aga	doc_384045275284_item	2361928	et	3	main
ma	doc_384045275284_item	2361935	et	3	main
õppima	doc_384045275284_item	2361937	et	3	main
on	doc_392411160212_item	2361961	et	4	main
ilmuma	doc_392411160212_item	2361962	et	3	main
ilmunud	doc_392411160212_item	2361963	et	4	main
inimeselt	doc_392411160212_item	2361982	et	3	main
sellepärast	doc_392411160212_item	2361985	et	3	main
võimalik	doc_392411160212_item	2361987	et	3	main
vaid	doc_392411160212_item	2361988	et	3	main
üksikute	doc_392411160212_item	2361989	et	4	main
nakatumine	doc_392411160212_item	2361991	et	4	main
juhi	doc_392411160212_item	2361993	et	4	main
linnugrippi	doc_392411160212_item	2362010	et	4	main
peaks	doc_392411160212_item	2362012	et	4	main
eestis	doc_392411160212_item	2362013	et	3	main
juhtuma	doc_392411160212_item	2362014	et	4	main
siis	doc_392411160212_item	2362015	et	3	main
kaljumäe	doc_392411160212_item	2362023	et	3	main
kommentaaris	doc_392411160212_item	2362025	et	3	main
võib	doc_392411160212_item	2362037	et	3	main
tekkida	doc_392411160212_item	2362039	et	3	main
tavagripp	doc_392411160212_item	2362043	et	3	main
ühineda	doc_392411160212_item	2362045	et	3	main
tüvi	doc_392411160212_item	2362047	et	3	main
selleks	doc_392411160212_item	2362053	et	4	main
viirus	doc_392411160212_item	2362055	et	4	main
nimetatakse	doc_392411160212_item	2362067	et	3	main
suurt	doc_392411160212_item	2362069	et	3	main
levib	doc_392411160212_item	2362074	et	3	main
ulatuslikult	doc_392411160212_item	2362075	et	4	main
millega	doc_392411160212_item	2362084	et	3	main
inimeste	doc_392411160212_item	2362087	et	3	main
juhul	doc_392411160212_item	2362096	et	3	main
olukorda	doc_392411160212_item	2362121	et	4	main
seotud	doc_392411160212_item	2362128	et	4	main
25-50	doc_392411160212_item	2362133	et	2	main
kestvusega	doc_392411160212_item	2362138	et	4	main
olen	doc_392411160213_item	2362144	et	3	main
ma	doc_392411160213_item	2362147	et	3	main
ma	doc_392411160213_item	2362150	et	3	main
oli	doc_392411160213_item	2362160	et	3	main
mulle	doc_392411160213_item	2362190	et	4	main
seal	doc_392411160213_item	2362194	et	4	main
maal	doc_392411160213_item	2362195	et	4	main
ei	doc_392411160213_item	2362201	et	4	main
armasta	doc_392411160213_item	2362202	et	4	main
et	doc_392411160213_item	2362206	et	3	main
ja	doc_392411160213_item	2362211	et	3	main
aias	doc_392411160213_item	2362215	et	4	main
töötan	doc_392411160213_item	2362217	et	3	main
siin	doc_392411160213_item	2362221	et	4	main
me	doc_392411160213_item	2362227	et	4	main
mul	doc_392411160213_item	2362231	et	3	main
ole	doc_392411160213_item	2362233	et	4	main
soovi	doc_392411160213_item	2362234	et	4	main
õppida	doc_392411160213_item	2362235	et	3	main
omavahel	doc_392411160213_item	2362244	et	3	main
räägivad	doc_392411160213_item	2362246	et	3	main
keeles	doc_392411160213_item	2362248	et	4	main
ja	doc_392411160213_item	2362249	et	3	main
meeldi	doc_392411160213_item	2362253	et	4	main
minu	doc_392411160213_item	2362259	et	3	main
raha	doc_392411160213_item	2362264	et	4	main
teise	doc_392411160213_item	2362265	et	4	main
minema	doc_392411160213_item	2362266	et	3	main
siin	doc_392411160213_item	2362267	et	4	main
sobib	doc_392411160213_item	2362272	et	3	main
on	doc_384045275284_item	2361924	et	4	main
ma	doc_384045275284_item	2361929	et	3	main
konkursi	doc_384045275284_item	2361932	et	3	main
sest	doc_384045275284_item	2361938	et	4	main
valikut	doc_384045275284_item	2361940	et	3	main
nakatumise	doc_392411160212_item	2361952	et	4	main
väärinfo	doc_392411160212_item	2361964	et	4	main
mis	doc_392411160212_item	2361965	et	4	main
ütleb	doc_392411160212_item	2361966	et	3	main
et	doc_392411160212_item	2361967	et	3	main
linnugrippi	doc_392411160212_item	2361968	et	4	main
võib	doc_392411160212_item	2361969	et	3	main
nakatama	doc_392411160212_item	2361970	et	4	main
nakatuma	doc_392411160212_item	2361971	et	4	main
nakatuda	doc_392411160212_item	2361972	et	3	main
kuni	doc_392411160212_item	2361973	et	3	main
veerand	doc_392411160212_item	2361974	et	4	main
eesti	doc_392411160212_item	2361975	et	4	main
elanikest	doc_392411160212_item	2361976	et	3	main
linnugripi	doc_392411160212_item	2361977	et	3	main
tüvi	doc_392411160212_item	2361978	et	3	main
h5n1	doc_392411160212_item	2361979	et	4	main
ei	doc_392411160212_item	2361980	et	4	main
nakka	doc_392411160212_item	2361981	et	4	main
läbinud	doc_384045275284_item	2361931	et	4	main
mehaanikat	doc_384045275284_item	2361934	et	3	main
läksin	doc_384045275284_item	2361936	et	3	main
rohkem	doc_384045275284_item	2361939	et	4	main
tallinna	doc_384045275284_item	2361948	et	4	main
tehnikaülikoolis	doc_384045275284_item	2361949	et	4	main
harjutus	doc_392411160212_item	2361950	et	4	main
oht	doc_392411160212_item	2361953	et	3	main
jätkuvalt	doc_392411160212_item	2361955	et	4	main
02032006	doc_392411160212_item	2361957	et	2	main
tänases	doc_392411160212_item	2361958	et	3	main
eesti	doc_392411160212_item	2361959	et	4	main
päevalehes	doc_392411160212_item	2361960	et	3	main
inimeste	doc_392411160212_item	2361990	et	3	main
kaljumäe	doc_392411160212_item	2361995	et	3	main
juhtumeid	doc_392411160212_item	2362006	et	3	main
kui	doc_392411160212_item	2362008	et	3	main
on	doc_392411160212_item	2362016	et	4	main
rääkis	doc_392411160212_item	2362024	et	3	main
gripist	doc_392411160212_item	2362027	et	3	main
milleks	doc_392411160212_item	2362028	et	4	main
ennetavalt	doc_392411160212_item	2362032	et	4	main
tekkimatekitama	doc_392411160212_item	2362038	et	4	main
kui	doc_392411160212_item	2362040	et	3	main
ühinemaühendama	doc_392411160212_item	2362044	et	4	main
linnugripi	doc_392411160212_item	2362046	et	3	main
ei	doc_392411160212_item	2362049	et	4	main
tekkimatekitama	doc_392411160212_item	2362050	et	4	main
tekita	doc_392411160212_item	2362051	et	4	main
muteeruma	doc_392411160212_item	2362056	et	3	main
ole	doc_392411160212_item	2362059	et	4	main
tekkima	doc_392411160212_item	2362064	et	3	main
erakordselt	doc_392411160212_item	2362068	et	4	main
epideemiat	doc_392411160212_item	2362071	et	3	main
mis	doc_392411160212_item	2362072	et	4	main
levimalevitama	doc_392411160212_item	2362073	et	4	main
haarates	doc_392411160212_item	2362078	et	3	main
riike	doc_392411160212_item	2362080	et	3	main
kontinente	doc_392411160212_item	2362082	et	3	main
gripipandeemia	doc_392411160212_item	2362092	et	4	main
tekkimatekitama	doc_392411160212_item	2362094	et	4	main
inimesele	doc_392411160212_item	2361983	et	3	main
tervishoiuameti	doc_392411160212_item	2361992	et	3	main
2003	doc_392411160212_item	2362001	et	2	main
aastast	doc_392411160212_item	2362002	et	4	main
laboratoorselt	doc_392411160212_item	2362003	et	4	main
kinnitatud	doc_392411160212_item	2362004	et	4	main
173	doc_392411160212_item	2362007	et	2	main
nakatumine	doc_392411160212_item	2362011	et	4	main
kaljumäe	doc_392411160212_item	2362021	et	3	main
pandeemilisest	doc_392411160212_item	2362026	et	3	main
tervishoiuamet	doc_392411160212_item	2362029	et	3	main
sotsiaalministeerium	doc_392411160212_item	2362031	et	3	main
linnugripp	doc_392411160212_item	2362041	et	3	main
h5n1	doc_392411160212_item	2362048	et	4	main
peab	doc_392411160212_item	2362054	et	4	main
pandeemiaks	doc_392411160212_item	2362066	et	3	main
ning	doc_392411160212_item	2362083	et	3	main
haigestumine	doc_392411160212_item	2362089	et	4	main
kui	doc_392411160212_item	2362097	et	3	main
kus	doc_392411160212_item	2362122	et	3	main
ühes	doc_392411160212_item	2362123	et	4	main
esinevad	doc_392411160212_item	2362131	et	4	main
ning	doc_392411160212_item	2362136	et	3	main
gripipuhangud	doc_392411160212_item	2362139	et	3	main
essee	doc_392411160213_item	2362140	et	4	main
tuttavaks	doc_392411160213_item	2362142	et	4	main
praegu	doc_392411160213_item	2362146	et	3	main
tšuvašias	doc_392411160213_item	2362149	et	2	main
siia	doc_392411160213_item	2362152	et	4	main
kuud	doc_392411160213_item	2362154	et	4	main
tagasi	doc_392411160213_item	2362155	et	3	main
oma	doc_392411160213_item	2362156	et	4	main
abikaasaga	doc_392411160213_item	2362157	et	3	main
minu	doc_392411160213_item	2362158	et	3	main
abikaasa	doc_392411160213_item	2362159	et	4	main
tema	doc_392411160213_item	2362188	et	4	main
meeldi	doc_392411160213_item	2362192	et	4	main
on	doc_392411160213_item	2362196	et	4	main
töötada	doc_392411160213_item	2362203	et	3	main
väga	doc_392411160213_item	2362204	et	3	main
tore	doc_392411160213_item	2362205	et	3	main
ei	doc_392411160213_item	2362208	et	4	main
peres	doc_392411160213_item	2362238	et	3	main
vene	doc_392411160213_item	2362241	et	4	main
oma	doc_392411160213_item	2362247	et	4	main
ei	doc_392411160213_item	2362252	et	4	main
rahvaraha	doc_392411160213_item	2362255	et	4	main
on	doc_392411160213_item	2362256	et	4	main
rublad	doc_392411160213_item	2362257	et	3	main
ja	doc_392411160213_item	2362258	et	3	main
on	doc_392411160213_item	2362268	et	4	main
hea	doc_392411160213_item	2362269	et	4	main
ma	doc_392411160213_item	2362278	et	3	main
siin	doc_392411160213_item	2362282	et	4	main
tore	doc_392411160213_item	2362284	et	3	main
mulle	doc_392411160213_item	2362287	et	4	main
maitsevad	doc_392411160213_item	2362288	et	4	main
lup	doc_392411160213_item	2362290	et	4	main
on	doc_392411160213_item	2362305	et	4	main
et	doc_392411160213_item	2362309	et	3	main
ma	doc_392411160213_item	2362325	et	3	main
aga	doc_392411160213_item	2362334	et	3	main
ma	doc_392411160213_item	2362336	et	3	main
linna	doc_392411160213_item	2362338	et	4	main
kirjutan	doc_392411160213_item	2362342	et	3	main
sõpradele	doc_392411160213_item	2362345	et	3	main
saadan	doc_392411160213_item	2362347	et	4	main
estisse	doc_392411160213_item	2362352	et	4	main
ja	doc_392411160213_item	2362353	et	3	main
ja	doc_392411160213_item	2362368	et	3	main
uurimuse	doc_392411160214_item	2362375	et	3	main
all	doc_392411160214_item	2362423	et	3	main
alates	doc_392411160212_item	2362000	et	3	main
inimese	doc_392411160212_item	2362009	et	4	main
üllar	doc_392411160212_item	2362022	et	4	main
valmistamavalmistuma	doc_392411160212_item	2362033	et	4	main
ja	doc_392411160212_item	2362042	et	3	main
ei	doc_392411160212_item	2362058	et	4	main
maailmas	doc_392411160212_item	2362060	et	3	main
pandeemilise	doc_392411160212_item	2362061	et	3	main
gripi	doc_392411160212_item	2362062	et	3	main
tekkinud	doc_392411160212_item	2362065	et	4	main
gripi	doc_392411160212_item	2362070	et	3	main
riigipiiride	doc_392411160212_item	2362077	et	3	main
paljusid	doc_392411160212_item	2362079	et	3	main
ja	doc_392411160212_item	2362081	et	3	main
kaasneb	doc_392411160212_item	2362086	et	3	main
kõrge	doc_392411160212_item	2362088	et	4	main
suremus	doc_392411160212_item	2362091	et	3	main
ilmub	doc_392411160212_item	2362099	et	3	main
uus	doc_392411160212_item	2362100	et	3	main
mitte	doc_392411160212_item	2362102	et	3	main
varem	doc_392411160212_item	2362101	et	4	main
esinemaesindama	doc_392411160212_item	2362103	et	4	main
esinenud	doc_392411160212_item	2362104	et	4	main
gripiviirus	doc_392411160212_item	2362105	et	4	main
viirus	doc_392411160212_item	2362106	et	4	main
levimalevitaam	doc_392411160212_item	2362107	et	4	main
levib	doc_392411160212_item	2362108	et	3	main
inimeselt-inimesele	doc_392411160212_item	2362110	et	3	main
ja	doc_392411160212_item	2362111	et	3	main
uus	doc_392411160212_item	2362112	et	3	main
viirus	doc_392411160212_item	2362113	et	4	main
aktiivselt	doc_392411160212_item	2362109	et	4	main
on	doc_392411160212_item	2362114	et	4	main
kõrge	doc_392411160212_item	2362115	et	4	main
suremusega	doc_392411160212_item	2362116	et	3	main
gripipandeemiaks	doc_392411160212_item	2362117	et	3	main
saab	doc_392411160212_item	2362118	et	3	main
pidada	doc_392411160212_item	2362119	et	4	main
sellist	doc_392411160212_item	2362120	et	4	main
siduma	doc_392411160212_item	2362127	et	3	main
suuremad	doc_392411160212_item	2362132	et	4	main
haigusjuhuga	doc_392411160212_item	2362134	et	3	main
saame	doc_392411160213_item	2362141	et	4	main
elan	doc_392411160213_item	2362148	et	3	main
4	doc_392411160213_item	2362153	et	2	main
ei	doc_392411160213_item	2362191	et	4	main
aga	doc_392411160213_item	2362199	et	3	main
ma	doc_392411160213_item	2362200	et	3	main
ole	doc_392411160213_item	2362209	et	4	main
ema	doc_392411160213_item	2362214	et	4	main
ma	doc_392411160213_item	2362216	et	3	main
inimesed	doc_392411160213_item	2362222	et	3	main
räägivad	doc_392411160213_item	2362223	et	3	main
keeles	doc_392411160213_item	2362225	et	4	main
ajuti	doc_392411160213_item	2362229	et	4	main
ei	doc_392411160213_item	2362232	et	4	main
nende	doc_392411160213_item	2362236	et	4	main
keeles	doc_392411160213_item	2362242	et	4	main
mulle	doc_392411160213_item	2362250	et	4	main
tšuvašias	doc_392411160213_item	2362254	et	2	main
oli	doc_392411160213_item	2362261	et	3	main
piirkonnas	doc_392411160212_item	2362129	et	4	main
eesnimi	doc_392411160213_item	2362145	et	3	main
komandeeritud	doc_392411160213_item	2362161	et	4	main
töölt	doc_392411160213_item	2362162	et	3	main
see	doc_392411160213_item	2362163	et	3	main
on	doc_392411160213_item	2362165	et	4	main
minu	doc_392411160213_item	2362166	et	3	main
abikaasa	doc_392411160213_item	2362167	et	4	main
riik	doc_392411160213_item	2362164	et	3	main
kodumaa	doc_392411160213_item	2362168	et	4	main
ma	doc_392411160213_item	2362169	et	3	main
nagu	doc_392411160213_item	2362170	et	3	main
dekabristi	doc_392411160213_item	2362171	et	4	main
naine	doc_392411160213_item	2362172	et	3	main
sõitsin	doc_392411160213_item	2362173	et	3	main
temaga	doc_392411160213_item	2362174	et	3	main
siin	doc_392411160213_item	2362175	et	4	main
peame	doc_392411160213_item	2362177	et	4	main
elama	doc_392411160213_item	2362178	et	3	main
me	doc_392411160213_item	2362176	et	4	main
veel	doc_392411160213_item	2362179	et	4	main
5	doc_392411160213_item	2362180	et	2	main
kuud	doc_392411160213_item	2362181	et	4	main
emaga	doc_392411160213_item	2362189	et	3	main
elada	doc_392411160213_item	2362193	et	3	main
tööd	doc_392411160213_item	2362198	et	4	main
koduloomi	doc_392411160213_item	2362210	et	4	main
abistan	doc_392411160213_item	2362213	et	3	main
vene	doc_392411160213_item	2362218	et	4	main
keele	doc_392411160213_item	2362219	et	4	main
repetiitorina	doc_392411160213_item	2362220	et	3	main
olime	doc_392411160213_item	2362228	et	3	main
ja	doc_392411160213_item	2362230	et	3	main
keelt	doc_392411160213_item	2362237	et	4	main
me	doc_392411160213_item	2362239	et	4	main
suhtleme	doc_392411160213_item	2362240	et	3	main
nad	doc_392411160213_item	2362245	et	3	main
raske	doc_392411160213_item	2362262	et	4	main
mulle	doc_392411160213_item	2362273	et	4	main
kui	doc_392411160213_item	2362274	et	3	main
30	doc_392411160213_item	2362276	et	2	main
hup	doc_392411160213_item	2362289	et	4	main
koogid	doc_392411160213_item	2362292	et	4	main
vene	doc_392411160213_item	2362295	et	4	main
kahjuks	doc_392411160213_item	2362297	et	4	main
kallid	doc_392411160213_item	2362306	et	3	main
ei	doc_392411160213_item	2362311	et	4	main
elan	doc_392411160213_item	2362322	et	3	main
üksildaselt	doc_392411160213_item	2362324	et	4	main
püüan	doc_392411160213_item	2362331	et	3	main
kirju	doc_392411160213_item	2362343	et	4	main
suvel	doc_392411160213_item	2362349	et	3	main
tuleme	doc_392411160213_item	2362351	et	3	main
uuesti	doc_392411160213_item	2362354	et	3	main
õnnelik	doc_392411160213_item	2362359	et	3	main
essee	doc_392411160214_item	2362370	et	4	main
viis	doc_392411160214_item	2362373	et	4	main
istuv	doc_392411160214_item	2362404	et	4	main
nad	doc_392411160214_item	2362406	et	3	main
istuvad	doc_392411160214_item	2362407	et	4	main
kodus	doc_392411160214_item	2362411	et	4	main
diivanil	doc_392411160214_item	2362412	et	3	main
paljudel	doc_392411160214_item	2362413	et	3	main
on	doc_392411160214_item	2362414	et	4	main
halvad	doc_392411160214_item	2362415	et	4	main
taeva	doc_392411160214_item	2362422	et	3	main
lisama	doc_392411160214_item	2362427	et	3	main
ebatervislikku	doc_392411160214_item	2362428	et	4	main
ja	doc_392411160214_item	2362429	et	3	main
ebaregulaarset	doc_392411160214_item	2362430	et	3	main
toitumist	doc_392411160214_item	2362431	et	4	main
nad	doc_392411160214_item	2362432	et	3	main
võivad	doc_392411160214_item	2362433	et	4	main
kuiva	doc_392411160214_item	2362443	et	4	main
ainult	doc_392411160214_item	2362449	et	4	main
kriililine	doc_392411160214_item	2362454	et	4	main
eluiga	doc_392411160214_item	2362467	et	4	main
ületöötamine	doc_392411160214_item	2362469	et	3	main
ebatervisliku	doc_392411160214_item	2362480	et	3	main
aga	doc_392411160214_item	2362484	et	3	main
olen	doc_392411160214_item	2362485	et	3	main
nõus	doc_392411160214_item	2362488	et	4	main
mehed	doc_392411160214_item	2362489	et	3	main
tunnevad	doc_392411160214_item	2362490	et	3	main
end	doc_392411160214_item	2362491	et	4	main
kohustatuks	doc_392411160214_item	2362492	et	4	main
pere	doc_392411160214_item	2362495	et	4	main
ei	doc_392411160214_item	2362501	et	4	main
on	doc_392411160214_item	2362512	et	4	main
et	doc_392411160214_item	2362522	et	3	main
tervist	doc_392411160214_item	2362524	et	4	main
inimesed	doc_392411160214_item	2362529	et	3	main
saa	doc_392411160214_item	2362531	et	4	main
aru	doc_392411160214_item	2362532	et	4	main
teine	doc_392411160214_item	2362533	et	3	main
kui	doc_392411160214_item	2362540	et	3	main
ohus	doc_392411160214_item	2362553	et	3	main
kohal	doc_392411160214_item	2362556	et	4	main
liigne	doc_392411160214_item	2362558	et	3	main
meestel	doc_392411160214_item	2362561	et	4	main
veres	doc_392411160214_item	2362563	et	3	main
neile	doc_392411160214_item	2362564	et	4	main
meeldib	doc_392411160214_item	2362565	et	3	main
ohusetunne	doc_392411160214_item	2362566	et	4	main
see	doc_392411160214_item	2362567	et	3	main
oma	doc_392411160213_item	2362224	et	4	main
tšuvašias	doc_392411160213_item	2362226	et	2	main
aga	doc_392411160213_item	2362243	et	3	main
see	doc_392411160213_item	2362251	et	3	main
jaoks	doc_392411160213_item	2362260	et	4	main
kliima	doc_392411160213_item	2362270	et	4	main
ei	doc_392411160213_item	2362279	et	4	main
on	doc_392411160213_item	2362283	et	4	main
ei	doc_392411160213_item	2362299	et	4	main
eestisse	doc_392411160213_item	2362304	et	4	main
eesti	doc_392411160213_item	2362313	et	4	main
side	doc_392411160213_item	2362314	et	4	main
eestis	doc_392411160213_item	2362315	et	3	main
jäid	doc_392411160213_item	2362316	et	4	main
vanemad	doc_392411160213_item	2362317	et	4	main
sõbrad	doc_392411160213_item	2362318	et	3	main
ja	doc_392411160213_item	2362319	et	3	main
koer	doc_392411160213_item	2362320	et	3	main
ühest	doc_392411160213_item	2362263	et	4	main
ta	doc_392411160213_item	2362271	et	4	main
tundsin	doc_392411160213_item	2362280	et	3	main
ja	doc_392411160213_item	2362291	et	3	main
ja	doc_392411160213_item	2362293	et	3	main
pirukaid	doc_392411160213_item	2362294	et	3	main
ahjast	doc_392411160213_item	2362296	et	4	main
ole	doc_392411160213_item	2362300	et	4	main
ja	doc_392411160213_item	2362302	et	3	main
helistamine	doc_392411160213_item	2362303	et	4	main
see	doc_392411160213_item	2362307	et	3	main
tähendab	doc_392411160213_item	2362308	et	3	main
mul	doc_392411160213_item	2362310	et	3	main
kohvikusse	doc_392411160213_item	2362340	et	4	main
oma	doc_392411160213_item	2362344	et	4	main
ja	doc_392411160213_item	2362346	et	3	main
fotot	doc_392411160213_item	2362348	et	3	main
olen	doc_392411160213_item	2362356	et	3	main
ja	doc_392411160213_item	2362358	et	3	main
et	doc_392411160213_item	2362360	et	3	main
olen	doc_392411160213_item	2362362	et	3	main
kodus	doc_392411160213_item	2362364	et	4	main
oma	doc_392411160213_item	2362365	et	4	main
perega	doc_392411160213_item	2362366	et	3	main
sõpradega	doc_392411160213_item	2362367	et	3	main
mille	doc_392411160214_item	2362376	et	3	main
eluviis	doc_392411160214_item	2362405	et	3	main
tööl	doc_392411160214_item	2362408	et	3	main
autos	doc_392411160214_item	2362409	et	3	main
ja	doc_392411160214_item	2362410	et	3	main
näiteks	doc_392411160214_item	2362417	et	4	main
tehases	doc_392411160214_item	2362419	et	3	main
avara	doc_392411160214_item	2362421	et	3	main
üks	doc_392411160214_item	2362435	et	3	main
ja	doc_392411160214_item	2362438	et	3	main
käivad	doc_392411160214_item	2362448	et	4	main
olukord	doc_392411160214_item	2362455	et	3	main
kohal	doc_392411160214_item	2362457	et	4	main
meeste	doc_392411160214_item	2362466	et	4	main
ja	doc_392411160214_item	2362470	et	3	main
on	doc_392411160214_item	2362479	et	4	main
osa	doc_392411160214_item	2362482	et	4	main
täiesti	doc_392411160214_item	2362487	et	3	main
ja	doc_392411160214_item	2362496	et	3	main
süüdistavad	doc_392411160214_item	2362497	et	4	main
kui	doc_392411160214_item	2362499	et	3	main
lähe	doc_392411160214_item	2362502	et	4	main
töötavad	doc_392411160214_item	2362505	et	4	main
töökohtadel	doc_392411160214_item	2362507	et	3	main
ilma	doc_392411160214_item	2362508	et	4	main
puhkuseta	doc_392411160214_item	2362509	et	3	main
ja	doc_392411160214_item	2362510	et	3	main
peresuhted	doc_392411160214_item	2362527	et	3	main
mõnikord	doc_392411160214_item	2362528	et	3	main
ei	doc_392411160214_item	2362530	et	4	main
teisest	doc_392411160214_item	2362534	et	4	main
ja	doc_392411160214_item	2362535	et	3	main
pereelu	doc_392411160214_item	2362536	et	4	main
see	doc_392411160214_item	2362543	et	3	main
meeste	doc_392411160214_item	2362545	et	4	main
aga	doc_392411160214_item	2362547	et	3	main
naiste	doc_392411160214_item	2362548	et	3	main
eluiga	doc_392411160214_item	2362549	et	4	main
riskimine	doc_392411160214_item	2362559	et	4	main
midagi	doc_392411160214_item	2362604	et	4	main
oli	doc_392411160213_item	2362275	et	3	main
siis	doc_392411160213_item	2362277	et	3	main
kummi	doc_392411160213_item	2362281	et	4	main
rahvaköök	doc_392411160213_item	2362285	et	3	main
eriti	doc_392411160213_item	2362286	et	3	main
kodus	doc_392411160213_item	2362298	et	4	main
interneti	doc_392411160213_item	2362301	et	4	main
ole	doc_392411160213_item	2362312	et	4	main
ma	doc_392411160213_item	2362321	et	3	main
väga	doc_392411160213_item	2362323	et	3	main
oma	doc_392411160213_item	2362327	et	4	main
järele	doc_392411160213_item	2362329	et	4	main
emale	doc_392411160213_item	2362333	et	3	main
puhkepäevadel	doc_392411160213_item	2362335	et	3	main
ma	doc_392411160213_item	2362341	et	3	main
me	doc_392411160213_item	2362350	et	4	main
rõõmus	doc_392411160213_item	2362357	et	4	main
ma	doc_392411160213_item	2362361	et	3	main
oma	doc_392411160213_item	2362363	et	4	main
ajaleht	doc_392411160214_item	2362371	et	3	main
töötingimused	doc_392411160214_item	2362416	et	3	main
ehitamises	doc_392411160214_item	2362424	et	4	main
peab	doc_392411160214_item	2362426	et	4	main
päevas	doc_392411160214_item	2362437	et	3	main
juures	doc_392411160214_item	2362446	et	4	main
kui	doc_392411160214_item	2362451	et	3	main
juba	doc_392411160214_item	2362453	et	3	main
vastajaid	doc_392411160214_item	2362462	et	4	main
kes	doc_392411160214_item	2362463	et	4	main
arvas	doc_392411160214_item	2362464	et	3	main
et	doc_392411160214_item	2362465	et	3	main
tubakaga	doc_392411160214_item	2362472	et	3	main
arvates	doc_392411160214_item	2362474	et	4	main
ja	doc_392411160214_item	2362476	et	3	main
tubaka	doc_392411160214_item	2362477	et	3	main
ületöötamisega	doc_392411160214_item	2362483	et	3	main
ma	doc_392411160214_item	2362486	et	3	main
oma	doc_392411160214_item	2362494	et	4	main
end	doc_392411160214_item	2362498	et	4	main
pidevalt	doc_392411160214_item	2362511	et	4	main
keerulised	doc_392411160214_item	2362526	et	4	main
ei	doc_392411160214_item	2362537	et	4	main
käi	doc_392411160214_item	2362538	et	4	main
tahaks	doc_392411160214_item	2362541	et	3	main
lühendab	doc_392411160214_item	2362544	et	3	main
viimasel	doc_392411160214_item	2362555	et	3	main
on	doc_392411160214_item	2362557	et	4	main
riskimine	doc_392411160214_item	2362560	et	4	main
mitte	doc_392411160214_item	2362603	et	3	main
ei	doc_392411160214_item	2362605	et	4	main
saa	doc_392411160214_item	2362606	et	4	main
kriipsutada	doc_392411160214_item	2362607	et	3	main
igatsen	doc_392411160213_item	2362326	et	3	main
kutsika	doc_392411160213_item	2362328	et	3	main
ma	doc_392411160213_item	2362330	et	3	main
helistada	doc_392411160213_item	2362332	et	3	main
sõidan	doc_392411160213_item	2362337	et	3	main
interneti	doc_392411160213_item	2362339	et	4	main
ma	doc_392411160213_item	2362355	et	3	main
koeraga	doc_392411160213_item	2362369	et	3	main
postimees	doc_392411160214_item	2362372	et	4	main
läbi	doc_392411160214_item	2362374	et	4	main
käigus	doc_392411160214_item	2362377	et	4	main
selgitas	doc_392411160214_item	2362378	et	3	main
välja	doc_392411160214_item	2362379	et	4	main
mis	doc_392411160214_item	2362380	et	4	main
lühendab	doc_392411160214_item	2362381	et	3	main
eesti	doc_392411160214_item	2362382	et	4	main
meeste	doc_392411160214_item	2362383	et	4	main
eluiga	doc_392411160214_item	2362384	et	4	main
kõige	doc_392411160214_item	2362385	et	4	main
suurem	doc_392411160214_item	2362386	et	4	main
protsent	doc_392411160214_item	2362387	et	3	main
inimestest	doc_392411160214_item	2362388	et	3	main
ütles	doc_392411160214_item	2362389	et	3	main
et	doc_392411160214_item	2362390	et	3	main
meeste	doc_392411160214_item	2362391	et	4	main
tervist	doc_392411160214_item	2362392	et	4	main
kahjustavad	doc_392411160214_item	2362393	et	4	main
kõigepealt	doc_392411160214_item	2362394	et	3	main
ebatervislikud	doc_392411160214_item	2362395	et	3	main
eluviisid	doc_392411160214_item	2362396	et	3	main
meie	doc_392411160214_item	2362397	et	4	main
mehed	doc_392411160214_item	2362398	et	3	main
vähe	doc_392411160214_item	2362399	et	3	main
liiguvad	doc_392411160214_item	2362400	et	3	main
neil	doc_392411160214_item	2362401	et	4	main
on	doc_392411160214_item	2362402	et	4	main
peamiselt	doc_392411160214_item	2362403	et	4	main
mürgitusainetega	doc_392411160214_item	2362418	et	3	main
või	doc_392411160214_item	2362420	et	4	main
süüa	doc_392411160214_item	2362434	et	3	main
söövad	doc_392411160214_item	2362439	et	4	main
palju	doc_392411160214_item	2362440	et	4	main
rasvast	doc_392411160214_item	2362441	et	4	main
ja	doc_392411160214_item	2362442	et	3	main
aga	doc_392411160214_item	2362447	et	3	main
on	doc_392411160214_item	2362452	et	4	main
eluviisi	doc_392411160214_item	2362481	et	4	main
kindlustada	doc_392411160214_item	2362493	et	3	main
see	doc_392411160214_item	2362500	et	3	main
mitmel	doc_392411160214_item	2362506	et	4	main
arvamus	doc_392411160214_item	2362521	et	3	main
meeste	doc_392411160214_item	2362523	et	4	main
kahjustavad	doc_392411160214_item	2362525	et	4	main
nii	doc_392411160214_item	2362539	et	3	main
eluiga	doc_392411160214_item	2362546	et	4	main
selles	doc_392411160214_item	2362550	et	4	main
situatsioonis	doc_392411160214_item	2362551	et	3	main
on	doc_392411160214_item	2362552	et	4	main
ka	doc_392411160214_item	2362554	et	3	main
välja	doc_392411160214_item	2362608	et	4	main
siia	doc_392411160214_item	2362425	et	4	main
kord	doc_392411160214_item	2362436	et	4	main
toitu	doc_392411160214_item	2362444	et	4	main
arsti	doc_392411160214_item	2362445	et	4	main
siis	doc_392411160214_item	2362450	et	3	main
teisel	doc_392411160214_item	2362456	et	4	main
on	doc_392411160214_item	2362458	et	4	main
kaks	doc_392411160214_item	2362459	et	3	main
suurt	doc_392411160214_item	2362460	et	3	main
rühma	doc_392411160214_item	2362461	et	4	main
lühendavad	doc_392411160214_item	2362468	et	4	main
alkohol	doc_392411160214_item	2362471	et	3	main
minu	doc_392411160214_item	2362473	et	3	main
alkoholi	doc_392411160214_item	2362475	et	4	main
tarvimine	doc_392411160214_item	2362478	et	4	main
hästi	doc_392411160214_item	2362503	et	3	main
mõned	doc_392411160214_item	2362504	et	3	main
stressi	doc_392411160214_item	2362513	et	4	main
all	doc_392411160214_item	2362514	et	3	main
tunnevad	doc_392411160214_item	2362515	et	3	main
end	doc_392411160214_item	2362516	et	4	main
väsinutena	doc_392411160214_item	2362517	et	4	main
kolmal	doc_392411160214_item	2362518	et	4	main
kohal	doc_392411160214_item	2362519	et	4	main
on	doc_392411160214_item	2362520	et	4	main
muidugi	doc_392411160214_item	2362542	et	4	main
on	doc_392411160214_item	2362562	et	4	main
adrenaliini	doc_392411160214_item	2362570	et	4	main
nad	doc_392411160214_item	2362571	et	3	main
tihti	doc_392411160214_item	2362572	et	3	main
sõidavad	doc_392411160214_item	2362573	et	3	main
autoga	doc_392411160214_item	2362574	et	3	main
väga	doc_392411160214_item	2362575	et	3	main
kiiresti	doc_392411160214_item	2362576	et	3	main
valitavad	doc_392411160214_item	2362577	et	4	main
seotud	doc_392411160214_item	2362578	et	4	main
ohuga	doc_392411160214_item	2362579	et	3	main
tööd	doc_392411160214_item	2362580	et	4	main
riskivad	doc_392411160214_item	2362581	et	4	main
oma	doc_392411160214_item	2362582	et	4	main
varaga	doc_392411160214_item	2362583	et	3	main
kui	doc_392411160214_item	2362584	et	3	main
alustavad	doc_392411160214_item	2362585	et	4	main
uut	doc_392411160214_item	2362586	et	3	main
äri	doc_392411160214_item	2362587	et	4	main
vastused	doc_392411160214_item	2362589	et	3	main
on	doc_392411160214_item	2362590	et	4	main
kõik	doc_392411160214_item	2362588	et	4	main
õilased	doc_392411160214_item	2362591	et	4	main
ma	doc_392411160214_item	2362592	et	3	main
ei	doc_392411160214_item	2362593	et	4	main
saa	doc_392411160214_item	2362594	et	4	main
öelda	doc_392411160214_item	2362595	et	4	main
mida	doc_392411160214_item	2362596	et	4	main
veel	doc_392411160214_item	2362597	et	4	main
võib	doc_392411160214_item	2362598	et	3	main
annab	doc_392411160214_item	2362568	et	3	main
lisa	doc_392411160214_item	2362569	et	4	main
põhjustele	doc_392411160214_item	2362601	et	3	main
üle	doc_392411160216_item	2362866	et	3	main
ei	doc_392411160216_item	2362868	et	4	main
huvita	doc_392411160216_item	2362869	et	4	main
halba	doc_392411160216_item	2362876	et	4	main
järele	doc_392411160216_item	2362878	et	4	main
prügihoidla	doc_392411160216_item	2362884	et	4	main
õpilased	doc_392411160216_item	2362896	et	3	main
on	doc_392411160217_item	2362922	et	4	main
kaupluses	doc_392411160217_item	2362927	et	3	main
ta	doc_392411160217_item	2362934	et	4	main
vanni	doc_392411160217_item	2362936	et	4	main
pastaga	doc_392411160217_item	2362937	et	3	main
pastaga	doc_392411160217_item	2362938	et	3	main
firma	doc_392411160217_item	2362951	et	4	main
on	doc_392411160217_item	2362952	et	4	main
4	doc_392411160217_item	2362955	et	2	main
puhastaval	doc_392411160217_item	2362960	et	4	main
tänapäeval	doc_392411160217_item	2362984	et	3	main
väga	doc_392411160217_item	2362990	et	3	main
essee	doc_392411160218_item	2362992	et	4	main
rahastama	doc_392411160218_item	2362999	et	4	main
rahastaksin	doc_392411160218_item	2363003	et	4	main
puhastamist	doc_392411160218_item	2363005	et	4	main
et	doc_392411160218_item	2363009	et	3	main
täis	doc_392411160218_item	2363012	et	4	main
meie	doc_392411160218_item	2363014	et	4	main
keemilised	doc_392411160218_item	2363019	et	4	main
seda	doc_392411160218_item	2363024	et	3	main
reklaamide	doc_392411160218_item	2363029	et	3	main
et	doc_392411160218_item	2363037	et	3	main
olen	doc_392411160218_item	2363046	et	3	main
võivad	doc_392411160218_item	2363052	et	4	main
läbiviimise	doc_392411160218_item	2363062	et	3	main
lisada	doc_392411160214_item	2362599	et	3	main
sellele	doc_392411160214_item	2362600	et	4	main
ja	doc_392411160214_item	2362602	et	3	main
inimeste	doc_392411160216_item	2362865	et	3	main
uue	doc_392411160216_item	2362882	et	3	main
hoiduma	doc_392411160216_item	2362888	et	3	main
olev	doc_392411160217_item	2362928	et	4	main
suur	doc_392411160217_item	2362932	et	3	main
hüürib	doc_392411160217_item	2362935	et	4	main
hüüriv	doc_392411160217_item	2362940	et	4	main
on	doc_392411160217_item	2362942	et	4	main
väga	doc_392411160217_item	2362953	et	3	main
populaarne	doc_392411160217_item	2362954	et	3	main
šaampoon	doc_392411160217_item	2362956	et	2	main
5	doc_392411160217_item	2362965	et	2	main
inimese	doc_392411160217_item	2362968	et	4	main
meigivahendid	doc_392411160217_item	2362973	et	3	main
müüakse	doc_392411160217_item	2362974	et	3	main
kaupluses	doc_392411160217_item	2362976	et	3	main
palju	doc_392411160217_item	2362981	et	4	main
aineid	doc_392411160217_item	2362983	et	3	main
kodukeemilised	doc_392411160217_item	2362987	et	4	main
milliseid	doc_392411160218_item	2362997	et	3	main
kõigepealt	doc_392411160218_item	2363001	et	3	main
veekogude	doc_392411160218_item	2363004	et	3	main
olen	doc_392411160218_item	2363006	et	3	main
vesi	doc_392411160218_item	2363011	et	4	main
ohte	doc_392411160218_item	2363013	et	4	main
tervisele	doc_392411160218_item	2363015	et	3	main
ma	doc_392411160218_item	2363025	et	3	main
kindel	doc_392411160218_item	2363027	et	3	main
on	doc_392411160218_item	2363035	et	4	main
inimesed	doc_392411160218_item	2363038	et	3	main
mõlgutama	doc_392411160218_item	2363041	et	4	main
nende	doc_392411160216_item	2362864	et	4	main
keskkonda	doc_392411160216_item	2362872	et	4	main
haiseb	doc_392411160216_item	2362875	et	3	main
toidu	doc_392411160216_item	2362877	et	3	main
raha	doc_392411160216_item	2362879	et	4	main
puudus	doc_392411160216_item	2362880	et	4	main
takistab	doc_392411160216_item	2362881	et	3	main
keskkonna	doc_392411160216_item	2362889	et	3	main
sõltub	doc_392411160216_item	2362893	et	3	main
nende	doc_392411160216_item	2362894	et	4	main
tervis	doc_392411160216_item	2362895	et	3	main
kauplustes	doc_392411160217_item	2362921	et	4	main
suur	doc_392411160217_item	2362923	et	3	main
harjutus	doc_392411160216_item	2362861	et	4	main
ma	doc_392411160216_item	2362862	et	3	main
elu	doc_392411160216_item	2362871	et	4	main
pühkmehunnik	doc_392411160216_item	2362874	et	4	main
kaasaegse	doc_392411160216_item	2362883	et	3	main
inimesed	doc_392411160216_item	2362886	et	3	main
sest	doc_392411160216_item	2362891	et	4	main
sellest	doc_392411160216_item	2362892	et	4	main
nõudpesuvahendite	doc_392411160217_item	2362929	et	4	main
on	doc_392411160217_item	2362931	et	4	main
3	doc_392411160217_item	2362944	et	2	main
puhastab	doc_392411160217_item	2362957	et	3	main
juukseid	doc_392411160217_item	2362959	et	3	main
on	doc_392411160217_item	2362962	et	4	main
meigivahendid	doc_392411160217_item	2362966	et	3	main
inimese	doc_392411160217_item	2362970	et	4	main
igas	doc_392411160217_item	2362975	et	3	main
on	doc_392411160217_item	2362989	et	4	main
erinevad	doc_392411160217_item	2362991	et	4	main
kui	doc_392411160218_item	2362993	et	3	main
mul	doc_392411160218_item	2362994	et	3	main
raamatutest	doc_392411160218_item	2363008	et	4	main
vees	doc_392411160218_item	2363017	et	3	main
on	doc_392411160218_item	2363020	et	4	main
et	doc_392411160218_item	2363028	et	3	main
trükkimist	doc_392411160218_item	2363030	et	4	main
rahastatud	doc_392411160218_item	2363033	et	4	main
oluline	doc_392411160218_item	2363034	et	4	main
tihti	doc_392411160218_item	2363040	et	3	main
meie	doc_392411160218_item	2363043	et	4	main
keskkonnast	doc_392411160218_item	2363044	et	4	main
ma	doc_392411160218_item	2363045	et	3	main
veendunud	doc_392411160218_item	2363047	et	4	main
loodust	doc_392411160218_item	2363051	et	4	main
olulisel	doc_392411160218_item	2363056	et	4	main
eesti	doc_392411160221_item	2363294	et	4	main
käsitlen	doc_392411160221_item	2363307	et	3	main
elukeskkond	doc_392411160221_item	2363312	et	3	main
ma	doc_392411160221_item	2363314	et	3	main
jääta	doc_392411160221_item	2363316	et	4	main
imestan	doc_392411160216_item	2362863	et	3	main
kes	doc_392411160216_item	2362867	et	4	main
meie	doc_392411160216_item	2362870	et	4	main
vana	doc_392411160216_item	2362873	et	4	main
ehitamisest	doc_392411160216_item	2362885	et	4	main
peavad	doc_392411160216_item	2362887	et	4	main
eest	doc_392411160216_item	2362890	et	4	main
olid	doc_392411160216_item	2362897	et	4	main
väsinud	doc_392411160216_item	2362898	et	4	main
kevade	doc_392411160216_item	2362899	et	4	main
koristamisest	doc_392411160216_item	2362900	et	4	main
vanas	doc_392411160216_item	2362901	et	3	main
pargis	doc_392411160216_item	2362902	et	3	main
olen	doc_392411160216_item	2362903	et	3	main
tüdinenud	doc_392411160216_item	2362904	et	4	main
keskkonnapuhastamises	doc_392411160216_item	2362905	et	3	main
projektis	doc_392411160216_item	2362906	et	3	main
osalemast	doc_392411160216_item	2362907	et	3	main
ei	doc_392411160216_item	2362909	et	4	main
me	doc_392411160216_item	2362908	et	4	main
tohi	doc_392411160216_item	2362910	et	4	main
mingil	doc_392411160216_item	2362911	et	4	main
juhut	doc_392411160216_item	2362912	et	4	main
puhas	doc_392411160216_item	2362913	et	3	main
keskkond	doc_392411160216_item	2362914	et	3	main
projektile	doc_392411160216_item	2362915	et	3	main
minemata	doc_392411160216_item	2362916	et	4	main
jätta	doc_392411160216_item	2362917	et	3	main
harjutus	doc_392411160217_item	2362918	et	4	main
1	doc_392411160217_item	2362919	et	2	main
tänapäeval	doc_392411160217_item	2362920	et	3	main
valik	doc_392411160217_item	2362925	et	3	main
tänapäeval	doc_392411160217_item	2362926	et	3	main
vanni	doc_392411160217_item	2362939	et	4	main
nõudpesuvahendite	doc_392411160217_item	2362924	et	4	main
valik	doc_392411160217_item	2362930	et	3	main
2	doc_392411160217_item	2362933	et	2	main
taivor	doc_392411160217_item	2362941	et	4	main
väsinud	doc_392411160217_item	2362943	et	4	main
reklaamib	doc_392411160217_item	2362946	et	3	main
kauba	doc_392411160217_item	2362948	et	3	main
kauba	doc_392411160217_item	2362949	et	3	main
juukseid	doc_392411160217_item	2362958	et	3	main
šampoonil	doc_392411160217_item	2362961	et	2	main
hea	doc_392411160217_item	2362963	et	4	main
lõhn	doc_392411160217_item	2362964	et	3	main
teevad	doc_392411160217_item	2362967	et	3	main
ilusamaks	doc_392411160217_item	2362971	et	4	main
6	doc_392411160217_item	2362977	et	2	main
kaupluses	doc_392411160217_item	2362979	et	3	main
kodukeemilisi	doc_392411160217_item	2362982	et	4	main
müüdavad	doc_392411160217_item	2362986	et	4	main
oli	doc_392411160218_item	2362995	et	3	main
projekte	doc_392411160218_item	2362998	et	3	main
siis	doc_392411160218_item	2363000	et	3	main
ma	doc_392411160218_item	2363002	et	3	main
olevad	doc_392411160218_item	2363018	et	4	main
firma	doc_392411160217_item	2362945	et	4	main
selle	doc_392411160217_item	2362947	et	4	main
reklaameriv	doc_392411160217_item	2362950	et	4	main
ilusamaks	doc_392411160217_item	2362969	et	4	main
tegevad	doc_392411160217_item	2362972	et	4	main
tänapäeval	doc_392411160217_item	2362978	et	3	main
müüakse	doc_392411160217_item	2362980	et	3	main
kaupluses	doc_392411160217_item	2362985	et	3	main
ained	doc_392411160217_item	2362988	et	3	main
valik	doc_392411160218_item	2362996	et	3	main
lugenud	doc_392411160218_item	2363007	et	4	main
määrdunud	doc_392411160218_item	2363010	et	4	main
mustas	doc_392411160218_item	2363016	et	4	main
väga	doc_392411160218_item	2363021	et	3	main
pärast	doc_392411160218_item	2363023	et	4	main
olen	doc_392411160218_item	2363026	et	3	main
peaks	doc_392411160218_item	2363031	et	4	main
olema	doc_392411160218_item	2363032	et	4	main
see	doc_392411160218_item	2363036	et	3	main
peavad	doc_392411160218_item	2363039	et	4	main
et	doc_392411160218_item	2363048	et	3	main
ilusad	doc_392411160218_item	2363049	et	3	main
aitama	doc_392411160218_item	2363053	et	3	main
mürgised	doc_392411160218_item	2363022	et	4	main
selles	doc_392411160218_item	2363054	et	4	main
siis	doc_392411160218_item	2363055	et	3	main
rahastamine	doc_392411160218_item	2363063	et	4	main
mõtteid	doc_392411160218_item	2363042	et	3	main
reklaamid	doc_392411160218_item	2363050	et	4	main
kohal	doc_392411160218_item	2363057	et	4	main
on	doc_392411160218_item	2363058	et	4	main
rahastada	doc_392411160218_item	2363059	et	4	main
uürituse	doc_392411160218_item	2363060	et	4	main
loodusesõbrad	doc_392411160218_item	2363061	et	3	main
haldussüsteemist	doc_392411160221_item	2363295	et	4	main
riigi	doc_392411160221_item	2363298	et	3	main
erinevatest	doc_392411160221_item	2363300	et	4	main
valdkondadest	doc_392411160221_item	2363301	et	3	main
ja	doc_392411160221_item	2363302	et	3	main
otsustada	doc_392411160221_item	2363303	et	3	main
millisse	doc_392411160221_item	2363304	et	4	main
teemaringi	doc_392411160221_item	2363305	et	4	main
ma	doc_392411160221_item	2363306	et	3	main
elu	doc_392411160221_item	2363323	et	4	main
mugavam	doc_392411160221_item	2363326	et	4	main
et	doc_392411160221_item	2363330	et	3	main
eestis	doc_392411160221_item	2363331	et	3	main
arvatakse	doc_392411160221_item	2363332	et	3	main
et	doc_392411160221_item	2363333	et	3	main
eelistamine	doc_392411160221_item	2363348	et	4	main
andakse	doc_392411160221_item	2363349	et	4	main
tema	doc_392411160221_item	2363356	et	4	main
essee	doc_392411160222_item	2363358	et	4	main
korraldada	doc_392411160222_item	2363363	et	3	main
ajas	doc_392411160222_item	2363372	et	4	main
palju	doc_392411160222_item	2363378	et	4	main
tuvisalisuse	doc_392411160222_item	2363379	et	4	main
palju	doc_392411160222_item	2363382	et	4	main
illegaalse	doc_392411160222_item	2363383	et	3	main
organisatsioneid	doc_392411160222_item	2363384	et	4	main
see	doc_392411160222_item	2363385	et	3	main
probleem	doc_392411160222_item	2363389	et	3	main
arvan	doc_392411160222_item	2363391	et	3	main
meie	doc_392411160222_item	2363393	et	4	main
mõnedes	doc_392411160222_item	2363403	et	3	main
teeid	doc_392411160222_item	2363428	et	4	main
valdkonnad	doc_392411160222_item	2363438	et	4	main
ekonimilise	doc_392411160222_item	2363441	et	4	main
ettekanne	doc_392411160224_item	2363546	et	4	main
valdkondadest	doc_392411160224_item	2363554	et	3	main
siis	doc_392411160224_item	2363555	et	3	main
kõigepealt	doc_392411160224_item	2363556	et	3	main
räägiksin	doc_392411160224_item	2363557	et	3	main
kuna	doc_392411160224_item	2363561	et	3	main
inimene	doc_392411160224_item	2363563	et	3	main
tee	doc_392411160224_item	2363579	et	4	main
aga	doc_392411160224_item	2363583	et	3	main
ning	doc_392411160221_item	2363296	et	3	main
ühiskonna	doc_392411160221_item	2363299	et	4	main
siis	doc_392411160221_item	2363308	et	3	main
lihtsam	doc_392411160221_item	2363325	et	4	main
perspektiivsem	doc_392411160221_item	2363328	et	4	main
on	doc_392411160221_item	2363335	et	4	main
sama	doc_392411160221_item	2363336	et	4	main
estlased	doc_392411160221_item	2363340	et	4	main
ja	doc_392411160221_item	2363341	et	3	main
pole	doc_392411160221_item	2363342	et	3	main
halvam	doc_392411160221_item	2363343	et	4	main
neid	doc_392411160221_item	2363344	et	4	main
tahaksin	doc_392411160221_item	2363346	et	3	main
ja	doc_392411160221_item	2363351	et	3	main
iseloomule	doc_392411160221_item	2363353	et	3	main
mitte	doc_392411160221_item	2363355	et	3	main
on	doc_392411160222_item	2363365	et	4	main
me	doc_392411160222_item	2363373	et	4	main
eestis	doc_392411160222_item	2363376	et	3	main
ja	doc_392411160222_item	2363381	et	3	main
et	doc_392411160222_item	2363392	et	3	main
milline	doc_392411160222_item	2363421	et	3	main
essee	doc_392411160221_item	2363288	et	4	main
kui	doc_392411160221_item	2363289	et	3	main
mul	doc_392411160221_item	2363290	et	3	main
tuleb	doc_392411160221_item	2363291	et	3	main
teha	doc_392411160221_item	2363292	et	3	main
ettekanne	doc_392411160221_item	2363293	et	4	main
meie	doc_392411160221_item	2363297	et	4	main
eestimaa	doc_392411160221_item	2363310	et	4	main
kui	doc_392411160221_item	2363311	et	3	main
sest	doc_392411160221_item	2363313	et	4	main
kavatsen	doc_392411160221_item	2363315	et	3	main
elada	doc_392411160221_item	2363317	et	3	main
ja	doc_392411160221_item	2363319	et	3	main
oli	doc_392411160221_item	2363324	et	3	main
nagu	doc_392411160221_item	2363339	et	3	main
rahvusele	doc_392411160221_item	2363357	et	3	main
kõigepealt	doc_392411160222_item	2363359	et	3	main
politseitöö	doc_392411160222_item	2363364	et	4	main
vaja	doc_392411160222_item	2363366	et	4	main
teha	doc_392411160222_item	2363367	et	3	main
politseioperatsioneid	doc_392411160222_item	2363369	et	4	main
vaga	doc_392411160222_item	2363387	et	4	main
peab	doc_392411160222_item	2363395	et	4	main
kontrollimise	doc_392411160222_item	2363402	et	4	main
valiksin	doc_392411160221_item	2363309	et	3	main
eestis	doc_392411160221_item	2363318	et	3	main
tahaksin	doc_392411160221_item	2363320	et	3	main
et	doc_392411160221_item	2363321	et	3	main
sugused	doc_392411160221_item	2363337	et	3	main
inimesed	doc_392411160221_item	2363338	et	3	main
et	doc_392411160221_item	2363347	et	3	main
haridusele	doc_392411160221_item	2363350	et	3	main
inimeste	doc_392411160221_item	2363352	et	3	main
aga	doc_392411160221_item	2363354	et	3	main
on	doc_392411160222_item	2363360	et	4	main
vaja	doc_392411160222_item	2363361	et	4	main
viimases	doc_392411160222_item	2363371	et	3	main
et	doc_392411160222_item	2363375	et	3	main
on	doc_392411160222_item	2363386	et	4	main
ma	doc_392411160222_item	2363390	et	3	main
olema	doc_392411160222_item	2363396	et	4	main
samuti	doc_392411160222_item	2363398	et	3	main
märkama	doc_392411160222_item	2363423	et	3	main
lähendamise	doc_392411160222_item	2363429	et	4	main
eesti	doc_392411160222_item	2363431	et	4	main
hästi	doc_392411160222_item	2363433	et	3	main
riik	doc_392411160222_item	2363435	et	3	main
ja	doc_392411160222_item	2363436	et	3	main
kõik	doc_392411160222_item	2363437	et	4	main
kui	doc_392411160224_item	2363542	et	3	main
tuleks	doc_392411160224_item	2363544	et	4	main
meie	doc_392411160224_item	2363550	et	4	main
eestis	doc_392411160224_item	2363560	et	3	main
olla	doc_392411160224_item	2363566	et	3	main
ei	doc_392411160224_item	2363578	et	4	main
oma	doc_392411160224_item	2363580	et	4	main
kui	doc_392411160224_item	2363584	et	3	main
siis	doc_392411160224_item	2363593	et	3	main
inimesed	doc_392411160224_item	2363594	et	3	main
ei	doc_392411160224_item	2363595	et	4	main
tea	doc_392411160224_item	2363596	et	4	main
kuidas	doc_392411160224_item	2363597	et	3	main
kindel	doc_392411160224_item	2363601	et	3	main
aga	doc_392411160224_item	2363616	et	3	main
meie	doc_392411160221_item	2363322	et	4	main
ja	doc_392411160221_item	2363327	et	3	main
tahaksin	doc_392411160221_item	2363329	et	3	main
venelased	doc_392411160221_item	2363334	et	3	main
veel	doc_392411160221_item	2363345	et	4	main
hästi	doc_392411160222_item	2363362	et	3	main
enam	doc_392411160222_item	2363368	et	4	main
sest	doc_392411160222_item	2363370	et	4	main
kuulume	doc_392411160222_item	2363374	et	4	main
on	doc_392411160222_item	2363377	et	4	main
probleemid	doc_392411160222_item	2363380	et	3	main
tõsine	doc_392411160222_item	2363388	et	4	main
riik	doc_392411160222_item	2363394	et	3	main
turvalisuses	doc_392411160222_item	2363397	et	4	main
on	doc_392411160222_item	2363399	et	4	main
vaja	doc_392411160222_item	2363400	et	4	main
tõmbata	doc_392411160222_item	2363401	et	4	main
meies	doc_392411160222_item	2363404	et	4	main
valdkondades	doc_392411160222_item	2363405	et	3	main
mõned	doc_392411160222_item	2363406	et	3	main
regioonid	doc_392411160222_item	2363407	et	3	main
on	doc_392411160222_item	2363408	et	4	main
halvasti	doc_392411160222_item	2363409	et	3	main
areneda	doc_392411160222_item	2363410	et	3	main
ja	doc_392411160222_item	2363411	et	3	main
seepärast	doc_392411160222_item	2363412	et	3	main
me	doc_392411160222_item	2363413	et	4	main
peame	doc_392411160222_item	2363414	et	4	main
lähendama	doc_392411160222_item	2363415	et	3	main
seda	doc_392411160222_item	2363416	et	3	main
ma	doc_392411160222_item	2363417	et	3	main
pakkun	doc_392411160222_item	2363418	et	4	main
korraldada	doc_392411160222_item	2363419	et	3	main
komisione	doc_392411160222_item	2363420	et	4	main
peab	doc_392411160222_item	2363422	et	4	main
olulisemaid	doc_392411160222_item	2363424	et	4	main
probleemid	doc_392411160222_item	2363425	et	3	main
ja	doc_392411160222_item	2363426	et	3	main
leida	doc_392411160222_item	2363427	et	3	main
praegu	doc_392411160222_item	2363430	et	3	main
on	doc_392411160222_item	2363432	et	4	main
olema	doc_392411160222_item	2363440	et	4	main
rikased	doc_392411160222_item	2363442	et	4	main
essee	doc_392411160224_item	2363541	et	4	main
turvalisuste	doc_392411160224_item	2363558	et	4	main
probleemidest	doc_392411160224_item	2363559	et	3	main
iga	doc_392411160224_item	2363562	et	4	main
et	doc_392411160224_item	2363567	et	3	main
ta	doc_392411160224_item	2363569	et	4	main
politsei	doc_392411160224_item	2363585	et	4	main
arenemise	doc_392411160222_item	2363434	et	4	main
peavad	doc_392411160222_item	2363439	et	4	main
teha	doc_392411160224_item	2363545	et	3	main
tahaks	doc_392411160224_item	2363564	et	3	main
eestis	doc_392411160224_item	2363568	et	3	main
käsitleksin	doc_392411160224_item	2363572	et	3	main
ka	doc_392411160224_item	2363573	et	3	main
politseitööst	doc_392411160224_item	2363574	et	3	main
arvan	doc_392411160224_item	2363575	et	3	main
et	doc_392411160224_item	2363576	et	3	main
tööd	doc_392411160224_item	2363581	et	4	main
hästi	doc_392411160224_item	2363582	et	3	main
ei	doc_392411160224_item	2363586	et	4	main
kuidas	doc_392411160224_item	2363588	et	3	main
rahvastik	doc_392411160224_item	2363604	et	3	main
ka	doc_392411160224_item	2363606	et	3	main
mis	doc_392411160224_item	2363609	et	4	main
nõuab	doc_392411160224_item	2363610	et	3	main
otsust	doc_392411160224_item	2363611	et	4	main
eestis	doc_392411160224_item	2363612	et	3	main
elab	doc_392411160224_item	2363613	et	3	main
palju	doc_392411160224_item	2363614	et	4	main
rahvust	doc_392411160224_item	2363615	et	3	main
kultuurid	doc_392411160224_item	2363620	et	3	main
ja	doc_392411160224_item	2363621	et	3	main
väga	doc_392411160224_item	2363624	et	3	main
paha	doc_392411160224_item	2363625	et	4	main
oluline	doc_392411160224_item	2363627	et	4	main
ka	doc_392411160224_item	2363628	et	3	main
eesti	doc_392411160224_item	2363629	et	4	main
keeletaust	doc_392411160224_item	2363630	et	4	main
eestis	doc_392411160224_item	2363632	et	3	main
palju	doc_392411160224_item	2363634	et	4	main
rahvast	doc_392411160224_item	2363635	et	4	main
siis	doc_392411160224_item	2363636	et	3	main
nad	doc_392411160224_item	2363637	et	3	main
peavad	doc_392411160224_item	2363638	et	4	main
ka	doc_392411160224_item	2363639	et	3	main
eesnimi	doc_392411160225_item	2363651	et	3	main
kehras	doc_392411160225_item	2363654	et	4	main
kehra	doc_392411160225_item	2363656	et	4	main
on	doc_392411160225_item	2363674	et	4	main
it	doc_392411160225_item	2363680	et	4	main
meeldib	doc_392411160225_item	2363683	et	3	main
sellepärast	doc_392411160225_item	2363685	et	3	main
et	doc_392411160225_item	2363686	et	3	main
siin	doc_392411160225_item	2363687	et	4	main
on	doc_392411160225_item	2363700	et	4	main
tudengi	doc_392411160225_item	2363708	et	3	main
elu	doc_392411160225_item	2363709	et	4	main
mul	doc_392411160224_item	2363543	et	3	main
eesti	doc_392411160224_item	2363547	et	4	main
haldussüsteemist	doc_392411160224_item	2363548	et	4	main
ning	doc_392411160224_item	2363549	et	3	main
riigi	doc_392411160224_item	2363551	et	3	main
ühiskonna	doc_392411160224_item	2363552	et	4	main
erinevatest	doc_392411160224_item	2363553	et	4	main
kindel	doc_392411160224_item	2363565	et	3	main
on	doc_392411160224_item	2363570	et	4	main
turvalises	doc_392411160224_item	2363571	et	4	main
politsei	doc_392411160224_item	2363577	et	4	main
oma	doc_392411160224_item	2363590	et	4	main
tööd	doc_392411160224_item	2363591	et	4	main
nendel	doc_392411160224_item	2363598	et	4	main
käituda	doc_392411160224_item	2363599	et	3	main
olen	doc_392411160224_item	2363600	et	3	main
erinevad	doc_392411160224_item	2363619	et	4	main
see	doc_392411160224_item	2363622	et	3	main
kuna	doc_392411160224_item	2363631	et	3	main
on	doc_392411160224_item	2363633	et	4	main
ja	doc_392411160225_item	2363646	et	3	main
asutasin	doc_392411160225_item	2363660	et	3	main
süsteemitehnika	doc_392411160225_item	2363665	et	4	main
et	doc_392411160225_item	2363668	et	3	main
mulle	doc_392411160225_item	2363669	et	4	main
meeldib	doc_392411160225_item	2363670	et	3	main
seda	doc_392411160225_item	2363671	et	3	main
suured	doc_392411160225_item	2363675	et	3	main
tulevikus	doc_392411160225_item	2363677	et	4	main
töötama	doc_392411160225_item	2363679	et	3	main
võimalused	doc_392411160225_item	2363690	et	3	main
vaja	doc_392411160225_item	2363701	et	4	main
ma	doc_392411160225_item	2363703	et	3	main
tutvuda	doc_392411160225_item	2363705	et	3	main
sõbradega	doc_392411160225_item	2363707	et	4	main
elu	doc_392411160225_item	2363714	et	4	main
aga	doc_392411160225_item	2363715	et	3	main
siin	doc_392411160225_item	2363716	et	4	main
on	doc_392411160225_item	2363717	et	4	main
on	doc_392411160225_item	2363723	et	4	main
palju	doc_392411160225_item	2363724	et	4	main
ja	doc_392411160225_item	2363726	et	3	main
keele	doc_392411160225_item	2363730	et	4	main
probleemid	doc_392411160225_item	2363751	et	3	main
uued	doc_392411160225_item	2363756	et	3	main
keeles	doc_392411160225_item	2363770	et	4	main
mind	doc_392411160225_item	2363779	et	4	main
keeles	doc_392411160225_item	2363785	et	4	main
ja	doc_392411160225_item	2363786	et	3	main
ma	doc_392411160225_item	2363787	et	3	main
elan	doc_392411160225_item	2363788	et	3	main
eestis	doc_392411160225_item	2363789	et	3	main
ma	doc_392411160225_item	2363796	et	3	main
saa	doc_392411160225_item	2363798	et	4	main
lõpetada	doc_392411160225_item	2363799	et	3	main
ülikool	doc_392411160226_item	2363804	et	4	main
olnud	doc_392411160226_item	2363826	et	4	main
nagu	doc_392411160226_item	2363829	et	3	main
need	doc_392411160226_item	2363832	et	3	main
kolme	doc_392411160226_item	2363837	et	4	main
ma	doc_392411160226_item	2363849	et	3	main
leidnud	doc_392411160226_item	2363851	et	4	main
hea	doc_392411160226_item	2363852	et	4	main
töökoht	doc_392411160226_item	2363853	et	3	main
on	doc_392411160226_item	2363873	et	4	main
kes	doc_392411160226_item	2363875	et	4	main
saan	doc_392411160226_item	2363889	et	4	main
kedagi	doc_392411160226_item	2363895	et	4	main
küsida	doc_392411160226_item	2363896	et	3	main
ja	doc_392411160226_item	2363897	et	3	main
ttü-s	doc_392411160226_item	2363900	et	3	main
oska	doc_392411160226_item	2363902	et	4	main
eestikeeles	doc_392411160226_item	2363907	et	4	main
saanud	doc_392411160226_item	2363912	et	4	main
siis	doc_392411160226_item	2363916	et	3	main
või	doc_392411160226_item	2363926	et	4	main
kardasin	doc_392411160226_item	2363931	et	3	main
see	doc_392411160226_item	2363942	et	3	main
mitte	doc_392411160226_item	2363947	et	3	main
inimestega	doc_392411160226_item	2363957	et	3	main
meeldib	doc_392411160226_item	2363959	et	3	main
palju	doc_392411160226_item	2363963	et	4	main
raamatud	doc_392411160226_item	2363965	et	4	main
minna	doc_392411160226_item	2363971	et	3	main
moodi	doc_392411160226_item	2363973	et	4	main
lõpetasin	doc_392411160226_item	2364023	et	3	main
praktika	doc_392411160226_item	2364041	et	4	main
essee	doc_392411160227_item	2364049	et	4	main
ülikool	doc_392411160227_item	2364052	et	4	main
tea	doc_392411160224_item	2363587	et	4	main
teha	doc_392411160224_item	2363589	et	3	main
eesti	doc_392411160224_item	2363603	et	4	main
on	doc_392411160224_item	2363605	et	4	main
nendel	doc_392411160224_item	2363617	et	4	main
on	doc_392411160224_item	2363618	et	4	main
on	doc_392411160224_item	2363623	et	4	main
on	doc_392411160224_item	2363626	et	4	main
eesti	doc_392411160224_item	2363640	et	4	main
ülikool	doc_392411160225_item	2363647	et	4	main
nimi	doc_392411160225_item	2363649	et	3	main
elan	doc_392411160225_item	2363653	et	3	main
lõpetasin	doc_392411160225_item	2363655	et	3	main
ttus	doc_392411160225_item	2363661	et	4	main
arvuti	doc_392411160225_item	2363663	et	4	main
eriala	doc_392411160225_item	2363672	et	4	main
spetsialistiga	doc_392411160225_item	2363681	et	3	main
mulle	doc_392411160225_item	2363682	et	4	main
ttu	doc_392411160225_item	2363684	et	4	main
võimalus	doc_392411160225_item	2363695	et	3	main
on	doc_392411160225_item	2363710	et	4	main
lõbusam	doc_392411160225_item	2363711	et	4	main
kui	doc_392411160225_item	2363712	et	3	main
süsteem	doc_392411160225_item	2363720	et	3	main
ja	doc_392411160225_item	2363721	et	3	main
eesti	doc_392411160225_item	2363729	et	4	main
teadusi	doc_392411160225_item	2363734	et	3	main
on	doc_392411160225_item	2363736	et	4	main
eesti	doc_392411160225_item	2363738	et	4	main
keelt	doc_392411160225_item	2363739	et	4	main
on	doc_392411160225_item	2363744	et	4	main
eesti	doc_392411160225_item	2363747	et	4	main
mul	doc_392411160225_item	2363749	et	3	main
õppida	doc_392411160225_item	2363755	et	3	main
mul	doc_392411160225_item	2363759	et	3	main
on	doc_392411160225_item	2363760	et	4	main
vaja	doc_392411160225_item	2363767	et	4	main
loodan	doc_392411160225_item	2363772	et	3	main
tulevikus	doc_392411160225_item	2363780	et	4	main
mul	doc_392411160225_item	2363781	et	3	main
tuleb	doc_392411160225_item	2363782	et	3	main
õpima	doc_392411160225_item	2363783	et	4	main
eesti	doc_392411160225_item	2363784	et	4	main
ttü	doc_392411160225_item	2363800	et	4	main
essee	doc_392411160226_item	2363801	et	4	main
minu	doc_392411160226_item	2363805	et	3	main
eesnimi	doc_392411160226_item	2363808	et	3	main
korralikult	doc_392411160224_item	2363592	et	4	main
et	doc_392411160224_item	2363602	et	3	main
tõsine	doc_392411160224_item	2363607	et	4	main
probleem	doc_392411160224_item	2363608	et	3	main
keelt	doc_392411160224_item	2363641	et	4	main
mina	doc_392411160225_item	2363645	et	4	main
on	doc_392411160225_item	2363650	et	4	main
ma	doc_392411160225_item	2363652	et	3	main
sel	doc_392411160225_item	2363658	et	3	main
end	doc_392411160225_item	2363691	et	4	main
arendada	doc_392411160225_item	2363692	et	3	main
siin	doc_392411160225_item	2363693	et	4	main
on	doc_392411160225_item	2363694	et	4	main
valida	doc_392411160225_item	2363696	et	3	main
tunnid	doc_392411160225_item	2363697	et	3	main
mis	doc_392411160225_item	2363698	et	4	main
siin	doc_392411160225_item	2363702	et	4	main
sain	doc_392411160225_item	2363704	et	3	main
kooli	doc_392411160225_item	2363713	et	4	main
raske	doc_392411160225_item	2363718	et	4	main
saada	doc_392411160225_item	2363733	et	4	main
suured	doc_392411160225_item	2363745	et	3	main
gramaatikaga	doc_392411160225_item	2363752	et	4	main
tahan	doc_392411160225_item	2363754	et	3	main
sõnad	doc_392411160225_item	2363757	et	4	main
väga	doc_392411160225_item	2363761	et	3	main
väike	doc_392411160225_item	2363762	et	4	main
sõnavara	doc_392411160225_item	2363763	et	4	main
ja	doc_392411160225_item	2363764	et	3	main
on	doc_392411160225_item	2363766	et	4	main
eesti	doc_392411160225_item	2363774	et	4	main
aidata	doc_392411160225_item	2363778	et	4	main
ma	doc_392411160225_item	2363790	et	3	main
et	doc_392411160225_item	2363792	et	3	main
eesti	doc_392411160225_item	2363794	et	4	main
ei	doc_392411160225_item	2363797	et	4	main
on	doc_392411160226_item	2363807	et	4	main
aastaal	doc_392411160226_item	2363815	et	4	main
ttü	doc_392411160226_item	2363817	et	4	main
ma	doc_392411160226_item	2363818	et	3	main
õpisin	doc_392411160226_item	2363819	et	4	main
ttüs	doc_392411160226_item	2363830	et	4	main
kokku	doc_392411160226_item	2363831	et	3	main
aga	doc_392411160226_item	2363839	et	3	main
ei	doc_392411160226_item	2363850	et	4	main
läks	doc_392411160226_item	2363856	et	3	main
ma	doc_392411160226_item	2363867	et	3	main
sõber	doc_392411160226_item	2363874	et	3	main
saama	doc_392411160226_item	2363877	et	4	main
fakultetis	doc_392411160226_item	2363878	et	4	main
juba	doc_392411160226_item	2363879	et	3	main
ma	doc_392411160226_item	2363888	et	3	main
ainult	doc_392411160226_item	2363891	et	4	main
siin	doc_392411160226_item	2363893	et	4	main
ttüs	doc_392411160226_item	2363894	et	4	main
võib	doc_392411160226_item	2363909	et	3	main
ja	doc_392411160226_item	2363915	et	3	main
tuleb	doc_392411160226_item	2363917	et	3	main
aga	doc_392411160226_item	2363919	et	3	main
sõber	doc_392411160226_item	2363923	et	3	main
kõik	doc_392411160226_item	2363928	et	4	main
küsimused	doc_392411160226_item	2363929	et	4	main
ttü	doc_392411160226_item	2363932	et	4	main
millal	doc_392411160226_item	2363933	et	3	main
käin	doc_392411160226_item	2363934	et	3	main
siin	doc_392411160226_item	2363935	et	4	main
ma	doc_392411160226_item	2363936	et	3	main
kardasin	doc_392411160226_item	2363937	et	3	main
koht	doc_392411160226_item	2363943	et	3	main
midagi	doc_392411160226_item	2363948	et	4	main
aga	doc_392411160226_item	2363949	et	3	main
pärast	doc_392411160226_item	2363950	et	4	main
ttü-s	doc_392411160226_item	2363960	et	3	main
võin	doc_392411160226_item	2363969	et	3	main
mulle	doc_392411160226_item	2363974	et	4	main
praegu	doc_392411160226_item	2363990	et	3	main
aru	doc_392411160224_item	2363642	et	4	main
saama	doc_392411160224_item	2363643	et	4	main
essee	doc_392411160225_item	2363644	et	4	main
minu	doc_392411160225_item	2363648	et	3	main
keskkool	doc_392411160225_item	2363657	et	4	main
aastal	doc_392411160225_item	2363659	et	3	main
valisin	doc_392411160225_item	2363662	et	3	main
ja	doc_392411160225_item	2363664	et	3	main
eriala	doc_392411160225_item	2363666	et	4	main
selepärast	doc_392411160225_item	2363667	et	4	main
mul	doc_392411160225_item	2363673	et	3	main
planid	doc_392411160225_item	2363676	et	4	main
tahan	doc_392411160225_item	2363678	et	3	main
on	doc_392411160225_item	2363688	et	4	main
suured	doc_392411160225_item	2363689	et	3	main
mull	doc_392411160225_item	2363699	et	3	main
paljuga	doc_392411160225_item	2363706	et	3	main
õpimine	doc_392411160225_item	2363719	et	4	main
siin	doc_392411160225_item	2363722	et	4	main
eksamid	doc_392411160225_item	2363725	et	3	main
arvastused	doc_392411160225_item	2363727	et	4	main
tööd	doc_392411160225_item	2363728	et	4	main
tahan	doc_392411160225_item	2363732	et	3	main
mul	doc_392411160225_item	2363735	et	3	main
vaja	doc_392411160225_item	2363737	et	4	main
mul	doc_392411160225_item	2363743	et	3	main
ma	doc_392411160225_item	2363753	et	3	main
eesti	doc_392411160225_item	2363769	et	4	main
ma	doc_392411160225_item	2363771	et	3	main
et	doc_392411160225_item	2363773	et	3	main
loengut	doc_392411160225_item	2363776	et	3	main
saavad	doc_392411160225_item	2363777	et	4	main
ilma	doc_392411160225_item	2363793	et	4	main
keelega	doc_392411160225_item	2363795	et	3	main
mina	doc_392411160226_item	2363802	et	4	main
ja	doc_392411160226_item	2363803	et	3	main
astusin	doc_392411160226_item	2363810	et	3	main
kahe	doc_392411160226_item	2363812	et	3	main
kuuendal	doc_392411160226_item	2363814	et	3	main
eest	doc_392411160226_item	2363816	et	4	main
dokkeri	doc_392411160226_item	2363821	et	4	main
ei	doc_392411160226_item	2363825	et	4	main
suur	doc_392411160226_item	2363828	et	3	main
ja	doc_392411160226_item	2363836	et	3	main
need	doc_392411160226_item	2363840	et	3	main
huvitavad	doc_392411160226_item	2363844	et	4	main
mõtlesin	doc_392411160226_item	2363847	et	3	main
või	doc_392411160226_item	2363848	et	4	main
ma	doc_392411160226_item	2363855	et	3	main
mul	doc_392411160226_item	2363872	et	3	main
mitte	doc_392411160226_item	2363890	et	3	main
küsida	doc_392411160226_item	2363892	et	3	main
vastuda	doc_392411160226_item	2363905	et	4	main
olle	doc_392411160226_item	2363910	et	4	main
aru	doc_392411160226_item	2363913	et	4	main
probleemid	doc_392411160226_item	2363918	et	3	main
kui	doc_392411160226_item	2363920	et	3	main
sul	doc_392411160226_item	2363921	et	3	main
ta	doc_392411160226_item	2363925	et	4	main
ma	doc_392411160226_item	2363930	et	3	main
teadnud	doc_392411160226_item	2363941	et	4	main
päeva	doc_392411160226_item	2363952	et	4	main
lõpetasin	doc_392411160226_item	2363953	et	3	main
uuede	doc_392411160226_item	2363956	et	4	main
raamatukogu	doc_392411160226_item	2363961	et	4	main
huvitavad	doc_392411160226_item	2363964	et	4	main
arvutid	doc_392411160226_item	2363966	et	4	main
kus	doc_392411160226_item	2363967	et	3	main
ma	doc_392411160226_item	2363968	et	3	main
internetisse	doc_392411160226_item	2363970	et	4	main
sama	doc_392411160226_item	2363972	et	4	main
et	doc_392411160226_item	2363976	et	3	main
raamatukogu	doc_392411160226_item	2363977	et	4	main
võin	doc_392411160226_item	2363979	et	3	main
internetist	doc_392411160226_item	2363981	et	4	main
leida	doc_392411160226_item	2363982	et	3	main
ja	doc_392411160226_item	2363984	et	3	main
kahjuks	doc_392411160226_item	2363989	et	4	main
kui	doc_392411160226_item	2364021	et	3	main
ja	doc_392411160226_item	2364043	et	3	main
on	doc_392411160227_item	2364055	et	4	main
on	doc_392411160227_item	2364059	et	4	main
ja	doc_392411160227_item	2364066	et	3	main
praegu	doc_392411160227_item	2364076	et	3	main
õpin	doc_392411160227_item	2364077	et	3	main
loengutelt	doc_392411160225_item	2363731	et	4	main
ära	doc_392411160225_item	2363740	et	4	main
õpida	doc_392411160225_item	2363741	et	4	main
praegu	doc_392411160225_item	2363742	et	3	main
probleemid	doc_392411160225_item	2363746	et	3	main
keelega	doc_392411160225_item	2363748	et	3	main
on	doc_392411160225_item	2363750	et	4	main
sest	doc_392411160225_item	2363758	et	4	main
mul	doc_392411160225_item	2363765	et	3	main
suhtlemine	doc_392411160225_item	2363768	et	4	main
keele	doc_392411160225_item	2363775	et	4	main
arvan	doc_392411160225_item	2363791	et	3	main
nimi	doc_392411160226_item	2363806	et	3	main
ma	doc_392411160226_item	2363809	et	3	main
ttü-s	doc_392411160226_item	2363811	et	3	main
tuhande	doc_392411160226_item	2363813	et	3	main
keevitajana	doc_392411160226_item	2363820	et	4	main
ja	doc_392411160226_item	2363822	et	3	main
need	doc_392411160226_item	2363823	et	3	main
kuud	doc_392411160226_item	2363835	et	4	main
olnud	doc_392411160226_item	2363842	et	4	main
õppima	doc_392411160226_item	2363869	et	3	main
arvutidega	doc_392411160226_item	2363870	et	4	main
ja	doc_392411160226_item	2363871	et	3	main
õpis	doc_392411160226_item	2363876	et	3	main
kui	doc_392411160226_item	2363883	et	3	main
olla	doc_392411160226_item	2363899	et	3	main
ei	doc_392411160226_item	2363901	et	4	main
vene	doc_392411160226_item	2363903	et	4	main
keeles	doc_392411160226_item	2363904	et	4	main
ma	doc_392411160226_item	2363908	et	3	main
ei	doc_392411160226_item	2363911	et	4	main
on	doc_392411160226_item	2363922	et	4	main
siis	doc_392411160226_item	2363924	et	3	main
ma	doc_392411160226_item	2363944	et	3	main
teadnud	doc_392411160226_item	2363946	et	4	main
tutvustasin	doc_392411160226_item	2363955	et	3	main
nii	doc_392411160226_item	2363962	et	3	main
meeldib	doc_392411160226_item	2363975	et	3	main
ma	doc_392411160226_item	2363978	et	3	main
raamat	doc_392411160226_item	2363983	et	3	main
ma	doc_392411160226_item	2364026	et	3	main
rääkida	doc_392411160226_item	2364028	et	3	main
kõikidest	doc_392411160226_item	2364030	et	4	main
mitte	doc_392411160226_item	2364032	et	3	main
see	doc_392411160226_item	2364039	et	3	main
praktika	doc_392411160226_item	2364042	et	4	main
veel	doc_392411160226_item	2364044	et	4	main
kord	doc_392411160226_item	2364045	et	4	main
praktika	doc_392411160226_item	2364046	et	4	main
mina	doc_392411160227_item	2364050	et	4	main
ja	doc_392411160227_item	2364051	et	3	main
eesnimi	doc_392411160227_item	2364056	et	3	main
mul	doc_392411160227_item	2364058	et	3	main
kaheksateist	doc_392411160227_item	2364060	et	4	main
aastat	doc_392411160227_item	2364061	et	3	main
vana	doc_392411160227_item	2364062	et	4	main
ma	doc_392411160227_item	2364063	et	3	main
elan	doc_392411160227_item	2364064	et	3	main
maardu	doc_392411160227_item	2364073	et	4	main
õppima	doc_392411160227_item	2364090	et	3	main
uus	doc_392411160227_item	2364096	et	3	main
see	doc_392411160227_item	2364100	et	3	main
mulle	doc_392411160227_item	2364106	et	4	main
head	doc_392411160227_item	2364122	et	4	main
võin	doc_392411160227_item	2364125	et	3	main
mis	doc_392411160227_item	2364134	et	4	main
keeles	doc_392411160227_item	2364146	et	4	main
pean	doc_392411160227_item	2364154	et	4	main
eesti	doc_392411160227_item	2364166	et	4	main
keele	doc_392411160227_item	2364167	et	4	main
et	doc_392411160227_item	2364174	et	3	main
ma	doc_392411160227_item	2364175	et	3	main
teha	doc_392411160227_item	2364188	et	3	main
olen	doc_392411160227_item	2364190	et	3	main
saan	doc_392411160228_item	2364226	et	4	main
et	doc_392411160228_item	2364229	et	3	main
heast	doc_392411160228_item	2364231	et	3	main
suurepärane	doc_392411160228_item	2364234	et	4	main
minu	doc_392411160228_item	2364236	et	3	main
häid	doc_392411160228_item	2364244	et	3	main
saamiseks	doc_392411160228_item	2364248	et	4	main
õpingut	doc_392411160228_item	2364260	et	3	main
minu	doc_392411160228_item	2364264	et	3	main
algas	doc_392411160228_item	2364266	et	3	main
ma	doc_392411160228_item	2364270	et	3	main
professionid	doc_392411160226_item	2363824	et	4	main
nii	doc_392411160226_item	2363827	et	3	main
võtsid	doc_392411160226_item	2363833	et	4	main
kolme	doc_392411160226_item	2363834	et	4	main
nädalat	doc_392411160226_item	2363838	et	3	main
ei	doc_392411160226_item	2363841	et	4	main
nii	doc_392411160226_item	2363843	et	3	main
nagu	doc_392411160226_item	2363845	et	3	main
ma	doc_392411160226_item	2363846	et	3	main
sellejärel	doc_392411160226_item	2363854	et	3	main
õppima	doc_392411160226_item	2363857	et	3	main
siin	doc_392411160226_item	2363858	et	4	main
ma	doc_392411160226_item	2363859	et	3	main
valitsin	doc_392411160226_item	2363860	et	4	main
arvuti	doc_392411160226_item	2363861	et	4	main
ja	doc_392411160226_item	2363862	et	3	main
süsteem	doc_392411160226_item	2363863	et	3	main
sellest	doc_392411160226_item	2363865	et	4	main
et	doc_392411160226_item	2363866	et	3	main
tehnika	doc_392411160226_item	2363864	et	4	main
tahaksin	doc_392411160226_item	2363868	et	3	main
kolm	doc_392411160226_item	2363880	et	3	main
aasta	doc_392411160226_item	2363881	et	4	main
sellejärel	doc_392411160226_item	2363882	et	3	main
mul	doc_392411160226_item	2363884	et	3	main
on	doc_392411160226_item	2363885	et	4	main
mingi	doc_392411160226_item	2363886	et	4	main
problemid	doc_392411160226_item	2363887	et	4	main
võib	doc_392411160226_item	2363898	et	3	main
aga	doc_392411160226_item	2363906	et	3	main
õige	doc_392411160226_item	2363914	et	4	main
vastuda	doc_392411160226_item	2363927	et	4	main
kõik	doc_392411160226_item	2363938	et	4	main
ma	doc_392411160226_item	2363939	et	3	main
ei	doc_392411160226_item	2363940	et	4	main
ei	doc_392411160226_item	2363945	et	4	main
esimese	doc_392411160226_item	2363951	et	3	main
kardama	doc_392411160226_item	2363954	et	3	main
mulle	doc_392411160226_item	2363958	et	4	main
sisseneda	doc_392411160226_item	2363980	et	4	main
pärast	doc_392411160226_item	2363985	et	4	main
võtta	doc_392411160226_item	2363986	et	3	main
see	doc_392411160226_item	2363987	et	3	main
raamat	doc_392411160226_item	2363988	et	3	main
kaks	doc_392411160226_item	2363991	et	3	main
nädalat	doc_392411160226_item	2363992	et	3	main
ma	doc_392411160226_item	2363993	et	3	main
ei	doc_392411160226_item	2363994	et	4	main
saa	doc_392411160226_item	2363995	et	4	main
spordisaali	doc_392411160226_item	2363996	et	4	main
minna	doc_392411160226_item	2363997	et	3	main
mulle	doc_392411160226_item	2363998	et	4	main
meeldib	doc_392411160226_item	2363999	et	3	main
loengud	doc_392411160226_item	2364000	et	3	main
mitte	doc_392411160226_item	2364001	et	3	main
kõik	doc_392411160226_item	2364002	et	4	main
aga	doc_392411160226_item	2364003	et	3	main
rohkem	doc_392411160226_item	2364004	et	4	main
nendest	doc_392411160226_item	2364005	et	4	main
eesti	doc_392411160226_item	2364006	et	4	main
keelest	doc_392411160226_item	2364007	et	4	main
ma	doc_392411160226_item	2364008	et	3	main
ootan	doc_392411160226_item	2364009	et	3	main
ap	doc_392411160226_item	2364010	et	4	main
see	doc_392411160226_item	2364012	et	3	main
aga	doc_392411160226_item	2364011	et	3	main
ei	doc_392411160226_item	2364013	et	4	main
ole	doc_392411160226_item	2364014	et	4	main
ainult	doc_392411160226_item	2364015	et	4	main
asi	doc_392411160226_item	2364016	et	4	main
veel	doc_392411160226_item	2364017	et	4	main
ma	doc_392411160226_item	2364018	et	3	main
loodan	doc_392411160226_item	2364019	et	3	main
et	doc_392411160226_item	2364020	et	3	main
ma	doc_392411160226_item	2364022	et	3	main
siis	doc_392411160226_item	2364025	et	3	main
oskan	doc_392411160226_item	2364027	et	3	main
on	doc_392411160226_item	2364036	et	4	main
hea	doc_392411160226_item	2364037	et	4	main
meeldne	doc_392411160226_item	2364038	et	4	main
head	doc_392411160226_item	2364047	et	4	main
aega	doc_392411160226_item	2364048	et	4	main
nimi	doc_392411160227_item	2364054	et	3	main
väikeses	doc_392411160227_item	2364065	et	4	main
kuursid	doc_392411160226_item	2364024	et	4	main
vaba	doc_392411160226_item	2364029	et	4	main
alati	doc_392411160226_item	2364031	et	4	main
ainult	doc_392411160226_item	2364033	et	4	main
kui	doc_392411160226_item	2364034	et	3	main
mul	doc_392411160226_item	2364035	et	3	main
tähendab	doc_392411160226_item	2364040	et	3	main
perekonnanimi	doc_392411160227_item	2364057	et	3	main
väga	doc_392411160227_item	2364067	et	3	main
linnas	doc_392411160227_item	2364069	et	4	main
ja	doc_392411160227_item	2364075	et	3	main
tallinna	doc_392411160227_item	2364078	et	4	main
ülikoolis	doc_392411160227_item	2364080	et	4	main
ma	doc_392411160227_item	2364081	et	3	main
väga	doc_392411160227_item	2364082	et	3	main
ammu	doc_392411160227_item	2364083	et	4	main
ootasin	doc_392411160227_item	2364084	et	3	main
seda	doc_392411160227_item	2364085	et	3	main
ülikoolis	doc_392411160227_item	2364091	et	4	main
elu	doc_392411160227_item	2364097	et	4	main
jaoks	doc_392411160227_item	2364099	et	4	main
ja	doc_392411160227_item	2364104	et	3	main
meeldis	doc_392411160227_item	2364108	et	3	main
tallinna	doc_392411160227_item	2364109	et	4	main
tehnika	doc_392411160227_item	2364110	et	4	main
ülikoolis	doc_392411160227_item	2364111	et	4	main
suur	doc_392411160227_item	2364112	et	3	main
hoone	doc_392411160227_item	2364113	et	4	main
hoone	doc_392411160227_item	2364114	et	4	main
sees	doc_392411160227_item	2364115	et	4	main
on	doc_392411160227_item	2364116	et	4	main
mugavalt	doc_392411160227_item	2364117	et	4	main
kõik	doc_392411160227_item	2364118	et	4	main
õpetajad	doc_392411160227_item	2364119	et	4	main
on	doc_392411160227_item	2364120	et	4	main
väga	doc_392411160227_item	2364121	et	3	main
ülikoolis	doc_392411160227_item	2364123	et	4	main
suhelda	doc_392411160227_item	2364126	et	4	main
tudengitega	doc_392411160227_item	2364127	et	3	main
nii	doc_392411160227_item	2364128	et	3	main
kui	doc_392411160227_item	2364130	et	3	main
tähtis	doc_392411160227_item	2364137	et	4	main
et	doc_392411160227_item	2364139	et	3	main
ja	doc_392411160227_item	2364147	et	3	main
et	doc_392411160227_item	2364148	et	3	main
saada	doc_392411160227_item	2364150	et	4	main
ma	doc_392411160227_item	2364153	et	3	main
eesti	doc_392411160227_item	2364157	et	4	main
juba	doc_392411160227_item	2364159	et	3	main
tore	doc_392411160227_item	2364162	et	3	main
meil	doc_392411160227_item	2364164	et	4	main
kasu	doc_392411160227_item	2364173	et	4	main
oma	doc_392411160227_item	2364178	et	4	main
parendada	doc_392411160227_item	2364180	et	3	main
grammatikat	doc_392411160227_item	2364181	et	3	main
ja	doc_392411160227_item	2364184	et	3	main
et	doc_392411160227_item	2364193	et	3	main
minu	doc_392411160228_item	2364221	et	3	main
kuna	doc_392411160228_item	2364224	et	3	main
on	doc_392411160228_item	2364238	et	4	main
ülikool	doc_392411160228_item	2364241	et	4	main
annab	doc_392411160228_item	2364242	et	3	main
õppides	doc_392411160228_item	2364253	et	4	main
gümnaasiumis	doc_392411160228_item	2364254	et	3	main
otsustasin	doc_392411160228_item	2364255	et	3	main
jatkan	doc_392411160228_item	2364258	et	4	main
sellel	doc_392411160228_item	2364262	et	4	main
minu	doc_392411160228_item	2364275	et	3	main
muutusid	doc_392411160228_item	2364278	et	4	main
ole	doc_392411160228_item	2364314	et	4	main
minu	doc_392411160227_item	2364053	et	3	main
maardus	doc_392411160227_item	2364070	et	4	main
ma	doc_392411160227_item	2364071	et	3	main
lõpetasin	doc_392411160227_item	2364072	et	3	main
millal	doc_392411160227_item	2364087	et	3	main
ma	doc_392411160227_item	2364088	et	3	main
uus	doc_392411160227_item	2364092	et	3	main
sõbrad	doc_392411160227_item	2364095	et	3	main
on	doc_392411160227_item	2364101	et	4	main
ilusas	doc_392411160227_item	2364068	et	3	main
gümnaasiumi	doc_392411160227_item	2364074	et	4	main
hetke	doc_392411160227_item	2364086	et	4	main
hakkan	doc_392411160227_item	2364089	et	3	main
mulle	doc_392411160227_item	2364098	et	4	main
tähtis	doc_392411160227_item	2364103	et	4	main
kohe	doc_392411160227_item	2364107	et	4	main
ma	doc_392411160227_item	2364124	et	3	main
väga	doc_392411160227_item	2364136	et	3	main
sellepärast	doc_392411160227_item	2364138	et	3	main
aastal	doc_392411160227_item	2364141	et	3	main
on	doc_392411160227_item	2364144	et	4	main
eesti	doc_392411160227_item	2364145	et	4	main
millest	doc_392411160227_item	2364151	et	3	main
räägitakse	doc_392411160227_item	2364152	et	3	main
on	doc_392411160227_item	2364165	et	4	main
suure	doc_392411160227_item	2364172	et	3	main
väga	doc_392411160227_item	2364191	et	3	main
hästi	doc_392411160228_item	2364227	et	3	main
seisukoht	doc_392411160228_item	2364237	et	3	main
selline	doc_392411160228_item	2364239	et	4	main
prestiizne	doc_392411160228_item	2364246	et	4	main
et	doc_392411160228_item	2364257	et	3	main
ülikoolis	doc_392411160228_item	2364261	et	4	main
õpin	doc_392411160228_item	2364271	et	3	main
piisavalt	doc_392411160228_item	2364315	et	4	main
minu	doc_392411160228_item	2364317	et	3	main
juba	doc_392411160228_item	2364323	et	3	main
ülikoolis	doc_392411160228_item	2364335	et	4	main
ühiselamus	doc_392411160228_item	2364338	et	4	main
on	doc_392411160228_item	2364340	et	4	main
niisugune	doc_392411160228_item	2364341	et	3	main
iseseisvus	doc_392411160228_item	2364343	et	4	main
et	doc_392411160228_item	2364344	et	3	main
toitumine	doc_392411160228_item	2364352	et	4	main
krõpsud	doc_392411160228_item	2364354	et	4	main
valmivad	doc_392411160228_item	2364356	et	4	main
maiustusi	doc_392411160228_item	2364359	et	4	main
palju	doc_392411160228_item	2364366	et	4	main
üliõpilasi	doc_392411160228_item	2364367	et	3	main
teavad	doc_392411160228_item	2364368	et	3	main
kui	doc_392411160228_item	2364369	et	3	main
kuna	doc_392411160228_item	2364374	et	3	main
elavad	doc_392411160228_item	2364386	et	4	main
abituriendid	doc_392411160228_item	2364387	et	3	main
tunnevad	doc_392411160228_item	2364388	et	3	main
mille	doc_392411160228_item	2364392	et	3	main
teavad	doc_392411160228_item	2364395	et	3	main
minu	doc_392411160228_item	2364421	et	3	main
tulevikuplaani	doc_392411160228_item	2364425	et	4	main
täpselt	doc_392411160228_item	2364433	et	4	main
on	doc_392411160228_item	2364443	et	4	main
ja	doc_392411160228_item	2364451	et	3	main
sõbrad	doc_392411160228_item	2364455	et	3	main
hästi	doc_392411160228_item	2364459	et	3	main
veetma	doc_392411160228_item	2364461	et	3	main
saan	doc_392411160228_item	2364465	et	4	main
mul	doc_392411160228_item	2364475	et	3	main
kogu	doc_392411160229_item	2364510	et	4	main
ma	doc_392411160229_item	2364513	et	3	main
perekond	doc_392411160229_item	2364522	et	3	main
on	doc_392411160229_item	2364528	et	4	main
minu	doc_392411160229_item	2364539	et	3	main
hobbid	doc_392411160229_item	2364540	et	4	main
just	doc_392411160229_item	2364554	et	3	main
informaatika	doc_392411160229_item	2364555	et	4	main
kasutamine	doc_392411160229_item	2364559	et	4	main
mind	doc_392411160229_item	2364565	et	4	main
huvitab	doc_392411160229_item	2364567	et	3	main
praegu	doc_392411160229_item	2364569	et	3	main
ülikoolis	doc_392411160229_item	2364593	et	4	main
väga	doc_392411160229_item	2364607	et	3	main
on	doc_392411160229_item	2364612	et	4	main
kõik	doc_392411160229_item	2364618	et	4	main
sõbralikud	doc_392411160229_item	2364620	et	3	main
palju	doc_392411160229_item	2364624	et	4	main
tudenge	doc_392411160229_item	2364632	et	4	main
see	doc_392411160229_item	2364637	et	3	main
väga	doc_392411160229_item	2364640	et	3	main
ma	doc_392411160229_item	2364650	et	3	main
tulesin	doc_392411160229_item	2364651	et	4	main
tehnika	doc_392411160227_item	2364079	et	4	main
koht	doc_392411160227_item	2364093	et	3	main
uued	doc_392411160227_item	2364094	et	3	main
väga	doc_392411160227_item	2364102	et	3	main
huvitav	doc_392411160227_item	2364105	et	4	main
vene	doc_392411160227_item	2364129	et	4	main
ka	doc_392411160227_item	2364131	et	3	main
on	doc_392411160227_item	2364135	et	4	main
teisel	doc_392411160227_item	2364140	et	4	main
kõik	doc_392411160227_item	2364142	et	4	main
aru	doc_392411160227_item	2364149	et	4	main
sügavalt	doc_392411160227_item	2364155	et	4	main
keelt	doc_392411160227_item	2364158	et	4	main
praegu	doc_392411160227_item	2364160	et	3	main
väga	doc_392411160227_item	2364161	et	3	main
tundid	doc_392411160227_item	2364168	et	4	main
tundidest	doc_392411160227_item	2364171	et	3	main
saaks	doc_392411160227_item	2364176	et	3	main
sõnavara	doc_392411160227_item	2364179	et	4	main
rääkida	doc_392411160227_item	2364182	et	3	main
õigesti	doc_392411160227_item	2364183	et	3	main
rõõmus	doc_392411160227_item	2364192	et	4	main
eesti	doc_392411160227_item	2364132	et	4	main
keeles	doc_392411160227_item	2364133	et	4	main
loengud	doc_392411160227_item	2364143	et	3	main
õppima	doc_392411160227_item	2364156	et	3	main
et	doc_392411160227_item	2364163	et	3	main
ma	doc_392411160227_item	2364169	et	3	main
ootan	doc_392411160227_item	2364170	et	3	main
laiendada	doc_392411160227_item	2364177	et	3	main
mina	doc_392411160227_item	2364185	et	4	main
püüan	doc_392411160227_item	2364186	et	3	main
seda	doc_392411160227_item	2364187	et	3	main
ma	doc_392411160227_item	2364189	et	3	main
astuda	doc_392411160227_item	2364194	et	3	main
ülikoolis	doc_392411160227_item	2364195	et	4	main
ja	doc_392411160227_item	2364196	et	3	main
õpin	doc_392411160227_item	2364197	et	3	main
ma	doc_392411160227_item	2364198	et	3	main
saan	doc_392411160227_item	2364199	et	4	main
arendada	doc_392411160227_item	2364200	et	3	main
iseenda	doc_392411160227_item	2364201	et	3	main
ja	doc_392411160227_item	2364202	et	3	main
laiendada	doc_392411160227_item	2364203	et	3	main
oma	doc_392411160227_item	2364204	et	4	main
silmaringi	doc_392411160227_item	2364205	et	4	main
ja	doc_392411160227_item	2364206	et	3	main
tulevikus	doc_392411160227_item	2364207	et	4	main
omada	doc_392411160227_item	2364208	et	3	main
hea	doc_392411160227_item	2364209	et	4	main
elukutse	doc_392411160227_item	2364210	et	4	main
essee	doc_392411160228_item	2364211	et	4	main
mina	doc_392411160228_item	2364212	et	4	main
ja	doc_392411160228_item	2364213	et	3	main
ülikool	doc_392411160228_item	2364214	et	4	main
õppimine	doc_392411160228_item	2364215	et	4	main
on	doc_392411160228_item	2364216	et	4	main
oluline	doc_392411160228_item	2364217	et	4	main
kogu	doc_392411160228_item	2364218	et	4	main
aeg	doc_392411160228_item	2364219	et	3	main
ja	doc_392411160228_item	2364220	et	3	main
ka	doc_392411160228_item	2364223	et	3	main
ma	doc_392411160228_item	2364225	et	3	main
ainult	doc_392411160228_item	2364230	et	4	main
õpingust	doc_392411160228_item	2364232	et	3	main
et	doc_392411160228_item	2364240	et	3	main
inimestele	doc_392411160228_item	2364243	et	3	main
elukutse	doc_392411160228_item	2364247	et	4	main
ja	doc_392411160228_item	2364249	et	3	main
selle	doc_392411160228_item	2364250	et	4	main
tõttu	doc_392411160228_item	2364251	et	4	main
juba	doc_392411160228_item	2364252	et	3	main
ma	doc_392411160228_item	2364256	et	3	main
aastal	doc_392411160228_item	2364263	et	3	main
elu	doc_392411160228_item	2364265	et	4	main
uuesti	doc_392411160228_item	2364267	et	3	main
praegu	doc_392411160228_item	2364269	et	3	main
jaoks	doc_392411160228_item	2364222	et	4	main
aru	doc_392411160228_item	2364228	et	4	main
sõltub	doc_392411160228_item	2364233	et	3	main
tulevik	doc_392411160228_item	2364235	et	3	main
võimalusi	doc_392411160228_item	2364245	et	3	main
oma	doc_392411160228_item	2364259	et	4	main
kuna	doc_392411160228_item	2364268	et	3	main
ja	doc_392411160228_item	2364273	et	3	main
vanemate	doc_392411160228_item	2364280	et	4	main
ja	doc_392411160228_item	2364281	et	3	main
lapsepõlvu	doc_392411160228_item	2364282	et	4	main
sõprade	doc_392411160228_item	2364283	et	3	main
eemal	doc_392411160228_item	2364284	et	3	main
ma	doc_392411160228_item	2364285	et	3	main
ehitan	doc_392411160228_item	2364286	et	3	main
oma	doc_392411160228_item	2364287	et	4	main
elu	doc_392411160228_item	2364288	et	4	main
teiste	doc_392411160228_item	2364289	et	4	main
inimeste	doc_392411160228_item	2364290	et	3	main
abita	doc_392411160228_item	2364291	et	3	main
siin	doc_392411160228_item	2364292	et	4	main
ma	doc_392411160228_item	2364293	et	3	main
teen	doc_392411160228_item	2364294	et	3	main
kõik	doc_392411160228_item	2364295	et	4	main
iseseisvalt	doc_392411160228_item	2364296	et	4	main
ja	doc_392411160228_item	2364297	et	3	main
loodan	doc_392411160228_item	2364298	et	3	main
ainult	doc_392411160228_item	2364299	et	4	main
oma	doc_392411160228_item	2364300	et	4	main
jõududele	doc_392411160228_item	2364301	et	3	main
meie	doc_392411160228_item	2364302	et	4	main
ajal	doc_392411160228_item	2364303	et	4	main
üliõpilased	doc_392411160228_item	2364304	et	3	main
peavad	doc_392411160228_item	2364305	et	4	main
nii	doc_392411160228_item	2364306	et	3	main
õppima	doc_392411160228_item	2364307	et	3	main
kui	doc_392411160228_item	2364308	et	3	main
ka	doc_392411160228_item	2364309	et	3	main
töötama	doc_392411160228_item	2364310	et	3	main
kuna	doc_392411160228_item	2364311	et	3	main
raha	doc_392411160228_item	2364312	et	4	main
ei	doc_392411160228_item	2364313	et	4	main
ülikoolis	doc_392411160228_item	2364272	et	4	main
ümbritsevad	doc_392411160228_item	2364276	et	4	main
annab	doc_392411160228_item	2364319	et	3	main
ma	doc_392411160228_item	2364326	et	3	main
õppides	doc_392411160228_item	2364334	et	4	main
probleemid	doc_392411160228_item	2364349	et	3	main
hamburgerid	doc_392411160228_item	2364353	et	3	main
süüakse	doc_392411160228_item	2364360	et	3	main
aga	doc_392411160228_item	2364362	et	3	main
on	doc_392411160228_item	2364376	et	4	main
või	doc_392411160228_item	2364391	et	4	main
sõltub	doc_392411160228_item	2364423	et	3	main
rajamine	doc_392411160228_item	2364426	et	4	main
tea	doc_392411160228_item	2364435	et	4	main
aga	doc_392411160228_item	2364436	et	3	main
olen	doc_392411160228_item	2364437	et	3	main
kindel	doc_392411160228_item	2364438	et	3	main
et	doc_392411160228_item	2364439	et	3	main
ülikooli	doc_392411160228_item	2364440	et	4	main
õppimise	doc_392411160228_item	2364441	et	4	main
noor	doc_392411160228_item	2364450	et	3	main
on	doc_392411160228_item	2364453	et	4	main
loodan	doc_392411160228_item	2364463	et	3	main
lahendada	doc_392411160228_item	2364466	et	3	main
õppimine	doc_392411160228_item	2364470	et	4	main
ülikoolis	doc_392411160228_item	2364471	et	4	main
õpetab	doc_392411160228_item	2364472	et	3	main
seda	doc_392411160228_item	2364476	et	3	main
et	doc_392411160228_item	2364484	et	3	main
praegu	doc_392411160228_item	2364489	et	3	main
essee	doc_392411160229_item	2364496	et	4	main
minu	doc_392411160229_item	2364511	et	3	main
eelan	doc_392411160229_item	2364514	et	4	main
kõik	doc_392411160228_item	2364274	et	4	main
asjad	doc_392411160228_item	2364277	et	3	main
elades	doc_392411160228_item	2364279	et	4	main
ema	doc_392411160228_item	2364318	et	4	main
praegu	doc_392411160228_item	2364316	et	3	main
mulle	doc_392411160228_item	2364320	et	4	main
kursusel	doc_392411160228_item	2364325	et	3	main
et	doc_392411160228_item	2364330	et	3	main
emal	doc_392411160228_item	2364331	et	3	main
raske	doc_392411160228_item	2364333	et	4	main
suur	doc_392411160228_item	2364342	et	3	main
selle	doc_392411160228_item	2364346	et	4	main
tõttu	doc_392411160228_item	2364347	et	4	main
ilmuvad	doc_392411160228_item	2364348	et	4	main
nuudlid	doc_392411160228_item	2364357	et	3	main
palju	doc_392411160228_item	2364358	et	4	main
väga	doc_392411160228_item	2364377	et	3	main
töö	doc_392411160228_item	2364379	et	4	main
tegevust	doc_392411160228_item	2364422	et	4	main
natuke	doc_392411160228_item	2364430	et	4	main
ei	doc_392411160228_item	2364434	et	4	main
kõige	doc_392411160228_item	2364444	et	4	main
toredamad	doc_392411160228_item	2364445	et	4	main
aastad	doc_392411160228_item	2364446	et	3	main
ma	doc_392411160228_item	2364448	et	3	main
mul	doc_392411160228_item	2364452	et	3	main
uued	doc_392411160228_item	2364454	et	3	main
aega	doc_392411160228_item	2364460	et	4	main
ma	doc_392411160228_item	2364462	et	3	main
et	doc_392411160228_item	2364464	et	3	main
erinevaid	doc_392411160228_item	2364467	et	4	main
probleeme	doc_392411160228_item	2364468	et	3	main
saades	doc_392411160228_item	2364478	et	3	main
sisse	doc_392411160228_item	2364480	et	4	main
olin	doc_392411160228_item	2364482	et	3	main
teen	doc_392411160228_item	2364485	et	3	main
saavutamise	doc_392411160228_item	2364494	et	4	main
ja	doc_392411160229_item	2364498	et	3	main
on	doc_392411160229_item	2364502	et	4	main
eesnimi	doc_392411160229_item	2364503	et	3	main
perekonnanimi	doc_392411160229_item	2364504	et	3	main
olen	doc_392411160229_item	2364506	et	3	main
aastad	doc_392411160229_item	2364508	et	3	main
tallinas	doc_392411160229_item	2364515	et	4	main
tallinna	doc_392411160229_item	2364518	et	4	main
gümnaasiumi	doc_392411160229_item	2364520	et	4	main
ei	doc_392411160229_item	2364523	et	4	main
on	doc_392411160229_item	2364541	et	4	main
näiteks	doc_392411160229_item	2364545	et	4	main
eriala	doc_392411160229_item	2364556	et	4	main
huvitab	doc_392411160229_item	2364560	et	3	main
seitse	doc_392411160229_item	2364563	et	3	main
ka	doc_392411160229_item	2364566	et	3	main
programeerimine	doc_392411160229_item	2364568	et	4	main
et	doc_392411160229_item	2364595	et	3	main
väga	doc_392411160229_item	2364598	et	3	main
asutus	doc_392411160229_item	2364600	et	4	main
need	doc_392411160229_item	2364610	et	3	main
kõik	doc_392411160229_item	2364611	et	4	main
on	doc_392411160229_item	2364622	et	4	main
ja	doc_392411160229_item	2364626	et	3	main
mis	doc_392411160229_item	2364628	et	4	main
kokku	doc_392411160229_item	2364633	et	3	main
ma	doc_392411160229_item	2364635	et	3	main
ka	doc_392411160229_item	2364639	et	3	main
tugevam	doc_392411160229_item	2364645	et	4	main
minul	doc_392411160229_item	2364678	et	3	main
paar	doc_392411160229_item	2364682	et	3	main
kirjutage	doc_397823701987_item	2364689	et	3	main
olete	doc_397823701987_item	2364691	et	3	main
poolt-	doc_397823701987_item	2364697	et	4	main
töö	doc_397823701987_item	2364700	et	4	main
peab	doc_397823701987_item	2364702	et	4	main
aitab	doc_397823701987_item	2364710	et	3	main
viimasel	doc_397823701987_item	2364714	et	3	main
ma	doc_397823701987_item	2364716	et	3	main
eesti	doc_397823701987_item	2364718	et	4	main
aru	doc_397823701987_item	2364725	et	4	main
inimestest	doc_397823701987_item	2364727	et	3	main
praegu	doc_397823701987_item	2364728	et	3	main
näidis	doc_397823701987_item	2364734	et	4	main
avatud	doc_397823701987_item	2364742	et	4	main
piirid	doc_397823701987_item	2364743	et	3	main
ja	doc_397823701987_item	2364744	et	3	main
hea	doc_397823701987_item	2364750	et	4	main
meie	doc_397823701987_item	2364756	et	4	main
raha	doc_392411160228_item	2364321	et	4	main
teisel	doc_392411160228_item	2364324	et	4	main
ise	doc_392411160228_item	2364328	et	4	main
ja	doc_392411160228_item	2364336	et	3	main
ebaterveslik	doc_392411160228_item	2364351	et	4	main
ainult	doc_392411160228_item	2364363	et	4	main
alguses	doc_392411160228_item	2364364	et	4	main
ikkagi	doc_392411160228_item	2364365	et	4	main
oma	doc_392411160228_item	2364372	et	4	main
toitumist	doc_392411160228_item	2364373	et	4	main
ühiselamus	doc_392411160228_item	2364385	et	4	main
hirmu	doc_392411160228_item	2364389	et	4	main
kelle	doc_392411160228_item	2364390	et	4	main
või	doc_392411160228_item	2364394	et	4	main
et	doc_392411160228_item	2364396	et	3	main
ei	doc_392411160228_item	2364398	et	4	main
jalgi	doc_392411160228_item	2364399	et	4	main
neid	doc_392411160228_item	2364400	et	4	main
ja	doc_392411160228_item	2364401	et	3	main
hakkavad	doc_392411160228_item	2364402	et	4	main
tarbima	doc_392411160228_item	2364403	et	3	main
alkohoolseid	doc_392411160228_item	2364404	et	3	main
jooke	doc_392411160228_item	2364405	et	3	main
nii	doc_392411160228_item	2364406	et	3	main
tihti	doc_392411160228_item	2364407	et	3	main
et	doc_392411160228_item	2364408	et	3	main
õppimine	doc_392411160228_item	2364409	et	4	main
jääb	doc_392411160228_item	2364410	et	3	main
tagal	doc_392411160228_item	2364411	et	4	main
plaanil	doc_392411160228_item	2364412	et	3	main
juba	doc_392411160228_item	2364413	et	3	main
ma	doc_392411160228_item	2364414	et	3	main
olen	doc_392411160228_item	2364415	et	3	main
täiskasvanu	doc_392411160228_item	2364416	et	4	main
ja	doc_392411160228_item	2364417	et	3	main
tean	doc_392411160228_item	2364418	et	3	main
täpselt	doc_392411160228_item	2364419	et	4	main
et	doc_392411160228_item	2364420	et	3	main
aga	doc_392411160228_item	2364322	et	3	main
pean	doc_392411160228_item	2364327	et	4	main
töötama	doc_392411160228_item	2364329	et	3	main
poleks	doc_392411160228_item	2364332	et	3	main
elades	doc_392411160228_item	2364337	et	4	main
üliõpilastel	doc_392411160228_item	2364339	et	4	main
tihti	doc_392411160228_item	2364345	et	3	main
näiteks	doc_392411160228_item	2364350	et	4	main
kiirelt	doc_392411160228_item	2364355	et	4	main
kõik	doc_392411160228_item	2364361	et	4	main
tingimata	doc_392411160228_item	2364370	et	4	main
jalgida	doc_392411160228_item	2364371	et	4	main
õppimine	doc_392411160228_item	2364375	et	4	main
raske	doc_392411160228_item	2364378	et	4	main
mis	doc_392411160228_item	2364380	et	4	main
nõuab	doc_392411160228_item	2364381	et	3	main
palju	doc_392411160228_item	2364382	et	4	main
energiat	doc_392411160228_item	2364383	et	3	main
mõnikord	doc_392411160228_item	2364384	et	3	main
pärast	doc_392411160228_item	2364393	et	4	main
vanemad	doc_392411160228_item	2364397	et	4	main
muidugi	doc_392411160228_item	2364427	et	4	main
kardan	doc_392411160228_item	2364429	et	4	main
midagi	doc_392411160228_item	2364431	et	4	main
mida	doc_392411160228_item	2364432	et	4	main
kuna	doc_392411160228_item	2364447	et	3	main
kellega	doc_392411160228_item	2364456	et	3	main
võimalus	doc_392411160228_item	2364458	et	3	main
ja	doc_392411160228_item	2364473	et	3	main
aitab	doc_392411160228_item	2364474	et	3	main
teha	doc_392411160228_item	2364477	et	3	main
ja	doc_392411160228_item	2364488	et	3	main
kõik	doc_392411160228_item	2364491	et	4	main
minu	doc_392411160228_item	2364492	et	3	main
eesmärgi	doc_392411160228_item	2364493	et	4	main
elu	doc_392411160229_item	2364512	et	4	main
ma	doc_392411160229_item	2364516	et	3	main
liiga	doc_392411160229_item	2364525	et	4	main
suur	doc_392411160229_item	2364526	et	3	main
sport	doc_392411160229_item	2364542	et	3	main
tegelen	doc_392411160229_item	2364547	et	3	main
sest	doc_392411160229_item	2364557	et	4	main
juba	doc_392411160229_item	2364562	et	3	main
aastad	doc_392411160229_item	2364564	et	3	main
oli	doc_392411160229_item	2364594	et	3	main
siin	doc_392411160229_item	2364605	et	4	main
õppivad	doc_392411160229_item	2364606	et	4	main
ma	doc_392411160229_item	2364615	et	3	main
arvasin	doc_392411160229_item	2364616	et	3	main
minu	doc_392411160228_item	2364424	et	3	main
ma	doc_392411160228_item	2364428	et	3	main
aastad	doc_392411160228_item	2364442	et	3	main
olen	doc_392411160228_item	2364449	et	3	main
on	doc_392411160228_item	2364457	et	4	main
ja	doc_392411160228_item	2364469	et	3	main
ülikooli	doc_392411160228_item	2364479	et	4	main
ma	doc_392411160228_item	2364481	et	3	main
kindel	doc_392411160228_item	2364483	et	3	main
tähtist	doc_392411160228_item	2364486	et	4	main
sammu	doc_392411160228_item	2364487	et	4	main
teen	doc_392411160228_item	2364490	et	3	main
jaoks	doc_392411160228_item	2364495	et	4	main
mina	doc_392411160229_item	2364497	et	4	main
ülikool	doc_392411160229_item	2364499	et	4	main
minu	doc_392411160229_item	2364500	et	3	main
nimi	doc_392411160229_item	2364501	et	3	main
ma	doc_392411160229_item	2364505	et	3	main
ühiksateist	doc_392411160229_item	2364507	et	4	main
vana	doc_392411160229_item	2364509	et	4	main
lõpetasin	doc_392411160229_item	2364517	et	3	main
läänemere	doc_392411160229_item	2364519	et	3	main
minu	doc_392411160229_item	2364521	et	3	main
seal	doc_392411160229_item	2364527	et	4	main
neli	doc_392411160229_item	2364529	et	3	main
liikmed	doc_392411160229_item	2364530	et	3	main
mina	doc_392411160229_item	2364531	et	4	main
minu	doc_392411160229_item	2364532	et	3	main
vanem	doc_392411160229_item	2364533	et	4	main
arvutid	doc_392411160229_item	2364544	et	4	main
võrkpalli	doc_392411160229_item	2364548	et	4	main
juba	doc_392411160229_item	2364549	et	3	main
viis	doc_392411160229_item	2364550	et	4	main
aastat	doc_392411160229_item	2364551	et	3	main
arvuti	doc_392411160229_item	2364558	et	4	main
tehnika	doc_392411160229_item	2364592	et	4	main
on	doc_392411160229_item	2364597	et	4	main
suur	doc_392411160229_item	2364599	et	3	main
liiga	doc_392411160229_item	2364602	et	4	main
inimesed	doc_392411160229_item	2364609	et	3	main
aga	doc_392411160229_item	2364614	et	3	main
siin	doc_392411160229_item	2364621	et	4	main
liikuvad	doc_392411160229_item	2364631	et	4	main
ja	doc_392411160229_item	2364642	et	3	main
üks	doc_392411160229_item	2364643	et	3	main
õppida	doc_392411160229_item	2364661	et	3	main
keelt	doc_392411160229_item	2364663	et	4	main
välismaal	doc_392411160229_item	2364676	et	4	main
ja	doc_392411160229_item	2364677	et	3	main
siinpool	doc_392411160229_item	2364684	et	3	main
lugege	doc_397823701987_item	2364686	et	3	main
kas	doc_397823701987_item	2364690	et	3	main
sellega	doc_397823701987_item	2364692	et	3	main
või	doc_397823701987_item	2364694	et	4	main
ja	doc_397823701987_item	2364698	et	3	main
120	doc_397823701987_item	2364705	et	2	main
sõna	doc_397823701987_item	2364706	et	4	main
oskamine	doc_397823701987_item	2364709	et	4	main
ajal	doc_397823701987_item	2364715	et	4	main
mulle	doc_397823701987_item	2364720	et	4	main
vaja	doc_397823701987_item	2364730	et	4	main
teada	doc_397823701987_item	2364731	et	3	main
keelte	doc_397823701987_item	2364733	et	3	main
või	doc_397823701987_item	2364737	et	4	main
rohkem	doc_397823701987_item	2364746	et	4	main
võimalusi	doc_397823701987_item	2364747	et	3	main
tänapäeval	doc_397823701987_item	2364755	et	3	main
ka	doc_397823701987_item	2364758	et	3	main
võõrkeelt	doc_397823701987_item	2364761	et	4	main
praegu	doc_397823701987_item	2364810	et	3	main
kui	doc_397823701987_item	2364816	et	3	main
kompuutri	doc_397823701987_item	2364819	et	4	main
on	doc_397823701987_item	2364823	et	4	main
ma	doc_397823701987_item	2364827	et	3	main
on	doc_397823701987_item	2364831	et	4	main
vajab	doc_397823701987_item	2364844	et	3	main
kui	doc_397823701987_item	2364852	et	3	main
ole	doc_392411160229_item	2364524	et	4	main
õde	doc_392411160229_item	2364534	et	4	main
minu	doc_392411160229_item	2364535	et	3	main
ema	doc_392411160229_item	2364536	et	4	main
ja	doc_392411160229_item	2364537	et	3	main
isa	doc_392411160229_item	2364538	et	4	main
ja	doc_392411160229_item	2364543	et	3	main
ma	doc_392411160229_item	2364546	et	3	main
ma	doc_392411160229_item	2364552	et	3	main
valitsin	doc_392411160229_item	2364553	et	4	main
mind	doc_392411160229_item	2364561	et	4	main
see	doc_392411160229_item	2364570	et	3	main
on	doc_392411160229_item	2364571	et	4	main
minu	doc_392411160229_item	2364572	et	3	main
hobbi	doc_392411160229_item	2364573	et	4	main
ja	doc_392411160229_item	2364574	et	3	main
ma	doc_392411160229_item	2364575	et	3	main
kavatsen	doc_392411160229_item	2364576	et	3	main
et	doc_392411160229_item	2364577	et	3	main
see	doc_392411160229_item	2364578	et	3	main
minu	doc_392411160229_item	2364579	et	3	main
hobbi	doc_392411160229_item	2364580	et	4	main
oleks	doc_392411160229_item	2364581	et	3	main
tulevikus	doc_392411160229_item	2364582	et	4	main
minu	doc_392411160229_item	2364583	et	3	main
erialaks	doc_392411160229_item	2364584	et	3	main
minu	doc_392411160229_item	2364585	et	3	main
esimene	doc_392411160229_item	2364586	et	3	main
mulje	doc_392411160229_item	2364587	et	4	main
kui	doc_392411160229_item	2364588	et	3	main
ma	doc_392411160229_item	2364589	et	3	main
astusin	doc_392411160229_item	2364590	et	3	main
tallinna	doc_392411160229_item	2364591	et	4	main
see	doc_392411160229_item	2364596	et	3	main
ja	doc_392411160229_item	2364601	et	3	main
sarnane	doc_392411160229_item	2364603	et	4	main
kooliga	doc_392411160229_item	2364604	et	4	main
palju	doc_392411160229_item	2364608	et	4	main
sarnased	doc_392411160229_item	2364613	et	4	main
et	doc_392411160229_item	2364617	et	3	main
on	doc_392411160229_item	2364619	et	4	main
üritused	doc_392411160229_item	2364625	et	4	main
arvates	doc_392411160229_item	2364630	et	4	main
nagu	doc_392411160229_item	2364634	et	3	main
tugev	doc_392411160229_item	2364641	et	4	main
tahaksin	doc_392411160229_item	2364660	et	3	main
eesti	doc_392411160229_item	2364662	et	4	main
sellel	doc_392411160229_item	2364664	et	4	main
tasemel	doc_392411160229_item	2364665	et	3	main
kui	doc_392411160229_item	2364666	et	3	main
ma	doc_392411160229_item	2364667	et	3	main
eestimaal	doc_392411160229_item	2364670	et	4	main
plaanis	doc_392411160229_item	2364679	et	4	main
aastad	doc_392411160229_item	2364683	et	3	main
mitte	doc_397823701987_item	2364695	et	3	main
umbes	doc_397823701987_item	2364704	et	4	main
meid	doc_397823701987_item	2364711	et	4	main
väga	doc_392411160229_item	2364623	et	3	main
semenaarid	doc_392411160229_item	2364627	et	4	main
minu	doc_392411160229_item	2364629	et	3	main
kuulsin	doc_392411160229_item	2364636	et	3	main
on	doc_392411160229_item	2364638	et	4	main
kõige	doc_392411160229_item	2364644	et	4	main
tehnika	doc_392411160229_item	2364646	et	4	main
ülikool	doc_392411160229_item	2364647	et	4	main
ja	doc_392411160229_item	2364648	et	3	main
seejärel	doc_392411160229_item	2364649	et	3	main
ülikoolil	doc_392411160229_item	2364654	et	4	main
õppida	doc_392411160229_item	2364655	et	3	main
eesti	doc_392411160229_item	2364656	et	4	main
keele	doc_392411160229_item	2364657	et	4	main
loengutega	doc_392411160229_item	2364658	et	4	main
just	doc_392411160229_item	2364652	et	3	main
sellel	doc_392411160229_item	2364653	et	4	main
töötada	doc_392411160229_item	2364669	et	3	main
sest	doc_392411160229_item	2364671	et	4	main
ma	doc_392411160229_item	2364672	et	3	main
ei	doc_392411160229_item	2364673	et	4	main
tahaksin	doc_392411160229_item	2364674	et	3	main
sõitma	doc_392411160229_item	2364675	et	3	main
töötama	doc_392411160229_item	2364681	et	3	main
essee	doc_397823701987_item	2364685	et	4	main
väidet	doc_397823701987_item	2364687	et	3	main
nõus	doc_397823701987_item	2364693	et	4	main
olema	doc_397823701987_item	2364703	et	4	main
elus	doc_397823701987_item	2364712	et	4	main
edasi	doc_397823701987_item	2364713	et	3	main
õppin	doc_397823701987_item	2364717	et	4	main
keelt	doc_397823701987_item	2364719	et	4	main
kui	doc_397823701987_item	2364722	et	3	main
on	doc_397823701987_item	2364729	et	4	main
rohkem	doc_397823701987_item	2364732	et	4	main
saksa	doc_397823701987_item	2364738	et	4	main
praegu	doc_397823701987_item	2364740	et	3	main
sõita	doc_397823701987_item	2364748	et	3	main
inimesed	doc_397823701987_item	2364752	et	3	main
võõrkeelt	doc_397823701987_item	2364754	et	4	main
praegu	doc_397823701987_item	2364762	et	3	main
majal	doc_397823701987_item	2364764	et	3	main
lapsega	doc_397823701987_item	2364770	et	3	main
väälismaal	doc_397823701987_item	2364773	et	4	main
meie	doc_397823701987_item	2364775	et	4	main
rohkem	doc_397823701987_item	2364777	et	4	main
abistab	doc_397823701987_item	2364812	et	3	main
vanem	doc_397823701987_item	2364814	et	4	main
istun	doc_397823701987_item	2364818	et	3	main
kus	doc_397823701987_item	2364830	et	3	main
inglise	doc_397823701987_item	2364832	et	4	main
keelt	doc_397823701987_item	2364833	et	4	main
aga	doc_397823701987_item	2364834	et	3	main
midagi	doc_397823701987_item	2364839	et	4	main
see	doc_397823701987_item	2364840	et	3	main
halb	doc_397823701987_item	2364843	et	3	main
kõik	doc_397823701987_item	2364851	et	4	main
kirjutage	doc_397823701989_item	2365035	et	3	main
või	doc_397823701989_item	2365040	et	4	main
poolt-	doc_397823701989_item	2365043	et	4	main
ja	doc_397823701989_item	2365044	et	3	main
vastuargumente	doc_397823701989_item	2365045	et	3	main
töö	doc_397823701989_item	2365046	et	4	main
pikkus	doc_397823701989_item	2365047	et	4	main
elus	doc_397823701989_item	2365058	et	4	main
korda	doc_397823701989_item	2365065	et	4	main
mul	doc_397823701989_item	2365086	et	3	main
keeles	doc_397823701989_item	2365104	et	4	main
eriti	doc_397823701989_item	2365105	et	3	main
telefooni	doc_397823701989_item	2365106	et	4	main
ma	doc_392411160229_item	2364659	et	3	main
saan	doc_392411160229_item	2364668	et	4	main
on	doc_392411160229_item	2364680	et	4	main
ja	doc_397823701987_item	2364688	et	3	main
esitage	doc_397823701987_item	2364696	et	3	main
vastuargumente	doc_397823701987_item	2364699	et	3	main
pikkus	doc_397823701987_item	2364701	et	4	main
väide	doc_397823701987_item	2364707	et	4	main
võõrkeelte	doc_397823701987_item	2364708	et	3	main
meeldib	doc_397823701987_item	2364721	et	3	main
saan	doc_397823701987_item	2364724	et	4	main
teistest	doc_397823701987_item	2364726	et	4	main
keelt	doc_397823701987_item	2364736	et	4	main
inimestel	doc_397823701987_item	2364745	et	3	main
kui	doc_397823701987_item	2364751	et	3	main
töö	doc_397823701987_item	2364757	et	4	main
kes	doc_397823701987_item	2364771	et	4	main
ja	doc_397823701987_item	2364774	et	3	main
suhtluskeelt	doc_397823701987_item	2364809	et	4	main
ees	doc_397823701987_item	2364820	et	4	main
mul	doc_397823701987_item	2364822	et	3	main
vaja	doc_397823701987_item	2364824	et	4	main
avan	doc_397823701987_item	2364828	et	3	main
ei	doc_397823701987_item	2364836	et	4	main
on	doc_397823701987_item	2364841	et	4	main
väga	doc_397823701987_item	2364842	et	3	main
ja	doc_397823701987_item	2364847	et	3	main
ja	doc_397823701987_item	2364849	et	3	main
te	doc_397823701987_item	2364854	et	4	main
olete	doc_397823701987_item	2364855	et	3	main
ma	doc_397823701987_item	2364723	et	3	main
inglise	doc_397823701987_item	2364735	et	4	main
keelt	doc_397823701987_item	2364739	et	4	main
on	doc_397823701987_item	2364741	et	4	main
väga	doc_397823701987_item	2364749	et	3	main
oskab	doc_397823701987_item	2364753	et	3	main
oskama	doc_397823701987_item	2364760	et	3	main
elab	doc_397823701987_item	2364772	et	3	main
oskavad	doc_397823701987_item	2364778	et	4	main
võõrkeelt	doc_397823701987_item	2364779	et	4	main
nad	doc_397823701987_item	2364780	et	3	main
kirjavahetusel	doc_397823701987_item	2364781	et	4	main
paljud	doc_397823701987_item	2364782	et	3	main
kursused	doc_397823701987_item	2364783	et	3	main
toimub	doc_397823701987_item	2364784	et	3	main
inglise	doc_397823701987_item	2364785	et	4	main
keelt	doc_397823701987_item	2364786	et	4	main
ma	doc_397823701987_item	2364787	et	3	main
tahaksin	doc_397823701987_item	2364788	et	3	main
õppida	doc_397823701987_item	2364789	et	3	main
inglise	doc_397823701987_item	2364790	et	4	main
keelt	doc_397823701987_item	2364791	et	4	main
see	doc_397823701987_item	2364792	et	3	main
on	doc_397823701987_item	2364793	et	4	main
populaarne	doc_397823701987_item	2364794	et	3	main
keel	doc_397823701987_item	2364795	et	4	main
paljudes	doc_397823701987_item	2364796	et	3	main
riigides	doc_397823701987_item	2364797	et	4	main
räägidakse	doc_397823701987_item	2364798	et	4	main
inglise	doc_397823701987_item	2364799	et	4	main
keelt	doc_397823701987_item	2364800	et	4	main
kui	doc_397823701987_item	2364801	et	3	main
ma	doc_397823701987_item	2364802	et	3	main
lähen	doc_397823701987_item	2364803	et	3	main
reisida	doc_397823701987_item	2364804	et	3	main
välismaale	doc_397823701987_item	2364805	et	4	main
ma	doc_397823701987_item	2364806	et	3	main
tahan	doc_397823701987_item	2364807	et	3	main
osada	doc_397823701987_item	2364808	et	4	main
nõudleb	doc_397823701987_item	2364759	et	3	main
igal	doc_397823701987_item	2364763	et	3	main
on	doc_397823701987_item	2364765	et	4	main
arvuti	doc_397823701987_item	2364766	et	4	main
lapsed	doc_397823701987_item	2364767	et	3	main
suhtevad	doc_397823701987_item	2364768	et	4	main
teistega	doc_397823701987_item	2364769	et	4	main
lapsed	doc_397823701987_item	2364776	et	3	main
mulle	doc_397823701987_item	2364811	et	4	main
ma	doc_397823701987_item	2364817	et	3	main
minu	doc_397823701987_item	2364813	et	3	main
poeg	doc_397823701987_item	2364815	et	3	main
ja	doc_397823701987_item	2364821	et	3	main
informatsiooni	doc_397823701987_item	2364826	et	4	main
lehekülje	doc_397823701987_item	2364829	et	3	main
saa	doc_397823701987_item	2364837	et	4	main
aru	doc_397823701987_item	2364838	et	4	main
õppida	doc_397823701987_item	2364845	et	3	main
õppida	doc_397823701987_item	2364848	et	3	main
üks	doc_397823701987_item	2364850	et	3	main
saada	doc_397823701987_item	2364825	et	4	main
mina	doc_397823701987_item	2364835	et	4	main
õppida	doc_397823701987_item	2364846	et	3	main
vana	doc_397823701987_item	2364853	et	4	main
essee	doc_397823701989_item	2365031	et	4	main
ja	doc_397823701989_item	2365034	et	3	main
olete	doc_397823701989_item	2365037	et	3	main
nõus	doc_397823701989_item	2365039	et	4	main
mitte	doc_397823701989_item	2365041	et	3	main
peab	doc_397823701989_item	2365048	et	4	main
lugege	doc_397823701989_item	2365032	et	3	main
olema	doc_397823701989_item	2365049	et	4	main
edasi	doc_397823701989_item	2365059	et	3	main
mina	doc_397823701989_item	2365060	et	4	main
õppisin	doc_397823701989_item	2365061	et	3	main
eesti	doc_397823701989_item	2365062	et	4	main
keelt	doc_397823701989_item	2365063	et	4	main
võimalust	doc_397823701989_item	2365088	et	3	main
rääkida	doc_397823701989_item	2365090	et	3	main
varem	doc_397823701989_item	2365099	et	4	main
praegu	doc_397823701989_item	2365109	et	3	main
päägin	doc_397823701989_item	2365111	et	4	main
teel	doc_397823701989_item	2365113	et	4	main
võin	doc_397823701989_item	2365120	et	3	main
töötada	doc_397823701989_item	2365123	et	3	main
eesti	doc_397823701989_item	2365125	et	4	main
keeles	doc_397823701989_item	2365126	et	4	main
või	doc_397823701989_item	2365131	et	4	main
konverentsid	doc_397823701989_item	2365137	et	3	main
harvam	doc_397823701989_item	2365145	et	4	main
rohkem	doc_397823701989_item	2365151	et	4	main
loen	doc_397823701989_item	2365156	et	3	main
õppida	doc_397823701989_item	2365173	et	3	main
kui	doc_397823701989_item	2365175	et	3	main
päevas	doc_397823701989_item	2365210	et	3	main
töötada	doc_397823701989_item	2365212	et	3	main
saan	doc_397823701989_item	2365219	et	4	main
aru	doc_397823701989_item	2365220	et	4	main
et	doc_397823701989_item	2365221	et	3	main
ametlik	doc_397823701990_item	2365226	et	3	main
lugege	doc_397823701990_item	2365228	et	3	main
vastake	doc_397823701990_item	2365232	et	3	main
kirjas	doc_397823701990_item	2365234	et	4	main
keelteoskus	doc_397823701990_item	2365245	et	3	main
autojuhiload	doc_397823701990_item	2365247	et	4	main
ja	doc_397823701990_item	2365249	et	3	main
pärast	doc_397823701990_item	2365265	et	4	main
vajatakse	doc_397823701990_item	2365270	et	4	main
kassapidajaid	doc_397823701990_item	2365272	et	3	main
koristajaid	doc_397823701990_item	2365274	et	4	main
3	doc_397823701990_item	2365307	et	2	main
kalevi	doc_397823701990_item	2365313	et	3	main
lugesin	doc_397823701990_item	2365320	et	3	main
põhjarannik	doc_397823701990_item	2365322	et	3	main
aastane	doc_397823701990_item	2365334	et	4	main
üks	doc_397823701990_item	2365342	et	3	main
mees	doc_397823701990_item	2365345	et	4	main
aga	doc_397823701990_item	2365347	et	3	main
suhtlemisatis	doc_397823701990_item	2365355	et	3	main
valda	doc_397823701990_item	2365357	et	4	main
ja	doc_397823701990_item	2365361	et	3	main
aastal	doc_397823701990_item	2365366	et	3	main
ma	doc_397823701990_item	2365384	et	3	main
ettepanekud	doc_397823701990_item	2365393	et	3	main
kui	doc_397823701990_item	2365395	et	3	main
töödata	doc_397823701990_item	2365400	et	4	main
080605a	doc_397823701990_item	2365402	et	4	main
mitte	doc_397823701991_item	2365416	et	3	main
väidet	doc_397823701989_item	2365033	et	3	main
kas	doc_397823701989_item	2365036	et	3	main
sellega	doc_397823701989_item	2365038	et	3	main
esitage	doc_397823701989_item	2365042	et	3	main
umbes	doc_397823701989_item	2365050	et	4	main
siis	doc_397823701989_item	2365093	et	3	main
mina	doc_397823701989_item	2365100	et	4	main
kardasin	doc_397823701989_item	2365101	et	3	main
rääkida	doc_397823701989_item	2365102	et	3	main
eesti	doc_397823701989_item	2365103	et	4	main
aga	doc_397823701989_item	2365108	et	3	main
mina	doc_397823701989_item	2365110	et	4	main
telefooni	doc_397823701989_item	2365112	et	4	main
peamiselt	doc_397823701989_item	2365114	et	4	main
ka	doc_397823701989_item	2365115	et	3	main
120	doc_397823701989_item	2365051	et	2	main
sõna	doc_397823701989_item	2365052	et	4	main
võõrkeelte	doc_397823701989_item	2365054	et	3	main
aitab	doc_397823701989_item	2365056	et	3	main
kursustel	doc_397823701989_item	2365066	et	3	main
ja	doc_397823701989_item	2365067	et	3	main
räägin	doc_397823701989_item	2365068	et	3	main
juba	doc_397823701989_item	2365069	et	3	main
keskmiselt	doc_397823701989_item	2365070	et	4	main
eesti	doc_397823701989_item	2365071	et	4	main
keeles	doc_397823701989_item	2365072	et	4	main
eesti	doc_397823701989_item	2365074	et	4	main
1	doc_397823701989_item	2365073	et	2	main
keel	doc_397823701989_item	2365075	et	4	main
aitab	doc_397823701989_item	2365076	et	3	main
mind	doc_397823701989_item	2365077	et	4	main
rohkem	doc_397823701989_item	2365078	et	4	main
suhelda	doc_397823701989_item	2365079	et	4	main
eestlastega	doc_397823701989_item	2365080	et	4	main
mina	doc_397823701989_item	2365081	et	4	main
meelsasti	doc_397823701989_item	2365082	et	3	main
tutvan	doc_397823701989_item	2365083	et	4	main
väide	doc_397823701989_item	2365053	et	4	main
oskamine	doc_397823701989_item	2365055	et	4	main
meid	doc_397823701989_item	2365057	et	4	main
mittu	doc_397823701989_item	2365064	et	4	main
kui	doc_397823701989_item	2365085	et	3	main
kuskel	doc_397823701989_item	2365089	et	4	main
keeles	doc_397823701989_item	2365092	et	4	main
mina	doc_397823701989_item	2365094	et	4	main
ainult	doc_397823701989_item	2365096	et	4	main
eesti	doc_397823701989_item	2365097	et	4	main
teel	doc_397823701989_item	2365107	et	4	main
kahjuks	doc_397823701989_item	2365127	et	4	main
ja	doc_397823701989_item	2365138	et	3	main
toimuvad	doc_397823701989_item	2365140	et	4	main
peamiselt	doc_397823701989_item	2365141	et	4	main
materjal	doc_397823701989_item	2365152	et	3	main
ja	doc_397823701989_item	2365155	et	3	main
1	doc_397823701989_item	2365164	et	2	main
minu	doc_397823701989_item	2365165	et	3	main
jaoks	doc_397823701989_item	2365166	et	4	main
eesti	doc_397823701989_item	2365167	et	4	main
raske	doc_397823701989_item	2365172	et	4	main
on	doc_397823701989_item	2365222	et	4	main
kuulutus	doc_397823701990_item	2365230	et	4	main
sellele	doc_397823701990_item	2365233	et	4	main
töökogemused	doc_397823701990_item	2365244	et	3	main
kirjutage	doc_397823701990_item	2365250	et	3	main
kui	doc_397823701990_item	2365256	et	3	main
avatakse	doc_397823701990_item	2365266	et	4	main
uus	doc_397823701990_item	2365267	et	3	main
tartu	doc_397823701990_item	2365305	et	4	main
tallinn	doc_397823701990_item	2365308	et	4	main
juhatajale	doc_397823701990_item	2365310	et	4	main
44-34	doc_397823701990_item	2365314	et	2	main
järve	doc_397823701990_item	2365316	et	4	main
nendega	doc_397823701989_item	2365084	et	4	main
on	doc_397823701989_item	2365087	et	4	main
eesti	doc_397823701989_item	2365091	et	4	main
räägin	doc_397823701989_item	2365095	et	3	main
keeles	doc_397823701989_item	2365098	et	4	main
keeles	doc_397823701989_item	2365117	et	4	main
2	doc_397823701989_item	2365118	et	2	main
mina	doc_397823701989_item	2365119	et	4	main
praegu	doc_397823701989_item	2365121	et	3	main
et	doc_397823701989_item	2365128	et	3	main
ma	doc_397823701989_item	2365129	et	3	main
kirjutada	doc_397823701989_item	2365132	et	3	main
ilma	doc_397823701989_item	2365133	et	4	main
vigadeta	doc_397823701989_item	2365134	et	3	main
simpoosiumid	doc_397823701989_item	2365139	et	4	main
keeles	doc_397823701989_item	2365143	et	4	main
ja	doc_397823701989_item	2365144	et	3	main
inglise	doc_397823701989_item	2365146	et	4	main
keeles	doc_397823701989_item	2365147	et	4	main
mina	doc_397823701989_item	2365148	et	4	main
sain	doc_397823701989_item	2365149	et	3	main
aru	doc_397823701989_item	2365150	et	4	main
varem	doc_397823701989_item	2365154	et	4	main
mulle	doc_397823701989_item	2365171	et	4	main
seda	doc_397823701989_item	2365174	et	3	main
aita	doc_397823701989_item	2365217	et	4	main
aga	doc_397823701989_item	2365218	et	3	main
eesti	doc_397823701989_item	2365116	et	4	main
rohkem	doc_397823701989_item	2365122	et	4	main
töödokumendidega	doc_397823701989_item	2365124	et	4	main
ei	doc_397823701989_item	2365130	et	4	main
3	doc_397823701989_item	2365135	et	2	main
meditsiinikoosolekud	doc_397823701989_item	2365136	et	3	main
eesti	doc_397823701989_item	2365142	et	4	main
kui	doc_397823701989_item	2365153	et	3	main
neid	doc_397823701989_item	2365157	et	4	main
loenguid	doc_397823701989_item	2365158	et	4	main
keelt	doc_397823701989_item	2365168	et	4	main
võõras	doc_397823701989_item	2365169	et	4	main
radiost	doc_397823701989_item	2365176	et	3	main
selles	doc_397823701989_item	2365209	et	4	main
ja	doc_397823701989_item	2365211	et	3	main
tööl	doc_397823701989_item	2365213	et	3	main
mõnikord	doc_397823701989_item	2365214	et	3	main
vaja	doc_397823701989_item	2365223	et	4	main
peab	doc_397823701990_item	2365235	et	4	main
ennast	doc_397823701990_item	2365241	et	4	main
perekonnaseis	doc_397823701990_item	2365242	et	4	main
oma	doc_397823701990_item	2365251	et	4	main
tööd	doc_397823701990_item	2365254	et	4	main
kauplusesse	doc_397823701990_item	2365269	et	4	main
müüjat	doc_397823701990_item	2365271	et	4	main
as	doc_397823701990_item	2365303	et	4	main
ajalehest	doc_397823701990_item	2365321	et	4	main
teie	doc_397823701990_item	2365323	et	4	main
töötajad	doc_397823701990_item	2365329	et	4	main
laps	doc_397823701990_item	2365343	et	4	main
mina	doc_397823701990_item	2365353	et	4	main
olen	doc_397823701990_item	2365354	et	3	main
ja	doc_397823701990_item	2365356	et	3	main
inglise	doc_397823701990_item	2365360	et	4	main
natukene	doc_397823701990_item	2365362	et	4	main
töötada	doc_397823701990_item	2365386	et	3	main
läbivaadata	doc_397823701990_item	2365394	et	4	main
lugege	doc_397823701991_item	2365407	et	3	main
ja	doc_397823701991_item	2365409	et	3	main
olete	doc_397823701991_item	2365412	et	3	main
nõus	doc_397823701991_item	2365414	et	4	main
või	doc_397823701991_item	2365415	et	4	main
ja	doc_397823701991_item	2365419	et	3	main
pikkus	doc_397823701991_item	2365422	et	4	main
sõna	doc_397823701991_item	2365427	et	4	main
mina	doc_397823701991_item	2365435	et	4	main
olen	doc_397823701991_item	2365436	et	3	main
pärit	doc_397823701991_item	2365437	et	3	main
olen	doc_397823701991_item	2365440	et	3	main
aastat	doc_397823701991_item	2365442	et	3	main
oskama	doc_397823701991_item	2365447	et	3	main
koolis	doc_397823701991_item	2365462	et	4	main
ja	doc_397823701991_item	2365465	et	3	main
aga	doc_397823701991_item	2365480	et	3	main
kes	doc_397823701991_item	2365483	et	4	main
neid	doc_397823701991_item	2365486	et	4	main
võib	doc_397823701991_item	2365487	et	3	main
õppida	doc_397823701991_item	2365488	et	3	main
arvan	doc_397823701991_item	2365492	et	3	main
ma	doc_397823701991_item	2365498	et	3	main
ilus	doc_397823701991_item	2365526	et	4	main
ma	doc_397823701991_item	2365528	et	3	main
uut	doc_397823701991_item	2365535	et	3	main
järgi	doc_397823701991_item	2365538	et	4	main
ei	doc_397823701991_item	2365543	et	4	main
kes	doc_397823701991_item	2365546	et	4	main
valdab	doc_397823701991_item	2365547	et	3	main
omab	doc_397823701991_item	2365550	et	3	main
kui	doc_397823701989_item	2365159	et	3	main
neid	doc_397823701989_item	2365160	et	4	main
sain	doc_397823701989_item	2365161	et	3	main
kätte	doc_397823701989_item	2365162	et	4	main
vastuargumente	doc_397823701989_item	2365163	et	3	main
keel	doc_397823701989_item	2365170	et	4	main
või	doc_397823701989_item	2365177	et	4	main
telerist	doc_397823701989_item	2365178	et	4	main
inimesed	doc_397823701989_item	2365179	et	3	main
räägivad	doc_397823701989_item	2365180	et	3	main
ruttu	doc_397823701989_item	2365181	et	4	main
eesti	doc_397823701989_item	2365182	et	4	main
keeles	doc_397823701989_item	2365183	et	4	main
mulle	doc_397823701989_item	2365184	et	4	main
on	doc_397823701989_item	2365185	et	4	main
näha	doc_397823701989_item	2365186	et	3	main
mõnikord	doc_397823701989_item	2365187	et	3	main
et	doc_397823701989_item	2365188	et	3	main
keel	doc_397823701989_item	2365189	et	4	main
on	doc_397823701989_item	2365190	et	4	main
nagu	doc_397823701989_item	2365191	et	3	main
jõgi	doc_397823701989_item	2365192	et	3	main
voolab	doc_397823701989_item	2365193	et	3	main
ja	doc_397823701989_item	2365194	et	3	main
mina	doc_397823701989_item	2365195	et	4	main
kuulen	doc_397823701989_item	2365196	et	3	main
meelsasti	doc_397823701989_item	2365197	et	3	main
aga	doc_397823701989_item	2365198	et	3	main
ei	doc_397823701989_item	2365199	et	4	main
saa	doc_397823701989_item	2365200	et	4	main
aru	doc_397823701989_item	2365201	et	4	main
2	doc_397823701989_item	2365202	et	2	main
mulle	doc_397823701989_item	2365203	et	4	main
raske	doc_397823701989_item	2365204	et	4	main
oppida	doc_397823701989_item	2365205	et	4	main
eesti	doc_397823701989_item	2365206	et	4	main
keelt	doc_397823701989_item	2365207	et	4	main
ja	doc_397823701989_item	2365208	et	3	main
jõudu	doc_397823701989_item	2365215	et	4	main
ei	doc_397823701989_item	2365216	et	4	main
võõrkeelt	doc_397823701989_item	2365225	et	4	main
läbi	doc_397823701990_item	2365229	et	4	main
ja	doc_397823701990_item	2365231	et	3	main
umbes	doc_397823701990_item	2365237	et	4	main
60	doc_397823701990_item	2365238	et	2	main
sõna	doc_397823701990_item	2365239	et	4	main
tutvustage	doc_397823701990_item	2365240	et	3	main
arvutioskus	doc_397823701990_item	2365246	et	3	main
soovidest	doc_397823701990_item	2365252	et	3	main
millist	doc_397823701990_item	2365253	et	3	main
suurt	doc_397823701990_item	2365257	et	3	main
töötasu	doc_397823701990_item	2365258	et	4	main
soovite	doc_397823701990_item	2365259	et	3	main
milline	doc_397823701990_item	2365260	et	3	main
töögraafik	doc_397823701990_item	2365261	et	3	main
sobib	doc_397823701990_item	2365262	et	3	main
kahe	doc_397823701990_item	2365263	et	3	main
kuu	doc_397823701990_item	2365264	et	4	main
turvamehi	doc_397823701990_item	2365273	et	3	main
mnt	doc_397823701990_item	2365306	et	4	main
taidukaupluse	doc_397823701990_item	2365309	et	4	main
perekonnanimi	doc_397823701990_item	2365312	et	3	main
avaldus	doc_397823701990_item	2365319	et	4	main
teil	doc_397823701990_item	2365326	et	4	main
vajat	doc_397823701990_item	2365328	et	4	main
kauplusesse	doc_397823701990_item	2365330	et	4	main
ja	doc_397823701990_item	2365339	et	3	main
vene	doc_397823701990_item	2365359	et	4	main
eelmisel	doc_397823701990_item	2365365	et	3	main
tahaksin	doc_397823701990_item	2365385	et	3	main
pikk	doc_397823701990_item	2365396	et	4	main
ja	doc_397823701990_item	2365398	et	3	main
perekonnanimi	doc_397823701990_item	2365405	et	3	main
väidet	doc_397823701991_item	2365408	et	3	main
kas	doc_397823701991_item	2365411	et	3	main
vastuargumente	doc_397823701991_item	2365420	et	3	main
umbes	doc_397823701991_item	2365425	et	4	main
väide	doc_397823701991_item	2365428	et	4	main
võõrkeelte	doc_397823701991_item	2365429	et	3	main
aitab	doc_397823701991_item	2365431	et	3	main
meid	doc_397823701991_item	2365432	et	4	main
ja	doc_397823701991_item	2365444	et	3	main
õppitasin	doc_397823701991_item	2365461	et	4	main
keelt	doc_397823701991_item	2365464	et	4	main
saaksa	doc_397823701991_item	2365466	et	4	main
keelt	doc_397823701991_item	2365467	et	4	main
praegu	doc_397823701991_item	2365468	et	3	main
käisin	doc_397823701991_item	2365469	et	3	main
umbes	doc_397823701991_item	2365470	et	4	main
10	doc_397823701991_item	2365471	et	2	main
eesti	doc_397823701991_item	2365478	et	4	main
tahan	doc_397823701991_item	2365482	et	3	main
valdavad	doc_397823701991_item	2365484	et	4	main
võõrkkeeli	doc_397823701991_item	2365485	et	4	main
ma	doc_397823701991_item	2365491	et	3	main
jargmisel	doc_397823701991_item	2365496	et	4	main
oli	doc_397823701991_item	2365503	et	3	main
kõrvaklapideta	doc_397823701991_item	2365522	et	4	main
see	doc_397823701991_item	2365523	et	3	main
keel	doc_397823701991_item	2365527	et	4	main
tahan	doc_397823701991_item	2365529	et	3	main
töö	doc_397823701991_item	2365537	et	4	main
tea	doc_397823701991_item	2365544	et	4	main
võrkeele	doc_397823701991_item	2365548	et	3	main
palju	doc_397823701991_item	2365551	et	4	main
informatssiooni	doc_397823701991_item	2365552	et	4	main
õppida	doc_397823701989_item	2365224	et	3	main
kiri	doc_397823701990_item	2365227	et	3	main
olema	doc_397823701990_item	2365236	et	4	main
haridus	doc_397823701990_item	2365243	et	3	main
hobid	doc_397823701990_item	2365248	et	3	main
soovite	doc_397823701990_item	2365255	et	3	main
toidukauplus	doc_397823701990_item	2365268	et	3	main
pakkijaid	doc_397823701990_item	2365275	et	4	main
kandidaatidelt	doc_397823701990_item	2365276	et	3	main
ootame	doc_397823701990_item	2365277	et	3	main
eesti	doc_397823701990_item	2365278	et	4	main
ja	doc_397823701990_item	2365279	et	3	main
vene	doc_397823701990_item	2365280	et	4	main
keele	doc_397823701990_item	2365281	et	4	main
oskust	doc_397823701990_item	2365282	et	3	main
head	doc_397823701990_item	2365283	et	4	main
suhtlemisoskust	doc_397823701990_item	2365284	et	3	main
soovitav	doc_397823701990_item	2365285	et	4	main
on	doc_397823701990_item	2365286	et	4	main
ka	doc_397823701990_item	2365287	et	3	main
arvutikasutamisoskus	doc_397823701990_item	2365288	et	3	main
pakume	doc_397823701990_item	2365289	et	3	main
mugavaid	doc_397823701990_item	2365290	et	3	main
töötingimusi	doc_397823701990_item	2365291	et	3	main
teile	doc_397823701990_item	2365292	et	4	main
sobivat	doc_397823701990_item	2365293	et	4	main
töögraafikut	doc_397823701990_item	2365294	et	3	main
kindlat	doc_397823701990_item	2365295	et	3	main
palka	doc_397823701990_item	2365296	et	4	main
lisainfo	doc_397823701990_item	2365297	et	4	main
as	doc_397823701990_item	2365298	et	4	main
kakuke	doc_397823701990_item	2365299	et	4	main
tartu	doc_397823701990_item	2365300	et	4	main
mnt3	doc_397823701990_item	2365301	et	4	main
tallinn	doc_397823701990_item	2365302	et	4	main
kakuke	doc_397823701990_item	2365304	et	4	main
eesnimi	doc_397823701990_item	2365311	et	3	main
kohtla	doc_397823701990_item	2365315	et	4	main
tel	doc_397823701990_item	2365317	et	4	main
00000	doc_397823701990_item	2365318	et	2	main
et	doc_397823701990_item	2365325	et	3	main
mina	doc_397823701990_item	2365331	et	4	main
30	doc_397823701990_item	2365333	et	2	main
vana	doc_397823701990_item	2365335	et	4	main
ma	doc_397823701990_item	2365336	et	3	main
olen	doc_397823701990_item	2365337	et	3	main
abielus	doc_397823701990_item	2365338	et	4	main
mul	doc_397823701990_item	2365340	et	3	main
t	doc_397823701990_item	2365352	et	4	main
eesti	doc_397823701990_item	2365358	et	4	main
soome	doc_397823701990_item	2365363	et	3	main
aga	doc_397823701990_item	2365388	et	3	main
võivad	doc_397823701990_item	2365390	et	4	main
teie	doc_397823701990_item	2365392	et	4	main
tahaksin	doc_397823701990_item	2365399	et	3	main
päevas	doc_397823701990_item	2365401	et	3	main
e	doc_397823701990_item	2365404	et	4	main
esitage	doc_397823701991_item	2365417	et	3	main
töö	doc_397823701991_item	2365421	et	4	main
120	doc_397823701991_item	2365426	et	2	main
oskamine	doc_397823701991_item	2365430	et	4	main
eestist	doc_397823701991_item	2365438	et	3	main
vana	doc_397823701991_item	2365443	et	4	main
võimaluse	doc_397823701991_item	2365449	et	3	main
avaneb	doc_397823701991_item	2365457	et	3	main
varem	doc_397823701991_item	2365460	et	4	main
a	doc_397823701991_item	2365472	et	4	main
aga	doc_397823701991_item	2365474	et	3	main
keelt	doc_397823701991_item	2365479	et	4	main
palju	doc_397823701991_item	2365493	et	4	main
nädalal	doc_397823701991_item	2365497	et	3	main
jurmalas	doc_397823701991_item	2365500	et	4	main
koolituses	doc_397823701991_item	2365501	et	4	main
ja	doc_397823701991_item	2365506	et	3	main
väga	doc_397823701991_item	2365525	et	3	main
käja	doc_397823701991_item	2365530	et	4	main
inglis	doc_397823701991_item	2365531	et	3	main
keeles	doc_397823701991_item	2365532	et	4	main
kursusel	doc_397823701991_item	2365533	et	3	main
palju	doc_397823701991_item	2365534	et	4	main
ingliskeeles	doc_397823701991_item	2365540	et	4	main
ja	doc_397823701991_item	2365541	et	3	main
lugege	doc_397823701993_item	2365721	et	3	main
ja	doc_397823701993_item	2365723	et	3	main
pikkus	doc_397823701993_item	2365736	et	4	main
sõna	doc_397823701993_item	2365741	et	4	main
elus	doc_397823701993_item	2365759	et	4	main
igal	doc_397823701993_item	2365771	et	3	main
päeval	doc_397823701993_item	2365772	et	3	main
seadmete	doc_397823701993_item	2365779	et	3	main
inglise	doc_397823701993_item	2365826	et	4	main
keeles	doc_397823701993_item	2365838	et	4	main
kuulutust	doc_397823701990_item	2365324	et	4	main
on	doc_397823701990_item	2365327	et	4	main
olen	doc_397823701990_item	2365332	et	3	main
on	doc_397823701990_item	2365341	et	4	main
minu	doc_397823701990_item	2365344	et	3	main
töötab	doc_397823701990_item	2365346	et	3	main
mina	doc_397823701990_item	2365348	et	4	main
vajan	doc_397823701990_item	2365349	et	3	main
t	doc_397823701990_item	2365350	et	4	main
öö	doc_397823701990_item	2365351	et	4	main
keeled	doc_397823701990_item	2365364	et	3	main
käisin	doc_397823701990_item	2365367	et	3	main
kursusel	doc_397823701990_item	2365368	et	3	main
ja	doc_397823701990_item	2365369	et	3	main
sain	doc_397823701990_item	2365370	et	3	main
arvutitunnistuse	doc_397823701990_item	2365371	et	3	main
mul	doc_397823701990_item	2365372	et	3	main
arvutikasutamisoskus	doc_397823701990_item	2365374	et	3	main
on	doc_397823701990_item	2365373	et	4	main
ja	doc_397823701990_item	2365375	et	3	main
autojuhiload	doc_397823701990_item	2365376	et	4	main
kõrgharidus	doc_397823701990_item	2365379	et	3	main
mul	doc_397823701990_item	2365377	et	3	main
mina	doc_397823701990_item	2365380	et	4	main
lõpetasin	doc_397823701990_item	2365381	et	3	main
on	doc_397823701990_item	2365378	et	4	main
tü	doc_397823701990_item	2365382	et	4	main
majanduskursusel	doc_397823701990_item	2365383	et	3	main
müüjat	doc_397823701990_item	2365387	et	4	main
on	doc_397823701990_item	2365389	et	4	main
võimalus	doc_397823701990_item	2365391	et	3	main
tööpalk	doc_397823701990_item	2365397	et	3	main
lugupidamisega	doc_397823701990_item	2365403	et	3	main
essee	doc_397823701991_item	2365406	et	4	main
kirjutage	doc_397823701991_item	2365410	et	3	main
sellega	doc_397823701991_item	2365413	et	3	main
poolt-	doc_397823701991_item	2365418	et	4	main
peab	doc_397823701991_item	2365423	et	4	main
ma	doc_397823701991_item	2365445	et	3	main
riigikeelt	doc_397823701991_item	2365448	et	4	main
jne	doc_397823701991_item	2365455	et	4	main
see	doc_397823701991_item	2365456	et	3	main
uksed	doc_397823701991_item	2365459	et	3	main
kursusel	doc_397823701991_item	2365473	et	3	main
väga	doc_397823701991_item	2365481	et	3	main
seal	doc_397823701991_item	2365490	et	4	main
haridus	doc_397823701991_item	2365495	et	3	main
olin	doc_397823701991_item	2365499	et	3	main
see	doc_397823701991_item	2365502	et	3	main
rahvuvaheline	doc_397823701991_item	2365504	et	4	main
koolitus	doc_397823701991_item	2365505	et	4	main
ilma	doc_397823701991_item	2365521	et	4	main
informatsiooni	doc_397823701991_item	2365536	et	4	main
sellepärast	doc_397823701991_item	2365542	et	3	main
mõndagi	doc_397823701991_item	2365545	et	4	main
see	doc_397823701991_item	2365549	et	3	main
olema	doc_397823701991_item	2365424	et	4	main
elus	doc_397823701991_item	2365433	et	4	main
edasi	doc_397823701991_item	2365434	et	3	main
ma	doc_397823701991_item	2365439	et	3	main
30	doc_397823701991_item	2365441	et	2	main
pean	doc_397823701991_item	2365446	et	4	main
järgi	doc_397823701991_item	2365450	et	4	main
oskama	doc_397823701991_item	2365451	et	3	main
võõrkeelt	doc_397823701991_item	2365452	et	4	main
inglis	doc_397823701991_item	2365453	et	3	main
saaksa	doc_397823701991_item	2365454	et	4	main
paljud	doc_397823701991_item	2365458	et	3	main
eesti	doc_397823701991_item	2365463	et	4	main
ei	doc_397823701991_item	2365475	et	4	main
saa	doc_397823701991_item	2365476	et	4	main
selgeks	doc_397823701991_item	2365477	et	3	main
välismaal	doc_397823701991_item	2365489	et	4	main
erilisi	doc_397823701991_item	2365494	et	4	main
toimuvad	doc_397823701991_item	2365508	et	4	main
koolitus	doc_397823701991_item	2365507	et	4	main
inglise	doc_397823701991_item	2365509	et	4	main
keeles	doc_397823701991_item	2365510	et	4	main
ja	doc_397823701991_item	2365511	et	3	main
oli	doc_397823701991_item	2365513	et	3	main
tõlge	doc_397823701991_item	2365514	et	3	main
muidugi	doc_397823701991_item	2365512	et	4	main
aga	doc_397823701991_item	2365515	et	3	main
ma	doc_397823701991_item	2365516	et	3	main
tahksin	doc_397823701991_item	2365517	et	4	main
kuulata	doc_397823701991_item	2365518	et	4	main
ja	doc_397823701991_item	2365519	et	3	main
suhelda	doc_397823701991_item	2365520	et	4	main
on	doc_397823701991_item	2365524	et	4	main
interneetis	doc_397823701991_item	2365539	et	4	main
essee	doc_397823701993_item	2365720	et	4	main
olema	doc_397823701993_item	2365738	et	4	main
väide	doc_397823701993_item	2365742	et	4	main
see	doc_397823701993_item	2365757	et	3	main
et	doc_397823701993_item	2365762	et	3	main
vaja	doc_397823701993_item	2365776	et	4	main
võõrkeelt	doc_397823701993_item	2365778	et	4	main
instruktsioonid	doc_397823701993_item	2365780	et	3	main
reaktiivede	doc_397823701993_item	2365781	et	4	main
kirjatud	doc_397823701993_item	2365784	et	4	main
kirjutage	doc_397823701993_item	2365724	et	3	main
olete	doc_397823701993_item	2365726	et	3	main
nõus	doc_397823701993_item	2365728	et	4	main
esitage	doc_397823701993_item	2365731	et	3	main
poolt-	doc_397823701993_item	2365732	et	4	main
ja	doc_397823701993_item	2365733	et	3	main
peab	doc_397823701993_item	2365737	et	4	main
aitab	doc_397823701993_item	2365745	et	3	main
elus	doc_397823701993_item	2365747	et	4	main
räägitakse	doc_397823701993_item	2365750	et	3	main
aitab	doc_397823701993_item	2365758	et	3	main
tööl	doc_397823701993_item	2365774	et	3	main
ja	doc_397823701993_item	2365786	et	3	main
keeles	doc_397823701993_item	2365788	et	4	main
tihti	doc_397823701993_item	2365789	et	3	main
arvutis	doc_397823701993_item	2365823	et	4	main
eesti	doc_397823701993_item	2365841	et	4	main
keeles	doc_397823701993_item	2365854	et	4	main
töötada	doc_397823701993_item	2365882	et	3	main
huvitavate	doc_397823701993_item	2365884	et	4	main
kiri	doc_397823701994_item	2365887	et	3	main
60	doc_397823701994_item	2365898	et	2	main
tutvustage	doc_397823701994_item	2365900	et	3	main
kui	doc_397823701994_item	2365916	et	3	main
töötasu	doc_397823701994_item	2365918	et	4	main
töögraafik	doc_397823701994_item	2365921	et	3	main
uus	doc_397823701994_item	2365927	et	3	main
müüjat	doc_397823701994_item	2365931	et	4	main
kassapidajaid	doc_397823701994_item	2365932	et	3	main
turvamehi	doc_397823701994_item	2365933	et	3	main
koristajaid	doc_397823701994_item	2365934	et	4	main
ja	doc_397823701994_item	2365939	et	3	main
keele	doc_397823701994_item	2365941	et	4	main
töötingimusi	doc_397823701994_item	2365951	et	3	main
kindlat	doc_397823701994_item	2365955	et	3	main
tartu	doc_397823701994_item	2365960	et	4	main
mnt3	doc_397823701994_item	2365961	et	4	main
tartu	doc_397823701994_item	2365965	et	4	main
eesnimi	doc_397823701994_item	2365969	et	3	main
jaama	doc_397823701994_item	2365972	et	4	main
43	doc_397823701994_item	2365974	et	2	main
lugesin	doc_397823701994_item	2365982	et	3	main
tööd	doc_397823701994_item	2365989	et	4	main
uues	doc_397823701994_item	2365990	et	3	main
kaupluses	doc_397823701994_item	2365991	et	3	main
müüjana	doc_397823701994_item	2365992	et	4	main
mina	doc_397823701994_item	2365993	et	4	main
olen	doc_397823701994_item	2365994	et	3	main
aastat	doc_397823701994_item	2365996	et	3	main
abielus	doc_397823701994_item	2365999	et	4	main
peres	doc_397823701994_item	2366000	et	3	main
ja	doc_397823701994_item	2366014	et	3	main
kas	doc_397823701993_item	2365725	et	3	main
sellega	doc_397823701993_item	2365727	et	3	main
või	doc_397823701993_item	2365729	et	4	main
mitte	doc_397823701993_item	2365730	et	3	main
vastuargumente	doc_397823701993_item	2365734	et	3	main
töö	doc_397823701993_item	2365735	et	4	main
120	doc_397823701993_item	2365740	et	2	main
võõrkeelte	doc_397823701993_item	2365743	et	3	main
meid	doc_397823701993_item	2365746	et	4	main
edasi	doc_397823701993_item	2365748	et	3	main
me	doc_397823701993_item	2365752	et	4	main
peame	doc_397823701993_item	2365753	et	4	main
teadma	doc_397823701993_item	2365754	et	3	main
võõrkeelte	doc_397823701993_item	2365755	et	3	main
sest	doc_397823701993_item	2365756	et	4	main
see	doc_397823701993_item	2365763	et	3	main
õige	doc_397823701993_item	2365765	et	4	main
ma	doc_397823701993_item	2365766	et	3	main
töötan	doc_397823701993_item	2365767	et	3	main
haigla	doc_397823701993_item	2365768	et	4	main
laboriteenistuses	doc_397823701993_item	2365769	et	3	main
ja	doc_397823701993_item	2365770	et	3	main
meie	doc_397823701993_item	2365773	et	4	main
kasutada	doc_397823701993_item	2365777	et	3	main
juhendid	doc_397823701993_item	2365782	et	3	main
inglise	doc_397823701993_item	2365785	et	4	main
esindajatega	doc_397823701993_item	2365825	et	4	main
keeles	doc_397823701993_item	2365827	et	4	main
reisida	doc_397823701993_item	2365829	et	3	main
oma	doc_397823701993_item	2365830	et	4	main
riigis	doc_397823701993_item	2365831	et	3	main
ja	doc_397823701993_item	2365832	et	3	main
minu	doc_397823701993_item	2365839	et	3	main
ka	doc_397823701993_item	2365844	et	3	main
võõrkeel	doc_397823701993_item	2365845	et	4	main
suhtlen	doc_397823701993_item	2365847	et	3	main
oma	doc_397823701993_item	2365848	et	4	main
vene	doc_397823701993_item	2365849	et	4	main
inglise	doc_397823701993_item	2365853	et	4	main
peavad	doc_397823701993_item	2365857	et	4	main
võõrkeelte	doc_397823701993_item	2365859	et	3	main
aitavad	doc_397823701993_item	2365879	et	4	main
suhelda	doc_397823701993_item	2365881	et	4	main
tutvustada	doc_397823701993_item	2365883	et	3	main
inimestega	doc_397823701993_item	2365885	et	3	main
läbi	doc_397823701994_item	2365889	et	4	main
kuulutus	doc_397823701994_item	2365890	et	4	main
sellele	doc_397823701994_item	2365893	et	4	main
kirjas	doc_397823701994_item	2365894	et	4	main
soovite	doc_397823701994_item	2365915	et	3	main
soovite	doc_397823701994_item	2365919	et	3	main
väidet	doc_397823701993_item	2365722	et	3	main
umbes	doc_397823701993_item	2365739	et	4	main
oskamine	doc_397823701993_item	2365744	et	4	main
praegu	doc_397823701993_item	2365749	et	3	main
et	doc_397823701993_item	2365751	et	3	main
ma	doc_397823701993_item	2365760	et	3	main
arvan	doc_397823701993_item	2365761	et	3	main
on	doc_397823701993_item	2365764	et	4	main
on	doc_397823701993_item	2365775	et	4	main
on	doc_397823701993_item	2365783	et	4	main
saksa	doc_397823701993_item	2365787	et	4	main
ma	doc_397823701993_item	2365790	et	3	main
käin	doc_397823701993_item	2365791	et	3	main
koolitustel	doc_397823701993_item	2365792	et	4	main
seminaaridel	doc_397823701993_item	2365793	et	4	main
on	doc_397823701993_item	2365795	et	4	main
osalejad	doc_397823701993_item	2365794	et	4	main
erinevast	doc_397823701993_item	2365796	et	4	main
maadest	doc_397823701993_item	2365797	et	4	main
ja	doc_397823701993_item	2365798	et	3	main
kasvõi	doc_397823701993_item	2365799	et	3	main
pean	doc_397823701993_item	2365801	et	4	main
ma	doc_397823701993_item	2365800	et	3	main
teadma	doc_397823701993_item	2365802	et	3	main
inglise	doc_397823701993_item	2365803	et	4	main
keelt	doc_397823701993_item	2365804	et	4	main
suhtlemise	doc_397823701993_item	2365805	et	4	main
jaoks	doc_397823701993_item	2365806	et	4	main
tööl	doc_397823701993_item	2365807	et	3	main
ka	doc_397823701993_item	2365808	et	3	main
on	doc_397823701993_item	2365809	et	4	main
kasulik	doc_397823701993_item	2365810	et	3	main
võõrkeeleoskus	doc_397823701993_item	2365811	et	3	main
ma	doc_397823701993_item	2365812	et	3	main
töötan	doc_397823701993_item	2365813	et	3	main
vastutava	doc_397823701993_item	2365814	et	4	main
laborandina	doc_397823701993_item	2365815	et	3	main
ja	doc_397823701993_item	2365816	et	3	main
teen	doc_397823701993_item	2365817	et	3	main
tellimuseid	doc_397823701993_item	2365818	et	4	main
välismaalide	doc_397823701993_item	2365819	et	3	main
firmadest	doc_397823701993_item	2365820	et	3	main
suhtlen	doc_397823701993_item	2365822	et	3	main
armastan	doc_397823701993_item	2365828	et	3	main
välismaal	doc_397823701993_item	2365833	et	4	main
keel	doc_397823701993_item	2365842	et	4	main
mõnikord	doc_397823701993_item	2365852	et	3	main
lapsed	doc_397823701993_item	2365856	et	3	main
teadma	doc_397823701993_item	2365858	et	3	main
riigides	doc_397823701993_item	2365876	et	4	main
ning	doc_397823701993_item	2365821	et	3	main
firmade	doc_397823701993_item	2365824	et	3	main
oma	doc_397823701993_item	2365834	et	4	main
riigis	doc_397823701993_item	2365835	et	3	main
suhtlen	doc_397823701993_item	2365836	et	3	main
eesti	doc_397823701993_item	2365837	et	4	main
on	doc_397823701993_item	2365843	et	4	main
välismaal	doc_397823701993_item	2365846	et	4	main
meie	doc_397823701993_item	2365855	et	4	main
parem	doc_397823701993_item	2365860	et	4	main
kui	doc_397823701993_item	2365861	et	3	main
me	doc_397823701993_item	2365862	et	4	main
teame	doc_397823701993_item	2365863	et	3	main
me	doc_397823701993_item	2365864	et	4	main
elame	doc_397823701993_item	2365865	et	3	main
euroliigis	doc_397823701993_item	2365866	et	3	main
ja	doc_397823701993_item	2365867	et	3	main
noored	doc_397823701993_item	2365868	et	3	main
inimesed	doc_397823701993_item	2365869	et	3	main
õppida	doc_397823701993_item	2365871	et	3	main
saavad	doc_397823701993_item	2365870	et	4	main
ja	doc_397823701993_item	2365872	et	3	main
töötada	doc_397823701993_item	2365873	et	3	main
jaoks	doc_397823701993_item	2365840	et	4	main
keeles	doc_397823701993_item	2365850	et	4	main
ja	doc_397823701993_item	2365851	et	3	main
kõikides	doc_397823701993_item	2365874	et	4	main
euroliigi	doc_397823701993_item	2365875	et	4	main
võõrkeeled	doc_397823701993_item	2365878	et	3	main
ja	doc_397823701994_item	2365891	et	3	main
umbes	doc_397823701994_item	2365897	et	4	main
hobid	doc_397823701994_item	2365908	et	3	main
oma	doc_397823701994_item	2365911	et	4	main
suurt	doc_397823701994_item	2365917	et	3	main
milline	doc_397823701994_item	2365920	et	3	main
toidukauplus	doc_397823701994_item	2365928	et	3	main
vene	doc_397823701994_item	2365940	et	4	main
oskust	doc_397823701994_item	2365942	et	3	main
soovitav	doc_397823701994_item	2365945	et	4	main
sobivat	doc_397823701994_item	2365953	et	4	main
palka	doc_397823701994_item	2365956	et	4	main
lisainfo	doc_397823701994_item	2365957	et	4	main
tallinn	doc_397823701994_item	2365962	et	4	main
tallinn	doc_397823701994_item	2365968	et	4	main
43567	doc_397823701994_item	2365975	et	2	main
tel	doc_397823701994_item	2365977	et	4	main
as	doc_397823701994_item	2365979	et	4	main
ajalehest	doc_397823701994_item	2365983	et	4	main
vana	doc_397823701994_item	2365997	et	4	main
olen	doc_397823701994_item	2365998	et	3	main
kasvab	doc_397823701994_item	2366001	et	3	main
on	doc_397823701994_item	2366005	et	4	main
haridus	doc_397823701994_item	2366008	et	3	main
ma	doc_397823701994_item	2366019	et	3	main
töötada	doc_397823701994_item	2366024	et	3	main
kaks	doc_397823701994_item	2366026	et	3	main
lõpetasin	doc_397823701994_item	2366029	et	3	main
mulle	doc_397823701994_item	2366032	et	4	main
tundid	doc_397823701994_item	2366038	et	4	main
päevas	doc_397823701994_item	2366039	et	3	main
ma	doc_397823701994_item	2366040	et	3	main
ma	doc_397823701994_item	2366043	et	3	main
selle	doc_397823701994_item	2366045	et	4	main
sellega	doc_397823701995_item	2366059	et	3	main
või	doc_397823701995_item	2366061	et	4	main
mitte	doc_397823701995_item	2366062	et	3	main
esitage	doc_397823701995_item	2366063	et	3	main
poolt-	doc_397823701995_item	2366064	et	4	main
töö	doc_397823701995_item	2366067	et	4	main
peab	doc_397823701995_item	2366069	et	4	main
oskamine	doc_397823701995_item	2366076	et	4	main
edasi	doc_397823701995_item	2366080	et	3	main
võõrkeelte	doc_397823701995_item	2366086	et	3	main
edasi	doc_397823701995_item	2366091	et	3	main
me	doc_397823701995_item	2366100	et	4	main
abikaasa	doc_397823701995_item	2366107	et	4	main
vene	doc_397823701995_item	2366121	et	4	main
haiglas	doc_397823701995_item	2366125	et	3	main
aru	doc_397823701995_item	2366130	et	4	main
minu	doc_397823701995_item	2366135	et	3	main
patsiendid	doc_397823701995_item	2366137	et	3	main
saksamaal	doc_397823701995_item	2366141	et	4	main
me	doc_397823701995_item	2366145	et	4	main
neljandas	doc_397823701995_item	2366151	et	3	main
ta	doc_397823701995_item	2366156	et	4	main
kirjutab	doc_397823701995_item	2366157	et	3	main
sõnastikuga	doc_397823701995_item	2366168	et	3	main
aastat	doc_397823701995_item	2366175	et	3	main
ja	doc_397823701996_item	2366208	et	3	main
töökogemused	doc_397823701996_item	2366221	et	3	main
oma	doc_397823701996_item	2366228	et	4	main
soovite	doc_397823701996_item	2366232	et	3	main
pärast	doc_397823701996_item	2366242	et	4	main
kauplusesse	doc_397823701996_item	2366246	et	4	main
müüjat	doc_397823701996_item	2366248	et	4	main
kassapidajaid	doc_397823701996_item	2366249	et	3	main
turvamehi	doc_397823701996_item	2366250	et	3	main
koristajaid	doc_397823701996_item	2366251	et	4	main
vene	doc_397823701996_item	2366257	et	4	main
keele	doc_397823701996_item	2366258	et	4	main
kindlat	doc_397823701996_item	2366272	et	3	main
as	doc_397823701996_item	2366280	et	4	main
kakule	doc_397823701996_item	2366281	et	3	main
mnt	doc_397823701996_item	2366283	et	4	main
mulle	doc_397823701993_item	2365877	et	4	main
vastake	doc_397823701994_item	2365892	et	3	main
olema	doc_397823701994_item	2365896	et	4	main
perekonnaseis	doc_397823701994_item	2365902	et	4	main
haridus	doc_397823701994_item	2365903	et	3	main
ja	doc_397823701994_item	2365909	et	3	main
millist	doc_397823701994_item	2365913	et	3	main
kuu	doc_397823701994_item	2365924	et	4	main
avatakse	doc_397823701994_item	2365926	et	4	main
vajatakse	doc_397823701994_item	2365930	et	4	main
eesti	doc_397823701994_item	2365938	et	4	main
head	doc_397823701994_item	2365943	et	4	main
pakume	doc_397823701994_item	2365949	et	3	main
teile	doc_397823701994_item	2365952	et	4	main
töögraafikut	doc_397823701994_item	2365954	et	3	main
3	doc_397823701994_item	2365967	et	2	main
eluk	doc_397823701994_item	2365971	et	4	main
juhatajale	doc_397823701994_item	2365981	et	4	main
ja	doc_397823701994_item	2365986	et	3	main
saada	doc_397823701994_item	2365988	et	4	main
mul	doc_397823701994_item	2366004	et	3	main
kesk	doc_397823701994_item	2366006	et	3	main
varem	doc_397823701994_item	2366009	et	4	main
töötasin	doc_397823701994_item	2366010	et	3	main
firmas	doc_397823701994_item	2366011	et	3	main
müügiagentina	doc_397823701994_item	2366012	et	4	main
eesti	doc_397823701994_item	2366013	et	4	main
olen	doc_397823701994_item	2366020	et	3	main
aastat	doc_397823701994_item	2366027	et	3	main
et	doc_397823701994_item	2366042	et	3	main
saan	doc_397823701994_item	2366044	et	4	main
tööd	doc_397823701994_item	2366046	et	4	main
perekonnanimi	doc_397823701994_item	2366051	et	3	main
lugege	doc_397823701995_item	2366053	et	3	main
ja	doc_397823701995_item	2366055	et	3	main
kas	doc_397823701995_item	2366057	et	3	main
vastuargumente	doc_397823701995_item	2366066	et	3	main
pikkus	doc_397823701995_item	2366068	et	4	main
väide	doc_397823701995_item	2366074	et	4	main
elus	doc_397823701995_item	2366079	et	4	main
sellega	doc_397823701995_item	2366084	et	3	main
aitab	doc_397823701995_item	2366088	et	3	main
meid	doc_397823701995_item	2366089	et	4	main
keelte	doc_397823701995_item	2366094	et	3	main
siis	doc_397823701995_item	2366097	et	3	main
suhelda	doc_397823701995_item	2366102	et	4	main
eestlane	doc_397823701995_item	2366109	et	3	main
poeg	doc_397823701995_item	2366113	et	3	main
meditsiiniõena	doc_397823701995_item	2366126	et	3	main
minult	doc_397823701995_item	2366134	et	3	main
on	doc_397823701995_item	2366143	et	4	main
olime	doc_397823701995_item	2366150	et	3	main
võrgkeelte	doc_397823701995_item	2366169	et	3	main
reisimisel	doc_397823701995_item	2366172	et	4	main
üheksa	doc_397823701995_item	2366174	et	4	main
reisisime	doc_397823701995_item	2366178	et	3	main
lugege	doc_397823701996_item	2366205	et	3	main
kuulutus	doc_397823701996_item	2366207	et	4	main
ennast	doc_397823701996_item	2366218	et	4	main
perekonnaseis	doc_397823701996_item	2366219	et	4	main
haridus	doc_397823701996_item	2366220	et	3	main
arvutioskus	doc_397823701996_item	2366223	et	3	main
kui	doc_397823701996_item	2366233	et	3	main
milline	doc_397823701996_item	2366237	et	3	main
avatakse	doc_397823701996_item	2366243	et	4	main
kandidaatidelt	doc_397823701996_item	2366253	et	3	main
ootame	doc_397823701996_item	2366254	et	3	main
ja	doc_397823701996_item	2366256	et	3	main
head	doc_397823701996_item	2366260	et	4	main
ka	doc_397823701996_item	2366264	et	3	main
pakume	doc_397823701996_item	2366266	et	3	main
teile	doc_397823701996_item	2366269	et	4	main
sobivat	doc_397823701996_item	2366270	et	4	main
töögraafikut	doc_397823701996_item	2366271	et	3	main
tartu	doc_397823701996_item	2366277	et	4	main
tartu	doc_397823701996_item	2366282	et	4	main
3	doc_397823701996_item	2366284	et	2	main
tallinn	doc_397823701996_item	2366285	et	4	main
sõpruse	doc_397823701996_item	2366288	et	3	main
töötu	doc_397823701996_item	2366323	et	4	main
noor	doc_397823701996_item	2366326	et	3	main
elada	doc_397823701993_item	2365880	et	3	main
ametlik	doc_397823701994_item	2365886	et	3	main
lugege	doc_397823701994_item	2365888	et	3	main
peab	doc_397823701994_item	2365895	et	4	main
sõna	doc_397823701994_item	2365899	et	4	main
ennast	doc_397823701994_item	2365901	et	4	main
töökogemused	doc_397823701994_item	2365904	et	3	main
keelteoskus	doc_397823701994_item	2365905	et	3	main
arvutioskus	doc_397823701994_item	2365906	et	3	main
autojuhiload	doc_397823701994_item	2365907	et	4	main
kirjutage	doc_397823701994_item	2365910	et	3	main
soovidest	doc_397823701994_item	2365912	et	3	main
tööd	doc_397823701994_item	2365914	et	4	main
kahe	doc_397823701994_item	2365923	et	3	main
pärast	doc_397823701994_item	2365925	et	4	main
kandidaatidelt	doc_397823701994_item	2365936	et	3	main
arvutikasutamisoskus	doc_397823701994_item	2365948	et	3	main
as	doc_397823701994_item	2365958	et	4	main
kakuke	doc_397823701994_item	2365959	et	4	main
kakuke	doc_397823701994_item	2365964	et	4	main
23	doc_397823701994_item	2365973	et	2	main
kuulutust	doc_397823701994_item	2365985	et	4	main
soovin	doc_397823701994_item	2365987	et	3	main
poeg	doc_397823701994_item	2366003	et	3	main
vene	doc_397823701994_item	2366015	et	4	main
keeles	doc_397823701994_item	2366016	et	4	main
hea	doc_397823701994_item	2366021	et	4	main
oskan	doc_397823701994_item	2366023	et	3	main
tallinnas	doc_397823701994_item	2366031	et	4	main
töötada	doc_397823701994_item	2366034	et	3	main
päev	doc_397823701994_item	2366036	et	3	main
loodan	doc_397823701994_item	2366041	et	3	main
8	doc_397823701994_item	2366047	et	2	main
eesnimi	doc_397823701994_item	2366050	et	3	main
essee	doc_397823701995_item	2366052	et	4	main
väidet	doc_397823701995_item	2366054	et	3	main
kirjutage	doc_397823701995_item	2366056	et	3	main
olete	doc_397823701995_item	2366058	et	3	main
nõus	doc_397823701995_item	2366060	et	4	main
120	doc_397823701995_item	2366072	et	2	main
meid	doc_397823701995_item	2366078	et	4	main
nõus	doc_397823701995_item	2366083	et	4	main
elus	doc_397823701995_item	2366090	et	4	main
rohkem	doc_397823701995_item	2366098	et	4	main
ma	doc_397823701995_item	2366103	et	3	main
minu	doc_397823701995_item	2366106	et	3	main
seitsmeaastane	doc_397823701995_item	2366112	et	4	main
keeles	doc_397823701995_item	2366122	et	4	main
ma	doc_397823701995_item	2366123	et	3	main
ja	doc_397823701995_item	2366127	et	3	main
pean	doc_397823701995_item	2366129	et	4	main
elab	doc_397823701995_item	2366140	et	3	main
hakkasime	doc_397823701995_item	2366146	et	3	main
kirjutama	doc_397823701995_item	2366148	et	3	main
klassis	doc_397823701995_item	2366152	et	3	main
ja	doc_397823701995_item	2366153	et	3	main
mulle	doc_397823701995_item	2366159	et	4	main
mina	doc_397823701995_item	2366162	et	4	main
keeles	doc_397823701995_item	2366167	et	4	main
aitab	doc_397823701995_item	2366171	et	3	main
tagasi	doc_397823701995_item	2366176	et	3	main
läbi	doc_397823701996_item	2366206	et	4	main
sõna	doc_397823701996_item	2366216	et	4	main
tutvustage	doc_397823701996_item	2366217	et	3	main
keelteoskus	doc_397823701996_item	2366222	et	3	main
sobib	doc_397823701996_item	2366239	et	3	main
uus	doc_397823701996_item	2366244	et	3	main
toidukauplus	doc_397823701996_item	2366245	et	3	main
eesti	doc_397823701996_item	2366255	et	4	main
suhtlemisoskust	doc_397823701996_item	2366261	et	3	main
on	doc_397823701996_item	2366263	et	4	main
mugavaid	doc_397823701996_item	2366267	et	3	main
as	doc_397823701996_item	2366275	et	4	main
kakuke	doc_397823701996_item	2366276	et	4	main
tallinn	doc_397823701996_item	2366291	et	4	main
on	doc_397823701996_item	2366331	et	4	main
müüjana	doc_397823701996_item	2366339	et	4	main
on	doc_397823701996_item	2366346	et	4	main
päeva	doc_397823701996_item	2366357	et	4	main
töötasu	doc_397823701996_item	2366365	et	4	main
5	doc_397823701996_item	2366368	et	2	main
sobib	doc_397823701994_item	2365922	et	3	main
kauplusesse	doc_397823701994_item	2365929	et	4	main
pakkijaid	doc_397823701994_item	2365935	et	4	main
ootame	doc_397823701994_item	2365937	et	3	main
suhtlemisoskust	doc_397823701994_item	2365944	et	3	main
on	doc_397823701994_item	2365946	et	4	main
ka	doc_397823701994_item	2365947	et	3	main
mugavaid	doc_397823701994_item	2365950	et	3	main
as	doc_397823701994_item	2365963	et	4	main
mnt	doc_397823701994_item	2365966	et	4	main
perekonnanimi	doc_397823701994_item	2365970	et	3	main
jõhvi	doc_397823701994_item	2365976	et	4	main
00000	doc_397823701994_item	2365978	et	2	main
kakuke	doc_397823701994_item	2365980	et	4	main
teie	doc_397823701994_item	2365984	et	4	main
32	doc_397823701994_item	2365995	et	2	main
seitsmeaastane	doc_397823701994_item	2366002	et	4	main
eri	doc_397823701994_item	2366007	et	4	main
räägin	doc_397823701994_item	2366017	et	3	main
vabalt	doc_397823701994_item	2366018	et	4	main
suhtleja	doc_397823701994_item	2366022	et	4	main
arvutiga	doc_397823701994_item	2366025	et	4	main
tagasi	doc_397823701994_item	2366028	et	3	main
soobib	doc_397823701994_item	2366033	et	4	main
iga	doc_397823701994_item	2366035	et	4	main
kaheksa	doc_397823701994_item	2366037	et	4	main
juuni	doc_397823701994_item	2366048	et	4	main
ja	doc_397823701995_item	2366065	et	3	main
olema	doc_397823701995_item	2366070	et	4	main
aitab	doc_397823701995_item	2366077	et	3	main
olen	doc_397823701995_item	2366082	et	3	main
et	doc_397823701995_item	2366085	et	3	main
rohkem	doc_397823701995_item	2366093	et	4	main
oskame	doc_397823701995_item	2366096	et	3	main
võime	doc_397823701995_item	2366101	et	4	main
abielus	doc_397823701995_item	2366105	et	4	main
peres	doc_397823701995_item	2366110	et	3	main
ja	doc_397823701995_item	2366114	et	3	main
ma	doc_397823701995_item	2366128	et	3	main
saada	doc_397823701995_item	2366131	et	4	main
mida	doc_397823701995_item	2366132	et	4	main
sõbranna	doc_397823701995_item	2366139	et	4	main
ta	doc_397823701995_item	2366142	et	4	main
teineteisele	doc_397823701995_item	2366147	et	3	main
kui	doc_397823701995_item	2366149	et	3	main
siiamani	doc_397823701995_item	2366155	et	4	main
kirju	doc_397823701995_item	2366158	et	4	main
kui	doc_397823701995_item	2366173	et	3	main
vastake	doc_397823701996_item	2366209	et	3	main
peab	doc_397823701996_item	2366212	et	4	main
umbes	doc_397823701996_item	2366214	et	4	main
60	doc_397823701996_item	2366215	et	2	main
hobid	doc_397823701996_item	2366225	et	3	main
kirjutage	doc_397823701996_item	2366227	et	3	main
soovidest	doc_397823701996_item	2366229	et	3	main
kuu	doc_397823701996_item	2366241	et	4	main
pakkijaid	doc_397823701996_item	2366252	et	4	main
oskust	doc_397823701996_item	2366259	et	3	main
arvutikasutamisoskus	doc_397823701996_item	2366265	et	3	main
töötingimusi	doc_397823701996_item	2366268	et	3	main
mnt3	doc_397823701996_item	2366278	et	4	main
eesnimi	doc_397823701996_item	2366286	et	3	main
2	doc_397823701996_item	2366289	et	2	main
avaldus	doc_397823701996_item	2366294	et	4	main
lugesin	doc_397823701996_item	2366295	et	3	main
ajalehest	doc_397823701996_item	2366296	et	4	main
ma	doc_397823701996_item	2366324	et	3	main
vähe	doc_397823701996_item	2366332	et	3	main
töötanud	doc_397823701996_item	2366334	et	4	main
oskan	doc_397823701996_item	2366340	et	3	main
ja	doc_397823701996_item	2366342	et	3	main
ka	doc_397823701996_item	2366347	et	3	main
kursuseid	doc_397823701996_item	2366349	et	3	main
lõppenud	doc_397823701996_item	2366351	et	4	main
mulle	doc_397823701996_item	2366352	et	4	main
2	doc_397823701996_item	2366360	et	2	main
t	doc_397823701996_item	2366362	et	4	main
tahan	doc_397823701996_item	2366371	et	3	main
on	doc_397823701996_item	2366380	et	4	main
teie	doc_397823701996_item	2366387	et	4	main
essee	doc_397823701997_item	2366390	et	4	main
väidet	doc_397823701997_item	2366392	et	3	main
kirjutage	doc_397823701997_item	2366394	et	3	main
sellega	doc_397823701997_item	2366397	et	3	main
eesti	doc_397823701997_item	2366425	et	4	main
saksa	doc_397823701997_item	2366429	et	4	main
nõus	doc_397823701997_item	2366432	et	4	main
sellega	doc_397823701997_item	2366433	et	3	main
võõrkeelte	doc_397823701997_item	2366435	et	3	main
majanduskursusel	doc_397823701994_item	2366030	et	3	main
2005	doc_397823701994_item	2366049	et	2	main
umbes	doc_397823701995_item	2366071	et	4	main
sõna	doc_397823701995_item	2366073	et	4	main
võõrkeelte	doc_397823701995_item	2366075	et	3	main
ma	doc_397823701995_item	2366081	et	3	main
oskamine	doc_397823701995_item	2366087	et	4	main
mida	doc_397823701995_item	2366092	et	4	main
me	doc_397823701995_item	2366095	et	4	main
inimestega	doc_397823701995_item	2366099	et	3	main
olen	doc_397823701995_item	2366104	et	3	main
on	doc_397823701995_item	2366108	et	4	main
kasvab	doc_397823701995_item	2366111	et	3	main
nendega	doc_397823701995_item	2366115	et	4	main
ma	doc_397823701995_item	2366116	et	3	main
räägin	doc_397823701995_item	2366117	et	3	main
eesti	doc_397823701995_item	2366118	et	4	main
keeles	doc_397823701995_item	2366119	et	4	main
ja	doc_397823701995_item	2366120	et	3	main
töötan	doc_397823701995_item	2366124	et	3	main
tahavad	doc_397823701995_item	2366133	et	3	main
eesti	doc_397823701995_item	2366136	et	4	main
minu	doc_397823701995_item	2366138	et	3	main
saakslane	doc_397823701995_item	2366144	et	4	main
kirjutame	doc_397823701995_item	2366154	et	3	main
saksa	doc_397823701995_item	2366160	et	4	main
keeles	doc_397823701995_item	2366161	et	4	main
kirjutan	doc_397823701995_item	2366163	et	3	main
talle	doc_397823701995_item	2366164	et	4	main
ka	doc_397823701995_item	2366165	et	3	main
saksa	doc_397823701995_item	2366166	et	4	main
oskamine	doc_397823701995_item	2366170	et	4	main
me	doc_397823701995_item	2366177	et	4	main
saksamaal	doc_397823701995_item	2366179	et	4	main
inglismaal	doc_397823701995_item	2366180	et	4	main
prantsusmaal	doc_397823701995_item	2366181	et	4	main
siis	doc_397823701995_item	2366182	et	3	main
oli	doc_397823701995_item	2366183	et	3	main
tore	doc_397823701995_item	2366184	et	3	main
keegi	doc_397823701995_item	2366186	et	4	main
kui	doc_397823701995_item	2366185	et	3	main
meie	doc_397823701995_item	2366187	et	4	main
rühmast	doc_397823701995_item	2366188	et	4	main
räägis	doc_397823701995_item	2366189	et	3	main
inimestega	doc_397823701995_item	2366190	et	3	main
inglise	doc_397823701995_item	2366191	et	4	main
keeles	doc_397823701995_item	2366192	et	4	main
kes	doc_397823701995_item	2366193	et	4	main
valdab	doc_397823701995_item	2366194	et	3	main
siis	doc_397823701995_item	2366196	et	3	main
võõrkeeli	doc_397823701995_item	2366195	et	3	main
nende	doc_397823701995_item	2366197	et	4	main
jaoks	doc_397823701995_item	2366198	et	4	main
kõik	doc_397823701995_item	2366199	et	4	main
teed	doc_397823701995_item	2366200	et	4	main
on	doc_397823701995_item	2366201	et	4	main
avatud	doc_397823701995_item	2366202	et	4	main
ametlik	doc_397823701996_item	2366203	et	3	main
kiri	doc_397823701996_item	2366204	et	3	main
sellele	doc_397823701996_item	2366210	et	4	main
kirjas	doc_397823701996_item	2366211	et	4	main
olema	doc_397823701996_item	2366213	et	4	main
autojuhiload	doc_397823701996_item	2366224	et	4	main
ja	doc_397823701996_item	2366226	et	3	main
millist	doc_397823701996_item	2366230	et	3	main
tööd	doc_397823701996_item	2366231	et	4	main
suurt	doc_397823701996_item	2366234	et	3	main
töötasu	doc_397823701996_item	2366235	et	4	main
soovite	doc_397823701996_item	2366236	et	3	main
töögraafik	doc_397823701996_item	2366238	et	3	main
kahe	doc_397823701996_item	2366240	et	3	main
vajatakse	doc_397823701996_item	2366247	et	4	main
soovitav	doc_397823701996_item	2366262	et	4	main
palka	doc_397823701996_item	2366273	et	4	main
lisainfo	doc_397823701996_item	2366274	et	4	main
tallinn	doc_397823701996_item	2366279	et	4	main
teie	doc_397823701996_item	2366297	et	4	main
kust	doc_397823701996_item	2366299	et	4	main
sain	doc_397823701996_item	2366300	et	3	main
teada	doc_397823701996_item	2366301	et	3	main
et	doc_397823701996_item	2366302	et	3	main
teie	doc_397823701996_item	2366303	et	4	main
kahe	doc_397823701996_item	2366305	et	3	main
avatate	doc_397823701996_item	2366304	et	4	main
kuu	doc_397823701996_item	2366306	et	4	main
pärast	doc_397823701996_item	2366307	et	4	main
uus	doc_397823701996_item	2366308	et	3	main
toidu	doc_397823701996_item	2366309	et	3	main
kaupluse	doc_397823701996_item	2366310	et	3	main
ja	doc_397823701996_item	2366311	et	3	main
vajatate	doc_397823701996_item	2366312	et	4	main
ma	doc_397823701996_item	2366314	et	3	main
olen	doc_397823701996_item	2366315	et	3	main
müüjat	doc_397823701996_item	2366313	et	4	main
ära	doc_397823701996_item	2366316	et	4	main
kursuseid	doc_397823701996_item	2366318	et	3	main
müüjaks	doc_397823701996_item	2366319	et	4	main
lõppenud	doc_397823701996_item	2366317	et	4	main
aga	doc_397823701996_item	2366320	et	3	main
praegu	doc_397823701996_item	2366322	et	3	main
olen	doc_397823701996_item	2366333	et	3	main
2	doc_397823701996_item	2366335	et	2	main
eesti	doc_397823701996_item	2366341	et	4	main
keelt	doc_397823701996_item	2366344	et	4	main
arvutioskused	doc_397823701996_item	2366345	et	3	main
ei	doc_397823701996_item	2366350	et	4	main
ja	doc_397823701996_item	2366359	et	3	main
päeva	doc_397823701996_item	2366361	et	4	main
4	doc_397823701996_item	2366367	et	2	main
vabaj	doc_397823701996_item	2366375	et	4	main
ma	doc_397823701996_item	2366377	et	3	main
hobi	doc_397823701996_item	2366382	et	4	main
et	doc_397823701996_item	2366384	et	3	main
kauplusesse	doc_397823701996_item	2366389	et	4	main
lugege	doc_397823701997_item	2366391	et	3	main
perekonnanimi	doc_397823701996_item	2366287	et	3	main
2	doc_397823701996_item	2366290	et	2	main
tel	doc_397823701996_item	2366292	et	4	main
000000	doc_397823701996_item	2366293	et	2	main
kuulutust	doc_397823701996_item	2366298	et	4	main
olen	doc_397823701996_item	2366321	et	3	main
olen	doc_397823701996_item	2366325	et	3	main
mulle	doc_397823701996_item	2366327	et	4	main
aastat	doc_397823701996_item	2366329	et	3	main
töökogemust	doc_397823701996_item	2366330	et	3	main
kuud	doc_397823701996_item	2366336	et	4	main
r	doc_397823701996_item	2366337	et	4	main
kioskis	doc_397823701996_item	2366338	et	3	main
vene	doc_397823701996_item	2366343	et	4	main
sobib	doc_397823701996_item	2366353	et	3	main
tavaline	doc_397823701996_item	2366354	et	4	main
töögraafik	doc_397823701996_item	2366355	et	3	main
2	doc_397823701996_item	2366356	et	2	main
öö	doc_397823701996_item	2366363	et	4	main
tuhat	doc_397823701996_item	2366369	et	4	main
loodan	doc_397823701996_item	2366383	et	3	main
sobin	doc_397823701996_item	2366385	et	3	main
toidu	doc_397823701996_item	2366388	et	3	main
kas	doc_397823701997_item	2366395	et	3	main
nõus	doc_397823701997_item	2366398	et	4	main
või	doc_397823701997_item	2366399	et	4	main
mitte	doc_397823701997_item	2366400	et	3	main
esitage	doc_397823701997_item	2366401	et	3	main
poolt-	doc_397823701997_item	2366402	et	4	main
ja	doc_397823701997_item	2366403	et	3	main
vastuargumente	doc_397823701997_item	2366404	et	3	main
töö	doc_397823701997_item	2366405	et	4	main
pikkus	doc_397823701997_item	2366406	et	4	main
peab	doc_397823701997_item	2366407	et	4	main
umbes	doc_397823701997_item	2366409	et	4	main
olema	doc_397823701997_item	2366408	et	4	main
120	doc_397823701997_item	2366410	et	2	main
sõna	doc_397823701997_item	2366411	et	4	main
väide	doc_397823701997_item	2366412	et	4	main
võõrkeelte	doc_397823701997_item	2366413	et	3	main
oskamine	doc_397823701997_item	2366414	et	4	main
aitab	doc_397823701997_item	2366415	et	3	main
meid	doc_397823701997_item	2366416	et	4	main
elus	doc_397823701997_item	2366417	et	4	main
edasi	doc_397823701997_item	2366418	et	3	main
ma	doc_397823701997_item	2366419	et	3	main
elan	doc_397823701997_item	2366420	et	3	main
edasi	doc_397823701997_item	2366440	et	3	main
sugulased	doc_397823701997_item	2366451	et	3	main
ma	doc_397823701997_item	2366453	et	3	main
keeles	doc_397823701997_item	2366463	et	4	main
tean	doc_397823701997_item	2366467	et	3	main
inglise	doc_397823701997_item	2366471	et	4	main
ja	doc_397823701997_item	2366472	et	3	main
keele	doc_397823701997_item	2366474	et	4	main
vähem	doc_397823701997_item	2366477	et	4	main
aga	doc_397823701997_item	2366482	et	3	main
tööd	doc_397823701997_item	2366492	et	4	main
peale	doc_397823701997_item	2366493	et	4	main
teises	doc_397823701997_item	2366500	et	4	main
see	doc_397823701997_item	2366506	et	3	main
keel	doc_397823701997_item	2366507	et	4	main
mulle	doc_397823701997_item	2366509	et	4	main
võõrkeelte	doc_397823701997_item	2366522	et	3	main
20	doc_397823701996_item	2366328	et	2	main
aga	doc_397823701996_item	2366348	et	3	main
kodus	doc_397823701996_item	2366358	et	4	main
l	doc_397823701996_item	2366364	et	4	main
ümbes	doc_397823701996_item	2366366	et	4	main
kuus	doc_397823701996_item	2366370	et	4	main
ka	doc_397823701996_item	2366372	et	3	main
töötingimusi	doc_397823701996_item	2366374	et	3	main
joonistan	doc_397823701996_item	2366378	et	3	main
see	doc_397823701996_item	2366379	et	3	main
tööle	doc_397823701996_item	2366386	et	3	main
ja	doc_397823701997_item	2366393	et	3	main
olete	doc_397823701997_item	2366396	et	3	main
venelane	doc_397823701997_item	2366423	et	3	main
oskamine	doc_397823701997_item	2366436	et	4	main
noor	doc_397823701997_item	2366443	et	3	main
elu	doc_397823701997_item	2366446	et	4	main
ees	doc_397823701997_item	2366447	et	4	main
sõita	doc_397823701997_item	2366455	et	3	main
terveks	doc_397823701997_item	2366458	et	4	main
ja	doc_397823701997_item	2366460	et	3	main
vene	doc_397823701997_item	2366462	et	4	main
ja	doc_397823701997_item	2366469	et	3	main
ja	doc_397823701997_item	2366480	et	3	main
keeles	doc_397823701997_item	2366505	et	4	main
meeldib	doc_397823701997_item	2366508	et	3	main
mugavaid	doc_397823701996_item	2366373	et	3	main
ajal	doc_397823701996_item	2366376	et	4	main
minu	doc_397823701996_item	2366381	et	3	main
eestis	doc_397823701997_item	2366421	et	3	main
tean	doc_397823701997_item	2366424	et	3	main
vene	doc_397823701997_item	2366426	et	4	main
inglise	doc_397823701997_item	2366427	et	4	main
ja	doc_397823701997_item	2366428	et	3	main
mul	doc_397823701997_item	2366444	et	3	main
on	doc_397823701997_item	2366445	et	4	main
venemaal	doc_397823701997_item	2366448	et	4	main
mul	doc_397823701997_item	2366449	et	3	main
kord	doc_397823701997_item	2366457	et	4	main
ma	doc_397823701997_item	2366466	et	3	main
kirjas	doc_397823701997_item	2366470	et	4	main
saksa	doc_397823701997_item	2366473	et	4	main
mul	doc_397823701997_item	2366476	et	3	main
kirjas	doc_397823701997_item	2366481	et	4	main
saksa	doc_397823701997_item	2366483	et	4	main
annab	doc_397823701997_item	2366488	et	3	main
mulle	doc_397823701997_item	2366489	et	4	main
võimaluse	doc_397823701997_item	2366490	et	3	main
lõpetamist	doc_397823701997_item	2366495	et	4	main
kuskil	doc_397823701997_item	2366496	et	3	main
kus	doc_397823701997_item	2366502	et	3	main
oskamine	doc_397823701997_item	2366523	et	4	main
arvutioskamine	doc_397823701997_item	2366525	et	3	main
pean	doc_397823701997_item	2366529	et	4	main
mingeid	doc_397823701997_item	2366536	et	3	main
et	doc_397823701997_item	2366546	et	3	main
olen	doc_397823701997_item	2366422	et	3	main
keeled	doc_397823701997_item	2366430	et	3	main
olen	doc_397823701997_item	2366431	et	3	main
et	doc_397823701997_item	2366434	et	3	main
olen	doc_397823701997_item	2366442	et	3	main
kuhu	doc_397823701997_item	2366452	et	3	main
võin	doc_397823701997_item	2366454	et	3	main
see	doc_397823701997_item	2366464	et	3	main
kõnes	doc_397823701997_item	2366468	et	3	main
oskust	doc_397823701997_item	2366475	et	3	main
kõnes	doc_397823701997_item	2366479	et	3	main
otsida	doc_397823701997_item	2366491	et	4	main
välismaal	doc_397823701997_item	2366497	et	4	main
ameriikas	doc_397823701997_item	2366498	et	4	main
pooles	doc_397823701997_item	2366501	et	4	main
räägivad	doc_397823701997_item	2366503	et	3	main
rohkem	doc_397823701997_item	2366510	et	4	main
ma	doc_397823701997_item	2366511	et	3	main
tean	doc_397823701997_item	2366512	et	3	main
teda	doc_397823701997_item	2366513	et	4	main
parem	doc_397823701997_item	2366514	et	4	main
eestis	doc_397823701997_item	2366515	et	3	main
on	doc_397823701997_item	2366516	et	4	main
palju	doc_397823701997_item	2366517	et	4	main
firmaid	doc_397823701997_item	2366518	et	4	main
kus	doc_397823701997_item	2366519	et	3	main
on	doc_397823701997_item	2366520	et	4	main
ei	doc_397823701997_item	2366534	et	4	main
nõus	doc_397823701997_item	2366545	et	4	main
oskamine	doc_397823701997_item	2366548	et	4	main
aitab	doc_397823701997_item	2366437	et	3	main
meid	doc_397823701997_item	2366438	et	4	main
elus	doc_397823701997_item	2366439	et	4	main
ma	doc_397823701997_item	2366441	et	3	main
elavad	doc_397823701997_item	2366450	et	4	main
mõni	doc_397823701997_item	2366456	et	3	main
suveks	doc_397823701997_item	2366459	et	3	main
suhelda	doc_397823701997_item	2366461	et	4	main
keel	doc_397823701997_item	2366465	et	4	main
inglise	doc_397823701997_item	2366478	et	4	main
keel	doc_397823701997_item	2366484	et	4	main
ainult	doc_397823701997_item	2366485	et	4	main
kõnes	doc_397823701997_item	2366486	et	3	main
see	doc_397823701997_item	2366487	et	3	main
kooli	doc_397823701997_item	2366494	et	4	main
või	doc_397823701997_item	2366499	et	4	main
inglise	doc_397823701997_item	2366504	et	4	main
vaja	doc_397823701997_item	2366521	et	4	main
aga	doc_397823701997_item	2366526	et	3	main
et	doc_397823701997_item	2366533	et	3	main
ole	doc_397823701997_item	2366540	et	4	main
kahe	doc_397823701997_item	2366543	et	3	main
arendama	doc_397823701997_item	2366530	et	3	main
keele	doc_397823701997_item	2366531	et	4	main
oskamine	doc_397823701997_item	2366532	et	4	main
vastuargumente	doc_397823701997_item	2366537	et	3	main
ei	doc_397823701997_item	2366539	et	4	main
ma	doc_397823701997_item	2366541	et	3	main
võõrkeelte	doc_397823701997_item	2366547	et	3	main
meid	doc_397823701997_item	2366550	et	4	main
elus	doc_397823701997_item	2366551	et	4	main
edasi	doc_397823701997_item	2366552	et	3	main
ja	doc_397823701997_item	2366524	et	3	main
ma	doc_397823701997_item	2366527	et	3	main
ise	doc_397823701997_item	2366528	et	4	main
unustada	doc_397823701997_item	2366535	et	3	main
mul	doc_397823701997_item	2366538	et	3	main
olen	doc_397823701997_item	2366542	et	3	main
käega	doc_397823701997_item	2366544	et	3	main
aitab	doc_397823701997_item	2366549	et	3	main
maksab	doc_397823702012_item	2368388	et	3	main
kirja	doc_397823702012_item	2368392	et	4	main
reisi	doc_397823702012_item	2368407	et	4	main
ma	doc_397823702012_item	2368409	et	3	main
umbes	doc_397823702012_item	2368415	et	4	main
eek	doc_397823702012_item	2368428	et	4	main
plaanite	doc_397823702012_item	2368365	et	3	main
palju	doc_397823702012_item	2368386	et	4	main
pikkus	doc_397823702012_item	2368394	et	4	main
augustist	doc_397823702012_item	2368404	et	3	main
venemaale	doc_397823702012_item	2368408	et	4	main
2000	doc_397823702012_item	2368416	et	2	main
aga	doc_397823702012_item	2368418	et	3	main
on	doc_397823702012_item	2368421	et	4	main
reserveeritud	doc_397823702012_item	2368423	et	4	main
tuba	doc_397823702012_item	2368424	et	4	main
hotellis	doc_397823702012_item	2368425	et	3	main
maksab	doc_397823702012_item	2368426	et	3	main
600	doc_397823702012_item	2368427	et	2	main
ma	doc_397823702012_item	2368429	et	3	main
ekskursioni	doc_397823702012_item	2368431	et	4	main
linnas	doc_397823702012_item	2368432	et	4	main
piletit	doc_397823702012_item	2368433	et	3	main
te	doc_397823702012_item	2368364	et	4	main
kus	doc_397823702012_item	2368383	et	3	main
kui	doc_397823702012_item	2368385	et	3	main
see	doc_397823702012_item	2368387	et	3	main
peatute	doc_397823702012_item	2368391	et	4	main
nõutav	doc_397823702012_item	2368393	et	4	main
ma	doc_397823702012_item	2368405	et	3	main
sovin	doc_397823702012_item	2368410	et	4	main
moskvasse	doc_397823702012_item	2368412	et	4	main
maksab	doc_397823702012_item	2368414	et	3	main
eek	doc_397823702012_item	2368417	et	4	main
linnas	doc_397823702012_item	2368419	et	4	main
mul	doc_397823702012_item	2368420	et	3	main
tuleb	doc_397823702012_item	2368434	et	3	main
tellida	doc_397823702012_item	2368435	et	3	main
nagemiseni	doc_397823702012_item	2368437	et	4	main
millega	doc_397823702015_item	2368711	et	3	main
ööbite	doc_397823702015_item	2368714	et	3	main
on	doc_397823702015_item	2368742	et	4	main
puhkus	doc_397823702015_item	2368748	et	3	main
ja	doc_397823702015_item	2368775	et	3	main
me	doc_397823702015_item	2368778	et	4	main
tuttava	doc_397823702015_item	2368780	et	4	main
me	doc_397823702015_item	2368784	et	4	main
sõidame	doc_397823702015_item	2368785	et	3	main
ööbite	doc_397823702012_item	2368384	et	3	main
kohtades	doc_397823702012_item	2368390	et	3	main
80	doc_397823702012_item	2368396	et	2	main
sõna	doc_397823702012_item	2368397	et	4	main
tere	doc_397823702012_item	2368398	et	3	main
kallis	doc_397823702012_item	2368399	et	4	main
marija	doc_397823702012_item	2368400	et	3	main
minu	doc_397823702012_item	2368401	et	3	main
kiri	doc_397823702012_item	2368363	et	3	main
reisi	doc_397823702012_item	2368366	et	4	main
venemaale	doc_397823702012_item	2368367	et	4	main
kirjutage	doc_397823702012_item	2368368	et	3	main
sellest	doc_397823702012_item	2368369	et	4	main
kiri	doc_397823702012_item	2368370	et	3	main
oma	doc_397823702012_item	2368371	et	4	main
eestlasest	doc_397823702012_item	2368372	et	3	main
sõbrale	doc_397823702012_item	2368373	et	3	main
kirjutage	doc_397823702012_item	2368374	et	3	main
millal	doc_397823702012_item	2368375	et	3	main
ja	doc_397823702012_item	2368376	et	3	main
kuhu	doc_397823702012_item	2368377	et	3	main
te	doc_397823702012_item	2368378	et	4	main
sõita	doc_397823702012_item	2368379	et	3	main
soovite	doc_397823702012_item	2368380	et	3	main
millega	doc_397823702012_item	2368381	et	3	main
reisite	doc_397823702012_item	2368382	et	3	main
millistes	doc_397823702012_item	2368389	et	3	main
umbes	doc_397823702012_item	2368395	et	4	main
sõidan	doc_397823702012_item	2368406	et	3	main
sõitu	doc_397823702012_item	2368411	et	4	main
puhkus	doc_397823702012_item	2368402	et	3	main
on	doc_397823702012_item	2368403	et	4	main
pilett	doc_397823702012_item	2368413	et	4	main
teatrisse	doc_397823702012_item	2368436	et	3	main
te	doc_397823702015_item	2368708	et	4	main
sõita	doc_397823702015_item	2368709	et	3	main
kus	doc_397823702015_item	2368713	et	3	main
peatute	doc_397823702015_item	2368721	et	4	main
pikkus	doc_397823702015_item	2368724	et	4	main
80	doc_397823702015_item	2368726	et	2	main
sõna	doc_397823702015_item	2368727	et	4	main
tere	doc_397823702015_item	2368728	et	3	main
anne	doc_397823702015_item	2368729	et	4	main
mul	doc_397823702015_item	2368730	et	3	main
on	doc_397823702015_item	2368731	et	4	main
väga	doc_397823702015_item	2368732	et	3	main
hea	doc_397823702015_item	2368743	et	4	main
ostsime	doc_397823702015_item	2368759	et	3	main
moskvasse	doc_397823702015_item	2368764	et	4	main
kolm	doc_397823702015_item	2368776	et	3	main
tuba	doc_397823702012_item	2368422	et	4	main
sovin	doc_397823702012_item	2368430	et	4	main
kiri	doc_397823702015_item	2368693	et	3	main
te	doc_397823702015_item	2368694	et	4	main
plaanite	doc_397823702015_item	2368695	et	3	main
reisi	doc_397823702015_item	2368696	et	4	main
venemaale	doc_397823702015_item	2368697	et	4	main
kirjutage	doc_397823702015_item	2368698	et	3	main
sellest	doc_397823702015_item	2368699	et	4	main
kiri	doc_397823702015_item	2368700	et	3	main
oma	doc_397823702015_item	2368701	et	4	main
eestlasest	doc_397823702015_item	2368702	et	3	main
sõbrale	doc_397823702015_item	2368703	et	3	main
kirjutage	doc_397823702015_item	2368704	et	3	main
millal	doc_397823702015_item	2368705	et	3	main
ja	doc_397823702015_item	2368706	et	3	main
palju	doc_397823702015_item	2368716	et	4	main
maksab	doc_397823702015_item	2368718	et	3	main
kohtades	doc_397823702015_item	2368720	et	3	main
kirja	doc_397823702015_item	2368722	et	4	main
nõutav	doc_397823702015_item	2368723	et	4	main
uudis	doc_397823702015_item	2368744	et	3	main
mul	doc_397823702015_item	2368745	et	3	main
koos	doc_397823702015_item	2368751	et	4	main
oma	doc_397823702015_item	2368752	et	4	main
perega	doc_397823702015_item	2368753	et	3	main
plaanerin	doc_397823702015_item	2368754	et	4	main
reisida	doc_397823702015_item	2368755	et	3	main
venemaale	doc_397823702015_item	2368756	et	4	main
rongiga	doc_397823702015_item	2368763	et	4	main
abikaasa	doc_397823702015_item	2368774	et	4	main
oleme	doc_397823702015_item	2368779	et	3	main
juba	doc_397823702015_item	2368781	et	3	main
kümme	doc_397823702015_item	2368782	et	3	main
maja	doc_397823702015_item	2368792	et	4	main
reisime	doc_397823702015_item	2368829	et	3	main
palun	doc_397823702015_item	2368831	et	3	main
kuidas	doc_397823702015_item	2368838	et	3	main
tervita	doc_397823702015_item	2368841	et	4	main
ja	doc_397823702016_item	2368858	et	3	main
te	doc_397823702016_item	2368860	et	4	main
millega	doc_397823702016_item	2368863	et	3	main
kus	doc_397823702016_item	2368865	et	3	main
ööbite	doc_397823702016_item	2368866	et	3	main
pikkus	doc_397823702016_item	2368876	et	4	main
80	doc_397823702016_item	2368878	et	2	main
tere	doc_397823702016_item	2368880	et	3	main
kallis	doc_397823702016_item	2368881	et	4	main
mulle	doc_397823702016_item	2368889	et	4	main
on	doc_397823702016_item	2368898	et	4	main
tahan	doc_397823702016_item	2368910	et	3	main
koos	doc_397823702016_item	2368926	et	4	main
täiskasvanud	doc_397823702016_item	2368930	et	4	main
ei	doc_397823702016_item	2368933	et	4	main
kaks	doc_397823702016_item	2368938	et	3	main
tuhat	doc_397823702016_item	2368939	et	4	main
tagasi	doc_397823702016_item	2368945	et	3	main
on	doc_397823702016_item	2368959	et	4	main
huvitav	doc_397823702016_item	2368969	et	4	main
sõidan	doc_397823702016_item	2368970	et	3	main
tagasi	doc_397823702016_item	2368971	et	3	main
marike	doc_397823702016_item	2368974	et	4	main
kirjuta	doc_397823702016_item	2368975	et	4	main
temale	doc_397823702017_item	2369026	et	3	main
minu	doc_397823702017_item	2369027	et	3	main
junil	doc_397823702017_item	2369030	et	4	main
ma	doc_397823702017_item	2369035	et	3	main
oma	doc_397823702017_item	2369037	et	4	main
me	doc_397823702017_item	2369039	et	4	main
me	doc_397823702017_item	2369043	et	4	main
sõidame	doc_397823702017_item	2369044	et	3	main
poeg	doc_397823702017_item	2369049	et	3	main
sugulased	doc_397823702017_item	2369054	et	3	main
otavad	doc_397823702017_item	2369056	et	4	main
peterburgi	doc_397823702017_item	2369061	et	4	main
museumi	doc_397823702017_item	2369065	et	4	main
ja	doc_397823702017_item	2369066	et	3	main
õhtul	doc_397823702017_item	2369078	et	3	main
teatris	doc_397823702017_item	2369080	et	3	main
ma	doc_397823702017_item	2369094	et	3	main
kiri	doc_397823702018_item	2369123	et	3	main
kirjutage	doc_397823702018_item	2369127	et	3	main
soovite	doc_397823702018_item	2369133	et	3	main
kui	doc_397823702015_item	2368715	et	3	main
millistes	doc_397823702015_item	2368719	et	3	main
kuhu	doc_397823702015_item	2368707	et	3	main
soovite	doc_397823702015_item	2368710	et	3	main
reisite	doc_397823702015_item	2368712	et	3	main
see	doc_397823702015_item	2368717	et	3	main
hea	doc_397823702015_item	2368733	et	4	main
mul	doc_397823702015_item	2368741	et	3	main
on	doc_397823702015_item	2368746	et	4	main
ja	doc_397823702015_item	2368749	et	3	main
mina	doc_397823702015_item	2368750	et	4	main
me	doc_397823702015_item	2368757	et	4	main
juuba	doc_397823702015_item	2368758	et	4	main
me	doc_397823702015_item	2368761	et	4	main
sõbranna	doc_397823702015_item	2368768	et	4	main
tal	doc_397823702015_item	2368770	et	3	main
suur	doc_397823702015_item	2368772	et	3	main
lapsed	doc_397823702015_item	2368777	et	3	main
aastat	doc_397823702015_item	2368783	et	3	main
teie	doc_397823702015_item	2368836	et	4	main
nägemiseni	doc_397823702015_item	2368843	et	4	main
te	doc_397823702016_item	2368846	et	4	main
reisi	doc_397823702016_item	2368848	et	4	main
venemaale	doc_397823702016_item	2368849	et	4	main
kirjutage	doc_397823702016_item	2368850	et	3	main
millal	doc_397823702016_item	2368857	et	3	main
soovite	doc_397823702016_item	2368862	et	3	main
reisite	doc_397823702016_item	2368864	et	3	main
maksab	doc_397823702016_item	2368870	et	3	main
kohtades	doc_397823702016_item	2368872	et	3	main
kirja	doc_397823702016_item	2368874	et	4	main
sõna	doc_397823702016_item	2368879	et	4	main
meel	doc_397823702016_item	2368886	et	4	main
kirjuta	doc_397823702016_item	2368893	et	4	main
mul	doc_397823702016_item	2368897	et	3	main
kõik	doc_397823702016_item	2368899	et	4	main
mul	doc_397823702016_item	2368901	et	3	main
on	doc_397823702016_item	2368902	et	4	main
juulis	doc_397823702016_item	2368903	et	3	main
puhkus	doc_397823702016_item	2368904	et	3	main
ja	doc_397823702016_item	2368905	et	3	main
sankt	doc_397823702016_item	2368912	et	4	main
mina	doc_397823702016_item	2368915	et	4	main
on	doc_397823702016_item	2368921	et	4	main
aga	doc_397823702016_item	2368928	et	3	main
neid	doc_397823702016_item	2368929	et	4	main
laps	doc_397823702016_item	2368931	et	4	main
soodust	doc_397823702016_item	2368932	et	3	main
biletit	doc_397823702016_item	2368943	et	4	main
mul	doc_397823702016_item	2368949	et	3	main
peterburgis	doc_397823702016_item	2368951	et	4	main
elab	doc_397823702016_item	2368952	et	3	main
sõbrana	doc_397823702016_item	2368953	et	3	main
me	doc_397823702016_item	2368954	et	4	main
hakkame	doc_397823702016_item	2368955	et	3	main
elada	doc_397823702016_item	2368956	et	3	main
marinale	doc_397823702016_item	2368957	et	4	main
korter	doc_397823702016_item	2368961	et	3	main
on	doc_397823702016_item	2368963	et	4	main
kõike	doc_397823702016_item	2368978	et	4	main
on	doc_397823702017_item	2369029	et	4	main
ma	doc_397823702017_item	2369031	et	3	main
sõidan	doc_397823702017_item	2369036	et	3	main
jõhvist	doc_397823702017_item	2369048	et	4	main
ja	doc_397823702017_item	2369052	et	3	main
juba	doc_397823702017_item	2369055	et	3	main
mulle	doc_397823702017_item	2369068	et	4	main
väga	doc_397823702017_item	2369069	et	3	main
meldib	doc_397823702017_item	2369070	et	4	main
see	doc_397823702017_item	2369071	et	3	main
linna	doc_397823702017_item	2369072	et	4	main
käime	doc_397823702017_item	2369079	et	4	main
või	doc_397823702017_item	2369081	et	4	main
kontsertisaalis	doc_397823702017_item	2369082	et	3	main
minul	doc_397823702017_item	2369086	et	3	main
ma	doc_397823702017_item	2369088	et	3	main
vaatasin	doc_397823702017_item	2369090	et	3	main
tema	doc_397823702017_item	2369091	et	4	main
kaks	doc_397823702017_item	2369092	et	3	main
tea	doc_397823702017_item	2369096	et	4	main
reisi	doc_397823702017_item	2369098	et	4	main
maksab	doc_397823702017_item	2369099	et	3	main
aga	doc_397823702017_item	2369100	et	3	main
ma	doc_397823702017_item	2369101	et	3	main
väga	doc_397823702017_item	2369102	et	3	main
umbes	doc_397823702015_item	2368725	et	4	main
meel	doc_397823702015_item	2368734	et	4	main
et	doc_397823702015_item	2368735	et	3	main
sain	doc_397823702015_item	2368736	et	3	main
sunult	doc_397823702015_item	2368737	et	4	main
kirja	doc_397823702015_item	2368738	et	4	main
vastan	doc_397823702015_item	2368739	et	3	main
kohe	doc_397823702015_item	2368740	et	4	main
varsti	doc_397823702015_item	2368747	et	3	main
biletid	doc_397823702015_item	2368760	et	4	main
sõidame	doc_397823702015_item	2368762	et	3	main
siin	doc_397823702015_item	2368765	et	4	main
elab	doc_397823702015_item	2368766	et	3	main
minu	doc_397823702015_item	2368767	et	3	main
svetlana	doc_397823702015_item	2368769	et	4	main
on	doc_397823702015_item	2368771	et	4	main
pere	doc_397823702015_item	2368773	et	4	main
kord	doc_397823702015_item	2368788	et	4	main
need	doc_397823702015_item	2368789	et	3	main
on	doc_397823702015_item	2368790	et	4	main
suur	doc_397823702015_item	2368791	et	3	main
ja	doc_397823702015_item	2368793	et	3	main
me	doc_397823702015_item	2368794	et	4	main
peatame	doc_397823702015_item	2368795	et	3	main
sõbranna	doc_397823702015_item	2368796	et	4	main
majas	doc_397823702015_item	2368797	et	3	main
me	doc_397823702015_item	2368798	et	4	main
plaanerinime	doc_397823702015_item	2368799	et	4	main
jalutada	doc_397823702015_item	2368800	et	3	main
linnas	doc_397823702015_item	2368801	et	4	main
koos	doc_397823702015_item	2368802	et	4	main
lapsega	doc_397823702015_item	2368803	et	3	main
läheme	doc_397823702015_item	2368804	et	3	main
loomaajas	doc_397823702015_item	2368805	et	4	main
ja	doc_397823702015_item	2368806	et	3	main
õhtul	doc_397823702015_item	2368807	et	3	main
võib	doc_397823702015_item	2368808	et	3	main
olla	doc_397823702015_item	2368809	et	3	main
käime	doc_397823702015_item	2368810	et	4	main
teatris	doc_397823702015_item	2368811	et	3	main
moskvas	doc_397823702015_item	2368812	et	4	main
on	doc_397823702015_item	2368813	et	4	main
väga	doc_397823702015_item	2368814	et	3	main
linn	doc_397823702015_item	2368816	et	3	main
huvitava	doc_397823702015_item	2368815	et	4	main
pärast	doc_397823702015_item	2368817	et	4	main
ma	doc_397823702015_item	2368818	et	3	main
kirjutan	doc_397823702015_item	2368819	et	3	main
sulle	doc_397823702015_item	2368820	et	3	main
mis	doc_397823702015_item	2368821	et	4	main
käisin	doc_397823702015_item	2368823	et	3	main
väga	doc_397823702015_item	2368826	et	3	main
rahull	doc_397823702015_item	2368827	et	4	main
et	doc_397823702015_item	2368828	et	3	main
küllas	doc_397823702015_item	2368786	et	3	main
esimine	doc_397823702015_item	2368787	et	4	main
ma	doc_397823702015_item	2368822	et	3	main
me	doc_397823702015_item	2368824	et	4	main
oleme	doc_397823702015_item	2368825	et	3	main
koos	doc_397823702015_item	2368830	et	4	main
kirjuta	doc_397823702015_item	2368832	et	4	main
kuidas	doc_397823702015_item	2368834	et	3	main
elab	doc_397823702015_item	2368835	et	3	main
lapsed	doc_397823702015_item	2368840	et	3	main
vanemaid	doc_397823702015_item	2368842	et	4	main
plaanite	doc_397823702016_item	2368847	et	3	main
kirjutage	doc_397823702016_item	2368856	et	3	main
kuhu	doc_397823702016_item	2368859	et	3	main
palju	doc_397823702016_item	2368868	et	4	main
merike	doc_397823702016_item	2368882	et	4	main
mul	doc_397823702016_item	2368883	et	3	main
mulle	doc_397823702016_item	2368894	et	4	main
plaanerin	doc_397823702016_item	2368906	et	4	main
reisi	doc_397823702016_item	2368907	et	4	main
sõida	doc_397823702016_item	2368911	et	4	main
ostan	doc_397823702016_item	2368916	et	3	main
mulle	doc_397823702015_item	2368833	et	4	main
õpivad	doc_397823702015_item	2368839	et	3	main
eesnimi	doc_397823702015_item	2368844	et	3	main
sõbrale	doc_397823702016_item	2368855	et	3	main
nõutav	doc_397823702016_item	2368875	et	4	main
on	doc_397823702016_item	2368884	et	4	main
sa	doc_397823702016_item	2368888	et	3	main
kirjutasid	doc_397823702016_item	2368890	et	4	main
sa	doc_397823702016_item	2368891	et	3	main
ei	doc_397823702016_item	2368892	et	4	main
ammu	doc_397823702016_item	2368896	et	4	main
hasti	doc_397823702016_item	2368900	et	4	main
ma	doc_397823702016_item	2368909	et	3	main
eile	doc_397823702016_item	2368914	et	3	main
ja	doc_397823702016_item	2368918	et	3	main
piletit	doc_397823702016_item	2368919	et	3	main
see	doc_397823702016_item	2368920	et	3	main
ma	doc_397823702016_item	2368924	et	3	main
ole	doc_397823702016_item	2368934	et	4	main
see	doc_397823702016_item	2368935	et	3	main
ümbes	doc_397823702016_item	2368937	et	4	main
edasi	doc_397823702016_item	2368944	et	3	main
on	doc_397823702016_item	2368947	et	4	main
tal	doc_397823702016_item	2368958	et	3	main
kohta	doc_397823702016_item	2368962	et	4	main
palju	doc_397823702016_item	2368964	et	4	main
mõtlen	doc_397823702016_item	2368965	et	3	main
et	doc_397823702016_item	2368966	et	3	main
puhkus	doc_397823702016_item	2368967	et	3	main
on	doc_397823702016_item	2368968	et	4	main
palun	doc_397823702016_item	2368976	et	3	main
head	doc_397823702016_item	2368979	et	4	main
umbes	doc_397823702017_item	2369017	et	4	main
sõna	doc_397823702017_item	2369019	et	4	main
tere	doc_397823702017_item	2369020	et	3	main
jaana	doc_397823702017_item	2369021	et	4	main
on	doc_397823702017_item	2369023	et	4	main
uudis	doc_397823702017_item	2369025	et	3	main
puhkas	doc_397823702017_item	2369028	et	3	main
venemale	doc_397823702017_item	2369034	et	4	main
kingitused	doc_397823702017_item	2369051	et	4	main
vatada	doc_397823702017_item	2369062	et	4	main
loomaajas	doc_397823702017_item	2369067	et	4	main
olin	doc_397823702017_item	2369075	et	3	main
hakkame	doc_397823702017_item	2369084	et	3	main
tädi	doc_397823702017_item	2369087	et	4	main
ei	doc_397823702017_item	2369089	et	4	main
ei	doc_397823702017_item	2369095	et	4	main
mitu	doc_397823702017_item	2369097	et	4	main
millal	doc_397823702018_item	2369128	et	3	main
te	doc_397823702018_item	2369131	et	4	main
millega	doc_397823702018_item	2369134	et	3	main
kui	doc_397823702018_item	2369138	et	3	main
see	doc_397823702018_item	2369140	et	3	main
maksab	doc_397823702018_item	2369141	et	3	main
millistes	doc_397823702018_item	2369142	et	3	main
nõutav	doc_397823702018_item	2369146	et	4	main
vastata	doc_397823702018_item	2369168	et	4	main
ma	doc_397823702018_item	2369181	et	3	main
sõita	doc_397823702018_item	2369183	et	3	main
me	doc_397823702018_item	2369187	et	4	main
homme	doc_397823702018_item	2369189	et	3	main
hommikul	doc_397823702018_item	2369190	et	3	main
käin	doc_397823702018_item	2369194	et	3	main
sõita	doc_397823702018_item	2369197	et	3	main
tulge	doc_397823702018_item	2369216	et	3	main
siis	doc_397823702018_item	2369219	et	3	main
täpselt	doc_397823702018_item	2369221	et	4	main
kuus	doc_397823702018_item	2369232	et	4	main
helista	doc_397823702018_item	2369245	et	4	main
kui	doc_397823702018_item	2369246	et	3	main
sa	doc_397823702018_item	2369247	et	3	main
ei	doc_397823702018_item	2369248	et	4	main
head	doc_397823702018_item	2369254	et	4	main
sõbranna	doc_397823702018_item	2369257	et	4	main
aus	doc_398228895326_item	2369266	et	4	main
br	doc_398228895326_item	2369268	et	4	main
ole	doc_398228895326_item	2369270	et	4	main
eesti	doc_398228895326_item	2369280	et	4	main
on	doc_398228895326_item	2369287	et	4	main
pere	doc_397823702015_item	2368837	et	4	main
kiri	doc_397823702016_item	2368845	et	3	main
sellest	doc_397823702016_item	2368851	et	4	main
kiri	doc_397823702016_item	2368852	et	3	main
oma	doc_397823702016_item	2368853	et	4	main
eestlasest	doc_397823702016_item	2368854	et	3	main
sõita	doc_397823702016_item	2368861	et	3	main
kui	doc_397823702016_item	2368867	et	3	main
see	doc_397823702016_item	2368869	et	3	main
millistes	doc_397823702016_item	2368871	et	3	main
peatute	doc_397823702016_item	2368873	et	4	main
umbes	doc_397823702016_item	2368877	et	4	main
hea	doc_397823702016_item	2368885	et	4	main
et	doc_397823702016_item	2368887	et	3	main
väga	doc_397823702016_item	2368895	et	3	main
venemaale	doc_397823702016_item	2368908	et	4	main
peterburgis	doc_397823702016_item	2368913	et	4	main
viiza	doc_397823702016_item	2368917	et	4	main
lapsega	doc_397823702016_item	2368927	et	3	main
krooni	doc_397823702016_item	2368940	et	4	main
ma	doc_397823702016_item	2368941	et	3	main
ostan	doc_397823702016_item	2368942	et	3	main
see	doc_397823702016_item	2368946	et	3	main
soodust	doc_397823702016_item	2368948	et	3	main
on	doc_397823702016_item	2368950	et	4	main
kirjutan	doc_397823702016_item	2368973	et	3	main
kiiremini	doc_397823702016_item	2368977	et	4	main
sulle	doc_397823702016_item	2368980	et	3	main
80	doc_397823702017_item	2369018	et	2	main
plaanin	doc_397823702017_item	2369032	et	3	main
suvenirid	doc_397823702017_item	2369053	et	4	main
vene	doc_397823702017_item	2369064	et	4	main
varem	doc_397823702017_item	2369073	et	4	main
ma	doc_397823702017_item	2369074	et	3	main
elama	doc_397823702017_item	2369085	et	3	main
aasta	doc_397823702017_item	2369093	et	4	main
kirjutage	doc_397823702018_item	2369121	et	3	main
ja	doc_397823702018_item	2369129	et	3	main
peatute	doc_397823702018_item	2369144	et	4	main
sinult	doc_397823702018_item	2369159	et	3	main
suur	doc_397823702018_item	2369161	et	3	main
sellest	doc_397823702018_item	2369177	et	4	main
kirjutada	doc_397823702018_item	2369178	et	3	main
sel	doc_397823702018_item	2369179	et	3	main
aastal	doc_397823702018_item	2369180	et	3	main
ma	doc_397823702018_item	2369192	et	3	main
näetusel	doc_397823702018_item	2369196	et	4	main
külastame	doc_397823702018_item	2369201	et	3	main
ermitažis	doc_397823702018_item	2369204	et	2	main
tulla	doc_397823702018_item	2369207	et	3	main
ja	doc_397823702018_item	2369209	et	3	main
minu	doc_397823702018_item	2369217	et	3	main
ma	doc_397823702018_item	2369223	et	3	main
sind	doc_397823702018_item	2369225	et	4	main
selle	doc_397823702018_item	2369226	et	4	main
kuu	doc_397823702018_item	2369227	et	4	main
viimasel	doc_397823702018_item	2369228	et	3	main
laupäeval	doc_397823702018_item	2369229	et	3	main
umbes	doc_397823702018_item	2369230	et	4	main
kell	doc_397823702018_item	2369231	et	3	main
õhtul	doc_397823702018_item	2369233	et	3	main
kõiki	doc_397823702018_item	2369244	et	4	main
kohtumiseni	doc_397823702018_item	2369255	et	4	main
midagi	doc_398228895326_item	2369262	et	4	main
hirmsamat	doc_398228895326_item	2369263	et	4	main
kui	doc_398228895326_item	2369264	et	3	main
ei	doc_398228895326_item	2369269	et	4	main
midagi	doc_398228895326_item	2369271	et	4	main
seda	doc_398228895326_item	2369277	et	3	main
naistegelane	doc_398228895326_item	2369283	et	3	main
peavad	doc_398228895326_item	2369291	et	4	main
br	doc_398228895326_item	2369321	et	4	main
osa	doc_398228895326_item	2369326	et	4	main
ja	doc_398228895326_item	2369330	et	3	main
erik	doc_398228895326_item	2369333	et	4	main
püüdis	doc_398228895326_item	2369337	et	3	main
seda	doc_398228895326_item	2369339	et	3	main
õnnestus	doc_398228895326_item	2369345	et	4	main
et	doc_398228895326_item	2369357	et	3	main
kõrgele	doc_398228895326_item	2369361	et	4	main
olid	doc_398228895326_item	2369387	et	4	main
taga	doc_398228895326_item	2369391	et	4	main
väga	doc_397823702016_item	2368922	et	3	main
kallid	doc_397823702016_item	2368923	et	3	main
sõidan	doc_397823702016_item	2368925	et	3	main
maksab	doc_397823702016_item	2368936	et	3	main
nelitoaline	doc_397823702016_item	2368960	et	4	main
sõin	doc_397823702016_item	2368972	et	3	main
ole	doc_397823702016_item	2368981	et	4	main
terve	doc_397823702016_item	2368982	et	4	main
suudlen	doc_397823702016_item	2368983	et	3	main
eesnimi	doc_397823702016_item	2368984	et	3	main
kiri	doc_397823702017_item	2368985	et	3	main
te	doc_397823702017_item	2368986	et	4	main
plaanite	doc_397823702017_item	2368987	et	3	main
reisi	doc_397823702017_item	2368988	et	4	main
venemaale	doc_397823702017_item	2368989	et	4	main
kirjutage	doc_397823702017_item	2368990	et	3	main
sellest	doc_397823702017_item	2368991	et	4	main
kiri	doc_397823702017_item	2368992	et	3	main
oma	doc_397823702017_item	2368993	et	4	main
eestlasest	doc_397823702017_item	2368994	et	3	main
sõbrale	doc_397823702017_item	2368995	et	3	main
kirjutage	doc_397823702017_item	2368996	et	3	main
millal	doc_397823702017_item	2368997	et	3	main
ja	doc_397823702017_item	2368998	et	3	main
te	doc_397823702017_item	2369000	et	4	main
kuhu	doc_397823702017_item	2368999	et	3	main
sõita	doc_397823702017_item	2369001	et	3	main
soovite	doc_397823702017_item	2369002	et	3	main
millega	doc_397823702017_item	2369003	et	3	main
reisite	doc_397823702017_item	2369004	et	3	main
kus	doc_397823702017_item	2369005	et	3	main
ööbite	doc_397823702017_item	2369006	et	3	main
kui	doc_397823702017_item	2369007	et	3	main
palju	doc_397823702017_item	2369008	et	4	main
see	doc_397823702017_item	2369009	et	3	main
maksab	doc_397823702017_item	2369010	et	3	main
millistes	doc_397823702017_item	2369011	et	3	main
kohtades	doc_397823702017_item	2369012	et	3	main
peatute	doc_397823702017_item	2369013	et	4	main
kirja	doc_397823702017_item	2369014	et	4	main
nõutav	doc_397823702017_item	2369015	et	4	main
pikkus	doc_397823702017_item	2369016	et	4	main
mul	doc_397823702017_item	2369022	et	3	main
hea	doc_397823702017_item	2369024	et	4	main
reisi	doc_397823702017_item	2369033	et	4	main
lastega	doc_397823702017_item	2369038	et	3	main
juba	doc_397823702017_item	2369040	et	3	main
müüjasime	doc_397823702017_item	2369041	et	4	main
pileti	doc_397823702017_item	2369042	et	3	main
2	doc_397823702017_item	2369045	et	2	main
junil	doc_397823702017_item	2369046	et	4	main
rongiga	doc_397823702017_item	2369047	et	4	main
müüjaksib	doc_397823702017_item	2369050	et	4	main
meid	doc_397823702017_item	2369057	et	4	main
me	doc_397823702017_item	2369058	et	4	main
tahame	doc_397823702017_item	2369059	et	3	main
sõidada	doc_397823702017_item	2369060	et	4	main
ermitazi	doc_397823702017_item	2369063	et	4	main
seal	doc_397823702017_item	2369076	et	4	main
tihti	doc_397823702017_item	2369077	et	3	main
me	doc_397823702017_item	2369083	et	4	main
tahan	doc_397823702017_item	2369103	et	3	main
sõida	doc_397823702017_item	2369104	et	4	main
kuhu	doc_397823702017_item	2369105	et	3	main
ma	doc_397823702017_item	2369106	et	3	main
sõidan	doc_397823702017_item	2369107	et	3	main
tagasi	doc_397823702017_item	2369108	et	3	main
ma	doc_397823702017_item	2369109	et	3	main
kirjutan	doc_397823702017_item	2369110	et	3	main
temale	doc_397823702017_item	2369111	et	3	main
nägemiseni	doc_397823702017_item	2369112	et	4	main
sulle	doc_397823702017_item	2369113	et	3	main
sõbranna	doc_397823702017_item	2369114	et	4	main
eesnimi	doc_397823702017_item	2369115	et	3	main
kiri	doc_397823702018_item	2369116	et	3	main
te	doc_397823702018_item	2369117	et	4	main
plaanite	doc_397823702018_item	2369118	et	3	main
reisi	doc_397823702018_item	2369119	et	4	main
venemaale	doc_397823702018_item	2369120	et	4	main
sõbrale	doc_397823702018_item	2369126	et	3	main
kuhu	doc_397823702018_item	2369130	et	3	main
kus	doc_397823702018_item	2369136	et	3	main
pikkus	doc_397823702018_item	2369147	et	4	main
umbes	doc_397823702018_item	2369148	et	4	main
80	doc_397823702018_item	2369149	et	2	main
tere	doc_397823702018_item	2369151	et	3	main
kallis	doc_397823702018_item	2369152	et	4	main
sõbranna	doc_397823702018_item	2369153	et	4	main
sellest	doc_397823702018_item	2369122	et	4	main
oma	doc_397823702018_item	2369124	et	4	main
eestlasest	doc_397823702018_item	2369125	et	3	main
sõita	doc_397823702018_item	2369132	et	3	main
reisite	doc_397823702018_item	2369135	et	3	main
kohtades	doc_397823702018_item	2369143	et	3	main
kirja	doc_397823702018_item	2369145	et	4	main
sain	doc_397823702018_item	2369156	et	3	main
eile	doc_397823702018_item	2369157	et	3	main
õhtul	doc_397823702018_item	2369158	et	3	main
kirja	doc_397823702018_item	2369160	et	4	main
aitäh	doc_397823702018_item	2369162	et	3	main
eest	doc_397823702018_item	2369164	et	4	main
ma	doc_397823702018_item	2369165	et	3	main
sest	doc_397823702018_item	2369169	et	4	main
on	doc_397823702018_item	2369171	et	4	main
sulle	doc_397823702018_item	2369172	et	3	main
uudis	doc_397823702018_item	2369173	et	3	main
ma	doc_397823702018_item	2369174	et	3	main
tahan	doc_397823702018_item	2369175	et	3	main
sulle	doc_397823702018_item	2369176	et	3	main
soovin	doc_397823702018_item	2369182	et	3	main
venemaale	doc_397823702018_item	2369184	et	4	main
veel	doc_397823702018_item	2369199	et	4	main
me	doc_397823702018_item	2369211	et	4	main
sõidame	doc_397823702018_item	2369212	et	3	main
nädalat	doc_397823702018_item	2369215	et	3	main
ma	doc_397823702018_item	2369241	et	3	main
saa	doc_397823702018_item	2369249	et	4	main
tulla	doc_397823702018_item	2369250	et	3	main
soovin	doc_397823702018_item	2369251	et	3	main
sulle	doc_397823702018_item	2369252	et	3	main
sinu	doc_397823702018_item	2369256	et	3	main
hirmsamat	doc_398228895326_item	2369272	et	4	main
üks	doc_398228895326_item	2369274	et	3	main
väljendit	doc_398228895326_item	2369278	et	3	main
film	doc_398228895326_item	2369286	et	3	main
pühendatud	doc_398228895326_item	2369288	et	4	main
neile	doc_398228895326_item	2369289	et	4	main
ööbite	doc_397823702018_item	2369137	et	3	main
palju	doc_397823702018_item	2369139	et	4	main
sõna	doc_397823702018_item	2369150	et	4	main
olga	doc_397823702018_item	2369154	et	4	main
ma	doc_397823702018_item	2369155	et	3	main
sulle	doc_397823702018_item	2369167	et	3	main
peterburgi	doc_397823702018_item	2369186	et	4	main
sõitme	doc_397823702018_item	2369188	et	4	main
autobussiga	doc_397823702018_item	2369191	et	3	main
muuseumis	doc_397823702018_item	2369195	et	3	main
laevaga	doc_397823702018_item	2369198	et	4	main
muuseumi	doc_397823702018_item	2369203	et	4	main
mõtlen	doc_397823702018_item	2369206	et	3	main
teatrietendust	doc_397823702018_item	2369208	et	3	main
balleti	doc_397823702018_item	2369210	et	3	main
tagasi	doc_397823702018_item	2369213	et	3	main
jargmisel	doc_397823702018_item	2369214	et	4	main
kõigest	doc_397823702018_item	2369220	et	4	main
rääkima	doc_397823702018_item	2369222	et	3	main
ootan	doc_397823702018_item	2369224	et	3	main
tulge	doc_397823702018_item	2369234	et	3	main
oma	doc_397823702018_item	2369235	et	4	main
abikaasa	doc_397823702018_item	2369236	et	4	main
ja	doc_397823702018_item	2369237	et	3	main
lapsed	doc_397823702018_item	2369238	et	3	main
tulge	doc_397823702018_item	2369239	et	3	main
kindlasti	doc_397823702018_item	2369240	et	3	main
teid	doc_397823702018_item	2369243	et	4	main
kõike	doc_397823702018_item	2369253	et	4	main
eesnimi	doc_397823702018_item	2369258	et	3	main
ei	doc_398228895326_item	2369260	et	4	main
ole	doc_398228895326_item	2369261	et	4	main
inimene	doc_398228895326_item	2369267	et	3	main
kui	doc_398228895326_item	2369273	et	3	main
inimene	doc_398228895326_item	2369276	et	3	main
kes	doc_398228895326_item	2369290	et	4	main
ja	doc_398228895326_item	2369293	et	3	main
selles	doc_398228895326_item	2369322	et	4	main
tulivesiga	doc_398228895326_item	2369324	et	4	main
tulevane	doc_398228895326_item	2369331	et	3	main
lugu	doc_398228895326_item	2369340	et	4	main
tabama	doc_398228895326_item	2369342	et	3	main
kurjategijad	doc_398228895326_item	2369343	et	3	main
br	doc_398228895326_item	2369353	et	4	main
niidid	doc_398228895326_item	2369358	et	3	main
ja	doc_398228895326_item	2369362	et	3	main
selle	doc_398228895326_item	2369389	et	4	main
tapsid	doc_398228895326_item	2369393	et	4	main
meid	doc_398228895326_item	2369397	et	4	main
mida	doc_398228895326_item	2369404	et	4	main
tema	doc_398228895326_item	2369419	et	4	main
kirja	doc_397823702018_item	2369163	et	4	main
tahan	doc_397823702018_item	2369166	et	3	main
mulle	doc_397823702018_item	2369170	et	4	main
sankt	doc_397823702018_item	2369185	et	4	main
tahan	doc_397823702018_item	2369193	et	3	main
me	doc_397823702018_item	2369200	et	4	main
petergofi	doc_397823702018_item	2369202	et	4	main
ma	doc_397823702018_item	2369205	et	3	main
külla	doc_397823702018_item	2369218	et	4	main
ootan	doc_397823702018_item	2369242	et	3	main
essee	doc_398228895326_item	2369259	et	4	main
üks	doc_398228895326_item	2369265	et	3	main
aus	doc_398228895326_item	2369275	et	4	main
lausus	doc_398228895326_item	2369279	et	4	main
filmi	doc_398228895326_item	2369281	et	4	main
tulivesi	doc_398228895326_item	2369282	et	4	main
hilda	doc_398228895326_item	2369284	et	4	main
br	doc_398228895326_item	2369285	et	4	main
lootusetut	doc_398228895326_item	2369294	et	4	main
võitlust	doc_398228895326_item	2369295	et	3	main
narkoäriga	doc_398228895326_item	2369296	et	3	main
1920	doc_398228895326_item	2369297	et	2	main
aastate	doc_398228895326_item	2369298	et	3	main
alguses	doc_398228895326_item	2369299	et	4	main
kuulutas	doc_398228895326_item	2369300	et	3	main
soome	doc_398228895326_item	2369301	et	3	main
valitsus	doc_398228895326_item	2369302	et	4	main
välja	doc_398228895326_item	2369303	et	4	main
seaduse	doc_398228895326_item	2369305	et	3	main
kuiva	doc_398228895326_item	2369304	et	4	main
mis	doc_398228895326_item	2369306	et	4	main
12	doc_398228895326_item	2369308	et	2	main
aastat	doc_398228895326_item	2369309	et	3	main
kestis	doc_398228895326_item	2369307	et	4	main
soome	doc_398228895326_item	2369310	et	3	main
majandust	doc_398228895326_item	2369311	et	4	main
vapustanud	doc_398228895326_item	2369312	et	4	main
keeluseadusest	doc_398228895326_item	2369313	et	4	main
lõikasid	doc_398228895326_item	2369314	et	4	main
kasu	doc_398228895326_item	2369315	et	4	main
lahe	doc_398228895326_item	2369316	et	4	main
vastaskaldal	doc_398228895326_item	2369317	et	3	main
asuva	doc_398228895326_item	2369318	et	4	main
eesti	doc_398228895326_item	2369319	et	4	main
piiritusevedajad	doc_398228895326_item	2369320	et	3	main
juulius	doc_398228895326_item	2369329	et	4	main
kattai	doc_398228895326_item	2369336	et	4	main
uurima	doc_398228895326_item	2369338	et	3	main
tal	doc_398228895326_item	2369344	et	3	main
onu	doc_398228895326_item	2369348	et	4	main
ja	doc_398228895326_item	2369349	et	3	main
aga	doc_398228895326_item	2369354	et	3	main
tuli	doc_398228895326_item	2369355	et	4	main
neid	doc_398228895326_item	2369363	et	4	main
välja	doc_398228895326_item	2369385	et	4	main
kes	doc_398228895326_item	2369386	et	4	main
br	doc_398228895326_item	2369395	et	4	main
hilda	doc_398228895326_item	2369405	et	4	main
aleksandrile	doc_398228895326_item	2369407	et	4	main
selles	doc_398228895326_item	2369410	et	4	main
aleksander	doc_398228895326_item	2369412	et	4	main
armastama	doc_398228895326_item	2369414	et	3	main
pärast	doc_398228895326_item	2369420	et	4	main
ränka	doc_398228895326_item	2369292	et	4	main
äris	doc_398228895326_item	2369323	et	3	main
võtsid	doc_398228895326_item	2369325	et	4	main
hilda	doc_398228895326_item	2369327	et	4	main
abikaasa	doc_398228895326_item	2369332	et	4	main
piirivalvur	doc_398228895326_item	2369334	et	3	main
ja	doc_398228895326_item	2369341	et	3	main
tabada	doc_398228895326_item	2369346	et	3	main
hilda	doc_398228895326_item	2369347	et	4	main
panna	doc_398228895326_item	2369350	et	4	main
teda	doc_398228895326_item	2369351	et	4	main
viisid	doc_398228895326_item	2369359	et	4	main
terve	doc_398228895326_item	2369388	et	4	main
olukord	doc_398228895326_item	2369401	et	3	main
asi	doc_398228895326_item	2369408	et	4	main
et	doc_398228895326_item	2369411	et	3	main
hakkas	doc_398228895326_item	2369413	et	3	main
hildat	doc_398228895326_item	2369415	et	4	main
filmi	doc_398228895326_item	2369416	et	4	main
jooksul	doc_398228895326_item	2369417	et	4	main
aga	doc_398228895326_item	2369418	et	3	main
suri	doc_398228895326_item	2369421	et	3	main
aleks	doc_398228895326_item	2369428	et	4	main
ei	doc_398228895326_item	2369429	et	4	main
sellele	doc_398228895326_item	2369441	et	4	main
naine	doc_398228895326_item	2369442	et	3	main
ei	doc_398228895326_item	2369443	et	4	main
saanud	doc_398228895326_item	2369444	et	4	main
tema	doc_398228895326_item	2369475	et	4	main
ei	doc_398228895326_item	2369477	et	4	main
sureks	doc_398228895326_item	2369478	et	3	main
ja	doc_398228895326_item	2369479	et	3	main
mitte	doc_398228895326_item	2369480	et	3	main
midagi	doc_398228895326_item	2369481	et	4	main
positsioonist	doc_398228895326_item	2369490	et	3	main
aus	doc_398228895326_item	2369497	et	4	main
inimene	doc_398228895326_item	2369498	et	3	main
sõdur	doc_398228895326_item	2369499	et	3	main
saanud	doc_398228895326_item	2369503	et	4	main
fraas	doc_398228895326_item	2369517	et	3	main
või	doc_398228895326_item	2369520	et	4	main
tea	doc_398228895326_item	2369525	et	4	main
mis	doc_398228895326_item	2369526	et	4	main
temaga	doc_398228895326_item	2369528	et	3	main
ta	doc_398228895326_item	2369535	et	4	main
kohal	doc_398228895326_item	2369541	et	4	main
tarbi	doc_398961616083_item	2369545	et	4	main
maailmas	doc_398961616083_item	2369547	et	3	main
inimene	doc_398961616083_item	2369548	et	3	main
nii	doc_398961616083_item	2369550	et	3	main
ta	doc_398961616083_item	2369556	et	4	main
mõtlegi	doc_398961616083_item	2369559	et	4	main
kasutada	doc_398961616083_item	2369567	et	3	main
ei	doc_398961616083_item	2369569	et	4	main
mõista	doc_398961616083_item	2369570	et	4	main
et	doc_398961616083_item	2369571	et	3	main
kunagi	doc_398961616083_item	2369574	et	3	main
ilma	doc_398961616083_item	2369611	et	4	main
aga	doc_398961616083_item	2369614	et	3	main
ju	doc_398961616083_item	2369616	et	3	main
meie	doc_398961616083_item	2369629	et	4	main
saavutusi	doc_398961616083_item	2369632	et	4	main
maailmas	doc_398961616083_item	2369636	et	3	main
ei	doc_398961616083_item	2369648	et	4	main
toimub	doc_398961616083_item	2369651	et	3	main
ainult	doc_398961616083_item	2369661	et	4	main
oma	doc_398961616083_item	2369662	et	4	main
kõik	doc_398961616083_item	2369667	et	4	main
oleks	doc_398961616083_item	2369670	et	3	main
on	doc_398961616083_item	2369734	et	4	main
on	doc_398961616083_item	2369741	et	4	main
meie	doc_398961616083_item	2369742	et	4	main
mida	doc_398961616083_item	2369752	et	4	main
annab	doc_398961616083_item	2369754	et	3	main
saa	doc_398961616083_item	2369761	et	4	main
üldse	doc_398961616083_item	2369762	et	3	main
elada	doc_398961616083_item	2369763	et	3	main
inimene	doc_398961616083_item	2369764	et	3	main
see	doc_398961616083_item	2369784	et	3	main
on	doc_398961616083_item	2369796	et	4	main
selles	doc_398961616083_item	2369829	et	4	main
ainult	doc_398961616083_item	2369831	et	4	main
onu	doc_398228895326_item	2369328	et	4	main
aleksander	doc_398228895326_item	2369335	et	4	main
vangi	doc_398228895326_item	2369352	et	4	main
nii	doc_398228895326_item	2369356	et	3	main
päris	doc_398228895326_item	2369360	et	4	main
kes	doc_398228895326_item	2369364	et	4	main
on	doc_398228895326_item	2369365	et	4	main
kõrgel	doc_398228895326_item	2369366	et	4	main
andsid	doc_398228895326_item	2369367	et	4	main
käsku	doc_398228895326_item	2369368	et	4	main
tappa	doc_398228895326_item	2369369	et	4	main
juuliust	doc_398228895326_item	2369370	et	3	main
sest	doc_398228895326_item	2369371	et	4	main
ta	doc_398228895326_item	2369372	et	4	main
juba	doc_398228895326_item	2369373	et	3	main
ei	doc_398228895326_item	2369374	et	4	main
olnud	doc_398228895326_item	2369375	et	4	main
neile	doc_398228895326_item	2369376	et	4	main
vaja	doc_398228895326_item	2369377	et	4	main
ja	doc_398228895326_item	2369378	et	3	main
lihtsalt	doc_398228895326_item	2369379	et	4	main
segas	doc_398228895326_item	2369380	et	3	main
aleksander	doc_398228895326_item	2369381	et	4	main
koos	doc_398228895326_item	2369382	et	4	main
erikuga	doc_398228895326_item	2369383	et	4	main
selgusid	doc_398228895326_item	2369384	et	4	main
äri	doc_398228895326_item	2369390	et	4	main
ja	doc_398228895326_item	2369392	et	3	main
neid	doc_398228895326_item	2369394	et	4	main
huvitab	doc_398228895326_item	2369398	et	3	main
see	doc_398228895326_item	2369403	et	3	main
ütles	doc_398228895326_item	2369406	et	3	main
on	doc_398228895326_item	2369409	et	4	main
aru	doc_398228895326_item	2369426	et	4	main
et	doc_398228895326_item	2369427	et	3	main
sest	doc_398228895326_item	2369433	et	4	main
vaatamata	doc_398228895326_item	2369440	et	4	main
ja	doc_398228895326_item	2369448	et	3	main
siis	doc_398228895326_item	2369449	et	3	main
aus	doc_398228895326_item	2369461	et	4	main
õige	doc_398228895326_item	2369468	et	4	main
aleks	doc_398228895326_item	2369470	et	4	main
võib-olla	doc_398228895326_item	2369474	et	3	main
ei	doc_398228895326_item	2369482	et	4	main
vaadata	doc_398228895326_item	2369486	et	4	main
situatsioonile	doc_398228895326_item	2369488	et	3	main
siis	doc_398228895326_item	2369491	et	3	main
ja	doc_398228895326_item	2369500	et	3	main
ei	doc_398228895326_item	2369502	et	4	main
öelda	doc_398228895326_item	2369514	et	4	main
kas	doc_398228895326_item	2369515	et	3	main
see	doc_398228895326_item	2369516	et	3	main
aga	doc_398228895326_item	2369396	et	3	main
mitte	doc_398228895326_item	2369399	et	3	main
see	doc_398228895326_item	2369400	et	3	main
aga	doc_398228895326_item	2369402	et	3	main
hilda	doc_398228895326_item	2369422	et	4	main
ole	doc_398228895326_item	2369430	et	4	main
tegi	doc_398228895326_item	2369435	et	4	main
kõik	doc_398228895326_item	2369436	et	4	main
seaduse	doc_398228895326_item	2369437	et	3	main
järgi	doc_398228895326_item	2369438	et	4	main
aga	doc_398228895326_item	2369439	et	3	main
talle	doc_398228895326_item	2369445	et	4	main
andeks	doc_398228895326_item	2369446	et	3	main
andma	doc_398228895326_item	2369447	et	3	main
sekkuks	doc_398228895326_item	2369472	et	3	main
onu	doc_398228895326_item	2369476	et	4	main
juhtuks	doc_398228895326_item	2369483	et	4	main
kuidagi	doc_398228895326_item	2369504	et	3	main
br	doc_398228895326_item	2369507	et	4	main
arvan	doc_398228895326_item	2369509	et	3	main
keegi	doc_398228895326_item	2369523	et	4	main
juhtuda	doc_398228895326_item	2369529	et	3	main
ja	doc_398228895326_item	2369530	et	3	main
keegi	doc_398228895326_item	2369531	et	4	main
hilda	doc_398228895326_item	2369538	et	4	main
või	doc_398228895326_item	2369539	et	4	main
inimene	doc_398961616083_item	2369544	et	3	main
elektrit	doc_398961616083_item	2369552	et	3	main
gaasi	doc_398961616083_item	2369554	et	4	main
ju	doc_398961616083_item	2369557	et	3	main
kui	doc_398961616083_item	2369561	et	3	main
tuleb	doc_398961616083_item	2369565	et	3	main
elu	doc_398961616083_item	2369610	et	4	main
olid	doc_398961616083_item	2369615	et	4	main
need	doc_398961616083_item	2369617	et	3	main
kui	doc_398961616083_item	2369619	et	3	main
said	doc_398961616083_item	2369621	et	4	main
maailma	doc_398961616083_item	2369631	et	4	main
ma	doc_398961616083_item	2369633	et	3	main
on	doc_398961616083_item	2369637	et	4	main
palju	doc_398961616083_item	2369639	et	4	main
inimesi	doc_398961616083_item	2369640	et	4	main
pärast	doc_398961616083_item	2369657	et	4	main
et	doc_398961616083_item	2369666	et	3	main
parem	doc_398961616083_item	2369671	et	4	main
kui	doc_398961616083_item	2369672	et	3	main
keegi	doc_398961616083_item	2369673	et	4	main
teame	doc_398961616083_item	2369711	et	3	main
ja	doc_398961616083_item	2369715	et	3	main
loodus	doc_398961616083_item	2369736	et	4	main
tähendab	doc_398961616083_item	2369738	et	3	main
elu	doc_398961616083_item	2369743	et	4	main
allikas	doc_398961616083_item	2369744	et	4	main
ja	doc_398961616083_item	2369745	et	3	main
saa	doc_398961616083_item	2369748	et	4	main
ilma	doc_398961616083_item	2369757	et	4	main
selleta	doc_398961616083_item	2369758	et	3	main
me	doc_398961616083_item	2369759	et	4	main
seda	doc_398961616083_item	2369766	et	3	main
aga	doc_398961616083_item	2369768	et	3	main
küsimus	doc_398961616083_item	2369770	et	4	main
palju	doc_398961616083_item	2369772	et	4	main
ta	doc_398961616083_item	2369773	et	4	main
seda	doc_398961616083_item	2369774	et	3	main
teeb	doc_398961616083_item	2369775	et	3	main
tule	doc_398961616083_item	2369782	et	4	main
too	doc_398961616083_item	2369786	et	4	main
mitte	doc_398961616083_item	2369788	et	3	main
üks	doc_398961616083_item	2369832	et	3	main
sest	doc_398961616083_item	2369847	et	4	main
ja	doc_398961616083_item	2369860	et	3	main
loodus	doc_398961616083_item	2369866	et	4	main
soovime	doc_398961616083_item	2369871	et	4	main
vana	doc_399014257165_item	2369883	et	4	main
ja	doc_399014257165_item	2369884	et	3	main
kulunud	doc_399014257165_item	2369885	et	4	main
väljend	doc_399014257165_item	2369886	et	3	main
ajakirjandus	doc_399014257165_item	2369890	et	3	main
või	doc_399014257165_item	2369891	et	4	main
lahkus	doc_399014257165_item	2369905	et	4	main
washington	doc_399014257165_item	2369919	et	4	main
bernstein	doc_399014257165_item	2369926	et	4	main
uurima	doc_399014257165_item	2369928	et	3	main
süüdi	doc_398228895326_item	2369431	et	4	main
selles	doc_398228895326_item	2369432	et	4	main
aleksile	doc_398228895326_item	2369452	et	4	main
et	doc_398228895326_item	2369453	et	3	main
ei	doc_398228895326_item	2369454	et	4	main
ole	doc_398228895326_item	2369455	et	4	main
mitte	doc_398228895326_item	2369456	et	3	main
midagi	doc_398228895326_item	2369457	et	4	main
jubedamat	doc_398228895326_item	2369458	et	4	main
kui	doc_398228895326_item	2369459	et	3	main
üks	doc_398228895326_item	2369460	et	3	main
inimene	doc_398228895326_item	2369462	et	3	main
br	doc_398228895326_item	2369463	et	4	main
hilda	doc_398228895326_item	2369464	et	4	main
onu	doc_398228895326_item	2369423	et	4	main
ta	doc_398228895326_item	2369424	et	4	main
sai	doc_398228895326_item	2369425	et	4	main
ta	doc_398228895326_item	2369434	et	4	main
ta	doc_398228895326_item	2369450	et	4	main
ütles	doc_398228895326_item	2369451	et	3	main
positsioonist	doc_398228895326_item	2369465	et	3	main
see	doc_398228895326_item	2369466	et	3	main
ei	doc_398228895326_item	2369471	et	4	main
kui	doc_398228895326_item	2369485	et	3	main
aleksi	doc_398228895326_item	2369489	et	4	main
tal	doc_398228895326_item	2369492	et	3	main
õigus	doc_398228895326_item	2369494	et	4	main
ta	doc_398228895326_item	2369495	et	4	main
ta	doc_398228895326_item	2369501	et	4	main
ma	doc_398228895326_item	2369508	et	3	main
et	doc_398228895326_item	2369510	et	3	main
täpselt	doc_398228895326_item	2369513	et	4	main
õige	doc_398228895326_item	2369519	et	4	main
vale	doc_398228895326_item	2369521	et	4	main
tea	doc_398228895326_item	2369533	et	4	main
kas	doc_398228895326_item	2369534	et	3	main
aleksi	doc_398228895326_item	2369540	et	4	main
sellest	doc_398961616083_item	2369560	et	4	main
resurse	doc_398961616083_item	2369564	et	4	main
inimene	doc_398961616083_item	2369568	et	3	main
need	doc_398961616083_item	2369572	et	3	main
resursid	doc_398961616083_item	2369573	et	4	main
ette	doc_398961616083_item	2369608	et	4	main
meie	doc_398961616083_item	2369609	et	4	main
inimesed	doc_398961616083_item	2369620	et	3	main
lihtsalt	doc_398961616083_item	2369623	et	4	main
mitte	doc_398961616083_item	2369627	et	3	main
ainult	doc_398961616083_item	2369643	et	4	main
ühe	doc_398961616083_item	2369644	et	4	main
päevaga	doc_398961616083_item	2369645	et	3	main
ja	doc_398961616083_item	2369646	et	3	main
mis	doc_398961616083_item	2369650	et	4	main
järgmise	doc_398961616083_item	2369652	et	3	main
või	doc_398961616083_item	2369654	et	4	main
elu	doc_398961616083_item	2369663	et	4	main
vastu	doc_398961616083_item	2369664	et	3	main
et	doc_398961616083_item	2369677	et	3	main
kaasaaegsel	doc_398961616083_item	2369707	et	3	main
kõik	doc_398961616083_item	2369709	et	4	main
vaja	doc_398961616083_item	2369719	et	4	main
jüüa	doc_398961616083_item	2369721	et	4	main
ka	doc_398961616083_item	2369724	et	3	main
aga	doc_398961616083_item	2369726	et	3	main
mis	doc_398961616083_item	2369727	et	4	main
annab	doc_398961616083_item	2369728	et	3	main
meile	doc_398961616083_item	2369729	et	4	main
kõik	doc_398961616083_item	2369730	et	4	main
neeid	doc_398961616083_item	2369731	et	4	main
toiduaineid	doc_398961616083_item	2369732	et	3	main
et	doc_398961616083_item	2369739	et	3	main
ei	doc_398961616083_item	2369747	et	4	main
peab	doc_398961616083_item	2369765	et	4	main
kõik	doc_398961616083_item	2369776	et	4	main
me	doc_398961616083_item	2369777	et	4	main
ei	doc_398961616083_item	2369785	et	4	main
meile	doc_398961616083_item	2369787	et	4	main
teiste	doc_398961616083_item	2369821	et	4	main
kokkuvõtteks	doc_398961616083_item	2369823	et	3	main
öelda	doc_398961616083_item	2369825	et	4	main
et	doc_398961616083_item	2369826	et	3	main
oleme	doc_398961616083_item	2369836	et	3	main
oma	doc_398961616083_item	2369837	et	4	main
maista	doc_398961616083_item	2369846	et	4	main
tarbisime	doc_398961616083_item	2369859	et	3	main
tarvime	doc_398961616083_item	2369861	et	4	main
tarbi	doc_398961616083_item	2369873	et	4	main
essee	doc_399014257165_item	2369876	et	4	main
see	doc_399014257165_item	2369881	et	3	main
on	doc_399014257165_item	2369882	et	4	main
siiski	doc_399014257165_item	2369888	et	4	main
kuningaid	doc_399014257165_item	2369895	et	3	main
on	doc_399014257165_item	2369897	et	4	main
näide	doc_399014257165_item	2369899	et	3	main
nixon	doc_399014257165_item	2369904	et	4	main
aastal	doc_399014257165_item	2369907	et	3	main
on	doc_398228895326_item	2369467	et	4	main
kui	doc_398228895326_item	2369469	et	3	main
siis	doc_398228895326_item	2369473	et	3	main
aga	doc_398228895326_item	2369484	et	3	main
sellele	doc_398228895326_item	2369487	et	4	main
on	doc_398228895326_item	2369493	et	4	main
on	doc_398228895326_item	2369496	et	4	main
teisiti	doc_398228895326_item	2369505	et	3	main
käituda	doc_398228895326_item	2369506	et	3	main
ei	doc_398228895326_item	2369511	et	4	main
saa	doc_398228895326_item	2369512	et	4	main
on	doc_398228895326_item	2369518	et	4	main
sest	doc_398228895326_item	2369522	et	4	main
on	doc_398228895326_item	2369536	et	4	main
homme	doc_398228895326_item	2369537	et	3	main
tarbi	doc_398961616083_item	2369543	et	4	main
tänapäevases	doc_398961616083_item	2369546	et	4	main
tarbib	doc_398961616083_item	2369549	et	3	main
aga	doc_398961616083_item	2369555	et	3	main
looduslikke	doc_398961616083_item	2369563	et	3	main
saavad	doc_398961616083_item	2369575	et	4	main
lõppeda	doc_398961616083_item	2369576	et	3	main
asjadeta	doc_398961616083_item	2369613	et	3	main
ei	doc_398228895326_item	2369524	et	4	main
võib	doc_398228895326_item	2369527	et	3	main
ei	doc_398228895326_item	2369532	et	4	main
body	doc_398228895326_item	2369542	et	4	main
palju	doc_398961616083_item	2369551	et	4	main
vett	doc_398961616083_item	2369553	et	3	main
ei	doc_398961616083_item	2369558	et	4	main
palju	doc_398961616083_item	2369562	et	4	main
selleks	doc_398961616083_item	2369566	et	4	main
aga	doc_398961616083_item	2369577	et	3	main
mis	doc_398961616083_item	2369578	et	4	main
teha	doc_398961616083_item	2369579	et	3	main
kui	doc_398961616083_item	2369580	et	3	main
kõik	doc_398961616083_item	2369581	et	4	main
elu	doc_398961616083_item	2369583	et	4	main
meie	doc_398961616083_item	2369582	et	4	main
on	doc_398961616083_item	2369584	et	4	main
seotud	doc_398961616083_item	2369585	et	4	main
asjadega	doc_398961616083_item	2369586	et	3	main
mis	doc_398961616083_item	2369587	et	4	main
ei	doc_398961616083_item	2369588	et	4	main
saa	doc_398961616083_item	2369589	et	4	main
töötada	doc_398961616083_item	2369590	et	3	main
ilma	doc_398961616083_item	2369591	et	4	main
elektrita	doc_398961616083_item	2369592	et	3	main
näiteks	doc_398961616083_item	2369593	et	4	main
arvutid	doc_398961616083_item	2369594	et	4	main
kodutehnika	doc_398961616083_item	2369595	et	4	main
teler	doc_398961616083_item	2369596	et	3	main
mobiiltelefon	doc_398961616083_item	2369597	et	3	main
jne	doc_398961616083_item	2369598	et	4	main
me	doc_398961616083_item	2369599	et	4	main
elame	doc_398961616083_item	2369600	et	3	main
kahekümne	doc_398961616083_item	2369601	et	4	main
esimeses	doc_398961616083_item	2369602	et	3	main
sajandis	doc_398961616083_item	2369603	et	3	main
ja	doc_398961616083_item	2369604	et	3	main
isegi	doc_398961616083_item	2369605	et	4	main
ei	doc_398961616083_item	2369606	et	4	main
kujuta	doc_398961616083_item	2369607	et	4	main
selliste	doc_398961616083_item	2369612	et	4	main
muinasajad	doc_398961616083_item	2369618	et	3	main
kasutades	doc_398961616083_item	2369628	et	3	main
et	doc_398961616083_item	2369635	et	3	main
elavad	doc_398961616083_item	2369642	et	4	main
huvita	doc_398961616083_item	2369649	et	4	main
50	doc_398961616083_item	2369653	et	2	main
100	doc_398961616083_item	2369655	et	2	main
aasta	doc_398961616083_item	2369656	et	4	main
nad	doc_398961616083_item	2369658	et	3	main
tunnevad	doc_398961616083_item	2369659	et	3	main
huvi	doc_398961616083_item	2369660	et	4	main
tahavad	doc_398961616083_item	2369665	et	3	main
teavad	doc_398961616083_item	2369676	et	3	main
kunagi	doc_398961616083_item	2369679	et	3	main
et	doc_398961616083_item	2369712	et	3	main
elada	doc_398961616083_item	2369714	et	3	main
meil	doc_398961616083_item	2369717	et	4	main
see	doc_398961616083_item	2369722	et	3	main
ka	doc_398961616083_item	2369735	et	3	main
see	doc_398961616083_item	2369737	et	3	main
mitte	doc_398961616083_item	2369749	et	3	main
seda	doc_398961616083_item	2369751	et	3	main
ta	doc_398961616083_item	2369753	et	4	main
ei	doc_398961616083_item	2369760	et	4	main
kui	doc_398961616083_item	2369771	et	3	main
teha	doc_398961616083_item	2369783	et	3	main
mingit	doc_398961616083_item	2369789	et	3	main
kasu	doc_398961616083_item	2369790	et	4	main
vaid	doc_398961616083_item	2369791	et	3	main
vastupidi	doc_398961616083_item	2369792	et	3	main
toob	doc_398961616083_item	2369793	et	3	main
kahju	doc_398961616083_item	2369794	et	4	main
jaoks	doc_398961616083_item	2369822	et	4	main
tahaksin	doc_398961616083_item	2369824	et	3	main
me	doc_398961616083_item	2369827	et	4	main
elame	doc_398961616083_item	2369828	et	3	main
maailmas	doc_398961616083_item	2369830	et	3	main
elu	doc_398961616083_item	2369838	et	4	main
peremehed	doc_398961616083_item	2369839	et	3	main
ja	doc_398961616083_item	2369840	et	3	main
tahame	doc_398961616083_item	2369842	et	3	main
kõike	doc_398961616083_item	2369843	et	4	main
proovida	doc_398961616083_item	2369844	et	3	main
ja	doc_398961616083_item	2369845	et	3	main
elu	doc_398961616083_item	2369848	et	4	main
ja	doc_398961616083_item	2369853	et	3	main
et	doc_398961616083_item	2369857	et	3	main
me	doc_398961616083_item	2369858	et	4	main
meie	doc_398961616083_item	2369865	et	4	main
me	doc_398961616083_item	2369869	et	4	main
inimene	doc_398961616083_item	2369874	et	3	main
tarbi	doc_398961616083_item	2369875	et	4	main
meedia	doc_399014257165_item	2369877	et	4	main
ajakirjandus	doc_399014257165_item	2369878	et	3	main
kolmas	doc_399014257165_item	2369879	et	3	main
riigivõim	doc_399014257165_item	2369880	et	3	main
tõsta	doc_399014257165_item	2369892	et	4	main
richard	doc_399014257165_item	2369903	et	4	main
ametikohalt	doc_399014257165_item	2369906	et	4	main
skandaali	doc_399014257165_item	2369910	et	4	main
tõttu	doc_399014257165_item	2369911	et	4	main
samas	doc_399014257165_item	2369912	et	4	main
see	doc_399014257165_item	2369913	et	3	main
posti	doc_399014257165_item	2369920	et	4	main
algas	doc_399014257165_item	2369943	et	3	main
lahkus	doc_399014257165_item	2369948	et	4	main
veel	doc_399014257165_item	2369950	et	4	main
novembris	doc_399014257165_item	2369951	et	3	main
ei	doc_399014257165_item	2369957	et	4	main
pätt	doc_399014257165_item	2369959	et	3	main
ka	doc_399014257165_item	2369963	et	3	main
olemaks	doc_399014257165_item	2369970	et	4	main
toimetaja	doc_399014257165_item	2369980	et	4	main
the	doc_399014257165_item	2369983	et	4	main
et	doc_399014257165_item	2369988	et	3	main
abikaasa	doc_399014257165_item	2369991	et	4	main
cia	doc_399014257165_item	2369993	et	4	main
luureagent	doc_399014257165_item	2369994	et	3	main
istus	doc_399014257165_item	2369996	et	4	main
ka	doc_399014257165_item	2370023	et	3	main
elada	doc_398961616083_item	2369622	et	3	main
loodusest	doc_398961616083_item	2369624	et	4	main
sõltuvuses	doc_398961616083_item	2369625	et	4	main
ja	doc_398961616083_item	2369626	et	3	main
kaasaaegse	doc_398961616083_item	2369630	et	3	main
arvan	doc_398961616083_item	2369634	et	3	main
nii	doc_398961616083_item	2369638	et	3	main
kes	doc_398961616083_item	2369641	et	4	main
neid	doc_398961616083_item	2369647	et	4	main
nende	doc_398961616083_item	2369668	et	4	main
elus	doc_398961616083_item	2369669	et	4	main
teisel	doc_398961616083_item	2369674	et	4	main
inimesed	doc_398961616083_item	2369675	et	3	main
nad	doc_398961616083_item	2369678	et	3	main
surevad	doc_398961616083_item	2369680	et	4	main
ja	doc_398961616083_item	2369681	et	3	main
kõik	doc_398961616083_item	2369682	et	4	main
need	doc_398961616083_item	2369683	et	3	main
halvad	doc_398961616083_item	2369684	et	4	main
asjad	doc_398961616083_item	2369685	et	3	main
nt	doc_398961616083_item	2369686	et	4	main
kui	doc_398961616083_item	2369687	et	3	main
lõpeb	doc_398961616083_item	2369688	et	4	main
kõik	doc_398961616083_item	2369689	et	4	main
looduslik	doc_398961616083_item	2369690	et	3	main
energia	doc_398961616083_item	2369691	et	4	main
ja	doc_398961616083_item	2369692	et	3	main
üldse	doc_398961616083_item	2369693	et	3	main
resursid	doc_398961616083_item	2369694	et	4	main
ei	doc_398961616083_item	2369695	et	4	main
puutu	doc_398961616083_item	2369696	et	4	main
neid	doc_398961616083_item	2369697	et	4	main
kunagi	doc_398961616083_item	2369698	et	3	main
tarbi	doc_398961616083_item	2369699	et	4	main
inimene	doc_398961616083_item	2369700	et	3	main
tarbi	doc_398961616083_item	2369701	et	4	main
see	doc_398961616083_item	2369702	et	3	main
on	doc_398961616083_item	2369703	et	4	main
nagu	doc_398961616083_item	2369704	et	3	main
deviis	doc_398961616083_item	2369705	et	3	main
meie	doc_398961616083_item	2369706	et	4	main
inimesel	doc_398961616083_item	2369708	et	3	main
me	doc_398961616083_item	2369710	et	4	main
lihtsalt	doc_398961616083_item	2369713	et	4	main
eksisteerida	doc_398961616083_item	2369716	et	3	main
on	doc_398961616083_item	2369718	et	4	main
süüa	doc_398961616083_item	2369720	et	3	main
on	doc_398961616083_item	2369723	et	4	main
tarvitamine	doc_398961616083_item	2369725	et	4	main
see	doc_398961616083_item	2369733	et	3	main
loodus	doc_398961616083_item	2369740	et	4	main
me	doc_398961616083_item	2369746	et	4	main
tarvitada	doc_398961616083_item	2369750	et	3	main
meile	doc_398961616083_item	2369755	et	4	main
sest	doc_398961616083_item	2369756	et	4	main
tarvitama	doc_398961616083_item	2369767	et	3	main
teine	doc_398961616083_item	2369769	et	3	main
teame	doc_398961616083_item	2369778	et	3	main
et	doc_398961616083_item	2369779	et	3	main
kuritarvitada	doc_398961616083_item	2369780	et	3	main
ei	doc_398961616083_item	2369781	et	4	main
inimesel	doc_398961616083_item	2369795	et	3	main
õigus	doc_398961616083_item	2369797	et	4	main
tarbima	doc_398961616083_item	2369798	et	3	main
kõike	doc_398961616083_item	2369799	et	4	main
mida	doc_398961616083_item	2369800	et	4	main
ta	doc_398961616083_item	2369801	et	4	main
tahab	doc_398961616083_item	2369802	et	3	main
ainult	doc_398961616083_item	2369803	et	4	main
piiratud	doc_398961616083_item	2369804	et	4	main
koguses	doc_398961616083_item	2369805	et	4	main
vajalikus	doc_398961616083_item	2369807	et	4	main
või	doc_398961616083_item	2369806	et	4	main
tema	doc_398961616083_item	2369808	et	4	main
jaoks	doc_398961616083_item	2369809	et	4	main
koguses	doc_398961616083_item	2369810	et	4	main
niiviisil	doc_398961616083_item	2369811	et	3	main
see	doc_398961616083_item	2369812	et	3	main
on	doc_398961616083_item	2369813	et	4	main
kasulik	doc_398961616083_item	2369814	et	3	main
tema	doc_398961616083_item	2369815	et	4	main
jaoks	doc_398961616083_item	2369816	et	4	main
ja	doc_398961616083_item	2369817	et	3	main
ei	doc_398961616083_item	2369818	et	4	main
ole	doc_398961616083_item	2369819	et	4	main
kahjulik	doc_398961616083_item	2369820	et	3	main
me	doc_398961616083_item	2369834	et	4	main
me	doc_398961616083_item	2369841	et	4	main
kord	doc_398961616083_item	2369833	et	4	main
ise	doc_398961616083_item	2369835	et	4	main
ole	doc_398961616083_item	2369850	et	4	main
pikk	doc_398961616083_item	2369852	et	4	main
see	doc_398961616083_item	2369855	et	3	main
mis	doc_398961616083_item	2369863	et	4	main
ise	doc_398961616083_item	2369870	et	4	main
tõsi	doc_399014257165_item	2369889	et	4	main
ja	doc_399014257165_item	2369893	et	3	main
lähiajaloos	doc_399014257165_item	2369896	et	4	main
hea	doc_399014257165_item	2369898	et	4	main
ameerika	doc_399014257165_item	2369900	et	3	main
president	doc_399014257165_item	2369902	et	3	main
1974	doc_399014257165_item	2369908	et	2	main
watergate	doc_399014257165_item	2369909	et	4	main
oli	doc_399014257165_item	2369914	et	3	main
uuriva	doc_399014257165_item	2369915	et	4	main
algpunktiks	doc_399014257165_item	2369917	et	4	main
toimetajad	doc_399014257165_item	2369921	et	4	main
woodward	doc_399014257165_item	2369923	et	4	main
ja	doc_399014257165_item	2369924	et	3	main
jõudnud	doc_399014257165_item	2369934	et	4	main
jäled	doc_399014257165_item	2369936	et	4	main
lõpuks	doc_399014257165_item	2369939	et	4	main
aastal	doc_399014257165_item	2369944	et	3	main
väitis	doc_399014257165_item	2369954	et	3	main
raiutakse	doc_399014257165_item	2369961	et	3	main
nüüd	doc_399014257165_item	2369964	et	4	main
ilewis	doc_399014257165_item	2369967	et	4	main
süüdistatakse	doc_399014257165_item	2369969	et	3	main
informatsioonivoolajaks	doc_399014257165_item	2369979	et	3	main
miller	doc_399014257165_item	2369982	et	4	main
timesista	doc_399014257165_item	2369986	et	4	main
on	doc_399014257165_item	2369992	et	4	main
ta	doc_399014257165_item	2370000	et	4	main
meil	doc_399014257165_item	2370021	et	4	main
pärast	doc_399014257165_item	2370034	et	4	main
mida	doc_399014257165_item	2370043	et	4	main
manninenilt	doc_399014257165_item	2370050	et	4	main
w	doc_399014257165_item	2370059	et	4	main
bushile	doc_399014257165_item	2370060	et	4	main
osaleb	doc_399014257165_item	2370063	et	3	main
koalitsiooni	doc_399014257165_item	2370066	et	4	main
relvi	doc_399014257165_item	2370073	et	4	main
afganistaanis	doc_399014257165_item	2370080	et	4	main
olen	doc_399014257165_item	2370082	et	3	main
parlamend	doc_399014257165_item	2370095	et	4	main
ja	doc_399014257165_item	2370102	et	3	main
ja	doc_399014257165_item	2370104	et	3	main
ajakijanikkud	doc_399014257165_item	2370114	et	4	main
ja	doc_399014257165_item	2370121	et	3	main
inimeste	doc_399014257165_item	2370127	et	3	main
meil	doc_399014257165_item	2370133	et	4	main
on	doc_399014257165_item	2370134	et	4	main
viieminuti	doc_399014257165_item	2370142	et	3	main
saame	doc_399014257165_item	2370146	et	4	main
kollast	doc_399014257165_item	2370148	et	4	main
televisioonit	doc_399014257165_item	2370151	et	4	main
telekas	doc_399014257165_item	2370152	et	4	main
tõsieluprogramme	doc_399014257165_item	2370155	et	3	main
on	doc_399014257165_item	2370158	et	4	main
see	doc_399014257165_item	2370162	et	3	main
ka	doc_399014257165_item	2370169	et	3	main
hommiku	doc_399014257165_item	2370175	et	3	main
the	doc_399014257165_item	2370208	et	4	main
telefoonikõnesid	doc_399014257165_item	2370215	et	4	main
et	doc_399014257165_item	2370219	et	3	main
tahaks	doc_399014257165_item	2370222	et	3	main
tähentas	doc_399014257165_item	2370235	et	4	main
olnud	doc_399014257165_item	2370257	et	4	main
saladused	doc_399014257165_item	2370266	et	3	main
heas	doc_399014257165_item	2370273	et	3	main
kui	doc_399014257165_item	2370274	et	3	main
toimub	doc_399014257165_item	2370277	et	3	main
olnud	doc_399014257166_item	2370315	et	4	main
on	doc_399014257166_item	2370320	et	4	main
ilmselt	doc_399014257166_item	2370325	et	4	main
esialgu	doc_399014257166_item	2370335	et	3	main
esimesed	doc_399014257166_item	2370340	et	3	main
hakkasid	doc_399014257166_item	2370342	et	4	main
eestis	doc_399014257166_item	2370343	et	3	main
ei	doc_398961616083_item	2369849	et	4	main
nii	doc_398961616083_item	2369851	et	3	main
siis	doc_398961616083_item	2369854	et	3	main
tähendab	doc_398961616083_item	2369856	et	3	main
kõike	doc_398961616083_item	2369862	et	4	main
annab	doc_398961616083_item	2369864	et	3	main
ja	doc_398961616083_item	2369867	et	3	main
mis	doc_398961616083_item	2369868	et	4	main
tarbima	doc_398961616083_item	2369872	et	3	main
aga	doc_399014257165_item	2369887	et	3	main
kukkutada	doc_399014257165_item	2369894	et	4	main
ûhendriikidest	doc_399014257165_item	2369901	et	4	main
ajakirjanduse	doc_399014257165_item	2369916	et	3	main
kaks	doc_399014257165_item	2369918	et	3	main
carl	doc_399014257165_item	2369925	et	4	main
hakkasid	doc_399014257165_item	2369927	et	4	main
demokraadliku	doc_399014257165_item	2369931	et	4	main
partei	doc_399014257165_item	2369932	et	4	main
keskbüroosse	doc_399014257165_item	2369933	et	3	main
ise	doc_399014257165_item	2369940	et	4	main
1972	doc_399014257165_item	2369945	et	2	main
1974	doc_399014257165_item	2369949	et	2	main
1973	doc_399014257165_item	2369952	et	2	main
nixon	doc_399014257165_item	2369953	et	4	main
asepresidedi	doc_399014257165_item	2369965	et	4	main
ja	doc_399014257165_item	2369973	et	3	main
ise	doc_399014257165_item	2369974	et	4	main
olla	doc_399014257165_item	2369977	et	3	main
paljastas	doc_399014257165_item	2369987	et	3	main
miller	doc_399014257165_item	2369995	et	4	main
sest	doc_399014257165_item	2369998	et	4	main
watergate	doc_399014257165_item	2370025	et	4	main
peaministri	doc_399014257165_item	2370030	et	3	main
kohalt	doc_399014257165_item	2370031	et	4	main
aastal	doc_399014257165_item	2370032	et	3	main
päeva	doc_399014257165_item	2370036	et	4	main
soome	doc_399014257165_item	2370062	et	3	main
müü	doc_399014257165_item	2370072	et	4	main
ühendriikidele	doc_399014257165_item	2370075	et	3	main
kes	doc_399014257165_item	2370077	et	4	main
ma	doc_399014257165_item	2370081	et	3	main
et	doc_399014257165_item	2370089	et	3	main
on	doc_399014257165_item	2370091	et	4	main
maa	doc_399014257165_item	2370099	et	4	main
rahust	doc_399014257165_item	2370103	et	4	main
meie	doc_399014257165_item	2370112	et	4	main
veedeti	doc_399014257165_item	2370116	et	3	main
ühe	doc_399014257165_item	2370118	et	4	main
aastas	doc_399014257165_item	2370120	et	3	main
selle	doc_399014257165_item	2370122	et	4	main
pidi	doc_399014257165_item	2370128	et	4	main
tähte	doc_399014257165_item	2370143	et	4	main
ajakirjandust	doc_399014257165_item	2370149	et	3	main
ja	doc_399014257165_item	2370150	et	3	main
on	doc_399014257165_item	2370153	et	4	main
ja	doc_399014257165_item	2370160	et	3	main
sama	doc_399014257165_item	2370163	et	4	main
on	doc_399014257165_item	2370167	et	4	main
näha	doc_399014257165_item	2370168	et	3	main
saame	doc_399014257165_item	2370172	et	4	main
järgmise	doc_399014257165_item	2370174	et	3	main
siis	doc_399014257165_item	2370177	et	3	main
sun	doc_399014257165_item	2370209	et	4	main
charles	doc_399014257165_item	2370221	et	4	main
olla	doc_399014257165_item	2370223	et	3	main
siniverelised	doc_399014257165_item	2370238	et	4	main
sama	doc_399014257165_item	2370240	et	4	main
tobedad	doc_399014257165_item	2370241	et	3	main
nagu	doc_399014257165_item	2370242	et	3	main
tavalised	doc_399014257165_item	2370243	et	4	main
suguelundid	doc_399014257165_item	2370246	et	3	main
charles	doc_399014257165_item	2370260	et	4	main
internet	doc_399014257165_item	2370271	et	4	main
nii	doc_399014257165_item	2370272	et	3	main
kerge	doc_399014257166_item	2370316	et	4	main
bob	doc_399014257165_item	2369922	et	4	main
pealtkuulamisaparaadid	doc_399014257165_item	2369935	et	3	main
presidendini	doc_399014257165_item	2369941	et	4	main
ja	doc_399014257165_item	2369946	et	3	main
ma	doc_399014257165_item	2369956	et	3	main
ole	doc_399014257165_item	2369958	et	4	main
maha	doc_399014257165_item	2369962	et	4	main
nõuniku	doc_399014257165_item	2369966	et	3	main
libby	doc_399014257165_item	2369968	et	4	main
kurk	doc_399014257165_item	2369972	et	3	main
seotud	doc_399014257165_item	2369978	et	4	main
judith	doc_399014257165_item	2369981	et	4	main
et	doc_399014257165_item	2369999	et	3	main
ei	doc_399014257165_item	2370001	et	4	main
oma	doc_399014257165_item	2370003	et	4	main
informatsiooniallikat	doc_399014257165_item	2370004	et	3	main
kuid	doc_399014257165_item	2370005	et	4	main
kolm	doc_399014257165_item	2370006	et	3	main
kuud	doc_399014257165_item	2370007	et	4	main
vanglas	doc_399014257165_item	2370008	et	3	main
pehmendas	doc_399014257165_item	2370009	et	3	main
teda	doc_399014257165_item	2370010	et	4	main
ja	doc_399014257165_item	2370011	et	3	main
andis	doc_399014257165_item	2370013	et	3	main
ta	doc_399014257165_item	2370012	et	4	main
üles	doc_399014257165_item	2370014	et	3	main
oma	doc_399014257165_item	2370015	et	4	main
sügavad	doc_399014257165_item	2370016	et	4	main
kurgud	doc_399014257165_item	2370017	et	3	main
ja	doc_399014257165_item	2370018	et	3	main
vallandati	doc_399014257165_item	2370019	et	3	main
ajalehest	doc_399014257165_item	2370020	et	4	main
kuidas	doc_399014257165_item	2369929	et	3	main
oli	doc_399014257165_item	2369930	et	3	main
viisid	doc_399014257165_item	2369937	et	4	main
lõpude	doc_399014257165_item	2369938	et	4	main
uurimus	doc_399014257165_item	2369942	et	3	main
nixon	doc_399014257165_item	2369947	et	4	main
et	doc_399014257165_item	2369955	et	3	main
päid	doc_399014257165_item	2369960	et	3	main
sügav	doc_399014257165_item	2369971	et	4	main
asepresident	doc_399014257165_item	2369975	et	3	main
võib	doc_399014257165_item	2369976	et	3	main
new	doc_399014257165_item	2369984	et	4	main
york	doc_399014257165_item	2369985	et	4	main
ühe	doc_399014257165_item	2369989	et	4	main
suursaadiku	doc_399014257165_item	2369990	et	3	main
vanglas	doc_399014257165_item	2369997	et	3	main
avaldanud	doc_399014257165_item	2370002	et	4	main
oma	doc_399014257165_item	2370024	et	4	main
anneli	doc_399014257165_item	2370027	et	4	main
oli	doc_399014257165_item	2370044	et	3	main
saanud	doc_399014257165_item	2370045	et	4	main
kantseleist	doc_399014257165_item	2370048	et	4	main
eri	doc_399014257165_item	2370064	et	4	main
ja	doc_399014257165_item	2370069	et	3	main
et	doc_399014257165_item	2370070	et	3	main
soome	doc_399014257165_item	2370071	et	3	main
mu	doc_399014257165_item	2370084	et	3	main
elu	doc_399014257165_item	2370085	et	4	main
taibanud	doc_399014257165_item	2370087	et	4	main
liitub	doc_399014257165_item	2370100	et	3	main
uurivad	doc_399014257165_item	2370113	et	4	main
kuningaks	doc_399014257165_item	2370123	et	3	main
kuulata	doc_399014257165_item	2370131	et	4	main
iga	doc_399014257165_item	2370136	et	4	main
sellest	doc_399014257165_item	2370145	et	4	main
tänata	doc_399014257165_item	2370147	et	3	main
igasuguseid	doc_399014257165_item	2370154	et	3	main
muid	doc_399014257165_item	2370161	et	4	main
kuulsaks	doc_399014257165_item	2370164	et	4	main
saamise	doc_399014257165_item	2370165	et	4	main
himu	doc_399014257165_item	2370166	et	4	main
nendes	doc_399014257165_item	2370171	et	4	main
lugeda	doc_399014257165_item	2370173	et	3	main
mitteteevad	doc_399014257165_item	2370206	et	4	main
pealt	doc_399014257165_item	2370212	et	4	main
charlesi	doc_399014257165_item	2370214	et	4	main
hing	doc_399014257165_item	2370228	et	3	main
mainimast	doc_399014257165_item	2370230	et	3	main
teadmine	doc_399014257165_item	2370234	et	4	main
on	doc_399014257165_item	2370239	et	4	main
mõistuse	doc_399014257165_item	2370248	et	3	main
mata-hari	doc_399014257165_item	2370258	et	4	main
andnud	doc_399014257165_item	2370262	et	4	main
üle	doc_399014257165_item	2370263	et	3	main
riigi	doc_399014257165_item	2370265	et	3	main
üks	doc_399014257165_item	2370267	et	3	main
võimsam	doc_399014257165_item	2370268	et	4	main
meedia	doc_399014257165_item	2370269	et	4	main
see	doc_399014257165_item	2370276	et	3	main
erinevaid	doc_399014257166_item	2370309	et	4	main
meediatüüpe	doc_399014257166_item	2370310	et	3	main
paar	doc_399014257166_item	2370311	et	3	main
oleks	doc_399014257166_item	2370314	et	3	main
et	doc_399014257166_item	2370318	et	3	main
kõige	doc_399014257166_item	2370321	et	4	main
meediavahend	doc_399014257166_item	2370323	et	3	main
ikkagi	doc_399014257166_item	2370332	et	4	main
lugu	doc_399014257166_item	2370337	et	4	main
televisioonisaatet	doc_399014257166_item	2370341	et	4	main
kui	doc_399014257166_item	2370348	et	3	main
huvitavamatelt	doc_399014257166_item	2370358	et	4	main
filmid	doc_399014257166_item	2370361	et	4	main
ja	doc_399014257166_item	2370362	et	3	main
igasugused	doc_399014257166_item	2370363	et	3	main
võtta	doc_399014257166_item	2370366	et	3	main
näiteks	doc_399014257166_item	2370368	et	4	main
kaklus	doc_399014257166_item	2370371	et	3	main
seiklusfilmi	doc_399014257166_item	2370373	et	4	main
üsna	doc_399014257166_item	2370378	et	3	main
sarnased	doc_399014257166_item	2370379	et	4	main
tuttavad	doc_399014257166_item	2370406	et	4	main
on	doc_399014257165_item	2370022	et	4	main
skandaal	doc_399014257165_item	2370026	et	3	main
jäätteenmäki	doc_399014257165_item	2370028	et	4	main
lahkus	doc_399014257165_item	2370029	et	4	main
69	doc_399014257165_item	2370035	et	2	main
presidendi	doc_399014257165_item	2370047	et	4	main
käsidlesid	doc_399014257165_item	2370052	et	4	main
toonase	doc_399014257165_item	2370053	et	3	main
peaministri	doc_399014257165_item	2370054	et	3	main
paavo	doc_399014257165_item	2370055	et	4	main
lipponeni	doc_399014257165_item	2370056	et	4	main
lubadusi	doc_399014257165_item	2370057	et	3	main
george	doc_399014257165_item	2370058	et	4	main
2004	doc_399014257165_item	2370033	et	2	main
nimetamise	doc_399014257165_item	2370037	et	4	main
ta	doc_399014257165_item	2370038	et	4	main
kasutas	doc_399014257165_item	2370039	et	3	main
valimiskampaanias	doc_399014257165_item	2370040	et	3	main
salajasi	doc_399014257165_item	2370041	et	3	main
pabereid	doc_399014257165_item	2370042	et	3	main
kätte	doc_399014257165_item	2370046	et	4	main
martti	doc_399014257165_item	2370049	et	4	main
paberid	doc_399014257165_item	2370051	et	3	main
et	doc_399014257165_item	2370061	et	3	main
graanate	doc_399014257165_item	2370074	et	4	main
maale	doc_399014257165_item	2370076	et	4	main
oli	doc_399014257165_item	2370078	et	3	main
sõjas	doc_399014257165_item	2370079	et	3	main
aja	doc_399014257165_item	2370086	et	4	main
valesti	doc_399014257165_item	2370088	et	3	main
kus	doc_399014257165_item	2370094	et	3	main
näiteks	doc_399014257165_item	2370097	et	4	main
sõjast	doc_399014257165_item	2370101	et	3	main
on	doc_399014257165_item	2370106	et	4	main
täidesaadja	doc_399014257165_item	2370109	et	4	main
kus	doc_399014257165_item	2370110	et	3	main
olid	doc_399014257165_item	2370111	et	4	main
maade	doc_399014257165_item	2370065	et	3	main
iraaki	doc_399014257165_item	2370067	et	4	main
küsimuses	doc_399014257165_item	2370068	et	4	main
kogu	doc_399014257165_item	2370083	et	4	main
soome	doc_399014257165_item	2370090	et	3	main
demokraatlik	doc_399014257165_item	2370092	et	3	main
riik	doc_399014257165_item	2370093	et	3	main
otsustab	doc_399014257165_item	2370096	et	3	main
kuhu	doc_399014257165_item	2370098	et	3	main
valitsus	doc_399014257165_item	2370105	et	4	main
tegev	doc_399014257165_item	2370107	et	4	main
organ	doc_399014257165_item	2370108	et	3	main
keskajal	doc_399014257165_item	2370115	et	3	main
karnevaale	doc_399014257165_item	2370117	et	4	main
korra	doc_399014257165_item	2370119	et	4	main
valiti	doc_399014257165_item	2370124	et	3	main
narr	doc_399014257165_item	2370125	et	3	main
tema	doc_399014257165_item	2370129	et	4	main
sõna	doc_399014257165_item	2370130	et	4	main
karnevaale	doc_399014257165_item	2370135	et	4	main
selliseid	doc_399014257165_item	2370141	et	4	main
inglismaal	doc_399014257165_item	2370207	et	4	main
kuulas	doc_399014257165_item	2370211	et	3	main
prints	doc_399014257165_item	2370213	et	3	main
siis	doc_399014257165_item	2370217	et	3	main
kõikide	doc_399014257165_item	2370126	et	4	main
nüüd	doc_399014257165_item	2370132	et	4	main
päev	doc_399014257165_item	2370137	et	3	main
meedia	doc_399014257165_item	2370138	et	4	main
loob	doc_399014257165_item	2370139	et	3	main
tähte	doc_399014257165_item	2370140	et	4	main
ja	doc_399014257165_item	2370144	et	3	main
on	doc_399014257165_item	2370156	et	4	main
robinsonid	doc_399014257165_item	2370157	et	4	main
idolsid	doc_399014257165_item	2370159	et	4	main
salaarmsates	doc_399014257165_item	2370170	et	3	main
iltasanomitest	doc_399014257165_item	2370176	et	4	main
see	doc_399014257165_item	2370178	et	3	main
saladus	doc_399014257165_item	2370179	et	3	main
on	doc_399014257165_item	2370180	et	4	main
üht	doc_399014257165_item	2370181	et	3	main
pikk	doc_399014257165_item	2370182	et	4	main
nagu	doc_399014257165_item	2370183	et	3	main
ise	doc_399014257165_item	2370184	et	4	main
tegu	doc_399014257165_item	2370185	et	4	main
kollane	doc_399014257165_item	2370186	et	4	main
ajakirjandus	doc_399014257165_item	2370187	et	3	main
ei	doc_399014257165_item	2370188	et	4	main
karda	doc_399014257165_item	2370189	et	4	main
midagi	doc_399014257165_item	2370190	et	4	main
vanheneid	doc_399014257165_item	2370191	et	4	main
need	doc_399014257165_item	2370192	et	3	main
maksvad	doc_399014257165_item	2370193	et	4	main
raha	doc_399014257165_item	2370194	et	4	main
sellele	doc_399014257165_item	2370195	et	4	main
kes	doc_399014257165_item	2370196	et	4	main
annavad	doc_399014257165_item	2370197	et	3	main
teada	doc_399014257165_item	2370198	et	3	main
kes	doc_399014257165_item	2370199	et	4	main
kus	doc_399014257165_item	2370200	et	3	main
mida	doc_399014257165_item	2370201	et	4	main
millal	doc_399014257165_item	2370202	et	3	main
kellega	doc_399014257165_item	2370203	et	3	main
teevad	doc_399014257165_item	2370204	et	3	main
või	doc_399014257165_item	2370205	et	4	main
leht	doc_399014257165_item	2370210	et	3	main
ja	doc_399014257165_item	2370216	et	3	main
kirjutas	doc_399014257165_item	2370218	et	3	main
prints	doc_399014257165_item	2370220	et	3	main
camilla	doc_399014257165_item	2370225	et	4	main
väikekodanlik	doc_399014257165_item	2370227	et	3	main
keeldub	doc_399014257165_item	2370229	et	3	main
kus	doc_399014257165_item	2370231	et	3	main
mida	doc_399014257165_item	2370232	et	4	main
ainult	doc_399014257165_item	2370236	et	4	main
et	doc_399014257165_item	2370237	et	3	main
kui	doc_399014257165_item	2370245	et	3	main
asi	doc_399014257165_item	2370250	et	4	main
oleks	doc_399014257165_item	2370251	et	3	main
olnud	doc_399014257165_item	2370252	et	4	main
teine	doc_399014257165_item	2370253	et	3	main
kui	doc_399014257165_item	2370254	et	3	main
camilla	doc_399014257165_item	2370255	et	4	main
oleks	doc_399014257165_item	2370256	et	3	main
oleks	doc_399014257165_item	2370261	et	3	main
kõige	doc_399014257165_item	2370264	et	4	main
halvas	doc_399014257165_item	2370275	et	4	main
aastat	doc_399014257166_item	2370312	et	3	main
tagasi	doc_399014257166_item	2370313	et	3	main
televiisor	doc_399014257166_item	2370319	et	3	main
nüüd	doc_399014257166_item	2370326	et	4	main
võimsamaks	doc_399014257166_item	2370328	et	4	main
meedia	doc_399014257166_item	2370329	et	4	main
vahendiks	doc_399014257166_item	2370330	et	3	main
on	doc_399014257166_item	2370331	et	4	main
internet	doc_399014257166_item	2370333	et	4	main
on	doc_399014257166_item	2370339	et	4	main
juba	doc_399014257166_item	2370345	et	3	main
tunduvad	doc_399014257166_item	2370355	et	4	main
nad	doc_399014257166_item	2370356	et	3	main
palju	doc_399014257166_item	2370357	et	4	main
kümme	doc_399014257166_item	2370369	et	3	main
väikseid	doc_399014257166_item	2370383	et	4	main
nagu	doc_399014257166_item	2370385	et	3	main
ümbrus	doc_399014257166_item	2370389	et	3	main
on	doc_399014257166_item	2370403	et	4	main
tavaliselt	doc_399014257166_item	2370404	et	4	main
hollywood	doc_399014257166_item	2370407	et	4	main
õhtul	doc_399014257166_item	2370421	et	3	main
muud	doc_399014257166_item	2370423	et	4	main
siis	doc_399014257166_item	2370426	et	3	main
võib	doc_399014257166_item	2370427	et	3	main
muidugi	doc_399014257166_item	2370428	et	4	main
vahtida	doc_399014257166_item	2370438	et	3	main
erakordseid	doc_399014257166_item	2370440	et	3	main
filme	doc_399014257166_item	2370443	et	3	main
nagu	doc_399014257166_item	2370447	et	3	main
nii	doc_399014257166_item	2370448	et	3	main
arvata	doc_399014257166_item	2370449	et	4	main
see	doc_399014257166_item	2370450	et	3	main
kes	doc_399014257166_item	2370451	et	4	main
peksa	doc_399014257166_item	2370455	et	4	main
ma	doc_399014257166_item	2370459	et	3	main
tohi	doc_399014257166_item	2370476	et	4	main
luges	doc_399014257166_item	2370484	et	3	main
hirmus	doc_399014257166_item	2370490	et	4	main
ja	doc_399014257166_item	2370492	et	3	main
professor	doc_399014257166_item	2370494	et	3	main
ju	doc_399014257166_item	2370522	et	3	main
selliseid	doc_399014257166_item	2370525	et	4	main
asju	doc_399014257166_item	2370526	et	3	main
mida	doc_399014257166_item	2370527	et	4	main
chaplini	doc_399014257166_item	2370536	et	4	main
filmid	doc_399014257166_item	2370537	et	4	main
tehtud	doc_399014257166_item	2370548	et	4	main
ainult	doc_399014257166_item	2370559	et	4	main
seintele	doc_399014257166_item	2370566	et	3	main
ei	doc_399014257166_item	2370568	et	4	main
tarantino	doc_399014257166_item	2370575	et	4	main
kus	doc_399014257166_item	2370577	et	3	main
kõige	doc_399014257166_item	2370581	et	4	main
on	doc_399014257166_item	2370586	et	4	main
selliseid	doc_399014257166_item	2370594	et	4	main
filme	doc_399014257166_item	2370595	et	3	main
mõtlevad	doc_399014257166_item	2370598	et	4	main
et	doc_399014257166_item	2370599	et	3	main
nii	doc_399014257166_item	2370600	et	3	main
tampax	doc_399014257165_item	2370224	et	4	main
mu	doc_399014257165_item	2370226	et	3	main
selle	doc_399014257165_item	2370233	et	4	main
surevad	doc_399014257165_item	2370244	et	4	main
võtavad	doc_399014257165_item	2370247	et	3	main
koha	doc_399014257165_item	2370249	et	4	main
ja	doc_399014257165_item	2370259	et	3	main
on	doc_399014257165_item	2370270	et	4	main
reaalajas	doc_399014257165_item	2370278	et	3	main
kõik	doc_399014257165_item	2370279	et	4	main
mis	doc_399014257165_item	2370280	et	4	main
seal	doc_399014257165_item	2370281	et	4	main
on	doc_399014257165_item	2370282	et	4	main
on	doc_399014257165_item	2370283	et	4	main
kontrollimatu	doc_399014257165_item	2370284	et	4	main
asjad	doc_399014257165_item	2370285	et	3	main
on	doc_399014257165_item	2370286	et	4	main
õige	doc_399014257165_item	2370287	et	4	main
või	doc_399014257165_item	2370288	et	4	main
valesti	doc_399014257165_item	2370289	et	3	main
aga	doc_399014257165_item	2370290	et	3	main
ükskõik	doc_399014257165_item	2370291	et	3	main
need	doc_399014257165_item	2370292	et	3	main
säilivad	doc_399014257165_item	2370293	et	4	main
internetis	doc_399014257165_item	2370294	et	4	main
alati	doc_399014257165_item	2370295	et	4	main
ja	doc_399014257165_item	2370296	et	3	main
igavesti	doc_399014257165_item	2370297	et	4	main
aamen	doc_399014257165_item	2370298	et	4	main
aga	doc_399014257165_item	2370299	et	3	main
see	doc_399014257165_item	2370300	et	3	main
ongi	doc_399014257165_item	2370301	et	4	main
teine	doc_399014257165_item	2370302	et	3	main
lugu	doc_399014257165_item	2370303	et	4	main
essee	doc_399014257166_item	2370304	et	4	main
meedia	doc_399014257166_item	2370305	et	4	main
on	doc_399014257166_item	2370306	et	4	main
olemas	doc_399014257166_item	2370307	et	4	main
mitmeid	doc_399014257166_item	2370308	et	4	main
öelda	doc_399014257166_item	2370317	et	4	main
võimsaim	doc_399014257166_item	2370322	et	4	main
aga	doc_399014257166_item	2370324	et	3	main
vaatame	doc_399014257166_item	2370334	et	3	main
tulema	doc_399014257166_item	2370344	et	4	main
seriaalid	doc_399014257166_item	2370364	et	3	main
kui	doc_399014257166_item	2370365	et	3	main
või	doc_399014257166_item	2370372	et	4	main
on	doc_399014257166_item	2370374	et	4	main
nad	doc_399014257166_item	2370375	et	3	main
üksteisele	doc_399014257166_item	2370376	et	3	main
kõik	doc_399014257166_item	2370377	et	4	main
on	doc_399014257166_item	2370381	et	4	main
erinevusi	doc_399014257166_item	2370384	et	4	main
näitlejad	doc_399014257166_item	2370386	et	4	main
neile	doc_399014257166_item	2370391	et	4	main
on	doc_399014257166_item	2370393	et	4	main
see	doc_399014257166_item	2370394	et	3	main
et	doc_399014257166_item	2370395	et	3	main
nende	doc_399014257166_item	2370396	et	4	main
suuri	doc_399014257166_item	2370400	et	3	main
rahasi	doc_399014257166_item	2370401	et	4	main
kümne	doc_399014257166_item	2370430	et	4	main
euro	doc_399014257166_item	2370431	et	4	main
ameerika	doc_399014257166_item	2370439	et	3	main
ja	doc_399014257166_item	2370441	et	3	main
tavaliselt	doc_399014257166_item	2370444	et	4	main
on	doc_399014257166_item	2370445	et	4	main
lõpp	doc_399014257166_item	2370446	et	3	main
paha	doc_399014257166_item	2370453	et	4	main
ja	doc_399014257166_item	2370456	et	3	main
et	doc_399014257166_item	2370464	et	3	main
kes	doc_399014257166_item	2370470	et	4	main
tohib	doc_399014257166_item	2370472	et	3	main
rääkis	doc_399014257166_item	2370481	et	3	main
tema	doc_399014257166_item	2370483	et	4	main
muinasjuttu	doc_399014257166_item	2370487	et	4	main
oli	doc_399014257166_item	2370489	et	3	main
kaklus	doc_399014257166_item	2370491	et	3	main
peksmine	doc_399014257166_item	2370493	et	4	main
nüüd	doc_399014257166_item	2370528	et	4	main
midagi	doc_399014257166_item	2370542	et	4	main
ja	doc_399014257166_item	2370543	et	3	main
kui	doc_399014257166_item	2370550	et	3	main
ja	doc_399014257166_item	2370567	et	3	main
tea	doc_399014257166_item	2370569	et	4	main
kuhu	doc_399014257166_item	2370570	et	3	main
kaklemine	doc_399014257166_item	2370578	et	4	main
filmis	doc_399014257166_item	2370584	et	4	main
lapsed	doc_399014257166_item	2370592	et	3	main
vaatavad	doc_399014257166_item	2370593	et	4	main
kõik	doc_399014257166_item	2370602	et	4	main
on	doc_399014257166_item	2370612	et	4	main
paar	doc_399014257166_item	2370616	et	3	main
näiteks	doc_399014257166_item	2370619	et	4	main
ma	doc_399014257166_item	2370628	et	3	main
et	doc_399014257166_item	2370630	et	3	main
pärast	doc_399014257166_item	2370633	et	4	main
ilusad	doc_399014257166_item	2370651	et	3	main
jooksnud	doc_399014257166_item	2370653	et	4	main
et	doc_399014257166_item	2370658	et	3	main
üks	doc_399014257166_item	2370661	et	3	main
kestab	doc_399014257166_item	2370663	et	4	main
loba	doc_399014257166_item	2370674	et	4	main
kui	doc_399014257166_item	2370675	et	3	main
ainult	doc_399014257166_item	2370679	et	4	main
minutit	doc_399014257166_item	2370683	et	3	main
ma	doc_399014257166_item	2370685	et	3	main
sellele	doc_399014257166_item	2370692	et	4	main
mis	doc_399014257166_item	2370693	et	4	main
nii	doc_399014257166_item	2370721	et	3	main
mõjukad	doc_399014257166_item	2370731	et	3	main
meediavahendid	doc_399014257166_item	2370732	et	3	main
päeval	doc_399014257166_item	2370734	et	3	main
kahjuks	doc_399014257166_item	2370735	et	4	main
tehtud	doc_399014257166_item	2370747	et	4	main
hea	doc_399014257166_item	2370756	et	4	main
midagi	doc_399014257166_item	2370760	et	4	main
juhtub	doc_399014257166_item	2370762	et	3	main
siis	doc_399014257166_item	2370764	et	3	main
päev	doc_399014257166_item	2370773	et	3	main
tähtsad	doc_399014257166_item	2370776	et	3	main
kõige	doc_399014257166_item	2370327	et	4	main
milline	doc_399014257166_item	2370336	et	3	main
televiisoriga	doc_399014257166_item	2370338	et	3	main
viiekümnendatel	doc_399014257166_item	2370346	et	3	main
aastatel	doc_399014257166_item	2370347	et	4	main
neid	doc_399014257166_item	2370349	et	4	main
või	doc_399014257166_item	2370352	et	4	main
filme	doc_399014257166_item	2370353	et	3	main
vaadata	doc_399014257166_item	2370354	et	4	main
ameerika	doc_399014257166_item	2370370	et	3	main
mingisuguseid	doc_399014257166_item	2370382	et	3	main
ja	doc_399014257166_item	2370388	et	3	main
peale	doc_399014257166_item	2370397	et	4	main
kasutatkse	doc_399014257166_item	2370398	et	4	main
kõigile	doc_399014257166_item	2370405	et	4	main
ja	doc_399014257166_item	2370409	et	3	main
mida	doc_399014257166_item	2370410	et	4	main
rohkem	doc_399014257166_item	2370411	et	4	main
püss	doc_399014257166_item	2370412	et	3	main
paugub	doc_399014257166_item	2370413	et	3	main
seda	doc_399014257166_item	2370414	et	3	main
parem	doc_399014257166_item	2370415	et	4	main
film	doc_399014257166_item	2370416	et	3	main
on	doc_399014257166_item	2370417	et	4	main
njah	doc_399014257166_item	2370418	et	4	main
kui	doc_399014257166_item	2370419	et	3	main
reede	doc_399014257166_item	2370420	et	4	main
teha	doc_399014257166_item	2370424	et	3	main
huvitavaid	doc_399014257166_item	2370442	et	4	main
vanglasse	doc_399014257166_item	2370458	et	4	main
seda	doc_399014257166_item	2370463	et	3	main
sellistele	doc_399014257166_item	2370465	et	4	main
filmidele	doc_399014257166_item	2370467	et	3	main
vaadata	doc_399014257166_item	2370477	et	4	main
ühel	doc_399014257166_item	2370478	et	3	main
kursusel	doc_399014257166_item	2370479	et	3	main
professor	doc_399014257166_item	2370480	et	3	main
lapsele	doc_399014257166_item	2370486	et	4	main
lugu	doc_399014257166_item	2370499	et	4	main
varajaseid	doc_399014257166_item	2370350	et	4	main
saateid	doc_399014257166_item	2370351	et	3	main
kui	doc_399014257166_item	2370359	et	3	main
praegused	doc_399014257166_item	2370360	et	3	main
suvaliselt	doc_399014257166_item	2370367	et	4	main
muidugi	doc_399014257166_item	2370380	et	4	main
nimed	doc_399014257166_item	2370387	et	3	main
ühist	doc_399014257166_item	2370390	et	3	main
jällegi	doc_399014257166_item	2370392	et	4	main
väga	doc_399014257166_item	2370399	et	3	main
näitlejad	doc_399014257166_item	2370402	et	4	main
midagi	doc_399014257166_item	2370422	et	4	main
pole	doc_399014257166_item	2370425	et	3	main
minna	doc_399014257166_item	2370429	et	3	main
kinno	doc_399014257166_item	2370433	et	3	main
oli	doc_399014257166_item	2370452	et	3	main
ei	doc_399014257166_item	2370460	et	4	main
imesta	doc_399014257166_item	2370461	et	4	main
ültse	doc_399014257166_item	2370462	et	4	main
aastavanuseid	doc_399014257166_item	2370469	et	4	main
seda	doc_399014257166_item	2370471	et	3	main
kes	doc_399014257166_item	2370474	et	4	main
ei	doc_399014257166_item	2370475	et	4	main
enda	doc_399014257166_item	2370485	et	4	main
milles	doc_399014257166_item	2370488	et	3	main
ise	doc_399014257166_item	2370495	et	4	main
milline	doc_399014257166_item	2370497	et	3	main
muinasjutt	doc_399014257166_item	2370501	et	3	main
näidatakse	doc_399014257166_item	2370529	et	3	main
kus	doc_399014257166_item	2370538	et	3	main
midagi	doc_399014257166_item	2370544	et	4	main
naljakas	doc_399014257166_item	2370560	et	4	main
mitte	doc_399014257166_item	2370561	et	3	main
lendas	doc_399014257166_item	2370565	et	3	main
veel	doc_399014257166_item	2370571	et	4	main
nüüd	doc_399014257166_item	2370572	et	4	main
ongi	doc_399014257166_item	2370579	et	4	main
sellest	doc_399014257166_item	2370585	et	4	main
palju	doc_399014257166_item	2370587	et	4	main
kas	doc_399014257166_item	2370596	et	3	main
probleemid	doc_399014257166_item	2370603	et	3	main
muidugi	doc_399014257166_item	2370613	et	4	main
sõna	doc_399014257166_item	2370617	et	4	main
vapratest	doc_399014257166_item	2370620	et	3	main
ja	doc_399014257166_item	2370621	et	3	main
tunnevad	doc_399014257166_item	2370624	et	3	main
seebikat	doc_399014257166_item	2370626	et	4	main
seebikad	doc_399014257166_item	2370641	et	4	main
kaua	doc_399014257166_item	2370648	et	3	main
aga	doc_399014257166_item	2370654	et	3	main
ma	doc_399014257166_item	2370656	et	3	main
ja	doc_399014257166_item	2370667	et	3	main
seda	doc_399014257166_item	2370676	et	3	main
40	doc_399014257166_item	2370682	et	2	main
et	doc_399014257166_item	2370687	et	3	main
üsna	doc_399014257166_item	2370689	et	3	main
vaikselt	doc_399014257166_item	2370738	et	4	main
lehte	doc_399014257166_item	2370748	et	4	main
ja	doc_399014257166_item	2370750	et	3	main
internetiga	doc_399014257166_item	2370753	et	4	main
see	doc_399014257166_item	2370755	et	3	main
saab	doc_399014257166_item	2370765	et	3	main
sealt	doc_399014257166_item	2370768	et	4	main
nende	doc_399014257166_item	2370778	et	4	main
vaadata	doc_399014257166_item	2370815	et	4	main
igasuguseid	doc_399014257166_item	2370816	et	3	main
vaatamas	doc_399014257166_item	2370821	et	3	main
nii	doc_399014257166_item	2370823	et	3	main
päeval	doc_399014257166_item	2370829	et	3	main
ilmselt	doc_399014257166_item	2370830	et	4	main
võmalik	doc_399014257166_item	2370831	et	4	main
oma	doc_399014257166_item	2370832	et	4	main
elu	doc_399014257166_item	2370833	et	4	main
elada	doc_399014257166_item	2370834	et	3	main
minemata	doc_399014257166_item	2370835	et	4	main
keegi	doc_399014257166_item	2370842	et	4	main
seda	doc_399014257166_item	2370843	et	3	main
prooviks	doc_399014257166_item	2370844	et	4	main
see	doc_399014257166_item	2370856	et	3	main
sangarid	doc_399014257166_item	2370408	et	3	main
eest	doc_399014257166_item	2370432	et	4	main
istuma	doc_399014257166_item	2370434	et	3	main
oma	doc_399014257166_item	2370435	et	4	main
kommipakkiga	doc_399014257166_item	2370436	et	4	main
ja	doc_399014257166_item	2370437	et	3	main
saab	doc_399014257166_item	2370454	et	3	main
läheb	doc_399014257166_item	2370457	et	3	main
ameerika	doc_399014257166_item	2370466	et	3	main
soovitatakse	doc_399014257166_item	2370468	et	3	main
ja	doc_399014257166_item	2370473	et	3	main
et	doc_399014257166_item	2370482	et	3	main
mõtles	doc_399014257166_item	2370496	et	3	main
hirmus	doc_399014257166_item	2370498	et	4	main
see	doc_399014257166_item	2370500	et	3	main
oli	doc_399014257166_item	2370502	et	3	main
aga	doc_399014257166_item	2370503	et	3	main
tema	doc_399014257166_item	2370504	et	4	main
laps	doc_399014257166_item	2370505	et	4	main
ei	doc_399014257166_item	2370506	et	4	main
seda	doc_399014257166_item	2370508	et	3	main
tähelegi	doc_399014257166_item	2370509	et	3	main
pannud	doc_399014257166_item	2370507	et	4	main
vaid	doc_399014257166_item	2370510	et	3	main
see	doc_399014257166_item	2370511	et	3	main
nagu	doc_399014257166_item	2370512	et	3	main
oli	doc_399014257166_item	2370513	et	3	main
jaoks	doc_399014257166_item	2370515	et	4	main
lapse	doc_399014257166_item	2370514	et	4	main
üsna	doc_399014257166_item	2370516	et	3	main
normaalne	doc_399014257166_item	2370517	et	3	main
asi	doc_399014257166_item	2370518	et	4	main
vanasti	doc_399014257166_item	2370519	et	3	main
tõesti	doc_399014257166_item	2370520	et	3	main
sellised	doc_399014257166_item	2370533	et	4	main
vanad	doc_399014257166_item	2370534	et	3	main
charlie	doc_399014257166_item	2370535	et	4	main
keegi	doc_399014257166_item	2370539	et	4	main
ei	doc_399014257166_item	2370540	et	4	main
paha	doc_399014257166_item	2370545	et	4	main
põhimõtteliselt	doc_399014257166_item	2370546	et	4	main
kellelegi	doc_399014257166_item	2370549	et	4	main
selline	doc_399014257166_item	2370562	et	4	main
kus	doc_399014257166_item	2370563	et	3	main
veri	doc_399014257166_item	2370564	et	3	main
on	doc_399014257166_item	2370573	et	4	main
igasugused	doc_399014257166_item	2370574	et	3	main
see	doc_399014257166_item	2370580	et	3	main
asi	doc_399014257166_item	2370583	et	4	main
räägitud	doc_399014257166_item	2370588	et	4	main
et	doc_399014257166_item	2370589	et	3	main
kui	doc_399014257166_item	2370590	et	3	main
väiksed	doc_399014257166_item	2370591	et	4	main
on	doc_399014257166_item	2370606	et	4	main
huvitavad	doc_399014257166_item	2370610	et	4	main
veel	doc_399014257166_item	2370636	et	4	main
teiset	doc_399014257166_item	2370639	et	4	main
ja	doc_399014257166_item	2370650	et	3	main
seda	doc_399014257166_item	2370655	et	3	main
tean	doc_399014257166_item	2370657	et	3	main
umbes	doc_399014257166_item	2370664	et	4	main
aja	doc_399014257166_item	2370669	et	4	main
väga	doc_399014257166_item	2370672	et	3	main
palju	doc_399014257166_item	2370673	et	4	main
telekas	doc_399014257166_item	2370521	et	4	main
ei	doc_399014257166_item	2370523	et	4	main
näidatud	doc_399014257166_item	2370524	et	4	main
mulle	doc_399014257166_item	2370530	et	4	main
tulevad	doc_399014257166_item	2370531	et	4	main
meelde	doc_399014257166_item	2370532	et	3	main
rääkinud	doc_399014257166_item	2370541	et	4	main
ei	doc_399014257166_item	2370547	et	4	main
nenedes	doc_399014257166_item	2370551	et	4	main
vanades	doc_399014257166_item	2370552	et	3	main
filmides	doc_399014257166_item	2370553	et	4	main
tehti	doc_399014257166_item	2370554	et	3	main
paha	doc_399014257166_item	2370555	et	4	main
siis	doc_399014257166_item	2370556	et	3	main
se	doc_399014257166_item	2370557	et	4	main
oli	doc_399014257166_item	2370558	et	3	main
filmid	doc_399014257166_item	2370576	et	4	main
olulisem	doc_399014257166_item	2370582	et	4	main
nad	doc_399014257166_item	2370597	et	3	main
peabgi	doc_399014257166_item	2370601	et	4	main
veel	doc_399014257166_item	2370607	et	4	main
eriti	doc_399014257166_item	2370609	et	3	main
seriaalid	doc_399014257166_item	2370611	et	3	main
lahendama	doc_399014257166_item	2370604	et	3	main
siis	doc_399014257166_item	2370605	et	3	main
seriaalid	doc_399014257166_item	2370608	et	3	main
ameerika	doc_399014257166_item	2370614	et	3	main
seriaalid	doc_399014257166_item	2370615	et	3	main
siis	doc_399014257166_item	2370618	et	3	main
ilusatest	doc_399014257166_item	2370622	et	3	main
kõik	doc_399014257166_item	2370623	et	4	main
seda	doc_399014257166_item	2370625	et	3	main
ja	doc_399014257166_item	2370627	et	3	main
arvan	doc_399014257166_item	2370629	et	3	main
just	doc_399014257166_item	2370631	et	3	main
selle	doc_399014257166_item	2370632	et	4	main
naljakam	doc_399014257166_item	2370637	et	4	main
kui	doc_399014257166_item	2370638	et	3	main
ameerika	doc_399014257166_item	2370640	et	3	main
ausalt	doc_399014257166_item	2370643	et	4	main
vaprad	doc_399014257166_item	2370649	et	3	main
kaua	doc_399014257166_item	2370660	et	3	main
osa	doc_399014257166_item	2370662	et	4	main
minutit	doc_399014257166_item	2370666	et	3	main
vaatakas	doc_399014257166_item	2370678	et	4	main
aastas	doc_399014257166_item	2370681	et	3	main
pihta	doc_399014257166_item	2370691	et	4	main
ta	doc_399014257166_item	2370634	et	4	main
ongi	doc_399014257166_item	2370635	et	4	main
ma	doc_399014257166_item	2370642	et	3	main
öeldes	doc_399014257166_item	2370644	et	3	main
ei	doc_399014257166_item	2370645	et	4	main
teagi	doc_399014257166_item	2370646	et	4	main
kui	doc_399014257166_item	2370647	et	3	main
on	doc_399014257166_item	2370652	et	4	main
liiga	doc_399014257166_item	2370659	et	4	main
40	doc_399014257166_item	2370665	et	2	main
selle	doc_399014257166_item	2370668	et	4	main
sees	doc_399014257166_item	2370670	et	4	main
ajatakse	doc_399014257166_item	2370671	et	3	main
korra	doc_399014257166_item	2370680	et	4	main
kindel	doc_399014257166_item	2370686	et	3	main
saaks	doc_399014257166_item	2370688	et	3	main
kiiresti	doc_399014257166_item	2370690	et	3	main
seal	doc_399014257166_item	2370694	et	4	main
juhtunud	doc_399014257166_item	2370695	et	4	main
on	doc_399014257166_item	2370696	et	4	main
ja	doc_399014257166_item	2370697	et	3	main
millest	doc_399014257166_item	2370698	et	3	main
räägitakse	doc_399014257166_item	2370699	et	3	main
no	doc_399014257166_item	2370700	et	3	main
muidugi	doc_399014257166_item	2370701	et	4	main
on	doc_399014257166_item	2370702	et	4	main
ka	doc_399014257166_item	2370703	et	3	main
mõned	doc_399014257166_item	2370704	et	3	main
eesti	doc_399014257166_item	2370705	et	4	main
ja	doc_399014257166_item	2370706	et	3	main
seebikad	doc_399014257166_item	2370708	et	4	main
soome	doc_399014257166_item	2370707	et	3	main
sellised	doc_399014257166_item	2370709	et	4	main
jamad	doc_399014257166_item	2370710	et	4	main
aga	doc_399014257166_item	2370711	et	3	main
kõige	doc_399014257166_item	2370712	et	4	main
kergem	doc_399014257166_item	2370713	et	4	main
on	doc_399014257166_item	2370714	et	4	main
alati	doc_399014257166_item	2370715	et	4	main
süüdistada	doc_399014257166_item	2370716	et	3	main
ameerikat	doc_399014257166_item	2370717	et	4	main
essee	doc_399014257166_item	2370718	et	4	main
käsitleb	doc_399014257166_item	2370719	et	3	main
meediat	doc_399014257166_item	2370720	et	3	main
nüüd	doc_399014257166_item	2370723	et	4	main
ka	doc_399014257166_item	2370725	et	3	main
teistest	doc_399014257166_item	2370726	et	4	main
meediavahenditest	doc_399014257166_item	2370727	et	3	main
ajalehed	doc_399014257166_item	2370728	et	3	main
on	doc_399014257166_item	2370729	et	4	main
täna	doc_399014257166_item	2370733	et	4	main
muutuma	doc_399014257166_item	2370739	et	4	main
lugeda	doc_399014257166_item	2370749	et	3	main
asi	doc_399014257166_item	2370757	et	4	main
kui	doc_399014257166_item	2370759	et	3	main
seebikat	doc_399014257166_item	2370677	et	4	main
olen	doc_399014257166_item	2370684	et	3	main
et	doc_399014257166_item	2370722	et	3	main
veel	doc_399014257166_item	2370724	et	4	main
lehed	doc_399014257166_item	2370736	et	3	main
hakkavad	doc_399014257166_item	2370737	et	4	main
internettrükkideks	doc_399014257166_item	2370740	et	4	main
ongi	doc_399014257166_item	2370743	et	4	main
nautida	doc_399014257166_item	2370751	et	3	main
et	doc_399014257166_item	2370758	et	3	main
kohe	doc_399014257166_item	2370767	et	4	main
lugeda	doc_399014257166_item	2370769	et	3	main
alles	doc_399014257166_item	2370771	et	3	main
lehtedes	doc_399014257166_item	2370774	et	4	main
rahata	doc_399014257166_item	2370806	et	4	main
sõbrale	doc_399014257166_item	2370807	et	3	main
tellida	doc_399014257166_item	2370808	et	3	main
oma	doc_399014257166_item	2370819	et	4	main
interneti	doc_399014257166_item	2370825	et	4	main
ise	doc_399014257166_item	2370837	et	4	main
välja	doc_399014257166_item	2370838	et	4	main
oleks	doc_399014257166_item	2370839	et	3	main
huvitav	doc_399014257166_item	2370840	et	4	main
kui	doc_399014257166_item	2370841	et	3	main
kui	doc_399014257166_item	2370850	et	3	main
oleks	doc_399014257166_item	2370851	et	3	main
töötaja	doc_399014257166_item	2370853	et	4	main
ka	doc_399014257166_item	2370855	et	3	main
ka	doc_399014257166_item	2370730	et	3	main
selle	doc_399014257166_item	2370741	et	4	main
pärast	doc_399014257166_item	2370742	et	4	main
lahe	doc_399014257166_item	2370744	et	4	main
hommikul	doc_399014257166_item	2370745	et	3	main
paperist	doc_399014257166_item	2370746	et	4	main
muidugi	doc_399014257166_item	2370752	et	4	main
on	doc_399014257166_item	2370754	et	4	main
uut	doc_399014257166_item	2370761	et	3	main
seda	doc_399014257166_item	2370766	et	3	main
lehest	doc_399014257166_item	2370770	et	4	main
järgmine	doc_399014257166_item	2370772	et	3	main
arvusmood	doc_399014257166_item	2370777	et	4	main
kaudu	doc_399014257166_item	2370779	et	3	main
inimesed	doc_399014257166_item	2370780	et	3	main
võivad	doc_399014257166_item	2370781	et	4	main
mõjutada	doc_399014257166_item	2370782	et	3	main
teisi	doc_399014257166_item	2370783	et	4	main
ja	doc_399014257166_item	2370784	et	3	main
panna	doc_399014257166_item	2370785	et	4	main
neid	doc_399014257166_item	2370786	et	4	main
mõtlema	doc_399014257166_item	2370787	et	3	main
internet	doc_399014257166_item	2370788	et	4	main
on	doc_399014257166_item	2370789	et	4	main
täna	doc_399014257166_item	2370790	et	4	main
päeval	doc_399014257166_item	2370791	et	3	main
liikagi	doc_399014257166_item	2370792	et	4	main
mõjukas	doc_399014257166_item	2370793	et	4	main
selle	doc_399014257166_item	2370794	et	4	main
abil	doc_399014257166_item	2370795	et	4	main
saab	doc_399014257166_item	2370796	et	3	main
juba	doc_399014257166_item	2370797	et	3	main
kõike	doc_399014257166_item	2370798	et	4	main
teha	doc_399014257166_item	2370799	et	3	main
võib	doc_399014257166_item	2370800	et	3	main
tellida	doc_399014257166_item	2370801	et	3	main
süüa	doc_399014257166_item	2370802	et	3	main
koju	doc_399014257166_item	2370803	et	3	main
helsitada	doc_399014257166_item	2370804	et	4	main
ilma	doc_399014257166_item	2370805	et	4	main
kusagil	doc_399014257166_item	2370763	et	3	main
on	doc_399014257166_item	2370775	et	4	main
erinevaid	doc_399014257166_item	2370809	et	4	main
reisipileteid	doc_399014257166_item	2370810	et	3	main
kuulata	doc_399014257166_item	2370811	et	4	main
muusikat	doc_399014257166_item	2370812	et	3	main
tellida	doc_399014257166_item	2370813	et	3	main
riideit	doc_399014257166_item	2370814	et	4	main
käia	doc_399014257166_item	2370818	et	4	main
televiisoriprogramme	doc_399014257166_item	2370817	et	4	main
pangaarvet	doc_399014257166_item	2370820	et	3	main
ja	doc_399014257166_item	2370822	et	3	main
ülde	doc_399014257166_item	2370836	et	4	main
freelancer	doc_399014257166_item	2370852	et	4	main
oleks	doc_399014257166_item	2370858	et	3	main
abil	doc_399014257166_item	2370826	et	4	main
paeb	doc_399014257166_item	2370847	et	4	main
minema	doc_399014257166_item	2370848	et	3	main
aga	doc_399014257166_item	2370849	et	3	main
lahendatud	doc_399014257166_item	2370859	et	4	main
edasi	doc_399014257166_item	2370824	et	3	main
on	doc_399014257166_item	2370827	et	4	main
täna	doc_399014257166_item	2370828	et	4	main
muidugi	doc_399014257166_item	2370845	et	4	main
tööle	doc_399014257166_item	2370846	et	3	main
siis	doc_399014257166_item	2370854	et	3	main
probleem	doc_399014257166_item	2370857	et	3	main
oma	doc_399014257169_item	2371653	et	4	main
aja	doc_399014257169_item	2371655	et	4	main
liikus	doc_399014257169_item	2371664	et	3	main
narride	doc_399014257169_item	2371672	et	3	main
erinevad	doc_399014257169_item	2371644	et	4	main
olemasolu	doc_399014257169_item	2371654	et	4	main
teise	doc_399014257169_item	2371667	et	4	main
seltskondlikutel	doc_399014257169_item	2371670	et	4	main
ja	doc_399014257169_item	2371674	et	3	main
kirikuõpetajate	doc_399014257169_item	2371679	et	3	main
mõjutaski	doc_399014257169_item	2371685	et	3	main
tähelepanuväärselt	doc_399014257169_item	2371688	et	4	main
ka	doc_399014257169_item	2371696	et	3	main
laiemale	doc_399014257169_item	2371699	et	4	main
siiski	doc_399014257169_item	2371723	et	4	main
keelest	doc_399014257169_item	2371728	et	4	main
meedia	doc_399014257169_item	2371643	et	4	main
kommunikatsioonivahendid	doc_399014257169_item	2371647	et	3	main
mõjutanud	doc_399014257169_item	2371649	et	4	main
lapsepõlvest	doc_399014257169_item	2371656	et	4	main
tänapäeva	doc_399014257169_item	2371659	et	4	main
ühest	doc_399014257169_item	2371665	et	4	main
kohast	doc_399014257169_item	2371666	et	4	main
õukondade	doc_399014257169_item	2371669	et	3	main
kokkusaamistel	doc_399014257169_item	2371671	et	4	main
lauludes	doc_399014257169_item	2371673	et	3	main
kõnedel	doc_399014257169_item	2371681	et	3	main
jutlustel	doc_399014257169_item	2371683	et	3	main
sõna	doc_399014257169_item	2371698	et	4	main
piibel	doc_399014257169_item	2371701	et	4	main
teised	doc_399014257169_item	2371703	et	4	main
olid	doc_399014257169_item	2371706	et	4	main
neid	doc_399014257169_item	2371715	et	4	main
osanud	doc_399014257169_item	2371717	et	4	main
suurim	doc_399014257169_item	2371718	et	3	main
osa	doc_399014257169_item	2371719	et	4	main
meediad	doc_399014257169_item	2371645	et	4	main
ja	doc_399014257169_item	2371646	et	3	main
on	doc_399014257169_item	2371648	et	4	main
inimkonda	doc_399014257169_item	2371650	et	4	main
selle	doc_399014257169_item	2371651	et	4	main
enne	doc_399014257169_item	2371658	et	4	main
igapäevaelu	doc_399014257169_item	2371687	et	4	main
ja	doc_399014257169_item	2371689	et	3	main
guttenbergi	doc_399014257169_item	2371691	et	4	main
tegi	doc_399014257169_item	2371694	et	4	main
lagunemise	doc_399014257169_item	2371700	et	4	main
jooksul	doc_399014257169_item	2371708	et	4	main
esimesed	doc_399014257169_item	2371709	et	3	main
väga	doc_399014257169_item	2371710	et	3	main
tähtsad	doc_399014257169_item	2371711	et	3	main
massimeedia	doc_399014257169_item	2371712	et	4	main
informatsioonikanalid	doc_399014257169_item	2371713	et	3	main
kuigi	doc_399014257169_item	2371714	et	3	main
viimati	doc_399014257169_item	2371724	et	3	main
ladina	doc_399014257169_item	2371727	et	4	main
niiöelda	doc_399014257169_item	2371731	et	4	main
kes	doc_399014257169_item	2371742	et	4	main
oli	doc_399014257169_item	2371743	et	3	main
seotud	doc_399014257169_item	2371745	et	4	main
meediatega	doc_399014257169_item	2371747	et	3	main
soome	doc_399014257169_item	2371748	et	3	main
ja	doc_399014257169_item	2371777	et	3	main
vahepeal	doc_399014257169_item	2371782	et	3	main
igaühe	doc_399014257169_item	2371783	et	4	main
elutuppa	doc_399014257169_item	2371785	et	3	main
ja	doc_399014257169_item	2371786	et	3	main
mida	doc_399014257169_item	2371787	et	4	main
vist	doc_399014257169_item	2371790	et	4	main
tähenduses	doc_399014257169_item	2371797	et	4	main
press	doc_399014257169_item	2371798	et	3	main
meediaühiskonda	doc_399014257169_item	2371811	et	4	main
tänapäeva	doc_399014257169_item	2371812	et	4	main
järgi	doc_399014257169_item	2371838	et	4	main
meedium	doc_399014257169_item	2371842	et	3	main
ja	doc_399014257169_item	2371847	et	3	main
ühine	doc_399014257169_item	2371852	et	4	main
on	doc_399014257169_item	2371856	et	4	main
peamiselt	doc_399014257169_item	2371861	et	4	main
nüüdsel	doc_399014257169_item	2371890	et	3	main
inimese	doc_399014257169_item	2371911	et	4	main
teatu	doc_399014257169_item	2371915	et	4	main
essee	doc_399014257169_item	2371642	et	4	main
terve	doc_399014257169_item	2371652	et	4	main
tänapäevani	doc_399014257169_item	2371657	et	3	main
informatsioonirikka	doc_399014257169_item	2371660	et	4	main
meediaühiskonna	doc_399014257169_item	2371661	et	4	main
kujunemist	doc_399014257169_item	2371662	et	4	main
informatsioon	doc_399014257169_item	2371663	et	3	main
näiteks	doc_399014257169_item	2371668	et	4	main
saadikute	doc_399014257169_item	2371675	et	3	main
teatrinäidenditel	doc_399014257169_item	2371677	et	3	main
või	doc_399014257169_item	2371678	et	4	main
suulistel	doc_399014257169_item	2371680	et	4	main
johannes	doc_399014257169_item	2371690	et	4	main
leiutis	doc_399014257169_item	2371692	et	3	main
kiriklikud	doc_399014257169_item	2371704	et	4	main
kirjutised	doc_399014257169_item	2371705	et	3	main
aja	doc_399014257169_item	2371707	et	4	main
inimestest	doc_399014257169_item	2371720	et	3	main
lugeda	doc_399014257169_item	2371721	et	3	main
rahvakeelde	doc_399014257169_item	2371729	et	4	main
meedia	doc_399014257169_item	2371732	et	4	main
tegelane	doc_399014257169_item	2371741	et	3	main
esimeste	doc_399014257169_item	2371746	et	4	main
reeglipäraselt	doc_399014257169_item	2371755	et	4	main
gramofon	doc_399014257169_item	2371776	et	4	main
perekonna	doc_399014257169_item	2371784	et	4	main
info	doc_399014257169_item	2371792	et	4	main
edastamiseks	doc_399014257169_item	2371793	et	4	main
ja	doc_399014257169_item	2371795	et	3	main
reklaamid	doc_399014257169_item	2371804	et	4	main
sajandi	doc_399014257169_item	2371806	et	3	main
tulid	doc_399014257169_item	2371808	et	4	main
ka	doc_399014257169_item	2371809	et	3	main
osaks	doc_399014257169_item	2371810	et	3	main
suur	doc_399014257169_item	2371815	et	3	main
spekter	doc_399014257169_item	2371816	et	3	main
ja	doc_399014257169_item	2371823	et	3	main
vahel	doc_399014257169_item	2371676	et	4	main
ja	doc_399014257169_item	2371682	et	3	main
kirik	doc_399014257169_item	2371684	et	3	main
inimeste	doc_399014257169_item	2371686	et	3	main
trükioskus	doc_399014257169_item	2371693	et	3	main
võimalikuks	doc_399014257169_item	2371695	et	3	main
trükitu	doc_399014257169_item	2371697	et	4	main
ja	doc_399014257169_item	2371702	et	3	main
ei	doc_399014257169_item	2371716	et	4	main
aga	doc_399014257169_item	2371722	et	3	main
tõlkimine	doc_399014257169_item	2371726	et	4	main
see	doc_399014257169_item	2371740	et	3	main
sajandil	doc_399014257169_item	2371753	et	3	main
ja	doc_399014257169_item	2371754	et	3	main
hakkasid	doc_399014257169_item	2371757	et	4	main
ka	doc_399014257169_item	2371775	et	3	main
raadio	doc_399014257169_item	2371778	et	4	main
alguses	doc_399014257169_item	2371788	et	4	main
kinofilmid	doc_399014257169_item	2371799	et	3	main
ning	doc_399014257169_item	2371802	et	3	main
meediat	doc_399014257169_item	2371813	et	3	main
erinevaid	doc_399014257169_item	2371817	et	4	main
abivahendeid	doc_399014257169_item	2371819	et	3	main
aga	doc_399014257169_item	2371830	et	3	main
term	doc_399014257169_item	2371832	et	3	main
sõna	doc_399014257169_item	2371841	et	4	main
i	doc_399014257169_item	2371843	et	4	main
keskel	doc_399014257169_item	2371845	et	3	main
nimetus	doc_399014257169_item	2371853	et	4	main
meedia	doc_399014257169_item	2371855	et	4	main
väga	doc_399014257169_item	2371857	et	3	main
lai	doc_399014257169_item	2371858	et	3	main
mõiste	doc_399014257169_item	2371859	et	4	main
aga	doc_399014257169_item	2371860	et	3	main
tihtipeale	doc_399014257169_item	2371881	et	3	main
juba	doc_399014257169_item	2371885	et	3	main
roll	doc_399014257169_item	2371894	et	3	main
inimese	doc_399014257169_item	2371897	et	4	main
elus	doc_399014257169_item	2371899	et	4	main
ei	doc_399014257169_item	2371900	et	4	main
kuidagi	doc_399014257169_item	2371908	et	3	main
ka	doc_399014257169_item	2371909	et	3	main
loob	doc_399014257169_item	2371910	et	3	main
elab	doc_399014257169_item	2371919	et	3	main
on	doc_399014257169_item	2371921	et	4	main
erinevatest	doc_399014257169_item	2371944	et	4	main
või	doc_399014257169_item	2371954	et	4	main
sõda	doc_399014257169_item	2371957	et	4	main
kes	doc_399014257169_item	2371958	et	4	main
universumiks	doc_399014257169_item	2371962	et	3	main
hirmu	doc_399014257169_item	2371966	et	4	main
alati	doc_399014257169_item	2371972	et	4	main
mida	doc_399014257169_item	2371973	et	4	main
on	doc_399014257169_item	2371977	et	4	main
suurem	doc_399014257169_item	2371982	et	4	main
ka	doc_399014257169_item	2371984	et	3	main
on	doc_399014257169_item	2371991	et	4	main
ka	doc_399014257169_item	2371993	et	3	main
meedias	doc_399014257169_item	2371996	et	4	main
öeldakse	doc_399014257169_item	2371997	et	3	main
on	doc_399014257169_item	2371999	et	4	main
loodud	doc_399014257169_item	2372009	et	4	main
teemasid	doc_399014257169_item	2372016	et	3	main
teada	doc_399014257169_item	2372024	et	3	main
maailmas	doc_399014257169_item	2372026	et	3	main
maades	doc_399014257169_item	2372035	et	4	main
ei	doc_399014257169_item	2372036	et	4	main
väljunud	doc_399014257169_item	2372041	et	4	main
kriisi	doc_399014257169_item	2372045	et	4	main
põhimõtteliselt	doc_399014257169_item	2372052	et	4	main
asi	doc_399014257169_item	2372054	et	4	main
asi	doc_399014257169_item	2372056	et	4	main
muidugi	doc_399014257169_item	2372066	et	4	main
kes	doc_399014257169_item	2372093	et	4	main
poliitilise	doc_399014257169_item	2372095	et	3	main
ka	doc_399014257169_item	2372099	et	3	main
massimeedia	doc_399014257169_item	2372102	et	4	main
või	doc_399014257169_item	2372104	et	4	main
näiteks	doc_399014257169_item	2372105	et	4	main
ruandas	doc_399014257169_item	2372106	et	4	main
üks	doc_399014257169_item	2372107	et	3	main
asju	doc_399014257169_item	2372112	et	3	main
piibli	doc_399014257169_item	2371725	et	3	main
võit	doc_399014257169_item	2371734	et	3	main
agricola	doc_399014257169_item	2371739	et	4	main
tugevasti	doc_399014257169_item	2371744	et	3	main
17	doc_399014257169_item	2371759	et	2	main
sajandil	doc_399014257169_item	2371760	et	3	main
trükioskuse	doc_399014257169_item	2371761	et	3	main
järel	doc_399014257169_item	2371762	et	4	main
meedia	doc_399014257169_item	2371763	et	4	main
tööriistana	doc_399014257169_item	2371764	et	3	main
on	doc_399014257169_item	2371765	et	4	main
hiljem	doc_399014257169_item	2371766	et	3	main
olnud	doc_399014257169_item	2371767	et	4	main
nii	doc_399014257169_item	2371768	et	3	main
telegraaf	doc_399014257169_item	2371769	et	4	main
telefon	doc_399014257169_item	2371770	et	3	main
ja	doc_399014257169_item	2371771	et	3	main
selle	doc_399014257169_item	2371772	et	4	main
eelkäijad	doc_399014257169_item	2371773	et	3	main
oli	doc_399014257169_item	2371730	et	3	main
suur	doc_399014257169_item	2371733	et	3	main
mõistagi	doc_399014257169_item	2371735	et	4	main
oli	doc_399014257169_item	2371736	et	3	main
soomes	doc_399014257169_item	2371737	et	4	main
mikael	doc_399014257169_item	2371738	et	4	main
esimesed	doc_399014257169_item	2371749	et	3	main
ajalehed	doc_399014257169_item	2371750	et	3	main
ilmusid	doc_399014257169_item	2371751	et	4	main
16	doc_399014257169_item	2371752	et	2	main
need	doc_399014257169_item	2371756	et	3	main
ilmuma	doc_399014257169_item	2371758	et	3	main
ulatus	doc_399014257169_item	2371780	et	4	main
kasutati	doc_399014257169_item	2371789	et	4	main
poliitilises	doc_399014257169_item	2371796	et	3	main
19	doc_399014257169_item	2371805	et	2	main
lõpul	doc_399014257169_item	2371807	et	3	main
tehnilisi	doc_399014257169_item	2371818	et	3	main
on	doc_399014257169_item	2371820	et	4	main
arvuti	doc_399014257169_item	2371821	et	4	main
digitaalne	doc_399014257169_item	2371828	et	3	main
meedia	doc_399014257169_item	2371833	et	4	main
siis	doc_399014257169_item	2371834	et	3	main
tegelikult	doc_399014257169_item	2371835	et	4	main
tähendab	doc_399014257169_item	2371836	et	3	main
vikipeedia	doc_399014257169_item	2371837	et	4	main
keele	doc_399014257169_item	2371840	et	4	main
tähendab	doc_399014257169_item	2371844	et	3	main
olevat	doc_399014257169_item	2371846	et	4	main
on	doc_399014257169_item	2371848	et	4	main
tegelikult	doc_399014257169_item	2371849	et	4	main
ka	doc_399014257169_item	2371882	et	3	main
massikommunikatsioonil	doc_399014257169_item	2371888	et	3	main
on	doc_399014257169_item	2371889	et	4	main
ajal	doc_399014257169_item	2371891	et	4	main
väga	doc_399014257169_item	2371892	et	3	main
suur	doc_399014257169_item	2371893	et	3	main
vist	doc_399014257169_item	2371902	et	4	main
väga	doc_399014257169_item	2371903	et	3	main
valesti	doc_399014257169_item	2371904	et	3	main
väljendatud	doc_399014257169_item	2371905	et	4	main
et	doc_399014257169_item	2371906	et	3	main
vähemalt	doc_399014257169_item	2371914	et	4	main
milles	doc_399014257169_item	2371917	et	3	main
inimese	doc_399014257169_item	2371927	et	4	main
põhineb	doc_399014257169_item	2371929	et	3	main
massikommunikatsioonivahendite	doc_399014257169_item	2371946	et	3	main
kõik	doc_399014257169_item	2371948	et	4	main
naabrimaade	doc_399014257169_item	2371950	et	3	main
kus	doc_399014257169_item	2371955	et	3	main
miss	doc_399014257169_item	2371961	et	3	main
peale	doc_399014257169_item	2371967	et	4	main
ajab	doc_399014257169_item	2371970	et	3	main
informatioonist	doc_399014257169_item	2371976	et	4	main
meediate	doc_399014257169_item	2371979	et	3	main
asjade	doc_399014257169_item	2371988	et	3	main
olukord	doc_399014257169_item	2371990	et	3	main
siis	doc_399014257169_item	2371992	et	3	main
või	doc_399014257169_item	2371998	et	4	main
hullem	doc_399014257169_item	2372002	et	4	main
osa	doc_399014257169_item	2372013	et	4	main
põhimõte	doc_399014257169_item	2372020	et	3	main
anda	doc_399014257169_item	2372022	et	3	main
inimestele	doc_399014257169_item	2372023	et	3	main
hetkel	doc_399014257169_item	2372033	et	4	main
meie	doc_399014257169_item	2372034	et	4	main
kontrolli	doc_399014257169_item	2372039	et	4	main
alt	doc_399014257169_item	2372040	et	4	main
rahvusvahelist	doc_399014257169_item	2372044	et	4	main
poleks	doc_399014257169_item	2372051	et	3	main
või	doc_399014257169_item	2372064	et	4	main
ametlik	doc_399014257169_item	2372089	et	3	main
võimu	doc_399014257169_item	2372096	et	4	main
teada	doc_399014257169_item	2372111	et	3	main
väga	doc_399014257169_item	2372113	et	3	main
samuti	doc_399014257169_item	2372115	et	3	main
sõjas	doc_399014257169_item	2372117	et	3	main
suur	doc_399014257169_item	2372120	et	3	main
algamisega	doc_399014257169_item	2372123	et	4	main
selle	doc_399014257169_item	2372129	et	4	main
meedia	doc_399014257169_item	2372144	et	4	main
kui	doc_399014257169_item	2371774	et	3	main
mis	doc_399014257169_item	2371779	et	4	main
ka	doc_399014257169_item	2371781	et	3	main
ka	doc_399014257169_item	2371791	et	3	main
militaarses	doc_399014257169_item	2371794	et	3	main
ja	doc_399014257169_item	2371800	et	3	main
telekas	doc_399014257169_item	2371801	et	4	main
esimesed	doc_399014257169_item	2371803	et	3	main
valitseb	doc_399014257169_item	2371814	et	3	main
internet	doc_399014257169_item	2371822	et	4	main
selle	doc_399014257169_item	2371824	et	4	main
kommunikatsioon	doc_399014257169_item	2371829	et	3	main
mis	doc_399014257169_item	2371831	et	4	main
ladina	doc_399014257169_item	2371839	et	4	main
kandjate	doc_399014257169_item	2371851	et	4	main
lihtsalt	doc_399014257169_item	2371883	et	4	main
mainitul	doc_399014257169_item	2371887	et	4	main
tavalise	doc_399014257169_item	2371896	et	4	main
tavalises	doc_399014257169_item	2371898	et	4	main
meedia	doc_399014257169_item	2371907	et	4	main
või	doc_399014257169_item	2371913	et	4	main
meedia	doc_399014257169_item	2371922	et	4	main
poolt	doc_399014257169_item	2371923	et	4	main
loodud	doc_399014257169_item	2371924	et	4	main
meediatest	doc_399014257169_item	2371945	et	4	main
juhtub	doc_399014257169_item	2371953	et	3	main
käib	doc_399014257169_item	2371956	et	3	main
kuidas	doc_399014257169_item	2371964	et	3	main
suurem	doc_399014257169_item	2371974	et	4	main
seda	doc_399014257169_item	2371981	et	3	main
kas	doc_399014257169_item	2371987	et	3	main
muidugi	doc_399014257169_item	2372003	et	4	main
meedia	doc_399014257169_item	2372005	et	4	main
suur	doc_399014257169_item	2372012	et	3	main
millest	doc_399014257169_item	2372017	et	3	main
kõrval	doc_399014257169_item	2371825	et	4	main
ka	doc_399014257169_item	2371826	et	3	main
muu	doc_399014257169_item	2371827	et	4	main
informatiooni	doc_399014257169_item	2371850	et	4	main
wikipedias	doc_399014257169_item	2371854	et	4	main
turustamiskommunikatsiooni	doc_399014257169_item	2371862	et	4	main
ametkonna	doc_399014257169_item	2371863	et	3	main
järgi	doc_399014257169_item	2371864	et	4	main
on	doc_399014257169_item	2371865	et	4	main
meedia	doc_399014257169_item	2371866	et	4	main
reklaamiabinõu	doc_399014257169_item	2371867	et	4	main
sõnum	doc_399014257169_item	2371869	et	3	main
millega	doc_399014257169_item	2371868	et	3	main
saadetakse	doc_399014257169_item	2371870	et	3	main
objektile	doc_399014257169_item	2371871	et	3	main
teada	doc_399014257169_item	2371872	et	3	main
meedia	doc_399014257169_item	2371873	et	4	main
võib	doc_399014257169_item	2371874	et	3	main
siis	doc_399014257169_item	2371875	et	3	main
olla	doc_399014257169_item	2371876	et	3	main
ükskõik	doc_399014257169_item	2371877	et	3	main
mis	doc_399014257169_item	2371878	et	4	main
massikommunikatsioonivahend	doc_399014257169_item	2371879	et	3	main
või	doc_399014257169_item	2371880	et	4	main
massikommunikatsioon	doc_399014257169_item	2371884	et	3	main
eespool	doc_399014257169_item	2371886	et	3	main
ka	doc_399014257169_item	2371895	et	3	main
ole	doc_399014257169_item	2371901	et	4	main
elu	doc_399014257169_item	2371912	et	4	main
tõelisuse	doc_399014257169_item	2371916	et	4	main
inimene	doc_399014257169_item	2371918	et	3	main
mis	doc_399014257169_item	2371920	et	4	main
mis	doc_399014257169_item	2371936	et	4	main
ajutes	doc_399014257169_item	2371937	et	4	main
liigub	doc_399014257169_item	2371938	et	3	main
valimistel	doc_399014257169_item	2371951	et	4	main
on	doc_399014257169_item	2371959	et	4	main
või	doc_399014257169_item	2371963	et	4	main
linnugripp	doc_399014257169_item	2371965	et	3	main
ajab	doc_399014257169_item	2371968	et	3	main
kui	doc_399014257169_item	2371969	et	3	main
ja	doc_399014257169_item	2371971	et	3	main
saada	doc_399014257169_item	2371978	et	4	main
kaudu	doc_399014257169_item	2371980	et	3	main
on	doc_399014257169_item	2371983	et	4	main
nende	doc_399014257169_item	2371985	et	4	main
tõeline	doc_399014257169_item	2371989	et	4	main
kõik	doc_399014257169_item	2372000	et	4	main
on	doc_399014257169_item	2372004	et	4	main
mõiste	doc_399014257169_item	2372006	et	4	main
inimeste	doc_399014257169_item	2372007	et	3	main
poolt	doc_399014257169_item	2372008	et	4	main
informatsioonist	doc_399014257169_item	2372014	et	3	main
käsitlebgi	doc_399014257169_item	2372015	et	4	main
räägitakse	doc_399014257169_item	2372018	et	3	main
on	doc_399014257169_item	2372021	et	4	main
toimub	doc_399014257169_item	2372027	et	3	main
minu	doc_399014257169_item	2372029	et	3	main
praegusel	doc_399014257169_item	2372032	et	3	main
küsimust	doc_399014257169_item	2372048	et	4	main
et	doc_399014257169_item	2372049	et	3	main
usaldusväärne	doc_399014257169_item	2372053	et	3	main
oma	doc_399014257169_item	2372062	et	4	main
maailma	doc_399014257169_item	2372063	et	4	main
meedia	doc_399014257169_item	2372067	et	4	main
siis	doc_399014257169_item	2372091	et	3	main
nendel	doc_399014257169_item	2372092	et	4	main
olid	doc_399014257169_item	2372094	et	4	main
raadiokanal	doc_399014257169_item	2372108	et	4	main
subjektiivselt	doc_399014257169_item	2372114	et	4	main
tähendus	doc_399014257169_item	2372121	et	4	main
peale	doc_399014257169_item	2372130	et	4	main
germanistina	doc_399014257169_item	2372132	et	3	main
ei	doc_399014257169_item	2372134	et	4	main
mõtle	doc_399014257169_item	2372135	et	4	main
aga	doc_399014257169_item	2372136	et	3	main
tahtsin	doc_399014257169_item	2372137	et	3	main
rõhutada	doc_399014257169_item	2372138	et	3	main
seda	doc_399014257169_item	2372139	et	3	main
kui	doc_399014257169_item	2372140	et	3	main
suur	doc_399014257169_item	2372141	et	3	main
vist	doc_399014257169_item	2372142	et	4	main
ka	doc_399014257169_item	2372143	et	3	main
võim	doc_399014257169_item	2372145	et	3	main
mis	doc_399014257169_item	2372154	et	4	main
informatsioonist	doc_399014257169_item	2372156	et	3	main
on	doc_399014257169_item	2372161	et	4	main
meediatõelisuses	doc_399014257169_item	2372166	et	4	main
kus	doc_399014257169_item	2372170	et	3	main
võtame	doc_399014257169_item	2372175	et	3	main
nagu	doc_399014257169_item	2372178	et	3	main
nägemisvõimatu	doc_399014257169_item	2372180	et	4	main
vaatame	doc_399014257169_item	2372184	et	3	main
jaoks	doc_399014257169_item	2372193	et	4	main
täpsemalt	doc_399014257169_item	2371925	et	4	main
siis	doc_399014257169_item	2371926	et	3	main
teadmine	doc_399014257169_item	2371928	et	4	main
meedia	doc_399014257169_item	2371930	et	4	main
mõjule	doc_399014257169_item	2371931	et	3	main
ja	doc_399014257169_item	2371932	et	3	main
kõik	doc_399014257169_item	2371933	et	4	main
see	doc_399014257169_item	2371934	et	3	main
informatsioon	doc_399014257169_item	2371935	et	3	main
ongi	doc_399014257169_item	2371939	et	4	main
minu	doc_399014257169_item	2371940	et	3	main
arvates	doc_399014257169_item	2371941	et	4	main
põhimõtteliselt	doc_399014257169_item	2371942	et	4	main
pärit	doc_399014257169_item	2371943	et	3	main
puhul	doc_399014257169_item	2371947	et	4	main
mis	doc_399014257169_item	2371949	et	4	main
näiteks	doc_399014257169_item	2371952	et	4	main
saanud	doc_399014257169_item	2371960	et	4	main
osa	doc_399014257169_item	2371975	et	4	main
väärsus	doc_399014257169_item	2371986	et	4	main
nii	doc_399014257169_item	2371994	et	3	main
kui	doc_399014257169_item	2371995	et	3	main
veel	doc_399014257169_item	2372001	et	4	main
asi	doc_399014257169_item	2372010	et	4	main
ja	doc_399014257169_item	2372011	et	3	main
üldiselt	doc_399014257169_item	2372019	et	4	main
või	doc_399014257169_item	2372043	et	4	main
pole	doc_399014257169_item	2372046	et	3	main
meedia	doc_399014257169_item	2372050	et	4	main
teine	doc_399014257169_item	2372055	et	3	main
on	doc_399014257169_item	2372057	et	4	main
tänapäeval	doc_399014257169_item	2372058	et	3	main
reklaam	doc_399014257169_item	2372059	et	3	main
mis	doc_399014257169_item	2372060	et	4	main
tõelisus	doc_399014257169_item	2372090	et	4	main
oli	doc_399014257169_item	2372098	et	3	main
tegelik	doc_399014257169_item	2372100	et	3	main
võim	doc_399014257169_item	2372103	et	3	main
inimestele	doc_399014257169_item	2372110	et	3	main
sõda	doc_399014257169_item	2372124	et	4	main
on	doc_399014257169_item	2372125	et	4	main
mina	doc_399014257169_item	2372131	et	4	main
rohkem	doc_399014257169_item	2372151	et	4	main
jaoks	doc_399014257169_item	2372163	et	4	main
tähtis	doc_399014257169_item	2372164	et	4	main
millises	doc_399014257169_item	2372165	et	3	main
sellises	doc_399014257169_item	2372169	et	4	main
linnupoeg	doc_399014257169_item	2372181	et	3	main
või	doc_399014257169_item	2372182	et	4	main
selle	doc_399014257169_item	2372187	et	4	main
on	doc_399014257169_item	2372227	et	4	main
kust	doc_399014257169_item	2372230	et	4	main
oleks	doc_399014257169_item	2372231	et	3	main
kõige	doc_399014257169_item	2372234	et	4	main
just	doc_399014257169_item	2372237	et	3	main
jaoks	doc_399014257169_item	2372239	et	4	main
jälle	doc_399014257169_item	2372247	et	3	main
mis	doc_399014257169_item	2372025	et	4	main
no	doc_399014257169_item	2372028	et	3	main
arvates	doc_399014257169_item	2372030	et	4	main
kui	doc_399014257169_item	2372031	et	3	main
ole	doc_399014257169_item	2372037	et	4	main
olemas	doc_399014257169_item	2372038	et	4	main
olukorda	doc_399014257169_item	2372042	et	4	main
mingit	doc_399014257169_item	2372047	et	3	main
loob	doc_399014257169_item	2372061	et	3	main
siis	doc_399014257169_item	2372065	et	3	main
usaldatavus	doc_399014257169_item	2372068	et	4	main
või	doc_399014257169_item	2372070	et	4	main
sõja	doc_399014257169_item	2372071	et	3	main
ajal	doc_399014257169_item	2372072	et	4	main
kriisi	doc_399014257169_item	2372069	et	4	main
ühe	doc_399014257169_item	2372073	et	4	main
näite	doc_399014257169_item	2372074	et	4	main
võiks	doc_399014257169_item	2372075	et	4	main
tuua	doc_399014257169_item	2372076	et	3	main
natsi-	doc_399014257169_item	2372077	et	4	main
või	doc_399014257169_item	2372078	et	4	main
nõukogude	doc_399014257169_item	2372079	et	3	main
aja	doc_399014257169_item	2372080	et	4	main
propagandast	doc_399014257169_item	2372081	et	4	main
loodi	doc_399014257169_item	2372083	et	4	main
tollal	doc_399014257169_item	2372082	et	3	main
meedia	doc_399014257169_item	2372084	et	4	main
poolt	doc_399014257169_item	2372085	et	4	main
ka	doc_399014257169_item	2372086	et	3	main
kohati	doc_399014257169_item	2372087	et	4	main
uus	doc_399014257169_item	2372088	et	3	main
valdajad	doc_399014257169_item	2372097	et	4	main
võim	doc_399014257169_item	2372101	et	3	main
andis	doc_399014257169_item	2372109	et	3	main
telepropagandal	doc_399014257169_item	2372118	et	3	main
balkani	doc_399014257169_item	2372116	et	4	main
oli	doc_399014257169_item	2372119	et	3	main
sõja	doc_399014257169_item	2372122	et	3	main
asi	doc_399014257169_item	2372127	et	4	main
ja	doc_399014257169_item	2372128	et	3	main
et	doc_399014257169_item	2372153	et	3	main
sellest	doc_399014257169_item	2372155	et	4	main
mille	doc_399014257169_item	2372157	et	3	main
me	doc_399014257169_item	2372167	et	4	main
muudkui	doc_399014257169_item	2372172	et	3	main
tuleb	doc_399014257169_item	2372173	et	3	main
mõtiskleme	doc_399014257169_item	2372186	et	3	main
peale	doc_399014257169_item	2372188	et	4	main
et	doc_399014257169_item	2372189	et	3	main
just	doc_399014257169_item	2372191	et	3	main
meie	doc_399014257169_item	2372192	et	4	main
võib	doc_399014257169_item	2372221	et	3	main
selle	doc_399014257169_item	2372223	et	4	main
tõesti	doc_399014257169_item	2372246	et	3	main
keeruline	doc_399014257169_item	2372126	et	4	main
täpsemalt	doc_399014257169_item	2372133	et	4	main
selles	doc_399014257169_item	2372152	et	4	main
hulgas	doc_399014257169_item	2372158	et	4	main
meie	doc_399014257169_item	2372159	et	4	main
elame	doc_399014257169_item	2372160	et	3	main
informatioonit	doc_399014257169_item	2372171	et	4	main
ja	doc_399014257169_item	2372174	et	3	main
vastu	doc_399014257169_item	2372177	et	3	main
veel	doc_399014257169_item	2372179	et	4	main
ja	doc_399014257169_item	2372185	et	3	main
võiks	doc_399014257169_item	2372194	et	4	main
tähtis	doc_399014257169_item	2372195	et	4	main
olla	doc_399014257169_item	2372196	et	3	main
et	doc_399014257169_item	2372197	et	3	main
kas	doc_399014257169_item	2372198	et	3	main
tegelikult	doc_399014257169_item	2372199	et	4	main
küsimus	doc_399014257169_item	2372200	et	4	main
on	doc_399014257169_item	2372201	et	4	main
selles	doc_399014257169_item	2372202	et	4	main
et	doc_399014257169_item	2372203	et	3	main
meedia	doc_399014257169_item	2372204	et	4	main
toob	doc_399014257169_item	2372205	et	3	main
meile	doc_399014257169_item	2372206	et	4	main
nii	doc_399014257169_item	2372207	et	3	main
palju	doc_399014257169_item	2372208	et	4	main
informatsiooni	doc_399014257169_item	2372209	et	4	main
et	doc_399014257169_item	2372210	et	3	main
meil	doc_399014257169_item	2372211	et	4	main
polegi	doc_399014257169_item	2372212	et	3	main
võimalik	doc_399014257169_item	2372213	et	3	main
seda	doc_399014257169_item	2372214	et	3	main
kõike	doc_399014257169_item	2372215	et	4	main
vaikides	doc_399014257169_item	2372216	et	4	main
vastu	doc_399014257169_item	2372217	et	3	main
võtta	doc_399014257169_item	2372218	et	3	main
muidugi	doc_399014257169_item	2372219	et	4	main
ikka	doc_399014257169_item	2372220	et	4	main
mõelda	doc_399014257169_item	2372222	et	4	main
peale	doc_399014257169_item	2372224	et	4	main
et	doc_399014257169_item	2372225	et	3	main
see	doc_399014257169_item	2372233	et	3	main
kas	doc_399014257169_item	2372242	et	3	main
matti	doc_399014257169_item	2372243	et	4	main
ja	doc_399014257169_item	2372244	et	3	main
mervi	doc_399014257169_item	2372245	et	4	main
armastavad	doc_399014257169_item	2372249	et	4	main
võib	doc_399014257169_item	2372146	et	3	main
olla	doc_399014257169_item	2372147	et	3	main
asi	doc_399014257169_item	2372148	et	4	main
ongi	doc_399014257169_item	2372149	et	4	main
tänapäeval	doc_399014257169_item	2372150	et	3	main
meie	doc_399014257169_item	2372162	et	4	main
elame	doc_399014257169_item	2372168	et	3	main
kõige	doc_399014257169_item	2372176	et	4	main
kriitiliselt	doc_399014257169_item	2372183	et	4	main
mis	doc_399014257169_item	2372190	et	4	main
mis	doc_399014257169_item	2372226	et	4	main
täpsem	doc_399014257169_item	2372235	et	4	main
informatsioon	doc_399014257169_item	2372236	et	3	main
enda	doc_399014257169_item	2372238	et	4	main
ja	doc_399014257169_item	2372240	et	3	main
et	doc_399014257169_item	2372241	et	3	main
need	doc_399014257169_item	2372228	et	3	main
meediakanalid	doc_399014257169_item	2372229	et	3	main
leida	doc_399014257169_item	2372232	et	3	main
teineteist	doc_399014257169_item	2372248	et	4	main
esmaspäeval	doc_399014257182_item	2374684	et	3	main
kaheksa	doc_399014257182_item	2374688	et	4	main
lähen	doc_399014257182_item	2374706	et	3	main
kümme	doc_399014257182_item	2374717	et	3	main
keel	doc_399014257182_item	2374721	et	4	main
tulen	doc_399014257182_item	2374723	et	3	main
kell	doc_399014257182_item	2374733	et	3	main
neliteist	doc_399014257182_item	2374741	et	4	main
lähen	doc_399014257182_item	2374743	et	3	main
loeng	doc_399014257182_item	2374751	et	3	main
keel	doc_399014257182_item	2374755	et	4	main
ma	doc_399014257182_item	2374758	et	3	main
tulen	doc_399014257182_item	2374759	et	3	main
koju	doc_399014257182_item	2374760	et	3	main
ja	doc_399014257182_item	2374761	et	3	main
tegen	doc_399014257182_item	2374762	et	4	main
söön	doc_399014257182_item	2374769	et	3	main
ma	doc_399014257182_item	2374778	et	3	main
internet	doc_399014257182_item	2374780	et	4	main
kell	doc_399014257182_item	2374784	et	3	main
keskpäevaeines	doc_399014257182_item	2374824	et	3	main
koju	doc_399014257182_item	2374828	et	3	main
ja	doc_399014257182_item	2374831	et	3	main
kell	doc_399014257182_item	2374844	et	3	main
viisteist	doc_399014257182_item	2374845	et	4	main
see	doc_399014257182_item	2374846	et	3	main
on	doc_399014257182_item	2374847	et	4	main
tegen	doc_399014257182_item	2374855	et	4	main
mu	doc_399014257182_item	2374856	et	3	main
ma	doc_399014257182_item	2374858	et	3	main
söön	doc_399014257182_item	2374866	et	3	main
raamatukogusse	doc_399014257182_item	2374871	et	3	main
ma	doc_399014257182_item	2374873	et	3	main
teisipäeval	doc_399014257182_item	2374875	et	3	main
magan	doc_399014257182_item	2374877	et	3	main
hiline	doc_399014257182_item	2374879	et	4	main
ärkan	doc_399014257182_item	2374882	et	3	main
üksteist	doc_399014257182_item	2374884	et	4	main
kolmteist	doc_399014257182_item	2374890	et	4	main
kolmveerand	doc_399014257182_item	2374896	et	4	main
kell	doc_399014257182_item	2374687	et	3	main
ja	doc_399014257182_item	2374689	et	3	main
poole	doc_399014257182_item	2374693	et	4	main
ma	doc_399014257182_item	2374695	et	3	main
pesen	doc_399014257182_item	2374696	et	3	main
kell	doc_399014257182_item	2374697	et	3	main
üheksa	doc_399014257182_item	2374698	et	4	main
ja	doc_399014257182_item	2374699	et	3	main
ma	doc_399014257182_item	2374700	et	3	main
panen	doc_399014257182_item	2374701	et	3	main
poole	doc_399014257182_item	2374703	et	4	main
kümme	doc_399014257182_item	2374704	et	3	main
söön	doc_399014257182_item	2374731	et	3	main
söön	doc_399014257182_item	2374737	et	3	main
juustiga	doc_399014257182_item	2374739	et	3	main
viisteist	doc_399014257182_item	2374748	et	4	main
mul	doc_399014257182_item	2374749	et	3	main
lõunat	doc_399014257182_item	2374770	et	3	main
mängin	doc_399014257182_item	2374776	et	3	main
tarvitan	doc_399014257182_item	2374779	et	3	main
magan	doc_399014257182_item	2374782	et	3	main
poole	doc_399014257182_item	2374785	et	4	main
ma	doc_399014257182_item	2374826	et	3	main
kaksteist	doc_399014257182_item	2374830	et	4	main
keskpäevaeine	doc_399014257182_item	2374834	et	4	main
kell	doc_399014257182_item	2374835	et	3	main
söön	doc_399014257182_item	2374859	et	3	main
üheksateist	doc_399014257182_item	2374863	et	4	main
ma	doc_399014257182_item	2374865	et	3	main
lähen	doc_399014257182_item	2374870	et	3	main
õpin	doc_399014257182_item	2374874	et	3	main
kell	doc_399014257182_item	2374883	et	3	main
kell	doc_399014257182_item	2374888	et	3	main
ülikooli	doc_399014257182_item	2374900	et	4	main
koju	doc_399014257182_item	2374924	et	3	main
kaheksateist	doc_399014257182_item	2374927	et	4	main
lähen	doc_399014257182_item	2374934	et	3	main
sõbraga	doc_399014257182_item	2374936	et	3	main
söön	doc_399014257182_item	2374952	et	3	main
ma	doc_399014257182_item	2374954	et	3	main
ärkan	doc_399014257182_item	2374686	et	3	main
ma	doc_399014257182_item	2374690	et	3	main
kell	doc_399014257182_item	2374702	et	3	main
ma	doc_399014257182_item	2374705	et	3	main
loeng	doc_399014257182_item	2374716	et	3	main
see	doc_399014257182_item	2374718	et	3	main
eestii	doc_399014257182_item	2374720	et	4	main
kell	doc_399014257182_item	2374725	et	3	main
ja	doc_399014257182_item	2374727	et	3	main
ma	doc_399014257182_item	2374735	et	3	main
ma	doc_399014257182_item	2374742	et	3	main
raamatukogu	doc_399014257182_item	2374744	et	4	main
laenama	doc_399014257182_item	2374745	et	3	main
raamatud	doc_399014257182_item	2374746	et	4	main
kell	doc_399014257182_item	2374747	et	3	main
see	doc_399014257182_item	2374752	et	3	main
mu	doc_399014257182_item	2374763	et	3	main
kodutöö	doc_399014257182_item	2374764	et	4	main
kell	doc_399014257182_item	2374765	et	3	main
poole	doc_399014257182_item	2374766	et	4	main
üheksateist	doc_399014257182_item	2374767	et	4	main
õhtu	doc_399014257182_item	2374771	et	4	main
õpin	doc_399014257182_item	2374773	et	3	main
kitarr	doc_399014257182_item	2374775	et	3	main
ma	doc_399014257182_item	2374685	et	3	main
söön	doc_399014257182_item	2374691	et	3	main
jalgsi	doc_399014257182_item	2374708	et	3	main
on	doc_399014257182_item	2374710	et	4	main
poole	doc_399014257182_item	2374711	et	4	main
ma	doc_399014257182_item	2374722	et	3	main
kaksteist	doc_399014257182_item	2374726	et	4	main
internet	doc_399014257182_item	2374729	et	4	main
ma	doc_399014257182_item	2374730	et	3	main
keskpäevaeina	doc_399014257182_item	2374732	et	4	main
kolmteist	doc_399014257182_item	2374734	et	4	main
on	doc_399014257182_item	2374750	et	4	main
neli	doc_399014257182_item	2374787	et	3	main
võin	doc_399014257182_item	2374821	et	3	main
teisipäeval	doc_399014257182_item	2374825	et	3	main
vene	doc_399014257182_item	2374848	et	4	main
kell	doc_399014257182_item	2374861	et	3	main
pizzat	doc_399014257182_item	2374867	et	4	main
ma	doc_399014257182_item	2374886	et	3	main
poole	doc_399014257182_item	2374889	et	4	main
ma	doc_399014257182_item	2374891	et	3	main
söön	doc_399014257182_item	2374892	et	3	main
keskpäevaeina	doc_399014257182_item	2374893	et	4	main
ja	doc_399014257182_item	2374894	et	3	main
kell	doc_399014257182_item	2374895	et	3	main
ma	doc_399014257182_item	2374922	et	3	main
söön	doc_399014257182_item	2374930	et	3	main
kolmapäev	doc_399014257182_item	2374932	et	3	main
kümme	doc_399014257182_item	2374957	et	3	main
ülikooli	doc_399014257182_item	2374961	et	4	main
kolmveerand	doc_399014257182_item	2374963	et	4	main
üksteist	doc_399014257182_item	2374964	et	4	main
mul	doc_399014257182_item	2374965	et	3	main
on	doc_399014257182_item	2374966	et	4	main
loeng	doc_399014257182_item	2374967	et	3	main
ma	doc_399014257182_item	2374974	et	3	main
koju	doc_399014257182_item	2374976	et	3	main
raske	doc_399014257182_item	2375015	et	4	main
koju	doc_399014257182_item	2375018	et	3	main
ma	doc_399014257182_item	2375024	et	3	main
lõunat	doc_399014257182_item	2375026	et	3	main
ja	doc_399014257182_item	2375029	et	3	main
vara	doc_399014257182_item	2375040	et	4	main
seitse	doc_399014257182_item	2375045	et	3	main
ja	doc_399014257182_item	2375046	et	3	main
ma	doc_399014257182_item	2375047	et	3	main
ja	doc_399014257182_item	2375054	et	3	main
lähen	doc_399014257182_item	2375056	et	3	main
kolmveerand	doc_399014257182_item	2375058	et	4	main
üheksa	doc_399014257182_item	2375059	et	4	main
mul	doc_399014257182_item	2375060	et	3	main
kestab	doc_399014257182_item	2375069	et	4	main
ma	doc_399014257182_item	2375072	et	3	main
koju	doc_399014257182_item	2375074	et	3	main
üksteist	doc_399014257182_item	2375076	et	4	main
ja	doc_399014257182_item	2375077	et	3	main
ma	doc_399014257182_item	2375078	et	3	main
magan	doc_399014257182_item	2375079	et	3	main
ma	doc_399014257182_item	2375080	et	3	main
lähen	doc_399014257182_item	2375086	et	3	main
mul	doc_399014257182_item	2375088	et	3	main
loeng	doc_399014257182_item	2375090	et	3	main
viisteist	doc_399014257182_item	2375092	et	4	main
kuusteist	doc_399014257182_item	2375101	et	4	main
kell	doc_399014257182_item	2375105	et	3	main
ma	doc_399014257182_item	2375108	et	3	main
essee	doc_399014257182_item	2374681	et	4	main
minu	doc_399014257182_item	2374682	et	3	main
nädal	doc_399014257182_item	2374683	et	3	main
kell	doc_399014257182_item	2374692	et	3	main
üheksa	doc_399014257182_item	2374694	et	4	main
ülikooli	doc_399014257182_item	2374707	et	4	main
kell	doc_399014257182_item	2374709	et	3	main
kolmveerand	doc_399014257182_item	2374712	et	4	main
kümme	doc_399014257182_item	2374713	et	3	main
mul	doc_399014257182_item	2374714	et	3	main
on	doc_399014257182_item	2374715	et	4	main
on	doc_399014257182_item	2374719	et	4	main
koju	doc_399014257182_item	2374724	et	3	main
tarvitan	doc_399014257182_item	2374728	et	3	main
harilikult	doc_399014257182_item	2374736	et	4	main
voileib	doc_399014257182_item	2374738	et	4	main
kell	doc_399014257182_item	2374740	et	3	main
on	doc_399014257182_item	2374753	et	4	main
vene	doc_399014257182_item	2374754	et	4	main
kell	doc_399014257182_item	2374756	et	3	main
kuusteist	doc_399014257182_item	2374757	et	4	main
ma	doc_399014257182_item	2374768	et	3	main
ma	doc_399014257182_item	2374772	et	3	main
ma	doc_399014257182_item	2374774	et	3	main
ma	doc_399014257182_item	2374781	et	3	main
minema	doc_399014257182_item	2374783	et	3	main
teisipäeval	doc_399014257182_item	2374788	et	3	main
ma	doc_399014257182_item	2374789	et	3	main
ärkan	doc_399014257182_item	2374790	et	3	main
kell	doc_399014257182_item	2374791	et	3	main
üheksa	doc_399014257182_item	2374792	et	4	main
ma	doc_399014257182_item	2374793	et	3	main
söön	doc_399014257182_item	2374794	et	3	main
hommikust	doc_399014257182_item	2374795	et	4	main
ja	doc_399014257182_item	2374796	et	3	main
ma	doc_399014257182_item	2374797	et	3	main
pesen	doc_399014257182_item	2374798	et	3	main
ma	doc_399014257182_item	2374799	et	3	main
lähen	doc_399014257182_item	2374800	et	3	main
ülikooli	doc_399014257182_item	2374801	et	4	main
kell	doc_399014257182_item	2374802	et	3	main
on	doc_399014257182_item	2374803	et	4	main
kolm	doc_399014257182_item	2374804	et	3	main
veerand	doc_399014257182_item	2374805	et	4	main
üksteist	doc_399014257182_item	2374806	et	4	main
mul	doc_399014257182_item	2374807	et	3	main
on	doc_399014257182_item	2374808	et	4	main
loeng	doc_399014257182_item	2374809	et	3	main
kell	doc_399014257182_item	2374810	et	3	main
üksteist	doc_399014257182_item	2374811	et	4	main
see	doc_399014257182_item	2374812	et	3	main
on	doc_399014257182_item	2374813	et	4	main
poliitika	doc_399014257182_item	2374814	et	4	main
ma	doc_399014257182_item	2374815	et	3	main
elan	doc_399014257182_item	2374816	et	3	main
lähedane	doc_399014257182_item	2374817	et	3	main
ülikooli	doc_399014257182_item	2374818	et	4	main
sellepärast	doc_399014257182_item	2374819	et	3	main
ma	doc_399014257182_item	2374820	et	3	main
koju	doc_399014257182_item	2374823	et	3	main
kell	doc_399014257182_item	2374829	et	3	main
ma	doc_399014257182_item	2374832	et	3	main
ja	doc_399014257182_item	2374777	et	3	main
kakskümmend	doc_399014257182_item	2374786	et	4	main
minema	doc_399014257182_item	2374822	et	3	main
tulen	doc_399014257182_item	2374827	et	3	main
söön	doc_399014257182_item	2374833	et	3	main
on	doc_399014257182_item	2374842	et	4	main
loeng	doc_399014257182_item	2374843	et	3	main
ja	doc_399014257182_item	2374854	et	3	main
kodutöö	doc_399014257182_item	2374857	et	4	main
ma	doc_399014257182_item	2374876	et	3	main
kolmapäeval	doc_399014257182_item	2374880	et	3	main
pesen	doc_399014257182_item	2374887	et	3	main
kolmapäeval	doc_399014257182_item	2374901	et	3	main
mul	doc_399014257182_item	2374902	et	3	main
on	doc_399014257182_item	2374903	et	4	main
üks	doc_399014257182_item	2374904	et	3	main
loeng	doc_399014257182_item	2374905	et	3	main
ainus	doc_399014257182_item	2374906	et	4	main
see	doc_399014257182_item	2374907	et	3	main
on	doc_399014257182_item	2374908	et	4	main
eestii	doc_399014257182_item	2374909	et	4	main
keel	doc_399014257182_item	2374910	et	4	main
loeng	doc_399014257182_item	2374911	et	3	main
kestab	doc_399014257182_item	2374912	et	4	main
kaks	doc_399014257182_item	2374913	et	3	main
tundid	doc_399014257182_item	2374914	et	4	main
loeng	doc_399014257182_item	2374915	et	3	main
taga	doc_399014257182_item	2374916	et	4	main
ma	doc_399014257182_item	2374917	et	3	main
vaatlen	doc_399014257182_item	2374918	et	3	main
eestii	doc_399014257182_item	2374919	et	4	main
filmi	doc_399014257182_item	2374920	et	4	main
kell	doc_399014257182_item	2374925	et	3	main
ma	doc_399014257182_item	2374929	et	3	main
lõunat	doc_399014257182_item	2374931	et	3	main
ma	doc_399014257182_item	2374933	et	3	main
tulen	doc_399014257182_item	2374938	et	3	main
hiline	doc_399014257182_item	2374940	et	4	main
ma	doc_399014257182_item	2374942	et	3	main
magan	doc_399014257182_item	2374943	et	3	main
minema	doc_399014257182_item	2374944	et	3	main
kell	doc_399014257182_item	2374948	et	3	main
ja	doc_399014257182_item	2374950	et	3	main
ma	doc_399014257182_item	2374951	et	3	main
hommikueine	doc_399014257182_item	2374953	et	4	main
ma	doc_399014257182_item	2374959	et	3	main
on	doc_399014257182_item	2374971	et	4	main
ja	doc_399014257182_item	2374979	et	3	main
on	doc_399014257182_item	2375014	et	4	main
tulen	doc_399014257182_item	2375017	et	3	main
poole	doc_399014257182_item	2374836	et	4	main
viisteist	doc_399014257182_item	2374837	et	4	main
ma	doc_399014257182_item	2374838	et	3	main
lähen	doc_399014257182_item	2374839	et	3	main
ülikooli	doc_399014257182_item	2374840	et	4	main
mul	doc_399014257182_item	2374841	et	3	main
keel	doc_399014257182_item	2374849	et	4	main
ma	doc_399014257182_item	2374850	et	3	main
tulen	doc_399014257182_item	2374851	et	3	main
koju	doc_399014257182_item	2374852	et	3	main
kuusteist	doc_399014257182_item	2374853	et	4	main
lõunat	doc_399014257182_item	2374860	et	3	main
poole	doc_399014257182_item	2374862	et	4	main
harilikult	doc_399014257182_item	2374864	et	4	main
õhtu	doc_399014257182_item	2374868	et	4	main
ma	doc_399014257182_item	2374869	et	3	main
ja	doc_399014257182_item	2374872	et	3	main
minema	doc_399014257182_item	2374878	et	3	main
ma	doc_399014257182_item	2374881	et	3	main
ja	doc_399014257182_item	2374885	et	3	main
kolmteist	doc_399014257182_item	2374897	et	4	main
ma	doc_399014257182_item	2374898	et	3	main
lähen	doc_399014257182_item	2374899	et	3	main
ja	doc_399014257182_item	2374928	et	3	main
kõrtsi	doc_399014257182_item	2374935	et	4	main
ma	doc_399014257182_item	2374946	et	3	main
üksteist	doc_399014257182_item	2374949	et	4	main
kell	doc_399014257182_item	2374962	et	3	main
see	doc_399014257182_item	2374970	et	3	main
tulen	doc_399014257182_item	2374975	et	3	main
kell	doc_399014257182_item	2374977	et	3	main
ma	doc_399014257182_item	2374980	et	3	main
söön	doc_399014257182_item	2374981	et	3	main
keskpäevaeina	doc_399014257182_item	2374982	et	4	main
tartivas	doc_399014257182_item	2374984	et	4	main
ka	doc_399014257182_item	2374985	et	3	main
internetti	doc_399014257182_item	2374986	et	4	main
ma	doc_399014257182_item	2374983	et	3	main
ja	doc_399014257182_item	2374987	et	3	main
ma	doc_399014257182_item	2374988	et	3	main
kirjutan	doc_399014257182_item	2374989	et	3	main
vene	doc_399014257182_item	2374990	et	4	main
jutt	doc_399014257182_item	2374991	et	3	main
ma	doc_399014257182_item	2374992	et	3	main
lähen	doc_399014257182_item	2374993	et	3	main
ülikooli	doc_399014257182_item	2374994	et	4	main
kell	doc_399014257182_item	2374995	et	3	main
kolmveerand	doc_399014257182_item	2374996	et	4	main
kolmteist	doc_399014257182_item	2374997	et	4	main
mul	doc_399014257182_item	2374998	et	3	main
on	doc_399014257182_item	2374999	et	4	main
loeng	doc_399014257182_item	2375000	et	3	main
kell	doc_399014257182_item	2375001	et	3	main
see	doc_399014257182_item	2375003	et	3	main
on	doc_399014257182_item	2375004	et	4	main
kolmteist	doc_399014257182_item	2375002	et	4	main
vene	doc_399014257182_item	2375005	et	4	main
grammatika	doc_399014257182_item	2375006	et	4	main
see	doc_399014257182_item	2375007	et	3	main
loeng	doc_399014257182_item	2375008	et	3	main
on	doc_399014257182_item	2375009	et	4	main
väga	doc_399014257182_item	2375010	et	3	main
raske	doc_399014257182_item	2375011	et	4	main
vene	doc_399014257182_item	2375012	et	4	main
klassiga	doc_399014257182_item	2374921	et	3	main
tulen	doc_399014257182_item	2374923	et	3	main
poole	doc_399014257182_item	2374926	et	4	main
ma	doc_399014257182_item	2374937	et	3	main
koju	doc_399014257182_item	2374939	et	3	main
ja	doc_399014257182_item	2374941	et	3	main
neljapäeval	doc_399014257182_item	2374945	et	3	main
ärkan	doc_399014257182_item	2374947	et	3	main
pesen	doc_399014257182_item	2374955	et	3	main
kell	doc_399014257182_item	2374956	et	3	main
ja	doc_399014257182_item	2374958	et	3	main
lähen	doc_399014257182_item	2374960	et	3	main
eestii	doc_399014257182_item	2374972	et	4	main
ja	doc_399014257182_item	2375020	et	3	main
kodutöö	doc_399014257182_item	2375023	et	4	main
pesen	doc_399014257182_item	2375051	et	3	main
ma	doc_399014257182_item	2375055	et	3	main
kell	doc_399014257182_item	2375063	et	3	main
üheksa	doc_399014257182_item	2375064	et	4	main
loeng	doc_399014257182_item	2375068	et	3	main
ja	doc_399014257182_item	2375084	et	3	main
ja	doc_399014257182_item	2375102	et	3	main
poole	doc_399014257182_item	2375106	et	4	main
lähen	doc_399014257182_item	2375109	et	3	main
sõbraga	doc_399014257182_item	2375111	et	3	main
ja	doc_399014257182_item	2375112	et	3	main
me	doc_399014257182_item	2375113	et	4	main
purju	doc_399014257182_item	2375114	et	3	main
hommiks	doc_399014257182_item	2375122	et	4	main
laupäeval	doc_399014257182_item	2375123	et	3	main
ma	doc_399014257182_item	2375127	et	3	main
söön	doc_399014257182_item	2375134	et	3	main
kell	doc_399014257182_item	2375136	et	3	main
vaatan	doc_399014257182_item	2375162	et	3	main
kitarri	doc_399014257182_item	2375164	et	4	main
mängin	doc_399014257182_item	2375165	et	3	main
ja	doc_399014257182_item	2375166	et	3	main
tegan	doc_399014257182_item	2375167	et	4	main
kell	doc_399014257182_item	2374968	et	3	main
üksteist	doc_399014257182_item	2374969	et	4	main
keel	doc_399014257182_item	2374973	et	4	main
kaksteist	doc_399014257182_item	2374978	et	4	main
grammatika	doc_399014257182_item	2375013	et	4	main
kussteist	doc_399014257182_item	2375019	et	4	main
söön	doc_399014257182_item	2375025	et	3	main
ja	doc_399014257182_item	2375033	et	3	main
kitarri	doc_399014257182_item	2375035	et	4	main
ma	doc_399014257182_item	2375050	et	3	main
on	doc_399014257182_item	2375061	et	4	main
loeng	doc_399014257182_item	2375062	et	3	main
politika	doc_399014257182_item	2375067	et	4	main
tundid	doc_399014257182_item	2375071	et	4	main
ma	doc_399014257182_item	2375085	et	3	main
ülikooli	doc_399014257182_item	2375087	et	4	main
on	doc_399014257182_item	2375089	et	4	main
tulen	doc_399014257182_item	2375098	et	3	main
koju	doc_399014257182_item	2375099	et	3	main
kakskummend	doc_399014257182_item	2375107	et	4	main
kõrtsi	doc_399014257182_item	2375110	et	4	main
neli	doc_399014257182_item	2375121	et	3	main
ma	doc_399014257182_item	2375124	et	3	main
hiline	doc_399014257182_item	2375126	et	4	main
kell	doc_399014257182_item	2375129	et	3	main
pesen	doc_399014257182_item	2375132	et	3	main
ma	doc_399014257182_item	2375148	et	3	main
umbes	doc_399014257182_item	2375150	et	4	main
tundi	doc_399014257182_item	2375152	et	4	main
linnas	doc_399014257182_item	2375153	et	4	main
kell	doc_399014257182_item	2375158	et	3	main
ja	doc_399014257182_item	2375160	et	3	main
ma	doc_399014257182_item	2375016	et	3	main
tegen	doc_399014257182_item	2375021	et	4	main
üheksateist	doc_399014257182_item	2375028	et	4	main
õhtu	doc_399014257182_item	2375030	et	4	main
ma	doc_399014257182_item	2375031	et	3	main
õpin	doc_399014257182_item	2375032	et	3	main
mängin	doc_399014257182_item	2375036	et	3	main
magan	doc_399014257182_item	2375038	et	3	main
hommikueine	doc_399014257182_item	2375049	et	4	main
kaheksa	doc_399014257182_item	2375053	et	4	main
on	doc_399014257182_item	2375066	et	4	main
kaks	doc_399014257182_item	2375070	et	3	main
tulen	doc_399014257182_item	2375073	et	3	main
kell	doc_399014257182_item	2375075	et	3	main
kell	doc_399014257182_item	2375082	et	3	main
vene	doc_399014257182_item	2375095	et	4	main
kirjutamine	doc_399014257182_item	2375096	et	4	main
ma	doc_399014257182_item	2375097	et	3	main
kell	doc_399014257182_item	2375100	et	3	main
iodvenden	doc_399014257182_item	2375104	et	4	main
kolmteist	doc_399014257182_item	2375130	et	4	main
ma	doc_399014257182_item	2375133	et	3	main
keskpäevaeina	doc_399014257182_item	2375135	et	4	main
neliteist	doc_399014257182_item	2375138	et	4	main
ja	doc_399014257182_item	2375139	et	3	main
ma	doc_399014257182_item	2375140	et	3	main
lähen	doc_399014257182_item	2375141	et	3	main
linna	doc_399014257182_item	2375142	et	4	main
bussiga	doc_399014257182_item	2375143	et	3	main
ma	doc_399014257182_item	2375144	et	3	main
lähen	doc_399014257182_item	2375145	et	3	main
ja	doc_399014257182_item	2375147	et	3	main
poolteist	doc_399014257182_item	2375151	et	4	main
kuusteist	doc_399014257182_item	2375159	et	4	main
telekas	doc_399014257182_item	2375163	et	4	main
mu	doc_399014257182_item	2375168	et	3	main
kodutöö	doc_399014257182_item	2375169	et	4	main
mu	doc_399014257182_item	2375022	et	3	main
kolmveerand	doc_399014257182_item	2375027	et	4	main
ma	doc_399014257182_item	2375034	et	3	main
ma	doc_399014257182_item	2375037	et	3	main
minema	doc_399014257182_item	2375039	et	3	main
reede	doc_399014257182_item	2375041	et	4	main
ma	doc_399014257182_item	2375042	et	3	main
ärkan	doc_399014257182_item	2375043	et	3	main
kell	doc_399014257182_item	2375044	et	3	main
söön	doc_399014257182_item	2375048	et	3	main
kell	doc_399014257182_item	2375052	et	3	main
ülikooli	doc_399014257182_item	2375057	et	4	main
see	doc_399014257182_item	2375065	et	3	main
ärkan	doc_399014257182_item	2375081	et	3	main
neliteist	doc_399014257182_item	2375083	et	4	main
kell	doc_399014257182_item	2375091	et	3	main
see	doc_399014257182_item	2375093	et	3	main
on	doc_399014257182_item	2375094	et	4	main
ma	doc_399014257182_item	2375103	et	3	main
jääme	doc_399014257182_item	2375115	et	4	main
me	doc_399014257182_item	2375116	et	4	main
koju	doc_399014257182_item	2375118	et	3	main
kell	doc_399014257182_item	2375119	et	3	main
poole	doc_399014257182_item	2375120	et	4	main
tuleme	doc_399014257182_item	2375117	et	3	main
arkan	doc_399014257182_item	2375125	et	4	main
tõusen	doc_399014257182_item	2375128	et	3	main
kauplusid	doc_399014257182_item	2375146	et	4	main
tulen	doc_399014257182_item	2375156	et	3	main
koju	doc_399014257182_item	2375157	et	3	main
ma	doc_399014257182_item	2375161	et	3	main
poole	doc_399014257182_item	2375174	et	4	main
kakskummend	doc_399014257182_item	2375175	et	4	main
ja	doc_399014257182_item	2375131	et	3	main
poole	doc_399014257182_item	2375137	et	4	main
vaatan	doc_399014257182_item	2375149	et	3	main
ringi	doc_399014257182_item	2375154	et	4	main
ma	doc_399014257182_item	2375155	et	3	main
ma	doc_399014257182_item	2375170	et	3	main
söön	doc_399014257182_item	2375171	et	3	main
hommikueine	doc_399014257182_item	2375172	et	4	main
kell	doc_399014257182_item	2375173	et	3	main
ja	doc_399014257182_item	2375176	et	3	main
vaatan	doc_399014257182_item	2375177	et	3	main
telekas	doc_399014257182_item	2375178	et	4	main
ma	doc_399014257182_item	2375179	et	3	main
magan	doc_399014257182_item	2375180	et	3	main
minema	doc_399014257182_item	2375181	et	3	main
töötab	doc_399014257187_item	2375903	et	3	main
tema	doc_399014257187_item	2375906	et	4	main
tippjuht	doc_399014257187_item	2375909	et	3	main
valimisi	doc_399014257187_item	2375911	et	4	main
eu-referendumi	doc_399014257187_item	2375914	et	3	main
töö	doc_399014257187_item	2375918	et	4	main
kõigi	doc_399014257187_item	2375921	et	4	main
meeldi	doc_399014257187_item	2375927	et	4	main
kallas	doc_399014257187_item	2375934	et	4	main
kuulama	doc_399014257187_item	2375941	et	3	main
tahab	doc_399014257187_item	2375907	et	3	main
nimetati	doc_399014257187_item	2375913	et	4	main
olulisem	doc_399014257187_item	2375922	et	4	main
ütleb	doc_399014257187_item	2375935	et	3	main
mida	doc_399014257187_item	2375937	et	4	main
ei	doc_399014257187_item	2375939	et	4	main
ikka	doc_399014257187_item	2375944	et	4	main
tema	doc_399014257187_item	2375902	et	4	main
projektijuht	doc_399014257187_item	2375905	et	3	main
arto	doc_399014257187_item	2375916	et	4	main
elus	doc_399014257187_item	2375920	et	4	main
laisklust	doc_399014257187_item	2375924	et	3	main
sellepärast	doc_399014257187_item	2375932	et	3	main
seda	doc_399014257187_item	2375936	et	3	main
et	doc_399014257187_item	2375942	et	3	main
ajal	doc_399014257187_item	2375901	et	4	main
on	doc_399014257187_item	2375919	et	4	main
essee	doc_399014257187_item	2375888	et	4	main
on	doc_399014257187_item	2375890	et	4	main
vägä	doc_399014257187_item	2375891	et	4	main
arto	doc_399014257187_item	2375889	et	4	main
auahne	doc_399014257187_item	2375892	et	4	main
noori	doc_399014257187_item	2375893	et	3	main
22-aastane	doc_399014257187_item	2375894	et	4	main
mees	doc_399014257187_item	2375895	et	4	main
tema	doc_399014257187_item	2375896	et	4	main
on	doc_399014257187_item	2375897	et	4	main
üliõpilane	doc_399014257187_item	2375898	et	3	main
aga	doc_399014257187_item	2375899	et	3	main
valimiskampaania	doc_399014257187_item	2375900	et	4	main
reformierakonna	doc_399014257187_item	2375904	et	4	main
olla	doc_399014257187_item	2375908	et	3	main
pärast	doc_399014257187_item	2375910	et	4	main
ta	doc_399014257187_item	2375912	et	4	main
projektijuht	doc_399014257187_item	2375915	et	3	main
meelest	doc_399014257187_item	2375917	et	4	main
asi	doc_399014257187_item	2375923	et	4	main
ei	doc_399014257187_item	2375926	et	4	main
et	doc_399014257187_item	2375933	et	3	main
taha	doc_399014257187_item	2375940	et	4	main
temale	doc_399014257187_item	2375925	et	3	main
tema	doc_399014257187_item	2375928	et	4	main
armastab	doc_399014257187_item	2375929	et	3	main
siim	doc_399014257187_item	2375930	et	4	main
kallast	doc_399014257187_item	2375931	et	4	main
inimesed	doc_399014257187_item	2375938	et	3	main
tugevad	doc_399014257187_item	2375943	et	4	main
saavutad	doc_399014257187_item	2375945	et	3	main
võitu	doc_399014257187_item	2375946	et	4	main
meeldib	doc_399014257196_item	2376968	et	3	main
parem	doc_399014257196_item	2376975	et	4	main
kui	doc_399014257196_item	2376980	et	3	main
lauset	doc_399014257196_item	2376962	et	3	main
sügis	doc_399014257196_item	2376964	et	3	main
külm	doc_399014257196_item	2376966	et	3	main
aastaaeg	doc_399014257196_item	2376976	et	3	main
sügis	doc_399014257196_item	2376977	et	3	main
vihma	doc_399014257196_item	2376981	et	4	main
koolid	doc_399014257196_item	2376994	et	3	main
asuvad	doc_399014257196_item	2376996	et	4	main
glasgows	doc_399014257196_item	2376998	et	4	main
sügis	doc_399014257196_item	2376999	et	3	main
septembris	doc_399014257196_item	2377002	et	3	main
ja	doc_399014257196_item	2377003	et	3	main
tuul	doc_399014257196_item	2377006	et	3	main
puhub	doc_399014257196_item	2377007	et	3	main
võiga	doc_399014257197_item	2377028	et	3	main
leivas	doc_399014257197_item	2377030	et	3	main
lisa	doc_399014257197_item	2377048	et	4	main
soovima	doc_399014257197_item	2377052	et	4	main
pean	doc_399014257199_item	2377219	et	4	main
minema	doc_399014257199_item	2377220	et	3	main
10	doc_399014257196_item	2376961	et	2	main
on	doc_399014257196_item	2376965	et	4	main
mulle	doc_399014257196_item	2376967	et	4	main
kõige	doc_399014257196_item	2376970	et	4	main
kõige	doc_399014257196_item	2376974	et	4	main
oleks	doc_399014257196_item	2376978	et	3	main
ei	doc_399014257196_item	2376982	et	4	main
kogu	doc_399014257196_item	2376984	et	4	main
sügises	doc_399014257196_item	2376986	et	3	main
sügises	doc_399014257196_item	2376990	et	3	main
jalgpalli	doc_399014257196_item	2376992	et	4	main
retsept	doc_399014257197_item	2377010	et	3	main
sügis	doc_399014257196_item	2376969	et	3	main
on	doc_399014257196_item	2376973	et	4	main
alustab	doc_399014257196_item	2376993	et	3	main
sügises	doc_399014257196_item	2377005	et	3	main
vingelt	doc_399014257196_item	2377008	et	4	main
harjutus	doc_399014257197_item	2377009	et	4	main
peekoniks	doc_399014257197_item	2377011	et	3	main
kaksikvõieib	doc_399014257197_item	2377012	et	4	main
1	doc_399014257197_item	2377013	et	2	main
ostab	doc_399014257197_item	2377014	et	3	main
leiba	doc_399014257197_item	2377015	et	4	main
ja	doc_399014257197_item	2377017	et	3	main
peekonit	doc_399014257197_item	2377018	et	3	main
2	doc_399014257197_item	2377019	et	2	main
praadib	doc_399014257197_item	2377020	et	4	main
võid	doc_399014257197_item	2377016	et	4	main
või	doc_399014257197_item	2377023	et	4	main
grillahi	doc_399014257197_item	2377026	et	3	main
määrib	doc_399014257197_item	2377029	et	3	main
või	doc_399014257197_item	2377031	et	4	main
asetab	doc_399014257197_item	2377036	et	3	main
peale	doc_399014257197_item	2377038	et	4	main
lõik	doc_399014257197_item	2377043	et	3	main
peale	doc_399014257197_item	2377045	et	4	main
head	doc_399014257197_item	2377054	et	4	main
isu	doc_399014257197_item	2377055	et	4	main
kallis	doc_399014257199_item	2377173	et	4	main
olen	doc_399014257199_item	2377179	et	3	main
naljaasi	doc_399014257199_item	2377217	et	3	main
nüüd	doc_399014257199_item	2377221	et	4	main
ma	doc_399014257199_item	2377223	et	3	main
armistan	doc_399014257199_item	2377224	et	4	main
sind	doc_399014257199_item	2377225	et	4	main
harjutus	doc_399014257196_item	2376960	et	4	main
sügiset	doc_399014257196_item	2376963	et	4	main
rohkem	doc_399014257196_item	2376971	et	4	main
sügis	doc_399014257196_item	2376972	et	3	main
kenan	doc_399014257196_item	2376979	et	4	main
aja	doc_399014257196_item	2376985	et	4	main
aastaaeg	doc_399014257196_item	2376991	et	3	main
tagasiteele	doc_399014257196_item	2376995	et	3	main
sügises	doc_399014257196_item	2376997	et	3	main
on	doc_399014257196_item	2377000	et	4	main
augustis	doc_399014257196_item	2377001	et	3	main
oktoobris	doc_399014257196_item	2377004	et	3	main
peekonit	doc_399014257197_item	2377021	et	3	main
6	doc_399014257197_item	2377053	et	2	main
kuidas	doc_399014257199_item	2377175	et	3	main
käib	doc_399014257199_item	2377177	et	3	main
ma	doc_399014257199_item	2377218	et	3	main
sajaks	doc_399014257196_item	2376983	et	4	main
lehi	doc_399014257196_item	2376987	et	4	main
vähenevad	doc_399014257196_item	2376988	et	4	main
pue	doc_399014257196_item	2376989	et	4	main
all	doc_399014257197_item	2377025	et	3	main
röstima	doc_399014257197_item	2377033	et	3	main
4	doc_399014257197_item	2377035	et	2	main
siis	doc_399014257197_item	2377040	et	3	main
teine	doc_399014257197_item	2377042	et	3	main
leiva	doc_399014257197_item	2377044	et	3	main
peekoni	doc_399014257197_item	2377046	et	3	main
tomatkaste	doc_399014257197_item	2377049	et	4	main
sa	doc_399014257197_item	2377051	et	3	main
praepannis	doc_399014257197_item	2377022	et	3	main
grillima	doc_399014257197_item	2377024	et	4	main
3	doc_399014257197_item	2377027	et	2	main
esimene	doc_399014257197_item	2377032	et	3	main
leiva	doc_399014257197_item	2377034	et	3	main
peekoni	doc_399014257197_item	2377037	et	3	main
leiva	doc_399014257197_item	2377039	et	3	main
asetama	doc_399014257197_item	2377041	et	3	main
5	doc_399014257197_item	2377047	et	2	main
kui	doc_399014257197_item	2377050	et	3	main
kiri	doc_399014257199_item	2377172	et	3	main
käsi	doc_399014257199_item	2377176	et	4	main
siin	doc_399014257199_item	2377180	et	4	main
ma	doc_399014257199_item	2377182	et	3	main
nagemist	doc_399014257199_item	2377222	et	4	main
mamma	doc_399014257199_item	2377174	et	4	main
ma	doc_399014257199_item	2377178	et	3	main
eestis	doc_399014257199_item	2377181	et	3	main
armistad	doc_399014257199_item	2377183	et	4	main
eestimaad	doc_399014257199_item	2377184	et	4	main
tallinn	doc_399014257199_item	2377185	et	4	main
on	doc_399014257199_item	2377186	et	4	main
väga	doc_399014257199_item	2377187	et	3	main
ilus	doc_399014257199_item	2377188	et	4	main
aga	doc_399014257199_item	2377189	et	3	main
mind	doc_399014257199_item	2377190	et	4	main
homme	doc_399014257199_item	2377191	et	3	main
ei	doc_399014257199_item	2377192	et	4	main
ole	doc_399014257199_item	2377193	et	4	main
mul	doc_399014257199_item	2377194	et	3	main
on	doc_399014257199_item	2377195	et	4	main
vaba	doc_399014257199_item	2377196	et	4	main
päev	doc_399014257199_item	2377197	et	3	main
ma	doc_399014257199_item	2377198	et	3	main
pean	doc_399014257199_item	2377199	et	4	main
minema	doc_399014257199_item	2377200	et	3	main
tartusse	doc_399014257199_item	2377202	et	3	main
homme	doc_399014257199_item	2377203	et	3	main
ma	doc_399014257199_item	2377204	et	3	main
loodan	doc_399014257199_item	2377205	et	3	main
et	doc_399014257199_item	2377206	et	3	main
rongiga	doc_399014257199_item	2377201	et	4	main
sinu	doc_399014257199_item	2377207	et	3	main
on	doc_399014257199_item	2377208	et	4	main
hästi	doc_399014257199_item	2377209	et	3	main
ma	doc_399014257199_item	2377210	et	3	main
ei	doc_399014257199_item	2377211	et	4	main
mööda	doc_399014257199_item	2377212	et	4	main
laskma	doc_399014257199_item	2377213	et	3	main
sinu	doc_399014257199_item	2377214	et	3	main
see	doc_399014257199_item	2377215	et	3	main
on	doc_399014257199_item	2377216	et	4	main
allkiri	doc_399014257199_item	2377226	et	3	main
a	doc_399014257208_item	2378305	et	4	main
ta	doc_399014257208_item	2378310	et	4	main
parema	doc_399014257208_item	2378318	et	4	main
umbes	doc_399014257208_item	2378322	et	4	main
on	doc_399014257208_item	2378328	et	4	main
mnt	doc_399014257208_item	2378346	et	4	main
väljaku	doc_399014257208_item	2378349	et	4	main
gotsa	doc_399014257208_item	2378354	et	4	main
siis	doc_399014257208_item	2378355	et	3	main
pst	doc_399014257208_item	2378359	et	3	main
tal	doc_399014257208_item	2378371	et	3	main
leida	doc_399014257208_item	2378374	et	3	main
sada	doc_399014257208_item	2378324	et	4	main
vabaduse	doc_399014257208_item	2378329	et	4	main
väljakul	doc_399014257208_item	2378330	et	3	main
kunstihoone	doc_399014257208_item	2378331	et	4	main
ees	doc_399014257208_item	2378332	et	4	main
kuhu	doc_399014257208_item	2378333	et	3	main
ta	doc_399014257208_item	2378334	et	4	main
suund	doc_399014257208_item	2378350	et	3	main
võtma	doc_399014257208_item	2378351	et	3	main
on	doc_399014257208_item	2378362	et	4	main
lossi	doc_399014257208_item	2378369	et	4	main
minema	doc_399014257208_item	2378375	et	3	main
vasaku	doc_399014257208_item	2378384	et	3	main
keele	doc_399014257208_item	2378303	et	4	main
elab	doc_399014257208_item	2378307	et	3	main
tahab	doc_399014257208_item	2378311	et	3	main
minna	doc_399014257208_item	2378312	et	3	main
juhata	doc_399014257208_item	2378315	et	4	main
pikk	doc_399014257208_item	2378319	et	4	main
edasi	doc_399014257208_item	2378321	et	3	main
kaks	doc_399014257208_item	2378323	et	3	main
meeter	doc_399014257208_item	2378325	et	3	main
viru	doc_399014257208_item	2378348	et	4	main
esimene	doc_399014257208_item	2378352	et	3	main
aita	doc_399014257208_item	2378370	et	4	main
edasi	doc_399014257208_item	2378376	et	3	main
kaks	doc_399014257208_item	2378379	et	3	main
teelahkmel	doc_399014257208_item	2378382	et	3	main
harjutus	doc_399014257208_item	2378301	et	4	main
eesti	doc_399014257208_item	2378302	et	4	main
tiiu	doc_399014257208_item	2378306	et	4	main
pargari	doc_399014257208_item	2378308	et	4	main
tänaval	doc_399014257208_item	2378309	et	4	main
platsile	doc_399014257208_item	2378314	et	4	main
teed	doc_399014257208_item	2378316	et	4	main
keerata	doc_399014257208_item	2378317	et	4	main
sheet	doc_399014257208_item	2378304	et	4	main
raekoja	doc_399014257208_item	2378313	et	3	main
otse	doc_399014257208_item	2378320	et	4	main
peab	doc_399014257208_item	2378335	et	4	main
minema	doc_399014257208_item	2378336	et	3	main
et	doc_399014257208_item	2378337	et	3	main
jõuda	doc_399014257208_item	2378338	et	3	main
poole	doc_399014257208_item	2378347	et	4	main
parema	doc_399014257208_item	2378353	et	4	main
keerata	doc_399014257208_item	2378356	et	4	main
vasaku	doc_399014257208_item	2378357	et	3	main
c	doc_399014257208_item	2378360	et	4	main
peep	doc_399014257208_item	2378361	et	4	main
kaarli	doc_399014257208_item	2378363	et	4	main
kirikus	doc_399014257208_item	2378364	et	3	main
ta	doc_399014257208_item	2378365	et	4	main
peab	doc_399014257208_item	2378366	et	4	main
minema	doc_399014257208_item	2378367	et	3	main
toompea	doc_399014257208_item	2378368	et	4	main
tee	doc_399014257208_item	2378373	et	4	main
umbes	doc_399014257208_item	2378378	et	4	main
sada	doc_399014257208_item	2378380	et	4	main
keerata	doc_399014257208_item	2378383	et	4	main
faigi	doc_399014257208_item	2378385	et	4	main
tee	doc_399014257208_item	2378386	et	4	main
b	doc_399014257208_item	2378326	et	4	main
tõnu	doc_399014257208_item	2378327	et	4	main
estonia	doc_399014257208_item	2378339	et	4	main
teatri	doc_399014257208_item	2378340	et	3	main
juurde	doc_399014257208_item	2378341	et	4	main
minema	doc_399014257208_item	2378342	et	3	main
vasaku	doc_399014257208_item	2378343	et	3	main
piki	doc_399014257208_item	2378344	et	4	main
pärnu	doc_399014257208_item	2378345	et	4	main
estonia	doc_399014257208_item	2378358	et	4	main
õige	doc_399014257208_item	2378372	et	4	main
toompea	doc_399014257208_item	2378377	et	4	main
meeter	doc_399014257208_item	2378381	et	3	main
nädalapäev	doc_399014257214_item	2378976	et	3	main
ma	doc_399014257214_item	2378978	et	3	main
kolm	doc_399014257214_item	2378984	et	3	main
mõnikord	doc_399014257214_item	2378991	et	3	main
ma	doc_399014257214_item	2378993	et	3	main
ma	doc_399014257214_item	2378998	et	3	main
ja	doc_399014257214_item	2379021	et	3	main
natuke	doc_399014257214_item	2379023	et	4	main
essee	doc_399014257214_item	2378969	et	4	main
week	doc_399014257214_item	2378971	et	4	main
iga	doc_399014257214_item	2378975	et	4	main
esmaspäev	doc_399014257214_item	2378977	et	3	main
eesti	doc_399014257214_item	2378980	et	4	main
ma	doc_399014257214_item	2378972	et	3	main
lähen	doc_399014257214_item	2378973	et	3	main
ulikoolis	doc_399014257214_item	2378974	et	4	main
keelt	doc_399014257214_item	2378983	et	4	main
tundi	doc_399014257214_item	2378985	et	4	main
raske	doc_399014257214_item	2378987	et	4	main
mina	doc_399014257214_item	2378988	et	4	main
vene	doc_399014257214_item	2378995	et	4	main
õpin	doc_399014257214_item	2378979	et	3	main
vene	doc_399014257214_item	2378982	et	4	main
väga	doc_399014257214_item	2378986	et	3	main
jälle	doc_399014257214_item	2378997	et	3	main
räägi	doc_399014257214_item	2379000	et	4	main
keelt	doc_399014257214_item	2379002	et	4	main
aga	doc_399014257214_item	2379003	et	3	main
ma	doc_399014257214_item	2379004	et	3	main
my	doc_399014257214_item	2378970	et	4	main
ja	doc_399014257214_item	2378981	et	3	main
võimelemine	doc_399014257214_item	2378990	et	4	main
teisipäev	doc_399014257214_item	2378992	et	3	main
õpin	doc_399014257214_item	2378994	et	3	main
keelt	doc_399014257214_item	2378996	et	4	main
vene	doc_399014257214_item	2379001	et	4	main
oskan	doc_399014257214_item	2379005	et	3	main
natuke	doc_399014257214_item	2379006	et	4	main
kolmapaev	doc_399014257214_item	2379007	et	4	main
õhtul	doc_399014257214_item	2379008	et	3	main
ma	doc_399014257214_item	2379009	et	3	main
töötan	doc_399014257214_item	2379010	et	3	main
ja	doc_399014257214_item	2379011	et	3	main
lähme	doc_399014257214_item	2379012	et	3	main
klubbisse	doc_399014257214_item	2379013	et	4	main
sõbraga	doc_399014257214_item	2379014	et	3	main
nädalavahetus	doc_399014257214_item	2379015	et	4	main
magab	doc_399014257214_item	2379017	et	3	main
ma	doc_399014257214_item	2379016	et	3	main
kaua	doc_399014257214_item	2379018	et	3	main
sõbraga	doc_399014257214_item	2379019	et	3	main
kinno	doc_399014257214_item	2379020	et	3	main
lähme	doc_399014257214_item	2378989	et	3	main
ei	doc_399014257214_item	2378999	et	4	main
1	doc_399014257216_item	2379222	et	2	main
kolmapäeva	doc_399014257216_item	2379224	et	4	main
klubisse	doc_399014257216_item	2379228	et	3	main
kaua	doc_399014257216_item	2379234	et	3	main
meeldiv	doc_399014257216_item	2379242	et	4	main
kell	doc_399014257216_item	2379251	et	3	main
ma	doc_399014257216_item	2379254	et	3	main
ning	doc_399014257216_item	2379258	et	3	main
keelt	doc_399014257216_item	2379260	et	4	main
kolm	doc_399014257216_item	2379262	et	3	main
ja	doc_399014257216_item	2379267	et	3	main
minutit	doc_399014257216_item	2379277	et	3	main
kuulama	doc_399014257216_item	2379280	et	3	main
mulle	doc_399014257216_item	2379282	et	4	main
reede	doc_399014257216_item	2379300	et	4	main
õpin	doc_399014257214_item	2379022	et	3	main
lähen	doc_399014257216_item	2379227	et	3	main
sellepärast	doc_399014257216_item	2379230	et	3	main
hommikusööki	doc_399014257216_item	2379237	et	4	main
üksteist	doc_399014257216_item	2379239	et	4	main
kell	doc_399014257216_item	2379240	et	3	main
mulle	doc_399014257216_item	2379241	et	4	main
eesti	doc_399014257216_item	2379256	et	4	main
ma	doc_399014257216_item	2379263	et	3	main
ametipostil	doc_399014257216_item	2379266	et	3	main
viis	doc_399014257216_item	2379272	et	4	main
seejärel	doc_399014257216_item	2379273	et	3	main
läheb	doc_399014257216_item	2379274	et	3	main
silvi	doc_399014257216_item	2379290	et	4	main
lõuna	doc_399014257216_item	2379294	et	4	main
väsinud	doc_399014257216_item	2379311	et	4	main
pean	doc_399014257216_item	2379317	et	4	main
reisimine	doc_399014257216_item	2379318	et	4	main
yorkisse	doc_399014257216_item	2379322	et	4	main
yorkis	doc_399014257216_item	2379336	et	4	main
ärritav	doc_399014257216_item	2379338	et	4	main
vilt	doc_399014257216_item	2379340	et	3	main
väsinud	doc_399014257216_item	2379341	et	4	main
hotell	doc_399014257216_item	2379342	et	3	main
be	doc_399014257216_item	2379343	et	4	main
väga	doc_399014257216_item	2379344	et	3	main
nõustuma	doc_399014257216_item	2379352	et	3	main
jalutuskäiku	doc_399014257216_item	2379379	et	4	main
oste	doc_399014257216_item	2379382	et	3	main
peale	doc_399014257216_item	2379411	et	4	main
auk	doc_399014257216_item	2379413	et	3	main
kurb	doc_399014257216_item	2379420	et	3	main
ma	doc_399014257216_item	2379421	et	3	main
enne	doc_399014257216_item	2379424	et	4	main
jääma	doc_399014257216_item	2379431	et	4	main
tantsuõ	doc_399014257216_item	2379433	et	4	main
4	doc_399014257216_item	2379436	et	2	main
hiljaks	doc_399014257216_item	2379440	et	3	main
seda	doc_399014257216_item	2379450	et	3	main
uuesti	doc_399014257216_item	2379453	et	3	main
puiestee	doc_399014257216_item	2379460	et	4	main
aga	doc_399014257216_item	2379465	et	3	main
new	doc_399014257216_item	2379472	et	4	main
ammu	doc_399014257216_item	2379476	et	4	main
ja	doc_399014257216_item	2379477	et	3	main
tutvuma	doc_399014257216_item	2379481	et	3	main
york	doc_399014257216_item	2379489	et	4	main
mitmesugune	doc_399014257216_item	2379491	et	3	main
kodusse	doc_399014257216_item	2379521	et	3	main
sõbrana	doc_399014257216_item	2379524	et	3	main
kaalus	doc_399014257216_item	2379540	et	4	main
neli	doc_399014257216_item	2379558	et	3	main
kolmapäev	doc_399014257216_item	2379561	et	3	main
vasaku	doc_399014257216_item	2379563	et	3	main
vooodist	doc_399014257216_item	2379565	et	4	main
sööma	doc_399014257216_item	2379571	et	4	main
ja	doc_399014257216_item	2379573	et	3	main
pakkima	doc_399014257216_item	2379577	et	3	main
essee	doc_399014257216_item	2379219	et	4	main
minu	doc_399014257216_item	2379220	et	3	main
neljapaeval	doc_399014257216_item	2379231	et	4	main
magab	doc_399014257216_item	2379233	et	3	main
umbes	doc_399014257216_item	2379238	et	4	main
tee	doc_399014257216_item	2379244	et	4	main
ning	doc_399014257216_item	2379245	et	3	main
praemuna	doc_399014257216_item	2379246	et	4	main
ma	doc_399014257216_item	2379247	et	3	main
sõidan	doc_399014257216_item	2379248	et	3	main
ülikooli	doc_399014257216_item	2379249	et	4	main
bussiga	doc_399014257216_item	2379250	et	3	main
tund	doc_399014257216_item	2379253	et	3	main
keelt	doc_399014257216_item	2379257	et	4	main
käin	doc_399014257216_item	2379265	et	3	main
loen	doc_399014257216_item	2379268	et	3	main
kela	doc_399014257216_item	2379271	et	4	main
laulja	doc_399014257216_item	2379285	et	4	main
niisugune	doc_399014257216_item	2379286	et	3	main
maarja	doc_399014257216_item	2379287	et	3	main
sööma	doc_399014257216_item	2379293	et	4	main
kaima	doc_399014257216_item	2379297	et	4	main
2	doc_399014257216_item	2379299	et	2	main
ma	doc_399014257216_item	2379301	et	3	main
väga	doc_399014257216_item	2379304	et	3	main
kell	doc_399014257216_item	2379307	et	3	main
new	doc_399014257216_item	2379319	et	4	main
päevik	doc_399014257216_item	2379221	et	3	main
ma	doc_399014257216_item	2379226	et	3	main
ma	doc_399014257216_item	2379232	et	3	main
söön	doc_399014257216_item	2379236	et	3	main
valge	doc_399014257216_item	2379243	et	4	main
üks	doc_399014257216_item	2379252	et	3	main
opin	doc_399014257216_item	2379255	et	4	main
tavaliselt	doc_399014257216_item	2379264	et	4	main
artikkeli	doc_399014257216_item	2379269	et	3	main
kodus	doc_399014257216_item	2379275	et	4	main
kakskummend	doc_399014257216_item	2379276	et	4	main
muusika	doc_399014257216_item	2379281	et	4	main
meeldiv	doc_399014257216_item	2379283	et	4	main
eesti	doc_399014257216_item	2379284	et	4	main
ines	doc_399014257216_item	2379288	et	3	main
ning	doc_399014257216_item	2379289	et	3	main
vrait	doc_399014257216_item	2379291	et	4	main
vara	doc_399014257216_item	2379295	et	4	main
olenisud	doc_399014257216_item	2379310	et	4	main
liikuda	doc_399014257216_item	2379313	et	3	main
raske	doc_399014257216_item	2379315	et	4	main
new	doc_399014257216_item	2379321	et	4	main
sõitma	doc_399014257216_item	2379323	et	3	main
nädalalõpp	doc_399014257216_item	2379325	et	3	main
sõbraga	doc_399014257216_item	2379326	et	3	main
kaudu	doc_399014257216_item	2379329	et	3	main
ma	doc_399014257216_item	2379333	et	3	main
new	doc_399014257216_item	2379335	et	4	main
odav	doc_399014257216_item	2379346	et	3	main
puhas	doc_399014257216_item	2379347	et	3	main
minu	doc_399014257216_item	2379350	et	3	main
me	doc_399014257216_item	2379381	et	4	main
poevargus	doc_399014257216_item	2379386	et	3	main
minu	doc_399014257216_item	2379389	et	3	main
sõbranat	doc_399014257216_item	2379391	et	4	main
lilianat	doc_399014257216_item	2379392	et	4	main
pärast	doc_399014257216_item	2379401	et	4	main
lõunat	doc_399014257216_item	2379402	et	3	main
me	doc_399014257216_item	2379403	et	4	main
mulle	doc_399014257216_item	2379409	et	4	main
joobnud	doc_399014257216_item	2379432	et	4	main
pühapäev	doc_399014257216_item	2379437	et	3	main
sugugi	doc_399014257216_item	2379443	et	4	main
hästi	doc_399014257216_item	2379444	et	3	main
hommikust	doc_399014257216_item	2379446	et	4	main
parem	doc_399014257216_item	2379451	et	4	main
uuesti	doc_399014257216_item	2379455	et	3	main
tegema	doc_399014257216_item	2379458	et	3	main
ma	doc_399014257216_item	2379470	et	3	main
kuus	doc_399014257216_item	2379474	et	4	main
edasi	doc_399014257216_item	2379479	et	3	main
be	doc_399014257216_item	2379482	et	4	main
teine	doc_399014257216_item	2379523	et	3	main
mahasin	doc_399014257216_item	2379525	et	4	main
veel	doc_399014257216_item	2379527	et	4	main
võtma	doc_399014257216_item	2379542	et	3	main
gymnasti	doc_399014257216_item	2379545	et	4	main
õhtul	doc_399014257216_item	2379546	et	3	main
meie	doc_399014257216_item	2379547	et	4	main
6	doc_399014257216_item	2379559	et	2	main
ma	doc_399014257216_item	2379562	et	3	main
minu	doc_399014257216_item	2379582	et	3	main
ma	doc_399014257216_item	2379587	et	3	main
lennujaama	doc_399014257216_item	2379589	et	4	main
umbes	doc_399014257216_item	2379590	et	4	main
neli	doc_399014257216_item	2379591	et	3	main
koduteel	doc_399014257216_item	2379594	et	3	main
juba	doc_399014257216_item	2379597	et	3	main
kuigi	doc_399014257216_item	2379602	et	3	main
magada	doc_399014257216_item	2379604	et	3	main
jala	doc_399014257216_item	2379607	et	4	main
pärast	doc_399014257216_item	2379615	et	4	main
pakkima	doc_399014257216_item	2379623	et	3	main
kogu	doc_399014257216_item	2379626	et	4	main
aga	doc_399014257216_item	2379628	et	3	main
ma	doc_399014257216_item	2379630	et	3	main
neljapäev	doc_399014257216_item	2379223	et	3	main
õhtul	doc_399014257216_item	2379225	et	3	main
sõbraga	doc_399014257216_item	2379229	et	3	main
ma	doc_399014257216_item	2379235	et	3	main
vene	doc_399014257216_item	2379259	et	4	main
kell	doc_399014257216_item	2379261	et	3	main
kuni	doc_399014257216_item	2379270	et	3	main
teekond	doc_399014257216_item	2379278	et	3	main
ma	doc_399014257216_item	2379279	et	3	main
ma	doc_399014257216_item	2379292	et	3	main
ning	doc_399014257216_item	2379296	et	3	main
voodi	doc_399014257216_item	2379298	et	4	main
üles	doc_399014257216_item	2379302	et	3	main
varajane	doc_399014257216_item	2379305	et	3	main
kolm	doc_399014257216_item	2379308	et	3	main
edasi	doc_399014257216_item	2379312	et	3	main
oli	doc_399014257216_item	2379314	et	3	main
ma	doc_399014257216_item	2379316	et	3	main
lühidalt	doc_399014257216_item	2379324	et	4	main
lendama	doc_399014257216_item	2379328	et	3	main
amsterdami	doc_399014257216_item	2379330	et	4	main
reede	doc_399014257216_item	2379353	et	4	main
meie	doc_399014257216_item	2379355	et	4	main
joogi	doc_399014257216_item	2379357	et	4	main
tegema	doc_399014257216_item	2379380	et	3	main
itaallased	doc_399014257216_item	2379393	et	3	main
me	doc_399014257216_item	2379395	et	4	main
külastamasin	doc_399014257216_item	2379404	et	4	main
maa	doc_399014257216_item	2379405	et	4	main
see	doc_399014257216_item	2379407	et	3	main
inimesed	doc_399014257216_item	2379414	et	3	main
pisarsilmi	doc_399014257216_item	2379416	et	3	main
uinakutsin	doc_399014257216_item	2379422	et	4	main
ja	doc_399014257216_item	2379426	et	3	main
halvasti	doc_399014257216_item	2379435	et	3	main
aratama	doc_399014257216_item	2379439	et	4	main
peavaluga	doc_399014257216_item	2379441	et	3	main
mitte	doc_399014257216_item	2379442	et	3	main
pärast	doc_399014257216_item	2379445	et	4	main
sööma	doc_399014257216_item	2379447	et	4	main
ikka	doc_399014257216_item	2379452	et	4	main
me	doc_399014257216_item	2379456	et	4	main
viies	doc_399014257216_item	2379459	et	4	main
võlgu	doc_399014257216_item	2379461	et	4	main
külastamasin	doc_399014257216_item	2379471	et	4	main
väga	doc_399014257216_item	2379475	et	3	main
nõnda	doc_399014257216_item	2379478	et	3	main
vaastamisväärsustega	doc_399014257216_item	2379480	et	4	main
armistad	doc_399014257216_item	2379487	et	4	main
kord	doc_399014257216_item	2379528	et	4	main
yorkis	doc_399014257216_item	2379531	et	4	main
pole	doc_399014257216_item	2379536	et	3	main
juurde	doc_399014257216_item	2379541	et	4	main
pean	doc_399014257216_item	2379544	et	4	main
välja	doc_399014257216_item	2379548	et	4	main
minema	doc_399014257216_item	2379549	et	3	main
rahulik	doc_399014257216_item	2379554	et	3	main
kell	doc_399014257216_item	2379556	et	3	main
teisipaev	doc_399014257216_item	2379560	et	4	main
jalaga	doc_399014257216_item	2379564	et	3	main
ma	doc_399014257216_item	2379567	et	3	main
üliväsinud	doc_399014257216_item	2379569	et	3	main
sisse	doc_399014257216_item	2379574	et	4	main
kokku	doc_399014257216_item	2379576	et	3	main
siis	doc_399014257216_item	2379578	et	3	main
kell	doc_399014257216_item	2379585	et	3	main
kell	doc_399014257216_item	2379592	et	3	main
jätkamasin	doc_399014257216_item	2379595	et	4	main
kaua	doc_399014257216_item	2379596	et	3	main
ärkama	doc_399014257216_item	2379303	et	3	main
hommikus	doc_399014257216_item	2379306	et	3	main
ma	doc_399014257216_item	2379309	et	3	main
yorki	doc_399014257216_item	2379320	et	4	main
parast	doc_399014257216_item	2379331	et	3	main
lõunat	doc_399014257216_item	2379332	et	3	main
saabumas	doc_399014257216_item	2379334	et	3	main
hasti	doc_399014257216_item	2379345	et	4	main
kindel	doc_399014257216_item	2379349	et	3	main
minema	doc_399014257216_item	2379356	et	3	main
ja	doc_399014257216_item	2379358	et	3	main
klubbisse	doc_399014257216_item	2379359	et	4	main
midagi	doc_399014257216_item	2379360	et	4	main
tegema	doc_399014257216_item	2379383	et	3	main
ei	doc_399014257216_item	2379385	et	4	main
ma	doc_399014257216_item	2379387	et	3	main
vana	doc_399014257216_item	2379390	et	4	main
tunneme	doc_399014257216_item	2379396	et	3	main
null	doc_399014257216_item	2379406	et	3	main
judinad	doc_399014257216_item	2379410	et	3	main
nõudma	doc_399014257216_item	2379417	et	3	main
väga	doc_399014257216_item	2379419	et	3	main
klubbisse	doc_399014257216_item	2379428	et	4	main
me	doc_399014257216_item	2379429	et	4	main
ma	doc_399014257216_item	2379438	et	3	main
tundma	doc_399014257216_item	2379449	et	3	main
ja	doc_399014257216_item	2379454	et	3	main
ostama	doc_399014257216_item	2379462	et	4	main
võlgadesse	doc_399014257216_item	2379463	et	3	main
sattuma	doc_399014257216_item	2379464	et	3	main
kui	doc_399014257216_item	2379466	et	3	main
palju	doc_399014257216_item	2379467	et	4	main
see	doc_399014257216_item	2379468	et	3	main
maksab	doc_399014257216_item	2379469	et	3	main
ei	doc_399014257216_item	2379483	et	4	main
minu	doc_399014257216_item	2379484	et	3	main
new	doc_399014257216_item	2379488	et	4	main
minu	doc_399014257216_item	2379522	et	3	main
jäämasin	doc_399014257216_item	2379526	et	3	main
new	doc_399014257216_item	2379530	et	4	main
puhvetilett	doc_399014257216_item	2379532	et	3	main
mille	doc_399014257216_item	2379533	et	3	main
ma	doc_399014257216_item	2379535	et	3	main
ma	doc_399014257216_item	2379543	et	3	main
suur	doc_399014257216_item	2379553	et	3	main
voodi	doc_399014257216_item	2379555	et	4	main
meie	doc_399014257216_item	2379570	et	4	main
lõunat	doc_399014257216_item	2379572	et	3	main
või	doc_399014257216_item	2379575	et	4	main
välja	doc_399014257216_item	2379579	et	4	main
kirjutama	doc_399014257216_item	2379580	et	3	main
hotellist	doc_399014257216_item	2379581	et	4	main
lennukaugus	doc_399014257216_item	2379583	et	4	main
ei	doc_399014257216_item	2379600	et	4	main
sööt	doc_399014257216_item	2379605	et	3	main
hirmuäratav	doc_399014257216_item	2379606	et	3	main
lennukiga	doc_399014257216_item	2379608	et	3	main
ma	doc_399014257216_item	2379609	et	3	main
saabuma	doc_399014257216_item	2379610	et	3	main
kodus	doc_399014257216_item	2379611	et	4	main
umbes	doc_399014257216_item	2379612	et	4	main
väsinud	doc_399014257216_item	2379621	et	4	main
vara	doc_399014257216_item	2379646	et	4	main
vene	doc_399014257216_item	2379663	et	4	main
lugema	doc_399014257216_item	2379667	et	4	main
lugema	doc_399014257216_item	2379669	et	4	main
kuu	doc_399014257216_item	2379673	et	4	main
meeldiv	doc_399014257216_item	2379679	et	4	main
varitsema	doc_399014257216_item	2379686	et	3	main
ma	doc_399014257216_item	2379327	et	3	main
väga	doc_399014257216_item	2379337	et	3	main
ükskõik	doc_399014257216_item	2379339	et	3	main
ning	doc_399014257216_item	2379348	et	3	main
sõbrana	doc_399014257216_item	2379351	et	3	main
õhtul	doc_399014257216_item	2379354	et	3	main
magama	doc_399014257216_item	2379361	et	3	main
jääma	doc_399014257216_item	2379362	et	4	main
see	doc_399014257216_item	2379363	et	3	main
võõrastemaja	doc_399014257216_item	2379364	et	4	main
võib	doc_399014257216_item	2379365	et	3	main
majutada	doc_399014257216_item	2379366	et	3	main
neli	doc_399014257216_item	2379367	et	3	main
inimest	doc_399014257216_item	2379368	et	3	main
3	doc_399014257216_item	2379369	et	2	main
laupäev	doc_399014257216_item	2379370	et	3	main
pärast	doc_399014257216_item	2379371	et	4	main
magab	doc_399014257216_item	2379372	et	3	main
kaua	doc_399014257216_item	2379373	et	3	main
hommikust	doc_399014257216_item	2379374	et	4	main
sööma	doc_399014257216_item	2379375	et	4	main
hottelli	doc_399014257216_item	2379376	et	4	main
sõitma	doc_399014257216_item	2379377	et	3	main
meie	doc_399014257216_item	2379378	et	4	main
minema	doc_399014257216_item	2379384	et	3	main
kohtama	doc_399014257216_item	2379388	et	3	main
naine	doc_399014257216_item	2379394	et	3	main
tema	doc_399014257216_item	2379397	et	4	main
järele	doc_399014257216_item	2379398	et	4	main
suurt	doc_399014257216_item	2379399	et	3	main
puudust	doc_399014257216_item	2379400	et	4	main
ajab	doc_399014257216_item	2379408	et	3	main
suur	doc_399014257216_item	2379412	et	3	main
seisma	doc_399014257216_item	2379415	et	3	main
surnud	doc_399014257216_item	2379418	et	4	main
tegemasin	doc_399014257216_item	2379423	et	4	main
lõunastama	doc_399014257216_item	2379425	et	3	main
veel	doc_399014257216_item	2379427	et	4	main
purju	doc_399014257216_item	2379430	et	3	main
väga	doc_399014257216_item	2379434	et	3	main
ma	doc_399014257216_item	2379448	et	3	main
minema	doc_399014257216_item	2379457	et	3	main
york	doc_399014257216_item	2379473	et	4	main
eelnevus	doc_399014257216_item	2379485	et	4	main
ma	doc_399014257216_item	2379486	et	3	main
väga	doc_399014257216_item	2379490	et	3	main
ja	doc_399014257216_item	2379492	et	3	main
ehtne	doc_399014257216_item	2379493	et	3	main
asi	doc_399014257216_item	2379494	et	4	main
õhtul	doc_399014257216_item	2379496	et	3	main
ma	doc_399014257216_item	2379497	et	3	main
kohtuma	doc_399014257216_item	2379498	et	3	main
pühapäeva	doc_399014257216_item	2379495	et	4	main
vana	doc_399014257216_item	2379499	et	4	main
sõbraga	doc_399014257216_item	2379500	et	3	main
john	doc_399014257216_item	2379501	et	4	main
üks	doc_399014257216_item	2379502	et	3	main
tähtis	doc_399014257216_item	2379503	et	4	main
sõprus	doc_399014257216_item	2379504	et	3	main
5	doc_399014257216_item	2379505	et	2	main
esmaspaev	doc_399014257216_item	2379506	et	4	main
minu	doc_399014257216_item	2379507	et	3	main
sõbrana	doc_399014257216_item	2379508	et	3	main
tegema	doc_399014257216_item	2379509	et	3	main
mina	doc_399014257216_item	2379510	et	4	main
üles	doc_399014257216_item	2379511	et	3	main
ärkama	doc_399014257216_item	2379512	et	3	main
vara	doc_399014257216_item	2379513	et	4	main
nad	doc_399014257216_item	2379514	et	3	main
on	doc_399014257216_item	2379515	et	4	main
väga	doc_399014257216_item	2379516	et	3	main
jutukas	doc_399014257216_item	2379517	et	4	main
kaks	doc_399014257216_item	2379518	et	3	main
sõprus	doc_399014257216_item	2379519	et	3	main
käimasin	doc_399014257216_item	2379520	et	4	main
tegemine	doc_399014257216_item	2379529	et	4	main
sarnast	doc_399014257216_item	2379534	et	4	main
varem	doc_399014257216_item	2379537	et	4	main
näinud	doc_399014257216_item	2379538	et	4	main
ma	doc_399014257216_item	2379539	et	3	main
veel	doc_399014257216_item	2379550	et	4	main
jälle	doc_399014257216_item	2379551	et	3	main
linn	doc_399014257216_item	2379552	et	3	main
umbes	doc_399014257216_item	2379557	et	4	main
tõusma	doc_399014257216_item	2379566	et	3	main
olen	doc_399014257216_item	2379568	et	3	main
kuus	doc_399014257216_item	2379586	et	4	main
reisima	doc_399014257216_item	2379593	et	3	main
ammu	doc_399014257216_item	2379598	et	4	main
saanud	doc_399014257216_item	2379601	et	4	main
üks	doc_399014257216_item	2379613	et	3	main
kell	doc_399014257216_item	2379614	et	3	main
lõunat	doc_399014257216_item	2379616	et	3	main
ma	doc_399014257216_item	2379617	et	3	main
olin	doc_399014257216_item	2379618	et	3	main
liiga	doc_399014257216_item	2379620	et	4	main
võib-olla	doc_399014257216_item	2379619	et	3	main
ma	doc_399014257216_item	2379624	et	3	main
on	doc_399014257216_item	2379636	et	4	main
paha	doc_399014257216_item	2379637	et	4	main
ammendamine	doc_399014257216_item	2379638	et	4	main
ma	doc_399014257216_item	2379648	et	3	main
ülikoolis	doc_399014257216_item	2379658	et	4	main
ma	doc_399014257216_item	2379659	et	3	main
õppima	doc_399014257216_item	2379660	et	3	main
eesti	doc_399014257216_item	2379661	et	4	main
ja	doc_399014257216_item	2379662	et	3	main
mulle	doc_399014257216_item	2379677	et	4	main
sugugi	doc_399014257216_item	2379681	et	4	main
üles	doc_399014257216_item	2379683	et	3	main
ja	doc_399014257216_item	2379685	et	3	main
õhkutõusmine	doc_399014257216_item	2379584	et	3	main
saabuma	doc_399014257216_item	2379588	et	3	main
ma	doc_399014257216_item	2379599	et	3	main
kaua	doc_399014257216_item	2379603	et	3	main
magama	doc_399014257216_item	2379625	et	3	main
öö	doc_399014257216_item	2379627	et	4	main
kobama	doc_399014257216_item	2379631	et	3	main
kaunis	doc_399014257216_item	2379632	et	4	main
kulunud	doc_399014257216_item	2379633	et	4	main
mu	doc_399014257216_item	2379634	et	3	main
süda	doc_399014257216_item	2379635	et	3	main
värske	doc_399014257216_item	2379644	et	4	main
keelt	doc_399014257216_item	2379664	et	4	main
artikkeli	doc_399014257216_item	2379670	et	3	main
ei	doc_399014257216_item	2379678	et	4	main
käiseid	doc_399014257216_item	2379682	et	3	main
kevadine	doc_399014257216_item	2379687	et	4	main
lahti	doc_399014257216_item	2379622	et	4	main
hommikusel	doc_399014257216_item	2379629	et	4	main
eksima	doc_399014257216_item	2379641	et	4	main
järgmisel	doc_399014257216_item	2379642	et	3	main
nädalal	doc_399014257216_item	2379643	et	3	main
alustama	doc_399014257216_item	2379645	et	3	main
pean	doc_399014257216_item	2379649	et	4	main
raske	doc_399014257216_item	2379651	et	4	main
just	doc_399014257216_item	2379652	et	3	main
ülikiiresti	doc_399014257216_item	2379653	et	3	main
ja	doc_399014257216_item	2379665	et	3	main
uuesti	doc_399014257216_item	2379668	et	3	main
november	doc_399014257216_item	2379671	et	3	main
halvasti	doc_399014257216_item	2379672	et	3	main
pima	doc_399014257216_item	2379674	et	4	main
ning	doc_399014257216_item	2379675	et	3	main
rõhuv	doc_399014257216_item	2379676	et	4	main
mitte	doc_399014257216_item	2379680	et	3	main
käärima	doc_399014257216_item	2379684	et	4	main
aeg	doc_399014257216_item	2379688	et	3	main
ma	doc_399014257216_item	2379639	et	3	main
olen	doc_399014257216_item	2379640	et	3	main
öö	doc_399014257216_item	2379647	et	4	main
töö	doc_399014257216_item	2379650	et	4	main
jõulud	doc_399014257216_item	2379654	et	3	main
ma	doc_399014257216_item	2379655	et	3	main
pean	doc_399014257216_item	2379656	et	4	main
tegelema	doc_399014257216_item	2379657	et	3	main
läbi	doc_399014257216_item	2379666	et	4	main
vaatavad	doc_399014257220_item	2380621	et	4	main
tallinna	doc_399014257220_item	2380623	et	4	main
vaatavad	doc_399014257220_item	2380631	et	4	main
viltu	doc_399014257220_item	2380632	et	3	main
tallinna	doc_399014257220_item	2380633	et	4	main
21	doc_399014257220_item	2380641	et	2	main
samanimelise	doc_399014257220_item	2380645	et	4	main
järgi	doc_399014257220_item	2380649	et	4	main
kolm	doc_399014257220_item	2380657	et	3	main
kalevipoeg	doc_399014257220_item	2380659	et	3	main
kavas	doc_399014257220_item	2380661	et	3	main
meetri	doc_399014257220_item	2380665	et	3	main
rannajoonest	doc_399014257220_item	2380667	et	4	main
kalevipoja	doc_399014257220_item	2380627	et	4	main
eesti	doc_399014257220_item	2380629	et	4	main
lahte	doc_399014257220_item	2380638	et	4	main
rahvaeepose	doc_399014257220_item	2380647	et	3	main
laekunud	doc_399014257220_item	2380655	et	4	main
ideeprojekti	doc_399014257220_item	2380658	et	4	main
püstitada	doc_399014257220_item	2380662	et	3	main
piritale	doc_399014257220_item	2380669	et	4	main
rannatee	doc_399014257220_item	2380671	et	4	main
iseenesest	doc_399014257220_item	2380711	et	4	main
ja	doc_399014257220_item	2380714	et	3	main
rahvuseepose	doc_399014257220_item	2380715	et	3	main
kui	doc_399014257220_item	2380727	et	3	main
ühenduste	doc_399014257220_item	2380730	et	4	main
vastu	doc_399014257220_item	2380738	et	3	main
jäänud	doc_399014257220_item	2380747	et	4	main
on	doc_399014257220_item	2380751	et	4	main
idee	doc_399014257220_item	2380759	et	4	main
skulptor	doc_399014257220_item	2380765	et	3	main
alustas	doc_399014257220_item	2380770	et	3	main
kopenhaageni	doc_399014257220_item	2380780	et	4	main
kavandis	doc_399014257220_item	2380786	et	3	main
sõtniku	doc_399014257220_item	2380825	et	4	main
see	doc_399014257220_item	2380833	et	3	main
turistimarsruudi	doc_399014257220_item	2380835	et	3	main
või	doc_399014257220_item	2380840	et	4	main
siluetti	doc_399014257220_item	2380847	et	4	main
olnud	doc_399014257220_item	2380859	et	4	main
tutvustas	doc_399014257220_item	2380865	et	3	main
pronkskuju	doc_399014257220_item	2380867	et	4	main
kätega	doc_399014257220_item	2380870	et	3	main
tassib	doc_399014257220_item	2380872	et	3	main
maailma	doc_399014257220_item	2380885	et	4	main
paat	doc_399014257220_item	2380893	et	3	main
mõned	doc_399014257220_item	2380895	et	3	main
kes	doc_399014257220_item	2380897	et	4	main
sümboliseerivad	doc_399014257220_item	2380898	et	4	main
boikoteerib	doc_399014257220_item	2380904	et	3	main
näiteks	doc_399014257220_item	2380914	et	4	main
keskerakond	doc_399014257220_item	2380922	et	3	main
kõrgete	doc_399014257220_item	2380929	et	4	main
ehituste	doc_399014257220_item	2380930	et	4	main
kriitika	doc_399014257220_item	2380934	et	4	main
pärast	doc_399014257220_item	2380938	et	4	main
liitus	doc_399014257220_item	2380946	et	4	main
on	doc_399014257220_item	2380950	et	4	main
süüdlane	doc_399014257220_item	2380967	et	3	main
vägistamises	doc_399014257220_item	2380969	et	4	main
sümbol	doc_399014257220_item	2380978	et	3	main
järgi	doc_399014257220_item	2380993	et	4	main
püstitada	doc_399014257220_item	2380997	et	3	main
ja	doc_399014257220_item	2381000	et	3	main
tõlge	doc_399014257220_item	2380619	et	3	main
loomeühendused	doc_399014257220_item	2380620	et	3	main
lahte	doc_399014257220_item	2380624	et	4	main
kavandatud	doc_399014257220_item	2380625	et	4	main
hiiglaslikule	doc_399014257220_item	2380626	et	3	main
tallinna	doc_399014257220_item	2380637	et	4	main
suurune	doc_399014257220_item	2380640	et	4	main
kõrge	doc_399014257220_item	2380643	et	4	main
linna	doc_399014257220_item	2380650	et	4	main
saja	doc_399014257220_item	2380664	et	4	main
kaugusele	doc_399014257220_item	2380666	et	4	main
tallinnast	doc_399014257220_item	2380668	et	3	main
viltu	doc_399014257220_item	2380622	et	3	main
püstitada	doc_399014257220_item	2380636	et	3	main
kalevipoeg	doc_399014257220_item	2380644	et	3	main
kangelase	doc_399014257220_item	2380648	et	3	main
korraldatud	doc_399014257220_item	2380651	et	4	main
konkursile	doc_399014257220_item	2380652	et	3	main
oli	doc_399014257220_item	2380653	et	3	main
tähtajaks	doc_399014257220_item	2380654	et	3	main
merre	doc_399014257220_item	2380663	et	3	main
sobi	doc_399014257220_item	2380718	et	4	main
memoriaalkompleksi	doc_399014257220_item	2380720	et	4	main
varem	doc_399014257220_item	2380722	et	4	main
skulptorite	doc_399014257220_item	2380726	et	3	main
arhitektide	doc_399014257220_item	2380729	et	3	main
esindajad	doc_399014257220_item	2380731	et	4	main
ideekonkursi	doc_399014257220_item	2380732	et	3	main
protestides	doc_399014257220_item	2380735	et	4	main
jüri	doc_399014257220_item	2380740	et	4	main
32	doc_399014257220_item	2380742	et	2	main
maismaaarhitekt	doc_399014257220_item	2380752	et	3	main
on	doc_399014257220_item	2380754	et	4	main
planeerinud	doc_399014257220_item	2380755	et	4	main
linna	doc_399014257220_item	2380756	et	4	main
parke	doc_399014257220_item	2380757	et	3	main
isa	doc_399014257220_item	2380760	et	4	main
on	doc_399014257220_item	2380761	et	4	main
kes	doc_399014257220_item	2380769	et	4	main
kalevipoja	doc_399014257220_item	2380771	et	4	main
tallinnale	doc_399014257220_item	2380779	et	4	main
väikse	doc_399014257220_item	2380781	et	4	main
merineitsiga	doc_399014257220_item	2380782	et	3	main
võrreldav	doc_399014257220_item	2380783	et	4	main
sümbol	doc_399014257220_item	2380784	et	3	main
väike	doc_399014257220_item	2380788	et	4	main
kujule	doc_399014257220_item	2380628	et	3	main
kunstnikud	doc_399014257220_item	2380630	et	3	main
linna	doc_399014257220_item	2380634	et	4	main
kavatsusele	doc_399014257220_item	2380635	et	4	main
paneelmaja	doc_399014257220_item	2380639	et	4	main
meetrit	doc_399014257220_item	2380642	et	3	main
eesti	doc_399014257220_item	2380646	et	4	main
ainult	doc_399014257220_item	2380656	et	4	main
on	doc_399014257220_item	2380660	et	4	main
viiva	doc_399014257220_item	2380670	et	4	main
on	doc_399014257220_item	2380675	et	4	main
kalda	doc_399014257220_item	2380676	et	3	main
nõukogude	doc_399014257220_item	2380678	et	3	main
võimu	doc_399014257220_item	2380679	et	4	main
ajal	doc_399014257220_item	2380680	et	4	main
rajatud	doc_399014257220_item	2380681	et	4	main
teise	doc_399014257220_item	2380682	et	4	main
maailmasõja	doc_399014257220_item	2380683	et	3	main
kangelastele	doc_399014257220_item	2380684	et	4	main
pühendatud	doc_399014257220_item	2380685	et	4	main
memoriaalkompleks	doc_399014257220_item	2380686	et	3	main
millest	doc_399014257220_item	2380687	et	3	main
paistab	doc_399014257220_item	2380688	et	3	main
merele	doc_399014257220_item	2380689	et	3	main
kõrge	doc_399014257220_item	2380690	et	4	main
obelisk	doc_399014257220_item	2380691	et	3	main
ning	doc_399014257220_item	2380692	et	3	main
rannatrepp	doc_399014257220_item	2380693	et	3	main
linna	doc_399014257220_item	2380694	et	4	main
ja	doc_399014257220_item	2380695	et	3	main
skulptorite	doc_399014257220_item	2380696	et	3	main
liidu	doc_399014257220_item	2380697	et	3	main
eriarvamused	doc_399014257220_item	2380698	et	3	main
algasid	doc_399014257220_item	2380699	et	4	main
juba	doc_399014257220_item	2380700	et	3	main
kuju	doc_399014257220_item	2380701	et	4	main
suurusest	doc_399014257220_item	2380702	et	4	main
ja	doc_399014257220_item	2380703	et	3	main
äärde	doc_399014257220_item	2380672	et	4	main
samal	doc_399014257220_item	2380673	et	3	main
kohal	doc_399014257220_item	2380674	et	4	main
eesti	doc_399014257220_item	2380706	et	4	main
idee	doc_399014257220_item	2380710	et	4	main
on	doc_399014257220_item	2380712	et	4	main
aegunud	doc_399014257220_item	2380713	et	4	main
kangelane	doc_399014257220_item	2380716	et	3	main
ka	doc_399014257220_item	2380728	et	3	main
linnapea	doc_399014257220_item	2380739	et	4	main
juhitud	doc_399014257220_item	2380743	et	4	main
sõltumatu	doc_399014257220_item	2380748	et	4	main
siiski	doc_399014257220_item	2380762	et	4	main
kunstnik	doc_399014257220_item	2380763	et	3	main
vaieldav	doc_399014257220_item	2380764	et	4	main
40	doc_399014257220_item	2380768	et	2	main
lõpul	doc_399014257220_item	2380775	et	3	main
ideeks	doc_399014257220_item	2380776	et	3	main
tallinna	doc_399014257220_item	2380787	et	4	main
merineitsi	doc_399014257220_item	2380789	et	4	main
oli	doc_399014257220_item	2380790	et	3	main
ainult	doc_399014257220_item	2380791	et	4	main
14	doc_399014257220_item	2380792	et	2	main
meetrit	doc_399014257220_item	2380793	et	3	main
parim	doc_399014257220_item	2380830	et	4	main
teel	doc_399014257220_item	2380837	et	4	main
pirita	doc_399014257220_item	2380838	et	4	main
sanatooriumisse	doc_399014257220_item	2380839	et	3	main
oli	doc_399014257220_item	2380851	et	3	main
pille	doc_399014257220_item	2380863	et	3	main
kalevipoeg	doc_399014257220_item	2380871	et	3	main
sümboliseerib	doc_399014257220_item	2380875	et	3	main
kojunaasmist	doc_399014257220_item	2380877	et	3	main
seda	doc_399014257220_item	2380879	et	3	main
ta	doc_399014257220_item	2380881	et	4	main
on	doc_399014257220_item	2380882	et	4	main
käes	doc_399014257220_item	2380887	et	4	main
eestlaste	doc_399014257220_item	2380899	et	4	main
kojutulekut	doc_399014257220_item	2380900	et	3	main
mõjuvõimsam	doc_399014257220_item	2380907	et	4	main
mis	doc_399014257220_item	2380909	et	4	main
on	doc_399014257220_item	2380910	et	4	main
asukoha	doc_399014257220_item	2380917	et	4	main
suhtes	doc_399014257220_item	2380918	et	4	main
on	doc_399014257220_item	2380920	et	4	main
ääres	doc_399014257220_item	2380677	et	4	main
asukohast	doc_399014257220_item	2380704	et	4	main
ühenduse	doc_399014257220_item	2380708	et	4	main
ei	doc_399014257220_item	2380717	et	4	main
juurde	doc_399014257220_item	2380721	et	4	main
sügisel	doc_399014257220_item	2380723	et	3	main
nii	doc_399014257220_item	2380725	et	3	main
komisjonist	doc_399014257220_item	2380733	et	3	main
tagasi	doc_399014257220_item	2380734	et	3	main
liige	doc_399014257220_item	2380750	et	4	main
algupärase	doc_399014257220_item	2380758	et	4	main
kangro	doc_399014257220_item	2380767	et	4	main
turustamisega	doc_399014257220_item	2380772	et	4	main
1990ndate	doc_399014257220_item	2380774	et	4	main
kujundada	doc_399014257220_item	2380778	et	3	main
algses	doc_399014257220_item	2380785	et	3	main
ettepanekul	doc_399014257220_item	2380797	et	3	main
ka	doc_399014257220_item	2380827	et	3	main
on	doc_399014257220_item	2380829	et	4	main
jääb	doc_399014257220_item	2380834	et	3	main
äärde	doc_399014257220_item	2380836	et	4	main
see	doc_399014257220_item	2380842	et	3	main
ka	doc_399014257220_item	2380845	et	3	main
ateljees	doc_399014257220_item	2380850	et	3	main
esmaspäevalgi	doc_399014257220_item	2380853	et	4	main
vaimustunud	doc_399014257220_item	2380854	et	4	main
kunstnik	doc_399014257220_item	2380856	et	3	main
ise	doc_399014257220_item	2380857	et	4	main
ei	doc_399014257220_item	2380858	et	4	main
aga	doc_399014257220_item	2380861	et	3	main
skulptuur	doc_399014257220_item	2380874	et	3	main
kangelase	doc_399014257220_item	2380876	et	3	main
pärast	doc_399014257220_item	2380878	et	4	main
on	doc_399014257220_item	2380888	et	4	main
kunstniku	doc_399014257220_item	2380889	et	3	main
tulemusena	doc_399014257220_item	2380891	et	3	main
ja	doc_399014257220_item	2380894	et	3	main
peale	doc_399014257220_item	2380901	et	4	main
ka	doc_399014257220_item	2380906	et	3	main
arhitektideliit	doc_399014257220_item	2380908	et	4	main
raekoja	doc_399014257220_item	2380916	et	3	main
tallinnas	doc_399014257220_item	2380919	et	4	main
on	doc_399014257220_item	2380924	et	4	main
ka	doc_399014257220_item	2380925	et	3	main
varem	doc_399014257220_item	2380926	et	4	main
vastu	doc_399014257220_item	2380931	et	3	main
skulptuurtehingu	doc_399014257220_item	2380935	et	3	main
saanud	doc_399014257220_item	2380951	et	4	main
ka	doc_399014257220_item	2380952	et	3	main
kalevipoeg	doc_399014257220_item	2380953	et	3	main
ise	doc_399014257220_item	2380954	et	4	main
ka	doc_399014257220_item	2380966	et	3	main
konkursi	doc_399014257220_item	2380981	et	3	main
jaanuari	doc_399014257220_item	2380984	et	4	main
järel	doc_399014257220_item	2380987	et	4	main
võitlustöödest	doc_399014257220_item	2380988	et	3	main
korraldatakse	doc_399014257220_item	2380989	et	3	main
aastate	doc_399014257220_item	2380998	et	3	main
2008	doc_399014257220_item	2381001	et	2	main
meres	doc_399014257220_item	2380705	et	3	main
kujurite	doc_399014257220_item	2380707	et	3	main
hinnangul	doc_399014257220_item	2380709	et	3	main
nõukogudeaegse	doc_399014257220_item	2380719	et	3	main
astusid	doc_399014257220_item	2380724	et	4	main
žürii	doc_399014257220_item	2380736	et	2	main
bürokraatlikkuse	doc_399014257220_item	2380737	et	4	main
ratase	doc_399014257220_item	2380741	et	4	main
komisjoni	doc_399014257220_item	2380744	et	4	main
ainus	doc_399014257220_item	2380745	et	4	main
järele	doc_399014257220_item	2380746	et	4	main
kunstiline	doc_399014257220_item	2380749	et	4	main
kes	doc_399014257220_item	2380753	et	4	main
tauno	doc_399014257220_item	2380766	et	4	main
juba	doc_399014257220_item	2380773	et	3	main
oli	doc_399014257220_item	2380777	et	3	main
kõrge	doc_399014257220_item	2380794	et	4	main
aga	doc_399014257220_item	2380795	et	3	main
linna	doc_399014257220_item	2380796	et	4	main
see	doc_399014257220_item	2380798	et	3	main
kasvas	doc_399014257220_item	2380799	et	3	main
21	doc_399014257220_item	2380800	et	2	main
meetriseks	doc_399014257220_item	2380801	et	4	main
vaatasime	doc_399014257220_item	2380802	et	3	main
kuidas	doc_399014257220_item	2380803	et	3	main
kuju	doc_399014257220_item	2380804	et	4	main
sobib	doc_399014257220_item	2380805	et	3	main
kokku	doc_399014257220_item	2380806	et	3	main
maarjamäe	doc_399014257220_item	2380807	et	3	main
memoriaalkompleksiga	doc_399014257220_item	2380808	et	4	main
tegime	doc_399014257220_item	2380809	et	3	main
arvestusi	doc_399014257220_item	2380810	et	4	main
ja	doc_399014257220_item	2380811	et	3	main
visualiseerisime	doc_399014257220_item	2380812	et	4	main
need	doc_399014257220_item	2380813	et	3	main
otsustasime	doc_399014257220_item	2380814	et	3	main
21	doc_399014257220_item	2380815	et	2	main
meetri	doc_399014257220_item	2380816	et	3	main
poolt	doc_399014257220_item	2380817	et	4	main
see	doc_399014257220_item	2380818	et	3	main
paistaks	doc_399014257220_item	2380819	et	3	main
silma	doc_399014257220_item	2380820	et	4	main
põhjendab	doc_399014257220_item	2380821	et	3	main
arvates	doc_399014257220_item	2380826	et	4	main
sest	doc_399014257220_item	2380832	et	4	main
botaanikaaeda	doc_399014257220_item	2380841	et	4	main
ei	doc_399014257220_item	2380843	et	4	main
piira	doc_399014257220_item	2380844	et	4	main
tauno	doc_399014257220_item	2380848	et	4	main
galerist	doc_399014257220_item	2380862	et	4	main
mägila	doc_399014257220_item	2380864	et	4	main
paati	doc_399014257220_item	2380873	et	4	main
kui	doc_399014257220_item	2380880	et	3	main
kangelase	doc_399014257220_item	2380886	et	3	main
visiooni	doc_399014257220_item	2380890	et	4	main
veel	doc_399014257220_item	2380892	et	4	main
inimkujud	doc_399014257220_item	2380896	et	3	main
kujurite	doc_399014257220_item	2380902	et	3	main
tülis	doc_399014257220_item	2380911	et	4	main
linnaga	doc_399014257220_item	2380912	et	3	main
ka	doc_399014257220_item	2380913	et	3	main
ainuvõimul	doc_399014257220_item	2380921	et	3	main
aselinnapea	doc_399014257220_item	2380822	et	4	main
olga	doc_399014257220_item	2380823	et	4	main
sõtnik	doc_399014257220_item	2380824	et	4	main
asukoht	doc_399014257220_item	2380828	et	3	main
võimalik	doc_399014257220_item	2380831	et	3	main
vanalinna	doc_399014257220_item	2380846	et	4	main
kangro	doc_399014257220_item	2380849	et	4	main
veel	doc_399014257220_item	2380852	et	4	main
õhkkond	doc_399014257220_item	2380855	et	3	main
linnas	doc_399014257220_item	2380860	et	4	main
vaimustunult	doc_399014257220_item	2380866	et	4	main
kus	doc_399014257220_item	2380868	et	3	main
suurte	doc_399014257220_item	2380869	et	3	main
rännanud	doc_399014257220_item	2380883	et	4	main
ümber	doc_399014257220_item	2380884	et	3	main
ühenduse	doc_399014257220_item	2380903	et	4	main
skulptuurtehingut	doc_399014257220_item	2380905	et	3	main
uue	doc_399014257220_item	2380915	et	3	main
ideed	doc_399014257220_item	2380941	et	4	main
osaks	doc_399014257220_item	2380949	et	3	main
legendi	doc_399014257220_item	2380956	et	4	main
ta	doc_399014257220_item	2380975	et	4	main
on	doc_399014257220_item	2380976	et	4	main
kalevipoja	doc_399014257220_item	2380980	et	4	main
avaldatakse	doc_399014257220_item	2380983	et	3	main
abilinnapea	doc_399014257220_item	2380991	et	4	main
sõtniku	doc_399014257220_item	2380992	et	4	main
kavas	doc_399014257220_item	2380996	et	3	main
poolehoidu	doc_399014257220_item	2380928	et	4	main
kunstnike	doc_399014257220_item	2380933	et	3	main
vastu	doc_399014257220_item	2380936	et	3	main
seda	doc_399014257220_item	2380939	et	3	main
aega	doc_399014257220_item	2380943	et	4	main
turustanud	doc_399014257220_item	2380944	et	4	main
keskerakonnaga	doc_399014257220_item	2380947	et	4	main
kriitika	doc_399014257220_item	2380948	et	4	main
järgi	doc_399014257220_item	2380957	et	4	main
ta	doc_399014257220_item	2380958	et	4	main
küll	doc_399014257220_item	2380959	et	4	main
loopis	doc_399014257220_item	2380960	et	3	main
vaenlast	doc_399014257220_item	2380961	et	3	main
suurte	doc_399014257220_item	2380962	et	3	main
kividega	doc_399014257220_item	2380963	et	3	main
aga	doc_399014257220_item	2380964	et	3	main
oli	doc_399014257220_item	2380965	et	3	main
mis	doc_399014257220_item	2380923	et	4	main
näidanud	doc_399014257220_item	2380927	et	4	main
teiste	doc_399014257220_item	2380932	et	4	main
kasvas	doc_399014257220_item	2380937	et	3	main
kui	doc_399014257220_item	2380940	et	3	main
kaua	doc_399014257220_item	2380942	et	3	main
kangro	doc_399014257220_item	2380945	et	4	main
sest	doc_399014257220_item	2380955	et	4	main
sobiv	doc_399014257220_item	2380977	et	4	main
mille	doc_399014257220_item	2380986	et	3	main
näitus	doc_399014257220_item	2380990	et	3	main
kuju	doc_399014257220_item	2380995	et	4	main
neiu	doc_399014257220_item	2380968	et	4	main
meres	doc_399014257220_item	2380970	et	3	main
on	doc_399014257220_item	2380971	et	4	main
küsitud	doc_399014257220_item	2380972	et	4	main
et	doc_399014257220_item	2380973	et	3	main
kas	doc_399014257220_item	2380974	et	3	main
meres	doc_399014257220_item	2380979	et	3	main
tulemused	doc_399014257220_item	2380982	et	3	main
lõpul	doc_399014257220_item	2380985	et	3	main
on	doc_399014257220_item	2380994	et	4	main
2007	doc_399014257220_item	2380999	et	2	main
jooksul	doc_399014257220_item	2381002	et	4	main
loomeühendused	doc_399014257222_item	2381388	et	3	main
viltu	doc_399014257222_item	2381390	et	3	main
kujule	doc_399014257222_item	2381396	et	3	main
vaatavad	doc_399014257222_item	2381399	et	4	main
viltu	doc_399014257222_item	2381400	et	3	main
tallinna	doc_399014257222_item	2381401	et	4	main
hiiglaslikule	doc_399014257222_item	2381394	et	3	main
kalevipoja	doc_399014257222_item	2381395	et	4	main
kavatsusele	doc_399014257222_item	2381403	et	4	main
paneelmaja	doc_399014257222_item	2381407	et	4	main
kõrge	doc_399014257222_item	2381411	et	4	main
samanimelise	doc_399014257222_item	2381413	et	4	main
eesti	doc_399014257222_item	2381414	et	4	main
on	doc_399014257222_item	2381428	et	4	main
kavas	doc_399014257222_item	2381429	et	3	main
püstitada	doc_399014257222_item	2381430	et	3	main
saja	doc_399014257222_item	2381432	et	4	main
kaugusele	doc_399014257222_item	2381434	et	4	main
rajatud	doc_399014257222_item	2381449	et	4	main
paistab	doc_399014257222_item	2381456	et	3	main
suurusest	doc_399014257222_item	2381470	et	4	main
ja	doc_399014257222_item	2381471	et	3	main
hinnangul	doc_399014257222_item	2381477	et	3	main
iseenesest	doc_399014257222_item	2381479	et	4	main
aegunud	doc_399014257222_item	2381481	et	4	main
ja	doc_399014257222_item	2381482	et	3	main
rahvuseepose	doc_399014257222_item	2381483	et	3	main
on	doc_399014257222_item	2381522	et	4	main
vaieldav	doc_399014257222_item	2381532	et	4	main
tauno	doc_399014257222_item	2381534	et	4	main
40	doc_399014257222_item	2381536	et	2	main
tõlge	doc_399014257222_item	2381387	et	3	main
lahte	doc_399014257222_item	2381392	et	4	main
kunstnikud	doc_399014257222_item	2381398	et	3	main
lahte	doc_399014257222_item	2381406	et	4	main
rahvaeepose	doc_399014257222_item	2381415	et	3	main
kangelase	doc_399014257222_item	2381416	et	3	main
järgi	doc_399014257222_item	2381417	et	4	main
linna	doc_399014257222_item	2381402	et	4	main
ainult	doc_399014257222_item	2381424	et	4	main
rannajoonest	doc_399014257222_item	2381435	et	4	main
ajal	doc_399014257222_item	2381448	et	4	main
merele	doc_399014257222_item	2381457	et	3	main
ning	doc_399014257222_item	2381460	et	3	main
linna	doc_399014257222_item	2381462	et	4	main
eriarvamused	doc_399014257222_item	2381466	et	3	main
eesti	doc_399014257222_item	2381474	et	4	main
kangelane	doc_399014257222_item	2381484	et	3	main
juurde	doc_399014257222_item	2381489	et	4	main
maismaaarhitekt	doc_399014257222_item	2381520	et	3	main
kes	doc_399014257222_item	2381521	et	4	main
kalevipoja	doc_399014257222_item	2381539	et	4	main
väikse	doc_399014257222_item	2381549	et	4	main
merineitsiga	doc_399014257222_item	2381550	et	3	main
võrreldav	doc_399014257222_item	2381551	et	4	main
sümbol	doc_399014257222_item	2381552	et	3	main
algses	doc_399014257222_item	2381553	et	3	main
merineitsi	doc_399014257222_item	2381557	et	4	main
kõrge	doc_399014257222_item	2381562	et	4	main
linna	doc_399014257222_item	2381564	et	4	main
21	doc_399014257222_item	2381568	et	2	main
kuju	doc_399014257222_item	2381572	et	4	main
visualiseerisime	doc_399014257222_item	2381580	et	4	main
meetri	doc_399014257222_item	2381584	et	3	main
oli	doc_399014257222_item	2381619	et	3	main
esmaspäevalgi	doc_399014257222_item	2381621	et	4	main
kunstnik	doc_399014257222_item	2381624	et	3	main
aga	doc_399014257222_item	2381629	et	3	main
suurte	doc_399014257222_item	2381637	et	3	main
on	doc_399014257222_item	2381650	et	4	main
rännanud	doc_399014257222_item	2381651	et	4	main
ümber	doc_399014257222_item	2381652	et	3	main
maailma	doc_399014257222_item	2381653	et	4	main
eestlaste	doc_399014257222_item	2381667	et	4	main
ka	doc_399014257222_item	2381674	et	3	main
mis	doc_399014257222_item	2381677	et	4	main
tülis	doc_399014257222_item	2381679	et	4	main
linnaga	doc_399014257222_item	2381680	et	3	main
ka	doc_399014257222_item	2381681	et	3	main
on	doc_399014257222_item	2381688	et	4	main
ainuvõimul	doc_399014257222_item	2381689	et	3	main
ise	doc_399014257222_item	2381722	et	4	main
järgi	doc_399014257222_item	2381725	et	4	main
ka	doc_399014257222_item	2381734	et	3	main
neiu	doc_399014257222_item	2381736	et	4	main
meres	doc_399014257222_item	2381738	et	3	main
on	doc_399014257222_item	2381739	et	4	main
sümbol	doc_399014257222_item	2381746	et	3	main
meres	doc_399014257222_item	2381747	et	3	main
kalevipoja	doc_399014257222_item	2381748	et	4	main
konkursi	doc_399014257222_item	2381749	et	3	main
tulemused	doc_399014257222_item	2381750	et	3	main
jaanuari	doc_399014257222_item	2381752	et	4	main
abilinnapea	doc_399014257222_item	2381759	et	4	main
on	doc_399014257222_item	2381762	et	4	main
helsingi	doc_399014257223_item	2381775	et	4	main
linna	doc_399014257223_item	2381776	et	4	main
muuseum	doc_399014257223_item	2381777	et	3	main
elanike	doc_399014257223_item	2381789	et	3	main
piiri	doc_399014257223_item	2381794	et	4	main
linna	doc_399014257223_item	2381802	et	4	main
vaatavad	doc_399014257222_item	2381389	et	4	main
tallinna	doc_399014257222_item	2381391	et	4	main
kavandatud	doc_399014257222_item	2381393	et	4	main
eesti	doc_399014257222_item	2381397	et	4	main
püstitada	doc_399014257222_item	2381404	et	3	main
21	doc_399014257222_item	2381409	et	2	main
meetrit	doc_399014257222_item	2381410	et	3	main
kalevipoeg	doc_399014257222_item	2381412	et	3	main
tallinna	doc_399014257222_item	2381405	et	4	main
suurune	doc_399014257222_item	2381408	et	4	main
merre	doc_399014257222_item	2381431	et	3	main
tallinnast	doc_399014257222_item	2381436	et	3	main
ääres	doc_399014257222_item	2381445	et	4	main
nõukogude	doc_399014257222_item	2381446	et	3	main
võimu	doc_399014257222_item	2381447	et	4	main
pühendatud	doc_399014257222_item	2381453	et	4	main
memoriaalkompleks	doc_399014257222_item	2381454	et	3	main
millest	doc_399014257222_item	2381455	et	3	main
skulptorite	doc_399014257222_item	2381464	et	3	main
algasid	doc_399014257222_item	2381467	et	4	main
juba	doc_399014257222_item	2381468	et	3	main
kujurite	doc_399014257222_item	2381475	et	3	main
planeerinud	doc_399014257222_item	2381523	et	4	main
idee	doc_399014257222_item	2381527	et	4	main
turustamisega	doc_399014257222_item	2381540	et	4	main
ainult	doc_399014257222_item	2381559	et	4	main
see	doc_399014257222_item	2381566	et	3	main
kuidas	doc_399014257222_item	2381571	et	3	main
sobib	doc_399014257222_item	2381573	et	3	main
kokku	doc_399014257222_item	2381574	et	3	main
maarjamäe	doc_399014257222_item	2381575	et	3	main
memoriaalkompleksiga	doc_399014257222_item	2381576	et	4	main
tegime	doc_399014257222_item	2381577	et	3	main
vaimustunud	doc_399014257222_item	2381622	et	4	main
ise	doc_399014257222_item	2381625	et	4	main
ei	doc_399014257222_item	2381626	et	4	main
vaimustunult	doc_399014257222_item	2381634	et	4	main
kojunaasmist	doc_399014257222_item	2381645	et	3	main
seda	doc_399014257222_item	2381647	et	3	main
kangelase	doc_399014257222_item	2381654	et	3	main
veel	doc_399014257222_item	2381660	et	4	main
mõned	doc_399014257222_item	2381663	et	3	main
mõjuvõimsam	doc_399014257222_item	2381675	et	4	main
näiteks	doc_399014257222_item	2381682	et	4	main
raekoja	doc_399014257222_item	2381684	et	3	main
suhtes	doc_399014257222_item	2381686	et	4	main
mis	doc_399014257222_item	2381691	et	4	main
kividega	doc_399014257222_item	2381731	et	3	main
oli	doc_399014257222_item	2381733	et	3	main
ta	doc_399014257222_item	2381743	et	4	main
on	doc_399014257222_item	2381744	et	4	main
sobiv	doc_399014257222_item	2381745	et	4	main
võitlustöödest	doc_399014257222_item	2381756	et	3	main
korraldatakse	doc_399014257222_item	2381757	et	3	main
aastate	doc_399014257222_item	2381766	et	3	main
ja	doc_399014257222_item	2381768	et	3	main
signe	doc_399014257223_item	2381772	et	4	main
legendaarsest	doc_399014257223_item	2381780	et	3	main
fotograafist	doc_399014257223_item	2381781	et	4	main
raamat	doc_399014257223_item	2381782	et	3	main
aastasada	doc_399014257223_item	2381785	et	4	main
aastal	doc_399014257223_item	2381796	et	3	main
aastas	doc_399014257223_item	2381801	et	3	main
ja	doc_399014257223_item	2381805	et	3	main
arhitektide	doc_399014257223_item	2381808	et	3	main
ja	doc_399014257223_item	2381809	et	3	main
otsustajade	doc_399014257223_item	2381811	et	4	main
silmad	doc_399014257223_item	2381812	et	4	main
sada	doc_399014257223_item	2381813	et	4	main
1906	doc_399014257223_item	2381822	et	2	main
helsingi	doc_399014257223_item	2381825	et	4	main
selle	doc_399014257223_item	2381828	et	4	main
branderi	doc_399014257223_item	2381840	et	4	main
brander	doc_399014257223_item	2381849	et	4	main
907	doc_399014257223_item	2381859	et	2	main
linnamuuseumi	doc_399014257223_item	2381866	et	4	main
helsingi	doc_399014257223_item	2381869	et	4	main
esimese	doc_399014257223_item	2381875	et	3	main
signe	doc_399014257223_item	2381877	et	4	main
branderi	doc_399014257223_item	2381898	et	4	main
helsingi-fotodest	doc_399014257223_item	2381901	et	3	main
pole	doc_399014257223_item	2381904	et	3	main
raamatut	doc_399014257223_item	2381908	et	3	main
ei	doc_399014257223_item	2381910	et	4	main
saa	doc_399014257223_item	2381920	et	4	main
fotoraamatu	doc_399014257223_item	2381925	et	4	main
muisuskaitsekomisjoonis	doc_399014257223_item	2381926	et	4	main
asjatundjad	doc_399014257223_item	2381936	et	3	main
linna	doc_399014257222_item	2381418	et	4	main
korraldatud	doc_399014257222_item	2381419	et	4	main
konkursile	doc_399014257222_item	2381420	et	3	main
oli	doc_399014257222_item	2381421	et	3	main
laekunud	doc_399014257222_item	2381423	et	4	main
kolm	doc_399014257222_item	2381425	et	3	main
kalevipoeg	doc_399014257222_item	2381427	et	3	main
meetri	doc_399014257222_item	2381433	et	3	main
viiva	doc_399014257222_item	2381438	et	4	main
äärde	doc_399014257222_item	2381440	et	4	main
kangelastele	doc_399014257222_item	2381452	et	4	main
kõrge	doc_399014257222_item	2381458	et	4	main
liidu	doc_399014257222_item	2381465	et	3	main
kuju	doc_399014257222_item	2381469	et	4	main
asukohast	doc_399014257222_item	2381472	et	4	main
meres	doc_399014257222_item	2381473	et	3	main
ei	doc_399014257222_item	2381485	et	4	main
tähtajaks	doc_399014257222_item	2381422	et	3	main
ideeprojekti	doc_399014257222_item	2381426	et	4	main
piritale	doc_399014257222_item	2381437	et	4	main
rannatee	doc_399014257222_item	2381439	et	4	main
samal	doc_399014257222_item	2381441	et	3	main
kohal	doc_399014257222_item	2381442	et	4	main
on	doc_399014257222_item	2381443	et	4	main
kalda	doc_399014257222_item	2381444	et	3	main
teise	doc_399014257222_item	2381450	et	4	main
maailmasõja	doc_399014257222_item	2381451	et	3	main
obelisk	doc_399014257222_item	2381459	et	3	main
rannatrepp	doc_399014257222_item	2381461	et	3	main
ja	doc_399014257222_item	2381463	et	3	main
ühenduse	doc_399014257222_item	2381476	et	4	main
idee	doc_399014257222_item	2381478	et	4	main
on	doc_399014257222_item	2381480	et	4	main
sobi	doc_399014257222_item	2381486	et	4	main
nõukogudeaegse	doc_399014257222_item	2381487	et	3	main
memoriaalkompleksi	doc_399014257222_item	2381488	et	4	main
varem	doc_399014257222_item	2381490	et	4	main
sügisel	doc_399014257222_item	2381491	et	3	main
astusid	doc_399014257222_item	2381492	et	4	main
nii	doc_399014257222_item	2381493	et	3	main
skulptorite	doc_399014257222_item	2381494	et	3	main
kui	doc_399014257222_item	2381495	et	3	main
ka	doc_399014257222_item	2381496	et	3	main
arhitektide	doc_399014257222_item	2381497	et	3	main
ühenduste	doc_399014257222_item	2381498	et	4	main
esindajad	doc_399014257222_item	2381499	et	4	main
ideekonkursi	doc_399014257222_item	2381500	et	3	main
komisjonist	doc_399014257222_item	2381501	et	3	main
tagasi	doc_399014257222_item	2381502	et	3	main
protestides	doc_399014257222_item	2381503	et	4	main
žürii	doc_399014257222_item	2381504	et	2	main
bürokraatlikkuse	doc_399014257222_item	2381505	et	4	main
vastu	doc_399014257222_item	2381506	et	3	main
linnapea	doc_399014257222_item	2381507	et	4	main
jüri	doc_399014257222_item	2381508	et	4	main
ratase	doc_399014257222_item	2381509	et	4	main
32	doc_399014257222_item	2381510	et	2	main
juhitud	doc_399014257222_item	2381511	et	4	main
komisjoni	doc_399014257222_item	2381512	et	4	main
ainus	doc_399014257222_item	2381513	et	4	main
järele	doc_399014257222_item	2381514	et	4	main
jäänud	doc_399014257222_item	2381515	et	4	main
sõltumatu	doc_399014257222_item	2381516	et	4	main
kunstiline	doc_399014257222_item	2381517	et	4	main
liige	doc_399014257222_item	2381518	et	4	main
on	doc_399014257222_item	2381519	et	4	main
linna	doc_399014257222_item	2381524	et	4	main
algupärase	doc_399014257222_item	2381526	et	4	main
isa	doc_399014257222_item	2381528	et	4	main
on	doc_399014257222_item	2381529	et	4	main
1990ndate	doc_399014257222_item	2381542	et	4	main
lõpul	doc_399014257222_item	2381543	et	3	main
ideeks	doc_399014257222_item	2381544	et	3	main
tallinnale	doc_399014257222_item	2381547	et	4	main
kopenhaageni	doc_399014257222_item	2381548	et	4	main
tallinna	doc_399014257222_item	2381555	et	4	main
14	doc_399014257222_item	2381560	et	2	main
aga	doc_399014257222_item	2381563	et	3	main
arvestusi	doc_399014257222_item	2381578	et	4	main
poolt	doc_399014257222_item	2381585	et	4	main
paistaks	doc_399014257222_item	2381587	et	3	main
see	doc_399014257222_item	2381586	et	3	main
silma	doc_399014257222_item	2381588	et	4	main
põhjendab	doc_399014257222_item	2381589	et	3	main
aselinnapea	doc_399014257222_item	2381590	et	4	main
olga	doc_399014257222_item	2381591	et	4	main
sõtnik	doc_399014257222_item	2381592	et	4	main
sõtniku	doc_399014257222_item	2381593	et	4	main
arvates	doc_399014257222_item	2381594	et	4	main
ka	doc_399014257222_item	2381595	et	3	main
asukoht	doc_399014257222_item	2381596	et	3	main
on	doc_399014257222_item	2381597	et	4	main
parim	doc_399014257222_item	2381598	et	4	main
võimalik	doc_399014257222_item	2381599	et	3	main
sest	doc_399014257222_item	2381600	et	4	main
see	doc_399014257222_item	2381601	et	3	main
jääb	doc_399014257222_item	2381602	et	3	main
turistimarsruudi	doc_399014257222_item	2381603	et	3	main
äärde	doc_399014257222_item	2381604	et	4	main
teel	doc_399014257222_item	2381605	et	4	main
pirita	doc_399014257222_item	2381606	et	4	main
sanatooriumisse	doc_399014257222_item	2381607	et	3	main
või	doc_399014257222_item	2381608	et	4	main
botaanikaaeda	doc_399014257222_item	2381609	et	4	main
see	doc_399014257222_item	2381610	et	3	main
ei	doc_399014257222_item	2381611	et	4	main
piira	doc_399014257222_item	2381612	et	4	main
ka	doc_399014257222_item	2381613	et	3	main
vanalinna	doc_399014257222_item	2381614	et	4	main
siluetti	doc_399014257222_item	2381615	et	4	main
tauno	doc_399014257222_item	2381616	et	4	main
parke	doc_399014257222_item	2381525	et	3	main
siiski	doc_399014257222_item	2381530	et	4	main
kunstnik	doc_399014257222_item	2381531	et	3	main
skulptor	doc_399014257222_item	2381533	et	3	main
kangro	doc_399014257222_item	2381535	et	4	main
juba	doc_399014257222_item	2381541	et	3	main
kujundada	doc_399014257222_item	2381546	et	3	main
kavandis	doc_399014257222_item	2381554	et	3	main
väike	doc_399014257222_item	2381556	et	4	main
meetrit	doc_399014257222_item	2381561	et	3	main
kasvas	doc_399014257222_item	2381567	et	3	main
vaatasime	doc_399014257222_item	2381570	et	3	main
ja	doc_399014257222_item	2381579	et	3	main
21	doc_399014257222_item	2381583	et	2	main
ateljees	doc_399014257222_item	2381618	et	3	main
veel	doc_399014257222_item	2381620	et	4	main
mägila	doc_399014257222_item	2381632	et	4	main
tutvustas	doc_399014257222_item	2381633	et	3	main
kätega	doc_399014257222_item	2381638	et	3	main
kalevipoeg	doc_399014257222_item	2381639	et	3	main
skulptuur	doc_399014257222_item	2381642	et	3	main
pärast	doc_399014257222_item	2381646	et	4	main
kui	doc_399014257222_item	2381648	et	3	main
käes	doc_399014257222_item	2381655	et	4	main
tulemusena	doc_399014257222_item	2381659	et	3	main
paat	doc_399014257222_item	2381661	et	3	main
kes	doc_399014257222_item	2381665	et	4	main
sümboliseerivad	doc_399014257222_item	2381666	et	4	main
skulptuurtehingut	doc_399014257222_item	2381673	et	3	main
arhitektideliit	doc_399014257222_item	2381676	et	4	main
on	doc_399014257222_item	2381678	et	4	main
uue	doc_399014257222_item	2381683	et	3	main
asukoha	doc_399014257222_item	2381685	et	4	main
tallinnas	doc_399014257222_item	2381687	et	4	main
ta	doc_399014257222_item	2381726	et	4	main
küll	doc_399014257222_item	2381727	et	4	main
loopis	doc_399014257222_item	2381728	et	3	main
vaenlast	doc_399014257222_item	2381729	et	3	main
suurte	doc_399014257222_item	2381730	et	3	main
avaldatakse	doc_399014257222_item	2381751	et	3	main
lõpul	doc_399014257222_item	2381753	et	3	main
2007	doc_399014257222_item	2381767	et	2	main
2008	doc_399014257222_item	2381769	et	2	main
tõlge	doc_399014257223_item	2381771	et	3	main
raamatu	doc_399014257223_item	2381779	et	4	main
viib	doc_399014257223_item	2381783	et	3	main
helsingisse	doc_399014257223_item	2381787	et	4	main
helsingi	doc_399014257223_item	2381788	et	4	main
arv	doc_399014257223_item	2381790	et	3	main
000	doc_399014257223_item	2381793	et	2	main
oli	doc_399014257223_item	2381798	et	3	main
tohutu	doc_399014257223_item	2381803	et	4	main
kes	doc_399014257222_item	2381537	et	4	main
alustas	doc_399014257222_item	2381538	et	3	main
oli	doc_399014257222_item	2381545	et	3	main
oli	doc_399014257222_item	2381558	et	3	main
ettepanekul	doc_399014257222_item	2381565	et	3	main
meetriseks	doc_399014257222_item	2381569	et	4	main
need	doc_399014257222_item	2381581	et	3	main
otsustasime	doc_399014257222_item	2381582	et	3	main
kangro	doc_399014257222_item	2381617	et	4	main
õhkkond	doc_399014257222_item	2381623	et	3	main
pronkskuju	doc_399014257222_item	2381635	et	4	main
tassib	doc_399014257222_item	2381640	et	3	main
sümboliseerib	doc_399014257222_item	2381643	et	3	main
ta	doc_399014257222_item	2381649	et	4	main
on	doc_399014257222_item	2381656	et	4	main
visiooni	doc_399014257222_item	2381658	et	4	main
ja	doc_399014257222_item	2381662	et	3	main
inimkujud	doc_399014257222_item	2381664	et	3	main
boikoteerib	doc_399014257222_item	2381672	et	3	main
on	doc_399014257222_item	2381692	et	4	main
ka	doc_399014257222_item	2381693	et	3	main
varem	doc_399014257222_item	2381694	et	4	main
poolehoidu	doc_399014257222_item	2381696	et	4	main
näidanud	doc_399014257222_item	2381695	et	4	main
kõrgete	doc_399014257222_item	2381697	et	4	main
ehituste	doc_399014257222_item	2381698	et	4	main
vastu	doc_399014257222_item	2381699	et	3	main
teiste	doc_399014257222_item	2381700	et	4	main
kunstnike	doc_399014257222_item	2381701	et	3	main
kriitika	doc_399014257222_item	2381702	et	4	main
skulptuurtehingu	doc_399014257222_item	2381703	et	3	main
vastu	doc_399014257222_item	2381704	et	3	main
kasvas	doc_399014257222_item	2381705	et	3	main
pärast	doc_399014257222_item	2381706	et	4	main
seda	doc_399014257222_item	2381707	et	3	main
kui	doc_399014257222_item	2381708	et	3	main
ideed	doc_399014257222_item	2381709	et	4	main
kaua	doc_399014257222_item	2381710	et	3	main
aega	doc_399014257222_item	2381711	et	4	main
turustanud	doc_399014257222_item	2381712	et	4	main
kangro	doc_399014257222_item	2381713	et	4	main
liitus	doc_399014257222_item	2381714	et	4	main
keskerakonnaga	doc_399014257222_item	2381715	et	4	main
kriitika	doc_399014257222_item	2381716	et	4	main
osaks	doc_399014257222_item	2381717	et	3	main
on	doc_399014257222_item	2381718	et	4	main
saanud	doc_399014257222_item	2381719	et	4	main
ka	doc_399014257222_item	2381720	et	3	main
olnud	doc_399014257222_item	2381627	et	4	main
linnas	doc_399014257222_item	2381628	et	4	main
galerist	doc_399014257222_item	2381630	et	4	main
pille	doc_399014257222_item	2381631	et	3	main
kus	doc_399014257222_item	2381636	et	3	main
paati	doc_399014257222_item	2381641	et	4	main
kangelase	doc_399014257222_item	2381644	et	3	main
kunstniku	doc_399014257222_item	2381657	et	3	main
kojutulekut	doc_399014257222_item	2381668	et	3	main
peale	doc_399014257222_item	2381669	et	4	main
kujurite	doc_399014257222_item	2381670	et	3	main
ühenduse	doc_399014257222_item	2381671	et	4	main
keskerakond	doc_399014257222_item	2381690	et	3	main
kalevipoeg	doc_399014257222_item	2381721	et	3	main
sest	doc_399014257222_item	2381723	et	4	main
legendi	doc_399014257222_item	2381724	et	4	main
aga	doc_399014257222_item	2381732	et	3	main
süüdlane	doc_399014257222_item	2381735	et	3	main
vägistamises	doc_399014257222_item	2381737	et	4	main
küsitud	doc_399014257222_item	2381740	et	4	main
et	doc_399014257222_item	2381741	et	3	main
kas	doc_399014257222_item	2381742	et	3	main
järel	doc_399014257222_item	2381755	et	4	main
näitus	doc_399014257222_item	2381758	et	3	main
sõtniku	doc_399014257222_item	2381760	et	4	main
järgi	doc_399014257222_item	2381761	et	4	main
branderi	doc_399014257223_item	2381773	et	4	main
helsingi	doc_399014257223_item	2381774	et	4	main
ringkäikule	doc_399014257223_item	2381784	et	4	main
tagusesse	doc_399014257223_item	2381786	et	4	main
100	doc_399014257223_item	2381792	et	2	main
1902	doc_399014257223_item	2381795	et	2	main
kolmekordistunud	doc_399014257223_item	2381799	et	4	main
muutumine	doc_399014257223_item	2381806	et	4	main
jaoks	doc_399014257223_item	2381829	et	4	main
muinsuskaitsekomisjoon	doc_399014257223_item	2381832	et	4	main
fotograaf	doc_399014257223_item	2381838	et	4	main
aastat	doc_399014257223_item	2381854	et	3	main
töö	doc_399014257223_item	2381856	et	4	main
sai	doc_399014257223_item	2381858	et	4	main
andnud	doc_399014257223_item	2381873	et	4	main
on	doc_399014257223_item	2381895	et	4	main
helsingi	doc_399014257223_item	2381902	et	4	main
avaltatud	doc_399014257223_item	2381906	et	4	main
oleks	doc_399014257223_item	2381911	et	3	main
branderi	doc_399014257223_item	2381914	et	4	main
fotod	doc_399014257223_item	2381915	et	3	main
mille	doc_399014257222_item	2381754	et	3	main
kuju	doc_399014257222_item	2381763	et	4	main
kavas	doc_399014257222_item	2381764	et	3	main
püstitada	doc_399014257222_item	2381765	et	3	main
jooksul	doc_399014257222_item	2381770	et	4	main
koostis	doc_399014257223_item	2381778	et	4	main
ületas	doc_399014257223_item	2381791	et	3	main
see	doc_399014257223_item	2381797	et	3	main
30	doc_399014257223_item	2381800	et	2	main
kasv	doc_399014257223_item	2381804	et	3	main
avas	doc_399014257223_item	2381807	et	4	main
helsingi	doc_399014257223_item	2381810	et	4	main
aasta	doc_399014257223_item	2381814	et	4	main
tagasi	doc_399014257223_item	2381815	et	3	main
et	doc_399014257223_item	2381816	et	3	main
säilitada	doc_399014257223_item	2381817	et	3	main
midagi	doc_399014257223_item	2381818	et	4	main
kaduvade	doc_399014257223_item	2381819	et	4	main
puumajade	doc_399014257223_item	2381820	et	3	main
otsustas	doc_399014257223_item	2381824	et	3	main
linnavalitsus	doc_399014257223_item	2381826	et	3	main
on	doc_399014257223_item	2381843	et	4	main
hiljem	doc_399014257223_item	2381844	et	3	main
targaks	doc_399014257223_item	2381845	et	3	main
ja	doc_399014257223_item	2381846	et	3	main
millest	doc_399014257223_item	2381861	et	3	main
ikka	doc_399014257223_item	2381863	et	4	main
nüüd	doc_399014257223_item	2381872	et	4	main
raamatu	doc_399014257223_item	2381876	et	4	main
branderi	doc_399014257223_item	2381878	et	4	main
fotodest	doc_399014257223_item	2381879	et	3	main
põhinedes	doc_399014257223_item	2381880	et	3	main
ainult	doc_399014257223_item	2381881	et	4	main
tema	doc_399014257223_item	2381882	et	4	main
fotodel	doc_399014257223_item	2381883	et	3	main
fotograaf	doc_399014257223_item	2381884	et	4	main
jan	doc_399014257223_item	2381885	et	4	main
alanco	doc_399014257223_item	2381886	et	4	main
riitta	doc_399014257223_item	2381889	et	4	main
parimadest	doc_399014257223_item	2381900	et	4	main
ajaloost	doc_399014257223_item	2381903	et	4	main
1900aastade	doc_399014257223_item	2381916	et	4	main
algusest	doc_399014257223_item	2381917	et	4	main
said	doc_399014257223_item	2381927	et	4	main
aja	doc_399014257223_item	2381930	et	4	main
kultuuriajaloo	doc_399014257223_item	2381935	et	4	main
professor	doc_399014257223_item	2381940	et	3	main
kes	doc_399014257223_item	2381943	et	4	main
pildistamispaigadest	doc_399014257223_item	2381952	et	4	main
milles	doc_399014257223_item	2381953	et	3	main
ehitama	doc_399014257223_item	2381969	et	4	main
sajandi	doc_399014257223_item	2381973	et	3	main
puumajad	doc_399014257223_item	2381979	et	3	main
kõrgede	doc_399014257223_item	2381982	et	4	main
brander	doc_399014257223_item	2381992	et	4	main
temal	doc_399014257223_item	2381996	et	3	main
sündinud	doc_399014257223_item	2382008	et	4	main
seevastu	doc_399014257223_item	2382020	et	3	main
ateljees	doc_399014257223_item	2382030	et	3	main
oli	doc_399014257223_item	2382032	et	3	main
ka	doc_399014257223_item	2382034	et	3	main
selleaegse	doc_399014257223_item	2382043	et	3	main
linna	doc_399014257223_item	2382046	et	4	main
maastikuid	doc_399014257223_item	2382048	et	4	main
ta	doc_399014257223_item	2382051	et	4	main
saladus	doc_399014257223_item	2382064	et	3	main
ligikaudu	doc_399014257223_item	2382068	et	3	main
koduloomi	doc_399014257223_item	2382075	et	4	main
köögivili	doc_399014257223_item	2382082	et	3	main
on	doc_399014257223_item	2382085	et	4	main
oli	doc_399014257223_item	2382116	et	3	main
midagi	doc_399014257223_item	2382118	et	4	main
haruldane	doc_399014257223_item	2382123	et	3	main
kulgev	doc_399014257223_item	2382130	et	4	main
koer	doc_399014257223_item	2382131	et	3	main
hobune	doc_399014257223_item	2382138	et	4	main
aastal	doc_399014257223_item	2381823	et	3	main
tuleks	doc_399014257223_item	2381830	et	4	main
mis	doc_399014257223_item	2381833	et	4	main
aastal	doc_399014257223_item	2381836	et	3	main
kaugeleulatuvaks	doc_399014257223_item	2381847	et	3	main
kiitatud	doc_399014257223_item	2381848	et	4	main
pildistas	doc_399014257223_item	2381850	et	3	main
helsingi	doc_399014257223_item	2381851	et	4	main
umbes	doc_399014257223_item	2381852	et	4	main
seitsme	doc_399014257223_item	2381853	et	3	main
linnast	doc_399014257223_item	2381821	et	4	main
et	doc_399014257223_item	2381827	et	3	main
rajada	doc_399014257223_item	2381831	et	3	main
palkas	doc_399014257223_item	2381834	et	3	main
järgmisel	doc_399014257223_item	2381835	et	3	main
tööle	doc_399014257223_item	2381837	et	3	main
signe	doc_399014257223_item	2381839	et	4	main
1869-1942	doc_399014257223_item	2381841	et	2	main
otsust	doc_399014257223_item	2381842	et	4	main
fotot	doc_399014257223_item	2381860	et	3	main
linnamuuseum	doc_399014257223_item	2381870	et	3	main
on	doc_399014257223_item	2381871	et	4	main
ja	doc_399014257223_item	2381887	et	3	main
on	doc_399014257223_item	2381891	et	4	main
umbes	doc_399014257223_item	2381896	et	4	main
sada	doc_399014257223_item	2381897	et	4	main
ilmselt	doc_399014257223_item	2381905	et	4	main
milles	doc_399014257223_item	2381909	et	3	main
vähemalt	doc_399014257223_item	2381912	et	4	main
mõni	doc_399014257223_item	2381913	et	3	main
nüüd	doc_399014257223_item	2381919	et	4	main
esimest	doc_399014257223_item	2381922	et	4	main
kokku	doc_399014257223_item	2381928	et	3	main
kõige	doc_399014257223_item	2381931	et	4	main
parimad	doc_399014257223_item	2381932	et	4	main
linnapildi	doc_399014257223_item	2381933	et	4	main
ja	doc_399014257223_item	2381934	et	3	main
hulgas	doc_399014257223_item	2381938	et	4	main
gustaf	doc_399014257223_item	2381941	et	4	main
andis	doc_399014257223_item	2381949	et	3	main
hakati	doc_399014257223_item	2381968	et	3	main
oli	doc_399014257223_item	2381988	et	3	main
et	doc_399014257223_item	2381990	et	3	main
signe	doc_399014257223_item	2381991	et	4	main
valiti	doc_399014257223_item	2381993	et	3	main
helsingi	doc_399014257223_item	2381994	et	4	main
juba	doc_399014257223_item	2381998	et	3	main
maastikufotograafina	doc_399014257223_item	2382005	et	4	main
parkanos	doc_399014257223_item	2382009	et	4	main
helsingis	doc_399014257223_item	2382012	et	4	main
õpetajaks	doc_399014257223_item	2382014	et	4	main
aga	doc_399014257223_item	2382015	et	3	main
ei	doc_399014257223_item	2382016	et	4	main
kunagi	doc_399014257223_item	2382017	et	3	main
töötanud	doc_399014257223_item	2382018	et	4	main
välja	doc_399014257223_item	2382040	et	4	main
väga	doc_399014257223_item	2382049	et	3	main
jäänud	doc_399014257223_item	2382053	et	4	main
ja	doc_399014257223_item	2382058	et	3	main
tema	doc_399014257223_item	2382061	et	4	main
lapsi	doc_399014257223_item	2382071	et	4	main
või	doc_399014257223_item	2382074	et	4	main
uut	doc_399014257223_item	2382119	et	3	main
1907-1913	doc_399014257223_item	2381855	et	2	main
tulemuseks	doc_399014257223_item	2381857	et	3	main
koosneb	doc_399014257223_item	2381862	et	3	main
veel	doc_399014257223_item	2381864	et	4	main
helsingi	doc_399014257223_item	2381865	et	4	main
fotoarhiivi	doc_399014257223_item	2381867	et	4	main
süda	doc_399014257223_item	2381868	et	3	main
välja	doc_399014257223_item	2381874	et	4	main
uurija	doc_399014257223_item	2381888	et	4	main
pakarinen	doc_399014257223_item	2381890	et	4	main
koostanud	doc_399014257223_item	2381892	et	4	main
raamatu	doc_399014257223_item	2381893	et	4	main
milles	doc_399014257223_item	2381894	et	3	main
kõige	doc_399014257223_item	2381899	et	4	main
mittu	doc_399014257223_item	2381907	et	4	main
aga	doc_399014257223_item	2381918	et	3	main
tema	doc_399014257223_item	2381921	et	4	main
korda	doc_399014257223_item	2381923	et	4	main
oma	doc_399014257223_item	2381924	et	4	main
nende	doc_399014257223_item	2381937	et	4	main
koostamist	doc_399014257223_item	2381947	et	4	main
komisjoon	doc_399014257223_item	2381948	et	4	main
ja	doc_399014257223_item	2381965	et	3	main
linnaosa	doc_399014257223_item	2381967	et	4	main
linna	doc_399014257223_item	2381971	et	4	main
hakkasid	doc_399014257223_item	2381980	et	4	main
ja	doc_399014257223_item	2382003	et	3	main
õppis	doc_399014257223_item	2382011	et	3	main
sai	doc_399014257223_item	2382021	et	4	main
sellest	doc_399014257223_item	2382031	et	4	main
temal	doc_399014257223_item	2382033	et	3	main
kogemust	doc_399014257223_item	2382035	et	3	main
fotograafateljeedest	doc_399014257223_item	2382037	et	4	main
tema	doc_399014257223_item	2382038	et	4	main
tahtis	doc_399014257223_item	2382039	et	3	main
oskuslikult	doc_399014257223_item	2382050	et	4	main
üksikasjad	doc_399014257223_item	2382059	et	3	main
piltidel	doc_399014257223_item	2382066	et	3	main
on	doc_399014257223_item	2382067	et	4	main
alati	doc_399014257223_item	2382069	et	4	main
politseinikke	doc_399014257223_item	2382073	et	3	main
sada	doc_399014257223_item	2382076	et	4	main
aasta	doc_399014257223_item	2382077	et	4	main
tagasi	doc_399014257223_item	2382078	et	3	main
maastikufotograafina	doc_399014257223_item	2382122	et	4	main
vahel	doc_399014257223_item	2382124	et	4	main
ilma	doc_399014257223_item	2382135	et	4	main
viib	doc_399014257223_item	2382145	et	3	main
ja	doc_399014257223_item	2382157	et	3	main
kampi	doc_399014257223_item	2382166	et	4	main
töölösse	doc_399014257223_item	2382168	et	3	main
pild	doc_399014257223_item	2382179	et	3	main
tehtud	doc_399014257223_item	2382181	et	4	main
on	doc_399014257223_item	2382185	et	4	main
äratundmatuks	doc_399014257223_item	2382197	et	4	main
näiteks	doc_399014257223_item	2382198	et	4	main
1913	doc_399014257223_item	2382218	et	2	main
selle	doc_399014257223_item	2381929	et	4	main
arhitekt	doc_399014257223_item	2381939	et	3	main
helsingi	doc_399014257223_item	2381945	et	4	main
branderile	doc_399014257223_item	2381950	et	4	main
kavatseti	doc_399014257223_item	2381954	et	3	main
olulisi	doc_399014257223_item	2381955	et	4	main
muutusi	doc_399014257223_item	2381956	et	4	main
helsingi	doc_399014257223_item	2381957	et	4	main
kasvas	doc_399014257223_item	2381958	et	3	main
ja	doc_399014257223_item	2381959	et	3	main
muutus	doc_399014257223_item	2381960	et	4	main
väledalt	doc_399014257223_item	2381961	et	4	main
1900aastade	doc_399014257223_item	2381962	et	4	main
alguses	doc_399014257223_item	2381963	et	4	main
töölö	doc_399014257223_item	2381964	et	4	main
nyström	doc_399014257223_item	2381942	et	4	main
juhtis	doc_399014257223_item	2381944	et	3	main
üldplaani	doc_399014257223_item	2381946	et	4	main
plaani	doc_399014257223_item	2381951	et	4	main
eira	doc_399014257223_item	2381966	et	4	main
ja	doc_399014257223_item	2381970	et	3	main
19	doc_399014257223_item	2381972	et	2	main
ehitatud	doc_399014257223_item	2381975	et	4	main
ühe-	doc_399014257223_item	2381976	et	4	main
ja	doc_399014257223_item	2381977	et	3	main
kahekorrulised	doc_399014257223_item	2381978	et	4	main
kaduma	doc_399014257223_item	2381981	et	4	main
kivimüüride	doc_399014257223_item	2381983	et	4	main
pakarise	doc_399014257223_item	2381986	et	4	main
oli	doc_399014257223_item	2381997	et	3	main
pildistamise	doc_399014257223_item	2382000	et	4	main
lõpus	doc_399014257223_item	2381974	et	4	main
eest	doc_399014257223_item	2381984	et	4	main
riitta	doc_399014257223_item	2381985	et	4	main
sõnul	doc_399014257223_item	2381987	et	3	main
enesestmõistetatav	doc_399014257223_item	2381989	et	4	main
fotograafiks	doc_399014257223_item	2381995	et	4	main
tõestust	doc_399014257223_item	2381999	et	4	main
oskamise	doc_399014257223_item	2382001	et	4	main
kohta	doc_399014257223_item	2382002	et	4	main
eriti	doc_399014257223_item	2382004	et	3	main
brander	doc_399014257223_item	2382006	et	4	main
oli	doc_399014257223_item	2382007	et	3	main
ja	doc_399014257223_item	2382010	et	3	main
joonestamise	doc_399014257223_item	2382013	et	4	main
õpetajana	doc_399014257223_item	2382019	et	4	main
kellele	doc_399014257223_item	2382024	et	4	main
ei	doc_399014257223_item	2382025	et	4	main
meeldinud	doc_399014257223_item	2382026	et	4	main
portree-fotograafimine	doc_399014257223_item	2382027	et	4	main
ega	doc_399014257223_item	2382028	et	3	main
brander	doc_399014257223_item	2382041	et	4	main
arenematu	doc_399014257223_item	2382044	et	4	main
tehniikaga	doc_399014257223_item	2382045	et	4	main
olid	doc_399014257223_item	2382060	et	4	main
elavuse	doc_399014257223_item	2382063	et	4	main
tema	doc_399014257223_item	2382065	et	4	main
kaupmehi	doc_399014257223_item	2382072	et	3	main
kasvatasid	doc_399014257223_item	2382079	et	4	main
helsinglastele	doc_399014257223_item	2382083	et	3	main
veel	doc_399014257223_item	2382117	et	4	main
ja	doc_399014257223_item	2382120	et	3	main
on	doc_399014257223_item	2382125	et	4	main
trammirööbaste	doc_399014257223_item	2382128	et	3	main
või	doc_399014257223_item	2382132	et	4	main
keskel	doc_399014257223_item	2382133	et	3	main
hoovi	doc_399014257223_item	2382134	et	4	main
seisav	doc_399014257223_item	2382137	et	4	main
piltid	doc_399014257223_item	2382139	et	4	main
on	doc_399014257223_item	2382140	et	4	main
järjestatud	doc_399014257223_item	2382141	et	4	main
raamatusse	doc_399014257223_item	2382142	et	4	main
mis	doc_399014257223_item	2382144	et	4	main
lugeja	doc_399014257223_item	2382146	et	4	main
linnaosade	doc_399014257223_item	2382159	et	4	main
viib	doc_399014257223_item	2382164	et	3	main
kõrval	doc_399014257223_item	2382171	et	4	main
on	doc_399014257223_item	2382172	et	4	main
mis	doc_399014257223_item	2382176	et	4	main
vaatevinkel	doc_399014257223_item	2382186	et	3	main
nüüdislugejale	doc_399014257223_item	2382189	et	3	main
linn	doc_399014257223_item	2382192	et	3	main
töölö	doc_399014257223_item	2382199	et	4	main
piltide	doc_399014257223_item	2382203	et	3	main
maakohta	doc_399014257223_item	2382205	et	4	main
helsinglastele	doc_399014257223_item	2382210	et	3	main
branderi	doc_399014257223_item	2382211	et	4	main
ja	doc_399014257223_item	2382212	et	3	main
muinsuskaitsekomisjooni	doc_399014257223_item	2382213	et	4	main
erimeeldusi	doc_399014257223_item	2382216	et	4	main
protokollidest	doc_399014257223_item	2382219	et	4	main
oli	doc_399014257223_item	2382223	et	3	main
põhjus	doc_399014257223_item	2382225	et	4	main
lihtsalt	doc_399014257223_item	2382232	et	4	main
raha	doc_399014257223_item	2382233	et	4	main
linnamuuseum	doc_399014257223_item	2382234	et	3	main
võttis	doc_399014257223_item	2382235	et	3	main
puhkemine	doc_399014257223_item	2382244	et	4	main
lõpetas	doc_399014257223_item	2382247	et	3	main
algas	doc_399014257223_item	2382253	et	3	main
alles	doc_399014257223_item	2382255	et	3	main
oma	doc_399014257223_item	2382258	et	4	main
fotograafi	doc_399014257223_item	2382260	et	4	main
sai	doc_399014257223_item	2382261	et	4	main
linnamuuseum	doc_399014257223_item	2382262	et	3	main
alles	doc_399014257223_item	2382263	et	3	main
aastal	doc_399014257223_item	2382264	et	3	main
aastadel	doc_399014257223_item	2382278	et	4	main
tõttu	doc_399014257223_item	2382286	et	4	main
üle	doc_399014257223_item	2382300	et	3	main
on	doc_399014257223_item	2382311	et	4	main
ka	doc_399014257223_item	2382312	et	3	main
temast	doc_399014257223_item	2382022	et	3	main
fotograaf	doc_399014257223_item	2382023	et	4	main
töötamine	doc_399014257223_item	2382029	et	4	main
helsingi	doc_399014257223_item	2382036	et	4	main
pildistas	doc_399014257223_item	2382042	et	3	main
ja	doc_399014257223_item	2382047	et	3	main
ei	doc_399014257223_item	2382052	et	4	main
rahule	doc_399014257223_item	2382054	et	4	main
hingetu	doc_399014257223_item	2382055	et	4	main
arhitektuuripildistamisega	doc_399014257223_item	2382056	et	3	main
inimesed	doc_399014257223_item	2382057	et	3	main
piltide	doc_399014257223_item	2382062	et	3	main
mõõdujaid	doc_399014257223_item	2382070	et	4	main
venelased	doc_399014257223_item	2382080	et	3	main
töölös	doc_399014257223_item	2382081	et	4	main
tihti	doc_399014257223_item	2382084	et	3	main
pildile	doc_399014257223_item	2382086	et	3	main
saanud	doc_399014257223_item	2382087	et	4	main
inimesed	doc_399014257223_item	2382088	et	3	main
sattunud	doc_399014257223_item	2382089	et	4	main
kohale	doc_399014257223_item	2382090	et	4	main
täiesti	doc_399014257223_item	2382091	et	3	main
juhuslikult	doc_399014257223_item	2382092	et	4	main
brander	doc_399014257223_item	2382093	et	4	main
on	doc_399014257223_item	2382094	et	4	main
palunud	doc_399014257223_item	2382095	et	4	main
nendele	doc_399014257223_item	2382096	et	4	main
hetkeks	doc_399014257223_item	2382097	et	4	main
pildile	doc_399014257223_item	2382098	et	3	main
seisma	doc_399014257223_item	2382099	et	3	main
jääda	doc_399014257223_item	2382100	et	4	main
inimeste	doc_399014257223_item	2382101	et	3	main
heast	doc_399014257223_item	2382102	et	3	main
tujust	doc_399014257223_item	2382103	et	3	main
võib	doc_399014257223_item	2382104	et	3	main
järeldades	doc_399014257223_item	2382105	et	3	main
oskas	doc_399014257223_item	2382106	et	3	main
brander	doc_399014257223_item	2382107	et	4	main
esitada	doc_399014257223_item	2382108	et	3	main
oma	doc_399014257223_item	2382109	et	4	main
asi	doc_399014257223_item	2382110	et	4	main
ja	doc_399014257223_item	2382111	et	3	main
äratas	doc_399014257223_item	2382112	et	3	main
helsinglaste	doc_399014257223_item	2382113	et	3	main
uudishimu	doc_399014257223_item	2382114	et	4	main
pildistamine	doc_399014257223_item	2382115	et	4	main
ergutav	doc_399014257223_item	2382126	et	4	main
aastasaja	doc_399014257223_item	2382148	et	4	main
helsingisse	doc_399014257223_item	2382150	et	4	main
ekskursioon	doc_399014257223_item	2382151	et	3	main
algab	doc_399014257223_item	2382152	et	3	main
hermanni	doc_399014257223_item	2382153	et	4	main
tagusesse	doc_399014257223_item	2382149	et	4	main
linnaosast	doc_399014257223_item	2382154	et	4	main
viib	doc_399014257223_item	2382155	et	3	main
naine	doc_399014257223_item	2382121	et	3	main
detail	doc_399014257223_item	2382127	et	3	main
järel	doc_399014257223_item	2382129	et	4	main
rakmeid	doc_399014257223_item	2382136	et	3	main
kruunuhaka	doc_399014257223_item	2382158	et	4	main
kaudu	doc_399014257223_item	2382160	et	3	main
lõunapoolsi	doc_399014257223_item	2382161	et	4	main
sealt	doc_399014257223_item	2382163	et	4	main
pilti	doc_399014257223_item	2382170	et	4	main
täpne	doc_399014257223_item	2382174	et	3	main
kust	doc_399014257223_item	2382178	et	4	main
on	doc_399014257223_item	2382180	et	4	main
ja	doc_399014257223_item	2382182	et	3	main
milles	doc_399014257223_item	2382183	et	3	main
on	doc_399014257223_item	2382188	et	4	main
on	doc_399014257223_item	2382193	et	4	main
kohas	doc_399014257223_item	2382195	et	4	main
muutunud	doc_399014257223_item	2382196	et	4	main
oli	doc_399014257223_item	2382201	et	3	main
ajal	doc_399014257223_item	2382204	et	4	main
venelased	doc_399014257223_item	2382207	et	3	main
kasvatasid	doc_399014257223_item	2382208	et	4	main
köögivilja	doc_399014257223_item	2382209	et	4	main
tekkis	doc_399014257223_item	2382215	et	3	main
aastal	doc_399014257223_item	2382217	et	3	main
ei	doc_399014257223_item	2382220	et	4	main
selgu	doc_399014257223_item	2382221	et	4	main
erimeeldusde	doc_399014257223_item	2382224	et	4	main
branderi	doc_399014257223_item	2382237	et	4	main
asemel	doc_399014257223_item	2382238	et	4	main
uue	doc_399014257223_item	2382239	et	3	main
fotograafi	doc_399014257223_item	2382240	et	4	main
aga	doc_399014257223_item	2382241	et	3	main
esimese	doc_399014257223_item	2382242	et	3	main
fotografeerimise	doc_399014257223_item	2382248	et	4	main
1950	doc_399014257223_item	2382256	et	2	main
1981	doc_399014257223_item	2382265	et	2	main
brander	doc_399014257223_item	2382266	et	4	main
näiteks	doc_399014257223_item	2382275	et	4	main
hakkasid	doc_399014257223_item	2382279	et	4	main
tema	doc_399014257223_item	2382280	et	4	main
tervis	doc_399014257223_item	2382281	et	3	main
ja	doc_399014257223_item	2382282	et	3	main
nägemisvõime	doc_399014257223_item	2382283	et	4	main
nõrgenema	doc_399014257223_item	2382284	et	3	main
kust	doc_399014257223_item	2382292	et	4	main
patsientid	doc_399014257223_item	2382293	et	4	main
ei	doc_399014257223_item	2382302	et	4	main
juhtunud	doc_399014257223_item	2382303	et	4	main
vaimse	doc_399014257223_item	2382305	et	3	main
segases	doc_399014257223_item	2382316	et	3	main
uurimisretkeks	doc_399014257223_item	2382143	et	4	main
ringkäikule	doc_399014257223_item	2382147	et	4	main
matk	doc_399014257223_item	2382165	et	3	main
kaudu	doc_399014257223_item	2382167	et	3	main
iga	doc_399014257223_item	2382169	et	4	main
kaart	doc_399014257223_item	2382175	et	4	main
näitab	doc_399014257223_item	2382177	et	3	main
vältimatu	doc_399014257223_item	2382190	et	4	main
sest	doc_399014257223_item	2382191	et	4	main
mönes	doc_399014257223_item	2382194	et	4	main
branderi	doc_399014257223_item	2382202	et	4	main
kus	doc_399014257223_item	2382206	et	3	main
vahel	doc_399014257223_item	2382214	et	4	main
pakarinen	doc_399014257223_item	2382226	et	4	main
süü	doc_399014257223_item	2382229	et	4	main
maailmasõja	doc_399014257223_item	2382243	et	3	main
süstemaatliline	doc_399014257223_item	2382251	et	4	main
uuesti	doc_399014257223_item	2382254	et	3	main
töötamist	doc_399014257223_item	2382268	et	4	main
fotograafina	doc_399014257223_item	2382269	et	4	main
ta	doc_399014257223_item	2382273	et	4	main
rohekae	doc_399014257223_item	2382285	et	4	main
sattus	doc_399014257223_item	2382288	et	3	main
kivelä	doc_399014257223_item	2382290	et	4	main
hiljem	doc_399014257223_item	2382294	et	3	main
tõttu	doc_399014257223_item	2382297	et	4	main
nikkilä	doc_399014257223_item	2382319	et	4	main
aastal	doc_399014257223_item	2382321	et	3	main
hulgas	doc_399014257223_item	2382328	et	4	main
kes	doc_399014257223_item	2382335	et	4	main
maha	doc_399014257223_item	2382337	et	4	main
ühishauda	doc_399014257223_item	2382338	et	4	main
hakanieme	doc_399014257223_item	2382156	et	4	main
linnaosadesse	doc_399014257223_item	2382162	et	3	main
algupärane	doc_399014257223_item	2382173	et	4	main
suunas	doc_399014257223_item	2382184	et	4	main
kaart	doc_399014257223_item	2382187	et	4	main
linnaosa	doc_399014257223_item	2382200	et	4	main
et	doc_399014257223_item	2382228	et	3	main
võis	doc_399014257223_item	2382230	et	4	main
olla	doc_399014257223_item	2382231	et	3	main
aastakümneiks	doc_399014257223_item	2382249	et	3	main
linnaümbruse	doc_399014257223_item	2382250	et	3	main
salvestus	doc_399014257223_item	2382252	et	4	main
aastadel	doc_399014257223_item	2382257	et	4	main
püsiva	doc_399014257223_item	2382259	et	4	main
mitmel	doc_399014257223_item	2382270	et	4	main
pildistas	doc_399014257223_item	2382274	et	3	main
1930	doc_399014257223_item	2382277	et	2	main
1941	doc_399014257223_item	2382287	et	2	main
nikkilä	doc_399014257223_item	2382298	et	4	main
vaimuhaiglasse	doc_399014257223_item	2382299	et	4	main
branderi	doc_399014257223_item	2382304	et	4	main
tervise	doc_399014257223_item	2382306	et	3	main
puhul	doc_399014257223_item	2382307	et	4	main
olgugi	doc_399014257223_item	2382308	et	4	main
et	doc_399014257223_item	2382309	et	3	main
seda	doc_399014257223_item	2382310	et	3	main
olukorras	doc_399014257223_item	2382317	et	3	main
üle	doc_399014257223_item	2382323	et	3	main
brander	doc_399014257223_item	2382334	et	4	main
teiste	doc_399014257223_item	2382339	et	4	main
mis	doc_399014257223_item	2382222	et	4	main
arvab	doc_399014257223_item	2382227	et	3	main
tõõle	doc_399014257223_item	2382236	et	4	main
aastal	doc_399014257223_item	2382245	et	3	main
1914	doc_399014257223_item	2382246	et	2	main
jätkas	doc_399014257223_item	2382267	et	3	main
pool	doc_399014257223_item	2382271	et	4	main
soomes	doc_399014257223_item	2382272	et	4	main
mõisaid	doc_399014257223_item	2382276	et	3	main
brander	doc_399014257223_item	2382289	et	4	main
haiglasse	doc_399014257223_item	2382291	et	4	main
viitikse	doc_399014257223_item	2382295	et	3	main
sõja	doc_399014257223_item	2382296	et	3	main
üleviimine	doc_399014257223_item	2382301	et	3	main
suri	doc_399014257223_item	2382318	et	3	main
1942	doc_399014257223_item	2382322	et	2	main
nende	doc_399014257223_item	2382327	et	4	main
helsingi	doc_399014257223_item	2382330	et	4	main
mattasti	doc_399014257223_item	2382336	et	4	main
hulgas	doc_399014257223_item	2382341	et	4	main
kunagi	doc_399014257223_item	2382313	et	3	main
väitatud	doc_399014257223_item	2382314	et	4	main
sõja	doc_399014257223_item	2382315	et	3	main
haiglas	doc_399014257223_item	2382320	et	3	main
saja	doc_399014257223_item	2382324	et	4	main
nälga	doc_399014257223_item	2382326	et	4	main
oli	doc_399014257223_item	2382329	et	3	main
legendaarne	doc_399014257223_item	2382331	et	3	main
patsienti	doc_399014257223_item	2382325	et	4	main
fotograaf	doc_399014257223_item	2382332	et	4	main
signe	doc_399014257223_item	2382333	et	4	main
patsientide	doc_399014257223_item	2382340	et	3	main
signe	doc_399014257227_item	2383739	et	4	main
helsingi	doc_399014257227_item	2383741	et	4	main
tegi	doc_399014257227_item	2383743	et	4	main
raamatu	doc_399014257227_item	2383744	et	4	main
legendaarsest	doc_399014257227_item	2383745	et	3	main
fotograafist	doc_399014257227_item	2383746	et	4	main
raamat	doc_399014257227_item	2383747	et	3	main
viib	doc_399014257227_item	2383748	et	3	main
linnaekskursioonile	doc_399014257227_item	2383749	et	3	main
saja	doc_399014257227_item	2383750	et	4	main
rahvaarv	doc_399014257227_item	2383755	et	3	main
piiri	doc_399014257227_item	2383760	et	4	main
kolme	doc_399014257227_item	2383763	et	4	main
linna	doc_399014257227_item	2383769	et	4	main
ja	doc_399014257227_item	2383776	et	3	main
kaduvat	doc_399014257227_item	2383780	et	4	main
aastal	doc_399014257227_item	2383792	et	3	main
asutada	doc_399014257227_item	2383793	et	3	main
signe	doc_399014257227_item	2383802	et	4	main
helsingit	doc_399014257227_item	2383816	et	4	main
helsingi	doc_399014257227_item	2383754	et	4	main
aastal	doc_399014257227_item	2383761	et	3	main
muutused	doc_399014257227_item	2383773	et	4	main
helsingi	doc_399014257227_item	2383777	et	4	main
jäädvustama	doc_399014257227_item	2383779	et	3	main
puumajade	doc_399014257227_item	2383781	et	3	main
linna	doc_399014257227_item	2383782	et	4	main
helsingin	doc_399014257227_item	2383788	et	4	main
järgmisel	doc_399014257227_item	2383797	et	3	main
tööle	doc_399014257227_item	2383800	et	3	main
brander	doc_399014257227_item	2383814	et	4	main
pildistas	doc_399014257227_item	2383815	et	3	main
seitsme	doc_399014257227_item	2383817	et	3	main
töö	doc_399014257227_item	2383821	et	4	main
sündis	doc_399014257227_item	2383823	et	3	main
linnamuuseumi	doc_399014257227_item	2383831	et	4	main
fotoahiivi	doc_399014257227_item	2383832	et	4	main
branderi	doc_399014257227_item	2383840	et	4	main
piltidest	doc_399014257227_item	2383841	et	3	main
mis	doc_399014257227_item	2383844	et	4	main
tema	doc_399014257227_item	2383847	et	4	main
fotograaf	doc_399014257227_item	2383849	et	4	main
jan	doc_399014257227_item	2383850	et	4	main
alanco	doc_399014257227_item	2383851	et	4	main
ja	doc_399014257227_item	2383852	et	3	main
teinud	doc_399014257227_item	2383857	et	4	main
umbes	doc_399014257227_item	2383861	et	4	main
branderi	doc_399014257227_item	2383864	et	4	main
helsingi	doc_399014257227_item	2383867	et	4	main
ajaloost	doc_399014257227_item	2383868	et	4	main
ei	doc_399014257227_item	2383869	et	4	main
palju	doc_399014257227_item	2383873	et	4	main
oleks	doc_399014257227_item	2383877	et	3	main
branderi	doc_399014257227_item	2383882	et	4	main
fotot	doc_399014257227_item	2383883	et	3	main
1900	doc_399014257227_item	2383884	et	2	main
aastate	doc_399014257227_item	2383885	et	3	main
algusest	doc_399014257227_item	2383886	et	4	main
muinsuskaitse	doc_399014257227_item	2383895	et	4	main
asjatundjad	doc_399014257227_item	2383904	et	3	main
kavandatud	doc_399014257227_item	2383923	et	4	main
helsingi	doc_399014257227_item	2383926	et	4	main
eira	doc_399014257227_item	2383936	et	4	main
baranderi	doc_399014257227_item	2383740	et	4	main
linnamuuseum	doc_399014257227_item	2383742	et	3	main
aasta	doc_399014257227_item	2383751	et	4	main
ületas	doc_399014257227_item	2383756	et	3	main
1902	doc_399014257227_item	2383762	et	2	main
aastakümne	doc_399014257227_item	2383764	et	4	main
see	doc_399014257227_item	2383766	et	3	main
sada	doc_399014257227_item	2383783	et	4	main
aastat	doc_399014257227_item	2383784	et	3	main
tagasi	doc_399014257227_item	2383785	et	3	main
otsustas	doc_399014257227_item	2383790	et	3	main
otsust	doc_399014257227_item	2383805	et	4	main
mitu	doc_399014257227_item	2383808	et	4	main
korda	doc_399014257227_item	2383809	et	4	main
aasta	doc_399014257227_item	2383818	et	4	main
fotot	doc_399014257227_item	2383825	et	3	main
linnamuuseum	doc_399014257227_item	2383835	et	3	main
nüüd	doc_399014257227_item	2383837	et	4	main
avaldanud	doc_399014257227_item	2383838	et	4	main
pakarinen	doc_399014257227_item	2383855	et	4	main
on	doc_399014257227_item	2383856	et	4	main
sada	doc_399014257227_item	2383862	et	4	main
raamatuid	doc_399014257227_item	2383874	et	3	main
ei	doc_399014257227_item	2383876	et	4	main
alles	doc_399014257227_item	2383888	et	3	main
ta	doc_399014257227_item	2383890	et	4	main
saab	doc_399014257227_item	2383891	et	3	main
täielikult	doc_399014257227_item	2383892	et	4	main
omal	doc_399014257227_item	2383898	et	3	main
ajal	doc_399014257227_item	2383899	et	4	main
tõlge	doc_399014257227_item	2383738	et	3	main
tagusesse	doc_399014257227_item	2383752	et	4	main
100	doc_399014257227_item	2383757	et	2	main
elaniku	doc_399014257227_item	2383759	et	3	main
kolmekordistunud	doc_399014257227_item	2383768	et	4	main
suur	doc_399014257227_item	2383770	et	3	main
kasv	doc_399014257227_item	2383771	et	3	main
ja	doc_399014257227_item	2383772	et	3	main
otsustajad	doc_399014257227_item	2383778	et	4	main
jaoks	doc_399014257227_item	2383787	et	4	main
kaupunginvaltuusto	doc_399014257227_item	2383789	et	4	main
komisjoni	doc_399014257227_item	2383795	et	4	main
palkas	doc_399014257227_item	2383799	et	3	main
branderi	doc_399014257227_item	2383803	et	4	main
hiljem	doc_399014257227_item	2383807	et	3	main
1907-1913	doc_399014257227_item	2383820	et	2	main
on	doc_399014257227_item	2383829	et	4	main
helsingi	doc_399014257227_item	2383830	et	4	main
helsingi	doc_399014257227_item	2383834	et	4	main
on	doc_399014257227_item	2383836	et	4	main
esimese	doc_399014257227_item	2383842	et	3	main
terviklikult	doc_399014257227_item	2383846	et	4	main
raamatu	doc_399014257227_item	2383858	et	4	main
ole	doc_399014257227_item	2383870	et	4	main
sees	doc_399014257227_item	2383878	et	4	main
mõnda	doc_399014257227_item	2383880	et	4	main
raamatu	doc_399014257227_item	2383894	et	4	main
aastate	doc_399014257227_item	2383932	et	3	main
oli	doc_399014257227_item	2383938	et	3	main
1800	doc_399014257227_item	2383941	et	2	main
esimesl	doc_399014257227_item	2383943	et	4	main
linna	doc_399014257227_item	2383945	et	4	main
hakkasid	doc_399014257227_item	2383951	et	4	main
fotograafiks	doc_399014257227_item	2383963	et	4	main
oli	doc_399014257227_item	2383964	et	3	main
iseenesest	doc_399014257227_item	2383965	et	4	main
mõistetav	doc_399014257227_item	2383966	et	4	main
tal	doc_399014257227_item	2383967	et	3	main
juba	doc_399014257227_item	2383969	et	3	main
joonistusõpetajaks	doc_399014257227_item	2383982	et	3	main
fotograaf	doc_399014257227_item	2383995	et	4	main
natuke	doc_399014257227_item	2384008	et	4	main
kogemust	doc_399014257227_item	2384009	et	3	main
kohta	doc_399014257227_item	2384022	et	4	main
linna-	doc_399014257227_item	2384025	et	4	main
ja	doc_399014257227_item	2384026	et	3	main
ta	doc_399014257227_item	2384028	et	4	main
piltidel	doc_399014257227_item	2384042	et	3	main
pildile	doc_399014257227_item	2384052	et	3	main
on	doc_399014257227_item	2384054	et	4	main
olnud	doc_399014257227_item	2384056	et	4	main
palunud	doc_399014257227_item	2384060	et	4	main
neid	doc_399014257227_item	2384061	et	4	main
hea	doc_399014257227_item	2384067	et	4	main
et	doc_399014257227_item	2384072	et	3	main
esitleda	doc_399014257227_item	2384076	et	3	main
hoovi	doc_399014257227_item	2384090	et	4	main
helsingisse	doc_399014257227_item	2383753	et	4	main
000	doc_399014257227_item	2383758	et	2	main
jooksul	doc_399014257227_item	2383765	et	4	main
on	doc_399014257227_item	2383767	et	4	main
äratasid	doc_399014257227_item	2383774	et	4	main
arhitektid	doc_399014257227_item	2383775	et	3	main
selle	doc_399014257227_item	2383786	et	4	main
1906	doc_399014257227_item	2383791	et	2	main
muinsuskaite	doc_399014257227_item	2383794	et	4	main
mis	doc_399014257227_item	2383796	et	4	main
aastal	doc_399014257227_item	2383798	et	3	main
fotograaf	doc_399014257227_item	2383801	et	4	main
1869-1942	doc_399014257227_item	2383804	et	2	main
on	doc_399014257227_item	2383806	et	4	main
kiidetud	doc_399014257227_item	2383810	et	4	main
targaks	doc_399014257227_item	2383811	et	3	main
ja	doc_399014257227_item	2383812	et	3	main
perspektiivikaks	doc_399014257227_item	2383813	et	3	main
jooksul	doc_399014257227_item	2383819	et	4	main
signe	doc_399014257227_item	2383839	et	4	main
põhineb	doc_399014257227_item	2383845	et	3	main
fotodel	doc_399014257227_item	2383848	et	3	main
on	doc_399014257227_item	2383860	et	4	main
helsingiteemalist	doc_399014257227_item	2383865	et	4	main
fotot	doc_399014257227_item	2383866	et	3	main
eriti	doc_399014257227_item	2383872	et	3	main
kasvõi	doc_399014257227_item	2383879	et	3	main
signe	doc_399014257227_item	2383881	et	4	main
oma	doc_399014257227_item	2383893	et	4	main
parimad	doc_399014257227_item	2383900	et	4	main
linnapiltide	doc_399014257227_item	2383901	et	3	main
ja	doc_399014257227_item	2383902	et	3	main
kultuuriajaloo	doc_399014257227_item	2383903	et	4	main
oli	doc_399014257227_item	2383922	et	3	main
suuri	doc_399014257227_item	2383924	et	3	main
muutusi	doc_399014257227_item	2383925	et	4	main
kasvas	doc_399014257227_item	2383927	et	3	main
ja	doc_399014257227_item	2383928	et	3	main
muutus	doc_399014257227_item	2383929	et	4	main
mühinal	doc_399014257227_item	2383930	et	3	main
1900	doc_399014257227_item	2383931	et	2	main
alguses	doc_399014257227_item	2383933	et	4	main
töölö	doc_399014257227_item	2383934	et	4	main
ja	doc_399014257227_item	2383935	et	3	main
aastate	doc_399014257227_item	2383942	et	3	main
poolel	doc_399014257227_item	2383944	et	4	main
kogemust	doc_399014257227_item	2383970	et	3	main
eriti	doc_399014257227_item	2383974	et	3	main
pildistamisest	doc_399014257227_item	2383976	et	4	main
ta	doc_399014257227_item	2383984	et	4	main
ateljeetööst	doc_399014257227_item	2384002	et	3	main
oli	doc_399014257227_item	2384004	et	3	main
sellel	doc_399014257227_item	2384006	et	4	main
alalgi	doc_399014257227_item	2384007	et	4	main
eri	doc_399014257227_item	2384011	et	4	main
maastikupilte	doc_399014257227_item	2384027	et	3	main
ei	doc_399014257227_item	2384029	et	4	main
inimesed	doc_399014257227_item	2384033	et	3	main
on	doc_399014257227_item	2384043	et	4	main
peaaegu	doc_399014257227_item	2384044	et	3	main
plitseinikke	doc_399014257227_item	2384048	et	4	main
sattunud	doc_399014257227_item	2384053	et	4	main
on	doc_399014257227_item	2384059	et	4	main
tuju	doc_399014257227_item	2384068	et	4	main
järeldada	doc_399014257227_item	2384071	et	3	main
valjasteta	doc_399014257227_item	2384091	et	4	main
pildi	doc_399014257227_item	2384123	et	4	main
täpne	doc_399014257227_item	2384127	et	3	main
praeguse	doc_399014257227_item	2384143	et	3	main
kohtades	doc_399014257227_item	2384152	et	3	main
näiteks	doc_399014257227_item	2384155	et	4	main
töölö	doc_399014257227_item	2384156	et	4	main
venelased	doc_399014257227_item	2384163	et	3	main
branderi	doc_399014257227_item	2384167	et	4	main
ja	doc_399014257227_item	2384168	et	3	main
komisjoni	doc_399014257227_item	2384169	et	4	main
erimeelsusi	doc_399014257227_item	2384172	et	4	main
põhjusest	doc_399014257227_item	2384186	et	4	main
palkas	doc_399014257227_item	2384190	et	3	main
tulemusena	doc_399014257227_item	2383822	et	3	main
907	doc_399014257227_item	2383824	et	2	main
mis	doc_399014257227_item	2383826	et	4	main
veel	doc_399014257227_item	2383827	et	4	main
praegugi	doc_399014257227_item	2383828	et	3	main
tuumik	doc_399014257227_item	2383833	et	3	main
teose	doc_399014257227_item	2383843	et	3	main
uurija	doc_399014257227_item	2383853	et	4	main
riitta	doc_399014257227_item	2383854	et	4	main
kus	doc_399014257227_item	2383859	et	3	main
parimat	doc_399014257227_item	2383863	et	4	main
avaldatud	doc_399014257227_item	2383871	et	4	main
kus	doc_399014257227_item	2383875	et	3	main
aga	doc_399014257227_item	2383887	et	3	main
nüüd	doc_399014257227_item	2383889	et	4	main
komisjonis	doc_399014257227_item	2383896	et	3	main
istusid	doc_399014257227_item	2383897	et	4	main
muu	doc_399014257227_item	2383905	et	4	main
hulgas	doc_399014257227_item	2383906	et	4	main
arhitekt	doc_399014257227_item	2383907	et	3	main
professor	doc_399014257227_item	2383908	et	3	main
gustaf	doc_399014257227_item	2383909	et	4	main
nyström	doc_399014257227_item	2383910	et	4	main
kes	doc_399014257227_item	2383911	et	4	main
juhatas	doc_399014257227_item	2383912	et	3	main
helsingi	doc_399014257227_item	2383913	et	4	main
linnaplaneeringut	doc_399014257227_item	2383914	et	4	main
komisjon	doc_399014257227_item	2383915	et	3	main
tegi	doc_399014257227_item	2383916	et	4	main
branderi	doc_399014257227_item	2383917	et	4	main
jaoks	doc_399014257227_item	2383918	et	4	main
planeeringu	doc_399014257227_item	2383919	et	4	main
kohtadest	doc_399014257227_item	2383920	et	3	main
kuhu	doc_399014257227_item	2383921	et	3	main
ehitamine	doc_399014257227_item	2383937	et	4	main
ja	doc_399014257227_item	2383940	et	3	main
puumajad	doc_399014257227_item	2383950	et	3	main
oli	doc_399014257227_item	2383968	et	3	main
helsingis	doc_399014257227_item	2383981	et	4	main
ei	doc_399014257227_item	2383985	et	4	main
töötanud	doc_399014257227_item	2383987	et	4	main
mitte	doc_399014257227_item	2383988	et	3	main
kunagi	doc_399014257227_item	2383989	et	3	main
õpetajana	doc_399014257227_item	2383990	et	4	main
selle	doc_399014257227_item	2383991	et	4	main
ei	doc_399014257227_item	2383997	et	4	main
pildistamisest	doc_399014257227_item	2384000	et	4	main
tal	doc_399014257227_item	2384003	et	3	main
muidugi	doc_399014257227_item	2384005	et	4	main
ta	doc_399014257227_item	2384013	et	4	main
hoopis	doc_399014257227_item	2384015	et	3	main
välja	doc_399014257227_item	2384016	et	4	main
bander	doc_399014257227_item	2384017	et	4	main
pildistas	doc_399014257227_item	2384018	et	3	main
paigalseisva	doc_399014257227_item	2384031	et	3	main
möödakäijaidlapsi	doc_399014257227_item	2384046	et	4	main
ja	doc_399014257227_item	2384049	et	3	main
tihtipeale	doc_399014257227_item	2384051	et	3	main
pildistada	doc_399014257227_item	2384065	et	3	main
brander	doc_399014257227_item	2384073	et	4	main
asja	doc_399014257227_item	2384075	et	4	main
uudishimu	doc_399014257227_item	2384080	et	4	main
pikantne	doc_399014257227_item	2384083	et	3	main
detail	doc_399014257227_item	2384084	et	3	main
koer	doc_399014257227_item	2384087	et	3	main
töölösse	doc_399014257227_item	2384121	et	3	main
algamas	doc_399014257227_item	2383939	et	3	main
taanduma	doc_399014257227_item	2383952	et	3	main
kõrgete	doc_399014257227_item	2383953	et	4	main
teelt	doc_399014257227_item	2383955	et	3	main
riitta	doc_399014257227_item	2383956	et	4	main
pakarise	doc_399014257227_item	2383957	et	4	main
hinnangul	doc_399014257227_item	2383958	et	3	main
kivimüüride	doc_399014257227_item	2383954	et	4	main
signe	doc_399014257227_item	2383959	et	4	main
branderi	doc_399014257227_item	2383960	et	4	main
valik	doc_399014257227_item	2383961	et	3	main
helsingi	doc_399014257227_item	2383962	et	4	main
ehitatud	doc_399014257227_item	2383946	et	4	main
ühe-	doc_399014257227_item	2383947	et	4	main
ja	doc_399014257227_item	2383948	et	3	main
kahekorruselised	doc_399014257227_item	2383949	et	4	main
fotograafina	doc_399014257227_item	2383972	et	4	main
ja	doc_399014257227_item	2383973	et	3	main
maastikkude	doc_399014257227_item	2383975	et	4	main
parkanis	doc_399014257227_item	2383977	et	4	main
sündinud	doc_399014257227_item	2383978	et	4	main
brander	doc_399014257227_item	2383979	et	4	main
õppis	doc_399014257227_item	2383980	et	3	main
kes	doc_399014257227_item	2383996	et	4	main
portreede	doc_399014257227_item	2383999	et	4	main
ega	doc_399014257227_item	2384001	et	3	main
helsingi	doc_399014257227_item	2384010	et	4	main
tahtis	doc_399014257227_item	2384014	et	3	main
tehnika	doc_399014257227_item	2384021	et	4	main
eriti	doc_399014257227_item	2384023	et	3	main
osavalt	doc_399014257227_item	2384024	et	4	main
rahuldunud	doc_399014257227_item	2384030	et	4	main
igasugu	doc_399014257227_item	2384035	et	3	main
olid	doc_399014257227_item	2384037	et	4	main
elulisuse	doc_399014257227_item	2384040	et	4	main
saladustema	doc_399014257227_item	2384041	et	4	main
kohal	doc_399014257227_item	2384055	et	4	main
juhuslikult	doc_399014257227_item	2384057	et	4	main
hetkeks	doc_399014257227_item	2384062	et	4	main
peatuda	doc_399014257227_item	2384063	et	3	main
et	doc_399014257227_item	2384064	et	3	main
põhjal	doc_399014257227_item	2384069	et	4	main
oskas	doc_399014257227_item	2384074	et	3	main
äratada	doc_399014257227_item	2384078	et	3	main
kõndiv	doc_399014257227_item	2384086	et	4	main
algupärane	doc_399014257227_item	2384126	et	4	main
on	doc_399014257227_item	2384139	et	4	main
muutunud	doc_399014257227_item	2384153	et	4	main
ajal	doc_399014257227_item	2384160	et	4	main
kus	doc_399014257227_item	2384162	et	3	main
1913	doc_399014257227_item	2384173	et	2	main
tüli	doc_399014257227_item	2384181	et	4	main
võis	doc_399014257227_item	2384182	et	4	main
lihtsast	doc_399014257227_item	2384185	et	3	main
branderi	doc_399014257227_item	2384191	et	4	main
linnaümbruse	doc_399014257227_item	2384204	et	3	main
taasalgas	doc_399014257227_item	2384206	et	3	main
tervis	doc_399014257227_item	2384228	et	3	main
nägemine	doc_399014257227_item	2384230	et	4	main
kivelä	doc_399014257227_item	2384240	et	4	main
haiglasse	doc_399014257227_item	2384241	et	4	main
millest	doc_399014257227_item	2384242	et	3	main
patsiendid	doc_399014257227_item	2384243	et	3	main
hiljem	doc_399014257227_item	2384244	et	3	main
haiglasse	doc_399014257227_item	2384250	et	4	main
kuigi	doc_399014257227_item	2384258	et	3	main
väidetud	doc_399014257227_item	2384262	et	4	main
sõjaoludes	doc_399014257227_item	2384263	et	3	main
oli	doc_399014257227_item	2384275	et	3	main
ka	doc_399014257227_item	2384276	et	3	main
helsingi	doc_399014257227_item	2384277	et	4	main
maeti	doc_399014257227_item	2384283	et	3	main
koos	doc_399014257227_item	2384284	et	4	main
teiste	doc_399014257227_item	2384285	et	4	main
patsientidega	doc_399014257227_item	2384286	et	3	main
ühishauda	doc_399014257227_item	2384287	et	4	main
arhitektid	doc_399014257228_item	2384326	et	3	main
linnaisad	doc_399014257228_item	2384328	et	4	main
kaduva	doc_399014257228_item	2384330	et	4	main
tagasi	doc_399014257228_item	2384334	et	3	main
helsingi	doc_399014257228_item	2384337	et	4	main
linnavolikogu	doc_399014257228_item	2384338	et	4	main
1906	doc_399014257228_item	2384339	et	2	main
aastal	doc_399014257228_item	2384340	et	3	main
mis	doc_399014257228_item	2384343	et	4	main
fotograafi	doc_399014257228_item	2384348	et	4	main
hiljem	doc_399014257228_item	2384357	et	3	main
targaks	doc_399014257228_item	2384358	et	3	main
ja	doc_399014257228_item	2384359	et	3	main
ettenägevaks	doc_399014257228_item	2384360	et	3	main
pildistas	doc_399014257228_item	2384363	et	3	main
seitse	doc_399014257228_item	2384365	et	3	main
19071913	doc_399014257228_item	2384367	et	2	main
osava	doc_399014257227_item	2383971	et	3	main
aga	doc_399014257227_item	2383983	et	3	main
ole	doc_399014257227_item	2383986	et	4	main
asemel	doc_399014257227_item	2383992	et	4	main
temast	doc_399014257227_item	2383993	et	3	main
tuli	doc_399014257227_item	2383994	et	4	main
hoolinud	doc_399014257227_item	2383998	et	4	main
fotofirmades	doc_399014257227_item	2384012	et	3	main
tolleaegse	doc_399014257227_item	2384019	et	3	main
algelise	doc_399014257227_item	2384020	et	4	main
arhitektuuriga	doc_399014257227_item	2384032	et	3	main
ja	doc_399014257227_item	2384034	et	3	main
pisidetailid	doc_399014257227_item	2384036	et	3	main
tema	doc_399014257227_item	2384038	et	4	main
fotode	doc_399014257227_item	2384039	et	3	main
alati	doc_399014257227_item	2384045	et	4	main
kaupmehi	doc_399014257227_item	2384047	et	3	main
koduloomi	doc_399014257227_item	2384050	et	4	main
brander	doc_399014257227_item	2384058	et	4	main
inimeste	doc_399014257227_item	2384066	et	3	main
võib	doc_399014257227_item	2384070	et	3	main
ja	doc_399014257227_item	2384077	et	3	main
helsingilaste	doc_399014257227_item	2384079	et	4	main
vahel	doc_399014257227_item	2384081	et	4	main
on	doc_399014257227_item	2384082	et	4	main
trammirööbastel	doc_399014257227_item	2384085	et	3	main
või	doc_399014257227_item	2384088	et	4	main
keset	doc_399014257227_item	2384089	et	4	main
seisev	doc_399014257227_item	2384092	et	4	main
hobune	doc_399014257227_item	2384093	et	4	main
pildid	doc_399014257227_item	2384094	et	3	main
raamatus	doc_399014257227_item	2384095	et	4	main
on	doc_399014257227_item	2384096	et	4	main
seatud	doc_399014257227_item	2384097	et	4	main
järjekorda	doc_399014257227_item	2384098	et	4	main
nagu	doc_399014257227_item	2384099	et	3	main
lugeja	doc_399014257227_item	2384100	et	4	main
liiguks	doc_399014257227_item	2384101	et	4	main
linnaekskursioonil	doc_399014257227_item	2384102	et	3	main
saja	doc_399014257227_item	2384103	et	4	main
aasta	doc_399014257227_item	2384104	et	4	main
taguses	doc_399014257227_item	2384105	et	3	main
helsingis	doc_399014257227_item	2384106	et	4	main
ekskursioon	doc_399014257227_item	2384107	et	3	main
algab	doc_399014257227_item	2384108	et	3	main
hermannist	doc_399014257227_item	2384109	et	4	main
jätkub	doc_399014257227_item	2384110	et	3	main
haganieme	doc_399014257227_item	2384111	et	4	main
ja	doc_399014257227_item	2384112	et	3	main
kruunuhaka	doc_399014257227_item	2384113	et	4	main
kaudu	doc_399014257227_item	2384114	et	3	main
lõunapoolsetesse	doc_399014257227_item	2384115	et	4	main
linnajagudesse	doc_399014257227_item	2384116	et	3	main
ning	doc_399014257227_item	2384117	et	3	main
sealt	doc_399014257227_item	2384118	et	4	main
kampi	doc_399014257227_item	2384119	et	4	main
kaudu	doc_399014257227_item	2384120	et	3	main
kaart	doc_399014257227_item	2384128	et	4	main
räägib	doc_399014257227_item	2384130	et	3	main
vaadatud	doc_399014257227_item	2384140	et	4	main
lugejale	doc_399014257227_item	2384145	et	4	main
iga	doc_399014257227_item	2384122	et	4	main
kõrval	doc_399014257227_item	2384124	et	4	main
on	doc_399014257227_item	2384125	et	4	main
mis	doc_399014257227_item	2384129	et	4	main
kustkohast	doc_399014257227_item	2384132	et	4	main
tehtud	doc_399014257227_item	2384135	et	4	main
ja	doc_399014257227_item	2384136	et	3	main
kuhu	doc_399014257227_item	2384137	et	3	main
suunda	doc_399014257227_item	2384138	et	4	main
kaart	doc_399014257227_item	2384141	et	4	main
aja	doc_399014257227_item	2384144	et	4	main
möödapääsmatu	doc_399014257227_item	2384146	et	4	main
asi	doc_399014257227_item	2384147	et	4	main
kuna	doc_399014257227_item	2384148	et	3	main
linn	doc_399014257227_item	2384149	et	3	main
oli	doc_399014257227_item	2384157	et	3	main
branderi	doc_399014257227_item	2384158	et	4	main
hesingilastele	doc_399014257227_item	2384165	et	4	main
köögivilju	doc_399014257227_item	2384166	et	3	main
ole	doc_399014257227_item	2384176	et	4	main
tekkida	doc_399014257227_item	2384183	et	3	main
nii	doc_399014257227_item	2384184	et	3	main
rahast	doc_399014257227_item	2384188	et	4	main
linnamuuseum	doc_399014257227_item	2384189	et	3	main
fotograafi	doc_399014257227_item	2384194	et	4	main
aga	doc_399014257227_item	2384195	et	3	main
esimese	doc_399014257227_item	2384196	et	3	main
maailmasõja	doc_399014257227_item	2384197	et	3	main
puhkemine	doc_399014257227_item	2384198	et	4	main
1914	doc_399014257227_item	2384199	et	2	main
lõpetas	doc_399014257227_item	2384200	et	3	main
soomes	doc_399014257227_item	2384222	et	4	main
pildistas	doc_399014257227_item	2384226	et	3	main
ja	doc_399014257227_item	2384229	et	3	main
aastal	doc_399014257227_item	2384233	et	3	main
tagajärjel	doc_399014257227_item	2384235	et	3	main
brander	doc_399014257227_item	2384236	et	4	main
1941	doc_399014257227_item	2384238	et	2	main
üleviimine	doc_399014257227_item	2384252	et	3	main
ei	doc_399014257227_item	2384253	et	4	main
põhjustatud	doc_399014257227_item	2384255	et	4	main
branderi	doc_399014257227_item	2384256	et	4	main
meeltesegadusest	doc_399014257227_item	2384257	et	4	main
sedagi	doc_399014257227_item	2384259	et	3	main
kunagi	doc_399014257227_item	2384261	et	3	main
1942	doc_399014257227_item	2384264	et	2	main
surid	doc_399014257227_item	2384268	et	4	main
200	doc_399014257227_item	2384271	et	2	main
patsienti	doc_399014257227_item	2384272	et	4	main
signe	doc_399014257227_item	2384280	et	4	main
suurenemine	doc_399014257228_item	2384322	et	4	main
ja	doc_399014257228_item	2384327	et	3	main
linna	doc_399014257228_item	2384332	et	4	main
selleks	doc_399014257228_item	2384335	et	4	main
muinsuskaitsekomisjoni	doc_399014257228_item	2384342	et	4	main
signe	doc_399014257228_item	2384349	et	4	main
branderi	doc_399014257228_item	2384350	et	4	main
18691942	doc_399014257228_item	2384351	et	2	main
kiidetud	doc_399014257228_item	2384361	et	4	main
helsingit	doc_399014257228_item	2384364	et	4	main
mis	doc_399014257228_item	2384374	et	4	main
moodustab	doc_399014257228_item	2384375	et	3	main
helsingi	doc_399014257228_item	2384376	et	4	main
põhiosa	doc_399014257228_item	2384379	et	4	main
ajaloost	doc_399014257228_item	2384416	et	4	main
välja	doc_399014257228_item	2384419	et	4	main
palju	doc_399014257228_item	2384422	et	4	main
mitu	doc_399014257228_item	2384427	et	4	main
2000	doc_399014257228_item	2384433	et	2	main
oma	doc_399014257228_item	2384442	et	4	main
muinsuskaitsekomisjoni	doc_399014257228_item	2384444	et	4	main
olid	doc_399014257228_item	2384446	et	4	main
ja	doc_399014257228_item	2384452	et	3	main
teiste	doc_399014257228_item	2384455	et	4	main
linnaplaneerimise	doc_399014257228_item	2384464	et	3	main
branderi	doc_399014257228_item	2384468	et	4	main
plaani	doc_399014257228_item	2384470	et	4	main
oli	doc_399014257228_item	2384473	et	3	main
muutus	doc_399014257228_item	2384480	et	4	main
mühinaga	doc_399014257228_item	2384481	et	3	main
hakati	doc_399014257228_item	2384485	et	3	main
ja	doc_399014257228_item	2384488	et	3	main
eira	doc_399014257228_item	2384489	et	4	main
sellest	doc_399014257227_item	2384131	et	4	main
pilt	doc_399014257227_item	2384133	et	3	main
on	doc_399014257227_item	2384134	et	4	main
on	doc_399014257227_item	2384142	et	4	main
on	doc_399014257227_item	2384150	et	4	main
mõnedes	doc_399014257227_item	2384151	et	3	main
pildistamise	doc_399014257227_item	2384159	et	4	main
vahel	doc_399014257227_item	2384170	et	4	main
aastalprotokollides	doc_399014257227_item	2384174	et	4	main
pakarise	doc_399014257227_item	2384179	et	4	main
arvates	doc_399014257227_item	2384180	et	4	main
kui	doc_399014257227_item	2384187	et	3	main
pildistamised	doc_399014257227_item	2384201	et	4	main
aastakümneteks	doc_399014257227_item	2384202	et	4	main
organiseeritud	doc_399014257227_item	2384203	et	4	main
1950	doc_399014257227_item	2384208	et	2	main
fotograafitööd	doc_399014257227_item	2384220	et	4	main
siirdati	doc_399014257227_item	2384247	et	4	main
psühhoneuroloogia	doc_399014257227_item	2384249	et	4	main
haiglas	doc_399014257227_item	2384267	et	3	main
hulgas	doc_399014257227_item	2384274	et	4	main
kes	doc_399014257227_item	2384282	et	4	main
ja	doc_399014257228_item	2384323	et	3	main
talletama	doc_399014257228_item	2384329	et	3	main
otsustas	doc_399014257228_item	2384336	et	3	main
aastal	doc_399014257228_item	2384345	et	3	main
seda	doc_399014257228_item	2384352	et	3	main
mittu	doc_399014257228_item	2384355	et	4	main
on	doc_399014257228_item	2384371	et	4	main
helsingi	doc_399014257228_item	2384415	et	4	main
pole	doc_399014257228_item	2384417	et	3	main
vist	doc_399014257228_item	2384418	et	4	main
poleks	doc_399014257228_item	2384425	et	3	main
vähemalt	doc_399014257228_item	2384426	et	4	main
signe	doc_399014257228_item	2384428	et	4	main
branderi	doc_399014257228_item	2384429	et	4	main
algusest	doc_399014257228_item	2384435	et	4	main
aga	doc_399014257228_item	2384436	et	3	main
alles	doc_399014257228_item	2384437	et	3	main
nüüd	doc_399014257228_item	2384438	et	4	main
saab	doc_399014257228_item	2384439	et	3	main
pildiraamatu	doc_399014257228_item	2384443	et	4	main
aja	doc_399014257228_item	2384449	et	4	main
kultuuriajaloo	doc_399014257228_item	2384453	et	4	main
hulgas	doc_399014257228_item	2384456	et	4	main
arhitekt	doc_399014257228_item	2384457	et	3	main
professor	doc_399014257228_item	2384458	et	3	main
gustaf	doc_399014257228_item	2384459	et	4	main
koostas	doc_399014257228_item	2384467	et	4	main
jaoks	doc_399014257228_item	2384469	et	4	main
pildistamiskohtadest	doc_399014257228_item	2384471	et	4	main
kuhu	doc_399014257228_item	2384472	et	3	main
2000	doc_399014257228_item	2384482	et	2	main
alguses	doc_399014257228_item	2384484	et	4	main
töölö	doc_399014257228_item	2384487	et	4	main
fotograafina	doc_399014257228_item	2384524	et	4	main
helsingis	doc_399014257228_item	2384529	et	4	main
ei	doc_399014257228_item	2384532	et	4	main
sai	doc_399014257228_item	2384539	et	4	main
kes	doc_399014257228_item	2384541	et	4	main
ei	doc_399014257228_item	2384542	et	4	main
armastanud	doc_399014257228_item	2384543	et	4	main
portreteerimist	doc_399014257228_item	2384544	et	4	main
oli	doc_399014257228_item	2384548	et	3	main
kogemusi	doc_399014257228_item	2384550	et	3	main
ta	doc_399014257228_item	2384555	et	4	main
tahtis	doc_399014257228_item	2384556	et	3	main
ennast	doc_399014257228_item	2384557	et	4	main
välitöödele	doc_399014257228_item	2384558	et	3	main
algelise	doc_399014257228_item	2384562	et	4	main
abil	doc_399014257228_item	2384564	et	4	main
brander	doc_399014257228_item	2384566	et	4	main
linna	doc_399014257228_item	2384567	et	4	main
ja	doc_399014257228_item	2384568	et	3	main
rahuldunud	doc_399014257228_item	2384574	et	4	main
piltide	doc_399014257228_item	2384583	et	3	main
elavaks	doc_399014257228_item	2384584	et	4	main
saladuseks	doc_399014257228_item	2384585	et	3	main
piltidel	doc_399014257228_item	2384587	et	3	main
et	doc_399014257228_item	2384624	et	3	main
brander	doc_399014257228_item	2384625	et	4	main
tundmatuseni	doc_399014257227_item	2384154	et	4	main
maakoht	doc_399014257227_item	2384161	et	3	main
kasvatasid	doc_399014257227_item	2384164	et	4	main
tuli	doc_399014257227_item	2384171	et	4	main
ei	doc_399014257227_item	2384175	et	4	main
erimeelsuste	doc_399014257227_item	2384177	et	4	main
põhjusi	doc_399014257227_item	2384178	et	3	main
jäädvustamine	doc_399014257227_item	2384205	et	4	main
linnamuuseum	doc_399014257227_item	2384210	et	3	main
muu	doc_399014257227_item	2384223	et	4	main
hulgas	doc_399014257227_item	2384224	et	4	main
ta	doc_399014257227_item	2384225	et	4	main
1930	doc_399014257227_item	2384232	et	2	main
glaukoomi	doc_399014257227_item	2384234	et	4	main
sõja	doc_399014257227_item	2384245	et	3	main
tõttu	doc_399014257227_item	2384246	et	4	main
olnud	doc_399014257227_item	2384254	et	4	main
aastal	doc_399014257227_item	2384265	et	3	main
nälga	doc_399014257227_item	2384269	et	4	main
umbes	doc_399014257227_item	2384270	et	4	main
legendaarne	doc_399014257227_item	2384278	et	3	main
fotograaf	doc_399014257227_item	2384279	et	4	main
asemele	doc_399014257227_item	2384192	et	4	main
uue	doc_399014257227_item	2384193	et	3	main
alles	doc_399014257227_item	2384207	et	3	main
aastatel	doc_399014257227_item	2384209	et	4	main
sai	doc_399014257227_item	2384211	et	4	main
oma	doc_399014257227_item	2384212	et	4	main
põhikohaga	doc_399014257227_item	2384213	et	4	main
fotograafi	doc_399014257227_item	2384214	et	4	main
alles	doc_399014257227_item	2384215	et	3	main
1981	doc_399014257227_item	2384216	et	2	main
aastal	doc_399014257227_item	2384217	et	3	main
brander	doc_399014257227_item	2384218	et	4	main
jätkas	doc_399014257227_item	2384219	et	3	main
mujal	doc_399014257227_item	2384221	et	3	main
mõisaidtema	doc_399014257227_item	2384227	et	4	main
nõrgenesid	doc_399014257227_item	2384231	et	4	main
sattus	doc_399014257227_item	2384237	et	3	main
aastal	doc_399014257227_item	2384239	et	3	main
nikkilä	doc_399014257227_item	2384248	et	4	main
see	doc_399014257227_item	2384251	et	3	main
on	doc_399014257227_item	2384260	et	4	main
nikkilä	doc_399014257227_item	2384266	et	4	main
nende	doc_399014257227_item	2384273	et	4	main
brander	doc_399014257227_item	2384281	et	4	main
tõlge	doc_399014257228_item	2384288	et	3	main
signe	doc_399014257228_item	2384289	et	4	main
branderi	doc_399014257228_item	2384290	et	4	main
helsingi	doc_399014257228_item	2384291	et	4	main
linnamuuseum	doc_399014257228_item	2384292	et	3	main
tegi	doc_399014257228_item	2384293	et	4	main
raamatu	doc_399014257228_item	2384294	et	4	main
legendaarsest	doc_399014257228_item	2384295	et	3	main
fotograafist	doc_399014257228_item	2384296	et	4	main
raamat	doc_399014257228_item	2384297	et	3	main
viib	doc_399014257228_item	2384298	et	3	main
vaatama	doc_399014257228_item	2384299	et	3	main
saja	doc_399014257228_item	2384300	et	4	main
aasta	doc_399014257228_item	2384301	et	4	main
tagust	doc_399014257228_item	2384302	et	3	main
helsingi	doc_399014257228_item	2384303	et	4	main
helsingi	doc_399014257228_item	2384304	et	4	main
elanike	doc_399014257228_item	2384305	et	3	main
arv	doc_399014257228_item	2384306	et	3	main
ületas	doc_399014257228_item	2384307	et	3	main
100	doc_399014257228_item	2384308	et	2	main
000	doc_399014257228_item	2384309	et	2	main
inimese	doc_399014257228_item	2384310	et	4	main
piiri	doc_399014257228_item	2384311	et	4	main
aastal	doc_399014257228_item	2384312	et	3	main
1902	doc_399014257228_item	2384313	et	2	main
see	doc_399014257228_item	2384314	et	3	main
oli	doc_399014257228_item	2384315	et	3	main
kolme	doc_399014257228_item	2384316	et	4	main
aastakümne	doc_399014257228_item	2384317	et	4	main
jooksul	doc_399014257228_item	2384318	et	4	main
kolmekordistunud	doc_399014257228_item	2384319	et	4	main
linna	doc_399014257228_item	2384320	et	4	main
areng	doc_399014257228_item	2384324	et	3	main
aastasada	doc_399014257228_item	2384333	et	4	main
rajada	doc_399014257228_item	2384341	et	3	main
järgmisel	doc_399014257228_item	2384344	et	3	main
võttis	doc_399014257228_item	2384346	et	3	main
tohutu	doc_399014257228_item	2384321	et	4	main
panid	doc_399014257228_item	2384325	et	4	main
puuhoonetest	doc_399014257228_item	2384331	et	4	main
on	doc_399014257228_item	2384354	et	4	main
korda	doc_399014257228_item	2384356	et	4	main
907	doc_399014257228_item	2384372	et	2	main
pilti	doc_399014257228_item	2384373	et	4	main
fotokogu	doc_399014257228_item	2384378	et	4	main
nüüd	doc_399014257228_item	2384380	et	4	main
on	doc_399014257228_item	2384381	et	4	main
helsingi	doc_399014257228_item	2384382	et	4	main
linnamuuseum	doc_399014257228_item	2384383	et	3	main
välja	doc_399014257228_item	2384384	et	4	main
andnud	doc_399014257228_item	2384385	et	4	main
signe	doc_399014257228_item	2384386	et	4	main
branderi	doc_399014257228_item	2384387	et	4	main
piltidest	doc_399014257228_item	2384388	et	3	main
esimese	doc_399014257228_item	2384389	et	3	main
teose	doc_399014257228_item	2384390	et	3	main
mis	doc_399014257228_item	2384391	et	4	main
koosneb	doc_399014257228_item	2384392	et	3	main
täiesti	doc_399014257228_item	2384393	et	3	main
tema	doc_399014257228_item	2384394	et	4	main
fotodest	doc_399014257228_item	2384395	et	3	main
fotograaf	doc_399014257228_item	2384396	et	4	main
jan	doc_399014257228_item	2384397	et	4	main
alanco	doc_399014257228_item	2384398	et	4	main
ning	doc_399014257228_item	2384399	et	3	main
teadur	doc_399014257228_item	2384400	et	3	main
riitta	doc_399014257228_item	2384401	et	4	main
pakarinen	doc_399014257228_item	2384402	et	4	main
on	doc_399014257228_item	2384403	et	4	main
teinud	doc_399014257228_item	2384404	et	4	main
raamatu	doc_399014257228_item	2384405	et	4	main
mis	doc_399014257228_item	2384406	et	4	main
sisaldab	doc_399014257228_item	2384407	et	3	main
umbes	doc_399014257228_item	2384408	et	4	main
sada	doc_399014257228_item	2384409	et	4	main
signe	doc_399014257228_item	2384410	et	4	main
branderi	doc_399014257228_item	2384411	et	4	main
parimat	doc_399014257228_item	2384412	et	4	main
tööle	doc_399014257228_item	2384347	et	3	main
otsust	doc_399014257228_item	2384353	et	4	main
brander	doc_399014257228_item	2384362	et	4	main
aastat	doc_399014257228_item	2384366	et	3	main
selle	doc_399014257228_item	2384368	et	4	main
töö	doc_399014257228_item	2384369	et	4	main
tulemuseks	doc_399014257228_item	2384370	et	3	main
linnamuuseumi	doc_399014257228_item	2384377	et	4	main
fotod	doc_399014257228_item	2384413	et	3	main
helsingist	doc_399014257228_item	2384414	et	4	main
antud	doc_399014257228_item	2384420	et	4	main
väga	doc_399014257228_item	2384421	et	3	main
ta	doc_399014257228_item	2384440	et	4	main
oma	doc_399014257228_item	2384448	et	4	main
juhiks	doc_399014257228_item	2384465	et	4	main
oodata	doc_399014257228_item	2384474	et	4	main
helsingi	doc_399014257228_item	2384477	et	4	main
eriti	doc_399014257228_item	2384522	et	3	main
kunagi	doc_399014257228_item	2384534	et	3	main
helsingi	doc_399014257228_item	2384551	et	4	main
fotoateljeedes	doc_399014257228_item	2384552	et	3	main
töötamisest	doc_399014257228_item	2384553	et	4	main
aga	doc_399014257228_item	2384554	et	3	main
oskuslikult	doc_399014257228_item	2384571	et	4	main
pildistamisega	doc_399014257228_item	2384577	et	4	main
inimesed	doc_399014257228_item	2384578	et	3	main
on	doc_399014257228_item	2384588	et	4	main
rõõmsameelsusest	doc_399014257228_item	2384621	et	4	main
inimeste	doc_399014257228_item	2384633	et	3	main
detailiks	doc_399014257228_item	2384648	et	4	main
piki	doc_399014257228_item	2384649	et	4	main
seisav	doc_399014257228_item	2384657	et	4	main
lugeja	doc_399014257228_item	2384666	et	4	main
aasta	doc_399014257228_item	2384673	et	4	main
helsingit	doc_399014257228_item	2384675	et	4	main
retk	doc_399014257228_item	2384676	et	3	main
algab	doc_399014257228_item	2384677	et	3	main
kruununhaka	doc_399014257228_item	2384683	et	4	main
kampi	doc_399014257228_item	2384690	et	4	main
originaalkaart	doc_399014257228_item	2384699	et	4	main
mis	doc_399014257228_item	2384700	et	4	main
räägib	doc_399014257228_item	2384701	et	3	main
helsingi	doc_399014257228_item	2384736	et	4	main
siiski	doc_399014257228_item	2384742	et	4	main
tülli	doc_399014257228_item	2384743	et	4	main
1913	doc_399014257228_item	2384744	et	2	main
aastal	doc_399014257228_item	2384745	et	3	main
prokollidest	doc_399014257228_item	2384746	et	4	main
arvab	doc_399014257228_item	2384754	et	3	main
lihtsalt	doc_399014257228_item	2384758	et	4	main
aga	doc_399014257228_item	2384768	et	3	main
ta	doc_399014257228_item	2384800	et	4	main
ja	doc_399014257228_item	2384806	et	3	main
halvenema	doc_399014257228_item	2384809	et	3	main
viidi	doc_399014257228_item	2384815	et	4	main
1941	doc_399014257228_item	2384816	et	2	main
aastal	doc_399014257228_item	2384817	et	3	main
kivelä	doc_399014257228_item	2384818	et	4	main
patsiendid	doc_399014257228_item	2384821	et	3	main
paigutati	doc_399014257228_item	2384826	et	3	main
ümberpaigutamine	doc_399014257228_item	2384829	et	3	main
vaimsest	doc_399014257228_item	2384833	et	3	main
tervisest	doc_399014257228_item	2384834	et	4	main
ehkki	doc_399014257228_item	2384835	et	3	main
sõja	doc_399014257228_item	2384841	et	3	main
1942	doc_399014257228_item	2384847	et	2	main
saja	doc_399014257228_item	2384850	et	4	main
patsiendi	doc_399014257228_item	2384851	et	3	main
nälga	doc_399014257228_item	2384852	et	4	main
teiste	doc_399014257228_item	2384864	et	4	main
milles	doc_399014257228_item	2384424	et	3	main
liikmeteks	doc_399014257228_item	2384445	et	3	main
mõned	doc_399014257228_item	2384447	et	3	main
linnafotograafia	doc_399014257228_item	2384451	et	4	main
nyström	doc_399014257228_item	2384460	et	4	main
kes	doc_399014257228_item	2384461	et	4	main
oli	doc_399014257228_item	2384462	et	3	main
komisjon	doc_399014257228_item	2384466	et	3	main
muutusi	doc_399014257228_item	2384476	et	4	main
ja	doc_399014257228_item	2384479	et	3	main
ning	doc_399014257228_item	2384491	et	3	main
sajandi	doc_399014257228_item	2384493	et	3	main
alguses	doc_399014257228_item	2384494	et	4	main
rajatud	doc_399014257228_item	2384495	et	4	main
ühe-	doc_399014257228_item	2384496	et	4	main
ja	doc_399014257228_item	2384497	et	3	main
kahekorrulised	doc_399014257228_item	2384498	et	4	main
puuhooned	doc_399014257228_item	2384499	et	4	main
hakkasid	doc_399014257228_item	2384500	et	4	main
kaduma	doc_399014257228_item	2384501	et	4	main
kõrgete	doc_399014257228_item	2384502	et	4	main
kivimüüride	doc_399014257228_item	2384503	et	4	main
teelt	doc_399014257228_item	2384504	et	3	main
riitta	doc_399014257228_item	2384505	et	4	main
pakarise	doc_399014257228_item	2384506	et	4	main
hinnangul	doc_399014257228_item	2384507	et	3	main
oli	doc_399014257228_item	2384508	et	3	main
signe	doc_399014257228_item	2384509	et	4	main
branderi	doc_399014257228_item	2384510	et	4	main
valik	doc_399014257228_item	2384511	et	3	main
helsingi	doc_399014257228_item	2384512	et	4	main
pildistajaks	doc_399014257228_item	2384513	et	4	main
enesestmõistetav	doc_399014257228_item	2384514	et	3	main
ta	doc_399014257228_item	2384515	et	4	main
oli	doc_399014257228_item	2384516	et	3	main
juba	doc_399014257228_item	2384517	et	3	main
tõestanud	doc_399014257228_item	2384518	et	4	main
oma	doc_399014257228_item	2384519	et	4	main
fotograafi	doc_399014257228_item	2384520	et	4	main
andekust	doc_399014257228_item	2384521	et	4	main
maastiku	doc_399014257228_item	2384523	et	4	main
parkanos	doc_399014257228_item	2384525	et	4	main
brander	doc_399014257228_item	2384527	et	4	main
õpis	doc_399014257228_item	2384528	et	3	main
ametis	doc_399014257228_item	2384536	et	3	main
temast	doc_399014257228_item	2384538	et	3	main
tal	doc_399014257228_item	2384547	et	3	main
oma	doc_399014257228_item	2384560	et	4	main
surnud	doc_399014257228_item	2384575	et	4	main
arhitektuuri	doc_399014257228_item	2384576	et	4	main
ja	doc_399014257228_item	2384579	et	3	main
olid	doc_399014257228_item	2384581	et	4	main
tema	doc_399014257228_item	2384582	et	4	main
raamatuid	doc_399014257228_item	2384423	et	3	main
poolt	doc_399014257228_item	2384430	et	4	main
tehtud	doc_399014257228_item	2384431	et	4	main
pilti	doc_399014257228_item	2384432	et	4	main
sajandi	doc_399014257228_item	2384434	et	3	main
päris	doc_399014257228_item	2384441	et	4	main
parimad	doc_399014257228_item	2384450	et	4	main
asjatundjad	doc_399014257228_item	2384454	et	3	main
helsingi	doc_399014257228_item	2384463	et	4	main
olulisi	doc_399014257228_item	2384475	et	4	main
kasvas	doc_399014257228_item	2384478	et	3	main
sajandi	doc_399014257228_item	2384483	et	3	main
ehitama	doc_399014257228_item	2384486	et	4	main
linnaosi	doc_399014257228_item	2384490	et	4	main
1900	doc_399014257228_item	2384492	et	2	main
joonistusõpetajaks	doc_399014257228_item	2384530	et	3	main
aga	doc_399014257228_item	2384531	et	3	main
töötanud	doc_399014257228_item	2384533	et	4	main
seevastu	doc_399014257228_item	2384537	et	3	main
ja	doc_399014257228_item	2384545	et	3	main
aja	doc_399014257228_item	2384561	et	4	main
maastiku	doc_399014257228_item	2384569	et	4	main
üsna	doc_399014257228_item	2384570	et	3	main
tema	doc_399014257228_item	2384586	et	4	main
uudishimu	doc_399014257228_item	2384634	et	4	main
pildistamine	doc_399014257228_item	2384635	et	4	main
oli	doc_399014257228_item	2384636	et	3	main
veel	doc_399014257228_item	2384637	et	4	main
uus	doc_399014257228_item	2384638	et	3	main
asi	doc_399014257228_item	2384639	et	4	main
ja	doc_399014257228_item	2384640	et	3	main
naine	doc_399014257228_item	2384641	et	3	main
maastiku	doc_399014257228_item	2384642	et	4	main
pildistajana	doc_399014257228_item	2384643	et	4	main
haruldane	doc_399014257228_item	2384644	et	3	main
trammirööpaid	doc_399014257228_item	2384650	et	3	main
pildid	doc_399014257228_item	2384659	et	3	main
liikub	doc_399014257228_item	2384667	et	4	main
linnaosast	doc_399014257228_item	2384679	et	4	main
jätkub	doc_399014257228_item	2384680	et	3	main
linnaosadesse	doc_399014257228_item	2384686	et	3	main
jätkub	doc_399014257228_item	2384689	et	3	main
sündinud	doc_399014257228_item	2384526	et	4	main
selles	doc_399014257228_item	2384535	et	4	main
fotograaf	doc_399014257228_item	2384540	et	4	main
ateljeetööd	doc_399014257228_item	2384546	et	4	main
siiski	doc_399014257228_item	2384549	et	4	main
pühenduda	doc_399014257228_item	2384559	et	3	main
tehnika	doc_399014257228_item	2384563	et	4	main
pildistas	doc_399014257228_item	2384565	et	3	main
ta	doc_399014257228_item	2384572	et	4	main
ei	doc_399014257228_item	2384573	et	4	main
detailid	doc_399014257228_item	2384580	et	3	main
peaaegu	doc_399014257228_item	2384589	et	3	main
alati	doc_399014257228_item	2384590	et	4	main
möödakäijaid	doc_399014257228_item	2384591	et	3	main
lapsi	doc_399014257228_item	2384592	et	4	main
kaupmehi	doc_399014257228_item	2384593	et	3	main
politseinike	doc_399014257228_item	2384594	et	3	main
või	doc_399014257228_item	2384595	et	4	main
koduloomi	doc_399014257228_item	2384596	et	4	main
sada	doc_399014257228_item	2384597	et	4	main
aastat	doc_399014257228_item	2384598	et	3	main
tagasi	doc_399014257228_item	2384599	et	3	main
kasvatasid	doc_399014257228_item	2384600	et	4	main
venelased	doc_399014257228_item	2384601	et	3	main
helsingi	doc_399014257228_item	2384602	et	4	main
elanikele	doc_399014257228_item	2384603	et	3	main
töölös	doc_399014257228_item	2384604	et	4	main
köögivilja	doc_399014257228_item	2384605	et	4	main
sageli	doc_399014257228_item	2384606	et	3	main
on	doc_399014257228_item	2384607	et	4	main
inimesed	doc_399014257228_item	2384608	et	3	main
sattunud	doc_399014257228_item	2384609	et	4	main
pildile	doc_399014257228_item	2384610	et	3	main
juhuslikult	doc_399014257228_item	2384611	et	4	main
brander	doc_399014257228_item	2384612	et	4	main
on	doc_399014257228_item	2384613	et	4	main
palunud	doc_399014257228_item	2384614	et	4	main
hetkeks	doc_399014257228_item	2384616	et	4	main
neid	doc_399014257228_item	2384615	et	4	main
pildistamiseks	doc_399014257228_item	2384617	et	4	main
peatuda	doc_399014257228_item	2384618	et	3	main
inimeste	doc_399014257228_item	2384619	et	3	main
heatahtlikusest	doc_399014257228_item	2384620	et	4	main
võib	doc_399014257228_item	2384622	et	3	main
teadis	doc_399014257228_item	2384626	et	4	main
asja	doc_399014257228_item	2384629	et	4	main
esitada	doc_399014257228_item	2384630	et	3	main
ja	doc_399014257228_item	2384631	et	3	main
järeldada	doc_399014257228_item	2384623	et	3	main
on	doc_399014257228_item	2384646	et	4	main
pikantseks	doc_399014257228_item	2384647	et	3	main
jooksev	doc_399014257228_item	2384651	et	4	main
hobune	doc_399014257228_item	2384658	et	4	main
on	doc_399014257228_item	2384660	et	4	main
järjestatud	doc_399014257228_item	2384662	et	4	main
nagu	doc_399014257228_item	2384669	et	3	main
hermanni	doc_399014257228_item	2384678	et	4	main
kaudu	doc_399014257228_item	2384684	et	3	main
sealt	doc_399014257228_item	2384687	et	4	main
töölö	doc_399014257228_item	2384692	et	4	main
iga	doc_399014257228_item	2384694	et	4	main
on	doc_399014257228_item	2384697	et	4	main
täpne	doc_399014257228_item	2384698	et	3	main
kust	doc_399014257228_item	2384702	et	4	main
kohast	doc_399014257228_item	2384703	et	4	main
foto	doc_399014257228_item	2384704	et	4	main
on	doc_399014257228_item	2384705	et	4	main
tehtud	doc_399014257228_item	2384706	et	4	main
ja	doc_399014257228_item	2384707	et	3	main
millises	doc_399014257228_item	2384708	et	3	main
suunas	doc_399014257228_item	2384709	et	4	main
vaade	doc_399014257228_item	2384710	et	3	main
on	doc_399014257228_item	2384711	et	4	main
kaart	doc_399014257228_item	2384712	et	4	main
on	doc_399014257228_item	2384713	et	4	main
tänapäeva	doc_399014257228_item	2384714	et	4	main
lugejale	doc_399014257228_item	2384715	et	4	main
vältimatu	doc_399014257228_item	2384716	et	4	main
sest	doc_399014257228_item	2384717	et	4	main
linn	doc_399014257228_item	2384718	et	3	main
on	doc_399014257228_item	2384719	et	4	main
mitmes	doc_399014257228_item	2384720	et	4	main
köögivilja	doc_399014257228_item	2384735	et	4	main
brander	doc_399014257228_item	2384738	et	4	main
komisjon	doc_399014257228_item	2384740	et	3	main
läksid	doc_399014257228_item	2384741	et	4	main
põhjuseks	doc_399014257228_item	2384752	et	3	main
pakarinen	doc_399014257228_item	2384753	et	4	main
riid	doc_399014257228_item	2384756	et	3	main
tekis	doc_399014257228_item	2384757	et	3	main
esimese	doc_399014257228_item	2384769	et	3	main
oma	doc_399014257228_item	2384794	et	4	main
pildistas	doc_399014257228_item	2384801	et	3	main
brander	doc_399014257228_item	2384814	et	4	main
kuidas	doc_399014257228_item	2384627	et	3	main
oma	doc_399014257228_item	2384628	et	4	main
mõnikord	doc_399014257228_item	2384645	et	3	main
koer	doc_399014257228_item	2384652	et	3	main
keset	doc_399014257228_item	2384654	et	4	main
raamatus	doc_399014257228_item	2384661	et	4	main
vastavalt	doc_399014257228_item	2384663	et	4	main
uurimusretkele	doc_399014257228_item	2384664	et	4	main
kus	doc_399014257228_item	2384665	et	3	main
keset	doc_399014257228_item	2384671	et	4	main
lõunapoolsetesse	doc_399014257228_item	2384685	et	4	main
kaudu	doc_399014257228_item	2384691	et	3	main
linnaossa	doc_399014257228_item	2384693	et	3	main
foto	doc_399014257228_item	2384695	et	4	main
kõrval	doc_399014257228_item	2384696	et	4	main
kohas	doc_399014257228_item	2384721	et	4	main
täitsa	doc_399014257228_item	2384723	et	3	main
äratundmatuks	doc_399014257228_item	2384724	et	4	main
näiteks	doc_399014257228_item	2384725	et	4	main
maakoht	doc_399014257228_item	2384731	et	3	main
venelased	doc_399014257228_item	2384733	et	3	main
ei	doc_399014257228_item	2384747	et	4	main
erimeelsuse	doc_399014257228_item	2384751	et	4	main
raha	doc_399014257228_item	2384759	et	4	main
maailmasõja	doc_399014257228_item	2384770	et	3	main
fotograafi	doc_399014257228_item	2384795	et	4	main
tööd	doc_399014257228_item	2384796	et	4	main
soome	doc_399014257228_item	2384797	et	3	main
nägemine	doc_399014257228_item	2384807	et	4	main
glaukoomi	doc_399014257228_item	2384812	et	4	main
tõttu	doc_399014257228_item	2384813	et	4	main
sõja	doc_399014257228_item	2384823	et	3	main
nikkilä	doc_399014257228_item	2384827	et	4	main
tulenenud	doc_399014257228_item	2384831	et	4	main
oludes	doc_399014257228_item	2384843	et	3	main
üle	doc_399014257228_item	2384849	et	3	main
oli	doc_399014257228_item	2384855	et	3	main
legendaarne	doc_399014257228_item	2384856	et	3	main
pildistaja	doc_399014257228_item	2384858	et	4	main
maeti	doc_399014257228_item	2384862	et	3	main
ühishauda	doc_399014257228_item	2384866	et	4	main
äratas	doc_399014257228_item	2384632	et	3	main
või	doc_399014257228_item	2384653	et	4	main
hoovi	doc_399014257228_item	2384655	et	4	main
rakmedeta	doc_399014257228_item	2384656	et	4	main
ringi	doc_399014257228_item	2384668	et	4	main
matkal	doc_399014257228_item	2384670	et	3	main
saja	doc_399014257228_item	2384672	et	4	main
tagust	doc_399014257228_item	2384674	et	3	main
hakaniemi	doc_399014257228_item	2384681	et	4	main
ja	doc_399014257228_item	2384682	et	3	main
see	doc_399014257228_item	2384688	et	3	main
töölö	doc_399014257228_item	2384726	et	4	main
oli	doc_399014257228_item	2384727	et	3	main
fotode	doc_399014257228_item	2384729	et	3	main
kus	doc_399014257228_item	2384732	et	3	main
elanikele	doc_399014257228_item	2384737	et	3	main
oli	doc_399014257228_item	2384750	et	3	main
et	doc_399014257228_item	2384755	et	3	main
asemel	doc_399014257228_item	2384764	et	4	main
tööle	doc_399014257228_item	2384765	et	3	main
uue	doc_399014257228_item	2384766	et	3	main
fotograafi	doc_399014257228_item	2384767	et	4	main
1914	doc_399014257228_item	2384772	et	2	main
erinevates	doc_399014257228_item	2384798	et	4	main
kohtades	doc_399014257228_item	2384799	et	3	main
näiteks	doc_399014257228_item	2384802	et	4	main
mõisahooneid	doc_399014257228_item	2384803	et	4	main
tema	doc_399014257228_item	2384804	et	4	main
hakkasid	doc_399014257228_item	2384808	et	4	main
haiglasse	doc_399014257228_item	2384819	et	4	main
kust	doc_399014257228_item	2384820	et	4	main
tõttu	doc_399014257228_item	2384824	et	4	main
ei	doc_399014257228_item	2384830	et	4	main
branderi	doc_399014257228_item	2384832	et	4	main
väidetud	doc_399014257228_item	2384840	et	4	main
nikkilä	doc_399014257228_item	2384845	et	4	main
kes	doc_399014257228_item	2384861	et	4	main
muutunud	doc_399014257228_item	2384722	et	4	main
branderi	doc_399014257228_item	2384728	et	4	main
ajal	doc_399014257228_item	2384730	et	4	main
kasvatasid	doc_399014257228_item	2384734	et	4	main
ja	doc_399014257228_item	2384739	et	3	main
ilmne	doc_399014257228_item	2384748	et	4	main
mis	doc_399014257228_item	2384749	et	4	main
pärast	doc_399014257228_item	2384760	et	4	main
linnamuuseum	doc_399014257228_item	2384761	et	3	main
võttis	doc_399014257228_item	2384762	et	3	main
branderi	doc_399014257228_item	2384763	et	4	main
algus	doc_399014257228_item	2384771	et	4	main
lõpetas	doc_399014257228_item	2384773	et	3	main
pildistamise	doc_399014257228_item	2384774	et	4	main
mitmeks	doc_399014257228_item	2384775	et	4	main
aastakümneks	doc_399014257228_item	2384776	et	4	main
plaanipärane	doc_399014257228_item	2384777	et	4	main
linnakeskkonna	doc_399014257228_item	2384778	et	3	main
pildistamine	doc_399014257228_item	2384779	et	4	main
algas	doc_399014257228_item	2384780	et	3	main
uuesti	doc_399014257228_item	2384781	et	3	main
alles	doc_399014257228_item	2384782	et	3	main
1950	doc_399014257228_item	2384783	et	2	main
aastatel	doc_399014257228_item	2384784	et	4	main
linnamuuseum	doc_399014257228_item	2384785	et	3	main
sai	doc_399014257228_item	2384786	et	4	main
oma	doc_399014257228_item	2384787	et	4	main
alalise	doc_399014257228_item	2384788	et	4	main
fotograafi	doc_399014257228_item	2384789	et	4	main
alles	doc_399014257228_item	2384790	et	3	main
1981	doc_399014257228_item	2384791	et	2	main
brander	doc_399014257228_item	2384792	et	4	main
jätkas	doc_399014257228_item	2384793	et	3	main
tervis	doc_399014257228_item	2384805	et	3	main
1930	doc_399014257228_item	2384810	et	2	main
aastatel	doc_399014257228_item	2384811	et	4	main
ümber	doc_399014257228_item	2384825	et	3	main
seda	doc_399014257228_item	2384836	et	3	main
on	doc_399014257228_item	2384837	et	4	main
ka	doc_399014257228_item	2384838	et	3	main
segastes	doc_399014257228_item	2384842	et	3	main
hulgas	doc_399014257228_item	2384854	et	4	main
patsientidega	doc_399014257228_item	2384865	et	3	main
hiljem	doc_399014257228_item	2384822	et	3	main
psühhiaatriahaiglasse	doc_399014257228_item	2384828	et	4	main
kunagi	doc_399014257228_item	2384839	et	3	main
suri	doc_399014257228_item	2384844	et	3	main
haiglas	doc_399014257228_item	2384846	et	3	main
aastal	doc_399014257228_item	2384848	et	3	main
nende	doc_399014257228_item	2384853	et	4	main
helsingi	doc_399014257228_item	2384857	et	4	main
signe	doc_399014257228_item	2384859	et	4	main
brander	doc_399014257228_item	2384860	et	4	main
koos	doc_399014257228_item	2384863	et	4	main
kalevipoja	doc_399014257230_item	2385260	et	4	main
eesti	doc_399014257230_item	2385267	et	4	main
kõrge	doc_399014257230_item	2385280	et	4	main
kalevipoeg	doc_399014257230_item	2385281	et	3	main
rahvuseepose	doc_399014257230_item	2385282	et	3	main
korraldatud	doc_399014257230_item	2385287	et	4	main
tallinnast	doc_399014257230_item	2385305	et	3	main
maailmasõja	doc_399014257230_item	2385315	et	3	main
obelisk	doc_399014257230_item	2385323	et	3	main
ning	doc_399014257230_item	2385324	et	3	main
linna	doc_399014257230_item	2385326	et	4	main
ja	doc_399014257230_item	2385327	et	3	main
lahkhelid	doc_399014257230_item	2385330	et	3	main
kuju	doc_399014257230_item	2385332	et	4	main
suurusest	doc_399014257230_item	2385333	et	4	main
eesti	doc_399014257230_item	2385337	et	4	main
aja	doc_399014257230_item	2385349	et	4	main
mälestusmärgikompleksi	doc_399014257230_item	2385350	et	4	main
kõrvale	doc_399014257230_item	2385351	et	4	main
varem	doc_399014257230_item	2385352	et	4	main
sügisel	doc_399014257230_item	2385353	et	3	main
nii	doc_399014257230_item	2385354	et	3	main
skulptorite	doc_399014257230_item	2385355	et	3	main
kui	doc_399014257230_item	2385356	et	3	main
ka	doc_399014257230_item	2385357	et	3	main
tõmbasid	doc_399014257230_item	2385360	et	4	main
on	doc_399014257230_item	2385389	et	4	main
kalevipoja-üritust	doc_399014257230_item	2385400	et	4	main
juba	doc_399014257230_item	2385401	et	3	main
oli	doc_399014257230_item	2385406	et	3	main
sümbool	doc_399014257230_item	2385412	et	4	main
kavas	doc_399014257230_item	2385414	et	3	main
tallinna	doc_399014257230_item	2385415	et	4	main
lisati	doc_399014257230_item	2385428	et	3	main
järele	doc_399014257230_item	2385432	et	4	main
mälestusmärk	doc_399014257230_item	2385434	et	3	main
kokku	doc_399014257230_item	2385436	et	3	main
seda	doc_399014257230_item	2385443	et	3	main
see	doc_399014257230_item	2385448	et	3	main
aselinnapea	doc_399014257230_item	2385452	et	4	main
supelranna	doc_399014257230_item	2385468	et	3	main
tauno	doc_399014257230_item	2385481	et	4	main
esmaspäeval	doc_399014257230_item	2385486	et	3	main
kunstnik	doc_399014257230_item	2385489	et	3	main
ei	doc_399014257230_item	2385491	et	4	main
olnud	doc_399014257230_item	2385492	et	4	main
vaate	doc_399014257230_item	2385522	et	4	main
eestlaste	doc_399014257230_item	2385531	et	4	main
kujuplaani	doc_399014257230_item	2385536	et	4	main
tõlge	doc_399014257230_item	2385253	et	3	main
kunstiühingud	doc_399014257230_item	2385254	et	3	main
vaatavad	doc_399014257230_item	2385255	et	4	main
viltu	doc_399014257230_item	2385256	et	3	main
kujule	doc_399014257230_item	2385261	et	3	main
linnavalitsusele	doc_399014257230_item	2385263	et	4	main
võitlustööd	doc_399014257230_item	2385266	et	4	main
tallinna	doc_399014257230_item	2385271	et	4	main
mitmekorruselise	doc_399014257230_item	2385275	et	4	main
tähtaja	doc_399014257230_item	2385290	et	3	main
meetri	doc_399014257230_item	2385302	et	3	main
viiva	doc_399014257230_item	2385307	et	4	main
rannatee	doc_399014257230_item	2385308	et	4	main
kõrge	doc_399014257230_item	2385322	et	4	main
ja	doc_399014257230_item	2385334	et	3	main
on	doc_399014257230_item	2385341	et	4	main
vananenud	doc_399014257230_item	2385343	et	4	main
sobi	doc_399014257230_item	2385347	et	4	main
nõukogude	doc_399014257230_item	2385348	et	3	main
ära	doc_399014257230_item	2385363	et	4	main
züriist	doc_399014257230_item	2385364	et	4	main
linna	doc_399014257230_item	2385384	et	4	main
idee	doc_399014257230_item	2385387	et	4	main
hiiglaslikule	doc_399014257230_item	2385259	et	3	main
tallinna	doc_399014257230_item	2385262	et	4	main
vaatavad	doc_399014257230_item	2385269	et	4	main
kavale	doc_399014257230_item	2385272	et	3	main
võitlusele	doc_399014257230_item	2385288	et	3	main
lõppedes	doc_399014257230_item	2385291	et	4	main
ainult	doc_399014257230_item	2385293	et	4	main
kolm	doc_399014257230_item	2385294	et	3	main
rannast	doc_399014257230_item	2385304	et	4	main
piritale	doc_399014257230_item	2385306	et	4	main
äärde	doc_399014257230_item	2385309	et	4	main
rannas	doc_399014257230_item	2385310	et	3	main
idee	doc_399014257230_item	2385340	et	4	main
ega	doc_399014257230_item	2385344	et	3	main
rahvuseepose	doc_399014257230_item	2385345	et	3	main
kangelane	doc_399014257230_item	2385346	et	3	main
ametiühingud	doc_399014257230_item	2385359	et	3	main
plaaninud	doc_399014257230_item	2385383	et	4	main
algupärase	doc_399014257230_item	2385386	et	4	main
skulptor	doc_399014257230_item	2385393	et	3	main
tauno	doc_399014257230_item	2385394	et	4	main
aastate	doc_399014257230_item	2385403	et	3	main
mereneiu	doc_399014257230_item	2385410	et	4	main
väike	doc_399014257230_item	2385416	et	4	main
mereneiu	doc_399014257230_item	2385417	et	4	main
oli	doc_399014257230_item	2385418	et	3	main
kõrge	doc_399014257230_item	2385422	et	4	main
21	doc_399014257230_item	2385429	et	2	main
mälestusmärgikompleksiga	doc_399014257230_item	2385438	et	4	main
jõudsime	doc_399014257230_item	2385444	et	3	main
meetrit	doc_399014257230_item	2385447	et	3	main
hea	doc_399014257230_item	2385461	et	4	main
pirita	doc_399014257230_item	2385467	et	4	main
tallinna	doc_399014257230_item	2385470	et	4	main
varjuta	doc_399014257230_item	2385478	et	4	main
vanalinna	doc_399014257230_item	2385479	et	4	main
galeriis	doc_399014257230_item	2385483	et	3	main
ise	doc_399014257230_item	2385490	et	4	main
linnas	doc_399014257230_item	2385493	et	4	main
aga	doc_399014257230_item	2385494	et	3	main
sümboliseerivad	doc_399014257230_item	2385530	et	4	main
boikoteerib	doc_399014257230_item	2385537	et	3	main
mõjukam	doc_399014257230_item	2385539	et	4	main
mis	doc_399014257230_item	2385542	et	4	main
kakleb	doc_399014257230_item	2385543	et	3	main
linnajuhatusega	doc_399014257230_item	2385544	et	4	main
erakonnana	doc_399014257230_item	2385555	et	4	main
kujuplaani	doc_399014257230_item	2385569	et	4	main
turustanud	doc_399014257230_item	2385578	et	4	main
tulemused	doc_399014257230_item	2385612	et	3	main
avalikustatakse	doc_399014257230_item	2385613	et	3	main
on	doc_399014257230_item	2385625	et	4	main
tuleva	doc_399014257230_item	2385628	et	4	main
helsingi	doc_399014257231_item	2385636	et	4	main
viib	doc_399014257231_item	2385643	et	3	main
helsingisse	doc_399014257231_item	2385648	et	4	main
tallinalahte	doc_399014257230_item	2385257	et	4	main
kolm	doc_399014257230_item	2385265	et	3	main
püstitada	doc_399014257230_item	2385273	et	3	main
samanimelise	doc_399014257230_item	2385283	et	4	main
kangelasisiku	doc_399014257230_item	2385284	et	3	main
järgi	doc_399014257230_item	2385285	et	4	main
oli	doc_399014257230_item	2385289	et	3	main
võistlusettepanekut	doc_399014257230_item	2385295	et	3	main
on	doc_399014257230_item	2385297	et	4	main
kavatsetud	doc_399014257230_item	2385298	et	4	main
püstitada	doc_399014257230_item	2385299	et	3	main
merre	doc_399014257230_item	2385300	et	3	main
saja	doc_399014257230_item	2385301	et	4	main
on	doc_399014257230_item	2385311	et	4	main
rannatrepikoda	doc_399014257230_item	2385325	et	4	main
asukohast	doc_399014257230_item	2385335	et	4	main
ühingu	doc_399014257230_item	2385339	et	3	main
tegelikult	doc_399014257230_item	2385342	et	4	main
arhitektide	doc_399014257230_item	2385358	et	3	main
esindaja	doc_399014257230_item	2385362	et	4	main
parke	doc_399014257230_item	2385385	et	3	main
isa	doc_399014257230_item	2385388	et	4	main
vaidlusalune	doc_399014257230_item	2385392	et	4	main
kangro	doc_399014257230_item	2385395	et	4	main
40	doc_399014257230_item	2385396	et	2	main
kes	doc_399014257230_item	2385397	et	4	main
algas	doc_399014257230_item	2385398	et	3	main
turustada	doc_399014257230_item	2385399	et	3	main
1990	doc_399014257230_item	2385402	et	2	main
kopenhaageni	doc_399014257230_item	2385408	et	4	main
meetrit	doc_399014257230_item	2385421	et	3	main
linna	doc_399014257230_item	2385424	et	4	main
maarjamäe	doc_399014257230_item	2385437	et	3	main
ja	doc_399014257230_item	2385441	et	3	main
21	doc_399014257230_item	2385446	et	2	main
olga	doc_399014257230_item	2385453	et	4	main
sõtnik	doc_399014257230_item	2385454	et	4	main
on	doc_399014257230_item	2385458	et	4	main
ka	doc_399014257230_item	2385459	et	3	main
ei	doc_399014257230_item	2385477	et	4	main
valitses	doc_399014257230_item	2385484	et	3	main
atmosfäär	doc_399014257230_item	2385488	et	3	main
kunstniku	doc_399014257230_item	2385521	et	3	main
veel	doc_399014257230_item	2385524	et	4	main
paat	doc_399014257230_item	2385525	et	3	main
ja	doc_399014257230_item	2385526	et	3	main
mõned	doc_399014257230_item	2385527	et	3	main
inimisikud	doc_399014257230_item	2385528	et	3	main
peale	doc_399014257230_item	2385533	et	4	main
ühingut	doc_399014257230_item	2385535	et	3	main
näiteks	doc_399014257230_item	2385546	et	4	main
juures	doc_399014257230_item	2385553	et	4	main
mis	doc_399014257230_item	2385557	et	4	main
hoonete	doc_399014257230_item	2385564	et	4	main
vastu	doc_399014257230_item	2385570	et	3	main
aega	doc_399014257230_item	2385577	et	4	main
merre	doc_399014257230_item	2385610	et	3	main
järgmise	doc_399014257230_item	2385630	et	3	main
tõlge	doc_399014257231_item	2385633	et	3	main
branderi	doc_399014257231_item	2385635	et	4	main
raamatu	doc_399014257231_item	2385639	et	4	main
raamat	doc_399014257231_item	2385642	et	3	main
ringsõidule	doc_399014257231_item	2385644	et	3	main
tagusesse	doc_399014257231_item	2385647	et	4	main
ületas	doc_399014257231_item	2385651	et	3	main
piiri	doc_399014257231_item	2385654	et	4	main
see	doc_399014257231_item	2385659	et	3	main
tagasi	doc_399014257231_item	2385670	et	3	main
helsingi	doc_399014257231_item	2385673	et	4	main
kavatsetud	doc_399014257230_item	2385258	et	4	main
jäeti	doc_399014257230_item	2385264	et	3	main
kunstnikud	doc_399014257230_item	2385268	et	3	main
viltu	doc_399014257230_item	2385270	et	3	main
tallinnalahte	doc_399014257230_item	2385274	et	4	main
maja	doc_399014257230_item	2385276	et	4	main
suurune	doc_399014257230_item	2385277	et	4	main
21	doc_399014257230_item	2385278	et	2	main
meetrit	doc_399014257230_item	2385279	et	3	main
linna	doc_399014257230_item	2385286	et	4	main
jäetud	doc_399014257230_item	2385292	et	4	main
kalevipoeg	doc_399014257230_item	2385296	et	3	main
kaugusele	doc_399014257230_item	2385303	et	4	main
vastaval	doc_399014257230_item	2385312	et	4	main
kohal	doc_399014257230_item	2385313	et	4	main
teise	doc_399014257230_item	2385314	et	4	main
kangelastele	doc_399014257230_item	2385316	et	4	main
püstitatud	doc_399014257230_item	2385317	et	4	main
mälestusmärgikompleks	doc_399014257230_item	2385318	et	3	main
kust	doc_399014257230_item	2385319	et	4	main
paistavad	doc_399014257230_item	2385320	et	3	main
merele	doc_399014257230_item	2385321	et	3	main
skulptorite	doc_399014257230_item	2385328	et	3	main
ühingu	doc_399014257230_item	2385329	et	3	main
algavad	doc_399014257230_item	2385331	et	4	main
meres	doc_399014257230_item	2385336	et	3	main
skulptorite	doc_399014257230_item	2385338	et	3	main
oma	doc_399014257230_item	2385361	et	4	main
protestiks	doc_399014257230_item	2385365	et	4	main
zrürii	doc_399014257230_item	2385366	et	4	main
bürokraatlikkuse	doc_399014257230_item	2385367	et	4	main
vastu	doc_399014257230_item	2385368	et	3	main
linnapea	doc_399014257230_item	2385369	et	4	main
jüri	doc_399014257230_item	2385370	et	4	main
ratase	doc_399014257230_item	2385371	et	4	main
32	doc_399014257230_item	2385372	et	2	main
juhitud	doc_399014257230_item	2385373	et	4	main
ainukeseks	doc_399014257230_item	2385375	et	4	main
sõltumatuks	doc_399014257230_item	2385376	et	4	main
kunstnikuliikmeks	doc_399014257230_item	2385377	et	3	main
zürii	doc_399014257230_item	2385374	et	4	main
on	doc_399014257230_item	2385378	et	4	main
jäänud	doc_399014257230_item	2385379	et	4	main
maastikuarhitekt	doc_399014257230_item	2385380	et	3	main
kes	doc_399014257230_item	2385381	et	4	main
on	doc_399014257230_item	2385382	et	4	main
siiski	doc_399014257230_item	2385390	et	4	main
ideeks	doc_399014257230_item	2385405	et	3	main
luua	doc_399014257230_item	2385407	et	4	main
väikse	doc_399014257230_item	2385409	et	4	main
ainult	doc_399014257230_item	2385419	et	4	main
14	doc_399014257230_item	2385420	et	2	main
kunstnik	doc_399014257230_item	2385391	et	3	main
lõpus	doc_399014257230_item	2385404	et	4	main
taoline	doc_399014257230_item	2385411	et	3	main
algupärases	doc_399014257230_item	2385413	et	4	main
aga	doc_399014257230_item	2385423	et	3	main
ettepaneku	doc_399014257230_item	2385425	et	3	main
kohaselt	doc_399014257230_item	2385426	et	4	main
meetrini	doc_399014257230_item	2385430	et	3	main
kuidas	doc_399014257230_item	2385433	et	3	main
arvestusi	doc_399014257230_item	2385440	et	4	main
visualiseerisime	doc_399014257230_item	2385442	et	4	main
silma	doc_399014257230_item	2385450	et	4	main
võimalikult	doc_399014257230_item	2385460	et	4	main
asub	doc_399014257230_item	2385464	et	3	main
turismiliini	doc_399014257230_item	2385465	et	4	main
ääres	doc_399014257230_item	2385466	et	4	main
botaanikaaia	doc_399014257230_item	2385471	et	4	main
sõites	doc_399014257230_item	2385473	et	3	main
peale	doc_399014257230_item	2385474	et	4	main
seda	doc_399014257230_item	2385475	et	3	main
see	doc_399014257230_item	2385476	et	3	main
kangro	doc_399014257230_item	2385482	et	4	main
vaimustunud	doc_399014257230_item	2385487	et	4	main
kõrgust	doc_399014257230_item	2385427	et	4	main
mõtlesime	doc_399014257230_item	2385431	et	3	main
sobib	doc_399014257230_item	2385435	et	3	main
tegime	doc_399014257230_item	2385439	et	3	main
tulemuseni	doc_399014257230_item	2385445	et	3	main
tõrkaks	doc_399014257230_item	2385449	et	4	main
põhjendab	doc_399014257230_item	2385451	et	3	main
sõtniku	doc_399014257230_item	2385455	et	4	main
järgi	doc_399014257230_item	2385456	et	4	main
koht	doc_399014257230_item	2385457	et	3	main
sest	doc_399014257230_item	2385462	et	4	main
see	doc_399014257230_item	2385463	et	3	main
ja	doc_399014257230_item	2385469	et	3	main
poole	doc_399014257230_item	2385472	et	4	main
siluetti	doc_399014257230_item	2385480	et	4	main
veel	doc_399014257230_item	2385485	et	4	main
galerist	doc_399014257230_item	2385495	et	4	main
pille	doc_399014257230_item	2385496	et	3	main
mägila	doc_399014257230_item	2385497	et	4	main
esitles	doc_399014257230_item	2385498	et	3	main
vaimustunult	doc_399014257230_item	2385499	et	4	main
pronksikuju	doc_399014257230_item	2385500	et	4	main
milles	doc_399014257230_item	2385501	et	3	main
suurte	doc_399014257230_item	2385502	et	3	main
peodega	doc_399014257230_item	2385503	et	3	main
kalevipoeg	doc_399014257230_item	2385504	et	3	main
kannab	doc_399014257230_item	2385505	et	3	main
paati	doc_399014257230_item	2385506	et	4	main
kuju	doc_399014257230_item	2385507	et	4	main
sümboliseerib	doc_399014257230_item	2385508	et	3	main
kangelase	doc_399014257230_item	2385509	et	3	main
kojutulekut	doc_399014257230_item	2385510	et	3	main
reisilt	doc_399014257230_item	2385511	et	3	main
mille	doc_399014257230_item	2385512	et	3	main
on	doc_399014257230_item	2385514	et	4	main
ta	doc_399014257230_item	2385513	et	4	main
teinud	doc_399014257230_item	2385515	et	4	main
maailma	doc_399014257230_item	2385516	et	4	main
ringi	doc_399014257230_item	2385517	et	4	main
kangelase	doc_399014257230_item	2385518	et	3	main
käes	doc_399014257230_item	2385519	et	4	main
on	doc_399014257230_item	2385520	et	4	main
järgi	doc_399014257230_item	2385523	et	4	main
kes	doc_399014257230_item	2385529	et	4	main
kojutulekut	doc_399014257230_item	2385532	et	3	main
arhitektide	doc_399014257230_item	2385540	et	3	main
uue	doc_399014257230_item	2385547	et	3	main
keskerakond	doc_399014257230_item	2385556	et	3	main
varem	doc_399014257230_item	2385560	et	4	main
huvi	doc_399014257230_item	2385562	et	4	main
kõrgete	doc_399014257230_item	2385563	et	4	main
pärast	doc_399014257230_item	2385572	et	4	main
kui	doc_399014257230_item	2385574	et	3	main
kaua	doc_399014257230_item	2385576	et	3	main
jaanuari	doc_399014257230_item	2385614	et	4	main
ja	doc_399014257230_item	2385616	et	3	main
skulptorite	doc_399014257230_item	2385534	et	3	main
veelgi	doc_399014257230_item	2385538	et	4	main
liit	doc_399014257230_item	2385541	et	3	main
linnamaja	doc_399014257230_item	2385548	et	4	main
tallinnas	doc_399014257230_item	2385550	et	4	main
ainukese	doc_399014257230_item	2385554	et	4	main
osutanud	doc_399014257230_item	2385561	et	4	main
teiste	doc_399014257230_item	2385566	et	4	main
kasvas	doc_399014257230_item	2385571	et	3	main
seda	doc_399014257230_item	2385573	et	3	main
ideed	doc_399014257230_item	2385575	et	4	main
kangro	doc_399014257230_item	2385579	et	4	main
liitus	doc_399014257230_item	2385580	et	4	main
suvel	doc_399014257230_item	2385581	et	3	main
keskerakonda	doc_399014257230_item	2385582	et	4	main
on	doc_399014257230_item	2385584	et	4	main
kriitikat	doc_399014257230_item	2385583	et	3	main
saanud	doc_399014257230_item	2385585	et	4	main
osaks	doc_399014257230_item	2385586	et	3	main
ka	doc_399014257230_item	2385587	et	3	main
kalevipoeg	doc_399014257230_item	2385588	et	3	main
ise	doc_399014257230_item	2385589	et	4	main
kes	doc_399014257230_item	2385590	et	4	main
legenda	doc_399014257230_item	2385591	et	4	main
järgi	doc_399014257230_item	2385592	et	4	main
viskas	doc_399014257230_item	2385593	et	3	main
kividega	doc_399014257230_item	2385594	et	3	main
vaenlasi	doc_399014257230_item	2385595	et	3	main
oli	doc_399014257230_item	2385597	et	3	main
aga	doc_399014257230_item	2385596	et	3	main
süüdi	doc_399014257230_item	2385598	et	4	main
ka	doc_399014257230_item	2385599	et	3	main
neitsi	doc_399014257230_item	2385600	et	4	main
vägistamises	doc_399014257230_item	2385601	et	4	main
meres	doc_399014257230_item	2385602	et	3	main
on	doc_399014257230_item	2385603	et	4	main
küsitud	doc_399014257230_item	2385604	et	4	main
kas	doc_399014257230_item	2385605	et	3	main
tema	doc_399014257230_item	2385606	et	4	main
ka	doc_399014257230_item	2385545	et	3	main
asukohast	doc_399014257230_item	2385549	et	4	main
on	doc_399014257230_item	2385551	et	4	main
võimu	doc_399014257230_item	2385552	et	4	main
on	doc_399014257230_item	2385558	et	4	main
juba	doc_399014257230_item	2385559	et	3	main
vastu	doc_399014257230_item	2385565	et	3	main
kunstnikkute	doc_399014257230_item	2385567	et	4	main
kriitika	doc_399014257230_item	2385568	et	4	main
on	doc_399014257230_item	2385607	et	4	main
sobiv	doc_399014257230_item	2385608	et	4	main
sümbool	doc_399014257230_item	2385609	et	4	main
lõpus	doc_399014257230_item	2385615	et	4	main
korraldatakse	doc_399014257230_item	2385619	et	3	main
näitus	doc_399014257230_item	2385620	et	3	main
sõtniku	doc_399014257230_item	2385622	et	4	main
püstitada	doc_399014257230_item	2385627	et	3	main
aasta	doc_399014257230_item	2385631	et	4	main
jooksul	doc_399014257230_item	2385632	et	4	main
aasta	doc_399014257231_item	2385646	et	4	main
rahvaarv	doc_399014257231_item	2385650	et	3	main
sada	doc_399014257231_item	2385668	et	4	main
aastat	doc_399014257231_item	2385669	et	3	main
ja	doc_399014257231_item	2385672	et	3	main
kaduvate	doc_399014257231_item	2385676	et	4	main
linna	doc_399014257231_item	2385678	et	4	main
helsingi	doc_399014257231_item	2385680	et	4	main
linnavolikogu	doc_399014257231_item	2385681	et	4	main
otsustas	doc_399014257231_item	2385682	et	3	main
1906	doc_399014257231_item	2385683	et	2	main
aastal	doc_399014257231_item	2385684	et	3	main
rajada	doc_399014257231_item	2385685	et	3	main
signe	doc_399014257231_item	2385692	et	4	main
helsingi	doc_399014257231_item	2385722	et	4	main
linnamuuseum	doc_399014257231_item	2385727	et	3	main
nüüd	doc_399014257231_item	2385729	et	4	main
avalikustanud	doc_399014257231_item	2385730	et	4	main
piltidest	doc_399014257231_item	2385733	et	3	main
teose	doc_399014257231_item	2385735	et	3	main
piltidele	doc_399014257231_item	2385740	et	3	main
uurija	doc_399014257231_item	2385745	et	4	main
sada	doc_399014257231_item	2385754	et	4	main
antud	doc_399014257231_item	2385761	et	4	main
välja	doc_399014257231_item	2385762	et	4	main
oleks	doc_399014257231_item	2385769	et	3	main
vähemalt	doc_399014257231_item	2385770	et	4	main
mõned	doc_399014257231_item	2385771	et	3	main
signe	doc_399014257231_item	2385772	et	4	main
võetud	doc_399014257231_item	2385773	et	4	main
pildid	doc_399014257231_item	2385774	et	3	main
20	doc_399014257231_item	2385775	et	2	main
nüüd	doc_399014257231_item	2385780	et	4	main
oma	doc_399014257231_item	2385784	et	4	main
oma	doc_399014257231_item	2385788	et	4	main
aja	doc_399014257231_item	2385789	et	4	main
komisjon	doc_399014257231_item	2385801	et	3	main
mullistusi	doc_399014257231_item	2385811	et	4	main
muutus	doc_399014257231_item	2385815	et	4	main
suure	doc_399014257231_item	2385817	et	3	main
sajandi	doc_399014257231_item	2385820	et	3	main
töölö	doc_399014257231_item	2385822	et	4	main
eira	doc_399014257231_item	2385824	et	4	main
ehitamine	doc_399014257231_item	2385825	et	4	main
ehitatud	doc_399014257231_item	2385833	et	4	main
riitta	doc_399014257231_item	2385843	et	4	main
enesestmõistetav	doc_399014257231_item	2385852	et	3	main
kinnitust	doc_399014257231_item	2385857	et	4	main
eriti	doc_399014257231_item	2385860	et	3	main
maastikupildistajana	doc_399014257231_item	2385861	et	3	main
parkanos	doc_399014257231_item	2385862	et	4	main
ta	doc_399014257231_item	2385870	et	4	main
teinud	doc_399014257231_item	2385873	et	4	main
kellele	doc_399014257231_item	2385881	et	4	main
ei	doc_399014257231_item	2385882	et	4	main
elavuse	doc_399014257231_item	2385928	et	4	main
saladus	doc_399014257231_item	2385929	et	3	main
piltidel	doc_399014257231_item	2385931	et	3	main
aastat	doc_399014257231_item	2385942	et	3	main
olnud	doc_399014257231_item	2385954	et	4	main
hetkeks	doc_399014257231_item	2385962	et	4	main
pildistada	doc_399014257231_item	2385964	et	3	main
kalevipoja-konkursi	doc_399014257230_item	2385611	et	3	main
aselinnapea	doc_399014257230_item	2385621	et	4	main
järgi	doc_399014257230_item	2385623	et	4	main
kuju	doc_399014257230_item	2385624	et	4	main
ja	doc_399014257230_item	2385629	et	3	main
signe	doc_399014257231_item	2385634	et	4	main
tegi	doc_399014257231_item	2385638	et	4	main
pildistajast	doc_399014257231_item	2385641	et	4	main
saja	doc_399014257231_item	2385645	et	4	main
000	doc_399014257231_item	2385653	et	2	main
aastakümne	doc_399014257231_item	2385657	et	4	main
kolmekordistunud	doc_399014257231_item	2385661	et	4	main
kasv	doc_399014257231_item	2385664	et	3	main
ja	doc_399014257231_item	2385665	et	3	main
muutumine	doc_399014257231_item	2385666	et	4	main
äratas	doc_399014257231_item	2385667	et	3	main
otsustajad	doc_399014257231_item	2385674	et	4	main
branderi	doc_399014257231_item	2385693	et	4	main
branderi	doc_399014257231_item	2385732	et	4	main
alanco	doc_399014257231_item	2385743	et	4	main
riitta	doc_399014257231_item	2385746	et	4	main
raamatu	doc_399014257231_item	2385750	et	4	main
ei	doc_399014257231_item	2385768	et	4	main
algusest	doc_399014257231_item	2385777	et	4	main
pildiraamatu	doc_399014257231_item	2385785	et	4	main
ja	doc_399014257231_item	2385814	et	3	main
tohutult	doc_399014257231_item	2385816	et	4	main
20	doc_399014257231_item	2385819	et	2	main
alguses	doc_399014257231_item	2385821	et	4	main
ja	doc_399014257231_item	2385823	et	3	main
sajandi	doc_399014257231_item	2385830	et	3	main
poolel	doc_399014257231_item	2385832	et	4	main
kahekorruselised	doc_399014257231_item	2385836	et	4	main
hakkasid	doc_399014257231_item	2385838	et	4	main
suurde	doc_399014257231_item	2385840	et	3	main
hindel	doc_399014257231_item	2385845	et	3	main
signe	doc_399014257231_item	2385846	et	4	main
ta	doc_399014257231_item	2385853	et	4	main
pildistajana	doc_399014257231_item	2385859	et	4	main
joonistuse	doc_399014257231_item	2385867	et	4	main
ei	doc_399014257231_item	2385871	et	4	main
selle	doc_399014257231_item	2385876	et	4	main
sai	doc_399014257231_item	2385879	et	4	main
pildistaja	doc_399014257231_item	2385880	et	4	main
olid	doc_399014257231_item	2385925	et	4	main
piltide	doc_399014257231_item	2385927	et	3	main
kauplejaid	doc_399014257231_item	2385937	et	4	main
politseinikke	doc_399014257231_item	2385938	et	3	main
või	doc_399014257231_item	2385939	et	4	main
venelased	doc_399014257231_item	2385944	et	3	main
köögivilja	doc_399014257231_item	2385947	et	4	main
jaoks	doc_399014257231_item	2385949	et	4	main
piltidesse	doc_399014257231_item	2385950	et	3	main
enamasti	doc_399014257231_item	2385953	et	4	main
haruldus	doc_399014257231_item	2385989	et	3	main
õue	doc_399014257231_item	2385998	et	4	main
hobune	doc_399014257231_item	2386003	et	4	main
saja	doc_399014257231_item	2386014	et	4	main
retk	doc_399014257231_item	2386018	et	3	main
hermannist	doc_399014257231_item	2386020	et	4	main
ja	doc_399014257231_item	2386023	et	3	main
lõunapoolsetesse	doc_399014257231_item	2386026	et	4	main
linnaosadesse	doc_399014257231_item	2386027	et	3	main
võetud	doc_399014257231_item	2386046	et	4	main
ja	doc_399014257231_item	2386047	et	3	main
kuhu	doc_399014257231_item	2386048	et	3	main
poole	doc_399014257231_item	2386049	et	4	main
vaade	doc_399014257231_item	2386050	et	3	main
on	doc_399014257231_item	2386051	et	4	main
on	doc_399014257231_item	2386060	et	4	main
kohas	doc_399014257231_item	2386062	et	4	main
muutunud	doc_399014257231_item	2386063	et	4	main
täiesti	doc_399014257231_item	2386064	et	3	main
ajal	doc_399014257231_item	2386071	et	4	main
maakoht	doc_399014257231_item	2386072	et	3	main
kus	doc_399014257231_item	2386073	et	3	main
helsingilaste	doc_399014257231_item	2386077	et	4	main
vahele	doc_399014257231_item	2386082	et	4	main
põhjus	doc_399014257231_item	2386088	et	4	main
ei	doc_399014257231_item	2386089	et	4	main
pakarinen	doc_399014257231_item	2386092	et	4	main
pärast	doc_399014257230_item	2385617	et	4	main
seda	doc_399014257230_item	2385618	et	3	main
kavatsetud	doc_399014257230_item	2385626	et	4	main
linnamuuseum	doc_399014257231_item	2385637	et	3	main
legendaarsest	doc_399014257231_item	2385640	et	3	main
kolme	doc_399014257231_item	2385656	et	4	main
linna	doc_399014257231_item	2385662	et	4	main
hiiglaslik	doc_399014257231_item	2385663	et	3	main
puumajade	doc_399014257231_item	2385677	et	3	main
mis	doc_399014257231_item	2385687	et	4	main
järgmisel	doc_399014257231_item	2385689	et	3	main
1869-1942	doc_399014257231_item	2385694	et	2	main
tööle	doc_399014257231_item	2385695	et	3	main
korda	doc_399014257231_item	2385700	et	4	main
hiljem	doc_399014257231_item	2385701	et	3	main
targaks	doc_399014257231_item	2385702	et	3	main
ja	doc_399014257231_item	2385703	et	3	main
kaugeleulatuvaks	doc_399014257231_item	2385704	et	3	main
brander	doc_399014257231_item	2385705	et	4	main
pildistas	doc_399014257231_item	2385706	et	3	main
helsingit	doc_399014257231_item	2385707	et	4	main
umbes	doc_399014257231_item	2385708	et	4	main
seitsme	doc_399014257231_item	2385709	et	3	main
aasta	doc_399014257231_item	2385710	et	4	main
jooksul	doc_399014257231_item	2385711	et	4	main
1907-13	doc_399014257231_item	2385712	et	2	main
tulemusena	doc_399014257231_item	2385714	et	3	main
tekkis	doc_399014257231_item	2385715	et	3	main
907	doc_399014257231_item	2385716	et	2	main
pilti	doc_399014257231_item	2385717	et	4	main
mis	doc_399014257231_item	2385718	et	4	main
töö	doc_399014257231_item	2385713	et	4	main
on	doc_399014257231_item	2385719	et	4	main
ikka	doc_399014257231_item	2385720	et	4	main
helsingi	doc_399014257231_item	2385649	et	4	main
100	doc_399014257231_item	2385652	et	2	main
1902	doc_399014257231_item	2385655	et	2	main
jooksul	doc_399014257231_item	2385658	et	4	main
oli	doc_399014257231_item	2385660	et	3	main
arhitektid	doc_399014257231_item	2385671	et	3	main
jäädvustama	doc_399014257231_item	2385675	et	3	main
muinsuskaitsekomisjoni	doc_399014257231_item	2385686	et	4	main
palkas	doc_399014257231_item	2385688	et	3	main
pildistaja	doc_399014257231_item	2385691	et	4	main
otsust	doc_399014257231_item	2385696	et	4	main
mitu	doc_399014257231_item	2385699	et	4	main
veel	doc_399014257231_item	2385721	et	4	main
helsingi	doc_399014257231_item	2385726	et	4	main
on	doc_399014257231_item	2385728	et	4	main
tema	doc_399014257231_item	2385739	et	4	main
on	doc_399014257231_item	2385748	et	4	main
kus	doc_399014257231_item	2385751	et	3	main
helsingi-teemalist	doc_399014257231_item	2385757	et	4	main
fotot	doc_399014257231_item	2385758	et	3	main
vaevalt	doc_399014257231_item	2385759	et	4	main
on	doc_399014257231_item	2385760	et	4	main
alles	doc_399014257231_item	2385779	et	3	main
tema	doc_399014257231_item	2385781	et	4	main
täiesti	doc_399014257231_item	2385783	et	3	main
nyström	doc_399014257231_item	2385796	et	4	main
jaoks	doc_399014257231_item	2385804	et	4	main
ettepaneku	doc_399014257231_item	2385805	et	3	main
helsingi	doc_399014257231_item	2385812	et	4	main
algasid	doc_399014257231_item	2385826	et	4	main
ja	doc_399014257231_item	2385827	et	3	main
linna	doc_399014257231_item	2385828	et	4	main
esimesel	doc_399014257231_item	2385831	et	3	main
puumajad	doc_399014257231_item	2385837	et	3	main
pildistajaks	doc_399014257231_item	2385850	et	4	main
juba	doc_399014257231_item	2385855	et	3	main
brander	doc_399014257231_item	2385864	et	4	main
õppis	doc_399014257231_item	2385865	et	3	main
helsingis	doc_399014257231_item	2385866	et	4	main
meeldinud	doc_399014257231_item	2385883	et	4	main
portreete	doc_399014257231_item	2385884	et	4	main
on	doc_399014257231_item	2385932	et	4	main
peaaegu	doc_399014257231_item	2385933	et	3	main
möödakäijaid	doc_399014257231_item	2385935	et	3	main
lapsi	doc_399014257231_item	2385936	et	4	main
tagasi	doc_399014257231_item	2385943	et	3	main
kohal	doc_399014257231_item	2385956	et	4	main
on	doc_399014257231_item	2385958	et	4	main
et	doc_399014257231_item	2385963	et	3	main
mõnikord	doc_399014257231_item	2385990	et	3	main
raudteerööpaid	doc_399014257231_item	2385994	et	3	main
jälgiv	doc_399014257231_item	2385995	et	4	main
keskel	doc_399014257231_item	2385999	et	3	main
uurimisretkeks	doc_399014257231_item	2386008	et	4	main
kus	doc_399014257231_item	2386009	et	3	main
lugeja	doc_399014257231_item	2386010	et	4	main
liigub	doc_399014257231_item	2386011	et	3	main
otsekui	doc_399014257231_item	2386012	et	3	main
taguses	doc_399014257231_item	2386016	et	3	main
tuleb	doc_399014257231_item	2386021	et	3	main
kruununhaka	doc_399014257231_item	2386024	et	4	main
jätkub	doc_399014257231_item	2386030	et	3	main
kamppi	doc_399014257231_item	2386031	et	4	main
kaudu	doc_399014257231_item	2386032	et	3	main
töölösse	doc_399014257231_item	2386033	et	3	main
igaühe	doc_399014257231_item	2386034	et	4	main
pildi	doc_399014257231_item	2386035	et	4	main
on	doc_399014257231_item	2386054	et	4	main
lugejale	doc_399014257231_item	2386057	et	4	main
äratundmatuks	doc_399014257231_item	2386065	et	4	main
näiteks	doc_399014257231_item	2386066	et	4	main
töölö	doc_399014257231_item	2386067	et	4	main
kasvatasid	doc_399014257231_item	2386075	et	4	main
1913	doc_399014257231_item	2386086	et	2	main
selgu	doc_399014257231_item	2386090	et	4	main
oma	doc_399014257231_item	2386124	et	4	main
hakkasid	doc_399014257231_item	2386144	et	4	main
aastatel	doc_399014257231_item	2386147	et	4	main
patsiendid	doc_399014257231_item	2386158	et	3	main
psühiatrilisse	doc_399014257231_item	2386165	et	4	main
haiglasse	doc_399014257231_item	2386166	et	4	main
selleks	doc_399014257231_item	2385679	et	4	main
aastal	doc_399014257231_item	2385690	et	3	main
on	doc_399014257231_item	2385697	et	4	main
kiidetud	doc_399014257231_item	2385698	et	4	main
tuumaks	doc_399014257231_item	2385725	et	3	main
esimese	doc_399014257231_item	2385734	et	3	main
põhineb	doc_399014257231_item	2385737	et	3	main
ja	doc_399014257231_item	2385744	et	3	main
branderi	doc_399014257231_item	2385755	et	4	main
parimat	doc_399014257231_item	2385756	et	4	main
aga	doc_399014257231_item	2385778	et	3	main
saab	doc_399014257231_item	2385782	et	3	main
muinsuskaitsekomisjonis	doc_399014257231_item	2385786	et	3	main
professor	doc_399014257231_item	2385794	et	3	main
linnaplaneerimist	doc_399014257231_item	2385800	et	3	main
branderi	doc_399014257231_item	2385803	et	4	main
kasvas	doc_399014257231_item	2385813	et	3	main
linnamuuseumi	doc_399014257231_item	2385723	et	4	main
pildiarhiivi	doc_399014257231_item	2385724	et	4	main
signe	doc_399014257231_item	2385731	et	4	main
mis	doc_399014257231_item	2385736	et	4	main
täiesti	doc_399014257231_item	2385738	et	3	main
pildistaja	doc_399014257231_item	2385741	et	4	main
jan	doc_399014257231_item	2385742	et	4	main
pakarinen	doc_399014257231_item	2385747	et	4	main
teinud	doc_399014257231_item	2385749	et	4	main
on	doc_399014257231_item	2385752	et	4	main
umbes	doc_399014257231_item	2385753	et	4	main
mõndagi	doc_399014257231_item	2385763	et	4	main
raamatut	doc_399014257231_item	2385764	et	3	main
helsingi	doc_399014257231_item	2385765	et	4	main
ajaloost	doc_399014257231_item	2385766	et	4	main
milles	doc_399014257231_item	2385767	et	3	main
sajandi	doc_399014257231_item	2385776	et	3	main
istus	doc_399014257231_item	2385787	et	4	main
parimaid	doc_399014257231_item	2385790	et	4	main
asjatundjaid	doc_399014257231_item	2385791	et	3	main
muuseas	doc_399014257231_item	2385792	et	3	main
arhitekt	doc_399014257231_item	2385793	et	3	main
gustaf	doc_399014257231_item	2385795	et	4	main
kes	doc_399014257231_item	2385797	et	4	main
juhtis	doc_399014257231_item	2385798	et	3	main
helsingi	doc_399014257231_item	2385799	et	4	main
tegi	doc_399014257231_item	2385802	et	4	main
pildistamiskohtadest	doc_399014257231_item	2385806	et	4	main
kuhu	doc_399014257231_item	2385807	et	3	main
oli	doc_399014257231_item	2385808	et	3	main
oodata	doc_399014257231_item	2385809	et	4	main
suuri	doc_399014257231_item	2385810	et	3	main
hooga	doc_399014257231_item	2385818	et	3	main
19	doc_399014257231_item	2385829	et	2	main
ja	doc_399014257231_item	2385835	et	3	main
kivimüüride	doc_399014257231_item	2385841	et	4	main
eest	doc_399014257231_item	2385842	et	4	main
branderi	doc_399014257231_item	2385847	et	4	main
valik	doc_399014257231_item	2385848	et	3	main
helsingi	doc_399014257231_item	2385849	et	4	main
oli	doc_399014257231_item	2385854	et	3	main
andnud	doc_399014257231_item	2385856	et	4	main
oskusliku	doc_399014257231_item	2385858	et	3	main
ent	doc_399014257231_item	2385869	et	3	main
kunagi	doc_399014257231_item	2385872	et	3	main
tööd	doc_399014257231_item	2385875	et	4	main
ühe-	doc_399014257231_item	2385834	et	4	main
kaduma	doc_399014257231_item	2385839	et	4	main
pakarinen	doc_399014257231_item	2385844	et	4	main
oli	doc_399014257231_item	2385851	et	3	main
sündinud	doc_399014257231_item	2385863	et	4	main
õpetajaks	doc_399014257231_item	2385868	et	4	main
õpetaja	doc_399014257231_item	2385874	et	4	main
asemel	doc_399014257231_item	2385877	et	4	main
temast	doc_399014257231_item	2385878	et	3	main
tegemine	doc_399014257231_item	2385885	et	4	main
ega	doc_399014257231_item	2385886	et	3	main
ta	doc_399014257231_item	2385887	et	4	main
tundnud	doc_399014257231_item	2385888	et	4	main
end	doc_399014257231_item	2385889	et	4	main
hästi	doc_399014257231_item	2385890	et	3	main
ateljeetöös	doc_399014257231_item	2385891	et	3	main
siiski	doc_399014257231_item	2385892	et	4	main
tal	doc_399014257231_item	2385893	et	3	main
oli	doc_399014257231_item	2385894	et	3	main
kogemust	doc_399014257231_item	2385895	et	3	main
ka	doc_399014257231_item	2385896	et	3	main
sellest	doc_399014257231_item	2385897	et	4	main
helsingi	doc_399014257231_item	2385898	et	4	main
fotoärides	doc_399014257231_item	2385899	et	3	main
aga	doc_399014257231_item	2385900	et	3	main
ta	doc_399014257231_item	2385901	et	4	main
tahtis	doc_399014257231_item	2385902	et	3	main
pääseda	doc_399014257231_item	2385903	et	3	main
väljale	doc_399014257231_item	2385904	et	3	main
brander	doc_399014257231_item	2385905	et	4	main
pildistas	doc_399014257231_item	2385906	et	3	main
tollase	doc_399014257231_item	2385907	et	3	main
kohmaka	doc_399014257231_item	2385908	et	3	main
tehnikaga	doc_399014257231_item	2385909	et	3	main
linna	doc_399014257231_item	2385910	et	4	main
ja	doc_399014257231_item	2385911	et	3	main
maastikke	doc_399014257231_item	2385912	et	4	main
väga	doc_399014257231_item	2385913	et	3	main
oskuslikult	doc_399014257231_item	2385914	et	4	main
ta	doc_399014257231_item	2385915	et	4	main
ei	doc_399014257231_item	2385916	et	4	main
olnud	doc_399014257231_item	2385917	et	4	main
rahul	doc_399014257231_item	2385918	et	4	main
surnud	doc_399014257231_item	2385919	et	4	main
arhitektuuri	doc_399014257231_item	2385920	et	4	main
inimesed	doc_399014257231_item	2385922	et	3	main
tema	doc_399014257231_item	2385926	et	4	main
alati	doc_399014257231_item	2385934	et	4	main
sada	doc_399014257231_item	2385941	et	4	main
sattunud	doc_399014257231_item	2385951	et	4	main
juhuslikult	doc_399014257231_item	2385955	et	4	main
peatuma	doc_399014257231_item	2385961	et	4	main
neid	doc_399014257231_item	2385965	et	4	main
inimeste	doc_399014257231_item	2385966	et	3	main
heast	doc_399014257231_item	2385967	et	3	main
tujust	doc_399014257231_item	2385968	et	3	main
võib	doc_399014257231_item	2385969	et	3	main
järeldada	doc_399014257231_item	2385970	et	3	main
et	doc_399014257231_item	2385971	et	3	main
brander	doc_399014257231_item	2385972	et	4	main
oskas	doc_399014257231_item	2385973	et	3	main
esitada	doc_399014257231_item	2385974	et	3	main
oma	doc_399014257231_item	2385975	et	4	main
asja	doc_399014257231_item	2385976	et	4	main
ja	doc_399014257231_item	2385977	et	3	main
äratada	doc_399014257231_item	2385978	et	3	main
uudishimulikkust	doc_399014257231_item	2385979	et	4	main
helsingilastes	doc_399014257231_item	2385980	et	4	main
pildistamine	doc_399014257231_item	2385981	et	4	main
oli	doc_399014257231_item	2385982	et	3	main
pildistamisega	doc_399014257231_item	2385921	et	4	main
ja	doc_399014257231_item	2385923	et	3	main
üksikasjad	doc_399014257231_item	2385924	et	3	main
tema	doc_399014257231_item	2385930	et	4	main
koduloomi	doc_399014257231_item	2385940	et	4	main
kasvatasid	doc_399014257231_item	2385945	et	4	main
töölös	doc_399014257231_item	2385946	et	4	main
helsingilaste	doc_399014257231_item	2385948	et	4	main
on	doc_399014257231_item	2385952	et	4	main
brander	doc_399014257231_item	2385957	et	4	main
palunud	doc_399014257231_item	2385959	et	4	main
neid	doc_399014257231_item	2385960	et	4	main
veel	doc_399014257231_item	2385983	et	4	main
uus	doc_399014257231_item	2385984	et	3	main
detail	doc_399014257231_item	2385992	et	3	main
rakmeid	doc_399014257231_item	2386001	et	3	main
seisav	doc_399014257231_item	2386002	et	4	main
korraldatud	doc_399014257231_item	2386006	et	4	main
ringsõidul	doc_399014257231_item	2386013	et	3	main
algupärane	doc_399014257231_item	2386038	et	4	main
täpne	doc_399014257231_item	2386039	et	3	main
kaart	doc_399014257231_item	2386040	et	4	main
mis	doc_399014257231_item	2386041	et	4	main
näitab	doc_399014257231_item	2386042	et	3	main
vältimatu	doc_399014257231_item	2386055	et	4	main
mitmes	doc_399014257231_item	2386061	et	4	main
oli	doc_399014257231_item	2386068	et	3	main
branderi	doc_399014257231_item	2386069	et	4	main
piltide	doc_399014257231_item	2386070	et	3	main
branderi	doc_399014257231_item	2386079	et	4	main
ja	doc_399014257231_item	2386080	et	3	main
komisjoni	doc_399014257231_item	2386081	et	4	main
et	doc_399014257231_item	2386094	et	3	main
sai	doc_399014257231_item	2386123	et	4	main
näiteks	doc_399014257231_item	2386138	et	4	main
nõrgenema	doc_399014257231_item	2386145	et	3	main
aastal	doc_399014257231_item	2386154	et	3	main
kivelä	doc_399014257231_item	2386155	et	4	main
sõja	doc_399014257231_item	2386161	et	3	main
ümberpaigutamise	doc_399014257231_item	2386167	et	3	main
põhjuseks	doc_399014257231_item	2386168	et	3	main
seda	doc_399014257231_item	2386175	et	3	main
väidetud	doc_399014257231_item	2386178	et	4	main
asi	doc_399014257231_item	2385985	et	4	main
ja	doc_399014257231_item	2385986	et	3	main
naine	doc_399014257231_item	2385987	et	3	main
pildistajana	doc_399014257231_item	2385988	et	4	main
koer	doc_399014257231_item	2385996	et	3	main
ilma	doc_399014257231_item	2386000	et	4	main
pildid	doc_399014257231_item	2386004	et	3	main
on	doc_399014257231_item	2386005	et	4	main
helsingis	doc_399014257231_item	2386017	et	4	main
hakaniemi	doc_399014257231_item	2386022	et	4	main
kaudu	doc_399014257231_item	2386025	et	3	main
kõrval	doc_399014257231_item	2386036	et	4	main
kust	doc_399014257231_item	2386043	et	4	main
olnud	doc_399014257231_item	2386052	et	4	main
kaasaegsele	doc_399014257231_item	2386056	et	3	main
linn	doc_399014257231_item	2386059	et	3	main
venelased	doc_399014257231_item	2386074	et	3	main
jaoks	doc_399014257231_item	2386078	et	4	main
siiski	doc_399014257231_item	2386084	et	4	main
lahkhelid	doc_399014257231_item	2386085	et	3	main
lahkhelide	doc_399014257231_item	2386087	et	3	main
protokollidest	doc_399014257231_item	2386091	et	4	main
pikantne	doc_399014257231_item	2385991	et	3	main
on	doc_399014257231_item	2385993	et	4	main
või	doc_399014257231_item	2385997	et	4	main
raamatusse	doc_399014257231_item	2386007	et	4	main
aasta	doc_399014257231_item	2386015	et	4	main
algab	doc_399014257231_item	2386019	et	3	main
sealt	doc_399014257231_item	2386028	et	4	main
reis	doc_399014257231_item	2386029	et	4	main
on	doc_399014257231_item	2386037	et	4	main
pilt	doc_399014257231_item	2386044	et	3	main
on	doc_399014257231_item	2386045	et	4	main
kaart	doc_399014257231_item	2386053	et	4	main
sest	doc_399014257231_item	2386058	et	4	main
köögivilja	doc_399014257231_item	2386076	et	4	main
tekkisid	doc_399014257231_item	2386083	et	4	main
arvab	doc_399014257231_item	2386093	et	3	main
tüli	doc_399014257231_item	2386096	et	4	main
tekkis	doc_399014257231_item	2386097	et	3	main
lihtsalt	doc_399014257231_item	2386098	et	4	main
linnamuuseum	doc_399014257231_item	2386100	et	3	main
rahast	doc_399014257231_item	2386099	et	4	main
palkas	doc_399014257231_item	2386101	et	3	main
branderi	doc_399014257231_item	2386102	et	4	main
asemele	doc_399014257231_item	2386103	et	4	main
uue	doc_399014257231_item	2386104	et	3	main
pildistaja	doc_399014257231_item	2386105	et	4	main
aga	doc_399014257231_item	2386106	et	3	main
esimese	doc_399014257231_item	2386107	et	3	main
maailmasõja	doc_399014257231_item	2386108	et	3	main
puhkemine	doc_399014257231_item	2386109	et	4	main
1914	doc_399014257231_item	2386110	et	2	main
lõpetas	doc_399014257231_item	2386111	et	3	main
pildistustegevuse	doc_399014257231_item	2386112	et	4	main
aastakümneteks	doc_399014257231_item	2386113	et	4	main
süstemaatiline	doc_399014257231_item	2386114	et	3	main
linnakeskkonna	doc_399014257231_item	2386115	et	3	main
jäädvustamine	doc_399014257231_item	2386116	et	4	main
algas	doc_399014257231_item	2386117	et	3	main
uuesti	doc_399014257231_item	2386118	et	3	main
alles	doc_399014257231_item	2386119	et	3	main
1950	doc_399014257231_item	2386120	et	2	main
pildistaja	doc_399014257231_item	2386126	et	4	main
brander	doc_399014257231_item	2386129	et	4	main
pildistas	doc_399014257231_item	2386137	et	3	main
mõisaid	doc_399014257231_item	2386139	et	3	main
ja	doc_399014257231_item	2386142	et	3	main
tõttu	doc_399014257231_item	2386150	et	4	main
brander	doc_399014257231_item	2386151	et	4	main
sattus	doc_399014257231_item	2386152	et	3	main
1941	doc_399014257231_item	2386153	et	2	main
viidi	doc_399014257231_item	2386159	et	4	main
branderi	doc_399014257231_item	2386171	et	4	main
tervis	doc_399014257231_item	2386173	et	3	main
võibolla	doc_399014257231_item	2386095	et	4	main
aastatel	doc_399014257231_item	2386121	et	4	main
püsiva	doc_399014257231_item	2386125	et	4	main
alles	doc_399014257231_item	2386127	et	3	main
jätkas	doc_399014257231_item	2386130	et	3	main
tööd	doc_399014257231_item	2386132	et	4	main
tema	doc_399014257231_item	2386140	et	4	main
tervis	doc_399014257231_item	2386141	et	3	main
1930	doc_399014257231_item	2386146	et	2	main
haiglasse	doc_399014257231_item	2386156	et	4	main
kust	doc_399014257231_item	2386157	et	4	main
tõttu	doc_399014257231_item	2386162	et	4	main
üle	doc_399014257231_item	2386163	et	3	main
ei	doc_399014257231_item	2386169	et	4	main
olnud	doc_399014257231_item	2386170	et	4	main
on	doc_399014257231_item	2386176	et	4	main
mõnikord	doc_399014257231_item	2386177	et	3	main
linnamuuseum	doc_399014257231_item	2386122	et	3	main
1981	doc_399014257231_item	2386128	et	2	main
pildistaja	doc_399014257231_item	2386131	et	4	main
eri	doc_399014257231_item	2386133	et	4	main
pooltel	doc_399014257231_item	2386134	et	3	main
soomet	doc_399014257231_item	2386135	et	4	main
ta	doc_399014257231_item	2386136	et	4	main
nägemine	doc_399014257231_item	2386143	et	4	main
rohelise	doc_399014257231_item	2386148	et	4	main
kae	doc_399014257231_item	2386149	et	4	main
hiljem	doc_399014257231_item	2386160	et	3	main
nikkilä	doc_399014257231_item	2386164	et	4	main
vaimne	doc_399014257231_item	2386172	et	3	main
sõja	doc_399014257231_item	2386179	et	3	main
ebaselgetes	doc_399014257231_item	2386180	et	4	main
oludes	doc_399014257231_item	2386181	et	3	main
haiglas	doc_399014257231_item	2386182	et	3	main
suri	doc_399014257231_item	2386183	et	3	main
1942	doc_399014257231_item	2386184	et	2	main
aastal	doc_399014257231_item	2386185	et	3	main
rohkem	doc_399014257231_item	2386186	et	4	main
kui	doc_399014257231_item	2386187	et	3	main
sada	doc_399014257231_item	2386188	et	4	main
patsienti	doc_399014257231_item	2386189	et	4	main
nälga	doc_399014257231_item	2386190	et	4	main
nende	doc_399014257231_item	2386191	et	4	main
hulgas	doc_399014257231_item	2386192	et	4	main
oli	doc_399014257231_item	2386193	et	3	main
helsingi	doc_399014257231_item	2386194	et	4	main
legendaarne	doc_399014257231_item	2386195	et	3	main
pildistaja	doc_399014257231_item	2386196	et	4	main
signe	doc_399014257231_item	2386197	et	4	main
brander	doc_399014257231_item	2386198	et	4	main
kes	doc_399014257231_item	2386199	et	4	main
maeti	doc_399014257231_item	2386200	et	3	main
teiste	doc_399014257231_item	2386201	et	4	main
patsientidega	doc_399014257231_item	2386202	et	3	main
ühishauda	doc_399014257231_item	2386203	et	4	main
kuigi	doc_399014257231_item	2386174	et	3	main
kalevipoja	doc_399014257235_item	2387786	et	4	main
võõrastavad	doc_399014257235_item	2387790	et	4	main
tallinna	doc_399014257235_item	2387791	et	4	main
lahele	doc_399014257235_item	2387796	et	4	main
elumajakõrgune	doc_399014257235_item	2387797	et	4	main
21	doc_399014257235_item	2387798	et	2	main
meetrit	doc_399014257235_item	2387799	et	3	main
kõrge	doc_399014257235_item	2387800	et	4	main
tallinnast	doc_399014257235_item	2387825	et	3	main
kalda	doc_399014257235_item	2387833	et	3	main
peal	doc_399014257235_item	2387834	et	4	main
on	doc_399014257235_item	2387842	et	4	main
merele	doc_399014257235_item	2387843	et	3	main
ning	doc_399014257235_item	2387849	et	3	main
linna	doc_399014257235_item	2387851	et	4	main
ühingu	doc_399014257235_item	2387854	et	3	main
algasid	doc_399014257235_item	2387856	et	4	main
juba	doc_399014257235_item	2387857	et	3	main
kuju	doc_399014257235_item	2387858	et	4	main
ühingu	doc_399014257235_item	2387865	et	3	main
kunstikeliidud	doc_399014257235_item	2387781	et	4	main
kavandatud	doc_399014257235_item	2387784	et	4	main
eesti	doc_399014257235_item	2387788	et	4	main
püstitada	doc_399014257235_item	2387794	et	3	main
eesti	doc_399014257235_item	2387802	et	4	main
kangelase	doc_399014257235_item	2387805	et	3	main
saja	doc_399014257235_item	2387821	et	4	main
rannatee	doc_399014257235_item	2387828	et	4	main
kohale	doc_399014257235_item	2387829	et	4	main
unistus	doc_399014257235_item	2387848	et	4	main
skulptorite	doc_399014257235_item	2387864	et	3	main
juba	doc_399014257235_item	2387870	et	3	main
ning	doc_399014257235_item	2387872	et	3	main
koosseisu	doc_399014257235_item	2387895	et	4	main
tauno	doc_399014257235_item	2387924	et	4	main
kes	doc_399014257235_item	2387927	et	4	main
luua	doc_399014257235_item	2387937	et	4	main
tallinnale	doc_399014257235_item	2387938	et	4	main
sümbol	doc_399014257235_item	2387943	et	3	main
kavandis	doc_399014257235_item	2387945	et	3	main
väike	doc_399014257235_item	2387947	et	4	main
meetrit	doc_399014257235_item	2387952	et	3	main
linna	doc_399014257235_item	2387955	et	4	main
memoriaalkompleksiga	doc_399014257235_item	2387966	et	4	main
visualiseerisime	doc_399014257235_item	2387970	et	4	main
jõudsime	doc_399014257235_item	2387972	et	3	main
see	doc_399014257235_item	2387975	et	3	main
põhjendab	doc_399014257235_item	2387978	et	3	main
on	doc_399014257235_item	2387985	et	4	main
parim	doc_399014257235_item	2387986	et	4	main
tutvustas	doc_399014257235_item	2388024	et	3	main
maailmale	doc_399014257235_item	2388043	et	4	main
inimfiguurid	doc_399014257235_item	2388054	et	3	main
ühingule	doc_399014257235_item	2388061	et	3	main
mõjukam	doc_399014257235_item	2388065	et	4	main
liit	doc_399014257235_item	2388067	et	3	main
kes	doc_399014257235_item	2388068	et	4	main
keskerakond	doc_399014257235_item	2388083	et	3	main
varem	doc_399014257235_item	2388087	et	4	main
kõrghooneid	doc_399014257235_item	2388089	et	4	main
tõlge	doc_399014257235_item	2387780	et	3	main
võõrastavad	doc_399014257235_item	2387782	et	4	main
tallinnalahele	doc_399014257235_item	2387783	et	3	main
hiiglaslikku	doc_399014257235_item	2387785	et	4	main
tallinna	doc_399014257235_item	2387795	et	4	main
rahvuseepose	doc_399014257235_item	2387804	et	3	main
kaugusele	doc_399014257235_item	2387823	et	4	main
rannast	doc_399014257235_item	2387824	et	4	main
piritale	doc_399014257235_item	2387826	et	4	main
samas	doc_399014257235_item	2387830	et	4	main
nõukogudeaegne	doc_399014257235_item	2387835	et	3	main
näha	doc_399014257235_item	2387844	et	3	main
obelisk	doc_399014257235_item	2387846	et	3	main
impotendi	doc_399014257235_item	2387847	et	4	main
suurusest	doc_399014257235_item	2387859	et	4	main
ja	doc_399014257235_item	2387860	et	3	main
kohast	doc_399014257235_item	2387861	et	4	main
arvates	doc_399014257235_item	2387866	et	4	main
vananenud	doc_399014257235_item	2387871	et	4	main
ei	doc_399014257235_item	2387875	et	4	main
nõukogudeaegse	doc_399014257235_item	2387877	et	3	main
mälestuskompleksi	doc_399014257235_item	2387878	et	4	main
varem	doc_399014257235_item	2387880	et	4	main
sügisel	doc_399014257235_item	2387881	et	3	main
nii	doc_399014257235_item	2387882	et	3	main
skulptorite	doc_399014257235_item	2387883	et	3	main
vastu	doc_399014257235_item	2387896	et	3	main
kangro	doc_399014257235_item	2387925	et	4	main
kalevipoja	doc_399014257235_item	2387930	et	4	main
projekti	doc_399014257235_item	2387931	et	4	main
idee	doc_399014257235_item	2387935	et	4	main
väikse	doc_399014257235_item	2387940	et	4	main
algses	doc_399014257235_item	2387944	et	3	main
tallinna	doc_399014257235_item	2387946	et	4	main
14	doc_399014257235_item	2387951	et	2	main
21	doc_399014257235_item	2387959	et	2	main
uurisime	doc_399014257235_item	2387961	et	3	main
kuju	doc_399014257235_item	2387963	et	4	main
21	doc_399014257235_item	2387973	et	2	main
meetrini	doc_399014257235_item	2387974	et	3	main
olga	doc_399014257235_item	2387980	et	4	main
võimalikest	doc_399014257235_item	2387987	et	4	main
kõrvale	doc_399014257235_item	2387993	et	4	main
kuju	doc_399014257235_item	2387787	et	4	main
kunstnikud	doc_399014257235_item	2387789	et	3	main
linna	doc_399014257235_item	2387792	et	4	main
kalevipoeg	doc_399014257235_item	2387801	et	3	main
järgi	doc_399014257235_item	2387806	et	4	main
linna	doc_399014257235_item	2387807	et	4	main
konkursile	doc_399014257235_item	2387809	et	3	main
oli	doc_399014257235_item	2387810	et	3	main
esmaspäevaks	doc_399014257235_item	2387811	et	3	main
korraldatud	doc_399014257235_item	2387808	et	4	main
laekunud	doc_399014257235_item	2387812	et	4	main
vaid	doc_399014257235_item	2387813	et	3	main
kolm	doc_399014257235_item	2387814	et	3	main
tööd	doc_399014257235_item	2387815	et	4	main
kalevipoeg	doc_399014257235_item	2387816	et	3	main
on	doc_399014257235_item	2387817	et	4	main
kavas	doc_399014257235_item	2387818	et	3	main
püstitada	doc_399014257235_item	2387819	et	3	main
merre	doc_399014257235_item	2387820	et	3	main
on	doc_399014257235_item	2387832	et	4	main
kangelastele	doc_399014257235_item	2387838	et	4	main
püstitatud	doc_399014257235_item	2387839	et	4	main
mälestuskompleks	doc_399014257235_item	2387840	et	3	main
millest	doc_399014257235_item	2387841	et	3	main
kõrge	doc_399014257235_item	2387845	et	4	main
ja	doc_399014257235_item	2387852	et	3	main
eesti	doc_399014257235_item	2387863	et	4	main
idee	doc_399014257235_item	2387867	et	4	main
kangelane	doc_399014257235_item	2387874	et	3	main
lähedusse	doc_399014257235_item	2387879	et	4	main
ametiliidud	doc_399014257235_item	2387886	et	3	main
kutsusid	doc_399014257235_item	2387887	et	4	main
oma	doc_399014257235_item	2387889	et	4	main
linnapea	doc_399014257235_item	2387897	et	4	main
jüri	doc_399014257235_item	2387898	et	4	main
kahtlase	doc_399014257235_item	2387921	et	3	main
kujur	doc_399014257235_item	2387923	et	3	main
müüma	doc_399014257235_item	2387929	et	3	main
90ndate	doc_399014257235_item	2387933	et	4	main
oli	doc_399014257235_item	2387936	et	3	main
mereneitsiga	doc_399014257235_item	2387941	et	3	main
vaid	doc_399014257235_item	2387950	et	3	main
sobiks	doc_399014257235_item	2387964	et	4	main
kalkulatsioone	doc_399014257235_item	2387968	et	3	main
torkaks	doc_399014257235_item	2387976	et	3	main
meelest	doc_399014257235_item	2387983	et	4	main
koht	doc_399014257235_item	2387984	et	3	main
suurte	doc_399014257235_item	2388027	et	3	main
paati	doc_399014257235_item	2388031	et	4	main
seda	doc_399014257235_item	2388037	et	3	main
ta	doc_399014257235_item	2388039	et	4	main
ja	doc_399014257235_item	2388052	et	3	main
ka	doc_399014257235_item	2388064	et	3	main
plaani	doc_399014257235_item	2387793	et	4	main
samanimelise	doc_399014257235_item	2387803	et	4	main
meetri	doc_399014257235_item	2387822	et	3	main
viiva	doc_399014257235_item	2387827	et	4	main
kohas	doc_399014257235_item	2387831	et	4	main
teise	doc_399014257235_item	2387836	et	4	main
maailmasõja	doc_399014257235_item	2387837	et	3	main
rannatrepid	doc_399014257235_item	2387850	et	3	main
skulptorite	doc_399014257235_item	2387853	et	3	main
erimeelsused	doc_399014257235_item	2387855	et	4	main
meres	doc_399014257235_item	2387862	et	3	main
on	doc_399014257235_item	2387868	et	4	main
arhitektide	doc_399014257235_item	2387885	et	3	main
protestimaks	doc_399014257235_item	2387892	et	4	main
žürii	doc_399014257235_item	2387893	et	2	main
ametnikest	doc_399014257235_item	2387894	et	3	main
32a	doc_399014257235_item	2387900	et	4	main
juhitud	doc_399014257235_item	2387901	et	4	main
žürii	doc_399014257235_item	2387902	et	2	main
ainukeseks	doc_399014257235_item	2387903	et	4	main
erapooletuks	doc_399014257235_item	2387904	et	4	main
kunstnikust	doc_399014257235_item	2387905	et	3	main
liikmeks	doc_399014257235_item	2387906	et	3	main
jäi	doc_399014257235_item	2387907	et	3	main
maastikuarhitekt	doc_399014257235_item	2387908	et	3	main
kes	doc_399014257235_item	2387909	et	4	main
on	doc_399014257235_item	2387910	et	4	main
teinud	doc_399014257235_item	2387911	et	4	main
planeeringuid	doc_399014257235_item	2387912	et	4	main
linna	doc_399014257235_item	2387913	et	4	main
parkide	doc_399014257235_item	2387914	et	3	main
jaoks	doc_399014257235_item	2387915	et	4	main
idee	doc_399014257235_item	2387916	et	4	main
on	doc_399014257235_item	2387918	et	4	main
siiski	doc_399014257235_item	2387919	et	4	main
autor	doc_399014257235_item	2387917	et	3	main
kunstnik	doc_399014257235_item	2387920	et	3	main
40a	doc_399014257235_item	2387926	et	4	main
kööpenhaageni	doc_399014257235_item	2387939	et	4	main
mereneitsi	doc_399014257235_item	2387948	et	4	main
kõrge	doc_399014257235_item	2387953	et	4	main
maarjamäe	doc_399014257235_item	2387965	et	3	main
ning	doc_399014257235_item	2387969	et	3	main
selle	doc_399014257235_item	2387971	et	4	main
abilinnapea	doc_399014257235_item	2387979	et	4	main
sõtnik	doc_399014257235_item	2387981	et	4	main
sõtniku	doc_399014257235_item	2387982	et	4	main
kuna	doc_399014257235_item	2387988	et	3	main
see	doc_399014257235_item	2387989	et	3	main
jääb	doc_399014257235_item	2387990	et	3	main
turistide	doc_399014257235_item	2387991	et	3	main
marsruuti	doc_399014257235_item	2387992	et	4	main
galerist	doc_399014257235_item	2388021	et	4	main
mägila	doc_399014257235_item	2388023	et	4	main
innustunult	doc_399014257235_item	2388025	et	4	main
pronkskuju	doc_399014257235_item	2388026	et	4	main
pärast	doc_399014257235_item	2388036	et	4	main
teinud	doc_399014257235_item	2388041	et	4	main
ringi	doc_399014257235_item	2388042	et	4	main
kätte	doc_399014257235_item	2388046	et	4	main
lisatud	doc_399014257235_item	2388048	et	4	main
projekti	doc_399014257235_item	2388063	et	4	main
iseenesest	doc_399014257235_item	2387869	et	4	main
rahvuseepose	doc_399014257235_item	2387873	et	3	main
sobi	doc_399014257235_item	2387876	et	4	main
kui	doc_399014257235_item	2387884	et	3	main
tagasi	doc_399014257235_item	2387888	et	3	main
esindajad	doc_399014257235_item	2387890	et	4	main
žüriist	doc_399014257235_item	2387891	et	2	main
ratase	doc_399014257235_item	2387899	et	4	main
kuulsusega	doc_399014257235_item	2387922	et	4	main
hakkas	doc_399014257235_item	2387928	et	3	main
juba	doc_399014257235_item	2387932	et	3	main
lõpul	doc_399014257235_item	2387934	et	3	main
võrdne	doc_399014257235_item	2387942	et	3	main
oli	doc_399014257235_item	2387949	et	3	main
aga	doc_399014257235_item	2387954	et	3	main
ettepanekul	doc_399014257235_item	2387956	et	3	main
lisati	doc_399014257235_item	2387957	et	3	main
pikkust	doc_399014257235_item	2387958	et	4	main
meetrini	doc_399014257235_item	2387960	et	3	main
kuidas	doc_399014257235_item	2387962	et	3	main
tegime	doc_399014257235_item	2387967	et	3	main
silma	doc_399014257235_item	2387977	et	4	main
pirita	doc_399014257235_item	2387994	et	4	main
spaa	doc_399014257235_item	2387995	et	4	main
ja	doc_399014257235_item	2387996	et	3	main
tallinna	doc_399014257235_item	2387997	et	4	main
botaanikaaeda	doc_399014257235_item	2387998	et	4	main
sõites	doc_399014257235_item	2387999	et	3	main
see	doc_399014257235_item	2388000	et	3	main
ei	doc_399014257235_item	2388001	et	4	main
peidaks	doc_399014257235_item	2388002	et	3	main
ka	doc_399014257235_item	2388003	et	3	main
vanalinna	doc_399014257235_item	2388004	et	4	main
siluetti	doc_399014257235_item	2388005	et	4	main
tauno	doc_399014257235_item	2388006	et	4	main
kangro	doc_399014257235_item	2388007	et	4	main
galeriis	doc_399014257235_item	2388008	et	3	main
vanalinnas	doc_399014257235_item	2388009	et	4	main
oli	doc_399014257235_item	2388010	et	3	main
veel	doc_399014257235_item	2388011	et	4	main
esmaspäevalgi	doc_399014257235_item	2388012	et	4	main
innustunud	doc_399014257235_item	2388013	et	4	main
meeleolu	doc_399014257235_item	2388014	et	4	main
kunstnik	doc_399014257235_item	2388015	et	3	main
ise	doc_399014257235_item	2388016	et	4	main
ei	doc_399014257235_item	2388017	et	4	main
olnud	doc_399014257235_item	2388018	et	4	main
linnas	doc_399014257235_item	2388019	et	4	main
aga	doc_399014257235_item	2388020	et	3	main
pille	doc_399014257235_item	2388022	et	3	main
kalevipojast	doc_399014257235_item	2388029	et	4	main
kui	doc_399014257235_item	2388038	et	3	main
oli	doc_399014257235_item	2388040	et	3	main
peale	doc_399014257235_item	2388044	et	4	main
mõned	doc_399014257235_item	2388053	et	3	main
mis	doc_399014257235_item	2388055	et	4	main
sümboliseerivad	doc_399014257235_item	2388056	et	4	main
eestlaste	doc_399014257235_item	2388057	et	4	main
kojujõudmist	doc_399014257235_item	2388058	et	3	main
lisaks	doc_399014257235_item	2388059	et	4	main
skulptorite	doc_399014257235_item	2388060	et	3	main
suhtes	doc_399014257235_item	2388077	et	4	main
peopesadega	doc_399014257235_item	2388028	et	3	main
kandmas	doc_399014257235_item	2388030	et	3	main
kuju	doc_399014257235_item	2388032	et	4	main
sümboliseerib	doc_399014257235_item	2388033	et	3	main
kangelase	doc_399014257235_item	2388034	et	3	main
kojunaasmist	doc_399014257235_item	2388035	et	3	main
kangelase	doc_399014257235_item	2388045	et	3	main
on	doc_399014257235_item	2388047	et	4	main
kunstniku	doc_399014257235_item	2388049	et	3	main
poolt	doc_399014257235_item	2388050	et	4	main
paat	doc_399014257235_item	2388051	et	3	main
boikoteerib	doc_399014257235_item	2388062	et	3	main
on	doc_399014257235_item	2388069	et	4	main
tülis	doc_399014257235_item	2388070	et	4	main
linnaga	doc_399014257235_item	2388071	et	3	main
ka	doc_399014257235_item	2388072	et	3	main
linna	doc_399014257235_item	2388074	et	4	main
haldushoone	doc_399014257235_item	2388075	et	4	main
asukoha	doc_399014257235_item	2388076	et	4	main
ainsa	doc_399014257235_item	2388081	et	3	main
kes	doc_399014257235_item	2388084	et	4	main
ka	doc_399014257235_item	2388086	et	3	main
pooldanud	doc_399014257235_item	2388088	et	4	main
teiste	doc_399014257235_item	2388090	et	4	main
kunstnike	doc_399014257235_item	2388091	et	3	main
kriitika	doc_399014257235_item	2388092	et	4	main
projekti	doc_399014257235_item	2388093	et	4	main
astus	doc_399014257235_item	2388103	et	3	main
liikmeks	doc_399014257235_item	2388106	et	3	main
loopis	doc_399014257235_item	2388117	et	3	main
pihta	doc_399014257235_item	2388119	et	4	main
aga	doc_399014257235_item	2388122	et	3	main
vägistas	doc_399014257235_item	2388125	et	3	main
konkursi	doc_399014257235_item	2388136	et	3	main
järgi	doc_399014257235_item	2388147	et	4	main
kuju	doc_399014257235_item	2388148	et	4	main
tuleva	doc_399014257235_item	2388153	et	4	main
aasta	doc_399014257235_item	2388154	et	4	main
tõlge	doc_399014257236_item	2388156	et	3	main
kalevipoja	doc_399014257236_item	2388163	et	4	main
vastu	doc_399014257236_item	2388168	et	3	main
tallinnalahte	doc_399014257236_item	2388179	et	4	main
suurusega	doc_399014257236_item	2388182	et	4	main
kõrge	doc_399014257236_item	2388185	et	4	main
teise	doc_399014257236_item	2388223	et	4	main
skulptoriühingu	doc_399014257236_item	2388237	et	4	main
juba	doc_399014257236_item	2388240	et	3	main
skulptoriühingu	doc_399014257236_item	2388247	et	4	main
idée	doc_399014257236_item	2388248	et	4	main
on	doc_399014257236_item	2388251	et	4	main
vananenud	doc_399014257236_item	2388252	et	4	main
mälestusmärgi	doc_399014257236_item	2388260	et	4	main
liidud	doc_399014257236_item	2388270	et	3	main
ära	doc_399014257236_item	2388275	et	4	main
vastutada	doc_399014257236_item	2388279	et	3	main
ametiisikulisusele	doc_399014257236_item	2388281	et	4	main
linnapea	doc_399014257236_item	2388282	et	4	main
jüri	doc_399014257236_item	2388283	et	4	main
ratase	doc_399014257236_item	2388284	et	4	main
32	doc_399014257236_item	2388285	et	2	main
iseseisev	doc_399014257236_item	2388290	et	3	main
on	doc_399014257236_item	2388305	et	4	main
siiski	doc_399014257236_item	2388306	et	4	main
kunstnik	doc_399014257236_item	2388307	et	3	main
vaieltav	doc_399014257236_item	2388308	et	4	main
kalevipoeg	doc_399014257236_item	2388315	et	3	main
lõpus	doc_399014257236_item	2388321	et	4	main
kopenhaageni	doc_399014257236_item	2388326	et	4	main
mereneitsiga	doc_399014257236_item	2388328	et	3	main
symbool	doc_399014257236_item	2388330	et	4	main
plaanis	doc_399014257236_item	2388332	et	4	main
ainult	doc_399014257236_item	2388337	et	4	main
kõrge	doc_399014257236_item	2388340	et	4	main
arvutasime	doc_399014257236_item	2388358	et	3	main
on	doc_399014257236_item	2388375	et	4	main
veel	doc_399014257236_item	2388406	et	4	main
innukas	doc_399014257236_item	2388408	et	4	main
tunne	doc_399014257236_item	2388409	et	4	main
pille	doc_399014257236_item	2388416	et	3	main
innukalt	doc_399014257236_item	2388419	et	4	main
kuju	doc_399014257236_item	2388421	et	4	main
symboliseerib	doc_399014257236_item	2388429	et	4	main
arhitektide	doc_399014257235_item	2388066	et	3	main
uue	doc_399014257235_item	2388073	et	3	main
on	doc_399014257235_item	2388079	et	4	main
olnud	doc_399014257235_item	2388110	et	4	main
ise	doc_399014257235_item	2388113	et	4	main
järgi	doc_399014257235_item	2388116	et	4	main
tallinnas	doc_399014257235_item	2388078	et	4	main
võimul	doc_399014257235_item	2388080	et	3	main
on	doc_399014257235_item	2388085	et	4	main
vastu	doc_399014257235_item	2388094	et	3	main
kasvas	doc_399014257235_item	2388095	et	3	main
pärast	doc_399014257235_item	2388096	et	4	main
seda	doc_399014257235_item	2388097	et	3	main
suvel	doc_399014257235_item	2388104	et	3	main
objektiks	doc_399014257235_item	2388108	et	3	main
legendi	doc_399014257235_item	2388115	et	4	main
suuri	doc_399014257235_item	2388120	et	3	main
kes	doc_399014257235_item	2388123	et	4	main
meres	doc_399014257235_item	2388126	et	3	main
on	doc_399014257235_item	2388128	et	4	main
küsitud	doc_399014257235_item	2388129	et	4	main
kas	doc_399014257235_item	2388130	et	3	main
ta	doc_399014257235_item	2388131	et	4	main
on	doc_399014257235_item	2388132	et	4	main
püstitada	doc_399014257235_item	2388151	et	3	main
jooksul	doc_399014257235_item	2388155	et	4	main
tallinnalahte	doc_399014257236_item	2388160	et	4	main
linn	doc_399014257236_item	2388166	et	3	main
võistlustööd	doc_399014257236_item	2388170	et	4	main
tallinna	doc_399014257236_item	2388175	et	4	main
linna	doc_399014257236_item	2388176	et	4	main
maja	doc_399014257236_item	2388181	et	4	main
meetrid	doc_399014257236_item	2388184	et	3	main
rahvaeepose	doc_399014257236_item	2388189	et	3	main
järgi	doc_399014257236_item	2388191	et	4	main
poolt	doc_399014257236_item	2388193	et	4	main
korraldatud	doc_399014257236_item	2388194	et	4	main
võistlusele	doc_399014257236_item	2388195	et	3	main
kangelastele	doc_399014257236_item	2388225	et	4	main
kuju	doc_399014257236_item	2388241	et	4	main
ja	doc_399014257236_item	2388243	et	3	main
ega	doc_399014257236_item	2388253	et	3	main
kangelane	doc_399014257236_item	2388255	et	3	main
sobiv	doc_399014257236_item	2388257	et	4	main
juurte	doc_399014257236_item	2388262	et	3	main
varem	doc_399014257236_item	2388263	et	4	main
sügisel	doc_399014257236_item	2388264	et	3	main
nii	doc_399014257236_item	2388265	et	3	main
skulptorite	doc_399014257236_item	2388266	et	3	main
kui	doc_399014257236_item	2388267	et	3	main
žüriist	doc_399014257236_item	2388274	et	2	main
žürii	doc_399014257236_item	2388288	et	2	main
kes	doc_399014257236_item	2388297	et	4	main
parke	doc_399014257236_item	2388301	et	3	main
idée	doc_399014257236_item	2388303	et	4	main
kangro40	doc_399014257236_item	2388311	et	4	main
mereneits	doc_399014257236_item	2388335	et	4	main
oli	doc_399014257236_item	2388336	et	3	main
meetrid	doc_399014257236_item	2388339	et	3	main
juurde	doc_399014257236_item	2388357	et	4	main
otsustasime	doc_399014257236_item	2388362	et	3	main
põhjendas	doc_399014257236_item	2388368	et	3	main
asetäitja	doc_399014257236_item	2388370	et	4	main
olga	doc_399014257236_item	2388371	et	4	main
sõtnik	doc_399014257236_item	2388372	et	4	main
valitses	doc_399014257236_item	2388405	et	3	main
polnud	doc_399014257236_item	2388411	et	3	main
aga	doc_399014257236_item	2388414	et	3	main
esidles	doc_399014257236_item	2388418	et	4	main
prontsist	doc_399014257236_item	2388420	et	4	main
parteina	doc_399014257235_item	2388082	et	3	main
pikalt	doc_399014257235_item	2388100	et	4	main
propageerinud	doc_399014257235_item	2388101	et	4	main
kangro	doc_399014257235_item	2388102	et	4	main
kes	doc_399014257235_item	2388114	et	4	main
kivisid	doc_399014257235_item	2388121	et	3	main
ka	doc_399014257235_item	2388124	et	3	main
neiu	doc_399014257235_item	2388127	et	4	main
sobiv	doc_399014257235_item	2388133	et	4	main
korraldatakse	doc_399014257235_item	2388143	et	3	main
kavas	doc_399014257235_item	2388150	et	3	main
hiidlastniku	doc_399014257236_item	2388162	et	4	main
kolm	doc_399014257236_item	2388169	et	3	main
eestlased	doc_399014257236_item	2388171	et	3	main
vaatavad	doc_399014257236_item	2388173	et	4	main
21	doc_399014257236_item	2388183	et	2	main
eesti	doc_399014257236_item	2388187	et	4	main
nõukogute	doc_399014257236_item	2388221	et	4	main
püstitatud	doc_399014257236_item	2388226	et	4	main
erimeelsused	doc_399014257236_item	2388238	et	4	main
kui	doc_399014257236_item	2388249	et	3	main
niisugune	doc_399014257236_item	2388250	et	3	main
nõukogute	doc_399014257236_item	2388258	et	4	main
aja	doc_399014257236_item	2388259	et	4	main
ka	doc_399014257236_item	2388268	et	3	main
arhitektite	doc_399014257236_item	2388269	et	4	main
oma	doc_399014257236_item	2388272	et	4	main
kui	doc_399014257236_item	2388276	et	3	main
et	doc_399014257236_item	2388278	et	3	main
žürii	doc_399014257236_item	2388280	et	2	main
ainus	doc_399014257236_item	2388289	et	4	main
planeerinud	doc_399014257236_item	2388299	et	4	main
skulptor	doc_399014257236_item	2388309	et	3	main
kes	doc_399014257236_item	2388312	et	4	main
tallinnasse	doc_399014257236_item	2388325	et	3	main
esialgses	doc_399014257236_item	2388331	et	3	main
väike	doc_399014257236_item	2388334	et	4	main
ettepaneku	doc_399014257236_item	2388343	et	3	main
ja	doc_399014257236_item	2388359	et	3	main
21	doc_399014257236_item	2388363	et	2	main
see	doc_399014257236_item	2388365	et	3	main
silma	doc_399014257236_item	2388367	et	4	main
linnapea	doc_399014257236_item	2388369	et	4	main
sõnul	doc_399014257236_item	2388374	et	3	main
koht	doc_399014257236_item	2388377	et	3	main
esmaspäevalgi	doc_399014257236_item	2388407	et	4	main
kunstnik	doc_399014257236_item	2388410	et	3	main
linnas	doc_399014257236_item	2388413	et	4	main
gallerist	doc_399014257236_item	2388415	et	4	main
suurde	doc_399014257236_item	2388423	et	3	main
kangelase	doc_399014257236_item	2388440	et	3	main
vaadates	doc_399014257236_item	2388445	et	3	main
ja	doc_399014257236_item	2388448	et	3	main
sümboliseerib	doc_399014257236_item	2388451	et	3	main
kojutulekut	doc_399014257236_item	2388453	et	3	main
on	doc_399014257236_item	2388466	et	4	main
uus	doc_399014257236_item	2388477	et	3	main
raekoda	doc_399014257236_item	2388478	et	4	main
tallinnas	doc_399014257236_item	2388479	et	4	main
kunstnikute	doc_399014257236_item	2388494	et	4	main
kriitika	doc_399014257236_item	2388495	et	4	main
aega	doc_399014257236_item	2388505	et	4	main
erakonnaga	doc_399014257236_item	2388510	et	4	main
loopis	doc_399014257236_item	2388521	et	3	main
süüdi	doc_399014257236_item	2388527	et	4	main
välja	doc_399014257236_item	2388545	et	4	main
mille	doc_399014257236_item	2388548	et	3	main
näituseks	doc_399014257236_item	2388554	et	4	main
linnapea	doc_399014257236_item	2388555	et	4	main
sõtniku	doc_399014257236_item	2388557	et	4	main
et	doc_399014257236_item	2388561	et	3	main
branderi	doc_399014257237_item	2388569	et	4	main
helsingi	doc_399014257237_item	2388570	et	4	main
linnamuuseum	doc_399014257237_item	2388571	et	3	main
ringsõidule	doc_399014257237_item	2388578	et	3	main
tõttu	doc_399014257237_item	2388619	et	4	main
helsingi	doc_399014257237_item	2388620	et	4	main
kui	doc_399014257235_item	2388098	et	3	main
ideed	doc_399014257235_item	2388099	et	4	main
keskerakonna	doc_399014257235_item	2388105	et	4	main
kriitika	doc_399014257235_item	2388107	et	4	main
on	doc_399014257235_item	2388109	et	4	main
ka	doc_399014257235_item	2388111	et	3	main
kalevipoeg	doc_399014257235_item	2388112	et	3	main
vaenlaste	doc_399014257235_item	2388118	et	3	main
merele	doc_399014257235_item	2388135	et	3	main
tulemused	doc_399014257235_item	2388137	et	3	main
jaanuari	doc_399014257235_item	2388139	et	4	main
ning	doc_399014257235_item	2388141	et	3	main
kavanditest	doc_399014257235_item	2388142	et	3	main
näitus	doc_399014257235_item	2388144	et	3	main
on	doc_399014257235_item	2388149	et	4	main
mõeldud	doc_399014257236_item	2388161	et	4	main
tallinna	doc_399014257236_item	2388165	et	4	main
kunstnikud	doc_399014257236_item	2388172	et	3	main
viltu	doc_399014257236_item	2388174	et	3	main
mitmekorrusellise	doc_399014257236_item	2388180	et	4	main
kalevipoeg	doc_399014257236_item	2388186	et	3	main
samanimega	doc_399014257236_item	2388188	et	3	main
maailmasõja	doc_399014257236_item	2388224	et	3	main
kompleks	doc_399014257236_item	2388228	et	4	main
paistab	doc_399014257236_item	2388230	et	3	main
merele	doc_399014257236_item	2388231	et	3	main
obeliski	doc_399014257236_item	2388232	et	4	main
algavad	doc_399014257236_item	2388239	et	4	main
suurusest	doc_399014257236_item	2388242	et	4	main
paigast	doc_399014257236_item	2388244	et	4	main
merel	doc_399014257236_item	2388245	et	3	main
eesti	doc_399014257236_item	2388246	et	4	main
rahvaeepose	doc_399014257236_item	2388254	et	3	main
ole	doc_399014257236_item	2388256	et	4	main
kompleksi	doc_399014257236_item	2388261	et	4	main
esindajad	doc_399014257236_item	2388273	et	4	main
protestina	doc_399014257236_item	2388277	et	3	main
juhitud	doc_399014257236_item	2388287	et	4	main
on	doc_399014257236_item	2388292	et	4	main
lõpuks	doc_399014257236_item	2388294	et	4	main
on	doc_399014257236_item	2388298	et	4	main
isa	doc_399014257236_item	2388304	et	4	main
algas	doc_399014257236_item	2388313	et	3	main
juba	doc_399014257236_item	2388317	et	3	main
idéeks	doc_399014257236_item	2388322	et	4	main
oli	doc_399014257236_item	2388323	et	3	main
väike	doc_399014257236_item	2388327	et	4	main
rinnastatav	doc_399014257236_item	2388329	et	4	main
14	doc_399014257236_item	2388338	et	2	main
linna	doc_399014257236_item	2388342	et	4	main
kõrgust	doc_399014257236_item	2388345	et	4	main
lisati	doc_399014257236_item	2388346	et	3	main
21	doc_399014257236_item	2388348	et	2	main
vaatasime	doc_399014257236_item	2388350	et	3	main
kuidas	doc_399014257236_item	2388351	et	3	main
sobib	doc_399014257236_item	2388353	et	3	main
maarjamäe	doc_399014257236_item	2388354	et	3	main
mälestusmargi	doc_399014257236_item	2388355	et	3	main
kompleksi	doc_399014257236_item	2388356	et	4	main
paistis	doc_399014257236_item	2388366	et	3	main
sõtniki	doc_399014257236_item	2388373	et	4	main
vened	doc_399014257236_item	2388427	et	3	main
ta	doc_399014257236_item	2388435	et	4	main
oli	doc_399014257236_item	2388436	et	3	main
eestlase	doc_399014257236_item	2388452	et	3	main
skulptoride	doc_399014257236_item	2388455	et	4	main
püstitamist	doc_399014257236_item	2388458	et	4	main
boikoteeris	doc_399014257236_item	2388459	et	3	main
ka	doc_399014257236_item	2388469	et	3	main
valitseb	doc_399014257236_item	2388480	et	3	main
mis	doc_399014257236_item	2388485	et	4	main
ennemki	doc_399014257236_item	2388487	et	4	main
avaldanud	doc_399014257236_item	2388488	et	4	main
sümpaatiat	doc_399014257236_item	2388489	et	3	main
kõrgeid	doc_399014257236_item	2388490	et	3	main
kohda	doc_399014257236_item	2388498	et	4	main
on	doc_399014257236_item	2388512	et	4	main
võtnud	doc_399014257236_item	2388514	et	4	main
ise	doc_399014257236_item	2388517	et	4	main
kes	doc_399014257236_item	2388518	et	4	main
vaenlasi	doc_399014257236_item	2388522	et	3	main
sümbol	doc_399014257235_item	2388134	et	3	main
avalikustatakse	doc_399014257235_item	2388138	et	3	main
lõpus	doc_399014257235_item	2388140	et	4	main
abilinnapea	doc_399014257235_item	2388145	et	4	main
sõtniku	doc_399014257235_item	2388146	et	4	main
kahe	doc_399014257235_item	2388152	et	3	main
kunstnikuliidud	doc_399014257236_item	2388157	et	3	main
vaatavad	doc_399014257236_item	2388158	et	4	main
viltu	doc_399014257236_item	2388159	et	3	main
kujule	doc_399014257236_item	2388164	et	3	main
võtis	doc_399014257236_item	2388167	et	3	main
plaani	doc_399014257236_item	2388177	et	4	main
püstitada	doc_399014257236_item	2388178	et	3	main
kangelaskuju	doc_399014257236_item	2388190	et	4	main
linna	doc_399014257236_item	2388192	et	4	main
oli	doc_399014257236_item	2388196	et	3	main
kuni	doc_399014257236_item	2388197	et	3	main
tähtaegani	doc_399014257236_item	2388198	et	4	main
esmaspäeval	doc_399014257236_item	2388199	et	3	main
tulnud	doc_399014257236_item	2388200	et	4	main
vaid	doc_399014257236_item	2388201	et	3	main
kolm	doc_399014257236_item	2388202	et	3	main
võistlustööd	doc_399014257236_item	2388203	et	4	main
kalevipoeg	doc_399014257236_item	2388204	et	3	main
oli	doc_399014257236_item	2388205	et	3	main
mõeldud	doc_399014257236_item	2388206	et	4	main
püstitada	doc_399014257236_item	2388207	et	3	main
merre	doc_399014257236_item	2388208	et	3	main
saja	doc_399014257236_item	2388209	et	4	main
meetri	doc_399014257236_item	2388210	et	3	main
kaugusele	doc_399014257236_item	2388211	et	4	main
rannast	doc_399014257236_item	2388212	et	4	main
tallinn	doc_399014257236_item	2388213	et	4	main
pirita	doc_399014257236_item	2388214	et	4	main
randtee	doc_399014257236_item	2388215	et	4	main
ääre	doc_399014257236_item	2388216	et	3	main
vastaval	doc_399014257236_item	2388217	et	4	main
kohal	doc_399014257236_item	2388218	et	4	main
rannas	doc_399014257236_item	2388219	et	3	main
on	doc_399014257236_item	2388220	et	4	main
ajal	doc_399014257236_item	2388222	et	4	main
mälestusmärgi	doc_399014257236_item	2388227	et	4	main
kust	doc_399014257236_item	2388229	et	4	main
ning	doc_399014257236_item	2388233	et	3	main
rannatrepp	doc_399014257236_item	2388234	et	3	main
linna	doc_399014257236_item	2388235	et	4	main
ja	doc_399014257236_item	2388236	et	3	main
võtsid	doc_399014257236_item	2388271	et	4	main
poolt	doc_399014257236_item	2388286	et	4	main
kunstnikliige	doc_399014257236_item	2388291	et	3	main
lõpude	doc_399014257236_item	2388293	et	4	main
ainult	doc_399014257236_item	2388295	et	4	main
maastikuarhitekt	doc_399014257236_item	2388296	et	3	main
linna	doc_399014257236_item	2388300	et	4	main
esialgse	doc_399014257236_item	2388302	et	3	main
tauno	doc_399014257236_item	2388310	et	4	main
turustada	doc_399014257236_item	2388314	et	3	main
kavatsust	doc_399014257236_item	2388316	et	4	main
1990	doc_399014257236_item	2388318	et	2	main
nda	doc_399014257236_item	2388319	et	4	main
aasta	doc_399014257236_item	2388320	et	4	main
luua	doc_399014257236_item	2388324	et	4	main
tallinna	doc_399014257236_item	2388333	et	4	main
aga	doc_399014257236_item	2388341	et	3	main
puhul	doc_399014257236_item	2388344	et	4	main
kuni	doc_399014257236_item	2388347	et	3	main
meetrini	doc_399014257236_item	2388349	et	3	main
kuju	doc_399014257236_item	2388352	et	4	main
visualiseerisime	doc_399014257236_item	2388360	et	4	main
seda	doc_399014257236_item	2388361	et	3	main
meetrini	doc_399014257236_item	2388364	et	3	main
see	doc_399014257236_item	2388376	et	3	main
kõige	doc_399014257236_item	2388378	et	4	main
parim	doc_399014257236_item	2388379	et	4	main
sest	doc_399014257236_item	2388380	et	4	main
see	doc_399014257236_item	2388381	et	3	main
jääb	doc_399014257236_item	2388382	et	3	main
turistide	doc_399014257236_item	2388383	et	3	main
sight-seeingi	doc_399014257236_item	2388384	et	4	main
tee	doc_399014257236_item	2388385	et	4	main
kõrvale	doc_399014257236_item	2388386	et	4	main
pirita	doc_399014257236_item	2388387	et	4	main
sanatooriumi	doc_399014257236_item	2388388	et	4	main
ja	doc_399014257236_item	2388389	et	3	main
botaanika	doc_399014257236_item	2388391	et	4	main
aia	doc_399014257236_item	2388392	et	4	main
tallinna	doc_399014257236_item	2388390	et	4	main
suunda	doc_399014257236_item	2388393	et	4	main
minnes	doc_399014257236_item	2388394	et	3	main
see	doc_399014257236_item	2388395	et	3	main
ei	doc_399014257236_item	2388396	et	4	main
ka	doc_399014257236_item	2388397	et	3	main
varja	doc_399014257236_item	2388398	et	4	main
vanalinna	doc_399014257236_item	2388399	et	4	main
siluetti	doc_399014257236_item	2388400	et	4	main
tauno	doc_399014257236_item	2388401	et	4	main
kangro	doc_399014257236_item	2388402	et	4	main
gallerias	doc_399014257236_item	2388403	et	4	main
vanalinnas	doc_399014257236_item	2388404	et	4	main
ise	doc_399014257236_item	2388412	et	4	main
mägila	doc_399014257236_item	2388417	et	4	main
kus	doc_399014257236_item	2388422	et	3	main
kaleviporg	doc_399014257236_item	2388425	et	4	main
rändanud	doc_399014257236_item	2388439	et	4	main
vaatevinkelist	doc_399014257236_item	2388444	et	4	main
vveel	doc_399014257236_item	2388446	et	4	main
mõni	doc_399014257236_item	2388449	et	3	main
ühingu	doc_399014257236_item	2388456	et	3	main
samba	doc_399014257236_item	2388457	et	4	main
veel	doc_399014257236_item	2388461	et	4	main
mõjuvõimsaim	doc_399014257236_item	2388462	et	4	main
arhitektide	doc_399014257236_item	2388463	et	3	main
liit	doc_399014257236_item	2388464	et	3	main
mis	doc_399014257236_item	2388465	et	4	main
läinud	doc_399014257236_item	2388468	et	4	main
partei	doc_399014257236_item	2388483	et	4	main
turustanud	doc_399014257236_item	2388506	et	4	main
kangro	doc_399014257236_item	2388507	et	4	main
kriitikat	doc_399014257236_item	2388511	et	3	main
vastu	doc_399014257236_item	2388513	et	3	main
ka	doc_399014257236_item	2388515	et	3	main
kätega	doc_399014257236_item	2388424	et	3	main
kannab	doc_399014257236_item	2388426	et	3	main
sammas	doc_399014257236_item	2388428	et	4	main
kangelase	doc_399014257236_item	2388430	et	3	main
kojutulekut	doc_399014257236_item	2388431	et	3	main
peale	doc_399014257236_item	2388432	et	4	main
seda	doc_399014257236_item	2388433	et	3	main
kui	doc_399014257236_item	2388434	et	3	main
maailma	doc_399014257236_item	2388437	et	4	main
käes	doc_399014257236_item	2388441	et	4	main
on	doc_399014257236_item	2388442	et	4	main
kunstniku	doc_399014257236_item	2388443	et	3	main
paat	doc_399014257236_item	2388447	et	3	main
inimkogu	doc_399014257236_item	2388450	et	4	main
peale	doc_399014257236_item	2388454	et	4	main
riidu	doc_399014257236_item	2388467	et	4	main
üks	doc_399014257236_item	2388482	et	3	main
hooneid	doc_399014257236_item	2388491	et	4	main
kohda	doc_399014257236_item	2388492	et	4	main
püstitamise	doc_399014257236_item	2388497	et	4	main
suuremaks	doc_399014257236_item	2388500	et	4	main
siis	doc_399014257236_item	2388501	et	3	main
liitus	doc_399014257236_item	2388508	et	4	main
muisnaisjuttu	doc_399014257236_item	2388519	et	4	main
järgi	doc_399014257236_item	2388520	et	4	main
aga	doc_399014257236_item	2388525	et	3	main
ta	doc_399014257236_item	2388535	et	4	main
on	doc_399014257236_item	2388536	et	4	main
andakse	doc_399014257236_item	2388544	et	4	main
lõpuks	doc_399014257236_item	2388547	et	4	main
pärast	doc_399014257236_item	2388549	et	4	main
võitlusest	doc_399014257236_item	2388550	et	4	main
asetäitja	doc_399014257236_item	2388556	et	4	main
on	doc_399014257236_item	2388559	et	4	main
mõeltud	doc_399014257236_item	2388560	et	4	main
aasta	doc_399014257236_item	2388565	et	4	main
jooksul	doc_399014257236_item	2388566	et	4	main
tõlge	doc_399014257237_item	2388567	et	3	main
signe	doc_399014257237_item	2388568	et	4	main
otsustas	doc_399014257237_item	2388622	et	3	main
1906	doc_399014257237_item	2388624	et	2	main
korda	doc_399014257237_item	2388640	et	4	main
brander	doc_399014257237_item	2388645	et	4	main
veelgi	doc_399014257237_item	2388658	et	4	main
linnamuuseumi	doc_399014257237_item	2388661	et	4	main
tuumaparemiku	doc_399014257237_item	2388663	et	3	main
avaldanud	doc_399014257237_item	2388668	et	4	main
pildidest	doc_399014257237_item	2388671	et	3	main
mis	doc_399014257237_item	2388674	et	4	main
täiesti	doc_399014257237_item	2388676	et	3	main
parimast	doc_399014257237_item	2388695	et	4	main
antud	doc_399014257237_item	2388703	et	4	main
raamatut	doc_399014257237_item	2388704	et	3	main
töötass	doc_399014257237_item	2388728	et	3	main
juhatas	doc_399014257237_item	2388742	et	3	main
koostamist	doc_399014257237_item	2388745	et	4	main
koostas	doc_399014257237_item	2388747	et	4	main
branderile	doc_399014257237_item	2388748	et	4	main
plaani	doc_399014257237_item	2388749	et	4	main
ja	doc_399014257237_item	2388760	et	3	main
1900	doc_399014257237_item	2388762	et	2	main
alguses	doc_399014257237_item	2388764	et	4	main
kohinaga	doc_399014257237_item	2388765	et	4	main
ehitamine	doc_399014257237_item	2388769	et	4	main
oli	doc_399014257237_item	2388770	et	3	main
kahekorrulised	doc_399014257237_item	2388779	et	4	main
puit	doc_399014257237_item	2388780	et	3	main
majad	doc_399014257237_item	2388781	et	3	main
sai	doc_399014257237_item	2388825	et	4	main
ateljeetöö	doc_399014257237_item	2388832	et	4	main
kogemust	doc_399014257237_item	2388835	et	3	main
tahtis	doc_399014257237_item	2388840	et	3	main
brander	doc_399014257237_item	2388843	et	4	main
tolleaegses	doc_399014257237_item	2388845	et	3	main
algelises	doc_399014257237_item	2388846	et	4	main
tehnikas	doc_399014257237_item	2388847	et	3	main
väga	doc_399014257237_item	2388848	et	3	main
andekalt	doc_399014257237_item	2388849	et	4	main
ei	doc_399014257237_item	2388854	et	4	main
ringi	doc_399014257236_item	2388438	et	4	main
ka	doc_399014257236_item	2388460	et	3	main
muu	doc_399014257236_item	2388470	et	4	main
hulgas	doc_399014257236_item	2388471	et	4	main
sellel	doc_399014257236_item	2388472	et	4	main
teemal	doc_399014257236_item	2388473	et	3	main
et	doc_399014257236_item	2388474	et	3	main
kuhu	doc_399014257236_item	2388475	et	3	main
ehitatakse	doc_399014257236_item	2388476	et	3	main
ainult	doc_399014257236_item	2388481	et	4	main
keskerakond	doc_399014257236_item	2388484	et	3	main
on	doc_399014257236_item	2388486	et	4	main
teiste	doc_399014257236_item	2388493	et	4	main
samba	doc_399014257236_item	2388496	et	4	main
tuli	doc_399014257236_item	2388499	et	4	main
kui	doc_399014257236_item	2388502	et	3	main
idéet	doc_399014257236_item	2388503	et	4	main
kaua	doc_399014257236_item	2388504	et	3	main
suvel	doc_399014257236_item	2388509	et	3	main
kalevipoeg	doc_399014257236_item	2388516	et	3	main
suurde	doc_399014257236_item	2388523	et	3	main
oli	doc_399014257236_item	2388526	et	3	main
ka	doc_399014257236_item	2388528	et	3	main
vägistamisele	doc_399014257236_item	2388530	et	4	main
meres	doc_399014257236_item	2388531	et	3	main
on	doc_399014257236_item	2388532	et	4	main
küsitud	doc_399014257236_item	2388533	et	4	main
kas	doc_399014257236_item	2388534	et	3	main
avaldatakse	doc_399014257236_item	2388543	et	3	main
sammas	doc_399014257236_item	2388562	et	4	main
püsditatakse	doc_399014257236_item	2388563	et	4	main
järgmise	doc_399014257236_item	2388564	et	3	main
raamat	doc_399014257237_item	2388576	et	3	main
viib	doc_399014257237_item	2388577	et	3	main
linnavolikogu	doc_399014257237_item	2388621	et	4	main
võttis	doc_399014257237_item	2388630	et	3	main
otsust	doc_399014257237_item	2388638	et	4	main
ja	doc_399014257237_item	2388642	et	3	main
kiidetud	doc_399014257237_item	2388644	et	4	main
fotografeeris	doc_399014257237_item	2388646	et	3	main
helsingit	doc_399014257237_item	2388647	et	4	main
umbes	doc_399014257237_item	2388648	et	4	main
seitse	doc_399014257237_item	2388649	et	3	main
aastat	doc_399014257237_item	2388650	et	3	main
1907-13	doc_399014257237_item	2388651	et	2	main
moodustavad	doc_399014257237_item	2388659	et	4	main
fotodele	doc_399014257237_item	2388678	et	3	main
jan	doc_399014257237_item	2388680	et	4	main
riitta	doc_399014257237_item	2388684	et	4	main
pakarinen	doc_399014257237_item	2388685	et	4	main
mis	doc_399014257237_item	2388690	et	4	main
koosneb	doc_399014257237_item	2388691	et	3	main
branderi	doc_399014257237_item	2388692	et	4	main
umbes	doc_399014257237_item	2388693	et	4	main
pole	doc_399014257237_item	2388701	et	3	main
välja	doc_399014257237_item	2388702	et	4	main
muistsuskaitsekomisjonis	doc_399014257237_item	2388727	et	4	main
gustaf	doc_399014257237_item	2388739	et	4	main
nyström	doc_399014257237_item	2388740	et	4	main
pildistada	doc_399014257237_item	2388751	et	3	main
oli	doc_399014257237_item	2388754	et	3	main
kasvas	doc_399014257237_item	2388759	et	3	main
töölö	doc_399014257237_item	2388766	et	4	main
1800-aastade	doc_399014257237_item	2388773	et	4	main
linnas	doc_399014257237_item	2388775	et	4	main
õpetajana	doc_399014257237_item	2388821	et	4	main
ega	doc_399014257237_item	2388831	et	3	main
tööst	doc_399014257237_item	2388836	et	3	main
välja	doc_399014257237_item	2388841	et	4	main
linna	doc_399014257237_item	2388850	et	4	main
ning	doc_399014257237_item	2388851	et	3	main
rahule	doc_399014257237_item	2388856	et	4	main
tema	doc_399014257237_item	2388868	et	4	main
politseinike	doc_399014257237_item	2388876	et	3	main
koduloomi	doc_399014257237_item	2388878	et	4	main
sagelienamasti	doc_399014257237_item	2388879	et	4	main
jõudsid	doc_399014257237_item	2388884	et	4	main
juhuslikult	doc_399014257237_item	2388885	et	4	main
on	doc_399014257237_item	2388889	et	4	main
peatuda	doc_399014257237_item	2388892	et	3	main
inimeste	doc_399014257237_item	2388894	et	3	main
kivedega	doc_399014257236_item	2388524	et	4	main
tulemused	doc_399014257236_item	2388542	et	3	main
jaanuari	doc_399014257236_item	2388546	et	4	main
raamatu	doc_399014257237_item	2388573	et	4	main
legendaarsest	doc_399014257237_item	2388574	et	3	main
fotograafist	doc_399014257237_item	2388575	et	4	main
saja	doc_399014257237_item	2388579	et	4	main
aasta	doc_399014257237_item	2388580	et	4	main
tagusesse	doc_399014257237_item	2388581	et	4	main
helsingisse	doc_399014257237_item	2388582	et	4	main
helsingi	doc_399014257237_item	2388583	et	4	main
rahva	doc_399014257237_item	2388584	et	3	main
arv	doc_399014257237_item	2388585	et	3	main
ületas	doc_399014257237_item	2388586	et	3	main
100	doc_399014257237_item	2388587	et	2	main
000	doc_399014257237_item	2388588	et	2	main
elaniku	doc_399014257237_item	2388589	et	3	main
piiri	doc_399014257237_item	2388590	et	4	main
aastal	doc_399014257237_item	2388591	et	3	main
1902	doc_399014257237_item	2388592	et	2	main
kolme	doc_399014257237_item	2388593	et	4	main
kümne	doc_399014257237_item	2388594	et	4	main
aasta	doc_399014257237_item	2388595	et	4	main
jooksul	doc_399014257237_item	2388596	et	4	main
elanike	doc_399014257237_item	2388597	et	3	main
arv	doc_399014257237_item	2388598	et	3	main
oli	doc_399014257237_item	2388599	et	3	main
kolmekordistunud	doc_399014257237_item	2388600	et	4	main
linna	doc_399014257237_item	2388601	et	4	main
tohutu	doc_399014257237_item	2388602	et	4	main
kasv	doc_399014257237_item	2388603	et	3	main
ja	doc_399014257237_item	2388604	et	3	main
muutus	doc_399014257237_item	2388605	et	4	main
äratasid	doc_399014257237_item	2388606	et	4	main
arhitektid	doc_399014257237_item	2388607	et	3	main
ja	doc_399014257237_item	2388608	et	3	main
helsingi	doc_399014257237_item	2388609	et	4	main
otsustajad	doc_399014257237_item	2388610	et	4	main
sada	doc_399014257237_item	2388611	et	4	main
aastat	doc_399014257237_item	2388612	et	3	main
neiu	doc_399014257236_item	2388529	et	4	main
sobiv	doc_399014257236_item	2388537	et	4	main
sümbol	doc_399014257236_item	2388538	et	3	main
merre	doc_399014257236_item	2388539	et	3	main
kalevipoeg	doc_399014257236_item	2388540	et	3	main
võistluse	doc_399014257236_item	2388541	et	3	main
osalenud	doc_399014257236_item	2388551	et	4	main
tööd	doc_399014257236_item	2388552	et	4	main
korraldatakse	doc_399014257236_item	2388553	et	3	main
sõnul	doc_399014257236_item	2388558	et	3	main
tegi	doc_399014257237_item	2388572	et	4	main
tagasi	doc_399014257237_item	2388613	et	3	main
kaduvat	doc_399014257237_item	2388615	et	4	main
puitmajadest	doc_399014257237_item	2388616	et	3	main
linna	doc_399014257237_item	2388617	et	4	main
selle	doc_399014257237_item	2388618	et	4	main
asutada	doc_399014257237_item	2388625	et	3	main
signe	doc_399014257237_item	2388633	et	4	main
branderi	doc_399014257237_item	2388634	et	4	main
1869-1942	doc_399014257237_item	2388635	et	2	main
hiljem	doc_399014257237_item	2388636	et	3	main
on	doc_399014257237_item	2388637	et	4	main
targaks	doc_399014257237_item	2388641	et	3	main
töö	doc_399014257237_item	2388652	et	4	main
907	doc_399014257237_item	2388655	et	2	main
on	doc_399014257237_item	2388666	et	4	main
nüüd	doc_399014257237_item	2388667	et	4	main
põhineb	doc_399014257237_item	2388675	et	3	main
raamatu	doc_399014257237_item	2388689	et	4	main
fotost	doc_399014257237_item	2388698	et	3	main
ajaloost	doc_399014257237_item	2388700	et	4	main
saab	doc_399014257237_item	2388722	et	3	main
oma	doc_399014257237_item	2388725	et	4	main
fotoraamatu	doc_399014257237_item	2388726	et	4	main
kultuuriajaloo	doc_399014257237_item	2388734	et	4	main
asjatundjaid	doc_399014257237_item	2388735	et	3	main
ms	doc_399014257237_item	2388736	et	4	main
arhitekt	doc_399014257237_item	2388737	et	3	main
professor	doc_399014257237_item	2388738	et	3	main
linnaplaani	doc_399014257237_item	2388744	et	4	main
kus	doc_399014257237_item	2388753	et	3	main
aastade	doc_399014257237_item	2388763	et	4	main
ning	doc_399014257237_item	2388772	et	3	main
alguses	doc_399014257237_item	2388774	et	4	main
ehitatud	doc_399014257237_item	2388776	et	4	main
ühe-	doc_399014257237_item	2388777	et	4	main
ja	doc_399014257237_item	2388778	et	3	main
asemel	doc_399014257237_item	2388823	et	4	main
portree	doc_399014257237_item	2388830	et	4	main
ta	doc_399014257237_item	2388839	et	4	main
minna	doc_399014257237_item	2388842	et	3	main
ainult	doc_399014257237_item	2388857	et	4	main
arhitektuuripildistamisega	doc_399014257237_item	2388859	et	3	main
ja	doc_399014257237_item	2388861	et	3	main
pilditel	doc_399014257237_item	2388869	et	4	main
alati	doc_399014257237_item	2388872	et	4	main
kaupmehi	doc_399014257237_item	2388875	et	3	main
või	doc_399014257237_item	2388877	et	4	main
sattunud	doc_399014257237_item	2388887	et	4	main
hea	doc_399014257237_item	2388895	et	4	main
talletama	doc_399014257237_item	2388614	et	3	main
muistsuskaitsekomisjoni	doc_399014257237_item	2388626	et	4	main
mis	doc_399014257237_item	2388627	et	4	main
aastal	doc_399014257237_item	2388629	et	3	main
fotograafi	doc_399014257237_item	2388632	et	4	main
mitu	doc_399014257237_item	2388639	et	4	main
laiaulatuslikkuks	doc_399014257237_item	2388643	et	4	main
mis	doc_399014257237_item	2388657	et	4	main
signe	doc_399014257237_item	2388669	et	4	main
teose	doc_399014257237_item	2388673	et	3	main
tema	doc_399014257237_item	2388677	et	4	main
välja	doc_399014257237_item	2388687	et	4	main
andnud	doc_399014257237_item	2388688	et	4	main
sajast	doc_399014257237_item	2388694	et	4	main
milles	doc_399014257237_item	2388705	et	3	main
aastal	doc_399014257237_item	2388623	et	3	main
järgmisel	doc_399014257237_item	2388628	et	3	main
tööle	doc_399014257237_item	2388631	et	3	main
tulemukseks	doc_399014257237_item	2388653	et	3	main
oli	doc_399014257237_item	2388654	et	3	main
fotot	doc_399014257237_item	2388656	et	3	main
helsingi	doc_399014257237_item	2388660	et	4	main
fotoarhiivi	doc_399014257237_item	2388662	et	4	main
helsingi	doc_399014257237_item	2388664	et	4	main
linnamuuseum	doc_399014257237_item	2388665	et	3	main
branderi	doc_399014257237_item	2388670	et	4	main
esimese	doc_399014257237_item	2388672	et	3	main
fotograaf	doc_399014257237_item	2388679	et	4	main
alanco	doc_399014257237_item	2388681	et	4	main
ja	doc_399014257237_item	2388682	et	3	main
uurija	doc_399014257237_item	2388683	et	4	main
on	doc_399014257237_item	2388686	et	4	main
helsingi	doc_399014257237_item	2388696	et	4	main
teemalisest	doc_399014257237_item	2388697	et	4	main
helsingi	doc_399014257237_item	2388699	et	4	main
ei	doc_399014257237_item	2388706	et	4	main
sisalduks	doc_399014257237_item	2388707	et	3	main
vähemalt	doc_399014257237_item	2388708	et	4	main
mõni	doc_399014257237_item	2388709	et	3	main
foto	doc_399014257237_item	2388710	et	4	main
mis	doc_399014257237_item	2388711	et	4	main
signe	doc_399014257237_item	2388712	et	4	main
brander	doc_399014257237_item	2388713	et	4	main
on	doc_399014257237_item	2388714	et	4	main
1900	doc_399014257237_item	2388715	et	2	main
aastade	doc_399014257237_item	2388716	et	4	main
alguses	doc_399014257237_item	2388717	et	4	main
pildistanud	doc_399014257237_item	2388718	et	4	main
aga	doc_399014257237_item	2388719	et	3	main
alles	doc_399014257237_item	2388720	et	3	main
nüüd	doc_399014257237_item	2388721	et	4	main
tema	doc_399014257237_item	2388723	et	4	main
täiesti	doc_399014257237_item	2388724	et	3	main
oma	doc_399014257237_item	2388729	et	4	main
parimaid	doc_399014257237_item	2388731	et	4	main
helsingi	doc_399014257237_item	2388743	et	4	main
komisjon	doc_399014257237_item	2388746	et	3	main
kohti	doc_399014257237_item	2388752	et	4	main
ootada	doc_399014257237_item	2388755	et	4	main
suuri	doc_399014257237_item	2388756	et	3	main
muutusi	doc_399014257237_item	2388757	et	4	main
ja	doc_399014257237_item	2388767	et	3	main
eest	doc_399014257237_item	2388786	et	4	main
selle	doc_399014257237_item	2388822	et	4	main
kellele	doc_399014257237_item	2388827	et	4	main
tal	doc_399014257237_item	2388833	et	3	main
oli	doc_399014257237_item	2388834	et	3	main
helsingi	doc_399014257237_item	2388837	et	4	main
fotoateljeedes	doc_399014257237_item	2388838	et	3	main
fotografeeris	doc_399014257237_item	2388844	et	3	main
ta	doc_399014257237_item	2388853	et	4	main
elavuse	doc_399014257237_item	2388866	et	4	main
saladus	doc_399014257237_item	2388867	et	3	main
möödujaid	doc_399014257237_item	2388873	et	4	main
lapsi	doc_399014257237_item	2388874	et	4	main
inimesed	doc_399014257237_item	2388881	et	3	main
kes	doc_399014257237_item	2388882	et	4	main
pildile	doc_399014257237_item	2388883	et	3	main
brander	doc_399014257237_item	2388888	et	4	main
arvates	doc_399014257237_item	2388898	et	4	main
oli	doc_399014257237_item	2388899	et	3	main
või	doc_399014257237_item	2388929	et	4	main
aja	doc_399014257237_item	2388730	et	4	main
linnapildi	doc_399014257237_item	2388732	et	4	main
ja	doc_399014257237_item	2388733	et	3	main
kes	doc_399014257237_item	2388741	et	4	main
mida	doc_399014257237_item	2388750	et	4	main
helsingi	doc_399014257237_item	2388758	et	4	main
muudus	doc_399014257237_item	2388761	et	4	main
eira	doc_399014257237_item	2388768	et	4	main
algamas	doc_399014257237_item	2388771	et	3	main
hakkasid	doc_399014257237_item	2388782	et	4	main
kõrgede	doc_399014257237_item	2388783	et	4	main
kivist	doc_399014257237_item	2388784	et	4	main
müüride	doc_399014257237_item	2388785	et	3	main
kaduma	doc_399014257237_item	2388787	et	4	main
riitta	doc_399014257237_item	2388788	et	4	main
pakarinen	doc_399014257237_item	2388789	et	4	main
mõtleb	doc_399014257237_item	2388790	et	3	main
et	doc_399014257237_item	2388791	et	3	main
signe	doc_399014257237_item	2388792	et	4	main
branderi	doc_399014257237_item	2388793	et	4	main
valik	doc_399014257237_item	2388794	et	3	main
helsingi	doc_399014257237_item	2388795	et	4	main
fotograafiks	doc_399014257237_item	2388796	et	4	main
oli	doc_399014257237_item	2388797	et	3	main
enesestmõistetav	doc_399014257237_item	2388798	et	3	main
temal	doc_399014257237_item	2388799	et	3	main
oli	doc_399014257237_item	2388800	et	3	main
juba	doc_399014257237_item	2388801	et	3	main
tõestust	doc_399014257237_item	2388802	et	4	main
osava	doc_399014257237_item	2388803	et	3	main
fotograafina	doc_399014257237_item	2388804	et	4	main
töötamise	doc_399014257237_item	2388805	et	4	main
ja	doc_399014257237_item	2388806	et	3	main
eriti	doc_399014257237_item	2388807	et	3	main
maastikufotografeerimise	doc_399014257237_item	2388808	et	3	main
alal	doc_399014257237_item	2388809	et	4	main
parkanos	doc_399014257237_item	2388810	et	4	main
sündinud	doc_399014257237_item	2388811	et	4	main
brander	doc_399014257237_item	2388812	et	4	main
õppis	doc_399014257237_item	2388813	et	3	main
kunstiõpetajaks	doc_399014257237_item	2388814	et	3	main
helsingis	doc_399014257237_item	2388815	et	4	main
aga	doc_399014257237_item	2388816	et	3	main
ta	doc_399014257237_item	2388817	et	4	main
ei	doc_399014257237_item	2388818	et	4	main
töötanud	doc_399014257237_item	2388819	et	4	main
kunagi	doc_399014257237_item	2388820	et	3	main
temast	doc_399014257237_item	2388824	et	3	main
fotograaf	doc_399014257237_item	2388826	et	4	main
ei	doc_399014257237_item	2388828	et	4	main
meeldinud	doc_399014257237_item	2388829	et	4	main
maastikuid	doc_399014257237_item	2388852	et	4	main
jäänud	doc_399014257237_item	2388855	et	4	main
on	doc_399014257237_item	2388870	et	4	main
olid	doc_399014257237_item	2388880	et	4	main
kohal	doc_399014257237_item	2388886	et	4	main
põhjal	doc_399014257237_item	2388897	et	4	main
oma	doc_399014257237_item	2388902	et	4	main
asja	doc_399014257237_item	2388903	et	4	main
esindades	doc_399014257237_item	2388904	et	3	main
ja	doc_399014257237_item	2388905	et	3	main
äratas	doc_399014257237_item	2388906	et	3	main
uudishimu	doc_399014257237_item	2388907	et	4	main
helsingi	doc_399014257237_item	2388908	et	4	main
linnlaste	doc_399014257237_item	2388909	et	4	main
hulgas	doc_399014257237_item	2388910	et	4	main
fotografeerimine	doc_399014257237_item	2388911	et	4	main
oli	doc_399014257237_item	2388912	et	3	main
veel	doc_399014257237_item	2388913	et	4	main
uus	doc_399014257237_item	2388914	et	3	main
ja	doc_399014257237_item	2388915	et	3	main
naine	doc_399014257237_item	2388916	et	3	main
maastikufotograafina	doc_399014257237_item	2388917	et	4	main
haruldane	doc_399014257237_item	2388918	et	3	main
nähtus	doc_399014257237_item	2388919	et	4	main
mõnikord	doc_399014257237_item	2388920	et	3	main
koer	doc_399014257237_item	2388928	et	3	main
hobune	doc_399014257237_item	2388935	et	4	main
raamatus	doc_399014257237_item	2388938	et	4	main
korraldadud	doc_399014257237_item	2388939	et	4	main
taguses	doc_399014257237_item	2388948	et	3	main
ja	doc_399014257237_item	2388955	et	3	main
kaudu	doc_399014257237_item	2388957	et	3	main
sealt	doc_399014257237_item	2388960	et	4	main
kampi	doc_399014257237_item	2388962	et	4	main
on	doc_399014257237_item	2388985	et	4	main
kohas	doc_399014257237_item	2388993	et	4	main
maakoht	doc_399014257237_item	2389003	et	3	main
ei	doc_399014257237_item	2389018	et	4	main
pakarinen	doc_399014257237_item	2389022	et	4	main
püsiva	doc_399014257237_item	2389058	et	4	main
jätkas	doc_399014257237_item	2389064	et	3	main
ta	doc_399014257237_item	2389070	et	4	main
tema	doc_399014257237_item	2389074	et	4	main
segases	doc_399014257237_item	2389113	et	3	main
nikkilä	doc_399014257237_item	2389116	et	4	main
aastal	doc_399014257237_item	2389118	et	3	main
helsingi	doc_399014257237_item	2389128	et	4	main
surnud	doc_399014257237_item	2388858	et	4	main
inimesed	doc_399014257237_item	2388860	et	3	main
detailid	doc_399014257237_item	2388862	et	3	main
olid	doc_399014257237_item	2388863	et	4	main
tema	doc_399014257237_item	2388864	et	4	main
fotode	doc_399014257237_item	2388865	et	3	main
peaaegu	doc_399014257237_item	2388871	et	3	main
palunud	doc_399014257237_item	2388890	et	4	main
hetkeks	doc_399014257237_item	2388891	et	4	main
pildistamiseks	doc_399014257237_item	2388893	et	4	main
brander	doc_399014257237_item	2388900	et	4	main
osav	doc_399014257237_item	2388901	et	3	main
sai	doc_399014257237_item	2388921	et	4	main
detailiks	doc_399014257237_item	2388923	et	4	main
mööda	doc_399014257237_item	2388924	et	4	main
trammi	doc_399014257237_item	2388925	et	4	main
rööpaid	doc_399014257237_item	2388926	et	3	main
piltid	doc_399014257237_item	2388936	et	4	main
liigub	doc_399014257237_item	2388943	et	3	main
jätkub	doc_399014257237_item	2388953	et	3	main
kruunuhaku	doc_399014257237_item	2388956	et	4	main
kõrval	doc_399014257237_item	2388967	et	4	main
suunas	doc_399014257237_item	2388980	et	4	main
kasvatasid	doc_399014257237_item	2389006	et	4	main
linnlastele	doc_399014257237_item	2389008	et	4	main
siiski	doc_399014257237_item	2389009	et	4	main
tekkisid	doc_399014257237_item	2389014	et	4	main
erimeelsused	doc_399014257237_item	2389015	et	4	main
aastal1913	doc_399014257237_item	2389016	et	3	main
põhjused	doc_399014257237_item	2389021	et	3	main
et	doc_399014257237_item	2389024	et	3	main
olevat	doc_399014257237_item	2389026	et	4	main
pildistamise	doc_399014257237_item	2389044	et	4	main
uuesti	doc_399014257237_item	2389050	et	3	main
alles	doc_399014257237_item	2389052	et	3	main
linnamuuseum	doc_399014257237_item	2389055	et	3	main
oma	doc_399014257237_item	2389065	et	4	main
ms	doc_399014257237_item	2389072	et	4	main
möisasid	doc_399014257237_item	2389073	et	4	main
tervis	doc_399014257237_item	2389075	et	3	main
ja	doc_399014257237_item	2389076	et	3	main
nägemine	doc_399014257237_item	2389077	et	4	main
sõja	doc_399014257237_item	2389112	et	3	main
1942	doc_399014257237_item	2389119	et	2	main
nende	doc_399014257237_item	2389125	et	4	main
koos	doc_399014257237_item	2389135	et	4	main
teiste	doc_399014257237_item	2389136	et	4	main
patsientidega	doc_399014257237_item	2389137	et	3	main
tuju	doc_399014257237_item	2388896	et	4	main
pikantseks	doc_399014257237_item	2388922	et	3	main
möödev	doc_399014257237_item	2388927	et	4	main
rakmedeta	doc_399014257237_item	2388933	et	4	main
niimoodi	doc_399014257237_item	2388940	et	3	main
et	doc_399014257237_item	2388941	et	3	main
lugeja	doc_399014257237_item	2388942	et	4	main
nagu	doc_399014257237_item	2388944	et	3	main
sõit	doc_399014257237_item	2388950	et	3	main
hakaniemi	doc_399014257237_item	2388954	et	4	main
linnaosadesse	doc_399014257237_item	2388959	et	3	main
edasi	doc_399014257237_item	2388961	et	3	main
kaudu	doc_399014257237_item	2388963	et	3	main
töölösse	doc_399014257237_item	2388964	et	3	main
iga	doc_399014257237_item	2388965	et	4	main
kus	doc_399014257237_item	2388973	et	3	main
vaatepilti	doc_399014257237_item	2388981	et	4	main
on	doc_399014257237_item	2388982	et	4	main
vaadatud	doc_399014257237_item	2388983	et	4	main
kaasaegsele	doc_399014257237_item	2388987	et	3	main
muutunud	doc_399014257237_item	2388996	et	4	main
esiteks	doc_399014257237_item	2388997	et	3	main
töölö	doc_399014257237_item	2388998	et	4	main
venelased	doc_399014257237_item	2389005	et	3	main
vahel	doc_399014257237_item	2389013	et	4	main
erimeelsuste	doc_399014257237_item	2389020	et	4	main
lihtsalt	doc_399014257237_item	2389028	et	4	main
pärast	doc_399014257237_item	2389030	et	4	main
linnamuuseum	doc_399014257237_item	2389031	et	3	main
võttis	doc_399014257237_item	2389032	et	3	main
tööle	doc_399014257237_item	2389033	et	3	main
uue	doc_399014257237_item	2389034	et	3	main
fotograafi	doc_399014257237_item	2389035	et	4	main
aastakümneteks	doc_399014257237_item	2389045	et	4	main
salvestus	doc_399014257237_item	2389048	et	4	main
hakkas	doc_399014257237_item	2389049	et	3	main
1950	doc_399014257237_item	2389053	et	2	main
alles	doc_399014257237_item	2389060	et	3	main
aastal	doc_399014257237_item	2389061	et	3	main
fotograafitööd	doc_399014257237_item	2389066	et	4	main
pool	doc_399014257237_item	2389068	et	4	main
rohkem	doc_399014257237_item	2389120	et	4	main
kui	doc_399014257237_item	2389121	et	3	main
hulkas	doc_399014257237_item	2389126	et	4	main
fotograaf	doc_399014257237_item	2389130	et	4	main
ühishauta	doc_399014257237_item	2389138	et	4	main
keskel	doc_399014257237_item	2388930	et	3	main
hoovi	doc_399014257237_item	2388931	et	4	main
ilma	doc_399014257237_item	2388932	et	4	main
uurimisretkel	doc_399014257237_item	2388945	et	4	main
saja	doc_399014257237_item	2388946	et	4	main
helsingis	doc_399014257237_item	2388949	et	4	main
hermannist	doc_399014257237_item	2388952	et	4	main
lõunapoolsetesse	doc_399014257237_item	2388958	et	4	main
on	doc_399014257237_item	2388968	et	4	main
täpne	doc_399014257237_item	2388969	et	3	main
originaalkaart	doc_399014257237_item	2388970	et	4	main
vajalik	doc_399014257237_item	2388986	et	3	main
sest	doc_399014257237_item	2388989	et	4	main
mitmes	doc_399014257237_item	2388992	et	4	main
oli	doc_399014257237_item	2388999	et	3	main
branderi	doc_399014257237_item	2389000	et	4	main
fotode	doc_399014257237_item	2389001	et	3	main
kus	doc_399014257237_item	2389004	et	3	main
köögivilja	doc_399014257237_item	2389007	et	4	main
branderi	doc_399014257237_item	2389010	et	4	main
ja	doc_399014257237_item	2389011	et	3	main
protokollist	doc_399014257237_item	2389017	et	4	main
seisev	doc_399014257237_item	2388934	et	4	main
on	doc_399014257237_item	2388937	et	4	main
aasta	doc_399014257237_item	2388947	et	4	main
algab	doc_399014257237_item	2388951	et	3	main
foto	doc_399014257237_item	2388966	et	4	main
mis	doc_399014257237_item	2388971	et	4	main
selgitab	doc_399014257237_item	2388972	et	3	main
kohas	doc_399014257237_item	2388974	et	4	main
pilt	doc_399014257237_item	2388975	et	3	main
on	doc_399014257237_item	2388976	et	4	main
tehtud	doc_399014257237_item	2388977	et	4	main
ja	doc_399014257237_item	2388978	et	3	main
mis	doc_399014257237_item	2388979	et	4	main
kaart	doc_399014257237_item	2388984	et	4	main
lugejale	doc_399014257237_item	2388988	et	4	main
linna	doc_399014257237_item	2388990	et	4	main
on	doc_399014257237_item	2388991	et	4	main
täiesti	doc_399014257237_item	2388994	et	3	main
tundmatuseni	doc_399014257237_item	2388995	et	4	main
ajal	doc_399014257237_item	2389002	et	4	main
komisjoni	doc_399014257237_item	2389012	et	4	main
selgu	doc_399014257237_item	2389019	et	4	main
arvab	doc_399014257237_item	2389023	et	3	main
tüli	doc_399014257237_item	2389025	et	4	main
asemele	doc_399014257237_item	2389037	et	4	main
aga	doc_399014257237_item	2389038	et	3	main
esimese	doc_399014257237_item	2389039	et	3	main
maailmasõda	doc_399014257237_item	2389040	et	4	main
aastal	doc_399014257237_item	2389041	et	3	main
1914	doc_399014257237_item	2389042	et	2	main
lopetas	doc_399014257237_item	2389043	et	4	main
aastatel	doc_399014257237_item	2389054	et	4	main
sai	doc_399014257237_item	2389056	et	4	main
oma	doc_399014257237_item	2389057	et	4	main
brander	doc_399014257237_item	2389063	et	4	main
mitmel	doc_399014257237_item	2389067	et	4	main
pildistas	doc_399014257237_item	2389071	et	3	main
aastadel	doc_399014257237_item	2389081	et	4	main
olukorras	doc_399014257237_item	2389114	et	3	main
juhtunud	doc_399014257237_item	2389027	et	4	main
raha	doc_399014257237_item	2389029	et	4	main
branderi	doc_399014257237_item	2389036	et	4	main
süstemaatiline	doc_399014257237_item	2389046	et	3	main
linnakeskkonna	doc_399014257237_item	2389047	et	3	main
toimuma	doc_399014257237_item	2389051	et	3	main
fotograafi	doc_399014257237_item	2389059	et	4	main
1981	doc_399014257237_item	2389062	et	2	main
soomes	doc_399014257237_item	2389069	et	4	main
läksid	doc_399014257237_item	2389078	et	4	main
nõrgenemaks	doc_399014257237_item	2389079	et	3	main
1930	doc_399014257237_item	2389080	et	2	main
glaukooma	doc_399014257237_item	2389082	et	4	main
tõttu	doc_399014257237_item	2389083	et	4	main
aastal	doc_399014257237_item	2389084	et	3	main
1941	doc_399014257237_item	2389085	et	2	main
sattus	doc_399014257237_item	2389086	et	3	main
brander	doc_399014257237_item	2389087	et	4	main
kivelä	doc_399014257237_item	2389088	et	4	main
haiglasse	doc_399014257237_item	2389089	et	4	main
kust	doc_399014257237_item	2389090	et	4	main
patsiendid	doc_399014257237_item	2389091	et	3	main
hiljem	doc_399014257237_item	2389092	et	3	main
sõja	doc_399014257237_item	2389093	et	3	main
tõttu	doc_399014257237_item	2389094	et	4	main
viidi	doc_399014257237_item	2389095	et	4	main
üle	doc_399014257237_item	2389096	et	3	main
nikkilä	doc_399014257237_item	2389097	et	4	main
vaimu	doc_399014257237_item	2389098	et	4	main
haiglasse	doc_399014257237_item	2389099	et	4	main
üle	doc_399014257237_item	2389100	et	3	main
viimine	doc_399014257237_item	2389101	et	4	main
ei	doc_399014257237_item	2389102	et	4	main
põhinenud	doc_399014257237_item	2389103	et	4	main
branderi	doc_399014257237_item	2389104	et	4	main
vaimsel	doc_399014257237_item	2389105	et	3	main
tervisel	doc_399014257237_item	2389106	et	3	main
kuigi	doc_399014257237_item	2389107	et	3	main
sedagi	doc_399014257237_item	2389108	et	3	main
on	doc_399014257237_item	2389109	et	4	main
mõnikord	doc_399014257237_item	2389110	et	3	main
väidetud	doc_399014257237_item	2389111	et	4	main
suri	doc_399014257237_item	2389115	et	3	main
haiglas	doc_399014257237_item	2389117	et	3	main
nälga	doc_399014257237_item	2389124	et	4	main
oli	doc_399014257237_item	2389127	et	3	main
signe	doc_399014257237_item	2389131	et	4	main
brander	doc_399014257237_item	2389132	et	4	main
sada	doc_399014257237_item	2389122	et	4	main
patsienti	doc_399014257237_item	2389123	et	4	main
legendaarne	doc_399014257237_item	2389129	et	3	main
kes	doc_399014257237_item	2389133	et	4	main
maeti	doc_399014257237_item	2389134	et	3	main
oli	doc_399014257241_item	2390025	et	3	main
enne	doc_399014257241_item	2390027	et	4	main
tähtaja	doc_399014257241_item	2390028	et	3	main
lõppu	doc_399014257241_item	2390029	et	4	main
esmaspäeval	doc_399014257241_item	2390030	et	3	main
vaid	doc_399014257241_item	2390031	et	3	main
kolm	doc_399014257241_item	2390032	et	3	main
pakkumist	doc_399014257241_item	2390033	et	4	main
kalevipoeg	doc_399014257241_item	2390034	et	3	main
meetri	doc_399014257241_item	2390039	et	3	main
rannast	doc_399014257241_item	2390041	et	4	main
pirita	doc_399014257241_item	2390042	et	4	main
vastaval	doc_399014257241_item	2390045	et	4	main
teise	doc_399014257241_item	2390052	et	4	main
obelisk	doc_399014257241_item	2390062	et	3	main
kujurite	doc_399014257241_item	2390067	et	3	main
juba	doc_399014257241_item	2390071	et	3	main
ühenduse	doc_399014257241_item	2390079	et	4	main
idee	doc_399014257241_item	2390080	et	4	main
ei	doc_399014257241_item	2390087	et	4	main
mälestuskompleksi	doc_399014257241_item	2390090	et	4	main
kõrvale	doc_399014257241_item	2390091	et	4	main
ametiühingud	doc_399014257241_item	2390099	et	3	main
oma	doc_399014257241_item	2390102	et	4	main
suure	doc_399014257241_item	2390109	et	3	main
osa	doc_399014257241_item	2390110	et	4	main
vastu	doc_399014257241_item	2390111	et	3	main
rattase	doc_399014257241_item	2390115	et	4	main
linna	doc_399014257241_item	2390128	et	4	main
kangro	doc_399014257241_item	2390139	et	4	main
lõpus	doc_399014257241_item	2390147	et	4	main
tallinnale	doc_399014257241_item	2390151	et	4	main
väike	doc_399014257241_item	2390160	et	4	main
merineitsi	doc_399014257241_item	2390161	et	4	main
oli	doc_399014257241_item	2390162	et	3	main
vaid	doc_399014257241_item	2390163	et	3	main
abilinnapea	doc_399014257241_item	2390190	et	4	main
sõtnik	doc_399014257241_item	2390192	et	4	main
sõnul	doc_399014257241_item	2390194	et	3	main
on	doc_399014257241_item	2390195	et	4	main
koht	doc_399014257241_item	2390196	et	3	main
pirita	doc_399014257241_item	2390202	et	4	main
ning	doc_399014257241_item	2390204	et	3	main
samas	doc_399014257241_item	2390209	et	4	main
tauno	doc_399014257241_item	2390215	et	4	main
kangro	doc_399014257241_item	2390216	et	4	main
vanalinna	doc_399014257241_item	2390217	et	4	main
galeriis	doc_399014257241_item	2390218	et	3	main
oli	doc_399014257241_item	2390219	et	3	main
kunstnik	doc_399014257241_item	2390224	et	3	main
esitles	doc_399014257241_item	2390233	et	3	main
mõned	doc_399014257241_item	2390257	et	3	main
konkurssile	doc_399014257241_item	2390024	et	4	main
jäetud	doc_399014257241_item	2390026	et	4	main
saja	doc_399014257241_item	2390038	et	4	main
äärde	doc_399014257241_item	2390044	et	4	main
näha	doc_399014257241_item	2390059	et	3	main
merele	doc_399014257241_item	2390060	et	3	main
linna	doc_399014257241_item	2390065	et	4	main
tüli	doc_399014257241_item	2390069	et	4	main
skulptorite	doc_399014257241_item	2390078	et	3	main
ja	doc_399014257241_item	2390084	et	3	main
rahvuseepose	doc_399014257241_item	2390085	et	3	main
ka	doc_399014257241_item	2390097	et	3	main
liiga	doc_399014257241_item	2390108	et	4	main
jüri	doc_399014257241_item	2390114	et	4	main
järgi	doc_399014257241_item	2390021	et	4	main
korraldatud	doc_399014257241_item	2390023	et	4	main
merre	doc_399014257241_item	2390037	et	3	main
kaugusele	doc_399014257241_item	2390040	et	4	main
tee	doc_399014257241_item	2390043	et	4	main
nõukogude	doc_399014257241_item	2390050	et	3	main
kangelastele	doc_399014257241_item	2390054	et	4	main
püstitatud	doc_399014257241_item	2390055	et	4	main
mälestuskompleks	doc_399014257241_item	2390056	et	3	main
on	doc_399014257241_item	2390058	et	4	main
kõrge	doc_399014257241_item	2390061	et	4	main
eesti	doc_399014257241_item	2390077	et	4	main
juba	doc_399014257241_item	2390082	et	3	main
varem	doc_399014257241_item	2390092	et	4	main
sügisel	doc_399014257241_item	2390093	et	3	main
kutsus	doc_399014257241_item	2390100	et	4	main
esindajad	doc_399014257241_item	2390103	et	4	main
žüriist	doc_399014257241_item	2390104	et	2	main
et	doc_399014257241_item	2390105	et	3	main
protesteerida	doc_399014257241_item	2390106	et	3	main
züriis	doc_399014257241_item	2390112	et	4	main
planeerinud	doc_399014257241_item	2390127	et	4	main
isaks	doc_399014257241_item	2390132	et	3	main
siiski	doc_399014257241_item	2390134	et	4	main
kes	doc_399014257241_item	2390141	et	4	main
alustas	doc_399014257241_item	2390142	et	3	main
kalevipoja	doc_399014257241_item	2390143	et	4	main
idee	doc_399014257241_item	2390148	et	4	main
plaanis	doc_399014257241_item	2390158	et	4	main
aga	doc_399014257241_item	2390165	et	3	main
torkaks	doc_399014257241_item	2390187	et	3	main
kuna	doc_399014257241_item	2390198	et	3	main
jääb	doc_399014257241_item	2390199	et	3	main
botaanikaaeda	doc_399014257241_item	2390207	et	4	main
kuju	doc_399014257241_item	2390210	et	4	main
varja	doc_399014257241_item	2390212	et	4	main
esmaspäevalgi	doc_399014257241_item	2390221	et	4	main
mägila	doc_399014257241_item	2390232	et	4	main
pärast	doc_399014257241_item	2390246	et	4	main
maailmareisi	doc_399014257241_item	2390247	et	4	main
kunstniku	doc_399014257241_item	2390248	et	3	main
nägemuse	doc_399014257241_item	2390249	et	3	main
järgi	doc_399014257241_item	2390250	et	4	main
on	doc_399014257241_item	2390251	et	4	main
kangelase	doc_399014257241_item	2390252	et	3	main
kätel	doc_399014257241_item	2390253	et	3	main
figuurid	doc_399014257241_item	2390258	et	3	main
mis	doc_399014257241_item	2390259	et	4	main
kojutulekut	doc_399014257241_item	2390262	et	3	main
lisaks	doc_399014257241_item	2390263	et	4	main
skulptorite	doc_399014257241_item	2390264	et	3	main
mõjukas	doc_399014257241_item	2390269	et	4	main
vastu	doc_399014257241_item	2390294	et	3	main
suhtes	doc_399014257241_item	2390299	et	4	main
tutvustanud	doc_399014257241_item	2390306	et	4	main
tõlge	doc_399014257241_item	2389991	et	3	main
kunstnike	doc_399014257241_item	2389992	et	3	main
liidud	doc_399014257241_item	2389993	et	3	main
vaatavad	doc_399014257241_item	2389994	et	4	main
viltu	doc_399014257241_item	2389995	et	3	main
tallinna	doc_399014257241_item	2389996	et	4	main
lahte	doc_399014257241_item	2389997	et	4	main
kavandatud	doc_399014257241_item	2389998	et	4	main
hiiglaslikule	doc_399014257241_item	2389999	et	3	main
kalevipoja	doc_399014257241_item	2390000	et	4	main
kujule	doc_399014257241_item	2390001	et	3	main
eesti	doc_399014257241_item	2390002	et	4	main
kunstnikud	doc_399014257241_item	2390003	et	3	main
vaatavad	doc_399014257241_item	2390004	et	4	main
viltu	doc_399014257241_item	2390005	et	3	main
tallinna	doc_399014257241_item	2390006	et	4	main
linna	doc_399014257241_item	2390007	et	4	main
kavale	doc_399014257241_item	2390008	et	3	main
püstitada	doc_399014257241_item	2390009	et	3	main
tallinna	doc_399014257241_item	2390010	et	4	main
lahte	doc_399014257241_item	2390011	et	4	main
mitmekorruselise	doc_399014257241_item	2390012	et	4	main
maja	doc_399014257241_item	2390013	et	4	main
suurune	doc_399014257241_item	2390014	et	4	main
kõrge	doc_399014257241_item	2390015	et	4	main
kalevipoeg	doc_399014257241_item	2390016	et	3	main
eesti	doc_399014257241_item	2390017	et	4	main
samanimelise	doc_399014257241_item	2390018	et	4	main
rahvuseepose	doc_399014257241_item	2390019	et	3	main
kangelase	doc_399014257241_item	2390020	et	3	main
püstitada	doc_399014257241_item	2390036	et	3	main
rannas	doc_399014257241_item	2390047	et	3	main
seisab	doc_399014257241_item	2390048	et	3	main
millest	doc_399014257241_item	2390057	et	3	main
rannatrepp	doc_399014257241_item	2390064	et	3	main
asukohast	doc_399014257241_item	2390075	et	4	main
linna	doc_399014257241_item	2390022	et	4	main
kavatsetakse	doc_399014257241_item	2390035	et	3	main
kohal	doc_399014257241_item	2390046	et	4	main
ka	doc_399014257241_item	2390049	et	3	main
ajal	doc_399014257241_item	2390051	et	4	main
maailmasõja	doc_399014257241_item	2390053	et	3	main
ning	doc_399014257241_item	2390063	et	3	main
ja	doc_399014257241_item	2390066	et	3	main
ühenduse	doc_399014257241_item	2390068	et	4	main
algas	doc_399014257241_item	2390070	et	3	main
kuju	doc_399014257241_item	2390072	et	4	main
suurusest	doc_399014257241_item	2390073	et	4	main
ja	doc_399014257241_item	2390074	et	3	main
aegunud	doc_399014257241_item	2390083	et	4	main
nii	doc_399014257241_item	2390094	et	3	main
kui	doc_399014257241_item	2390096	et	3	main
arhitektide	doc_399014257241_item	2390098	et	3	main
32	doc_399014257241_item	2390116	et	2	main
juhatatud	doc_399014257241_item	2390117	et	4	main
žürii	doc_399014257241_item	2390118	et	2	main
ainus	doc_399014257241_item	2390119	et	4	main
sõltumatu	doc_399014257241_item	2390120	et	4	main
kunstnikust	doc_399014257241_item	2390121	et	3	main
on	doc_399014257241_item	2390123	et	4	main
maastikuarhitekt	doc_399014257241_item	2390124	et	3	main
kes	doc_399014257241_item	2390125	et	4	main
on	doc_399014257241_item	2390126	et	4	main
algupärase	doc_399014257241_item	2390130	et	4	main
40	doc_399014257241_item	2390140	et	2	main
luua	doc_399014257241_item	2390150	et	4	main
tallinna	doc_399014257241_item	2390159	et	4	main
silma	doc_399014257241_item	2390188	et	4	main
teele	doc_399014257241_item	2390201	et	3	main
tallinna	doc_399014257241_item	2390206	et	4	main
vaimustust	doc_399014257241_item	2390223	et	4	main
ei	doc_399014257241_item	2390226	et	4	main
paati	doc_399014257241_item	2390241	et	4	main
kuju	doc_399014257241_item	2390242	et	4	main
sümboliseerib	doc_399014257241_item	2390243	et	3	main
kangelase	doc_399014257241_item	2390244	et	3	main
kojujõudmist	doc_399014257241_item	2390245	et	3	main
veel	doc_399014257241_item	2390254	et	4	main
projekti	doc_399014257241_item	2390267	et	4	main
meeldumust	doc_399014257241_item	2390292	et	4	main
kõrghoonete	doc_399014257241_item	2390293	et	4	main
kriitikat	doc_399014257241_item	2390311	et	3	main
vaenlasi	doc_399014257241_item	2390321	et	3	main
kividega	doc_399014257241_item	2390323	et	3	main
kes	doc_399014257241_item	2390325	et	4	main
on	doc_399014257241_item	2390331	et	4	main
sobiv	doc_399014257241_item	2390338	et	4	main
konkurssil	doc_399014257241_item	2390349	et	4	main
näitus	doc_399014257241_item	2390353	et	3	main
sõtniku	doc_399014257241_item	2390355	et	4	main
sõnul	doc_399014257241_item	2390356	et	3	main
on	doc_399014257241_item	2390357	et	4	main
kuju	doc_399014257241_item	2390358	et	4	main
kavas	doc_399014257241_item	2390359	et	3	main
püstitada	doc_399014257241_item	2390360	et	3	main
järgmise	doc_399014257241_item	2390361	et	3	main
ja	doc_399014257241_item	2390362	et	3	main
helsingi	doc_399014257241_item	2390368	et	4	main
saadi	doc_399014257242_item	2390428	et	4	main
koostöö	doc_399014257242_item	2390431	et	4	main
terves	doc_399014257242_item	2390440	et	4	main
põhja	doc_399014257242_item	2390442	et	4	main
osavõtjateks	doc_399014257242_item	2390444	et	3	main
norra	doc_399014257242_item	2390451	et	4	main
ja	doc_399014257242_item	2390452	et	3	main
islandi	doc_399014257242_item	2390453	et	4	main
usa	doc_399014257242_item	2390456	et	4	main
vaadlejariigid	doc_399014257242_item	2390459	et	4	main
regionaalnõukogud	doc_399014257242_item	2390465	et	3	main
ministrinõukogu	doc_399014257242_item	2390475	et	4	main
põhjamaade	doc_399014257242_item	2390476	et	3	main
põhja	doc_399014257242_item	2390519	et	4	main
on	doc_399014257242_item	2390521	et	4	main
meres	doc_399014257241_item	2390076	et	3	main
on	doc_399014257241_item	2390081	et	4	main
kangelane	doc_399014257241_item	2390086	et	3	main
sobi	doc_399014257241_item	2390088	et	4	main
nõukoguaegse	doc_399014257241_item	2390089	et	3	main
skulptorite	doc_399014257241_item	2390095	et	3	main
tagasi	doc_399014257241_item	2390101	et	3	main
ametnikute	doc_399014257241_item	2390107	et	4	main
linnapea	doc_399014257241_item	2390113	et	4	main
idee	doc_399014257241_item	2390131	et	4	main
on	doc_399014257241_item	2390133	et	4	main
kunstnik	doc_399014257241_item	2390135	et	3	main
vaidlusalune	doc_399014257241_item	2390136	et	4	main
skulptor	doc_399014257241_item	2390137	et	3	main
projekti	doc_399014257241_item	2390144	et	4	main
juba	doc_399014257241_item	2390145	et	3	main
oli	doc_399014257241_item	2390149	et	3	main
kopenhaageni	doc_399014257241_item	2390152	et	4	main
merineitsi	doc_399014257241_item	2390154	et	4	main
sarnane	doc_399014257241_item	2390155	et	4	main
sümbol	doc_399014257241_item	2390156	et	3	main
esialgses	doc_399014257241_item	2390157	et	3	main
kõrgune	doc_399014257241_item	2390164	et	4	main
põhjendab	doc_399014257241_item	2390189	et	3	main
olga	doc_399014257241_item	2390191	et	4	main
sõtniku	doc_399014257241_item	2390193	et	4	main
turistite	doc_399014257241_item	2390200	et	4	main
ka	doc_399014257241_item	2390205	et	3	main
sõites	doc_399014257241_item	2390208	et	3	main
ei	doc_399014257241_item	2390211	et	4	main
vanalinna	doc_399014257241_item	2390213	et	4	main
veel	doc_399014257241_item	2390220	et	4	main
liige	doc_399014257241_item	2390122	et	4	main
parke	doc_399014257241_item	2390129	et	3	main
tauno	doc_399014257241_item	2390138	et	4	main
1990ndate	doc_399014257241_item	2390146	et	4	main
väikse	doc_399014257241_item	2390153	et	4	main
linnavalitsuse	doc_399014257241_item	2390166	et	3	main
ettepaneku	doc_399014257241_item	2390167	et	3	main
järgi	doc_399014257241_item	2390168	et	4	main
lisati	doc_399014257241_item	2390169	et	3	main
sellele	doc_399014257241_item	2390170	et	4	main
vaatasime	doc_399014257241_item	2390172	et	3	main
kuidas	doc_399014257241_item	2390173	et	3	main
kuju	doc_399014257241_item	2390174	et	4	main
sobib	doc_399014257241_item	2390175	et	3	main
kõrgust	doc_399014257241_item	2390171	et	4	main
kokku	doc_399014257241_item	2390176	et	3	main
maarjamäe	doc_399014257241_item	2390177	et	3	main
mälestuskompleksiga	doc_399014257241_item	2390178	et	4	main
tegime	doc_399014257241_item	2390179	et	3	main
arvestusi	doc_399014257241_item	2390180	et	4	main
ning	doc_399014257241_item	2390181	et	3	main
visualiseerisime	doc_399014257241_item	2390182	et	4	main
selle	doc_399014257241_item	2390183	et	4	main
otsustasime	doc_399014257241_item	2390184	et	3	main
kasuks	doc_399014257241_item	2390185	et	4	main
see	doc_399014257241_item	2390186	et	3	main
parim	doc_399014257241_item	2390197	et	4	main
spasse	doc_399014257241_item	2390203	et	4	main
siluetti	doc_399014257241_item	2390214	et	4	main
ise	doc_399014257241_item	2390225	et	4	main
olnud	doc_399014257241_item	2390227	et	4	main
linnas	doc_399014257241_item	2390228	et	4	main
aga	doc_399014257241_item	2390229	et	3	main
galerist	doc_399014257241_item	2390230	et	4	main
pille	doc_399014257241_item	2390231	et	3	main
kannab	doc_399014257241_item	2390240	et	3	main
ja	doc_399014257241_item	2390256	et	3	main
sümboliseerivad	doc_399014257241_item	2390260	et	4	main
eestlaste	doc_399014257241_item	2390261	et	4	main
ka	doc_399014257241_item	2390268	et	3	main
seda	doc_399014257241_item	2390302	et	3	main
ideed	doc_399014257241_item	2390304	et	4	main
on	doc_399014257241_item	2390312	et	4	main
kes	doc_399014257241_item	2390317	et	4	main
aga	doc_399014257241_item	2390324	et	3	main
tunda	doc_399014257241_item	2390222	et	3	main
innukalt	doc_399014257241_item	2390234	et	4	main
pronkskuju	doc_399014257241_item	2390235	et	4	main
kus	doc_399014257241_item	2390236	et	3	main
suurte	doc_399014257241_item	2390237	et	3	main
pihkudega	doc_399014257241_item	2390238	et	3	main
kalevipoeg	doc_399014257241_item	2390239	et	3	main
paat	doc_399014257241_item	2390255	et	3	main
arhitektide	doc_399014257241_item	2390270	et	3	main
liit	doc_399014257241_item	2390271	et	3	main
kes	doc_399014257241_item	2390272	et	4	main
tülitseb	doc_399014257241_item	2390273	et	3	main
linnaga	doc_399014257241_item	2390274	et	3	main
ka	doc_399014257241_item	2390275	et	3	main
muuhulgas	doc_399014257241_item	2390276	et	3	main
uue	doc_399014257241_item	2390277	et	3	main
linnavalitsushoone	doc_399014257241_item	2390278	et	4	main
asukoha	doc_399014257241_item	2390279	et	4	main
pärast	doc_399014257241_item	2390280	et	4	main
tallinnas	doc_399014257241_item	2390281	et	4	main
valitseb	doc_399014257241_item	2390282	et	3	main
ainsana	doc_399014257241_item	2390283	et	3	main
erakonnana	doc_399014257241_item	2390284	et	4	main
keskerakond	doc_399014257241_item	2390285	et	3	main
kes	doc_399014257241_item	2390286	et	4	main
on	doc_399014257241_item	2390287	et	4	main
ka	doc_399014257241_item	2390288	et	3	main
varem	doc_399014257241_item	2390289	et	4	main
oma	doc_399014257241_item	2390291	et	4	main
osutanud	doc_399014257241_item	2390290	et	4	main
ühendusele	doc_399014257241_item	2390265	et	4	main
boikoteerib	doc_399014257241_item	2390266	et	3	main
kunstnike	doc_399014257241_item	2390296	et	3	main
kasvas	doc_399014257241_item	2390300	et	3	main
keskerakonda	doc_399014257241_item	2390310	et	4	main
legendi	doc_399014257241_item	2390318	et	4	main
järgi	doc_399014257241_item	2390319	et	4	main
kas	doc_399014257241_item	2390335	et	3	main
osalenud	doc_399014257241_item	2390350	et	4	main
abilinnapea	doc_399014257241_item	2390354	et	4	main
ka	doc_399014257241_item	2390367	et	3	main
tõlge	doc_399014257242_item	2390372	et	3	main
mõõdet	doc_399014257242_item	2390374	et	4	main
ka	doc_399014257242_item	2390377	et	3	main
paremad	doc_399014257242_item	2390383	et	4	main
omavahel	doc_399014257242_item	2390420	et	3	main
kasu	doc_399014257242_item	2390427	et	4	main
heaolu	doc_399014257242_item	2390436	et	4	main
ja	doc_399014257242_item	2390437	et	3	main
stabiilsuse	doc_399014257242_item	2390438	et	4	main
lisamiseks	doc_399014257242_item	2390439	et	4	main
mõõtme	doc_399014257242_item	2390443	et	3	main
eli	doc_399014257242_item	2390446	et	4	main
on	doc_399014257242_item	2390463	et	4	main
põhja	doc_399014257242_item	2390464	et	4	main
rahvusvahelised	doc_399014257242_item	2390479	et	4	main
põhja	doc_399014257242_item	2390481	et	4	main
kirde-euroopa	doc_399014257242_item	2390515	et	4	main
poole	doc_399014257242_item	2390516	et	4	main
ülejäänud	doc_399014257241_item	2390295	et	4	main
kriitika	doc_399014257241_item	2390297	et	4	main
projekti	doc_399014257241_item	2390298	et	4	main
pärast	doc_399014257241_item	2390301	et	4	main
kui	doc_399014257241_item	2390303	et	3	main
kaua	doc_399014257241_item	2390305	et	3	main
palvinud	doc_399014257241_item	2390313	et	4	main
ka	doc_399014257241_item	2390314	et	3	main
kalevipoeg	doc_399014257241_item	2390315	et	3	main
on	doc_399014257241_item	2390326	et	4	main
süüdi	doc_399014257241_item	2390327	et	4	main
ka	doc_399014257241_item	2390328	et	3	main
selle	doc_399014257241_item	2390333	et	4	main
üle	doc_399014257241_item	2390334	et	3	main
avaldatakse	doc_399014257241_item	2390344	et	3	main
jaanuari	doc_399014257241_item	2390345	et	4	main
lõpus	doc_399014257241_item	2390346	et	4	main
töödest	doc_399014257241_item	2390351	et	3	main
kas	doc_399014257241_item	2390366	et	3	main
oma	doc_399014257241_item	2390370	et	4	main
kangro	doc_399014257241_item	2390307	et	4	main
astus	doc_399014257241_item	2390308	et	3	main
suvel	doc_399014257241_item	2390309	et	3	main
ise	doc_399014257241_item	2390316	et	4	main
loopis	doc_399014257241_item	2390320	et	3	main
vägistamises	doc_399014257241_item	2390330	et	4	main
arutletud	doc_399014257241_item	2390332	et	4	main
sümbol	doc_399014257241_item	2390339	et	3	main
merre	doc_399014257241_item	2390340	et	3	main
kalevipoja	doc_399014257241_item	2390341	et	4	main
võistluse	doc_399014257241_item	2390342	et	3	main
tulemused	doc_399014257241_item	2390343	et	3	main
pärast	doc_399014257241_item	2390348	et	4	main
korraldatakse	doc_399014257241_item	2390352	et	3	main
aasta	doc_399014257241_item	2390364	et	4	main
põhja	doc_399014257242_item	2390373	et	4	main
läheb	doc_399014257242_item	2390375	et	3	main
tulevikus	doc_399014257242_item	2390378	et	4	main
venemaa	doc_399014257242_item	2390379	et	4	main
kaasatulek	doc_399014257242_item	2390380	et	3	main
loob	doc_399014257242_item	2390381	et	3	main
põhjust	doc_399014257242_item	2390418	et	4	main
teha	doc_399014257242_item	2390419	et	3	main
ja	doc_399014257242_item	2390422	et	3	main
saaksid	doc_399014257242_item	2390425	et	4	main
tugevdamine	doc_399014257242_item	2390432	et	4	main
on	doc_399014257242_item	2390433	et	4	main
paras	doc_399014257242_item	2390434	et	3	main
viis	doc_399014257242_item	2390435	et	4	main
kirde-euroopas	doc_399014257242_item	2390441	et	3	main
on	doc_399014257242_item	2390445	et	4	main
liikmesriigid	doc_399014257242_item	2390447	et	3	main
ja	doc_399014257242_item	2390448	et	3	main
komisjon	doc_399014257242_item	2390449	et	3	main
venemaa	doc_399014257242_item	2390450	et	4	main
ja	doc_399014257242_item	2390457	et	3	main
kanada	doc_399014257242_item	2390458	et	4	main
teisi	doc_399014257242_item	2390460	et	4	main
tähtsaid	doc_399014257242_item	2390461	et	3	main
tegutsejaid	doc_399014257242_item	2390462	et	4	main
läänemere	doc_399014257242_item	2390466	et	3	main
artika	doc_399014257242_item	2390469	et	4	main
barentsi	doc_399014257242_item	2390471	et	4	main
euroarktiline	doc_399014257242_item	2390472	et	3	main
ning	doc_399014257242_item	2390478	et	3	main
kõrgemal	doc_399014257242_item	2390517	et	4	main
tasandil	doc_399014257242_item	2390518	et	3	main
mõiste	doc_399014257242_item	2390522	et	4	main
kõnedes	doc_399014257242_item	2390526	et	3	main
finantsallikate	doc_399014257242_item	2390532	et	3	main
on	doc_399014257242_item	2390548	et	4	main
aastal	doc_399014257242_item	2390561	et	3	main
ja	doc_399014257242_item	2390563	et	3	main
ja	doc_399014257242_item	2390565	et	3	main
aastal	doc_399014257242_item	2390567	et	3	main
lisatakse	doc_399014257242_item	2390597	et	4	main
miljardi	doc_399014257242_item	2390607	et	3	main
summaga	doc_399014257242_item	2390611	et	4	main
meie	doc_399014257242_item	2390614	et	4	main
niimoodi	doc_399014257242_item	2390630	et	3	main
ja	doc_399014257242_item	2390644	et	3	main
kanada	doc_399014257242_item	2390645	et	4	main
on	doc_399014257242_item	2390646	et	4	main
ei	doc_399014257242_item	2390652	et	4	main
peterburi	doc_399014257242_item	2390676	et	4	main
sügisel	doc_399014257242_item	2390682	et	3	main
sellele	doc_399014257242_item	2390684	et	4	main
esimesele	doc_399014257242_item	2390685	et	3	main
projektile	doc_399014257242_item	2390686	et	3	main
on	doc_399014257242_item	2390687	et	4	main
läänemere	doc_399014257242_item	2390688	et	3	main
ka	doc_399014257242_item	2390692	et	3	main
paet	doc_399014257243_item	2390733	et	4	main
mõõde	doc_399014257243_item	2390739	et	4	main
on	doc_399014257243_item	2390754	et	4	main
saadi	doc_399014257243_item	2390765	et	4	main
islandi	doc_399014257243_item	2390790	et	4	main
on	doc_399014257243_item	2390791	et	4	main
partnerriigid	doc_399014257243_item	2390792	et	3	main
usa	doc_399014257243_item	2390793	et	4	main
teisi	doc_399014257243_item	2390797	et	4	main
suurte	doc_399014257241_item	2390322	et	3	main
neiu	doc_399014257241_item	2390329	et	4	main
ta	doc_399014257241_item	2390336	et	4	main
on	doc_399014257241_item	2390337	et	4	main
ja	doc_399014257241_item	2390347	et	3	main
ülejärgmise	doc_399014257241_item	2390363	et	3	main
jooksul	doc_399014257241_item	2390365	et	4	main
vaja	doc_399014257241_item	2390369	et	4	main
hiigelkuju	doc_399014257241_item	2390371	et	4	main
vaja	doc_399014257242_item	2390376	et	4	main
endisest	doc_399014257242_item	2390382	et	3	main
eeldused	doc_399014257242_item	2390384	et	4	main
põhja	doc_399014257242_item	2390385	et	4	main
mõõtme	doc_399014257242_item	2390386	et	3	main
teostusele	doc_399014257242_item	2390387	et	4	main
soome	doc_399014257242_item	2390388	et	3	main
ja	doc_399014257242_item	2390389	et	3	main
on	doc_399014257242_item	2390391	et	4	main
eesti	doc_399014257242_item	2390390	et	4	main
selles	doc_399014257242_item	2390392	et	4	main
töös	doc_399014257242_item	2390393	et	3	main
teenäitajateks	doc_399014257242_item	2390394	et	3	main
urmas	doc_399014257242_item	2390395	et	3	main
paet	doc_399014257242_item	2390396	et	4	main
ja	doc_399014257242_item	2390397	et	3	main
erkki	doc_399014257242_item	2390398	et	3	main
tuomioja	doc_399014257242_item	2390399	et	4	main
kirjutavad	doc_399014257242_item	2390400	et	4	main
põhja	doc_399014257242_item	2390401	et	4	main
mõõde	doc_399014257242_item	2390402	et	4	main
sai	doc_399014257242_item	2390403	et	4	main
eli	doc_399014257242_item	2390404	et	4	main
välispoliitika	doc_399014257242_item	2390405	et	4	main
osaks	doc_399014257242_item	2390406	et	3	main
1999	doc_399014257242_item	2390408	et	2	main
aastal	doc_399014257242_item	2390407	et	3	main
taustal	doc_399014257242_item	2390409	et	3	main
oli	doc_399014257242_item	2390410	et	3	main
idee	doc_399014257242_item	2390411	et	4	main
sellest	doc_399014257242_item	2390412	et	4	main
et	doc_399014257242_item	2390413	et	3	main
elil	doc_399014257242_item	2390414	et	4	main
ja	doc_399014257242_item	2390415	et	3	main
loode-venemaal	doc_399014257242_item	2390416	et	4	main
on	doc_399014257242_item	2390417	et	4	main
mõlemad	doc_399014257242_item	2390424	et	3	main
aru	doc_399014257242_item	2390429	et	4	main
et	doc_399014257242_item	2390430	et	3	main
on	doc_399014257242_item	2390454	et	4	main
partnerriigid	doc_399014257242_item	2390455	et	3	main
nõukogu	doc_399014257242_item	2390468	et	4	main
nõukogu	doc_399014257242_item	2390470	et	4	main
nõukogu	doc_399014257242_item	2390473	et	4	main
balti	doc_399014257242_item	2390474	et	3	main
finantsorganisatsioonid	doc_399014257242_item	2390480	et	3	main
mõõtme	doc_399014257242_item	2390482	et	3	main
programmi	doc_399014257242_item	2390483	et	4	main
peapiirkondi	doc_399014257242_item	2390484	et	4	main
on	doc_399014257242_item	2390485	et	4	main
majandus	doc_399014257242_item	2390486	et	4	main
inimkapital	doc_399014257242_item	2390487	et	3	main
sh	doc_399014257242_item	2390488	et	4	main
tervise-	doc_399014257242_item	2390489	et	3	main
ja	doc_399014257242_item	2390490	et	3	main
sotsiaalküsimused	doc_399014257242_item	2390491	et	3	main
keskkonna-	doc_399014257242_item	2390492	et	3	main
ja	doc_399014257242_item	2390493	et	3	main
piiriülene	doc_399014257242_item	2390495	et	3	main
tuumaturvaküsimused	doc_399014257242_item	2390494	et	3	main
ja	doc_399014257242_item	2390496	et	3	main
regionaalne	doc_399014257242_item	2390497	et	3	main
koostöö	doc_399014257242_item	2390498	et	4	main
ning	doc_399014257242_item	2390499	et	3	main
õigus-	doc_399014257242_item	2390500	et	4	main
ja	doc_399014257242_item	2390501	et	3	main
siseküsimused	doc_399014257242_item	2390502	et	3	main
kõrgemal	doc_399014257242_item	2390503	et	4	main
tasandil	doc_399014257242_item	2390504	et	3	main
põhja	doc_399014257242_item	2390505	et	4	main
mõõde	doc_399014257242_item	2390506	et	4	main
on	doc_399014257242_item	2390507	et	4	main
poliitika	doc_399014257242_item	2390508	et	4	main
mille	doc_399014257242_item	2390509	et	3	main
abil	doc_399014257242_item	2390510	et	4	main
eli	doc_399014257242_item	2390511	et	4	main
tähelepanu	doc_399014257242_item	2390512	et	4	main
koostööd	doc_399014257242_item	2390421	et	4	main
et	doc_399014257242_item	2390423	et	3	main
sellest	doc_399014257242_item	2390426	et	4	main
riikide	doc_399014257242_item	2390467	et	3	main
ministrinõukogu	doc_399014257242_item	2390477	et	4	main
on	doc_399014257242_item	2390513	et	4	main
mõõde	doc_399014257242_item	2390520	et	4	main
on	doc_399014257242_item	2390528	et	4	main
hädavajalik	doc_399014257242_item	2390530	et	3	main
mõõtmel	doc_399014257242_item	2390535	et	3	main
siiski	doc_399014257242_item	2390537	et	4	main
ole	doc_399014257242_item	2390538	et	4	main
ka	doc_399014257242_item	2390544	et	3	main
viisi	doc_399014257242_item	2390558	et	4	main
keskkonnapartnerlus	doc_399014257242_item	2390559	et	3	main
asutati	doc_399014257242_item	2390560	et	4	main
2001	doc_399014257242_item	2390562	et	2	main
sotsiaal-	doc_399014257242_item	2390564	et	4	main
eesmärgiks	doc_399014257242_item	2390570	et	3	main
2	doc_399014257242_item	2390606	et	2	main
nii	doc_399014257242_item	2390609	et	3	main
soomele	doc_399014257242_item	2390622	et	4	main
ja	doc_399014257242_item	2390625	et	3	main
finantseeritakse	doc_399014257242_item	2390629	et	3	main
fondist	doc_399014257242_item	2390635	et	3	main
kuhu	doc_399014257242_item	2390636	et	3	main
peaosa	doc_399014257242_item	2390649	et	4	main
projektide	doc_399014257242_item	2390650	et	3	main
finantsrahast	doc_399014257242_item	2390651	et	4	main
ole	doc_399014257242_item	2390653	et	4	main
vaid	doc_399014257242_item	2390656	et	3	main
laen	doc_399014257242_item	2390658	et	4	main
võetakse	doc_399014257242_item	2390659	et	3	main
rahvusvahelistelt	doc_399014257242_item	2390660	et	4	main
finantsorganisatsioonidelt	doc_399014257242_item	2390661	et	3	main
ja	doc_399014257242_item	2390662	et	3	main
laenu	doc_399014257242_item	2390663	et	4	main
kasutavad	doc_399014257242_item	2390664	et	4	main
poolsed	doc_399014257242_item	2390666	et	3	main
partnerid	doc_399014257242_item	2390667	et	3	main
nagu	doc_399014257242_item	2390668	et	3	main
kohalikud	doc_399014257242_item	2390669	et	3	main
firmad	doc_399014257242_item	2390670	et	3	main
ja	doc_399014257242_item	2390671	et	3	main
esimene	doc_399014257242_item	2390674	et	3	main
on	doc_399014257242_item	2390679	et	4	main
sellel	doc_399014257242_item	2390681	et	4	main
ja	doc_399014257243_item	2390734	et	3	main
kirjutavad	doc_399014257243_item	2390737	et	4	main
eli	doc_399014257243_item	2390741	et	4	main
1999	doc_399014257243_item	2390745	et	2	main
ja	doc_399014257243_item	2390752	et	3	main
et	doc_399014257243_item	2390760	et	3	main
aru	doc_399014257243_item	2390766	et	4	main
et	doc_399014257243_item	2390767	et	3	main
eli	doc_399014257243_item	2390783	et	4	main
komisjon	doc_399014257243_item	2390786	et	3	main
ja	doc_399014257243_item	2390794	et	3	main
tegutsejaid	doc_399014257243_item	2390799	et	4	main
on	doc_399014257243_item	2390800	et	4	main
põhja	doc_399014257243_item	2390801	et	4	main
regionaalnõukogud	doc_399014257243_item	2390802	et	3	main
läänemere	doc_399014257243_item	2390803	et	3	main
riikide	doc_399014257243_item	2390804	et	3	main
nõukogu	doc_399014257243_item	2390810	et	4	main
balti	doc_399014257243_item	2390811	et	3	main
ja	doc_399014257243_item	2390830	et	3	main
ja	doc_399014257243_item	2390838	et	3	main
tasandil	doc_399014257243_item	2390841	et	3	main
on	doc_399014257243_item	2390844	et	4	main
poliitika	doc_399014257243_item	2390845	et	4	main
mille	doc_399014257243_item	2390846	et	3	main
pööratud	doc_399014257243_item	2390851	et	4	main
mõõde	doc_399014257243_item	2390857	et	4	main
mõiste	doc_399014257243_item	2390859	et	4	main
esineb	doc_399014257243_item	2390861	et	3	main
on	doc_399014257243_item	2390865	et	4	main
põhja	doc_399014257243_item	2390871	et	4	main
ole	doc_399014257243_item	2390875	et	4	main
konkresetes	doc_399014257243_item	2390888	et	4	main
ettevõtmistes	doc_399014257243_item	2390889	et	3	main
pööratud	doc_399014257242_item	2390514	et	4	main
ja	doc_399014257242_item	2390527	et	3	main
ilmne	doc_399014257242_item	2390543	et	4	main
põhja	doc_399014257242_item	2390546	et	4	main
mõõde	doc_399014257242_item	2390547	et	4	main
nagu	doc_399014257242_item	2390553	et	3	main
neid	doc_399014257242_item	2390555	et	4	main
on	doc_399014257242_item	2390556	et	4	main
kahte	doc_399014257242_item	2390557	et	4	main
vee	doc_399014257242_item	2390572	et	3	main
kui	doc_399014257242_item	2390595	et	3	main
sellele	doc_399014257242_item	2390596	et	4	main
umbes	doc_399014257242_item	2390604	et	4	main
kuni	doc_399014257242_item	2390605	et	3	main
ja	doc_399014257242_item	2390621	et	3	main
ülejäänud	doc_399014257242_item	2390623	et	4	main
elile	doc_399014257242_item	2390624	et	4	main
keskkonnapartnerluse	doc_399014257242_item	2390627	et	3	main
et	doc_399014257242_item	2390631	et	3	main
tuleb	doc_399014257242_item	2390633	et	3	main
komisjon	doc_399014257242_item	2390638	et	3	main
venemaa	doc_399014257242_item	2390642	et	4	main
norra	doc_399014257242_item	2390643	et	4	main
annetus	doc_399014257242_item	2390655	et	4	main
laen	doc_399014257242_item	2390657	et	4	main
loode	doc_399014257242_item	2390677	et	4	main
veepuhastusjaam	doc_399014257242_item	2390678	et	3	main
jäätmekoormus	doc_399014257242_item	2390689	et	3	main
esimesed	doc_399014257242_item	2390693	et	3	main
mõõtme	doc_399014257243_item	2390723	et	3	main
urmas	doc_399014257243_item	2390732	et	3	main
põhja	doc_399014257243_item	2390738	et	4	main
sai	doc_399014257243_item	2390740	et	4	main
välispoliitika	doc_399014257243_item	2390742	et	4	main
osaks	doc_399014257243_item	2390743	et	3	main
aastal	doc_399014257243_item	2390744	et	3	main
taustal	doc_399014257243_item	2390746	et	3	main
oli	doc_399014257243_item	2390747	et	3	main
idee	doc_399014257243_item	2390748	et	4	main
loode-venemaal	doc_399014257243_item	2390753	et	4	main
teha	doc_399014257243_item	2390756	et	3	main
ja	doc_399014257243_item	2390759	et	3	main
mõlemad	doc_399014257243_item	2390761	et	3	main
sellest	doc_399014257243_item	2390763	et	4	main
ja	doc_399014257243_item	2390785	et	3	main
nõukogu	doc_399014257243_item	2390805	et	4	main
artika	doc_399014257243_item	2390806	et	4	main
nõukogu	doc_399014257243_item	2390807	et	4	main
põhjamaade	doc_399014257243_item	2390813	et	3	main
tervise-	doc_399014257243_item	2390826	et	3	main
ja	doc_399014257243_item	2390827	et	3	main
keskkonna-	doc_399014257243_item	2390829	et	3	main
ning	doc_399014257243_item	2390836	et	3	main
mõõde	doc_399014257243_item	2390843	et	4	main
poole	doc_399014257243_item	2390853	et	4	main
kõrgemal	doc_399014257243_item	2390854	et	4	main
kui	doc_399014257243_item	2390877	et	3	main
on	doc_399014257243_item	2390885	et	4	main
näha	doc_399014257243_item	2390886	et	3	main
ka	doc_399014257243_item	2390887	et	3	main
projektide	doc_399014257243_item	2390924	et	3	main
on	doc_399014257243_item	2390927	et	4	main
projekte	doc_399014257243_item	2390953	et	3	main
mis	doc_399014257243_item	2390954	et	4	main
tähtsad	doc_399014257243_item	2390956	et	3	main
eestile	doc_399014257243_item	2390957	et	3	main
ja	doc_399014257243_item	2390958	et	3	main
soomele	doc_399014257243_item	2390959	et	4	main
niimoodi	doc_399014257243_item	2390967	et	3	main
tuleb	doc_399014257243_item	2390970	et	3	main
firmad	doc_399014257243_item	2391007	et	3	main
partnerluse	doc_399014257243_item	2391010	et	3	main
sellel	doc_399014257243_item	2391018	et	4	main
tänu	doc_399014257243_item	2391020	et	4	main
sellele	doc_399014257243_item	2391021	et	4	main
piirkonna	doc_399014257243_item	2391038	et	4	main
erinevate	doc_399014257242_item	2390531	et	4	main
põhja	doc_399014257242_item	2390534	et	4	main
ei	doc_399014257242_item	2390536	et	4	main
tähendust	doc_399014257242_item	2390539	et	4	main
kui	doc_399014257242_item	2390540	et	3	main
see	doc_399014257242_item	2390541	et	3	main
ei	doc_399014257242_item	2390542	et	4	main
praktikas	doc_399014257242_item	2390545	et	3	main
tervisepartnerlus	doc_399014257242_item	2390566	et	3	main
keskkonnapartnerluse	doc_399014257242_item	2390569	et	3	main
ja	doc_399014257242_item	2390573	et	3	main
õhu	doc_399014257242_item	2390574	et	3	main
puhastamine	doc_399014257242_item	2390575	et	4	main
kindla	doc_399014257242_item	2390576	et	3	main
jäätme	doc_399014257242_item	2390577	et	3	main
käitlemine	doc_399014257242_item	2390578	et	4	main
keskkonnasõbralikumaks	doc_399014257242_item	2390579	et	4	main
ja	doc_399014257242_item	2390580	et	3	main
tuumajäätmete	doc_399014257242_item	2390581	et	4	main
turvalisemale	doc_399014257242_item	2390582	et	4	main
hoiule	doc_399014257242_item	2390583	et	3	main
saamine	doc_399014257242_item	2390584	et	4	main
loode-venemaal	doc_399014257242_item	2390585	et	4	main
keskkonnapartnerluse	doc_399014257242_item	2390586	et	3	main
projektide	doc_399014257242_item	2390587	et	3	main
tänapäevane	doc_399014257242_item	2390588	et	4	main
väärtus	doc_399014257242_item	2390589	et	3	main
umbes	doc_399014257242_item	2390591	et	4	main
12	doc_399014257242_item	2390592	et	2	main
miljardit	doc_399014257242_item	2390593	et	3	main
on	doc_399014257242_item	2390590	et	4	main
eurot	doc_399014257242_item	2390594	et	3	main
mis	doc_399014257242_item	2390523	et	4	main
esineb	doc_399014257242_item	2390524	et	3	main
poliitilistes	doc_399014257242_item	2390525	et	3	main
olnud	doc_399014257242_item	2390529	et	4	main
avamiseks	doc_399014257242_item	2390533	et	4	main
näha	doc_399014257242_item	2390549	et	3	main
ka	doc_399014257242_item	2390550	et	3	main
konkresetes	doc_399014257242_item	2390551	et	4	main
ettevõtmistes	doc_399014257242_item	2390552	et	3	main
partnerprojektides	doc_399014257242_item	2390554	et	3	main
2003	doc_399014257242_item	2390568	et	2	main
on	doc_399014257242_item	2390571	et	4	main
esialgselt	doc_399014257242_item	2390598	et	4	main
otsustatud	doc_399014257242_item	2390599	et	4	main
lisaprojektide	doc_399014257242_item	2390600	et	3	main
väärtus	doc_399014257242_item	2390601	et	3	main
euroni	doc_399014257242_item	2390608	et	3	main
suure	doc_399014257242_item	2390610	et	3	main
praegu	doc_399014257242_item	2390613	et	3	main
lähiümbruses	doc_399014257242_item	2390615	et	3	main
mis	doc_399014257242_item	2390617	et	4	main
tähtsad	doc_399014257242_item	2390619	et	3	main
eestile	doc_399014257242_item	2390620	et	3	main
projektid	doc_399014257242_item	2390628	et	3	main
algkapital	doc_399014257242_item	2390632	et	3	main
partnerluse	doc_399014257242_item	2390634	et	3	main
teised	doc_399014257242_item	2390639	et	4	main
el-riigid	doc_399014257242_item	2390640	et	3	main
raha	doc_399014257242_item	2390648	et	4	main
vene	doc_399014257242_item	2390665	et	4	main
partnerluse	doc_399014257242_item	2390673	et	3	main
vähenenud	doc_399014257242_item	2390691	et	4	main
tuumajäätmeprojektid	doc_399014257242_item	2390694	et	3	main
loob	doc_399014257243_item	2390718	et	3	main
tõuseb	doc_399014257242_item	2390602	et	3	main
kogusumma	doc_399014257242_item	2390603	et	4	main
teostatakse	doc_399014257242_item	2390612	et	3	main
projekte	doc_399014257242_item	2390616	et	3	main
on	doc_399014257242_item	2390618	et	4	main
venemaale	doc_399014257242_item	2390626	et	4	main
eli	doc_399014257242_item	2390637	et	4	main
ning	doc_399014257242_item	2390641	et	3	main
annetanud	doc_399014257242_item	2390647	et	4	main
aga	doc_399014257242_item	2390654	et	3	main
regionaalnõukogud	doc_399014257242_item	2390672	et	3	main
projekt	doc_399014257242_item	2390675	et	3	main
valminud	doc_399014257242_item	2390680	et	4	main
tänu	doc_399014257242_item	2390683	et	4	main
tunduvalt	doc_399014257242_item	2390690	et	4	main
on	doc_399014257242_item	2390695	et	4	main
äsja	doc_399014257242_item	2390696	et	3	main
alanud	doc_399014257242_item	2390697	et	4	main
need	doc_399014257242_item	2390698	et	3	main
puudutavad	doc_399014257242_item	2390699	et	4	main
gremiha	doc_399014257242_item	2390700	et	4	main
piirkonna	doc_399014257242_item	2390701	et	4	main
tuumajäätmete	doc_399014257242_item	2390702	et	4	main
säilitamist	doc_399014257242_item	2390703	et	4	main
ning	doc_399014257242_item	2390704	et	3	main
murmanski	doc_399014257242_item	2390705	et	4	main
piirkonna	doc_399014257242_item	2390706	et	4	main
kiirguse	doc_399014257242_item	2390707	et	3	main
valmisolekusüsteemi	doc_399014257242_item	2390708	et	4	main
tõlge	doc_399014257243_item	2390709	et	3	main
põhja	doc_399014257243_item	2390710	et	4	main
mõõdet	doc_399014257243_item	2390711	et	4	main
läheb	doc_399014257243_item	2390712	et	3	main
vaja	doc_399014257243_item	2390713	et	4	main
ka	doc_399014257243_item	2390714	et	3	main
tulevikus	doc_399014257243_item	2390715	et	4	main
venemaa	doc_399014257243_item	2390716	et	4	main
kaasatulek	doc_399014257243_item	2390717	et	3	main
endisest	doc_399014257243_item	2390719	et	3	main
paremad	doc_399014257243_item	2390720	et	4	main
eeldused	doc_399014257243_item	2390721	et	4	main
teenäitajateks	doc_399014257243_item	2390731	et	3	main
tuomioja	doc_399014257243_item	2390736	et	4	main
sellest	doc_399014257243_item	2390749	et	4	main
et	doc_399014257243_item	2390750	et	3	main
elil	doc_399014257243_item	2390751	et	4	main
koostööd	doc_399014257243_item	2390758	et	4	main
on	doc_399014257243_item	2390782	et	4	main
liikmesriigid	doc_399014257243_item	2390784	et	3	main
venemaa	doc_399014257243_item	2390787	et	4	main
norra	doc_399014257243_item	2390788	et	4	main
ja	doc_399014257243_item	2390789	et	3	main
vaadlejariigid	doc_399014257243_item	2390796	et	4	main
tähtsaid	doc_399014257243_item	2390798	et	3	main
barentsi	doc_399014257243_item	2390808	et	4	main
euroarktiline	doc_399014257243_item	2390809	et	3	main
ning	doc_399014257243_item	2390815	et	3	main
rahvusvahelised	doc_399014257243_item	2390816	et	4	main
põhja	doc_399014257243_item	2390818	et	4	main
peapiirkondi	doc_399014257243_item	2390821	et	4	main
majandus	doc_399014257243_item	2390823	et	4	main
põhja	doc_399014257243_item	2390722	et	4	main
teostusele	doc_399014257243_item	2390724	et	4	main
soome	doc_399014257243_item	2390725	et	3	main
ja	doc_399014257243_item	2390726	et	3	main
eesti	doc_399014257243_item	2390727	et	4	main
on	doc_399014257243_item	2390728	et	4	main
selles	doc_399014257243_item	2390729	et	4	main
töös	doc_399014257243_item	2390730	et	3	main
erkki	doc_399014257243_item	2390735	et	3	main
põhjust	doc_399014257243_item	2390755	et	4	main
omavahel	doc_399014257243_item	2390757	et	3	main
saaksid	doc_399014257243_item	2390762	et	4	main
kasu	doc_399014257243_item	2390764	et	4	main
koostöö	doc_399014257243_item	2390768	et	4	main
tugevdamine	doc_399014257243_item	2390769	et	4	main
on	doc_399014257243_item	2390770	et	4	main
paras	doc_399014257243_item	2390771	et	3	main
viis	doc_399014257243_item	2390772	et	4	main
heaolu	doc_399014257243_item	2390773	et	4	main
ja	doc_399014257243_item	2390774	et	3	main
stabiilsuse	doc_399014257243_item	2390775	et	4	main
lisamiseks	doc_399014257243_item	2390776	et	4	main
terves	doc_399014257243_item	2390777	et	4	main
kirde-euroopas	doc_399014257243_item	2390778	et	3	main
põhja	doc_399014257243_item	2390779	et	4	main
mõõtme	doc_399014257243_item	2390780	et	3	main
osavõtjateks	doc_399014257243_item	2390781	et	3	main
kanada	doc_399014257243_item	2390795	et	4	main
ministrinõukogu	doc_399014257243_item	2390812	et	4	main
finantsorganisatsioonid	doc_399014257243_item	2390817	et	3	main
mõõtme	doc_399014257243_item	2390819	et	3	main
ministrinõukogu	doc_399014257243_item	2390814	et	4	main
programmi	doc_399014257243_item	2390820	et	4	main
sotsiaalküsimused	doc_399014257243_item	2390828	et	3	main
tuumaturvaküsimused	doc_399014257243_item	2390831	et	3	main
siseküsimused	doc_399014257243_item	2390839	et	3	main
abil	doc_399014257243_item	2390847	et	4	main
kirde-euroopa	doc_399014257243_item	2390852	et	4	main
põhja	doc_399014257243_item	2390856	et	4	main
poliitilistes	doc_399014257243_item	2390862	et	3	main
kõnedes	doc_399014257243_item	2390863	et	3	main
ja	doc_399014257243_item	2390864	et	3	main
olnud	doc_399014257243_item	2390866	et	4	main
hädavajalik	doc_399014257243_item	2390867	et	3	main
mõõtmel	doc_399014257243_item	2390872	et	3	main
see	doc_399014257243_item	2390878	et	3	main
ka	doc_399014257243_item	2390881	et	3	main
põhja	doc_399014257243_item	2390883	et	4	main
mõõde	doc_399014257243_item	2390884	et	4	main
partnerprojektides	doc_399014257243_item	2390891	et	3	main
on	doc_399014257243_item	2390893	et	4	main
kahte	doc_399014257243_item	2390894	et	4	main
on	doc_399014257243_item	2390822	et	4	main
inimkapital	doc_399014257243_item	2390824	et	3	main
sh	doc_399014257243_item	2390825	et	4	main
piiriülene	doc_399014257243_item	2390832	et	3	main
regionaalne	doc_399014257243_item	2390834	et	3	main
kõrgemal	doc_399014257243_item	2390840	et	4	main
eli	doc_399014257243_item	2390848	et	4	main
tähelepanu	doc_399014257243_item	2390849	et	4	main
on	doc_399014257243_item	2390858	et	4	main
erinevate	doc_399014257243_item	2390868	et	4	main
finantsallikate	doc_399014257243_item	2390869	et	3	main
avamiseks	doc_399014257243_item	2390870	et	4	main
siiski	doc_399014257243_item	2390874	et	4	main
tähendust	doc_399014257243_item	2390876	et	4	main
ilmne	doc_399014257243_item	2390880	et	4	main
praktikas	doc_399014257243_item	2390882	et	3	main
nagu	doc_399014257243_item	2390890	et	3	main
neid	doc_399014257243_item	2390892	et	4	main
asutati	doc_399014257243_item	2390897	et	4	main
aastal	doc_399014257243_item	2390898	et	3	main
2001	doc_399014257243_item	2390899	et	2	main
ja	doc_399014257243_item	2390900	et	3	main
sotsiaal-	doc_399014257243_item	2390901	et	4	main
ja	doc_399014257243_item	2390902	et	3	main
tervisepartnerlus	doc_399014257243_item	2390903	et	3	main
aastal	doc_399014257243_item	2390904	et	3	main
2003	doc_399014257243_item	2390905	et	2	main
keskkonnapartnerluse	doc_399014257243_item	2390906	et	3	main
eesmärgiks	doc_399014257243_item	2390907	et	3	main
on	doc_399014257243_item	2390908	et	4	main
vee	doc_399014257243_item	2390909	et	3	main
ja	doc_399014257243_item	2390910	et	3	main
õhu	doc_399014257243_item	2390911	et	3	main
puhastamine	doc_399014257243_item	2390912	et	4	main
kindla	doc_399014257243_item	2390913	et	3	main
jäätme	doc_399014257243_item	2390914	et	3	main
käitlemine	doc_399014257243_item	2390915	et	4	main
keskkonnasõbralikumaks	doc_399014257243_item	2390916	et	4	main
ja	doc_399014257243_item	2390917	et	3	main
tuumajäätmete	doc_399014257243_item	2390918	et	4	main
turvalisemale	doc_399014257243_item	2390919	et	4	main
hoiule	doc_399014257243_item	2390920	et	3	main
saamine	doc_399014257243_item	2390921	et	4	main
miljardit	doc_399014257243_item	2390930	et	3	main
sellele	doc_399014257243_item	2390933	et	4	main
meie	doc_399014257243_item	2390951	et	4	main
ja	doc_399014257243_item	2390962	et	3	main
venemaale	doc_399014257243_item	2390963	et	4	main
finantseeritakse	doc_399014257243_item	2390966	et	3	main
algkapital	doc_399014257243_item	2390969	et	3	main
esimene	doc_399014257243_item	2391011	et	3	main
projektile	doc_399014257243_item	2391023	et	3	main
jäätmekoormus	doc_399014257243_item	2391026	et	3	main
puudutavad	doc_399014257243_item	2391036	et	4	main
tuumajäätmete	doc_399014257243_item	2391039	et	4	main
ning	doc_399014257243_item	2391041	et	3	main
ja	doc_399014257243_item	2390833	et	3	main
koostöö	doc_399014257243_item	2390835	et	4	main
õigus-	doc_399014257243_item	2390837	et	4	main
põhja	doc_399014257243_item	2390842	et	4	main
on	doc_399014257243_item	2390850	et	4	main
tasandil	doc_399014257243_item	2390855	et	3	main
mis	doc_399014257243_item	2390860	et	4	main
ei	doc_399014257243_item	2390873	et	4	main
ei	doc_399014257243_item	2390879	et	4	main
viisi	doc_399014257243_item	2390895	et	4	main
loode-venemaal	doc_399014257243_item	2390922	et	4	main
väärtus	doc_399014257243_item	2390926	et	3	main
2	doc_399014257243_item	2390943	et	2	main
nii	doc_399014257243_item	2390946	et	3	main
lähiümbruses	doc_399014257243_item	2390952	et	3	main
on	doc_399014257243_item	2390955	et	4	main
keskkonnapartnerluse	doc_399014257243_item	2390964	et	3	main
projektid	doc_399014257243_item	2390965	et	3	main
et	doc_399014257243_item	2390968	et	3	main
komisjon	doc_399014257243_item	2390975	et	3	main
el-riigid	doc_399014257243_item	2390977	et	3	main
ning	doc_399014257243_item	2390978	et	3	main
venemaa	doc_399014257243_item	2390979	et	4	main
ja	doc_399014257243_item	2391008	et	3	main
regionaalnõukogud	doc_399014257243_item	2391009	et	3	main
peterburi	doc_399014257243_item	2391013	et	4	main
veepuhastusjaam	doc_399014257243_item	2391015	et	3	main
on	doc_399014257243_item	2391016	et	4	main
on	doc_399014257243_item	2391032	et	4	main
äsja	doc_399014257243_item	2391033	et	3	main
alanud	doc_399014257243_item	2391034	et	4	main
piirkonna	doc_399014257243_item	2391043	et	4	main
kiirguse	doc_399014257243_item	2391044	et	3	main
valmisolekusüsteemi	doc_399014257243_item	2391045	et	4	main
keskkonnapartnerlus	doc_399014257243_item	2390896	et	3	main
tänapäevane	doc_399014257243_item	2390925	et	4	main
umbes	doc_399014257243_item	2390928	et	4	main
eurot	doc_399014257243_item	2390931	et	3	main
otsustatud	doc_399014257243_item	2390936	et	4	main
lisaprojektide	doc_399014257243_item	2390937	et	3	main
väärtus	doc_399014257243_item	2390938	et	3	main
tõuseb	doc_399014257243_item	2390939	et	3	main
kogusumma	doc_399014257243_item	2390940	et	4	main
kuni	doc_399014257243_item	2390942	et	3	main
miljardi	doc_399014257243_item	2390944	et	3	main
suure	doc_399014257243_item	2390947	et	3	main
praegu	doc_399014257243_item	2390950	et	3	main
ülejäänud	doc_399014257243_item	2390960	et	4	main
partnerluse	doc_399014257243_item	2390971	et	3	main
kuhu	doc_399014257243_item	2390973	et	3	main
projekt	doc_399014257243_item	2391012	et	3	main
loode	doc_399014257243_item	2391014	et	4	main
sügisel	doc_399014257243_item	2391019	et	3	main
keskkonnapartnerluse	doc_399014257243_item	2390923	et	3	main
12	doc_399014257243_item	2390929	et	2	main
kui	doc_399014257243_item	2390932	et	3	main
lisatakse	doc_399014257243_item	2390934	et	4	main
esialgselt	doc_399014257243_item	2390935	et	4	main
umbes	doc_399014257243_item	2390941	et	4	main
euroni	doc_399014257243_item	2390945	et	3	main
summaga	doc_399014257243_item	2390948	et	4	main
teostatakse	doc_399014257243_item	2390949	et	3	main
elile	doc_399014257243_item	2390961	et	4	main
fondist	doc_399014257243_item	2390972	et	3	main
eli	doc_399014257243_item	2390974	et	4	main
teised	doc_399014257243_item	2390976	et	4	main
norra	doc_399014257243_item	2390980	et	4	main
ja	doc_399014257243_item	2390981	et	3	main
kanada	doc_399014257243_item	2390982	et	4	main
on	doc_399014257243_item	2390983	et	4	main
annetanud	doc_399014257243_item	2390984	et	4	main
raha	doc_399014257243_item	2390985	et	4	main
peaosa	doc_399014257243_item	2390986	et	4	main
projektide	doc_399014257243_item	2390987	et	3	main
finantsrahast	doc_399014257243_item	2390988	et	4	main
ei	doc_399014257243_item	2390989	et	4	main
ole	doc_399014257243_item	2390990	et	4	main
aga	doc_399014257243_item	2390991	et	3	main
annetus	doc_399014257243_item	2390992	et	4	main
vaid	doc_399014257243_item	2390993	et	3	main
laen	doc_399014257243_item	2390994	et	4	main
laen	doc_399014257243_item	2390995	et	4	main
võetakse	doc_399014257243_item	2390996	et	3	main
rahvusvahelistelt	doc_399014257243_item	2390997	et	4	main
finantsorganisatsioonidelt	doc_399014257243_item	2390998	et	3	main
ja	doc_399014257243_item	2390999	et	3	main
laenu	doc_399014257243_item	2391000	et	4	main
kasutavad	doc_399014257243_item	2391001	et	4	main
vene	doc_399014257243_item	2391002	et	4	main
poolsed	doc_399014257243_item	2391003	et	3	main
partnerid	doc_399014257243_item	2391004	et	3	main
nagu	doc_399014257243_item	2391005	et	3	main
kohalikud	doc_399014257243_item	2391006	et	3	main
valminud	doc_399014257243_item	2391017	et	4	main
on	doc_399014257243_item	2391024	et	4	main
tunduvalt	doc_399014257243_item	2391027	et	4	main
vähenenud	doc_399014257243_item	2391028	et	4	main
ka	doc_399014257243_item	2391029	et	3	main
esimesed	doc_399014257243_item	2391030	et	3	main
tuumajäätmeprojektid	doc_399014257243_item	2391031	et	3	main
gremiha	doc_399014257243_item	2391037	et	4	main
esimesele	doc_399014257243_item	2391022	et	3	main
läänemere	doc_399014257243_item	2391025	et	3	main
need	doc_399014257243_item	2391035	et	3	main
säilitamist	doc_399014257243_item	2391040	et	4	main
murmanski	doc_399014257243_item	2391042	et	4	main
vajatakse	doc_399014257245_item	2391386	et	4	main
euroopa	doc_399014257245_item	2391392	et	4	main
el	doc_399014257245_item	2391394	et	4	main
välispoliitika	doc_399014257245_item	2391395	et	4	main
osaks	doc_399014257245_item	2391396	et	3	main
aastal	doc_399014257245_item	2391397	et	3	main
möte	doc_399014257245_item	2391401	et	4	main
mölematele	doc_399014257245_item	2391413	et	4	main
tugevdamine	doc_399014257245_item	2391416	et	4	main
parim	doc_399014257245_item	2391418	et	4	main
osapoolteks	doc_399014257245_item	2391428	et	4	main
komissjon	doc_399014257245_item	2391433	et	4	main
venemaa	doc_399014257245_item	2391434	et	4	main
ühendriigid	doc_399014257245_item	2391441	et	3	main
kanada	doc_399014257245_item	2391443	et	4	main
muud	doc_399014257245_item	2391445	et	4	main
tähtsad	doc_399014257245_item	2391446	et	3	main
tegurid	doc_399014257245_item	2391447	et	3	main
on	doc_399014257245_item	2391448	et	4	main
euroarktiline	doc_399014257245_item	2391457	et	3	main
nöukogu	doc_399014257245_item	2391459	et	4	main
baltimaade	doc_399014257245_item	2391460	et	3	main
1999	doc_399014257245_item	2391398	et	2	main
et	doc_399014257245_item	2391403	et	3	main
ja	doc_399014257245_item	2391405	et	3	main
loode-venemaal	doc_399014257245_item	2391406	et	4	main
on	doc_399014257245_item	2391429	et	4	main
ja	doc_399014257245_item	2391432	et	3	main
ameerika	doc_399014257245_item	2391440	et	3	main
nöukogu	doc_399014257245_item	2391456	et	4	main
ministrite	doc_399014257245_item	2391465	et	3	main
nöukogu	doc_399014257245_item	2391466	et	4	main
dimensiooni	doc_399014257245_item	2391472	et	4	main
tegutsemisprogrammi	doc_399014257245_item	2391473	et	4	main
pöhialad	doc_399014257245_item	2391474	et	4	main
oma	doc_399014257245_item	2391506	et	4	main
on	doc_399014257245_item	2391513	et	4	main
esineb	doc_399014257245_item	2391516	et	3	main
könedes	doc_399014257245_item	2391518	et	4	main
on	doc_399014257245_item	2391520	et	4	main
ole	doc_399014257245_item	2391528	et	4	main
sel	doc_399014257245_item	2391529	et	3	main
juhul	doc_399014257245_item	2391530	et	3	main
dimensioonil	doc_399014257245_item	2391538	et	3	main
on	doc_399014257245_item	2391539	et	4	main
konkreetsed	doc_399014257245_item	2391540	et	3	main
projektid	doc_399014257245_item	2391541	et	3	main
aastal	doc_399014257245_item	2391550	et	3	main
soome	doc_399014257245_item	2391568	et	3	main
ja	doc_399014257245_item	2391579	et	3	main
erkki	doc_399014257245_item	2391580	et	3	main
keskkonnasöbralik	doc_399014257245_item	2391591	et	4	main
tähtsad	doc_399014257245_item	2391630	et	3	main
kui	doc_399014257245_item	2391633	et	3	main
soomele	doc_399014257245_item	2391635	et	4	main
loodud	doc_399014257245_item	2391650	et	4	main
kuhu	doc_399014257245_item	2391652	et	3	main
norra	doc_399014257245_item	2391663	et	4	main
ja	doc_399014257245_item	2391664	et	3	main
investeerinud	doc_399014257245_item	2391667	et	4	main
suurim	doc_399014257245_item	2391669	et	3	main
löunaosa	doc_399014257245_item	2391700	et	4	main
selle	doc_399014257245_item	2391703	et	4	main
läänemere	doc_399014257245_item	2391711	et	3	main
tõlge	doc_399014257245_item	2391383	et	3	main
pöhja	doc_399014257245_item	2391384	et	4	main
dimensiooni	doc_399014257245_item	2391385	et	4	main
pöhja	doc_399014257245_item	2391389	et	4	main
sai	doc_399014257245_item	2391391	et	4	main
liidu	doc_399014257245_item	2391393	et	3	main
kasu	doc_399014257245_item	2391414	et	4	main
heaolu	doc_399014257245_item	2391421	et	4	main
stabiilsust	doc_399014257245_item	2391423	et	4	main
el	doc_399014257245_item	2391430	et	4	main
liikmesriigid	doc_399014257245_item	2391431	et	3	main
ja	doc_399014257245_item	2391442	et	3	main
vaatlejariigid	doc_399014257245_item	2391444	et	4	main
läänemere	doc_399014257245_item	2391452	et	3	main
kui	doc_399014257245_item	2391467	et	3	main
el	doc_399014257245_item	2391503	et	4	main
termin	doc_399014257245_item	2391514	et	3	main
hädavajalik	doc_399014257245_item	2391522	et	3	main
avamisel	doc_399014257245_item	2391524	et	4	main
dimensioonil	doc_399014257245_item	2391526	et	3	main
ei	doc_399014257245_item	2391527	et	4	main
on	doc_399014257245_item	2391545	et	4	main
keskkonna	doc_399014257245_item	2391547	et	3	main
rajati	doc_399014257245_item	2391549	et	3	main
2001	doc_399014257245_item	2391551	et	2	main
tervisepartnerlus	doc_399014257245_item	2391555	et	3	main
kaasamine	doc_399014257245_item	2391559	et	4	main
projekti	doc_399014257245_item	2391560	et	4	main
toimingule	doc_399014257245_item	2391567	et	3	main
tuomioja	doc_399014257245_item	2391581	et	4	main
keskkonnapartnerluse	doc_399014257245_item	2391582	et	3	main
eesmärgiks	doc_399014257245_item	2391583	et	3	main
ja	doc_399014257245_item	2391586	et	3	main
paigaldus	doc_399014257245_item	2391595	et	4	main
nii	doc_399014257245_item	2391621	et	3	main
abil	doc_399014257245_item	2391624	et	4	main
nii	doc_399014257245_item	2391631	et	3	main
viisil	doc_399014257245_item	2391644	et	4	main
et	doc_399014257245_item	2391645	et	3	main
algkapital	doc_399014257245_item	2391646	et	3	main
saadaksetuleb	doc_399014257245_item	2391647	et	4	main
partnerite	doc_399014257245_item	2391648	et	3	main
vahel	doc_399014257245_item	2391649	et	4	main
komissjon	doc_399014257245_item	2391654	et	4	main
ja	doc_399014257245_item	2391655	et	3	main
hulk	doc_399014257245_item	2391656	et	3	main
el	doc_399014257245_item	2391657	et	4	main
maid	doc_399014257245_item	2391658	et	4	main
ning	doc_399014257245_item	2391659	et	3	main
venemaa	doc_399014257245_item	2391691	et	4	main
sankt-peterburi	doc_399014257245_item	2391699	et	4	main
sellele	doc_399014257245_item	2391707	et	4	main
projektile	doc_399014257245_item	2391708	et	3	main
väheneb	doc_399014257245_item	2391709	et	3	main
märkimisväärselt	doc_399014257245_item	2391710	et	4	main
projektid	doc_399014257245_item	2391716	et	3	main
samuti	doc_399014257245_item	2391718	et	3	main
hakanud	doc_399014257245_item	2391720	et	4	main
seotud	doc_399014257245_item	2391724	et	4	main
säilitamisega	doc_399014257245_item	2391728	et	4	main
kiirguse	doc_399014257245_item	2391732	et	3	main
ka	doc_399014257245_item	2391387	et	3	main
tulevikus	doc_399014257245_item	2391388	et	4	main
tagaplaanil	doc_399014257245_item	2391399	et	4	main
sellest	doc_399014257245_item	2391402	et	4	main
el	doc_399014257245_item	2391404	et	4	main
tasub	doc_399014257245_item	2391407	et	3	main
teha	doc_399014257245_item	2391408	et	3	main
koostööd	doc_399014257245_item	2391409	et	4	main
kuna	doc_399014257245_item	2391410	et	3	main
see	doc_399014257245_item	2391411	et	3	main
toob	doc_399014257245_item	2391412	et	3	main
koostöö	doc_399014257245_item	2391415	et	4	main
pöhja	doc_399014257245_item	2391426	et	4	main
norra	doc_399014257245_item	2391435	et	4	main
ja	doc_399014257245_item	2391436	et	3	main
island	doc_399014257245_item	2391437	et	4	main
on	doc_399014257245_item	2391438	et	4	main
partnerriigid	doc_399014257245_item	2391439	et	3	main
pöhja	doc_399014257245_item	2391449	et	4	main
piirkondlikud	doc_399014257245_item	2391450	et	3	main
nöukogu	doc_399014257245_item	2391454	et	4	main
pöhjamaade	doc_399014257245_item	2391464	et	4	main
rahvusvahelised	doc_399014257245_item	2391469	et	4	main
pöhja	doc_399014257245_item	2391471	et	4	main
abil	doc_399014257245_item	2391502	et	4	main
on	doc_399014257245_item	2391504	et	4	main
pööranud	doc_399014257245_item	2391505	et	4	main
poliitilistes	doc_399014257245_item	2391517	et	3	main
tähtsust	doc_399014257245_item	2391531	et	4	main
kui	doc_399014257245_item	2391532	et	3	main
see	doc_399014257245_item	2391533	et	3	main
argielus	doc_399014257245_item	2391536	et	4	main
partnerlusprojekt	doc_399014257245_item	2391543	et	3	main
kaks	doc_399014257245_item	2391546	et	3	main
partnerlus	doc_399014257245_item	2391548	et	3	main
ja	doc_399014257245_item	2391552	et	3	main
aastal	doc_399014257245_item	2391556	et	3	main
vöimalused	doc_399014257245_item	2391564	et	4	main
pöhja	doc_399014257245_item	2391565	et	4	main
dimensiooni	doc_399014257245_item	2391566	et	4	main
paet	doc_399014257245_item	2391578	et	4	main
summa	doc_399014257245_item	2391623	et	4	main
teostatakse	doc_399014257245_item	2391625	et	3	main
lähipiirkonnas	doc_399014257245_item	2391626	et	4	main
projekte	doc_399014257245_item	2391627	et	3	main
mis	doc_399014257245_item	2391628	et	4	main
el-le	doc_399014257245_item	2391637	et	3	main
ja	doc_399014257245_item	2391638	et	3	main
on	doc_399014257245_item	2391666	et	4	main
ja	doc_399014257245_item	2391690	et	3	main
piirkondlikust	doc_399014257245_item	2391692	et	4	main
ja	doc_399014257245_item	2391693	et	3	main
kohalikust	doc_399014257245_item	2391694	et	4	main
esimesed	doc_399014257245_item	2391714	et	3	main
on	doc_399014257245_item	2391717	et	4	main
need	doc_399014257245_item	2391722	et	3	main
piirkonna	doc_399014257245_item	2391726	et	4	main
piirkonna	doc_399014257245_item	2391731	et	4	main
süsteemiga	doc_399014257245_item	2391733	et	3	main
ja	doc_399014257245_item	2391735	et	3	main
püütakse	doc_399014257245_item	2391738	et	3	main
kordineerida	doc_399014257245_item	2391739	et	4	main
dimensioon	doc_399014257245_item	2391390	et	3	main
oli	doc_399014257245_item	2391400	et	3	main
on	doc_399014257245_item	2391417	et	4	main
viis	doc_399014257245_item	2391419	et	4	main
lisamaks	doc_399014257245_item	2391420	et	4	main
ja	doc_399014257245_item	2391422	et	3	main
kogu	doc_399014257245_item	2391424	et	4	main
kagu-euuropas	doc_399014257245_item	2391425	et	4	main
dimensiooni	doc_399014257245_item	2391427	et	4	main
nöukogud	doc_399014257245_item	2391451	et	4	main
maade	doc_399014257245_item	2391453	et	3	main
arktika	doc_399014257245_item	2391455	et	4	main
barentsi	doc_399014257245_item	2391458	et	4	main
nöukogu	doc_399014257245_item	2391462	et	4	main
nii	doc_399014257245_item	2391463	et	3	main
finantsorganisatsioonid	doc_399014257245_item	2391470	et	3	main
majandus	doc_399014257245_item	2391476	et	4	main
inimkapital	doc_399014257245_item	2391477	et	3	main
arvatud	doc_399014257245_item	2391479	et	4	main
kaasa	doc_399014257245_item	2391478	et	4	main
tervise-	doc_399014257245_item	2391480	et	3	main
ja	doc_399014257245_item	2391481	et	3	main
sotsiaalküsimused	doc_399014257245_item	2391482	et	3	main
keskkonna-	doc_399014257245_item	2391483	et	3	main
ja	doc_399014257245_item	2391484	et	3	main
piiriülene	doc_399014257245_item	2391486	et	3	main
tuumaohutusküsimused	doc_399014257245_item	2391485	et	3	main
ja	doc_399014257245_item	2391487	et	3	main
regionaalne	doc_399014257245_item	2391488	et	3	main
koostöö	doc_399014257245_item	2391489	et	4	main
ning	doc_399014257245_item	2391490	et	3	main
öigus	doc_399014257245_item	2391491	et	4	main
ja	doc_399014257245_item	2391492	et	3	main
siseasjad	doc_399014257245_item	2391493	et	3	main
körgemal	doc_399014257245_item	2391494	et	4	main
tasandil	doc_399014257245_item	2391495	et	3	main
pöhja	doc_399014257245_item	2391496	et	4	main
dimensiooni	doc_399014257245_item	2391497	et	4	main
vöib	doc_399014257245_item	2391498	et	4	main
pidada	doc_399014257245_item	2391499	et	4	main
poliitikaks	doc_399014257245_item	2391500	et	3	main
ministrite	doc_399014257245_item	2391461	et	3	main
ka	doc_399014257245_item	2391468	et	3	main
on	doc_399014257245_item	2391475	et	4	main
mis	doc_399014257245_item	2391515	et	4	main
mille	doc_399014257245_item	2391501	et	3	main
tähelepanu	doc_399014257245_item	2391507	et	4	main
kagu-euroopasse	doc_399014257245_item	2391508	et	3	main
körgema	doc_399014257245_item	2391509	et	4	main
tasandi	doc_399014257245_item	2391510	et	3	main
pöhja	doc_399014257245_item	2391511	et	4	main
dimensioon	doc_399014257245_item	2391512	et	3	main
ja	doc_399014257245_item	2391519	et	3	main
olnud	doc_399014257245_item	2391521	et	4	main
finantseerimisallikate	doc_399014257245_item	2391523	et	3	main
väljendu	doc_399014257245_item	2391535	et	4	main
pöhja	doc_399014257245_item	2391537	et	4	main
näiteks	doc_399014257245_item	2391542	et	4	main
sotsiaal-	doc_399014257245_item	2391553	et	4	main
venemaa	doc_399014257245_item	2391558	et	4	main
loob	doc_399014257245_item	2391561	et	3	main
endisest	doc_399014257245_item	2391562	et	3	main
paremad	doc_399014257245_item	2391563	et	4	main
eesti	doc_399014257245_item	2391570	et	4	main
olla	doc_399014257245_item	2391572	et	3	main
sellelaadses	doc_399014257245_item	2391573	et	3	main
töös	doc_399014257245_item	2391574	et	3	main
teenäitajateks	doc_399014257245_item	2391575	et	3	main
kirjutavad	doc_399014257245_item	2391576	et	4	main
urmas	doc_399014257245_item	2391577	et	3	main
öhupuhastus	doc_399014257245_item	2391587	et	4	main
samuti	doc_399014257245_item	2391588	et	3	main
tahkete	doc_399014257245_item	2391589	et	4	main
jäätmete	doc_399014257245_item	2391590	et	4	main
kohta	doc_399014257245_item	2391597	et	4	main
pöhja	doc_399014257245_item	2391525	et	4	main
ei	doc_399014257245_item	2391534	et	4	main
neid	doc_399014257245_item	2391544	et	4	main
ja	doc_399014257245_item	2391554	et	3	main
2003	doc_399014257245_item	2391557	et	2	main
ja	doc_399014257245_item	2391569	et	3	main
vöivad	doc_399014257245_item	2391571	et	4	main
on	doc_399014257245_item	2391584	et	4	main
vee-	doc_399014257245_item	2391585	et	3	main
käsitlemine	doc_399014257245_item	2391592	et	4	main
ja	doc_399014257245_item	2391593	et	3	main
tuumajäätmete	doc_399014257245_item	2391594	et	4	main
turvalisemasse	doc_399014257245_item	2391596	et	4	main
loode-venemaal	doc_399014257245_item	2391598	et	4	main
keskkonnapartnerlusprojekti	doc_399014257245_item	2391599	et	4	main
praegune	doc_399014257245_item	2391600	et	3	main
väärtus	doc_399014257245_item	2391601	et	3	main
on	doc_399014257245_item	2391602	et	4	main
umbes	doc_399014257245_item	2391603	et	4	main
12	doc_399014257245_item	2391604	et	2	main
miljr	doc_399014257245_item	2391605	et	4	main
eurot	doc_399014257245_item	2391606	et	3	main
kui	doc_399014257245_item	2391607	et	3	main
siia	doc_399014257245_item	2391608	et	4	main
lisada	doc_399014257245_item	2391610	et	3	main
veel	doc_399014257245_item	2391609	et	4	main
algselt	doc_399014257245_item	2391611	et	4	main
planeeritud	doc_399014257245_item	2391612	et	4	main
lisaprojektide	doc_399014257245_item	2391613	et	3	main
hind	doc_399014257245_item	2391614	et	3	main
kogusumma	doc_399014257245_item	2391615	et	4	main
väärtuseks	doc_399014257245_item	2391616	et	4	main
tuleks	doc_399014257245_item	2391617	et	4	main
2	doc_399014257245_item	2391618	et	2	main
miljr	doc_399014257245_item	2391619	et	4	main
eurot	doc_399014257245_item	2391620	et	3	main
on	doc_399014257245_item	2391629	et	4	main
eestile	doc_399014257245_item	2391632	et	3	main
liskas	doc_399014257245_item	2391660	et	4	main
sellele	doc_399014257245_item	2391661	et	4	main
kanada	doc_399014257245_item	2391665	et	4	main
raha	doc_399014257245_item	2391668	et	4	main
valitsusest	doc_399014257245_item	2391695	et	4	main
partnerluse	doc_399014257245_item	2391696	et	3	main
esimene	doc_399014257245_item	2391697	et	3	main
projekt	doc_399014257245_item	2391698	et	3	main
veepuhastusjaam	doc_399014257245_item	2391701	et	3	main
ülekoormus	doc_399014257245_item	2391713	et	3	main
tasapisi	doc_399014257245_item	2391719	et	3	main
suure	doc_399014257245_item	2391622	et	3	main
ka	doc_399014257245_item	2391634	et	3	main
kogu	doc_399014257245_item	2391636	et	4	main
venemaale	doc_399014257245_item	2391639	et	4	main
keskkonnapartnerluse	doc_399014257245_item	2391640	et	3	main
projektid	doc_399014257245_item	2391641	et	3	main
rahastatakse	doc_399014257245_item	2391642	et	4	main
sel	doc_399014257245_item	2391643	et	3	main
fondist	doc_399014257245_item	2391651	et	3	main
el	doc_399014257245_item	2391653	et	4	main
venemaa	doc_399014257245_item	2391662	et	4	main
osa	doc_399014257245_item	2391670	et	4	main
projektide	doc_399014257245_item	2391671	et	3	main
rahastusest	doc_399014257245_item	2391672	et	4	main
ei	doc_399014257245_item	2391673	et	4	main
ole	doc_399014257245_item	2391674	et	4	main
siiski	doc_399014257245_item	2391675	et	4	main
investeeringuraha	doc_399014257245_item	2391676	et	4	main
vaid	doc_399014257245_item	2391677	et	3	main
laen	doc_399014257245_item	2391678	et	4	main
laenu	doc_399014257245_item	2391679	et	4	main
vöetakse	doc_399014257245_item	2391680	et	4	main
rahvusvahelistest	doc_399014257245_item	2391681	et	4	main
organisatsioonidest	doc_399014257245_item	2391682	et	3	main
ja	doc_399014257245_item	2391683	et	3	main
venemaa	doc_399014257245_item	2391684	et	4	main
ettevötetelt	doc_399014257245_item	2391685	et	4	main
nagu	doc_399014257245_item	2391686	et	3	main
näiteks	doc_399014257245_item	2391687	et	4	main
kohalikest	doc_399014257245_item	2391688	et	3	main
ettevötetest	doc_399014257245_item	2391689	et	4	main
valmis	doc_399014257245_item	2391702	et	4	main
aasta	doc_399014257245_item	2391704	et	4	main
sügisel	doc_399014257245_item	2391705	et	3	main
tänu	doc_399014257245_item	2391706	et	4	main
jäätmete	doc_399014257245_item	2391712	et	4	main
tuumajäätmete	doc_399014257245_item	2391715	et	4	main
arenema	doc_399014257245_item	2391721	et	3	main
gremihi	doc_399014257245_item	2391725	et	4	main
tuumajäätmete	doc_399014257245_item	2391727	et	4	main
murmanski	doc_399014257245_item	2391730	et	4	main
sotsiaal-	doc_399014257245_item	2391734	et	4	main
töhustada	doc_399014257245_item	2391741	et	4	main
nakkushaiguste	doc_399014257245_item	2391742	et	4	main
ebatervisliku	doc_399014257245_item	2391744	et	3	main
seotud	doc_399014257245_item	2391746	et	4	main
haiguste	doc_399014257245_item	2391747	et	4	main
vastaseid	doc_399014257245_item	2391748	et	3	main
toiminguid	doc_399014257245_item	2391749	et	3	main
ning	doc_399014257245_item	2391750	et	3	main
vähendada	doc_399014257245_item	2391751	et	3	main
sotsiaalprobleemidest	doc_399014257245_item	2391752	et	3	main
barentsi	doc_399014257245_item	2391760	et	4	main
objekti	doc_399014257245_item	2391774	et	4	main
tervislik	doc_399014257245_item	2391779	et	3	main
nii	doc_399014257245_item	2391790	et	3	main
kasu	doc_399014257245_item	2391799	et	4	main
väheneks	doc_399014257245_item	2391808	et	3	main
lisamine	doc_399014257245_item	2391826	et	4	main
ja	doc_399014257245_item	2391740	et	3	main
ning	doc_399014257245_item	2391743	et	3	main
tingitud	doc_399014257245_item	2391753	et	4	main
ohte	doc_399014257245_item	2391754	et	4	main
alustanud	doc_399014257245_item	2391757	et	4	main
juba	doc_399014257245_item	2391758	et	3	main
hiv-	doc_399014257245_item	2391764	et	4	main
ja	doc_399014257245_item	2391765	et	3	main
aidsiprogrammi	doc_399014257245_item	2391766	et	4	main
mida	doc_399014257245_item	2391767	et	4	main
avardatakse	doc_399014257245_item	2391768	et	3	main
nüüd	doc_399014257245_item	2391769	et	4	main
ka	doc_399014257245_item	2391770	et	3	main
tervisehoid	doc_399014257245_item	2391776	et	3	main
vangide	doc_399014257245_item	2391778	et	3	main
ja	doc_399014257245_item	2391782	et	3	main
kolmas	doc_399014257245_item	2391786	et	3	main
maadele	doc_399014257245_item	2391789	et	4	main
läänemere	doc_399014257245_item	2391791	et	3	main
kui	doc_399014257245_item	2391793	et	3	main
ka	doc_399014257245_item	2391794	et	3	main
kaugemal	doc_399014257245_item	2391795	et	4	main
euroopas	doc_399014257245_item	2391796	et	3	main
oleks	doc_399014257245_item	2391797	et	3	main
sellest	doc_399014257245_item	2391798	et	4	main
muutuks	doc_399014257245_item	2391802	et	4	main
ja	doc_399014257245_item	2391804	et	3	main
seotud	doc_399014257245_item	2391806	et	4	main
partnerlusega	doc_399014257245_item	2391810	et	3	main
seotud	doc_399014257245_item	2391811	et	4	main
programmid	doc_399014257245_item	2391812	et	4	main
vöiksid	doc_399014257245_item	2391813	et	4	main
olla	doc_399014257245_item	2391814	et	3	main
näiteks	doc_399014257245_item	2391815	et	4	main
piiriületuspunktide	doc_399014257245_item	2391816	et	3	main
paremaks	doc_399014257245_item	2391817	et	4	main
muutmine	doc_399014257245_item	2391818	et	4	main
logistikavörkude	doc_399014257245_item	2391819	et	4	main
ja	doc_399014257245_item	2391820	et	3	main
kaubaveo	doc_399014257245_item	2391824	et	3	main
turavlisuse	doc_399014257245_item	2391825	et	4	main
on	doc_399014257245_item	2391723	et	4	main
ja	doc_399014257245_item	2391729	et	3	main
eluviisiga	doc_399014257245_item	2391745	et	4	main
loode-venemaa	doc_399014257245_item	2391755	et	4	main
on	doc_399014257245_item	2391756	et	4	main
piirkonnavahelise	doc_399014257245_item	2391761	et	4	main
koostöölepinguga	doc_399014257245_item	2391762	et	4	main
mitmekülgse	doc_399014257245_item	2391763	et	3	main
baltimaadesse	doc_399014257245_item	2391771	et	4	main
vöetakse	doc_399014257245_item	2391773	et	4	main
alla	doc_399014257245_item	2391775	et	3	main
liiklusest	doc_399014257245_item	2391781	et	4	main
logistikast	doc_399014257245_item	2391783	et	4	main
tulla	doc_399014257245_item	2391785	et	3	main
köikidele	doc_399014257245_item	2391788	et	4	main
piirkonnas	doc_399014257245_item	2391792	et	4	main
et	doc_399014257245_item	2391800	et	3	main
paremaks	doc_399014257245_item	2391803	et	4	main
tollitöö	doc_399014257245_item	2391821	et	4	main
tervisepartnerluse	doc_399014257245_item	2391736	et	3	main
abil	doc_399014257245_item	2391737	et	4	main
järgnevalt	doc_399014257245_item	2391772	et	4	main
olukord	doc_399014257245_item	2391780	et	3	main
vöiks	doc_399014257245_item	2391784	et	3	main
partnerlusprogramm	doc_399014257245_item	2391787	et	3	main
kaubavahetus	doc_399014257245_item	2391801	et	4	main
sellega	doc_399014257245_item	2391805	et	3	main
sellise	doc_399014257245_item	2391809	et	4	main
ja	doc_399014257245_item	2391823	et	3	main
seoses	doc_399014257245_item	2391759	et	4	main
ja	doc_399014257245_item	2391777	et	3	main
bürokraatia	doc_399014257245_item	2391807	et	4	main
lihtsustamine	doc_399014257245_item	2391822	et	4	main
varane	doc_401436695441_item	2393335	et	4	main
territooriumil	doc_401436695441_item	2393338	et	3	main
kulda	doc_401436695441_item	2393351	et	4	main
aga	doc_401436695441_item	2393352	et	3	main
väga	doc_401436695441_item	2393359	et	3	main
leiti	doc_401436695441_item	2393361	et	3	main
teine	doc_401436695441_item	2393363	et	3	main
said	doc_401436695441_item	2393392	et	4	main
1	doc_401436695441_item	2393405	et	2	main
saj	doc_401436695441_item	2393406	et	4	main
pkr	doc_401436695441_item	2393407	et	4	main
ehteid	doc_401436695441_item	2393408	et	3	main
tehti	doc_401436695441_item	2393409	et	3	main
kivist	doc_401436695441_item	2393410	et	4	main
ja	doc_401436695441_item	2393411	et	3	main
kasvatamisega	doc_401436695441_item	2393420	et	4	main
metalliaeg	doc_401436695441_item	2393336	et	3	main
eesti	doc_401436695441_item	2393337	et	4	main
2	doc_401436695441_item	2393339	et	2	main
mõiste	doc_401436695441_item	2393340	et	4	main
animism	doc_401436695441_item	2393341	et	3	main
tähendus	doc_401436695441_item	2393342	et	4	main
1	doc_401436695441_item	2393343	et	2	main
esimene	doc_401436695441_item	2393344	et	3	main
eestis	doc_401436695441_item	2393348	et	3	main
mandrilt	doc_401436695441_item	2393356	et	4	main
ja	doc_401436695441_item	2393357	et	3	main
palju	doc_401436695441_item	2393360	et	4	main
metall	doc_401436695441_item	2393364	et	3	main
et	doc_401436695441_item	2393389	et	3	main
kauba	doc_401436695441_item	2393393	et	3	main
sõja	doc_401436695441_item	2393396	et	3	main
hakkatakse	doc_401436695441_item	2393414	et	4	main
intensiivselt	doc_401436695441_item	2393415	et	4	main
tegelema	doc_401436695441_item	2393416	et	3	main
põllumajandusega	doc_401436695441_item	2393417	et	3	main
ja	doc_401436695441_item	2393418	et	3	main
koduloomade	doc_401436695441_item	2393419	et	4	main
on	doc_401436695441_item	2393422	et	4	main
pärast	doc_401436695441_item	2393431	et	4	main
neid	doc_401436695441_item	2393432	et	4	main
elab	doc_401436695441_item	2393433	et	3	main
rohkem	doc_401436695441_item	2393434	et	4	main
neid	doc_401436695441_item	2393440	et	4	main
hobuseid	doc_401436695441_item	2393451	et	4	main
veeloomadena	doc_401436695441_item	2393453	et	3	main
maakogestamis	doc_401436695441_item	2393455	et	4	main
lõigata	doc_401436695441_item	2393466	et	4	main
rituaalides	doc_401436695441_item	2393471	et	3	main
tal	doc_401436695441_item	2393472	et	3	main
maagiline	doc_401436695441_item	2393474	et	4	main
ilm	doc_401436695441_item	2393487	et	3	main
mulk	doc_401436695441_item	2393500	et	3	main
tegelema	doc_401436695441_item	2393504	et	3	main
see	doc_401436695441_item	2393532	et	3	main
hakkati	doc_401436695441_item	2393543	et	3	main
ehitama	doc_401436695441_item	2393544	et	4	main
linnuseid	doc_401436695441_item	2393546	et	3	main
müüritega	doc_401436695441_item	2393547	et	4	main
taratega	doc_401436695441_item	2393548	et	4	main
uus	doc_401436695441_item	2393549	et	3	main
matusetraditsioon	doc_401436695441_item	2393550	et	3	main
pärib	doc_401436695441_item	2393551	et	3	main
skandinaaviast	doc_401436695441_item	2393552	et	3	main
eriti	doc_401436695441_item	2393559	et	3	main
lae	doc_401436695441_item	2393571	et	4	main
kontrolltöö	doc_401436695441_item	2393333	et	4	main
1	doc_401436695441_item	2393334	et	2	main
metall	doc_401436695441_item	2393345	et	3	main
oli	doc_401436695441_item	2393346	et	3	main
ei	doc_401436695441_item	2393349	et	4	main
ameerika	doc_401436695441_item	2393355	et	3	main
ka	doc_401436695441_item	2393358	et	3	main
vahetuses	doc_401436695441_item	2393394	et	4	main
ja	doc_401436695441_item	2393395	et	3	main
varane	doc_401436695441_item	2393398	et	4	main
aastatuh	doc_401436695441_item	2393402	et	4	main
luust	doc_401436695441_item	2393412	et	4	main
rauaajal	doc_401436695441_item	2393413	et	3	main
asulad	doc_401436695441_item	2393421	et	3	main
veel	doc_401436695441_item	2393424	et	4	main
vähe	doc_401436695441_item	2393441	et	3	main
et	doc_401436695441_item	2393486	et	3	main
jahutati	doc_401436695441_item	2393491	et	4	main
kooti	doc_401436695441_item	2393497	et	4	main
viljandimaamehed	doc_401436695441_item	2393499	et	3	main
esimesena	doc_401436695441_item	2393502	et	3	main
lydia	doc_401436695441_item	2393505	et	4	main
hakkasid	doc_401436695441_item	2393521	et	4	main
selleks	doc_401436695441_item	2393524	et	4	main
et	doc_401436695441_item	2393525	et	3	main
maase	doc_401436695441_item	2393530	et	4	main
oli	doc_401436695441_item	2393533	et	3	main
peale	doc_401436695441_item	2393536	et	4	main
pandi	doc_401436695441_item	2393538	et	4	main
savi	doc_401436695441_item	2393539	et	4	main
sõnnik	doc_401436695441_item	2393540	et	3	main
kivikirst	doc_401436695441_item	2393553	et	3	main
pae	doc_401436695441_item	2393555	et	3	main
see	doc_401436695441_item	2393557	et	3	main
haud	doc_401436695441_item	2393572	et	4	main
ärkasin	doc_403280563851_item	2393612	et	3	main
kaua	doc_403280563851_item	2393620	et	3	main
voodis	doc_403280563851_item	2393623	et	3	main
sööma	doc_403280563851_item	2393628	et	4	main
olid	doc_403280563851_item	2393631	et	4	main
ema	doc_403280563851_item	2393638	et	4	main
alustasime	doc_403280563851_item	2393643	et	3	main
oma	doc_403280563851_item	2393649	et	4	main
toas	doc_403280563851_item	2393650	et	3	main
elutoas	doc_403280563851_item	2393651	et	3	main
valmistasime	doc_403280563851_item	2393657	et	3	main
me	doc_403280563851_item	2393702	et	4	main
kostitas	doc_403280563851_item	2393708	et	3	main
mind	doc_403280563851_item	2393709	et	4	main
ma	doc_403280563851_item	2393719	et	3	main
minu	doc_403280563851_item	2393730	et	3	main
vaatas	doc_403280563851_item	2393732	et	3	main
leia	doc_401436695441_item	2393350	et	4	main
leiab	doc_401436695441_item	2393354	et	3	main
egiptuses	doc_401436695441_item	2393362	et	4	main
nii	doc_401436695441_item	2393388	et	3	main
pronksist	doc_401436695441_item	2393390	et	4	main
jooksul	doc_401436695441_item	2393397	et	4	main
metalliaeg	doc_401436695441_item	2393399	et	3	main
eestis	doc_401436695441_item	2393400	et	3	main
ii	doc_401436695441_item	2393401	et	4	main
kiviajal	doc_401436695441_item	2393429	et	3	main
kasvatasid	doc_401436695441_item	2393443	et	4	main
kasutati	doc_401436695441_item	2393452	et	4	main
põlluriistad	doc_401436695441_item	2393454	et	3	main
mis	doc_401436695441_item	2393458	et	4	main
kuld	doc_401436695441_item	2393347	et	3	main
seda	doc_401436695441_item	2393353	et	3	main
oli	doc_401436695441_item	2393365	et	3	main
pronks	doc_401436695441_item	2393366	et	3	main
vask	doc_401436695441_item	2393367	et	3	main
tina	doc_401436695441_item	2393368	et	4	main
seda	doc_401436695441_item	2393369	et	3	main
kasutati	doc_401436695441_item	2393370	et	4	main
lähis-idas	doc_401436695441_item	2393371	et	3	main
esimesed	doc_401436695441_item	2393372	et	3	main
pronksi	doc_401436695441_item	2393373	et	4	main
esemeid	doc_401436695441_item	2393374	et	3	main
on	doc_401436695441_item	2393375	et	4	main
leitud	doc_401436695441_item	2393376	et	4	main
saaremaalt	doc_401436695441_item	2393377	et	4	main
kuna	doc_401436695441_item	2393378	et	3	main
sõideti	doc_401436695441_item	2393379	et	3	main
väga	doc_401436695441_item	2393380	et	3	main
palju	doc_401436695441_item	2393381	et	4	main
üle	doc_401436695441_item	2393382	et	3	main
mere	doc_401436695441_item	2393383	et	3	main
kaubeldi	doc_401436695441_item	2393384	et	3	main
ka	doc_401436695441_item	2393385	et	3	main
sealsete	doc_401436695441_item	2393386	et	4	main
asuniketega	doc_401436695441_item	2393387	et	4	main
asju	doc_401436695441_item	2393391	et	3	main
keskel	doc_401436695441_item	2393403	et	3	main
ekr-	doc_401436695441_item	2393404	et	4	main
ikka	doc_401436695441_item	2393423	et	4	main
veekogude	doc_401436695441_item	2393425	et	3	main
ääres	doc_401436695441_item	2393426	et	4	main
nagu	doc_401436695441_item	2393427	et	3	main
oligi	doc_401436695441_item	2393428	et	3	main
selle	doc_401436695441_item	2393430	et	4	main
äres	doc_401436695441_item	2393436	et	4	main
ja	doc_401436695441_item	2393437	et	3	main
lõunas	doc_401436695441_item	2393438	et	3	main
on	doc_401436695441_item	2393439	et	4	main
inimesed	doc_401436695441_item	2393442	et	3	main
lamastele	doc_401436695441_item	2393445	et	4	main
vahend	doc_401436695441_item	2393456	et	3	main
sai	doc_401436695441_item	2393465	et	4	main
ja	doc_401436695441_item	2393468	et	3	main
oleks	doc_401436695441_item	2393488	et	3	main
kirjutas	doc_401436695441_item	2393507	et	3	main
mulgist	doc_401436695441_item	2393508	et	3	main
tol	doc_401436695441_item	2393509	et	3	main
ja	doc_401436695441_item	2393513	et	3	main
kasutati	doc_401436695441_item	2393516	et	4	main
oma	doc_401436695441_item	2393526	et	4	main
kaitsta	doc_401436695441_item	2393528	et	4	main
hakkati	doc_401436695441_item	2393529	et	3	main
puu	doc_401436695441_item	2393534	et	4	main
levinud	doc_401436695441_item	2393560	et	4	main
põhja	doc_401436695441_item	2393563	et	4	main
eestis	doc_401436695441_item	2393564	et	3	main
sõnad	doc_401436695441_item	2393566	et	4	main
germaani	doc_401436695441_item	2393567	et	3	main
pärit	doc_401436695441_item	2393568	et	3	main
mõõk	doc_401436695441_item	2393569	et	3	main
põld	doc_401436695441_item	2393570	et	3	main
tavaliselt	doc_403280563851_item	2393610	et	4	main
üksteist	doc_403280563851_item	2393614	et	4	main
sest	doc_403280563851_item	2393615	et	4	main
meeldib	doc_403280563851_item	2393617	et	3	main
peipsi	doc_401436695441_item	2393435	et	4	main
lisaks	doc_401436695441_item	2393444	et	4	main
ja	doc_401436695441_item	2393446	et	3	main
kitsetele	doc_401436695441_item	2393447	et	4	main
sigu	doc_401436695441_item	2393448	et	3	main
ja	doc_401436695441_item	2393449	et	3	main
hobuseid	doc_401436695441_item	2393450	et	4	main
kõblas	doc_401436695441_item	2393457	et	3	main
seda	doc_401436695441_item	2393469	et	3	main
sirpi	doc_401436695441_item	2393484	et	4	main
vette	doc_401436695441_item	2393485	et	3	main
hea	doc_401436695441_item	2393489	et	4	main
lina	doc_401436695441_item	2393495	et	4	main
rõivast	doc_401436695441_item	2393498	et	4	main
hakkaid	doc_401436695441_item	2393501	et	4	main
sellega	doc_401436695441_item	2393503	et	3	main
koidula	doc_401436695441_item	2393506	et	4	main
ajal	doc_401436695441_item	2393510	et	4	main
tegeleti	doc_401436695441_item	2393511	et	3	main
kalapüügiga	doc_401436695441_item	2393512	et	3	main
rasva	doc_401436695441_item	2393515	et	4	main
teisi	doc_401436695441_item	2393522	et	4	main
röövima	doc_401436695441_item	2393523	et	4	main
kaivama	doc_401436695441_item	2393531	et	4	main
tol	doc_401436695441_item	2393541	et	3	main
muinas	doc_401436695441_item	2393545	et	4	main
kaaned	doc_401436695441_item	2393554	et	3	main
saartel	doc_401436695441_item	2393561	et	3	main
ja	doc_401436695441_item	2393562	et	3	main
jõuavad	doc_401436695441_item	2393565	et	4	main
lõuna-eesti	doc_401436695441_item	2393573	et	4	main
hõimud	doc_401436695441_item	2393574	et	4	main
selle	doc_403280563851_item	2393607	et	4	main
päeva	doc_403280563851_item	2393608	et	4	main
puhkepäeviti	doc_403280563851_item	2393619	et	4	main
veidi	doc_403280563851_item	2393624	et	3	main
läksin	doc_403280563851_item	2393626	et	3	main
teda	doc_403280563851_item	2393641	et	4	main
korterit	doc_403280563851_item	2393645	et	3	main
tegin	doc_403280563851_item	2393647	et	3	main
esikus	doc_403280563851_item	2393653	et	3	main
me	doc_403280563851_item	2393656	et	4	main
hapukapsasuppi	doc_403280563851_item	2393658	et	4	main
praetud	doc_403280563851_item	2393660	et	4	main
vennaga	doc_403280563851_item	2393682	et	3	main
jalgpalli	doc_403280563851_item	2393687	et	4	main
see	doc_403280563851_item	2393688	et	3	main
aga	doc_403280563851_item	2393689	et	3	main
meeldib	doc_403280563851_item	2393690	et	3	main
neile	doc_403280563851_item	2393691	et	4	main
väga	doc_403280563851_item	2393692	et	3	main
tulin	doc_403280563851_item	2393698	et	3	main
juurde	doc_403280563851_item	2393701	et	4	main
õhtuni	doc_403280563851_item	2393705	et	3	main
mul	doc_403280563851_item	2393723	et	3	main
oli	doc_403280563851_item	2393724	et	3	main
telerit	doc_403280563851_item	2393733	et	3	main
ma	doc_403280563851_item	2393740	et	3	main
und	doc_403280563851_item	2393744	et	4	main
ma	doc_403280563851_item	2393745	et	3	main
huvitavat	doc_403280563851_item	2393747	et	4	main
raamatut	doc_403280563851_item	2393748	et	3	main
kella	doc_403280563851_item	2393749	et	4	main
oli	doc_401436695441_item	2393459	et	3	main
kivist	doc_401436695441_item	2393460	et	4	main
sirp	doc_401436695441_item	2393461	et	3	main
oli	doc_401436695441_item	2393462	et	3	main
pronksist	doc_401436695441_item	2393463	et	4	main
sellega	doc_401436695441_item	2393464	et	3	main
vilju	doc_401436695441_item	2393467	et	4	main
kasutati	doc_401436695441_item	2393470	et	4	main
oli	doc_401436695441_item	2393473	et	3	main
tähendus	doc_401436695441_item	2393475	et	4	main
ja	doc_401436695441_item	2393476	et	3	main
seda	doc_401436695441_item	2393477	et	3	main
leiti	doc_401436695441_item	2393478	et	3	main
vees	doc_401436695441_item	2393479	et	3	main
sest	doc_401436695441_item	2393480	et	4	main
et	doc_401436695441_item	2393481	et	3	main
inimesed	doc_401436695441_item	2393482	et	3	main
viskasid	doc_401436695441_item	2393483	et	4	main
teravilja	doc_401436695441_item	2393490	et	4	main
käsikivi	doc_401436695441_item	2393492	et	4	main
abil	doc_401436695441_item	2393493	et	4	main
kultuurtaimed	doc_401436695441_item	2393494	et	3	main
kasvatus	doc_401436695441_item	2393496	et	4	main
hülgepüügiga	doc_401436695441_item	2393514	et	3	main
küünlate	doc_401436695441_item	2393517	et	4	main
valmistamiseks	doc_401436695441_item	2393518	et	4	main
ühed	doc_401436695441_item	2393519	et	3	main
hõimud	doc_401436695441_item	2393520	et	4	main
vara	doc_401436695441_item	2393527	et	4	main
ja	doc_401436695441_item	2393535	et	3	main
siis	doc_401436695441_item	2393537	et	3	main
ajal	doc_401436695441_item	2393542	et	4	main
kivi	doc_401436695441_item	2393556	et	4	main
oli	doc_401436695441_item	2393558	et	3	main
kontakteerisid	doc_401436695441_item	2393575	et	4	main
volga	doc_401436695441_item	2393576	et	4	main
hõimudega	doc_401436695441_item	2393577	et	3	main
p-e	doc_401436695441_item	2393578	et	3	main
enam	doc_401436695441_item	2393579	et	4	main
skandinaaviaga	doc_401436695441_item	2393580	et	4	main
2	doc_401436695441_item	2393581	et	2	main
animism	doc_401436695441_item	2393582	et	3	main
see	doc_401436695441_item	2393583	et	3	main
on	doc_401436695441_item	2393584	et	4	main
uskumus	doc_401436695441_item	2393585	et	3	main
et	doc_401436695441_item	2393586	et	3	main
eluta	doc_401436695441_item	2393587	et	3	main
loodusel	doc_401436695441_item	2393588	et	4	main
on	doc_401436695441_item	2393589	et	4	main
ka	doc_401436695441_item	2393590	et	3	main
hing	doc_401436695441_item	2393591	et	3	main
nt	doc_401436695441_item	2393592	et	4	main
puudel	doc_401436695441_item	2393593	et	4	main
on	doc_401436695441_item	2393594	et	4	main
hing	doc_401436695441_item	2393595	et	3	main
essee	doc_403280563851_item	2393596	et	4	main
eile	doc_403280563851_item	2393597	et	3	main
oli	doc_403280563851_item	2393598	et	3	main
üks	doc_403280563851_item	2393599	et	3	main
tavaline	doc_403280563851_item	2393600	et	4	main
päev	doc_403280563851_item	2393601	et	3	main
eile	doc_403280563851_item	2393602	et	3	main
oli	doc_403280563851_item	2393603	et	3	main
laupäev	doc_403280563851_item	2393604	et	3	main
ma	doc_403280563851_item	2393605	et	3	main
veetsin	doc_403280563851_item	2393606	et	3	main
kui	doc_403280563851_item	2393609	et	3	main
kell	doc_403280563851_item	2393613	et	3	main
mulle	doc_403280563851_item	2393616	et	4	main
lamasin	doc_403280563851_item	2393622	et	3	main
meil	doc_403280563851_item	2393630	et	4	main
võileivad	doc_403280563851_item	2393632	et	3	main
ja	doc_403280563851_item	2393633	et	3	main
tee	doc_403280563851_item	2393634	et	4	main
palus	doc_403280563851_item	2393639	et	4	main
me	doc_403280563851_item	2393642	et	4	main
koristama	doc_403280563851_item	2393644	et	3	main
ma	doc_403280563851_item	2393646	et	3	main
korda	doc_403280563851_item	2393648	et	4	main
ja	doc_403280563851_item	2393659	et	3	main
ja	doc_403280563851_item	2393680	et	3	main
tahtsid	doc_403280563851_item	2393683	et	4	main
mina	doc_403280563851_item	2393696	et	4	main
aga	doc_403280563851_item	2393697	et	3	main
sõbratari	doc_403280563851_item	2393700	et	4	main
sõbranna	doc_403280563851_item	2393707	et	4	main
me	doc_403280563851_item	2393710	et	4	main
sõime	doc_403280563851_item	2393711	et	4	main
suitsukalasalatit	doc_403280563851_item	2393712	et	3	main
ja	doc_403280563851_item	2393713	et	3	main
jõime	doc_403280563851_item	2393714	et	3	main
tulin	doc_403280563851_item	2393720	et	3	main
koju	doc_403280563851_item	2393721	et	3	main
vaja	doc_403280563851_item	2393725	et	4	main
triikida	doc_403280563851_item	2393726	et	4	main
pesu	doc_403280563851_item	2393727	et	4	main
sel	doc_403280563851_item	2393728	et	3	main
kaheksateistkümneks	doc_403280563851_item	2393750	et	4	main
ma	doc_403280563851_item	2393751	et	3	main
see	doc_403280563851_item	2393753	et	3	main
tavaline	doc_403280563851_item	2393757	et	4	main
päev	doc_403280563851_item	2393758	et	3	main
ma	doc_403280563851_item	2393611	et	3	main
magada	doc_403280563851_item	2393618	et	3	main
ma	doc_403280563851_item	2393621	et	3	main
kööki	doc_403280563851_item	2393627	et	4	main
pärast	doc_403280563851_item	2393635	et	4	main
seda	doc_403280563851_item	2393636	et	3	main
minu	doc_403280563851_item	2393637	et	3	main
ja	doc_403280563851_item	2393652	et	3	main
koristamist	doc_403280563851_item	2393655	et	4	main
isa	doc_403280563851_item	2393681	et	4	main
vaadata	doc_403280563851_item	2393684	et	4	main
telerit	doc_403280563851_item	2393685	et	3	main
näidatakse	doc_403280563851_item	2393686	et	3	main
pesi	doc_403280563851_item	2393694	et	4	main
pesu	doc_403280563851_item	2393695	et	4	main
külla	doc_403280563851_item	2393699	et	4	main
ajasime	doc_403280563851_item	2393703	et	3	main
teed	doc_403280563851_item	2393715	et	4	main
kella	doc_403280563851_item	2393717	et	4	main
seitsmeks	doc_403280563851_item	2393718	et	3	main
tagasi	doc_403280563851_item	2393722	et	3	main
ajal	doc_403280563851_item	2393729	et	4	main
kell	doc_403280563851_item	2393738	et	3	main
enne	doc_403280563851_item	2393743	et	4	main
oli	doc_403280563851_item	2393754	et	3	main
üks	doc_403280563851_item	2393756	et	3	main
ja	doc_403280563851_item	2393625	et	3	main
hommikusöögiks	doc_403280563851_item	2393629	et	3	main
aitama	doc_403280563851_item	2393640	et	3	main
pärast	doc_403280563851_item	2393654	et	4	main
kartulit	doc_403280563851_item	2393661	et	3	main
lihaga	doc_403280563851_item	2393662	et	3	main
sel	doc_403280563851_item	2393663	et	3	main
ajal	doc_403280563851_item	2393664	et	4	main
minu	doc_403280563851_item	2393665	et	3	main
vend	doc_403280563851_item	2393666	et	3	main
tegeles	doc_403280563851_item	2393667	et	3	main
arvutiga	doc_403280563851_item	2393668	et	4	main
isa	doc_403280563851_item	2393669	et	4	main
aga	doc_403280563851_item	2393670	et	3	main
oli	doc_403280563851_item	2393671	et	3	main
tööl	doc_403280563851_item	2393672	et	3	main
ta	doc_403280563851_item	2393673	et	4	main
tuli	doc_403280563851_item	2393674	et	4	main
koju	doc_403280563851_item	2393675	et	3	main
lõunaks	doc_403280563851_item	2393676	et	4	main
me	doc_403280563851_item	2393677	et	4	main
sõime	doc_403280563851_item	2393678	et	4	main
üheskoos	doc_403280563851_item	2393679	et	3	main
ema	doc_403280563851_item	2393693	et	4	main
juttu	doc_403280563851_item	2393704	et	4	main
minu	doc_403280563851_item	2393706	et	3	main
pirukatega	doc_403280563851_item	2393716	et	3	main
pere	doc_403280563851_item	2393731	et	4	main
ja	doc_403280563851_item	2393734	et	3	main
kümme	doc_403280563851_item	2393739	et	3	main
uinusin	doc_403280563851_item	2393752	et	3	main
minu	doc_403280563851_item	2393755	et	3	main
ema	doc_403280563851_item	2393735	et	4	main
veel	doc_403280563851_item	2393736	et	4	main
kudus	doc_403280563851_item	2393737	et	4	main
läksin	doc_403280563851_item	2393741	et	3	main
magama	doc_403280563851_item	2393742	et	3	main
lugesin	doc_403280563851_item	2393746	et	3	main
ela	doc_40918597572_item	2396087	et	4	main
viimastel	doc_40918597572_item	2396094	et	3	main
nähtus	doc_40918597572_item	2396098	et	4	main
teda	doc_40918597572_item	2396124	et	4	main
autojuhtidele	doc_40918597572_item	2396126	et	3	main
toonud	doc_40918597572_item	2396128	et	4	main
ka	doc_40918597572_item	2396133	et	3	main
mugavam	doc_40918597572_item	2396145	et	4	main
sõita	doc_40918597572_item	2396147	et	3	main
teedele	doc_40918597572_item	2396154	et	3	main
soda	doc_40918597572_item	2396155	et	4	main
ja	doc_40918597572_item	2396157	et	3	main
hingasid	doc_40918597572_item	2396160	et	4	main
raskelt	doc_40918597572_item	2396161	et	4	main
nurkadest	doc_40918597572_item	2396165	et	3	main
välja	doc_40918597572_item	2396166	et	4	main
ja	doc_40918597572_item	2396168	et	3	main
tõeline	doc_40918597572_item	2396207	et	4	main
olid	doc_40918597572_item	2396211	et	4	main
nimetab	doc_40918597572_item	2396215	et	3	main
sa	doc_40918597572_item	2396229	et	3	main
suudadki	doc_40918597572_item	2396230	et	3	main
sellise	doc_40918597572_item	2396232	et	4	main
mõnu	doc_40918597572_item	2396235	et	4	main
kuhu	doc_40918597572_item	2396243	et	3	main
armastajaid	doc_40918597572_item	2396247	et	4	main
talv	doc_40918597572_item	2396250	et	3	main
tore	doc_40918597572_item	2396252	et	3	main
pakasel	doc_40918597572_item	2396081	et	3	main
kuid	doc_40918597572_item	2396090	et	4	main
lumine	doc_40918597572_item	2396091	et	4	main
aastatel	doc_40918597572_item	2396095	et	4	main
haruldane	doc_40918597572_item	2396097	et	3	main
ta	doc_40918597572_item	2396103	et	4	main
või	doc_40918597572_item	2396107	et	4	main
mitte	doc_40918597572_item	2396108	et	3	main
ja	doc_40918597572_item	2396109	et	3	main
lõpuks	doc_40918597572_item	2396110	et	4	main
unustanud	doc_40918597572_item	2396125	et	4	main
ei	doc_40918597572_item	2396127	et	4	main
muidugi	doc_40918597572_item	2396130	et	4	main
mingit	doc_40918597572_item	2396131	et	3	main
ei	doc_40918597572_item	2396135	et	4	main
on	doc_40918597572_item	2396143	et	4	main
ja	doc_40918597572_item	2396152	et	3	main
puisates	doc_40918597572_item	2396153	et	4	main
rajama	doc_40918597572_item	2396171	et	3	main
tulid	doc_40918597572_item	2396202	et	4	main
välja	doc_40918597572_item	2396203	et	4	main
tihti	doc_40918597572_item	2396216	et	3	main
suusatada	doc_40918597572_item	2396222	et	3	main
juures	doc_40918597572_item	2396236	et	4	main
lärmata	doc_40918597572_item	2396237	et	4	main
aitas	doc_40918597572_item	2396238	et	3	main
tuli	doc_40918597572_item	2396244	et	4	main
uisutamise	doc_40918597572_item	2396246	et	4	main
ikkagi	doc_40918597572_item	2396249	et	4	main
on	doc_40918597572_item	2396251	et	4	main
kord	doc_40918597572_item	2396080	et	4	main
ja	doc_40918597572_item	2396082	et	3	main
ajal	doc_40918597572_item	2396084	et	4	main
meil	doc_40918597572_item	2396096	et	4	main
sel	doc_40918597572_item	2396100	et	3	main
mõtles	doc_40918597572_item	2396102	et	3	main
kaua	doc_40918597572_item	2396104	et	3	main
kas	doc_40918597572_item	2396105	et	3	main
tulla	doc_40918597572_item	2396106	et	3	main
et	doc_40918597572_item	2396121	et	3	main
see	doc_40918597572_item	2396129	et	3	main
kommunaaltöötajad	doc_40918597572_item	2396134	et	3	main
hüppanud	doc_40918597572_item	2396136	et	4	main
õnnest	doc_40918597572_item	2396138	et	4	main
sest	doc_40918597572_item	2396139	et	4	main
istuda	doc_40918597572_item	2396140	et	3	main
ja	doc_40918597572_item	2396141	et	3	main
palju	doc_40918597572_item	2396144	et	4	main
kui	doc_40918597572_item	2396146	et	3	main
kojamehed	doc_40918597572_item	2396156	et	3	main
ja	doc_40918597572_item	2396162	et	3	main
võtsid	doc_40918597572_item	2396163	et	4	main
labidad	doc_40918597572_item	2396167	et	3	main
hakkasid	doc_40918597572_item	2396169	et	4	main
teid	doc_40918597572_item	2396170	et	4	main
värskele	doc_40918597572_item	2396204	et	4	main
õhule	doc_40918597572_item	2396205	et	3	main
ja	doc_40918597572_item	2396209	et	3	main
mida	doc_40918597572_item	2396213	et	4	main
on	doc_40918597572_item	2396219	et	4	main
essee	doc_40918597572_item	2396079	et	4	main
küll	doc_40918597572_item	2396088	et	4	main
lõunas	doc_40918597572_item	2396089	et	3	main
seda	doc_40918597572_item	2396112	et	3	main
küll	doc_40918597572_item	2396113	et	4	main
alles	doc_40918597572_item	2396114	et	3	main
kalendritalve	doc_40918597572_item	2396115	et	4	main
teisel	doc_40918597572_item	2396116	et	4	main
poolel	doc_40918597572_item	2396117	et	4	main
ja	doc_40918597572_item	2396118	et	3	main
tuli	doc_40918597572_item	2396119	et	4	main
välja	doc_40918597572_item	2396120	et	4	main
külmal	doc_40918597572_item	2396083	et	3	main
me	doc_40918597572_item	2396085	et	4	main
ei	doc_40918597572_item	2396086	et	4	main
talv	doc_40918597572_item	2396092	et	3	main
on	doc_40918597572_item	2396093	et	4	main
ka	doc_40918597572_item	2396099	et	3	main
aastal	doc_40918597572_item	2396101	et	3	main
tuligi	doc_40918597572_item	2396111	et	4	main
pole	doc_40918597572_item	2396123	et	3	main
rõõmu	doc_40918597572_item	2396132	et	4	main
öistel	doc_40918597572_item	2396148	et	4	main
tänavatel	doc_40918597572_item	2396149	et	4	main
korjates	doc_40918597572_item	2396150	et	3	main
lund	doc_40918597572_item	2396151	et	3	main
lärm	doc_40918597572_item	2396208	et	3	main
rahvas	doc_40918597572_item	2396214	et	4	main
tõlge	doc_40918597574_item	2396463	et	3	main
luigetiigi	doc_40918597574_item	2396470	et	3	main
kohvikute	doc_40918597574_item	2396478	et	4	main
traditsioone	doc_40918597574_item	2396479	et	3	main
kuuluvas	doc_40918597574_item	2396482	et	4	main
asuv	doc_40918597574_item	2396486	et	4	main
suveterrass	doc_40918597574_item	2396492	et	3	main
inimesele	doc_40918597574_item	2396495	et	3	main
miljööle	doc_40918597574_item	2396508	et	3	main
suvel	doc_40918597574_item	2396509	et	3	main
pargist	doc_40918597574_item	2396521	et	3	main
luigetiigi	doc_40918597574_item	2396528	et	3	main
mln	doc_40918597574_item	2396539	et	4	main
teostas	doc_40918597574_item	2396541	et	3	main
ehitusfirma	doc_40918597574_item	2396542	et	4	main
tetsmann	doc_40918597574_item	2396548	et	4	main
sisekujundamisel	doc_40918597574_item	2396551	et	3	main
kohvik	doc_40918597574_item	2396552	et	3	main
1000-1800	doc_40918597574_item	2396561	et	2	main
abilinnapea	doc_40918597574_item	2396562	et	4	main
olga	doc_40918597574_item	2396563	et	4	main
parkmuuseumiks	doc_40918597574_item	2396576	et	3	main
hannsen-tammsaare	doc_40918597574_item	2396582	et	3	main
vilde	doc_40918597574_item	2396585	et	4	main
lisas	doc_40918597574_item	2396600	et	4	main
esimest	doc_40918597575_item	2396616	et	4	main
keegi	doc_40918597572_item	2396122	et	4	main
suurest	doc_40918597572_item	2396137	et	4	main
oodata	doc_40918597572_item	2396142	et	4	main
eramajade	doc_40918597572_item	2396158	et	3	main
omanikud	doc_40918597572_item	2396159	et	3	main
kaugetest	doc_40918597572_item	2396164	et	4	main
ja	doc_40918597572_item	2396172	et	3	main
hoove	doc_40918597572_item	2396173	et	3	main
puhastama	doc_40918597572_item	2396174	et	3	main
kes	doc_40918597572_item	2396175	et	4	main
aga	doc_40918597572_item	2396176	et	3	main
tundis	doc_40918597572_item	2396177	et	3	main
siiralt	doc_40918597572_item	2396178	et	4	main
rõõmu	doc_40918597572_item	2396179	et	4	main
valgest	doc_40918597572_item	2396180	et	4	main
katest	doc_40918597572_item	2396181	et	3	main
ja	doc_40918597572_item	2396182	et	3	main
pakasest	doc_40918597572_item	2396183	et	4	main
olid	doc_40918597572_item	2396184	et	4	main
suusatajad	doc_40918597572_item	2396185	et	4	main
ja	doc_40918597572_item	2396186	et	3	main
talvise	doc_40918597572_item	2396187	et	4	main
kalapüügi	doc_40918597572_item	2396188	et	4	main
armastajad	doc_40918597572_item	2396189	et	4	main
igati	doc_40918597572_item	2396190	et	3	main
kasutusel	doc_40918597572_item	2396191	et	4	main
oli	doc_40918597572_item	2396192	et	3	main
suusarada	doc_40918597572_item	2396193	et	4	main
raekülas	doc_40918597572_item	2396194	et	3	main
nii	doc_40918597572_item	2396195	et	3	main
lapsed	doc_40918597572_item	2396196	et	3	main
kui	doc_40918597572_item	2396197	et	3	main
täiskasvanud	doc_40918597572_item	2396198	et	4	main
ning	doc_40918597572_item	2396199	et	3	main
isegi	doc_40918597572_item	2396200	et	4	main
loomad	doc_40918597572_item	2396201	et	3	main
kuid	doc_40918597572_item	2396206	et	4	main
kära	doc_40918597572_item	2396210	et	4	main
munamäel	doc_40918597572_item	2396212	et	3	main
lastemäeks	doc_40918597572_item	2396217	et	3	main
siin	doc_40918597572_item	2396218	et	4	main
alati	doc_40918597572_item	2396220	et	4	main
ja	doc_40918597572_item	2396227	et	3	main
kuidas	doc_40918597572_item	2396228	et	3	main
vaikida	doc_40918597572_item	2396231	et	4	main
kiiruse	doc_40918597572_item	2396233	et	4	main
ja	doc_40918597572_item	2396234	et	3	main
kõrval	doc_40918597572_item	2396240	et	4	main
asuv	doc_40918597572_item	2396241	et	4	main
liuväli	doc_40918597572_item	2396242	et	3	main
rohkesti	doc_40918597572_item	2396245	et	3	main
ja	doc_40918597572_item	2396248	et	3	main
kohvik	doc_40918597574_item	2396465	et	3	main
kadrioru	doc_40918597574_item	2396468	et	3	main
viini	doc_40918597574_item	2396477	et	4	main
lossikompleksi	doc_40918597574_item	2396481	et	4	main
valvurimajakeses	doc_40918597574_item	2396483	et	4	main
weizenbergi	doc_40918597574_item	2396484	et	4	main
22	doc_40918597574_item	2396485	et	2	main
külastajale	doc_40918597574_item	2396491	et	4	main
seest	doc_40918597574_item	2396496	et	3	main
gravüüridega	doc_40918597574_item	2396502	et	3	main
plaanitakse	doc_40918597574_item	2396510	et	4	main
armastatud	doc_40918597572_item	2396221	et	4	main
meie	doc_40918597572_item	2396223	et	4	main
linna	doc_40918597572_item	2396224	et	4	main
noored	doc_40918597572_item	2396225	et	3	main
elanikud	doc_40918597572_item	2396226	et	3	main
ka	doc_40918597572_item	2396239	et	3	main
tiigiäärne	doc_40918597574_item	2396464	et	3	main
ääres	doc_40918597574_item	2396471	et	4	main
park	doc_40918597574_item	2396473	et	3	main
mis	doc_40918597574_item	2396475	et	4	main
on	doc_40918597574_item	2396476	et	4	main
kohvik	doc_40918597574_item	2396487	et	3	main
on	doc_40918597574_item	2396488	et	4	main
aga	doc_40918597574_item	2396493	et	3	main
ajaloolise	doc_40918597574_item	2396507	et	4	main
pargis	doc_40918597574_item	2396525	et	3	main
sisetööd	doc_40918597574_item	2396534	et	4	main
mille	doc_40918597574_item	2396535	et	3	main
oli	doc_40918597574_item	2396537	et	3	main
krooni	doc_40918597574_item	2396540	et	4	main
on	doc_40918597574_item	2396553	et	4	main
laupäeviti	doc_40918597574_item	2396557	et	4	main
sõnul	doc_40918597574_item	2396565	et	3	main
vastavalt	doc_40918597574_item	2396572	et	4	main
millele	doc_40918597574_item	2396573	et	3	main
muutub	doc_40918597574_item	2396574	et	3	main
park	doc_40918597574_item	2396575	et	3	main
ja	doc_40918597574_item	2396591	et	3	main
harjutus	doc_40918597575_item	2396602	et	4	main
tartu	doc_40918597575_item	2396604	et	4	main
tartust	doc_40918597575_item	2396612	et	3	main
1030	doc_40918597575_item	2396620	et	2	main
aastal	doc_40918597575_item	2396621	et	3	main
on	doc_40918597575_item	2396624	et	4	main
ka	doc_40918597575_item	2396626	et	3	main
dorpatiks	doc_40918597575_item	2396629	et	4	main
5	doc_40918597575_item	2396630	et	2	main
16	doc_40918597575_item	2396639	et	2	main
gustav	doc_40918597575_item	2396653	et	4	main
kõige	doc_40918597575_item	2396672	et	4	main
tõlge	doc_40918597576_item	2396677	et	3	main
raamat	doc_40918597576_item	2396686	et	3	main
kinno	doc_40918597576_item	2396701	et	3	main
6	doc_40918597576_item	2396709	et	2	main
püksid	doc_40918597576_item	2396713	et	3	main
ja	doc_40918597576_item	2396715	et	3	main
elanud	doc_40918597576_item	2396722	et	4	main
aastat	doc_40918597576_item	2396725	et	3	main
ma	doc_40918597576_item	2396727	et	3	main
olen	doc_40918597576_item	2396728	et	3	main
seal	doc_40918597576_item	2396729	et	4	main
pühapäeval	doc_40918597574_item	2396466	et	3	main
kohvik	doc_40918597574_item	2396472	et	3	main
cafe	doc_40918597574_item	2396474	et	4	main
järgiv	doc_40918597574_item	2396480	et	4	main
mõeldud	doc_40918597574_item	2396489	et	4	main
40-le	doc_40918597574_item	2396490	et	3	main
on	doc_40918597574_item	2396497	et	4	main
kaunistatud	doc_40918597574_item	2396499	et	4	main
pargivaadetega	doc_40918597574_item	2396500	et	3	main
riietus	doc_40918597574_item	2396504	et	4	main
vastab	doc_40918597574_item	2396505	et	3	main
kavatsetakse	doc_40918597574_item	2396523	et	3	main
kontserte	doc_40918597574_item	2396526	et	3	main
avati	doc_40918597574_item	2396467	et	3	main
pargis	doc_40918597574_item	2396469	et	3	main
60-le	doc_40918597574_item	2396494	et	3	main
kohvik	doc_40918597574_item	2396498	et	3	main
vanade	doc_40918597574_item	2396501	et	3	main
ettekandjate	doc_40918597574_item	2396503	et	3	main
pargi	doc_40918597574_item	2396506	et	4	main
pargikülastajatele	doc_40918597574_item	2396511	et	3	main
müüa	doc_40918597574_item	2396512	et	3	main
piknikukorve	doc_40918597574_item	2396513	et	3	main
samuti	doc_40918597574_item	2396514	et	3	main
hakatakse	doc_40918597574_item	2396515	et	3	main
müüma	doc_40918597574_item	2396516	et	3	main
seal	doc_40918597574_item	2396517	et	4	main
brošüüre	doc_40918597574_item	2396518	et	2	main
ja	doc_40918597574_item	2396519	et	3	main
kaarte	doc_40918597574_item	2396520	et	4	main
tulevikus	doc_40918597574_item	2396522	et	4	main
väärtus	doc_40918597574_item	2396536	et	3	main
2	doc_40918597574_item	2396538	et	2	main
anna	doc_40918597574_item	2396547	et	4	main
võttis	doc_40918597574_item	2396549	et	3	main
830-2000	doc_40918597574_item	2396556	et	2	main
ja	doc_40918597574_item	2396559	et	3	main
pühapäeviti	doc_40918597574_item	2396560	et	4	main
pargikohvik	doc_40918597574_item	2396566	et	3	main
loodud	doc_40918597574_item	2396568	et	4	main
arenguprogrammi	doc_40918597574_item	2396570	et	4	main
raamides	doc_40918597574_item	2396571	et	4	main
anton	doc_40918597574_item	2396581	et	4	main
väliskunsti	doc_40918597574_item	2396589	et	4	main
kunstimuuseum	doc_40918597574_item	2396593	et	3	main
on	doc_40918597574_item	2396595	et	4	main
lõuna-eestis	doc_40918597575_item	2396606	et	3	main
kaldal	doc_40918597575_item	2396608	et	3	main
emajõgi	doc_40918597575_item	2396610	et	3	main
läbi	doc_40918597575_item	2396613	et	4	main
tartut	doc_40918597575_item	2396615	et	3	main
dokumentides	doc_40918597575_item	2396618	et	3	main
palju	doc_40918597575_item	2396631	et	4	main
rikkaid	doc_40918597575_item	2396632	et	4	main
6	doc_40918597575_item	2396641	et	2	main
tartu	doc_40918597575_item	2396642	et	4	main
on	doc_40918597575_item	2396644	et	4	main
kolmsada	doc_40918597575_item	2396645	et	4	main
rahvusteater	doc_40918597575_item	2396659	et	3	main
vanemuine	doc_40918597575_item	2396660	et	4	main
tartus	doc_40918597575_item	2396662	et	3	main
umbes	doc_40918597575_item	2396664	et	4	main
sada	doc_40918597575_item	2396665	et	4	main
suurem	doc_40918597575_item	2396673	et	4	main
linn	doc_40918597575_item	2396674	et	3	main
kollane	doc_40918597576_item	2396685	et	4	main
oleks	doc_40918597576_item	2396692	et	3	main
5	doc_40918597576_item	2396704	et	2	main
pannen	doc_40918597576_item	2396711	et	4	main
on	doc_40918597576_item	2396721	et	4	main
glasgows	doc_40918597576_item	2396723	et	4	main
kaks	doc_40918597576_item	2396724	et	3	main
8	doc_40918597576_item	2396726	et	2	main
kohvi	doc_40918597576_item	2396736	et	4	main
piimaga	doc_40918597576_item	2396737	et	3	main
ja	doc_40918597576_item	2396738	et	3	main
suukrata	doc_40918597576_item	2396739	et	4	main
väike	doc_40918597577_item	2396748	et	4	main
aga	doc_40918597577_item	2396749	et	3	main
on	doc_40918597577_item	2396754	et	4	main
glasgows	doc_40918597577_item	2396763	et	4	main
inimest	doc_40918597577_item	2396769	et	3	main
edinburghis	doc_40918597577_item	2396770	et	4	main
korraldada	doc_40918597574_item	2396524	et	3	main
jõululaati	doc_40918597574_item	2396527	et	4	main
ääres	doc_40918597574_item	2396529	et	4	main
ja	doc_40918597574_item	2396530	et	3	main
teisi	doc_40918597574_item	2396531	et	4	main
üritusi	doc_40918597574_item	2396532	et	4	main
ehitus	doc_40918597574_item	2396544	et	4	main
as	doc_40918597574_item	2396545	et	4	main
on	doc_40918597574_item	2396567	et	4	main
pargi	doc_40918597574_item	2396577	et	4	main
territooriumil	doc_40918597574_item	2396578	et	3	main
juba	doc_40918597574_item	2396580	et	3	main
majamuuseum	doc_40918597574_item	2396583	et	3	main
muuseum	doc_40918597574_item	2396590	et	3	main
eesti	doc_40918597574_item	2396592	et	4	main
järjekorras	doc_40918597574_item	2396594	et	3	main
vene	doc_40918597574_item	2396596	et	4	main
muuseum	doc_40918597574_item	2396597	et	3	main
ja	doc_40918597574_item	2396598	et	3	main
lastemuuseum	doc_40918597574_item	2396599	et	3	main
1	doc_40918597575_item	2396603	et	2	main
3	doc_40918597575_item	2396614	et	2	main
korda	doc_40918597575_item	2396617	et	4	main
sajandil	doc_40918597575_item	2396640	et	3	main
ülikool	doc_40918597575_item	2396643	et	4	main
adolf	doc_40918597575_item	2396654	et	4	main
asutas	doc_40918597575_item	2396655	et	3	main
tartusse	doc_40918597575_item	2396656	et	3	main
1	doc_40918597576_item	2396678	et	2	main
3	doc_40918597576_item	2396689	et	2	main
täna	doc_40918597576_item	2396702	et	4	main
ei	doc_40918597576_item	2396706	et	4	main
kased	doc_40918597576_item	2396708	et	3	main
jalge	doc_40918597576_item	2396714	et	4	main
sinise	doc_40918597576_item	2396716	et	4	main
t-särgi	doc_40918597576_item	2396717	et	4	main
kümne	doc_40918597576_item	2396730	et	4	main
10	doc_40918597576_item	2396740	et	2	main
kas	doc_40918597576_item	2396741	et	3	main
sul	doc_40918597576_item	2396742	et	3	main
on	doc_40918597576_item	2396743	et	4	main
on	doc_40918597577_item	2396747	et	4	main
edinburgh	doc_40918597577_item	2396756	et	4	main
asub	doc_40918597577_item	2396757	et	3	main
suurem	doc_40918597577_item	2396760	et	4	main
ainult	doc_40918597577_item	2396772	et	4	main
nelisada	doc_40918597577_item	2396773	et	4	main
asub	doc_40918597578_item	2396810	et	3	main
eestis	doc_40918597578_item	2396812	et	3	main
emajõgi	doc_40918597578_item	2396814	et	3	main
tartut	doc_40918597578_item	2396819	et	3	main
nimesid	doc_40918597578_item	2396831	et	3	main
palju	doc_40918597578_item	2396842	et	4	main
tartu	doc_40918597578_item	2396847	et	4	main
ülikool	doc_40918597578_item	2396848	et	4	main
seitsekümmend	doc_40918597578_item	2396852	et	4	main
7	doc_40918597578_item	2396856	et	2	main
sada	doc_40918597578_item	2396869	et	4	main
eesti	doc_40918597578_item	2396877	et	4	main
tõlge	doc_40918597579_item	2396881	et	3	main
london	doc_40918597579_item	2396883	et	4	main
on	doc_40918597579_item	2396884	et	4	main
peal	doc_40918597579_item	2396893	et	4	main
3	doc_40918597579_item	2396894	et	2	main
rohkem	doc_40918597579_item	2396898	et	4	main
armastaks	doc_40918597579_item	2396901	et	3	main
eestis	doc_40918597579_item	2396902	et	3	main
hoone	doc_40918597574_item	2396533	et	4	main
kentel	doc_40918597574_item	2396543	et	4	main
arhitekt	doc_40918597574_item	2396546	et	3	main
osa	doc_40918597574_item	2396550	et	4	main
avatud	doc_40918597574_item	2396554	et	4	main
argipäeviti	doc_40918597574_item	2396555	et	3	main
900-1900	doc_40918597574_item	2396558	et	2	main
sõtniku	doc_40918597574_item	2396564	et	4	main
kadrioru	doc_40918597574_item	2396569	et	3	main
asuvad	doc_40918597574_item	2396579	et	4	main
eduard	doc_40918597574_item	2396584	et	4	main
majamuuseum	doc_40918597574_item	2396586	et	3	main
mikkeli	doc_40918597574_item	2396587	et	4	main
muuseum	doc_40918597574_item	2396588	et	3	main
sõtnik	doc_40918597574_item	2396601	et	4	main
asub	doc_40918597575_item	2396605	et	3	main
emajõe	doc_40918597575_item	2396607	et	3	main
2	doc_40918597575_item	2396609	et	2	main
voolab	doc_40918597575_item	2396611	et	3	main
mainiti	doc_40918597575_item	2396619	et	3	main
4	doc_40918597575_item	2396622	et	2	main
nimetatud	doc_40918597575_item	2396625	et	4	main
tarbatuks	doc_40918597575_item	2396627	et	4	main
ja	doc_40918597575_item	2396628	et	3	main
elas	doc_40918597575_item	2396635	et	3	main
tartus	doc_40918597575_item	2396636	et	3	main
keskajal	doc_40918597575_item	2396637	et	3	main
aastat	doc_40918597575_item	2396648	et	3	main
7	doc_40918597575_item	2396650	et	2	main
rootsi	doc_40918597575_item	2396651	et	4	main
kuningas	doc_40918597575_item	2396652	et	4	main
8	doc_40918597575_item	2396658	et	2	main
tuhat	doc_40918597575_item	2396666	et	4	main
inimest	doc_40918597575_item	2396667	et	3	main
elab	doc_40918597575_item	2396668	et	3	main
tartus	doc_40918597575_item	2396669	et	3	main
10	doc_40918597575_item	2396670	et	2	main
on	doc_40918597575_item	2396675	et	4	main
london	doc_40918597576_item	2396679	et	4	main
suurem	doc_40918597576_item	2396681	et	4	main
kui	doc_40918597576_item	2396682	et	3	main
glasgow	doc_40918597576_item	2396683	et	4	main
2	doc_40918597576_item	2396684	et	2	main
laual	doc_40918597576_item	2396688	et	3	main
kui	doc_40918597576_item	2396690	et	3	main
õhtul	doc_40918597576_item	2396703	et	3	main
ma	doc_40918597576_item	2396710	et	3	main
pruunid	doc_40918597576_item	2396712	et	3	main
pärast	doc_40918597576_item	2396732	et	4	main
mulle	doc_40918597576_item	2396734	et	4	main
meeldis	doc_40918597576_item	2396735	et	3	main
essee	doc_40918597577_item	2396745	et	4	main
šotimaa	doc_40918597577_item	2396752	et	2	main
edinburgh	doc_40918597577_item	2396755	et	4	main
on	doc_40918597577_item	2396762	et	4	main
glasgows	doc_40918597577_item	2396764	et	4	main
elab	doc_40918597577_item	2396765	et	3	main
umbes	doc_40918597577_item	2396766	et	4	main
tartu	doc_40918597578_item	2396809	et	4	main
lõuna	doc_40918597578_item	2396811	et	4	main
2	doc_40918597578_item	2396813	et	2	main
3	doc_40918597578_item	2396818	et	2	main
jaroslav	doc_40918597578_item	2396829	et	4	main
kuus	doc_40918597578_item	2396853	et	4	main
vana	doc_40918597578_item	2396855	et	4	main
gustav	doc_40918597578_item	2396857	et	4	main
asub	doc_40918597578_item	2396865	et	3	main
9	doc_40918597578_item	2396867	et	2	main
inimest	doc_40918597578_item	2396871	et	3	main
tallinn	doc_40918597578_item	2396875	et	4	main
suurem	doc_40918597578_item	2396879	et	4	main
mul	doc_40918597579_item	2396896	et	3	main
seal	doc_40918597579_item	2396932	et	4	main
9	doc_40918597579_item	2396935	et	2	main
mulle	doc_40918597579_item	2396936	et	4	main
ja	doc_40918597579_item	2396940	et	3	main
suhkreta	doc_40918597579_item	2396941	et	4	main
essee	doc_40918597580_item	2396947	et	4	main
on	doc_40918597580_item	2396949	et	4	main
on	doc_40918597580_item	2396962	et	4	main
kõige	doc_40918597580_item	2396963	et	4	main
glasgow	doc_40918597580_item	2396967	et	4	main
keelt	doc_40918597580_item	2396977	et	4	main
seal	doc_40918597580_item	2396978	et	4	main
elab	doc_40918597580_item	2396979	et	3	main
umbes	doc_40918597580_item	2396980	et	4	main
tartut	doc_40918597575_item	2396623	et	3	main
saksa	doc_40918597575_item	2396633	et	4	main
kaupmehi	doc_40918597575_item	2396634	et	3	main
14	doc_40918597575_item	2396638	et	2	main
seitsekümmend	doc_40918597575_item	2396646	et	4	main
kuus	doc_40918597575_item	2396647	et	4	main
vana	doc_40918597575_item	2396649	et	4	main
ülikooli	doc_40918597575_item	2396657	et	4	main
asub	doc_40918597575_item	2396661	et	3	main
9	doc_40918597575_item	2396663	et	2	main
eesti	doc_40918597575_item	2396671	et	4	main
tallinn	doc_40918597575_item	2396676	et	4	main
on	doc_40918597576_item	2396680	et	4	main
on	doc_40918597576_item	2396687	et	4	main
mul	doc_40918597576_item	2396691	et	3	main
rohkem	doc_40918597576_item	2396693	et	4	main
raha	doc_40918597576_item	2396694	et	4	main
ma	doc_40918597576_item	2396695	et	3	main
tahaksin	doc_40918597576_item	2396696	et	3	main
reisida	doc_40918597576_item	2396697	et	3	main
eestisse	doc_40918597576_item	2396698	et	4	main
4	doc_40918597576_item	2396699	et	2	main
lähme	doc_40918597576_item	2396700	et	3	main
mulle	doc_40918597576_item	2396705	et	4	main
meeldi	doc_40918597576_item	2396707	et	4	main
selga	doc_40918597576_item	2396718	et	4	main
7	doc_40918597576_item	2396719	et	2	main
mari	doc_40918597576_item	2396720	et	4	main
minutit	doc_40918597576_item	2396731	et	3	main
9	doc_40918597576_item	2396733	et	2	main
mašina	doc_40918597576_item	2396744	et	2	main
šotimaa	doc_40918597577_item	2396746	et	2	main
ida-šotimaal	doc_40918597577_item	2396758	et	2	main
kõige	doc_40918597577_item	2396759	et	4	main
kuussada	doc_40918597577_item	2396767	et	4	main
tuhat	doc_40918597577_item	2396774	et	4	main
kõige	doc_40918597577_item	2396776	et	4	main
ilusam	doc_40918597577_item	2396777	et	4	main
linn	doc_40918597577_item	2396778	et	3	main
šotimaal	doc_40918597577_item	2396779	et	2	main
on	doc_40918597577_item	2396780	et	4	main
stirling	doc_40918597577_item	2396781	et	4	main
stirling	doc_40918597577_item	2396782	et	4	main
asub	doc_40918597577_item	2396783	et	3	main
keske-šotimaal	doc_40918597577_item	2396784	et	2	main
forthi	doc_40918597577_item	2396785	et	4	main
jõe	doc_40918597577_item	2396786	et	3	main
kaldal	doc_40918597577_item	2396787	et	3	main
linna	doc_40918597577_item	2396788	et	4	main
ajaluga	doc_40918597577_item	2396789	et	4	main
on	doc_40918597577_item	2396790	et	4	main
väga	doc_40918597577_item	2396791	et	3	main
huvitav	doc_40918597577_item	2396792	et	4	main
põhja	doc_40918597577_item	2396793	et	4	main
šotimaal	doc_40918597577_item	2396794	et	2	main
on	doc_40918597577_item	2396795	et	4	main
mägid	doc_40918597577_item	2396796	et	4	main
metsad	doc_40918597577_item	2396797	et	3	main
järvid	doc_40918597577_item	2396798	et	3	main
ja	doc_40918597577_item	2396799	et	3	main
jõed	doc_40918597577_item	2396800	et	3	main
suvel	doc_40918597577_item	2396801	et	3	main
palju	doc_40918597577_item	2396802	et	4	main
inimesi	doc_40918597577_item	2396803	et	4	main
sõidas	doc_40918597577_item	2396804	et	4	main
sisse	doc_40918597577_item	2396805	et	4	main
puhkamas	doc_40918597577_item	2396806	et	3	main
harjutus	doc_40918597578_item	2396807	et	4	main
ilus	doc_40918597577_item	2396750	et	4	main
maa	doc_40918597577_item	2396751	et	4	main
pealinn	doc_40918597577_item	2396753	et	3	main
linn	doc_40918597577_item	2396761	et	3	main
tuhat	doc_40918597577_item	2396768	et	4	main
1	doc_40918597578_item	2396808	et	2	main
läbi	doc_40918597578_item	2396816	et	4	main
korda	doc_40918597578_item	2396821	et	4	main
mainiti	doc_40918597578_item	2396823	et	3	main
aastast	doc_40918597578_item	2396825	et	4	main
rikkaid	doc_40918597578_item	2396843	et	4	main
aastat	doc_40918597578_item	2396854	et	3	main
adolf	doc_40918597578_item	2396858	et	4	main
asutas	doc_40918597578_item	2396859	et	3	main
tartusse	doc_40918597578_item	2396860	et	3	main
ülikooli	doc_40918597578_item	2396861	et	4	main
8	doc_40918597578_item	2396862	et	2	main
rahvusteater	doc_40918597578_item	2396863	et	3	main
tartus	doc_40918597578_item	2396866	et	3	main
umbes	doc_40918597578_item	2396868	et	4	main
tartus	doc_40918597578_item	2396873	et	3	main
on	doc_40918597578_item	2396876	et	4	main
kui	doc_40918597579_item	2396895	et	3	main
raha	doc_40918597579_item	2396899	et	4	main
ma	doc_40918597579_item	2396900	et	3	main
reisida	doc_40918597579_item	2396903	et	3	main
kümne	doc_40918597579_item	2396933	et	4	main
minutit	doc_40918597579_item	2396934	et	3	main
šotimaa	doc_40918597580_item	2396948	et	2	main
väike	doc_40918597580_item	2396950	et	4	main
on	doc_40918597580_item	2396957	et	4	main
suur	doc_40918597580_item	2396958	et	3	main
glasgow	doc_40918597580_item	2396961	et	4	main
on	doc_40918597580_item	2396968	et	4	main
me	doc_40918597580_item	2396971	et	4	main
inglise	doc_40918597580_item	2396973	et	4	main
keelt	doc_40918597580_item	2396974	et	4	main
ja	doc_40918597580_item	2396975	et	3	main
gaeli	doc_40918597580_item	2396976	et	4	main
million	doc_40918597580_item	2396982	et	4	main
ilm	doc_40918597580_item	2396986	et	3	main
kraadi	doc_40918597580_item	2396995	et	4	main
on	doc_40918597580_item	2396998	et	4	main
šotimaa	doc_40918597580_item	2397004	et	2	main
on	doc_40918597580_item	2397010	et	4	main
kirjeldus	doc_41618862214_item	2397015	et	4	main
kirjutama	doc_41618862214_item	2397019	et	3	main
välja	doc_41618862214_item	2397020	et	4	main
elab	doc_40918597577_item	2396771	et	3	main
inimest	doc_40918597577_item	2396775	et	3	main
tartust	doc_40918597578_item	2396815	et	3	main
voolab	doc_40918597578_item	2396817	et	3	main
esimest	doc_40918597578_item	2396820	et	4	main
dokumentides	doc_40918597578_item	2396822	et	3	main
1030	doc_40918597578_item	2396824	et	2	main
kiievi	doc_40918597578_item	2396827	et	4	main
vürst	doc_40918597578_item	2396828	et	3	main
tark	doc_40918597578_item	2396830	et	3	main
on	doc_40918597578_item	2396832	et	4	main
tartu	doc_40918597578_item	2396833	et	4	main
kandnud	doc_40918597578_item	2396835	et	4	main
5	doc_40918597578_item	2396836	et	2	main
14	doc_40918597578_item	2396837	et	2	main
16	doc_40918597578_item	2396838	et	2	main
sajandil	doc_40918597578_item	2396839	et	3	main
elas	doc_40918597578_item	2396840	et	3	main
tartus	doc_40918597578_item	2396841	et	3	main
on	doc_40918597578_item	2396849	et	4	main
kolm	doc_40918597578_item	2396850	et	3	main
elab	doc_40918597578_item	2396872	et	3	main
suurem	doc_40918597579_item	2396885	et	4	main
kui	doc_40918597579_item	2396886	et	3	main
glasgow	doc_40918597579_item	2396887	et	4	main
2	doc_40918597579_item	2396888	et	2	main
kollane	doc_40918597579_item	2396889	et	4	main
raamat	doc_40918597579_item	2396890	et	3	main
on	doc_40918597579_item	2396891	et	4	main
laua	doc_40918597579_item	2396892	et	3	main
oleks	doc_40918597579_item	2396897	et	3	main
t-särk	doc_40918597579_item	2396921	et	3	main
ma	doc_40918597579_item	2396930	et	3	main
10	doc_40918597579_item	2396942	et	2	main
kas	doc_40918597579_item	2396943	et	3	main
maa	doc_40918597580_item	2396951	et	4	main
šoti	doc_40918597580_item	2396952	et	2	main
linn	doc_40918597580_item	2396959	et	3	main
linn	doc_40918597580_item	2396965	et	3	main
ülikoolilinn	doc_40918597580_item	2396969	et	3	main
talvel	doc_40918597580_item	2396997	et	4	main
sajab	doc_40918597580_item	2397003	et	3	main
suurem	doc_40918597580_item	2397006	et	4	main
sest	doc_41618862214_item	2397027	et	4	main
varasid	doc_41618862214_item	2397031	et	3	main
lapsi	doc_41618862214_item	2397034	et	4	main
kontrollima	doc_41618862214_item	2397035	et	4	main
mitmesuguseid	doc_41618862214_item	2397036	et	3	main
õpetab	doc_41618862214_item	2397043	et	3	main
lapsi	doc_41618862214_item	2397044	et	4	main
ametite	doc_41618862215_item	2397045	et	3	main
tööd	doc_41618862215_item	2397055	et	4	main
ta	doc_41618862215_item	2397056	et	4	main
peab	doc_41618862215_item	2397073	et	4	main
olema	doc_41618862215_item	2397074	et	4	main
mõistav	doc_41618862215_item	2397077	et	4	main
et	doc_41618862215_item	2397083	et	3	main
sooviksid	doc_41618862216_item	2397106	et	4	main
muuta	doc_41618862216_item	2397107	et	4	main
midagi	doc_41618862216_item	2397116	et	4	main
tahaks	doc_41618862216_item	2397124	et	3	main
et	doc_41618862216_item	2397129	et	3	main
õpilased	doc_41618862216_item	2397130	et	3	main
selle	doc_41618862216_item	2397140	et	4	main
et	doc_41618862216_item	2397156	et	3	main
oleks	doc_41618862216_item	2397161	et	3	main
kaks	doc_41618862216_item	2397216	et	3	main
ja	doc_41618862216_item	2397218	et	3	main
kõike	doc_41618862216_item	2397221	et	4	main
eluiga	doc_41618862217_item	2397244	et	4	main
eluiga	doc_41618862217_item	2397247	et	4	main
ilma	doc_41618862217_item	2397251	et	4	main
ka	doc_41618862217_item	2397290	et	3	main
elektriseadmeid	doc_41618862218_item	2397297	et	3	main
on	doc_41618862218_item	2397298	et	4	main
kodus	doc_41618862218_item	2397299	et	4	main
kindlasti	doc_41618862218_item	2397300	et	3	main
pliit	doc_41618862218_item	2397308	et	3	main
teha	doc_41618862218_item	2397322	et	3	main
see	doc_41618862218_item	2397329	et	3	main
inimesed	doc_41618862218_item	2397338	et	3	main
hoiavad	doc_41618862218_item	2397339	et	3	main
tooded	doc_41618862218_item	2397340	et	4	main
rohkem	doc_41618862218_item	2397349	et	4	main
kes	doc_41618862218_item	2397354	et	4	main
inimene	doc_41618862218_item	2397374	et	3	main
millised	doc_41618862218_item	2397378	et	3	main
miks	doc_41618862218_item	2397383	et	4	main
meeldivad	doc_41618862218_item	2397385	et	4	main
4	doc_40918597578_item	2396826	et	2	main
veel	doc_40918597578_item	2396834	et	4	main
saksa	doc_40918597578_item	2396844	et	4	main
kaupmehi	doc_40918597578_item	2396845	et	3	main
6	doc_40918597578_item	2396846	et	2	main
sada	doc_40918597578_item	2396851	et	4	main
vanemuine	doc_40918597578_item	2396864	et	4	main
tuhat	doc_40918597578_item	2396870	et	4	main
10	doc_40918597578_item	2396874	et	2	main
kõige	doc_40918597578_item	2396878	et	4	main
linn	doc_40918597578_item	2396880	et	3	main
1	doc_40918597579_item	2396882	et	2	main
4	doc_40918597579_item	2396904	et	2	main
lähe	doc_40918597579_item	2396905	et	4	main
õhtul	doc_40918597579_item	2396906	et	3	main
kinno	doc_40918597579_item	2396907	et	3	main
5	doc_40918597579_item	2396908	et	2	main
mulle	doc_40918597579_item	2396909	et	4	main
ei	doc_40918597579_item	2396910	et	4	main
meeldi	doc_40918597579_item	2396911	et	4	main
kassid	doc_40918597579_item	2396912	et	3	main
6	doc_40918597579_item	2396913	et	2	main
ma	doc_40918597579_item	2396914	et	3	main
panen	doc_40918597579_item	2396915	et	3	main
seljas	doc_40918597579_item	2396916	et	4	main
pruunid	doc_40918597579_item	2396917	et	3	main
püksid	doc_40918597579_item	2396918	et	3	main
ja	doc_40918597579_item	2396919	et	3	main
sinise	doc_40918597579_item	2396920	et	4	main
7	doc_40918597579_item	2396922	et	2	main
glasgows	doc_40918597579_item	2396925	et	4	main
meeldib	doc_40918597579_item	2396937	et	3	main
kohv	doc_40918597579_item	2396938	et	3	main
piimaga	doc_40918597579_item	2396939	et	3	main
auto	doc_40918597579_item	2396946	et	4	main
pealinn	doc_40918597580_item	2396953	et	3	main
aga	doc_40918597580_item	2396960	et	3	main
šotimaal	doc_40918597580_item	2396966	et	2	main
šotimaal	doc_40918597580_item	2396970	et	2	main
viis	doc_40918597580_item	2396981	et	4	main
inimest	doc_40918597580_item	2396983	et	3	main
on	doc_40918597580_item	2396985	et	4	main
paike	doc_40918597580_item	2396988	et	4	main
ja	doc_40918597580_item	2396990	et	3	main
on	doc_40918597580_item	2396991	et	4	main
kulm	doc_40918597580_item	2397000	et	3	main
kui	doc_40918597580_item	2397012	et	3	main
politseinik	doc_41618862214_item	2397016	et	4	main
trahvid	doc_41618862214_item	2397021	et	4	main
õpetaja	doc_41618862214_item	2397032	et	4	main
kasuline	doc_41618862214_item	2397040	et	4	main
kirjeldus	doc_41618862215_item	2397046	et	4	main
kõik	doc_41618862215_item	2397052	et	4	main
peab	doc_41618862215_item	2397057	et	4	main
paberid	doc_41618862215_item	2397085	et	3	main
õigel	doc_41618862215_item	2397097	et	3	main
kandma	doc_41618862215_item	2397102	et	3	main
haridussüsteemis	doc_41618862216_item	2397109	et	3	main
et	doc_41618862216_item	2397112	et	3	main
ainult	doc_41618862216_item	2397119	et	4	main
üks	doc_41618862216_item	2397120	et	3	main
mis	doc_41618862216_item	2397122	et	4	main
et	doc_41618862216_item	2397125	et	3	main
et	doc_41618862216_item	2397136	et	3	main
on	doc_41618862216_item	2397148	et	4	main
ka	doc_41618862216_item	2397149	et	3	main
mõnel	doc_41618862216_item	2397150	et	3	main
vaja	doc_41618862216_item	2397151	et	4	main
palju	doc_41618862216_item	2397152	et	4	main
mari	doc_40918597579_item	2396923	et	4	main
on	doc_40918597579_item	2396924	et	4	main
kaks	doc_40918597579_item	2396926	et	3	main
aastat	doc_40918597579_item	2396927	et	3	main
elanud	doc_40918597579_item	2396928	et	4	main
8	doc_40918597579_item	2396929	et	2	main
lähen	doc_40918597579_item	2396931	et	3	main
tena	doc_40918597579_item	2396944	et	4	main
on	doc_40918597579_item	2396945	et	4	main
on	doc_40918597580_item	2396954	et	4	main
edinburgh	doc_40918597580_item	2396955	et	4	main
edinburgh	doc_40918597580_item	2396956	et	4	main
suurem	doc_40918597580_item	2396964	et	4	main
räägime	doc_40918597580_item	2396972	et	3	main
suvel	doc_40918597580_item	2396984	et	3	main
paistab	doc_40918597580_item	2396989	et	3	main
sooja	doc_40918597580_item	2396996	et	4	main
ilm	doc_40918597580_item	2396999	et	3	main
ja	doc_40918597580_item	2397001	et	3	main
kui	doc_40918597580_item	2397007	et	3	main
irismaa	doc_40918597580_item	2397008	et	4	main
šotimaa	doc_40918597580_item	2397009	et	2	main
inglismaa	doc_40918597580_item	2397013	et	4	main
firma	doc_41618862215_item	2397047	et	4	main
peab	doc_41618862215_item	2397049	et	4	main
et	doc_41618862215_item	2397051	et	3	main
kohusetundlik	doc_41618862215_item	2397075	et	3	main
raamatupidaja	doc_41618862215_item	2397079	et	4	main
kindel	doc_41618862215_item	2397081	et	3	main
programmitega	doc_41618862215_item	2397092	et	4	main
ja	doc_41618862215_item	2397093	et	3	main
paberitega	doc_41618862215_item	2397094	et	3	main
nad	doc_41618862215_item	2397095	et	3	main
peavad	doc_41618862215_item	2397096	et	4	main
muutusid	doc_41618862216_item	2397131	et	4	main
oma	doc_41618862216_item	2397132	et	4	main
arvamust	doc_41618862216_item	2397133	et	3	main
haridusest	doc_41618862216_item	2397134	et	4	main
tahan	doc_41618862216_item	2397135	et	3	main
soov	doc_41618862216_item	2397139	et	3	main
haridust	doc_41618862216_item	2397141	et	4	main
aga	doc_41618862216_item	2397143	et	3	main
muidu	doc_41618862216_item	2397144	et	3	main
et	doc_41618862216_item	2397145	et	3	main
haridust	doc_41618862216_item	2397146	et	4	main
raha	doc_41618862216_item	2397153	et	4	main
on	doc_41618862216_item	2397158	et	4	main
see	doc_41618862216_item	2397203	et	3	main
kui	doc_41618862216_item	2397206	et	3	main
vaja	doc_41618862216_item	2397208	et	4	main
midagi	doc_41618862216_item	2397209	et	4	main
teada	doc_41618862216_item	2397210	et	3	main
ainult	doc_41618862216_item	2397215	et	4	main
ilus	doc_40918597580_item	2396987	et	4	main
umbes	doc_40918597580_item	2396992	et	4	main
kaks	doc_40918597580_item	2396993	et	3	main
kummend	doc_40918597580_item	2396994	et	4	main
vihma	doc_40918597580_item	2397002	et	4	main
on	doc_40918597580_item	2397005	et	4	main
väiksem	doc_40918597580_item	2397011	et	4	main
ametite	doc_41618862214_item	2397014	et	3	main
leida	doc_41618862214_item	2397017	et	3	main
varasid	doc_41618862214_item	2397018	et	3	main
politsei	doc_41618862214_item	2397022	et	4	main
auto	doc_41618862214_item	2397023	et	4	main
püstool	doc_41618862214_item	2397024	et	4	main
väga	doc_41618862214_item	2397025	et	3	main
ohtlik	doc_41618862214_item	2397026	et	3	main
on	doc_41618862214_item	2397029	et	4	main
tööd	doc_41618862214_item	2397037	et	4	main
priit	doc_41618862214_item	2397038	et	3	main
vaatama	doc_41618862215_item	2397050	et	3	main
teeksid	doc_41618862215_item	2397053	et	4	main
oma	doc_41618862215_item	2397054	et	4	main
ja	doc_41618862215_item	2397076	et	3	main
peab	doc_41618862215_item	2397080	et	4	main
kõik	doc_41618862215_item	2397084	et	4	main
korras	doc_41618862215_item	2397087	et	4	main
raamatupidajad	doc_41618862215_item	2397088	et	3	main
töötavad	doc_41618862215_item	2397089	et	4	main
arvutitega	doc_41618862215_item	2397090	et	4	main
raamatupidamise	doc_41618862215_item	2397091	et	3	main
üle	doc_41618862215_item	2397101	et	3	main
meie	doc_41618862216_item	2397108	et	4	main
praegu	doc_41618862216_item	2397110	et	3	main
arvan	doc_41618862216_item	2397111	et	3	main
muutuks	doc_41618862216_item	2397117	et	4	main
tänapäeval	doc_41618862214_item	2397028	et	3	main
palju	doc_41618862214_item	2397030	et	4	main
õpetama	doc_41618862214_item	2397033	et	3	main
klassipäevik	doc_41618862214_item	2397039	et	3	main
sest	doc_41618862214_item	2397041	et	4	main
ta	doc_41618862214_item	2397042	et	4	main
juht	doc_41618862215_item	2397048	et	3	main
kindel	doc_41618862215_item	2397058	et	3	main
olema	doc_41618862215_item	2397059	et	4	main
et	doc_41618862215_item	2397060	et	3	main
firma	doc_41618862215_item	2397061	et	4	main
ja	doc_41618862215_item	2397063	et	3	main
teenis	doc_41618862215_item	2397064	et	3	main
raha	doc_41618862215_item	2397065	et	4	main
kasvaks	doc_41618862215_item	2397062	et	4	main
ta	doc_41618862215_item	2397066	et	4	main
töötab	doc_41618862215_item	2397067	et	3	main
arvutiga	doc_41618862215_item	2397068	et	4	main
ja	doc_41618862215_item	2397069	et	3	main
paberitega	doc_41618862215_item	2397070	et	3	main
firma	doc_41618862215_item	2397071	et	4	main
juht	doc_41618862215_item	2397072	et	3	main
inimene	doc_41618862215_item	2397078	et	3	main
olema	doc_41618862215_item	2397082	et	4	main
oleksid	doc_41618862215_item	2397086	et	4	main
ajal	doc_41618862215_item	2397098	et	4	main
inimestele	doc_41618862215_item	2397099	et	3	main
palku	doc_41618862215_item	2397100	et	3	main
kontrolltöö	doc_41618862216_item	2397103	et	4	main
mida	doc_41618862216_item	2397104	et	4	main
sa	doc_41618862216_item	2397105	et	3	main
ei	doc_41618862216_item	2397113	et	4	main
taha	doc_41618862216_item	2397114	et	4	main
et	doc_41618862216_item	2397115	et	3	main
on	doc_41618862216_item	2397118	et	4	main
asi	doc_41618862216_item	2397121	et	4	main
ma	doc_41618862216_item	2397123	et	3	main
oleks	doc_41618862216_item	2397126	et	3	main
parem	doc_41618862216_item	2397127	et	4	main
tahan	doc_41618862216_item	2397128	et	3	main
neil	doc_41618862216_item	2397137	et	4	main
saada	doc_41618862216_item	2397142	et	4	main
saada	doc_41618862216_item	2397147	et	4	main
maksta	doc_41618862216_item	2397154	et	4	main
mõtlen	doc_41618862216_item	2397155	et	3	main
õeti	doc_41618862216_item	2397162	et	4	main
on	doc_41618862216_item	2397172	et	4	main
säästab	doc_41618862216_item	2397204	et	3	main
on	doc_41618862216_item	2397207	et	4	main
leida	doc_41618862216_item	2397213	et	3	main
mina	doc_41618862216_item	2397222	et	4	main
reisin	doc_41618862216_item	2397223	et	3	main
väga	doc_41618862216_item	2397224	et	3	main
palju	doc_41618862216_item	2397225	et	4	main
ja	doc_41618862216_item	2397226	et	3	main
minu	doc_41618862216_item	2397227	et	3	main
kõnesid	doc_41618862216_item	2397238	et	3	main
vastu	doc_41618862216_item	2397239	et	3	main
minu	doc_41618862217_item	2397245	et	3	main
toitumisest	doc_41618862217_item	2397249	et	4	main
toitu	doc_41618862217_item	2397252	et	4	main
teiste	doc_41618862217_item	2397260	et	4	main
sõltub	doc_41618862217_item	2397293	et	3	main
tervisest	doc_41618862217_item	2397294	et	4	main
milliseid	doc_41618862218_item	2397296	et	3	main
miks	doc_41618862218_item	2397303	et	4	main
arvan	doc_41618862218_item	2397304	et	3	main
et	doc_41618862218_item	2397305	et	3	main
minul	doc_41618862218_item	2397310	et	3	main
ei	doc_41618862218_item	2397318	et	4	main
süüa	doc_41618862218_item	2397321	et	3	main
pesumasin	doc_41618862218_item	2397328	et	3	main
on	doc_41618862218_item	2397330	et	4	main
oluline	doc_41618862218_item	2397331	et	4	main
sest	doc_41618862218_item	2397332	et	4	main
saaks	doc_41618862218_item	2397342	et	3	main
vähendada	doc_41618862218_item	2397343	et	3	main
arvan	doc_41618862218_item	2397345	et	3	main
peab	doc_41618862218_item	2397347	et	4	main
olema	doc_41618862218_item	2397348	et	4	main
politseinikud	doc_41618862218_item	2397353	et	4	main
vangla	doc_41618862218_item	2397362	et	4	main
kuritegijat	doc_41618862218_item	2397365	et	3	main
peab	doc_41618862218_item	2397375	et	4	main
autod	doc_41618862218_item	2397379	et	3	main
rohkem	doc_41618862218_item	2397389	et	4	main
ilmus	doc_41618862216_item	2397138	et	4	main
see	doc_41618862216_item	2397157	et	3	main
probleem	doc_41618862216_item	2397160	et	3	main
et	doc_41618862216_item	2397163	et	3	main
saaks	doc_41618862216_item	2397165	et	3	main
haridust	doc_41618862216_item	2397166	et	4	main
mitte	doc_41618862216_item	2397168	et	3	main
vaid	doc_41618862216_item	2397169	et	3	main
need	doc_41618862216_item	2397170	et	3	main
kellel	doc_41618862216_item	2397171	et	4	main
suur	doc_41618862216_item	2397173	et	3	main
rahakott	doc_41618862216_item	2397174	et	3	main
ilma	doc_41618862216_item	2397175	et	4	main
milliste	doc_41618862216_item	2397176	et	3	main
leiutisteta	doc_41618862216_item	2397177	et	3	main
sa	doc_41618862216_item	2397178	et	3	main
ei	doc_41618862216_item	2397179	et	4	main
saaks	doc_41618862216_item	2397180	et	3	main
elada	doc_41618862216_item	2397181	et	3	main
miks	doc_41618862216_item	2397182	et	4	main
ma	doc_41618862216_item	2397183	et	3	main
saaks	doc_41618862216_item	2397185	et	3	main
ei	doc_41618862216_item	2397184	et	4	main
elada	doc_41618862216_item	2397186	et	3	main
ilma	doc_41618862216_item	2397187	et	4	main
mobiiltelefonita	doc_41618862216_item	2397188	et	3	main
sellepärast	doc_41618862216_item	2397189	et	3	main
et	doc_41618862216_item	2397190	et	3	main
ma	doc_41618862216_item	2397191	et	3	main
olen	doc_41618862216_item	2397192	et	3	main
juba	doc_41618862216_item	2397193	et	3	main
harjunud	doc_41618862216_item	2397195	et	4	main
ammu	doc_41618862216_item	2397194	et	4	main
seda	doc_41618862216_item	2397196	et	3	main
kasutada	doc_41618862216_item	2397197	et	3	main
ja	doc_41618862216_item	2397198	et	3	main
see	doc_41618862216_item	2397199	et	3	main
on	doc_41618862216_item	2397200	et	4	main
ka	doc_41618862216_item	2397159	et	3	main
igaüks	doc_41618862216_item	2397164	et	3	main
saada	doc_41618862216_item	2397167	et	4	main
väga	doc_41618862216_item	2397201	et	3	main
saada	doc_41618862216_item	2397211	et	4	main
sekundit	doc_41618862216_item	2397217	et	3	main
tean	doc_41618862216_item	2397220	et	3	main
on	doc_41618862216_item	2397229	et	4	main
väga	doc_41618862216_item	2397230	et	3	main
millest	doc_41618862217_item	2397242	et	3	main
ei	doc_41618862217_item	2397254	et	4	main
saa	doc_41618862217_item	2397255	et	4	main
elada	doc_41618862217_item	2397256	et	3	main
veel	doc_41618862217_item	2397257	et	4	main
sõltub	doc_41618862217_item	2397258	et	3	main
suhtest	doc_41618862217_item	2397259	et	4	main
hea	doc_41618862217_item	2397283	et	4	main
inimeste	doc_41618862217_item	2397291	et	3	main
kontrolltöö	doc_41618862218_item	2397295	et	4	main
on	doc_41618862218_item	2397306	et	4	main
vaja	doc_41618862218_item	2397307	et	4	main
kodus	doc_41618862218_item	2397313	et	4	main
pliiti	doc_41618862218_item	2397315	et	4	main
mina	doc_41618862218_item	2397320	et	4	main
oluline	doc_41618862218_item	2397323	et	4	main
trikkraud	doc_41618862218_item	2397326	et	4	main
ja	doc_41618862218_item	2397327	et	3	main
kuidas	doc_41618862218_item	2397341	et	3	main
haritud	doc_41618862218_item	2397350	et	4	main
ja	doc_41618862218_item	2397351	et	3	main
inimesi	doc_41618862218_item	2397356	et	4	main
ei	doc_41618862218_item	2397363	et	4	main
iga	doc_41618862218_item	2397373	et	4	main
teile	doc_41618862218_item	2397380	et	4	main
arvan	doc_41618862218_item	2397443	et	3	main
et	doc_41618862218_item	2397444	et	3	main
interneti	doc_41618862218_item	2397458	et	4	main
inimesed	doc_41618862218_item	2397471	et	3	main
ajalehte	doc_41618862218_item	2397488	et	4	main
või	doc_41618862218_item	2397489	et	4	main
firma	doc_41618862218_item	2397493	et	4	main
sõltub	doc_41618862218_item	2397499	et	3	main
konkurentsist	doc_41618862218_item	2397501	et	3	main
käive	doc_41618862218_item	2397513	et	3	main
suur	doc_41618862218_item	2397515	et	3	main
turul	doc_41618862218_item	2397540	et	3	main
eluiga	doc_41618862219_item	2397546	et	4	main
me	doc_41618862219_item	2397567	et	4	main
maole	doc_41618862219_item	2397580	et	4	main
inimesed	doc_41618862219_item	2397596	et	3	main
meditsiin	doc_41618862219_item	2397600	et	3	main
alati	doc_41618862219_item	2397602	et	4	main
keskkonnas	doc_41618862219_item	2397621	et	3	main
elektriseadmeid	doc_41618862219_item	2397637	et	3	main
meil	doc_41618862219_item	2397664	et	4	main
tuleb	doc_41618862219_item	2397665	et	3	main
nõus	doc_41618862219_item	2397672	et	4	main
on	doc_41618862219_item	2397676	et	4	main
seda	doc_41618862219_item	2397680	et	3	main
peab	doc_41618862219_item	2397691	et	4	main
olema	doc_41618862219_item	2397692	et	4	main
teler	doc_41618862219_item	2397693	et	3	main
mul	doc_41618862219_item	2397694	et	3	main
oleks	doc_41618862219_item	2397695	et	3	main
igav	doc_41618862219_item	2397697	et	3	main
iga	doc_41618862219_item	2397702	et	4	main
vajab	doc_41618862219_item	2397704	et	3	main
e	doc_41618862219_item	2397712	et	4	main
lihtne	doc_41618862216_item	2397202	et	3	main
aega	doc_41618862216_item	2397205	et	4	main
inimest	doc_41618862216_item	2397212	et	3	main
siis	doc_41618862216_item	2397214	et	3	main
ma	doc_41618862216_item	2397219	et	3	main
jaoks	doc_41618862216_item	2397228	et	4	main
oluline	doc_41618862216_item	2397231	et	4	main
et	doc_41618862216_item	2397232	et	3	main
ma	doc_41618862216_item	2397233	et	3	main
saaks	doc_41618862216_item	2397234	et	3	main
alati	doc_41618862216_item	2397235	et	4	main
helistada	doc_41618862216_item	2397236	et	3	main
ja	doc_41618862216_item	2397237	et	3	main
kontrolltöö	doc_41618862217_item	2397241	et	4	main
arust	doc_41618862217_item	2397246	et	4	main
inimene	doc_41618862217_item	2397253	et	3	main
raha	doc_41618862217_item	2397289	et	4	main
on	doc_41618862218_item	2397311	et	4	main
ei	doc_41618862218_item	2397316	et	4	main
ole	doc_41618862218_item	2397317	et	4	main
on	doc_41618862218_item	2397324	et	4	main
veel	doc_41618862218_item	2397325	et	4	main
inimesed	doc_41618862218_item	2397333	et	3	main
peavad	doc_41618862218_item	2397334	et	4	main
korralik	doc_41618862218_item	2397335	et	3	main
riietuda	doc_41618862218_item	2397336	et	3	main
kuritegevust	doc_41618862218_item	2397344	et	4	main
et	doc_41618862218_item	2397346	et	3	main
kuritegevuse	doc_41618862218_item	2397357	et	4	main
eest	doc_41618862218_item	2397358	et	4	main
kaitsma	doc_41618862218_item	2397359	et	3	main
arvan	doc_41618862218_item	2397360	et	3	main
paranda	doc_41618862218_item	2397364	et	4	main
sest	doc_41618862218_item	2397366	et	4	main
kaitsma	doc_41618862218_item	2397377	et	3	main
meeldivad	doc_41618862218_item	2397381	et	4	main
nagu	doc_41618862218_item	2397390	et	3	main
volkswagen	doc_41618862218_item	2397391	et	4	main
ja	doc_41618862218_item	2397421	et	3	main
autod	doc_41618862218_item	2397423	et	3	main
näevad	doc_41618862218_item	2397425	et	3	main
loetakse	doc_41618862218_item	2397431	et	3	main
rohkem	doc_41618862218_item	2397432	et	4	main
palju	doc_41618862218_item	2397441	et	4	main
tänapäeval	doc_41618862218_item	2397445	et	3	main
vähem	doc_41618862218_item	2397448	et	4	main
palju	doc_41618862218_item	2397457	et	4	main
keegi	doc_41618862218_item	2397464	et	4	main
vaatab	doc_41618862218_item	2397465	et	3	main
telerit	doc_41618862218_item	2397466	et	3	main
on	doc_41618862218_item	2397475	et	4	main
aega	doc_41618862218_item	2397484	et	4	main
millest	doc_41618862218_item	2397491	et	3	main
mina	doc_41618862218_item	2397495	et	4	main
et	doc_41618862218_item	2397497	et	3	main
palju	doc_41618862218_item	2397507	et	4	main
suur	doc_41618862218_item	2397512	et	3	main
kasum	doc_41618862218_item	2397516	et	3	main
sõltub	doc_41618862218_item	2397521	et	3	main
millise	doc_41618862218_item	2397524	et	3	main
on	doc_41618862218_item	2397529	et	4	main
harus	doc_41618862218_item	2397531	et	3	main
firma	doc_41618862218_item	2397538	et	4	main
siis	doc_41618862218_item	2397539	et	3	main
kontrolltöö	doc_41618862219_item	2397543	et	4	main
sõltub	doc_41618862219_item	2397545	et	3	main
minu	doc_41618862219_item	2397557	et	3	main
lahjasid	doc_41618862219_item	2397570	et	3	main
siis	doc_41618862219_item	2397575	et	3	main
on	doc_41618862219_item	2397577	et	4	main
kogu	doc_41618862219_item	2397582	et	4	main
meditsiinist	doc_41618862219_item	2397585	et	3	main
on	doc_41618862219_item	2397590	et	4	main
nii	doc_41618862219_item	2397591	et	3	main
palju	doc_41618862219_item	2397592	et	4	main
teadma	doc_41618862219_item	2397598	et	3	main
suhelda	doc_41618862219_item	2397623	et	4	main
inimestega	doc_41618862219_item	2397625	et	3	main
peab	doc_41618862219_item	2397628	et	4	main
spordiga	doc_41618862219_item	2397630	et	3	main
pikendab	doc_41618862219_item	2397634	et	3	main
triikida	doc_41618862219_item	2397666	et	4	main
et	doc_41618862219_item	2397673	et	3	main
tihti	doc_41618862219_item	2397682	et	3	main
meie	doc_41618862219_item	2397684	et	4	main
puhas	doc_41618862219_item	2397687	et	3	main
võtta	doc_41618862216_item	2397240	et	3	main
sõltub	doc_41618862217_item	2397243	et	3	main
sõltub	doc_41618862217_item	2397248	et	3	main
sest	doc_41618862217_item	2397250	et	4	main
inimestega	doc_41618862217_item	2397261	et	3	main
suhtest	doc_41618862217_item	2397262	et	4	main
perekonnas	doc_41618862217_item	2397263	et	4	main
arvan	doc_41618862217_item	2397264	et	3	main
et	doc_41618862217_item	2397265	et	3	main
sõltub	doc_41618862217_item	2397266	et	3	main
ka	doc_41618862217_item	2397267	et	3	main
poliitika	doc_41618862217_item	2397268	et	4	main
olukorrast	doc_41618862217_item	2397269	et	4	main
riigis	doc_41618862217_item	2397270	et	3	main
sõltub	doc_41618862217_item	2397271	et	3	main
ka	doc_41618862217_item	2397272	et	3	main
hea	doc_41618862217_item	2397273	et	4	main
hariduse	doc_41618862217_item	2397274	et	3	main
saavusest	doc_41618862217_item	2397275	et	4	main
kui	doc_41618862217_item	2397276	et	3	main
inimene	doc_41618862217_item	2397277	et	3	main
on	doc_41618862217_item	2397278	et	4	main
haritud	doc_41618862217_item	2397279	et	4	main
siis	doc_41618862217_item	2397280	et	3	main
ta	doc_41618862217_item	2397281	et	4	main
saab	doc_41618862217_item	2397282	et	3	main
töökoha	doc_41618862217_item	2397284	et	4	main
leida	doc_41618862217_item	2397285	et	3	main
ja	doc_41618862217_item	2397286	et	3	main
teenida	doc_41618862217_item	2397287	et	3	main
palju	doc_41618862217_item	2397288	et	4	main
eluiga	doc_41618862217_item	2397292	et	4	main
vaja	doc_41618862218_item	2397301	et	4	main
ja	doc_41618862218_item	2397302	et	3	main
kodus	doc_41618862218_item	2397309	et	4	main
gaasipliit	doc_41618862218_item	2397312	et	3	main
kui	doc_41618862218_item	2397314	et	3	main
saa	doc_41618862218_item	2397319	et	4	main
külmkappis	doc_41618862218_item	2397337	et	4	main
julged	doc_41618862218_item	2397352	et	4	main
saavad	doc_41618862218_item	2397355	et	4	main
et	doc_41618862218_item	2397361	et	3	main
vanglas	doc_41618862218_item	2397367	et	3	main
on	doc_41618862218_item	2397368	et	4	main
kuritegijate	doc_41618862218_item	2397369	et	3	main
ühiskond	doc_41618862218_item	2397370	et	3	main
arvan	doc_41618862218_item	2397371	et	3	main
et	doc_41618862218_item	2397372	et	3	main
iseenda	doc_41618862218_item	2397376	et	3	main
ja	doc_41618862218_item	2397382	et	3	main
mulle	doc_41618862218_item	2397384	et	4	main
saksa	doc_41618862218_item	2397386	et	4	main
autod	doc_41618862218_item	2397387	et	3	main
või	doc_41618862218_item	2397392	et	4	main
nad	doc_41618862218_item	2397394	et	3	main
on	doc_41618862218_item	2397395	et	4	main
väga	doc_41618862218_item	2397396	et	3	main
tehtud	doc_41618862218_item	2397398	et	4	main
kvaliteetset	doc_41618862218_item	2397397	et	3	main
ja	doc_41618862218_item	2397399	et	3	main
on	doc_41618862218_item	2397400	et	4	main
väga	doc_41618862218_item	2397401	et	3	main
populaarsed	doc_41618862218_item	2397402	et	3	main
välismaal	doc_41618862218_item	2397403	et	4	main
bmw	doc_41618862218_item	2397404	et	4	main
näiteks	doc_41618862218_item	2397405	et	4	main
on	doc_41618862218_item	2397406	et	4	main
prestiizhikas	doc_41618862218_item	2397407	et	4	main
auto	doc_41618862218_item	2397408	et	4	main
mina	doc_41618862218_item	2397409	et	4	main
hindan	doc_41618862218_item	2397410	et	3	main
autos	doc_41618862218_item	2397411	et	3	main
mugavuse	doc_41618862218_item	2397412	et	4	main
ja	doc_41618862218_item	2397413	et	3	main
turvalisuse	doc_41618862218_item	2397414	et	4	main
eest	doc_41618862218_item	2397415	et	4	main
üldse	doc_41618862218_item	2397416	et	3	main
ei	doc_41618862218_item	2397417	et	4	main
meeldi	doc_41618862218_item	2397418	et	4	main
mulle	doc_41618862218_item	2397419	et	4	main
korea	doc_41618862218_item	2397420	et	4	main
või	doc_41618862218_item	2397433	et	4	main
vähem	doc_41618862218_item	2397434	et	4	main
kui	doc_41618862218_item	2397435	et	3	main
varem	doc_41618862218_item	2397436	et	4	main
loevad	doc_41618862218_item	2397447	et	3	main
varem	doc_41618862218_item	2397450	et	4	main
loeb	doc_41618862218_item	2397461	et	3	main
noored	doc_41618862218_item	2397473	et	3	main
väga	doc_41618862218_item	2397476	et	3	main
et	doc_41618862218_item	2397478	et	3	main
loevad	doc_41618862218_item	2397485	et	3	main
nad	doc_41618862218_item	2397486	et	3	main
ainult	doc_41618862218_item	2397487	et	4	main
juhtkonnast	doc_41618862218_item	2397500	et	4	main
kapitalist	doc_41618862218_item	2397502	et	4	main
kõige	doc_41618862218_item	2397388	et	4	main
bmw	doc_41618862218_item	2397393	et	4	main
nad	doc_41618862218_item	2397424	et	3	main
nagu	doc_41618862218_item	2397426	et	3	main
kas	doc_41618862218_item	2397429	et	3	main
loen	doc_41618862218_item	2397439	et	3	main
väga	doc_41618862218_item	2397440	et	3	main
aga	doc_41618862218_item	2397442	et	3	main
inimesed	doc_41618862218_item	2397446	et	3	main
kui	doc_41618862218_item	2397449	et	3	main
elame	doc_41618862218_item	2397451	et	3	main
progressivses	doc_41618862218_item	2397452	et	4	main
maailmas	doc_41618862218_item	2397453	et	3	main
eestis	doc_41618862218_item	2397454	et	3	main
on	doc_41618862218_item	2397455	et	4	main
väga	doc_41618862218_item	2397456	et	3	main
kasutajad	doc_41618862218_item	2397459	et	4	main
internetis	doc_41618862218_item	2397463	et	4	main
tänapäeval	doc_41618862218_item	2397467	et	3	main
loevad	doc_41618862218_item	2397468	et	3	main
eesti	doc_41618862218_item	2397469	et	4	main
vanad	doc_41618862218_item	2397470	et	3	main
mitte	doc_41618862218_item	2397472	et	3	main
kahju	doc_41618862218_item	2397477	et	4	main
lugemist	doc_41618862218_item	2397480	et	4	main
inimestel	doc_41618862218_item	2397481	et	3	main
ei	doc_41618862218_item	2397482	et	4	main
ole	doc_41618862218_item	2397483	et	4	main
ajakirju	doc_41618862218_item	2397490	et	4	main
edukus	doc_41618862218_item	2397494	et	4	main
arvan	doc_41618862218_item	2397496	et	3	main
see	doc_41618862218_item	2397498	et	3	main
personaalist	doc_41618862218_item	2397503	et	4	main
eelarvest	doc_41618862218_item	2397505	et	4	main
seadest	doc_41618862218_item	2397506	et	4	main
firmas	doc_41618862218_item	2397510	et	3	main
on	doc_41618862218_item	2397519	et	4	main
sellest	doc_41618862218_item	2397523	et	4	main
kui	doc_41618862218_item	2397535	et	3	main
meie	doc_41618862219_item	2397547	et	4	main
eluiga	doc_41618862219_item	2397548	et	4	main
sõltub	doc_41618862219_item	2397549	et	3	main
pärilikust	doc_41618862219_item	2397550	et	4	main
ma	doc_41618862219_item	2397551	et	3	main
võin	doc_41618862219_item	2397552	et	3	main
põdeda	doc_41618862219_item	2397553	et	3	main
emalisal	doc_41618862219_item	2397558	et	3	main
ka	doc_41618862219_item	2397561	et	3	main
eluiga	doc_41618862219_item	2397562	et	4	main
sõltub	doc_41618862219_item	2397563	et	3	main
rohkem	doc_41618862219_item	2397569	et	4	main
toite	doc_41618862219_item	2397571	et	4	main
ja	doc_41618862219_item	2397573	et	3	main
kasulikum	doc_41618862219_item	2397578	et	4	main
meie	doc_41618862219_item	2397579	et	4	main
või	doc_41618862219_item	2397581	et	4	main
et	doc_41618862219_item	2397595	et	3	main
jaapani	doc_41618862218_item	2397422	et	4	main
mänguasjad	doc_41618862218_item	2397427	et	3	main
välja	doc_41618862218_item	2397428	et	4	main
tänapäeval	doc_41618862218_item	2397430	et	3	main
miks	doc_41618862218_item	2397437	et	4	main
minu	doc_41618862218_item	2397438	et	3	main
keegi	doc_41618862218_item	2397460	et	4	main
raamatuid	doc_41618862218_item	2397462	et	3	main
see	doc_41618862218_item	2397474	et	3	main
raamatute	doc_41618862218_item	2397479	et	3	main
sõltub	doc_41618862218_item	2397492	et	3	main
äriplanist	doc_41618862218_item	2397504	et	4	main
asjadest	doc_41618862218_item	2397508	et	3	main
on	doc_41618862218_item	2397511	et	4	main
siis	doc_41618862218_item	2397517	et	3	main
ka	doc_41618862218_item	2397522	et	3	main
haru	doc_41618862218_item	2397525	et	4	main
valib	doc_41618862218_item	2397526	et	3	main
kas	doc_41618862218_item	2397528	et	3	main
mitte	doc_41618862218_item	2397534	et	3	main
on	doc_41618862218_item	2397541	et	4	main
millised	doc_41618862219_item	2397555	et	3	main
olid	doc_41618862219_item	2397556	et	4	main
meie	doc_41618862219_item	2397564	et	4	main
toitumist	doc_41618862219_item	2397565	et	4	main
kui	doc_41618862219_item	2397566	et	3	main
veel	doc_41618862219_item	2397584	et	4	main
sõltub	doc_41618862219_item	2397586	et	3	main
meie	doc_41618862219_item	2397587	et	4	main
eluiga	doc_41618862219_item	2397588	et	4	main
maailmas	doc_41618862219_item	2397589	et	3	main
haigusi	doc_41618862219_item	2397594	et	4	main
et	doc_41618862219_item	2397599	et	3	main
headega	doc_41618862219_item	2397624	et	3	main
ka	doc_41618862219_item	2397626	et	3	main
inimene	doc_41618862219_item	2397627	et	3	main
tegelema	doc_41618862219_item	2397629	et	3	main
selle	doc_41618862219_item	2397631	et	4	main
pärast	doc_41618862219_item	2397632	et	4	main
sport	doc_41618862219_item	2397633	et	3	main
miks	doc_41618862219_item	2397643	et	4	main
kodus	doc_41618862219_item	2397644	et	4	main
on	doc_41618862219_item	2397645	et	4	main
triikraud	doc_41618862219_item	2397657	et	3	main
on	doc_41618862219_item	2397659	et	4	main
asi	doc_41618862219_item	2397662	et	4	main
sest	doc_41618862219_item	2397663	et	4	main
ma	doc_41618862219_item	2397670	et	3	main
väga	doc_41618862219_item	2397681	et	3	main
olla	doc_41618862219_item	2397699	et	3	main
j	doc_41618862219_item	2397710	et	4	main
n	doc_41618862219_item	2397711	et	4	main
elektriseadmed	doc_41618862219_item	2397714	et	3	main
aitavad	doc_41618862219_item	2397715	et	4	main
valmistamiseks	doc_41618862219_item	2397718	et	4	main
kuidas	doc_41618862219_item	2397719	et	3	main
olema	doc_41618862219_item	2397729	et	4	main
organiseeritud	doc_41618862219_item	2397732	et	4	main
turvasüsteem	doc_41618862219_item	2397733	et	3	main
patruleerima	doc_41618862219_item	2397744	et	4	main
vähem	doc_41618862219_item	2397771	et	4	main
ei	doc_41618862219_item	2397778	et	4	main
ole	doc_41618862219_item	2397779	et	4	main
kõige	doc_41618862219_item	2397789	et	4	main
parem	doc_41618862219_item	2397795	et	4	main
auto	doc_41618862219_item	2397804	et	4	main
on	doc_41618862219_item	2397812	et	4	main
peab	doc_41618862219_item	2397815	et	4	main
olema	doc_41618862219_item	2397816	et	4	main
8	doc_41618862219_item	2397818	et	2	main
aastat	doc_41618862219_item	2397819	et	3	main
siis	doc_41618862219_item	2397820	et	3	main
ma	doc_41618862219_item	2397821	et	3	main
öelda	doc_41618862219_item	2397824	et	4	main
on	doc_41618862219_item	2397837	et	4	main
väga	doc_41618862219_item	2397838	et	3	main
mugavad	doc_41618862219_item	2397839	et	3	main
istmed	doc_41618862219_item	2397842	et	3	main
tea	doc_41618862219_item	2397845	et	4	main
suur	doc_41618862219_item	2397856	et	3	main
öelda	doc_41618862219_item	2397860	et	4	main
et	doc_41618862219_item	2397861	et	3	main
see	doc_41618862219_item	2397862	et	3	main
auto	doc_41618862219_item	2397863	et	4	main
ja	doc_41618862219_item	2397870	et	3	main
tänapäeval	doc_41618862219_item	2397873	et	3	main
kui	doc_41618862219_item	2397878	et	3	main
miks	doc_41618862219_item	2397880	et	4	main
mulle	doc_41618862219_item	2397881	et	4	main
kui	doc_41618862218_item	2397509	et	3	main
ja	doc_41618862218_item	2397514	et	3	main
firma	doc_41618862218_item	2397518	et	4	main
edukus	doc_41618862218_item	2397520	et	4	main
juhatus	doc_41618862218_item	2397527	et	4	main
selles	doc_41618862218_item	2397530	et	4	main
keegi	doc_41618862218_item	2397532	et	4	main
või	doc_41618862218_item	2397533	et	4	main
on	doc_41618862218_item	2397536	et	4	main
mingi	doc_41618862218_item	2397537	et	4	main
konkurents	doc_41618862218_item	2397542	et	3	main
millest	doc_41618862219_item	2397544	et	3	main
haigusi	doc_41618862219_item	2397554	et	4	main
või	doc_41618862219_item	2397559	et	4	main
vanaemalvanaisal	doc_41618862219_item	2397560	et	4	main
sööme	doc_41618862219_item	2397568	et	4	main
puuvilju	doc_41618862219_item	2397572	et	3	main
juurvilju	doc_41618862219_item	2397574	et	3	main
see	doc_41618862219_item	2397576	et	3	main
kehale	doc_41618862219_item	2397583	et	3	main
raskusi	doc_41618862219_item	2397593	et	4	main
peavad	doc_41618862219_item	2397597	et	4	main
võib	doc_41618862219_item	2397601	et	3	main
aidata	doc_41618862219_item	2397603	et	4	main
neid	doc_41618862219_item	2397604	et	4	main
on	doc_41618862219_item	2397605	et	4	main
väga	doc_41618862219_item	2397606	et	3	main
oluline	doc_41618862219_item	2397607	et	4	main
meie	doc_41618862219_item	2397608	et	4	main
jaoks	doc_41618862219_item	2397609	et	4	main
keskkond	doc_41618862219_item	2397610	et	3	main
me	doc_41618862219_item	2397611	et	4	main
teame	doc_41618862219_item	2397612	et	3	main
et	doc_41618862219_item	2397613	et	3	main
keskkond	doc_41618862219_item	2397614	et	3	main
mõjub	doc_41618862219_item	2397615	et	3	main
inimesele	doc_41618862219_item	2397616	et	3	main
on	doc_41618862219_item	2397617	et	4	main
tähtis	doc_41618862219_item	2397618	et	4	main
elada	doc_41618862219_item	2397619	et	3	main
heas	doc_41618862219_item	2397620	et	3	main
milliseid	doc_41618862219_item	2397636	et	3	main
kodus	doc_41618862219_item	2397639	et	4	main
kindlasti	doc_41618862219_item	2397640	et	3	main
kindlasti	doc_41618862219_item	2397646	et	3	main
vaja	doc_41618862219_item	2397647	et	4	main
külmkapp	doc_41618862219_item	2397648	et	3	main
vajalik	doc_41618862219_item	2397661	et	3	main
olen	doc_41618862219_item	2397671	et	3	main
et	doc_41618862219_item	2397683	et	3	main
jaoks	doc_41618862219_item	2397689	et	4	main
kodus	doc_41618862219_item	2397690	et	4	main
kodus	doc_41618862219_item	2397698	et	4	main
saaks	doc_41618862219_item	2397720	et	3	main
vähendada	doc_41618862219_item	2397721	et	3	main
oleks	doc_41618862219_item	2397725	et	3	main
riigis	doc_41618862219_item	2397727	et	3	main
peab	doc_41618862219_item	2397728	et	4	main
peavad	doc_41618862219_item	2397742	et	4	main
politsei	doc_41618862219_item	2397745	et	4	main
siis	doc_41618862219_item	2397754	et	3	main
inimesed	doc_41618862219_item	2397755	et	3	main
on	doc_41618862219_item	2397762	et	4	main
kuritegevust	doc_41618862219_item	2397772	et	4	main
teevad	doc_41618862219_item	2397774	et	3	main
miks	doc_41618862219_item	2397788	et	4	main
meeldivad	doc_41618862219_item	2397792	et	4	main
bmw-d	doc_41618862219_item	2397793	et	4	main
aknadega	doc_41618862219_item	2397803	et	4	main
siis	doc_41618862219_item	2397810	et	3	main
tal	doc_41618862219_item	2397814	et	3	main
ja	doc_41618862219_item	2397622	et	3	main
eluiga	doc_41618862219_item	2397635	et	4	main
on	doc_41618862219_item	2397638	et	4	main
vaja	doc_41618862219_item	2397641	et	4	main
ja	doc_41618862219_item	2397642	et	3	main
sellepärast	doc_41618862219_item	2397649	et	3	main
seal	doc_41618862219_item	2397650	et	4	main
säilitatakse	doc_41618862219_item	2397651	et	3	main
toit	doc_41618862219_item	2397652	et	3	main
kodus	doc_41618862219_item	2397653	et	4	main
peab	doc_41618862219_item	2397654	et	4	main
olema	doc_41618862219_item	2397655	et	4	main
ka	doc_41618862219_item	2397656	et	3	main
see	doc_41618862219_item	2397658	et	3	main
väga	doc_41618862219_item	2397660	et	3	main
peaaegu	doc_41618862219_item	2397667	et	3	main
iga	doc_41618862219_item	2397668	et	4	main
päev	doc_41618862219_item	2397669	et	3	main
igas	doc_41618862219_item	2397674	et	3	main
kodus	doc_41618862219_item	2397675	et	4	main
tolmuimeja	doc_41618862219_item	2397677	et	4	main
me	doc_41618862219_item	2397678	et	4	main
kasutame	doc_41618862219_item	2397679	et	3	main
kodu	doc_41618862219_item	2397685	et	4	main
oleks	doc_41618862219_item	2397686	et	3	main
minu	doc_41618862219_item	2397688	et	3	main
ilma	doc_41618862219_item	2397700	et	4	main
telerita	doc_41618862219_item	2397701	et	3	main
nt	doc_41618862219_item	2397706	et	4	main
elektripliit	doc_41618862219_item	2397707	et	3	main
toidu	doc_41618862219_item	2397717	et	3	main
kui	doc_41618862219_item	2397723	et	3	main
väga	doc_41618862219_item	2397730	et	3	main
pidevalt	doc_41618862219_item	2397743	et	4	main
range	doc_41618862219_item	2397752	et	4	main
karistus	doc_41618862219_item	2397753	et	4	main
kuritegevuse	doc_41618862219_item	2397760	et	4	main
riik	doc_41618862219_item	2397764	et	3	main
andma	doc_41618862219_item	2397766	et	3	main
seda	doc_41618862219_item	2397775	et	3	main
rahata	doc_41618862219_item	2397782	et	4	main
millised	doc_41618862219_item	2397783	et	3	main
autod	doc_41618862219_item	2397784	et	3	main
kõige	doc_41618862219_item	2397794	et	4	main
peab	doc_41618862219_item	2397805	et	4	main
ta	doc_41618862219_item	2397811	et	4	main
veel	doc_41618862219_item	2397823	et	4	main
et	doc_41618862219_item	2397825	et	3	main
bmw-s	doc_41618862219_item	2397833	et	3	main
tema	doc_41618862219_item	2397834	et	4	main
saloon	doc_41618862219_item	2397835	et	4	main
ei	doc_41618862219_item	2397844	et	4	main
kui	doc_41618862219_item	2397847	et	3	main
on	doc_41618862219_item	2397850	et	4	main
mõtlen	doc_41618862219_item	2397853	et	3	main
ma	doc_41618862219_item	2397858	et	3	main
või	doc_41618862219_item	2397876	et	4	main
kui	doc_41618862219_item	2397921	et	3	main
on	doc_41618862219_item	2397928	et	4	main
rohkem	doc_41618862219_item	2397937	et	4	main
ma	doc_41618862219_item	2397942	et	3	main
ala	doc_41618862219_item	2397951	et	4	main
koostööpartneritest	doc_41618862219_item	2397963	et	4	main
reklaamikampania	doc_41618862219_item	2397969	et	4	main
kauaaegsed	doc_41618862219_item	2397981	et	3	main
kliendid	doc_41618862219_item	2397982	et	3	main
ja	doc_41618862219_item	2397998	et	3	main
vaja	doc_41618862219_item	2398001	et	4	main
välisturgudele	doc_41618862219_item	2398004	et	3	main
väga	doc_41618862219_item	2397696	et	3	main
perenaine	doc_41618862219_item	2397703	et	3	main
köögielektriseadmeid	doc_41618862219_item	2397705	et	3	main
veekeetja	doc_41618862219_item	2397708	et	4	main
mikser	doc_41618862219_item	2397709	et	3	main
need	doc_41618862219_item	2397713	et	3	main
meile	doc_41618862219_item	2397716	et	4	main
hästi	doc_41618862219_item	2397731	et	3	main
tugevad	doc_41618862219_item	2397739	et	4	main
kaasatundlikud	doc_41618862219_item	2397740	et	3	main
linnas	doc_41618862219_item	2397741	et	4	main
ka	doc_41618862219_item	2397746	et	3	main
eest	doc_41618862219_item	2397748	et	4	main
peab	doc_41618862219_item	2397749	et	4	main
kardavad	doc_41618862219_item	2397756	et	4	main
vanglat	doc_41618862219_item	2397757	et	3	main
kõige	doc_41618862219_item	2397758	et	4	main
põhjus	doc_41618862219_item	2397761	et	4	main
rohkem	doc_41618862219_item	2397767	et	4	main
töökohti	doc_41618862219_item	2397768	et	4	main
et	doc_41618862219_item	2397769	et	3	main
oleks	doc_41618862219_item	2397770	et	3	main
tal	doc_41618862219_item	2397777	et	3	main
elada	doc_41618862219_item	2397781	et	3	main
rohkem	doc_41618862219_item	2397790	et	4	main
mulle	doc_41618862219_item	2397791	et	4	main
oleks	doc_41618862219_item	2397798	et	3	main
olema	doc_41618862219_item	2397806	et	4	main
noor	doc_41618862219_item	2397807	et	3	main
aga	doc_41618862219_item	2397808	et	3	main
muidugi	doc_41618862219_item	2397809	et	4	main
kallim	doc_41618862219_item	2397813	et	4	main
võin	doc_41618862219_item	2397822	et	3	main
ka	doc_41618862219_item	2397830	et	3	main
meeldi	doc_41618862219_item	2397832	et	4	main
pehmed	doc_41618862219_item	2397841	et	3	main
ma	doc_41618862219_item	2397843	et	3	main
suur	doc_41618862219_item	2397848	et	3	main
kiirus	doc_41618862219_item	2397851	et	4	main
aga	doc_41618862219_item	2397852	et	3	main
päris	doc_41618862219_item	2397855	et	4	main
ilus	doc_41618862219_item	2397866	et	4	main
mugav	doc_41618862219_item	2397867	et	3	main
hästi	doc_41618862219_item	2397868	et	3	main
tehtud	doc_41618862219_item	2397869	et	4	main
rohkem	doc_41618862219_item	2397875	et	4	main
inimene	doc_41618862219_item	2397922	et	3	main
sõltub	doc_41618862219_item	2397939	et	3	main
et	doc_41618862219_item	2397944	et	3	main
töötavad	doc_41618862219_item	2397947	et	4	main
siis	doc_41618862219_item	2397953	et	3	main
on	doc_41618862219_item	2397955	et	4	main
edu	doc_41618862219_item	2397957	et	4	main
mõeldud	doc_41618862219_item	2397968	et	4	main
tal	doc_41618862219_item	2397971	et	3	main
edu	doc_41618862219_item	2397980	et	4	main
siseturul	doc_41618862219_item	2397997	et	3	main
tervise	doc_41618862220_item	2398024	et	3	main
inimeste	doc_41618862220_item	2398028	et	3	main
füüsilised	doc_41618862220_item	2398036	et	3	main
seda	doc_41618862220_item	2398047	et	3	main
on	doc_41618862220_item	2398063	et	4	main
rohkem	doc_41618862220_item	2398064	et	4	main
inimestel	doc_41618862220_item	2398069	et	3	main
palju	doc_41618862220_item	2398072	et	4	main
alkohooli	doc_41618862220_item	2398073	et	3	main
ilma	doc_41618862220_item	2398078	et	4	main
minu	doc_41618862220_item	2398086	et	3	main
minu	doc_41618862220_item	2398104	et	3	main
ja	doc_41618862220_item	2398106	et	3	main
räägin	doc_41618862220_item	2398109	et	3	main
see	doc_41618862220_item	2398112	et	3	main
heas	doc_41618862220_item	2398115	et	3	main
sellele	doc_41618862220_item	2398120	et	4	main
nõuda	doc_41618862220_item	2398122	et	3	main
on	doc_41618862220_item	2398127	et	4	main
parem	doc_41618862220_item	2398129	et	4	main
meelelahutus	doc_41618862220_item	2398130	et	4	main
minu	doc_41618862220_item	2398131	et	3	main
see	doc_41618862220_item	2398149	et	3	main
on	doc_41618862220_item	2398150	et	4	main
nii	doc_41618862220_item	2398158	et	3	main
depressioonis	doc_41618862221_item	2398185	et	3	main
kodutööd	doc_41618862221_item	2398198	et	4	main
lapsedel	doc_41618862221_item	2398202	et	4	main
kuritegevust	doc_41618862219_item	2397722	et	4	main
kuritegevust	doc_41618862219_item	2397724	et	4	main
vähem	doc_41618862219_item	2397726	et	4	main
politseinikud	doc_41618862219_item	2397734	et	4	main
peaksid	doc_41618862219_item	2397735	et	4	main
olema	doc_41618862219_item	2397736	et	4	main
hästi	doc_41618862219_item	2397737	et	3	main
õpetatud	doc_41618862219_item	2397738	et	4	main
kuritegevuse	doc_41618862219_item	2397747	et	4	main
olema	doc_41618862219_item	2397750	et	4	main
väga	doc_41618862219_item	2397751	et	3	main
tuntum	doc_41618862219_item	2397759	et	4	main
töötus	doc_41618862219_item	2397763	et	4	main
peab	doc_41618862219_item	2397765	et	4	main
inimesed	doc_41618862219_item	2397773	et	3	main
et	doc_41618862219_item	2397776	et	3	main
võimalust	doc_41618862219_item	2397780	et	3	main
teile	doc_41618862219_item	2397785	et	4	main
meeldivad	doc_41618862219_item	2397786	et	4	main
ja	doc_41618862219_item	2397787	et	3	main
et	doc_41618862219_item	2397796	et	3	main
ta	doc_41618862219_item	2397797	et	4	main
musta	doc_41618862219_item	2397799	et	4	main
värvi	doc_41618862219_item	2397800	et	4	main
ja	doc_41618862219_item	2397801	et	3	main
tumedadega	doc_41618862219_item	2397802	et	4	main
vähemalt	doc_41618862219_item	2397817	et	4	main
mulle	doc_41618862219_item	2397831	et	4	main
ja	doc_41618862219_item	2397840	et	3	main
tal	doc_41618862219_item	2397849	et	3	main
üldiselt	doc_41618862219_item	2397857	et	4	main
võib	doc_41618862219_item	2397859	et	3	main
turvaline	doc_41618862219_item	2397871	et	4	main
kas	doc_41618862219_item	2397872	et	3	main
vähem	doc_41618862219_item	2397877	et	4	main
tundub	doc_41618862219_item	2397882	et	3	main
et	doc_41618862219_item	2397883	et	3	main
praegu	doc_41618862219_item	2397884	et	3	main
loetakse	doc_41618862219_item	2397885	et	3	main
vähem	doc_41618862219_item	2397886	et	4	main
küljest	doc_41618862219_item	2397888	et	4	main
ühest	doc_41618862219_item	2397887	et	4	main
meie	doc_41618862219_item	2397889	et	4	main
mailmas	doc_41618862219_item	2397890	et	4	main
on	doc_41618862219_item	2397891	et	4	main
nii	doc_41618862219_item	2397892	et	3	main
palju	doc_41618862219_item	2397893	et	4	main
meelelahutusi	doc_41618862219_item	2397894	et	4	main
nagu	doc_41618862219_item	2397895	et	3	main
arvuti	doc_41618862219_item	2397896	et	4	main
televisioon	doc_41618862219_item	2397897	et	4	main
muusika	doc_41618862219_item	2397898	et	4	main
j	doc_41618862219_item	2397899	et	4	main
n	doc_41618862219_item	2397900	et	4	main
et	doc_41618862219_item	2397902	et	3	main
inimestel	doc_41618862219_item	2397903	et	3	main
on	doc_41618862219_item	2397904	et	4	main
e	doc_41618862219_item	2397901	et	4	main
teised	doc_41618862219_item	2397905	et	4	main
huvid	doc_41618862219_item	2397906	et	3	main
muidu	doc_41618862219_item	2397907	et	3	main
noored	doc_41618862219_item	2397908	et	3	main
loevad	doc_41618862219_item	2397909	et	3	main
koolis	doc_41618862219_item	2397910	et	4	main
ülikoolis	doc_41618862219_item	2397911	et	4	main
aga	doc_41618862219_item	2397912	et	3	main
seda	doc_41618862219_item	2397913	et	3	main
nõuatakse	doc_41618862219_item	2397914	et	4	main
aga	doc_41618862219_item	2397915	et	3	main
teisest	doc_41618862219_item	2397916	et	4	main
küljest	doc_41618862219_item	2397917	et	4	main
kõik	doc_41618862219_item	2397918	et	4	main
sõltub	doc_41618862219_item	2397919	et	3	main
auto	doc_41618862219_item	2397826	et	4	main
on	doc_41618862219_item	2397827	et	4	main
heas	doc_41618862219_item	2397828	et	3	main
seisukorras	doc_41618862219_item	2397829	et	3	main
seal	doc_41618862219_item	2397836	et	4	main
täpselt	doc_41618862219_item	2397846	et	4	main
et	doc_41618862219_item	2397854	et	3	main
on	doc_41618862219_item	2397864	et	4	main
väga	doc_41618862219_item	2397865	et	3	main
loetakse	doc_41618862219_item	2397874	et	3	main
varem	doc_41618862219_item	2397879	et	4	main
inimesest	doc_41618862219_item	2397920	et	3	main
olla	doc_41618862219_item	2397924	et	3	main
ta	doc_41618862219_item	2397927	et	4	main
huvitanud	doc_41618862219_item	2397929	et	4	main
raamatudes	doc_41618862219_item	2397930	et	4	main
siis	doc_41618862219_item	2397931	et	3	main
millest	doc_41618862219_item	2397938	et	3	main
mõtlen	doc_41618862219_item	2397943	et	3	main
firmas	doc_41618862219_item	2397946	et	3	main
oma	doc_41618862219_item	2397950	et	4	main
firmal	doc_41618862219_item	2397954	et	3	main
kui	doc_41618862219_item	2397964	et	3	main
firmal	doc_41618862219_item	2397965	et	3	main
hästi	doc_41618862219_item	2397967	et	3	main
valik	doc_41618862219_item	2397975	et	3	main
siis	doc_41618862219_item	2397976	et	3	main
firmal	doc_41618862219_item	2397977	et	3	main
on	doc_41618862219_item	2397978	et	4	main
ka	doc_41618862219_item	2397979	et	3	main
firmale	doc_41618862219_item	2397989	et	3	main
on	doc_41618862219_item	2398000	et	4	main
firmale	doc_41618862219_item	2398002	et	3	main
kõige	doc_41618862219_item	2398005	et	4	main
teha	doc_41618862220_item	2398022	et	3	main
hästi	doc_41618862220_item	2398027	et	3	main
mõjutavad	doc_41618862220_item	2398030	et	4	main
toit	doc_41618862220_item	2398032	et	3	main
liiga	doc_41618862220_item	2398034	et	4	main
eluviis	doc_41618862220_item	2398041	et	3	main
et	doc_41618862220_item	2398048	et	3	main
eluviisi	doc_41618862220_item	2398062	et	4	main
jääma	doc_41618862220_item	2398067	et	4	main
tarbivad	doc_41618862220_item	2398071	et	4	main
suitsetavad	doc_41618862220_item	2398074	et	4	main
j	doc_41618862220_item	2398075	et	4	main
elada	doc_41618862220_item	2398084	et	3	main
kujuta	doc_41618862220_item	2398095	et	4	main
ette	doc_41618862220_item	2398096	et	4	main
neist	doc_41618862220_item	2398102	et	4	main
kuid	doc_41618862220_item	2398108	et	4	main
mind	doc_41618862220_item	2398114	et	4	main
treeningut	doc_41618862220_item	2398125	et	3	main
see	doc_41618862220_item	2398126	et	3	main
transport	doc_41618862220_item	2398146	et	3	main
sellele	doc_41618862220_item	2398148	et	4	main
väga	doc_41618862220_item	2398153	et	3	main
õpikud	doc_41618862221_item	2398186	et	3	main
on	doc_41618862221_item	2398187	et	4	main
koolis	doc_41618862221_item	2398190	et	4	main
minu	doc_41618862221_item	2398191	et	3	main
arvates	doc_41618862221_item	2398192	et	4	main
palju	doc_41618862221_item	2398197	et	4	main
on	doc_41618862221_item	2398203	et	4	main
mille	doc_41618862221_item	2398205	et	3	main
koolis	doc_41618862221_item	2398212	et	4	main
ole	doc_41618862221_item	2398221	et	4	main
lihtsalt	doc_41618862221_item	2398230	et	4	main
ole	doc_41618862221_item	2398232	et	4	main
kaks	doc_41618862221_item	2398239	et	3	main
peaks	doc_41618862221_item	2398251	et	4	main
inimene	doc_41618862221_item	2398252	et	3	main
tegema	doc_41618862221_item	2398253	et	3	main
et	doc_41618862221_item	2398254	et	3	main
võimalust	doc_41618862221_item	2398264	et	3	main
osta	doc_41618862221_item	2398268	et	4	main
gaasirelvi	doc_41618862221_item	2398269	et	4	main
ja	doc_41618862221_item	2398270	et	3	main
sellepärast	doc_41618862221_item	2398271	et	3	main
kaklemine	doc_41618862221_item	2398279	et	4	main
narkootikumide	doc_41618862221_item	2398281	et	3	main
pole	doc_41618862221_item	2398284	et	3	main
arvan	doc_41618862221_item	2398288	et	3	main
on	doc_41618862221_item	2398291	et	4	main
sest	doc_41618862221_item	2398326	et	4	main
ainult	doc_41618862221_item	2398329	et	4	main
tahab	doc_41618862219_item	2397923	et	3	main
edukus	doc_41618862219_item	2397941	et	4	main
kõrge	doc_41618862219_item	2397948	et	4	main
kvalifikatsiooniga	doc_41618862219_item	2397949	et	3	main
asjatundja	doc_41618862219_item	2397952	et	4	main
firma	doc_41618862219_item	2397959	et	4	main
edukus	doc_41618862219_item	2397960	et	4	main
sõltub	doc_41618862219_item	2397961	et	3	main
heast	doc_41618862219_item	2397962	et	3	main
meedia	doc_41618862219_item	2397974	et	4	main
toovad	doc_41618862219_item	2397987	et	4	main
ka	doc_41618862219_item	2397988	et	3	main
edukust	doc_41618862219_item	2397990	et	4	main
ka	doc_41618862219_item	2397991	et	3	main
firmal	doc_41618862219_item	2397992	et	3	main
peab	doc_41618862219_item	2397993	et	4	main
olema	doc_41618862219_item	2397994	et	4	main
kindlasti	doc_41618862219_item	2397999	et	3	main
peab	doc_41618862219_item	2398009	et	4	main
olema	doc_41618862219_item	2398010	et	4	main
täpne	doc_41618862219_item	2398011	et	3	main
eesmärk	doc_41618862219_item	2398012	et	3	main
mida	doc_41618862219_item	2398013	et	4	main
ta	doc_41618862219_item	2398014	et	4	main
tahab	doc_41618862219_item	2398015	et	3	main
teha	doc_41618862219_item	2398016	et	3	main
kontrolltöö	doc_41618862220_item	2398017	et	4	main
mida	doc_41618862220_item	2398018	et	4	main
saab	doc_41618862220_item	2398019	et	3	main
inimene	doc_41618862220_item	2398020	et	3	main
ise	doc_41618862220_item	2398021	et	4	main
väga	doc_41618862220_item	2398026	et	3	main
tervislik	doc_41618862220_item	2398031	et	3	main
mitte	doc_41618862220_item	2398033	et	3	main
rasked	doc_41618862220_item	2398035	et	3	main
üldse	doc_41618862220_item	2398039	et	3	main
kuid	doc_41618862220_item	2398042	et	4	main
kindlusta	doc_41618862220_item	2398046	et	4	main
on	doc_41618862220_item	2398050	et	4	main
võimalusi	doc_41618862220_item	2398065	et	3	main
terveks	doc_41618862220_item	2398066	et	4	main
e	doc_41618862220_item	2398077	et	4	main
milliste	doc_41618862220_item	2398079	et	3	main
leiutisteta	doc_41618862220_item	2398080	et	3	main
sa	doc_41618862220_item	2398081	et	3	main
ei	doc_41618862220_item	2398082	et	4	main
saaks	doc_41618862220_item	2398083	et	3	main
elus	doc_41618862220_item	2398087	et	4	main
palju	doc_41618862220_item	2398089	et	4	main
asju	doc_41618862220_item	2398090	et	3	main
ilma	doc_41618862220_item	2398091	et	4	main
millist	doc_41618862220_item	2398092	et	3	main
ma	doc_41618862220_item	2398093	et	3	main
ei	doc_41618862220_item	2398094	et	4	main
tähtsamad	doc_41618862220_item	2398101	et	4	main
jalgrattas	doc_41618862220_item	2398105	et	3	main
jalgrattast	doc_41618862220_item	2398110	et	4	main
ei	doc_41618862220_item	2398121	et	4	main
mingisugust	doc_41618862220_item	2398123	et	3	main
jalgrattas	doc_41618862220_item	2398133	et	3	main
nagu	doc_41618862220_item	2398134	et	3	main
kõik	doc_41618862220_item	2398135	et	4	main
väga	doc_41618862220_item	2398144	et	3	main
lisaks	doc_41618862220_item	2398147	et	4	main
on	doc_41618862220_item	2398152	et	4	main
mina	doc_41618862220_item	2398163	et	4	main
sõitsin	doc_41618862220_item	2398164	et	3	main
on	doc_41618862221_item	2398184	et	4	main
halvad	doc_41618862221_item	2398189	et	4	main
ja	doc_41618862221_item	2398199	et	3	main
ülekoormus	doc_41618862221_item	2398204	et	3	main
koolis	doc_41618862221_item	2398211	et	4	main
iga	doc_41618862221_item	2398216	et	4	main
haritud	doc_41618862219_item	2397925	et	4	main
kui	doc_41618862219_item	2397926	et	3	main
ta	doc_41618862219_item	2397932	et	4	main
on	doc_41618862219_item	2397933	et	4	main
muidugi	doc_41618862219_item	2397934	et	4	main
tahab	doc_41618862219_item	2397935	et	3	main
lugeda	doc_41618862219_item	2397936	et	3	main
firma	doc_41618862219_item	2397940	et	4	main
kui	doc_41618862219_item	2397945	et	3	main
kindlasti	doc_41618862219_item	2397956	et	3	main
ka	doc_41618862219_item	2397958	et	3	main
on	doc_41618862219_item	2397966	et	4	main
kui	doc_41618862219_item	2397970	et	3	main
on	doc_41618862219_item	2397972	et	4	main
õige	doc_41618862219_item	2397973	et	4	main
kes	doc_41618862219_item	2397983	et	4	main
annavad	doc_41618862219_item	2397984	et	3	main
palju	doc_41618862219_item	2397985	et	4	main
kasumit	doc_41618862219_item	2397986	et	3	main
tugev	doc_41618862219_item	2397995	et	4	main
positsioon	doc_41618862219_item	2397996	et	3	main
väljatuleks	doc_41618862219_item	2398003	et	3	main
oluline	doc_41618862219_item	2398006	et	4	main
et	doc_41618862219_item	2398007	et	3	main
firmal	doc_41618862219_item	2398008	et	3	main
oma	doc_41618862220_item	2398023	et	4	main
tervisele	doc_41618862220_item	2398029	et	3	main
ja	doc_41618862220_item	2398038	et	3	main
tervislik	doc_41618862220_item	2398040	et	3	main
inimene	doc_41618862220_item	2398049	et	3	main
kui	doc_41618862220_item	2398068	et	3	main
n	doc_41618862220_item	2398076	et	4	main
miks	doc_41618862220_item	2398085	et	4	main
on	doc_41618862220_item	2398088	et	4	main
minu	doc_41618862220_item	2398097	et	3	main
elu	doc_41618862220_item	2398098	et	4	main
võib-olla	doc_41618862220_item	2398099	et	3	main
esiteks	doc_41618862220_item	2398111	et	3	main
aitab	doc_41618862220_item	2398113	et	3	main
vormis	doc_41618862220_item	2398117	et	4	main
olla	doc_41618862220_item	2398118	et	3	main
heaks	doc_41618862220_item	2398025	et	4	main
treeningud	doc_41618862220_item	2398037	et	3	main
isegi	doc_41618862220_item	2398043	et	4	main
see	doc_41618862220_item	2398044	et	3	main
ei	doc_41618862220_item	2398045	et	4	main
absoluutselt	doc_41618862220_item	2398051	et	4	main
terve	doc_41618862220_item	2398052	et	4	main
kuid	doc_41618862220_item	2398053	et	4	main
proovida	doc_41618862220_item	2398054	et	3	main
võib	doc_41618862220_item	2398055	et	3	main
alati	doc_41618862220_item	2398056	et	4	main
sest	doc_41618862220_item	2398057	et	4	main
inimestel	doc_41618862220_item	2398058	et	3	main
kes	doc_41618862220_item	2398059	et	4	main
viivad	doc_41618862220_item	2398060	et	4	main
tervislikku	doc_41618862220_item	2398061	et	4	main
kes	doc_41618862220_item	2398070	et	4	main
kõige	doc_41618862220_item	2398100	et	4	main
on	doc_41618862220_item	2398103	et	4	main
mobiiltelefon	doc_41618862220_item	2398107	et	3	main
füüsilises	doc_41618862220_item	2398116	et	3	main
lisaks	doc_41618862220_item	2398119	et	4	main
kõige	doc_41618862220_item	2398128	et	4	main
füüsilised	doc_41618862220_item	2398137	et	3	main
koormused	doc_41618862220_item	2398138	et	3	main
stressi	doc_41618862220_item	2398140	et	4	main
vastu	doc_41618862220_item	2398141	et	3	main
see	doc_41618862220_item	2398142	et	3	main
on	doc_41618862220_item	2398143	et	4	main
mugav	doc_41618862220_item	2398145	et	3	main
keskkonnasõbralik	doc_41618862220_item	2398151	et	3	main
meil	doc_41618862220_item	2398156	et	4	main
lapsed	doc_41618862221_item	2398183	et	3	main
on	doc_41618862221_item	2398193	et	4	main
sellepärast	doc_41618862221_item	2398200	et	3	main
õppimine	doc_41618862221_item	2398208	et	4	main
vaja	doc_41618862221_item	2398214	et	4	main
sul	doc_41618862221_item	2398229	et	3	main
ei	doc_41618862221_item	2398231	et	4	main
võimalik	doc_41618862221_item	2398233	et	3	main
käia	doc_41618862221_item	2398234	et	4	main
igapäev	doc_41618862221_item	2398235	et	3	main
korda	doc_41618862221_item	2398240	et	4	main
aastas	doc_41618862221_item	2398249	et	3	main
mida	doc_41618862221_item	2398250	et	4	main
vältida	doc_41618862221_item	2398255	et	3	main
igal	doc_41618862221_item	2398260	et	3	main
või	doc_41618862221_item	2398267	et	4	main
kui	doc_41618862221_item	2398275	et	3	main
väide	doc_41618862221_item	2398321	et	4	main
peab	doc_41618862221_item	2398323	et	4	main
seal	doc_41618862221_item	2398327	et	4	main
vastused	doc_41618862221_item	2398330	et	3	main
kus	doc_41618862221_item	2398332	et	3	main
ei	doc_41618862221_item	2398333	et	4	main
ja	doc_41618862221_item	2398346	et	3	main
ma	doc_41618862221_item	2398352	et	3	main
nendes	doc_41618862221_item	2398362	et	4	main
eest	doc_41618862221_item	2398371	et	4	main
endast	doc_41618862221_item	2398378	et	4	main
ma	doc_41618862221_item	2398383	et	3	main
tõsi	doc_41618862222_item	2398421	et	4	main
sina	doc_41618862222_item	2398423	et	4	main
riietust	doc_41618862222_item	2398435	et	4	main
valid	doc_41618862222_item	2398437	et	3	main
tööintervjuuks	doc_41618862222_item	2398438	et	3	main
lõhna	doc_41618862222_item	2398442	et	4	main
ka	doc_41618862222_item	2398444	et	3	main
tähtsam	doc_41618862222_item	2398447	et	4	main
cv	doc_41618862222_item	2398468	et	4	main
nagu	doc_41618862222_item	2398483	et	3	main
aastal	doc_41618862222_item	2398486	et	3	main
aitavad	doc_41618862222_item	2398498	et	4	main
aitab	doc_41618862222_item	2398505	et	3	main
ka	doc_41618862222_item	2398515	et	3	main
lihtsalt	doc_41618862222_item	2398519	et	4	main
selle	doc_41618862222_item	2398523	et	4	main
kes	doc_41618862222_item	2398534	et	4	main
haiseb	doc_41618862222_item	2398535	et	3	main
arva	doc_41618862222_item	2398543	et	4	main
on	doc_41618862222_item	2398555	et	4	main
praegu	doc_41618862222_item	2398556	et	3	main
ülekoormus	doc_41618862222_item	2398561	et	3	main
ei	doc_41618862222_item	2398566	et	4	main
pärast	doc_41618862222_item	2398593	et	4	main
õppimine	doc_41618862222_item	2398601	et	4	main
koolis	doc_41618862222_item	2398604	et	4	main
tavalisel	doc_41618862222_item	2398621	et	4	main
pea	doc_41618862222_item	2398623	et	4	main
ka	doc_41618862222_item	2398624	et	3	main
tegema	doc_41618862222_item	2398625	et	3	main
kirja	doc_41618862222_item	2398631	et	4	main
kolm	doc_41618862222_item	2398632	et	3	main
soovitust	doc_41618862222_item	2398633	et	4	main
elektriseadmetega	doc_41618862222_item	2398634	et	3	main
riski	doc_41618862222_item	2398660	et	4	main
olemusest	doc_41618862222_item	2398667	et	4	main
kus	doc_41618862222_item	2398668	et	3	main
varem	doc_41618862222_item	2398670	et	4	main
kui	doc_41618862222_item	2398703	et	3	main
spetsiaalset	doc_41618862220_item	2398124	et	3	main
jaoks	doc_41618862220_item	2398132	et	4	main
teised	doc_41618862220_item	2398136	et	4	main
aitab	doc_41618862220_item	2398139	et	3	main
halb	doc_41618862220_item	2398154	et	3	main
et	doc_41618862220_item	2398155	et	3	main
on	doc_41618862220_item	2398157	et	4	main
vähe	doc_41618862220_item	2398159	et	3	main
parkimisplatsi	doc_41618862220_item	2398160	et	4	main
jalgrattastele	doc_41618862220_item	2398161	et	4	main
muidu	doc_41618862220_item	2398162	et	3	main
alati	doc_41618862220_item	2398165	et	4	main
sellega	doc_41618862220_item	2398166	et	3	main
span	doc_41618862220_item	2398167	et	4	main
kontrolltöö	doc_41618862221_item	2398168	et	4	main
mis	doc_41618862221_item	2398169	et	4	main
on	doc_41618862221_item	2398170	et	4	main
praegu	doc_41618862221_item	2398171	et	3	main
koolis	doc_41618862221_item	2398172	et	4	main
kõige	doc_41618862221_item	2398173	et	4	main
suuremad	doc_41618862221_item	2398174	et	4	main
probleemid	doc_41618862221_item	2398175	et	3	main
esimene	doc_41618862221_item	2398176	et	3	main
probleem	doc_41618862221_item	2398177	et	3	main
on	doc_41618862221_item	2398178	et	4	main
see	doc_41618862221_item	2398179	et	3	main
et	doc_41618862221_item	2398180	et	3	main
mitte	doc_41618862221_item	2398181	et	3	main
andekad	doc_41618862221_item	2398182	et	3	main
väga	doc_41618862221_item	2398188	et	3	main
vaja	doc_41618862221_item	2398194	et	4	main
teha	doc_41618862221_item	2398195	et	3	main
liiga	doc_41618862221_item	2398196	et	4	main
paljudel	doc_41618862221_item	2398201	et	3	main
erineb	doc_41618862221_item	2398207	et	3	main
kõrgkoolis	doc_41618862221_item	2398209	et	4	main
õppimisest	doc_41618862221_item	2398210	et	4	main
käia	doc_41618862221_item	2398215	et	4	main
kõrgkoolis	doc_41618862221_item	2398236	et	4	main
on	doc_41618862221_item	2398237	et	4	main
eksamid	doc_41618862221_item	2398238	et	3	main
kuriteo	doc_41618862221_item	2398256	et	4	main
riski	doc_41618862221_item	2398259	et	4	main
ole	doc_41618862221_item	2398263	et	4	main
õppida	doc_41618862221_item	2398265	et	3	main
politseinikud	doc_41618862221_item	2398272	et	4	main
juhtub	doc_41618862221_item	2398277	et	3	main
tööintervjuuks	doc_41618862221_item	2398283	et	3	main
et	doc_41618862221_item	2398289	et	3	main
poolest	doc_41618862221_item	2398206	et	4	main
on	doc_41618862221_item	2398213	et	4	main
vaja	doc_41618862221_item	2398222	et	4	main
näiteks	doc_41618862221_item	2398223	et	4	main
kui	doc_41618862221_item	2398224	et	3	main
sa	doc_41618862221_item	2398225	et	3	main
töötad	doc_41618862221_item	2398226	et	3	main
siis	doc_41618862221_item	2398228	et	3	main
aastas	doc_41618862221_item	2398241	et	3	main
eksamid	doc_41618862221_item	2398244	et	3	main
sattumise	doc_41618862221_item	2398258	et	4	main
inimesel	doc_41618862221_item	2398261	et	3	main
linnas	doc_41618862221_item	2398278	et	4	main
vaja	doc_41618862221_item	2398285	et	4	main
ma	doc_41618862221_item	2398287	et	3	main
natukene	doc_41618862221_item	2398290	et	4	main
vaja	doc_41618862221_item	2398292	et	4	main
valmistuda	doc_41618862221_item	2398293	et	3	main
aga	doc_41618862221_item	2398294	et	3	main
on	doc_41618862221_item	2398295	et	4	main
ka	doc_41618862221_item	2398296	et	3	main
kasulik	doc_41618862221_item	2398297	et	3	main
teada	doc_41618862221_item	2398298	et	3	main
lühike	doc_41618862221_item	2398325	et	4	main
kirjand	doc_41618862221_item	2398342	et	3	main
hea	doc_41618862221_item	2398347	et	4	main
tööd	doc_41618862221_item	2398350	et	4	main
taha	doc_41618862221_item	2398360	et	4	main
inimesed	doc_41618862221_item	2398365	et	3	main
palju	doc_41618862221_item	2398379	et	4	main
rääkima	doc_41618862221_item	2398380	et	3	main
ühest	doc_41618862221_item	2398381	et	4	main
kui	doc_41618862222_item	2398422	et	3	main
valmistuda	doc_41618862222_item	2398429	et	3	main
sa	doc_41618862222_item	2398436	et	3	main
minnes	doc_41618862222_item	2398439	et	3	main
mis	doc_41618862222_item	2398440	et	4	main
kõige	doc_41618862222_item	2398446	et	4	main
on	doc_41618862222_item	2398448	et	4	main
teada	doc_41618862222_item	2398449	et	3	main
miks	doc_41618862222_item	2398450	et	4	main
sa	doc_41618862222_item	2398451	et	3	main
seda	doc_41618862222_item	2398452	et	3	main
tööd	doc_41618862222_item	2398453	et	4	main
tahad	doc_41618862222_item	2398454	et	3	main
olema	doc_41618862222_item	2398464	et	4	main
ja	doc_41618862222_item	2398466	et	3	main
is	doc_41618862222_item	2398469	et	4	main
ja	doc_41618862222_item	2398470	et	3	main
ja	doc_41618862222_item	2398476	et	3	main
tuleb	doc_41618862222_item	2398479	et	3	main
fraase	doc_41618862222_item	2398482	et	3	main
roti	doc_41618862222_item	2398485	et	3	main
olen	doc_41618862222_item	2398489	et	3	main
hea	doc_41618862222_item	2398496	et	4	main
aga	doc_41618862222_item	2398502	et	3	main
see	doc_41618862222_item	2398504	et	3	main
muljet	doc_41618862222_item	2398507	et	3	main
ja	doc_41618862222_item	2398509	et	3	main
ja	doc_41618862222_item	2398518	et	3	main
inimesega	doc_41618862222_item	2398524	et	3	main
kellel	doc_41618862222_item	2398529	et	4	main
on	doc_41618862222_item	2398530	et	4	main
nii	doc_41618862222_item	2398544	et	3	main
intervjuul	doc_41618862222_item	2398545	et	3	main
pead	doc_41618862222_item	2398546	et	4	main
olema	doc_41618862222_item	2398547	et	4	main
lakooniline	doc_41618862222_item	2398548	et	3	main
ja	doc_41618862222_item	2398549	et	3	main
tuleb	doc_41618862222_item	2398551	et	3	main
liiga	doc_41618862222_item	2398562	et	4	main
mida	doc_41618862222_item	2398568	et	4	main
konspekti	doc_41618862222_item	2398595	et	4	main
luuletust	doc_41618862222_item	2398597	et	4	main
mille	doc_41618862222_item	2398598	et	3	main
poolest	doc_41618862222_item	2398599	et	4	main
erineb	doc_41618862222_item	2398600	et	3	main
kõrgkoolis	doc_41618862222_item	2398605	et	4	main
valid	doc_41618862222_item	2398607	et	3	main
ained	doc_41618862222_item	2398608	et	3	main
millal	doc_41618862222_item	2398610	et	3	main
sügis	doc_41618862222_item	2398618	et	3	main
kasutage	doc_41618862222_item	2398637	et	3	main
kukkuda	doc_41618862222_item	2398646	et	3	main
minnes	doc_41618862222_item	2398663	et	3	main
et	doc_41618862222_item	2398690	et	3	main
päev	doc_41618862221_item	2398217	et	3	main
aga	doc_41618862221_item	2398218	et	3	main
kõrgkoolis	doc_41618862221_item	2398219	et	4	main
ei	doc_41618862221_item	2398220	et	4	main
kuskil	doc_41618862221_item	2398227	et	3	main
aga	doc_41618862221_item	2398242	et	3	main
koolis	doc_41618862221_item	2398243	et	4	main
on	doc_41618862221_item	2398245	et	4	main
ainult	doc_41618862221_item	2398246	et	4	main
üks	doc_41618862221_item	2398247	et	3	main
kord	doc_41618862221_item	2398248	et	4	main
ohvriks	doc_41618862221_item	2398257	et	3	main
ei	doc_41618862221_item	2398262	et	4	main
dzjudot	doc_41618862221_item	2398266	et	4	main
peavad	doc_41618862221_item	2398273	et	4	main
sekkuma	doc_41618862221_item	2398274	et	3	main
midagi	doc_41618862221_item	2398276	et	4	main
kallaletung	doc_41618862221_item	2398280	et	3	main
levitamine	doc_41618862221_item	2398282	et	4	main
valmistuda	doc_41618862221_item	2398286	et	3	main
et	doc_41618862221_item	2398299	et	3	main
ei	doc_41618862221_item	2398300	et	4	main
maksa	doc_41618862221_item	2398301	et	4	main
tööintervjuul	doc_41618862221_item	2398302	et	3	main
endast	doc_41618862221_item	2398303	et	4	main
vägisi	doc_41618862221_item	2398304	et	3	main
kedagi	doc_41618862221_item	2398305	et	4	main
kujutada	doc_41618862221_item	2398307	et	3	main
cv	doc_41618862221_item	2398308	et	4	main
ja	doc_41618862221_item	2398309	et	3	main
avaldus	doc_41618862221_item	2398310	et	4	main
teist	doc_41618862221_item	2398306	et	4	main
peavad	doc_41618862221_item	2398311	et	4	main
olema	doc_41618862221_item	2398312	et	4	main
lühikesed	doc_41618862221_item	2398313	et	4	main
ja	doc_41618862221_item	2398314	et	3	main
lakoonilised	doc_41618862221_item	2398315	et	3	main
minu	doc_41618862221_item	2398316	et	3	main
arvates	doc_41618862221_item	2398317	et	4	main
see	doc_41618862221_item	2398318	et	3	main
on	doc_41618862221_item	2398319	et	4	main
õige	doc_41618862221_item	2398320	et	4	main
olema	doc_41618862221_item	2398324	et	4	main
ole	doc_41618862221_item	2398334	et	4	main
vaja	doc_41618862221_item	2398335	et	4	main
pikkalt	doc_41618862221_item	2398336	et	3	main
sobiv	doc_41618862221_item	2398344	et	4	main
välimus	doc_41618862221_item	2398348	et	3	main
leida	doc_41618862221_item	2398351	et	3	main
nõus	doc_41618862221_item	2398355	et	4	main
sest	doc_41618862221_item	2398356	et	4	main
et	doc_41618862221_item	2398361	et	3	main
firmas	doc_41618862221_item	2398363	et	3	main
peab	doc_41618862221_item	2398377	et	4	main
küljest	doc_41618862221_item	2398382	et	4	main
cv	doc_41618862221_item	2398322	et	4	main
on	doc_41618862221_item	2398328	et	4	main
küsimustele	doc_41618862221_item	2398331	et	4	main
ei	doc_41618862221_item	2398339	et	4	main
ole	doc_41618862221_item	2398340	et	4	main
ka	doc_41618862221_item	2398341	et	3	main
riietus	doc_41618862221_item	2398345	et	4	main
inimesed	doc_41618862221_item	2398358	et	3	main
ei	doc_41618862221_item	2398359	et	4	main
töötavad	doc_41618862221_item	2398364	et	4	main
ei	doc_41618862221_item	2398367	et	4	main
enda	doc_41618862221_item	2398370	et	4	main
nägu	doc_41618862221_item	2398375	et	4	main
tööintervjuul	doc_41618862221_item	2398376	et	3	main
sellega	doc_41618862221_item	2398385	et	3	main
nõus	doc_41618862221_item	2398386	et	4	main
on	doc_41618862221_item	2398388	et	4	main
sest	doc_41618862221_item	2398387	et	4	main
parem	doc_41618862221_item	2398389	et	4	main
rääkida	doc_41618862221_item	2398390	et	3	main
kui	doc_41618862221_item	2398391	et	3	main
vakke	doc_41618862221_item	2398392	et	3	main
olla	doc_41618862221_item	2398393	et	3	main
aga	doc_41618862221_item	2398394	et	3	main
teisest	doc_41618862221_item	2398395	et	4	main
küljest	doc_41618862221_item	2398396	et	4	main
ei	doc_41618862221_item	2398397	et	4	main
tohi	doc_41618862221_item	2398398	et	4	main
ka	doc_41618862221_item	2398399	et	3	main
liiga	doc_41618862221_item	2398400	et	4	main
palju	doc_41618862221_item	2398401	et	4	main
rääkida	doc_41618862221_item	2398402	et	3	main
sest	doc_41618862221_item	2398403	et	4	main
tavaliset	doc_41618862221_item	2398404	et	4	main
ainult	doc_41618862221_item	2398405	et	4	main
rumalad	doc_41618862221_item	2398406	et	3	main
inimesed	doc_41618862221_item	2398407	et	3	main
räägivad	doc_41618862221_item	2398408	et	3	main
palju	doc_41618862221_item	2398409	et	4	main
kontrolltöö	doc_41618862222_item	2398410	et	4	main
tööintervjuuks	doc_41618862222_item	2398411	et	3	main
pole	doc_41618862222_item	2398412	et	3	main
vaja	doc_41618862222_item	2398413	et	4	main
valmistuda	doc_41618862222_item	2398414	et	3	main
mina	doc_41618862222_item	2398415	et	4	main
arvan	doc_41618862222_item	2398416	et	3	main
et	doc_41618862222_item	2398417	et	3	main
see	doc_41618862222_item	2398418	et	3	main
ei	doc_41618862222_item	2398419	et	4	main
ole	doc_41618862222_item	2398420	et	4	main
kirjutada	doc_41618862221_item	2398337	et	3	main
avaldus	doc_41618862221_item	2398338	et	4	main
p	doc_41618862221_item	2398343	et	4	main
aitavad	doc_41618862221_item	2398349	et	4	main
olen	doc_41618862221_item	2398353	et	3	main
sellega	doc_41618862221_item	2398354	et	3	main
tavaliselt	doc_41618862221_item	2398357	et	4	main
kes	doc_41618862221_item	2398366	et	4	main
saa	doc_41618862221_item	2398368	et	4	main
hoolitsema	doc_41618862221_item	2398369	et	4	main
töötajad	doc_41618862221_item	2398372	et	4	main
on	doc_41618862221_item	2398373	et	4	main
firma	doc_41618862221_item	2398374	et	4	main
olen	doc_41618862221_item	2398384	et	3	main
soovid	doc_41618862222_item	2398424	et	4	main
tuleb	doc_41618862222_item	2398427	et	3	main
mõtlema	doc_41618862222_item	2398431	et	3	main
avaldus	doc_41618862222_item	2398462	et	4	main
lühikesed	doc_41618862222_item	2398465	et	4	main
lakoonilised	doc_41618862222_item	2398467	et	3	main
ennast	doc_41618862222_item	2398475	et	4	main
oskusest	doc_41618862222_item	2398478	et	4	main
vältida	doc_41618862222_item	2398480	et	3	main
sündinud	doc_41618862222_item	2398487	et	4	main
neitsi	doc_41618862222_item	2398490	et	4	main
horoskopi	doc_41618862222_item	2398491	et	4	main
järgi	doc_41618862222_item	2398492	et	4	main
välimus	doc_41618862222_item	2398497	et	3	main
muidugi	doc_41618862222_item	2398501	et	4	main
esiteks	doc_41618862222_item	2398503	et	3	main
head	doc_41618862222_item	2398506	et	4	main
sellepärast	doc_41618862222_item	2398510	et	3	main
tööd	doc_41618862222_item	2398511	et	4	main
intervjuueerija	doc_41618862222_item	2398513	et	4	main
on	doc_41618862222_item	2398514	et	4	main
tavaline	doc_41618862222_item	2398516	et	4	main
inimene	doc_41618862222_item	2398517	et	3	main
tööd	doc_41618862222_item	2398425	et	4	main
tuleb	doc_41618862222_item	2398430	et	3	main
selle	doc_41618862222_item	2398432	et	4	main
peale	doc_41618862222_item	2398433	et	4	main
parfüümi	doc_41618862222_item	2398441	et	4	main
ja	doc_41618862222_item	2398455	et	3	main
intervjuueerijale	doc_41618862222_item	2398458	et	4	main
seletada	doc_41618862222_item	2398459	et	3	main
cv	doc_41618862222_item	2398460	et	4	main
ja	doc_41618862222_item	2398461	et	3	main
avalduses	doc_41618862222_item	2398471	et	4	main
tuleb	doc_41618862222_item	2398472	et	3	main
lühidalt	doc_41618862222_item	2398473	et	4	main
rääkida	doc_41618862222_item	2398474	et	3	main
olen	doc_41618862222_item	2398484	et	3	main
ja	doc_41618862222_item	2398488	et	3	main
riietus	doc_41618862222_item	2398494	et	4	main
ja	doc_41618862222_item	2398495	et	3	main
leida	doc_41618862222_item	2398500	et	3	main
ei	doc_41618862222_item	2398520	et	4	main
ole	doc_41618862222_item	2398521	et	4	main
töötada	doc_41618862222_item	2398528	et	3	main
ja	doc_41618862222_item	2398533	et	3	main
tööintervjuul	doc_41618862222_item	2398536	et	3	main
peab	doc_41618862222_item	2398537	et	4	main
endast	doc_41618862222_item	2398538	et	4	main
palju	doc_41618862222_item	2398539	et	4	main
rääkima	doc_41618862222_item	2398540	et	3	main
ma	doc_41618862222_item	2398541	et	3	main
väldida	doc_41618862222_item	2398552	et	4	main
lobimisest	doc_41618862222_item	2398553	et	4	main
keerulised	doc_41618862222_item	2398563	et	4	main
tea	doc_41618862222_item	2398567	et	4	main
kõrgkoolis	doc_41618862222_item	2398602	et	4	main
või	doc_41618862222_item	2398617	et	4	main
leida	doc_41618862222_item	2398426	et	3	main
ikkagi	doc_41618862222_item	2398428	et	4	main
mis	doc_41618862222_item	2398434	et	4	main
valid	doc_41618862222_item	2398443	et	3	main
aga	doc_41618862222_item	2398445	et	3	main
osata	doc_41618862222_item	2398456	et	4	main
seda	doc_41618862222_item	2398457	et	3	main
peavad	doc_41618862222_item	2398463	et	4	main
oma	doc_41618862222_item	2398477	et	4	main
niisuguseid	doc_41618862222_item	2398481	et	3	main
sobiv	doc_41618862222_item	2398493	et	4	main
tööd	doc_41618862222_item	2398499	et	4	main
jääda	doc_41618862222_item	2398508	et	4	main
leida	doc_41618862222_item	2398512	et	3	main
meeldiv	doc_41618862222_item	2398522	et	4	main
pärast	doc_41618862222_item	2398527	et	4	main
must	doc_41618862222_item	2398531	et	4	main
mis	doc_41618862222_item	2398554	et	4	main
probleemid	doc_41618862222_item	2398560	et	3	main
õpetaja	doc_41618862222_item	2398565	et	4	main
soovid	doc_41618862222_item	2398612	et	4	main
õppida	doc_41618862222_item	2398614	et	3	main
semestril	doc_41618862222_item	2398619	et	3	main
juukse	doc_41618862222_item	2398648	et	3	main
vannitoas	doc_41618862222_item	2398650	et	3	main
hilja	doc_41618862222_item	2398661	et	3	main
koju	doc_41618862222_item	2398662	et	3	main
teie	doc_41618862222_item	2398704	et	4	main
minuti	doc_41618862222_item	2398707	et	3	main
seadme	doc_41618862222_item	2398710	et	3	main
stepsli	doc_41618862222_item	2398712	et	3	main
hoides	doc_41618862222_item	2398713	et	4	main
ärge	doc_41618862222_item	2398722	et	3	main
seadmet	doc_41618862222_item	2398726	et	4	main
profesionaali	doc_41618862222_item	2398735	et	4	main
jaoks	doc_41618862222_item	2398736	et	4	main
et	doc_41618862223_item	2398745	et	3	main
kes	doc_41618862223_item	2398747	et	4	main
head	doc_41618862223_item	2398750	et	4	main
suhtlemine	doc_41618862223_item	2398760	et	4	main
paremini	doc_41618862223_item	2398762	et	4	main
peavad	doc_41618862223_item	2398771	et	4	main
cv	doc_41618862223_item	2398778	et	4	main
sa	doc_41618862223_item	2398787	et	3	main
pead	doc_41618862223_item	2398792	et	4	main
palju	doc_41618862223_item	2398794	et	4	main
kirjutada	doc_41618862223_item	2398795	et	3	main
see	doc_41618862223_item	2398796	et	3	main
on	doc_41618862223_item	2398797	et	4	main
nii	doc_41618862223_item	2398798	et	3	main
rääkida	doc_41618862222_item	2398525	et	3	main
ja	doc_41618862222_item	2398526	et	3	main
riietus	doc_41618862222_item	2398532	et	4	main
ei	doc_41618862222_item	2398542	et	4	main
enesekindel	doc_41618862222_item	2398550	et	3	main
koolis	doc_41618862222_item	2398557	et	4	main
kõige	doc_41618862222_item	2398558	et	4	main
suuremad	doc_41618862222_item	2398559	et	4	main
õpikud	doc_41618862222_item	2398564	et	3	main
on	doc_41618862222_item	2398569	et	4	main
tähtsam	doc_41618862222_item	2398570	et	4	main
õpetama	doc_41618862222_item	2398571	et	3	main
ja	doc_41618862222_item	2398572	et	3	main
annab	doc_41618862222_item	2398573	et	3	main
nii	doc_41618862222_item	2398574	et	3	main
palju	doc_41618862222_item	2398575	et	4	main
kui	doc_41618862222_item	2398576	et	3	main
võimalik	doc_41618862222_item	2398577	et	3	main
on	doc_41618862222_item	2398578	et	4	main
mida	doc_41618862222_item	2398579	et	4	main
rohkem	doc_41618862222_item	2398580	et	4	main
seda	doc_41618862222_item	2398581	et	3	main
parem	doc_41618862222_item	2398582	et	4	main
ei	doc_41618862222_item	2398583	et	4	main
tekki	doc_41618862222_item	2398584	et	4	main
dialoogi	doc_41618862222_item	2398585	et	4	main
lastel	doc_41618862222_item	2398586	et	4	main
õpetajaga	doc_41618862222_item	2398587	et	4	main
nad	doc_41618862222_item	2398588	et	3	main
lapsed	doc_41618862222_item	2398589	et	3	main
lihtsalt	doc_41618862222_item	2398590	et	4	main
ja	doc_41618862222_item	2398592	et	3	main
konspekteerivad	doc_41618862222_item	2398591	et	4	main
õpivad	doc_41618862222_item	2398594	et	3	main
nagu	doc_41618862222_item	2398596	et	3	main
õppimisest	doc_41618862222_item	2398603	et	4	main
ise	doc_41618862222_item	2398606	et	4	main
ja	doc_41618862222_item	2398609	et	3	main
sa	doc_41618862222_item	2398611	et	3	main
neid	doc_41618862222_item	2398613	et	4	main
näiteks	doc_41618862222_item	2398615	et	4	main
kevad-	doc_41618862222_item	2398616	et	3	main
kõrgkoolis	doc_41618862222_item	2398620	et	4	main
ei	doc_41618862222_item	2398622	et	4	main
koduseid	doc_41618862222_item	2398626	et	4	main
ärge	doc_41618862222_item	2398636	et	3	main
töötavate	doc_41618862222_item	2398639	et	4	main
seal	doc_41618862222_item	2398641	et	4	main
kus	doc_41618862222_item	2398642	et	3	main
ta	doc_41618862222_item	2398643	et	4	main
võib	doc_41618862222_item	2398644	et	3	main
näiteks	doc_41618862222_item	2398647	et	4	main
fönni	doc_41618862222_item	2398649	et	4	main
ohvriks	doc_41618862222_item	2398658	et	3	main
vältige	doc_41618862222_item	2398664	et	3	main
kohtudes	doc_41618862222_item	2398666	et	3	main
teie	doc_41618862222_item	2398669	et	4	main
vaja	doc_41618862222_item	2398693	et	4	main
abi	doc_41618862222_item	2398694	et	4	main
lukku	doc_41618862222_item	2398699	et	4	main
ikkagi	doc_41618862222_item	2398700	et	4	main
sel	doc_41618862222_item	2398701	et	3	main
hoides	doc_41618862222_item	2398717	et	4	main
katki	doc_41618862222_item	2398720	et	4	main
minna	doc_41618862222_item	2398721	et	3	main
proovige	doc_41618862222_item	2398728	et	3	main
vaja	doc_41618862223_item	2398741	et	4	main
valmistuda	doc_41618862223_item	2398742	et	3	main
ma	doc_41618862223_item	2398743	et	3	main
igaüks	doc_41618862223_item	2398746	et	3	main
leida	doc_41618862223_item	2398749	et	3	main
sa	doc_41618862223_item	2398756	et	3	main
seda	doc_41618862223_item	2398758	et	3	main
ja	doc_41618862223_item	2398769	et	3	main
olema	doc_41618862223_item	2398772	et	4	main
arvates	doc_41618862223_item	2398777	et	4	main
kui	doc_41618862223_item	2398786	et	3	main
ennast	doc_41618862223_item	2398793	et	4	main
ja	doc_41618862223_item	2398822	et	3	main
ole	doc_41618862223_item	2398826	et	4	main
kui	doc_41618862223_item	2398829	et	3	main
sul	doc_41618862223_item	2398830	et	3	main
vaja	doc_41618862223_item	2398832	et	4	main
inimest	doc_41618862223_item	2398840	et	3	main
teevad	doc_41618862223_item	2398842	et	3	main
tööintervjuul	doc_41618862223_item	2398854	et	3	main
rääkida	doc_41618862223_item	2398868	et	3	main
peab	doc_41618862223_item	2398872	et	4	main
umbes	doc_41618862223_item	2398874	et	4	main
kuuskümmend	doc_41618862223_item	2398876	et	4	main
kõige	doc_41618862223_item	2398887	et	4	main
et	doc_41618862223_item	2398892	et	3	main
koolis	doc_41618862223_item	2398894	et	4	main
on	doc_41618862223_item	2398898	et	4	main
õppetajatega	doc_41618862223_item	2398900	et	4	main
nendel	doc_41618862223_item	2398901	et	4	main
minu	doc_41618862223_item	2398906	et	3	main
peavad	doc_41618862223_item	2398909	et	4	main
õppida	doc_41618862223_item	2398910	et	3	main
kord	doc_41618862223_item	2398912	et	4	main
erinevad	doc_41618862223_item	2398928	et	4	main
asjad	doc_41618862223_item	2398929	et	3	main
koolis	doc_41618862223_item	2398930	et	4	main
sa	doc_41618862223_item	2398931	et	3	main
või	doc_41618862223_item	2398952	et	4	main
laste	doc_41618862223_item	2398966	et	4	main
eest	doc_41618862223_item	2398967	et	4	main
on	doc_41618862223_item	2398999	et	4	main
sinu	doc_41618862223_item	2399002	et	3	main
kas	doc_41618862223_item	2399007	et	3	main
valmistuda	doc_41618862224_item	2399016	et	3	main
tööintervjuuk	doc_41618862224_item	2399020	et	4	main
mida	doc_41618862224_item	2399031	et	4	main
nad	doc_41618862224_item	2399032	et	3	main
väljend	doc_41618862224_item	2399040	et	3	main
seelises	doc_41618862224_item	2399049	et	4	main
töökal	doc_41618862224_item	2399050	et	3	main
lühikesed	doc_41618862224_item	2399056	et	4	main
lühikesed	doc_41618862224_item	2399067	et	4	main
ülesanneid	doc_41618862222_item	2398627	et	4	main
iga	doc_41618862222_item	2398628	et	4	main
päev	doc_41618862222_item	2398629	et	3	main
pange	doc_41618862222_item	2398630	et	4	main
töötamiseks	doc_41618862222_item	2398635	et	4	main
elektriga	doc_41618862222_item	2398638	et	3	main
seadme	doc_41618862222_item	2398640	et	3	main
vette	doc_41618862222_item	2398645	et	3	main
mida	doc_41618862222_item	2398651	et	4	main
peaks	doc_41618862222_item	2398652	et	4	main
inimene	doc_41618862222_item	2398653	et	3	main
tegema	doc_41618862222_item	2398654	et	3	main
et	doc_41618862222_item	2398655	et	3	main
vähendada	doc_41618862222_item	2398656	et	3	main
kuriteo	doc_41618862222_item	2398657	et	4	main
sattumise	doc_41618862222_item	2398659	et	4	main
tumedas	doc_41618862222_item	2398665	et	3	main
ei	doc_41618862222_item	2398671	et	4	main
olnud	doc_41618862222_item	2398672	et	4	main
ja	doc_41618862222_item	2398673	et	3	main
niisugust	doc_41618862222_item	2398674	et	3	main
tänavat	doc_41618862222_item	2398675	et	4	main
mida	doc_41618862222_item	2398676	et	4	main
te	doc_41618862222_item	2398677	et	4	main
ei	doc_41618862222_item	2398678	et	4	main
tunne	doc_41618862222_item	2398679	et	4	main
ärge	doc_41618862222_item	2398680	et	3	main
laske	doc_41618862222_item	2398681	et	4	main
koju	doc_41618862222_item	2398682	et	3	main
mitte	doc_41618862222_item	2398683	et	3	main
tuntuvat	doc_41618862222_item	2398684	et	3	main
inimesed	doc_41618862222_item	2398685	et	3	main
isegi	doc_41618862222_item	2398686	et	4	main
kui	doc_41618862222_item	2398687	et	3	main
nad	doc_41618862222_item	2398688	et	3	main
ütlevad	doc_41618862222_item	2398689	et	4	main
neil	doc_41618862222_item	2398691	et	4	main
on	doc_41618862222_item	2398692	et	4	main
oma	doc_41618862222_item	2398697	et	4	main
autot	doc_41618862222_item	2398698	et	3	main
aga	doc_41618862222_item	2398714	et	3	main
kunagi	doc_41618862222_item	2398723	et	3	main
seda	doc_41618862222_item	2398729	et	3	main
p	doc_41618862222_item	2398737	et	4	main
tahab	doc_41618862223_item	2398748	et	3	main
valmistuda	doc_41618862223_item	2398753	et	3	main
kui	doc_41618862223_item	2398755	et	3	main
teed	doc_41618862223_item	2398757	et	4	main
sinu	doc_41618862223_item	2398759	et	3	main
ja	doc_41618862223_item	2398774	et	3	main
minu	doc_41618862223_item	2398776	et	3	main
peavad	doc_41618862223_item	2398781	et	4	main
tahad	doc_41618862223_item	2398788	et	3	main
riietus	doc_41618862223_item	2398821	et	4	main
hea	doc_41618862223_item	2398823	et	4	main
näiteks	doc_41618862223_item	2398835	et	4	main
kaks	doc_41618862223_item	2398839	et	3	main
hästi	doc_41618862223_item	2398845	et	3	main
alati	doc_41618862223_item	2398847	et	4	main
kellel	doc_41618862223_item	2398850	et	4	main
peaks	doc_41618862223_item	2398855	et	4	main
endast	doc_41618862223_item	2398870	et	4	main
nelikümmend	doc_41618862223_item	2398880	et	4	main
praegu	doc_41618862223_item	2398885	et	3	main
suuremad	doc_41618862223_item	2398888	et	4	main
kõige	doc_41618862223_item	2398895	et	4	main
suured	doc_41618862223_item	2398896	et	3	main
probleemid	doc_41618862223_item	2398897	et	3	main
on	doc_41618862223_item	2398902	et	4	main
väga	doc_41618862223_item	2398903	et	3	main
arvates	doc_41618862223_item	2398907	et	4	main
mille	doc_41618862223_item	2398915	et	3	main
poolest	doc_41618862223_item	2398916	et	4	main
koolis	doc_41618862223_item	2398921	et	4	main
koolis	doc_41618862223_item	2398923	et	4	main
kõrgkoolis	doc_41618862223_item	2398925	et	4	main
pead	doc_41618862223_item	2398932	et	4	main
õppida	doc_41618862223_item	2398933	et	3	main
sest	doc_41618862223_item	2398934	et	4	main
kesk	doc_41618862223_item	2398935	et	3	main
haridus	doc_41618862223_item	2398936	et	3	main
on	doc_41618862223_item	2398937	et	4	main
sa	doc_41618862223_item	2398946	et	3	main
ei	doc_41618862223_item	2398953	et	4	main
pange	doc_41618862223_item	2398955	et	4	main
soovitust	doc_41618862223_item	2398958	et	4	main
elektriseadmetega	doc_41618862223_item	2398959	et	3	main
läks	doc_41618862223_item	2398970	et	3	main
vii	doc_41618862223_item	2398972	et	4	main
kaksteist	doc_41618862223_item	2398993	et	4	main
paigaldatud	doc_41618862223_item	2399004	et	4	main
kontrolli	doc_41618862223_item	2399006	et	4	main
kõik	doc_41618862223_item	2399008	et	4	main
kontrolltöö	doc_41618862224_item	2399012	et	4	main
tööintervjuuks	doc_41618862224_item	2399013	et	3	main
arvan	doc_41618862224_item	2399018	et	3	main
inimesed	doc_41618862224_item	2399024	et	3	main
tahavad	doc_41618862224_item	2399026	et	3	main
peavad	doc_41618862224_item	2399029	et	4	main
mõtelda	doc_41618862224_item	2399030	et	4	main
hea	doc_41618862224_item	2399039	et	4	main
vastuvõttu	doc_41618862224_item	2399041	et	4	main
komisjoon	doc_41618862224_item	2399042	et	4	main
töötada	doc_41618862224_item	2399048	et	3	main
cv	doc_41618862224_item	2399051	et	4	main
avaldus	doc_41618862224_item	2399053	et	4	main
peavad	doc_41618862224_item	2399054	et	4	main
lakoonilised	doc_41618862224_item	2399058	et	3	main
cv	doc_41618862224_item	2399062	et	4	main
olema	doc_41618862224_item	2399066	et	4	main
olema	doc_41618862224_item	2399077	et	4	main
seda	doc_41618862224_item	2399088	et	3	main
hea	doc_41618862224_item	2399095	et	4	main
alati	doc_41618862222_item	2398695	et	4	main
pange	doc_41618862222_item	2398696	et	4	main
juhul	doc_41618862222_item	2398702	et	3	main
lahkute	doc_41618862222_item	2398705	et	4	main
jooksul	doc_41618862222_item	2398708	et	4	main
juhtme	doc_41618862222_item	2398716	et	3	main
see	doc_41618862222_item	2398718	et	3	main
5	doc_41618862222_item	2398706	et	2	main
tõmmake	doc_41618862222_item	2398709	et	3	main
pistikupesast	doc_41618862222_item	2398711	et	4	main
mitte	doc_41618862222_item	2398715	et	3	main
võib	doc_41618862222_item	2398719	et	3	main
rikutud	doc_41618862222_item	2398725	et	4	main
kontrolltöö	doc_41618862223_item	2398738	et	4	main
tööintervjuuks	doc_41618862223_item	2398739	et	3	main
pole	doc_41618862223_item	2398740	et	3	main
peab	doc_41618862223_item	2398752	et	4	main
oleks	doc_41618862223_item	2398761	et	3	main
ja	doc_41618862223_item	2398763	et	3	main
tööandja	doc_41618862223_item	2398764	et	4	main
avaldus	doc_41618862223_item	2398770	et	4	main
lühikesed	doc_41618862223_item	2398773	et	4	main
lakoonilised	doc_41618862223_item	2398775	et	3	main
sest	doc_41618862223_item	2398785	et	4	main
leida	doc_41618862223_item	2398790	et	3	main
kõige	doc_41618862223_item	2398827	et	4	main
kui	doc_41618862223_item	2398836	et	3	main
oma	doc_41618862223_item	2398843	et	4	main
on	doc_41618862223_item	2398851	et	4	main
välimus	doc_41618862223_item	2398852	et	3	main
parem	doc_41618862223_item	2398853	et	4	main
pea	doc_41618862223_item	2398867	et	4	main
mis	doc_41618862223_item	2398883	et	4	main
koolis	doc_41618862223_item	2398886	et	4	main
probleemid	doc_41618862223_item	2398889	et	3	main
seotud	doc_41618862223_item	2398899	et	4	main
vana	doc_41618862223_item	2398904	et	4	main
uues	doc_41618862223_item	2398913	et	3	main
erineb	doc_41618862223_item	2398917	et	3	main
õppimisest	doc_41618862223_item	2398920	et	4	main
kasutage	doc_41618862222_item	2398724	et	3	main
ärge	doc_41618862222_item	2398727	et	3	main
ise	doc_41618862222_item	2398730	et	4	main
parandada	doc_41618862222_item	2398731	et	3	main
jätke	doc_41618862222_item	2398732	et	4	main
see	doc_41618862222_item	2398733	et	3	main
töö	doc_41618862222_item	2398734	et	4	main
mõtlen	doc_41618862223_item	2398744	et	3	main
tööd	doc_41618862223_item	2398751	et	4	main
tööintervjuuks	doc_41618862223_item	2398754	et	3	main
alati	doc_41618862223_item	2398765	et	4	main
seda	doc_41618862223_item	2398766	et	3	main
näeb	doc_41618862223_item	2398767	et	3	main
cv	doc_41618862223_item	2398768	et	4	main
ja	doc_41618862223_item	2398779	et	3	main
avaldused	doc_41618862223_item	2398780	et	4	main
olema	doc_41618862223_item	2398782	et	4	main
mitte	doc_41618862223_item	2398783	et	3	main
lühikesed	doc_41618862223_item	2398784	et	4	main
tööd	doc_41618862223_item	2398789	et	4	main
sa	doc_41618862223_item	2398791	et	3	main
sest	doc_41618862223_item	2398799	et	4	main
tööandjadele	doc_41618862223_item	2398800	et	4	main
on	doc_41618862223_item	2398801	et	4	main
vaja	doc_41618862223_item	2398802	et	4	main
teada	doc_41618862223_item	2398803	et	3	main
sinust	doc_41618862223_item	2398804	et	3	main
rohkem	doc_41618862223_item	2398805	et	4	main
mis	doc_41618862223_item	2398806	et	4	main
inimene	doc_41618862223_item	2398807	et	3	main
sa	doc_41618862223_item	2398808	et	3	main
oled	doc_41618862223_item	2398809	et	3	main
riietus	doc_41618862223_item	2398811	et	4	main
sobiv	doc_41618862223_item	2398810	et	4	main
ja	doc_41618862223_item	2398812	et	3	main
hea	doc_41618862223_item	2398813	et	4	main
välimus	doc_41618862223_item	2398814	et	3	main
aitavad	doc_41618862223_item	2398815	et	4	main
tööd	doc_41618862223_item	2398816	et	4	main
leida	doc_41618862223_item	2398817	et	3	main
ma	doc_41618862223_item	2398818	et	3	main
mõtlen	doc_41618862223_item	2398819	et	3	main
et	doc_41618862223_item	2398820	et	3	main
ei	doc_41618862223_item	2398825	et	4	main
tööandjale	doc_41618862223_item	2398837	et	3	main
on	doc_41618862223_item	2398838	et	4	main
kes	doc_41618862223_item	2398841	et	4	main
ta	doc_41618862223_item	2398871	et	4	main
on	doc_41618862223_item	2398884	et	4	main
ma	doc_41618862223_item	2398890	et	3	main
tänapäeva	doc_41618862223_item	2398893	et	4	main
süsteemis	doc_41618862223_item	2398914	et	3	main
kõrgkoolis	doc_41618862223_item	2398951	et	4	main
kui	doc_41618862223_item	2398968	et	3	main
katki	doc_41618862223_item	2398971	et	4	main
ära	doc_41618862223_item	2398994	et	4	main
suhtle	doc_41618862223_item	2398995	et	4	main
inimestega	doc_41618862223_item	2398996	et	3	main
kelle	doc_41618862223_item	2398997	et	4	main
välimus	doc_41618862223_item	2398998	et	3	main
kodus	doc_41618862223_item	2399003	et	4	main
signalizatsioon	doc_41618862223_item	2399005	et	4	main
et	doc_41618862224_item	2399019	et	3	main
välimus	doc_41618862223_item	2398824	et	3	main
tähtsam	doc_41618862223_item	2398828	et	4	main
on	doc_41618862223_item	2398831	et	4	main
tööd	doc_41618862223_item	2398833	et	4	main
leida	doc_41618862223_item	2398834	et	3	main
tööd	doc_41618862223_item	2398844	et	4	main
tööandja	doc_41618862223_item	2398846	et	4	main
valib	doc_41618862223_item	2398848	et	3	main
selle	doc_41618862223_item	2398849	et	4	main
endast	doc_41618862223_item	2398856	et	4	main
rääkima	doc_41618862223_item	2398858	et	3	main
palju	doc_41618862223_item	2398857	et	4	main
minu	doc_41618862223_item	2398859	et	3	main
arvates	doc_41618862223_item	2398860	et	4	main
see	doc_41618862223_item	2398861	et	3	main
kes	doc_41618862223_item	2398862	et	4	main
tahab	doc_41618862223_item	2398863	et	3	main
saada	doc_41618862223_item	2398864	et	4	main
tööd	doc_41618862223_item	2398865	et	4	main
ei	doc_41618862223_item	2398866	et	4	main
ainult	doc_41618862223_item	2398869	et	4	main
rääkida	doc_41618862223_item	2398873	et	3	main
nii	doc_41618862223_item	2398875	et	3	main
protsenti	doc_41618862223_item	2398877	et	4	main
endast	doc_41618862223_item	2398878	et	4	main
ja	doc_41618862223_item	2398879	et	3	main
protsenti	doc_41618862223_item	2398881	et	4	main
töölt	doc_41618862223_item	2398882	et	3	main
mõtlen	doc_41618862223_item	2398891	et	3	main
haridus	doc_41618862223_item	2398905	et	3	main
nad	doc_41618862223_item	2398908	et	3	main
veel	doc_41618862223_item	2398911	et	4	main
õppimine	doc_41618862223_item	2398918	et	4	main
kõrgkoolis	doc_41618862223_item	2398919	et	4	main
on	doc_41618862223_item	2398926	et	4	main
väga	doc_41618862223_item	2398927	et	3	main
vaja	doc_41618862223_item	2398938	et	4	main
vajalik	doc_41618862223_item	2398945	et	3	main
ise	doc_41618862223_item	2398948	et	4	main
kas	doc_41618862223_item	2398949	et	3	main
töötamiseks	doc_41618862223_item	2398960	et	4	main
ära	doc_41618862223_item	2398961	et	4	main
mina	doc_41618862224_item	2399017	et	4	main
saada	doc_41618862224_item	2399027	et	4	main
esimeses	doc_41618862224_item	2399035	et	3	main
minutis	doc_41618862224_item	2399036	et	3	main
et	doc_41618862224_item	2399037	et	3	main
näita	doc_41618862224_item	2399044	et	4	main
et	doc_41618862224_item	2399045	et	3	main
te	doc_41618862224_item	2399046	et	4	main
tahate	doc_41618862224_item	2399047	et	3	main
ja	doc_41618862224_item	2399052	et	3	main
ja	doc_41618862224_item	2399057	et	3	main
niisugused	doc_41618862224_item	2399078	et	3	main
tööd	doc_41618862224_item	2399098	et	4	main
sobiv	doc_41618862224_item	2399103	et	4	main
ja	doc_41618862224_item	2399105	et	3	main
riietuses	doc_41618862224_item	2399134	et	4	main
tööandjad	doc_41618862224_item	2399136	et	3	main
mõtelda	doc_41618862224_item	2399138	et	4	main
et	doc_41618862224_item	2399139	et	3	main
jah	doc_41618862224_item	2399151	et	3	main
peaks	doc_41618862224_item	2399156	et	4	main
palju	doc_41618862224_item	2399158	et	4	main
rääkima	doc_41618862224_item	2399159	et	3	main
aga	doc_41618862224_item	2399160	et	3	main
kes	doc_41618862224_item	2399167	et	4	main
koolis	doc_41618862224_item	2399186	et	4	main
praegu	doc_41618862224_item	2399190	et	3	main
õpilased	doc_41618862224_item	2399197	et	3	main
koolis	doc_41618862224_item	2399211	et	4	main
on	doc_41618862224_item	2399222	et	4	main
on	doc_41618862224_item	2399228	et	4	main
kõrgkoolis	doc_41618862224_item	2399236	et	4	main
õppimisest	doc_41618862224_item	2399237	et	4	main
erineb	doc_41618862224_item	2399241	et	3	main
koolis	doc_41618862224_item	2399260	et	4	main
koolis	doc_41618862224_item	2399272	et	4	main
ma	doc_41618862225_item	2399307	et	3	main
ei	doc_41618862225_item	2399308	et	4	main
uue	doc_41618862225_item	2399315	et	3	main
pead	doc_41618862225_item	2399318	et	4	main
küsimusest	doc_41618862225_item	2399320	et	4	main
millega	doc_41618862225_item	2399321	et	3	main
sinu	doc_41618862225_item	2399325	et	3	main
avaldus	doc_41618862225_item	2399339	et	4	main
näe	doc_41618862225_item	2399344	et	4	main
mida	doc_41618862225_item	2399379	et	4	main
peaks	doc_41618862225_item	2399383	et	4	main
endast	doc_41618862225_item	2399384	et	4	main
rääkima	doc_41618862225_item	2399386	et	3	main
see	doc_41618862225_item	2399387	et	3	main
sõldub	doc_41618862225_item	2399388	et	4	main
palju	doc_41618862225_item	2399397	et	4	main
ole	doc_41618862225_item	2399410	et	4	main
inimene	doc_41618862225_item	2399412	et	3	main
koolis	doc_41618862225_item	2399416	et	4	main
kõige	doc_41618862225_item	2399417	et	4	main
kõige	doc_41618862225_item	2399426	et	4	main
suuremad	doc_41618862225_item	2399427	et	4	main
suitsamine	doc_41618862225_item	2399429	et	4	main
tund	doc_41618862225_item	2399430	et	3	main
kestab	doc_41618862225_item	2399431	et	4	main
õppekud	doc_41618862225_item	2399435	et	4	main
mille	doc_41618862225_item	2399436	et	3	main
õppimine	doc_41618862223_item	2398922	et	4	main
ja	doc_41618862223_item	2398924	et	3	main
kõigile	doc_41618862223_item	2398939	et	4	main
aga	doc_41618862223_item	2398940	et	3	main
kõrgkoolis	doc_41618862223_item	2398941	et	4	main
õppida	doc_41618862223_item	2398942	et	3	main
on	doc_41618862223_item	2398943	et	4	main
mitte	doc_41618862223_item	2398944	et	3	main
mõtled	doc_41618862223_item	2398947	et	3	main
õppida	doc_41618862223_item	2398950	et	3	main
ole	doc_41618862223_item	2398954	et	4	main
kirja	doc_41618862223_item	2398956	et	4	main
kolm	doc_41618862223_item	2398957	et	3	main
töötage	doc_41618862223_item	2398962	et	3	main
vee	doc_41618862223_item	2398963	et	3	main
kõrval	doc_41618862223_item	2398964	et	4	main
hoida	doc_41618862223_item	2398965	et	3	main
elektrimasin	doc_41618862223_item	2398969	et	3	main
masin	doc_41618862223_item	2398973	et	3	main
remondile	doc_41618862223_item	2398974	et	3	main
ära	doc_41618862223_item	2398975	et	4	main
tee	doc_41618862223_item	2398976	et	4	main
midagi	doc_41618862223_item	2398977	et	4	main
ise	doc_41618862223_item	2398978	et	4	main
mida	doc_41618862223_item	2398979	et	4	main
peaks	doc_41618862223_item	2398980	et	4	main
inimene	doc_41618862223_item	2398981	et	3	main
tegema	doc_41618862223_item	2398982	et	3	main
et	doc_41618862223_item	2398983	et	3	main
vähendada	doc_41618862223_item	2398984	et	3	main
kuriteo	doc_41618862223_item	2398985	et	4	main
ohvriks	doc_41618862223_item	2398986	et	3	main
sattumise	doc_41618862223_item	2398987	et	4	main
riski	doc_41618862223_item	2398988	et	4	main
ära	doc_41618862223_item	2398989	et	4	main
jaluta	doc_41618862223_item	2398990	et	4	main
õues	doc_41618862223_item	2398991	et	4	main
pärast	doc_41618862223_item	2398992	et	4	main
halb	doc_41618862223_item	2399000	et	3	main
kui	doc_41618862223_item	2399001	et	3	main
andurid	doc_41618862223_item	2399009	et	3	main
töötavad	doc_41618862223_item	2399010	et	4	main
hästi	doc_41618862223_item	2399011	et	3	main
pole	doc_41618862224_item	2399014	et	3	main
vaja	doc_41618862224_item	2399015	et	4	main
peavad	doc_41618862224_item	2399021	et	4	main
kõik	doc_41618862224_item	2399023	et	4	main
kes	doc_41618862224_item	2399025	et	4	main
võivad	doc_41618862224_item	2399033	et	4	main
peab	doc_41618862224_item	2399043	et	4	main
mina	doc_41618862224_item	2399059	et	4	main
ja	doc_41618862224_item	2399063	et	3	main
sest	doc_41618862224_item	2399070	et	4	main
see	doc_41618862224_item	2399071	et	3	main
on	doc_41618862224_item	2399072	et	4	main
dokument	doc_41618862224_item	2399073	et	3	main
aga	doc_41618862224_item	2399074	et	3	main
dokumendid	doc_41618862224_item	2399075	et	3	main
peavad	doc_41618862224_item	2399076	et	4	main
te	doc_41618862224_item	2399080	et	4	main
te	doc_41618862224_item	2399086	et	4	main
riietus	doc_41618862224_item	2399093	et	4	main
ja	doc_41618862224_item	2399094	et	3	main
leida	doc_41618862224_item	2399099	et	3	main
arvan	doc_41618862224_item	2399101	et	3	main
riietus	doc_41618862224_item	2399104	et	4	main
töölt	doc_41618862224_item	2399122	et	3	main
tööintervjuul	doc_41618862224_item	2399132	et	3	main
siis	doc_41618862224_item	2399135	et	3	main
rääkima	doc_41618862224_item	2399150	et	3	main
tööintervjuul	doc_41618862224_item	2399169	et	3	main
halbad	doc_41618862224_item	2399172	et	4	main
mis	doc_41618862224_item	2399183	et	4	main
kõige	doc_41618862224_item	2399187	et	4	main
koolis	doc_41618862224_item	2399191	et	4	main
palju	doc_41618862224_item	2399194	et	4	main
näiteks	doc_41618862224_item	2399196	et	4	main
arvavad	doc_41618862224_item	2399198	et	4	main
kormus	doc_41618862224_item	2399200	et	4	main
on	doc_41618862224_item	2399201	et	4	main
saa	doc_41618862224_item	2399207	et	4	main
palju	doc_41618862224_item	2399209	et	4	main
erineb	doc_41618862224_item	2399234	et	3	main
õppimine	doc_41618862224_item	2399235	et	4	main
kõrgkoolis	doc_41618862224_item	2399240	et	4	main
ole	doc_41618862224_item	2399246	et	4	main
kodune	doc_41618862224_item	2399249	et	4	main
sa	doc_41618862224_item	2399255	et	3	main
oled	doc_41618862224_item	2399256	et	3	main
tundil	doc_41618862224_item	2399257	et	4	main
ei	doc_41618862224_item	2399259	et	4	main
me	doc_41618862224_item	2399261	et	4	main
kõrg	doc_41618862224_item	2399268	et	4	main
112	doc_41618862224_item	2399301	et	2	main
kui	doc_41618862225_item	2399312	et	3	main
tahad	doc_41618862225_item	2399314	et	3	main
cv	doc_41618862225_item	2399326	et	4	main
peavad	doc_41618862225_item	2399329	et	4	main
lühikesed	doc_41618862225_item	2399331	et	4	main
ja	doc_41618862225_item	2399332	et	3	main
lakoonilised	doc_41618862225_item	2399333	et	3	main
muidugi	doc_41618862225_item	2399334	et	4	main
sellepärast	doc_41618862225_item	2399335	et	3	main
kui	doc_41618862225_item	2399336	et	3	main
tööandja	doc_41618862225_item	2399342	et	4	main
aga	doc_41618862225_item	2399346	et	3	main
sobiv	doc_41618862225_item	2399353	et	4	main
riietus	doc_41618862225_item	2399354	et	4	main
ja	doc_41618862225_item	2399355	et	3	main
aitavad	doc_41618862225_item	2399358	et	4	main
sellepärast	doc_41618862225_item	2399403	et	3	main
saab	doc_41618862225_item	2399405	et	3	main
mõtleda	doc_41618862225_item	2399406	et	4	main
et	doc_41618862225_item	2399407	et	3	main
mis	doc_41618862225_item	2399413	et	4	main
praegu	doc_41618862225_item	2399415	et	3	main
praegu	doc_41618862225_item	2399420	et	3	main
probleemid	doc_41618862225_item	2399424	et	3	main
palju	doc_41618862225_item	2399432	et	4	main
õppimine	doc_41618862225_item	2399439	et	4	main
kõrgkoolis	doc_41618862225_item	2399444	et	4	main
erineb	doc_41618862225_item	2399445	et	3	main
valmistuda	doc_41618862224_item	2399022	et	3	main
töökoht	doc_41618862224_item	2399028	et	3	main
öelda	doc_41618862224_item	2399034	et	4	main
oleks	doc_41618862224_item	2399038	et	3	main
olema	doc_41618862224_item	2399055	et	4	main
arvan	doc_41618862224_item	2399060	et	3	main
et	doc_41618862224_item	2399061	et	3	main
avaldus	doc_41618862224_item	2399064	et	4	main
peavad	doc_41618862224_item	2399065	et	4	main
tahate	doc_41618862224_item	2399081	et	3	main
öelda	doc_41618862224_item	2399083	et	4	main
võite	doc_41618862224_item	2399087	et	4	main
tegema	doc_41618862224_item	2399089	et	3	main
tööintervjuu	doc_41618862224_item	2399090	et	4	main
ajal	doc_41618862224_item	2399091	et	4	main
välimus	doc_41618862224_item	2399096	et	3	main
mina	doc_41618862224_item	2399100	et	4	main
et	doc_41618862224_item	2399102	et	3	main
hea	doc_41618862224_item	2399106	et	4	main
välimus	doc_41618862224_item	2399107	et	3	main
on	doc_41618862224_item	2399108	et	4	main
tõesti	doc_41618862224_item	2399109	et	3	main
aitavad	doc_41618862224_item	2399110	et	4	main
tööd	doc_41618862224_item	2399111	et	4	main
leid	doc_41618862224_item	2399112	et	4	main
kui	doc_41618862224_item	2399113	et	3	main
tööandjad	doc_41618862224_item	2399114	et	3	main
näitavad	doc_41618862224_item	2399115	et	4	main
et	doc_41618862224_item	2399116	et	3	main
riietus	doc_41618862224_item	2399117	et	4	main
on	doc_41618862224_item	2399118	et	4	main
puhas	doc_41618862224_item	2399119	et	3	main
ja	doc_41618862224_item	2399120	et	3	main
sobib	doc_41618862224_item	2399121	et	3	main
sest	doc_41618862224_item	2399123	et	4	main
aidata	doc_41618862224_item	2399126	et	4	main
huvita	doc_41618862224_item	2399142	et	4	main
see	doc_41618862224_item	2399143	et	3	main
töö	doc_41618862224_item	2399144	et	4	main
koht	doc_41618862224_item	2399145	et	3	main
peaks	doc_41618862224_item	2399147	et	4	main
endast	doc_41618862224_item	2399148	et	4	main
palju	doc_41618862224_item	2399149	et	4	main
niisugused	doc_41618862224_item	2399165	et	3	main
inimesed	doc_41618862224_item	2399166	et	3	main
esimesel	doc_41618862224_item	2399168	et	3	main
asjad	doc_41618862224_item	2399173	et	3	main
juhtus	doc_41618862224_item	2399175	et	3	main
ja	doc_41618862224_item	2399177	et	3	main
on	doc_41618862224_item	2399184	et	4	main
suuremad	doc_41618862224_item	2399188	et	4	main
probleemid	doc_41618862224_item	2399189	et	3	main
väga	doc_41618862224_item	2399193	et	3	main
probleemid	doc_41618862224_item	2399195	et	3	main
et	doc_41618862224_item	2399199	et	3	main
nad	doc_41618862224_item	2399205	et	3	main
väga	doc_41618862224_item	2399213	et	3	main
palju	doc_41618862224_item	2399224	et	4	main
raske	doc_41618862224_item	2399230	et	4	main
õpilastele	doc_41618862224_item	2399231	et	4	main
mille	doc_41618862224_item	2399232	et	3	main
koolis	doc_41618862224_item	2399238	et	4	main
nii	doc_41618862224_item	2399247	et	3	main
palju	doc_41618862224_item	2399248	et	4	main
huvita	doc_41618862224_item	2399253	et	4	main
kas	doc_41618862224_item	2399254	et	3	main
peame	doc_41618862224_item	2399262	et	4	main
olema	doc_41618862224_item	2399263	et	4	main
koolis	doc_41618862224_item	2399269	et	4	main
erineb	doc_41618862224_item	2399270	et	3	main
ja	doc_41618862224_item	2399068	et	3	main
lakoonilised	doc_41618862224_item	2399069	et	3	main
kui	doc_41618862224_item	2399079	et	3	main
midagi	doc_41618862224_item	2399082	et	4	main
ise	doc_41618862224_item	2399084	et	4	main
endast	doc_41618862224_item	2399085	et	4	main
sobiv	doc_41618862224_item	2399092	et	4	main
aitavad	doc_41618862224_item	2399097	et	4	main
see	doc_41618862224_item	2399124	et	3	main
võib	doc_41618862224_item	2399125	et	3	main
töö	doc_41618862224_item	2399127	et	4	main
leida	doc_41618862224_item	2399128	et	3	main
kui	doc_41618862224_item	2399129	et	3	main
te	doc_41618862224_item	2399130	et	4	main
tulete	doc_41618862224_item	2399131	et	3	main
võivad	doc_41618862224_item	2399137	et	4	main
teid	doc_41618862224_item	2399140	et	4	main
ei	doc_41618862224_item	2399141	et	4	main
arvan	doc_41618862224_item	2399153	et	3	main
et	doc_41618862224_item	2399154	et	3	main
sellepärast	doc_41618862224_item	2399163	et	3	main
on	doc_41618862224_item	2399164	et	4	main
rääkivad	doc_41618862224_item	2399170	et	4	main
temaga	doc_41618862224_item	2399176	et	3	main
ei	doc_41618862224_item	2399179	et	4	main
saa	doc_41618862224_item	2399180	et	4	main
saata	doc_41618862224_item	2399181	et	3	main
töökoht	doc_41618862224_item	2399182	et	3	main
liiga	doc_41618862224_item	2399202	et	4	main
raske	doc_41618862224_item	2399203	et	4	main
ja	doc_41618862224_item	2399204	et	3	main
tegema	doc_41618862224_item	2399210	et	3	main
tavalises	doc_41618862224_item	2399133	et	4	main
tööintervjuul	doc_41618862224_item	2399146	et	3	main
ma	doc_41618862224_item	2399152	et	3	main
tööintervjuul	doc_41618862224_item	2399155	et	3	main
endast	doc_41618862224_item	2399157	et	4	main
ainult	doc_41618862224_item	2399161	et	4	main
plussid	doc_41618862224_item	2399162	et	3	main
endast	doc_41618862224_item	2399171	et	4	main
mis	doc_41618862224_item	2399174	et	4	main
nad	doc_41618862224_item	2399178	et	3	main
praegu	doc_41618862224_item	2399185	et	3	main
on	doc_41618862224_item	2399192	et	4	main
ei	doc_41618862224_item	2399206	et	4	main
nii	doc_41618862224_item	2399208	et	3	main
on	doc_41618862224_item	2399212	et	4	main
palju	doc_41618862224_item	2399214	et	4	main
tundi	doc_41618862224_item	2399215	et	4	main
ja	doc_41618862224_item	2399216	et	3	main
õpilased	doc_41618862224_item	2399217	et	3	main
tulevad	doc_41618862224_item	2399218	et	4	main
koju	doc_41618862224_item	2399219	et	3	main
õhtul	doc_41618862224_item	2399220	et	3	main
veel	doc_41618862224_item	2399221	et	4	main
väga	doc_41618862224_item	2399223	et	3	main
ja	doc_41618862224_item	2399226	et	3	main
poolest	doc_41618862224_item	2399233	et	4	main
õppimine	doc_41618862224_item	2399239	et	4	main
koolis	doc_41618862224_item	2399243	et	4	main
ei	doc_41618862224_item	2399245	et	4	main
ei	doc_41618862224_item	2399252	et	4	main
või	doc_41618862224_item	2399258	et	4	main
kormusest	doc_41618862224_item	2399271	et	4	main
kontrolltöö	doc_41618862225_item	2399302	et	4	main
tööintervjuuks	doc_41618862225_item	2399303	et	3	main
pole	doc_41618862225_item	2399304	et	3	main
vaja	doc_41618862225_item	2399305	et	4	main
valmistuda	doc_41618862225_item	2399306	et	3	main
sellega	doc_41618862225_item	2399311	et	3	main
sa	doc_41618862225_item	2399317	et	3	main
mõtlema	doc_41618862225_item	2399319	et	3	main
kodunetööd	doc_41618862224_item	2399225	et	4	main
see	doc_41618862224_item	2399227	et	3	main
tõesti	doc_41618862224_item	2399229	et	3	main
õppimisest	doc_41618862224_item	2399242	et	4	main
et	doc_41618862224_item	2399244	et	3	main
tööd	doc_41618862224_item	2399250	et	4	main
õpetajadel	doc_41618862224_item	2399251	et	4	main
kõikidel	doc_41618862224_item	2399264	et	4	main
tundil	doc_41618862224_item	2399265	et	4	main
ja	doc_41618862224_item	2399266	et	3	main
kormus	doc_41618862224_item	2399267	et	4	main
ta	doc_41618862224_item	2399273	et	4	main
on	doc_41618862224_item	2399274	et	4	main
parem	doc_41618862224_item	2399275	et	4	main
mida	doc_41618862224_item	2399276	et	4	main
peaks	doc_41618862224_item	2399277	et	4	main
inimene	doc_41618862224_item	2399278	et	3	main
tegema	doc_41618862224_item	2399279	et	3	main
et	doc_41618862224_item	2399280	et	3	main
vähendada	doc_41618862224_item	2399281	et	3	main
kuriteo	doc_41618862224_item	2399282	et	4	main
ohvriks	doc_41618862224_item	2399283	et	3	main
sattumise	doc_41618862224_item	2399284	et	4	main
riski	doc_41618862224_item	2399285	et	4	main
1	doc_41618862224_item	2399286	et	2	main
ei	doc_41618862224_item	2399287	et	4	main
tohi	doc_41618862224_item	2399288	et	4	main
jalutada	doc_41618862224_item	2399289	et	3	main
õhtul	doc_41618862224_item	2399290	et	3	main
üksi	doc_41618862224_item	2399291	et	4	main
2	doc_41618862224_item	2399292	et	2	main
suletada	doc_41618862224_item	2399293	et	4	main
kõik	doc_41618862224_item	2399294	et	4	main
uksed	doc_41618862224_item	2399295	et	3	main
3	doc_41618862224_item	2399297	et	2	main
korteris	doc_41618862224_item	2399296	et	3	main
alati	doc_41618862224_item	2399298	et	4	main
mäletama	doc_41618862224_item	2399299	et	3	main
tel	doc_41618862224_item	2399300	et	4	main
nõus	doc_41618862225_item	2399310	et	4	main
töökoht	doc_41618862225_item	2399316	et	3	main
ja	doc_41618862225_item	2399327	et	3	main
olema	doc_41618862225_item	2399330	et	4	main
või	doc_41618862225_item	2399340	et	4	main
cv	doc_41618862225_item	2399341	et	4	main
sinu	doc_41618862225_item	2399345	et	3	main
teie	doc_41618862225_item	2399349	et	4	main
hea	doc_41618862225_item	2399356	et	4	main
välimus	doc_41618862225_item	2399357	et	3	main
tööintervjuul	doc_41618862225_item	2399382	et	3	main
maunu	doc_41618862225_item	2399392	et	4	main
meelest	doc_41618862225_item	2399393	et	4	main
et	doc_41618862225_item	2399394	et	3	main
kui	doc_41618862225_item	2399395	et	3	main
sa	doc_41618862225_item	2399396	et	3	main
sa	doc_41618862225_item	2399408	et	3	main
on	doc_41618862225_item	2399414	et	4	main
olen	doc_41618862225_item	2399309	et	3	main
sa	doc_41618862225_item	2399313	et	3	main
saab	doc_41618862225_item	2399323	et	3	main
avaldus	doc_41618862225_item	2399328	et	4	main
kirjutab	doc_41618862225_item	2399338	et	3	main
ta	doc_41618862225_item	2399347	et	4	main
lugeb	doc_41618862225_item	2399348	et	4	main
avaldus	doc_41618862225_item	2399350	et	4	main
ja	doc_41618862225_item	2399351	et	3	main
cv	doc_41618862225_item	2399352	et	4	main
temal	doc_41618862225_item	2399380	et	3	main
küsivad	doc_41618862225_item	2399390	et	4	main
tööintervjuuerijad	doc_41618862225_item	2399391	et	4	main
endast	doc_41618862225_item	2399399	et	4	main
on	doc_41618862225_item	2399401	et	4	main
tööintervjuuerijad	doc_41618862225_item	2399404	et	4	main
suuremad	doc_41618862225_item	2399418	et	4	main
koolis	doc_41618862225_item	2399421	et	4	main
palju	doc_41618862225_item	2399423	et	4	main
probleemid	doc_41618862225_item	2399428	et	3	main
kõrgkoolis	doc_41618862225_item	2399440	et	4	main
et	doc_41618862225_item	2399448	et	3	main
palju	doc_41618862225_item	2399451	et	4	main
ülikooli	doc_41618862225_item	2399457	et	4	main
kirja	doc_41618862225_item	2399468	et	4	main
soovitust	doc_41618862225_item	2399470	et	4	main
elektriseadmetega	doc_41618862225_item	2399471	et	3	main
esiteks	doc_41618862225_item	2399473	et	3	main
peate	doc_41618862225_item	2399477	et	4	main
valja	doc_41618862225_item	2399479	et	3	main
kui	doc_41618862225_item	2399486	et	3	main
mees	doc_418750402001_item	2399542	et	4	main
ta	doc_418750402001_item	2399543	et	4	main
on	doc_418750402001_item	2399544	et	4	main
sportlane	doc_418750402001_item	2399545	et	3	main
tal	doc_418750402001_item	2399546	et	3	main
on	doc_418750402001_item	2399547	et	4	main
on	doc_418750402001_item	2399551	et	4	main
aktiivselt	doc_418750402001_item	2399562	et	4	main
on	doc_418750402001_item	2399571	et	4	main
ääres	doc_418750402001_item	2399577	et	4	main
ta	doc_418750402001_item	2399583	et	4	main
oma	doc_418750402001_item	2399588	et	4	main
ma	doc_418750402002_item	2399598	et	3	main
on	doc_418750402002_item	2399605	et	4	main
tõsine	doc_418750402002_item	2399607	et	4	main
inimesed	doc_418750402002_item	2399610	et	3	main
trükkimine	doc_418750402002_item	2399643	et	4	main
liigi	doc_418750402002_item	2399653	et	4	main
tahavad	doc_418750402002_item	2399661	et	3	main
keskkonnale	doc_418750402002_item	2399664	et	3	main
veel	doc_418750402002_item	2399665	et	4	main
projekt	doc_418750402002_item	2399670	et	3	main
eestis	doc_418750402002_item	2399674	et	3	main
tõsisem	doc_418750402003_item	2399711	et	4	main
lärm	doc_418750402003_item	2399713	et	3	main
olen	doc_418750402003_item	2399715	et	3	main
ja	doc_418750402003_item	2399719	et	3	main
ja	doc_418750402003_item	2399724	et	3	main
vaikuses	doc_418750402003_item	2399725	et	4	main
koputavad	doc_418750402003_item	2399734	et	4	main
on	doc_418750402003_item	2399739	et	4	main
kasutada	doc_418750402003_item	2399741	et	3	main
plastik	doc_418750402003_item	2399744	et	3	main
hästi	doc_418750402003_item	2399747	et	3	main
remondi	doc_418750402003_item	2399759	et	4	main
meie	doc_418750402004_item	2399770	et	4	main
näiteks	doc_418750402004_item	2399777	et	4	main
puhastusvahendid	doc_418750402004_item	2399778	et	3	main
ja	doc_418750402004_item	2399779	et	3	main
pesuvahendid	doc_418750402004_item	2399780	et	3	main
väga	doc_418750402004_item	2399786	et	3	main
köögis	doc_418750402004_item	2399789	et	3	main
puhas	doc_418750402004_item	2399791	et	3	main
vaja	doc_418750402004_item	2399793	et	4	main
et	doc_418750402004_item	2399794	et	3	main
ei	doc_418750402004_item	2399795	et	4	main
me	doc_418750402004_item	2399802	et	4	main
inimene	doc_418750402004_item	2399807	et	3	main
meie	doc_418750402004_item	2399819	et	4	main
värske	doc_418750402004_item	2399822	et	4	main
erilist	doc_418750402004_item	2399831	et	4	main
vahendit	doc_418750402004_item	2399832	et	3	main
tööandja	doc_41618862225_item	2399322	et	4	main
küsida	doc_41618862225_item	2399324	et	3	main
ta	doc_41618862225_item	2399337	et	4	main
ei	doc_41618862225_item	2399343	et	4	main
tööd	doc_41618862225_item	2399359	et	4	main
leida	doc_41618862225_item	2399360	et	3	main
minu	doc_41618862225_item	2399361	et	3	main
seisukohast	doc_41618862225_item	2399362	et	4	main
on	doc_41618862225_item	2399363	et	4	main
ma	doc_41618862225_item	2399364	et	3	main
olen	doc_41618862225_item	2399365	et	3	main
sellega	doc_41618862225_item	2399367	et	3	main
kui	doc_41618862225_item	2399368	et	3	main
inimene	doc_41618862225_item	2399369	et	3	main
nõus	doc_41618862225_item	2399366	et	4	main
soovib	doc_41618862225_item	2399370	et	3	main
leida	doc_41618862225_item	2399371	et	3	main
hea	doc_41618862225_item	2399372	et	4	main
töö	doc_41618862225_item	2399373	et	4	main
sa	doc_41618862225_item	2399374	et	3	main
pead	doc_41618862225_item	2399375	et	4	main
riietuda	doc_41618862225_item	2399376	et	3	main
head	doc_41618862225_item	2399377	et	4	main
riietused	doc_41618862225_item	2399378	et	4	main
on	doc_41618862225_item	2399381	et	4	main
palju	doc_41618862225_item	2399385	et	4	main
mis	doc_41618862225_item	2399389	et	4	main
rääkib	doc_41618862225_item	2399398	et	4	main
see	doc_41618862225_item	2399400	et	3	main
halb	doc_41618862225_item	2399402	et	3	main
ei	doc_41618862225_item	2399409	et	4	main
tark	doc_41618862225_item	2399411	et	3	main
probleemid	doc_41618862225_item	2399419	et	3	main
aga	doc_41618862225_item	2399425	et	3	main
kerulised	doc_41618862225_item	2399434	et	4	main
koolis	doc_41618862225_item	2399442	et	4	main
loeng	doc_41618862225_item	2399449	et	3	main
minna	doc_41618862225_item	2399456	et	3	main
või	doc_41618862225_item	2399458	et	4	main
siis	doc_41618862225_item	2399463	et	3	main
käi	doc_41618862225_item	2399465	et	4	main
pange	doc_41618862225_item	2399467	et	4	main
kord	doc_41618862225_item	2399475	et	4	main
lülitama	doc_41618862225_item	2399478	et	4	main
oma	doc_41618862225_item	2399480	et	4	main
elektriseadmed	doc_41618862225_item	2399481	et	3	main
ei	doc_41618862225_item	2399483	et	4	main
elektriseadmetega	doc_41618862225_item	2399485	et	3	main
suveastaeg	doc_418750402001_item	2399537	et	4	main
aja	doc_418750402001_item	2399538	et	4	main
pildil	doc_418750402001_item	2399539	et	3	main
on	doc_418750402001_item	2399540	et	4	main
ta	doc_418750402001_item	2399550	et	4	main
purjelauaga	doc_418750402001_item	2399552	et	3	main
ma	doc_418750402001_item	2399554	et	3	main
et	doc_418750402001_item	2399556	et	3	main
veetab	doc_418750402001_item	2399558	et	4	main
oma	doc_418750402001_item	2399559	et	4	main
sest	doc_418750402001_item	2399565	et	4	main
arvan	doc_418750402001_item	2399567	et	3	main
ta	doc_418750402001_item	2399574	et	4	main
mere	doc_418750402001_item	2399576	et	3	main
ja	doc_418750402001_item	2399578	et	3	main
sõitab	doc_418750402001_item	2399580	et	4	main
t	doc_418750402001_item	2399587	et	4	main
tegevust	doc_418750402001_item	2399589	et	4	main
arvamus	doc_418750402002_item	2399590	et	3	main
kõigepealt	doc_418750402002_item	2399591	et	3	main
kui	doc_418750402002_item	2399592	et	3	main
ma	doc_418750402002_item	2399593	et	3	main
olen	doc_418750402002_item	2399594	et	3	main
projekt	doc_418750402002_item	2399602	et	3	main
vett	doc_418750402002_item	2399613	et	3	main
ma	doc_418750402002_item	2399621	et	3	main
prügi	doc_418750402002_item	2399623	et	4	main
projekt	doc_418750402002_item	2399626	et	3	main
linna	doc_418750402002_item	2399628	et	4	main
ma	doc_418750402002_item	2399640	et	3	main
rahastan	doc_418750402002_item	2399641	et	4	main
reklaamide	doc_418750402002_item	2399642	et	3	main
looduseprobleemidest	doc_418750402002_item	2399656	et	3	main
paljud	doc_418750402002_item	2399657	et	3	main
ma	doc_418750402002_item	2399671	et	3	main
et	doc_418750402002_item	2399673	et	3	main
kodus	doc_418750402003_item	2399716	et	4	main
rahuses	doc_418750402003_item	2399723	et	4	main
puurivad	doc_418750402003_item	2399737	et	4	main
aknad	doc_418750402003_item	2399745	et	3	main
või	doc_418750402003_item	2399757	et	4	main
rohkem	doc_418750402004_item	2399773	et	4	main
keemilisi	doc_418750402004_item	2399775	et	4	main
on	doc_418750402004_item	2399785	et	4	main
et	doc_418750402004_item	2399788	et	3	main
on	doc_418750402004_item	2399790	et	4	main
on	doc_418750402004_item	2399792	et	4	main
me	doc_418750402004_item	2399812	et	4	main
ka	doc_418750402004_item	2399813	et	3	main
kasutame	doc_418750402004_item	2399814	et	3	main
vaja	doc_418750402004_item	2399817	et	4	main
riietus	doc_418750402004_item	2399820	et	4	main
pulbert	doc_418750402004_item	2399829	et	4	main
või	doc_418750402004_item	2399830	et	4	main
on	doc_418750402004_item	2399836	et	4	main
kuid	doc_418750402004_item	2399852	et	4	main
ja	doc_418750402004_item	2399867	et	3	main
plaate	doc_418750402004_item	2399883	et	3	main
poleerida	doc_418750402004_item	2399893	et	3	main
on	doc_41618862225_item	2399422	et	4	main
aega	doc_41618862225_item	2399433	et	4	main
õppimisest	doc_41618862225_item	2399441	et	4	main
õppimisest	doc_41618862225_item	2399446	et	4	main
ei	doc_41618862225_item	2399461	et	4	main
töötamiseks	doc_41618862225_item	2399472	et	4	main
kõrval	doc_41618862225_item	2399487	et	4	main
on	doc_41618862225_item	2399488	et	4	main
veesi	doc_41618862225_item	2399489	et	4	main
kolmaks	doc_41618862225_item	2399490	et	4	main
ei	doc_41618862225_item	2399491	et	4	main
anna	doc_41618862225_item	2399492	et	4	main
elektriseadmed	doc_41618862225_item	2399493	et	3	main
lapsele	doc_41618862225_item	2399494	et	4	main
mida	doc_41618862225_item	2399495	et	4	main
peaks	doc_41618862225_item	2399496	et	4	main
inimene	doc_41618862225_item	2399497	et	3	main
tegema	doc_41618862225_item	2399498	et	3	main
et	doc_41618862225_item	2399499	et	3	main
vähendada	doc_41618862225_item	2399500	et	3	main
kuriteo	doc_41618862225_item	2399501	et	4	main
ohvriks	doc_41618862225_item	2399502	et	3	main
sattumise	doc_41618862225_item	2399503	et	4	main
teadlased	doc_41618862225_item	2399505	et	3	main
riski	doc_41618862225_item	2399504	et	4	main
väidavad	doc_41618862225_item	2399506	et	3	main
kui	doc_41618862225_item	2399507	et	3	main
kell	doc_41618862225_item	2399508	et	3	main
on	doc_41618862225_item	2399509	et	4	main
kuus	doc_41618862225_item	2399510	et	4	main
või	doc_41618862225_item	2399511	et	4	main
üheksa	doc_41618862225_item	2399512	et	4	main
sa	doc_41618862225_item	2399513	et	3	main
ei	doc_41618862225_item	2399514	et	4	main
pea	doc_41618862225_item	2399515	et	4	main
käima	doc_41618862225_item	2399516	et	4	main
tänavalis	doc_41618862225_item	2399517	et	3	main
sellepärast	doc_41618862225_item	2399518	et	3	main
see	doc_41618862225_item	2399519	et	3	main
on	doc_41618862225_item	2399520	et	4	main
poolest	doc_41618862225_item	2399437	et	4	main
erineb	doc_41618862225_item	2399438	et	3	main
õppimine	doc_41618862225_item	2399443	et	4	main
koolis	doc_41618862225_item	2399447	et	4	main
saad	doc_41618862225_item	2399455	et	4	main
sa	doc_41618862225_item	2399460	et	3	main
ei	doc_41618862225_item	2399464	et	4	main
minna	doc_41618862225_item	2399466	et	3	main
te	doc_41618862225_item	2399476	et	4	main
sest	doc_418750402001_item	2399528	et	4	main
tanaval	doc_418750402001_item	2399529	et	4	main
sõita	doc_418750402001_item	2399553	et	3	main
arvan	doc_418750402001_item	2399555	et	3	main
ta	doc_418750402001_item	2399557	et	4	main
ja	doc_418750402001_item	2399563	et	3	main
lemmikspordihuvi	doc_418750402001_item	2399573	et	4	main
puhatab	doc_418750402001_item	2399575	et	4	main
purjelauaga	doc_418750402001_item	2399581	et	3	main
naudib	doc_418750402001_item	2399584	et	3	main
mee	doc_418750402001_item	2399586	et	3	main
linna	doc_418750402002_item	2399595	et	4	main
vesi	doc_418750402002_item	2399604	et	4	main
väga	doc_418750402002_item	2399606	et	3	main
probleem	doc_418750402002_item	2399608	et	3	main
pahast	doc_418750402002_item	2399612	et	4	main
paigaldamine	doc_418750402002_item	2399625	et	4	main
peab	doc_418750402002_item	2399629	et	4	main
olema	doc_418750402002_item	2399630	et	4	main
puhast	doc_418750402002_item	2399631	et	3	main
ja	doc_418750402002_item	2399632	et	3	main
ilust	doc_418750402002_item	2399633	et	3	main
on	doc_418750402002_item	2399634	et	4	main
vaja	doc_418750402002_item	2399635	et	4	main
paigaldama	doc_418750402002_item	2399636	et	3	main
ürituste	doc_418750402002_item	2399646	et	4	main
inimeseid	doc_418750402002_item	2399655	et	4	main
minu	doc_418750402002_item	2399659	et	3	main
ma	doc_418750402002_item	2399666	et	3	main
rahastan	doc_418750402002_item	2399667	et	4	main
looduskaitsealasid	doc_418750402002_item	2399668	et	4	main
väga	doc_418750402002_item	2399676	et	3	main
tihti	doc_418750402003_item	2399718	et	3	main
ma	doc_418750402003_item	2399720	et	3	main
tihti	doc_418750402003_item	2399731	et	3	main
nad	doc_418750402003_item	2399732	et	3	main
ala	doc_418750402003_item	2399733	et	4	main
kõigepealt	doc_418750402003_item	2399738	et	3	main
vaja	doc_418750402003_item	2399740	et	4	main
on	doc_418750402003_item	2399746	et	4	main
summutavad	doc_418750402003_item	2399748	et	4	main
müra	doc_418750402003_item	2399749	et	4	main
piiravad	doc_418750402003_item	2399758	et	4	main
veel	doc_418750402003_item	2399761	et	4	main
peres	doc_418750402004_item	2399771	et	3	main
puhastusvahendid	doc_418750402004_item	2399783	et	3	main
köögis	doc_418750402004_item	2399784	et	3	main
rasva	doc_418750402004_item	2399797	et	4	main
puhastusvahendid	doc_418750402004_item	2399804	et	3	main
iga	doc_418750402004_item	2399806	et	4	main
peab	doc_418750402004_item	2399808	et	4	main
hoidma	doc_418750402004_item	2399809	et	3	main
omat	doc_418750402004_item	2399810	et	4	main
tervishoidust	doc_418750402004_item	2399811	et	4	main
et	doc_418750402004_item	2399818	et	3	main
kestab	doc_41618862225_item	2399450	et	4	main
aega	doc_41618862225_item	2399452	et	4	main
ja	doc_41618862225_item	2399453	et	3	main
saa	doc_41618862225_item	2399454	et	4	main
kui	doc_41618862225_item	2399459	et	3	main
taha	doc_41618862225_item	2399462	et	4	main
kolm	doc_41618862225_item	2399469	et	3	main
iga	doc_41618862225_item	2399474	et	4	main
teiseks	doc_41618862225_item	2399482	et	4	main
töö	doc_41618862225_item	2399484	et	4	main
riskiaeg	doc_41618862225_item	2399521	et	3	main
kirjeldus	doc_418750402001_item	2399523	et	4	main
on	doc_418750402001_item	2399530	et	4	main
soe	doc_418750402001_item	2399531	et	4	main
ja	doc_418750402001_item	2399532	et	3	main
päikeseline	doc_418750402001_item	2399533	et	3	main
kujutatud	doc_418750402001_item	2399541	et	4	main
spordiriietus	doc_418750402001_item	2399548	et	3	main
vaheaega	doc_418750402001_item	2399560	et	4	main
väga	doc_418750402001_item	2399561	et	3	main
ma	doc_418750402001_item	2399566	et	3	main
purjelauaga	doc_418750402001_item	2399569	et	3	main
sõitmine	doc_418750402001_item	2399570	et	4	main
ta	doc_418750402001_item	2399579	et	4	main
lainetel	doc_418750402001_item	2399582	et	3	main
mõned	doc_418750402002_item	2399609	et	3	main
pildi	doc_418750402001_item	2399522	et	4	main
pilt	doc_418750402001_item	2399524	et	3	main
on	doc_418750402001_item	2399525	et	4	main
tehtud	doc_418750402001_item	2399526	et	4	main
suvel	doc_418750402001_item	2399527	et	3	main
ilm	doc_418750402001_item	2399534	et	3	main
see	doc_418750402001_item	2399535	et	3	main
on	doc_418750402001_item	2399536	et	4	main
ja	doc_418750402001_item	2399549	et	3	main
toredalt	doc_418750402001_item	2399564	et	4	main
et	doc_418750402001_item	2399568	et	3	main
tema	doc_418750402001_item	2399572	et	4	main
meert	doc_418750402001_item	2399585	et	4	main
valikogu	doc_418750402002_item	2399596	et	4	main
liige	doc_418750402002_item	2399597	et	4	main
rahastan	doc_418750402002_item	2399599	et	4	main
veekogude	doc_418750402002_item	2399600	et	3	main
puhastamine	doc_418750402002_item	2399601	et	4	main
must	doc_418750402002_item	2399603	et	4	main
kannatavad	doc_418750402002_item	2399611	et	4	main
must	doc_418750402002_item	2399614	et	4	main
vesi	doc_418750402002_item	2399615	et	4	main
on	doc_418750402002_item	2399616	et	4	main
halb	doc_418750402002_item	2399617	et	3	main
tervise	doc_418750402002_item	2399618	et	3	main
põhjus	doc_418750402002_item	2399619	et	4	main
samuti	doc_418750402002_item	2399620	et	3	main
rahastan	doc_418750402002_item	2399622	et	4	main
meie	doc_418750402002_item	2399627	et	4	main
oalju	doc_418750402002_item	2399637	et	4	main
prügikastid	doc_418750402002_item	2399638	et	3	main
kindlasti	doc_418750402002_item	2399639	et	3	main
ja	doc_418750402002_item	2399644	et	3	main
loodussõbraline	doc_418750402002_item	2399645	et	4	main
läbiviimine	doc_418750402002_item	2399647	et	3	main
projektid	doc_418750402002_item	2399648	et	3	main
sel	doc_418750402002_item	2399649	et	3	main
moel	doc_418750402002_item	2399650	et	4	main
palju	doc_418750402002_item	2399654	et	4	main
meelest	doc_418750402002_item	2399660	et	4	main
aidata	doc_418750402002_item	2399662	et	4	main
meiel	doc_418750402002_item	2399663	et	4	main
rajamine	doc_418750402002_item	2399669	et	4	main
on	doc_418750402002_item	2399675	et	4	main
kõige	doc_418750402003_item	2399710	et	4	main
väga	doc_418750402003_item	2399717	et	3	main
kaistide	doc_418750402002_item	2399624	et	4	main
me	doc_418750402002_item	2399651	et	4	main
meelitame	doc_418750402002_item	2399652	et	3	main
inimesed	doc_418750402002_item	2399658	et	3	main
arvan	doc_418750402002_item	2399672	et	3	main
loodus	doc_418750402002_item	2399678	et	4	main
ja	doc_418750402002_item	2399679	et	3	main
ilus	doc_418750402002_item	2399677	et	4	main
tema	doc_418750402002_item	2399680	et	4	main
on	doc_418750402002_item	2399681	et	4	main
vaja	doc_418750402002_item	2399682	et	4	main
säilitama	doc_418750402002_item	2399683	et	4	main
ja	doc_418750402002_item	2399684	et	3	main
seellepärast	doc_418750402002_item	2399685	et	4	main
on	doc_418750402002_item	2399686	et	4	main
vaja	doc_418750402002_item	2399687	et	4	main
rajama	doc_418750402002_item	2399688	et	3	main
looduskaitsealasid	doc_418750402002_item	2399689	et	4	main
arvamus	doc_418750402003_item	2399690	et	3	main
ma	doc_418750402003_item	2399691	et	3	main
arvan	doc_418750402003_item	2399692	et	3	main
et	doc_418750402003_item	2399693	et	3	main
on	doc_418750402003_item	2399695	et	4	main
väga	doc_418750402003_item	2399696	et	3	main
tõsine	doc_418750402003_item	2399697	et	4	main
probleem	doc_418750402003_item	2399698	et	3	main
müra	doc_418750402003_item	2399694	et	4	main
iga	doc_418750402003_item	2399699	et	4	main
päev	doc_418750402003_item	2399700	et	3	main
me	doc_418750402003_item	2399701	et	4	main
puutume	doc_418750402003_item	2399702	et	4	main
kokku	doc_418750402003_item	2399703	et	3	main
müraga	doc_418750402003_item	2399704	et	3	main
käraga	doc_418750402003_item	2399705	et	3	main
lärmiga	doc_418750402003_item	2399706	et	3	main
kisaga	doc_418750402003_item	2399707	et	3	main
minu	doc_418750402003_item	2399708	et	3	main
jaoks	doc_418750402003_item	2399709	et	4	main
on	doc_418750402003_item	2399712	et	4	main
ma	doc_418750402003_item	2399714	et	3	main
tahan	doc_418750402003_item	2399721	et	3	main
naabrid	doc_418750402003_item	2399727	et	3	main
remonti	doc_418750402003_item	2399729	et	4	main
väga	doc_418750402003_item	2399730	et	3	main
lõhuvad	doc_418750402003_item	2399735	et	3	main
seinad	doc_418750402003_item	2399736	et	3	main
aknad	doc_418750402003_item	2399743	et	3	main
aega	doc_418750402003_item	2399760	et	4	main
on	doc_418750402003_item	2399762	et	4	main
vaja	doc_418750402003_item	2399763	et	4	main
kasutada	doc_418750402003_item	2399764	et	3	main
ja	doc_418750402004_item	2399798	et	3	main
pori	doc_418750402004_item	2399799	et	4	main
täppu	doc_418750402004_item	2399800	et	4	main
veel	doc_418750402004_item	2399801	et	4	main
pesuvahendid	doc_418750402004_item	2399815	et	3	main
me	doc_418750402004_item	2399826	et	4	main
kasutame	doc_418750402004_item	2399827	et	3	main
hea	doc_418750402004_item	2399828	et	4	main
meie	doc_418750402004_item	2399834	et	4	main
tervist	doc_418750402004_item	2399854	et	4	main
ained	doc_418750402004_item	2399857	et	3	main
pesta	doc_418750402004_item	2399862	et	4	main
praegu	doc_418750402004_item	2399863	et	3	main
kaupluses	doc_418750402004_item	2399864	et	3	main
müüakse	doc_418750402004_item	2399865	et	3	main
paljuerinevaid	doc_418750402004_item	2399866	et	3	main
keemindid	doc_418750402004_item	2399870	et	4	main
näiteks	doc_418750402004_item	2399882	et	4	main
auto-	doc_418750402004_item	2399896	et	4	main
mõned	doc_418750402004_item	2399911	et	3	main
vahendid	doc_418750402004_item	2399913	et	3	main
see	doc_418750402004_item	2399915	et	3	main
elus	doc_418750402004_item	2399922	et	4	main
võivad	doc_418750402004_item	2399938	et	4	main
olla	doc_418750402004_item	2399939	et	3	main
hoida	doc_418750402004_item	2399951	et	3	main
kodutöö	doc_418750402004_item	2399975	et	4	main
mõju	doc_418750402005_item	2399980	et	4	main
jäämed	doc_418750402005_item	2399981	et	4	main
merevee	doc_418750402005_item	2399985	et	3	main
vähenemine	doc_418750402005_item	2399997	et	4	main
meie	doc_418750402005_item	2399999	et	4	main
kliimat	doc_418750402005_item	2400000	et	3	main
on	doc_418750402005_item	2400001	et	4	main
mere	doc_418750402005_item	2400006	et	3	main
88	doc_418750402005_item	2400009	et	2	main
ma	doc_418750402005_item	2400011	et	3	main
juba	doc_418750402005_item	2400012	et	3	main
ametlik	doc_418750402006_item	2400015	et	3	main
te	doc_418750402006_item	2400027	et	4	main
nimi	doc_418750402006_item	2400042	et	3	main
meil	doc_418750402006_item	2400045	et	4	main
ole	doc_418750402006_item	2400047	et	4	main
tõsised	doc_418750402006_item	2400048	et	4	main
probleemid	doc_418750402006_item	2400049	et	3	main
aga	doc_418750402006_item	2400050	et	3	main
muutada	doc_418750402006_item	2400053	et	4	main
kui	doc_418750402007_item	2400079	et	3	main
siis	doc_418750402007_item	2400082	et	3	main
on	doc_418750402007_item	2400084	et	4	main
arvan	doc_418750402007_item	2400088	et	3	main
koolis	doc_418750402007_item	2400090	et	4	main
ole	doc_418750402007_item	2400092	et	4	main
lapsed	doc_418750402007_item	2400105	et	3	main
koolis	doc_418750402007_item	2400109	et	4	main
riietust	doc_418750402007_item	2400111	et	4	main
peaks	doc_418750402007_item	2400113	et	4	main
osta	doc_418750402007_item	2400114	et	4	main
lihtsam	doc_418750402007_item	2400119	et	4	main
õppida	doc_418750402007_item	2400120	et	3	main
peab	doc_418750402007_item	2400123	et	4	main
ainult	doc_418750402007_item	2400133	et	4	main
arvan	doc_418750402007_item	2400141	et	3	main
natuke	doc_418750402007_item	2400145	et	4	main
koduseid	doc_418750402007_item	2400147	et	4	main
aeg	doc_418750402007_item	2400154	et	3	main
ise	doc_418750402007_item	2400167	et	4	main
valima	doc_418750402007_item	2400168	et	3	main
õppeaineid	doc_418750402007_item	2400169	et	3	main
olla	doc_418750402003_item	2399722	et	3	main
praegu	doc_418750402003_item	2399726	et	3	main
tegevad	doc_418750402003_item	2399728	et	4	main
plastik	doc_418750402003_item	2399742	et	3	main
samuti	doc_418750402003_item	2399750	et	3	main
on	doc_418750402003_item	2399751	et	4	main
vaja	doc_418750402003_item	2399752	et	4	main
et	doc_418750402003_item	2399753	et	3	main
valikogu	doc_418750402003_item	2399754	et	4	main
korteriuhis	doc_418750402003_item	2399755	et	3	main
keelustavad	doc_418750402003_item	2399756	et	4	main
erinevaid	doc_418750402003_item	2399765	et	4	main
müra	doc_418750402003_item	2399766	et	4	main
summutavaid	doc_418750402003_item	2399767	et	4	main
materjali	doc_418750402003_item	2399768	et	4	main
arvamus	doc_418750402004_item	2399769	et	3	main
kõige	doc_418750402004_item	2399772	et	4	main
läheb	doc_418750402004_item	2399774	et	3	main
vahendeid	doc_418750402004_item	2399776	et	3	main
me	doc_418750402004_item	2399781	et	4	main
kasutame	doc_418750402004_item	2399782	et	3	main
vaja	doc_418750402004_item	2399787	et	4	main
ole	doc_418750402004_item	2399796	et	4	main
kasutame	doc_418750402004_item	2399803	et	3	main
vannitoas	doc_418750402004_item	2399805	et	3	main
on	doc_418750402004_item	2399816	et	4	main
riietus	doc_418750402004_item	2399835	et	4	main
lõhnab	doc_418750402004_item	2399838	et	3	main
seda	doc_418750402004_item	2399840	et	3	main
mugava	doc_418750402004_item	2399842	et	3	main
kombates	doc_418750402004_item	2399843	et	3	main
ma	doc_418750402004_item	2399844	et	3	main
et	doc_418750402004_item	2399846	et	3	main
kergendavad	doc_418750402004_item	2399849	et	4	main
meie	doc_418750402004_item	2399850	et	4	main
elu	doc_418750402004_item	2399851	et	4	main
kõigepealt	doc_418750402004_item	2399855	et	3	main
võivad	doc_418750402004_item	2399871	et	4	main
puhastada	doc_418750402004_item	2399872	et	3	main
ükskõik	doc_418750402004_item	2399873	et	3	main
mida	doc_418750402004_item	2399874	et	4	main
nagu	doc_418750402004_item	2399875	et	3	main
nõusid	doc_418750402004_item	2399876	et	3	main
pliiti	doc_418750402004_item	2399877	et	4	main
vaipu	doc_418750402004_item	2399878	et	3	main
nad	doc_418750402004_item	2399879	et	3	main
valgendavad	doc_418750402004_item	2399880	et	4	main
asju	doc_418750402004_item	2399881	et	3	main
ja	doc_418750402004_item	2399885	et	3	main
on	doc_418750402004_item	2399887	et	4	main
vahendid	doc_418750402004_item	2399890	et	3	main
mis	doc_418750402004_item	2399891	et	4	main
näiteks	doc_418750402004_item	2399895	et	4	main
mõneid	doc_418750402004_item	2399899	et	4	main
võivad	doc_418750402004_item	2399901	et	4	main
midagi	doc_418750402004_item	2399909	et	4	main
on	doc_418750402004_item	2399821	et	4	main
ja	doc_418750402004_item	2399823	et	3	main
puhas	doc_418750402004_item	2399824	et	3	main
kui	doc_418750402004_item	2399825	et	3	main
ained	doc_418750402004_item	2399848	et	3	main
kahjustavad	doc_418750402004_item	2399853	et	4	main
keemilised	doc_418750402004_item	2399856	et	4	main
aidavad	doc_418750402004_item	2399858	et	4	main
meile	doc_418750402004_item	2399859	et	4	main
puhastada	doc_418750402004_item	2399860	et	3	main
ja	doc_418750402004_item	2399861	et	3	main
odavaid	doc_418750402004_item	2399868	et	3	main
käterätikud	doc_418750402004_item	2399886	et	3	main
olemas	doc_418750402004_item	2399888	et	4	main
erinevad	doc_418750402004_item	2399889	et	4	main
pindu	doc_418750402004_item	2399894	et	4	main
on	doc_418750402004_item	2399916	et	4	main
väga	doc_418750402004_item	2399917	et	3	main
oluline	doc_418750402004_item	2399918	et	4	main
kui	doc_418750402004_item	2399919	et	3	main
meie	doc_418750402004_item	2399920	et	4	main
igapäevases	doc_418750402004_item	2399921	et	4	main
on	doc_418750402004_item	2399923	et	4	main
mikrobe	doc_418750402004_item	2399924	et	4	main
ja	doc_418750402004_item	2399925	et	3	main
keemiavahendid	doc_418750402004_item	2399928	et	3	main
kahulik	doc_418750402004_item	2399940	et	4	main
ja	doc_418750402004_item	2399941	et	3	main
siin	doc_418750402004_item	2399942	et	4	main
juhendi	doc_418750402004_item	2399948	et	3	main
kohast	doc_418750402004_item	2399949	et	4	main
kättesaadavas	doc_418750402004_item	2399953	et	3	main
mulle	doc_418750402004_item	2399971	et	4	main
kergem	doc_418750402004_item	2399972	et	4	main
tegema	doc_418750402004_item	2399973	et	3	main
meie	doc_418750402004_item	2399974	et	4	main
tase	doc_418750402005_item	2399986	et	3	main
tüuseb	doc_418750402005_item	2399987	et	4	main
ilm	doc_418750402005_item	2399989	et	3	main
tormid	doc_418750402005_item	2399990	et	3	main
üleujutused	doc_418750402005_item	2399991	et	4	main
bioloogilise	doc_418750402005_item	2399995	et	4	main
tulevikus	doc_418750402005_item	2399998	et	4	main
2100	doc_418750402005_item	2400004	et	2	main
kuni	doc_418750402005_item	2400008	et	3	main
cm	doc_418750402005_item	2400010	et	4	main
teadsin	doc_418750402005_item	2400013	et	3	main
teade	doc_418750402006_item	2400016	et	4	main
teade	doc_418750402006_item	2400017	et	4	main
omavalitsuse	doc_418750402006_item	2400018	et	3	main
tarkuse	doc_418750402006_item	2400020	et	4	main
tallinn	doc_418750402006_item	2400023	et	4	main
teade	doc_418750402006_item	2400025	et	4	main
et	doc_418750402006_item	2400026	et	3	main
meie	doc_418750402006_item	2400035	et	4	main
mis	doc_418750402006_item	2400041	et	4	main
ei	doc_418750402006_item	2400046	et	4	main
vaja	doc_418750402006_item	2400052	et	4	main
kõigepealt	doc_418750402006_item	2400056	et	3	main
arvan	doc_418750402006_item	2400058	et	3	main
vaja	doc_418750402006_item	2400060	et	4	main
2	doc_418750402007_item	2400086	et	2	main
olema	doc_418750402007_item	2400098	et	4	main
puhtalt	doc_418750402007_item	2400099	et	4	main
riides	doc_418750402007_item	2400100	et	4	main
sellepärast	doc_418750402007_item	2400104	et	3	main
rohkem	doc_418750402007_item	2400115	et	4	main
igas	doc_418750402007_item	2400121	et	3	main
et	doc_418750402007_item	2400129	et	3	main
vajalikku	doc_418750402007_item	2400138	et	4	main
õpetajad	doc_418750402007_item	2400143	et	4	main
andma	doc_418750402007_item	2400149	et	3	main
et	doc_418750402007_item	2400150	et	3	main
ei	doc_418750402007_item	2400158	et	4	main
anda	doc_418750402007_item	2400163	et	3	main
edasi	doc_418750402007_item	2400174	et	3	main
ülikoolis	doc_418750402007_item	2400176	et	4	main
kursustel	doc_418750402007_item	2400178	et	3	main
siis	doc_418750402007_item	2400179	et	3	main
tal	doc_418750402007_item	2400180	et	3	main
nädalas	doc_418750402007_item	2400186	et	3	main
siis	doc_418750402004_item	2399833	et	3	main
hästi	doc_418750402004_item	2399837	et	3	main
ja	doc_418750402004_item	2399839	et	3	main
on	doc_418750402004_item	2399841	et	4	main
arvan	doc_418750402004_item	2399845	et	3	main
keemilised	doc_418750402004_item	2399847	et	4	main
vahendeid	doc_418750402004_item	2399869	et	3	main
kangaid	doc_418750402004_item	2399884	et	3	main
võivad	doc_418750402004_item	2399892	et	4	main
ja	doc_418750402004_item	2399897	et	3	main
vahendeid	doc_418750402004_item	2399900	et	3	main
tugevdada	doc_418750402004_item	2399902	et	3	main
asju	doc_418750402004_item	2399903	et	3	main
see	doc_418750402004_item	2399904	et	3	main
võib	doc_418750402004_item	2399905	et	3	main
olla	doc_418750402004_item	2399906	et	3	main
hambad	doc_418750402004_item	2399907	et	3	main
või	doc_418750402004_item	2399908	et	4	main
veel	doc_418750402004_item	2399910	et	4	main
spetsialiselt	doc_418750402004_item	2399912	et	4	main
produtserivad	doc_418750402004_item	2399914	et	4	main
erinevaid	doc_418750402004_item	2399930	et	4	main
putukaid	doc_418750402004_item	2399931	et	3	main
ja	doc_418750402004_item	2399932	et	3	main
närilisi	doc_418750402004_item	2399933	et	3	main
hävitada	doc_418750402004_item	2399934	et	3	main
aga	doc_418750402004_item	2399935	et	3	main
keemia	doc_418750402004_item	2399936	et	4	main
vahendid	doc_418750402004_item	2399937	et	3	main
vaja	doc_418750402004_item	2399944	et	4	main
kas	doc_418750402004_item	2399945	et	3	main
nende	doc_418750402004_item	2399946	et	4	main
rangelt	doc_418750402004_item	2399947	et	4	main
lastele	doc_418750402004_item	2399952	et	4	main
kliimamuutuse	doc_418750402005_item	2399979	et	4	main
sulavad	doc_418750402005_item	2399982	et	4	main
liustikud	doc_418750402005_item	2399983	et	3	main
äärmuslik	doc_418750402005_item	2399988	et	3	main
ja	doc_418750402005_item	2399993	et	3	main
tõusuks	doc_418750402005_item	2400007	et	4	main
et	doc_418750402005_item	2400014	et	3	main
liit	doc_418750402006_item	2400019	et	3	main
mööblipindu	doc_418750402004_item	2399898	et	4	main
baktereid	doc_418750402004_item	2399926	et	3	main
ja	doc_418750402004_item	2399955	et	3	main
keemilis	doc_418750402004_item	2399957	et	4	main
ja	doc_418750402004_item	2399969	et	3	main
on	doc_418750402005_item	2399978	et	4	main
vähenevad	doc_418750402005_item	2399984	et	4	main
kuumalained	doc_418750402005_item	2399994	et	4	main
aastaks	doc_418750402005_item	2400003	et	4	main
10355	doc_418750402006_item	2400022	et	2	main
teie	doc_418750402006_item	2400024	et	4	main
aidata	doc_418750402006_item	2400029	et	4	main
linnas	doc_418750402006_item	2400040	et	4	main
on	doc_418750402006_item	2400051	et	4	main
rohkem	doc_418750402007_item	2400078	et	4	main
et	doc_418750402007_item	2400089	et	3	main
õppeasutus	doc_418750402007_item	2400103	et	4	main
pea	doc_418750402007_item	2400107	et	4	main
nii	doc_418750402007_item	2400117	et	3	main
koolis	doc_418750402007_item	2400122	et	4	main
olema	doc_418750402007_item	2400124	et	4	main
kseroks	doc_418750402007_item	2400125	et	3	main
ja	doc_418750402007_item	2400126	et	3	main
hea	doc_418750402007_item	2400127	et	4	main
vastust	doc_418750402007_item	2400134	et	4	main
paberile	doc_418750402007_item	2400135	et	3	main
peaks	doc_418750402007_item	2400144	et	4	main
vähem	doc_418750402007_item	2400146	et	4	main
vaba	doc_418750402007_item	2400153	et	4	main
oma	doc_418750402007_item	2400155	et	4	main
hobidele	doc_418750402007_item	2400156	et	3	main
ole	doc_418750402007_item	2400159	et	4	main
vaja	doc_418750402007_item	2400160	et	4	main
üldse	doc_418750402007_item	2400161	et	3	main
kodutööid	doc_418750402007_item	2400162	et	4	main
5	doc_418750402007_item	2400164	et	2	main
õpilased	doc_418750402007_item	2400165	et	3	main
peaks	doc_418750402007_item	2400166	et	4	main
tahab	doc_418750402007_item	2400173	et	3	main
tunde	doc_418750402007_item	2400185	et	4	main
õppida	doc_418750402008_item	2400227	et	3	main
eestlaste	doc_418750402008_item	2400232	et	4	main
vene	doc_418750402008_item	2400241	et	4	main
venemaal	doc_418750402008_item	2400263	et	4	main
igasuguseid	doc_418750402008_item	2400277	et	3	main
dokumente	doc_418750402008_item	2400278	et	3	main
et	doc_418750402008_item	2400279	et	3	main
elada	doc_418750402008_item	2400280	et	3	main
seal	doc_418750402008_item	2400281	et	4	main
kuulus	doc_418750402008_item	2400288	et	4	main
tahavad	doc_418750402008_item	2400290	et	3	main
1	doc_418750402009_item	2400326	et	2	main
inimeste	doc_418750402009_item	2400330	et	3	main
meie	doc_418750402009_item	2400335	et	4	main
pühkmehunnik	doc_418750402009_item	2400340	et	4	main
halba	doc_418750402009_item	2400342	et	4	main
toidu	doc_418750402009_item	2400343	et	3	main
halva	doc_418750402009_item	2400357	et	4	main
keskkonna	doc_418750402009_item	2400358	et	3	main
eest	doc_418750402009_item	2400359	et	4	main
nende	doc_418750402009_item	2400363	et	4	main
ei	doc_418750402009_item	2400381	et	4	main
puhas	doc_418750402009_item	2400385	et	3	main
harjutus	doc_418750402010_item	2400389	et	4	main
kaupluses	doc_418750402010_item	2400392	et	3	main
nõudepesu	doc_418750402010_item	2400394	et	4	main
valik	doc_418750402010_item	2400396	et	3	main
kaupa	doc_418750402010_item	2400407	et	4	main
reklaamiv	doc_418750402010_item	2400408	et	4	main
kaupluses	doc_418750402010_item	2400430	et	3	main
on	doc_418750402010_item	2400434	et	4	main
oleks	doc_418750402011_item	2400440	et	3	main
valik	doc_418750402011_item	2400441	et	3	main
ohte	doc_418750402011_item	2400458	et	4	main
keemilised	doc_418750402011_item	2400464	et	4	main
mürgised	doc_418750402011_item	2400468	et	4	main
sain	doc_418750402012_item	2400520	et	3	main
kuidas	doc_418750402012_item	2400522	et	3	main
ja	doc_418750402012_item	2400525	et	3	main
on	doc_418750402012_item	2400529	et	4	main
kapsast	doc_418750402012_item	2400532	et	4	main
sellel	doc_418750402012_item	2400545	et	4	main
veel	doc_418750402004_item	2399927	et	4	main
võivad	doc_418750402004_item	2399929	et	4	main
on	doc_418750402004_item	2399943	et	4	main
tulla	doc_418750402004_item	2399950	et	3	main
kohas	doc_418750402004_item	2399954	et	4	main
kasutada	doc_418750402004_item	2399956	et	3	main
ainet	doc_418750402004_item	2399958	et	3	main
kummikindades	doc_418750402004_item	2399959	et	4	main
ma	doc_418750402004_item	2399960	et	3	main
väidan	doc_418750402004_item	2399961	et	3	main
et	doc_418750402004_item	2399962	et	3	main
kodukeemial	doc_418750402004_item	2399963	et	3	main
oleb	doc_418750402004_item	2399964	et	4	main
rohkem	doc_418750402004_item	2399965	et	4	main
plusse	doc_418750402004_item	2399966	et	3	main
kuid	doc_418750402004_item	2399967	et	4	main
minnusi	doc_418750402004_item	2399968	et	4	main
sellepärast	doc_418750402004_item	2399970	et	3	main
arvamus	doc_418750402005_item	2399976	et	3	main
milline	doc_418750402005_item	2399977	et	3	main
põud	doc_418750402005_item	2399992	et	3	main
mutmekesisuse	doc_418750402005_item	2399996	et	4	main
muutuda	doc_418750402005_item	2400002	et	3	main
prognoositakse	doc_418750402005_item	2400005	et	3	main
15	doc_418750402006_item	2400021	et	2	main
ootate	doc_418750402006_item	2400030	et	3	main
ideead	doc_418750402006_item	2400032	et	4	main
parandada	doc_418750402006_item	2400034	et	3	main
keskkonda	doc_418750402006_item	2400036	et	4	main
ma	doc_418750402006_item	2400037	et	3	main
elan	doc_418750402006_item	2400038	et	3	main
väikeses	doc_418750402006_item	2400039	et	4	main
narva	doc_418750402006_item	2400044	et	4	main
mõned	doc_418750402006_item	2400054	et	3	main
ma	doc_418750402006_item	2400057	et	3	main
on	doc_418750402006_item	2400059	et	4	main
25	doc_418750402007_item	2400080	et	2	main
õpilast	doc_418750402007_item	2400081	et	4	main
õppeprotsess	doc_418750402007_item	2400083	et	3	main
ei	doc_418750402007_item	2400091	et	4	main
vaja	doc_418750402007_item	2400093	et	4	main
koolivormiriietust	doc_418750402007_item	2400094	et	3	main
aga	doc_418750402007_item	2400095	et	3	main
õpilased	doc_418750402007_item	2400096	et	3	main
kool	doc_418750402007_item	2400101	et	4	main
ei	doc_418750402007_item	2400106	et	4	main
väljakutsuvat	doc_418750402007_item	2400110	et	3	main
3	doc_418750402007_item	2400112	et	2	main
tehnika	doc_418750402007_item	2400128	et	4	main
tunnides	doc_418750402007_item	2400130	et	4	main
õpilased	doc_418750402007_item	2400131	et	3	main
kirjutaksid	doc_418750402007_item	2400132	et	4	main
informatsiooni	doc_418750402007_item	2400139	et	4	main
4	doc_418750402007_item	2400140	et	2	main
ülesandeid	doc_418750402007_item	2400148	et	3	main
õpilasel	doc_418750402007_item	2400151	et	3	main
puhkepäevadel	doc_418750402007_item	2400157	et	3	main
õppida	doc_418750402007_item	2400175	et	3	main
rohkem	doc_418750402007_item	2400183	et	4	main
keemia	doc_418750402007_item	2400184	et	4	main
küsimus	doc_418750402008_item	2400190	et	4	main
kodumaal	doc_418750402008_item	2400228	et	4	main
soovivad	doc_418750402008_item	2400243	et	4	main
minna	doc_418750402008_item	2400246	et	3	main
nende	doc_418750402008_item	2400248	et	4	main
taha	doc_418750402008_item	2400261	et	4	main
õppida	doc_418750402008_item	2400262	et	3	main
on	doc_418750402008_item	2400275	et	4	main
vaja	doc_418750402008_item	2400276	et	4	main
huvitav	doc_418750402008_item	2400283	et	4	main
asub	doc_418750402008_item	2400287	et	3	main
õppida	doc_418750402008_item	2400291	et	3	main
tallinnas	doc_418750402008_item	2400322	et	4	main
või	doc_418750402008_item	2400323	et	4	main
harjutus	doc_418750402009_item	2400325	et	4	main
2	doc_418750402009_item	2400338	et	2	main
raha	doc_418750402009_item	2400346	et	4	main
5	doc_418750402009_item	2400365	et	2	main
olid	doc_418750402009_item	2400367	et	4	main
tüdinenud	doc_418750402009_item	2400375	et	4	main
proektile	doc_418750402009_item	2400387	et	4	main
olev	doc_418750402010_item	2400393	et	4	main
vahendite	doc_418750402010_item	2400395	et	3	main
2	doc_418750402010_item	2400399	et	2	main
küüriv	doc_418750402010_item	2400402	et	4	main
on	doc_418750402010_item	2400404	et	4	main
populaarne	doc_418750402010_item	2400412	et	3	main
6	doc_418750402010_item	2400428	et	2	main
müüdavad	doc_418750402010_item	2400431	et	4	main
raamatutest	doc_418750402011_item	2400453	et	4	main
vesi	doc_418750402011_item	2400456	et	4	main
väga	doc_418750402011_item	2400467	et	3	main
pärast	doc_418750402011_item	2400469	et	4	main
seda	doc_418750402011_item	2400470	et	3	main
ma	doc_418750402011_item	2400471	et	3	main
olen	doc_418750402011_item	2400472	et	3	main
kindel	doc_418750402011_item	2400473	et	3	main
et	doc_418750402011_item	2400474	et	3	main
reklaamide	doc_418750402011_item	2400475	et	3	main
tahate	doc_418750402006_item	2400028	et	3	main
uue	doc_418750402006_item	2400031	et	3	main
kuidas	doc_418750402006_item	2400033	et	3	main
on	doc_418750402006_item	2400043	et	4	main
asjad	doc_418750402006_item	2400055	et	3	main
vastus	doc_418750402007_item	2400061	et	3	main
küsimusele	doc_418750402007_item	2400062	et	4	main
1	doc_418750402007_item	2400063	et	2	main
mulle	doc_418750402007_item	2400064	et	4	main
tundub	doc_418750402007_item	2400065	et	3	main
et	doc_418750402007_item	2400066	et	3	main
mõnikord	doc_418750402007_item	2400067	et	3	main
õpilaste	doc_418750402007_item	2400068	et	4	main
arv	doc_418750402007_item	2400069	et	3	main
klassis	doc_418750402007_item	2400070	et	3	main
on	doc_418750402007_item	2400071	et	4	main
liiga	doc_418750402007_item	2400072	et	4	main
suur	doc_418750402007_item	2400073	et	3	main
klassis	doc_418750402007_item	2400074	et	3	main
ei	doc_418750402007_item	2400075	et	4	main
pea	doc_418750402007_item	2400076	et	4	main
õppima	doc_418750402007_item	2400077	et	3	main
ebbaktiivsem	doc_418750402007_item	2400085	et	4	main
ma	doc_418750402007_item	2400087	et	3	main
peavad	doc_418750402007_item	2400097	et	4	main
on	doc_418750402007_item	2400102	et	4	main
kandma	doc_418750402007_item	2400108	et	3	main
õppematerjali	doc_418750402007_item	2400116	et	4	main
on	doc_418750402007_item	2400118	et	4	main
ja	doc_418750402007_item	2400136	et	3	main
otsiksid	doc_418750402007_item	2400137	et	4	main
et	doc_418750402007_item	2400142	et	3	main
oli	doc_418750402007_item	2400152	et	3	main
kui	doc_418750402007_item	2400171	et	3	main
on	doc_418750402008_item	2400191	et	4	main
õpilaste	doc_418750402008_item	2400193	et	4	main
ja	doc_418750402008_item	2400196	et	3	main
eesti	doc_418750402008_item	2400197	et	4	main
noored	doc_418750402008_item	2400198	et	3	main
vastasid	doc_418750402008_item	2400199	et	4	main
kuhu	doc_418750402008_item	2400200	et	3	main
nad	doc_418750402008_item	2400201	et	3	main
soovivad	doc_418750402008_item	2400202	et	4	main
edasi	doc_418750402008_item	2400203	et	3	main
õppima	doc_418750402008_item	2400204	et	3	main
minne	doc_418750402008_item	2400205	et	4	main
vastused	doc_418750402008_item	2400206	et	3	main
olid	doc_418750402008_item	2400207	et	4	main
erinevad	doc_418750402008_item	2400208	et	4	main
õpilased	doc_418750402008_item	2400209	et	3	main
nimetasid	doc_418750402008_item	2400210	et	4	main
riiki	doc_418750402008_item	2400212	et	4	main
seitse	doc_418750402008_item	2400211	et	3	main
need	doc_418750402008_item	2400213	et	3	main
on	doc_418750402008_item	2400214	et	4	main
eesti	doc_418750402008_item	2400215	et	4	main
usa	doc_418750402008_item	2400216	et	4	main
soome	doc_418750402008_item	2400217	et	3	main
saksamaa	doc_418750402008_item	2400218	et	4	main
rootsi	doc_418750402008_item	2400219	et	4	main
venemaa	doc_418750402008_item	2400220	et	4	main
ja	doc_418750402008_item	2400221	et	3	main
suurem	doc_418750402008_item	2400223	et	4	main
enampopulaarsem	doc_418750402008_item	2400230	et	4	main
on	doc_418750402008_item	2400234	et	4	main
aga	doc_418750402008_item	2400236	et	3	main
venelaste	doc_418750402008_item	2400237	et	4	main
jaoks	doc_418750402008_item	2400238	et	4	main
soome	doc_418750402008_item	2400239	et	3	main
paljud	doc_418750402008_item	2400240	et	3	main
õppima	doc_418750402008_item	2400245	et	3	main
sest	doc_418750402008_item	2400247	et	4	main
jaoks	doc_418750402008_item	2400249	et	4	main
on	doc_418750402008_item	2400250	et	4	main
emakeeles	doc_418750402008_item	2400253	et	4	main
elada	doc_418750402008_item	2400255	et	3	main
venelastega	doc_418750402008_item	2400257	et	4	main
eestlased	doc_418750402008_item	2400258	et	3	main
üldse	doc_418750402008_item	2400259	et	3	main
ei	doc_418750402008_item	2400260	et	4	main
eesti	doc_418750402008_item	2400271	et	4	main
kodakondsus	doc_418750402008_item	2400272	et	3	main
ja	doc_418750402008_item	2400273	et	3	main
neil	doc_418750402008_item	2400274	et	4	main
on	doc_418750402008_item	2400282	et	4	main
õppida	doc_418750402008_item	2400321	et	3	main
näiteks	doc_418750402007_item	2400170	et	4	main
õpilane	doc_418750402007_item	2400172	et	3	main
keemia	doc_418750402007_item	2400177	et	4	main
on	doc_418750402007_item	2400181	et	4	main
vaja	doc_418750402007_item	2400182	et	4	main
kirjeldus	doc_418750402008_item	2400189	et	4	main
seotud	doc_418750402008_item	2400192	et	4	main
edasiõppimiseelistustega	doc_418750402008_item	2400194	et	3	main
vene	doc_418750402008_item	2400195	et	4	main
arvamus	doc_418750402008_item	2400187	et	3	main
skeemi	doc_418750402008_item	2400188	et	4	main
kõige	doc_418750402008_item	2400229	et	4	main
riik	doc_418750402008_item	2400231	et	3	main
venemaale	doc_418750402008_item	2400244	et	4	main
ja	doc_418750402008_item	2400254	et	3	main
koos	doc_418750402008_item	2400256	et	4	main
põhjus	doc_418750402008_item	2400265	et	4	main
see	doc_418750402008_item	2400267	et	3	main
et	doc_418750402008_item	2400268	et	3	main
neil	doc_418750402008_item	2400269	et	4	main
tartus	doc_418750402008_item	2400285	et	3	main
kus	doc_418750402008_item	2400286	et	3	main
imestan	doc_418750402009_item	2400328	et	3	main
üle	doc_418750402009_item	2400331	et	3	main
keskkonda	doc_418750402009_item	2400337	et	4	main
vana	doc_418750402009_item	2400339	et	4	main
haiseb	doc_418750402009_item	2400341	et	3	main
takistab	doc_418750402009_item	2400348	et	3	main
kaasaegse	doc_418750402009_item	2400350	et	3	main
ehitamisest	doc_418750402009_item	2400352	et	4	main
inimesed	doc_418750402009_item	2400354	et	3	main
peavad	doc_418750402009_item	2400355	et	4	main
hoiduma	doc_418750402009_item	2400356	et	3	main
sõltub	doc_418750402009_item	2400362	et	3	main
õpilased	doc_418750402009_item	2400366	et	3	main
väsinud	doc_418750402009_item	2400368	et	4	main
kevade	doc_418750402009_item	2400369	et	4	main
7	doc_418750402009_item	2400379	et	2	main
tohi	doc_418750402009_item	2400382	et	4	main
1	doc_418750402010_item	2400390	et	2	main
on	doc_418750402010_item	2400397	et	4	main
pastaga	doc_418750402010_item	2400400	et	3	main
väsinud	doc_418750402010_item	2400405	et	4	main
firma	doc_418750402010_item	2400409	et	4	main
inimese	doc_418750402010_item	2400421	et	4	main
tegevad	doc_418750402010_item	2400423	et	4	main
meigivahendeid	doc_418750402010_item	2400424	et	3	main
müüakse	doc_418750402010_item	2400425	et	3	main
igas	doc_418750402010_item	2400426	et	3	main
kaupluses	doc_418750402010_item	2400427	et	3	main
kodukeemilised	doc_418750402010_item	2400432	et	4	main
erinevad	doc_418750402010_item	2400436	et	4	main
kui	doc_418750402011_item	2400438	et	3	main
mul	doc_418750402011_item	2400439	et	3	main
proekte	doc_418750402011_item	2400443	et	4	main
kõigepealt	doc_418750402011_item	2400446	et	3	main
ma	doc_418750402011_item	2400447	et	3	main
rahastaksin	doc_418750402011_item	2400448	et	4	main
veekogude	doc_418750402011_item	2400449	et	3	main
täis	doc_418750402011_item	2400457	et	4	main
on	doc_418750402011_item	2400466	et	4	main
olema	doc_418750402011_item	2400478	et	4	main
rahastatud	doc_418750402011_item	2400479	et	4	main
õigesti	doc_418750402012_item	2400523	et	3	main
leena	doc_418750402012_item	2400542	et	3	main
ta	doc_418750402012_item	2400550	et	4	main
sai	doc_418750402012_item	2400551	et	4	main
kogemus	doc_418750402012_item	2400552	et	3	main
suhelda	doc_418750402012_item	2400553	et	4	main
kogemus	doc_418750402012_item	2400573	et	3	main
aga	doc_418750402012_item	2400581	et	3	main
kui	doc_418750402012_item	2400585	et	3	main
kuidas	doc_418750402012_item	2400595	et	3	main
tallinnas	doc_418750402012_item	2400602	et	4	main
sellepärast	doc_418750402012_item	2400613	et	3	main
et	doc_418750402012_item	2400614	et	3	main
ta	doc_418750402012_item	2400615	et	4	main
keel	doc_418750402012_item	2400625	et	4	main
kogemust	doc_418750402012_item	2400627	et	3	main
suve	doc_418750402012_item	2400628	et	4	main
lõpp	doc_418750402012_item	2400629	et	3	main
peipsi-järve	doc_418750402012_item	2400632	et	4	main
ääres	doc_418750402012_item	2400633	et	4	main
kus	doc_418750402012_item	2400634	et	3	main
ma	doc_418750402012_item	2400635	et	3	main
aitasin	doc_418750402012_item	2400636	et	3	main
huvitav	doc_418750402012_item	2400644	et	4	main
ta	doc_418750402012_item	2400650	et	4	main
mina	doc_418750402012_item	2400659	et	4	main
soomes	doc_418750402012_item	2400675	et	4	main
oli	doc_418750402012_item	2400679	et	3	main
taani	doc_418750402008_item	2400222	et	4	main
osa	doc_418750402008_item	2400224	et	4	main
noortest	doc_418750402008_item	2400225	et	4	main
tahab	doc_418750402008_item	2400226	et	3	main
jaoks	doc_418750402008_item	2400233	et	4	main
rootsi	doc_418750402008_item	2400235	et	4	main
õpilasi	doc_418750402008_item	2400242	et	3	main
kergem	doc_418750402008_item	2400251	et	4	main
õppida	doc_418750402008_item	2400252	et	3	main
üks	doc_418750402008_item	2400264	et	3	main
on	doc_418750402008_item	2400266	et	4	main
on	doc_418750402008_item	2400270	et	4	main
et	doc_418750402008_item	2400284	et	3	main
ülikool	doc_418750402008_item	2400289	et	4	main
ainult	doc_418750402008_item	2400292	et	4	main
mõned	doc_418750402008_item	2400293	et	3	main
venelased	doc_418750402008_item	2400294	et	3	main
sest	doc_418750402008_item	2400295	et	4	main
õppimine	doc_418750402008_item	2400296	et	4	main
on	doc_418750402008_item	2400297	et	4	main
põhiliselt	doc_418750402008_item	2400298	et	4	main
eesti	doc_418750402008_item	2400299	et	4	main
keeles	doc_418750402008_item	2400300	et	4	main
ja	doc_418750402008_item	2400301	et	3	main
linnas	doc_418750402008_item	2400302	et	4	main
elab	doc_418750402008_item	2400303	et	3	main
vähe	doc_418750402008_item	2400304	et	3	main
venalasi	doc_418750402008_item	2400305	et	4	main
ise	doc_418750402008_item	2400306	et	4	main
eelistan	doc_418750402008_item	2400307	et	3	main
eestis	doc_418750402008_item	2400308	et	3	main
õppida	doc_418750402008_item	2400309	et	3	main
kahjuks	doc_418750402008_item	2400310	et	4	main
ma	doc_418750402008_item	2400311	et	3	main
ei	doc_418750402008_item	2400312	et	4	main
otsustanud	doc_418750402008_item	2400313	et	4	main
veel	doc_418750402008_item	2400314	et	4	main
linnas	doc_418750402008_item	2400315	et	4	main
aga	doc_418750402008_item	2400316	et	3	main
mõtlen	doc_418750402008_item	2400317	et	3	main
et	doc_418750402008_item	2400318	et	3	main
oleks	doc_418750402008_item	2400319	et	3	main
hea	doc_418750402008_item	2400320	et	4	main
ma	doc_418750402009_item	2400327	et	3	main
ei	doc_418750402009_item	2400333	et	4	main
huvita	doc_418750402009_item	2400334	et	4	main
järele	doc_418750402009_item	2400344	et	4	main
sest	doc_418750402009_item	2400360	et	4	main
tervis	doc_418750402009_item	2400364	et	3	main
keskkonnapuhastamises	doc_418750402009_item	2400376	et	3	main
osalemast	doc_418750402009_item	2400378	et	3	main
me	doc_418750402009_item	2400380	et	4	main
juhul	doc_418750402009_item	2400384	et	3	main
suur	doc_418750402010_item	2400398	et	3	main
vanni	doc_418750402010_item	2400401	et	4	main
taivor	doc_418750402010_item	2400403	et	4	main
3	doc_418750402010_item	2400406	et	2	main
on	doc_418750402010_item	2400410	et	4	main
4	doc_418750402010_item	2400413	et	2	main
juukseid	doc_418750402010_item	2400414	et	3	main
puhastaval	doc_418750402010_item	2400415	et	4	main
shampoonil	doc_418750402010_item	2400416	et	4	main
on	doc_418750402010_item	2400417	et	4	main
hea	doc_418750402010_item	2400418	et	4	main
lõhn	doc_418750402010_item	2400419	et	3	main
5	doc_418750402010_item	2400420	et	2	main
ilusamaks	doc_418750402010_item	2400422	et	4	main
tänapäeval	doc_418750402010_item	2400429	et	3	main
väga	doc_418750402010_item	2400435	et	3	main
arvamus	doc_418750402011_item	2400437	et	3	main
puhastamise	doc_418750402011_item	2400450	et	4	main
lugenud	doc_418750402011_item	2400452	et	4	main
et	doc_418750402011_item	2400454	et	3	main
määrdunud	doc_418750402011_item	2400455	et	4	main
ained	doc_418750402011_item	2400465	et	3	main
oluline	doc_418750402011_item	2400480	et	4	main
sealt	doc_418750402012_item	2400518	et	4	main
ma	doc_418750402012_item	2400519	et	3	main
tartus	doc_418750402008_item	2400324	et	3	main
nende	doc_418750402009_item	2400329	et	4	main
kes	doc_418750402009_item	2400332	et	4	main
elu	doc_418750402009_item	2400336	et	4	main
3	doc_418750402009_item	2400345	et	2	main
puudus	doc_418750402009_item	2400347	et	4	main
uue	doc_418750402009_item	2400349	et	3	main
prügihoidla	doc_418750402009_item	2400351	et	4	main
4	doc_418750402009_item	2400353	et	2	main
sellest	doc_418750402009_item	2400361	et	4	main
koristamisest	doc_418750402009_item	2400370	et	4	main
vanas	doc_418750402009_item	2400371	et	3	main
pargis	doc_418750402009_item	2400372	et	3	main
6	doc_418750402009_item	2400373	et	2	main
olen	doc_418750402009_item	2400374	et	3	main
proektis	doc_418750402009_item	2400377	et	4	main
mingil	doc_418750402009_item	2400383	et	4	main
keskkond	doc_418750402009_item	2400386	et	3	main
minemata	doc_418750402009_item	2400388	et	4	main
tänapäeval	doc_418750402010_item	2400391	et	3	main
väga	doc_418750402010_item	2400411	et	3	main
ained	doc_418750402010_item	2400433	et	3	main
milliseid	doc_418750402011_item	2400442	et	3	main
rahastada	doc_418750402011_item	2400444	et	4	main
siis	doc_418750402011_item	2400445	et	3	main
olen	doc_418750402011_item	2400451	et	3	main
meie	doc_418750402011_item	2400459	et	4	main
tervisele	doc_418750402011_item	2400460	et	3	main
mustas	doc_418750402011_item	2400461	et	4	main
vees	doc_418750402011_item	2400462	et	3	main
olevad	doc_418750402011_item	2400463	et	4	main
peaks	doc_418750402011_item	2400477	et	4	main
on	doc_418750402011_item	2400481	et	4	main
see	doc_418750402011_item	2400482	et	3	main
et	doc_418750402011_item	2400483	et	3	main
inimesed	doc_418750402011_item	2400484	et	3	main
peavad	doc_418750402011_item	2400485	et	4	main
tihti	doc_418750402011_item	2400486	et	3	main
mõlgutama	doc_418750402011_item	2400487	et	4	main
meie	doc_418750402011_item	2400488	et	4	main
keskkonnast	doc_418750402011_item	2400489	et	4	main
ma	doc_418750402011_item	2400490	et	3	main
olen	doc_418750402011_item	2400491	et	3	main
veendunud	doc_418750402011_item	2400492	et	4	main
et	doc_418750402011_item	2400493	et	3	main
ilusad	doc_418750402011_item	2400494	et	3	main
reklaamid	doc_418750402011_item	2400495	et	4	main
võivad	doc_418750402011_item	2400497	et	4	main
loodust	doc_418750402011_item	2400496	et	4	main
aitama	doc_418750402011_item	2400498	et	3	main
selles	doc_418750402011_item	2400499	et	4	main
siis	doc_418750402011_item	2400500	et	3	main
olulisel	doc_418750402011_item	2400501	et	4	main
kohal	doc_418750402011_item	2400502	et	4	main
on	doc_418750402011_item	2400503	et	4	main
ürituse	doc_418750402011_item	2400504	et	4	main
loodusesõbrad	doc_418750402011_item	2400505	et	3	main
läbiviimist	doc_418750402011_item	2400506	et	3	main
rahastamine	doc_418750402011_item	2400507	et	4	main
kirjand	doc_418750402012_item	2400508	et	3	main
suve	doc_418750402012_item	2400509	et	4	main
kogemus	doc_418750402012_item	2400510	et	3	main
sellel	doc_418750402012_item	2400511	et	4	main
trükkimist	doc_418750402011_item	2400476	et	4	main
suvel	doc_418750402012_item	2400512	et	3	main
ma	doc_418750402012_item	2400513	et	3	main
olen	doc_418750402012_item	2400514	et	3	main
emaga	doc_418750402012_item	2400515	et	3	main
soomes	doc_418750402012_item	2400516	et	4	main
põllutöödel	doc_418750402012_item	2400517	et	3	main
korjama	doc_418750402012_item	2400527	et	3	main
taimi	doc_418750402012_item	2400537	et	4	main
ja	doc_418750402012_item	2400538	et	3	main
sain	doc_418750402012_item	2400539	et	3	main
mitmekesist	doc_418750402012_item	2400540	et	4	main
põllutöökogemust	doc_418750402012_item	2400541	et	3	main
oli	doc_418750402012_item	2400543	et	3	main
teatrikaaslastega	doc_418750402012_item	2400549	et	4	main
erinevate	doc_418750402012_item	2400555	et	4	main
ta	doc_418750402012_item	2400559	et	4	main
veel	doc_418750402012_item	2400575	et	4	main
me	doc_418750402012_item	2400578	et	4	main
olime	doc_418750402012_item	2400579	et	3	main
ajal	doc_418750402012_item	2400583	et	4	main
oma	doc_418750402012_item	2400588	et	4	main
oma	doc_418750402012_item	2400597	et	4	main
leena	doc_418750402012_item	2400600	et	3	main
kuidas	doc_418750402012_item	2400604	et	3	main
oma	doc_418750402012_item	2400606	et	4	main
sest	doc_418750402012_item	2400608	et	4	main
ta	doc_418750402012_item	2400609	et	4	main
töötas	doc_418750402012_item	2400610	et	3	main
räägis	doc_418750402012_item	2400616	et	3	main
eesti	doc_418750402012_item	2400621	et	4	main
ta	doc_418750402012_item	2400623	et	4	main
sai	doc_418750402012_item	2400624	et	4	main
laagris	doc_418750402012_item	2400648	et	3	main
praktiseeris	doc_418750402012_item	2400651	et	3	main
inglise	doc_418750402012_item	2400652	et	4	main
lõpuks	doc_418750402012_item	2400654	et	4	main
ma	doc_418750402012_item	2400655	et	3	main
leena	doc_418750402012_item	2400661	et	3	main
suve	doc_418750402012_item	2400664	et	4	main
osaliselt	doc_418750402012_item	2400665	et	4	main
võrdselt	doc_418750402012_item	2400666	et	4	main
sest	doc_418750402012_item	2400667	et	4	main
kasumiseks	doc_418750402012_item	2400673	et	4	main
olime	doc_418750402012_item	2400674	et	3	main
suve	doc_418750402012_item	2400682	et	4	main
kontrolltöö	doc_42187174247_item	2400684	et	4	main
kontrolltöö	doc_42187174247_item	2400685	et	4	main
1631	doc_42187174247_item	2400722	et	2	main
tallinnas	doc_42187174247_item	2400727	et	4	main
tänapäeva	doc_42187174247_item	2400730	et	4	main
gümnaasiumisi	doc_42187174247_item	2400737	et	4	main
kõigepealt	doc_42187174247_item	2400740	et	3	main
3	doc_42187174247_item	2400743	et	2	main
klassis	doc_42187174247_item	2400744	et	3	main
rootsi	doc_42187174247_item	2400746	et	4	main
kuningriik	doc_42187174247_item	2400747	et	3	main
pidas	doc_42187174247_item	2400748	et	3	main
väga	doc_42187174247_item	2400749	et	3	main
vajalikuks	doc_42187174247_item	2400750	et	3	main
hariduse	doc_42187174247_item	2400751	et	3	main
andmist	doc_42187174247_item	2400752	et	4	main
gustav	doc_42187174247_item	2400754	et	4	main
alla	doc_42187174247_item	2400758	et	3	main
ülikooliks	doc_42187174247_item	2400767	et	4	main
tartusse	doc_42187174247_item	2400783	et	3	main
1	doc_42187174247_item	2400824	et	2	main
keelt	doc_42187174247_item	2400826	et	4	main
grammatika	doc_42187174247_item	2400829	et	4	main
teha	doc_42187174247_item	2400834	et	3	main
tema	doc_42187174247_item	2400837	et	4	main
üliõpilaste	doc_42187174247_item	2400853	et	4	main
mingit	doc_42187174247_item	2400862	et	3	main
ülikoolis	doc_42187174247_item	2400866	et	4	main
enamik	doc_42187174247_item	2400870	et	3	main
aastane	doc_42187174247_item	2400885	et	4	main
aastail	doc_42187174247_item	2400896	et	4	main
kandidaat	doc_42187174247_item	2400899	et	3	main
romantism	doc_42187174247_item	2400921	et	3	main
troonile	doc_42187174247_item	2400930	et	3	main
pärisorjusest	doc_42187174247_item	2400938	et	4	main
seoses	doc_42187174247_item	2400941	et	4	main
salatit	doc_418750402012_item	2400524	et	3	main
vaja	doc_418750402012_item	2400530	et	4	main
istutama	doc_418750402012_item	2400536	et	4	main
soomes	doc_418750402012_item	2400544	et	4	main
suvel	doc_418750402012_item	2400546	et	3	main
ka	doc_418750402012_item	2400547	et	3	main
tema	doc_418750402012_item	2400548	et	4	main
väga	doc_418750402012_item	2400554	et	3	main
mina	doc_418750402012_item	2400558	et	4	main
suheldas	doc_418750402012_item	2400560	et	4	main
eenglise	doc_418750402012_item	2400561	et	4	main
keeles	doc_418750402012_item	2400562	et	4	main
selle	doc_418750402012_item	2400563	et	4	main
pärast	doc_418750402012_item	2400564	et	4	main
ma	doc_418750402012_item	2400565	et	3	main
võin	doc_418750402012_item	2400566	et	3	main
öelda	doc_418750402012_item	2400567	et	4	main
et	doc_418750402012_item	2400568	et	3	main
me	doc_418750402012_item	2400569	et	4	main
saime	doc_418750402012_item	2400570	et	3	main
keele	doc_418750402012_item	2400571	et	4	main
kasumiseks	doc_418750402012_item	2400572	et	4	main
teada	doc_418750402012_item	2400521	et	3	main
maasikad	doc_418750402012_item	2400526	et	3	main
miks	doc_418750402012_item	2400528	et	4	main
palavuses	doc_418750402012_item	2400531	et	4	main
rohima	doc_418750402012_item	2400533	et	3	main
kuidas	doc_418750402012_item	2400534	et	3	main
peama	doc_418750402012_item	2400535	et	4	main
inimestega	doc_418750402012_item	2400556	et	3	main
soomes	doc_418750402012_item	2400574	et	4	main
sellel	doc_418750402012_item	2400576	et	4	main
suvel	doc_418750402012_item	2400577	et	3	main
ja	doc_418750402012_item	2400584	et	3	main
veetsin	doc_418750402012_item	2400587	et	3	main
raisata	doc_418750402012_item	2400596	et	4	main
sai	doc_418750402012_item	2400601	et	4	main
müüjana	doc_418750402012_item	2400611	et	4	main
sadamas	doc_418750402012_item	2400612	et	4	main
ema	doc_418750402012_item	2400637	et	4	main
aias	doc_418750402012_item	2400638	et	4	main
itaalias	doc_418750402012_item	2400646	et	4	main
veetsime	doc_418750402012_item	2400662	et	3	main
me	doc_418750402012_item	2400668	et	4	main
saime	doc_418750402012_item	2400669	et	3	main
kogemuse	doc_418750402012_item	2400670	et	3	main
ja	doc_418750402012_item	2400676	et	3	main
rahuolev	doc_418750402012_item	2400680	et	3	main
eesti	doc_42187174247_item	2400686	et	4	main
kultuuriloost	doc_42187174247_item	2400687	et	4	main
1	doc_42187174247_item	2400688	et	2	main
kirjutas	doc_42187174247_item	2400757	et	3	main
oli	doc_42187174247_item	2400770	et	3	main
usuteaduskond	doc_42187174247_item	2400782	et	3	main
õpetati	doc_42187174247_item	2400827	et	3	main
vaid	doc_42187174247_item	2400828	et	3	main
paasil	doc_42187174247_item	2400830	et	4	main
igas	doc_42187174247_item	2400831	et	3	main
valitud	doc_42187174247_item	2400839	et	4	main
eksamil	doc_42187174247_item	2400844	et	3	main
kuulama	doc_42187174247_item	2400846	et	3	main
tulla	doc_42187174247_item	2400847	et	3	main
rootsist	doc_42187174247_item	2400854	et	3	main
kooli	doc_42187174247_item	2400857	et	4	main
puhul	doc_42187174247_item	2400859	et	4	main
lõpemese	doc_42187174247_item	2400863	et	4	main
dokumenti	doc_42187174247_item	2400864	et	4	main
diplom	doc_42187174247_item	2400865	et	3	main
õppemaksu	doc_42187174247_item	2400869	et	4	main
olid	doc_42187174247_item	2400872	et	4	main
väga	doc_42187174247_item	2400874	et	3	main
palju	doc_42187174247_item	2400875	et	4	main
piltlikult	doc_42187174247_item	2400889	et	4	main
näidati	doc_42187174247_item	2400890	et	3	main
kuidas	doc_42187174247_item	2400891	et	3	main
harimatust	doc_42187174247_item	2400892	et	4	main
inimesest	doc_42187174247_item	2400893	et	3	main
ette	doc_42187174247_item	2400902	et	4	main
ja	doc_42187174247_item	2400903	et	3	main
ta	doc_42187174247_item	2400904	et	4	main
venemaal	doc_42187174247_item	2400929	et	4	main
said	doc_42187174247_item	2400936	et	4	main
eestlased	doc_42187174247_item	2400937	et	3	main
varem	doc_42187174247_item	2400952	et	4	main
viina	doc_42187174247_item	2400955	et	4	main
baltimaadel	doc_42187174247_item	2400956	et	4	main
oli	doc_42187174247_item	2400957	et	3	main
tartu	doc_42187174248_item	2401008	et	4	main
vabastati	doc_42187174248_item	2401018	et	3	main
pärisorjusest	doc_42187174248_item	2401020	et	4	main
see	doc_42187174248_item	2401023	et	3	main
jaoks	doc_42187174248_item	2401025	et	4	main
sisuliselt	doc_42187174248_item	2401026	et	4	main
tähendas	doc_42187174248_item	2401027	et	3	main
1	doc_42187174248_item	2401028	et	2	main
kolitada	doc_42187174248_item	2401036	et	4	main
esto	doc_42187174248_item	2401042	et	4	main
tartusse	doc_42187174248_item	2401045	et	3	main
esimene	doc_42187174248_item	2401046	et	3	main
gümnaasium	doc_42187174248_item	2401047	et	3	main
kus	doc_42187174248_item	2401048	et	3	main
ainult	doc_42187174248_item	2401051	et	4	main
poisid	doc_42187174248_item	2401052	et	4	main
gümnaasiumis	doc_42187174248_item	2401067	et	3	main
13-14	doc_42187174248_item	2401070	et	2	main
nagu	doc_418750402012_item	2400557	et	3	main
vaba	doc_418750402012_item	2400589	et	4	main
siis	doc_418750402012_item	2400599	et	3	main
seal	doc_418750402012_item	2400617	et	4	main
ainult	doc_418750402012_item	2400618	et	4	main
keeles	doc_418750402012_item	2400622	et	4	main
ma	doc_418750402012_item	2400630	et	3	main
veetsin	doc_418750402012_item	2400631	et	3	main
samas	doc_418750402012_item	2400639	et	4	main
kui	doc_418750402012_item	2400640	et	3	main
leenal	doc_418750402012_item	2400641	et	4	main
oli	doc_418750402012_item	2400642	et	3	main
reis	doc_418750402012_item	2400645	et	4	main
noorte	doc_418750402012_item	2400647	et	3	main
kus	doc_418750402012_item	2400649	et	3	main
keelt	doc_418750402012_item	2400653	et	4	main
ja	doc_418750402012_item	2400660	et	3	main
seda	doc_418750402012_item	2400663	et	3	main
keele	doc_418750402012_item	2400672	et	4	main
meist	doc_418750402012_item	2400678	et	3	main
tallinnas	doc_418750402012_item	2400580	et	4	main
erineval	doc_418750402012_item	2400582	et	4	main
ma	doc_418750402012_item	2400586	et	3	main
aega	doc_418750402012_item	2400590	et	4	main
kristiinekeskuses	doc_418750402012_item	2400591	et	4	main
ja	doc_418750402012_item	2400592	et	3	main
sain	doc_418750402012_item	2400593	et	3	main
teada	doc_418750402012_item	2400594	et	3	main
raha	doc_418750402012_item	2400598	et	4	main
kogemuse	doc_418750402012_item	2400603	et	3	main
teenida	doc_418750402012_item	2400605	et	3	main
raha	doc_418750402012_item	2400607	et	4	main
inglise	doc_418750402012_item	2400619	et	4	main
ja	doc_418750402012_item	2400620	et	3	main
parandamist	doc_418750402012_item	2400626	et	4	main
väga	doc_418750402012_item	2400643	et	3	main
tahan	doc_418750402012_item	2400656	et	3	main
ööelda	doc_418750402012_item	2400657	et	4	main
et	doc_418750402012_item	2400658	et	3	main
inglise	doc_418750402012_item	2400671	et	4	main
igaüks	doc_418750402012_item	2400677	et	3	main
tartu	doc_42187174247_item	2400689	et	4	main
ülikooli	doc_42187174247_item	2400690	et	4	main
taasavamise	doc_42187174247_item	2400691	et	4	main
tähtsus	doc_42187174247_item	2400692	et	4	main
eesti	doc_42187174247_item	2400693	et	4	main
haridus-	doc_42187174247_item	2400694	et	3	main
ja	doc_42187174247_item	2400695	et	3	main
kultuurielule	doc_42187174247_item	2400696	et	3	main
2	doc_42187174247_item	2400697	et	2	main
millal	doc_42187174247_item	2400698	et	3	main
vabastati	doc_42187174247_item	2400699	et	3	main
eestlased	doc_42187174247_item	2400700	et	3	main
pärisorjusest	doc_42187174247_item	2400701	et	4	main
ja	doc_42187174247_item	2400702	et	3	main
mida	doc_42187174247_item	2400703	et	4	main
see	doc_42187174247_item	2400704	et	3	main
nende	doc_42187174247_item	2400705	et	4	main
jaoks	doc_42187174247_item	2400706	et	4	main
sisuliselt	doc_42187174247_item	2400707	et	4	main
tähendas	doc_42187174247_item	2400708	et	3	main
1	doc_42187174247_item	2400709	et	2	main
1583	doc_42187174247_item	2400710	et	2	main
jesuiitide	doc_42187174247_item	2400711	et	3	main
eesmärk	doc_42187174247_item	2400713	et	3	main
seminar	doc_42187174247_item	2400712	et	3	main
koolitada	doc_42187174247_item	2400714	et	3	main
tõlke	doc_42187174247_item	2400715	et	4	main
aitaks	doc_42187174247_item	2400717	et	3	main
vaimulikke	doc_42187174247_item	2400718	et	3	main
1630	doc_42187174247_item	2400719	et	2	main
kes	doc_42187174247_item	2400716	et	4	main
gümnaasium	doc_42187174247_item	2400720	et	3	main
analoogne	doc_42187174247_item	2400724	et	3	main
ka	doc_42187174247_item	2400726	et	3	main
mida	doc_42187174247_item	2400728	et	4	main
peetakse	doc_42187174247_item	2400729	et	3	main
selleks	doc_42187174247_item	2400735	et	4	main
et	doc_42187174247_item	2400736	et	3	main
provintsides	doc_42187174247_item	2400753	et	3	main
ülikooli	doc_42187174247_item	2400760	et	4	main
1632	doc_42187174247_item	2400762	et	2	main
tartu	doc_42187174247_item	2400763	et	4	main
gümnaasium	doc_42187174247_item	2400764	et	3	main
muudeti	doc_42187174247_item	2400765	et	3	main
tartu	doc_42187174247_item	2400766	et	4	main
see	doc_418750402012_item	2400681	et	3	main
ees	doc_418750402012_item	2400683	et	4	main
tartus	doc_42187174247_item	2400721	et	3	main
gustav	doc_42187174247_item	2400731	et	4	main
pääseda	doc_42187174247_item	2400738	et	3	main
õppima	doc_42187174247_item	2400741	et	3	main
adolf	doc_42187174247_item	2400756	et	4	main
tartu	doc_42187174247_item	2400759	et	4	main
asutamisele	doc_42187174247_item	2400761	et	4	main
tartu	doc_42187174247_item	2400768	et	4	main
ajal	doc_42187174247_item	2400772	et	4	main
1	doc_42187174247_item	2400775	et	2	main
2	doc_42187174247_item	2400777	et	2	main
õigusteaduskond	doc_42187174247_item	2400778	et	3	main
3	doc_42187174247_item	2400779	et	2	main
arstiteaduskond	doc_42187174247_item	2400780	et	3	main
tuli	doc_42187174247_item	2400833	et	4	main
võisid	doc_42187174247_item	2400845	et	4	main
linnakodanikud	doc_42187174247_item	2400849	et	3	main
rohkem	doc_42187174247_item	2400851	et	4	main
ja	doc_42187174247_item	2400855	et	3	main
üliõpilased	doc_42187174247_item	2400876	et	3	main
17	doc_42187174247_item	2400881	et	2	main
oli	doc_42187174247_item	2400883	et	3	main
rebaseks	doc_42187174247_item	2400887	et	4	main
harinud	doc_42187174247_item	2400897	et	4	main
kutsuti	doc_42187174247_item	2400900	et	3	main
asutati	doc_42187174247_item	2400723	et	4	main
gümnaasium	doc_42187174247_item	2400725	et	3	main
adolfi	doc_42187174247_item	2400732	et	4	main
gümnaasiumi	doc_42187174247_item	2400733	et	4	main
eelkäiaks	doc_42187174247_item	2400734	et	3	main
pidi	doc_42187174247_item	2400739	et	4	main
triviaalkoolis	doc_42187174247_item	2400742	et	4	main
linnakoolis	doc_42187174247_item	2400745	et	4	main
ii	doc_42187174247_item	2400755	et	4	main
tol	doc_42187174247_item	2400771	et	3	main
teaduskonda	doc_42187174247_item	2400774	et	4	main
filosoofia	doc_42187174247_item	2400776	et	4	main
4	doc_42187174247_item	2400781	et	2	main
enamasti	doc_42187174247_item	2400785	et	4	main
vaesemate	doc_42187174247_item	2400786	et	4	main
aadlike	doc_42187174247_item	2400787	et	4	main
lapsed	doc_42187174247_item	2400788	et	3	main
tartu	doc_42187174247_item	2400789	et	4	main
ülikooli	doc_42187174247_item	2400790	et	4	main
rektoriks	doc_42187174247_item	2400791	et	3	main
tollel	doc_42187174247_item	2400792	et	4	main
ajal	doc_42187174247_item	2400793	et	4	main
oli	doc_42187174247_item	2400794	et	3	main
19	doc_42187174247_item	2400795	et	2	main
aastane	doc_42187174247_item	2400796	et	4	main
j	doc_42187174247_item	2400797	et	4	main
skytre	doc_42187174247_item	2400798	et	4	main
kuid	doc_42187174247_item	2400799	et	4	main
tegelikult	doc_42187174247_item	2400800	et	4	main
juhtis	doc_42187174247_item	2400801	et	3	main
ülikooli	doc_42187174247_item	2400802	et	4	main
professor	doc_42187174247_item	2400803	et	3	main
andreas	doc_42187174247_item	2400804	et	4	main
tartu	doc_42187174247_item	2400805	et	4	main
ülikooli	doc_42187174247_item	2400806	et	4	main
juurde	doc_42187174247_item	2400807	et	4	main
kuulusid	doc_42187174247_item	2400808	et	4	main
mõisad	doc_42187174247_item	2400809	et	3	main
talupoegade	doc_42187174247_item	2400810	et	3	main
saagist	doc_42187174247_item	2400811	et	4	main
saanud	doc_42187174247_item	2400812	et	4	main
tulu	doc_42187174247_item	2400813	et	4	main
läks	doc_42187174247_item	2400814	et	3	main
ülikooli	doc_42187174247_item	2400815	et	4	main
majandamiseks	doc_42187174247_item	2400816	et	4	main
tartu	doc_42187174247_item	2400817	et	4	main
ülikoolis	doc_42187174247_item	2400818	et	4	main
kinnitati	doc_42187174247_item	2400819	et	4	main
ülikoolis	doc_42187174247_item	2400769	et	4	main
4	doc_42187174247_item	2400773	et	2	main
tulid	doc_42187174247_item	2400784	et	4	main
professorit	doc_42187174247_item	2400821	et	3	main
loeng	doc_42187174247_item	2400823	et	3	main
üliõpilasel	doc_42187174247_item	2400835	et	3	main
eksam	doc_42187174247_item	2400836	et	3	main
ainetes	doc_42187174247_item	2400840	et	3	main
oli	doc_42187174247_item	2400842	et	3	main
ka	doc_42187174247_item	2400848	et	3	main
kõige	doc_42187174247_item	2400850	et	4	main
oli	doc_42187174247_item	2400852	et	3	main
soomest	doc_42187174247_item	2400856	et	3	main
lõpetamise	doc_42187174247_item	2400858	et	4	main
ei	doc_42187174247_item	2400860	et	4	main
ei	doc_42187174247_item	2400867	et	4	main
9	doc_42187174247_item	2400884	et	2	main
sai	doc_42187174247_item	2400894	et	4	main
ülikooli	doc_42187174247_item	2400895	et	4	main
hakatakse	doc_42187174247_item	2400922	et	3	main
euroopa	doc_42187174247_item	2400924	et	4	main
tema	doc_42187174247_item	2400933	et	4	main
liha	doc_42187174247_item	2400947	et	4	main
kingseppad	doc_42187174247_item	2400975	et	4	main
haridus-	doc_42187174248_item	2401013	et	3	main
kultuurielule	doc_42187174248_item	2401015	et	3	main
30	doc_42187174247_item	2400820	et	2	main
üks	doc_42187174247_item	2400822	et	3	main
tund	doc_42187174247_item	2400825	et	3	main
kuus	doc_42187174247_item	2400832	et	4	main
poolt	doc_42187174247_item	2400838	et	4	main
eksam	doc_42187174247_item	2400841	et	3	main
avalik	doc_42187174247_item	2400843	et	3	main
antud	doc_42187174247_item	2400861	et	4	main
nõutud	doc_42187174247_item	2400868	et	4	main
üliõpilasi	doc_42187174247_item	2400871	et	3	main
ühistoidul	doc_42187174247_item	2400873	et	3	main
said	doc_42187174247_item	2400877	et	4	main
stipendiume	doc_42187174247_item	2400878	et	3	main
noorim	doc_42187174247_item	2400879	et	3	main
üliõpilane	doc_42187174247_item	2400880	et	3	main
saj	doc_42187174247_item	2400882	et	4	main
depositsioon	doc_42187174247_item	2400886	et	4	main
löömine	doc_42187174247_item	2400888	et	4	main
üliõpilas	doc_42187174247_item	2400898	et	4	main
komisjoni	doc_42187174247_item	2400901	et	4	main
pidi	doc_42187174247_item	2400905	et	4	main
vastama	doc_42187174247_item	2400906	et	3	main
küsimustele	doc_42187174247_item	2400907	et	4	main
kultuur	doc_42187174247_item	2400908	et	3	main
kuni	doc_42187174247_item	2400909	et	3	main
18	doc_42187174247_item	2400910	et	2	main
saj	doc_42187174247_item	2400911	et	4	main
oli	doc_42187174247_item	2400912	et	3	main
valdavaks	doc_42187174247_item	2400913	et	4	main
kunstistiiliks	doc_42187174247_item	2400914	et	3	main
barokk	doc_42187174247_item	2400915	et	3	main
kadrioru	doc_42187174247_item	2400916	et	3	main
loss	doc_42187174247_item	2400917	et	3	main
tartu	doc_42187174247_item	2400918	et	4	main
kivisild	doc_42187174247_item	2400919	et	3	main
1700	doc_42187174247_item	2400920	et	2	main
ülistama	doc_42187174247_item	2400923	et	3	main
rahvaste	doc_42187174247_item	2400925	et	4	main
minevikku	doc_42187174247_item	2400926	et	4	main
1801	doc_42187174247_item	2400927	et	2	main
aleksander	doc_42187174247_item	2400931	et	4	main
valitsuse	doc_42187174247_item	2400934	et	4	main
seaduslikult	doc_42187174247_item	2400939	et	4	main
priiks	doc_42187174247_item	2400940	et	3	main
tõrva	doc_42187174247_item	2400949	et	4	main
meremeeste	doc_42187174247_item	2400954	et	4	main
kaotamist	doc_42187174247_item	2400967	et	4	main
hakkas	doc_42187174247_item	2400968	et	3	main
linnades	doc_42187174247_item	2400969	et	3	main
rahva	doc_42187174247_item	2400970	et	3	main
arv	doc_42187174247_item	2400971	et	3	main
kasvama	doc_42187174247_item	2400972	et	3	main
eestlased	doc_42187174247_item	2400973	et	3	main
olid	doc_42187174247_item	2400974	et	4	main
kontrolltöö	doc_42187174248_item	2401004	et	4	main
1	doc_42187174248_item	2401007	et	2	main
ülikooli	doc_42187174248_item	2401009	et	4	main
1583a	doc_42187174248_item	2401029	et	4	main
jesuiitide	doc_42187174248_item	2401032	et	3	main
õppida	doc_42187174248_item	2401050	et	3	main
a	doc_42187174248_item	2401054	et	4	main
anoloogne	doc_42187174248_item	2401057	et	4	main
gümnaasium	doc_42187174248_item	2401058	et	3	main
et	doc_42187174248_item	2401059	et	3	main
gümnaasiumi	doc_42187174248_item	2401061	et	4	main
tuli	doc_42187174248_item	2401062	et	4	main
õppida	doc_42187174248_item	2401063	et	3	main
õppisid	doc_42187174248_item	2401068	et	4	main
antud	doc_42187174248_item	2401075	et	4	main
tõuseb	doc_42187174247_item	2400928	et	3	main
i	doc_42187174247_item	2400932	et	4	main
ajal	doc_42187174247_item	2400935	et	4	main
laevanduse	doc_42187174247_item	2400942	et	3	main
arenguga	doc_42187174247_item	2400943	et	3	main
vajati	doc_42187174247_item	2400944	et	3	main
rohkem	doc_42187174247_item	2400950	et	4	main
vaimalik	doc_42187174247_item	2400958	et	4	main
seda	doc_42187174247_item	2400959	et	3	main
tooma	doc_42187174247_item	2400960	et	3	main
ja	doc_42187174247_item	2400961	et	3	main
ära	doc_42187174247_item	2400963	et	4	main
pärast	doc_42187174247_item	2400965	et	4	main
rätsepad	doc_42187174247_item	2400976	et	3	main
müürsepad	doc_42187174247_item	2400977	et	3	main
tekivad	doc_42187174247_item	2400978	et	3	main
vabrikud	doc_42187174247_item	2400979	et	3	main
kanga	doc_42187174247_item	2400980	et	3	main
värvimine	doc_42187174247_item	2400981	et	4	main
sits	doc_42187174247_item	2400982	et	3	main
tekstiil	doc_42187174247_item	2400983	et	3	main
tööstus	doc_42187174247_item	2400984	et	3	main
tinu	doc_42187174247_item	2400985	et	4	main
vabrik	doc_42187174247_item	2400986	et	3	main
paberivabrik	doc_42187174247_item	2400987	et	3	main
1816	doc_42187174247_item	2400988	et	2	main
uus	doc_42187174247_item	2400989	et	3	main
talurahva	doc_42187174247_item	2400990	et	3	main
seadus	doc_42187174247_item	2400991	et	4	main
eestis	doc_42187174247_item	2400992	et	3	main
1819	doc_42187174247_item	2400993	et	2	main
leedus	doc_42187174247_item	2400994	et	4	main
vabastati	doc_42187174247_item	2400995	et	3	main
pärisorjusest	doc_42187174247_item	2400996	et	4	main
neid	doc_42187174247_item	2400997	et	4	main
ei	doc_42187174247_item	2400998	et	4	main
saanud	doc_42187174247_item	2400999	et	4	main
enam	doc_42187174247_item	2401000	et	4	main
müüa	doc_42187174247_item	2401001	et	3	main
osta	doc_42187174247_item	2401002	et	4	main
kontrolltöö	doc_42187174248_item	2401003	et	4	main
kanepit	doc_42187174247_item	2400945	et	3	main
ja	doc_42187174247_item	2400946	et	3	main
samuti	doc_42187174247_item	2400948	et	3	main
kui	doc_42187174247_item	2400951	et	3	main
ka	doc_42187174247_item	2400953	et	3	main
mõisnikukule	doc_42187174247_item	2400962	et	4	main
müüa	doc_42187174247_item	2400964	et	3	main
pärisorjuse	doc_42187174247_item	2400966	et	3	main
kultuuriloost	doc_42187174248_item	2401006	et	4	main
taasavamise	doc_42187174248_item	2401010	et	4	main
tähtsus	doc_42187174248_item	2401011	et	4	main
ja	doc_42187174248_item	2401021	et	3	main
nende	doc_42187174248_item	2401024	et	4	main
tartusse	doc_42187174248_item	2401031	et	3	main
seminar	doc_42187174248_item	2401033	et	3	main
tõlgi	doc_42187174248_item	2401037	et	4	main
andreas	doc_42187174248_item	2401041	et	4	main
1630a	doc_42187174248_item	2401043	et	4	main
1631	doc_42187174248_item	2401053	et	2	main
asutati	doc_42187174248_item	2401055	et	4	main
tallinnasse	doc_42187174248_item	2401056	et	3	main
3-	doc_42187174248_item	2401064	et	4	main
poisid	doc_42187174248_item	2401069	et	4	main
a	doc_42187174248_item	2401071	et	4	main
tüdrukutele	doc_42187174248_item	2401072	et	4	main
1632a	doc_42187174248_item	2401076	et	4	main
muutub	doc_42187174248_item	2401079	et	3	main
11-12	doc_42187174248_item	2401112	et	2	main
pidi	doc_42187174248_item	2401133	et	4	main
oskama	doc_42187174248_item	2401134	et	3	main
kirjutama	doc_42187174248_item	2401135	et	3	main
lugema	doc_42187174248_item	2401136	et	4	main
ja	doc_42187174248_item	2401137	et	3	main
tü	doc_42187174248_item	2401142	et	4	main
kinnitati	doc_42187174248_item	2401155	et	4	main
korda	doc_42187174248_item	2401161	et	4	main
said	doc_42187174248_item	2401166	et	4	main
protessorid	doc_42187174248_item	2401168	et	4	main
aastas	doc_42187174248_item	2401173	et	3	main
rebaste	doc_42187174248_item	2401174	et	4	main
korteris	doc_42187174248_item	2401178	et	3	main
põhja-eestit	doc_42187174248_item	2401180	et	3	main
pärisorjusest	doc_42187174248_item	2401182	et	4	main
talupoegadel	doc_42187174248_item	2401187	et	3	main
oli	doc_42187174248_item	2401188	et	3	main
võimalus	doc_42187174248_item	2401189	et	3	main
omada	doc_42187174248_item	2401190	et	3	main
raha	doc_42187174248_item	2401223	et	4	main
kartulit	doc_42187174248_item	2401229	et	3	main
see	doc_42187174248_item	2401239	et	3	main
raha	doc_42187174248_item	2401244	et	4	main
nad	doc_42187174248_item	2401246	et	3	main
9	doc_42187174248_item	2401250	et	2	main
väljaostmine	doc_42187174248_item	2401267	et	3	main
linnaelanike	doc_42187174248_item	2401268	et	3	main
igas	doc_42187174248_item	2401272	et	3	main
hakatakse	doc_42187174248_item	2401281	et	3	main
tööpuudus	doc_42187174248_item	2401287	et	3	main
lastele	doc_42187174248_item	2401298	et	4	main
mingit	doc_42187174249_item	2401341	et	3	main
valitseja	doc_42187174249_item	2401347	et	4	main
mingis	doc_42187174249_item	2401363	et	4	main
ka	doc_42187174249_item	2401381	et	3	main
1850	doc_42187174249_item	2401383	et	2	main
rahvakoolide	doc_42187174249_item	2401387	et	3	main
seminari	doc_42187174249_item	2401397	et	4	main
on	doc_42187174249_item	2401409	et	4	main
tähtis	doc_42187174249_item	2401410	et	4	main
sellepärast	doc_42187174249_item	2401411	et	3	main
eesti	doc_42187174249_item	2401416	et	4	main
rahvus	doc_42187174249_item	2401417	et	3	main
pani	doc_42187174249_item	2401420	et	4	main
aluse	doc_42187174249_item	2401421	et	4	main
iseseisvumisele	doc_42187174249_item	2401423	et	3	main
igal	doc_42187174249_item	2401431	et	3	main
ajastul	doc_42187174249_item	2401432	et	3	main
perioodil	doc_42187174249_item	2401433	et	3	main
oma	doc_42187174249_item	2401435	et	4	main
vennad	doc_42187174249_item	2401449	et	3	main
petersonid	doc_42187174249_item	2401450	et	4	main
ta	doc_42187174249_item	2401473	et	4	main
ões	doc_42187174249_item	2401479	et	4	main
koostaja	doc_42187174249_item	2401483	et	4	main
samuti	doc_42187174249_item	2401484	et	3	main
eesti	doc_42187174248_item	2401005	et	4	main
eesti	doc_42187174248_item	2401012	et	4	main
ja	doc_42187174248_item	2401014	et	3	main
2	doc_42187174248_item	2401016	et	2	main
millal	doc_42187174248_item	2401017	et	3	main
eestlased	doc_42187174248_item	2401019	et	3	main
oli	doc_42187174248_item	2401035	et	3	main
klassilis	doc_42187174248_item	2401065	et	4	main
haridust	doc_42187174248_item	2401073	et	4	main
ei	doc_42187174248_item	2401074	et	4	main
a	doc_42187174248_item	2401113	et	4	main
käimine	doc_42187174248_item	2401115	et	4	main
kohustuslik	doc_42187174248_item	2401117	et	3	main
mida	doc_42187174248_item	2401022	et	4	main
asutati	doc_42187174248_item	2401030	et	4	main
eesmärk	doc_42187174248_item	2401034	et	3	main
tartu	doc_42187174248_item	2401038	et	4	main
ülikoolis	doc_42187174248_item	2401039	et	4	main
õppis	doc_42187174248_item	2401040	et	3	main
asutati	doc_42187174248_item	2401044	et	4	main
said	doc_42187174248_item	2401049	et	4	main
saada	doc_42187174248_item	2401060	et	4	main
linnakoolis	doc_42187174248_item	2401066	et	4	main
gümnaasium	doc_42187174248_item	2401078	et	3	main
tartu	doc_42187174248_item	2401080	et	4	main
ülikooliks	doc_42187174248_item	2401081	et	4	main
pidulikult	doc_42187174248_item	2401082	et	4	main
avati	doc_42187174248_item	2401083	et	3	main
tü	doc_42187174248_item	2401084	et	4	main
2510	doc_42187174248_item	2401085	et	2	main
1632a	doc_42187174248_item	2401086	et	4	main
seal	doc_42187174248_item	2401087	et	4	main
võis	doc_42187174248_item	2401088	et	4	main
õppida	doc_42187174248_item	2401089	et	3	main
õigusteaduskonnas	doc_42187174248_item	2401090	et	4	main
arstiteaduskonnas	doc_42187174248_item	2401091	et	4	main
usuteaduskonnas	doc_42187174248_item	2401092	et	4	main
ja	doc_42187174248_item	2401093	et	3	main
filosoofiat	doc_42187174248_item	2401094	et	3	main
1680a	doc_42187174248_item	2401095	et	4	main
anti	doc_42187174248_item	2401096	et	3	main
välja	doc_42187174248_item	2401097	et	4	main
trk	doc_42187174248_item	2401098	et	4	main
ajalooline	doc_42187174248_item	2401099	et	4	main
raamat	doc_42187174248_item	2401100	et	3	main
mitmes	doc_42187174248_item	2401101	et	4	main
osas	doc_42187174248_item	2401102	et	4	main
rektoriks	doc_42187174248_item	2401103	et	3	main
võis	doc_42187174248_item	2401104	et	4	main
saada	doc_42187174248_item	2401105	et	4	main
19a	doc_42187174248_item	2401106	et	4	main
noormees	doc_42187174248_item	2401107	et	4	main
ülikooli	doc_42187174248_item	2401108	et	4	main
võisid	doc_42187174248_item	2401109	et	4	main
astuda	doc_42187174248_item	2401110	et	3	main
poisid	doc_42187174248_item	2401111	et	4	main
tartu	doc_42187174248_item	2401077	et	4	main
loengul	doc_42187174248_item	2401114	et	3	main
eksamid	doc_42187174248_item	2401118	et	3	main
nad	doc_42187174248_item	2401128	et	3	main
keeles	doc_42187174248_item	2401141	et	4	main
palga	doc_42187174248_item	2401149	et	3	main
maksmisele	doc_42187174248_item	2401150	et	4	main
ja	doc_42187174248_item	2401151	et	3	main
õpilaste	doc_42187174248_item	2401152	et	4	main
said	doc_42187174248_item	2401159	et	4	main
ja	doc_42187174248_item	2401164	et	3	main
palka	doc_42187174248_item	2401170	et	4	main
hõbedat	doc_42187174248_item	2401172	et	3	main
ristimine	doc_42187174248_item	2401175	et	4	main
oli	doc_42187174248_item	2401176	et	3	main
2	doc_42187174248_item	2401179	et	2	main
vabastati	doc_42187174248_item	2401181	et	3	main
1816a	doc_42187174248_item	2401183	et	4	main
ja	doc_42187174248_item	2401184	et	3	main
neid	doc_42187174248_item	2401192	et	4	main
talupojad	doc_42187174248_item	2401221	et	4	main
lina	doc_42187174248_item	2401238	et	4	main
ja	doc_42187174248_item	2401245	et	3	main
inimestest	doc_42187174248_item	2401251	et	3	main
talupojad	doc_42187174248_item	2401258	et	4	main
1840a	doc_42187174248_item	2401259	et	4	main
hakkab	doc_42187174248_item	2401260	et	3	main
osa	doc_42187174248_item	2401261	et	4	main
usku	doc_42187174248_item	2401264	et	4	main
linnas	doc_42187174248_item	2401273	et	4	main
põllumaj	doc_42187174248_item	2401284	et	4	main
tekib	doc_42187174248_item	2401286	et	3	main
masinad	doc_42187174248_item	2401289	et	3	main
töö	doc_42187174248_item	2401292	et	4	main
ja	doc_42187174248_item	2401297	et	3	main
2	doc_42187174249_item	2401322	et	2	main
jaoks	doc_42187174249_item	2401333	et	4	main
väga	doc_42187174249_item	2401334	et	3	main
tähtis	doc_42187174249_item	2401335	et	4	main
toimunud	doc_42187174249_item	2401340	et	4	main
ei	doc_42187174249_item	2401348	et	4	main
vene	doc_42187174249_item	2401350	et	4	main
juba	doc_42187174249_item	2401353	et	3	main
ärkamisaega	doc_42187174249_item	2401365	et	4	main
ette	doc_42187174249_item	2401367	et	4	main
kaotamine	doc_42187174249_item	2401369	et	4	main
1816a	doc_42187174249_item	2401370	et	4	main
kasvas	doc_42187174249_item	2401385	et	3	main
kirikukoolid	doc_42187174249_item	2401389	et	3	main
ilmalikuteks	doc_42187174249_item	2401391	et	4	main
a	doc_42187174249_item	2401393	et	4	main
oma	doc_42187174249_item	2401396	et	4	main
seminaris	doc_42187174249_item	2401400	et	3	main
valmistati	doc_42187174249_item	2401401	et	4	main
häid	doc_42187174249_item	2401402	et	3	main
õpetajaid	doc_42187174249_item	2401403	et	4	main
et	doc_42187174249_item	2401412	et	3	main
sel	doc_42187174249_item	2401413	et	3	main
perioodil	doc_42187174249_item	2401414	et	3	main
tekkis	doc_42187174249_item	2401415	et	3	main
ajal	doc_42187174249_item	2401426	et	4	main
on	doc_42187174249_item	2401427	et	4	main
iseseisvumise	doc_42187174249_item	2401428	et	3	main
juured	doc_42187174249_item	2401429	et	3	main
nagu	doc_42187174249_item	2401430	et	3	main
ärkamisaja	doc_42187174249_item	2401438	et	3	main
on	doc_42187174249_item	2401451	et	4	main
oli	doc_42187174249_item	2401474	et	3	main
juht	doc_42187174249_item	2401480	et	3	main
kalevipoeg	doc_42187174249_item	2401488	et	3	main
eesti	doc_42187174249_item	2401492	et	4	main
arenemisele	doc_42187174249_item	2401503	et	4	main
ja	doc_42187174249_item	2401504	et	3	main
õnnele	doc_42187174249_item	2401505	et	4	main
samuti	doc_42187174249_item	2401506	et	3	main
teda	doc_42187174249_item	2401514	et	4	main
ka	doc_42187174249_item	2401516	et	3	main
ta	doc_42187174249_item	2401518	et	4	main
oli	doc_42187174248_item	2401116	et	3	main
iga	doc_42187174248_item	2401120	et	4	main
saama	doc_42187174248_item	2401138	et	4	main
aru	doc_42187174248_item	2401139	et	4	main
toetusele	doc_42187174248_item	2401153	et	4	main
30	doc_42187174248_item	2401156	et	2	main
üliõpilased	doc_42187174248_item	2401158	et	3	main
olid	doc_42187174248_item	2401119	et	4	main
kuu	doc_42187174248_item	2401121	et	4	main
algasid	doc_42187174248_item	2401123	et	4	main
kell	doc_42187174248_item	2401124	et	3	main
hommikul	doc_42187174248_item	2401126	et	3	main
olid	doc_42187174248_item	2401129	et	4	main
ladina	doc_42187174248_item	2401130	et	4	main
keeles	doc_42187174248_item	2401131	et	4	main
õpilane	doc_42187174248_item	2401132	et	3	main
selles	doc_42187174248_item	2401140	et	4	main
mõisad	doc_42187174248_item	2401145	et	3	main
talupoegade	doc_42187174248_item	2401146	et	3	main
tulu	doc_42187174248_item	2401147	et	4	main
läks	doc_42187174248_item	2401148	et	3	main
mittu	doc_42187174248_item	2401160	et	4	main
süüa	doc_42187174248_item	2401163	et	3	main
stependiumi	doc_42187174248_item	2401167	et	4	main
said	doc_42187174248_item	2401169	et	4	main
400	doc_42187174248_item	2401171	et	2	main
kinnisvara	doc_42187174248_item	2401191	et	4	main
kõrvale	doc_42187174248_item	2401224	et	4	main
kasvatama	doc_42187174248_item	2401228	et	4	main
head	doc_42187174248_item	2401234	et	4	main
tulu	doc_42187174248_item	2401235	et	4	main
lõuna-eestis	doc_42187174248_item	2401236	et	3	main
kasvatatakse	doc_42187174248_item	2401237	et	3	main
koguvada	doc_42187174248_item	2401243	et	4	main
saavad	doc_42187174248_item	2401247	et	4	main
ülejäänud	doc_42187174248_item	2401254	et	4	main
maal	doc_42187174248_item	2401255	et	4	main
talude	doc_42187174248_item	2401266	et	3	main
tooma	doc_42187174248_item	2401282	et	3	main
kogu	doc_42187174248_item	2401291	et	4	main
inimese	doc_42187174248_item	2401293	et	4	main
eest	doc_42187174248_item	2401294	et	4	main
miks	doc_42187174249_item	2401321	et	4	main
liikumise	doc_42187174249_item	2401324	et	4	main
panus	doc_42187174249_item	2401325	et	4	main
perioodil	doc_42187174249_item	2401338	et	3	main
eesti	doc_42187174249_item	2401343	et	4	main
ärkamisaega	doc_42187174249_item	2401358	et	4	main
võib	doc_42187174249_item	2401359	et	3	main
nimetada	doc_42187174249_item	2401360	et	3	main
valmistas	doc_42187174249_item	2401366	et	3	main
pärisorjuse	doc_42187174249_item	2401368	et	3	main
ja	doc_42187174249_item	2401376	et	3	main
teised	doc_42187174249_item	2401377	et	4	main
talurahvaseadused	doc_42187174249_item	2401378	et	3	main
aastaks	doc_42187174249_item	2401384	et	4	main
1849	doc_42187174249_item	2401392	et	2	main
tõi	doc_42187174249_item	2401395	et	3	main
ja	doc_42187174249_item	2401418	et	3	main
loengud	doc_42187174248_item	2401122	et	3	main
7	doc_42187174248_item	2401125	et	2	main
ja	doc_42187174248_item	2401127	et	3	main
juurde	doc_42187174248_item	2401143	et	4	main
kuulusid	doc_42187174248_item	2401144	et	4	main
tü	doc_42187174248_item	2401154	et	4	main
professorit	doc_42187174248_item	2401157	et	3	main
päevas	doc_42187174248_item	2401162	et	3	main
mõned	doc_42187174248_item	2401165	et	3	main
rektori	doc_42187174248_item	2401177	et	3	main
lõuna-eestit	doc_42187174248_item	2401185	et	3	main
1819a	doc_42187174248_item	2401186	et	4	main
ei	doc_42187174248_item	2401193	et	4	main
saa	doc_42187174248_item	2401194	et	4	main
osta	doc_42187174248_item	2401195	et	4	main
ja	doc_42187174248_item	2401196	et	3	main
hakkati	doc_42187174248_item	2401198	et	3	main
müüa	doc_42187174248_item	2401197	et	3	main
pandma	doc_42187174248_item	2401199	et	4	main
perekonnanimesi	doc_42187174248_item	2401200	et	4	main
nt	doc_42187174248_item	2401201	et	4	main
pukk	doc_42187174248_item	2401202	et	3	main
rebane	doc_42187174248_item	2401203	et	4	main
maad	doc_42187174248_item	2401204	et	4	main
aga	doc_42187174248_item	2401205	et	3	main
kuulusid	doc_42187174248_item	2401206	et	4	main
mõisnukule	doc_42187174248_item	2401207	et	4	main
nad	doc_42187174248_item	2401208	et	3	main
pidid	doc_42187174248_item	2401209	et	4	main
maad	doc_42187174248_item	2401210	et	4	main
rentima	doc_42187174248_item	2401211	et	3	main
1832a	doc_42187174248_item	2401212	et	4	main
said	doc_42187174248_item	2401213	et	4	main
talupojad	doc_42187174248_item	2401214	et	4	main
minna	doc_42187174248_item	2401215	et	3	main
linna	doc_42187174248_item	2401216	et	4	main
või	doc_42187174248_item	2401217	et	4	main
välismaale	doc_42187174248_item	2401218	et	4	main
elama	doc_42187174248_item	2401219	et	3	main
nutikamad	doc_42187174248_item	2401220	et	4	main
panna	doc_42187174248_item	2401225	et	4	main
hakkatakse	doc_42187174248_item	2401227	et	4	main
saab	doc_42187174248_item	2401231	et	3	main
kartulist	doc_42187174248_item	2401232	et	4	main
on	doc_42187174248_item	2401240	et	4	main
rahateenimisvõimalus	doc_42187174248_item	2401241	et	3	main
osta	doc_42187174248_item	2401249	et	4	main
linnas	doc_42187174248_item	2401253	et	4	main
muutma	doc_42187174248_item	2401263	et	3	main
1860a-	doc_42187174248_item	2401265	et	4	main
hakkab	doc_42187174248_item	2401270	et	3	main
hakkavad	doc_42187174248_item	2401275	et	4	main
tööle	doc_42187174248_item	2401276	et	3	main
teevad	doc_42187174248_item	2401290	et	3	main
naistele	doc_42187174248_item	2401296	et	3	main
eestlaste	doc_42187174249_item	2401326	et	4	main
hariduselu	doc_42187174249_item	2401327	et	4	main
oskasid	doc_42187174248_item	2401222	et	4	main
19saj	doc_42187174248_item	2401226	et	4	main
põhja-eesti	doc_42187174248_item	2401230	et	4	main
väga	doc_42187174248_item	2401233	et	3	main
talupojad	doc_42187174248_item	2401242	et	4	main
maad	doc_42187174248_item	2401248	et	4	main
elab	doc_42187174248_item	2401252	et	3	main
tekkivad	doc_42187174248_item	2401256	et	4	main
jõukad	doc_42187174248_item	2401257	et	3	main
talurahvast	doc_42187174248_item	2401262	et	4	main
arv	doc_42187174248_item	2401269	et	3	main
kasvama	doc_42187174248_item	2401271	et	3	main
elanikud	doc_42187174248_item	2401274	et	3	main
rätsepaks	doc_42187174248_item	2401277	et	3	main
postsepaks	doc_42187174248_item	2401278	et	3	main
jne	doc_42187174248_item	2401279	et	4	main
tallinas	doc_42187174248_item	2401280	et	4	main
tikke	doc_42187174248_item	2401283	et	4	main
riiste	doc_42187174248_item	2401285	et	3	main
kuna	doc_42187174248_item	2401288	et	3	main
ära	doc_42187174248_item	2401295	et	4	main
makstakse	doc_42187174248_item	2401299	et	3	main
vähem	doc_42187174248_item	2401300	et	4	main
tekivad	doc_42187174248_item	2401301	et	3	main
väiksed	doc_42187174248_item	2401302	et	4	main
poodnikud	doc_42187174248_item	2401303	et	3	main
poed	doc_42187174248_item	2401304	et	4	main
postkontorid	doc_42187174248_item	2401305	et	3	main
postijaamad	doc_42187174248_item	2401306	et	3	main
kontrolltöö	doc_42187174249_item	2401307	et	4	main
kontrolltöö	doc_42187174249_item	2401308	et	4	main
eesti	doc_42187174249_item	2401309	et	4	main
kultuuriloost	doc_42187174249_item	2401310	et	4	main
1	doc_42187174249_item	2401311	et	2	main
kes	doc_42187174249_item	2401312	et	4	main
olid	doc_42187174249_item	2401313	et	4	main
tähtsamad	doc_42187174249_item	2401314	et	4	main
esimese	doc_42187174249_item	2401315	et	3	main
rahvusliku	doc_42187174249_item	2401316	et	3	main
ärkamisaja	doc_42187174249_item	2401317	et	3	main
tegelased	doc_42187174249_item	2401318	et	3	main
sinu	doc_42187174249_item	2401319	et	3	main
meelest	doc_42187174249_item	2401320	et	4	main
vennastekoguduse	doc_42187174249_item	2401323	et	3	main
1	doc_42187174249_item	2401329	et	2	main
ärkamisaeg	doc_42187174249_item	2401330	et	3	main
edendamisse	doc_42187174249_item	2401328	et	4	main
aeg	doc_42187174249_item	2401336	et	3	main
sel	doc_42187174249_item	2401337	et	3	main
seega	doc_42187174249_item	2401346	et	4	main
vahetanud	doc_42187174249_item	2401349	et	4	main
oli	doc_42187174249_item	2401352	et	3	main
rahu	doc_42187174249_item	2401361	et	4	main
eestimaal	doc_42187174249_item	2401371	et	4	main
ja	doc_42187174249_item	2401372	et	3	main
1819	doc_42187174249_item	2401373	et	2	main
a	doc_42187174249_item	2401374	et	4	main
muutusid	doc_42187174249_item	2401379	et	4	main
arenes	doc_42187174249_item	2401404	et	3	main
eestikeelsete	doc_42187174249_item	2401405	et	4	main
raamatute	doc_42187174249_item	2401406	et	3	main
eesti	doc_42187174249_item	2401422	et	4	main
vähemalt	doc_42187174249_item	2401424	et	4	main
sellel	doc_42187174249_item	2401425	et	4	main
silmapaistvad	doc_42187174249_item	2401436	et	3	main
kujud	doc_42187174249_item	2401437	et	3	main
silmatorkavamad	doc_42187174249_item	2401440	et	4	main
faehlmann	doc_42187174249_item	2401442	et	4	main
kreutzwald	doc_42187174249_item	2401443	et	4	main
vaja	doc_42187174249_item	2401452	et	4	main
esitas	doc_42187174249_item	2401470	et	3	main
ja	doc_42187174249_item	2401478	et	3	main
ja	doc_42187174249_item	2401491	et	3	main
ühislooming	doc_42187174249_item	2401494	et	3	main
annab	doc_42187174249_item	2401496	et	3	main
usku	doc_42187174249_item	2401499	et	4	main
kalevi	doc_42187174249_item	2401500	et	3	main
rahva	doc_42187174249_item	2401501	et	3	main
ellujäämisele	doc_42187174249_item	2401502	et	4	main
te	doc_42187174249_item	2401507	et	4	main
nimetatakse	doc_42187174249_item	2401515	et	3	main
oli	doc_42187174249_item	2401519	et	3	main
i	doc_42187174249_item	2401523	et	4	main
eestikeelse	doc_42187174249_item	2401527	et	3	main
vanemuise	doc_42187174249_item	2401534	et	4	main
tähtsamate	doc_42187174249_item	2401536	et	4	main
tütar	doc_42187174249_item	2401543	et	3	main
vanemuise	doc_42187174249_item	2401545	et	4	main
säärane	doc_42187174249_item	2401548	et	3	main
üks	doc_42187174249_item	2401550	et	3	main
poeetidest	doc_42187174249_item	2401552	et	3	main
loomingus	doc_42187174249_item	2401554	et	3	main
romantismi	doc_42187174249_item	2401556	et	4	main
mõju	doc_42187174249_item	2401557	et	4	main
ja	doc_42187174249_item	2401558	et	3	main
on	doc_42187174249_item	2401559	et	4	main
vastu	doc_42187174249_item	2401564	et	3	main
1878a	doc_42187174249_item	2401568	et	4	main
oli	doc_42187174249_item	2401570	et	3	main
radikaalseim	doc_42187174249_item	2401571	et	4	main
arengut	doc_42187174249_item	2401577	et	3	main
ja	doc_42187174249_item	2401581	et	3	main
baltisaksa	doc_42187174249_item	2401590	et	4	main
vahel	doc_42187174249_item	2401594	et	4	main
pärimuste	doc_42187174249_item	2401607	et	4	main
on	doc_42187174249_item	2401612	et	4	main
tähtsad	doc_42187174249_item	2401623	et	3	main
tütarlaps	doc_42187174249_item	2401630	et	4	main
allikal	doc_42187174249_item	2401631	et	3	main
kunileid	doc_42187174249_item	2401632	et	4	main
oli	doc_42187174249_item	2401633	et	3	main
üldlaulupeo	doc_42187174249_item	2401639	et	4	main
luuletuste	doc_42187174249_item	2401646	et	4	main
vennastekoguduste	doc_42187174249_item	2401663	et	4	main
liikumine	doc_42187174249_item	2401664	et	4	main
on	doc_42187174249_item	2401665	et	4	main
18	doc_42187174249_item	2401667	et	2	main
olid	doc_42187174249_item	2401678	et	4	main
kajastatud	doc_42187174249_item	2401679	et	4	main
ratsionalismi	doc_42187174249_item	2401680	et	4	main
euroopa	doc_42187174249_item	2401705	et	4	main
tartu	doc_42187174249_item	2401714	et	4	main
eestlaste	doc_42187174249_item	2401718	et	4	main
lugeda	doc_42187174249_item	2401726	et	3	main
eestlaste	doc_429435411727_item	2401742	et	4	main
ja	doc_429435411727_item	2401755	et	3	main
ettekujutus	doc_429435411727_item	2401772	et	4	main
funktsioonis	doc_429435411727_item	2401793	et	3	main
oli	doc_429435411727_item	2401796	et	3	main
päikese	doc_429435411727_item	2401799	et	4	main
on	doc_42187174249_item	2401331	et	4	main
eestlaste	doc_42187174249_item	2401332	et	4	main
ei	doc_42187174249_item	2401339	et	4	main
sõda	doc_42187174249_item	2401342	et	4	main
alade	doc_42187174249_item	2401344	et	3	main
pärast	doc_42187174249_item	2401345	et	4	main
võim	doc_42187174249_item	2401351	et	3	main
umbes	doc_42187174249_item	2401354	et	4	main
sada	doc_42187174249_item	2401355	et	4	main
aastat	doc_42187174249_item	2401356	et	3	main
ja	doc_42187174249_item	2401357	et	3	main
perioodiks	doc_42187174249_item	2401362	et	3	main
mõttes	doc_42187174249_item	2401364	et	3	main
liivimaal	doc_42187174249_item	2401375	et	4	main
kiiresti	doc_42187174249_item	2401380	et	3	main
haridusolud	doc_42187174249_item	2401382	et	3	main
kiiresti	doc_42187174249_item	2401386	et	3	main
arv	doc_42187174249_item	2401388	et	3	main
muudeti	doc_42187174249_item	2401390	et	3	main
cimze	doc_42187174249_item	2401394	et	4	main
valka	doc_42187174249_item	2401398	et	4	main
selles	doc_42187174249_item	2401399	et	4	main
kirjastamine	doc_42187174249_item	2401407	et	4	main
ärkamisaeg	doc_42187174249_item	2401408	et	3	main
ärkamisaeg	doc_42187174249_item	2401419	et	3	main
on	doc_42187174249_item	2401434	et	4	main
jannsen	doc_42187174249_item	2401444	et	4	main
koidula	doc_42187174249_item	2401445	et	4	main
jakobson	doc_42187174249_item	2401446	et	4	main
hurt	doc_42187174249_item	2401447	et	3	main
köler	doc_42187174249_item	2401448	et	4	main
kalevipoja	doc_42187174249_item	2401471	et	4	main
visandid	doc_42187174249_item	2401472	et	3	main
ülikooli	doc_42187174249_item	2401476	et	4	main
lektor	doc_42187174249_item	2401477	et	3	main
kreutzwald	doc_42187174249_item	2401481	et	4	main
kalevipoja	doc_42187174249_item	2401482	et	4	main
koidula	doc_42187174249_item	2401509	et	4	main
ja	doc_42187174249_item	2401511	et	3	main
õpetaja	doc_42187174249_item	2401512	et	4	main
papaks	doc_42187174249_item	2401517	et	3	main
rahva	doc_42187174249_item	2401520	et	3	main
lõpliku	doc_42187174249_item	2401521	et	3	main
ja	doc_42187174249_item	2401533	et	3	main
ürituste	doc_42187174249_item	2401538	et	4	main
autor	doc_42187174249_item	2401547	et	3	main
mulk	doc_42187174249_item	2401549	et	3	main
kelle	doc_42187174249_item	2401553	et	4	main
armastus	doc_42187174249_item	2401562	et	4	main
rajaja	doc_42187174249_item	2401567	et	4	main
reformidega	doc_42187174249_item	2401580	et	3	main
hurt	doc_42187174249_item	2401583	et	3	main
seostas	doc_42187174249_item	2401585	et	3	main
a	doc_42187174249_item	2401598	et	4	main
eks	doc_42187174249_item	2401601	et	3	main
köler	doc_42187174249_item	2401609	et	4	main
kunstnik	doc_42187174249_item	2401610	et	3	main
kõige	doc_42187174249_item	2401439	et	4	main
on	doc_42187174249_item	2401441	et	4	main
mainida	doc_42187174249_item	2401453	et	3	main
ahrensit	doc_42187174249_item	2401454	et	4	main
veskit	doc_42187174249_item	2401455	et	3	main
wiedemanni	doc_42187174249_item	2401456	et	4	main
kunileud	doc_42187174249_item	2401457	et	4	main
türnpuu	doc_42187174249_item	2401458	et	4	main
härmat	doc_42187174249_item	2401459	et	4	main
faehlmann	doc_42187174249_item	2401460	et	4	main
1838	doc_42187174249_item	2401461	et	2	main
a	doc_42187174249_item	2401462	et	4	main
ões	doc_42187174249_item	2401464	et	4	main
ja	doc_42187174249_item	2401465	et	3	main
1839	doc_42187174249_item	2401466	et	2	main
rajas	doc_42187174249_item	2401463	et	4	main
a	doc_42187174249_item	2401467	et	4	main
seltsi	doc_42187174249_item	2401468	et	4	main
koosolekul	doc_42187174249_item	2401469	et	3	main
tartu	doc_42187174249_item	2401475	et	4	main
kirjanduse	doc_42187174249_item	2401486	et	3	main
autor	doc_42187174249_item	2401487	et	3	main
on	doc_42187174249_item	2401489	et	4	main
mis	doc_42187174249_item	2401495	et	4	main
lootust	doc_42187174249_item	2401497	et	4	main
on	doc_42187174249_item	2401508	et	4	main
ajalehe	doc_42187174249_item	2401528	et	3	main
perno	doc_42187174249_item	2401530	et	4	main
ärkamisaja	doc_42187174249_item	2401537	et	3	main
isamaa	doc_42187174249_item	2401563	et	4	main
seostas	doc_42187174249_item	2401575	et	3	main
eesti	doc_42187174249_item	2401576	et	4	main
venemaaga	doc_42187174249_item	2401582	et	3	main
kirikuisa	doc_42187174249_item	2401584	et	4	main
eesti	doc_42187174249_item	2401586	et	4	main
arengut	doc_42187174249_item	2401587	et	3	main
võrreldes	doc_42187174249_item	2401588	et	3	main
jakobsoniga	doc_42187174249_item	2401589	et	4	main
tekkiski	doc_42187174249_item	2401595	et	3	main
1878	doc_42187174249_item	2401597	et	2	main
samuti	doc_42187174249_item	2401599	et	3	main
esimees	doc_42187174249_item	2401602	et	4	main
ja	doc_42187174249_item	2401603	et	3	main
ta	doc_42187174249_item	2401604	et	4	main
asutas	doc_42187174249_item	2401605	et	3	main
kellel	doc_42187174249_item	2401611	et	4	main
on	doc_42187174249_item	2401622	et	4	main
helilooja	doc_42187174249_item	2401634	et	4	main
ajal	doc_42187174249_item	2401640	et	4	main
sõnad	doc_42187174249_item	2401647	et	4	main
keelemehed	doc_42187174249_item	2401661	et	3	main
propageeris	doc_42187174249_item	2401670	et	3	main
kõlblust	doc_42187174249_item	2401672	et	4	main
sotsiaalset	doc_42187174249_item	2401673	et	3	main
võrdlust	doc_42187174249_item	2401674	et	4	main
ja	doc_42187174249_item	2401675	et	3	main
vendlust	doc_42187174249_item	2401676	et	3	main
saamine	doc_42187174249_item	2401683	et	4	main
sest	doc_42187174249_item	2401702	et	4	main
soovis	doc_42187174249_item	2401708	et	4	main
olla	doc_42187174249_item	2401709	et	3	main
18	doc_42187174249_item	2401712	et	2	main
saj	doc_42187174249_item	2401713	et	4	main
hulgas	doc_42187174249_item	2401719	et	4	main
suur	doc_42187174249_item	2401721	et	3	main
inimesi	doc_42187174249_item	2401723	et	4	main
eestlaste	doc_429435411727_item	2401734	et	4	main
üldiseloomustus	doc_429435411727_item	2401736	et	4	main
2	doc_429435411727_item	2401737	et	2	main
1	doc_429435411727_item	2401741	et	2	main
muinasusundi	doc_429435411727_item	2401743	et	3	main
ja	doc_429435411727_item	2401758	et	3	main
protsess	doc_429435411727_item	2401760	et	3	main
võib	doc_429435411727_item	2401762	et	3	main
öelda	doc_429435411727_item	2401764	et	4	main
keeruline	doc_429435411727_item	2401768	et	4	main
uskumuste	doc_429435411727_item	2401769	et	4	main
süsteem	doc_429435411727_item	2401770	et	3	main
ja	doc_429435411727_item	2401771	et	3	main
hingest	doc_429435411727_item	2401776	et	4	main
territooriumile	doc_429435411727_item	2401780	et	3	main
vahel	doc_429435411727_item	2401781	et	4	main
isegi	doc_429435411727_item	2401782	et	4	main
püstkoja	doc_429435411727_item	2401783	et	3	main
põranda	doc_429435411727_item	2401784	et	3	main
alla	doc_429435411727_item	2401785	et	3	main
kaasa	doc_429435411727_item	2401786	et	4	main
merevaik	doc_429435411727_item	2401794	et	3	main
mis	doc_429435411727_item	2401795	et	4	main
asukate	doc_429435411727_item	2401797	et	4	main
jaoks	doc_429435411727_item	2401798	et	4	main
väljaspool	doc_429435411727_item	2401808	et	3	main
selili	doc_429435411727_item	2401815	et	3	main
õpetliku	doc_42187174249_item	2401485	et	3	main
kreutzwaldi	doc_42187174249_item	2401490	et	4	main
rahva	doc_42187174249_item	2401493	et	3	main
ja	doc_42187174249_item	2401498	et	3	main
inspireerija	doc_42187174249_item	2401510	et	4	main
jannsen	doc_42187174249_item	2401513	et	4	main
üldlaulupeo	doc_42187174249_item	2401524	et	4	main
esimese	doc_42187174249_item	2401526	et	3	main
autor	doc_42187174249_item	2401529	et	3	main
postimees	doc_42187174249_item	2401531	et	4	main
1857	doc_42187174249_item	2401532	et	2	main
tähtis	doc_42187174249_item	2401539	et	4	main
koidula	doc_42187174249_item	2401541	et	4	main
ärkamisaja	doc_42187174249_item	2401551	et	3	main
näidatud	doc_42187174249_item	2401560	et	4	main
sakala	doc_42187174249_item	2401566	et	4	main
ta	doc_42187174249_item	2401574	et	4	main
aleksandri	doc_42187174249_item	2401578	et	4	main
ii	doc_42187174249_item	2401579	et	4	main
suunaga	doc_42187174249_item	2401591	et	4	main
sellepärast	doc_42187174249_item	2401592	et	3	main
nende	doc_42187174249_item	2401593	et	4	main
eesti	doc_42187174249_item	2401606	et	4	main
loomingus	doc_42187174249_item	2401621	et	3	main
eesti	doc_42187174249_item	2401625	et	4	main
mütoloogia	doc_42187174249_item	2401626	et	4	main
ja	doc_42187174249_item	2401627	et	3	main
loodus	doc_42187174249_item	2401628	et	4	main
n	doc_42187174249_item	2401629	et	4	main
muusika	doc_42187174249_item	2401636	et	4	main
mängis	doc_42187174249_item	2401637	et	3	main
pandud	doc_42187174249_item	2401644	et	4	main
sajandile	doc_42187174249_item	2401668	et	3	main
hariduse	doc_42187174249_item	2401682	et	3	main
18	doc_42187174249_item	2401687	et	2	main
hariduselu	doc_42187174249_item	2401700	et	4	main
poole	doc_42187174249_item	2401706	et	4	main
suletud	doc_42187174249_item	2401717	et	4	main
protsent	doc_42187174249_item	2401722	et	3	main
kontrolltöö	doc_429435411727_item	2401732	et	4	main
on	doc_429435411727_item	2401739	et	4	main
oli	doc_429435411727_item	2401767	et	3	main
ja	doc_429435411727_item	2401775	et	3	main
maeti	doc_429435411727_item	2401778	et	3	main
ehte	doc_429435411727_item	2401792	et	3	main
kivi	doc_429435411727_item	2401800	et	4	main
nöörkeraamika	doc_429435411727_item	2401801	et	4	main
hõimudeni	doc_429435411727_item	2401802	et	3	main
asula	doc_429435411727_item	2401809	et	4	main
vaid	doc_429435411727_item	2401816	et	3	main
mugavas	doc_429435411727_item	2401817	et	3	main
olid	doc_429435411727_item	2401821	et	4	main
tööriistad	doc_429435411727_item	2401823	et	3	main
ja	doc_429435411727_item	2401825	et	3	main
ilmusid	doc_429435411727_item	2401832	et	4	main
aeg	doc_429435411727_item	2401852	et	3	main
hakkati	doc_429435411727_item	2401855	et	3	main
kaasa	doc_429435411727_item	2401857	et	4	main
panema	doc_429435411727_item	2401858	et	3	main
ka	doc_429435411727_item	2401859	et	3	main
relvi	doc_429435411727_item	2401860	et	4	main
vere	doc_429435411727_item	2401868	et	3	main
sõltuvad	doc_429435411727_item	2401879	et	4	main
surnute	doc_429435411727_item	2401880	et	4	main
austamisest	doc_429435411727_item	2401881	et	4	main
ohverdati	doc_429435411727_item	2401882	et	3	main
tööriistu	doc_429435411727_item	2401883	et	3	main
ja	doc_429435411727_item	2401884	et	3	main
tarbeesemeid	doc_429435411727_item	2401885	et	3	main
hiljemalt	doc_429435411727_item	2401886	et	3	main
mida	doc_429435411727_item	2401893	et	4	main
jõkke	doc_429435411727_item	2401895	et	3	main
peamiseks	doc_429435411727_item	2401898	et	3	main
toimingud	doc_429435411727_item	2401907	et	3	main
on	doc_429435411727_item	2401910	et	4	main
baltimaa	doc_429435411727_item	2401921	et	4	main
tänase	doc_429435411727_item	2401926	et	3	main
jäänud	doc_429435411727_item	2401929	et	4	main
komme	doc_429435411727_item	2401931	et	4	main
väge	doc_429435411727_item	2401945	et	3	main
alepõllundus	doc_429435411727_item	2401947	et	3	main
raiuti	doc_429435411727_item	2401951	et	3	main
ühendaja	doc_42187174249_item	2401522	et	4	main
peategelane	doc_42187174249_item	2401525	et	3	main
rajaja	doc_42187174249_item	2401535	et	4	main
kuju	doc_42187174249_item	2401540	et	4	main
jannseni	doc_42187174249_item	2401542	et	4	main
esimese	doc_42187174249_item	2401544	et	3	main
näidendi	doc_42187174249_item	2401546	et	3	main
kajastub	doc_42187174249_item	2401555	et	3	main
tema	doc_42187174249_item	2401561	et	4	main
jakobson	doc_42187174249_item	2401565	et	4	main
mis	doc_42187174249_item	2401569	et	4	main
eesti	doc_42187174249_item	2401572	et	4	main
ajaleht	doc_42187174249_item	2401573	et	3	main
lõhe	doc_42187174249_item	2401596	et	4	main
hurt	doc_42187174249_item	2401600	et	3	main
kogumise	doc_42187174249_item	2401608	et	4	main
suur	doc_42187174249_item	2401613	et	3	main
tähtsus	doc_42187174249_item	2401614	et	4	main
palvekirjade	doc_42187174249_item	2401615	et	3	main
vennad	doc_42187174249_item	2401616	et	3	main
petersonid	doc_42187174249_item	2401617	et	4	main
edasiandmisel	doc_42187174249_item	2401618	et	3	main
tsaarile	doc_42187174249_item	2401619	et	3	main
tema	doc_42187174249_item	2401620	et	4	main
kelle	doc_42187174249_item	2401635	et	4	main
ja	doc_42187174249_item	2401641	et	3	main
millele	doc_42187174249_item	2401642	et	3	main
olid	doc_42187174249_item	2401643	et	4	main
ahrens	doc_42187174249_item	2401648	et	4	main
olid	doc_42187174249_item	2401660	et	4	main
2	doc_42187174249_item	2401662	et	2	main
alandlikkust	doc_42187174249_item	2401671	et	4	main
siin	doc_42187174249_item	2401677	et	4	main
ja	doc_42187174249_item	2401684	et	3	main
rahva	doc_42187174249_item	2401685	et	3	main
saj	doc_42187174249_item	2401688	et	4	main
ilmus	doc_42187174249_item	2401689	et	4	main
piibli	doc_42187174249_item	2401690	et	3	main
eestikeelne	doc_42187174249_item	2401691	et	3	main
täielik	doc_42187174249_item	2401692	et	3	main
tõlge	doc_42187174249_item	2401693	et	3	main
eestlaste	doc_42187174249_item	2401699	et	4	main
ja	doc_42187174249_item	2401707	et	3	main
haritud	doc_42187174249_item	2401710	et	4	main
kuigi	doc_42187174249_item	2401711	et	3	main
oli	doc_42187174249_item	2401716	et	3	main
teemad	doc_42187174249_item	2401624	et	3	main
i	doc_42187174249_item	2401638	et	4	main
koidula	doc_42187174249_item	2401645	et	4	main
on	doc_42187174249_item	2401649	et	4	main
loodud	doc_42187174249_item	2401650	et	4	main
eesti	doc_42187174249_item	2401651	et	4	main
keele	doc_42187174249_item	2401652	et	4	main
grammatika	doc_42187174249_item	2401653	et	4	main
soome	doc_42187174249_item	2401654	et	3	main
keele	doc_42187174249_item	2401655	et	4	main
alusel	doc_42187174249_item	2401656	et	4	main
veski	doc_42187174249_item	2401657	et	4	main
ja	doc_42187174249_item	2401658	et	3	main
wiedelmann	doc_42187174249_item	2401659	et	4	main
iseloomulik	doc_42187174249_item	2401666	et	3	main
see	doc_42187174249_item	2401669	et	3	main
ideed	doc_42187174249_item	2401681	et	4	main
valgustamine	doc_42187174249_item	2401686	et	4	main
1739	doc_42187174249_item	2401694	et	2	main
kõik	doc_42187174249_item	2401695	et	4	main
need	doc_42187174249_item	2401696	et	3	main
tegurid	doc_42187174249_item	2401697	et	3	main
mõjutasid	doc_42187174249_item	2401698	et	4	main
edenemist	doc_42187174249_item	2401701	et	4	main
rahvas	doc_42187174249_item	2401703	et	4	main
pööras	doc_42187174249_item	2401704	et	4	main
ülikool	doc_42187174249_item	2401715	et	4	main
oli	doc_42187174249_item	2401720	et	3	main
kes	doc_42187174249_item	2401724	et	4	main
asda	doc_427657030946_item	2401728	et	4	main
proov	doc_427657030946_item	2401731	et	3	main
muinasusundi	doc_429435411727_item	2401735	et	3	main
mis	doc_429435411727_item	2401738	et	4	main
on	doc_429435411727_item	2401745	et	4	main
üsna	doc_429435411727_item	2401746	et	3	main
raske	doc_429435411727_item	2401747	et	4	main
kirjeldada	doc_429435411727_item	2401748	et	3	main
kuna	doc_429435411727_item	2401749	et	3	main
muinasaeg	doc_429435411727_item	2401750	et	3	main
igasugused	doc_429435411727_item	2401757	et	3	main
kindlasti	doc_429435411727_item	2401763	et	3	main
et	doc_429435411727_item	2401765	et	3	main
inimestel	doc_429435411727_item	2401766	et	3	main
elust	doc_429435411727_item	2401774	et	3	main
surnuid	doc_429435411727_item	2401777	et	4	main
asula	doc_429435411727_item	2401779	et	4	main
tarbeesemeid	doc_429435411727_item	2401789	et	3	main
amuleti	doc_429435411727_item	2401790	et	3	main
neoliitikumi	doc_429435411727_item	2401803	et	4	main
teisel	doc_429435411727_item	2401804	et	4	main
territooriumi	doc_429435411727_item	2401810	et	4	main
sängitati	doc_429435411727_item	2401812	et	3	main
küljel	doc_429435411727_item	2401819	et	3	main
8	doc_429435411727_item	2401827	et	2	main
ekr	doc_429435411727_item	2401830	et	4	main
nö	doc_429435411727_item	2401833	et	4	main
kivimetest	doc_429435411727_item	2401839	et	4	main
keskmine	doc_429435411727_item	2401844	et	3	main
sellel	doc_429435411727_item	2401853	et	4	main
sümbol	doc_429435411727_item	2401869	et	3	main
hõbedat	doc_429435411727_item	2401888	et	3	main
tähtsuse	doc_429435411727_item	2401904	et	4	main
ilmastiku	doc_429435411727_item	2401908	et	4	main
kauem	doc_429435411727_item	2401924	et	4	main
ulatub	doc_429435411727_item	2401933	et	3	main
soov	doc_429435411727_item	2401942	et	3	main
saamiseks	doc_429435411727_item	2401949	et	4	main
maha	doc_429435411727_item	2401952	et	4	main
väetiseks	doc_429435411727_item	2401957	et	3	main
1	doc_43125203602_item	2401973	et	2	main
muinasusundi	doc_43125203602_item	2401975	et	3	main
2	doc_43125203602_item	2401977	et	2	main
põletusmatused	doc_43125203602_item	2401994	et	3	main
matuste	doc_43125203602_item	2401995	et	3	main
on	doc_43125203602_item	2401998	et	4	main
maetud	doc_43125203602_item	2402004	et	4	main
varandus	doc_43125203602_item	2402010	et	3	main
maeti	doc_43125203602_item	2402012	et	3	main
maeti	doc_43125203602_item	2402016	et	3	main
on	doc_43125203602_item	2402020	et	4	main
inimest	doc_43125203602_item	2402024	et	3	main
alla	doc_43125203602_item	2402028	et	3	main
ümber	doc_43125203602_item	2402031	et	3	main
on	doc_43125203602_item	2402035	et	4	main
jäänud	doc_43125203602_item	2402036	et	4	main
usk	doc_43125203602_item	2402037	et	3	main
rändmungad	doc_43125203602_item	2402074	et	3	main
nad	doc_43125203602_item	2402075	et	3	main
millesse	doc_43125203602_item	2402080	et	3	main
kohtades	doc_43125203602_item	2402084	et	3	main
ususid	doc_43125203602_item	2402086	et	4	main
loodus	doc_43125203602_item	2402090	et	4	main
samat	doc_43125203602_item	2402092	et	4	main
on	doc_43125203602_item	2402098	et	4	main
mõnedel	doc_43125203602_item	2402100	et	3	main
usk	doc_43125203602_item	2402102	et	3	main
oskas	doc_42187174249_item	2401725	et	3	main
proov	doc_427657030946_item	2401727	et	3	main
sdas	doc_427657030946_item	2401729	et	4	main
da	doc_427657030946_item	2401730	et	4	main
1	doc_429435411727_item	2401733	et	2	main
alepõllundus	doc_429435411727_item	2401740	et	3	main
üldiselt	doc_429435411727_item	2401744	et	4	main
oli	doc_429435411727_item	2401751	et	3	main
päris	doc_429435411727_item	2401752	et	4	main
pikk	doc_429435411727_item	2401753	et	4	main
ajajärk	doc_429435411727_item	2401754	et	3	main
toimusid	doc_429435411727_item	2401756	et	4	main
arengu	doc_429435411727_item	2401759	et	3	main
kuid	doc_429435411727_item	2401761	et	4	main
hauatagusest	doc_429435411727_item	2401773	et	3	main
pandi	doc_429435411727_item	2401787	et	4	main
tööriistu	doc_429435411727_item	2401788	et	3	main
ja	doc_429435411727_item	2401791	et	3	main
jõudsid	doc_429435411727_item	2401806	et	4	main
kalmed	doc_429435411727_item	2401807	et	3	main
mitte	doc_429435411727_item	2401814	et	3	main
tarbeesemed	doc_429435411727_item	2401826	et	3	main
saj	doc_429435411727_item	2401829	et	4	main
mis	doc_429435411727_item	2401835	et	4	main
valmistatud	doc_429435411727_item	2401837	et	4	main
suurematest	doc_429435411727_item	2401838	et	4	main
oli	doc_429435411727_item	2401848	et	3	main
konfliktide	doc_429435411727_item	2401851	et	3	main
surnutele	doc_429435411727_item	2401856	et	4	main
kõigi	doc_429435411727_item	2401870	et	4	main
jooksul	doc_429435411727_item	2401872	et	4	main
arvasid	doc_429435411727_item	2401874	et	4	main
et	doc_429435411727_item	2401875	et	3	main
edu	doc_429435411727_item	2401876	et	4	main
ja	doc_429435411727_item	2401877	et	3	main
õnne	doc_429435411727_item	2401878	et	4	main
sirp	doc_429435411727_item	2401890	et	3	main
erilise	doc_429435411727_item	2401903	et	4	main
maagilised	doc_429435411727_item	2401906	et	4	main
muinasusklikuna	doc_429435411727_item	2401925	et	3	main
on	doc_429435411727_item	2401928	et	4	main
jaanitule	doc_429435411727_item	2401930	et	4	main
suurendada	doc_429435411727_item	2401943	et	3	main
põletati	doc_429435411727_item	2401954	et	3	main
jäi	doc_429435411727_item	2401956	et	3	main
metalli	doc_429435411727_item	2401969	et	4	main
ajal	doc_429435411727_item	2401970	et	4	main
eestlaste	doc_43125203602_item	2401974	et	4	main
austati	doc_43125203602_item	2401984	et	3	main
surnuid	doc_43125203602_item	2401985	et	4	main
inimesi	doc_43125203602_item	2401986	et	4	main
rääkida	doc_43125203602_item	2401990	et	3	main
ja	doc_43125203602_item	2402001	et	3	main
on	doc_43125203602_item	2402003	et	4	main
ka	doc_43125203602_item	2402005	et	3	main
koos	doc_43125203602_item	2402006	et	4	main
ka	doc_43125203602_item	2402017	et	3	main
kivikalmedesse	doc_43125203602_item	2402018	et	4	main
poolel	doc_429435411727_item	2401805	et	4	main
inimesi	doc_429435411727_item	2401811	et	4	main
nüüd	doc_429435411727_item	2401813	et	4	main
poosis	doc_429435411727_item	2401818	et	3	main
hauapanused	doc_429435411727_item	2401820	et	3	main
endiselt	doc_429435411727_item	2401822	et	4	main
9	doc_429435411727_item	2401828	et	2	main
eestis	doc_429435411727_item	2401831	et	3	main
olid	doc_429435411727_item	2401836	et	4	main
kirst	doc_429435411727_item	2401843	et	3	main
ja	doc_429435411727_item	2401845	et	3	main
sõdade	doc_429435411727_item	2401849	et	3	main
vahel	doc_429435411727_item	2401861	et	4	main
haudadest	doc_429435411727_item	2401862	et	3	main
muinasaja	doc_429435411727_item	2401871	et	3	main
inimesed	doc_429435411727_item	2401873	et	3	main
ka	doc_429435411727_item	2401887	et	3	main
tööriist	doc_429435411727_item	2401892	et	3	main
rauaajal	doc_429435411727_item	2401897	et	3	main
elatusalaks	doc_429435411727_item	2401899	et	3	main
omandanud	doc_429435411727_item	2401905	et	4	main
püsis	doc_429435411727_item	2401922	et	4	main
kõige	doc_429435411727_item	2401923	et	4	main
olnud	doc_429435411727_item	2401941	et	4	main
2	doc_429435411727_item	2401946	et	2	main
ja	doc_429435411727_item	2401953	et	3	main
vastus	doc_43125203602_item	2401971	et	3	main
pealt	doc_43125203602_item	2401983	et	4	main
tohtinud	doc_43125203602_item	2401989	et	4	main
ajal	doc_43125203602_item	2401996	et	4	main
herneid	doc_43125203602_item	2402002	et	3	main
inimesega	doc_43125203602_item	2402007	et	3	main
liivakääpadesse	doc_43125203602_item	2402014	et	4	main
vaid	doc_43125203602_item	2402029	et	3	main
pandi	doc_43125203602_item	2402030	et	4	main
teda	doc_43125203602_item	2402032	et	4	main
siiamaani	doc_43125203602_item	2402034	et	3	main
näiteks	doc_43125203602_item	2402039	et	4	main
kirikus	doc_43125203602_item	2402040	et	3	main
juuakse	doc_43125203602_item	2402041	et	3	main
et	doc_43125203602_item	2402045	et	3	main
parandab	doc_43125203602_item	2402047	et	3	main
ristist	doc_43125203602_item	2402049	et	4	main
on	doc_43125203602_item	2402050	et	4	main
tulema	doc_43125203602_item	2402073	et	4	main
rääkisid	doc_43125203602_item	2402076	et	4	main
inimestele	doc_43125203602_item	2402077	et	3	main
usundist	doc_43125203602_item	2402078	et	3	main
ja	doc_43125203602_item	2402079	et	3	main
et	doc_43125203602_item	2402089	et	3	main
hing	doc_43125203602_item	2402099	et	3	main
maagiasse	doc_43125203602_item	2402103	et	4	main
ongi	doc_43125203602_item	2402120	et	4	main
nende	doc_43125203602_item	2402122	et	4	main
kasvatada	doc_43125203602_item	2402125	et	3	main
lina	doc_43125203602_item	2402129	et	4	main
kanep	doc_43125203602_item	2402130	et	3	main
väärtuslik	doc_43125203602_item	2402133	et	3	main
kontrolltöö	doc_43125203603_item	2402136	et	4	main
eestlaste	doc_43125203603_item	2402140	et	4	main
sapiens	doc_43125203603_item	2402157	et	4	main
religiosusega	doc_43125203603_item	2402160	et	4	main
selle	doc_43125203603_item	2402163	et	4	main
matmiskombed	doc_43125203603_item	2402169	et	3	main
võhandu	doc_43125203603_item	2402176	et	4	main
jões	doc_43125203603_item	2402177	et	3	main
leiti	doc_43125203603_item	2402178	et	3	main
palju	doc_43125203603_item	2402179	et	4	main
sirpe	doc_43125203603_item	2402180	et	3	main
see	doc_43125203603_item	2402181	et	3	main
tähendab	doc_43125203603_item	2402182	et	3	main
et	doc_43125203603_item	2402183	et	3	main
olnud	doc_43125203603_item	2402186	et	4	main
oma	doc_43125203603_item	2402221	et	4	main
palju	doc_43125203603_item	2402225	et	4	main
matmispaikadelt	doc_43125203603_item	2402229	et	3	main
maagilise	doc_43125203603_item	2402236	et	4	main
tähendusega	doc_43125203603_item	2402237	et	4	main
ainult	doc_43125203603_item	2402243	et	4	main
kristlaste	doc_43125203603_item	2402244	et	3	main
merevaigul	doc_43125203603_item	2402265	et	3	main
surnutele	doc_43125203603_item	2402272	et	4	main
tervendava	doc_43125203603_item	2402277	et	4	main
ehted	doc_429435411727_item	2401824	et	3	main
kivikirstkalmed	doc_429435411727_item	2401834	et	4	main
ja	doc_429435411727_item	2401840	et	3	main
sisse	doc_429435411727_item	2401841	et	4	main
rajutati	doc_429435411727_item	2401842	et	3	main
noorem	doc_429435411727_item	2401846	et	4	main
rauaaeg	doc_429435411727_item	2401847	et	3	main
ja	doc_429435411727_item	2401850	et	3	main
ajal	doc_429435411727_item	2401854	et	4	main
avastatud	doc_429435411727_item	2401863	et	4	main
ka	doc_429435411727_item	2401864	et	3	main
okrit	doc_429435411727_item	2401865	et	4	main
elu	doc_429435411727_item	2401866	et	4	main
ja	doc_429435411727_item	2401867	et	3	main
näiteks	doc_429435411727_item	2401889	et	4	main
oli	doc_429435411727_item	2401891	et	3	main
ohverdati	doc_429435411727_item	2401894	et	3	main
rooma	doc_429435411727_item	2401896	et	4	main
on	doc_429435411727_item	2401900	et	4	main
rahva	doc_429435411727_item	2401901	et	3	main
jaoks	doc_429435411727_item	2401902	et	4	main
mõjutamiseks	doc_429435411727_item	2401909	et	4	main
teada	doc_429435411727_item	2401911	et	3	main
et	doc_429435411727_item	2401912	et	3	main
baltimaade	doc_429435411727_item	2401913	et	3	main
rahvad	doc_429435411727_item	2401914	et	3	main
ei	doc_429435411727_item	2401915	et	4	main
lubanud	doc_429435411727_item	2401916	et	4	main
ennast	doc_429435411727_item	2401917	et	4	main
ristida	doc_429435411727_item	2401918	et	4	main
ja	doc_429435411727_item	2401919	et	3	main
sellepärast	doc_429435411727_item	2401920	et	3	main
päevani	doc_429435411727_item	2401927	et	3	main
mis	doc_429435411727_item	2401932	et	4	main
rooma	doc_429435411727_item	2401934	et	4	main
rauaaega	doc_429435411727_item	2401935	et	4	main
ja	doc_429435411727_item	2401936	et	3	main
mille	doc_429435411727_item	2401937	et	3	main
uskumuslikuks	doc_429435411727_item	2401938	et	4	main
tagamaaks	doc_429435411727_item	2401939	et	3	main
on	doc_429435411727_item	2401940	et	4	main
päikese	doc_429435411727_item	2401944	et	4	main
põllumaa	doc_429435411727_item	2401948	et	4	main
mets	doc_429435411727_item	2401950	et	3	main
tuhk	doc_429435411727_item	2401955	et	3	main
mõne	doc_429435411727_item	2401959	et	3	main
aasta	doc_429435411727_item	2401960	et	4	main
vältel	doc_429435411727_item	2401961	et	4	main
kuni	doc_429435411727_item	2401962	et	3	main
mulla	doc_429435411727_item	2401963	et	4	main
viljakus	doc_429435411727_item	2401964	et	4	main
langes	doc_429435411727_item	2401965	et	4	main
hakkati	doc_429435411727_item	2401966	et	3	main
kasutama	doc_429435411727_item	2401967	et	3	main
varasel	doc_429435411727_item	2401968	et	4	main
kasutati	doc_429435411727_item	2401958	et	4	main
1	doc_43125203602_item	2401981	et	2	main
kõige	doc_43125203602_item	2401982	et	4	main
halvasti	doc_43125203602_item	2401991	et	3	main
tuli	doc_43125203602_item	2401993	et	4	main
tööriistad	doc_43125203602_item	2402009	et	3	main
inimesi	doc_43125203602_item	2402015	et	4	main
kivikalmed	doc_43125203602_item	2402019	et	3	main
maetud	doc_43125203602_item	2402026	et	4	main
puhasvesi	doc_43125203602_item	2402043	et	4	main
allikavesi	doc_43125203602_item	2402046	et	4	main
silmanägemise	doc_43125203602_item	2402048	et	3	main
sellest	doc_43125203602_item	2402056	et	4	main
rist	doc_43125203602_item	2402070	et	3	main
lõuna-eestist	doc_43125203602_item	2402071	et	3	main
hakksid	doc_43125203602_item	2402072	et	4	main
inimesed	doc_43125203602_item	2402082	et	3	main
sellesse	doc_43125203602_item	2402088	et	4	main
loodusel	doc_43125203602_item	2402097	et	4	main
rajuti	doc_43125203602_item	2402106	et	4	main
põletati	doc_43125203602_item	2402110	et	3	main
maa	doc_43125203602_item	2402112	et	4	main
peale	doc_43125203602_item	2402114	et	4	main
põld	doc_43125203602_item	2402118	et	3	main
arheoloogid	doc_43125203603_item	2402149	et	3	main
ning	doc_43125203603_item	2402150	et	3	main
ajaloolased	doc_43125203603_item	2402151	et	3	main
homo	doc_43125203603_item	2402159	et	4	main
arheoloogilisi	doc_43125203603_item	2402161	et	4	main
tõendeid	doc_43125203603_item	2402162	et	3	main
palju	doc_43125203603_item	2402167	et	4	main
nii	doc_43125203603_item	2402168	et	3	main
sirp	doc_43125203603_item	2402184	et	3	main
kuid	doc_43125203603_item	2402189	et	4	main
maagilise	doc_43125203603_item	2402191	et	4	main
tähendusega	doc_43125203603_item	2402192	et	4	main
ese	doc_43125203603_item	2402193	et	3	main
arvatavasti	doc_43125203603_item	2402194	et	3	main
ohverdati	doc_43125203603_item	2402195	et	3	main
sirpe	doc_43125203603_item	2402196	et	3	main
surnuid	doc_43125203603_item	2402222	et	4	main
näiteks	doc_43125203603_item	2402238	et	4	main
ajast	doc_43125203603_item	2402245	et	4	main
tähendust	doc_43125203603_item	2402259	et	4	main
usuti	doc_43125203603_item	2402266	et	3	main
selle	doc_43125203603_item	2402267	et	4	main
ja	doc_43125203603_item	2402269	et	3	main
tervendavatesse	doc_43125203603_item	2402270	et	4	main
toimedesse	doc_43125203603_item	2402271	et	3	main
et	doc_43125203603_item	2402280	et	3	main
eestlased	doc_43125203603_item	2402282	et	3	main
surnutele	doc_43125203603_item	2402284	et	4	main
tööriistu	doc_43125203603_item	2402286	et	3	main
ja	doc_43125203603_item	2402287	et	3	main
ehteid	doc_43125203603_item	2402288	et	3	main
tähendab	doc_43125203603_item	2402289	et	3	main
et	doc_43125203603_item	2402290	et	3	main
usuti	doc_43125203603_item	2402291	et	3	main
maavälisse	doc_43125203603_item	2402292	et	4	main
tõenäoliselt	doc_43125203603_item	2402295	et	4	main
tööriistu	doc_43125203603_item	2402307	et	3	main
veel	doc_43125203603_item	2402318	et	4	main
küsimusele	doc_43125203602_item	2401972	et	4	main
üldiseloomustus	doc_43125203602_item	2401976	et	4	main
mis	doc_43125203602_item	2401978	et	4	main
on	doc_43125203602_item	2401979	et	4	main
alepõllundus	doc_43125203602_item	2401980	et	3	main
nendest	doc_43125203602_item	2401987	et	4	main
ei	doc_43125203602_item	2401988	et	4	main
13saj	doc_43125203602_item	2401992	et	4	main
inimesed	doc_43125203602_item	2401997	et	3	main
ohverdanud	doc_43125203602_item	2401999	et	4	main
ube	doc_43125203602_item	2402000	et	3	main
ehted	doc_43125203602_item	2402008	et	3	main
lõuna-eestis	doc_43125203602_item	2402011	et	3	main
inimesi	doc_43125203602_item	2402013	et	4	main
leitud	doc_43125203602_item	2402021	et	4	main
eestis	doc_43125203602_item	2402023	et	3	main
maa	doc_43125203602_item	2402027	et	4	main
allikavett	doc_43125203602_item	2402042	et	3	main
kannatuse	doc_43125203602_item	2402054	et	4	main
sümbol	doc_43125203602_item	2402055	et	3	main
teistes	doc_43125203602_item	2402083	et	4	main
elab	doc_43125203602_item	2402091	et	3	main
moodi	doc_43125203602_item	2402093	et	4	main
nagu	doc_43125203602_item	2402094	et	3	main
nemad	doc_43125203602_item	2402095	et	3	main
et	doc_43125203602_item	2402096	et	3	main
algul	doc_43125203602_item	2402105	et	4	main
maha	doc_43125203602_item	2402108	et	4	main
põlludel	doc_43125203602_item	2402123	et	4	main
kontrolltöö	doc_43125203603_item	2402135	et	4	main
eesti	doc_43125203603_item	2402137	et	4	main
arva	doc_43125203603_item	2402152	et	4	main
on	doc_43125203603_item	2402153	et	4	main
et	doc_43125203603_item	2402155	et	3	main
võrdub	doc_43125203603_item	2402158	et	3	main
on	doc_43125203603_item	2402165	et	4	main
päris	doc_43125203603_item	2402166	et	4	main
teised	doc_43125203603_item	2402172	et	4	main
arheoloogilised	doc_43125203603_item	2402173	et	4	main
selleks	doc_43125203603_item	2402197	et	4	main
et	doc_43125203603_item	2402198	et	3	main
saada	doc_43125203603_item	2402199	et	4	main
esivanemaid	doc_43125203603_item	2402223	et	4	main
võib	doc_43125203603_item	2402227	et	3	main
inimestele	doc_43125203603_item	2402230	et	3	main
kaasa	doc_43125203603_item	2402232	et	4	main
ehteid	doc_43125203603_item	2402235	et	3	main
tuntud	doc_43125203603_item	2402242	et	4	main
oli	doc_43125203603_item	2402262	et	3	main
eesmärgiga	doc_43125203603_item	2402278	et	3	main
see	doc_43125203603_item	2402279	et	3	main
oleks	doc_43125203603_item	2402296	et	3	main
vaja	doc_43125203603_item	2402297	et	4	main
aitasid	doc_43125203603_item	2402302	et	4	main
kui	doc_43125203603_item	2402306	et	3	main
peeti	doc_43125203603_item	2402309	et	4	main
ei	doc_43125203603_item	2402319	et	4	main
puid	doc_43125203603_item	2402328	et	3	main
jne	doc_43125203603_item	2402329	et	4	main
ohverdati	doc_43125203603_item	2402331	et	3	main
kristlaste	doc_43125203603_item	2402338	et	3	main
religioonist	doc_43125203603_item	2402339	et	3	main
vikingi	doc_43125203603_item	2402342	et	4	main
on	doc_43125203603_item	2402353	et	4	main
rohkesti	doc_43125203603_item	2402354	et	3	main
arvatavasti	doc_43125203603_item	2402358	et	3	main
kannavad	doc_43125203603_item	2402362	et	3	main
usuga	doc_43125203603_item	2402364	et	3	main
seotud	doc_43125203603_item	2402365	et	4	main
matmispaik	doc_43125203603_item	2402369	et	3	main
pidi	doc_43125203603_item	2402373	et	4	main
mõnesid	doc_43125203603_item	2402384	et	3	main
tule	doc_43125203603_item	2402394	et	4	main
inimesed	doc_43125203603_item	2402401	et	3	main
puid	doc_43125203603_item	2402403	et	3	main
tunnuseks	doc_43125203603_item	2402438	et	3	main
oli	doc_43125203603_item	2402442	et	3	main
oli	doc_43125203603_item	2402446	et	3	main
ühte	doc_43125203603_item	2402462	et	4	main
osat	doc_43125203603_item	2402463	et	4	main
jäeti	doc_43125203603_item	2402464	et	3	main
tähtsam	doc_432051777896_item	2402504	et	4	main
õppida	doc_432051777896_item	2402511	et	3	main
10	doc_432051777896_item	2402516	et	2	main
aastat	doc_432051777896_item	2402517	et	3	main
ka	doc_43125203602_item	2402022	et	3	main
ei	doc_43125203602_item	2402025	et	4	main
kive	doc_43125203602_item	2402033	et	3	main
millesegi	doc_43125203602_item	2402038	et	4	main
usuti	doc_43125203602_item	2402044	et	3	main
saanud	doc_43125203602_item	2402051	et	4	main
kiriku	doc_43125203602_item	2402052	et	3	main
sümbol	doc_43125203602_item	2402053	et	3	main
on	doc_43125203602_item	2402057	et	4	main
saanud	doc_43125203602_item	2402058	et	4	main
ka	doc_43125203602_item	2402059	et	3	main
surmasümbol	doc_43125203602_item	2402060	et	3	main
tänapäeva	doc_43125203602_item	2402061	et	4	main
kalmistul	doc_43125203602_item	2402062	et	3	main
võib	doc_43125203602_item	2402063	et	3	main
näha	doc_43125203602_item	2402064	et	3	main
palju	doc_43125203602_item	2402065	et	4	main
haudasi	doc_43125203602_item	2402066	et	3	main
mille	doc_43125203602_item	2402067	et	3	main
peal	doc_43125203602_item	2402068	et	4	main
on	doc_43125203602_item	2402069	et	4	main
usuvad	doc_43125203602_item	2402081	et	3	main
inimesed	doc_43125203602_item	2402085	et	3	main
ka	doc_43125203602_item	2402087	et	3	main
oli	doc_43125203602_item	2402101	et	3	main
mets	doc_43125203602_item	2402107	et	3	main
sai	doc_43125203602_item	2402124	et	4	main
2	doc_43125203602_item	2402104	et	2	main
siis	doc_43125203602_item	2402109	et	3	main
see	doc_43125203602_item	2402111	et	3	main
ja	doc_43125203602_item	2402113	et	3	main
seda	doc_43125203602_item	2402115	et	3	main
tehti	doc_43125203602_item	2402116	et	3	main
sinna	doc_43125203602_item	2402117	et	3	main
see	doc_43125203602_item	2402119	et	3	main
alepõllundus	doc_43125203602_item	2402121	et	3	main
oder	doc_43125203602_item	2402127	et	3	main
kultuuriloost	doc_43125203603_item	2402138	et	4	main
2	doc_43125203603_item	2402143	et	2	main
veendunud	doc_43125203603_item	2402154	et	4	main
ka	doc_43125203603_item	2402171	et	3	main
leiud	doc_43125203603_item	2402174	et	3	main
näiteks	doc_43125203603_item	2402175	et	4	main
ei	doc_43125203603_item	2402185	et	4	main
ainult	doc_43125203603_item	2402187	et	4	main
töövahend	doc_43125203603_item	2402188	et	3	main
ka	doc_43125203603_item	2402190	et	3	main
väga	doc_43125203603_item	2402224	et	3	main
infot	doc_43125203603_item	2402226	et	3	main
anti	doc_43125203603_item	2402231	et	3	main
tööriistu	doc_43125203603_item	2402233	et	3	main
ja	doc_43125203603_item	2402234	et	3	main
ole	doc_43125203603_item	2402241	et	4	main
ka	doc_43125203603_item	2402247	et	3	main
omasid	doc_43125203603_item	2402256	et	4	main
oma	doc_43125203603_item	2402257	et	4	main
kindlat	doc_43125203603_item	2402258	et	3	main
tähendus	doc_43125203603_item	2402261	et	4	main
eestlaste	doc_43125203603_item	2402263	et	4	main
pandi	doc_43125203603_item	2402273	et	4	main
silmade	doc_43125203603_item	2402274	et	3	main
muistsed	doc_43125203603_item	2402281	et	3	main
ellu	doc_43125203603_item	2402293	et	4	main
väga	doc_43125203603_item	2402310	et	3	main
millestesse	doc_43125203603_item	2402315	et	4	main
tehti	doc_43125203603_item	2402316	et	3	main
auke	doc_43125203603_item	2402317	et	4	main
ole	doc_43125203603_item	2402320	et	4	main
teada	doc_43125203603_item	2402321	et	3	main
eesmärgiga	doc_43125203603_item	2402326	et	3	main
surnutele	doc_43125203603_item	2402330	et	4	main
vilju	doc_43125203603_item	2402332	et	4	main
tekkima	doc_43125203603_item	2402341	et	3	main
levitajatelt	doc_43125203603_item	2402349	et	4	main
alates	doc_43125203603_item	2402352	et	3	main
see	doc_43125203603_item	2402367	et	3	main
kividega	doc_43125203603_item	2402372	et	3	main
tähendama	doc_43125203603_item	2402375	et	3	main
et	doc_43125203603_item	2402376	et	3	main
see	doc_43125203603_item	2402377	et	3	main
on	doc_43125203603_item	2402378	et	4	main
me	doc_43125203603_item	2402382	et	4	main
muistseestlaste	doc_43125203603_item	2402385	et	4	main
näiteks	doc_43125203603_item	2402387	et	4	main
jõulude	doc_43125203603_item	2402388	et	3	main
ei	doc_43125203603_item	2402393	et	4	main
vaid	doc_43125203603_item	2402397	et	3	main
ehtisid	doc_43125203603_item	2402402	et	4	main
rauaajal	doc_43125203603_item	2402411	et	3	main
siis	doc_43125203603_item	2402414	et	3	main
rohkesti	doc_43125203603_item	2402417	et	3	main
kalapüügist	doc_43125203603_item	2402419	et	3	main
jahtimisest	doc_43125203603_item	2402421	et	4	main
teada	doc_43125203603_item	2402431	et	3	main
et	doc_43125203603_item	2402432	et	3	main
oli	doc_43125203603_item	2402439	et	3	main
jaotatud	doc_43125203603_item	2402447	et	4	main
kolmeks	doc_43125203603_item	2402448	et	4	main
osaks	doc_43125203603_item	2402449	et	3	main
ning	doc_43125203603_item	2402450	et	3	main
esimesel	doc_43125203603_item	2402451	et	3	main
kasvatati	doc_43125203603_item	2402452	et	3	main
suverukkist	doc_43125203603_item	2402453	et	4	main
talverukkist	doc_43125203603_item	2402455	et	4	main
istutati	doc_43125203603_item	2402457	et	3	main
puhkama	doc_43125203603_item	2402465	et	3	main
midagi	doc_43125203603_item	2402471	et	4	main
sellest	doc_43125203603_item	2402472	et	4	main
koosneski	doc_43125203603_item	2402473	et	3	main
kõige	doc_432051777896_item	2402503	et	4	main
on	doc_432051777896_item	2402507	et	4	main
armastan	doc_432051777896_item	2402510	et	3	main
vilja	doc_43125203602_item	2402126	et	4	main
nisu	doc_43125203602_item	2402128	et	4	main
hirss	doc_43125203602_item	2402131	et	3	main
tuder	doc_43125203602_item	2402132	et	3	main
õlitaim	doc_43125203602_item	2402134	et	3	main
1	doc_43125203603_item	2402139	et	2	main
muinasusundi	doc_43125203603_item	2402141	et	3	main
üldiseloomustus	doc_43125203603_item	2402142	et	4	main
mis	doc_43125203603_item	2402144	et	4	main
on	doc_43125203603_item	2402145	et	4	main
alepõllundus	doc_43125203603_item	2402146	et	3	main
1	doc_43125203603_item	2402147	et	2	main
paljud	doc_43125203603_item	2402148	et	3	main
homo	doc_43125203603_item	2402156	et	4	main
kohta	doc_43125203603_item	2402164	et	4	main
kui	doc_43125203603_item	2402170	et	3	main
paremat	doc_43125203603_item	2402200	et	4	main
saaki	doc_43125203603_item	2402201	et	4	main
vanem	doc_43125203603_item	2402202	et	4	main
pronksiaeg	doc_43125203603_item	2402203	et	3	main
loodusjõud	doc_43125203603_item	2402204	et	4	main
millelt	doc_43125203603_item	2402205	et	3	main
paluti	doc_43125203603_item	2402206	et	3	main
jõudu	doc_43125203603_item	2402207	et	4	main
ja	doc_43125203603_item	2402208	et	3	main
abi	doc_43125203603_item	2402209	et	4	main
oli	doc_43125203603_item	2402210	et	3	main
äike	doc_43125203603_item	2402211	et	3	main
väga	doc_43125203603_item	2402212	et	3	main
iseloomustavaks	doc_43125203603_item	2402213	et	4	main
jooneks	doc_43125203603_item	2402214	et	3	main
oli	doc_43125203603_item	2402215	et	3	main
see	doc_43125203603_item	2402216	et	3	main
et	doc_43125203603_item	2402217	et	3	main
muistsed	doc_43125203603_item	2402218	et	3	main
eestlased	doc_43125203603_item	2402219	et	3	main
austasid	doc_43125203603_item	2402220	et	4	main
saada	doc_43125203603_item	2402228	et	4	main
rist	doc_43125203603_item	2402239	et	3	main
ei	doc_43125203603_item	2402240	et	4	main
vaid	doc_43125203603_item	2402246	et	3	main
varem	doc_43125203603_item	2402248	et	4	main
on	doc_43125203603_item	2402249	et	4	main
pandud	doc_43125203603_item	2402250	et	4	main
surnutele	doc_43125203603_item	2402251	et	4	main
kaasa	doc_43125203603_item	2402252	et	4	main
ristikujulisi	doc_43125203603_item	2402253	et	4	main
ehteid	doc_43125203603_item	2402254	et	3	main
mis	doc_43125203603_item	2402255	et	4	main
suur	doc_43125203603_item	2402260	et	3	main
jaoks	doc_43125203603_item	2402264	et	4	main
maagilistesse	doc_43125203603_item	2402268	et	4	main
kohale	doc_43125203603_item	2402275	et	4	main
merevaigu	doc_43125203603_item	2402276	et	3	main
panid	doc_43125203603_item	2402283	et	4	main
kus	doc_43125203603_item	2402294	et	3	main
kurja	doc_43125203603_item	2402303	et	4	main
jõu	doc_43125203603_item	2402304	et	3	main
töövahendeid	doc_43125203603_item	2402308	et	3	main
tähtsaks	doc_43125203603_item	2402311	et	4	main
kive	doc_43125203603_item	2402314	et	3	main
suuri	doc_43125203603_item	2402327	et	3	main
viitab	doc_43125203603_item	2402333	et	3	main
mungadelt	doc_43125203603_item	2402346	et	4	main
rändavatelt	doc_43125203603_item	2402347	et	4	main
religiooni	doc_43125203603_item	2402348	et	4	main
leitud	doc_43125203603_item	2402355	et	4	main
ehteid	doc_43125203603_item	2402357	et	3	main
ka	doc_43125203603_item	2402359	et	3	main
matmiskombed	doc_43125203603_item	2402361	et	3	main
mingit	doc_43125203603_item	2402363	et	3	main
et	doc_43125203603_item	2402368	et	3	main
ehtimine	doc_43125203603_item	2402391	et	4	main
see	doc_43125203603_item	2402392	et	3	main
usundist	doc_43125203603_item	2402396	et	3	main
muinasaja	doc_43125203603_item	2402398	et	3	main
kus	doc_43125203603_item	2402400	et	3	main
toitusid	doc_43125203603_item	2402415	et	4	main
viljast	doc_43125203603_item	2402418	et	4	main
kuid	doc_43125203603_item	2402422	et	4	main
kaasa	doc_43125203603_item	2402285	et	4	main
läinud	doc_43125203603_item	2402298	et	4	main
nii	doc_43125203603_item	2402299	et	3	main
ehteid	doc_43125203603_item	2402300	et	3	main
mis	doc_43125203603_item	2402301	et	4	main
eest	doc_43125203603_item	2402305	et	4	main
loodusjõude	doc_43125203603_item	2402312	et	3	main
suuri	doc_43125203603_item	2402313	et	3	main
põhjusega	doc_43125203603_item	2402323	et	3	main
mis	doc_43125203603_item	2402325	et	4	main
lugupidamisele	doc_43125203603_item	2402335	et	3	main
allikad	doc_43125203603_item	2402337	et	3	main
hakkavad	doc_43125203603_item	2402340	et	4	main
tähendust	doc_43125203603_item	2402366	et	4	main
ümbritsetud	doc_43125203603_item	2402371	et	4	main
ju	doc_43125203603_item	2402374	et	3	main
omamoodi	doc_43125203603_item	2402379	et	3	main
kaitstud	doc_43125203603_item	2402380	et	4	main
kasutame	doc_43125203603_item	2402383	et	3	main
kuuse	doc_43125203603_item	2402390	et	4	main
religioonist	doc_43125203603_item	2402399	et	3	main
paeladega	doc_43125203603_item	2402404	et	4	main
jne	doc_43125203603_item	2402405	et	4	main
2	doc_43125203603_item	2402406	et	2	main
põllunduse	doc_43125203603_item	2402407	et	3	main
tipphetk	doc_43125203603_item	2402408	et	3	main
oli	doc_43125203603_item	2402409	et	3	main
saj	doc_43125203603_item	2402413	et	4	main
muinasinimesed	doc_43125203603_item	2402416	et	3	main
tegevusala	doc_43125203603_item	2402423	et	4	main
millele	doc_43125203603_item	2402424	et	3	main
pöörati	doc_43125203603_item	2402425	et	3	main
suuremat	doc_43125203603_item	2402426	et	4	main
selle	doc_43125203603_item	2402437	et	4	main
et	doc_43125203603_item	2402441	et	3	main
kolmeväljasüsteem	doc_43125203603_item	2402444	et	3	main
põld	doc_43125203603_item	2402445	et	3	main
või	doc_43125203603_item	2402459	et	4	main
ja	doc_43125203603_item	2402461	et	3	main
vana	doc_432051777896_item	2402502	et	4	main
haridus	doc_432051777896_item	2402508	et	3	main
ma	doc_432051777896_item	2402509	et	3	main
koolis	doc_432051777896_item	2402521	et	4	main
ma	doc_432051777896_item	2402525	et	3	main
et	doc_432051777896_item	2402541	et	3	main
raamatuid	doc_432051777896_item	2402544	et	3	main
kuulata	doc_432051777896_item	2402547	et	4	main
tahan	doc_432051777896_item	2402550	et	3	main
rääkida	doc_432051777896_item	2402551	et	3	main
kirju	doc_432051777896_item	2402559	et	4	main
loodan	doc_432051777896_item	2402561	et	3	main
me	doc_432051777896_item	2402563	et	4	main
ma	doc_432051777896_item	2402569	et	3	main
minu	doc_432051777896_item	2402576	et	3	main
loodan	doc_432051777896_item	2402585	et	3	main
lugupidamisega	doc_432051777896_item	2402591	et	3	main
tere	doc_432051777897_item	2402595	et	3	main
xxxx	doc_432051777897_item	2402599	et	4	main
oska	doc_432051777897_item	2402623	et	4	main
elu	doc_432051777898_item	2402643	et	4	main
mõjutavad	doc_432051777898_item	2402644	et	4	main
mõned	doc_432051777898_item	2402645	et	3	main
öelda	doc_432051777898_item	2402652	et	4	main
inimese	doc_432051777898_item	2402666	et	4	main
siis	doc_432051777898_item	2402673	et	3	main
inimestel	doc_432051777898_item	2402678	et	3	main
mitte	doc_432051777898_item	2402706	et	3	main
endale	doc_432051777898_item	2402711	et	4	main
ma	doc_432051777898_item	2402721	et	3	main
et	doc_432051777898_item	2402723	et	3	main
elu	doc_432051777898_item	2402725	et	4	main
aga	doc_432051777898_item	2402732	et	3	main
elu	doc_432051777898_item	2402755	et	4	main
või	doc_432051777898_item	2402760	et	4	main
tere	doc_432051777899_item	2402764	et	3	main
aaaaaa	doc_432051777899_item	2402769	et	4	main
ahtme	doc_432051777899_item	2402804	et	4	main
gümnaasiumis	doc_432051777899_item	2402805	et	3	main
esimene	doc_432051777899_item	2402806	et	3	main
on	doc_432051777899_item	2402812	et	4	main
ja	doc_432051777899_item	2402821	et	3	main
on	doc_432051777899_item	2402824	et	4	main
on	doc_432051777899_item	2402832	et	4	main
mis	doc_43125203603_item	2402322	et	4	main
ja	doc_43125203603_item	2402324	et	3	main
esivanemate	doc_43125203603_item	2402334	et	4	main
esimesed	doc_43125203603_item	2402336	et	3	main
aja	doc_43125203603_item	2402343	et	4	main
lõpus	doc_43125203603_item	2402344	et	4	main
800-1030aa	doc_43125203603_item	2402345	et	3	main
sellest	doc_43125203603_item	2402350	et	4	main
ajast	doc_43125203603_item	2402351	et	4	main
ristikujulisi	doc_43125203603_item	2402356	et	4	main
esimesed	doc_43125203603_item	2402360	et	3	main
oli	doc_43125203603_item	2402370	et	3	main
tänapäevalgi	doc_43125203603_item	2402381	et	4	main
kombeid	doc_43125203603_item	2402386	et	4	main
ajal	doc_43125203603_item	2402389	et	4	main
kristlaste	doc_43125203603_item	2402395	et	3	main
keskmisel	doc_43125203603_item	2402410	et	3	main
9-13	doc_43125203603_item	2402412	et	2	main
ning	doc_43125203603_item	2402420	et	3	main
on	doc_43125203603_item	2402430	et	4	main
ajal	doc_43125203603_item	2402434	et	4	main
tekkis	doc_43125203603_item	2402435	et	3	main
alepõllundus	doc_43125203603_item	2402436	et	3	main
kasutusel	doc_43125203603_item	2402443	et	4	main
seda	doc_43125203603_item	2402456	et	3	main
augustis	doc_43125203603_item	2402458	et	3	main
septembris	doc_43125203603_item	2402460	et	3	main
seal	doc_43125203603_item	2402466	et	4	main
üks	doc_43125203603_item	2402469	et	3	main
minu	doc_432051777896_item	2402505	et	3	main
keelt	doc_432051777896_item	2402513	et	4	main
põhjus	doc_432051777896_item	2402523	et	4	main
tulin	doc_432051777896_item	2402526	et	3	main
eesti	doc_432051777896_item	2402538	et	4	main
kirjutada	doc_432051777896_item	2402558	et	3	main
õppimisega	doc_432051777896_item	2402568	et	4	main
tahaksin	doc_432051777896_item	2402579	et	3	main
millal	doc_432051777896_item	2402581	et	3	main
eksam	doc_432051777896_item	2402584	et	3	main
seda	doc_432051777896_item	2402588	et	3	main
õigesti	doc_432051777896_item	2402590	et	3	main
dokument	doc_432051777897_item	2402594	et	3	main
ei	doc_432051777897_item	2402622	et	4	main
aga	doc_432051777897_item	2402626	et	3	main
tahan	doc_432051777897_item	2402628	et	3	main
eesti	doc_432051777897_item	2402630	et	4	main
keel	doc_432051777897_item	2402631	et	4	main
mis	doc_432051777898_item	2402634	et	4	main
selstkond	doc_432051777898_item	2402649	et	4	main
mõjutavad	doc_432051777898_item	2402655	et	4	main
inimesed	doc_432051777898_item	2402656	et	3	main
kui	doc_432051777898_item	2402668	et	3	main
ja	doc_432051777898_item	2402671	et	3	main
aga	doc_432051777898_item	2402677	et	3	main
sageli	doc_432051777898_item	2402708	et	3	main
on	doc_432051777898_item	2402726	et	4	main
aga	doc_432051777898_item	2402741	et	3	main
läheb	doc_432051777898_item	2402744	et	3	main
väga	doc_432051777898_item	2402749	et	3	main
kurb	doc_432051777898_item	2402750	et	3	main
mõtte	doc_432051777898_item	2402751	et	3	main
ei	doc_432051777898_item	2402759	et	4	main
õpetaja	doc_432051777899_item	2402765	et	4	main
minu	doc_432051777899_item	2402766	et	3	main
oma	doc_432051777899_item	2402813	et	4	main
vaja	doc_432051777899_item	2402827	et	4	main
ajalehti	doc_432051777899_item	2402830	et	4	main
ma	doc_432051777899_item	2402836	et	3	main
tahan	doc_432051777899_item	2402837	et	3	main
lugeda	doc_432051777899_item	2402840	et	3	main
raamatuid	doc_432051777899_item	2402842	et	3	main
loodan	doc_432051777899_item	2402849	et	3	main
kirjutamisega	doc_432051777899_item	2402859	et	4	main
tähtsam	doc_432051777899_item	2402864	et	4	main
ülikooli	doc_432051777899_item	2402874	et	4	main
teada	doc_432051777899_item	2402881	et	3	main
õppinud	doc_432051777899_item	2402885	et	4	main
tähelepanu	doc_43125203603_item	2402427	et	4	main
oli	doc_43125203603_item	2402428	et	3	main
põlluharimine	doc_43125203603_item	2402429	et	3	main
sel	doc_43125203603_item	2402433	et	3	main
see	doc_43125203603_item	2402440	et	3	main
teisel	doc_43125203603_item	2402454	et	4	main
ei	doc_43125203603_item	2402467	et	4	main
kasvatatud	doc_43125203603_item	2402468	et	4	main
aasta	doc_43125203603_item	2402470	et	4	main
alepõllundus	doc_43125203603_item	2402474	et	3	main
muidu	doc_43125203603_item	2402475	et	3	main
on	doc_43125203603_item	2402476	et	4	main
veel	doc_43125203603_item	2402477	et	4	main
teada	doc_43125203603_item	2402478	et	3	main
et	doc_43125203603_item	2402479	et	3	main
tolleaegsed	doc_43125203603_item	2402480	et	3	main
inimesed	doc_43125203603_item	2402481	et	3	main
oskasid	doc_43125203603_item	2402482	et	4	main
teha	doc_43125203603_item	2402483	et	3	main
jahut	doc_43125203603_item	2402484	et	4	main
ja	doc_43125203603_item	2402485	et	3	main
vilja	doc_43125203603_item	2402486	et	4	main
kasvatati	doc_43125203603_item	2402487	et	3	main
ka	doc_43125203603_item	2402488	et	3	main
linade	doc_43125203603_item	2402489	et	3	main
tegemiseks	doc_43125203603_item	2402490	et	4	main
uus	doc_432051777896_item	2402491	et	3	main
dokument	doc_432051777896_item	2402492	et	3	main
tere	doc_432051777896_item	2402493	et	3	main
õpitaja	doc_432051777896_item	2402494	et	4	main
minu	doc_432051777896_item	2402495	et	3	main
nimi	doc_432051777896_item	2402496	et	3	main
on	doc_432051777896_item	2402497	et	4	main
xxxxxxxxx	doc_432051777896_item	2402498	et	4	main
22	doc_432051777896_item	2402500	et	2	main
aastat	doc_432051777896_item	2402501	et	3	main
olen	doc_432051777896_item	2402499	et	3	main
elus	doc_432051777896_item	2402506	et	4	main
eesti	doc_432051777896_item	2402512	et	4	main
olen	doc_432051777896_item	2402514	et	3	main
õppinud	doc_432051777896_item	2402515	et	4	main
õppinud	doc_432051777896_item	2402520	et	4	main
miks	doc_432051777896_item	2402524	et	4	main
lugeda	doc_432051777896_item	2402542	et	3	main
ajalehte	doc_432051777896_item	2402543	et	4	main
ma	doc_432051777896_item	2402549	et	3	main
minu	doc_432051777896_item	2402552	et	3	main
elust	doc_432051777896_item	2402555	et	3	main
ma	doc_432051777896_item	2402556	et	3	main
tegeleme	doc_432051777896_item	2402564	et	3	main
põhjalikult	doc_432051777896_item	2402565	et	4	main
eesti	doc_432051777896_item	2402566	et	4	main
natuke	doc_432051777896_item	2402571	et	4	main
et	doc_432051777896_item	2402572	et	3	main
see	doc_432051777896_item	2402573	et	3	main
on	doc_432051777896_item	2402574	et	4	main
raske	doc_432051777896_item	2402575	et	4	main
meil	doc_432051777896_item	2402582	et	4	main
kiri	doc_432051777896_item	2402589	et	3	main
minu	doc_432051777897_item	2402596	et	3	main
xxxxxxxxx	doc_432051777897_item	2402600	et	4	main
mina	doc_432051777897_item	2402621	et	4	main
varem	doc_432051777896_item	2402518	et	4	main
olen	doc_432051777896_item	2402519	et	3	main
sellele	doc_432051777896_item	2402527	et	4	main
on	doc_432051777896_item	2402529	et	4	main
see	doc_432051777896_item	2402530	et	3	main
et	doc_432051777896_item	2402531	et	3	main
tahan	doc_432051777896_item	2402532	et	3	main
seda	doc_432051777896_item	2402533	et	3	main
elukutselt	doc_432051777896_item	2402534	et	4	main
keelt	doc_432051777896_item	2402539	et	4	main
tahan	doc_432051777896_item	2402546	et	3	main
muusikat	doc_432051777896_item	2402548	et	3	main
eesti	doc_432051777896_item	2402553	et	4	main
sõpradega	doc_432051777896_item	2402554	et	3	main
tahan	doc_432051777896_item	2402557	et	3	main
et	doc_432051777896_item	2402562	et	3	main
keele	doc_432051777896_item	2402567	et	4	main
ma	doc_432051777896_item	2402578	et	3	main
teada	doc_432051777896_item	2402580	et	3	main
on	doc_432051777896_item	2402583	et	4	main
uus	doc_432051777897_item	2402593	et	3	main
on	doc_432051777897_item	2402598	et	4	main
ma	doc_432051777897_item	2402601	et	3	main
elan	doc_432051777897_item	2402602	et	3	main
kohtla-järvel	doc_432051777897_item	2402603	et	4	main
kohtla-jarve	doc_432051777897_item	2402604	et	4	main
asub	doc_432051777897_item	2402605	et	3	main
ida-eestis	doc_432051777897_item	2402606	et	3	main
ma	doc_432051777897_item	2402607	et	3	main
olen	doc_432051777897_item	2402608	et	3	main
sündind	doc_432051777897_item	2402609	et	4	main
kohtla-järvel	doc_432051777897_item	2402610	et	4	main
ma	doc_432051777897_item	2402611	et	3	main
õpin	doc_432051777897_item	2402612	et	3	main
polütehnikumis	doc_432051777897_item	2402613	et	3	main
eesti	doc_432051777897_item	2402614	et	4	main
ilus	doc_432051777897_item	2402616	et	4	main
on	doc_432051777897_item	2402615	et	4	main
maa	doc_432051777897_item	2402617	et	4	main
ma	doc_432051777897_item	2402618	et	3	main
armastan	doc_432051777897_item	2402619	et	3	main
eestimaad	doc_432051777897_item	2402620	et	4	main
eesti	doc_432051777897_item	2402624	et	4	main
uus	doc_432051777898_item	2402632	et	3	main
inimese	doc_432051777898_item	2402636	et	4	main
tahan	doc_432051777898_item	2402651	et	3	main
meid	doc_432051777898_item	2402654	et	4	main
iseloom	doc_432051777898_item	2402667	et	3	main
punktuaalne	doc_432051777898_item	2402672	et	4	main
vaid	doc_432051777898_item	2402703	et	3	main
me	doc_432051777898_item	2402704	et	4	main
seda	doc_432051777898_item	2402705	et	3	main
span	doc_432051777898_item	2402715	et	4	main
viimaseks	doc_432051777898_item	2402716	et	3	main
räägiksin	doc_432051777898_item	2402717	et	3	main
ajast	doc_432051777898_item	2402719	et	4	main
ajani	doc_432051777898_item	2402720	et	3	main
meie	doc_432051777898_item	2402724	et	4	main
elame	doc_432051777898_item	2402729	et	3	main
tulevikut	doc_432051777898_item	2402731	et	4	main
näiteks	doc_432051777898_item	2402737	et	4	main
lähed	doc_432051777898_item	2402738	et	3	main
autol	doc_432051777898_item	2402742	et	3	main
katki	doc_432051777898_item	2402745	et	4	main
esimene	doc_432051777896_item	2402522	et	3	main
kursusele	doc_432051777896_item	2402528	et	3	main
saada	doc_432051777896_item	2402535	et	4	main
mul	doc_432051777896_item	2402536	et	3	main
on	doc_432051777896_item	2402537	et	4	main
vaja	doc_432051777896_item	2402540	et	4	main
ma	doc_432051777896_item	2402545	et	3	main
ma	doc_432051777896_item	2402560	et	3	main
kardan	doc_432051777896_item	2402570	et	4	main
jaoks	doc_432051777896_item	2402577	et	4	main
et	doc_432051777896_item	2402586	et	3	main
kirjutasin	doc_432051777896_item	2402587	et	3	main
xxxxxxxxx	doc_432051777896_item	2402592	et	4	main
nimi	doc_432051777897_item	2402597	et	3	main
keel	doc_432051777897_item	2402625	et	4	main
dokument	doc_432051777898_item	2402633	et	3	main
arvates	doc_432051777898_item	2402641	et	4	main
meie	doc_432051777898_item	2402642	et	4	main
ma	doc_432051777898_item	2402650	et	3	main
et	doc_432051777898_item	2402653	et	3	main
kes	doc_432051777898_item	2402657	et	4	main
elavad	doc_432051777898_item	2402658	et	4	main
heatahtlik	doc_432051777898_item	2402670	et	3	main
on	doc_432051777898_item	2402675	et	4	main
kergem	doc_432051777898_item	2402676	et	4	main
mis	doc_432051777898_item	2402700	et	4	main
meid	doc_432051777898_item	2402701	et	4	main
mõjutab	doc_432051777898_item	2402702	et	3	main
ei	doc_432051777898_item	2402709	et	4	main
juhusest	doc_432051777898_item	2402718	et	4	main
ma	doc_432051777897_item	2402627	et	3	main
õpida	doc_432051777897_item	2402629	et	4	main
mõjutab	doc_432051777898_item	2402635	et	3	main
elu	doc_432051777898_item	2402637	et	4	main
span	doc_432051777898_item	2402638	et	4	main
span	doc_432051777898_item	2402639	et	4	main
minu	doc_432051777898_item	2402640	et	3	main
tegurid	doc_432051777898_item	2402646	et	3	main
kõigepealt	doc_432051777898_item	2402647	et	3	main
meie	doc_432051777898_item	2402648	et	4	main
meie	doc_432051777898_item	2402659	et	4	main
kõrval	doc_432051777898_item	2402660	et	4	main
span	doc_432051777898_item	2402661	et	4	main
teine	doc_432051777898_item	2402662	et	3	main
tähtis	doc_432051777898_item	2402663	et	4	main
tegur	doc_432051777898_item	2402664	et	3	main
on	doc_432051777898_item	2402665	et	4	main
oled	doc_432051777898_item	2402669	et	3	main
elada	doc_432051777898_item	2402674	et	3	main
pahatahtliku	doc_432051777898_item	2402679	et	3	main
ja	doc_432051777898_item	2402680	et	3	main
ebatäpse	doc_432051777898_item	2402681	et	3	main
iseloomuga	doc_432051777898_item	2402682	et	3	main
elu	doc_432051777898_item	2402683	et	4	main
on	doc_432051777898_item	2402684	et	4	main
väga	doc_432051777898_item	2402685	et	3	main
raske	doc_432051777898_item	2402686	et	4	main
span	doc_432051777898_item	2402687	et	4	main
kolmandale	doc_432051777898_item	2402688	et	3	main
kohale	doc_432051777898_item	2402689	et	4	main
ma	doc_432051777898_item	2402690	et	3	main
paneksin	doc_432051777898_item	2402691	et	3	main
elukohta	doc_432051777898_item	2402692	et	4	main
ma	doc_432051777898_item	2402693	et	3	main
arvan	doc_432051777898_item	2402694	et	3	main
elukoht	doc_432051777898_item	2402696	et	3	main
et	doc_432051777898_item	2402695	et	3	main
on	doc_432051777898_item	2402697	et	4	main
niisugune	doc_432051777898_item	2402698	et	3	main
tegur	doc_432051777898_item	2402699	et	3	main
inimene	doc_432051777898_item	2402707	et	3	main
vali	doc_432051777898_item	2402710	et	4	main
elukohta	doc_432051777898_item	2402712	et	4	main
ning	doc_432051777898_item	2402713	et	3	main
sünnikohta	doc_432051777898_item	2402714	et	4	main
me	doc_432051777898_item	2402728	et	4	main
ei	doc_432051777898_item	2402733	et	4	main
tea	doc_432051777898_item	2402734	et	4	main
üle	doc_432051777898_item	2402739	et	3	main
pidur	doc_432051777898_item	2402743	et	3	main
mida	doc_432051777898_item	2402756	et	4	main
xxxxxxxx	doc_432051777899_item	2402770	et	4	main
õppinud	doc_432051777899_item	2402797	et	4	main
kümme	doc_432051777899_item	2402799	et	3	main
põhjus	doc_432051777899_item	2402807	et	4	main
miks	doc_432051777899_item	2402808	et	4	main
tulin	doc_432051777899_item	2402809	et	3	main
sellele	doc_432051777899_item	2402810	et	4	main
kursusele	doc_432051777899_item	2402811	et	3	main
soovitus	doc_432051777899_item	2402814	et	4	main
teine	doc_432051777899_item	2402816	et	3	main
mul	doc_432051777899_item	2402823	et	3	main
eesti	doc_432051777899_item	2402825	et	4	main
keelt	doc_432051777899_item	2402826	et	4	main
vaja	doc_432051777899_item	2402833	et	4	main
eesti	doc_432051777899_item	2402834	et	4	main
raamatuid	doc_432051777899_item	2402847	et	3	main
et	doc_432051777899_item	2402850	et	3	main
sest	doc_432051777899_item	2402860	et	4	main
see	doc_432051777899_item	2402861	et	3	main
on	doc_432051777899_item	2402862	et	4	main
väga	doc_432051777899_item	2402863	et	3	main
ma	doc_432051777899_item	2402867	et	3	main
sest	doc_432051777899_item	2402875	et	4	main
tahaksin	doc_432051777899_item	2402880	et	3	main
veel	doc_432051777899_item	2402886	et	4	main
abistada	doc_432051777899_item	2402898	et	3	main
õpetaja	doc_432051777901_item	2403023	et	4	main
nimi	doc_432051777901_item	2403025	et	3	main
xxxxxx	doc_432051777901_item	2403027	et	4	main
eesti	doc_432051777901_item	2403049	et	4	main
aastat	doc_432051777901_item	2403054	et	3	main
miks	doc_432051777901_item	2403063	et	4	main
tulin	doc_432051777901_item	2403064	et	3	main
sellele	doc_432051777901_item	2403065	et	4	main
kursusele	doc_432051777901_item	2403066	et	3	main
teine	doc_432051777901_item	2403072	et	3	main
vene	doc_432051777901_item	2403077	et	4	main
keeles	doc_432051777901_item	2403078	et	4	main
mul	doc_432051777901_item	2403079	et	3	main
ma	doc_432051777901_item	2403091	et	3	main
ja	doc_432051777901_item	2403094	et	3	main
et	doc_432051777901_item	2403121	et	3	main
mõtlen	doc_432051777898_item	2402722	et	3	main
juhus	doc_432051777898_item	2402727	et	4	main
planeerime	doc_432051777898_item	2402730	et	3	main
midagi	doc_432051777898_item	2402735	et	4	main
homsest	doc_432051777898_item	2402736	et	3	main
tee	doc_432051777898_item	2402740	et	4	main
ja	doc_432051777898_item	2402746	et	3	main
mõjutada	doc_432051777898_item	2402757	et	3	main
uus	doc_432051777899_item	2402762	et	3	main
olen	doc_432051777899_item	2402771	et	3	main
kaheksateist	doc_432051777899_item	2402772	et	4	main
aastat	doc_432051777899_item	2402773	et	3	main
vana	doc_432051777899_item	2402774	et	4	main
kõige	doc_432051777899_item	2402775	et	4	main
tähtsam	doc_432051777899_item	2402776	et	4	main
minu	doc_432051777899_item	2402777	et	3	main
elus	doc_432051777899_item	2402778	et	4	main
on	doc_432051777899_item	2402779	et	4	main
õppimine	doc_432051777899_item	2402780	et	4	main
ja	doc_432051777899_item	2402781	et	3	main
perekond	doc_432051777899_item	2402782	et	3	main
ma	doc_432051777899_item	2402783	et	3	main
armastan	doc_432051777899_item	2402784	et	3	main
jalutada	doc_432051777899_item	2402785	et	3	main
pargis	doc_432051777899_item	2402786	et	3	main
koos	doc_432051777899_item	2402787	et	4	main
käia	doc_432051777899_item	2402789	et	4	main
tööle	doc_432051777899_item	2402790	et	3	main
sõpradega	doc_432051777899_item	2402788	et	3	main
tegeleda	doc_432051777899_item	2402791	et	3	main
spordiga	doc_432051777899_item	2402792	et	3	main
jne	doc_432051777899_item	2402793	et	4	main
eesti	doc_432051777899_item	2402794	et	4	main
keelt	doc_432051777899_item	2402795	et	4	main
olen	doc_432051777899_item	2402796	et	3	main
kõik	doc_432051777898_item	2402747	et	4	main
span	doc_432051777898_item	2402748	et	4	main
aga	doc_432051777898_item	2402752	et	3	main
niisugune	doc_432051777898_item	2402753	et	3	main
on	doc_432051777898_item	2402754	et	4	main
me	doc_432051777898_item	2402758	et	4	main
span	doc_432051777898_item	2402761	et	4	main
dokument	doc_432051777899_item	2402763	et	3	main
nimi	doc_432051777899_item	2402767	et	3	main
on	doc_432051777899_item	2402768	et	4	main
varem	doc_432051777899_item	2402801	et	4	main
olen	doc_432051777899_item	2402802	et	3	main
õppinud	doc_432051777899_item	2402803	et	4	main
õppida	doc_432051777899_item	2402815	et	3	main
põhjus	doc_432051777899_item	2402817	et	4	main
saada	doc_432051777899_item	2402819	et	4	main
kõrgharidust	doc_432051777899_item	2402822	et	4	main
et	doc_432051777899_item	2402828	et	3	main
keelt	doc_432051777899_item	2402835	et	4	main
oma	doc_432051777899_item	2402846	et	4	main
põhjalikult	doc_432051777899_item	2402853	et	4	main
natuke	doc_432051777899_item	2402869	et	4	main
et	doc_432051777899_item	2402870	et	3	main
ei	doc_432051777899_item	2402871	et	4	main
inglismaale	doc_432051777899_item	2402878	et	4	main
ma	doc_432051777899_item	2402879	et	3	main
kus	doc_432051777899_item	2402882	et	3	main
tahaksin	doc_432051777899_item	2402887	et	3	main
saate	doc_432051777899_item	2402897	et	4	main
minu	doc_432051777901_item	2403024	et	3	main
minu	doc_432051777901_item	2403035	et	3	main
ma	doc_432051777901_item	2403043	et	3	main
veetma	doc_432051777901_item	2403045	et	3	main
sugulastega	doc_432051777901_item	2403048	et	4	main
kaheksa	doc_432051777901_item	2403053	et	4	main
õppinud	doc_432051777901_item	2403057	et	4	main
narva	doc_432051777901_item	2403058	et	4	main
soldino	doc_432051777901_item	2403059	et	4	main
gümnaasiumis	doc_432051777901_item	2403060	et	3	main
esimene	doc_432051777901_item	2403061	et	3	main
põhjus	doc_432051777901_item	2403062	et	4	main
mulle	doc_432051777901_item	2403068	et	4	main
meeldib	doc_432051777901_item	2403069	et	3	main
vaja	doc_432051777901_item	2403083	et	4	main
et	doc_432051777901_item	2403084	et	3	main
lugeda	doc_432051777901_item	2403085	et	3	main
erinevaid	doc_432051777901_item	2403086	et	4	main
tahan	doc_432051777901_item	2403092	et	3	main
uus	doc_432051777902_item	2403122	et	3	main
pere	doc_432051777902_item	2403141	et	4	main
ma	doc_432051777902_item	2403144	et	3	main
armastan	doc_432051777902_item	2403145	et	3	main
spordi	doc_432051777902_item	2403149	et	4	main
lugeda	doc_432051777902_item	2403150	et	3	main
aastat	doc_432051777902_item	2403157	et	3	main
on	doc_432051777902_item	2403175	et	4	main
eesti	doc_432051777902_item	2403182	et	4	main
olen	doc_432051777903_item	2403194	et	3	main
armastus	doc_432051777903_item	2403203	et	4	main
ma	doc_432051777903_item	2403204	et	3	main
armastan	doc_432051777903_item	2403205	et	3	main
10	doc_432051777903_item	2403211	et	2	main
kursusele	doc_432051777903_item	2403218	et	3	main
eesti	doc_432051777903_item	2403227	et	4	main
umbes	doc_432051777899_item	2402798	et	4	main
aastat	doc_432051777899_item	2402800	et	3	main
on	doc_432051777899_item	2402818	et	4	main
eriala	doc_432051777899_item	2402820	et	4	main
lugeda	doc_432051777899_item	2402829	et	3	main
mul	doc_432051777899_item	2402831	et	3	main
raadiot	doc_432051777899_item	2402839	et	3	main
eesti	doc_432051777899_item	2402841	et	4	main
ma	doc_432051777899_item	2402848	et	3	main
me	doc_432051777899_item	2402851	et	4	main
minu	doc_432051777899_item	2402865	et	3	main
sõitma	doc_432051777899_item	2402877	et	3	main
te	doc_432051777899_item	2402883	et	4	main
teada	doc_432051777899_item	2402888	et	3	main
mõtlete	doc_432051777899_item	2402891	et	3	main
meie	doc_432051777899_item	2402892	et	4	main
tehnikumist	doc_432051777899_item	2402893	et	4	main
loodan	doc_432051777899_item	2402894	et	3	main
et	doc_432051777899_item	2402895	et	3	main
te	doc_432051777899_item	2402896	et	4	main
eesti	doc_432051777899_item	2402899	et	4	main
keelt	doc_432051777899_item	2402900	et	4	main
ära	doc_432051777899_item	2402901	et	4	main
õppima	doc_432051777899_item	2402902	et	3	main
lugupidamisega	doc_432051777899_item	2402903	et	3	main
xxxxxx	doc_432051777899_item	2402904	et	4	main
kuulata	doc_432051777899_item	2402838	et	4	main
vaadata	doc_432051777899_item	2402843	et	4	main
telerit	doc_432051777899_item	2402844	et	3	main
kirjutada	doc_432051777899_item	2402845	et	3	main
tegeleme	doc_432051777899_item	2402852	et	3	main
eesti	doc_432051777899_item	2402854	et	4	main
tundis	doc_432051777899_item	2402855	et	3	main
grammatikaga	doc_432051777899_item	2402856	et	3	main
kuulamisega	doc_432051777899_item	2402857	et	4	main
ja	doc_432051777899_item	2402858	et	3	main
jaoks	doc_432051777899_item	2402866	et	4	main
kardan	doc_432051777899_item	2402868	et	4	main
saa	doc_432051777899_item	2402872	et	4	main
lõpetada	doc_432051777899_item	2402873	et	3	main
pean	doc_432051777899_item	2402876	et	4	main
olete	doc_432051777899_item	2402884	et	3	main
mida	doc_432051777899_item	2402889	et	4	main
te	doc_432051777899_item	2402890	et	4	main
dokument	doc_432051777901_item	2403021	et	3	main
xxxxxxx	doc_432051777901_item	2403028	et	4	main
olen	doc_432051777901_item	2403029	et	3	main
vana	doc_432051777901_item	2403032	et	4	main
kõige	doc_432051777901_item	2403033	et	4	main
tähtsam	doc_432051777901_item	2403034	et	4	main
on	doc_432051777901_item	2403037	et	4	main
pere	doc_432051777901_item	2403039	et	4	main
vanemad	doc_432051777901_item	2403041	et	4	main
armastan	doc_432051777901_item	2403044	et	3	main
õppinud	doc_432051777901_item	2403052	et	4	main
on	doc_432051777901_item	2403067	et	4	main
minu	doc_432051777901_item	2403070	et	3	main
on	doc_432051777901_item	2403074	et	4	main
käib	doc_432051777901_item	2403076	et	3	main
eesti	doc_432051777901_item	2403089	et	4	main
uus	doc_432051777901_item	2403020	et	3	main
elus	doc_432051777901_item	2403036	et	4	main
minu	doc_432051777901_item	2403038	et	3	main
minu	doc_432051777901_item	2403040	et	3	main
sugulased	doc_432051777901_item	2403042	et	3	main
aja	doc_432051777901_item	2403046	et	4	main
minu	doc_432051777901_item	2403047	et	3	main
varem	doc_432051777901_item	2403055	et	4	main
olen	doc_432051777901_item	2403056	et	3	main
põhjus	doc_432051777901_item	2403073	et	4	main
õppimine	doc_432051777901_item	2403075	et	4	main
eesti	doc_432051777901_item	2403081	et	4	main
keelt	doc_432051777901_item	2403082	et	4	main
kirjandus	doc_432051777901_item	2403090	et	3	main
minu	doc_432051777902_item	2403126	et	3	main
nimi	doc_432051777902_item	2403127	et	3	main
xxxxxx	doc_432051777902_item	2403129	et	4	main
xxxxxxxx	doc_432051777902_item	2403130	et	4	main
olen	doc_432051777902_item	2403131	et	3	main
19	doc_432051777902_item	2403132	et	2	main
aastat	doc_432051777902_item	2403133	et	3	main
vana	doc_432051777902_item	2403134	et	4	main
on	doc_432051777902_item	2403139	et	4	main
õde	doc_432051777902_item	2403143	et	4	main
kuulada	doc_432051777902_item	2403146	et	4	main
muusikat	doc_432051777902_item	2403147	et	3	main
tegeleda	doc_432051777902_item	2403148	et	3	main
raamatud	doc_432051777902_item	2403151	et	4	main
varem	doc_432051777902_item	2403158	et	4	main
vene	doc_432051777902_item	2403178	et	4	main
mul	doc_432051777902_item	2403180	et	3	main
xxxxxxxxxx	doc_432051777903_item	2403193	et	4	main
21	doc_432051777903_item	2403195	et	2	main
tähtsam	doc_432051777903_item	2403199	et	4	main
armastada	doc_432051777903_item	2403206	et	3	main
õppinud	doc_432051777903_item	2403210	et	4	main
esimene	doc_432051777903_item	2403213	et	3	main
miks	doc_432051777903_item	2403215	et	4	main
on	doc_432051777903_item	2403219	et	4	main
teine	doc_432051777903_item	2403221	et	3	main
vaja	doc_432051777903_item	2403229	et	4	main
et	doc_432051777903_item	2403230	et	3	main
lugeda	doc_432051777903_item	2403231	et	3	main
suhtlemise	doc_432051777903_item	2403240	et	4	main
oskused	doc_432051777903_item	2403241	et	3	main
ükskõik	doc_432051777903_item	2403247	et	3	main
ma	doc_432051777903_item	2403257	et	3	main
loodan	doc_432051777903_item	2403258	et	3	main
et	doc_432051777903_item	2403259	et	3	main
me	doc_432051777903_item	2403260	et	4	main
tegeleme	doc_432051777903_item	2403261	et	3	main
ei	doc_432051777903_item	2403269	et	4	main
erialast	doc_432051777903_item	2403276	et	4	main
tere	doc_432051777901_item	2403022	et	3	main
on	doc_432051777901_item	2403026	et	4	main
19	doc_432051777901_item	2403030	et	2	main
aastat	doc_432051777901_item	2403031	et	3	main
keel	doc_432051777901_item	2403050	et	4	main
olen	doc_432051777901_item	2403051	et	3	main
eri	doc_432051777901_item	2403071	et	4	main
on	doc_432051777901_item	2403080	et	4	main
tekste	doc_432051777901_item	2403087	et	3	main
ajalehed	doc_432051777901_item	2403088	et	3	main
kuulata	doc_432051777901_item	2403093	et	4	main
räägida	doc_432051777901_item	2403095	et	4	main
estlastega	doc_432051777901_item	2403096	et	4	main
töötada	doc_432051777901_item	2403097	et	3	main
eestlastega	doc_432051777901_item	2403098	et	4	main
probleemita	doc_432051777901_item	2403099	et	3	main
ma	doc_432051777901_item	2403100	et	3	main
loodan	doc_432051777901_item	2403101	et	3	main
et	doc_432051777901_item	2403102	et	3	main
me	doc_432051777901_item	2403103	et	4	main
tegeleme	doc_432051777901_item	2403104	et	3	main
põhjalikult	doc_432051777901_item	2403105	et	4	main
räägida	doc_432051777901_item	2403106	et	4	main
sest	doc_432051777901_item	2403107	et	4	main
ma	doc_432051777901_item	2403108	et	3	main
arvan	doc_432051777901_item	2403109	et	3	main
et	doc_432051777901_item	2403110	et	3	main
oskamine	doc_432051777901_item	2403111	et	4	main
on	doc_432051777901_item	2403113	et	4	main
suhtlema	doc_432051777901_item	2403112	et	3	main
oluliseim	doc_432051777901_item	2403114	et	4	main
kui	doc_432051777901_item	2403115	et	3	main
teoreetiline	doc_432051777901_item	2403116	et	3	main
teadmiseid	doc_432051777901_item	2403117	et	4	main
ma	doc_432051777901_item	2403118	et	3	main
kardan	doc_432051777901_item	2403119	et	4	main
natuke	doc_432051777901_item	2403120	et	4	main
tere	doc_432051777902_item	2403124	et	3	main
minu	doc_432051777902_item	2403140	et	3	main
keelt	doc_432051777902_item	2403153	et	4	main
olen	doc_432051777902_item	2403154	et	3	main
õppimine	doc_432051777902_item	2403176	et	4	main
nimi	doc_432051777903_item	2403191	et	3	main
on	doc_432051777903_item	2403202	et	4	main
olen	doc_432051777903_item	2403209	et	3	main
aastat	doc_432051777903_item	2403212	et	3	main
põhjus	doc_432051777903_item	2403214	et	4	main
tekste	doc_432051777903_item	2403233	et	3	main
vaja	doc_432051777903_item	2403236	et	4	main
eesti	doc_432051777903_item	2403238	et	4	main
keele	doc_432051777903_item	2403239	et	4	main
tahan	doc_432051777903_item	2403243	et	3	main
ükskõik	doc_432051777903_item	2403245	et	3	main
mul	doc_432051777903_item	2403249	et	3	main
hea	doc_432051777903_item	2403253	et	4	main
kardan	doc_432051777903_item	2403265	et	4	main
natuke	doc_432051777903_item	2403266	et	4	main
õpetaja	doc_432051777902_item	2403125	et	4	main
kõige	doc_432051777902_item	2403135	et	4	main
tähtsam	doc_432051777902_item	2403136	et	4	main
vanemad	doc_432051777902_item	2403142	et	4	main
õppinud	doc_432051777902_item	2403155	et	4	main
8	doc_432051777902_item	2403156	et	2	main
õppinud	doc_432051777902_item	2403160	et	4	main
narva	doc_432051777902_item	2403161	et	4	main
esimene	doc_432051777902_item	2403163	et	3	main
põhjus	doc_432051777902_item	2403164	et	4	main
kutseõppekeskuses	doc_432051777902_item	2403162	et	4	main
miks	doc_432051777902_item	2403165	et	4	main
tulin	doc_432051777902_item	2403166	et	3	main
sellele	doc_432051777902_item	2403167	et	4	main
kursusele	doc_432051777902_item	2403168	et	3	main
on	doc_432051777902_item	2403169	et	4	main
mulle	doc_432051777902_item	2403170	et	4	main
minu	doc_432051777902_item	2403171	et	3	main
eri	doc_432051777902_item	2403172	et	4	main
teine	doc_432051777902_item	2403173	et	3	main
põhjus	doc_432051777902_item	2403174	et	4	main
dokument	doc_432051777902_item	2403123	et	3	main
on	doc_432051777902_item	2403128	et	4	main
minu	doc_432051777902_item	2403137	et	3	main
elus	doc_432051777902_item	2403138	et	4	main
eesti	doc_432051777902_item	2403152	et	4	main
olen	doc_432051777902_item	2403159	et	3	main
keeles	doc_432051777902_item	2403179	et	4	main
dokument	doc_432051777903_item	2403189	et	3	main
minu	doc_432051777903_item	2403190	et	3	main
vana	doc_432051777903_item	2403197	et	4	main
keelt	doc_432051777903_item	2403208	et	4	main
tulin	doc_432051777903_item	2403216	et	3	main
soovitus	doc_432051777903_item	2403220	et	4	main
saada	doc_432051777903_item	2403223	et	4	main
eriala	doc_432051777903_item	2403224	et	4	main
mul	doc_432051777903_item	2403225	et	3	main
on	doc_432051777903_item	2403226	et	4	main
erinevaid	doc_432051777903_item	2403232	et	4	main
vaja	doc_432051777903_item	2403251	et	4	main
jõua	doc_432051777903_item	2403270	et	4	main
teada	doc_432051777903_item	2403273	et	3	main
käib	doc_432051777902_item	2403177	et	3	main
on	doc_432051777902_item	2403181	et	4	main
keelt	doc_432051777902_item	2403183	et	4	main
vaja	doc_432051777902_item	2403184	et	4	main
et	doc_432051777902_item	2403185	et	3	main
lugeda	doc_432051777902_item	2403186	et	3	main
ajalehed	doc_432051777902_item	2403187	et	3	main
uus	doc_432051777903_item	2403188	et	3	main
on	doc_432051777903_item	2403192	et	4	main
aastat	doc_432051777903_item	2403196	et	3	main
kõige	doc_432051777903_item	2403198	et	4	main
minu	doc_432051777903_item	2403200	et	3	main
elus	doc_432051777903_item	2403201	et	4	main
eesti	doc_432051777903_item	2403207	et	4	main
sellele	doc_432051777903_item	2403217	et	4	main
põhjus	doc_432051777903_item	2403222	et	4	main
on	doc_432051777903_item	2403235	et	4	main
hea	doc_432051777903_item	2403237	et	4	main
on	doc_432051777903_item	2403250	et	4	main
ka	doc_432051777903_item	2403252	et	3	main
eesti	doc_432051777903_item	2403254	et	4	main
keele	doc_432051777903_item	2403255	et	4	main
kirjutamisoskused	doc_432051777903_item	2403256	et	3	main
me	doc_432051777903_item	2403268	et	4	main
kõik	doc_432051777903_item	2403274	et	4	main
keelt	doc_432051777903_item	2403228	et	4	main
mul	doc_432051777903_item	2403234	et	3	main
ma	doc_432051777903_item	2403242	et	3	main
rääkida	doc_432051777903_item	2403244	et	3	main
inimestega	doc_432051777903_item	2403246	et	3	main
olukordades	doc_432051777903_item	2403248	et	3	main
põhjalikult	doc_432051777903_item	2403262	et	4	main
sellega	doc_432051777903_item	2403263	et	3	main
ma	doc_432051777903_item	2403264	et	3	main
ma	doc_432051777903_item	2403271	et	3	main
tahaksin	doc_432051777903_item	2403272	et	3	main
rokkmuusika	doc_432051777905_item	2403413	et	4	main
ta	doc_432051777905_item	2403422	et	4	main
rokkstaar	doc_432051777905_item	2403424	et	3	main
keelt	doc_432051777905_item	2403431	et	4	main
olen	doc_432051777905_item	2403432	et	3	main
õppinud	doc_432051777905_item	2403433	et	4	main
miks	doc_432051777905_item	2403443	et	4	main
ei	doc_432051777905_item	2403451	et	4	main
et	doc_432051777905_item	2403461	et	3	main
kohtla-jarve	doc_432051777905_item	2403462	et	4	main
hea	doc_432051777905_item	2403465	et	4	main
on	doc_432051777905_item	2403473	et	4	main
lugeda	doc_432051777905_item	2403478	et	3	main
ma	doc_432051777905_item	2403485	et	3	main
raske	doc_432051777906_item	2403522	et	4	main
elada	doc_432051777906_item	2403523	et	3	main
iga	doc_432051777906_item	2403535	et	4	main
peab	doc_432051777906_item	2403537	et	4	main
lootma	doc_432051777906_item	2403538	et	3	main
iseendast	doc_432051777906_item	2403539	et	3	main
kõik	doc_432051777906_item	2403540	et	4	main
inimest	doc_432051777906_item	2403542	et	3	main
sõbrad	doc_432051777906_item	2403544	et	3	main
me	doc_432051777906_item	2403551	et	4	main
ja	doc_432051777906_item	2403566	et	3	main
läheb	doc_432051777906_item	2403572	et	3	main
elus	doc_432051777906_item	2403573	et	4	main
hästi	doc_432051777906_item	2403574	et	3	main
sest	doc_432051777906_item	2403575	et	4	main
arvan	doc_432051777906_item	2403576	et	3	main
et	doc_432051777906_item	2403577	et	3	main
see	doc_432051777906_item	2403578	et	3	main
span	doc_432051777906_item	2403583	et	4	main
elukohast	doc_432051777906_item	2403588	et	4	main
majas	doc_432051777906_item	2403591	et	3	main
riigis	doc_432051777906_item	2403592	et	3	main
me	doc_432051777906_item	2403593	et	4	main
elame	doc_432051777906_item	2403594	et	3	main
kui	doc_432051777906_item	2403595	et	3	main
riigis	doc_432051777906_item	2403596	et	3	main
seisukord	doc_432051777906_item	2403599	et	3	main
võimalust	doc_432051777906_item	2403621	et	3	main
meie	doc_432051777906_item	2403627	et	4	main
need	doc_432051777907_item	2403639	et	3	main
keskkond	doc_432051777907_item	2403644	et	3	main
raha	doc_432051777907_item	2403653	et	4	main
inimene	doc_432051777907_item	2403681	et	3	main
ebanormaalses	doc_432051777907_item	2403683	et	3	main
degradeerib	doc_432051777907_item	2403687	et	3	main
mõju	doc_432051777907_item	2403691	et	4	main
üks	doc_432051777907_item	2403694	et	3	main
vaja	doc_432051777907_item	2403698	et	4	main
edasi	doc_432051777907_item	2403701	et	3	main
haridus	doc_432051777907_item	2403710	et	3	main
ei	doc_432051777907_item	2403713	et	4	main
leida	doc_432051777907_item	2403715	et	3	main
mõtlen	doc_432051777907_item	2403728	et	3	main
inimesed	doc_432051777907_item	2403731	et	3	main
neil	doc_432051777907_item	2403734	et	4	main
oleks	doc_432051777907_item	2403735	et	3	main
kõrgharidus	doc_432051777907_item	2403736	et	3	main
et	doc_432051777907_item	2403737	et	3	main
kõigel	doc_432051777907_item	2403738	et	4	main
oleks	doc_432051777907_item	2403739	et	3	main
et	doc_432051777903_item	2403267	et	3	main
oma	doc_432051777903_item	2403275	et	4	main
vene	doc_432051777905_item	2403412	et	4	main
ühest	doc_432051777905_item	2403420	et	4	main
uus	doc_432051777905_item	2403387	et	3	main
dokument	doc_432051777905_item	2403388	et	3	main
tere	doc_432051777905_item	2403389	et	3	main
õpetaja	doc_432051777905_item	2403390	et	4	main
minu	doc_432051777905_item	2403391	et	3	main
nimi	doc_432051777905_item	2403392	et	3	main
on	doc_432051777905_item	2403393	et	4	main
xxxxx	doc_432051777905_item	2403394	et	4	main
xxxxxxxxxxxxx	doc_432051777905_item	2403395	et	4	main
olen	doc_432051777905_item	2403396	et	3	main
20	doc_432051777905_item	2403397	et	2	main
aastat	doc_432051777905_item	2403398	et	3	main
vana	doc_432051777905_item	2403399	et	4	main
kõige	doc_432051777905_item	2403400	et	4	main
tähtsam	doc_432051777905_item	2403401	et	4	main
minu	doc_432051777905_item	2403402	et	3	main
elus	doc_432051777905_item	2403403	et	4	main
on	doc_432051777905_item	2403404	et	4	main
minu	doc_432051777905_item	2403405	et	3	main
armastus	doc_432051777905_item	2403406	et	4	main
ma	doc_432051777905_item	2403407	et	3	main
armastan	doc_432051777905_item	2403408	et	3	main
kõige	doc_432051777905_item	2403409	et	4	main
veel	doc_432051777905_item	2403415	et	4	main
nimi	doc_432051777905_item	2403427	et	3	main
aastat	doc_432051777905_item	2403436	et	3	main
olen	doc_432051777905_item	2403438	et	3	main
koolis	doc_432051777905_item	2403440	et	4	main
esimene	doc_432051777905_item	2403441	et	3	main
põhjus	doc_432051777905_item	2403442	et	4	main
ma	doc_432051777905_item	2403450	et	3	main
ülikooli	doc_432051777905_item	2403456	et	4	main
meeldib	doc_432051777905_item	2403469	et	3	main
et	doc_432051777905_item	2403477	et	3	main
ja	doc_432051777905_item	2403482	et	3	main
on	doc_432051777906_item	2403521	et	4	main
meie	doc_432051777906_item	2403524	et	4	main
elus	doc_432051777906_item	2403525	et	4	main
praegu	doc_432051777906_item	2403526	et	3	main
inimene	doc_432051777906_item	2403527	et	3	main
olema	doc_432051777906_item	2403529	et	4	main
aktiivsena	doc_432051777906_item	2403530	et	3	main
span	doc_432051777906_item	2403543	et	4	main
mõjutavad	doc_432051777906_item	2403546	et	4	main
inimese	doc_432051777906_item	2403547	et	4	main
käitumine	doc_432051777906_item	2403554	et	4	main
kõik	doc_432051777906_item	2403558	et	4	main
sõltub	doc_432051777906_item	2403559	et	3	main
on	doc_432051777906_item	2403568	et	4	main
kõige	doc_432051777906_item	2403580	et	4	main
elus	doc_432051777906_item	2403582	et	4	main
meie	doc_432051777906_item	2403585	et	4	main
halb	doc_432051777906_item	2403598	et	3	main
kõik	doc_432051777906_item	2403601	et	4	main
aga	doc_432051777906_item	2403623	et	3	main
dokument	doc_432051777907_item	2403633	et	3	main
on	doc_432051777907_item	2403641	et	4	main
võimalused	doc_432051777907_item	2403658	et	3	main
keskkonnas	doc_432051777907_item	2403684	et	3	main
halva	doc_432051777907_item	2403690	et	4	main
mis	doc_432051777907_item	2403696	et	4	main
saa	doc_432051777907_item	2403714	et	4	main
hea	doc_432051777907_item	2403716	et	4	main
tööd	doc_432051777907_item	2403717	et	4	main
haridus	doc_432051777907_item	2403718	et	3	main
see	doc_432051777907_item	2403719	et	3	main
vajab	doc_432051777907_item	2403724	et	3	main
peavad	doc_432051777907_item	2403732	et	4	main
elu	doc_432051777907_item	2403742	et	4	main
dokument	doc_432051777908_item	2403757	et	3	main
oma	doc_432051777908_item	2403767	et	4	main
elu	doc_432051777908_item	2403773	et	4	main
asi	doc_432051777908_item	2403785	et	4	main
elu	doc_432051777908_item	2403800	et	4	main
kellega	doc_432051777908_item	2403802	et	3	main
nad	doc_432051777908_item	2403808	et	3	main
head	doc_432051777908_item	2403818	et	4	main
pahaks	doc_432051777908_item	2403824	et	4	main
ka	doc_432051777908_item	2403832	et	3	main
see	doc_432051777908_item	2403837	et	3	main
ta	doc_432051777908_item	2403840	et	4	main
span	doc_432051777909_item	2403853	et	4	main
inimese	doc_432051777909_item	2403857	et	4	main
elus	doc_432051777909_item	2403858	et	4	main
pealt	doc_432051777909_item	2403863	et	4	main
kui	doc_432051777909_item	2403868	et	3	main
näiteks	doc_432051777909_item	2403870	et	4	main
hea	doc_432051777909_item	2403872	et	4	main
soovist	doc_432051777909_item	2403897	et	4	main
kui	doc_432051777909_item	2403898	et	3	main
inimene	doc_432051777909_item	2403899	et	3	main
pealt	doc_432051777905_item	2403410	et	4	main
kuulada	doc_432051777905_item	2403411	et	4	main
vääga	doc_432051777905_item	2403417	et	4	main
vääga	doc_432051777905_item	2403418	et	4	main
armastan	doc_432051777905_item	2403419	et	3	main
neiust	doc_432051777905_item	2403421	et	4	main
on	doc_432051777905_item	2403423	et	4	main
ja	doc_432051777905_item	2403425	et	3	main
tema	doc_432051777905_item	2403426	et	4	main
on	doc_432051777905_item	2403428	et	4	main
juba	doc_432051777905_item	2403434	et	3	main
varem	doc_432051777905_item	2403437	et	4	main
sellele	doc_432051777905_item	2403445	et	4	main
astuma	doc_432051777905_item	2403454	et	3	main
sankt-peterburi	doc_432051777905_item	2403455	et	4	main
teine	doc_432051777905_item	2403457	et	3	main
see	doc_432051777905_item	2403460	et	3	main
keelt	doc_432051777905_item	2403475	et	4	main
anekdootid	doc_432051777905_item	2403480	et	4	main
siis	doc_432051777906_item	2403519	et	3	main
temal	doc_432051777906_item	2403520	et	3	main
ta	doc_432051777906_item	2403531	et	4	main
sõltub	doc_432051777906_item	2403541	et	3	main
elu	doc_432051777906_item	2403548	et	4	main
nendega	doc_432051777906_item	2403553	et	4	main
harjumus	doc_432051777906_item	2403555	et	4	main
iseloom	doc_432051777906_item	2403556	et	3	main
need	doc_432051777906_item	2403557	et	3	main
sõbrad	doc_432051777906_item	2403565	et	3	main
siis	doc_432051777906_item	2403570	et	3	main
tähtsaim	doc_432051777906_item	2403581	et	4	main
elu	doc_432051777906_item	2403586	et	4	main
on	doc_432051777906_item	2403597	et	4	main
siis	doc_432051777906_item	2403600	et	3	main
muutub	doc_432051777906_item	2403602	et	3	main
ja	doc_432051777905_item	2403414	et	3	main
ma	doc_432051777905_item	2403416	et	3	main
õppinud	doc_432051777905_item	2403439	et	4	main
kursusele	doc_432051777905_item	2403446	et	3	main
saa	doc_432051777905_item	2403452	et	4	main
on	doc_432051777905_item	2403459	et	4	main
polütehniküm	doc_432051777905_item	2403463	et	4	main
on	doc_432051777905_item	2403464	et	4	main
siin	doc_432051777905_item	2403470	et	4	main
õppida	doc_432051777905_item	2403471	et	3	main
mul	doc_432051777905_item	2403472	et	3	main
valja	doc_432051777905_item	2403476	et	3	main
mõned	doc_432051777905_item	2403483	et	3	main
tahan	doc_432051777905_item	2403486	et	3	main
peab	doc_432051777906_item	2403528	et	4	main
elus	doc_432051777906_item	2403534	et	4	main
inimene	doc_432051777906_item	2403536	et	3	main
päeval	doc_432051777906_item	2403550	et	3	main
sõbradest	doc_432051777906_item	2403560	et	4	main
vanematest	doc_432051777906_item	2403561	et	4	main
ja	doc_432051777906_item	2403562	et	3	main
kui	doc_432051777906_item	2403563	et	3	main
meie	doc_432051777906_item	2403564	et	4	main
on	doc_432051777906_item	2403579	et	4	main
veel	doc_432051777906_item	2403584	et	4	main
mis	doc_432051777906_item	2403589	et	4	main
linnas	doc_432051777906_item	2403590	et	4	main
kõik	doc_432051777906_item	2403626	et	4	main
riigis	doc_432051777906_item	2403628	et	3	main
muutub	doc_432051777906_item	2403629	et	3	main
paremaks	doc_432051777906_item	2403630	et	4	main
span	doc_432051777906_item	2403631	et	4	main
uus	doc_432051777907_item	2403632	et	3	main
faktorid	doc_432051777907_item	2403640	et	3	main
näiteks	doc_432051777907_item	2403642	et	4	main
võim	doc_432051777907_item	2403645	et	3	main
ja	doc_432051777907_item	2403646	et	3	main
nii	doc_432051777907_item	2403647	et	3	main
edasi	doc_432051777907_item	2403648	et	3	main
kui	doc_432051777907_item	2403649	et	3	main
inimesel	doc_432051777907_item	2403650	et	3	main
ei	doc_432051777907_item	2403651	et	4	main
ole	doc_432051777907_item	2403652	et	4	main
siis	doc_432051777907_item	2403654	et	3	main
tal	doc_432051777907_item	2403655	et	3	main
elu	doc_432051777907_item	2403661	et	4	main
kui	doc_432051777907_item	2403680	et	3	main
elab	doc_432051777907_item	2403682	et	3	main
alla	doc_432051777907_item	2403692	et	3	main
inemesele	doc_432051777907_item	2403699	et	4	main
elus	doc_432051777907_item	2403702	et	4	main
ilma	doc_432051777907_item	2403703	et	4	main
hariduseta	doc_432051777907_item	2403711	et	3	main
põhjalik	doc_432051777907_item	2403721	et	3	main
mida	doc_432051777907_item	2403723	et	4	main
kõik	doc_432051777907_item	2403730	et	4	main
haridus	doc_432051777907_item	2403741	et	3	main
teadus	doc_432051777907_item	2403750	et	4	main
arvates	doc_432051777908_item	2403759	et	4	main
kasvatavad	doc_432051777908_item	2403766	et	4	main
ma	doc_432051777908_item	2403776	et	3	main
usk	doc_432051777908_item	2403792	et	3	main
span	doc_432051777908_item	2403794	et	4	main
inimeste	doc_432051777908_item	2403795	et	3	main
sõbrad	doc_432051777908_item	2403796	et	3	main
ka	doc_432051777908_item	2403797	et	3	main
mõjutab	doc_432051777908_item	2403798	et	3	main
sest	doc_432051777908_item	2403801	et	4	main
ta	doc_432051777908_item	2403803	et	4	main
nii	doc_432051777908_item	2403806	et	3	main
saa	doc_432051777908_item	2403817	et	4	main
et	doc_432051777908_item	2403830	et	3	main
kuidas	doc_432051777908_item	2403839	et	3	main
käitub	doc_432051777908_item	2403841	et	3	main
elu	doc_432051777909_item	2403849	et	4	main
tähtis	doc_432051777909_item	2403861	et	4	main
kõige	doc_432051777909_item	2403862	et	4	main
juhus	doc_432051777909_item	2403866	et	4	main
inimesel	doc_432051777909_item	2403869	et	3	main
tahab	doc_432051777909_item	2403900	et	3	main
hästi	doc_432051777909_item	2403901	et	3	main
ta	doc_432051777909_item	2403904	et	4	main
teenida	doc_432051777909_item	2403916	et	3	main
mara	doc_432051777905_item	2403429	et	4	main
eesti	doc_432051777905_item	2403430	et	4	main
10	doc_432051777905_item	2403435	et	2	main
tulin	doc_432051777905_item	2403444	et	3	main
on	doc_432051777905_item	2403447	et	4	main
see	doc_432051777905_item	2403448	et	3	main
et	doc_432051777905_item	2403449	et	3	main
sisse	doc_432051777905_item	2403453	et	4	main
põhjus	doc_432051777905_item	2403458	et	4	main
ülikool	doc_432051777905_item	2403466	et	4	main
ja	doc_432051777905_item	2403467	et	3	main
mulle	doc_432051777905_item	2403468	et	4	main
eesti	doc_432051777905_item	2403474	et	4	main
eesti	doc_432051777905_item	2403479	et	4	main
horoskopid	doc_432051777905_item	2403481	et	4	main
kirjad	doc_432051777905_item	2403484	et	4	main
kuulata	doc_432051777905_item	2403487	et	4	main
nashe	doc_432051777905_item	2403488	et	4	main
rariot	doc_432051777905_item	2403489	et	4	main
või	doc_432051777905_item	2403490	et	4	main
mõned	doc_432051777905_item	2403491	et	3	main
radiot	doc_432051777905_item	2403492	et	4	main
kus	doc_432051777905_item	2403493	et	3	main
mängib	doc_432051777905_item	2403494	et	3	main
vene	doc_432051777905_item	2403495	et	4	main
rokk	doc_432051777905_item	2403496	et	3	main
muusika	doc_432051777905_item	2403497	et	4	main
uus	doc_432051777906_item	2403498	et	3	main
dokument	doc_432051777906_item	2403499	et	3	main
arvan	doc_432051777906_item	2403500	et	3	main
et	doc_432051777906_item	2403501	et	3	main
kõige	doc_432051777906_item	2403502	et	4	main
rohkem	doc_432051777906_item	2403503	et	4	main
mõjutab	doc_432051777906_item	2403504	et	3	main
inimese	doc_432051777906_item	2403505	et	4	main
elu	doc_432051777906_item	2403506	et	4	main
on	doc_432051777906_item	2403507	et	4	main
iseloom	doc_432051777906_item	2403508	et	3	main
sõbrad	doc_432051777906_item	2403509	et	3	main
elukoht	doc_432051777906_item	2403510	et	3	main
vanemad	doc_432051777906_item	2403511	et	4	main
ja	doc_432051777906_item	2403512	et	3	main
raha	doc_432051777906_item	2403513	et	4	main
span	doc_432051777906_item	2403514	et	4	main
kui	doc_432051777906_item	2403515	et	3	main
inimene	doc_432051777906_item	2403516	et	3	main
on	doc_432051777906_item	2403517	et	4	main
passiivne	doc_432051777906_item	2403518	et	3	main
peab	doc_432051777906_item	2403532	et	4	main
kohanema	doc_432051777906_item	2403533	et	3	main
ka	doc_432051777906_item	2403545	et	3	main
iga	doc_432051777906_item	2403549	et	4	main
suhtleme	doc_432051777906_item	2403552	et	3	main
vanemad	doc_432051777906_item	2403567	et	4	main
head	doc_432051777906_item	2403569	et	4	main
kõik	doc_432051777906_item	2403571	et	4	main
sõltub	doc_432051777906_item	2403587	et	3	main
esimesele	doc_432051777906_item	2403603	et	3	main
kohale	doc_432051777906_item	2403604	et	4	main
lähevad	doc_432051777906_item	2403605	et	3	main
raha	doc_432051777906_item	2403606	et	4	main
inimesed	doc_432051777906_item	2403607	et	3	main
mõtlevad	doc_432051777906_item	2403608	et	4	main
ainult	doc_432051777906_item	2403609	et	4	main
rahast	doc_432051777906_item	2403610	et	4	main
kust	doc_432051777906_item	2403611	et	4	main
neid	doc_432051777906_item	2403612	et	4	main
võtta	doc_432051777906_item	2403613	et	3	main
ilma	doc_432051777906_item	2403614	et	4	main
nendeta	doc_432051777906_item	2403615	et	4	main
praegu	doc_432051777906_item	2403616	et	3	main
liiga	doc_432051777906_item	2403617	et	4	main
raske	doc_432051777906_item	2403618	et	4	main
elada	doc_432051777906_item	2403619	et	3	main
vähe	doc_432051777906_item	2403620	et	3	main
palju	doc_432051777907_item	2403637	et	4	main
faktorei	doc_432051777907_item	2403638	et	4	main
on	doc_432051777907_item	2403656	et	4	main
elada	doc_432051777907_item	2403659	et	3	main
kohustab	doc_432051777907_item	2403662	et	3	main
siis	doc_432051777907_item	2403685	et	3	main
sattub	doc_432051777907_item	2403689	et	3	main
veel	doc_432051777907_item	2403693	et	4	main
selleta	doc_432051777907_item	2403704	et	3	main
tulevad	doc_432051777907_item	2403705	et	4	main
on	doc_432051777907_item	2403709	et	4	main
on	doc_432051777907_item	2403720	et	4	main
elus	doc_432051777906_item	2403622	et	4	main
loodan	doc_432051777906_item	2403624	et	3	main
et	doc_432051777906_item	2403625	et	3	main
elus	doc_432051777907_item	2403634	et	4	main
inimest	doc_432051777907_item	2403635	et	3	main
mõjutab	doc_432051777907_item	2403636	et	3	main
raha	doc_432051777907_item	2403643	et	4	main
halbad	doc_432051777907_item	2403657	et	4	main
rahus	doc_432051777907_item	2403660	et	4	main
meid	doc_432051777907_item	2403663	et	4	main
raha	doc_432051777907_item	2403664	et	4	main
teenima	doc_432051777907_item	2403665	et	3	main
rahata	doc_432051777907_item	2403666	et	4	main
ei	doc_432051777907_item	2403667	et	4	main
saa	doc_432051777907_item	2403668	et	4	main
elada	doc_432051777907_item	2403669	et	3	main
kõik	doc_432051777907_item	2403670	et	4	main
inimene	doc_432051777907_item	2403671	et	3	main
tahab	doc_432051777907_item	2403672	et	3	main
süüa	doc_432051777907_item	2403673	et	3	main
juua	doc_432051777907_item	2403674	et	3	main
tahab	doc_432051777907_item	2403675	et	3	main
riietada	doc_432051777907_item	2403676	et	3	main
ja	doc_432051777907_item	2403677	et	3	main
nii	doc_432051777907_item	2403678	et	3	main
edasi	doc_432051777907_item	2403679	et	3	main
ta	doc_432051777907_item	2403686	et	4	main
ja	doc_432051777907_item	2403688	et	3	main
asi	doc_432051777907_item	2403695	et	4	main
väga	doc_432051777907_item	2403697	et	3	main
ja	doc_432051777907_item	2403700	et	3	main
mingid	doc_432051777907_item	2403706	et	4	main
raskused	doc_432051777907_item	2403707	et	4	main
see	doc_432051777907_item	2403708	et	3	main
inimene	doc_432051777907_item	2403712	et	3	main
asi	doc_432051777907_item	2403722	et	4	main
elus	doc_432051777907_item	2403726	et	4	main
et	doc_432051777907_item	2403729	et	3	main
et	doc_432051777907_item	2403733	et	3	main
ja	doc_432051777907_item	2403751	et	3	main
rohkem	doc_432051777907_item	2403753	et	4	main
tehnoloogiat	doc_432051777907_item	2403754	et	3	main
span	doc_432051777907_item	2403755	et	4	main
uus	doc_432051777908_item	2403756	et	3	main
kõige	doc_432051777908_item	2403760	et	4	main
on	doc_432051777908_item	2403762	et	4	main
inimeste	doc_432051777908_item	2403763	et	3	main
teiseks	doc_432051777908_item	2403775	et	4	main
probleem	doc_432051777908_item	2403779	et	3	main
on	doc_432051777908_item	2403782	et	4	main
tähtsam	doc_432051777908_item	2403784	et	4	main
elavad	doc_432051777908_item	2403788	et	4	main
nende	doc_432051777908_item	2403791	et	4	main
suhtleb	doc_432051777908_item	2403804	et	3	main
väga	doc_432051777908_item	2403812	et	3	main
tööd	doc_432051777908_item	2403819	et	4	main
inimene	doc_432051777907_item	2403725	et	3	main
ma	doc_432051777907_item	2403727	et	3	main
kõik	doc_432051777907_item	2403740	et	4	main
paremaks	doc_432051777907_item	2403744	et	4	main
oleks	doc_432051777907_item	2403746	et	3	main
rohkem	doc_432051777907_item	2403747	et	4	main
spetsialiste	doc_432051777907_item	2403748	et	3	main
mutuks	doc_432051777907_item	2403743	et	4	main
siis	doc_432051777907_item	2403745	et	3	main
arendaks	doc_432051777907_item	2403749	et	3	main
oleks	doc_432051777907_item	2403752	et	3	main
lapsi	doc_432051777908_item	2403768	et	4	main
see	doc_432051777908_item	2403769	et	3	main
rohkem	doc_432051777908_item	2403770	et	4	main
mõjutab	doc_432051777908_item	2403771	et	3	main
span	doc_432051777908_item	2403774	et	4	main
sest	doc_432051777908_item	2403780	et	4	main
see	doc_432051777908_item	2403781	et	3	main
ka	doc_432051777908_item	2403783	et	3	main
inimesed	doc_432051777908_item	2403787	et	3	main
nii	doc_432051777908_item	2403789	et	3	main
nende	doc_432051777908_item	2403799	et	4	main
saab	doc_432051777908_item	2403805	et	3	main
on	doc_432051777908_item	2403811	et	4	main
vajalik	doc_432051777908_item	2403813	et	3	main
leida	doc_432051777908_item	2403820	et	3	main
elu	doc_432051777908_item	2403822	et	4	main
mõjub	doc_432051777908_item	2403823	et	3	main
iseloom	doc_432051777908_item	2403831	et	3	main
elu	doc_432051777908_item	2403836	et	4	main
dokument	doc_432051777909_item	2403845	et	3	main
mis	doc_432051777909_item	2403846	et	4	main
mõjutab	doc_432051777909_item	2403847	et	3	main
kõige	doc_432051777909_item	2403850	et	4	main
on	doc_432051777909_item	2403859	et	4	main
tervis	doc_432051777909_item	2403864	et	3	main
minu	doc_432051777909_item	2403907	et	3	main
arvates	doc_432051777909_item	2403908	et	4	main
on	doc_432051777909_item	2403910	et	4	main
tervis	doc_432051777909_item	2403918	et	3	main
inimese	doc_432051777910_item	2403929	et	4	main
nõus	doc_432051777910_item	2403940	et	4	main
sest	doc_432051777910_item	2403941	et	4	main
näiteks	doc_432051777910_item	2403945	et	4	main
ma	doc_432051777910_item	2403946	et	3	main
õpin	doc_432051777910_item	2403947	et	3	main
kohtla-järvel	doc_432051777910_item	2403948	et	4	main
eest	doc_432051777910_item	2403957	et	4	main
ja	doc_432051777910_item	2403958	et	3	main
annab	doc_432051777910_item	2403959	et	3	main
mõjuta	doc_432051777910_item	2403966	et	4	main
sest	doc_432051777910_item	2403972	et	4	main
sellepärast	doc_432051777910_item	2403973	et	3	main
see	doc_432051777910_item	2403974	et	3	main
on	doc_432051777910_item	2403975	et	4	main
ei	doc_432051777910_item	2403976	et	4	main
sugust	doc_432051777910_item	2403983	et	3	main
lõpetaseks	doc_432051777910_item	2403986	et	4	main
teeb	doc_432051777910_item	2403993	et	3	main
dokument	doc_432051777911_item	2403998	et	3	main
tere	doc_432051777911_item	2403999	et	3	main
õpetaja	doc_432051777911_item	2404000	et	4	main
edusammu	doc_432051777911_item	2404023	et	4	main
kes	doc_432051777911_item	2404028	et	4	main
õppinud	doc_432051777911_item	2404034	et	4	main
esimene	doc_432051777911_item	2404037	et	3	main
tulin	doc_432051777911_item	2404040	et	3	main
et	doc_432051777911_item	2404048	et	3	main
rohkem	doc_432051777911_item	2404054	et	4	main
või	doc_432051777911_item	2404057	et	4	main
mul	doc_432051777911_item	2404059	et	3	main
ja	doc_432051777911_item	2404068	et	3	main
täita	doc_432051777911_item	2404069	et	4	main
palju	doc_432051777911_item	2404070	et	4	main
igasuguseid	doc_432051777911_item	2404071	et	3	main
müüjaga	doc_432051777911_item	2404087	et	4	main
kui	doc_432051777911_item	2404088	et	3	main
ma	doc_432051777911_item	2404122	et	3	main
tahtsin	doc_432051777911_item	2404123	et	3	main
loodan	doc_432051777911_item	2404135	et	3	main
minu	doc_432051777911_item	2404139	et	3	main
ja	doc_432051777911_item	2404141	et	3	main
vastate	doc_432051777911_item	2404142	et	3	main
minu	doc_432051777908_item	2403758	et	3	main
tähtsam	doc_432051777908_item	2403761	et	4	main
vanemad	doc_432051777908_item	2403764	et	4	main
kes	doc_432051777908_item	2403765	et	4	main
inimese	doc_432051777908_item	2403772	et	4	main
valiksin	doc_432051777908_item	2403777	et	3	main
rahvuse	doc_432051777908_item	2403778	et	3	main
paljud	doc_432051777908_item	2403786	et	3	main
kuidas	doc_432051777908_item	2403790	et	3	main
nõuab	doc_432051777908_item	2403793	et	3	main
nagu	doc_432051777908_item	2403807	et	3	main
span	doc_432051777908_item	2403809	et	4	main
haridus	doc_432051777908_item	2403810	et	3	main
sest	doc_432051777908_item	2403814	et	4	main
haridusete	doc_432051777908_item	2403815	et	3	main
ei	doc_432051777908_item	2403816	et	4	main
ja	doc_432051777908_item	2403821	et	3	main
mõjutada	doc_432051777908_item	2403834	et	3	main
sõltub	doc_432051777908_item	2403838	et	3	main
ringkonnas	doc_432051777908_item	2403842	et	4	main
span	doc_432051777908_item	2403843	et	4	main
uus	doc_432051777909_item	2403844	et	3	main
rohkem	doc_432051777909_item	2403851	et	4	main
mina	doc_432051777909_item	2403854	et	4	main
arvan	doc_432051777909_item	2403855	et	3	main
et	doc_432051777909_item	2403856	et	3	main
kõige	doc_432051777909_item	2403860	et	4	main
haridus	doc_432051777909_item	2403865	et	3	main
on	doc_432051777909_item	2403871	et	4	main
elada	doc_432051777909_item	2403902	et	3	main
teeb	doc_432051777909_item	2403906	et	3	main
tervis	doc_432051777909_item	2403909	et	3	main
väga	doc_432051777909_item	2403911	et	3	main
sest	doc_432051777909_item	2403913	et	4	main
asjad	doc_432051777909_item	2403914	et	3	main
võib	doc_432051777909_item	2403915	et	3	main
elu	doc_432051777910_item	2403930	et	4	main
meelest	doc_432051777910_item	2403934	et	4	main
aitada	doc_432051777910_item	2403937	et	4	main
ja	doc_432051777910_item	2403938	et	3	main
anda	doc_432051777910_item	2403939	et	3	main
vanemad	doc_432051777910_item	2403953	et	4	main
mulle	doc_432051777910_item	2403960	et	4	main
see	doc_432051777910_item	2403969	et	3	main
on	doc_432051777910_item	2403970	et	4	main
mitte	doc_432051777910_item	2403981	et	3	main
tahan	doc_432051777910_item	2403988	et	3	main
ise	doc_432051777910_item	2403992	et	4	main
ettevõtlikuks	doc_432051777911_item	2404024	et	3	main
olen	doc_432051777911_item	2404033	et	3	main
on	doc_432051777911_item	2404046	et	4	main
mulle	doc_432051777911_item	2404053	et	4	main
kui	doc_432051777911_item	2404055	et	3	main
ma	doc_432051777911_item	2404073	et	3	main
telerist	doc_432051777911_item	2404080	et	4	main
tahan	doc_432051777911_item	2404082	et	3	main
rääkida	doc_432051777911_item	2404084	et	3	main
ma	doc_432051777911_item	2404126	et	3	main
ära	doc_432051777911_item	2404133	et	4	main
et	doc_432051777911_item	2404136	et	3	main
lugupidamisega	doc_432051777911_item	2404144	et	3	main
span	doc_432051777908_item	2403825	et	4	main
ja	doc_432051777908_item	2403826	et	3	main
lõppuks	doc_432051777908_item	2403827	et	3	main
tahan	doc_432051777908_item	2403828	et	3	main
öelda	doc_432051777908_item	2403829	et	4	main
võib	doc_432051777908_item	2403833	et	3	main
inimeste	doc_432051777908_item	2403835	et	3	main
inimese	doc_432051777909_item	2403848	et	4	main
span	doc_432051777909_item	2403852	et	4	main
raha	doc_432051777909_item	2403867	et	4	main
tervis	doc_432051777909_item	2403873	et	3	main
ja	doc_432051777909_item	2403874	et	3	main
ta	doc_432051777909_item	2403875	et	4	main
regulaarselt	doc_432051777909_item	2403876	et	4	main
hoolitseb	doc_432051777909_item	2403877	et	3	main
oma	doc_432051777909_item	2403878	et	4	main
tervise	doc_432051777909_item	2403879	et	3	main
eest	doc_432051777909_item	2403880	et	4	main
siis	doc_432051777909_item	2403881	et	3	main
tal	doc_432051777909_item	2403882	et	3	main
on	doc_432051777909_item	2403883	et	4	main
võimalus	doc_432051777909_item	2403884	et	3	main
ilma	doc_432051777909_item	2403885	et	4	main
probleemita	doc_432051777909_item	2403886	et	3	main
saada	doc_432051777909_item	2403887	et	4	main
haridust	doc_432051777909_item	2403888	et	4	main
õppida	doc_432051777909_item	2403889	et	3	main
keeli	doc_432051777909_item	2403890	et	4	main
leida	doc_432051777909_item	2403891	et	3	main
tööd	doc_432051777909_item	2403892	et	4	main
viimane	doc_432051777909_item	2403893	et	3	main
aga	doc_432051777909_item	2403894	et	3	main
sõltub	doc_432051777909_item	2403895	et	3	main
inimeste	doc_432051777909_item	2403896	et	3	main
siis	doc_432051777909_item	2403903	et	3	main
aga	doc_432051777909_item	2403917	et	3	main
palju	doc_432051777909_item	2403905	et	4	main
tähtis	doc_432051777909_item	2403912	et	4	main
ei	doc_432051777909_item	2403919	et	4	main
span	doc_432051777909_item	2403921	et	4	main
dokument	doc_432051777910_item	2403923	et	3	main
arvates	doc_432051777910_item	2403925	et	4	main
rohkem	doc_432051777910_item	2403932	et	4	main
minu	doc_432051777910_item	2403933	et	3	main
vanemad	doc_432051777910_item	2403935	et	4	main
tal	doc_432051777910_item	2403942	et	3	main
elan	doc_432051777910_item	2403951	et	3	main
ühiselamu	doc_432051777910_item	2403956	et	4	main
span	doc_432051777910_item	2403963	et	4	main
aga	doc_432051777910_item	2403964	et	3	main
inimese	doc_432051777910_item	2403967	et	4	main
inimese	doc_432051777910_item	2403991	et	4	main
oma	doc_432051777910_item	2403994	et	4	main
armastan	doc_432051777911_item	2404021	et	3	main
ja	doc_432051777911_item	2404025	et	3	main
inemisi	doc_432051777911_item	2404027	et	4	main
keelt	doc_432051777911_item	2404032	et	4	main
miks	doc_432051777911_item	2404039	et	4	main
see	doc_432051777911_item	2404047	et	3	main
meeldib	doc_432051777911_item	2404052	et	3	main
on	doc_432051777911_item	2404060	et	4	main
eesti	doc_432051777911_item	2404061	et	4	main
keelt	doc_432051777911_item	2404062	et	4	main
ja	doc_432051777911_item	2404079	et	3	main
ma	doc_432051777911_item	2404081	et	3	main
eesti	doc_432051777911_item	2404085	et	4	main
keeles	doc_432051777911_item	2404086	et	4	main
eesti	doc_432051777911_item	2404127	et	4	main
tundides	doc_432051777911_item	2404129	et	3	main
keelt	doc_432051777911_item	2404131	et	4	main
hästi	doc_432051777911_item	2404132	et	3	main
mulle	doc_432051777911_item	2404143	et	4	main
xxxx	doc_432051777911_item	2404146	et	4	main
sina	doc_432051777914_item	2404428	et	4	main
sul	doc_432051777914_item	2404433	et	3	main
näiteks	doc_432051777914_item	2404439	et	4	main
peab	doc_432051777914_item	2404441	et	4	main
saa	doc_432051777909_item	2403920	et	4	main
uus	doc_432051777910_item	2403922	et	3	main
minu	doc_432051777910_item	2403924	et	3	main
et	doc_432051777910_item	2403926	et	3	main
kõige	doc_432051777910_item	2403931	et	4	main
politehnikumis	doc_432051777910_item	2403949	et	4	main
ei	doc_432051777910_item	2403965	et	4	main
vaja	doc_432051777910_item	2403977	et	4	main
sünniaeg	doc_432051777910_item	2403978	et	3	main
ei	doc_432051777910_item	2403979	et	4	main
anda	doc_432051777910_item	2403980	et	3	main
span	doc_432051777910_item	2403985	et	4	main
ma	doc_432051777910_item	2403987	et	3	main
et	doc_432051777910_item	2403990	et	3	main
vanemad	doc_432051777910_item	2403927	et	4	main
mõjutab	doc_432051777910_item	2403928	et	3	main
võivad	doc_432051777910_item	2403936	et	4	main
suur	doc_432051777910_item	2403943	et	3	main
kogemus	doc_432051777910_item	2403944	et	3	main
ja	doc_432051777910_item	2403950	et	3	main
ühiselamus	doc_432051777910_item	2403952	et	4	main
maksavad	doc_432051777910_item	2403954	et	3	main
raha	doc_432051777910_item	2403955	et	4	main
jaoks	doc_432051777910_item	2403961	et	4	main
toitumine	doc_432051777910_item	2403962	et	4	main
elu	doc_432051777910_item	2403968	et	4	main
sünniaeg	doc_432051777910_item	2403971	et	3	main
mingi	doc_432051777910_item	2403982	et	4	main
aitab	doc_432051777910_item	2403984	et	3	main
täpsustada	doc_432051777910_item	2403989	et	3	main
elu	doc_432051777910_item	2403995	et	4	main
span	doc_432051777910_item	2403996	et	4	main
uus	doc_432051777911_item	2403997	et	3	main
minu	doc_432051777911_item	2404001	et	3	main
nimi	doc_432051777911_item	2404002	et	3	main
on	doc_432051777911_item	2404003	et	4	main
xxxx	doc_432051777911_item	2404004	et	4	main
xxxxx	doc_432051777911_item	2404005	et	4	main
olen	doc_432051777911_item	2404006	et	3	main
üheksateist	doc_432051777911_item	2404007	et	4	main
aastat	doc_432051777911_item	2404008	et	3	main
vana	doc_432051777911_item	2404009	et	4	main
kõige	doc_432051777911_item	2404010	et	4	main
tähtsam	doc_432051777911_item	2404011	et	4	main
minu	doc_432051777911_item	2404012	et	3	main
elus	doc_432051777911_item	2404013	et	4	main
on	doc_432051777911_item	2404014	et	4	main
minu	doc_432051777911_item	2404015	et	3	main
ema	doc_432051777911_item	2404016	et	4	main
ja	doc_432051777911_item	2404017	et	3	main
minu	doc_432051777911_item	2404018	et	3	main
tulevik	doc_432051777911_item	2404019	et	3	main
ma	doc_432051777911_item	2404020	et	3	main
kaheksa	doc_432051777911_item	2404035	et	4	main
põhjus	doc_432051777911_item	2404038	et	4	main
sellele	doc_432051777911_item	2404041	et	4	main
kursuselle	doc_432051777911_item	2404042	et	3	main
on	doc_432051777911_item	2404043	et	4	main
rakenduskõrgharidus	doc_432051777911_item	2404044	et	3	main
teine	doc_432051777911_item	2404045	et	3	main
keemia	doc_432051777911_item	2404049	et	4	main
keskkonnakaitse	doc_432051777911_item	2404051	et	4	main
infotehnoloogia	doc_432051777911_item	2404056	et	4	main
automaatikaseadmed	doc_432051777911_item	2404058	et	3	main
ajalehti	doc_432051777911_item	2404067	et	4	main
tahan	doc_432051777911_item	2404074	et	3	main
igat	doc_432051777911_item	2404076	et	3	main
radiost	doc_432051777911_item	2404078	et	3	main
hakkama	doc_432051777911_item	2404121	et	3	main
teada	doc_432051777911_item	2404124	et	3	main
keele	doc_432051777911_item	2404128	et	4	main
eest	doc_432051777911_item	2404130	et	4	main
xxxxx	doc_432051777911_item	2404145	et	4	main
igat	doc_432051777911_item	2404022	et	3	main
armastan	doc_432051777911_item	2404026	et	3	main
nii	doc_432051777911_item	2404029	et	3	main
teevad	doc_432051777911_item	2404030	et	3	main
eesti	doc_432051777911_item	2404031	et	4	main
aastat	doc_432051777911_item	2404036	et	3	main
ja	doc_432051777911_item	2404050	et	3	main
vaja	doc_432051777911_item	2404063	et	4	main
et	doc_432051777911_item	2404064	et	3	main
lugeda	doc_432051777911_item	2404065	et	3	main
raamatuid	doc_432051777911_item	2404066	et	3	main
ankeete	doc_432051777911_item	2404072	et	3	main
kuulata	doc_432051777911_item	2404075	et	4	main
sõnumit	doc_432051777911_item	2404077	et	3	main
ka	doc_432051777911_item	2404083	et	3	main
ostan	doc_432051777911_item	2404089	et	3	main
midagi	doc_432051777911_item	2404090	et	4	main
kauplusest	doc_432051777911_item	2404091	et	4	main
ma	doc_432051777911_item	2404092	et	3	main
tahan	doc_432051777911_item	2404093	et	3	main
osata	doc_432051777911_item	2404094	et	4	main
ka	doc_432051777911_item	2404095	et	3	main
kirjutada	doc_432051777911_item	2404096	et	3	main
eesti	doc_432051777911_item	2404097	et	4	main
keeles	doc_432051777911_item	2404098	et	4	main
kardan	doc_432051777911_item	2404100	et	4	main
et	doc_432051777911_item	2404101	et	3	main
veel	doc_432051777911_item	2404102	et	4	main
ma	doc_432051777911_item	2404099	et	3	main
ei	doc_432051777911_item	2404103	et	4	main
tea	doc_432051777911_item	2404104	et	4	main
eesti	doc_432051777911_item	2404105	et	4	main
keelt	doc_432051777911_item	2404106	et	4	main
hästi	doc_432051777911_item	2404107	et	3	main
ilmselt	doc_432051777911_item	2404108	et	4	main
hakkan	doc_432051777911_item	2404109	et	3	main
tegema	doc_432051777911_item	2404110	et	3	main
palju	doc_432051777911_item	2404111	et	4	main
vigu	doc_432051777911_item	2404112	et	3	main
aga	doc_432051777911_item	2404113	et	3	main
ma	doc_432051777911_item	2404114	et	3	main
usun	doc_432051777911_item	2404115	et	3	main
et	doc_432051777911_item	2404116	et	3	main
me	doc_432051777911_item	2404117	et	4	main
saame	doc_432051777911_item	2404118	et	4	main
sellega	doc_432051777911_item	2404119	et	3	main
hästi	doc_432051777911_item	2404120	et	3	main
saan	doc_432051777911_item	2404125	et	4	main
õppida	doc_432051777911_item	2404134	et	3	main
te	doc_432051777911_item	2404137	et	4	main
saate	doc_432051777911_item	2404138	et	4	main
kirja	doc_432051777911_item	2404140	et	4	main
välimus	doc_432051777914_item	2404426	et	3	main
oled	doc_432051777914_item	2404429	et	3	main
siis	doc_432051777914_item	2404432	et	3	main
pangas	doc_432051777914_item	2404440	et	4	main
istuma	doc_432051777914_item	2404442	et	3	main
iseloom	doc_432051777914_item	2404451	et	3	main
iseloomuga	doc_432051777914_item	2404454	et	3	main
elada	doc_432051777914_item	2404456	et	3	main
span	doc_432051777914_item	2404457	et	4	main
tähtkuju	doc_432051777914_item	2404461	et	4	main
inimese	doc_432051777914_item	2404423	et	4	main
kui	doc_432051777914_item	2404427	et	3	main
tööd	doc_432051777914_item	2404438	et	4	main
ma	doc_432051777914_item	2404445	et	3	main
veel	doc_432051777914_item	2404449	et	4	main
leebe	doc_432051777914_item	2404453	et	4	main
mõtlen	doc_432051777914_item	2404459	et	3	main
et	doc_432051777914_item	2404460	et	3	main
mõjuta	doc_432051777914_item	2404463	et	4	main
elu	doc_432051777914_item	2404465	et	4	main
saatuses	doc_432051777914_item	2404469	et	4	main
ma	doc_432051777914_item	2404471	et	3	main
inimese	doc_432051777914_item	2404477	et	4	main
mõjutab	doc_432051777915_item	2404483	et	3	main
tähtsam	doc_432051777915_item	2404492	et	4	main
on	doc_432051777915_item	2404493	et	4	main
ma	doc_432051777915_item	2404502	et	3	main
nad	doc_432051777915_item	2404505	et	3	main
rahad	doc_432051777915_item	2404521	et	4	main
kõik	doc_432051777915_item	2404525	et	4	main
sõltuvad	doc_432051777915_item	2404527	et	4	main
rohkem	doc_432051777916_item	2404539	et	4	main
lastele	doc_432051777916_item	2404545	et	4	main
oma	doc_432051777916_item	2404547	et	4	main
elukoht	doc_432051777916_item	2404551	et	3	main
aga	doc_432051777916_item	2404552	et	3	main
see	doc_432051777916_item	2404553	et	3	main
on	doc_432051777916_item	2404554	et	4	main
mõjutab	doc_432051777916_item	2404558	et	3	main
on	doc_432051777916_item	2404561	et	4	main
kõigel	doc_432051777916_item	2404569	et	4	main
inimesel	doc_432051777916_item	2404570	et	3	main
sünnikoht	doc_432051777916_item	2404571	et	3	main
ma	doc_432051777916_item	2404621	et	3	main
see	doc_432051777916_item	2404623	et	3	main
tegurid	doc_432051777916_item	2404636	et	3	main
erinevad	doc_432051777916_item	2404644	et	4	main
meelest	doc_432051777917_item	2404656	et	4	main
see	doc_432051777917_item	2404657	et	3	main
minu	doc_432051777917_item	2404661	et	3	main
et	doc_432051777917_item	2404665	et	3	main
sull	doc_432051777917_item	2404667	et	4	main
raha	doc_432051777917_item	2404670	et	4	main
sa	doc_432051777917_item	2404672	et	3	main
oli	doc_432051777917_item	2404686	et	3	main
ja	doc_432051777917_item	2404688	et	3	main
kõik	doc_432051777917_item	2404689	et	4	main
sulle	doc_432051777917_item	2404690	et	3	main
meeldis	doc_432051777917_item	2404691	et	3	main
siis	doc_432051777917_item	2404692	et	3	main
on	doc_432051777917_item	2404693	et	4	main
veel	doc_432051777917_item	2404697	et	4	main
üks	doc_432051777917_item	2404699	et	3	main
mis	doc_432051777917_item	2404701	et	4	main
see	doc_432051777917_item	2404705	et	3	main
on	doc_432051777917_item	2404713	et	4	main
kõige	doc_432051777917_item	2404714	et	4	main
on	doc_432051777918_item	2404725	et	4	main
näiteks	doc_432051777918_item	2404728	et	4	main
uus	doc_432051777914_item	2404397	et	3	main
dokument	doc_432051777914_item	2404398	et	3	main
head	doc_432051777914_item	2404399	et	4	main
ma	doc_432051777914_item	2404400	et	3	main
arvan	doc_432051777914_item	2404401	et	3	main
et	doc_432051777914_item	2404402	et	3	main
inimese	doc_432051777914_item	2404403	et	4	main
elu	doc_432051777914_item	2404404	et	4	main
kõige	doc_432051777914_item	2404405	et	4	main
rohkem	doc_432051777914_item	2404406	et	4	main
mõjutab	doc_432051777914_item	2404407	et	3	main
raha	doc_432051777914_item	2404408	et	4	main
kui	doc_432051777914_item	2404409	et	3	main
sul	doc_432051777914_item	2404410	et	3	main
on	doc_432051777914_item	2404411	et	4	main
raha	doc_432051777914_item	2404412	et	4	main
siis	doc_432051777914_item	2404413	et	3	main
sul	doc_432051777914_item	2404414	et	3	main
on	doc_432051777914_item	2404415	et	4	main
haridus	doc_432051777914_item	2404416	et	3	main
ja	doc_432051777914_item	2404417	et	3	main
hea	doc_432051777914_item	2404418	et	4	main
tööd	doc_432051777914_item	2404419	et	4	main
veel	doc_432051777914_item	2404420	et	4	main
minu	doc_432051777914_item	2404421	et	3	main
elu	doc_432051777914_item	2404424	et	4	main
võimalusi	doc_432051777914_item	2404436	et	3	main
leida	doc_432051777914_item	2404437	et	3	main
kergem	doc_432051777914_item	2404455	et	4	main
ma	doc_432051777914_item	2404458	et	3	main
inimese	doc_432051777914_item	2404464	et	4	main
ma	doc_432051777914_item	2404466	et	3	main
arvan	doc_432051777914_item	2404472	et	3	main
span	doc_432051777914_item	2404479	et	4	main
uus	doc_432051777915_item	2404480	et	3	main
mis	doc_432051777915_item	2404482	et	4	main
ja	doc_432051777915_item	2404501	et	3	main
aitavad	doc_432051777915_item	2404506	et	4	main
tähtis	doc_432051777915_item	2404524	et	4	main
maailmas	doc_432051777915_item	2404526	et	3	main
rahast	doc_432051777915_item	2404528	et	4	main
span	doc_432051777915_item	2404529	et	4	main
oma	doc_432051777916_item	2404544	et	4	main
ajutine	doc_432051777916_item	2404555	et	4	main
aga	doc_432051777916_item	2404556	et	3	main
väga	doc_432051777916_item	2404557	et	3	main
ka	doc_432051777916_item	2404560	et	3	main
peab	doc_432051777916_item	2404567	et	4	main
olema	doc_432051777916_item	2404568	et	4	main
mõjutab	doc_432051777916_item	2404572	et	3	main
natukene	doc_432051777916_item	2404573	et	4	main
ka	doc_432051777916_item	2404574	et	3	main
välimus	doc_432051777916_item	2404575	et	3	main
span	doc_432051777916_item	2404576	et	4	main
ma	doc_432051777916_item	2404577	et	3	main
mõjuta	doc_432051777916_item	2404581	et	4	main
sest	doc_432051777916_item	2404583	et	4	main
paljud	doc_432051777916_item	2404628	et	3	main
inimesed	doc_432051777916_item	2404631	et	3	main
arvan	doc_432051777916_item	2404633	et	3	main
see	doc_432051777916_item	2404635	et	3	main
uus	doc_432051777917_item	2404646	et	3	main
on	doc_432051777917_item	2404658	et	4	main
positsioon	doc_432051777917_item	2404662	et	3	main
tahad	doc_432051777917_item	2404681	et	3	main
nii	doc_432051777917_item	2404683	et	3	main
span	doc_432051777917_item	2404696	et	4	main
ei	doc_432051777917_item	2404702	et	4	main
osta	doc_432051777917_item	2404704	et	4	main
span	doc_432051777917_item	2404708	et	4	main
kaks	doc_432051777917_item	2404710	et	3	main
missugused	doc_432051777917_item	2404712	et	3	main
uus	doc_432051777918_item	2404719	et	3	main
mõjutab	doc_432051777914_item	2404425	et	3	main
arvates	doc_432051777914_item	2404422	et	4	main
meeldiv	doc_432051777914_item	2404430	et	4	main
inimene	doc_432051777914_item	2404431	et	3	main
on	doc_432051777914_item	2404434	et	4	main
rohkem	doc_432051777914_item	2404435	et	4	main
inimesed	doc_432051777914_item	2404444	et	3	main
nii	doc_432051777914_item	2404447	et	3	main
sest	doc_432051777914_item	2404452	et	4	main
ei	doc_432051777914_item	2404462	et	4	main
ei	doc_432051777914_item	2404467	et	4	main
saatus	doc_432051777914_item	2404474	et	3	main
sõbrad	doc_432051777915_item	2404494	et	3	main
ja	doc_432051777915_item	2404495	et	3	main
vanemad	doc_432051777915_item	2404496	et	4	main
tean	doc_432051777915_item	2404503	et	3	main
õnnestus	doc_432051777915_item	2404507	et	4	main
aga	doc_432051777915_item	2404508	et	3	main
elus	doc_432051777915_item	2404509	et	4	main
on	doc_432051777915_item	2404510	et	4	main
asju	doc_432051777915_item	2404511	et	3	main
milleta	doc_432051777915_item	2404512	et	3	main
inemesed	doc_432051777915_item	2404513	et	4	main
ei	doc_432051777915_item	2404514	et	4	main
saa	doc_432051777915_item	2404515	et	4	main
elada	doc_432051777915_item	2404516	et	3	main
see	doc_432051777915_item	2404517	et	3	main
on	doc_432051777915_item	2404518	et	4	main
rahad	doc_432051777915_item	2404519	et	4	main
tanapäeval	doc_432051777915_item	2404520	et	4	main
uus	doc_432051777916_item	2404530	et	3	main
dokument	doc_432051777916_item	2404531	et	3	main
ma	doc_432051777916_item	2404532	et	3	main
arvan	doc_432051777916_item	2404533	et	3	main
et	doc_432051777916_item	2404534	et	3	main
mõjutab	doc_432051777916_item	2404535	et	3	main
elu	doc_432051777916_item	2404537	et	4	main
kõige	doc_432051777916_item	2404538	et	4	main
nad	doc_432051777916_item	2404542	et	3	main
ja	doc_432051777916_item	2404564	et	3	main
ei	doc_432051777916_item	2404580	et	4	main
süüniaeg	doc_432051777916_item	2404582	et	4	main
sümpaatsed	doc_432051777914_item	2404443	et	3	main
arvan	doc_432051777914_item	2404446	et	3	main
ja	doc_432051777914_item	2404448	et	3	main
mõjutab	doc_432051777914_item	2404450	et	3	main
usu	doc_432051777914_item	2404468	et	4	main
sellepärast	doc_432051777914_item	2404470	et	3	main
et	doc_432051777914_item	2404473	et	3	main
ei	doc_432051777914_item	2404475	et	4	main
mõjuta	doc_432051777914_item	2404476	et	4	main
dokument	doc_432051777915_item	2404481	et	3	main
elu	doc_432051777915_item	2404485	et	4	main
kõige	doc_432051777915_item	2404486	et	4	main
rohkem	doc_432051777915_item	2404487	et	4	main
span	doc_432051777915_item	2404488	et	4	main
esimesel	doc_432051777915_item	2404489	et	3	main
seda	doc_432051777915_item	2404497	et	3	main
inimesed	doc_432051777915_item	2404498	et	3	main
armastavad	doc_432051777915_item	2404499	et	4	main
et	doc_432051777915_item	2404504	et	3	main
elu	doc_432051777914_item	2404478	et	4	main
inimese	doc_432051777915_item	2404484	et	4	main
juhul	doc_432051777915_item	2404490	et	3	main
kõige	doc_432051777915_item	2404491	et	4	main
mind	doc_432051777915_item	2404500	et	4	main
on	doc_432051777915_item	2404522	et	4	main
inimese	doc_432051777916_item	2404536	et	4	main
annavad	doc_432051777916_item	2404543	et	3	main
haridus	doc_432051777916_item	2404546	et	3	main
elule	doc_432051777916_item	2404559	et	3	main
tarkus	doc_432051777916_item	2404563	et	4	main
iseloom	doc_432051777916_item	2404565	et	3	main
et	doc_432051777916_item	2404579	et	3	main
inimese	doc_432051777916_item	2404625	et	4	main
aga	doc_432051777916_item	2404627	et	3	main
rukkub	doc_432051777916_item	2404630	et	4	main
kõik	doc_432051777916_item	2404637	et	4	main
mõjutab	doc_432051777916_item	2404639	et	3	main
inimese	doc_432051777916_item	2404640	et	4	main
span	doc_432051777916_item	2404645	et	4	main
mis	doc_432051777917_item	2404648	et	4	main
span	doc_432051777917_item	2404660	et	4	main
selline	doc_432051777917_item	2404664	et	4	main
kui	doc_432051777917_item	2404666	et	3	main
sa	doc_432051777917_item	2404680	et	3	main
et	doc_432051777917_item	2404684	et	3	main
saa	doc_432051777917_item	2404703	et	4	main
on	doc_432051777917_item	2404706	et	4	main
et	doc_432051777918_item	2404723	et	3	main
saama	doc_432051777918_item	2404733	et	4	main
leidma	doc_432051777918_item	2404746	et	3	main
et	doc_432051777918_item	2404752	et	3	main
sellepärast	doc_432051777918_item	2404766	et	3	main
aga	doc_432051777918_item	2404775	et	3	main
uus	doc_432051777920_item	2404948	et	3	main
dokument	doc_432051777920_item	2404949	et	3	main
üliõpilane	doc_432051777920_item	2404960	et	3	main
tähtsam	doc_432051777920_item	2404962	et	4	main
inglise	doc_432051777920_item	2404980	et	4	main
sellele	doc_432051777920_item	2404986	et	4	main
et	doc_432051777920_item	2404990	et	3	main
eestis	doc_432051777920_item	2404996	et	3	main
see	doc_432051777920_item	2405006	et	3	main
eesti	doc_432051777920_item	2405019	et	4	main
ajalehti	doc_432051777920_item	2405022	et	4	main
kirju	doc_432051777920_item	2405034	et	4	main
eesti	doc_432051777920_item	2405041	et	4	main
natuke	doc_432051777920_item	2405046	et	4	main
ei	doc_432051777920_item	2405054	et	4	main
saa	doc_432051777920_item	2405055	et	4	main
seda	doc_432051777920_item	2405056	et	3	main
väga	doc_432051777915_item	2404523	et	3	main
vanemad	doc_432051777916_item	2404540	et	4	main
sest	doc_432051777916_item	2404541	et	4	main
elu	doc_432051777916_item	2404548	et	4	main
vaade	doc_432051777916_item	2404549	et	3	main
raha	doc_432051777916_item	2404550	et	4	main
haridus	doc_432051777916_item	2404562	et	3	main
see	doc_432051777916_item	2404566	et	3	main
arvan	doc_432051777916_item	2404578	et	3	main
vanus	doc_432051777916_item	2404584	et	4	main
ei	doc_432051777916_item	2404585	et	4	main
ole	doc_432051777916_item	2404586	et	4	main
tähtis	doc_432051777916_item	2404587	et	4	main
kui	doc_432051777916_item	2404588	et	3	main
teile	doc_432051777916_item	2404589	et	4	main
on	doc_432051777916_item	2404590	et	4	main
haridus	doc_432051777916_item	2404591	et	3	main
ja	doc_432051777916_item	2404592	et	3	main
tarkus	doc_432051777916_item	2404593	et	4	main
rahvus	doc_432051777916_item	2404594	et	3	main
sest	doc_432051777916_item	2404595	et	4	main
kui	doc_432051777916_item	2404596	et	3	main
on	doc_432051777916_item	2404598	et	4	main
ta	doc_432051777916_item	2404597	et	4	main
eestlane	doc_432051777916_item	2404599	et	3	main
või	doc_432051777916_item	2404600	et	4	main
venelane	doc_432051777916_item	2404601	et	3	main
või	doc_432051777916_item	2404602	et	4	main
lätlane	doc_432051777916_item	2404603	et	3	main
see	doc_432051777916_item	2404604	et	3	main
ei	doc_432051777916_item	2404605	et	4	main
mõjutab	doc_432051777916_item	2404606	et	3	main
kõige	doc_432051777916_item	2404607	et	4	main
tähtsam	doc_432051777916_item	2404608	et	4	main
oma	doc_432051777916_item	2404609	et	4	main
iseloom	doc_432051777916_item	2404610	et	3	main
inimene	doc_432051777916_item	2404611	et	3	main
tähtkuju	doc_432051777916_item	2404612	et	4	main
on	doc_432051777916_item	2404613	et	4	main
kõige	doc_432051777916_item	2404614	et	4	main
ebatähtsam	doc_432051777916_item	2404615	et	4	main
span	doc_432051777916_item	2404616	et	4	main
ma	doc_432051777916_item	2404617	et	3	main
ei	doc_432051777916_item	2404618	et	4	main
rääkinud	doc_432051777916_item	2404619	et	4	main
rahast	doc_432051777916_item	2404620	et	4	main
arvan	doc_432051777916_item	2404622	et	3	main
mõjutab	doc_432051777916_item	2404624	et	3	main
elu	doc_432051777916_item	2404626	et	4	main
natuke	doc_432051777916_item	2404638	et	4	main
elu	doc_432051777916_item	2404641	et	4	main
elus	doc_432051777917_item	2404649	et	4	main
on	doc_432051777917_item	2404650	et	4	main
kõige	doc_432051777917_item	2404651	et	4	main
tähtsam	doc_432051777917_item	2404652	et	4	main
span	doc_432051777917_item	2404653	et	4	main
span	doc_432051777917_item	2404654	et	4	main
minu	doc_432051777917_item	2404655	et	3	main
rahad	doc_432051777916_item	2404629	et	4	main
ma	doc_432051777916_item	2404632	et	3	main
et	doc_432051777916_item	2404634	et	3	main
igaüksi	doc_432051777916_item	2404642	et	4	main
mõjutab	doc_432051777916_item	2404643	et	3	main
dokument	doc_432051777917_item	2404647	et	3	main
on	doc_432051777917_item	2404663	et	4	main
ole	doc_432051777917_item	2404669	et	4	main
lihtsalt	doc_432051777917_item	2404673	et	4	main
oled	doc_432051777917_item	2404674	et	3	main
ja	doc_432051777917_item	2404675	et	3	main
elada	doc_432051777917_item	2404682	et	3	main
vaja	doc_432051777917_item	2404694	et	4	main
on	doc_432051777917_item	2404698	et	4	main
armastus	doc_432051777917_item	2404707	et	4	main
need	doc_432051777917_item	2404709	et	3	main
asi	doc_432051777917_item	2404711	et	4	main
span	doc_432051777917_item	2404718	et	4	main
dokument	doc_432051777918_item	2404720	et	3	main
ma	doc_432051777918_item	2404721	et	3	main
väga	doc_432051777918_item	2404726	et	3	main
tähtis	doc_432051777918_item	2404727	et	4	main
minu	doc_432051777918_item	2404729	et	3	main
sellepärast	doc_432051777918_item	2404737	et	3	main
kui	doc_432051777918_item	2404739	et	3	main
väga	doc_432051777918_item	2404747	et	3	main
ma	doc_432051777918_item	2404750	et	3	main
et	doc_432051777918_item	2404767	et	3	main
jaoks	doc_432051777918_item	2404769	et	4	main
ja	doc_432051777918_item	2404773	et	3	main
välimus	doc_432051777918_item	2404779	et	3	main
õpetaja	doc_432051777920_item	2404951	et	4	main
minu	doc_432051777920_item	2404952	et	3	main
nimi	doc_432051777920_item	2404953	et	3	main
on	doc_432051777920_item	2404954	et	4	main
aastane	doc_432051777920_item	2404958	et	4	main
kursusele	doc_432051777920_item	2404987	et	3	main
venelane	doc_432051777920_item	2404993	et	3	main
keelt	doc_432051777920_item	2405002	et	4	main
teine	doc_432051777920_item	2405003	et	3	main
on	doc_432051777920_item	2405013	et	4	main
eesti	doc_432051777920_item	2405014	et	4	main
raamatud	doc_432051777920_item	2405020	et	4	main
raha	doc_432051777917_item	2404659	et	4	main
ei	doc_432051777917_item	2404668	et	4	main
siis	doc_432051777917_item	2404671	et	3	main
piiratad	doc_432051777917_item	2404676	et	4	main
enda	doc_432051777917_item	2404677	et	4	main
aga	doc_432051777917_item	2404678	et	3	main
kui	doc_432051777917_item	2404679	et	3	main
sull	doc_432051777917_item	2404685	et	4	main
lõbus	doc_432051777917_item	2404687	et	4	main
raha	doc_432051777917_item	2404695	et	4	main
asi	doc_432051777917_item	2404700	et	4	main
tähtsamaid	doc_432051777917_item	2404715	et	4	main
minu	doc_432051777917_item	2404716	et	3	main
meelest	doc_432051777917_item	2404717	et	4	main
arvan	doc_432051777918_item	2404722	et	3	main
väga	doc_432051777918_item	2404734	et	3	main
hea	doc_432051777918_item	2404735	et	4	main
on	doc_432051777918_item	2404741	et	4	main
haridus	doc_432051777918_item	2404743	et	3	main
ma	doc_432051777918_item	2404744	et	3	main
ole	doc_432051777918_item	2404764	et	4	main
minu	doc_432051777918_item	2404768	et	3	main
hing	doc_432051777918_item	2404772	et	3	main
ma	doc_432051777918_item	2404777	et	3	main
haridus	doc_432051777918_item	2404724	et	3	main
haridus	doc_432051777918_item	2404736	et	3	main
et	doc_432051777918_item	2404738	et	3	main
mul	doc_432051777918_item	2404740	et	3	main
hea	doc_432051777918_item	2404742	et	4	main
võin	doc_432051777918_item	2404745	et	3	main
haridus	doc_432051777918_item	2404753	et	3	main
mõjutab	doc_432051777918_item	2404754	et	3	main
inimese	doc_432051777918_item	2404755	et	4	main
elu	doc_432051777918_item	2404756	et	4	main
kõige	doc_432051777918_item	2404757	et	4	main
rohkem	doc_432051777918_item	2404758	et	4	main
aga	doc_432051777918_item	2404759	et	3	main
minu	doc_432051777918_item	2404760	et	3	main
jaoks	doc_432051777918_item	2404730	et	4	main
väga	doc_432051777918_item	2404731	et	3	main
tähtis	doc_432051777918_item	2404732	et	4	main
hea	doc_432051777918_item	2404748	et	4	main
töö	doc_432051777918_item	2404749	et	4	main
arvan	doc_432051777918_item	2404751	et	3	main
jaoks	doc_432051777918_item	2404761	et	4	main
välimus	doc_432051777918_item	2404762	et	3	main
ei	doc_432051777918_item	2404763	et	4	main
tähtis	doc_432051777918_item	2404770	et	4	main
inimeste	doc_432051777918_item	2404771	et	3	main
sisemaailm	doc_432051777918_item	2404774	et	3	main
tähtis	doc_432051777918_item	2404765	et	4	main
pärast	doc_432051777918_item	2404776	et	4	main
vaatan	doc_432051777918_item	2404778	et	3	main
span	doc_432051777918_item	2404780	et	4	main
tere	doc_432051777920_item	2404950	et	3	main
on	doc_432051777920_item	2404988	et	4	main
see	doc_432051777920_item	2404989	et	3	main
mina	doc_432051777920_item	2404991	et	4	main
olen	doc_432051777920_item	2404992	et	3	main
ja	doc_432051777920_item	2404994	et	3	main
elan	doc_432051777920_item	2404995	et	3	main
sest	doc_432051777920_item	2404997	et	4	main
ma	doc_432051777920_item	2404998	et	3	main
pean	doc_432051777920_item	2404999	et	4	main
põhjus	doc_432051777920_item	2405004	et	4	main
meldib	doc_432051777920_item	2405009	et	4	main
tahan	doc_432051777920_item	2405024	et	3	main
kuulata	doc_432051777920_item	2405025	et	4	main
tahan	doc_432051777920_item	2405028	et	3	main
loodan	doc_432051777920_item	2405036	et	3	main
me	doc_432051777920_item	2405038	et	4	main
keelega	doc_432051777920_item	2405042	et	3	main
et	doc_432051777920_item	2405047	et	3	main
teada	doc_432051777920_item	2405060	et	3	main
xxxx	doc_432051777920_item	2404955	et	4	main
polütehnikumi	doc_432051777920_item	2404959	et	4	main
kõige	doc_432051777920_item	2404961	et	4	main
minu	doc_432051777920_item	2404963	et	3	main
esimene	doc_432051777920_item	2404982	et	3	main
põhjus	doc_432051777920_item	2404983	et	4	main
tulin	doc_432051777920_item	2404985	et	3	main
eesti	doc_432051777920_item	2405001	et	4	main
on	doc_432051777920_item	2405005	et	4	main
keelt	doc_432051777920_item	2405015	et	4	main
vaja	doc_432051777920_item	2405016	et	4	main
ja	doc_432051777920_item	2405021	et	3	main
ma	doc_432051777920_item	2405023	et	3	main
telerit	doc_432051777920_item	2405026	et	3	main
ma	doc_432051777920_item	2405027	et	3	main
rääkida	doc_432051777920_item	2405029	et	3	main
ma	doc_432051777920_item	2405031	et	3	main
et	doc_432051777920_item	2405037	et	3	main
kardan	doc_432051777920_item	2405045	et	4	main
keel	doc_432051777920_item	2405049	et	4	main
raske	doc_432051777920_item	2405051	et	4	main
ja	doc_432051777920_item	2405052	et	3	main
ma	doc_432051777920_item	2405053	et	3	main
tegema	doc_432051777920_item	2405064	et	3	main
väga	doc_432051777920_item	2405069	et	3	main
ma	doc_432051777920_item	2405073	et	3	main
õppida	doc_432051777920_item	2405075	et	3	main
xxxxxxxxx	doc_432051777920_item	2405080	et	4	main
1pange	doc_432051777922_item	2405226	et	4	main
ja	doc_432051777922_item	2405229	et	3	main
masin	doc_432051777922_item	2405248	et	3	main
2	doc_432051777922_item	2405252	et	2	main
valja	doc_432051777922_item	2405264	et	3	main
jätke	doc_432051777922_item	2405267	et	4	main
tunniks	doc_432051777922_item	2405270	et	3	main
ja	doc_432051777922_item	2405281	et	3	main
dokument	doc_432051777923_item	2405284	et	3	main
vanemad	doc_432051777923_item	2405291	et	4	main
hea	doc_432051777923_item	2405301	et	4	main
ja	doc_432051777923_item	2405302	et	3	main
ja	doc_432051777923_item	2405312	et	3	main
nad	doc_432051777923_item	2405319	et	3	main
head	doc_432051777923_item	2405327	et	4	main
inimesed	doc_432051777923_item	2405328	et	3	main
olen	doc_432051777920_item	2404956	et	3	main
üheksateistkümne	doc_432051777920_item	2404957	et	4	main
elus	doc_432051777920_item	2404964	et	4	main
on	doc_432051777920_item	2404965	et	4	main
elu	doc_432051777920_item	2404966	et	4	main
ma	doc_432051777920_item	2404967	et	3	main
armastan	doc_432051777920_item	2404968	et	3	main
oma	doc_432051777920_item	2404969	et	4	main
pere	doc_432051777920_item	2404970	et	4	main
eesti	doc_432051777920_item	2404971	et	4	main
keelt	doc_432051777920_item	2404972	et	4	main
olen	doc_432051777920_item	2404973	et	3	main
õppinud	doc_432051777920_item	2404974	et	4	main
12	doc_432051777920_item	2404975	et	2	main
aastat	doc_432051777920_item	2404976	et	3	main
varem	doc_432051777920_item	2404977	et	4	main
olen	doc_432051777920_item	2404978	et	3	main
õppinud	doc_432051777920_item	2404979	et	4	main
keelt	doc_432051777920_item	2404981	et	4	main
miks	doc_432051777920_item	2404984	et	4	main
teama	doc_432051777920_item	2405000	et	4	main
et	doc_432051777920_item	2405007	et	3	main
mulle	doc_432051777920_item	2405008	et	4	main
eesti	doc_432051777920_item	2405010	et	4	main
keel	doc_432051777920_item	2405011	et	4	main
mul	doc_432051777920_item	2405012	et	3	main
et	doc_432051777920_item	2405017	et	3	main
lugelda	doc_432051777920_item	2405018	et	4	main
ma	doc_432051777920_item	2405035	et	3	main
tegeleme	doc_432051777920_item	2405039	et	3	main
põhjalikult	doc_432051777920_item	2405040	et	4	main
mina	doc_432051777920_item	2405044	et	4	main
ma	doc_432051777920_item	2405062	et	3	main
eesti	doc_432051777920_item	2405067	et	4	main
hästi	doc_432051777920_item	2405070	et	3	main
et	doc_432051777920_item	2405072	et	3	main
juhend	doc_432051777922_item	2405224	et	3	main
pesumasin	doc_432051777922_item	2405225	et	3	main
masinasse	doc_432051777922_item	2405228	et	4	main
valmis	doc_432051777922_item	2405231	et	4	main
ja	doc_432051777922_item	2405233	et	3	main
loputusvahendid	doc_432051777922_item	2405234	et	4	main
pistik	doc_432051777922_item	2405243	et	3	main
programm	doc_432051777922_item	2405246	et	3	main
pesu	doc_432051777922_item	2405262	et	4	main
masinast	doc_432051777922_item	2405263	et	4	main
luuk	doc_432051777922_item	2405268	et	3	main
paariks	doc_432051777922_item	2405269	et	4	main
ärge	doc_432051777922_item	2405278	et	3	main
kassid	doc_432051777922_item	2405280	et	3	main
tähtis	doc_432051777923_item	2405289	et	4	main
kui	doc_432051777923_item	2405290	et	3	main
edu	doc_432051777923_item	2405303	et	4	main
sest	doc_432051777923_item	2405310	et	4	main
tema	doc_432051777923_item	2405320	et	4	main
juurde	doc_432051777923_item	2405321	et	4	main
ka	doc_432051777923_item	2405333	et	3	main
ma	doc_432051777923_item	2405339	et	3	main
arvan	doc_432051777923_item	2405340	et	3	main
saatud	doc_432051777923_item	2405342	et	4	main
ka	doc_432051777923_item	2405344	et	3	main
edukas	doc_432051777923_item	2405350	et	4	main
poisid	doc_432051777924_item	2405409	et	4	main
sest	doc_432051777924_item	2405415	et	4	main
et	doc_432051777924_item	2405416	et	3	main
eestlastega	doc_432051777920_item	2405030	et	4	main
tahan	doc_432051777920_item	2405032	et	3	main
kirjutada	doc_432051777920_item	2405033	et	3	main
aga	doc_432051777920_item	2405043	et	3	main
eesti	doc_432051777920_item	2405048	et	4	main
on	doc_432051777920_item	2405050	et	4	main
ma	doc_432051777920_item	2405058	et	3	main
mida	doc_432051777920_item	2405061	et	4	main
et	doc_432051777920_item	2405065	et	3	main
keel	doc_432051777920_item	2405068	et	4	main
loodan	doc_432051777920_item	2405071	et	3	main
saan	doc_432051777920_item	2405074	et	4	main
eesti	doc_432051777920_item	2405076	et	4	main
teha	doc_432051777920_item	2405057	et	3	main
tahaksin	doc_432051777920_item	2405059	et	3	main
pean	doc_432051777920_item	2405063	et	4	main
teab	doc_432051777920_item	2405066	et	3	main
keelt	doc_432051777920_item	2405077	et	4	main
lugupidamisega	doc_432051777920_item	2405078	et	3	main
xxxxx	doc_432051777920_item	2405079	et	4	main
pesu	doc_432051777922_item	2405227	et	4	main
sulgege	doc_432051777922_item	2405235	et	3	main
pesumasina	doc_432051777922_item	2405237	et	3	main
ja	doc_432051777922_item	2405247	et	3	main
hakkab	doc_432051777922_item	2405249	et	3	main
pärast	doc_432051777922_item	2405251	et	4	main
kuivatage	doc_432051777922_item	2405265	et	3	main
nb	doc_432051777922_item	2405277	et	4	main
hoolitsevad	doc_432051777923_item	2405293	et	4	main
span	doc_432051777923_item	2405304	et	4	main
2	doc_432051777923_item	2405305	et	2	main
on	doc_432051777923_item	2405307	et	4	main
ka	doc_432051777923_item	2405308	et	3	main
tähtis	doc_432051777923_item	2405309	et	4	main
inimene	doc_432051777923_item	2405314	et	3	main
aru	doc_432051777923_item	2405316	et	4	main
ja	doc_432051777923_item	2405318	et	3	main
span	doc_432051777923_item	2405322	et	4	main
ja	doc_432051777923_item	2405329	et	3	main
pean	doc_432051777923_item	2405332	et	4	main
sõbrad	doc_432051777923_item	2405336	et	3	main
või	doc_432051777923_item	2405351	et	4	main
span	doc_432051777923_item	2405353	et	4	main
span	doc_432051777924_item	2405366	et	4	main
sellel	doc_432051777924_item	2405367	et	4	main
pildil	doc_432051777924_item	2405368	et	3	main
ma	doc_432051777924_item	2405369	et	3	main
näen	doc_432051777924_item	2405370	et	3	main
õu	doc_432051777924_item	2405371	et	4	main
mängivad	doc_432051777924_item	2405410	et	4	main
varsti	doc_432051777924_item	2405417	et	3	main
mõõtke	doc_432051777922_item	2405230	et	3	main
pesu-	doc_432051777922_item	2405232	et	4	main
luuk	doc_432051777922_item	2405238	et	3	main
täiteventiil	doc_432051777922_item	2405240	et	3	main
pistke	doc_432051777922_item	2405242	et	3	main
seinakontakti	doc_432051777922_item	2405244	et	4	main
masin	doc_432051777922_item	2405266	et	3	main
koerad	doc_432051777922_item	2405282	et	3	main
vanemad	doc_432051777923_item	2405286	et	4	main
on	doc_432051777923_item	2405287	et	4	main
väga	doc_432051777923_item	2405288	et	3	main
minu	doc_432051777923_item	2405294	et	3	main
eest	doc_432051777923_item	2405295	et	4	main
minu	doc_432051777923_item	2405297	et	3	main
elu	doc_432051777923_item	2405298	et	4	main
edasi	doc_432051777923_item	2405299	et	3	main
tark	doc_432051777923_item	2405313	et	3	main
saab	doc_432051777923_item	2405315	et	3	main
teineteisega	doc_432051777923_item	2405317	et	3	main
hoolikalt	doc_432051777922_item	2405236	et	4	main
avage	doc_432051777922_item	2405239	et	3	main
ja	doc_432051777922_item	2405241	et	3	main
vali	doc_432051777922_item	2405245	et	4	main
töötama	doc_432051777922_item	2405250	et	3	main
tundi	doc_432051777922_item	2405253	et	4	main
masin	doc_432051777922_item	2405254	et	3	main
pesu	doc_432051777922_item	2405255	et	4	main
pesta	doc_432051777922_item	2405256	et	4	main
edasi	doc_432051777922_item	2405257	et	3	main
avage	doc_432051777922_item	2405258	et	3	main
luuk	doc_432051777922_item	2405259	et	3	main
ja	doc_432051777922_item	2405260	et	3	main
võtke	doc_432051777922_item	2405261	et	3	main
lahti	doc_432051777922_item	2405271	et	4	main
ja	doc_432051777922_item	2405272	et	3	main
masin	doc_432051777922_item	2405273	et	3	main
saaks	doc_432051777922_item	2405274	et	3	main
seest	doc_432051777922_item	2405275	et	3	main
kuivada	doc_432051777922_item	2405276	et	4	main
pesta	doc_432051777922_item	2405279	et	4	main
uus	doc_432051777923_item	2405283	et	3	main
1	doc_432051777923_item	2405285	et	2	main
väga	doc_432051777923_item	2405292	et	3	main
siis	doc_432051777923_item	2405296	et	3	main
on	doc_432051777923_item	2405300	et	4	main
iseloom	doc_432051777923_item	2405306	et	3	main
hea	doc_432051777923_item	2405311	et	4	main
3	doc_432051777923_item	2405323	et	2	main
kui	doc_432051777923_item	2405324	et	3	main
sõbrad	doc_432051777923_item	2405325	et	3	main
on	doc_432051777923_item	2405326	et	4	main
minu	doc_432051777923_item	2405335	et	3	main
tulevikus	doc_432051777923_item	2405348	et	4	main
raha	doc_432051777923_item	2405360	et	4	main
span	doc_432051777923_item	2405363	et	4	main
õues	doc_432051777924_item	2405372	et	4	main
on	doc_432051777924_item	2405373	et	4	main
spordiväljak	doc_432051777924_item	2405374	et	3	main
arvan	doc_432051777924_item	2405401	et	3	main
nad	doc_432051777924_item	2405413	et	3	main
naeratavad	doc_432051777924_item	2405414	et	4	main
ma	doc_432051777924_item	2405420	et	3	main
arvan	doc_432051777924_item	2405421	et	3	main
ründemängija	doc_432051777924_item	2405435	et	4	main
jalgpallis	doc_432051777924_item	2405436	et	3	main
aga	doc_432051777924_item	2405437	et	3	main
väike	doc_432051777924_item	2405438	et	4	main
poiss	doc_432051777924_item	2405439	et	3	main
nendele	doc_432051777924_item	2405445	et	4	main
või	doc_432051777924_item	2405447	et	4	main
kümme	doc_432051777924_item	2405448	et	3	main
ole	doc_432051777924_item	2405461	et	4	main
ei	doc_432051777924_item	2405468	et	4	main
kedagi	doc_432051777925_item	2405489	et	4	main
leidmine	doc_432051777925_item	2405499	et	4	main
sest	doc_432051777925_item	2405505	et	4	main
inimene	doc_432051777925_item	2405507	et	3	main
tavaliselt	doc_432051777925_item	2405509	et	4	main
ka	doc_432051777925_item	2405510	et	3	main
parema	doc_432051777925_item	2405511	et	4	main
töökoha	doc_432051777925_item	2405512	et	4	main
inimeste	doc_432051777925_item	2405517	et	3	main
toetus	doc_432051777925_item	2405529	et	4	main
span	doc_432051777925_item	2405530	et	4	main
vahend	doc_432051777925_item	2405535	et	3	main
veendunud	doc_432051777925_item	2405541	et	4	main
et	doc_432051777925_item	2405542	et	3	main
arvates	doc_432051777926_item	2405550	et	4	main
et	doc_432051777926_item	2405556	et	3	main
palju	doc_432051777926_item	2405558	et	4	main
selleta	doc_432051777926_item	2405565	et	3	main
elu	doc_432051777926_item	2405566	et	4	main
on	doc_432051777926_item	2405567	et	4	main
inemesel	doc_432051777926_item	2405571	et	4	main
ja	doc_432051777926_item	2405576	et	3	main
siis	doc_432051777923_item	2405330	et	3	main
ma	doc_432051777923_item	2405331	et	3	main
nagu	doc_432051777923_item	2405334	et	3	main
span	doc_432051777923_item	2405337	et	4	main
on	doc_432051777923_item	2405343	et	4	main
on	doc_432051777923_item	2405349	et	4	main
ebaedukas	doc_432051777923_item	2405352	et	4	main
5	doc_432051777923_item	2405354	et	2	main
käesoleval	doc_432051777923_item	2405355	et	3	main
ajal	doc_432051777923_item	2405356	et	4	main
ma	doc_432051777923_item	2405357	et	3	main
maailma	doc_432051777923_item	2405361	et	4	main
valitsevad	doc_432051777923_item	2405362	et	4	main
uus	doc_432051777924_item	2405364	et	3	main
dokument	doc_432051777924_item	2405365	et	3	main
ma	doc_432051777924_item	2405375	et	3	main
arvan	doc_432051777924_item	2405376	et	3	main
et	doc_432051777924_item	2405377	et	3	main
see	doc_432051777924_item	2405378	et	3	main
õu	doc_432051777924_item	2405379	et	4	main
asub	doc_432051777924_item	2405380	et	3	main
meie	doc_432051777924_item	2405381	et	4	main
pealinnas	doc_432051777924_item	2405382	et	4	main
tallinnas	doc_432051777924_item	2405383	et	4	main
staadionil	doc_432051777924_item	2405384	et	3	main
mängivad	doc_432051777924_item	2405385	et	4	main
pikk	doc_432051777924_item	2405386	et	4	main
ja	doc_432051777924_item	2405387	et	3	main
väike	doc_432051777924_item	2405388	et	4	main
poisid	doc_432051777924_item	2405389	et	4	main
nad	doc_432051777924_item	2405390	et	3	main
mängivad	doc_432051777924_item	2405391	et	4	main
jalgpalli	doc_432051777924_item	2405392	et	4	main
väike	doc_432051777924_item	2405393	et	4	main
poiss	doc_432051777924_item	2405394	et	3	main
on	doc_432051777924_item	2405395	et	4	main
väga	doc_432051777924_item	2405396	et	3	main
rõõmus	doc_432051777924_item	2405397	et	4	main
päike	doc_432051777924_item	2405398	et	3	main
paistab	doc_432051777924_item	2405399	et	3	main
4	doc_432051777923_item	2405338	et	2	main
et	doc_432051777923_item	2405341	et	3	main
tähtis	doc_432051777923_item	2405345	et	4	main
sest	doc_432051777923_item	2405346	et	4	main
inimene	doc_432051777923_item	2405347	et	3	main
arvan	doc_432051777923_item	2405358	et	3	main
et	doc_432051777923_item	2405359	et	3	main
ma	doc_432051777924_item	2405400	et	3	main
see	doc_432051777924_item	2405403	et	3	main
kevad	doc_432051777924_item	2405405	et	3	main
jalgpalli	doc_432051777924_item	2405411	et	4	main
suvi	doc_432051777924_item	2405419	et	3	main
tulevikus	doc_432051777924_item	2405425	et	4	main
tuntud	doc_432051777924_item	2405427	et	4	main
praegu	doc_432051777924_item	2405442	et	3	main
vana	doc_432051777924_item	2405450	et	4	main
kooskõlas	doc_432051777924_item	2405462	et	3	main
kõrguse	doc_432051777924_item	2405463	et	4	main
mida	doc_432051777924_item	2405470	et	4	main
ütlema	doc_432051777924_item	2405473	et	3	main
span	doc_432051777924_item	2405475	et	4	main
uus	doc_432051777925_item	2405476	et	3	main
dokument	doc_432051777925_item	2405477	et	3	main
sest	doc_432051777925_item	2405485	et	4	main
äga	doc_432051777925_item	2405491	et	4	main
elukoht	doc_432051777925_item	2405494	et	3	main
sellest	doc_432051777925_item	2405496	et	4	main
sõltub	doc_432051777925_item	2405497	et	3	main
töökoha	doc_432051777925_item	2405498	et	4	main
on	doc_432051777925_item	2405502	et	4	main
haritud	doc_432051777925_item	2405506	et	4	main
saab	doc_432051777925_item	2405508	et	3	main
ümbritsevate	doc_432051777925_item	2405516	et	4	main
väga	doc_432051777925_item	2405522	et	3	main
tähtis	doc_432051777925_item	2405523	et	4	main
sõbrad	doc_432051777925_item	2405525	et	3	main
on	doc_432051777925_item	2405526	et	4	main
tähtsad	doc_432051777925_item	2405527	et	3	main
nagu	doc_432051777925_item	2405528	et	3	main
tähtis	doc_432051777925_item	2405534	et	4	main
elukls	doc_432051777925_item	2405537	et	4	main
ma	doc_432051777925_item	2405539	et	3	main
uus	doc_432051777926_item	2405547	et	3	main
dokument	doc_432051777926_item	2405548	et	3	main
minu	doc_432051777926_item	2405549	et	3	main
on	doc_432051777926_item	2405553	et	4	main
tahtis	doc_432051777926_item	2405555	et	3	main
sellest	doc_432051777926_item	2405557	et	4	main
sõltub	doc_432051777926_item	2405559	et	3	main
span	doc_432051777926_item	2405569	et	4	main
et	doc_432051777924_item	2405402	et	3	main
on	doc_432051777924_item	2405404	et	4	main
selle	doc_432051777924_item	2405406	et	4	main
pärast	doc_432051777924_item	2405407	et	4	main
et	doc_432051777924_item	2405408	et	3	main
riietuses	doc_432051777924_item	2405412	et	4	main
see	doc_432051777924_item	2405423	et	3	main
väravavaht	doc_432051777924_item	2405441	et	3	main
võib	doc_432051777924_item	2405443	et	3	main
kaheksa	doc_432051777924_item	2405446	et	4	main
aastat	doc_432051777924_item	2405449	et	3	main
nb	doc_432051777924_item	2405453	et	4	main
jutustus	doc_432051777924_item	2405459	et	4	main
ei	doc_432051777924_item	2405460	et	4	main
ma	doc_432051777924_item	2405471	et	3	main
saan	doc_432051777924_item	2405472	et	4	main
rohkem	doc_432051777924_item	2405474	et	4	main
minu	doc_432051777925_item	2405478	et	3	main
arvates	doc_432051777925_item	2405479	et	4	main
et	doc_432051777925_item	2405480	et	3	main
väga	doc_432051777925_item	2405481	et	3	main
et	doc_432051777925_item	2405486	et	3	main
ei	doc_432051777925_item	2405487	et	4	main
ole	doc_432051777925_item	2405488	et	4	main
tähtis	doc_432051777925_item	2405492	et	4	main
on	doc_432051777925_item	2405493	et	4	main
sest	doc_432051777925_item	2405495	et	4	main
haridus	doc_432051777925_item	2405501	et	3	main
span	doc_432051777925_item	2405513	et	4	main
iseloom	doc_432051777925_item	2405514	et	3	main
on	doc_432051777925_item	2405544	et	4	main
tingitud	doc_432051777925_item	2405545	et	4	main
elukoht	doc_432051777926_item	2405552	et	3	main
väga	doc_432051777926_item	2405554	et	3	main
raha	doc_432051777926_item	2405564	et	4	main
tema	doc_432051777926_item	2405577	et	4	main
elu	doc_432051777926_item	2405578	et	4	main
on	doc_432051777926_item	2405579	et	4	main
heitlik	doc_432051777926_item	2405580	et	3	main
tuleb	doc_432051777924_item	2405418	et	3	main
et	doc_432051777924_item	2405422	et	3	main
olevad	doc_432051777924_item	2405426	et	4	main
ma	doc_432051777924_item	2405429	et	3	main
mõtlen	doc_432051777924_item	2405430	et	3	main
pikk	doc_432051777924_item	2405432	et	4	main
poiss	doc_432051777924_item	2405433	et	3	main
oleb	doc_432051777924_item	2405434	et	4	main
span	doc_432051777924_item	2405451	et	4	main
palun	doc_432051777924_item	2405455	et	3	main
vabandage	doc_432051777924_item	2405456	et	3	main
et	doc_432051777924_item	2405457	et	3	main
tea	doc_432051777924_item	2405469	et	4	main
on	doc_432051777925_item	2405483	et	4	main
vanemad	doc_432051777925_item	2405484	et	4	main
lähedased	doc_432051777925_item	2405490	et	3	main
span	doc_432051777925_item	2405500	et	4	main
tähtis	doc_432051777925_item	2405504	et	4	main
mõjutab	doc_432051777925_item	2405515	et	3	main
kuid	doc_432051777925_item	2405519	et	4	main
poisid	doc_432051777924_item	2405424	et	4	main
sportlased	doc_432051777924_item	2405428	et	3	main
et	doc_432051777924_item	2405431	et	3	main
oleb	doc_432051777924_item	2405440	et	4	main
olla	doc_432051777924_item	2405444	et	3	main
span	doc_432051777924_item	2405452	et	4	main
span	doc_432051777924_item	2405454	et	4	main
minu	doc_432051777924_item	2405458	et	3	main
selle	doc_432051777924_item	2405464	et	4	main
pärast	doc_432051777924_item	2405465	et	4	main
et	doc_432051777924_item	2405466	et	3	main
ma	doc_432051777924_item	2405467	et	3	main
tähtis	doc_432051777925_item	2405482	et	4	main
väga	doc_432051777925_item	2405503	et	3	main
suhtlusi	doc_432051777925_item	2405518	et	3	main
see	doc_432051777925_item	2405520	et	3	main
span	doc_432051777925_item	2405546	et	4	main
span	doc_432051777926_item	2405560	et	4	main
väga	doc_432051777926_item	2405561	et	3	main
tähtis	doc_432051777926_item	2405562	et	4	main
iseloom	doc_432051777926_item	2405570	et	3	main
võib	doc_432051777926_item	2405572	et	3	main
nõrk	doc_432051777926_item	2405574	et	3	main
span	doc_432051777926_item	2405581	et	4	main
minu	doc_432051777926_item	2405582	et	3	main
elus	doc_437545024342_item	2405829	et	4	main
20	doc_437545024342_item	2405835	et	2	main
1991	doc_437545024342_item	2405837	et	2	main
a	doc_437545024342_item	2405838	et	4	main
kuulutas	doc_437545024342_item	2405839	et	3	main
1	doc_437545024342_item	2405844	et	2	main
elus	doc_437545024342_item	2405848	et	4	main
muutused	doc_437545024342_item	2405851	et	4	main
jäle	doc_437545024342_item	2405860	et	3	main
kuulusid	doc_437545024342_item	2405879	et	4	main
ja	doc_437545024342_item	2405887	et	3	main
balti	doc_437545024342_item	2405888	et	3	main
riikides	doc_437545024342_item	2405889	et	3	main
isegi	doc_437545024342_item	2405890	et	4	main
tehti	doc_437545024342_item	2405891	et	3	main
balti	doc_437545024342_item	2405892	et	3	main
kett	doc_437545024342_item	2405893	et	4	main
milles	doc_437545024342_item	2405894	et	3	main
muutuvatest	doc_437545024342_item	2405907	et	4	main
poliitilises	doc_437545024342_item	2405912	et	3	main
1991	doc_437545024342_item	2405914	et	2	main
ja	doc_437545024342_item	2405935	et	3	main
majandusreform	doc_437545024342_item	2405939	et	3	main
eestis	doc_437545024342_item	2405976	et	3	main
sellele	doc_437545024342_item	2405984	et	4	main
et	doc_437545024342_item	2405985	et	3	main
on	doc_432051777925_item	2405521	et	4	main
span	doc_432051777925_item	2405524	et	4	main
aga	doc_432051777925_item	2405531	et	3	main
raha	doc_432051777925_item	2405532	et	4	main
on	doc_432051777925_item	2405533	et	4	main
selleks	doc_432051777925_item	2405536	et	4	main
span	doc_432051777925_item	2405538	et	4	main
olen	doc_432051777925_item	2405540	et	3	main
saatus	doc_432051777925_item	2405543	et	3	main
et	doc_432051777926_item	2405551	et	3	main
on	doc_432051777926_item	2405563	et	4	main
võimatu	doc_432051777926_item	2405568	et	4	main
olla	doc_432051777926_item	2405573	et	3	main
tahtetu	doc_432051777926_item	2405575	et	4	main
arvates	doc_432051777926_item	2405583	et	4	main
et	doc_432051777926_item	2405584	et	3	main
väga	doc_432051777926_item	2405585	et	3	main
tahtis	doc_432051777926_item	2405586	et	3	main
on	doc_432051777926_item	2405587	et	4	main
vanemad	doc_432051777926_item	2405588	et	4	main
sest	doc_432051777926_item	2405589	et	4	main
nad	doc_432051777926_item	2405590	et	3	main
on	doc_432051777926_item	2405591	et	4	main
väga	doc_432051777926_item	2405592	et	3	main
tahtsad	doc_432051777926_item	2405593	et	4	main
minu	doc_432051777926_item	2405594	et	3	main
elus	doc_432051777926_item	2405595	et	4	main
span	doc_432051777926_item	2405596	et	4	main
väga	doc_432051777926_item	2405597	et	3	main
tähtis	doc_432051777926_item	2405598	et	4	main
on	doc_432051777926_item	2405599	et	4	main
iseloom	doc_432051777926_item	2405600	et	3	main
sellepärast	doc_432051777926_item	2405601	et	3	main
et	doc_432051777926_item	2405602	et	3	main
ei	doc_432051777926_item	2405603	et	4	main
toonud	doc_432051777926_item	2405604	et	4	main
üksindus	doc_432051777926_item	2405605	et	3	main
span	doc_432051777926_item	2405606	et	4	main
1	doc_437545024342_item	2405822	et	2	main
muudatused	doc_437545024342_item	2405825	et	3	main
2	doc_437545024342_item	2405830	et	2	main
laulev	doc_437545024342_item	2405833	et	4	main
taastatuks	doc_437545024342_item	2405843	et	4	main
eesti	doc_437545024342_item	2405846	et	4	main
varem	doc_437545024342_item	2405856	et	4	main
kui	doc_437545024342_item	2405857	et	3	main
tiitma	doc_437545024342_item	2405885	et	4	main
tekkimine	doc_437545024342_item	2405886	et	4	main
2	doc_437545024342_item	2405897	et	2	main
muudatustest	doc_437545024342_item	2405909	et	3	main
taasisesisvunud	doc_437545024342_item	2405910	et	4	main
ülemnõukogu	doc_437545024342_item	2405919	et	4	main
enne	doc_437545024342_item	2405921	et	4	main
balti	doc_437545024342_item	2405925	et	3	main
riikides	doc_437545024342_item	2405926	et	3	main
keeleseadus	doc_437545024342_item	2405927	et	4	main
muidugi	doc_437545024342_item	2405928	et	4	main
see	doc_437545024342_item	2405929	et	3	main
jäi	doc_437545024342_item	2405930	et	3	main
kehtima	doc_437545024342_item	2405931	et	3	main
pärast	doc_437545024342_item	2405933	et	4	main
hakati	doc_437545024342_item	2405936	et	3	main
elus	doc_437545024342_item	2405942	et	4	main
muudatus	doc_437545024342_item	2405944	et	4	main
a	doc_437545024342_item	2405947	et	4	main
võeti	doc_437545024342_item	2405948	et	3	main
vastu	doc_437545024342_item	2405949	et	3	main
uus	doc_437545024342_item	2405950	et	3	main
põhiseadus	doc_437545024342_item	2405951	et	4	main
millele	doc_437545024342_item	2405952	et	3	main
järgnesid	doc_437545024342_item	2405953	et	4	main
kuhu	doc_437545024342_item	2405963	et	3	main
kuulus	doc_437545024342_item	2405964	et	4	main
president	doc_437545024342_item	2405967	et	3	main
meri	doc_437545024342_item	2405969	et	3	main
esimeseks	doc_437545024342_item	2405973	et	3	main
suured	doc_437545024342_item	2405977	et	3	main
muudatused	doc_437545024342_item	2405978	et	3	main
eesti	doc_437545024342_item	2405980	et	4	main
poliitilises	doc_437545024342_item	2405981	et	3	main
elus	doc_437545024342_item	2405982	et	4	main
ei	doc_437545024342_item	2405987	et	4	main
onud	doc_437545024342_item	2405988	et	3	main
enam	doc_437545024342_item	2405989	et	4	main
elu	doc_437545024342_item	2405995	et	4	main
referendum	doc_437545024342_item	2406022	et	3	main
euroopa	doc_437545024342_item	2406024	et	4	main
eesti	doc_437545024342_item	2405827	et	4	main
tähendab	doc_437545024342_item	2405832	et	3	main
revolutsioon	doc_437545024342_item	2405834	et	3	main
augustil	doc_437545024342_item	2405836	et	3	main
eesti	doc_437545024342_item	2405840	et	4	main
ja	doc_437545024342_item	2405852	et	3	main
muudatused	doc_437545024342_item	2405853	et	3	main
iseseisvaks	doc_437545024342_item	2405861	et	3	main
kuhu	doc_437545024342_item	2405878	et	3	main
umbes	doc_437545024342_item	2405896	et	4	main
nime	doc_437545024342_item	2405899	et	4	main
seda	doc_437545024342_item	2405900	et	3	main
saa	doc_437545024342_item	2405902	et	4	main
jätta	doc_437545024342_item	2405903	et	3	main
mainimata	doc_437545024342_item	2405904	et	4	main
kui	doc_437545024342_item	2405905	et	3	main
räägime	doc_437545024342_item	2405906	et	3	main
toimusid	doc_437545024342_item	2405916	et	4	main
kongressi	doc_437545024342_item	2405920	et	4	main
võeti	doc_437545024342_item	2405923	et	3	main
eestis	doc_437545024342_item	2405934	et	3	main
läbi	doc_437545024342_item	2405937	et	4	main
hääli	doc_437545024342_item	2405959	et	4	main
paremtsentristlik	doc_437545024342_item	2405960	et	3	main
parei	doc_437545024342_item	2405961	et	4	main
isamaaliit	doc_437545024342_item	2405962	et	3	main
meri	doc_437545024342_item	2405971	et	3	main
toimusid	doc_437545024342_item	2405979	et	4	main
eesti	doc_437545024342_item	2405986	et	4	main
sõltuv	doc_437545024342_item	2405992	et	4	main
kontrolltöö	doc_437545024342_item	2405821	et	4	main
poliitilises	doc_437545024342_item	2405828	et	3	main
ülemnõukogu	doc_437545024342_item	2405841	et	4	main
taasiseseisvunud	doc_437545024342_item	2405845	et	4	main
poliitilises	doc_437545024342_item	2405847	et	3	main
hakkasid	doc_437545024342_item	2405849	et	4	main
toimuma	doc_437545024342_item	2405850	et	3	main
eesti	doc_437545024342_item	2405858	et	4	main
sa	doc_437545024342_item	2405859	et	3	main
e	doc_437545024342_item	2405880	et	4	main
savisaar	doc_437545024342_item	2405881	et	3	main
s	doc_437545024342_item	2405882	et	4	main
kallas	doc_437545024342_item	2405883	et	4	main
made	doc_437545024342_item	2405884	et	3	main
ei	doc_437545024342_item	2405901	et	4	main
eesti	doc_437545024342_item	2405911	et	4	main
elus	doc_437545024342_item	2405913	et	4	main
ka	doc_437545024342_item	2405932	et	3	main
viima	doc_437545024342_item	2405938	et	3	main
poliitilises	doc_437545024342_item	2405941	et	3	main
toimus	doc_437545024342_item	2405943	et	3	main
et	doc_437545024342_item	2405945	et	3	main
1992	doc_437545024342_item	2405946	et	2	main
tulevane	doc_437545024342_item	2405966	et	3	main
presidendiks	doc_437545024342_item	2405974	et	4	main
taasiseseisvunud	doc_437545024342_item	2405975	et	4	main
tänu	doc_437545024342_item	2405983	et	4	main
poliitiliselt	doc_437545024342_item	2405990	et	4	main
poliitiline	doc_437545024342_item	2405994	et	3	main
astumisest	doc_437545024342_item	2406026	et	4	main
1988	doc_437545024342_item	2406032	et	2	main
a	doc_437545024342_item	2406033	et	4	main
nn	doc_437545024342_item	2406040	et	4	main
läbi	doc_437545024342_item	2406057	et	4	main
laulude	doc_437545024342_item	2406058	et	3	main
ning	doc_437545024342_item	2406059	et	3	main
see	doc_437545024342_item	2406060	et	3	main
sündmus	doc_437545024342_item	2406061	et	3	main
kodu	doc_438857714625_item	2406070	et	4	main
ma	doc_438857714625_item	2406071	et	3	main
elan	doc_438857714625_item	2406072	et	3	main
eesti	doc_438857714625_item	2406073	et	4	main
linnas	doc_438857714625_item	2406079	et	4	main
on	doc_438857714625_item	2406091	et	4	main
kasvavad	doc_438857714625_item	2406094	et	4	main
põõsad	doc_438857714625_item	2406097	et	3	main
mänguväljak	doc_438857714625_item	2406111	et	3	main
ja	doc_438857714625_item	2406117	et	3	main
on	doc_438857714625_item	2406121	et	4	main
lähedal	doc_438857714625_item	2406125	et	4	main
ja	doc_438857714625_item	2406128	et	3	main
pähklimääe	doc_438857714625_item	2406131	et	4	main
gimnasiuumis	doc_438857714625_item	2406132	et	4	main
lasteaed	doc_438857714625_item	2406133	et	3	main
kaubakeskus	doc_438857714625_item	2406134	et	3	main
juuksla	doc_438857714625_item	2406137	et	4	main
baar	doc_438857714625_item	2406138	et	3	main
käin	doc_438857714625_item	2406141	et	3	main
õues	doc_438857714625_item	2406142	et	4	main
jalutamas	doc_438857714625_item	2406144	et	3	main
elan	doc_438857714625_item	2406146	et	3	main
korrusel	doc_438857714625_item	2406150	et	3	main
mugavustega	doc_438857714625_item	2406156	et	4	main
muutused	doc_437545024342_item	2405823	et	4	main
ja	doc_437545024342_item	2405824	et	3	main
taasiseseisvunud	doc_437545024342_item	2405826	et	4	main
mida	doc_437545024342_item	2405831	et	4	main
iseseisvuse	doc_437545024342_item	2405842	et	4	main
juba	doc_437545024342_item	2405854	et	3	main
palju	doc_437545024342_item	2405855	et	4	main
sest	doc_437545024342_item	2405862	et	4	main
nagu	doc_437545024342_item	2405863	et	3	main
ma	doc_437545024342_item	2405864	et	3	main
tean	doc_437545024342_item	2405865	et	3	main
eesti	doc_437545024342_item	2405866	et	4	main
sai	doc_437545024342_item	2405867	et	4	main
taasiseseisvaks	doc_437545024342_item	2405868	et	3	main
1991	doc_437545024342_item	2405869	et	2	main
aastal	doc_437545024342_item	2405870	et	3	main
kuid	doc_437545024342_item	2405871	et	4	main
sellele	doc_437545024342_item	2405872	et	4	main
eelnesid	doc_437545024342_item	2405873	et	4	main
meeleavaldused	doc_437545024342_item	2405874	et	3	main
rahvuslikud	doc_437545024342_item	2405875	et	3	main
liikumised	doc_437545024342_item	2405876	et	4	main
rahvarinne	doc_437545024342_item	2405877	et	3	main
osales	doc_437545024342_item	2405895	et	3	main
miljonit	doc_437545024342_item	2405898	et	3	main
ja	doc_437545024342_item	2405908	et	3	main
aastal	doc_437545024342_item	2405915	et	3	main
valimised	doc_437545024342_item	2405917	et	4	main
eesti	doc_437545024342_item	2405918	et	4	main
taasiseseisvumist	doc_437545024342_item	2405922	et	3	main
vasti	doc_437545024342_item	2405924	et	4	main
eesti	doc_437545024342_item	2405940	et	4	main
ka	doc_437545024342_item	2405954	et	3	main
esimesed	doc_437545024342_item	2405955	et	3	main
põhiseaduslikud	doc_437545024342_item	2405956	et	3	main
sai	doc_437545024342_item	2405957	et	4	main
enim	doc_437545024342_item	2405958	et	4	main
ka	doc_437545024342_item	2405965	et	3	main
lennart	doc_437545024342_item	2405968	et	4	main
lennart	doc_437545024342_item	2405970	et	4	main
sai	doc_437545024342_item	2405972	et	4	main
moskvast	doc_437545024342_item	2405991	et	4	main
võttis	doc_437545024342_item	2405996	et	3	main
suunda	doc_437545024342_item	2405997	et	4	main
euroopale	doc_437545024342_item	2405998	et	3	main
oli	doc_437545024342_item	2405999	et	3	main
ka	doc_437545024342_item	2406000	et	3	main
allkirjutatud	doc_437545024342_item	2406001	et	3	main
euroopa	doc_437545024342_item	2406002	et	4	main
liiduga	doc_437545024342_item	2406003	et	3	main
kaubandusleping	doc_437545024342_item	2406004	et	3	main
see	doc_437545024342_item	2406005	et	3	main
tähendab	doc_437545024342_item	2406006	et	3	main
tihedat	doc_437545024342_item	2406007	et	3	main
koostööd	doc_437545024342_item	2406008	et	4	main
euroopa	doc_437545024342_item	2406009	et	4	main
riikidega	doc_437545024342_item	2406010	et	3	main
eesti	doc_437545024342_item	2406011	et	4	main
võeti	doc_437545024342_item	2406012	et	3	main
vastu	doc_437545024342_item	2406013	et	3	main
ka	doc_437545024342_item	2406014	et	3	main
ürosse	doc_437545024342_item	2406015	et	4	main
sel	doc_437545024342_item	2406016	et	3	main
aastal	doc_437545024342_item	2406017	et	3	main
peaks	doc_437545024342_item	2406018	et	4	main
eestis	doc_437545024342_item	2406019	et	3	main
toimuma	doc_437545024342_item	2406020	et	3	main
2	doc_437545024342_item	2406027	et	2	main
lauluväljakul	doc_437545024342_item	2406036	et	3	main
rahvusliku	doc_437545024342_item	2406037	et	3	main
väljendada	doc_437545024342_item	2406047	et	3	main
on	doc_437545024342_item	2406053	et	4	main
meeleavaldus	doc_437545024342_item	2406054	et	3	main
eesti	doc_437545024342_item	2406063	et	4	main
ajalukku	doc_437545024342_item	2406064	et	4	main
vabariigis	doc_438857714625_item	2406074	et	3	main
ida	doc_438857714625_item	2406075	et	4	main
viru	doc_438857714625_item	2406076	et	4	main
kivimajas	doc_438857714625_item	2406088	et	4	main
maja	doc_438857714625_item	2406089	et	4	main
ümbruses	doc_438857714625_item	2406090	et	3	main
ilus	doc_438857714625_item	2406101	et	4	main
õue	doc_438857714625_item	2406107	et	4	main
kõnnitee	doc_438857714625_item	2406116	et	4	main
segamets	doc_438857714625_item	2406118	et	3	main
eesti	doc_437545024342_item	2405993	et	4	main
liitu	doc_437545024342_item	2406025	et	4	main
revolutsioon	doc_437545024342_item	2406029	et	3	main
juuni	doc_437545024342_item	2406030	et	4	main
korraldatud	doc_437545024342_item	2406034	et	4	main
öölaulupidu	doc_437545024342_item	2406041	et	4	main
millel	doc_437545024342_item	2406042	et	3	main
lauldi	doc_437545024342_item	2406043	et	3	main
isamaalaulud	doc_437545024342_item	2406044	et	3	main
sellega	doc_437545024342_item	2406045	et	3	main
oma	doc_437545024342_item	2406048	et	4	main
minu	doc_438857714625_item	2406080	et	3	main
palju	doc_438857714625_item	2406092	et	4	main
ääres	doc_438857714625_item	2406099	et	4	main
on	doc_438857714625_item	2406100	et	4	main
laste	doc_438857714625_item	2406110	et	4	main
ees	doc_438857714625_item	2406113	et	4	main
maja	doc_438857714625_item	2406119	et	4	main
ka	doc_437545024342_item	2406021	et	3	main
eesti	doc_437545024342_item	2406023	et	4	main
laulev	doc_437545024342_item	2406028	et	4	main
algul	doc_437545024342_item	2406031	et	4	main
liikumise	doc_437545024342_item	2406038	et	4	main
korraldatud	doc_437545024342_item	2406039	et	4	main
soovi	doc_437545024342_item	2406049	et	4	main
saada	doc_437545024342_item	2406050	et	4	main
iseseisvaks	doc_437545024342_item	2406051	et	3	main
see	doc_437545024342_item	2406052	et	3	main
tallinnas	doc_437545024342_item	2406035	et	4	main
püüti	doc_437545024342_item	2406046	et	3	main
mis	doc_437545024342_item	2406055	et	4	main
kui	doc_437545024342_item	2406065	et	3	main
laulev	doc_437545024342_item	2406066	et	4	main
revolutsioon	doc_437545024342_item	2406067	et	3	main
essee	doc_438857714625_item	2406068	et	4	main
minu	doc_438857714625_item	2406069	et	3	main
maakonnas	doc_438857714625_item	2406077	et	4	main
töökoht	doc_438857714625_item	2406081	et	3	main
äärelinnas	doc_438857714625_item	2406083	et	4	main
elan	doc_438857714625_item	2406085	et	3	main
uuel	doc_438857714625_item	2406086	et	3	main
tänaval	doc_438857714625_item	2406087	et	4	main
rohelust	doc_438857714625_item	2406093	et	4	main
ja	doc_438857714625_item	2406096	et	3	main
pehme	doc_438857714625_item	2406102	et	4	main
muru	doc_438857714625_item	2406103	et	4	main
õue	doc_438857714625_item	2406108	et	4	main
maja	doc_438857714625_item	2406112	et	4	main
on	doc_438857714625_item	2406114	et	4	main
sõidutee	doc_438857714625_item	2406115	et	4	main
meie	doc_438857714625_item	2406123	et	4	main
asuvad	doc_438857714625_item	2406126	et	4	main
toidu-	doc_438857714625_item	2406127	et	3	main
õhtuti	doc_438857714625_item	2406139	et	3	main
ma	doc_438857714625_item	2406140	et	3	main
ma	doc_438857714625_item	2406145	et	3	main
külm	doc_438857714625_item	2406164	et	3	main
vesi	doc_438857714625_item	2406165	et	4	main
elektri	doc_438857714625_item	2406180	et	3	main
kõrval	doc_438857714625_item	2406217	et	4	main
seinal	doc_438857714625_item	2406218	et	3	main
on	doc_438857714625_item	2406219	et	4	main
peegel	doc_438857714625_item	2406220	et	3	main
avaldus	doc_437545024342_item	2406056	et	4	main
läks	doc_437545024342_item	2406062	et	3	main
narva	doc_438857714625_item	2406078	et	4	main
asub	doc_438857714625_item	2406082	et	3	main
ma	doc_438857714625_item	2406084	et	3	main
puud	doc_438857714625_item	2406095	et	4	main
tee	doc_438857714625_item	2406098	et	4	main
maja	doc_438857714625_item	2406104	et	4	main
tagasi	doc_438857714625_item	2406105	et	3	main
on	doc_438857714625_item	2406106	et	4	main
on	doc_438857714625_item	2406109	et	4	main
kõrval	doc_438857714625_item	2406120	et	4	main
koeraga	doc_438857714625_item	2406143	et	3	main
meie	doc_438857714625_item	2406158	et	4	main
on	doc_438857714625_item	2406170	et	4	main
ma	doc_438857714625_item	2406178	et	3	main
kapi	doc_438857714625_item	2406216	et	4	main
kolm	doc_438857714625_item	2406222	et	3	main
suur	doc_438857714625_item	2406226	et	3	main
ja	doc_438857714625_item	2406247	et	3	main
on	doc_438857714625_item	2406249	et	4	main
eraldi	doc_438857714625_item	2406250	et	4	main
vannitoas	doc_438857714625_item	2406251	et	3	main
hambapasta	doc_438857714625_item	2406261	et	4	main
on	doc_438857714625_item	2406263	et	4	main
on	doc_438857714625_item	2406267	et	4	main
vasakul	doc_438857714625_item	2406293	et	4	main
seisab	doc_438857714625_item	2406294	et	3	main
nurgadiivan	doc_438857714625_item	2406295	et	3	main
siis	doc_438857714625_item	2406301	et	3	main
magamistuba	doc_438857714625_item	2406313	et	4	main
see	doc_438857714625_item	2406314	et	3	main
ei	doc_438857714625_item	2406315	et	4	main
tuba	doc_438857714625_item	2406319	et	4	main
hubane	doc_438857714625_item	2406327	et	3	main
paremal	doc_438857714625_item	2406329	et	4	main
seina	doc_438857714625_item	2406330	et	4	main
juures	doc_438857714625_item	2406337	et	4	main
nurgas	doc_438857714625_item	2406361	et	3	main
põrandal	doc_438857714625_item	2406371	et	3	main
vaipkate	doc_438857714625_item	2406373	et	4	main
seisab	doc_438857714625_item	2406384	et	3	main
suur	doc_438857714625_item	2406391	et	3	main
taga	doc_438857714625_item	2406399	et	4	main
nurgas	doc_438857714625_item	2406400	et	3	main
maja	doc_438857714625_item	2406124	et	4	main
tööstuskaupade	doc_438857714625_item	2406129	et	3	main
kauplused	doc_438857714625_item	2406130	et	3	main
üheksakorruselises	doc_438857714625_item	2406147	et	4	main
majas	doc_438857714625_item	2406148	et	3	main
neljandal	doc_438857714625_item	2406149	et	3	main
neljatoalises	doc_438857714625_item	2406151	et	4	main
korteris	doc_438857714625_item	2406152	et	3	main
ma	doc_438857714625_item	2406153	et	3	main
elan	doc_438857714625_item	2406154	et	3	main
korteris	doc_438857714625_item	2406159	et	3	main
kaabeltelevisioon	doc_438857714625_item	2406167	et	4	main
maksan	doc_438857714625_item	2406179	et	3	main
krooni	doc_438857714625_item	2406185	et	4	main
kuus	doc_438857714625_item	2406186	et	4	main
vee	doc_438857714625_item	2406187	et	3	main
sada	doc_438857714625_item	2406184	et	4	main
eest	doc_438857714625_item	2406188	et	4	main
ma	doc_438857714625_item	2406189	et	3	main
maksan	doc_438857714625_item	2406190	et	3	main
mõõturi	doc_438857714625_item	2406191	et	4	main
järgi	doc_438857714625_item	2406192	et	4	main
minu	doc_438857714625_item	2406193	et	3	main
korteris	doc_438857714625_item	2406194	et	3	main
on	doc_438857714625_item	2406195	et	4	main
kaks	doc_438857714625_item	2406196	et	3	main
esikud	doc_438857714625_item	2406197	et	3	main
väike	doc_438857714625_item	2406198	et	4	main
ja	doc_438857714625_item	2406199	et	3	main
suur	doc_438857714625_item	2406200	et	3	main
see	doc_438857714625_item	2406201	et	3	main
väike	doc_438857714625_item	2406202	et	4	main
esik	doc_438857714625_item	2406203	et	3	main
välisuksest	doc_438857714625_item	2406204	et	4	main
vasakul	doc_438857714625_item	2406205	et	4	main
seina	doc_438857714625_item	2406206	et	4	main
seisab	doc_438857714625_item	2406207	et	3	main
kummut	doc_438857714625_item	2406208	et	3	main
ja	doc_438857714625_item	2406209	et	3	main
nagu	doc_438857714625_item	2406210	et	3	main
ukse	doc_438857714625_item	2406211	et	3	main
vastas	doc_438857714625_item	2406212	et	4	main
seisab	doc_438857714625_item	2406213	et	3	main
kapp	doc_438857714625_item	2406214	et	3	main
peegelustega	doc_438857714625_item	2406215	et	3	main
bussipeatus	doc_438857714625_item	2406122	et	4	main
polikliinik	doc_438857714625_item	2406135	et	3	main
apteek	doc_438857714625_item	2406136	et	3	main
kõige	doc_438857714625_item	2406155	et	4	main
korteris	doc_438857714625_item	2406157	et	3	main
keskküte	doc_438857714625_item	2406161	et	3	main
soe	doc_438857714625_item	2406162	et	4	main
kanalisatsioon	doc_438857714625_item	2406166	et	3	main
rõdu	doc_438857714625_item	2406168	et	4	main
keskküte	doc_438857714625_item	2406169	et	3	main
kuuma	doc_438857714625_item	2406176	et	4	main
vett	doc_438857714625_item	2406177	et	3	main
umbes	doc_438857714625_item	2406182	et	4	main
ja	doc_438857714625_item	2406221	et	3	main
pildid	doc_438857714625_item	2406224	et	3	main
diivanilaud	doc_438857714625_item	2406233	et	4	main
vaas	doc_438857714625_item	2406234	et	3	main
on	doc_438857714625_item	2406239	et	4	main
ja	doc_438857714625_item	2406241	et	3	main
riiulil	doc_438857714625_item	2406243	et	3	main
telefon	doc_438857714625_item	2406245	et	3	main
pesumasin	doc_438857714625_item	2406255	et	3	main
käterätikud	doc_438857714625_item	2406258	et	3	main
ja	doc_438857714625_item	2406260	et	3	main
uksest	doc_438857714625_item	2406292	et	4	main
väike	doc_438857714625_item	2406299	et	4	main
palju	doc_438857714625_item	2406303	et	4	main
akna	doc_438857714625_item	2406305	et	3	main
on	doc_438857714625_item	2406307	et	4	main
valge	doc_438857714625_item	2406308	et	4	main
tüllkardin	doc_438857714625_item	2406309	et	3	main
siin	doc_438857714625_item	2406310	et	4	main
väga	doc_438857714625_item	2406317	et	3	main
tuba	doc_438857714625_item	2406322	et	4	main
päikesepaisteline	doc_438857714625_item	2406324	et	4	main
juures	doc_438857714625_item	2406331	et	4	main
seisab	doc_438857714625_item	2406332	et	3	main
on	doc_438857714625_item	2406349	et	4	main
ka	doc_438857714625_item	2406350	et	3	main
juures	doc_438857714625_item	2406360	et	4	main
tugitoolvoodi	doc_438857714625_item	2406363	et	4	main
tüllkardin	doc_438857714625_item	2406367	et	3	main
minu	doc_438857714625_item	2406376	et	3	main
laud	doc_438857714625_item	2406383	et	4	main
diivani	doc_438857714625_item	2406393	et	4	main
pilt	doc_438857714625_item	2406397	et	3	main
ees	doc_438857714625_item	2406425	et	4	main
on	doc_438857714625_item	2406435	et	4	main
on	doc_438857714625_item	2406439	et	4	main
köök	doc_438857714625_item	2406441	et	3	main
elutuba	doc_438857714625_item	2406443	et	4	main
koos	doc_438857714625_item	2406445	et	4	main
uksest	doc_438857714625_item	2406446	et	4	main
seisab	doc_438857714625_item	2406450	et	3	main
samsung	doc_438857714625_item	2406453	et	4	main
toidu	doc_438857714625_item	2406457	et	3	main
on	doc_438857714625_item	2406469	et	4	main
taldrikud	doc_438857714625_item	2406471	et	3	main
ja	doc_438857714625_item	2406474	et	3	main
nurgas	doc_438857714625_item	2406476	et	3	main
köögikraan	doc_438857714625_item	2406479	et	3	main
kolmandas	doc_438857714625_item	2406483	et	3	main
kapis	doc_438857714625_item	2406484	et	3	main
neljandas	doc_438857714625_item	2406490	et	3	main
neli	doc_438857714625_item	2406497	et	3	main
dessertlusikat	doc_438857714625_item	2406501	et	4	main
elektripliit	doc_438857714625_item	2406508	et	3	main
kohah	doc_438857714625_item	2406509	et	4	main
on	doc_438857714625_item	2406510	et	4	main
tõmbekapp	doc_438857714625_item	2406511	et	3	main
viiendas	doc_438857714625_item	2406512	et	3	main
kohviveski	doc_438857714625_item	2406518	et	4	main
kõrval	doc_438857714625_item	2406520	et	4	main
on	doc_438857714625_item	2406521	et	4	main
aken	doc_438857714625_item	2406525	et	3	main
on	doc_438857714625_item	2406531	et	4	main
aknalaual	doc_438857714625_item	2406537	et	3	main
elan	doc_438857714626_item	2406543	et	3	main
vabariigis	doc_438857714626_item	2406545	et	3	main
linnas	doc_438857714626_item	2406550	et	4	main
narva	doc_438857714626_item	2406551	et	4	main
on	doc_438857714625_item	2406160	et	4	main
ja	doc_438857714625_item	2406163	et	3	main
väga	doc_438857714625_item	2406171	et	3	main
kallis	doc_438857714625_item	2406172	et	4	main
juunis	doc_438857714625_item	2406173	et	3	main
ei	doc_438857714625_item	2406174	et	4	main
olnud	doc_438857714625_item	2406175	et	4	main
eest	doc_438857714625_item	2406181	et	4	main
kaks	doc_438857714625_item	2406183	et	3	main
uksest	doc_438857714625_item	2406228	et	4	main
juures	doc_438857714625_item	2406231	et	4	main
sektsioonkapp	doc_438857714625_item	2406240	et	4	main
riiul	doc_438857714625_item	2406242	et	4	main
tualett	doc_438857714625_item	2406246	et	3	main
vannituba	doc_438857714625_item	2406248	et	4	main
on	doc_438857714625_item	2406252	et	4	main
valamu	doc_438857714625_item	2406256	et	4	main
hambaharjad	doc_438857714625_item	2406259	et	3	main
lastetoas	doc_438857714625_item	2406265	et	3	main
on	doc_438857714625_item	2406302	et	4	main
ees	doc_438857714625_item	2406306	et	4	main
minu	doc_438857714625_item	2406312	et	3	main
aga	doc_438857714625_item	2406320	et	3	main
uksest	doc_438857714625_item	2406328	et	4	main
seina	doc_438857714625_item	2406336	et	4	main
lae	doc_438857714625_item	2406339	et	4	main
kahe	doc_438857714625_item	2406341	et	3	main
öökapiga	doc_438857714625_item	2406342	et	3	main
edasi	doc_438857714625_item	2406343	et	3	main
kohal	doc_438857714625_item	2406353	et	4	main
on	doc_438857714625_item	2406355	et	4	main
seisab	doc_438857714625_item	2406362	et	3	main
ees	doc_438857714625_item	2406365	et	4	main
magamistoa	doc_438857714625_item	2406370	et	3	main
on	doc_438857714625_item	2406372	et	4	main
see	doc_438857714625_item	2406374	et	3	main
uksest	doc_438857714625_item	2406378	et	4	main
paremal	doc_438857714625_item	2406379	et	4	main
nurgas	doc_438857714625_item	2406380	et	3	main
seisab	doc_438857714625_item	2406381	et	3	main
seinal	doc_438857714625_item	2406395	et	3	main
on	doc_438857714625_item	2406421	et	4	main
ees	doc_438857714625_item	2406423	et	4	main
on	doc_438857714625_item	2406426	et	4	main
suur	doc_438857714625_item	2406431	et	3	main
kollektioon	doc_438857714625_item	2406433	et	4	main
vasakul	doc_438857714625_item	2406447	et	4	main
külmkapp	doc_438857714625_item	2406451	et	3	main
hoian	doc_438857714625_item	2406456	et	3	main
tassid	doc_438857714625_item	2406472	et	4	main
klassid	doc_438857714625_item	2406473	et	3	main
kannud	doc_438857714625_item	2406475	et	3	main
on	doc_438857714625_item	2406477	et	4	main
all	doc_438857714625_item	2406480	et	3	main
prügiämber	doc_438857714625_item	2406482	et	3	main
on	doc_438857714625_item	2406485	et	4	main
ja	doc_438857714625_item	2406487	et	3	main
pannid	doc_438857714625_item	2406488	et	3	main
see	doc_438857714625_item	2406489	et	3	main
kapis	doc_438857714625_item	2406491	et	3	main
sahtlis	doc_438857714625_item	2406493	et	3	main
kahvelit	doc_438857714625_item	2406498	et	3	main
supilusikat	doc_438857714625_item	2406500	et	3	main
teelusikat	doc_438857714625_item	2406502	et	3	main
kapid	doc_438857714625_item	2406504	et	4	main
vahel	doc_438857714625_item	2406505	et	4	main
kapis	doc_438857714625_item	2406513	et	3	main
akna	doc_438857714625_item	2406533	et	3	main
on	doc_438857714625_item	2406538	et	4	main
vaike	doc_438857714625_item	2406539	et	3	main
essee	doc_438857714626_item	2406541	et	4	main
piirilinn	doc_438857714626_item	2406553	et	3	main
äärelinn	doc_438857714626_item	2406557	et	3	main
asuvad	doc_438857714626_item	2406575	et	4	main
toidu	doc_438857714626_item	2406576	et	3	main
aptek	doc_438857714626_item	2406580	et	4	main
maja	doc_438857714626_item	2406591	et	4	main
hoovis	doc_438857714626_item	2406592	et	4	main
maja	doc_438857714626_item	2406600	et	4	main
on	doc_438857714626_item	2406602	et	4	main
palju	doc_438857714626_item	2406603	et	4	main
hekk	doc_438857714626_item	2406613	et	3	main
paremal	doc_438857714625_item	2406229	et	4	main
seina	doc_438857714625_item	2406230	et	4	main
seisab	doc_438857714625_item	2406232	et	3	main
on	doc_438857714625_item	2406235	et	4	main
peegel	doc_438857714625_item	2406254	et	3	main
väike	doc_438857714625_item	2406268	et	4	main
tuba	doc_438857714625_item	2406269	et	4	main
uksest	doc_438857714625_item	2406270	et	4	main
paremal	doc_438857714625_item	2406271	et	4	main
seina	doc_438857714625_item	2406272	et	4	main
juures	doc_438857714625_item	2406273	et	4	main
seisab	doc_438857714625_item	2406274	et	3	main
riidekapp	doc_438857714625_item	2406275	et	3	main
uksest	doc_438857714625_item	2406276	et	4	main
vasakul	doc_438857714625_item	2406277	et	4	main
seisab	doc_438857714625_item	2406278	et	3	main
diivanvoodi	doc_438857714625_item	2406279	et	4	main
tool	doc_438857714625_item	2406280	et	3	main
sektsioonkapp	doc_438857714625_item	2406281	et	4	main
ja	doc_438857714625_item	2406282	et	3	main
kirjutuslaud	doc_438857714625_item	2406283	et	4	main
teine	doc_438857714625_item	2406284	et	3	main
lastetoas	doc_438857714625_item	2406285	et	3	main
uksest	doc_438857714625_item	2406286	et	4	main
paremal	doc_438857714625_item	2406287	et	4	main
seisab	doc_438857714625_item	2406288	et	3	main
kirjutuslaud	doc_438857714625_item	2406289	et	4	main
ja	doc_438857714625_item	2406290	et	3	main
riidekapp	doc_438857714625_item	2406291	et	3	main
väike	doc_438857714625_item	2406223	et	4	main
see	doc_438857714625_item	2406225	et	3	main
esik	doc_438857714625_item	2406227	et	3	main
diivanilaud	doc_438857714625_item	2406236	et	4	main
peal	doc_438857714625_item	2406237	et	4	main
edasi	doc_438857714625_item	2406238	et	3	main
on	doc_438857714625_item	2406244	et	4	main
vann	doc_438857714625_item	2406253	et	3	main
seebid	doc_438857714625_item	2406257	et	3	main
siis	doc_438857714625_item	2406262	et	3	main
esimene	doc_438857714625_item	2406264	et	3	main
see	doc_438857714625_item	2406266	et	3	main
on	doc_438857714625_item	2406298	et	4	main
tüdruk	doc_438857714625_item	2406300	et	3	main
nukud	doc_438857714625_item	2406304	et	3	main
on	doc_438857714625_item	2406311	et	4	main
suur	doc_438857714625_item	2406318	et	3	main
see	doc_438857714625_item	2406321	et	3	main
on	doc_438857714625_item	2406323	et	4	main
soe	doc_438857714625_item	2406325	et	4	main
ja	doc_438857714625_item	2406326	et	3	main
pruunikas	doc_438857714625_item	2406333	et	4	main
kõrval	doc_438857714625_item	2406335	et	4	main
seisab	doc_438857714625_item	2406338	et	3	main
prunnikas	doc_438857714625_item	2406351	et	4	main
seinal	doc_438857714625_item	2406354	et	3	main
peegel	doc_438857714625_item	2406356	et	3	main
akna	doc_438857714625_item	2406364	et	3	main
ja	doc_438857714625_item	2406368	et	3	main
külgkardinat	doc_438857714625_item	2406369	et	4	main
on	doc_438857714625_item	2406375	et	4	main
elutuba	doc_438857714625_item	2406377	et	4	main
telelaud	doc_438857714625_item	2406382	et	4	main
seina	doc_438857714625_item	2406388	et	4	main
kohal	doc_438857714625_item	2406394	et	4	main
riipub	doc_438857714625_item	2406396	et	4	main
akna	doc_438857714625_item	2406424	et	3	main
aknalaual	doc_438857714625_item	2406429	et	3	main
on	doc_438857714625_item	2406444	et	4	main
juures	doc_438857714625_item	2406449	et	4	main
külmkapis	doc_438857714625_item	2406454	et	3	main
kapis	doc_438857714625_item	2406468	et	3	main
nõud	doc_438857714625_item	2406470	et	3	main
korgitser	doc_438857714625_item	2406495	et	3	main
see	doc_438857714625_item	2406296	et	3	main
tuba	doc_438857714625_item	2406297	et	4	main
ole	doc_438857714625_item	2406316	et	4	main
riidekapp	doc_438857714625_item	2406334	et	3	main
voodi	doc_438857714625_item	2406340	et	4	main
seina	doc_438857714625_item	2406344	et	4	main
juures	doc_438857714625_item	2406345	et	4	main
seisab	doc_438857714625_item	2406346	et	3	main
kummut	doc_438857714625_item	2406347	et	3	main
see	doc_438857714625_item	2406348	et	3	main
kummuti	doc_438857714625_item	2406352	et	4	main
uksest	doc_438857714625_item	2406357	et	4	main
vasakul	doc_438857714625_item	2406358	et	4	main
akna	doc_438857714625_item	2406359	et	3	main
on	doc_438857714625_item	2406366	et	4	main
teler	doc_438857714625_item	2406385	et	3	main
magnitofon	doc_438857714625_item	2406386	et	4	main
laserplaadimängija	doc_438857714625_item	2406387	et	4	main
juures	doc_438857714625_item	2406389	et	4	main
seisab	doc_438857714625_item	2406390	et	3	main
diivan	doc_438857714625_item	2406392	et	3	main
akna	doc_438857714625_item	2406401	et	3	main
diivani	doc_438857714625_item	2406398	et	4	main
juures	doc_438857714625_item	2406402	et	4	main
seisab	doc_438857714625_item	2406403	et	3	main
arvutilaud	doc_438857714625_item	2406404	et	4	main
arvutilaual	doc_438857714625_item	2406405	et	3	main
seisab	doc_438857714625_item	2406406	et	3	main
arvuti	doc_438857714625_item	2406407	et	4	main
ja	doc_438857714625_item	2406408	et	3	main
kaks	doc_438857714625_item	2406409	et	3	main
toalill	doc_438857714625_item	2406410	et	3	main
diivani	doc_438857714625_item	2406411	et	4	main
ja	doc_438857714625_item	2406412	et	3	main
arvutilauda	doc_438857714625_item	2406413	et	4	main
vähel	doc_438857714625_item	2406414	et	3	main
põrandal	doc_438857714625_item	2406415	et	3	main
seisab	doc_438857714625_item	2406416	et	3	main
toalill	doc_438857714625_item	2406418	et	3	main
suur	doc_438857714625_item	2406417	et	3	main
väike	doc_438857714625_item	2406419	et	4	main
diivan	doc_438857714625_item	2406420	et	3	main
tüllkardin	doc_438857714625_item	2406428	et	3	main
rõdu	doc_438857714625_item	2406438	et	4	main
ja	doc_438857714625_item	2406442	et	3	main
seina	doc_438857714625_item	2406448	et	4	main
marki	doc_438857714625_item	2406452	et	4	main
ma	doc_438857714625_item	2406455	et	3	main
on	doc_438857714625_item	2406481	et	4	main
neli	doc_438857714625_item	2406499	et	3	main
on	doc_438857714625_item	2406506	et	4	main
elektripliit	doc_438857714625_item	2406507	et	3	main
elektripliit	doc_438857714625_item	2406519	et	3	main
söögilaud	doc_438857714625_item	2406532	et	4	main
tüllkardin	doc_438857714625_item	2406536	et	3	main
toalilled	doc_438857714625_item	2406540	et	3	main
ma	doc_438857714626_item	2406542	et	3	main
narva	doc_438857714626_item	2406549	et	4	main
ma	doc_438857714626_item	2406554	et	3	main
tööstuskaupade	doc_438857714626_item	2406578	et	3	main
bussipeatus	doc_438857714626_item	2406590	et	4	main
puud	doc_438857714626_item	2406607	et	4	main
maja	doc_438857714626_item	2406621	et	4	main
vana	doc_438857714626_item	2406623	et	4	main
akna	doc_438857714625_item	2406422	et	3	main
valge	doc_438857714625_item	2406427	et	4	main
on	doc_438857714625_item	2406430	et	4	main
kaktuse	doc_438857714625_item	2406432	et	3	main
põrandal	doc_438857714625_item	2406434	et	3	main
beež	doc_438857714625_item	2406436	et	2	main
vaip	doc_438857714625_item	2406437	et	3	main
elutoast	doc_438857714625_item	2406440	et	3	main
külmkapp	doc_438857714625_item	2406458	et	3	main
kõrval	doc_438857714625_item	2406459	et	4	main
on	doc_438857714625_item	2406461	et	4	main
seinal	doc_438857714625_item	2406460	et	3	main
sektsioonkapp	doc_438857714625_item	2406462	et	4	main
ühes	doc_438857714625_item	2406463	et	4	main
kapis	doc_438857714625_item	2406464	et	3	main
on	doc_438857714625_item	2406465	et	4	main
toiduained	doc_438857714625_item	2406466	et	3	main
teises	doc_438857714625_item	2406467	et	4	main
köögikraan	doc_438857714625_item	2406478	et	3	main
potid	doc_438857714625_item	2406486	et	4	main
siis	doc_438857714625_item	2406492	et	3	main
on	doc_438857714625_item	2406494	et	4	main
avaja	doc_438857714625_item	2406496	et	4	main
leivanuga	doc_438857714625_item	2406503	et	4	main
on	doc_438857714625_item	2406514	et	4	main
kodumasinad	doc_438857714625_item	2406515	et	3	main
mikser	doc_438857714625_item	2406516	et	3	main
mahlapress	doc_438857714625_item	2406517	et	3	main
mikrolaineahu	doc_438857714625_item	2406522	et	4	main
elektrikann	doc_438857714625_item	2406524	et	3	main
on	doc_438857714625_item	2406526	et	4	main
külmkapi	doc_438857714625_item	2406527	et	3	main
vastas	doc_438857714625_item	2406528	et	4	main
akna	doc_438857714625_item	2406529	et	3	main
ees	doc_438857714625_item	2406530	et	4	main
on	doc_438857714625_item	2406535	et	4	main
maakonnas	doc_438857714626_item	2406548	et	4	main
kauplused	doc_438857714626_item	2406579	et	3	main
lasteaed	doc_438857714626_item	2406582	et	3	main
üks	doc_438857714626_item	2406583	et	3	main
sõidutee	doc_438857714626_item	2406585	et	4	main
kõnnitee	doc_438857714626_item	2406586	et	4	main
on	doc_438857714626_item	2406593	et	4	main
liivakast	doc_438857714626_item	2406596	et	4	main
ja	doc_438857714626_item	2406597	et	3	main
pingid	doc_438857714626_item	2406599	et	3	main
umbruses	doc_438857714626_item	2406601	et	3	main
erinevad	doc_438857714626_item	2406606	et	4	main
tee	doc_438857714626_item	2406610	et	4	main
meie	doc_438857714626_item	2406620	et	4	main
ja	doc_438857714625_item	2406523	et	3	main
ees	doc_438857714625_item	2406534	et	4	main
eesti	doc_438857714626_item	2406544	et	4	main
ida	doc_438857714626_item	2406546	et	4	main
viru	doc_438857714626_item	2406547	et	4	main
on	doc_438857714626_item	2406552	et	4	main
aadress	doc_438857714626_item	2406559	et	3	main
on	doc_438857714626_item	2406560	et	4	main
posti	doc_438857714626_item	2406561	et	4	main
tänaval	doc_438857714626_item	2406562	et	4	main
nelikümmend	doc_438857714626_item	2406563	et	4	main
viis	doc_438857714626_item	2406564	et	4	main
korter	doc_438857714626_item	2406565	et	3	main
viisteist	doc_438857714626_item	2406566	et	4	main
ma	doc_438857714626_item	2406567	et	3	main
elan	doc_438857714626_item	2406568	et	3	main
viiekorruselises	doc_438857714626_item	2406569	et	4	main
paneel	doc_438857714626_item	2406570	et	3	main
maja	doc_438857714626_item	2406571	et	4	main
meie	doc_438857714626_item	2406572	et	4	main
elan	doc_438857714626_item	2406555	et	3	main
on	doc_438857714626_item	2406556	et	4	main
ma	doc_438857714626_item	2406558	et	3	main
maja	doc_438857714626_item	2406573	et	4	main
lähedal	doc_438857714626_item	2406574	et	4	main
kool	doc_438857714626_item	2406584	et	4	main
natuke	doc_438857714626_item	2406587	et	4	main
eemale	doc_438857714626_item	2406588	et	3	main
jääb	doc_438857714626_item	2406589	et	3	main
laste	doc_438857714626_item	2406594	et	4	main
kasvavad	doc_438857714626_item	2406605	et	4	main
põõsad	doc_438857714626_item	2406609	et	3	main
ilus	doc_438857714626_item	2406617	et	4	main
pehme	doc_438857714626_item	2406618	et	4	main
on	doc_438857714626_item	2406622	et	4	main
meie	doc_438857714626_item	2406624	et	4	main
sissekäigus	doc_438857714626_item	2406625	et	3	main
maja	doc_438857714626_item	2406630	et	4	main
käib	doc_438857714626_item	2406632	et	3	main
meie	doc_438857714626_item	2406634	et	4	main
trepikoda	doc_438857714626_item	2406635	et	4	main
majas	doc_438857714626_item	2406640	et	3	main
ja	doc_438857714626_item	2406647	et	3	main
korteri	doc_438857714626_item	2406656	et	3	main
on	doc_438857714626_item	2406661	et	4	main
kaks	doc_438857714626_item	2406662	et	3	main
esik	doc_438857714626_item	2406665	et	3	main
ja	doc_438857714626_item	2406667	et	3	main
tualett	doc_438857714626_item	2406668	et	3	main
on	doc_438857714626_item	2406670	et	4	main
suur	doc_438857714626_item	2406698	et	3	main
ja	doc_438857714626_item	2406708	et	3	main
eraldi	doc_438857714626_item	2406711	et	4	main
väga	doc_438857714626_item	2406715	et	3	main
on	doc_438857714626_item	2406727	et	4	main
kraanikaus	doc_438857714626_item	2406728	et	4	main
peegel	doc_438857714626_item	2406735	et	3	main
hambapasta	doc_438857714626_item	2406739	et	4	main
hambaharid	doc_438857714626_item	2406740	et	4	main
on	doc_438857714626_item	2406747	et	4	main
nagi	doc_438857714626_item	2406749	et	4	main
vahetult	doc_438857714626_item	2406756	et	4	main
on	doc_438857714626_item	2406769	et	4	main
valge	doc_438857714626_item	2406770	et	4	main
vaip	doc_438857714626_item	2406771	et	3	main
köök	doc_438857714626_item	2406800	et	3	main
suured	doc_438857714626_item	2406812	et	3	main
umbes	doc_438857714626_item	2406813	et	4	main
riiulid	doc_438857714626_item	2406829	et	3	main
eesemesel	doc_438857714626_item	2406830	et	4	main
suhkrutoos	doc_438857714626_item	2406834	et	3	main
kohikann	doc_438857714626_item	2406836	et	3	main
piimakann	doc_438857714626_item	2406838	et	3	main
riiul	doc_438857714626_item	2406840	et	4	main
tassid	doc_438857714626_item	2406843	et	4	main
riiul	doc_438857714626_item	2406849	et	4	main
suur	doc_438857714626_item	2406851	et	3	main
mikser	doc_438857714626_item	2406860	et	3	main
ja	doc_438857714626_item	2406872	et	3	main
vaja	doc_438857714626_item	2406876	et	4	main
kardinaild	doc_438857714626_item	2406915	et	4	main
ja	doc_438857714626_item	2406577	et	3	main
üks	doc_438857714626_item	2406581	et	3	main
mänguväljak	doc_438857714626_item	2406595	et	3	main
mõned	doc_438857714626_item	2406598	et	3	main
rohelust	doc_438857714626_item	2406604	et	4	main
ja	doc_438857714626_item	2406608	et	3	main
ääres	doc_438857714626_item	2406611	et	4	main
on	doc_438857714626_item	2406612	et	4	main
muru	doc_438857714626_item	2406619	et	4	main
on	doc_438857714626_item	2406626	et	4	main
gaas	doc_438857714626_item	2406644	et	3	main
vesi	doc_438857714626_item	2406649	et	4	main
elan	doc_438857714626_item	2406651	et	3	main
neljas	doc_438857714626_item	2406653	et	4	main
korrusel	doc_438857714626_item	2406654	et	3	main
köök	doc_438857714626_item	2406664	et	3	main
peal	doc_438857714626_item	2406694	et	4	main
sein	doc_438857714626_item	2406696	et	3	main
ummargune	doc_438857714626_item	2406699	et	4	main
peegel	doc_438857714626_item	2406700	et	3	main
põrandal	doc_438857714626_item	2406701	et	3	main
on	doc_438857714626_item	2406702	et	4	main
vannituba	doc_438857714626_item	2406709	et	4	main
minu	doc_438857714626_item	2406712	et	3	main
umbes	doc_438857714626_item	2406717	et	4	main
ning	doc_438857714626_item	2406614	et	3	main
hoovis	doc_438857714626_item	2406615	et	4	main
on	doc_438857714626_item	2406616	et	4	main
meie	doc_438857714626_item	2406629	et	4	main
lukus	doc_438857714626_item	2406633	et	3	main
meie	doc_438857714626_item	2406639	et	4	main
keskküte	doc_438857714626_item	2406645	et	3	main
külm	doc_438857714626_item	2406648	et	3	main
on	doc_438857714626_item	2406652	et	4	main
minu	doc_438857714626_item	2406655	et	3	main
korteris	doc_438857714626_item	2406660	et	3	main
vannituba	doc_438857714626_item	2406666	et	4	main
vasak	doc_438857714626_item	2406695	et	3	main
minu	doc_438857714626_item	2406705	et	3	main
korteri	doc_438857714626_item	2406706	et	3	main
on	doc_438857714626_item	2406710	et	4	main
on	doc_438857714626_item	2406714	et	4	main
üksest	doc_438857714626_item	2406720	et	3	main
kohal	doc_438857714626_item	2406730	et	4	main
on	doc_438857714626_item	2406732	et	4	main
ja	doc_438857714626_item	2406734	et	3	main
riiul	doc_438857714626_item	2406736	et	4	main
klaas	doc_438857714626_item	2406738	et	3	main
seina	doc_438857714626_item	2406746	et	4	main
sein	doc_438857714626_item	2406762	et	3	main
maast	doc_438857714626_item	2406766	et	3	main
laeni	doc_438857714626_item	2406767	et	4	main
on	doc_438857714626_item	2406774	et	4	main
mina	doc_438857714626_item	2406776	et	4	main
südakorter	doc_438857714626_item	2406802	et	3	main
kuus	doc_438857714626_item	2406814	et	4	main
üksest	doc_438857714626_item	2406816	et	3	main
teekann	doc_438857714626_item	2406835	et	3	main
ja	doc_438857714626_item	2406837	et	3	main
alustassit	doc_438857714626_item	2406844	et	4	main
on	doc_438857714626_item	2406850	et	4	main
väike	doc_438857714626_item	2406853	et	4	main
kastrulid	doc_438857714626_item	2406854	et	3	main
neljandal	doc_438857714626_item	2406855	et	3	main
riiul	doc_438857714626_item	2406856	et	4	main
võileivagrill	doc_438857714626_item	2406861	et	3	main
söögilaud	doc_438857714626_item	2406863	et	4	main
kahvlid	doc_438857714626_item	2406873	et	3	main
vasakul	doc_438857714626_item	2406874	et	4	main
ess	doc_438857714626_item	2406911	et	3	main
valge	doc_438857714626_item	2406913	et	4	main
tüllkardinad	doc_438857714626_item	2406914	et	4	main
seisab	doc_438857714626_item	2406925	et	3	main
all	doc_438857714626_item	2406928	et	3	main
minu	doc_438857714626_item	2406932	et	3	main
on	doc_438857714626_item	2406934	et	4	main
seitsetest	doc_438857714626_item	2406939	et	3	main
põhjapoolne	doc_438857714626_item	2406954	et	3	main
ja	doc_438857714626_item	2406958	et	3	main
seina	doc_438857714626_item	2406967	et	4	main
juures	doc_438857714626_item	2406968	et	4	main
pesukapp	doc_438857714626_item	2406971	et	3	main
ja	doc_438857714626_item	2406981	et	3	main
komandal	doc_438857714626_item	2406982	et	4	main
riiul	doc_438857714626_item	2406983	et	4	main
on	doc_438857714626_item	2406988	et	4	main
kirjutus	doc_438857714626_item	2406997	et	4	main
üksest	doc_438857714626_item	2407003	et	3	main
mugavad	doc_438857714626_item	2407009	et	3	main
seinalampi	doc_438857714626_item	2407016	et	4	main
neli	doc_438857714626_item	2407018	et	3	main
juures	doc_438857714626_item	2407023	et	4	main
ja	doc_438857714626_item	2407029	et	3	main
suur	doc_438857714626_item	2407042	et	3	main
võõrastetuba	doc_438857714626_item	2407045	et	4	main
on	doc_438857714626_item	2407047	et	4	main
põrandal	doc_438857714626_item	2407051	et	3	main
on	doc_438857714626_item	2407052	et	4	main
suur	doc_438857714626_item	2407053	et	3	main
paremal	doc_438857714626_item	2407057	et	4	main
seisab	doc_438857714626_item	2407060	et	3	main
riidekap	doc_438857714626_item	2407063	et	4	main
vastas	doc_438857714626_item	2407064	et	4	main
kõrgete	doc_438857714626_item	2407071	et	4	main
seljatugedega	doc_438857714626_item	2407072	et	3	main
tugitoolid	doc_438857714626_item	2407074	et	3	main
on	doc_438857714626_item	2407119	et	4	main
neliteist	doc_438857714626_item	2406627	et	4	main
välisuks	doc_438857714626_item	2406631	et	4	main
on	doc_438857714626_item	2406636	et	4	main
mugavused	doc_438857714626_item	2406643	et	4	main
ma	doc_438857714626_item	2406650	et	3	main
on	doc_438857714626_item	2406657	et	4	main
minu	doc_438857714626_item	2406659	et	3	main
tuba	doc_438857714626_item	2406663	et	4	main
esik	doc_438857714626_item	2406669	et	3	main
väike	doc_438857714626_item	2406671	et	4	main
valjas	doc_438857714626_item	2406672	et	4	main
üksest	doc_438857714626_item	2406673	et	3	main
paremal	doc_438857714626_item	2406674	et	4	main
seina	doc_438857714626_item	2406675	et	4	main
juures	doc_438857714626_item	2406676	et	4	main
seisab	doc_438857714626_item	2406677	et	3	main
kapp	doc_438857714626_item	2406678	et	3	main
kapi	doc_438857714626_item	2406679	et	4	main
kõrval	doc_438857714626_item	2406680	et	4	main
seina	doc_438857714626_item	2406681	et	4	main
on	doc_438857714626_item	2406682	et	4	main
nagi	doc_438857714626_item	2406683	et	4	main
nagis	doc_438857714626_item	2406684	et	3	main
ripuvad	doc_438857714626_item	2406685	et	3	main
palitud	doc_438857714626_item	2406686	et	4	main
ja	doc_438857714626_item	2406687	et	3	main
mütsid	doc_438857714626_item	2406688	et	3	main
põrandal	doc_438857714626_item	2406689	et	3	main
on	doc_438857714626_item	2406690	et	4	main
väike	doc_438857714626_item	2406691	et	4	main
hall	doc_438857714626_item	2406692	et	4	main
vaib	doc_438857714626_item	2406693	et	4	main
korterit	doc_438857714626_item	2406628	et	3	main
alati	doc_438857714626_item	2406637	et	4	main
puhas	doc_438857714626_item	2406638	et	3	main
on	doc_438857714626_item	2406641	et	4	main
kõik	doc_438857714626_item	2406642	et	4	main
soe	doc_438857714626_item	2406646	et	4	main
erastatud	doc_438857714626_item	2406658	et	4	main
on	doc_438857714626_item	2406697	et	4	main
kolm	doc_438857714626_item	2406718	et	3	main
sampoon	doc_438857714626_item	2406741	et	4	main
ja	doc_438857714626_item	2406742	et	3	main
seep	doc_438857714626_item	2406743	et	4	main
üksest	doc_438857714626_item	2406744	et	3	main
on	doc_438857714626_item	2406751	et	4	main
käterätik	doc_438857714626_item	2406752	et	3	main
ja	doc_438857714626_item	2406753	et	3	main
vann	doc_438857714626_item	2406773	et	3	main
pesupulber	doc_438857714626_item	2406775	et	3	main
abikaasa	doc_438857714626_item	2406806	et	4	main
on	doc_438857714626_item	2406808	et	4	main
põhjapoolne	doc_438857714626_item	2406809	et	3	main
köök	doc_438857714626_item	2406810	et	3	main
on	doc_438857714626_item	2406811	et	4	main
paremal	doc_438857714626_item	2406817	et	4	main
kaetud	doc_438857714626_item	2406703	et	4	main
linoleumiga	doc_438857714626_item	2406704	et	3	main
tualett	doc_438857714626_item	2406707	et	3	main
vannituba	doc_438857714626_item	2406713	et	4	main
väike	doc_438857714626_item	2406716	et	4	main
ruutmeetrit	doc_438857714626_item	2406719	et	3	main
paremal	doc_438857714626_item	2406721	et	4	main
juures	doc_438857714626_item	2406723	et	4	main
pesumasin	doc_438857714626_item	2406725	et	3	main
seina	doc_438857714626_item	2406726	et	4	main
seina	doc_438857714626_item	2406731	et	4	main
saunalina	doc_438857714626_item	2406754	et	4	main
üksest	doc_438857714626_item	2406755	et	3	main
seina	doc_438857714626_item	2406757	et	4	main
vannitoa	doc_438857714626_item	2406761	et	3	main
on	doc_438857714626_item	2406763	et	4	main
kahhelkiviga	doc_438857714626_item	2406765	et	3	main
komndopunkt	doc_438857714626_item	2406804	et	4	main
minu	doc_438857714626_item	2406805	et	3	main
köök	doc_438857714626_item	2406807	et	3	main
seina	doc_438857714626_item	2406818	et	4	main
söögilaud	doc_438857714626_item	2406820	et	4	main
gaasipliit	doc_438857714626_item	2406821	et	3	main
köögikapp	doc_438857714626_item	2406825	et	3	main
köögikapp	doc_438857714626_item	2406826	et	3	main
on	doc_438857714626_item	2406832	et	4	main
taldrikud	doc_438857714626_item	2406847	et	3	main
peal	doc_438857714626_item	2406862	et	4	main
on	doc_438857714626_item	2406864	et	4	main
elektrikann	doc_438857714626_item	2406865	et	3	main
söögilaud	doc_438857714626_item	2406866	et	4	main
kast	doc_438857714626_item	2406867	et	3	main
on	doc_438857714626_item	2406875	et	4	main
on	doc_438857714626_item	2406907	et	4	main
laelamp	doc_438857714626_item	2406909	et	3	main
akna	doc_438857714626_item	2406910	et	3	main
meie	doc_438857714626_item	2406921	et	4	main
all	doc_438857714626_item	2406923	et	3	main
laud	doc_438857714626_item	2406924	et	4	main
seisab	doc_438857714626_item	2406930	et	3	main
ja	doc_438857714626_item	2406940	et	3	main
ruutmeetrit	doc_438857714626_item	2406942	et	3	main
hubane	doc_438857714626_item	2406957	et	3	main
riiuled	doc_438857714626_item	2406974	et	4	main
on	doc_438857714626_item	2406977	et	4	main
voodi	doc_438857714626_item	2406978	et	4	main
pesu	doc_438857714626_item	2406979	et	4	main
aluspesu	doc_438857714626_item	2406985	et	4	main
akna	doc_438857714626_item	2406992	et	3	main
ja	doc_438857714626_item	2407001	et	3	main
laualamp	doc_438857714626_item	2407002	et	3	main
on	doc_438857714626_item	2407014	et	4	main
kaks	doc_438857714626_item	2407015	et	3	main
õmblusmasin	doc_438857714626_item	2407026	et	3	main
kulgmine	doc_438857714626_item	2407030	et	4	main
on	doc_438857714626_item	2407039	et	4	main
tuba	doc_438857714626_item	2407043	et	4	main
punane	doc_438857714626_item	2407054	et	4	main
vaib	doc_438857714626_item	2407055	et	4	main
ja	doc_438857714626_item	2407062	et	3	main
tugitoolid	doc_438857714626_item	2407073	et	3	main
seina	doc_438857714626_item	2407079	et	4	main
teisel	doc_438857714626_item	2407127	et	4	main
kolmandal	doc_438857714626_item	2407134	et	3	main
on	doc_438857714626_item	2407140	et	4	main
on	doc_438857714626_item	2407143	et	4	main
melhiorilusikad	doc_438857714626_item	2407145	et	4	main
ja	doc_438857714626_item	2407146	et	3	main
melhiorikahvlid	doc_438857714626_item	2407147	et	4	main
on	doc_438857714626_item	2407153	et	4	main
nelja	doc_438857714626_item	2407166	et	4	main
vaas	doc_438857714626_item	2407172	et	3	main
üks	doc_438857714626_item	2407175	et	3	main
üks	doc_438857714626_item	2407180	et	3	main
juures	doc_438857714626_item	2407188	et	4	main
kapp	doc_438857714626_item	2407190	et	3	main
esemesel	doc_438857714626_item	2407198	et	4	main
naelid	doc_438857714626_item	2407201	et	3	main
valtsid	doc_438857714626_item	2407221	et	4	main
on	doc_438857714626_item	2407223	et	4	main
soe	doc_438857714626_item	2407237	et	4	main
külm	doc_438857714626_item	2407239	et	3	main
seina	doc_438857714626_item	2406722	et	4	main
seisab	doc_438857714626_item	2406724	et	3	main
kranikaus	doc_438857714626_item	2406729	et	4	main
riiul	doc_438857714626_item	2406733	et	4	main
on	doc_438857714626_item	2406737	et	4	main
vasakul	doc_438857714626_item	2406745	et	4	main
väike	doc_438857714626_item	2406748	et	4	main
nagi	doc_438857714626_item	2406750	et	4	main
juures	doc_438857714626_item	2406758	et	4	main
seisab	doc_438857714626_item	2406759	et	3	main
vann	doc_438857714626_item	2406760	et	3	main
kaetud	doc_438857714626_item	2406764	et	4	main
põrandall	doc_438857714626_item	2406768	et	4	main
all	doc_438857714626_item	2406772	et	3	main
tualett	doc_438857714626_item	2406777	et	3	main
on	doc_438857714626_item	2406778	et	4	main
kaks	doc_438857714626_item	2406779	et	3	main
ruutmeetrit	doc_438857714626_item	2406780	et	3	main
üksest	doc_438857714626_item	2406781	et	3	main
paremal	doc_438857714626_item	2406782	et	4	main
seinal	doc_438857714626_item	2406783	et	3	main
rippuma	doc_438857714626_item	2406784	et	3	main
on	doc_438857714626_item	2406785	et	4	main
tualetti	doc_438857714626_item	2406786	et	4	main
paber	doc_438857714626_item	2406787	et	3	main
tualettitoa	doc_438857714626_item	2406788	et	4	main
sein	doc_438857714626_item	2406789	et	3	main
on	doc_438857714626_item	2406790	et	4	main
kaetud	doc_438857714626_item	2406791	et	4	main
kahhelkiviga	doc_438857714626_item	2406792	et	3	main
maast	doc_438857714626_item	2406793	et	3	main
laeni	doc_438857714626_item	2406794	et	4	main
põrandall	doc_438857714626_item	2406795	et	4	main
on	doc_438857714626_item	2406796	et	4	main
väike	doc_438857714626_item	2406797	et	4	main
tumepunane	doc_438857714626_item	2406798	et	4	main
väib	doc_438857714626_item	2406799	et	4	main
on	doc_438857714626_item	2406801	et	4	main
ja	doc_438857714626_item	2406803	et	3	main
ruutmeetrit	doc_438857714626_item	2406815	et	3	main
juures	doc_438857714626_item	2406819	et	4	main
ja	doc_438857714626_item	2406824	et	3	main
riiul	doc_438857714626_item	2406831	et	4	main
serviis	doc_438857714626_item	2406833	et	3	main
teisel	doc_438857714626_item	2406839	et	4	main
ol	doc_438857714626_item	2406841	et	4	main
taldrikud	doc_438857714626_item	2406842	et	3	main
ja	doc_438857714626_item	2406846	et	3	main
kolmandal	doc_438857714626_item	2406848	et	3	main
ja	doc_438857714626_item	2406852	et	3	main
korgitser	doc_438857714626_item	2406878	et	3	main
lage	doc_438857714626_item	2406906	et	3	main
suur	doc_438857714626_item	2406908	et	3	main
eldse	doc_438857714626_item	2406916	et	4	main
aknalaud	doc_438857714626_item	2406917	et	4	main
armsam	doc_438857714626_item	2406919	et	4	main
on	doc_438857714626_item	2406938	et	4	main
kakskümmend	doc_438857714626_item	2406941	et	4	main
väike	doc_438857714626_item	2406943	et	4	main
tuba	doc_438857714626_item	2406944	et	4	main
on	doc_438857714626_item	2406945	et	4	main
päike	doc_438857714626_item	2406949	et	3	main
sepoolne	doc_438857714626_item	2406950	et	4	main
suur	doc_438857714626_item	2406951	et	3	main
tuba	doc_438857714626_item	2406952	et	4	main
magamistuba	doc_438857714626_item	2406955	et	4	main
valgusküllane	doc_438857714626_item	2406959	et	4	main
vaib	doc_438857714626_item	2406964	et	4	main
üksest	doc_438857714626_item	2406965	et	3	main
paremal	doc_438857714626_item	2406966	et	4	main
pesukapp	doc_438857714626_item	2406970	et	3	main
eesemesel	doc_438857714626_item	2406975	et	4	main
neljandl	doc_438857714626_item	2406986	et	4	main
riiul	doc_438857714626_item	2406987	et	4	main
käterätikud	doc_438857714626_item	2406989	et	3	main
laudlinad	doc_438857714626_item	2406991	et	3	main
juures	doc_438857714626_item	2406993	et	4	main
seisab	doc_438857714626_item	2406994	et	3	main
on	doc_438857714626_item	2406999	et	4	main
arvuti	doc_438857714626_item	2407000	et	4	main
juures	doc_438857714626_item	2407006	et	4	main
pilti	doc_438857714626_item	2407019	et	4	main
tugitoolvoodi	doc_438857714626_item	2407020	et	4	main
akna	doc_438857714626_item	2407027	et	3	main
vaib	doc_438857714626_item	2407036	et	4	main
all	doc_438857714626_item	2407037	et	3	main
lagi	doc_438857714626_item	2407038	et	4	main
võõrastetuba	doc_438857714626_item	2407046	et	4	main
avar	doc_438857714626_item	2407048	et	3	main
ja	doc_438857714626_item	2407049	et	3	main
hubane	doc_438857714626_item	2407050	et	3	main
seina	doc_438857714626_item	2407058	et	4	main
juures	doc_438857714626_item	2407059	et	4	main
sektsioonkapp	doc_438857714626_item	2407061	et	4	main
kaks	doc_438857714626_item	2407078	et	3	main
lampi	doc_438857714626_item	2407080	et	4	main
kolmandal	doc_438857714626_item	2407118	et	3	main
salvrätikud	doc_438857714626_item	2407120	et	3	main
neeli	doc_438857714626_item	2407121	et	4	main
esemesel	doc_438857714626_item	2407123	et	4	main
riiul	doc_438857714626_item	2407124	et	4	main
riiul	doc_438857714626_item	2407128	et	4	main
pitsid	doc_438857714626_item	2407131	et	3	main
sahtel	doc_438857714626_item	2407142	et	3	main
on	doc_438857714626_item	2407150	et	4	main
baar	doc_438857714626_item	2407151	et	3	main
tüllkardinad	doc_438857714626_item	2407157	et	4	main
akna	doc_438857714626_item	2407161	et	3	main
toliga	doc_438857714626_item	2407167	et	4	main
kristall	doc_438857714626_item	2407171	et	3	main
on	doc_438857714626_item	2407174	et	4	main
seina	doc_438857714626_item	2407187	et	4	main
on	doc_438857714626_item	2407200	et	4	main
väike	doc_438857714626_item	2406822	et	4	main
kulmutuskapp	doc_438857714626_item	2406823	et	4	main
on	doc_438857714626_item	2406827	et	4	main
neli	doc_438857714626_item	2406828	et	3	main
klaasid	doc_438857714626_item	2406845	et	4	main
on	doc_438857714626_item	2406857	et	4	main
rannad	doc_438857714626_item	2406858	et	3	main
röster	doc_438857714626_item	2406859	et	3	main
paremal	doc_438857714626_item	2406868	et	4	main
on	doc_438857714626_item	2406869	et	4	main
lusikad	doc_438857714626_item	2406870	et	3	main
noad	doc_438857714626_item	2406871	et	3	main
ja	doc_438857714626_item	2406877	et	3	main
juures	doc_438857714626_item	2406879	et	4	main
pesemine	doc_438857714626_item	2406880	et	4	main
peal	doc_438857714626_item	2406881	et	4	main
sein	doc_438857714626_item	2406882	et	3	main
ripub	doc_438857714626_item	2406883	et	3	main
riiv	doc_438857714626_item	2406884	et	3	main
sõel	doc_438857714626_item	2406885	et	3	main
kulp	doc_438857714626_item	2406886	et	3	main
potilapp	doc_438857714626_item	2406887	et	3	main
ja	doc_438857714626_item	2406888	et	3	main
käterätik	doc_438857714626_item	2406889	et	3	main
köök	doc_438857714626_item	2406890	et	3	main
on	doc_438857714626_item	2406891	et	4	main
üks	doc_438857714626_item	2406892	et	3	main
aken	doc_438857714626_item	2406893	et	3	main
köögiaken	doc_438857714626_item	2406894	et	3	main
avaneb	doc_438857714626_item	2406895	et	3	main
hoovi	doc_438857714626_item	2406896	et	4	main
poole	doc_438857714626_item	2406897	et	4	main
akna	doc_438857714626_item	2406898	et	3	main
laual	doc_438857714626_item	2406899	et	3	main
seisavad	doc_438857714626_item	2406900	et	3	main
toalilled	doc_438857714626_item	2406901	et	3	main
aknalauad	doc_438857714626_item	2406902	et	3	main
on	doc_438857714626_item	2406903	et	4	main
valge	doc_438857714626_item	2406904	et	4	main
peal	doc_438857714626_item	2406905	et	4	main
on	doc_438857714626_item	2406912	et	4	main
on	doc_438857714626_item	2406918	et	4	main
koht	doc_438857714626_item	2406920	et	3	main
kass	doc_438857714626_item	2406922	et	3	main
taburetid	doc_438857714626_item	2406927	et	3	main
kraanikaus	doc_438857714626_item	2406929	et	4	main
umbes	doc_438857714626_item	2406937	et	4	main
magamistuba	doc_438857714626_item	2406946	et	4	main
magamistuba	doc_438857714626_item	2406947	et	4	main
on	doc_438857714626_item	2406948	et	4	main
põrandal	doc_438857714626_item	2406960	et	3	main
on	doc_438857714626_item	2406961	et	4	main
beež	doc_438857714626_item	2406963	et	2	main
on	doc_438857714626_item	2406972	et	4	main
riiul	doc_438857714626_item	2406976	et	4	main
on	doc_438857714626_item	2406984	et	4	main
laud	doc_438857714626_item	2406998	et	4	main
seina	doc_438857714626_item	2407005	et	4	main
seisab	doc_438857714626_item	2407007	et	3	main
kohal	doc_438857714626_item	2407012	et	4	main
seinal	doc_438857714626_item	2407013	et	3	main
neeli	doc_438857714626_item	2406926	et	4	main
prügiämber	doc_438857714626_item	2406931	et	3	main
korter	doc_438857714626_item	2406933	et	3	main
kaks	doc_438857714626_item	2406935	et	3	main
elutuba	doc_438857714626_item	2406936	et	4	main
on	doc_438857714626_item	2406953	et	4	main
on	doc_438857714626_item	2406956	et	4	main
suur	doc_438857714626_item	2406962	et	3	main
seisab	doc_438857714626_item	2406969	et	3	main
neli	doc_438857714626_item	2406973	et	3	main
teisel	doc_438857714626_item	2406980	et	4	main
ja	doc_438857714626_item	2406990	et	3	main
kirjutuslaud	doc_438857714626_item	2406995	et	4	main
peal	doc_438857714626_item	2406996	et	4	main
vasakul	doc_438857714626_item	2407004	et	4	main
suur	doc_438857714626_item	2407008	et	3	main
tugitoolvoodi	doc_438857714626_item	2407010	et	4	main
tugitoolvoodi	doc_438857714626_item	2407011	et	4	main
ja	doc_438857714626_item	2407017	et	3	main
nurgas	doc_438857714626_item	2407022	et	3	main
akna	doc_438857714626_item	2407024	et	3	main
seisab	doc_438857714626_item	2407025	et	3	main
kardinad	doc_438857714626_item	2407031	et	4	main
põrandall	doc_438857714626_item	2407032	et	4	main
on	doc_438857714626_item	2407033	et	4	main
suur	doc_438857714626_item	2407034	et	3	main
beež	doc_438857714626_item	2407035	et	2	main
väike	doc_438857714626_item	2407040	et	4	main
laelamp	doc_438857714626_item	2407041	et	3	main
vasakul	doc_438857714626_item	2407065	et	4	main
seina	doc_438857714626_item	2407066	et	4	main
juures	doc_438857714626_item	2407067	et	4	main
seisab	doc_438857714626_item	2407068	et	3	main
suur	doc_438857714626_item	2407069	et	3	main
kohal	doc_438857714626_item	2407075	et	4	main
on	doc_438857714626_item	2407077	et	4	main
sektsioonkapp	doc_438857714626_item	2407081	et	4	main
riiul	doc_438857714626_item	2407139	et	4	main
kõrval	doc_438857714626_item	2407148	et	4	main
lagi	doc_438857714626_item	2407152	et	4	main
laelamp	doc_438857714626_item	2407155	et	3	main
ja	doc_438857714626_item	2407158	et	3	main
rullkardinad	doc_438857714626_item	2407160	et	4	main
on	doc_438857714626_item	2407170	et	4	main
minu	doc_438857714626_item	2407177	et	3	main
minu	doc_438857714626_item	2407182	et	3	main
kapp	doc_438857714626_item	2407191	et	3	main
neli	doc_438857714626_item	2407193	et	3	main
sahtelid	doc_438857714626_item	2407194	et	3	main
kapp	doc_438857714626_item	2407195	et	3	main
kruvid	doc_438857714626_item	2407202	et	4	main
ma	doc_438857714626_item	2407227	et	3	main
eest	doc_438857714626_item	2407230	et	4	main
umbes	doc_438857714626_item	2407231	et	4	main
kaks	doc_438857714626_item	2407232	et	3	main
sada	doc_438857714626_item	2407233	et	4	main
krooni	doc_438857714626_item	2407234	et	4	main
vesi	doc_438857714626_item	2407240	et	4	main
ma	doc_438857714626_item	2407245	et	3	main
maksan	doc_438857714626_item	2407246	et	3	main
essee	doc_438857714627_item	2407252	et	4	main
minu	doc_438857714627_item	2407253	et	3	main
kodu	doc_438857714627_item	2407254	et	4	main
ma	doc_438857714627_item	2407255	et	3	main
elan	doc_438857714627_item	2407256	et	3	main
estis	doc_438857714627_item	2407257	et	4	main
narvas	doc_438857714627_item	2407260	et	4	main
ei	doc_438857714627_item	2407271	et	4	main
korrust	doc_438857714627_item	2407277	et	3	main
trepikoda	doc_438857714627_item	2407279	et	4	main
üheksa	doc_438857714627_item	2407282	et	4	main
korterit	doc_438857714627_item	2407283	et	3	main
maja	doc_438857714627_item	2407284	et	4	main
meil	doc_438857714627_item	2407292	et	4	main
vesi	doc_438857714627_item	2407306	et	4	main
on	doc_438857714627_item	2407325	et	4	main
hea	doc_438857714627_item	2407346	et	4	main
ja	doc_438857714627_item	2407347	et	3	main
suurem	doc_438857714627_item	2407362	et	4	main
on	doc_438857714627_item	2407365	et	4	main
elutuba	doc_438857714627_item	2407369	et	4	main
vasakule	doc_438857714627_item	2407384	et	4	main
on	doc_438857714627_item	2407393	et	4	main
vasakule	doc_438857714627_item	2407397	et	4	main
asub	doc_438857714627_item	2407402	et	3	main
tuba	doc_438857714627_item	2407411	et	4	main
taga	doc_438857714626_item	2407021	et	4	main
tüllkardinad	doc_438857714626_item	2407028	et	4	main
on	doc_438857714626_item	2407044	et	4	main
üksest	doc_438857714626_item	2407056	et	3	main
mugavad	doc_438857714626_item	2407070	et	3	main
seinal	doc_438857714626_item	2407076	et	3	main
on	doc_438857714626_item	2407082	et	4	main
neli	doc_438857714626_item	2407083	et	3	main
sektsioonid	doc_438857714626_item	2407084	et	3	main
esemesel	doc_438857714626_item	2407085	et	4	main
sektsioon	doc_438857714626_item	2407086	et	3	main
esemesel	doc_438857714626_item	2407087	et	4	main
on	doc_438857714626_item	2407089	et	4	main
riiul	doc_438857714626_item	2407088	et	4	main
raamatud	doc_438857714626_item	2407090	et	4	main
teisel	doc_438857714626_item	2407091	et	4	main
riiul	doc_438857714626_item	2407092	et	4	main
muusikakeskus	doc_438857714626_item	2407094	et	3	main
on	doc_438857714626_item	2407093	et	4	main
kolmandal	doc_438857714626_item	2407095	et	3	main
riiul	doc_438857714626_item	2407096	et	4	main
on	doc_438857714626_item	2407097	et	4	main
teler	doc_438857714626_item	2407098	et	3	main
neljandal	doc_438857714626_item	2407099	et	3	main
riiul	doc_438857714626_item	2407100	et	4	main
on	doc_438857714626_item	2407101	et	4	main
teisel	doc_438857714626_item	2407103	et	4	main
laserplaadimängija	doc_438857714626_item	2407102	et	4	main
sektsioon	doc_438857714626_item	2407104	et	3	main
ja	doc_438857714626_item	2407105	et	3	main
kolmandal	doc_438857714626_item	2407106	et	3	main
sektsioon	doc_438857714626_item	2407107	et	3	main
esemesel	doc_438857714626_item	2407108	et	4	main
riiul	doc_438857714626_item	2407109	et	4	main
on	doc_438857714626_item	2407110	et	4	main
voodipesu	doc_438857714626_item	2407111	et	4	main
teisel	doc_438857714626_item	2407112	et	4	main
riiul	doc_438857714626_item	2407113	et	4	main
on	doc_438857714626_item	2407114	et	4	main
teeserviis	doc_438857714626_item	2407115	et	3	main
ja	doc_438857714626_item	2407116	et	3	main
kohviseerviis	doc_438857714626_item	2407117	et	4	main
siktsioon	doc_438857714626_item	2407122	et	4	main
raamatud	doc_438857714626_item	2407126	et	4	main
on	doc_438857714626_item	2407129	et	4	main
veniklaasid	doc_438857714626_item	2407133	et	4	main
sektsioonkapp	doc_438857714626_item	2407149	et	4	main
suur	doc_438857714626_item	2407154	et	3	main
akna	doc_438857714626_item	2407156	et	3	main
laud	doc_438857714626_item	2407169	et	4	main
korteris	doc_438857714626_item	2407178	et	3	main
klaasitud	doc_438857714626_item	2407184	et	4	main
üksest	doc_438857714626_item	2407185	et	3	main
paremal	doc_438857714626_item	2407186	et	4	main
on	doc_438857714626_item	2407196	et	4	main
tööinstrument	doc_438857714626_item	2407197	et	3	main
haamer	doc_438857714626_item	2407203	et	3	main
ja	doc_438857714626_item	2407204	et	3	main
meeter	doc_438857714626_item	2407205	et	3	main
teisel	doc_438857714626_item	2407206	et	4	main
sahtel	doc_438857714626_item	2407207	et	3	main
on	doc_438857714626_item	2407208	et	4	main
metallipuurid	doc_438857714626_item	2407209	et	3	main
puupuurid	doc_438857714626_item	2407210	et	3	main
ja	doc_438857714626_item	2407211	et	3	main
betoonpuurid	doc_438857714626_item	2407212	et	3	main
kolmandal	doc_438857714626_item	2407213	et	3	main
ja	doc_438857714626_item	2407214	et	3	main
neljandal	doc_438857714626_item	2407215	et	3	main
sahtelid	doc_438857714626_item	2407216	et	3	main
on	doc_438857714626_item	2407217	et	4	main
pintsel	doc_438857714626_item	2407218	et	3	main
värvimine	doc_438857714626_item	2407219	et	4	main
ja	doc_438857714626_item	2407220	et	3	main
maksan	doc_438857714626_item	2407228	et	3	main
elektri	doc_438857714626_item	2407229	et	3	main
ja	doc_438857714626_item	2407238	et	3	main
mõõturi	doc_438857714626_item	2407243	et	4	main
krooni	doc_438857714626_item	2407250	et	4	main
viisteist	doc_438857714627_item	2407268	et	4	main
meie	doc_438857714627_item	2407269	et	4	main
kaks	doc_438857714627_item	2407278	et	3	main
välisuksed	doc_438857714627_item	2407285	et	4	main
kaivad	doc_438857714627_item	2407286	et	4	main
lukus	doc_438857714627_item	2407287	et	3	main
kõik	doc_438857714627_item	2407288	et	4	main
naabrid	doc_438857714627_item	2407289	et	3	main
kõigi	doc_438857714627_item	2407295	et	4	main
on	doc_438857714626_item	2407125	et	4	main
kristall	doc_438857714626_item	2407130	et	3	main
ja	doc_438857714626_item	2407132	et	3	main
riiul	doc_438857714626_item	2407135	et	4	main
on	doc_438857714626_item	2407136	et	4	main
baar	doc_438857714626_item	2407137	et	3	main
neljandal	doc_438857714626_item	2407138	et	3	main
sahtel	doc_438857714626_item	2407141	et	3	main
melhiorinoad	doc_438857714626_item	2407144	et	4	main
külgmine	doc_438857714626_item	2407159	et	3	main
juures	doc_438857714626_item	2407162	et	4	main
seisab	doc_438857714626_item	2407163	et	3	main
ümmargune	doc_438857714626_item	2407164	et	3	main
laud	doc_438857714626_item	2407165	et	4	main
peal	doc_438857714626_item	2407168	et	4	main
edasi	doc_438857714626_item	2407173	et	3	main
rõdule	doc_438857714626_item	2407176	et	3	main
on	doc_438857714626_item	2407179	et	4	main
rõdule	doc_438857714626_item	2407181	et	3	main
rõdele	doc_438857714626_item	2407183	et	4	main
seisab	doc_438857714626_item	2407189	et	3	main
on	doc_438857714626_item	2407192	et	4	main
sahtel	doc_438857714626_item	2407199	et	3	main
põrandal	doc_438857714626_item	2407222	et	3	main
väike	doc_438857714626_item	2407224	et	4	main
hall	doc_438857714626_item	2407225	et	4	main
gaasi	doc_438857714626_item	2407236	et	4	main
maksan	doc_438857714626_item	2407242	et	3	main
umbes	doc_438857714626_item	2407248	et	4	main
majas	doc_438857714627_item	2407263	et	3	main
number	doc_438857714627_item	2407264	et	3	main
kaks	doc_438857714627_item	2407265	et	3	main
korteris	doc_438857714627_item	2407266	et	3	main
ole	doc_438857714627_item	2407272	et	4	main
suur	doc_438857714627_item	2407273	et	3	main
on	doc_438857714627_item	2407275	et	4	main
kivimaja	doc_438857714627_item	2407294	et	4	main
see	doc_438857714627_item	2407297	et	3	main
keskkütte	doc_438857714627_item	2407299	et	4	main
aed	doc_438857714627_item	2407327	et	3	main
narova	doc_438857714627_item	2407329	et	4	main
on	doc_438857714627_item	2407335	et	4	main
ümberringi	doc_438857714627_item	2407339	et	3	main
linaosa	doc_438857714627_item	2407349	et	4	main
me	doc_438857714627_item	2407350	et	4	main
ja	doc_438857714627_item	2407370	et	3	main
meie	doc_438857714627_item	2407381	et	4	main
asuvad	doc_438857714627_item	2407385	et	4	main
veel	doc_438857714627_item	2407395	et	4	main
esimene	doc_438857714627_item	2407400	et	3	main
tuba	doc_438857714627_item	2407401	et	4	main
kolme	doc_438857714627_item	2407410	et	4	main
on	doc_438857714627_item	2407417	et	4	main
jalatsiriiul	doc_438857714627_item	2407431	et	4	main
vastas	doc_438857714627_item	2407433	et	4	main
suur	doc_438857714627_item	2407435	et	3	main
kandiline	doc_438857714627_item	2407436	et	4	main
peegel	doc_438857714627_item	2407437	et	3	main
esikus	doc_438857714627_item	2407438	et	3	main
põrand	doc_438857714627_item	2407439	et	3	main
laelamp	doc_438857714627_item	2407449	et	3	main
minu	doc_438857714627_item	2407450	et	3	main
elutuba	doc_438857714627_item	2407451	et	4	main
seisavad	doc_438857714627_item	2407458	et	3	main
tugitoolide	doc_438857714627_item	2407463	et	3	main
seisab	doc_438857714627_item	2407487	et	3	main
kapp	doc_438857714627_item	2407489	et	3	main
kujukesed	doc_438857714627_item	2407493	et	4	main
vaas	doc_438857714627_item	2407495	et	3	main
kaks	doc_438857714627_item	2407499	et	3	main
ja	doc_438857714627_item	2407511	et	3	main
seisavad	doc_438857714627_item	2407514	et	3	main
juures	doc_438857714627_item	2407517	et	4	main
on	doc_438857714627_item	2407524	et	4	main
paremal	doc_438857714627_item	2407545	et	4	main
lai	doc_438857714627_item	2407547	et	3	main
juures	doc_438857714627_item	2407557	et	4	main
põrandal	doc_438857714627_item	2407558	et	3	main
kõrval	doc_438857714627_item	2407569	et	4	main
ripub	doc_438857714627_item	2407570	et	3	main
ümmargune	doc_438857714627_item	2407571	et	3	main
seinakell	doc_438857714627_item	2407572	et	3	main
kirju	doc_438857714626_item	2407226	et	4	main
kuus	doc_438857714626_item	2407235	et	4	main
ma	doc_438857714626_item	2407241	et	3	main
järgi	doc_438857714626_item	2407244	et	4	main
keskküte	doc_438857714626_item	2407247	et	3	main
kaheksasada	doc_438857714626_item	2407249	et	4	main
virumaal	doc_438857714627_item	2407259	et	4	main
maja	doc_438857714627_item	2407270	et	4	main
on	doc_438857714627_item	2407281	et	4	main
on	doc_438857714627_item	2407293	et	4	main
mugavustega	doc_438857714627_item	2407296	et	4	main
on	doc_438857714627_item	2407298	et	4	main
elekter	doc_438857714627_item	2407300	et	3	main
kanalisatsioon	doc_438857714627_item	2407301	et	3	main
kaabeltelevisioon	doc_438857714627_item	2407302	et	4	main
majas	doc_438857714627_item	2407303	et	3	main
sest	doc_438857714627_item	2407309	et	4	main
meil	doc_438857714627_item	2407310	et	4	main
on	doc_438857714627_item	2407311	et	4	main
soe	doc_438857714627_item	2407312	et	4	main
vesi	doc_438857714627_item	2407313	et	4	main
alati	doc_438857714627_item	2407314	et	4	main
maja	doc_438857714627_item	2407315	et	4	main
õues	doc_438857714627_item	2407316	et	4	main
on	doc_438857714627_item	2407317	et	4	main
mõned	doc_438857714627_item	2407318	et	3	main
pinged	doc_438857714627_item	2407319	et	3	main
ja	doc_438857714627_item	2407320	et	3	main
kasvavad	doc_438857714627_item	2407321	et	4	main
mõned	doc_438857714627_item	2407331	et	3	main
tee	doc_438857714627_item	2407336	et	4	main
samasugused	doc_438857714627_item	2407341	et	3	main
elame	doc_438857714627_item	2407351	et	3	main
on	doc_438857714627_item	2407355	et	4	main
kolmetoaline	doc_438857714627_item	2407357	et	4	main
korter	doc_438857714627_item	2407358	et	3	main
kaks	doc_438857714627_item	2407359	et	3	main
tuba	doc_438857714627_item	2407360	et	4	main
on	doc_438857714627_item	2407361	et	4	main
on	doc_438857714627_item	2407377	et	4	main
idapoolne	doc_438857714627_item	2407378	et	3	main
siin	doc_438857714627_item	2407379	et	4	main
on	doc_438857714627_item	2407380	et	4	main
ja	doc_438857714627_item	2407387	et	3	main
eraldi	doc_438857714627_item	2407394	et	4	main
paremale	doc_438857714627_item	2407404	et	4	main
esikust	doc_438857714627_item	2407406	et	4	main
vastas	doc_438857714627_item	2407409	et	4	main
vastas	doc_438857714627_item	2407415	et	4	main
välisuksest	doc_438857714627_item	2407422	et	4	main
suur	doc_438857714627_item	2407425	et	3	main
on	doc_438857714627_item	2407440	et	4	main
on	doc_438857714627_item	2407444	et	4	main
lael	doc_438857714627_item	2407447	et	4	main
on	doc_438857714627_item	2407448	et	4	main
vasakul	doc_438857714627_item	2407457	et	4	main
on	doc_438857714627_item	2407491	et	4	main
küünlajalad	doc_438857714627_item	2407494	et	3	main
maali	doc_438857714627_item	2407500	et	4	main
televiisorikapp	doc_438857714627_item	2407505	et	4	main
ees	doc_438857714627_item	2407508	et	4	main
on	doc_438857714627_item	2407509	et	4	main
külgkardinad	doc_438857714627_item	2407512	et	4	main
akna	doc_438857714627_item	2407516	et	3	main
suured	doc_438857714627_item	2407520	et	3	main
magamistuba	doc_438857714627_item	2407528	et	4	main
avar	doc_438857714627_item	2407529	et	3	main
ja	doc_438857714627_item	2407530	et	3	main
pime	doc_438857714627_item	2407531	et	3	main
ka	doc_438857714627_item	2407532	et	3	main
uksest	doc_438857714627_item	2407533	et	4	main
kuus	doc_438857714626_item	2407251	et	4	main
ida	doc_438857714627_item	2407258	et	4	main
tallinna	doc_438857714627_item	2407261	et	4	main
tänaval	doc_438857714627_item	2407262	et	4	main
number	doc_438857714627_item	2407267	et	3	main
majas	doc_438857714627_item	2407274	et	3	main
kolm	doc_438857714627_item	2407276	et	3	main
trepikojas	doc_438857714627_item	2407280	et	3	main
teavad	doc_438857714627_item	2407290	et	3	main
igaüht	doc_438857714627_item	2407291	et	3	main
on	doc_438857714627_item	2407304	et	4	main
külm	doc_438857714627_item	2407305	et	3	main
ja	doc_438857714627_item	2407307	et	3	main
gaasiboilerid	doc_438857714627_item	2407308	et	3	main
erinevad	doc_438857714627_item	2407322	et	4	main
puud	doc_438857714627_item	2407323	et	4	main
lähedal	doc_438857714627_item	2407324	et	4	main
ees	doc_438857714627_item	2407334	et	4	main
rahulik	doc_438857714627_item	2407348	et	3	main
korrusel	doc_438857714627_item	2407353	et	3	main
tubade	doc_438857714627_item	2407363	et	3	main
on	doc_438857714627_item	2407368	et	4	main
üks	doc_438857714627_item	2407372	et	3	main
esikust	doc_438857714627_item	2407383	et	4	main
vannituba	doc_438857714627_item	2407386	et	4	main
tualett	doc_438857714627_item	2407388	et	3	main
vannituba	doc_438857714627_item	2407390	et	4	main
edasi	doc_438857714627_item	2407396	et	3	main
on	doc_438857714627_item	2407398	et	4	main
köök	doc_438857714627_item	2407399	et	3	main
otse	doc_438857714627_item	2407407	et	4	main
välisukse	doc_438857714627_item	2407408	et	4	main
on	doc_438857714627_item	2407412	et	4	main
vannitoa	doc_438857714627_item	2407413	et	3	main
ukse	doc_438857714627_item	2407414	et	3	main
esik	doc_438857714627_item	2407416	et	3	main
kitsas	doc_438857714627_item	2407419	et	4	main
pime	doc_438857714627_item	2407326	et	3	main
jõgi	doc_438857714627_item	2407328	et	3	main
piir	doc_438857714627_item	2407330	et	3	main
toidukauplused	doc_438857714627_item	2407332	et	3	main
maja	doc_438857714627_item	2407333	et	4	main
tallinna	doc_438857714627_item	2407337	et	4	main
tänav	doc_438857714627_item	2407338	et	4	main
on	doc_438857714627_item	2407340	et	4	main
kolmekorruselised	doc_438857714627_item	2407342	et	4	main
majad	doc_438857714627_item	2407343	et	3	main
see	doc_438857714627_item	2407344	et	3	main
on	doc_438857714627_item	2407345	et	4	main
esimesel	doc_438857714627_item	2407352	et	3	main
meil	doc_438857714627_item	2407354	et	4	main
erastatud	doc_438857714627_item	2407356	et	4	main
aknad	doc_438857714627_item	2407364	et	3	main
põhjapoolne	doc_438857714627_item	2407366	et	3	main
siin	doc_438857714627_item	2407367	et	4	main
magamistuba	doc_438857714627_item	2407371	et	4	main
tuba	doc_438857714627_item	2407373	et	4	main
on	doc_438857714627_item	2407374	et	4	main
väikesem	doc_438857714627_item	2407375	et	4	main
aken	doc_438857714627_item	2407376	et	3	main
kabinet	doc_438857714627_item	2407382	et	3	main
meil	doc_438857714627_item	2407389	et	4	main
ja	doc_438857714627_item	2407391	et	3	main
tualett	doc_438857714627_item	2407392	et	3	main
esikust	doc_438857714627_item	2407403	et	4	main
teine	doc_438857714627_item	2407405	et	3	main
väike	doc_438857714627_item	2407418	et	4	main
ja	doc_438857714627_item	2407420	et	3	main
vasakul	doc_438857714627_item	2407423	et	4	main
ripub	doc_438857714627_item	2407424	et	3	main
seinanagi	doc_438857714627_item	2407426	et	4	main
riiuliga	doc_438857714627_item	2407427	et	4	main
nagi	doc_438857714627_item	2407428	et	4	main
all	doc_438857714627_item	2407429	et	3	main
on	doc_438857714627_item	2407430	et	4	main
on	doc_438857714627_item	2407434	et	4	main
väike	doc_438857714627_item	2407445	et	4	main
kaks	doc_438857714627_item	2407459	et	3	main
tugitooli	doc_438857714627_item	2407461	et	4	main
seina	doc_438857714627_item	2407485	et	4	main
kapi	doc_438857714627_item	2407496	et	4	main
ripuvad	doc_438857714627_item	2407498	et	3	main
paremal	doc_438857714627_item	2407502	et	4	main
seisab	doc_438857714627_item	2407504	et	3	main
teleriga	doc_438857714627_item	2407506	et	3	main
akna	doc_438857714627_item	2407507	et	3	main
toalilled	doc_438857714627_item	2407515	et	3	main
põrandal	doc_438857714627_item	2407518	et	3	main
on	doc_438857714627_item	2407519	et	4	main
nagi	doc_438857714627_item	2407432	et	4	main
põrandal	doc_438857714627_item	2407443	et	3	main
vaip	doc_438857714627_item	2407446	et	3	main
on	doc_438857714627_item	2407452	et	4	main
avar	doc_438857714627_item	2407453	et	3	main
aga	doc_438857714627_item	2407454	et	3	main
ja	doc_438857714627_item	2407462	et	3	main
kahekohaline	doc_438857714627_item	2407466	et	4	main
diivan	doc_438857714627_item	2407467	et	3	main
tugitoolide	doc_438857714627_item	2407468	et	3	main
ja	doc_438857714627_item	2407469	et	3	main
diivani	doc_438857714627_item	2407470	et	4	main
juures	doc_438857714627_item	2407471	et	4	main
seisab	doc_438857714627_item	2407472	et	3	main
ümmargune	doc_438857714627_item	2407473	et	3	main
diivanilaud	doc_438857714627_item	2407474	et	4	main
tugitoolide	doc_438857714627_item	2407475	et	3	main
vahel	doc_438857714627_item	2407476	et	4	main
on	doc_438857714627_item	2407477	et	4	main
põrandalamp	doc_438857714627_item	2407478	et	3	main
diivanil	doc_438857714627_item	2407479	et	3	main
ja	doc_438857714627_item	2407480	et	3	main
tugitoolidel	doc_438857714627_item	2407481	et	3	main
on	doc_438857714627_item	2407482	et	4	main
väikesed	doc_438857714627_item	2407483	et	4	main
padjad	doc_438857714627_item	2407484	et	3	main
pime	doc_438857714627_item	2407421	et	3	main
kaetud	doc_438857714627_item	2407441	et	4	main
linoleumiga	doc_438857714627_item	2407442	et	3	main
pimedavõitu	doc_438857714627_item	2407455	et	4	main
uksest	doc_438857714627_item	2407456	et	4	main
suur	doc_438857714627_item	2407460	et	3	main
kõrval	doc_438857714627_item	2407464	et	4	main
on	doc_438857714627_item	2407465	et	4	main
juures	doc_438857714627_item	2407486	et	4	main
kapis	doc_438857714627_item	2407490	et	3	main
tüllkardin	doc_438857714627_item	2407510	et	3	main
aknalaual	doc_438857714627_item	2407513	et	3	main
toalilled	doc_438857714627_item	2407521	et	3	main
terrakota	doc_438857714627_item	2407525	et	4	main
seina	doc_438857714627_item	2407535	et	4	main
juures	doc_438857714627_item	2407536	et	4	main
seisab	doc_438857714627_item	2407537	et	3	main
suur	doc_438857714627_item	2407538	et	3	main
riidekapp	doc_438857714627_item	2407539	et	3	main
uksest	doc_438857714627_item	2407544	et	4	main
heledavärvi	doc_438857714627_item	2407576	et	4	main
on	doc_438857714627_item	2407585	et	4	main
valgusküllasem	doc_438857714627_item	2407586	et	4	main
uksest	doc_438857714627_item	2407587	et	4	main
raamatud	doc_438857714627_item	2407593	et	4	main
pildid	doc_438857714627_item	2407596	et	3	main
laulalamp	doc_438857714627_item	2407610	et	4	main
vasakul	doc_438857714627_item	2407615	et	4	main
toalill	doc_438857714627_item	2407618	et	3	main
teine	doc_438857714627_item	2407622	et	3	main
nurgas	doc_438857714627_item	2407630	et	3	main
tugitoll	doc_438857714627_item	2407632	et	3	main
akna	doc_438857714627_item	2407639	et	3	main
külgkardinad	doc_438857714627_item	2407644	et	4	main
ka	doc_438857714627_item	2407645	et	3	main
aknalaual	doc_438857714627_item	2407646	et	3	main
kasvad	doc_438857714627_item	2407647	et	3	main
vasakul	doc_438857714627_item	2407655	et	4	main
kõrval	doc_438857714627_item	2407679	et	4	main
seisab	doc_438857714627_item	2407680	et	3	main
külmkapp	doc_438857714627_item	2407681	et	3	main
akna	doc_438857714627_item	2407682	et	3	main
ees	doc_438857714627_item	2407683	et	4	main
elektrikann	doc_438857714627_item	2407726	et	3	main
neli	doc_438857714627_item	2407733	et	3	main
on	doc_438857714627_item	2407737	et	4	main
lusikad	doc_438857714627_item	2407738	et	3	main
noad	doc_438857714627_item	2407740	et	3	main
peeniksed	doc_438857714627_item	2407752	et	4	main
neljas	doc_438857714627_item	2407754	et	4	main
kitsas	doc_438857714627_item	2407759	et	4	main
seinakapis	doc_438857714627_item	2407760	et	3	main
klaasid	doc_438857714627_item	2407764	et	4	main
porgandeid	doc_438857714627_item	2407789	et	3	main
gaasipliit	doc_438857714627_item	2407791	et	3	main
gaasipliidi	doc_438857714627_item	2407798	et	3	main
kohal	doc_438857714627_item	2407799	et	4	main
põrand	doc_438857714627_item	2407802	et	3	main
ripplaed	doc_438857714627_item	2407815	et	4	main
madal	doc_438857714627_item	2407488	et	3	main
erinevad	doc_438857714627_item	2407492	et	4	main
kohal	doc_438857714627_item	2407497	et	4	main
uksest	doc_438857714627_item	2407501	et	4	main
nurgas	doc_438857714627_item	2407503	et	3	main
ka	doc_438857714627_item	2407522	et	3	main
vaip	doc_438857714627_item	2407526	et	3	main
kapi	doc_438857714627_item	2407540	et	4	main
uksed	doc_438857714627_item	2407541	et	3	main
külgkardinad	doc_438857714627_item	2407582	et	4	main
meie	doc_438857714627_item	2407583	et	4	main
kabinet	doc_438857714627_item	2407584	et	3	main
on	doc_438857714627_item	2407592	et	4	main
paberid	doc_438857714627_item	2407595	et	3	main
kõrval	doc_438857714627_item	2407614	et	4	main
seisab	doc_438857714627_item	2407616	et	3	main
paremal	doc_438857714627_item	2407620	et	4	main
põrandal	doc_438857714627_item	2407523	et	3	main
meie	doc_438857714627_item	2407527	et	4	main
vasakul	doc_438857714627_item	2407534	et	4	main
on	doc_438857714627_item	2407542	et	4	main
seisab	doc_438857714627_item	2407546	et	3	main
öökapiga	doc_438857714627_item	2407550	et	3	main
öökappidel	doc_438857714627_item	2407551	et	3	main
on	doc_438857714627_item	2407552	et	4	main
kaks	doc_438857714627_item	2407553	et	3	main
väikest	doc_438857714627_item	2407554	et	4	main
lampi	doc_438857714627_item	2407555	et	4	main
peeglitega	doc_438857714627_item	2407543	et	3	main
voodi	doc_438857714627_item	2407548	et	4	main
kahe	doc_438857714627_item	2407549	et	3	main
beezid	doc_438857714627_item	2407559	et	4	main
kapi	doc_438857714627_item	2407561	et	4	main
voodi	doc_438857714627_item	2407563	et	4	main
on	doc_438857714627_item	2407575	et	4	main
ees	doc_438857714627_item	2407578	et	4	main
tüllkardin	doc_438857714627_item	2407580	et	3	main
kapis	doc_438857714627_item	2407591	et	3	main
fotod	doc_438857714627_item	2407597	et	3	main
teised	doc_438857714627_item	2407599	et	4	main
akna	doc_438857714627_item	2407601	et	3	main
seisab	doc_438857714627_item	2407603	et	3	main
kirjutuslaud	doc_438857714627_item	2407604	et	4	main
ja	doc_438857714627_item	2407605	et	3	main
tool	doc_438857714627_item	2407606	et	3	main
telefon	doc_438857714627_item	2407612	et	3	main
on	doc_438857714627_item	2407621	et	4	main
uksest	doc_438857714627_item	2407624	et	4	main
on	doc_438857714627_item	2407626	et	4	main
mõned	doc_438857714627_item	2407627	et	3	main
raamaturiiulid	doc_438857714627_item	2407628	et	3	main
raamatutega	doc_438857714627_item	2407629	et	3	main
seisavad	doc_438857714627_item	2407631	et	3	main
ja	doc_438857714627_item	2407633	et	3	main
ees	doc_438857714627_item	2407640	et	4	main
tüllkardin	doc_438857714627_item	2407642	et	3	main
suur	doc_438857714627_item	2407653	et	3	main
uksest	doc_438857714627_item	2407654	et	4	main
kaks	doc_438857714627_item	2407658	et	3	main
köögikappi	doc_438857714627_item	2407660	et	4	main
veel	doc_438857714627_item	2407671	et	4	main
köögikapp	doc_438857714627_item	2407674	et	3	main
asub	doc_438857714627_item	2407676	et	3	main
vasakul	doc_438857714627_item	2407678	et	4	main
voodi	doc_438857714627_item	2407556	et	4	main
voodiümbrusvaibad	doc_438857714627_item	2407560	et	3	main
ja	doc_438857714627_item	2407562	et	3	main
vahel	doc_438857714627_item	2407564	et	4	main
seisab	doc_438857714627_item	2407565	et	3	main
kummut	doc_438857714627_item	2407566	et	3	main
seinal	doc_438857714627_item	2407567	et	3	main
voodi	doc_438857714627_item	2407568	et	4	main
akna	doc_438857714627_item	2407577	et	3	main
on	doc_438857714627_item	2407579	et	4	main
ja	doc_438857714627_item	2407581	et	3	main
vasakul	doc_438857714627_item	2407588	et	4	main
seisab	doc_438857714627_item	2407589	et	3	main
sektsioonkapp	doc_438857714627_item	2407590	et	4	main
asjad	doc_438857714627_item	2407600	et	3	main
laual	doc_438857714627_item	2407607	et	3	main
asub	doc_438857714627_item	2407608	et	3	main
kompuuter	doc_438857714627_item	2407609	et	4	main
laulakell	doc_438857714627_item	2407611	et	4	main
toll	doc_438857714627_item	2407623	et	3	main
paremal	doc_438857714627_item	2407625	et	4	main
on	doc_438857714627_item	2407636	et	4	main
vaip	doc_438857714627_item	2407638	et	3	main
ole	doc_438857714627_item	2407652	et	4	main
köögikomplekt	doc_438857714627_item	2407657	et	3	main
laia	doc_438857714627_item	2407659	et	4	main
kappide	doc_438857714627_item	2407666	et	3	main
seinakapid	doc_438857714627_item	2407670	et	3	main
riivid	doc_438857714627_item	2407720	et	4	main
kapiplaadil	doc_438857714627_item	2407722	et	3	main
on	doc_438857714627_item	2407732	et	4	main
sahtlis	doc_438857714627_item	2407736	et	3	main
kahvlid	doc_438857714627_item	2407739	et	3	main
teised	doc_438857714627_item	2407747	et	4	main
nõud	doc_438857714627_item	2407762	et	3	main
sibulaid	doc_438857714627_item	2407790	et	3	main
seisab	doc_438857714627_item	2407792	et	3	main
on	doc_438857714627_item	2407803	et	4	main
kahhelkiviga	doc_438857714627_item	2407824	et	3	main
vann	doc_438857714627_item	2407835	et	3	main
kapiga	doc_438857714627_item	2407837	et	3	main
ripub	doc_438857714627_item	2407851	et	3	main
gaasiboiler	doc_438857714627_item	2407852	et	3	main
seinanagides	doc_438857714627_item	2407853	et	3	main
põrandal	doc_438857714627_item	2407856	et	3	main
veel	doc_438857714627_item	2407862	et	4	main
puhastusevahendid	doc_438857714627_item	2407865	et	4	main
on	doc_438857714627_item	2407869	et	4	main
korteris	doc_438857714627_item	2407876	et	3	main
meeldi	doc_438857714627_item	2407882	et	4	main
korter	doc_438857714627_item	2407884	et	3	main
ja	doc_438857714627_item	2407887	et	3	main
essee	doc_438857714628_item	2407891	et	4	main
9	doc_438857714628_item	2407899	et	2	main
on	doc_438857714628_item	2407909	et	4	main
ma	doc_438857714628_item	2407916	et	3	main
majas	doc_438857714628_item	2407919	et	3	main
ole	doc_438857714628_item	2407924	et	4	main
aga	doc_438857714628_item	2407925	et	3	main
keskküte	doc_438857714628_item	2407926	et	3	main
on	doc_438857714628_item	2407927	et	4	main
meie	doc_438857714628_item	2407937	et	4	main
maja	doc_438857714628_item	2407938	et	4	main
elame	doc_438857714628_item	2407943	et	3	main
elame	doc_438857714628_item	2407949	et	3	main
me	doc_438857714628_item	2407953	et	4	main
elame	doc_438857714628_item	2407954	et	3	main
mänguväljak	doc_438857714628_item	2407969	et	3	main
mänguväljakul	doc_438857714628_item	2407970	et	3	main
maja	doc_438857714628_item	2407978	et	4	main
on	doc_438857714628_item	2407980	et	4	main
rohelust	doc_438857714628_item	2407982	et	4	main
palju	doc_438857714628_item	2407989	et	4	main
maja	doc_438857714628_item	2407992	et	4	main
taga	doc_438857714628_item	2407993	et	4	main
eesti	doc_438857714628_item	2407995	et	4	main
lasteaias	doc_438857714628_item	2408009	et	4	main
lapsi	doc_438857714628_item	2408012	et	4	main
jalutavad	doc_438857714628_item	2408016	et	4	main
laste	doc_438857714628_item	2408017	et	4	main
mänguväljakul	doc_438857714628_item	2408018	et	3	main
kõik	doc_438857714627_item	2407573	et	4	main
mööbel	doc_438857714627_item	2407574	et	3	main
ametlikud	doc_438857714627_item	2407594	et	3	main
ja	doc_438857714627_item	2407598	et	3	main
juures	doc_438857714627_item	2407602	et	4	main
laua	doc_438857714627_item	2407613	et	3	main
suur	doc_438857714627_item	2407617	et	3	main
laua	doc_438857714627_item	2407619	et	3	main
põrandal	doc_438857714627_item	2407635	et	3	main
toalilled	doc_438857714627_item	2407648	et	3	main
asub	doc_438857714627_item	2407656	et	3	main
samasugused	doc_438857714627_item	2407669	et	3	main
on	doc_438857714627_item	2407672	et	4	main
asub	doc_438857714627_item	2407684	et	3	main
söögilaud	doc_438857714627_item	2407685	et	4	main
hakklihamasin	doc_438857714627_item	2407721	et	3	main
seisavad	doc_438857714627_item	2407723	et	3	main
kitsas	doc_438857714627_item	2407730	et	4	main
kapis	doc_438857714627_item	2407731	et	3	main
sahtlit	doc_438857714627_item	2407734	et	3	main
ja	doc_438857714627_item	2407746	et	3	main
kolmas	doc_438857714627_item	2407749	et	3	main
erinevad	doc_438857714627_item	2407751	et	4	main
on	doc_438857714627_item	2407755	et	4	main
käterätikud	doc_438857714627_item	2407756	et	3	main
ja	doc_438857714627_item	2407757	et	3	main
salvrätikud	doc_438857714627_item	2407758	et	3	main
osas	doc_438857714627_item	2407785	et	4	main
laia	doc_438857714627_item	2407795	et	4	main
vahel	doc_438857714627_item	2407797	et	4	main
akna	doc_438857714627_item	2407806	et	3	main
ees	doc_438857714627_item	2407807	et	4	main
ribikardinad	doc_438857714627_item	2407809	et	4	main
köögis	doc_438857714627_item	2407810	et	3	main
vannitoas	doc_438857714627_item	2407811	et	3	main
ja	doc_438857714627_item	2407812	et	3	main
kraanikauss	doc_438857714627_item	2407836	et	3	main
kappides	doc_438857714627_item	2407844	et	4	main
vanni	doc_438857714627_item	2407849	et	4	main
ripuvad	doc_438857714627_item	2407854	et	3	main
vannitoamatt	doc_438857714627_item	2407858	et	3	main
seal	doc_438857714627_item	2407863	et	4	main
minu	doc_438857714627_item	2407875	et	3	main
ei	doc_438857714627_item	2407881	et	4	main
pime	doc_438857714627_item	2407886	et	3	main
n	doc_438857714628_item	2407898	et	4	main
palju	doc_438857714628_item	2407910	et	4	main
elan	doc_438857714628_item	2407917	et	3	main
põrandalamp	doc_438857714627_item	2407634	et	3	main
kirju	doc_438857714627_item	2407637	et	4	main
on	doc_438857714627_item	2407641	et	4	main
ja	doc_438857714627_item	2407643	et	3	main
meie	doc_438857714627_item	2407649	et	4	main
köök	doc_438857714627_item	2407650	et	3	main
ei	doc_438857714627_item	2407651	et	4	main
ja	doc_438857714627_item	2407661	et	3	main
üks	doc_438857714627_item	2407662	et	3	main
kitsas	doc_438857714627_item	2407663	et	4	main
kapp	doc_438857714627_item	2407664	et	3	main
seinal	doc_438857714627_item	2407665	et	3	main
kohal	doc_438857714627_item	2407667	et	4	main
ripuvad	doc_438857714627_item	2407668	et	3	main
kõrgem	doc_438857714627_item	2407673	et	4	main
see	doc_438857714627_item	2407675	et	3	main
aknast	doc_438857714627_item	2407677	et	4	main
söögilaua	doc_438857714627_item	2407686	et	3	main
juures	doc_438857714627_item	2407687	et	4	main
seisab	doc_438857714627_item	2407688	et	3	main
kolm	doc_438857714627_item	2407689	et	3	main
taburetti	doc_438857714627_item	2407690	et	4	main
üks	doc_438857714627_item	2407691	et	3	main
lai	doc_438857714627_item	2407692	et	3	main
kapp	doc_438857714627_item	2407693	et	3	main
on	doc_438857714627_item	2407694	et	4	main
valamuga	doc_438857714627_item	2407695	et	3	main
kapis	doc_438857714627_item	2407696	et	3	main
valamu	doc_438857714627_item	2407697	et	4	main
all	doc_438857714627_item	2407698	et	3	main
on	doc_438857714627_item	2407699	et	4	main
prügiämber	doc_438857714627_item	2407700	et	3	main
hari	doc_438857714627_item	2407701	et	4	main
kühvel	doc_438857714627_item	2407703	et	3	main
kapis	doc_438857714627_item	2407704	et	3	main
valamu	doc_438857714627_item	2407705	et	4	main
kohal	doc_438857714627_item	2407706	et	4	main
asub	doc_438857714627_item	2407707	et	3	main
ja	doc_438857714627_item	2407702	et	3	main
nõud	doc_438857714627_item	2407708	et	3	main
taldrikud	doc_438857714627_item	2407709	et	3	main
kruusid	doc_438857714627_item	2407710	et	3	main
tassid	doc_438857714627_item	2407711	et	4	main
teises	doc_438857714627_item	2407712	et	4	main
laias	doc_438857714627_item	2407713	et	4	main
kapis	doc_438857714627_item	2407714	et	3	main
on	doc_438857714627_item	2407715	et	4	main
potid	doc_438857714627_item	2407716	et	4	main
kausid	doc_438857714627_item	2407717	et	3	main
panid	doc_438857714627_item	2407718	et	4	main
sõelad	doc_438857714627_item	2407719	et	3	main
veekann	doc_438857714627_item	2407724	et	3	main
seinakapis	doc_438857714627_item	2407727	et	3	main
toiduained	doc_438857714627_item	2407729	et	3	main
avajad	doc_438857714627_item	2407744	et	4	main
korgitser	doc_438857714627_item	2407745	et	3	main
köögitarbed	doc_438857714627_item	2407748	et	3	main
asjad	doc_438857714627_item	2407753	et	3	main
ka	doc_438857714627_item	2407763	et	3	main
bokaalid	doc_438857714627_item	2407765	et	4	main
alumises	doc_438857714627_item	2407784	et	3	main
ma	doc_438857714627_item	2407786	et	3	main
kitsa	doc_438857714627_item	2407793	et	3	main
kaetud	doc_438857714627_item	2407804	et	4	main
on	doc_438857714627_item	2407808	et	4	main
tualetis	doc_438857714627_item	2407813	et	3	main
on	doc_438857714627_item	2407814	et	4	main
põrandad	doc_438857714627_item	2407821	et	3	main
köögis	doc_438857714627_item	2407825	et	3	main
kraanikausi	doc_438857714627_item	2407839	et	3	main
kohal	doc_438857714627_item	2407840	et	4	main
ripub	doc_438857714627_item	2407841	et	3	main
vannikapp	doc_438857714627_item	2407842	et	3	main
pesu-	doc_438857714627_item	2407847	et	4	main
on	doc_438857714627_item	2407857	et	4	main
tualetis	doc_438857714627_item	2407859	et	3	main
seinakapp	doc_438857714627_item	2407861	et	3	main
wc	doc_438857714627_item	2407870	et	4	main
matt	doc_438857714627_item	2407871	et	3	main
mulle	doc_438857714627_item	2407872	et	4	main
meeldib	doc_438857714627_item	2407873	et	3	main
palju	doc_438857714627_item	2407878	et	4	main
sest	doc_438857714627_item	2407883	et	4	main
on	doc_438857714627_item	2407885	et	4	main
asub	doc_438857714627_item	2407888	et	3	main
korrusel	doc_438857714627_item	2407890	et	3	main
minu	doc_438857714628_item	2407892	et	3	main
aadress	doc_438857714628_item	2407893	et	3	main
on	doc_438857714628_item	2407894	et	4	main
korter	doc_438857714628_item	2407900	et	3	main
vabaduse	doc_438857714628_item	2407903	et	4	main
seal	doc_438857714628_item	2407907	et	4	main
kasvavad	doc_438857714628_item	2407908	et	4	main
asub	doc_438857714628_item	2407913	et	3	main
kadastiku	doc_438857714628_item	2407914	et	3	main
tiik	doc_438857714628_item	2407915	et	3	main
sissekäigus	doc_438857714628_item	2407928	et	3	main
välisuksel	doc_438857714628_item	2407939	et	4	main
korrusel	doc_438857714628_item	2407945	et	3	main
korteris	doc_438857714628_item	2407947	et	3	main
kesklinnas	doc_438857714628_item	2407959	et	4	main
geneva	doc_438857714628_item	2407960	et	4	main
astri	doc_438857714628_item	2407963	et	3	main
on	doc_438857714628_item	2407971	et	4	main
ronimisredelid	doc_438857714628_item	2407973	et	3	main
kiik	doc_438857714628_item	2407974	et	3	main
palju	doc_438857714628_item	2407981	et	4	main
kasvavad	doc_438857714628_item	2407983	et	4	main
sirelid	doc_438857714628_item	2407984	et	3	main
meie	doc_438857714628_item	2407991	et	4	main
asub	doc_438857714628_item	2407994	et	3	main
lasteaed	doc_438857714628_item	2407996	et	3	main
seal	doc_438857714628_item	2407997	et	4	main
kasvavad	doc_438857714628_item	2407998	et	4	main
muru	doc_438857714628_item	2408007	et	4	main
on	doc_438857714628_item	2408010	et	4	main
võileivagrill	doc_438857714627_item	2407725	et	3	main
on	doc_438857714627_item	2407728	et	4	main
ühes	doc_438857714627_item	2407735	et	4	main
teises	doc_438857714627_item	2407741	et	4	main
on	doc_438857714627_item	2407742	et	4	main
kulbid	doc_438857714627_item	2407743	et	3	main
asuvad	doc_438857714627_item	2407750	et	4	main
on	doc_438857714627_item	2407761	et	4	main
pitsid	doc_438857714627_item	2407766	et	3	main
ja	doc_438857714627_item	2407767	et	3	main
teeserviis	doc_438857714627_item	2407768	et	3	main
kõrges	doc_438857714627_item	2407769	et	4	main
kapis	doc_438857714627_item	2407770	et	3	main
on	doc_438857714627_item	2407771	et	4	main
kolm	doc_438857714627_item	2407772	et	3	main
osa	doc_438857714627_item	2407773	et	4	main
ülemises	doc_438857714627_item	2407774	et	3	main
osas	doc_438857714627_item	2407775	et	4	main
on	doc_438857714627_item	2407776	et	4	main
lõunaserviis	doc_438857714627_item	2407777	et	3	main
mahlapress	doc_438857714627_item	2407778	et	3	main
köögikombain	doc_438857714627_item	2407779	et	3	main
keskmises	doc_438857714627_item	2407780	et	3	main
seisavad	doc_438857714627_item	2407781	et	3	main
purgid	doc_438857714627_item	2407782	et	4	main
juurviljadega	doc_438857714627_item	2407783	et	3	main
hoian	doc_438857714627_item	2407787	et	3	main
kartuleid	doc_438857714627_item	2407788	et	3	main
ja	doc_438857714627_item	2407794	et	3	main
kappide	doc_438857714627_item	2407796	et	3	main
ripub	doc_438857714627_item	2407800	et	3	main
tõmbekapp	doc_438857714627_item	2407801	et	3	main
linoleumiga	doc_438857714627_item	2407805	et	3	main
vannitoas	doc_438857714627_item	2407816	et	3	main
ja	doc_438857714627_item	2407817	et	3	main
tualetis	doc_438857714627_item	2407818	et	3	main
seinad	doc_438857714627_item	2407819	et	3	main
ja	doc_438857714627_item	2407820	et	3	main
kaetud	doc_438857714627_item	2407823	et	4	main
on	doc_438857714627_item	2407827	et	4	main
ja	doc_438857714627_item	2407829	et	3	main
alumiste	doc_438857714627_item	2407830	et	3	main
kappide	doc_438857714627_item	2407831	et	3	main
vahel	doc_438857714627_item	2407832	et	4	main
vannitoas	doc_438857714627_item	2407833	et	3	main
seisavad	doc_438857714627_item	2407834	et	3	main
automaatpesumasin	doc_438857714627_item	2407838	et	3	main
ripub	doc_438857714627_item	2407860	et	3	main
ja	doc_438857714627_item	2407866	et	3	main
põrandal	doc_438857714627_item	2407868	et	3	main
on	doc_438857714627_item	2407877	et	4	main
ruumi	doc_438857714627_item	2407879	et	4	main
vabaduse	doc_438857714628_item	2407895	et	4	main
prospekt	doc_438857714628_item	2407896	et	3	main
16	doc_438857714628_item	2407902	et	2	main
prospekt	doc_438857714628_item	2407904	et	3	main
puud	doc_438857714628_item	2407911	et	4	main
viiekorruselises	doc_438857714628_item	2407918	et	4	main
minu	doc_438857714628_item	2407920	et	3	main
korterit	doc_438857714628_item	2407931	et	3	main
me	doc_438857714628_item	2407942	et	4	main
kolmandal	doc_438857714628_item	2407944	et	3	main
juures	doc_438857714628_item	2407961	et	4	main
lähedal	doc_438857714628_item	2407964	et	4	main
hoovis	doc_438857714628_item	2407966	et	4	main
on	doc_438857714628_item	2407967	et	4	main
liivakast	doc_438857714628_item	2407972	et	4	main
ja	doc_438857714628_item	2407975	et	3	main
ümbruses	doc_438857714628_item	2407979	et	3	main
puud	doc_438857714628_item	2408000	et	4	main
ja	doc_438857714628_item	2408001	et	3	main
põõsad	doc_438857714628_item	2408002	et	3	main
ja	doc_438857714628_item	2408003	et	3	main
suvel	doc_438857714628_item	2408004	et	3	main
ilus	doc_438857714628_item	2408005	et	4	main
pehme	doc_438857714628_item	2408006	et	4	main
palju	doc_438857714628_item	2408011	et	4	main
nad	doc_438857714628_item	2408013	et	3	main
mängivad	doc_438857714628_item	2408014	et	4	main
väike	doc_438857714628_item	2408023	et	4	main
9	doc_438857714628_item	2408036	et	2	main
2	doc_438857714628_item	2408038	et	2	main
on	doc_438857714628_item	2408049	et	4	main
aknalaual	doc_438857714628_item	2408053	et	3	main
seinal	doc_438857714628_item	2408056	et	3	main
maalid	doc_438857714628_item	2408058	et	4	main
ja	doc_438857714628_item	2408070	et	3	main
šampoon	doc_438857714628_item	2408080	et	2	main
on	doc_438857714628_item	2408084	et	4	main
pesumasin	doc_438857714628_item	2408089	et	3	main
põrandal	doc_438857714628_item	2408113	et	3	main
lilled	doc_438857714628_item	2408122	et	3	main
on	doc_438857714628_item	2408124	et	4	main
on	doc_438857714628_item	2408129	et	4	main
raamatud	doc_438857714628_item	2408130	et	4	main
videomagnitofon	doc_438857714628_item	2408131	et	4	main
laserplaadimängija	doc_438857714628_item	2408132	et	4	main
ja	doc_438857714628_item	2408133	et	3	main
teler	doc_438857714628_item	2408134	et	3	main
akna	doc_438857714628_item	2408135	et	3	main
küldkardinad	doc_438857714628_item	2408138	et	4	main
tüllkardinad	doc_438857714628_item	2408140	et	4	main
elutoas	doc_438857714628_item	2408141	et	3	main
on	doc_438857714628_item	2408142	et	4	main
laelamp	doc_438857714628_item	2408143	et	3	main
ja	doc_438857714628_item	2408144	et	3	main
ja	doc_438857714628_item	2408152	et	3	main
on	doc_438857714627_item	2407822	et	4	main
kahhelkivi	doc_438857714627_item	2407826	et	4	main
ülemiste	doc_438857714627_item	2407828	et	4	main
peegliga	doc_438857714627_item	2407843	et	3	main
asuvad	doc_438857714627_item	2407845	et	4	main
kosmeetika-	doc_438857714627_item	2407846	et	4	main
puhastusevahendid	doc_438857714627_item	2407848	et	4	main
kohal	doc_438857714627_item	2407850	et	4	main
käterätikud	doc_438857714627_item	2407855	et	3	main
on	doc_438857714627_item	2407864	et	4	main
majapidamisinventar	doc_438857714627_item	2407867	et	3	main
sest	doc_438857714627_item	2407874	et	4	main
aga	doc_438857714627_item	2407880	et	3	main
esimesel	doc_438857714627_item	2407889	et	3	main
maja	doc_438857714628_item	2407897	et	4	main
n	doc_438857714628_item	2407901	et	4	main
on	doc_438857714628_item	2407905	et	4	main
olus	doc_438857714628_item	2407906	et	3	main
seal	doc_438857714628_item	2407912	et	4	main
majas	doc_438857714628_item	2407921	et	3	main
lifti	doc_438857714628_item	2407922	et	4	main
kakskümmend	doc_438857714628_item	2407930	et	4	main
trepikoda	doc_438857714628_item	2407933	et	4	main
on	doc_438857714628_item	2407940	et	4	main
kaubanduskeskuse	doc_438857714628_item	2407962	et	3	main
laste	doc_438857714628_item	2407968	et	4	main
mõned	doc_438857714628_item	2407976	et	3	main
kastanid	doc_438857714628_item	2407986	et	3	main
ja	doc_438857714628_item	2407988	et	3	main
põõsaid	doc_438857714628_item	2407990	et	3	main
erinevad	doc_438857714628_item	2407999	et	4	main
eesti	doc_438857714628_item	2408008	et	4	main
lasteaias	doc_438857714628_item	2408019	et	4	main
minu	doc_438857714628_item	2408020	et	3	main
kaksteist	doc_438857714628_item	2408030	et	4	main
ruutmeetrit	doc_438857714628_item	2408031	et	3	main
on	doc_438857714628_item	2408035	et	4	main
elutuba	doc_438857714628_item	2408042	et	4	main
ja	doc_438857714628_item	2408044	et	3	main
on	doc_438857714628_item	2408046	et	4	main
põhjapoolsed	doc_438857714628_item	2408047	et	3	main
elutuba	doc_438857714628_item	2408048	et	4	main
hubane	doc_438857714628_item	2408052	et	3	main
toalilled	doc_438857714628_item	2408055	et	3	main
lastetuba	doc_438857714628_item	2408062	et	4	main
on	doc_438857714628_item	2408063	et	4	main
sahvris	doc_438857714628_item	2408065	et	3	main
me	doc_438857714628_item	2408066	et	4	main
hambaharjad	doc_438857714628_item	2408079	et	3	main
ja	doc_438857714628_item	2408088	et	3	main
esikus	doc_438857714628_item	2408104	et	3	main
sektsioonkapp	doc_438857714628_item	2408109	et	4	main
mugav	doc_438857714628_item	2408111	et	3	main
vaasis	doc_438857714628_item	2408121	et	3	main
sahtlid	doc_438857714628_item	2408127	et	3	main
on	doc_438857714628_item	2408137	et	4	main
ja	doc_438857714628_item	2408139	et	3	main
kirjutuslaud	doc_438857714628_item	2408151	et	4	main
fotod	doc_438857714628_item	2408156	et	3	main
laual	doc_438857714628_item	2408169	et	3	main
paremal	doc_438857714628_item	2408173	et	4	main
köögikapp	doc_438857714628_item	2408211	et	3	main
kapis	doc_438857714628_item	2408212	et	3	main
palju	doc_438857714628_item	2408214	et	4	main
ei	doc_438857714628_item	2407923	et	4	main
on	doc_438857714628_item	2407929	et	4	main
meie	doc_438857714628_item	2407932	et	4	main
on	doc_438857714628_item	2407934	et	4	main
alati	doc_438857714628_item	2407935	et	4	main
puhas	doc_438857714628_item	2407936	et	3	main
fonolukk	doc_438857714628_item	2407941	et	4	main
kolmetoalises	doc_438857714628_item	2407946	et	4	main
me	doc_438857714628_item	2407948	et	4	main
kõigi	doc_438857714628_item	2407950	et	4	main
mugavustega	doc_438857714628_item	2407951	et	4	main
korteris	doc_438857714628_item	2407952	et	3	main
kivimajas	doc_438857714628_item	2407955	et	4	main
minu	doc_438857714628_item	2407956	et	3	main
maja	doc_438857714628_item	2407957	et	4	main
asub	doc_438857714628_item	2407958	et	3	main
maja	doc_438857714628_item	2407965	et	4	main
pingid	doc_438857714628_item	2407977	et	3	main
kirsipuud	doc_438857714628_item	2407985	et	4	main
paplid	doc_438857714628_item	2407987	et	3	main
ja	doc_438857714628_item	2408015	et	3	main
korter	doc_438857714628_item	2408021	et	3	main
kaks	doc_438857714628_item	2408024	et	3	main
tuba	doc_438857714628_item	2408025	et	4	main
on	doc_438857714628_item	2408026	et	4	main
12	doc_438857714628_item	2408027	et	2	main
м	doc_438857714628_item	2408028	et	2	main
2	doc_438857714628_item	2408029	et	2	main
tuba	doc_438857714628_item	2408034	et	4	main
magamistuba	doc_438857714628_item	2408039	et	4	main
köök	doc_438857714628_item	2408045	et	3	main
väike	doc_438857714628_item	2408050	et	4	main
aga	doc_438857714628_item	2408051	et	3	main
seisavad	doc_438857714628_item	2408054	et	3	main
ripuvad	doc_438857714628_item	2408057	et	3	main
magamistuba	doc_438857714628_item	2408059	et	4	main
on	doc_438857714628_item	2408060	et	4	main
valgusküllane	doc_438857714628_item	2408064	et	4	main
talveriideid	doc_438857714628_item	2408068	et	3	main
vannituba	doc_438857714628_item	2408071	et	4	main
vannitoas	doc_438857714628_item	2408074	et	3	main
pesemisvahendid	doc_438857714628_item	2408076	et	3	main
ja	doc_438857714628_item	2408081	et	3	main
vannitoas	doc_438857714628_item	2408083	et	3	main
valamu	doc_438857714628_item	2408087	et	4	main
on	doc_438857714628_item	2408091	et	4	main
ja	doc_438857714628_item	2408093	et	3	main
on	doc_438857714628_item	2408105	et	4	main
asub	doc_438857714628_item	2408108	et	3	main
ja	doc_438857714628_item	2408110	et	3	main
diivan	doc_438857714628_item	2408112	et	3	main
on	doc_438857714628_item	2408114	et	4	main
ja	doc_438857714628_item	2408126	et	3	main
riiulites	doc_438857714628_item	2408128	et	3	main
seinalamp	doc_438857714628_item	2408145	et	3	main
lastetoas	doc_438857714628_item	2408146	et	3	main
riidekapp	doc_438857714628_item	2408153	et	3	main
laual	doc_438857714628_item	2408157	et	3	main
arvuti	doc_438857714628_item	2408159	et	4	main
ja	doc_438857714628_item	2408160	et	3	main
printer	doc_438857714628_item	2408161	et	3	main
akna	doc_438857714628_item	2408162	et	3	main
ees	doc_438857714628_item	2408163	et	4	main
magamistoas	doc_438857714628_item	2408172	et	3	main
röster	doc_438857714628_item	2408227	et	3	main
sahtris	doc_438857714628_item	2408241	et	4	main
ja	doc_438857714628_item	2408245	et	3	main
gaasipliit	doc_438857714628_item	2408257	et	3	main
ja	doc_438857714628_item	2408258	et	3	main
all	doc_438857714628_item	2408261	et	3	main
ämber	doc_438857714628_item	2408265	et	3	main
kus	doc_438857714628_item	2408266	et	3	main
kohal	doc_438857714628_item	2408277	et	4	main
põrand	doc_438857714628_item	2408286	et	3	main
me	doc_438857714628_item	2408297	et	4	main
elame	doc_438857714628_item	2408298	et	3	main
keskküte	doc_438857714628_item	2408302	et	3	main
mulle	doc_438857714628_item	2408313	et	4	main
essee	doc_438857714629_item	2408322	et	4	main
ma	doc_438857714629_item	2408323	et	3	main
eesti	doc_438857714629_item	2408325	et	4	main
narva	doc_438857714629_item	2408332	et	4	main
kivimajas	doc_438857714629_item	2408338	et	4	main
maja	doc_438857714629_item	2408339	et	4	main
ümbruses	doc_438857714629_item	2408340	et	3	main
maja	doc_438857714629_item	2408345	et	4	main
laste	doc_438857714629_item	2408348	et	4	main
pink	doc_438857714629_item	2408351	et	3	main
kaks	doc_438857714629_item	2408353	et	3	main
lähedal	doc_438857714629_item	2408359	et	4	main
laste	doc_438857714629_item	2408363	et	4	main
eemal	doc_438857714629_item	2408370	et	3	main
tuba	doc_438857714629_item	2408398	et	4	main
lastetuba	doc_438857714629_item	2408402	et	4	main
vannituba	doc_438857714629_item	2408405	et	4	main
on	doc_438857714629_item	2408406	et	4	main
korteris	doc_438857714629_item	2408414	et	3	main
elutoast	doc_438857714629_item	2408421	et	3	main
üks	doc_438857714628_item	2408033	et	3	main
on	doc_438857714628_item	2408040	et	4	main
pikk	doc_438857714628_item	2408061	et	4	main
wc	doc_438857714628_item	2408069	et	4	main
koos	doc_438857714628_item	2408073	et	4	main
on	doc_438857714628_item	2408075	et	4	main
hambapasta	doc_438857714628_item	2408078	et	4	main
pesupulbrid	doc_438857714628_item	2408082	et	3	main
vann	doc_438857714628_item	2408085	et	3	main
väiksevõitu	doc_438857714628_item	2408092	et	4	main
pime	doc_438857714628_item	2408094	et	3	main
seinal	doc_438857714628_item	2408096	et	3	main
nagi	doc_438857714628_item	2408098	et	4	main
elutoas	doc_438857714628_item	2408107	et	3	main
punasekirju	doc_438857714628_item	2408115	et	4	main
vaip	doc_438857714628_item	2408116	et	3	main
laual	doc_438857714628_item	2408117	et	3	main
on	doc_438857714628_item	2408118	et	4	main
vaas	doc_438857714628_item	2408119	et	3	main
ja	doc_438857714628_item	2408120	et	3	main
on	doc_438857714628_item	2408022	et	4	main
ja	doc_438857714628_item	2408032	et	3	main
м	doc_438857714628_item	2408037	et	2	main
päikesepoolne	doc_438857714628_item	2408041	et	3	main
lastetuba	doc_438857714628_item	2408043	et	4	main
hoiame	doc_438857714628_item	2408067	et	3	main
on	doc_438857714628_item	2408072	et	4	main
seep	doc_438857714628_item	2408077	et	4	main
peegel	doc_438857714628_item	2408086	et	3	main
esik	doc_438857714628_item	2408090	et	3	main
esikus	doc_438857714628_item	2408095	et	3	main
ripuvad	doc_438857714628_item	2408097	et	3	main
ja	doc_438857714628_item	2408099	et	3	main
peegel	doc_438857714628_item	2408100	et	3	main
nagis	doc_438857714628_item	2408101	et	3	main
ripuvad	doc_438857714628_item	2408102	et	3	main
välisriided	doc_438857714628_item	2408103	et	3	main
ripplagi	doc_438857714628_item	2408106	et	3	main
sektsioonkapis	doc_438857714628_item	2408123	et	4	main
riiuleid	doc_438857714628_item	2408125	et	4	main
ääres	doc_438857714628_item	2408148	et	4	main
seisavad	doc_438857714628_item	2408149	et	3	main
seinal	doc_438857714628_item	2408154	et	3	main
on	doc_438857714628_item	2408174	et	4	main
voodi	doc_438857714628_item	2408175	et	4	main
riidekapp	doc_438857714628_item	2408176	et	3	main
toa	doc_438857714628_item	2408177	et	3	main
nurgas	doc_438857714628_item	2408178	et	3	main
taldrikud	doc_438857714628_item	2408219	et	3	main
klassid	doc_438857714628_item	2408221	et	3	main
kohvimasin	doc_438857714628_item	2408226	et	3	main
kohviveski	doc_438857714628_item	2408230	et	4	main
juures	doc_438857714628_item	2408232	et	4	main
söögilaud	doc_438857714628_item	2408234	et	4	main
taburetid	doc_438857714628_item	2408236	et	3	main
söögilaual	doc_438857714628_item	2408237	et	3	main
seina	doc_438857714628_item	2408254	et	4	main
kartuleid	doc_438857714628_item	2408269	et	3	main
juures	doc_438857714628_item	2408272	et	4	main
nõudepesu	doc_438857714628_item	2408274	et	4	main
vahend	doc_438857714628_item	2408275	et	3	main
gaasipliidi	doc_438857714628_item	2408276	et	3	main
kaetud	doc_438857714628_item	2408283	et	4	main
järgi	doc_438857714628_item	2408312	et	4	main
minu	doc_438857714628_item	2408315	et	3	main
ta	doc_438857714628_item	2408317	et	4	main
väike	doc_438857714628_item	2408319	et	4	main
aga	doc_438857714628_item	2408320	et	3	main
maakonnas	doc_438857714629_item	2408329	et	4	main
elan	doc_438857714629_item	2408336	et	3	main
rohelist	doc_438857714629_item	2408343	et	4	main
muru	doc_438857714629_item	2408344	et	4	main
üks	doc_438857714629_item	2408350	et	3	main
vana	doc_438857714629_item	2408355	et	4	main
meie	doc_438857714629_item	2408357	et	4	main
maja	doc_438857714629_item	2408358	et	4	main
sõidutee	doc_438857714629_item	2408366	et	4	main
ja	doc_438857714629_item	2408368	et	3	main
elutuba	doc_438857714629_item	2408399	et	4	main
tualett	doc_438857714629_item	2408403	et	3	main
väiksevõitu	doc_438857714629_item	2408410	et	4	main
ja	doc_438857714629_item	2408411	et	3	main
pime	doc_438857714629_item	2408412	et	3	main
on	doc_438857714629_item	2408415	et	4	main
üks	doc_438857714629_item	2408416	et	3	main
rõdu	doc_438857714629_item	2408417	et	4	main
uks	doc_438857714629_item	2408418	et	3	main
elutuba	doc_438857714629_item	2408423	et	4	main
soe	doc_438857714629_item	2408427	et	4	main
on	doc_438857714629_item	2408429	et	4	main
ripplae	doc_438857714629_item	2408430	et	4	main
ja	doc_438857714629_item	2408431	et	3	main
ilus	doc_438857714629_item	2408432	et	4	main
laelamp	doc_438857714629_item	2408433	et	3	main
seisab	doc_438857714629_item	2408439	et	3	main
diivanilaud	doc_438857714629_item	2408440	et	4	main
diivanilaual	doc_438857714629_item	2408441	et	4	main
on	doc_438857714629_item	2408442	et	4	main
on	doc_438857714629_item	2408450	et	4	main
aknalaual	doc_438857714629_item	2408461	et	3	main
on	doc_438857714629_item	2408462	et	4	main
toalilled	doc_438857714629_item	2408463	et	3	main
ees	doc_438857714628_item	2408136	et	4	main
seina	doc_438857714628_item	2408147	et	4	main
diivan	doc_438857714628_item	2408150	et	3	main
ribikardinad	doc_438857714628_item	2408165	et	4	main
lastetoas	doc_438857714628_item	2408166	et	3	main
on	doc_438857714628_item	2408167	et	4	main
laelamp	doc_438857714628_item	2408168	et	3	main
on	doc_438857714628_item	2408170	et	4	main
on	doc_438857714628_item	2408179	et	4	main
suur	doc_438857714628_item	2408180	et	3	main
teler	doc_438857714628_item	2408181	et	3	main
seinal	doc_438857714628_item	2408182	et	3	main
ripub	doc_438857714628_item	2408183	et	3	main
peegel	doc_438857714628_item	2408184	et	3	main
magamistoas	doc_438857714628_item	2408185	et	3	main
on	doc_438857714628_item	2408186	et	4	main
2	doc_438857714628_item	2408187	et	2	main
kaks	doc_438857714628_item	2408188	et	3	main
seinalampi	doc_438857714628_item	2408189	et	4	main
riidekapis	doc_438857714628_item	2408190	et	3	main
pesu	doc_438857714628_item	2408192	et	4	main
ja	doc_438857714628_item	2408193	et	3	main
riided	doc_438857714628_item	2408194	et	3	main
on	doc_438857714628_item	2408191	et	4	main
akna	doc_438857714628_item	2408195	et	3	main
ees	doc_438857714628_item	2408196	et	4	main
on	doc_438857714628_item	2408197	et	4	main
küldkardinad	doc_438857714628_item	2408198	et	4	main
ja	doc_438857714628_item	2408199	et	3	main
tüllkardinad	doc_438857714628_item	2408200	et	4	main
minu	doc_438857714628_item	2408201	et	3	main
köök	doc_438857714628_item	2408202	et	3	main
on	doc_438857714628_item	2408203	et	4	main
väike	doc_438857714628_item	2408204	et	4	main
ümbes	doc_438857714628_item	2408205	et	4	main
6	doc_438857714628_item	2408206	et	2	main
ruutmeetrit	doc_438857714628_item	2408207	et	3	main
köögis	doc_438857714628_item	2408208	et	3	main
paremal	doc_438857714628_item	2408209	et	4	main
seisab	doc_438857714628_item	2408210	et	3	main
ripuvad	doc_438857714628_item	2408155	et	3	main
on	doc_438857714628_item	2408158	et	4	main
on	doc_438857714628_item	2408164	et	4	main
laualamp	doc_438857714628_item	2408171	et	3	main
toiduained	doc_438857714628_item	2408223	et	3	main
on	doc_438857714628_item	2408233	et	4	main
ja	doc_438857714628_item	2408235	et	3	main
seisab	doc_438857714628_item	2408238	et	3	main
elektrikann	doc_438857714628_item	2408239	et	3	main
söögilaua	doc_438857714628_item	2408240	et	3	main
seisavad	doc_438857714628_item	2408256	et	3	main
hoiame	doc_438857714628_item	2408268	et	3	main
valamu	doc_438857714628_item	2408271	et	4	main
on	doc_438857714628_item	2408273	et	4	main
tõmbekapp	doc_438857714628_item	2408279	et	3	main
sein	doc_438857714628_item	2408281	et	3	main
on	doc_438857714628_item	2408287	et	4	main
linoleumiga	doc_438857714628_item	2408289	et	3	main
on	doc_438857714628_item	2408291	et	4	main
ripplagi	doc_438857714628_item	2408292	et	3	main
köögiakna	doc_438857714628_item	2408293	et	3	main
kõigi	doc_438857714628_item	2408299	et	4	main
soe	doc_438857714628_item	2408303	et	4	main
vesi	doc_438857714628_item	2408306	et	4	main
narva	doc_438857714629_item	2408330	et	4	main
mänguväljak	doc_438857714629_item	2408364	et	3	main
kõnnitee	doc_438857714629_item	2408365	et	4	main
bussipeatus	doc_438857714629_item	2408367	et	4	main
on	doc_438857714629_item	2408396	et	4	main
kolm	doc_438857714629_item	2408397	et	3	main
on	doc_438857714629_item	2408409	et	4	main
päikesepaisteline	doc_438857714629_item	2408425	et	4	main
paremal	doc_438857714629_item	2408435	et	4	main
seina	doc_438857714629_item	2408445	et	4	main
juures	doc_438857714629_item	2408446	et	4	main
diivan	doc_438857714629_item	2408447	et	3	main
diivani	doc_438857714629_item	2408448	et	4	main
ribikardinad	doc_438857714629_item	2408460	et	4	main
kõrval	doc_438857714629_item	2408487	et	4	main
seina	doc_438857714629_item	2408488	et	4	main
edasi	doc_438857714629_item	2408493	et	3	main
elutubas	doc_438857714629_item	2408498	et	4	main
taga	doc_438857714629_item	2408515	et	4	main
nägi	doc_438857714629_item	2408519	et	3	main
on	doc_438857714628_item	2408213	et	4	main
riiuleid	doc_438857714628_item	2408215	et	4	main
riiulitel	doc_438857714628_item	2408216	et	3	main
on	doc_438857714628_item	2408217	et	4	main
nõud	doc_438857714628_item	2408218	et	3	main
tassid	doc_438857714628_item	2408220	et	4	main
kodumasinad	doc_438857714628_item	2408225	et	3	main
hakkalihamasin	doc_438857714628_item	2408229	et	4	main
lusikad	doc_438857714628_item	2408246	et	3	main
on	doc_438857714628_item	2408248	et	4	main
mikrolaineahi	doc_438857714628_item	2408252	et	3	main
paremal	doc_438857714628_item	2408253	et	4	main
valamu	doc_438857714628_item	2408260	et	4	main
prügiämber	doc_438857714628_item	2408263	et	3	main
me	doc_438857714628_item	2408267	et	4	main
kahhelkividega	doc_438857714628_item	2408284	et	3	main
köögi	doc_438857714628_item	2408285	et	3	main
mugavustega	doc_438857714628_item	2408300	et	4	main
ja	doc_438857714628_item	2408304	et	3	main
mõõturi	doc_438857714628_item	2408311	et	4	main
meeldib	doc_438857714628_item	2408314	et	3	main
hubane	doc_438857714628_item	2408321	et	3	main
elan	doc_438857714629_item	2408324	et	3	main
vabariigis	doc_438857714629_item	2408326	et	3	main
ida	doc_438857714629_item	2408327	et	4	main
viru	doc_438857714629_item	2408328	et	4	main
linnas	doc_438857714629_item	2408331	et	4	main
ma	doc_438857714629_item	2408335	et	3	main
palju	doc_438857714629_item	2408342	et	4	main
on	doc_438857714629_item	2408347	et	4	main
kauplused	doc_438857714629_item	2408362	et	3	main
natuke	doc_438857714629_item	2408369	et	4	main
baar	doc_438857714629_item	2408372	et	3	main
ja	doc_438857714629_item	2408401	et	3	main
eraldi	doc_438857714629_item	2408407	et	4	main
köök	doc_438857714629_item	2408408	et	3	main
rõdule	doc_438857714629_item	2408419	et	3	main
on	doc_438857714629_item	2408420	et	4	main
kannud	doc_438857714628_item	2408222	et	3	main
ja	doc_438857714628_item	2408224	et	3	main
mikser	doc_438857714628_item	2408228	et	3	main
köögiakna	doc_438857714628_item	2408231	et	3	main
on	doc_438857714628_item	2408242	et	4	main
noad	doc_438857714628_item	2408243	et	3	main
kahvlid	doc_438857714628_item	2408244	et	3	main
nurgas	doc_438857714628_item	2408247	et	3	main
külmkapp	doc_438857714628_item	2408249	et	3	main
külmkapil	doc_438857714628_item	2408250	et	3	main
seisab	doc_438857714628_item	2408251	et	3	main
ääres	doc_438857714628_item	2408255	et	4	main
valamu	doc_438857714628_item	2408259	et	4	main
asub	doc_438857714628_item	2408262	et	3	main
ja	doc_438857714628_item	2408264	et	3	main
köögis	doc_438857714628_item	2408270	et	3	main
seisab	doc_438857714628_item	2408278	et	3	main
köögi	doc_438857714628_item	2408280	et	3	main
on	doc_438857714628_item	2408282	et	4	main
kaetud	doc_438857714628_item	2408288	et	4	main
köögis	doc_438857714628_item	2408290	et	3	main
ees	doc_438857714628_item	2408294	et	4	main
on	doc_438857714628_item	2408295	et	4	main
tüllkardinad	doc_438857714628_item	2408296	et	4	main
korteris	doc_438857714628_item	2408301	et	3	main
külm	doc_438857714628_item	2408305	et	3	main
vee	doc_438857714628_item	2408307	et	3	main
eest	doc_438857714628_item	2408308	et	4	main
ma	doc_438857714628_item	2408309	et	3	main
maksan	doc_438857714628_item	2408310	et	3	main
korter	doc_438857714628_item	2408316	et	3	main
on	doc_438857714628_item	2408318	et	4	main
on	doc_438857714629_item	2408333	et	4	main
piirilinn	doc_438857714629_item	2408334	et	3	main
üheksakorruselises	doc_438857714629_item	2408337	et	4	main
on	doc_438857714629_item	2408341	et	4	main
hoovis	doc_438857714629_item	2408346	et	4	main
ronimisredelid	doc_438857714629_item	2408349	et	3	main
ja	doc_438857714629_item	2408352	et	3	main
suurt	doc_438857714629_item	2408354	et	3	main
puud	doc_438857714629_item	2408356	et	4	main
asuvad	doc_438857714629_item	2408360	et	4	main
toidukaupade	doc_438857714629_item	2408361	et	3	main
on	doc_438857714629_item	2408371	et	4	main
meie	doc_438857714629_item	2408373	et	4	main
majas	doc_438857714629_item	2408374	et	3	main
on	doc_438857714629_item	2408375	et	4	main
viis	doc_438857714629_item	2408376	et	4	main
sissekäiku	doc_438857714629_item	2408377	et	4	main
sissekäigus	doc_438857714629_item	2408378	et	3	main
on	doc_438857714629_item	2408379	et	4	main
kolmkümmend	doc_438857714629_item	2408380	et	4	main
kuus	doc_438857714629_item	2408381	et	4	main
korterit	doc_438857714629_item	2408382	et	3	main
ma	doc_438857714629_item	2408383	et	3	main
elan	doc_438857714629_item	2408384	et	3	main
teises	doc_438857714629_item	2408385	et	4	main
trepikojas	doc_438857714629_item	2408386	et	3	main
esimesel	doc_438857714629_item	2408387	et	3	main
korrusel	doc_438857714629_item	2408388	et	3	main
kolmetoalises	doc_438857714629_item	2408389	et	4	main
korteris	doc_438857714629_item	2408390	et	3	main
meie	doc_438857714629_item	2408391	et	4	main
korter	doc_438857714629_item	2408392	et	3	main
on	doc_438857714629_item	2408393	et	4	main
erastatud	doc_438857714629_item	2408394	et	4	main
korteris	doc_438857714629_item	2408395	et	3	main
magamistuba	doc_438857714629_item	2408400	et	4	main
ja	doc_438857714629_item	2408404	et	3	main
minu	doc_438857714629_item	2408413	et	3	main
meil	doc_438857714629_item	2408422	et	4	main
ja	doc_438857714629_item	2408426	et	3	main
juures	doc_438857714629_item	2408437	et	4	main
nurgas	doc_438857714629_item	2408438	et	3	main
kõrval	doc_438857714629_item	2408444	et	4	main
kohal	doc_438857714629_item	2408449	et	4	main
seisavad	doc_438857714629_item	2408454	et	3	main
tugitooli	doc_438857714629_item	2408456	et	4	main
sektsioonkapi	doc_438857714629_item	2408486	et	4	main
juures	doc_438857714629_item	2408489	et	4	main
seisab	doc_438857714629_item	2408490	et	3	main
on	doc_438857714629_item	2408500	et	4	main
punase	doc_438857714629_item	2408502	et	4	main
kirju	doc_438857714629_item	2408503	et	4	main
vaip	doc_438857714629_item	2408504	et	3	main
on	doc_438857714629_item	2408510	et	4	main
avar	doc_438857714629_item	2408511	et	3	main
ja	doc_438857714629_item	2408520	et	3	main
vasakul	doc_438857714629_item	2408526	et	4	main
kohal	doc_438857714629_item	2408532	et	4	main
seinal	doc_438857714629_item	2408533	et	3	main
ripub	doc_438857714629_item	2408534	et	3	main
suur	doc_438857714629_item	2408535	et	3	main
värviline	doc_438857714629_item	2408536	et	4	main
on	doc_438857714629_item	2408543	et	4	main
ribikardinad	doc_438857714629_item	2408557	et	4	main
sektsioonkapp	doc_438857714629_item	2408578	et	4	main
sektsioonkapis	doc_438857714629_item	2408579	et	4	main
paliu	doc_438857714629_item	2408584	et	4	main
kõrval	doc_438857714629_item	2408587	et	4	main
kirjutuslaud	doc_438857714629_item	2408589	et	4	main
kirjutuslaual	doc_438857714629_item	2408590	et	3	main
seisab	doc_438857714629_item	2408591	et	3	main
seina	doc_438857714629_item	2408595	et	4	main
kušeti	doc_438857714629_item	2408599	et	2	main
põrandas	doc_438857714629_item	2408601	et	3	main
uks	doc_438857714629_item	2408602	et	3	main
keldrisse	doc_438857714629_item	2408603	et	3	main
põrandal	doc_438857714629_item	2408604	et	3	main
pruuni	doc_438857714629_item	2408605	et	4	main
vaip	doc_438857714629_item	2408606	et	3	main
valamu	doc_438857714629_item	2408620	et	4	main
juures	doc_438857714629_item	2408635	et	4	main
köögikapis	doc_438857714629_item	2408646	et	3	main
kohviveski	doc_438857714629_item	2408657	et	4	main
kohvimasin	doc_438857714629_item	2408658	et	3	main
hakklihamasin	doc_438857714629_item	2408660	et	3	main
võileivagrill	doc_438857714629_item	2408664	et	3	main
mikrolaineahi	doc_438857714629_item	2408665	et	3	main
taburetid	doc_438857714629_item	2408675	et	3	main
ees	doc_438857714629_item	2408677	et	4	main
on	doc_438857714629_item	2408678	et	4	main
öökapp	doc_438857714629_item	2408704	et	3	main
ukse	doc_438857714629_item	2408710	et	3	main
vasakul	doc_438857714629_item	2408724	et	4	main
vähe	doc_438857714629_item	2408732	et	3	main
pesumasin	doc_438857714629_item	2408736	et	3	main
kraanikauss	doc_438857714629_item	2408738	et	3	main
vannitoa	doc_438857714629_item	2408739	et	3	main
balsam	doc_438857714629_item	2408760	et	4	main
hambaharjad	doc_438857714629_item	2408761	et	3	main
kõigi	doc_438857714629_item	2408765	et	4	main
arvuti	doc_438857714630_item	2408823	et	4	main
on	doc_438857714630_item	2408826	et	4	main
akna	doc_438857714630_item	2408828	et	3	main
on	doc_438857714630_item	2408841	et	4	main
holitseb	doc_438857714630_item	2408846	et	4	main
meie	doc_438857714630_item	2408847	et	4	main
tütar	doc_438857714630_item	2408848	et	3	main
maša	doc_438857714630_item	2408849	et	2	main
lühter	doc_438857714630_item	2408850	et	3	main
on	doc_438857714630_item	2408853	et	4	main
on	doc_438857714630_item	2408875	et	4	main
lamp	doc_438857714630_item	2408876	et	3	main
on	doc_438857714630_item	2408879	et	4	main
avar	doc_438857714630_item	2408914	et	3	main
on	doc_438857714629_item	2408424	et	4	main
uksest	doc_438857714629_item	2408434	et	4	main
akna	doc_438857714629_item	2408452	et	3	main
juures	doc_438857714629_item	2408453	et	4	main
kaks	doc_438857714629_item	2408455	et	3	main
ees	doc_438857714629_item	2408458	et	4	main
on	doc_438857714629_item	2408459	et	4	main
nurgas	doc_438857714629_item	2408464	et	3	main
akna	doc_438857714629_item	2408465	et	3	main
juures	doc_438857714629_item	2408466	et	4	main
seisab	doc_438857714629_item	2408467	et	3	main
lapselaud	doc_438857714629_item	2408468	et	4	main
lastelaual	doc_438857714629_item	2408469	et	3	main
on	doc_438857714629_item	2408470	et	4	main
suur	doc_438857714629_item	2408471	et	3	main
toalill	doc_438857714629_item	2408472	et	3	main
uksest	doc_438857714629_item	2408473	et	4	main
vasakul	doc_438857714629_item	2408474	et	4	main
seina	doc_438857714629_item	2408475	et	4	main
juures	doc_438857714629_item	2408476	et	4	main
sektsioonkapp	doc_438857714629_item	2408477	et	4	main
sektsioonkapis	doc_438857714629_item	2408478	et	4	main
on	doc_438857714629_item	2408479	et	4	main
teler	doc_438857714629_item	2408480	et	3	main
elutoas	doc_438857714629_item	2408428	et	3	main
seina	doc_438857714629_item	2408436	et	4	main
laserplaadimängija	doc_438857714629_item	2408443	et	4	main
seinalamp	doc_438857714629_item	2408451	et	3	main
akna	doc_438857714629_item	2408457	et	3	main
videomagnetofon	doc_438857714629_item	2408483	et	3	main
raamatlaua	doc_438857714629_item	2408492	et	4	main
suur	doc_438857714629_item	2408501	et	3	main
meil	doc_438857714629_item	2408505	et	4	main
ja	doc_438857714629_item	2408512	et	3	main
nurgas	doc_438857714629_item	2408516	et	3	main
on	doc_438857714629_item	2408518	et	4	main
riiul	doc_438857714629_item	2408521	et	4	main
seisab	doc_438857714629_item	2408529	et	3	main
seinal	doc_438857714629_item	2408549	et	3	main
seina	doc_438857714629_item	2408570	et	4	main
raamatud	doc_438857714629_item	2408580	et	4	main
muusikakeskus	doc_438857714629_item	2408581	et	3	main
voodipesu	doc_438857714629_item	2408582	et	4	main
lastemänguasjaid	doc_438857714629_item	2408585	et	4	main
uksest	doc_438857714629_item	2408593	et	4	main
seisab	doc_438857714629_item	2408597	et	3	main
tüllkärdin	doc_438857714629_item	2408609	et	4	main
vasakul	doc_438857714629_item	2408614	et	4	main
nurgas	doc_438857714629_item	2408615	et	3	main
seisab	doc_438857714629_item	2408616	et	3	main
külmkapp	doc_438857714629_item	2408617	et	3	main
valamu	doc_438857714629_item	2408618	et	4	main
kulp	doc_438857714629_item	2408631	et	3	main
köögikapi	doc_438857714629_item	2408651	et	3	main
gaasimõõdur	doc_438857714629_item	2408662	et	4	main
köögiakna	doc_438857714629_item	2408676	et	3	main
vastas	doc_438857714629_item	2408705	et	4	main
asub	doc_438857714629_item	2408712	et	3	main
ta	doc_438857714629_item	2408714	et	4	main
riiuli	doc_438857714629_item	2408717	et	3	main
vannitoas	doc_438857714629_item	2408734	et	3	main
on	doc_438857714629_item	2408735	et	4	main
maast	doc_438857714629_item	2408744	et	3	main
laeni	doc_438857714629_item	2408745	et	4	main
kraanikausi	doc_438857714629_item	2408746	et	3	main
all	doc_438857714629_item	2408747	et	3	main
seisab	doc_438857714629_item	2408748	et	3	main
pesukorv	doc_438857714629_item	2408749	et	3	main
ripub	doc_438857714629_item	2408752	et	3	main
on	doc_438857714629_item	2408755	et	4	main
elan	doc_438857714629_item	2408764	et	3	main
mugavustega	doc_438857714629_item	2408766	et	4	main
korter	doc_438857714630_item	2408770	et	3	main
päikesepoolne	doc_438857714630_item	2408814	et	3	main
toas	doc_438857714630_item	2408815	et	3	main
roheline	doc_438857714630_item	2408819	et	4	main
laual	doc_438857714630_item	2408821	et	3	main
lauga	doc_438857714630_item	2408825	et	3	main
ees	doc_438857714630_item	2408829	et	4	main
palju	doc_438857714630_item	2408842	et	4	main
laes	doc_438857714630_item	2408851	et	4	main
põrandal	doc_438857714630_item	2408852	et	3	main
pehme	doc_438857714630_item	2408854	et	4	main
suur	doc_438857714630_item	2408864	et	3	main
kõrval	doc_438857714630_item	2408870	et	4	main
kummil	doc_438857714630_item	2408874	et	4	main
valgusküllane	doc_438857714630_item	2408916	et	4	main
aken	doc_438857714630_item	2408918	et	3	main
ripuvad	doc_438857714630_item	2408923	et	3	main
diivanilaual	doc_438857714630_item	2408928	et	4	main
on	doc_438857714630_item	2408929	et	4	main
vaas	doc_438857714630_item	2408930	et	3	main
elutoas	doc_438857714630_item	2408941	et	3	main
mugavad	doc_438857714630_item	2408943	et	3	main
vastas	doc_438857714630_item	2408945	et	4	main
tugitooli	doc_438857714630_item	2408946	et	4	main
väga	doc_438857714630_item	2408952	et	3	main
jüüres	doc_438857714630_item	2408964	et	4	main
televiisor	doc_438857714630_item	2408970	et	3	main
on	doc_438857714630_item	2408973	et	4	main
aknad	doc_438857714630_item	2408987	et	3	main
on	doc_438857714630_item	2409004	et	4	main
hubane	doc_438857714630_item	2409026	et	3	main
ja	doc_438857714630_item	2409035	et	3	main
ribikardinad	doc_438857714630_item	2409044	et	4	main
nõud	doc_438857714629_item	2408481	et	3	main
raamatud	doc_438857714629_item	2408482	et	4	main
lastemänguasjad	doc_438857714629_item	2408485	et	3	main
lahtikäiv	doc_438857714629_item	2408491	et	4	main
vasakul	doc_438857714629_item	2408494	et	4	main
on	doc_438857714629_item	2408495	et	4	main
uks	doc_438857714629_item	2408496	et	3	main
rõdule	doc_438857714629_item	2408497	et	3	main
põrandal	doc_438857714629_item	2408499	et	3	main
päikesepoolne	doc_438857714629_item	2408508	et	3	main
magamistuba	doc_438857714629_item	2408509	et	4	main
ukse	doc_438857714629_item	2408514	et	3	main
seinal	doc_438857714629_item	2408517	et	3	main
ripuvad	doc_438857714629_item	2408523	et	3	main
seina	doc_438857714629_item	2408527	et	4	main
juures	doc_438857714629_item	2408528	et	4	main
villanevaip	doc_438857714629_item	2408537	et	4	main
vastas	doc_438857714629_item	2408538	et	4	main
diivanilaual	doc_438857714629_item	2408542	et	4	main
on	doc_438857714629_item	2408546	et	4	main
vaip	doc_438857714629_item	2408548	et	3	main
kohal	doc_438857714629_item	2408551	et	4	main
riidekapp	doc_438857714629_item	2408573	et	3	main
uksest	doc_438857714629_item	2408575	et	4	main
väike	doc_438857714629_item	2408577	et	4	main
ja	doc_438857714629_item	2408583	et	3	main
sektsioonkapi	doc_438857714629_item	2408586	et	4	main
on	doc_438857714629_item	2408588	et	4	main
akna	doc_438857714629_item	2408607	et	3	main
ees	doc_438857714629_item	2408608	et	4	main
uksest	doc_438857714629_item	2408613	et	4	main
kõrval	doc_438857714629_item	2408619	et	4	main
köögikapp	doc_438857714629_item	2408623	et	3	main
sõel	doc_438857714629_item	2408633	et	3	main
valamu	doc_438857714629_item	2408634	et	4	main
on	doc_438857714629_item	2408636	et	4	main
gaasipliit	doc_438857714629_item	2408637	et	3	main
gaasipliidi	doc_438857714629_item	2408638	et	3	main
kohal	doc_438857714629_item	2408639	et	4	main
ripub	doc_438857714629_item	2408640	et	3	main
tõmbekapp	doc_438857714629_item	2408641	et	3	main
edasi	doc_438857714629_item	2408642	et	3	main
seisab	doc_438857714629_item	2408643	et	3	main
noad	doc_438857714629_item	2408647	et	3	main
ripub	doc_438857714629_item	2408653	et	3	main
teisel	doc_438857714629_item	2408654	et	4	main
seinakapp	doc_438857714629_item	2408655	et	3	main
seinakapis	doc_438857714629_item	2408656	et	3	main
uksest	doc_438857714629_item	2408667	et	4	main
seina	doc_438857714629_item	2408669	et	4	main
juures	doc_438857714629_item	2408670	et	4	main
seisab	doc_438857714629_item	2408671	et	3	main
suur	doc_438857714629_item	2408672	et	3	main
välisuksest	doc_438857714629_item	2408706	et	4	main
uks	doc_438857714629_item	2408707	et	3	main
riiulil	doc_438857714629_item	2408754	et	3	main
pesemisvahendid	doc_438857714629_item	2408756	et	3	main
ma	doc_438857714629_item	2408763	et	3	main
korteris	doc_438857714629_item	2408767	et	3	main
minu	doc_438857714630_item	2408769	et	3	main
elan	doc_438857714630_item	2408772	et	3	main
narvas	doc_438857714630_item	2408773	et	4	main
rõdu	doc_438857714630_item	2408807	et	4	main
valgusküllane	doc_438857714630_item	2408810	et	4	main
aga	doc_438857714630_item	2408812	et	3	main
hubane	doc_438857714630_item	2408813	et	3	main
ja	doc_438857714630_item	2408818	et	3	main
arvutitool	doc_438857714630_item	2408827	et	3	main
on	doc_438857714630_item	2408830	et	4	main
lilledega	doc_438857714630_item	2408831	et	4	main
ja	doc_438857714630_item	2408855	et	3	main
on	doc_438857714630_item	2408860	et	4	main
on	doc_438857714630_item	2408863	et	4	main
voodi	doc_438857714630_item	2408865	et	4	main
ilus	doc_438857714630_item	2408868	et	4	main
vastas	doc_438857714630_item	2408877	et	4	main
aken	doc_438857714630_item	2408878	et	3	main
on	doc_438857714630_item	2408913	et	4	main
on	doc_438857714630_item	2408919	et	4	main
diivanil	doc_438857714630_item	2408925	et	3	main
lilled	doc_438857714630_item	2408935	et	3	main
ja	doc_438857714629_item	2408484	et	3	main
magamistuba	doc_438857714629_item	2408506	et	4	main
on	doc_438857714629_item	2408507	et	4	main
valgusküllane	doc_438857714629_item	2408513	et	4	main
välisriided	doc_438857714629_item	2408524	et	3	main
laud	doc_438857714629_item	2408541	et	4	main
põrandal	doc_438857714629_item	2408545	et	3	main
roheline	doc_438857714629_item	2408547	et	4	main
teleri	doc_438857714629_item	2408550	et	3	main
ripuvad	doc_438857714629_item	2408552	et	3	main
pildid	doc_438857714629_item	2408553	et	3	main
akna	doc_438857714629_item	2408554	et	3	main
ees	doc_438857714629_item	2408555	et	4	main
hubane	doc_438857714629_item	2408567	et	3	main
uksest	doc_438857714629_item	2408568	et	4	main
vasakul	doc_438857714629_item	2408569	et	4	main
seisab	doc_438857714629_item	2408572	et	3	main
vastas	doc_438857714629_item	2408574	et	4	main
laualamp	doc_438857714629_item	2408592	et	3	main
kušett	doc_438857714629_item	2408598	et	2	main
taga	doc_438857714629_item	2408600	et	4	main
külgkärdinad	doc_438857714629_item	2408611	et	4	main
all	doc_438857714629_item	2408621	et	3	main
nagis	doc_438857714629_item	2408522	et	3	main
uksest	doc_438857714629_item	2408525	et	4	main
diivanvoodi	doc_438857714629_item	2408530	et	4	main
diivanvoodi	doc_438857714629_item	2408531	et	4	main
seisab	doc_438857714629_item	2408539	et	3	main
diivani	doc_438857714629_item	2408540	et	4	main
teler	doc_438857714629_item	2408544	et	3	main
on	doc_438857714629_item	2408556	et	4	main
ja	doc_438857714629_item	2408558	et	3	main
valge	doc_438857714629_item	2408559	et	4	main
tüllkardin	doc_438857714629_item	2408560	et	3	main
lastetuba	doc_438857714629_item	2408561	et	4	main
ka	doc_438857714629_item	2408562	et	3	main
näikesepoolne	doc_438857714629_item	2408563	et	4	main
avar	doc_438857714629_item	2408564	et	3	main
valgusküllane	doc_438857714629_item	2408565	et	4	main
ja	doc_438857714629_item	2408566	et	3	main
on	doc_438857714629_item	2408576	et	4	main
juures	doc_438857714629_item	2408571	et	4	main
paremal	doc_438857714629_item	2408594	et	4	main
juures	doc_438857714629_item	2408596	et	4	main
ja	doc_438857714629_item	2408610	et	3	main
köögis	doc_438857714629_item	2408612	et	3	main
on	doc_438857714629_item	2408622	et	4	main
riiv	doc_438857714629_item	2408632	et	3	main
köögikapp	doc_438857714629_item	2408645	et	3	main
potid	doc_438857714629_item	2408650	et	4	main
mikser	doc_438857714629_item	2408659	et	3	main
ja	doc_438857714629_item	2408661	et	3	main
köögikapil	doc_438857714629_item	2408663	et	3	main
elektrikann	doc_438857714629_item	2408666	et	3	main
elutuba	doc_438857714629_item	2408708	et	4	main
elutoa	doc_438857714629_item	2408709	et	3	main
riiul	doc_438857714629_item	2408713	et	4	main
seisab	doc_438857714629_item	2408715	et	3	main
kohal	doc_438857714629_item	2408718	et	4	main
ripub	doc_438857714629_item	2408719	et	3	main
ilus	doc_438857714629_item	2408720	et	4	main
valamu	doc_438857714629_item	2408624	et	4	main
kohal	doc_438857714629_item	2408625	et	4	main
seinakapp	doc_438857714629_item	2408626	et	3	main
seinakapis	doc_438857714629_item	2408627	et	3	main
kruusid	doc_438857714629_item	2408628	et	3	main
tassid	doc_438857714629_item	2408629	et	4	main
taldrukud	doc_438857714629_item	2408630	et	4	main
teisel	doc_438857714629_item	2408644	et	4	main
kahvlid	doc_438857714629_item	2408648	et	3	main
lusikad	doc_438857714629_item	2408649	et	3	main
kohal	doc_438857714629_item	2408652	et	4	main
paremal	doc_438857714629_item	2408668	et	4	main
söögilaud	doc_438857714629_item	2408673	et	4	main
ja	doc_438857714629_item	2408674	et	3	main
külgkardinad	doc_438857714629_item	2408679	et	4	main
köögipõrand	doc_438857714629_item	2408680	et	3	main
ja	doc_438857714629_item	2408681	et	3	main
esikupõrand	doc_438857714629_item	2408682	et	4	main
on	doc_438857714629_item	2408683	et	4	main
linoleumiga	doc_438857714629_item	2408685	et	3	main
kaetud	doc_438857714629_item	2408684	et	4	main
esik	doc_438857714629_item	2408686	et	3	main
on	doc_438857714629_item	2408687	et	4	main
suur	doc_438857714629_item	2408688	et	3	main
ja	doc_438857714629_item	2408689	et	3	main
avar	doc_438857714629_item	2408690	et	3	main
välisuksest	doc_438857714629_item	2408691	et	4	main
paremal	doc_438857714629_item	2408692	et	4	main
kaks	doc_438857714629_item	2408693	et	3	main
ukset	doc_438857714629_item	2408694	et	4	main
tualeti	doc_438857714629_item	2408695	et	3	main
ja	doc_438857714629_item	2408696	et	3	main
vannituppa	doc_438857714629_item	2408697	et	3	main
uste	doc_438857714629_item	2408698	et	3	main
vahel	doc_438857714629_item	2408699	et	4	main
seina	doc_438857714629_item	2408700	et	4	main
seisab	doc_438857714629_item	2408702	et	3	main
juures	doc_438857714629_item	2408701	et	4	main
väike	doc_438857714629_item	2408703	et	4	main
kõrval	doc_438857714629_item	2408711	et	4	main
nurgas	doc_438857714629_item	2408716	et	3	main
ümmargune	doc_438857714629_item	2408721	et	3	main
valisuksest	doc_438857714629_item	2408723	et	4	main
suur	doc_438857714629_item	2408726	et	3	main
seinakapid	doc_438857714629_item	2408729	et	3	main
ruumi	doc_438857714629_item	2408733	et	4	main
vann	doc_438857714629_item	2408737	et	3	main
seinad	doc_438857714629_item	2408740	et	3	main
vannitoaga	doc_438857714629_item	2408750	et	3	main
riiul	doc_438857714629_item	2408753	et	4	main
nuustikud	doc_438857714629_item	2408762	et	3	main
essee	doc_438857714630_item	2408768	et	4	main
peetri	doc_438857714630_item	2408775	et	3	main
ma	doc_438857714630_item	2408776	et	3	main
elan	doc_438857714630_item	2408777	et	3	main
viiekorruselises	doc_438857714630_item	2408778	et	4	main
paneelmajas	doc_438857714630_item	2408779	et	3	main
minu	doc_438857714630_item	2408780	et	3	main
korter	doc_438857714630_item	2408781	et	3	main
nari	doc_438857714630_item	2408817	et	4	main
peegel	doc_438857714629_item	2408722	et	3	main
on	doc_438857714629_item	2408725	et	4	main
kapp	doc_438857714629_item	2408727	et	3	main
ja	doc_438857714629_item	2408728	et	3	main
vannitoas	doc_438857714629_item	2408730	et	3	main
on	doc_438857714629_item	2408731	et	4	main
on	doc_438857714629_item	2408741	et	4	main
kaetud	doc_438857714629_item	2408742	et	4	main
kahhelkiviga	doc_438857714629_item	2408743	et	3	main
seinal	doc_438857714629_item	2408751	et	3	main
seep	doc_438857714629_item	2408757	et	4	main
hambapasta	doc_438857714629_item	2408758	et	4	main
šampoon	doc_438857714629_item	2408759	et	2	main
ma	doc_438857714630_item	2408771	et	3	main
tänaval	doc_438857714630_item	2408774	et	4	main
erastatud	doc_438857714630_item	2408782	et	4	main
korteris	doc_438857714630_item	2408783	et	3	main
elavad	doc_438857714630_item	2408784	et	4	main
mina	doc_438857714630_item	2408785	et	4	main
abikaasa	doc_438857714630_item	2408786	et	4	main
tütred	doc_438857714630_item	2408787	et	3	main
ja	doc_438857714630_item	2408788	et	3	main
koer	doc_438857714630_item	2408789	et	3	main
me	doc_438857714630_item	2408790	et	4	main
neljandal	doc_438857714630_item	2408792	et	3	main
korrusel	doc_438857714630_item	2408793	et	3	main
kolmetoalises	doc_438857714630_item	2408794	et	4	main
elame	doc_438857714630_item	2408791	et	3	main
korteris	doc_438857714630_item	2408795	et	3	main
meiel	doc_438857714630_item	2408796	et	4	main
korteris	doc_438857714630_item	2408797	et	3	main
siin	doc_438857714630_item	2408798	et	4	main
elutuba	doc_438857714630_item	2408799	et	4	main
magamistuba	doc_438857714630_item	2408800	et	4	main
lastetuba	doc_438857714630_item	2408801	et	4	main
vannituba	doc_438857714630_item	2408802	et	4	main
köök	doc_438857714630_item	2408803	et	3	main
esik	doc_438857714630_item	2408804	et	3	main
ja	doc_438857714630_item	2408805	et	3	main
suur	doc_438857714630_item	2408806	et	3	main
lastetuba	doc_438857714630_item	2408808	et	4	main
on	doc_438857714630_item	2408809	et	4	main
ja	doc_438857714630_item	2408811	et	3	main
on	doc_438857714630_item	2408816	et	4	main
lastesektsioon	doc_438857714630_item	2408820	et	3	main
seisab	doc_438857714630_item	2408822	et	3	main
on	doc_438857714630_item	2408834	et	4	main
kaks	doc_438857714630_item	2408835	et	3	main
ja	doc_438857714630_item	2408837	et	3	main
sinine	doc_438857714630_item	2408838	et	4	main
kell	doc_438857714630_item	2408839	et	3	main
siin	doc_438857714630_item	2408840	et	4	main
vaip	doc_438857714630_item	2408857	et	3	main
roosidega	doc_438857714630_item	2408858	et	4	main
päikesepoolne	doc_438857714630_item	2408861	et	3	main
magamistoas	doc_438857714630_item	2408862	et	3	main
on	doc_438857714630_item	2408867	et	4	main
voogiga	doc_438857714630_item	2408871	et	4	main
on	doc_438857714630_item	2408872	et	4	main
kummit	doc_438857714630_item	2408873	et	3	main
riidekapp	doc_438857714630_item	2408880	et	3	main
ja	doc_438857714630_item	2408915	et	3	main
vastas	doc_438857714630_item	2408917	et	4	main
nahkdiivan	doc_438857714630_item	2408921	et	3	main
maalid	doc_438857714630_item	2408924	et	4	main
seisab	doc_438857714630_item	2408926	et	3	main
vassis	doc_438857714630_item	2408933	et	3	main
tugitoolid	doc_438857714630_item	2408944	et	3	main
on	doc_438857714630_item	2408947	et	4	main
sektsioonil	doc_438857714630_item	2408955	et	3	main
aken	doc_438857714630_item	2408965	et	3	main
akna	doc_438857714630_item	2408971	et	3	main
vaip	doc_438857714630_item	2408980	et	3	main
akna	doc_438857714630_item	2408988	et	3	main
ribikardinad	doc_438857714630_item	2408991	et	4	main
vasakul	doc_438857714630_item	2408999	et	4	main
kõrval	doc_438857714630_item	2408824	et	4	main
kardinad	doc_438857714630_item	2408832	et	4	main
seinal	doc_438857714630_item	2408833	et	3	main
pilti	doc_438857714630_item	2408836	et	4	main
lilli	doc_438857714630_item	2408843	et	4	main
nende	doc_438857714630_item	2408844	et	4	main
eest	doc_438857714630_item	2408845	et	4	main
ilus	doc_438857714630_item	2408856	et	4	main
magamistuba	doc_438857714630_item	2408859	et	4	main
voodile	doc_438857714630_item	2408866	et	3	main
voodikate	doc_438857714630_item	2408869	et	3	main
kõrval	doc_438857714630_item	2408881	et	4	main
kapiga	doc_438857714630_item	2408882	et	3	main
seinal	doc_438857714630_item	2408883	et	3	main
ripuvad	doc_438857714630_item	2408884	et	3	main
vanaegkell	doc_438857714630_item	2408885	et	4	main
jüüres	doc_438857714630_item	2408887	et	4	main
nurgas	doc_438857714630_item	2408886	et	3	main
kapi	doc_438857714630_item	2408888	et	4	main
on	doc_438857714630_item	2408889	et	4	main
suur	doc_438857714630_item	2408890	et	3	main
lill	doc_438857714630_item	2408891	et	3	main
vastas	doc_438857714630_item	2408892	et	4	main
voodi	doc_438857714630_item	2408893	et	4	main
seinal	doc_438857714630_item	2408894	et	3	main
on	doc_438857714630_item	2408895	et	4	main
teler	doc_438857714630_item	2408896	et	3	main
toas	doc_438857714630_item	2408897	et	3	main
on	doc_438857714630_item	2408898	et	4	main
tapeet	doc_438857714630_item	2408899	et	3	main
lilline	doc_438857714630_item	2408900	et	4	main
akna	doc_438857714630_item	2408901	et	3	main
ees	doc_438857714630_item	2408902	et	4	main
on	doc_438857714630_item	2408903	et	4	main
kreemiga	doc_438857714630_item	2408904	et	4	main
kardinad	doc_438857714630_item	2408905	et	4	main
kristalllühter	doc_438857714630_item	2408906	et	3	main
laes	doc_438857714630_item	2408907	et	4	main
on	doc_438857714630_item	2408909	et	4	main
põrandal	doc_438857714630_item	2408908	et	3	main
valge	doc_438857714630_item	2408910	et	4	main
vaip	doc_438857714630_item	2408911	et	3	main
elutuba	doc_438857714630_item	2408912	et	4	main
suur	doc_438857714630_item	2408920	et	3	main
seinal	doc_438857714630_item	2408922	et	3	main
diivanilaud	doc_438857714630_item	2408927	et	4	main
on	doc_438857714630_item	2408934	et	4	main
diivaniga	doc_438857714630_item	2408937	et	3	main
seisab	doc_438857714630_item	2408939	et	3	main
väike	doc_438857714630_item	2408948	et	4	main
raamatusektsioon	doc_438857714630_item	2408949	et	3	main
raamatud	doc_438857714630_item	2408954	et	4	main
seinal	doc_438857714630_item	2408957	et	3	main
akvaarium	doc_438857714630_item	2408959	et	3	main
suur	doc_438857714630_item	2408969	et	3	main
ees	doc_438857714630_item	2408972	et	4	main
valge	doc_438857714630_item	2408974	et	4	main
kardinad	doc_438857714630_item	2408975	et	4	main
elutoa	doc_438857714630_item	2408976	et	3	main
põrandal	doc_438857714630_item	2408977	et	3	main
suur	doc_438857714630_item	2408986	et	3	main
on	doc_438857714630_item	2408990	et	4	main
põrand	doc_438857714630_item	2408992	et	3	main
on	doc_438857714630_item	2408993	et	4	main
seinal	doc_438857714630_item	2409000	et	3	main
seisab	doc_438857714630_item	2409001	et	3	main
kapp	doc_438857714630_item	2409002	et	3	main
kappis	doc_438857714630_item	2409003	et	3	main
söögituba	doc_438857714630_item	2409022	et	4	main
avar	doc_438857714630_item	2409024	et	3	main
nurgas	doc_438857714630_item	2409027	et	3	main
vastas	doc_438857714630_item	2409028	et	4	main
uksega	doc_438857714630_item	2409029	et	3	main
seisab	doc_438857714630_item	2409030	et	3	main
nurgdiivan	doc_438857714630_item	2409031	et	4	main
kõrval	doc_438857714630_item	2409032	et	4	main
nurgadiivaniga	doc_438857714630_item	2409033	et	3	main
söögilaud	doc_438857714630_item	2409034	et	4	main
teise	doc_438857714630_item	2409036	et	4	main
valge	doc_438857714630_item	2409040	et	4	main
aknalaual	doc_438857714630_item	2409045	et	3	main
on	doc_438857714630_item	2409049	et	4	main
linoleumiga	doc_438857714630_item	2409051	et	3	main
ripuvad	doc_438857714630_item	2409062	et	3	main
on	doc_438857714630_item	2409104	et	4	main
ning	doc_438857714630_item	2408931	et	3	main
ajalehed	doc_438857714630_item	2408932	et	3	main
kõrval	doc_438857714630_item	2408936	et	4	main
nurgas	doc_438857714630_item	2408938	et	3	main
põrandalamp	doc_438857714630_item	2408940	et	3	main
on	doc_438857714630_item	2408942	et	4	main
sektsioonis	doc_438857714630_item	2408950	et	3	main
on	doc_438857714630_item	2408951	et	4	main
on	doc_438857714630_item	2408961	et	4	main
ilus	doc_438857714630_item	2408963	et	4	main
televiisarilaud	doc_438857714630_item	2408967	et	4	main
on	doc_438857714630_item	2408978	et	4	main
beežikirju	doc_438857714630_item	2408979	et	2	main
meiel	doc_438857714630_item	2408981	et	4	main
suur	doc_438857714630_item	2408982	et	3	main
rõdu	doc_438857714630_item	2408983	et	4	main
rõdul	doc_438857714630_item	2408984	et	3	main
ees	doc_438857714630_item	2408989	et	4	main
kaetud	doc_438857714630_item	2408994	et	4	main
linoleumiga	doc_438857714630_item	2408995	et	3	main
rõdul	doc_438857714630_item	2408996	et	3	main
riiulid	doc_438857714630_item	2409005	et	3	main
kappis	doc_438857714630_item	2409006	et	3	main
ma	doc_438857714630_item	2409007	et	3	main
hoian	doc_438857714630_item	2409008	et	3	main
keedis	doc_438857714630_item	2409009	et	4	main
ja	doc_438857714630_item	2409010	et	3	main
kodukonservid	doc_438857714630_item	2409011	et	3	main
ning	doc_438857714630_item	2409012	et	3	main
marineeritudseenid	doc_438857714630_item	2409013	et	4	main
rõdul	doc_438857714630_item	2409014	et	3	main
on	doc_438857714630_item	2409015	et	4	main
väga	doc_438857714630_item	2409016	et	3	main
palju	doc_438857714630_item	2409017	et	4	main
lilled	doc_438857714630_item	2409018	et	3	main
söögituba	doc_438857714630_item	2409019	et	4	main
on	doc_438857714630_item	2409020	et	4	main
taburetid	doc_438857714630_item	2409037	et	3	main
akna	doc_438857714630_item	2409041	et	3	main
on	doc_438857714630_item	2409043	et	4	main
põrand	doc_438857714630_item	2409048	et	3	main
iga	doc_438857714630_item	2409052	et	4	main
hommikul	doc_438857714630_item	2409053	et	3	main
köögipõrandad	doc_438857714630_item	2409056	et	3	main
meiel	doc_438857714630_item	2409064	et	4	main
seisab	doc_438857714630_item	2409093	et	3	main
on	doc_438857714630_item	2409101	et	4	main
köögis	doc_438857714630_item	2409103	et	3	main
siin	doc_438857714630_item	2409117	et	4	main
on	doc_438857714630_item	2409123	et	4	main
sahtlised	doc_438857714630_item	2409127	et	4	main
sein	doc_438857714630_item	2409141	et	3	main
nurgas	doc_438857714630_item	2409151	et	3	main
pesumasin	doc_438857714630_item	2409181	et	3	main
pika	doc_438857714630_item	2409187	et	4	main
peegel	doc_438857714630_item	2409188	et	3	main
vannipõrand	doc_438857714630_item	2409189	et	3	main
on	doc_438857714630_item	2409195	et	4	main
wc	doc_438857714630_item	2409198	et	4	main
sein	doc_438857714630_item	2409204	et	3	main
pehme	doc_438857714630_item	2409212	et	4	main
seinakapis	doc_438857714630_item	2409220	et	3	main
wc	doc_438857714630_item	2409222	et	4	main
ja	doc_438857714630_item	2409230	et	3	main
tualetis	doc_438857714630_item	2409232	et	3	main
ma	doc_438857714630_item	2409238	et	3	main
palju	doc_438857714630_item	2408953	et	4	main
on	doc_438857714630_item	2408956	et	4	main
seisab	doc_438857714630_item	2408958	et	3	main
akvaarium	doc_438857714630_item	2408960	et	3	main
väga	doc_438857714630_item	2408962	et	3	main
seisab	doc_438857714630_item	2408966	et	3	main
ja	doc_438857714630_item	2408968	et	3	main
on	doc_438857714630_item	2408985	et	4	main
on	doc_438857714630_item	2408997	et	4	main
ripplaed	doc_438857714630_item	2408998	et	4	main
põhjapoolne	doc_438857714630_item	2409021	et	3	main
on	doc_438857714630_item	2409023	et	4	main
ja	doc_438857714630_item	2409025	et	3	main
on	doc_438857714630_item	2409039	et	4	main
toalilled	doc_438857714630_item	2409047	et	3	main
seinal	doc_438857714630_item	2409058	et	3	main
seisavad	doc_438857714630_item	2409059	et	3	main
köögikapid	doc_438857714630_item	2409060	et	3	main
seinikapid	doc_438857714630_item	2409063	et	4	main
on	doc_438857714630_item	2409065	et	4	main
on	doc_438857714630_item	2409096	et	4	main
valamu	doc_438857714630_item	2409099	et	4	main
juures	doc_438857714630_item	2409100	et	4	main
on	doc_438857714630_item	2409107	et	4	main
valgusküllane	doc_438857714630_item	2409108	et	4	main
on	doc_438857714630_item	2409114	et	4	main
kaetud	doc_438857714630_item	2409115	et	4	main
linoleumiga	doc_438857714630_item	2409116	et	3	main
riiulid	doc_438857714630_item	2409124	et	3	main
sahtlid	doc_438857714630_item	2409126	et	3	main
on	doc_438857714630_item	2409128	et	4	main
jalatsid	doc_438857714630_item	2409129	et	3	main
nagis	doc_438857714630_item	2409130	et	3	main
ripuvad	doc_438857714630_item	2409131	et	3	main
vallisriided	doc_438857714630_item	2409132	et	4	main
on	doc_438857714630_item	2409138	et	4	main
avar	doc_438857714630_item	2409139	et	3	main
vannitoa	doc_438857714630_item	2409140	et	3	main
kaetud	doc_438857714630_item	2409143	et	4	main
maast	doc_438857714630_item	2409145	et	3	main
käterätikud	doc_438857714630_item	2409147	et	3	main
vannitoas	doc_438857714630_item	2409149	et	3	main
nagis	doc_438857714630_item	2409150	et	3	main
riiulid	doc_438857714630_item	2409152	et	3	main
pesemisvahendid	doc_438857714630_item	2409154	et	3	main
seep	doc_438857714630_item	2409155	et	4	main
šampoon	doc_438857714630_item	2409156	et	2	main
on	doc_438857714630_item	2409190	et	4	main
on	doc_438857714630_item	2409205	et	4	main
kaetud	doc_438857714630_item	2409206	et	4	main
laeni	doc_438857714630_item	2409209	et	4	main
põrandal	doc_438857714630_item	2409210	et	3	main
on	doc_438857714630_item	2409211	et	4	main
on	doc_438857714630_item	2409215	et	4	main
seinakapis	doc_438857714630_item	2409217	et	3	main
riiulid	doc_438857714630_item	2409219	et	3	main
söögilaud	doc_438857714630_item	2409038	et	4	main
ees	doc_438857714630_item	2409042	et	4	main
seisavad	doc_438857714630_item	2409046	et	3	main
ja	doc_438857714630_item	2409061	et	3	main
elab	doc_438857714630_item	2409068	et	3	main
meie	doc_438857714630_item	2409069	et	4	main
koer	doc_438857714630_item	2409070	et	3	main
siin	doc_438857714630_item	2409071	et	4	main
on	doc_438857714630_item	2409072	et	4	main
gasipliit	doc_438857714630_item	2409073	et	4	main
kõrval	doc_438857714630_item	2409074	et	4	main
üksega	doc_438857714630_item	2409075	et	4	main
seisab	doc_438857714630_item	2409076	et	3	main
külmkapp	doc_438857714630_item	2409077	et	3	main
külmkapp	doc_438857714630_item	2409078	et	3	main
on	doc_438857714630_item	2409079	et	4	main
väga	doc_438857714630_item	2409080	et	3	main
pikk	doc_438857714630_item	2409081	et	4	main
külmkapil	doc_438857714630_item	2409082	et	3	main
seisab	doc_438857714630_item	2409083	et	3	main
vaike	doc_438857714630_item	2409084	et	3	main
televiisor	doc_438857714630_item	2409085	et	3	main
seinal	doc_438857714630_item	2409086	et	3	main
kõrval	doc_438857714630_item	2409087	et	4	main
üksega	doc_438857714630_item	2409088	et	4	main
ripuvad	doc_438857714630_item	2409089	et	3	main
käteratik	doc_438857714630_item	2409090	et	4	main
vasakul	doc_438857714630_item	2409091	et	4	main
nurgas	doc_438857714630_item	2409092	et	3	main
kaetud	doc_438857714630_item	2409050	et	4	main
pühin	doc_438857714630_item	2409054	et	3	main
harjaga	doc_438857714630_item	2409055	et	3	main
paremal	doc_438857714630_item	2409057	et	4	main
köögipuumööbel	doc_438857714630_item	2409066	et	3	main
söögitoas	doc_438857714630_item	2409067	et	3	main
valamus	doc_438857714630_item	2409095	et	3	main
kraani	doc_438857714630_item	2409097	et	4	main
köögis	doc_438857714630_item	2409098	et	3	main
esiks	doc_438857714630_item	2409109	et	4	main
on	doc_438857714630_item	2409110	et	4	main
on	doc_438857714630_item	2409118	et	4	main
väga	doc_438857714630_item	2409119	et	3	main
kapp	doc_438857714630_item	2409121	et	3	main
vannituba	doc_438857714630_item	2409137	et	4	main
kahhelkiviga	doc_438857714630_item	2409144	et	3	main
balsam	doc_438857714630_item	2409157	et	4	main
valamu	doc_438857714630_item	2409178	et	4	main
valge	doc_438857714630_item	2409183	et	4	main
värv	doc_438857714630_item	2409184	et	3	main
kaetud	doc_438857714630_item	2409191	et	4	main
wc	doc_438857714630_item	2409203	et	4	main
siin	doc_438857714630_item	2409214	et	4	main
wc	doc_438857714630_item	2409234	et	4	main
elan	doc_438857714630_item	2409239	et	3	main
on	doc_438857714630_item	2409244	et	4	main
mõnus	doc_438857714630_item	2409245	et	4	main
viru	doc_438857714631_item	2409252	et	4	main
tänav	doc_438857714631_item	2409261	et	4	main
asub	doc_438857714631_item	2409262	et	3	main
maja	doc_438857714631_item	2409269	et	4	main
maja	doc_438857714631_item	2409279	et	4	main
mitu	doc_438857714631_item	2409291	et	4	main
väikest	doc_438857714631_item	2409292	et	4	main
kauplust	doc_438857714631_item	2409293	et	4	main
elumajad	doc_438857714631_item	2409294	et	3	main
jääb	doc_438857714631_item	2409303	et	3	main
neste	doc_438857714631_item	2409305	et	4	main
üheksakorruselises	doc_438857714631_item	2409308	et	4	main
kivimajas	doc_438857714631_item	2409309	et	4	main
kahetoalises	doc_438857714631_item	2409312	et	4	main
pügišaht	doc_438857714631_item	2409322	et	2	main
külm	doc_438857714631_item	2409325	et	3	main
on	doc_438857714631_item	2409338	et	4	main
elutuba	doc_438857714631_item	2409352	et	4	main
elutuba	doc_438857714631_item	2409355	et	4	main
avar	doc_438857714631_item	2409357	et	3	main
suur	doc_438857714631_item	2409365	et	3	main
vaip	doc_438857714631_item	2409370	et	3	main
weel	doc_438857714631_item	2409376	et	4	main
seal	doc_438857714631_item	2409377	et	4	main
lamp	doc_438857714631_item	2409422	et	3	main
on	doc_438857714631_item	2409430	et	4	main
ja	doc_438857714631_item	2409433	et	3	main
ja	doc_438857714631_item	2409447	et	3	main
edasi	doc_438857714631_item	2409449	et	3	main
висит	doc_438857714631_item	2409454	et	2	main
keel	doc_438857714631_item	2409455	et	4	main
lilled	doc_438857714631_item	2409461	et	3	main
põpandal	doc_438857714631_item	2409462	et	4	main
valamu	doc_438857714631_item	2409471	et	4	main
ühes	doc_438857714631_item	2409480	et	4	main
toiduained	doc_438857714631_item	2409483	et	3	main
klaasid	doc_438857714631_item	2409490	et	4	main
potid	doc_438857714631_item	2409492	et	4	main
edasi	doc_438857714631_item	2409495	et	3	main
vannituba	doc_438857714631_item	2409522	et	4	main
käterätikud	doc_438857714631_item	2409530	et	3	main
tualett	doc_438857714631_item	2409534	et	3	main
vannituba	doc_438857714631_item	2409536	et	4	main
on	doc_438857714631_item	2409541	et	4	main
eesti	doc_438857714632_item	2409550	et	4	main
tänaval	doc_438857714632_item	2409568	et	4	main
ümbruses	doc_438857714632_item	2409576	et	3	main
kasvavad	doc_438857714632_item	2409580	et	4	main
hansapank	doc_438857714632_item	2409591	et	3	main
haigla	doc_438857714632_item	2409593	et	4	main
kõnnitee	doc_438857714632_item	2409600	et	4	main
ma	doc_438857714632_item	2409602	et	3	main
elan	doc_438857714632_item	2409603	et	3	main
viiekorruselises	doc_438857714632_item	2409604	et	4	main
metallvalamu	doc_438857714630_item	2409094	et	4	main
nõudepesuvahend	doc_438857714630_item	2409102	et	3	main
mõnus	doc_438857714630_item	2409105	et	4	main
esik	doc_438857714630_item	2409106	et	3	main
palju	doc_438857714630_item	2409111	et	4	main
peegli	doc_438857714630_item	2409112	et	3	main
esikpõrand	doc_438857714630_item	2409113	et	3	main
palju	doc_438857714630_item	2409120	et	4	main
ja	doc_438857714630_item	2409125	et	3	main
vastas	doc_438857714630_item	2409133	et	4	main
kapi	doc_438857714630_item	2409134	et	4	main
ripuvad	doc_438857714630_item	2409135	et	3	main
pildid	doc_438857714630_item	2409136	et	3	main
on	doc_438857714630_item	2409142	et	4	main
laeni	doc_438857714630_item	2409146	et	4	main
on	doc_438857714630_item	2409153	et	4	main
lastešampoon	doc_438857714630_item	2409158	et	2	main
mänguasjad	doc_438857714630_item	2409159	et	3	main
seisab	doc_438857714630_item	2409179	et	3	main
on	doc_438857714630_item	2409182	et	4	main
uksel	doc_438857714630_item	2409185	et	3	main
ripu	doc_438857714630_item	2409186	et	4	main
vannitoa	doc_438857714630_item	2409193	et	3	main
põrandal	doc_438857714630_item	2409194	et	3	main
ja	doc_438857714630_item	2409199	et	3	main
on	doc_438857714630_item	2409201	et	4	main
eraldi	doc_438857714630_item	2409202	et	4	main
kahhelkiviga	doc_438857714630_item	2409207	et	3	main
vaip	doc_438857714630_item	2409213	et	3	main
seinakapp	doc_438857714630_item	2409216	et	3	main
on	doc_438857714630_item	2409218	et	4	main
essee	doc_438857714631_item	2409246	et	4	main
ma	doc_438857714631_item	2409247	et	3	main
elan	doc_438857714631_item	2409248	et	3	main
eesti	doc_438857714631_item	2409249	et	4	main
vabariigis	doc_438857714631_item	2409250	et	3	main
ida	doc_438857714631_item	2409251	et	4	main
narva	doc_438857714631_item	2409254	et	4	main
ma	doc_438857714631_item	2409256	et	3	main
elan	doc_438857714631_item	2409257	et	3	main
liiva	doc_438857714631_item	2409258	et	4	main
tanavas	doc_438857714631_item	2409259	et	4	main
ta	doc_438857714631_item	2409264	et	4	main
on	doc_438857714631_item	2409265	et	4	main
puhas	doc_438857714631_item	2409266	et	3	main
erinevad	doc_438857714631_item	2409275	et	4	main
lähedal	doc_438857714631_item	2409285	et	4	main
gaarazid	doc_438857714631_item	2409288	et	4	main
juuksla	doc_438857714631_item	2409297	et	4	main
ma	doc_438857714631_item	2409306	et	3	main
elan	doc_438857714631_item	2409307	et	3	main
korrusel	doc_438857714631_item	2409311	et	3	main
ja	doc_438857714631_item	2409316	et	3	main
vannituba	doc_438857714631_item	2409330	et	4	main
eraldi	doc_438857714631_item	2409331	et	4	main
sisseköigus	doc_438857714631_item	2409332	et	4	main
on	doc_438857714631_item	2409333	et	4	main
puhas	doc_438857714631_item	2409340	et	3	main
korter	doc_438857714631_item	2409342	et	3	main
erastatud	doc_438857714631_item	2409343	et	4	main
meie	doc_438857714631_item	2409344	et	4	main
korter	doc_438857714631_item	2409345	et	3	main
tuba	doc_438857714631_item	2409351	et	4	main
on	doc_438857714631_item	2409356	et	4	main
valgusküllane	doc_438857714631_item	2409359	et	4	main
see	doc_438857714631_item	2409360	et	3	main
on	doc_438857714631_item	2409361	et	4	main
esik	doc_438857714631_item	2409362	et	3	main
ilus	doc_438857714631_item	2409369	et	4	main
palju	doc_438857714631_item	2409373	et	4	main
on	doc_438857714631_item	2409378	et	4	main
suur	doc_438857714631_item	2409379	et	3	main
peegel	doc_438857714631_item	2409380	et	3	main
seinal	doc_438857714631_item	2409381	et	3	main
keel	doc_438857714631_item	2409383	et	4	main
suur	doc_438857714631_item	2409421	et	3	main
komputer	doc_438857714631_item	2409431	et	4	main
vaas	doc_438857714631_item	2409432	et	3	main
vaasis	doc_438857714631_item	2409434	et	3	main
veel	doc_438857714631_item	2409436	et	4	main
vihikut	doc_438857714631_item	2409445	et	3	main
on	doc_438857714631_item	2409463	et	4	main
kapis	doc_438857714630_item	2409122	et	3	main
ripuvad	doc_438857714630_item	2409148	et	3	main
ja	doc_438857714630_item	2409160	et	3	main
nuustikud	doc_438857714630_item	2409161	et	3	main
valamu	doc_438857714630_item	2409162	et	4	main
ääres	doc_438857714630_item	2409163	et	4	main
seisab	doc_438857714630_item	2409164	et	3	main
pesukorv	doc_438857714630_item	2409165	et	3	main
pesukorvis	doc_438857714630_item	2409166	et	3	main
on	doc_438857714630_item	2409167	et	4	main
must	doc_438857714630_item	2409168	et	4	main
pesu	doc_438857714630_item	2409169	et	4	main
kohal	doc_438857714630_item	2409170	et	4	main
valamu	doc_438857714630_item	2409171	et	4	main
ripuvad	doc_438857714630_item	2409172	et	3	main
pesemisvahendid	doc_438857714630_item	2409173	et	3	main
veedelseep	doc_438857714630_item	2409174	et	4	main
hambapasta	doc_438857714630_item	2409175	et	4	main
hambaharjad	doc_438857714630_item	2409176	et	3	main
vastas	doc_438857714630_item	2409177	et	4	main
pesumasin	doc_438857714630_item	2409180	et	3	main
kahelkiviga	doc_438857714630_item	2409192	et	4	main
pehme	doc_438857714630_item	2409196	et	4	main
vaip	doc_438857714630_item	2409197	et	3	main
vannituba	doc_438857714630_item	2409200	et	4	main
maast	doc_438857714630_item	2409208	et	3	main
on	doc_438857714630_item	2409221	et	4	main
paber	doc_438857714630_item	2409223	et	3	main
lastepott	doc_438857714630_item	2409237	et	3	main
kõigi	doc_438857714630_item	2409240	et	4	main
meie	doc_438857714631_item	2409260	et	4	main
lai	doc_438857714631_item	2409267	et	3	main
puud	doc_438857714631_item	2409276	et	4	main
hoovis	doc_438857714631_item	2409280	et	4	main
mänguväljak	doc_438857714631_item	2409282	et	3	main
meie	doc_438857714631_item	2409283	et	4	main
maja	doc_438857714631_item	2409284	et	4	main
leivakombinat	doc_438857714631_item	2409287	et	4	main
tempo	doc_438857714631_item	2409290	et	4	main
sõidutee	doc_438857714631_item	2409296	et	4	main
karina	doc_438857714631_item	2409299	et	3	main
natuke	doc_438857714631_item	2409301	et	4	main
on	doc_438857714631_item	2409314	et	4	main
kõge	doc_438857714631_item	2409317	et	4	main
mugavustega	doc_438857714631_item	2409318	et	4	main
lift	doc_438857714631_item	2409319	et	3	main
ja	doc_438857714631_item	2409329	et	3	main
trepikoda	doc_438857714631_item	2409337	et	4	main
alati	doc_438857714631_item	2409339	et	4	main
lastetuba	doc_438857714631_item	2409354	et	4	main
ja	doc_438857714631_item	2409358	et	3	main
on	doc_438857714631_item	2409368	et	4	main
on	doc_438857714631_item	2409424	et	4	main
lastetoas	doc_438857714631_item	2409426	et	3	main
toal	doc_438857714631_item	2409429	et	3	main
lilled	doc_438857714631_item	2409435	et	3	main
on	doc_438857714631_item	2409437	et	4	main
on	doc_438857714631_item	2409443	et	4	main
kooliraamat	doc_438857714631_item	2409444	et	3	main
on	doc_438857714631_item	2409451	et	4	main
laelamp	doc_438857714631_item	2409452	et	3	main
seinal	doc_438857714631_item	2409453	et	3	main
on	doc_438857714631_item	2409460	et	4	main
köögikapid	doc_438857714631_item	2409472	et	3	main
radio	doc_438857714631_item	2409478	et	4	main
külmkapp	doc_438857714631_item	2409479	et	3	main
on	doc_438857714631_item	2409482	et	4	main
teises	doc_438857714631_item	2409484	et	4	main
ja	doc_438857714631_item	2409493	et	3	main
on	doc_438857714631_item	2409497	et	4	main
leib	doc_438857714631_item	2409498	et	3	main
vaas	doc_438857714631_item	2409499	et	3	main
ja	doc_438857714631_item	2409500	et	3	main
vaasis	doc_438857714631_item	2409501	et	3	main
lilled	doc_438857714631_item	2409502	et	3	main
valamu	doc_438857714631_item	2409527	et	4	main
meie	doc_438857714631_item	2409539	et	4	main
minu	doc_438857714632_item	2409546	et	3	main
krenholmi	doc_438857714632_item	2409563	et	4	main
õmbluses	doc_438857714632_item	2409564	et	3	main
puud	doc_438857714632_item	2409582	et	4	main
kool	doc_438857714632_item	2409589	et	4	main
apteek	doc_438857714632_item	2409594	et	3	main
kingaparandus	doc_438857714632_item	2409596	et	3	main
soe	doc_438857714632_item	2409612	et	4	main
magamistuba	doc_438857714632_item	2409627	et	4	main
elutoas	doc_438857714632_item	2409628	et	3	main
on	doc_438857714632_item	2409673	et	4	main
pildid	doc_438857714632_item	2409674	et	3	main
valamu	doc_438857714632_item	2409678	et	4	main
mikser	doc_438857714632_item	2409684	et	3	main
ja	doc_438857714632_item	2409687	et	3	main
on	doc_438857714632_item	2409691	et	4	main
nõud	doc_438857714632_item	2409696	et	3	main
kannud	doc_438857714632_item	2409701	et	3	main
pann	doc_438857714632_item	2409718	et	3	main
pannil	doc_438857714632_item	2409720	et	3	main
käterätik	doc_438857714632_item	2409733	et	3	main
nagi	doc_438857714632_item	2409739	et	4	main
palitud	doc_438857714632_item	2409742	et	4	main
vann	doc_438857714632_item	2409752	et	3	main
hambaharjad	doc_438857714632_item	2409758	et	3	main
seep	doc_438857714630_item	2409224	et	4	main
hambapasta	doc_438857714630_item	2409225	et	4	main
šampoon	doc_438857714630_item	2409226	et	2	main
pesupulberid	doc_438857714630_item	2409227	et	3	main
paber	doc_438857714630_item	2409228	et	3	main
rätikud	doc_438857714630_item	2409229	et	3	main
iimanraikastaja	doc_438857714630_item	2409231	et	4	main
on	doc_438857714630_item	2409233	et	4	main
paber	doc_438857714630_item	2409235	et	3	main
ja	doc_438857714630_item	2409236	et	3	main
mugavustega	doc_438857714630_item	2409241	et	4	main
korteris	doc_438857714630_item	2409242	et	3	main
korteris	doc_438857714630_item	2409243	et	3	main
maakonnas	doc_438857714631_item	2409253	et	4	main
linnas	doc_438857714631_item	2409255	et	4	main
äärelinnas	doc_438857714631_item	2409263	et	4	main
ümbruses	doc_438857714631_item	2409270	et	3	main
on	doc_438857714631_item	2409271	et	4	main
kasvavad	doc_438857714631_item	2409274	et	4	main
põõsad	doc_438857714631_item	2409278	et	3	main
on	doc_438857714631_item	2409281	et	4	main
asuvad	doc_438857714631_item	2409286	et	4	main
kohvik	doc_438857714631_item	2409298	et	3	main
ja	doc_438857714631_item	2409300	et	3	main
eemale	doc_438857714631_item	2409302	et	3	main
bensiinijaam	doc_438857714631_item	2409304	et	3	main
keskkute	doc_438857714631_item	2409320	et	4	main
roheline	doc_438857714631_item	2409268	et	4	main
palju	doc_438857714631_item	2409272	et	4	main
rohelust	doc_438857714631_item	2409273	et	4	main
ja	doc_438857714631_item	2409277	et	3	main
kauplus	doc_438857714631_item	2409289	et	3	main
bussipeatus	doc_438857714631_item	2409295	et	4	main
teisel	doc_438857714631_item	2409310	et	4	main
ta	doc_438857714631_item	2409313	et	4	main
suur	doc_438857714631_item	2409315	et	3	main
rõdu	doc_438857714631_item	2409321	et	4	main
vesi	doc_438857714631_item	2409326	et	4	main
gaaz	doc_438857714631_item	2409327	et	4	main
esik	doc_438857714631_item	2409328	et	3	main
sadakaheksa	doc_438857714631_item	2409334	et	4	main
korterit	doc_438857714631_item	2409335	et	3	main
meie	doc_438857714631_item	2409336	et	4	main
on	doc_438857714631_item	2409346	et	4	main
suur	doc_438857714631_item	2409347	et	3	main
meil	doc_438857714631_item	2409348	et	4	main
on	doc_438857714631_item	2409349	et	4	main
kaks	doc_438857714631_item	2409350	et	3	main
seal	doc_438857714631_item	2409363	et	4	main
riidekappid	doc_438857714631_item	2409366	et	4	main
põrandal	doc_438857714631_item	2409367	et	3	main
lael	doc_438857714631_item	2409371	et	4	main
висит	doc_438857714631_item	2409382	et	2	main
see	doc_438857714631_item	2409423	et	3	main
on	doc_438857714631_item	2409427	et	4	main
tool	doc_438857714631_item	2409428	et	3	main
nii	doc_438857714631_item	2409448	et	3	main
lael	doc_438857714631_item	2409450	et	4	main
ja	doc_438857714631_item	2409456	et	3	main
palju	doc_438857714631_item	2409457	et	4	main
see	doc_438857714631_item	2409465	et	3	main
köök	doc_438857714631_item	2409467	et	3	main
on	doc_438857714631_item	2409469	et	4	main
tassid	doc_438857714631_item	2409489	et	4	main
kannud	doc_438857714631_item	2409491	et	3	main
pesumasin	doc_438857714631_item	2409528	et	3	main
hambaharjad	doc_438857714631_item	2409531	et	3	main
ja	doc_438857714631_item	2409535	et	3	main
on	doc_438857714631_item	2409537	et	4	main
eraldi	doc_438857714631_item	2409538	et	4	main
ja	doc_438857714631_item	2409543	et	3	main
mugav	doc_438857714631_item	2409544	et	3	main
seitse	doc_438857714632_item	2409571	et	3	main
rohelust	doc_438857714632_item	2409579	et	4	main
ja	doc_438857714632_item	2409583	et	3	main
asuvad	doc_438857714632_item	2409588	et	4	main
juuksla	doc_438857714632_item	2409595	et	4	main
toidu	doc_438857714632_item	2409597	et	3	main
bussipeatus	doc_438857714632_item	2409601	et	4	main
korrusel	doc_438857714632_item	2409607	et	3	main
meie	doc_438857714632_item	2409608	et	4	main
vesi	doc_438857714632_item	2409615	et	4	main
korter	doc_438857714632_item	2409617	et	3	main
ole	doc_438857714632_item	2409619	et	4	main
soe	doc_438857714631_item	2409323	et	4	main
ja	doc_438857714631_item	2409324	et	3	main
meie	doc_438857714631_item	2409341	et	4	main
ja	doc_438857714631_item	2409353	et	3	main
asub	doc_438857714631_item	2409364	et	3	main
on	doc_438857714631_item	2409372	et	4	main
väikesed	doc_438857714631_item	2409374	et	4	main
lampid	doc_438857714631_item	2409375	et	4	main
see	doc_438857714631_item	2409384	et	3	main
on	doc_438857714631_item	2409385	et	4	main
elutuba	doc_438857714631_item	2409386	et	4	main
elutoas	doc_438857714631_item	2409387	et	3	main
on	doc_438857714631_item	2409388	et	4	main
uus	doc_438857714631_item	2409389	et	3	main
mööbel	doc_438857714631_item	2409390	et	3	main
siin	doc_438857714631_item	2409391	et	4	main
on	doc_438857714631_item	2409392	et	4	main
diivan	doc_438857714631_item	2409393	et	3	main
kaks	doc_438857714631_item	2409394	et	3	main
tugitool	doc_438857714631_item	2409395	et	3	main
sektsioonkapp	doc_438857714631_item	2409396	et	4	main
sektsioonkappis	doc_438857714631_item	2409397	et	4	main
on	doc_438857714631_item	2409398	et	4	main
palju	doc_438857714631_item	2409399	et	4	main
ilusad	doc_438857714631_item	2409400	et	3	main
nõud	doc_438857714631_item	2409401	et	3	main
põrandal	doc_438857714631_item	2409402	et	3	main
on	doc_438857714631_item	2409403	et	4	main
ilus	doc_438857714631_item	2409404	et	4	main
vaip	doc_438857714631_item	2409405	et	3	main
veel	doc_438857714631_item	2409406	et	4	main
on	doc_438857714631_item	2409407	et	4	main
televiisor	doc_438857714631_item	2409408	et	3	main
dvd	doc_438857714631_item	2409409	et	4	main
radio	doc_438857714631_item	2409410	et	4	main
seinal	doc_438857714631_item	2409411	et	3	main
висит	doc_438857714631_item	2409412	et	2	main
suur	doc_438857714631_item	2409413	et	3	main
pilt	doc_438857714631_item	2409414	et	3	main
aknast	doc_438857714631_item	2409415	et	4	main
on	doc_438857714631_item	2409416	et	4	main
palju	doc_438857714631_item	2409417	et	4	main
lillid	doc_438857714631_item	2409418	et	3	main
lael	doc_438857714631_item	2409419	et	4	main
on	doc_438857714631_item	2409420	et	4	main
lastetuba	doc_438857714631_item	2409425	et	4	main
voodi	doc_438857714631_item	2409438	et	4	main
riidekapp	doc_438857714631_item	2409439	et	3	main
ja	doc_438857714631_item	2409440	et	3	main
kapp	doc_438857714631_item	2409441	et	3	main
kus	doc_438857714631_item	2409442	et	3	main
pliatsid	doc_438857714631_item	2409446	et	4	main
piltid	doc_438857714631_item	2409458	et	4	main
aknast	doc_438857714631_item	2409459	et	4	main
vaip	doc_438857714631_item	2409464	et	3	main
on	doc_438857714631_item	2409466	et	4	main
köögis	doc_438857714631_item	2409468	et	3	main
suur	doc_438857714631_item	2409473	et	3	main
taburetid	doc_438857714631_item	2409475	et	3	main
kapis	doc_438857714631_item	2409485	et	3	main
taldrikud	doc_438857714631_item	2409488	et	3	main
ja	doc_438857714631_item	2409503	et	3	main
limmonad	doc_438857714631_item	2409504	et	4	main
on	doc_438857714631_item	2409506	et	4	main
see	doc_438857714631_item	2409505	et	3	main
rõdu	doc_438857714631_item	2409507	et	4	main
seal	doc_438857714631_item	2409508	et	4	main
asub	doc_438857714631_item	2409509	et	3	main
palju	doc_438857714631_item	2409510	et	4	main
lilled	doc_438857714631_item	2409511	et	3	main
laul	doc_438857714631_item	2409512	et	4	main
ja	doc_438857714631_item	2409513	et	3	main
kaks	doc_438857714631_item	2409514	et	3	main
toolid	doc_438857714631_item	2409515	et	3	main
laual	doc_438857714631_item	2409516	et	3	main
on	doc_438857714631_item	2409517	et	4	main
ilus	doc_438857714631_item	2409518	et	4	main
lill	doc_438857714631_item	2409519	et	3	main
see	doc_438857714631_item	2409520	et	3	main
on	doc_438857714631_item	2409521	et	4	main
gaasipliit	doc_438857714631_item	2409470	et	3	main
lamid	doc_438857714631_item	2409474	et	4	main
väike	doc_438857714631_item	2409476	et	4	main
televisor	doc_438857714631_item	2409477	et	4	main
kapis	doc_438857714631_item	2409481	et	3	main
on	doc_438857714631_item	2409486	et	4	main
nõud	doc_438857714631_item	2409487	et	3	main
nii	doc_438857714631_item	2409494	et	3	main
laual	doc_438857714631_item	2409496	et	3	main
vannitoas	doc_438857714631_item	2409523	et	3	main
on	doc_438857714631_item	2409524	et	4	main
vann	doc_438857714631_item	2409525	et	3	main
peegel	doc_438857714631_item	2409526	et	3	main
hambapasta	doc_438857714631_item	2409533	et	4	main
korter	doc_438857714631_item	2409540	et	3	main
essee	doc_438857714632_item	2409545	et	4	main
kodu	doc_438857714632_item	2409547	et	4	main
ma	doc_438857714632_item	2409548	et	3	main
elan	doc_438857714632_item	2409549	et	3	main
äärelinnas	doc_438857714632_item	2409560	et	4	main
ma	doc_438857714632_item	2409565	et	3	main
pikal	doc_438857714632_item	2409567	et	4	main
majas	doc_438857714632_item	2409569	et	3	main
number	doc_438857714632_item	2409570	et	3	main
korteris	doc_438857714632_item	2409572	et	3	main
viisteistkümmnes	doc_438857714632_item	2409574	et	4	main
on	doc_438857714632_item	2409577	et	4	main
palju	doc_438857714632_item	2409578	et	4	main
erinevad	doc_438857714632_item	2409581	et	4	main
meie	doc_438857714632_item	2409585	et	4	main
lasteaed	doc_438857714632_item	2409590	et	3	main
turg	doc_438857714632_item	2409592	et	3	main
sõidutee	doc_438857714632_item	2409599	et	4	main
majas	doc_438857714632_item	2409609	et	3	main
külm	doc_438857714632_item	2409614	et	3	main
suur	doc_438857714632_item	2409621	et	3	main
on	doc_438857714632_item	2409623	et	4	main
tuba	doc_438857714632_item	2409625	et	4	main
elutuba	doc_438857714632_item	2409626	et	4	main
diivan	doc_438857714632_item	2409634	et	3	main
voodi	doc_438857714632_item	2409658	et	4	main
öökappi	doc_438857714632_item	2409663	et	4	main
riidekapis	doc_438857714632_item	2409664	et	3	main
on	doc_438857714632_item	2409665	et	4	main
seinal	doc_438857714632_item	2409672	et	3	main
köögikapid	doc_438857714632_item	2409680	et	3	main
laud	doc_438857714632_item	2409686	et	4	main
kapis	doc_438857714632_item	2409690	et	3	main
toiduained	doc_438857714632_item	2409692	et	3	main
teises	doc_438857714632_item	2409693	et	4	main
kapis	doc_438857714632_item	2409703	et	3	main
pott	doc_438857714632_item	2409709	et	3	main
ja	doc_438857714632_item	2409719	et	3	main
on	doc_438857714632_item	2409723	et	4	main
klaasid	doc_438857714632_item	2409724	et	4	main
ja	doc_438857714632_item	2409725	et	3	main
kann	doc_438857714632_item	2409726	et	3	main
kannus	doc_438857714632_item	2409727	et	4	main
on	doc_438857714632_item	2409728	et	4	main
valamu	doc_438857714632_item	2409730	et	4	main
nagis	doc_438857714632_item	2409740	et	3	main
mütsid	doc_438857714632_item	2409744	et	3	main
on	doc_438857714632_item	2409746	et	4	main
peegel	doc_438857714632_item	2409753	et	3	main
pesumasin	doc_438857714632_item	2409755	et	3	main
ja	doc_438857714632_item	2409759	et	3	main
ja	doc_438857714632_item	2409762	et	3	main
eraldi	doc_438857714632_item	2409765	et	4	main
poolest	doc_439979801331_item	2409790	et	4	main
prisma	doc_439979801331_item	2409799	et	4	main
elu	doc_439979801331_item	2409807	et	4	main
kui	doc_439979801331_item	2409818	et	3	main
iseseisev	doc_439979801331_item	2409819	et	3	main
seebid	doc_438857714631_item	2409529	et	3	main
ja	doc_438857714631_item	2409532	et	3	main
ilus	doc_438857714631_item	2409542	et	4	main
vabariigis	doc_438857714632_item	2409551	et	3	main
ida	doc_438857714632_item	2409552	et	4	main
viru	doc_438857714632_item	2409553	et	4	main
maakonnas	doc_438857714632_item	2409554	et	4	main
narva	doc_438857714632_item	2409555	et	4	main
linnas	doc_438857714632_item	2409556	et	4	main
minu	doc_438857714632_item	2409557	et	3	main
töökoht	doc_438857714632_item	2409558	et	3	main
asub	doc_438857714632_item	2409559	et	3	main
ma	doc_438857714632_item	2409561	et	3	main
töötan	doc_438857714632_item	2409562	et	3	main
elan	doc_438857714632_item	2409566	et	3	main
number	doc_438857714632_item	2409573	et	3	main
maja	doc_438857714632_item	2409575	et	4	main
põõsad	doc_438857714632_item	2409584	et	3	main
maja	doc_438857714632_item	2409586	et	4	main
lähedal	doc_438857714632_item	2409587	et	4	main
kauplused	doc_438857714632_item	2409598	et	3	main
on	doc_438857714632_item	2409610	et	4	main
meie	doc_438857714632_item	2409616	et	4	main
meil	doc_438857714632_item	2409622	et	4	main
kaks	doc_438857714632_item	2409624	et	3	main
on	doc_438857714632_item	2409629	et	4	main
uus	doc_438857714632_item	2409630	et	3	main
mööbel	doc_438857714632_item	2409631	et	3	main
siin	doc_438857714632_item	2409632	et	4	main
on	doc_438857714632_item	2409633	et	4	main
sektsioonkapp	doc_438857714632_item	2409637	et	4	main
raamatlaud	doc_438857714632_item	2409639	et	4	main
on	doc_438857714632_item	2409643	et	4	main
raamatud	doc_438857714632_item	2409653	et	4	main
ja	doc_438857714632_item	2409654	et	3	main
magamistoas	doc_438857714632_item	2409656	et	3	main
pesu	doc_438857714632_item	2409666	et	4	main
ja	doc_438857714632_item	2409667	et	3	main
riided	doc_438857714632_item	2409668	et	3	main
magamistoas	doc_438857714632_item	2409669	et	3	main
on	doc_438857714632_item	2409670	et	4	main
on	doc_438857714632_item	2409676	et	4	main
kohvimasin	doc_438857714632_item	2409681	et	3	main
mikrolaineahi	doc_438857714632_item	2409683	et	3	main
kapis	doc_438857714632_item	2409694	et	3	main
klaasid	doc_438857714632_item	2409699	et	4	main
kolmandas	doc_438857714632_item	2409702	et	3	main
potid	doc_438857714632_item	2409705	et	4	main
veel	doc_438857714632_item	2409717	et	4	main
majas	doc_438857714632_item	2409605	et	3	main
viiendal	doc_438857714632_item	2409606	et	3	main
keskküte	doc_438857714632_item	2409611	et	3	main
ja	doc_438857714632_item	2409613	et	3	main
ei	doc_438857714632_item	2409618	et	4	main
väga	doc_438857714632_item	2409620	et	3	main
tugitooli	doc_438857714632_item	2409636	et	4	main
televiisor	doc_438857714632_item	2409638	et	3	main
videomagnetofon	doc_438857714632_item	2409640	et	3	main
muusikakeskus	doc_438857714632_item	2409641	et	3	main
seinal	doc_438857714632_item	2409642	et	3	main
pildid	doc_438857714632_item	2409644	et	3	main
laual	doc_438857714632_item	2409645	et	3	main
on	doc_438857714632_item	2409652	et	4	main
riidekapp	doc_438857714632_item	2409659	et	3	main
kaks	doc_438857714632_item	2409662	et	3	main
seinalamp	doc_438857714632_item	2409671	et	3	main
köögis	doc_438857714632_item	2409675	et	3	main
gaasipliit	doc_438857714632_item	2409677	et	3	main
köögikombain	doc_438857714632_item	2409682	et	3	main
hakklihamasin	doc_438857714632_item	2409685	et	3	main
taldrikud	doc_438857714632_item	2409697	et	3	main
tassid	doc_438857714632_item	2409698	et	4	main
ja	doc_438857714632_item	2409700	et	3	main
on	doc_438857714632_item	2409704	et	4	main
ja	doc_438857714632_item	2409706	et	3	main
pannid	doc_438857714632_item	2409707	et	3	main
on	doc_438857714632_item	2409710	et	4	main
pliidil	doc_438857714632_item	2409711	et	3	main
potis	doc_438857714632_item	2409712	et	4	main
on	doc_438857714632_item	2409713	et	4	main
supp	doc_438857714632_item	2409714	et	3	main
pliidil	doc_438857714632_item	2409715	et	3	main
on	doc_438857714632_item	2409716	et	4	main
liha	doc_438857714632_item	2409721	et	4	main
juures	doc_438857714632_item	2409731	et	4	main
ripub	doc_438857714632_item	2409732	et	3	main
on	doc_438857714632_item	2409735	et	4	main
peegel	doc_438857714632_item	2409737	et	3	main
ripuvad	doc_438857714632_item	2409741	et	3	main
käterätikud	doc_438857714632_item	2409757	et	3	main
alates	doc_439979801331_item	2409786	et	3	main
aastate	doc_439979801331_item	2409788	et	3	main
pea	doc_439979801331_item	2409800	et	4	main
probleem	doc_439979801331_item	2409801	et	3	main
ja	doc_439979801331_item	2409805	et	3	main
areng	doc_439979801331_item	2409808	et	3	main
käigus	doc_439979801331_item	2409815	et	4	main
kadus	doc_439979801331_item	2409816	et	3	main
ideest	doc_439979801331_item	2409837	et	4	main
samal	doc_439979801331_item	2409838	et	3	main
uus	doc_439979801331_item	2409841	et	3	main
asus	doc_439979801331_item	2409843	et	4	main
elu	doc_439979801331_item	2409852	et	4	main
1940	doc_439979801331_item	2409853	et	2	main
see	doc_439979801331_item	2409856	et	3	main
see	doc_439979801331_item	2409860	et	3	main
maal	doc_439979801331_item	2409870	et	4	main
tegevuse	doc_439979801331_item	2409881	et	4	main
vaesema	doc_439979801331_item	2409882	et	4	main
rahvagruppi	doc_439979801331_item	2409883	et	4	main
huvidele	doc_439979801331_item	2409884	et	3	main
tehti	doc_439979801331_item	2409885	et	3	main
tasuta	doc_439979801331_item	2409889	et	4	main
ja	doc_439979801331_item	2409900	et	3	main
ajalooline	doc_439979801331_item	2409901	et	4	main
kattuvad	doc_439979801331_item	2409903	et	4	main
idee	doc_439979801331_item	2409922	et	4	main
tootmine	doc_439979801331_item	2409924	et	4	main
ja	doc_439979801331_item	2409925	et	3	main
inimeste	doc_439979801331_item	2409926	et	3	main
heaolu	doc_439979801331_item	2409927	et	4	main
tuli	doc_439979801331_item	2409929	et	4	main
korraldada	doc_439979801331_item	2409930	et	3	main
loenguid	doc_439979801331_item	2409931	et	4	main
vestlusi	doc_439979801331_item	2409932	et	3	main
õppusi	doc_439979801331_item	2409933	et	3	main
soovitada	doc_439979801331_item	2409934	et	3	main
komsomoli-	doc_439979801331_item	2409942	et	4	main
ja	doc_439979801331_item	2409943	et	3	main
parteiorganisatsioonidesse	doc_439979801331_item	2409944	et	3	main
kaks	doc_438857714632_item	2409635	et	3	main
on	doc_438857714632_item	2409646	et	4	main
vaas	doc_438857714632_item	2409647	et	3	main
ja	doc_438857714632_item	2409648	et	3	main
vaasis	doc_438857714632_item	2409649	et	3	main
lilled	doc_438857714632_item	2409650	et	3	main
sektsioonkapis	doc_438857714632_item	2409651	et	4	main
nõud	doc_438857714632_item	2409655	et	3	main
on	doc_438857714632_item	2409657	et	4	main
peegel	doc_438857714632_item	2409660	et	3	main
ja	doc_438857714632_item	2409661	et	3	main
külmkapp	doc_438857714632_item	2409679	et	3	main
taburetid	doc_438857714632_item	2409688	et	3	main
ühes	doc_438857714632_item	2409689	et	4	main
on	doc_438857714632_item	2409695	et	4	main
üks	doc_438857714632_item	2409708	et	3	main
laual	doc_438857714632_item	2409722	et	3	main
veesi	doc_438857714632_item	2409729	et	4	main
seinakapp	doc_438857714632_item	2409736	et	3	main
ja	doc_438857714632_item	2409743	et	3	main
esikus	doc_438857714632_item	2409745	et	3	main
veel	doc_438857714632_item	2409747	et	4	main
väike	doc_438857714632_item	2409748	et	4	main
seebid	doc_438857714632_item	2409756	et	3	main
läbi	doc_439979801331_item	2409797	et	4	main
ühiskondliku	doc_439979801331_item	2409798	et	3	main
rahva	doc_439979801331_item	2409806	et	3	main
kulges	doc_439979801331_item	2409809	et	3	main
eraldi	doc_439979801331_item	2409811	et	4	main
nii	doc_439979801331_item	2409812	et	3	main
teise	doc_439979801331_item	2409813	et	4	main
maailmasõja	doc_439979801331_item	2409814	et	3	main
oli	doc_439979801331_item	2409821	et	3	main
nii	doc_439979801331_item	2409824	et	3	main
rahvuslikul	doc_439979801331_item	2409828	et	3	main
rahvuseks	doc_439979801331_item	2409835	et	4	main
kasvamise	doc_439979801331_item	2409836	et	4	main
kui	doc_439979801331_item	2409840	et	3	main
on	doc_439979801331_item	2409850	et	4	main
näha	doc_439979801331_item	2409851	et	3	main
probleem	doc_439979801331_item	2409855	et	3	main
näitab	doc_439979801331_item	2409858	et	3	main
johannes	doc_439979801331_item	2409875	et	4	main
valitsus	doc_439979801331_item	2409877	et	4	main
esialgu	doc_439979801331_item	2409879	et	3	main
1949	doc_439979801331_item	2409894	et	2	main
aeg	doc_439979801331_item	2409896	et	3	main
rohkem	doc_439979801331_item	2409904	et	4	main
propaganda	doc_439979801331_item	2409909	et	4	main
hakkas	doc_439979801331_item	2409910	et	3	main
rahvale	doc_439979801331_item	2409928	et	3	main
kõige	doc_439979801331_item	2409939	et	4	main
peamine	doc_439979801331_item	2409940	et	3	main
oli	doc_439979801331_item	2409941	et	3	main
tahtsid	doc_439979801331_item	2409951	et	4	main
iseloomustas	doc_439979801331_item	2410012	et	3	main
rohkem	doc_439979801331_item	2410015	et	4	main
kohvipausist	doc_439979801331_item	2410022	et	3	main
ajal	doc_439979801331_item	2410025	et	4	main
rahvas	doc_439979801331_item	2410034	et	4	main
oli	doc_439979801331_item	2410035	et	3	main
teineteisst	doc_439979801331_item	2410036	et	4	main
antud	doc_439979801331_item	2410043	et	4	main
et	doc_439979801331_item	2410044	et	3	main
alustan	doc_439979801331_item	2410045	et	3	main
uuesti	doc_439979801331_item	2410046	et	3	main
1929a	doc_439979801331_item	2410047	et	4	main
pange	doc_441430986980_item	2410138	et	4	main
piret	doc_441430986980_item	2410144	et	4	main
kuulutust	doc_441430986980_item	2410155	et	4	main
et	doc_441430986980_item	2410156	et	3	main
pireti	doc_441430986980_item	2410183	et	4	main
kinnitusel	doc_441430986980_item	2410184	et	4	main
korriliku	doc_441430986980_item	2410203	et	4	main
seal	doc_441430986980_item	2410212	et	4	main
esikus	doc_438857714632_item	2409734	et	3	main
ja	doc_438857714632_item	2409738	et	3	main
riiul	doc_438857714632_item	2409749	et	4	main
vannitoas	doc_438857714632_item	2409750	et	3	main
on	doc_438857714632_item	2409751	et	4	main
valamu	doc_438857714632_item	2409754	et	4	main
tualett	doc_438857714632_item	2409761	et	3	main
meie	doc_438857714632_item	2409766	et	4	main
korter	doc_438857714632_item	2409767	et	3	main
on	doc_438857714632_item	2409768	et	4	main
ilus	doc_438857714632_item	2409769	et	4	main
ja	doc_438857714632_item	2409770	et	3	main
mugav	doc_438857714632_item	2409771	et	3	main
essee	doc_439979801331_item	2409772	et	4	main
voim	doc_439979801331_item	2409773	et	4	main
indiviid	doc_439979801331_item	2409774	et	3	main
ja	doc_439979801331_item	2409775	et	3	main
kohanemine	doc_439979801331_item	2409776	et	4	main
elulugudes	doc_439979801331_item	2409777	et	3	main
vanemad	doc_439979801331_item	2409778	et	4	main
eestlased	doc_439979801331_item	2409779	et	3	main
elust	doc_439979801331_item	2409780	et	3	main
nõukogude	doc_439979801331_item	2409781	et	3	main
eestis	doc_439979801331_item	2409782	et	3	main
elu	doc_439979801331_item	2409783	et	4	main
nõukogude	doc_439979801331_item	2409784	et	3	main
eestis	doc_439979801331_item	2409785	et	3	main
hambapasta	doc_438857714632_item	2409760	et	4	main
vannituba	doc_438857714632_item	2409763	et	4	main
on	doc_438857714632_item	2409764	et	4	main
1950	doc_439979801331_item	2409787	et	2	main
kirjeldavad	doc_439979801331_item	2409791	et	4	main
elulugudes	doc_439979801331_item	2409793	et	3	main
eestlased	doc_439979801331_item	2409795	et	3	main
oli	doc_439979801331_item	2409802	et	3	main
et	doc_439979801331_item	2409803	et	3	main
teineteist	doc_439979801331_item	2409810	et	4	main
muudatusi	doc_439979801331_item	2409823	et	3	main
kui	doc_439979801331_item	2409826	et	3	main
ka	doc_439979801331_item	2409827	et	3	main
väikeriigi	doc_439979801331_item	2409833	et	3	main
sest	doc_439979801331_item	2409861	et	4	main
11-st	doc_439979801331_item	2409864	et	3	main
ei	doc_439979801331_item	2409871	et	4	main
tääkohti	doc_439979801331_item	2409887	et	4	main
kehtestati	doc_439979801331_item	2409888	et	3	main
haridus	doc_439979801331_item	2409890	et	3	main
ja	doc_439979801331_item	2409891	et	3	main
on	doc_439979801331_item	2409906	et	4	main
komunismiehitajad	doc_439979801331_item	2409908	et	4	main
kasvatamise	doc_439979801331_item	2409921	et	4	main
oli	doc_439979801331_item	2409923	et	3	main
ajalehti	doc_439979801331_item	2409936	et	4	main
liikmete	doc_439979801331_item	2409946	et	3	main
aga	doc_439979801331_item	2409953	et	3	main
l	doc_439979801331_item	2409961	et	4	main
osanud	doc_439979801331_item	2409963	et	4	main
et	doc_439979801331_item	2409974	et	3	main
saanud	doc_439979801331_item	2409978	et	4	main
ameteid	doc_439979801331_item	2410011	et	3	main
alkoholi	doc_439979801331_item	2410016	et	4	main
pruukimine	doc_439979801331_item	2410017	et	4	main
paljud	doc_439979801331_item	2410018	et	3	main
nõukogude	doc_439979801331_item	2410024	et	3	main
korralikku	doc_439979801331_item	2410026	et	4	main
riigi	doc_439979801331_item	2410027	et	3	main
tööd	doc_439979801331_item	2410028	et	4	main
üldse	doc_439979801331_item	2410029	et	3	main
lahus	doc_439979801331_item	2410037	et	4	main
kahte	doc_439979801331_item	2410038	et	4	main
teisest	doc_439979801331_item	2409789	et	4	main
oma	doc_439979801331_item	2409792	et	4	main
vanemad	doc_439979801331_item	2409794	et	4	main
harva	doc_439979801331_item	2409796	et	4	main
riigi	doc_439979801331_item	2409804	et	3	main
eesti	doc_439979801331_item	2409817	et	4	main
riik	doc_439979801331_item	2409820	et	3	main
riiklikul	doc_439979801331_item	2409825	et	3	main
eestlased	doc_439979801331_item	2409830	et	3	main
loobuma	doc_439979801331_item	2409832	et	3	main
ühtseks	doc_439979801331_item	2409834	et	4	main
riigikord	doc_439979801331_item	2409842	et	3	main
juurutama	doc_439979801331_item	2409844	et	3	main
oma	doc_439979801331_item	2409845	et	4	main
artikkel	doc_439979801331_item	2409857	et	3	main
10	doc_439979801331_item	2409862	et	2	main
muutunud	doc_439979801331_item	2409872	et	4	main
suunas	doc_439979801331_item	2409878	et	4	main
oma	doc_439979801331_item	2409880	et	4	main
arstiabi	doc_439979801331_item	2409892	et	4	main
on	doc_439979801331_item	2409895	et	4	main
inividuaalne	doc_439979801331_item	2409898	et	4	main
tähelepanu	doc_439979801331_item	2409905	et	4	main
palju	doc_439979801331_item	2409822	et	4	main
pinnal	doc_439979801331_item	2409829	et	3	main
pidid	doc_439979801331_item	2409831	et	4	main
ajal	doc_439979801331_item	2409839	et	4	main
nõukogulikku	doc_439979801331_item	2409846	et	4	main
ideoloogiat	doc_439979801331_item	2409847	et	3	main
selles	doc_439979801331_item	2409848	et	4	main
artiklis	doc_439979801331_item	2409849	et	3	main
unustamise	doc_439979801331_item	2409854	et	4	main
hästi	doc_439979801331_item	2409859	et	3	main
informante	doc_439979801331_item	2409863	et	4	main
on	doc_439979801331_item	2409865	et	4	main
pärit	doc_439979801331_item	2409866	et	3	main
maalt	doc_439979801331_item	2409867	et	3	main
enne	doc_439979801331_item	2409868	et	4	main
1940	doc_439979801331_item	2409869	et	2	main
esialgu	doc_439979801331_item	2409873	et	3	main
midagi	doc_439979801331_item	2409874	et	4	main
vares-barbaruse	doc_439979801331_item	2409876	et	4	main
juurde	doc_439979801331_item	2409886	et	4	main
1939	doc_439979801331_item	2409893	et	2	main
kus	doc_439979801331_item	2409897	et	3	main
aeg	doc_439979801331_item	2409899	et	3	main
aeg	doc_439979801331_item	2409902	et	3	main
elusfäärile	doc_439979801331_item	2409907	et	3	main
1961	doc_439979801331_item	2409911	et	2	main
aastal	doc_439979801331_item	2409912	et	3	main
k-ehitaja	doc_439979801331_item	2409913	et	4	main
pidi	doc_439979801331_item	2409914	et	4	main
olema	doc_439979801331_item	2409915	et	4	main
korraliku	doc_439979801331_item	2409916	et	3	main
ideoloogiatöö	doc_439979801331_item	2409917	et	4	main
resultaat	doc_439979801331_item	2409918	et	3	main
nõukogude	doc_439979801331_item	2409919	et	3	main
inimeseks	doc_439979801331_item	2409920	et	3	main
ajakirju	doc_439979801331_item	2409937	et	4	main
raamatuid	doc_439979801331_item	2409938	et	3	main
mitte	doc_439979801331_item	2409954	et	3	main
võimalus	doc_439979801331_item	2409957	et	3	main
ei	doc_439979801331_item	2409962	et	4	main
kirjutada	doc_439979801331_item	2409964	et	3	main
toimetajat	doc_439979801331_item	2409976	et	4	main
lugemiseks	doc_439979801331_item	2409935	et	4	main
uute	doc_439979801331_item	2409945	et	3	main
aaluda	doc_439979801331_item	2409952	et	4	main
kõikidel	doc_439979801331_item	2409955	et	4	main
jääda	doc_439979801331_item	2409958	et	4	main
n	doc_439979801331_item	2409959	et	4	main
selge	doc_439979801331_item	2409973	et	4	main
ei	doc_439979801331_item	2409977	et	4	main
1949	doc_439979801331_item	2409979	et	2	main
inimesed	doc_439979801331_item	2409980	et	3	main
ei	doc_439979801331_item	2409981	et	4	main
olnud	doc_439979801331_item	2409982	et	4	main
nii	doc_439979801331_item	2409983	et	3	main
huvitatud	doc_439979801331_item	2409984	et	4	main
oma	doc_439979801331_item	2409985	et	4	main
arengus	doc_439979801331_item	2409986	et	3	main
vaid	doc_439979801331_item	2409987	et	3	main
peamine	doc_439979801331_item	2409988	et	3	main
oli	doc_439979801331_item	2409989	et	3	main
et	doc_439979801331_item	2409990	et	3	main
paber	doc_439979801331_item	2409991	et	3	main
klapiks	doc_439979801331_item	2409992	et	4	main
nõuetega	doc_439979801331_item	2409993	et	4	main
lõpetadi	doc_439979801331_item	2409994	et	4	main
talupidamine	doc_439979801331_item	2409995	et	3	main
kui	doc_439979801331_item	2409996	et	3	main
elustiil	doc_439979801331_item	2409997	et	4	main
kolhoosid	doc_439979801331_item	2409998	et	3	main
ei	doc_439979801331_item	2409999	et	4	main
pakkunud	doc_439979801331_item	2410000	et	4	main
talupojadele	doc_439979801331_item	2410001	et	3	main
rahuolu	doc_439979801331_item	2410002	et	4	main
oma	doc_439979801331_item	2410003	et	4	main
tööst	doc_439979801331_item	2410004	et	3	main
negatiivne	doc_439979801331_item	2410005	et	3	main
oli	doc_439979801331_item	2410006	et	3	main
ka	doc_439979801331_item	2410007	et	3	main
see	doc_439979801331_item	2410008	et	3	main
et	doc_439979801331_item	2410009	et	3	main
osa	doc_439979801331_item	2410010	et	4	main
juurde	doc_439979801331_item	2409947	et	4	main
võtmine	doc_439979801331_item	2409948	et	4	main
inimesed	doc_439979801331_item	2409949	et	3	main
ise	doc_439979801331_item	2409950	et	4	main
oli	doc_439979801331_item	2409956	et	3	main
olga	doc_439979801331_item	2409960	et	4	main
ajakirjanduslikus	doc_439979801331_item	2409965	et	4	main
mõttes	doc_439979801331_item	2409966	et	3	main
lobises	doc_439979801331_item	2409967	et	3	main
büroodel	doc_439979801331_item	2409968	et	3	main
parteikomitee	doc_439979801331_item	2409969	et	4	main
naistega	doc_439979801331_item	2409970	et	3	main
tühja	doc_439979801331_item	2409971	et	4	main
asju	doc_439979801331_item	2409972	et	3	main
temast	doc_439979801331_item	2409975	et	3	main
nõukogude	doc_439979801331_item	2410013	et	3	main
ei	doc_439979801331_item	2410030	et	4	main
elu	doc_439979801331_item	2410039	et	4	main
elada	doc_439979801331_item	2410042	et	3	main
eksamitöö	doc_441430986980_item	2410136	et	4	main
i	doc_441430986980_item	2410137	et	4	main
vormi	doc_441430986980_item	2410143	et	4	main
eesti	doc_441430986980_item	2410162	et	4	main
võitis	doc_441430986980_item	2410166	et	3	main
konkurss	doc_441430986980_item	2410167	et	3	main
ja	doc_441430986980_item	2410169	et	3	main
on	doc_441430986980_item	2410170	et	4	main
emakeelt	doc_441430986980_item	2410180	et	4	main
üllatunud	doc_441430986980_item	2410196	et	4	main
audiga	doc_441430986980_item	2410204	et	3	main
mulle	doc_441430986980_item	2410205	et	4	main
maaliti	doc_441430986980_item	2410206	et	3	main
lenda	doc_441430986980_item	2410215	et	4	main
ajal	doc_439979801331_item	2410014	et	4	main
täätajad	doc_439979801331_item	2410019	et	4	main
riigitööl	doc_439979801331_item	2410020	et	3	main
istusid	doc_439979801331_item	2410021	et	4	main
kohvipausini	doc_439979801331_item	2410023	et	3	main
ja	doc_439979801331_item	2410033	et	3	main
kuulutus	doc_441430986980_item	2410154	et	4	main
keele	doc_441430986980_item	2410163	et	4	main
konkurssi	doc_441430986980_item	2410168	et	4	main
nüüd	doc_441430986980_item	2410171	et	4	main
juba	doc_441430986980_item	2410172	et	3	main
üle	doc_441430986980_item	2410173	et	3	main
nädal	doc_441430986980_item	2410174	et	3	main
nädalat	doc_441430986980_item	2410175	et	3	main
väikestele	doc_441430986980_item	2410176	et	4	main
õpetama	doc_441430986980_item	2410181	et	3	main
tundis	doc_441430986980_item	2410185	et	3	main
siberisse	doc_441430986980_item	2410187	et	4	main
jõudma	doc_441430986980_item	2410188	et	3	main
jõudma	doc_441430986980_item	2410189	et	3	main
et	doc_441430986980_item	2410190	et	3	main
on	doc_441430986980_item	2410191	et	4	main
tulema	doc_441430986980_item	2410199	et	4	main
tuli	doc_441430986980_item	2410200	et	4	main
vastu	doc_441430986980_item	2410201	et	3	main
korralik	doc_441430986980_item	2410202	et	3	main
selline	doc_441430986980_item	2410209	et	4	main
pilt	doc_441430986980_item	2410210	et	3	main
et	doc_441430986980_item	2410211	et	3	main
lind	doc_441430986980_item	2410216	et	3	main
kui	doc_441430986980_item	2410220	et	3	main
ja	doc_441430986980_item	2410222	et	3	main
tahtmist	doc_441430986980_item	2410224	et	4	main
piret	doc_441430986980_item	2410226	et	4	main
küla	doc_441430986980_item	2410239	et	4	main
siinsed	doc_441430986980_item	2410262	et	3	main
kuidagi	doc_441430986980_item	2410265	et	3	main
mõnus	doc_441430986980_item	2410267	et	4	main
mõnusam	doc_441430986980_item	2410270	et	4	main
mahlakasem	doc_441430986980_item	2410272	et	4	main
mitte	doc_441430986980_item	2410273	et	3	main
mõni	doc_441430986980_item	2410279	et	3	main
venemaa	doc_441430986980_item	2410285	et	4	main
elab	doc_441430986980_item	2410295	et	3	main
emakeelt	doc_441430986980_item	2410302	et	4	main
õpivad	doc_441430986980_item	2410309	et	3	main
tooma	doc_441430986980_item	2410328	et	3	main
talvepuud	doc_441430986980_item	2410330	et	4	main
veel	doc_441430986980_item	2410334	et	4	main
suure	doc_441430986980_item	2410344	et	3	main
külapood	doc_441430986980_item	2410352	et	3	main
suurt	doc_441430986980_item	2410357	et	3	main
iii	doc_441430986980_item	2410370	et	4	main
sõnadest	doc_441430986980_item	2410373	et	3	main
õigesse	doc_441430986980_item	2410377	et	3	main
ja	doc_441430986980_item	2410379	et	3	main
tegema	doc_441430986980_item	2410384	et	3	main
ja	doc_441430986980_item	2410387	et	3	main
igaüks	doc_441430986980_item	2410399	et	3	main
paras	doc_441430986980_item	2410402	et	3	main
stress	doc_441430986980_item	2410404	et	3	main
meie	doc_441430986980_item	2410406	et	4	main
tooma	doc_441430986980_item	2410411	et	3	main
tagajärg	doc_441430986980_item	2410413	et	3	main
tehtud	doc_439979801331_item	2410031	et	4	main
riik	doc_439979801331_item	2410032	et	3	main
pole	doc_439979801331_item	2410040	et	3	main
kellelegi	doc_439979801331_item	2410041	et	4	main
toomet	doc_441430986980_item	2410145	et	4	main
siberisse	doc_441430986980_item	2410157	et	4	main
ülem-suetuki	doc_441430986980_item	2410158	et	4	main
õpetajat	doc_441430986980_item	2410164	et	4	main
eestlastele	doc_441430986980_item	2410177	et	4	main
need	doc_441430986980_item	2410178	et	3	main
õpetab	doc_441430986980_item	2410182	et	3	main
ta	doc_441430986980_item	2410186	et	4	main
kui	doc_441430986980_item	2410197	et	3	main
siber	doc_441430986980_item	2410207	et	4	main
siberi	doc_441430986980_item	2410208	et	4	main
kasva	doc_441430986980_item	2410218	et	4	main
veel	doc_441430986980_item	2410235	et	4	main
algama	doc_441430986980_item	2410236	et	3	main
alganud	doc_441430986980_item	2410237	et	4	main
kartuleid	doc_441430986980_item	2410242	et	3	main
on	doc_441430986980_item	2410244	et	4	main
sügisel	doc_441430986980_item	2410246	et	3	main
ja	doc_441430986980_item	2410256	et	3	main
õppimine	doc_441430986980_item	2410257	et	4	main
käib	doc_441430986980_item	2410258	et	3	main
täie	doc_441430986980_item	2410259	et	3	main
hoog	doc_441430986980_item	2410260	et	3	main
eestlased	doc_441430986980_item	2410263	et	3	main
teistmoodi	doc_441430986980_item	2410266	et	3	main
ja	doc_441430986980_item	2410268	et	3	main
aktsenti	doc_441430986980_item	2410276	et	4	main
keeles	doc_441430986980_item	2410293	et	4	main
külas	doc_441430986980_item	2410294	et	3	main
kõik	doc_441430986980_item	2410304	et	4	main
rääkida	doc_441430986980_item	2410306	et	3	main
poolpõlenud	doc_441430986980_item	2410311	et	4	main
saatma	doc_441430986980_item	2410315	et	3	main
eestist	doc_441430986980_item	2410317	et	3	main
siberi	doc_441430986980_item	2410320	et	4	main
tooti	doc_441430986980_item	2410329	et	4	main
kütmine	doc_441430986980_item	2410347	et	4	main
ostan	doc_441430986980_item	2410351	et	3	main
etteantud	doc_441430986980_item	2410372	et	4	main
laused	doc_441430986980_item	2410374	et	3	main
vormi	doc_441430986980_item	2410378	et	4	main
kirjavahemärke	doc_441430986980_item	2410381	et	4	main
naiselikum	doc_441430986980_item	2410386	et	4	main
mehelikum	doc_441430986980_item	2410389	et	4	main
igaüks	doc_441430986980_item	2410390	et	3	main
kaunim	doc_441430986980_item	2410391	et	4	main
ja	doc_441430986980_item	2410398	et	3	main
panema	doc_441430986980_item	2410405	et	3	main
tegutsema	doc_441430986980_item	2410407	et	3	main
aga	doc_441430986980_item	2410408	et	3	main
lisakoormus	doc_441430986980_item	2410409	et	3	main
soovimatu	doc_441430986980_item	2410412	et	4	main
tooda	doc_441430986980_item	2410421	et	4	main
tagajärgi	doc_441430986980_item	2410423	et	4	main
saama	doc_441430986980_item	2410431	et	4	main
ja	doc_441430986980_item	2410434	et	3	main
ei	doc_441430986980_item	2410436	et	4	main
olema	doc_441430986980_item	2410448	et	4	main
tänapäeval	doc_441430986980_item	2410464	et	3	main
sellel	doc_441430986980_item	2410469	et	4	main
söömine	doc_441430986980_item	2410487	et	4	main
huvitav	doc_441430986980_item	2410489	et	4	main
vaatamine	doc_441430986980_item	2410491	et	4	main
aeg	doc_441430986980_item	2410492	et	3	main
kuid	doc_441430986980_item	2410493	et	4	main
telefonihelin	doc_441430986980_item	2410494	et	3	main
katkestab	doc_441430986980_item	2410495	et	3	main
ka	doc_441430986980_item	2410496	et	3	main
pühapäeval	doc_441430986980_item	2410497	et	3	main
on	doc_441430986980_item	2410146	et	4	main
sulgudes	doc_441430986980_item	2410139	et	4	main
olevad	doc_441430986980_item	2410140	et	4	main
sõnad	doc_441430986980_item	2410141	et	4	main
õigesse	doc_441430986980_item	2410142	et	3	main
ettevõtlik	doc_441430986980_item	2410147	et	3	main
naine	doc_441430986980_item	2410148	et	3	main
suvel	doc_441430986980_item	2410149	et	3	main
nägema	doc_441430986980_item	2410150	et	3	main
nägis	doc_441430986980_item	2410151	et	4	main
ta	doc_441430986980_item	2410152	et	4	main
ajalehes	doc_441430986980_item	2410153	et	3	main
küla	doc_441430986980_item	2410159	et	4	main
külla	doc_441430986980_item	2410160	et	4	main
otsitakse	doc_441430986980_item	2410161	et	3	main
piret	doc_441430986980_item	2410165	et	4	main
nende	doc_441430986980_item	2410179	et	4	main
oodatud	doc_441430986980_item	2410192	et	4	main
olin	doc_441430986980_item	2410193	et	3	main
üsna	doc_441430986980_item	2410194	et	3	main
üllatuma	doc_441430986980_item	2410195	et	3	main
mulle	doc_441430986980_item	2410198	et	4	main
ei	doc_441430986980_item	2410213	et	4	main
lendama	doc_441430986980_item	2410214	et	3	main
algust	doc_441430986980_item	2410229	et	4	main
koht	doc_441430986980_item	2410230	et	3	main
kohta	doc_441430986980_item	2410231	et	4	main
jõudis	doc_441430986980_item	2410232	et	3	main
polnud	doc_441430986980_item	2410233	et	3	main
kool	doc_441430986980_item	2410234	et	4	main
võtma	doc_441430986980_item	2410240	et	3	main
hooga	doc_441430986980_item	2410261	et	3	main
räägivad	doc_441430986980_item	2410264	et	3	main
mahlakas	doc_441430986980_item	2410269	et	4	main
ja	doc_441430986980_item	2410271	et	3	main
nagu	doc_441430986980_item	2410278	et	3	main
murret	doc_441430986980_item	2410281	et	4	main
siiski	doc_441430986980_item	2410284	et	4	main
üle	doc_441430986980_item	2410297	et	3	main
inimest	doc_441430986980_item	2410301	et	3	main
sõnul	doc_441430986980_item	2410308	et	3	main
lapsed	doc_441430986980_item	2410310	et	3	main
varsti	doc_441430986980_item	2410314	et	3	main
õpikud	doc_441430986980_item	2410319	et	3	main
ega	doc_441430986980_item	2410217	et	3	main
rohi	doc_441430986980_item	2410219	et	4	main
noor	doc_441430986980_item	2410221	et	3	main
tahtmine	doc_441430986980_item	2410223	et	4	main
täis	doc_441430986980_item	2410225	et	4	main
kogu	doc_441430986980_item	2410238	et	4	main
kartulivõtt	doc_441430986980_item	2410243	et	3	main
siin	doc_441430986980_item	2410245	et	4	main
kõige	doc_441430986980_item	2410247	et	4	main
tähtis	doc_441430986980_item	2410248	et	4	main
salves	doc_441430986980_item	2410255	et	4	main
aktsent	doc_441430986980_item	2410275	et	3	main
vaid	doc_441430986980_item	2410277	et	3	main
kool	doc_441430986980_item	2410282	et	4	main
on	doc_441430986980_item	2410283	et	4	main
aine	doc_441430986980_item	2410289	et	4	main
ained	doc_441430986980_item	2410290	et	3	main
õpetatakse	doc_441430986980_item	2410291	et	3	main
vene	doc_441430986980_item	2410292	et	4	main
kolmsada	doc_441430986980_item	2410298	et	4	main
kolmesaja	doc_441430986980_item	2410299	et	4	main
kõikidega	doc_441430986980_item	2410305	et	4	main
raamatud	doc_441430986980_item	2410312	et	4	main
raamatutega	doc_441430986980_item	2410313	et	3	main
saadetakse	doc_441430986980_item	2410316	et	3	main
uued	doc_441430986980_item	2410318	et	3	main
mulle	doc_441430986980_item	2410326	et	4	main
juba	doc_441430986980_item	2410327	et	3	main
soe	doc_441430986980_item	2410335	et	4	main
kütmist	doc_441430986980_item	2410348	et	4	main
kui	doc_441430986980_item	2410349	et	3	main
muud	doc_441430986980_item	2410358	et	4	main
ei	doc_441430986980_item	2410359	et	4	main
moodustage	doc_441430986980_item	2410371	et	3	main
pannes	doc_441430986980_item	2410375	et	4	main
naeratus	doc_441430986980_item	2410383	et	4	main
naised	doc_441430986980_item	2410385	et	3	main
mehed	doc_441430986980_item	2410388	et	3	main
mehedmehelikumaks	doc_441430986980_item	2410397	et	4	main
3	doc_441430986980_item	2410401	et	2	main
kogus	doc_441430986980_item	2410403	et	4	main
võima	doc_441430986980_item	2410410	et	3	main
meid	doc_441430986980_item	2410416	et	4	main
aga	doc_441430986980_item	2410418	et	3	main
pärast	doc_441430986980_item	2410227	et	4	main
õppeaasta	doc_441430986980_item	2410228	et	4	main
võttis	doc_441430986980_item	2410241	et	3	main
tähtsaim	doc_441430986980_item	2410249	et	4	main
ettevõtmine	doc_441430986980_item	2410250	et	3	main
tänaseks	doc_441430986980_item	2410251	et	4	main
on	doc_441430986980_item	2410252	et	4	main
kartul	doc_441430986980_item	2410253	et	3	main
salv	doc_441430986980_item	2410254	et	3	main
vene	doc_441430986980_item	2410274	et	4	main
mõnet	doc_441430986980_item	2410280	et	4	main
kool	doc_441430986980_item	2410286	et	4	main
ja	doc_441430986980_item	2410287	et	3	main
ülejäänud	doc_441430986980_item	2410288	et	4	main
veidi	doc_441430986980_item	2410296	et	3	main
inimene	doc_441430986980_item	2410300	et	3	main
saab	doc_441430986980_item	2410303	et	3	main
pireti	doc_441430986980_item	2410307	et	4	main
talve	doc_441430986980_item	2410321	et	4	main
ei	doc_441430986980_item	2410323	et	4	main
kartma	doc_441430986980_item	2410324	et	3	main
karda	doc_441430986980_item	2410325	et	4	main
praegu	doc_441430986980_item	2410331	et	3	main
on	doc_441430986980_item	2410332	et	4	main
päevad	doc_441430986980_item	2410333	et	3	main
jahedad	doc_441430986980_item	2410341	et	3	main
juba	doc_441430986980_item	2410343	et	3	main
vaja	doc_441430986980_item	2410350	et	4	main
külapoodist	doc_441430986980_item	2410353	et	4	main
seal	doc_441430986980_item	2410356	et	4	main
slõhtuleht	doc_441430986980_item	2410369	et	4	main
kasutades	doc_441430986980_item	2410380	et	3	main
naeratus	doc_441430986980_item	2410392	et	4	main
teeb	doc_441430986980_item	2410393	et	3	main
naised	doc_441430986980_item	2410394	et	3	main
kaunimaks	doc_441430986980_item	2410400	et	4	main
paneb	doc_441430986980_item	2410415	et	3	main
laskma	doc_441430986980_item	2410427	et	3	main
ülekoormus	doc_441430986980_item	2410428	et	3	main
pinge	doc_441430986980_item	2410430	et	4	main
tekkides	doc_441430986980_item	2410440	et	4	main
telefon	doc_441430986980_item	2410447	et	3	main
nii	doc_441430986980_item	2410451	et	3	main
nii	doc_441430986980_item	2410465	et	3	main
lõunasöök	doc_441430986980_item	2410484	et	3	main
ja	doc_441430986980_item	2410503	et	3	main
1	doc_441430986980_item	2410517	et	2	main
piret	doc_441430986980_item	2410322	et	4	main
sojad	doc_441430986980_item	2410336	et	3	main
kuid	doc_441430986980_item	2410337	et	4	main
ööd	doc_441430986980_item	2410338	et	4	main
juba	doc_441430986980_item	2410339	et	3	main
jahe	doc_441430986980_item	2410340	et	3	main
harjutan	doc_441430986980_item	2410342	et	3	main
vene	doc_441430986980_item	2410345	et	4	main
ahju	doc_441430986980_item	2410346	et	4	main
vildid	doc_441430986980_item	2410354	et	4	main
ega	doc_441430986980_item	2410355	et	3	main
müüdagi	doc_441430986980_item	2410360	et	3	main
naerab	doc_441430986980_item	2410361	et	3	main
talveks	doc_441430986980_item	2410362	et	4	main
valmistuma	doc_441430986980_item	2410363	et	3	main
valmistutud	doc_441430986980_item	2410364	et	4	main
piret	doc_441430986980_item	2410365	et	4	main
vapralt	doc_441430986980_item	2410366	et	4	main
lühendatud	doc_441430986980_item	2410367	et	4	main
ajalehest	doc_441430986980_item	2410368	et	4	main
sõnad	doc_441430986980_item	2410376	et	4	main
2	doc_441430986980_item	2410382	et	2	main
naiselikumaks	doc_441430986980_item	2410395	et	4	main
ja	doc_441430986980_item	2410396	et	3	main
tegutsema	doc_441430986980_item	2410417	et	3	main
lisakoormus	doc_441430986980_item	2410419	et	3	main
tekkima	doc_441430986980_item	2410429	et	3	main
sportima	doc_441430986980_item	2410433	et	4	main
puhkama	doc_441430986980_item	2410435	et	3	main
saama	doc_441430986980_item	2410450	et	4	main
aparaat	doc_441430986980_item	2410453	et	3	main
et	doc_441430986980_item	2410454	et	3	main
abil	doc_441430986980_item	2410456	et	4	main
et	doc_441430986980_item	2410468	et	3	main
elab	doc_441430986980_item	2410472	et	3	main
ja	doc_441430986980_item	2410486	et	3	main
huvitava	doc_441430986980_item	2410506	et	4	main
aega	doc_441430986980_item	2410509	et	4	main
pange	doc_441430986980_item	2410511	et	4	main
õigesse	doc_441430986980_item	2410515	et	3	main
lugu	doc_441430986980_item	2410521	et	4	main
kõikis	doc_441430986980_item	2410530	et	4	main
ja	doc_441430986980_item	2410531	et	3	main
igaühes	doc_441430986980_item	2410534	et	3	main
sa	doc_441430986980_item	2410543	et	3	main
sport	doc_441430986980_item	2410545	et	3	main
naistele	doc_441430986980_item	2410558	et	3	main
autodele	doc_441430986980_item	2410560	et	3	main
7	doc_441430986980_item	2410584	et	2	main
hoiduma	doc_441430986980_item	2410601	et	3	main
päikelt	doc_441430986980_item	2410611	et	4	main
sidenditega	doc_441430986980_item	2410616	et	3	main
tellisime	doc_441430986980_item	2410618	et	4	main
lõuna	doc_441430986980_item	2410620	et	4	main
paras	doc_441430986980_item	2410414	et	3	main
võib	doc_441430986980_item	2410420	et	3	main
tohi	doc_441430986980_item	2410437	et	4	main
laskuda	doc_441430986980_item	2410438	et	3	main
ülekoormust	doc_441430986980_item	2410439	et	4	main
puhata	doc_441430986980_item	2410445	et	4	main
5	doc_441430986980_item	2410446	et	2	main
maagiliseks	doc_441430986980_item	2410466	et	4	main
abil	doc_441430986980_item	2410470	et	4	main
ja	doc_441430986980_item	2410473	et	3	main
hingab	doc_441430986980_item	2410474	et	3	main
kuid	doc_441430986980_item	2410476	et	4	main
telefonihelin	doc_441430986980_item	2410477	et	3	main
katkestama	doc_441430986980_item	2410478	et	3	main
ka	doc_441430986980_item	2410479	et	3	main
pühapäev	doc_441430986980_item	2410480	et	3	main
varahommik	doc_441430986980_item	2410481	et	3	main
uni	doc_441430986980_item	2410482	et	3	main
segama	doc_441430986980_item	2410483	et	3	main
pahandab	doc_441430986980_item	2410488	et	3	main
telesaade	doc_441430986980_item	2410490	et	4	main
valmistamist	doc_441430986980_item	2410502	et	4	main
söömise	doc_441430986980_item	2410504	et	4	main
pahandab	doc_441430986980_item	2410505	et	3	main
vatamise	doc_441430986980_item	2410508	et	4	main
sulgudes	doc_441430986980_item	2410512	et	4	main
vormi	doc_441430986980_item	2410516	et	4	main
väga	doc_441430986980_item	2410520	et	3	main
oma	doc_441430986980_item	2410522	et	4	main
vanemad	doc_441430986980_item	2410523	et	4	main
omadele	doc_441430986980_item	2410524	et	3	main
vanematele	doc_441430986980_item	2410525	et	4	main
3	doc_441430986980_item	2410539	et	2	main
ma	doc_441430986980_item	2410540	et	3	main
spordi	doc_441430986980_item	2410546	et	4	main
aga	doc_441430986980_item	2410547	et	3	main
sa	doc_441430986980_item	2410548	et	3	main
tunned	doc_441430986980_item	2410549	et	3	main
autod	doc_441430986980_item	2410556	et	3	main
on	doc_441430986980_item	2410563	et	4	main
väikesed	doc_441430986980_item	2410580	et	4	main
peab	doc_441430986980_item	2410600	et	4	main
10	doc_441430986980_item	2410604	et	2	main
1	doc_441430986980_item	2410617	et	2	main
aga	doc_441430986980_item	2410621	et	3	main
palju	doc_441430986980_item	2410625	et	4	main
olid	doc_441430986980_item	2410628	et	4	main
õpilased	doc_441430986980_item	2410630	et	3	main
tulevad	doc_441430986980_item	2410640	et	4	main
naeru	doc_441430986980_item	2410644	et	4	main
oleks	doc_441430986980_item	2410646	et	3	main
ei	doc_441430986980_item	2410653	et	4	main
töö	doc_441430986980_item	2410662	et	4	main
seest	doc_441430986980_item	2410696	et	3	main
suvel	doc_441430986981_item	2410714	et	3	main
ta	doc_441430986981_item	2410717	et	4	main
kuulutus	doc_441430986981_item	2410719	et	4	main
kuulutust	doc_441430986981_item	2410720	et	4	main
soovimatu	doc_441430986980_item	2410422	et	4	main
4	doc_441430986980_item	2410424	et	2	main
ei	doc_441430986980_item	2410425	et	4	main
tohtima	doc_441430986980_item	2410426	et	3	main
maandama	doc_441430986980_item	2410432	et	3	main
pinge	doc_441430986980_item	2410441	et	4	main
saate	doc_441430986980_item	2410442	et	4	main
maandada	doc_441430986980_item	2410443	et	3	main
sportida	doc_441430986980_item	2410444	et	4	main
tänapäev	doc_441430986980_item	2410449	et	3	main
maagiline	doc_441430986980_item	2410452	et	4	main
see	doc_441430986980_item	2410455	et	3	main
lausa	doc_441430986980_item	2410457	et	4	main
elama	doc_441430986980_item	2410458	et	3	main
ja	doc_441430986980_item	2410459	et	3	main
hingama	doc_441430986980_item	2410460	et	3	main
telefon	doc_441430986980_item	2410461	et	3	main
on	doc_441430986980_item	2410462	et	4	main
saanud	doc_441430986980_item	2410463	et	4	main
aparaadiks	doc_441430986980_item	2410467	et	3	main
lausa	doc_441430986980_item	2410471	et	4	main
6	doc_441430986980_item	2410475	et	2	main
valmistamine	doc_441430986980_item	2410485	et	4	main
telesaade	doc_441430986980_item	2410507	et	4	main
olevad	doc_441430986980_item	2410513	et	4	main
ma	doc_441430986980_item	2410518	et	3	main
aitavad	doc_441430986980_item	2410528	et	4	main
kõik	doc_441430986980_item	2410529	et	4	main
2	doc_441430986980_item	2410535	et	2	main
artikli	doc_441430986980_item	2410537	et	3	main
arvasin	doc_441430986980_item	2410541	et	3	main
huvi	doc_441430986980_item	2410550	et	4	main
kiired	doc_441430986980_item	2410555	et	4	main
4	doc_441430986980_item	2410561	et	2	main
väikesed	doc_441430986980_item	2410582	et	4	main
valdkond	doc_441430986980_item	2410589	et	3	main
valdkonnale	doc_441430986980_item	2410591	et	4	main
külmetamist	doc_441430986980_item	2410603	et	4	main
tunnen	doc_441430986980_item	2410606	et	3	main
suvine	doc_441430986980_item	2410608	et	4	main
päike	doc_441430986980_item	2410609	et	3	main
suviselt	doc_441430986980_item	2410610	et	4	main
kolmekäigulise	doc_441430986980_item	2410619	et	4	main
see	doc_441430986980_item	2410623	et	3	main
oodata	doc_441430986980_item	2410636	et	4	main
kui	doc_441430986980_item	2410637	et	3	main
vanemad	doc_441430986980_item	2410638	et	4	main
tagasi	doc_441430986980_item	2410639	et	3	main
5	doc_441430986980_item	2410651	et	2	main
läheb	doc_441430986980_item	2410657	et	3	main
teatrisse	doc_441430986980_item	2410659	et	3	main
lõpetage	doc_441430986980_item	2410661	et	3	main
siis	doc_441430986980_item	2410663	et	3	main
7	doc_441430986980_item	2410667	et	2	main
piret	doc_441430986981_item	2410709	et	4	main
ettevõtlik	doc_441430986981_item	2410712	et	3	main
nägis	doc_441430986981_item	2410716	et	4	main
ajalehes	doc_441430986981_item	2410718	et	3	main
et	doc_441430986981_item	2410721	et	3	main
ülem-suetuki	doc_441430986981_item	2410723	et	4	main
otsitakse	doc_441430986981_item	2410726	et	3	main
nädala	doc_441430986981_item	2410740	et	3	main
siberisse	doc_441430986981_item	2410752	et	4	main
üllatunud	doc_441430986981_item	2410761	et	4	main
audiga	doc_441430986981_item	2410769	et	3	main
maaliti	doc_441430986981_item	2410771	et	3	main
ei	doc_441430986981_item	2410778	et	4	main
lendama	doc_441430986981_item	2410779	et	3	main
lenda	doc_441430986981_item	2410780	et	4	main
lind	doc_441430986981_item	2410781	et	3	main
ega	doc_441430986981_item	2410782	et	3	main
kasva	doc_441430986981_item	2410783	et	4	main
pärast	doc_441430986981_item	2410792	et	4	main
õppeaasta	doc_441430986981_item	2410793	et	4	main
algust	doc_441430986981_item	2410794	et	4	main
koht	doc_441430986981_item	2410795	et	3	main
kohale	doc_441430986981_item	2410796	et	4	main
jõudis	doc_441430986981_item	2410797	et	3	main
polnud	doc_441430986981_item	2410798	et	3	main
kool	doc_441430986981_item	2410799	et	4	main
võttis	doc_441430986981_item	2410806	et	3	main
siin	doc_441430986981_item	2410810	et	4	main
sügisel	doc_441430986981_item	2410811	et	3	main
kartul	doc_441430986981_item	2410818	et	3	main
salv	doc_441430986981_item	2410819	et	3	main
salvis	doc_441430986981_item	2410820	et	4	main
õppimine	doc_441430986981_item	2410822	et	4	main
täie	doc_441430986981_item	2410824	et	3	main
räägivad	doc_441430986981_item	2410829	et	3	main
teistmoodi	doc_441430986981_item	2410831	et	3	main
ja	doc_441430986981_item	2410836	et	3	main
õpetatakse	doc_441430986981_item	2410856	et	3	main
keeles	doc_441430986981_item	2410858	et	4	main
külas	doc_441430986981_item	2410859	et	3	main
elab	doc_441430986981_item	2410860	et	3	main
veidi	doc_441430986981_item	2410861	et	3	main
kõik	doc_441430986981_item	2410869	et	4	main
lapsed	doc_441430986981_item	2410875	et	3	main
saatma	doc_441430986981_item	2410880	et	3	main
uued	doc_441430986981_item	2410883	et	3	main
varahommikul	doc_441430986980_item	2410498	et	3	main
segab	doc_441430986980_item	2410499	et	3	main
uni	doc_441430986980_item	2410500	et	3	main
lõunasööki	doc_441430986980_item	2410501	et	4	main
iv	doc_441430986980_item	2410510	et	4	main
sõnad	doc_441430986980_item	2410514	et	4	main
pean	doc_441430986980_item	2410519	et	4	main
sest	doc_441430986980_item	2410526	et	4	main
usaldavad	doc_441430986980_item	2410532	et	4	main
nõuded	doc_441430986980_item	2410538	et	3	main
et	doc_441430986980_item	2410542	et	3	main
ilusad	doc_441430986980_item	2410552	et	3	main
ja	doc_441430986980_item	2410554	et	3	main
muudatused	doc_441430986980_item	2410581	et	3	main
see	doc_441430986980_item	2410585	et	3	main
kuulub	doc_441430986980_item	2410587	et	3	main
v	doc_441430986980_item	2410612	et	4	main
täitke	doc_441430986980_item	2410613	et	3	main
lüngad	doc_441430986980_item	2410614	et	3	main
sobivate	doc_441430986980_item	2410615	et	4	main
kõrvallauast	doc_441430986980_item	2410642	et	4	main
kuid	doc_441430986980_item	2410645	et	4	main
anekdooti	doc_441430986980_item	2410649	et	4	main
seest	doc_441430986980_item	2410656	et	3	main
jalutama	doc_441430986980_item	2410666	et	3	main
või	doc_441430986980_item	2410690	et	4	main
linna	doc_441430986980_item	2410692	et	4	main
10	doc_441430986980_item	2410693	et	2	main
avasin	doc_441430986980_item	2410694	et	3	main
ukse	doc_441430986980_item	2410695	et	3	main
sele	doc_441430986980_item	2410697	et	4	main
pange	doc_441430986981_item	2410703	et	4	main
olevad	doc_441430986981_item	2410705	et	4	main
toomet	doc_441430986981_item	2410710	et	4	main
nägema	doc_441430986981_item	2410715	et	3	main
siberisse	doc_441430986981_item	2410722	et	4	main
küla	doc_441430986981_item	2410724	et	4	main
külas	doc_441430986981_item	2410725	et	3	main
õpetajat	doc_441430986981_item	2410729	et	4	main
konkurssi	doc_441430986981_item	2410733	et	4	main
väikestele	doc_441430986981_item	2410741	et	4	main
oodatud	doc_441430986981_item	2410757	et	4	main
olin	doc_441430986981_item	2410758	et	3	main
üsna	doc_441430986981_item	2410759	et	3	main
üllatuma	doc_441430986981_item	2410760	et	3	main
kui	doc_441430986981_item	2410762	et	3	main
mulle	doc_441430986981_item	2410763	et	4	main
tulema	doc_441430986981_item	2410764	et	4	main
tuli	doc_441430986981_item	2410765	et	4	main
seal	doc_441430986981_item	2410777	et	4	main
rohi	doc_441430986981_item	2410784	et	4	main
tahtmine	doc_441430986981_item	2410788	et	4	main
täis	doc_441430986981_item	2410790	et	4	main
võtma	doc_441430986981_item	2410805	et	3	main
kartulivõtt	doc_441430986981_item	2410808	et	3	main
kõige	doc_441430986981_item	2410812	et	4	main
nad	doc_441430986980_item	2410527	et	3	main
igaüks	doc_441430986980_item	2410533	et	3	main
kohandasin	doc_441430986980_item	2410536	et	3	main
huvitud	doc_441430986980_item	2410544	et	4	main
ainult	doc_441430986980_item	2410551	et	4	main
naised	doc_441430986980_item	2410553	et	3	main
ilusatele	doc_441430986980_item	2410557	et	3	main
kiirtele	doc_441430986980_item	2410559	et	3	main
praegu	doc_441430986980_item	2410562	et	3	main
oht	doc_441430986980_item	2410564	et	3	main
haigestuda	doc_441430986980_item	2410565	et	3	main
difteeria	doc_441430986980_item	2410566	et	4	main
difteeriaga	doc_441430986980_item	2410567	et	3	main
5	doc_441430986980_item	2410568	et	2	main
tüdinesin	doc_441430986980_item	2410569	et	3	main
uus	doc_441430986980_item	2410570	et	3	main
töökoht	doc_441430986980_item	2410571	et	3	main
uue	doc_441430986980_item	2410572	et	3	main
töökohta	doc_441430986980_item	2410573	et	4	main
kiiresti	doc_441430986980_item	2410574	et	3	main
6	doc_441430986980_item	2410575	et	2	main
piirdusime	doc_441430986980_item	2410576	et	3	main
selles	doc_441430986980_item	2410577	et	4	main
küsimuses	doc_441430986980_item	2410578	et	4	main
vaid	doc_441430986980_item	2410579	et	3	main
muudatused	doc_441430986980_item	2410583	et	3	main
küsimus	doc_441430986980_item	2410586	et	4	main
teine	doc_441430986980_item	2410588	et	3	main
teisele	doc_441430986980_item	2410590	et	4	main
8	doc_441430986980_item	2410592	et	2	main
närimiskumm	doc_441430986980_item	2410593	et	3	main
kleepus	doc_441430986980_item	2410594	et	3	main
püksid	doc_441430986980_item	2410595	et	3	main
pükstele	doc_441430986980_item	2410596	et	3	main
9	doc_441430986980_item	2410597	et	2	main
külmal	doc_441430986980_item	2410598	et	3	main
ajal	doc_441430986980_item	2410599	et	4	main
külmetamine	doc_441430986980_item	2410602	et	4	main
ma	doc_441430986980_item	2410605	et	3	main
rõõmu	doc_441430986980_item	2410607	et	4	main
ja	doc_441430986980_item	2410622	et	3	main
2	doc_441430986980_item	2410626	et	2	main
kui	doc_441430986980_item	2410631	et	3	main
3	doc_441430986980_item	2410633	et	2	main
lapsel	doc_441430986980_item	2410634	et	4	main
paluti	doc_441430986980_item	2410635	et	3	main
kostis	doc_441430986980_item	2410643	et	4	main
keegi	doc_441430986980_item	2410647	et	4	main
just	doc_441430986980_item	2410648	et	3	main
ta	doc_441430986980_item	2410652	et	4	main
trenni	doc_441430986980_item	2410655	et	4	main
6	doc_441430986980_item	2410660	et	2	main
pärast	doc_441430986980_item	2410664	et	4	main
lähete	doc_441430986980_item	2410665	et	4	main
i	doc_441430986981_item	2410702	et	4	main
naine	doc_441430986981_item	2410713	et	3	main
need	doc_441430986981_item	2410743	et	3	main
kinnitusel	doc_441430986981_item	2410749	et	4	main
vastu	doc_441430986981_item	2410766	et	3	main
mulle	doc_441430986981_item	2410770	et	4	main
siber	doc_441430986981_item	2410772	et	4	main
kui	doc_441430986981_item	2410785	et	3	main
veel	doc_441430986981_item	2410800	et	4	main
küla	doc_441430986981_item	2410804	et	4	main
kartuleid	doc_441430986981_item	2410807	et	3	main
on	doc_441430986981_item	2410809	et	4	main
käib	doc_441430986981_item	2410823	et	3	main
hoog	doc_441430986981_item	2410825	et	3	main
siinsed	doc_441430986981_item	2410827	et	3	main
mitte	doc_441430986981_item	2410838	et	3	main
aktsent	doc_441430986981_item	2410840	et	3	main
venemaa	doc_441430986981_item	2410850	et	4	main
aine	doc_441430986981_item	2410854	et	4	main
vene	doc_441430986981_item	2410857	et	4	main
kolmsada	doc_441430986981_item	2410863	et	4	main
kolmsaja	doc_441430986981_item	2410864	et	4	main
inimene	doc_441430986981_item	2410865	et	3	main
inimest	doc_441430986981_item	2410866	et	3	main
kõiged	doc_441430986981_item	2410870	et	4	main
poolpõlenud	doc_441430986981_item	2410876	et	4	main
saadakse	doc_441430986981_item	2410881	et	3	main
õpikud	doc_441430986981_item	2410884	et	3	main
praegu	doc_441430986981_item	2410896	et	3	main
on	doc_441430986981_item	2410897	et	4	main
päevad	doc_441430986981_item	2410898	et	3	main
veel	doc_441430986981_item	2410899	et	4	main
ööd	doc_441430986981_item	2410903	et	4	main
juba	doc_441430986981_item	2410908	et	3	main
vene	doc_441430986981_item	2410910	et	4	main
kütmine	doc_441430986981_item	2410912	et	4	main
kütta	doc_441430986981_item	2410913	et	3	main
kui	doc_441430986981_item	2410914	et	3	main
vaja	doc_441430986981_item	2410915	et	4	main
ostan	doc_441430986981_item	2410916	et	3	main
külapood	doc_441430986981_item	2410917	et	3	main
külapoes	doc_441430986981_item	2410918	et	3	main
talveks	doc_441430986981_item	2410927	et	4	main
vapralt	doc_441430986981_item	2410931	et	4	main
lühendatud	doc_441430986981_item	2410932	et	4	main
etteantud	doc_441430986981_item	2410937	et	4	main
sõnadest	doc_441430986981_item	2410938	et	3	main
laused	doc_441430986981_item	2410939	et	3	main
pannes	doc_441430986981_item	2410940	et	4	main
kasutades	doc_441430986981_item	2410945	et	3	main
kaunim	doc_441430986981_item	2410956	et	4	main
naeratamine	doc_441430986981_item	2410957	et	4	main
teeb	doc_441430986981_item	2410958	et	3	main
maksis	doc_441430986980_item	2410624	et	4	main
kohal	doc_441430986980_item	2410627	et	4	main
nii	doc_441430986980_item	2410629	et	3	main
õpetajad	doc_441430986980_item	2410632	et	4	main
4	doc_441430986980_item	2410641	et	2	main
rääkinud	doc_441430986980_item	2410650	et	4	main
tule	doc_441430986980_item	2410654	et	4	main
hoopis	doc_441430986980_item	2410658	et	3	main
selles	doc_441430986980_item	2410668	et	4	main
baaris	doc_441430986980_item	2410669	et	3	main
ei	doc_441430986980_item	2410670	et	4	main
suitsetada	doc_441430986980_item	2410672	et	3	main
ega	doc_441430986980_item	2410673	et	3	main
tohi	doc_441430986980_item	2410671	et	4	main
alkoholi	doc_441430986980_item	2410674	et	4	main
tarbida	doc_441430986980_item	2410675	et	3	main
8	doc_441430986980_item	2410676	et	2	main
nad	doc_441430986980_item	2410677	et	3	main
töötasid	doc_441430986980_item	2410678	et	4	main
küll	doc_441430986980_item	2410679	et	4	main
pingsalt	doc_441430986980_item	2410680	et	4	main
aga	doc_441430986980_item	2410681	et	3	main
tulemust	doc_441430986980_item	2410682	et	4	main
ei	doc_441430986980_item	2410683	et	4	main
olnud	doc_441430986980_item	2410684	et	4	main
9	doc_441430986980_item	2410685	et	2	main
kas	doc_441430986980_item	2410686	et	3	main
sa	doc_441430986980_item	2410687	et	3	main
sõidad	doc_441430986980_item	2410688	et	3	main
maale	doc_441430986980_item	2410689	et	4	main
jääd	doc_441430986980_item	2410691	et	4	main
pärast	doc_441430986980_item	2410698	et	4	main
kuulsin	doc_441430986980_item	2410699	et	3	main
koputust	doc_441430986980_item	2410700	et	4	main
eksamitöö	doc_441430986981_item	2410701	et	4	main
sulgudes	doc_441430986981_item	2410704	et	4	main
sõnad	doc_441430986981_item	2410706	et	4	main
õigesse	doc_441430986981_item	2410707	et	3	main
vormi	doc_441430986981_item	2410708	et	4	main
on	doc_441430986981_item	2410711	et	4	main
keele	doc_441430986981_item	2410728	et	4	main
piret	doc_441430986981_item	2410730	et	4	main
võitis	doc_441430986981_item	2410731	et	3	main
konkurss	doc_441430986981_item	2410732	et	3	main
ja	doc_441430986981_item	2410734	et	3	main
on	doc_441430986981_item	2410735	et	4	main
nüüd	doc_441430986981_item	2410736	et	4	main
juba	doc_441430986981_item	2410737	et	3	main
üle	doc_441430986981_item	2410738	et	3	main
nädal	doc_441430986981_item	2410739	et	3	main
pireti	doc_441430986981_item	2410748	et	4	main
tundis	doc_441430986981_item	2410750	et	3	main
jõudnud	doc_441430986981_item	2410754	et	4	main
et	doc_441430986981_item	2410755	et	3	main
on	doc_441430986981_item	2410756	et	4	main
korralik	doc_441430986981_item	2410767	et	3	main
ja	doc_441430986981_item	2410787	et	3	main
algama	doc_441430986981_item	2410801	et	3	main
alganud	doc_441430986981_item	2410802	et	4	main
on	doc_441430986981_item	2410817	et	4	main
mõnusamalt	doc_441430986981_item	2410835	et	4	main
vene	doc_441430986981_item	2410839	et	4	main
aktsenti	doc_441430986981_item	2410841	et	4	main
vaid	doc_441430986981_item	2410842	et	3	main
nagu	doc_441430986981_item	2410843	et	3	main
mõni	doc_441430986981_item	2410844	et	3	main
mõnd	doc_441430986981_item	2410845	et	3	main
ülejäänud	doc_441430986981_item	2410853	et	4	main
ained	doc_441430986981_item	2410855	et	3	main
pireti	doc_441430986981_item	2410872	et	4	main
õpivad	doc_441430986981_item	2410874	et	3	main
kartma	doc_441430986981_item	2410889	et	3	main
jahe	doc_441430986981_item	2410905	et	3	main
suure	doc_441430986981_item	2410909	et	3	main
ahju	doc_441430986981_item	2410911	et	4	main
valmistuma	doc_441430986981_item	2410928	et	3	main
kirjavahemärke	doc_441430986981_item	2410946	et	4	main
naeratus	doc_441430986981_item	2410948	et	4	main
meest	doc_441430986981_item	2410964	et	4	main
tagajärg	doc_441430986981_item	2410978	et	3	main
meid	doc_441430986981_item	2410981	et	4	main
aga	doc_441430986981_item	2410983	et	3	main
stressi	doc_441430986981_item	2410985	et	4	main
kogumine	doc_441430986981_item	2410986	et	4	main
võib	doc_441430986981_item	2410987	et	3	main
tuua	doc_441430986981_item	2410988	et	3	main
soovitamatu	doc_441430986981_item	2410989	et	4	main
tagajärjed	doc_441430986981_item	2410990	et	3	main
4	doc_441430986981_item	2410991	et	2	main
pinge	doc_441430986981_item	2410997	et	4	main
saama	doc_441430986981_item	2410998	et	4	main
on	doc_441430986981_item	2411031	et	4	main
nii	doc_441430986981_item	2411033	et	3	main
aparaadi	doc_441430986981_item	2411035	et	3	main
et	doc_441430986981_item	2411036	et	3	main
elada	doc_441430986981_item	2411040	et	3	main
hingata	doc_441430986981_item	2411042	et	4	main
lõunasöök	doc_441430986981_item	2411052	et	3	main
vaatamine	doc_441430986981_item	2411059	et	4	main
telefonihelin	doc_441430986981_item	2411062	et	3	main
ka	doc_441430986981_item	2411064	et	3	main
varahommiku	doc_441430986981_item	2411066	et	3	main
und	doc_441430986981_item	2411067	et	4	main
segab	doc_441430986981_item	2411068	et	3	main
sulgudes	doc_441430986981_item	2411080	et	4	main
vanemad	doc_441430986981_item	2411091	et	4	main
sest	doc_441430986981_item	2411094	et	4	main
kõik	doc_441430986981_item	2411097	et	4	main
ja	doc_441430986981_item	2411099	et	3	main
usaldavad	doc_441430986981_item	2411100	et	4	main
igaüks	doc_441430986981_item	2411101	et	3	main
igaühele	doc_441430986981_item	2411102	et	3	main
eesti	doc_441430986981_item	2410727	et	4	main
eestlastele	doc_441430986981_item	2410742	et	4	main
neile	doc_441430986981_item	2410744	et	4	main
emakeelt	doc_441430986981_item	2410745	et	4	main
õpetama	doc_441430986981_item	2410746	et	3	main
õpetamast	doc_441430986981_item	2410747	et	3	main
ta	doc_441430986981_item	2410751	et	4	main
jõudma	doc_441430986981_item	2410753	et	3	main
korraliku	doc_441430986981_item	2410768	et	3	main
siberist	doc_441430986981_item	2410773	et	4	main
selline	doc_441430986981_item	2410774	et	4	main
pilt	doc_441430986981_item	2410775	et	3	main
et	doc_441430986981_item	2410776	et	3	main
noor	doc_441430986981_item	2410786	et	3	main
tahtmist	doc_441430986981_item	2410789	et	4	main
piret	doc_441430986981_item	2410791	et	4	main
kogu	doc_441430986981_item	2410803	et	4	main
tähtis	doc_441430986981_item	2410813	et	4	main
tähtsaim	doc_441430986981_item	2410814	et	4	main
ettevõtmine	doc_441430986981_item	2410815	et	3	main
tänaseks	doc_441430986981_item	2410816	et	4	main
ja	doc_441430986981_item	2410821	et	3	main
hooga	doc_441430986981_item	2410826	et	3	main
mõnus	doc_441430986981_item	2410832	et	4	main
ja	doc_441430986981_item	2410833	et	3	main
mahlasemalt	doc_441430986981_item	2410837	et	4	main
kool	doc_441430986981_item	2410851	et	4	main
üle	doc_441430986981_item	2410862	et	3	main
sõnul	doc_441430986981_item	2410873	et	3	main
siberi	doc_441430986981_item	2410885	et	4	main
ei	doc_441430986981_item	2410888	et	4	main
karda	doc_441430986981_item	2410890	et	4	main
mulle	doc_441430986981_item	2410891	et	4	main
juba	doc_441430986981_item	2410892	et	3	main
tooma	doc_441430986981_item	2410893	et	3	main
soe	doc_441430986981_item	2410900	et	4	main
soojad	doc_441430986981_item	2410901	et	3	main
jahedad	doc_441430986981_item	2410906	et	3	main
seal	doc_441430986981_item	2410921	et	4	main
muud	doc_441430986981_item	2410923	et	4	main
ei	doc_441430986981_item	2410924	et	4	main
naerab	doc_441430986981_item	2410926	et	3	main
piret	doc_441430986981_item	2410930	et	4	main
ajalehest	doc_441430986981_item	2410933	et	4	main
sõnad	doc_441430986981_item	2410941	et	4	main
õigesse	doc_441430986981_item	2410942	et	3	main
2	doc_441430986981_item	2410947	et	2	main
tegema	doc_441430986981_item	2410949	et	3	main
ja	doc_441430986981_item	2410952	et	3	main
mehed	doc_441430986981_item	2410953	et	3	main
mehelikum	doc_441430986981_item	2410954	et	4	main
igaüks	doc_441430986981_item	2410955	et	3	main
ja	doc_441430986981_item	2410963	et	3	main
mehelikkuks	doc_441430986981_item	2410965	et	4	main
kogus	doc_441430986981_item	2410968	et	4	main
lisakoormus	doc_441430986981_item	2410974	et	3	main
võima	doc_441430986981_item	2410975	et	3	main
tooma	doc_441430986981_item	2410976	et	3	main
soovimatu	doc_441430986981_item	2410977	et	4	main
paras	doc_441430986981_item	2410984	et	3	main
tekkima	doc_441430986981_item	2410996	et	3	main
abil	doc_441430986981_item	2411024	et	4	main
elama	doc_441430986981_item	2411026	et	3	main
tänapäeval	doc_441430986981_item	2411029	et	3	main
ja	doc_441430986981_item	2411041	et	3	main
pühapäev	doc_441430986981_item	2411048	et	3	main
ja	doc_441430986981_item	2411054	et	3	main
telesaade	doc_441430986981_item	2411058	et	4	main
katkestab	doc_441430986981_item	2411063	et	3	main
iv	doc_441430986981_item	2411078	et	4	main
olevad	doc_441430986981_item	2411081	et	4	main
õigesse	doc_441430986981_item	2411083	et	3	main
1	doc_441430986981_item	2411085	et	2	main
ma	doc_441430986981_item	2411086	et	3	main
pean	doc_441430986981_item	2411087	et	4	main
väga	doc_441430986981_item	2411088	et	3	main
3	doc_441430986981_item	2411108	et	2	main
huvitud	doc_441430986981_item	2411113	et	4	main
spordiga	doc_441430986981_item	2411115	et	3	main
sa	doc_441430986981_item	2411117	et	3	main
huvi	doc_441430986981_item	2411119	et	4	main
ainult	doc_441430986981_item	2411120	et	4	main
eestlased	doc_441430986981_item	2410828	et	3	main
kuidagi	doc_441430986981_item	2410830	et	3	main
mahlakas	doc_441430986981_item	2410834	et	4	main
murret	doc_441430986981_item	2410846	et	4	main
kool	doc_441430986981_item	2410847	et	4	main
on	doc_441430986981_item	2410848	et	4	main
siiski	doc_441430986981_item	2410849	et	4	main
ja	doc_441430986981_item	2410852	et	3	main
emakeelt	doc_441430986981_item	2410867	et	4	main
saab	doc_441430986981_item	2410868	et	3	main
rääkida	doc_441430986981_item	2410871	et	3	main
raamatud	doc_441430986981_item	2410877	et	4	main
raamatuid	doc_441430986981_item	2410878	et	3	main
varsti	doc_441430986981_item	2410879	et	3	main
eestist	doc_441430986981_item	2410882	et	3	main
talve	doc_441430986981_item	2410886	et	4	main
talvepuud	doc_441430986981_item	2410895	et	4	main
kuid	doc_441430986981_item	2410902	et	4	main
harjutan	doc_441430986981_item	2410907	et	3	main
vildid	doc_441430986981_item	2410919	et	4	main
ega	doc_441430986981_item	2410920	et	3	main
slõhtuleht	doc_441430986981_item	2410934	et	4	main
vormi	doc_441430986981_item	2410943	et	4	main
naised	doc_441430986981_item	2410950	et	3	main
3	doc_441430986981_item	2410966	et	2	main
stress	doc_441430986981_item	2410969	et	3	main
lisakoormus	doc_441430986981_item	2410979	et	3	main
tegutsema	doc_441430986981_item	2410982	et	3	main
ülekoormus	doc_441430986981_item	2410995	et	3	main
et	doc_441430986981_item	2411022	et	3	main
lausa	doc_441430986981_item	2411025	et	4	main
hingama	doc_441430986981_item	2411028	et	3	main
maagilist	doc_441430986981_item	2411034	et	4	main
selle	doc_441430986981_item	2411037	et	4	main
varahommik	doc_441430986981_item	2411049	et	3	main
segama	doc_441430986981_item	2411051	et	3	main
söömine	doc_441430986981_item	2411055	et	4	main
pahandab	doc_441430986981_item	2411056	et	3	main
lugu	doc_441430986981_item	2411089	et	4	main
oma	doc_441430986981_item	2411090	et	4	main
nad	doc_441430986981_item	2411095	et	3	main
nõuded	doc_441430986981_item	2411106	et	3	main
arvasin	doc_441430986981_item	2411110	et	3	main
kiired	doc_441430986981_item	2411124	et	4	main
autodega	doc_441430986981_item	2411130	et	3	main
kirjade	doc_441430986981_item	2411134	et	3	main
on	doc_441430986981_item	2411139	et	4	main
uue	doc_441430986981_item	2411148	et	3	main
kiiresti	doc_441430986981_item	2411150	et	3	main
piirdusime	doc_441430986981_item	2411152	et	3	main
kuulub	doc_441430986981_item	2411163	et	3	main
8	doc_441430986981_item	2411168	et	2	main
püksi	doc_441430986981_item	2411172	et	4	main
peale	doc_441430986981_item	2411173	et	4	main
9	doc_441430986981_item	2411174	et	2	main
ajal	doc_441430986981_item	2411176	et	4	main
peab	doc_441430986981_item	2411177	et	4	main
hoiduma	doc_441430986981_item	2411178	et	3	main
10	doc_441430986981_item	2411181	et	2	main
tunnen	doc_441430986981_item	2411183	et	3	main
suvine	doc_441430986981_item	2411185	et	4	main
täitke	doc_441430986981_item	2411190	et	3	main
lüngad	doc_441430986981_item	2411191	et	3	main
sidenditega	doc_441430986981_item	2411193	et	3	main
palju	doc_441430986981_item	2411201	et	4	main
kohal	doc_441430986981_item	2411203	et	4	main
olid	doc_441430986981_item	2411204	et	4	main
nii	doc_441430986981_item	2411205	et	3	main
õpilased	doc_441430986981_item	2411206	et	3	main
piret	doc_441430986981_item	2410887	et	4	main
toodi	doc_441430986981_item	2410894	et	4	main
juba	doc_441430986981_item	2410904	et	3	main
suurt	doc_441430986981_item	2410922	et	3	main
müüdagi	doc_441430986981_item	2410925	et	3	main
valmistudes	doc_441430986981_item	2410929	et	3	main
iii	doc_441430986981_item	2410935	et	4	main
moodustage	doc_441430986981_item	2410936	et	3	main
ja	doc_441430986981_item	2410944	et	3	main
naiselikum	doc_441430986981_item	2410951	et	4	main
paras	doc_441430986981_item	2410967	et	3	main
panema	doc_441430986981_item	2410970	et	3	main
meie	doc_441430986981_item	2410971	et	4	main
tegutsema	doc_441430986981_item	2410972	et	3	main
aga	doc_441430986981_item	2410973	et	3	main
paneb	doc_441430986981_item	2410980	et	3	main
maandama	doc_441430986981_item	2410999	et	3	main
sportima	doc_441430986981_item	2411000	et	4	main
ja	doc_441430986981_item	2411001	et	3	main
puhkama	doc_441430986981_item	2411002	et	3	main
ei	doc_441430986981_item	2411003	et	4	main
tohi	doc_441430986981_item	2411004	et	4	main
lasta	doc_441430986981_item	2411005	et	4	main
ülekoormuse	doc_441430986981_item	2411006	et	3	main
tekkimist	doc_441430986981_item	2411007	et	4	main
pinget	doc_441430986981_item	2411008	et	3	main
saab	doc_441430986981_item	2411009	et	3	main
maandada	doc_441430986981_item	2411010	et	3	main
sportiga	doc_441430986981_item	2411011	et	4	main
ja	doc_441430986981_item	2411012	et	3	main
puhkusega	doc_441430986981_item	2411013	et	3	main
5	doc_441430986981_item	2411014	et	2	main
telefon	doc_441430986981_item	2411015	et	3	main
olema	doc_441430986981_item	2411016	et	4	main
saama	doc_441430986981_item	2411018	et	4	main
nii	doc_441430986981_item	2411019	et	3	main
tänapäev	doc_441430986981_item	2411017	et	3	main
maagiline	doc_441430986981_item	2411020	et	4	main
igaüht	doc_441430986981_item	2410959	et	3	main
kaunim	doc_441430986981_item	2410960	et	4	main
naist	doc_441430986981_item	2410961	et	3	main
naiselikkuks	doc_441430986981_item	2410962	et	4	main
ei	doc_441430986981_item	2410992	et	4	main
tohtima	doc_441430986981_item	2410993	et	3	main
laskma	doc_441430986981_item	2410994	et	3	main
aparaat	doc_441430986981_item	2411021	et	3	main
see	doc_441430986981_item	2411023	et	3	main
ja	doc_441430986981_item	2411027	et	3	main
abil	doc_441430986981_item	2411038	et	4	main
kuid	doc_441430986981_item	2411044	et	4	main
ka	doc_441430986981_item	2411047	et	3	main
huvitav	doc_441430986981_item	2411057	et	4	main
kuid	doc_441430986981_item	2411061	et	4	main
vanemale	doc_441430986981_item	2411093	et	4	main
aitavad	doc_441430986981_item	2411096	et	4	main
kõigis	doc_441430986981_item	2411098	et	4	main
et	doc_441430986981_item	2411111	et	3	main
ilusad	doc_441430986981_item	2411121	et	3	main
ja	doc_441430986981_item	2411123	et	3	main
autod	doc_441430986981_item	2411125	et	3	main
naistega	doc_441430986981_item	2411127	et	3	main
ja	doc_441430986981_item	2411133	et	3	main
vastu	doc_441430986981_item	2411136	et	3	main
difteeriat	doc_441430986981_item	2411143	et	3	main
väikseid	doc_441430986981_item	2411158	et	4	main
7	doc_441430986981_item	2411160	et	2	main
küsimus	doc_441430986981_item	2411162	et	4	main
teisse	doc_441430986981_item	2411166	et	4	main
kleepus	doc_441430986981_item	2411170	et	3	main
püksid	doc_441430986981_item	2411171	et	3	main
külmetamine	doc_441430986981_item	2411179	et	4	main
lõuna	doc_441430986981_item	2411197	et	4	main
maksis	doc_441430986981_item	2411200	et	4	main
keegi	doc_441430986981_item	2411224	et	4	main
rääkinud	doc_441430986981_item	2411227	et	4	main
ta	doc_441430986981_item	2411229	et	4	main
töö	doc_441430986981_item	2411239	et	4	main
alkoholi	doc_441430986981_item	2411250	et	4	main
töötasid	doc_441430986981_item	2411254	et	4	main
jääd	doc_441430986981_item	2411267	et	4	main
kuid	doc_441430986981_item	2411272	et	4	main
eksamitöö	doc_441430986982_item	2411275	et	4	main
olevad	doc_441430986982_item	2411279	et	4	main
suvel	doc_441430986982_item	2411288	et	3	main
ta	doc_441430986982_item	2411291	et	4	main
ajalehes	doc_441430986982_item	2411292	et	3	main
kuulutus	doc_441430986982_item	2411293	et	4	main
piret	doc_441430986982_item	2411304	et	4	main
konkurss	doc_441430986982_item	2411306	et	3	main
väikestele	doc_441430986982_item	2411315	et	4	main
emakeelt	doc_441430986982_item	2411319	et	4	main
jõudma	doc_441430986982_item	2411327	et	3	main
üllatunud	doc_441430986982_item	2411335	et	4	main
korralik	doc_441430986982_item	2411341	et	3	main
audiga	doc_441430986982_item	2411343	et	3	main
mulle	doc_441430986982_item	2411344	et	4	main
maaliti	doc_441430986982_item	2411345	et	3	main
ei	doc_441430986982_item	2411352	et	4	main
lendama	doc_441430986982_item	2411353	et	3	main
täis	doc_441430986982_item	2411364	et	4	main
piret	doc_441430986982_item	2411365	et	4	main
küla	doc_441430986982_item	2411378	et	4	main
siinsed	doc_441430986982_item	2411400	et	3	main
kuidagi	doc_441430986982_item	2411403	et	3	main
vene	doc_441430986982_item	2411411	et	4	main
kool	doc_441430986982_item	2411419	et	4	main
venemaa	doc_441430986982_item	2411422	et	4	main
kool	doc_441430986982_item	2411423	et	4	main
ja	doc_441430986982_item	2411424	et	3	main
elab	doc_441430986982_item	2411432	et	3	main
lapsed	doc_441430986982_item	2411445	et	3	main
poolpõlenud	doc_441430986982_item	2411446	et	4	main
varsti	doc_441430986982_item	2411449	et	3	main
uued	doc_441430986982_item	2411453	et	3	main
tooma	doc_441430986982_item	2411463	et	3	main
soe	doc_441430986982_item	2411470	et	4	main
suure	doc_441430986982_item	2411478	et	3	main
ahju	doc_441430986982_item	2411480	et	4	main
ei	doc_441430986982_item	2411493	et	4	main
müüdagi	doc_441430986982_item	2411494	et	3	main
telefon	doc_441430986981_item	2411030	et	3	main
saanud	doc_441430986981_item	2411032	et	4	main
lausa	doc_441430986981_item	2411039	et	4	main
6	doc_441430986981_item	2411043	et	2	main
telefonihelin	doc_441430986981_item	2411045	et	3	main
katkestama	doc_441430986981_item	2411046	et	3	main
uni	doc_441430986981_item	2411050	et	3	main
valmistamine	doc_441430986981_item	2411053	et	4	main
aeg	doc_441430986981_item	2411060	et	3	main
pühapäeva	doc_441430986981_item	2411065	et	4	main
lõunasööki	doc_441430986981_item	2411069	et	4	main
valmistusele	doc_441430986981_item	2411070	et	4	main
ja	doc_441430986981_item	2411071	et	3	main
söömisele	doc_441430986981_item	2411072	et	4	main
pahandab	doc_441430986981_item	2411073	et	3	main
huvitavale	doc_441430986981_item	2411074	et	4	main
telesaatele	doc_441430986981_item	2411075	et	3	main
vaatamise	doc_441430986981_item	2411076	et	4	main
ajale	doc_441430986981_item	2411077	et	3	main
pange	doc_441430986981_item	2411079	et	4	main
sõnad	doc_441430986981_item	2411082	et	4	main
vormi	doc_441430986981_item	2411084	et	4	main
oma	doc_441430986981_item	2411092	et	4	main
ma	doc_441430986981_item	2411109	et	3	main
sa	doc_441430986981_item	2411112	et	3	main
aga	doc_441430986981_item	2411116	et	3	main
tunned	doc_441430986981_item	2411118	et	3	main
autode	doc_441430986981_item	2411135	et	3	main
4	doc_441430986981_item	2411137	et	2	main
selles	doc_441430986981_item	2411153	et	4	main
vaid	doc_441430986981_item	2411155	et	3	main
teine	doc_441430986981_item	2411164	et	3	main
valdkonda	doc_441430986981_item	2411167	et	4	main
närimiskumm	doc_441430986981_item	2411169	et	3	main
suvisest	doc_441430986981_item	2411187	et	4	main
päikest	doc_441430986981_item	2411188	et	4	main
kolmekäigulise	doc_441430986981_item	2411196	et	4	main
just	doc_441430986981_item	2411225	et	3	main
5	doc_441430986981_item	2411228	et	2	main
vaid	doc_441430986981_item	2411233	et	3	main
läheb	doc_441430986981_item	2411234	et	3	main
hoopis	doc_441430986981_item	2411235	et	3	main
teatrisse	doc_441430986981_item	2411236	et	3	main
pingsalt	doc_441430986981_item	2411256	et	4	main
ukse	doc_441430986981_item	2411271	et	3	main
kuulsin	doc_441430986981_item	2411273	et	3	main
piret	doc_441430986982_item	2411283	et	4	main
toomet	doc_441430986982_item	2411284	et	4	main
kuulutuse	doc_441430986982_item	2411294	et	4	main
otsitakse	doc_441430986982_item	2411300	et	3	main
konkurssi	doc_441430986982_item	2411307	et	4	main
ja	doc_441430986982_item	2411308	et	3	main
nüüd	doc_441430986982_item	2411310	et	4	main
eestlastele	doc_441430986982_item	2411316	et	4	main
2	doc_441430986981_item	2411103	et	2	main
kohandasin	doc_441430986981_item	2411104	et	3	main
artikli	doc_441430986981_item	2411105	et	3	main
nõudeid	doc_441430986981_item	2411107	et	3	main
sport	doc_441430986981_item	2411114	et	3	main
kirjade	doc_441430986981_item	2411129	et	3	main
naiste	doc_441430986981_item	2411132	et	3	main
praegu	doc_441430986981_item	2411138	et	3	main
haigestuda	doc_441430986981_item	2411141	et	3	main
5	doc_441430986981_item	2411144	et	2	main
tüdinesin	doc_441430986981_item	2411145	et	3	main
uus	doc_441430986981_item	2411146	et	3	main
töökohta	doc_441430986981_item	2411149	et	4	main
6	doc_441430986981_item	2411151	et	2	main
väikesed	doc_441430986981_item	2411156	et	4	main
muudatused	doc_441430986981_item	2411157	et	3	main
muudatusi	doc_441430986981_item	2411159	et	3	main
valdkond	doc_441430986981_item	2411165	et	3	main
külmal	doc_441430986981_item	2411175	et	3	main
külmetamist	doc_441430986981_item	2411180	et	4	main
v	doc_441430986981_item	2411189	et	4	main
sobivate	doc_441430986981_item	2411192	et	4	main
1	doc_441430986981_item	2411194	et	2	main
tellisime	doc_441430986981_item	2411195	et	4	main
see	doc_441430986981_item	2411199	et	3	main
ei	doc_441430986981_item	2411230	et	4	main
tule	doc_441430986981_item	2411231	et	4	main
siis	doc_441430986981_item	2411240	et	3	main
jalutama	doc_441430986981_item	2411242	et	3	main
selles	doc_441430986981_item	2411244	et	4	main
baaris	doc_441430986981_item	2411245	et	3	main
ei	doc_441430986981_item	2411246	et	4	main
küll	doc_441430986981_item	2411255	et	4	main
ei	doc_441430986981_item	2411259	et	4	main
sa	doc_441430986981_item	2411263	et	3	main
linna	doc_441430986981_item	2411268	et	4	main
koputust	doc_441430986981_item	2411274	et	4	main
on	doc_441430986982_item	2411285	et	4	main
nägema	doc_441430986982_item	2411289	et	3	main
nägi	doc_441430986982_item	2411290	et	3	main
ülem-suetuki	doc_441430986982_item	2411297	et	4	main
õpetajat	doc_441430986982_item	2411303	et	4	main
võitis	doc_441430986982_item	2411305	et	3	main
need	doc_441430986982_item	2411317	et	3	main
nende	doc_441430986982_item	2411318	et	4	main
õpetama	doc_441430986982_item	2411320	et	3	main
õpetab	doc_441430986982_item	2411321	et	3	main
kinnitusel	doc_441430986982_item	2411323	et	4	main
oodatud	doc_441430986982_item	2411331	et	4	main
olin	doc_441430986982_item	2411332	et	3	main
mulle	doc_441430986982_item	2411337	et	4	main
rohi	doc_441430986982_item	2411358	et	4	main
ja	doc_441430986982_item	2411361	et	3	main
õppeaasta	doc_441430986982_item	2411367	et	4	main
algust	doc_441430986982_item	2411368	et	4	main
koht	doc_441430986982_item	2411369	et	3	main
kogu	doc_441430986982_item	2411377	et	4	main
ja	doc_441430986982_item	2411394	et	3	main
õppimine	doc_441430986982_item	2411395	et	4	main
käib	doc_441430986982_item	2411396	et	3	main
täie	doc_441430986982_item	2411397	et	3	main
hoog	doc_441430986982_item	2411398	et	3	main
eestlased	doc_441430986982_item	2411401	et	3	main
teistmoodi	doc_441430986982_item	2411404	et	3	main
ja	doc_441430986982_item	2411406	et	3	main
mitte	doc_441430986982_item	2411410	et	3	main
aktsenti	doc_441430986982_item	2411413	et	4	main
nagu	doc_441430986982_item	2411415	et	3	main
mõnd	doc_441430986982_item	2411417	et	3	main
naised	doc_441430986981_item	2411122	et	3	main
ilusa	doc_441430986981_item	2411126	et	3	main
ja	doc_441430986981_item	2411128	et	3	main
ilusa	doc_441430986981_item	2411131	et	3	main
oht	doc_441430986981_item	2411140	et	3	main
difteeria	doc_441430986981_item	2411142	et	4	main
töökoht	doc_441430986981_item	2411147	et	3	main
küsimuses	doc_441430986981_item	2411154	et	4	main
see	doc_441430986981_item	2411161	et	3	main
ma	doc_441430986981_item	2411182	et	3	main
rõõmu	doc_441430986981_item	2411184	et	4	main
päike	doc_441430986981_item	2411186	et	3	main
kuid	doc_441430986981_item	2411198	et	4	main
2	doc_441430986981_item	2411202	et	2	main
kui	doc_441430986981_item	2411207	et	3	main
ka	doc_441430986981_item	2411208	et	3	main
õpetajad	doc_441430986981_item	2411209	et	4	main
3	doc_441430986981_item	2411210	et	2	main
lapsel	doc_441430986981_item	2411211	et	4	main
paluti	doc_441430986981_item	2411212	et	3	main
oodata	doc_441430986981_item	2411213	et	4	main
kuni	doc_441430986981_item	2411214	et	3	main
vanemad	doc_441430986981_item	2411215	et	4	main
tagasi	doc_441430986981_item	2411216	et	3	main
tulevad	doc_441430986981_item	2411217	et	4	main
4	doc_441430986981_item	2411218	et	2	main
kõrvallauast	doc_441430986981_item	2411219	et	4	main
kostis	doc_441430986981_item	2411220	et	4	main
sest	doc_441430986981_item	2411222	et	4	main
oleks	doc_441430986981_item	2411223	et	3	main
trenni	doc_441430986981_item	2411232	et	4	main
6	doc_441430986981_item	2411237	et	2	main
tohi	doc_441430986981_item	2411247	et	4	main
suitsetada	doc_441430986981_item	2411248	et	3	main
ega	doc_441430986981_item	2411249	et	3	main
8	doc_441430986981_item	2411252	et	2	main
aga	doc_441430986981_item	2411257	et	3	main
olnud	doc_441430986981_item	2411260	et	4	main
kas	doc_441430986981_item	2411262	et	3	main
maale	doc_441430986981_item	2411265	et	4	main
või	doc_441430986981_item	2411266	et	4	main
avasin	doc_441430986981_item	2411270	et	3	main
i	doc_441430986982_item	2411276	et	4	main
sulgudes	doc_441430986982_item	2411278	et	4	main
sõnad	doc_441430986982_item	2411280	et	4	main
õigesse	doc_441430986982_item	2411281	et	3	main
vormi	doc_441430986982_item	2411282	et	4	main
ettevõtlik	doc_441430986982_item	2411286	et	3	main
naine	doc_441430986982_item	2411287	et	3	main
et	doc_441430986982_item	2411295	et	3	main
külas	doc_441430986982_item	2411299	et	3	main
eesti	doc_441430986982_item	2411301	et	4	main
on	doc_441430986982_item	2411309	et	4	main
juba	doc_441430986982_item	2411311	et	3	main
üle	doc_441430986982_item	2411312	et	3	main
nädal	doc_441430986982_item	2411313	et	3	main
üsna	doc_441430986982_item	2411333	et	3	main
siberist	doc_441430986982_item	2411347	et	4	main
kohale	doc_441430986982_item	2411370	et	4	main
jõudis	doc_441430986982_item	2411371	et	3	main
polnud	doc_441430986982_item	2411372	et	3	main
kool	doc_441430986982_item	2411373	et	4	main
võtma	doc_441430986982_item	2411379	et	3	main
võttis	doc_441430986982_item	2411380	et	3	main
kartuleid	doc_441430986982_item	2411381	et	3	main
kartulivõtt	doc_441430986982_item	2411382	et	3	main
on	doc_441430986982_item	2411383	et	4	main
siin	doc_441430986982_item	2411384	et	4	main
naeru	doc_441430986981_item	2411221	et	4	main
anekdooti	doc_441430986981_item	2411226	et	4	main
lõpetage	doc_441430986981_item	2411238	et	3	main
lähete	doc_441430986981_item	2411241	et	4	main
7	doc_441430986981_item	2411243	et	2	main
tarbida	doc_441430986981_item	2411251	et	3	main
nad	doc_441430986981_item	2411253	et	3	main
tulemust	doc_441430986981_item	2411258	et	4	main
9	doc_441430986981_item	2411261	et	2	main
sõidad	doc_441430986981_item	2411264	et	3	main
10	doc_441430986981_item	2411269	et	2	main
pange	doc_441430986982_item	2411277	et	4	main
siberisse	doc_441430986982_item	2411296	et	4	main
küla	doc_441430986982_item	2411298	et	4	main
keele	doc_441430986982_item	2411302	et	4	main
nädalat	doc_441430986982_item	2411314	et	3	main
jõuda	doc_441430986982_item	2411328	et	3	main
et	doc_441430986982_item	2411329	et	3	main
on	doc_441430986982_item	2411330	et	4	main
üllatuma	doc_441430986982_item	2411334	et	3	main
tuli	doc_441430986982_item	2411339	et	4	main
korraliku	doc_441430986982_item	2411342	et	3	main
siber	doc_441430986982_item	2411346	et	4	main
noor	doc_441430986982_item	2411360	et	3	main
pärast	doc_441430986982_item	2411366	et	4	main
veel	doc_441430986982_item	2411374	et	4	main
on	doc_441430986982_item	2411390	et	4	main
kartul	doc_441430986982_item	2411391	et	3	main
salv	doc_441430986982_item	2411392	et	3	main
salves	doc_441430986982_item	2411393	et	4	main
mõnusalt	doc_441430986982_item	2411408	et	4	main
aktsent	doc_441430986982_item	2411412	et	3	main
mõni	doc_441430986982_item	2411416	et	3	main
murret	doc_441430986982_item	2411418	et	4	main
aine	doc_441430986982_item	2411426	et	4	main
veidi	doc_441430986982_item	2411433	et	3	main
kolmsada	doc_441430986982_item	2411435	et	4	main
raamatud	doc_441430986982_item	2411447	et	4	main
õpikud	doc_441430986982_item	2411454	et	3	main
mulle	doc_441430986982_item	2411461	et	4	main
talvepuud	doc_441430986982_item	2411465	et	4	main
ööd	doc_441430986982_item	2411472	et	4	main
juba	doc_441430986982_item	2411477	et	3	main
vene	doc_441430986982_item	2411479	et	4	main
kütmine	doc_441430986982_item	2411481	et	4	main
kütmist	doc_441430986982_item	2411482	et	4	main
kui	doc_441430986982_item	2411483	et	3	main
seal	doc_441430986982_item	2411490	et	4	main
suurt	doc_441430986982_item	2411491	et	3	main
muud	doc_441430986982_item	2411492	et	4	main
piret	doc_441430986982_item	2411499	et	4	main
lühendatud	doc_441430986982_item	2411501	et	4	main
moodustage	doc_441430986982_item	2411505	et	3	main
mehed	doc_441430986982_item	2411522	et	3	main
igaüks	doc_441430986982_item	2411524	et	3	main
naisi	doc_441430986982_item	2411528	et	3	main
naiselikum	doc_441430986982_item	2411529	et	4	main
ja	doc_441430986982_item	2411530	et	3	main
mehelikum	doc_441430986982_item	2411532	et	4	main
igaühe	doc_441430986982_item	2411533	et	4	main
kaunim	doc_441430986982_item	2411534	et	4	main
3	doc_441430986982_item	2411535	et	2	main
meid	doc_441430986982_item	2411552	et	4	main
aga	doc_441430986982_item	2411554	et	3	main
see	doc_441430986982_item	2411592	et	3	main
telefon	doc_441430986982_item	2411598	et	3	main
tänapäeval	doc_441430986982_item	2411600	et	3	main
et	doc_441430986982_item	2411604	et	3	main
varahommik	doc_441430986982_item	2411618	et	3	main
valmistamine	doc_441430986982_item	2411622	et	4	main
söömine	doc_441430986982_item	2411624	et	4	main
pühapäeva	doc_441430986982_item	2411634	et	4	main
varahommiku	doc_441430986982_item	2411635	et	3	main
une	doc_441430986982_item	2411636	et	3	main
segab	doc_441430986982_item	2411637	et	3	main
sulgudes	doc_441430986982_item	2411649	et	4	main
lugu	doc_441430986982_item	2411658	et	4	main
naised	doc_441430986982_item	2411691	et	3	main
difteeriad	doc_441430986982_item	2411706	et	3	main
6	doc_441430986982_item	2411714	et	2	main
muudatused	doc_441430986982_item	2411720	et	3	main
külmetamist	doc_441430986982_item	2411742	et	4	main
v	doc_441430986982_item	2411751	et	4	main
täitke	doc_441430986982_item	2411752	et	3	main
pireti	doc_441430986982_item	2411322	et	4	main
tundis	doc_441430986982_item	2411324	et	3	main
ta	doc_441430986982_item	2411325	et	4	main
siberisse	doc_441430986982_item	2411326	et	4	main
kui	doc_441430986982_item	2411336	et	3	main
tulema	doc_441430986982_item	2411338	et	4	main
vastu	doc_441430986982_item	2411340	et	3	main
selline	doc_441430986982_item	2411348	et	4	main
pilt	doc_441430986982_item	2411349	et	3	main
et	doc_441430986982_item	2411350	et	3	main
seal	doc_441430986982_item	2411351	et	4	main
lenda	doc_441430986982_item	2411354	et	4	main
lind	doc_441430986982_item	2411355	et	3	main
ega	doc_441430986982_item	2411356	et	3	main
kasva	doc_441430986982_item	2411357	et	4	main
kui	doc_441430986982_item	2411359	et	3	main
tahtmine	doc_441430986982_item	2411362	et	4	main
tahtmise	doc_441430986982_item	2411363	et	4	main
algama	doc_441430986982_item	2411375	et	3	main
alatud	doc_441430986982_item	2411376	et	4	main
kõige	doc_441430986982_item	2411386	et	4	main
tähtis	doc_441430986982_item	2411387	et	4	main
ettevõtmine	doc_441430986982_item	2411388	et	3	main
tänaseks	doc_441430986982_item	2411389	et	4	main
hooga	doc_441430986982_item	2411399	et	3	main
räägivad	doc_441430986982_item	2411402	et	3	main
mahlakas	doc_441430986982_item	2411407	et	4	main
vaid	doc_441430986982_item	2411414	et	3	main
on	doc_441430986982_item	2411420	et	4	main
ülejäänud	doc_441430986982_item	2411425	et	4	main
vene	doc_441430986982_item	2411429	et	4	main
emakeelt	doc_441430986982_item	2411438	et	4	main
kõik	doc_441430986982_item	2411440	et	4	main
raamatutest	doc_441430986982_item	2411448	et	4	main
talve	doc_441430986982_item	2411456	et	4	main
juba	doc_441430986982_item	2411462	et	3	main
tõid	doc_441430986982_item	2411464	et	4	main
on	doc_441430986982_item	2411467	et	4	main
päevad	doc_441430986982_item	2411468	et	3	main
veel	doc_441430986982_item	2411469	et	4	main
jahe	doc_441430986982_item	2411474	et	3	main
vaja	doc_441430986982_item	2411484	et	4	main
külapood	doc_441430986982_item	2411486	et	3	main
vildid	doc_441430986982_item	2411488	et	4	main
ega	doc_441430986982_item	2411489	et	3	main
vapralt	doc_441430986982_item	2411500	et	4	main
etteantud	doc_441430986982_item	2411506	et	4	main
sõnad	doc_441430986982_item	2411510	et	4	main
kasutades	doc_441430986982_item	2411514	et	3	main
sügisel	doc_441430986982_item	2411385	et	3	main
mõnus	doc_441430986982_item	2411405	et	4	main
mahlakalt	doc_441430986982_item	2411409	et	4	main
õpetatakse	doc_441430986982_item	2411428	et	3	main
külas	doc_441430986982_item	2411431	et	3	main
inimene	doc_441430986982_item	2411436	et	3	main
saab	doc_441430986982_item	2411439	et	3	main
rääkida	doc_441430986982_item	2411441	et	3	main
pireti	doc_441430986982_item	2411442	et	4	main
sõnul	doc_441430986982_item	2411443	et	3	main
õpivad	doc_441430986982_item	2411444	et	3	main
saatma	doc_441430986982_item	2411450	et	3	main
siberi	doc_441430986982_item	2411455	et	4	main
piret	doc_441430986982_item	2411457	et	4	main
ei	doc_441430986982_item	2411458	et	4	main
kartma	doc_441430986982_item	2411459	et	3	main
juba	doc_441430986982_item	2411473	et	3	main
jahedad	doc_441430986982_item	2411475	et	3	main
ajalehest	doc_441430986982_item	2411502	et	4	main
sõnadest	doc_441430986982_item	2411507	et	3	main
mehi	doc_441430986982_item	2411531	et	3	main
panema	doc_441430986982_item	2411539	et	3	main
soovimatu	doc_441430986982_item	2411546	et	4	main
tuua	doc_441430986982_item	2411557	et	3	main
soovimatu	doc_441430986982_item	2411558	et	4	main
lausa	doc_441430986982_item	2411594	et	4	main
elama	doc_441430986982_item	2411595	et	3	main
hingama	doc_441430986982_item	2411597	et	3	main
on	doc_441430986982_item	2411599	et	4	main
nii	doc_441430986982_item	2411601	et	3	main
aparaat	doc_441430986982_item	2411603	et	3	main
6	doc_441430986982_item	2411612	et	2	main
kuid	doc_441430986982_item	2411613	et	4	main
telefonihelin	doc_441430986982_item	2411614	et	3	main
katkestama	doc_441430986982_item	2411615	et	3	main
ka	doc_441430986982_item	2411616	et	3	main
uni	doc_441430986982_item	2411619	et	3	main
üle	doc_441430986982_item	2411434	et	3	main
siiski	doc_441430986982_item	2411421	et	4	main
ained	doc_441430986982_item	2411427	et	3	main
keeles	doc_441430986982_item	2411430	et	4	main
inimest	doc_441430986982_item	2411437	et	3	main
saadavad	doc_441430986982_item	2411451	et	4	main
eestist	doc_441430986982_item	2411452	et	3	main
karda	doc_441430986982_item	2411460	et	4	main
praegu	doc_441430986982_item	2411466	et	3	main
kuid	doc_441430986982_item	2411471	et	4	main
harjutan	doc_441430986982_item	2411476	et	3	main
ostan	doc_441430986982_item	2411485	et	3	main
külapoest	doc_441430986982_item	2411487	et	4	main
talveks	doc_441430986982_item	2411496	et	4	main
valmistuma	doc_441430986982_item	2411497	et	3	main
valmistub	doc_441430986982_item	2411498	et	3	main
laused	doc_441430986982_item	2411508	et	3	main
vormi	doc_441430986982_item	2411512	et	4	main
kirjavahemärke	doc_441430986982_item	2411515	et	4	main
2	doc_441430986982_item	2411516	et	2	main
naeratus	doc_441430986982_item	2411517	et	4	main
tegema	doc_441430986982_item	2411518	et	3	main
naised	doc_441430986982_item	2411519	et	3	main
naiselikum	doc_441430986982_item	2411520	et	4	main
mehelikum	doc_441430986982_item	2411523	et	4	main
kaunim	doc_441430986982_item	2411525	et	4	main
naeratus	doc_441430986982_item	2411526	et	4	main
teeb	doc_441430986982_item	2411527	et	3	main
paras	doc_441430986982_item	2411536	et	3	main
võima	doc_441430986982_item	2411544	et	3	main
paras	doc_441430986982_item	2411548	et	3	main
kogus	doc_441430986982_item	2411549	et	4	main
stress	doc_441430986982_item	2411550	et	3	main
paneb	doc_441430986982_item	2411551	et	3	main
tegutsema	doc_441430986982_item	2411553	et	3	main
maagiline	doc_441430986982_item	2411589	et	4	main
aparaat	doc_441430986982_item	2411590	et	3	main
ja	doc_441430986982_item	2411610	et	3	main
hingata	doc_441430986982_item	2411611	et	4	main
lõunasöök	doc_441430986982_item	2411621	et	3	main
ja	doc_441430986982_item	2411623	et	3	main
pahandab	doc_441430986982_item	2411625	et	3	main
huvitav	doc_441430986982_item	2411626	et	4	main
telesaade	doc_441430986982_item	2411627	et	4	main
lõunasööki	doc_441430986982_item	2411638	et	4	main
valmistamist	doc_441430986982_item	2411639	et	4	main
ajal	doc_441430986982_item	2411646	et	4	main
sõnad	doc_441430986982_item	2411651	et	4	main
õigesse	doc_441430986982_item	2411652	et	3	main
vormi	doc_441430986982_item	2411653	et	4	main
1	doc_441430986982_item	2411654	et	2	main
ma	doc_441430986982_item	2411655	et	3	main
pean	doc_441430986982_item	2411656	et	4	main
väga	doc_441430986982_item	2411657	et	3	main
vanematest	doc_441430986982_item	2411662	et	4	main
sest	doc_441430986982_item	2411663	et	4	main
ilusad	doc_441430986982_item	2411690	et	3	main
ja	doc_441430986982_item	2411692	et	3	main
5	doc_441430986982_item	2411707	et	2	main
uus	doc_441430986982_item	2411709	et	3	main
uue	doc_441430986982_item	2411711	et	3	main
kiiresti	doc_441430986982_item	2411713	et	3	main
väikesed	doc_441430986982_item	2411719	et	4	main
väikesi	doc_441430986982_item	2411721	et	4	main
kuulub	doc_441430986982_item	2411726	et	3	main
püksid	doc_441430986982_item	2411734	et	3	main
külmal	doc_441430986982_item	2411737	et	3	main
10	doc_441430986982_item	2411743	et	2	main
ma	doc_441430986982_item	2411744	et	3	main
see	doc_441430986982_item	2411761	et	3	main
naeru	doc_441430986982_item	2411782	et	4	main
see	doc_441430986982_item	2411783	et	3	main
oleks	doc_441430986982_item	2411784	et	3	main
just	doc_441430986982_item	2411786	et	3	main
tule	doc_441430986982_item	2411792	et	4	main
teatrisse	doc_441430986982_item	2411797	et	3	main
naerab	doc_441430986982_item	2411495	et	3	main
slõhtuleht	doc_441430986982_item	2411503	et	4	main
iii	doc_441430986982_item	2411504	et	4	main
pannes	doc_441430986982_item	2411509	et	4	main
õigesse	doc_441430986982_item	2411511	et	3	main
ja	doc_441430986982_item	2411513	et	3	main
ja	doc_441430986982_item	2411521	et	3	main
stress	doc_441430986982_item	2411538	et	3	main
meie	doc_441430986982_item	2411540	et	4	main
aga	doc_441430986982_item	2411542	et	3	main
lisakoormus	doc_441430986982_item	2411555	et	3	main
4	doc_441430986982_item	2411560	et	2	main
ei	doc_441430986982_item	2411561	et	4	main
tohtima	doc_441430986982_item	2411562	et	3	main
laskma	doc_441430986982_item	2411563	et	3	main
ülekoormus	doc_441430986982_item	2411564	et	3	main
tekkima	doc_441430986982_item	2411565	et	3	main
pinge	doc_441430986982_item	2411566	et	4	main
abil	doc_441430986982_item	2411593	et	4	main
ja	doc_441430986982_item	2411596	et	3	main
lausa	doc_441430986982_item	2411608	et	4	main
elada	doc_441430986982_item	2411609	et	3	main
aeg	doc_441430986982_item	2411629	et	3	main
kuid	doc_441430986982_item	2411630	et	4	main
telefonihelin	doc_441430986982_item	2411631	et	3	main
katkestab	doc_441430986982_item	2411632	et	3	main
huvitavat	doc_441430986982_item	2411643	et	4	main
pange	doc_441430986982_item	2411648	et	4	main
oma	doc_441430986982_item	2411661	et	4	main
aga	doc_441430986982_item	2411685	et	3	main
huvi	doc_441430986982_item	2411688	et	4	main
ainult	doc_441430986982_item	2411689	et	4	main
kiired	doc_441430986982_item	2411693	et	4	main
autod	doc_441430986982_item	2411694	et	3	main
ilusaid	doc_441430986982_item	2411695	et	3	main
naisi	doc_441430986982_item	2411696	et	3	main
ja	doc_441430986982_item	2411697	et	3	main
kiireid	doc_441430986982_item	2411698	et	4	main
tüdinesin	doc_441430986982_item	2411708	et	3	main
töökoht	doc_441430986982_item	2411710	et	3	main
selles	doc_441430986982_item	2411716	et	4	main
kogus	doc_441430986982_item	2411537	et	4	main
tegutsema	doc_441430986982_item	2411541	et	3	main
lisakoormus	doc_441430986982_item	2411543	et	3	main
tooma	doc_441430986982_item	2411545	et	3	main
tagajärg	doc_441430986982_item	2411547	et	3	main
võib	doc_441430986982_item	2411556	et	3	main
tagajärgu	doc_441430986982_item	2411559	et	3	main
saama	doc_441430986982_item	2411567	et	4	main
maandama	doc_441430986982_item	2411568	et	3	main
sportima	doc_441430986982_item	2411569	et	4	main
ja	doc_441430986982_item	2411570	et	3	main
puhkama	doc_441430986982_item	2411571	et	3	main
ei	doc_441430986982_item	2411572	et	4	main
tohti	doc_441430986982_item	2411573	et	4	main
laskma	doc_441430986982_item	2411574	et	3	main
ülekoormust	doc_441430986982_item	2411575	et	4	main
tekkida	doc_441430986982_item	2411576	et	3	main
pinget	doc_441430986982_item	2411577	et	3	main
saab	doc_441430986982_item	2411578	et	3	main
maandada	doc_441430986982_item	2411579	et	3	main
sportida	doc_441430986982_item	2411580	et	4	main
ja	doc_441430986982_item	2411581	et	3	main
puhata	doc_441430986982_item	2411582	et	4	main
5	doc_441430986982_item	2411583	et	2	main
telefon	doc_441430986982_item	2411584	et	3	main
olema	doc_441430986982_item	2411585	et	4	main
tänapäev	doc_441430986982_item	2411586	et	3	main
saama	doc_441430986982_item	2411587	et	4	main
nii	doc_441430986982_item	2411588	et	3	main
et	doc_441430986982_item	2411591	et	3	main
maagiline	doc_441430986982_item	2411602	et	4	main
selle	doc_441430986982_item	2411605	et	4	main
abil	doc_441430986982_item	2411606	et	4	main
saab	doc_441430986982_item	2411607	et	3	main
pühapäev	doc_441430986982_item	2411617	et	3	main
segama	doc_441430986982_item	2411620	et	3	main
vaatamine	doc_441430986982_item	2411628	et	4	main
ja	doc_441430986982_item	2411640	et	3	main
söömist	doc_441430986982_item	2411641	et	4	main
pahandab	doc_441430986982_item	2411642	et	3	main
iv	doc_441430986982_item	2411647	et	4	main
vanemad	doc_441430986982_item	2411660	et	4	main
tunned	doc_441430986982_item	2411687	et	3	main
4	doc_441430986982_item	2411700	et	2	main
on	doc_441430986982_item	2411702	et	4	main
oht	doc_441430986982_item	2411703	et	3	main
haigestuda	doc_441430986982_item	2411704	et	3	main
difteeria	doc_441430986982_item	2411705	et	4	main
töökoha	doc_441430986982_item	2411712	et	4	main
küsimuses	doc_441430986982_item	2411717	et	4	main
muudatusi	doc_441430986982_item	2411722	et	3	main
see	doc_441430986982_item	2411724	et	3	main
kleepus	doc_441430986982_item	2411733	et	3	main
püksidele	doc_441430986982_item	2411735	et	3	main
peab	doc_441430986982_item	2411739	et	4	main
rõõmu	doc_441430986982_item	2411746	et	4	main
suvist	doc_441430986982_item	2411749	et	4	main
päikest	doc_441430986982_item	2411750	et	4	main
kuigi	doc_441430986982_item	2411760	et	3	main
kõrvallauast	doc_441430986982_item	2411780	et	4	main
keegi	doc_441430986982_item	2411785	et	4	main
anekdooti	doc_441430986982_item	2411787	et	4	main
trenni	doc_441430986982_item	2411793	et	4	main
6	doc_441430986982_item	2411798	et	2	main
tulemust	doc_441430986982_item	2411819	et	4	main
ole	doc_441779960551_item	2411838	et	4	main
hardi	doc_441779960551_item	2411853	et	4	main
teema	doc_441779960551_item	2411861	et	4	main
ka	doc_441779960551_item	2411862	et	3	main
alkoholi	doc_441779960551_item	2411871	et	4	main
peategelast	doc_441779960551_item	2411887	et	3	main
br	doc_441779960551_item	2411921	et	4	main
see	doc_441779960551_item	2411923	et	3	main
raha	doc_441779960551_item	2411926	et	4	main
mitte	doc_441779960551_item	2411931	et	3	main
koha	doc_441779960551_item	2411943	et	4	main
ülemused	doc_441779960551_item	2411949	et	4	main
siseminister	doc_441779960551_item	2411955	et	3	main
aitasid	doc_441779960551_item	2411957	et	4	main
inimene	doc_441779960551_item	2411982	et	3	main
enda	doc_441779960551_item	2411986	et	4	main
matustel	doc_441779960551_item	2411988	et	3	main
ja	doc_441779960551_item	2411989	et	3	main
ma	doc_441779960551_item	2411990	et	3	main
et	doc_441779960551_item	2411992	et	3	main
hilda	doc_441779960551_item	2412001	et	4	main
peavad	doc_441779960551_item	2412020	et	4	main
kõik	doc_441779960551_item	2412021	et	4	main
välja	doc_441779960551_item	2412026	et	4	main
võitleda	doc_441779960551_item	2412028	et	4	main
liiga	doc_441779960551_item	2412031	et	4	main
filmis	doc_441779960551_item	2412040	et	4	main
võitlus	doc_441779960551_item	2412043	et	3	main
üks	doc_441779960551_item	2412045	et	3	main
siseminister	doc_441779960551_item	2412053	et	3	main
body	doc_441779960551_item	2412056	et	4	main
hirmsamat	doc_441779960552_item	2412061	et	4	main
br	doc_441779960552_item	2412066	et	4	main
inimene	doc_441779960552_item	2412067	et	3	main
mees	doc_441779960552_item	2412118	et	4	main
aus	doc_441779960552_item	2412122	et	4	main
on	doc_441779960552_item	2412129	et	4	main
hea	doc_441779960552_item	2412131	et	4	main
alati	doc_441779960552_item	2412138	et	4	main
iseenna	doc_441779960552_item	2412145	et	4	main
on	doc_441779960552_item	2412155	et	4	main
vähe	doc_441779960552_item	2412156	et	3	main
ja	doc_441779960552_item	2412157	et	3	main
tihti	doc_441779960552_item	2412158	et	3	main
ausaks	doc_441779960552_item	2412169	et	4	main
ähvardati	doc_441779960552_item	2412193	et	3	main
ka	doc_441430986982_item	2411633	et	3	main
telesaade	doc_441430986982_item	2411644	et	4	main
vaatamise	doc_441430986982_item	2411645	et	4	main
olevad	doc_441430986982_item	2411650	et	4	main
oma	doc_441430986982_item	2411659	et	4	main
nad	doc_441430986982_item	2411664	et	3	main
aitavad	doc_441430986982_item	2411665	et	4	main
kõik	doc_441430986982_item	2411666	et	4	main
kõike	doc_441430986982_item	2411667	et	4	main
ja	doc_441430986982_item	2411668	et	3	main
usaldavad	doc_441430986982_item	2411669	et	4	main
igaüks	doc_441430986982_item	2411670	et	3	main
igaüht	doc_441430986982_item	2411671	et	3	main
2	doc_441430986982_item	2411672	et	2	main
kohandasin	doc_441430986982_item	2411673	et	3	main
artikli	doc_441430986982_item	2411674	et	3	main
nõuded	doc_441430986982_item	2411675	et	3	main
nõuetega	doc_441430986982_item	2411676	et	4	main
3	doc_441430986982_item	2411677	et	2	main
ma	doc_441430986982_item	2411678	et	3	main
arvasin	doc_441430986982_item	2411679	et	3	main
et	doc_441430986982_item	2411680	et	3	main
sa	doc_441430986982_item	2411681	et	3	main
huvitud	doc_441430986982_item	2411682	et	4	main
sport	doc_441430986982_item	2411683	et	3	main
sporti	doc_441430986982_item	2411684	et	4	main
sa	doc_441430986982_item	2411686	et	3	main
autosid	doc_441430986982_item	2411699	et	3	main
praegu	doc_441430986982_item	2411701	et	3	main
piirdusime	doc_441430986982_item	2411715	et	3	main
vaid	doc_441430986982_item	2411718	et	3	main
küsimus	doc_441430986982_item	2411725	et	4	main
teine	doc_441430986982_item	2411727	et	3	main
valdkond	doc_441430986982_item	2411728	et	3	main
teisele	doc_441430986982_item	2411729	et	4	main
valdkonnale	doc_441430986982_item	2411730	et	4	main
8	doc_441430986982_item	2411731	et	2	main
närimiskumm	doc_441430986982_item	2411732	et	3	main
9	doc_441430986982_item	2411736	et	2	main
ajal	doc_441430986982_item	2411738	et	4	main
hoiduma	doc_441430986982_item	2411740	et	3	main
tunnen	doc_441430986982_item	2411745	et	3	main
1	doc_441430986982_item	2411756	et	2	main
kolmekäigulise	doc_441430986982_item	2411758	et	4	main
kostis	doc_441430986982_item	2411781	et	4	main
ei	doc_441430986982_item	2411791	et	4	main
hoopis	doc_441430986982_item	2411796	et	3	main
7	doc_441430986982_item	2411804	et	2	main
selles	doc_441430986982_item	2411805	et	4	main
baaris	doc_441430986982_item	2411806	et	3	main
töötasid	doc_441430986982_item	2411815	et	4	main
küll	doc_441430986982_item	2411816	et	4	main
ei	doc_441430986982_item	2411820	et	4	main
kas	doc_441430986982_item	2411823	et	3	main
kuulsin	doc_441430986982_item	2411834	et	3	main
essee	doc_441779960551_item	2411836	et	4	main
ei	doc_441779960551_item	2411837	et	4	main
aus	doc_441779960551_item	2411843	et	4	main
inimene	doc_441779960551_item	2411844	et	3	main
br	doc_441779960551_item	2411845	et	4	main
film	doc_441779960551_item	2411846	et	3	main
tulivesi	doc_441779960551_item	2411847	et	4	main
filmi	doc_441779960551_item	2411855	et	4	main
esitas	doc_441779960551_item	2411857	et	3	main
saada	doc_441779960551_item	2411880	et	4	main
br	doc_441779960551_item	2411883	et	4	main
eerik	doc_441779960551_item	2411891	et	4	main
7	doc_441430986982_item	2411723	et	2	main
külmetamine	doc_441430986982_item	2411741	et	4	main
suvine	doc_441430986982_item	2411747	et	4	main
päike	doc_441430986982_item	2411748	et	3	main
sobivate	doc_441430986982_item	2411754	et	4	main
lõuna	doc_441430986982_item	2411759	et	4	main
maksis	doc_441430986982_item	2411762	et	4	main
palju	doc_441430986982_item	2411763	et	4	main
kohal	doc_441430986982_item	2411765	et	4	main
2	doc_441430986982_item	2411764	et	2	main
olid	doc_441430986982_item	2411766	et	4	main
nii	doc_441430986982_item	2411767	et	3	main
õpilased	doc_441430986982_item	2411768	et	3	main
kui	doc_441430986982_item	2411769	et	3	main
õpetajad	doc_441430986982_item	2411770	et	4	main
3	doc_441430986982_item	2411771	et	2	main
lapsel	doc_441430986982_item	2411772	et	4	main
paluti	doc_441430986982_item	2411773	et	3	main
oodata	doc_441430986982_item	2411774	et	4	main
kuni	doc_441430986982_item	2411775	et	3	main
vanemad	doc_441430986982_item	2411776	et	4	main
tagasi	doc_441430986982_item	2411777	et	3	main
tulevad	doc_441430986982_item	2411778	et	4	main
lüngad	doc_441430986982_item	2411753	et	3	main
sidenditega	doc_441430986982_item	2411755	et	3	main
tellisime	doc_441430986982_item	2411757	et	4	main
4	doc_441430986982_item	2411779	et	2	main
5	doc_441430986982_item	2411789	et	2	main
ta	doc_441430986982_item	2411790	et	4	main
läheb	doc_441430986982_item	2411795	et	3	main
siis	doc_441430986982_item	2411801	et	3	main
ei	doc_441430986982_item	2411807	et	4	main
tohi	doc_441430986982_item	2411808	et	4	main
pingsalt	doc_441430986982_item	2411817	et	4	main
rääkinud	doc_441430986982_item	2411788	et	4	main
sest	doc_441430986982_item	2411794	et	4	main
lõpetage	doc_441430986982_item	2411799	et	3	main
suitsetada	doc_441430986982_item	2411809	et	3	main
ning	doc_441430986982_item	2411810	et	3	main
alkoholi	doc_441430986982_item	2411811	et	4	main
8	doc_441430986982_item	2411813	et	2	main
nad	doc_441430986982_item	2411814	et	3	main
aga	doc_441430986982_item	2411818	et	3	main
olnud	doc_441430986982_item	2411821	et	4	main
sõidad	doc_441430986982_item	2411825	et	3	main
või	doc_441430986982_item	2411827	et	4	main
jääd	doc_441430986982_item	2411828	et	4	main
linna	doc_441430986982_item	2411829	et	4	main
10	doc_441430986982_item	2411830	et	2	main
avasin	doc_441430986982_item	2411831	et	3	main
kui	doc_441430986982_item	2411833	et	3	main
midagi	doc_441779960551_item	2411839	et	4	main
hirmsamat	doc_441779960551_item	2411840	et	4	main
kui	doc_441779960551_item	2411841	et	3	main
müümine	doc_441779960551_item	2411872	et	4	main
öösiti	doc_441779960551_item	2411873	et	4	main
või	doc_441779960551_item	2411874	et	4	main
mitte	doc_441779960551_item	2411875	et	3	main
kui	doc_441779960551_item	2411876	et	3	main
mitte	doc_441779960551_item	2411877	et	3	main
siis	doc_441779960551_item	2411878	et	3	main
kuidas	doc_441779960551_item	2411879	et	3	main
kolm	doc_441779960551_item	2411886	et	3	main
mees	doc_441779960551_item	2411890	et	4	main
konterbant	doc_441779960551_item	2411922	et	3	main
suur	doc_441779960551_item	2411925	et	3	main
kuid	doc_441779960551_item	2411927	et	4	main
ainult	doc_441779960551_item	2411932	et	4	main
kes	doc_441779960551_item	2411934	et	4	main
kes	doc_441779960551_item	2411940	et	4	main
selle	doc_441779960551_item	2411942	et	4	main
pealt	doc_441779960551_item	2411944	et	4	main
silmad	doc_441779960551_item	2411945	et	4	main
kinni	doc_441779960551_item	2411946	et	3	main
nad	doc_441779960551_item	2411956	et	3	main
üks	doc_441779960551_item	2411980	et	3	main
aus	doc_441779960551_item	2411981	et	4	main
niimoodi	doc_441779960551_item	2411983	et	3	main
tal	doc_441779960551_item	2411993	et	3	main
õigus	doc_441779960551_item	2411995	et	4	main
mees	doc_441779960551_item	2412002	et	4	main
üksi	doc_441779960551_item	2412018	et	4	main
tuleb	doc_441779960551_item	2412025	et	3	main
ei	doc_441779960551_item	2412029	et	4	main
saa	doc_441779960551_item	2412030	et	4	main
oli	doc_441779960551_item	2412034	et	3	main
ei	doc_441779960552_item	2412058	et	4	main
üks	doc_441779960552_item	2412063	et	3	main
kartnud	doc_441779960552_item	2412072	et	4	main
töötaksid	doc_441779960552_item	2412105	et	4	main
ausad	doc_441779960552_item	2412106	et	3	main
inimesed	doc_441779960552_item	2412107	et	3	main
võiks	doc_441779960552_item	2412110	et	4	main
iga	doc_441779960552_item	2412113	et	4	main
tahab	doc_441779960552_item	2412115	et	3	main
olla	doc_441779960552_item	2412126	et	3	main
aga	doc_441779960552_item	2412128	et	3	main
oled	doc_441779960552_item	2412133	et	3	main
tõtt	doc_441779960552_item	2412140	et	4	main
kas	doc_441779960552_item	2412147	et	3	main
on	doc_441779960552_item	2412148	et	4	main
on	doc_441779960552_item	2412152	et	4	main
aga	doc_441779960552_item	2412153	et	3	main
pealekaebajaks	doc_441779960552_item	2412161	et	3	main
võin	doc_441779960552_item	2412164	et	3	main
et	doc_441779960552_item	2412166	et	3	main
ei	doc_441779960552_item	2412201	et	4	main
ütleks	doc_441779960552_item	2412202	et	3	main
aga	doc_441779960552_item	2412210	et	3	main
ja	doc_441779960552_item	2412215	et	3	main
samal	doc_441779960552_item	2412222	et	3	main
narkootikumite	doc_441779960552_item	2412228	et	4	main
kas	doc_441779960552_item	2412230	et	3	main
ja	doc_441779960552_item	2412233	et	3	main
vaja	doc_441779960552_item	2412248	et	4	main
karistatakse	doc_441779960552_item	2412255	et	3	main
töö	doc_441430986982_item	2411800	et	4	main
lähete	doc_441430986982_item	2411802	et	4	main
jalutama	doc_441430986982_item	2411803	et	3	main
tarbida	doc_441430986982_item	2411812	et	3	main
9	doc_441430986982_item	2411822	et	2	main
sa	doc_441430986982_item	2411824	et	3	main
ukse	doc_441430986982_item	2411832	et	3	main
koputust	doc_441430986982_item	2411835	et	4	main
üks	doc_441779960551_item	2411842	et	3	main
tänapäeval	doc_441779960551_item	2411852	et	3	main
rezhisöör	doc_441779960551_item	2411856	et	4	main
tänapäeval	doc_441779960551_item	2411863	et	3	main
meie	doc_441779960551_item	2411864	et	4	main
valitsus	doc_441779960551_item	2411865	et	4	main
otsib	doc_441779960551_item	2411866	et	3	main
lahti	doc_441779960551_item	2411882	et	4	main
filmis	doc_441779960551_item	2411884	et	4	main
on	doc_441779960551_item	2411885	et	4	main
on	doc_441779960551_item	2411924	et	4	main
raha	doc_441779960551_item	2411929	et	4	main
need	doc_441779960551_item	2411933	et	3	main
sellega	doc_441779960551_item	2411935	et	3	main
ka	doc_441779960551_item	2411938	et	3	main
vabariigi	doc_441779960551_item	2411954	et	3	main
arvan	doc_441779960551_item	2411991	et	3	main
ja	doc_441779960551_item	2412005	et	3	main
br	doc_441779960551_item	2412011	et	4	main
salakaubandusega	doc_441779960551_item	2412012	et	3	main
on	doc_441779960551_item	2412013	et	4	main
maale	doc_441430986982_item	2411826	et	4	main
on	doc_441779960551_item	2411848	et	4	main
väga	doc_441779960551_item	2411849	et	3	main
aktuaalne	doc_441779960551_item	2411850	et	3	main
ka	doc_441779960551_item	2411851	et	3	main
hormer	doc_441779960551_item	2411854	et	4	main
meile	doc_441779960551_item	2411858	et	4	main
mõtisklemiseks	doc_441779960551_item	2411859	et	4	main
salakaubanduse	doc_441779960551_item	2411860	et	3	main
vastust	doc_441779960551_item	2411867	et	4	main
küsimusele	doc_441779960551_item	2411868	et	4	main
kas	doc_441779960551_item	2411869	et	3	main
lubada	doc_441779960551_item	2411870	et	3	main
salakaubandusest	doc_441779960551_item	2411881	et	4	main
hilda	doc_441779960551_item	2411888	et	4	main
tema	doc_441779960551_item	2411889	et	4	main
kes	doc_441779960551_item	2411892	et	4	main
tegeleb	doc_441779960551_item	2411893	et	3	main
piirituse	doc_441779960551_item	2411894	et	4	main
salakaubavedamisega	doc_441779960551_item	2411895	et	3	main
ja	doc_441779960551_item	2411896	et	3	main
leitenant	doc_441779960551_item	2411897	et	4	main
aleks	doc_441779960551_item	2411898	et	4	main
aleks	doc_441779960551_item	2411899	et	4	main
üksi	doc_441779960551_item	2411900	et	4	main
võitleb	doc_441779960551_item	2411901	et	3	main
salakaubanduse	doc_441779960551_item	2411902	et	3	main
süsteemiga	doc_441779960551_item	2411903	et	3	main
ja	doc_441779960551_item	2411904	et	3	main
seda	doc_441779960551_item	2411905	et	3	main
tuleb	doc_441779960551_item	2411906	et	3	main
tal	doc_441779960551_item	2411907	et	3	main
kuid	doc_441779960551_item	2411909	et	4	main
välja	doc_441779960551_item	2411908	et	4	main
liiga	doc_441779960551_item	2411910	et	4	main
kõrge	doc_441779960551_item	2411911	et	4	main
hinnaga	doc_441779960551_item	2411912	et	3	main
filmi	doc_441779960551_item	2411913	et	4	main
lõpus	doc_441779960551_item	2411914	et	4	main
sureb	doc_441779960551_item	2411915	et	3	main
keda	doc_441779960551_item	2411917	et	4	main
armastasid	doc_441779960551_item	2411918	et	4	main
mõlemad	doc_441779960551_item	2411919	et	3	main
mehed	doc_441779960551_item	2411920	et	3	main
hilda	doc_441779960551_item	2411916	et	4	main
saavad	doc_441779960551_item	2411930	et	4	main
tegelevad	doc_441779960551_item	2411936	et	4	main
vaid	doc_441779960551_item	2411937	et	3	main
paneb	doc_441779960551_item	2411941	et	3	main
olid	doc_441779960551_item	2411950	et	4	main
kapten	doc_441779960551_item	2411951	et	3	main
ja	doc_441779960551_item	2411952	et	3	main
seda	doc_441779960551_item	2411928	et	3	main
ülemus	doc_441779960551_item	2411939	et	4	main
filmis	doc_441779960551_item	2411947	et	4	main
tulivesi	doc_441779960551_item	2411948	et	4	main
ja	doc_441779960551_item	2411958	et	3	main
kuid	doc_441779960551_item	2411962	et	4	main
vangi	doc_441779960551_item	2411963	et	4	main
läksid	doc_441779960551_item	2411964	et	4	main
teised	doc_441779960551_item	2411965	et	4	main
näiteks	doc_441779960551_item	2411966	et	4	main
hilda	doc_441779960551_item	2411967	et	4	main
julius	doc_441779960551_item	2411969	et	4	main
sibul	doc_441779960551_item	2411970	et	3	main
onu	doc_441779960551_item	2411968	et	4	main
filmis	doc_441779960551_item	2411971	et	4	main
oli	doc_441779960551_item	2411972	et	3	main
öeldud	doc_441779960551_item	2411973	et	4	main
fraas	doc_441779960551_item	2411974	et	3	main
ei	doc_441779960551_item	2411975	et	4	main
ole	doc_441779960551_item	2411976	et	4	main
midagi	doc_441779960551_item	2411977	et	4	main
jubedamat	doc_441779960551_item	2411978	et	4	main
kui	doc_441779960551_item	2411979	et	3	main
eesti	doc_441779960551_item	2411953	et	4	main
lubasid	doc_441779960551_item	2411959	et	4	main
salakauba	doc_441779960551_item	2411960	et	3	main
sissetoomist	doc_441779960551_item	2411961	et	4	main
hilda	doc_441779960551_item	2411985	et	4	main
onu	doc_441779960551_item	2411987	et	4	main
oli	doc_441779960551_item	2411994	et	3	main
sest	doc_441779960551_item	2411996	et	4	main
vanglas	doc_441779960551_item	2411997	et	3	main
suri	doc_441779960551_item	2411998	et	3	main
ta	doc_441779960551_item	2411999	et	4	main
oli	doc_441779960551_item	2412003	et	3	main
rahulik	doc_441779960551_item	2412006	et	3	main
muutus	doc_441779960551_item	2412008	et	4	main
vaja	doc_441779960551_item	2412014	et	4	main
seda	doc_441779960551_item	2412019	et	3	main
siis	doc_441779960551_item	2412023	et	3	main
kõik	doc_441779960551_item	2412024	et	4	main
verd	doc_441779960551_item	2412033	et	3	main
lastud	doc_441779960551_item	2412036	et	4	main
ebavõrdne	doc_441779960551_item	2412042	et	3	main
leitenant	doc_441779960551_item	2412046	et	4	main
oli	doc_441779960551_item	2412047	et	3	main
seaduse	doc_441779960551_item	2412048	et	3	main
poolel	doc_441779960551_item	2412049	et	4	main
kuid	doc_441779960551_item	2412050	et	4	main
mitte	doc_441779960551_item	2412055	et	3	main
ole	doc_441779960552_item	2412059	et	4	main
midagi	doc_441779960552_item	2412071	et	4	main
ettevõttes	doc_441779960552_item	2412103	et	3	main
usaldada	doc_441779960552_item	2412111	et	3	main
inimene	doc_441779960552_item	2412114	et	3	main
tema	doc_441779960552_item	2412117	et	4	main
oleks	doc_441779960552_item	2412121	et	3	main
ütles	doc_441779960551_item	2411984	et	3	main
onu	doc_441779960551_item	2412000	et	4	main
vanglas	doc_441779960551_item	2412004	et	3	main
elu	doc_441779960551_item	2412007	et	4	main
veel	doc_441779960551_item	2412009	et	4	main
ebarahulikumaks	doc_441779960551_item	2412010	et	4	main
võidelda	doc_441779960551_item	2412015	et	4	main
kuid	doc_441779960551_item	2412016	et	4	main
mitte	doc_441779960551_item	2412017	et	3	main
üksi	doc_441779960551_item	2412027	et	4	main
palju	doc_441779960551_item	2412032	et	4	main
välja	doc_441779960551_item	2412035	et	4	main
selle	doc_441779960551_item	2412037	et	4	main
võidu	doc_441779960551_item	2412038	et	4	main
esitatud	doc_441779960551_item	2412041	et	4	main
ainult	doc_441779960551_item	2412044	et	4	main
seadus	doc_441779960551_item	2412051	et	4	main
rahvas	doc_441779960551_item	2412052	et	4	main
kapten	doc_441779960551_item	2412054	et	3	main
kui	doc_441779960552_item	2412062	et	3	main
aus	doc_441779960552_item	2412064	et	4	main
on	doc_441779960552_item	2412068	et	4	main
kogu	doc_441779960552_item	2412069	et	4	main
aeg	doc_441779960552_item	2412070	et	3	main
firmas	doc_441779960552_item	2412104	et	3	main
ta	doc_441779960552_item	2412109	et	4	main
või	doc_441779960552_item	2412119	et	4	main
naine	doc_441779960552_item	2412120	et	3	main
ja	doc_441779960552_item	2412123	et	3	main
ise	doc_441779960552_item	2412125	et	4	main
et	doc_441779960552_item	2412132	et	3	main
ja	doc_441779960552_item	2412141	et	3	main
sees	doc_441779960552_item	2412146	et	4	main
maailmas	doc_441779960552_item	2412149	et	3	main
neid	doc_441779960552_item	2412159	et	4	main
nimetakse	doc_441779960552_item	2412160	et	3	main
olla	doc_441779960552_item	2412168	et	3	main
surmaga	doc_441779960552_item	2412194	et	3	main
kui	doc_441779960552_item	2412195	et	3	main
tõtt	doc_441779960552_item	2412197	et	4	main
avaldate	doc_441779960552_item	2412198	et	3	main
minu	doc_441779960552_item	2412204	et	3	main
on	doc_441779960552_item	2412211	et	4	main
ütleks	doc_441779960552_item	2412214	et	3	main
eest	doc_441779960552_item	2412218	et	4	main
tahtma	doc_441779960551_item	2412022	et	3	main
eest	doc_441779960551_item	2412039	et	4	main
essee	doc_441779960552_item	2412057	et	4	main
midagi	doc_441779960552_item	2412060	et	4	main
inimene	doc_441779960552_item	2412065	et	3	main
varem	doc_441779960552_item	2412073	et	4	main
olid	doc_441779960552_item	2412074	et	4	main
ühed	doc_441779960552_item	2412075	et	3	main
hirmud	doc_441779960552_item	2412076	et	4	main
karti	doc_441779960552_item	2412077	et	4	main
äikest	doc_441779960552_item	2412078	et	4	main
või	doc_441779960552_item	2412079	et	4	main
jumala	doc_441779960552_item	2412080	et	3	main
karistust	doc_441779960552_item	2412081	et	4	main
praegused	doc_441779960552_item	2412082	et	3	main
hirmud	doc_441779960552_item	2412083	et	4	main
on	doc_441779960552_item	2412084	et	4	main
aga	doc_441779960552_item	2412085	et	3	main
teised	doc_441779960552_item	2412086	et	4	main
muutuvad	doc_441779960552_item	2412087	et	4	main
inimesed	doc_441779960552_item	2412088	et	3	main
muutub	doc_441779960552_item	2412089	et	3	main
elu	doc_441779960552_item	2412090	et	4	main
ja	doc_441779960552_item	2412091	et	3	main
kartused	doc_441779960552_item	2412092	et	3	main
ka	doc_441779960552_item	2412093	et	3	main
br	doc_441779960552_item	2412094	et	4	main
ausust	doc_441779960552_item	2412095	et	4	main
alati	doc_441779960552_item	2412096	et	4	main
väärtustati	doc_441779960552_item	2412097	et	4	main
iga	doc_441779960552_item	2412098	et	4	main
tööandja	doc_441779960552_item	2412099	et	4	main
soovib	doc_441779960552_item	2412100	et	3	main
et	doc_441779960552_item	2412101	et	3	main
tema	doc_441779960552_item	2412102	et	4	main
keda	doc_441779960552_item	2412108	et	4	main
samuti	doc_441779960552_item	2412112	et	3	main
et	doc_441779960552_item	2412116	et	3	main
see	doc_441779960552_item	2412130	et	3	main
aus	doc_441779960552_item	2412134	et	4	main
inimene	doc_441779960552_item	2412135	et	3	main
aus	doc_441779960552_item	2412136	et	4	main
inimene	doc_441779960552_item	2412137	et	3	main
selliseid	doc_441779960552_item	2412150	et	4	main
inimesi	doc_441779960552_item	2412151	et	4	main
kohta	doc_441779960552_item	2412163	et	4	main
püüan	doc_441779960552_item	2412167	et	3	main
te	doc_441779960552_item	2412196	et	4	main
mina	doc_441779960552_item	2412199	et	4	main
surm	doc_441779960552_item	2412205	et	3	main
perekonnale	doc_441779960552_item	2412209	et	4	main
kes	doc_441779960552_item	2412213	et	4	main
br	doc_441779960552_item	2412221	et	4	main
helistada	doc_441779960552_item	2412231	et	3	main
öelda	doc_441779960552_item	2412234	et	4	main
tõtt	doc_441779960552_item	2412235	et	4	main
see	doc_441779960552_item	2412236	et	3	main
seadust	doc_441779960552_item	2412240	et	4	main
aga	doc_441779960552_item	2412241	et	3	main
ülal	doc_441779960552_item	2412250	et	3	main
teda	doc_441779960552_item	2412254	et	4	main
kui	doc_441779960552_item	2412274	et	3	main
aus	doc_441779960552_item	2412277	et	4	main
ja	doc_441779960552_item	2412279	et	3	main
sa	doc_441779960552_item	2412281	et	3	main
tõtt	doc_441779960552_item	2412282	et	4	main
sinu	doc_441779960552_item	2412283	et	3	main
ees	doc_441779960552_item	2412284	et	4	main
seisab	doc_441779960552_item	2412285	et	3	main
samal	doc_441779960552_item	2412305	et	3	main
ka	doc_441779960552_item	2412308	et	3	main
saladuseks	doc_441779960552_item	2412310	et	3	main
kus	doc_441779960552_item	2412312	et	3	main
siis	doc_441779960552_item	2412314	et	3	main
vastus	doc_442386364033_item	2412323	et	3	main
2	doc_442386364033_item	2412329	et	2	main
inimgrupile	doc_442386364033_item	2412338	et	3	main
ja	doc_442386364033_item	2412341	et	3	main
kultuur	doc_442386364033_item	2412343	et	3	main
ilmneb	doc_442386364033_item	2412345	et	3	main
muistised	doc_442386364033_item	2412357	et	3	main
1	doc_442386364033_item	2412363	et	2	main
jaguneb	doc_442386364033_item	2412365	et	3	main
neoliitikumiks	doc_442386364033_item	2412368	et	3	main
vanem	doc_442386364033_item	2412370	et	4	main
raske	doc_442386364033_item	2412373	et	4	main
mingeid	doc_442386364033_item	2412375	et	3	main
kultuurikiht	doc_442386364033_item	2412378	et	3	main
mandrijää	doc_442386364033_item	2412383	et	4	main
sellel	doc_442386364033_item	2412425	et	4	main
tööriistu	doc_442386364033_item	2412427	et	3	main
elatusaladeks	doc_442386364033_item	2412434	et	3	main
juustega	doc_442386364033_item	2412451	et	3	main
tulnud	doc_442386364033_item	2412455	et	4	main
sõnad	doc_442386364033_item	2412456	et	4	main
elementidega	doc_442386364033_item	2412460	et	3	main
inimene	doc_442386364033_item	2412484	et	3	main
neoliitikum	doc_442386364033_item	2412489	et	3	main
on	doc_442386364033_item	2412490	et	4	main
eesti	doc_442386364033_item	2412509	et	4	main
territooriumile	doc_442386364033_item	2412510	et	3	main
elamiskohti	doc_442386364033_item	2412514	et	4	main
süüa	doc_442386364033_item	2412518	et	3	main
lõke	doc_442386364033_item	2412520	et	4	main
neoliitikumi	doc_442386364033_item	2412522	et	4	main
on	doc_442386364033_item	2412533	et	4	main
kõige	doc_442386364033_item	2412534	et	4	main
venemaal	doc_442386364033_item	2412540	et	4	main
l	doc_442386364033_item	2412542	et	4	main
tehti	doc_442386364033_item	2412546	et	3	main
taimi	doc_442386364033_item	2412555	et	4	main
at	doc_442386364033_item	2412558	et	4	main
soome-ugri	doc_442386364033_item	2412575	et	3	main
kasutatud	doc_442386364033_item	2412581	et	4	main
matmiskomme	doc_442386364033_item	2412628	et	4	main
matma	doc_442386364033_item	2412631	et	3	main
nad	doc_442386364033_item	2412637	et	3	main
püüab	doc_441779960552_item	2412124	et	3	main
ausaks	doc_441779960552_item	2412127	et	4	main
räägib	doc_441779960552_item	2412139	et	3	main
ei	doc_441779960552_item	2412142	et	4	main
hoia	doc_441779960552_item	2412143	et	4	main
seda	doc_441779960552_item	2412144	et	3	main
neid	doc_441779960552_item	2412154	et	4	main
iseenda	doc_441779960552_item	2412162	et	3	main
öelda	doc_441779960552_item	2412165	et	4	main
inimeseks	doc_441779960552_item	2412170	et	3	main
kui	doc_441779960552_item	2412171	et	3	main
tõtt	doc_441779960552_item	2412172	et	4	main
võib	doc_441779960552_item	2412173	et	3	main
kellelegi	doc_441779960552_item	2412174	et	4	main
paha	doc_441779960552_item	2412175	et	4	main
teha	doc_441779960552_item	2412176	et	3	main
ja	doc_441779960552_item	2412177	et	3	main
kui	doc_441779960552_item	2412178	et	3	main
mind	doc_441779960552_item	2412179	et	4	main
võivad	doc_441779960552_item	2412180	et	4	main
ülesandjaks	doc_441779960552_item	2412181	et	3	main
nimetada	doc_441779960552_item	2412182	et	3	main
ma	doc_441779960552_item	2412183	et	3	main
hoian	doc_441779960552_item	2412184	et	3	main
see	doc_441779960552_item	2412185	et	3	main
kinni	doc_441779960552_item	2412186	et	3	main
br	doc_441779960552_item	2412187	et	4	main
mida	doc_441779960552_item	2412188	et	4	main
teeksite	doc_441779960552_item	2412189	et	3	main
teie	doc_441779960552_item	2412190	et	4	main
kuid	doc_441779960552_item	2412191	et	4	main
teile	doc_441779960552_item	2412192	et	4	main
küll	doc_441779960552_item	2412200	et	4	main
toob	doc_441779960552_item	2412206	et	3	main
minu	doc_441779960552_item	2412208	et	3	main
neid	doc_441779960552_item	2412212	et	4	main
selle	doc_441779960552_item	2412217	et	4	main
oma	doc_441779960552_item	2412219	et	4	main
eluga	doc_441779960552_item	2412220	et	3	main
kui	doc_441779960552_item	2412225	et	3	main
tegeleb	doc_441779960552_item	2412227	et	3	main
levimisega	doc_441779960552_item	2412229	et	4	main
politseisse	doc_441779960552_item	2412232	et	3	main
on	doc_441779960552_item	2412243	et	4	main
lapsed	doc_441779960552_item	2412244	et	3	main
ja	doc_441779960552_item	2412245	et	3	main
tal	doc_441779960552_item	2412246	et	3	main
on	doc_441779960552_item	2412247	et	4	main
pidada	doc_441779960552_item	2412251	et	4	main
kui	doc_441779960552_item	2412253	et	3	main
lapsi	doc_441779960552_item	2412256	et	4	main
sa	doc_441779960552_item	2412275	et	3	main
valik	doc_441779960552_item	2412286	et	3	main
tahame	doc_441779960552_item	2412296	et	3	main
meid	doc_441779960552_item	2412298	et	4	main
meiega	doc_441779960552_item	2412302	et	4	main
ausad	doc_441779960552_item	2412303	et	3	main
võiksid	doc_441779960552_item	2412307	et	4	main
hoida	doc_441779960552_item	2412311	et	3	main
tõeline	doc_441779960552_item	2412315	et	4	main
ausus	doc_441779960552_item	2412316	et	4	main
1	doc_442386364033_item	2412325	et	2	main
teatud	doc_442386364033_item	2412337	et	4	main
vaimne	doc_442386364033_item	2412342	et	3	main
arheoloogilise	doc_442386364033_item	2412346	et	4	main
uurimistöö	doc_442386364033_item	2412347	et	4	main
sarnased	doc_442386364033_item	2412354	et	4	main
kindel	doc_442386364033_item	2412359	et	3	main
paleoliitikumiks	doc_442386364033_item	2412366	et	3	main
kuna	doc_442386364033_item	2412377	et	3	main
kaua	doc_442386364033_item	2412381	et	3	main
sest	doc_441779960552_item	2412203	et	4	main
õnnetust	doc_441779960552_item	2412207	et	4	main
maksaks	doc_441779960552_item	2412216	et	4	main
ajal	doc_441779960552_item	2412223	et	4	main
naine	doc_441779960552_item	2412237	et	3	main
vastu	doc_441779960552_item	2412239	et	3	main
tal	doc_441779960552_item	2412242	et	3	main
neid	doc_441779960552_item	2412249	et	4	main
üksinda	doc_441779960552_item	2412252	et	4	main
oled	doc_441779960552_item	2412276	et	3	main
inimene	doc_441779960552_item	2412278	et	3	main
kas	doc_441779960552_item	2412287	et	3	main
või	doc_441779960552_item	2412290	et	4	main
kõik	doc_441779960552_item	2412295	et	4	main
aga	doc_441779960552_item	2412304	et	3	main
midagi	doc_441779960552_item	2412309	et	4	main
kuidas	doc_441779960552_item	2412318	et	3	main
näiteks	doc_441779960552_item	2412224	et	4	main
naine	doc_441779960552_item	2412226	et	3	main
tegutseb	doc_441779960552_item	2412238	et	3	main
saadetakse	doc_441779960552_item	2412257	et	3	main
lastekoju	doc_441779960552_item	2412258	et	4	main
kas	doc_441779960552_item	2412259	et	3	main
see	doc_441779960552_item	2412260	et	3	main
on	doc_441779960552_item	2412261	et	4	main
parim	doc_441779960552_item	2412262	et	4	main
koht	doc_441779960552_item	2412263	et	3	main
nende	doc_441779960552_item	2412264	et	4	main
jaoks	doc_441779960552_item	2412265	et	4	main
br	doc_441779960552_item	2412266	et	4	main
tõe	doc_441779960552_item	2412267	et	4	main
avaldamine	doc_441779960552_item	2412268	et	4	main
ei	doc_441779960552_item	2412269	et	4	main
ole	doc_441779960552_item	2412270	et	4	main
alati	doc_441779960552_item	2412271	et	4	main
hea	doc_441779960552_item	2412272	et	4	main
tegevus	doc_441779960552_item	2412273	et	4	main
tead	doc_441779960552_item	2412280	et	4	main
tegutsema	doc_441779960552_item	2412288	et	3	main
süda	doc_441779960552_item	2412291	et	3	main
br	doc_441779960552_item	2412293	et	4	main
et	doc_441779960552_item	2412297	et	3	main
ümbritsevad	doc_441779960552_item	2412299	et	4	main
inimesed	doc_441779960552_item	2412300	et	3	main
on	doc_441779960552_item	2412313	et	4	main
ta	doc_441779960552_item	2412319	et	4	main
näeb	doc_441779960552_item	2412321	et	3	main
eesti	doc_442386364033_item	2412327	et	4	main
territooriumil	doc_442386364033_item	2412328	et	3	main
arheoloogiline	doc_442386364033_item	2412331	et	4	main
kultuur	doc_442386364033_item	2412332	et	3	main
arheoloogiline	doc_442386364033_item	2412335	et	4	main
kultuur	doc_442386364033_item	2412336	et	3	main
igale	doc_442386364033_item	2412349	et	3	main
arheoloogilise	doc_442386364033_item	2412350	et	4	main
ja	doc_442386364033_item	2412356	et	3	main
ning	doc_442386364033_item	2412358	et	3	main
ajajärk	doc_442386364033_item	2412362	et	3	main
kiviaeg	doc_442386364033_item	2412364	et	3	main
paleoliitikum	doc_442386364033_item	2412369	et	3	main
väga	doc_442386364033_item	2412372	et	3	main
peatuspaiku	doc_442386364033_item	2412376	et	3	main
oli	doc_442386364033_item	2412379	et	3	main
püsis	doc_442386364033_item	2412382	et	4	main
mesoliitikum	doc_442386364033_item	2412384	et	3	main
lõuna	doc_442386364033_item	2412421	et	4	main
nt	doc_442386364033_item	2412431	et	4	main
odaotsad	doc_442386364033_item	2412433	et	3	main
olid	doc_442386364033_item	2412435	et	4	main
küttimine	doc_442386364033_item	2412436	et	4	main
hülged	doc_442386364033_item	2412437	et	3	main
metshobused	doc_442386364033_item	2412438	et	4	main
kalapüük	doc_442386364033_item	2412442	et	3	main
mesoliitikumi	doc_442386364033_item	2412445	et	4	main
oli	doc_442386364033_item	2412447	et	3	main
on	doc_442386364033_item	2412457	et	4	main
ja	doc_442386364033_item	2412461	et	3	main
a	doc_442386364033_item	2412475	et	4	main
aluse	doc_442386364033_item	2412478	et	4	main
kiviaeg	doc_442386364033_item	2412483	et	3	main
tarkemaks	doc_442386364033_item	2412486	et	3	main
hakkab	doc_442386364033_item	2412498	et	3	main
ja	doc_442386364033_item	2412503	et	3	main
sellel	doc_442386364033_item	2412506	et	4	main
hakkavad	doc_442386364033_item	2412508	et	4	main
püstkodades	doc_442386364033_item	2412517	et	3	main
tehti	doc_442386364033_item	2412519	et	3	main
nii	doc_442386364033_item	2412536	et	3	main
ka	doc_442386364033_item	2412539	et	3	main
kammkeraamika	doc_442386364033_item	2412556	et	4	main
ekr	doc_442386364033_item	2412559	et	4	main
kannab	doc_442386364033_item	2412560	et	3	main
sellise	doc_442386364033_item	2412561	et	4	main
nimi	doc_442386364033_item	2412562	et	3	main
sest	doc_442386364033_item	2412563	et	4	main
esemetel	doc_442386364033_item	2412564	et	3	main
oli	doc_442386364033_item	2412565	et	3	main
muster	doc_442386364033_item	2412566	et	3	main
hilis	doc_442386364033_item	2412582	et	4	main
keraamika	doc_442386364033_item	2412587	et	4	main
tüüp	doc_442386364033_item	2412588	et	3	main
at	doc_442386364033_item	2412591	et	4	main
sellel	doc_442386364033_item	2412621	et	4	main
tuleb	doc_442386364033_item	2412623	et	3	main
uus	doc_442386364033_item	2412626	et	3	main
komme	doc_442386364033_item	2412627	et	4	main
surmust	doc_442386364033_item	2412643	et	3	main
35-40	doc_442386364033_item	2412646	et	2	main
aastat	doc_442386364033_item	2412647	et	3	main
pärast	doc_442386364033_item	2412655	et	4	main
hakati	doc_442386364033_item	2412656	et	3	main
inimesi	doc_442386364033_item	2412657	et	4	main
matma	doc_442386364033_item	2412658	et	3	main
asulas	doc_442386364033_item	2412659	et	3	main
kiviaeg	doc_442386364034_item	2412673	et	3	main
7500	doc_442386364034_item	2412682	et	2	main
kaldal	doc_442386364034_item	2412687	et	3	main
lähedal	doc_442386364034_item	2412689	et	4	main
seaduse	doc_441779960552_item	2412289	et	3	main
järgi	doc_441779960552_item	2412292	et	4	main
meie	doc_441779960552_item	2412294	et	4	main
olid	doc_441779960552_item	2412301	et	4	main
ajal	doc_441779960552_item	2412306	et	4	main
ja	doc_441779960552_item	2412317	et	3	main
välja	doc_441779960552_item	2412320	et	4	main
body	doc_441779960552_item	2412322	et	4	main
küsimusele	doc_442386364033_item	2412324	et	4	main
materiaalne	doc_442386364033_item	2412340	et	3	main
käigus	doc_442386364033_item	2412348	et	4	main
leiud	doc_442386364033_item	2412355	et	3	main
ja	doc_442386364033_item	2412361	et	3	main
mesoliitikumiks	doc_442386364033_item	2412367	et	3	main
kiviaeg	doc_442386364033_item	2412371	et	3	main
tulid	doc_442386364033_item	2412420	et	4	main
valgevene	doc_442386364033_item	2412424	et	4	main
ajal	doc_442386364033_item	2412426	et	4	main
valmistati	doc_442386364033_item	2412428	et	4	main
kitsa	doc_442386364033_item	2412448	et	3	main
tagasi	doc_442386364033_item	2412476	et	3	main
saab	doc_442386364033_item	2412485	et	3	main
ja	doc_442386364033_item	2412487	et	3	main
korilaste	doc_442386364033_item	2412494	et	3	main
õitseaeg	doc_442386364033_item	2412495	et	3	main
eesti	doc_442386364033_item	2412496	et	4	main
territooriumil	doc_442386364033_item	2412497	et	3	main
välja	doc_442386364033_item	2412500	et	4	main
materiaalne	doc_442386364033_item	2412502	et	3	main
tulema	doc_442386364033_item	2412511	et	4	main
on	doc_442386364033_item	2412526	et	4	main
vanem	doc_442386364033_item	2412535	et	4	main
eestis	doc_442386364033_item	2412537	et	3	main
teokarpe	doc_442386364033_item	2412552	et	4	main
ja	doc_442386364033_item	2412553	et	3	main
isegi	doc_442386364033_item	2412554	et	4	main
kammi	doc_442386364033_item	2412567	et	4	main
joonistama	doc_442386364033_item	2412574	et	3	main
kultuuri	doc_442386364033_item	2412577	et	4	main
loodusmotiive	doc_442386364033_item	2412579	et	3	main
ilmus	doc_442386364033_item	2412584	et	4	main
üks	doc_442386364033_item	2412586	et	3	main
kiviaeg	doc_442386364033_item	2412326	et	3	main
mõiste	doc_442386364033_item	2412330	et	4	main
tähendus	doc_442386364033_item	2412333	et	4	main
2	doc_442386364033_item	2412334	et	2	main
iseloomulik	doc_442386364033_item	2412339	et	3	main
mis	doc_442386364033_item	2412344	et	4	main
kultuurile	doc_442386364033_item	2412351	et	3	main
on	doc_442386364033_item	2412352	et	4	main
omased	doc_442386364033_item	2412353	et	3	main
territoorium	doc_442386364033_item	2412360	et	3	main
avastada	doc_442386364033_item	2412374	et	3	main
õhuke	doc_442386364033_item	2412380	et	4	main
keskmine	doc_442386364033_item	2412385	et	3	main
kiviaeg	doc_442386364033_item	2412386	et	3	main
ix	doc_442386364033_item	2412387	et	4	main
at	doc_442386364033_item	2412388	et	4	main
lõpp	doc_442386364033_item	2412389	et	3	main
iv	doc_442386364033_item	2412390	et	4	main
at	doc_442386364033_item	2412391	et	4	main
kesk	doc_442386364033_item	2412392	et	3	main
ekr	doc_442386364033_item	2412393	et	4	main
asustus	doc_442386364033_item	2412394	et	4	main
eesti	doc_442386364033_item	2412395	et	4	main
territooriumil	doc_442386364033_item	2412396	et	3	main
toimus	doc_442386364033_item	2412397	et	3	main
mesoliitikumis	doc_442386364033_item	2412398	et	3	main
kõige	doc_442386364033_item	2412399	et	4	main
vanem	doc_442386364033_item	2412400	et	4	main
asula	doc_442386364033_item	2412401	et	4	main
pulli	doc_442386364033_item	2412402	et	4	main
kütid	doc_442386364033_item	2412403	et	4	main
asub	doc_442386364033_item	2412404	et	3	main
pärnu	doc_442386364033_item	2412405	et	4	main
jõe	doc_442386364033_item	2412406	et	3	main
ääres	doc_442386364033_item	2412407	et	4	main
kultuur	doc_442386364033_item	2412409	et	3	main
on	doc_442386364033_item	2412410	et	4	main
ka	doc_442386364033_item	2412411	et	3	main
väga	doc_442386364033_item	2412412	et	3	main
vana	doc_442386364033_item	2412413	et	4	main
kalevid	doc_442386364033_item	2412414	et	3	main
kunda	doc_442386364033_item	2412408	et	4	main
arvatakse	doc_442386364033_item	2412415	et	3	main
et	doc_442386364033_item	2412416	et	3	main
kalevid	doc_442386364033_item	2412417	et	3	main
ja	doc_442386364033_item	2412418	et	3	main
kütid	doc_442386364033_item	2412419	et	4	main
leedu	doc_442386364033_item	2412423	et	4	main
noolotsad	doc_442386364033_item	2412432	et	3	main
karu	doc_442386364033_item	2412440	et	4	main
põder	doc_442386364033_item	2412441	et	3	main
korjamine	doc_442386364033_item	2412444	et	4	main
inimene	doc_442386364033_item	2412446	et	3	main
näoga	doc_442386364033_item	2412449	et	3	main
mesoliitikumist	doc_442386364033_item	2412454	et	4	main
pani	doc_442386364033_item	2412477	et	4	main
eesti	doc_442386364033_item	2412479	et	4	main
neoliitikum	doc_442386364033_item	2412481	et	3	main
noorem	doc_442386364033_item	2412482	et	4	main
kujunema	doc_442386364033_item	2412499	et	3	main
vaimne	doc_442386364033_item	2412504	et	3	main
inimesed	doc_442386364033_item	2412513	et	3	main
otsida	doc_442386364033_item	2412515	et	4	main
tegemine	doc_442386364033_item	2412530	et	4	main
narva	doc_442386364033_item	2412531	et	4	main
keraamika	doc_442386364033_item	2412532	et	4	main
kui	doc_442386364033_item	2412538	et	3	main
euroopas	doc_442386364033_item	2412543	et	3	main
keraamikat	doc_442386364033_item	2412545	et	3	main
kujuline	doc_442386364033_item	2412568	et	4	main
kujundeid	doc_442386364033_item	2412573	et	3	main
neoliitikumis	doc_442386364033_item	2412583	et	3	main
veel	doc_442386364033_item	2412585	et	4	main
nöörkeraamika	doc_442386364033_item	2412589	et	4	main
eesti	doc_442386364033_item	2412624	et	4	main
territooriumile	doc_442386364033_item	2412625	et	3	main
maeti	doc_442386364033_item	2412633	et	3	main
karti	doc_442386364033_item	2412644	et	4	main
elati	doc_442386364033_item	2412645	et	3	main
maeti	doc_442386364033_item	2412651	et	3	main
püstkoda	doc_442386364033_item	2412653	et	4	main
mõiste	doc_442386364034_item	2412677	et	4	main
kultuur	doc_442386364034_item	2412679	et	3	main
tähendus	doc_442386364034_item	2412680	et	4	main
1	doc_442386364034_item	2412681	et	2	main
pärnu	doc_442386364034_item	2412685	et	4	main
tähendab	doc_442386364034_item	2412696	et	3	main
3000	doc_442386364034_item	2412705	et	2	main
nad	doc_442386364034_item	2412708	et	3	main
sellelt	doc_442386364034_item	2412718	et	4	main
ja	doc_442386364034_item	2412722	et	3	main
oli	doc_442386364034_item	2412726	et	3	main
kalastajate	doc_442386364034_item	2412727	et	4	main
jahimeeste	doc_442386364034_item	2412728	et	4	main
ja	doc_442386364034_item	2412729	et	3	main
korjajate	doc_442386364034_item	2412731	et	4	main
hauk	doc_442386364034_item	2412741	et	4	main
kitse	doc_442386364034_item	2412749	et	4	main
ja	doc_442386364034_item	2412750	et	3	main
valmistati	doc_442386364034_item	2412755	et	4	main
savist	doc_442386364034_item	2412757	et	4	main
ja	doc_442386364034_item	2412758	et	3	main
kivist	doc_442386364034_item	2412759	et	4	main
tehtud	doc_442386364034_item	2412771	et	4	main
10-70	doc_442386364034_item	2412778	et	2	main
moodustasid	doc_442386364034_item	2412780	et	4	main
oli	doc_442386364034_item	2412821	et	3	main
eriti	doc_442386364034_item	2412826	et	3	main
tähendus	doc_442386364034_item	2412830	et	4	main
merevaiku	doc_442386364034_item	2412831	et	4	main
isegi	doc_442386364034_item	2412833	et	4	main
inimese	doc_442386364034_item	2412835	et	4	main
silmadele	doc_442386364034_item	2412836	et	3	main
surnuid	doc_442386364034_item	2412837	et	4	main
tavaline	doc_442386364034_item	2412848	et	4	main
e	doc_442386364034_item	2412852	et	4	main
aa	doc_442386364034_item	2412855	et	3	main
inimesed	doc_442386364034_item	2412859	et	3	main
tegelema	doc_442386364034_item	2412861	et	3	main
savist	doc_442386364034_item	2412874	et	4	main
nööri	doc_442386364034_item	2412907	et	4	main
abil	doc_442386364034_item	2412908	et	4	main
venekirvestel	doc_442386364034_item	2412911	et	4	main
võhandu	doc_442386364034_item	2412918	et	4	main
põhjal	doc_442386364034_item	2412920	et	4	main
väga	doc_442386364034_item	2412936	et	3	main
tööriistad	doc_442386364034_item	2412940	et	3	main
poolt	doc_442386364033_item	2412422	et	4	main
puust	doc_442386364033_item	2412429	et	4	main
kivist	doc_442386364033_item	2412430	et	4	main
siga	doc_442386364033_item	2412439	et	4	main
loodusandide	doc_442386364033_item	2412443	et	3	main
sirgete	doc_442386364033_item	2412450	et	4	main
tumedama	doc_442386364033_item	2412452	et	4	main
nahaga	doc_442386364033_item	2412453	et	3	main
seotud	doc_442386364033_item	2412458	et	4	main
maastiku	doc_442386364033_item	2412459	et	4	main
kalade	doc_442386364033_item	2412462	et	3	main
nimedega	doc_442386364033_item	2412463	et	3	main
neem	doc_442386364033_item	2412464	et	3	main
meri	doc_442386364033_item	2412465	et	3	main
mägi	doc_442386364033_item	2412466	et	3	main
mets	doc_442386364033_item	2412467	et	3	main
haug	doc_442386364033_item	2412469	et	3	main
arvatakse	doc_442386364033_item	2412470	et	3	main
et	doc_442386364033_item	2412471	et	3	main
soo	doc_442386364033_item	2412468	et	4	main
kunda	doc_442386364033_item	2412472	et	4	main
kultuur	doc_442386364033_item	2412473	et	3	main
10000	doc_442386364033_item	2412474	et	2	main
ajaloole	doc_442386364033_item	2412480	et	4	main
osalevamaks	doc_442386364033_item	2412488	et	4	main
kalastajate	doc_442386364033_item	2412491	et	4	main
küttide	doc_442386364033_item	2412492	et	3	main
ja	doc_442386364033_item	2412493	et	3	main
paikkondlik	doc_442386364033_item	2412501	et	3	main
kultuur	doc_442386364033_item	2412505	et	3	main
ajal	doc_442386364033_item	2412507	et	4	main
võõrad	doc_442386364033_item	2412512	et	3	main
elati	doc_442386364033_item	2412516	et	3	main
peal	doc_442386364033_item	2412521	et	4	main
kõige	doc_442386364033_item	2412523	et	4	main
tähtsamaks	doc_442386364033_item	2412524	et	4	main
tunnuseks	doc_442386364033_item	2412525	et	3	main
keraamika	doc_442386364033_item	2412527	et	4	main
savist	doc_442386364033_item	2412528	et	4	main
nõude	doc_442386364033_item	2412529	et	4	main
ja	doc_442386364033_item	2412541	et	3	main
narva	doc_442386364033_item	2412544	et	4	main
jämedast	doc_442386364033_item	2412547	et	3	main
savist	doc_442386364033_item	2412548	et	4	main
sisse	doc_442386364033_item	2412549	et	4	main
segati	doc_442386364033_item	2412550	et	3	main
kivipudru	doc_442386364033_item	2412551	et	3	main
iv	doc_442386364033_item	2412557	et	4	main
pärast	doc_442386364033_item	2412569	et	4	main
hakati	doc_442386364033_item	2412570	et	3	main
ka	doc_442386364033_item	2412571	et	3	main
geomeetrilisi	doc_442386364033_item	2412572	et	4	main
rahva	doc_442386364033_item	2412576	et	3	main
tunnus	doc_442386364033_item	2412578	et	3	main
ei	doc_442386364033_item	2412580	et	4	main
iii	doc_442386364033_item	2412590	et	4	main
ekr	doc_442386364033_item	2412592	et	4	main
muster	doc_442386364033_item	2412593	et	3	main
oli	doc_442386364033_item	2412594	et	3	main
nagu	doc_442386364033_item	2412595	et	3	main
nööri	doc_442386364033_item	2412596	et	4	main
tehtud	doc_442386364033_item	2412598	et	4	main
vahendil	doc_442386364033_item	2412597	et	3	main
hilisneoliitikum	doc_442386364033_item	2412599	et	3	main
neoliitikumi	doc_442386364033_item	2412600	et	4	main
ii	doc_442386364033_item	2412601	et	4	main
pool	doc_442386364033_item	2412602	et	4	main
ajal	doc_442386364033_item	2412604	et	4	main
sellel	doc_442386364033_item	2412603	et	4	main
inimesed	doc_442386364033_item	2412605	et	3	main
kasvatasid	doc_442386364033_item	2412606	et	4	main
loomi	doc_442386364033_item	2412607	et	4	main
veised	doc_442386364033_item	2412608	et	3	main
sead	doc_442386364033_item	2412609	et	4	main
kasvatati	doc_442386364033_item	2412610	et	3	main
neid	doc_442386364033_item	2412611	et	4	main
enda	doc_442386364033_item	2412612	et	4	main
tarbeks	doc_442386364033_item	2412613	et	3	main
on	doc_442386364033_item	2412614	et	4	main
leitud	doc_442386364033_item	2412615	et	4	main
jälge	doc_442386364033_item	2412616	et	4	main
et	doc_442386364033_item	2412617	et	3	main
osati	doc_442386364033_item	2412618	et	3	main
vilja	doc_442386364033_item	2412619	et	4	main
kasvatada	doc_442386364033_item	2412620	et	3	main
hakati	doc_442386364033_item	2412629	et	3	main
ajal	doc_442386364033_item	2412622	et	4	main
inimesi	doc_442386364033_item	2412634	et	4	main
nagu	doc_442386364033_item	2412636	et	3	main
tavaliselt	doc_442386364033_item	2412638	et	4	main
hauda	doc_442386364033_item	2412640	et	4	main
pandi	doc_442386364033_item	2412641	et	4	main
tööriistu	doc_442386364033_item	2412642	et	3	main
eest	doc_442386364033_item	2412649	et	4	main
või	doc_442386364033_item	2412660	et	4	main
väljas	doc_442386364033_item	2412661	et	4	main
pool	doc_442386364033_item	2412662	et	4	main
see	doc_442386364033_item	2412663	et	3	main
sõltus	doc_442386364033_item	2412664	et	4	main
inimesest	doc_442386364033_item	2412665	et	3	main
austati	doc_442386364033_item	2412666	et	3	main
teda	doc_442386364033_item	2412667	et	4	main
või	doc_442386364033_item	2412668	et	4	main
ei	doc_442386364033_item	2412669	et	4	main
vastus	doc_442386364034_item	2412670	et	3	main
küsimusele	doc_442386364034_item	2412671	et	4	main
1	doc_442386364034_item	2412672	et	2	main
inimesi	doc_442386364033_item	2412630	et	4	main
esialgu	doc_442386364033_item	2412632	et	3	main
nii	doc_442386364033_item	2412635	et	3	main
magasid	doc_442386364033_item	2412639	et	4	main
surnute	doc_442386364033_item	2412648	et	4	main
arheoloogiline	doc_442386364034_item	2412678	et	4	main
eesti	doc_442386364034_item	2412694	et	4	main
nahka	doc_442386364034_item	2412721	et	4	main
keskmine	doc_442386364034_item	2412724	et	3	main
õitsenguaeg	doc_442386364034_item	2412732	et	4	main
ajalt	doc_442386364034_item	2412734	et	4	main
peale	doc_442386364034_item	2412743	et	4	main
küttisid	doc_442386364034_item	2412745	et	4	main
mehed	doc_442386364034_item	2412746	et	3	main
ka	doc_442386364034_item	2412747	et	3	main
töö-	doc_442386364034_item	2412752	et	4	main
puust	doc_442386364034_item	2412756	et	4	main
asus	doc_442386364034_item	2412784	et	4	main
mille	doc_442386364034_item	2412786	et	3	main
ajal	doc_442386364034_item	2412820	et	4	main
magab	doc_442386364034_item	2412842	et	3	main
kindel	doc_442386364034_item	2412846	et	3	main
neoliitikum	doc_442386364034_item	2412853	et	3	main
keraamika	doc_442386364034_item	2412865	et	4	main
aa	doc_442386364034_item	2412870	et	3	main
kuhu	doc_442386364034_item	2412875	et	3	main
isegi	doc_442386364034_item	2412916	et	4	main
hoolitseti	doc_442386364033_item	2412650	et	3	main
inimesi	doc_442386364033_item	2412652	et	4	main
alla	doc_442386364033_item	2412654	et	3	main
2	doc_442386364034_item	2412676	et	2	main
a	doc_442386364034_item	2412683	et	4	main
jõe	doc_442386364034_item	2412686	et	3	main
sindi	doc_442386364034_item	2412688	et	4	main
territooriumil	doc_442386364034_item	2412695	et	3	main
ainult	doc_442386364034_item	2412702	et	4	main
mesoliitikumis	doc_442386364034_item	2412703	et	3	main
hea	doc_442386364034_item	2412716	et	4	main
saak	doc_442386364034_item	2412717	et	3	main
tehti	doc_442386364034_item	2412762	et	3	main
elati	doc_442386364034_item	2412767	et	3	main
koonusekujulistes	doc_442386364034_item	2412769	et	4	main
kodukondadega	doc_442386364034_item	2412781	et	4	main
keskel	doc_442386364034_item	2412783	et	3	main
peal	doc_442386364034_item	2412787	et	4	main
sest	doc_442386364034_item	2412818	et	4	main
animistlik	doc_442386364034_item	2412822	et	3	main
usund	doc_442386364034_item	2412823	et	3	main
amuletidel	doc_442386364034_item	2412825	et	4	main
päikesekivist	doc_442386364034_item	2412827	et	4	main
oli	doc_442386364034_item	2412828	et	3	main
maeti	doc_442386364034_item	2412838	et	3	main
asendis	doc_442386364034_item	2412839	et	3	main
nagu	doc_442386364034_item	2412840	et	3	main
ta	doc_442386364034_item	2412841	et	4	main
vanem	doc_442386364034_item	2412850	et	4	main
ekr	doc_442386364034_item	2412856	et	4	main
pool	doc_442386364034_item	2412858	et	4	main
kõige	doc_442386364034_item	2412863	et	4	main
vanem	doc_442386364034_item	2412864	et	4	main
3000-2200	doc_442386364034_item	2412869	et	2	main
tehti	doc_442386364034_item	2412872	et	3	main
tehtud	doc_442386364034_item	2412909	et	4	main
suur	doc_442386364034_item	2412913	et	3	main
ohverdati	doc_442386364034_item	2412917	et	3	main
jõe	doc_442386364034_item	2412919	et	3	main
on	doc_442386364034_item	2412921	et	4	main
teha	doc_442386364034_item	2412938	et	3	main
matmiskombed	doc_442386364034_item	2412949	et	3	main
haua	doc_442386364034_item	2412957	et	3	main
arheoloogiline	doc_442386364034_item	2412967	et	4	main
eluviis	doc_442386364034_item	2412972	et	3	main
grosberg	doc_446076497168_item	2413001	et	4	main
ja	doc_446076497168_item	2413002	et	3	main
sõbrad	doc_446076497168_item	2413003	et	3	main
tõlgis	doc_446076497168_item	2413004	et	3	main
janno	doc_446076497168_item	2413005	et	4	main
kuidas	doc_446076497168_item	2413011	et	3	main
ei	doc_446076497168_item	2413018	et	4	main
leidnud	doc_446076497168_item	2413019	et	4	main
üldse	doc_446076497168_item	2413020	et	3	main
eesti	doc_442386364034_item	2412674	et	4	main
territooriumil	doc_442386364034_item	2412675	et	3	main
ekr	doc_442386364034_item	2412684	et	4	main
asula	doc_442386364034_item	2412693	et	4	main
eesti	doc_442386364034_item	2412697	et	4	main
esimesed	doc_442386364034_item	2412700	et	3	main
aa	doc_442386364034_item	2412706	et	3	main
ekr	doc_442386364034_item	2412707	et	4	main
olid	doc_442386364034_item	2412709	et	4	main
oli	doc_442386364034_item	2412712	et	3	main
tol	doc_442386364034_item	2412713	et	3	main
ajal	doc_442386364034_item	2412714	et	4	main
väga	doc_442386364034_item	2412715	et	3	main
liha	doc_442386364034_item	2412720	et	4	main
pulli	doc_442386364034_item	2412690	et	4	main
küla	doc_442386364034_item	2412691	et	4	main
esimene	doc_442386364034_item	2412692	et	3	main
territooriumile	doc_442386364034_item	2412698	et	3	main
asusid	doc_442386364034_item	2412699	et	4	main
inimesed	doc_442386364034_item	2412701	et	3	main
7500	doc_442386364034_item	2412704	et	2	main
põhjapõtraküttid	doc_442386364034_item	2412710	et	4	main
põder	doc_442386364034_item	2412711	et	3	main
saadi	doc_442386364034_item	2412719	et	4	main
metsaandide	doc_442386364034_item	2412730	et	3	main
põhjapõtra	doc_442386364034_item	2412744	et	4	main
metssiga	doc_442386364034_item	2412748	et	4	main
ja	doc_442386364034_item	2412753	et	3	main
väiksemaid	doc_442386364034_item	2412760	et	4	main
isegi	doc_442386364034_item	2412763	et	4	main
tulekivist	doc_442386364034_item	2412764	et	4	main
ja	doc_442386364034_item	2412765	et	3	main
puitkodades	doc_442386364034_item	2412768	et	3	main
ehitistes	doc_442386364034_item	2412772	et	3	main
püstkojas	doc_442386364034_item	2412774	et	3	main
4-10	doc_442386364034_item	2412776	et	2	main
püstkoda	doc_442386364034_item	2412779	et	4	main
kolle	doc_442386364034_item	2412785	et	4	main
loomakujukesi	doc_442386364034_item	2412817	et	4	main
tol	doc_442386364034_item	2412819	et	3	main
rasva	doc_442386364034_item	2412723	et	4	main
kiviaeg	doc_442386364034_item	2412725	et	3	main
tolt	doc_442386364034_item	2412733	et	3	main
on	doc_442386364034_item	2412735	et	4	main
pärit	doc_442386364034_item	2412736	et	3	main
niisugused	doc_442386364034_item	2412737	et	3	main
kalanimetused	doc_442386364034_item	2412738	et	4	main
nagu	doc_442386364034_item	2412739	et	3	main
siig	doc_442386364034_item	2412740	et	3	main
rääbis	doc_442386364034_item	2412742	et	3	main
kobrast	doc_442386364034_item	2412751	et	4	main
jahiriistu	doc_442386364034_item	2412754	et	3	main
tööriistu	doc_442386364034_item	2412761	et	3	main
kvartsist	doc_442386364034_item	2412766	et	4	main
puuokstest	doc_442386364034_item	2412770	et	3	main
ühes	doc_442386364034_item	2412773	et	4	main
elas	doc_442386364034_item	2412775	et	3	main
inimest	doc_442386364034_item	2412777	et	3	main
püstkoja	doc_442386364034_item	2412782	et	3	main
küpsetati	doc_442386364034_item	2412788	et	3	main
toitu	doc_442386364034_item	2412789	et	4	main
tol	doc_442386364034_item	2412790	et	3	main
ajal	doc_442386364034_item	2412791	et	4	main
oli	doc_442386364034_item	2412792	et	3	main
väga	doc_442386364034_item	2412793	et	3	main
keeruline	doc_442386364034_item	2412794	et	4	main
usundite	doc_442386364034_item	2412795	et	3	main
süsteem	doc_442386364034_item	2412796	et	3	main
inimesed	doc_442386364034_item	2412797	et	3	main
hoolisid	doc_442386364034_item	2412798	et	4	main
surnu	doc_442386364034_item	2412799	et	4	main
keha	doc_442386364034_item	2412800	et	4	main
eest	doc_442386364034_item	2412801	et	4	main
surnuid	doc_442386364034_item	2412802	et	4	main
maeti	doc_442386364034_item	2412803	et	3	main
asula	doc_442386364034_item	2412804	et	4	main
territooriumile	doc_442386364034_item	2412805	et	3	main
vahel	doc_442386364034_item	2412806	et	4	main
isegi	doc_442386364034_item	2412807	et	4	main
püstkoja	doc_442386364034_item	2412808	et	3	main
põranda	doc_442386364034_item	2412809	et	3	main
alla	doc_442386364034_item	2412810	et	3	main
hauda	doc_442386364034_item	2412811	et	4	main
pandi	doc_442386364034_item	2412812	et	4	main
väikeseid	doc_442386364034_item	2412813	et	4	main
tööriistu	doc_442386364034_item	2412814	et	3	main
ja	doc_442386364034_item	2412815	et	3	main
mingi	doc_442386364034_item	2412816	et	4	main
surnu	doc_442386364034_item	2412834	et	4	main
ja	doc_442386364034_item	2412847	et	3	main
esimene	doc_442386364034_item	2412857	et	3	main
tüüp	doc_442386364034_item	2412866	et	3	main
narva	doc_442386364034_item	2412867	et	4	main
ekr	doc_442386364034_item	2412871	et	4	main
jämedast	doc_442386364034_item	2412873	et	3	main
sisse	doc_442386364034_item	2412876	et	4	main
segati	doc_442386364034_item	2412877	et	3	main
kiviputru	doc_442386364034_item	2412878	et	4	main
teokarpe	doc_442386364034_item	2412879	et	4	main
ja	doc_442386364034_item	2412880	et	3	main
taimi	doc_442386364034_item	2412881	et	4	main
kammkeraamika	doc_442386364034_item	2412882	et	4	main
2500-2200	doc_442386364034_item	2412883	et	2	main
järgmine	doc_442386364034_item	2412884	et	3	main
keraamikatüüp	doc_442386364034_item	2412885	et	4	main
terava	doc_442386364034_item	2412886	et	3	main
põhjaga	doc_442386364034_item	2412887	et	3	main
pajad	doc_442386364034_item	2412888	et	4	main
kaunistatud	doc_442386364034_item	2412889	et	4	main
geomeetriliste	doc_442386364034_item	2412890	et	4	main
kujunditega	doc_442386364034_item	2412891	et	3	main
ja	doc_442386364034_item	2412892	et	3	main
tehtud	doc_442386364034_item	2412893	et	4	main
kammi	doc_442386364034_item	2412894	et	4	main
abil	doc_442386364034_item	2412895	et	4	main
aukudega	doc_442386364034_item	2412896	et	3	main
e	doc_442386364034_item	2412898	et	4	main
venekirveste	doc_442386364034_item	2412899	et	4	main
kultuur	doc_442386364034_item	2412900	et	3	main
2200	doc_442386364034_item	2412901	et	2	main
nöörkeraamika	doc_442386364034_item	2412897	et	4	main
a	doc_442386364034_item	2412902	et	4	main
ekr	doc_442386364034_item	2412903	et	4	main
pajad	doc_442386364034_item	2412904	et	4	main
ja	doc_442386364034_item	2412824	et	3	main
suur	doc_442386364034_item	2412829	et	3	main
pandi	doc_442386364034_item	2412832	et	4	main
sest	doc_442386364034_item	2412843	et	4	main
surm	doc_442386364034_item	2412844	et	3	main
oli	doc_442386364034_item	2412845	et	3	main
asi	doc_442386364034_item	2412849	et	4	main
kiviaeg	doc_442386364034_item	2412851	et	3	main
3000-2500	doc_442386364034_item	2412854	et	2	main
hakkasid	doc_442386364034_item	2412860	et	4	main
keraamikaga	doc_442386364034_item	2412862	et	3	main
keraamika	doc_442386364034_item	2412868	et	4	main
mustriga	doc_442386364034_item	2412910	et	3	main
oli	doc_442386364034_item	2412912	et	3	main
neid	doc_442386364034_item	2412915	et	4	main
teisel	doc_442386364034_item	2412927	et	4	main
pool	doc_442386364034_item	2412928	et	4	main
inimesed	doc_442386364034_item	2412929	et	3	main
hakkasid	doc_442386364034_item	2412930	et	4	main
raske	doc_442386364034_item	2412937	et	4	main
muutusid	doc_442386364034_item	2412948	et	4	main
peale	doc_442386364034_item	2412952	et	4	main
suurte	doc_442386364034_item	2412953	et	3	main
keskele	doc_442386364034_item	2412958	et	3	main
pereisa	doc_442386364034_item	2412960	et	4	main
ümber	doc_442386364034_item	2412962	et	3	main
teisi	doc_442386364034_item	2412964	et	4	main
pereliikmeid	doc_442386364034_item	2412965	et	3	main
2	doc_442386364034_item	2412966	et	2	main
kõige	doc_446076497168_item	2413007	et	4	main
rohkem	doc_446076497168_item	2413008	et	4	main
on	doc_446076497168_item	2413012	et	4	main
ma	doc_446076497168_item	2413017	et	3	main
vigu	doc_446076497168_item	2413022	et	3	main
kõik	doc_446076497168_item	2413028	et	4	main
ilmus	doc_446076497168_item	2413029	et	4	main
õigel	doc_446076497168_item	2413030	et	3	main
lõppus	doc_446076497168_item	2413041	et	4	main
olid	doc_446076497168_item	2413042	et	4	main
ühes	doc_446076497168_item	2413044	et	4	main
osa	doc_446076497168_item	2413051	et	4	main
kursiivis	doc_446076497168_item	2413054	et	3	main
ühes	doc_446076497168_item	2413071	et	4	main
valesti	doc_446076497168_item	2413074	et	3	main
eesti	doc_446076497168_item	2413079	et	4	main
oli	doc_446076497168_item	2413082	et	3	main
tõlgitud	doc_446076497168_item	2413083	et	4	main
ma	doc_446076497168_item	2413084	et	3	main
pean	doc_446076497168_item	2413085	et	4	main
tööle	doc_446076497168_item	2413086	et	3	main
minema	doc_446076497168_item	2413087	et	3	main
sõbrad	doc_446076497168_item	2413088	et	3	main
sõnad	doc_446076497168_item	2413100	et	4	main
poole	doc_446076497168_item	2413114	et	4	main
ütles	doc_446076497168_item	2413115	et	3	main
joey	doc_446076497168_item	2413116	et	4	main
ja	doc_446076497168_item	2413117	et	3	main
küsis	doc_446076497168_item	2413118	et	3	main
eesti	doc_446076497168_item	2413123	et	4	main
nime	doc_446076497168_item	2413127	et	4	main
selline	doc_446076497168_item	2413131	et	4	main
olid	doc_446076497168_item	2413142	et	4	main
kohas	doc_446076497168_item	2413144	et	4	main
ja	doc_446076497168_item	2413151	et	3	main
veel	doc_446076497168_item	2413161	et	4	main
mängufilme	doc_446076497168_item	2413162	et	3	main
pbk	doc_446076497168_item	2413163	et	4	main
hall	doc_446076497168_item	2413183	et	4	main
jõudnud	doc_446076497168_item	2413193	et	4	main
oli	doc_446076497168_item	2413199	et	3	main
mitte	doc_446076497168_item	2413201	et	3	main
ja	doc_446076497168_item	2413212	et	3	main
ei	doc_446076497168_item	2413214	et	4	main
näinud	doc_446076497168_item	2413221	et	4	main
kasutati	doc_446076497168_item	2413223	et	4	main
kus	doc_446076497168_item	2413224	et	3	main
oli	doc_446076497168_item	2413225	et	3	main
ei	doc_446076497168_item	2413228	et	4	main
meeldinud	doc_446076497168_item	2413229	et	4	main
veel	doc_446076497168_item	2413230	et	4	main
see	doc_446076497168_item	2413231	et	3	main
tom	doc_446076497168_item	2413240	et	4	main
olid	doc_442386364034_item	2412905	et	4	main
kaunistatud	doc_442386364034_item	2412906	et	4	main
tähtsus	doc_442386364034_item	2412914	et	4	main
leitud	doc_442386364034_item	2412922	et	4	main
mõned	doc_442386364034_item	2412923	et	3	main
neoliitikumi	doc_442386364034_item	2412925	et	4	main
aja	doc_442386364034_item	2412926	et	4	main
oli	doc_442386364034_item	2412935	et	3	main
sest	doc_442386364034_item	2412939	et	4	main
olid	doc_442386364034_item	2412941	et	4	main
primitiivsed	doc_442386364034_item	2412942	et	3	main
inimesed	doc_442386364034_item	2412943	et	3	main
veekogude	doc_442386364034_item	2412946	et	3	main
pandud	doc_442386364034_item	2412956	et	4	main
maeti	doc_442386364034_item	2412959	et	3	main
kõiki	doc_442386364034_item	2412963	et	4	main
reet	doc_446076497168_item	2413000	et	4	main
sest	doc_446076497168_item	2413015	et	4	main
seal	doc_446076497168_item	2413016	et	4	main
lauseid	doc_446076497168_item	2413023	et	3	main
punktid	doc_446076497168_item	2413043	et	4	main
kohas	doc_446076497168_item	2413045	et	4	main
kui	doc_446076497168_item	2413046	et	3	main
poiss	doc_446076497168_item	2413047	et	3	main
ja	doc_446076497168_item	2413055	et	3	main
ainuke	doc_446076497168_item	2413057	et	4	main
oli	doc_446076497168_item	2413059	et	3	main
et	doc_446076497168_item	2413061	et	3	main
jäi	doc_446076497168_item	2413063	et	3	main
panin	doc_446076497168_item	2413066	et	3	main
ka	doc_446076497168_item	2413067	et	3	main
seda	doc_446076497168_item	2413068	et	3	main
tähele	doc_446076497168_item	2413069	et	3	main
i	doc_446076497168_item	2413076	et	4	main
go	doc_446076497168_item	2413078	et	4	main
keelde	doc_446076497168_item	2413080	et	4	main
oli	doc_446076497168_item	2413092	et	3	main
tõlgimata	doc_446076497168_item	2413102	et	4	main
palju	doc_446076497168_item	2413109	et	4	main
venekirved	doc_442386364034_item	2412924	et	3	main
natuke	doc_442386364034_item	2412931	et	4	main
tegelema	doc_442386364034_item	2412932	et	3	main
põllumajandusega	doc_442386364034_item	2412933	et	3	main
see	doc_442386364034_item	2412934	et	3	main
ääres	doc_442386364034_item	2412947	et	4	main
ümber	doc_442386364034_item	2412955	et	3	main
kultuur	doc_442386364034_item	2412968	et	3	main
ühele	doc_442386364034_item	2412969	et	3	main
iseloomulik	doc_442386364034_item	2412971	et	3	main
kombed	doc_442386364034_item	2412974	et	3	main
mis	doc_442386364034_item	2412975	et	4	main
on	doc_442386364034_item	2412976	et	4	main
kindlaks	doc_442386364034_item	2412977	et	3	main
tehtud	doc_442386364034_item	2412978	et	4	main
arheoloogiliste	doc_442386364034_item	2412979	et	4	main
kaevandamiste	doc_442386364034_item	2412980	et	4	main
käigul	doc_442386364034_item	2412981	et	3	main
analüüs	doc_446076497168_item	2412982	et	3	main
subtitreerimine	doc_446076497168_item	2412983	et	4	main
ma	doc_446076497168_item	2412984	et	3	main
vaatasin	doc_446076497168_item	2412985	et	3	main
kahte	doc_446076497168_item	2412986	et	4	main
sarja	doc_446076497168_item	2412987	et	4	main
etv	doc_446076497168_item	2412988	et	4	main
meie	doc_446076497168_item	2412989	et	4	main
salajane	doc_446076497168_item	2412990	et	3	main
elu	doc_446076497168_item	2412991	et	4	main
ja	doc_446076497168_item	2412992	et	3	main
kanal	doc_446076497168_item	2412993	et	4	main
2	doc_446076497168_item	2412994	et	2	main
sõbrad	doc_446076497168_item	2412995	et	3	main
meie	doc_446076497168_item	2412996	et	4	main
salajane	doc_446076497168_item	2412997	et	3	main
elu	doc_446076497168_item	2412998	et	4	main
tõlgis	doc_446076497168_item	2412999	et	3	main
eelistasid	doc_442386364034_item	2412944	et	4	main
elama	doc_442386364034_item	2412945	et	3	main
maeti	doc_442386364034_item	2412950	et	3	main
maa	doc_442386364034_item	2412951	et	4	main
kividega	doc_442386364034_item	2412954	et	3	main
selle	doc_442386364034_item	2412961	et	4	main
inimgrupile	doc_442386364034_item	2412970	et	3	main
usund	doc_442386364034_item	2412973	et	3	main
buschmann	doc_446076497168_item	2413006	et	4	main
tõlgitud	doc_446076497168_item	2413013	et	4	main
etv	doc_446076497168_item	2413014	et	4	main
grammatilist	doc_446076497168_item	2413021	et	3	main
olid	doc_446076497168_item	2413024	et	4	main
poolitatud	doc_446076497168_item	2413027	et	4	main
väga	doc_446076497168_item	2413035	et	3	main
hästi	doc_446076497168_item	2413036	et	3	main
oli	doc_446076497168_item	2413037	et	3	main
tekst	doc_446076497168_item	2413039	et	3	main
olnud	doc_446076497168_item	2413053	et	4	main
kohas	doc_446076497168_item	2413072	et	4	main
tõlgitud	doc_446076497168_item	2413075	et	4	main
must	doc_446076497168_item	2413077	et	4	main
see	doc_446076497168_item	2413081	et	3	main
ja	doc_446076497168_item	2413090	et	3	main
kasutatud	doc_446076497168_item	2413093	et	4	main
mind	doc_446076497168_item	2413098	et	4	main
mõned	doc_446076497168_item	2413099	et	3	main
kohas	doc_446076497168_item	2413104	et	4	main
oli	doc_446076497168_item	2413105	et	3	main
dialoog	doc_446076497168_item	2413106	et	3	main
ruumis	doc_446076497168_item	2413107	et	4	main
oli	doc_446076497168_item	2413108	et	3	main
midagi	doc_446076497168_item	2413119	et	4	main
ei	doc_446076497168_item	2413128	et	4	main
pannud	doc_446076497168_item	2413129	et	4	main
ja	doc_446076497168_item	2413130	et	3	main
siis	doc_446076497168_item	2413138	et	3	main
ikka	doc_446076497168_item	2413139	et	4	main
loogilises	doc_446076497168_item	2413143	et	4	main
kolme	doc_446076497168_item	2413156	et	4	main
subtiiter	doc_446076497168_item	2413185	et	4	main
lugeda	doc_446076497168_item	2413194	et	3	main
lõpuni	doc_446076497168_item	2413195	et	3	main
kohtadest	doc_446076497168_item	2413197	et	3	main
poolitatud	doc_446076497168_item	2413200	et	4	main
loogiliselt	doc_446076497168_item	2413202	et	4	main
lauseid	doc_446076497168_item	2413204	et	3	main
ei	doc_446076497168_item	2413205	et	4	main
hakkanud	doc_446076497168_item	2413206	et	4	main
igas	doc_446076497168_item	2413207	et	3	main
grammatilst	doc_446076497168_item	2413217	et	4	main
punkt	doc_446076497168_item	2413222	et	4	main
seda	doc_446076497168_item	2413226	et	3	main
et	doc_446076497168_item	2413232	et	3	main
subtiiter	doc_446076497168_item	2413243	et	4	main
kasutanud	doc_446076497168_item	2413249	et	4	main
mr	doc_446076497168_item	2413255	et	4	main
mrs	doc_446076497168_item	2413256	et	4	main
seda	doc_446076497168_item	2413257	et	3	main
üldse	doc_446076497168_item	2413258	et	3	main
pole	doc_446076497168_item	2413259	et	3	main
say	doc_446076497168_item	2413267	et	4	main
tom	doc_446076497168_item	2413268	et	4	main
seda	doc_446076497168_item	2413276	et	3	main
osa	doc_446076497168_item	2413278	et	4	main
üldse	doc_446076497168_item	2413280	et	3	main
ära	doc_446076497168_item	2413282	et	4	main
minu	doc_446076497168_item	2413283	et	3	main
meelest	doc_446076497168_item	2413284	et	4	main
see	doc_446076497168_item	2413285	et	3	main
oli	doc_446076497168_item	2413286	et	3	main
on	doc_446076497168_item	2413332	et	4	main
essee	doc_446076497169_item	2413340	et	4	main
ei	doc_446076497169_item	2413341	et	4	main
ole	doc_446076497169_item	2413342	et	4	main
midagi	doc_446076497169_item	2413343	et	4	main
hirmsamat	doc_446076497169_item	2413344	et	4	main
kui	doc_446076497169_item	2413345	et	3	main
üks	doc_446076497169_item	2413346	et	3	main
sirgjoonelise	doc_446076497169_item	2413352	et	4	main
inimene	doc_446076497169_item	2413356	et	3	main
vaadates	doc_446076497169_item	2413366	et	3	main
mulle	doc_446076497168_item	2413009	et	4	main
meeldis	doc_446076497168_item	2413010	et	3	main
ajal	doc_446076497168_item	2413031	et	4	main
lause	doc_446076497168_item	2413040	et	4	main
ei	doc_446076497168_item	2413052	et	4	main
kord	doc_446076497168_item	2413058	et	4	main
tekst	doc_446076497168_item	2413062	et	3	main
oli	doc_446076497168_item	2413073	et	3	main
lõppus	doc_446076497168_item	2413091	et	4	main
must	doc_446076497168_item	2413094	et	4	main
kast	doc_446076497168_item	2413095	et	3	main
mis	doc_446076497168_item	2413096	et	4	main
häiris	doc_446076497168_item	2413097	et	3	main
ühes	doc_446076497168_item	2413103	et	4	main
inimesi	doc_446076497168_item	2413110	et	4	main
naine	doc_446076497168_item	2413111	et	3	main
pöördas	doc_446076497168_item	2413112	et	4	main
mehe	doc_446076497168_item	2413113	et	3	main
aga	doc_446076497168_item	2413120	et	3	main
kui	doc_446076497168_item	2413121	et	3	main
siis	doc_446076497168_item	2413125	et	3	main
mulje	doc_446076497168_item	2413132	et	4	main
et	doc_446076497168_item	2413134	et	3	main
lauseid	doc_446076497168_item	2413141	et	3	main
korda	doc_446076497168_item	2413147	et	4	main
subtiiter	doc_446076497168_item	2413148	et	4	main
hiljaks	doc_446076497168_item	2413150	et	3	main
punktiga	doc_446076497168_item	2413157	et	4	main
siis	doc_446076497168_item	2413158	et	3	main
ma	doc_446076497168_item	2413159	et	3	main
vaatasin	doc_446076497168_item	2413160	et	3	main
häiris	doc_446076497168_item	2413182	et	3	main
ei	doc_446076497168_item	2413192	et	4	main
kohas	doc_446076497168_item	2413208	et	4	main
suure	doc_446076497168_item	2413209	et	3	main
läbitähega	doc_446076497168_item	2413210	et	3	main
laulutekst	doc_446076497168_item	2413211	et	3	main
oli	doc_446076497168_item	2413234	et	3	main
olid	doc_446076497168_item	2413237	et	4	main
ei	doc_446076497168_item	2413248	et	4	main
filmi	doc_446076497168_item	2413251	et	4	main
ühtegi	doc_446076497168_item	2413253	et	4	main
keeles	doc_446076497168_item	2413270	et	4	main
oleks	doc_446076497168_item	2413271	et	3	main
aga	doc_446076497168_item	2413275	et	3	main
tähtis	doc_446076497168_item	2413287	et	4	main
tähele	doc_446076497168_item	2413290	et	3	main
et	doc_446076497168_item	2413291	et	3	main
meelest	doc_446076497168_item	2413321	et	4	main
niigi	doc_446076497168_item	2413323	et	4	main
aru	doc_446076497168_item	2413324	et	4	main
lugemiskiirus	doc_446076497168_item	2413331	et	4	main
ei	doc_446076497168_item	2413335	et	4	main
liiga	doc_446076497168_item	2413337	et	4	main
kohusetundlik	doc_446076497169_item	2413354	et	3	main
laitmatu	doc_446076497169_item	2413355	et	4	main
kes	doc_446076497169_item	2413357	et	4	main
pälvib	doc_446076497169_item	2413358	et	3	main
austust	doc_446076497169_item	2413359	et	4	main
aastate	doc_446076497169_item	2413378	et	3	main
hulljulged	doc_446076497169_item	2413381	et	3	main
salapiirituse	doc_446076497169_item	2413386	et	4	main
soome	doc_446076497169_item	2413390	et	3	main
mõtlema	doc_446076497169_item	2413392	et	3	main
br	doc_446076497169_item	2413397	et	4	main
inimene	doc_446076497169_item	2413399	et	3	main
on	doc_446076497169_item	2413401	et	4	main
aus	doc_446076497169_item	2413402	et	4	main
selles	doc_446076497169_item	2413410	et	4	main
parem	doc_446076497169_item	2413421	et	4	main
tõtt	doc_446076497169_item	2413426	et	4	main
ausalt	doc_446076497169_item	2413450	et	4	main
pead	doc_446076497169_item	2413455	et	4	main
mõtlema	doc_446076497169_item	2413457	et	3	main
milliseid	doc_446076497169_item	2413458	et	3	main
probleeme	doc_446076497169_item	2413459	et	3	main
sellepärast	doc_446076497169_item	2413461	et	3	main
kui	doc_446076497169_item	2413464	et	3	main
või	doc_446076497169_item	2413470	et	4	main
palju	doc_446076497169_item	2413491	et	4	main
sa	doc_446076497169_item	2413502	et	3	main
vale	doc_446076497169_item	2413517	et	4	main
loogilises	doc_446076497168_item	2413025	et	4	main
kohas	doc_446076497168_item	2413026	et	4	main
tekst	doc_446076497168_item	2413032	et	3	main
ja	doc_446076497168_item	2413033	et	3	main
kõne	doc_446076497168_item	2413034	et	4	main
loetav	doc_446076497168_item	2413038	et	4	main
laulis	doc_446076497168_item	2413048	et	4	main
see	doc_446076497168_item	2413049	et	3	main
teksti	doc_446076497168_item	2413050	et	4	main
üks	doc_446076497168_item	2413056	et	3	main
see	doc_446076497168_item	2413060	et	3	main
teisesse	doc_446076497168_item	2413064	et	4	main
kaadrisse	doc_446076497168_item	2413065	et	3	main
et	doc_446076497168_item	2413070	et	3	main
alguses	doc_446076497168_item	2413089	et	4	main
olid	doc_446076497168_item	2413101	et	4	main
tõlgiti	doc_446076497168_item	2413122	et	3	main
kelle	doc_446076497168_item	2413135	et	4	main
poole	doc_446076497168_item	2413136	et	4	main
naine	doc_446076497168_item	2413137	et	3	main
paar	doc_446076497168_item	2413146	et	3	main
jäi	doc_446076497168_item	2413149	et	3	main
mitu	doc_446076497168_item	2413152	et	4	main
korda	doc_446076497168_item	2413153	et	4	main
kast	doc_446076497168_item	2413184	et	3	main
kiiresti	doc_446076497168_item	2413190	et	3	main
tekst	doc_446076497168_item	2413198	et	3	main
uued	doc_446076497168_item	2413203	et	3	main
telefonivestlus	doc_446076497168_item	2413213	et	3	main
vaja	doc_446076497168_item	2413227	et	4	main
subtiiter	doc_446076497168_item	2413233	et	4	main
tekstid	doc_446076497168_item	2413236	et	3	main
liiga	doc_446076497168_item	2413238	et	4	main
pikkad	doc_446076497168_item	2413239	et	4	main
poolitatud	doc_446076497168_item	2413245	et	4	main
loogiliselt	doc_446076497168_item	2413246	et	4	main
tõlgitud	doc_446076497168_item	2413260	et	4	main
eesti	doc_446076497168_item	2413261	et	4	main
kohas	doc_446076497168_item	2413264	et	4	main
poiss	doc_446076497168_item	2413265	et	3	main
ütles	doc_446076497168_item	2413266	et	3	main
olnud	doc_446076497168_item	2413272	et	4	main
tõlkija	doc_446076497168_item	2413279	et	4	main
on	doc_446076497168_item	2413322	et	4	main
poissi	doc_446076497168_item	2413330	et	4	main
br	doc_446076497169_item	2413349	et	4	main
pälvib	doc_446076497169_item	2413364	et	3	main
hardi	doc_446076497169_item	2413367	et	4	main
volmeri	doc_446076497169_item	2413368	et	4	main
filmi	doc_446076497169_item	2413369	et	4	main
kus	doc_446076497169_item	2413380	et	3	main
noored	doc_446076497169_item	2413382	et	3	main
riskantse	doc_446076497169_item	2413385	et	3	main
veoga	doc_446076497169_item	2413387	et	3	main
juurde	doc_446076497169_item	2413389	et	4	main
tõesti	doc_446076497169_item	2413394	et	3	main
olla	doc_446076497169_item	2413432	et	3	main
võivad	doc_446076497169_item	2413438	et	4	main
või	doc_446076497169_item	2413443	et	4	main
br	doc_446076497169_item	2413446	et	4	main
enne	doc_446076497169_item	2413447	et	4	main
öelda	doc_446076497169_item	2413451	et	4	main
teha	doc_446076497169_item	2413453	et	3	main
kas	doc_446076497169_item	2413468	et	3	main
parem	doc_446076497169_item	2413492	et	4	main
tundma	doc_446076497169_item	2413493	et	3	main
nagu	doc_446076497169_item	2413494	et	3	main
mingi	doc_446076497169_item	2413495	et	4	main
kui	doc_446076497169_item	2413501	et	3	main
teine	doc_446076497169_item	2413509	et	3	main
midagi	doc_446076497170_item	2413525	et	4	main
kui	doc_446076497170_item	2413527	et	3	main
tänapäeva	doc_446076497170_item	2413532	et	4	main
on	doc_446076497170_item	2413534	et	4	main
erinevaid	doc_446076497170_item	2413536	et	4	main
head	doc_446076497170_item	2413540	et	4	main
puutume	doc_446076497170_item	2413548	et	4	main
saa	doc_446076497170_item	2413554	et	4	main
ausaid	doc_446076497170_item	2413561	et	3	main
inimesi	doc_446076497170_item	2413562	et	4	main
br	doc_446076497170_item	2413584	et	4	main
film	doc_446076497170_item	2413588	et	3	main
räägib	doc_446076497170_item	2413589	et	3	main
salakaubavedajatest	doc_446076497170_item	2413590	et	3	main
tahtsid	doc_446076497170_item	2413598	et	4	main
pidada	doc_446076497170_item	2413600	et	4	main
neid	doc_446076497170_item	2413601	et	4	main
kus	doc_446076497170_item	2413612	et	3	main
käsul	doc_446076497170_item	2413616	et	3	main
sest	doc_446076497170_item	2413617	et	4	main
piirivalvur	doc_446076497170_item	2413618	et	3	main
keelde	doc_446076497168_item	2413124	et	4	main
mehe	doc_446076497168_item	2413126	et	3	main
jäi	doc_446076497168_item	2413133	et	3	main
pöördas	doc_446076497168_item	2413140	et	4	main
poolitatud	doc_446076497168_item	2413145	et	4	main
subtiiter	doc_446076497168_item	2413154	et	4	main
lõpes	doc_446076497168_item	2413155	et	3	main
вызов	doc_446076497168_item	2413164	et	2	main
tõlgis	doc_446076497168_item	2413165	et	3	main
a	doc_446076497168_item	2413166	et	4	main
kuzmina	doc_446076497168_item	2413167	et	4	main
ja	doc_446076497168_item	2413168	et	3	main
tv	doc_446076497168_item	2413169	et	4	main
3	doc_446076497168_item	2413170	et	2	main
tom	doc_446076497168_item	2413171	et	4	main
ja	doc_446076497168_item	2413172	et	3	main
huck	doc_446076497168_item	2413173	et	4	main
tõlgis	doc_446076497168_item	2413174	et	3	main
tiina	doc_446076497168_item	2413175	et	4	main
leemets	doc_446076497168_item	2413176	et	4	main
terve	doc_446076497168_item	2413177	et	4	main
filmi	doc_446076497168_item	2413178	et	4	main
jooksul	doc_446076497168_item	2413179	et	4	main
вызов	doc_446076497168_item	2413180	et	2	main
mind	doc_446076497168_item	2413181	et	4	main
jooksis	doc_446076497168_item	2413186	et	4	main
mõne	doc_446076497168_item	2413187	et	3	main
kohtades	doc_446076497168_item	2413188	et	3	main
liiga	doc_446076497168_item	2413189	et	4	main
et	doc_446076497168_item	2413191	et	3	main
paljudes	doc_446076497168_item	2413196	et	3	main
olnud	doc_446076497168_item	2413215	et	4	main
kursiivis	doc_446076497168_item	2413216	et	3	main
vigu	doc_446076497168_item	2413218	et	3	main
ma	doc_446076497168_item	2413219	et	3	main
ei	doc_446076497168_item	2413220	et	4	main
keskel	doc_446076497168_item	2413235	et	3	main
huck	doc_446076497168_item	2413242	et	4	main
oli	doc_446076497168_item	2413244	et	3	main
terve	doc_446076497168_item	2413250	et	4	main
sir	doc_446076497168_item	2413254	et	4	main
keelde	doc_446076497168_item	2413262	et	4	main
ühes	doc_446076497168_item	2413263	et	4	main
eesti	doc_446076497168_item	2413269	et	4	main
tom	doc_446076497168_item	2413274	et	4	main
panin	doc_446076497168_item	2413288	et	3	main
ka	doc_446076497168_item	2413289	et	3	main
eesti	doc_446076497168_item	2413292	et	4	main
keelde	doc_446076497168_item	2413293	et	4	main
ei	doc_446076497168_item	2413294	et	4	main
olnud	doc_446076497168_item	2413295	et	4	main
paar	doc_446076497168_item	2413296	et	3	main
korda	doc_446076497168_item	2413297	et	4	main
tõlgitud	doc_446076497168_item	2413298	et	4	main
please	doc_446076497168_item	2413299	et	4	main
thank	doc_446076497168_item	2413300	et	4	main
you	doc_446076497168_item	2413301	et	4	main
palun	doc_446076497168_item	2413302	et	3	main
tänan	doc_446076497168_item	2413303	et	3	main
äkki	doc_446076497168_item	2413304	et	3	main
tõlkija	doc_446076497168_item	2413305	et	4	main
arvates	doc_446076497168_item	2413306	et	4	main
see	doc_446076497168_item	2413307	et	3	main
teksti	doc_446076497168_item	2413308	et	4	main
osa	doc_446076497168_item	2413309	et	4	main
ei	doc_446076497168_item	2413310	et	4	main
olnud	doc_446076497168_item	2413311	et	4	main
oluline	doc_446076497168_item	2413312	et	4	main
paar	doc_446076497168_item	2413313	et	3	main
korda	doc_446076497168_item	2413314	et	4	main
oli	doc_446076497168_item	2413315	et	3	main
tõlgitud	doc_446076497168_item	2413316	et	4	main
poissi	doc_446076497168_item	2413317	et	4	main
nimi	doc_446076497168_item	2413318	et	3	main
huck	doc_446076497168_item	2413319	et	4	main
minu	doc_446076497168_item	2413320	et	3	main
ja	doc_446076497168_item	2413241	et	3	main
lõpupunkti	doc_446076497168_item	2413247	et	4	main
jooksul	doc_446076497168_item	2413252	et	4	main
ütle	doc_446076497168_item	2413273	et	4	main
teksti	doc_446076497168_item	2413277	et	4	main
jättis	doc_446076497168_item	2413281	et	3	main
saadav	doc_446076497168_item	2413325	et	4	main
et	doc_446076497168_item	2413326	et	3	main
poiss	doc_446076497168_item	2413327	et	3	main
hüüab	doc_446076497168_item	2413328	et	3	main
teise	doc_446076497168_item	2413329	et	4	main
hea	doc_446076497168_item	2413333	et	4	main
olnud	doc_446076497168_item	2413336	et	4	main
pikkad	doc_446076497168_item	2413338	et	4	main
p	doc_446076497168_item	2413339	et	4	main
iseloomuga	doc_446076497169_item	2413353	et	3	main
austust	doc_446076497169_item	2413365	et	4	main
mis	doc_446076497169_item	2413371	et	4	main
lõpus	doc_446076497169_item	2413379	et	4	main
kas	doc_446076497169_item	2413393	et	3	main
äri	doc_446076497169_item	2413407	et	4	main
ausalt	doc_446076497169_item	2413408	et	4	main
aga	doc_446076497169_item	2413409	et	3	main
vait	doc_446076497169_item	2413422	et	3	main
olla	doc_446076497169_item	2413423	et	3	main
ja	doc_446076497169_item	2413435	et	3	main
paljud	doc_446076497169_item	2413436	et	3	main
saada	doc_446076497169_item	2413442	et	4	main
isegi	doc_446076497169_item	2413444	et	4	main
hukkuda	doc_446076497169_item	2413445	et	3	main
võivad	doc_446076497169_item	2413460	et	4	main
aga	doc_446076497169_item	2413463	et	3	main
ikka	doc_446076497169_item	2413466	et	4	main
kivi	doc_446076497169_item	2413496	et	4	main
langes	doc_446076497169_item	2413498	et	4	main
br	doc_446076497169_item	2413499	et	4	main
aga	doc_446076497169_item	2413500	et	3	main
iga	doc_446076497169_item	2413516	et	4	main
tekstid	doc_446076497168_item	2413334	et	3	main
aus	doc_446076497169_item	2413347	et	4	main
inimene	doc_446076497169_item	2413348	et	3	main
aus	doc_446076497169_item	2413350	et	4	main
inimene	doc_446076497169_item	2413351	et	3	main
br	doc_446076497169_item	2413360	et	4	main
aga	doc_446076497169_item	2413361	et	3	main
kas	doc_446076497169_item	2413362	et	3	main
tõesti	doc_446076497169_item	2413363	et	3	main
tulivesi	doc_446076497169_item	2413370	et	4	main
1920-ndate	doc_446076497169_item	2413377	et	4	main
mehed	doc_446076497169_item	2413383	et	3	main
ülemerenaabrite	doc_446076497169_item	2413388	et	3	main
hakkad	doc_446076497169_item	2413391	et	3	main
nii	doc_446076497169_item	2413396	et	3	main
kui	doc_446076497169_item	2413398	et	3	main
ise	doc_446076497169_item	2413400	et	4	main
siis	doc_446076497169_item	2413403	et	3	main
ajab	doc_446076497169_item	2413404	et	3	main
ta	doc_446076497169_item	2413405	et	4	main
ka	doc_446076497169_item	2413406	et	3	main
me	doc_446076497169_item	2413412	et	4	main
ja	doc_446076497169_item	2413414	et	3	main
ise	doc_446076497169_item	2413416	et	4	main
arvan	doc_446076497169_item	2413417	et	3	main
et	doc_446076497169_item	2413418	et	3	main
mõnikord	doc_446076497169_item	2413419	et	3	main
on	doc_446076497169_item	2413420	et	4	main
rääkib	doc_446076497169_item	2413372	et	4	main
meile	doc_446076497169_item	2413373	et	4	main
elust	doc_446076497169_item	2413374	et	3	main
eestimaa	doc_446076497169_item	2413375	et	4	main
rannakülas	doc_446076497169_item	2413376	et	3	main
tegelesid	doc_446076497169_item	2413384	et	4	main
on	doc_446076497169_item	2413395	et	4	main
filmis	doc_446076497169_item	2413411	et	4	main
näeme	doc_446076497169_item	2413413	et	3	main
ma	doc_446076497169_item	2413415	et	3	main
kui	doc_446076497169_item	2413424	et	3	main
halastamatu	doc_446076497169_item	2413434	et	4	main
selle	doc_446076497169_item	2413439	et	4	main
tõttu	doc_446076497169_item	2413440	et	4	main
kui	doc_446076497169_item	2413448	et	3	main
või	doc_446076497169_item	2413452	et	4	main
sa	doc_446076497169_item	2413454	et	3	main
hästi	doc_446076497169_item	2413456	et	3	main
rääkida	doc_446076497169_item	2413469	et	3	main
südamelt	doc_446076497169_item	2413497	et	3	main
ei	doc_446076497169_item	2413504	et	4	main
räägi	doc_446076497169_item	2413505	et	4	main
siis	doc_446076497169_item	2413507	et	3	main
body	doc_446076497169_item	2413521	et	4	main
ei	doc_446076497170_item	2413523	et	4	main
üks	doc_446076497170_item	2413528	et	3	main
palju	doc_446076497170_item	2413535	et	4	main
inimesi	doc_446076497170_item	2413537	et	4	main
mõned	doc_446076497170_item	2413538	et	3	main
pahad	doc_446076497170_item	2413544	et	4	main
ja	doc_446076497170_item	2413545	et	3	main
nendega	doc_446076497170_item	2413551	et	4	main
teistest	doc_446076497170_item	2413557	et	4	main
tahavad	doc_446076497170_item	2413564	et	3	main
piirivalvurist	doc_446076497170_item	2413592	et	3	main
aleksist	doc_446076497170_item	2413593	et	4	main
vedajaid	doc_446076497170_item	2413602	et	4	main
julius	doc_446076497170_item	2413609	et	4	main
inimeseks	doc_446076497170_item	2413621	et	3	main
rääkis	doc_446076497170_item	2413623	et	3	main
siiski	doc_446076497170_item	2413638	et	4	main
nii	doc_446076497170_item	2413639	et	3	main
juhtub	doc_446076497170_item	2413640	et	3	main
ka	doc_446076497170_item	2413641	et	3	main
ole	doc_446076497170_item	2413659	et	4	main
peal	doc_446076497170_item	2413662	et	4	main
austatakse	doc_446076497170_item	2413664	et	3	main
tundub	doc_446076497170_item	2413668	et	3	main
inimeste	doc_446076497170_item	2413678	et	3	main
ka	doc_446076497170_item	2413681	et	3	main
br	doc_446076497170_item	2413693	et	4	main
ausalt	doc_446076497170_item	2413699	et	4	main
seejuures	doc_446076497170_item	2413721	et	3	main
küsimus	doc_446076497170_item	2413735	et	4	main
kõikidele	doc_446076497170_item	2413736	et	4	main
tuleb	doc_446076497170_item	2413737	et	3	main
seejuures	doc_446076497170_item	2413743	et	3	main
võib	doc_446076497170_item	2413757	et	3	main
et	doc_446076497170_item	2413760	et	3	main
et	doc_446076497170_item	2413767	et	3	main
teeninud	doc_446076497170_item	2413773	et	4	main
aus	doc_446076497170_item	2413778	et	4	main
ja	doc_446470622100_item	2413814	et	3	main
tänava	doc_446470622100_item	2413817	et	4	main
rääkida	doc_446076497169_item	2413425	et	3	main
sellepärast	doc_446076497169_item	2413427	et	3	main
et	doc_446076497169_item	2413428	et	3	main
tõde	doc_446076497169_item	2413429	et	4	main
mõnikord	doc_446076497169_item	2413430	et	3	main
võib	doc_446076497169_item	2413431	et	3	main
nii	doc_446076497169_item	2413433	et	3	main
inimesed	doc_446076497169_item	2413437	et	3	main
kahju	doc_446076497169_item	2413441	et	4	main
midagi	doc_446076497169_item	2413449	et	4	main
tekkida	doc_446076497169_item	2413462	et	3	main
oled	doc_446076497169_item	2413465	et	3	main
segaduses	doc_446076497169_item	2413467	et	3	main
mitte	doc_446076497169_item	2413471	et	3	main
siis	doc_446076497169_item	2413472	et	3	main
mõtle	doc_446076497169_item	2413473	et	4	main
sellest	doc_446076497169_item	2413474	et	4	main
et	doc_446076497169_item	2413475	et	3	main
parem	doc_446076497169_item	2413476	et	4	main
on	doc_446076497169_item	2413477	et	4	main
mõru	doc_446076497169_item	2413478	et	4	main
tõtt	doc_446076497169_item	2413479	et	4	main
kui	doc_446076497169_item	2413480	et	3	main
magus	doc_446076497169_item	2413481	et	3	main
pettus	doc_446076497169_item	2413482	et	4	main
ja	doc_446076497169_item	2413483	et	3	main
kui	doc_446076497169_item	2413484	et	3	main
rääkid	doc_446076497169_item	2413485	et	4	main
kõike	doc_446076497169_item	2413486	et	4	main
ära	doc_446076497169_item	2413487	et	4	main
siis	doc_446076497169_item	2413488	et	3	main
hakkad	doc_446076497169_item	2413489	et	3	main
end	doc_446076497169_item	2413490	et	4	main
ise	doc_446076497169_item	2413503	et	4	main
tõtt	doc_446076497169_item	2413506	et	4	main
keegi	doc_446076497169_item	2413508	et	4	main
teeb	doc_446076497169_item	2413510	et	3	main
seda	doc_446076497169_item	2413511	et	3	main
sinu	doc_446076497169_item	2413512	et	3	main
asemel	doc_446076497169_item	2413513	et	4	main
sellepärast	doc_446076497169_item	2413514	et	3	main
et	doc_446076497169_item	2413515	et	3	main
välja	doc_446076497169_item	2413520	et	4	main
essee	doc_446076497170_item	2413522	et	4	main
br	doc_446076497170_item	2413531	et	4	main
maailmas	doc_446076497170_item	2413533	et	3	main
on	doc_446076497170_item	2413539	et	4	main
peamiselt	doc_446076497170_item	2413546	et	4	main
me	doc_446076497170_item	2413547	et	4	main
ei	doc_446076497170_item	2413553	et	4	main
olemas	doc_446076497170_item	2413559	et	4	main
ka	doc_446076497170_item	2413560	et	3	main
kõik	doc_446076497170_item	2413565	et	4	main
lühidalt	doc_446076497170_item	2413585	et	4	main
see	doc_446076497170_item	2413587	et	3	main
naisest	doc_446076497170_item	2413595	et	3	main
hildast	doc_446076497170_item	2413596	et	4	main
satub	doc_446076497170_item	2413604	et	3	main
haiglasse	doc_446076497170_item	2413605	et	4	main
ja	doc_446076497170_item	2413606	et	3	main
peategelanna	doc_446076497170_item	2413607	et	4	main
onu	doc_446076497170_item	2413608	et	4	main
vanglasse	doc_446076497170_item	2413611	et	4	main
teda	doc_446076497170_item	2413613	et	4	main
ministri	doc_446076497170_item	2413615	et	3	main
kõik	doc_446076497170_item	2413624	et	4	main
suutnud	doc_446076497170_item	2413629	et	4	main
sellele	doc_446076497170_item	2413633	et	4	main
piirivalvurile	doc_446076497170_item	2413634	et	3	main
meiega	doc_446076497170_item	2413642	et	4	main
aus	doc_446076497170_item	2413648	et	4	main
ju	doc_446076497170_item	2413650	et	3	main
hea	doc_446076497170_item	2413651	et	4	main
kui	doc_446076497170_item	2413652	et	3	main
sa	doc_446076497170_item	2413653	et	3	main
koormust	doc_446076497170_item	2413660	et	4	main
hinge	doc_446076497170_item	2413661	et	4	main
armastatakse	doc_446076497170_item	2413665	et	3	main
nii	doc_446076497170_item	2413670	et	3	main
on	doc_446076497170_item	2413674	et	4	main
ju	doc_446076497170_item	2413675	et	3	main
võib	doc_446076497170_item	2413680	et	3	main
kellest	doc_446076497170_item	2413685	et	4	main
siis	doc_446076497170_item	2413694	et	3	main
kas	doc_446076497170_item	2413697	et	3	main
sind	doc_446076497170_item	2413722	et	4	main
võivaletada	doc_446076497170_item	2413742	et	4	main
et	doc_446076497170_item	2413747	et	3	main
kui	doc_446076497170_item	2413748	et	3	main
rääkinud	doc_446076497170_item	2413753	et	4	main
lähedasest	doc_446076497170_item	2413755	et	3	main
siis	doc_446076497170_item	2413756	et	3	main
inimest	doc_446076497170_item	2413762	et	3	main
kindel	doc_446076497170_item	2413766	et	3	main
koeraga	doc_446470622100_item	2413812	et	3	main
tahtis	doc_446470622100_item	2413816	et	3	main
kiiresti	doc_446470622100_item	2413823	et	3	main
koeraomanik	doc_446470622100_item	2413825	et	3	main
saanud	doc_446470622100_item	2413827	et	4	main
teda	doc_446470622100_item	2413828	et	4	main
peatuda	doc_446470622100_item	2413829	et	3	main
pidurdada	doc_446470622100_item	2413850	et	3	main
kuulsis	doc_446470622100_item	2413852	et	4	main
hääl	doc_446470622100_item	2413855	et	3	main
vaid	doc_446470622100_item	2413856	et	3	main
oli	doc_446470622100_item	2413857	et	3	main
päris	doc_446470622100_item	2413858	et	4	main
libe	doc_446470622100_item	2413859	et	3	main
ja	doc_446470622100_item	2413860	et	3	main
tema	doc_446470622100_item	2413861	et	4	main
pea	doc_446470622100_item	2413876	et	4	main
auto	doc_446470622100_item	2413896	et	4	main
essee	doc_446717232815_item	2413898	et	4	main
libahunt	doc_446717232815_item	2413899	et	3	main
alati	doc_446076497169_item	2413518	et	4	main
tuleb	doc_446076497169_item	2413519	et	3	main
ole	doc_446076497170_item	2413524	et	4	main
inimene	doc_446076497170_item	2413530	et	3	main
sest	doc_446076497170_item	2413552	et	4	main
on	doc_446076497170_item	2413558	et	4	main
ja	doc_446076497170_item	2413594	et	3	main
aleks	doc_446076497170_item	2413603	et	4	main
sattub	doc_446076497170_item	2413610	et	3	main
tapetakse	doc_446076497170_item	2413614	et	3	main
ja	doc_446076497170_item	2413626	et	3	main
br	doc_446076497170_item	2413635	et	4	main
poolt	doc_446076497170_item	2413646	et	4	main
on	doc_446076497170_item	2413649	et	4	main
ei	doc_446076497170_item	2413658	et	4	main
paljudele	doc_446076497170_item	2413667	et	3	main
et	doc_446076497170_item	2413669	et	3	main
peabki	doc_446076497170_item	2413671	et	4	main
aga	doc_446076497170_item	2413673	et	3	main
teine	doc_446076497170_item	2413676	et	3	main
aususest	doc_446076497170_item	2413679	et	4	main
nii	doc_446076497170_item	2413683	et	3	main
räägiti	doc_446076497170_item	2413686	et	3	main
tuleb	doc_446076497170_item	2413695	et	3	main
hirmsat	doc_446076497170_item	2413526	et	3	main
aus	doc_446076497170_item	2413529	et	4	main
teised	doc_446076497170_item	2413541	et	4	main
aga	doc_446076497170_item	2413542	et	3	main
on	doc_446076497170_item	2413543	et	4	main
kokku	doc_446076497170_item	2413549	et	3	main
siiski	doc_446076497170_item	2413550	et	4	main
neid	doc_446076497170_item	2413555	et	4	main
eristada	doc_446076497170_item	2413556	et	3	main
kes	doc_446076497170_item	2413563	et	4	main
ausalt	doc_446076497170_item	2413566	et	4	main
ära	doc_446076497170_item	2413567	et	4	main
rääkida	doc_446076497170_item	2413568	et	3	main
aga	doc_446076497170_item	2413569	et	3	main
lõpuks	doc_446076497170_item	2413570	et	4	main
võib	doc_446076497170_item	2413571	et	3	main
välja	doc_446076497170_item	2413572	et	4	main
tulla	doc_446076497170_item	2413573	et	3	main
nii	doc_446076497170_item	2413574	et	3	main
et	doc_446076497170_item	2413575	et	3	main
nad	doc_446076497170_item	2413576	et	3	main
rikkuvad	doc_446076497170_item	2413577	et	4	main
kõik	doc_446076497170_item	2413578	et	4	main
ära	doc_446076497170_item	2413579	et	4	main
nii	doc_446076497170_item	2413580	et	3	main
juhtuski	doc_446076497170_item	2413581	et	4	main
filmis	doc_446076497170_item	2413582	et	4	main
tulivesi	doc_446076497170_item	2413583	et	4	main
öeldes	doc_446076497170_item	2413586	et	3	main
ühest	doc_446076497170_item	2413591	et	4	main
piirivalvurid	doc_446076497170_item	2413597	et	3	main
kinni	doc_446076497170_item	2413599	et	3	main
sellepärast	doc_446076497170_item	2413627	et	3	main
aga	doc_446076497170_item	2413636	et	3	main
miks	doc_446076497170_item	2413637	et	4	main
tõelises	doc_446076497170_item	2413643	et	4	main
räägid	doc_446076497170_item	2413654	et	4	main
tõtt	doc_446076497170_item	2413655	et	4	main
ja	doc_446076497170_item	2413666	et	3	main
kannatada	doc_446076497170_item	2413682	et	3	main
see	doc_446076497170_item	2413684	et	3	main
ja	doc_446076497170_item	2413687	et	3	main
see	doc_446076497170_item	2413688	et	3	main
kes	doc_446076497170_item	2413689	et	4	main
seda	doc_446076497170_item	2413690	et	3	main
inimest	doc_446076497170_item	2413691	et	3	main
armastab	doc_446076497170_item	2413692	et	3	main
kõik	doc_446076497170_item	2413698	et	4	main
sinu	doc_446076497170_item	2413724	et	3	main
pärast	doc_446076497170_item	2413726	et	4	main
on	doc_446076497170_item	2413732	et	4	main
väga	doc_446076497170_item	2413733	et	3	main
rääkida	doc_446076497170_item	2413741	et	3	main
pidada	doc_446076497170_item	2413746	et	4	main
valetada	doc_446076497170_item	2413759	et	3	main
kui	doc_446076497170_item	2413764	et	3	main
ta	doc_446076497170_item	2413768	et	4	main
seda	doc_446076497170_item	2413770	et	3	main
valetamist	doc_446076497170_item	2413771	et	4	main
ära	doc_446076497170_item	2413772	et	4	main
oma	doc_446470622100_item	2413811	et	4	main
õues	doc_446470622100_item	2413813	et	4	main
kooksis	doc_446470622100_item	2413821	et	4	main
nii	doc_446470622100_item	2413822	et	3	main
auto	doc_446470622100_item	2413830	et	4	main
ei	doc_446470622100_item	2413835	et	4	main
pidurdada	doc_446470622100_item	2413837	et	3	main
jalgrattur	doc_446470622100_item	2413844	et	3	main
lumi	doc_446470622100_item	2413845	et	3	main
katki	doc_446470622100_item	2413864	et	4	main
vigastas	doc_446470622100_item	2413875	et	3	main
ja	doc_446470622100_item	2413892	et	3	main
minu	doc_446470622100_item	2413895	et	3	main
ära	doc_446470622100_item	2413897	et	4	main
filmis	doc_446717232815_item	2413908	et	4	main
kelle	doc_446717232815_item	2413916	et	4	main
on	doc_446717232815_item	2413918	et	4	main
libahundiks	doc_446717232815_item	2413919	et	3	main
hukatud	doc_446717232815_item	2413921	et	4	main
kasvab	doc_446717232815_item	2413923	et	3	main
vabaks	doc_446717232815_item	2413926	et	3	main
metsa	doc_446717232815_item	2413937	et	4	main
et	doc_446717232815_item	2413940	et	3	main
libahunt	doc_446717232815_item	2413941	et	3	main
on	doc_446717232815_item	2413942	et	4	main
ka	doc_446717232815_item	2413946	et	3	main
poeg	doc_446717232815_item	2413950	et	3	main
armastavad	doc_446717232815_item	2413954	et	4	main
kui	doc_446717232815_item	2413956	et	3	main
veel	doc_446717232815_item	2413973	et	4	main
mari	doc_446717232815_item	2413974	et	4	main
kes	doc_446717232815_item	2413980	et	4	main
tiinat	doc_446717232815_item	2413983	et	4	main
mari	doc_446717232815_item	2413986	et	4	main
ta	doc_446717232815_item	2414030	et	4	main
ilusam	doc_446717232815_item	2414032	et	4	main
mari	doc_446717232815_item	2414036	et	4	main
siis	doc_446717232815_item	2414040	et	3	main
tuli	doc_446717232815_item	2414047	et	4	main
kuulata	doc_446717232815_item	2414048	et	4	main
ja	doc_446717232815_item	2414049	et	3	main
ja	doc_446717232815_item	2414051	et	3	main
kui	doc_446717232815_item	2414053	et	3	main
tiinaga	doc_446717232815_item	2414056	et	4	main
aga	doc_446717232815_item	2414066	et	3	main
tiinat	doc_446717232815_item	2414074	et	4	main
arvan	doc_446717232815_item	2414104	et	3	main
siin	doc_446717232815_item	2414106	et	4	main
ta	doc_446717232815_item	2414109	et	4	main
osutus	doc_446076497170_item	2413619	et	4	main
ausaks	doc_446076497170_item	2413620	et	4	main
ja	doc_446076497170_item	2413622	et	3	main
ära	doc_446076497170_item	2413625	et	4	main
ei	doc_446076497170_item	2413628	et	4	main
peategelanna	doc_446076497170_item	2413630	et	4	main
andeks	doc_446076497170_item	2413631	et	3	main
anda	doc_446076497170_item	2413632	et	3	main
elus	doc_446076497170_item	2413644	et	4	main
ühelt	doc_446076497170_item	2413645	et	3	main
olla	doc_446076497170_item	2413647	et	3	main
siis	doc_446076497170_item	2413656	et	3	main
sul	doc_446076497170_item	2413657	et	3	main
sind	doc_446076497170_item	2413663	et	4	main
olema	doc_446076497170_item	2413672	et	4	main
pool	doc_446076497170_item	2413677	et	4	main
valida	doc_446076497170_item	2413696	et	3	main
ära	doc_446076497170_item	2413700	et	4	main
rääkida	doc_446076497170_item	2413701	et	3	main
või	doc_446076497170_item	2413702	et	4	main
siis	doc_446076497170_item	2413703	et	3	main
valetada	doc_446076497170_item	2413704	et	3	main
et	doc_446076497170_item	2413705	et	3	main
päästa	doc_446076497170_item	2413706	et	4	main
seda	doc_446076497170_item	2413707	et	3	main
inimest	doc_446076497170_item	2413708	et	3	main
kurvast	doc_446076497170_item	2413709	et	3	main
saatusest	doc_446076497170_item	2413710	et	4	main
tõsi	doc_446076497170_item	2413711	et	4	main
kui	doc_446076497170_item	2413712	et	3	main
oled	doc_446076497170_item	2413713	et	3	main
siis	doc_446076497170_item	2413715	et	3	main
aus	doc_446076497170_item	2413714	et	4	main
paljud	doc_446076497170_item	2413716	et	3	main
võivad	doc_446076497170_item	2413717	et	4	main
sind	doc_446076497170_item	2413718	et	4	main
armastada	doc_446076497170_item	2413719	et	3	main
aga	doc_446076497170_item	2413720	et	3	main
vihata	doc_446076497170_item	2413723	et	4	main
aususe	doc_446076497170_item	2413725	et	4	main
aga	doc_446076497170_item	2413727	et	3	main
mida	doc_446076497170_item	2413728	et	4	main
teha	doc_446076497170_item	2413729	et	3	main
siis	doc_446076497170_item	2413730	et	3	main
see	doc_446076497170_item	2413731	et	3	main
ise	doc_446076497170_item	2413738	et	4	main
otsustada	doc_446076497170_item	2413739	et	3	main
kas	doc_446076497170_item	2413740	et	3	main
tuleb	doc_446076497170_item	2413744	et	3	main
armastad	doc_446076497170_item	2413749	et	3	main
inimest	doc_446076497170_item	2413750	et	3	main
oled	doc_446076497170_item	2413752	et	3	main
tema	doc_446076497170_item	2413754	et	4	main
seda	doc_446076497170_item	2413761	et	3	main
päästa	doc_446076497170_item	2413763	et	4	main
oled	doc_446076497170_item	2413765	et	3	main
olen	doc_446076497170_item	2413775	et	3	main
läbi	doc_446470622100_item	2413818	et	4	main
minna	doc_446470622100_item	2413819	et	3	main
koer	doc_446470622100_item	2413820	et	3	main
ei	doc_446470622100_item	2413826	et	4	main
mis	doc_446470622100_item	2413831	et	4	main
teiselt	doc_446470622100_item	2413841	et	4	main
oli	doc_446470622100_item	2413846	et	3	main
proovisid	doc_446470622100_item	2413849	et	4	main
enne	doc_446470622100_item	2413865	et	4	main
raske	doc_446076497170_item	2413734	et	4	main
meeles	doc_446076497170_item	2413745	et	3	main
aga	doc_446076497170_item	2413751	et	3	main
ju	doc_446076497170_item	2413758	et	3	main
on	doc_446076497170_item	2413769	et	4	main
br	doc_446076497170_item	2413774	et	4	main
nõus	doc_446076497170_item	2413776	et	4	main
et	doc_446076497170_item	2413777	et	3	main
inimene	doc_446076497170_item	2413779	et	3	main
on	doc_446076497170_item	2413780	et	4	main
kõige	doc_446076497170_item	2413781	et	4	main
hirmsam	doc_446076497170_item	2413782	et	4	main
kogu	doc_446076497170_item	2413783	et	4	main
maailmas	doc_446076497170_item	2413784	et	3	main
sest	doc_446076497170_item	2413785	et	4	main
tema	doc_446076497170_item	2413786	et	4	main
ausus	doc_446076497170_item	2413787	et	4	main
mõnedel	doc_446076497170_item	2413788	et	3	main
juhtudel	doc_446076497170_item	2413789	et	3	main
toob	doc_446076497170_item	2413790	et	3	main
ainult	doc_446076497170_item	2413791	et	4	main
kannatusi	doc_446076497170_item	2413792	et	4	main
ja	doc_446076497170_item	2413793	et	3	main
pärast	doc_446076497170_item	2413794	et	4	main
on	doc_446076497170_item	2413795	et	4	main
raske	doc_446076497170_item	2413796	et	4	main
andeks	doc_446076497170_item	2413797	et	3	main
anda	doc_446076497170_item	2413798	et	3	main
body	doc_446076497170_item	2413799	et	4	main
pildi	doc_446470622100_item	2413800	et	4	main
kirjeldamine	doc_446470622100_item	2413801	et	4	main
pildi	doc_446470622100_item	2413802	et	4	main
kirjeldamine	doc_446470622100_item	2413803	et	4	main
oli	doc_446470622100_item	2413804	et	3	main
talvine	doc_446470622100_item	2413805	et	4	main
ja	doc_446470622100_item	2413806	et	3	main
lumene	doc_446470622100_item	2413807	et	4	main
ilm	doc_446470622100_item	2413808	et	3	main
koeraomanik	doc_446470622100_item	2413809	et	3	main
jalutas	doc_446470622100_item	2413810	et	3	main
vist	doc_446470622100_item	2413815	et	4	main
sel	doc_446470622100_item	2413833	et	3	main
ajal	doc_446470622100_item	2413834	et	4	main
saanud	doc_446470622100_item	2413836	et	4	main
sest	doc_446470622100_item	2413838	et	4	main
oli	doc_446470622100_item	2413839	et	3	main
libe	doc_446470622100_item	2413840	et	3	main
polel	doc_446470622100_item	2413842	et	4	main
sõitis	doc_446470622100_item	2413843	et	3	main
tema	doc_446470622100_item	2413848	et	4	main
kui	doc_446470622100_item	2413851	et	3	main
auto	doc_446470622100_item	2413853	et	4	main
pidurite	doc_446470622100_item	2413854	et	3	main
tegi	doc_446470622100_item	2413862	et	4	main
kui	doc_446470622100_item	2413866	et	3	main
reageerida	doc_446470622100_item	2413868	et	3	main
aga	doc_446470622100_item	2413869	et	3	main
põhilised	doc_446470622100_item	2413870	et	3	main
näinud	doc_446470622100_item	2413880	et	4	main
järsult	doc_446470622100_item	2413890	et	4	main
tragöödia	doc_446717232815_item	2413906	et	4	main
elust	doc_446717232815_item	2413911	et	3	main
tüdruk	doc_446717232815_item	2413915	et	3	main
tragöödia	doc_446717232815_item	2413943	et	4	main
romantilised	doc_446717232815_item	2413947	et	3	main
tammaru	doc_446717232815_item	2413949	et	4	main
margus	doc_446717232815_item	2413951	et	3	main
tiina	doc_446717232815_item	2413953	et	4	main
esimesena	doc_446717232815_item	2413981	et	3	main
eesmärk	doc_446717232815_item	2414023	et	3	main
oli	doc_446717232815_item	2414024	et	3	main
tiinale	doc_446717232815_item	2414026	et	4	main
maksma	doc_446717232815_item	2414028	et	3	main
margusesse	doc_446717232815_item	2414039	et	4	main
oleks	doc_446717232815_item	2414059	et	3	main
mitte	doc_446717232815_item	2414063	et	3	main
alustada	doc_446717232815_item	2414065	et	3	main
mina	doc_446717232815_item	2414103	et	4	main
esimene	doc_446717232815_item	2414108	et	3	main
armastanud	doc_446717232815_item	2414112	et	4	main
ta	doc_446717232815_item	2414115	et	4	main
et	doc_446470622100_item	2413824	et	3	main
sõitnud	doc_446470622100_item	2413832	et	4	main
palju	doc_446470622100_item	2413847	et	4	main
koeraomaniku	doc_446470622100_item	2413863	et	3	main
olid	doc_446470622100_item	2413872	et	4	main
jalgratturil	doc_446470622100_item	2413873	et	3	main
ma	doc_446470622100_item	2413878	et	3	main
ei	doc_446470622100_item	2413879	et	4	main
kahjuks	doc_446470622100_item	2413881	et	4	main
midagi	doc_446470622100_item	2413882	et	4	main
mis	doc_446470622100_item	2413885	et	4	main
sõitis	doc_446470622100_item	2413886	et	3	main
minu	doc_446470622100_item	2413887	et	3	main
ees	doc_446470622100_item	2413888	et	4	main
hakas	doc_446470622100_item	2413889	et	4	main
mina	doc_446470622100_item	2413893	et	4	main
tehtud	doc_446717232815_item	2413903	et	4	main
järgi	doc_446717232815_item	2413907	et	4	main
eestis	doc_446717232815_item	2413912	et	3	main
tekib	doc_446717232815_item	2413929	et	3	main
et	doc_446717232815_item	2413931	et	3	main
libahunt	doc_446717232815_item	2413934	et	3	main
põgeneb	doc_446717232815_item	2413936	et	3	main
vaatamata	doc_446717232815_item	2413938	et	4	main
sellele	doc_446717232815_item	2413939	et	4	main
kõik	doc_446717232815_item	2413957	et	4	main
tiinat	doc_446717232815_item	2413959	et	4	main
et	doc_446717232815_item	2413960	et	3	main
margus	doc_446717232815_item	2413965	et	3	main
ei	doc_446717232815_item	2413966	et	4	main
seda	doc_446717232815_item	2413968	et	3	main
aga	doc_446717232815_item	2413969	et	3	main
nende	doc_446717232815_item	2413970	et	4	main
käitumist	doc_446717232815_item	2413987	et	4	main
võib	doc_446717232815_item	2413988	et	3	main
õigustada	doc_446717232815_item	2413989	et	3	main
võitles	doc_446717232815_item	2413992	et	3	main
oma	doc_446717232815_item	2413993	et	4	main
võib-olla	doc_446717232815_item	2414021	et	3	main
kätte	doc_446717232815_item	2414027	et	4	main
oli	doc_446717232815_item	2414031	et	3	main
mis	doc_446717232815_item	2414037	et	4	main
saan	doc_446717232815_item	2414042	et	4	main
et	doc_446717232815_item	2414044	et	3	main
muidugi	doc_446717232815_item	2414046	et	4	main
elu	doc_446717232815_item	2414058	et	4	main
raske	doc_446717232815_item	2414061	et	4	main
võimatu	doc_446717232815_item	2414064	et	4	main
sellest	doc_446717232815_item	2414067	et	4	main
lähtub	doc_446717232815_item	2414068	et	3	main
ka	doc_446717232815_item	2414069	et	3	main
et	doc_446717232815_item	2414070	et	3	main
ta	doc_446717232815_item	2414071	et	4	main
võiksid	doc_446717232815_item	2414119	et	4	main
kus	doc_446717232815_item	2414122	et	3	main
ei	doc_446717232815_item	2414124	et	4	main
tuntud	doc_446717232815_item	2414125	et	4	main
uut	doc_446717232815_item	2414130	et	3	main
raske	doc_446717232815_item	2414134	et	4	main
see	doc_446717232815_item	2414135	et	3	main
on	doc_446717232815_item	2414136	et	4	main
üldiselt	doc_446717232815_item	2414142	et	4	main
ma	doc_446717232815_item	2414143	et	3	main
ütlen	doc_446717232815_item	2414144	et	3	main
see	doc_446717232815_item	2414146	et	3	main
süüdistati	doc_446717232815_item	2414153	et	3	main
ühiskondlik-poliitilised	doc_446717232816_item	2414183	et	3	main
nimetage	doc_446717232816_item	2414190	et	3	main
tuntumaid	doc_446717232816_item	2414193	et	4	main
nende	doc_446717232816_item	2414196	et	4	main
teoseid	doc_446717232816_item	2414197	et	3	main
3	doc_446717232816_item	2414198	et	2	main
mart	doc_446717232816_item	2414199	et	3	main
lugu	doc_446717232816_item	2414202	et	4	main
rahvas	doc_446717232816_item	2414216	et	4	main
filmirezhisöörina	doc_446717232816_item	2414224	et	4	main
tema	doc_446717232816_item	2414225	et	4	main
valge	doc_446717232816_item	2414228	et	4	main
laev	doc_446717232816_item	2414229	et	3	main
midagi	doc_446717232816_item	2414234	et	4	main
uut	doc_446717232816_item	2414235	et	3	main
ansamble	doc_446717232816_item	2414244	et	4	main
saai	doc_446470622100_item	2413867	et	4	main
traumid	doc_446470622100_item	2413871	et	4	main
ta	doc_446470622100_item	2413874	et	4	main
enam	doc_446470622100_item	2413877	et	4	main
sest	doc_446470622100_item	2413883	et	4	main
auto	doc_446470622100_item	2413884	et	4	main
pidurdama	doc_446470622100_item	2413891	et	3	main
lõhkusin	doc_446470622100_item	2413894	et	3	main
august	doc_446717232815_item	2413904	et	4	main
jutustatakse	doc_446717232815_item	2413909	et	3	main
taluperre	doc_446717232815_item	2413913	et	3	main
orjarahva	doc_446717232815_item	2413924	et	3	main
ja	doc_446717232815_item	2413927	et	3	main
kahtlus	doc_446717232815_item	2413930	et	4	main
ka	doc_446717232815_item	2413932	et	3	main
tüdruk	doc_446717232815_item	2413935	et	3	main
seal	doc_446717232815_item	2413944	et	4	main
on	doc_446717232815_item	2413945	et	4	main
jooned	doc_446717232815_item	2413948	et	3	main
üksteist	doc_446717232815_item	2413955	et	4	main
on	doc_446717232815_item	2413962	et	4	main
libahunt	doc_446717232815_item	2413963	et	3	main
vahel	doc_446717232815_item	2413971	et	4	main
oli	doc_446717232815_item	2413972	et	3	main
ja	doc_446717232815_item	2413979	et	3	main
süüdistas	doc_446717232815_item	2413982	et	3	main
sest	doc_446717232815_item	2413990	et	4	main
armastuse	doc_446717232815_item	2413994	et	4	main
film	doc_446717232815_item	2413900	et	3	main
libahunt	doc_446717232815_item	2413901	et	3	main
on	doc_446717232815_item	2413902	et	4	main
kitzbergi	doc_446717232815_item	2413905	et	4	main
orjaaegsest	doc_446717232815_item	2413910	et	3	main
satub	doc_446717232815_item	2413914	et	3	main
ema	doc_446717232815_item	2413917	et	4	main
peetuna	doc_446717232815_item	2413920	et	4	main
tüdruk	doc_446717232815_item	2413922	et	3	main
keskel	doc_446717232815_item	2413925	et	3	main
erinevaks	doc_446717232815_item	2413928	et	4	main
tüdrukon	doc_446717232815_item	2413933	et	4	main
ja	doc_446717232815_item	2413952	et	3	main
süüdistasid	doc_446717232815_item	2413958	et	4	main
ta	doc_446717232815_item	2413961	et	4	main
ainult	doc_446717232815_item	2413964	et	4	main
usunud	doc_446717232815_item	2413967	et	4	main
kes	doc_446717232815_item	2413975	et	4	main
ka	doc_446717232815_item	2413976	et	3	main
armastas	doc_446717232815_item	2413977	et	3	main
margust	doc_446717232815_item	2413978	et	3	main
ühest	doc_446717232815_item	2413984	et	4	main
küljest	doc_446717232815_item	2413985	et	4	main
ta	doc_446717232815_item	2413991	et	4	main
eest	doc_446717232815_item	2413995	et	4	main
aga	doc_446717232815_item	2413996	et	3	main
teiselt	doc_446717232815_item	2413997	et	4	main
poolt	doc_446717232815_item	2413998	et	4	main
talle	doc_446717232815_item	2413999	et	4	main
oli	doc_446717232815_item	2414000	et	3	main
tähtis	doc_446717232815_item	2414001	et	4	main
ainult	doc_446717232815_item	2414002	et	4	main
oma	doc_446717232815_item	2414003	et	4	main
heaolu	doc_446717232815_item	2414004	et	4	main
ta	doc_446717232815_item	2414005	et	4	main
ei	doc_446717232815_item	2414006	et	4	main
mõtle	doc_446717232815_item	2414007	et	4	main
teistest	doc_446717232815_item	2414008	et	4	main
ta	doc_446717232815_item	2414009	et	4	main
ei	doc_446717232815_item	2414010	et	4	main
mõtle	doc_446717232815_item	2414011	et	4	main
margusest	doc_446717232815_item	2414012	et	4	main
kes	doc_446717232815_item	2414013	et	4	main
ei	doc_446717232815_item	2414014	et	4	main
armastanud	doc_446717232815_item	2414015	et	4	main
teda	doc_446717232815_item	2414016	et	4	main
kes	doc_446717232815_item	2414017	et	4	main
armastas	doc_446717232815_item	2414018	et	3	main
tiinat	doc_446717232815_item	2414019	et	4	main
ja	doc_446717232815_item	2414020	et	3	main
eelkõige	doc_446717232815_item	2414025	et	3	main
sest	doc_446717232815_item	2414029	et	4	main
elavam	doc_446717232815_item	2414034	et	4	main
ma	doc_446717232815_item	2414041	et	3	main
vanemaid	doc_446717232815_item	2414045	et	4	main
ta	doc_446717232815_item	2414054	et	4	main
väga	doc_446717232815_item	2414060	et	3	main
kui	doc_446717232815_item	2414062	et	3	main
armastanud	doc_446717232815_item	2414073	et	4	main
aga	doc_446717232815_item	2414102	et	3	main
et	doc_446717232815_item	2414105	et	3	main
oli	doc_446717232815_item	2414107	et	3	main
läks	doc_446717232815_item	2414116	et	3	main
tiinaga	doc_446717232815_item	2414117	et	4	main
mari	doc_446717232815_item	2414022	et	4	main
ja	doc_446717232815_item	2414033	et	3	main
kui	doc_446717232815_item	2414035	et	3	main
puutub	doc_446717232815_item	2414038	et	3	main
ütelda	doc_446717232815_item	2414043	et	4	main
austada	doc_446717232815_item	2414050	et	3	main
võib-olla	doc_446717232815_item	2414052	et	3	main
läks	doc_446717232815_item	2414055	et	3	main
iseseisvat	doc_446717232815_item	2414057	et	3	main
ei	doc_446717232815_item	2414072	et	4	main
väga	doc_446717232815_item	2414075	et	3	main
tugevasti	doc_446717232815_item	2414076	et	3	main
oma	doc_446717232815_item	2414077	et	4	main
armastuse	doc_446717232815_item	2414078	et	4	main
eest	doc_446717232815_item	2414079	et	4	main
tuleks	doc_446717232815_item	2414080	et	4	main
võidelda	doc_446717232815_item	2414081	et	4	main
aga	doc_446717232815_item	2414082	et	3	main
ta	doc_446717232815_item	2414083	et	4	main
ei	doc_446717232815_item	2414084	et	4	main
saa	doc_446717232815_item	2414085	et	4	main
siin	doc_446717232815_item	2414086	et	4	main
võivad	doc_446717232815_item	2414087	et	4	main
olla	doc_446717232815_item	2414088	et	3	main
kaks	doc_446717232815_item	2414089	et	3	main
asju	doc_446717232815_item	2414090	et	3	main
ta	doc_446717232815_item	2414091	et	4	main
lihtsalt	doc_446717232815_item	2414092	et	4	main
ei	doc_446717232815_item	2414093	et	4	main
armastanud	doc_446717232815_item	2414094	et	4	main
tiinat	doc_446717232815_item	2414095	et	4	main
või	doc_446717232815_item	2414096	et	4	main
oli	doc_446717232815_item	2414098	et	3	main
ta	doc_446717232815_item	2414097	et	4	main
väga	doc_446717232815_item	2414099	et	3	main
nõrk	doc_446717232815_item	2414100	et	3	main
inimene	doc_446717232815_item	2414101	et	3	main
lihtsalt	doc_446717232815_item	2414110	et	4	main
tiinat	doc_446717232815_item	2414113	et	4	main
rännata	doc_446717232815_item	2414120	et	4	main
nad	doc_446717232815_item	2414127	et	3	main
alustada	doc_446717232815_item	2414129	et	3	main
oleks	doc_446717232815_item	2414133	et	3	main
alati	doc_446717232815_item	2414137	et	4	main
raske	doc_446717232815_item	2414138	et	4	main
alustada	doc_446717232815_item	2414139	et	3	main
midagi	doc_446717232815_item	2414140	et	4	main
uut	doc_446717232815_item	2414141	et	3	main
et	doc_446717232815_item	2414145	et	3	main
on	doc_446717232815_item	2414147	et	4	main
inimest	doc_446717232815_item	2414152	et	3	main
selle	doc_446717232815_item	2414154	et	4	main
on	doc_446717232815_item	2414158	et	4	main
kultuuritarbimist	doc_446717232816_item	2414178	et	3	main
muutused	doc_446717232816_item	2414184	et	4	main
vaiksoo	doc_446717232816_item	2414203	et	4	main
muutuma	doc_446717232816_item	2414209	et	4	main
televisioon	doc_446717232816_item	2414219	et	4	main
ei	doc_446717232815_item	2414111	et	4	main
kui	doc_446717232815_item	2414114	et	3	main
seal	doc_446717232815_item	2414126	et	4	main
elu	doc_446717232815_item	2414131	et	4	main
hirmus	doc_446717232815_item	2414149	et	4	main
kui	doc_446717232815_item	2414151	et	3	main
erinev	doc_446717232815_item	2414160	et	4	main
2	doc_446717232816_item	2414181	et	2	main
missugused	doc_446717232816_item	2414182	et	3	main
3	doc_446717232816_item	2414189	et	2	main
eesti	doc_446717232816_item	2414192	et	4	main
kirjanikke	doc_446717232816_item	2414194	et	3	main
ja	doc_446717232816_item	2414195	et	3	main
kodu	doc_446717232816_item	2414201	et	4	main
kino	doc_446717232816_item	2414218	et	4	main
komissarov	doc_446717232816_item	2414220	et	4	main
jõnn	doc_446717232816_item	2414231	et	4	main
ootas	doc_446717232816_item	2414233	et	3	main
läänepoolsemat	doc_446717232816_item	2414237	et	4	main
eestis	doc_446717232816_item	2414248	et	3	main
kassettide	doc_446717232816_item	2414251	et	4	main
aeg	doc_446717232816_item	2414254	et	3	main
ja	doc_446717232816_item	2414256	et	3	main
ei	doc_446717232816_item	2414258	et	4	main
luules	doc_446717232816_item	2414264	et	4	main
vabavärss	doc_446717232816_item	2414266	et	3	main
rohkem	doc_446717232816_item	2414269	et	4	main
klassikaline	doc_446717232816_item	2414270	et	4	main
1960	doc_446717232816_item	2414271	et	2	main
luule	doc_446717232816_item	2414275	et	4	main
oma	doc_446717232816_item	2414312	et	4	main
nii	doc_446717232816_item	2414318	et	3	main
nõukogude	doc_446717232816_item	2414324	et	3	main
ja	doc_446717232816_item	2414330	et	3	main
vabadusena	doc_446717232816_item	2414331	et	4	main
elama	doc_446717232816_item	2414332	et	3	main
maareform	doc_446717232816_item	2414333	et	3	main
maad	doc_446717232816_item	2414334	et	4	main
omanikutele	doc_446717232816_item	2414337	et	4	main
ime	doc_446717232816_item	2414338	et	4	main
mis	doc_446717232816_item	2414340	et	4	main
majandust	doc_446717232816_item	2414352	et	4	main
keeleks	doc_446717232816_item	2414367	et	4	main
1	doc_446717232816_item	2414368	et	2	main
tallinnas	doc_446717232816_item	2414371	et	4	main
haritlaskond	doc_446717232816_item	2414378	et	3	main
ei	doc_446717232816_item	2414387	et	4	main
ajalehe	doc_446717232817_item	2414421	et	3	main
on	doc_446717232817_item	2414428	et	4	main
riigipööre	doc_446717232817_item	2414435	et	4	main
moskvas	doc_446717232817_item	2414436	et	4	main
on	doc_446717232817_item	2414444	et	4	main
tubade	doc_446717232817_item	2414447	et	3	main
mood	doc_446717232817_item	2414450	et	3	main
uudist	doc_446717232817_item	2414461	et	3	main
kõik	doc_446717232817_item	2414462	et	4	main
segaduses	doc_446717232817_item	2414464	et	3	main
filmi	doc_446717232817_item	2414465	et	4	main
kaudu	doc_446717232817_item	2414472	et	3	main
või	doc_446717232817_item	2414491	et	4	main
kõik	doc_446717232817_item	2414494	et	4	main
tagasi	doc_446717232817_item	2414498	et	3	main
ja	doc_446717232817_item	2414532	et	3	main
kaitsta	doc_446717232817_item	2414549	et	4	main
televisioonis	doc_446717232817_item	2414551	et	4	main
on	doc_446717232817_item	2414552	et	4	main
segadus	doc_446717232817_item	2414553	et	3	main
näidatakse	doc_446717232817_item	2414554	et	3	main
tuli	doc_446717232817_item	2414579	et	4	main
poolt	doc_446717232817_item	2414585	et	4	main
filmi	doc_446717232817_item	2414586	et	4	main
lõpus	doc_446717232817_item	2414587	et	4	main
näidatakse	doc_446717232817_item	2414588	et	3	main
kuidas	doc_446717232817_item	2414589	et	3	main
savisaar	doc_446717232817_item	2414590	et	3	main
sõda	doc_446717232817_item	2414598	et	4	main
on	doc_446717232817_item	2414599	et	4	main
inimestele	doc_446717232817_item	2414605	et	3	main
et	doc_446717232817_item	2414607	et	3	main
kõik	doc_446717232817_item	2414611	et	4	main
saab	doc_446717232817_item	2414612	et	3	main
mina	doc_446717232817_item	2414641	et	4	main
nad	doc_446717232815_item	2414118	et	3	main
kaugemale	doc_446717232815_item	2414121	et	4	main
neid	doc_446717232815_item	2414123	et	4	main
saaksid	doc_446717232815_item	2414128	et	4	main
situatsioon	doc_446717232815_item	2414150	et	3	main
teistest	doc_446717232815_item	2414159	et	4	main
aastatel	doc_446717232816_item	2414180	et	4	main
toimusid	doc_446717232816_item	2414185	et	4	main
pärast	doc_446717232816_item	2414187	et	4	main
laar	doc_446717232816_item	2414200	et	3	main
professionaalsemaks	doc_446717232816_item	2414210	et	4	main
sest	doc_446717232816_item	2414211	et	4	main
seda	doc_446717232816_item	2414212	et	3	main
nõutis	doc_446717232816_item	2414213	et	4	main
ja	doc_446717232816_item	2414214	et	3	main
ootas	doc_446717232816_item	2414215	et	3	main
tööd	doc_446717232816_item	2414222	et	4	main
tuntumad	doc_446717232816_item	2414226	et	4	main
tööd	doc_446717232816_item	2414227	et	4	main
rahvas	doc_446717232816_item	2414232	et	4	main
moodsat	doc_446717232816_item	2414236	et	3	main
jõudis	doc_446717232816_item	2414239	et	3	main
beatles	doc_446717232816_item	2414243	et	4	main
arenes	doc_446717232816_item	2414265	et	3	main
muusika	doc_446717232816_item	2414267	et	4	main
koidula	doc_446717232816_item	2414274	et	4	main
arm	doc_446717232816_item	2414280	et	3	main
oli	doc_446717232816_item	2414317	et	3	main
oli	doc_446717232816_item	2414341	et	3	main
1987	doc_446717232816_item	2414343	et	2	main
aastal	doc_446717232816_item	2414344	et	3	main
savisaar	doc_446717232816_item	2414345	et	3	main
kallaste	doc_446717232816_item	2414346	et	4	main
maad	doc_446717232816_item	2414361	et	4	main
muutus	doc_446717232816_item	2414365	et	4	main
endale	doc_446717232816_item	2414382	et	4	main
hirmu	doc_446717232816_item	2414385	et	4	main
välja	doc_446717232817_item	2414425	et	4	main
mis	doc_446717232817_item	2414426	et	4	main
tuli	doc_446717232817_item	2414438	et	4	main
välja	doc_446717232817_item	2414440	et	4	main
mis	doc_446717232817_item	2414442	et	4	main
kõik	doc_446717232817_item	2414457	et	4	main
sisse	doc_446717232817_item	2414466	et	4	main
on	doc_446717232817_item	2414474	et	4	main
inimesed	doc_446717232817_item	2414484	et	3	main
eestist	doc_446717232817_item	2414486	et	3	main
soome	doc_446717232817_item	2414490	et	3	main
kartsid	doc_446717232817_item	2414496	et	4	main
ei	doc_446717232817_item	2414500	et	4	main
ei	doc_446717232817_item	2414504	et	4	main
mööda	doc_446717232817_item	2414521	et	4	main
keegi	doc_446717232817_item	2414534	et	4	main
tea	doc_446717232817_item	2414536	et	4	main
kaitse	doc_446717232817_item	2414546	et	4	main
filmi	doc_446717232817_item	2414555	et	4	main
on	doc_446717232817_item	2414583	et	4	main
jõudsid	doc_446717232817_item	2414593	et	4	main
teletorni	doc_446717232817_item	2414594	et	4	main
iseseisav	doc_446717232817_item	2414603	et	4	main
paraneb	doc_446717232817_item	2414609	et	3	main
korda	doc_446717232817_item	2414613	et	4	main
tolajal	doc_446717232817_item	2414614	et	4	main
muidugi	doc_446717232815_item	2414132	et	4	main
väga	doc_446717232815_item	2414148	et	3	main
eest	doc_446717232815_item	2414155	et	4	main
et	doc_446717232815_item	2414156	et	3	main
ta	doc_446717232815_item	2414157	et	4	main
praegu	doc_446717232815_item	2414161	et	3	main
ka	doc_446717232815_item	2414162	et	3	main
tihti	doc_446717232815_item	2414163	et	3	main
juhtuvad	doc_446717232815_item	2414164	et	4	main
sellised	doc_446717232815_item	2414165	et	4	main
situatsioonid	doc_446717232815_item	2414166	et	3	main
aga	doc_446717232815_item	2414167	et	3	main
tavaliselt	doc_446717232815_item	2414168	et	4	main
nüüd	doc_446717232815_item	2414169	et	4	main
ei	doc_446717232815_item	2414170	et	4	main
tapeti	doc_446717232815_item	2414171	et	3	main
kontrolltöö	doc_446717232816_item	2414172	et	4	main
1	doc_446717232816_item	2414173	et	2	main
millised	doc_446717232816_item	2414174	et	3	main
tunnused	doc_446717232816_item	2414175	et	3	main
iseloomustavad	doc_446717232816_item	2414176	et	4	main
eestlaste	doc_446717232816_item	2414177	et	4	main
19601970ndatel	doc_446717232816_item	2414179	et	4	main
eestis	doc_446717232816_item	2414186	et	3	main
taasiseseisvumist	doc_446717232816_item	2414188	et	3	main
kaasaegseid	doc_446717232816_item	2414191	et	3	main
rummo	doc_446717232816_item	2414204	et	4	main
runnel	doc_446717232816_item	2414205	et	4	main
1	doc_446717232816_item	2414206	et	2	main
kultuur	doc_446717232816_item	2414207	et	3	main
hakkas	doc_446717232816_item	2414208	et	3	main
arenes	doc_446717232816_item	2414217	et	3	main
hakkas	doc_446717232816_item	2414221	et	3	main
kihnu	doc_446717232816_item	2414230	et	4	main
toimus	doc_446717232816_item	2414247	et	3	main
dzhäззifestival	doc_446717232816_item	2414250	et	2	main
ja	doc_446717232816_item	2414252	et	3	main
üldlaulupidu	doc_446717232816_item	2414272	et	4	main
parandada	doc_446717232816_item	2414320	et	3	main
mis	doc_446717232816_item	2414321	et	4	main
ajal	doc_446717232816_item	2414325	et	4	main
rahvas	doc_446717232816_item	2414326	et	4	main
tiitme	doc_446717232816_item	2414347	et	4	main
made	doc_446717232816_item	2414348	et	3	main
aitas	doc_446717232816_item	2414349	et	3	main
ja	doc_446717232816_item	2414370	et	3	main
teadvustanud	doc_446717232816_item	2414381	et	4	main
eksistensionaalsed	doc_446717232816_item	2414384	et	4	main
pealkirjadega	doc_446717232817_item	2414422	et	3	main
tuleb	doc_446717232817_item	2414424	et	3	main
tegemist	doc_446717232817_item	2414429	et	4	main
aasta	doc_446717232817_item	2414431	et	4	main
tegemist	doc_446717232817_item	2414445	et	4	main
igaühel	doc_446717232817_item	2414451	et	3	main
selle	doc_446717232817_item	2414459	et	4	main
olid	doc_446717232817_item	2414463	et	4	main
dokumentaalsed	doc_446717232817_item	2414469	et	3	main
kaadrid	doc_446717232817_item	2414470	et	3	main
mille	doc_446717232817_item	2414471	et	3	main
kergem	doc_446717232817_item	2414475	et	4	main
kõik	doc_446717232817_item	2414480	et	4	main
eestis	doc_446717232817_item	2414482	et	3	main
ära	doc_446717232817_item	2414487	et	4	main
sõita	doc_446717232817_item	2414488	et	3	main
kas	doc_446717232817_item	2414489	et	3	main
kuid	doc_446717232817_item	2414493	et	4	main
ka	doc_446717232817_item	2414495	et	3	main
pärast	doc_446717232817_item	2414499	et	4	main
saa	doc_446717232817_item	2414501	et	4	main
mõned	doc_446717232817_item	2414502	et	3	main
laevad	doc_446717232817_item	2414503	et	4	main
paanika	doc_446717232817_item	2414526	et	4	main
on	doc_446717232817_item	2414528	et	4	main
suits	doc_446717232817_item	2414529	et	3	main
kõik	doc_446717232817_item	2414530	et	4	main
ei	doc_446717232817_item	2414535	et	4	main
mis	doc_446717232817_item	2414537	et	4	main
tuled	doc_446717232817_item	2414538	et	4	main
mis	doc_446717232817_item	2414558	et	4	main
saab	doc_446717232817_item	2414559	et	3	main
sel	doc_446717232817_item	2414560	et	3	main
1103	doc_446717232817_item	2414578	et	2	main
et	doc_446717232817_item	2414581	et	3	main
taasiseseisvuse	doc_446717232817_item	2414584	et	4	main
kindralid	doc_446717232817_item	2414592	et	3	main
juurde	doc_446717232817_item	2414595	et	4	main
sõnad	doc_446717232817_item	2414596	et	4	main
annavad	doc_446717232817_item	2414604	et	3	main
läkin	doc_446717232817_item	2414617	et	4	main
kooli	doc_446717232817_item	2414618	et	4	main
ja	doc_446717232817_item	2414619	et	3	main
isa	doc_446717232817_item	2414627	et	4	main
istusime	doc_446717232817_item	2414628	et	3	main
mis	doc_446717232817_item	2414633	et	4	main
saab	doc_446717232817_item	2414634	et	3	main
mulle	doc_446717232817_item	2414635	et	4	main
see	doc_446717232817_item	2414636	et	3	main
film	doc_446717232817_item	2414637	et	3	main
väga	doc_446717232817_item	2414638	et	3	main
meeldis	doc_446717232817_item	2414639	et	3	main
need	doc_446717232817_item	2414650	et	3	main
eesti	doc_446717232817_item	2414659	et	4	main
kultuuri	doc_446717232818_item	2414669	et	4	main
tegema	doc_446717232816_item	2414223	et	3	main
eestisse	doc_446717232816_item	2414238	et	4	main
rokkn	doc_446717232816_item	2414240	et	4	main
roll	doc_446717232816_item	2414241	et	3	main
the	doc_446717232816_item	2414242	et	4	main
plaatide	doc_446717232816_item	2414253	et	3	main
realismi	doc_446717232816_item	2414263	et	4	main
lydia	doc_446717232816_item	2414273	et	4	main
mu	doc_446717232816_item	2414276	et	3	main
isamaa	doc_446717232816_item	2414277	et	4	main
on	doc_446717232816_item	2414278	et	4	main
ja	doc_446717232816_item	2414281	et	3	main
laul	doc_446717232816_item	2414282	et	4	main
sellel	doc_446717232816_item	2414283	et	4	main
tekstil	doc_446717232816_item	2414284	et	3	main
sai	doc_446717232816_item	2414285	et	4	main
mitteametlikuks	doc_446717232816_item	2414286	et	3	main
hümniks	doc_446717232816_item	2414287	et	3	main
rahvas	doc_446717232816_item	2414288	et	4	main
tahtis	doc_446717232816_item	2414289	et	3	main
kuulata	doc_446717232816_item	2414290	et	4	main
lääne	doc_446717232816_item	2414291	et	4	main
muusikat	doc_446717232816_item	2414292	et	3	main
kanda	doc_446717232816_item	2414293	et	4	main
moodsat	doc_446717232816_item	2414294	et	3	main
rüivad	doc_446717232816_item	2414295	et	4	main
vaadata	doc_446717232816_item	2414296	et	4	main
uusi	doc_446717232816_item	2414297	et	3	main
filmi	doc_446717232816_item	2414298	et	4	main
2	doc_446717232816_item	2414299	et	2	main
eesti	doc_446717232816_item	2414300	et	4	main
hakkas	doc_446717232816_item	2414301	et	3	main
iseseisvalt	doc_446717232816_item	2414302	et	4	main
tegutsema	doc_446717232816_item	2414303	et	3	main
oma	doc_446717232816_item	2414304	et	4	main
valuuta	doc_446717232816_item	2414305	et	4	main
kroon	doc_446717232816_item	2414306	et	3	main
oma	doc_446717232816_item	2414307	et	4	main
maa	doc_446717232816_item	2414308	et	4	main
talupoegade	doc_446717232816_item	2414309	et	3	main
jaoks	doc_446717232816_item	2414310	et	4	main
haarimiseks	doc_446717232816_item	2414311	et	4	main
1964	doc_446717232816_item	2414245	et	2	main
aastal	doc_446717232816_item	2414246	et	3	main
esimene	doc_446717232816_item	2414249	et	3	main
luuletused	doc_446717232816_item	2414255	et	4	main
kunst	doc_446717232816_item	2414257	et	3	main
pidanud	doc_446717232816_item	2414259	et	4	main
rohkem	doc_446717232816_item	2414260	et	4	main
kujundama	doc_446717232816_item	2414261	et	3	main
sotsialistliku	doc_446717232816_item	2414262	et	3	main
oli	doc_446717232816_item	2414268	et	3	main
minu	doc_446717232816_item	2414279	et	3	main
valistsus	doc_446717232816_item	2414313	et	4	main
siin	doc_446717232816_item	2414316	et	4	main
palju	doc_446717232816_item	2414319	et	4	main
savisaar	doc_446717232816_item	2414314	et	3	main
kallaste	doc_446717232816_item	2414315	et	4	main
oli	doc_446717232816_item	2414322	et	3	main
tehtud	doc_446717232816_item	2414323	et	4	main
andsid	doc_446717232816_item	2414335	et	4	main
tagasi	doc_446717232816_item	2414336	et	3	main
parandada	doc_446717232816_item	2414350	et	3	main
demoraatlikud	doc_446717232816_item	2414353	et	4	main
sofhoosid	doc_446717232816_item	2414355	et	4	main
tuleb	doc_446717232816_item	2414356	et	3	main
kinni	doc_446717232816_item	2414357	et	3	main
panna	doc_446717232816_item	2414358	et	4	main
ja	doc_446717232816_item	2414359	et	3	main
anda	doc_446717232816_item	2414360	et	3	main
eesti	doc_446717232816_item	2414363	et	4	main
keel	doc_446717232816_item	2414364	et	4	main
ametlikuks	doc_446717232816_item	2414366	et	3	main
noorte	doc_446717232816_item	2414373	et	3	main
sõpruskonnad	doc_446717232816_item	2414375	et	4	main
uus	doc_446717232816_item	2414376	et	3	main
stalinismi	doc_446717232816_item	2414383	et	4	main
kes	doc_446717232816_item	2414386	et	4	main
pidanud	doc_446717232816_item	2414388	et	4	main
sündmustega	doc_446717232817_item	2414427	et	3	main
1991	doc_446717232817_item	2414430	et	2	main
augusti	doc_446717232817_item	2414432	et	3	main
rezhisööril	doc_446717232817_item	2414437	et	4	main
näidata	doc_446717232817_item	2414441	et	4	main
ajaga	doc_446717232817_item	2414443	et	3	main
tollaegne	doc_446717232817_item	2414446	et	4	main
sisustus	doc_446717232817_item	2414448	et	4	main
soengud	doc_446717232817_item	2414449	et	3	main
kodus	doc_446717232817_item	2414452	et	4	main
oli	doc_446717232817_item	2414453	et	3	main
raadio	doc_446717232817_item	2414454	et	4	main
ja	doc_446717232817_item	2414455	et	3	main
peaaegu	doc_446717232817_item	2414456	et	3	main
hommiku	doc_446717232817_item	2414460	et	3	main
aru	doc_446717232817_item	2414476	et	4	main
kuidas	doc_446717232817_item	2414478	et	3	main
rootsi	doc_446717232817_item	2414492	et	4	main
pidi	doc_446717232816_item	2414327	et	4	main
ümberõppima	doc_446717232816_item	2414328	et	4	main
iseseisvalt	doc_446717232816_item	2414329	et	4	main
organisatsioon	doc_446717232816_item	2414339	et	3	main
asutatud	doc_446717232816_item	2414342	et	4	main
eesti	doc_446717232816_item	2414351	et	4	main
valimised	doc_446717232816_item	2414354	et	4	main
talupoegadele	doc_446717232816_item	2414362	et	3	main
tartus	doc_446717232816_item	2414369	et	3	main
tekkisid	doc_446717232816_item	2414372	et	4	main
kunstnikke	doc_446717232816_item	2414374	et	3	main
noor	doc_446717232816_item	2414377	et	3	main
kes	doc_446717232816_item	2414379	et	4	main
ei	doc_446717232816_item	2414380	et	4	main
oma	doc_446717232816_item	2414389	et	4	main
loominguga	doc_446717232816_item	2414390	et	3	main
tegelema	doc_446717232816_item	2414391	et	3	main
range	doc_446717232816_item	2414392	et	4	main
sotsialismi-realismi	doc_446717232816_item	2414393	et	4	main
valve	doc_446717232816_item	2414394	et	4	main
all	doc_446717232816_item	2414395	et	3	main
loomingus	doc_446717232816_item	2414396	et	3	main
hästi	doc_446717232816_item	2414397	et	3	main
näha	doc_446717232816_item	2414398	et	3	main
vabadusearmastus	doc_446717232816_item	2414399	et	3	main
usk	doc_446717232816_item	2414400	et	3	main
paremasse	doc_446717232816_item	2414401	et	4	main
televisioonis	doc_446717232816_item	2414403	et	4	main
tulevikku	doc_446717232816_item	2414402	et	4	main
hakkasid	doc_446717232816_item	2414404	et	4	main
töötama	doc_446717232816_item	2414405	et	3	main
erialse	doc_446717232816_item	2414406	et	4	main
haridusega	doc_446717232816_item	2414407	et	3	main
eesti	doc_446717232816_item	2414408	et	4	main
soost	doc_446717232816_item	2414409	et	4	main
inimesed	doc_446717232816_item	2414410	et	3	main
essee	doc_446717232817_item	2414411	et	4	main
kui	doc_446717232817_item	2414412	et	3	main
hästi	doc_446717232817_item	2414413	et	3	main
kajastuvad	doc_446717232817_item	2414414	et	4	main
filmis	doc_446717232817_item	2414415	et	4	main
eesti	doc_446717232817_item	2414416	et	4	main
taasiseseisvumissündmused	doc_446717232817_item	2414417	et	3	main
film	doc_446717232817_item	2414418	et	3	main
algab	doc_446717232817_item	2414419	et	3	main
tollaegse	doc_446717232817_item	2414420	et	4	main
kohe	doc_446717232817_item	2414423	et	4	main
riigipööre	doc_446717232817_item	2414433	et	4	main
sõjaväeline	doc_446717232817_item	2414434	et	4	main
hästi	doc_446717232817_item	2414439	et	3	main
kuulsid	doc_446717232817_item	2414458	et	4	main
rezhisöör	doc_446717232817_item	2414467	et	4	main
pani	doc_446717232817_item	2414468	et	4	main
meil	doc_446717232817_item	2414473	et	4	main
saada	doc_446717232817_item	2414477	et	4	main
see	doc_446717232817_item	2414479	et	3	main
toimus	doc_446717232817_item	2414481	et	3	main
paljud	doc_446717232817_item	2414483	et	3	main
tahtsid	doc_446717232817_item	2414485	et	4	main
et	doc_446717232817_item	2414497	et	3	main
väljunud	doc_446717232817_item	2414505	et	4	main
sel	doc_446717232817_item	2414506	et	3	main
päeval	doc_446717232817_item	2414507	et	3	main
piirid	doc_446717232817_item	2414508	et	3	main
pandi	doc_446717232817_item	2414509	et	4	main
kinni	doc_446717232817_item	2414510	et	3	main
merel	doc_446717232817_item	2414511	et	3	main
juba	doc_446717232817_item	2414512	et	3	main
olid	doc_446717232817_item	2414513	et	4	main
vene	doc_446717232817_item	2414514	et	4	main
sõjalaevad	doc_446717232817_item	2414515	et	3	main
dokumentaalkaadritest	doc_446717232817_item	2414516	et	4	main
selgub	doc_446717232817_item	2414517	et	3	main
kuidas	doc_446717232817_item	2414518	et	3	main
tankid	doc_446717232817_item	2414519	et	3	main
sõitsid	doc_446717232817_item	2414520	et	4	main
tänavat	doc_446717232817_item	2414522	et	4	main
inimeste	doc_446717232817_item	2414523	et	3	main
vahel	doc_446717232817_item	2414524	et	4	main
on	doc_446717232817_item	2414525	et	4	main
põgenevad	doc_446717232817_item	2414531	et	4	main
kulminatsiooniline	doc_446717232817_item	2414539	et	4	main
moment	doc_446717232817_item	2414540	et	3	main
filmis	doc_446717232817_item	2414541	et	4	main
oli	doc_446717232817_item	2414542	et	3	main
teletorni	doc_446717232817_item	2414543	et	4	main
rünnatamine	doc_446717232817_item	2414544	et	4	main
liit	doc_446717232817_item	2414547	et	3	main
teletorni	doc_446717232817_item	2414550	et	4	main
kell	doc_446717232817_item	2414577	et	3	main
välja	doc_446717232817_item	2414580	et	4	main
ja	doc_446717232817_item	2414591	et	3	main
poisid	doc_446717232817_item	2414597	et	4	main
on	doc_446717232817_item	2414602	et	4	main
mina	doc_446717232817_item	2414615	et	4	main
juba	doc_446717232817_item	2414616	et	3	main
ise	doc_446717232817_item	2414621	et	4	main
kuidas	doc_446717232817_item	2414623	et	3	main
mina	doc_446717232817_item	2414624	et	4	main
minu	doc_446717232817_item	2414625	et	3	main
emaja	doc_446717232817_item	2414626	et	4	main
ees	doc_446717232817_item	2414630	et	4	main
ootasime	doc_446717232817_item	2414632	et	3	main
tuli	doc_446717232817_item	2414645	et	4	main
hästi	doc_446717232817_item	2414646	et	3	main
õnnelik	doc_446717232817_item	2414657	et	3	main
et	doc_446717232817_item	2414658	et	3	main
kontrolltöö	doc_446717232818_item	2414662	et	4	main
nn	doc_446717232818_item	2414666	et	4	main
üldiseloomustus	doc_446717232818_item	2414670	et	4	main
sest	doc_446717232818_item	2414678	et	4	main
tänavatel	doc_446717232817_item	2414527	et	4	main
mitte	doc_446717232817_item	2414533	et	3	main
eesti	doc_446717232817_item	2414545	et	4	main
proovib	doc_446717232817_item	2414548	et	3	main
kõik	doc_446717232817_item	2414556	et	4	main
ootavad	doc_446717232817_item	2414557	et	4	main
ajal	doc_446717232817_item	2414561	et	4	main
toompeal	doc_446717232817_item	2414562	et	3	main
on	doc_446717232817_item	2414563	et	4	main
juba	doc_446717232817_item	2414564	et	3	main
valmis	doc_446717232817_item	2414565	et	4	main
iseseisvuse	doc_446717232817_item	2414566	et	4	main
deklaratsiooni	doc_446717232817_item	2414567	et	4	main
tekstesines	doc_446717232817_item	2414568	et	4	main
arnold	doc_446717232817_item	2414569	et	4	main
rüütel	doc_446717232817_item	2414570	et	3	main
toimus	doc_446717232817_item	2414571	et	3	main
hääletamine	doc_446717232817_item	2414572	et	4	main
kes	doc_446717232817_item	2414573	et	4	main
on	doc_446717232817_item	2414574	et	4	main
taasiseseisvuse	doc_446717232817_item	2414575	et	4	main
poolt	doc_446717232817_item	2414576	et	4	main
rohkemus	doc_446717232817_item	2414582	et	4	main
läbi	doc_446717232817_item	2414600	et	4	main
eesti	doc_446717232817_item	2414601	et	4	main
lootust	doc_446717232817_item	2414606	et	4	main
elu	doc_446717232817_item	2414608	et	4	main
et	doc_446717232817_item	2414610	et	3	main
mina	doc_446717232817_item	2414620	et	4	main
televiisori	doc_446717232817_item	2414629	et	4	main
ja	doc_446717232817_item	2414631	et	3	main
arvan	doc_446717232817_item	2414642	et	3	main
sündmused	doc_446717232817_item	2414651	et	3	main
olid	doc_446717232817_item	2414653	et	4	main
mina	doc_446717232817_item	2414654	et	4	main
olen	doc_446717232817_item	2414655	et	3	main
väga	doc_446717232817_item	2414656	et	3	main
iseseisvaks	doc_446717232817_item	2414661	et	3	main
sulaperioodi	doc_446717232818_item	2414667	et	4	main
2	doc_446717232818_item	2414671	et	2	main
aima	doc_446717232818_item	2414673	et	4	main
kauge	doc_446717232818_item	2414674	et	4	main
balti	doc_446717232818_item	2414681	et	3	main
pealinnade	doc_446717232818_item	2414682	et	3	main
millisest	doc_446717232818_item	2414694	et	3	main
millal	doc_446717232818_item	2414699	et	3	main
see	doc_446717232818_item	2414700	et	3	main
kultuurilugu	doc_446717232818_item	2414713	et	4	main
filmis	doc_446717232818_item	2414714	et	4	main
esmajoones	doc_446717232818_item	2414715	et	3	main
venemaal	doc_446717232818_item	2414723	et	4	main
liberaalsemaks	doc_446717232818_item	2414735	et	4	main
see	doc_446717232818_item	2414736	et	3	main
mõjutas	doc_446717232818_item	2414737	et	3	main
ka	doc_446717232818_item	2414738	et	3	main
ja	doc_446717232818_item	2414745	et	3	main
valitsesid	doc_446717232818_item	2414747	et	4	main
el	doc_446717232818_item	2414750	et	4	main
loomeinimesi	doc_446717232818_item	2414757	et	4	main
see	doc_446717232818_item	2414769	et	3	main
tulevikku	doc_446717232818_item	2414773	et	4	main
optimistlikud	doc_446717232818_item	2414779	et	3	main
järginud	doc_446717232818_item	2414786	et	4	main
sotsialistliku-realismi	doc_446717232818_item	2414788	et	4	main
ühiskondliku	doc_446717232818_item	2414828	et	3	main
korda	doc_446717232818_item	2414829	et	4	main
psüühikasse	doc_446717232818_item	2414833	et	4	main
seda	doc_446717232818_item	2414836	et	3	main
selle	doc_446717232818_item	2414840	et	4	main
aitasid	doc_446717232818_item	2414843	et	4	main
ühiskonna	doc_446717232818_item	2414846	et	4	main
luules	doc_446717232818_item	2414865	et	4	main
sink	doc_446717232818_item	2414877	et	3	main
muidugi	doc_446717232818_item	2414879	et	4	main
tuli	doc_446717232818_item	2414880	et	4	main
uuris	doc_446717232818_item	2414908	et	4	main
raam	doc_446717232818_item	2414919	et	3	main
hakati	doc_446717232818_item	2414921	et	3	main
kultuuri	doc_446717232818_item	2414930	et	4	main
kutsuti	doc_446717232818_item	2414931	et	3	main
ka	doc_446717232818_item	2414932	et	3	main
tõusid	doc_446717232818_item	2414941	et	4	main
palju	doc_446717232818_item	2414947	et	4	main
samuti	doc_446717232818_item	2414956	et	3	main
see	doc_446717232818_item	2414965	et	3	main
ketist	doc_446717232818_item	2414970	et	3	main
3	doc_446717232818_item	2414975	et	2	main
vahel	doc_446717232818_item	2414978	et	4	main
käsi-käest	doc_446717232818_item	2414981	et	4	main
600	doc_446717232818_item	2414982	et	2	main
asta	doc_446717232818_item	2414988	et	4	main
mäletan	doc_446717232817_item	2414622	et	3	main
ja	doc_446717232817_item	2414640	et	3	main
et	doc_446717232817_item	2414643	et	3	main
mis	doc_446717232817_item	2414652	et	4	main
sai	doc_446717232817_item	2414660	et	4	main
1960	doc_446717232818_item	2414664	et	2	main
vahel	doc_446717232818_item	2414683	et	4	main
moskvale	doc_446717232818_item	2414689	et	4	main
sisendab	doc_446717232818_item	2414690	et	3	main
hirmu	doc_446717232818_item	2414691	et	4	main
see	doc_446717232818_item	2414692	et	3	main
ahel	doc_446717232818_item	2414693	et	3	main
3	doc_446717232818_item	2414709	et	2	main
eesti	doc_446717232818_item	2414710	et	4	main
vaadatud	doc_446717232818_item	2414717	et	4	main
filmide	doc_446717232818_item	2414718	et	3	main
võimul	doc_446717232818_item	2414724	et	3	main
oli	doc_446717232818_item	2414727	et	3	main
veidi	doc_446717232818_item	2414728	et	3	main
ja	doc_446717232818_item	2414740	et	3	main
meie	doc_446717232818_item	2414741	et	4	main
kultuuri	doc_446717232818_item	2414742	et	4	main
ei	doc_446717232818_item	2414759	et	4	main
olnud	doc_446717232818_item	2414760	et	4	main
rängalt	doc_446717232818_item	2414762	et	4	main
saanud	doc_446717232818_item	2414764	et	4	main
stalinismi	doc_446717232818_item	2414765	et	4	main
põlvkond	doc_446717232818_item	2414771	et	3	main
tulevikku	doc_446717232818_item	2414775	et	4	main
nad	doc_446717232818_item	2414777	et	3	main
ning	doc_446717232818_item	2414780	et	3	main
peeti	doc_446717232818_item	2414821	et	4	main
puhtast	doc_446717232818_item	2414823	et	4	main
ühiskonda	doc_446717232818_item	2414827	et	4	main
inimese	doc_446717232818_item	2414832	et	4	main
analüüsida	doc_446717232818_item	2414835	et	3	main
ma	doc_446717232818_item	2414837	et	3	main
avatumaks	doc_446717232818_item	2414850	et	4	main
nähti	doc_446717232818_item	2414854	et	4	main
nendest	doc_446717232818_item	2414857	et	4	main
asjadest	doc_446717232818_item	2414858	et	3	main
võib	doc_446717232818_item	2414859	et	3	main
juba	doc_446717232818_item	2414860	et	3	main
veidi	doc_446717232818_item	2414861	et	3	main
avalikult	doc_446717232818_item	2414862	et	4	main
rääts	doc_446717232818_item	2414878	et	3	main
moora	doc_446717232818_item	2414909	et	4	main
edusamme	doc_446717232818_item	2414918	et	3	main
samuti	doc_446717232818_item	2414920	et	3	main
ka	doc_446717232818_item	2414923	et	3	main
kuldseteks	doc_446717232818_item	2414933	et	4	main
esile	doc_446717232818_item	2414942	et	3	main
samuti	doc_446717232818_item	2414945	et	3	main
teatris	doc_446717232818_item	2414948	et	3	main
kevade	doc_446717232818_item	2414955	et	4	main
60ndad	doc_446717232818_item	2414958	et	4	main
väga	doc_446717232818_item	2414960	et	3	main
aeg	doc_446717232818_item	2414962	et	3	main
räägib	doc_446717232818_item	2414967	et	3	main
kett	doc_446717232818_item	2414972	et	4	main
riigi	doc_446717232818_item	2414977	et	3	main
hoidsid	doc_446717232818_item	2414980	et	4	main
1989	doc_446717232818_item	2414987	et	2	main
mil	doc_446717232818_item	2414991	et	4	main
mööda	doc_446717232818_item	2414993	et	4	main
50	doc_446717232818_item	2414994	et	2	main
teel	doc_446717232818_item	2415023	et	4	main
inimesi	doc_446717232818_item	2415027	et	4	main
ja	doc_446717232818_item	2415028	et	3	main
kett	doc_446717232818_item	2415042	et	4	main
muutis	doc_446717232818_item	2415048	et	3	main
3	doc_446717232818_item	2415060	et	2	main
60ndatel	doc_446717232818_item	2415061	et	4	main
linastus	doc_446717232818_item	2415062	et	4	main
libahunt	doc_446717232818_item	2415069	et	3	main
kajastatakse	doc_446717232818_item	2415070	et	3	main
veel	doc_446717232818_item	2415076	et	4	main
tähtis	doc_446717232818_item	2415086	et	4	main
filmimaailm	doc_446717232818_item	2415090	et	3	main
samuti	doc_446717232818_item	2415094	et	3	main
film	doc_446717232818_item	2415096	et	3	main
eesti	doc_446717232818_item	2415099	et	4	main
filmid	doc_446717232818_item	2415121	et	4	main
rezhisööril	doc_446717232817_item	2414644	et	4	main
välja	doc_446717232817_item	2414647	et	4	main
üle	doc_446717232817_item	2414648	et	3	main
anda	doc_446717232817_item	2414649	et	3	main
1	doc_446717232818_item	2414663	et	2	main
aastate	doc_446717232818_item	2414665	et	3	main
eesti	doc_446717232818_item	2414668	et	4	main
nii	doc_446717232818_item	2414685	et	3	main
aja-	doc_446717232818_item	2414711	et	4	main
ja	doc_446717232818_item	2414712	et	3	main
põhjal	doc_446717232818_item	2414719	et	4	main
1	doc_446717232818_item	2414720	et	2	main
ei	doc_446717232818_item	2414672	et	4	main
korea	doc_446717232818_item	2414675	et	4	main
ega	doc_446717232818_item	2414676	et	3	main
hiina	doc_446717232818_item	2414677	et	3	main
aga	doc_446717232818_item	2414684	et	3	main
toompealt	doc_446717232818_item	2414686	et	3	main
gediminasest	doc_446717232818_item	2414688	et	4	main
sündmusest	doc_446717232818_item	2414695	et	4	main
paimla	doc_446717232818_item	2414697	et	4	main
toimus	doc_446717232818_item	2414701	et	3	main
mida	doc_446717232818_item	2414703	et	4	main
see	doc_446717232818_item	2414704	et	3	main
balti	doc_446717232818_item	2414705	et	3	main
riikide	doc_446717232818_item	2414706	et	3	main
jaoks	doc_446717232818_item	2414707	et	4	main
tähendas	doc_446717232818_item	2414708	et	3	main
loengutes	doc_446717232818_item	2414716	et	4	main
sulaperioodil	doc_446717232818_item	2414721	et	3	main
muutus	doc_446717232818_item	2414734	et	4	main
ajal	doc_446717232818_item	2414751	et	4	main
nad	doc_446717232818_item	2414758	et	3	main
võimu	doc_446717232818_item	2414766	et	4	main
vägivalda	doc_446717232818_item	2414767	et	4	main
ebademokraatiat	doc_446717232818_item	2414768	et	3	main
uus	doc_446717232818_item	2414770	et	3	main
nägi	doc_446717232818_item	2414774	et	3	main
heldena	doc_446717232818_item	2414776	et	3	main
niivõrd	doc_446717232818_item	2414787	et	3	main
jooni	doc_446717232818_item	2414789	et	4	main
siseneda	doc_446717232818_item	2414831	et	3	main
aja	doc_446717232818_item	2414841	et	4	main
muutmisele	doc_446717232818_item	2414847	et	4	main
muutusid	doc_446717232818_item	2414849	et	4	main
neid	doc_446717232818_item	2414852	et	4	main
vabavärssi	doc_446717232818_item	2414868	et	4	main
munder	doc_446717232818_item	2414869	et	3	main
muusikas	doc_446717232818_item	2414870	et	3	main
tuli	doc_446717232818_item	2414871	et	4	main
esile	doc_446717232818_item	2414872	et	3	main
keelt	doc_446717232818_item	2414906	et	4	main
ajalugu	doc_446717232818_item	2414907	et	4	main
oli	doc_446717232818_item	2414912	et	3	main
moodsate	doc_446717232818_item	2414924	et	3	main
teadusharudega	doc_446717232818_item	2414925	et	3	main
psühholoogia	doc_446717232818_item	2414927	et	4	main
keskküla	doc_446717232818_item	2414943	et	4	main
käidi	doc_446717232818_item	2414946	et	3	main
kinos	doc_446717232818_item	2414949	et	3	main
1969	doc_446717232818_item	2414953	et	2	main
linastus	doc_446717232818_item	2414954	et	4	main
kokkuvõttek	doc_446717232818_item	2414957	et	4	main
2	doc_446717232818_item	2414964	et	2	main
luuletus	doc_446717232818_item	2414966	et	4	main
ilmselgelt	doc_446717232818_item	2414968	et	4	main
ju	doc_446717232818_item	2414973	et	3	main
balti	doc_446717232818_item	2414976	et	3	main
inimesed	doc_446717232818_item	2414979	et	3	main
km	doc_446717232818_item	2414983	et	4	main
rahumeelsel	doc_446717232818_item	2415022	et	3	main
koos	doc_446717232818_item	2415034	et	4	main
suudetakse	doc_446717232818_item	2415035	et	3	main
palju	doc_446717232818_item	2415036	et	4	main
et	doc_446717232818_item	2415040	et	3	main
väga	doc_446717232818_item	2415045	et	3	main
nägid	doc_446717232818_item	2415058	et	4	main
seda	doc_446717232818_item	2415059	et	3	main
kevade	doc_446717232818_item	2415066	et	4	main
viimne	doc_446717232818_item	2415067	et	3	main
inimesi	doc_446717232818_item	2415072	et	4	main
elu	doc_446717232818_item	2415073	et	4	main
eestlase	doc_446717232818_item	2415078	et	3	main
kooli	doc_446717232818_item	2415082	et	4	main
elu	doc_446717232818_item	2415083	et	4	main
areneb	doc_446717232818_item	2415092	et	3	main
olu	doc_446717232818_item	2415100	et	4	main
nipernaadi	doc_446717232818_item	2415101	et	4	main
gailiti	doc_446717232818_item	2415102	et	4	main
eesti	doc_446717232818_item	2415105	et	4	main
maaelu	doc_446717232818_item	2415109	et	4	main
inimsuhted	doc_446717232818_item	2415111	et	3	main
need	doc_446717232818_item	2415122	et	3	main
paelast	doc_446717232818_item	2414679	et	4	main
me	doc_446717232818_item	2414680	et	4	main
kui	doc_446717232818_item	2414687	et	3	main
kõneldakse	doc_446717232818_item	2414696	et	3	main
luuletuses	doc_446717232818_item	2414698	et	4	main
ja	doc_446717232818_item	2414702	et	3	main
hrushtshov	doc_446717232818_item	2414725	et	4	main
liberaalsemate	doc_446717232818_item	2414729	et	4	main
eestit	doc_446717232818_item	2414739	et	3	main
pehmenes	doc_446717232818_item	2414744	et	3	main
ühiskonnas	doc_446717232818_item	2414746	et	4	main
optimistlikud	doc_446717232818_item	2414748	et	3	main
meeleolud	doc_446717232818_item	2414749	et	3	main
peale	doc_446717232818_item	2414754	et	4	main
uus	doc_446717232818_item	2414755	et	3	main
põlvkond	doc_446717232818_item	2414756	et	3	main
olid	doc_446717232818_item	2414778	et	4	main
täis	doc_446717232818_item	2414781	et	4	main
elutahet	doc_446717232818_item	2414782	et	3	main
elurõõmu	doc_446717232818_item	2414783	et	4	main
nad	doc_446717232818_item	2414784	et	3	main
oli	doc_446717232818_item	2414722	et	3	main
kes	doc_446717232818_item	2414726	et	4	main
vaadetega	doc_446717232818_item	2414730	et	3	main
ning	doc_446717232818_item	2414731	et	3	main
seega	doc_446717232818_item	2414732	et	4	main
ühiskond	doc_446717232818_item	2414733	et	3	main
tsensuur	doc_446717232818_item	2414743	et	3	main
tuli	doc_446717232818_item	2414752	et	4	main
kultuuris	doc_446717232818_item	2414753	et	3	main
nii	doc_446717232818_item	2414761	et	3	main
tunda	doc_446717232818_item	2414763	et	3	main
vaatas	doc_446717232818_item	2414772	et	3	main
ei	doc_446717232818_item	2414785	et	4	main
vaid	doc_446717232818_item	2414790	et	3	main
pigem	doc_446717232818_item	2414791	et	3	main
otsisid	doc_446717232818_item	2414792	et	4	main
kontakti	doc_446717232818_item	2414793	et	4	main
läänega	doc_446717232818_item	2414794	et	3	main
ning	doc_446717232818_item	2414795	et	3	main
põliste	doc_446717232818_item	2414796	et	4	main
eesti	doc_446717232818_item	2414797	et	4	main
traditsioonidega	doc_446717232818_item	2414798	et	3	main
peale	doc_446717232818_item	2414799	et	4	main
tuli	doc_446717232818_item	2414800	et	4	main
nö	doc_446717232818_item	2414801	et	4	main
kassetipõlvkond	doc_446717232818_item	2414802	et	3	main
runnel	doc_446717232818_item	2414803	et	4	main
vluik	doc_446717232818_item	2414804	et	4	main
eniit	doc_446717232818_item	2414805	et	4	main
jviiding	doc_446717232818_item	2414806	et	4	main
munt	doc_446717232818_item	2414807	et	4	main
mtraat	doc_446717232818_item	2414808	et	4	main
jt	doc_446717232818_item	2414809	et	4	main
kuna	doc_446717232818_item	2414810	et	3	main
tsensuur	doc_446717232818_item	2414811	et	3	main
oli	doc_446717232818_item	2414812	et	3	main
nõrgenenud	doc_446717232818_item	2414813	et	4	main
siis	doc_446717232818_item	2414814	et	3	main
muutusid	doc_446717232818_item	2414815	et	4	main
raamatute	doc_446717232818_item	2414816	et	3	main
süzheed	doc_446717232818_item	2414817	et	4	main
otsiti	doc_446717232818_item	2414818	et	3	main
harmoonilist	doc_446717232818_item	2414819	et	3	main
inimest	doc_446717232818_item	2414820	et	3	main
isegi	doc_446717232818_item	2414825	et	4	main
kritiseeriti	doc_446717232818_item	2414826	et	3	main
inimesed	doc_446717232818_item	2414848	et	3	main
et	doc_446717232818_item	2414856	et	3	main
teha	doc_446717232818_item	2414864	et	3	main
dodekafoon	doc_446717232818_item	2414873	et	4	main
lugu	doc_446717232818_item	2414822	et	4	main
loodusest	doc_446717232818_item	2414824	et	4	main
püüti	doc_446717232818_item	2414830	et	3	main
ja	doc_446717232818_item	2414834	et	3	main
arvan	doc_446717232818_item	2414838	et	3	main
et	doc_446717232818_item	2414839	et	3	main
kirjanikud	doc_446717232818_item	2414842	et	3	main
palju	doc_446717232818_item	2414844	et	4	main
kaasa	doc_446717232818_item	2414845	et	4	main
lugedes	doc_446717232818_item	2414851	et	3	main
raamatuid	doc_446717232818_item	2414853	et	3	main
ju	doc_446717232818_item	2414855	et	3	main
uttu	doc_446717232818_item	2414863	et	3	main
viljeldi	doc_446717232818_item	2414866	et	3	main
enim	doc_446717232818_item	2414867	et	4	main
tuntumad	doc_446717232818_item	2414874	et	4	main
muusikud	doc_446717232818_item	2414875	et	4	main
eestisse	doc_446717232818_item	2414881	et	4	main
ka	doc_446717232818_item	2414882	et	3	main
läänelikku	doc_446717232818_item	2414883	et	4	main
kirjandust	doc_446717232818_item	2414884	et	3	main
ja	doc_446717232818_item	2414885	et	3	main
muusikad	doc_446717232818_item	2414886	et	3	main
the	doc_446717232818_item	2414887	et	4	main
beatles	doc_446717232818_item	2414888	et	4	main
epresley	doc_446717232818_item	2414889	et	4	main
samuti	doc_446717232818_item	2414890	et	3	main
oli	doc_446717232818_item	2414891	et	3	main
veidi	doc_446717232818_item	2414893	et	3	main
märgata	doc_446717232818_item	2414892	et	4	main
ka	doc_446717232818_item	2414894	et	3	main
hipi	doc_446717232818_item	2414895	et	4	main
kultuuri	doc_446717232818_item	2414896	et	4	main
tegutses	doc_446717232818_item	2414897	et	3	main
ka	doc_446717232818_item	2414898	et	3	main
keeleteadlane	doc_446717232818_item	2414899	et	3	main
pariste	doc_446717232818_item	2414900	et	4	main
kes	doc_446717232818_item	2414901	et	4	main
uuris	doc_446717232818_item	2414902	et	4	main
ja	doc_446717232818_item	2414903	et	3	main
arendas	doc_446717232818_item	2414904	et	3	main
eesti	doc_446717232818_item	2414905	et	4	main
apärt	doc_446717232818_item	2414876	et	4	main
kes	doc_446717232818_item	2414910	et	4	main
ka	doc_446717232818_item	2414911	et	3	main
kunstiajaloos	doc_446717232818_item	2414916	et	4	main
etnograafia	doc_446717232818_item	2414913	et	4	main
teaduse	doc_446717232818_item	2414914	et	3	main
taastaja	doc_446717232818_item	2414915	et	4	main
tegi	doc_446717232818_item	2414917	et	4	main
tegelema	doc_446717232818_item	2414922	et	3	main
sotsioloogia	doc_446717232818_item	2414928	et	4	main
60ndate	doc_446717232818_item	2414929	et	4	main
60ndateks	doc_446717232818_item	2414934	et	4	main
arrak	doc_446717232818_item	2414944	et	3	main
oli	doc_446717232818_item	2414959	et	3	main
soodne	doc_446717232818_item	2414961	et	3	main
kultuurile	doc_446717232818_item	2414963	et	3	main
balti	doc_446717232818_item	2414969	et	3	main
balti	doc_446717232818_item	2414971	et	3	main
augustil	doc_446717232818_item	2414990	et	3	main
sai	doc_446717232818_item	2414992	et	4	main
aastat	doc_446717232818_item	2414995	et	3	main
mrp-st	doc_446717232818_item	2414996	et	3	main
balti	doc_446717232818_item	2414997	et	3	main
ühendas	doc_446717232818_item	2415026	et	3	main
üha	doc_446717232818_item	2415029	et	3	main
selgemaks	doc_446717232818_item	2415030	et	4	main
sai	doc_446717232818_item	2415031	et	4	main
see	doc_446717232818_item	2415032	et	3	main
et	doc_446717232818_item	2415033	et	3	main
arvati	doc_446717232818_item	2415039	et	4	main
emotsionaalselt	doc_446717232818_item	2415044	et	4	main
inimeste	doc_446717232818_item	2415049	et	3	main
oma	doc_446717232818_item	2415051	et	4	main
ning	doc_446717232818_item	2415053	et	3	main
samuti	doc_446717232818_item	2415054	et	3	main
välisriigid	doc_446717232818_item	2415055	et	3	main
reliikvia	doc_446717232818_item	2415068	et	4	main
loomust	doc_446717232818_item	2415079	et	4	main
probleeme	doc_446717232818_item	2415081	et	3	main
komissarov	doc_446717232818_item	2415088	et	4	main
eesti	doc_446717232818_item	2415089	et	4	main
ukuaru	doc_446717232818_item	2415097	et	4	main
põhjal	doc_446717232818_item	2415104	et	4	main
inimene	doc_446717232818_item	2415106	et	3	main
muidugi	doc_446717232818_item	2415112	et	4	main
eestit	doc_446717232818_item	2415128	et	3	main
samuti	doc_446717232818_item	2415130	et	3	main
ja	doc_446717232818_item	2415134	et	3	main
kultuuri	doc_446717232818_item	2415136	et	4	main
august	doc_446717232818_item	2415141	et	4	main
minu	doc_446717232818_item	2415143	et	3	main
meeleolu	doc_446717232818_item	2415152	et	4	main
loov	doc_446717232818_item	2415153	et	4	main
eesti	doc_446717232818_item	2415157	et	4	main
on	doc_446717232818_item	2415159	et	4	main
ajalugu	doc_446717232818_item	2415165	et	4	main
vanad	doc_446717232818_item	2415166	et	3	main
eestlased	doc_446717232818_item	2415167	et	3	main
ja	doc_446717232818_item	2415168	et	3	main
metalliaeg	doc_45035221884_item	2415350	et	3	main
1	doc_45035221884_item	2415357	et	2	main
pronksiaeg	doc_45035221884_item	2415361	et	3	main
v	doc_45035221884_item	2415370	et	4	main
küberneetika	doc_446717232818_item	2414926	et	4	main
ühiskonnas	doc_446717232818_item	2414935	et	4	main
toimus	doc_446717232818_item	2414936	et	3	main
ju	doc_446717232818_item	2414937	et	3	main
areng	doc_446717232818_item	2414938	et	3	main
paremuse	doc_446717232818_item	2414939	et	4	main
poolekunstis	doc_446717232818_item	2414940	et	3	main
filmid	doc_446717232818_item	2414950	et	4	main
viimne	doc_446717232818_item	2414951	et	3	main
reliikvia	doc_446717232818_item	2414952	et	4	main
moodustati	doc_446717232818_item	2414974	et	3	main
inimkett	doc_446717232818_item	2414984	et	4	main
see	doc_446717232818_item	2414985	et	3	main
moodustati	doc_446717232818_item	2414986	et	3	main
23	doc_446717232818_item	2414989	et	2	main
riikidele	doc_446717232818_item	2414998	et	3	main
oli	doc_446717232818_item	2414999	et	3	main
see	doc_446717232818_item	2415000	et	3	main
väga	doc_446717232818_item	2415001	et	3	main
tähtis	doc_446717232818_item	2415002	et	4	main
nad	doc_446717232818_item	2415003	et	3	main
näitasid	doc_446717232818_item	2415004	et	4	main
endid	doc_446717232818_item	2415005	et	4	main
maailma	doc_446717232818_item	2415006	et	4	main
areenil	doc_446717232818_item	2415007	et	3	main
näitasid	doc_446717232818_item	2415008	et	4	main
et	doc_446717232818_item	2415009	et	3	main
neil	doc_446717232818_item	2415010	et	4	main
on	doc_446717232818_item	2415011	et	4	main
tugev	doc_446717232818_item	2415012	et	4	main
soov	doc_446717232818_item	2415013	et	3	main
saada	doc_446717232818_item	2415014	et	4	main
iseseisvaks	doc_446717232818_item	2415015	et	3	main
ega	doc_446717232818_item	2415016	et	3	main
soovi	doc_446717232818_item	2415017	et	4	main
mitte	doc_446717232818_item	2415018	et	3	main
sõda	doc_446717232818_item	2415019	et	4	main
vaid	doc_446717232818_item	2415020	et	3	main
vabadust	doc_446717232818_item	2415021	et	4	main
kett	doc_446717232818_item	2415025	et	4	main
saata	doc_446717232818_item	2415038	et	3	main
balti	doc_446717232818_item	2415041	et	3	main
see	doc_446717232818_item	2415047	et	3	main
eesti	doc_446717232818_item	2415064	et	4	main
filme	doc_446717232818_item	2415065	et	3	main
selleaja	doc_446717232818_item	2415071	et	3	main
ühiskonda	doc_446717232818_item	2415074	et	4	main
eriti	doc_446717232818_item	2415077	et	3	main
ning	doc_446717232818_item	2415080	et	3	main
60ndatel	doc_446717232818_item	2415084	et	4	main
oli	doc_446717232818_item	2415085	et	3	main
raamatu	doc_446717232818_item	2415103	et	4	main
kajastab	doc_446717232818_item	2415127	et	3	main
eesti	doc_446717232818_item	2415132	et	4	main
sugulasrahvad	doc_446717232818_item	2415133	et	3	main
tähtis	doc_446717232818_item	2415139	et	4	main
1991	doc_446717232818_item	2415142	et	2	main
isiklik	doc_446717232818_item	2415144	et	3	main
tähtsad	doc_446717232818_item	2415161	et	3	main
balti	doc_446717232818_item	2415024	et	3	main
korda	doc_446717232818_item	2415037	et	4	main
oli	doc_446717232818_item	2415043	et	3	main
tähtis	doc_446717232818_item	2415046	et	4	main
suhtumist	doc_446717232818_item	2415050	et	4	main
riiki	doc_446717232818_item	2415052	et	4	main
tunnetasid	doc_446717232818_item	2415056	et	4	main
ja	doc_446717232818_item	2415057	et	3	main
palju	doc_446717232818_item	2415063	et	4	main
kevades	doc_446717232818_item	2415075	et	4	main
rezhisöör	doc_446717232818_item	2415087	et	4	main
arenes	doc_446717232818_item	2415091	et	3	main
jõudsalt	doc_446717232818_item	2415093	et	4	main
linastus	doc_446717232818_item	2415095	et	4	main
jällegi	doc_446717232818_item	2415098	et	4	main
rännu	doc_446717232818_item	2415107	et	3	main
kihk	doc_446717232818_item	2415108	et	3	main
meri	doc_446717232818_item	2415110	et	3	main
ei	doc_446717232818_item	2415113	et	4	main
saa	doc_446717232818_item	2415114	et	4	main
välja	doc_446717232818_item	2415115	et	4	main
jätta	doc_446717232818_item	2415116	et	3	main
dokumentaalfilme	doc_446717232818_item	2415117	et	3	main
nt	doc_446717232818_item	2415118	et	4	main
mark	doc_446717232818_item	2415119	et	3	main
soosaare	doc_446717232818_item	2415120	et	3	main
aga	doc_446717232818_item	2415129	et	3	main
ka	doc_446717232818_item	2415131	et	3	main
väga	doc_446717232818_item	2415138	et	3	main
emotsionaalselt	doc_446717232818_item	2415146	et	4	main
rahvast	doc_446717232818_item	2415149	et	4	main
iseseisvus	doc_446717232818_item	2415151	et	4	main
filmid	doc_446717232818_item	2415158	et	4	main
olu	doc_446717232818_item	2415169	et	4	main
eestlased	doc_446717232818_item	2415170	et	3	main
on	doc_446717232818_item	2415171	et	4	main
alati	doc_446717232818_item	2415172	et	4	main
filmi	doc_446717232818_item	2415173	et	4	main
ainet	doc_446717232818_item	2415174	et	3	main
saanud	doc_446717232818_item	2415175	et	4	main
elust	doc_446717232818_item	2415176	et	3	main
enesest	doc_446717232818_item	2415177	et	4	main
eesti	doc_446717232818_item	2415178	et	4	main
film	doc_446717232818_item	2415179	et	3	main
on	doc_446717232818_item	2415180	et	4	main
kui	doc_446717232818_item	2415181	et	3	main
ajaloo-allikas	doc_446717232818_item	2415182	et	4	main
on	doc_446717232818_item	2415123	et	4	main
täitsa	doc_446717232818_item	2415124	et	3	main
elust	doc_446717232818_item	2415125	et	3	main
samuti	doc_446717232818_item	2415137	et	3	main
film	doc_446717232818_item	2415140	et	3	main
lemmik	doc_446717232818_item	2415145	et	3	main
tähendusrikas	doc_446717232818_item	2415148	et	4	main
ühendav	doc_446717232818_item	2415150	et	4	main
film	doc_446717232818_item	2415154	et	3	main
et	doc_446717232818_item	2415156	et	3	main
kuna	doc_446717232818_item	2415162	et	3	main
kajastub	doc_446717232818_item	2415164	et	3	main
enesest	doc_446717232818_item	2415126	et	4	main
nende	doc_446717232818_item	2415135	et	4	main
väga	doc_446717232818_item	2415147	et	3	main
arvan	doc_446717232818_item	2415155	et	3	main
väga	doc_446717232818_item	2415160	et	3	main
nendes	doc_446717232818_item	2415163	et	4	main
atekr	doc_45035221884_item	2415363	et	4	main
saj	doc_45035221884_item	2415365	et	4	main
ja	doc_45035221884_item	2415367	et	3	main
varane	doc_45035221884_item	2415368	et	4	main
ajaarvamisevahetus	doc_45035221884_item	2415373	et	4	main
seas	doc_45035221884_item	2415383	et	4	main
domineerisid	doc_45035221884_item	2415384	et	4	main
kirved	doc_45035221884_item	2415385	et	3	main
ja	doc_45035221884_item	2415386	et	3	main
ja	doc_45035221884_item	2415388	et	3	main
avaldas	doc_45035221884_item	2415392	et	3	main
vähe	doc_45035221884_item	2415394	et	3	main
domineeris	doc_45035221884_item	2415398	et	3	main
ja	doc_45035221884_item	2415423	et	3	main
hakati	doc_45035221884_item	2415429	et	3	main
ise	doc_45035221884_item	2415431	et	4	main
sulama	doc_45035221884_item	2415433	et	4	main
viljelusmajandusele	doc_45035221884_item	2415445	et	3	main
uskulised	doc_45035221884_item	2415459	et	4	main
vaated	doc_45035221884_item	2415460	et	3	main
ja	doc_45035221884_item	2415461	et	3	main
üldine	doc_45035221884_item	2415462	et	4	main
nisu	doc_45035221884_item	2415477	et	4	main
kanapit	doc_45035221884_item	2415481	et	4	main
kari	doc_45035221884_item	2415484	et	4	main
uued	doc_45035221884_item	2415521	et	3	main
hakati	doc_45035221884_item	2415523	et	3	main
oli	doc_45035221884_item	2415527	et	3	main
mille	doc_45035221884_item	2415530	et	3	main
sängitati	doc_45035221884_item	2415535	et	3	main
meest	doc_45035221884_item	2415537	et	4	main
kanda	doc_45035221884_item	2415547	et	4	main
luuplaadist	doc_45035221884_item	2415552	et	3	main
kujukesi	doc_45035221884_item	2415556	et	4	main
kujutasid	doc_45035221884_item	2415558	et	4	main
inimesi	doc_45035221884_item	2415565	et	4	main
mille	doc_45035221884_item	2415572	et	3	main
samuti	doc_45035221884_item	2415582	et	3	main
et	doc_45035221884_item	2415584	et	3	main
eesti	doc_45035221885_item	2415598	et	4	main
territooriumil	doc_45035221885_item	2415599	et	3	main
viikingiaeg	doc_45035221885_item	2415605	et	3	main
oli	doc_45035221885_item	2415608	et	3	main
eestlased	doc_45035221885_item	2415611	et	3	main
ka	doc_45035221885_item	2415617	et	3	main
tolleaegsed	doc_45035221885_item	2415622	et	3	main
mis	doc_45035221885_item	2415628	et	4	main
pärast	doc_45035221885_item	2415631	et	4	main
metallid	doc_45035221885_item	2415646	et	3	main
transiitmaa	doc_45035221885_item	2415656	et	4	main
küttimine	doc_45035221885_item	2415668	et	4	main
jne	doc_45035221885_item	2415674	et	4	main
ja	doc_45035221885_item	2415675	et	3	main
loomade	doc_45035221885_item	2415676	et	4	main
kasvataminehobused	doc_45035221885_item	2415677	et	4	main
tulnud	doc_45035221885_item	2415685	et	4	main
teha	doc_45035221885_item	2415690	et	3	main
palvesid	doc_45035221885_item	2415722	et	4	main
küsimusele	doc_45035221884_item	2415347	et	4	main
varane	doc_45035221884_item	2415349	et	4	main
eesti	doc_45035221884_item	2415351	et	4	main
territooriumil	doc_45035221884_item	2415352	et	3	main
mõiste	doc_45035221884_item	2415354	et	4	main
ii	doc_45035221884_item	2415362	et	4	main
saj	doc_45035221884_item	2415371	et	4	main
pronksiaja	doc_45035221884_item	2415374	et	3	main
kohtas	doc_45035221884_item	2415377	et	3	main
lambaid	doc_45035221884_item	2415421	et	3	main
kasutati	doc_45035221884_item	2415426	et	4	main
veoloomadena	doc_45035221884_item	2415428	et	3	main
suur	doc_45035221884_item	2415437	et	3	main
ajaloos	doc_45035221884_item	2415439	et	4	main
see	doc_45035221884_item	2415446	et	3	main
inimeste	doc_45035221884_item	2415456	et	3	main
suhted	doc_45035221884_item	2415458	et	3	main
suhtumine	doc_45035221884_item	2415463	et	4	main
hirssi	doc_45035221884_item	2415478	et	4	main
tol	doc_45035221884_item	2415482	et	3	main
ja	doc_45035221884_item	2415490	et	3	main
nende	doc_45035221884_item	2415492	et	4	main
matmiskombed	doc_45035221884_item	2415522	et	3	main
suur	doc_45035221884_item	2415528	et	3	main
keskel	doc_45035221884_item	2415531	et	3	main
keskele	doc_45035221884_item	2415534	et	3	main
oli	doc_45035221884_item	2415545	et	3	main
või	doc_45035221884_item	2415553	et	4	main
millesed	doc_45035221884_item	2415557	et	4	main
karusid	doc_45035221884_item	2415559	et	3	main
see	doc_45035221884_item	2415566	et	3	main
peab	doc_45035221884_item	2415589	et	4	main
vastus	doc_45035221885_item	2415594	et	3	main
küsimusele	doc_45035221885_item	2415595	et	4	main
1	doc_45035221885_item	2415596	et	2	main
viikingiaeg	doc_45035221885_item	2415597	et	3	main
1	doc_45035221885_item	2415604	et	2	main
territooriumil	doc_45035221885_item	2415607	et	3	main
kuid	doc_45035221885_item	2415615	et	4	main
linnades	doc_45035221885_item	2415618	et	3	main
ja	doc_45035221885_item	2415626	et	3	main
tartu	doc_45035221885_item	2415627	et	4	main
kuulusid	doc_45035221885_item	2415629	et	4	main
ka	doc_45035221885_item	2415630	et	3	main
so	doc_45035221885_item	2415635	et	4	main
kaubanduslik	doc_45035221885_item	2415636	et	3	main
liit	doc_45035221885_item	2415637	et	3	main
linnades	doc_45035221885_item	2415638	et	3	main
toimus	doc_45035221885_item	2415639	et	3	main
kaubanduslik	doc_45035221885_item	2415640	et	3	main
areng	doc_45035221885_item	2415641	et	3	main
sisse	doc_45035221885_item	2415642	et	4	main
rauda	doc_45035221885_item	2415645	et	4	main
viina	doc_45035221885_item	2415647	et	4	main
viidi	doc_45035221885_item	2415649	et	4	main
nahku	doc_45035221885_item	2415650	et	4	main
oder	doc_45035221885_item	2415651	et	3	main
2	doc_45035221884_item	2415353	et	2	main
animism	doc_45035221884_item	2415355	et	3	main
varasele	doc_45035221884_item	2415358	et	4	main
kuuluvad	doc_45035221884_item	2415360	et	4	main
v	doc_45035221884_item	2415364	et	4	main
ekr	doc_45035221884_item	2415366	et	4	main
ekr-	doc_45035221884_item	2415372	et	4	main
esimesel	doc_45035221884_item	2415375	et	3	main
pronksesemeid	doc_45035221884_item	2415378	et	3	main
siis	doc_45035221884_item	2415389	et	3	main
veel	doc_45035221884_item	2415393	et	4	main
majandusele	doc_45035221884_item	2415396	et	4	main
rohkem	doc_45035221884_item	2415399	et	4	main
omaniku	doc_45035221884_item	2415400	et	3	main
hobuseid	doc_45035221884_item	2415424	et	4	main
ka	doc_45035221884_item	2415427	et	3	main
ka	doc_45035221884_item	2415430	et	3	main
pronksi	doc_45035221884_item	2415432	et	4	main
varasel	doc_45035221884_item	2415434	et	4	main
rauaajal	doc_45035221884_item	2415435	et	3	main
oli	doc_45035221884_item	2415436	et	3	main
tõi	doc_45035221884_item	2415447	et	3	main
ümbritsevasse	doc_45035221884_item	2415464	et	4	main
maailma	doc_45035221884_item	2415465	et	4	main
rauaajal	doc_45035221884_item	2415473	et	3	main
kasvatati	doc_45035221884_item	2415474	et	3	main
peamiselt	doc_45035221884_item	2415475	et	4	main
odra	doc_45035221884_item	2415476	et	3	main
tõelised	doc_45035221884_item	2415488	et	4	main
siis	doc_45035221884_item	2415491	et	3	main
kaitsmiseks	doc_45035221884_item	2415493	et	4	main
ehitati	doc_45035221884_item	2415494	et	3	main
kindlustatud	doc_45035221884_item	2415495	et	4	main
vastus	doc_45035221884_item	2415346	et	3	main
1	doc_45035221884_item	2415348	et	2	main
tähendus	doc_45035221884_item	2415356	et	4	main
metalliajale	doc_45035221884_item	2415359	et	3	main
rauaaeg	doc_45035221884_item	2415369	et	3	main
poolel	doc_45035221884_item	2415376	et	4	main
veel	doc_45035221884_item	2415379	et	4	main
odaotsad	doc_45035221884_item	2415387	et	3	main
uus	doc_45035221884_item	2415390	et	3	main
rikkust	doc_45035221884_item	2415401	et	3	main
ja	doc_45035221884_item	2415402	et	3	main
ühiskondliku	doc_45035221884_item	2415403	et	3	main
seisundit	doc_45035221884_item	2415404	et	3	main
pronksiaja	doc_45035221884_item	2415405	et	3	main
teisel	doc_45035221884_item	2415406	et	4	main
poolel	doc_45035221884_item	2415407	et	4	main
tänu	doc_45035221884_item	2415408	et	4	main
metallkirvestele	doc_45035221884_item	2415409	et	4	main
hakkas	doc_45035221884_item	2415410	et	3	main
levima	doc_45035221884_item	2415411	et	3	main
alepõllundus	doc_45035221884_item	2415412	et	3	main
kõige	doc_45035221884_item	2415413	et	4	main
tähtsam	doc_45035221884_item	2415414	et	4	main
elatusala	doc_45035221884_item	2415415	et	4	main
oli	doc_45035221884_item	2415416	et	3	main
koduloomapidamine	doc_45035221884_item	2415417	et	3	main
kasvatati	doc_45035221884_item	2415418	et	3	main
veiseid	doc_45035221884_item	2415419	et	3	main
sigu	doc_45035221884_item	2415420	et	3	main
kitsi	doc_45035221884_item	2415422	et	4	main
majanduselt	doc_45035221884_item	2415444	et	4	main
muutusi	doc_45035221884_item	2415449	et	4	main
tekkisid	doc_45035221884_item	2415466	et	4	main
uut	doc_45035221884_item	2415467	et	3	main
tüüpi	doc_45035221884_item	2415468	et	4	main
asulad	doc_45035221884_item	2415469	et	3	main
ja	doc_45035221884_item	2415470	et	3	main
hooned	doc_45035221884_item	2415471	et	4	main
lina	doc_45035221884_item	2415479	et	4	main
ajal	doc_45035221884_item	2415483	et	4	main
ja	doc_45035221884_item	2415485	et	3	main
pronksesemeid	doc_45035221884_item	2415486	et	3	main
oli	doc_45035221884_item	2415487	et	3	main
asulaid	doc_45035221884_item	2415496	et	4	main
eestis	doc_45035221884_item	2415497	et	3	main
oli	doc_45035221884_item	2415498	et	3	main
ehitama	doc_45035221884_item	2415524	et	4	main
oli	doc_45035221884_item	2415532	et	3	main
2	doc_45035221884_item	2415538	et	2	main
animism	doc_45035221884_item	2415539	et	3	main
on	doc_45035221884_item	2415540	et	4	main
kombeks	doc_45035221884_item	2415546	et	4	main
väikesi	doc_45035221884_item	2415555	et	4	main
või	doc_45035221884_item	2415564	et	4	main
inimesi	doc_45035221884_item	2415578	et	4	main
aidata	doc_45035221884_item	2415579	et	4	main
harva	doc_45035221884_item	2415380	et	4	main
ja	doc_45035221884_item	2415381	et	3	main
nende	doc_45035221884_item	2415382	et	4	main
materjal	doc_45035221884_item	2415391	et	3	main
mõju	doc_45035221884_item	2415395	et	4	main
see	doc_45035221884_item	2415397	et	3	main
mida	doc_45035221884_item	2415425	et	4	main
tähtsus	doc_45035221884_item	2415438	et	4	main
sest	doc_45035221884_item	2415440	et	4	main
toimus	doc_45035221884_item	2415441	et	3	main
üleminek	doc_45035221884_item	2415442	et	3	main
anastavalt	doc_45035221884_item	2415443	et	4	main
kaasa	doc_45035221884_item	2415448	et	4	main
kõigis	doc_45035221884_item	2415450	et	4	main
eluvaldkondades	doc_45035221884_item	2415451	et	3	main
muutus	doc_45035221884_item	2415452	et	4	main
ühiskondlik	doc_45035221884_item	2415453	et	3	main
sotsiaalne	doc_45035221884_item	2415454	et	3	main
struktuur	doc_45035221884_item	2415455	et	3	main
omavahelised	doc_45035221884_item	2415457	et	4	main
varasel	doc_45035221884_item	2415472	et	4	main
ja	doc_45035221884_item	2415480	et	3	main
varandused	doc_45035221884_item	2415489	et	3	main
neid	doc_45035221884_item	2415499	et	4	main
kõige	doc_45035221884_item	2415500	et	4	main
rohkem	doc_45035221884_item	2415501	et	4	main
rannikul	doc_45035221884_item	2415502	et	3	main
tuntud	doc_45035221884_item	2415503	et	4	main
on	doc_45035221884_item	2415504	et	4	main
asva	doc_45035221884_item	2415505	et	4	main
asula	doc_45035221884_item	2415506	et	4	main
saaremaal	doc_45035221884_item	2415507	et	4	main
samuti	doc_45035221884_item	2415508	et	3	main
kasvas	doc_45035221884_item	2415509	et	3	main
mehe	doc_45035221884_item	2415510	et	3	main
roll	doc_45035221884_item	2415511	et	3	main
ühiskonnas	doc_45035221884_item	2415512	et	4	main
ja	doc_45035221884_item	2415513	et	3	main
kujunes	doc_45035221884_item	2415514	et	3	main
nn	doc_45035221884_item	2415515	et	4	main
patriarhaalne	doc_45035221884_item	2415516	et	3	main
suurpere	doc_45035221884_item	2415517	et	4	main
sellest	doc_45035221884_item	2415518	et	4	main
kõnelevad	doc_45035221884_item	2415519	et	4	main
kõigepealt	doc_45035221884_item	2415520	et	3	main
kiviring	doc_45035221884_item	2415529	et	3	main
merevaigust	doc_45035221884_item	2415554	et	4	main
olla	doc_45035221884_item	2415568	et	3	main
animistlike	doc_45035221884_item	2415570	et	3	main
järgi	doc_45035221884_item	2415573	et	4	main
vastavate	doc_45035221884_item	2415574	et	4	main
olendite	doc_45035221884_item	2415575	et	3	main
hing	doc_45035221884_item	2415576	et	3	main
võis	doc_45035221884_item	2415577	et	4	main
arvati	doc_45035221884_item	2415583	et	4	main
elutul	doc_45035221884_item	2415587	et	4	main
eesti	doc_45035221885_item	2415606	et	4	main
maal	doc_45035221885_item	2415614	et	4	main
suuremad	doc_45035221885_item	2415621	et	4	main
olid	doc_45035221885_item	2415624	et	4	main
eestist	doc_45035221885_item	2415648	et	3	main
lina	doc_45035221885_item	2415652	et	4	main
hea	doc_45035221885_item	2415655	et	4	main
sest	doc_45035221885_item	2415657	et	4	main
seos	doc_45035221885_item	2415659	et	3	main
tegevusalaks	doc_45035221885_item	2415666	et	3	main
oli	doc_45035221885_item	2415667	et	3	main
põllumajandus	doc_45035221885_item	2415669	et	3	main
lina	doc_45035221885_item	2415673	et	4	main
gruppidena	doc_45035221885_item	2415693	et	3	main
kivikirstkalmed	doc_45035221884_item	2415525	et	4	main
see	doc_45035221884_item	2415526	et	3	main
kirst	doc_45035221884_item	2415533	et	3	main
tavaliselt	doc_45035221884_item	2415536	et	4	main
seotud	doc_45035221884_item	2415541	et	4	main
muinasuskumustega	doc_45035221884_item	2415542	et	3	main
tol	doc_45035221884_item	2415543	et	3	main
ajal	doc_45035221884_item	2415544	et	4	main
kaelas	doc_45035221884_item	2415548	et	4	main
või	doc_45035221884_item	2415549	et	4	main
riiete	doc_45035221884_item	2415550	et	3	main
küljes	doc_45035221884_item	2415551	et	4	main
kopraid	doc_45035221884_item	2415560	et	4	main
sigu	doc_45035221884_item	2415561	et	3	main
põtru	doc_45035221884_item	2415562	et	3	main
veelinde	doc_45035221884_item	2415563	et	4	main
võib	doc_45035221884_item	2415567	et	3	main
seotud	doc_45035221884_item	2415569	et	4	main
kujutelmadega	doc_45035221884_item	2415571	et	3	main
või	doc_45035221884_item	2415580	et	4	main
ohustada	doc_45035221884_item	2415581	et	3	main
ja	doc_45035221884_item	2415586	et	3	main
loodusel	doc_45035221884_item	2415588	et	4	main
olema	doc_45035221884_item	2415590	et	4	main
hing	doc_45035221884_item	2415591	et	3	main
ja	doc_45035221884_item	2415592	et	3	main
vägi	doc_45035221884_item	2415593	et	3	main
tähendus	doc_45035221885_item	2415603	et	4	main
ekr	doc_45035221885_item	2415610	et	4	main
mõned	doc_45035221885_item	2415616	et	3	main
linnused	doc_45035221885_item	2415619	et	3	main
kõige	doc_45035221885_item	2415620	et	4	main
linnad	doc_45035221885_item	2415623	et	3	main
majajärku	doc_45035221885_item	2415633	et	4	main
hansaliitu	doc_45035221885_item	2415634	et	4	main
soola	doc_45035221885_item	2415644	et	4	main
eesti	doc_45035221885_item	2415653	et	4	main
ta	doc_45035221885_item	2415658	et	4	main
euroopa	doc_45035221885_item	2415660	et	4	main
baltimaad	doc_45035221885_item	2415661	et	4	main
ja	doc_45035221885_item	2415662	et	3	main
kasvatati	doc_45035221885_item	2415670	et	3	main
seda	doc_45035221885_item	2415686	et	3	main
siin	doc_45035221885_item	2415689	et	4	main
inimesed	doc_45035221885_item	2415691	et	3	main
koos	doc_45035221885_item	2415694	et	4	main
inimest	doc_45035221885_item	2415697	et	3	main
kõik	doc_45035221885_item	2415698	et	4	main
kivist	doc_45035221885_item	2415728	et	4	main
raua	doc_45035221885_item	2415733	et	3	main
kui	doc_45035221885_item	2415742	et	3	main
kultuuriloost	doc_450956289271_item	2415761	et	4	main
keskaegne	doc_450956289271_item	2415765	et	3	main
miks	doc_450956289271_item	2415768	et	4	main
elasid	doc_450956289271_item	2415776	et	4	main
ja	doc_450956289271_item	2415779	et	3	main
elas	doc_450956289271_item	2415781	et	3	main
seal	doc_450956289271_item	2415782	et	4	main
ka	doc_450956289271_item	2415783	et	3	main
eestlasi	doc_450956289271_item	2415784	et	3	main
mujalt	doc_450956289271_item	2415785	et	3	main
tulnud	doc_450956289271_item	2415786	et	4	main
eesti	doc_450956289271_item	2415791	et	4	main
võim	doc_450956289271_item	2415796	et	3	main
nad	doc_450956289271_item	2415798	et	3	main
rikad	doc_450956289271_item	2415800	et	4	main
tartu	doc_450956289271_item	2415821	et	4	main
väiksemat	doc_450956289271_item	2415825	et	4	main
narva	doc_450956289271_item	2415827	et	4	main
rapla	doc_450956289271_item	2415828	et	4	main
ja	doc_450956289271_item	2415829	et	3	main
paide	doc_450956289271_item	2415830	et	4	main
igas	doc_450956289271_item	2415831	et	3	main
raad	doc_450956289271_item	2415840	et	4	main
kuhu	doc_450956289271_item	2415841	et	3	main
raehärrat	doc_450956289271_item	2415844	et	3	main
hiljem	doc_450956289271_item	2415845	et	3	main
oli	doc_450956289271_item	2415847	et	3	main
valiti	doc_450956289271_item	2415851	et	3	main
igal	doc_450956289271_item	2415867	et	3	main
põhiliselt	doc_450956289271_item	2415885	et	4	main
lihttöölised	doc_450956289271_item	2415890	et	3	main
kuigi	doc_450956289271_item	2415891	et	3	main
linnas	doc_450956289271_item	2415892	et	4	main
suri	doc_450956289271_item	2415893	et	3	main
vähemaks	doc_450956289271_item	2415897	et	4	main
linnaelanikud	doc_450956289271_item	2415901	et	3	main
linna	doc_450956289271_item	2415909	et	4	main
piires	doc_450956289271_item	2415910	et	4	main
kaubandust	doc_450956289271_item	2415921	et	3	main
kuna	doc_450956289271_item	2415926	et	3	main
rukkist	doc_450956289271_item	2415940	et	4	main
ka	doc_450956289271_item	2415941	et	3	main
sisse	doc_450956289271_item	2415949	et	4	main
heeringat	doc_450956289271_item	2415952	et	3	main
elaval	doc_45035221884_item	2415585	et	4	main
2	doc_45035221885_item	2415600	et	2	main
mõiste	doc_45035221885_item	2415601	et	4	main
muinasaeg	doc_45035221885_item	2415602	et	3	main
5-8saj	doc_45035221885_item	2415609	et	4	main
elasid	doc_45035221885_item	2415612	et	4	main
enamasti	doc_45035221885_item	2415613	et	4	main
tallinn	doc_45035221885_item	2415625	et	4	main
13saj	doc_45035221885_item	2415632	et	4	main
viidi	doc_45035221885_item	2415643	et	4	main
eestlaste	doc_45035221885_item	2415664	et	4	main
peamiseks	doc_45035221885_item	2415665	et	3	main
tatra	doc_45035221885_item	2415671	et	3	main
sead	doc_45035221885_item	2415678	et	4	main
veised	doc_45035221885_item	2415679	et	3	main
jne	doc_45035221885_item	2415680	et	4	main
raud	doc_45035221885_item	2415681	et	3	main
oli	doc_45035221885_item	2415682	et	3	main
juba	doc_45035221885_item	2415683	et	3	main
eestisse	doc_45035221885_item	2415684	et	4	main
ka	doc_45035221885_item	2415688	et	3	main
10-20	doc_45035221885_item	2415696	et	2	main
koos	doc_45035221885_item	2415700	et	4	main
perekond	doc_45035221885_item	2415699	et	3	main
vanematega	doc_45035221885_item	2415701	et	4	main
surnuid	doc_45035221885_item	2415702	et	4	main
maeti	doc_45035221885_item	2415703	et	3	main
maa	doc_45035221885_item	2415704	et	4	main
peale	doc_45035221885_item	2415705	et	4	main
kividest	doc_45035221885_item	2415706	et	3	main
ring	doc_45035221885_item	2415707	et	3	main
keskel	doc_45035221885_item	2415708	et	3	main
oli	doc_45035221885_item	2415709	et	3	main
esimesed	doc_45035221885_item	2415711	et	3	main
rist	doc_45035221885_item	2415710	et	3	main
rändjutustajad	doc_45035221885_item	2415712	et	3	main
hakkasid	doc_45035221885_item	2415713	et	4	main
kolima	doc_45035221885_item	2415714	et	3	main
baltimaades	doc_45035221885_item	2415716	et	4	main
hakati	doc_45035221885_item	2415717	et	3	main
ka	doc_45035221885_item	2415715	et	3	main
rajama	doc_45035221885_item	2415718	et	3	main
kirikuid	doc_45035221885_item	2415719	et	4	main
kus	doc_45035221885_item	2415720	et	3	main
isegi	doc_45035221885_item	2415726	et	4	main
savist	doc_45035221885_item	2415727	et	4	main
muinasaeg	doc_45035221885_item	2415731	et	3	main
aega	doc_45035221885_item	2415737	et	4	main
oli	doc_45035221885_item	2415739	et	3	main
enne	doc_45035221885_item	2415740	et	4	main
seda	doc_45035221885_item	2415741	et	3	main
письменность	doc_45035221885_item	2415745	et	2	main
ja	doc_45035221885_item	2415748	et	3	main
kui	doc_45035221885_item	2415751	et	3	main
1	doc_450956289271_item	2415762	et	2	main
missugune	doc_450956289271_item	2415763	et	3	main
oli	doc_450956289271_item	2415764	et	3	main
linnakultuur	doc_450956289271_item	2415766	et	3	main
vene-liivi	doc_450956289271_item	2415771	et	4	main
keskajal	doc_450956289271_item	2415774	et	3	main
linnas	doc_450956289271_item	2415775	et	4	main
saksalased	doc_450956289271_item	2415778	et	4	main
vähemuses	doc_450956289271_item	2415780	et	4	main
rahvas	doc_450956289271_item	2415787	et	4	main
oli	doc_450956289271_item	2415795	et	3	main
kuna	doc_450956289271_item	2415797	et	3	main
kaupmehed	doc_450956289271_item	2415803	et	3	main
neli	doc_450956289271_item	2415824	et	3	main
tähtsam	doc_450956289271_item	2415836	et	4	main
oli	doc_45035221885_item	2415654	et	3	main
venemaad	doc_45035221885_item	2415663	et	4	main
odra	doc_45035221885_item	2415672	et	3	main
hakati	doc_45035221885_item	2415687	et	3	main
elasid	doc_45035221885_item	2415692	et	4	main
toimusid	doc_45035221885_item	2415721	et	4	main
peamised	doc_45035221885_item	2415723	et	3	main
tööriistad	doc_45035221885_item	2415724	et	3	main
so	doc_45035221885_item	2415732	et	4	main
muinasajaks	doc_45035221885_item	2415735	et	3	main
kirjakeel	doc_45035221885_item	2415744	et	4	main
ja	doc_45035221885_item	2415746	et	3	main
seda	doc_45035221885_item	2415750	et	3	main
oskus	doc_45035221885_item	2415755	et	3	main
kontrolltöö	doc_450956289271_item	2415758	et	4	main
paremini	doc_450956289271_item	2415789	et	4	main
sakslaste	doc_450956289271_item	2415793	et	3	main
veel	doc_450956289271_item	2415823	et	4	main
viljandi	doc_450956289271_item	2415826	et	4	main
oli	doc_450956289271_item	2415839	et	3	main
kuulus	doc_450956289271_item	2415842	et	4	main
üheks	doc_450956289271_item	2415852	et	3	main
oma	doc_450956289271_item	2415870	et	4	main
raad	doc_450956289271_item	2415872	et	4	main
pidi	doc_450956289271_item	2415873	et	4	main
tsunftid	doc_450956289271_item	2415883	et	3	main
kuulusid	doc_450956289271_item	2415886	et	4	main
sakslased	doc_450956289271_item	2415887	et	3	main
eestlased	doc_450956289271_item	2415888	et	3	main
olid	doc_450956289271_item	2415889	et	4	main
kuna	doc_450956289271_item	2415900	et	3	main
katkenud	doc_450956289271_item	2415908	et	4	main
hariti	doc_450956289271_item	2415911	et	3	main
taimi	doc_450956289271_item	2415914	et	4	main
ka	doc_450956289271_item	2415915	et	3	main
oli	doc_450956289271_item	2415916	et	3	main
vahel	doc_450956289271_item	2415925	et	4	main
kaupmehed	doc_450956289271_item	2415928	et	3	main
kaubandus	doc_450956289271_item	2415931	et	3	main
toimus	doc_450956289271_item	2415932	et	3	main
eestit	doc_450956289271_item	2415935	et	3	main
viidi	doc_450956289271_item	2415937	et	4	main
rasva	doc_450956289271_item	2415943	et	4	main
ehituseks	doc_450956289271_item	2415945	et	4	main
jne	doc_450956289271_item	2415957	et	4	main
iv	doc_450956289271_item	2415986	et	4	main
vallutada	doc_450956289271_item	2415991	et	3	main
liivimaa	doc_450956289271_item	2415993	et	4	main
oli	doc_450956289271_item	2416001	et	3	main
pääs	doc_450956289271_item	2416002	et	3	main
et	doc_450956289271_item	2416012	et	3	main
iv	doc_450956289271_item	2416034	et	4	main
maja	doc_45265275512_item	2416053	et	4	main
ja	doc_45265275512_item	2416059	et	3	main
lastetuba	doc_45265275512_item	2416061	et	4	main
ja	doc_45265275512_item	2416062	et	3	main
magamistuba	doc_45265275512_item	2416063	et	4	main
teil	doc_45265275512_item	2416068	et	4	main
ja	doc_45265275513_item	2416113	et	3	main
b	doc_45265275513_item	2416115	et	4	main
ta	doc_45265275513_item	2416121	et	4	main
armastab	doc_45265275513_item	2416123	et	3	main
sina	doc_45265275513_item	2416132	et	4	main
aga	doc_45265275513_item	2416142	et	3	main
xx	doc_45265275513_item	2416146	et	4	main
kui	doc_45265275513_item	2416150	et	3	main
rockstar	doc_45265275514_item	2416188	et	4	main
85	doc_45265275514_item	2416204	et	2	main
vana	doc_45265275514_item	2416217	et	4	main
ma	doc_45265275514_item	2416218	et	3	main
õpin	doc_45265275514_item	2416219	et	3	main
elati	doc_45035221885_item	2415695	et	3	main
puust	doc_45035221885_item	2415729	et	4	main
peetakse	doc_45035221885_item	2415736	et	3	main
mis	doc_45035221885_item	2415738	et	4	main
levitati	doc_45035221885_item	2415743	et	4	main
enne	doc_45035221885_item	2415749	et	4	main
levis	doc_45035221885_item	2415752	et	4	main
eesti	doc_45035221885_item	2415753	et	4	main
talupojade	doc_45035221885_item	2415756	et	3	main
2	doc_450956289271_item	2415767	et	2	main
võimalikuks	doc_450956289271_item	2415770	et	3	main
sõda	doc_450956289271_item	2415772	et	4	main
rahvas	doc_450956289271_item	2415792	et	4	main
käes	doc_450956289271_item	2415794	et	4	main
olid	doc_450956289271_item	2415799	et	4	main
rikalt	doc_450956289271_item	2415801	et	4	main
kullameistrid	doc_450956289271_item	2415804	et	3	main
kuna	doc_450956289271_item	2415805	et	3	main
meister	doc_450956289271_item	2415806	et	3	main
pidi	doc_450956289271_item	2415807	et	4	main
omama	doc_450956289271_item	2415808	et	4	main
varandust	doc_450956289271_item	2415809	et	3	main
pidama	doc_450956289271_item	2415810	et	4	main
uhkeid	doc_450956289271_item	2415811	et	4	main
oidusid	doc_450956289271_item	2415812	et	3	main
ja	doc_450956289271_item	2415813	et	3	main
olema	doc_450956289271_item	2415814	et	4	main
tähtsamad	doc_450956289271_item	2415816	et	4	main
abielumees	doc_450956289271_item	2415815	et	4	main
linnad	doc_450956289271_item	2415817	et	3	main
olid	doc_450956289271_item	2415818	et	4	main
tallinn	doc_450956289271_item	2415819	et	4	main
ja	doc_450956289271_item	2415820	et	3	main
jaid	doc_45035221885_item	2415725	et	4	main
2	doc_45035221885_item	2415730	et	2	main
aeg	doc_45035221885_item	2415734	et	3	main
kristlus	doc_45035221885_item	2415747	et	4	main
keele	doc_45035221885_item	2415754	et	4	main
hulgas	doc_45035221885_item	2415757	et	4	main
kontrolltöö	doc_450956289271_item	2415759	et	4	main
eesti	doc_450956289271_item	2415760	et	4	main
sai	doc_450956289271_item	2415769	et	4	main
1	doc_450956289271_item	2415773	et	2	main
välismaalased	doc_450956289271_item	2415777	et	3	main
elas	doc_450956289271_item	2415788	et	3	main
kui	doc_450956289271_item	2415790	et	3	main
elasid	doc_450956289271_item	2415802	et	4	main
kehtisid	doc_450956289271_item	2415833	et	4	main
omad	doc_450956289271_item	2415834	et	4	main
seadused	doc_450956289271_item	2415835	et	3	main
24	doc_450956289271_item	2415843	et	2	main
raehärrasid	doc_450956289271_item	2415846	et	3	main
12	doc_450956289271_item	2415848	et	2	main
nad	doc_450956289271_item	2415850	et	3	main
linnal	doc_450956289271_item	2415868	et	3	main
raha	doc_450956289271_item	2415871	et	4	main
linnas	doc_450956289271_item	2415877	et	4	main
olid	doc_450956289271_item	2415878	et	4	main
ka	doc_450956289271_item	2415879	et	3	main
kaupmeeste	doc_450956289271_item	2415880	et	4	main
gildid	doc_450956289271_item	2415881	et	3	main
kuhu	doc_450956289271_item	2415884	et	3	main
inimesi	doc_450956289271_item	2415895	et	4	main
muutunud	doc_450956289271_item	2415899	et	4	main
põhiliselt	doc_450956289271_item	2415902	et	4	main
tulid	doc_450956289271_item	2415903	et	4	main
maalt	doc_450956289271_item	2415904	et	3	main
maaga	doc_450956289271_item	2415905	et	3	main
side	doc_450956289271_item	2415906	et	4	main
ja	doc_450956289271_item	2415822	et	3	main
linnas	doc_450956289271_item	2415832	et	4	main
linnas	doc_450956289271_item	2415838	et	4	main
aastaks	doc_450956289271_item	2415853	et	4	main
raad	doc_450956289271_item	2415854	et	4	main
tegeles	doc_450956289271_item	2415855	et	3	main
siseasjadega	doc_450956289271_item	2415856	et	3	main
otsustas	doc_450956289271_item	2415858	et	3	main
raad	doc_450956289271_item	2415857	et	4	main
keda	doc_450956289271_item	2415859	et	4	main
võtta	doc_450956289271_item	2415860	et	3	main
linna	doc_450956289271_item	2415861	et	4	main
elanikuks	doc_450956289271_item	2415862	et	3	main
pidasid	doc_450956289271_item	2415863	et	4	main
ka	doc_450956289271_item	2415864	et	3	main
kohut	doc_450956289271_item	2415865	et	3	main
võimuorgan	doc_450956289271_item	2415837	et	3	main
ja	doc_450956289271_item	2415849	et	3	main
kuna	doc_450956289271_item	2415866	et	3	main
raha	doc_450956289271_item	2415874	et	4	main
ka	doc_450956289271_item	2415875	et	3	main
käsitööliste	doc_450956289271_item	2415882	et	4	main
palju	doc_450956289271_item	2415894	et	4	main
ei	doc_450956289271_item	2415898	et	4	main
kasvatati	doc_450956289271_item	2415913	et	3	main
maahärra	doc_450956289271_item	2415918	et	4	main
kes	doc_450956289271_item	2415919	et	4	main
teostas	doc_450956289271_item	2415920	et	3	main
linna	doc_450956289271_item	2415924	et	4	main
sakslased	doc_450956289271_item	2415930	et	3	main
ka	doc_450956289271_item	2415933	et	3	main
kivi	doc_450956289271_item	2415944	et	4	main
toodi	doc_450956289271_item	2415950	et	4	main
metalle	doc_450956289271_item	2415956	et	3	main
liivi	doc_450956289271_item	2415966	et	4	main
grožnõi	doc_450956289271_item	2415987	et	2	main
väga	doc_450956289271_item	2415989	et	3	main
1	doc_450956289271_item	2416011	et	2	main
liusatakse	doc_450956289271_item	2416014	et	3	main
2	doc_450956289271_item	2416017	et	2	main
oli	doc_450956289271_item	2415869	et	3	main
mündistama	doc_450956289271_item	2415876	et	4	main
tahtjais	doc_450956289271_item	2415896	et	4	main
ei	doc_450956289271_item	2415907	et	4	main
põldu	doc_450956289271_item	2415912	et	4	main
linnal	doc_450956289271_item	2415917	et	3	main
ja	doc_450956289271_item	2415923	et	3	main
põhiliselt	doc_450956289271_item	2415927	et	4	main
olid	doc_450956289271_item	2415929	et	4	main
kala	doc_450956289271_item	2415942	et	4	main
vürtse	doc_450956289271_item	2415953	et	3	main
üldiselt	doc_450956289271_item	2415958	et	4	main
linnaelu	doc_450956289271_item	2415959	et	4	main
arenes	doc_450956289271_item	2415960	et	3	main
arenes	doc_450956289271_item	2415961	et	3	main
ka	doc_450956289271_item	2415962	et	3	main
kaubandus	doc_450956289271_item	2415963	et	3	main
2	doc_450956289271_item	2415964	et	2	main
ivan	doc_450956289271_item	2415985	et	4	main
seal	doc_450956289271_item	2416000	et	4	main
tõi	doc_450956289271_item	2416005	et	3	main
mittu	doc_450956289271_item	2416006	et	4	main
liivi	doc_450956289271_item	2416008	et	4	main
sõda	doc_450956289271_item	2416009	et	4	main
õigeuskliku	doc_450956289271_item	2416016	et	3	main
nad	doc_450956289271_item	2416019	et	3	main
vene	doc_450956289271_item	2416028	et	4	main
territoorium	doc_450956289271_item	2416029	et	3	main
alustas	doc_450956289271_item	2416036	et	3	main
sõda	doc_450956289271_item	2416038	et	4	main
dialoog	doc_45265275512_item	2416042	et	3	main
a	doc_45265275512_item	2416043	et	4	main
tere	doc_45265275512_item	2416044	et	3	main
b	doc_45265275512_item	2416045	et	4	main
tere	doc_45265275512_item	2416046	et	3	main
on	doc_45265275512_item	2416064	et	4	main
teisel	doc_45265275512_item	2416065	et	4	main
korrusel	doc_45265275512_item	2416066	et	3	main
a	doc_45265275512_item	2416067	et	4	main
ei	doc_45265275512_item	2416080	et	4	main
emaga	doc_45265275513_item	2416114	et	3	main
ela	doc_45265275513_item	2416117	et	4	main
väikevendiga	doc_45265275513_item	2416120	et	4	main
maa	doc_450956289271_item	2415922	et	4	main
väljaspool	doc_450956289271_item	2415934	et	3	main
eestist	doc_450956289271_item	2415936	et	3	main
välja	doc_450956289271_item	2415938	et	4	main
teravilja	doc_450956289271_item	2415939	et	4	main
lina	doc_450956289271_item	2415946	et	4	main
ja	doc_450956289271_item	2415947	et	3	main
kanepitaimi	doc_450956289271_item	2415948	et	4	main
soola	doc_450956289271_item	2415951	et	4	main
humalaid	doc_450956289271_item	2415954	et	3	main
sõda	doc_450956289271_item	2415967	et	4	main
liivimaa	doc_450956289271_item	2415968	et	4	main
aadlikud	doc_450956289271_item	2415969	et	3	main
elasid	doc_450956289271_item	2415970	et	4	main
liiga	doc_450956289271_item	2415971	et	4	main
hästi	doc_450956289271_item	2415972	et	3	main
ja	doc_450956289271_item	2415973	et	3	main
nad	doc_450956289271_item	2415974	et	3	main
muutusid	doc_450956289271_item	2415975	et	4	main
laisaks	doc_450956289271_item	2415976	et	4	main
ja	doc_450956289271_item	2415977	et	3	main
etevaatlikus	doc_450956289271_item	2415978	et	4	main
kadus	doc_450956289271_item	2415979	et	3	main
sel	doc_450956289271_item	2415980	et	3	main
ajal	doc_450956289271_item	2415981	et	4	main
venemaal	doc_450956289271_item	2415982	et	4	main
troonile	doc_450956289271_item	2415983	et	3	main
istus	doc_450956289271_item	2415984	et	4	main
veine	doc_450956289271_item	2415955	et	3	main
enne	doc_450956289271_item	2415965	et	4	main
armastas	doc_450956289271_item	2415990	et	3	main
ja	doc_450956289271_item	2415992	et	3	main
pakus	doc_450956289271_item	2415994	et	3	main
erilist	doc_450956289271_item	2415996	et	4	main
huvi	doc_450956289271_item	2415997	et	4	main
sellepärast	doc_450956289271_item	2415998	et	3	main
et	doc_450956289271_item	2415999	et	3	main
ta	doc_450956289271_item	2416004	et	4	main
algatamiseks	doc_450956289271_item	2416010	et	4	main
taga	doc_450956289271_item	2416015	et	4	main
kaubelda	doc_450956289271_item	2416022	et	4	main
grožnõi	doc_450956289271_item	2416035	et	2	main
1558	doc_450956289271_item	2416039	et	2	main
dialoog	doc_45265275512_item	2416041	et	3	main
sisse	doc_45265275512_item	2416049	et	4	main
see	doc_45265275512_item	2416050	et	3	main
on	doc_45265275512_item	2416051	et	4	main
esimesel	doc_45265275512_item	2416054	et	3	main
on	doc_45265275512_item	2416069	et	4	main
teie	doc_45265275512_item	2416074	et	4	main
majas	doc_45265275512_item	2416075	et	3	main
auto	doc_45265275513_item	2416124	et	4	main
oli	doc_45265275513_item	2416128	et	3	main
never	doc_45265275513_item	2416130	et	4	main
olen	doc_45265275513_item	2416139	et	3	main
sa	doc_45265275513_item	2416152	et	3	main
ma	doc_45265275513_item	2416155	et	3	main
vana	doc_45265275513_item	2416159	et	4	main
dialoog	doc_45265275514_item	2416160	et	3	main
c	doc_45265275514_item	2416161	et	4	main
tere	doc_45265275514_item	2416162	et	3	main
kuulus	doc_45265275514_item	2416187	et	4	main
ainult	doc_45265275514_item	2416192	et	4	main
kui	doc_45265275514_item	2416208	et	3	main
sina	doc_45265275514_item	2416210	et	4	main
100	doc_45265275514_item	2416215	et	2	main
aalstat	doc_45265275514_item	2416216	et	4	main
väga	doc_45265275514_item	2416222	et	3	main
esimese	doc_453262085738_item	2416229	et	3	main
on	doc_453262085738_item	2416231	et	4	main
luule	doc_453262085738_item	2416232	et	4	main
luuletus	doc_453262085738_item	2416239	et	4	main
marie	doc_453262085738_item	2416240	et	4	main
under	doc_453262085738_item	2416241	et	4	main
nagu	doc_453262085738_item	2416257	et	3	main
1920-30	doc_453262085738_item	2416266	et	2	main
sobiv	doc_453262085738_item	2416271	et	4	main
inimene	doc_453262085738_item	2416275	et	3	main
suudlus	doc_453262085738_item	2416277	et	3	main
sama	doc_453262085738_item	2416282	et	4	main
head	doc_453262085738_item	2416283	et	4	main
kes	doc_450956289271_item	2415988	et	4	main
talle	doc_450956289271_item	2415995	et	4	main
merele	doc_450956289271_item	2416003	et	3	main
põhjust	doc_450956289271_item	2416007	et	4	main
seal	doc_450956289271_item	2416013	et	4	main
et	doc_450956289271_item	2416018	et	3	main
takkistavad	doc_450956289271_item	2416020	et	4	main
venemaal	doc_450956289271_item	2416021	et	4	main
3	doc_450956289271_item	2416024	et	2	main
liivimaa	doc_450956289271_item	2416025	et	4	main
on	doc_450956289271_item	2416026	et	4	main
iidne	doc_450956289271_item	2416027	et	3	main
ivan	doc_450956289271_item	2416033	et	4	main
meie	doc_45265275512_item	2416052	et	4	main
esik	doc_45265275512_item	2416057	et	3	main
ilus	doc_45265275512_item	2416071	et	4	main
maja	doc_45265275512_item	2416072	et	4	main
on	doc_45265275512_item	2416076	et	4	main
ka	doc_45265275512_item	2416077	et	3	main
saun	doc_45265275512_item	2416078	et	3	main
b	doc_45265275512_item	2416079	et	4	main
aga	doc_45265275513_item	2416125	et	3	main
ei	doc_45265275513_item	2416127	et	4	main
a	doc_45265275513_item	2416137	et	4	main
ma	doc_45265275513_item	2416138	et	3	main
brasiliast	doc_45265275513_item	2416141	et	4	main
on	doc_45265275513_item	2416147	et	4	main
küla	doc_45265275513_item	2416149	et	4	main
b	doc_45265275513_item	2416154	et	4	main
olen	doc_45265275513_item	2416156	et	3	main
aastat	doc_45265275513_item	2416158	et	3	main
praegu	doc_45265275514_item	2416190	et	3	main
harva	doc_45265275514_item	2416193	et	4	main
teen	doc_45265275514_item	2416194	et	3	main
muusikat	doc_45265275514_item	2416195	et	3	main
kui	doc_45265275514_item	2416197	et	3	main
väike	doc_45265275514_item	2416206	et	4	main
d	doc_45265275514_item	2416212	et	4	main
ma	doc_45265275514_item	2416213	et	3	main
olen	doc_45265275514_item	2416214	et	3	main
nägemist	doc_45265275514_item	2416224	et	4	main
aega	doc_45265275514_item	2416226	et	4	main
see	doc_453262085738_item	2416235	et	3	main
avalikult	doc_453262085738_item	2416243	et	4	main
ja	doc_453262085738_item	2416244	et	3	main
ja	doc_453262085738_item	2416262	et	3	main
tema	doc_453262085738_item	2416264	et	4	main
selle	doc_453262085738_item	2416272	et	4	main
või	doc_453262085738_item	2416280	et	4	main
momentid	doc_453262085738_item	2416286	et	4	main
oma	doc_453262085738_item	2416287	et	4	main
saa	doc_45618460770_item	2416448	et	4	main
tihti	doc_45618460770_item	2416449	et	3	main
seletada	doc_45618460770_item	2416450	et	3	main
nagu	doc_45618460770_item	2416472	et	3	main
euroopaga	doc_450956289271_item	2416023	et	3	main
nende	doc_450956289271_item	2416030	et	4	main
ettekäänete	doc_450956289271_item	2416031	et	3	main
abil	doc_450956289271_item	2416032	et	4	main
liivi	doc_450956289271_item	2416037	et	4	main
aastal	doc_450956289271_item	2416040	et	3	main
tulemast	doc_45265275512_item	2416047	et	4	main
tule	doc_45265275512_item	2416048	et	4	main
korrusel	doc_45265275512_item	2416055	et	3	main
on	doc_45265275512_item	2416056	et	4	main
köök	doc_45265275512_item	2416058	et	3	main
elutuba	doc_45265275512_item	2416060	et	4	main
väga	doc_45265275512_item	2416070	et	3	main
kas	doc_45265275512_item	2416073	et	3	main
ole	doc_45265275512_item	2416081	et	4	main
saun	doc_45265275512_item	2416082	et	3	main
on	doc_45265275512_item	2416083	et	4	main
maja	doc_45265275512_item	2416084	et	4	main
taga	doc_45265275512_item	2416085	et	4	main
aias	doc_45265275512_item	2416086	et	4	main
me	doc_45265275512_item	2416087	et	4	main
käime	doc_45265275512_item	2416088	et	4	main
saunasse	doc_45265275512_item	2416089	et	3	main
tavaliselt	doc_45265275512_item	2416090	et	4	main
nädalavahetusel	doc_45265275512_item	2416091	et	4	main
b	doc_45265275513_item	2416093	et	4	main
ma	doc_45265275513_item	2416094	et	3	main
olen	doc_45265275513_item	2416095	et	3	main
dialoog	doc_45265275513_item	2416092	et	3	main
sündinud	doc_45265275513_item	2416096	et	4	main
xxs	doc_45265275513_item	2416097	et	4	main
ta	doc_45265275513_item	2416098	et	4	main
on	doc_45265275513_item	2416099	et	4	main
väike	doc_45265275513_item	2416100	et	4	main
küla	doc_45265275513_item	2416101	et	4	main
saksamaal	doc_45265275513_item	2416102	et	4	main
ei	doc_45265275513_item	2416103	et	4	main
palju	doc_45265275513_item	2416104	et	4	main
inimesi	doc_45265275513_item	2416105	et	4	main
elavad	doc_45265275513_item	2416106	et	4	main
siin	doc_45265275513_item	2416107	et	4	main
a	doc_45265275513_item	2416108	et	4	main
kas	doc_45265275513_item	2416109	et	3	main
sa	doc_45265275513_item	2416110	et	3	main
elad	doc_45265275513_item	2416111	et	3	main
isaga	doc_45265275513_item	2416112	et	3	main
ei	doc_45265275513_item	2416116	et	4	main
ma	doc_45265275513_item	2416118	et	3	main
elan	doc_45265275513_item	2416119	et	3	main
ta	doc_45265275513_item	2416126	et	4	main
tšampion	doc_45265275513_item	2416129	et	2	main
aga	doc_45265275513_item	2416131	et	3	main
kust	doc_45265275513_item	2416133	et	4	main
sa	doc_45265275513_item	2416134	et	3	main
ka	doc_45265275513_item	2416144	et	3	main
xxs	doc_45265275513_item	2416145	et	4	main
oled	doc_45265275513_item	2416153	et	3	main
c	doc_45265275514_item	2416201	et	4	main
ma	doc_45265275514_item	2416202	et	3	main
olen	doc_45265275514_item	2416203	et	3	main
aastat	doc_45265275514_item	2416205	et	3	main
ülikoolis	doc_45265275514_item	2416220	et	4	main
analüüs	doc_453262085738_item	2416227	et	3	main
on	doc_453262085738_item	2416236	et	4	main
tunnete	doc_453262085738_item	2416238	et	4	main
ja	doc_453262085738_item	2416249	et	3	main
under	doc_453262085738_item	2416259	et	4	main
nagu	doc_453262085738_item	2416263	et	3	main
aastatel	doc_453262085738_item	2416267	et	4	main
on	doc_453262085738_item	2416269	et	4	main
luuletusele	doc_453262085738_item	2416273	et	4	main
ta	doc_453262085738_item	2416278	et	4	main
tunneb	doc_453262085738_item	2416279	et	3	main
ka	doc_45265275513_item	2416122	et	3	main
pärit	doc_45265275513_item	2416135	et	3	main
oled	doc_45265275513_item	2416136	et	3	main
pärit	doc_45265275513_item	2416140	et	3	main
elan	doc_45265275513_item	2416143	et	3	main
ilus	doc_45265275513_item	2416148	et	4	main
vana	doc_45265275513_item	2416151	et	4	main
40	doc_45265275513_item	2416157	et	2	main
d	doc_45265275514_item	2416163	et	4	main
tere	doc_45265275514_item	2416164	et	3	main
kuidas	doc_45265275514_item	2416165	et	3	main
läheb	doc_45265275514_item	2416166	et	3	main
c	doc_45265275514_item	2416167	et	4	main
tänan	doc_45265275514_item	2416168	et	3	main
hästi	doc_45265275514_item	2416169	et	3	main
aga	doc_45265275514_item	2416170	et	3	main
sinul	doc_45265275514_item	2416171	et	3	main
d	doc_45265275514_item	2416172	et	4	main
aitäh	doc_45265275514_item	2416173	et	3	main
pole	doc_45265275514_item	2416174	et	3	main
viga	doc_45265275514_item	2416175	et	4	main
kuidas	doc_45265275514_item	2416176	et	3	main
sinu	doc_45265275514_item	2416177	et	3	main
nimi	doc_45265275514_item	2416178	et	3	main
on	doc_45265275514_item	2416179	et	4	main
c	doc_45265275514_item	2416180	et	4	main
minu	doc_45265275514_item	2416181	et	3	main
nimi	doc_45265275514_item	2416182	et	3	main
on	doc_45265275514_item	2416183	et	4	main
kaido	doc_45265275514_item	2416184	et	4	main
ma	doc_45265275514_item	2416185	et	3	main
olen	doc_45265275514_item	2416186	et	3	main
aga	doc_45265275514_item	2416189	et	3	main
ma	doc_45265275514_item	2416191	et	3	main
d	doc_45265275514_item	2416196	et	4	main
vana	doc_45265275514_item	2416198	et	4	main
sa	doc_45265275514_item	2416199	et	3	main
oled	doc_45265275514_item	2416200	et	3	main
naerab	doc_45265275514_item	2416207	et	3	main
vana	doc_45265275514_item	2416209	et	4	main
oled	doc_45265275514_item	2416211	et	3	main
c	doc_45265275514_item	2416221	et	4	main
dhead	doc_45265275514_item	2416225	et	4	main
suudluse	doc_453262085738_item	2416228	et	3	main
plaanil	doc_453262085738_item	2416230	et	3	main
kangelaste	doc_453262085738_item	2416233	et	4	main
läbielamised	doc_453262085738_item	2416234	et	3	main
absolutselt	doc_453262085738_item	2416242	et	4	main
tundedest	doc_453262085738_item	2416248	et	4	main
intiimsest	doc_453262085738_item	2416251	et	3	main
marie	doc_453262085738_item	2416258	et	4	main
elu	doc_453262085738_item	2416261	et	4	main
väga	doc_453262085738_item	2416270	et	3	main
kui	doc_453262085738_item	2416274	et	3	main
loeb	doc_453262085738_item	2416276	et	3	main
meenutab	doc_453262085738_item	2416281	et	3	main
ja	doc_453262085738_item	2416284	et	3	main
pingelik	doc_453262085738_item	2416285	et	4	main
panevad	doc_45618460770_item	2416439	et	4	main
panevad	doc_45618460770_item	2416444	et	4	main
mõtlema	doc_45618460770_item	2416445	et	3	main
me	doc_45618460770_item	2416446	et	4	main
ei	doc_45618460770_item	2416447	et	4	main
toimub	doc_45618460770_item	2416454	et	3	main
signaal	doc_45618460770_item	2416473	et	3	main
meile	doc_45618460770_item	2416474	et	4	main
et	doc_45618460770_item	2416475	et	3	main
inimene	doc_45618460770_item	2416476	et	3	main
on	doc_45618460770_item	2416477	et	4	main
isegi	doc_45618460770_item	2416483	et	4	main
me	doc_45618460770_item	2416486	et	4	main
saa	doc_45618460770_item	2416488	et	4	main
ellu	doc_45618460770_item	2416489	et	4	main
palju	doc_45618460770_item	2416494	et	4	main
valime	doc_45618460770_item	2416502	et	3	main
kahju	doc_45618460770_item	2416511	et	4	main
looduse	doc_45618460770_item	2416522	et	4	main
kool	doc_45618460771_item	2416539	et	4	main
lahendada	doc_45618460771_item	2416548	et	3	main
kes	doc_45618460771_item	2416552	et	4	main
ei	doc_45618460771_item	2416553	et	4	main
hakata	doc_45618460771_item	2416562	et	4	main
ole	doc_45618460771_item	2416566	et	4	main
füüsikat	doc_45618460771_item	2416574	et	3	main
eesti	doc_45618460771_item	2416615	et	4	main
keel	doc_45618460771_item	2416616	et	4	main
võõras	doc_45618460771_item	2416622	et	4	main
katastroofid	doc_45618460772_item	2416626	et	3	main
hästi	doc_45265275514_item	2416223	et	3	main
isiklikke	doc_453262085738_item	2416237	et	3	main
kirgelt	doc_453262085738_item	2416245	et	4	main
räägib	doc_453262085738_item	2416246	et	3	main
oma	doc_453262085738_item	2416247	et	4	main
isegi	doc_453262085738_item	2416250	et	4	main
osast	doc_453262085738_item	2416252	et	4	main
luuletus	doc_453262085738_item	2416253	et	4	main
on	doc_453262085738_item	2416254	et	4	main
nii	doc_453262085738_item	2416255	et	3	main
emotsionaalne	doc_453262085738_item	2416256	et	3	main
privaatne	doc_453262085738_item	2416260	et	3	main
armastus	doc_453262085738_item	2416265	et	4	main
pealkiri	doc_453262085738_item	2416268	et	3	main
elust	doc_453262085738_item	2416288	et	3	main
miks	doc_45618460770_item	2416451	et	4	main
traagilised	doc_45618460770_item	2416455	et	3	main
teda	doc_45618460770_item	2416496	et	4	main
mugavusi	doc_45618460770_item	2416504	et	4	main
ohutust	doc_45618460770_item	2416506	et	4	main
loodusest	doc_45618460770_item	2416510	et	4	main
et	doc_45618460770_item	2416518	et	3	main
aga	doc_45618460770_item	2416524	et	3	main
tee	doc_45618460770_item	2416526	et	4	main
vene	doc_45618460771_item	2416530	et	4	main
vene	doc_45618460771_item	2416538	et	4	main
eesti	doc_45618460771_item	2416541	et	4	main
saaksid	doc_45618460771_item	2416569	et	4	main
vene	doc_45618460771_item	2416570	et	4	main
või	doc_45618460771_item	2416576	et	4	main
seletada	doc_45618460771_item	2416578	et	3	main
panevad	doc_45618460772_item	2416632	et	4	main
väikese	doc_45618460772_item	2416641	et	4	main
et	doc_45618460772_item	2416647	et	3	main
purustustega	doc_45618460772_item	2416652	et	4	main
siis	doc_45618460772_item	2416660	et	3	main
saanud	doc_45618460772_item	2416662	et	4	main
inimesed	doc_45618460772_item	2416663	et	3	main
rasketel	doc_45618460772_item	2416704	et	3	main
saaks	doc_45618460773_item	2416720	et	3	main
kui	doc_45618460773_item	2416722	et	3	main
siia	doc_45618460773_item	2416725	et	4	main
ei	doc_45618460773_item	2416728	et	4	main
ei	doc_45618460773_item	2416745	et	4	main
pea	doc_45618460773_item	2416746	et	4	main
katastroofid	doc_45618460770_item	2416438	et	3	main
eestlaste	doc_45618460770_item	2416441	et	4	main
katastroofid	doc_45618460770_item	2416443	et	3	main
kaugele	doc_45618460770_item	2416480	et	4	main
oma	doc_45618460770_item	2416484	et	4	main
ei	doc_45618460770_item	2416487	et	4	main
on	doc_45618460770_item	2416493	et	4	main
me	doc_45618460770_item	2416501	et	4	main
huvitav	doc_45618460770_item	2416515	et	4	main
inimene	doc_45618460770_item	2416519	et	3	main
mõtlema	doc_45618460770_item	2416440	et	3	main
laused	doc_45618460770_item	2416442	et	3	main
mingi	doc_45618460770_item	2416452	et	4	main
sündmus	doc_45618460770_item	2416453	et	3	main
sündmused	doc_45618460770_item	2416456	et	3	main
näitavad	doc_45618460770_item	2416457	et	4	main
meile	doc_45618460770_item	2416458	et	4	main
kui	doc_45618460770_item	2416459	et	3	main
kaitsetud	doc_45618460770_item	2416460	et	4	main
olendid	doc_45618460770_item	2416461	et	3	main
inimesed	doc_45618460770_item	2416462	et	3	main
on	doc_45618460770_item	2416463	et	4	main
nende	doc_45618460770_item	2416464	et	4	main
vastu	doc_45618460770_item	2416465	et	3	main
me	doc_45618460770_item	2416466	et	4	main
oleme	doc_45618460770_item	2416467	et	3	main
abitud	doc_45618460770_item	2416468	et	4	main
looduse	doc_45618460770_item	2416469	et	4	main
kataklüsmid	doc_45618460770_item	2416470	et	3	main
on	doc_45618460770_item	2416471	et	4	main
juba	doc_45618460770_item	2416478	et	3	main
liiga	doc_45618460770_item	2416479	et	4	main
tehnoloogiaga	doc_45618460770_item	2416485	et	3	main
võimukam	doc_45618460770_item	2416495	et	4	main
peatada	doc_45618460770_item	2416500	et	3	main
tunne	doc_45618460770_item	2416509	et	4	main
ainult	doc_45618460770_item	2416512	et	4	main
seda	doc_45618460770_item	2416514	et	3	main
on	doc_45618460770_item	2416516	et	4	main
see	doc_45618460770_item	2416517	et	3	main
räägib	doc_45618460770_item	2416520	et	3	main
kaitsmisest	doc_45618460770_item	2416523	et	4	main
eestlaste	doc_45618460771_item	2416535	et	4	main
laused	doc_45618460771_item	2416536	et	3	main
kui	doc_45618460771_item	2416537	et	3	main
seda	doc_45618460771_item	2416543	et	3	main
sest	doc_45618460771_item	2416549	et	4	main
lapsed	doc_45618460771_item	2416551	et	3	main
ei	doc_45618460771_item	2416557	et	4	main
suuda	doc_45618460771_item	2416558	et	4	main
vene	doc_45618460771_item	2416563	et	4	main
kes	doc_45618460771_item	2416568	et	4	main
õpilastele	doc_45618460771_item	2416571	et	4	main
eesti	doc_45618460771_item	2416572	et	4	main
geograafiat	doc_45618460771_item	2416575	et	3	main
teda	doc_45618460771_item	2416579	et	4	main
oli	doc_45618460771_item	2416580	et	3	main
raske	doc_45618460771_item	2416613	et	4	main
kuid	doc_45618460771_item	2416614	et	4	main
nagu	doc_45618460771_item	2416623	et	3	main
mõtlema	doc_45618460772_item	2416633	et	3	main
saa	doc_45618460772_item	2416638	et	4	main
mõeldes	doc_45618460772_item	2416639	et	3	main
oma	doc_45618460772_item	2416640	et	4	main
toimunud	doc_45618460772_item	2416658	et	4	main
ei	doc_45618460772_item	2416661	et	4	main
ennast	doc_45618460772_item	2416664	et	4	main
nähtusele	doc_45618460772_item	2416671	et	4	main
hakata	doc_45618460772_item	2416673	et	4	main
aegadel	doc_45618460772_item	2416705	et	3	main
milleta	doc_45618460773_item	2416707	et	3	main
elada	doc_45618460773_item	2416718	et	3	main
me	doc_45618460773_item	2416730	et	4	main
milleks	doc_45618460773_item	2416735	et	4	main
tänapäeva	doc_45618460773_item	2416743	et	4	main
inimene	doc_45618460773_item	2416744	et	3	main
enam	doc_45618460773_item	2416753	et	4	main
pead	doc_45618460773_item	2416756	et	4	main
tänapäeva	doc_45618460773_item	2416758	et	4	main
nii	doc_45618460773_item	2416763	et	3	main
meile	doc_45618460773_item	2416767	et	4	main
on	doc_45618460773_item	2416768	et	4	main
elus	doc_45618460773_item	2416774	et	4	main
toime	doc_45618460773_item	2416775	et	4	main
tulla	doc_45618460773_item	2416776	et	3	main
metsades	doc_45618460773_item	2416780	et	3	main
toitu	doc_45618460773_item	2416785	et	4	main
vanasti	doc_45618460773_item	2416787	et	3	main
oleks	doc_45618460773_item	2416794	et	3	main
toit	doc_45618460773_item	2416798	et	3	main
milleta	doc_45618460773_item	2416800	et	3	main
meist	doc_45618460773_item	2416803	et	3	main
algabki	doc_45618460773_item	2416806	et	3	main
läinud	doc_45618460770_item	2416481	et	4	main
et	doc_45618460770_item	2416482	et	3	main
jääda	doc_45618460770_item	2416490	et	4	main
sest	doc_45618460770_item	2416491	et	4	main
loodus	doc_45618460770_item	2416492	et	4	main
on	doc_45618460770_item	2416497	et	4	main
täitsa	doc_45618460770_item	2416498	et	3	main
võimatu	doc_45618460770_item	2416499	et	4	main
alati	doc_45618460770_item	2416503	et	4	main
mitte	doc_45618460770_item	2416505	et	3	main
inimene	doc_45618460770_item	2416507	et	3	main
ei	doc_45618460770_item	2416508	et	4	main
hävib	doc_45618460770_item	2416513	et	3	main
palju	doc_45618460770_item	2416521	et	4	main
kui	doc_45618460771_item	2416529	et	3	main
õpiks	doc_45618460771_item	2416532	et	4	main
keeles	doc_45618460771_item	2416542	et	4	main
probleemi	doc_45618460771_item	2416544	et	4	main
ei	doc_45618460771_item	2416545	et	4	main
valda	doc_45618460771_item	2416554	et	4	main
eesti	doc_45618460771_item	2416555	et	4	main
kohe	doc_45618460771_item	2416559	et	4	main
võõrkeeles	doc_45618460771_item	2416560	et	4	main
õppima	doc_45618460771_item	2416561	et	3	main
ei	doc_45618460771_item	2416565	et	4	main
ajalugu	doc_45618460771_item	2416577	et	4	main
ei	doc_45618460771_item	2416617	et	4	main
ole	doc_45618460771_item	2416618	et	4	main
minu	doc_45618460771_item	2416619	et	3	main
jaoks	doc_45618460771_item	2416620	et	4	main
ei	doc_45618460770_item	2416525	et	4	main
selleks	doc_45618460770_item	2416527	et	4	main
midagi	doc_45618460770_item	2416528	et	4	main
kool	doc_45618460771_item	2416531	et	4	main
eesti	doc_45618460771_item	2416533	et	4	main
keeles	doc_45618460771_item	2416534	et	4	main
õpiks	doc_45618460771_item	2416540	et	4	main
ole	doc_45618460771_item	2416546	et	4	main
kerge	doc_45618460771_item	2416547	et	4	main
vene	doc_45618460771_item	2416550	et	4	main
keelt	doc_45618460771_item	2416556	et	4	main
koolides	doc_45618460771_item	2416564	et	3	main
õpetajaid	doc_45618460771_item	2416567	et	4	main
keeles	doc_45618460771_item	2416573	et	4	main
võimatu	doc_45618460771_item	2416581	et	4	main
kuulata	doc_45618460771_item	2416582	et	4	main
nii	doc_45618460771_item	2416583	et	3	main
juhtub	doc_45618460771_item	2416584	et	3	main
kõikides	doc_45618460771_item	2416585	et	4	main
vene	doc_45618460771_item	2416586	et	4	main
koolides	doc_45618460771_item	2416587	et	3	main
sest	doc_45618460771_item	2416588	et	4	main
spetsialiste	doc_45618460771_item	2416589	et	3	main
ei	doc_45618460771_item	2416590	et	4	main
nad	doc_45618460771_item	2416592	et	3	main
oskavad	doc_45618460771_item	2416593	et	4	main
jätku	doc_45618460771_item	2416591	et	4	main
kõnekeelt	doc_45618460771_item	2416594	et	4	main
aga	doc_45618460771_item	2416595	et	3	main
ei	doc_45618460771_item	2416596	et	4	main
võõrkeeles	doc_45618460771_item	2416598	et	4	main
suuda	doc_45618460771_item	2416597	et	4	main
kooli	doc_45618460771_item	2416599	et	4	main
materjali	doc_45618460771_item	2416600	et	4	main
jälgida	doc_45618460771_item	2416601	et	3	main
mina	doc_45618460771_item	2416602	et	4	main
õpin	doc_45618460771_item	2416603	et	3	main
eesti	doc_45618460771_item	2416604	et	4	main
koolis	doc_45618460771_item	2416605	et	4	main
juba	doc_45618460771_item	2416606	et	3	main
kaks	doc_45618460771_item	2416607	et	3	main
nädalat	doc_45618460771_item	2416608	et	3	main
ja	doc_45618460771_item	2416609	et	3	main
mul	doc_45618460771_item	2416610	et	3	main
on	doc_45618460771_item	2416611	et	4	main
päris	doc_45618460771_item	2416612	et	4	main
teistele	doc_45618460771_item	2416625	et	4	main
inimene	doc_45618460772_item	2416634	et	3	main
ei	doc_45618460772_item	2416637	et	4	main
võime	doc_45618460772_item	2416644	et	4	main
kuna	doc_45618460772_item	2416655	et	3	main
öösel	doc_45618460772_item	2416659	et	4	main
kuidagi	doc_45618460772_item	2416665	et	3	main
endalt	doc_45618460772_item	2416668	et	4	main
sellisele	doc_45618460772_item	2416670	et	4	main
vastu	doc_45618460772_item	2416672	et	3	main
siis	doc_45618460772_item	2416674	et	3	main
alguses	doc_45618460772_item	2416675	et	4	main
ei	doc_45618460772_item	2416676	et	4	main
tulegi	doc_45618460772_item	2416677	et	4	main
midagi	doc_45618460772_item	2416678	et	4	main
pähe	doc_45618460772_item	2416679	et	4	main
keegi	doc_45618460772_item	2416680	et	4	main
ju	doc_45618460772_item	2416681	et	3	main
ei	doc_45618460772_item	2416682	et	4	main
soovi	doc_45618460772_item	2416683	et	4	main
elada	doc_45618460772_item	2416684	et	3	main
kohas	doc_45618460772_item	2416685	et	4	main
mida	doc_45618460772_item	2416686	et	4	main
raputavad	doc_45618460772_item	2416687	et	4	main
maavärinad	doc_45618460772_item	2416688	et	3	main
ja	doc_45618460772_item	2416689	et	3	main
laastavad	doc_45618460772_item	2416690	et	4	main
tormid	doc_45618460772_item	2416691	et	3	main
elava	doc_45618460772_item	2416692	et	4	main
vastu	doc_45618460772_item	2416693	et	3	main
küll	doc_45618460772_item	2416694	et	4	main
ei	doc_45618460772_item	2416695	et	4	main
saa	doc_45618460772_item	2416696	et	4	main
kuid	doc_45618460772_item	2416697	et	4	main
lootus	doc_45618460772_item	2416698	et	4	main
ja	doc_45618460772_item	2416699	et	3	main
optimistlik	doc_45618460772_item	2416700	et	3	main
mõtlemine	doc_45618460772_item	2416701	et	4	main
tulevad	doc_45618460772_item	2416702	et	4	main
ka	doc_45618460772_item	2416703	et	3	main
nii	doc_45618460771_item	2416621	et	3	main
paljudele	doc_45618460771_item	2416624	et	3	main
panevad	doc_45618460772_item	2416627	et	4	main
vastu	doc_45618460772_item	2416636	et	3	main
kodumaa	doc_45618460772_item	2416642	et	4	main
kaasnevaid	doc_45618460772_item	2416653	et	4	main
loodusnähtusi	doc_45618460772_item	2416654	et	3	main
kõik	doc_45618460772_item	2416656	et	4	main
oli	doc_45618460772_item	2416657	et	3	main
kasuks	doc_45618460772_item	2416706	et	4	main
tänapäeva	doc_45618460773_item	2416708	et	4	main
inimene	doc_45618460773_item	2416709	et	3	main
elada	doc_45618460773_item	2416710	et	3	main
ei	doc_45618460773_item	2416711	et	4	main
ei	doc_45618460773_item	2416719	et	4	main
ilma	doc_45618460773_item	2416726	et	4	main
isegi	doc_45618460773_item	2416732	et	4	main
täpselt	doc_45618460773_item	2416734	et	4	main
hakkama	doc_45618460773_item	2416741	et	3	main
saada	doc_45618460773_item	2416742	et	4	main
nii	doc_45618460773_item	2416754	et	3	main
palju	doc_45618460773_item	2416755	et	4	main
vaevama	doc_45618460773_item	2416757	et	3	main
mõtle	doc_45618460773_item	2416761	et	4	main
mille	doc_45618460773_item	2416772	et	3	main
küttima	doc_45618460773_item	2416781	et	3	main
hoolitsesid	doc_45618460773_item	2416788	et	4	main
kõik	doc_45618460773_item	2416795	et	4	main
eelkõige	doc_45618460773_item	2416797	et	3	main
ilma	doc_45618460773_item	2416799	et	4	main
poleks	doc_45618460773_item	2416823	et	3	main
siin	doc_45618460773_item	2416829	et	4	main
ära	doc_45618460773_item	2416833	et	4	main
elus	doc_45618460773_item	2416841	et	4	main
edu	doc_45618460773_item	2416852	et	4	main
rohkem	doc_45618460773_item	2416854	et	4	main
inimene	doc_45618460773_item	2416856	et	3	main
kui	doc_45618460773_item	2416858	et	3	main
ta	doc_45618460773_item	2416865	et	4	main
õnnelik	doc_45618460773_item	2416867	et	3	main
eest	doc_45618460773_item	2416879	et	4	main
siin	doc_45618460773_item	2416888	et	4	main
on	doc_45618460773_item	2416894	et	4	main
olnud	doc_45618460773_item	2416895	et	4	main
on	doc_45618460773_item	2416899	et	4	main
mulle	doc_45618460773_item	2416901	et	4	main
milleta	doc_45618460773_item	2416902	et	3	main
saab	doc_45618460773_item	2416903	et	3	main
saan	doc_45618460773_item	2416915	et	4	main
aru	doc_45618460773_item	2416917	et	4	main
panevad	doc_45618460774_item	2416920	et	4	main
mõtlema	doc_45618460774_item	2416921	et	3	main
ei	doc_45618460774_item	2416926	et	4	main
teha	doc_45618460774_item	2416935	et	3	main
ei	doc_45618460774_item	2416939	et	4	main
ette	doc_45618460774_item	2416941	et	4	main
ei	doc_45618460774_item	2416950	et	4	main
kontrollida	doc_45618460774_item	2416955	et	4	main
paljud	doc_45618460774_item	2416960	et	3	main
mõtle	doc_45618460774_item	2416963	et	4	main
öeldakse	doc_45618460774_item	2416965	et	3	main
vastu	doc_45618460774_item	2416973	et	3	main
osa	doc_45618460774_item	2416976	et	4	main
siiski	doc_45618460774_item	2416978	et	4	main
kui	doc_45618460774_item	2416986	et	3	main
üks	doc_45618460775_item	2417024	et	3	main
sama	doc_45618460775_item	2417032	et	4	main
et	doc_45618460775_item	2417044	et	3	main
sellest	doc_45618460775_item	2417045	et	4	main
oleks	doc_45618460775_item	2417046	et	3	main
eemal	doc_45618460775_item	2417048	et	3	main
hoida	doc_45618460775_item	2417049	et	3	main
keegi	doc_45618460775_item	2417053	et	4	main
teeb	doc_45618460775_item	2417054	et	3	main
enam	doc_45618460775_item	2417060	et	4	main
korrata	doc_45618460775_item	2417062	et	4	main
tore	doc_45618460775_item	2417063	et	3	main
aga	doc_45618460775_item	2417064	et	3	main
see	doc_45618460775_item	2417065	et	3	main
juures	doc_45618460775_item	2417077	et	4	main
korda	doc_45618460775_item	2417082	et	4	main
korda	doc_45618460775_item	2417084	et	4	main
ei	doc_45618460775_item	2417085	et	4	main
löö	doc_45618460775_item	2417086	et	4	main
siis	doc_45618460775_item	2417093	et	3	main
juhtu	doc_45618460775_item	2417095	et	4	main
mõtlema	doc_45618460772_item	2416628	et	3	main
eestlaste	doc_45618460772_item	2416629	et	4	main
laused	doc_45618460772_item	2416630	et	3	main
katastroofid	doc_45618460772_item	2416631	et	3	main
looduse	doc_45618460772_item	2416635	et	4	main
peale	doc_45618460772_item	2416643	et	4	main
olla	doc_45618460772_item	2416645	et	3	main
õnnelikud	doc_45618460772_item	2416646	et	3	main
meil	doc_45618460772_item	2416648	et	4	main
ei	doc_45618460772_item	2416649	et	4	main
esine	doc_45618460772_item	2416650	et	4	main
suurte	doc_45618460772_item	2416651	et	3	main
kaitsta	doc_45618460772_item	2416666	et	4	main
küsides	doc_45618460772_item	2416667	et	3	main
kuidas	doc_45618460772_item	2416669	et	3	main
saaks	doc_45618460773_item	2416712	et	3	main
eestlaste	doc_45618460773_item	2416713	et	4	main
laused	doc_45618460773_item	2416714	et	3	main
milleta	doc_45618460773_item	2416715	et	3	main
tänapäeva	doc_45618460773_item	2416716	et	4	main
inimene	doc_45618460773_item	2416717	et	3	main
kord	doc_45618460773_item	2416721	et	4	main
me	doc_45618460773_item	2416723	et	4	main
kõik	doc_45618460773_item	2416724	et	4	main
tulime	doc_45618460773_item	2416727	et	3	main
meid	doc_45618460773_item	2416736	et	4	main
saamise	doc_45618460773_item	2416751	et	4	main
enam	doc_45618460773_item	2416762	et	4	main
kui	doc_45618460773_item	2416765	et	3	main
loodud	doc_45618460773_item	2416769	et	4	main
enam	doc_45618460773_item	2416777	et	4	main
ega	doc_45618460773_item	2416782	et	3	main
kuidas	doc_45618460773_item	2416784	et	3	main
et	doc_45618460773_item	2416792	et	3	main
olemas	doc_45618460773_item	2416796	et	4	main
saa	doc_45618460773_item	2416802	et	4	main
ei	doc_45618460773_item	2416825	et	4	main
enam	doc_45618460773_item	2416831	et	4	main
midagi	doc_45618460773_item	2416832	et	4	main
õnn	doc_45618460773_item	2416850	et	3	main
krabisevat	doc_45618460773_item	2416863	et	4	main
siis	doc_45618460773_item	2416864	et	3	main
minu	doc_45618460773_item	2416869	et	3	main
arvates	doc_45618460773_item	2416870	et	4	main
paberis	doc_45618460773_item	2416872	et	3	main
ei	doc_45618460773_item	2416873	et	4	main
tulu	doc_45618460773_item	2416878	et	4	main
siiski	doc_45618460773_item	2416882	et	4	main
kes	doc_45618460773_item	2416898	et	4	main
rääkinud	doc_45618460773_item	2416900	et	4	main
siin	doc_45618460773_item	2416904	et	4	main
maakeral	doc_45618460773_item	2416905	et	3	main
hakkama	doc_45618460773_item	2416906	et	3	main
ja	doc_45618460773_item	2416907	et	3	main
milleta	doc_45618460773_item	2416908	et	3	main
seda	doc_45618460773_item	2416910	et	3	main
keegi	doc_45618460774_item	2416925	et	4	main
me	doc_45618460774_item	2416933	et	4	main
miks	doc_45618460774_item	2416937	et	4	main
vastu	doc_45618460774_item	2416945	et	3	main
miski	doc_45618460774_item	2416948	et	4	main
tagajärgi	doc_45618460774_item	2416958	et	4	main
tohi	doc_45618460774_item	2416968	et	4	main
saada	doc_45618460774_item	2416974	et	4	main
selle	doc_45618460774_item	2416981	et	4	main
ütleksin	doc_45618460774_item	2416983	et	3	main
teadnud	doc_45618460773_item	2416729	et	4	main
alguses	doc_45618460773_item	2416731	et	4	main
päris	doc_45618460773_item	2416733	et	4	main
siia	doc_45618460773_item	2416737	et	4	main
loodi	doc_45618460773_item	2416738	et	4	main
ja	doc_45618460773_item	2416739	et	3	main
kuidas	doc_45618460773_item	2416740	et	3	main
oma	doc_45618460773_item	2416747	et	4	main
toidu	doc_45618460773_item	2416748	et	3	main
ja	doc_45618460773_item	2416749	et	3	main
hakkama	doc_45618460773_item	2416750	et	3	main
ei	doc_45618460773_item	2416760	et	4	main
palju	doc_45618460773_item	2416764	et	4	main
vanasti	doc_45618460773_item	2416766	et	3	main
abil	doc_45618460773_item	2416773	et	4	main
pea	doc_45618460773_item	2416779	et	4	main
mõtlema	doc_45618460773_item	2416783	et	3	main
muretseda	doc_45618460773_item	2416786	et	3	main
selle	doc_45618460773_item	2416789	et	4	main
eest	doc_45618460773_item	2416790	et	4	main
ei	doc_45618460773_item	2416801	et	4	main
ükski	doc_45618460773_item	2416804	et	4	main
kõik	doc_45618460773_item	2416807	et	4	main
töökohast	doc_45618460773_item	2416808	et	4	main
sest	doc_45618460773_item	2416809	et	4	main
kuidas	doc_45618460773_item	2416810	et	3	main
hakkama	doc_45618460773_item	2416811	et	3	main
saada	doc_45618460773_item	2416812	et	4	main
kui	doc_45618460773_item	2416813	et	3	main
sul	doc_45618460773_item	2416814	et	3	main
pole	doc_45618460773_item	2416815	et	3	main
kindlat	doc_45618460773_item	2416816	et	3	main
sissetulekut	doc_45618460773_item	2416817	et	3	main
ükskõik	doc_45618460773_item	2416818	et	3	main
kui	doc_45618460773_item	2416819	et	3	main
kurb	doc_45618460773_item	2416820	et	3	main
see	doc_45618460773_item	2416821	et	3	main
tee	doc_45618460773_item	2416826	et	4	main
rahata	doc_45618460773_item	2416828	et	4	main
mida	doc_45618460773_item	2416838	et	4	main
me	doc_45618460773_item	2416839	et	4	main
siin	doc_45618460773_item	2416840	et	4	main
tervis	doc_45618460773_item	2416849	et	3	main
on	doc_45618460773_item	2416860	et	4	main
ongi	doc_45618460773_item	2416866	et	4	main
kõik	doc_45618460773_item	2416876	et	4	main
elus	doc_45618460773_item	2416889	et	4	main
ilma	doc_45618460773_item	2416890	et	4	main
just	doc_45618460773_item	2416896	et	3	main
alles	doc_45618460773_item	2416918	et	3	main
eestlaste	doc_45618460774_item	2416922	et	4	main
tee	doc_45618460774_item	2416927	et	4	main
mida	doc_45618460774_item	2416932	et	4	main
inimesed	doc_45618460774_item	2416938	et	3	main
mõtle	doc_45618460774_item	2416940	et	4	main
öeldakse	doc_45618460774_item	2416942	et	3	main
ei	doc_45618460774_item	2416946	et	4	main
ja	doc_45618460774_item	2416949	et	3	main
kuid	doc_45618460774_item	2416952	et	4	main
tegude	doc_45618460774_item	2416957	et	3	main
ei	doc_45618460774_item	2416967	et	4	main
selleks	doc_45618460774_item	2416970	et	4	main
toimivad	doc_45618460774_item	2416979	et	4	main
et	doc_45618460774_item	2416984	et	3	main
midagi	doc_45618460774_item	2416988	et	4	main
eest	doc_45618460774_item	2416990	et	4	main
ei	doc_45618460774_item	2416991	et	4	main
tohi	doc_45618460774_item	2416992	et	4	main
primaat	doc_45618460775_item	2417026	et	3	main
soovi	doc_45618460775_item	2417028	et	4	main
halba	doc_45618460775_item	2417033	et	4	main
vea	doc_45618460775_item	2417057	et	4	main
pärast	doc_45618460773_item	2416752	et	4	main
inimene	doc_45618460773_item	2416759	et	3	main
kõik	doc_45618460773_item	2416770	et	4	main
vajalik	doc_45618460773_item	2416771	et	3	main
ei	doc_45618460773_item	2416778	et	4	main
mehed	doc_45618460773_item	2416791	et	3	main
perekonnal	doc_45618460773_item	2416793	et	4	main
tegelikult	doc_45618460773_item	2416805	et	4	main
ka	doc_45618460773_item	2416822	et	3	main
muidugi	doc_45618460773_item	2416834	et	4	main
on	doc_45618460773_item	2416835	et	4	main
ka	doc_45618460773_item	2416836	et	3	main
esemeid	doc_45618460773_item	2416837	et	3	main
raha	doc_45618460773_item	2416842	et	4	main
ja	doc_45618460773_item	2416851	et	3	main
et	doc_45618460773_item	2416857	et	3	main
tal	doc_45618460773_item	2416859	et	3	main
piisavas	doc_45618460773_item	2416861	et	4	main
koguses	doc_45618460773_item	2416862	et	4	main
saa	doc_45618460773_item	2416874	et	4	main
peituda	doc_45618460773_item	2416875	et	3	main
saab	doc_45618460773_item	2416880	et	3	main
paljutki	doc_45618460773_item	2416881	et	3	main
midagi	doc_45618460773_item	2416885	et	4	main
ennast	doc_45618460773_item	2416891	et	4	main
ülestöötamiseta	doc_45618460773_item	2416892	et	3	main
tema	doc_45618460773_item	2416893	et	4	main
ma	doc_45618460773_item	2416909	et	3	main
ei	doc_45618460773_item	2416911	et	4	main
mõistnud	doc_45618460773_item	2416912	et	4	main
nüüd	doc_45618460773_item	2416913	et	4	main
laused	doc_45618460774_item	2416923	et	3	main
meie	doc_45618460774_item	2416928	et	4	main
ära	doc_45618460774_item	2416930	et	4	main
ise	doc_45618460774_item	2416934	et	4	main
et	doc_45618460774_item	2416943	et	3	main
saa	doc_45618460774_item	2416947	et	4	main
saagi	doc_45618460774_item	2416951	et	4	main
suudame	doc_45618460774_item	2416954	et	3	main
ometi	doc_45618460774_item	2416959	et	3	main
ei	doc_45618460774_item	2416962	et	4	main
nii	doc_45618460774_item	2416964	et	3	main
anda	doc_45618460774_item	2416969	et	3	main
et	doc_45618460774_item	2416971	et	3	main
inimesi	doc_45618460774_item	2416977	et	4	main
kohta	doc_45618460774_item	2416982	et	4	main
mitte	doc_45618460774_item	2416987	et	3	main
probleemide	doc_45618460774_item	2416989	et	3	main
midagi	doc_45618460775_item	2417021	et	4	main
ühte	doc_45618460775_item	2417030	et	4	main
elamust	doc_45618460775_item	2417034	et	4	main
me	doc_45618460775_item	2417039	et	4	main
elame	doc_45618460775_item	2417040	et	3	main
võimalik	doc_45618460775_item	2417047	et	3	main
inimene	doc_45618460775_item	2417050	et	3	main
mingi	doc_45618460775_item	2417055	et	4	main
proovib	doc_45618460775_item	2417058	et	3	main
tegelane	doc_45618460775_item	2417066	et	3	main
pruugi	doc_45618460775_item	2417072	et	4	main
täie	doc_45618460775_item	2417075	et	3	main
välk	doc_45618460775_item	2417080	et	3	main
kui	doc_45618460775_item	2417088	et	3	main
juhtunud	doc_45618460775_item	2417091	et	4	main
uuesti	doc_45618460775_item	2417098	et	3	main
laused	doc_45618460776_item	2417100	et	3	main
elust	doc_45618460776_item	2417106	et	3	main
ma	doc_45618460776_item	2417107	et	3	main
kas	doc_45618460776_item	2417113	et	3	main
sa	doc_45618460776_item	2417118	et	3	main
tähele	doc_45618460776_item	2417120	et	3	main
ei	doc_45618460776_item	2417121	et	4	main
on	doc_45618460776_item	2417123	et	4	main
võimalik	doc_45618460776_item	2417124	et	3	main
vältida	doc_45618460776_item	2417130	et	3	main
vigu	doc_45618460776_item	2417131	et	3	main
isegi	doc_45618460776_item	2417132	et	4	main
kui	doc_45618460776_item	2417133	et	3	main
algkoolist	doc_45618460776_item	2417147	et	4	main
ei	doc_45618460776_item	2417158	et	4	main
kooli	doc_45618460776_item	2417182	et	4	main
teed	doc_45618460776_item	2417183	et	4	main
leida	doc_45618460776_item	2417184	et	3	main
mis	doc_45618460776_item	2417191	et	4	main
vigu	doc_45618460776_item	2417238	et	3	main
probleem	doc_45618460776_item	2417246	et	3	main
et	doc_45618460776_item	2417254	et	3	main
siis	doc_45618460773_item	2416824	et	3	main
ilma	doc_45618460773_item	2416827	et	4	main
ilmas	doc_45618460773_item	2416830	et	4	main
eest	doc_45618460773_item	2416843	et	4	main
osta	doc_45618460773_item	2416844	et	4	main
ei	doc_45618460773_item	2416845	et	4	main
saa	doc_45618460773_item	2416846	et	4	main
nii	doc_45618460773_item	2416847	et	3	main
armastus	doc_45618460773_item	2416848	et	4	main
üha	doc_45618460773_item	2416853	et	3	main
arvab	doc_45618460773_item	2416855	et	3	main
kuid	doc_45618460773_item	2416868	et	4	main
ühes	doc_45618460773_item	2416871	et	4	main
teenitud	doc_45618460773_item	2416877	et	4	main
mitte	doc_45618460773_item	2416883	et	3	main
kõike	doc_45618460773_item	2416884	et	4	main
ei	doc_45618460773_item	2416886	et	4	main
saa	doc_45618460773_item	2416887	et	4	main
see	doc_45618460773_item	2416897	et	3	main
saan	doc_45618460773_item	2416914	et	4	main
sellest	doc_45618460773_item	2416916	et	4	main
katastroofid	doc_45618460774_item	2416919	et	3	main
mitte	doc_45618460774_item	2416924	et	3	main
eest	doc_45618460774_item	2416929	et	4	main
asju	doc_45618460774_item	2416931	et	3	main
võiksime	doc_45618460774_item	2416936	et	3	main
looduse	doc_45618460774_item	2416944	et	4	main
me	doc_45618460774_item	2416953	et	4	main
looduse	doc_45618460774_item	2416956	et	4	main
inimesed	doc_45618460774_item	2416961	et	3	main
et	doc_45618460774_item	2416966	et	3	main
midagi	doc_45618460774_item	2416972	et	4	main
kuid	doc_45618460774_item	2416975	et	4	main
nii	doc_45618460774_item	2416980	et	3	main
parem	doc_45618460774_item	2416985	et	4	main
põgeneda	doc_45618460774_item	2416993	et	3	main
nendega	doc_45618460774_item	2416994	et	4	main
tuleb	doc_45618460774_item	2416995	et	3	main
silmitsi	doc_45618460774_item	2416996	et	4	main
seista	doc_45618460774_item	2416997	et	4	main
ja	doc_45618460774_item	2416998	et	3	main
vastu	doc_45618460774_item	2416999	et	3	main
hakata	doc_45618460774_item	2417000	et	4	main
kui	doc_45618460774_item	2417001	et	3	main
mitte	doc_45618460774_item	2417002	et	3	main
niisama	doc_45618460774_item	2417003	et	3	main
igapäevaselt	doc_45618460774_item	2417004	et	4	main
võiksime	doc_45618460774_item	2417005	et	3	main
seda	doc_45618460774_item	2417006	et	3	main
teha	doc_45618460774_item	2417007	et	3	main
kasvõi	doc_45618460774_item	2417008	et	3	main
hädaolukordades	doc_45618460774_item	2417009	et	3	main
eestlaste	doc_45618460775_item	2417010	et	4	main
laused	doc_45618460775_item	2417011	et	3	main
inimene	doc_45618460775_item	2417012	et	3	main
juba	doc_45618460775_item	2417013	et	3	main
aegade	doc_45618460775_item	2417014	et	3	main
algusest	doc_45618460775_item	2417015	et	4	main
isegi	doc_45618460775_item	2417016	et	4	main
kui	doc_45618460775_item	2417018	et	3	main
siis	doc_45618460775_item	2417017	et	3	main
ta	doc_45618460775_item	2417019	et	4	main
polnud	doc_45618460775_item	2417020	et	3	main
kui	doc_45618460775_item	2417023	et	3	main
kogeda	doc_45618460775_item	2417029	et	3	main
ja	doc_45618460775_item	2417031	et	3	main
mitu	doc_45618460775_item	2417035	et	4	main
korda	doc_45618460775_item	2417036	et	4	main
maailm	doc_45618460775_item	2417037	et	3	main
kus	doc_45618460775_item	2417038	et	3	main
et	doc_45618460775_item	2417052	et	3	main
seda	doc_45618460775_item	2417059	et	3	main
kes	doc_45618460775_item	2417067	et	4	main
tervise	doc_45618460775_item	2417076	et	3	main
usutakse	doc_45618460775_item	2417078	et	4	main
kaks	doc_45618460775_item	2417083	et	3	main
kuskil	doc_45618460775_item	2417089	et	3	main
midagi	doc_45618460775_item	2417092	et	4	main
seda	doc_45618460775_item	2417096	et	3	main
eestlaste	doc_45618460776_item	2417099	et	4	main
muud	doc_45618460775_item	2417022	et	4	main
urisev	doc_45618460775_item	2417025	et	4	main
ei	doc_45618460775_item	2417027	et	4	main
ei	doc_45618460775_item	2417041	et	4	main
ole	doc_45618460775_item	2417042	et	4	main
elektrikarjus	doc_45618460775_item	2417043	et	4	main
nähes	doc_45618460775_item	2417051	et	4	main
saatusliku	doc_45618460775_item	2417056	et	3	main
mitte	doc_45618460775_item	2417061	et	3	main
vea	doc_45618460775_item	2417069	et	4	main
ei	doc_45618460775_item	2417071	et	4	main
olla	doc_45618460775_item	2417073	et	3	main
ühte	doc_45618460775_item	2417081	et	4	main
seal	doc_45618460775_item	2417097	et	4	main
vigade	doc_45618460776_item	2417101	et	3	main
mida	doc_45618460776_item	2417117	et	4	main
selle	doc_45618460775_item	2417068	et	4	main
demonstreeris	doc_45618460775_item	2417070	et	3	main
enam	doc_45618460775_item	2417074	et	4	main
väljendisse	doc_45618460775_item	2417079	et	3	main
seega	doc_45618460775_item	2417087	et	4	main
on	doc_45618460775_item	2417090	et	4	main
ei	doc_45618460775_item	2417094	et	4	main
osa	doc_45618460776_item	2417105	et	4	main
päris	doc_45618460776_item	2417108	et	4	main
kindel	doc_45618460776_item	2417109	et	3	main
selles	doc_45618460776_item	2417110	et	4	main
ei	doc_45618460776_item	2417111	et	4	main
väikesest	doc_45618460776_item	2417115	et	4	main
ise	doc_45618460776_item	2417119	et	4	main
pane	doc_45618460776_item	2417122	et	4	main
midagi	doc_45618460776_item	2417125	et	4	main
õppida	doc_45618460776_item	2417126	et	3	main
ma	doc_45618460776_item	2417134	et	3	main
väga	doc_45618460776_item	2417135	et	3	main
ei	doc_45618460776_item	2417136	et	4	main
tahaks	doc_45618460776_item	2417137	et	3	main
vigu	doc_45618460776_item	2417138	et	3	main
teha	doc_45618460776_item	2417139	et	3	main
neid	doc_45618460776_item	2417142	et	4	main
ikka	doc_45618460776_item	2417143	et	4	main
ma	doc_45618460776_item	2417144	et	3	main
üht	doc_45618460776_item	2417148	et	3	main
lugu	doc_45618460776_item	2417149	et	4	main
räägib	doc_45618460776_item	2417151	et	3	main
õppinud	doc_45618460776_item	2417159	et	4	main
ei	doc_45618460776_item	2417161	et	4	main
venekeelt	doc_45618460776_item	2417163	et	4	main
siis	doc_45618460776_item	2417164	et	3	main
üldse	doc_45618460776_item	2417165	et	3	main
teadsin	doc_45618460776_item	2417166	et	3	main
ainult	doc_45618460776_item	2417167	et	4	main
kestis	doc_45618460776_item	2417174	et	4	main
ja	doc_45618460776_item	2417176	et	3	main
huvitav	doc_45618460776_item	2417190	et	4	main
õpigi	doc_45618460776_item	2417229	et	4	main
oma	doc_45618460776_item	2417230	et	4	main
veast	doc_45618460776_item	2417231	et	3	main
tegema	doc_45618460776_item	2417239	et	3	main
peavad	doc_45618460776_item	2417241	et	4	main
pole	doc_45618460776_item	2417245	et	3	main
aeg	doc_45618460776_item	2417256	et	3	main
läheb	doc_45618460776_item	2417258	et	3	main
ma	doc_45618460776_item	2417266	et	3	main
tean	doc_45618460776_item	2417267	et	3	main
enda	doc_45618460776_item	2417269	et	4	main
et	doc_45618460776_item	2417271	et	3	main
bussiga	doc_45618460776_item	2417273	et	3	main
see	doc_45618460776_item	2417277	et	3	main
ebamugav	doc_45618460776_item	2417280	et	3	main
kogu	doc_45618460776_item	2417285	et	4	main
bussiga	doc_45618460776_item	2417287	et	3	main
arvan	doc_45618460776_item	2417294	et	3	main
kui	doc_45618460776_item	2417301	et	3	main
autoga	doc_45618460776_item	2417303	et	3	main
tark	doc_45618460776_item	2417318	et	3	main
miks	doc_45618460776_item	2417321	et	4	main
midagi	doc_45618460776_item	2417323	et	4	main
üks	doc_45618460776_item	2417330	et	3	main
endiselt	doc_45618460776_item	2417350	et	4	main
hakkama	doc_45618460776_item	2417364	et	3	main
ei	doc_45618460776_item	2417369	et	4	main
muutuks	doc_45618460776_item	2417370	et	4	main
ja	doc_45618460776_item	2417371	et	3	main
ei	doc_45618460776_item	2417394	et	4	main
ilma	doc_45618460776_item	2417429	et	4	main
sellepeale	doc_45618460776_item	2417434	et	3	main
et	doc_45618460776_item	2417435	et	3	main
ei	doc_45618460776_item	2417442	et	4	main
peab	doc_45618460776_item	2417450	et	4	main
sinuga	doc_45618460776_item	2417451	et	3	main
alati	doc_45618460776_item	2417452	et	4	main
pärast	doc_45618460776_item	2417456	et	4	main
juhtugi	doc_45618460776_item	2417479	et	4	main
ja	doc_45618460776_item	2417490	et	3	main
mitte	doc_45618460776_item	2417494	et	3	main
et	doc_45618460777_item	2417498	et	3	main
loodust	doc_45618460777_item	2417500	et	4	main
päris	doc_45618460777_item	2417504	et	4	main
õige	doc_45618460777_item	2417505	et	4	main
üle	doc_45618460777_item	2417506	et	3	main
ei	doc_45618460777_item	2417515	et	4	main
tegemine	doc_45618460776_item	2417102	et	4	main
on	doc_45618460776_item	2417103	et	4	main
mingisugusest	doc_45618460776_item	2417114	et	3	main
äpardusest	doc_45618460776_item	2417116	et	4	main
me	doc_45618460776_item	2417127	et	4	main
ei	doc_45618460776_item	2417128	et	4	main
oma	doc_45618460776_item	2417146	et	4	main
mis	doc_45618460776_item	2417150	et	4	main
täpselt	doc_45618460776_item	2417152	et	4	main
sellest	doc_45618460776_item	2417153	et	4	main
et	doc_45618460776_item	2417154	et	3	main
ma	doc_45618460776_item	2417155	et	3	main
ma	doc_45618460776_item	2417160	et	3	main
jooksmine	doc_45618460776_item	2417173	et	4	main
ei	doc_45618460776_item	2417178	et	4	main
siis	doc_45618460776_item	2417192	et	3	main
oleks	doc_45618460776_item	2417193	et	3	main
olnud	doc_45618460776_item	2417194	et	4	main
kui	doc_45618460776_item	2417195	et	3	main
nad	doc_45618460776_item	2417196	et	3	main
saada	doc_45618460776_item	2417222	et	4	main
ka	doc_45618460776_item	2417225	et	3	main
muidugi	doc_45618460776_item	2417232	et	4	main
sundida	doc_45618460776_item	2417237	et	4	main
need	doc_45618460776_item	2417240	et	3	main
tulema	doc_45618460776_item	2417242	et	4	main
jääb	doc_45618460776_item	2417262	et	3	main
mugavusest	doc_45618460776_item	2417265	et	4	main
kogemusest	doc_45618460776_item	2417270	et	4	main
ei	doc_45618460776_item	2417274	et	4	main
suhteliselt	doc_45618460776_item	2417279	et	4	main
tagasi	doc_45618460776_item	2417282	et	3	main
aeg	doc_45618460776_item	2417286	et	3	main
ei	doc_45618460776_item	2417289	et	4	main
teinud	doc_45618460776_item	2417290	et	4	main
ma	doc_45618460776_item	2417296	et	3	main
ilmselt	doc_45618460776_item	2417298	et	4	main
nööpi	doc_45618460776_item	2417312	et	4	main
ette	doc_45618460776_item	2417313	et	4	main
mingi	doc_45618460776_item	2417317	et	4	main
siis	doc_45618460776_item	2417320	et	3	main
on	doc_45618460776_item	2417322	et	4	main
mõtetud	doc_45618460776_item	2417324	et	4	main
teha	doc_45618460776_item	2417325	et	3	main
info	doc_45618460776_item	2417326	et	4	main
on	doc_45618460776_item	2417327	et	4	main
ka	doc_45618460776_item	2417328	et	3	main
nendest	doc_45618460776_item	2417331	et	4	main
asjadest	doc_45618460776_item	2417332	et	3	main
milleta	doc_45618460776_item	2417333	et	3	main
tänapäeval	doc_45618460776_item	2417334	et	3	main
hakkama	doc_45618460776_item	2417335	et	3	main
ei	doc_45618460776_item	2417336	et	4	main
kuid	doc_45618460776_item	2417343	et	4	main
läheb	doc_45618460776_item	2417349	et	3	main
edasi	doc_45618460776_item	2417351	et	3	main
asi	doc_45618460776_item	2417354	et	4	main
kui	doc_45618460776_item	2417367	et	3	main
meie	doc_45618460776_item	2417372	et	4	main
rutiin	doc_45618460776_item	2417374	et	3	main
arvata	doc_45618460776_item	2417385	et	4	main
ainult	doc_45618460776_item	2417388	et	4	main
ka	doc_45618460776_item	2417391	et	3	main
oleks	doc_45618460776_item	2417431	et	3	main
võimalik	doc_45618460776_item	2417437	et	3	main
võibolla	doc_45618460776_item	2417441	et	4	main
ta	doc_45618460776_item	2417449	et	4	main
selle	doc_45618460776_item	2417455	et	4	main
kunagi	doc_45618460776_item	2417471	et	3	main
eluaja	doc_45618460776_item	2417476	et	3	main
ei	doc_45618460776_item	2417478	et	4	main
ma	doc_45618460776_item	2417480	et	3	main
tõesti	doc_45618460776_item	2417481	et	3	main
loodan	doc_45618460776_item	2417482	et	3	main
et	doc_45618460776_item	2417483	et	3	main
sellest	doc_45618460776_item	2417484	et	4	main
see	doc_45618460777_item	2417497	et	3	main
armastan	doc_45618460777_item	2417499	et	3	main
kõige	doc_45618460777_item	2417507	et	4	main
armastan	doc_45618460777_item	2417508	et	3	main
muusikat	doc_45618460777_item	2417510	et	3	main
kuulata	doc_45618460777_item	2417511	et	4	main
lampvõimendiga	doc_45618460777_item	2417512	et	3	main
kuid	doc_45618460777_item	2417513	et	4	main
praegu	doc_45618460777_item	2417517	et	3	main
maakohas	doc_45618460777_item	2417520	et	4	main
paratamatu	doc_45618460776_item	2417104	et	4	main
ole	doc_45618460776_item	2417112	et	4	main
saa	doc_45618460776_item	2417129	et	4	main
mäletan	doc_45618460776_item	2417145	et	3	main
veast	doc_45618460776_item	2417157	et	3	main
osanud	doc_45618460776_item	2417162	et	4	main
eest	doc_45618460776_item	2417171	et	4	main
ära	doc_45618460776_item	2417172	et	4	main
pikalt	doc_45618460776_item	2417175	et	4	main
ometi	doc_45618460776_item	2417177	et	3	main
suutnud	doc_45618460776_item	2417179	et	4	main
ma	doc_45618460776_item	2417180	et	3	main
teist	doc_45618460776_item	2417181	et	4	main
aru	doc_45618460776_item	2417221	et	4	main
juhtuda	doc_45618460776_item	2417224	et	3	main
sa	doc_45618460776_item	2417227	et	3	main
keegi	doc_45618460776_item	2417236	et	4	main
iseenesest	doc_45618460776_item	2417243	et	4	main
milleta	doc_45618460776_item	2417247	et	3	main
mida	doc_45618460776_item	2417255	et	4	main
võimetumaks	doc_45618460776_item	2417260	et	4	main
inimkond	doc_45618460776_item	2417261	et	3	main
ma	doc_45618460776_item	2417272	et	3	main
viitsi	doc_45618460776_item	2417275	et	4	main
välja	doc_45618460776_item	2417292	et	4	main
ma	doc_45618460776_item	2417293	et	3	main
ei	doc_45618460776_item	2417299	et	4	main
ma	doc_45618460776_item	2417302	et	3	main
teeb	doc_45618460776_item	2417316	et	3	main
masin	doc_45618460776_item	2417319	et	3	main
saa	doc_45618460776_item	2417337	et	4	main
ilma	doc_45618460776_item	2417339	et	4	main
ja	doc_45618460776_item	2417347	et	3	main
olid	doc_45618460776_item	2417358	et	4	main
ka	doc_45618460776_item	2417359	et	3	main
omad	doc_45618460776_item	2417360	et	4	main
asjad	doc_45618460776_item	2417361	et	3	main
milleta	doc_45618460776_item	2417362	et	3	main
saanud	doc_45618460776_item	2417366	et	4	main
midagi	doc_45618460776_item	2417368	et	4	main
jääks	doc_45618460776_item	2417375	et	4	main
alati	doc_45618460776_item	2417376	et	4	main
samaks	doc_45618460776_item	2417377	et	3	main
siis	doc_45618460776_item	2417378	et	3	main
oleks	doc_45618460776_item	2417379	et	3	main
see	doc_45618460776_item	2417380	et	3	main
väga	doc_45618460776_item	2417381	et	3	main
igav	doc_45618460776_item	2417382	et	3	main
ma	doc_45618460776_item	2417383	et	3	main
mitte	doc_45618460776_item	2417387	et	3	main
teen	doc_45618460776_item	2417140	et	3	main
ma	doc_45618460776_item	2417141	et	3	main
oma	doc_45618460776_item	2417156	et	4	main
sõna	doc_45618460776_item	2417168	et	4	main
raha	doc_45618460776_item	2417169	et	4	main
selline	doc_45618460776_item	2417170	et	4	main
õpetuse	doc_45618460776_item	2417185	et	4	main
said	doc_45618460776_item	2417186	et	4	main
nemad	doc_45618460776_item	2417187	et	3	main
mitte	doc_45618460776_item	2417188	et	3	main
mina	doc_45618460776_item	2417189	et	4	main
poleks	doc_45618460776_item	2417197	et	3	main
midagi	doc_45618460776_item	2417198	et	4	main
sellist	doc_45618460776_item	2417199	et	4	main
kunagi	doc_45618460776_item	2417200	et	3	main
teinud	doc_45618460776_item	2417201	et	4	main
see	doc_45618460776_item	2417202	et	3	main
poleks	doc_45618460776_item	2417203	et	3	main
olnud	doc_45618460776_item	2417204	et	4	main
viga	doc_45618460776_item	2417205	et	4	main
vigu	doc_45618460776_item	2417206	et	3	main
me	doc_45618460776_item	2417207	et	4	main
niisama	doc_45618460776_item	2417208	et	3	main
ei	doc_45618460776_item	2417209	et	4	main
tee	doc_45618460776_item	2417210	et	4	main
selleks	doc_45618460776_item	2417211	et	4	main
on	doc_45618460776_item	2417212	et	4	main
mingi	doc_45618460776_item	2417213	et	4	main
põhjus	doc_45618460776_item	2417214	et	4	main
alati	doc_45618460776_item	2417215	et	4	main
ei	doc_45618460776_item	2417216	et	4	main
pruugi	doc_45618460776_item	2417217	et	4	main
sa	doc_45618460776_item	2417218	et	3	main
sellest	doc_45618460776_item	2417219	et	4	main
kohe	doc_45618460776_item	2417220	et	4	main
võib	doc_45618460776_item	2417223	et	3	main
et	doc_45618460776_item	2417226	et	3	main
ei	doc_45618460776_item	2417228	et	4	main
ei	doc_45618460776_item	2417233	et	4	main
saa	doc_45618460776_item	2417234	et	4	main
sind	doc_45618460776_item	2417235	et	4	main
viga	doc_45618460776_item	2417244	et	4	main
tänapäevainimene	doc_45618460776_item	2417248	et	3	main
elada	doc_45618460776_item	2417249	et	3	main
ei	doc_45618460776_item	2417250	et	4	main
saaks	doc_45618460776_item	2417251	et	3	main
ma	doc_45618460776_item	2417252	et	3	main
arvan	doc_45618460776_item	2417253	et	3	main
edasi	doc_45618460776_item	2417257	et	3	main
seda	doc_45618460776_item	2417259	et	3	main
jõuetus	doc_45618460776_item	2417263	et	4	main
oma	doc_45618460776_item	2417268	et	4	main
on	doc_45618460776_item	2417278	et	4	main
ja	doc_45618460776_item	2417288	et	3	main
sellest	doc_45618460776_item	2417291	et	4	main
sureks	doc_45618460776_item	2417300	et	3	main
kunagi	doc_45618460776_item	2417305	et	3	main
sõita	doc_45618460776_item	2417307	et	3	main
panna	doc_45618460776_item	2417314	et	4	main
seda	doc_45618460776_item	2417315	et	3	main
tuleneb	doc_45618460776_item	2417264	et	3	main
sõita	doc_45618460776_item	2417276	et	3	main
aastaid	doc_45618460776_item	2417281	et	4	main
ma	doc_45618460776_item	2417283	et	3	main
sõitsin	doc_45618460776_item	2417284	et	3	main
et	doc_45618460776_item	2417295	et	3	main
ära	doc_45618460776_item	2417297	et	4	main
enam	doc_45618460776_item	2417304	et	4	main
ei	doc_45618460776_item	2417306	et	4	main
varsti	doc_45618460776_item	2417308	et	3	main
osata	doc_45618460776_item	2417309	et	4	main
enam	doc_45618460776_item	2417310	et	4	main
pluusile	doc_45618460776_item	2417311	et	3	main
kindlasti	doc_45618460776_item	2417329	et	3	main
nendeta	doc_45618460776_item	2417340	et	4	main
oleks	doc_45618460776_item	2417341	et	3	main
raske	doc_45618460776_item	2417342	et	4	main
elu	doc_45618460776_item	2417348	et	4	main
kuid	doc_45618460776_item	2417352	et	4	main
sellega	doc_45618460776_item	2417353	et	3	main
ei	doc_45618460776_item	2417355	et	4	main
lõppe	doc_45618460776_item	2417356	et	4	main
nad	doc_45618460776_item	2417363	et	3	main
igapäevane	doc_45618460776_item	2417373	et	4	main
et	doc_45618460776_item	2417386	et	3	main
tänapäevainimene	doc_45618460776_item	2417389	et	3	main
vaid	doc_45618460776_item	2417390	et	3	main
kiviaja	doc_45618460776_item	2417392	et	3	main
inimene	doc_45618460776_item	2417393	et	3	main
et	doc_45618460776_item	2417421	et	3	main
tõesti	doc_45618460776_item	2417423	et	3	main
selleta	doc_45618460776_item	2417430	et	3	main
arvavad	doc_45618460776_item	2417433	et	4	main
kuid	doc_45618460776_item	2417447	et	4	main
ei	doc_45618460776_item	2417466	et	4	main
lõpeb	doc_45618460776_item	2417472	et	4	main
võibolla	doc_45618460776_item	2417473	et	4	main
jooksul	doc_45618460776_item	2417477	et	4	main
tule	doc_45618460776_item	2417486	et	4	main
kolmandat	doc_45618460776_item	2417487	et	3	main
maailmasõda	doc_45618460776_item	2417488	et	4	main
inimeste	doc_45618460776_item	2417489	et	3	main
kindlasti	doc_45618460776_item	2417493	et	3	main
üle	doc_45618460777_item	2417501	et	3	main
pole	doc_45618460777_item	2417503	et	3	main
see	doc_45618460777_item	2417514	et	3	main
peal	doc_45618460777_item	2417525	et	4	main
siis	doc_45618460777_item	2417529	et	3	main
saab	doc_45618460777_item	2417530	et	3	main
suunda	doc_45618460777_item	2417534	et	4	main
kõndida	doc_45618460777_item	2417535	et	3	main
on	doc_45618460777_item	2417539	et	4	main
kus	doc_45618460777_item	2417545	et	3	main
hea	doc_45618460777_item	2417547	et	4	main
uisutada	doc_45618460777_item	2417548	et	3	main
jääst	doc_45618460777_item	2417551	et	3	main
ei	doc_45618460777_item	2417572	et	4	main
nagu	doc_45618460777_item	2417576	et	3	main
on	doc_45618460777_item	2417580	et	4	main
sulav	doc_45618460777_item	2417581	et	4	main
lumi	doc_45618460777_item	2417582	et	3	main
ja	doc_45618460777_item	2417583	et	3	main
maapind	doc_45618460777_item	2417586	et	3	main
laused	doc_45618460778_item	2417590	et	3	main
sellele	doc_45618460778_item	2417597	et	4	main
ei	doc_45618460778_item	2417626	et	4	main
halba	doc_45618460778_item	2417632	et	4	main
teha	doc_45618460778_item	2417633	et	3	main
paljud	doc_45618460778_item	2417634	et	3	main
haigused	doc_45618460778_item	2417635	et	4	main
kraanist	doc_45618460778_item	2417656	et	3	main
jookseks	doc_45618460778_item	2417659	et	4	main
kas	doc_45618460778_item	2417664	et	3	main
tänapäevainimene	doc_45618460778_item	2417669	et	3	main
elada	doc_45618460778_item	2417670	et	3	main
saa	doc_45618460778_item	2417672	et	4	main
asju	doc_45618460778_item	2417677	et	3	main
elada	doc_45618460778_item	2417679	et	3	main
saaks	doc_45618460778_item	2417681	et	3	main
saad	doc_45618460778_item	2417693	et	4	main
olgu	doc_45618460776_item	2417338	et	3	main
me	doc_45618460776_item	2417344	et	4	main
saaks	doc_45618460776_item	2417345	et	3	main
hakkama	doc_45618460776_item	2417346	et	3	main
neil	doc_45618460776_item	2417357	et	4	main
ei	doc_45618460776_item	2417365	et	4	main
julgen	doc_45618460776_item	2417384	et	3	main
suudaks	doc_45618460776_item	2417395	et	3	main
elada	doc_45618460776_item	2417396	et	3	main
ilma	doc_45618460776_item	2417397	et	4	main
põnevusetta	doc_45618460776_item	2417398	et	4	main
inimesed	doc_45618460776_item	2417399	et	3	main
ütlevad	doc_45618460776_item	2417400	et	4	main
vahel	doc_45618460776_item	2417401	et	4	main
et	doc_45618460776_item	2417402	et	3	main
nad	doc_45618460776_item	2417403	et	3	main
ei	doc_45618460776_item	2417404	et	4	main
saa	doc_45618460776_item	2417405	et	4	main
hakkama	doc_45618460776_item	2417406	et	3	main
ilma	doc_45618460776_item	2417407	et	4	main
mobiiltelefonita	doc_45618460776_item	2417408	et	3	main
tegelikult	doc_45618460776_item	2417409	et	4	main
on	doc_45618460776_item	2417410	et	4	main
viga	doc_45618460776_item	2417411	et	4	main
selles	doc_45618460776_item	2417412	et	4	main
et	doc_45618460776_item	2417413	et	3	main
nad	doc_45618460776_item	2417414	et	3	main
on	doc_45618460776_item	2417415	et	4	main
sellega	doc_45618460776_item	2417416	et	3	main
juba	doc_45618460776_item	2417417	et	3	main
liiga	doc_45618460776_item	2417418	et	4	main
ära	doc_45618460776_item	2417419	et	4	main
harjunud	doc_45618460776_item	2417420	et	4	main
oska	doc_45618460776_item	2417425	et	4	main
nad	doc_45618460776_item	2417432	et	3	main
pole	doc_45618460776_item	2417436	et	3	main
mobiilita	doc_45618460776_item	2417439	et	3	main
lähe	doc_45618460776_item	2417443	et	4	main
seda	doc_45618460776_item	2417444	et	3	main
üldse	doc_45618460776_item	2417445	et	3	main
vaja	doc_45618460776_item	2417446	et	4	main
olema	doc_45618460776_item	2417454	et	4	main
see	doc_45618460776_item	2417474	et	3	main
ei	doc_45618460776_item	2417485	et	4	main
masinate	doc_45618460776_item	2417491	et	3	main
laused	doc_45618460777_item	2417496	et	3	main
kõige	doc_45618460777_item	2417502	et	4	main
ole	doc_45618460777_item	2417516	et	4	main
harva	doc_45618460777_item	2417522	et	4	main
jää	doc_45618460777_item	2417524	et	4	main
mitu	doc_45618460777_item	2417531	et	4	main
kilomeetrit	doc_45618460777_item	2417532	et	4	main
igasse	doc_45618460777_item	2417533	et	3	main
et	doc_45618460777_item	2417550	et	3	main
vajuks	doc_45618460777_item	2417553	et	4	main
sügis	doc_45618460777_item	2417554	et	3	main
mulle	doc_45618460777_item	2417557	et	4	main
ja	doc_45618460777_item	2417585	et	3	main
on	doc_45618460777_item	2417587	et	4	main
eestlaste	doc_45618460778_item	2417589	et	4	main
nad	doc_45618460776_item	2417422	et	3	main
ei	doc_45618460776_item	2417424	et	4	main
ette	doc_45618460776_item	2417426	et	4	main
kujutada	doc_45618460776_item	2417427	et	3	main
kuidas	doc_45618460776_item	2417428	et	3	main
ilma	doc_45618460776_item	2417438	et	4	main
sul	doc_45618460776_item	2417440	et	3	main
samas	doc_45618460776_item	2417448	et	4	main
kaasas	doc_45618460776_item	2417453	et	4	main
keegi	doc_45618460776_item	2417457	et	4	main
ei	doc_45618460776_item	2417458	et	4	main
hooli	doc_45618460776_item	2417459	et	4	main
ainult	doc_45618460776_item	2417460	et	4	main
hoolitakse	doc_45618460776_item	2417461	et	3	main
kuidas	doc_45618460776_item	2417462	et	3	main
mugavam	doc_45618460776_item	2417463	et	4	main
on	doc_45618460776_item	2417464	et	4	main
ma	doc_45618460776_item	2417465	et	3	main
ole	doc_45618460776_item	2417467	et	4	main
kindel	doc_45618460776_item	2417468	et	3	main
millega	doc_45618460776_item	2417469	et	3	main
see	doc_45618460776_item	2417470	et	3	main
minu	doc_45618460776_item	2417475	et	3	main
vahel	doc_45618460776_item	2417492	et	4	main
eestlaste	doc_45618460777_item	2417495	et	4	main
ma	doc_45618460777_item	2417509	et	3	main
teemaks	doc_45618460777_item	2417518	et	4	main
mu	doc_45618460777_item	2417519	et	3	main
on	doc_45618460777_item	2417521	et	4	main
aga	doc_45618460777_item	2417526	et	3	main
mõnes	doc_45618460777_item	2417537	et	3	main
kohas	doc_45618460777_item	2417538	et	4	main
jäälahmakas	doc_45618460777_item	2417541	et	4	main
puhast	doc_45618460777_item	2417543	et	3	main
on	doc_45618460777_item	2417546	et	4	main
läbi	doc_45618460777_item	2417552	et	4	main
meeldi	doc_45618460777_item	2417556	et	4	main
meeldi	doc_45618460777_item	2417560	et	4	main
et	doc_45618460777_item	2417564	et	3	main
koledmaks	doc_45618460777_item	2417567	et	4	main
ja	doc_45618460777_item	2417568	et	3	main
kool	doc_45618460777_item	2417569	et	4	main
hakkab	doc_45618460777_item	2417570	et	3	main
kevad	doc_45618460777_item	2417571	et	3	main
samuti	doc_45618460777_item	2417575	et	3	main
jää	doc_45618460777_item	2417584	et	4	main
päeva	doc_45618460778_item	2417592	et	4	main
ja	doc_45618460778_item	2417594	et	3	main
juhtuda	doc_45618460778_item	2417601	et	3	main
millal	doc_45618460778_item	2417628	et	3	main
nad	doc_45618460778_item	2417629	et	3	main
ole	doc_45618460778_item	2417644	et	4	main
leitud	doc_45618460778_item	2417646	et	4	main
ettegi	doc_45618460778_item	2417650	et	4	main
et	doc_45618460778_item	2417655	et	3	main
vesi	doc_45618460778_item	2417657	et	4	main
kodus	doc_45618460778_item	2417662	et	4	main
kõik	doc_45618460778_item	2417665	et	4	main
see	doc_45618460778_item	2417667	et	3	main
milleta	doc_45618460778_item	2417668	et	3	main
tõsisemaid	doc_45618460778_item	2417676	et	4	main
elada	doc_45618460778_item	2417688	et	3	main
selleks	doc_45618460778_item	2417730	et	4	main
madalale	doc_45618460778_item	2417737	et	4	main
ebatervislikud	doc_45618460778_item	2417753	et	3	main
tahaksingi	doc_45618460778_item	2417755	et	3	main
inimesed	doc_45618460778_item	2417762	et	3	main
lihtsalt	doc_45618460778_item	2417764	et	4	main
küsitakse	doc_45618460778_item	2417770	et	4	main
milleta	doc_45618460778_item	2417771	et	3	main
tänapäeval	doc_45618460778_item	2417772	et	3	main
elada	doc_45618460778_item	2417773	et	3	main
ei	doc_45618460778_item	2417774	et	4	main
siis	doc_45618460778_item	2417787	et	3	main
nad	doc_45618460778_item	2417788	et	3	main
teiste	doc_45618460778_item	2417802	et	4	main
inimestega	doc_45618460778_item	2417803	et	3	main
ja	doc_45618460778_item	2417804	et	3	main
need	doc_45618460778_item	2417806	et	3	main
juba	doc_45618460779_item	2417822	et	3	main
lühikese	doc_45618460779_item	2417824	et	4	main
aja	doc_45618460779_item	2417825	et	4	main
üleelama	doc_45618460779_item	2417829	et	4	main
mis	doc_45618460779_item	2417832	et	4	main
kas	doc_45618460779_item	2417834	et	3	main
siis	doc_45618460779_item	2417835	et	3	main
miks	doc_45618460779_item	2417840	et	4	main
mitte	doc_45618460779_item	2417841	et	3	main
puhul	doc_45618460779_item	2417848	et	4	main
on	doc_45618460779_item	2417850	et	4	main
vastupidiselt	doc_45618460779_item	2417851	et	4	main
ei	doc_45618460779_item	2417857	et	4	main
see	doc_45618460779_item	2417866	et	3	main
siiani	doc_45618460779_item	2417899	et	4	main
miski	doc_45618460779_item	2417903	et	4	main
ei	doc_45618460779_item	2417905	et	4	main
väitnud	doc_45618460779_item	2417907	et	4	main
kaugele	doc_45618460779_item	2417914	et	4	main
mitte	doc_45618460779_item	2417920	et	3	main
tahan	doc_45618460779_item	2417923	et	3	main
tulevikus	doc_45618460779_item	2417924	et	4	main
olla	doc_45618460779_item	2417926	et	3	main
tohiks	doc_45618460779_item	2417933	et	3	main
kellegi	doc_45618460779_item	2417936	et	4	main
teise	doc_45618460779_item	2417937	et	4	main
sinust	doc_45618460779_item	2417955	et	3	main
kui	doc_45618460779_item	2417963	et	3	main
vaid	doc_45618460779_item	2417974	et	3	main
see	doc_45618460779_item	2417982	et	3	main
olla	doc_45618460779_item	2417988	et	3	main
on	doc_45618460779_item	2417999	et	4	main
naerda	doc_45618460779_item	2418006	et	4	main
merel	doc_45618460777_item	2417523	et	3	main
pealegi	doc_45618460777_item	2417536	et	4	main
suur	doc_45618460777_item	2417540	et	3	main
jääd	doc_45618460777_item	2417544	et	4	main
sügis	doc_45618460777_item	2417558	et	3	main
mulle	doc_45618460777_item	2417561	et	4	main
sellepärast	doc_45618460777_item	2417563	et	3	main
loodus	doc_45618460777_item	2417565	et	4	main
läheb	doc_45618460777_item	2417566	et	3	main
mulle	doc_45618460777_item	2417574	et	4	main
sest	doc_45618460777_item	2417578	et	4	main
elavad	doc_45618460778_item	2417591	et	4	main
ei	doc_45618460778_item	2417595	et	4	main
et	doc_45618460778_item	2417598	et	3	main
ja	doc_45618460778_item	2417602	et	3	main
igapäevast	doc_45618460778_item	2417603	et	4	main
elu	doc_45618460778_item	2417604	et	4	main
totaalselt	doc_45618460778_item	2417605	et	4	main
muuta	doc_45618460778_item	2417606	et	4	main
on	doc_45618460778_item	2417607	et	4	main
ka	doc_45618460778_item	2417608	et	3	main
halbu	doc_45618460778_item	2417609	et	3	main
inimesi	doc_45618460778_item	2417610	et	4	main
kes	doc_45618460778_item	2417611	et	4	main
ei	doc_45618460778_item	2417612	et	4	main
saa	doc_45618460778_item	2417613	et	4	main
oma	doc_45618460778_item	2417614	et	4	main
eluga	doc_45618460778_item	2417615	et	3	main
hakkama	doc_45618460778_item	2417616	et	3	main
ja	doc_45618460778_item	2417617	et	3	main
lähevad	doc_45618460778_item	2417618	et	3	main
halvale	doc_45618460778_item	2417619	et	3	main
teele	doc_45618460778_item	2417620	et	3	main
maailma	doc_45618460778_item	2417624	et	4	main
ka	doc_45618460778_item	2417640	et	3	main
neid	doc_45618460778_item	2417641	et	4	main
millele	doc_45618460778_item	2417642	et	3	main
nad	doc_45618460778_item	2417647	et	3	main
raadiota	doc_45618460778_item	2417654	et	3	main
ongi	doc_45618460778_item	2417666	et	4	main
ei	doc_45618460778_item	2417671	et	4	main
palju	doc_45618460778_item	2417675	et	4	main
milleta	doc_45618460778_item	2417678	et	3	main
sõbrad	doc_45618460778_item	2417682	et	3	main
kelleta	doc_45618460778_item	2417685	et	3	main
samuti	doc_45618460778_item	2417686	et	3	main
inimene	doc_45618460778_item	2417687	et	3	main
ei	doc_45618460778_item	2417689	et	4	main
saaks	doc_45618460778_item	2417690	et	3	main
kuus	doc_45618460778_item	2417725	et	4	main
ainult	doc_45618460778_item	2417726	et	4	main
kroonid	doc_45618460778_item	2417729	et	4	main
et	doc_45618460778_item	2417734	et	3	main
meie	doc_45618460778_item	2417749	et	4	main
öelda	doc_45618460778_item	2417760	et	4	main
kui	doc_45618460778_item	2417768	et	3	main
siis	doc_45618460778_item	2417776	et	3	main
mõtlevad	doc_45618460778_item	2417780	et	4	main
on	doc_45618460778_item	2417800	et	4	main
suhted	doc_45618460778_item	2417801	et	3	main
jooksul	doc_45618460779_item	2417826	et	4	main
pidanud	doc_45618460779_item	2417828	et	4	main
eluvaldkonnas	doc_45618460779_item	2417833	et	4	main
teaduses	doc_45618460779_item	2417837	et	3	main
kaastunne	doc_45618460779_item	2417844	et	3	main
ega	doc_45618460779_item	2417862	et	3	main
osad	doc_45618460779_item	2417869	et	3	main
kui	doc_45618460777_item	2417527	et	3	main
on	doc_45618460777_item	2417528	et	4	main
ilusat	doc_45618460777_item	2417542	et	3	main
ilma	doc_45618460777_item	2417549	et	4	main
ei	doc_45618460777_item	2417555	et	4	main
ei	doc_45618460777_item	2417559	et	4	main
ka	doc_45618460777_item	2417562	et	3	main
meeldi	doc_45618460777_item	2417573	et	4	main
sügis	doc_45618460777_item	2417577	et	3	main
siis	doc_45618460777_item	2417579	et	3	main
märg	doc_45618460777_item	2417588	et	3	main
mõtle	doc_45618460778_item	2417596	et	4	main
miskit	doc_45618460778_item	2417599	et	3	main
korraga	doc_45618460778_item	2417593	et	4	main
võib	doc_45618460778_item	2417600	et	3	main
terroristid	doc_45618460778_item	2417621	et	3	main
meie	doc_45618460778_item	2417623	et	4	main
kunagi	doc_45618460778_item	2417625	et	3	main
võivad	doc_45618460778_item	2417630	et	4	main
meile	doc_45618460778_item	2417631	et	4	main
on	doc_45618460778_item	2417639	et	4	main
ravi	doc_45618460778_item	2417645	et	4	main
ei	doc_45618460778_item	2417648	et	4	main
kujutaks	doc_45618460778_item	2417649	et	4	main
ilma	doc_45618460778_item	2417652	et	4	main
televiisorita	doc_45618460778_item	2417653	et	3	main
tuled	doc_45618460778_item	2417660	et	4	main
jne	doc_45618460778_item	2417663	et	4	main
on	doc_45618460778_item	2417673	et	4	main
sest	doc_45618460778_item	2417691	et	4	main
mõned	doc_45618460778_item	2417727	et	3	main
tulebki	doc_45618460778_item	2417731	et	3	main
mitte	doc_45618460778_item	2417735	et	3	main
hea	doc_45618460778_item	2417746	et	4	main
seda	doc_45618460778_item	2417758	et	3	main
on	doc_45618460778_item	2417763	et	4	main
harjunud	doc_45618460778_item	2417765	et	4	main
saaks	doc_45618460778_item	2417775	et	3	main
esmalt	doc_45618460778_item	2417779	et	3	main
tehnoloogia	doc_45618460778_item	2417781	et	4	main
peale	doc_45618460778_item	2417782	et	4	main
kui	doc_45618460778_item	2417783	et	3	main
nad	doc_45618460778_item	2417784	et	3	main
mõtleks	doc_45618460778_item	2417786	et	3	main
saaks	doc_45618460778_item	2417789	et	3	main
et	doc_45618460778_item	2417791	et	3	main
tervis	doc_45618460778_item	2417805	et	3	main
tähtsamad	doc_45618460778_item	2417809	et	4	main
laused	doc_45618460779_item	2417811	et	3	main
ohustavad	doc_45618460778_item	2417622	et	4	main
tea	doc_45618460778_item	2417627	et	4	main
on	doc_45618460778_item	2417636	et	4	main
ravitavad	doc_45618460778_item	2417637	et	4	main
aga	doc_45618460778_item	2417638	et	3	main
ei	doc_45618460778_item	2417643	et	4	main
elu	doc_45618460778_item	2417651	et	4	main
ei	doc_45618460778_item	2417658	et	4	main
säravad	doc_45618460778_item	2417661	et	4	main
ka	doc_45618460778_item	2417674	et	3	main
ei	doc_45618460778_item	2417680	et	4	main
on	doc_45618460778_item	2417683	et	4	main
need	doc_45618460778_item	2417684	et	3	main
neile	doc_45618460778_item	2417692	et	4	main
sa	doc_45618460778_item	2417694	et	3	main
alati	doc_45618460778_item	2417695	et	4	main
loota	doc_45618460778_item	2417696	et	4	main
ja	doc_45618460778_item	2417697	et	3	main
muidu	doc_45618460778_item	2417698	et	3	main
lõbusalt	doc_45618460778_item	2417699	et	4	main
aega	doc_45618460778_item	2417700	et	4	main
veeta	doc_45618460778_item	2417701	et	4	main
tänapäeval	doc_45618460778_item	2417702	et	3	main
ei	doc_45618460778_item	2417703	et	4	main
ole	doc_45618460778_item	2417704	et	4	main
võimalik	doc_45618460778_item	2417705	et	3	main
ilma	doc_45618460778_item	2417706	et	4	main
töö	doc_45618460778_item	2417707	et	4	main
kohata	doc_45618460778_item	2417708	et	4	main
elada	doc_45618460778_item	2417709	et	3	main
sest	doc_45618460778_item	2417710	et	4	main
muidu	doc_45618460778_item	2417711	et	3	main
see	doc_45618460778_item	2417712	et	3	main
raha	doc_45618460778_item	2417713	et	4	main
ei	doc_45618460778_item	2417714	et	4	main
tule	doc_45618460778_item	2417715	et	4	main
kuskilt	doc_45618460778_item	2417716	et	4	main
vaevalt	doc_45618460778_item	2417717	et	4	main
tahab	doc_45618460778_item	2417718	et	3	main
keegi	doc_45618460778_item	2417719	et	4	main
elada	doc_45618460778_item	2417720	et	3	main
töötu	doc_45618460778_item	2417721	et	4	main
mis	doc_45618460778_item	2417723	et	4	main
elus	doc_45618460778_item	2417732	et	4	main
nii	doc_45618460778_item	2417736	et	3	main
tänapäeva	doc_45618460778_item	2417740	et	4	main
terviseta	doc_45618460778_item	2417747	et	3	main
suhteliselt	doc_45618460778_item	2417752	et	4	main
edasi	doc_45618460778_item	2417759	et	3	main
et	doc_45618460778_item	2417761	et	3	main
nad	doc_45618460778_item	2417777	et	3	main
see	doc_45618460778_item	2417792	et	3	main
olegi	doc_45618460778_item	2417794	et	4	main
nii	doc_45618460778_item	2417795	et	3	main
tähtis	doc_45618460778_item	2417796	et	4	main
vaid	doc_45618460778_item	2417797	et	3	main
see	doc_45618460778_item	2417798	et	3	main
kuidas	doc_45618460778_item	2417799	et	3	main
on	doc_45618460778_item	2417807	et	4	main
abirahast	doc_45618460778_item	2417722	et	4	main
on	doc_45618460778_item	2417724	et	4	main
sajad	doc_45618460778_item	2417728	et	4	main
pingutada	doc_45618460778_item	2417733	et	3	main
langeda	doc_45618460778_item	2417738	et	3	main
kindlasti	doc_45618460778_item	2417739	et	3	main
inimene	doc_45618460778_item	2417741	et	3	main
ei	doc_45618460778_item	2417742	et	4	main
saaks	doc_45618460778_item	2417743	et	3	main
elada	doc_45618460778_item	2417744	et	3	main
ilma	doc_45618460778_item	2417745	et	4	main
sest	doc_45618460778_item	2417748	et	4	main
toitumisharjumised	doc_45618460778_item	2417750	et	3	main
on	doc_45618460778_item	2417751	et	4	main
ma	doc_45618460778_item	2417754	et	3	main
oma	doc_45618460778_item	2417756	et	4	main
kirjandiga	doc_45618460778_item	2417757	et	3	main
mugavustega	doc_45618460778_item	2417766	et	4	main
ja	doc_45618460778_item	2417767	et	3	main
neilt	doc_45618460778_item	2417769	et	4	main
just	doc_45618460778_item	2417778	et	3	main
rohkem	doc_45618460778_item	2417785	et	4	main
aru	doc_45618460778_item	2417790	et	4	main
ei	doc_45618460778_item	2417793	et	4	main
palju	doc_45618460778_item	2417808	et	4	main
eestlaste	doc_45618460779_item	2417810	et	4	main
eestlased	doc_45618460779_item	2417812	et	3	main
rahvus	doc_45618460779_item	2417814	et	3	main
mis	doc_45618460779_item	2417815	et	4	main
on	doc_45618460779_item	2417813	et	4	main
ei	doc_45618460779_item	2417816	et	4	main
ole	doc_45618460779_item	2417817	et	4	main
eksisteerinud	doc_45618460779_item	2417818	et	4	main
eriti	doc_45618460779_item	2417819	et	3	main
kaua	doc_45618460779_item	2417820	et	3	main
kuid	doc_45618460779_item	2417821	et	4	main
spordis	doc_45618460779_item	2417836	et	3	main
või	doc_45618460779_item	2417839	et	4	main
inimeste	doc_45618460779_item	2417847	et	3	main
kellel	doc_45618460779_item	2417849	et	4	main
sundida	doc_45618460779_item	2417859	et	4	main
austama	doc_45618460779_item	2417861	et	3	main
kellelegi	doc_45618460779_item	2417863	et	4	main
kaasatundma	doc_45618460779_item	2417864	et	4	main
et	doc_45618460779_item	2417868	et	3	main
ebaõnnestub	doc_45618460779_item	2417902	et	3	main
pürgimine	doc_45618460779_item	2417911	et	4	main
ja	doc_45618460779_item	2417912	et	3	main
absoluutselt	doc_45618460779_item	2417919	et	4	main
selle	doc_45618460779_item	2417823	et	4	main
paljutki	doc_45618460779_item	2417830	et	3	main
ükskõik	doc_45618460779_item	2417831	et	3	main
ka	doc_45618460779_item	2417842	et	3	main
kehtib	doc_45618460779_item	2417845	et	3	main
heale	doc_45618460779_item	2417852	et	3	main
midagi	doc_45618460779_item	2417853	et	4	main
ebaõnnestunud	doc_45618460779_item	2417854	et	4	main
saa	doc_45618460779_item	2417858	et	4	main
teist	doc_45618460779_item	2417860	et	4	main
tähendab	doc_45618460779_item	2417867	et	3	main
inimesed	doc_45618460779_item	2417870	et	3	main
ei	doc_45618460779_item	2417871	et	4	main
austagi	doc_45618460779_item	2417872	et	4	main
ega	doc_45618460779_item	2417873	et	3	main
tunnegi	doc_45618460779_item	2417874	et	4	main
kaasa	doc_45618460779_item	2417875	et	4	main
üksteisele	doc_45618460779_item	2417876	et	3	main
omad	doc_45618460779_item	2417877	et	4	main
kogemused	doc_45618460779_item	2417878	et	3	main
ja	doc_45618460779_item	2417879	et	3	main
nähtud	doc_45618460779_item	2417880	et	4	main
pilt	doc_45618460779_item	2417881	et	3	main
elust	doc_45618460779_item	2417882	et	3	main
on	doc_45618460779_item	2417883	et	4	main
näidanud	doc_45618460779_item	2417884	et	4	main
et	doc_45618460779_item	2417885	et	3	main
suurem	doc_45618460779_item	2417886	et	4	main
osa	doc_45618460779_item	2417887	et	4	main
eestlasi	doc_45618460779_item	2417888	et	3	main
on	doc_45618460779_item	2417889	et	4	main
kadedad	doc_45618460779_item	2417890	et	3	main
üksteise	doc_45618460779_item	2417891	et	4	main
peale	doc_45618460779_item	2417892	et	4	main
oleme	doc_45618460779_item	2417827	et	3	main
poliitikas	doc_45618460779_item	2417838	et	3	main
pereelus	doc_45618460779_item	2417843	et	4	main
aga	doc_45618460779_item	2417846	et	3	main
ühtegi	doc_45618460779_item	2417855	et	4	main
inimest	doc_45618460779_item	2417856	et	3	main
kas	doc_45618460779_item	2417865	et	3	main
neil	doc_45618460779_item	2417896	et	4	main
on	doc_45618460779_item	2417898	et	4	main
hästi	doc_45618460779_item	2417900	et	3	main
soov	doc_45618460779_item	2417913	et	3	main
jõuda	doc_45618460779_item	2417915	et	3	main
oleksid	doc_45618460779_item	2417916	et	4	main
halvad	doc_45618460779_item	2417917	et	4	main
ei	doc_45618460779_item	2417918	et	4	main
mina	doc_45618460779_item	2417922	et	4	main
inimene	doc_45618460779_item	2417931	et	3	main
seda	doc_45618460779_item	2417934	et	3	main
naaber	doc_45618460779_item	2417947	et	3	main
ja	doc_45618460779_item	2417953	et	3	main
sellega	doc_45618460779_item	2417954	et	3	main
seda	doc_45618460779_item	2417970	et	3	main
mitte	doc_45618460779_item	2417971	et	3	main
ainult	doc_45618460779_item	2417972	et	4	main
kogu	doc_45618460779_item	2417976	et	4	main
tohiks	doc_45618460779_item	2417987	et	3	main
kellegi	doc_45618460779_item	2417989	et	4	main
eesmärk	doc_45618460779_item	2417991	et	3	main
mis	doc_45618460779_item	2417998	et	4	main
on	doc_45618460779_item	2418010	et	4	main
miskit	doc_45618460779_item	2418011	et	3	main
aga	doc_45618460779_item	2418016	et	3	main
kõigil	doc_45618460779_item	2418024	et	4	main
hästi	doc_45618460779_item	2418027	et	3	main
on	doc_45618460779_item	2418031	et	4	main
asja	doc_45618460779_item	2418033	et	4	main
endale	doc_45618460779_item	2418037	et	4	main
meelde	doc_45618460779_item	2418039	et	3	main
teada	doc_45618460779_item	2418059	et	3	main
kui	doc_45618460779_item	2418060	et	3	main
paratamatult	doc_45618460779_item	2418067	et	4	main
saa	doc_45618460779_item	2418069	et	4	main
millal	doc_45618460779_item	2418072	et	3	main
kuna	doc_45618460779_item	2418085	et	3	main
kes	doc_45618460779_item	2418128	et	4	main
oma	doc_45618460779_item	2418132	et	4	main
kas	doc_45618460779_item	2418134	et	3	main
ole	doc_45618460779_item	2418137	et	4	main
paneb	doc_45618460779_item	2418141	et	3	main
on	doc_45618460779_item	2418145	et	4	main
selleks	doc_45618460779_item	2418147	et	4	main
et	doc_45618460779_item	2418148	et	3	main
mind	doc_45618460779_item	2418149	et	4	main
egiptus	doc_45618460779_item	2418155	et	4	main
ja	doc_45618460779_item	2418156	et	3	main
türgi	doc_45618460779_item	2418157	et	4	main
puhkuspaigad	doc_45618460779_item	2418162	et	4	main
tihedatest	doc_45618460779_item	2418164	et	4	main
sinna	doc_45618460779_item	2418170	et	3	main
minna	doc_45618460779_item	2418172	et	3	main
et	doc_45618460779_item	2418175	et	3	main
ei	doc_45618460779_item	2418177	et	4	main
vaja	doc_45618460779_item	2418179	et	4	main
minna	doc_45618460779_item	2418180	et	3	main
huvitav	doc_45618460779_item	2418181	et	4	main
kuidas	doc_45618460779_item	2418182	et	3	main
kui	doc_45618460779_item	2418183	et	3	main
me	doc_45618460779_item	2418184	et	4	main
ei	doc_45618460779_item	2418185	et	4	main
suuda	doc_45618460779_item	2418186	et	4	main
ja	doc_45618460779_item	2417893	et	3	main
naudivad	doc_45618460779_item	2417894	et	3	main
kellel	doc_45618460779_item	2417897	et	4	main
läinud	doc_45618460779_item	2417901	et	4	main
ole	doc_45618460779_item	2417906	et	4	main
et	doc_45618460779_item	2417908	et	3	main
elus	doc_45618460779_item	2417909	et	4	main
edasi	doc_45618460779_item	2417910	et	3	main
ka	doc_45618460779_item	2417921	et	3	main
ei	doc_45618460779_item	2417932	et	4	main
teha	doc_45618460779_item	2417935	et	3	main
rõõmu	doc_45618460779_item	2417942	et	4	main
selle	doc_45618460779_item	2417943	et	4	main
üle	doc_45618460779_item	2417944	et	3	main
kui	doc_45618460779_item	2417945	et	3	main
raha	doc_45618460779_item	2417952	et	4	main
majanduslikult	doc_45618460779_item	2417956	et	4	main
vähem	doc_45618460779_item	2417957	et	4	main
jõukamaks	doc_45618460779_item	2417958	et	4	main
muutub	doc_45618460779_item	2417959	et	3	main
tähtis	doc_45618460779_item	2417964	et	4	main
eestis	doc_45618460779_item	2417973	et	3	main
üle	doc_45618460779_item	2417975	et	3	main
maailma	doc_45618460779_item	2417977	et	4	main
mina	doc_45618460779_item	2417978	et	4	main
aga	doc_45618460779_item	2417979	et	3	main
leian	doc_45618460779_item	2417980	et	3	main
vale	doc_45618460779_item	2417984	et	4	main
kes	doc_45618460779_item	2417996	et	4	main
või	doc_45618460779_item	2417997	et	4	main
tähtsamad	doc_45618460779_item	2418002	et	4	main
samuti	doc_45618460779_item	2418003	et	3	main
ei	doc_45618460779_item	2418004	et	4	main
tohiks	doc_45618460779_item	2418005	et	3	main
kaasatunda	doc_45618460779_item	2418015	et	4	main
oleme	doc_45618460779_item	2418021	et	3	main
seega	doc_45618460779_item	2418030	et	4	main
kaks	doc_45618460779_item	2418032	et	3	main
ei	doc_45618460779_item	2418043	et	4	main
peale	doc_45618460779_item	2418052	et	4	main
taha	doc_45618460779_item	2418058	et	4	main
palju	doc_45618460779_item	2418061	et	4	main
neis	doc_45618460779_item	2418063	et	4	main
kunas	doc_45618460779_item	2418077	et	3	main
kord	doc_45618460779_item	2418080	et	4	main
on	doc_45618460779_item	2418083	et	4	main
heaks	doc_45618460779_item	2418087	et	4	main
linnukesi	doc_45618460779_item	2418121	et	4	main
mis	doc_45618460779_item	2418123	et	4	main
teinud	doc_45618460779_item	2418126	et	4	main
roboti	doc_45618460779_item	2418127	et	3	main
mõelda	doc_45618460779_item	2418131	et	4	main
see	doc_45618460779_item	2418140	et	3	main
siin	doc_45618460779_item	2418150	et	4	main
on	doc_45618460779_item	2418158	et	4	main
väga	doc_45618460779_item	2418160	et	3	main
hoolimata	doc_45618460779_item	2418163	et	4	main
pommiplahvatustest	doc_45618460779_item	2418165	et	4	main
ka	doc_45618460779_item	2418166	et	3	main
mina	doc_45618460779_item	2418167	et	4	main
olen	doc_45618460779_item	2418168	et	3	main
puhkama	doc_45618460779_item	2418171	et	3	main
aga	doc_45618460779_item	2418173	et	3	main
asjad	doc_45618460780_item	2418232	et	3	main
on	doc_45618460780_item	2418234	et	4	main
ohtlikud	doc_45618460780_item	2418235	et	3	main
ta	doc_45618460780_item	2418237	et	4	main
peab	doc_45618460780_item	2418238	et	4	main
ta	doc_45618460780_item	2418244	et	4	main
omaette	doc_45618460780_item	2418252	et	3	main
kell	doc_45618460780_item	2418254	et	3	main
üks	doc_45618460780_item	2418259	et	3	main
õpetada	doc_45618460781_item	2418266	et	3	main
seletada	doc_45618460781_item	2418268	et	3	main
töö	doc_45618460781_item	2418285	et	4	main
nõuab	doc_45618460781_item	2418286	et	3	main
suhtlemisoskust	doc_45618460781_item	2418290	et	3	main
müüja	doc_45618460781_item	2418304	et	4	main
töökohustusel	doc_45618460781_item	2418305	et	3	main
erinevad	doc_45618460781_item	2418325	et	4	main
müüja	doc_45618460781_item	2418333	et	4	main
pakkuda	doc_45618460781_item	2418337	et	3	main
kaup	doc_45618460781_item	2418339	et	3	main
kliendile	doc_45618460781_item	2418341	et	3	main
mida	doc_45618460781_item	2418345	et	4	main
talle	doc_45618460781_item	2418346	et	4	main
kui	doc_45618460779_item	2417895	et	3	main
ma	doc_45618460779_item	2417904	et	3	main
kulul	doc_45618460779_item	2417938	et	4	main
su	doc_45618460779_item	2417946	et	3	main
näitab	doc_45618460779_item	2417962	et	3	main
inimese	doc_45618460779_item	2417966	et	4	main
on	doc_45618460779_item	2417983	et	4	main
ei	doc_45618460779_item	2417986	et	4	main
tunduvalt	doc_45618460779_item	2418001	et	4	main
tuleks	doc_45618460779_item	2418014	et	4	main
me	doc_45618460779_item	2418019	et	4	main
kõik	doc_45618460779_item	2418020	et	4	main
inimesed	doc_45618460779_item	2418022	et	3	main
ja	doc_45618460779_item	2418028	et	3	main
kõik	doc_45618460779_item	2418036	et	4	main
et	doc_45618460779_item	2418041	et	3	main
ela	doc_45618460779_item	2418044	et	4	main
soon	doc_45618460779_item	2418045	et	3	main
üksi	doc_45618460779_item	2418047	et	4	main
ja	doc_45618460779_item	2418048	et	3	main
minu	doc_45618460779_item	2418053	et	3	main
ma	doc_45618460779_item	2418056	et	3	main
kuid	doc_45618460779_item	2418066	et	4	main
midagi	doc_45618460779_item	2418074	et	4	main
juhtub	doc_45618460779_item	2418075	et	3	main
ning	doc_45618460779_item	2418076	et	3	main
suuda	doc_45618460779_item	2418130	et	4	main
ei	doc_45618460779_item	2418136	et	4	main
katastroof	doc_45618460779_item	2418138	et	3	main
ei	doc_45618460779_item	2418153	et	4	main
oleks	doc_45618460779_item	2418154	et	3	main
kardan	doc_45618460779_item	2418174	et	4	main
erinevad	doc_45618460780_item	2418226	et	4	main
ja	doc_45618460780_item	2418229	et	3	main
teised	doc_45618460780_item	2418231	et	4	main
midagi	doc_45618460780_item	2418240	et	4	main
teha	doc_45618460780_item	2418241	et	3	main
mitte	doc_45618460780_item	2418246	et	3	main
kaksteist	doc_45618460780_item	2418255	et	4	main
ametite	doc_45618460781_item	2418261	et	3	main
on	doc_45618460781_item	2418265	et	4	main
materjali	doc_45618460781_item	2418270	et	4	main
tööd	doc_45618460781_item	2418273	et	4	main
õpetaja	doc_45618460781_item	2418274	et	4	main
töövahendid	doc_45618460781_item	2418275	et	3	main
erialane	doc_45618460781_item	2418287	et	4	main
õpetaja	doc_45618460781_item	2418292	et	4	main
lapsi	doc_45618460781_item	2418295	et	4	main
olema	doc_45618460781_item	2418296	et	4	main
rahulik	doc_45618460781_item	2418297	et	3	main
ja	doc_45618460781_item	2418298	et	3	main
temal	doc_45618460781_item	2418299	et	3	main
on	doc_45618460781_item	2418306	et	4	main
väljapanek	doc_45618460781_item	2418314	et	3	main
võib	doc_45618460781_item	2418327	et	3	main
laol	doc_45618460781_item	2418330	et	4	main
või	doc_45618460781_item	2418331	et	4	main
peab	doc_45618460781_item	2418334	et	4	main
oma	doc_45618460781_item	2418338	et	4	main
aidata	doc_45618460781_item	2418340	et	4	main
valida	doc_45618460781_item	2418342	et	3	main
rohkem	doc_45618460781_item	2418347	et	4	main
peab	doc_45618460781_item	2418353	et	4	main
olema	doc_45618460781_item	2418354	et	4	main
ta	doc_45618460781_item	2418361	et	4	main
ja	doc_45618460781_item	2418365	et	3	main
ametite	doc_45618460782_item	2418368	et	3	main
on	doc_45618460782_item	2418372	et	4	main
ja	doc_45618460782_item	2418374	et	3	main
on	doc_45618460782_item	2418379	et	4	main
trahvida	doc_45618460783_item	2418423	et	3	main
iseloomuomadused	doc_45618460783_item	2418436	et	4	main
viisakas	doc_45618460783_item	2418438	et	4	main
anda	doc_45618460783_item	2418447	et	3	main
on	doc_45618460783_item	2418456	et	4	main
suhtlemisvaba	doc_45618460783_item	2418459	et	4	main
iseloom	doc_45618460783_item	2418463	et	3	main
lõbus	doc_45618460783_item	2418464	et	4	main
suvel	doc_460280307193_item	2418469	et	3	main
ebatavalisse	doc_460280307193_item	2418474	et	4	main
teed	doc_460280307193_item	2418505	et	4	main
koju	doc_460280307193_item	2418506	et	3	main
nii	doc_460280307193_item	2418507	et	3	main
juhtus	doc_460280307193_item	2418508	et	3	main
meie	doc_460280307193_item	2418509	et	4	main
edukas	doc_45618460779_item	2417925	et	4	main
kuid	doc_45618460779_item	2417927	et	4	main
leian	doc_45618460779_item	2417928	et	3	main
et	doc_45618460779_item	2417929	et	3	main
ükski	doc_45618460779_item	2417930	et	4	main
on	doc_45618460779_item	2417939	et	4	main
ebainimlik	doc_45618460779_item	2417940	et	3	main
tunda	doc_45618460779_item	2417941	et	3	main
kaotab	doc_45618460779_item	2417948	et	3	main
investeeringutega	doc_45618460779_item	2417949	et	3	main
suurel	doc_45618460779_item	2417950	et	3	main
hulgal	doc_45618460779_item	2417951	et	3	main
selline	doc_45618460779_item	2417960	et	4	main
mõtteviis	doc_45618460779_item	2417961	et	3	main
on	doc_45618460779_item	2417965	et	4	main
jaoks	doc_45618460779_item	2417967	et	4	main
raha	doc_45618460779_item	2417968	et	4	main
ja	doc_45618460779_item	2417969	et	3	main
et	doc_45618460779_item	2417981	et	3	main
raha	doc_45618460779_item	2417985	et	4	main
elu	doc_45618460779_item	2417990	et	4	main
on	doc_45618460779_item	2417992	et	4	main
asju	doc_45618460779_item	2417993	et	3	main
ja	doc_45618460779_item	2417994	et	3	main
inimesi	doc_45618460779_item	2417995	et	4	main
sellest	doc_45618460779_item	2418000	et	4	main
nende	doc_45618460779_item	2418007	et	4	main
üle	doc_45618460779_item	2418008	et	3	main
kellel	doc_45618460779_item	2418009	et	4	main
neile	doc_45618460779_item	2418013	et	4	main
mitte	doc_45618460779_item	2418017	et	3	main
ebaõnnestunud	doc_45618460779_item	2418012	et	4	main
haletseda	doc_45618460779_item	2418018	et	3	main
meil	doc_45618460779_item	2418023	et	4	main
läheb	doc_45618460779_item	2418025	et	3	main
aeg-ajalt	doc_45618460779_item	2418026	et	4	main
vahepeal	doc_45618460779_item	2418038	et	3	main
tuletama	doc_45618460779_item	2418040	et	3	main
ma	doc_45618460779_item	2418042	et	3	main
maailmas	doc_45618460779_item	2418046	et	3	main
ka	doc_45618460779_item	2418049	et	3	main
kõik	doc_45618460779_item	2418050	et	4	main
on	doc_45618460779_item	2418054	et	4	main
inimesi	doc_45618460779_item	2418062	et	4	main
hukkunud	doc_45618460779_item	2418064	et	4	main
ei	doc_45618460779_item	2418068	et	4	main
mõtet	doc_45618460779_item	2418071	et	3	main
tuleb	doc_45618460779_item	2418078	et	3	main
looduskatastroofid	doc_45618460779_item	2418084	et	3	main
halvasti	doc_45618460779_item	2418029	et	3	main
mida	doc_45618460779_item	2418034	et	4	main
peaksid	doc_45618460779_item	2418035	et	4	main
need	doc_45618460779_item	2418051	et	3	main
isiksused	doc_45618460779_item	2418055	et	3	main
ei	doc_45618460779_item	2418057	et	4	main
on	doc_45618460779_item	2418065	et	4	main
peast	doc_45618460779_item	2418070	et	4	main
veel	doc_45618460779_item	2418073	et	4	main
minu	doc_45618460779_item	2418079	et	3	main
kõige	doc_45618460779_item	2418081	et	4	main
hävitavamad	doc_45618460779_item	2418082	et	4	main
nende	doc_45618460779_item	2418086	et	4	main
või	doc_45618460779_item	2418088	et	4	main
vastu	doc_45618460779_item	2418089	et	3	main
ei	doc_45618460779_item	2418090	et	4	main
suuda	doc_45618460779_item	2418091	et	4	main
me	doc_45618460779_item	2418092	et	4	main
midagi	doc_45618460779_item	2418094	et	4	main
teha	doc_45618460779_item	2418095	et	3	main
miks	doc_45618460779_item	2418096	et	4	main
mitte	doc_45618460779_item	2418093	et	3	main
ei	doc_45618460779_item	2418097	et	4	main
teatatud	doc_45618460779_item	2418098	et	4	main
lähenevast	doc_45618460779_item	2418099	et	4	main
ohust	doc_45618460779_item	2418100	et	3	main
varem	doc_45618460779_item	2418101	et	4	main
looduskatastroof	doc_45618460779_item	2418102	et	3	main
ei	doc_45618460779_item	2418103	et	4	main
pea	doc_45618460779_item	2418104	et	4	main
olema	doc_45618460779_item	2418105	et	4	main
ilmtingimata	doc_45618460779_item	2418106	et	3	main
inimestega	doc_45618460779_item	2418108	et	3	main
kas	doc_45618460779_item	2418109	et	3	main
sel	doc_45618460779_item	2418110	et	3	main
meremehel	doc_45618460779_item	2418111	et	3	main
seotud	doc_45618460779_item	2418107	et	4	main
ei	doc_45618460779_item	2418112	et	4	main
tule	doc_45618460779_item	2418113	et	4	main
pisar	doc_45618460779_item	2418114	et	3	main
silma	doc_45618460779_item	2418115	et	4	main
nähes	doc_45618460779_item	2418116	et	4	main
telekast	doc_45618460779_item	2418117	et	4	main
üleni	doc_45618460779_item	2418118	et	3	main
naftaseid	doc_45618460779_item	2418119	et	4	main
külmuvaid	doc_45618460779_item	2418120	et	4	main
kõik	doc_45618460779_item	2418139	et	4	main
vähe	doc_45618460779_item	2418144	et	3	main
vaja	doc_45618460779_item	2418146	et	4	main
populaarsed	doc_45618460779_item	2418161	et	3	main
trell	doc_45618460780_item	2418222	et	3	main
või	doc_45618460780_item	2418224	et	4	main
religioon	doc_45618460779_item	2418122	et	3	main
on	doc_45618460779_item	2418124	et	4	main
inimesest	doc_45618460779_item	2418125	et	3	main
ei	doc_45618460779_item	2418129	et	4	main
peaga	doc_45618460779_item	2418133	et	3	main
see	doc_45618460779_item	2418135	et	3	main
mõtlema	doc_45618460779_item	2418142	et	3	main
kui	doc_45618460779_item	2418143	et	3	main
maailmas	doc_45618460779_item	2418151	et	3	main
enam	doc_45618460779_item	2418152	et	4	main
praegu	doc_45618460779_item	2418159	et	3	main
mõelnud	doc_45618460779_item	2418169	et	4	main
tagasilennupiletit	doc_45618460779_item	2418176	et	3	main
pruugigi	doc_45618460779_item	2418178	et	4	main
selle	doc_45618460779_item	2418187	et	4	main
üle	doc_45618460779_item	2418188	et	3	main
valitseda	doc_45618460779_item	2418189	et	3	main
me	doc_45618460779_item	2418190	et	4	main
ei	doc_45618460779_item	2418191	et	4	main
saa	doc_45618460779_item	2418192	et	4	main
hakkama	doc_45618460779_item	2418193	et	3	main
isegi	doc_45618460779_item	2418194	et	4	main
inimeste	doc_45618460779_item	2418195	et	3	main
ohjeldamisega	doc_45618460779_item	2418196	et	4	main
ametite	doc_45618460780_item	2418197	et	3	main
kirjeldus	doc_45618460780_item	2418198	et	4	main
ehitaja	doc_45618460780_item	2418199	et	4	main
ta	doc_45618460780_item	2418200	et	4	main
peab	doc_45618460780_item	2418201	et	4	main
töötama	doc_45618460780_item	2418202	et	3	main
viis	doc_45618460780_item	2418203	et	4	main
päeva	doc_45618460780_item	2418204	et	4	main
nädalas	doc_45618460780_item	2418205	et	3	main
kaheksast	doc_45618460780_item	2418206	et	4	main
kuueni	doc_45618460780_item	2418207	et	4	main
peal	doc_45618460780_item	2418208	et	4	main
alati	doc_45618460780_item	2418209	et	4	main
peab	doc_45618460780_item	2418210	et	4	main
olema	doc_45618460780_item	2418211	et	4	main
kiiver	doc_45618460780_item	2418212	et	3	main
ja	doc_45618460780_item	2418213	et	3	main
kindad	doc_45618460780_item	2418214	et	3	main
käel	doc_45618460780_item	2418215	et	3	main
ehitajal	doc_45618460780_item	2418216	et	4	main
on	doc_45618460780_item	2418217	et	4	main
palju	doc_45618460780_item	2418218	et	4	main
töövahendeid	doc_45618460780_item	2418219	et	3	main
näiteks	doc_45618460780_item	2418220	et	4	main
haamer	doc_45618460780_item	2418221	et	3	main
supler	doc_45618460780_item	2418223	et	3	main
olla	doc_45618460780_item	2418225	et	3	main
purkides	doc_45618460780_item	2418228	et	4	main
värvid	doc_45618460780_item	2418227	et	4	main
töötingimused	doc_45618460780_item	2418233	et	3	main
muidugi	doc_45618460780_item	2418242	et	4	main
alati	doc_45618460780_item	2418251	et	4	main
iseseisvalt	doc_45618460780_item	2418253	et	4	main
kirjeldus	doc_45618460781_item	2418262	et	4	main
õpilasi	doc_45618460781_item	2418267	et	3	main
laud	doc_45618460781_item	2418277	et	4	main
raamatud	doc_45618460781_item	2418278	et	4	main
klassipäevik	doc_45618460781_item	2418279	et	3	main
pastapliats	doc_45618460781_item	2418280	et	4	main
õpetaja	doc_45618460781_item	2418281	et	4	main
töötab	doc_45618460781_item	2418282	et	3	main
klassiruumis	doc_45618460781_item	2418283	et	3	main
õpetaja	doc_45618460781_item	2418284	et	4	main
haridust	doc_45618460781_item	2418288	et	4	main
peab	doc_45618460781_item	2418300	et	4	main
olema	doc_45618460781_item	2418301	et	4	main
tema	doc_45618460781_item	2418315	et	4	main
töövahendid	doc_45618460781_item	2418316	et	3	main
paljud	doc_45618460780_item	2418230	et	3	main
tihti	doc_45618460780_item	2418236	et	3	main
kui	doc_45618460780_item	2418243	et	3	main
legaalselt	doc_45618460780_item	2418247	et	4	main
ta	doc_45618460780_item	2418249	et	4	main
vastab	doc_45618460780_item	2418250	et	3	main
alati	doc_45618460780_item	2418256	et	4	main
lõun	doc_45618460780_item	2418258	et	4	main
õpetaja	doc_45618460781_item	2418263	et	4	main
hinnata	doc_45618460781_item	2418271	et	4	main
õpilaste	doc_45618460781_item	2418272	et	4	main
peab	doc_45618460781_item	2418293	et	4	main
müüja	doc_45618460781_item	2418303	et	4	main
ja	doc_45618460781_item	2418313	et	3	main
on	doc_45618460781_item	2418317	et	4	main
arvuti	doc_45618460781_item	2418321	et	4	main
müüjatel	doc_45618460781_item	2418323	et	4	main
on	doc_45618460781_item	2418324	et	4	main
väljas	doc_45618460781_item	2418332	et	4	main
õigesti	doc_45618460781_item	2418336	et	3	main
asi	doc_45618460781_item	2418344	et	4	main
kõige	doc_45618460781_item	2418350	et	4	main
tähtis	doc_45618460781_item	2418351	et	4	main
iseloomuomadus	doc_45618460781_item	2418352	et	4	main
töötab	doc_45618460781_item	2418357	et	3	main
ja	doc_45618460781_item	2418359	et	3	main
õpetaja	doc_45618460782_item	2418370	et	4	main
oskusi	doc_45618460782_item	2418375	et	3	main
töövahendina	doc_45618460782_item	2418378	et	3	main
ja	doc_45618460782_item	2418385	et	3	main
kõrgel	doc_45618460780_item	2418239	et	4	main
töötab	doc_45618460780_item	2418245	et	3	main
lepinguta	doc_45618460780_item	2418248	et	3	main
kohustuslik	doc_45618460780_item	2418257	et	3	main
tund	doc_45618460780_item	2418260	et	3	main
töökohustused	doc_45618460781_item	2418264	et	3	main
uut	doc_45618460781_item	2418269	et	3	main
on	doc_45618460781_item	2418276	et	4	main
hea	doc_45618460781_item	2418289	et	4	main
kindlasti	doc_45618460781_item	2418291	et	3	main
armastama	doc_45618460781_item	2418294	et	3	main
humorimeel	doc_45618460781_item	2418302	et	4	main
kaupade	doc_45618460781_item	2418307	et	3	main
müümine	doc_45618460781_item	2418308	et	4	main
suhtlemine	doc_45618460781_item	2418309	et	4	main
klientidega	doc_45618460781_item	2418310	et	3	main
kaupade	doc_45618460781_item	2418311	et	3	main
vastuvõtt	doc_45618460781_item	2418312	et	3	main
kassaapparat	doc_45618460781_item	2418318	et	4	main
ja	doc_45618460781_item	2418319	et	3	main
mõnikord	doc_45618460781_item	2418320	et	3	main
töö	doc_45618460781_item	2418326	et	4	main
olla	doc_45618460781_item	2418328	et	3	main
see	doc_45618460781_item	2418343	et	3	main
täpsus	doc_45618460781_item	2418355	et	4	main
rahaga	doc_45618460781_item	2418358	et	4	main
muidugi	doc_45618460781_item	2418360	et	4	main
peab	doc_45618460781_item	2418362	et	4	main
olema	doc_45618460781_item	2418363	et	4	main
kirjeldus	doc_45618460782_item	2418369	et	4	main
õpilastele	doc_45618460782_item	2418376	et	4	main
tema	doc_45618460782_item	2418380	et	4	main
pea	doc_45618460782_item	2418381	et	4	main
ning	doc_45618460782_item	2418382	et	3	main
politseinik	doc_45618460783_item	2418421	et	4	main
oskusi	doc_45618460783_item	2418431	et	3	main
sport	doc_45618460783_item	2418432	et	3	main
keelt	doc_45618460783_item	2418435	et	4	main
mitte	doc_45618460783_item	2418437	et	3	main
mitte	doc_45618460783_item	2418439	et	3	main
töövahendid	doc_45618460783_item	2418451	et	3	main
töötingimused	doc_45618460783_item	2418453	et	3	main
koht	doc_45618460783_item	2418455	et	3	main
läinud	doc_460280307193_item	2418468	et	4	main
mul	doc_460280307193_item	2418471	et	3	main
mulle	doc_460280307193_item	2418504	et	4	main
tüdruku	doc_460280307193_item	2418516	et	3	main
punane	doc_460280307193_item	2418520	et	4	main
kohalikus	doc_460280307193_item	2418530	et	4	main
et	doc_460280307193_item	2418543	et	3	main
ümber	doc_460280307193_item	2418545	et	3	main
lähedane	doc_460280307193_item	2418549	et	3	main
käia	doc_460280307193_item	2418562	et	4	main
kõige	doc_460280307193_item	2418564	et	4	main
zaura	doc_460280307193_item	2418567	et	4	main
vanu	doc_460280307193_item	2418568	et	4	main
hobi	doc_460280307193_item	2418572	et	4	main
teha	doc_460280307193_item	2418574	et	3	main
paberist	doc_460280307193_item	2418576	et	3	main
selle	doc_460280307193_item	2418577	et	4	main
kunsti	doc_460280307193_item	2418578	et	4	main
shokeeris	doc_460280307193_item	2418582	et	4	main
nende	doc_460280307193_item	2418584	et	4	main
traditsioon	doc_460280307193_item	2418586	et	3	main
et	doc_460280307193_item	2418592	et	3	main
seinad	doc_460280307193_item	2418622	et	3	main
on	doc_460280307193_item	2418631	et	4	main
joonistatud	doc_460280307193_item	2418632	et	4	main
igal	doc_460280307193_item	2418634	et	3	main
lemmikjook	doc_460280307193_item	2418640	et	3	main
aga	doc_460280307193_item	2418644	et	3	main
maitseb	doc_460280307193_item	2418646	et	4	main
talle	doc_460280307193_item	2418647	et	4	main
uudne	doc_460280307193_item	2418656	et	3	main
on	doc_460280307193_item	2418658	et	4	main
liha	doc_460280307193_item	2418660	et	4	main
seene	doc_460280307193_item	2418661	et	3	main
kastes	doc_460280307193_item	2418662	et	4	main
on	doc_460280307193_item	2418665	et	4	main
zaura	doc_460280307193_item	2418706	et	4	main
printsi	doc_460280307193_item	2418712	et	4	main
hobusel	doc_460280307193_item	2418714	et	4	main
kinkis	doc_460280307193_item	2418716	et	3	main
töötingimused	doc_45618460781_item	2418322	et	3	main
kaupluses	doc_45618460781_item	2418329	et	3	main
oskama	doc_45618460781_item	2418335	et	3	main
sobib	doc_45618460781_item	2418348	et	3	main
müüja	doc_45618460781_item	2418349	et	4	main
ta	doc_45618460781_item	2418356	et	4	main
töökohustusena	doc_45618460782_item	2418371	et	3	main
nõu	doc_45618460782_item	2418373	et	4	main
õpikut	doc_45618460782_item	2418383	et	3	main
pastakat	doc_45618460782_item	2418386	et	3	main
töötingimused	doc_45618460782_item	2418387	et	3	main
on	doc_45618460782_item	2418388	et	4	main
erinevad	doc_45618460782_item	2418389	et	4	main
nagu	doc_45618460782_item	2418390	et	3	main
klassikabinetid	doc_45618460782_item	2418391	et	3	main
õpetaja	doc_45618460782_item	2418392	et	4	main
peab	doc_45618460782_item	2418393	et	4	main
olema	doc_45618460782_item	2418394	et	4	main
suhtlejana	doc_45618460782_item	2418395	et	4	main
abivalmis	doc_45618460782_item	2418396	et	3	main
ja	doc_45618460782_item	2418397	et	3	main
kordumatu	doc_45618460782_item	2418398	et	4	main
inimisena	doc_45618460782_item	2418399	et	4	main
piirivalvur	doc_45618460782_item	2418400	et	3	main
töökohustusena	doc_45618460782_item	2418401	et	3	main
riigi	doc_45618460782_item	2418403	et	3	main
piiri	doc_45618460782_item	2418404	et	4	main
valvuda	doc_45618460782_item	2418405	et	4	main
on	doc_45618460782_item	2418402	et	4	main
ning	doc_45618460782_item	2418406	et	3	main
piiririkkujaid	doc_45618460782_item	2418407	et	3	main
karistada	doc_45618460782_item	2418408	et	3	main
töövahendid	doc_45618460782_item	2418409	et	3	main
relvad	doc_45618460782_item	2418410	et	3	main
moblad	doc_45618460782_item	2418411	et	4	main
helkurit	doc_45618460782_item	2418412	et	4	main
jne	doc_45618460782_item	2418413	et	4	main
töötavad	doc_45618460782_item	2418414	et	4	main
õues	doc_45618460782_item	2418415	et	4	main
peab	doc_45618460782_item	2418416	et	4	main
olla	doc_45618460782_item	2418417	et	3	main
truu	doc_45618460782_item	2418418	et	4	main
ametite	doc_45618460783_item	2418419	et	3	main
kirjeldus	doc_45618460783_item	2418420	et	4	main
töövahendid	doc_45618460783_item	2418425	et	3	main
kaks	doc_45618460783_item	2418434	et	3	main
raha	doc_45618460783_item	2418444	et	4	main
üle	doc_45618460783_item	2418445	et	3	main
kandma	doc_45618460783_item	2418446	et	3	main
viisakas	doc_45618460781_item	2418364	et	4	main
meeldiva	doc_45618460781_item	2418366	et	4	main
välimusega	doc_45618460781_item	2418367	et	3	main
anda	doc_45618460782_item	2418377	et	3	main
vihikud	doc_45618460782_item	2418384	et	3	main
inimesi	doc_45618460783_item	2418424	et	4	main
radaar	doc_45618460783_item	2418426	et	4	main
püstool	doc_45618460783_item	2418427	et	4	main
töötingimusi	doc_45618460783_item	2418428	et	3	main
väga	doc_45618460783_item	2418429	et	3	main
arvuti	doc_45618460783_item	2418457	et	4	main
oskusi	doc_45618460783_item	2418458	et	3	main
vähemalt	doc_45618460783_item	2418460	et	4	main
kaks	doc_45618460783_item	2418461	et	3	main
keelt	doc_45618460783_item	2418462	et	4	main
fantaasialend	doc_460280307193_item	2418467	et	3	main
sattuda	doc_460280307193_item	2418473	et	3	main
kes	doc_460280307193_item	2418502	et	4	main
zaura	doc_460280307193_item	2418519	et	4	main
on	doc_460280307193_item	2418522	et	4	main
29	doc_460280307193_item	2418524	et	2	main
veebruaril	doc_460280307193_item	2418525	et	3	main
metsakas	doc_460280307193_item	2418535	et	4	main
olin	doc_460280307193_item	2418538	et	3	main
siis	doc_460280307193_item	2418541	et	3	main
maja	doc_460280307193_item	2418544	et	4	main
puustusmaa	doc_460280307193_item	2418547	et	4	main
kilomeetri	doc_460280307193_item	2418553	et	4	main
kaugusel	doc_460280307193_item	2418554	et	4	main
linna	doc_460280307193_item	2418560	et	4	main
meelsamini	doc_460280307193_item	2418565	et	3	main
vaatab	doc_460280307193_item	2418566	et	3	main
origamimind	doc_460280307193_item	2418581	et	4	main
üks	doc_460280307193_item	2418583	et	3	main
aasta	doc_460280307193_item	2418587	et	4	main
kasvatavad	doc_460280307193_item	2418590	et	4	main
töökohustusi	doc_45618460783_item	2418422	et	3	main
erinevad	doc_45618460783_item	2418430	et	4	main
vähemalt	doc_45618460783_item	2418433	et	4	main
lõbus	doc_45618460783_item	2418440	et	4	main
pangatöötaja	doc_45618460783_item	2418441	et	4	main
klienditeenindaja	doc_45618460783_item	2418442	et	4	main
töökohustusi	doc_45618460783_item	2418443	et	3	main
raha	doc_45618460783_item	2418448	et	4	main
raha	doc_45618460783_item	2418450	et	4	main
arvuti	doc_45618460783_item	2418452	et	4	main
õnn	doc_460280307193_item	2418472	et	3	main
olukorda	doc_460280307193_item	2418475	et	4	main
puhkasin	doc_460280307193_item	2418476	et	3	main
maal	doc_460280307193_item	2418477	et	4	main
mille	doc_460280307193_item	2418478	et	3	main
juures	doc_460280307193_item	2418479	et	4	main
asub	doc_460280307193_item	2418480	et	3	main
tihe	doc_460280307193_item	2418481	et	3	main
mets	doc_460280307193_item	2418482	et	3	main
ükskord	doc_460280307193_item	2418483	et	3	main
otsustasin	doc_460280307193_item	2418484	et	3	main
jalutada	doc_460280307193_item	2418485	et	3	main
seal	doc_460280307193_item	2418486	et	4	main
ja	doc_460280307193_item	2418487	et	3	main
eksisin	doc_460280307193_item	2418488	et	3	main
ekslesin	doc_460280307193_item	2418490	et	3	main
metsas	doc_460280307193_item	2418491	et	3	main
ära	doc_460280307193_item	2418489	et	4	main
ringi	doc_460280307193_item	2418492	et	4	main
umbes	doc_460280307193_item	2418493	et	4	main
4	doc_460280307193_item	2418494	et	2	main
tundi	doc_460280307193_item	2418495	et	4	main
ja	doc_460280307193_item	2418496	et	3	main
siis	doc_460280307193_item	2418497	et	3	main
päästis	doc_460280307193_item	2418499	et	3	main
üks	doc_460280307193_item	2418500	et	3	main
tüdruk	doc_460280307193_item	2418501	et	3	main
võtta	doc_45618460783_item	2418449	et	3	main
oma	doc_45618460783_item	2418454	et	4	main
viisakas	doc_45618460783_item	2418465	et	4	main
essee	doc_460280307193_item	2418466	et	4	main
oli	doc_460280307193_item	2418470	et	3	main
pärast	doc_460280307193_item	2418511	et	4	main
sain	doc_460280307193_item	2418513	et	3	main
on	doc_460280307193_item	2418518	et	4	main
mind	doc_460280307193_item	2418498	et	4	main
nätas	doc_460280307193_item	2418503	et	4	main
tutvus	doc_460280307193_item	2418510	et	4	main
teada	doc_460280307193_item	2418514	et	3	main
nimi	doc_460280307193_item	2418517	et	3	main
ta	doc_460280307193_item	2418521	et	4	main
sündinud	doc_460280307193_item	2418523	et	4	main
1992	doc_460280307193_item	2418526	et	2	main
lisapäevaaastal	doc_460280307193_item	2418527	et	3	main
õpib	doc_460280307193_item	2418529	et	3	main
koolis	doc_460280307193_item	2418531	et	4	main
ja	doc_460280307193_item	2418532	et	3	main
elab	doc_460280307193_item	2418533	et	3	main
maal	doc_460280307193_item	2418534	et	4	main
maja	doc_460280307193_item	2418550	et	4	main
üks	doc_460280307193_item	2418555	et	3	main
tüdruk	doc_460280307193_item	2418558	et	3	main
filme	doc_460280307193_item	2418570	et	3	main
kujukesi	doc_460280307193_item	2418575	et	4	main
nad	doc_460280307193_item	2418589	et	3	main
põrsast	doc_460280307193_item	2418591	et	4	main
jõulupüha	doc_460280307193_item	2418593	et	4	main
tema	doc_460280307193_item	2418623	et	4	main
on	doc_460280307193_item	2418625	et	4	main
ka	doc_460280307193_item	2418626	et	3	main
pool	doc_460280307193_item	2418635	et	4	main
on	doc_460280307193_item	2418636	et	4	main
esemed	doc_460280307193_item	2418637	et	3	main
paberist	doc_460280307193_item	2418638	et	3	main
on	doc_460280307193_item	2418641	et	4	main
mahl	doc_460280307193_item	2418643	et	3	main
jõhvikad	doc_460280307193_item	2418653	et	3	main
tema	doc_460280307193_item	2418655	et	4	main
heledada	doc_460280307193_item	2418666	et	4	main
oli	doc_460280307193_item	2418692	et	3	main
planeedis	doc_460280307193_item	2418694	et	3	main
pere	doc_460280307193_item	2418698	et	4	main
uut	doc_460280307193_item	2418701	et	3	main
kodus	doc_460280307193_item	2418703	et	4	main
oli	doc_460280307193_item	2418710	et	3	main
valgel	doc_460280307193_item	2418713	et	4	main
metsakale	doc_460280307193_item	2418722	et	4	main
sinna	doc_460280307193_item	2418727	et	3	main
jalgrattaga	doc_460280307193_item	2418731	et	3	main
kelguga	doc_460280307193_item	2418733	et	3	main
kokku	doc_460280307194_item	2418737	et	3	main
klassikaaslaste	doc_460280307194_item	2418740	et	4	main
ma	doc_460280307194_item	2418751	et	3	main
oli	doc_460280307194_item	2418755	et	3	main
a	doc_460280307194_item	2418757	et	4	main
jutustus	doc_460280307194_item	2418758	et	4	main
tervist	doc_460280307194_item	2418762	et	4	main
ta	doc_460280307194_item	2418765	et	4	main
tänapäeva	doc_460280307194_item	2418768	et	4	main
haigust	doc_460280307194_item	2418769	et	4	main
mille	doc_460280307194_item	2418770	et	3	main
hästi	doc_460280307194_item	2418778	et	3	main
esinemine	doc_460280307194_item	2418793	et	4	main
oli	doc_460280307194_item	2418794	et	3	main
informatiivne	doc_460280307194_item	2418795	et	3	main
on	doc_460280307194_item	2418800	et	4	main
oli	doc_460280307194_item	2418822	et	3	main
lihtne	doc_460280307194_item	2418824	et	3	main
oli	doc_460280307194_item	2418827	et	3	main
olnud	doc_460280307194_item	2418836	et	4	main
huvitav	doc_460280307194_item	2418837	et	4	main
minu	doc_460280307194_item	2418838	et	3	main
jaoks	doc_460280307194_item	2418839	et	4	main
teine	doc_460280307194_item	2418840	et	3	main
puue	doc_460280307194_item	2418841	et	3	main
oli	doc_460280307194_item	2418842	et	3	main
selles	doc_460280307194_item	2418843	et	4	main
et	doc_460280307194_item	2418844	et	3	main
liiga	doc_460280307194_item	2418848	et	4	main
ma	doc_460280307194_item	2418852	et	3	main
jõudnud	doc_460280307194_item	2418854	et	4	main
jälgida	doc_460280307194_item	2418855	et	3	main
jutustamist	doc_460280307194_item	2418856	et	4	main
m	doc_460280307194_item	2418862	et	4	main
s	doc_460280307194_item	2418869	et	4	main
k	doc_460280307194_item	2418872	et	4	main
mis	doc_460280307194_item	2418874	et	4	main
ma	doc_460280307193_item	2418512	et	3	main
et	doc_460280307193_item	2418515	et	3	main
zaura	doc_460280307193_item	2418528	et	4	main
eramajas	doc_460280307193_item	2418536	et	3	main
kui	doc_460280307193_item	2418537	et	3	main
ja	doc_460280307193_item	2418548	et	3	main
kümme	doc_460280307193_item	2418552	et	3	main
kord	doc_460280307193_item	2418556	et	4	main
nädalas	doc_460280307193_item	2418557	et	3	main
must-valgeid	doc_460280307193_item	2418569	et	3	main
nimetus	doc_460280307193_item	2418579	et	4	main
pere	doc_460280307193_item	2418585	et	4	main
peale	doc_460280307193_item	2418630	et	4	main
liblikad	doc_460280307193_item	2418633	et	3	main
söögist	doc_460280307193_item	2418645	et	4	main
kõige	doc_460280307193_item	2418648	et	4	main
apelsini	doc_460280307193_item	2418650	et	4	main
suhkrus	doc_460280307193_item	2418654	et	3	main
elu	doc_460280307193_item	2418693	et	4	main
tõenäosus	doc_460280307193_item	2418696	et	3	main
tähistab	doc_460280307193_item	2418700	et	3	main
aastat	doc_460280307193_item	2418702	et	3	main
ootus	doc_460280307193_item	2418709	et	3	main
mulle	doc_460280307193_item	2418717	et	4	main
silli	doc_460280307193_item	2418718	et	4	main
paberist	doc_460280307193_item	2418720	et	3	main
kahjuks	doc_460280307193_item	2418721	et	4	main
sõida	doc_460280307193_item	2418724	et	4	main
transport	doc_460280307193_item	2418725	et	3	main
ja	doc_460280307193_item	2418726	et	3	main
võib	doc_460280307193_item	2418728	et	3	main
proovin	doc_460280307194_item	2418744	et	3	main
iseloomustada	doc_460280307194_item	2418746	et	4	main
igaüht	doc_460280307194_item	2418747	et	3	main
esimene	doc_460280307194_item	2418748	et	3	main
esinemine	doc_460280307194_item	2418749	et	4	main
oma	doc_460280307194_item	2418753	et	4	main
ohustavad	doc_460280307194_item	2418763	et	4	main
m	doc_460280307194_item	2418777	et	4	main
ta	doc_460280307194_item	2418783	et	4	main
m	doc_460280307194_item	2418792	et	4	main
probleem	doc_460280307194_item	2418799	et	3	main
kõne	doc_460280307194_item	2418846	et	4	main
mõnikord	doc_460280307194_item	2418851	et	3	main
ei	doc_460280307194_item	2418853	et	4	main
hea	doc_460280307194_item	2418865	et	4	main
mitte	doc_460280307194_item	2418867	et	3	main
mängufilmi	doc_460280307194_item	2418877	et	4	main
d	doc_460280307194_item	2418880	et	4	main
filmi	doc_460280307194_item	2418884	et	4	main
tema	doc_460280307193_item	2418539	et	4	main
külas	doc_460280307193_item	2418540	et	3	main
imestasin	doc_460280307193_item	2418542	et	3	main
on	doc_460280307193_item	2418546	et	4	main
on	doc_460280307193_item	2418551	et	4	main
sõidab	doc_460280307193_item	2418559	et	3	main
et	doc_460280307193_item	2418561	et	3	main
kinos	doc_460280307193_item	2418563	et	3	main
tema	doc_460280307193_item	2418571	et	4	main
on	doc_460280307193_item	2418573	et	4	main
on	doc_460280307193_item	2418580	et	4	main
jooksul	doc_460280307193_item	2418588	et	4	main
eel	doc_460280307193_item	2418594	et	4	main
tappa	doc_460280307193_item	2418595	et	4	main
teda	doc_460280307193_item	2418596	et	4	main
ja	doc_460280307193_item	2418597	et	3	main
ära	doc_460280307193_item	2418598	et	4	main
süüa	doc_460280307193_item	2418599	et	3	main
zaural	doc_460280307193_item	2418600	et	4	main
on	doc_460280307193_item	2418601	et	4	main
sellest	doc_460280307193_item	2418602	et	4	main
väga	doc_460280307193_item	2418603	et	3	main
kahju	doc_460280307193_item	2418604	et	4	main
tüdruk	doc_460280307193_item	2418607	et	3	main
räägib	doc_460280307193_item	2418608	et	3	main
see	doc_460280307193_item	2418605	et	3	main
ebatavaline	doc_460280307193_item	2418606	et	4	main
vabalt	doc_460280307193_item	2418609	et	4	main
eesti	doc_460280307193_item	2418610	et	4	main
ja	doc_460280307193_item	2418611	et	3	main
vene	doc_460280307193_item	2418612	et	4	main
keelt	doc_460280307193_item	2418613	et	4	main
praktiliselt	doc_460280307193_item	2418614	et	4	main
kõik	doc_460280307193_item	2418615	et	4	main
tema	doc_460280307193_item	2418616	et	4	main
asjad	doc_460280307193_item	2418617	et	3	main
on	doc_460280307193_item	2418618	et	4	main
eredad	doc_460280307193_item	2418619	et	3	main
ja	doc_460280307193_item	2418620	et	3	main
triibulised	doc_460280307193_item	2418621	et	4	main
toas	doc_460280307193_item	2418624	et	3	main
triibulised	doc_460280307193_item	2418627	et	4	main
ja	doc_460280307193_item	2418628	et	3	main
zaura	doc_460280307193_item	2418639	et	4	main
rohkem	doc_460280307193_item	2418649	et	4	main
ja	doc_460280307193_item	2418652	et	3	main
zaura	doc_460280307193_item	2418663	et	4	main
riided	doc_460280307193_item	2418664	et	3	main
peolauas	doc_460280307193_item	2418691	et	3	main
alati	doc_460280307193_item	2418699	et	4	main
kõige	doc_460280307193_item	2418704	et	4	main
tähtsam	doc_460280307193_item	2418705	et	4	main
kohata	doc_460280307193_item	2418711	et	4	main
jõuda	doc_460280307193_item	2418729	et	3	main
ma	doc_460280307194_item	2418735	et	3	main
neli	doc_460280307194_item	2418738	et	3	main
nende	doc_460280307193_item	2418629	et	4	main
granaadi	doc_460280307193_item	2418642	et	3	main
küpsis	doc_460280307193_item	2418651	et	4	main
roog	doc_460280307193_item	2418657	et	3	main
niiske	doc_460280307193_item	2418659	et	4	main
ja	doc_460280307193_item	2418667	et	3	main
triibulised	doc_460280307193_item	2418668	et	4	main
koos	doc_460280307193_item	2418669	et	4	main
lehvidega	doc_460280307193_item	2418670	et	3	main
ja	doc_460280307193_item	2418671	et	3	main
pärliteradega	doc_460280307193_item	2418672	et	3	main
ta	doc_460280307193_item	2418673	et	4	main
alati	doc_460280307193_item	2418674	et	4	main
riietub	doc_460280307193_item	2418675	et	3	main
pidulikult	doc_460280307193_item	2418676	et	4	main
nagu	doc_460280307193_item	2418677	et	3	main
väike	doc_460280307193_item	2418678	et	4	main
nukk	doc_460280307193_item	2418679	et	3	main
sellel	doc_460280307193_item	2418680	et	4	main
aastal	doc_460280307193_item	2418681	et	3	main
tähistasin	doc_460280307193_item	2418682	et	3	main
uut	doc_460280307193_item	2418683	et	3	main
aastat	doc_460280307193_item	2418684	et	3	main
tema	doc_460280307193_item	2418685	et	4	main
küls	doc_460280307193_item	2418686	et	4	main
põhiteema	doc_460280307193_item	2418687	et	4	main
mis	doc_460280307193_item	2418688	et	4	main
oli	doc_460280307193_item	2418689	et	3	main
käsitud	doc_460280307193_item	2418690	et	3	main
marsil	doc_460280307193_item	2418695	et	3	main
tema	doc_460280307193_item	2418697	et	4	main
uue	doc_460280307193_item	2418707	et	3	main
aastatuhande	doc_460280307193_item	2418708	et	4	main
zaura	doc_460280307193_item	2418715	et	4	main
ainult	doc_460280307193_item	2418730	et	4	main
ja	doc_460280307193_item	2418732	et	3	main
analüüs	doc_460280307194_item	2418734	et	3	main
vaatasin	doc_460280307194_item	2418736	et	3	main
esinemist	doc_460280307194_item	2418741	et	4	main
mida	doc_460280307194_item	2418750	et	4	main
silmadega	doc_460280307194_item	2418754	et	3	main
inimese	doc_460280307194_item	2418761	et	4	main
üht	doc_460280307194_item	2418767	et	3	main
ülesandega	doc_460280307194_item	2418781	et	3	main
ja	doc_460280307194_item	2418785	et	3	main
sai	doc_460280307194_item	2418786	et	4	main
ja	doc_460280307194_item	2418796	et	3	main
tehtud	doc_460280307193_item	2418719	et	4	main
ei	doc_460280307193_item	2418723	et	4	main
oma	doc_460280307194_item	2418739	et	4	main
teemal	doc_460280307194_item	2418742	et	3	main
tervis	doc_460280307194_item	2418743	et	3	main
m	doc_460280307194_item	2418756	et	4	main
teemal	doc_460280307194_item	2418759	et	3	main
tänapäeva	doc_460280307194_item	2418760	et	4	main
haigused	doc_460280307194_item	2418764	et	4	main
valis	doc_460280307194_item	2418766	et	3	main
et	doc_460280307194_item	2418776	et	3	main
oma	doc_460280307194_item	2418780	et	4	main
toime	doc_460280307194_item	2418782	et	4	main
aru	doc_460280307194_item	2418787	et	4	main
kõike	doc_460280307194_item	2418788	et	4	main
millest	doc_460280307194_item	2418789	et	3	main
ta	doc_460280307194_item	2418790	et	4	main
jutustas	doc_460280307194_item	2418791	et	3	main
täis	doc_460280307194_item	2418797	et	4	main
aktuaalne	doc_460280307194_item	2418802	et	3	main
maailmas	doc_460280307194_item	2418803	et	3	main
see	doc_460280307194_item	2418804	et	3	main
on	doc_460280307194_item	2418805	et	4	main
uus	doc_460280307194_item	2418806	et	3	main
haigus	doc_460280307194_item	2418807	et	4	main
ja	doc_460280307194_item	2418808	et	3	main
ma	doc_460280307194_item	2418809	et	3	main
arvan	doc_460280307194_item	2418810	et	3	main
et	doc_460280307194_item	2418811	et	3	main
kõigile	doc_460280307194_item	2418812	et	4	main
oleks	doc_460280307194_item	2418813	et	3	main
kasulik	doc_460280307194_item	2418814	et	3	main
kuulata	doc_460280307194_item	2418815	et	4	main
rohkem	doc_460280307194_item	2418816	et	4	main
informatsiooni	doc_460280307194_item	2418817	et	4	main
sellest	doc_460280307194_item	2418818	et	4	main
m	doc_460280307194_item	2418819	et	4	main
töö	doc_460280307194_item	2418820	et	4	main
linnugripist	doc_460280307194_item	2418834	et	3	main
ei	doc_460280307194_item	2418835	et	4	main
m	doc_460280307194_item	2418845	et	4	main
kiire	doc_460280307194_item	2418849	et	4	main
öelda	doc_460280307194_item	2418859	et	4	main
et	doc_460280307194_item	2418860	et	3	main
d	doc_460280307194_item	2418870	et	4	main
esinemine	doc_460280307194_item	2418873	et	4	main
võiks	doc_460280307194_item	2418875	et	4	main
olla	doc_460280307194_item	2418876	et	3	main
ja	doc_460280307194_item	2418881	et	3	main
on	doc_460280307194_item	2418927	et	4	main
tublid	doc_460280307194_item	2418928	et	3	main
ja	doc_460280307194_item	2418929	et	3	main
elama	doc_460280307194_item	2418938	et	3	main
kõigile	doc_460280307194_item	2418941	et	4	main
kasulik	doc_460280307194_item	2418945	et	3	main
lühifilmi	doc_460280307194_item	2418948	et	4	main
vaatamist	doc_460280307194_item	2418950	et	4	main
tahad	doc_460280307194_item	2418951	et	3	main
mõelda	doc_460280307194_item	2418952	et	4	main
film	doc_460280307194_item	2418961	et	3	main
ettevalmistatud	doc_460280307194_item	2418970	et	4	main
minu	doc_460280307194_item	2418971	et	3	main
oli	doc_460280307194_item	2418974	et	3	main
poisid	doc_460280307194_item	2418976	et	4	main
natuke	doc_460280307194_item	2418745	et	4	main
nägin	doc_460280307194_item	2418752	et	3	main
nimetus	doc_460280307194_item	2418771	et	4	main
on	doc_460280307194_item	2418772	et	4	main
linnugripp	doc_460280307194_item	2418773	et	3	main
ma	doc_460280307194_item	2418774	et	3	main
arvan	doc_460280307194_item	2418775	et	3	main
tuli	doc_460280307194_item	2418779	et	4	main
teadis	doc_460280307194_item	2418784	et	4	main
linnugripi	doc_460280307194_item	2418798	et	3	main
väga	doc_460280307194_item	2418801	et	3	main
vormistus	doc_460280307194_item	2418821	et	4	main
liiga	doc_460280307194_item	2418823	et	4	main
paber	doc_460280307194_item	2418825	et	3	main
joonistatud	doc_460280307194_item	2418828	et	4	main
kana	doc_460280307194_item	2418829	et	4	main
ja	doc_460280307194_item	2418830	et	3	main
kirjutatud	doc_460280307194_item	2418831	et	4	main
mingisugune	doc_460280307194_item	2418832	et	3	main
lühiinformatsioon	doc_460280307194_item	2418833	et	3	main
kokkuvõteks	doc_460280307194_item	2418857	et	3	main
võiks	doc_460280307194_item	2418858	et	4	main
esinemine	doc_460280307194_item	2418863	et	4	main
ja	doc_460280307194_item	2418871	et	3	main
moto	doc_460280307194_item	2418878	et	4	main
k	doc_460280307194_item	2418882	et	4	main
inimest	doc_460280307194_item	2418923	et	3	main
suurest	doc_460280307194_item	2418924	et	4	main
hädast	doc_460280307194_item	2418925	et	4	main
meie	doc_460280307194_item	2418935	et	4	main
on	doc_460280307194_item	2418962	et	4	main
nende	doc_460280307194_item	2418966	et	4	main
ei	doc_460280307194_item	2418968	et	4	main
olnud	doc_460280307194_item	2418969	et	4	main
see	doc_460280307194_item	2418973	et	3	main
k	doc_460280307194_item	2418987	et	4	main
valisid	doc_460280307194_item	2419008	et	4	main
ütlesid	doc_460280307194_item	2419013	et	4	main
sõnu	doc_460280307194_item	2419034	et	4	main
vormistus	doc_460280307194_item	2419045	et	4	main
seal	doc_460280307194_item	2419046	et	4	main
oli	doc_460280307194_item	2419047	et	3	main
kõik	doc_460280307194_item	2419048	et	4	main
vajalik	doc_460280307194_item	2419049	et	3	main
pildid	doc_460280307194_item	2419050	et	3	main
punktid	doc_460280307194_item	2419051	et	4	main
esinemine	doc_460280307194_item	2419057	et	4	main
k	doc_460280307194_item	2419060	et	4	main
organiseeritud	doc_460280307194_item	2419081	et	4	main
värvid	doc_460280307194_item	2419119	et	4	main
söögi	doc_460280307194_item	2419120	et	4	main
kus	doc_460280307194_item	2418826	et	3	main
oli	doc_460280307194_item	2418847	et	3	main
ja	doc_460280307194_item	2418850	et	3	main
üldiselt	doc_460280307194_item	2418861	et	4	main
oli	doc_460280307194_item	2418864	et	3	main
aga	doc_460280307194_item	2418866	et	3	main
suurepärane	doc_460280307194_item	2418868	et	4	main
ei	doc_460280307194_item	2418886	et	4	main
mis	doc_460280307194_item	2418885	et	4	main
ole	doc_460280307194_item	2418887	et	4	main
seotud	doc_460280307194_item	2418888	et	4	main
teemaga	doc_460280307194_item	2418889	et	3	main
tervis	doc_460280307194_item	2418890	et	3	main
aga	doc_460280307194_item	2418891	et	3	main
kätt	doc_460280307194_item	2418892	et	3	main
südavale	doc_460280307194_item	2418893	et	4	main
pannes	doc_460280307194_item	2418894	et	4	main
nende	doc_460280307194_item	2418895	et	4	main
töö	doc_460280307194_item	2418896	et	4	main
meeldis	doc_460280307194_item	2418897	et	3	main
mulle	doc_460280307194_item	2418898	et	4	main
kõige	doc_460280307194_item	2418899	et	4	main
rohkem	doc_460280307194_item	2418900	et	4	main
ma	doc_460280307194_item	2418901	et	3	main
arvan	doc_460280307194_item	2418902	et	3	main
et	doc_460280307194_item	2418903	et	3	main
mängufilmi	doc_460280307194_item	2418904	et	4	main
moto	doc_460280307194_item	2418905	et	4	main
võiks	doc_460280307194_item	2418906	et	4	main
olla	doc_460280307194_item	2418907	et	3	main
kõik	doc_460280307194_item	2418908	et	4	main
mis	doc_460280307194_item	2418909	et	4	main
juhtub	doc_460280307194_item	2418910	et	3	main
on	doc_460280307194_item	2418911	et	4	main
paremaks	doc_460280307194_item	2418912	et	4	main
filmi	doc_460280307194_item	2418913	et	4	main
on	doc_460280307194_item	2418915	et	4	main
peaidee	doc_460280307194_item	2418914	et	4	main
selles	doc_460280307194_item	2418916	et	4	main
et	doc_460280307194_item	2418917	et	3	main
mõnikord	doc_460280307194_item	2418918	et	3	main
väike	doc_460280307194_item	2418919	et	4	main
ebaedu	doc_460280307194_item	2418920	et	4	main
võib	doc_460280307194_item	2418921	et	3	main
mälestustes	doc_460280307194_item	2418936	et	4	main
arvan	doc_460280307194_item	2418939	et	3	main
s	doc_460280307194_item	2418879	et	4	main
tegid	doc_460280307194_item	2418883	et	4	main
päästa	doc_460280307194_item	2418922	et	4	main
tegid	doc_460280307194_item	2418930	et	4	main
mis	doc_460280307194_item	2418933	et	4	main
jääb	doc_460280307194_item	2418934	et	3	main
huvitav	doc_460280307194_item	2418943	et	4	main
ja	doc_460280307194_item	2418944	et	3	main
seotud	doc_460280307194_item	2418963	et	4	main
jutustus	doc_460280307194_item	2418967	et	4	main
arvates	doc_460280307194_item	2418972	et	4	main
esinemine	doc_460280307194_item	2418988	et	4	main
rühmas	doc_460280307194_item	2418992	et	4	main
oli	doc_460280307194_item	2418993	et	3	main
oli	doc_460280307194_item	2419005	et	3	main
16	doc_460280307194_item	2419010	et	2	main
ravimtaime	doc_460280307194_item	2419011	et	4	main
ja	doc_460280307194_item	2419012	et	3	main
ainult	doc_460280307194_item	2419015	et	4	main
poisid	doc_460280307194_item	2418926	et	4	main
suurepärast	doc_460280307194_item	2418931	et	4	main
tööd	doc_460280307194_item	2418932	et	4	main
edasi	doc_460280307194_item	2418937	et	3	main
seda	doc_460280307194_item	2418947	et	3	main
pärast	doc_460280307194_item	2418949	et	4	main
kui	doc_460280307194_item	2418953	et	3	main
film	doc_460280307194_item	2418954	et	3	main
lõppes	doc_460280307194_item	2418955	et	4	main
poisid	doc_460280307194_item	2418956	et	4	main
jutustada	doc_460280307194_item	2418958	et	3	main
proovisid	doc_460280307194_item	2418957	et	4	main
kuidas	doc_460280307194_item	2418959	et	3	main
nende	doc_460280307194_item	2418960	et	4	main
et	doc_460280307194_item	2418940	et	3	main
oleks	doc_460280307194_item	2418942	et	3	main
vaadata	doc_460280307194_item	2418946	et	4	main
teemaga	doc_460280307194_item	2418964	et	3	main
m	doc_460280307194_item	2418983	et	4	main
k	doc_460280307194_item	2418984	et	4	main
n	doc_460280307194_item	2418985	et	4	main
vaatamata	doc_460280307194_item	2418989	et	4	main
et	doc_460280307194_item	2418991	et	3	main
palju	doc_460280307194_item	2418994	et	4	main
inimesi	doc_460280307194_item	2418995	et	4	main
minu	doc_460280307194_item	2418996	et	3	main
tüdrukute	doc_460280307194_item	2419003	et	4	main
olnud	doc_460280307194_item	2419023	et	4	main
huvitav	doc_460280307194_item	2419024	et	4	main
ja	doc_460280307194_item	2419025	et	3	main
esinemise	doc_460280307194_item	2419028	et	4	main
ajal	doc_460280307194_item	2419029	et	4	main
tüdrukud	doc_460280307194_item	2419030	et	3	main
kasutasid	doc_460280307194_item	2419031	et	4	main
tundmatud	doc_460280307194_item	2419033	et	4	main
presentatsioon	doc_460280307194_item	2419036	et	4	main
mulle	doc_460280307194_item	2419042	et	4	main
meeldis	doc_460280307194_item	2419043	et	3	main
presentatsiooni	doc_460280307194_item	2419044	et	4	main
värvid	doc_460280307194_item	2419053	et	4	main
ja	doc_460280307194_item	2419055	et	3	main
a	doc_460280307194_item	2419062	et	4	main
eluviis	doc_460280307194_item	2419066	et	3	main
üks	doc_460280307194_item	2419068	et	3	main
vaatamata	doc_460280307194_item	2419070	et	4	main
mõnus	doc_460280307194_item	2419117	et	4	main
fotod	doc_460280307194_item	2419123	et	3	main
reklaamis	doc_460280307194_item	2419125	et	4	main
tööd	doc_460280307194_item	2419136	et	4	main
hästi	doc_460280307194_item	2419137	et	3	main
kuidas	doc_460280307194_item	2419138	et	3	main
me	doc_460280307194_item	2419139	et	4	main
tegime	doc_460280307194_item	2419140	et	3	main
rühmas	doc_460280307194_item	2419144	et	4	main
kolm	doc_460280307194_item	2419146	et	3	main
a	doc_460280307194_item	2419148	et	4	main
e	doc_460280307194_item	2419149	et	4	main
ja	doc_460280307194_item	2419150	et	3	main
mina	doc_460280307194_item	2419151	et	4	main
kõigepealt	doc_460280307194_item	2419161	et	3	main
rühma	doc_460280307194_item	2419164	et	4	main
haigust	doc_460280307194_item	2419169	et	4	main
leidis	doc_460280307194_item	2419173	et	4	main
informatsiooni	doc_460280307194_item	2419175	et	4	main
ja	doc_460280307194_item	2419176	et	3	main
pilte	doc_460280307194_item	2419177	et	3	main
kohta	doc_460280307194_item	2419180	et	4	main
kirjutas	doc_460280307194_item	2419182	et	3	main
punkti	doc_460280307194_item	2419184	et	4	main
siis	doc_460280307194_item	2419185	et	3	main
me	doc_460280307194_item	2419186	et	4	main
töid	doc_460280307194_item	2419191	et	3	main
ta	doc_460280307194_item	2419195	et	4	main
tegi	doc_460280307194_item	2419196	et	4	main
pointis	doc_460280307194_item	2419198	et	4	main
presentatsiooni	doc_460280307194_item	2419199	et	4	main
analüüs	doc_460280307195_item	2419200	et	3	main
meenutame	doc_460280307195_item	2419201	et	3	main
aega	doc_460280307195_item	2419210	et	4	main
tervis	doc_460280307194_item	2418965	et	3	main
ekspromt	doc_460280307194_item	2418975	et	4	main
tegid	doc_460280307194_item	2418977	et	4	main
ja	doc_460280307194_item	2418980	et	3	main
tihti	doc_460280307194_item	2418981	et	3	main
sellele	doc_460280307194_item	2418990	et	4	main
töö	doc_460280307194_item	2418999	et	4	main
oli	doc_460280307194_item	2419000	et	3	main
üsna	doc_460280307194_item	2419001	et	3	main
nõrk	doc_460280307194_item	2419002	et	3	main
ravimtaimedest	doc_460280307194_item	2419006	et	4	main
nas	doc_460280307194_item	2419007	et	4	main
kokku	doc_460280307194_item	2419009	et	3	main
paar	doc_460280307194_item	2419016	et	3	main
minu	doc_460280307194_item	2419018	et	3	main
see	doc_460280307194_item	2419020	et	3	main
presentatsioon	doc_460280307194_item	2419021	et	4	main
jätav	doc_460280307194_item	2419027	et	4	main
palju	doc_460280307194_item	2419032	et	4	main
ei	doc_460280307194_item	2419037	et	4	main
mõnusad	doc_460280307194_item	2419052	et	3	main
ja	doc_460280307194_item	2419061	et	3	main
oli	doc_460280307194_item	2419067	et	3	main
et	doc_460280307194_item	2419072	et	3	main
oli	doc_460280307194_item	2419079	et	3	main
oli	doc_460280307194_item	2419116	et	3	main
heledad	doc_460280307194_item	2419118	et	3	main
oma	doc_460280307194_item	2419141	et	4	main
oli	doc_460280307194_item	2419145	et	3	main
inimest	doc_460280307194_item	2419147	et	3	main
liige	doc_460280307194_item	2419165	et	4	main
valis	doc_460280307194_item	2419166	et	3	main
üht	doc_460280307194_item	2419168	et	3	main
saatsime	doc_460280307194_item	2419189	et	3	main
suvekoolivaheaeg	doc_460280307195_item	2419204	et	3	main
meenutada	doc_460280307195_item	2419208	et	3	main
oma	doc_460280307195_item	2419213	et	4	main
suvega	doc_460280307195_item	2419215	et	3	main
minu	doc_460280307195_item	2419216	et	3	main
oli	doc_460280307195_item	2419218	et	3	main
erinevates	doc_460280307195_item	2419238	et	4	main
arkadi	doc_460280307195_item	2419246	et	4	main
sõprade	doc_460280307195_item	2419253	et	3	main
puhkasid	doc_460280307195_item	2419256	et	4	main
kumbki	doc_460280307195_item	2419258	et	4	main
püüelsid	doc_460280307195_item	2419259	et	4	main
parendada	doc_460280307195_item	2419260	et	3	main
eestikeelseid	doc_460280307195_item	2419265	et	3	main
kelle	doc_460280307195_item	2419270	et	4	main
on	doc_460280307195_item	2419272	et	4	main
eesti	doc_460280307195_item	2419273	et	4	main
vaatasin	doc_460280307195_item	2419276	et	3	main
filme	doc_460280307195_item	2419278	et	3	main
teenindasin	doc_460280307195_item	2419280	et	3	main
uusi	doc_460280307195_item	2419295	et	3	main
ajal	doc_460280307195_item	2419298	et	4	main
sai	doc_460280307195_item	2419300	et	4	main
kogemuse	doc_460280307195_item	2419302	et	3	main
juhtida	doc_460280307195_item	2419303	et	4	main
autot	doc_460280307195_item	2419304	et	3	main
ja	doc_460280307195_item	2419305	et	3	main
ta	doc_460280307195_item	2419310	et	4	main
lõket	doc_460280307195_item	2419317	et	4	main
teenindamisest	doc_460280307195_item	2419324	et	4	main
võõrkeeles	doc_460280307195_item	2419341	et	4	main
hästi	doc_460280307195_item	2419350	et	3	main
kõik	doc_460280307195_item	2419355	et	4	main
nii	doc_460280307195_item	2419357	et	3	main
sellele	doc_460280307195_item	2419364	et	4	main
palju	doc_460280307194_item	2418978	et	4	main
vigu	doc_460280307194_item	2418979	et	3	main
takerdusid	doc_460280307194_item	2418982	et	4	main
ja	doc_460280307194_item	2418986	et	3	main
meelest	doc_460280307194_item	2418997	et	4	main
nende	doc_460280307194_item	2418998	et	4	main
jutustus	doc_460280307194_item	2419004	et	4	main
igaühest	doc_460280307194_item	2419014	et	4	main
sõna	doc_460280307194_item	2419017	et	4	main
jaoks	doc_460280307194_item	2419019	et	4	main
ei	doc_460280307194_item	2419022	et	4	main
sellepärast	doc_460280307194_item	2419035	et	3	main
aga	doc_460280307194_item	2419040	et	3	main
k	doc_460280307194_item	2419054	et	4	main
esinemine	doc_460280307194_item	2419063	et	4	main
parimatest	doc_460280307194_item	2419069	et	4	main
tüüdrukud	doc_460280307194_item	2419073	et	4	main
üldtuntud	doc_460280307194_item	2419075	et	3	main
fakte	doc_460280307194_item	2419076	et	3	main
nende	doc_460280307194_item	2419077	et	4	main
esinemine	doc_460280307194_item	2419078	et	4	main
ja	doc_460280307194_item	2419082	et	3	main
vormistus	doc_460280307194_item	2419115	et	4	main
ja	doc_460280307194_item	2419121	et	3	main
nagu	doc_460280307194_item	2419124	et	3	main
võib	doc_460280307194_item	2419130	et	3	main
tegid	doc_460280307194_item	2419134	et	4	main
oma	doc_460280307194_item	2419135	et	4	main
meie	doc_460280307194_item	2419143	et	4	main
seda	doc_460280307194_item	2419171	et	3	main
koos	doc_460280307194_item	2419187	et	4	main
e-ga	doc_460280307194_item	2419188	et	3	main
a-i	doc_460280307194_item	2419192	et	4	main
ja	doc_460280307194_item	2419194	et	3	main
suve	doc_460280307195_item	2419202	et	4	main
on	doc_460280307195_item	2419205	et	4	main
proovin	doc_460280307195_item	2419207	et	3	main
ja	doc_460280307195_item	2419211	et	3	main
paarikaaslane	doc_460280307195_item	2419217	et	3	main
arkadi	doc_460280307195_item	2419219	et	4	main
on	doc_460280307195_item	2419221	et	4	main
minu	doc_460280307195_item	2419223	et	3	main
muidugi	doc_460280307195_item	2419225	et	4	main
on	doc_460280307195_item	2419226	et	4	main
vaheaega	doc_460280307195_item	2419235	et	4	main
eestis	doc_460280307195_item	2419236	et	3	main
aga	doc_460280307195_item	2419237	et	3	main
tallinnas	doc_460280307195_item	2419244	et	4	main
ja	doc_460280307195_item	2419245	et	3	main
narvas	doc_460280307195_item	2419247	et	4	main
ja	doc_460280307195_item	2419255	et	3	main
luges	doc_460280307195_item	2419264	et	3	main
ja	doc_460280307195_item	2419267	et	3	main
ja	doc_460280307195_item	2419279	et	3	main
ning	doc_460280307195_item	2419281	et	3	main
maailmast	doc_460280307195_item	2419288	et	4	main
ja	doc_460280307195_item	2419289	et	3	main
vabalt	doc_460280307195_item	2419290	et	4	main
oskavad	doc_460280307195_item	2419291	et	4	main
võõrkeelt	doc_460280307195_item	2419292	et	4	main
igaüks	doc_460280307195_item	2419293	et	3	main
suvepuhkuse	doc_460280307195_item	2419297	et	3	main
arkadi	doc_460280307195_item	2419299	et	4	main
kasuliku	doc_460280307195_item	2419301	et	3	main
tegema	doc_460280307195_item	2419316	et	3	main
järelikult	doc_460280307195_item	2419329	et	3	main
sain	doc_460280307195_item	2419330	et	3	main
ka	doc_460280307195_item	2419331	et	3	main
teenida	doc_460280307195_item	2419333	et	3	main
raha	doc_460280307195_item	2419335	et	4	main
suhelda	doc_460280307195_item	2419336	et	4	main
rääkida	doc_460280307195_item	2419340	et	3	main
võiks	doc_460280307195_item	2419343	et	4	main
et	doc_460280307195_item	2419345	et	3	main
suurepäraselt	doc_460280307195_item	2419353	et	4	main
nagu	doc_460280307195_item	2419358	et	3	main
ja	doc_460280307195_item	2419361	et	3	main
vaatamata	doc_460280307195_item	2419363	et	4	main
igaüks	doc_460280307195_item	2419365	et	3	main
silmaring	doc_460280307195_item	2419369	et	3	main
sai	doc_460280307195_item	2419371	et	4	main
meelde	doc_460280307194_item	2419026	et	3	main
olnud	doc_460280307194_item	2419038	et	4	main
arusaadav	doc_460280307194_item	2419039	et	4	main
egav	doc_460280307194_item	2419041	et	4	main
a	doc_460280307194_item	2419056	et	4	main
minu	doc_460280307194_item	2419058	et	3	main
meelest	doc_460280307194_item	2419059	et	4	main
teemal	doc_460280307194_item	2419064	et	3	main
tervislik	doc_460280307194_item	2419065	et	3	main
sellele	doc_460280307194_item	2419071	et	4	main
rääkisid	doc_460280307194_item	2419074	et	4	main
hästi	doc_460280307194_item	2419080	et	3	main
informatiivne	doc_460280307194_item	2419083	et	3	main
arvan	doc_460280307194_item	2419084	et	3	main
et	doc_460280307194_item	2419085	et	3	main
informatsioon	doc_460280307194_item	2419086	et	3	main
millest	doc_460280307194_item	2419087	et	3	main
nad	doc_460280307194_item	2419088	et	3	main
jutustasid	doc_460280307194_item	2419089	et	4	main
oleks	doc_460280307194_item	2419090	et	3	main
kasulik	doc_460280307194_item	2419091	et	3	main
igale	doc_460280307194_item	2419092	et	3	main
inimesele	doc_460280307194_item	2419093	et	3	main
kes	doc_460280307194_item	2419094	et	4	main
hoolitseb	doc_460280307194_item	2419095	et	3	main
oma	doc_460280307194_item	2419096	et	4	main
tervise	doc_460280307194_item	2419097	et	3	main
ja	doc_460280307194_item	2419099	et	3	main
lihtsalt	doc_460280307194_item	2419100	et	4	main
eest	doc_460280307194_item	2419098	et	4	main
üldarenguks	doc_460280307194_item	2419101	et	3	main
ma	doc_460280307194_item	2419102	et	3	main
ei	doc_460280307194_item	2419103	et	4	main
mõtle	doc_460280307194_item	2419104	et	4	main
et	doc_460280307194_item	2419105	et	3	main
jutustus	doc_460280307194_item	2419106	et	4	main
oli	doc_460280307194_item	2419107	et	3	main
väga	doc_460280307194_item	2419108	et	3	main
huvitav	doc_460280307194_item	2419109	et	4	main
see	doc_460280307194_item	2419110	et	3	main
oli	doc_460280307194_item	2419111	et	3	main
tavaline	doc_460280307194_item	2419112	et	4	main
ja	doc_460280307194_item	2419113	et	3	main
arusaadav	doc_460280307194_item	2419114	et	4	main
naiste	doc_460280307194_item	2419122	et	3	main
vajalikud	doc_460280307194_item	2419127	et	3	main
kokkuvõteks	doc_460280307194_item	2419129	et	3	main
presentatsiooni	doc_460280307194_item	2419142	et	4	main
me	doc_460280307194_item	2419152	et	4	main
otsustasime	doc_460280307194_item	2419153	et	3	main
teha	doc_460280307194_item	2419154	et	3	main
presentatsiooni	doc_460280307194_item	2419155	et	4	main
teemal	doc_460280307194_item	2419156	et	3	main
tänapäeva	doc_460280307194_item	2419157	et	4	main
inimese	doc_460280307194_item	2419158	et	4	main
ohustavad	doc_460280307194_item	2419159	et	4	main
ja	doc_460280307194_item	2419126	et	3	main
punktid	doc_460280307194_item	2419128	et	4	main
öelda	doc_460280307194_item	2419131	et	4	main
et	doc_460280307194_item	2419132	et	3	main
tüdrukud	doc_460280307194_item	2419133	et	3	main
haigused	doc_460280307194_item	2419160	et	4	main
iga	doc_460280307194_item	2419162	et	4	main
meie	doc_460280307194_item	2419163	et	4	main
pärast	doc_460280307194_item	2419170	et	4	main
igaüks	doc_460280307194_item	2419172	et	3	main
internetist	doc_460280307194_item	2419174	et	4	main
haiguse	doc_460280307194_item	2419179	et	4	main
lõppenud	doc_460280307195_item	2419206	et	4	main
möödunud	doc_460280307195_item	2419209	et	4	main
kes	doc_460280307195_item	2419220	et	4	main
mõned	doc_460280307195_item	2419227	et	3	main
sarnased	doc_460280307195_item	2419228	et	4	main
jooned	doc_460280307195_item	2419229	et	3	main
arkadi	doc_460280307195_item	2419230	et	4	main
kohtadesmina	doc_460280307195_item	2419239	et	4	main
puhkasin	doc_460280307195_item	2419240	et	3	main
narvas	doc_460280307195_item	2419241	et	4	main
laagnas	doc_460280307195_item	2419242	et	4	main
ja	doc_460280307195_item	2419243	et	3	main
pärnus	doc_460280307195_item	2419248	et	3	main
ja	doc_460280307195_item	2419249	et	3	main
seltsis	doc_460280307195_item	2419254	et	4	main
ajalehti	doc_460280307195_item	2419266	et	4	main
suhtles	doc_460280307195_item	2419268	et	3	main
emakeel	doc_460280307195_item	2419271	et	4	main
mina	doc_460280307195_item	2419275	et	4	main
võõrkeelseid	doc_460280307195_item	2419277	et	3	main
kes	doc_460280307195_item	2419284	et	4	main
eestisse	doc_460280307195_item	2419286	et	4	main
võõrkeeles	doc_460280307195_item	2419307	et	4	main
pärnus	doc_460280307195_item	2419308	et	3	main
kui	doc_460280307195_item	2419309	et	3	main
õppis	doc_460280307195_item	2419315	et	3	main
mina	doc_460280307195_item	2419321	et	4	main
töökogemuse	doc_460280307195_item	2419323	et	3	main
sest	doc_460280307195_item	2419325	et	4	main
töötasin	doc_460280307195_item	2419326	et	3	main
suvel	doc_460280307195_item	2419327	et	3	main
baarmenina	doc_460280307195_item	2419328	et	4	main
kogemus	doc_460280307195_item	2419332	et	3	main
oma	doc_460280307195_item	2419334	et	4	main
klientidega	doc_460280307195_item	2419338	et	3	main
mitte	doc_460280307195_item	2419352	et	3	main
mitte	doc_460280307195_item	2419354	et	3	main
juhtus	doc_460280307195_item	2419356	et	3	main
endale	doc_460280307194_item	2419167	et	4	main
oma	doc_460280307194_item	2419178	et	4	main
ja	doc_460280307194_item	2419181	et	3	main
sobivaid	doc_460280307194_item	2419183	et	4	main
oma	doc_460280307194_item	2419190	et	4	main
e-mailile	doc_460280307194_item	2419193	et	4	main
pover	doc_460280307194_item	2419197	et	4	main
jahjuks	doc_460280307195_item	2419203	et	4	main
võrrelda	doc_460280307195_item	2419212	et	4	main
paarikaaslase	doc_460280307195_item	2419214	et	3	main
pinginaaber	doc_460280307195_item	2419224	et	3	main
ja	doc_460280307195_item	2419231	et	3	main
mõlemad	doc_460280307195_item	2419251	et	3	main
mõnusalt	doc_460280307195_item	2419257	et	4	main
võõrkeeleoskust	doc_460280307195_item	2419262	et	3	main
arkadi	doc_460280307195_item	2419263	et	4	main
keel	doc_460280307195_item	2419274	et	4	main
välismaalastega	doc_460280307195_item	2419283	et	4	main
kogemusi	doc_460280307195_item	2419296	et	3	main
metsas	doc_460280307195_item	2419312	et	3	main
siis	doc_460280307195_item	2419314	et	3	main
ja	doc_460280307195_item	2419318	et	3	main
ka	doc_460280307195_item	2419222	et	3	main
mina	doc_460280307195_item	2419232	et	4	main
veetsime	doc_460280307195_item	2419233	et	3	main
oma	doc_460280307195_item	2419234	et	4	main
tallinnas	doc_460280307195_item	2419250	et	4	main
olid	doc_460280307195_item	2419252	et	4	main
oma	doc_460280307195_item	2419261	et	4	main
inimestega	doc_460280307195_item	2419269	et	3	main
rääkisin	doc_460280307195_item	2419282	et	3	main
tulid	doc_460280307195_item	2419285	et	4	main
kogu	doc_460280307195_item	2419287	et	4	main
sai	doc_460280307195_item	2419294	et	4	main
suhelda	doc_460280307195_item	2419306	et	4	main
käis	doc_460280307195_item	2419311	et	4	main
matkal	doc_460280307195_item	2419313	et	3	main
püstitas	doc_460280307195_item	2419319	et	3	main
telke	doc_460280307195_item	2419320	et	3	main
ja	doc_460280307195_item	2419339	et	3	main
möödus	doc_460280307195_item	2419348	et	3	main
aga	doc_460280307195_item	2419351	et	3	main
me	doc_460280307195_item	2419359	et	4	main
planeerisime	doc_460280307195_item	2419362	et	3	main
natuke	doc_460280307195_item	2419366	et	4	main
ja	doc_460280307195_item	2419370	et	3	main
põneva	doc_460280307195_item	2419372	et	3	main
mulje	doc_460280307195_item	2419373	et	4	main
sain	doc_460280307195_item	2419322	et	3	main
erinevate	doc_460280307195_item	2419337	et	4	main
kokkuvõtteks	doc_460280307195_item	2419342	et	3	main
öelda	doc_460280307195_item	2419344	et	4	main
meie	doc_460280307195_item	2419346	et	4	main
suvi	doc_460280307195_item	2419347	et	3	main
üsna	doc_460280307195_item	2419349	et	3	main
tahtsime	doc_460280307195_item	2419360	et	3	main
laiendas	doc_460280307195_item	2419367	et	3	main
oma	doc_460280307195_item	2419368	et	4	main
me	doc_460280307199_item	2419827	et	4	main
igalpoolpraktiliselt	doc_460280307199_item	2419831	et	4	main
rohkem	doc_460280307199_item	2419842	et	4	main
mõned	doc_460280307199_item	2419843	et	3	main
vähem	doc_460280307199_item	2419844	et	4	main
nad	doc_460280307199_item	2419845	et	3	main
ja	doc_460280307199_item	2419848	et	3	main
iga	doc_460280307199_item	2419850	et	4	main
nõusid	doc_460280307199_item	2419863	et	3	main
nad	doc_460280307199_item	2419882	et	3	main
kergendavad	doc_460280307199_item	2419884	et	4	main
meie	doc_460280307199_item	2419885	et	4	main
elu	doc_460280307199_item	2419886	et	4	main
harjunud	doc_460280307199_item	2419892	et	4	main
kloor	doc_460280307199_item	2419904	et	3	main
kuid	doc_460280307199_item	2419816	et	4	main
päev	doc_460280307199_item	2419851	et	3	main
nõudepesuvahendiga	doc_460280307199_item	2419864	et	3	main
meigivad	doc_460280307199_item	2419866	et	4	main
lõhnastavad	doc_460280307199_item	2419868	et	4	main
end	doc_460280307199_item	2419869	et	4	main
korterit	doc_460280307199_item	2419874	et	3	main
ja	doc_460280307199_item	2419878	et	3	main
teiselt	doc_460280307199_item	2419887	et	4	main
nii	doc_460280307199_item	2419891	et	3	main
vahendeid	doc_460280307199_item	2419895	et	3	main
nad	doc_460280307199_item	2419899	et	3	main
mis	doc_460280307199_item	2419905	et	4	main
ja	doc_460280307199_item	2419952	et	3	main
edasi	doc_460280307199_item	2419954	et	3	main
küsimus	doc_460280307199_item	2419960	et	4	main
seotud	doc_460280307199_item	2419961	et	4	main
vahendite	doc_460280307199_item	2419963	et	3	main
väga	doc_460280307199_item	2419966	et	3	main
nad	doc_460280307199_item	2419968	et	3	main
mugavad	doc_460280307199_item	2419970	et	3	main
essee	doc_460280307199_item	2419810	et	4	main
vahendid	doc_460280307199_item	2419812	et	3	main
meie	doc_460280307199_item	2419814	et	4	main
elu	doc_460280307199_item	2419815	et	4	main
keemilised	doc_460280307199_item	2419811	et	4	main
väitega	doc_460280307199_item	2419822	et	3	main
täielikult	doc_460280307199_item	2419823	et	4	main
praeguses	doc_460280307199_item	2419825	et	3	main
elus	doc_460280307199_item	2419826	et	4	main
vahendeid	doc_460280307199_item	2419830	et	3	main
pesemis-	doc_460280307199_item	2419833	et	4	main
puhastamis-	doc_460280307199_item	2419834	et	4	main
ja	doc_460280307199_item	2419835	et	3	main
vahendid	doc_460280307199_item	2419837	et	3	main
sisaldavad	doc_460280307199_item	2419838	et	4	main
mõned	doc_460280307199_item	2419841	et	3	main
tugevatoimelised	doc_460280307199_item	2419847	et	4	main
juukseid	doc_460280307199_item	2419859	et	3	main
keha	doc_460280307199_item	2419861	et	4	main
keemilised	doc_460280307199_item	2419870	et	4	main
vahendid	doc_460280307199_item	2419871	et	3	main
meil	doc_460280307199_item	2419873	et	4	main
remonti	doc_460280307199_item	2419876	et	4	main
välja	doc_460280307199_item	2419880	et	4	main
poolt	doc_460280307199_item	2419888	et	4	main
kasutada	doc_460280307199_item	2419893	et	3	main
unustavad	doc_460280307199_item	2419897	et	4	main
kahjutavad	doc_460280307199_item	2419900	et	3	main
nende	doc_460280307199_item	2419901	et	4	main
tervist	doc_460280307199_item	2419902	et	4	main
isegi	doc_460280307199_item	2419922	et	4	main
kindad	doc_460280307199_item	2419924	et	3	main
mõnikord	doc_460280307199_item	2419925	et	3	main
saa	doc_460280307199_item	2419927	et	4	main
kaitsta	doc_460280307199_item	2419928	et	4	main
nahk	doc_460280307199_item	2419929	et	3	main
muutub	doc_460280307199_item	2419930	et	3	main
kuivaks	doc_460280307199_item	2419931	et	4	main
ja	doc_460280307199_item	2419932	et	3	main
praguneb	doc_460280307199_item	2419933	et	3	main
eriti	doc_460280307199_item	2419934	et	3	main
ainetega	doc_460280307199_item	2419942	et	3	main
koristajad	doc_460280307199_item	2419947	et	4	main
ujula	doc_460280307199_item	2419950	et	4	main
töötajad	doc_460280307199_item	2419951	et	4	main
nii	doc_460280307199_item	2419953	et	3	main
kõik	doc_460280307199_item	2419955	et	4	main
ülalpool	doc_460280307199_item	2419956	et	3	main
kasutamisega	doc_460280307199_item	2419964	et	4	main
kergendavad	doc_460280307199_item	2419813	et	4	main
kahjustavad	doc_460280307199_item	2419817	et	4	main
tervist	doc_460280307199_item	2419818	et	4	main
ma	doc_460280307199_item	2419819	et	3	main
olen	doc_460280307199_item	2419820	et	3	main
selle	doc_460280307199_item	2419821	et	4	main
kasutame	doc_460280307199_item	2419828	et	3	main
kõik	doc_460280307199_item	2419832	et	4	main
keemilisi	doc_460280307199_item	2419839	et	4	main
aineid	doc_460280307199_item	2419840	et	3	main
me	doc_460280307199_item	2419852	et	4	main
puhastame	doc_460280307199_item	2419853	et	3	main
hambaid	doc_460280307199_item	2419854	et	3	main
hambapastaga	doc_460280307199_item	2419855	et	3	main
peseme	doc_460280307199_item	2419856	et	3	main
käsi	doc_460280307199_item	2419857	et	4	main
seebiga	doc_460280307199_item	2419858	et	3	main
shampooniga	doc_460280307199_item	2419860	et	4	main
naised	doc_460280307199_item	2419865	et	3	main
ja	doc_460280307199_item	2419867	et	3	main
aitavad	doc_460280307199_item	2419872	et	4	main
teha	doc_460280307199_item	2419877	et	3	main
on	doc_460280307199_item	2419890	et	4	main
keemilisi	doc_460280307199_item	2419894	et	4	main
et	doc_460280307199_item	2419896	et	3	main
et	doc_460280307199_item	2419898	et	3	main
on	doc_460280307199_item	2419906	et	4	main
nahale	doc_460280307199_item	2419921	et	3	main
ei	doc_460280307199_item	2419926	et	4	main
ohus	doc_460280307199_item	2419935	et	3	main
tegemist	doc_460280307199_item	2419943	et	4	main
näiteks	doc_460280307199_item	2419946	et	4	main
ja	doc_460280307199_item	2419949	et	3	main
öeldu	doc_460280307199_item	2419957	et	4	main
on	doc_460280307199_item	2419965	et	4	main
on	doc_460280307199_item	2419969	et	4	main
aga	doc_460280307199_item	2419973	et	3	main
tervisele	doc_460280307199_item	2419975	et	3	main
nõus	doc_460280307199_item	2419824	et	4	main
keemilisi	doc_460280307199_item	2419829	et	4	main
kosmeetilised	doc_460280307199_item	2419836	et	3	main
on	doc_460280307199_item	2419846	et	4	main
efektiivsed	doc_460280307199_item	2419849	et	3	main
dushigeeliga	doc_460280307199_item	2419862	et	4	main
koristada	doc_460280307199_item	2419875	et	3	main
kaunilt	doc_460280307199_item	2419879	et	4	main
näha	doc_460280307199_item	2419881	et	3	main
tõesti	doc_460280307199_item	2419883	et	3	main
inimesed	doc_460280307199_item	2419889	et	3	main
näiteks	doc_460280307199_item	2419903	et	4	main
pesuvalgendite	doc_460280307199_item	2419907	et	3	main
ja	doc_460280307199_item	2419908	et	3	main
puhastamisvahendite	doc_460280307199_item	2419909	et	3	main
koostises	doc_460280307199_item	2419910	et	3	main
tekitab	doc_460280307199_item	2419911	et	3	main
allergiat	doc_460280307199_item	2419912	et	3	main
ja	doc_460280307199_item	2419913	et	3	main
hingamisteede	doc_460280307199_item	2419914	et	3	main
haigusi	doc_460280307199_item	2419915	et	4	main
keemilised	doc_460280307199_item	2419916	et	4	main
ained	doc_460280307199_item	2419917	et	3	main
on	doc_460280307199_item	2419918	et	4	main
kahjulikud	doc_460280307199_item	2419919	et	3	main
käte	doc_460280307199_item	2419920	et	3	main
spetsiaalsed	doc_460280307199_item	2419923	et	3	main
kes	doc_460280307199_item	2419939	et	4	main
teevad	doc_460280307199_item	2419940	et	3	main
keemiliste	doc_460280307199_item	2419941	et	4	main
iga	doc_460280307199_item	2419944	et	4	main
päev	doc_460280307199_item	2419945	et	3	main
et	doc_460280307199_item	2419959	et	3	main
keemiliste	doc_460280307199_item	2419962	et	4	main
ja	doc_460280307199_item	2419971	et	3	main
efektiivsed	doc_460280307199_item	2419972	et	3	main
ohtlikud	doc_460280307199_item	2419974	et	3	main
teksti	doc_460280307201_item	2420156	et	4	main
et	doc_460280307201_item	2420164	et	3	main
ees	doc_460280307201_item	2420166	et	4	main
on	doc_460280307201_item	2420167	et	4	main
suur	doc_460280307201_item	2420168	et	3	main
ökoloogiline	doc_460280307201_item	2420169	et	4	main
probleem	doc_460280307201_item	2420170	et	3	main
on	doc_460280307199_item	2419936	et	4	main
need	doc_460280307199_item	2419937	et	3	main
inimesed	doc_460280307199_item	2419938	et	3	main
laboratooriumi	doc_460280307199_item	2419948	et	4	main
näitab	doc_460280307199_item	2419958	et	3	main
vaieldav	doc_460280307199_item	2419967	et	4	main
nimi	doc_460280307201_item	2420157	et	3	main
uuesti	doc_460280307201_item	2420160	et	3	main
mida	doc_460280307201_item	2420171	et	4	main
tekstist	doc_460280307201_item	2420176	et	3	main
kõik	doc_460280307201_item	2420181	et	4	main
selle	doc_460280307201_item	2420155	et	4	main
kasuta	doc_460280307201_item	2420159	et	4	main
ja	doc_460280307201_item	2420161	et	3	main
tähendab	doc_460280307201_item	2420163	et	3	main
meie	doc_460280307201_item	2420165	et	4	main
on	doc_460280307201_item	2420172	et	4	main
vaja	doc_460280307201_item	2420173	et	4	main
lahutada	doc_460280307201_item	2420174	et	3	main
mida	doc_460280307201_item	2420183	et	4	main
näiteks	doc_460280307201_item	2420222	et	4	main
kui	doc_460280307201_item	2420223	et	3	main
sest	doc_460280307201_item	2420229	et	4	main
lagunevatest	doc_460280307201_item	2420230	et	4	main
nii	doc_460280307201_item	2420241	et	3	main
katki	doc_460280307201_item	2420246	et	4	main
ning	doc_460280307201_item	2420256	et	3	main
kogumispunkti	doc_460280307201_item	2420260	et	4	main
ei	doc_460280307201_item	2420266	et	4	main
teaksid	doc_460280307201_item	2420320	et	4	main
puhkamine	doc_460280307202_item	2420332	et	4	main
õppeaasta	doc_460280307202_item	2420344	et	4	main
päevitada	doc_460280307202_item	2420350	et	3	main
supelda	doc_460280307202_item	2420352	et	4	main
jalutada	doc_460280307202_item	2420355	et	3	main
õues	doc_460280307202_item	2420356	et	4	main
loodan	doc_460280307202_item	2420357	et	3	main
et	doc_460280307202_item	2420358	et	3	main
jõudu	doc_460280307202_item	2420362	et	4	main
suurem	doc_460280307202_item	2420383	et	4	main
osa	doc_460280307202_item	2420384	et	4	main
minu	doc_460280307202_item	2420385	et	3	main
sõbrad	doc_460280307202_item	2420391	et	3	main
õpivad	doc_460280307202_item	2420394	et	3	main
parem	doc_460280307202_item	2420401	et	4	main
aeg	doc_460280307202_item	2420402	et	3	main
sõita	doc_460280307202_item	2420411	et	3	main
tahan	doc_460280307202_item	2420412	et	3	main
saaremaal	doc_460280307202_item	2420414	et	4	main
saaremaa	doc_460280307202_item	2420417	et	4	main
on	doc_460280307202_item	2420418	et	4	main
minu	doc_460280307202_item	2420419	et	3	main
valik	doc_460280307202_item	2420420	et	3	main
arvamus	doc_460280307201_item	2420154	et	3	main
saime	doc_460280307201_item	2420178	et	3	main
et	doc_460280307201_item	2420180	et	3	main
asjad	doc_460280307201_item	2420182	et	3	main
me	doc_460280307201_item	2420184	et	4	main
kasutame	doc_460280307201_item	2420185	et	3	main
tuleb	doc_460280307201_item	2420186	et	3	main
taas	doc_460280307201_item	2420187	et	3	main
töödelda	doc_460280307201_item	2420188	et	4	main
see	doc_460280307201_item	2420189	et	3	main
võib	doc_460280307201_item	2420190	et	3	main
olla	doc_460280307201_item	2420191	et	3	main
klaastaara	doc_460280307201_item	2420192	et	4	main
paber	doc_460280307201_item	2420193	et	3	main
papp	doc_460280307201_item	2420194	et	3	main
vanad	doc_460280307201_item	2420195	et	3	main
ajalehed	doc_460280307201_item	2420196	et	3	main
metall	doc_460280307201_item	2420197	et	3	main
jne	doc_460280307201_item	2420198	et	4	main
autor	doc_460280307201_item	2420199	et	3	main
tahtis	doc_460280307201_item	2420200	et	3	main
ütelda	doc_460280307201_item	2420201	et	4	main
et	doc_460280307201_item	2420202	et	3	main
see	doc_460280307201_item	2420203	et	3	main
on	doc_460280307201_item	2420204	et	4	main
suur	doc_460280307201_item	2420205	et	3	main
tänapäevane	doc_460280307201_item	2420206	et	4	main
probleem	doc_460280307201_item	2420207	et	3	main
ja	doc_460280307201_item	2420208	et	3	main
ta	doc_460280307201_item	2420209	et	4	main
tahaks	doc_460280307201_item	2420210	et	3	main
et	doc_460280307201_item	2420211	et	3	main
iga	doc_460280307201_item	2420212	et	4	main
meist	doc_460280307201_item	2420213	et	3	main
mõtleks	doc_460280307201_item	2420214	et	3	main
oma	doc_460280307201_item	2420215	et	4	main
tegevusest	doc_460280307201_item	2420216	et	4	main
ja	doc_460280307201_item	2420217	et	3	main
püüaks	doc_460280307201_item	2420218	et	3	main
hoida	doc_460280307201_item	2420219	et	3	main
looduslikke	doc_460280307201_item	2420220	et	3	main
bioloogiline	doc_460280307201_item	2420228	et	4	main
kaua	doc_460280307201_item	2420242	et	3	main
kui	doc_460280307201_item	2420243	et	3	main
läheb	doc_460280307201_item	2420245	et	3	main
võid	doc_460280307201_item	2420248	et	4	main
kui	doc_460280307201_item	2420250	et	3	main
prügi	doc_460280307201_item	2420259	et	4	main
aga	doc_460280307201_item	2420261	et	3	main
on	doc_460280307201_item	2420158	et	4	main
see	doc_460280307201_item	2420162	et	3	main
sellest	doc_460280307201_item	2420175	et	4	main
teada	doc_460280307201_item	2420179	et	3	main
komposti	doc_460280307201_item	2420232	et	4	main
taastöödeldavaid	doc_460280307201_item	2420234	et	3	main
võid	doc_460280307201_item	2420238	et	4	main
kilekotti	doc_460280307201_item	2420240	et	4	main
see	doc_460280307201_item	2420244	et	3	main
sa	doc_460280307201_item	2420247	et	3	main
abistada	doc_460280307201_item	2420249	et	3	main
viima	doc_460280307201_item	2420252	et	3	main
taaskasutatavat	doc_460280307201_item	2420258	et	4	main
kui	doc_460280307201_item	2420262	et	3	main
ole	doc_460280307201_item	2420267	et	4	main
võimalust	doc_460280307201_item	2420269	et	3	main
see	doc_460280307201_item	2420271	et	3	main
planeet	doc_460280307201_item	2420276	et	3	main
kasulik	doc_460280307201_item	2420312	et	3	main
väiksedele	doc_460280307201_item	2420314	et	4	main
et	doc_460280307201_item	2420316	et	3	main
nad	doc_460280307201_item	2420317	et	3	main
me	doc_460280307201_item	2420177	et	4	main
resursse	doc_460280307201_item	2420221	et	4	main
sul	doc_460280307201_item	2420224	et	3	main
köögijäätmetest	doc_460280307201_item	2420231	et	4	main
asju	doc_460280307201_item	2420235	et	3	main
sa	doc_460280307201_item	2420237	et	3	main
kasutada	doc_460280307201_item	2420239	et	3	main
hakkad	doc_460280307201_item	2420251	et	3	main
klaastaara	doc_460280307201_item	2420253	et	4	main
kogu	doc_460280307201_item	2420254	et	4	main
paberit	doc_460280307201_item	2420255	et	3	main
ma	doc_460280307201_item	2420263	et	3	main
tean	doc_460280307201_item	2420264	et	3	main
on	doc_460280307201_item	2420272	et	4	main
probleem	doc_460280307201_item	2420274	et	3	main
muutab	doc_460280307201_item	2420277	et	4	main
oleks	doc_460280307201_item	2420311	et	3	main
tegevust	doc_460280307202_item	2420326	et	4	main
väsinud	doc_460280307202_item	2420337	et	4	main
ja	doc_460280307202_item	2420338	et	3	main
mul	doc_460280307202_item	2420339	et	3	main
on	doc_460280307202_item	2420340	et	4	main
uue	doc_460280307202_item	2420343	et	3	main
plaanin	doc_460280307202_item	2420347	et	3	main
magada	doc_460280307202_item	2420349	et	3	main
ja	doc_460280307202_item	2420354	et	3	main
nii	doc_460280307202_item	2420359	et	3	main
sugulasi	doc_460280307202_item	2420364	et	3	main
aga	doc_460280307202_item	2420389	et	3	main
on	doc_460280307202_item	2420407	et	4	main
kuhugi	doc_460280307202_item	2420410	et	4	main
olla	doc_460280307202_item	2420413	et	3	main
ja	doc_460280307202_item	2420415	et	3	main
sest	doc_460280307202_item	2420421	et	4	main
elan	doc_460280307202_item	2420423	et	3	main
juba	doc_460280307202_item	2420425	et	3	main
ei	doc_460280307202_item	2420430	et	4	main
olnud	doc_460280307202_item	2420431	et	4	main
kõige	doc_460280307202_item	2420438	et	4	main
palju	doc_460280307202_item	2420445	et	4	main
tahan	doc_460280307202_item	2420448	et	3	main
rootsi	doc_460280307202_item	2420450	et	4	main
see	doc_460280307202_item	2420452	et	3	main
riik	doc_460280307202_item	2420453	et	3	main
on	doc_460280307202_item	2420454	et	4	main
pärast	doc_460280307202_item	2420467	et	4	main
teada	doc_460280307202_item	2420472	et	3	main
on	doc_460280307202_item	2420498	et	4	main
praktika	doc_460280307202_item	2420505	et	4	main
lugemine	doc_460280307202_item	2420514	et	4	main
palju	doc_460280307202_item	2420526	et	4	main
lugeda	doc_460280307202_item	2420527	et	3	main
mina	doc_460280307202_item	2420540	et	4	main
ainult	doc_460280307202_item	2420541	et	4	main
sa	doc_460280307203_item	2420563	et	3	main
jagad	doc_460280307203_item	2420564	et	3	main
kööki	doc_460280307203_item	2420566	et	4	main
tekst	doc_460280307203_item	2420577	et	3	main
klassi	doc_460280307204_item	2420631	et	4	main
õpilastele	doc_460280307204_item	2420632	et	4	main
ma	doc_460280307204_item	2420633	et	3	main
intervjueerisin	doc_460280307204_item	2420634	et	3	main
paremad	doc_460280307204_item	2420649	et	4	main
minu	doc_460280307204_item	2420651	et	3	main
kõige	doc_460280307204_item	2420653	et	4	main
nädalani	doc_460280307204_item	2420672	et	3	main
soovitustest	doc_460280307204_item	2420675	et	4	main
suvi	doc_460280307204_item	2420678	et	3	main
kõige	doc_460280307204_item	2420680	et	4	main
meil	doc_460280307204_item	2420688	et	4	main
ilm	doc_460280307204_item	2420697	et	3	main
reisivad	doc_460280307204_item	2420699	et	4	main
koos	doc_460280307204_item	2420700	et	4	main
sõpradega	doc_460280307204_item	2420701	et	3	main
ja	doc_460280307204_item	2420707	et	3	main
reis	doc_460280307205_item	2420739	et	4	main
olen	doc_460280307205_item	2420748	et	3	main
selle	doc_460280307205_item	2420749	et	4	main
midagi	doc_460280307205_item	2420759	et	4	main
teeneid	doc_460280307205_item	2420767	et	4	main
juukselõikla	doc_460280307205_item	2420770	et	4	main
ja	doc_460280307205_item	2420772	et	3	main
on	doc_460280307201_item	2420225	et	4	main
aed	doc_460280307201_item	2420226	et	3	main
tee	doc_460280307201_item	2420227	et	4	main
kasuta	doc_460280307201_item	2420233	et	4	main
või	doc_460280307201_item	2420236	et	4	main
üldse	doc_460280307201_item	2420257	et	3	main
meil	doc_460280307201_item	2420265	et	4	main
seda	doc_460280307201_item	2420268	et	3	main
ka	doc_460280307201_item	2420273	et	3	main
meie	doc_460280307201_item	2420275	et	4	main
mustaks	doc_460280307201_item	2420278	et	4	main
ja	doc_460280307201_item	2420279	et	3	main
on	doc_460280307201_item	2420280	et	4	main
vaja	doc_460280307201_item	2420281	et	4	main
midagi	doc_460280307201_item	2420282	et	4	main
teha	doc_460280307201_item	2420283	et	3	main
sellest	doc_460280307201_item	2420284	et	4	main
infost	doc_460280307201_item	2420285	et	3	main
mina	doc_460280307201_item	2420286	et	4	main
juba	doc_460280307201_item	2420287	et	3	main
kuulsin	doc_460280307201_item	2420288	et	3	main
ja	doc_460280307201_item	2420289	et	3	main
ma	doc_460280307201_item	2420290	et	3	main
just	doc_460280307201_item	2420291	et	3	main
lugesin	doc_460280307201_item	2420292	et	3	main
sellest	doc_460280307201_item	2420293	et	4	main
veel	doc_460280307201_item	2420294	et	4	main
kord	doc_460280307201_item	2420295	et	4	main
see	doc_460280307201_item	2420296	et	3	main
artikel	doc_460280307201_item	2420297	et	4	main
on	doc_460280307201_item	2420298	et	4	main
tavalistele	doc_460280307201_item	2420300	et	4	main
mõeldud	doc_460280307201_item	2420299	et	4	main
inimestele	doc_460280307201_item	2420301	et	3	main
ja	doc_460280307201_item	2420302	et	3	main
nad	doc_460280307201_item	2420303	et	3	main
peavad	doc_460280307201_item	2420304	et	4	main
seda	doc_460280307201_item	2420305	et	3	main
teadma	doc_460280307201_item	2420306	et	3	main
ja	doc_460280307201_item	2420307	et	3	main
minu	doc_460280307201_item	2420308	et	3	main
seda	doc_460280307201_item	2420310	et	3	main
ja	doc_460280307201_item	2420270	et	3	main
lapsepõlvast	doc_460280307201_item	2420318	et	3	main
juba	doc_460280307201_item	2420319	et	3	main
sellest	doc_460280307201_item	2420321	et	4	main
probleemist	doc_460280307201_item	2420323	et	4	main
vaja	doc_460280307202_item	2420341	et	4	main
ma	doc_460280307202_item	2420346	et	3	main
uut	doc_460280307202_item	2420361	et	3	main
ja	doc_460280307202_item	2420366	et	3	main
minu	doc_460280307202_item	2420390	et	3	main
kohtumiste	doc_460280307202_item	2420403	et	4	main
jaoks	doc_460280307202_item	2420404	et	4	main
reisimine	doc_460280307202_item	2420405	et	4	main
rootsil	doc_460280307202_item	2420416	et	3	main
ja	doc_460280307202_item	2420428	et	3	main
saaremaa	doc_460280307202_item	2420435	et	4	main
on	doc_460280307202_item	2420436	et	4	main
sõita	doc_460280307202_item	2420449	et	3	main
sest	doc_460280307202_item	2420451	et	4	main
vaatamisväärsuste	doc_460280307202_item	2420466	et	4	main
rohkem	doc_460280307202_item	2420471	et	4	main
eestikeeleoskuse	doc_460280307202_item	2420478	et	3	main
see	doc_460280307202_item	2420480	et	3	main
et	doc_460280307202_item	2420483	et	3	main
parem	doc_460280307202_item	2420487	et	4	main
võrus	doc_460280307202_item	2420496	et	3	main
natukene	doc_460280307202_item	2420499	et	4	main
ka	doc_460280307202_item	2420509	et	3	main
sõpru	doc_460280307202_item	2420513	et	3	main
kirjanduse	doc_460280307202_item	2420515	et	3	main
andis	doc_460280307202_item	2420517	et	3	main
ja	doc_460280307202_item	2420522	et	3	main
suvel	doc_460280307202_item	2420538	et	3	main
sõda	doc_460280307202_item	2420544	et	4	main
rahu	doc_460280307202_item	2420546	et	4	main
üks	doc_460280307203_item	2420548	et	3	main
kord	doc_460280307203_item	2420549	et	4	main
lugesin	doc_460280307203_item	2420550	et	3	main
ma	doc_460280307203_item	2420551	et	3	main
oli	doc_460280307203_item	2420561	et	3	main
kujutatud	doc_460280307203_item	2420569	et	4	main
leib	doc_460280307203_item	2420570	et	3	main
ja	doc_460280307203_item	2420571	et	3	main
tarakan	doc_460280307203_item	2420572	et	3	main
raid	doc_460280307203_item	2420578	et	4	main
lahendab	doc_460280307203_item	2420580	et	3	main
probleemed	doc_460280307203_item	2420582	et	4	main
mitte	doc_460280307203_item	2420584	et	3	main
tappa	doc_460280307203_item	2420587	et	4	main
tarakane	doc_460280307203_item	2420588	et	3	main
nii	doc_460280307203_item	2420589	et	3	main
efektiivselt	doc_460280307203_item	2420590	et	4	main
nagu	doc_460280307203_item	2420591	et	3	main
seda	doc_460280307203_item	2420592	et	3	main
seda	doc_460280307203_item	2420621	et	3	main
küsitluse	doc_460280307204_item	2420624	et	4	main
oli	doc_460280307204_item	2420626	et	3	main
millega	doc_460280307204_item	2420627	et	3	main
meldib	doc_460280307204_item	2420628	et	4	main
tegeleda	doc_460280307204_item	2420629	et	3	main
4	doc_460280307204_item	2420635	et	2	main
2	doc_460280307204_item	2420637	et	2	main
ja	doc_460280307204_item	2420639	et	3	main
küsitlesin	doc_460280307204_item	2420642	et	3	main
neid	doc_460280307204_item	2420644	et	4	main
sest	doc_460280307204_item	2420645	et	4	main
populaarsem	doc_460280307204_item	2420654	et	4	main
päevast	doc_460280307204_item	2420670	et	4	main
sõltub	doc_460280307204_item	2420674	et	3	main
võimalustest	doc_460280307204_item	2420677	et	3	main
on	doc_460280307204_item	2420679	et	4	main
sobivam	doc_460280307204_item	2420681	et	4	main
aeg	doc_460280307204_item	2420682	et	3	main
reisimise	doc_460280307204_item	2420683	et	4	main
on	doc_460280307204_item	2420687	et	4	main
õues	doc_460280307204_item	2420691	et	4	main
hea	doc_460280307204_item	2420693	et	4	main
soe	doc_460280307204_item	2420694	et	4	main
ja	doc_460280307204_item	2420695	et	3	main
või	doc_460280307204_item	2420702	et	4	main
on	doc_460280307204_item	2420705	et	4	main
inimesed	doc_460280307204_item	2420709	et	3	main
arvates	doc_460280307201_item	2420309	et	4	main
lugeda	doc_460280307201_item	2420313	et	3	main
lastele	doc_460280307201_item	2420315	et	4	main
mida	doc_460280307202_item	2420327	et	4	main
plaanin	doc_460280307202_item	2420328	et	3	main
koolivaheajal	doc_460280307202_item	2420329	et	3	main
teha	doc_460280307202_item	2420330	et	3	main
hea	doc_460280307202_item	2420331	et	4	main
jaoks	doc_460280307202_item	2420345	et	4	main
saan	doc_460280307202_item	2420360	et	4	main
sõpru	doc_460280307202_item	2420365	et	3	main
sugulastest	doc_460280307202_item	2420386	et	4	main
elab	doc_460280307202_item	2420387	et	3	main
venemaal	doc_460280307202_item	2420388	et	4	main
kõige	doc_460280307202_item	2420400	et	4	main
mul	doc_460280307202_item	2420406	et	3	main
soov	doc_460280307202_item	2420409	et	3	main
ma	doc_460280307202_item	2420422	et	3	main
eestis	doc_460280307202_item	2420424	et	3	main
17	doc_460280307202_item	2420426	et	2	main
saartel	doc_460280307202_item	2420433	et	3	main
aga	doc_460280307202_item	2420434	et	3	main
huvitavaid	doc_460280307202_item	2420446	et	4	main
on	doc_460280307202_item	2420469	et	4	main
nende	doc_460280307202_item	2420473	et	4	main
kommetest	doc_460280307202_item	2420476	et	4	main
kõige	doc_460280307202_item	2420486	et	4	main
kui	doc_460280307202_item	2420489	et	3	main
võõrkeelt	doc_460280307202_item	2420491	et	4	main
ma	doc_460280307202_item	2420492	et	3	main
hakkan	doc_460280307202_item	2420493	et	3	main
elada	doc_460280307202_item	2420494	et	3	main
aga	doc_460280307202_item	2420501	et	3	main
tahaksin	doc_460280307202_item	2420508	et	3	main
leida	doc_460280307202_item	2420510	et	3	main
eesti	doc_460280307202_item	2420512	et	4	main
loetelu	doc_460280307202_item	2420521	et	4	main
seepärast	doc_460280307202_item	2420523	et	3	main
on	doc_460280307202_item	2420524	et	4	main
nii	doc_460280307202_item	2420531	et	3	main
raamatut	doc_460280307202_item	2420543	et	3	main
arvamus	doc_460280307203_item	2420547	et	3	main
reklaami	doc_460280307203_item	2420558	et	4	main
tema	doc_460280307203_item	2420559	et	4	main
pildidl	doc_460280307203_item	2420567	et	4	main
olid	doc_460280307203_item	2420568	et	4	main
super	doc_460280307203_item	2420579	et	3	main
miski	doc_460280307203_item	2420585	et	4	main
globaalsest	doc_460280307201_item	2420322	et	3	main
essee	doc_460280307202_item	2420324	et	4	main
viis	doc_460280307202_item	2420325	et	4	main
kooliajal	doc_460280307202_item	2420333	et	3	main
olin	doc_460280307202_item	2420334	et	3	main
ma	doc_460280307202_item	2420335	et	3	main
väga	doc_460280307202_item	2420336	et	3	main
puhata	doc_460280307202_item	2420342	et	4	main
palju	doc_460280307202_item	2420348	et	4	main
liivarannal	doc_460280307202_item	2420351	et	3	main
meres	doc_460280307202_item	2420353	et	3	main
koguda	doc_460280307202_item	2420363	et	3	main
vanu	doc_460280307202_item	2420367	et	4	main
tuttavaid	doc_460280307202_item	2420368	et	3	main
külastamine	doc_460280307202_item	2420369	et	4	main
kooliajal	doc_460280307202_item	2420370	et	3	main
ei	doc_460280307202_item	2420371	et	4	main
ole	doc_460280307202_item	2420372	et	4	main
aega	doc_460280307202_item	2420373	et	4	main
küllalt	doc_460280307202_item	2420374	et	4	main
et	doc_460280307202_item	2420375	et	3	main
kohtuda	doc_460280307202_item	2420376	et	3	main
oma	doc_460280307202_item	2420377	et	4	main
sugulaste	doc_460280307202_item	2420378	et	4	main
sõprade	doc_460280307202_item	2420379	et	3	main
ja	doc_460280307202_item	2420380	et	3	main
tuttavatega	doc_460280307202_item	2420381	et	3	main
tihti	doc_460280307202_item	2420382	et	3	main
ja	doc_460280307202_item	2420392	et	3	main
tuttavad	doc_460280307202_item	2420393	et	4	main
või	doc_460280307202_item	2420395	et	4	main
töötavad	doc_460280307202_item	2420396	et	4	main
seepärast	doc_460280307202_item	2420397	et	3	main
suvevaheaeg	doc_460280307202_item	2420398	et	3	main
on	doc_460280307202_item	2420399	et	4	main
suur	doc_460280307202_item	2420408	et	3	main
eesti	doc_460280307202_item	2420432	et	4	main
suurem	doc_460280307202_item	2420439	et	4	main
mõtlen	doc_460280307202_item	2420440	et	3	main
et	doc_460280307202_item	2420441	et	3	main
seal	doc_460280307202_item	2420442	et	4	main
on	doc_460280307202_item	2420443	et	4	main
mind	doc_460280307202_item	2420468	et	4	main
huvitaks	doc_460280307202_item	2420470	et	4	main
oma	doc_460280307202_item	2420477	et	4	main
praktiseerimine	doc_460280307202_item	2420479	et	4	main
on	doc_460280307202_item	2420481	et	4	main
suhtlemine	doc_460280307202_item	2420484	et	4	main
eestiperes	doc_460280307202_item	2420495	et	3	main
loodan	doc_460280307202_item	2420502	et	3	main
et	doc_460280307202_item	2420503	et	3	main
mind	doc_460280307202_item	2420507	et	4	main
uusi	doc_460280307202_item	2420511	et	3	main
õpetaja	doc_460280307202_item	2420516	et	4	main
meile	doc_460280307202_item	2420518	et	4	main
suurt	doc_460280307202_item	2420519	et	3	main
raamatute	doc_460280307202_item	2420520	et	3	main
aga	doc_460280307202_item	2420528	et	3	main
kooliajast	doc_460280307202_item	2420529	et	4	main
on	doc_460280307202_item	2420530	et	4	main
üht	doc_460280307202_item	2420542	et	3	main
ajalehte	doc_460280307203_item	2420552	et	4	main
linn	doc_460280307203_item	2420553	et	3	main
ja	doc_460280307203_item	2420554	et	3	main
leidsin	doc_460280307203_item	2420555	et	3	main
seal	doc_460280307203_item	2420556	et	4	main
naljaka	doc_460280307203_item	2420557	et	3	main
kellega	doc_460280307203_item	2420562	et	3	main
oma	doc_460280307203_item	2420565	et	4	main
järgmine	doc_460280307203_item	2420576	et	3	main
teie	doc_460280307203_item	2420581	et	4	main
ei	doc_460280307203_item	2420586	et	4	main
essee	doc_460280307204_item	2420623	et	4	main
teema	doc_460280307204_item	2420625	et	4	main
inimest	doc_460280307204_item	2420636	et	3	main
poissi	doc_460280307204_item	2420638	et	4	main
2	doc_460280307204_item	2420640	et	2	main
tüdrukut	doc_460280307204_item	2420641	et	3	main
just	doc_460280307204_item	2420643	et	3	main
minu	doc_460280307204_item	2420648	et	3	main
arvates	doc_460280307204_item	2420652	et	4	main
kahe	doc_460280307204_item	2420671	et	3	main
jaoks	doc_460280307204_item	2420684	et	4	main
sest	doc_460280307204_item	2420685	et	4	main
on	doc_460280307204_item	2420692	et	4	main
kallid	doc_460280307204_item	2420706	et	3	main
lähedased	doc_460280307204_item	2420708	et	3	main
aga	doc_460280307204_item	2420710	et	3	main
mõtlen	doc_460280307204_item	2420719	et	3	main
aastat	doc_460280307202_item	2420427	et	3	main
iialgi	doc_460280307202_item	2420429	et	4	main
neist	doc_460280307202_item	2420437	et	4	main
vaatamiseks	doc_460280307202_item	2420444	et	4	main
kohti	doc_460280307202_item	2420447	et	4	main
meie	doc_460280307202_item	2420455	et	4	main
lähedane	doc_460280307202_item	2420456	et	3	main
naaber	doc_460280307202_item	2420457	et	3	main
rootsi	doc_460280307202_item	2420458	et	4	main
meelitab	doc_460280307202_item	2420459	et	3	main
keskaegse	doc_460280307202_item	2420460	et	3	main
arhitektuuri	doc_460280307202_item	2420461	et	4	main
sillutataud	doc_460280307202_item	2420462	et	4	main
tänavate	doc_460280307202_item	2420463	et	4	main
ja	doc_460280307202_item	2420464	et	3	main
huvitavate	doc_460280307202_item	2420465	et	4	main
kultuurist	doc_460280307202_item	2420474	et	3	main
ja	doc_460280307202_item	2420475	et	3	main
teada	doc_460280307202_item	2420482	et	3	main
on	doc_460280307202_item	2420485	et	4	main
praktika	doc_460280307202_item	2420488	et	4	main
õpid	doc_460280307202_item	2420490	et	4	main
mul	doc_460280307202_item	2420497	et	3	main
hirm	doc_460280307202_item	2420500	et	3	main
see	doc_460280307202_item	2420504	et	3	main
aitab	doc_460280307202_item	2420506	et	3	main
vaja	doc_460280307202_item	2420525	et	4	main
palju	doc_460280307202_item	2420532	et	4	main
raamatuid	doc_460280307202_item	2420533	et	3	main
loetud	doc_460280307202_item	2420534	et	4	main
ja	doc_460280307202_item	2420535	et	3	main
arvan	doc_460280307202_item	2420536	et	3	main
et	doc_460280307202_item	2420537	et	3	main
loen	doc_460280307202_item	2420539	et	3	main
ja	doc_460280307202_item	2420545	et	3	main
pealkiri	doc_460280307203_item	2420560	et	3	main
pildi	doc_460280307203_item	2420573	et	4	main
all	doc_460280307203_item	2420574	et	3	main
oli	doc_460280307203_item	2420575	et	3	main
tarakanidega	doc_460280307203_item	2420583	et	3	main
teed	doc_460280307203_item	2420593	et	4	main
raid	doc_460280307203_item	2420594	et	4	main
super	doc_460280307203_item	2420595	et	3	main
mulle	doc_460280307203_item	2420596	et	4	main
tundus	doc_460280307203_item	2420597	et	3	main
seda	doc_460280307203_item	2420598	et	3	main
reklaami	doc_460280307203_item	2420599	et	4	main
huvitav	doc_460280307203_item	2420600	et	4	main
sest	doc_460280307203_item	2420601	et	4	main
autorid	doc_460280307203_item	2420602	et	3	main
lahendasid	doc_460280307203_item	2420603	et	4	main
tõsist	doc_460280307203_item	2420605	et	4	main
probleemi	doc_460280307203_item	2420606	et	4	main
huumoriga	doc_460280307203_item	2420607	et	3	main
seda	doc_460280307203_item	2420604	et	3	main
õnneks	doc_460280307203_item	2420608	et	4	main
minu	doc_460280307203_item	2420609	et	3	main
kodus	doc_460280307203_item	2420610	et	4	main
ei	doc_460280307203_item	2420611	et	4	main
ole	doc_460280307203_item	2420612	et	4	main
tarakane	doc_460280307203_item	2420613	et	3	main
aga	doc_460280307203_item	2420614	et	3	main
kui	doc_460280307203_item	2420615	et	3	main
nad	doc_460280307203_item	2420616	et	3	main
oleksid	doc_460280307203_item	2420617	et	4	main
mina	doc_460280307203_item	2420618	et	4	main
kindlasti	doc_460280307203_item	2420619	et	3	main
kasutaksin	doc_460280307203_item	2420620	et	3	main
vahendit	doc_460280307203_item	2420622	et	3	main
meie	doc_460280307204_item	2420630	et	4	main
on	doc_460280307204_item	2420647	et	4	main
sõbrad	doc_460280307204_item	2420650	et	3	main
see	doc_460280307204_item	2420673	et	3	main
ja	doc_460280307204_item	2420676	et	3	main
suvel	doc_460280307204_item	2420686	et	3	main
ja	doc_460280307204_item	2420690	et	3	main
vanematega	doc_460280307204_item	2420703	et	4	main
sõpradega	doc_460280307204_item	2420712	et	3	main
aega	doc_460280307204_item	2420716	et	4	main
annab	doc_460280307204_item	2420722	et	3	main
nad	doc_460280307204_item	2420646	et	3	main
tegevusala	doc_460280307204_item	2420655	et	4	main
on	doc_460280307204_item	2420656	et	4	main
reisimine	doc_460280307204_item	2420657	et	4	main
eesti	doc_460280307204_item	2420658	et	4	main
ja	doc_460280307204_item	2420659	et	3	main
välismaad	doc_460280307204_item	2420660	et	4	main
on	doc_460280307204_item	2420661	et	4	main
kõige	doc_460280307204_item	2420662	et	4	main
paremad	doc_460280307204_item	2420663	et	4	main
kohad	doc_460280307204_item	2420664	et	4	main
reisimise	doc_460280307204_item	2420665	et	4	main
reisimine	doc_460280307204_item	2420667	et	4	main
kestab	doc_460280307204_item	2420668	et	4	main
jaoks	doc_460280307204_item	2420666	et	4	main
ühest	doc_460280307204_item	2420669	et	4	main
vaheaeg	doc_460280307204_item	2420689	et	3	main
päikesepaisteline	doc_460280307204_item	2420696	et	4	main
tavaliselt	doc_460280307204_item	2420698	et	4	main
vanemad	doc_460280307204_item	2420704	et	4	main
koos	doc_460280307204_item	2420711	et	4	main
on	doc_460280307204_item	2420713	et	4	main
võimalik	doc_460280307204_item	2420714	et	3	main
veeta	doc_460280307204_item	2420715	et	4	main
et	doc_460280307204_item	2420720	et	3	main
reisimine	doc_460280307204_item	2420721	et	4	main
uusi	doc_460280307204_item	2420723	et	3	main
palju	doc_460280307204_item	2420726	et	4	main
muljeid	doc_460280307204_item	2420727	et	3	main
emotsiooneid	doc_460280307204_item	2420730	et	4	main
pakkub	doc_460280307205_item	2420740	et	4	main
uusi	doc_460280307205_item	2420741	et	3	main
elamusi	doc_460280307205_item	2420742	et	3	main
väitega	doc_460280307205_item	2420750	et	3	main
inimesed	doc_460280307205_item	2420755	et	3	main
leida	doc_460280307205_item	2420757	et	3	main
lisaks	doc_460280307205_item	2420761	et	4	main
olema	doc_460280307205_item	2420763	et	4	main
võimalus	doc_460280307205_item	2420764	et	3	main
kasutada	doc_460280307205_item	2420765	et	3	main
näiteks	doc_460280307205_item	2420768	et	4	main
ilusaloong	doc_460280307205_item	2420771	et	4	main
cd-	doc_460280307205_item	2420773	et	4	main
oleks	doc_460280307205_item	2420777	et	3	main
vanemad	doc_460280307205_item	2420780	et	4	main
ja	doc_460280307205_item	2420787	et	3	main
lõpuks	doc_460280307205_item	2420790	et	4	main
see	doc_460280307205_item	2420798	et	3	main
kaupu	doc_460280307205_item	2420803	et	3	main
ainult	doc_460280307205_item	2420809	et	4	main
kõik	doc_460280307205_item	2420811	et	4	main
saavad	doc_460280307205_item	2420813	et	4	main
miski	doc_460280307205_item	2420814	et	4	main
hakkab	doc_460280307205_item	2420820	et	3	main
kasvama	doc_460280307205_item	2420821	et	3	main
alkoholi	doc_460280307206_item	2420826	et	4	main
on	doc_460280307206_item	2420828	et	4	main
et	doc_460280307206_item	2420837	et	3	main
noored	doc_460280307206_item	2420847	et	3	main
vanem	doc_460280307206_item	2420859	et	4	main
loendab	doc_460280307206_item	2420875	et	3	main
ise	doc_460280307206_item	2420876	et	4	main
ja	doc_460280307206_item	2420878	et	3	main
niisugused	doc_460280307206_item	2420882	et	3	main
et	doc_460280307206_item	2420922	et	3	main
on	doc_460280307206_item	2420924	et	4	main
alkoholi	doc_460280307206_item	2420929	et	4	main
tarbimine	doc_460280307206_item	2420930	et	4	main
on	doc_460280307206_item	2420931	et	4	main
noorte	doc_460280307206_item	2420932	et	3	main
see	doc_460280307206_item	2420942	et	3	main
ja	doc_460280307206_item	2420945	et	3	main
essee	doc_460280307207_item	2420948	et	4	main
nii	doc_460280307207_item	2420956	et	3	main
seda	doc_460280307207_item	2420959	et	3	main
muretut	doc_460280307207_item	2420962	et	4	main
toila-orus	doc_460280307207_item	2420973	et	3	main
suve	doc_460280307207_item	2420983	et	4	main
sain	doc_460280307207_item	2421027	et	3	main
uusi	doc_460280307207_item	2421028	et	3	main
näiteks	doc_460280307207_item	2421031	et	4	main
sain	doc_460280307207_item	2421032	et	3	main
sõida	doc_460280307207_item	2421036	et	4	main
ujuda	doc_460280307207_item	2421039	et	3	main
liisaks	doc_460280307207_item	2421041	et	4	main
sain	doc_460280307207_item	2421042	et	3	main
teada	doc_460280307207_item	2421043	et	3	main
kuidas	doc_460280307207_item	2421044	et	3	main
õigesti	doc_460280307207_item	2421045	et	3	main
et	doc_460280307207_item	2421048	et	3	main
vajalikku	doc_460280307207_item	2421050	et	4	main
võõras	doc_460280307207_item	2421052	et	4	main
suvel	doc_460280307207_item	2421060	et	3	main
eksameid	doc_460280307207_item	2421081	et	3	main
poolt	doc_460280307207_item	2421084	et	4	main
olla	doc_460280307207_item	2421086	et	3	main
ja	doc_460280307207_item	2421088	et	3	main
õppida	doc_460280307207_item	2421111	et	3	main
lõbusalt	doc_460280307204_item	2420717	et	4	main
ma	doc_460280307204_item	2420718	et	3	main
sa	doc_460280307204_item	2420731	et	3	main
võid	doc_460280307204_item	2420732	et	4	main
ja	doc_460280307205_item	2420743	et	3	main
on	doc_460280307205_item	2420744	et	4	main
sest	doc_460280307205_item	2420753	et	4	main
teisi	doc_460280307205_item	2420766	et	4	main
videolaenamine	doc_460280307205_item	2420775	et	3	main
jäta	doc_460280307205_item	2420782	et	4	main
mänguasjade	doc_460280307205_item	2420785	et	3	main
keskele	doc_460280307205_item	2420786	et	3	main
peab	doc_460280307205_item	2420792	et	4	main
sissetulekuga	doc_460280307205_item	2420796	et	3	main
saadaval	doc_460280307205_item	2420805	et	4	main
kaubakeskuse	doc_460280307205_item	2420818	et	3	main
populaarsus	doc_460280307205_item	2420819	et	4	main
tutvusi	doc_460280307204_item	2420725	et	3	main
ja	doc_460280307204_item	2420728	et	3	main
teadmisi	doc_460280307204_item	2420724	et	4	main
praktiseerida	doc_460280307204_item	2420733	et	3	main
oma	doc_460280307204_item	2420734	et	4	main
ka	doc_460280307204_item	2420736	et	3	main
arvamus	doc_460280307205_item	2420737	et	3	main
iga	doc_460280307205_item	2420738	et	4	main
romaantika	doc_460280307205_item	2420746	et	4	main
ma	doc_460280307205_item	2420747	et	3	main
osaliselt	doc_460280307205_item	2420751	et	4	main
endale	doc_460280307205_item	2420758	et	4	main
soobivat	doc_460280307205_item	2420760	et	4	main
peab	doc_460280307205_item	2420762	et	4	main
apteek	doc_460280307205_item	2420769	et	3	main
see	doc_460280307205_item	2420776	et	3	main
last	doc_460280307205_item	2420783	et	4	main
istuda	doc_460280307205_item	2420788	et	3	main
kaubakeskus	doc_460280307205_item	2420791	et	3	main
on	doc_460280307205_item	2420799	et	4	main
siis	doc_460280307205_item	2420810	et	3	main
ja	doc_460280307205_item	2420817	et	3	main
arvamus	doc_460280307206_item	2420822	et	3	main
alkoholi	doc_460280307206_item	2420840	et	4	main
inimesed	doc_460280307206_item	2420848	et	3	main
alaealised	doc_460280307206_item	2420850	et	4	main
ja	doc_460280307206_item	2420852	et	3	main
olla	doc_460280307206_item	2420858	et	3	main
ole	doc_460280307206_item	2420862	et	4	main
rikub	doc_460280307206_item	2420871	et	3	main
seadust	doc_460280307206_item	2420872	et	4	main
kes	doc_460280307206_item	2420884	et	4	main
lõbusam	doc_460280307206_item	2420925	et	4	main
kahjuks	doc_460280307206_item	2420926	et	4	main
hulgas	doc_460280307206_item	2420933	et	4	main
mõtle	doc_460280307206_item	2420940	et	4	main
ja	doc_460280307207_item	2420961	et	3	main
pärnus	doc_460280307207_item	2420970	et	3	main
narva-jõesuus	doc_460280307207_item	2420971	et	3	main
ja	doc_460280307207_item	2420972	et	3	main
ja	doc_460280307207_item	2420977	et	3	main
mõtlen	doc_460280307207_item	2420980	et	3	main
kõigepealt	doc_460280307207_item	2420987	et	3	main
oma	doc_460280307207_item	2420990	et	4	main
pärnus	doc_460280307207_item	2420994	et	3	main
mul	doc_460280307207_item	2420995	et	3	main
oli	doc_460280307207_item	2420996	et	3	main
võimalus	doc_460280307207_item	2420997	et	3	main
eesti	doc_460280307207_item	2421000	et	4	main
reisi	doc_460280307207_item	2421022	et	4	main
thailandisse	doc_460280307207_item	2421024	et	4	main
suvepuhkuse	doc_460280307207_item	2421025	et	3	main
juhtida	doc_460280307207_item	2421034	et	4	main
kaarte	doc_460280307207_item	2421047	et	4	main
leida	doc_460280307207_item	2421049	et	3	main
eest	doc_460280307207_item	2421058	et	4	main
juba	doc_460280307207_item	2421059	et	3	main
püüdlik	doc_460280307207_item	2421089	et	3	main
vaja	doc_460280307207_item	2421102	et	4	main
ev	doc_462410643036_item	2421118	et	4	main
mida	doc_462410643036_item	2421125	et	4	main
kui	doc_462410643036_item	2421127	et	3	main
sulast	doc_462410643036_item	2421133	et	4	main
1	doc_462410643036_item	2421134	et	2	main
võimalus	doc_462410643036_item	2421141	et	3	main
vabadus	doc_462410643036_item	2421148	et	4	main
aja	doc_462410643036_item	2421171	et	4	main
partei	doc_462410643036_item	2421176	et	4	main
kätte	doc_462410643036_item	2421178	et	4	main
votsialistlik	doc_462410643036_item	2421180	et	4	main
majandus	doc_462410643036_item	2421182	et	4	main
eraomandiõigus	doc_462410643036_item	2421189	et	4	main
maa	doc_462410643036_item	2421190	et	4	main
prioriteediks	doc_462410643036_item	2421200	et	3	main
tutvused	doc_462410643036_item	2421203	et	3	main
toit	doc_462410643036_item	2421206	et	3	main
ning	doc_462410643036_item	2421207	et	3	main
hüved	doc_462410643036_item	2421208	et	3	main
olid	doc_462410643036_item	2421209	et	4	main
defitsiitsed	doc_462410643036_item	2421210	et	3	main
läbi	doc_462410643036_item	2421214	et	4	main
tutvuste	doc_462410643036_item	2421215	et	3	main
riigi	doc_462410643036_item	2421232	et	3	main
oli	doc_462410643036_item	2421242	et	3	main
positiivseid	doc_460280307204_item	2420729	et	3	main
võõrkeeleoskust	doc_460280307204_item	2420735	et	3	main
oma-moodi	doc_460280307205_item	2420745	et	4	main
nõus	doc_460280307205_item	2420752	et	4	main
mõned	doc_460280307205_item	2420754	et	3	main
võiks	doc_460280307205_item	2420756	et	4	main
mugav	doc_460280307205_item	2420778	et	3	main
võiks	doc_460280307205_item	2420781	et	4	main
kohvikus	doc_460280307205_item	2420789	et	3	main
mõeldud	doc_460280307205_item	2420794	et	4	main
tähtis	doc_460280307205_item	2420800	et	4	main
sarnaseid	doc_460280307205_item	2420802	et	4	main
inimesed	doc_460280307205_item	2420812	et	3	main
osta	doc_460280307205_item	2420815	et	4	main
suitsetamine	doc_460280307206_item	2420824	et	4	main
tarbimine	doc_460280307206_item	2420827	et	4	main
teie	doc_460280307206_item	2420829	et	4	main
arvates	doc_460280307206_item	2420830	et	4	main
noorte	doc_460280307206_item	2420831	et	3	main
mõtlen	doc_460280307206_item	2420836	et	3	main
suitsetamine	doc_460280307206_item	2420838	et	4	main
ja	doc_460280307206_item	2420839	et	3	main
tarbimine	doc_460280307206_item	2420841	et	4	main
on	doc_460280307206_item	2420842	et	4	main
noorte	doc_460280307206_item	2420843	et	3	main
suitsuvad	doc_460280307206_item	2420851	et	4	main
joovad	doc_460280307206_item	2420853	et	4	main
sest	doc_460280307206_item	2420855	et	4	main
nad	doc_460280307206_item	2420856	et	3	main
tahavad	doc_460280307206_item	2420857	et	3	main
ei	doc_460280307206_item	2420861	et	4	main
lubanud	doc_460280307206_item	2420863	et	4	main
suitsutada	doc_460280307206_item	2420864	et	3	main
või	doc_460280307206_item	2420865	et	4	main
juua	doc_460280307206_item	2420866	et	3	main
kui	doc_460280307206_item	2420869	et	3	main
siis	doc_460280307206_item	2420873	et	3	main
äkilisena	doc_460280307206_item	2420877	et	3	main
suitsetamine	doc_460280307206_item	2420927	et	4	main
on	doc_460280307206_item	2420943	et	4	main
lõppenud	doc_460280307207_item	2420953	et	4	main
on	doc_460280307207_item	2420955	et	4	main
narvas	doc_460280307207_item	2420968	et	4	main
et	doc_460280307207_item	2420981	et	3	main
ja	doc_460280307207_item	2420985	et	3	main
parendada	doc_460280307207_item	2420989	et	3	main
võõrkeeleoskust	doc_460280307207_item	2420991	et	3	main
toilo-orus	doc_460280307207_item	2420992	et	3	main
ja	doc_460280307207_item	2420993	et	3	main
ajal	doc_460280307207_item	2421026	et	4	main
ka	doc_460280307207_item	2421030	et	3	main
autot	doc_460280307207_item	2421035	et	3	main
allveemaskega	doc_460280307207_item	2421040	et	4	main
omalt	doc_460280307207_item	2421083	et	4	main
püüan	doc_460280307207_item	2421085	et	3	main
kannatlik	doc_460280307207_item	2421087	et	3	main
kokkuvõtteks	doc_460280307207_item	2421090	et	3	main
suvi	doc_460280307207_item	2421095	et	3	main
hästi	doc_460280307207_item	2421098	et	3	main
on	doc_460280307207_item	2421101	et	4	main
välja	doc_462410643036_item	2421115	et	4	main
peamised	doc_462410643036_item	2421116	et	3	main
erinevused	doc_462410643036_item	2421117	et	4	main
ja	doc_460280307205_item	2420774	et	3	main
kui	doc_460280307205_item	2420779	et	3	main
mängunurka	doc_460280307205_item	2420784	et	4	main
olema	doc_460280307205_item	2420793	et	4	main
erineva	doc_460280307205_item	2420795	et	4	main
inimestele	doc_460280307205_item	2420797	et	3	main
et	doc_460280307205_item	2420801	et	3	main
oleks	doc_460280307205_item	2420804	et	3	main
väga	doc_460280307205_item	2420806	et	3	main
erinevate	doc_460280307205_item	2420807	et	4	main
hindadega	doc_460280307205_item	2420808	et	3	main
sealt	doc_460280307205_item	2420816	et	4	main
kas	doc_460280307206_item	2420823	et	3	main
eriti	doc_460280307206_item	2420849	et	3	main
alkoholi	doc_460280307206_item	2420854	et	4	main
alkoholi	doc_460280307206_item	2420867	et	4	main
aga	doc_460280307206_item	2420868	et	3	main
noormees	doc_460280307206_item	2420870	et	4	main
täisealisena	doc_460280307206_item	2420879	et	4	main
veel	doc_460280307206_item	2420880	et	4	main
mõtlevad	doc_460280307206_item	2420921	et	4	main
nii	doc_460280307206_item	2420923	et	3	main
mõned	doc_460280307206_item	2420936	et	3	main
noored	doc_460280307206_item	2420937	et	3	main
et	doc_460280307206_item	2420941	et	3	main
ebakasulik	doc_460280307206_item	2420944	et	3	main
rikub	doc_460280307206_item	2420946	et	3	main
aga	doc_460280307207_item	2420954	et	3	main
meeldiv	doc_460280307207_item	2420957	et	4	main
lõbusat	doc_460280307207_item	2420960	et	3	main
tallinnas	doc_460280307207_item	2420969	et	4	main
oma	doc_460280307207_item	2420975	et	4	main
perega	doc_460280307207_item	2420978	et	3	main
veetsin	doc_460280307207_item	2420982	et	3	main
huvitavalt	doc_460280307207_item	2420984	et	4	main
tunnetuslikult	doc_460280307207_item	2420986	et	4	main
püüdsin	doc_460280307207_item	2420988	et	3	main
suhelda	doc_460280307207_item	2420998	et	4	main
ja	doc_460280307206_item	2420825	et	3	main
hulgas	doc_460280307206_item	2420832	et	4	main
populaarsed	doc_460280307206_item	2420833	et	3	main
põhjendage	doc_460280307206_item	2420834	et	3	main
ma	doc_460280307206_item	2420835	et	3	main
hulgas	doc_460280307206_item	2420844	et	4	main
populaarsed	doc_460280307206_item	2420845	et	3	main
mõned	doc_460280307206_item	2420846	et	3	main
nad	doc_460280307206_item	2420860	et	3	main
ta	doc_460280307206_item	2420874	et	4	main
on	doc_460280307206_item	2420881	et	4	main
noored	doc_460280307206_item	2420883	et	3	main
ei	doc_460280307206_item	2420886	et	4	main
ise	doc_460280307206_item	2420885	et	4	main
taha	doc_460280307206_item	2420887	et	4	main
juua	doc_460280307206_item	2420888	et	3	main
või	doc_460280307206_item	2420889	et	4	main
suitsutada	doc_460280307206_item	2420890	et	3	main
aga	doc_460280307206_item	2420891	et	3	main
nad	doc_460280307206_item	2420892	et	3	main
seda	doc_460280307206_item	2420894	et	3	main
seda	doc_460280307206_item	2420895	et	3	main
tevad	doc_460280307206_item	2420893	et	4	main
võib	doc_460280307206_item	2420896	et	3	main
olla	doc_460280307206_item	2420897	et	3	main
kui	doc_460280307206_item	2420898	et	3	main
on	doc_460280307206_item	2420900	et	4	main
alaealisel	doc_460280307206_item	2420899	et	4	main
vanad	doc_460280307206_item	2420901	et	3	main
sõbrad	doc_460280307206_item	2420902	et	3	main
ja	doc_460280307206_item	2420903	et	3	main
ta	doc_460280307206_item	2420904	et	4	main
ei	doc_460280307206_item	2420905	et	4	main
tahab	doc_460280307206_item	2420906	et	3	main
nende	doc_460280307206_item	2420907	et	4	main
sarnaseks	doc_460280307206_item	2420908	et	4	main
olla	doc_460280307206_item	2420909	et	3	main
lisaks	doc_460280307206_item	2420910	et	4	main
mõned	doc_460280307206_item	2420911	et	3	main
noored	doc_460280307206_item	2420912	et	3	main
ei	doc_460280307206_item	2420913	et	4	main
saa	doc_460280307206_item	2420914	et	4	main
märkida	doc_460280307206_item	2420915	et	4	main
tähtpäevi	doc_460280307206_item	2420916	et	4	main
ilma	doc_460280307206_item	2420917	et	4	main
alkoholita	doc_460280307206_item	2420918	et	3	main
sest	doc_460280307206_item	2420919	et	4	main
nad	doc_460280307206_item	2420920	et	3	main
ja	doc_460280307206_item	2420928	et	3	main
küllalt	doc_460280307206_item	2420934	et	4	main
populaarsed	doc_460280307206_item	2420935	et	3	main
lihtsalt	doc_460280307206_item	2420938	et	4	main
ei	doc_460280307206_item	2420939	et	4	main
tervist	doc_460280307206_item	2420947	et	4	main
meenutame	doc_460280307207_item	2420949	et	3	main
suve	doc_460280307207_item	2420950	et	4	main
suvevaheaeg	doc_460280307207_item	2420951	et	3	main
on	doc_460280307207_item	2420952	et	4	main
meenutada	doc_460280307207_item	2420958	et	3	main
aega	doc_460280307207_item	2420963	et	4	main
veetsin	doc_460280307207_item	2420964	et	3	main
oma	doc_460280307207_item	2420965	et	4	main
vaheaega	doc_460280307207_item	2420966	et	4	main
eestis	doc_460280307207_item	2420967	et	3	main
puhkasin	doc_460280307207_item	2420974	et	3	main
sõprade	doc_460280307207_item	2420976	et	3	main
ma	doc_460280307207_item	2420979	et	3	main
inimestega	doc_460280307207_item	2420999	et	3	main
keeles	doc_460280307207_item	2421001	et	4	main
aga	doc_460280307207_item	2421002	et	3	main
see	doc_460280307207_item	2421003	et	3	main
oli	doc_460280307207_item	2421004	et	3	main
väga	doc_460280307207_item	2421005	et	3	main
kuna	doc_460280307207_item	2421007	et	3	main
raske	doc_460280307207_item	2421006	et	4	main
huvitavalt	doc_460280307207_item	2421008	et	4	main
veel	doc_460280307207_item	2421009	et	4	main
lugesin	doc_460280307207_item	2421010	et	3	main
inglise	doc_460280307207_item	2421011	et	4	main
keelseid	doc_460280307207_item	2421012	et	3	main
ja	doc_460280307207_item	2421014	et	3	main
ajalehti	doc_460280307207_item	2421013	et	4	main
raamatuid	doc_460280307207_item	2421015	et	3	main
praktiseerisin	doc_460280307207_item	2421016	et	3	main
kõnet	doc_460280307207_item	2421017	et	3	main
inglise	doc_460280307207_item	2421018	et	4	main
keelt	doc_460280307207_item	2421019	et	4	main
ka	doc_460280307207_item	2421020	et	3	main
oma	doc_460280307207_item	2421021	et	4	main
ajal	doc_460280307207_item	2421023	et	4	main
kogemuse	doc_460280307207_item	2421033	et	3	main
veeskutteriga	doc_460280307207_item	2421037	et	3	main
õppeaasta	doc_460280307207_item	2421057	et	4	main
see	doc_460280307207_item	2421061	et	3	main
on	doc_460280307207_item	2421062	et	4	main
meie	doc_460280307207_item	2421063	et	4	main
öelda	doc_460280307207_item	2421092	et	4	main
minu	doc_460280307207_item	2421094	et	3	main
üsna	doc_460280307207_item	2421097	et	3	main
praegu	doc_460280307207_item	2421100	et	3	main
kõike	doc_460280307207_item	2421104	et	4	main
ainult	doc_460280307207_item	2421106	et	4	main
veelkord	doc_460280307207_item	2421110	et	3	main
ja	doc_462410643036_item	2421119	et	3	main
ja	doc_462410643036_item	2421122	et	3	main
esindusorganeid	doc_462410643036_item	2421143	et	3	main
valida	doc_462410643036_item	2421145	et	3	main
sõna	doc_462410643036_item	2421147	et	4	main
hirmu	doc_462410643036_item	2421154	et	4	main
ka	doc_462410643036_item	2421163	et	3	main
puudus	doc_462410643036_item	2421166	et	4	main
kogemusi	doc_460280307207_item	2421029	et	3	main
ja	doc_460280307207_item	2421038	et	3	main
kasutada	doc_460280307207_item	2421046	et	3	main
marsruuti	doc_460280307207_item	2421051	et	4	main
linnas	doc_460280307207_item	2421053	et	4	main
ma	doc_460280307207_item	2421054	et	3	main
mõtlesin	doc_460280307207_item	2421055	et	3	main
uue	doc_460280307207_item	2421056	et	3	main
viimane	doc_460280307207_item	2421064	et	3	main
õppeaasta	doc_460280307207_item	2421065	et	4	main
ja	doc_460280307207_item	2421066	et	3	main
sooviks	doc_460280307207_item	2421067	et	4	main
veeta	doc_460280307207_item	2421068	et	4	main
seda	doc_460280307207_item	2421069	et	3	main
ja	doc_460280307207_item	2421071	et	3	main
rõõmsalt	doc_460280307207_item	2421072	et	4	main
ma	doc_460280307207_item	2421073	et	3	main
tean	doc_460280307207_item	2421074	et	3	main
et	doc_460280307207_item	2421075	et	3	main
edukalt	doc_460280307207_item	2421070	et	4	main
raske	doc_460280307207_item	2421076	et	4	main
töö	doc_460280307207_item	2421077	et	4	main
ootab	doc_460280307207_item	2421078	et	3	main
meid	doc_460280307207_item	2421079	et	4	main
enne	doc_460280307207_item	2421080	et	4	main
siis	doc_460280307207_item	2421082	et	3	main
võiks	doc_460280307207_item	2421091	et	4	main
et	doc_460280307207_item	2421093	et	3	main
möödus	doc_460280307207_item	2421096	et	3	main
aga	doc_460280307207_item	2421099	et	3	main
unustada	doc_460280307207_item	2421103	et	3	main
ja	doc_460280307207_item	2421105	et	3	main
õppida	doc_460280307207_item	2421107	et	3	main
õppida	doc_460280307207_item	2421108	et	3	main
ja	doc_460280307207_item	2421109	et	3	main
kontrolltöö	doc_462410643036_item	2421112	et	4	main
nn	doc_462410643036_item	2421131	et	4	main
hrustshovi	doc_462410643036_item	2421132	et	4	main
rahva	doc_462410643036_item	2421142	et	3	main
ise	doc_462410643036_item	2421144	et	4	main
puudus	doc_462410643036_item	2421146	et	4	main
oli	doc_462410643036_item	2421151	et	3	main
riigi	doc_462410643036_item	2421152	et	3	main
paljusus	doc_462410643036_item	2421159	et	4	main
keelati	doc_462410643036_item	2421162	et	4	main
oma	doc_462410643036_item	2421184	et	4	main
puudus	doc_462410643036_item	2421188	et	4	main
polnud	doc_462410643036_item	2421197	et	3	main
nomenklatuuri	doc_462410643036_item	2421219	et	4	main
elasid	doc_462410643036_item	2421225	et	4	main
võrdsetes	doc_462410643036_item	2421227	et	4	main
tingimustes	doc_462410643036_item	2421228	et	3	main
kuid	doc_462410643036_item	2421229	et	4	main
teelikult	doc_462410643036_item	2421230	et	4	main
põllumajandus	doc_462410643036_item	2421241	et	3	main
kus	doc_462410643036_item	2421249	et	3	main
mida	doc_462410643036_item	2421257	et	4	main
ei	doc_462410643036_item	2421272	et	4	main
arvestatud	doc_462410643036_item	2421273	et	4	main
siinsete	doc_462410643036_item	2421276	et	4	main
endised	doc_462410643036_item	2421335	et	3	main
teadusearendajad	doc_462410643036_item	2421338	et	3	main
nende	doc_462410643036_item	2421340	et	4	main
kohtadele	doc_462410643036_item	2421341	et	3	main
või	doc_462410643036_item	2421346	et	4	main
koguni	doc_462410643036_item	2421347	et	4	main
puhta	doc_462410643036_item	2421353	et	4	main
oli	doc_462410643036_item	2421380	et	3	main
oli	doc_462410643036_item	2421390	et	3	main
kord	doc_462410643036_item	2421404	et	4	main
sõnavabadus	doc_462410643036_item	2421408	et	4	main
vabadus	doc_462410643036_item	2421410	et	4	main
erinevate	doc_462410643036_item	2421411	et	4	main
meediaallikate	doc_462410643036_item	2421412	et	3	main
tsensuur	doc_462410643036_item	2421413	et	3	main
palju	doc_462410643036_item	2421417	et	4	main
kõige	doc_462410643036_item	2421419	et	4	main
1	doc_462410643036_item	2421113	et	2	main
tooge	doc_462410643036_item	2421114	et	3	main
ensv	doc_462410643036_item	2421120	et	4	main
ühiskonnakorralduses	doc_462410643036_item	2421121	et	3	main
2	doc_462410643036_item	2421124	et	2	main
mõeldakse	doc_462410643036_item	2421126	et	3	main
ensv	doc_462410643036_item	2421135	et	4	main
tekkis	doc_462410643036_item	2421136	et	3	main
totalitaarne	doc_462410643036_item	2421137	et	3	main
puudus	doc_462410643036_item	2421140	et	4	main
rahvas	doc_462410643036_item	2421150	et	4	main
kontrolli	doc_462410643036_item	2421153	et	4	main
ning	doc_462410643036_item	2421155	et	3	main
terrori	doc_462410643036_item	2421156	et	3	main
all	doc_462410643036_item	2421157	et	3	main
parteide	doc_462410643036_item	2421158	et	3	main
oli	doc_462410643036_item	2421160	et	3	main
tegevus	doc_462410643036_item	2421165	et	4	main
sõltumatu	doc_462410643036_item	2421167	et	4	main
kohus	doc_462410643036_item	2421168	et	4	main
ning	doc_462410643036_item	2421169	et	3	main
ühe	doc_462410643036_item	2421175	et	4	main
ühiskonnamudel	doc_462410643036_item	2421181	et	3	main
plaanimajandus	doc_462410643036_item	2421186	et	3	main
inimestel	doc_462410643036_item	2421187	et	3	main
väärtust	doc_462410643036_item	2421199	et	4	main
said	doc_462410643036_item	2421201	et	4	main
sidemed	doc_462410643036_item	2421202	et	3	main
kõik	doc_462410643036_item	2421204	et	4	main
majatarbekaubad	doc_462410643036_item	2421205	et	3	main
saadi	doc_462410643036_item	2421212	et	4	main
riigi	doc_462410643036_item	2421218	et	3	main
kommunistlikku	doc_462410643036_item	2421222	et	4	main
parteisse	doc_462410643036_item	2421223	et	3	main
jätkus	doc_462410643036_item	2421231	et	4	main
pakutavaid	doc_462410643036_item	2421234	et	4	main
ära	doc_462410643036_item	2421239	et	4	main
koondunud	doc_462410643036_item	2421243	et	4	main
ning	doc_462410643036_item	2421245	et	3	main
kehtisid	doc_462410643036_item	2421254	et	4	main
tuli	doc_462410643036_item	2421258	et	4	main
saaki	doc_462410643036_item	2421261	et	4	main
tuli	doc_462410643036_item	2421262	et	4	main
ülevalt	doc_462410643036_item	2421267	et	4	main
poolt	doc_462410643036_item	2421268	et	4	main
pädevad	doc_462410643036_item	2421274	et	3	main
vähegi	doc_462410643036_item	2421286	et	4	main
talupojad	doc_462410643036_item	2421289	et	4	main
saadeti	doc_462410643036_item	2421321	et	3	main
küüditamislained	doc_462410643036_item	2421325	et	3	main
ühiskonna	doc_462410643036_item	2421326	et	4	main
oli	doc_462410643036_item	2421328	et	3	main
maha	doc_462410643036_item	2421332	et	4	main
vähe	doc_462410643036_item	2421343	et	3	main
vene-eestlased	doc_462410643036_item	2421345	et	3	main
kehtis	doc_462410643036_item	2421352	et	3	main
mõiste	doc_462410643036_item	2421355	et	4	main
tööle	doc_462410643036_item	2421357	et	3	main
muu	doc_462410643036_item	2421373	et	4	main
teeneka	doc_462410643036_item	2421374	et	3	main
ka	doc_462410643036_item	2421381	et	3	main
eesti	doc_462410643036_item	2421386	et	4	main
vabariigi	doc_462410643036_item	2421387	et	3	main
ühiskonna	doc_462410643036_item	2421388	et	4	main
alustel	doc_462410643036_item	2421392	et	4	main
vabariigis	doc_462410643036_item	2421406	et	3	main
usustunnistuse	doc_462410643036_item	2421409	et	4	main
kõrgem	doc_462410643036_item	2421420	et	4	main
ka	doc_462410643036_item	2421429	et	3	main
seal	doc_462410643036_item	2421430	et	4	main
töörahva	doc_462410643036_item	2421431	et	3	main
koondunud	doc_462410643036_item	2421437	et	4	main
kätte	doc_462410643036_item	2421439	et	4	main
eesti	doc_462410643036_item	2421440	et	4	main
vabariigi	doc_462410643036_item	2421441	et	3	main
keel	doc_462410643036_item	2421446	et	4	main
esimese	doc_462410643036_item	2421447	et	3	main
koondunud	doc_462410643036_item	2421456	et	4	main
autritoorse	doc_462410643036_item	2421457	et	4	main
valitsust	doc_462410643036_item	2421466	et	4	main
oma	doc_462410643036_item	2421480	et	4	main
majanduses	doc_462410643036_item	2421123	et	4	main
ensv	doc_462410643036_item	2421128	et	4	main
kutluuriajaloos	doc_462410643036_item	2421129	et	4	main
kõneldakse	doc_462410643036_item	2421130	et	3	main
reziim	doc_462410643036_item	2421138	et	4	main
rahval	doc_462410643036_item	2421139	et	3	main
kogu	doc_462410643036_item	2421149	et	4	main
keelatud	doc_462410643036_item	2421161	et	4	main
seltside	doc_462410643036_item	2421164	et	3	main
vaba	doc_462410643036_item	2421170	et	4	main
valitses	doc_462410643036_item	2421179	et	3	main
oli	doc_462410643036_item	2421183	et	3	main
iseloomult	doc_462410643036_item	2421185	et	3	main
omandisk	doc_462410643036_item	2421195	et	4	main
tegelikult	doc_462410643036_item	2421198	et	4	main
ainult	doc_462410643036_item	2421213	et	4	main
või	doc_462410643036_item	2421216	et	4	main
liige	doc_462410643036_item	2421220	et	4	main
näilised	doc_462410643036_item	2421224	et	3	main
poolt	doc_462410643036_item	2421233	et	4	main
hüvesid	doc_462410643036_item	2421235	et	3	main
ainult	doc_462410643036_item	2421236	et	4	main
vaevaga	doc_462410643036_item	2421237	et	4	main
kolhooside	doc_462410643036_item	2421244	et	3	main
võrku	doc_462410643036_item	2421248	et	4	main
järgi	doc_462410643036_item	2421252	et	4	main
tööd	doc_462410643036_item	2421253	et	4	main
päevanormid	doc_462410643036_item	2421256	et	3	main
ka	doc_462410643036_item	2421260	et	3	main
külvata	doc_462410643036_item	2421263	et	4	main
ja	doc_462410643036_item	2421264	et	3	main
tulnud	doc_462410643036_item	2421269	et	4	main
käskudele	doc_462410643036_item	2421270	et	3	main
sageli	doc_462410643036_item	2421271	et	3	main
ilmastikku	doc_462410643036_item	2421277	et	4	main
põllumajanduse	doc_462410643036_item	2421279	et	3	main
toodangut	doc_462410643036_item	2421280	et	3	main
vaevu	doc_462410643036_item	2421282	et	4	main
piirides	doc_462410643036_item	2421284	et	3	main
kätte	doc_462410643036_item	2421285	et	4	main
kirjandus	doc_462410643036_item	2421172	et	3	main
võim	doc_462410643036_item	2421173	et	3	main
koondus	doc_462410643036_item	2421174	et	4	main
ladviku	doc_462410643036_item	2421177	et	3	main
natsionaliseeriti	doc_462410643036_item	2421191	et	3	main
ning	doc_462410643036_item	2421192	et	3	main
muudeti	doc_462410643036_item	2421193	et	3	main
riigi	doc_462410643036_item	2421194	et	3	main
rahval	doc_462410643036_item	2421196	et	3	main
neid	doc_462410643036_item	2421211	et	4	main
olles	doc_462410643036_item	2421217	et	3	main
kuuludes	doc_462410643036_item	2421221	et	3	main
inimesed	doc_462410643036_item	2421226	et	3	main
pooleks	doc_462410643036_item	2421238	et	4	main
elamiseks	doc_462410643036_item	2421240	et	4	main
sohvooside	doc_462410643036_item	2421247	et	4	main
nn	doc_462410643036_item	2421255	et	4	main
korjata	doc_462410643036_item	2421265	et	4	main
oludega	doc_462410643036_item	2421278	et	3	main
rikkamad	doc_462410643036_item	2421287	et	4	main
maksudega	doc_462410643036_item	2421291	et	3	main
ja	doc_462410643036_item	2421292	et	3	main
viljanormidega	doc_462410643036_item	2421293	et	3	main
sinna	doc_462410643036_item	2421294	et	3	main
maale	doc_462410643036_item	2421295	et	4	main
et	doc_462410643036_item	2421296	et	3	main
nad	doc_462410643036_item	2421297	et	3	main
olid	doc_462410643036_item	2421298	et	4	main
sunnitud	doc_462410643036_item	2421299	et	4	main
kolhoosidesse	doc_462410643036_item	2421300	et	3	main
astuma	doc_462410643036_item	2421301	et	3	main
samas	doc_462410643036_item	2421302	et	4	main
esialgu	doc_462410643036_item	2421303	et	3	main
stalini	doc_462410643036_item	2421304	et	4	main
ajal	doc_462410643036_item	2421305	et	4	main
ei	doc_462410643036_item	2421306	et	4	main
tahetud	doc_462410643036_item	2421307	et	4	main
ka	doc_462410643036_item	2421308	et	3	main
omal	doc_462410643036_item	2421309	et	3	main
soovil	doc_462410643036_item	2421310	et	3	main
kolhoosi	doc_462410643036_item	2421311	et	4	main
astujaid	doc_462410643036_item	2421312	et	4	main
kes	doc_462410643036_item	2421313	et	4	main
olid	doc_462410643036_item	2421314	et	4	main
nn	doc_462410643036_item	2421315	et	4	main
kulakud	doc_462410643036_item	2421316	et	3	main
neid	doc_462410643036_item	2421317	et	4	main
lihtsalt	doc_462410643036_item	2421318	et	4	main
ja	doc_462410643036_item	2421320	et	3	main
represseriti	doc_462410643036_item	2421319	et	4	main
ka	doc_462410643036_item	2421329	et	3	main
pädevad	doc_462410643036_item	2421344	et	3	main
muust	doc_462410643036_item	2421348	et	4	main
rahvusest	doc_462410643036_item	2421349	et	4	main
uusi	doc_462410643036_item	2421350	et	3	main
ülikooli	doc_462410643036_item	2421356	et	4	main
kooli	doc_462410643036_item	2421358	et	4	main
võtmisel	doc_462410643036_item	2421359	et	4	main
inimese	doc_462410643036_item	2421375	et	4	main
poeg	doc_462410643036_item	2421376	et	3	main
ja	doc_462410643036_item	2421377	et	3	main
järglane	doc_462410643036_item	2421378	et	3	main
usutunnistus	doc_462410643036_item	2421382	et	3	main
hiljem	doc_462410643036_item	2421246	et	3	main
tehti	doc_462410643036_item	2421250	et	3	main
plaani	doc_462410643036_item	2421251	et	4	main
täita	doc_462410643036_item	2421259	et	4	main
vastavalt	doc_462410643036_item	2421266	et	4	main
ülemused	doc_462410643036_item	2421275	et	4	main
saadi	doc_462410643036_item	2421281	et	4	main
miinimumi	doc_462410643036_item	2421283	et	4	main
endised	doc_462410643036_item	2421288	et	3	main
suruti	doc_462410643036_item	2421290	et	3	main
1949	doc_462410643036_item	2421323	et	2	main
korralduses	doc_462410643036_item	2421327	et	4	main
rehva	doc_462410643036_item	2421330	et	4	main
kultuuri	doc_462410643036_item	2421331	et	4	main
surumise	doc_462410643036_item	2421333	et	4	main
tendents	doc_462410643036_item	2421334	et	3	main
kirjanikud	doc_462410643036_item	2421337	et	3	main
oli	doc_462410643036_item	2421384	et	3	main
valitses	doc_462410643036_item	2421407	et	3	main
leebe	doc_462410643036_item	2421415	et	4	main
järgi	doc_462410643036_item	2421427	et	4	main
oli	doc_462410643036_item	2421435	et	3	main
ajal	doc_462410643036_item	2421442	et	4	main
pätsi	doc_462410643036_item	2421459	et	4	main
ning	doc_462410643036_item	2421464	et	3	main
vahemusrahvaste	doc_462410643036_item	2421474	et	4	main
algharidust	doc_462410643036_item	2421482	et	4	main
ning	doc_462410643036_item	2421484	et	3	main
välja	doc_462410643036_item	2421486	et	4	main
majanduses	doc_462410643036_item	2421488	et	4	main
ning	doc_462410643036_item	2421491	et	3	main
kapitalistlikud	doc_462410643036_item	2421492	et	3	main
tootmissuhted	doc_462410643036_item	2421493	et	3	main
paremad	doc_462410643036_item	2421515	et	4	main
tuleviku	doc_462410643036_item	2421516	et	4	main
näiliselt	doc_462410643036_item	2421526	et	4	main
see	doc_462410643036_item	2421529	et	3	main
elada	doc_462410643036_item	2421549	et	3	main
tööd	doc_462410643036_item	2421552	et	4	main
teha	doc_462410643036_item	2421553	et	3	main
kuuluda	doc_462410643036_item	2421556	et	4	main
iseenda	doc_462410643036_item	2421560	et	3	main
kui	doc_462410643036_item	2421563	et	3	main
selle	doc_462410643036_item	2421572	et	4	main
all	doc_462410643036_item	2421573	et	3	main
stalini	doc_462410643036_item	2421577	et	4	main
paljastamisega	doc_462410643036_item	2421579	et	4	main
džässifestivale	doc_462410643036_item	2421629	et	2	main
tekkib	doc_462410643036_item	2421630	et	3	main
küll	doc_462410643036_item	2421631	et	4	main
kuulamise	doc_462410643036_item	2421636	et	4	main
kontrolltöö	doc_462410643037_item	2421641	et	4	main
eestis	doc_462410643037_item	2421652	et	3	main
muistseks	doc_462410643037_item	2421653	et	3	main
nimetatakse	doc_462410643037_item	2421655	et	3	main
vabaduse	doc_462410643037_item	2421668	et	4	main
on	doc_462410643037_item	2421672	et	4	main
kiviaja	doc_462410643037_item	2421679	et	3	main
e	doc_462410643037_item	2421682	et	4	main
varase	doc_462410643037_item	2421695	et	4	main
aja	doc_462410643037_item	2421697	et	4	main
tegelikult	doc_462410643037_item	2421699	et	4	main
vahel	doc_462410643037_item	2421705	et	4	main
asumisele	doc_462410643036_item	2421322	et	4	main
1941	doc_462410643036_item	2421324	et	2	main
kultuuritegelased	doc_462410643036_item	2421336	et	3	main
represseeriti	doc_462410643036_item	2421339	et	3	main
paigutati	doc_462410643036_item	2421342	et	3	main
tegijaid	doc_462410643036_item	2421351	et	4	main
ankeedi	doc_462410643036_item	2421354	et	4	main
esimestena	doc_462410643036_item	2421360	et	3	main
said	doc_462410643036_item	2421361	et	4	main
hariduse	doc_462410643036_item	2421362	et	3	main
proletariaadi	doc_462410643036_item	2421363	et	3	main
perekondadest	doc_462410643036_item	2421364	et	3	main
lapsed	doc_462410643036_item	2421365	et	3	main
taunitav	doc_462410643036_item	2421366	et	4	main
oli	doc_462410643036_item	2421367	et	3	main
olla	doc_462410643036_item	2421368	et	3	main
endise	doc_462410643036_item	2421369	et	3	main
ev	doc_462410643036_item	2421370	et	4	main
riigiametniku	doc_462410643036_item	2421371	et	3	main
või	doc_462410643036_item	2421372	et	4	main
taunitav	doc_462410643036_item	2421379	et	4	main
teretulnud	doc_462410643036_item	2421383	et	4	main
ateism	doc_462410643036_item	2421385	et	3	main
rajatud	doc_462410643036_item	2421393	et	4	main
tööstust	doc_462410643036_item	2421395	et	4	main
ning	doc_462410643036_item	2421396	et	3	main
oli	doc_462410643036_item	2421414	et	3	main
kehtis	doc_462410643036_item	2421416	et	3	main
võimukandja	doc_462410643036_item	2421421	et	4	main
riigis	doc_462410643036_item	2421423	et	3	main
kehtis	doc_462410643036_item	2421428	et	3	main
k	doc_462410643036_item	2421458	et	4	main
kätte	doc_462410643036_item	2421460	et	4	main
kuid	doc_462410643036_item	2421461	et	4	main
hirmu	doc_462410643036_item	2421465	et	4	main
ensv	doc_462410643036_item	2421468	et	4	main
vahemusrahvastel	doc_462410643036_item	2421478	et	4	main
keelset	doc_462410643036_item	2421481	et	3	main
ajakirjade	doc_462410643036_item	2421485	et	3	main
kuhu	doc_462410643036_item	2421494	et	3	main
sekkunud	doc_462410643036_item	2421498	et	4	main
rahvas	doc_462410643036_item	2421499	et	4	main
oli	doc_462410643036_item	2421504	et	3	main
sest	doc_462410643036_item	2421509	et	4	main
mida	doc_462410643036_item	2421510	et	4	main
ka	doc_462410643036_item	2421522	et	3	main
mida	doc_462410643036_item	2421524	et	4	main
omane	doc_462410643036_item	2421531	et	3	main
kõikidele	doc_462410643036_item	2421532	et	4	main
demokraatlikele	doc_462410643036_item	2421533	et	3	main
paremini	doc_462410643036_item	2421548	et	4	main
tarvitses	doc_462410643036_item	2421550	et	3	main
rohkem	doc_462410643036_item	2421551	et	4	main
mitte	doc_462410643036_item	2421554	et	3	main
omal	doc_462410643036_item	2421559	et	3	main
räägitakse	doc_462410643036_item	2421564	et	3	main
1956	doc_462410643036_item	2421574	et	2	main
fr	doc_462410643036_item	2421585	et	4	main
aktiviseerub	doc_462410643036_item	2421638	et	3	main
tegevus	doc_462410643036_item	2421640	et	4	main
1	doc_462410643037_item	2421642	et	2	main
varane	doc_462410643037_item	2421643	et	4	main
metalliaeg	doc_462410643037_item	2421644	et	3	main
tähendus	doc_462410643037_item	2421650	et	4	main
aladele	doc_462410643037_item	2421665	et	3	main
muistse	doc_462410643037_item	2421667	et	3	main
kaotuseni	doc_462410643037_item	2421669	et	4	main
pärast	doc_462410643037_item	2421678	et	4	main
2000	doc_462410643037_item	2421681	et	2	main
kestis	doc_462410643037_item	2421687	et	4	main
saj	doc_462410643037_item	2421690	et	4	main
nimetatakse	doc_462410643037_item	2421694	et	3	main
varase	doc_462410643037_item	2421702	et	4	main
arvatavasti	doc_462410643037_item	2421726	et	3	main
skandinaaviast	doc_462410643037_item	2421727	et	3	main
volga	doc_462410643037_item	2421732	et	4	main
rahvaste	doc_462410643037_item	2421733	et	4	main
kaudu	doc_462410643037_item	2421734	et	3	main
mindi	doc_462410643037_item	2421735	et	3	main
üle	doc_462410643037_item	2421736	et	3	main
juba	doc_462410643037_item	2421748	et	3	main
ühiskond	doc_462410643037_item	2421750	et	3	main
tegeldi	doc_462410643037_item	2421755	et	3	main
kiviajale	doc_462410643037_item	2421759	et	3	main
nagu	doc_462410643037_item	2421762	et	3	main
tööriistad	doc_462410643037_item	2421766	et	3	main
ka	doc_462410643037_item	2421771	et	3	main
luust	doc_462410643037_item	2421774	et	4	main
kasutasid	doc_462410643037_item	2421776	et	4	main
oma	doc_462410643037_item	2421777	et	4	main
ka	doc_462410643037_item	2421791	et	3	main
1000	doc_462410643037_item	2421799	et	2	main
kui	doc_462410643037_item	2421804	et	3	main
1	doc_462410643037_item	2421829	et	2	main
rauda	doc_462410643037_item	2421837	et	4	main
elu	doc_462410643037_item	2421868	et	4	main
määral	doc_462410643037_item	2421870	et	3	main
igapäevane	doc_462410643037_item	2421880	et	4	main
tekkima	doc_462410643037_item	2421892	et	3	main
kaubandus	doc_462410643037_item	2421893	et	3	main
rooma	doc_462410643037_item	2421898	et	4	main
korraldus	doc_462410643036_item	2421389	et	4	main
kapitalistlikel	doc_462410643036_item	2421391	et	3	main
arendati	doc_462410643036_item	2421394	et	3	main
majandust	doc_462410643036_item	2421397	et	4	main
ning	doc_462410643036_item	2421398	et	3	main
alles	doc_462410643036_item	2421399	et	3	main
siis	doc_462410643036_item	2421400	et	3	main
mugandati	doc_462410643036_item	2421401	et	3	main
sellega	doc_462410643036_item	2421402	et	3	main
valitsev	doc_462410643036_item	2421403	et	4	main
eesti	doc_462410643036_item	2421405	et	4	main
parteisus	doc_462410643036_item	2421418	et	4	main
oli	doc_462410643036_item	2421422	et	3	main
rahvas	doc_462410643036_item	2421424	et	4	main
ülemvõi	doc_462410643036_item	2421432	et	4	main
kuid	doc_462410643036_item	2421433	et	4	main
see	doc_462410643036_item	2421436	et	3	main
partei	doc_462410643036_item	2421438	et	4	main
oli	doc_462410643036_item	2421443	et	3	main
asjaajamiskeeleks	doc_462410643036_item	2421444	et	4	main
eesti	doc_462410643036_item	2421445	et	4	main
ajal	doc_462410643036_item	2421449	et	4	main
nagu	doc_462410643036_item	2421467	et	3	main
polnud	doc_462410643036_item	2421469	et	3	main
ev	doc_462410643036_item	2421470	et	4	main
kehtis	doc_462410643036_item	2421471	et	3	main
aastas	doc_462410643036_item	2421472	et	3	main
1925	doc_462410643036_item	2421473	et	2	main
saada	doc_462410643036_item	2421479	et	4	main
andmist	doc_462410643036_item	2421487	et	4	main
valitses	doc_462410643036_item	2421489	et	3	main
turumajandus	doc_462410643036_item	2421490	et	3	main
palka	doc_462410643036_item	2421502	et	4	main
stiimul	doc_462410643036_item	2421505	et	3	main
täiendamiseks	doc_462410643036_item	2421508	et	4	main
parema	doc_462410643036_item	2421511	et	4	main
seda	doc_462410643036_item	2421514	et	3	main
polnud	doc_462410643036_item	2421527	et	3	main
peale	doc_462410643036_item	2421538	et	4	main
ideoloogilist	doc_462410643036_item	2421539	et	4	main
propagandat	doc_462410643036_item	2421540	et	3	main
inimeselt	doc_462410643036_item	2421541	et	3	main
said	doc_462410643036_item	2421542	et	4	main
selleks	doc_462410643036_item	2421546	et	4	main
talupoeg	doc_462410643036_item	2421557	et	3	main
2	doc_462410643036_item	2421562	et	2	main
ensv	doc_462410643036_item	2421565	et	4	main
nn	doc_462410643036_item	2421567	et	4	main
hruštšovi	doc_462410643036_item	2421568	et	2	main
toimunud	doc_462410643036_item	2421576	et	4	main
kuritegude	doc_462410643036_item	2421578	et	3	main
kaasnenud	doc_462410643036_item	2421580	et	4	main
paljude	doc_462410643036_item	2421581	et	3	main
eesti	doc_462410643036_item	2421582	et	4	main
kirjanikke	doc_462410643036_item	2421583	et	3	main
varjatud	doc_462410643036_item	2421632	et	4	main
kujul	doc_462410643036_item	2421633	et	4	main
1	doc_462410643037_item	2421651	et	2	main
ajajärku	doc_462410643037_item	2421656	et	4	main
algab	doc_462410643037_item	2421658	et	3	main
esimesest	doc_462410643037_item	2421659	et	3	main
inimeste	doc_462410643037_item	2421660	et	3	main
saabumisest	doc_462410643037_item	2421661	et	4	main
8000	doc_462410643037_item	2421662	et	2	main
ekr	doc_462410643037_item	2421663	et	4	main
kuni	doc_462410643037_item	2421666	et	3	main
ja	doc_462410643037_item	2421676	et	3	main
rauaaeg	doc_462410643037_item	2421677	et	3	main
lõppu	doc_462410643037_item	2421680	et	4	main
kr	doc_462410643037_item	2421692	et	4	main
kasutama	doc_462410643037_item	2421721	et	3	main
annastavalt	doc_462410643037_item	2421737	et	4	main
oli	doc_462410643037_item	2421752	et	3	main
roll	doc_462410643037_item	2421754	et	3	main
tegevusega	doc_462410643037_item	2421761	et	4	main
osaliselt	doc_462410643037_item	2421769	et	4	main
aga	doc_462410643037_item	2421770	et	3	main
paremini	doc_462410643037_item	2421784	et	4	main
viimistletud	doc_462410643037_item	2421785	et	4	main
sirp	doc_462410643037_item	2421789	et	3	main
siinsetel	doc_462410643037_item	2421793	et	4	main
ensv	doc_462410643036_item	2421425	et	4	main
konstitutsiooni	doc_462410643036_item	2421426	et	4	main
tegelikult	doc_462410643036_item	2421434	et	4	main
ev	doc_462410643036_item	2421448	et	4	main
oli	doc_462410643036_item	2421450	et	3	main
riigi	doc_462410643036_item	2421451	et	3	main
korralduse	doc_462410643036_item	2421452	et	4	main
mil	doc_462410643036_item	2421453	et	4	main
viimastel	doc_462410643036_item	2421454	et	3	main
aastatel	doc_462410643036_item	2421455	et	4	main
sellist	doc_462410643036_item	2421462	et	4	main
terrorit	doc_462410643036_item	2421463	et	3	main
kultuuriautonoomia	doc_462410643036_item	2421475	et	4	main
mis	doc_462410643036_item	2421476	et	4	main
lubas	doc_462410643036_item	2421477	et	3	main
seltsiliikumist	doc_462410643036_item	2421483	et	3	main
riik	doc_462410643036_item	2421495	et	3	main
ei	doc_462410643036_item	2421497	et	4	main
sai	doc_462410643036_item	2421500	et	4	main
reaalset	doc_462410643036_item	2421501	et	3	main
ning	doc_462410643036_item	2421507	et	3	main
ja	doc_462410643036_item	2421517	et	3	main
karjääri	doc_462410643036_item	2421518	et	4	main
väljavaated	doc_462410643036_item	2421519	et	3	main
otseselt	doc_462410643036_item	2421496	et	4	main
ning	doc_462410643036_item	2421503	et	3	main
enesearendamiseks	doc_462410643036_item	2421506	et	3	main
hariduse	doc_462410643036_item	2421512	et	3	main
saadi	doc_462410643036_item	2421513	et	4	main
olid	doc_462410643036_item	2421520	et	4	main
oli	doc_462410643036_item	2421521	et	3	main
tööpuudus	doc_462410643036_item	2421523	et	3	main
kuid	doc_462410643036_item	2421528	et	4	main
ei	doc_462410643036_item	2421536	et	4	main
surud	doc_462410643036_item	2421537	et	4	main
vabalt	doc_462410643036_item	2421543	et	4	main
reisid	doc_462410643036_item	2421544	et	4	main
ning	doc_462410643036_item	2421545	et	3	main
parteisse	doc_462410643036_item	2421555	et	3	main
kultuuriloos	doc_462410643036_item	2421566	et	4	main
sulast	doc_462410643036_item	2421569	et	4	main
siis	doc_462410643036_item	2421570	et	3	main
mõeldakse	doc_462410643036_item	2421571	et	3	main
a	doc_462410643036_item	2421575	et	4	main
tuglas	doc_462410643036_item	2421586	et	4	main
meister	doc_462410643036_item	2421622	et	3	main
margarita	doc_462410643036_item	2421624	et	4	main
teos	doc_462410643036_item	2421625	et	4	main
tõlke	doc_462410643036_item	2421626	et	4	main
eestis	doc_462410643036_item	2421627	et	3	main
korraldatakse	doc_462410643036_item	2421628	et	3	main
muusika	doc_462410643036_item	2421635	et	4	main
eesti	doc_462410643037_item	2421645	et	4	main
territooriumil	doc_462410643037_item	2421646	et	3	main
2	doc_462410643037_item	2421647	et	2	main
mõiste	doc_462410643037_item	2421648	et	4	main
mis	doc_462410643037_item	2421657	et	4	main
kr	doc_462410643037_item	2421683	et	4	main
pronksiaeg	doc_462410643037_item	2421685	et	3	main
mida	doc_462410643037_item	2421693	et	4	main
metalli	doc_462410643037_item	2421703	et	4	main
aja	doc_462410643037_item	2421704	et	4	main
mis	doc_462410643037_item	2421723	et	4	main
või	doc_462410643037_item	2421729	et	4	main
variant	doc_462410643037_item	2421731	et	3	main
mindi	doc_462410643037_item	2421739	et	3	main
tekkis	doc_462410643037_item	2421742	et	3	main
tol	doc_462410643037_item	2421745	et	3	main
perioodil	doc_462410643037_item	2421746	et	3	main
ka	doc_462410643037_item	2421758	et	3	main
küttimine	doc_462410643037_item	2421763	et	4	main
esivanemate	doc_462410643037_item	2421778	et	4	main
kogemust	doc_462410643037_item	2421779	et	3	main
tööriistad	doc_462410643037_item	2421780	et	3	main
kõblas	doc_462410643037_item	2421788	et	3	main
aga	doc_462410643037_item	2421790	et	3	main
ei	doc_462410643037_item	2421797	et	4	main
tunti	doc_462410643037_item	2421801	et	3	main
maaveljelus	doc_462410643037_item	2421803	et	4	main
rääkida	doc_462410643037_item	2421805	et	3	main
perioodil	doc_462410643037_item	2421808	et	3	main
ekr	doc_462410643037_item	2421810	et	4	main
6saj	doc_462410643037_item	2421811	et	4	main
olid	doc_462410643037_item	2421813	et	4	main
maapealsed	doc_462410643037_item	2421814	et	3	main
suurematest	doc_462410643037_item	2421816	et	4	main
ring	doc_462410643037_item	2421819	et	3	main
ensv-s	doc_462410643036_item	2421525	et	3	main
on	doc_462410643036_item	2421530	et	4	main
riikidele	doc_462410643036_item	2421534	et	3	main
rahvale	doc_462410643036_item	2421535	et	3	main
et	doc_462410643036_item	2421547	et	3	main
oli	doc_462410643036_item	2421558	et	3	main
peremee	doc_462410643036_item	2421561	et	3	main
rehabiliteerimist	doc_462410643036_item	2421584	et	4	main
k	doc_462410643036_item	2421587	et	4	main
merilaas	doc_462410643036_item	2421588	et	3	main
j	doc_462410643036_item	2421589	et	4	main
kross	doc_462410643036_item	2421590	et	3	main
tsensuur	doc_462410643036_item	2421591	et	3	main
lõdvenes	doc_462410643036_item	2421592	et	3	main
inimesteni	doc_462410643036_item	2421593	et	3	main
jõudsid	doc_462410643036_item	2421594	et	4	main
seni	doc_462410643036_item	2421595	et	3	main
kulu	doc_462410643036_item	2421596	et	4	main
all	doc_462410643036_item	2421597	et	3	main
olnud	doc_462410643036_item	2421598	et	4	main
raamatud	doc_462410643036_item	2421599	et	4	main
tugevnesid	doc_462410643036_item	2421600	et	4	main
sidemed	doc_462410643036_item	2421601	et	3	main
paguluskirjanikega	doc_462410643036_item	2421602	et	3	main
1965	doc_462410643036_item	2421603	et	2	main
aastal	doc_462410643036_item	2421604	et	3	main
ilmus	doc_462410643036_item	2421605	et	4	main
loomingu	doc_462410643036_item	2421606	et	3	main
raamatukogu	doc_462410643036_item	2421607	et	4	main
esseid	doc_462410643036_item	2421608	et	3	main
ning	doc_462410643036_item	2421609	et	3	main
kirjanike	doc_462410643036_item	2421610	et	3	main
teoseid	doc_462410643036_item	2421611	et	3	main
ilmus	doc_462410643036_item	2421612	et	4	main
ka	doc_462410643036_item	2421613	et	3	main
palju	doc_462410643036_item	2421614	et	4	main
tõlkekirjandust	doc_462410643036_item	2421615	et	3	main
inimeste	doc_462410643036_item	2421616	et	3	main
kultuurikontaktid	doc_462410643036_item	2421617	et	3	main
suurenesid	doc_462410643036_item	2421618	et	4	main
ilmus	doc_462410643036_item	2421619	et	4	main
ka	doc_462410643036_item	2421620	et	3	main
bulkakovi	doc_462410643036_item	2421621	et	4	main
ja	doc_462410643036_item	2421623	et	3	main
lääneliku	doc_462410643036_item	2421634	et	4	main
võimalus	doc_462410643036_item	2421637	et	3	main
dissidentide	doc_462410643036_item	2421639	et	3	main
animism	doc_462410643037_item	2421649	et	3	main
ajaks	doc_462410643037_item	2421654	et	4	main
eesti	doc_462410643037_item	2421664	et	4	main
13	doc_462410643037_item	2421670	et	2	main
sajandil	doc_462410643037_item	2421671	et	3	main
olemas	doc_462410643037_item	2421673	et	4	main
kiviaeg	doc_462410643037_item	2421674	et	3	main
pronksiaeg	doc_462410643037_item	2421675	et	3	main
algas	doc_462410643037_item	2421684	et	3	main
mis	doc_462410643037_item	2421686	et	4	main
kuni	doc_462410643037_item	2421688	et	3	main
6	doc_462410643037_item	2421689	et	2	main
e	doc_462410643037_item	2421691	et	4	main
metalli	doc_462410643037_item	2421696	et	4	main
aluseks	doc_462410643037_item	2421698	et	4	main
pronksi	doc_462410643037_item	2421700	et	4	main
ja	doc_462410643037_item	2421701	et	3	main
on	doc_462410643037_item	2421706	et	4	main
üsna	doc_462410643037_item	2421707	et	3	main
raske	doc_462410643037_item	2421708	et	4	main
kindlat	doc_462410643037_item	2421709	et	3	main
jooni	doc_462410643037_item	2421710	et	4	main
teha	doc_462410643037_item	2421712	et	3	main
piiri	doc_462410643037_item	2421711	et	4	main
sest	doc_462410643037_item	2421713	et	4	main
suuri	doc_462410643037_item	2421714	et	3	main
muutusi	doc_462410643037_item	2421715	et	4	main
ei	doc_462410643037_item	2421716	et	4	main
toimunud	doc_462410643037_item	2421717	et	4	main
pronksiajal	doc_462410643037_item	2421718	et	3	main
inimesed	doc_462410643037_item	2421719	et	3	main
hakkasid	doc_462410643037_item	2421720	et	4	main
pronksi	doc_462410643037_item	2421722	et	4	main
tuli	doc_462410643037_item	2421724	et	4	main
neile	doc_462410643037_item	2421725	et	4	main
üle	doc_462410643037_item	2421740	et	3	main
künnipõlendus	doc_462410643037_item	2421744	et	4	main
oli	doc_462410643037_item	2421747	et	3	main
patriarhaarne	doc_462410643037_item	2421749	et	4	main
mehe	doc_462410643037_item	2421751	et	3	main
tähtsam	doc_462410643037_item	2421753	et	4	main
kalandus	doc_462410643037_item	2421764	et	3	main
koristamine	doc_462410643037_item	2421765	et	4	main
puust	doc_462410643037_item	2421773	et	4	main
inimesed	doc_462410643037_item	2421775	et	3	main
olid	doc_462410643037_item	2421781	et	4	main
tugevamad	doc_462410643037_item	2421782	et	4	main
ja	doc_462410643037_item	2421783	et	3	main
olid	doc_462410643037_item	2421787	et	4	main
käsikivi	doc_462410643037_item	2421792	et	4	main
veel	doc_462410643037_item	2421796	et	4	main
tuntud	doc_462410643037_item	2421798	et	4	main
2000	doc_462410643037_item	2421809	et	2	main
tehti	doc_462410643037_item	2421818	et	3	main
kivist	doc_462410643037_item	2421822	et	4	main
püüdsid	doc_462410643037_item	2421833	et	4	main
söömisest	doc_462410643037_item	2421848	et	4	main
saj	doc_462410643037_item	2421852	et	4	main
mõjutas	doc_462410643037_item	2421866	et	3	main
ajaloo	doc_462410643037_item	2421871	et	4	main
jooksul	doc_462410643037_item	2421873	et	4	main
on	doc_462410643037_item	2421874	et	4	main
väga	doc_462410643037_item	2421875	et	3	main
varasel	doc_462410643037_item	2421886	et	4	main
kätte	doc_462410643037_item	2421728	et	4	main
teine	doc_462410643037_item	2421730	et	3	main
majanduselt	doc_462410643037_item	2421738	et	4	main
viljelusmajandusele	doc_462410643037_item	2421741	et	3	main
alepõlendus	doc_462410643037_item	2421743	et	4	main
loomakasvatusega	doc_462410643037_item	2421756	et	3	main
kui	doc_462410643037_item	2421757	et	3	main
iseloomuliku	doc_462410643037_item	2421760	et	3	main
olid	doc_462410643037_item	2421767	et	4	main
tehtudpronksist	doc_462410643037_item	2421768	et	4	main
kivist	doc_462410643037_item	2421772	et	4	main
uued	doc_462410643037_item	2421786	et	3	main
aladel	doc_462410643037_item	2421794	et	3	main
juba	doc_462410643037_item	2421802	et	3	main
matmiskommetest	doc_462410643037_item	2421806	et	4	main
siis	doc_462410643037_item	2421807	et	3	main
ekr	doc_462410643037_item	2421812	et	4	main
mille	doc_462410643037_item	2421820	et	3	main
kr	doc_462410643037_item	2421828	et	4	main
saj	doc_462410643037_item	2421830	et	4	main
siinsed	doc_462410643037_item	2421831	et	3	main
elanikud	doc_462410643037_item	2421832	et	3	main
juba	doc_462410643037_item	2421834	et	3	main
ise	doc_462410643037_item	2421835	et	4	main
sead	doc_462410643037_item	2421845	et	4	main
hobused	doc_462410643037_item	2421846	et	4	main
mille	doc_462410643037_item	2421847	et	3	main
ainult	doc_462410643037_item	2421850	et	4	main
luust	doc_462410643037_item	2421861	et	4	main
rauda	doc_462410643037_item	2421864	et	4	main
suurel	doc_462410643037_item	2421869	et	3	main
inimeste	doc_462410643037_item	2421879	et	3	main
ja	doc_462410643037_item	2421883	et	3	main
muutusid	doc_462410643037_item	2421885	et	4	main
sai	doc_462410643037_item	2421895	et	4	main
rauaaja	doc_462410643037_item	2421902	et	3	main
vikingi	doc_462410643037_item	2421905	et	4	main
ajale	doc_462410643037_item	2421906	et	3	main
inimesed	doc_462410643037_item	2421907	et	3	main
metalliajal	doc_462410643037_item	2421910	et	3	main
murrang	doc_462410643037_item	2421932	et	3	main
elu	doc_462410643037_item	2421945	et	4	main
ja	doc_462410643037_item	2421946	et	3	main
on	doc_462410643037_item	2421955	et	4	main
lüli	doc_462410643037_item	2421957	et	4	main
ajaloos	doc_462410643037_item	2421959	et	4	main
2	doc_462410643037_item	2421960	et	2	main
animism	doc_462410643037_item	2421961	et	3	main
kiviajale	doc_462410643037_item	2421962	et	3	main
ja	doc_462410643037_item	2421963	et	3	main
uskumuste	doc_462410643037_item	2421967	et	4	main
et	doc_462410643037_item	2421973	et	3	main
hing	doc_462410643037_item	2421974	et	3	main
eluta	doc_462410643037_item	2421978	et	3	main
miks	doc_462410643038_item	2422014	et	4	main
1970-ndatel	doc_462410643038_item	2422016	et	4	main
hakkas	doc_462410643038_item	2422017	et	3	main
eestis	doc_462410643038_item	2422018	et	3	main
arenema	doc_462410643038_item	2422019	et	3	main
kultuurielu	doc_462410643038_item	2422020	et	4	main
tehtud	doc_462410643038_item	2422036	et	4	main
oli	doc_462410643038_item	2422038	et	3	main
populaarne	doc_462410643038_item	2422039	et	3	main
need	doc_462410643038_item	2422044	et	3	main
ameerika	doc_462410643038_item	2422047	et	3	main
muusikaga	doc_462410643038_item	2422057	et	3	main
esines	doc_462410643038_item	2422060	et	3	main
ajaloolised	doc_462410643038_item	2422068	et	4	main
saated	doc_462410643038_item	2422069	et	3	main
aastat	doc_462410643038_item	2422073	et	3	main
perioodi	doc_462410643038_item	2422076	et	4	main
väliseestlaste	doc_462410643038_item	2422085	et	4	main
kirjandus	doc_462410643038_item	2422086	et	3	main
tihenesid	doc_462410643038_item	2422087	et	4	main
kontaktid	doc_462410643038_item	2422088	et	3	main
1970	doc_462410643038_item	2422090	et	2	main
aa	doc_462410643038_item	2422091	et	3	main
korraldati	doc_462410643038_item	2422092	et	3	main
i	doc_462410643038_item	2422093	et	4	main
olid	doc_462410643038_item	2422124	et	4	main
väetamist	doc_462410643037_item	2421795	et	4	main
ekr	doc_462410643037_item	2421800	et	4	main
kivikirstkalmed	doc_462410643037_item	2421815	et	4	main
kividest	doc_462410643037_item	2421817	et	3	main
oli	doc_462410643037_item	2421821	et	3	main
6	doc_462410643037_item	2421825	et	2	main
sulata	doc_462410643037_item	2421838	et	4	main
peamine	doc_462410643037_item	2421839	et	3	main
elatusala	doc_462410643037_item	2421840	et	4	main
oli	doc_462410643037_item	2421841	et	3	main
koduloomapidamine	doc_462410643037_item	2421842	et	3	main
veised	doc_462410643037_item	2421843	et	3	main
lambad	doc_462410643037_item	2421844	et	3	main
pronksist	doc_462410643037_item	2421862	et	4	main
inimeste	doc_462410643037_item	2421867	et	3	main
arengu	doc_462410643037_item	2421872	et	3	main
elu	doc_462410643037_item	2421881	et	4	main
kultuur	doc_462410643037_item	2421884	et	3	main
inimeste	doc_462410643037_item	2421890	et	3	main
elus	doc_462410643037_item	2421891	et	4	main
mis	doc_462410643037_item	2421894	et	4	main
ja	doc_462410643037_item	2421900	et	3	main
enam	doc_462410643037_item	2421911	et	4	main
näiteks	doc_462410643037_item	2421915	et	4	main
rauaajaga	doc_462410643037_item	2421917	et	3	main
seega	doc_462410643037_item	2421918	et	4	main
kokkuvõtteks	doc_462410643037_item	2421919	et	3	main
võib	doc_462410643037_item	2421920	et	3	main
rauaajal	doc_462410643037_item	2421930	et	3	main
toimus	doc_462410643037_item	2421931	et	3	main
mingil	doc_462410643037_item	2421943	et	4	main
määral	doc_462410643037_item	2421944	et	3	main
kultuuride	doc_462410643037_item	2421952	et	3	main
selle	doc_462410643037_item	2421969	et	4	main
kõikjal	doc_462410643037_item	2421976	et	3	main
ajaloodokument	doc_462410643038_item	2422011	et	3	main
ühiskonnakriitika	doc_462410643038_item	2422013	et	4	main
oli	doc_462410643038_item	2422023	et	3	main
televisioon	doc_462410643038_item	2422025	et	4	main
näitama	doc_462410643038_item	2422027	et	3	main
oma	doc_462410643038_item	2422028	et	4	main
filme	doc_462410643038_item	2422029	et	3	main
esimesed	doc_462410643038_item	2422030	et	3	main
filmid	doc_462410643038_item	2422031	et	4	main
eestis	doc_462410643038_item	2422037	et	3	main
rohkem	doc_462410643038_item	2422050	et	4	main
ilmusid	doc_462410643038_item	2422051	et	4	main
uued	doc_462410643038_item	2422052	et	3	main
saated	doc_462410643038_item	2422053	et	3	main
need	doc_462410643038_item	2422054	et	3	main
olid	doc_462410643038_item	2422066	et	4	main
25	doc_462410643038_item	2422072	et	2	main
seda	doc_462410643038_item	2422075	et	3	main
kättesaadavaks	doc_462410643038_item	2422084	et	4	main
festivall	doc_462410643038_item	2422095	et	4	main
said	doc_462410643038_item	2422097	et	4	main
varane	doc_462410643037_item	2421823	et	4	main
metalliaeg	doc_462410643037_item	2421824	et	3	main
saj	doc_462410643037_item	2421826	et	4	main
e	doc_462410643037_item	2421827	et	4	main
soomaagist	doc_462410643037_item	2421836	et	4	main
loobuti	doc_462410643037_item	2421849	et	3	main
14	doc_462410643037_item	2421851	et	2	main
hakkasid	doc_462410643037_item	2421853	et	4	main
tekkima	doc_462410643037_item	2421854	et	3	main
linnused	doc_462410643037_item	2421855	et	3	main
muinaslinnused	doc_462410643037_item	2421856	et	3	main
tööriistad	doc_462410643037_item	2421857	et	3	main
tehti	doc_462410643037_item	2421858	et	3	main
nii	doc_462410643037_item	2421859	et	3	main
puust	doc_462410643037_item	2421860	et	4	main
rauast	doc_462410643037_item	2421863	et	4	main
kasutuselevõtt	doc_462410643037_item	2421865	et	3	main
huvitav	doc_462410643037_item	2421876	et	4	main
jälgida	doc_462410643037_item	2421877	et	3	main
kuidas	doc_462410643037_item	2421878	et	3	main
maailmavaated	doc_462410643037_item	2421882	et	3	main
jooneks	doc_462410643037_item	2421897	et	3	main
vähem	doc_462410643037_item	2421912	et	4	main
metalliajal	doc_462410643037_item	2421887	et	3	main
juba	doc_462410643037_item	2421888	et	3	main
hakkasid	doc_462410643037_item	2421889	et	4	main
iseloomulikuks	doc_462410643037_item	2421896	et	3	main
rauaajale	doc_462410643037_item	2421899	et	3	main
noorema	doc_462410643037_item	2421901	et	4	main
algusesse	doc_462410643037_item	2421903	et	4	main
kuuluva	doc_462410643037_item	2421904	et	4	main
varasel	doc_462410643037_item	2421909	et	4	main
öelda	doc_462410643037_item	2421921	et	4	main
metalliaja	doc_462410643037_item	2421923	et	3	main
tähendab	doc_462410643037_item	2421926	et	3	main
pronksi	doc_462410643037_item	2421927	et	4	main
ja	doc_462410643037_item	2421928	et	3	main
varasel	doc_462410643037_item	2421929	et	4	main
ajaloo	doc_462410643037_item	2421933	et	4	main
käigul	doc_462410643037_item	2421934	et	3	main
metalli	doc_462410643037_item	2421935	et	4	main
kasutuselevõtt	doc_462410643037_item	2421936	et	3	main
andis	doc_462410643037_item	2421937	et	3	main
inimkonnale	doc_462410643037_item	2421938	et	4	main
rohkem	doc_462410643037_item	2421939	et	4	main
võimalusi	doc_462410643037_item	2421940	et	3	main
ja	doc_462410643037_item	2421941	et	3	main
kergendas	doc_462410643037_item	2421942	et	3	main
inimkonna	doc_462410643037_item	2421951	et	4	main
üldse	doc_462410643037_item	2421964	et	3	main
iseloomulik	doc_462410643037_item	2421966	et	3	main
järgi	doc_462410643037_item	2421970	et	4	main
on	doc_462410643037_item	2421975	et	4	main
nii	doc_462410643037_item	2421977	et	3	main
1	doc_462410643038_item	2422015	et	2	main
olid	doc_462410643038_item	2422032	et	4	main
vene	doc_462410643038_item	2422033	et	4	main
ka	doc_462410643038_item	2422042	et	3	main
olid	doc_462410643038_item	2422045	et	4	main
multufilmidega	doc_462410643038_item	2422048	et	4	main
olid	doc_462410643038_item	2422055	et	4	main
olid	doc_462410643038_item	2422063	et	4	main
spetsiaalsed	doc_462410643038_item	2422064	et	3	main
saated	doc_462410643038_item	2422065	et	3	main
täna	doc_462410643038_item	2422071	et	4	main
esialgu	doc_462410643038_item	2422079	et	3	main
tuntuks	doc_462410643038_item	2422098	et	4	main
mõned	doc_462410643038_item	2422099	et	3	main
oli	doc_462410643038_item	2422128	et	3	main
viga	doc_462410643038_item	2422133	et	4	main
neid	doc_462410643038_item	2422142	et	4	main
järelmaksuga	doc_462410643038_item	2422143	et	3	main
ehitati	doc_462410643038_item	2422144	et	3	main
balti	doc_462410643038_item	2422145	et	3	main
ei	doc_462410643038_item	2422153	et	4	main
tehtnuud	doc_462410643038_item	2422154	et	4	main
arvates	doc_462410643038_item	2422170	et	4	main
tol	doc_462410643038_item	2422191	et	3	main
arvan	doc_462410643038_item	2422193	et	3	main
vastu	doc_462410643038_item	2422205	et	3	main
propageeriti	doc_462410643038_item	2422209	et	3	main
võrdsust	doc_462410643038_item	2422211	et	4	main
kõik	doc_462410643038_item	2422212	et	4	main
kes	doc_462410643038_item	2422221	et	4	main
saa	doc_462410643038_item	2422223	et	4	main
minna	doc_462410643038_item	2422224	et	3	main
vastu	doc_462410643038_item	2422225	et	3	main
teistele	doc_462410643038_item	2422226	et	4	main
see	doc_462410643038_item	2422227	et	3	main
pole	doc_462410643038_item	2422228	et	3	main
või	doc_462410643038_item	2422237	et	4	main
olid	doc_462410643037_item	2421908	et	4	main
päiksed	doc_462410643037_item	2421913	et	3	main
võrreldes	doc_462410643037_item	2421914	et	3	main
keskmise	doc_462410643037_item	2421916	et	3	main
et	doc_462410643037_item	2421922	et	3	main
algusel	doc_462410643037_item	2421924	et	4	main
see	doc_462410643037_item	2421925	et	3	main
metalli	doc_462410643037_item	2421947	et	4	main
kasutuselevõtt	doc_462410643037_item	2421948	et	3	main
andis	doc_462410643037_item	2421949	et	3	main
kiiruse	doc_462410643037_item	2421950	et	4	main
metalliaeg	doc_462410643037_item	2421954	et	3	main
arvasid	doc_462410643037_item	2421972	et	4	main
tähtsal	doc_462410643038_item	2422021	et	3	main
eesti	doc_462410643038_item	2422024	et	4	main
hakatakse	doc_462410643038_item	2422026	et	3	main
režissööride	doc_462410643038_item	2422034	et	2	main
abil	doc_462410643038_item	2422035	et	4	main
multufilmid	doc_462410643038_item	2422043	et	4	main
peamiselt	doc_462410643038_item	2422056	et	4	main
ka	doc_462410643038_item	2422067	et	3	main
tagasi	doc_462410643038_item	2422074	et	3	main
iseloomustab	doc_462410643038_item	2422078	et	4	main
pärast-proosa	doc_462410643038_item	2422081	et	4	main
eestlastele	doc_462410643038_item	2422082	et	4	main
väliskirjandusega	doc_462410643038_item	2422089	et	3	main
sealt	doc_462410643038_item	2422096	et	4	main
näitemajandeid	doc_462410643038_item	2422122	et	3	main
nagu	doc_462410643038_item	2422125	et	3	main
auto	doc_462410643038_item	2422139	et	4	main
sai	doc_462410643038_item	2422157	et	4	main
eestis	doc_462410643038_item	2422160	et	3	main
on	doc_462410643038_item	2422172	et	4	main
see	doc_462410643038_item	2422176	et	3	main
minu	doc_462410643038_item	2422179	et	3	main
arvamus	doc_462410643038_item	2422180	et	3	main
mis	doc_462410643038_item	2422189	et	4	main
ajal	doc_462410643038_item	2422192	et	4	main
et	doc_462410643038_item	2422195	et	3	main
inimene	doc_462410643038_item	2422197	et	3	main
olema	doc_462410643038_item	2422214	et	4	main
ei	doc_462410643038_item	2422222	et	4	main
olema	doc_462410643038_item	2422233	et	4	main
nagu	doc_462410643038_item	2422234	et	3	main
teised	doc_462410643038_item	2422236	et	4	main
arengule	doc_462410643037_item	2421953	et	3	main
tähtis	doc_462410643037_item	2421956	et	4	main
maailma	doc_462410643037_item	2421958	et	4	main
muinasajale	doc_462410643037_item	2421965	et	3	main
süsteem	doc_462410643037_item	2421968	et	3	main
inimesed	doc_462410643037_item	2421971	et	3	main
kui	doc_462410643037_item	2421979	et	3	main
elulisel	doc_462410643037_item	2421980	et	4	main
loodusel	doc_462410643037_item	2421981	et	4	main
asjadel	doc_462410643037_item	2421982	et	3	main
oli	doc_462410643037_item	2421983	et	3	main
animalistlik	doc_462410643037_item	2421984	et	4	main
ja	doc_462410643037_item	2421985	et	3	main
totemistlik	doc_462410643037_item	2421986	et	3	main
süsteemid	doc_462410643037_item	2421987	et	3	main
uskumused	doc_462410643037_item	2421988	et	3	main
kontrolltöö	doc_462410643038_item	2421989	et	4	main
1	doc_462410643038_item	2421990	et	2	main
majanduslikud-kultuurilised	doc_462410643038_item	2421992	et	4	main
tegurid	doc_462410643038_item	2421993	et	3	main
missugused	doc_462410643038_item	2421991	et	3	main
andsid	doc_462410643038_item	2421994	et	4	main
1970ndatel	doc_462410643038_item	2421995	et	4	main
põhjust	doc_462410643038_item	2421996	et	4	main
eesti	doc_462410643038_item	2421997	et	4	main
nsvl	doc_462410643038_item	2421998	et	4	main
tunda	doc_462410643038_item	2421999	et	3	main
end	doc_462410643038_item	2422000	et	4	main
nsvl	doc_462410643038_item	2422001	et	4	main
2	doc_462410643038_item	2422003	et	2	main
l	doc_462410643038_item	2422004	et	4	main
laiuse	doc_462410643038_item	2422005	et	4	main
lähisvälismaana	doc_462410643038_item	2422002	et	3	main
mängufilm	doc_462410643038_item	2422006	et	3	main
libahunt	doc_462410643038_item	2422007	et	3	main
kas	doc_462410643038_item	2422008	et	3	main
teie	doc_462410643038_item	2422009	et	4	main
arvates	doc_462410643038_item	2422010	et	4	main
või	doc_462410643038_item	2422012	et	4	main
kohal	doc_462410643038_item	2422022	et	4	main
huumorifilm	doc_462410643038_item	2422040	et	3	main
õitsesid	doc_462410643038_item	2422041	et	4	main
sarnased	doc_462410643038_item	2422046	et	4	main
järjest	doc_462410643038_item	2422049	et	4	main
seotud	doc_462410643038_item	2422058	et	4	main
siin	doc_462410643038_item	2422059	et	4	main
palju	doc_462410643038_item	2422061	et	4	main
lapsi	doc_462410643038_item	2422062	et	4	main
nt	doc_462410643038_item	2422070	et	4	main
kirjanduses	doc_462410643038_item	2422077	et	3	main
luule	doc_462410643038_item	2422080	et	4	main
sai	doc_462410643038_item	2422083	et	4	main
dzässi	doc_462410643038_item	2422094	et	4	main
heliloojad	doc_462410643038_item	2422100	et	3	main
hakatakse	doc_462410643038_item	2422101	et	3	main
baletti	doc_462410643038_item	2422102	et	4	main
näitama	doc_462410643038_item	2422103	et	3	main
pärts	doc_462410643038_item	2422104	et	4	main
rahvusvaheliselt	doc_462410643038_item	2422105	et	4	main
tuntud	doc_462410643038_item	2422106	et	4	main
klassik	doc_462410643038_item	2422107	et	3	main
tallinna	doc_462410643038_item	2422108	et	4	main
elanikud	doc_462410643038_item	2422109	et	3	main
said	doc_462410643038_item	2422110	et	4	main
vaadata	doc_462410643038_item	2422111	et	4	main
tv	doc_462410643038_item	2422113	et	4	main
välismuusika	doc_462410643038_item	2422114	et	4	main
polnud	doc_462410643038_item	2422115	et	3	main
soome	doc_462410643038_item	2422112	et	3	main
soovitav	doc_462410643038_item	2422116	et	4	main
eestimuusika	doc_462410643038_item	2422117	et	4	main
õitses	doc_462410643038_item	2422118	et	4	main
eestisse	doc_462410643038_item	2422119	et	4	main
ehitati	doc_462410643038_item	2422120	et	3	main
palju	doc_462410643038_item	2422121	et	4	main
miniriigid	doc_462410643038_item	2422126	et	3	main
mis	doc_462410643038_item	2422130	et	4	main
oli	doc_462410643038_item	2422132	et	3	main
eestis	doc_462410643038_item	2422134	et	3	main
hakkasid	doc_462410643038_item	2422135	et	4	main
ilmuma	doc_462410643038_item	2422136	et	3	main
luksuskaubad	doc_462410643038_item	2422137	et	3	main
külmkapp	doc_462410643038_item	2422138	et	3	main
eestlased	doc_462410643038_item	2422152	et	3	main
2	doc_462410643038_item	2422168	et	2	main
ajaloodokument	doc_462410643038_item	2422174	et	3	main
võib-olla	doc_462410643038_item	2422175	et	3	main
seda	doc_462410643038_item	2422194	et	3	main
ühiskonnale	doc_462410643038_item	2422206	et	4	main
sellel	doc_462410643038_item	2422207	et	4	main
absoluutselt	doc_462410643038_item	2422210	et	4	main
peavad	doc_462410643038_item	2422213	et	4	main
eraldi	doc_462410643038_item	2422238	et	4	main
need	doc_462410643038_item	2422123	et	3	main
soojuselektrijaama	doc_462410643038_item	2422146	et	4	main
bsej	doc_462410643038_item	2422147	et	4	main
siin	doc_462410643038_item	2422148	et	4	main
töötasid	doc_462410643038_item	2422149	et	4	main
valdavalt	doc_462410643038_item	2422150	et	4	main
venelased	doc_462410643038_item	2422151	et	3	main
siin	doc_462410643038_item	2422127	et	4	main
kõik	doc_462410643038_item	2422129	et	4	main
inimesel	doc_462410643038_item	2422131	et	3	main
võis	doc_462410643038_item	2422140	et	4	main
osta	doc_462410643038_item	2422141	et	4	main
kodune	doc_462410643038_item	2422155	et	4	main
populaarseks	doc_462410643038_item	2422158	et	4	main
on	doc_462410643038_item	2422161	et	4	main
meri	doc_462410643038_item	2422162	et	3	main
see	doc_462410643038_item	2422163	et	3	main
on	doc_462410643038_item	2422164	et	4	main
nagu	doc_462410643038_item	2422165	et	3	main
pääs	doc_462410643038_item	2422166	et	3	main
läänte	doc_462410643038_item	2422167	et	3	main
minu	doc_462410643038_item	2422169	et	3	main
libahunt	doc_462410643038_item	2422171	et	3	main
on	doc_462410643038_item	2422177	et	4	main
mulle	doc_462410643038_item	2422182	et	4	main
tundub	doc_462410643038_item	2422183	et	3	main
et	doc_462410643038_item	2422184	et	3	main
see	doc_462410643038_item	2422185	et	3	main
libahunt	doc_462410643038_item	2422186	et	3	main
on	doc_462410643038_item	2422187	et	4	main
üskkõik	doc_462410643038_item	2422188	et	4	main
olla	doc_462410643038_item	2422199	et	3	main
olukorras	doc_462410643038_item	2422201	et	3	main
üks	doc_462410643038_item	2422202	et	3	main
inimene	doc_462410643038_item	2422203	et	3	main
seisab	doc_462410643038_item	2422204	et	3	main
ajal	doc_462410643038_item	2422208	et	4	main
võimalik	doc_462410643038_item	2422229	et	3	main
see	doc_462410643038_item	2422230	et	3	main
tähendab	doc_462410643038_item	2422231	et	3	main
pead	doc_462410643038_item	2422232	et	4	main
tehnika	doc_462410643038_item	2422156	et	4	main
siin	doc_462410643038_item	2422159	et	4	main
rohkem	doc_462410643038_item	2422173	et	4	main
ainult	doc_462410643038_item	2422178	et	4	main
aga	doc_462410643038_item	2422181	et	3	main
inimene	doc_462410643038_item	2422190	et	3	main
iga	doc_462410643038_item	2422196	et	4	main
võis	doc_462410643038_item	2422198	et	4	main
sellises	doc_462410643038_item	2422200	et	4	main
sarnased	doc_462410643038_item	2422215	et	4	main
filmis	doc_462410643038_item	2422216	et	4	main
on	doc_462410643038_item	2422217	et	4	main
näidatud	doc_462410643038_item	2422218	et	4	main
üks	doc_462410643038_item	2422219	et	3	main
inimene	doc_462410643038_item	2422220	et	3	main
kõik	doc_462410643038_item	2422235	et	4	main
ühiskonnast	doc_462410643038_item	2422239	et	4	main
mind	doc_464301607715_item	2422617	et	4	main
kodus	doc_464301607715_item	2422618	et	4	main
tere	doc_464301607715_item	2422619	et	3	main
vastu	doc_464301607715_item	2422622	et	3	main
2	doc_464301607715_item	2422624	et	2	main
väljast	doc_464301607715_item	2422625	et	4	main
sisse	doc_464301607715_item	2422626	et	4	main
astudes	doc_464301607715_item	2422627	et	3	main
märkas	doc_464301607715_item	2422628	et	3	main
ta	doc_464301607715_item	2422629	et	4	main
taga	doc_464301607715_item	2422638	et	4	main
siis	doc_464301607715_item	2422641	et	3	main
väga	doc_464301607715_item	2422645	et	3	main
võetakse	doc_464301607715_item	2422623	et	3	main
tuttavat	doc_464301607715_item	2422631	et	3	main
talumeest	doc_464301607715_item	2422632	et	4	main
naaber	doc_464301607715_item	2422633	et	3	main
külast	doc_464301607715_item	2422634	et	4	main
mis	doc_464301607715_item	2422635	et	4	main
olin	doc_464301607715_item	2422640	et	3	main
nii	doc_464301607715_item	2422649	et	3	main
minu	doc_464301607715_item	2422651	et	3	main
öelda	doc_464301607715_item	2422654	et	4	main
jämedune	doc_464301607715_item	2422667	et	3	main
mille	doc_464301607715_item	2422669	et	3	main
võis	doc_464301607715_item	2422676	et	4	main
mõelda	doc_464301607715_item	2422707	et	4	main
kodukandis	doc_464301607715_item	2422712	et	3	main
toimub	doc_464301607715_item	2422714	et	3	main
kirjandusolümpiaad	doc_464301607715_item	2422716	et	3	main
aastal	doc_464301607715_item	2422719	et	3	main
oli	doc_464301607715_item	2422720	et	3	main
õpilastele	doc_464301607715_item	2422726	et	4	main
sisukat	doc_464301607715_item	2422732	et	3	main
kes	doc_464301607715_item	2422740	et	4	main
joostes	doc_464301607715_item	2422743	et	4	main
et	doc_464301607715_item	2422746	et	3	main
kuhu	doc_464301607715_item	2422748	et	3	main
suured	doc_464301607715_item	2422754	et	3	main
mitukümmend	doc_464301607715_item	2422768	et	4	main
tõus	doc_464301607715_item	2422771	et	4	main
sillast	doc_464301607715_item	2422772	et	4	main
selleni	doc_464301607715_item	2422773	et	3	main
lähemalt	doc_464301607716_item	2422811	et	4	main
te	doc_464301607716_item	2422815	et	4	main
pakume	doc_464301607716_item	2422822	et	3	main
kellaseppale	doc_464301607716_item	2422824	et	4	main
neljandal	doc_464301607716_item	2422840	et	3	main
kursuses	doc_464301607716_item	2422841	et	3	main
sõitke	doc_464301607716_item	2422844	et	3	main
vasakule	doc_464301607716_item	2422849	et	4	main
saate	doc_464301607716_item	2422852	et	4	main
trammiga	doc_464301607716_item	2422853	et	3	main
nr	doc_464301607716_item	2422854	et	4	main
3	doc_464301607716_item	2422855	et	2	main
11	doc_464301607716_item	2422856	et	2	main
pilet	doc_464301607716_item	2422857	et	3	main
ole	doc_464301607716_item	2422865	et	4	main
ei	doc_464301607716_item	2422872	et	4	main
üle	doc_464301607716_item	2422876	et	3	main
14	doc_464301607716_item	2422879	et	2	main
sõitke	doc_464301607716_item	2422881	et	3	main
augustis	doc_464301607716_item	2422917	et	3	main
palju	doc_464301607716_item	2422920	et	4	main
ning	doc_464301607716_item	2422922	et	3	main
mille	doc_464301607716_item	2422935	et	3	main
tulnud	doc_464301607715_item	2422620	et	4	main
metsa	doc_464301607715_item	2422637	et	4	main
ja	doc_464301607715_item	2422647	et	3	main
et	doc_464301607715_item	2422650	et	3	main
poiss	doc_464301607715_item	2422656	et	3	main
ei	doc_464301607715_item	2422657	et	4	main
seisa	doc_464301607715_item	2422658	et	4	main
pudeliski	doc_464301607715_item	2422659	et	3	main
4	doc_464301607715_item	2422660	et	2	main
juhtimiseks	doc_464301607715_item	2422706	et	4	main
praegu	doc_464301607715_item	2422710	et	3	main
tema	doc_464301607715_item	2422711	et	4	main
mis	doc_464301607715_item	2422717	et	4	main
sel	doc_464301607715_item	2422718	et	3	main
harjutus	doc_464301607715_item	2422613	et	4	main
1	doc_464301607715_item	2422614	et	2	main
teadsin	doc_464301607715_item	2422615	et	3	main
et	doc_464301607715_item	2422616	et	3	main
asus	doc_464301607715_item	2422636	et	4	main
3	doc_464301607715_item	2422639	et	2	main
kaheteistkümne	doc_464301607715_item	2422642	et	4	main
elav	doc_464301607715_item	2422646	et	4	main
läbi	doc_464301607715_item	2422661	et	4	main
vabriku	doc_464301607715_item	2422662	et	3	main
tuli	doc_464301607715_item	2422665	et	4	main
ühes	doc_464301607715_item	2422670	et	4	main
otsas	doc_464301607715_item	2422671	et	4	main
kõrvale	doc_464301607715_item	2422705	et	4	main
3igaaastane	doc_464301607715_item	2422715	et	4	main
teemaline	doc_464301607715_item	2422722	et	4	main
pakkus	doc_464301607715_item	2422723	et	3	main
mistõttu	doc_464301607715_item	2422729	et	3	main
esitati	doc_464301607715_item	2422730	et	4	main
tagaaetavat	doc_464301607715_item	2422738	et	4	main
metslooma	doc_464301607715_item	2422739	et	4	main
välja	doc_464301607715_item	2422742	et	4	main
hallid	doc_464301607715_item	2422755	et	4	main
soolamisruum	doc_464301607715_item	2422766	et	3	main
kala	doc_464301607715_item	2422776	et	4	main
sõpra	doc_464301607716_item	2422810	et	4	main
tulla	doc_464301607716_item	2422820	et	3	main
9	doc_464301607716_item	2422843	et	2	main
ristmiku	doc_464301607716_item	2422846	et	4	main
10	doc_464301607716_item	2422850	et	2	main
trahvi	doc_464301607716_item	2422860	et	4	main
maksma	doc_464301607716_item	2422861	et	3	main
kohapeal	doc_464301607716_item	2422875	et	3	main
tänava	doc_464301607716_item	2422877	et	4	main
metsas	doc_464301607716_item	2422919	et	3	main
külalisena	doc_464301607715_item	2422621	et	4	main
kohe	doc_464301607715_item	2422630	et	4	main
aastane	doc_464301607715_item	2422643	et	4	main
poisijõnglane	doc_464301607715_item	2422644	et	3	main
teotahteline	doc_464301607715_item	2422648	et	4	main
armastati	doc_464301607715_item	2422653	et	3	main
kivist	doc_464301607715_item	2422663	et	4	main
pöidla	doc_464301607715_item	2422666	et	3	main
raudtoru	doc_464301607715_item	2422668	et	4	main
saada	doc_464301607715_item	2422677	et	4	main
et	doc_464301607715_item	2422678	et	3	main
sellega	doc_464301607715_item	2422679	et	3	main
piimanõusid	doc_464301607715_item	2422680	et	3	main
pesta	doc_464301607715_item	2422681	et	4	main
1	doc_464301607715_item	2422682	et	2	main
tüürimees	doc_464301607715_item	2422683	et	4	main
astus	doc_464301607715_item	2422684	et	3	main
raadioaparaadi	doc_464301607715_item	2422685	et	3	main
juurde	doc_464301607715_item	2422686	et	4	main
mis	doc_464301607715_item	2422687	et	4	main
oli	doc_464301607715_item	2422688	et	3	main
üles	doc_464301607715_item	2422689	et	3	main
seatud	doc_464301607715_item	2422690	et	4	main
roolikambrisse	doc_464301607715_item	2422691	et	3	main
kuhu	doc_464301607715_item	2422692	et	3	main
viis	doc_464301607715_item	2422693	et	4	main
omalaadne	doc_464301607715_item	2422694	et	3	main
keerd	doc_464301607715_item	2422695	et	3	main
trepp	doc_464301607715_item	2422696	et	3	main
2	doc_464301607715_item	2422697	et	2	main
kui	doc_464301607715_item	2422698	et	3	main
külmavärinad	doc_464301607715_item	2422699	et	3	main
väljakannatamatuks	doc_464301607715_item	2422700	et	3	main
muutusid	doc_464301607715_item	2422701	et	4	main
püüdis	doc_464301607715_item	2422702	et	3	main
ta	doc_464301607715_item	2422703	et	4	main
tähelepanu	doc_464301607715_item	2422704	et	4	main
kohta	doc_464301607715_item	2422652	et	4	main
see	doc_464301607715_item	2422655	et	3	main
otsaseina	doc_464301607715_item	2422664	et	4	main
olevast	doc_464301607715_item	2422672	et	4	main
kraanist	doc_464301607715_item	2422673	et	3	main
tulipalavat	doc_464301607715_item	2422674	et	3	main
vett	doc_464301607715_item	2422675	et	3	main
mis	doc_464301607715_item	2422709	et	4	main
gailiti	doc_464301607715_item	2422721	et	4	main
palju	doc_464301607715_item	2422727	et	4	main
huvi	doc_464301607715_item	2422728	et	4	main
seisatab	doc_464301607715_item	2422745	et	3	main
5	doc_464301607715_item	2422753	et	2	main
meetrit	doc_464301607715_item	2422769	et	3	main
tuli	doc_464301607715_item	2422777	et	4	main
ülesvedada	doc_464301607715_item	2422779	et	4	main
tahaksin	doc_464301607716_item	2422808	et	3	main
kas	doc_464301607716_item	2422814	et	3	main
homme	doc_464301607716_item	2422817	et	3	main
sellest	doc_464301607715_item	2422708	et	4	main
muhu-saarel	doc_464301607715_item	2422713	et	3	main
4	doc_464301607715_item	2422734	et	2	main
ta	doc_464301607715_item	2422735	et	4	main
tuletas	doc_464301607715_item	2422736	et	3	main
meelde	doc_464301607715_item	2422737	et	3	main
vaadata	doc_464301607715_item	2422747	et	4	main
poole	doc_464301607715_item	2422749	et	4	main
parem	doc_464301607715_item	2422750	et	4	main
oleks	doc_464301607715_item	2422751	et	3	main
põgeneda	doc_464301607715_item	2422752	et	3	main
lendavad	doc_464301607715_item	2422757	et	4	main
kolmnurkses	doc_464301607715_item	2422759	et	3	main
rivis	doc_464301607715_item	2422760	et	3	main
kaunisjärsk	doc_464301607715_item	2422774	et	3	main
kuid	doc_464301607715_item	2422775	et	4	main
kastides	doc_464301607715_item	2422778	et	3	main
käsitsi	doc_464301607715_item	2422780	et	3	main
4	doc_464301607716_item	2422813	et	2	main
saate	doc_464301607716_item	2422816	et	4	main
on	doc_464301607716_item	2422827	et	4	main
kaks	doc_464301607716_item	2422828	et	3	main
uut	doc_464301607716_item	2422829	et	3	main
pintsakud	doc_464301607716_item	2422830	et	3	main
7	doc_464301607716_item	2422831	et	2	main
püdsid	doc_464301607716_item	2422833	et	4	main
8	doc_464301607716_item	2422836	et	2	main
piret	doc_464301607716_item	2422837	et	4	main
järgmise	doc_464301607716_item	2422845	et	3	main
keerake	doc_464301607716_item	2422848	et	3	main
pidi	doc_464301607716_item	2422859	et	4	main
meeldiv	doc_464301607716_item	2422867	et	4	main
parki	doc_464301607716_item	2422869	et	4	main
jalutada	doc_464301607716_item	2422870	et	3	main
käivad	doc_464301607716_item	2422924	et	4	main
korjama	doc_464301607716_item	2422926	et	3	main
suurete	doc_464301607716_item	2422927	et	3	main
korvidesse	doc_464301607716_item	2422928	et	3	main
iga	doc_464301607716_item	2422930	et	4	main
sünnipäeval	doc_464301607716_item	2422931	et	3	main
ma	doc_464301607716_item	2422932	et	3	main
pähklidega	doc_464301607716_item	2422937	et	4	main
meie	doc_464301607715_item	2422724	et	4	main
kooli	doc_464301607715_item	2422725	et	4	main
mitu	doc_464301607715_item	2422731	et	4	main
uurimistööd	doc_464301607715_item	2422733	et	4	main
metsast	doc_464301607715_item	2422741	et	4	main
silmapilguks	doc_464301607715_item	2422744	et	4	main
linnud	doc_464301607715_item	2422756	et	3	main
korrapärases	doc_464301607715_item	2422758	et	4	main
lõuna	doc_464301607715_item	2422761	et	4	main
poole	doc_464301607715_item	2422762	et	4	main
6	doc_464301607715_item	2422763	et	2	main
kaalumis	doc_464301607715_item	2422764	et	3	main
ja	doc_464301607715_item	2422765	et	3	main
oli	doc_464301607715_item	2422767	et	3	main
eemal	doc_464301607715_item	2422770	et	3	main
7	doc_464301607715_item	2422781	et	2	main
kui	doc_464301607715_item	2422782	et	3	main
heinad	doc_464301607715_item	2422783	et	3	main
ja	doc_464301607715_item	2422784	et	3	main
haodpuud	doc_464301607715_item	2422785	et	4	main
kojuveetud	doc_464301607715_item	2422786	et	3	main
oli	doc_464301607715_item	2422787	et	3	main
pärast	doc_464301607715_item	2422788	et	4	main
tööpäeva	doc_464301607715_item	2422789	et	4	main
söögilauda	doc_464301607715_item	2422790	et	4	main
istudes	doc_464301607715_item	2422791	et	4	main
kõigil	doc_464301607715_item	2422792	et	4	main
täismehe	doc_464301607715_item	2422793	et	3	main
tunne	doc_464301607715_item	2422794	et	4	main
harjutus	doc_464301607716_item	2422795	et	4	main
1	doc_464301607716_item	2422796	et	2	main
ma	doc_464301607716_item	2422797	et	3	main
lugen	doc_464301607716_item	2422798	et	4	main
huvitavat	doc_464301607716_item	2422799	et	4	main
raamatut	doc_464301607716_item	2422800	et	3	main
2	doc_464301607716_item	2422801	et	2	main
nad	doc_464301607716_item	2422802	et	3	main
pidavad	doc_464301607716_item	2422803	et	4	main
sõitma	doc_464301607716_item	2422804	et	3	main
lasnamäele	doc_464301607716_item	2422805	et	3	main
3	doc_464301607716_item	2422806	et	2	main
ma	doc_464301607716_item	2422807	et	3	main
sinu	doc_464301607716_item	2422809	et	3	main
tutvuda	doc_464301607716_item	2422812	et	3	main
meie	doc_464301607716_item	2422818	et	4	main
büroose	doc_464301607716_item	2422819	et	4	main
5	doc_464301607716_item	2422821	et	2	main
keldris	doc_464301607716_item	2422834	et	3	main
tehnikaülikoolis	doc_464301607716_item	2422839	et	4	main
12	doc_464301607716_item	2422862	et	2	main
pimedas	doc_464301607716_item	2422863	et	3	main
eriti	doc_464301607716_item	2422866	et	3	main
läbi	doc_464301607716_item	2422868	et	4	main
13	doc_464301607716_item	2422871	et	2	main
tohi	doc_464301607716_item	2422873	et	4	main
minna	doc_464301607716_item	2422878	et	3	main
ärge	doc_464301607716_item	2422880	et	3	main
kõnniteepeal	doc_464301607716_item	2422882	et	3	main
jalgrattaga	doc_464301607716_item	2422883	et	3	main
3	doc_464301607716_item	2422916	et	2	main
on	doc_464301607716_item	2422918	et	4	main
tordi	doc_464301607716_item	2422934	et	3	main
kaunistan	doc_464301607716_item	2422936	et	3	main
tööd	doc_464301607716_item	2422823	et	4	main
6	doc_464301607716_item	2422825	et	2	main
mihkelil	doc_464301607716_item	2422826	et	3	main
kassid	doc_464301607716_item	2422832	et	3	main
hiiri	doc_464301607716_item	2422835	et	4	main
õpib	doc_464301607716_item	2422838	et	3	main
ärijuhtimist	doc_464301607716_item	2422842	et	3	main
ja	doc_464301607716_item	2422847	et	3	main
kadriorgu	doc_464301607716_item	2422851	et	4	main
reisija	doc_464301607716_item	2422858	et	4	main
ei	doc_464301607716_item	2422864	et	4	main
vale	doc_464301607716_item	2422874	et	4	main
15	doc_464301607716_item	2422884	et	2	main
lähme	doc_464301607716_item	2422885	et	3	main
raamatukokku	doc_464301607716_item	2422886	et	4	main
värskeid	doc_464301607716_item	2422887	et	4	main
ajalehi	doc_464301607716_item	2422888	et	4	main
lugema	doc_464301607716_item	2422889	et	4	main
16	doc_464301607716_item	2422890	et	2	main
moskva	doc_464301607716_item	2422891	et	4	main
rong	doc_464301607716_item	2422892	et	3	main
saabus	doc_464301607716_item	2422893	et	3	main
balti	doc_464301607716_item	2422894	et	3	main
kümme	doc_464301607716_item	2422896	et	3	main
jaamas	doc_464301607716_item	2422895	et	3	main
minutid	doc_464301607716_item	2422897	et	3	main
varem	doc_464301607716_item	2422898	et	4	main
1	doc_464301607716_item	2422899	et	2	main
juulis	doc_464301607716_item	2422900	et	3	main
korjatakse	doc_464301607716_item	2422901	et	3	main
palju	doc_464301607716_item	2422902	et	4	main
maasikaid	doc_464301607716_item	2422903	et	3	main
millest	doc_464301607716_item	2422904	et	3	main
keedakse	doc_464301607716_item	2422905	et	3	main
moosi	doc_464301607716_item	2422906	et	4	main
2	doc_464301607716_item	2422907	et	2	main
külalapsed	doc_464301607716_item	2422909	et	3	main
kõik	doc_464301607716_item	2422908	et	4	main
mängivad	doc_464301607716_item	2422910	et	4	main
koos	doc_464301607716_item	2422911	et	4	main
palli	doc_464301607716_item	2422912	et	4	main
ja	doc_464301607716_item	2422913	et	3	main
sõidavad	doc_464301607716_item	2422914	et	3	main
jalgrattadega	doc_464301607716_item	2422915	et	4	main
ja	doc_464301607716_item	2422938	et	3	main
martsipanidega	doc_464301607716_item	2422939	et	3	main
marju	doc_464301607716_item	2422921	et	3	main
inimesed	doc_464301607716_item	2422923	et	3	main
neid	doc_464301607716_item	2422925	et	4	main
4	doc_464301607716_item	2422929	et	2	main
küpsetan	doc_464301607716_item	2422933	et	3	main
essee	doc_464301607720_item	2423243	et	4	main
suur	doc_464301607720_item	2423249	et	3	main
on	doc_464301607720_item	2423251	et	4	main
diivanilaual	doc_464301607720_item	2423260	et	4	main
vaas	doc_464301607720_item	2423264	et	3	main
vasis	doc_464301607720_item	2423265	et	3	main
on	doc_464301607720_item	2423266	et	4	main
pilti	doc_464301607720_item	2423280	et	4	main
on	doc_464301607720_item	2423282	et	4	main
raadio	doc_464301607720_item	2423294	et	4	main
on	doc_464301607720_item	2423302	et	4	main
elutoad	doc_464301607720_item	2423309	et	3	main
kodulilled	doc_464301607720_item	2423311	et	3	main
on	doc_464301607720_item	2423248	et	4	main
tugitooli	doc_464301607720_item	2423254	et	4	main
sektsioonkapp	doc_464301607720_item	2423259	et	4	main
kuus	doc_464301607720_item	2423279	et	4	main
pilti	doc_464301607720_item	2423284	et	4	main
üks	doc_464301607720_item	2423287	et	3	main
toas	doc_464301607720_item	2423289	et	3	main
kinni	doc_464301607720_item	2423296	et	3	main
on	doc_464301607720_item	2423310	et	4	main
kaks	doc_464301607720_item	2423317	et	3	main
ma	doc_464301607721_item	2423322	et	3	main
töötan	doc_464301607721_item	2423323	et	3	main
aga	doc_464301607721_item	2423325	et	3	main
minu	doc_464301607721_item	2423326	et	3	main
mees	doc_464301607721_item	2423327	et	4	main
raske	doc_464301607721_item	2423339	et	4	main
minu	doc_464301607721_item	2423344	et	3	main
kolleegidega	doc_464301607721_item	2423353	et	3	main
me	doc_464301607721_item	2423372	et	4	main
elasime	doc_464301607721_item	2423373	et	3	main
ja	doc_464301607721_item	2423374	et	3	main
töötasime	doc_464301607721_item	2423375	et	3	main
kiievis	doc_464301607721_item	2423376	et	4	main
eluga	doc_464301607721_item	2423383	et	3	main
rahul	doc_464301607721_item	2423385	et	4	main
meie	doc_464301607722_item	2423387	et	4	main
puhkepäevast	doc_464301607722_item	2423388	et	4	main
sauna	doc_464301607722_item	2423396	et	4	main
pirita	doc_464301607722_item	2423399	et	4	main
sõbrad	doc_464301607722_item	2423411	et	3	main
meie	doc_464301607722_item	2423414	et	4	main
me	doc_464301607722_item	2423416	et	4	main
on	doc_464301607723_item	2423427	et	4	main
meil	doc_464301607723_item	2423430	et	4	main
majas	doc_464301607723_item	2423431	et	3	main
56	doc_464301607723_item	2423433	et	2	main
teiste	doc_464301607723_item	2423438	et	4	main
korteris	doc_464301607723_item	2423440	et	3	main
lauda	doc_464301607723_item	2423454	et	4	main
lauda	doc_464301607723_item	2423459	et	4	main
minu	doc_464301607720_item	2423246	et	3	main
diivan	doc_464301607720_item	2423252	et	3	main
teler	doc_464301607720_item	2423256	et	3	main
on	doc_464301607720_item	2423278	et	4	main
seinal	doc_464301607720_item	2423281	et	3	main
väiked	doc_464301607720_item	2423283	et	4	main
radio	doc_464301607720_item	2423292	et	4	main
õhtul	doc_464301607720_item	2423293	et	3	main
lahti	doc_464301607720_item	2423300	et	4	main
jures	doc_464301607720_item	2423304	et	4	main
kelled	doc_464301607720_item	2423308	et	4	main
aknet	doc_464301607720_item	2423318	et	3	main
xxx-es	doc_464301607721_item	2423324	et	4	main
huvitav	doc_464301607721_item	2423340	et	4	main
aga	doc_464301607721_item	2423343	et	3	main
mehe	doc_464301607721_item	2423345	et	3	main
meeldib	doc_464301607721_item	2423350	et	3	main
töötada	doc_464301607721_item	2423351	et	3	main
sest	doc_464301607721_item	2423354	et	4	main
kolleegid	doc_464301607721_item	2423356	et	3	main
meeldivad	doc_464301607721_item	2423359	et	4	main
ja	doc_464301607721_item	2423360	et	3	main
professionaalsed	doc_464301607721_item	2423361	et	3	main
inimesed	doc_464301607721_item	2423362	et	3	main
praegu	doc_464301607721_item	2423363	et	3	main
me	doc_464301607721_item	2423364	et	4	main
elame	doc_464301607721_item	2423365	et	3	main
xx-al	doc_464301607721_item	2423366	et	4	main
tallinnas	doc_464301607721_item	2423369	et	4	main
aga	doc_464301607721_item	2423370	et	3	main
varem	doc_464301607721_item	2423371	et	4	main
oleme	doc_464301607721_item	2423381	et	3	main
üleeile	doc_464301607722_item	2423391	et	3	main
sõprad	doc_464301607722_item	2423392	et	4	main
kutsid	doc_464301607722_item	2423394	et	3	main
olis	doc_464301607722_item	2423397	et	4	main
meie	doc_464301607722_item	2423410	et	4	main
kojus	doc_464301607722_item	2423415	et	4	main
juuasime	doc_464301607722_item	2423417	et	4	main
essee	doc_464301607723_item	2423422	et	4	main
minu	doc_464301607723_item	2423423	et	3	main
korteri	doc_464301607723_item	2423424	et	3	main
korter	doc_464301607723_item	2423436	et	3	main
korrusel	doc_464301607723_item	2423439	et	3	main
tuba	doc_464301607723_item	2423443	et	4	main
suur	doc_464301607723_item	2423445	et	3	main
1	doc_464301607723_item	2423455	et	2	main
piir	doc_464301607723_item	2423458	et	3	main
tooli	doc_464301607723_item	2423461	et	4	main
meie	doc_464301607724_item	2423463	et	4	main
köök	doc_464301607724_item	2423464	et	3	main
köökis	doc_464301607724_item	2423479	et	4	main
laelamp	doc_464301607724_item	2423480	et	3	main
köökis	doc_464301607724_item	2423491	et	4	main
kappis	doc_464301607724_item	2423496	et	3	main
raamatud	doc_464301607724_item	2423521	et	4	main
magamistuba	doc_464301607725_item	2423526	et	4	main
põrandal	doc_464301607725_item	2423544	et	3	main
on	doc_464301607725_item	2423557	et	4	main
minu	doc_464301607720_item	2423244	et	3	main
elutuba	doc_464301607720_item	2423247	et	4	main
seal	doc_464301607720_item	2423250	et	4	main
on	doc_464301607720_item	2423261	et	4	main
ajalehed	doc_464301607720_item	2423262	et	3	main
ja	doc_464301607720_item	2423263	et	3	main
lilled	doc_464301607720_item	2423267	et	3	main
seksioonkapis	doc_464301607720_item	2423268	et	4	main
on	doc_464301607720_item	2423269	et	4	main
raamatud	doc_464301607720_item	2423270	et	4	main
ja	doc_464301607720_item	2423271	et	3	main
nõud	doc_464301607720_item	2423272	et	3	main
toas	doc_464301607720_item	2423285	et	3	main
on	doc_464301607720_item	2423295	et	4	main
aga	doc_464301607720_item	2423297	et	3	main
teler	doc_464301607720_item	2423298	et	3	main
on	doc_464301607720_item	2423299	et	4	main
toas	doc_464301607720_item	2423305	et	3	main
on	doc_464301607720_item	2423313	et	4	main
ja	doc_464301607720_item	2423316	et	3	main
töö	doc_464301607721_item	2423321	et	4	main
on	doc_464301607721_item	2423338	et	4	main
oma	doc_464301607721_item	2423352	et	4	main
on	doc_464301607721_item	2423357	et	4	main
energilised	doc_464301607721_item	2423358	et	3	main
võib	doc_464301607721_item	2423377	et	3	main
öelda	doc_464301607721_item	2423378	et	4	main
et	doc_464301607721_item	2423379	et	3	main
me	doc_464301607721_item	2423380	et	4	main
üpris	doc_464301607721_item	2423384	et	3	main
nad	doc_464301607722_item	2423393	et	3	main
saunal	doc_464301607722_item	2423395	et	3	main
käisid	doc_464301607722_item	2423412	et	4	main
süüasime	doc_464301607722_item	2423420	et	4	main
suppi	doc_464301607722_item	2423421	et	4	main
meie	doc_464301607723_item	2423435	et	4	main
3	doc_464301607723_item	2423442	et	2	main
ja	doc_464301607723_item	2423446	et	3	main
väike	doc_464301607723_item	2423448	et	4	main
korteris	doc_464301607723_item	2423449	et	3	main
on	doc_464301607723_item	2423450	et	4	main
5	doc_464301607723_item	2423451	et	2	main
akent	doc_464301607723_item	2423452	et	3	main
3	doc_464301607723_item	2423453	et	2	main
essee	doc_464301607724_item	2423462	et	4	main
väike	doc_464301607724_item	2423467	et	4	main
köök	doc_464301607724_item	2423468	et	3	main
üks	doc_464301607724_item	2423469	et	3	main
laud	doc_464301607724_item	2423470	et	4	main
ja	doc_464301607724_item	2423471	et	3	main
neli	doc_464301607724_item	2423472	et	3	main
tooli	doc_464301607724_item	2423473	et	4	main
on	doc_464301607724_item	2423481	et	4	main
on	doc_464301607724_item	2423489	et	4	main
on	doc_464301607724_item	2423492	et	4	main
köökis	doc_464301607724_item	2423497	et	4	main
ja	doc_464301607724_item	2423522	et	3	main
on	doc_464301607725_item	2423528	et	4	main
seal	doc_464301607725_item	2423538	et	4	main
laualamp	doc_464301607725_item	2423545	et	3	main
ei	doc_464301607725_item	2423549	et	4	main
üks	doc_464301607725_item	2423558	et	3	main
on	doc_464301607725_item	2423561	et	4	main
üks	doc_464301607725_item	2423566	et	3	main
ja	doc_464301607725_item	2423568	et	3	main
öökappi	doc_464301607725_item	2423570	et	4	main
aga	doc_464301607725_item	2423577	et	3	main
on	doc_464301607725_item	2423579	et	4	main
on	doc_464301607725_item	2423582	et	4	main
magamistuba	doc_464301607725_item	2423589	et	4	main
asub	doc_464301607725_item	2423590	et	3	main
elutuba	doc_464301607720_item	2423245	et	4	main
kaks	doc_464301607720_item	2423253	et	3	main
diivanilaud	doc_464301607720_item	2423255	et	4	main
kuus	doc_464301607720_item	2423257	et	4	main
tooli	doc_464301607720_item	2423258	et	4	main
põrandal	doc_464301607720_item	2423273	et	3	main
on	doc_464301607720_item	2423274	et	4	main
suur	doc_464301607720_item	2423275	et	3	main
vaip	doc_464301607720_item	2423276	et	3	main
toas	doc_464301607720_item	2423277	et	3	main
on	doc_464301607720_item	2423286	et	4	main
laelamp	doc_464301607720_item	2423288	et	3	main
on	doc_464301607720_item	2423290	et	4	main
veel	doc_464301607720_item	2423291	et	4	main
raadio	doc_464301607720_item	2423301	et	4	main
teleri	doc_464301607720_item	2423303	et	3	main
on	doc_464301607720_item	2423306	et	4	main
kaks	doc_464301607720_item	2423307	et	3	main
toas	doc_464301607720_item	2423312	et	3	main
üks	doc_464301607720_item	2423314	et	3	main
uks	doc_464301607720_item	2423315	et	3	main
essee	doc_464301607721_item	2423319	et	4	main
minu	doc_464301607721_item	2423320	et	3	main
firmas	doc_464301607721_item	2423330	et	3	main
meile	doc_464301607721_item	2423331	et	4	main
meeldib	doc_464301607721_item	2423332	et	3	main
oma	doc_464301607721_item	2423333	et	4	main
tööd	doc_464301607721_item	2423334	et	4	main
teha	doc_464301607721_item	2423335	et	3	main
minu	doc_464301607721_item	2423336	et	3	main
töö	doc_464301607721_item	2423337	et	4	main
meie	doc_464301607721_item	2423355	et	4	main
ja	doc_464301607721_item	2423367	et	3	main
töötame	doc_464301607721_item	2423368	et	3	main
oma	doc_464301607721_item	2423382	et	4	main
essee	doc_464301607722_item	2423386	et	4	main
jogil	doc_464301607722_item	2423398	et	4	main
me	doc_464301607722_item	2423400	et	4	main
käisime	doc_464301607722_item	2423401	et	3	main
saunal	doc_464301607722_item	2423402	et	3	main
autos	doc_464301607722_item	2423403	et	3	main
me	doc_464301607722_item	2423404	et	4	main
olime	doc_464301607722_item	2423405	et	3	main
saunal	doc_464301607722_item	2423406	et	3	main
kuuni	doc_464301607722_item	2423407	et	3	main
eile	doc_464301607722_item	2423413	et	3	main
asub	doc_464301607723_item	2423437	et	3	main
laia	doc_464301607723_item	2423456	et	4	main
6	doc_464301607723_item	2423460	et	2	main
meil	doc_464301607724_item	2423465	et	4	main
on	doc_464301607724_item	2423474	et	4	main
laes	doc_464301607724_item	2423482	et	4	main
üks	doc_464301607724_item	2423483	et	3	main
pilt	doc_464301607724_item	2423484	et	3	main
köökis	doc_464301607724_item	2423490	et	4	main
essee	doc_464301607725_item	2423524	et	4	main
lampi	doc_464301607725_item	2423541	et	4	main
põrandalamp	doc_464301607725_item	2423542	et	3	main
on	doc_464301607725_item	2423546	et	4	main
on	doc_464301607725_item	2423554	et	4	main
lilled	doc_464301607725_item	2423555	et	3	main
väike	doc_464301607725_item	2423562	et	4	main
on	doc_464301607725_item	2423565	et	4	main
riidekapp	doc_464301607725_item	2423567	et	3	main
kaks	doc_464301607725_item	2423569	et	3	main
ja	doc_464301607725_item	2423571	et	3	main
teler	doc_464301607725_item	2423576	et	3	main
poole	doc_464301607725_item	2423592	et	4	main
töötab	doc_464301607721_item	2423328	et	3	main
ühis	doc_464301607721_item	2423329	et	4	main
ja	doc_464301607721_item	2423341	et	3	main
tasuv	doc_464301607721_item	2423342	et	4	main
töö	doc_464301607721_item	2423346	et	4	main
intensiivne	doc_464301607721_item	2423348	et	3	main
on	doc_464301607721_item	2423347	et	4	main
meile	doc_464301607721_item	2423349	et	4	main
me	doc_464301607722_item	2423389	et	4	main
olime	doc_464301607722_item	2423390	et	3	main
üksteist	doc_464301607722_item	2423408	et	4	main
õhtul	doc_464301607722_item	2423409	et	3	main
tee	doc_464301607722_item	2423418	et	4	main
ja	doc_464301607722_item	2423419	et	3	main
meie	doc_464301607723_item	2423425	et	4	main
majas	doc_464301607723_item	2423426	et	3	main
16	doc_464301607723_item	2423428	et	2	main
korterit	doc_464301607723_item	2423429	et	3	main
elab	doc_464301607723_item	2423432	et	3	main
inimest	doc_464301607723_item	2423434	et	3	main
on	doc_464301607723_item	2423441	et	4	main
1	doc_464301607723_item	2423444	et	2	main
2	doc_464301607723_item	2423447	et	2	main
ja	doc_464301607723_item	2423457	et	3	main
on	doc_464301607724_item	2423466	et	4	main
aken	doc_464301607724_item	2423477	et	3	main
on	doc_464301607724_item	2423478	et	4	main
köökis	doc_464301607724_item	2423486	et	4	main
5	doc_464301607724_item	2423487	et	2	main
lille	doc_464301607724_item	2423488	et	4	main
nõud	doc_464301607724_item	2423494	et	3	main
on	doc_464301607724_item	2423495	et	4	main
on	doc_464301607724_item	2423498	et	4	main
9	doc_464301607724_item	2423499	et	2	main
sektsioonikapi	doc_464301607724_item	2423500	et	4	main
elektripliit	doc_464301607724_item	2423501	et	3	main
pliidi	doc_464301607724_item	2423502	et	3	main
ja	doc_464301607724_item	2423503	et	3	main
külmkapp	doc_464301607724_item	2423504	et	3	main
ei	doc_464301607724_item	2423506	et	4	main
köökis	doc_464301607724_item	2423505	et	4	main
ole	doc_464301607724_item	2423507	et	4	main
üks	doc_464301607724_item	2423508	et	3	main
ramatukapi	doc_464301607724_item	2423509	et	4	main
asub	doc_464301607724_item	2423510	et	3	main
akna	doc_464301607724_item	2423511	et	3	main
juures	doc_464301607724_item	2423512	et	4	main
elektriraadiator	doc_464301607724_item	2423513	et	4	main
on	doc_464301607724_item	2423514	et	4	main
köökis	doc_464301607724_item	2423515	et	4	main
ramatud	doc_464301607724_item	2423516	et	4	main
on	doc_464301607724_item	2423517	et	4	main
kapis	doc_464301607724_item	2423518	et	3	main
sektsioonikapis	doc_464301607724_item	2423519	et	4	main
on	doc_464301607724_item	2423520	et	4	main
meie	doc_464301607725_item	2423525	et	4	main
aken	doc_464301607725_item	2423535	et	3	main
on	doc_464301607725_item	2423536	et	4	main
magamistoas	doc_464301607725_item	2423537	et	3	main
on	doc_464301607725_item	2423539	et	4	main
kaks	doc_464301607725_item	2423540	et	3	main
laual	doc_464301607725_item	2423547	et	3	main
magamistoas	doc_464301607725_item	2423548	et	3	main
ole	doc_464301607725_item	2423550	et	4	main
seinal	doc_464301607725_item	2423556	et	3	main
pilt	doc_464301607725_item	2423559	et	3	main
vaip	doc_464301607725_item	2423563	et	3	main
voodi	doc_464301607725_item	2423572	et	4	main
toas	doc_464301607725_item	2423573	et	3	main
on	doc_464301607725_item	2423574	et	4	main
ta	doc_464301607725_item	2423578	et	4	main
kinni	doc_464301607725_item	2423580	et	3	main
teler	doc_464301607725_item	2423581	et	3	main
köökis	doc_464301607724_item	2423475	et	4	main
üks	doc_464301607724_item	2423476	et	3	main
on	doc_464301607724_item	2423485	et	4	main
nõud	doc_464301607724_item	2423493	et	3	main
nõud	doc_464301607724_item	2423523	et	3	main
meil	doc_464301607725_item	2423527	et	4	main
väike	doc_464301607725_item	2423529	et	4	main
magamistuba	doc_464301607725_item	2423530	et	4	main
üks	doc_464301607725_item	2423531	et	3	main
uks	doc_464301607725_item	2423532	et	3	main
ja	doc_464301607725_item	2423533	et	3	main
üks	doc_464301607725_item	2423534	et	3	main
on	doc_464301607725_item	2423543	et	4	main
laelampi	doc_464301607725_item	2423551	et	4	main
seal	doc_464301607725_item	2423552	et	4	main
aknal	doc_464301607725_item	2423553	et	3	main
seal	doc_464301607725_item	2423564	et	4	main
veel	doc_464301607725_item	2423575	et	4	main
akna	doc_464301607725_item	2423583	et	3	main
juures	doc_464301607725_item	2423584	et	4	main
lääne	doc_464301607725_item	2423591	et	4	main
kahekorruselises	doc_464301607726_item	2423600	et	4	main
majas	doc_464301607726_item	2423601	et	3	main
kivi	doc_464301607726_item	2423602	et	4	main
teisel	doc_464301607726_item	2423603	et	4	main
korrusel	doc_464301607726_item	2423604	et	3	main
see	doc_464301607726_item	2423605	et	3	main
on	doc_464301607726_item	2423606	et	4	main
vana	doc_464301607726_item	2423607	et	4	main
maja	doc_464301607726_item	2423608	et	4	main
meie	doc_464301607726_item	2423609	et	4	main
majas	doc_464301607726_item	2423610	et	3	main
ei	doc_464301607726_item	2423611	et	4	main
ole	doc_464301607726_item	2423612	et	4	main
lift	doc_464301607726_item	2423613	et	3	main
ja	doc_464301607726_item	2423614	et	3	main
keskkütet	doc_464301607726_item	2423615	et	3	main
aga	doc_464301607726_item	2423616	et	3	main
ahjuküte	doc_464301607726_item	2423617	et	3	main
ja	doc_464301607726_item	2423618	et	3	main
elektriküte	doc_464301607726_item	2423619	et	3	main
on	doc_464301607726_item	2423620	et	4	main
me	doc_464301607726_item	2423621	et	4	main
ahjuküttega	doc_464301607726_item	2423623	et	3	main
majas	doc_464301607726_item	2423624	et	3	main
korter	doc_464301607726_item	2423626	et	3	main
korteris	doc_464301607726_item	2423632	et	3	main
ei	doc_464301607726_item	2423635	et	4	main
suur	doc_464301607726_item	2423637	et	3	main
suur	doc_464301607726_item	2423641	et	3	main
on	doc_464301607726_item	2423647	et	4	main
väiked	doc_464301607726_item	2423648	et	4	main
magamistuba	doc_464301607726_item	2423655	et	4	main
üks	doc_464301607726_item	2423656	et	3	main
uks	doc_464301607726_item	2423657	et	3	main
on	doc_464301607726_item	2423671	et	4	main
laual	doc_464301607726_item	2423672	et	3	main
magamistoas	doc_464301607726_item	2423673	et	3	main
seinal	doc_464301607726_item	2423677	et	3	main
üks	doc_464301607726_item	2423679	et	3	main
seal	doc_464301607726_item	2423681	et	4	main
riide	doc_464301607726_item	2423684	et	4	main
kaks	doc_464301607726_item	2423687	et	3	main
öökappi	doc_464301607726_item	2423688	et	4	main
ja	doc_464301607726_item	2423689	et	3	main
rahul	doc_464301607726_item	2423695	et	4	main
põrandal	doc_464301607725_item	2423560	et	3	main
kardinad	doc_464301607725_item	2423585	et	4	main
on	doc_464301607725_item	2423586	et	4	main
hele	doc_464301607725_item	2423587	et	3	main
roosad	doc_464301607725_item	2423588	et	4	main
meie	doc_464301607726_item	2423594	et	4	main
meie	doc_464301607726_item	2423625	et	4	main
kolmetoalises	doc_464301607726_item	2423631	et	4	main
umbes	doc_464301607726_item	2423642	et	4	main
tuba	doc_464301607726_item	2423646	et	4	main
ja	doc_464301607726_item	2423658	et	3	main
toas	doc_464301607726_item	2423663	et	3	main
kaks	doc_464301607726_item	2423665	et	3	main
on	doc_464301607726_item	2423678	et	4	main
xx	doc_464301607727_item	2423701	et	4	main
valdis	doc_464301607727_item	2423702	et	4	main
meie	doc_464301607727_item	2423728	et	4	main
sõidab	doc_464301607727_item	2423734	et	3	main
palju	doc_464301607727_item	2423735	et	4	main
bussid	doc_464301607727_item	2423737	et	3	main
ja	doc_464301607727_item	2423738	et	3	main
käivad	doc_464301607727_item	2423740	et	4	main
ühendus	doc_464301607727_item	2423742	et	4	main
on	doc_464301607727_item	2423744	et	4	main
hea	doc_464301607727_item	2423745	et	4	main
pool	doc_464301607727_item	2423748	et	4	main
linna	doc_464301607727_item	2423752	et	4	main
meie	doc_464301607727_item	2423763	et	4	main
meie	doc_464301607727_item	2423767	et	4	main
elan	doc_464301607727_item	2423773	et	3	main
lõhikut	doc_464301607727_item	2423775	et	3	main
xx-alt	doc_464301607728_item	2423782	et	4	main
sind	doc_464301607728_item	2423784	et	4	main
eest	doc_464301607728_item	2423786	et	4	main
sinu	doc_464301607728_item	2423787	et	3	main
kiri	doc_464301607728_item	2423788	et	3	main
rõõmustas	doc_464301607728_item	2423789	et	3	main
mind	doc_464301607728_item	2423790	et	4	main
elan	doc_464301607728_item	2423798	et	3	main
korteris	doc_464301607728_item	2423822	et	3	main
magatuba	doc_464301607728_item	2423826	et	4	main
lähadal	doc_464301607728_item	2423835	et	4	main
toolle	doc_464301607728_item	2423838	et	4	main
minutit	doc_464301607728_item	2423841	et	3	main
autoga	doc_464301607728_item	2423842	et	3	main
olen	doc_464301607728_item	2423844	et	3	main
olen	doc_464301607729_item	2423856	et	3	main
petersburgisse	doc_464301607729_item	2423858	et	4	main
ja	doc_464301607729_item	2423859	et	3	main
moskvale	doc_464301607729_item	2423860	et	4	main
petersburgis	doc_464301607729_item	2423869	et	4	main
räägivad	doc_464301607729_item	2423879	et	3	main
samuti	doc_464301607729_item	2423886	et	3	main
linn	doc_464301607729_item	2423890	et	3	main
essee	doc_464301607730_item	2423904	et	4	main
oleks	doc_464301607730_item	2423910	et	3	main
elu	doc_464301607730_item	2423917	et	4	main
parem	doc_464301607730_item	2423918	et	4	main
ma	doc_464301607730_item	2423919	et	3	main
kui	doc_464301607730_item	2423922	et	3	main
kui	doc_464301607730_item	2423924	et	3	main
kultuuriselt	doc_464301607730_item	2423932	et	4	main
tegeks	doc_464301607730_item	2423969	et	4	main
lihtsemaks	doc_464301607730_item	2423972	et	4	main
maadega	doc_464301607730_item	2423977	et	3	main
me	doc_464301607731_item	2423990	et	4	main
karli	doc_464301607731_item	2423992	et	4	main
kirikusse	doc_464301607731_item	2423993	et	4	main
tõnu	doc_464301607731_item	2423998	et	4	main
mägiga	doc_464301607731_item	2423999	et	4	main
seal	doc_464301607731_item	2424005	et	4	main
olnud	doc_464301607731_item	2424008	et	4	main
pühapäeval	doc_464301607731_item	2424015	et	3	main
puhkasin	doc_464301607731_item	2424018	et	3	main
essee	doc_464301607726_item	2423593	et	4	main
elame	doc_464301607726_item	2423622	et	3	main
on	doc_464301607726_item	2423627	et	4	main
soe	doc_464301607726_item	2423628	et	4	main
korter	doc_464301607726_item	2423634	et	3	main
on	doc_464301607726_item	2423640	et	4	main
umbes	doc_464301607726_item	2423649	et	4	main
9	doc_464301607726_item	2423650	et	2	main
üks	doc_464301607726_item	2423659	et	3	main
seal	doc_464301607726_item	2423662	et	4	main
on	doc_464301607726_item	2423664	et	4	main
on	doc_464301607726_item	2423682	et	4	main
üks	doc_464301607726_item	2423683	et	3	main
kapp	doc_464301607726_item	2423685	et	3	main
ja	doc_464301607726_item	2423686	et	3	main
xx-al	doc_464301607727_item	2423700	et	4	main
see	doc_464301607727_item	2423706	et	3	main
autotee	doc_464301607727_item	2423732	et	4	main
xx-alle	doc_464301607727_item	2423741	et	4	main
kesklinnaga	doc_464301607727_item	2423743	et	3	main
pärast	doc_464301607727_item	2423750	et	4	main
saan	doc_464301607727_item	2423753	et	4	main
bussiga	doc_464301607727_item	2423755	et	3	main
on	doc_464301607727_item	2423757	et	4	main
100	doc_464301607727_item	2423758	et	2	main
lähedal	doc_464301607727_item	2423762	et	4	main
majas	doc_464301607727_item	2423768	et	3	main
liiklusega	doc_464301607727_item	2423770	et	3	main
ma	doc_464301607727_item	2423772	et	3	main
väike	doc_464301607727_item	2423774	et	4	main
kallis	doc_464301607728_item	2423779	et	4	main
eesnimi	doc_464301607728_item	2423780	et	3	main
oma	doc_464301607728_item	2423791	et	4	main
kirjas	doc_464301607728_item	2423793	et	4	main
sa	doc_464301607728_item	2423794	et	3	main
küsisid	doc_464301607728_item	2423795	et	4	main
kuidas	doc_464301607728_item	2423796	et	3	main
ma	doc_464301607728_item	2423799	et	3	main
kolm	doc_464301607728_item	2423824	et	3	main
pargi	doc_464301607728_item	2423834	et	4	main
väga	doc_464301607728_item	2423847	et	3	main
külastanud	doc_464301607729_item	2423857	et	4	main
reisi	doc_464301607729_item	2423861	et	4	main
maksab	doc_464301607729_item	2423862	et	3	main
2000	doc_464301607729_item	2423863	et	2	main
eurot	doc_464301607729_item	2423864	et	3	main
vene	doc_464301607729_item	2423880	et	4	main
kelt	doc_464301607729_item	2423881	et	3	main
ma	doc_464301607729_item	2423882	et	3	main
räägin	doc_464301607729_item	2423883	et	3	main
rohkem	doc_464301607729_item	2423898	et	4	main
petersburg	doc_464301607729_item	2423899	et	4	main
venelased	doc_464301607729_item	2423900	et	3	main
kui	doc_464301607730_item	2423905	et	3	main
ma	doc_464301607730_item	2423909	et	3	main
ma	doc_464301607730_item	2423913	et	3	main
soome-ugrilase	doc_464301607730_item	2423915	et	3	main
ma	doc_464301607730_item	2423936	et	3	main
tegeks	doc_464301607730_item	2423937	et	4	main
mitte	doc_464301607730_item	2423948	et	3	main
olid	doc_464301607730_item	2423958	et	4	main
sõltusid	doc_464301607730_item	2423959	et	4	main
me	doc_464301607730_item	2423963	et	4	main
naapre	doc_464301607730_item	2423976	et	4	main
aidsi-abi	doc_464301607731_item	2423996	et	4	main
me	doc_464301607731_item	2424001	et	4	main
lund	doc_464301607731_item	2424006	et	3	main
jõulu-asjad	doc_464301607731_item	2424014	et	3	main
ma	doc_464301607731_item	2424017	et	3	main
ja	doc_464301607731_item	2424019	et	3	main
helistada	doc_464301607731_item	2424024	et	3	main
ometi	doc_464301607731_item	2424031	et	3	main
ühiselamus	doc_464301607733_item	2424097	et	4	main
maja	doc_464301607726_item	2423595	et	4	main
ja	doc_464301607726_item	2423596	et	3	main
korter	doc_464301607726_item	2423597	et	3	main
ma	doc_464301607726_item	2423598	et	3	main
elan	doc_464301607726_item	2423599	et	3	main
me	doc_464301607726_item	2423629	et	4	main
meie	doc_464301607726_item	2423633	et	4	main
ole	doc_464301607726_item	2423636	et	4	main
üks	doc_464301607726_item	2423638	et	3	main
kaheksateist	doc_464301607726_item	2423643	et	4	main
kaks	doc_464301607726_item	2423645	et	3	main
on	doc_464301607726_item	2423653	et	4	main
väike	doc_464301607726_item	2423654	et	4	main
on	doc_464301607726_item	2423661	et	4	main
lampi	doc_464301607726_item	2423666	et	4	main
põrandalamp	doc_464301607726_item	2423667	et	3	main
on	doc_464301607726_item	2423668	et	4	main
põrandal	doc_464301607726_item	2423669	et	3	main
laualamp	doc_464301607726_item	2423670	et	3	main
laelampi	doc_464301607726_item	2423676	et	4	main
pilt	doc_464301607726_item	2423680	et	3	main
essee	doc_464301607727_item	2423696	et	4	main
on	doc_464301607727_item	2423721	et	4	main
looduslik	doc_464301607727_item	2423723	et	3	main
siin	doc_464301607727_item	2423733	et	4	main
autosid	doc_464301607727_item	2423736	et	3	main
taksod	doc_464301607727_item	2423739	et	3	main
bussid	doc_464301607727_item	2423746	et	3	main
ma	doc_464301607727_item	2423751	et	3	main
126	doc_464301607727_item	2423754	et	2	main
bussipeatus	doc_464301607727_item	2423756	et	4	main
metrid	doc_464301607727_item	2423759	et	4	main
maja	doc_464301607727_item	2423764	et	4	main
tervitus	doc_464301607728_item	2423781	et	4	main
hästi	doc_464301607728_item	2423801	et	3	main
korrusel	doc_464301607728_item	2423821	et	3	main
on	doc_464301607728_item	2423823	et	4	main
elutuba	doc_464301607728_item	2423827	et	4	main
sõidan	doc_464301607728_item	2423837	et	3	main
kodust	doc_464301607728_item	2423839	et	4	main
ma	doc_464301607728_item	2423843	et	3	main
rahul	doc_464301607728_item	2423848	et	4	main
ma	doc_464301607729_item	2423850	et	3	main
ma	doc_464301607729_item	2423855	et	3	main
päevast	doc_464301607729_item	2423868	et	4	main
seitse	doc_464301607729_item	2423871	et	3	main
moskvas	doc_464301607729_item	2423873	et	4	main
ma	doc_464301607729_item	2423874	et	3	main
vene	doc_464301607729_item	2423884	et	4	main
petersburg	doc_464301607729_item	2423887	et	4	main
petersburgis	doc_464301607729_item	2423901	et	4	main
ma	doc_464301607730_item	2423906	et	3	main
kui	doc_464301607730_item	2423908	et	3	main
elame	doc_464301607726_item	2423630	et	3	main
tuba	doc_464301607726_item	2423639	et	4	main
ruutmeetrit	doc_464301607726_item	2423644	et	3	main
ja	doc_464301607726_item	2423651	et	3	main
meil	doc_464301607726_item	2423652	et	4	main
aken	doc_464301607726_item	2423660	et	3	main
ei	doc_464301607726_item	2423674	et	4	main
ole	doc_464301607726_item	2423675	et	4	main
voodi	doc_464301607726_item	2423690	et	4	main
ma	doc_464301607726_item	2423691	et	3	main
on	doc_464301607726_item	2423692	et	4	main
oma	doc_464301607726_item	2423693	et	4	main
korteriga	doc_464301607726_item	2423694	et	3	main
koduümbrus	doc_464301607727_item	2423697	et	3	main
elan	doc_464301607727_item	2423699	et	3	main
tänavas	doc_464301607727_item	2423704	et	4	main
1-16	doc_464301607727_item	2423705	et	2	main
on	doc_464301607727_item	2423707	et	4	main
roheline	doc_464301607727_item	2423708	et	4	main
rajoon	doc_464301607727_item	2423709	et	3	main
siin	doc_464301607727_item	2423710	et	4	main
kasvavad	doc_464301607727_item	2423711	et	4	main
puud	doc_464301607727_item	2423712	et	4	main
ja	doc_464301607727_item	2423713	et	3	main
lilled	doc_464301607727_item	2423714	et	3	main
meie	doc_464301607727_item	2423715	et	4	main
asub	doc_464301607727_item	2423717	et	3	main
maja	doc_464301607727_item	2423716	et	4	main
joa	doc_464301607727_item	2423718	et	3	main
lähetal	doc_464301607727_item	2423719	et	4	main
siin	doc_464301607727_item	2423720	et	4	main
ilus	doc_464301607727_item	2423722	et	4	main
see	doc_464301607727_item	2423724	et	3	main
maja	doc_464301607727_item	2423729	et	4	main
lähedal	doc_464301607727_item	2423730	et	4	main
on	doc_464301607727_item	2423731	et	4	main
maja	doc_464301607727_item	2423761	et	4	main
asub	doc_464301607727_item	2423766	et	3	main
tänav	doc_464301607727_item	2423771	et	4	main
viimases	doc_464301607728_item	2423792	et	3	main
elan	doc_464301607728_item	2423800	et	3	main
ma	doc_464301607727_item	2423698	et	3	main
y	doc_464301607727_item	2423703	et	4	main
on	doc_464301607727_item	2423725	et	4	main
vaikne	doc_464301607727_item	2423726	et	3	main
rajoon	doc_464301607727_item	2423727	et	3	main
käivad	doc_464301607727_item	2423747	et	4	main
tundi	doc_464301607727_item	2423749	et	4	main
meie	doc_464301607727_item	2423760	et	4	main
valitus	doc_464301607727_item	2423765	et	4	main
suure	doc_464301607727_item	2423769	et	3	main
tänavas	doc_464301607727_item	2423776	et	4	main
kiri	doc_464301607728_item	2423777	et	3	main
tere	doc_464301607728_item	2423778	et	3	main
tänan	doc_464301607728_item	2423783	et	3	main
kirja	doc_464301607728_item	2423785	et	4	main
ma	doc_464301607728_item	2423797	et	3	main
mul	doc_464301607728_item	2423802	et	3	main
on	doc_464301607728_item	2423803	et	4	main
sulle	doc_464301607728_item	2423804	et	3	main
teatada	doc_464301607728_item	2423805	et	3	main
suur	doc_464301607728_item	2423806	et	3	main
uudis	doc_464301607728_item	2423807	et	3	main
hiljuti	doc_464301607728_item	2423808	et	4	main
me	doc_464301607728_item	2423809	et	4	main
ostsime	doc_464301607728_item	2423810	et	3	main
uue	doc_464301607728_item	2423811	et	3	main
korteri	doc_464301607728_item	2423812	et	3	main
korter	doc_464301607728_item	2423813	et	3	main
asub	doc_464301607728_item	2423814	et	3	main
xx-al	doc_464301607728_item	2423815	et	4	main
see	doc_464301607728_item	2423816	et	3	main
on	doc_464301607728_item	2423817	et	4	main
kahekoruselises	doc_464301607728_item	2423818	et	4	main
majas	doc_464301607728_item	2423819	et	3	main
teisel	doc_464301607728_item	2423820	et	4	main
tuba	doc_464301607728_item	2423825	et	4	main
mina	doc_464301607728_item	2423836	et	4	main
korteriga	doc_464301607728_item	2423846	et	3	main
essee	doc_464301607729_item	2423849	et	4	main
mulle	doc_464301607729_item	2423865	et	4	main
mugavat	doc_464301607729_item	2423866	et	3	main
ja	doc_464301607729_item	2423870	et	3	main
päevast	doc_464301607729_item	2423872	et	4	main
muuseumpat	doc_464301607729_item	2423877	et	4	main
venelased	doc_464301607729_item	2423878	et	3	main
kelt	doc_464301607729_item	2423885	et	3	main
ilus	doc_464301607729_item	2423889	et	4	main
on	doc_464301607729_item	2423892	et	4	main
mulle	doc_464301607729_item	2423895	et	4	main
meeldib	doc_464301607729_item	2423896	et	3	main
kõige	doc_464301607729_item	2423897	et	4	main
sõbralikad	doc_464301607729_item	2423903	et	4	main
oleks	doc_464301607730_item	2423907	et	3	main
eesti	doc_464301607730_item	2423911	et	4	main
teeks	doc_464301607730_item	2423914	et	4	main
üliõpilased	doc_464301607730_item	2423916	et	3	main
nende	doc_464301607730_item	2423921	et	4	main
eestis	doc_464301607730_item	2423923	et	3	main
poliitiselt	doc_464301607730_item	2423930	et	4	main
aga	doc_464301607730_item	2423931	et	3	main
rahvusedest	doc_464301607730_item	2423945	et	4	main
nüüd	doc_464301607730_item	2423947	et	4	main
keegi	doc_464301607730_item	2423949	et	4	main
alati	doc_464301607730_item	2423957	et	4	main
jõulisedest	doc_464301607730_item	2423960	et	4	main
kabineti	doc_464301607728_item	2423828	et	4	main
cv	doc_464301607728_item	2423829	et	4	main
köök	doc_464301607728_item	2423830	et	3	main
minu	doc_464301607728_item	2423831	et	3	main
maja	doc_464301607728_item	2423832	et	4	main
asub	doc_464301607728_item	2423833	et	3	main
kolmkümne	doc_464301607728_item	2423840	et	4	main
oma	doc_464301607728_item	2423845	et	4	main
olen	doc_464301607729_item	2423851	et	3	main
äinud	doc_464301607729_item	2423853	et	4	main
k	doc_464301607729_item	2423852	et	4	main
venemaal	doc_464301607729_item	2423854	et	4	main
kaheksa	doc_464301607729_item	2423867	et	4	main
olen	doc_464301607729_item	2423875	et	3	main
külastanud	doc_464301607729_item	2423876	et	4	main
on	doc_464301607729_item	2423888	et	4	main
moskva	doc_464301607729_item	2423891	et	4	main
suur	doc_464301607729_item	2423893	et	3	main
linn	doc_464301607729_item	2423894	et	3	main
on	doc_464301607729_item	2423902	et	4	main
president	doc_464301607730_item	2423912	et	3	main
toetaks	doc_464301607730_item	2423920	et	4	main
venemaal	doc_464301607730_item	2423925	et	4	main
toetaks	doc_464301607730_item	2423927	et	4	main
ei	doc_464301607730_item	2423928	et	4	main
ainult	doc_464301607730_item	2423929	et	4	main
siis	doc_464301607730_item	2423938	et	3	main
et	doc_464301607730_item	2423939	et	3	main
kõik	doc_464301607730_item	2423940	et	4	main
inimesed	doc_464301607730_item	2423941	et	3	main
teavad	doc_464301607730_item	2423942	et	3	main
muust	doc_464301607730_item	2423943	et	4	main
soome-ugrilaselt	doc_464301607730_item	2423944	et	3	main
siis	doc_464301607730_item	2423946	et	3	main
rahvused	doc_464301607730_item	2423956	et	3	main
sõbralik	doc_464301607730_item	2423974	et	3	main
essee	doc_464301607731_item	2423978	et	4	main
kraadi	doc_464301607731_item	2423987	et	4	main
pärastlõuna	doc_464301607731_item	2424016	et	4	main
õhtul	doc_464301607731_item	2424020	et	3	main
iisraelis	doc_464301607731_item	2424023	et	4	main
ta	doc_464301607731_item	2424026	et	4	main
oli	doc_464301607731_item	2424028	et	3	main
nädalalõpeksi	doc_464301607731_item	2424042	et	4	main
ma	doc_464301607733_item	2424095	et	3	main
palju	doc_464301607733_item	2424101	et	4	main
sest	doc_464301607733_item	2424103	et	4	main
ma	doc_464301607733_item	2424104	et	3	main
aga	doc_464301607733_item	2424107	et	3	main
ma	doc_464301607733_item	2424108	et	3	main
äratasin	doc_464301607733_item	2424109	et	3	main
autoga	doc_464301607733_item	2424124	et	3	main
jaapani	doc_464301607733_item	2424127	et	4	main
me	doc_464301607733_item	2424135	et	4	main
jaapani	doc_464301607733_item	2424141	et	4	main
essee	doc_464301607734_item	2424148	et	4	main
ma	doc_464301607734_item	2424150	et	3	main
tramis	doc_464301607734_item	2424186	et	4	main
tulime	doc_464301607734_item	2424193	et	3	main
me	doc_464301607734_item	2424204	et	4	main
käisime	doc_464301607734_item	2424205	et	3	main
saunas	doc_464301607734_item	2424206	et	3	main
ja	doc_464301607734_item	2424207	et	3	main
ma	doc_464301607734_item	2424208	et	3	main
lugesin	doc_464301607734_item	2424209	et	3	main
koik	doc_464301607734_item	2424210	et	4	main
helsingin	doc_464301607734_item	2424211	et	4	main
mõõdunudassilt	doc_464301607734_item	2424213	et	4	main
lugema	doc_464301607734_item	2424218	et	4	main
loen	doc_464301607734_item	2424221	et	3	main
busika	doc_464301607735_item	2424253	et	4	main
rias	doc_464301607735_item	2424254	et	4	main
söösime	doc_464301607735_item	2424256	et	4	main
toit	doc_464301607735_item	2424258	et	3	main
oli	doc_464301607735_item	2424259	et	3	main
pubis	doc_464301607735_item	2424266	et	4	main
ma	doc_464301607736_item	2424284	et	3	main
reedel	doc_464301607736_item	2424287	et	3	main
ma	doc_464301607736_item	2424289	et	3	main
oli	doc_464301607736_item	2424321	et	3	main
matkajate	doc_464301607736_item	2424327	et	4	main
meeldis	doc_464301607737_item	2424338	et	3	main
vaga	doc_464301607737_item	2424339	et	4	main
ja	doc_464301607737_item	2424347	et	3	main
koju	doc_464301607737_item	2424356	et	3	main
laupäev	doc_464301607737_item	2424358	et	3	main
lõpetanud	doc_464301607737_item	2424372	et	4	main
oli	doc_464301607737_item	2424378	et	3	main
räpase	doc_464301607737_item	2424380	et	4	main
ma	doc_464301607730_item	2423926	et	3	main
ja	doc_464301607730_item	2423933	et	3	main
finantsiliselt	doc_464301607730_item	2423934	et	4	main
ja	doc_464301607730_item	2423935	et	3	main
ei	doc_464301607730_item	2423950	et	4	main
tea	doc_464301607730_item	2423951	et	4	main
eriti	doc_464301607730_item	2423952	et	3	main
noored	doc_464301607730_item	2423953	et	3	main
inimesed	doc_464301607730_item	2423954	et	3	main
soome-ugrilased	doc_464301607730_item	2423955	et	3	main
naaberdest	doc_464301607730_item	2423961	et	4	main
aga	doc_464301607730_item	2423962	et	3	main
olnud	doc_464301607730_item	2423966	et	4	main
vabad	doc_464301607730_item	2423967	et	3	main
viisa	doc_464301607730_item	2423970	et	4	main
oeleksin	doc_464301607730_item	2423973	et	4	main
nädalalõpuks	doc_464301607731_item	2423979	et	3	main
nädalalõpuksis	doc_464301607731_item	2423980	et	4	main
oli	doc_464301607731_item	2423981	et	3	main
ja	doc_464301607731_item	2423989	et	3	main
me	doc_464301607731_item	2423994	et	4	main
vaatasime	doc_464301607731_item	2423995	et	3	main
olin	doc_464301607731_item	2424007	et	3	main
väga	doc_464301607731_item	2424009	et	3	main
ilus	doc_464301607731_item	2424010	et	4	main
siis	doc_464301607731_item	2424011	et	3	main
me	doc_464301607731_item	2424012	et	4	main
soovisin	doc_464301607731_item	2424021	et	4	main
aga	doc_464301607731_item	2424025	et	3	main
ei	doc_464301607731_item	2424027	et	4	main
lotte	doc_464301607731_item	2424034	et	3	main
televiisiorist	doc_464301607731_item	2424035	et	4	main
mõtlen	doc_464301607731_item	2424036	et	3	main
laupäeval	doc_464301607733_item	2424098	et	3	main
jõin	doc_464301607733_item	2424100	et	3	main
veini	doc_464301607733_item	2424102	et	4	main
olin	doc_464301607733_item	2424105	et	3	main
purjus	doc_464301607733_item	2424106	et	3	main
pool	doc_464301607733_item	2424110	et	4	main
ja	doc_464301607733_item	2424128	et	3	main
olid	doc_464301607733_item	2424132	et	4	main
ilus	doc_464301607733_item	2424147	et	4	main
mis	doc_464301607734_item	2424149	et	4	main
nädalavahetusel	doc_464301607734_item	2424151	et	4	main
mõõdunud	doc_464301607734_item	2424153	et	4	main
nädalavahetusel	doc_464301607734_item	2424154	et	4	main
ma	doc_464301607734_item	2424155	et	3	main
käisin	doc_464301607734_item	2424156	et	3	main
minna	doc_464301607734_item	2424165	et	3	main
soomes	doc_464301607734_item	2424203	et	4	main
sanoma	doc_464301607734_item	2424212	et	4	main
ma	doc_464301607734_item	2424220	et	3	main
kodus	doc_464301607734_item	2424226	et	4	main
nädalavahetusal	doc_464301607735_item	2424228	et	3	main
olin	doc_464301607735_item	2424230	et	3	main
külastasin	doc_464301607735_item	2424233	et	3	main
ma	doc_464301607735_item	2424235	et	3	main
koos	doc_464301607735_item	2424237	et	4	main
erasmus	doc_464301607735_item	2424239	et	4	main
üliõpilased	doc_464301607735_item	2424240	et	3	main
me	doc_464301607735_item	2424241	et	4	main
tuba	doc_464301607735_item	2424244	et	4	main
oli	doc_464301607735_item	2424245	et	3	main
suur	doc_464301607735_item	2424246	et	3	main
toas	doc_464301607735_item	2424247	et	3	main
oli	doc_464301607735_item	2424248	et	3	main
palju	doc_464301607735_item	2424249	et	4	main
me	doc_464301607735_item	2424262	et	4	main
olime	doc_464301607735_item	2424263	et	3	main
peol	doc_464301607735_item	2424264	et	4	main
prantsuse	doc_464301607735_item	2424265	et	3	main
ja	doc_464301607735_item	2424267	et	3	main
essee	doc_464301607736_item	2424278	et	4	main
möödunud	doc_464301607736_item	2424279	et	4	main
nädalavahetusel	doc_464301607736_item	2424280	et	4	main
ma	doc_464301607736_item	2424281	et	3	main
ma	doc_464301607736_item	2424324	et	3	main
meile	doc_464301607737_item	2424337	et	4	main
seda	doc_464301607737_item	2424353	et	3	main
taksiga	doc_464301607737_item	2424357	et	3	main
alati	doc_464301607730_item	2423964	et	4	main
oleme	doc_464301607730_item	2423965	et	3	main
ma	doc_464301607730_item	2423968	et	3	main
saad	doc_464301607730_item	2423971	et	4	main
kõik	doc_464301607730_item	2423975	et	4	main
halva	doc_464301607731_item	2423982	et	4	main
ilma	doc_464301607731_item	2423983	et	4	main
reedel	doc_464301607731_item	2423984	et	3	main
oli	doc_464301607731_item	2423985	et	3	main
seistse	doc_464301607731_item	2423986	et	4	main
külma	doc_464301607731_item	2423988	et	4	main
läksime	doc_464301607731_item	2423991	et	3	main
kontsertit	doc_464301607731_item	2423997	et	4	main
pühapäeval	doc_464301607731_item	2424000	et	3	main
jalutasin	doc_464301607731_item	2424002	et	3	main
metsas	doc_464301607731_item	2424003	et	3	main
sest	doc_464301607731_item	2424004	et	4	main
tegime	doc_464301607731_item	2424013	et	3	main
sõbra	doc_464301607731_item	2424022	et	3	main
lõpuks	doc_464301607731_item	2424030	et	4	main
vaatasime	doc_464301607731_item	2424033	et	3	main
essee	doc_464301607733_item	2424094	et	4	main
pidutsesin	doc_464301607733_item	2424096	et	3	main
sõbõ	doc_464301607733_item	2424123	et	4	main
korea	doc_464301607733_item	2424129	et	4	main
väga	doc_464301607733_item	2424133	et	3	main
kuulasime	doc_464301607733_item	2424136	et	3	main
ka	doc_464301607733_item	2424138	et	3	main
minu	doc_464301607733_item	2424143	et	3	main
oli	doc_464301607733_item	2424145	et	3	main
tegin	doc_464301607734_item	2424152	et	3	main
kuhu	doc_464301607734_item	2424162	et	3	main
ma	doc_464301607734_item	2424163	et	3	main
ja	doc_464301607734_item	2424183	et	3	main
oli	doc_464301607734_item	2424196	et	3	main
nädälalt	doc_464301607734_item	2424214	et	4	main
ei	doc_464301607734_item	2424216	et	4	main
internetist	doc_464301607734_item	2424219	et	4	main
essee	doc_464301607735_item	2424227	et	4	main
ma	doc_464301607735_item	2424229	et	3	main
magasime	doc_464301607735_item	2424242	et	3	main
võõrastekodus	doc_464301607735_item	2424243	et	3	main
me	doc_464301607735_item	2424255	et	4	main
restaurans	doc_464301607735_item	2424257	et	4	main
hea	doc_464301607735_item	2424260	et	4	main
õhtuti	doc_464301607735_item	2424261	et	3	main
pühapäeval	doc_464301607735_item	2424268	et	3	main
tallinn	doc_464301607736_item	2424286	et	4	main
kodus	doc_464301607731_item	2424029	et	4	main
me	doc_464301607731_item	2424032	et	4	main
et	doc_464301607731_item	2424037	et	3	main
see	doc_464301607731_item	2424038	et	3	main
olen	doc_464301607731_item	2424039	et	3	main
olnud	doc_464301607731_item	2424040	et	4	main
head	doc_464301607731_item	2424041	et	4	main
ma	doc_464301607733_item	2424099	et	3	main
üheksa	doc_464301607733_item	2424111	et	4	main
pühapäeval	doc_464301607733_item	2424112	et	3	main
ma	doc_464301607733_item	2424113	et	3	main
tohiksin	doc_464301607733_item	2424114	et	3	main
sõbraga	doc_464301607733_item	2424115	et	3	main
internetiga	doc_464301607733_item	2424116	et	4	main
ma	doc_464301607733_item	2424117	et	3	main
käisin	doc_464301607733_item	2424118	et	3	main
eesti	doc_464301607733_item	2424119	et	4	main
sõbõ	doc_464301607733_item	2424120	et	4	main
minu	doc_464301607733_item	2424122	et	3	main
vaatasime	doc_464301607733_item	2424126	et	3	main
need	doc_464301607733_item	2424131	et	3	main
me	doc_464301607733_item	2424139	et	4	main
sõime	doc_464301607733_item	2424140	et	4	main
väga	doc_464301607733_item	2424146	et	3	main
stokholmis	doc_464301607734_item	2424157	et	4	main
abikaasaga	doc_464301607734_item	2424158	et	3	main
seal	doc_464301607734_item	2424159	et	4	main
oli	doc_464301607734_item	2424160	et	3	main
jouluturu	doc_464301607734_item	2424161	et	4	main
tahtsin	doc_464301607734_item	2424164	et	3	main
läksime	doc_464301607734_item	2424167	et	3	main
helsingist	doc_464301607734_item	2424168	et	4	main
laevaga	doc_464301607734_item	2424169	et	4	main
üks	doc_464301607734_item	2424170	et	3	main
öö	doc_464301607734_item	2424171	et	4	main
olime	doc_464301607734_item	2424172	et	3	main
laevas	doc_464301607734_item	2424173	et	3	main
laevas	doc_464301607734_item	2424174	et	3	main
oli	doc_464301607734_item	2424175	et	3	main
palju	doc_464301607734_item	2424176	et	4	main
inimesi	doc_464301607734_item	2424177	et	4	main
stokholmis	doc_464301607734_item	2424178	et	4	main
me	doc_464301607734_item	2424179	et	4	main
sõime	doc_464301607734_item	2424180	et	4	main
hea	doc_464301607734_item	2424181	et	4	main
louna	doc_464301607734_item	2424182	et	4	main
majas	doc_464301607733_item	2424121	et	3	main
me	doc_464301607733_item	2424125	et	4	main
liikumised	doc_464301607733_item	2424130	et	4	main
head	doc_464301607733_item	2424134	et	4	main
muusikatid	doc_464301607733_item	2424137	et	4	main
toitu	doc_464301607733_item	2424142	et	4	main
nädalavahetus	doc_464301607733_item	2424144	et	4	main
me	doc_464301607734_item	2424166	et	4	main
jõime	doc_464301607734_item	2424184	et	3	main
meile	doc_464301607734_item	2424187	et	4	main
meeldid	doc_464301607734_item	2424188	et	3	main
stokholm	doc_464301607734_item	2424189	et	4	main
helsingisse	doc_464301607734_item	2424195	et	4	main
ajakirjanikud	doc_464301607734_item	2424222	et	3	main
kui	doc_464301607734_item	2424223	et	3	main
olen	doc_464301607734_item	2424225	et	3	main
riias	doc_464301607735_item	2424231	et	4	main
mõned	doc_464301607735_item	2424238	et	3	main
ma	doc_464301607735_item	2424251	et	3	main
laksin	doc_464301607735_item	2424252	et	3	main
ma	doc_464301607735_item	2424270	et	3	main
laskin	doc_464301607735_item	2424271	et	4	main
tallinnas	doc_464301607735_item	2424276	et	4	main
õhtuti	doc_464301607735_item	2424277	et	3	main
alustasin	doc_464301607736_item	2424285	et	3	main
ja	doc_464301607736_item	2424288	et	3	main
ilus	doc_464301607736_item	2424323	et	4	main
essee	doc_464301607737_item	2424329	et	4	main
ma	doc_464301607737_item	2424331	et	3	main
käisin	doc_464301607737_item	2424332	et	3	main
kontsert	doc_464301607737_item	2424334	et	3	main
minu	doc_464301607737_item	2424335	et	3	main
sobraga	doc_464301607737_item	2424336	et	4	main
me	doc_464301607737_item	2424343	et	4	main
käisime	doc_464301607737_item	2424344	et	3	main
sobrad	doc_464301607737_item	2424345	et	3	main
me	doc_464301607737_item	2424348	et	4	main
jõime	doc_464301607737_item	2424349	et	3	main
õlud	doc_464301607737_item	2424350	et	4	main
müürseppid	doc_464301607737_item	2424359	et	4	main
vannituba	doc_464301607737_item	2424364	et	4	main
porandal	doc_464301607737_item	2424365	et	4	main
ja	doc_464301607737_item	2424366	et	3	main
seinad	doc_464301607737_item	2424367	et	3	main
terve	doc_464301607737_item	2424375	et	4	main
tundasi	doc_464301607737_item	2424382	et	4	main
me	doc_464301607737_item	2424390	et	4	main
lugesin	doc_464301607737_item	2424398	et	3	main
virukeskus	doc_464301607737_item	2424404	et	3	main
sõime	doc_464301607737_item	2424406	et	4	main
ja	doc_464301607737_item	2424408	et	3	main
essee	doc_464301607738_item	2424413	et	4	main
reedel	doc_464301607738_item	2424414	et	3	main
ma	doc_464301607738_item	2424415	et	3	main
tuba	doc_464301607738_item	2424418	et	4	main
poes	doc_464301607738_item	2424421	et	3	main
ja	doc_464301607738_item	2424441	et	3	main
kirikud	doc_464301607738_item	2424458	et	3	main
sõime	doc_464301607738_item	2424461	et	4	main
me	doc_464301607738_item	2424465	et	4	main
käisime	doc_464301607738_item	2424466	et	3	main
me	doc_464301607738_item	2424469	et	4	main
jõime	doc_464301607738_item	2424470	et	3	main
õlu	doc_464301607738_item	2424471	et	3	main
kodus	doc_464301607738_item	2424474	et	4	main
me	doc_464301607738_item	2424476	et	4	main
saksa	doc_464301607738_item	2424478	et	4	main
magasime	doc_464301607738_item	2424481	et	3	main
kohvit	doc_464301607734_item	2424185	et	4	main
palju	doc_464301607734_item	2424190	et	4	main
kui	doc_464301607734_item	2424191	et	3	main
me	doc_464301607734_item	2424192	et	4	main
tagas	doc_464301607734_item	2424194	et	3	main
tugev	doc_464301607734_item	2424197	et	4	main
tuul	doc_464301607734_item	2424198	et	3	main
pühapäeval	doc_464301607734_item	2424199	et	3	main
ma	doc_464301607734_item	2424200	et	3	main
olin	doc_464301607734_item	2424201	et	3	main
kodus	doc_464301607734_item	2424202	et	4	main
mulle	doc_464301607734_item	2424215	et	4	main
meeldid	doc_464301607734_item	2424217	et	3	main
ma	doc_464301607734_item	2424224	et	3	main
ma	doc_464301607735_item	2424232	et	3	main
linn	doc_464301607735_item	2424234	et	3	main
olin	doc_464301607735_item	2424236	et	3	main
voodisid	doc_464301607735_item	2424250	et	4	main
pärastlõuna	doc_464301607735_item	2424269	et	4	main
busika	doc_464301607735_item	2424272	et	4	main
tallinnas	doc_464301607735_item	2424273	et	4	main
ma	doc_464301607735_item	2424274	et	3	main
olin	doc_464301607735_item	2424275	et	3	main
olin	doc_464301607736_item	2424282	et	3	main
rigas	doc_464301607736_item	2424283	et	4	main
tagasi	doc_464301607736_item	2424290	et	3	main
tulin	doc_464301607736_item	2424291	et	3	main
pühapäeval	doc_464301607736_item	2424292	et	3	main
ma	doc_464301607736_item	2424293	et	3	main
läksin	doc_464301607736_item	2424294	et	3	main
bussiga	doc_464301607736_item	2424295	et	3	main
sõbriga	doc_464301607736_item	2424296	et	4	main
see	doc_464301607736_item	2424297	et	3	main
oli	doc_464301607736_item	2424298	et	3	main
väga	doc_464301607736_item	2424299	et	3	main
lõbus	doc_464301607736_item	2424300	et	4	main
külastasin	doc_464301607736_item	2424302	et	3	main
ma	doc_464301607736_item	2424301	et	3	main
linnas	doc_464301607736_item	2424303	et	4	main
ja	doc_464301607736_item	2424304	et	3	main
ma	doc_464301607736_item	2424305	et	3	main
olin	doc_464301607736_item	2424306	et	3	main
poes	doc_464301607736_item	2424307	et	3	main
sõbriga	doc_464301607736_item	2424308	et	4	main
ma	doc_464301607736_item	2424309	et	3	main
läksin	doc_464301607736_item	2424310	et	3	main
ka	doc_464301607736_item	2424311	et	3	main
restoranis	doc_464301607736_item	2424312	et	3	main
reval	doc_464301607736_item	2424313	et	4	main
hotellis	doc_464301607736_item	2424314	et	3	main
mul	doc_464301607736_item	2424315	et	3	main
oli	doc_464301607736_item	2424316	et	3	main
nägemine	doc_464301607736_item	2424317	et	4	main
linna	doc_464301607736_item	2424318	et	4	main
peal	doc_464301607736_item	2424319	et	4	main
see	doc_464301607736_item	2424320	et	3	main
noorte	doc_464301607736_item	2424326	et	3	main
öömajas	doc_464301607736_item	2424328	et	3	main
reedel	doc_464301607737_item	2424330	et	3	main
jazzi	doc_464301607737_item	2424333	et	4	main
veidi	doc_464301607737_item	2424351	et	3	main
me	doc_464301607737_item	2424354	et	4	main
tulesid	doc_464301607737_item	2424360	et	3	main
parandasid	doc_464301607737_item	2424363	et	4	main
väga	doc_464301607736_item	2424322	et	3	main
magin	doc_464301607736_item	2424325	et	4	main
palju	doc_464301607737_item	2424340	et	4	main
muusikat	doc_464301607737_item	2424341	et	3	main
hiljem	doc_464301607737_item	2424342	et	3	main
juurde	doc_464301607737_item	2424346	et	4	main
pärast	doc_464301607737_item	2424352	et	4	main
läksime	doc_464301607737_item	2424355	et	3	main
korterid	doc_464301607737_item	2424361	et	3	main
olime	doc_464301607737_item	2424386	et	3	main
väga	doc_464301607737_item	2424387	et	3	main
vasinud	doc_464301607737_item	2424388	et	4	main
vaatasime	doc_464301607737_item	2424391	et	3	main
ja	doc_464301607737_item	2424393	et	3	main
poes	doc_464301607737_item	2424403	et	3	main
hiljem	doc_464301607737_item	2424409	et	3	main
me	doc_464301607737_item	2424410	et	4	main
läksime	doc_464301607737_item	2424411	et	3	main
koju	doc_464301607737_item	2424412	et	3	main
käisin	doc_464301607738_item	2424420	et	3	main
nad	doc_464301607737_item	2424362	et	3	main
töö	doc_464301607737_item	2424371	et	4	main
koristasin	doc_464301607737_item	2424374	et	3	main
sest	doc_464301607737_item	2424377	et	4	main
vaga	doc_464301607737_item	2424379	et	4	main
ta	doc_464301607737_item	2424381	et	4	main
käisin	doc_464301607737_item	2424402	et	3	main
koristasin	doc_464301607738_item	2424416	et	3	main
ma	doc_464301607738_item	2424422	et	3	main
helistasin	doc_464301607738_item	2424426	et	3	main
me	doc_464301607738_item	2424451	et	4	main
käisime	doc_464301607738_item	2424452	et	3	main
vanalinnas	doc_464301607738_item	2424453	et	4	main
ja	doc_464301607738_item	2424454	et	3	main
ja	doc_464301607738_item	2424459	et	3	main
lugesime	doc_464301607738_item	2424477	et	3	main
ja	doc_464301607738_item	2424480	et	3	main
kui	doc_464301607737_item	2424368	et	3	main
nad	doc_464301607737_item	2424369	et	3	main
olid	doc_464301607737_item	2424370	et	4	main
me	doc_464301607737_item	2424373	et	4	main
korterid	doc_464301607737_item	2424376	et	3	main
sigala	doc_464301607737_item	2424383	et	4	main
hiljem	doc_464301607737_item	2424384	et	3	main
siis	doc_464301607737_item	2424389	et	3	main
telekat	doc_464301607737_item	2424392	et	3	main
voodi	doc_464301607737_item	2424395	et	4	main
pühapäeval	doc_464301607737_item	2424396	et	3	main
ma	doc_464301607737_item	2424397	et	3	main
me	doc_464301607737_item	2424405	et	4	main
lõunat	doc_464301607737_item	2424407	et	3	main
ja	doc_464301607738_item	2424425	et	3	main
üks	doc_464301607738_item	2424429	et	3	main
tules	doc_464301607738_item	2424431	et	3	main
saksamaalt	doc_464301607738_item	2424432	et	3	main
lennujaam	doc_464301607738_item	2424436	et	3	main
pelmeeni	doc_464301607738_item	2424440	et	4	main
vanalinnas	doc_464301607738_item	2424443	et	4	main
pubis	doc_464301607738_item	2424446	et	4	main
ja	doc_464301607738_item	2424447	et	3	main
jõime	doc_464301607738_item	2424448	et	3	main
õlu	doc_464301607738_item	2424449	et	3	main
pühapäeval	doc_464301607738_item	2424450	et	3	main
vaatasime	doc_464301607738_item	2424457	et	3	main
me	doc_464301607738_item	2424460	et	4	main
hõõgvein	doc_464301607738_item	2424462	et	3	main
jõululaatis	doc_464301607738_item	2424463	et	4	main
õhtul	doc_464301607738_item	2424464	et	3	main
vestlesime	doc_464301607738_item	2424473	et	3	main
siis	doc_464301607738_item	2424475	et	3	main
ma	doc_464301607741_item	2424732	et	3	main
naine	doc_464301607741_item	2424734	et	3	main
janele	doc_464301607741_item	2424763	et	4	main
väike	doc_464301607741_item	2424770	et	4	main
linn	doc_464301607741_item	2424771	et	3	main
sest	doc_464301607741_item	2424783	et	4	main
ja	doc_464301607741_item	2424787	et	3	main
õhtul	doc_464301607741_item	2424789	et	3	main
sõitsime	doc_464301607741_item	2424791	et	3	main
koju	doc_464301607741_item	2424792	et	3	main
me	doc_464301607737_item	2424385	et	4	main
käisime	doc_464301607737_item	2424394	et	3	main
ajalehte	doc_464301607737_item	2424399	et	4	main
kohe	doc_464301607737_item	2424400	et	4	main
ma	doc_464301607737_item	2424401	et	3	main
minu	doc_464301607738_item	2424417	et	3	main
ja	doc_464301607738_item	2424419	et	3	main
kirjutasin	doc_464301607738_item	2424423	et	3	main
sõbrad	doc_464301607738_item	2424427	et	3	main
laupäeval	doc_464301607738_item	2424428	et	3	main
sõber	doc_464301607738_item	2424430	et	3	main
ma	doc_464301607738_item	2424434	et	3	main
me	doc_464301607738_item	2424438	et	4	main
käisime	doc_464301607738_item	2424442	et	3	main
me	doc_464301607738_item	2424444	et	4	main
käisime	doc_464301607738_item	2424445	et	3	main
me	doc_464301607738_item	2424456	et	4	main
kinos	doc_464301607738_item	2424467	et	3	main
ajaleht	doc_464301607738_item	2424479	et	3	main
meil	doc_464301607738_item	2424424	et	4	main
lennuga	doc_464301607738_item	2424433	et	3	main
käisin	doc_464301607738_item	2424435	et	3	main
õhtul	doc_464301607738_item	2424437	et	3	main
sõime	doc_464301607738_item	2424439	et	4	main
poes	doc_464301607738_item	2424455	et	3	main
siis	doc_464301607738_item	2424468	et	3	main
ja	doc_464301607738_item	2424472	et	3	main
essee	doc_464301607741_item	2424729	et	4	main
meie	doc_464301607741_item	2424736	et	4	main
meie	doc_464301607741_item	2424739	et	4	main
veina	doc_464301607741_item	2424746	et	4	main
vanemad	doc_464301607741_item	2424764	et	4	main
sauest	doc_464301607741_item	2424772	et	4	main
ja	doc_464301607741_item	2424779	et	3	main
meie	doc_464301607741_item	2424780	et	4	main
sõitsime	doc_464301607741_item	2424785	et	3	main
meie	doc_464301607741_item	2424790	et	4	main
see	doc_464301607743_item	2424938	et	3	main
uus	doc_464301607743_item	2424942	et	3	main
laupaval	doc_464301607743_item	2424948	et	4	main
puhib	doc_464301607743_item	2424958	et	4	main
ja	doc_464301607743_item	2424965	et	3	main
me	doc_464301607743_item	2424967	et	4	main
jõima	doc_464301607743_item	2424968	et	4	main
koju	doc_464301607743_item	2424991	et	3	main
ja	doc_464301607743_item	2424992	et	3	main
olin	doc_464301607743_item	2424994	et	3	main
väsinud	doc_464301607743_item	2424996	et	4	main
kontrolltöö	doc_4683472066_item	2424997	et	4	main
1	doc_4683472066_item	2424998	et	2	main
3	doc_4683472066_item	2425014	et	2	main
venemaal	doc_4683472066_item	2425022	et	4	main
eestis	doc_4683472066_item	2425027	et	3	main
kindlustatuse	doc_4683472066_item	2425042	et	4	main
tase	doc_4683472066_item	2425043	et	3	main
jäi	doc_4683472066_item	2425044	et	3	main
väga	doc_4683472066_item	2425045	et	3	main
madalaks	doc_4683472066_item	2425046	et	3	main
pärast	doc_4683472066_item	2425047	et	4	main
demonstrantide	doc_4683472066_item	2425049	et	3	main
rahulolematuselaine	doc_4683472066_item	2425054	et	4	main
avaldati	doc_4683472066_item	2425055	et	3	main
manifest	doc_4683472066_item	2425057	et	3	main
lubatidemokraatlikke	doc_4683472066_item	2425059	et	4	main
minu	doc_464301607741_item	2424733	et	3	main
laps	doc_464301607741_item	2424737	et	4	main
meie	doc_464301607741_item	2424743	et	4	main
jõime	doc_464301607741_item	2424744	et	3	main
palju	doc_464301607741_item	2424745	et	4	main
oli	doc_464301607741_item	2424751	et	3	main
hea	doc_464301607741_item	2424753	et	4	main
ja	doc_464301607741_item	2424755	et	3	main
oli	doc_464301607741_item	2424758	et	3	main
elavad	doc_464301607741_item	2424766	et	4	main
sauel	doc_464301607741_item	2424767	et	3	main
saue	doc_464301607741_item	2424768	et	4	main
on	doc_464301607741_item	2424774	et	4	main
24	doc_464301607741_item	2424775	et	2	main
kümmendneli	doc_464301607741_item	2424777	et	4	main
ei	doc_464301607741_item	2424781	et	4	main
käinud	doc_464301607741_item	2424782	et	4	main
riiasse	doc_464301607743_item	2424921	et	4	main
kell	doc_464301607743_item	2424929	et	3	main
riias	doc_464301607743_item	2424933	et	4	main
läksime	doc_464301607743_item	2424935	et	3	main
restoranis	doc_464301607743_item	2424937	et	3	main
kesklinnasse	doc_464301607743_item	2424946	et	4	main
me	doc_464301607743_item	2424960	et	4	main
nägime	doc_464301607743_item	2424961	et	3	main
majad	doc_464301607743_item	2424963	et	3	main
ma	doc_464301607743_item	2424993	et	3	main
mis	doc_4683472066_item	2424999	et	4	main
majanduslikku	doc_4683472066_item	2425005	et	4	main
olid	doc_4683472066_item	2425009	et	4	main
vabadussõja	doc_4683472066_item	2425010	et	3	main
teaduselu	doc_4683472066_item	2425017	et	4	main
möödunud	doc_464301607741_item	2424730	et	4	main
ja	doc_464301607741_item	2424735	et	3	main
läksime	doc_464301607741_item	2424738	et	3	main
sõbra	doc_464301607741_item	2424740	et	3	main
kodus	doc_464301607741_item	2424741	et	4	main
ja	doc_464301607741_item	2424747	et	3	main
sõime	doc_464301607741_item	2424748	et	4	main
pirukasid	doc_464301607741_item	2424750	et	3	main
sest	doc_464301607741_item	2424760	et	4	main
meie	doc_464301607741_item	2424761	et	4	main
käisime	doc_464301607741_item	2424762	et	3	main
on	doc_464301607741_item	2424769	et	4	main
kaks	doc_464301607741_item	2424776	et	3	main
rongega	doc_464301607741_item	2424786	et	4	main
laupäeval	doc_464301607741_item	2424788	et	3	main
reedel	doc_464301607741_item	2424731	et	3	main
seal	doc_464301607741_item	2424742	et	4	main
juustu-hakkliha	doc_464301607741_item	2424749	et	4	main
väga	doc_464301607741_item	2424752	et	3	main
õhtul	doc_464301607741_item	2424754	et	3	main
laupäeval	doc_464301607741_item	2424756	et	3	main
hommikul	doc_464301607741_item	2424757	et	3	main
hea	doc_464301607741_item	2424759	et	4	main
nad	doc_464301607741_item	2424765	et	3	main
tallinnani	doc_464301607741_item	2424773	et	4	main
km	doc_464301607741_item	2424778	et	4	main
meie	doc_464301607741_item	2424784	et	4	main
pühapäeval	doc_464301607741_item	2424793	et	3	main
oli	doc_464301607741_item	2424794	et	3	main
rahulik	doc_464301607741_item	2424795	et	3	main
ja	doc_464301607741_item	2424796	et	3	main
meie	doc_464301607741_item	2424797	et	4	main
jalutasime	doc_464301607741_item	2424798	et	3	main
vähe	doc_464301607741_item	2424799	et	3	main
ja	doc_464301607741_item	2424800	et	3	main
õhtul	doc_464301607741_item	2424801	et	3	main
meie	doc_464301607741_item	2424802	et	4	main
vaatasime	doc_464301607741_item	2424803	et	3	main
teleka	doc_464301607741_item	2424804	et	3	main
essee	doc_464301607743_item	2424913	et	4	main
mis	doc_464301607743_item	2424914	et	4	main
ma	doc_464301607743_item	2424915	et	3	main
nädalavahetusel	doc_464301607743_item	2424916	et	4	main
tegin	doc_464301607743_item	2424917	et	3	main
reedel	doc_464301607743_item	2424918	et	3	main
ma	doc_464301607743_item	2424919	et	3	main
läksin	doc_464301607743_item	2424920	et	3	main
autobussiga	doc_464301607743_item	2424922	et	3	main
oli	doc_464301607743_item	2424924	et	3	main
viis	doc_464301607743_item	2424925	et	4	main
tundid	doc_464301607743_item	2424926	et	4	main
istuda	doc_464301607743_item	2424927	et	3	main
autobussis	doc_464301607743_item	2424928	et	3	main
seitse	doc_464301607743_item	2424930	et	3	main
oli	doc_464301607743_item	2424940	et	3	main
siis	doc_464301607743_item	2424943	et	3	main
me	doc_464301607743_item	2424944	et	4	main
läksime	doc_464301607743_item	2424950	et	3	main
tuul	doc_464301607743_item	2424959	et	3	main
tänavad	doc_464301607743_item	2424964	et	4	main
monumentid	doc_464301607743_item	2424966	et	4	main
ma	doc_464301607743_item	2424989	et	3	main
väga	doc_464301607743_item	2424995	et	3	main
poliitilist	doc_4683472066_item	2425003	et	3	main
põhjused	doc_4683472066_item	2425013	et	3	main
1905	doc_4683472066_item	2425019	et	2	main
teravnesid	doc_4683472066_item	2425021	et	4	main
poliitilised	doc_4683472066_item	2425023	et	3	main
vastuolud	doc_4683472066_item	2425026	et	3	main
ja	doc_4683472066_item	2425028	et	3	main
lätis	doc_4683472066_item	2425029	et	4	main
hakkasid	doc_4683472066_item	2425030	et	4	main
kiiresti	doc_4683472066_item	2425039	et	3	main
rahumeelsete	doc_4683472066_item	2425048	et	3	main
kogu	doc_4683472066_item	2425052	et	4	main
kartuli	doc_4683472066_item	2425070	et	3	main
baltisaksa	doc_4683472066_item	2425083	et	4	main
aadliga	doc_4683472066_item	2425084	et	3	main
mittetootlik	doc_4683472066_item	2425096	et	3	main
kõigil	doc_4683472066_item	2425101	et	4	main
elualadel	doc_4683472066_item	2425102	et	3	main
me	doc_464301607743_item	2424931	et	4	main
me	doc_464301607743_item	2424934	et	4	main
pubisse	doc_464301607743_item	2424947	et	4	main
me	doc_464301607743_item	2424949	et	4	main
nägeda	doc_464301607743_item	2424951	et	4	main
linna	doc_464301607743_item	2424952	et	4	main
ilm	doc_464301607743_item	2424953	et	3	main
kirikud	doc_464301607743_item	2424962	et	3	main
iseloomustab	doc_4683472066_item	2425000	et	4	main
ühiskonna	doc_4683472066_item	2425002	et	4	main
ja	doc_4683472066_item	2425004	et	3	main
süsteemi	doc_4683472066_item	2425006	et	4	main
2	doc_4683472066_item	2425007	et	2	main
millised	doc_4683472066_item	2425008	et	3	main
iseloomustage	doc_4683472066_item	2425015	et	4	main
ew	doc_4683472066_item	2425016	et	4	main
a	doc_4683472066_item	2425020	et	4	main
ideed	doc_4683472066_item	2425033	et	4	main
eestis	doc_4683472066_item	2425034	et	3	main
ja	doc_4683472066_item	2425035	et	3	main
lätis	doc_4683472066_item	2425036	et	4	main
töölisklass	doc_4683472066_item	2425037	et	3	main
maad	doc_4683472066_item	2425053	et	4	main
palju	doc_4683472066_item	2425066	et	4	main
elus	doc_4683472066_item	2425069	et	4	main
19	doc_4683472066_item	2425072	et	2	main
algul	doc_4683472066_item	2425074	et	4	main
ideed	doc_4683472066_item	2425079	et	4	main
crjakobson	doc_4683472066_item	2425080	et	4	main
järgnevatel	doc_4683472066_item	2425088	et	4	main
aastakümnetel	doc_4683472066_item	2425089	et	4	main
rahvas	doc_4683472066_item	2425097	et	4	main
kiir	doc_4683472066_item	2425099	et	4	main
hoogsalt	doc_4683472066_item	2425104	et	4	main
metalli	doc_4683472066_item	2425105	et	4	main
masinatööstus	doc_4683472066_item	2425107	et	3	main
jposka	doc_4683472066_item	2425121	et	4	main
eestlaste	doc_4683472066_item	2425124	et	4	main
valitsus	doc_4683472066_item	2425142	et	4	main
läks	doc_4683472066_item	2425151	et	3	main
sai	doc_4683472066_item	2425154	et	4	main
kirjutati	doc_4683472066_item	2425159	et	3	main
vaherahu	doc_4683472066_item	2425164	et	4	main
põhjused	doc_4683472066_item	2425168	et	3	main
eesti	doc_4683472066_item	2425170	et	4	main
oli	doc_4683472066_item	2425181	et	3	main
ülikiire	doc_4683472066_item	2425194	et	4	main
vaheaega	doc_4683472066_item	2425201	et	4	main
ülikooli	doc_4683472066_item	2425205	et	4	main
ka	doc_4683472066_item	2425208	et	3	main
maailmamainega	doc_4683472066_item	2425210	et	4	main
teadlasi	doc_4683472066_item	2425211	et	3	main
see	doc_464301607743_item	2424923	et	3	main
olime	doc_464301607743_item	2424932	et	3	main
lõunatada	doc_464301607743_item	2424936	et	3	main
restoran	doc_464301607743_item	2424939	et	3	main
vaga	doc_464301607743_item	2424941	et	4	main
läksime	doc_464301607743_item	2424945	et	3	main
oli	doc_464301607743_item	2424954	et	3	main
väga	doc_464301607743_item	2424955	et	3	main
külm	doc_464301607743_item	2424956	et	3	main
ja	doc_464301607743_item	2424957	et	3	main
teed	doc_464301607743_item	2424969	et	4	main
kakskümmendil	doc_464301607743_item	2424970	et	4	main
korrusel	doc_464301607743_item	2424971	et	3	main
latvija	doc_464301607743_item	2424972	et	4	main
hotelis	doc_464301607743_item	2424973	et	4	main
õhtul	doc_464301607743_item	2424974	et	3	main
me	doc_464301607743_item	2424975	et	4	main
läksime	doc_464301607743_item	2424976	et	3	main
restoranis	doc_464301607743_item	2424977	et	3	main
lõunatada	doc_464301607743_item	2424978	et	3	main
ja	doc_464301607743_item	2424979	et	3	main
jälle	doc_464301607743_item	2424980	et	3	main
läksime	doc_464301607743_item	2424981	et	3	main
pubisse	doc_464301607743_item	2424982	et	4	main
püühapaeval	doc_464301607743_item	2424983	et	4	main
me	doc_464301607743_item	2424984	et	4	main
läksime	doc_464301607743_item	2424985	et	3	main
koju	doc_464301607743_item	2424986	et	3	main
kell	doc_464301607743_item	2424987	et	3	main
kaheksa	doc_464301607743_item	2424988	et	4	main
olin	doc_464301607743_item	2424990	et	3	main
nõukogude	doc_4683472066_item	2425001	et	3	main
võidu	doc_4683472066_item	2425011	et	4	main
peamised	doc_4683472066_item	2425012	et	3	main
1	doc_4683472066_item	2425018	et	2	main
levima	doc_4683472066_item	2425031	et	3	main
sotsiaaldemokratlikud	doc_4683472066_item	2425032	et	4	main
kuid	doc_4683472066_item	2425040	et	4	main
tulistamist	doc_4683472066_item	2425050	et	4	main
kus	doc_4683472066_item	2425058	et	3	main
ka	doc_4683472066_item	2425063	et	3	main
abinõusid	doc_4683472066_item	2425064	et	3	main
väga	doc_4683472066_item	2425065	et	3	main
domineerisid	doc_4683472066_item	2425075	et	4	main
baltikumi	doc_4683472066_item	2425076	et	4	main
või	doc_4683472066_item	2425095	et	4	main
ühendati	doc_4683472066_item	2425123	et	4	main
asualad	doc_4683472066_item	2425125	et	3	main
ühtseks	doc_4683472066_item	2425126	et	4	main
haldusüksuseks	doc_4683472066_item	2425127	et	4	main
järgnevalt	doc_4683472066_item	2425128	et	4	main
a	doc_4683472066_item	2425140	et	4	main
ja	doc_4683472066_item	2425149	et	3	main
kokkuvarisemisel	doc_4683472066_item	2425153	et	3	main
mille	doc_4683472066_item	2425157	et	3	main
1918	doc_4683472066_item	2425160	et	2	main
2	doc_4683472066_item	2425165	et	2	main
peamised	doc_4683472066_item	2425167	et	3	main
kõigepealt	doc_4683472066_item	2425169	et	3	main
rahvas	doc_4683472066_item	2425171	et	4	main
tahtis	doc_4683472066_item	2425172	et	3	main
vabaks	doc_4683472066_item	2425173	et	3	main
saada	doc_4683472066_item	2425174	et	4	main
elut	doc_4683472066_item	2425178	et	4	main
elada	doc_4683472066_item	2425185	et	3	main
vähesus	doc_4683472066_item	2425190	et	4	main
pärast	doc_4683472066_item	2425199	et	4	main
развся	doc_4683472066_item	2425230	et	2	main
maailmasõja	doc_4683472066_item	2425236	et	3	main
hakkasid	doc_4683472066_item	2425243	et	4	main
oma	doc_4683472066_item	2425244	et	4	main
kontrolltöö	doc_4683472067_item	2425256	et	4	main
1970	doc_4683472067_item	2425259	et	2	main
3	doc_4683472067_item	2425273	et	2	main
sõnade	doc_4683472067_item	2425274	et	3	main
perestroika	doc_4683472067_item	2425275	et	4	main
ja	doc_4683472067_item	2425276	et	3	main
püüdis	doc_4683472067_item	2425292	et	3	main
19701985	doc_4683472067_item	2425294	et	2	main
kultuuriareaaliga	doc_4683472067_item	2425298	et	3	main
suur	doc_4683472067_item	2425303	et	3	main
loomeikka	doc_4683472067_item	2425309	et	3	main
oli	doc_4683472067_item	2425312	et	3	main
kirjanduse	doc_4683472067_item	2425314	et	3	main
heeliloomingu	doc_4683472067_item	2425315	et	4	main
oli	doc_4683472067_item	2425328	et	3	main
väga	doc_4683472067_item	2425329	et	3	main
oluline	doc_4683472067_item	2425330	et	4	main
fakt	doc_4683472067_item	2425331	et	3	main
alati	doc_4683472067_item	2425338	et	4	main
näitas	doc_4683472067_item	2425357	et	3	main
öölaulupeol	doc_4683472067_item	2425361	et	4	main
kokku	doc_4683472067_item	2425362	et	3	main
saanud	doc_4683472067_item	2425363	et	4	main
tuhad	doc_4683472067_item	2425364	et	3	main
enesekindlamaks	doc_4683472067_item	2425373	et	4	main
mis	doc_4683472067_item	2425374	et	4	main
väga	doc_4683472067_item	2425375	et	3	main
oluline	doc_4683472067_item	2425376	et	4	main
ja	doc_4683472067_item	2425381	et	3	main
avalikustamine	doc_4683472067_item	2425398	et	4	main
stalinismi	doc_4683472067_item	2425402	et	4	main
hõlmus	doc_4683472067_item	2425412	et	3	main
põhiliselt	doc_4683472067_item	2425415	et	4	main
impeeriumi	doc_4683472067_item	2425416	et	4	main
kritiliste	doc_4683472067_item	2425420	et	4	main
glasnostji	doc_4683472067_item	2425433	et	4	main
tegevus	doc_482578971776_item	2425446	et	4	main
toimub	doc_482578971776_item	2425447	et	3	main
end	doc_482578971776_item	2425452	et	4	main
ette	doc_482578971776_item	2425453	et	4	main
s	doc_482578971776_item	2425455	et	4	main
õ	doc_482578971776_item	2425456	et	4	main
ja	doc_482578971776_item	2425457	et	3	main
ning	doc_4683472066_item	2425024	et	3	main
rahvuslikud	doc_4683472066_item	2425025	et	3	main
suurenes	doc_4683472066_item	2425038	et	4	main
nende	doc_4683472066_item	2425041	et	4	main
haaras	doc_4683472066_item	2425051	et	4	main
tsaari	doc_4683472066_item	2425056	et	4	main
mängis	doc_4683472066_item	2425067	et	3	main
valgustaja	doc_4683472066_item	2425078	et	4	main
nõudis	doc_4683472066_item	2425081	et	3	main
põllumajanduslik	doc_4683472066_item	2425090	et	3	main
rahvastik	doc_4683472066_item	2425091	et	3	main
vähenes	doc_4683472066_item	2425092	et	3	main
tööstuslik	doc_4683472066_item	2425093	et	3	main
pooltootlik	doc_4683472066_item	2425094	et	3	main
suurenes	doc_4683472066_item	2425098	et	4	main
areng	doc_4683472066_item	2425100	et	3	main
jahutööstuse	doc_4683472066_item	2425108	et	3	main
laienemine	doc_4683472066_item	2425109	et	4	main
1900	doc_4683472066_item	2425110	et	2	main
1903	doc_4683472066_item	2425111	et	2	main
1917	doc_4683472066_item	2425113	et	2	main
majanduskriis	doc_4683472066_item	2425112	et	3	main
vene	doc_4683472066_item	2425114	et	4	main
ajutine	doc_4683472066_item	2425115	et	4	main
valitsus	doc_4683472066_item	2425116	et	4	main
autonoomia	doc_4683472066_item	2425117	et	4	main
eestimaa	doc_4683472066_item	2425118	et	4	main
ajutine	doc_4683472066_item	2425119	et	4	main
maanõukogu	doc_4683472066_item	2425120	et	4	main
24	doc_4683472066_item	2425137	et	2	main
veebruar	doc_4683472066_item	2425138	et	3	main
konstantin	doc_4683472066_item	2425144	et	4	main
okupatsiooni	doc_4683472066_item	2425152	et	4	main
a	doc_4683472066_item	2425161	et	4	main
vabadussõja	doc_4683472066_item	2425166	et	3	main
et	doc_4683472066_item	2425180	et	3	main
juba	doc_4683472066_item	2425182	et	3	main
jälle	doc_4683472066_item	2425203	et	3	main
1865	doc_4683472066_item	2425221	et	2	main
mänguseltsi	doc_4683472066_item	2425225	et	4	main
vanemuine	doc_4683472066_item	2425226	et	4	main
väga	doc_4683472066_item	2425227	et	3	main
kiiresti	doc_4683472066_item	2425228	et	3	main
hakkas	doc_4683472066_item	2425229	et	3	main
teadus	doc_4683472066_item	2425231	et	4	main
kultuurielu	doc_4683472066_item	2425233	et	4	main
jkross	doc_4683472066_item	2425255	et	4	main
1	doc_4683472067_item	2425257	et	2	main
1980	doc_4683472067_item	2425260	et	2	main
a-te	doc_4683472067_item	2425261	et	3	main
eesti	doc_4683472067_item	2425262	et	4	main
revolutsiooni	doc_4683472067_item	2425269	et	4	main
kultuurielu	doc_4683472067_item	2425284	et	4	main
oli	doc_4683472067_item	2425285	et	3	main
üsna	doc_4683472067_item	2425286	et	3	main
väärtuslik	doc_4683472067_item	2425287	et	3	main
ja	doc_4683472067_item	2425288	et	3	main
kunstikultuur	doc_4683472067_item	2425291	et	3	main
hoida	doc_4683472067_item	2425295	et	3	main
hulk	doc_4683472067_item	2425304	et	3	main
sellele	doc_4683472067_item	2425311	et	4	main
kunsti	doc_4683472067_item	2425317	et	4	main
olukord	doc_4683472067_item	2425318	et	3	main
stabiilselt	doc_4683472067_item	2425319	et	4	main
tasemel	doc_4683472067_item	2425321	et	3	main
perioodil	doc_4683472067_item	2425323	et	3	main
eesti	doc_4683472067_item	2425335	et	4	main
eesti	doc_4683472067_item	2425342	et	4	main
eesti	doc_4683472067_item	2425355	et	4	main
ühendas	doc_4683472067_item	2425367	et	3	main
rahvast	doc_4683472067_item	2425368	et	4	main
neid	doc_4683472067_item	2425370	et	4	main
vabadusi	doc_4683472066_item	2425060	et	4	main
aga	doc_4683472066_item	2425061	et	3	main
suurendati	doc_4683472066_item	2425062	et	3	main
majanduslikku	doc_4683472066_item	2425068	et	4	main
kasvatus	doc_4683472066_item	2425071	et	4	main
saj	doc_4683472066_item	2425073	et	4	main
vaimuelus	doc_4683472066_item	2425077	et	4	main
eestlastele	doc_4683472066_item	2425082	et	4	main
võrdseid	doc_4683472066_item	2425085	et	3	main
õigusi	doc_4683472066_item	2425086	et	4	main
1987	doc_4683472066_item	2425087	et	2	main
laienes	doc_4683472066_item	2425103	et	3	main
ja	doc_4683472066_item	2425106	et	3	main
ajutine	doc_4683472066_item	2425141	et	4	main
peaministr	doc_4683472066_item	2425143	et	4	main
päts	doc_4683472066_item	2425145	et	3	main
kogu	doc_4683472066_item	2425146	et	4	main
võim	doc_4683472066_item	2425147	et	3	main
lätis	doc_4683472066_item	2425148	et	4	main
saksa	doc_4683472066_item	2425155	et	4	main
revolutsioon	doc_4683472066_item	2425156	et	3	main
tulemusena	doc_4683472066_item	2425158	et	3	main
compiegne	doc_4683472066_item	2425163	et	4	main
tahtsid	doc_4683472066_item	2425176	et	4	main
paremat	doc_4683472066_item	2425177	et	4	main
raske	doc_4683472066_item	2425184	et	4	main
kõik	doc_4683472066_item	2425186	et	4	main
majanduslikud	doc_4683472066_item	2425187	et	3	main
kriisid	doc_4683472066_item	2425188	et	3	main
tarbekaupade	doc_4683472066_item	2425189	et	3	main
põhjustas	doc_4683472066_item	2425191	et	3	main
hinnatõusu	doc_4683472066_item	2425192	et	4	main
ja	doc_4683472066_item	2425193	et	3	main
saja-aastast	doc_4683472066_item	2425200	et	4	main
tartu	doc_4683472066_item	2425204	et	4	main
asutati	doc_4683472066_item	2425222	et	4	main
ja	doc_4683472066_item	2425224	et	3	main
ii	doc_4683472066_item	2425235	et	4	main
olid	doc_4683472066_item	2425239	et	4	main
ja	doc_4683472066_item	2425241	et	3	main
oli	doc_4683472066_item	2425254	et	3	main
nn	doc_4683472067_item	2425265	et	4	main
öölaulupidude	doc_4683472067_item	2425266	et	4	main
ja	doc_4683472067_item	2425267	et	3	main
laulva	doc_4683472067_item	2425268	et	4	main
glasnostj	doc_4683472067_item	2425277	et	4	main
tähendus	doc_4683472067_item	2425278	et	4	main
ja	doc_4683472067_item	2425279	et	3	main
silmapaistev	doc_4683472067_item	2425289	et	4	main
alustanud	doc_4683472067_item	2425306	et	4	main
parimasse	doc_4683472067_item	2425308	et	4	main
tänu	doc_4683472067_item	2425310	et	4	main
eesti	doc_4683472067_item	2425313	et	4	main
kõrgel	doc_4683472067_item	2425320	et	4	main
sellel	doc_4683472067_item	2425322	et	4	main
eesti	doc_4683472067_item	2425325	et	4	main
ajaloos	doc_4683472067_item	2425336	et	4	main
suur	doc_4683472067_item	2425340	et	3	main
eesti	doc_4683472067_item	2425344	et	4	main
järgi	doc_4683472067_item	2425354	et	4	main
iseloom	doc_4683472067_item	2425359	et	3	main
jõud	doc_4683472067_item	2425360	et	4	main
tegi	doc_4683472067_item	2425369	et	4	main
perestroika	doc_4683472067_item	2425380	et	4	main
need	doc_4683472067_item	2425383	et	3	main
kuuluvad	doc_4683472067_item	2425385	et	4	main
a	doc_4683472067_item	2425388	et	4	main
kui	doc_4683472067_item	2425389	et	3	main
tähendavad	doc_4683472067_item	2425397	et	4	main
inimene	doc_4683472067_item	2425410	et	3	main
see	doc_4683472067_item	2425413	et	3	main
kubermangukomissar	doc_4683472066_item	2425122	et	3	main
asendati	doc_4683472066_item	2425129	et	3	main
vene	doc_4683472066_item	2425130	et	4	main
ametnikud	doc_4683472066_item	2425131	et	3	main
eestlastega	doc_4683472066_item	2425132	et	4	main
otsustati	doc_4683472066_item	2425133	et	3	main
kehtestada	doc_4683472066_item	2425134	et	3	main
emakeelne	doc_4683472066_item	2425135	et	3	main
kooliharidus	doc_4683472066_item	2425136	et	3	main
1918	doc_4683472066_item	2425139	et	2	main
eestis	doc_4683472066_item	2425150	et	3	main
alla	doc_4683472066_item	2425162	et	3	main
kõik	doc_4683472066_item	2425175	et	4	main
sellepärast	doc_4683472066_item	2425179	et	3	main
nii	doc_4683472066_item	2425183	et	3	main
inflatsiooni	doc_4683472066_item	2425195	et	4	main
3	doc_4683472066_item	2425196	et	2	main
1802	doc_4683472066_item	2425197	et	2	main
aasta	doc_4683472066_item	2425198	et	4	main
avati	doc_4683472066_item	2425202	et	3	main
tartus	doc_4683472066_item	2425206	et	3	main
töötas	doc_4683472066_item	2425207	et	3	main
palju	doc_4683472066_item	2425209	et	4	main
näiteks	doc_4683472066_item	2425212	et	4	main
embrioloogia	doc_4683472066_item	2425213	et	4	main
rajaja	doc_4683472066_item	2425214	et	4	main
kn	doc_4683472066_item	2425215	et	4	main
von	doc_4683472066_item	2425216	et	4	main
baer	doc_4683472066_item	2425217	et	4	main
astronoom	doc_4683472066_item	2425218	et	3	main
fg	doc_4683472066_item	2425219	et	4	main
struve	doc_4683472066_item	2425220	et	4	main
laulu-	doc_4683472066_item	2425223	et	4	main
ja	doc_4683472066_item	2425232	et	3	main
pärast	doc_4683472066_item	2425234	et	4	main
levinud	doc_4683472066_item	2425238	et	4	main
laulupeod	doc_4683472066_item	2425240	et	4	main
tantsimispeod	doc_4683472066_item	2425242	et	4	main
üks	doc_4683472066_item	2425252	et	3	main
iseloomustage	doc_4683472067_item	2425258	et	4	main
kultuurielu	doc_4683472067_item	2425263	et	4	main
2	doc_4683472067_item	2425264	et	2	main
osa	doc_4683472067_item	2425270	et	4	main
sisu	doc_4683472067_item	2425280	et	4	main
1	doc_4683472067_item	2425281	et	2	main
19701980a-te	doc_4683472067_item	2425282	et	3	main
eesti	doc_4683472067_item	2425290	et	4	main
just	doc_4683472067_item	2425299	et	3	main
noortest	doc_4683472067_item	2425307	et	4	main
mis	doc_4683472067_item	2425327	et	4	main
väga	doc_4683472066_item	2425237	et	3	main
tööd	doc_4683472066_item	2425245	et	4	main
kirjutada	doc_4683472066_item	2425246	et	3	main
novelle	doc_4683472066_item	2425247	et	3	main
ja	doc_4683472066_item	2425248	et	3	main
luuletusi	doc_4683472066_item	2425249	et	4	main
paljud	doc_4683472066_item	2425250	et	3	main
autorid	doc_4683472066_item	2425251	et	3	main
nendes	doc_4683472066_item	2425253	et	4	main
eesti	doc_4683472067_item	2425271	et	4	main
taasiseseisvumisel	doc_4683472067_item	2425272	et	3	main
eesti	doc_4683472067_item	2425283	et	4	main
ka	doc_4683472067_item	2425293	et	3	main
sidet	doc_4683472067_item	2425296	et	4	main
läänepoolse	doc_4683472067_item	2425297	et	3	main
sellel	doc_4683472067_item	2425300	et	4	main
etaapil	doc_4683472067_item	2425301	et	4	main
jõudis	doc_4683472067_item	2425302	et	3	main
eelmiselkümnendal	doc_4683472067_item	2425305	et	4	main
kujutava	doc_4683472067_item	2425316	et	4	main
jõudis	doc_4683472067_item	2425324	et	3	main
filmikunst	doc_4683472067_item	2425326	et	3	main
2	doc_4683472067_item	2425334	et	2	main
laulupeod	doc_4683472067_item	2425337	et	4	main
osa	doc_4683472067_item	2425341	et	4	main
rahvaks	doc_4683472067_item	2425343	et	3	main
taasiseseisvumise	doc_4683472067_item	2425345	et	3	main
perioodil	doc_4683472067_item	2425346	et	3	main
rahvas	doc_4683472067_item	2425356	et	4	main
laulupidu	doc_4683472067_item	2425366	et	4	main
3	doc_4683472067_item	2425379	et	2	main
sõnad	doc_4683472067_item	2425384	et	4	main
peaministriks	doc_4683472067_item	2425391	et	3	main
oli	doc_4683472067_item	2425392	et	3	main
gorbatshov	doc_4683472067_item	2425394	et	4	main
need	doc_4683472067_item	2425395	et	3	main
sõnad	doc_4683472067_item	2425396	et	4	main
rahvas	doc_4683472067_item	2425399	et	4	main
väga	doc_4683472067_item	2425408	et	3	main
küll	doc_4683472067_item	2425414	et	4	main
võimalikuks	doc_4683472067_item	2425419	et	3	main
teemal	doc_4683472067_item	2425424	et	3	main
keskkonnaprobleemid	doc_4683472067_item	2425425	et	3	main
olnud	doc_4683472067_item	2425429	et	4	main
olemas	doc_4683472067_item	2425430	et	4	main
ilmselt	doc_4683472067_item	2425432	et	4	main
leninid	doc_482578971776_item	2425442	et	4	main
minu	doc_482578971776_item	2425444	et	3	main
leninid	doc_482578971776_item	2425445	et	4	main
saksamaa	doc_482578971776_item	2425450	et	4	main
tulevase	doc_482578971776_item	2425454	et	4	main
kino	doc_482578971776_item	2425471	et	4	main
on	doc_482578971776_item	2425472	et	4	main
tema	doc_482578971776_item	2425477	et	4	main
suure	doc_482578971776_item	2425478	et	3	main
elueesmärgile	doc_482578971776_item	2425479	et	3	main
ehk	doc_482578971776_item	2425480	et	3	main
ülesehitamisele	doc_482578971776_item	2425483	et	3	main
usaldust	doc_482578971776_item	2425497	et	4	main
vaid	doc_482578971776_item	2425498	et	3	main
temast	doc_482578971776_item	2425499	et	3	main
sai	doc_482578971776_item	2425500	et	4	main
ka	doc_482578971776_item	2425501	et	3	main
oli	doc_482578971776_item	2425508	et	3	main
päris	doc_482578971776_item	2425509	et	4	main
hea	doc_482578971776_item	2425510	et	4	main
tema	doc_482578971776_item	2425515	et	4	main
välja	doc_482578971776_item	2425532	et	4	main
mehi	doc_482578971776_item	2425533	et	3	main
kes	doc_482578971776_item	2425534	et	4	main
sarnasid	doc_482578971776_item	2425535	et	3	main
bolševikide	doc_482578971776_item	2425536	et	2	main
liidriga	doc_482578971776_item	2425537	et	3	main
kaitsmise	doc_482578971776_item	2425546	et	4	main
koolitas	doc_482578971776_item	2425549	et	3	main
oleks	doc_482578971776_item	2425555	et	3	main
lenini	doc_482578971776_item	2425556	et	4	main
sotsiaaldemokraatide	doc_482578971776_item	2425559	et	3	main
aitas	doc_482578971776_item	2425561	et	3	main
eestimaale	doc_482578971776_item	2425570	et	4	main
sõltumatuse	doc_482578971776_item	2425571	et	4	main
kinkida	doc_482578971776_item	2425572	et	3	main
peas	doc_482578971776_item	2425574	et	4	main
teine	doc_482578971776_item	2425576	et	3	main
ning	doc_482578971776_item	2425578	et	3	main
asetas	doc_482578971776_item	2425580	et	3	main
nimega	doc_482578971776_item	2425584	et	3	main
vanja	doc_482578971776_item	2425585	et	4	main
pärast	doc_482578971776_item	2425589	et	4	main
laps	doc_482578971776_item	2425621	et	4	main
eesti	doc_4683472067_item	2425332	et	4	main
kultuurieluks	doc_4683472067_item	2425333	et	3	main
võttis	doc_4683472067_item	2425339	et	3	main
laulupeod	doc_4683472067_item	2425347	et	4	main
korraldati	doc_4683472067_item	2425348	et	3	main
öösel	doc_4683472067_item	2425349	et	4	main
aga	doc_4683472067_item	2425350	et	3	main
muidugi	doc_4683472067_item	2425351	et	4	main
laulva	doc_4683472067_item	2425352	et	4	main
revolutsiooni	doc_4683472067_item	2425353	et	4	main
oma	doc_4683472067_item	2425358	et	4	main
inimesi	doc_4683472067_item	2425365	et	4	main
sellisel	doc_4683472067_item	2425377	et	4	main
ajajooksul	doc_4683472067_item	2425378	et	3	main
umbes	doc_4683472067_item	2425386	et	4	main
1985	doc_4683472067_item	2425387	et	2	main
mihhail	doc_4683472067_item	2425393	et	4	main
sai	doc_4683472067_item	2425400	et	4	main
teada	doc_4683472067_item	2425401	et	3	main
kuriteodest	doc_4683472067_item	2425403	et	4	main
et	doc_4683472067_item	2425404	et	3	main
istalin	doc_4683472067_item	2425405	et	4	main
tegelikult	doc_4683472067_item	2425406	et	4	main
oli	doc_4683472067_item	2425407	et	3	main
esialgu	doc_4683472067_item	2425411	et	3	main
keskust	doc_4683472067_item	2425417	et	4	main
kaudu	doc_4683472067_item	2425434	et	3	main
inimesed	doc_4683472067_item	2425435	et	3	main
teada	doc_4683472067_item	2425438	et	3	main
arvustus	doc_482578971776_item	2425440	et	4	main
valmistas	doc_482578971776_item	2425451	et	3	main
üsna	doc_482578971776_item	2425461	et	3	main
rohkem	doc_482578971776_item	2425462	et	4	main
ja	doc_482578971776_item	2425463	et	3	main
rohkem	doc_482578971776_item	2425464	et	4	main
kasvas	doc_482578971776_item	2425465	et	3	main
suurvabariigi	doc_482578971776_item	2425482	et	3	main
keskküla	doc_482578971776_item	2425484	et	4	main
ning	doc_482578971776_item	2425516	et	3	main
valitsema	doc_482578971776_item	2425521	et	3	main
aitamise	doc_482578971776_item	2425523	et	4	main
kinkima	doc_482578971776_item	2425529	et	3	main
aleksender	doc_482578971776_item	2425530	et	4	main
otsis	doc_482578971776_item	2425531	et	4	main
on	doc_482578971776_item	2425543	et	4	main
ta	doc_482578971776_item	2425544	et	4	main
käitumine	doc_482578971776_item	2425554	et	4	main
hiljem	doc_482578971776_item	2425563	et	3	main
mõistis	doc_482578971776_item	2425565	et	4	main
uppus	doc_482578971776_item	2425587	et	3	main
meres	doc_482578971776_item	2425588	et	3	main
ei	doc_482578971776_item	2425622	et	4	main
ning	doc_482578971776_item	2425630	et	3	main
omakasupüüdlematu	doc_482578971776_item	2425631	et	4	main
kangelasi	doc_482578971776_item	2425638	et	3	main
on	doc_482578971776_item	2425639	et	4	main
väga	doc_482578971776_item	2425640	et	3	main
vähe	doc_482578971776_item	2425641	et	3	main
tanapäevases	doc_482578971776_item	2425642	et	4	main
kinematograafias	doc_482578971776_item	2425643	et	3	main
seas	doc_482578971776_item	2425647	et	4	main
ei	doc_482578971776_item	2425649	et	4	main
ole	doc_482578971776_item	2425650	et	4	main
nil	doc_482578971776_item	2425651	et	4	main
populaarne	doc_482578971776_item	2425652	et	3	main
mõned	doc_482578971776_item	2425653	et	3	main
kaltsakad	doc_482578971776_item	2425684	et	3	main
autori	doc_482578971776_item	2425701	et	3	main
ning	doc_482578971776_item	2425708	et	3	main
tema	doc_482578971776_item	2425709	et	4	main
teisikud	doc_482578971776_item	2425710	et	3	main
julgemaks	doc_4683472067_item	2425371	et	4	main
ja	doc_4683472067_item	2425372	et	3	main
glasnostj	doc_4683472067_item	2425382	et	4	main
nsvl	doc_4683472067_item	2425390	et	4	main
hirmus	doc_4683472067_item	2425409	et	4	main
kus	doc_4683472067_item	2425418	et	3	main
seisukohtade	doc_4683472067_item	2425421	et	3	main
sellisel	doc_4683472067_item	2425423	et	4	main
aga	doc_4683472067_item	2425431	et	3	main
tõde	doc_4683472067_item	2425437	et	4	main
minu	doc_482578971776_item	2425441	et	3	main
filmi	doc_482578971776_item	2425443	et	4	main
jaoks	doc_482578971776_item	2425458	et	4	main
venemaal	doc_482578971776_item	2425459	et	4	main
aga	doc_482578971776_item	2425460	et	3	main
vahel	doc_482578971776_item	2425470	et	4	main
keskküla	doc_482578971776_item	2425475	et	4	main
ning	doc_482578971776_item	2425476	et	3	main
oli	doc_482578971776_item	2425485	et	3	main
mees	doc_482578971776_item	2425489	et	4	main
kes	doc_482578971776_item	2425490	et	4	main
mitte	doc_482578971776_item	2425491	et	3	main
ainult	doc_482578971776_item	2425492	et	4	main
suudas	doc_482578971776_item	2425493	et	4	main
hea	doc_482578971776_item	2425502	et	4	main
v	doc_482578971776_item	2425503	et	4	main
ta	doc_482578971776_item	2425511	et	4	main
aitab	doc_482578971776_item	2425512	et	3	main
vabaduse	doc_482578971776_item	2425528	et	4	main
lenenile	doc_482578971776_item	2425538	et	4	main
aga	doc_482578971776_item	2425539	et	3	main
selgitas	doc_482578971776_item	2425540	et	3	main
et	doc_482578971776_item	2425541	et	3	main
jaoks	doc_482578971776_item	2425547	et	4	main
ta	doc_482578971776_item	2425548	et	4	main
välja	doc_482578971776_item	2425551	et	4	main
liider	doc_482578971776_item	2425560	et	3	main
keskküla	doc_482578971776_item	2425564	et	4	main
ei	doc_482578971776_item	2425568	et	4	main
kavatsegi	doc_482578971776_item	2425569	et	4	main
sündis	doc_482578971776_item	2425575	et	3	main
plaan	doc_482578971776_item	2425577	et	3	main
aleksander	doc_482578971776_item	2425579	et	4	main
lenini	doc_482578971776_item	2425581	et	4	main
koha	doc_482578971776_item	2425582	et	4	main
teisikuga	doc_482578971776_item	2425583	et	3	main
avaldamine	doc_4683472067_item	2425422	et	4	main
muidugi	doc_4683472067_item	2425426	et	4	main
need	doc_4683472067_item	2425427	et	3	main
alati	doc_4683472067_item	2425428	et	4	main
said	doc_4683472067_item	2425436	et	4	main
arvustus	doc_482578971776_item	2425439	et	4	main
ajal	doc_482578971776_item	2425448	et	4	main
millal	doc_482578971776_item	2425449	et	3	main
ja	doc_482578971776_item	2425468	et	3	main
sotsiaaldemokraatia	doc_482578971776_item	2425469	et	4	main
ja	doc_482578971776_item	2425487	et	3	main
välja	doc_482578971776_item	2425494	et	4	main
teenida	doc_482578971776_item	2425495	et	3	main
lennini	doc_482578971776_item	2425504	et	4	main
lenenile	doc_482578971776_item	2425513	et	4	main
sotsiaaldemokraatid	doc_482578971776_item	2425517	et	4	main
hakkaksid	doc_482578971776_item	2425518	et	4	main
tulevikus	doc_482578971776_item	2425519	et	4	main
venemaad	doc_482578971776_item	2425520	et	4	main
lenin	doc_482578971776_item	2425525	et	4	main
peab	doc_482578971776_item	2425526	et	4	main
eestimaale	doc_482578971776_item	2425527	et	4	main
elu	doc_482578971776_item	2425545	et	4	main
et	doc_482578971776_item	2425552	et	3	main
sarnane	doc_482578971776_item	2425558	et	4	main
et	doc_482578971776_item	2425566	et	3	main
bolševik	doc_482578971776_item	2425567	et	2	main
tema	doc_482578971776_item	2425573	et	4	main
lenin	doc_482578971776_item	2425586	et	4	main
meelelahutused	doc_482578971776_item	2425668	et	4	main
baaris	doc_482578971776_item	2425674	et	3	main
lõppus	doc_482578971776_item	2425675	et	4	main
teisikud	doc_482578971776_item	2425679	et	3	main
vargad	doc_482578971776_item	2425683	et	3	main
ja	doc_482578971776_item	2425686	et	3	main
nõrk	doc_482578971776_item	2425717	et	3	main
lõppuks	doc_482578971776_item	2425719	et	3	main
segi	doc_482578971776_item	2425721	et	3	main
ning	doc_482578971776_item	2425723	et	3	main
ja	doc_482578971776_item	2425733	et	3	main
kaudu	doc_482578971776_item	2425741	et	3	main
tabab	doc_482578971776_item	2425744	et	3	main
tõeliseks	doc_482578971776_item	2425751	et	4	main
ning	doc_482578971776_item	2425752	et	3	main
ehk	doc_482578971776_item	2425754	et	3	main
on	doc_482578971776_item	2425761	et	4	main
hull	doc_482578971776_item	2425762	et	3	main
aga	doc_482578971776_item	2425766	et	3	main
lenin	doc_482578971776_item	2425774	et	4	main
erineb	doc_482578971776_item	2425779	et	3	main
mitte	doc_482578971776_item	2425796	et	3	main
kui	doc_482578971776_item	2425798	et	3	main
ta	doc_482578971776_item	2425803	et	4	main
oli	doc_482578971776_item	2425804	et	3	main
monopolijate	doc_482578971776_item	2425805	et	4	main
hundiseaduste	doc_482578971776_item	2425808	et	4	main
kiri	doc_482578971777_item	2425810	et	3	main
tekis	doc_482578971777_item	2425813	et	3	main
probleem	doc_482578971777_item	2425814	et	3	main
võitlus	doc_482578971776_item	2425466	et	3	main
tsarismi	doc_482578971776_item	2425467	et	4	main
pühendatud	doc_482578971776_item	2425473	et	4	main
aleksandrile	doc_482578971776_item	2425474	et	4	main
eesti	doc_482578971776_item	2425481	et	4	main
noor	doc_482578971776_item	2425486	et	3	main
haritud	doc_482578971776_item	2425488	et	4	main
saksavalitsuse	doc_482578971776_item	2425496	et	3	main
sõber	doc_482578971776_item	2425505	et	3	main
tema	doc_482578971776_item	2425506	et	4	main
esmaplaan	doc_482578971776_item	2425507	et	3	main
et	doc_482578971776_item	2425514	et	3	main
selle	doc_482578971776_item	2425522	et	4	main
vastu	doc_482578971776_item	2425524	et	3	main
see	doc_482578971776_item	2425542	et	3	main
neid	doc_482578971776_item	2425550	et	4	main
nende	doc_482578971776_item	2425553	et	4	main
omaga	doc_482578971776_item	2425557	et	3	main
protsessile	doc_482578971776_item	2425562	et	3	main
hakkasid	doc_482578971776_item	2425590	et	4	main
venemaad	doc_482578971776_item	2425591	et	4	main
valitsema	doc_482578971776_item	2425592	et	3	main
need	doc_482578971776_item	2425593	et	3	main
teisikud	doc_482578971776_item	2425594	et	3	main
filmis	doc_482578971776_item	2425595	et	4	main
mulle	doc_482578971776_item	2425596	et	4	main
meeldis	doc_482578971776_item	2425597	et	3	main
kuidas	doc_482578971776_item	2425598	et	3	main
autor	doc_482578971776_item	2425599	et	3	main
a	doc_482578971776_item	2425600	et	4	main
keskküla	doc_482578971776_item	2425601	et	4	main
kaudu	doc_482578971776_item	2425602	et	3	main
näitas	doc_482578971776_item	2425603	et	3	main
tõelist	doc_482578971776_item	2425604	et	4	main
patriotism	doc_482578971776_item	2425605	et	3	main
see	doc_482578971776_item	2425606	et	3	main
sangar	doc_482578971776_item	2425607	et	3	main
riskis	doc_482578971776_item	2425608	et	4	main
eluga	doc_482578971776_item	2425609	et	3	main
oma	doc_482578971776_item	2425610	et	4	main
eesmärgi	doc_482578971776_item	2425611	et	4	main
jaoks	doc_482578971776_item	2425612	et	4	main
ta	doc_482578971776_item	2425613	et	4	main
pühendas	doc_482578971776_item	2425614	et	3	main
sellele	doc_482578971776_item	2425615	et	4	main
terve	doc_482578971776_item	2425616	et	4	main
elu	doc_482578971776_item	2425617	et	4	main
isegi	doc_482578971776_item	2425618	et	4	main
name	doc_482578971776_item	2425619	et	4	main
ja	doc_482578971776_item	2425620	et	3	main
olulised	doc_482578971776_item	2425626	et	4	main
isamaa-armastus	doc_482578971776_item	2425632	et	4	main
usk	doc_482578971776_item	2425633	et	3	main
sünnimaa	doc_482578971776_item	2425634	et	4	main
tema	doc_482578971776_item	2425676	et	4	main
olid	doc_482578971776_item	2425681	et	4	main
endised	doc_482578971776_item	2425682	et	3	main
mõrtsukad	doc_482578971776_item	2425685	et	3	main
ühiskonna	doc_482578971776_item	2425688	et	4	main
filmi	doc_482578971776_item	2425695	et	4	main
arvan	doc_482578971776_item	2425699	et	3	main
oli	doc_482578971776_item	2425704	et	3	main
tema	doc_482578971776_item	2425628	et	4	main
tugev	doc_482578971776_item	2425629	et	4	main
tulevikusse	doc_482578971776_item	2425636	et	4	main
niisuguseid	doc_482578971776_item	2425637	et	3	main
noorte	doc_482578971776_item	2425645	et	3	main
isegi	doc_482578971776_item	2425654	et	4	main
seda	doc_482578971776_item	2425655	et	3	main
tunnet	doc_482578971776_item	2425656	et	3	main
häbenevad	doc_482578971776_item	2425657	et	4	main
v	doc_482578971776_item	2425658	et	4	main
lenin	doc_482578971776_item	2425659	et	4	main
näidati	doc_482578971776_item	2425660	et	3	main
jõhkra	doc_482578971776_item	2425661	et	3	main
taktitundetu	doc_482578971776_item	2425662	et	4	main
ning	doc_482578971776_item	2425663	et	3	main
rumala	doc_482578971776_item	2425664	et	3	main
joodikuna	doc_482578971776_item	2425665	et	3	main
kelle	doc_482578971776_item	2425666	et	4	main
olnud	doc_482578971776_item	2425623	et	4	main
talle	doc_482578971776_item	2425624	et	4	main
nii	doc_482578971776_item	2425625	et	3	main
kui	doc_482578971776_item	2425627	et	3	main
hea	doc_482578971776_item	2425635	et	4	main
praegu	doc_482578971776_item	2425644	et	3	main
inimeste	doc_482578971776_item	2425646	et	3	main
patriotism	doc_482578971776_item	2425648	et	3	main
lemmikud	doc_482578971776_item	2425667	et	3	main
olid	doc_482578971776_item	2425669	et	4	main
lõbutudrukud	doc_482578971776_item	2425670	et	4	main
ning	doc_482578971776_item	2425671	et	3	main
kaklused	doc_482578971776_item	2425672	et	3	main
kusagil	doc_482578971776_item	2425673	et	3	main
tulid	doc_482578971776_item	2425678	et	4	main
idee	doc_482578971776_item	2425696	et	4	main
valesti	doc_482578971776_item	2425697	et	3	main
aga	doc_482578971776_item	2425698	et	3	main
jaoks	doc_482578971776_item	2425702	et	4	main
lenin	doc_482578971776_item	2425703	et	4	main
kõikide	doc_482578971776_item	2425705	et	4	main
oli	doc_482578971776_item	2425715	et	3	main
režissööril	doc_482578971776_item	2425722	et	2	main
mängival	doc_482578971776_item	2425725	et	4	main
õnnestus	doc_482578971776_item	2425727	et	4	main
silmides	doc_482578971776_item	2425736	et	3	main
ja	doc_482578971776_item	2425737	et	3	main
kus	doc_482578971776_item	2425742	et	3	main
kohal	doc_482578971776_item	2425746	et	4	main
temas	doc_482578971776_item	2425753	et	3	main
teisikku	doc_482578971776_item	2425758	et	4	main
miks	doc_482578971776_item	2425765	et	4	main
oma	doc_482578971776_item	2425778	et	4	main
režissööri	doc_482578971776_item	2425780	et	2	main
ma	doc_482578971776_item	2425782	et	3	main
aeg	doc_482578971776_item	2425784	et	3	main
teda	doc_482578971776_item	2425786	et	4	main
kes	doc_482578971776_item	2425793	et	4	main
vähem	doc_482578971776_item	2425797	et	4	main
töötajate	doc_482578971776_item	2425809	et	4	main
tere	doc_482578971777_item	2425811	et	3	main
tööl	doc_482578971777_item	2425820	et	3	main
kuidagi	doc_482578971777_item	2425822	et	3	main
kuid	doc_482578971777_item	2425824	et	4	main
tulnud	doc_482578971777_item	2425826	et	4	main
teha	doc_482578971777_item	2425832	et	3	main
olete	doc_482578971777_item	2425837	et	3	main
jaoks	doc_485437783973_item	2425863	et	4	main
inimeste	doc_485437783973_item	2425864	et	3	main
mentaliteet	doc_485437783973_item	2425865	et	3	main
poeedid	doc_485437783973_item	2425870	et	3	main
kultuuri	doc_485437783973_item	2425883	et	4	main
arengus	doc_485437783973_item	2425884	et	3	main
väikesed	doc_485437783973_item	2425885	et	4	main
külad	doc_485437783973_item	2425886	et	3	main
eesti	doc_485437783973_item	2425897	et	4	main
asemele	doc_482578971776_item	2425677	et	4	main
nad	doc_482578971776_item	2425680	et	3	main
muud	doc_482578971776_item	2425687	et	4	main
madalamad	doc_482578971776_item	2425689	et	4	main
osad	doc_482578971776_item	2425690	et	3	main
võib	doc_482578971776_item	2425691	et	3	main
olla	doc_482578971776_item	2425692	et	3	main
ma	doc_482578971776_item	2425693	et	3	main
mõistsin	doc_482578971776_item	2425694	et	3	main
et	doc_482578971776_item	2425700	et	3	main
olidki	doc_482578971776_item	2425711	et	4	main
need	doc_482578971776_item	2425712	et	3	main
pahed	doc_482578971776_item	2425713	et	3	main
ta	doc_482578971776_item	2425714	et	4	main
lenini	doc_482578971776_item	2425724	et	4	main
näitlejal	doc_482578971776_item	2425726	et	4	main
tõelist	doc_482578971776_item	2425729	et	4	main
lenin	doc_482578971776_item	2425743	et	4	main
oma	doc_482578971776_item	2425745	et	4	main
teisiku	doc_482578971776_item	2425747	et	3	main
kelle	doc_482578971776_item	2425748	et	4	main
õiges	doc_482578971776_item	2425755	et	3	main
näevad	doc_482578971776_item	2425757	et	3	main
kes	doc_482578971776_item	2425759	et	4	main
lihtsalt	doc_482578971776_item	2425760	et	4	main
tea	doc_482578971776_item	2425764	et	4	main
161k	doc_482578971776_item	2425768	et	4	main
kuidagi	doc_482578971776_item	2425770	et	3	main
selline	doc_482578971776_item	2425772	et	4	main
on	doc_482578971776_item	2425773	et	4	main
minu	doc_482578971776_item	2425777	et	3	main
ette	doc_482578971776_item	2425787	et	4	main
targaks	doc_482578971776_item	2425788	et	3	main
ning	doc_482578971776_item	2425789	et	3	main
hea	doc_482578971776_item	2425790	et	4	main
haridusega	doc_482578971776_item	2425791	et	3	main
oma	doc_482578971776_item	2425801	et	4	main
sünnimaad	doc_482578971776_item	2425802	et	4	main
mul	doc_482578971777_item	2425812	et	3	main
olen	doc_482578971777_item	2425815	et	3	main
nädalal	doc_482578971777_item	2425817	et	3	main
ei	doc_482578971777_item	2425825	et	4	main
nädalal	doc_482578971777_item	2425834	et	3	main
tänan	doc_482578971777_item	2425839	et	3	main
küsimusele	doc_485437783973_item	2425843	et	4	main
1	doc_485437783973_item	2425844	et	2	main
kultuur	doc_485437783973_item	2425845	et	3	main
areng	doc_485437783973_item	2425846	et	3	main
eesti	doc_485437783973_item	2425857	et	4	main
riigi	doc_485437783973_item	2425866	et	3	main
kunstnikud	doc_485437783973_item	2425868	et	3	main
osalised	doc_485437783973_item	2425881	et	4	main
eesti	doc_485437783973_item	2425882	et	4	main
toit	doc_485437783973_item	2425888	et	3	main
kaunistused	doc_485437783973_item	2425891	et	4	main
ja	doc_485437783973_item	2425893	et	3	main
inimpattude	doc_482578971776_item	2425706	et	3	main
kehastus	doc_482578971776_item	2425707	et	4	main
nii	doc_482578971776_item	2425716	et	3	main
et	doc_482578971776_item	2425718	et	3	main
läks	doc_482578971776_item	2425720	et	3	main
hirmu	doc_482578971776_item	2425730	et	4	main
pettumust	doc_482578971776_item	2425731	et	4	main
tähtsusetust	doc_482578971776_item	2425734	et	4	main
see	doc_482578971776_item	2425767	et	3	main
jäi	doc_482578971776_item	2425769	et	3	main
hingesse	doc_482578971776_item	2425771	et	4	main
jaoks	doc_482578971776_item	2425776	et	4	main
meheks	doc_482578971776_item	2425792	et	3	main
kapitalismi	doc_482578971776_item	2425807	et	4	main
päevad	doc_482578971777_item	2425819	et	3	main
püüdsin	doc_482578971777_item	2425821	et	3	main
välja	doc_482578971777_item	2425828	et	4	main
kui	doc_482578971777_item	2425835	et	3	main
tallinnas	doc_482578971777_item	2425838	et	4	main
j	doc_482578971777_item	2425840	et	4	main
i	doc_482578971777_item	2425841	et	4	main
vastus	doc_485437783973_item	2425842	et	3	main
ühiskond	doc_485437783973_item	2425850	et	3	main
inimese	doc_485437783973_item	2425853	et	4	main
kultuur	doc_485437783973_item	2425855	et	3	main
on	doc_485437783973_item	2425873	et	4	main
ja	doc_485437783973_item	2425876	et	3	main
rahva	doc_485437783973_item	2425889	et	3	main
eesti	doc_485437783973_item	2425895	et	4	main
ajalugu	doc_485437783973_item	2425896	et	4	main
näidata	doc_482578971776_item	2425728	et	4	main
abitust	doc_482578971776_item	2425732	et	4	main
inimese	doc_482578971776_item	2425735	et	4	main
käitumises	doc_482578971776_item	2425738	et	4	main
too	doc_482578971776_item	2425739	et	4	main
episoodi	doc_482578971776_item	2425740	et	4	main
kõik	doc_482578971776_item	2425749	et	4	main
peavad	doc_482578971776_item	2425750	et	4	main
lenenis	doc_482578971776_item	2425756	et	4	main
el	doc_482578971776_item	2425763	et	4	main
lavastaja	doc_482578971776_item	2425775	et	4	main
kangelasest	doc_482578971776_item	2425781	et	3	main
kogu	doc_482578971776_item	2425783	et	4	main
kujutlesin	doc_482578971776_item	2425785	et	3	main
armastas	doc_482578971776_item	2425794	et	3	main
venemaad	doc_482578971776_item	2425795	et	4	main
a	doc_482578971776_item	2425799	et	4	main
keskküla	doc_482578971776_item	2425800	et	4	main
ülemvõimu	doc_482578971776_item	2425806	et	4	main
sellel	doc_482578971777_item	2425816	et	4	main
kõik	doc_482578971777_item	2425818	et	4	main
midagi	doc_482578971777_item	2425827	et	4	main
eksamit	doc_482578971777_item	2425831	et	3	main
järgmisel	doc_482578971777_item	2425833	et	3	main
maailma	doc_485437783973_item	2425847	et	4	main
arkitektuur	doc_485437783973_item	2425848	et	4	main
meie	doc_485437783973_item	2425849	et	4	main
ajalugu	doc_485437783973_item	2425852	et	4	main
areng	doc_485437783973_item	2425867	et	3	main
heliloojad	doc_485437783973_item	2425869	et	3	main
eestist	doc_485437783973_item	2425875	et	3	main
kõik	doc_485437783973_item	2425877	et	4	main
need	doc_485437783973_item	2425878	et	3	main
inimesed	doc_485437783973_item	2425879	et	3	main
kes	doc_485437783973_item	2425880	et	4	main
riietus	doc_485437783973_item	2425890	et	4	main
sümboleid	doc_485437783973_item	2425892	et	3	main
lipp	doc_485437783973_item	2425894	et	3	main
kuidas	doc_485437783975_item	2426076	et	3	main
mingi	doc_485437783975_item	2426079	et	4	main
kuidas	doc_485437783975_item	2426098	et	3	main
eesti	doc_485437783975_item	2426102	et	4	main
tüüpilisem	doc_485437783975_item	2426107	et	4	main
mis	doc_485437783975_item	2426108	et	4	main
tuleb	doc_485437783975_item	2426109	et	3	main
vahetada	doc_482578971777_item	2425823	et	3	main
äkki	doc_482578971777_item	2425829	et	3	main
saaks	doc_482578971777_item	2425830	et	3	main
te	doc_482578971777_item	2425836	et	4	main
meie	doc_485437783973_item	2425851	et	4	main
käitumise	doc_485437783973_item	2425854	et	4	main
2	doc_485437783973_item	2425856	et	2	main
kultuur	doc_485437783973_item	2425858	et	3	main
esmakordselt	doc_485437783973_item	2425859	et	4	main
see	doc_485437783973_item	2425860	et	3	main
on	doc_485437783973_item	2425861	et	4	main
minu	doc_485437783973_item	2425862	et	3	main
kirjanikud	doc_485437783973_item	2425871	et	3	main
kes	doc_485437783973_item	2425872	et	4	main
pärit	doc_485437783973_item	2425874	et	3	main
rahva	doc_485437783973_item	2425887	et	3	main
keel	doc_485437783973_item	2425898	et	4	main
kultuuri	doc_485437783975_item	2426071	et	4	main
sünnist	doc_485437783975_item	2426072	et	4	main
siis	doc_485437783975_item	2426073	et	3	main
raamatud	doc_485437783975_item	2426082	et	4	main
rahvaluulet	doc_485437783975_item	2426089	et	3	main
poeesiat	doc_485437783975_item	2426090	et	3	main
huvitav	doc_485437783975_item	2426091	et	4	main
oleks	doc_485437783975_item	2426092	et	3	main
kuidas	doc_485437783975_item	2426094	et	3	main
keeleuurimused	doc_485437783975_item	2426101	et	3	main
arvan	doc_485437783975_item	2426104	et	3	main
kõige	doc_485437783975_item	2426106	et	4	main
on	doc_485437783975_item	2426113	et	4	main
saaremaal	doc_485437783975_item	2426137	et	4	main
vanalinn	doc_485437783975_item	2426139	et	3	main
kogu	doc_485437783975_item	2426140	et	4	main
iluga	doc_485437783975_item	2426141	et	3	main
aga	doc_485437783975_item	2426142	et	3	main
tumedates	doc_485437783975_item	2426143	et	3	main
ma	doc_485839256081_item	2426146	et	3	main
huvitundev	doc_485839256081_item	2426159	et	3	main
üksinda	doc_485839256081_item	2426165	et	4	main
diskole	doc_485839256081_item	2426172	et	4	main
mitte	doc_485839256081_item	2426175	et	3	main
tihti	doc_485839256081_item	2426177	et	3	main
lugemine	doc_485839256081_item	2426180	et	4	main
mul	doc_485839256081_item	2426224	et	3	main
sest	doc_485839256081_item	2426239	et	4	main
muidugi	doc_485839256081_item	2426260	et	4	main
teda	doc_485839256081_item	2426262	et	4	main
appi	doc_485839256081_item	2426265	et	4	main
sellistesse	doc_485839256081_item	2426291	et	4	main
mul	doc_485839256081_item	2426294	et	3	main
kohustusi	doc_485839256081_item	2426298	et	4	main
kodutööd	doc_485839256081_item	2426321	et	4	main
ja	doc_485839256082_item	2426327	et	3	main
inimene	doc_485839256082_item	2426329	et	3	main
korda	doc_485839256082_item	2426343	et	4	main
treeningume	doc_485839256082_item	2426347	et	4	main
maadleja	doc_485839256082_item	2426352	et	4	main
aastat	doc_485839256082_item	2426358	et	3	main
kui	doc_485839256082_item	2426362	et	3	main
vastus	doc_485437783975_item	2426064	et	3	main
hakkan	doc_485437783975_item	2426067	et	3	main
mõtlema	doc_485437783975_item	2426069	et	3	main
kreeka	doc_485437783975_item	2426070	et	4	main
kiri	doc_485437783975_item	2426078	et	3	main
rahva	doc_485437783975_item	2426080	et	3	main
laua	doc_485437783975_item	2426083	et	3	main
ilmset	doc_485437783975_item	2426085	et	3	main
sümboliseerivad	doc_485437783975_item	2426086	et	4	main
minu	doc_485437783975_item	2426087	et	3	main
riides	doc_485437783975_item	2426096	et	4	main
oli	doc_485437783975_item	2426099	et	3	main
rahva	doc_485437783975_item	2426114	et	3	main
pealkiri	doc_485437783975_item	2426134	et	3	main
vaielda	doc_485839256081_item	2426154	et	4	main
inimestega	doc_485839256081_item	2426155	et	3	main
olen	doc_485839256081_item	2426156	et	3	main
õhtuti	doc_485839256081_item	2426164	et	3	main
meeldib	doc_485839256081_item	2426166	et	3	main
ma	doc_485839256081_item	2426168	et	3	main
kodus	doc_485839256081_item	2426170	et	4	main
meeleolu	doc_485839256081_item	2426188	et	4	main
mina	doc_485839256081_item	2426198	et	4	main
heal	doc_485839256081_item	2426225	et	3	main
on	doc_485839256081_item	2426227	et	4	main
kingin	doc_485839256081_item	2426231	et	3	main
talle	doc_485839256081_item	2426232	et	4	main
kingitust	doc_485839256081_item	2426233	et	4	main
ja	doc_485839256081_item	2426234	et	3	main
tavalisedes	doc_485839256081_item	2426246	et	4	main
harva	doc_485839256081_item	2426249	et	4	main
üksteist	doc_485839256081_item	2426251	et	4	main
kui	doc_485839256081_item	2426252	et	3	main
mu	doc_485839256081_item	2426253	et	3	main
appi	doc_485839256081_item	2426257	et	4	main
harva	doc_485839256081_item	2426289	et	4	main
olukordadesse	doc_485839256081_item	2426292	et	3	main
oma	doc_485839256081_item	2426307	et	4	main
sõbradega	doc_485839256081_item	2426308	et	4	main
vähe	doc_485839256081_item	2426312	et	3	main
meeldib	doc_485839256082_item	2426337	et	3	main
kohtla-järvel	doc_485839256082_item	2426348	et	4	main
spordiklubis	doc_485839256082_item	2426349	et	3	main
ma	doc_485839256082_item	2426353	et	3	main
siis	doc_485839256082_item	2426367	et	3	main
ja	doc_485839256082_item	2426370	et	3	main
heal	doc_485839256082_item	2426380	et	3	main
siis	doc_485839256082_item	2426384	et	3	main
lähen	doc_485839256082_item	2426386	et	3	main
sünnipäevad	doc_485839256082_item	2426394	et	3	main
armastan	doc_485839256082_item	2426397	et	3	main
ma	doc_485839256082_item	2426422	et	3	main
appi	doc_485839256082_item	2426424	et	4	main
sis	doc_485839256082_item	2426436	et	3	main
ma	doc_485839256082_item	2426437	et	3	main
magan	doc_485839256082_item	2426438	et	3	main
või	doc_485839256082_item	2426439	et	4	main
istun	doc_485839256082_item	2426440	et	3	main
interneetiga	doc_485839256082_item	2426441	et	4	main
väga	doc_485839256082_item	2426457	et	3	main
kohvik	doc_485839256083_item	2426465	et	3	main
käin	doc_485839256083_item	2426467	et	3	main
iga	doc_485839256083_item	2426469	et	4	main
lõunatan	doc_485839256083_item	2426475	et	3	main
väisamiseks	doc_485839256083_item	2426489	et	4	main
järele	doc_485839256083_item	2426491	et	4	main
kultuur	doc_485437783975_item	2426066	et	3	main
kohe	doc_485437783975_item	2426068	et	4	main
peal	doc_485437783975_item	2426084	et	4	main
jaoks	doc_485437783975_item	2426088	et	4	main
käidi	doc_485437783975_item	2426097	et	3	main
et	doc_485437783975_item	2426105	et	3	main
eestlaste	doc_485437783975_item	2426116	et	4	main
mulgi	doc_485437783975_item	2426117	et	4	main
kapsas	doc_485437783975_item	2426118	et	4	main
mis	doc_485437783975_item	2426119	et	4	main
on	doc_485437783975_item	2426120	et	4	main
ees	doc_485437783975_item	2426127	et	4	main
lydia	doc_485437783975_item	2426128	et	4	main
koidula	doc_485437783975_item	2426129	et	4	main
vargamäe	doc_485437783975_item	2426135	et	3	main
värvides	doc_485437783975_item	2426144	et	4	main
olen	doc_485839256081_item	2426147	et	3	main
rahulik	doc_485839256081_item	2426149	et	3	main
ei	doc_485839256081_item	2426152	et	4	main
armasta	doc_485839256081_item	2426153	et	4	main
inimene	doc_485839256081_item	2426160	et	3	main
meeldib	doc_485839256081_item	2426162	et	3	main
tantsida	doc_485839256081_item	2426167	et	3	main
ja	doc_485839256081_item	2426181	et	3	main
ning	doc_485839256081_item	2426186	et	3	main
pöördan	doc_485839256081_item	2426199	et	4	main
aitab	doc_485839256081_item	2426221	et	3	main
lillei	doc_485839256081_item	2426235	et	4	main
mulle	doc_485839256081_item	2426236	et	4	main
et	doc_485839256081_item	2426240	et	3	main
saame	doc_485839256081_item	2426242	et	4	main
palub	doc_485839256081_item	2426255	et	3	main
siis	doc_485839256081_item	2426258	et	3	main
aitan	doc_485839256081_item	2426261	et	3	main
ma	doc_485839256081_item	2426263	et	3	main
minu	doc_485839256081_item	2426287	et	3	main
sõbrad	doc_485839256081_item	2426288	et	3	main
sattuvad	doc_485839256081_item	2426290	et	4	main
kui	doc_485839256081_item	2426293	et	3	main
mul	doc_485839256081_item	2426310	et	3	main
essee	doc_485839256082_item	2426322	et	4	main
ma	doc_485839256082_item	2426323	et	3	main
aidatan	doc_485839256082_item	2426331	et	4	main
mulle	doc_485839256082_item	2426336	et	4	main
ma	doc_485839256082_item	2426340	et	3	main
ma	doc_485839256082_item	2426350	et	3	main
juba	doc_485839256082_item	2426356	et	3	main
ma	doc_485839256082_item	2426368	et	3	main
loen	doc_485839256082_item	2426371	et	3	main
mulle	doc_485839256082_item	2426375	et	4	main
mu	doc_485839256082_item	2426379	et	3	main
tuttaval	doc_485839256082_item	2426381	et	4	main
ma	doc_485839256082_item	2426385	et	3	main
kauplusesse	doc_485839256082_item	2426387	et	4	main
ja	doc_485839256082_item	2426388	et	3	main
ostan	doc_485839256082_item	2426389	et	3	main
kingituse	doc_485839256082_item	2426390	et	4	main
ma	doc_485839256082_item	2426396	et	3	main
ja	doc_485839256082_item	2426400	et	3	main
küsimusele	doc_485437783975_item	2426065	et	4	main
peas	doc_485437783975_item	2426074	et	4	main
keerleb	doc_485437783975_item	2426075	et	3	main
tekkis	doc_485437783975_item	2426077	et	3	main
oma	doc_485437783975_item	2426081	et	4	main
teada	doc_485437783975_item	2426093	et	3	main
vanasti	doc_485437783975_item	2426095	et	3	main
moodne	doc_485437783975_item	2426100	et	3	main
kultuur	doc_485437783975_item	2426103	et	3	main
tantsud	doc_485437783975_item	2426115	et	3	main
rahvustoiduks	doc_485437783975_item	2426121	et	3	main
pärast	doc_485437783975_item	2426123	et	4	main
silme	doc_485437783975_item	2426126	et	4	main
tallinna	doc_485437783975_item	2426138	et	4	main
alati	doc_485839256081_item	2426148	et	4	main
ma	doc_485839256081_item	2426151	et	3	main
mulle	doc_485839256081_item	2426161	et	4	main
nii	doc_485839256081_item	2426176	et	3	main
kui	doc_485839256081_item	2426178	et	3	main
tantsimine	doc_485839256081_item	2426182	et	4	main
mul	doc_485839256081_item	2426184	et	3	main
mul	doc_485839256081_item	2426190	et	3	main
on	doc_485839256081_item	2426191	et	4	main
pingeline	doc_485839256081_item	2426192	et	4	main
olukord	doc_485839256081_item	2426193	et	3	main
siis	doc_485839256081_item	2426194	et	3	main
ma	doc_485839256081_item	2426195	et	3	main
küsin	doc_485839256081_item	2426196	et	3	main
nõu	doc_485839256081_item	2426197	et	4	main
esimesel	doc_485437783975_item	2426110	et	3	main
hetkel	doc_485437783975_item	2426111	et	4	main
meelde	doc_485437783975_item	2426112	et	3	main
millegi	doc_485437783975_item	2426122	et	4	main
on	doc_485437783975_item	2426124	et	4	main
praegu	doc_485437783975_item	2426125	et	3	main
portree	doc_485437783975_item	2426130	et	4	main
ka	doc_485437783975_item	2426131	et	3	main
tammsaare	doc_485437783975_item	2426132	et	3	main
raamatu	doc_485437783975_item	2426133	et	4	main
suitsusaun	doc_485437783975_item	2426136	et	3	main
essee	doc_485839256081_item	2426145	et	4	main
inimene	doc_485839256081_item	2426150	et	3	main
elurõõmus	doc_485839256081_item	2426157	et	4	main
ja	doc_485839256081_item	2426158	et	3	main
lugeda	doc_485839256081_item	2426163	et	3	main
tahtsin	doc_485839256081_item	2426169	et	3	main
lähen	doc_485839256081_item	2426171	et	3	main
sõbrannadega	doc_485839256081_item	2426173	et	3	main
no	doc_485839256081_item	2426174	et	3	main
tahaks	doc_485839256081_item	2426179	et	3	main
aitavad	doc_485839256081_item	2426183	et	4	main
lõõgastuda	doc_485839256081_item	2426185	et	3	main
tõstavad	doc_485839256081_item	2426187	et	3	main
kui	doc_485839256081_item	2426189	et	3	main
oma	doc_485839256081_item	2426200	et	4	main
ema	doc_485839256081_item	2426201	et	4	main
poole	doc_485839256081_item	2426202	et	4	main
ja	doc_485839256081_item	2426203	et	3	main
lähedase	doc_485839256081_item	2426204	et	3	main
sõbranna	doc_485839256081_item	2426205	et	4	main
poole	doc_485839256081_item	2426206	et	4	main
nad	doc_485839256081_item	2426207	et	3	main
on	doc_485839256081_item	2426208	et	4	main
targat	doc_485839256081_item	2426209	et	4	main
inimesed	doc_485839256081_item	2426210	et	3	main
ja	doc_485839256081_item	2426211	et	3	main
võib	doc_485839256081_item	2426212	et	3	main
olla	doc_485839256081_item	2426213	et	3	main
nad	doc_485839256081_item	2426214	et	3	main
olid	doc_485839256081_item	2426215	et	4	main
samasuguses	doc_485839256081_item	2426216	et	3	main
olukorras	doc_485839256081_item	2426217	et	3	main
minu	doc_485839256081_item	2426218	et	3	main
ema	doc_485839256081_item	2426219	et	4	main
alati	doc_485839256081_item	2426220	et	4	main
kui	doc_485839256081_item	2426223	et	3	main
sünnipäev	doc_485839256081_item	2426228	et	3	main
siis	doc_485839256081_item	2426229	et	3	main
ma	doc_485839256081_item	2426230	et	3	main
meeldivad	doc_485839256081_item	2426237	et	4	main
kõik	doc_485839256081_item	2426244	et	4	main
koos	doc_485839256081_item	2426245	et	4	main
mind	doc_485839256081_item	2426256	et	4	main
ma	doc_485839256081_item	2426259	et	3	main
ole	doc_485839256081_item	2426296	et	4	main
mind	doc_485839256081_item	2426222	et	4	main
tuttaval	doc_485839256081_item	2426226	et	4	main
sünnad	doc_485839256081_item	2426238	et	4	main
me	doc_485839256081_item	2426241	et	4	main
kokku	doc_485839256081_item	2426243	et	3	main
päevades	doc_485839256081_item	2426247	et	3	main
me	doc_485839256081_item	2426248	et	4	main
näeme	doc_485839256081_item	2426250	et	3	main
sõber	doc_485839256081_item	2426254	et	3	main
lähen	doc_485839256081_item	2426264	et	3	main
sest	doc_485839256081_item	2426266	et	4	main
et	doc_485839256081_item	2426267	et	3	main
minu	doc_485839256081_item	2426268	et	3	main
sõberpalub	doc_485839256081_item	2426269	et	4	main
mind	doc_485839256081_item	2426270	et	4	main
appi	doc_485839256081_item	2426271	et	4	main
ma	doc_485839256081_item	2426272	et	3	main
pean	doc_485839256081_item	2426273	et	4	main
talle	doc_485839256081_item	2426274	et	4	main
aitama	doc_485839256081_item	2426275	et	3	main
kui	doc_485839256081_item	2426276	et	3	main
mul	doc_485839256081_item	2426277	et	3	main
on	doc_485839256081_item	2426278	et	4	main
võimalus	doc_485839256081_item	2426279	et	3	main
ja	doc_485839256081_item	2426280	et	3	main
kui	doc_485839256081_item	2426281	et	3	main
on	doc_485839256081_item	2426283	et	4	main
see	doc_485839256081_item	2426282	et	3	main
minu	doc_485839256081_item	2426284	et	3	main
võimuses	doc_485839256081_item	2426285	et	3	main
enneks	doc_485839256081_item	2426286	et	4	main
ei	doc_485839256081_item	2426295	et	4	main
mingeid	doc_485839256081_item	2426297	et	3	main
siis	doc_485839256081_item	2426299	et	3	main
ma	doc_485839256081_item	2426300	et	3	main
kuulan	doc_485839256081_item	2426301	et	3	main
muusikat	doc_485839256081_item	2426302	et	3	main
jalutan	doc_485839256081_item	2426303	et	3	main
istun	doc_485839256081_item	2426304	et	3	main
arvutitaga	doc_485839256081_item	2426305	et	3	main
suhtlen	doc_485839256081_item	2426306	et	3	main
kahjuks	doc_485839256081_item	2426309	et	4	main
on	doc_485839256081_item	2426311	et	4	main
vaba	doc_485839256081_item	2426313	et	4	main
aega	doc_485839256081_item	2426314	et	4	main
sest	doc_485839256081_item	2426315	et	4	main
et	doc_485839256081_item	2426316	et	3	main
ma	doc_485839256081_item	2426317	et	3	main
õpin	doc_485839256081_item	2426318	et	3	main
ja	doc_485839256081_item	2426319	et	3	main
tegen	doc_485839256081_item	2426320	et	4	main
alati	doc_485839256082_item	2426325	et	4	main
heasüdamlik	doc_485839256082_item	2426326	et	3	main
ma	doc_485839256082_item	2426330	et	3	main
minu	doc_485839256082_item	2426332	et	3	main
sugulastega	doc_485839256082_item	2426333	et	4	main
ja	doc_485839256082_item	2426334	et	3	main
sõpradega	doc_485839256082_item	2426335	et	3	main
tegelema	doc_485839256082_item	2426339	et	3	main
kolm	doc_485839256082_item	2426342	et	3	main
nädalas	doc_485839256082_item	2426344	et	3	main
ole	doc_485839256082_item	2426351	et	4	main
läks	doc_485839256082_item	2426354	et	3	main
pingeline	doc_485839256082_item	2426365	et	4	main
olukord	doc_485839256082_item	2426366	et	3	main
istun	doc_485839256082_item	2426369	et	3	main
raamatu	doc_485839256082_item	2426372	et	4	main
aitab	doc_485839256082_item	2426376	et	3	main
on	doc_485839256082_item	2426382	et	4	main
sünnipäev	doc_485839256082_item	2426383	et	3	main
meeldivad	doc_485839256082_item	2426393	et	4	main
hea	doc_485839256082_item	2426403	et	4	main
sünnipäev	doc_485839256082_item	2426406	et	3	main
ma	doc_485839256082_item	2426407	et	3	main
tähistan	doc_485839256082_item	2426408	et	3	main
sõpradega	doc_485839256082_item	2426409	et	3	main
väga	doc_485839256082_item	2426410	et	3	main
emmale	doc_485839256082_item	2426426	et	3	main
haruldus	doc_485839256082_item	2426429	et	3	main
mul	doc_485839256082_item	2426431	et	3	main
hetki	doc_485839256082_item	2426446	et	4	main
on	doc_485839256082_item	2426456	et	4	main
vaba	doc_485839256082_item	2426461	et	4	main
essee	doc_485839256083_item	2426463	et	4	main
puhkepäevad	doc_485839256083_item	2426472	et	3	main
meeldin	doc_485839256083_item	2426486	et	3	main
sisse	doc_485839256083_item	2426487	et	4	main
me	doc_485839256083_item	2426501	et	4	main
kursusekaaslasega	doc_485839256083_item	2426505	et	3	main
pitskohvikus	doc_485839256083_item	2426509	et	3	main
käime	doc_485839256083_item	2426511	et	4	main
abikaasaga	doc_485839256083_item	2426512	et	3	main
ja	doc_485839256083_item	2426513	et	3	main
vahel	doc_485839256083_item	2426522	et	4	main
käin	doc_485839256083_item	2426524	et	3	main
sööma	doc_485839256083_item	2426531	et	4	main
või	doc_485839256083_item	2426543	et	4	main
tavaliselt	doc_485839256083_item	2426545	et	4	main
ma	doc_485839256083_item	2426546	et	3	main
ise	doc_485839256083_item	2426547	et	4	main
kohviku	doc_485839256083_item	2426555	et	3	main
ja	doc_485839256083_item	2426560	et	3	main
võib	doc_485839256083_item	2426562	et	3	main
midagi	doc_485839256083_item	2426564	et	4	main
pakutakse	doc_485839256083_item	2426579	et	3	main
ainult	doc_485839256083_item	2426580	et	4	main
leib	doc_485839256083_item	2426581	et	3	main
sees	doc_485839256083_item	2426582	et	4	main
sai	doc_485839256083_item	2426586	et	4	main
minu	doc_485839256083_item	2426601	et	3	main
peamiselt	doc_485839256083_item	2426608	et	4	main
kohvikus	doc_485839256083_item	2426609	et	3	main
standardikohase	doc_485839256083_item	2426611	et	4	main
olen	doc_485839256082_item	2426324	et	3	main
vastutuslik	doc_485839256082_item	2426328	et	4	main
sporti	doc_485839256082_item	2426338	et	4	main
sõidan	doc_485839256082_item	2426341	et	3	main
trenni	doc_485839256082_item	2426345	et	4	main
me	doc_485839256082_item	2426346	et	4	main
trennis	doc_485839256082_item	2426355	et	3	main
kuus	doc_485839256082_item	2426357	et	4	main
mulle	doc_485839256082_item	2426359	et	4	main
väga	doc_485839256082_item	2426360	et	3	main
meeldib	doc_485839256082_item	2426361	et	3	main
trennin	doc_485839256082_item	2426374	et	4	main
treening	doc_485839256082_item	2426377	et	3	main
mulle	doc_485839256082_item	2426391	et	4	main
väga	doc_485839256082_item	2426392	et	3	main
sõbrad	doc_485839256082_item	2426399	et	3	main
tihti	doc_485839256082_item	2426411	et	3	main
kui	doc_485839256082_item	2426412	et	3	main
mu	doc_485839256082_item	2426413	et	3	main
me	doc_485839256082_item	2426401	et	4	main
sõber	doc_485839256082_item	2426414	et	3	main
palub	doc_485839256082_item	2426415	et	3	main
mind	doc_485839256082_item	2426416	et	4	main
siis	doc_485839256082_item	2426418	et	3	main
appi	doc_485839256082_item	2426417	et	4	main
ma	doc_485839256082_item	2426419	et	3	main
aidatan	doc_485839256082_item	2426420	et	4	main
või	doc_485839256082_item	2426427	et	4	main
kui	doc_485839256082_item	2426430	et	3	main
ei	doc_485839256082_item	2426447	et	4	main
tihti	doc_485839256082_item	2426448	et	3	main
sest	doc_485839256082_item	2426449	et	4	main
ma	doc_485839256082_item	2426450	et	3	main
ei	doc_485839256082_item	2426459	et	4	main
ole	doc_485839256082_item	2426460	et	4	main
aja	doc_485839256082_item	2426462	et	4	main
seal	doc_485839256083_item	2426476	et	4	main
vahel	doc_485839256083_item	2426478	et	4	main
ma	doc_485839256083_item	2426479	et	3	main
kohvikus	doc_485839256083_item	2426481	et	3	main
aeg	doc_485839256083_item	2426488	et	3	main
kohvikus	doc_485839256083_item	2426493	et	3	main
käime	doc_485839256083_item	2426502	et	4	main
aga	doc_485839256083_item	2426506	et	3	main
ma	doc_485839256083_item	2426523	et	3	main
üksi	doc_485839256083_item	2426526	et	4	main
või	doc_485839256083_item	2426533	et	4	main
abikaasa	doc_485839256083_item	2426552	et	4	main
tasub	doc_485839256083_item	2426553	et	3	main
ühte	doc_485839256083_item	2426558	et	4	main
menüü	doc_485839256083_item	2426584	et	4	main
puudub	doc_485839256083_item	2426585	et	3	main
paljud	doc_485839256083_item	2426590	et	3	main
sööma	doc_485839256083_item	2426592	et	4	main
väga	doc_485839256083_item	2426598	et	3	main
abikaasale	doc_485839256083_item	2426602	et	4	main
kuna	doc_485839256083_item	2426603	et	3	main
ta	doc_485839256083_item	2426604	et	4	main
leib	doc_485839256083_item	2426607	et	3	main
erisuguselt	doc_485839256083_item	2426616	et	4	main
valmistatud	doc_485839256083_item	2426617	et	4	main
kohvi	doc_485839256083_item	2426620	et	4	main
jäätis	doc_485839256083_item	2426623	et	3	main
lihtsalt	doc_485839256084_item	2426652	et	4	main
seal	doc_485839256084_item	2426654	et	4	main
väga	doc_485839256084_item	2426656	et	3	main
meeldiv	doc_485839256084_item	2426657	et	4	main
puhkan	doc_485839256084_item	2426673	et	3	main
vestlen	doc_485839256084_item	2426676	et	3	main
ei	doc_485839256084_item	2426681	et	4	main
mul	doc_485839256084_item	2426690	et	3	main
helistan	doc_485839256084_item	2426700	et	3	main
ja	doc_485839256084_item	2426702	et	3	main
mul	doc_485839256082_item	2426363	et	3	main
on	doc_485839256082_item	2426364	et	4	main
või	doc_485839256082_item	2426373	et	4	main
kui	doc_485839256082_item	2426378	et	3	main
sest	doc_485839256082_item	2426395	et	4	main
minu	doc_485839256082_item	2426398	et	3	main
väga	doc_485839256082_item	2426402	et	3	main
puhkasime	doc_485839256082_item	2426404	et	3	main
minu	doc_485839256082_item	2426405	et	3	main
sind	doc_485839256082_item	2426421	et	4	main
lähen	doc_485839256082_item	2426423	et	3	main
kohustusi	doc_485839256082_item	2426435	et	4	main
või	doc_485839256082_item	2426442	et	4	main
vaatan	doc_485839256082_item	2426443	et	3	main
telerit	doc_485839256082_item	2426444	et	3	main
selliseid	doc_485839256082_item	2426445	et	4	main
mul	doc_485839256082_item	2426455	et	3	main
päev	doc_485839256083_item	2426470	et	3	main
paitsi	doc_485839256083_item	2426471	et	3	main
ma	doc_485839256083_item	2426474	et	3	main
koolis	doc_485839256083_item	2426477	et	4	main
käik	doc_485839256083_item	2426480	et	3	main
kauplustes	doc_485839256083_item	2426482	et	4	main
minema	doc_485839256083_item	2426492	et	3	main
natuke	doc_485839256083_item	2426495	et	4	main
koolis	doc_485839256083_item	2426499	et	4	main
baaris	doc_485839256083_item	2426500	et	3	main
või	doc_485839256083_item	2426508	et	4	main
me	doc_485839256083_item	2426510	et	4	main
kuid	doc_485839256083_item	2426521	et	4	main
kohvikus	doc_485839256083_item	2426525	et	3	main
ehkki	doc_485839256083_item	2426527	et	3	main
mulle	doc_485839256083_item	2426528	et	4	main
tundmatud	doc_485839256083_item	2426534	et	4	main
maksan	doc_485839256083_item	2426548	et	3	main
ajal	doc_485839256083_item	2426549	et	4	main
toit	doc_485839256083_item	2426550	et	3	main
väga	doc_485839256083_item	2426557	et	3	main
nägud	doc_485839256083_item	2426559	et	4	main
aga	doc_485839256083_item	2426587	et	3	main
supp	doc_485839256083_item	2426594	et	3	main
see	doc_485839256083_item	2426597	et	3	main
söö	doc_485839256083_item	2426606	et	4	main
minuga	doc_485839256082_item	2426425	et	3	main
sõ	doc_485839256082_item	2426428	et	4	main
ei	doc_485839256082_item	2426432	et	4	main
ole	doc_485839256082_item	2426433	et	4	main
mingeid	doc_485839256082_item	2426434	et	3	main
õppisin	doc_485839256082_item	2426451	et	3	main
ja	doc_485839256082_item	2426452	et	3	main
lähen	doc_485839256082_item	2426453	et	3	main
trenni	doc_485839256082_item	2426454	et	4	main
tihti	doc_485839256082_item	2426458	et	3	main
väisamine	doc_485839256083_item	2426464	et	4	main
ma	doc_485839256083_item	2426466	et	3	main
baaris	doc_485839256083_item	2426468	et	3	main
kuna	doc_485839256083_item	2426473	et	3	main
või	doc_485839256083_item	2426483	et	4	main
pitsakohvikus	doc_485839256083_item	2426484	et	3	main
mulle	doc_485839256083_item	2426485	et	4	main
kauplused	doc_485839256083_item	2426490	et	3	main
ja	doc_485839256083_item	2426494	et	3	main
pisut	doc_485839256083_item	2426496	et	3	main
keha	doc_485839256083_item	2426497	et	4	main
kinnitama	doc_485839256083_item	2426498	et	3	main
koos	doc_485839256083_item	2426504	et	4	main
vahel	doc_485839256083_item	2426514	et	4	main
õetütrelega	doc_485839256083_item	2426515	et	4	main
me	doc_485839256083_item	2426516	et	4	main
teeme	doc_485839256083_item	2426517	et	3	main
see	doc_485839256083_item	2426518	et	3	main
piisab	doc_485839256083_item	2426519	et	3	main
tihti	doc_485839256083_item	2426520	et	3	main
alati	doc_485839256083_item	2426503	et	4	main
kohvikus	doc_485839256083_item	2426507	et	3	main
üksi	doc_485839256083_item	2426532	et	4	main
kohvikus	doc_485839256083_item	2426542	et	3	main
pitsakohvikus	doc_485839256083_item	2426544	et	3	main
paljudesse	doc_485839256083_item	2426554	et	3	main
endale	doc_485839256083_item	2426565	et	4	main
neid	doc_485839256083_item	2426583	et	4	main
praegu	doc_485839256083_item	2426589	et	3	main
isegi	doc_485839256083_item	2426593	et	4	main
ja	doc_485839256083_item	2426596	et	3	main
meeldi	doc_485839256083_item	2426600	et	4	main
ei	doc_485839256083_item	2426605	et	4	main
menüü	doc_485839256083_item	2426610	et	4	main
seal	doc_485839256083_item	2426612	et	4	main
pakutakse	doc_485839256083_item	2426613	et	3	main
suppid	doc_485839256083_item	2426614	et	4	main
salatid	doc_485839256083_item	2426615	et	3	main
võib	doc_485839256083_item	2426629	et	3	main
hingelise	doc_485839256083_item	2426634	et	4	main
baar	doc_485839256084_item	2426638	et	3	main
võib	doc_485839256084_item	2426644	et	3	main
ja	doc_485839256084_item	2426650	et	3	main
magusroogadega	doc_485839256084_item	2426653	et	3	main
ma	doc_485839256084_item	2426683	et	3	main
sellepärast	doc_485839256084_item	2426688	et	3	main
kui	doc_485839256084_item	2426694	et	3	main
võimalus	doc_485839256084_item	2426696	et	3	main
ma	doc_485839256084_item	2426699	et	3	main
võime	doc_485839256084_item	2426708	et	4	main
väga	doc_485839256084_item	2426709	et	3	main
ainult	doc_485839256084_item	2426718	et	4	main
nende	doc_485839256084_item	2426719	et	4	main
inimestega	doc_485839256084_item	2426720	et	3	main
kes	doc_485839256084_item	2426721	et	4	main
meile	doc_485839256084_item	2426723	et	4	main
meeldivad	doc_485839256084_item	2426724	et	4	main
et	doc_485839256084_item	2426725	et	3	main
kui	doc_485839256084_item	2426729	et	3	main
näiteks	doc_485839256084_item	2426732	et	4	main
temaga	doc_485839256084_item	2426738	et	3	main
koos	doc_485839256084_item	2426754	et	4	main
kus	doc_485839256084_item	2426760	et	3	main
kord	doc_485839256084_item	2426765	et	4	main
vene	doc_485839256085_item	2426790	et	4	main
argikäitumisega	doc_485839256085_item	2426825	et	3	main
ning	doc_485839256085_item	2426829	et	3	main
rahvalaulud	doc_485839256085_item	2426831	et	3	main
ning	doc_485839256085_item	2426832	et	3	main
lasumisest	doc_485839256085_item	2426856	et	4	main
ükskõikseks	doc_485839256085_item	2426878	et	4	main
elavate	doc_485839256085_item	2426882	et	4	main
on	doc_485839256085_item	2426886	et	4	main
vene	doc_485839256085_item	2426892	et	4	main
folklooriväljaanne	doc_485839256085_item	2426894	et	4	main
kirja	doc_485839256085_item	2426895	et	4	main
publitseeritud	doc_485839256085_item	2426902	et	4	main
värsid	doc_485839256085_item	2426913	et	3	main
olme-perekondliku	doc_485839256085_item	2426916	et	3	main
proosa	doc_485839256085_item	2426941	et	4	main
mõistatusd	doc_485839256085_item	2426943	et	4	main
olulisel	doc_485839256085_item	2426946	et	4	main
pärimused	doc_485839256085_item	2426949	et	4	main
koostajatelt	doc_485839256085_item	2426957	et	4	main
преданья	doc_485839256085_item	2426958	et	2	main
старины	doc_485839256085_item	2426959	et	2	main
vanausuliste	doc_485839256085_item	2426962	et	4	main
повем	doc_485839256085_item	2426965	et	2	main
vaimulikud	doc_485839256085_item	2426968	et	3	main
бога	doc_485839256085_item	2426973	et	2	main
до	doc_485839256085_item	2426975	et	2	main
religioosne	doc_485839256085_item	2426977	et	3	main
pere	doc_485839256085_item	2426982	et	4	main
erip	doc_485839256085_item	2426991	et	4	main
с	doc_485839256085_item	2427028	et	2	main
свивалося	doc_485839256085_item	2427030	et	2	main
ja	doc_485839256085_item	2427032	et	3	main
покой	doc_485839256085_item	2427037	et	2	main
ja	doc_485839256085_item	2427039	et	3	main
складка	doc_485839256085_item	2427045	et	2	main
быль	doc_485839256085_item	2427047	et	2	main
ei	doc_485839256083_item	2426529	et	4	main
meeldi	doc_485839256083_item	2426530	et	4	main
inimesega	doc_485839256083_item	2426535	et	3	main
mind	doc_485839256083_item	2426536	et	4	main
ärritan	doc_485839256083_item	2426537	et	3	main
kui	doc_485839256083_item	2426538	et	3	main
minuga	doc_485839256083_item	2426539	et	3	main
üritatakse	doc_485839256083_item	2426540	et	3	main
tutvuma	doc_485839256083_item	2426541	et	3	main
või	doc_485839256083_item	2426551	et	4	main
menüü	doc_485839256083_item	2426556	et	4	main
alati	doc_485839256083_item	2426561	et	4	main
valima	doc_485839256083_item	2426563	et	3	main
järgi	doc_485839256083_item	2426566	et	4	main
maitsele	doc_485839256083_item	2426567	et	3	main
ja	doc_485839256083_item	2426568	et	3	main
meeleolule	doc_485839256083_item	2426569	et	3	main
sellepärast	doc_485839256083_item	2426570	et	3	main
mulle	doc_485839256083_item	2426571	et	4	main
meeldin	doc_485839256083_item	2426572	et	3	main
neid	doc_485839256083_item	2426573	et	4	main
väisama	doc_485839256083_item	2426574	et	3	main
kuid	doc_485839256083_item	2426575	et	4	main
paljudesse	doc_485839256083_item	2426576	et	3	main
kohviku	doc_485839256083_item	2426577	et	3	main
millegipärast	doc_485839256083_item	2426578	et	3	main
ometi	doc_485839256083_item	2426588	et	3	main
eelistavad	doc_485839256083_item	2426591	et	4	main
saiaga	doc_485839256083_item	2426595	et	3	main
ärge	doc_485839256083_item	2426599	et	3	main
kartul	doc_485839256083_item	2426618	et	3	main
tee	doc_485839256083_item	2426619	et	4	main
kookid	doc_485839256083_item	2426624	et	4	main
teissugune	doc_485839256083_item	2426627	et	3	main
minu	doc_485839256084_item	2426636	et	3	main
meelest	doc_485839256084_item	2426637	et	4	main
see	doc_485839256084_item	2426639	et	3	main
koht	doc_485839256084_item	2426641	et	3	main
kus	doc_485839256084_item	2426642	et	3	main
on	doc_485839256084_item	2426655	et	4	main
meie	doc_485839256084_item	2426679	et	4	main
linnas	doc_485839256084_item	2426680	et	4	main
tihti	doc_485839256084_item	2426684	et	3	main
restoranis	doc_485839256084_item	2426687	et	3	main
aega	doc_485839256084_item	2426693	et	4	main
minna	doc_485839256084_item	2426697	et	3	main
siis	doc_485839256084_item	2426698	et	3	main
sõbrannale	doc_485839256084_item	2426701	et	3	main
koos	doc_485839256084_item	2426705	et	4	main
baarisse	doc_485839256084_item	2426706	et	3	main
arvan	doc_485839256084_item	2426713	et	3	main
on	doc_485839256084_item	2426722	et	4	main
oleme	doc_485839256084_item	2426727	et	3	main
siis	doc_485839256084_item	2426734	et	3	main
söömas	doc_485839256084_item	2426739	et	4	main
mul	doc_485839256084_item	2426755	et	3	main
ainult	doc_485839256084_item	2426763	et	4	main
ta	doc_485839256084_item	2426767	et	4	main
sellega	doc_485839256084_item	2426771	et	3	main
et	doc_485839256084_item	2426772	et	3	main
pankoogid	doc_485839256084_item	2426777	et	4	main
restoran	doc_485839256084_item	2426780	et	3	main
jõhvis	doc_485839256084_item	2426782	et	3	main
limonaadid	doc_485839256083_item	2426622	et	3	main
essee	doc_485839256084_item	2426635	et	4	main
on	doc_485839256084_item	2426640	et	4	main
inimene	doc_485839256084_item	2426643	et	3	main
puhata	doc_485839256084_item	2426645	et	4	main
ja	doc_485839256084_item	2426646	et	3	main
kohvi	doc_485839256084_item	2426647	et	4	main
juua	doc_485839256084_item	2426648	et	3	main
pirukadega	doc_485839256084_item	2426651	et	4	main
vaheaega	doc_485839256084_item	2426660	et	4	main
veeta	doc_485839256084_item	2426661	et	4	main
ise	doc_485839256084_item	2426662	et	4	main
ma	doc_485839256084_item	2426663	et	3	main
käin	doc_485839256084_item	2426664	et	3	main
baaris	doc_485839256084_item	2426665	et	3	main
iga	doc_485839256084_item	2426666	et	4	main
kord	doc_485839256084_item	2426667	et	4	main
kui	doc_485839256084_item	2426668	et	3	main
olen	doc_485839256084_item	2426669	et	3	main
õppimisel	doc_485839256084_item	2426670	et	4	main
seal	doc_485839256084_item	2426671	et	4	main
mahlad	doc_485839256083_item	2426621	et	3	main
ja	doc_485839256083_item	2426625	et	3	main
paljud	doc_485839256083_item	2426626	et	3	main
sealalati	doc_485839256083_item	2426628	et	4	main
valima	doc_485839256083_item	2426630	et	3	main
midagi	doc_485839256083_item	2426631	et	4	main
endale	doc_485839256083_item	2426632	et	4	main
järgi	doc_485839256083_item	2426633	et	4	main
koogidega	doc_485839256084_item	2426649	et	4	main
oma	doc_485839256084_item	2426658	et	4	main
sõpradega	doc_485839256084_item	2426659	et	3	main
vaheajal	doc_485839256084_item	2426674	et	3	main
oma	doc_485839256084_item	2426677	et	4	main
gruppinaabridega	doc_485839256084_item	2426678	et	4	main
käi	doc_485839256084_item	2426682	et	4	main
või	doc_485839256084_item	2426686	et	4	main
ole	doc_485839256084_item	2426692	et	4	main
veeta	doc_485839256084_item	2426712	et	4	main
inimene	doc_485839256084_item	2426730	et	3	main
kui	doc_485839256084_item	2426741	et	3	main
eest	doc_485839256084_item	2426745	et	4	main
maksmisest	doc_485839256084_item	2426746	et	4	main
kui	doc_485839256084_item	2426747	et	3	main
ma	doc_485839256084_item	2426748	et	3	main
olen	doc_485839256084_item	2426749	et	3	main
sõbrannaga	doc_485839256084_item	2426750	et	3	main
siis	doc_485839256084_item	2426751	et	3	main
me	doc_485839256084_item	2426752	et	4	main
maksame	doc_485839256084_item	2426753	et	3	main
meelde	doc_485839256084_item	2426757	et	3	main
ma	doc_485839256084_item	2426761	et	3	main
üks	doc_485839256084_item	2426764	et	3	main
olid	doc_485839256084_item	2426774	et	4	main
väga	doc_485839256084_item	2426775	et	3	main
maitsvad	doc_485839256084_item	2426776	et	4	main
moosiga	doc_485839256084_item	2426778	et	3	main
esilehe	doc_485839256085_item	2426788	et	3	main
asusid	doc_485839256085_item	2426792	et	4	main
lõpetades	doc_485839256085_item	2426839	et	3	main
raamatust	doc_485839256085_item	2426847	et	4	main
meditsiinipärimusest	doc_485839256085_item	2426853	et	4	main
lausujatest	doc_485839256085_item	2426854	et	4	main
vanausuliste	doc_485839256085_item	2426858	et	4	main
pärimuskultuuri	doc_485839256085_item	2426879	et	4	main
huvilistele	doc_485839256085_item	2426883	et	4	main
peipsi	doc_485839256085_item	2426890	et	4	main
pandud	doc_485839256085_item	2426896	et	4	main
aastatel	doc_485839256085_item	2426897	et	4	main
19302006	doc_485839256085_item	2426898	et	2	main
kõik	doc_485839256085_item	2426899	et	4	main
gruppeeritult	doc_485839256085_item	2426909	et	4	main
vaimulikud	doc_485839256085_item	2426912	et	3	main
ja	doc_485839256085_item	2426915	et	3	main
kohalike	doc_485839256085_item	2426925	et	4	main
elanike	doc_485839256085_item	2426926	et	3	main
tšastuškad	doc_485839256085_item	2426938	et	2	main
muinasjutud	doc_485839256085_item	2426939	et	3	main
on	doc_485839256085_item	2426948	et	4	main
küla	doc_485839256085_item	2426954	et	4	main
posijatest	doc_485839256085_item	2426955	et	4	main
sisukord	doc_485839256085_item	2426956	et	3	main
кому	doc_485839256085_item	2426964	et	2	main
v	doc_485839256085_item	2426969	et	4	main
kodu	doc_485839256085_item	2426984	et	4	main
etikett	doc_485839256085_item	2426985	et	3	main
сохе	doc_485839256085_item	2426987	et	2	main
помощник	doc_485839256085_item	2426989	et	2	main
majanduselu	doc_485839256085_item	2426990	et	4	main
pulmakombed	doc_485839256085_item	2427031	et	3	main
небесное	doc_485839256085_item	2427035	et	2	main
matusetalitus	doc_485839256085_item	2427038	et	4	main
сказка	doc_485839256085_item	2427044	et	2	main
было	doc_485839256085_item	2427048	et	2	main
ü	doc_485839256085_item	2427058	et	4	main
береженого	doc_485839256085_item	2427061	et	2	main
maagia	doc_485839256085_item	2427069	et	4	main
калечит	doc_485839256085_item	2427074	et	2	main
встану	doc_485839256085_item	2427077	et	2	main
n	doc_485839256085_item	2427083	et	4	main
от	doc_485839256085_item	2427091	et	2	main
n	doc_485839256085_item	2427094	et	4	main
ma	doc_485839256084_item	2426672	et	3	main
ja	doc_485839256084_item	2426675	et	3	main
baaris	doc_485839256084_item	2426685	et	3	main
et	doc_485839256084_item	2426689	et	3	main
ei	doc_485839256084_item	2426691	et	4	main
on	doc_485839256084_item	2426695	et	4	main
me	doc_485839256084_item	2426703	et	4	main
aega	doc_485839256084_item	2426711	et	4	main
peame	doc_485839256084_item	2426715	et	4	main
läheme	doc_485839256084_item	2426704	et	3	main
kus	doc_485839256084_item	2426707	et	3	main
tore	doc_485839256084_item	2426710	et	3	main
me	doc_485839256084_item	2426714	et	4	main
käia	doc_485839256084_item	2426716	et	4	main
söömas	doc_485839256084_item	2426717	et	4	main
me	doc_485839256084_item	2426726	et	4	main
mind	doc_485839256084_item	2426731	et	4	main
ma	doc_485839256084_item	2426735	et	3	main
ei	doc_485839256084_item	2426736	et	4	main
tuleb	doc_485839256084_item	2426742	et	3	main
toidu	doc_485839256084_item	2426744	et	3	main
üks	doc_485839256084_item	2426758	et	3	main
olin	doc_485839256084_item	2426762	et	3	main
seal	doc_485839256084_item	2426773	et	4	main
lähedal	doc_485839256084_item	2426784	et	4	main
ristmikusel	doc_485839256084_item	2426785	et	4	main
uurimustöö	doc_485839256085_item	2426786	et	4	main
annotatsioon	doc_485839256085_item	2426787	et	3	main
peipsi	doc_485839256085_item	2426793	et	4	main
vaimulikud	doc_485839256085_item	2426821	et	3	main
kalendri-	doc_485839256085_item	2426828	et	3	main
ja	doc_485839256085_item	2426838	et	3	main
pajatustega	doc_485839256085_item	2426840	et	4	main
peamisest	doc_485839256085_item	2426842	et	3	main
elatusallikast	doc_485839256085_item	2426843	et	4	main
kalapüügist	doc_485839256085_item	2426844	et	3	main
peipsi	doc_485839256085_item	2426845	et	4	main
vetel	doc_485839256085_item	2426846	et	3	main
ning	doc_485839256085_item	2426855	et	3	main
järjepidevusest	doc_485839256085_item	2426860	et	4	main
tunnistust	doc_485839256085_item	2426862	et	4	main
jätta	doc_485839256085_item	2426876	et	3	main
see	doc_485839256085_item	2426877	et	3	main
raamat	doc_485839256085_item	2426885	et	3	main
spetsialiseeritud	doc_485839256085_item	2426888	et	4	main
lääneranniku	doc_485839256085_item	2426891	et	3	main
750	doc_485839256085_item	2426907	et	2	main
teksti	doc_485839256085_item	2426908	et	4	main
žanri-temaatilisel	doc_485839256085_item	2426910	et	2	main
printsiibil	doc_485839256085_item	2426911	et	3	main
religioosse	doc_485839256085_item	2426914	et	3	main
rahvajutud	doc_485839256085_item	2426919	et	3	main
kalapüügist	doc_485839256085_item	2426920	et	3	main
mängis	doc_485839256085_item	2426922	et	3	main
roll	doc_485839256085_item	2426924	et	3	main
kalendri-	doc_485839256085_item	2426930	et	3	main
ja	doc_485839256085_item	2426931	et	3	main
perekombestikuluule	doc_485839256085_item	2426932	et	4	main
laulud	doc_485839256085_item	2426933	et	3	main
humoristliku	doc_485839256085_item	2426934	et	3	main
sisuga	doc_485839256085_item	2426935	et	3	main
rahvalaulud	doc_485839256085_item	2426936	et	3	main
ehk	doc_485839256085_item	2426937	et	3	main
mitte-muinasjutuslik	doc_485839256085_item	2426940	et	4	main
lausumised	doc_485839256085_item	2426950	et	4	main
jutustused	doc_485839256085_item	2426953	et	4	main
peipsimaa	doc_485839256085_item	2426961	et	4	main
folklooritraditsioon	doc_485839256085_item	2426963	et	3	main
мою	doc_485839256085_item	2426967	et	2	main
обычай	doc_485839256085_item	2426979	et	2	main
закона	doc_485839256085_item	2426981	et	2	main
ja	doc_485839256085_item	2426983	et	3	main
топор	doc_485839256085_item	2426986	et	2	main
первый	doc_485839256085_item	2426988	et	2	main
s	doc_485839256085_item	2427021	et	4	main
nnitus-ristimise	doc_485839256085_item	2427023	et	4	main
kombed	doc_485839256085_item	2427024	et	3	main
ja	doc_485839256085_item	2427025	et	3	main
tavad	doc_485839256085_item	2427026	et	3	main
золото	doc_485839256085_item	2427027	et	2	main
вечный	doc_485839256085_item	2427036	et	2	main
surnute	doc_485839256085_item	2427040	et	4	main
m	doc_485839256085_item	2427041	et	4	main
стена	doc_485839256085_item	2427050	et	2	main
toloogilised	doc_485839256085_item	2427059	et	4	main
бережет	doc_485839256085_item	2427063	et	2	main
и	doc_485839256085_item	2427073	et	2	main
posimine	doc_485839256085_item	2427076	et	4	main
прочь	doc_485839256085_item	2427090	et	2	main
rahul	doc_485839256084_item	2426728	et	4	main
närveerib	doc_485839256084_item	2426733	et	3	main
tahaks	doc_485839256084_item	2426737	et	3	main
käia	doc_485839256084_item	2426740	et	4	main
asi	doc_485839256084_item	2426743	et	4	main
tuleb	doc_485839256084_item	2426756	et	3	main
restoran	doc_485839256084_item	2426759	et	3	main
aga	doc_485839256084_item	2426766	et	3	main
mulle	doc_485839256084_item	2426768	et	4	main
väga	doc_485839256084_item	2426769	et	3	main
meeldis	doc_485839256084_item	2426770	et	3	main
see	doc_485839256084_item	2426779	et	3	main
asub	doc_485839256084_item	2426781	et	3	main
keskplatsi	doc_485839256084_item	2426783	et	4	main
esiküljele	doc_485839256085_item	2426789	et	3	main
vanaususulised	doc_485839256085_item	2426791	et	4	main
läänerannikule	doc_485839256085_item	2426794	et	3	main
elama	doc_485839256085_item	2426795	et	3	main
see	doc_485839256085_item	2426796	et	3	main
raamat	doc_485839256085_item	2426797	et	3	main
on	doc_485839256085_item	2426798	et	4	main
peipsi	doc_485839256085_item	2426799	et	4	main
läänerannikul	doc_485839256085_item	2426800	et	3	main
elavate	doc_485839256085_item	2426801	et	4	main
vene	doc_485839256085_item	2426802	et	4	main
vanausuliste	doc_485839256085_item	2426803	et	4	main
folkloorist	doc_485839256085_item	2426804	et	4	main
ja	doc_485839256085_item	2426805	et	3	main
rahvapärimusest	doc_485839256085_item	2426806	et	4	main
laiema	doc_485839256085_item	2426807	et	4	main
lugejaskonna	doc_485839256085_item	2426808	et	3	main
ette	doc_485839256085_item	2426809	et	4	main
jõuavad	doc_485839256085_item	2426810	et	4	main
esmakordselt	doc_485839256085_item	2426811	et	4	main
umbes	doc_485839256085_item	2426812	et	4	main
750	doc_485839256085_item	2426813	et	2	main
teksti	doc_485839256085_item	2426814	et	4	main
mis	doc_485839256085_item	2426815	et	4	main
on	doc_485839256085_item	2426816	et	4	main
talletatud	doc_485839256085_item	2426817	et	4	main
arhiveeritud	doc_485839256085_item	2426818	et	4	main
aastatel	doc_485839256085_item	2426819	et	4	main
1930-2006	doc_485839256085_item	2426820	et	2	main
religioosse	doc_485839256085_item	2426823	et	3	main
rahvajutud	doc_485839256085_item	2426835	et	3	main
alates	doc_485839256085_item	2426836	et	3	main
leiab	doc_485839256085_item	2426848	et	3	main
lugemist	doc_485839256085_item	2426849	et	4	main
ka	doc_485839256085_item	2426850	et	3	main
vanausulistele	doc_485839256085_item	2426851	et	4	main
tüüpilisest	doc_485839256085_item	2426852	et	3	main
ning	doc_485839256085_item	2426857	et	3	main
eestis	doc_485839256085_item	2426881	et	3	main
käesolev	doc_485839256085_item	2426884	et	3	main
värsid	doc_485839256085_item	2426822	et	3	main
ning	doc_485839256085_item	2426824	et	3	main
seotud	doc_485839256085_item	2426826	et	4	main
pärimus	doc_485839256085_item	2426827	et	4	main
perekombestikuluule	doc_485839256085_item	2426830	et	4	main
tšastuškad	doc_485839256085_item	2426833	et	2	main
erinevad	doc_485839256085_item	2426834	et	4	main
muinasjuttudest	doc_485839256085_item	2426837	et	3	main
vanausuliste	doc_485839256085_item	2426841	et	4	main
kogukonna	doc_485839256085_item	2426859	et	4	main
annab	doc_485839256085_item	2426861	et	3	main
kuigi	doc_485839256085_item	2426863	et	3	main
kogumik	doc_485839256085_item	2426864	et	3	main
on	doc_485839256085_item	2426865	et	4	main
mõeldud	doc_485839256085_item	2426866	et	4	main
esmajoones	doc_485839256085_item	2426867	et	3	main
filoloogidele	doc_485839256085_item	2426868	et	3	main
etnoloogidele	doc_485839256085_item	2426869	et	3	main
humanitaarteaduste	doc_485839256085_item	2426870	et	3	main
üliõpilastele	doc_485839256085_item	2426871	et	4	main
ning	doc_485839256085_item	2426872	et	3	main
õpetajatele	doc_485839256085_item	2426873	et	4	main
ei	doc_485839256085_item	2426874	et	4	main
tohiks	doc_485839256085_item	2426875	et	3	main
ning	doc_485839256085_item	2426880	et	3	main
esimene	doc_485839256085_item	2426887	et	3	main
esmakordselt	doc_485839256085_item	2426903	et	4	main
raamat	doc_485839256085_item	2426904	et	3	main
sisaldab	doc_485839256085_item	2426905	et	3	main
ligi	doc_485839256085_item	2426906	et	3	main
etiketi	doc_485839256085_item	2426917	et	4	main
teaduslik	doc_485839256085_item	2426889	et	3	main
vanausuliste	doc_485839256085_item	2426893	et	4	main
tekstid	doc_485839256085_item	2426900	et	3	main
on	doc_485839256085_item	2426901	et	4	main
reeglid	doc_485839256085_item	2426918	et	3	main
mis	doc_485839256085_item	2426921	et	4	main
olulist	doc_485839256085_item	2426923	et	4	main
majandustegevuse	doc_485839256085_item	2426927	et	4	main
eripära	doc_485839256085_item	2426928	et	4	main
laste	doc_485839256085_item	2426944	et	4	main
nõiasõnad	doc_485839256085_item	2426951	et	3	main
ja	doc_485839256085_item	2426952	et	3	main
ä	doc_485839256085_item	2426970	et	4	main
rsid	doc_485839256085_item	2426971	et	4	main
без	doc_485839256085_item	2426972	et	2	main
ни	doc_485839256085_item	2426974	et	2	main
порога	doc_485839256085_item	2426976	et	2	main
крепче	doc_485839256085_item	2426980	et	2	main
ü	doc_485839256085_item	2427022	et	4	main
золотом	doc_485839256085_item	2427029	et	2	main
laulud	doc_485839256085_item	2427033	et	3	main
lestustavad	doc_485839256085_item	2427043	et	4	main
дело	doc_485839256085_item	2427049	et	2	main
legendid	doc_485839256085_item	2427053	et	3	main
ä	doc_485839256085_item	2427055	et	4	main
m	doc_485839256085_item	2427065	et	4	main
olme	doc_485839256085_item	2427068	et	4	main
слово	doc_485839256085_item	2427072	et	2	main
пойду	doc_485839256085_item	2427079	et	2	main
õ	doc_485839256085_item	2427084	et	4	main
nad	doc_485839256085_item	2427087	et	3	main
нас	doc_485839256085_item	2427092	et	2	main
õ	doc_485839256085_item	2427100	et	4	main
любишь	doc_485839256085_item	2427102	et	2	main
отшучиваться	doc_485839256085_item	2427106	et	2	main
vanas	doc_485839256085_item	2427110	et	3	main
ja	doc_485839256085_item	2427113	et	3	main
õ	doc_485839256085_item	2427115	et	4	main
не	doc_485839256085_item	2427121	et	2	main
neil	doc_485839256085_item	2427158	et	4	main
pool	doc_485839256085_item	2427161	et	4	main
kohanema	doc_485839256085_item	2427167	et	3	main
mehed	doc_485839256085_item	2427175	et	3	main
pärast	doc_485839256085_item	2427182	et	4	main
novgorodis	doc_485839256085_item	2427218	et	4	main
aegade	doc_485839256085_item	2427225	et	3	main
naised	doc_485839256085_item	2427227	et	3	main
hõivatud	doc_485839256085_item	2427229	et	4	main
tegelesid	doc_485839256085_item	2427231	et	4	main
aiandusega	doc_485839256085_item	2427232	et	3	main
taludes	doc_485839256085_item	2427253	et	4	main
tasuti	doc_485839256085_item	2427268	et	3	main
lastele	doc_485839256085_item	2427269	et	4	main
muude	doc_485839256085_item	2427274	et	4	main
laiuvad	doc_485839256085_item	2427287	et	4	main
peipsi	doc_485839256085_item	2427288	et	4	main
külas	doc_485839256085_item	2427294	et	3	main
mitu	doc_485839256085_item	2427296	et	4	main
teist	doc_485839256085_item	2427299	et	4	main
jääaluse	doc_485839256085_item	2427322	et	4	main
püügi	doc_485839256085_item	2427323	et	4	main
täiustades	doc_485839256085_item	2427327	et	3	main
mida	doc_485839256085_item	2427338	et	4	main
kohalikud	doc_485839256085_item	2427339	et	3	main
inimesed	doc_485839256085_item	2427340	et	3	main
lülide	doc_485839256085_item	2427347	et	3	main
kalapüügiriistade	doc_485839256085_item	2427352	et	3	main
sõltus	doc_485839256085_item	2427354	et	4	main
2006	doc_485839256085_item	2427363	et	2	main
sissetallatud	doc_485839256085_item	2427401	et	4	main
tehtud	doc_485839256085_item	2427406	et	4	main
mis	doc_485839256085_item	2427408	et	4	main
mitmepäevapikkuseks	doc_485839256085_item	2427414	et	4	main
osteti	doc_485839256085_item	2427423	et	3	main
kevadeti	doc_485839256085_item	2427425	et	4	main
aga	doc_485839256085_item	2427426	et	3	main
ajastu	doc_485839256085_item	2427434	et	4	main
omapäraseid	doc_485839256085_item	2427440	et	4	main
suure	doc_485839256085_item	2427446	et	3	main
nimetati	doc_485839256085_item	2427455	et	4	main
võistlusi	doc_485839256085_item	2427463	et	3	main
kujunemisel	doc_485839256085_item	2426929	et	4	main
vanasõnad	doc_485839256085_item	2426942	et	3	main
folkloor	doc_485839256085_item	2426945	et	4	main
kohal	doc_485839256085_item	2426947	et	4	main
глубокой	doc_485839256085_item	2426960	et	2	main
печаль	doc_485839256085_item	2426966	et	2	main
etikett	doc_485839256085_item	2426978	et	3	main
ä	doc_485839256085_item	2426992	et	4	main
ra	doc_485839256085_item	2426993	et	4	main
отец	doc_485839256085_item	2426994	et	2	main
рыбак	doc_485839256085_item	2426995	et	2	main
и	doc_485839256085_item	2426996	et	2	main
воду	doc_485839256085_item	2426999	et	2	main
в	doc_485839256085_item	2426998	et	2	main
смотрит	doc_485839256085_item	2427000	et	2	main
kalastus	doc_485839256085_item	2427001	et	4	main
peipsil	doc_485839256085_item	2427002	et	4	main
в	doc_485839256085_item	2427003	et	2	main
сын	doc_485839256085_item	2426997	et	2	main
праздник	doc_485839256085_item	2427004	et	2	main
и	doc_485839256085_item	2427005	et	2	main
у	doc_485839256085_item	2427006	et	2	main
воробья	doc_485839256085_item	2427007	et	2	main
пиво	doc_485839256085_item	2427008	et	2	main
kalendriaasta	doc_485839256085_item	2427009	et	4	main
kombestik	doc_485839256085_item	2427010	et	3	main
ja	doc_485839256085_item	2427011	et	3	main
tavad	doc_485839256085_item	2427012	et	3	main
бог	doc_485839256085_item	2427014	et	2	main
вспоить	doc_485839256085_item	2427015	et	2	main
дай	doc_485839256085_item	2427013	et	2	main
вскормить	doc_485839256085_item	2427016	et	2	main
и	doc_485839256085_item	2427017	et	2	main
на	doc_485839256085_item	2427018	et	2	main
коня	doc_485839256085_item	2427019	et	2	main
посадить	doc_485839256085_item	2427020	et	2	main
царство	doc_485839256085_item	2427034	et	2	main
ä	doc_485839256085_item	2427042	et	4	main
песня	doc_485839256085_item	2427046	et	2	main
ела	doc_485839256085_item	2427052	et	2	main
бог	doc_485839256085_item	2427062	et	2	main
rgid	doc_485839256085_item	2427067	et	4	main
слово	doc_485839256085_item	2427070	et	2	main
благословясь	doc_485839256085_item	2427078	et	2	main
lausumised	doc_485839256085_item	2427081	et	4	main
ias	doc_485839256085_item	2427085	et	4	main
черный	doc_485839256085_item	2427088	et	2	main
namisest	doc_485839256085_item	2427101	et	4	main
узловато	doc_485839256085_item	2427109	et	2	main
õ	doc_485839256085_item	2427111	et	4	main
k	doc_485839256085_item	2427114	et	4	main
nek	doc_485839256085_item	2427116	et	4	main
ää	doc_485839256085_item	2427117	et	4	main
nd	doc_485839256085_item	2427118	et	4	main
мету	doc_485839256085_item	2427119	et	2	main
мету	doc_485839256085_item	2427120	et	2	main
m	doc_485839256085_item	2427123	et	4	main
õ	doc_485839256085_item	2427124	et	4	main
istatused	doc_485839256085_item	2427125	et	4	main
белый	doc_485839256085_item	2427127	et	2	main
бегал	doc_485839256085_item	2427129	et	2	main
ü	doc_485839256085_item	2427134	et	4	main
глубокой	doc_485839256085_item	2427138	et	2	main
halli	doc_485839256085_item	2427140	et	4	main
saabudes	doc_485839256085_item	2427147	et	3	main
juba	doc_485839256085_item	2427151	et	3	main
maadele	doc_485839256085_item	2427153	et	4	main
sellel	doc_485839256085_item	2427154	et	4	main
põhjusel	doc_485839256085_item	2427155	et	3	main
hektarit	doc_485839256085_item	2427162	et	3	main
pidid	doc_485839256085_item	2427166	et	4	main
kohalike	doc_485839256085_item	2427168	et	4	main
omandama	doc_485839256085_item	2427170	et	3	main
arendama	doc_485839256085_item	2427172	et	3	main
majandusharusid	doc_485839256085_item	2427174	et	3	main
hinnatud	doc_485839256085_item	2427183	et	4	main
rikkamad	doc_485839256085_item	2427220	et	4	main
kasvatasid	doc_485839256085_item	2427233	et	4	main
müügiks	doc_485839256085_item	2427234	et	3	main
tsigurit	doc_485839256085_item	2427235	et	4	main
ja	doc_485839256085_item	2427239	et	3	main
eesti	doc_485839256085_item	2427252	et	4	main
kui	doc_485839256085_item	2427256	et	3	main
teravilja	doc_485839256085_item	2427271	et	4	main
kartuli	doc_485839256085_item	2427272	et	3	main
siiski	doc_485839256085_item	2427276	et	4	main
põhiliseks	doc_485839256085_item	2427278	et	3	main
kallast	doc_485839256085_item	2427289	et	4	main
mööda	doc_485839256085_item	2427290	et	4	main
kohanedes	doc_485839256085_item	2427330	et	3	main
iseka	doc_485839256085_item	2427331	et	3	main
ja	doc_485839256085_item	2427333	et	3	main
järve	doc_485839256085_item	2427335	et	4	main
salapärase	doc_485839256085_item	2427336	et	4	main
loomuga	doc_485839256085_item	2427337	et	3	main
ja	doc_485839256085_item	2427345	et	3	main
ja	doc_485839256085_item	2427351	et	3	main
sellest	doc_485839256085_item	2427362	et	4	main
kuuseokstest	doc_485839256085_item	2427405	et	3	main
majakesi	doc_485839256085_item	2427420	et	4	main
sügiseti	doc_485839256085_item	2427422	et	3	main
tõttu	doc_485839256085_item	2427430	et	4	main
maaharijatele	doc_485839256085_item	2427431	et	4	main
maha	doc_485839256085_item	2427432	et	4	main
mootorite	doc_485839256085_item	2427433	et	3	main
kalapüügiks	doc_485839256085_item	2427438	et	3	main
või	doc_485839256085_item	2427448	et	4	main
kanderaamistikule	doc_485839256085_item	2427451	et	4	main
vaimukalt	doc_485839256085_item	2427454	et	4	main
tänapäeval	doc_485839256085_item	2427458	et	3	main
lõbusaid	doc_485839256085_item	2427461	et	3	main
hinnatakse	doc_485839256085_item	2427465	et	4	main
деньги	doc_485839256085_item	2427051	et	2	main
p	doc_485839256085_item	2427054	et	4	main
rimused	doc_485839256085_item	2427056	et	4	main
m	doc_485839256085_item	2427057	et	4	main
muistendid	doc_485839256085_item	2427060	et	3	main
tunnused	doc_485839256085_item	2427064	et	3	main
ä	doc_485839256085_item	2427066	et	4	main
лечит	doc_485839256085_item	2427071	et	2	main
rahvameditsiin	doc_485839256085_item	2427075	et	3	main
перекрестясь	doc_485839256085_item	2427080	et	2	main
ja	doc_485839256085_item	2427082	et	3	main
õ	doc_485839256085_item	2427086	et	4	main
глаз	doc_485839256085_item	2427089	et	2	main
ras	doc_485839256085_item	2427099	et	4	main
умей	doc_485839256085_item	2427104	et	2	main
nad	doc_485839256085_item	2427112	et	3	main
jutud	doc_485839256085_item	2427093	et	3	main
ä	doc_485839256085_item	2427095	et	4	main
idadest	doc_485839256085_item	2427096	et	3	main
ja	doc_485839256085_item	2427097	et	3	main
ä	doc_485839256085_item	2427098	et	4	main
и	doc_485839256085_item	2427105	et	2	main
да	doc_485839256085_item	2427108	et	2	main
res	doc_485839256085_item	2427133	et	3	main
mee	doc_485839256085_item	2427135	et	3	main
старины	doc_485839256085_item	2427137	et	2	main
venemaalt	doc_485839256085_item	2427146	et	3	main
vanausulised	doc_485839256085_item	2427149	et	4	main
väga	doc_485839256085_item	2427159	et	3	main
vähe	doc_485839256085_item	2427160	et	3	main
peeti	doc_485839256085_item	2427163	et	4	main
töökuse	doc_485839256085_item	2427179	et	4	main
ja	doc_485839256085_item	2427180	et	3	main
on	doc_485839256085_item	2427209	et	4	main
petrogradis	doc_485839256085_item	2427219	et	4	main
kaubandusega	doc_485839256085_item	2427223	et	3	main
olid	doc_485839256085_item	2427228	et	4	main
kodumajanduses	doc_485839256085_item	2427230	et	3	main
kurke	doc_485839256085_item	2427238	et	3	main
käisid	doc_485839256085_item	2427250	et	4	main
tööl	doc_485839256085_item	2427251	et	3	main
poisid	doc_485839256085_item	2427255	et	4	main
eest	doc_485839256085_item	2427267	et	4	main
kümneid	doc_485839256085_item	2427291	et	4	main
oli	doc_485839256085_item	2427295	et	3	main
kalastusriartelli	doc_485839256085_item	2427297	et	4	main
enne	doc_485839256085_item	2427298	et	4	main
шутить	doc_485839256085_item	2427103	et	2	main
коротко	doc_485839256085_item	2427107	et	2	main
вымету	doc_485839256085_item	2427122	et	2	main
заяц	doc_485839256085_item	2427126	et	2	main
куда	doc_485839256085_item	2427128	et	2	main
lastefolkloor	doc_485839256085_item	2427130	et	4	main
kohanimestik	doc_485839256085_item	2427132	et	3	main
преданья	doc_485839256085_item	2427136	et	2	main
vana	doc_485839256085_item	2427139	et	4	main
aja	doc_485839256085_item	2427141	et	4	main
muistendid	doc_485839256085_item	2427142	et	3	main
peipsimaa	doc_485839256085_item	2427143	et	4	main
asusid	doc_485839256085_item	2427148	et	4	main
elama	doc_485839256085_item	2427150	et	3	main
asustatud	doc_485839256085_item	2427152	et	4	main
nad	doc_485839256085_item	2427165	et	3	main
meisterlikkuse	doc_485839256085_item	2427181	et	4	main
läbi	doc_485839256085_item	2427224	et	4	main
7-8	doc_485839256085_item	2427248	et	2	main
eluaastast	doc_485839256085_item	2427249	et	4	main
tüdrukud	doc_485839256085_item	2427257	et	3	main
läbi	doc_485839256085_item	2427259	et	4	main
liha	doc_485839256085_item	2427270	et	4	main
põllumajandussaadustega	doc_485839256085_item	2427275	et	3	main
majandustegevuse	doc_485839256085_item	2427279	et	4	main
alaks	doc_485839256085_item	2427280	et	3	main
oli	doc_485839256085_item	2427281	et	3	main
ammustest	doc_485839256085_item	2427282	et	4	main
aegadest	doc_485839256085_item	2427283	et	3	main
kalapüük	doc_485839256085_item	2427284	et	3	main
vanausuliste	doc_485839256085_item	2427285	et	4	main
külad	doc_485839256085_item	2427286	et	3	main
igas	doc_485839256085_item	2427293	et	3	main
maailmasõda	doc_485839256085_item	2427300	et	4	main
kalapüügiriistu	doc_485839256085_item	2427328	et	3	main
peipsi	doc_485839256085_item	2427334	et	4	main
nende	doc_485839256085_item	2427346	et	4	main
marsruut	doc_485839256085_item	2427350	et	3	main
valik	doc_485839256085_item	2427353	et	3	main
kalaliigist	doc_485839256085_item	2427355	et	3	main
mis	doc_485839256085_item	2427356	et	4	main
oli	doc_485839256085_item	2427357	et	3	main
parajasti	doc_485839256085_item	2427358	et	3	main
püügi	doc_485839256085_item	2427359	et	4	main
objektiks	doc_485839256085_item	2427360	et	3	main
kõigist	doc_485839256085_item	2427361	et	4	main
liikmetele	doc_485839256085_item	2427366	et	3	main
väga	doc_485839256085_item	2427368	et	3	main
olid	doc_485839256085_item	2427397	et	4	main
idakalda	doc_485839256085_item	2427398	et	3	main
suunas	doc_485839256085_item	2427399	et	4	main
mitme	doc_485839256085_item	2427402	et	4	main
suunda	doc_485839256085_item	2427410	et	4	main
ja	doc_485839256085_item	2427411	et	3	main
kilomeetrites	doc_485839256085_item	2427412	et	4	main
peale	doc_485839256085_item	2427418	et	4	main
lube	doc_485839256085_item	2427421	et	3	main
ehitama	doc_485839256085_item	2427439	et	4	main
asetades	doc_485839256085_item	2427442	et	3	main
ja	doc_485839256085_item	2427444	et	3	main
ratastega	doc_485839256085_item	2427450	et	3	main
neid	doc_485839256085_item	2427452	et	4	main
sõidukeid	doc_485839256085_item	2427453	et	3	main
ka	doc_485839256085_item	2427457	et	3	main
karakatitsate	doc_485839256085_item	2427462	et	4	main
ja	doc_485839256085_item	2427469	et	3	main
jääkuhjatisi	doc_485839256085_item	2427476	et	3	main
käisid	doc_485839256085_item	2427486	et	4	main
ulgtöödel	doc_485839256085_item	2427488	et	4	main
tsaariajal	doc_485839256085_item	2427489	et	3	main
esitajate-ja	doc_485839256085_item	2427131	et	3	main
vanausuliste	doc_485839256085_item	2427144	et	4	main
folklooritraditsioon	doc_485839256085_item	2427145	et	3	main
põllumaad	doc_485839256085_item	2427156	et	4	main
oli	doc_485839256085_item	2427157	et	3	main
normiks	doc_485839256085_item	2427164	et	4	main
tingimustega	doc_485839256085_item	2427169	et	3	main
ja	doc_485839256085_item	2427171	et	3	main
mittetraditsioonilisi	doc_485839256085_item	2427173	et	4	main
olid	doc_485839256085_item	2427176	et	4	main
üle	doc_485839256085_item	2427177	et	3	main
eesti	doc_485839256085_item	2427178	et	4	main
ehitusmeistrid	doc_485839256085_item	2427184	et	3	main
ja	doc_485839256085_item	2427185	et	3	main
pottseppad	doc_485839256085_item	2427186	et	4	main
spetsialiseerusid	doc_485839256085_item	2427187	et	4	main
põhiliselt	doc_485839256085_item	2427188	et	4	main
müüritöödel	doc_485839256085_item	2427189	et	3	main
paljud	doc_485839256085_item	2427190	et	3	main
majandusdushooned	doc_485839256085_item	2427191	et	4	main
ümbruskonna	doc_485839256085_item	2427192	et	4	main
taludes	doc_485839256085_item	2427193	et	4	main
ja	doc_485839256085_item	2427194	et	3	main
mõisates	doc_485839256085_item	2427195	et	3	main
on	doc_485839256085_item	2427196	et	4	main
vanausulistest	doc_485839256085_item	2427197	et	4	main
ehitusmeistrite	doc_485839256085_item	2427198	et	3	main
kätetöö	doc_485839256085_item	2427199	et	4	main
ka	doc_485839256085_item	2427200	et	3	main
palju	doc_485839256085_item	2427201	et	4	main
ametihooneid	doc_485839256085_item	2427202	et	4	main
tartus	doc_485839256085_item	2427203	et	3	main
tallinnas	doc_485839256085_item	2427204	et	4	main
ja	doc_485839256085_item	2427205	et	3	main
eesti	doc_485839256085_item	2427207	et	4	main
linnades	doc_485839256085_item	2427208	et	3	main
teistes	doc_485839256085_item	2427206	et	4	main
ehitatud	doc_485839256085_item	2427210	et	4	main
nende	doc_485839256085_item	2427211	et	4	main
kätega	doc_485839256085_item	2427212	et	3	main
tsaariajal	doc_485839256085_item	2427213	et	3	main
käidi	doc_485839256085_item	2427214	et	3	main
ehitustöödel	doc_485839256085_item	2427215	et	3	main
ka	doc_485839256085_item	2427216	et	3	main
pihkvas	doc_485839256085_item	2427217	et	4	main
mehed	doc_485839256085_item	2427221	et	3	main
tegelesid	doc_485839256085_item	2427222	et	4	main
vanausuliste	doc_485839256085_item	2427226	et	4	main
hiljem	doc_485839256085_item	2427236	et	3	main
sibulat	doc_485839256085_item	2427237	et	3	main
muid	doc_485839256085_item	2427240	et	4	main
köögivilju	doc_485839256085_item	2427241	et	3	main
esimese	doc_485839256085_item	2427242	et	3	main
vabariigi	doc_485839256085_item	2427243	et	3	main
ajal	doc_485839256085_item	2427244	et	4	main
vanausuliste	doc_485839256085_item	2427245	et	4	main
lapsed	doc_485839256085_item	2427246	et	3	main
juba	doc_485839256085_item	2427247	et	3	main
nii	doc_485839256085_item	2427254	et	3	main
suve	doc_485839256085_item	2427258	et	4	main
kuni	doc_485839256085_item	2427260	et	3	main
sügise	doc_485839256085_item	2427261	et	3	main
alguseni	doc_485839256085_item	2427262	et	3	main
töötasid	doc_485839256085_item	2427263	et	4	main
lapsed	doc_485839256085_item	2427264	et	3	main
põllutöödel	doc_485839256085_item	2427265	et	3	main
töö	doc_485839256085_item	2427266	et	4	main
ja	doc_485839256085_item	2427273	et	3	main
vanausuluste	doc_485839256085_item	2427277	et	4	main
kilomeetreid	doc_485839256085_item	2427292	et	4	main
kalapüügiga	doc_485839256085_item	2427301	et	3	main
tegelesid	doc_485839256085_item	2427302	et	4	main
peaaegu	doc_485839256085_item	2427303	et	3	main
kõik	doc_485839256085_item	2427304	et	4	main
täisealised	doc_485839256085_item	2427305	et	4	main
mehed	doc_485839256085_item	2427306	et	3	main
vaesetes	doc_485839256085_item	2427307	et	4	main
peredes	doc_485839256085_item	2427308	et	3	main
järvele	doc_485839256085_item	2427309	et	4	main
käisid	doc_485839256085_item	2427310	et	4	main
ka	doc_485839256085_item	2427311	et	3	main
naised	doc_485839256085_item	2427312	et	3	main
rikkam	doc_485839256085_item	2427313	et	4	main
kalasaak	doc_485839256085_item	2427314	et	3	main
oli	doc_485839256085_item	2427315	et	3	main
talve	doc_485839256085_item	2427316	et	4	main
kuudel	doc_485839256085_item	2427317	et	4	main
põlvest	doc_485839256085_item	2427318	et	4	main
põlve	doc_485839256085_item	2427319	et	4	main
lihvisid	doc_485839256085_item	2427320	et	4	main
vanausulised	doc_485839256085_item	2427321	et	4	main
võtteid	doc_485839256085_item	2427324	et	3	main
ja	doc_485839256085_item	2427325	et	3	main
oskusi	doc_485839256085_item	2427326	et	3	main
aupaklikult	doc_485839256085_item	2427341	et	4	main
nimetavad	doc_485839256085_item	2427342	et	4	main
mereks	doc_485839256085_item	2427343	et	3	main
suurus	doc_485839256085_item	2427348	et	4	main
liikumise	doc_485839256085_item	2427349	et	4	main
folklooriekspeditsiooni	doc_485839256085_item	2427365	et	4	main
rääkisid	doc_485839256085_item	2427367	et	4	main
põhjalikult	doc_485839256085_item	2427369	et	4	main
ivan	doc_485839256085_item	2427370	et	4	main
teetähistega	doc_485839256085_item	2427407	et	4	main
näitasid	doc_485839256085_item	2427409	et	4	main
püügiks	doc_485839256085_item	2427415	et	3	main
ja	doc_485839256085_item	2427329	et	3	main
ilma	doc_485839256085_item	2427332	et	4	main
artellide	doc_485839256085_item	2427344	et	3	main
aasta	doc_485839256085_item	2427364	et	4	main
loginovitš	doc_485839256085_item	2427371	et	2	main
kljavin	doc_485839256085_item	2427372	et	4	main
dementi	doc_485839256085_item	2427373	et	4	main
grigorjevitš	doc_485839256085_item	2427374	et	2	main
aljoksin	doc_485839256085_item	2427375	et	4	main
saveli	doc_485839256085_item	2427376	et	4	main
fjodorovitš	doc_485839256085_item	2427377	et	2	main
poljakov	doc_485839256085_item	2427378	et	4	main
ja	doc_485839256085_item	2427379	et	3	main
teised	doc_485839256085_item	2427380	et	4	main
kutselised	doc_485839256085_item	2427381	et	4	main
kalamehed	doc_485839256085_item	2427382	et	3	main
alistades	doc_485839256085_item	2427383	et	3	main
peipsi	doc_485839256085_item	2427384	et	4	main
järve	doc_485839256085_item	2427385	et	4	main
jää	doc_485839256085_item	2427386	et	4	main
välju	doc_485839256085_item	2427387	et	4	main
ilmutasid	doc_485839256085_item	2427388	et	4	main
kohalikud	doc_485839256085_item	2427389	et	3	main
elanikud	doc_485839256085_item	2427390	et	3	main
imestamapanevat	doc_485839256085_item	2427391	et	3	main
leidlikust	doc_485839256085_item	2427392	et	4	main
ja	doc_485839256085_item	2427393	et	3	main
oskust	doc_485839256085_item	2427394	et	3	main
igast	doc_485839256085_item	2427395	et	3	main
külast	doc_485839256085_item	2427396	et	4	main
lumme	doc_485839256085_item	2427400	et	4	main
kilomeetripikkused	doc_485839256085_item	2427403	et	4	main
talveteed	doc_485839256085_item	2427404	et	4	main
vahemaad	doc_485839256085_item	2427413	et	4	main
paigutatud	doc_485839256085_item	2427419	et	4	main
hobuseid	doc_485839256085_item	2427424	et	4	main
jääaluseks	doc_485839256085_item	2427437	et	4	main
sõidukeid	doc_485839256085_item	2427441	et	3	main
karakatitsadeks	doc_485839256085_item	2427456	et	4	main
kus	doc_485839256085_item	2427464	et	3	main
isetehtud	doc_485839256085_item	2427466	et	3	main
ületada	doc_485839256085_item	2427473	et	3	main
murde	doc_485839256085_item	2427478	et	4	main
kalamehed	doc_485839256085_item	2427487	et	3	main
kalurite	doc_485839256085_item	2427492	et	3	main
käsikääs	doc_485839256085_item	2427526	et	4	main
ja	doc_485839256085_item	2427539	et	3	main
ohtlikumaks	doc_485839256085_item	2427542	et	4	main
ja	doc_485839256085_item	2427544	et	3	main
on	doc_485839256085_item	2427552	et	4	main
kui	doc_485839256085_item	2427553	et	3	main
järvele	doc_485839256085_item	2427557	et	4	main
kas	doc_485839256085_item	2427579	et	3	main
minna	doc_485839256085_item	2427589	et	3	main
nii	doc_485839256085_item	2427590	et	3	main
ja	doc_485839256085_item	2427601	et	3	main
on	doc_485839256085_item	2427608	et	4	main
kasutati	doc_485839256085_item	2427416	et	4	main
jälaste	doc_485839256085_item	2427417	et	4	main
müüdi	doc_485839256085_item	2427427	et	4	main
need	doc_485839256085_item	2427428	et	3	main
tarbetuse	doc_485839256085_item	2427429	et	4	main
saabumisel	doc_485839256085_item	2427435	et	4	main
hakati	doc_485839256085_item	2427436	et	3	main
mootorrattaid	doc_485839256085_item	2427443	et	3	main
autosid	doc_485839256085_item	2427445	et	3	main
traktori	doc_485839256085_item	2427447	et	3	main
lennuki	doc_485839256085_item	2427449	et	3	main
korraldatakse	doc_485839256085_item	2427459	et	3	main
peipsimaal	doc_485839256085_item	2427460	et	4	main
disaini	doc_485839256085_item	2427468	et	4	main
sõiduomadusi	doc_485839256085_item	2427470	et	4	main
tuisanuid	doc_485839256085_item	2427474	et	4	main
kui	doc_485839256085_item	2427480	et	3	main
artellid	doc_485839256085_item	2427493	et	3	main
kalapüügiks	doc_485839256085_item	2427494	et	3	main
paatidel	doc_485839256085_item	2427496	et	3	main
kala	doc_485839256085_item	2427499	et	4	main
realiseeriti	doc_485839256085_item	2427500	et	3	main
kohapeal	doc_485839256085_item	2427501	et	3	main
tagasiteel	doc_485839256085_item	2427502	et	3	main
osteti	doc_485839256085_item	2427503	et	3	main
peterburist	doc_485839256085_item	2427504	et	4	main
kodumajanduses	doc_485839256085_item	2427505	et	3	main
vajalikke	doc_485839256085_item	2427506	et	3	main
linnakaupu	doc_485839256085_item	2427507	et	3	main
sõltumata	doc_485839256085_item	2427508	et	4	main
aastaajast	doc_485839256085_item	2427509	et	4	main
on	doc_485839256085_item	2427510	et	4	main
kaluri	doc_485839256085_item	2427511	et	3	main
ikka	doc_485839256085_item	2427513	et	4	main
elu	doc_485839256085_item	2427512	et	4	main
olnud	doc_485839256085_item	2427514	et	4	main
seotud	doc_485839256085_item	2427515	et	4	main
raskuste	doc_485839256085_item	2427516	et	4	main
ohtude	doc_485839256085_item	2427517	et	3	main
ja	doc_485839256085_item	2427518	et	3	main
riskidega	doc_485839256085_item	2427519	et	3	main
ka	doc_485839256085_item	2427520	et	3	main
kaluri	doc_485839256085_item	2427521	et	3	main
ja	doc_485839256085_item	2427523	et	3	main
kalameeste	doc_485839256085_item	2427532	et	4	main
seas	doc_485839256085_item	2427533	et	4	main
levinud	doc_485839256085_item	2427534	et	4	main
väga	doc_485839256085_item	2427535	et	3	main
palju	doc_485839256085_item	2427536	et	4	main
kaasani	doc_485839256085_item	2427548	et	3	main
jumalaema	doc_485839256085_item	2427549	et	4	main
päeval	doc_485839256085_item	2427555	et	3	main
lähiminevikus	doc_485839256085_item	2427561	et	3	main
hädad	doc_485839256085_item	2427563	et	3	main
õnnetused	doc_485839256085_item	2427565	et	4	main
selle	doc_485839256085_item	2427567	et	4	main
ebausu	doc_485839256085_item	2427568	et	3	main
õigsust	doc_485839256085_item	2427569	et	3	main
püütakse	doc_485839256085_item	2427570	et	3	main
ka	doc_485839256085_item	2427571	et	3	main
sõidukite	doc_485839256085_item	2427467	et	3	main
mis	doc_485839256085_item	2427471	et	4	main
vaesem	doc_485839256085_item	2427485	et	4	main
peipsi	doc_485839256085_item	2427491	et	4	main
varustatud	doc_485839256085_item	2427495	et	4	main
kaugel	doc_485839256085_item	2427497	et	4	main
ebaõnn	doc_485839256085_item	2427524	et	3	main
sellel	doc_485839256085_item	2427529	et	4	main
põhjusel	doc_485839256085_item	2427530	et	3	main
on	doc_485839256085_item	2427531	et	4	main
erinevaid	doc_485839256085_item	2427537	et	4	main
kõige	doc_485839256085_item	2427541	et	4	main
kalur	doc_485839256085_item	2427556	et	3	main
paljud	doc_485839256085_item	2427560	et	3	main
juhtunud	doc_485839256085_item	2427562	et	4	main
ja	doc_485839256085_item	2427564	et	3	main
kinnitavad	doc_485839256085_item	2427566	et	4	main
vältida	doc_485839256085_item	2427573	et	3	main
halba	doc_485839256085_item	2427576	et	4	main
hiilida	doc_485839256085_item	2427580	et	3	main
halva	doc_485839256085_item	2427582	et	4	main
mainega	doc_485839256085_item	2427583	et	4	main
või	doc_485839256085_item	2427585	et	4	main
nii	doc_485839256085_item	2427592	et	3	main
ei	doc_485839256085_item	2427594	et	4	main
minna	doc_485839256085_item	2427598	et	3	main
keelatud	doc_485839256085_item	2427609	et	4	main
meenutada	doc_485839256085_item	2427610	et	3	main
jänest	doc_485839256085_item	2427611	et	3	main
ei	doc_485839256085_item	2427623	et	4	main
võib	doc_485839256085_item	2427629	et	3	main
mis	doc_485839256085_item	2427637	et	4	main
к	doc_485839256085_item	2427653	et	2	main
вый	doc_485839256085_item	2427656	et	2	main
jt	doc_485839256085_item	2427660	et	4	main
ebasoodsam	doc_485839256085_item	2427662	et	4	main
imestama	doc_485839256085_item	2427673	et	3	main
nii	doc_485839256085_item	2427675	et	3	main
hirmutasid	doc_485839256085_item	2427709	et	4	main
oma	doc_485839256085_item	2427711	et	4	main
lapsi	doc_485839256085_item	2427713	et	4	main
hoides	doc_485839256085_item	2427714	et	4	main
järves	doc_485839256085_item	2427733	et	4	main
ja	doc_485839256085_item	2427734	et	3	main
tiheda	doc_485839256085_item	2427735	et	3	main
tekitatud	doc_485839256085_item	2427739	et	4	main
mägede	doc_485839256085_item	2427741	et	3	main
on	doc_485839256085_item	2427749	et	4	main
kirja	doc_485839256085_item	2427750	et	4	main
pandud	doc_485839256085_item	2427751	et	4	main
ka	doc_485839256085_item	2427752	et	3	main
vene	doc_485839256085_item	2427787	et	4	main
palju	doc_485839256085_item	2427796	et	4	main
ühist	doc_485839256085_item	2427797	et	3	main
pandud	doc_485839256085_item	2427806	et	4	main
sarnaseid	doc_485839256085_item	2427809	et	4	main
õigeusuliste	doc_485839256085_item	2427813	et	4	main
aitavad	doc_485839256085_item	2427472	et	4	main
lumehangeid	doc_485839256085_item	2427475	et	4	main
ja	doc_485839256085_item	2427477	et	3	main
suviti	doc_485839256085_item	2427479	et	3	main
peipsi	doc_485839256085_item	2427481	et	4	main
järv	doc_485839256085_item	2427482	et	3	main
oli	doc_485839256085_item	2427483	et	3	main
saagile	doc_485839256085_item	2427484	et	3	main
käisid	doc_485839256085_item	2427490	et	4	main
laadogal	doc_485839256085_item	2427498	et	4	main
keelde	doc_485839256085_item	2427540	et	4	main
päeva	doc_485839256085_item	2427550	et	4	main
parem	doc_485839256085_item	2427551	et	4	main
lähe	doc_485839256085_item	2427559	et	4	main
kohtumist	doc_485839256085_item	2427577	et	4	main
koju	doc_485839256085_item	2427587	et	3	main
õnne	doc_485839256085_item	2427593	et	4	main
vaidluste	doc_485839256085_item	2427600	et	3	main
skandaalid	doc_485839256085_item	2427603	et	3	main
ei	doc_485839256085_item	2427605	et	4	main
hoida	doc_485839256085_item	2427625	et	3	main
all	doc_485839256085_item	2427627	et	3	main
keerata	doc_485839256085_item	2427631	et	4	main
erilisi	doc_485839256085_item	2427634	et	4	main
artelli	doc_485839256085_item	2427640	et	4	main
väljaminekut	doc_485839256085_item	2427641	et	3	main
к	doc_485839256085_item	2427650	et	2	main
и	doc_485839256085_item	2427655	et	2	main
lääs	doc_485839256085_item	2427665	et	3	main
potist	doc_485839256085_item	2427669	et	4	main
üldjuhul	doc_485839256085_item	2427707	et	3	main
pahuraid	doc_485839256085_item	2427712	et	4	main
varasest	doc_485839256085_item	2427717	et	4	main
suplemisest	doc_485839256085_item	2427718	et	4	main
järves	doc_485839256085_item	2427719	et	4	main
vetevaim	doc_485839256085_item	2427720	et	3	main
õnn	doc_485839256085_item	2427522	et	3	main
käivad	doc_485839256085_item	2427525	et	4	main
ehk	doc_485839256085_item	2427527	et	3	main
just	doc_485839256085_item	2427528	et	3	main
enneid	doc_485839256085_item	2427538	et	4	main
kõuerohkeks	doc_485839256085_item	2427543	et	3	main
vihmaseks	doc_485839256085_item	2427545	et	4	main
peavad	doc_485839256085_item	2427546	et	4	main
kalamehed	doc_485839256085_item	2427547	et	3	main
sellel	doc_485839256085_item	2427554	et	4	main
ei	doc_485839256085_item	2427558	et	4	main
nii	doc_485839256085_item	2427574	et	3	main
eelistades	doc_485839256085_item	2427578	et	3	main
kõrvale	doc_485839256085_item	2427581	et	4	main
isegi	doc_485839256085_item	2427586	et	4	main
tule	doc_485839256085_item	2427595	et	4	main
kalale	doc_485839256085_item	2427596	et	3	main
tuleb	doc_485839256085_item	2427597	et	3	main
võrgud	doc_485839256085_item	2427612	et	3	main
jäävad	doc_485839256085_item	2427613	et	4	main
tühjaks	doc_485839256085_item	2427614	et	3	main
ei	doc_485839256085_item	2427615	et	4	main
tohi	doc_485839256085_item	2427616	et	4	main
vilistada	doc_485839256085_item	2427617	et	3	main
kutsud	doc_485839256085_item	2427618	et	4	main
tugeva	doc_485839256085_item	2427619	et	4	main
tuule	doc_485839256085_item	2427620	et	3	main
tohi	doc_485839256085_item	2427624	et	4	main
koorik	doc_485839256085_item	2427626	et	3	main
ümber	doc_485839256085_item	2427630	et	3	main
ka	doc_485839256085_item	2427633	et	3	main
maagilisi	doc_485839256085_item	2427635	et	4	main
toiminguid	doc_485839256085_item	2427636	et	3	main
järvele	doc_485839256085_item	2427642	et	4	main
tuultelegi	doc_485839256085_item	2427643	et	3	main
я	doc_485839256085_item	2427652	et	2	main
е	doc_485839256085_item	2427658	et	2	main
kõige	doc_485839256085_item	2427661	et	4	main
tuul	doc_485839256085_item	2427663	et	3	main
on	doc_485839256085_item	2427664	et	4	main
viib	doc_485839256085_item	2427668	et	3	main
paneb	doc_485839256085_item	2427672	et	3	main
selesse	doc_485839256085_item	2427700	et	4	main
kui	doc_485839256085_item	2427701	et	3	main
väljamõeldisse	doc_485839256085_item	2427702	et	3	main
muinasjutud	doc_485839256085_item	2427703	et	3	main
on	doc_485839256085_item	2427704	et	4	main
see	doc_485839256085_item	2427705	et	3	main
kõik	doc_485839256085_item	2427706	et	4	main
lühijutukesed	doc_485839256085_item	2427726	et	4	main
näkineidudest	doc_485839256085_item	2427728	et	3	main
olevat	doc_485839256085_item	2427730	et	4	main
elutsevad	doc_485839256085_item	2427731	et	4	main
peipsi	doc_485839256085_item	2427732	et	4	main
näkineiuga	doc_485839256085_item	2427745	et	4	main
peetakse	doc_485839256085_item	2427746	et	3	main
väga	doc_485839256085_item	2427747	et	3	main
legend	doc_485839256085_item	2427754	et	3	main
tõug	doc_485839256085_item	2427757	et	3	main
neid	doc_485839256085_item	2427759	et	4	main
pärinevaid	doc_485839256085_item	2427762	et	4	main
lausumistes	doc_485839256085_item	2427791	et	4	main
ja	doc_485839256085_item	2427792	et	3	main
kõrvutades	doc_485839256085_item	2427801	et	3	main
elemente	doc_485839256085_item	2427810	et	3	main
oma	doc_485839256085_item	2427819	et	4	main
pruut	doc_485839256085_item	2427822	et	3	main
see	doc_485839256085_item	2427825	et	3	main
alles	doc_485839256085_item	2427838	et	3	main
peale	doc_485839256085_item	2427839	et	4	main
kimbu	doc_485839256085_item	2427845	et	3	main
lilledega	doc_485839256085_item	2427847	et	4	main
tänapäeval	doc_485839256085_item	2427572	et	3	main
nimetatud	doc_485839256085_item	2427575	et	4	main
inimesest	doc_485839256085_item	2427584	et	3	main
tagasi	doc_485839256085_item	2427588	et	3	main
kui	doc_485839256085_item	2427591	et	3	main
rahulikult	doc_485839256085_item	2427599	et	4	main
riijuta	doc_485839256085_item	2427602	et	4	main
kalale	doc_485839256085_item	2427604	et	3	main
meeldi	doc_485839256085_item	2427606	et	4	main
järvel	doc_485839256085_item	2427607	et	4	main
välja	doc_485839256085_item	2427621	et	4	main
paat	doc_485839256085_item	2427628	et	3	main
on	doc_485839256085_item	2427644	et	4	main
omistatud	doc_485839256085_item	2427645	et	4	main
возгл	doc_485839256085_item	2427654	et	2	main
женец	doc_485839256085_item	2427659	et	2	main
kala	doc_485839256085_item	2427670	et	4	main
et	doc_485839256085_item	2427674	et	3	main
emad	doc_485839256085_item	2427710	et	3	main
neid	doc_485839256085_item	2427715	et	4	main
liiga	doc_485839256085_item	2427716	et	4	main
viib	doc_485839256085_item	2427721	et	3	main
palju	doc_485839256085_item	2427723	et	4	main
jões	doc_485839256085_item	2427736	et	3	main
punaste	doc_485839256085_item	2427740	et	4	main
vaaraost	doc_485839256085_item	2427755	et	4	main
ajal	doc_485839256085_item	2427783	et	4	main
läänerannikul	doc_485839256085_item	2427785	et	3	main
levinud	doc_485839256085_item	2427786	et	4	main
erinevates	doc_485839256085_item	2427802	et	4	main
vanausuliste	doc_485839256085_item	2427803	et	4	main
külades	doc_485839256085_item	2427804	et	3	main
kirja	doc_485839256085_item	2427805	et	4	main
leidub	doc_485839256085_item	2427811	et	3	main
ka	doc_485839256085_item	2427812	et	3	main
nina	doc_485839256085_item	2427814	et	4	main
küla	doc_485839256085_item	2427815	et	4	main
elanike	doc_485839256085_item	2427816	et	3	main
andis	doc_485839256085_item	2427821	et	3	main
pandi	doc_485839256085_item	2427824	et	4	main
võis	doc_485839256085_item	2427826	et	4	main
olla	doc_485839256085_item	2427827	et	3	main
tagastati	doc_485839256085_item	2427837	et	4	main
kuuse	doc_485839256085_item	2427852	et	4	main
peigmees	doc_485839256085_item	2427858	et	4	main
noored	doc_485839256085_item	2427863	et	3	main
laulsid	doc_485839256085_item	2427865	et	4	main
парна	doc_485839256085_item	2427867	et	2	main
растопляется	doc_485839256085_item	2427869	et	2	main
pärast	doc_485839256085_item	2427871	et	4	main
praemuna	doc_485839256085_item	2427878	et	4	main
pulmakomete	doc_485839256085_item	2427897	et	3	main
ja	doc_485839256085_item	2427901	et	3	main
laulud	doc_485839256085_item	2427903	et	3	main
pihkva	doc_485839256085_item	2427907	et	4	main
kubermangu	doc_485839256085_item	2427908	et	4	main
kuid	doc_485839256085_item	2427913	et	4	main
величальные	doc_485839256085_item	2427925	et	2	main
laulud	doc_485839256085_item	2427926	et	3	main
arvukus	doc_485839256085_item	2427931	et	4	main
jää	doc_485839256085_item	2427933	et	4	main
ülistati	doc_485839256085_item	2427945	et	3	main
erilise	doc_485839256085_item	2427955	et	4	main
eitavalt	doc_485839256085_item	2427971	et	4	main
ja	doc_485839256085_item	2427997	et	3	main
alustama	doc_485839256085_item	2427998	et	3	main
juttu	doc_485839256085_item	2427999	et	4	main
noorpaari	doc_485839256085_item	2428010	et	4	main
pulmalisi	doc_485839256085_item	2428016	et	4	main
leiba	doc_485839256085_item	2427622	et	4	main
on	doc_485839256085_item	2427632	et	4	main
saadavad	doc_485839256085_item	2427638	et	4	main
kalameeste	doc_485839256085_item	2427639	et	4	main
erilised	doc_485839256085_item	2427646	et	4	main
nimed	doc_485839256085_item	2427647	et	3	main
мокр	doc_485839256085_item	2427648	et	2	main
и	doc_485839256085_item	2427649	et	2	main
тепл	doc_485839256085_item	2427651	et	2	main
м	doc_485839256085_item	2427657	et	2	main
запад	doc_485839256085_item	2427666	et	2	main
see	doc_485839256085_item	2427667	et	3	main
ära	doc_485839256085_item	2427671	et	4	main
arhiivimaterjalides	doc_485839256085_item	2427676	et	3	main
kui	doc_485839256085_item	2427677	et	3	main
ka	doc_485839256085_item	2427678	et	3	main
2006	doc_485839256085_item	2427679	et	2	main
aasta	doc_485839256085_item	2427680	et	4	main
ekspeditsiooni	doc_485839256085_item	2427681	et	4	main
kirjapanekutes	doc_485839256085_item	2427682	et	3	main
ei	doc_485839256085_item	2427683	et	4	main
ole	doc_485839256085_item	2427684	et	4	main
ühtegi	doc_485839256085_item	2427685	et	4	main
lugu	doc_485839256085_item	2427686	et	4	main
ühestki	doc_485839256085_item	2427687	et	4	main
vetevaimust	doc_485839256085_item	2427688	et	4	main
või	doc_485839256085_item	2427689	et	4	main
mingist	doc_485839256085_item	2427690	et	4	main
muust	doc_485839256085_item	2427691	et	4	main
järve	doc_485839256085_item	2427692	et	4	main
peremehest	doc_485839256085_item	2427693	et	4	main
kui	doc_485839256085_item	2427694	et	3	main
ka	doc_485839256085_item	2427696	et	3	main
vetevaimust	doc_485839256085_item	2427695	et	4	main
kuuldi	doc_485839256085_item	2427697	et	4	main
siis	doc_485839256085_item	2427698	et	3	main
suhtuti	doc_485839256085_item	2427699	et	4	main
vetevaimuga	doc_485839256085_item	2427708	et	3	main
ära	doc_485839256085_item	2427722	et	4	main
populaarsemad	doc_485839256085_item	2427724	et	4	main
on	doc_485839256085_item	2427725	et	4	main
ka	doc_485839256085_item	2427737	et	3	main
ohtlikuks	doc_485839256085_item	2427748	et	3	main
vaarao	doc_485839256085_item	2427756	et	4	main
inimkalast	doc_485839256085_item	2427758	et	4	main
apokriiva	doc_485839256085_item	2427760	et	4	main
süžeedest	doc_485839256085_item	2427761	et	2	main
põgenemise	doc_485839256085_item	2427782	et	4	main
peipsi	doc_485839256085_item	2427784	et	4	main
lauludes	doc_485839256085_item	2427789	et	3	main
selles	doc_485839256085_item	2427798	et	4	main
võib	doc_485839256085_item	2427799	et	3	main
veenduda	doc_485839256085_item	2427800	et	3	main
materjali	doc_485839256085_item	2427807	et	4	main
pulmakommetes	doc_485839256085_item	2427817	et	4	main
kinnitades	doc_485839256085_item	2427818	et	3	main
kas	doc_485839256085_item	2427828	et	3	main
või	doc_485839256085_item	2427831	et	4	main
pulmi	doc_485839256085_item	2427840	et	4	main
paberlilledest	doc_485839256085_item	2427844	et	4	main
või	doc_485839256085_item	2427846	et	4	main
saun	doc_485839256085_item	2427855	et	3	main
saunakividele	doc_485839256085_item	2427860	et	3	main
neiud	doc_485839256085_item	2427864	et	4	main
pulmi	doc_485839256085_item	2427872	et	4	main
sööma	doc_485839256085_item	2427879	et	4	main
süüdi	doc_485839256085_item	2427895	et	4	main
rida	doc_485839256085_item	2427899	et	4	main
paljud	doc_485839256085_item	2427902	et	3	main
sarnanevad	doc_485839256085_item	2427904	et	4	main
idarannikul	doc_485839256085_item	2427906	et	3	main
kattu	doc_485839256085_item	2427917	et	4	main
rannakülades	doc_485839256085_item	2427919	et	3	main
ääretult	doc_485839256085_item	2427921	et	4	main
esitajate	doc_485839256085_item	2427928	et	4	main
pulmalauludele	doc_485839256085_item	2427937	et	3	main
kõiki	doc_485839256085_item	2427947	et	4	main
pulmapidulisi	doc_485839256085_item	2427948	et	4	main
maksma	doc_485839256085_item	2427954	et	3	main
vastata	doc_485839256085_item	2427970	et	4	main
pidi	doc_485839256085_item	2427994	et	4	main
tulema	doc_485839256085_item	2427995	et	4	main
viinapudeliga	doc_485839256085_item	2427996	et	3	main
kaupmehest	doc_485839256085_item	2428003	et	4	main
abielu	doc_485839256085_item	2428006	et	4	main
jumalateenistust	doc_485839256085_item	2428007	et	3	main
läbi	doc_485839256085_item	2428017	et	4	main
väljavahetama	doc_485839256085_item	2428038	et	4	main
mõistagi	doc_485839256085_item	2428041	et	4	main
mineraalveega	doc_485839256085_item	2428043	et	3	main
oma	doc_485839256085_item	2428056	et	4	main
lahtipunutud	doc_485839256085_item	2428065	et	4	main
esines	doc_485839256085_item	2428080	et	3	main
pulmad	doc_485839256085_item	2428096	et	3	main
see	doc_485839256085_item	2428100	et	3	main
2006	doc_485839256085_item	2428109	et	2	main
bõlitški	doc_485839256085_item	2427727	et	2	main
näkineiud	doc_485839256085_item	2427729	et	4	main
lainete	doc_485839256085_item	2427738	et	3	main
kallaste	doc_485839256085_item	2427742	et	4	main
urgudes	doc_485839256085_item	2427743	et	3	main
kohtumist	doc_485839256085_item	2427744	et	4	main
üks	doc_485839256085_item	2427753	et	3	main
mütoloogilisi	doc_485839256085_item	2427763	et	4	main
olendeid	doc_485839256085_item	2427764	et	3	main
ida-slaavlaste	doc_485839256085_item	2427765	et	3	main
folklooris	doc_485839256085_item	2427766	et	4	main
esineb	doc_485839256085_item	2427767	et	3	main
väga	doc_485839256085_item	2427768	et	3	main
harva	doc_485839256085_item	2427769	et	4	main
nende	doc_485839256085_item	2427770	et	4	main
päriolu	doc_485839256085_item	2427771	et	4	main
seostatakse	doc_485839256085_item	2427772	et	3	main
mustas	doc_485839256085_item	2427773	et	4	main
meres	doc_485839256085_item	2427774	et	3	main
uppunud	doc_485839256085_item	2427775	et	4	main
vaarao	doc_485839256085_item	2427776	et	4	main
sõdalastaga	doc_485839256085_item	2427777	et	4	main
kes	doc_485839256085_item	2427778	et	4	main
jälitasid	doc_485839256085_item	2427779	et	4	main
juute	doc_485839256085_item	2427780	et	3	main
eguptusest	doc_485839256085_item	2427781	et	4	main
pulmakommetes	doc_485839256085_item	2427788	et	4	main
sõbramehe	doc_485839256085_item	2427790	et	3	main
maagilistes	doc_485839256085_item	2427793	et	4	main
toimingutes	doc_485839256085_item	2427794	et	3	main
on	doc_485839256085_item	2427795	et	4	main
palju	doc_485839256085_item	2427808	et	4	main
lubadust	doc_485839256085_item	2427820	et	4	main
peighelele	doc_485839256085_item	2427823	et	4	main
sõrmus	doc_485839256085_item	2427830	et	3	main
mingi	doc_485839256085_item	2427832	et	4	main
valmistasid	doc_485839256085_item	2427842	et	4	main
pruudile	doc_485839256085_item	2427843	et	3	main
pruudile	doc_485839256085_item	2427853	et	3	main
kööti	doc_485839256085_item	2427854	et	4	main
valas	doc_485839256085_item	2427859	et	3	main
laulu	doc_485839256085_item	2427866	et	4	main
баенка	doc_485839256085_item	2427868	et	2	main
varsti	doc_485839256085_item	2427870	et	3	main
juurde	doc_485839256085_item	2427877	et	4	main
pidi	doc_485839256085_item	2427882	et	4	main
väimes	doc_485839256085_item	2427883	et	4	main
sümbolite	doc_485839256085_item	2427884	et	3	main
või	doc_485839256085_item	2427894	et	4	main
peipsi	doc_485839256085_item	2427905	et	4	main
levinud	doc_485839256085_item	2427911	et	4	main
kommetega	doc_485839256085_item	2427912	et	4	main
ei	doc_485839256085_item	2427916	et	4	main
rätik	doc_485839256085_item	2427829	et	3	main
muu	doc_485839256085_item	2427833	et	4	main
hinnaline	doc_485839256085_item	2427834	et	4	main
ese	doc_485839256085_item	2427835	et	3	main
mille	doc_485839256085_item	2427836	et	3	main
sõbrannad	doc_485839256085_item	2427841	et	3	main
pisikese	doc_485839256085_item	2427851	et	4	main
õlut	doc_485839256085_item	2427861	et	3	main
sõitis	doc_485839256085_item	2427873	et	3	main
naise	doc_485839256085_item	2427875	et	3	main
vanemate	doc_485839256085_item	2427876	et	4	main
abil	doc_485839256085_item	2427885	et	4	main
märku	doc_485839256085_item	2427886	et	4	main
oleva	doc_485839256085_item	2427896	et	4	main
talitusi	doc_485839256085_item	2427900	et	4	main
põhja	doc_485839256085_item	2427909	et	4	main
osas	doc_485839256085_item	2427910	et	4	main
need	doc_485839256085_item	2427915	et	3	main
populaarsed	doc_485839256085_item	2427922	et	3	main
mõnede	doc_485839256085_item	2427927	et	3	main
ei	doc_485839256085_item	2427932	et	4	main
alla	doc_485839256085_item	2427934	et	3	main
kõigile	doc_485839256085_item	2427935	et	4	main
et	doc_485839256085_item	2427944	et	3	main
neid	doc_485839256085_item	2427949	et	4	main
aga	doc_485839256085_item	2427950	et	3	main
kes	doc_485839256085_item	2427951	et	4	main
austuse	doc_485839256085_item	2427956	et	4	main
eest	doc_485839256085_item	2427957	et	4	main
ülistati	doc_485839256085_item	2427958	et	3	main
kas	doc_485839256085_item	2427959	et	3	main
on	doc_485839256085_item	2427967	et	4	main
juba	doc_485839256085_item	2427968	et	3	main
isamees	doc_485839256085_item	2427993	et	4	main
ja	doc_485839256085_item	2428002	et	3	main
tee	doc_485839256085_item	2428012	et	4	main
ja	doc_485839256085_item	2428013	et	3	main
ei	doc_485839256085_item	2428014	et	4	main
noor	doc_485839256085_item	2428020	et	3	main
ostis	doc_485839256085_item	2428022	et	4	main
vabaks	doc_485839256085_item	2428024	et	3	main
vabaks	doc_485839256085_item	2428025	et	3	main
ostmise	doc_485839256085_item	2428026	et	4	main
on	doc_485839256085_item	2428028	et	4	main
omapärane	doc_485839256085_item	2428030	et	4	main
lauale	doc_485839256085_item	2428031	et	4	main
pidi	doc_485839256085_item	2428037	et	4	main
või	doc_485839256085_item	2428045	et	4	main
välja	doc_485839256085_item	2428055	et	4	main
pruudi	doc_485839256085_item	2428057	et	3	main
laua	doc_485839256085_item	2428059	et	3	main
ka	doc_485839256085_item	2428063	et	3	main
maksma	doc_485839256085_item	2428064	et	3	main
teist	doc_485839256085_item	2428078	et	4	main
noormehed	doc_485839256085_item	2428083	et	3	main
pruute	doc_485839256085_item	2428085	et	3	main
pruudi	doc_485839256085_item	2428087	et	3	main
nimetati	doc_485839256085_item	2428094	et	4	main
seda	doc_485839256085_item	2428095	et	3	main
kuid	doc_485839256085_item	2428098	et	4	main
ei	doc_485839256085_item	2428102	et	4	main
nii	doc_485839256085_item	2428104	et	3	main
suurt	doc_485839256085_item	2428105	et	3	main
levikut	doc_485839256085_item	2428106	et	3	main
kui	doc_485839256085_item	2428107	et	3	main
pulmadest	doc_485839256085_item	2428121	et	3	main
ei	doc_485839256085_item	2428131	et	4	main
leia	doc_485839256085_item	2428132	et	4	main
leidus	doc_485839256085_item	2428152	et	4	main
arianti	doc_485839256085_item	2428156	et	4	main
ekspeditsiooni	doc_485839256085_item	2428159	et	4	main
käigus	doc_485839256085_item	2428160	et	4	main
kuke	doc_485839256085_item	2428170	et	3	main
erinevaid	doc_485839256085_item	2428175	et	4	main
raseduse	doc_485839256085_item	2428182	et	4	main
ei	doc_485839256085_item	2428188	et	4	main
ei	doc_485839256085_item	2428192	et	4	main
arhiivimaterjalides	doc_485839256085_item	2428210	et	3	main
selletaolist	doc_485839256085_item	2428216	et	3	main
peipsi	doc_485839256085_item	2428218	et	4	main
ka	doc_485839256085_item	2428220	et	3	main
ei	doc_485839256085_item	2428232	et	4	main
laule	doc_485839256085_item	2428240	et	4	main
naljalaule	doc_485839256085_item	2428242	et	4	main
on	doc_485839256085_item	2428247	et	4	main
ju	doc_485839256085_item	2428248	et	3	main
vanausulised	doc_485839256085_item	2428258	et	4	main
ja	doc_485839256085_item	2427848	et	3	main
lintidega	doc_485839256085_item	2427849	et	3	main
ehitud	doc_485839256085_item	2427850	et	4	main
kütmise	doc_485839256085_item	2427856	et	4	main
käigus	doc_485839256085_item	2427857	et	4	main
ja	doc_485839256085_item	2427862	et	3	main
noorpaar	doc_485839256085_item	2427874	et	4	main
kostitamise	doc_485839256085_item	2427880	et	4	main
ajal	doc_485839256085_item	2427881	et	4	main
andma	doc_485839256085_item	2427887	et	3	main
kas	doc_485839256085_item	2427888	et	3	main
ta	doc_485839256085_item	2427889	et	4	main
võttis	doc_485839256085_item	2427890	et	3	main
naiseks	doc_485839256085_item	2427891	et	3	main
ausa	doc_485839256085_item	2427892	et	3	main
neiu	doc_485839256085_item	2427893	et	4	main
struktuur	doc_485839256085_item	2427898	et	3	main
siiski	doc_485839256085_item	2427914	et	4	main
peipsi	doc_485839256085_item	2427918	et	4	main
on	doc_485839256085_item	2427920	et	4	main
ülistuslaulud	doc_485839256085_item	2427923	et	3	main
ülistuslaulude	doc_485839256085_item	2427930	et	3	main
kokku	doc_485839256085_item	2427938	et	3	main
süžeede	doc_485839256085_item	2427940	et	2	main
järjest	doc_485839256085_item	2427946	et	4	main
olid	doc_485839256085_item	2427952	et	4	main
või	doc_485839256085_item	2427960	et	4	main
kaks-kolm	doc_485839256085_item	2427961	et	3	main
kodus	doc_485839256085_item	2427969	et	4	main
peigmehest	doc_485839256085_item	2428004	et	4	main
ootas	doc_485839256085_item	2428008	et	3	main
külarahvas	doc_485839256085_item	2428009	et	4	main
lasknud	doc_485839256085_item	2428015	et	4	main
enne	doc_485839256085_item	2428018	et	4	main
pudel	doc_485839256085_item	2428034	et	3	main
mille	doc_485839256085_item	2428035	et	3	main
isamees	doc_485839256085_item	2428046	et	4	main
pidi	doc_485839256085_item	2428049	et	4	main
igal	doc_485839256085_item	2428052	et	3	main
ostma	doc_485839256085_item	2428054	et	3	main
koha	doc_485839256085_item	2428058	et	4	main
pidi	doc_485839256085_item	2428062	et	4	main
eest	doc_485839256085_item	2428067	et	4	main
maailmasõda	doc_485839256085_item	2428079	et	4	main
abielu	doc_485839256085_item	2428092	et	4	main
siiski	doc_485839256085_item	2428099	et	4	main
paljud	doc_485839256085_item	2428111	et	3	main
isegi	doc_485839256085_item	2428112	et	4	main
naised	doc_485839256085_item	2428114	et	3	main
lääneranniku	doc_485839256085_item	2428123	et	3	main
mida	doc_485839256085_item	2428127	et	4	main
1930	doc_485839256085_item	2428133	et	2	main
aasta	doc_485839256085_item	2428134	et	4	main
üheaegselt	doc_485839256085_item	2428145	et	4	main
sajab	doc_485839256085_item	2428146	et	3	main
vihm	doc_485839256085_item	2428147	et	3	main
ja	doc_485839256085_item	2428148	et	3	main
paistab	doc_485839256085_item	2428149	et	3	main
päike	doc_485839256085_item	2428150	et	3	main
viisteist	doc_485839256085_item	2428154	et	4	main
2006	doc_485839256085_item	2428157	et	2	main
vestluskaaslane	doc_485839256085_item	2428163	et	3	main
ja	doc_485839256085_item	2428171	et	3	main
ka	doc_485839256085_item	2428174	et	3	main
kelde	doc_485839256085_item	2428176	et	4	main
mida	doc_485839256085_item	2428177	et	4	main
naine	doc_485839256085_item	2428181	et	3	main
olnud	doc_485839256085_item	2428193	et	4	main
tänapäeval	doc_485839256085_item	2428208	et	3	main
midagi	doc_485839256085_item	2428215	et	4	main
опевальные	doc_485839256085_item	2427924	et	2	main
repertuaaris	doc_485839256085_item	2427929	et	3	main
teistele	doc_485839256085_item	2427936	et	4	main
ülistuslaulude	doc_485839256085_item	2427939	et	3	main
rohkust	doc_485839256085_item	2427941	et	4	main
seletab	doc_485839256085_item	2427942	et	3	main
asjaolu	doc_485839256085_item	2427943	et	4	main
nõus	doc_485839256085_item	2427953	et	4	main
korda	doc_485839256085_item	2427962	et	4	main
piisas	doc_485839256085_item	2427963	et	4	main
vaid	doc_485839256085_item	2427964	et	3	main
küsimusele	doc_485839256085_item	2427965	et	4	main
kas	doc_485839256085_item	2427966	et	3	main
süüdistuslaule	doc_485839256085_item	2427972	et	4	main
к	doc_485839256085_item	2427973	et	2	main
орильных	doc_485839256085_item	2427974	et	2	main
kus	doc_485839256085_item	2427975	et	3	main
peigmees	doc_485839256085_item	2427976	et	4	main
või	doc_485839256085_item	2427977	et	4	main
isamees	doc_485839256085_item	2427978	et	4	main
välja	doc_485839256085_item	2427979	et	4	main
naerdi	doc_485839256085_item	2427980	et	3	main
selles	doc_485839256085_item	2427981	et	4	main
regioonis	doc_485839256085_item	2427982	et	3	main
ei	doc_485839256085_item	2427983	et	4	main
ole	doc_485839256085_item	2427984	et	4	main
avastatud	doc_485839256085_item	2427985	et	4	main
kohalike	doc_485839256085_item	2427986	et	4	main
eripäraks	doc_485839256085_item	2427988	et	3	main
pulmakommete	doc_485839256085_item	2427987	et	4	main
on	doc_485839256085_item	2427989	et	4	main
ostu-müügi	doc_485839256085_item	2427990	et	4	main
motiivide	doc_485839256085_item	2427991	et	3	main
rohkus	doc_485839256085_item	2427992	et	4	main
kaubast	doc_485839256085_item	2428000	et	4	main
pruudist	doc_485839256085_item	2428001	et	3	main
pärast	doc_485839256085_item	2428005	et	4	main
piiras	doc_485839256085_item	2428011	et	4	main
kui	doc_485839256085_item	2428019	et	3	main
abielumees	doc_485839256085_item	2428021	et	4	main
end	doc_485839256085_item	2428023	et	4	main
pandi	doc_485839256085_item	2428032	et	4	main
tühi	doc_485839256085_item	2428033	et	3	main
täis	doc_485839256085_item	2428039	et	4	main
pudeliga	doc_485839256085_item	2428040	et	3	main
mitte	doc_485839256085_item	2428042	et	3	main
peigmees	doc_485839256085_item	2428044	et	4	main
rahaga	doc_485839256085_item	2428048	et	4	main
kergitama	doc_485839256085_item	2428051	et	3	main
jm	doc_485839256085_item	2428061	et	4	main
eest	doc_485839256085_item	2428072	et	4	main
oma	doc_485839256085_item	2428073	et	4	main
tulevase	doc_485839256085_item	2428074	et	4	main
äia	doc_485839256085_item	2428075	et	4	main
majas	doc_485839256085_item	2428076	et	3	main
juhuseid	doc_485839256085_item	2428081	et	3	main
varastasid	doc_485839256085_item	2428084	et	4	main
vanemad	doc_485839256085_item	2428088	et	4	main
olid	doc_485839256085_item	2428089	et	4	main
mingil	doc_485839256085_item	2428090	et	4	main
põhjusel	doc_485839256085_item	2428091	et	3	main
komme	doc_485839256085_item	2428101	et	4	main
saanud	doc_485839256085_item	2428103	et	4	main
leedus	doc_485839256085_item	2428108	et	4	main
eakad	doc_485839256085_item	2428113	et	3	main
peipsi	doc_485839256085_item	2428122	et	4	main
küsimust	doc_485839256085_item	2428140	et	4	main
mis	doc_485839256085_item	2428141	et	4	main
juhtub	doc_485839256085_item	2428142	et	3	main
siis	doc_485839256085_item	2428143	et	3	main
ligi	doc_485839256085_item	2428153	et	3	main
aasta	doc_485839256085_item	2428158	et	4	main
väga	doc_485839256085_item	2428164	et	3	main
oskas	doc_485839256085_item	2428166	et	3	main
teradega	doc_485839256085_item	2428172	et	3	main
täita	doc_485839256085_item	2428180	et	4	main
ajal	doc_485839256085_item	2428183	et	4	main
teistes	doc_485839256085_item	2428184	et	4	main
regioonides	doc_485839256085_item	2428185	et	3	main
kus	doc_485839256085_item	2428186	et	3	main
esitanud	doc_485839256085_item	2428189	et	4	main
ka	doc_485839256085_item	2428194	et	3	main
avastatud	doc_485839256085_item	2428196	et	4	main
vaimulikke	doc_485839256085_item	2428198	et	3	main
vaatamatta	doc_485839256085_item	2428200	et	4	main
avastatud	doc_485839256085_item	2428211	et	4	main
vaid	doc_485839256085_item	2428212	et	3	main
nähtavasti	doc_485839256085_item	2428214	et	3	main
läänerannikul	doc_485839256085_item	2428219	et	3	main
õigel	doc_485839256085_item	2428227	et	3	main
eelistasid	doc_485839256085_item	2428238	et	4	main
kirjeldasid	doc_485839256085_item	2428244	et	4	main
isegi	doc_485839256085_item	2428253	et	4	main
kolmanda	doc_485839256085_item	2428254	et	3	main
aastatuhande	doc_485839256085_item	2428255	et	4	main
meenutasid	doc_485839256085_item	2428259	et	4	main
pikkadel	doc_485839256085_item	2428263	et	4	main
talvistel	doc_485839256085_item	2428264	et	4	main
õhtudel	doc_485839256085_item	2428265	et	4	main
leviku	doc_485839256085_item	2428271	et	3	main
teatud	doc_485839256085_item	2428273	et	4	main
seas	doc_485839256085_item	2428281	et	4	main
6-9	doc_485839256085_item	2428286	et	2	main
lugemine	doc_485839256085_item	2428294	et	4	main
vorm	doc_485839256085_item	2428027	et	3	main
üpris	doc_485839256085_item	2428029	et	3	main
peigmees	doc_485839256085_item	2428036	et	4	main
peigmehe	doc_485839256085_item	2428047	et	3	main
kukrut	doc_485839256085_item	2428050	et	3	main
sammul	doc_485839256085_item	2428053	et	4	main
taga	doc_485839256085_item	2428060	et	4	main
patside	doc_485839256085_item	2428066	et	3	main
ülistuslaulude	doc_485839256085_item	2428068	et	3	main
eest	doc_485839256085_item	2428069	et	4	main
iga	doc_485839256085_item	2428070	et	4	main
trepiastme	doc_485839256085_item	2428071	et	3	main
enne	doc_485839256085_item	2428077	et	4	main
kus	doc_485839256085_item	2428082	et	3	main
kui	doc_485839256085_item	2428086	et	3	main
vastu	doc_485839256085_item	2428093	et	3	main
vargsi	doc_485839256085_item	2428097	et	3	main
aastal	doc_485839256085_item	2428110	et	3	main
peipsimaal	doc_485839256085_item	2428115	et	4	main
ei	doc_485839256085_item	2428116	et	4	main
olnud	doc_485839256085_item	2428117	et	4	main
kunagi	doc_485839256085_item	2428118	et	3	main
kuulnud	doc_485839256085_item	2428119	et	4	main
vargsi	doc_485839256085_item	2428120	et	3	main
kinnitavad	doc_485839256085_item	2428125	et	4	main
koostatud	doc_485839256085_item	2428137	et	4	main
küsitlusleht	doc_485839256085_item	2428138	et	3	main
sisaldas	doc_485839256085_item	2428139	et	3	main
vastuse	doc_485839256085_item	2428155	et	3	main
peagi	doc_485839256085_item	2428161	et	4	main
üksikasjaliselt	doc_485839256085_item	2428165	et	4	main
rääkida	doc_485839256085_item	2428167	et	3	main
meenutati	doc_485839256085_item	2428173	et	3	main
tingimatta	doc_485839256085_item	2428179	et	4	main
kogujad	doc_485839256085_item	2428187	et	4	main
küsimusi	doc_485839256085_item	2428191	et	4	main
midagi	doc_485839256085_item	2428195	et	4	main
ka	doc_485839256085_item	2428197	et	3	main
värsse	doc_485839256085_item	2428199	et	3	main
sellele	doc_485839256085_item	2428201	et	4	main
et	doc_485839256085_item	2428202	et	3	main
neid	doc_485839256085_item	2428203	et	4	main
mäletatakse	doc_485839256085_item	2428204	et	3	main
ja	doc_485839256085_item	2428205	et	3	main
lauldakse	doc_485839256085_item	2428206	et	3	main
ka	doc_485839256085_item	2428207	et	3	main
juhtus	doc_485839256085_item	2428217	et	3	main
muinasjuttudega	doc_485839256085_item	2428221	et	3	main
lihtsalt	doc_485839256085_item	2428223	et	4	main
ei	doc_485839256085_item	2428224	et	4	main
pandud	doc_485839256085_item	2428225	et	4	main
seas	doc_485839256085_item	2428231	et	4	main
tavandeid	doc_485839256085_item	2428245	et	3	main
lihtsam	doc_485839256085_item	2428250	et	4	main
peipsimaa	doc_485839256085_item	2428257	et	4	main
oma	doc_485839256085_item	2428260	et	4	main
pajatades	doc_485839256085_item	2428268	et	3	main
haritustase	doc_485839256085_item	2428279	et	4	main
õppisid	doc_485839256085_item	2428283	et	4	main
vanausulistel	doc_485839256085_item	2428296	et	4	main
au	doc_485839256085_item	2428297	et	4	main
millest	doc_485839256085_item	2428306	et	3	main
paremini	doc_485839256085_item	2428333	et	4	main
on	doc_485839256085_item	2428334	et	4	main
papist-armukesest	doc_485839256085_item	2428342	et	4	main
võlumuinasjutu	doc_485839256085_item	2428350	et	3	main
ja	doc_485839256085_item	2428351	et	3	main
ei	doc_485839256085_item	2428358	et	4	main
eluolu	doc_485839256085_item	2428361	et	4	main
pärimusi	doc_485839256085_item	2428369	et	4	main
ja	doc_485839256085_item	2428370	et	3	main
legende	doc_485839256085_item	2428371	et	3	main
ekspeditsiooni	doc_485839256085_item	2428372	et	4	main
vähem	doc_485839256085_item	2428377	et	4	main
huvi	doc_485839256085_item	2428392	et	4	main
folkloorimaterjalid	doc_485839256085_item	2428124	et	3	main
rahvatarkust	doc_485839256085_item	2428126	et	4	main
ei	doc_485839256085_item	2428128	et	4	main
otsi	doc_485839256085_item	2428129	et	4	main
seda	doc_485839256085_item	2428130	et	3	main
mustvee	doc_485839256085_item	2428135	et	3	main
kooliõpilastele	doc_485839256085_item	2428136	et	4	main
kui	doc_485839256085_item	2428144	et	3	main
küsimusele	doc_485839256085_item	2428151	et	4	main
igaüks	doc_485839256085_item	2428162	et	3	main
talvistepühade	doc_485839256085_item	2428168	et	4	main
ennustustest	doc_485839256085_item	2428169	et	4	main
tuli	doc_485839256085_item	2428178	et	4	main
selliseid	doc_485839256085_item	2428190	et	4	main
oli	doc_485839256085_item	2428209	et	3	main
üks	doc_485839256085_item	2428213	et	3	main
neid	doc_485839256085_item	2428222	et	4	main
kelle	doc_485839256085_item	2428230	et	4	main
folkloristi	doc_485839256085_item	2428237	et	4	main
neljavärsilisi	doc_485839256085_item	2428241	et	4	main
palju	doc_485839256085_item	2428249	et	4	main
siiski	doc_485839256085_item	2428252	et	4	main
algusel	doc_485839256085_item	2428256	et	4	main
vanaemasi	doc_485839256085_item	2428261	et	4	main
kes	doc_485839256085_item	2428262	et	4	main
meelt	doc_485839256085_item	2428267	et	4	main
vanausuliste	doc_485839256085_item	2428280	et	4	main
kohalikes	doc_485839256085_item	2428284	et	3	main
sees	doc_485839256085_item	2428298	et	4	main
esmajoones	doc_485839256085_item	2428307	et	3	main
kannatavad	doc_485839256085_item	2428308	et	4	main
just	doc_485839256085_item	2428309	et	3	main
muinasjutud	doc_485839256085_item	2428310	et	3	main
materjali	doc_485839256085_item	2428311	et	4	main
eripärast	doc_485839256085_item	2428321	et	4	main
venemaa	doc_485839256085_item	2428327	et	4	main
kubermangus	doc_485839256085_item	2428328	et	3	main
abielunaisest	doc_485839256085_item	2428341	et	3	main
võistlejatest	doc_485839256085_item	2428344	et	4	main
nendes	doc_485839256085_item	2428356	et	4	main
oodatust	doc_485839256085_item	2428375	et	4	main
vastuolulised	doc_485839256085_item	2428380	et	4	main
keeleteadlaste	doc_485839256085_item	2428387	et	3	main
ja	doc_485839256085_item	2428388	et	3	main
kohalikust	doc_485839256085_item	2428395	et	4	main
punasest	doc_485839256085_item	2428398	et	4	main
pärimusjutt	doc_485839256085_item	2428401	et	4	main
laiali	doc_485839256085_item	2428426	et	3	main
lihtsalt	doc_485839256085_item	2428431	et	4	main
tegelaskujudest	doc_485839256085_item	2428434	et	3	main
eestlane	doc_485839256085_item	2428446	et	3	main
oma	doc_485839256085_item	2428448	et	4	main
elu	doc_485839256085_item	2428449	et	4	main
lõpuni	doc_485839256085_item	2428450	et	3	main
vene	doc_485839256085_item	2428455	et	4	main
mikolale	doc_485839256085_item	2428456	et	4	main
küünalt	doc_485839256085_item	2428457	et	3	main
panemas	doc_485839256085_item	2428458	et	3	main
oma	doc_485839256085_item	2428463	et	4	main
endimisi	doc_485839256085_item	2428502	et	4	main
võtme	doc_485839256085_item	2428503	et	3	main
rolli	doc_485839256085_item	2428504	et	4	main
kirja	doc_485839256085_item	2428226	et	4	main
ajal	doc_485839256085_item	2428228	et	4	main
kogujad	doc_485839256085_item	2428229	et	4	main
olnud	doc_485839256085_item	2428233	et	4	main
peaaegu	doc_485839256085_item	2428234	et	3	main
ühtegi	doc_485839256085_item	2428235	et	4	main
professionaalset	doc_485839256085_item	2428236	et	3	main
üleskirjutada	doc_485839256085_item	2428239	et	4	main
tšastuškasi	doc_485839256085_item	2428243	et	2	main
mis	doc_485839256085_item	2428246	et	4	main
ja	doc_485839256085_item	2428251	et	3	main
muinasjutte	doc_485839256085_item	2428269	et	3	main
seletab	doc_485839256085_item	2428275	et	3	main
suhteliselt	doc_485839256085_item	2428277	et	4	main
kõrge	doc_485839256085_item	2428278	et	4	main
koolides	doc_485839256085_item	2428285	et	3	main
klaasi	doc_485839256085_item	2428287	et	4	main
oli	doc_485839256085_item	2428289	et	3	main
peagi	doc_485839256085_item	2428290	et	4	main
igaühel	doc_485839256085_item	2428291	et	3	main
ka	doc_485839256085_item	2428292	et	3	main
raamatute	doc_485839256085_item	2428293	et	3	main
oli	doc_485839256085_item	2428295	et	3	main
nappuse	doc_485839256085_item	2428312	et	4	main
tõttu	doc_485839256085_item	2428313	et	4	main
on	doc_485839256085_item	2428314	et	4	main
raske	doc_485839256085_item	2428315	et	4	main
rääkida	doc_485839256085_item	2428316	et	3	main
midagi	doc_485839256085_item	2428317	et	4	main
kindlat	doc_485839256085_item	2428318	et	3	main
suulise	doc_485839256085_item	2428319	et	4	main
traditsiooni	doc_485839256085_item	2428320	et	4	main
süžeed	doc_485839256085_item	2428323	et	2	main
säilinud	doc_485839256085_item	2428335	et	4	main
olustiku	doc_485839256085_item	2428336	et	3	main
rahvaanekdoodid	doc_485839256085_item	2428339	et	3	main
mütoloogilise	doc_485839256085_item	2428352	et	4	main
rahvajutu	doc_485839256085_item	2428353	et	3	main
vahepealse	doc_485839256085_item	2428354	et	3	main
liigi	doc_485839256085_item	2428355	et	4	main
kohaliku	doc_485839256085_item	2428360	et	3	main
väljendub	doc_485839256085_item	2428365	et	3	main
pigem	doc_485839256085_item	2428366	et	3	main
palju	doc_485839256085_item	2428376	et	4	main
vanausuliste	doc_485839256085_item	2428382	et	4	main
pigem	doc_485839256085_item	2428385	et	3	main
ajaloolaste	doc_485839256085_item	2428389	et	4	main
artiklitel	doc_485839256085_item	2428390	et	3	main
teatud	doc_485839256085_item	2428391	et	4	main
miks	doc_485839256085_item	2428405	et	4	main
külades	doc_485839256085_item	2428410	et	3	main
eestlasi	doc_485839256085_item	2428421	et	3	main
kõiki	doc_485839256085_item	2428424	et	4	main
käputäiega	doc_485839256085_item	2428432	et	3	main
tänapäevalgi	doc_485839256085_item	2428439	et	4	main
levivad	doc_485839256085_item	2428440	et	4	main
päästmistest	doc_485839256085_item	2428444	et	4	main
olevat	doc_485839256085_item	2428447	et	4	main
käinud	doc_485839256085_item	2428451	et	4	main
tänades	doc_485839256085_item	2428459	et	3	main
sel	doc_485839256085_item	2428460	et	3	main
elu	doc_485839256085_item	2428464	et	4	main
eest	doc_485839256085_item	2428466	et	4	main
mõnede	doc_485839256085_item	2428467	et	3	main
taevas	doc_485839256085_item	2428493	et	4	main
rahvalaule	doc_485839256085_item	2428513	et	4	main
neid	doc_485839256085_item	2428514	et	4	main
lauldakse	doc_485839256085_item	2428515	et	3	main
paastu	doc_485839256085_item	2428516	et	4	main
ajal	doc_485839256085_item	2428517	et	4	main
nii	doc_485839256085_item	2428527	et	3	main
säilinud	doc_485839256085_item	2428536	et	4	main
lahutasid	doc_485839256085_item	2428266	et	4	main
muinasjuttude	doc_485839256085_item	2428270	et	4	main
vähesust	doc_485839256085_item	2428272	et	4	main
määral	doc_485839256085_item	2428274	et	3	main
ka	doc_485839256085_item	2428276	et	3	main
nad	doc_485839256085_item	2428282	et	3	main
haridus	doc_485839256085_item	2428288	et	3	main
siinkohas	doc_485839256085_item	2428299	et	4	main
kindlasti	doc_485839256085_item	2428300	et	3	main
tuleb	doc_485839256085_item	2428301	et	3	main
mainida	doc_485839256085_item	2428302	et	3	main
ka	doc_485839256085_item	2428303	et	3	main
linnakultuuri	doc_485839256085_item	2428304	et	4	main
mõju	doc_485839256085_item	2428305	et	4	main
loode	doc_485839256085_item	2428326	et	4	main
levinud	doc_485839256085_item	2428329	et	4	main
repertuaari	doc_485839256085_item	2428330	et	4	main
raame	doc_485839256085_item	2428331	et	3	main
muinasjutud	doc_485839256085_item	2428337	et	3	main
samuti	doc_485839256085_item	2428338	et	3	main
endast	doc_485839256085_item	2428349	et	4	main
leidu	doc_485839256085_item	2428359	et	4	main
kohalik	doc_485839256085_item	2428363	et	3	main
keelelises	doc_485839256085_item	2428367	et	4	main
plaanis	doc_485839256085_item	2428368	et	4	main
segased	doc_485839256085_item	2428378	et	3	main
ja	doc_485839256085_item	2428379	et	3	main
venemaalt	doc_485839256085_item	2428384	et	3	main
põhinevad	doc_485839256085_item	2428386	et	4	main
röövlist	doc_485839256085_item	2428396	et	4	main
levinud	doc_485839256085_item	2428400	et	4	main
mis	doc_485839256085_item	2428402	et	4	main
vaimukalt	doc_485839256085_item	2428403	et	4	main
seletab	doc_485839256085_item	2428404	et	3	main
fikseeritud	doc_485839256085_item	2428322	et	4	main
ei	doc_485839256085_item	2428324	et	4	main
ületa	doc_485839256085_item	2428325	et	4	main
teistest	doc_485839256085_item	2428332	et	4	main
laisast	doc_485839256085_item	2428340	et	3	main
leidlikuses	doc_485839256085_item	2428343	et	4	main
luiskajatest	doc_485839256085_item	2428345	et	4	main
mõned	doc_485839256085_item	2428346	et	3	main
teosed	doc_485839256085_item	2428347	et	3	main
kujutavad	doc_485839256085_item	2428348	et	4	main
tekstides	doc_485839256085_item	2428357	et	3	main
tunnuseid	doc_485839256085_item	2428362	et	3	main
omapära	doc_485839256085_item	2428364	et	4	main
käigus	doc_485839256085_item	2428373	et	4	main
olinüleskirjutatud	doc_485839256085_item	2428374	et	4	main
lood	doc_485839256085_item	2428381	et	4	main
ümberasumisest	doc_485839256085_item	2428383	et	4	main
pärimus	doc_485839256085_item	2428394	et	4	main
on	doc_485839256085_item	2428399	et	4	main
elavad	doc_485839256085_item	2428407	et	4	main
kompaktselt	doc_485839256085_item	2428408	et	4	main
rahvarohketes	doc_485839256085_item	2428409	et	3	main
aga	doc_485839256085_item	2428411	et	3	main
eestlased	doc_485839256085_item	2428412	et	3	main
elavad	doc_485839256085_item	2428413	et	4	main
üksikult	doc_485839256085_item	2428414	et	4	main
oma	doc_485839256085_item	2428415	et	4	main
taludes	doc_485839256085_item	2428416	et	4	main
kurat	doc_485839256085_item	2428417	et	4	main
lendas	doc_485839256085_item	2428418	et	3	main
taevas	doc_485839256085_item	2428419	et	4	main
ja	doc_485839256085_item	2428420	et	3	main
puistas	doc_485839256085_item	2428422	et	3	main
ükshaaval	doc_485839256085_item	2428425	et	3	main
on	doc_485839256085_item	2428437	et	4	main
üks	doc_485839256085_item	2428445	et	3	main
vanausuliste	doc_485839256085_item	2428453	et	4	main
palvelas	doc_485839256085_item	2428454	et	3	main
ettekuulutuslikust	doc_485839256085_item	2428488	et	4	main
sõja	doc_485839256085_item	2428490	et	3	main
eel	doc_485839256085_item	2428491	et	4	main
olevat	doc_485839256085_item	2428492	et	4	main
igapäevaelus	doc_485839256085_item	2428501	et	4	main
tänaseni	doc_485839256085_item	2428508	et	4	main
vaimulikke	doc_485839256085_item	2428509	et	3	main
värsse	doc_485839256085_item	2428510	et	3	main
religioosse	doc_485839256085_item	2428511	et	3	main
sisuga	doc_485839256085_item	2428512	et	3	main
mil	doc_485839256085_item	2428518	et	4	main
laule	doc_485839256085_item	2428521	et	4	main
ei	doc_485839256085_item	2428523	et	4	main
tohi	doc_485839256085_item	2428524	et	4	main
lauldakse	doc_485839256085_item	2428525	et	3	main
vanast	doc_485839256085_item	2428539	et	3	main
osa	doc_485839256085_item	2428547	et	4	main
õigeusu	doc_485839256085_item	2428556	et	3	main
athose	doc_485839256085_item	2428559	et	4	main
värss	doc_485839256085_item	2428561	et	3	main
surmatunnist	doc_485839256085_item	2428562	et	4	main
venemaal	doc_485839256085_item	2428575	et	4	main
süžee	doc_485839256085_item	2428578	et	2	main
ema	doc_485839256085_item	2428581	et	4	main
loodud	doc_485839256085_item	2428588	et	4	main
munkade	doc_485839256085_item	2428589	et	3	main
ja	doc_485839256085_item	2428590	et	3	main
viitab	doc_485839256085_item	2428596	et	3	main
sõnade	doc_485839256085_item	2428598	et	3	main
võõras	doc_485839256085_item	2428602	et	4	main
будет	doc_485839256085_item	2428612	et	2	main
десница	doc_485839256085_item	2428618	et	2	main
над	doc_485839256085_item	2428622	et	2	main
pakub	doc_485839256085_item	2428393	et	3	main
vasjkast	doc_485839256085_item	2428397	et	4	main
vanausulised	doc_485839256085_item	2428406	et	4	main
ta	doc_485839256085_item	2428423	et	4	main
viskas	doc_485839256085_item	2428429	et	3	main
nikola-imetegija	doc_485839256085_item	2428438	et	4	main
imelistest	doc_485839256085_item	2428443	et	4	main
regulaarselt	doc_485839256085_item	2428452	et	4	main
moel	doc_485839256085_item	2428461	et	4	main
päästmise	doc_485839256085_item	2428465	et	4	main
panna	doc_485839256085_item	2428486	et	4	main
ilmutusest	doc_485839256085_item	2428489	et	4	main
nähtud	doc_485839256085_item	2428494	et	4	main
risti	doc_485839256085_item	2428495	et	4	main
kujutist	doc_485839256085_item	2428496	et	3	main
religioosne	doc_485839256085_item	2428497	et	3	main
maailmatunnetus	doc_485839256085_item	2428498	et	3	main
omab	doc_485839256085_item	2428499	et	3	main
vanausuliste	doc_485839256085_item	2428500	et	4	main
naised	doc_485839256085_item	2428506	et	3	main
mäletavad	doc_485839256085_item	2428507	et	4	main
kuratlikke	doc_485839256085_item	2428520	et	3	main
neid	doc_485839256085_item	2428526	et	4	main
pühade	doc_485839256085_item	2428528	et	3	main
argipäeviti	doc_485839256085_item	2428532	et	3	main
süžeed	doc_485839256085_item	2428538	et	2	main
evangeeliumi	doc_485839256085_item	2428550	et	4	main
jüngritest	doc_485839256085_item	2428557	et	3	main
viimsest	doc_485839256085_item	2428566	et	3	main
preestrideta	doc_485839256085_item	2428573	et	4	main
populaarsem	doc_485839256085_item	2428577	et	4	main
poolt	doc_485839256085_item	2428592	et	4	main
süllaabi-tooniline	doc_485839256085_item	2428605	et	4	main
värsisüsteem	doc_485839256085_item	2428606	et	3	main
рекла	doc_485839256085_item	2428609	et	2	main
моим	doc_485839256085_item	2428614	et	2	main
всегда	doc_485839256085_item	2428619	et	2	main
местом	doc_485839256085_item	2428623	et	2	main
oma	doc_485839256085_item	2428638	et	4	main
käe	doc_485839256085_item	2428639	et	3	main
kaitsvaks	doc_485839256085_item	2428642	et	4	main
on	doc_485839256085_item	2428649	et	4	main
ja	doc_485839256085_item	2428655	et	3	main
arhaailisel	doc_485839256085_item	2428666	et	4	main
arusaamal	doc_485839256085_item	2428667	et	3	main
võrdle	doc_485839256085_item	2428675	et	4	main
ja	doc_485839256085_item	2428677	et	3	main
inimese	doc_485839256085_item	2428680	et	4	main
teost	doc_485839256085_item	2428716	et	4	main
paradiisi	doc_485839256085_item	2428718	et	4	main
ja	doc_485839256085_item	2428722	et	3	main
leedust	doc_485839256085_item	2428724	et	4	main
eesti	doc_485839256085_item	2428725	et	4	main
vanausulistel	doc_485839256085_item	2428726	et	4	main
see	doc_485839256085_item	2428727	et	3	main
žanr	doc_485839256085_item	2428728	et	2	main
elab	doc_485839256085_item	2428729	et	3	main
käsikirjalises	doc_485839256085_item	2428733	et	4	main
raamatutest	doc_485839256085_item	2428735	et	4	main
värsid	doc_485839256085_item	2428745	et	3	main
neid	doc_485839256085_item	2428749	et	4	main
värssideks	doc_485839256085_item	2428752	et	3	main
trükikogumikke	doc_485839256085_item	2428763	et	4	main
palvelatesse	doc_485839256085_item	2428783	et	4	main
vaimulik	doc_485839256085_item	2428787	et	3	main
alekseevitš	doc_485839256085_item	2428790	et	2	main
teoste	doc_485839256085_item	2428794	et	3	main
muutu	doc_485839256085_item	2428798	et	4	main
üks	doc_485839256085_item	2428833	et	3	main
ia	doc_485839256085_item	2428838	et	4	main
peipsimaal	doc_485839256085_item	2428860	et	4	main
värsside	doc_485839256085_item	2428863	et	3	main
uuemat	doc_485839256085_item	2428870	et	4	main
motiive	doc_485839256085_item	2428877	et	3	main
stilistilisi	doc_485839256085_item	2428879	et	4	main
lapsukese	doc_485839256085_item	2428881	et	4	main
nutt	doc_485839256085_item	2428882	et	3	main
noorest	doc_485839256085_item	2428885	et	3	main
erakust	doc_485839256085_item	2428886	et	4	main
30	doc_485839256085_item	2428887	et	2	main
aga	doc_485839256085_item	2428427	et	3	main
vanausulisi	doc_485839256085_item	2428428	et	4	main
alla	doc_485839256085_item	2428430	et	3	main
kristlikest	doc_485839256085_item	2428433	et	3	main
kõige	doc_485839256085_item	2428435	et	4	main
populaatsem	doc_485839256085_item	2428436	et	4	main
jutud	doc_485839256085_item	2428441	et	3	main
kalameeste	doc_485839256085_item	2428442	et	4	main
pühakut	doc_485839256085_item	2428462	et	3	main
legendide	doc_485839256085_item	2428468	et	3	main
süžeed	doc_485839256085_item	2428469	et	2	main
geneetiliselt	doc_485839256085_item	2428470	et	4	main
pärinevad	doc_485839256085_item	2428471	et	4	main
piibli	doc_485839256085_item	2428472	et	3	main
lugudest	doc_485839256085_item	2428473	et	3	main
kuid	doc_485839256085_item	2428474	et	4	main
kohalikus	doc_485839256085_item	2428475	et	4	main
repertuaaris	doc_485839256085_item	2428476	et	3	main
on	doc_485839256085_item	2428477	et	4	main
neid	doc_485839256085_item	2428478	et	4	main
siiski	doc_485839256085_item	2428479	et	4	main
suhteliselt	doc_485839256085_item	2428480	et	4	main
vähe	doc_485839256085_item	2428481	et	3	main
2006	doc_485839256085_item	2428482	et	2	main
aastal	doc_485839256085_item	2428483	et	3	main
õnnestus	doc_485839256085_item	2428484	et	4	main
kirja	doc_485839256085_item	2428485	et	4	main
lugu	doc_485839256085_item	2428487	et	4	main
eakamad	doc_485839256085_item	2428505	et	4	main
ilmalikke	doc_485839256085_item	2428519	et	3	main
laulda	doc_485839256085_item	2428522	et	4	main
ka	doc_485839256085_item	2428531	et	3	main
mõned	doc_485839256085_item	2428537	et	3	main
testamendist	doc_485839256085_item	2428540	et	3	main
joosepi	doc_485839256085_item	2428543	et	4	main
põhineb	doc_485839256085_item	2428549	et	3	main
loodel	doc_485839256085_item	2428551	et	4	main
pühakute	doc_485839256085_item	2428552	et	3	main
elulugudel	doc_485839256085_item	2428553	et	3	main
kohus	doc_485839256085_item	2428564	et	4	main
värss	doc_485839256085_item	2428565	et	3	main
vaimulike	doc_485839256085_item	2428591	et	3	main
millele	doc_485839256085_item	2428595	et	3	main
rohkus	doc_485839256085_item	2428599	et	4	main
tekstides	doc_485839256085_item	2428600	et	3	main
rahvaluulele	doc_485839256085_item	2428601	et	4	main
гора	doc_485839256085_item	2428608	et	2	main
да	doc_485839256085_item	2428611	et	2	main
отсель	doc_485839256085_item	2428615	et	2	main
мой	doc_485839256085_item	2428620	et	2	main
кров	doc_485839256085_item	2428621	et	2	main
lausus	doc_485839256085_item	2428629	et	4	main
ta	doc_485839256085_item	2428631	et	4	main
minu	doc_485839256085_item	2428633	et	3	main
siin	doc_485839256085_item	2428644	et	4	main
paljudes	doc_485839256085_item	2428650	et	3	main
tekstides	doc_485839256085_item	2428651	et	3	main
mungast	doc_485839256085_item	2428660	et	4	main
antooniusest	doc_485839256085_item	2428661	et	4	main
vt	doc_485839256085_item	2428663	et	4	main
23	doc_485839256085_item	2428664	et	2	main
põhineb	doc_485839256085_item	2428665	et	3	main
kulgeb	doc_485839256085_item	2428672	et	3	main
rännakust	doc_485839256085_item	2428681	et	3	main
taevasse	doc_485839256085_item	2428682	et	4	main
suulises	doc_485839256085_item	2428731	et	4	main
tavaliselt	doc_485839256085_item	2428750	et	4	main
2006	doc_485839256085_item	2428753	et	2	main
on	doc_485839256085_item	2428755	et	4	main
näidanud	doc_485839256085_item	2428760	et	4	main
vaimulike	doc_485839256085_item	2428761	et	3	main
värsside	doc_485839256085_item	2428762	et	3	main
enne	doc_485839256085_item	2428767	et	4	main
põhinevad	doc_485839256085_item	2428771	et	4	main
mõnede	doc_485839256085_item	2428773	et	3	main
trükikoopiad	doc_485839256085_item	2428777	et	3	main
mõne	doc_485839256085_item	2428779	et	3	main
toodud	doc_485839256085_item	2428784	et	4	main
ei	doc_485839256085_item	2428797	et	4	main
ajal	doc_485839256085_item	2428529	et	4	main
kui	doc_485839256085_item	2428530	et	3	main
peipsi	doc_485839256085_item	2428533	et	4	main
läänerannikul	doc_485839256085_item	2428534	et	3	main
on	doc_485839256085_item	2428535	et	4	main
veeuputusest	doc_485839256085_item	2428542	et	4	main
nutulaul	doc_485839256085_item	2428544	et	4	main
siiski	doc_485839256085_item	2428545	et	4	main
suurim	doc_485839256085_item	2428546	et	3	main
jutustustel	doc_485839256085_item	2428554	et	4	main
samaarilanna	doc_485839256085_item	2428558	et	4	main
mägi	doc_485839256085_item	2428560	et	3	main
hirmus	doc_485839256085_item	2428563	et	4	main
jt	doc_485839256085_item	2428570	et	4	main
samuti	doc_485839256085_item	2428571	et	3	main
kui	doc_485839256085_item	2428572	et	3	main
kõige	doc_485839256085_item	2428576	et	4	main
on	doc_485839256085_item	2428579	et	4	main
võrdlemisi	doc_485839256085_item	2428593	et	4	main
rütmika	doc_485839256085_item	2428603	et	4	main
ja	doc_485839256085_item	2428604	et	3	main
сия	doc_485839256085_item	2428607	et	2	main
царица	doc_485839256085_item	2428610	et	2	main
прострет	doc_485839256085_item	2428616	et	2	main
сим	doc_485839256085_item	2428624	et	2	main
see	doc_485839256085_item	2428627	et	3	main
tsaaritar	doc_485839256085_item	2428630	et	3	main
saagu	doc_485839256085_item	2428632	et	3	main
saatuseks	doc_485839256085_item	2428634	et	4	main
kuid	doc_485839256085_item	2428646	et	4	main
samal	doc_485839256085_item	2428647	et	3	main
iidseid	doc_485839256085_item	2428653	et	3	main
kujundeid	doc_485839256085_item	2428656	et	3	main
värss	doc_485839256085_item	2428658	et	3	main
erinevates	doc_485839256085_item	2428669	et	4	main
erineva	doc_485839256085_item	2428673	et	4	main
mütoloogilisi	doc_485839256085_item	2428678	et	4	main
rahvajutte	doc_485839256085_item	2428679	et	3	main
nimetatakse	doc_485839256085_item	2428717	et	3	main
eriti	doc_485839256085_item	2428723	et	3	main
vaid	doc_485839256085_item	2428732	et	3	main
traditsioonis	doc_485839256085_item	2428734	et	3	main
mujal	doc_485839256085_item	2428746	et	3	main
lauljad	doc_485839256085_item	2428747	et	4	main
lihtsalt	doc_485839256085_item	2428751	et	4	main
aastal	doc_485839256085_item	2428754	et	3	main
vanausulised	doc_485839256085_item	2428756	et	4	main
revolutsiooni	doc_485839256085_item	2428768	et	4	main
ka	doc_485839256085_item	2428772	et	3	main
olid	doc_485839256085_item	2428782	et	4	main
daugavpilsist	doc_485839256085_item	2428786	et	4	main
praktiliselt	doc_485839256085_item	2428796	et	4	main
vahel	doc_485839256085_item	2428824	et	4	main
rütmiliselt	doc_485839256085_item	2428826	et	4	main
sobivaid	doc_485839256085_item	2428827	et	4	main
lüüriliste	doc_485839256085_item	2428828	et	3	main
viise	doc_485839256085_item	2428830	et	3	main
leidus	doc_485839256085_item	2428831	et	4	main
ka	doc_485839256085_item	2428832	et	3	main
huvi	doc_485839256085_item	2428842	et	4	main
luule	doc_485839256085_item	2428845	et	4	main
vastu	doc_485839256085_item	2428846	et	3	main
tuletasid	doc_485839256085_item	2428849	et	4	main
nooremale	doc_485839256085_item	2428855	et	4	main
teist	doc_485839256085_item	2428858	et	4	main
vaimulike	doc_485839256085_item	2428862	et	3	main
esineb	doc_485839256085_item	2428873	et	3	main
tüüpilisi	doc_485839256085_item	2428876	et	3	main
algab	doc_485839256085_item	2428892	et	3	main
varutakse	doc_485839256085_item	2428907	et	4	main
raijutud	doc_485839256085_item	2428913	et	4	main
s	doc_485839256085_item	2428926	et	4	main
eeskätt	doc_485839256085_item	2428936	et	3	main
korilauljad	doc_485839256085_item	2428938	et	4	main
rangelt	doc_485839256085_item	2428939	et	4	main
etiketti	doc_485839256085_item	2428942	et	4	main
eriti	doc_485839256085_item	2428945	et	3	main
välja	doc_485839256085_item	2428967	et	4	main
tuli	doc_485839256085_item	2428973	et	4	main
jumalateenistusele	doc_485839256085_item	2428975	et	3	main
ülemaailmsest	doc_485839256085_item	2428541	et	3	main
teoseid	doc_485839256085_item	2428548	et	3	main
iidse	doc_485839256085_item	2428555	et	3	main
ajast	doc_485839256085_item	2428567	et	4	main
bojarinna	doc_485839256085_item	2428568	et	4	main
morozova	doc_485839256085_item	2428569	et	4	main
vanausulistel	doc_485839256085_item	2428574	et	4	main
anus	doc_485839256085_item	2428580	et	3	main
oma	doc_485839256085_item	2428582	et	4	main
lapsukest	doc_485839256085_item	2428583	et	4	main
suurim	doc_485839256085_item	2428584	et	3	main
osa	doc_485839256085_item	2428585	et	4	main
teoseid	doc_485839256085_item	2428586	et	3	main
on	doc_485839256085_item	2428587	et	4	main
hiljaaegu	doc_485839256085_item	2428594	et	3	main
kirikuslaavi	doc_485839256085_item	2428597	et	4	main
жребием	doc_485839256085_item	2428613	et	2	main
моя	doc_485839256085_item	2428617	et	2	main
и	doc_485839256085_item	2428625	et	2	main
siit	doc_485839256085_item	2428635	et	3	main
sirutan	doc_485839256085_item	2428636	et	3	main
ma	doc_485839256085_item	2428637	et	3	main
et	doc_485839256085_item	2428640	et	3	main
ajal	doc_485839256085_item	2428648	et	4	main
motiive	doc_485839256085_item	2428654	et	3	main
noorest	doc_485839256085_item	2428659	et	3	main
et	doc_485839256085_item	2428668	et	3	main
maailmades	doc_485839256085_item	2428670	et	3	main
kiirusega	doc_485839256085_item	2428674	et	4	main
võlumuinasjutte	doc_485839256085_item	2428676	et	3	main
kuningriiki	doc_485839256085_item	2428684	et	4	main
hauatagusesse	doc_485839256085_item	2428685	et	4	main
maailma	doc_485839256085_item	2428686	et	4	main
jt	doc_485839256085_item	2428687	et	4	main
jälitades	doc_485839256085_item	2428688	et	3	main
imelist	doc_485839256085_item	2428689	et	4	main
lindu	doc_485839256085_item	2428690	et	4	main
antoonius	doc_485839256085_item	2428691	et	4	main
jätab	doc_485839256085_item	2428692	et	3	main
kloostri	doc_485839256085_item	2428693	et	3	main
ja	doc_485839256085_item	2428694	et	3	main
sattub	doc_485839256085_item	2428695	et	3	main
kolmeks	doc_485839256085_item	2428696	et	4	main
tunniks	doc_485839256085_item	2428697	et	3	main
paradiisi	doc_485839256085_item	2428698	et	4	main
maa	doc_485839256085_item	2428699	et	4	main
peal	doc_485839256085_item	2428700	et	4	main
aga	doc_485839256085_item	2428701	et	3	main
selle	doc_485839256085_item	2428702	et	4	main
ajaga	doc_485839256085_item	2428703	et	3	main
möödub	doc_485839256085_item	2428704	et	3	main
kolmsada	doc_485839256085_item	2428705	et	4	main
aastat	doc_485839256085_item	2428706	et	3	main
tekstis	doc_485839256085_item	2428707	et	3	main
paradiisi	doc_485839256085_item	2428708	et	4	main
ei	doc_485839256085_item	2428709	et	4	main
mainita	doc_485839256085_item	2428710	et	3	main
kuid	doc_485839256085_item	2428711	et	4	main
paljudes	doc_485839256085_item	2428712	et	3	main
regioonides	doc_485839256085_item	2428713	et	3	main
venemaal	doc_485839256085_item	2428714	et	4	main
seda	doc_485839256085_item	2428715	et	3	main
тп	doc_485839256085_item	2428626	et	2	main
mägi	doc_485839256085_item	2428628	et	3	main
olla	doc_485839256085_item	2428641	et	3	main
katteks	doc_485839256085_item	2428643	et	3	main
jn	doc_485839256085_item	2428645	et	4	main
säilinud	doc_485839256085_item	2428652	et	4	main
näiteks	doc_485839256085_item	2428657	et	4	main
süžee	doc_485839256085_item	2428662	et	2	main
aeg	doc_485839256085_item	2428671	et	3	main
veealusesse	doc_485839256085_item	2428683	et	4	main
lätist	doc_485839256085_item	2428721	et	4	main
ka	doc_485839256085_item	2428739	et	3	main
nimetavad	doc_485839256085_item	2428748	et	4	main
seal	doc_485839256085_item	2428764	et	4	main
hulgas	doc_485839256085_item	2428765	et	4	main
allikatel	doc_485839256085_item	2428770	et	4	main
süžeede	doc_485839256085_item	2428774	et	2	main
ja	doc_485839256085_item	2428776	et	3	main
mis	doc_485839256085_item	2428778	et	4	main
lätist	doc_485839256085_item	2428785	et	4	main
ilja	doc_485839256085_item	2428789	et	4	main
poolt	doc_485839256085_item	2428792	et	4	main
koopiates	doc_485839256085_item	2428793	et	3	main
sisu	doc_485839256085_item	2428795	et	4	main
värsse	doc_485839256085_item	2428821	et	3	main
kirikuviisidel	doc_485839256085_item	2428823	et	3	main
kasutatakse	doc_485839256085_item	2428825	et	3	main
ukraina	doc_485839256085_item	2428834	et	4	main
pärast	doc_485839256085_item	2428837	et	4	main
visiiti	doc_485839256085_item	2428840	et	4	main
taaselustus	doc_485839256085_item	2428841	et	4	main
õpetasid	doc_485839256085_item	2428854	et	4	main
levinuid	doc_485839256085_item	2428861	et	4	main
viise	doc_485839256085_item	2428864	et	3	main
antud	doc_485839256085_item	2428865	et	4	main
kogumikus	doc_485839256085_item	2428866	et	4	main
rahvaluulet	doc_485839256085_item	2428871	et	3	main
luulele	doc_485839256085_item	2428875	et	4	main
stereotüüpe	doc_485839256085_item	2428880	et	3	main
29	doc_485839256085_item	2428883	et	2	main
värss	doc_485839256085_item	2428884	et	3	main
istutakse	doc_485839256085_item	2428896	et	3	main
tõsist	doc_485839256085_item	2428899	et	4	main
tööd	doc_485839256085_item	2428900	et	4	main
minnakse	doc_485839256085_item	2428901	et	3	main
öösel	doc_485839256085_item	2428906	et	4	main
või	doc_485839256085_item	2428911	et	4	main
mille	doc_485839256085_item	2428915	et	3	main
nastavnik	doc_485839256085_item	2428917	et	4	main
on	doc_485839256085_item	2428918	et	4	main
vahest	doc_485839256085_item	2428922	et	4	main
neid	doc_485839256085_item	2428923	et	4	main
nimetatakse	doc_485839256085_item	2428924	et	3	main
puhtakspestud	doc_485839256085_item	2428929	et	3	main
viirukiga	doc_485839256085_item	2428932	et	3	main
põlvkonna	doc_485839256085_item	2428934	et	4	main
neid	doc_485839256085_item	2428949	et	4	main
nimetatakse	doc_485839256085_item	2428950	et	3	main
sulased	doc_485839256085_item	2428954	et	3	main
kohalik	doc_485839256085_item	2428959	et	3	main
tema	doc_485839256085_item	2428963	et	4	main
heideti	doc_485839256085_item	2428965	et	3	main
kogudusest	doc_485839256085_item	2428966	et	4	main
et	doc_485839256085_item	2428971	et	3	main
lõhikuga	doc_485839256085_item	2428978	et	3	main
märgistasid	doc_485839256085_item	2428980	et	4	main
oma	doc_485839256085_item	2428981	et	4	main
sööginõusi	doc_485839256085_item	2428982	et	4	main
vältimaks	doc_485839256085_item	2428983	et	3	main
et	doc_485839256085_item	2428984	et	3	main
ilmalikud	doc_485839256085_item	2428985	et	3	main
tulles	doc_485839256085_item	2428989	et	4	main
naisele	doc_485839256085_item	2429000	et	3	main
andis	doc_485839256085_item	2429001	et	3	main
ta	doc_485839256085_item	2429002	et	4	main
kinnitasid	doc_485839256085_item	2429021	et	4	main
suurte	doc_485839256085_item	2429023	et	3	main
nikolai	doc_485839256085_item	2429028	et	4	main
vetelpäästja	doc_485839256085_item	2429033	et	4	main
maine	doc_485839256085_item	2429034	et	4	main
sealt	doc_485839256085_item	2429045	et	4	main
linnuke	doc_485839256085_item	2428719	et	4	main
erinevalt	doc_485839256085_item	2428720	et	4	main
mitte	doc_485839256085_item	2428730	et	3	main
on	doc_485839256085_item	2428736	et	4	main
nähtavasti	doc_485839256085_item	2428737	et	3	main
võetud	doc_485839256085_item	2428738	et	4	main
peipsi	doc_485839256085_item	2428740	et	4	main
läänerannikul	doc_485839256085_item	2428741	et	3	main
juurdunud	doc_485839256085_item	2428742	et	4	main
termin	doc_485839256085_item	2428743	et	3	main
vaimulikud	doc_485839256085_item	2428744	et	3	main
ekspeditsiooni	doc_485839256085_item	2428757	et	4	main
liikmetele	doc_485839256085_item	2428758	et	3	main
tihti	doc_485839256085_item	2428759	et	3	main
trükituid	doc_485839256085_item	2428766	et	4	main
nendel	doc_485839256085_item	2428769	et	4	main
masinakirja-	doc_485839256085_item	2428775	et	4	main
aasta	doc_485839256085_item	2428780	et	4	main
eest	doc_485839256085_item	2428781	et	4	main
nastavnik	doc_485839256085_item	2428788	et	4	main
žilko	doc_485839256085_item	2428791	et	2	main
varieerimine	doc_485839256085_item	2428799	et	4	main
väljendub	doc_485839256085_item	2428800	et	3	main
vaid	doc_485839256085_item	2428801	et	3	main
mõnede	doc_485839256085_item	2428802	et	3	main
salmide	doc_485839256085_item	2428803	et	3	main
väljajätmises	doc_485839256085_item	2428804	et	3	main
ja	doc_485839256085_item	2428805	et	3	main
mõnede	doc_485839256085_item	2428806	et	3	main
arhaailste	doc_485839256085_item	2428808	et	4	main
sõnade	doc_485839256085_item	2428809	et	3	main
ja	doc_485839256085_item	2428810	et	3	main
väljendite	doc_485839256085_item	2428811	et	3	main
moonutamises	doc_485839256085_item	2428812	et	4	main
kuna	doc_485839256085_item	2428813	et	3	main
arusaamatute	doc_485839256085_item	2428807	et	4	main
trüki-	doc_485839256085_item	2428814	et	4	main
ja	doc_485839256085_item	2428815	et	3	main
käsikirjalised	doc_485839256085_item	2428816	et	4	main
kogumikud	doc_485839256085_item	2428817	et	4	main
ei	doc_485839256085_item	2428818	et	4	main
ole	doc_485839256085_item	2428819	et	4	main
noteeritud	doc_485839256085_item	2428820	et	4	main
kallastes	doc_485839256085_item	2428836	et	4	main
rahva	doc_485839256085_item	2428843	et	3	main
religioosse	doc_485839256085_item	2428844	et	3	main
naised	doc_485839256085_item	2428848	et	3	main
maailmasõda	doc_485839256085_item	2428859	et	4	main
on	doc_485839256085_item	2428867	et	4	main
kus	doc_485839256085_item	2428872	et	3	main
ja	doc_485839256085_item	2428878	et	3	main
palve	doc_485839256085_item	2428893	et	4	main
söögilauda	doc_485839256085_item	2428897	et	4	main
metsa	doc_485839256085_item	2428902	et	4	main
vett	doc_485839256085_item	2428909	et	3	main
sisse	doc_485839256085_item	2428920	et	4	main
lauldakse	doc_485839256085_item	2428822	et	3	main
laulude	doc_485839256085_item	2428829	et	3	main
lauluviis	doc_485839256085_item	2428835	et	3	main
žilko	doc_485839256085_item	2428839	et	2	main
eakad	doc_485839256085_item	2428847	et	3	main
meelde	doc_485839256085_item	2428850	et	3	main
oma	doc_485839256085_item	2428851	et	4	main
nooruspõlve	doc_485839256085_item	2428852	et	4	main
ja	doc_485839256085_item	2428853	et	3	main
enne	doc_485839256085_item	2428857	et	4	main
põlvkonnale	doc_485839256085_item	2428856	et	4	main
toodud	doc_485839256085_item	2428868	et	4	main
ka	doc_485839256085_item	2428869	et	3	main
vanausuliste	doc_485839256085_item	2428874	et	4	main
iga	doc_485839256085_item	2428890	et	4	main
päev	doc_485839256085_item	2428891	et	3	main
palvega	doc_485839256085_item	2428895	et	3	main
või	doc_485839256085_item	2428903	et	4	main
püha	doc_485839256085_item	2428908	et	4	main
ristikujuliselt	doc_485839256085_item	2428912	et	4	main
jääaugust	doc_485839256085_item	2428914	et	4	main
vaimulik	doc_485839256085_item	2428916	et	3	main
eelnevalt	doc_485839256085_item	2428919	et	4	main
enne	doc_485839256085_item	2428927	et	4	main
ülestõusmispüha	doc_485839256085_item	2428928	et	4	main
kiriku	doc_485839256085_item	2428941	et	3	main
on	doc_485839256085_item	2428944	et	4	main
range	doc_485839256085_item	2428946	et	4	main
mis	doc_485839256085_item	2428952	et	4	main
üks	doc_485839256085_item	2428958	et	3	main
jutustas	doc_485839256085_item	2428961	et	3	main
vanaisa	doc_485839256085_item	2428964	et	4	main
eest	doc_485839256085_item	2428970	et	4	main
palvelasse	doc_485839256085_item	2428974	et	4	main
moodsas	doc_485839256085_item	2428976	et	3	main
võõraste	doc_485839256085_item	2428990	et	4	main
külla	doc_485839256085_item	2428992	et	4	main
mees	doc_485839256085_item	2428993	et	4	main
jõi	doc_485839256085_item	2428994	et	3	main
juua	doc_485839256085_item	2429003	et	3	main
sealt	doc_485839256085_item	2429004	et	4	main
samast	doc_485839256085_item	2429005	et	4	main
ikooni	doc_485839256085_item	2429027	et	4	main
kellel	doc_485839256085_item	2429031	et	4	main
naastes	doc_485839256085_item	2429041	et	4	main
ikoone	doc_485839256085_item	2429047	et	3	main
päästavad	doc_485839256085_item	2429074	et	4	main
kasutati	doc_485839256085_item	2429077	et	4	main
ka	doc_485839256085_item	2429078	et	3	main
haigeks	doc_485839256085_item	2429084	et	4	main
loomi	doc_485839256085_item	2429105	et	4	main
lasti	doc_485839256085_item	2429107	et	4	main
millal	doc_485839256085_item	2429110	et	3	main
kurke	doc_485839256085_item	2429111	et	3	main
peale	doc_485839256085_item	2429128	et	4	main
päikese	doc_485839256085_item	2429129	et	4	main
loojangut	doc_485839256085_item	2429130	et	3	main
pesed	doc_485839256085_item	2429131	et	3	main
anumates	doc_485839256085_item	2429139	et	3	main
risti	doc_485839256085_item	2429148	et	4	main
sellele	doc_485839256085_item	2429149	et	4	main
halvad	doc_485839256085_item	2429155	et	4	main
oma	doc_485839256085_item	2429176	et	4	main
kuhu	doc_485839256085_item	2429179	et	3	main
kristus-lapsuke	doc_485839256085_item	2429181	et	4	main
tapmise	doc_485839256085_item	2429187	et	4	main
kehastuseks	doc_485839256085_item	2429194	et	4	main
sai	doc_485839256085_item	2429195	et	4	main
eest	doc_485839256085_item	2429211	et	4	main
eriti	doc_485839256085_item	2429225	et	3	main
on	doc_485839256085_item	2429227	et	4	main
joodikutest	doc_485839256085_item	2429229	et	3	main
kultuuris	doc_485839256085_item	2429244	et	3	main
on	doc_485839256085_item	2429245	et	4	main
mõisted	doc_485839256085_item	2429247	et	3	main
ja	doc_485839256085_item	2429249	et	3	main
põimunud	doc_485839256085_item	2429251	et	4	main
tihti	doc_485839256085_item	2429256	et	3	main
valemit	doc_485839256085_item	2429259	et	3	main
on	doc_485839256085_item	2429261	et	4	main
on	doc_485839256085_item	2429293	et	4	main
magama	doc_485839256085_item	2429294	et	3	main
välja	doc_485839256085_item	2429302	et	4	main
korda	doc_485839256085_item	2429306	et	4	main
metsa	doc_485839256085_item	2429308	et	4	main
täiendati	doc_485839256085_item	2429311	et	4	main
lindude	doc_485839256085_item	2429317	et	4	main
poole	doc_485839256085_item	2429318	et	4	main
teie	doc_485839256085_item	2429331	et	4	main
ilusad	doc_485839256085_item	2429346	et	3	main
seotud	doc_485839256085_item	2429362	et	4	main
religioossetes	doc_485839256085_item	2428888	et	3	main
peredes	doc_485839256085_item	2428889	et	3	main
lugemisega	doc_485839256085_item	2428894	et	4	main
alustatakse	doc_485839256085_item	2428898	et	3	main
soosse	doc_485839256085_item	2428904	et	4	main
kolmekuningapäeva	doc_485839256085_item	2428905	et	4	main
pühakojas	doc_485839256085_item	2428910	et	3	main
õnnistanud	doc_485839256085_item	2428921	et	4	main
jordanitek	doc_485839256085_item	2428925	et	4	main
nõusi	doc_485839256085_item	2428930	et	4	main
vanema	doc_485839256085_item	2428933	et	4	main
inimesed	doc_485839256085_item	2428935	et	3	main
kiriku	doc_485839256085_item	2428937	et	3	main
järgivad	doc_485839256085_item	2428940	et	4	main
vanausulistel-fedosejevlastel	doc_485839256085_item	2428947	et	4	main
siin	doc_485839256085_item	2428948	et	4	main
tähendab	doc_485839256085_item	2428953	et	3	main
jumala	doc_485839256085_item	2428956	et	3	main
ainult	doc_485839256085_item	2428968	et	4	main
ta	doc_485839256085_item	2428972	et	4	main
neid	doc_485839256085_item	2428986	et	4	main
ei	doc_485839256085_item	2428987	et	4	main
kasutaks	doc_485839256085_item	2428988	et	4	main
juurde	doc_485839256085_item	2428991	et	4	main
oma	doc_485839256085_item	2428999	et	4	main
imetegijale	doc_485839256085_item	2429029	et	3	main
oli	doc_485839256085_item	2429036	et	3	main
eelmise	doc_485839256085_item	2429037	et	3	main
algusel	doc_485839256085_item	2429039	et	4	main
ulutöödelt	doc_485839256085_item	2429042	et	3	main
tuua	doc_485839256085_item	2429044	et	3	main
isegi	doc_485839256085_item	2429051	et	4	main
olid	doc_485839256085_item	2429055	et	4	main
ajaliselt	doc_485839256085_item	2429056	et	4	main
tulekahjust	doc_485839256085_item	2429075	et	4	main
ja	doc_485839256085_item	2429088	et	3	main
esimest	doc_485839256085_item	2429103	et	4	main
oli	doc_485839256085_item	2429114	et	3	main
kirikupühadega	doc_485839256085_item	2429117	et	3	main
keelatud	doc_485839256085_item	2429118	et	4	main
suitsutakse	doc_485839256085_item	2428931	et	4	main
mis	doc_485839256085_item	2428943	et	4	main
rabskije	doc_485839256085_item	2428951	et	4	main
sõnapaarist	doc_485839256085_item	2428955	et	4	main
sulased	doc_485839256085_item	2428957	et	3	main
naisterahvas	doc_485839256085_item	2428960	et	4	main
et	doc_485839256085_item	2428962	et	3	main
selle	doc_485839256085_item	2428969	et	4	main
peopesast	doc_485839256085_item	2428997	et	4	main
ka	doc_485839256085_item	2428998	et	3	main
religioosse	doc_485839256085_item	2429006	et	3	main
maailmatunnetusega	doc_485839256085_item	2429007	et	3	main
on	doc_485839256085_item	2429008	et	4	main
läbipõimutud	doc_485839256085_item	2429009	et	4	main
paljud	doc_485839256085_item	2429010	et	3	main
vanausuliste	doc_485839256085_item	2429011	et	4	main
rahvatavandid	doc_485839256085_item	2429012	et	3	main
uskumused	doc_485839256085_item	2429013	et	3	main
ja	doc_485839256085_item	2429014	et	3	main
ümbritseva	doc_485839256085_item	2429015	et	4	main
maailma	doc_485839256085_item	2429016	et	4	main
maagilise	doc_485839256085_item	2429017	et	4	main
mõjutamise	doc_485839256085_item	2429018	et	4	main
viisid	doc_485839256085_item	2429019	et	4	main
kalurid	doc_485839256085_item	2429020	et	3	main
mantlis	doc_485839256085_item	2428977	et	3	main
vanausulised	doc_485839256085_item	2428979	et	4	main
vett	doc_485839256085_item	2428995	et	3	main
oma	doc_485839256085_item	2428996	et	4	main
paatide	doc_485839256085_item	2429024	et	3	main
eelistati	doc_485839256085_item	2429026	et	4	main
mikola-meeleheadtegija	doc_485839256085_item	2429030	et	4	main
oli	doc_485839256085_item	2429032	et	3	main
sajandi	doc_485839256085_item	2429038	et	3	main
traditsioon	doc_485839256085_item	2429040	et	3	main
laadogalt	doc_485839256085_item	2429043	et	4	main
igaastased	doc_485839256085_item	2429052	et	4	main
tuletõrjeühingu	doc_485839256085_item	2429053	et	3	main
jumalaema	doc_485839256085_item	2429060	et	4	main
ei	doc_485839256085_item	2429085	et	4	main
aiatöödega	doc_485839256085_item	2429089	et	3	main
tavad	doc_485839256085_item	2429091	et	3	main
uskumused	doc_485839256085_item	2429093	et	3	main
samuti	doc_485839256085_item	2429095	et	3	main
ilmaennustus	doc_485839256085_item	2429113	et	3	main
seotud	doc_485839256085_item	2429116	et	4	main
õhtuti	doc_485839256085_item	2429140	et	3	main
supleks	doc_485839256085_item	2429157	et	3	main
tohi	doc_485839256085_item	2429160	et	4	main
võrguga	doc_485839256085_item	2429177	et	3	main
ussi	doc_485839256085_item	2429186	et	4	main
hulk	doc_485839256085_item	2429197	et	3	main
antud	doc_485839256085_item	2429200	et	4	main
käitumisreeglid	doc_485839256085_item	2429202	et	3	main
tihtipeale	doc_485839256085_item	2429203	et	3	main
kinnitatakse	doc_485839256085_item	2429204	et	3	main
lugude	doc_485839256085_item	2429205	et	3	main
vargus	doc_485839256085_item	2429217	et	3	main
ehitamisele	doc_485839256085_item	2429220	et	4	main
omistamine	doc_485839256085_item	2429223	et	4	main
lääneranniku	doc_485839256085_item	2429242	et	3	main
paganlikega	doc_485839256085_item	2429252	et	3	main
palvete	doc_485839256085_item	2429258	et	3	main
palvete	doc_485839256085_item	2429264	et	3	main
välja	doc_485839256085_item	2429266	et	4	main
on	doc_485839256085_item	2429269	et	4	main
see	doc_485839256085_item	2429270	et	3	main
läinud	doc_485839256085_item	2429295	et	4	main
ka	doc_485839256085_item	2429296	et	3	main
aitab	doc_485839256085_item	2429297	et	3	main
kui	doc_485839256085_item	2429304	et	3	main
aastas	doc_485839256085_item	2429307	et	3	main
mindi	doc_485839256085_item	2429309	et	3	main
ikoone	doc_485839256085_item	2429022	et	3	main
ninaossa	doc_485839256085_item	2429025	et	3	main
kallastes	doc_485839256085_item	2429035	et	4	main
vanausuliste	doc_485839256085_item	2429046	et	4	main
kinkida	doc_485839256085_item	2429049	et	3	main
seotud	doc_485839256085_item	2429057	et	4	main
kodukiriku	doc_485839256085_item	2429058	et	3	main
pühaga	doc_485839256085_item	2429059	et	3	main
uinumise	doc_485839256085_item	2429061	et	4	main
pühaga	doc_485839256085_item	2429062	et	3	main
pidustused	doc_485839256085_item	2429063	et	3	main
lõpetati	doc_485839256085_item	2429064	et	3	main
palvelas	doc_485839256085_item	2429065	et	3	main
jumalateenistusega	doc_485839256085_item	2429066	et	3	main
tulekahjude	doc_485839256085_item	2429067	et	4	main
vastu	doc_485839256085_item	2429068	et	3	main
usuti	doc_485839256085_item	2429069	et	3	main
et	doc_485839256085_item	2429070	et	3	main
pühakojas	doc_485839256085_item	2429071	et	3	main
pühetsetud	doc_485839256085_item	2429072	et	4	main
pajuoksi	doc_485839256085_item	2429076	et	4	main
ja	doc_485839256085_item	2429048	et	3	main
pühakojale	doc_485839256085_item	2429050	et	3	main
festivalid	doc_485839256085_item	2429054	et	3	main
pajuoksad	doc_485839256085_item	2429073	et	3	main
karjamaale	doc_485839256085_item	2429080	et	4	main
saates	doc_485839256085_item	2429081	et	4	main
et	doc_485839256085_item	2429082	et	3	main
lehmakesed	doc_485839256085_item	2429083	et	4	main
jääks	doc_485839256085_item	2429086	et	4	main
seotud	doc_485839256085_item	2429090	et	4	main
olid	doc_485839256085_item	2429094	et	4	main
korda	doc_485839256085_item	2429104	et	4	main
samuti	doc_485839256085_item	2429115	et	3	main
ja	doc_485839256085_item	2429122	et	3	main
vesi	doc_485839256085_item	2429138	et	4	main
peavad	doc_485839256085_item	2429141	et	4	main
kaetud	doc_485839256085_item	2429143	et	4	main
olema	doc_485839256085_item	2429144	et	4	main
peale	doc_485839256085_item	2429150	et	4	main
maija	doc_485839256085_item	2429158	et	4	main
koera	doc_485839256085_item	2429161	et	4	main
ämblik	doc_485839256085_item	2429174	et	3	main
kurjuse	doc_485839256085_item	2429193	et	4	main
patte	doc_485839256085_item	2429198	et	3	main
lahtiütlemine	doc_485839256085_item	2429212	et	3	main
oma	doc_485839256085_item	2429213	et	4	main
usust	doc_485839256085_item	2429214	et	3	main
ikoonide	doc_485839256085_item	2429215	et	3	main
müük	doc_485839256085_item	2429216	et	3	main
kiriku	doc_485839256085_item	2429219	et	3	main
loomi	doc_485839256085_item	2429079	et	4	main
põllu-	doc_485839256085_item	2429087	et	3	main
ja	doc_485839256085_item	2429092	et	3	main
seotud	doc_485839256085_item	2429096	et	4	main
kirikupühadega	doc_485839256085_item	2429097	et	3	main
kas	doc_485839256085_item	2429098	et	3	main
oli	doc_485839256085_item	2429099	et	3	main
see	doc_485839256085_item	2429100	et	3	main
päev	doc_485839256085_item	2429101	et	3	main
millal	doc_485839256085_item	2429102	et	3	main
karjamaale	doc_485839256085_item	2429106	et	4	main
või	doc_485839256085_item	2429108	et	4	main
päev	doc_485839256085_item	2429109	et	3	main
istutati	doc_485839256085_item	2429112	et	3	main
on	doc_485839256085_item	2429119	et	4	main
pühade	doc_485839256085_item	2429120	et	3	main
ajal	doc_485839256085_item	2429121	et	4	main
pühapäeviti	doc_485839256085_item	2429123	et	4	main
ennast	doc_485839256085_item	2429132	et	4	main
kristuse	doc_485839256085_item	2429133	et	3	main
verega	doc_485839256085_item	2429134	et	3	main
kõik	doc_485839256085_item	2429135	et	4	main
toidud	doc_485839256085_item	2429136	et	3	main
peab	doc_485839256085_item	2429147	et	4	main
öösel	doc_485839256085_item	2429153	et	4	main
neis	doc_485839256085_item	2429154	et	4	main
et	doc_485839256085_item	2429159	et	3	main
kuna	doc_485839256085_item	2429173	et	3	main
koopa	doc_485839256085_item	2429178	et	3	main
oli	doc_485839256085_item	2429180	et	3	main
eest	doc_485839256085_item	2429188	et	4	main
keda	doc_485839256085_item	2429189	et	4	main
ida-slaavlased	doc_485839256085_item	2429190	et	3	main
traditsioonileselt	doc_485839256085_item	2429191	et	3	main
andeks	doc_485839256085_item	2429199	et	3	main
traditsioonilised	doc_485839256085_item	2429201	et	4	main
palvelas	doc_485839256085_item	2429218	et	3	main
raha	doc_485839256085_item	2429222	et	4	main
vanakurja	doc_485839256085_item	2429233	et	4	main
kätte	doc_485839256085_item	2429234	et	4	main
ja	doc_485839256085_item	2429235	et	3	main
vahel	doc_485839256085_item	2429236	et	4	main
seavad	doc_485839256085_item	2429237	et	3	main
end	doc_485839256085_item	2429238	et	4	main
eluohtlikke	doc_485839256085_item	2429239	et	3	main
olukordadesse	doc_485839256085_item	2429240	et	3	main
kohalikes	doc_485839256085_item	2429254	et	3	main
nad	doc_485839256085_item	2429262	et	3	main
luulelise	doc_485839256085_item	2429312	et	4	main
pöördumisega	doc_485839256085_item	2429313	et	4	main
metsaga	doc_485839256085_item	2429319	et	3	main
on	doc_485839256085_item	2429320	et	4	main
olgu	doc_485839256085_item	2429330	et	3	main
id	doc_485839256085_item	2429340	et	4	main
leivad	doc_485839256085_item	2429342	et	3	main
siledad	doc_485839256085_item	2429344	et	3	main
on	doc_485839256085_item	2429348	et	4	main
levinud	doc_485839256085_item	2429349	et	4	main
uskumus	doc_485839256085_item	2429350	et	3	main
võpatab	doc_485839256085_item	2429358	et	3	main
haigusi	doc_485839256085_item	2429369	et	4	main
jm	doc_485839256085_item	2429370	et	4	main
oma	doc_485839256085_item	2429374	et	4	main
tegusõna	doc_485839256085_item	2429383	et	4	main
surra	doc_485839256085_item	2429384	et	3	main
kohalikud	doc_485839256085_item	2429385	et	3	main
inimesed	doc_485839256085_item	2429386	et	3	main
eeslistavad	doc_485839256085_item	2429387	et	4	main
kuradit	doc_485839256085_item	2429391	et	3	main
nimetatakse	doc_485839256085_item	2429394	et	3	main
tema	doc_485839256085_item	2429396	et	4	main
too	doc_485839256085_item	2429397	et	4	main
vaenlane	doc_485839256085_item	2429398	et	3	main
ergsamalt	doc_485839256085_item	2429405	et	4	main
väljendub	doc_485839256085_item	2429406	et	3	main
rahva	doc_485839256085_item	2429407	et	3	main
vastastikune	doc_485839256085_item	2429411	et	4	main
ääretult	doc_485839256085_item	2429414	et	4	main
ja	doc_485839256085_item	2429421	et	3	main
tulevane	doc_485839256085_item	2429431	et	3	main
vältima	doc_485839256085_item	2429434	et	3	main
tööd	doc_485839256085_item	2429124	et	4	main
teha	doc_485839256085_item	2429125	et	3	main
käia	doc_485839256085_item	2429126	et	4	main
saunas	doc_485839256085_item	2429127	et	3	main
ja	doc_485839256085_item	2429137	et	3	main
kindlasti	doc_485839256085_item	2429142	et	3	main
või	doc_485839256085_item	2429145	et	4	main
siis	doc_485839256085_item	2429146	et	3	main
lööma	doc_485839256085_item	2429151	et	4	main
et	doc_485839256085_item	2429152	et	3	main
ei	doc_485839256085_item	2429156	et	4	main
lasta	doc_485839256085_item	2429162	et	4	main
sest	doc_485839256085_item	2429163	et	4	main
evangeeliumi	doc_485839256085_item	2429164	et	4	main
aegadel	doc_485839256085_item	2429165	et	3	main
sõbrunes	doc_485839256085_item	2429166	et	3	main
koer	doc_485839256085_item	2429167	et	3	main
kuradiga	doc_485839256085_item	2429168	et	3	main
patt	doc_485839256085_item	2429169	et	3	main
on	doc_485839256085_item	2429170	et	4	main
ämblikut	doc_485839256085_item	2429171	et	4	main
tappa	doc_485839256085_item	2429172	et	4	main
maskeeris	doc_485839256085_item	2429175	et	3	main
peidetud	doc_485839256085_item	2429182	et	4	main
tagajalitajate	doc_485839256085_item	2429183	et	4	main
eest	doc_485839256085_item	2429184	et	4	main
aga	doc_485839256085_item	2429185	et	3	main
pidasid	doc_485839256085_item	2429192	et	4	main
teatud	doc_485839256085_item	2429196	et	4	main
abil	doc_485839256085_item	2429206	et	4	main
jumala	doc_485839256085_item	2429207	et	3	main
karistusest	doc_485839256085_item	2429208	et	4	main
halbade	doc_485839256085_item	2429209	et	3	main
tegude	doc_485839256085_item	2429210	et	3	main
mõeldud	doc_485839256085_item	2429221	et	4	main
populaarsed	doc_485839256085_item	2429226	et	3	main
peipsi	doc_485839256085_item	2429241	et	4	main
atribuudid	doc_485839256085_item	2429248	et	3	main
variantides	doc_485839256085_item	2429255	et	3	main
kasutatakse	doc_485839256085_item	2429257	et	3	main
üldse	doc_485839256085_item	2429263	et	3	main
vastu	doc_485839256085_item	2429265	et	3	main
arvatavasti	doc_485839256085_item	2429268	et	3	main
seotud	doc_485839256085_item	2429271	et	4	main
majast	doc_485839256085_item	2429301	et	4	main
ajada	doc_485839256085_item	2429303	et	3	main
palvet	doc_485839256085_item	2429310	et	3	main
vaja	doc_485839256085_item	2429321	et	4	main
isegi	doc_485839256085_item	2429323	et	4	main
paluti	doc_485839256085_item	2429334	et	3	main
teha	doc_485839256085_item	2429335	et	3	main
kulitš	doc_485839256085_item	2429339	et	2	main
ja	doc_485839256085_item	2429341	et	3	main
oleks	doc_485839256085_item	2429343	et	3	main
ja	doc_485839256085_item	2429345	et	3	main
tänapäeval	doc_485839256085_item	2429347	et	3	main
kui	doc_485839256085_item	2429351	et	3	main
koheselt	doc_485839256085_item	2429371	et	4	main
2006	doc_485839256085_item	2429376	et	2	main
peagi	doc_485839256085_item	2429379	et	4	main
ütelda	doc_485839256085_item	2429388	et	4	main
perekonnatavades	doc_485839256085_item	2429413	et	3	main
jm	doc_485839256085_item	2429224	et	4	main
jutustused	doc_485839256085_item	2429228	et	4	main
kes	doc_485839256085_item	2429230	et	4	main
purjuspäi	doc_485839256085_item	2429231	et	3	main
sattuvad	doc_485839256085_item	2429232	et	4	main
vanausuliste	doc_485839256085_item	2429243	et	4	main
kristlikud	doc_485839256085_item	2429246	et	3	main
kujundid	doc_485839256085_item	2429250	et	3	main
rahvalausumiste	doc_485839256085_item	2429253	et	3	main
vahel	doc_485839256085_item	2429260	et	4	main
vahetatud	doc_485839256085_item	2429267	et	4	main
maagiliste	doc_485839256085_item	2429272	et	4	main
lausumiste	doc_485839256085_item	2429273	et	4	main
kirjaliku	doc_485839256085_item	2429274	et	3	main
leviga	doc_485839256085_item	2429275	et	3	main
majavaim	doc_485839256085_item	2429276	et	3	main
mitte	doc_485839256085_item	2429277	et	3	main
ainult	doc_485839256085_item	2429278	et	4	main
hoiatab	doc_485839256085_item	2429279	et	3	main
oma	doc_485839256085_item	2429280	et	4	main
hoolealuseid	doc_485839256085_item	2429281	et	4	main
mõne	doc_485839256085_item	2429282	et	3	main
sugulase	doc_485839256085_item	2429283	et	3	main
vastsest	doc_485839256085_item	2429284	et	4	main
surmast	doc_485839256085_item	2429285	et	4	main
ta	doc_485839256085_item	2429286	et	4	main
isegi	doc_485839256085_item	2429287	et	4	main
äratab	doc_485839256085_item	2429288	et	3	main
unest	doc_485839256085_item	2429289	et	3	main
neid	doc_485839256085_item	2429290	et	4	main
kes	doc_485839256085_item	2429291	et	4	main
palveta	doc_485839256085_item	2429292	et	4	main
ta	doc_485839256085_item	2429298	et	4	main
nõial	doc_485839256085_item	2429299	et	3	main
tondid	doc_485839256085_item	2429300	et	3	main
esimest	doc_485839256085_item	2429305	et	4	main
puude	doc_485839256085_item	2429314	et	4	main
metsloomade	doc_485839256085_item	2429315	et	4	main
ja	doc_485839256085_item	2429316	et	3	main
rahu	doc_485839256085_item	2429329	et	4	main
emakest-ahju	doc_485839256085_item	2429333	et	4	main
et	doc_485839256085_item	2429337	et	3	main
roppude	doc_485839256085_item	2429353	et	4	main
arhailiste	doc_485839256085_item	2429359	et	3	main
arusaamadega	doc_485839256085_item	2429360	et	3	main
on	doc_485839256085_item	2429361	et	4	main
nad	doc_485839256085_item	2429373	et	3	main
aasta	doc_485839256085_item	2429377	et	4	main
üldse	doc_485839256085_item	2429380	et	3	main
inimene	doc_485839256085_item	2429389	et	3	main
kaval	doc_485839256085_item	2429400	et	4	main
kultuuri	doc_485839256085_item	2429409	et	4	main
toime	doc_485839256085_item	2429412	et	4	main
rikas	doc_485839256085_item	2429415	et	4	main
on	doc_485839256085_item	2429416	et	4	main
naise	doc_485839256085_item	2429417	et	3	main
rasedusajaga	doc_485839256085_item	2429418	et	3	main
tulevase	doc_485839256085_item	2429424	et	4	main
ei	doc_485839256085_item	2429426	et	4	main
ütelda	doc_485839256085_item	2429430	et	4	main
peab	doc_485839256085_item	2429433	et	4	main
lapsele	doc_485839256085_item	2429449	et	4	main
terve	doc_485839256085_item	2429460	et	4	main
kanda	doc_485839256085_item	2429475	et	4	main
võlumuinasjuttudest	doc_485839256085_item	2429480	et	3	main
ja	doc_485839256085_item	2429484	et	3	main
säilinud	doc_485839256085_item	2429490	et	4	main
talituses	doc_485839256085_item	2429493	et	4	main
ristimise	doc_485839256085_item	2429497	et	4	main
kolmekordselt	doc_485839256085_item	2429499	et	4	main
muutub	doc_485839256085_item	2429508	et	3	main
ajal	doc_485839256085_item	2429512	et	4	main
vanemad	doc_485839256085_item	2429513	et	4	main
vestelda	doc_485839256085_item	2429322	et	4	main
ussidele	doc_485839256085_item	2429324	et	3	main
ja	doc_485839256085_item	2429325	et	3	main
puukidele	doc_485839256085_item	2429326	et	3	main
sooviti	doc_485839256085_item	2429327	et	3	main
heaolu	doc_485839256085_item	2429328	et	4	main
kodule	doc_485839256085_item	2429332	et	3	main
nii	doc_485839256085_item	2429336	et	3	main
lihavõttesaiad	doc_485839256085_item	2429338	et	3	main
keegi	doc_485839256085_item	2429352	et	4	main
sõnadega	doc_485839256085_item	2429354	et	3	main
sõimab	doc_485839256085_item	2429355	et	3	main
isegi	doc_485839256085_item	2429356	et	4	main
järv	doc_485839256085_item	2429357	et	3	main
varjatud	doc_485839256085_item	2429363	et	4	main
keeld	doc_485839256085_item	2429364	et	3	main
valjusti	doc_485839256085_item	2429365	et	3	main
nimetada	doc_485839256085_item	2429366	et	3	main
ohtlikke	doc_485839256085_item	2429367	et	3	main
olendeid	doc_485839256085_item	2429368	et	3	main
vastavad	doc_485839256085_item	2429372	et	4	main
nimele	doc_485839256085_item	2429375	et	3	main
kirjapanekutes	doc_485839256085_item	2429378	et	3	main
ei	doc_485839256085_item	2429381	et	4	main
leidu	doc_485839256085_item	2429382	et	4	main
või	doc_485839256085_item	2429392	et	4	main
vihjamisi	doc_485839256085_item	2429395	et	4	main
must	doc_485839256085_item	2429401	et	4	main
ketser	doc_485839256085_item	2429402	et	3	main
halb	doc_485839256085_item	2429403	et	3	main
kõige	doc_485839256085_item	2429404	et	4	main
kihtide	doc_485839256085_item	2429410	et	3	main
seotud	doc_485839256085_item	2429419	et	4	main
uskumuste	doc_485839256085_item	2429420	et	4	main
tsükkel	doc_485839256085_item	2429423	et	3	main
emale	doc_485839256085_item	2429425	et	3	main
tohi	doc_485839256085_item	2429427	et	4	main
milleski	doc_485839256085_item	2429428	et	4	main
ehmatuses	doc_485839256085_item	2429439	et	4	main
kätega	doc_485839256085_item	2429440	et	3	main
järgida	doc_485839256085_item	2429448	et	3	main
on	doc_485839256085_item	2429453	et	4	main
elu	doc_485839256085_item	2429461	et	4	main
väärteo	doc_485839256085_item	2429478	et	4	main
arusaam	doc_485839256085_item	2429482	et	3	main
surnud	doc_485839256085_item	2429485	et	4	main
on	doc_485839256085_item	2429487	et	4	main
rudimentses	doc_485839256085_item	2429488	et	4	main
lapse	doc_485839256085_item	2429491	et	4	main
kuhu	doc_485839256085_item	2429495	et	3	main
õnnistavad	doc_485839256085_item	2429514	et	4	main
rituaalsed	doc_485839256085_item	2429521	et	3	main
on	doc_485839256085_item	2429523	et	4	main
iseloomuga	doc_485839256085_item	2429525	et	3	main
baseeruvad	doc_485839256085_item	2429527	et	4	main
usul	doc_485839256085_item	2429528	et	3	main
esimese	doc_485839256085_item	2429529	et	3	main
päeva	doc_485839256085_item	2429530	et	4	main
olnud	doc_485839256085_item	2429534	et	4	main
seas	doc_485839256085_item	2429547	et	4	main
süles	doc_485839256085_item	2429554	et	3	main
püsivamaks	doc_485839256085_item	2429579	et	4	main
aegsasti	doc_485839256085_item	2429593	et	3	main
valmis	doc_485839256085_item	2429597	et	4	main
terve	doc_485839256085_item	2429598	et	4	main
lahkus	doc_485839256085_item	2429390	et	4	main
paganat	doc_485839256085_item	2429393	et	3	main
vanakuri	doc_485839256085_item	2429399	et	4	main
vaimse	doc_485839256085_item	2429408	et	3	main
keelude	doc_485839256085_item	2429422	et	3	main
ema	doc_485839256085_item	2429432	et	4	main
stressisituatsioone	doc_485839256085_item	2429435	et	3	main
puudutada	doc_485839256085_item	2429442	et	3	main
jm	doc_485839256085_item	2429443	et	4	main
valdavas	doc_485839256085_item	2429444	et	4	main
nimepanemise	doc_485839256085_item	2429450	et	3	main
hoolealust	doc_485839256085_item	2429459	et	4	main
eest	doc_485839256085_item	2429479	et	4	main
veest	doc_485839256085_item	2429486	et	4	main
ristimise	doc_485839256085_item	2429492	et	4	main
vett	doc_485839256085_item	2429494	et	3	main
kastetakse	doc_485839256085_item	2429502	et	4	main
et	doc_485839256085_item	2429503	et	3	main
tohi	doc_485839256085_item	2429504	et	4	main
soendada	doc_485839256085_item	2429505	et	3	main
muidu	doc_485839256085_item	2429506	et	3	main
see	doc_485839256085_item	2429507	et	3	main
noorpaari	doc_485839256085_item	2429515	et	4	main
mõned	doc_485839256085_item	2429526	et	3	main
vanaaastaõhtul	doc_485839256085_item	2429537	et	3	main
ära	doc_485839256085_item	2429538	et	4	main
et	doc_485839256085_item	2429540	et	3	main
kirikusse	doc_485839256085_item	2429541	et	4	main
jumalateenistusele	doc_485839256085_item	2429542	et	3	main
väikelast	doc_485839256085_item	2429555	et	4	main
pea	doc_485839256085_item	2429557	et	4	main
ta	doc_485839256085_item	2429558	et	4	main
kartma	doc_485839256085_item	2429559	et	3	main
kuradite	doc_485839256085_item	2429560	et	3	main
matuse	doc_485839256085_item	2429581	et	3	main
suririided	doc_485839256085_item	2429595	et	3	main
surija	doc_485839256085_item	2429600	et	4	main
näoga	doc_485839256085_item	2429603	et	3	main
poole	doc_485839256085_item	2429605	et	4	main
lastakse	doc_485839256085_item	2429607	et	3	main
vanema	doc_485839256085_item	2429610	et	4	main
põlvkonna	doc_485839256085_item	2429611	et	4	main
inimesed	doc_485839256085_item	2429612	et	3	main
olid	doc_485839256085_item	2429618	et	4	main
teises	doc_485839256085_item	2429621	et	4	main
ka	doc_485839256085_item	2429631	et	3	main
kirst	doc_485839256085_item	2429632	et	3	main
viljateraga	doc_485839256085_item	2429635	et	3	main
päeva	doc_485839256085_item	2429641	et	4	main
kõik	doc_485839256085_item	2429648	et	4	main
talitused	doc_485839256085_item	2429649	et	4	main
oleks	doc_485839256085_item	2429650	et	3	main
väikenegi	doc_485839256085_item	2429657	et	4	main
viib	doc_485839256085_item	2429659	et	3	main
selleni	doc_485839256085_item	2429660	et	3	main
et	doc_485839256085_item	2429661	et	3	main
tülitama	doc_485839256085_item	2429664	et	3	main
oma	doc_485839256085_item	2429669	et	4	main
ligidasi	doc_485839256085_item	2429670	et	3	main
viimased	doc_485839256085_item	2429679	et	3	main
kui	doc_485839256085_item	2429683	et	3	main
endaga	doc_485839256085_item	2429701	et	4	main
võtta	doc_485839256085_item	2429703	et	3	main
ei	doc_485839256085_item	2429707	et	4	main
tohi	doc_485839256085_item	2429708	et	4	main
ср	doc_485839256085_item	2429714	et	2	main
ei	doc_485839256085_item	2429717	et	4	main
soovitatav	doc_485839256085_item	2429719	et	4	main
kuna	doc_485839256085_item	2429724	et	3	main
pisarad	doc_485839256085_item	2429725	et	3	main
kombetalitused	doc_485839256085_item	2429736	et	4	main
ja	doc_485839256085_item	2429737	et	3	main
tavandid	doc_485839256085_item	2429738	et	3	main
on	doc_485839256085_item	2429746	et	4	main
venemaal	doc_485839256085_item	2429749	et	4	main
mõned	doc_485839256085_item	2429752	et	3	main
tehtud	doc_485839256085_item	2429761	et	4	main
elanikud	doc_485839256085_item	2429768	et	3	main
teavad	doc_485839256085_item	2429769	et	3	main
sõna	doc_485839256085_item	2429771	et	4	main
elavate	doc_485839256085_item	2429795	et	4	main
ära	doc_485839256085_item	2429429	et	4	main
ei	doc_485839256085_item	2429436	et	4	main
tohi	doc_485839256085_item	2429437	et	4	main
ta	doc_485839256085_item	2429438	et	4	main
osas	doc_485839256085_item	2429445	et	4	main
peredest	doc_485839256085_item	2429446	et	3	main
püütakse	doc_485839256085_item	2429447	et	3	main
et	doc_485839256085_item	2429455	et	3	main
kaitsja-ingel	doc_485839256085_item	2429456	et	3	main
kaitseb	doc_485839256085_item	2429457	et	4	main
oma	doc_485839256085_item	2429458	et	4	main
vältel	doc_485839256085_item	2429462	et	4	main
paneb	doc_485839256085_item	2429463	et	3	main
alla	doc_485839256085_item	2429464	et	3	main
oma	doc_485839256085_item	2429465	et	4	main
tiivad	doc_485839256085_item	2429466	et	3	main
kui	doc_485839256085_item	2429467	et	3	main
to	doc_485839256085_item	2429468	et	4	main
kukuma	doc_485839256085_item	2429469	et	4	main
hakkab	doc_485839256085_item	2429470	et	3	main
vahel	doc_485839256085_item	2429471	et	4	main
võtab	doc_485839256085_item	2429472	et	3	main
ka	doc_485839256085_item	2429473	et	3	main
nägu	doc_485839256085_item	2429441	et	4	main
seadusi	doc_485839256085_item	2429451	et	3	main
kuna	doc_485839256085_item	2429452	et	3	main
veendutud	doc_485839256085_item	2429454	et	4	main
pärinev	doc_485839256085_item	2429481	et	4	main
täielikult	doc_485839256085_item	2429500	et	4	main
surnuks	doc_485839256085_item	2429509	et	4	main
veeks	doc_485839256085_item	2429510	et	3	main
ikooniga	doc_485839256085_item	2429516	et	4	main
toimingud	doc_485839256085_item	2429522	et	3	main
kaitsva	doc_485839256085_item	2429524	et	4	main
tülis	doc_485839256085_item	2429533	et	4	main
vanausuliste	doc_485839256085_item	2429546	et	4	main
hoiab	doc_485839256085_item	2429553	et	3	main
ei	doc_485839256085_item	2429556	et	4	main
surnute	doc_485839256085_item	2429583	et	4	main
kombetalitused	doc_485839256085_item	2429585	et	4	main
ja	doc_485839256085_item	2429586	et	3	main
tavandid	doc_485839256085_item	2429587	et	3	main
ka	doc_485839256085_item	2429588	et	3	main
sellega	doc_485839256085_item	2429589	et	3	main
seotud	doc_485839256085_item	2429590	et	4	main
põrandale	doc_485839256085_item	2429602	et	3	main
mäletavad	doc_485839256085_item	2429613	et	4	main
rääkida	doc_485839256085_item	2429614	et	3	main
et	doc_485839256085_item	2429615	et	3	main
vanasti	doc_485839256085_item	2429616	et	3	main
puust	doc_485839256085_item	2429620	et	4	main
igaühel	doc_485839256085_item	2429624	et	3	main
risti	doc_485839256085_item	2429626	et	4	main
nähtamatult	doc_485839256085_item	2429642	et	4	main
hoolikalt	doc_485839256085_item	2429646	et	4	main
lahkunu	doc_485839256085_item	2429662	et	4	main
hakkab	doc_485839256085_item	2429663	et	3	main
kas	doc_485839256085_item	2429665	et	3	main
või	doc_485839256085_item	2429667	et	4	main
on	doc_485839256085_item	2429675	et	4	main
vaja	doc_485839256085_item	2429676	et	4	main
isegi	doc_485839256085_item	2429681	et	4	main
siis	doc_485839256085_item	2429682	et	3	main
viina	doc_485839256085_item	2429692	et	4	main
sigaretid	doc_485839256085_item	2429693	et	3	main
jm	doc_485839256085_item	2429694	et	4	main
popuraarsed	doc_485839256085_item	2429695	et	4	main
püüavad	doc_485839256085_item	2429700	et	3	main
заветы	doc_485839256085_item	2429715	et	2	main
kaua	doc_485839256085_item	2429722	et	3	main
valavad	doc_485839256085_item	2429726	et	4	main
need	doc_485839256085_item	2429745	et	3	main
tavandid	doc_485839256085_item	2429756	et	3	main
on	doc_485839256085_item	2429760	et	4	main
kogukondades	doc_485839256085_item	2429766	et	3	main
hästi	doc_485839256085_item	2429770	et	3	main
kaitsevad	doc_485839256085_item	2429799	et	4	main
neid	doc_485839256085_item	2429800	et	4	main
nende	doc_485839256085_item	2429805	et	4	main
surnut	doc_485839256085_item	2429817	et	4	main
pesti	doc_485839256085_item	2429818	et	3	main
keldrisse	doc_485839256085_item	2429820	et	3	main
ette	doc_485839256085_item	2429830	et	4	main
valmistati	doc_485839256085_item	2429831	et	4	main
seebiga	doc_485839256085_item	2429844	et	3	main
hammustusest	doc_485839256085_item	2429854	et	4	main
võib	doc_485839256085_item	2429855	et	3	main
ruttu	doc_485839256085_item	2429858	et	4	main
või	doc_485839256085_item	2429861	et	4	main
mulla	doc_485839256085_item	2429863	et	4	main
sisse	doc_485839256085_item	2429864	et	4	main
enesetapjaid	doc_485839256085_item	2429865	et	3	main
üldreeglina	doc_485839256085_item	2429866	et	3	main
maetakse	doc_485839256085_item	2429867	et	3	main
risti	doc_485839256085_item	2429892	et	4	main
käia	doc_485839256085_item	2429895	et	4	main
peab	doc_485839256085_item	2429914	et	4	main
kujutatakse	doc_485839256085_item	2429922	et	3	main
analoogina	doc_485839256085_item	2429925	et	3	main
maise	doc_485839256085_item	2429935	et	4	main
peipsimaal	doc_485839256085_item	2429944	et	4	main
muistendite	doc_485839256085_item	2429949	et	3	main
selliseid	doc_485839256085_item	2429953	et	4	main
selle	doc_485839256085_item	2429963	et	4	main
enda	doc_485839256085_item	2429474	et	4	main
vastutuse	doc_485839256085_item	2429476	et	4	main
inimese	doc_485839256085_item	2429477	et	4	main
elavast	doc_485839256085_item	2429483	et	4	main
vormis	doc_485839256085_item	2429489	et	4	main
last	doc_485839256085_item	2429496	et	4	main
ajal	doc_485839256085_item	2429498	et	4	main
sisse	doc_485839256085_item	2429501	et	4	main
pulmade	doc_485839256085_item	2429511	et	3	main
puistavad	doc_485839256085_item	2429517	et	4	main
üle	doc_485839256085_item	2429518	et	3	main
viljateradega	doc_485839256085_item	2429519	et	3	main
mõned	doc_485839256085_item	2429520	et	3	main
maagiasse	doc_485839256085_item	2429531	et	4	main
näiteks	doc_485839256085_item	2429532	et	4	main
lepivad	doc_485839256085_item	2429536	et	3	main
selleks	doc_485839256085_item	2429539	et	4	main
elab	doc_485839256085_item	2429548	et	3	main
tänapäevalgi	doc_485839256085_item	2429549	et	4	main
uskumus	doc_485839256085_item	2429550	et	3	main
kui	doc_485839256085_item	2429551	et	3	main
edela	doc_485839256085_item	2429576	et	3	main
kõige	doc_485839256085_item	2429578	et	4	main
osutusid	doc_485839256085_item	2429580	et	4	main
komplekt	doc_485839256085_item	2429599	et	3	main
ikoonide	doc_485839256085_item	2429604	et	3	main
hauda	doc_485839256085_item	2429608	et	4	main
hauaristid	doc_485839256085_item	2429617	et	4	main
ilmas	doc_485839256085_item	2429622	et	4	main
see	doc_485839256085_item	2429634	et	3	main
hõljub	doc_485839256085_item	2429643	et	3	main
jälgides	doc_485839256085_item	2429645	et	4	main
et	doc_485839256085_item	2429647	et	3	main
nõudmisega	doc_485839256085_item	2429671	et	4	main
vead	doc_485839256085_item	2429672	et	4	main
parandada	doc_485839256085_item	2429673	et	3	main
soovid	doc_485839256085_item	2429680	et	4	main
lahku	doc_485839256085_item	2429686	et	4	main
üldtunnustatud	doc_485839256085_item	2429687	et	3	main
surnud	doc_485839256085_item	2429699	et	4	main
midagi	doc_485839256085_item	2429709	et	4	main
küünlajuppi	doc_485839256085_item	2429713	et	4	main
surnuid	doc_485839256085_item	2429720	et	4	main
üle	doc_485839256085_item	2429729	et	3	main
eesti	doc_485839256085_item	2429730	et	4	main
mälestamise	doc_485839256085_item	2429735	et	4	main
idarannikul	doc_485839256085_item	2429748	et	3	main
täiendavad	doc_485839256085_item	2429757	et	4	main
mis	doc_485839256085_item	2429759	et	4	main
kohalikud	doc_485839256085_item	2429767	et	3	main
omaste	doc_485839256085_item	2429796	et	4	main
maiset	doc_485839256085_item	2429797	et	4	main
õnnetuste	doc_485839256085_item	2429801	et	4	main
on	doc_485839256085_item	2429808	et	4	main
tuled	doc_485839256085_item	2429811	et	4	main
siis	doc_485839256085_item	2429812	et	3	main
näed	doc_485839256085_item	2429813	et	3	main
ise	doc_485839256085_item	2429814	et	4	main
erilist	doc_485839256085_item	2429821	et	4	main
jõudu	doc_485839256085_item	2429823	et	4	main
mille	doc_485839256085_item	2429826	et	3	main
abil	doc_485839256085_item	2429827	et	4	main
kadunu	doc_485839256085_item	2429828	et	4	main
matusteks	doc_485839256085_item	2429829	et	3	main
maailma	doc_485839256085_item	2429833	et	4	main
ajal	doc_485839256085_item	2429835	et	4	main
üks	doc_485839256085_item	2429836	et	3	main
naine	doc_485839256085_item	2429837	et	3	main
sundis	doc_485839256085_item	2429838	et	3	main
oma	doc_485839256085_item	2429839	et	4	main
poega	doc_485839256085_item	2429840	et	4	main
veendumuse	doc_485839256085_item	2429845	et	4	main
et	doc_485839256085_item	2429846	et	3	main
teda	doc_485839256085_item	2429850	et	4	main
võta	doc_485839256085_item	2429852	et	4	main
pistes	doc_485839256085_item	2429857	et	4	main
kalmistu	doc_485839256085_item	2429868	et	4	main
ei	doc_485839256085_item	2429890	et	4	main
pandud	doc_485839256085_item	2429891	et	4	main
võib	doc_485839256085_item	2429902	et	3	main
minna	doc_485839256085_item	2429903	et	3	main
naabrid	doc_485839256085_item	2429535	et	3	main
minna	doc_485839256085_item	2429543	et	3	main
puhta	doc_485839256085_item	2429544	et	4	main
hingega	doc_485839256085_item	2429545	et	3	main
ema	doc_485839256085_item	2429552	et	4	main
salasepitsusi	doc_485839256085_item	2429561	et	3	main
neid	doc_485839256085_item	2429562	et	4	main
neitraliseerib	doc_485839256085_item	2429563	et	4	main
patuta	doc_485839256085_item	2429564	et	3	main
laps	doc_485839256085_item	2429565	et	4	main
peipsi	doc_485839256085_item	2429566	et	4	main
läänerannikul	doc_485839256085_item	2429567	et	3	main
samuti	doc_485839256085_item	2429568	et	3	main
kui	doc_485839256085_item	2429569	et	3	main
teistes	doc_485839256085_item	2429570	et	4	main
vanausulistega	doc_485839256085_item	2429571	et	4	main
asustatud	doc_485839256085_item	2429572	et	4	main
baltimaade	doc_485839256085_item	2429573	et	3	main
regioonides	doc_485839256085_item	2429574	et	3	main
ja	doc_485839256085_item	2429575	et	3	main
valgevenes	doc_485839256085_item	2429577	et	3	main
ja	doc_485839256085_item	2429582	et	3	main
mälestamise	doc_485839256085_item	2429584	et	4	main
mütoloogilised	doc_485839256085_item	2429591	et	4	main
muistendid	doc_485839256085_item	2429592	et	3	main
õmmeldakse	doc_485839256085_item	2429594	et	3	main
pannakse	doc_485839256085_item	2429596	et	3	main
pannakse	doc_485839256085_item	2429601	et	3	main
kirst	doc_485839256085_item	2429606	et	3	main
rättidel	doc_485839256085_item	2429609	et	3	main
ikka	doc_485839256085_item	2429619	et	4	main
oma	doc_485839256085_item	2429625	et	4	main
kanda	doc_485839256085_item	2429627	et	4	main
aegsasti	doc_485839256085_item	2429628	et	3	main
lahkunu	doc_485839256085_item	2429638	et	4	main
hing	doc_485839256085_item	2429639	et	3	main
nelikümmend	doc_485839256085_item	2429640	et	4	main
usutakse	doc_485839256085_item	2429655	et	4	main
et	doc_485839256085_item	2429656	et	3	main
kõrvalekaldumine	doc_485839256085_item	2429658	et	3	main
tingimata	doc_485839256085_item	2429674	et	4	main
lahkunu	doc_485839256085_item	2429678	et	4	main
lähvad	doc_485839256085_item	2429685	et	4	main
on	doc_485839256085_item	2429696	et	4	main
kaasa	doc_485839256085_item	2429702	et	4	main
kedagi	doc_485839256085_item	2429704	et	4	main
kalmistult	doc_485839256085_item	2429706	et	3	main
kaasa	doc_485839256085_item	2429710	et	4	main
võtta	doc_485839256085_item	2429711	et	3	main
63112	doc_485839256085_item	2429716	et	2	main
tuleb	doc_485839256085_item	2429623	et	3	main
valmistati	doc_485839256085_item	2429629	et	4	main
ette	doc_485839256085_item	2429630	et	4	main
täideti	doc_485839256085_item	2429633	et	3	main
veendumuste	doc_485839256085_item	2429636	et	4	main
järgi	doc_485839256085_item	2429637	et	4	main
kodukülas	doc_485839256085_item	2429644	et	3	main
toimetatud	doc_485839256085_item	2429651	et	4	main
vanade	doc_485839256085_item	2429652	et	3	main
tavade	doc_485839256085_item	2429653	et	3	main
järgi	doc_485839256085_item	2429654	et	4	main
unes	doc_485839256085_item	2429666	et	3	main
ilmsi	doc_485839256085_item	2429668	et	3	main
täita	doc_485839256085_item	2429677	et	4	main
need	doc_485839256085_item	2429684	et	3	main
kõlbluskaanonitega	doc_485839256085_item	2429688	et	3	main
kirstu	doc_485839256085_item	2429689	et	4	main
panna	doc_485839256085_item	2429690	et	4	main
pudel	doc_485839256085_item	2429691	et	3	main
lood	doc_485839256085_item	2429697	et	4	main
kuidas	doc_485839256085_item	2429698	et	3	main
ligistest	doc_485839256085_item	2429705	et	4	main
isegi	doc_485839256085_item	2429712	et	4	main
ole	doc_485839256085_item	2429718	et	4	main
liiga	doc_485839256085_item	2429721	et	4	main
taganutta	doc_485839256085_item	2429723	et	4	main
kirstud	doc_485839256085_item	2429728	et	3	main
vanausuliste	doc_485839256085_item	2429731	et	4	main
matuse	doc_485839256085_item	2429732	et	3	main
ja	doc_485839256085_item	2429733	et	3	main
surnute	doc_485839256085_item	2429734	et	4	main
on	doc_485839256085_item	2429739	et	4	main
palju	doc_485839256085_item	2429740	et	4	main
rikkamad	doc_485839256085_item	2429741	et	4	main
ja	doc_485839256085_item	2429742	et	3	main
arhhailisemad	doc_485839256085_item	2429743	et	4	main
kui	doc_485839256085_item	2429744	et	3	main
läti	doc_485839256085_item	2429762	et	4	main
leedu	doc_485839256085_item	2429764	et	4	main
elu	doc_485839256085_item	2429798	et	4	main
kuid	doc_485839256085_item	2429803	et	4	main
hauatagusest	doc_485839256085_item	2429806	et	3	main
vastumeelsed	doc_485839256085_item	2429810	et	3	main
nende	doc_485839256085_item	2429727	et	4	main
peipsi	doc_485839256085_item	2429747	et	4	main
pihkva	doc_485839256085_item	2429750	et	4	main
kandis	doc_485839256085_item	2429751	et	4	main
haruldased	doc_485839256085_item	2429753	et	3	main
uskumused	doc_485839256085_item	2429754	et	3	main
ja	doc_485839256085_item	2429755	et	3	main
kirjapanekuid	doc_485839256085_item	2429758	et	3	main
ja	doc_485839256085_item	2429763	et	3	main
vanausuliste	doc_485839256085_item	2429765	et	4	main
jõululaupäev	doc_485839256085_item	2429773	et	3	main
kuteinik	doc_485839256085_item	2429772	et	4	main
kuid	doc_485839256085_item	2429774	et	4	main
kutjad	doc_485839256085_item	2429775	et	4	main
nisuterast	doc_485839256085_item	2429776	et	4	main
valmistatud	doc_485839256085_item	2429777	et	4	main
puder	doc_485839256085_item	2429778	et	3	main
meega	doc_485839256085_item	2429779	et	3	main
siinkandis	doc_485839256085_item	2429780	et	3	main
lauale	doc_485839256085_item	2429781	et	4	main
pannakse	doc_485839256085_item	2429782	et	3	main
ainult	doc_485839256085_item	2429783	et	4	main
matustel	doc_485839256085_item	2429784	et	3	main
ja	doc_485839256085_item	2429785	et	3	main
peietel	doc_485839256085_item	2429786	et	3	main
kohalikud	doc_485839256085_item	2429787	et	3	main
vanausulised	doc_485839256085_item	2429788	et	4	main
arvavad	doc_485839256085_item	2429789	et	4	main
et	doc_485839256085_item	2429790	et	3	main
kadunud	doc_485839256085_item	2429791	et	4	main
sugulaste	doc_485839256085_item	2429792	et	4	main
hinged	doc_485839256085_item	2429793	et	3	main
jälgivad	doc_485839256085_item	2429794	et	4	main
eest	doc_485839256085_item	2429802	et	4	main
elust	doc_485839256085_item	2429807	et	3	main
hingedele	doc_485839256085_item	2429809	et	3	main
valati	doc_485839256085_item	2429819	et	3	main
sellise	doc_485839256085_item	2429843	et	4	main
üksk	doc_485839256085_item	2429848	et	4	main
päästa	doc_485839256085_item	2429856	et	4	main
jala	doc_485839256085_item	2429862	et	4	main
tohi	doc_485839256085_item	2429894	et	4	main
ootama	doc_485839256085_item	2429919	et	3	main
ilmaga	doc_485839256085_item	2429927	et	3	main
seal	doc_485839256085_item	2429930	et	4	main
asjadega	doc_485839256085_item	2429932	et	3	main
käivad	doc_485839256085_item	2429938	et	4	main
üks	doc_485839256085_item	2429940	et	3	main
jm	doc_485839256085_item	2429943	et	4	main
tavaliste	doc_485839256085_item	2429948	et	4	main
kus	doc_485839256085_item	2429955	et	3	main
näeb	doc_485839256085_item	2429969	et	3	main
on	doc_485839256085_item	2429981	et	4	main
kes	doc_485839256085_item	2429987	et	4	main
uhkes	doc_485839256085_item	2429991	et	4	main
seinad	doc_485839256085_item	2429995	et	3	main
tsükklis	doc_485839256085_item	2430025	et	4	main
kes	doc_485839256085_item	2430039	et	4	main
kurja	doc_485839256085_item	2430045	et	4	main
öösiti	doc_485839256085_item	2430056	et	4	main
mahajäätud	doc_485839256085_item	2430060	et	4	main
sõidab	doc_485839256085_item	2430075	et	3	main
jutte	doc_485839256085_item	2430104	et	3	main
abil	doc_485839256085_item	2430112	et	4	main
teadmiste	doc_485839256085_item	2430115	et	4	main
inimestele	doc_485839256085_item	2430117	et	3	main
palju	doc_485839256085_item	2430118	et	4	main
erandi	doc_485839256085_item	2430124	et	3	main
selliseid	doc_485839256085_item	2430130	et	4	main
ja	doc_485839256085_item	2430139	et	3	main
posijate	doc_485839256085_item	2430148	et	4	main
ja	doc_485839256085_item	2430149	et	3	main
etnograafilisi	doc_485839256085_item	2430163	et	4	main
kalendripühade	doc_485839256085_item	2430166	et	3	main
talsipühade	doc_485839256085_item	2430168	et	4	main
ajal	doc_485839256085_item	2430169	et	4	main
rohisid	doc_485839256085_item	2430175	et	4	main
panid	doc_485839256085_item	2430176	et	4	main
padja	doc_485839256085_item	2430177	et	3	main
alla	doc_485839256085_item	2430178	et	3	main
kaeve	doc_485839256085_item	2430182	et	4	main
või	doc_485839256085_item	2430184	et	4	main
värskeid	doc_485839256085_item	2430186	et	4	main
küpsetisi	doc_485839256085_item	2430187	et	4	main
veeklaasi	doc_485839256085_item	2430194	et	4	main
saatuse	doc_485839256085_item	2430199	et	3	main
kasutati	doc_485839256085_item	2430213	et	4	main
ennustustes	doc_485839256085_item	2430219	et	4	main
külades	doc_485839256085_item	2430226	et	3	main
või	doc_485839256085_item	2430234	et	4	main
pärast	doc_485839256085_item	2430239	et	4	main
seda	doc_485839256085_item	2430243	et	3	main
ja	doc_485839256085_item	2430252	et	3	main
день	doc_485839256085_item	2430258	et	2	main
ивана	doc_485839256085_item	2430262	et	2	main
teine	doc_485839256085_item	2430275	et	3	main
selle	doc_485839256085_item	2430284	et	4	main
jutud	doc_485839256085_item	2429804	et	3	main
vesi	doc_485839256085_item	2429815	et	4	main
millega	doc_485839256085_item	2429816	et	3	main
teise	doc_485839256085_item	2429832	et	4	main
end	doc_485839256085_item	2429842	et	4	main
kuul	doc_485839256085_item	2429849	et	4	main
hauale	doc_485839256085_item	2429896	et	3	main
päikese	doc_485839256085_item	2429898	et	4	main
lahkunu	doc_485839256085_item	2429901	et	4	main
saatma	doc_485839256085_item	2429905	et	3	main
surnuaia	doc_485839256085_item	2429908	et	4	main
väravad	doc_485839256085_item	2429909	et	3	main
selle	doc_485839256085_item	2429910	et	4	main
ajaga	doc_485839256085_item	2429911	et	3	main
suletud	doc_485839256085_item	2429912	et	4	main
hommikuni	doc_485839256085_item	2429916	et	4	main
taga	doc_485839256085_item	2429918	et	4	main
mütoloogilistes	doc_485839256085_item	2429920	et	4	main
teist	doc_485839256085_item	2429923	et	4	main
maise	doc_485839256085_item	2429926	et	4	main
sama	doc_485839256085_item	2429931	et	4	main
mis	doc_485839256085_item	2429933	et	4	main
oma	doc_485839256085_item	2429934	et	4	main
ajal	doc_485839256085_item	2429937	et	4	main
on	doc_485839256085_item	2429951	et	4	main
ka	doc_485839256085_item	2429952	et	3	main
muistendeid	doc_485839256085_item	2429954	et	3	main
inimese	doc_485839256085_item	2429956	et	4	main
surma	doc_485839256085_item	2429959	et	4	main
muutub	doc_485839256085_item	2429960	et	3	main
näitlik	doc_485839256085_item	2429961	et	3	main
kus	doc_485839256085_item	2429966	et	3	main
unes	doc_485839256085_item	2429971	et	3	main
arsenid	doc_485839256085_item	2429974	et	4	main
tema	doc_485839256085_item	2429982	et	4	main
aleksandr	doc_485839256085_item	2429986	et	4	main
väikeste	doc_485839256085_item	2430022	et	4	main
reegioonides	doc_485839256085_item	2430033	et	4	main
domineerivad	doc_485839256085_item	2430034	et	4	main
süžeed	doc_485839256085_item	2430035	et	2	main
võtnud	doc_485839256085_item	2430040	et	4	main
endale	doc_485839256085_item	2430041	et	4	main
on	doc_485839256085_item	2430048	et	4	main
teevad	doc_485839256085_item	2430058	et	3	main
inimest	doc_485839256085_item	2430062	et	3	main
mees	doc_485839256085_item	2430074	et	4	main
nõidujatest	doc_485839256085_item	2430113	et	4	main
maagilist	doc_485839256085_item	2429822	et	4	main
omistati	doc_485839256085_item	2429824	et	3	main
seebile	doc_485839256085_item	2429825	et	3	main
sõja	doc_485839256085_item	2429834	et	3	main
pesta	doc_485839256085_item	2429841	et	4	main
nüüd	doc_485839256085_item	2429847	et	4	main
ei	doc_485839256085_item	2429851	et	4	main
ussi	doc_485839256085_item	2429853	et	4	main
kahjustatud	doc_485839256085_item	2429859	et	4	main
käe	doc_485839256085_item	2429860	et	3	main
põhjapoolses	doc_485839256085_item	2429869	et	3	main
nurgas	doc_485839256085_item	2429870	et	3	main
kirstu	doc_485839256085_item	2429871	et	4	main
enesetapja	doc_485839256085_item	2429872	et	4	main
kehaga	doc_485839256085_item	2429873	et	3	main
ei	doc_485839256085_item	2429874	et	4	main
ole	doc_485839256085_item	2429875	et	4	main
soovitatav	doc_485839256085_item	2429876	et	4	main
viia	doc_485839256085_item	2429877	et	3	main
läbi	doc_485839256085_item	2429878	et	4	main
surnuaia	doc_485839256085_item	2429879	et	4	main
värava	doc_485839256085_item	2429880	et	3	main
tavaliselt	doc_485839256085_item	2429881	et	4	main
see	doc_485839256085_item	2429882	et	3	main
tõstetakse	doc_485839256085_item	2429883	et	4	main
kätel	doc_485839256085_item	2429884	et	3	main
üle	doc_485839256085_item	2429885	et	3	main
aia	doc_485839256085_item	2429886	et	4	main
vanasti	doc_485839256085_item	2429887	et	3	main
enesetapja	doc_485839256085_item	2429888	et	4	main
hauale	doc_485839256085_item	2429889	et	3	main
ei	doc_485839256085_item	2429893	et	4	main
pärast	doc_485839256085_item	2429897	et	4	main
loojangut	doc_485839256085_item	2429899	et	3	main
kuna	doc_485839256085_item	2429900	et	3	main
ja	doc_485839256085_item	2429906	et	3	main
on	doc_485839256085_item	2429913	et	4	main
värava	doc_485839256085_item	2429917	et	3	main
tegelevad	doc_485839256085_item	2429929	et	4	main
külla	doc_485839256085_item	2429939	et	4	main
teise	doc_485839256085_item	2429941	et	4	main
juurde	doc_485839256085_item	2429942	et	4	main
kogutud	doc_485839256085_item	2429945	et	4	main
materjalid	doc_485839256085_item	2429946	et	3	main
tõestavad	doc_485839256085_item	2429947	et	4	main
staatus	doc_485839256085_item	2429957	et	3	main
pärast	doc_485839256085_item	2429958	et	4	main
õde	doc_485839256085_item	2429968	et	4	main
ennast	doc_485839256085_item	2429970	et	4	main
oma	doc_485839256085_item	2429972	et	4	main
venda	doc_485839256085_item	2429973	et	4	main
vennast	doc_485839256085_item	2429983	et	4	main
töötab	doc_485839256085_item	2429988	et	3	main
elab	doc_485839256085_item	2429990	et	3	main
korteris	doc_485839256085_item	2429992	et	3	main
vaipadega	doc_485839256085_item	2429994	et	3	main
sugulasi	doc_485839256085_item	2429904	et	3	main
kui	doc_485839256085_item	2429907	et	3	main
ta	doc_485839256085_item	2429915	et	4	main
muistendites	doc_485839256085_item	2429921	et	3	main
ilma	doc_485839256085_item	2429924	et	4	main
surnud	doc_485839256085_item	2429928	et	4	main
elu	doc_485839256085_item	2429936	et	4	main
levikut	doc_485839256085_item	2429950	et	3	main
on	doc_485839256085_item	2429962	et	4	main
üks	doc_485839256085_item	2429967	et	3	main
et	doc_485839256085_item	2429978	et	3	main
saanud	doc_485839256085_item	2429984	et	4	main
kahhelplaadil	doc_485839256085_item	2430000	et	3	main
helesinine	doc_485839256085_item	2430001	et	4	main
lilleke	doc_485839256085_item	2430002	et	4	main
ristimatta	doc_485839256085_item	2430003	et	4	main
surnud	doc_485839256085_item	2430004	et	4	main
väikelapsed	doc_485839256085_item	2430005	et	3	main
teises	doc_485839256085_item	2430007	et	4	main
on	doc_485839256085_item	2430006	et	4	main
ilmas	doc_485839256085_item	2430008	et	4	main
pimedad	doc_485839256085_item	2430009	et	3	main
näevad	doc_485839256085_item	2430010	et	3	main
nad	doc_485839256085_item	2430011	et	3	main
ainult	doc_485839256085_item	2430012	et	4	main
siis	doc_485839256085_item	2430013	et	3	main
kui	doc_485839256085_item	2430014	et	3	main
maapeal	doc_485839256085_item	2430015	et	3	main
üheagselt	doc_485839256085_item	2430016	et	4	main
paistab	doc_485839256085_item	2430017	et	3	main
päike	doc_485839256085_item	2430018	et	3	main
ja	doc_485839256085_item	2430019	et	3	main
sajab	doc_485839256085_item	2430020	et	3	main
rahvajuttude	doc_485839256085_item	2430023	et	4	main
nagu	doc_485839256085_item	2430030	et	3	main
ka	doc_485839256085_item	2430031	et	3	main
teistes	doc_485839256085_item	2430032	et	4	main
kellegi	doc_485839256085_item	2430042	et	4	main
sugulase	doc_485839256085_item	2430043	et	3	main
seotud	doc_485839256085_item	2430049	et	4	main
süžeed	doc_485839256085_item	2430052	et	2	main
vaimudest	doc_485839256085_item	2430053	et	3	main
ja	doc_485839256085_item	2430054	et	3	main
hirmudest	doc_485839256085_item	2430055	et	3	main
põlevate	doc_485839256085_item	2430071	et	4	main
sabaga	doc_485839256085_item	2430073	et	3	main
mahukaid	doc_485839256085_item	2430103	et	4	main
nõiutud	doc_485839256085_item	2430105	et	4	main
aarete	doc_485839256085_item	2430106	et	3	main
otsimisest	doc_485839256085_item	2430107	et	4	main
madudest	doc_485839256085_item	2430108	et	3	main
saatanlike	doc_485839256085_item	2430114	et	3	main
on	doc_485839256085_item	2430132	et	4	main
tekstid	doc_485839256085_item	2430136	et	3	main
üldjuhul	doc_485839256085_item	2430140	et	3	main
jäävad	doc_485839256085_item	2430141	et	4	main
nad	doc_485839256085_item	2430142	et	3	main
on	doc_485839256085_item	2430152	et	4	main
üksikasju	doc_485839256085_item	2430164	et	3	main
neiud	doc_485839256085_item	2430170	et	4	main
juuksekamme	doc_485839256085_item	2430180	et	3	main
asetatud	doc_485839256085_item	2430195	et	4	main
poolt	doc_485839256085_item	2430200	et	4	main
poolest	doc_485839256085_item	2429964	et	4	main
lugu	doc_485839256085_item	2429965	et	4	main
otsimas	doc_485839256085_item	2429975	et	4	main
ja	doc_485839256085_item	2429976	et	3	main
avastab	doc_485839256085_item	2429977	et	3	main
seal	doc_485839256085_item	2429979	et	4	main
ilmas	doc_485839256085_item	2429980	et	4	main
vürst	doc_485839256085_item	2429985	et	3	main
kuskilgi	doc_485839256085_item	2429989	et	4	main
televiisoriga	doc_485839256085_item	2429993	et	3	main
kaetud	doc_485839256085_item	2429996	et	4	main
kahhelplaatidega	doc_485839256085_item	2429997	et	3	main
kus	doc_485839256085_item	2429998	et	3	main
igal	doc_485839256085_item	2429999	et	3	main
vihma	doc_485839256085_item	2430021	et	4	main
kadunukest	doc_485839256085_item	2430027	et	4	main
peipsi	doc_485839256085_item	2430028	et	4	main
läänerannikul	doc_485839256085_item	2430029	et	3	main
või	doc_485839256085_item	2430037	et	4	main
kuraditest	doc_485839256085_item	2430038	et	4	main
kuju	doc_485839256085_item	2430044	et	4	main
ka	doc_485839256085_item	2430050	et	3	main
paljud	doc_485839256085_item	2430051	et	3	main
tööd	doc_485839256085_item	2430059	et	4	main
punaste	doc_485839256085_item	2430064	et	4	main
silmadega	doc_485839256085_item	2430065	et	3	main
siga	doc_485839256085_item	2430066	et	4	main
viirastub	doc_485839256085_item	2430067	et	3	main
kitsetaoline	doc_485839256085_item	2430068	et	3	main
olend	doc_485839256085_item	2430069	et	3	main
paadis	doc_485839256085_item	2430070	et	3	main
äranõiutud	doc_485839256085_item	2430109	et	4	main
koduloomadest	doc_485839256085_item	2430110	et	3	main
teinud	doc_485839256085_item	2430120	et	4	main
hirmsast	doc_485839256085_item	2430122	et	3	main
jutte	doc_485839256085_item	2430131	et	3	main
kujutluste	doc_485839256085_item	2430145	et	4	main
kohalike	doc_485839256085_item	2430147	et	4	main
samuti	doc_485839256085_item	2430153	et	3	main
posimised	doc_485839256085_item	2430160	et	4	main
kirjelduses	doc_485839256085_item	2430167	et	4	main
oma	doc_485839256085_item	2430179	et	4	main
kokorasi	doc_485839256085_item	2430188	et	4	main
anti	doc_485839256085_item	2430189	et	3	main
esimesele	doc_485839256085_item	2430190	et	3	main
kohatud	doc_485839256085_item	2430192	et	4	main
meesterahvale	doc_485839256085_item	2430193	et	3	main
näha	doc_485839256085_item	2430198	et	3	main
kes	doc_485839256085_item	2430204	et	4	main
esimene	doc_485839256085_item	2430205	et	3	main
mehele	doc_485839256085_item	2430206	et	3	main
saab	doc_485839256085_item	2430207	et	3	main
kes	doc_485839256085_item	2430209	et	4	main
on	doc_485839256085_item	2430210	et	4	main
tulevane	doc_485839256085_item	2430211	et	3	main
väljavalitu	doc_485839256085_item	2430212	et	4	main
viise	doc_485839256085_item	2430217	et	3	main
rukiviljapäid	doc_485839256085_item	2430223	et	4	main
lõunapoolsetes	doc_485839256085_item	2430225	et	4	main
jegorij	doc_485839256085_item	2430228	et	4	main
kevadine	doc_485839256085_item	2430229	et	4	main
naised	doc_485839256085_item	2430230	et	3	main
panid	doc_485839256085_item	2430231	et	4	main
lüpsiku	doc_485839256085_item	2430232	et	3	main
veini	doc_485839256085_item	2430233	et	4	main
joodi	doc_485839256085_item	2430240	et	4	main
terved	doc_485839256085_item	2430251	et	4	main
piima	doc_485839256085_item	2430253	et	4	main
toovad	doc_485839256085_item	2430254	et	4	main
иногда	doc_485839256085_item	2430260	et	2	main
или	doc_485839256085_item	2430264	et	2	main
olevipäeval	doc_485839256085_item	2430267	et	3	main
lapsevanemad	doc_485839256085_item	2430279	et	4	main
kunagi	doc_485839256085_item	2430280	et	3	main
riielnud	doc_485839256085_item	2430282	et	4	main
lapsi	doc_485839256085_item	2430283	et	4	main
mis	doc_485839256085_item	2430286	et	4	main
selle	doc_485839256085_item	2430289	et	4	main
arvata	doc_485839256085_item	2430293	et	4	main
võib	doc_485839256085_item	2430294	et	3	main
et	doc_485839256085_item	2430295	et	3	main
bõliškad	doc_485839256085_item	2430024	et	2	main
rändavatest	doc_485839256085_item	2430026	et	4	main
enesetapjatest	doc_485839256085_item	2430036	et	4	main
vaimu	doc_485839256085_item	2430046	et	4	main
salasepitsustega	doc_485839256085_item	2430047	et	3	main
kuradid	doc_485839256085_item	2430057	et	3	main
veskis	doc_485839256085_item	2430061	et	3	main
jälitab	doc_485839256085_item	2430063	et	3	main
silmadega	doc_485839256085_item	2430072	et	3	main
ühe	doc_485839256085_item	2430076	et	4	main
rattaga	doc_485839256085_item	2430077	et	3	main
vankri	doc_485839256085_item	2430078	et	3	main
peal	doc_485839256085_item	2430079	et	4	main
jm	doc_485839256085_item	2430080	et	4	main
muistendite	doc_485839256085_item	2430082	et	3	main
mütoloogiliste	doc_485839256085_item	2430081	et	4	main
muud	doc_485839256085_item	2430083	et	4	main
temaatilised	doc_485839256085_item	2430084	et	4	main
gruppid	doc_485839256085_item	2430085	et	4	main
on	doc_485839256085_item	2430086	et	4	main
kohalikus	doc_485839256085_item	2430087	et	4	main
folklooris	doc_485839256085_item	2430088	et	4	main
esitatud	doc_485839256085_item	2430089	et	4	main
suhteliselt	doc_485839256085_item	2430090	et	4	main
vähe	doc_485839256085_item	2430091	et	3	main
ainult	doc_485839256085_item	2430092	et	4	main
kaks-kolm	doc_485839256085_item	2430093	et	3	main
inimest	doc_485839256085_item	2430094	et	3	main
rääkisid	doc_485839256085_item	2430095	et	4	main
metsavaimust	doc_485839256085_item	2430096	et	4	main
kuid	doc_485839256085_item	2430097	et	4	main
nemadki	doc_485839256085_item	2430098	et	3	main
ainult	doc_485839256085_item	2430099	et	4	main
kaudselt	doc_485839256085_item	2430100	et	4	main
vähe	doc_485839256085_item	2430101	et	3	main
on	doc_485839256085_item	2430102	et	4	main
nõiaraamatute	doc_485839256085_item	2430111	et	3	main
abil	doc_485839256085_item	2430116	et	4	main
halba	doc_485839256085_item	2430119	et	4	main
kaetamisest	doc_485839256085_item	2430127	et	4	main
ja	doc_485839256085_item	2430128	et	3	main
posimisest	doc_485839256085_item	2430129	et	4	main
palju	doc_485839256085_item	2430134	et	4	main
kuid	doc_485839256085_item	2430135	et	4	main
on	doc_485839256085_item	2430137	et	4	main
konspektiivsed	doc_485839256085_item	2430138	et	3	main
tüüpiliste	doc_485839256085_item	2430143	et	3	main
üpris	doc_485839256085_item	2430154	et	3	main
palju	doc_485839256085_item	2430161	et	4	main
ennustasid	doc_485839256085_item	2430171	et	4	main
tulevikku	doc_485839256085_item	2430172	et	4	main
teeristmikul	doc_485839256085_item	2430173	et	4	main
lund	doc_485839256085_item	2430174	et	3	main
ka	doc_485839256085_item	2430181	et	3	main
pirrukestest	doc_485839256085_item	2430183	et	4	main
tänaval	doc_485839256085_item	2430191	et	4	main
abielusõrmuses	doc_485839256085_item	2430196	et	3	main
maagilisi	doc_485839256085_item	2430216	et	4	main
rohttaimi	doc_485839256085_item	2430221	et	4	main
viina	doc_485839256085_item	2430235	et	4	main
sisse	doc_485839256085_item	2430236	et	4	main
ja	doc_485839256085_item	2430238	et	3	main
pitsi	doc_485839256085_item	2430242	et	4	main
palju	doc_485839256085_item	2430255	et	4	main
в	doc_485839256085_item	2430256	et	2	main
на	doc_485839256085_item	2430261	et	2	main
маккавея	doc_485839256085_item	2430266	et	2	main
vahest	doc_485839256085_item	2430268	et	4	main
või	doc_485839256085_item	2430270	et	4	main
makkaveipäeval	doc_485839256085_item	2430271	et	4	main
lapsed	doc_485839256085_item	2430272	et	3	main
püüdsid	doc_485839256085_item	2430273	et	4	main
riietatult	doc_485839256085_item	2430277	et	4	main
tava	doc_485839256085_item	2430290	et	4	main
rituaalsetele	doc_485839256085_item	2430291	et	3	main
pühi	doc_485839256085_item	2430323	et	4	main
ja	doc_485839256085_item	2430327	et	3	main
kodukirikupühadel	doc_485839256085_item	2430329	et	3	main
kombeks	doc_485839256085_item	2430331	et	4	main
kes	doc_485839256085_item	2430338	et	4	main
olid	doc_485839256085_item	2430345	et	4	main
eelnevalt	doc_485839256085_item	2430348	et	4	main
ära	doc_485839256085_item	2430355	et	4	main
peetripühal	doc_485839256085_item	2430360	et	4	main
külla	doc_485839256085_item	2430364	et	4	main
lemmikpüha	doc_485839256085_item	2430368	et	4	main
oli	doc_485839256085_item	2430369	et	3	main
kindlasti	doc_485839256085_item	2430378	et	3	main
aasta	doc_485839256085_item	2430381	et	4	main
peeti	doc_485839256085_item	2430383	et	4	main
sellel	doc_485839256085_item	2430390	et	4	main
ja	doc_485839256085_item	2430400	et	3	main
ka	doc_485839256085_item	2430409	et	3	main
pererahvas	doc_485839256085_item	2430414	et	4	main
oma	doc_485839256085_item	2430416	et	4	main
hoovi	doc_485839256085_item	2430417	et	4	main
üle	doc_485839256085_item	2430418	et	3	main
üllatusi	doc_485839256085_item	2430424	et	4	main
samuti	doc_485839256085_item	2430435	et	3	main
kui	doc_485839256085_item	2430436	et	3	main
loode	doc_485839256085_item	2430440	et	4	main
mõnedes	doc_485839256085_item	2430442	et	3	main
pandi	doc_485839256085_item	2430444	et	4	main
koduustele	doc_485839256085_item	2430445	et	3	main
kinni	doc_485839256085_item	2430454	et	3	main
puuriidad	doc_485839256085_item	2430459	et	4	main
saanid	doc_485839256085_item	2430461	et	3	main
tiriti	doc_485839256085_item	2430464	et	3	main
sedalaadi	doc_485839256085_item	2430469	et	4	main
rituaalsed	doc_485839256085_item	2430470	et	3	main
nõudsid	doc_485839256085_item	2430477	et	4	main
ka	doc_485839256085_item	2430478	et	3	main
maja	doc_485839256085_item	2430484	et	4	main
tünnid	doc_485839256085_item	2430488	et	3	main
võisid	doc_485839256085_item	2430490	et	4	main
nõia	doc_485839256085_item	2430121	et	3	main
surmast	doc_485839256085_item	2430123	et	4	main
moodustavad	doc_485839256085_item	2430125	et	4	main
jutud	doc_485839256085_item	2430126	et	3	main
üsna	doc_485839256085_item	2430133	et	3	main
vene	doc_485839256085_item	2430144	et	4	main
raamistiku	doc_485839256085_item	2430146	et	4	main
ravitsejate	doc_485839256085_item	2430150	et	4	main
repertuaar	doc_485839256085_item	2430151	et	3	main
väike	doc_485839256085_item	2430155	et	4	main
ja	doc_485839256085_item	2430156	et	3	main
seal	doc_485839256085_item	2430157	et	4	main
domineerivad	doc_485839256085_item	2430158	et	4	main
meditsiinilised	doc_485839256085_item	2430159	et	4	main
huvitavaid	doc_485839256085_item	2430162	et	4	main
leidub	doc_485839256085_item	2430165	et	3	main
tikkudest	doc_485839256085_item	2430185	et	3	main
püüti	doc_485839256085_item	2430197	et	3	main
määratu	doc_485839256085_item	2430201	et	4	main
ka	doc_485839256085_item	2430214	et	3	main
muid	doc_485839256085_item	2430215	et	4	main
kasutati	doc_485839256085_item	2430220	et	4	main
ja	doc_485839256085_item	2430222	et	3	main
peipsi	doc_485839256085_item	2430224	et	4	main
likku	doc_485839256085_item	2430237	et	3	main
а	doc_485839256085_item	2430259	et	2	main
на	doc_485839256085_item	2430265	et	2	main
seitsevennapäeval	doc_485839256085_item	2430269	et	3	main
teist	doc_485839256085_item	2430276	et	4	main
ei	doc_485839256085_item	2430281	et	4	main
kaudselt	doc_485839256085_item	2430287	et	4	main
tähistati	doc_485839256085_item	2430324	et	4	main
inimesi	doc_485839256085_item	2430337	et	4	main
juhuks	doc_485839256085_item	2430344	et	3	main
kaetud	doc_485839256085_item	2430350	et	4	main
olid	doc_485839256085_item	2430353	et	4	main
võis	doc_485839256085_item	2430362	et	4	main
uus	doc_485839256085_item	2430380	et	3	main
kalendri	doc_485839256085_item	2430388	et	3	main
järgi	doc_485839256085_item	2430389	et	4	main
täiskasvanud	doc_485839256085_item	2430397	et	4	main
tempudesse	doc_485839256085_item	2430402	et	3	main
sai	doc_485839256085_item	2430405	et	4	main
ju	doc_485839256085_item	2430406	et	3	main
naabrite	doc_485839256085_item	2430407	et	3	main
visatud	doc_485839256085_item	2430411	et	4	main
nääri	doc_485839256085_item	2430423	et	4	main
oli	doc_485839256085_item	2430425	et	3	main
palju	doc_485839256085_item	2430426	et	4	main
ja	doc_485839256085_item	2430427	et	3	main
erisuguseid	doc_485839256085_item	2430429	et	3	main
teivad	doc_485839256085_item	2430446	et	4	main
ette	doc_485839256085_item	2430447	et	4	main
kaltsudega	doc_485839256085_item	2430453	et	3	main
või	doc_485839256085_item	2430462	et	4	main
küla	doc_485839256085_item	2430465	et	4	main
teise	doc_485839256085_item	2430466	et	4	main
mis	doc_485839256085_item	2430476	et	4	main
viisid	doc_485839256085_item	2430482	et	4	main
soolahoidistega	doc_485839256085_item	2430489	et	3	main
sauna	doc_485839256085_item	2430492	et	4	main
katusele	doc_485839256085_item	2430493	et	3	main
väiksema	doc_485839256085_item	2430494	et	4	main
paadi	doc_485839256085_item	2430495	et	3	main
tirida	doc_485839256085_item	2430496	et	3	main
maslenitsa	doc_485839256085_item	2430523	et	4	main
ehitati	doc_485839256085_item	2430525	et	3	main
mängiti	doc_485839256085_item	2430528	et	3	main
lahingut	doc_485839256085_item	2430529	et	3	main
linnuse	doc_485839256085_item	2430530	et	3	main
ümberpiiramist	doc_485839256085_item	2430531	et	3	main
ja	doc_485839256085_item	2430532	et	3	main
selle	doc_485839256085_item	2430533	et	4	main
purustamist	doc_485839256085_item	2430534	et	4	main
pidupäevadel	doc_485839256085_item	2430535	et	3	main
said	doc_485839256085_item	2430536	et	4	main
piiril	doc_485839256085_item	2430540	et	3	main
sein	doc_485839256085_item	2430543	et	3	main
vastu	doc_485839256085_item	2430545	et	3	main
see	doc_485839256085_item	2430546	et	3	main
tava	doc_485839256085_item	2430547	et	4	main
ka	doc_485839256085_item	2430559	et	3	main
ei	doc_485839256085_item	2430565	et	4	main
leidu	doc_485839256085_item	2430566	et	4	main
analooge	doc_485839256085_item	2430567	et	3	main
külades	doc_485839256085_item	2430573	et	3	main
üle	doc_485839256085_item	2430595	et	3	main
linna	doc_485839256085_item	2430597	et	4	main
mida	doc_485839256085_item	2430600	et	4	main
ehtisid	doc_485839256085_item	2430601	et	4	main
medalid	doc_485839256085_item	2430602	et	3	main
tulega	doc_485839256085_item	2430603	et	3	main
imiteeriti	doc_485839256085_item	2430623	et	3	main
kustutamise	doc_485839256085_item	2430628	et	4	main
kiiruses	doc_485839256085_item	2430629	et	4	main
nägu	doc_485839256085_item	2430202	et	4	main
ennustustes	doc_485839256085_item	2430203	et	4	main
või	doc_485839256085_item	2430208	et	4	main
jäänipaeva	doc_485839256085_item	2430218	et	4	main
jüripäeval	doc_485839256085_item	2430227	et	3	main
kaks-kolm	doc_485839256085_item	2430241	et	3	main
jooki	doc_485839256085_item	2430244	et	4	main
ära	doc_485839256085_item	2430245	et	4	main
usuti	doc_485839256085_item	2430246	et	3	main
et	doc_485839256085_item	2430247	et	3	main
siis	doc_485839256085_item	2430248	et	3	main
on	doc_485839256085_item	2430249	et	4	main
lehmad	doc_485839256085_item	2430250	et	3	main
ильин	doc_485839256085_item	2430257	et	2	main
купалу	doc_485839256085_item	2430263	et	2	main
lükata	doc_485839256085_item	2430274	et	4	main
vette	doc_485839256085_item	2430278	et	3	main
eest	doc_485839256085_item	2430285	et	4	main
viitab	doc_485839256085_item	2430288	et	3	main
juurtele	doc_485839256085_item	2430292	et	3	main
sümboliseeris	doc_485839256085_item	2430298	et	4	main
suvehooaja	doc_485839256085_item	2430299	et	3	main
lõppu	doc_485839256085_item	2430300	et	4	main
laialt	doc_485839256085_item	2430301	et	4	main
on	doc_485839256085_item	2430302	et	4	main
levinud	doc_485839256085_item	2430303	et	4	main
uskumus	doc_485839256085_item	2430304	et	3	main
et	doc_485839256085_item	2430305	et	3	main
pärast	doc_485839256085_item	2430306	et	4	main
olevipäeva	doc_485839256085_item	2430307	et	4	main
avatud	doc_485839256085_item	2430308	et	4	main
vetes	doc_485839256085_item	2430309	et	3	main
ujuda	doc_485839256085_item	2430310	et	3	main
ei	doc_485839256085_item	2430311	et	4	main
tohi	doc_485839256085_item	2430312	et	4	main
kuna	doc_485839256085_item	2430313	et	3	main
jumal	doc_485839256085_item	2430314	et	3	main
on	doc_485839256085_item	2430315	et	4	main
vette	doc_485839256085_item	2430316	et	3	main
külma	doc_485839256085_item	2430317	et	4	main
kivi	doc_485839256085_item	2430318	et	4	main
visanud	doc_485839256085_item	2430319	et	4	main
pühi	doc_485839256085_item	2430320	et	4	main
aasta	doc_485839256085_item	2430322	et	4	main
kärarikkalt	doc_485839256085_item	2430326	et	4	main
lõbusalt	doc_485839256085_item	2430328	et	4	main
külla	doc_485839256085_item	2430333	et	4	main
kutsuda	doc_485839256085_item	2430334	et	3	main
ka	doc_485839256085_item	2430335	et	3	main
võõraid	doc_485839256085_item	2430336	et	3	main
peole	doc_485839256085_item	2430340	et	4	main
naaberküladest	doc_485839256085_item	2430342	et	3	main
selleks	doc_485839256085_item	2430343	et	4	main
külalislahked	doc_485839256085_item	2430352	et	3	main
piirissaare	doc_485839256085_item	2430357	et	3	main
petrovki	doc_485839256085_item	2430361	et	4	main
siia	doc_485839256085_item	2430363	et	4	main
kutsimattagi	doc_485839256085_item	2430365	et	4	main
tulla	doc_485839256085_item	2430366	et	3	main
noorte	doc_485839256085_item	2430367	et	3	main
söömisega	doc_485839256085_item	2430375	et	4	main
madisepäev	doc_485839256085_item	2430376	et	3	main
riietes	doc_485839256085_item	2430296	et	3	main
ujumine	doc_485839256085_item	2430297	et	4	main
eriti	doc_485839256085_item	2430321	et	3	main
peipsimaal	doc_485839256085_item	2430325	et	4	main
oli	doc_485839256085_item	2430330	et	3	main
koju	doc_485839256085_item	2430332	et	3	main
juba	doc_485839256085_item	2430347	et	3	main
mandrist	doc_485839256085_item	2430354	et	4	main
elanikud	doc_485839256085_item	2430358	et	3	main
maslenitsa	doc_485839256085_item	2430370	et	4	main
lõbusa	doc_485839256085_item	2430371	et	3	main
karnevali	doc_485839256085_item	2430372	et	4	main
ja	doc_485839256085_item	2430373	et	3	main
vana	doc_485839256085_item	2430379	et	4	main
vana	doc_485839256085_item	2430387	et	4	main
ja	doc_485839256085_item	2430395	et	3	main
tembud	doc_485839256085_item	2430396	et	3	main
üle	doc_485839256085_item	2430408	et	3	main
noorte	doc_485839256085_item	2430421	et	3	main
väga	doc_485839256085_item	2430428	et	3	main
venemaa	doc_485839256085_item	2430437	et	4	main
ümber	doc_485839256085_item	2430456	et	3	main
ja	doc_485839256085_item	2430458	et	3	main
väravad	doc_485839256085_item	2430463	et	3	main
märatsemised	doc_485839256085_item	2430471	et	4	main
võtsid	doc_485839256085_item	2430472	et	4	main
kollektiivseid	doc_485839256085_item	2430479	et	3	main
pingutusi	doc_485839256085_item	2430480	et	4	main
poisid	doc_485839256085_item	2430481	et	4	main
veel	doc_485839256085_item	2430521	et	4	main
kokku	doc_485839256085_item	2430541	et	3	main
novgorodlaste	doc_485839256085_item	2430554	et	4	main
meelismängudega	doc_485839256085_item	2430555	et	3	main
rahval	doc_485839256085_item	2430557	et	3	main
peod	doc_485839256085_item	2430561	et	4	main
meelelahutused	doc_485839256085_item	2430563	et	4	main
nime	doc_485839256085_item	2430577	et	4	main
saatel	doc_485839256085_item	2430588	et	4	main
erirõivastes	doc_485839256085_item	2430589	et	4	main
ja	doc_485839256085_item	2430590	et	3	main
läikivates	doc_485839256085_item	2430591	et	4	main
kiivrites	doc_485839256085_item	2430592	et	3	main
olid	doc_485839256085_item	2430339	et	4	main
tulnud	doc_485839256085_item	2430341	et	4	main
kodudes	doc_485839256085_item	2430346	et	3	main
lauad	doc_485839256085_item	2430349	et	3	main
eriti	doc_485839256085_item	2430351	et	3	main
lõigatud	doc_485839256085_item	2430356	et	4	main
suvisel	doc_485839256085_item	2430359	et	4	main
pannkookide	doc_485839256085_item	2430374	et	3	main
ja	doc_485839256085_item	2430377	et	3	main
mil	doc_485839256085_item	2430382	et	4	main
uue	doc_485839256085_item	2430384	et	3	main
aasta	doc_485839256085_item	2430385	et	4	main
päeval	doc_485839256085_item	2430391	et	3	main
olid	doc_485839256085_item	2430392	et	4	main
suhtusid	doc_485839256085_item	2430398	et	4	main
tüdrukute	doc_485839256085_item	2430401	et	4	main
sallivalt	doc_485839256085_item	2430403	et	4	main
nooruses	doc_485839256085_item	2430404	et	4	main
nalja	doc_485839256085_item	2430410	et	4	main
vaatas	doc_485839256085_item	2430413	et	3	main
kartlikult	doc_485839256085_item	2430415	et	4	main
olles	doc_485839256085_item	2430419	et	3	main
valmis	doc_485839256085_item	2430420	et	4	main
tempudeks	doc_485839256085_item	2430422	et	3	main
uusi	doc_485839256085_item	2430431	et	3	main
põhja	doc_485839256085_item	2430438	et	4	main
korstnad	doc_485839256085_item	2430448	et	4	main
topiti	doc_485839256085_item	2430449	et	3	main
öösiti	doc_485839256085_item	2430450	et	4	main
põhuga	doc_485839256085_item	2430451	et	3	main
või	doc_485839256085_item	2430452	et	4	main
tarad	doc_485839256085_item	2430457	et	3	main
otsa	doc_485839256085_item	2430467	et	4	main
vahel	doc_485839256085_item	2430473	et	4	main
ära	doc_485839256085_item	2430483	et	4	main
viisid	doc_485839256085_item	2430486	et	4	main
naaberküla	doc_485839256085_item	2430537	et	4	main
seotud	doc_485839256085_item	2430550	et	4	main
rituaalsete	doc_485839256085_item	2430551	et	3	main
rusikavõitlustega	doc_485839256085_item	2430552	et	3	main
iidsete	doc_485839256085_item	2430553	et	3	main
peipsimaa	doc_485839256085_item	2430556	et	4	main
teistes	doc_485839256085_item	2430568	et	4	main
mis	doc_485839256085_item	2430575	et	4	main
terve	doc_485839256085_item	2430596	et	4	main
tuletõrjesalkade	doc_485839256085_item	2430621	et	3	main
selle	doc_485839256085_item	2430627	et	4	main
vooliku	doc_485839256085_item	2430634	et	3	main
kustutab	doc_485839256085_item	2430641	et	3	main
pidu	doc_485839256085_item	2430653	et	4	main
ja	doc_485839256085_item	2430672	et	3	main
rahvalaule	doc_485839256085_item	2430674	et	4	main
koraldada	doc_485839256085_item	2430680	et	4	main
ülestõusmispüha	doc_485839256085_item	2430681	et	4	main
ajal	doc_485839256085_item	2430682	et	4	main
pidusaiade	doc_485839256085_item	2430683	et	3	main
juba	doc_485839256085_item	2430690	et	3	main
2006	doc_485839256085_item	2430706	et	2	main
kirja	doc_485839256085_item	2430711	et	4	main
pandud	doc_485839256085_item	2430712	et	4	main
tüüpi	doc_485839256085_item	2430714	et	4	main
lood	doc_485839256085_item	2430715	et	4	main
järve	doc_485839256085_item	2430723	et	4	main
olid	doc_485839256085_item	2430726	et	4	main
üks	doc_485839256085_item	2430728	et	3	main
konkreetne	doc_485839256085_item	2430729	et	3	main
mees	doc_485839256085_item	2430730	et	4	main
istutanud	doc_485839256085_item	2430736	et	4	main
mehe	doc_485839256085_item	2430738	et	3	main
nime	doc_485839256085_item	2430739	et	4	main
ja	doc_485839256085_item	2430740	et	3	main
teo	doc_485839256085_item	2430741	et	4	main
et	doc_485839256085_item	2430773	et	3	main
linnakestes	doc_485839256085_item	2430778	et	4	main
t	doc_485839256085_item	2430818	et	4	main
algust	doc_485839256085_item	2430386	et	4	main
lubatud	doc_485839256085_item	2430393	et	4	main
naljad	doc_485839256085_item	2430394	et	3	main
poiste	doc_485839256085_item	2430399	et	3	main
hommikuti	doc_485839256085_item	2430412	et	4	main
ka	doc_485839256085_item	2430430	et	3	main
tuli	doc_485839256085_item	2430432	et	4	main
pidevalt	doc_485839256085_item	2430433	et	4	main
juurde	doc_485839256085_item	2430434	et	4	main
ja	doc_485839256085_item	2430439	et	3	main
kubermangu	doc_485839256085_item	2430441	et	4	main
külades	doc_485839256085_item	2430443	et	3	main
lükati	doc_485839256085_item	2430455	et	4	main
paadid	doc_485839256085_item	2430460	et	3	main
jms	doc_485839256085_item	2430468	et	4	main
ootamatuid	doc_485839256085_item	2430474	et	4	main
vorme	doc_485839256085_item	2430475	et	3	main
esitrepi	doc_485839256085_item	2430485	et	3	main
keldris	doc_485839256085_item	2430487	et	3	main
ka	doc_485839256085_item	2430491	et	3	main
ja	doc_485839256085_item	2430497	et	3	main
sellega	doc_485839256085_item	2430498	et	3	main
korsten	doc_485839256085_item	2430499	et	4	main
katta	doc_485839256085_item	2430500	et	3	main
kord	doc_485839256085_item	2430501	et	4	main
oli	doc_485839256085_item	2430502	et	3	main
isegi	doc_485839256085_item	2430503	et	4	main
rahulikku	doc_485839256085_item	2430504	et	4	main
und	doc_485839256085_item	2430505	et	4	main
magava	doc_485839256085_item	2430506	et	4	main
pererahva	doc_485839256085_item	2430507	et	3	main
sängi	doc_485839256085_item	2430508	et	4	main
külge	doc_485839256085_item	2430509	et	4	main
hobune	doc_485839256085_item	2430510	et	4	main
seotud	doc_485839256085_item	2430511	et	4	main
peipsimaal	doc_485839256085_item	2430512	et	4	main
mäletatakse	doc_485839256085_item	2430513	et	3	main
ka	doc_485839256085_item	2430514	et	3	main
pühade	doc_485839256085_item	2430515	et	3	main
ajal	doc_485839256085_item	2430516	et	4	main
korraldatud	doc_485839256085_item	2430517	et	4	main
võistlusmänge	doc_485839256085_item	2430518	et	3	main
mustvees	doc_485839256085_item	2430519	et	3	main
mäletatakse	doc_485839256085_item	2430520	et	3	main
külade	doc_485839256085_item	2430539	et	3	main
kaklemiseks	doc_485839256085_item	2430542	et	4	main
seina	doc_485839256085_item	2430544	et	4	main
olid	doc_485839256085_item	2430558	et	4	main
ja	doc_485839256085_item	2430562	et	3	main
millel	doc_485839256085_item	2430564	et	3	main
ajal	doc_485839256085_item	2430571	et	4	main
korraldati	doc_485839256085_item	2430572	et	3	main
said	doc_485839256085_item	2430576	et	4	main
õhtud	doc_485839256085_item	2430579	et	3	main
oli	doc_485839256085_item	2430581	et	3	main
mainitud	doc_485839256085_item	2430583	et	4	main
kallaste	doc_485839256085_item	2430584	et	4	main
mehed	doc_485839256085_item	2430594	et	3	main
kes	doc_485839256085_item	2430630	et	4	main
järveni	doc_485839256085_item	2430637	et	3	main
ja	doc_485839256085_item	2430638	et	3	main
abil	doc_485839256085_item	2430640	et	4	main
kuidas	doc_485839256085_item	2430522	et	3	main
ajal	doc_485839256085_item	2430524	et	4	main
lumelinnust	doc_485839256085_item	2430526	et	4	main
ja	doc_485839256085_item	2430527	et	3	main
poisid	doc_485839256085_item	2430538	et	4	main
on	doc_485839256085_item	2430548	et	4	main
oletatavasti	doc_485839256085_item	2430549	et	3	main
omad	doc_485839256085_item	2430560	et	4	main
regioonides	doc_485839256085_item	2430569	et	3	main
talvistepühade	doc_485839256085_item	2430570	et	4	main
istjaid	doc_485839256085_item	2430574	et	4	main
tee	doc_485839256085_item	2430578	et	4	main
ülalpool	doc_485839256085_item	2430580	et	3	main
juba	doc_485839256085_item	2430582	et	3	main
tuleturjutate	doc_485839256085_item	2430585	et	4	main
festivali	doc_485839256085_item	2430586	et	4	main
puhkpilliorkestri	doc_485839256085_item	2430587	et	3	main
marsisid	doc_485839256085_item	2430593	et	4	main
lipu	doc_485839256085_item	2430598	et	3	main
all	doc_485839256085_item	2430599	et	3	main
võidu	doc_485839256085_item	2430604	et	4	main
eest	doc_485839256085_item	2430605	et	4	main
tuletõrjujate	doc_485839256085_item	2430606	et	3	main
kolonni	doc_485839256085_item	2430607	et	4	main
saatis	doc_485839256085_item	2430608	et	3	main
vaimustusest	doc_485839256085_item	2430609	et	4	main
säravate	doc_485839256085_item	2430610	et	4	main
silmadega	doc_485839256085_item	2430611	et	3	main
poistesalk	doc_485839256085_item	2430612	et	3	main
pidustustes	doc_485839256085_item	2430613	et	3	main
osalesid	doc_485839256085_item	2430614	et	4	main
ka	doc_485839256085_item	2430615	et	3	main
ametivennad	doc_485839256085_item	2430616	et	3	main
mustveest	doc_485839256085_item	2430617	et	4	main
traditsiooniks	doc_485839256085_item	2430618	et	3	main
oli	doc_485839256085_item	2430619	et	3	main
korraldada	doc_485839256085_item	2430620	et	3	main
võistlusi	doc_485839256085_item	2430622	et	3	main
ja	doc_485839256085_item	2430625	et	3	main
selle	doc_485839256085_item	2430636	et	4	main
kohalikus	doc_485839256085_item	2430646	et	4	main
pühakojas	doc_485839256085_item	2430647	et	3	main
milles	doc_485839256085_item	2430654	et	3	main
praktiliselt	doc_485839256085_item	2430656	et	4	main
rahvas	doc_485839256085_item	2430659	et	4	main
esitati	doc_485839256085_item	2430673	et	4	main
viimastel	doc_485839256085_item	2430675	et	3	main
isetehtud	doc_485839256085_item	2430692	et	3	main
võistlust	doc_485839256085_item	2430695	et	3	main
tekkes	doc_485839256085_item	2430705	et	3	main
inimeselt	doc_485839256085_item	2430710	et	3	main
pajatasid	doc_485839256085_item	2430717	et	4	main
kuidas	doc_485839256085_item	2430718	et	3	main
puhtad	doc_485839256085_item	2430720	et	3	main
liivased	doc_485839256085_item	2430721	et	4	main
liivaranda	doc_485839256085_item	2430735	et	4	main
põhjust	doc_485839256085_item	2430742	et	4	main
mees	doc_485839256085_item	2430748	et	4	main
tegi	doc_485839256085_item	2430757	et	4	main
seda	doc_485839256085_item	2430758	et	3	main
detailide	doc_485839256085_item	2430769	et	3	main
peipsiääre	doc_485839256085_item	2430774	et	3	main
külades	doc_485839256085_item	2430776	et	3	main
tulekahju	doc_485839256085_item	2430624	et	4	main
võisteldi	doc_485839256085_item	2430626	et	3	main
kiiremini	doc_485839256085_item	2430631	et	4	main
rullib	doc_485839256085_item	2430632	et	3	main
lahti	doc_485839256085_item	2430633	et	4	main
ja	doc_485839256085_item	2430648	et	3	main
algas	doc_485839256085_item	2430651	et	3	main
mustvees	doc_485839256085_item	2430660	et	3	main
enne	doc_485839256085_item	2430661	et	4	main
teist	doc_485839256085_item	2430662	et	4	main
maailmasõda	doc_485839256085_item	2430663	et	4	main
traditsiooniks	doc_485839256085_item	2430664	et	3	main
oli	doc_485839256085_item	2430665	et	3	main
tähistada	doc_485839256085_item	2430666	et	3	main
vene	doc_485839256085_item	2430667	et	4	main
valgustuspäeva	doc_485839256085_item	2430668	et	4	main
kus	doc_485839256085_item	2430669	et	3	main
demonstreeriti	doc_485839256085_item	2430670	et	3	main
rahvarõivaid	doc_485839256085_item	2430671	et	3	main
tõmbab	doc_485839256085_item	2430635	et	3	main
käsipumba	doc_485839256085_item	2430639	et	3	main
pärast	doc_485839256085_item	2430649	et	4	main
osales	doc_485839256085_item	2430655	et	3	main
aastatel	doc_485839256085_item	2430676	et	4	main
on	doc_485839256085_item	2430677	et	4	main
kuliš	doc_485839256085_item	2430684	et	2	main
ja	doc_485839256085_item	2430685	et	3	main
pühademunade	doc_485839256085_item	2430686	et	3	main
konkurss	doc_485839256085_item	2430687	et	3	main
ülalpool	doc_485839256085_item	2430688	et	3	main
oli	doc_485839256085_item	2430689	et	3	main
ja	doc_485839256085_item	2430702	et	3	main
rahvaanekdootide	doc_485839256085_item	2430704	et	3	main
aastal	doc_485839256085_item	2430707	et	3	main
rannad	doc_485839256085_item	2430724	et	3	main
pilliroopõõsast	doc_485839256085_item	2430733	et	4	main
kuid	doc_485839256085_item	2430737	et	4	main
jutustajad	doc_485839256085_item	2430745	et	4	main
erinevalt	doc_485839256085_item	2430746	et	4	main
üks	doc_485839256085_item	2430747	et	3	main
pardid	doc_485839256085_item	2430763	et	3	main
folkloorisüžee	doc_485839256085_item	2430765	et	2	main
ongi	doc_485839256085_item	2430768	et	4	main
näitab	doc_485839256085_item	2430772	et	3	main
vene	doc_485839256085_item	2430775	et	4	main
ja	doc_485839256085_item	2430777	et	3	main
ei	doc_485839256085_item	2430779	et	4	main
ole	doc_485839256085_item	2430780	et	4	main
sõna	doc_485839256085_item	2430784	et	4	main
eesti	doc_485839256085_item	2430826	et	4	main
keele	doc_485839256085_item	2430827	et	4	main
mitte	doc_485839256085_item	2430846	et	3	main
jt	doc_485839256085_item	2430848	et	4	main
on	doc_485839256085_item	2430857	et	4	main
ä	doc_485839256085_item	2430861	et	4	main
aastate	doc_485839256085_item	2430863	et	3	main
on	doc_485839256085_item	2430871	et	4	main
fikseeritud	doc_485839256085_item	2430872	et	4	main
p	doc_485839256085_item	2430876	et	4	main
rimusjutt	doc_485839256085_item	2430878	et	4	main
kalevipojast	doc_485839256085_item	2430879	et	4	main
hobusest	doc_485839256085_item	2430887	et	4	main
viitab	doc_485839256085_item	2430893	et	3	main
traditsioonile	doc_485839256085_item	2430895	et	3	main
millele	doc_485839256085_item	2430901	et	3	main
ü	doc_485839256085_item	2430904	et	4	main
tulekahju	doc_485839256085_item	2430642	et	4	main
siis	doc_485839256085_item	2430643	et	3	main
peeti	doc_485839256085_item	2430644	et	4	main
jumaleteenistus	doc_485839256085_item	2430645	et	4	main
seda	doc_485839256085_item	2430650	et	3	main
suur	doc_485839256085_item	2430652	et	3	main
kõik	doc_485839256085_item	2430657	et	4	main
kallaste	doc_485839256085_item	2430658	et	4	main
mainitud	doc_485839256085_item	2430691	et	4	main
karakatitsate	doc_485839256085_item	2430694	et	4	main
märgata	doc_485839256085_item	2430696	et	4	main
on	doc_485839256085_item	2430697	et	4	main
tendentsi	doc_485839256085_item	2430698	et	4	main
lõbusate	doc_485839256085_item	2430699	et	3	main
kolmelt	doc_485839256085_item	2430709	et	4	main
üht	doc_485839256085_item	2430713	et	3	main
vanasti	doc_485839256085_item	2430719	et	3	main
saanud	doc_485839256085_item	2430678	et	4	main
traditsiooniks	doc_485839256085_item	2430679	et	3	main
sõidukite	doc_485839256085_item	2430693	et	3	main
tõsieluloode	doc_485839256085_item	2430700	et	4	main
folkloriseerimises	doc_485839256085_item	2430701	et	3	main
kaasaegse	doc_485839256085_item	2430703	et	3	main
sai	doc_485839256085_item	2430708	et	4	main
mis	doc_485839256085_item	2430716	et	4	main
peipsi	doc_485839256085_item	2430722	et	4	main
pidavat	doc_485839256085_item	2430731	et	4	main
kaks-kolm	doc_485839256085_item	2430732	et	3	main
tegi	doc_485839256085_item	2430749	et	4	main
seda	doc_485839256085_item	2430750	et	3	main
ilu	doc_485839256085_item	2430751	et	4	main
pärast	doc_485839256085_item	2430752	et	4	main
teine	doc_485839256085_item	2430753	et	3	main
aga	doc_485839256085_item	2430754	et	3	main
kirglik	doc_485839256085_item	2430755	et	3	main
jahimees	doc_485839256085_item	2430756	et	4	main
tunnuseks	doc_485839256085_item	2430767	et	3	main
varieerimine	doc_485839256085_item	2430770	et	4	main
veel	doc_485839256085_item	2430782	et	4	main
viimast	doc_485839256085_item	2430783	et	4	main
riistade	doc_485839256085_item	2430820	et	3	main
ja	doc_485839256085_item	2430821	et	3	main
nimetustes	doc_485839256085_item	2430823	et	4	main
õ	doc_485839256085_item	2430829	et	4	main
nede	doc_485839256085_item	2430834	et	4	main
õ	doc_485839256085_item	2430836	et	4	main
nade	doc_485839256085_item	2430837	et	4	main
foneetilises	doc_485839256085_item	2430838	et	3	main
baptist	doc_485839256085_item	2430843	et	3	main
õ	doc_485839256085_item	2430853	et	4	main
ju	doc_485839256085_item	2430854	et	3	main
vanausuliste	doc_485839256085_item	2430855	et	4	main
l	doc_485839256085_item	2430860	et	4	main
bi	doc_485839256085_item	2430862	et	4	main
pandud	doc_485839256085_item	2430869	et	4	main
materjalides	doc_485839256085_item	2430870	et	3	main
ü	doc_485839256085_item	2430874	et	4	main
heitnud	doc_485839256085_item	2430881	et	4	main
ra	doc_485839256085_item	2430890	et	4	main
p	doc_485839256085_item	2430897	et	4	main
rimusjutt	doc_485839256085_item	2430899	et	4	main
olevat	doc_485839256085_item	2430902	et	4	main
mnes	doc_485839256085_item	2430905	et	4	main
eestlastelt	doc_485839256085_item	2430922	et	4	main
k	doc_485839256085_item	2430930	et	4	main
esimesest	doc_485839256085_item	2430933	et	3	main
õ	doc_485839256085_item	2430938	et	4	main
et	doc_485839256085_item	2430940	et	3	main
just	doc_485839256085_item	2430941	et	3	main
ü	doc_485839256085_item	2430946	et	4	main
ht	doc_485839256085_item	2430947	et	4	main
informaatorid	doc_485839256085_item	2430952	et	3	main
ks	doc_485839256085_item	2430956	et	4	main
nneks	doc_485839256085_item	2430970	et	4	main
ä	doc_485839256085_item	2430972	et	4	main
õ	doc_485839256085_item	2430981	et	4	main
kasu	doc_485839256085_item	2431003	et	4	main
veenvam	doc_485839256085_item	2431007	et	4	main
ä	doc_485839256085_item	2431014	et	4	main
gu	doc_485839256085_item	2431015	et	4	main
kukkumine	doc_485839256085_item	2431016	et	4	main
ennustab	doc_485839256085_item	2431018	et	3	main
iii	doc_485839256085_item	2431028	et	4	main
39	doc_485839256085_item	2431029	et	2	main
on	doc_485839256085_item	2431034	et	4	main
re	doc_485839256085_item	2431037	et	4	main
lades	doc_485839256085_item	2431040	et	3	main
komme	doc_485839256085_item	2431044	et	4	main
ja	doc_485839256085_item	2431057	et	3	main
руши	doc_485839256085_item	2431076	et	2	main
ei	doc_485839256085_item	2431077	et	4	main
ka	doc_485839256085_item	2431079	et	3	main
v	doc_485839256085_item	2431080	et	4	main
le	doc_485839256085_item	2431122	et	4	main
kombe	doc_485839256085_item	2431124	et	4	main
дзiны	doc_485839256085_item	2431131	et	2	main
ausuliste	doc_485839256085_item	2431133	et	4	main
elanud	doc_485839256085_item	2431137	et	4	main
naine	doc_485839256085_item	2431139	et	3	main
pillirootihniku	doc_485839256085_item	2430725	et	3	main
kasvanud	doc_485839256085_item	2430727	et	4	main
тросты	doc_485839256085_item	2430734	et	2	main
pakkusid	doc_485839256085_item	2430743	et	4	main
kõik	doc_485839256085_item	2430744	et	4	main
lootuses	doc_485839256085_item	2430759	et	4	main
et	doc_485839256085_item	2430760	et	3	main
pillirootihnikus	doc_485839256085_item	2430761	et	3	main
hakkavad	doc_485839256085_item	2430762	et	4	main
pesitsema	doc_485839256085_item	2430764	et	3	main
peamiseks	doc_485839256085_item	2430766	et	3	main
mis	doc_485839256085_item	2430771	et	4	main
pärimuskultuur	doc_485839256085_item	2430781	et	4	main
öelnud	doc_485839256085_item	2430785	et	4	main
ü	doc_485839256085_item	2430786	et	4	main
ldjuhul	doc_485839256085_item	2430787	et	4	main
ei	doc_485839256085_item	2430788	et	4	main
õ	doc_485839256085_item	2430789	et	4	main
ppinud	doc_485839256085_item	2430790	et	4	main
vanausulised	doc_485839256085_item	2430791	et	4	main
eesti	doc_485839256085_item	2430792	et	4	main
koolides	doc_485839256085_item	2430793	et	3	main
kuid	doc_485839256085_item	2430794	et	4	main
eesti	doc_485839256085_item	2430795	et	4	main
keelt	doc_485839256085_item	2430796	et	4	main
ja	doc_485839256085_item	2430797	et	3	main
kultuuri	doc_485839256085_item	2430798	et	4	main
tundsid	doc_485839256085_item	2430799	et	4	main
nad	doc_485839256085_item	2430800	et	3	main
h	doc_485839256085_item	2430801	et	4	main
ä	doc_485839256085_item	2430802	et	4	main
sti	doc_485839256085_item	2430803	et	4	main
nende	doc_485839256085_item	2430804	et	4	main
k	doc_485839256085_item	2430805	et	4	main
õ	doc_485839256085_item	2430806	et	4	main
nekeeles	doc_485839256085_item	2430807	et	4	main
on	doc_485839256085_item	2430808	et	4	main
ü	doc_485839256085_item	2430809	et	4	main
pris	doc_485839256085_item	2430810	et	4	main
palju	doc_485839256085_item	2430811	et	4	main
laens	doc_485839256085_item	2430812	et	4	main
õ	doc_485839256085_item	2430813	et	4	main
nu	doc_485839256085_item	2430814	et	4	main
eesti	doc_485839256085_item	2430815	et	4	main
keelest	doc_485839256085_item	2430816	et	4	main
eriti	doc_485839256085_item	2430817	et	3	main
öö	doc_485839256085_item	2430819	et	4	main
samuti	doc_485839256085_item	2430824	et	3	main
on	doc_485839256085_item	2430825	et	4	main
tunda	doc_485839256085_item	2430831	et	3	main
õ	doc_485839256085_item	2430833	et	4	main
s	doc_485839256085_item	2430835	et	4	main
mitte	doc_485839256085_item	2430842	et	3	main
folkloorile	doc_485839256085_item	2430856	et	4	main
tagasihoidlikum	doc_485839256085_item	2430859	et	4	main
k	doc_485839256085_item	2430864	et	4	main
õ	doc_485839256085_item	2430865	et	4	main
igis	doc_485839256085_item	2430866	et	4	main
kokku	doc_485839256085_item	2430867	et	3	main
vaid	doc_485839256085_item	2430873	et	3	main
ä	doc_485839256085_item	2430877	et	4	main
peletanud	doc_485839256085_item	2430891	et	4	main
ka	doc_485839256085_item	2430896	et	3	main
keeles	doc_485839256085_item	2430906	et	4	main
le	doc_485839256085_item	2430925	et	4	main
o	doc_485839256085_item	2430932	et	4	main
kukkumisest	doc_485839256085_item	2430934	et	4	main
variandis	doc_485839256085_item	2430936	et	3	main
fakti	doc_485839256085_item	2430950	et	4	main
interpreteerisit	doc_485839256085_item	2430953	et	4	main
ü	doc_485839256085_item	2430955	et	4	main
õ	doc_485839256085_item	2430969	et	4	main
keskp	doc_485839256085_item	2430971	et	4	main
k	doc_485839256085_item	2430980	et	4	main
aga	doc_485839256085_item	2430986	et	3	main
hea	doc_485839256085_item	2430994	et	4	main
too	doc_485839256085_item	2431002	et	4	main
tshehhi	doc_485839256085_item	2431011	et	4	main
nnetust	doc_485839256085_item	2431021	et	4	main
ä	doc_485839256085_item	2431032	et	4	main
abielunaistel	doc_485839256085_item	2431045	et	3	main
nnitajat	doc_485839256085_item	2431051	et	4	main
tuua	doc_485839256085_item	2431052	et	3	main
pirukaid	doc_485839256085_item	2431053	et	3	main
kingitusi	doc_485839256085_item	2431055	et	4	main
kombe	doc_485839256085_item	2431072	et	4	main
listatud	doc_485839256085_item	2431082	et	4	main
et	doc_485839256085_item	2431083	et	3	main
analoogiline	doc_485839256085_item	2431084	et	4	main
komme	doc_485839256085_item	2431085	et	4	main
oli	doc_485839256085_item	2431086	et	3	main
juba	doc_485839256085_item	2431087	et	3	main
esiasukatel	doc_485839256085_item	2431088	et	4	main
ja	doc_485839256085_item	2431089	et	3	main
ü	doc_485839256085_item	2431121	et	4	main
selle	doc_485839256085_item	2431123	et	4	main
е	doc_485839256085_item	2431130	et	2	main
ü	doc_485839256085_item	2431135	et	4	main
eesti	doc_485839256085_item	2431138	et	4	main
h	doc_485839256085_item	2431141	et	4	main
roosi	doc_485839256085_item	2431145	et	4	main
meelsasti	doc_485839256085_item	2431151	et	3	main
kuid	doc_485839256085_item	2431157	et	4	main
rohkem	doc_485839256085_item	2431158	et	4	main
ää	doc_485839256085_item	2431161	et	4	main
juhustest	doc_485839256085_item	2431163	et	3	main
k	doc_485839256085_item	2431166	et	4	main
ü	doc_485839256085_item	2431174	et	4	main
ka	doc_485839256085_item	2431177	et	3	main
varnja	doc_485839256085_item	2431180	et	4	main
ü	doc_485839256085_item	2431182	et	4	main
tõvesõnad	doc_485839256085_item	2431192	et	3	main
mis	doc_485839256085_item	2431193	et	4	main
on	doc_485839256085_item	2431222	et	4	main
laija	doc_485839256085_item	2431227	et	4	main
kirja	doc_485839256085_item	2431233	et	4	main
ja	doc_485839256085_item	2431240	et	3	main
senini	doc_485839256085_item	2431241	et	3	main
tõsiseks	doc_485839256085_item	2431243	et	4	main
прибалтики	doc_485839256085_item	2431253	et	2	main
raamat	doc_485839256085_item	2431271	et	3	main
sissejuhatavas	doc_485839256085_item	2431276	et	3	main
a	doc_485839256085_item	2431287	et	4	main
rea	doc_485839256085_item	2431294	et	3	main
seaduspärasusi	doc_485839256085_item	2431305	et	4	main
kristlikke	doc_485839256085_item	2431311	et	3	main
puudumise	doc_485839256085_item	2431318	et	4	main
ringtansulaulude	doc_485839256085_item	2431320	et	4	main
m	doc_485839256085_item	2430828	et	4	main
m	doc_485839256085_item	2430832	et	4	main
paptist	doc_485839256085_item	2430840	et	4	main
õ	doc_485839256085_item	2430841	et	4	main
abel	doc_485839256085_item	2430845	et	4	main
avel	doc_485839256085_item	2430847	et	4	main
kuid	doc_485839256085_item	2430849	et	4	main
tunduvalt	doc_485839256085_item	2430858	et	4	main
kirja	doc_485839256085_item	2430868	et	4	main
ks	doc_485839256085_item	2430875	et	4	main
suure	doc_485839256085_item	2430882	et	3	main
kivi	doc_485839256085_item	2430883	et	4	main
ja	doc_485839256085_item	2430884	et	3	main
sellega	doc_485839256085_item	2430885	et	3	main
oma	doc_485839256085_item	2430886	et	4	main
eesti	doc_485839256085_item	2430894	et	4	main
kuvist	doc_485839256085_item	2430900	et	4	main
kiri	doc_485839256085_item	2430907	et	3	main
kirjutatud	doc_485839256085_item	2430908	et	4	main
kes	doc_485839256085_item	2430909	et	4	main
selle	doc_485839256085_item	2430910	et	4	main
kirja	doc_485839256085_item	2430911	et	4	main
l	doc_485839256085_item	2430912	et	4	main
ä	doc_485839256085_item	2430913	et	4	main
bi	doc_485839256085_item	2430914	et	4	main
loeb	doc_485839256085_item	2430915	et	3	main
saab	doc_485839256085_item	2430916	et	3	main
l	doc_485839256085_item	2430917	et	4	main
õ	doc_485839256085_item	2430918	et	4	main
putu	doc_485839256085_item	2430919	et	4	main
aarde	doc_485839256085_item	2430920	et	3	main
omanikuks	doc_485839256085_item	2430921	et	4	main
on	doc_485839256085_item	2430923	et	4	main
ü	doc_485839256085_item	2430924	et	4	main
v	doc_485839256085_item	2430937	et	4	main
p	doc_485839256085_item	2430943	et	4	main
õ	doc_485839256085_item	2430944	et	4	main
kukkub	doc_485839256085_item	2430968	et	4	main
eval	doc_485839256085_item	2430973	et	4	main
materiaalset	doc_485839256085_item	2430975	et	3	main
hommikune	doc_485839256085_item	2430977	et	4	main
kukkumine	doc_485839256085_item	2430978	et	4	main
kuslike	doc_485839256085_item	2430983	et	4	main
teine	doc_485839256085_item	2430984	et	3	main
kuulda	doc_485839256085_item	2430989	et	4	main
k	doc_485839256085_item	2430990	et	4	main
rk	doc_485839256085_item	2430997	et	4	main
õ	doc_485839256085_item	2430998	et	4	main
kukkumine	doc_485839256085_item	2431000	et	4	main
seletus	doc_485839256085_item	2431005	et	4	main
surma	doc_485839256085_item	2431019	et	4	main
hinna	doc_485839256085_item	2431023	et	3	main
ekspeditsiooni	doc_485839256085_item	2431030	et	4	main
k	doc_485839256085_item	2431031	et	4	main
ää	doc_485839256085_item	2431036	et	4	main
ü	doc_485839256085_item	2431039	et	4	main
korduvalt	doc_485839256085_item	2431041	et	4	main
k	doc_485839256085_item	2431046	et	4	main
lastada	doc_485839256085_item	2431048	et	4	main
vasts	doc_485839256085_item	2431058	et	4	main
ndinule	doc_485839256085_item	2431060	et	4	main
on	doc_485839256085_item	2431065	et	4	main
komme	doc_485839256085_item	2431067	et	4	main
kaudselt	doc_485839256085_item	2431069	et	4	main
viitab	doc_485839256085_item	2431070	et	3	main
ka	doc_485839256085_item	2431071	et	3	main
nimetus	doc_485839256085_item	2431073	et	4	main
ole	doc_485839256085_item	2431078	et	4	main
olemasolu	doc_485839256085_item	2431091	et	4	main
tarbeesemete	doc_485839256085_item	2430822	et	3	main
ju	doc_485839256085_item	2430830	et	3	main
vormis	doc_485839256085_item	2430839	et	4	main
õ	doc_485839256085_item	2430844	et	4	main
eesti	doc_485839256085_item	2430850	et	4	main
folkloori	doc_485839256085_item	2430851	et	4	main
m	doc_485839256085_item	2430852	et	4	main
kes	doc_485839256085_item	2430880	et	4	main
hundi	doc_485839256085_item	2430888	et	3	main
ä	doc_485839256085_item	2430889	et	4	main
oletatavasti	doc_485839256085_item	2430892	et	3	main
ä	doc_485839256085_item	2430898	et	4	main
kaheteisk	doc_485839256085_item	2430903	et	4	main
v	doc_485839256085_item	2430926	et	4	main
õ	doc_485839256085_item	2430927	et	4	main
hjusel	doc_485839256085_item	2430945	et	4	main
iga	doc_485839256085_item	2430954	et	4	main
gu	doc_485839256085_item	2430967	et	4	main
ei	doc_485839256085_item	2430979	et	4	main
jutustaja	doc_485839256085_item	2430985	et	4	main
arvab	doc_485839256085_item	2430987	et	3	main
m	doc_485839256085_item	2430995	et	4	main
htune	doc_485839256085_item	2430999	et	4	main
ei	doc_485839256085_item	2431001	et	4	main
tundub	doc_485839256085_item	2431006	et	3	main
leiab	doc_485839256085_item	2431009	et	3	main
kinnitust	doc_485839256085_item	2431010	et	4	main
parallelides	doc_485839256085_item	2431012	et	4	main
k	doc_485839256085_item	2431013	et	4	main
õ	doc_485839256085_item	2431020	et	4	main
ja	doc_485839256085_item	2431022	et	3	main
t	doc_485839256085_item	2431024	et	4	main
õ	doc_485839256085_item	2431025	et	4	main
usu	doc_485839256085_item	2431026	et	4	main
сд	doc_485839256085_item	2431027	et	2	main
igus	doc_485839256085_item	2431033	et	4	main
k	doc_485839256085_item	2431038	et	4	main
fikseeritud	doc_485839256085_item	2431042	et	4	main
ja	doc_485839256085_item	2431054	et	3	main
emale	doc_485839256085_item	2431056	et	3	main
vanausulised	doc_485839256085_item	2431061	et	4	main
et	doc_485839256085_item	2431063	et	3	main
а	doc_485839256085_item	2431075	et	2	main
ä	doc_485839256085_item	2431081	et	4	main
ходить	doc_485839256085_item	2431126	et	2	main
адв	doc_485839256085_item	2431129	et	2	main
ä	doc_485839256085_item	2431142	et	4	main
ravitsejana	doc_485839256085_item	2431146	et	4	main
abi	doc_485839256085_item	2431147	et	4	main
saamiseks	doc_485839256085_item	2431148	et	4	main
öö	doc_485839256085_item	2431153	et	4	main
linnast	doc_485839256085_item	2431179	et	4	main
k	doc_485839256085_item	2431181	et	4	main
las	doc_485839256085_item	2431183	et	4	main
vene	doc_485839256085_item	2431189	et	4	main
olevat	doc_485839256085_item	2431194	et	4	main
nappus	doc_485839256085_item	2431221	et	4	main
etud	doc_485839256085_item	2430928	et	4	main
uskumus	doc_485839256085_item	2430929	et	3	main
ä	doc_485839256085_item	2430931	et	4	main
kahes	doc_485839256085_item	2430935	et	4	main
imalik	doc_485839256085_item	2430939	et	4	main
sellel	doc_485839256085_item	2430942	et	4	main
ja	doc_485839256085_item	2430948	et	3	main
samat	doc_485839256085_item	2430949	et	4	main
erinevad	doc_485839256085_item	2430951	et	4	main
omamoodi	doc_485839256085_item	2430957	et	3	main
ü	doc_485839256085_item	2430958	et	4	main
ks	doc_485839256085_item	2430959	et	4	main
oli	doc_485839256085_item	2430960	et	3	main
veendunud	doc_485839256085_item	2430961	et	4	main
et	doc_485839256085_item	2430962	et	3	main
õ	doc_485839256085_item	2430963	et	4	main
htul	doc_485839256085_item	2430964	et	4	main
k	doc_485839256085_item	2430965	et	4	main
ä	doc_485839256085_item	2430966	et	4	main
toob	doc_485839256085_item	2430974	et	3	main
kahju	doc_485839256085_item	2430976	et	4	main
lba	doc_485839256085_item	2430982	et	4	main
et	doc_485839256085_item	2430988	et	3	main
ä	doc_485839256085_item	2430991	et	4	main
gu	doc_485839256085_item	2430992	et	4	main
kukkumist	doc_485839256085_item	2430993	et	4	main
ä	doc_485839256085_item	2430996	et	4	main
teine	doc_485839256085_item	2431004	et	3	main
kuna	doc_485839256085_item	2431008	et	3	main
loojangul	doc_485839256085_item	2431017	et	3	main
peipsi	doc_485839256085_item	2431035	et	4	main
rituaalne	doc_485839256085_item	2431043	et	3	main
ü	doc_485839256085_item	2431047	et	4	main
s	doc_485839256085_item	2431049	et	4	main
ü	doc_485839256085_item	2431050	et	4	main
ü	doc_485839256085_item	2431059	et	4	main
arvavad	doc_485839256085_item	2431062	et	4	main
see	doc_485839256085_item	2431064	et	3	main
eestlaste	doc_485839256085_item	2431066	et	4	main
millele	doc_485839256085_item	2431068	et	3	main
в	doc_485839256085_item	2431074	et	2	main
selle	doc_485839256085_item	2431090	et	4	main
aitas	doc_485839256085_item	2431092	et	3	main
eestlastel	doc_485839256085_item	2431093	et	4	main
s	doc_485839256085_item	2431094	et	4	main
ä	doc_485839256085_item	2431095	et	4	main
ilitada	doc_485839256085_item	2431096	et	4	main
iidne	doc_485839256085_item	2431097	et	3	main
komme	doc_485839256085_item	2431098	et	4	main
valgevenes	doc_485839256085_item	2431099	et	3	main
vitebski	doc_485839256085_item	2431100	et	4	main
oblastis	doc_485839256085_item	2431101	et	3	main
analoogne	doc_485839256085_item	2431102	et	3	main
ritual	doc_485839256085_item	2431103	et	4	main
on	doc_485839256085_item	2431104	et	4	main
levinud	doc_485839256085_item	2431105	et	4	main
nii	doc_485839256085_item	2431106	et	3	main
valgevene	doc_485839256085_item	2431107	et	4	main
kui	doc_485839256085_item	2431108	et	3	main
vene	doc_485839256085_item	2431109	et	4	main
asulates	doc_485839256085_item	2431110	et	4	main
sealsed	doc_485839256085_item	2431111	et	3	main
vanausulised	doc_485839256085_item	2431112	et	4	main
on	doc_485839256085_item	2431113	et	4	main
samuti	doc_485839256085_item	2431114	et	3	main
v	doc_485839256085_item	2431115	et	4	main
õ	doc_485839256085_item	2431116	et	4	main
tnud	doc_485839256085_item	2431117	et	4	main
p	doc_485839256085_item	2431118	et	4	main
õ	doc_485839256085_item	2431119	et	4	main
liselanikelt	doc_485839256085_item	2431120	et	4	main
nimetuse	doc_485839256085_item	2431125	et	4	main
ответки	doc_485839256085_item	2431128	et	2	main
k	doc_485839256085_item	2431134	et	4	main
tema	doc_485839256085_item	2431149	et	4	main
rdusid	doc_485839256085_item	2431154	et	4	main
ka	doc_485839256085_item	2431155	et	3	main
vanausulised	doc_485839256085_item	2431156	et	4	main
on	doc_485839256085_item	2431159	et	4	main
isid	doc_485839256085_item	2431168	et	3	main
lades	doc_485839256085_item	2431175	et	3	main
kui	doc_485839256085_item	2431176	et	3	main
kaugelt	doc_485839256085_item	2431178	et	4	main
в	doc_485839256085_item	2431127	et	2	main
van	doc_485839256085_item	2431132	et	4	main
las	doc_485839256085_item	2431136	et	4	main
tuntud	doc_485839256085_item	2431144	et	4	main
p	doc_485839256085_item	2431152	et	4	main
r	doc_485839256085_item	2431160	et	4	main
gitud	doc_485839256085_item	2431162	et	4	main
kui	doc_485839256085_item	2431164	et	3	main
ä	doc_485839256085_item	2431167	et	4	main
vanausulistest	doc_485839256085_item	2431169	et	4	main
posijate	doc_485839256085_item	2431170	et	4	main
juurde	doc_485839256085_item	2431171	et	4	main
nii	doc_485839256085_item	2431172	et	3	main
naberk	doc_485839256085_item	2431173	et	4	main
avastatud	doc_485839256085_item	2431184	et	4	main
keles	doc_485839256085_item	2431190	et	4	main
kunagi	doc_485839256085_item	2431195	et	3	main
eesti	doc_485839256085_item	2431197	et	4	main
dialoog	doc_485839256085_item	2431203	et	3	main
ei	doc_485839256085_item	2431204	et	4	main
piirdu	doc_485839256085_item	2431205	et	4	main
folklooriteoste	doc_485839256085_item	2431206	et	3	main
otseste	doc_485839256085_item	2431207	et	3	main
laenudega	doc_485839256085_item	2431208	et	3	main
tähtsat	doc_485839256085_item	2431209	et	3	main
rolli	doc_485839256085_item	2431210	et	4	main
mängib	doc_485839256085_item	2431211	et	3	main
siin	doc_485839256085_item	2431212	et	4	main
ka	doc_485839256085_item	2431213	et	3	main
kontekstuaalne	doc_485839256085_item	2431214	et	4	main
vastasmõju	doc_485839256085_item	2431215	et	4	main
eesti	doc_485839256085_item	2431216	et	4	main
vanausuliste	doc_485839256085_item	2431217	et	4	main
folkloori	doc_485839256085_item	2431218	et	4	main
väljaannete	doc_485839256085_item	2431219	et	3	main
ilmne	doc_485839256085_item	2431220	et	4	main
selle	doc_485839256085_item	2431225	et	4	main
võtmisel	doc_485839256085_item	2431226	et	4	main
teadusringlusesse	doc_485839256085_item	2431228	et	4	main
erandjuhtudel	doc_485839256085_item	2431229	et	3	main
on	doc_485839256085_item	2431230	et	4	main
pandud	doc_485839256085_item	2431234	et	4	main
illustratiivmaterjalina	doc_485839256085_item	2431235	et	4	main
on	doc_485839256085_item	2431245	et	4	main
184241	doc_485839256085_item	2431255	et	2	main
autor	doc_485839256085_item	2431256	et	3	main
50	doc_485839256085_item	2431259	et	2	main
muinasjutu	doc_485839256085_item	2431263	et	3	main
kirja	doc_485839256085_item	2431264	et	4	main
muid	doc_485839256085_item	2431269	et	4	main
žaanre	doc_485839256085_item	2431270	et	2	main
näinud	doc_485839256085_item	2431274	et	4	main
tegi	doc_485839256085_item	2431279	et	4	main
folkloori	doc_485839256085_item	2431301	et	4	main
uurija	doc_485839256085_item	2431308	et	4	main
märkis	doc_485839256085_item	2431309	et	3	main
pärimuste	doc_485839256085_item	2431310	et	4	main
mittetavandilaulude	doc_485839256085_item	2431322	et	4	main
фрнп	doc_485839256085_item	2431325	et	2	main
191	doc_485839256085_item	2431327	et	2	main
omamata	doc_485839256085_item	2431337	et	4	main
kultuuris	doc_485839256085_item	2431351	et	3	main
f	doc_485839256085_item	2431352	et	4	main
oli	doc_485839256085_item	2431140	et	3	main
sti	doc_485839256085_item	2431143	et	4	main
poole	doc_485839256085_item	2431150	et	4	main
eestlased	doc_485839256085_item	2431165	et	3	main
k	doc_485839256085_item	2431185	et	4	main
kirjutatud	doc_485839256085_item	2431191	et	4	main
eestlastelt	doc_485839256085_item	2431199	et	4	main
olnud	doc_485839256085_item	2431223	et	4	main
üksikuid	doc_485839256085_item	2431231	et	4	main
tekste	doc_485839256085_item	2431232	et	3	main
tähtsaimaks	doc_485839256085_item	2431239	et	4	main
ainsaks	doc_485839256085_item	2431242	et	3	main
publikatsiooniks	doc_485839256085_item	2431244	et	3	main
населения	doc_485839256085_item	2431252	et	2	main
valinud	doc_485839256085_item	2431258	et	4	main
laulu	doc_485839256085_item	2431260	et	4	main
ja	doc_485839256085_item	2431261	et	3	main
1	doc_485839256085_item	2431262	et	2	main
folkloori	doc_485839256085_item	2431268	et	4	main
autor	doc_485839256085_item	2431278	et	3	main
katse	doc_485839256085_item	2431280	et	4	main
või	doc_485839256085_item	2431282	et	4	main
beloussov	doc_485839256085_item	2431288	et	4	main
kirjeldas	doc_485839256085_item	2431289	et	3	main
kaadrist	doc_485839256085_item	2431290	et	3	main
välja	doc_485839256085_item	2431291	et	4	main
parameetrite	doc_485839256085_item	2431295	et	4	main
muu	doc_485839256085_item	2431306	et	4	main
legendide	doc_485839256085_item	2431312	et	3	main
värsside	doc_485839256085_item	2431315	et	3	main
täieliku	doc_485839256085_item	2431317	et	3	main
rahvaluules	doc_485839256085_item	2431319	et	4	main
ä	doc_485839256085_item	2431186	et	4	main
sikirjas	doc_485839256085_item	2431187	et	4	main
oli	doc_485839256085_item	2431188	et	3	main
saadud	doc_485839256085_item	2431196	et	4	main
kodust	doc_485839256085_item	2431198	et	4	main
nii	doc_485839256085_item	2431200	et	3	main
et	doc_485839256085_item	2431201	et	3	main
kultuuridevaheline	doc_485839256085_item	2431202	et	4	main
takistuseks	doc_485839256085_item	2431224	et	4	main
keele-	doc_485839256085_item	2431236	et	4	main
ja	doc_485839256085_item	2431237	et	3	main
ajaloouuringutes	doc_485839256085_item	2431238	et	3	main
фрнп	doc_485839256085_item	2431254	et	2	main
pandud	doc_485839256085_item	2431265	et	4	main
ei	doc_485839256085_item	2431273	et	4	main
sisukas	doc_485839256085_item	2431275	et	4	main
artiklis	doc_485839256085_item	2431277	et	3	main
žaanre	doc_485839256085_item	2431293	et	2	main
võrdles	doc_485839256085_item	2431297	et	3	main
ja	doc_485839256085_item	2431299	et	3	main
õigeusuliste	doc_485839256085_item	2431300	et	4	main
hulgas	doc_485839256085_item	2431307	et	4	main
ja	doc_485839256085_item	2431313	et	3	main
kogumise	doc_485839256085_item	2431339	et	4	main
tööoskusi	doc_485839256085_item	2431340	et	3	main
rahva	doc_485839256085_item	2431350	et	3	main
o	doc_485839256085_item	2431360	et	4	main
pahhutinaga	doc_485839256085_item	2431391	et	4	main
kes	doc_485839256085_item	2431392	et	4	main
tundis	doc_485839256085_item	2431393	et	3	main
ja	doc_485839256085_item	2431403	et	3	main
kogumiku	doc_485839256085_item	2431410	et	4	main
aleksandr	doc_485839256085_item	2431246	et	4	main
beloussovi	doc_485839256085_item	2431247	et	4	main
materjal	doc_485839256085_item	2431248	et	3	main
kogumikus	doc_485839256085_item	2431249	et	4	main
фольклор	doc_485839256085_item	2431250	et	2	main
русского	doc_485839256085_item	2431251	et	2	main
on	doc_485839256085_item	2431257	et	4	main
peipsimaa	doc_485839256085_item	2431266	et	4	main
vanausulistelt	doc_485839256085_item	2431267	et	4	main
ette	doc_485839256085_item	2431272	et	4	main
kas	doc_485839256085_item	2431281	et	3	main
osaliselt	doc_485839256085_item	2431283	et	4	main
korvata	doc_485839256085_item	2431284	et	4	main
see	doc_485839256085_item	2431285	et	3	main
lünk	doc_485839256085_item	2431286	et	3	main
jäänud	doc_485839256085_item	2431292	et	4	main
alusel	doc_485839256085_item	2431296	et	4	main
vanausuliste	doc_485839256085_item	2431298	et	4	main
avastas	doc_485839256085_item	2431302	et	3	main
rida	doc_485839256085_item	2431303	et	4	main
huvipakkuvaid	doc_485839256085_item	2431304	et	3	main
vaimulike	doc_485839256085_item	2431314	et	3	main
peaaegu	doc_485839256085_item	2431316	et	3	main
ülekaalu	doc_485839256085_item	2431321	et	4	main
seotust	doc_485839256085_item	2431323	et	4	main
kalendritavanditele	doc_485839256085_item	2431324	et	3	main
183	doc_485839256085_item	2431326	et	2	main
196	doc_485839256085_item	2431328	et	2	main
tuleb	doc_485839256085_item	2431329	et	3	main
ära	doc_485839256085_item	2431330	et	4	main
folkloori	doc_485839256085_item	2431338	et	4	main
kihti	doc_485839256085_item	2431349	et	4	main
v	doc_485839256085_item	2431356	et	4	main
jegorov	doc_485839256085_item	2431357	et	4	main
jogener	doc_485839256085_item	2431359	et	4	main
peipsi	doc_485839256085_item	2431364	et	4	main
ääre	doc_485839256085_item	2431365	et	3	main
siin	doc_485839256085_item	2431369	et	4	main
suurepäraselt	doc_485839256085_item	2431394	et	4	main
ennustusi	doc_485839256085_item	2431400	et	4	main
humoristliku	doc_485839256085_item	2431405	et	3	main
rahvalaule	doc_485839256085_item	2431408	et	4	main
mustvee	doc_485839256085_item	2431421	et	3	main
määral	doc_485839256085_item	2431432	et	3	main
huvi	doc_485839256085_item	2431438	et	4	main
on	doc_485839256085_item	2431440	et	4	main
uurimisel	doc_485839256085_item	2431454	et	4	main
viimased	doc_485839256085_item	2431491	et	3	main
kogumistöö	doc_485839256085_item	2431494	et	4	main
regioonis	doc_485839256085_item	2431496	et	3	main
kogumik	doc_485839256085_item	2431514	et	3	main
liikmete	doc_485839256085_item	2431519	et	3	main
poolt	doc_485839256085_item	2431520	et	4	main
mineviku	doc_485839256085_item	2431334	et	3	main
suutsid	doc_485839256085_item	2431341	et	4	main
nad	doc_485839256085_item	2431342	et	3	main
siiski	doc_485839256085_item	2431343	et	4	main
üpris	doc_485839256085_item	2431344	et	3	main
täpselt	doc_485839256085_item	2431345	et	4	main
fikseerida	doc_485839256085_item	2431346	et	3	main
mitu	doc_485839256085_item	2431347	et	4	main
brandt	doc_485839256085_item	2431361	et	4	main
uurisid	doc_485839256085_item	2431362	et	4	main
avastasid	doc_485839256085_item	2431368	et	4	main
folklooritraditsiooni	doc_485839256085_item	2431371	et	4	main
kandjaid	doc_485839256085_item	2431372	et	4	main
kirjeldasid	doc_485839256085_item	2431373	et	4	main
selle	doc_485839256085_item	2431374	et	4	main
traditsiooni	doc_485839256085_item	2431375	et	4	main
erinevaid	doc_485839256085_item	2431376	et	4	main
külgi	doc_485839256085_item	2431377	et	4	main
erilist	doc_485839256085_item	2431378	et	4	main
tähelepanu	doc_485839256085_item	2431379	et	4	main
väärivad	doc_485839256085_item	2431380	et	4	main
olga	doc_485839256085_item	2431381	et	4	main
gildebrandti	doc_485839256085_item	2431382	et	4	main
kirjapanekud	doc_485839256085_item	2431383	et	3	main
aastal	doc_485839256085_item	2431384	et	3	main
1949	doc_485839256085_item	2431385	et	2	main
õnnestus	doc_485839256085_item	2431386	et	4	main
temal	doc_485839256085_item	2431387	et	3	main
kohtuda	doc_485839256085_item	2431388	et	3	main
kallastes	doc_485839256085_item	2431389	et	4	main
märkida	doc_485839256085_item	2431331	et	4	main
ka	doc_485839256085_item	2431332	et	3	main
kaugema	doc_485839256085_item	2431333	et	4	main
kogujaid	doc_485839256085_item	2431335	et	4	main
tihtipeale	doc_485839256085_item	2431336	et	3	main
kronoloogilist	doc_485839256085_item	2431348	et	4	main
konjaev	doc_485839256085_item	2431353	et	4	main
vanausuliste	doc_485839256085_item	2431366	et	4	main
kümneid	doc_485839256085_item	2431370	et	4	main
laule	doc_485839256085_item	2431402	et	4	main
antud	doc_485839256085_item	2431409	et	4	main
pärliks	doc_485839256085_item	2431412	et	4	main
just	doc_485839256085_item	2431414	et	3	main
temalt	doc_485839256085_item	2431415	et	3	main
kirja	doc_485839256085_item	2431416	et	4	main
pandud	doc_485839256085_item	2431417	et	4	main
tekstid	doc_485839256085_item	2431418	et	3	main
küsitlesid	doc_485839256085_item	2431425	et	4	main
oma	doc_485839256085_item	2431427	et	4	main
rahvatraditsioonide	doc_485839256085_item	2431429	et	3	main
teatud	doc_485839256085_item	2431431	et	4	main
tulemused	doc_485839256085_item	2431435	et	3	main
teaduslikku	doc_485839256085_item	2431437	et	4	main
ka	doc_485839256085_item	2431439	et	3	main
ülikooli	doc_485839256085_item	2431457	et	4	main
üliõpilased	doc_485839256085_item	2431458	et	3	main
kes	doc_485839256085_item	2431459	et	4	main
töötasid	doc_485839256085_item	2431460	et	4	main
üliõpilaste	doc_485839256085_item	2431464	et	4	main
pandud	doc_485839256085_item	2431467	et	4	main
et	doc_485839256085_item	2431490	et	3	main
oli	doc_485839256085_item	2431493	et	3	main
selles	doc_485839256085_item	2431495	et	4	main
2006	doc_485839256085_item	2431499	et	2	main
aastal	doc_485839256085_item	2431500	et	3	main
eesti	doc_485839256085_item	2431501	et	4	main
sai	doc_485839256085_item	2431509	et	4	main
korraldatud	doc_485839256085_item	2431510	et	4	main
meil	doc_485839256085_item	2431523	et	4	main
õnnestus	doc_485839256085_item	2431524	et	4	main
saavad	doc_485839256085_item	2431535	et	4	main
kogumistöö	doc_485839256085_item	2431540	et	4	main
need	doc_485839256085_item	2431544	et	3	main
põhjustel	doc_485839256085_item	2431548	et	3	main
eelmiste	doc_485839256085_item	2431550	et	3	main
kogujate	doc_485839256085_item	2431551	et	4	main
vaimilikud	doc_485839256085_item	2431561	et	4	main
värsid	doc_485839256085_item	2431562	et	3	main
kristlikud	doc_485839256085_item	2431563	et	3	main
legendid	doc_485839256085_item	2431564	et	3	main
pere	doc_485839256085_item	2431567	et	4	main
eeskätt	doc_485839256085_item	2431577	et	3	main
kadunud	doc_485839256085_item	2431583	et	4	main
ekspeditsiooni	doc_485839256085_item	2431588	et	4	main
on	doc_485839256085_item	2431597	et	4	main
tänapäeval	doc_485839256085_item	2431599	et	3	main
kohalike	doc_485839256085_item	2431603	et	4	main
elanike	doc_485839256085_item	2431604	et	3	main
elus	doc_485839256085_item	2431605	et	4	main
ja	doc_485839256085_item	2431606	et	3	main
väärib	doc_485839256085_item	2431607	et	3	main
aastaid	doc_485839256085_item	2431617	et	4	main
tööpõlluks	doc_485839256085_item	2431619	et	3	main
o	doc_485839256085_item	2431354	et	4	main
gromov	doc_485839256085_item	2431355	et	4	main
o	doc_485839256085_item	2431358	et	4	main
põhjalikult	doc_485839256085_item	2431363	et	4	main
külasi	doc_485839256085_item	2431367	et	4	main
lüürilisi	doc_485839256085_item	2431401	et	3	main
sisuga	doc_485839256085_item	2431406	et	3	main
tõeliseks	doc_485839256085_item	2431411	et	4	main
aasatal	doc_485839256085_item	2431419	et	4	main
1930	doc_485839256085_item	2431420	et	2	main
algkooli	doc_485839256085_item	2431423	et	4	main
kirjalikult	doc_485839256085_item	2431426	et	4	main
õpilasi	doc_485839256085_item	2431428	et	3	main
teemal	doc_485839256085_item	2431430	et	3	main
nad	doc_485839256085_item	2431441	et	3	main
kajastatud	doc_485839256085_item	2431442	et	4	main
peipsimaa	doc_485839256085_item	2431451	et	4	main
tartu	doc_485839256085_item	2431456	et	4	main
folklooripraktika	doc_485839256085_item	2431462	et	4	main
poolt	doc_485839256085_item	2431465	et	4	main
kahetsusväärne	doc_485839256085_item	2431489	et	3	main
initsiatiivil	doc_485839256085_item	2431508	et	3	main
antud	doc_485839256085_item	2431513	et	4	main
on	doc_485839256085_item	2431515	et	4	main
kolme	doc_485839256085_item	2431521	et	4	main
60	doc_485839256085_item	2431530	et	2	main
tunni	doc_485839256085_item	2431531	et	3	main
kvaliteetseid	doc_485839256085_item	2431532	et	3	main
helisalvestusi	doc_485839256085_item	2431533	et	3	main
mis	doc_485839256085_item	2431534	et	4	main
eelistuste	doc_485839256085_item	2431541	et	4	main
folkloorižaanrid	doc_485839256085_item	2431545	et	2	main
ja	doc_485839256085_item	2431579	et	3	main
kokkuvõtlikult	doc_485839256085_item	2431587	et	4	main
tõestavad	doc_485839256085_item	2431590	et	4	main
et	doc_485839256085_item	2431591	et	3	main
vene	doc_485839256085_item	2431592	et	4	main
regioonis	doc_485839256085_item	2431596	et	3	main
komponente	doc_485839256085_item	2431602	et	3	main
läänerannik	doc_485839256085_item	2431614	et	3	main
старины	doc_485839256085_item	2431630	et	2	main
бытовая	doc_485839256085_item	2431635	et	2	main
санкт-петербург	doc_485839256085_item	2431639	et	2	main
традиционная	doc_485839256085_item	2431644	et	2	main
отв	doc_485839256085_item	2431656	et	2	main
словарь	doc_485839256085_item	2431661	et	2	main
iii	doc_485839256085_item	2431663	et	4	main
толстая	doc_485839256085_item	2431667	et	2	main
отв	doc_485839256085_item	2431669	et	2	main
славянская	doc_485839256085_item	2431671	et	2	main
фрнп	doc_485839256085_item	2431677	et	2	main
русского	doc_485839256085_item	2431686	et	2	main
summary	doc_485839256085_item	2431691	et	4	main
перевода	doc_485839256085_item	2431693	et	2	main
фольклор	doc_485839256085_item	2431697	et	2	main
представляет	doc_485839256085_item	2431702	et	2	main
традиции	doc_485839256085_item	2431707	et	2	main
длительного	doc_485839256085_item	2431711	et	2	main
здесь	doc_485839256085_item	2431722	et	2	main
они	doc_485839256085_item	2431726	et	2	main
в	doc_485839256085_item	2431731	et	2	main
составляет	doc_485839256085_item	2431736	et	2	main
50	doc_485839256085_item	2431739	et	2	main
аф	doc_485839256085_item	2431744	et	2	main
фольклор	doc_485839256085_item	2431749	et	2	main
москва	doc_485839256085_item	2431753	et	2	main
из	doc_485839256085_item	2431756	et	2	main
мере	doc_485839256085_item	2431762	et	2	main
читателей	doc_485839256085_item	2431767	et	2	main
и	doc_485839256085_item	2431772	et	2	main
этого	doc_485839256085_item	2431776	et	2	main
лучшие	doc_485839256085_item	2431781	et	2	main
в	doc_485839256085_item	2431785	et	2	main
в	doc_485839256085_item	2431790	et	2	main
государственного	doc_485839256085_item	2431794	et	2	main
тарту	doc_485839256085_item	2431800	et	2	main
2006-го	doc_485839256085_item	2431805	et	2	main
данного	doc_485839256085_item	2431810	et	2	main
anna	doc_485839256085_item	2431390	et	4	main
vanu	doc_485839256085_item	2431395	et	4	main
pulmakombeid	doc_485839256085_item	2431396	et	4	main
rahva	doc_485839256085_item	2431397	et	3	main
enneid	doc_485839256085_item	2431398	et	4	main
uskumusi	doc_485839256085_item	2431399	et	4	main
tšastuškasi	doc_485839256085_item	2431404	et	2	main
neljavärsilisi	doc_485839256085_item	2431407	et	4	main
on	doc_485839256085_item	2431413	et	4	main
vene	doc_485839256085_item	2431422	et	4	main
küsitluse	doc_485839256085_item	2431434	et	4	main
antud	doc_485839256085_item	2431443	et	4	main
väljaandes	doc_485839256085_item	2431444	et	3	main
sajandi	doc_485839256085_item	2431446	et	3	main
vanausuliste	doc_485839256085_item	2431452	et	4	main
folklooritraditsiooni	doc_485839256085_item	2431453	et	4	main
ajal	doc_485839256085_item	2431463	et	4	main
oma	doc_485839256085_item	2431487	et	4	main
kodukandis	doc_485839256085_item	2431488	et	3	main
aastakümned	doc_485839256085_item	2431492	et	4	main
vanausuliste	doc_485839256085_item	2431502	et	4	main
koguduste	doc_485839256085_item	2431503	et	4	main
liidu	doc_485839256085_item	2431504	et	3	main
esimehe	doc_485839256085_item	2431505	et	3	main
pavel	doc_485839256085_item	2431506	et	4	main
koostatud	doc_485839256085_item	2431516	et	4	main
selle	doc_485839256085_item	2431517	et	4	main
kirja	doc_485839256085_item	2431525	et	4	main
panna	doc_485839256085_item	2431526	et	4	main
mitusada	doc_485839256085_item	2431527	et	4	main
folklooritekste	doc_485839256085_item	2431528	et	3	main
üle	doc_485839256085_item	2431529	et	3	main
tartus	doc_485839256085_item	2431539	et	3	main
mis	doc_485839256085_item	2431546	et	4	main
jäid	doc_485839256085_item	2431549	et	4	main
religioosne	doc_485839256085_item	2431565	et	3	main
teosed	doc_485839256085_item	2431576	et	3	main
laulud	doc_485839256085_item	2431581	et	3	main
siiski	doc_485839256085_item	2431586	et	4	main
kultuur	doc_485839256085_item	2431594	et	3	main
ka	doc_485839256085_item	2431598	et	3	main
üks	doc_485839256085_item	2431600	et	3	main
peipsi	doc_485839256085_item	2431613	et	4	main
õnnistusrikkaks	doc_485839256085_item	2431618	et	4	main
заветы	doc_485839256085_item	2431624	et	2	main
мифологические	doc_485839256085_item	2431631	et	2	main
магия	doc_485839256085_item	2431636	et	2	main
см	doc_485839256085_item	2431655	et	2	main
этнолингвистический	doc_485839256085_item	2431660	et	2	main
2004	doc_485839256085_item	2431665	et	2	main
москва	doc_485839256085_item	2431675	et	2	main
тс	doc_485839256085_item	2431681	et	2	main
населения	doc_485839256085_item	2431687	et	2	main
этноконфессиональный	doc_485839256085_item	2431704	et	2	main
в	doc_485839256085_item	2431709	et	2	main
õpetajad	doc_485839256085_item	2431424	et	4	main
pakuvad	doc_485839256085_item	2431433	et	3	main
ka	doc_485839256085_item	2431436	et	3	main
eelmise	doc_485839256085_item	2431445	et	3	main
60ndatel	doc_485839256085_item	2431447	et	4	main
astatel	doc_485839256085_item	2431448	et	4	main
oma	doc_485839256085_item	2431449	et	4	main
panuse	doc_485839256085_item	2431450	et	3	main
tegid	doc_485839256085_item	2431455	et	4	main
siin	doc_485839256085_item	2431461	et	4	main
kirja	doc_485839256085_item	2431466	et	4	main
materjalidest	doc_485839256085_item	2431468	et	3	main
võib	doc_485839256085_item	2431469	et	3	main
ära	doc_485839256085_item	2431470	et	4	main
märkida	doc_485839256085_item	2431471	et	4	main
i	doc_485839256085_item	2431472	et	4	main
ventšikova	doc_485839256085_item	2431473	et	2	main
ja	doc_485839256085_item	2431474	et	3	main
m	doc_485839256085_item	2431475	et	4	main
feklistova	doc_485839256085_item	2431476	et	4	main
kirjapanekuid	doc_485839256085_item	2431477	et	3	main
nende	doc_485839256085_item	2431478	et	4	main
perekonnanimede	doc_485839256085_item	2431479	et	3	main
järgi	doc_485839256085_item	2431480	et	4	main
võib	doc_485839256085_item	2431481	et	3	main
oletada	doc_485839256085_item	2431482	et	3	main
et	doc_485839256085_item	2431483	et	3	main
nad	doc_485839256085_item	2431484	et	3	main
olid	doc_485839256085_item	2431485	et	4	main
praktikal	doc_485839256085_item	2431486	et	3	main
seiskunud	doc_485839256085_item	2431497	et	4	main
vaid	doc_485839256085_item	2431498	et	3	main
varunini	doc_485839256085_item	2431507	et	4	main
folklooriekspeditsioon	doc_485839256085_item	2431511	et	3	main
peipsimaale	doc_485839256085_item	2431512	et	4	main
ekspeditsiooni	doc_485839256085_item	2431518	et	4	main
nädalaga	doc_485839256085_item	2431522	et	3	main
kuulusid	doc_485839256085_item	2431543	et	4	main
erinevatel	doc_485839256085_item	2431547	et	4	main
silmapiirist	doc_485839256085_item	2431552	et	3	main
muinasjutud	doc_485839256085_item	2431578	et	3	main
lüürilised	doc_485839256085_item	2431580	et	3	main
traditsiooniline	doc_485839256085_item	2431593	et	4	main
tähtsamaid	doc_485839256085_item	2431601	et	4	main
edasist	doc_485839256085_item	2431608	et	3	main
uurimist	doc_485839256085_item	2431609	et	4	main
autorite	doc_485839256085_item	2431610	et	3	main
arvamusel	doc_485839256085_item	2431611	et	3	main
veel	doc_485839256085_item	2431615	et	4	main
юа	doc_485839256085_item	2431626	et	2	main
заветам	doc_485839256085_item	2431629	et	2	main
заговоры	doc_485839256085_item	2431633	et	2	main
литвы	doc_485839256085_item	2431638	et	2	main
2005	doc_485839256085_item	2431640	et	2	main
народная	doc_485839256085_item	2431643	et	2	main
культура	doc_485839256085_item	2431645	et	2	main
т	doc_485839256085_item	2431648	et	2	main
2002	doc_485839256085_item	2431651	et	2	main
iii	doc_485839256085_item	2431653	et	4	main
славянские	doc_485839256085_item	2431658	et	2	main
словарь	doc_485839256085_item	2431674	et	2	main
2002	doc_485839256085_item	2431676	et	2	main
макашина	doc_485839256085_item	2431680	et	2	main
сост	doc_485839256085_item	2431684	et	2	main
москва	doc_485839256085_item	2431689	et	2	main
старообрядцев	doc_485839256085_item	2431698	et	2	main
эстония	doc_485839256085_item	2431701	et	2	main
вариант	doc_485839256085_item	2431705	et	2	main
условиях	doc_485839256085_item	2431710	et	2	main
окружения	doc_485839256085_item	2431713	et	2	main
произведений	doc_485839256085_item	2431723	et	2	main
и	doc_485839256085_item	2431729	et	2	main
иллюстративного	doc_485839256085_item	2431733	et	2	main
из	doc_485839256085_item	2431738	et	2	main
в	doc_485839256085_item	2431742	et	2	main
эстонский	doc_485839256085_item	2431746	et	2	main
русского	doc_485839256085_item	2431750	et	2	main
одна	doc_485839256085_item	2431755	et	2	main
в	doc_485839256085_item	2431760	et	2	main
познакомить	doc_485839256085_item	2431766	et	2	main
особенностями	doc_485839256085_item	2431769	et	2	main
поэзии	doc_485839256085_item	2431774	et	2	main
сборник	doc_485839256085_item	2431779	et	2	main
записанных	doc_485839256085_item	2431784	et	2	main
и	doc_485839256085_item	2431788	et	2	main
фольклора	doc_485839256085_item	2431793	et	2	main
фр	doc_485839256085_item	2431798	et	2	main
материалы	doc_485839256085_item	2431803	et	2	main
организованной	doc_485839256085_item	2431807	et	2	main
проекта	doc_485839256085_item	2431812	et	2	main
в	doc_485839256085_item	2431818	et	2	main
использовалась	doc_485839256085_item	2431821	et	2	main
их	doc_485839256085_item	2431828	et	2	main
в	doc_485839256085_item	2431833	et	2	main
принципу	doc_485839256085_item	2431839	et	2	main
особенностей	doc_485839256085_item	2431845	et	2	main
научный	doc_485839256085_item	2431851	et	2	main
массива	doc_485839256085_item	2431855	et	2	main
и	doc_485839256085_item	2431861	et	2	main
русской	doc_485839256085_item	2431867	et	2	main
в	doc_485839256085_item	2431870	et	2	main
до	doc_485839256085_item	2431876	et	2	main
последнего	doc_485839256085_item	2431898	et	2	main
к	doc_485839256085_item	2431903	et	2	main
не	doc_485839256085_item	2431907	et	2	main
легенды	doc_485839256085_item	2431911	et	2	main
волшебные	doc_485839256085_item	2431919	et	2	main
üleantud	doc_485839256085_item	2431536	et	4	main
eesti	doc_485839256085_item	2431537	et	4	main
kirjandusmuuseumisse	doc_485839256085_item	2431538	et	3	main
hulka	doc_485839256085_item	2431542	et	4	main
välja	doc_485839256085_item	2431553	et	4	main
või	doc_485839256085_item	2431554	et	4	main
said	doc_485839256085_item	2431555	et	4	main
kirja	doc_485839256085_item	2431556	et	4	main
pandud	doc_485839256085_item	2431557	et	4	main
teatad	doc_485839256085_item	2431558	et	3	main
määral	doc_485839256085_item	2431559	et	3	main
juhuslikult	doc_485839256085_item	2431560	et	4	main
ja	doc_485839256085_item	2431566	et	3	main
etikett	doc_485839256085_item	2431568	et	3	main
olmemaagia	doc_485839256085_item	2431569	et	4	main
kahetsusväärne	doc_485839256085_item	2431570	et	3	main
on	doc_485839256085_item	2431571	et	4	main
tõdeda	doc_485839256085_item	2431572	et	3	main
et	doc_485839256085_item	2431573	et	3	main
paljud	doc_485839256085_item	2431574	et	3	main
rahvaluule	doc_485839256085_item	2431575	et	4	main
on	doc_485839256085_item	2431582	et	4	main
elusast	doc_485839256085_item	2431584	et	4	main
käibivusest	doc_485839256085_item	2431585	et	4	main
tulemused	doc_485839256085_item	2431589	et	3	main
selles	doc_485839256085_item	2431595	et	4	main
jääb	doc_485839256085_item	2431612	et	3	main
pikki	doc_485839256085_item	2431616	et	4	main
folklooriuurijatele	doc_485839256085_item	2431620	et	3	main
ja	doc_485839256085_item	2431621	et	3	main
kirjandus	doc_485839256085_item	2431623	et	3	main
сост	doc_485839256085_item	2431627	et	2	main
сказания	doc_485839256085_item	2431632	et	2	main
старообрядцев	doc_485839256085_item	2431637	et	2	main
i	doc_485839256085_item	2431642	et	4	main
области	doc_485839256085_item	2431647	et	2	main
санкт-петербург	doc_485839256085_item	2431650	et	2	main
ред	doc_485839256085_item	2431657	et	2	main
т	doc_485839256085_item	2431662	et	2	main
см	doc_485839256085_item	2431666	et	2	main
ред	doc_485839256085_item	2431670	et	2	main
мифология	doc_485839256085_item	2431672	et	2	main
аф	doc_485839256085_item	2431679	et	2	main
нк	doc_485839256085_item	2431683	et	2	main
прибалтики	doc_485839256085_item	2431688	et	2	main
английский	doc_485839256085_item	2431695	et	2	main
западного	doc_485839256085_item	2431699	et	2	main
общерусской	doc_485839256085_item	2431706	et	2	main
как	doc_485839256085_item	2431724	et	2	main
историками	doc_485839256085_item	2431728	et	2	main
материала	doc_485839256085_item	2431734	et	2	main
вошедшая	doc_485839256085_item	2431741	et	2	main
раздел	doc_485839256085_item	2431747	et	2	main
1976	doc_485839256085_item	2431754	et	2	main
какой-то	doc_485839256085_item	2431761	et	2	main
пробел	doc_485839256085_item	2431765	et	2	main
традиционной	doc_485839256085_item	2431770	et	2	main
старообрядцев	doc_485839256085_item	2431775	et	2	main
вошли	doc_485839256085_item	2431780	et	2	main
хранящихся	doc_485839256085_item	2431789	et	2	main
имени	doc_485839256085_item	2431797	et	2	main
а	doc_485839256085_item	2431801	et	2	main
рамках	doc_485839256085_item	2431809	et	2	main
прошлых	doc_485839256085_item	2431814	et	2	main
2006	doc_485839256085_item	2431819	et	2	main
все	doc_485839256085_item	2431825	et	2	main
750	doc_485839256085_item	2431830	et	2	main
по	doc_485839256085_item	2431837	et	2	main
унификации	doc_485839256085_item	2431843	et	2	main
введение	doc_485839256085_item	2431849	et	2	main
значительного	doc_485839256085_item	2431854	et	2	main
заметно	doc_485839256085_item	2431859	et	2	main
сложившиеся	doc_485839256085_item	2431863	et	2	main
специфике	doc_485839256085_item	2431866	et	2	main
западном	doc_485839256085_item	2431871	et	2	main
среде	doc_485839256085_item	2431875	et	2	main
от	doc_485839256085_item	2431901	et	2	main
рукописным	doc_485839256085_item	2431905	et	2	main
христианские	doc_485839256085_item	2431910	et	2	main
сюжетов	doc_485839256085_item	2431914	et	2	main
невелик	doc_485839256085_item	2431916	et	2	main
etnoloogidele	doc_485839256085_item	2431622	et	3	main
новиков	doc_485839256085_item	2431625	et	2	main
по	doc_485839256085_item	2431628	et	2	main
поверья	doc_485839256085_item	2431634	et	2	main
нткп	doc_485839256085_item	2431641	et	2	main
псковской	doc_485839256085_item	2431646	et	2	main
i	doc_485839256085_item	2431649	et	4	main
сд	doc_485839256085_item	2431652	et	2	main
толстая	doc_485839256085_item	2431654	et	2	main
древности	doc_485839256085_item	2431659	et	2	main
москва	doc_485839256085_item	2431664	et	2	main
см	doc_485839256085_item	2431668	et	2	main
энциклопедический	doc_485839256085_item	2431673	et	2	main
белоусов	doc_485839256085_item	2431678	et	2	main
митропольская	doc_485839256085_item	2431682	et	2	main
фольклор	doc_485839256085_item	2431685	et	2	main
1976	doc_485839256085_item	2431690	et	2	main
для	doc_485839256085_item	2431692	et	2	main
на	doc_485839256085_item	2431694	et	2	main
язык	doc_485839256085_item	2431696	et	2	main
причудья	doc_485839256085_item	2431700	et	2	main
собой	doc_485839256085_item	2431703	et	2	main
сформировавшийся	doc_485839256085_item	2431708	et	2	main
иноязычного	doc_485839256085_item	2431712	et	2	main
в	doc_485839256085_item	2431714	et	2	main
научных	doc_485839256085_item	2431715	et	2	main
изданиях	doc_485839256085_item	2431716	et	2	main
напечатаны	doc_485839256085_item	2431717	et	2	main
лишь	doc_485839256085_item	2431718	et	2	main
отдельные	doc_485839256085_item	2431719	et	2	main
образцы	doc_485839256085_item	2431720	et	2	main
записанных	doc_485839256085_item	2431721	et	2	main
использовались	doc_485839256085_item	2431727	et	2	main
качестве	doc_485839256085_item	2431732	et	2	main
подборка	doc_485839256085_item	2431737	et	2	main
текстов	doc_485839256085_item	2431740	et	2	main
белоусовым	doc_485839256085_item	2431745	et	2	main
населения	doc_485839256085_item	2431751	et	2	main
целей	doc_485839256085_item	2431757	et	2	main
публикации	doc_485839256085_item	2431759	et	2	main
этот	doc_485839256085_item	2431764	et	2	main
культуры	doc_485839256085_item	2431771	et	2	main
в	doc_485839256085_item	2431778	et	2	main
текстов	doc_485839256085_item	2431783	et	2	main
годов	doc_485839256085_item	2431787	et	2	main
русского	doc_485839256085_item	2431792	et	2	main
литературного	doc_485839256085_item	2431795	et	2	main
крейцвальда	doc_485839256085_item	2431799	et	2	main
экспедиции	doc_485839256085_item	2431804	et	2	main
в	doc_485839256085_item	2431808	et	2	main
записи	doc_485839256085_item	2431813	et	2	main
году	doc_485839256085_item	2431820	et	2	main
современная	doc_485839256085_item	2431822	et	2	main
тексты	doc_485839256085_item	2431826	et	2	main
книге	doc_485839256085_item	2431834	et	2	main
жанрово-тематическому	doc_485839256085_item	2431838	et	2	main
за	doc_485839256085_item	2431841	et	2	main
не	doc_485839256085_item	2431846	et	2	main
в	doc_485839256085_item	2431850	et	2	main
материалов	doc_485839256085_item	2431857	et	2	main
уточнить	doc_485839256085_item	2431862	et	2	main
о	doc_485839256085_item	2431865	et	2	main
причудье	doc_485839256085_item	2431872	et	2	main
столетия	doc_485839256085_item	2431899	et	2	main
поколению	doc_485839256085_item	2431904	et	2	main
забыты	doc_485839256085_item	2431908	et	2	main
круг	doc_485839256085_item	2431913	et	2	main
сказки	doc_485839256085_item	2431917	et	2	main
репертуар	doc_485839256085_item	2431924	et	2	main
правило	doc_485839256085_item	2431725	et	2	main
диалектологами	doc_485839256085_item	2431730	et	2	main
исключение	doc_485839256085_item	2431735	et	2	main
подготовленный	doc_485839256085_item	2431743	et	2	main
книги	doc_485839256085_item	2431748	et	2	main
прибалтики	doc_485839256085_item	2431752	et	2	main
нашей	doc_485839256085_item	2431758	et	2	main
восполнить	doc_485839256085_item	2431763	et	2	main
с	doc_485839256085_item	2431768	et	2	main
народной	doc_485839256085_item	2431773	et	2	main
региона	doc_485839256085_item	2431777	et	2	main
образцы	doc_485839256085_item	2431782	et	2	main
19301969	doc_485839256085_item	2431786	et	2	main
фонде	doc_485839256085_item	2431791	et	2	main
музея	doc_485839256085_item	2431796	et	2	main
также	doc_485839256085_item	2431802	et	2	main
года	doc_485839256085_item	2431806	et	2	main
издательского	doc_485839256085_item	2431811	et	2	main
сделаны	doc_485839256085_item	2431816	et	2	main
лет	doc_485839256085_item	2431815	et	2	main
вручную	doc_485839256085_item	2431817	et	2	main
звукозаписывающая	doc_485839256085_item	2431823	et	2	main
около	doc_485839256085_item	2431829	et	2	main
впервые	doc_485839256085_item	2431832	et	2	main
сгруппированы	doc_485839256085_item	2431836	et	2	main
исключением	doc_485839256085_item	2431842	et	2	main
подверглись	doc_485839256085_item	2431847	et	2	main
столь	doc_485839256085_item	2431853	et	2	main
позволяет	doc_485839256085_item	2431858	et	2	main
представления	doc_485839256085_item	2431864	et	2	main
культуры	doc_485839256085_item	2431869	et	2	main
старообрядческой	doc_485839256085_item	2431874	et	2	main
передавались	doc_485839256085_item	2431900	et	2	main
путем	doc_485839256085_item	2431906	et	2	main
сравнительно	doc_485839256085_item	2431915	et	2	main
фиксировались	doc_485839256085_item	2431920	et	2	main
небогат	doc_485839256085_item	2431922	et	2	main
них	doc_485839256085_item	2431929	et	2	main
баллады	doc_485839256085_item	2431933	et	2	main
в	doc_485839256085_item	2431939	et	2	main
вместе	doc_485839256085_item	2431942	et	2	main
и	doc_485839256085_item	2431949	et	2	main
составляющих	doc_485839256085_item	2431955	et	2	main
местного	doc_485839256085_item	2431960	et	2	main
широко	doc_485839256085_item	2431964	et	2	main
семейно-бытового	doc_485839256085_item	2431969	et	2	main
поверья	doc_485839256085_item	2431974	et	2	main
праздниками	doc_485839256085_item	2431979	et	2	main
особый	doc_485839256085_item	2431983	et	2	main
тексты	doc_485839256085_item	2431986	et	2	main
издавна	doc_485839256085_item	2431991	et	2	main
жизни	doc_485839256085_item	2431996	et	2	main
причудья	doc_485839256085_item	2431998	et	2	main
в	doc_485839256085_item	2432003	et	2	main
опевальные	doc_485839256085_item	2432026	et	2	main
обычаи	doc_485839256085_item	2432032	et	2	main
будущую	doc_485839256085_item	2432037	et	2	main
и	doc_485839256085_item	2432042	et	2	main
странах	doc_485839256085_item	2432048	et	2	main
северо-западных	doc_485839256085_item	2432052	et	2	main
беларуси	doc_485839256085_item	2432054	et	2	main
и	doc_485839256085_item	2432060	et	2	main
и	doc_485839256085_item	2432065	et	2	main
памяти	doc_485839256085_item	2432070	et	2	main
редких	doc_485839256085_item	2432076	et	2	main
медицинских	doc_485839256085_item	2432102	et	2	main
убеждены	doc_485839256085_item	2432106	et	2	main
ни	doc_485839256085_item	2432112	et	2	main
нередко	doc_485839256085_item	2432117	et	2	main
прозы	doc_485839256085_item	2432122	et	2	main
аппаратура	doc_485839256085_item	2431824	et	2	main
а	doc_485839256085_item	2431827	et	2	main
публикуются	doc_485839256085_item	2431831	et	2	main
они	doc_485839256085_item	2431835	et	2	main
и	doc_485839256085_item	2431840	et	2	main
фонетических	doc_485839256085_item	2431844	et	2	main
редактированию	doc_485839256085_item	2431848	et	2	main
оборот	doc_485839256085_item	2431852	et	2	main
фольклорных	doc_485839256085_item	2431856	et	2	main
расширить	doc_485839256085_item	2431860	et	2	main
традиционной	doc_485839256085_item	2431868	et	2	main
в	doc_485839256085_item	2431873	et	2	main
сих	doc_485839256085_item	2431877	et	2	main
пор	doc_485839256085_item	2431878	et	2	main
активно	doc_485839256085_item	2431879	et	2	main
бытуют	doc_485839256085_item	2431880	et	2	main
духовные	doc_485839256085_item	2431881	et	2	main
стихи	doc_485839256085_item	2431882	et	2	main
народные	doc_485839256085_item	2431883	et	2	main
песни	doc_485839256085_item	2431884	et	2	main
религиозного	doc_485839256085_item	2431885	et	2	main
содержания	doc_485839256085_item	2431886	et	2	main
преимущественно	doc_485839256085_item	2431887	et	2	main
поздние	doc_485839256085_item	2431888	et	2	main
созданные	doc_485839256085_item	2431889	et	2	main
монахами	doc_485839256085_item	2431890	et	2	main
и	doc_485839256085_item	2431891	et	2	main
староверами-начетчиками	doc_485839256085_item	2431892	et	2	main
многие	doc_485839256085_item	2431893	et	2	main
из	doc_485839256085_item	2431894	et	2	main
них	doc_485839256085_item	2431895	et	2	main
на	doc_485839256085_item	2431896	et	2	main
протяжении	doc_485839256085_item	2431897	et	2	main
поколения	doc_485839256085_item	2431902	et	2	main
и	doc_485839256085_item	2431909	et	2	main
хотя	doc_485839256085_item	2431912	et	2	main
особенно	doc_485839256085_item	2431918	et	2	main
редко	doc_485839256085_item	2431921	et	2	main
лирических	doc_485839256085_item	2431926	et	2	main
доминируют	doc_485839256085_item	2431930	et	2	main
протяжные	doc_485839256085_item	2431935	et	2	main
с	doc_485839256085_item	2431943	et	2	main
традиционного	doc_485839256085_item	2431947	et	2	main
одной	doc_485839256085_item	2431952	et	2	main
и	doc_485839256085_item	2431958	et	2	main
правила	doc_485839256085_item	2431966	et	2	main
обряды	doc_485839256085_item	2431971	et	2	main
календарными	doc_485839256085_item	2431978	et	2	main
интерес	doc_485839256085_item	2431984	et	2	main
промыслу	doc_485839256085_item	2431989	et	2	main
ключевую	doc_485839256085_item	2431993	et	2	main
минувшего	doc_485839256085_item	2432001	et	2	main
и	doc_485839256085_item	2431923	et	2	main
хороводные	doc_485839256085_item	2431931	et	2	main
долевые	doc_485839256085_item	2431936	et	2	main
тем	doc_485839256085_item	2431944	et	2	main
являются	doc_485839256085_item	2431951	et	2	main
духовной	doc_485839256085_item	2431956	et	2	main
населения	doc_485839256085_item	2431961	et	2	main
представлены	doc_485839256085_item	2431965	et	2	main
этикета	doc_485839256085_item	2431970	et	2	main
связанные	doc_485839256085_item	2431975	et	2	main
хозяйственными	doc_485839256085_item	2431980	et	2	main
вызывают	doc_485839256085_item	2431985	et	2	main
который	doc_485839256085_item	2431990	et	2	main
роль	doc_485839256085_item	2431994	et	2	main
века	doc_485839256085_item	2432002	et	2	main
краю	doc_485839256085_item	2432005	et	2	main
устойчиво	doc_485839256085_item	2432006	et	2	main
сохранялись	doc_485839256085_item	2432007	et	2	main
многочисленные	doc_485839256085_item	2432008	et	2	main
обряды	doc_485839256085_item	2432010	et	2	main
свадебные	doc_485839256085_item	2432009	et	2	main
и	doc_485839256085_item	2432011	et	2	main
обычаи	doc_485839256085_item	2432012	et	2	main
с	doc_485839256085_item	2432013	et	2	main
богатым	doc_485839256085_item	2432014	et	2	main
набором	doc_485839256085_item	2432015	et	2	main
песен	doc_485839256085_item	2432016	et	2	main
дружки	doc_485839256085_item	2432018	et	2	main
приговоров	doc_485839256085_item	2432017	et	2	main
причитаний	doc_485839256085_item	2432019	et	2	main
невесты	doc_485839256085_item	2432020	et	2	main
популярностью	doc_485839256085_item	2432022	et	2	main
так	doc_485839256085_item	2432024	et	2	main
родильно-крестильные	doc_485839256085_item	2432029	et	2	main
способы	doc_485839256085_item	2432033	et	2	main
жизнь	doc_485839256085_item	2432038	et	2	main
и	doc_485839256085_item	2432045	et	2	main
и	doc_485839256085_item	2432050	et	2	main
соблюдают	doc_485839256085_item	2432057	et	2	main
обычаев	doc_485839256085_item	2432059	et	2	main
похорон	doc_485839256085_item	2432064	et	2	main
в	doc_485839256085_item	2432069	et	2	main
сохранилось	doc_485839256085_item	2432074	et	2	main
к	doc_485839256085_item	2432100	et	2	main
исполнители	doc_485839256085_item	2432105	et	2	main
нельзя	doc_485839256085_item	2432110	et	2	main
их	doc_485839256085_item	2432115	et	2	main
среди	doc_485839256085_item	2432119	et	2	main
несказочной	doc_485839256085_item	2432121	et	2	main
наиболее	doc_485839256085_item	2432128	et	2	main
ходячих	doc_485839256085_item	2432132	et	2	main
с	doc_485839256085_item	2432137	et	2	main
страхах	doc_485839256085_item	2432140	et	2	main
и	doc_485839256085_item	2432145	et	2	main
рассказов	doc_485839256085_item	2432149	et	2	main
сравнительно	doc_485839256085_item	2432154	et	2	main
баенника	doc_485839256085_item	2432160	et	2	main
традиции	doc_485839256085_item	2432168	et	2	main
о	doc_485839256085_item	2432173	et	2	main
о	doc_485839256085_item	2432179	et	2	main
бытовых	doc_485839256085_item	2431925	et	2	main
среди	doc_485839256085_item	2431928	et	2	main
песни	doc_485839256085_item	2431937	et	2	main
единичных	doc_485839256085_item	2431940	et	2	main
многие	doc_485839256085_item	2431945	et	2	main
фольклора	doc_485839256085_item	2431948	et	2	main
из	doc_485839256085_item	2431953	et	2	main
жизни	doc_485839256085_item	2431957	et	2	main
в	doc_485839256085_item	2431962	et	2	main
и	doc_485839256085_item	2431968	et	2	main
обычаи	doc_485839256085_item	2431972	et	2	main
важнейшими	doc_485839256085_item	2431977	et	2	main
селян	doc_485839256085_item	2431982	et	2	main
рыболовному	doc_485839256085_item	2431988	et	2	main
в	doc_485839256085_item	2431995	et	2	main
до	doc_485839256085_item	2431999	et	2	main
этом	doc_485839256085_item	2432004	et	2	main
наибольшей	doc_485839256085_item	2432021	et	2	main
величальные	doc_485839256085_item	2432027	et	2	main
и	doc_485839256085_item	2432031	et	2	main
на	doc_485839256085_item	2432036	et	2	main
ребенка	doc_485839256085_item	2432039	et	2	main
сегодня	doc_485839256085_item	2432043	et	2	main
других	doc_485839256085_item	2432047	et	2	main
районах	doc_485839256085_item	2432053	et	2	main
множество	doc_485839256085_item	2432058	et	2	main
время	doc_485839256085_item	2432063	et	2	main
близких	doc_485839256085_item	2432067	et	2	main
поколения	doc_485839256085_item	2432073	et	2	main
относятся	doc_485839256085_item	2432099	et	2	main
поскольку	doc_485839256085_item	2432104	et	2	main
заговорах	doc_485839256085_item	2432109	et	2	main
менять	doc_485839256085_item	2432111	et	2	main
тексты	doc_485839256085_item	2432116	et	2	main
произведений	doc_485839256085_item	2432120	et	2	main
центральное	doc_485839256085_item	2432123	et	2	main
популярны	doc_485839256085_item	2432129	et	2	main
покойниках	doc_485839256085_item	2432133	et	2	main
умершими	doc_485839256085_item	2432138	et	2	main
сглазе	doc_485839256085_item	2432144	et	2	main
о	doc_485839256085_item	2432150	et	2	main
немного	doc_485839256085_item	2432155	et	2	main
и	doc_485839256085_item	2432159	et	2	main
отдельные	doc_485839256085_item	2432164	et	2	main
местной	doc_485839256085_item	2432167	et	2	main
былички	doc_485839256085_item	2432172	et	2	main
домашнего	doc_485839256085_item	2432177	et	2	main
заклятых	doc_485839256085_item	2432181	et	2	main
обеднение	doc_485839256085_item	2432186	et	2	main
культура	doc_485839256085_item	2432191	et	2	main
продолжает	doc_485839256085_item	2432196	et	2	main
заслуживает	doc_485839256085_item	2432199	et	2	main
kontrolltöö	doc_489002948347_item	2432357	et	4	main
taasavamise	doc_489002948347_item	2432364	et	4	main
2	doc_489002948347_item	2432370	et	2	main
mida	doc_489002948347_item	2432376	et	4	main
see	doc_489002948347_item	2432377	et	3	main
песен	doc_485839256085_item	2431927	et	2	main
старинные	doc_485839256085_item	2431932	et	2	main
и	doc_485839256085_item	2431934	et	2	main
записаны	doc_485839256085_item	2431938	et	2	main
вариантах	doc_485839256085_item	2431941	et	2	main
жанры	doc_485839256085_item	2431946	et	2	main
сегодня	doc_485839256085_item	2431950	et	2	main
важнейших	doc_485839256085_item	2431954	et	2	main
быта	doc_485839256085_item	2431959	et	2	main
сборнике	doc_485839256085_item	2431963	et	2	main
религиозного	doc_485839256085_item	2431967	et	2	main
и	doc_485839256085_item	2431973	et	2	main
с	doc_485839256085_item	2431976	et	2	main
заботами	doc_485839256085_item	2431981	et	2	main
посвященные	doc_485839256085_item	2431987	et	2	main
играет	doc_485839256085_item	2431992	et	2	main
старообрядцев	doc_485839256085_item	2431997	et	2	main
середины	doc_485839256085_item	2432000	et	2	main
называемые	doc_485839256085_item	2432025	et	2	main
воздействия	doc_485839256085_item	2432035	et	2	main
хорошо	doc_485839256085_item	2432040	et	2	main
как	doc_485839256085_item	2432044	et	2	main
балтии	doc_485839256085_item	2432049	et	2	main
эстонии	doc_485839256085_item	2432056	et	2	main
запретов	doc_485839256085_item	2432061	et	2	main
поминок	doc_485839256085_item	2432066	et	2	main
людей	doc_485839256085_item	2432071	et	2	main
немало	doc_485839256085_item	2432075	et	2	main
тексты	doc_485839256085_item	2432098	et	2	main
заклинаний	doc_485839256085_item	2432103	et	2	main
в	doc_485839256085_item	2432108	et	2	main
одного	doc_485839256085_item	2432113	et	2	main
переписывали	doc_485839256085_item	2432118	et	2	main
место	doc_485839256085_item	2432124	et	2	main
мифологические	doc_485839256085_item	2432126	et	2	main
о	doc_485839256085_item	2432131	et	2	main
живых	doc_485839256085_item	2432136	et	2	main
привидениях	doc_485839256085_item	2432142	et	2	main
его	doc_485839256085_item	2432147	et	2	main
и	doc_485839256085_item	2432152	et	2	main
лешего	doc_485839256085_item	2432157	et	2	main
изредка	doc_485839256085_item	2432162	et	2	main
в	doc_485839256085_item	2432166	et	2	main
колдунах	doc_485839256085_item	2432174	et	2	main
кладах	doc_485839256085_item	2432182	et	2	main
фольклорной	doc_485839256085_item	2432187	et	2	main
у	doc_485839256085_item	2432192	et	2	main
дальнейших	doc_485839256085_item	2432200	et	2	main
пользовались	doc_485839256085_item	2432023	et	2	main
песни	doc_485839256085_item	2432028	et	2	main
обряды	doc_485839256085_item	2432030	et	2	main
магического	doc_485839256085_item	2432034	et	2	main
помнят	doc_485839256085_item	2432041	et	2	main
в	doc_485839256085_item	2432046	et	2	main
в	doc_485839256085_item	2432051	et	2	main
старообрядцы	doc_485839256085_item	2432055	et	2	main
во	doc_485839256085_item	2432062	et	2	main
родственников	doc_485839256085_item	2432068	et	2	main
старшего	doc_485839256085_item	2432072	et	2	main
оригинальных	doc_485839256085_item	2432078	et	2	main
и	doc_485839256085_item	2432077	et	2	main
деталей	doc_485839256085_item	2432079	et	2	main
и	doc_485839256085_item	2432080	et	2	main
подробностей	doc_485839256085_item	2432081	et	2	main
уходящих	doc_485839256085_item	2432082	et	2	main
своими	doc_485839256085_item	2432083	et	2	main
корнями	doc_485839256085_item	2432084	et	2	main
глубокую	doc_485839256085_item	2432086	et	2	main
в	doc_485839256085_item	2432085	et	2	main
древность	doc_485839256085_item	2432087	et	2	main
собиратели	doc_485839256085_item	2432088	et	2	main
отметили	doc_485839256085_item	2432089	et	2	main
здесь	doc_485839256085_item	2432090	et	2	main
довольно	doc_485839256085_item	2432091	et	2	main
развитую	doc_485839256085_item	2432092	et	2	main
заговорную	doc_485839256085_item	2432093	et	2	main
традицию	doc_485839256085_item	2432094	et	2	main
но	doc_485839256085_item	2432095	et	2	main
почти	doc_485839256085_item	2432096	et	2	main
все	doc_485839256085_item	2432097	et	2	main
разряду	doc_485839256085_item	2432101	et	2	main
что	doc_485839256085_item	2432107	et	2	main
слова	doc_485839256085_item	2432114	et	2	main
сказания	doc_485839256085_item	2432127	et	2	main
контактах	doc_485839256085_item	2432135	et	2	main
о	doc_485839256085_item	2432139	et	2	main
о	doc_485839256085_item	2432143	et	2	main
домовом	doc_485839256085_item	2432151	et	2	main
а	doc_485839256085_item	2432156	et	2	main
лишь	doc_485839256085_item	2432161	et	2	main
информаторы	doc_485839256085_item	2432165	et	2	main
закрепились	doc_485839256085_item	2432170	et	2	main
и	doc_485839256085_item	2432175	et	2	main
скота	doc_485839256085_item	2432178	et	2	main
несмотря	doc_485839256085_item	2432183	et	2	main
традиции	doc_485839256085_item	2432188	et	2	main
западного	doc_485839256085_item	2432194	et	2	main
исследований	doc_485839256085_item	2432201	et	2	main
1	doc_489002948347_item	2432361	et	2	main
jaoks	doc_489002948347_item	2432379	et	4	main
tü	doc_489002948347_item	2432383	et	4	main
sai	doc_489002948347_item	2432388	et	4	main
fr	doc_489002948347_item	2432390	et	4	main
hakati	doc_489002948347_item	2432397	et	3	main
hakati	doc_489002948347_item	2432401	et	3	main
viima	doc_489002948347_item	2432403	et	3	main
loengud	doc_489002948347_item	2432405	et	3	main
ja	doc_489002948347_item	2432417	et	3	main
töötasid	doc_489002948347_item	2432419	et	4	main
sündmus	doc_489002948347_item	2432422	et	3	main
kasulik	doc_489002948347_item	2432424	et	3	main
sakslastele	doc_489002948347_item	2432426	et	3	main
teiste	doc_489002948347_item	2432428	et	4	main
sest	doc_489002948347_item	2432431	et	4	main
üks	doc_489002948347_item	2432434	et	3	main
siin	doc_489002948347_item	2432438	et	4	main
lätlased	doc_489002948347_item	2432442	et	3	main
paljud	doc_489002948347_item	2432455	et	3	main
k	doc_489002948347_item	2432464	et	4	main
faehlmann	doc_489002948347_item	2432471	et	4	main
ja	doc_489002948347_item	2432472	et	3	main
venestuspoliitika	doc_489002948347_item	2432475	et	4	main
nagu	doc_489002948347_item	2432484	et	3	main
ja	doc_489002948347_item	2432486	et	3	main
kiiresti	doc_489002948347_item	2432492	et	3	main
hakas	doc_489002948347_item	2432493	et	4	main
ilmuma	doc_489002948347_item	2432494	et	3	main
1816	doc_489002948347_item	2432512	et	2	main
aastal	doc_489002948347_item	2432513	et	3	main
muidugi	doc_489002948347_item	2432514	et	4	main
nüüd	doc_489002948347_item	2432521	et	4	main
pidid	doc_489002948347_item	2432529	et	4	main
eest	doc_489002948347_item	2432533	et	4	main
занимают	doc_485839256085_item	2432125	et	2	main
сюжеты	doc_485839256085_item	2432130	et	2	main
о	doc_485839256085_item	2432134	et	2	main
и	doc_485839256085_item	2432141	et	2	main
способах	doc_485839256085_item	2432146	et	2	main
нейтрализации	doc_485839256085_item	2432148	et	2	main
дворовике	doc_485839256085_item	2432153	et	2	main
водяного	doc_485839256085_item	2432158	et	2	main
упоминали	doc_485839256085_item	2432163	et	2	main
не	doc_485839256085_item	2432169	et	2	main
также	doc_485839256085_item	2432171	et	2	main
порче	doc_485839256085_item	2432176	et	2	main
змеях	doc_485839256085_item	2432180	et	2	main
на	doc_485839256085_item	2432184	et	2	main
народная	doc_485839256085_item	2432189	et	2	main
причудья	doc_485839256085_item	2432195	et	2	main
и	doc_485839256085_item	2432198	et	2	main
очевидное	doc_485839256085_item	2432185	et	2	main
духовная	doc_485839256085_item	2432190	et	2	main
старообрядцев	doc_485839256085_item	2432193	et	2	main
функционировать	doc_485839256085_item	2432197	et	2	main
kontrolltöö	doc_489002948347_item	2432358	et	4	main
eesti	doc_489002948347_item	2432359	et	4	main
kultuuriloost	doc_489002948347_item	2432360	et	4	main
ülikooli	doc_489002948347_item	2432363	et	4	main
eesti	doc_489002948347_item	2432366	et	4	main
ja	doc_489002948347_item	2432368	et	3	main
millal	doc_489002948347_item	2432371	et	3	main
sisuliselt	doc_489002948347_item	2432380	et	4	main
1802	doc_489002948347_item	2432385	et	2	main
g	doc_489002948347_item	2432389	et	4	main
parrot	doc_489002948347_item	2432391	et	4	main
see	doc_489002948347_item	2432392	et	3	main
oli	doc_489002948347_item	2432393	et	3	main
väga	doc_489002948347_item	2432394	et	3	main
erialasid	doc_489002948347_item	2432400	et	4	main
ja	doc_489002948347_item	2432408	et	3	main
õpiti	doc_489002948347_item	2432409	et	3	main
eestlastest	doc_489002948347_item	2432415	et	4	main
tartu	doc_489002948347_item	2432362	et	4	main
tähtsus	doc_489002948347_item	2432365	et	4	main
kultuurielule	doc_489002948347_item	2432369	et	3	main
eestlased	doc_489002948347_item	2432373	et	3	main
ja	doc_489002948347_item	2432375	et	3	main
1	doc_489002948347_item	2432382	et	2	main
õpetama	doc_489002948347_item	2432398	et	3	main
keele	doc_489002948347_item	2432412	et	4	main
grammatikat	doc_489002948347_item	2432413	et	3	main
professorid	doc_489002948347_item	2432418	et	3	main
ka	doc_489002948347_item	2432425	et	3	main
õpisid	doc_489002948347_item	2432439	et	4	main
rikkalik	doc_489002948347_item	2432448	et	3	main
väljapaistvad	doc_489002948347_item	2432456	et	3	main
õpisid	doc_489002948347_item	2432458	et	4	main
von	doc_489002948347_item	2432465	et	4	main
j	doc_489002948347_item	2432467	et	4	main
teised	doc_489002948347_item	2432473	et	4	main
keelseid	doc_489002948347_item	2432497	et	3	main
raamatuid	doc_489002948347_item	2432498	et	3	main
rahvuslikku	doc_489002948347_item	2432504	et	4	main
see	doc_489002948347_item	2432515	et	3	main
talupojad	doc_489002948347_item	2432519	et	4	main
kuid	doc_489002948347_item	2432523	et	4	main
neid	doc_489002948347_item	2432524	et	4	main
vabastati	doc_489002948347_item	2432525	et	3	main
ilma	doc_489002948347_item	2432526	et	4	main
maata	doc_489002948347_item	2432527	et	3	main
talupojad	doc_489002948347_item	2432528	et	4	main
töötada	doc_489002948347_item	2432539	et	3	main
aga	doc_489002948347_item	2432542	et	3	main
talupojad	doc_489002948347_item	2432548	et	4	main
raha	doc_489002948347_item	2432554	et	4	main
koguda	doc_489002948347_item	2432555	et	3	main
sõitsid	doc_489002948347_item	2432565	et	4	main
linna	doc_489002948347_item	2432566	et	4	main
kuigi	doc_489002948347_item	2432601	et	3	main
nad	doc_489002948347_item	2432602	et	3	main
müüa	doc_489002948347_item	2432609	et	3	main
talupoeg	doc_489002948347_item	2432612	et	3	main
vajaliku	doc_489002948347_item	2432614	et	3	main
koguda	doc_489002948347_item	2432616	et	3	main
ja	doc_489002948347_item	2432628	et	3	main
palgata	doc_489002948347_item	2432629	et	4	main
töölisi	doc_489002948347_item	2432630	et	3	main
tugevamaks	doc_489002948347_item	2432636	et	4	main
eesti	doc_489002948348_item	2432639	et	4	main
eesti	doc_489002948348_item	2432646	et	4	main
haridus-	doc_489002948348_item	2432647	et	3	main
kultuurielule	doc_489002948348_item	2432649	et	3	main
sisuliselt	doc_489002948348_item	2432660	et	4	main
tähendas	doc_489002948348_item	2432661	et	3	main
19	doc_489002948348_item	2432663	et	2	main
algul	doc_489002948348_item	2432665	et	4	main
hakatakse	doc_489002948348_item	2432666	et	3	main
põhja	doc_489002948348_item	2432671	et	4	main
tulu	doc_489002948348_item	2432675	et	4	main
lõuna-eestis	doc_489002948348_item	2432676	et	3	main
kasvatatakse	doc_489002948348_item	2432677	et	3	main
lina	doc_489002948348_item	2432678	et	4	main
osta	doc_489002948348_item	2432690	et	4	main
soetab	doc_489002948348_item	2432721	et	3	main
tallinnas	doc_489002948348_item	2432734	et	4	main
müüa	doc_489002948348_item	2432745	et	3	main
poodnikud	doc_489002948348_item	2432748	et	3	main
1837	doc_489002948348_item	2432753	et	2	main
põhja-eesti	doc_489002948348_item	2432756	et	4	main
pärisorjuseks	doc_489002948348_item	2432757	et	3	main
vabaks1819a	doc_489002948348_item	2432758	et	4	main
omada	doc_489002948348_item	2432764	et	3	main
minna	doc_489002948348_item	2432784	et	3	main
linna	doc_489002948348_item	2432785	et	4	main
oskasid	doc_489002948348_item	2432791	et	4	main
nt	doc_489002948348_item	2432795	et	4	main
ülikooli	doc_489002948348_item	2432799	et	4	main
1632	doc_489002948348_item	2432801	et	2	main
a	doc_489002948348_item	2432802	et	4	main
vaimulikke	doc_489002948348_item	2432814	et	3	main
haridus-	doc_489002948347_item	2432367	et	3	main
vabastati	doc_489002948347_item	2432372	et	3	main
pärisorjusest	doc_489002948347_item	2432374	et	4	main
tähendas	doc_489002948347_item	2432381	et	3	main
rektoriks	doc_489002948347_item	2432387	et	3	main
tähtis	doc_489002948347_item	2432395	et	4	main
sündmus	doc_489002948347_item	2432396	et	3	main
rohkem	doc_489002948347_item	2432399	et	4	main
eesti	doc_489002948347_item	2432406	et	4	main
keeles	doc_489002948347_item	2432407	et	4	main
ka	doc_489002948347_item	2432410	et	3	main
eesti	doc_489002948347_item	2432411	et	4	main
lektorid	doc_489002948347_item	2432416	et	3	main
tüs	doc_489002948347_item	2432420	et	4	main
oli	doc_489002948347_item	2432423	et	3	main
ka	doc_489002948347_item	2432440	et	3	main
õpetasid	doc_489002948347_item	2432460	et	4	main
fr	doc_489002948347_item	2432469	et	4	main
r	doc_489002948347_item	2432470	et	4	main
ained	doc_489002948347_item	2432483	et	3	main
füüsika	doc_489002948347_item	2432485	et	4	main
keemia	doc_489002948347_item	2432487	et	4	main
arenesid	doc_489002948347_item	2432488	et	4	main
väga	doc_489002948347_item	2432489	et	3	main
hästi	doc_489002948347_item	2432490	et	3	main
ja	doc_489002948347_item	2432491	et	3	main
tü	doc_489002948347_item	2432499	et	4	main
liikumise	doc_489002948347_item	2432505	et	4	main
2	doc_489002948347_item	2432507	et	2	main
pärisorjuse	doc_489002948347_item	2432508	et	3	main
likvideerimine	doc_489002948347_item	2432509	et	4	main
toimus	doc_489002948347_item	2432510	et	3	main
seda	doc_489002948347_item	2432517	et	3	main
mõisnikule	doc_489002948347_item	2432531	et	3	main
seal	doc_489002948347_item	2432538	et	4	main
oli	doc_489002948347_item	2432541	et	3	main
võimalus	doc_489002948347_item	2432543	et	3	main
ära	doc_489002948347_item	2432545	et	4	main
kuid	doc_489002948347_item	2432547	et	4	main
palju	doc_489002948347_item	2432553	et	4	main
hakasid	doc_489002948347_item	2432558	et	4	main
paljud	doc_489002948347_item	2432562	et	3	main
talupojad	doc_489002948347_item	2432564	et	4	main
otsima	doc_489002948347_item	2432568	et	4	main
rahvas	doc_489002948347_item	2432595	et	4	main
oli	doc_489002948347_item	2432596	et	3	main
ikka	doc_489002948347_item	2432597	et	4	main
ja	doc_489002948347_item	2432610	et	3	main
sai	doc_489002948347_item	2432613	et	4	main
siis	doc_489002948347_item	2432617	et	3	main
talu	doc_489002948347_item	2432621	et	4	main
osta	doc_489002948347_item	2432623	et	4	main
ja	doc_489002948347_item	2432624	et	3	main
olla	doc_489002948347_item	2432625	et	3	main
iseenese	doc_489002948347_item	2432626	et	3	main
selle	doc_489002948347_item	2432631	et	4	main
kontrolltöö	doc_489002948348_item	2432638	et	4	main
kultuuriloost	doc_489002948348_item	2432640	et	4	main
1	doc_489002948348_item	2432641	et	2	main
tartu	doc_489002948348_item	2432642	et	4	main
ja	doc_489002948348_item	2432648	et	3	main
ja	doc_489002948348_item	2432655	et	3	main
saab	doc_489002948348_item	2432670	et	3	main
head	doc_489002948348_item	2432674	et	4	main
see	doc_489002948348_item	2432679	et	3	main
on	doc_489002948348_item	2432680	et	4	main
rahateenimisvõimalus	doc_489002948348_item	2432681	et	3	main
päriseks	doc_489002948348_item	2432688	et	4	main
jõukad	doc_489002948348_item	2432692	et	3	main
1840a	doc_489002948348_item	2432694	et	4	main
osa	doc_489002948348_item	2432696	et	4	main
talurahvast	doc_489002948348_item	2432697	et	4	main
endale	doc_489002948348_item	2432722	et	4	main
schwartz	doc_489002948348_item	2432725	et	4	main
saavad	doc_489002948348_item	2432742	et	4	main
toodanguid	doc_489002948348_item	2432744	et	3	main
tekkivad	doc_489002948348_item	2432746	et	4	main
aerulaevad	doc_489002948348_item	2432752	et	4	main
ä	doc_489002948348_item	2432759	et	4	main
lõuna-eesti	doc_489002948348_item	2432760	et	4	main
nende	doc_489002948347_item	2432378	et	4	main
taasavati	doc_489002948347_item	2432384	et	3	main
aastal	doc_489002948347_item	2432386	et	3	main
läbi	doc_489002948347_item	2432402	et	4	main
mõned	doc_489002948347_item	2432404	et	3	main
paljud	doc_489002948347_item	2432414	et	3	main
see	doc_489002948347_item	2432421	et	3	main
ja	doc_489002948347_item	2432427	et	3	main
inimestele	doc_489002948347_item	2432430	et	3	main
tü	doc_489002948347_item	2432432	et	4	main
oli	doc_489002948347_item	2432433	et	3	main
parimaid	doc_489002948347_item	2432435	et	4	main
baltimaade	doc_489002948347_item	2432436	et	3	main
venelased	doc_489002948347_item	2432441	et	3	main
sakslased	doc_489002948347_item	2432443	et	3	main
tüs	doc_489002948347_item	2432445	et	4	main
väga	doc_489002948347_item	2432447	et	3	main
tegelased	doc_489002948347_item	2432457	et	3	main
tüs	doc_489002948347_item	2432461	et	4	main
ajal	doc_489002948347_item	2432463	et	4	main
baer	doc_489002948347_item	2432466	et	4	main
hurt	doc_489002948347_item	2432468	et	3	main
kuigi	doc_489002948347_item	2432474	et	3	main
ajal	doc_489002948347_item	2432476	et	4	main
paljude	doc_489002948347_item	2432477	et	3	main
erialade	doc_489002948347_item	2432478	et	3	main
areng	doc_489002948347_item	2432479	et	3	main
halvenes	doc_489002948347_item	2432480	et	3	main
siiski	doc_489002948347_item	2432481	et	4	main
eesti	doc_489002948347_item	2432496	et	4	main
oli	doc_489002948347_item	2432501	et	3	main
samm	doc_489002948347_item	2432503	et	3	main
poole	doc_489002948347_item	2432506	et	4	main
tähendas	doc_489002948347_item	2432516	et	3	main
rahvuste	doc_489002948347_item	2432429	et	3	main
ülikoole	doc_489002948347_item	2432437	et	4	main
jne	doc_489002948347_item	2432444	et	4	main
oli	doc_489002948347_item	2432446	et	3	main
raamatukogu	doc_489002948347_item	2432449	et	4	main
mille	doc_489002948347_item	2432450	et	3	main
rajaja	doc_489002948347_item	2432451	et	4	main
oli	doc_489002948347_item	2432452	et	3	main
karl	doc_489002948347_item	2432453	et	4	main
margenstern	doc_489002948347_item	2432454	et	4	main
ja	doc_489002948347_item	2432459	et	3	main
tol	doc_489002948347_item	2432462	et	3	main
niisugused	doc_489002948347_item	2432482	et	3	main
rohkem	doc_489002948347_item	2432495	et	4	main
taasavamine	doc_489002948347_item	2432500	et	4	main
üks	doc_489002948347_item	2432502	et	3	main
eestimaal	doc_489002948347_item	2432511	et	4	main
et	doc_489002948347_item	2432518	et	3	main
olid	doc_489002948347_item	2432520	et	4	main
vabad	doc_489002948347_item	2432522	et	3	main
maksma	doc_489002948347_item	2432530	et	3	main
renti	doc_489002948347_item	2432534	et	4	main
ei	doc_489002948347_item	2432549	et	4	main
ja	doc_489002948347_item	2432556	et	3	main
palgatöölisteks	doc_489002948347_item	2432559	et	4	main
sammuti	doc_489002948347_item	2432561	et	3	main
oma	doc_489002948347_item	2432599	et	4	main
vallutajatest	doc_489002948347_item	2432600	et	4	main
said	doc_489002948347_item	2432603	et	4	main
toota	doc_489002948347_item	2432604	et	3	main
oma	doc_489002948347_item	2432605	et	4	main
kauba	doc_489002948347_item	2432606	et	3	main
ja	doc_489002948347_item	2432607	et	3	main
seda	doc_489002948347_item	2432608	et	3	main
välja	doc_489002948347_item	2432622	et	4	main
peremees	doc_489002948347_item	2432627	et	4	main
sai	doc_489002948347_item	2432633	et	4	main
kontrolltöö	doc_489002948348_item	2432637	et	4	main
tähtsus	doc_489002948348_item	2432645	et	4	main
vabastati	doc_489002948348_item	2432652	et	3	main
mida	doc_489002948348_item	2432656	et	4	main
see	doc_489002948348_item	2432657	et	3	main
nende	doc_489002948348_item	2432658	et	4	main
kasvatama	doc_489002948348_item	2432668	et	4	main
maad	doc_489002948348_item	2432689	et	4	main
talupojad	doc_489002948348_item	2432693	et	4	main
maa	doc_489002948347_item	2432532	et	4	main
küll	doc_489002948347_item	2432540	et	4	main
nad	doc_489002948347_item	2432557	et	3	main
mõisadel	doc_489002948347_item	2432560	et	4	main
tööd	doc_489002948347_item	2432567	et	4	main
kuid	doc_489002948347_item	2432569	et	4	main
enamik	doc_489002948347_item	2432570	et	3	main
neist	doc_489002948347_item	2432571	et	4	main
leidnud	doc_489002948347_item	2432573	et	4	main
ei	doc_489002948347_item	2432572	et	4	main
tööd	doc_489002948347_item	2432574	et	4	main
aga	doc_489002948347_item	2432575	et	3	main
mõned	doc_489002948347_item	2432576	et	3	main
leidsid	doc_489002948347_item	2432577	et	4	main
ja	doc_489002948347_item	2432578	et	3	main
isegi	doc_489002948347_item	2432579	et	4	main
rajasid	doc_489002948347_item	2432580	et	4	main
oma	doc_489002948347_item	2432581	et	4	main
äri	doc_489002948347_item	2432582	et	4	main
aga	doc_489002948347_item	2432583	et	3	main
neid	doc_489002948347_item	2432584	et	4	main
oli	doc_489002948347_item	2432585	et	3	main
üksikud	doc_489002948347_item	2432586	et	3	main
pärisorjuse	doc_489002948347_item	2432587	et	3	main
likvideerimine	doc_489002948347_item	2432588	et	4	main
tähendas	doc_489002948347_item	2432589	et	3	main
küll	doc_489002948347_item	2432590	et	4	main
vaimset	doc_489002948347_item	2432591	et	3	main
vabadust	doc_489002948347_item	2432592	et	4	main
kuid	doc_489002948347_item	2432593	et	4	main
et	doc_489002948347_item	2432535	et	3	main
nad	doc_489002948347_item	2432536	et	3	main
saaksid	doc_489002948347_item	2432537	et	4	main
maad	doc_489002948347_item	2432544	et	4	main
osta	doc_489002948347_item	2432546	et	4	main
saanud	doc_489002948347_item	2432550	et	4	main
veel	doc_489002948347_item	2432551	et	4	main
nii	doc_489002948347_item	2432552	et	3	main
vabanenud	doc_489002948347_item	2432563	et	4	main
eesti	doc_489002948347_item	2432594	et	4	main
sõltuv	doc_489002948347_item	2432598	et	4	main
kui	doc_489002948347_item	2432611	et	3	main
tõttu	doc_489002948347_item	2432632	et	4	main
eesti	doc_489002948347_item	2432634	et	4	main
rahvas	doc_489002948347_item	2432635	et	4	main
taasavamise	doc_489002948348_item	2432644	et	4	main
millal	doc_489002948348_item	2432651	et	3	main
eestlased	doc_489002948348_item	2432653	et	3	main
jaoks	doc_489002948348_item	2432659	et	4	main
kartulist	doc_489002948348_item	2432669	et	4	main
väga	doc_489002948348_item	2432673	et	3	main
koguvad	doc_489002948348_item	2432683	et	4	main
raha	doc_489002948348_item	2432684	et	4	main
ja	doc_489002948348_item	2432685	et	3	main
nad	doc_489002948348_item	2432686	et	3	main
saavad	doc_489002948348_item	2432687	et	4	main
hakkatakse	doc_489002948348_item	2432735	et	4	main
1810a	doc_489002948348_item	2432740	et	4	main
talupojad	doc_489002948348_item	2432741	et	4	main
oma	doc_489002948348_item	2432743	et	4	main
poed	doc_489002948348_item	2432749	et	4	main
postijaamad	doc_489002948348_item	2432751	et	3	main
võimalus	doc_489002948348_item	2432763	et	3	main
talupojad	doc_489002948348_item	2432790	et	4	main
2	doc_489002948348_item	2432797	et	2	main
asutati	doc_489002948348_item	2432804	et	4	main
tartusse	doc_489002948348_item	2432805	et	3	main
jesuiitide	doc_489002948348_item	2432806	et	3	main
kes	doc_489002948348_item	2432812	et	4	main
jumalateenistust	doc_489002948348_item	2432815	et	3	main
et	doc_489002948348_item	2432826	et	3	main
tuli	doc_489002948348_item	2432830	et	4	main
saanud	doc_489002948348_item	2432837	et	4	main
õppida	doc_489002948348_item	2432838	et	3	main
tüdrukud	doc_489002948348_item	2432839	et	3	main
1632a	doc_489002948348_item	2432840	et	4	main
muutub	doc_489002948348_item	2432841	et	3	main
gümnaasiumist	doc_489002948348_item	2432842	et	4	main
õppida	doc_489002948348_item	2432846	et	3	main
õigusteadust	doc_489002948348_item	2432847	et	4	main
ja	doc_489002948348_item	2432849	et	3	main
arstiteadust	doc_489002948348_item	2432850	et	4	main
filosoofiat	doc_489002948348_item	2432851	et	3	main
1680a	doc_489002948348_item	2432852	et	4	main
anti	doc_489002948348_item	2432853	et	3	main
ajalooline	doc_489002948348_item	2432856	et	4	main
range	doc_489002948348_item	2432861	et	4	main
kord	doc_489002948348_item	2432862	et	4	main
kuu	doc_489002948348_item	2432866	et	4	main
kirjutama	doc_489002948348_item	2432873	et	3	main
harud	doc_491521501646_item	2432890	et	3	main
häälikuline	doc_491521501646_item	2432892	et	4	main
ja	doc_491521501646_item	2432926	et	3	main
kokku	doc_491521501646_item	2432928	et	3	main
sõnavara	doc_491521501646_item	2432930	et	4	main
tahendab	doc_491521501646_item	2432934	et	3	main
transkriptsioonid	doc_491521501646_item	2432937	et	3	main
aitavad	doc_491521501646_item	2432939	et	4	main
inimestele	doc_491521501646_item	2432940	et	3	main
õigesti	doc_491521501646_item	2432941	et	3	main
sõna	doc_491521501646_item	2432942	et	4	main
hääldama	doc_491521501646_item	2432943	et	3	main
referaat	doc_491521501647_item	2432944	et	3	main
heinast	doc_491521501647_item	2432954	et	4	main
või	doc_491521501647_item	2432958	et	4	main
seda	doc_491521501647_item	2432965	et	3	main
tegemisel	doc_491521501647_item	2432971	et	4	main
oli	doc_491521501647_item	2432972	et	3	main
tema	doc_491521501647_item	2432973	et	4	main
riietumine	doc_491521501647_item	2432974	et	4	main
vanad	doc_491521501647_item	2432978	et	3	main
rahasumma	doc_489002948347_item	2432615	et	4	main
sai	doc_489002948347_item	2432618	et	4	main
ta	doc_489002948347_item	2432619	et	4	main
ka	doc_489002948347_item	2432620	et	3	main
ülikooli	doc_489002948348_item	2432643	et	4	main
2	doc_489002948348_item	2432650	et	2	main
pärisorjusest	doc_489002948348_item	2432654	et	4	main
2	doc_489002948348_item	2432662	et	2	main
saj	doc_489002948348_item	2432664	et	4	main
kartulit	doc_489002948348_item	2432667	et	3	main
eestis	doc_489002948348_item	2432672	et	3	main
talupojad	doc_489002948348_item	2432682	et	4	main
tekkivad	doc_489002948348_item	2432691	et	4	main
muutma	doc_489002948348_item	2432698	et	3	main
hakkab	doc_489002948348_item	2432695	et	3	main
usku	doc_489002948348_item	2432699	et	4	main
1860a	doc_489002948348_item	2432700	et	4	main
talude	doc_489002948348_item	2432701	et	3	main
väljaostmine	doc_489002948348_item	2432702	et	3	main
linnaelanike	doc_489002948348_item	2432703	et	3	main
arv	doc_489002948348_item	2432704	et	3	main
hakkab	doc_489002948348_item	2432705	et	3	main
kasvama	doc_489002948348_item	2432706	et	3	main
igas	doc_489002948348_item	2432707	et	3	main
linnas	doc_489002948348_item	2432708	et	4	main
elanikud	doc_489002948348_item	2432709	et	3	main
hakkavad	doc_489002948348_item	2432710	et	4	main
tööle	doc_489002948348_item	2432711	et	3	main
rätsepaks	doc_489002948348_item	2432712	et	3	main
potsepaks	doc_489002948348_item	2432713	et	4	main
jne	doc_489002948348_item	2432714	et	4	main
hans	doc_489002948348_item	2432715	et	4	main
tuleb	doc_489002948348_item	2432717	et	3	main
tööle	doc_489002948348_item	2432718	et	3	main
puumeistrina	doc_489002948348_item	2432719	et	3	main
aga	doc_489002948348_item	2432720	et	3	main
falck	doc_489002948348_item	2432716	et	4	main
vabriku	doc_489002948348_item	2432724	et	3	main
narva	doc_489002948348_item	2432727	et	4	main
tõelise	doc_489002948348_item	2432729	et	4	main
jne	doc_489002948348_item	2432733	et	4	main
põllum	doc_489002948348_item	2432738	et	4	main
riiste	doc_489002948348_item	2432739	et	3	main
väikesed	doc_489002948348_item	2432747	et	4	main
a	doc_489002948348_item	2432754	et	4	main
1816a	doc_489002948348_item	2432755	et	4	main
talupoegadel	doc_489002948348_item	2432761	et	3	main
on	doc_489002948348_item	2432762	et	4	main
nad	doc_489002948348_item	2432783	et	3	main
või	doc_489002948348_item	2432786	et	4	main
raha	doc_489002948348_item	2432792	et	4	main
tartu	doc_489002948348_item	2432798	et	4	main
rajamine	doc_489002948348_item	2432800	et	4	main
seminaar	doc_489002948348_item	2432807	et	4	main
eesmärk	doc_489002948348_item	2432808	et	3	main
on	doc_489002948348_item	2432809	et	4	main
koolitada	doc_489002948348_item	2432810	et	3	main
tõlke	doc_489002948348_item	2432811	et	4	main
tartusse	doc_489002948348_item	2432818	et	3	main
gümnaasiumis	doc_489002948348_item	2432821	et	3	main
gümnaasiumisse	doc_489002948348_item	2432828	et	3	main
linnakoolis	doc_489002948348_item	2432832	et	4	main
paberi	doc_489002948348_item	2432723	et	3	main
rajab	doc_489002948348_item	2432726	et	3	main
esimese	doc_489002948348_item	2432728	et	3	main
vabriku	doc_489002948348_item	2432730	et	3	main
esimesed	doc_489002948348_item	2432731	et	3	main
ketramismasinad	doc_489002948348_item	2432732	et	4	main
tootma	doc_489002948348_item	2432736	et	3	main
tikke	doc_489002948348_item	2432737	et	4	main
postkontorid	doc_489002948348_item	2432750	et	3	main
nad	doc_489002948348_item	2432766	et	3	main
ei	doc_489002948348_item	2432767	et	4	main
osta	doc_489002948348_item	2432769	et	4	main
saa	doc_489002948348_item	2432768	et	4	main
müüa	doc_489002948348_item	2432770	et	3	main
hakkati	doc_489002948348_item	2432771	et	3	main
panema	doc_489002948348_item	2432772	et	3	main
perekonnanimed	doc_489002948348_item	2432773	et	3	main
maad	doc_489002948348_item	2432774	et	4	main
kuulusid	doc_489002948348_item	2432775	et	4	main
mõisnikutele	doc_489002948348_item	2432776	et	4	main
nad	doc_489002948348_item	2432777	et	3	main
pidid	doc_489002948348_item	2432778	et	4	main
maad	doc_489002948348_item	2432779	et	4	main
rentima	doc_489002948348_item	2432780	et	3	main
1832a	doc_489002948348_item	2432781	et	4	main
said	doc_489002948348_item	2432782	et	4	main
kinnisvara	doc_489002948348_item	2432765	et	4	main
välismaale	doc_489002948348_item	2432787	et	4	main
elama	doc_489002948348_item	2432788	et	3	main
kõrvale	doc_489002948348_item	2432793	et	4	main
kõrtsmikud	doc_489002948348_item	2432796	et	3	main
asutati	doc_489002948348_item	2432817	et	4	main
esimene	doc_489002948348_item	2432819	et	3	main
nutikamad	doc_489002948348_item	2432789	et	4	main
panna	doc_489002948348_item	2432794	et	4	main
1583a	doc_489002948348_item	2432803	et	4	main
abistasid	doc_489002948348_item	2432813	et	4	main
1630	doc_489002948348_item	2432816	et	2	main
gümnaasium	doc_489002948348_item	2432820	et	3	main
õppida	doc_489002948348_item	2432823	et	3	main
poisid	doc_489002948348_item	2432825	et	4	main
ülikool	doc_489002948348_item	2432843	et	4	main
usu-	doc_489002948348_item	2432848	et	4	main
iga	doc_489002948348_item	2432865	et	4	main
kell	doc_489002948348_item	2432869	et	3	main
hommikul	doc_489002948348_item	2432871	et	3	main
ei	doc_489002948348_item	2432880	et	4	main
saanud	doc_489002948348_item	2432881	et	4	main
seda	doc_489002948348_item	2432882	et	3	main
visati	doc_489002948348_item	2432883	et	3	main
foneetika	doc_491521501646_item	2432891	et	4	main
see	doc_491521501646_item	2432922	et	3	main
fonoloogia	doc_491521501646_item	2432924	et	4	main
mis	doc_491521501646_item	2432932	et	4	main
sõna	doc_491521501646_item	2432933	et	4	main
võis	doc_491521501647_item	2432951	et	4	main
kes	doc_491521501647_item	2432963	et	4	main
tähtsamaks	doc_491521501647_item	2432968	et	4	main
selle	doc_491521501647_item	2432969	et	4	main
rõivad	doc_491521501647_item	2432975	et	3	main
peavad	doc_491521501647_item	2432976	et	4	main
pahupidi	doc_491521501647_item	2432985	et	3	main
karusnahaga	doc_491521501647_item	2432987	et	3	main
keha	doc_491521501647_item	2432992	et	4	main
välimusega	doc_491521501647_item	2433024	et	3	main
joonistati	doc_491521501647_item	2433026	et	4	main
pidulikude	doc_491521501647_item	2433038	et	4	main
atribuutidega	doc_491521501647_item	2433039	et	3	main
istuma	doc_491521501647_item	2433047	et	3	main
midagi	doc_491521501647_item	2433059	et	4	main
tõsist	doc_491521501647_item	2433060	et	4	main
õlest	doc_491521501647_item	2433067	et	4	main
nukk	doc_491521501647_item	2433068	et	3	main
mõnedes	doc_491521501647_item	2433069	et	3	main
kubermangudes	doc_491521501647_item	2433070	et	3	main
kujutatud	doc_491521501647_item	2433075	et	4	main
sajandil	doc_491521501647_item	2433083	et	3	main
venemaa	doc_491521501647_item	2433085	et	4	main
välja	doc_491521501647_item	2433096	et	4	main
ainult	doc_489002948348_item	2432824	et	4	main
sisse	doc_489002948348_item	2432829	et	4	main
õppida	doc_489002948348_item	2432831	et	3	main
3	doc_489002948348_item	2432833	et	2	main
klassi	doc_489002948348_item	2432834	et	4	main
gümnaasiumis	doc_489002948348_item	2432835	et	3	main
ülikoolis	doc_489002948348_item	2432844	et	4	main
välja	doc_489002948348_item	2432854	et	4	main
trs	doc_489002948348_item	2432855	et	4	main
ülikoolis	doc_489002948348_item	2432858	et	4	main
olid	doc_489002948348_item	2432864	et	4	main
7	doc_489002948348_item	2432870	et	2	main
õpiti	doc_489002948348_item	2432872	et	3	main
aru	doc_489002948348_item	2432879	et	4	main
keeleteaduse	doc_491521501646_item	2432889	et	3	main
on	doc_491521501646_item	2432895	et	4	main
huvitav	doc_491521501646_item	2432896	et	4	main
see	doc_491521501646_item	2432897	et	3	main
kui	doc_491521501646_item	2432898	et	3	main
haaldatakse	doc_491521501646_item	2432899	et	4	main
sõna	doc_491521501646_item	2432900	et	4	main
ode	doc_491521501646_item	2432901	et	4	main
fonoloogia	doc_491521501646_item	2432902	et	4	main
missugused	doc_491521501646_item	2432903	et	3	main
foneemi	doc_491521501646_item	2432904	et	4	main
ühes	doc_491521501646_item	2432905	et	4	main
ja	doc_491521501646_item	2432906	et	3	main
teises	doc_491521501646_item	2432907	et	4	main
keeles	doc_491521501646_item	2432908	et	4	main
on	doc_491521501646_item	2432909	et	4	main
ja	doc_491521501646_item	2432910	et	3	main
tingimuses	doc_491521501646_item	2432912	et	3	main
millises	doc_491521501646_item	2432911	et	3	main
nad	doc_491521501646_item	2432913	et	3	main
kombineerivad	doc_491521501646_item	2432914	et	4	main
grammatika	doc_491521501646_item	2432915	et	4	main
õpib	doc_491521501646_item	2432916	et	3	main
kuidas	doc_491521501646_item	2432917	et	3	main
õigesti	doc_491521501646_item	2432918	et	3	main
sõna	doc_491521501646_item	2432919	et	4	main
kirjutama	doc_491521501646_item	2432920	et	3	main
gramatika	doc_491521501646_item	2432921	et	4	main
õpetus	doc_491521501646_item	2432931	et	4	main
on	doc_491521501646_item	2432936	et	4	main
mis	doc_491521501646_item	2432938	et	4	main
venelastel	doc_491521501647_item	2432947	et	4	main
vastlapäeva	doc_491521501647_item	2432949	et	4	main
või	doc_491521501647_item	2432960	et	4	main
reaalse	doc_491521501647_item	2432961	et	3	main
rolli	doc_491521501647_item	2432966	et	4	main
kõige	doc_491521501647_item	2432967	et	4	main
nukku	doc_491521501647_item	2432970	et	4	main
kulunud	doc_491521501647_item	2432979	et	4	main
mõnikord	doc_491521501647_item	2432982	et	3	main
väljapoole	doc_491521501647_item	2432988	et	3	main
said	doc_489002948348_item	2432822	et	4	main
saada	doc_489002948348_item	2432827	et	4	main
ei	doc_489002948348_item	2432836	et	4	main
võib	doc_489002948348_item	2432845	et	3	main
oli	doc_489002948348_item	2432859	et	3	main
väga	doc_489002948348_item	2432860	et	3	main
loengud	doc_489002948348_item	2432867	et	3	main
ja	doc_489002948348_item	2432874	et	3	main
ladina	doc_489002948348_item	2432876	et	4	main
keeles	doc_489002948348_item	2432877	et	4	main
välja	doc_489002948348_item	2432884	et	4	main
uus	doc_491521501645_item	2432885	et	3	main
dokument	doc_491521501645_item	2432886	et	3	main
test	doc_491521501645_item	2432887	et	3	main
õpetus	doc_491521501646_item	2432893	et	4	main
morfoloogia	doc_491521501646_item	2432925	et	4	main
liksikoloogia	doc_491521501646_item	2432929	et	4	main
vastlapäeva	doc_491521501647_item	2432945	et	4	main
hernehirmutis	doc_491521501647_item	2432950	et	4	main
kujutatud	doc_491521501647_item	2432953	et	4	main
või	doc_491521501647_item	2432955	et	4	main
puust	doc_491521501647_item	2432956	et	4	main
mehena	doc_491521501647_item	2432957	et	3	main
mängis	doc_491521501647_item	2432964	et	3	main
rebinud	doc_491521501647_item	2432980	et	4	main
kasukas	doc_491521501647_item	2432989	et	4	main
jaoks	doc_491521501647_item	2432993	et	4	main
et	doc_491521501647_item	2433021	et	3	main
silmad	doc_491521501647_item	2433027	et	4	main
pere	doc_491521501647_item	2433034	et	4	main
nuku	doc_491521501647_item	2433035	et	3	main
vastavate	doc_491521501647_item	2433037	et	4	main
kodus	doc_491521501647_item	2433045	et	4	main
asendis	doc_491521501647_item	2433049	et	3	main
rituaal	doc_491521501647_item	2433056	et	3	main
kuid	doc_491521501647_item	2433061	et	4	main
mitte	doc_491521501647_item	2433062	et	3	main
alati	doc_491521501647_item	2433063	et	4	main
peamiseks	doc_491521501647_item	2433064	et	3	main
hernehirmutis	doc_491521501647_item	2433071	et	4	main
puust	doc_491521501647_item	2433073	et	4	main
lumememmena	doc_491521501647_item	2433076	et	3	main
mida	doc_491521501647_item	2433077	et	4	main
veeretati	doc_491521501647_item	2433078	et	3	main
kelkudega	doc_491521501647_item	2433079	et	3	main
mäest	doc_491521501647_item	2433080	et	3	main
spetsiaalselt	doc_491521501647_item	2433095	et	4	main
või	doc_491521501647_item	2433122	et	4	main
lärmiga	doc_491521501647_item	2433125	et	3	main
teda	doc_491521501647_item	2433126	et	4	main
riietus	doc_491521501647_item	2433133	et	4	main
protsessiooni	doc_491521501647_item	2433138	et	4	main
naases	doc_491521501647_item	2433140	et	4	main
terve	doc_491521501648_item	2433147	et	4	main
tegi	doc_491521501648_item	2433149	et	4	main
jooksul	doc_491521501648_item	2433173	et	4	main
laste	doc_491521501648_item	2433174	et	4	main
vihk	doc_491521501648_item	2433178	et	3	main
kolu	doc_491521501648_item	2433180	et	4	main
tavaliselt	doc_491521501648_item	2433181	et	4	main
korjasid	doc_491521501648_item	2433182	et	4	main
jooksul	doc_491521501648_item	2433187	et	4	main
tihti	doc_491521501648_item	2433194	et	3	main
latt	doc_491521501648_item	2433201	et	3	main
kõrge	doc_491521501648_item	2433208	et	4	main
koht	doc_491521501648_item	2433209	et	3	main
et	doc_491521501648_item	2433229	et	3	main
erksam	doc_491521501648_item	2433231	et	4	main
see	doc_491521501648_item	2433232	et	3	main
seda	doc_491521501648_item	2433234	et	3	main
vanausumuusika	doc_491521501649_item	2433246	et	4	main
kontsert	doc_491521501649_item	2433247	et	3	main
kolkja	doc_491521501649_item	2433248	et	4	main
grezn	doc_491521501649_item	2433256	et	4	main
riia	doc_491521501649_item	2433257	et	4	main
koorijuht	doc_491521501649_item	2433258	et	3	main
kolkja	doc_491521501649_item	2433261	et	4	main
koor	doc_491521501649_item	2433263	et	4	main
alguses	doc_491521501649_item	2433282	et	4	main
tuua	doc_491521501649_item	2433322	et	3	main
repertuaari	doc_491521501649_item	2433324	et	4	main
raamat	doc_489002948348_item	2432857	et	3	main
eksamid	doc_489002948348_item	2432863	et	3	main
hakkasid	doc_489002948348_item	2432868	et	4	main
lugema	doc_489002948348_item	2432875	et	4	main
kes	doc_489002948348_item	2432878	et	4	main
eksamitöö	doc_491521501646_item	2432888	et	4	main
foneetikal	doc_491521501646_item	2432894	et	3	main
on	doc_491521501646_item	2432923	et	4	main
semantika	doc_491521501646_item	2432927	et	4	main
foneetikas	doc_491521501646_item	2432935	et	3	main
hernehirmutis	doc_491521501647_item	2432946	et	4	main
venemaal	doc_491521501647_item	2432948	et	4	main
olla	doc_491521501647_item	2432952	et	3	main
naisena	doc_491521501647_item	2432959	et	3	main
inimesena	doc_491521501647_item	2432962	et	3	main
olema	doc_491521501647_item	2432977	et	4	main
aga	doc_491521501647_item	2432981	et	3	main
peale	doc_491521501647_item	2432984	et	4	main
nii	doc_491521501647_item	2432990	et	3	main
kui	doc_491521501647_item	2432994	et	3	main
ka	doc_491521501647_item	2432995	et	3	main
kogu	doc_491521501647_item	2432996	et	4	main
tema	doc_491521501647_item	2432997	et	4	main
riietus	doc_491521501647_item	2432998	et	4	main
tuli	doc_491521501647_item	2432999	et	4	main
tingimata	doc_491521501647_item	2433000	et	4	main
erinevatest	doc_491521501647_item	2433001	et	4	main
kodudest	doc_491521501647_item	2433002	et	3	main
kokku	doc_491521501647_item	2433003	et	3	main
korjata	doc_491521501647_item	2433004	et	4	main
muutes	doc_491521501647_item	2433005	et	4	main
hernrhirmutist	doc_491521501647_item	2433006	et	4	main
küla	doc_491521501647_item	2433007	et	4	main
sümboliks	doc_491521501647_item	2433008	et	4	main
paljudes	doc_491521501647_item	2433009	et	3	main
külades	doc_491521501647_item	2433010	et	3	main
tehti	doc_491521501647_item	2433011	et	3	main
ka	doc_491521501647_item	2433012	et	3	main
oma	doc_491521501647_item	2433013	et	4	main
pere	doc_491521501647_item	2433014	et	4	main
nukke	doc_491521501647_item	2433015	et	3	main
nad	doc_491521501647_item	2433016	et	3	main
küla	doc_491521501647_item	2433018	et	4	main
erinesid	doc_491521501647_item	2433017	et	4	main
hernehirmutisest	doc_491521501647_item	2433019	et	4	main
sellega	doc_491521501647_item	2433020	et	3	main
kena	doc_491521501647_item	2433023	et	4	main
panniga	doc_491521501647_item	2433040	et	4	main
kulbiga	doc_491521501647_item	2433041	et	3	main
sellises	doc_491521501647_item	2433048	et	4	main
nagu	doc_491521501647_item	2433050	et	3	main
küpsetaks	doc_491521501647_item	2433052	et	4	main
pannkooke	doc_491521501647_item	2433053	et	4	main
ei	doc_491521501647_item	2433057	et	4	main
sümboliksoli	doc_491521501647_item	2433066	et	4	main
teistes	doc_491521501647_item	2433074	et	4	main
alla	doc_491521501647_item	2433081	et	3	main
piirkondades	doc_491521501647_item	2433086	et	3	main
vastlapäeva	doc_491521501647_item	2433087	et	4	main
hernehirmutise	doc_491521501647_item	2433088	et	3	main
rolli	doc_491521501647_item	2433089	et	4	main
mängis	doc_491521501647_item	2433090	et	3	main
tõmmati	doc_491521501647_item	2432983	et	3	main
pööratud	doc_491521501647_item	2432986	et	4	main
heina	doc_491521501647_item	2432991	et	4	main
neile	doc_491521501647_item	2433025	et	4	main
kulmud	doc_491521501647_item	2433028	et	3	main
nina	doc_491521501647_item	2433029	et	4	main
riietati	doc_491521501647_item	2433030	et	3	main
erksatesse	doc_491521501647_item	2433031	et	3	main
pidulikkesse	doc_491521501647_item	2433032	et	3	main
kostüümidesse	doc_491521501647_item	2433033	et	3	main
varustati	doc_491521501647_item	2433036	et	3	main
kuid	doc_491521501647_item	2433054	et	4	main
see	doc_491521501647_item	2433055	et	3	main
tähendanud	doc_491521501647_item	2433058	et	4	main
oli	doc_491521501647_item	2433072	et	3	main
xix	doc_491521501647_item	2433082	et	4	main
ühiskonna	doc_491521501647_item	2433098	et	4	main
jaoks	doc_491521501647_item	2433099	et	4	main
teda	doc_491521501647_item	2433100	et	4	main
riietati	doc_491521501647_item	2433101	et	3	main
kulunud	doc_491521501647_item	2433102	et	4	main
ja	doc_491521501647_item	2433103	et	3	main
rebitud	doc_491521501647_item	2433104	et	4	main
mehe	doc_491521501647_item	2433105	et	3	main
rõivadesse	doc_491521501647_item	2433106	et	4	main
mõnikord	doc_491521501647_item	2433107	et	3	main
naise	doc_491521501647_item	2433108	et	3	main
varustati	doc_491521501647_item	2433109	et	3	main
arvukate	doc_491521501647_item	2433110	et	4	main
tobedate	doc_491521501647_item	2433111	et	3	main
rekvisiitidega	doc_491521501647_item	2433112	et	3	main
ja	doc_491521501647_item	2433113	et	3	main
selline	doc_491521501647_item	2433115	et	4	main
liikumisvahenditega	doc_491521501647_item	2433114	et	3	main
fantastiliselt	doc_491521501647_item	2433116	et	4	main
riietatud	doc_491521501647_item	2433117	et	4	main
inimene	doc_491521501647_item	2433118	et	3	main
sõitis	doc_491521501647_item	2433119	et	3	main
hobusega	doc_491521501647_item	2433120	et	4	main
saatsid	doc_491521501647_item	2433127	et	4	main
ühekülainimesed	doc_491521501647_item	2433128	et	3	main
tavalistesse	doc_491521501647_item	2433134	et	4	main
lõke	doc_491521501648_item	2433152	et	4	main
aasta	doc_491521501648_item	2433172	et	4	main
vihad	doc_491521501648_item	2433177	et	4	main
väikesed	doc_491521501648_item	2433183	et	4	main
lapsed	doc_491521501648_item	2433184	et	3	main
eelneva	doc_491521501648_item	2433185	et	4	main
küla	doc_491521501648_item	2433192	et	4	main
oli	doc_491521501648_item	2433197	et	3	main
kinnitatud	doc_491521501648_item	2433198	et	4	main
ritv	doc_491521501648_item	2433200	et	3	main
lõke	doc_491521501648_item	2433205	et	4	main
vastlapäeva	doc_491521501648_item	2433213	et	4	main
lõke	doc_491521501648_item	2433215	et	4	main
põlema	doc_491521501648_item	2433221	et	4	main
näha	doc_491521501648_item	2433227	et	3	main
kavaleht	doc_491521501649_item	2433238	et	3	main
vald	doc_491521501649_item	2433265	et	3	main
marina	doc_491521501649_item	2433267	et	3	main
kolkja	doc_491521501649_item	2433269	et	4	main
olid	doc_491521501647_item	2433022	et	4	main
pannkoogidega	doc_491521501647_item	2433042	et	4	main
ja	doc_491521501647_item	2433043	et	3	main
pandi	doc_491521501647_item	2433044	et	4	main
pingile	doc_491521501647_item	2433046	et	3	main
ta	doc_491521501647_item	2433051	et	4	main
püha	doc_491521501647_item	2433065	et	4	main
mõnedes	doc_491521501647_item	2433084	et	3	main
valitud	doc_491521501647_item	2433097	et	4	main
külast	doc_491521501647_item	2433129	et	4	main
välja	doc_491521501647_item	2433130	et	4	main
rõivadesse	doc_491521501647_item	2433135	et	4	main
vastlapäeva	doc_491521501648_item	2433144	et	4	main
lõke	doc_491521501648_item	2433145	et	4	main
venelastel	doc_491521501648_item	2433146	et	4	main
vankri	doc_491521501648_item	2433167	et	3	main
ratad	doc_491521501648_item	2433168	et	4	main
vanad	doc_491521501648_item	2433176	et	3	main
kogu	doc_491521501648_item	2433191	et	4	main
keset	doc_491521501648_item	2433195	et	4	main
pikk	doc_491521501648_item	2433199	et	4	main
rataga	doc_491521501648_item	2433202	et	4	main
otsas	doc_491521501648_item	2433203	et	4	main
kus	doc_491521501648_item	2433210	et	3	main
vastuvõtmine	doc_491521501648_item	2433214	et	3	main
hästi	doc_491521501648_item	2433226	et	3	main
mida	doc_491521501648_item	2433230	et	4	main
on	doc_491521501648_item	2433233	et	4	main
rikkam	doc_491521501648_item	2433235	et	4	main
küla	doc_491521501648_item	2433237	et	4	main
12	doc_491521501649_item	2433239	et	2	main
november	doc_491521501649_item	2433240	et	3	main
1700	doc_491521501649_item	2433242	et	2	main
maja	doc_491521501649_item	2433244	et	4	main
tallinn	doc_491521501649_item	2433245	et	4	main
maria	doc_491521501649_item	2433259	et	4	main
põhikooli	doc_491521501649_item	2433262	et	4	main
peipsiääre	doc_491521501649_item	2433264	et	3	main
koorijuht	doc_491521501649_item	2433266	et	3	main
avdejeva	doc_491521501649_item	2433268	et	4	main
õpetaja	doc_491521501649_item	2433279	et	4	main
kooli	doc_491521501649_item	2433283	et	4	main
rutenia	doc_491521501649_item	2433330	et	4	main
laulu-	doc_491521501649_item	2433342	et	4	main
tantsupeol	doc_491521501649_item	2433344	et	4	main
slaavi	doc_491521501649_item	2433345	et	3	main
pärg	doc_491521501649_item	2433346	et	3	main
aastal	doc_491521501649_item	2433355	et	3	main
tarsan	doc_491521501649_item	2433366	et	4	main
nina	doc_491521501649_item	2433370	et	4	main
usuõpetuse	doc_491521501649_item	2433378	et	3	main
tutvustada	doc_491521501649_item	2433384	et	3	main
ja	doc_491521501649_item	2433398	et	3	main
vanavene	doc_491521501649_item	2433421	et	4	main
põhiosa	doc_491521501649_item	2433427	et	4	main
publikule	doc_491521501649_item	2433434	et	3	main
2000aastal	doc_491521501649_item	2433435	et	3	main
püha	doc_491521501649_item	2433437	et	4	main
pidustustel	doc_491521501649_item	2433442	et	3	main
sai	doc_491521501649_item	2433469	et	4	main
norrast	doc_491521501649_item	2433472	et	4	main
2005aasta	doc_491521501649_item	2433475	et	4	main
lastekoor	doc_491521501649_item	2433477	et	4	main
laulis	doc_491521501649_item	2433478	et	4	main
septembris	doc_491521501649_item	2433484	et	3	main
koor	doc_491521501649_item	2433485	et	4	main
eestimaa	doc_491521501649_item	2433491	et	4	main
päeva	doc_491521501649_item	2433493	et	4	main
ja	doc_491521501649_item	2433510	et	3	main
tänaseks	doc_491521501649_item	2433517	et	4	main
ainus	doc_491521501649_item	2433518	et	4	main
kollektiiv	doc_491521501649_item	2433519	et	3	main
eestis	doc_491521501649_item	2433520	et	3	main
kolkja	doc_491521501649_item	2433529	et	4	main
värsid	doc_491521501649_item	2433539	et	3	main
lauluviisid	doc_491521501649_item	2433541	et	3	main
1	doc_491521501649_item	2433542	et	2	main
aed	doc_491521501649_item	2433549	et	3	main
joosepi	doc_491521501649_item	2433559	et	4	main
kirja	doc_491521501649_item	2433563	et	4	main
rimshi	doc_491521501649_item	2433569	et	4	main
mingisugune	doc_491521501647_item	2433091	et	3	main
talunik	doc_491521501647_item	2433092	et	3	main
kes	doc_491521501647_item	2433093	et	4	main
oli	doc_491521501647_item	2433094	et	3	main
põllule	doc_491521501647_item	2433121	et	3	main
metsa	doc_491521501647_item	2433123	et	4	main
suure	doc_491521501647_item	2433124	et	3	main
sõites	doc_491521501647_item	2433131	et	3	main
hernehirmutis	doc_491521501647_item	2433132	et	4	main
ja	doc_491521501647_item	2433136	et	3	main
ühe	doc_491521501648_item	2433150	et	4	main
suure	doc_491521501648_item	2433151	et	3	main
kuhu	doc_491521501648_item	2433153	et	3	main
iga	doc_491521501648_item	2433154	et	4	main
perekond	doc_491521501648_item	2433155	et	3	main
rehad	doc_491521501648_item	2433169	et	3	main
tünnid	doc_491521501648_item	2433171	et	3	main
läbi	doc_491521501648_item	2433193	et	4	main
tavaliselt	doc_491521501648_item	2433204	et	4	main
esialgu	doc_491521501648_item	2433211	et	3	main
oleks	doc_491521501648_item	2433224	et	3	main
kaugelt	doc_491521501648_item	2433225	et	4	main
kell	doc_491521501649_item	2433241	et	3	main
mustpeade	doc_491521501649_item	2433243	et	3	main
lastekoor	doc_491521501649_item	2433250	et	4	main
marina	doc_491521501649_item	2433252	et	3	main
vanausu	doc_491521501649_item	2433254	et	3	main
koor	doc_491521501649_item	2433255	et	4	main
selushinskaja	doc_491521501649_item	2433260	et	4	main
koori	doc_491521501649_item	2433271	et	4	main
asutas	doc_491521501649_item	2433272	et	3	main
90-te	doc_491521501649_item	2433273	et	3	main
alguses	doc_491521501649_item	2433275	et	4	main
marima	doc_491521501649_item	2433280	et	4	main
avdejeva	doc_491521501649_item	2433281	et	4	main
repertuaari	doc_491521501649_item	2433284	et	4	main
dirigent	doc_491521501649_item	2433331	et	3	main
akulenko	doc_491521501649_item	2433333	et	4	main
1997aastal	doc_491521501649_item	2433334	et	3	main
kolkja	doc_491521501649_item	2433335	et	4	main
põhikooli	doc_491521501649_item	2433336	et	4	main
esines	doc_491521501649_item	2433340	et	3	main
piirisaarel	doc_491521501649_item	2433363	et	4	main
ja	doc_491521501649_item	2433364	et	3	main
põhikoolis	doc_491521501649_item	2433376	et	4	main
andmist	doc_491521501649_item	2433380	et	4	main
eesmärgiks	doc_491521501649_item	2433382	et	3	main
vanausuliste	doc_491521501649_item	2433387	et	4	main
ajalugu	doc_491521501649_item	2433388	et	4	main
lugema	doc_491521501649_item	2433393	et	4	main
kirikuslaavi	doc_491521501649_item	2433394	et	4	main
kogu	doc_491521501647_item	2433137	et	4	main
osalejatega	doc_491521501647_item	2433139	et	4	main
külla	doc_491521501647_item	2433141	et	4	main
tagasi	doc_491521501647_item	2433142	et	3	main
referaat	doc_491521501648_item	2433143	et	3	main
küla	doc_491521501648_item	2433148	et	4	main
pidi	doc_491521501648_item	2433156	et	4	main
midagi	doc_491521501648_item	2433157	et	4	main
kütmiseks	doc_491521501648_item	2433158	et	4	main
tooma	doc_491521501648_item	2433159	et	3	main
toodi	doc_491521501648_item	2433160	et	4	main
vanu	doc_491521501648_item	2433161	et	4	main
asju	doc_491521501648_item	2433162	et	3	main
mida	doc_491521501648_item	2433163	et	4	main
enam	doc_491521501648_item	2433164	et	4	main
ei	doc_491521501648_item	2433165	et	4	main
kasutata	doc_491521501648_item	2433166	et	3	main
tühjad	doc_491521501648_item	2433170	et	3	main
korjatud	doc_491521501648_item	2433175	et	4	main
kogu	doc_491521501648_item	2433179	et	4	main
nädala	doc_491521501648_item	2433186	et	3	main
selleks	doc_491521501648_item	2433188	et	4	main
nad	doc_491521501648_item	2433189	et	3	main
käisid	doc_491521501648_item	2433190	et	4	main
lõket	doc_491521501648_item	2433196	et	4	main
ehitamiseks	doc_491521501648_item	2433206	et	4	main
valiti	doc_491521501648_item	2433207	et	3	main
toimus	doc_491521501648_item	2433212	et	3	main
peab	doc_491521501648_item	2433216	et	4	main
olema	doc_491521501648_item	2433217	et	4	main
erk	doc_491521501648_item	2433218	et	3	main
ja	doc_491521501648_item	2433219	et	3	main
hästi	doc_491521501648_item	2433220	et	3	main
seda	doc_491521501648_item	2433223	et	3	main
et	doc_491521501648_item	2433222	et	3	main
arvati	doc_491521501648_item	2433228	et	4	main
on	doc_491521501648_item	2433236	et	4	main
põhikooli	doc_491521501649_item	2433249	et	4	main
koorijuht	doc_491521501649_item	2433251	et	3	main
avdejeva	doc_491521501649_item	2433253	et	4	main
aastate	doc_491521501649_item	2433274	et	3	main
algklasside	doc_491521501649_item	2433278	et	3	main
kuulusid	doc_491521501649_item	2433285	et	4	main
valdavas	doc_491521501649_item	2433286	et	4	main
osas	doc_491521501649_item	2433287	et	4	main
laste	doc_491521501649_item	2433288	et	4	main
laulud	doc_491521501649_item	2433289	et	3	main
ja	doc_491521501649_item	2433290	et	3	main
vene	doc_491521501649_item	2433291	et	4	main
rahvalaulud	doc_491521501649_item	2433292	et	3	main
koor	doc_491521501649_item	2433293	et	4	main
esines	doc_491521501649_item	2433294	et	3	main
kooli	doc_491521501649_item	2433295	et	4	main
üritustel	doc_491521501649_item	2433296	et	4	main
ja	doc_491521501649_item	2433297	et	3	main
kolkja	doc_491521501649_item	2433298	et	4	main
rahvamajas	doc_491521501649_item	2433299	et	3	main
selleks	doc_491521501649_item	2433300	et	4	main
ajaks	doc_491521501649_item	2433301	et	4	main
marina	doc_491521501649_item	2433302	et	3	main
avdejeva	doc_491521501649_item	2433303	et	4	main
ise	doc_491521501649_item	2433304	et	4	main
laulis	doc_491521501649_item	2433305	et	4	main
juba	doc_491521501649_item	2433306	et	3	main
üle	doc_491521501649_item	2433307	et	3	main
kümne	doc_491521501649_item	2433308	et	4	main
aasta	doc_491521501649_item	2433309	et	4	main
tartu	doc_491521501649_item	2433310	et	4	main
vene	doc_491521501649_item	2433311	et	4	main
kooris	doc_491521501649_item	2433312	et	4	main
rutenia	doc_491521501649_item	2433313	et	4	main
mille	doc_491521501649_item	2433314	et	3	main
repertuaari	doc_491521501649_item	2433315	et	4	main
kuulus	doc_491521501649_item	2433316	et	4	main
ka	doc_491521501649_item	2433317	et	3	main
vene	doc_491521501649_item	2433318	et	4	main
vaimulik	doc_491521501649_item	2433319	et	3	main
muusika	doc_491521501649_item	2433320	et	4	main
idee	doc_491521501649_item	2433321	et	4	main
marinale	doc_491521501649_item	2433329	et	4	main
anzhelika	doc_491521501649_item	2433332	et	4	main
põhikooli	doc_491521501649_item	2433270	et	4	main
muusika	doc_491521501649_item	2433276	et	4	main
ja	doc_491521501649_item	2433277	et	3	main
lastekoori	doc_491521501649_item	2433323	et	4	main
ka	doc_491521501649_item	2433325	et	3	main
pakkus	doc_491521501649_item	2433328	et	3	main
lastekoor	doc_491521501649_item	2433337	et	4	main
samal	doc_491521501649_item	2433354	et	3	main
esines	doc_491521501649_item	2433357	et	3	main
vanausu	doc_491521501649_item	2433359	et	3	main
folkloorifestivalil	doc_491521501649_item	2433365	et	3	main
peipsiääre	doc_491521501649_item	2433368	et	3	main
baranina	doc_491521501649_item	2433371	et	4	main
initsiatiivil	doc_491521501649_item	2433372	et	3	main
samal	doc_491521501649_item	2433373	et	3	main
aastal	doc_491521501649_item	2433374	et	3	main
kolkja	doc_491521501649_item	2433375	et	4	main
tundide	doc_491521501649_item	2433379	et	3	main
keeles	doc_491521501649_item	2433395	et	4	main
vaimulikke	doc_491521501649_item	2433396	et	3	main
raamatuid	doc_491521501649_item	2433397	et	3	main
palveid	doc_491521501649_item	2433399	et	3	main
tunde	doc_491521501649_item	2433400	et	4	main
andis	doc_491521501649_item	2433401	et	3	main
vanausuliste	doc_491521501649_item	2433402	et	4	main
traditsioonide	doc_491521501649_item	2433403	et	3	main
ja	doc_491521501649_item	2433404	et	3	main
tavade	doc_491521501649_item	2433405	et	3	main
asjatundja	doc_491521501649_item	2433406	et	4	main
varnja	doc_491521501649_item	2433407	et	4	main
palvela	doc_491521501649_item	2433408	et	4	main
koorilaulja	doc_491521501649_item	2433409	et	4	main
zoja	doc_491521501649_item	2433410	et	4	main
kutkina	doc_491521501649_item	2433411	et	4	main
just	doc_491521501649_item	2433412	et	3	main
tema	doc_491521501649_item	2433413	et	4	main
esmakordselt	doc_491521501649_item	2433414	et	4	main
tutvustas	doc_491521501649_item	2433415	et	3	main
marina	doc_491521501649_item	2433416	et	3	main
avdejevale	doc_491521501649_item	2433417	et	4	main
xv	doc_491521501649_item	2433418	et	4	main
xvii	doc_491521501649_item	2433419	et	4	main
sajandi	doc_491521501649_item	2433420	et	3	main
vaimulikke	doc_491521501649_item	2433422	et	3	main
repertuaarist	doc_491521501649_item	2433429	et	3	main
esitati	doc_491521501649_item	2433433	et	4	main
mustvees	doc_491521501649_item	2433436	et	3	main
kolmainsuse	doc_491521501649_item	2433438	et	4	main
palvela	doc_491521501649_item	2433439	et	4	main
siin	doc_491521501649_item	2433443	et	4	main
laulis	doc_491521501649_item	2433450	et	4	main
kuulajate	doc_491521501649_item	2433466	et	4	main
külalisi	doc_491521501649_item	2433471	et	4	main
saksamaalt	doc_491521501649_item	2433474	et	3	main
suvel	doc_491521501649_item	2433476	et	3	main
sama	doc_491521501649_item	2433482	et	4	main
aasta	doc_491521501649_item	2433483	et	4	main
avada	doc_491521501649_item	2433488	et	3	main
23septembril	doc_491521501649_item	2433496	et	3	main
matkamajas	doc_491521501649_item	2433498	et	3	main
lauljad	doc_491521501649_item	2433500	et	4	main
vaimulikud	doc_491521501649_item	2433326	et	3	main
teosed	doc_491521501649_item	2433327	et	3	main
koosseisus	doc_491521501649_item	2433339	et	4	main
rahvusvahelisel	doc_491521501649_item	2433341	et	4	main
ja	doc_491521501649_item	2433343	et	3	main
see	doc_491521501649_item	2433347	et	3	main
oli	doc_491521501649_item	2433348	et	3	main
koori	doc_491521501649_item	2433349	et	4	main
esimene	doc_491521501649_item	2433350	et	3	main
tartus	doc_491521501649_item	2433367	et	3	main
alustati	doc_491521501649_item	2433377	et	4	main
mille	doc_491521501649_item	2433381	et	3	main
oli	doc_491521501649_item	2433383	et	3	main
peipsimaa	doc_491521501649_item	2433386	et	4	main
ka	doc_491521501649_item	2433392	et	3	main
esmakordselt	doc_491521501649_item	2433430	et	4	main
lastekoor	doc_491521501649_item	2433444	et	4	main
ka	doc_491521501649_item	2433446	et	3	main
õnnistuse	doc_491521501649_item	2433447	et	4	main
2003aastal	doc_491521501649_item	2433448	et	3	main
koor	doc_491521501649_item	2433449	et	4	main
regulaarselt	doc_491521501649_item	2433461	et	4	main
esines	doc_491521501649_item	2433462	et	3	main
kolkja	doc_491521501649_item	2433463	et	4	main
rahvamajas	doc_491521501649_item	2433464	et	3	main
kus	doc_491521501649_item	2433465	et	3	main
päeval	doc_491521501649_item	2433481	et	3	main
kutse	doc_491521501649_item	2433487	et	4	main
vähemusrahvuste	doc_491521501649_item	2433492	et	3	main
noored	doc_491521501649_item	2433499	et	3	main
lausa	doc_491521501649_item	2433501	et	4	main
vallutasid	doc_491521501649_item	2433502	et	4	main
tänusõnad	doc_491521501649_item	2433512	et	3	main
kolkja	doc_491521501649_item	2433513	et	4	main
koor	doc_491521501649_item	2433515	et	4	main
on	doc_491521501649_item	2433516	et	4	main
liturgiavälist	doc_491521501649_item	2433525	et	4	main
muusikat	doc_491521501649_item	2433526	et	3	main
marina	doc_491521501649_item	2433533	et	3	main
vanavene	doc_491521501649_item	2433537	et	4	main
oli	doc_491521501649_item	2433547	et	3	main
kauni	doc_491521501649_item	2433558	et	4	main
pannud	doc_491521501649_item	2433564	et	4	main
läti	doc_491521501649_item	2433567	et	4	main
poola	doc_491521501649_item	2433594	et	4	main
värss	doc_491521501649_item	2433595	et	3	main
on	doc_491521501649_item	2433596	et	4	main
igatsusest	doc_491521501649_item	2433597	et	4	main
3	doc_491521501649_item	2433600	et	2	main
bojarinna	doc_491521501649_item	2433604	et	4	main
morozova	doc_491521501649_item	2433605	et	4	main
4	doc_491521501649_item	2433613	et	2	main
oma	doc_491521501649_item	2433616	et	4	main
värsi	doc_491521501649_item	2433618	et	3	main
rutenia	doc_491521501649_item	2433338	et	4	main
etteaste	doc_491521501649_item	2433351	et	4	main
vaimuliku	doc_491521501649_item	2433352	et	3	main
muusikaga	doc_491521501649_item	2433353	et	3	main
koor	doc_491521501649_item	2433356	et	4	main
kolkja	doc_491521501649_item	2433358	et	4	main
muuseumi	doc_491521501649_item	2433360	et	4	main
avamisel	doc_491521501649_item	2433361	et	4	main
1998aastal	doc_491521501649_item	2433362	et	3	main
vallavanema	doc_491521501649_item	2433369	et	4	main
lastele	doc_491521501649_item	2433385	et	4	main
ja	doc_491521501649_item	2433389	et	3	main
kultuuri	doc_491521501649_item	2433390	et	4	main
õpetati	doc_491521501649_item	2433391	et	3	main
värsse	doc_491521501649_item	2433423	et	3	main
tänaseks	doc_491521501649_item	2433425	et	4	main
moodustavad	doc_491521501649_item	2433426	et	4	main
värsse	doc_491521501649_item	2433432	et	3	main
rajamise	doc_491521501649_item	2433440	et	4	main
sai	doc_491521501649_item	2433445	et	4	main
seas	doc_491521501649_item	2433467	et	4	main
tihti	doc_491521501649_item	2433468	et	3	main
linna	doc_491521501649_item	2433480	et	4	main
oma	doc_491521501649_item	2433489	et	4	main
kontsert	doc_491521501649_item	2433495	et	3	main
kuulajate	doc_491521501649_item	2433503	et	4	main
südamed	doc_491521501649_item	2433504	et	3	main
mille	doc_491521501649_item	2433505	et	3	main
märgiks	doc_491521501649_item	2433506	et	4	main
südamlikud	doc_491521501649_item	2433511	et	3	main
mis	doc_491521501649_item	2433424	et	4	main
koori	doc_491521501649_item	2433428	et	4	main
vaimulikke	doc_491521501649_item	2433431	et	3	main
70-aasta	doc_491521501649_item	2433441	et	4	main
varnja	doc_491521501649_item	2433451	et	4	main
püha	doc_491521501649_item	2433452	et	4	main
kolmainsuse	doc_491521501649_item	2433453	et	4	main
palvela	doc_491521501649_item	2433454	et	4	main
rajamise	doc_491521501649_item	2433455	et	4	main
100-aasta	doc_491521501649_item	2433456	et	4	main
pidustustel	doc_491521501649_item	2433457	et	3	main
aastatel	doc_491521501649_item	2433458	et	4	main
2002-2004	doc_491521501649_item	2433459	et	2	main
kollektiiv	doc_491521501649_item	2433460	et	3	main
kohata	doc_491521501649_item	2433470	et	4	main
rootsist	doc_491521501649_item	2433473	et	3	main
kallaste	doc_491521501649_item	2433479	et	4	main
sai	doc_491521501649_item	2433486	et	4	main
etteastega	doc_491521501649_item	2433490	et	3	main
pidulik	doc_491521501649_item	2433494	et	3	main
tallinna	doc_491521501649_item	2433497	et	4	main
kauakestev	doc_491521501649_item	2433508	et	3	main
põhikooli	doc_491521501649_item	2433514	et	4	main
kes	doc_491521501649_item	2433521	et	4	main
traditsioonilist	doc_491521501649_item	2433524	et	4	main
vaimulikke	doc_491521501649_item	2433527	et	3	main
värsse	doc_491521501649_item	2433528	et	3	main
põhikooli	doc_491521501649_item	2433530	et	4	main
avdejeva	doc_491521501649_item	2433534	et	4	main
kasulik	doc_491521501649_item	2433545	et	3	main
3	doc_491521501649_item	2433550	et	2	main
vanausukoor	doc_491521501649_item	2433554	et	4	main
nutulaul	doc_491521501649_item	2433560	et	4	main
ivan	doc_491521501649_item	2433565	et	4	main
zavoloko	doc_491521501649_item	2433566	et	4	main
värss	doc_491521501649_item	2433570	et	3	main
preisimaal	doc_491521501649_item	2433592	et	4	main
praegu	doc_491521501649_item	2433593	et	3	main
kaotatud	doc_491521501649_item	2433598	et	4	main
bojarinna	doc_491521501649_item	2433601	et	4	main
värss	doc_491521501649_item	2433603	et	3	main
vabadusest	doc_491521501649_item	2433609	et	4	main
vanausu	doc_491521501649_item	2433610	et	3	main
nimel	doc_491521501649_item	2433612	et	3	main
lapsele	doc_491521501649_item	2433617	et	4	main
viis	doc_491521501649_item	2433621	et	4	main
ivan	doc_491521501649_item	2433625	et	4	main
läti	doc_491521501649_item	2433627	et	4	main
külas	doc_491521501649_item	2433628	et	3	main
rimshi	doc_491521501649_item	2433629	et	4	main
5	doc_491521501649_item	2433630	et	2	main
kirik	doc_491521501649_item	2433631	et	3	main
värss	doc_491521501649_item	2433632	et	3	main
räägib	doc_491521501649_item	2433633	et	3	main
kahetsustundest	doc_491521501649_item	2433634	et	4	main
avvakum	doc_491521501649_item	2433639	et	4	main
pärast	doc_491521501649_item	2433651	et	4	main
kuuled	doc_491521501649_item	2433656	et	3	main
lauluviise	doc_491521501649_item	2433658	et	3	main
vaimulikke	doc_491521501649_item	2433659	et	3	main
värsse	doc_491521501649_item	2433660	et	3	main
koos	doc_491521501649_item	2433669	et	4	main
vene	doc_491521501649_item	2433682	et	4	main
loomingut	doc_491521501649_item	2433684	et	3	main
varakristlaste	doc_491521501649_item	2433686	et	3	main
vanasti	doc_491521501649_item	2433696	et	3	main
peaaegu	doc_491521501649_item	2433700	et	3	main
peredes	doc_491521501649_item	2433702	et	3	main
suvel	doc_491521501649_item	2433712	et	3	main
värside	doc_491521501649_item	2433720	et	4	main
oli	doc_491521501649_item	2433507	et	3	main
aplaus	doc_491521501649_item	2433509	et	3	main
esitab	doc_491521501649_item	2433522	et	3	main
koor	doc_491521501649_item	2433531	et	4	main
koorijuht	doc_491521501649_item	2433532	et	3	main
2	doc_491521501649_item	2433546	et	2	main
ja	doc_491521501649_item	2433552	et	3	main
samaarialanna	doc_491521501649_item	2433553	et	4	main
grezn	doc_491521501649_item	2433555	et	4	main
riia	doc_491521501649_item	2433556	et	4	main
1	doc_491521501649_item	2433557	et	2	main
morozova	doc_491521501649_item	2433602	et	4	main
palved	doc_491521501649_item	2433615	et	3	main
tekst	doc_491521501649_item	2433619	et	3	main
kirja	doc_491521501649_item	2433623	et	4	main
zavoloko	doc_491521501649_item	2433626	et	4	main
6	doc_491521501649_item	2433638	et	2	main
avvakumi	doc_491521501649_item	2433647	et	4	main
varakristluse	doc_491521501649_item	2433663	et	4	main
2sajandil	doc_491521501649_item	2433665	et	3	main
vanesse	doc_491521501649_item	2433666	et	4	main
põlanud	doc_491521501649_item	2433679	et	4	main
värsse	doc_491521501649_item	2433689	et	3	main
ja	doc_491521501649_item	2433692	et	3	main
ajal	doc_491521501649_item	2433714	et	4	main
ajal	doc_491521501649_item	2433716	et	4	main
viljalõikuse	doc_491521501649_item	2433717	et	3	main
ajal	doc_491521501649_item	2433718	et	4	main
jm	doc_491521501649_item	2433719	et	4	main
kosutas	doc_491521501649_item	2433722	et	3	main
kerged	doc_491521501649_item	2433736	et	3	main
on	doc_491521501649_item	2433740	et	4	main
znamennõj	doc_491521501649_item	2433759	et	4	main
vaimus	doc_491521501649_item	2433761	et	4	main
olulisel	doc_491521501649_item	2433762	et	4	main
kohal	doc_491521501649_item	2433763	et	4	main
vanausu	doc_491521501649_item	2433777	et	3	main
läti	doc_491521501649_item	2433781	et	4	main
koorijuht	doc_491521501649_item	2433782	et	3	main
maria	doc_491521501649_item	2433783	et	4	main
mail	doc_491521501649_item	2433791	et	4	main
ajast	doc_491521501649_item	2433827	et	4	main
koor	doc_491521501649_item	2433828	et	4	main
on	doc_491521501649_item	2433829	et	4	main
esinenud	doc_491521501649_item	2433830	et	4	main
riia	doc_491521501649_item	2433835	et	4	main
mustpeade	doc_491521501649_item	2433839	et	3	main
on	doc_491521501649_item	2433845	et	4	main
koori	doc_491521501649_item	2433871	et	4	main
vanavene	doc_491521501649_item	2433874	et	4	main
vaimulikud	doc_491521501649_item	2433875	et	3	main
värsid	doc_491521501649_item	2433876	et	3	main
on	doc_491521501649_item	2433890	et	4	main
liimed	doc_491521501649_item	2433894	et	4	main
on	doc_491521501649_item	2433904	et	4	main
kirjastanud	doc_491521501649_item	2433905	et	4	main
kogumikku	doc_491521501649_item	2433909	et	4	main
1999aastal	doc_491521501649_item	2433912	et	3	main
sai	doc_491521501649_item	2433915	et	4	main
osaks	doc_491521501649_item	2433920	et	3	main
koori	doc_491521501649_item	2433927	et	4	main
laulmist	doc_491521501649_item	2433932	et	4	main
nazarov	doc_491521501649_item	2433938	et	4	main
riia	doc_491521501649_item	2433939	et	4	main
grebenshikovi	doc_491521501649_item	2433940	et	4	main
koguduse	doc_491521501649_item	2433941	et	3	main
väga	doc_491521501649_item	2433945	et	3	main
znamennõi	doc_491521501649_item	2433947	et	4	main
neumade	doc_491521501649_item	2433949	et	4	main
järgi	doc_491521501649_item	2433950	et	4	main
ivan	doc_491521501649_item	2433954	et	4	main
sõber	doc_491521501649_item	2433956	et	3	main
laulis	doc_491521501649_item	2433964	et	4	main
selushinskaja	doc_491521501649_item	2433973	et	4	main
grezn	doc_491521501649_item	2433979	et	4	main
muusika	doc_491521501649_item	2433982	et	4	main
tundmine	doc_491521501649_item	2433984	et	4	main
samal	doc_491521501649_item	2433985	et	3	main
ajal	doc_491521501649_item	2433986	et	4	main
ka	doc_491521501649_item	2433987	et	3	main
haruldaselt	doc_491521501649_item	2433988	et	4	main
vanausu	doc_491521501649_item	2433523	et	3	main
xv-vxii	doc_491521501649_item	2433535	et	4	main
saj	doc_491521501649_item	2433536	et	4	main
vaimulikud	doc_491521501649_item	2433538	et	3	main
varnja	doc_491521501649_item	2433540	et	4	main
värss	doc_491521501649_item	2433543	et	3	main
hingele	doc_491521501649_item	2433544	et	4	main
kristus-lapsukesel	doc_491521501649_item	2433548	et	4	main
kristus	doc_491521501649_item	2433551	et	3	main
värsi	doc_491521501649_item	2433561	et	3	main
on	doc_491521501649_item	2433562	et	4	main
külas	doc_491521501649_item	2433568	et	3	main
joosepi	doc_491521501649_item	2433572	et	4	main
orjaks	doc_491521501649_item	2433573	et	4	main
andmisest	doc_491521501649_item	2433574	et	4	main
oma	doc_491521501649_item	2433575	et	4	main
lihaste	doc_491521501649_item	2433576	et	4	main
vendade	doc_491521501649_item	2433577	et	3	main
poolt	doc_491521501649_item	2433578	et	4	main
piibli	doc_491521501649_item	2433579	et	3	main
süzhee	doc_491521501649_item	2433580	et	4	main
2	doc_491521501649_item	2433581	et	2	main
värss	doc_491521501649_item	2433582	et	3	main
värsi	doc_491521501649_item	2433584	et	3	main
linnukesest	doc_491521501649_item	2433583	et	4	main
on	doc_491521501649_item	2433585	et	4	main
kirja	doc_491521501649_item	2433586	et	4	main
pannud	doc_491521501649_item	2433587	et	4	main
ivan	doc_491521501649_item	2433588	et	4	main
zavoloko	doc_491521501649_item	2433589	et	4	main
külas	doc_491521501649_item	2433591	et	3	main
voinovo	doc_491521501649_item	2433590	et	4	main
räägib	doc_491521501649_item	2433571	et	3	main
kodumaast	doc_491521501649_item	2433599	et	3	main
kangelasteost	doc_491521501649_item	2433606	et	4	main
loobumisest	doc_491521501649_item	2433607	et	4	main
aadliseisusest	doc_491521501649_item	2433608	et	4	main
hoidmise	doc_491521501649_item	2433611	et	4	main
ja	doc_491521501649_item	2433620	et	3	main
pannud	doc_491521501649_item	2433624	et	4	main
kaotatud	doc_491521501649_item	2433635	et	4	main
kiriku	doc_491521501649_item	2433636	et	3	main
pärast	doc_491521501649_item	2433637	et	4	main
pere	doc_491521501649_item	2433642	et	4	main
pagenduses	doc_491521501649_item	2433652	et	4	main
juba	doc_491521501649_item	2433662	et	3	main
nad	doc_491521501649_item	2433668	et	3	main
värsse	doc_491521501649_item	2433671	et	3	main
mungad	doc_491521501649_item	2433673	et	3	main
vanausulised	doc_491521501649_item	2433677	et	4	main
ka	doc_491521501649_item	2433681	et	3	main
vabal	doc_491521501649_item	2433694	et	3	main
värsse	doc_491521501649_item	2433698	et	3	main
vaheldumisi	doc_491521501649_item	2433706	et	4	main
vesteldes	doc_491521501649_item	2433707	et	3	main
lauldud	doc_491521501649_item	2433708	et	4	main
teemal	doc_491521501649_item	2433710	et	3	main
heinaniidu	doc_491521501649_item	2433715	et	3	main
hinge	doc_491521501649_item	2433723	et	4	main
lisas	doc_491521501649_item	2433724	et	4	main
ka	doc_491521501649_item	2433725	et	3	main
kehale	doc_491521501649_item	2433726	et	3	main
reipust	doc_491521501649_item	2433727	et	4	main
tundusid	doc_491521501649_item	2433735	et	4	main
vaimulikud	doc_491521501649_item	2433738	et	3	main
koostatud	doc_491521501649_item	2433745	et	4	main
piibli	doc_491521501649_item	2433746	et	3	main
viiside	doc_491521501649_item	2433760	et	3	main
on	doc_491521501649_item	2433765	et	4	main
värsid	doc_491521501649_item	2433767	et	3	main
räägivad	doc_491521501649_item	2433769	et	3	main
tagakuisamisest	doc_491521501649_item	2433771	et	4	main
loodud	doc_491521501649_item	2433789	et	4	main
maria	doc_491521501649_item	2433793	et	4	main
selushinskaja	doc_491521501649_item	2433794	et	4	main
algatusel	doc_491521501649_item	2433795	et	4	main
grezn	doc_491521501649_item	2433796	et	4	main
jätkas	doc_491521501649_item	2433797	et	3	main
eelmise	doc_491521501649_item	2433798	et	3	main
sajandi	doc_491521501649_item	2433799	et	3	main
seltsi	doc_491521501649_item	2433813	et	4	main
tööd	doc_491521501649_item	2433814	et	4	main
grezn	doc_491521501649_item	2433816	et	4	main
esimene	doc_491521501649_item	2433817	et	3	main
toimus	doc_491521501649_item	2433819	et	3	main
ema	doc_491521501649_item	2433614	et	4	main
on	doc_491521501649_item	2433622	et	4	main
ja	doc_491521501649_item	2433640	et	3	main
daurias	doc_491521501649_item	2433653	et	4	main
sa	doc_491521501649_item	2433655	et	3	main
paradiisi	doc_491521501649_item	2433657	et	4	main
lauldi	doc_491521501649_item	2433661	et	3	main
ajal	doc_491521501649_item	2433664	et	4	main
koostasid	doc_491521501649_item	2433672	et	4	main
hiljem	doc_491521501649_item	2433674	et	3	main
mittevaimulikud	doc_491521501649_item	2433676	et	3	main
ei	doc_491521501649_item	2433678	et	4	main
pidustustel	doc_491521501649_item	2433690	et	3	main
lihtsalt	doc_491521501649_item	2433693	et	4	main
vaimulikke	doc_491521501649_item	2433697	et	3	main
lauldi	doc_491521501649_item	2433699	et	3	main
kõikides	doc_491521501649_item	2433701	et	4	main
kõik	doc_491521501649_item	2433704	et	4	main
kodused	doc_491521501649_item	2433705	et	4	main
lauldi	doc_491521501649_item	2433711	et	3	main
lauldes	doc_491521501649_item	2433728	et	3	main
laabus	doc_491521501649_item	2433729	et	3	main
töö	doc_491521501649_item	2433730	et	4	main
paremini	doc_491521501649_item	2433731	et	4	main
ja	doc_491521501649_item	2433732	et	3	main
rasked	doc_491521501649_item	2433733	et	3	main
talutööd	doc_491521501649_item	2433734	et	4	main
kõik	doc_491521501649_item	2433737	et	4	main
vanausulistel	doc_491521501649_item	2433764	et	4	main
vaimulikud	doc_491521501649_item	2433766	et	3	main
vanausuliste	doc_491521501649_item	2433770	et	4	main
riia	doc_491521501649_item	2433780	et	4	main
selushinskaja	doc_491521501649_item	2433784	et	4	main
vanausu	doc_491521501649_item	2433785	et	3	main
koor	doc_491521501649_item	2433786	et	4	main
16	doc_491521501649_item	2433790	et	2	main
30-aastatel	doc_491521501649_item	2433800	et	4	main
teadlase	doc_491521501649_item	2433801	et	3	main
zavoloko	doc_491521501649_item	2433808	et	4	main
poolt	doc_491521501649_item	2433809	et	4	main
loodud	doc_491521501649_item	2433810	et	4	main
1993aastal	doc_491521501649_item	2433821	et	3	main
saalis	doc_491521501649_item	2433825	et	4	main
sellest	doc_491521501649_item	2433826	et	4	main
mitmeid	doc_491521501649_item	2433831	et	4	main
ühes	doc_491521501649_item	2433836	et	4	main
majas	doc_491521501649_item	2433840	et	3	main
moskvino	doc_491521501649_item	2433853	et	4	main
valgevenes	doc_491521501649_item	2433855	et	3	main
borissovis	doc_491521501649_item	2433857	et	4	main
minskis	doc_491521501649_item	2433858	et	4	main
voinovos	doc_491521501649_item	2433861	et	4	main
valdavas	doc_491521501649_item	2433867	et	4	main
oma	doc_491521501649_item	2433869	et	4	main
repertuaar	doc_491521501649_item	2433877	et	3	main
rikka	doc_491521501649_item	2433884	et	4	main
pärandist	doc_491521501649_item	2433887	et	3	main
kõik	doc_491521501649_item	2433888	et	4	main
koorilauljad	doc_491521501649_item	2433889	et	3	main
koori	doc_491521501649_item	2433913	et	4	main
ivan	doc_491521501649_item	2433916	et	4	main
tema	doc_491521501649_item	2433641	et	4	main
paguluses	doc_491521501649_item	2433643	et	4	main
värss	doc_491521501649_item	2433644	et	3	main
räägib	doc_491521501649_item	2433645	et	3	main
ülempreester	doc_491521501649_item	2433646	et	4	main
kannatustest	doc_491521501649_item	2433648	et	4	main
vanausu	doc_491521501649_item	2433649	et	3	main
hoidmise	doc_491521501649_item	2433650	et	4	main
7	doc_491521501649_item	2433654	et	2	main
tulid	doc_491521501649_item	2433667	et	4	main
ristiusuga	doc_491521501649_item	2433670	et	3	main
ka	doc_491521501649_item	2433675	et	3	main
ära	doc_491521501649_item	2433680	et	4	main
poeetide	doc_491521501649_item	2433683	et	3	main
vanausulised	doc_491521501649_item	2433685	et	4	main
eeskujul	doc_491521501649_item	2433687	et	3	main
laulsid	doc_491521501649_item	2433688	et	4	main
õhtuti	doc_491521501649_item	2433691	et	3	main
ajal	doc_491521501649_item	2433695	et	4	main
laulsid	doc_491521501649_item	2433703	et	4	main
värsi	doc_491521501649_item	2433709	et	3	main
põllutööde	doc_491521501649_item	2433713	et	3	main
laulmine	doc_491521501649_item	2433721	et	4	main
evangeeliumi	doc_491521501649_item	2433747	et	4	main
ja	doc_491521501649_item	2433748	et	3	main
ajaloolistel	doc_491521501649_item	2433749	et	4	main
filosoofilised	doc_491521501649_item	2433751	et	4	main
mõtisklused	doc_491521501649_item	2433752	et	4	main
mõttest	doc_491521501649_item	2433754	et	4	main
ja	doc_491521501649_item	2433755	et	3	main
igapäevaelust	doc_491521501649_item	2433756	et	4	main
värsse	doc_491521501649_item	2433757	et	3	main
lauldi	doc_491521501649_item	2433758	et	3	main
mis	doc_491521501649_item	2433768	et	4	main
koor	doc_491521501649_item	2433778	et	4	main
grezn	doc_491521501649_item	2433787	et	4	main
sai	doc_491521501649_item	2433788	et	4	main
1993aastal	doc_491521501649_item	2433792	et	3	main
pedagoogi	doc_491521501649_item	2433802	et	4	main
vanavene	doc_491521501649_item	2433803	et	4	main
muinasloo	doc_491521501649_item	2433811	et	4	main
kontsert	doc_491521501649_item	2433818	et	3	main
14novembril	doc_491521501649_item	2433820	et	3	main
riia	doc_491521501649_item	2433822	et	4	main
koguduse	doc_491521501649_item	2433824	et	3	main
sh	doc_491521501649_item	2433834	et	4	main
saalides	doc_491521501649_item	2433838	et	4	main
oma	doc_491521501649_item	2433841	et	4	main
lätis	doc_491521501649_item	2433843	et	4	main
koor	doc_491521501649_item	2433844	et	4	main
bobruiskis	doc_491521501649_item	2433856	et	4	main
usukaaslastele	doc_491521501649_item	2433870	et	4	main
pidevalt	doc_491521501649_item	2433878	et	4	main
vaimulikud	doc_491521501649_item	2433882	et	3	main
riia	doc_491521501649_item	2433891	et	4	main
grebenschikovi	doc_491521501649_item	2433892	et	4	main
nende	doc_491521501649_item	2433901	et	4	main
elust	doc_491521501649_item	2433902	et	3	main
kollektiiv	doc_491521501649_item	2433903	et	3	main
1994	doc_491521501649_item	2433910	et	2	main
nimvanausuliste	doc_491521501649_item	2433918	et	4	main
olid	doc_491521501649_item	2433923	et	4	main
ka	doc_491521501649_item	2433924	et	3	main
tütar	doc_491521501649_item	2433930	et	3	main
talle	doc_491521501649_item	2433934	et	4	main
tema	doc_491521501649_item	2433935	et	4	main
tuntud	doc_491521501649_item	2433946	et	4	main
asjatundja	doc_491521501649_item	2433951	et	4	main
professor	doc_491521501649_item	2433953	et	3	main
selushinskaja	doc_491521501649_item	2433960	et	4	main
east	doc_491521501649_item	2433963	et	3	main
õppides	doc_491521501649_item	2433966	et	4	main
kirikulaulmise	doc_491521501649_item	2433968	et	3	main
loodud	doc_491521501649_item	2433977	et	4	main
sügav	doc_491521501649_item	2433983	et	4	main
tõelise	doc_491521501649_item	2433994	et	4	main
zavoloko	doc_491521501649_item	2433999	et	4	main
ühingu	doc_491521501649_item	2434002	et	3	main
ühingu	doc_491521501649_item	2434005	et	3	main
te	doc_491521501650_item	2434012	et	4	main
sõbrale	doc_491521501650_item	2434017	et	3	main
värsid	doc_491521501649_item	2433739	et	3	main
religioosse-eestilise	doc_491521501649_item	2433741	et	3	main
sisuga	doc_491521501649_item	2433742	et	3	main
nad	doc_491521501649_item	2433743	et	3	main
on	doc_491521501649_item	2433744	et	4	main
süzheedel	doc_491521501649_item	2433750	et	4	main
inimelu	doc_491521501649_item	2433753	et	4	main
ahistamisest	doc_491521501649_item	2433772	et	4	main
ja	doc_491521501649_item	2433773	et	3	main
kannatustest	doc_491521501649_item	2433774	et	4	main
ristiusu	doc_491521501649_item	2433775	et	3	main
pärast	doc_491521501649_item	2433776	et	4	main
grezn	doc_491521501649_item	2433779	et	4	main
ajaloo	doc_491521501649_item	2433804	et	4	main
asjatundja	doc_491521501649_item	2433805	et	4	main
professor	doc_491521501649_item	2433806	et	3	main
ivan	doc_491521501649_item	2433807	et	4	main
hoidjate	doc_491521501649_item	2433812	et	4	main
koori	doc_491521501649_item	2433815	et	4	main
grebenschikovi	doc_491521501649_item	2433823	et	4	main
kordi	doc_491521501649_item	2433832	et	4	main
riias	doc_491521501649_item	2433833	et	4	main
esinenud	doc_491521501649_item	2433846	et	4	main
poolas	doc_491521501649_item	2433859	et	4	main
grondas	doc_491521501649_item	2433863	et	4	main
siiski	doc_491521501649_item	2433864	et	4	main
esitusele	doc_491521501649_item	2433880	et	4	main
vanavene	doc_491521501649_item	2433885	et	4	main
muusikakultuuri	doc_491521501649_item	2433886	et	4	main
koguduse	doc_491521501649_item	2433893	et	3	main
laulmine	doc_491521501649_item	2433897	et	4	main
suur	doc_491521501649_item	2433899	et	3	main
osa	doc_491521501649_item	2433900	et	4	main
kollektiiv	doc_491521501649_item	2433914	et	3	main
zavoloko	doc_491521501649_item	2433917	et	4	main
asutajateks	doc_491521501649_item	2433922	et	4	main
ajaloolase	doc_491521501649_item	2433952	et	3	main
mõttekaaslane	doc_491521501649_item	2433958	et	3	main
algatusel	doc_491521501649_item	2433974	et	4	main
1993aastal	doc_491521501649_item	2433975	et	3	main
sai	doc_491521501649_item	2433976	et	4	main
vanavene	doc_491521501649_item	2433980	et	4	main
juhatuse	doc_491521501649_item	2434006	et	4	main
kirja	doc_491521501650_item	2434014	et	4	main
oma	doc_491521501650_item	2434015	et	4	main
mida	doc_491521501650_item	2434020	et	4	main
teete	doc_491521501650_item	2434023	et	3	main
nõutav	doc_491521501650_item	2434025	et	4	main
kallis	doc_491521501650_item	2434032	et	4	main
pärast	doc_491521501650_item	2434064	et	4	main
me	doc_491521501650_item	2434065	et	4	main
uisutasime	doc_491521501650_item	2434066	et	3	main
õpin	doc_491521501650_item	2434084	et	3	main
kirja	doc_491521501650_item	2434087	et	4	main
õhtusööki	doc_491521501650_item	2434098	et	4	main
barankasid	doc_491521501650_item	2434101	et	3	main
ja	doc_491521501650_item	2434102	et	3	main
kuulati	doc_491521501650_item	2434106	et	4	main
esinduslikumaid	doc_491521501649_item	2433837	et	4	main
kodumaal	doc_491521501649_item	2433842	et	4	main
daugavpilsis	doc_491521501649_item	2433847	et	4	main
preilis	doc_491521501649_item	2433848	et	3	main
rezeknes	doc_491521501649_item	2433849	et	4	main
ekabpilsis	doc_491521501649_item	2433850	et	4	main
moskvino	doc_491521501649_item	2433851	et	4	main
külas	doc_491521501649_item	2433852	et	3	main
külas	doc_491521501649_item	2433854	et	3	main
suvalkas	doc_491521501649_item	2433860	et	4	main
gabrovy	doc_491521501649_item	2433862	et	4	main
koor	doc_491521501649_item	2433865	et	4	main
esineb	doc_491521501649_item	2433866	et	3	main
osas	doc_491521501649_item	2433868	et	4	main
kontsertrepertuaari	doc_491521501649_item	2433872	et	4	main
kuuluvad	doc_491521501649_item	2433873	et	4	main
täiendub	doc_491521501649_item	2433879	et	4	main
võetakse	doc_491521501649_item	2433881	et	3	main
laulud	doc_491521501649_item	2433883	et	3	main
ja	doc_491521501649_item	2433895	et	3	main
jumalateenistuslik	doc_491521501649_item	2433896	et	3	main
on	doc_491521501649_item	2433898	et	4	main
kaks	doc_491521501649_item	2433906	et	3	main
vaimulikke	doc_491521501649_item	2433907	et	3	main
värsside	doc_491521501649_item	2433908	et	3	main
1995	doc_491521501649_item	2433911	et	2	main
ühingu	doc_491521501649_item	2433919	et	3	main
ühingu	doc_491521501649_item	2433921	et	3	main
koorilikmed	doc_491521501649_item	2433925	et	4	main
juhib	doc_491521501649_item	2433926	et	3	main
jevlampi	doc_491521501649_item	2433929	et	4	main
selushinskaja	doc_491521501649_item	2433931	et	4	main
õpetas	doc_491521501649_item	2433933	et	3	main
juht	doc_491521501649_item	2433943	et	3	main
zavoloko	doc_491521501649_item	2433955	et	4	main
maria	doc_491521501649_item	2433959	et	4	main
juba	doc_491521501649_item	2433961	et	3	main
noorest	doc_491521501649_item	2433962	et	3	main
kooris	doc_491521501649_item	2433965	et	4	main
ära	doc_491521501649_item	2433967	et	4	main
sai	doc_491521501649_item	2433969	et	4	main
temast	doc_491521501649_item	2433970	et	3	main
koorijuht	doc_491521501649_item	2433971	et	3	main
maria	doc_491521501649_item	2433972	et	4	main
koor	doc_491521501649_item	2433978	et	4	main
vaimiliku	doc_491521501649_item	2433981	et	4	main
kaunis	doc_491521501649_item	2433989	et	4	main
lauluhääl	doc_491521501649_item	2433990	et	3	main
teevad	doc_491521501649_item	2433991	et	3	main
temast	doc_491521501649_item	2433992	et	3	main
maria	doc_491521501649_item	2433996	et	4	main
nimelise	doc_491521501649_item	2434000	et	4	main
kultuurivalgustusliku	doc_491521501649_item	2434001	et	3	main
aseesimees	doc_491521501649_item	2434007	et	4	main
eksamitöö	doc_491521501650_item	2434008	et	4	main
on	doc_491521501650_item	2434009	et	4	main
eestlasest	doc_491521501650_item	2434016	et	3	main
sain	doc_491521501650_item	2434035	et	3	main
oleme	doc_491521501650_item	2434055	et	3	main
ja	doc_491521501650_item	2434057	et	3	main
seal	doc_491521501650_item	2434059	et	4	main
väga	doc_491521501650_item	2434060	et	3	main
ilus	doc_491521501650_item	2434061	et	4	main
ja	doc_491521501650_item	2434062	et	3	main
suur	doc_491521501650_item	2434071	et	3	main
ootan	doc_491521501650_item	2434086	et	3	main
pakuti	doc_491521501650_item	2434099	et	3	main
õpilastele	doc_491521501650_item	2434100	et	4	main
12	doc_491521501650_item	2434105	et	2	main
huvitavat	doc_491521501650_item	2434108	et	4	main
eriti	doc_491521501650_item	2434125	et	3	main
publikule	doc_491521501650_item	2434127	et	3	main
vene	doc_491521501650_item	2434128	et	4	main
märge	doc_491521501650_item	2434151	et	4	main
vale	doc_491521501650_item	2434157	et	4	main
olulised	doc_491521501650_item	2434178	et	4	main
maria	doc_491521501649_item	2433928	et	4	main
vanaisa	doc_491521501649_item	2433936	et	4	main
ivan	doc_491521501649_item	2433937	et	4	main
kirikukoori	doc_491521501649_item	2433942	et	4	main
ustavschik	doc_491521501649_item	2433944	et	4	main
laulmise	doc_491521501649_item	2433948	et	4	main
ja	doc_491521501649_item	2433957	et	3	main
ja	doc_491521501649_item	2434004	et	3	main
koolivaheaeg	doc_491521501650_item	2434011	et	3	main
kirjutate	doc_491521501650_item	2434013	et	3	main
talle	doc_491521501650_item	2434019	et	4	main
koolivaheajal	doc_491521501650_item	2434022	et	3	main
umbes	doc_491521501650_item	2434028	et	4	main
80	doc_491521501650_item	2434029	et	2	main
sõna	doc_491521501650_item	2434030	et	4	main
tere	doc_491521501650_item	2434031	et	3	main
sinu	doc_491521501650_item	2434036	et	3	main
kätte	doc_491521501650_item	2434038	et	4	main
ma	doc_491521501650_item	2434039	et	3	main
saanud	doc_491521501650_item	2434041	et	4	main
sulle	doc_491521501650_item	2434042	et	3	main
varem	doc_491521501650_item	2434043	et	4	main
kirjutada	doc_491521501650_item	2434044	et	3	main
ma	doc_491521501650_item	2434045	et	3	main
õpin	doc_491521501650_item	2434046	et	3	main
kohtla-järve	doc_491521501650_item	2434047	et	4	main
tallinas	doc_491521501650_item	2434053	et	4	main
bootanikaajas	doc_491521501650_item	2434058	et	4	main
ja	doc_491521501650_item	2434067	et	3	main
kelgutasime	doc_491521501650_item	2434068	et	3	main
seal	doc_491521501650_item	2434074	et	4	main
sõber	doc_491521501650_item	2434089	et	3	main
pärast	doc_491521501650_item	2434097	et	4	main
koht	doc_491521501650_item	2434123	et	3	main
rahvatants	doc_491521501650_item	2434129	et	3	main
troika	doc_491521501650_item	2434130	et	4	main
kui	doc_491521501650_item	2434139	et	3	main
a-ruutu	doc_491521501650_item	2434145	et	4	main
b-ruutu	doc_491521501650_item	2434152	et	4	main
õige	doc_491521501650_item	2434156	et	4	main
õpib	doc_491521501650_item	2434167	et	3	main
kasutama	doc_491521501650_item	2434169	et	3	main
jaoks	doc_491521501650_item	2434172	et	4	main
on	doc_491521501650_item	2434173	et	4	main
on	doc_491521501650_item	2434181	et	4	main
koori	doc_491521501649_item	2433993	et	4	main
kaunistuse	doc_491521501649_item	2433995	et	4	main
selushinskaja	doc_491521501649_item	2433997	et	4	main
on	doc_491521501649_item	2433998	et	4	main
tegevdirektor	doc_491521501649_item	2434003	et	3	main
talvine	doc_491521501650_item	2434010	et	4	main
kirjutage	doc_491521501650_item	2434018	et	3	main
pikkus	doc_491521501650_item	2434026	et	4	main
on	doc_491521501650_item	2434027	et	4	main
ma	doc_491521501650_item	2434034	et	3	main
kutsekool	doc_491521501650_item	2434048	et	4	main
koolivaheajal	doc_491521501650_item	2434049	et	3	main
minu	doc_491521501650_item	2434050	et	3	main
pere	doc_491521501650_item	2434051	et	4	main
väga	doc_491521501650_item	2434070	et	3	main
linn	doc_491521501650_item	2434072	et	3	main
palju	doc_491521501650_item	2434075	et	4	main
sinu	doc_491521501650_item	2434088	et	3	main
puuduvad	doc_491521501650_item	2434092	et	4	main
õhtu	doc_491521501650_item	2434095	et	4	main
11	doc_491521501650_item	2434096	et	2	main
teid	doc_491521501650_item	2434103	et	4	main
väga	doc_491521501650_item	2434107	et	3	main
mis	doc_491521501650_item	2434110	et	4	main
eest	doc_491521501650_item	2434121	et	4	main
vene	doc_491521501650_item	2434132	et	4	main
õhtule	doc_491521501650_item	2434133	et	3	main
tagasi	doc_491521501650_item	2434134	et	3	main
mõeldes	doc_491521501650_item	2434135	et	3	main
heaks	doc_491521501650_item	2434138	et	4	main
nõustute	doc_491521501650_item	2434140	et	3	main
siis	doc_491521501650_item	2434142	et	3	main
märge	doc_491521501650_item	2434144	et	4	main
siis	doc_491521501650_item	2434150	et	3	main
16	doc_491521501650_item	2434158	et	2	main
hannes	doc_491521501650_item	2434159	et	4	main
väga	doc_491521501650_item	2434182	et	3	main
20	doc_491521501650_item	2434184	et	2	main
tahab	doc_491521501650_item	2434186	et	3	main
te	doc_491521501650_item	2434021	et	4	main
kirja	doc_491521501650_item	2434024	et	4	main
tiina	doc_491521501650_item	2434033	et	4	main
kirja	doc_491521501650_item	2434037	et	4	main
ei	doc_491521501650_item	2434040	et	4	main
puhtasime	doc_491521501650_item	2434052	et	4	main
me	doc_491521501650_item	2434054	et	4	main
muuseumis	doc_491521501650_item	2434056	et	3	main
lõbusalt	doc_491521501650_item	2434063	et	4	main
tallinn	doc_491521501650_item	2434069	et	4	main
ja	doc_491521501650_item	2434073	et	3	main
lumi	doc_491521501650_item	2434076	et	3	main
me	doc_491521501650_item	2434077	et	4	main
väga	doc_491521501650_item	2434078	et	3	main
hästi	doc_491521501650_item	2434079	et	3	main
puhtasime	doc_491521501650_item	2434080	et	4	main
ma	doc_491521501650_item	2434081	et	3	main
uuesti	doc_491521501650_item	2434082	et	3	main
tahan	doc_491521501650_item	2434083	et	3	main
ma	doc_491521501650_item	2434085	et	3	main
eesnimi	doc_491521501650_item	2434090	et	3	main
lisage	doc_491521501650_item	2434091	et	3	main
sõnad	doc_491521501650_item	2434093	et	4	main
vene	doc_491521501650_item	2434094	et	4	main
jooma	doc_491521501650_item	2434104	et	4	main
luulekava	doc_491521501650_item	2434109	et	4	main
võttis	doc_491521501650_item	2434111	et	3	main
23	doc_491521501650_item	2434112	et	2	main
kogu	doc_491521501650_item	2434113	et	4	main
õhtust	doc_491521501650_item	2434114	et	4	main
13	doc_491521501650_item	2434115	et	2	main
jõgeva	doc_491521501650_item	2434116	et	4	main
luulepäevadel	doc_491521501650_item	2434117	et	3	main
saadi	doc_491521501650_item	2434118	et	4	main
sama	doc_491521501650_item	2434119	et	4	main
kava	doc_491521501650_item	2434120	et	4	main
esimene	doc_491521501650_item	2434122	et	3	main
meeldis	doc_491521501650_item	2434126	et	3	main
15	doc_491521501650_item	2434131	et	2	main
tuju	doc_491521501650_item	2434137	et	4	main
väitega	doc_491521501650_item	2434141	et	3	main
tehke	doc_491521501650_item	2434143	et	4	main
b	doc_491521501650_item	2434155	et	4	main
harjus	doc_491521501650_item	2434160	et	4	main
uue	doc_491521501650_item	2434161	et	3	main
kooliga	doc_491521501650_item	2434162	et	4	main
kiiresti	doc_491521501650_item	2434163	et	3	main
hannes	doc_491521501650_item	2434165	et	4	main
alles	doc_491521501650_item	2434166	et	3	main
hannese	doc_491521501650_item	2434171	et	4	main
raha	doc_491521501650_item	2434174	et	4	main
ja	doc_491521501650_item	2434175	et	3	main
sõbrad	doc_491521501650_item	2434176	et	3	main
väga	doc_491521501650_item	2434177	et	3	main
19	doc_491521501650_item	2434179	et	2	main
kartlik	doc_491521501650_item	2434183	et	3	main
14	doc_491521501650_item	2434124	et	2	main
läheb	doc_491521501650_item	2434136	et	3	main
õige	doc_491521501650_item	2434146	et	4	main
kui	doc_491521501650_item	2434147	et	3	main
ei	doc_491521501650_item	2434148	et	4	main
nõustu	doc_491521501650_item	2434149	et	4	main
vale	doc_491521501650_item	2434153	et	4	main
a	doc_491521501650_item	2434154	et	4	main
17	doc_491521501650_item	2434164	et	2	main
arvutit	doc_491521501650_item	2434168	et	3	main
18	doc_491521501650_item	2434170	et	2	main
hannes	doc_491521501650_item	2434180	et	4	main
hannes	doc_491521501650_item	2434185	et	4	main
kuulsaks	doc_491521501650_item	2434187	et	4	main
saada	doc_491521501650_item	2434188	et	4	main
tähelepanelik	doc_491521501653_item	2434824	et	4	main
sõlmides	doc_491521501653_item	2434826	et	4	main
2	doc_491521501653_item	2434829	et	2	main
kui	doc_491521501653_item	2434830	et	3	main
lähete	doc_491521501653_item	2434831	et	4	main
vaatama	doc_491521501653_item	2434840	et	3	main
lähedes	doc_491521501653_item	2434841	et	4	main
olge	doc_491521501653_item	2434861	et	3	main
olge	doc_491521501653_item	2434867	et	3	main
parima	doc_491521501653_item	2434877	et	4	main
remonti	doc_491521501653_item	2434879	et	4	main
parima	doc_491521501653_item	2434883	et	4	main
tulemuse	doc_491521501653_item	2434884	et	3	main
viis	doc_491521501653_item	2434892	et	4	main
liiget	doc_491521501653_item	2434893	et	3	main
ühesõnalised	doc_491521501653_item	2434903	et	4	main
terveks	doc_491521501653_item	2434905	et	4	main
saama	doc_491521501653_item	2434906	et	4	main
tervistama	doc_491521501653_item	2434907	et	3	main
taga	doc_491521501653_item	2434911	et	4	main
mida	doc_491521501653_item	2434920	et	4	main
saadeti	doc_491521501653_item	2434923	et	3	main
pakuti	doc_491521501653_item	2434927	et	3	main
ostma	doc_491521501653_item	2434934	et	3	main
olema	doc_491521501653_item	2434936	et	4	main
имеют	doc_491521501653_item	2434942	et	2	main
и	doc_491521501653_item	2434945	et	2	main
kaubad	doc_491521501653_item	2434949	et	3	main
lagunevad	doc_491521501653_item	2434954	et	4	main
дома	doc_491521501653_item	2434960	et	2	main
teil	doc_491521501653_item	2434964	et	4	main
võimalus	doc_491521501653_item	2434966	et	3	main
клиенты	doc_491521501653_item	2434973	et	2	main
покупать	doc_491521501653_item	2434976	et	2	main
hiilima	doc_491521501653_item	2435014	et	3	main
mainet	doc_491521501653_item	2435027	et	4	main
määrsõna	doc_491521501653_item	2435033	et	4	main
riietub	doc_491521501653_item	2435039	et	3	main
müüja	doc_491521501653_item	2435045	et	4	main
pakkus	doc_491521501653_item	2435046	et	3	main
oma	doc_491521501653_item	2435047	et	4	main
kaupa	doc_491521501653_item	2435048	et	4	main
sulgudes	doc_491521501653_item	2435061	et	4	main
jube	doc_491521501653_item	2435068	et	4	main
jube	doc_491521501653_item	2435069	et	4	main
ootamatult	doc_491521501653_item	2435074	et	4	main
ringi	doc_491521501653_item	2435079	et	4	main
see	doc_491521501653_item	2435080	et	3	main
juhtum	doc_491521501653_item	2435081	et	3	main
oli	doc_491521501653_item	2435082	et	3	main
lihtsalt	doc_491521501653_item	2435083	et	4	main
kui	doc_491521501653_item	2435089	et	3	main
kontrolltöö	doc_491521501654_item	2435095	et	4	main
i	doc_491521501654_item	2435096	et	4	main
takistama	doc_491521501654_item	2435098	et	3	main
tuvastama	doc_491521501654_item	2435100	et	3	main
догадываться	doc_491521501654_item	2435103	et	2	main
kohtlema	doc_491521501654_item	2435104	et	3	main
umbusklik	doc_491521501654_item	2435106	et	3	main
плесневеть	doc_491521501654_item	2435114	et	2	main
sundima	doc_491521501654_item	2435117	et	4	main
lepingut	doc_491521501654_item	2435125	et	3	main
vaatama	doc_491521501654_item	2435137	et	3	main
võtke	doc_491521501654_item	2435138	et	3	main
korterit	doc_491521501654_item	2435142	et	3	main
kontrolltöö	doc_491521501653_item	2434799	et	4	main
i	doc_491521501653_item	2434800	et	4	main
tõlkige	doc_491521501653_item	2434801	et	3	main
takistama	doc_491521501653_item	2434802	et	3	main
препятствовать	doc_491521501653_item	2434803	et	2	main
tuvastama	doc_491521501653_item	2434804	et	3	main
taipama	doc_491521501653_item	2434805	et	3	main
kohtlema	doc_491521501653_item	2434806	et	3	main
umbusklik	doc_491521501653_item	2434807	et	3	main
peibutama	doc_491521501653_item	2434808	et	3	main
välja	doc_491521501653_item	2434809	et	4	main
venima	doc_491521501653_item	2434810	et	3	main
плесневеть	doc_491521501653_item	2434812	et	2	main
hallitama	doc_491521501653_item	2434811	et	3	main
küünistama	doc_491521501653_item	2434813	et	3	main
sundima	doc_491521501653_item	2434814	et	4	main
направлять	doc_491521501653_item	2434815	et	2	main
ii	doc_491521501653_item	2434816	et	4	main
kasutage	doc_491521501653_item	2434817	et	3	main
des-vormi	doc_491521501653_item	2434818	et	4	main
1	doc_491521501653_item	2434819	et	2	main
kui	doc_491521501653_item	2434820	et	3	main
lepingut	doc_491521501653_item	2434822	et	3	main
lepingut	doc_491521501653_item	2434825	et	3	main
üle	doc_491521501653_item	2434833	et	3	main
asjatundja	doc_491521501653_item	2434837	et	4	main
suhtlete	doc_491521501653_item	2434847	et	3	main
ametnikega	doc_491521501653_item	2434848	et	3	main
tehtes	doc_491521501653_item	2434881	et	3	main
saate	doc_491521501653_item	2434882	et	4	main
kuus	doc_491521501653_item	2434890	et	4	main
tundi	doc_491521501653_item	2434891	et	4	main
sada	doc_491521501653_item	2434895	et	4	main
lugema	doc_491521501653_item	2434924	et	4	main
pakkuma	doc_491521501653_item	2434926	et	3	main
lasteti	doc_491521501653_item	2434933	et	4	main
osteti	doc_491521501653_item	2434935	et	3	main
oldi	doc_491521501653_item	2434937	et	3	main
некоторые	doc_491521501653_item	2434940	et	2	main
качество	doc_491521501653_item	2434944	et	2	main
mõned	doc_491521501653_item	2434948	et	3	main
halva	doc_491521501653_item	2434951	et	4	main
kvaliteedi	doc_491521501653_item	2434952	et	3	main
возможность	doc_491521501653_item	2434959	et	2	main
kataloogi	doc_491521501653_item	2434969	et	4	main
имеют	doc_491521501653_item	2434974	et	2	main
рассрочку	doc_491521501653_item	2434979	et	2	main
on	doc_491521501653_item	2435017	et	4	main
firma	doc_491521501653_item	2435025	et	4	main
viii	doc_491521501653_item	2435029	et	4	main
kirjutage	doc_491521501653_item	2435030	et	3	main
lünka	doc_491521501653_item	2435031	et	4	main
seisid	doc_491521501653_item	2435035	et	4	main
väljakutsuvalt	doc_491521501653_item	2435044	et	4	main
lõhnas	doc_491521501653_item	2435051	et	4	main
väljakutsuvalt	doc_491521501653_item	2435056	et	4	main
olevad	doc_491521501653_item	2435062	et	4	main
välja	doc_491521501653_item	2435070	et	4	main
külm	doc_491521501653_item	2435071	et	3	main
lahtiselt	doc_491521501653_item	2435078	et	4	main
piinlik	doc_491521501653_item	2435088	et	3	main
hoia	doc_491521501653_item	2435092	et	4	main
korras	doc_491521501653_item	2435094	et	4	main
привлекать	doc_491521501654_item	2435109	et	2	main
hallitama	doc_491521501654_item	2435113	et	3	main
1	doc_491521501654_item	2435122	et	2	main
lähete	doc_491521501654_item	2435134	et	4	main
üle	doc_491521501654_item	2435136	et	3	main
kaasa	doc_491521501654_item	2435139	et	4	main
kaasa	doc_491521501654_item	2435146	et	4	main
3	doc_491521501654_item	2435148	et	2	main
kui	doc_491521501654_item	2435149	et	3	main
4	doc_491521501654_item	2435160	et	2	main
pakkumisi	doc_491521501654_item	2435169	et	4	main
olge	doc_491521501654_item	2435170	et	3	main
ka	doc_491521501654_item	2435171	et	3	main
remonti	doc_491521501654_item	2435178	et	4	main
kroonine	doc_491521501654_item	2435205	et	4	main
saama	doc_491521501654_item	2435214	et	4	main
lisama	doc_491521501654_item	2435218	et	3	main
olge	doc_491521501653_item	2434827	et	3	main
tähelepanelik	doc_491521501653_item	2434828	et	4	main
võtke	doc_491521501653_item	2434835	et	3	main
kaasa	doc_491521501653_item	2434836	et	4	main
3	doc_491521501653_item	2434845	et	2	main
abi	doc_491521501653_item	2434850	et	4	main
maaklerist	doc_491521501653_item	2434851	et	3	main
ametnikega	doc_491521501653_item	2434852	et	3	main
ise	doc_491521501653_item	2434863	et	4	main
pakkumisi	doc_491521501653_item	2434865	et	4	main
ka	doc_491521501653_item	2434868	et	3	main
5	doc_491521501653_item	2434871	et	2	main
kui	doc_491521501653_item	2434872	et	3	main
teete	doc_491521501653_item	2434873	et	3	main
ise	doc_491521501653_item	2434874	et	4	main
iii	doc_491521501653_item	2434885	et	4	main
moodustage	doc_491521501653_item	2434886	et	3	main
poolteist	doc_491521501653_item	2434888	et	4	main
viieliigne	doc_491521501653_item	2434894	et	3	main
sadaviiekrooniline	doc_491521501653_item	2434898	et	4	main
iv	doc_491521501653_item	2434901	et	4	main
moodustage	doc_491521501653_item	2434902	et	3	main
panema	doc_491521501653_item	2434909	et	3	main
aru	doc_491521501653_item	2434913	et	4	main
ära	doc_491521501653_item	2434916	et	4	main
minema	doc_491521501653_item	2434917	et	3	main
lahkuma	doc_491521501653_item	2434918	et	3	main
saatma	doc_491521501653_item	2434922	et	3	main
nõudma	doc_491521501653_item	2434928	et	3	main
laskma	doc_491521501653_item	2434931	et	3	main
ломаются	doc_491521501653_item	2434947	et	2	main
kiiresti	doc_491521501653_item	2434955	et	3	main
есть	doc_491521501653_item	2434958	et	2	main
изучить	doc_491521501653_item	2434962	et	2	main
постоянные	doc_491521501653_item	2434972	et	2	main
в	doc_491521501653_item	2434978	et	2	main
on	doc_491521501653_item	2434981	et	4	main
pikkaks	doc_491521501653_item	2434983	et	4	main
mõned	doc_491521501653_item	2435018	et	3	main
üleolevad	doc_491521501653_item	2435019	et	3	main
sõlmite	doc_491521501653_item	2434821	et	3	main
olge	doc_491521501653_item	2434823	et	3	main
korterit	doc_491521501653_item	2434832	et	3	main
korterit	doc_491521501653_item	2434838	et	3	main
kui	doc_491521501653_item	2434846	et	3	main
on	doc_491521501653_item	2434849	et	4	main
suheldes	doc_491521501653_item	2434853	et	3	main
on	doc_491521501653_item	2434854	et	4	main
abi	doc_491521501653_item	2434855	et	4	main
maaklerist	doc_491521501653_item	2434856	et	3	main
4	doc_491521501653_item	2434857	et	2	main
kui	doc_491521501653_item	2434858	et	3	main
ootate	doc_491521501653_item	2434859	et	3	main
pakkumisi	doc_491521501653_item	2434860	et	4	main
vaatama	doc_491521501653_item	2434834	et	3	main
üle	doc_491521501653_item	2434839	et	3	main
võtke	doc_491521501653_item	2434842	et	3	main
kaasa	doc_491521501653_item	2434843	et	4	main
asjatundja	doc_491521501653_item	2434844	et	4	main
aktiivne	doc_491521501653_item	2434864	et	3	main
oodates	doc_491521501653_item	2434866	et	3	main
ise	doc_491521501653_item	2434869	et	4	main
aktiivne	doc_491521501653_item	2434870	et	3	main
saate	doc_491521501653_item	2434876	et	4	main
tulemuse	doc_491521501653_item	2434878	et	3	main
ise	doc_491521501653_item	2434880	et	4	main
krooni	doc_491521501653_item	2434897	et	4	main
kakskümmend	doc_491521501653_item	2434899	et	4	main
ruutmeetrit	doc_491521501653_item	2434900	et	3	main
juurde	doc_491521501653_item	2434908	et	4	main
v	doc_491521501653_item	2434919	et	4	main
ka	doc_491521501653_item	2434862	et	3	main
remonti	doc_491521501653_item	2434875	et	4	main
liitsõnad	doc_491521501653_item	2434887	et	3	main
meetrit	doc_491521501653_item	2434889	et	3	main
viis	doc_491521501653_item	2434896	et	4	main
sünonüümid	doc_491521501653_item	2434904	et	3	main
lisandama	doc_491521501653_item	2434910	et	3	main
ajama	doc_491521501653_item	2434912	et	4	main
saama	doc_491521501653_item	2434914	et	4	main
mõistma	doc_491521501653_item	2434915	et	3	main
tehti	doc_491521501653_item	2434921	et	3	main
nõudeti	doc_491521501653_item	2434930	et	4	main
товары	doc_491521501653_item	2434941	et	2	main
быстро	doc_491521501653_item	2434946	et	2	main
у	doc_491521501653_item	2434956	et	2	main
спокойно	doc_491521501653_item	2434961	et	2	main
on	doc_491521501653_item	2434965	et	4	main
läbi	doc_491521501653_item	2434970	et	4	main
право	doc_491521501653_item	2434975	et	2	main
püsiklientidel	doc_491521501653_item	2434980	et	3	main
õigus	doc_491521501653_item	2434982	et	4	main
eksitavad	doc_491521501653_item	2435020	et	4	main
kahjustasid	doc_491521501653_item	2435024	et	4	main
sobiv	doc_491521501653_item	2435032	et	4	main
järjekorras	doc_491521501653_item	2435037	et	3	main
tüdinult	doc_491521501653_item	2435055	et	4	main
maitsetult	doc_491521501653_item	2435058	et	4	main
ix	doc_491521501653_item	2435059	et	4	main
koer	doc_491521501653_item	2435075	et	3	main
jookseb	doc_491521501653_item	2435076	et	3	main
on	doc_491521501653_item	2435086	et	4	main
piinlik	doc_491521501653_item	2435087	et	3	main
inimesed	doc_491521501653_item	2435090	et	3	main
välja	doc_491521501654_item	2435110	et	4	main
заставлять	doc_491521501654_item	2435118	et	2	main
kasutage	doc_491521501654_item	2435120	et	3	main
des-vormi	doc_491521501654_item	2435121	et	4	main
korterit	doc_491521501654_item	2435135	et	3	main
üle	doc_491521501654_item	2435143	et	3	main
abi	doc_491521501654_item	2435158	et	4	main
5	doc_491521501654_item	2435174	et	2	main
teete	doc_491521501654_item	2435176	et	3	main
ühesõnalised	doc_491521501654_item	2435211	et	4	main
juurde	doc_491521501654_item	2435216	et	4	main
v	doc_491521501654_item	2435228	et	4	main
ostati	doc_491521501654_item	2435242	et	4	main
vi	doc_491521501654_item	2435245	et	4	main
плохое	doc_491521501654_item	2435250	et	2	main
kvaliteet	doc_491521501654_item	2435259	et	3	main
nad	doc_491521501654_item	2435261	et	3	main
lähevad	doc_491521501654_item	2435263	et	3	main
возможность	doc_491521501654_item	2435268	et	2	main
teil	doc_491521501654_item	2435273	et	4	main
katalogi	doc_491521501654_item	2435276	et	4	main
rahulikult	doc_491521501654_item	2435278	et	4	main
kodus	doc_491521501654_item	2435279	et	4	main
постоянные	doc_491521501654_item	2435280	et	2	main
имеют	doc_491521501654_item	2435282	et	2	main
покупать	doc_491521501654_item	2435284	et	2	main
в	doc_491521501654_item	2435286	et	2	main
ostu	doc_491521501654_item	2435292	et	4	main
maha	doc_491521501654_item	2435296	et	4	main
korteriühistu	doc_491521501654_item	2435304	et	4	main
et	doc_491521501654_item	2435311	et	3	main
toote	doc_491521501654_item	2435323	et	4	main
kehtivad	doc_491521501654_item	2435329	et	4	main
viii	doc_491521501654_item	2435337	et	4	main
sobiv	doc_491521501654_item	2435340	et	4	main
järjekorras	doc_491521501654_item	2435345	et	3	main
pakkus	doc_491521501654_item	2435354	et	3	main
oma	doc_491521501654_item	2435355	et	4	main
kaupa	doc_491521501654_item	2435356	et	4	main
isuäratavalt	doc_491521501654_item	2435362	et	4	main
pealetükkivalt	doc_491521501654_item	2435365	et	4	main
sõnad	doc_491521501654_item	2435371	et	4	main
õigesse	doc_491521501654_item	2435372	et	3	main
вытягивать	doc_491521501655_item	2435420	et	2	main
ii	doc_491521501655_item	2435427	et	4	main
des-vormi	doc_491521501655_item	2435429	et	4	main
lepingut	doc_491521501655_item	2435433	et	3	main
loeti	doc_491521501653_item	2434925	et	3	main
nõuati	doc_491521501653_item	2434929	et	3	main
laseti	doc_491521501653_item	2434932	et	4	main
vi	doc_491521501653_item	2434938	et	4	main
tõlkige	doc_491521501653_item	2434939	et	3	main
плохое	doc_491521501653_item	2434943	et	2	main
on	doc_491521501653_item	2434950	et	4	main
ja	doc_491521501653_item	2434953	et	3	main
вас	doc_491521501653_item	2434957	et	2	main
каталог	doc_491521501653_item	2434963	et	2	main
kodus	doc_491521501653_item	2434967	et	4	main
rahulikult	doc_491521501653_item	2434968	et	4	main
vaadata	doc_491521501653_item	2434971	et	4	main
товар	doc_491521501653_item	2434977	et	2	main
ajaks	doc_491521501653_item	2434984	et	4	main
kaupa	doc_491521501653_item	2434985	et	4	main
osta	doc_491521501653_item	2434986	et	4	main
vii	doc_491521501653_item	2434987	et	4	main
tõmmake	doc_491521501653_item	2434988	et	3	main
maha	doc_491521501653_item	2434989	et	4	main
alla	doc_491521501653_item	2434990	et	3	main
valed	doc_491521501653_item	2434991	et	3	main
sõnad	doc_491521501653_item	2434992	et	4	main
seda	doc_491521501653_item	2434993	et	3	main
maja	doc_491521501653_item	2434994	et	4	main
haldab	doc_491521501653_item	2434996	et	3	main
kerkibkaasneb	doc_491521501653_item	2434995	et	4	main
korteriühistu	doc_491521501653_item	2434997	et	4	main
maakler	doc_491521501653_item	2434998	et	3	main
lasi	doc_491521501653_item	2434999	et	4	main
läbiajas	doc_491521501653_item	2435000	et	3	main
korda	doc_491521501653_item	2435001	et	4	main
nägi	doc_491521501653_item	2435002	et	3	main
vaeva	doc_491521501653_item	2435003	et	4	main
et	doc_491521501653_item	2435004	et	3	main
korterit	doc_491521501653_item	2435005	et	3	main
maha	doc_491521501653_item	2435006	et	4	main
müüa	doc_491521501653_item	2435007	et	3	main
lõvi	doc_491521501653_item	2435008	et	4	main
hakkas	doc_491521501653_item	2435009	et	3	main
saagile	doc_491521501653_item	2435010	et	3	main
peale	doc_491521501653_item	2435011	et	4	main
käimatoime	doc_491521501653_item	2435012	et	4	main
tulemaligi	doc_491521501653_item	2435013	et	4	main
toote	doc_491521501653_item	2435015	et	4	main
kasutusjuhendis	doc_491521501653_item	2435016	et	3	main
kehtivad	doc_491521501653_item	2435021	et	4	main
artiklid	doc_491521501653_item	2435023	et	3	main
pealetükkivalt	doc_491521501653_item	2435036	et	4	main
ta	doc_491521501653_item	2435038	et	4	main
maitsetult	doc_491521501653_item	2435041	et	4	main
toit	doc_491521501653_item	2435050	et	3	main
isuäratavalt	doc_491521501653_item	2435054	et	4	main
sõnad	doc_491521501653_item	2435063	et	4	main
õigesse	doc_491521501653_item	2435064	et	3	main
vormi	doc_491521501653_item	2435065	et	4	main
see	doc_491521501653_item	2435066	et	3	main
näeb	doc_491521501653_item	2435067	et	3	main
ootamatu	doc_491521501653_item	2435073	et	4	main
lahtine	doc_491521501653_item	2435077	et	3	main
hirmus	doc_491521501653_item	2435084	et	4	main
peibutama	doc_491521501654_item	2435108	et	3	main
стягивать	doc_491521501654_item	2435112	et	2	main
царапать	doc_491521501654_item	2435116	et	2	main
ii	doc_491521501654_item	2435119	et	4	main
kohad	doc_491521501653_item	2435022	et	4	main
olemust	doc_491521501653_item	2435026	et	3	main
puänti	doc_491521501653_item	2435028	et	4	main
inimesed	doc_491521501653_item	2435034	et	3	main
üsna	doc_491521501653_item	2435040	et	3	main
neiu	doc_491521501653_item	2435042	et	4	main
käitus	doc_491521501653_item	2435043	et	4	main
tüdinult	doc_491521501653_item	2435049	et	4	main
isuäratavalt	doc_491521501653_item	2435052	et	4	main
sõnad	doc_491521501653_item	2435053	et	4	main
pealetükkivalt	doc_491521501653_item	2435057	et	4	main
pange	doc_491521501653_item	2435060	et	4	main
tuli	doc_491521501653_item	2435072	et	4	main
hirmuslik	doc_491521501653_item	2435085	et	4	main
ei	doc_491521501653_item	2435091	et	4	main
asju	doc_491521501653_item	2435093	et	3	main
tõlkige	doc_491521501654_item	2435097	et	3	main
препятствовать	doc_491521501654_item	2435099	et	2	main
устанавливать	doc_491521501654_item	2435101	et	2	main
taipama	doc_491521501654_item	2435102	et	3	main
обращаться	doc_491521501654_item	2435105	et	2	main
недоверчивый	doc_491521501654_item	2435107	et	2	main
venima	doc_491521501654_item	2435111	et	3	main
küünistama	doc_491521501654_item	2435115	et	3	main
sõlmite	doc_491521501654_item	2435124	et	3	main
tähelepanelik	doc_491521501654_item	2435127	et	4	main
sõlmides	doc_491521501654_item	2435128	et	4	main
lepingut	doc_491521501654_item	2435129	et	3	main
olge	doc_491521501654_item	2435130	et	3	main
tähelepanelik	doc_491521501654_item	2435131	et	4	main
2	doc_491521501654_item	2435132	et	2	main
kui	doc_491521501654_item	2435133	et	3	main
minnes	doc_491521501654_item	2435141	et	3	main
vaatama	doc_491521501654_item	2435144	et	3	main
kui	doc_491521501654_item	2435161	et	3	main
olge	doc_491521501654_item	2435164	et	3	main
ise	doc_491521501654_item	2435166	et	4	main
ise	doc_491521501654_item	2435172	et	4	main
aktiivne	doc_491521501654_item	2435173	et	3	main
kui	doc_491521501654_item	2435175	et	3	main
iv	doc_491521501654_item	2435209	et	4	main
moodustage	doc_491521501654_item	2435210	et	3	main
terveks	doc_491521501654_item	2435213	et	4	main
ajama	doc_491521501654_item	2435220	et	4	main
saama	doc_491521501654_item	2435223	et	4	main
tehti	doc_491521501654_item	2435230	et	3	main
loeti	doc_491521501654_item	2435234	et	3	main
olema	doc_491521501654_item	2435243	et	4	main
oldi	doc_491521501654_item	2435244	et	3	main
некоторые	doc_491521501654_item	2435247	et	2	main
быстро	doc_491521501654_item	2435253	et	2	main
on	doc_491521501654_item	2435257	et	4	main
вас	doc_491521501654_item	2435266	et	2	main
изучить	doc_491521501654_item	2435271	et	2	main
võimalus	doc_491521501654_item	2435275	et	3	main
õigus	doc_491521501654_item	2435290	et	4	main
vii	doc_491521501654_item	2435294	et	4	main
valed	doc_491521501654_item	2435298	et	3	main
sõnad	doc_491521501654_item	2435299	et	4	main
lasi	doc_491521501654_item	2435306	et	4	main
läbiajas	doc_491521501654_item	2435307	et	3	main
korda	doc_491521501654_item	2435308	et	4	main
nägi	doc_491521501654_item	2435309	et	3	main
ligi	doc_491521501654_item	2435321	et	3	main
mainet	doc_491521501654_item	2435335	et	4	main
tüdinult	doc_491521501654_item	2435344	et	4	main
neiu	doc_491521501654_item	2435350	et	4	main
pealetükkivalt	doc_491521501654_item	2435357	et	4	main
sulgudes	doc_491521501654_item	2435369	et	4	main
jubedalt	doc_491521501654_item	2435377	et	4	main
неверный	doc_491521501655_item	2435415	et	2	main
привлекать	doc_491521501655_item	2435417	et	2	main
hallitama	doc_491521501655_item	2435421	et	3	main
заставлять	doc_491521501655_item	2435426	et	2	main
1	doc_491521501655_item	2435430	et	2	main
sõlmite	doc_491521501655_item	2435432	et	3	main
olge	doc_491521501655_item	2435434	et	3	main
korterit	doc_491521501655_item	2435443	et	3	main
kaasa	doc_491521501655_item	2435447	et	4	main
korteri	doc_491521501655_item	2435449	et	3	main
kaasa	doc_491521501655_item	2435454	et	4	main
asjatundja	doc_491521501655_item	2435455	et	4	main
3	doc_491521501655_item	2435456	et	2	main
kui	doc_491521501655_item	2435457	et	3	main
ise	doc_491521501655_item	2435474	et	4	main
ise	doc_491521501655_item	2435480	et	4	main
ise	doc_491521501655_item	2435490	et	4	main
parima	doc_491521501655_item	2435494	et	4	main
kui	doc_491521501654_item	2435123	et	3	main
olge	doc_491521501654_item	2435126	et	3	main
asjatundja	doc_491521501654_item	2435140	et	4	main
võtke	doc_491521501654_item	2435145	et	3	main
suhtlete	doc_491521501654_item	2435150	et	3	main
on	doc_491521501654_item	2435152	et	4	main
abi	doc_491521501654_item	2435153	et	4	main
maaklerist	doc_491521501654_item	2435154	et	3	main
suheldes	doc_491521501654_item	2435155	et	3	main
ametnikega	doc_491521501654_item	2435156	et	3	main
on	doc_491521501654_item	2435157	et	4	main
ootate	doc_491521501654_item	2435162	et	3	main
ka	doc_491521501654_item	2435165	et	3	main
aktiivne	doc_491521501654_item	2435167	et	3	main
oodates	doc_491521501654_item	2435168	et	3	main
saate	doc_491521501654_item	2435179	et	4	main
tulemuse	doc_491521501654_item	2435181	et	3	main
tehes	doc_491521501654_item	2435182	et	3	main
ise	doc_491521501654_item	2435183	et	4	main
remonti	doc_491521501654_item	2435184	et	4	main
saate	doc_491521501654_item	2435185	et	4	main
parima	doc_491521501654_item	2435186	et	4	main
tulemuse	doc_491521501654_item	2435187	et	3	main
iii	doc_491521501654_item	2435188	et	4	main
moodustage	doc_491521501654_item	2435189	et	3	main
liitsõnad	doc_491521501654_item	2435190	et	3	main
poolteist	doc_491521501654_item	2435191	et	4	main
meetrit	doc_491521501654_item	2435192	et	3	main
pooleteistmeetrine	doc_491521501654_item	2435193	et	4	main
kuus	doc_491521501654_item	2435194	et	4	main
tundi	doc_491521501654_item	2435195	et	4	main
kuuetunnine	doc_491521501654_item	2435196	et	4	main
viis	doc_491521501654_item	2435197	et	4	main
liiget	doc_491521501654_item	2435198	et	3	main
viieliikmeline	doc_491521501654_item	2435199	et	4	main
sada	doc_491521501654_item	2435200	et	4	main
viis	doc_491521501654_item	2435201	et	4	main
krooni	doc_491521501654_item	2435202	et	4	main
saja	doc_491521501654_item	2435203	et	4	main
viie	doc_491521501654_item	2435204	et	3	main
kakskümmend	doc_491521501654_item	2435206	et	4	main
asjatundja	doc_491521501654_item	2435147	et	4	main
ametnikega	doc_491521501654_item	2435151	et	3	main
maaklerist	doc_491521501654_item	2435159	et	3	main
pakkumisi	doc_491521501654_item	2435163	et	4	main
ise	doc_491521501654_item	2435177	et	4	main
parima	doc_491521501654_item	2435180	et	4	main
paranema	doc_491521501654_item	2435215	et	3	main
aru	doc_491521501654_item	2435222	et	4	main
taipama	doc_491521501654_item	2435224	et	3	main
saadeti	doc_491521501654_item	2435232	et	3	main
pakkuti	doc_491521501654_item	2435236	et	4	main
nõudma	doc_491521501654_item	2435237	et	3	main
nõudi	doc_491521501654_item	2435238	et	4	main
lasti	doc_491521501654_item	2435240	et	4	main
ostma	doc_491521501654_item	2435241	et	3	main
имеют	doc_491521501654_item	2435249	et	2	main
ломаются	doc_491521501654_item	2435254	et	2	main
у	doc_491521501654_item	2435265	et	2	main
дома	doc_491521501654_item	2435269	et	2	main
on	doc_491521501654_item	2435274	et	4	main
uurida	doc_491521501654_item	2435277	et	3	main
kerkibkaasneb	doc_491521501654_item	2435302	et	4	main
haldab	doc_491521501654_item	2435303	et	3	main
vaeva	doc_491521501654_item	2435310	et	4	main
kasutusjuhendis	doc_491521501654_item	2435324	et	3	main
üleolevad	doc_491521501654_item	2435327	et	3	main
kirjutage	doc_491521501654_item	2435338	et	3	main
lünka	doc_491521501654_item	2435339	et	4	main
määrsõna	doc_491521501654_item	2435341	et	4	main
inimesed	doc_491521501654_item	2435342	et	3	main
seisid	doc_491521501654_item	2435343	et	4	main
üsna	doc_491521501654_item	2435348	et	3	main
maitsetult	doc_491521501654_item	2435349	et	4	main
käitus	doc_491521501654_item	2435351	et	4	main
väljakutsuvalt	doc_491521501654_item	2435352	et	4	main
toit	doc_491521501654_item	2435358	et	3	main
lõhnas	doc_491521501654_item	2435359	et	4	main
tüdinult	doc_491521501654_item	2435363	et	4	main
olevad	doc_491521501654_item	2435370	et	4	main
välja	doc_491521501654_item	2435378	et	4	main
külm	doc_491521501654_item	2435379	et	3	main
tuli	doc_491521501654_item	2435380	et	4	main
догадываться	doc_491521501655_item	2435411	et	2	main
ruutmeetrit	doc_491521501654_item	2435207	et	3	main
kahekümneruutmeetrine	doc_491521501654_item	2435208	et	4	main
sünonüümid	doc_491521501654_item	2435212	et	3	main
panema	doc_491521501654_item	2435217	et	3	main
taga	doc_491521501654_item	2435219	et	4	main
jälitama	doc_491521501654_item	2435221	et	3	main
ära	doc_491521501654_item	2435225	et	4	main
minema	doc_491521501654_item	2435226	et	3	main
lahenema	doc_491521501654_item	2435227	et	3	main
pakkuma	doc_491521501654_item	2435235	et	3	main
товары	doc_491521501654_item	2435248	et	2	main
и	doc_491521501654_item	2435252	et	2	main
kaubadel	doc_491521501654_item	2435256	et	4	main
есть	doc_491521501654_item	2435267	et	2	main
спокойно	doc_491521501654_item	2435270	et	2	main
kaup	doc_491521501654_item	2435291	et	3	main
tõmmake	doc_491521501654_item	2435295	et	3	main
alla	doc_491521501654_item	2435297	et	3	main
seda	doc_491521501654_item	2435300	et	3	main
maja	doc_491521501654_item	2435301	et	4	main
maha	doc_491521501654_item	2435313	et	4	main
mida	doc_491521501654_item	2435229	et	4	main
saatma	doc_491521501654_item	2435231	et	3	main
lugema	doc_491521501654_item	2435233	et	4	main
laskma	doc_491521501654_item	2435239	et	3	main
tõlkige	doc_491521501654_item	2435246	et	3	main
качество	doc_491521501654_item	2435251	et	2	main
mõnedel	doc_491521501654_item	2435255	et	3	main
kehv	doc_491521501654_item	2435258	et	3	main
ja	doc_491521501654_item	2435260	et	3	main
ruttu	doc_491521501654_item	2435262	et	4	main
katki	doc_491521501654_item	2435264	et	4	main
каталог	doc_491521501654_item	2435272	et	2	main
клиенты	doc_491521501654_item	2435281	et	2	main
право	doc_491521501654_item	2435283	et	2	main
товар	doc_491521501654_item	2435285	et	2	main
рассрочку	doc_491521501654_item	2435287	et	2	main
püsiklientidel	doc_491521501654_item	2435288	et	3	main
on	doc_491521501654_item	2435289	et	4	main
järelmaksuga	doc_491521501654_item	2435293	et	3	main
maakler	doc_491521501654_item	2435305	et	3	main
korterit	doc_491521501654_item	2435312	et	3	main
müüa	doc_491521501654_item	2435314	et	3	main
lõvi	doc_491521501654_item	2435315	et	4	main
hakkas	doc_491521501654_item	2435316	et	3	main
saagile	doc_491521501654_item	2435317	et	3	main
peale	doc_491521501654_item	2435318	et	4	main
käimatoime	doc_491521501654_item	2435319	et	4	main
tulema	doc_491521501654_item	2435320	et	4	main
on	doc_491521501654_item	2435325	et	4	main
mõned	doc_491521501654_item	2435326	et	3	main
firma	doc_491521501654_item	2435333	et	4	main
olemust	doc_491521501654_item	2435334	et	3	main
ta	doc_491521501654_item	2435346	et	4	main
sõnad	doc_491521501654_item	2435361	et	4	main
väljakutsuvalt	doc_491521501654_item	2435364	et	4	main
maitsetult	doc_491521501654_item	2435366	et	4	main
ix	doc_491521501654_item	2435367	et	4	main
pange	doc_491521501654_item	2435368	et	4	main
see	doc_491521501654_item	2435374	et	3	main
näeb	doc_491521501654_item	2435375	et	3	main
jube	doc_491521501654_item	2435376	et	4	main
kohtlema	doc_491521501655_item	2435412	et	3	main
umbusklik	doc_491521501655_item	2435414	et	3	main
venima	doc_491521501655_item	2435419	et	3	main
sundima	doc_491521501655_item	2435425	et	4	main
tähelepanelik	doc_491521501655_item	2435439	et	4	main
vaatama	doc_491521501655_item	2435445	et	3	main
võtke	doc_491521501655_item	2435446	et	3	main
üle	doc_491521501655_item	2435450	et	3	main
võtke	doc_491521501655_item	2435453	et	3	main
aktiivne	doc_491521501655_item	2435475	et	3	main
aktiivne	doc_491521501655_item	2435481	et	3	main
teete	doc_491521501655_item	2435484	et	3	main
tulemuse	doc_491521501655_item	2435495	et	3	main
kuuetunnine	doc_491521501655_item	2435504	et	4	main
krooni	doc_491521501655_item	2435510	et	4	main
kakskümmend	doc_491521501655_item	2435514	et	4	main
ühesõnalised	doc_491521501655_item	2435519	et	4	main
hiilima	doc_491521501654_item	2435322	et	3	main
eksitavad	doc_491521501654_item	2435328	et	4	main
kohad	doc_491521501654_item	2435330	et	4	main
artiklid	doc_491521501654_item	2435331	et	3	main
kahjustasid	doc_491521501654_item	2435332	et	4	main
puänti	doc_491521501654_item	2435336	et	4	main
riietub	doc_491521501654_item	2435347	et	3	main
müüja	doc_491521501654_item	2435353	et	4	main
isuäratavalt	doc_491521501654_item	2435360	et	4	main
vormi	doc_491521501654_item	2435373	et	4	main
ootamatu	doc_491521501654_item	2435381	et	4	main
ootamatult	doc_491521501654_item	2435382	et	4	main
koer	doc_491521501654_item	2435383	et	3	main
jookseb	doc_491521501654_item	2435384	et	3	main
lahtine	doc_491521501654_item	2435385	et	3	main
lahtiselt	doc_491521501654_item	2435386	et	4	main
ringi	doc_491521501654_item	2435387	et	4	main
see	doc_491521501654_item	2435388	et	3	main
juhtum	doc_491521501654_item	2435389	et	3	main
oli	doc_491521501654_item	2435390	et	3	main
lihtsalt	doc_491521501654_item	2435391	et	4	main
hirmus	doc_491521501654_item	2435392	et	4	main
hirmus	doc_491521501654_item	2435393	et	4	main
on	doc_491521501654_item	2435394	et	4	main
piinlik	doc_491521501654_item	2435395	et	3	main
piinlik	doc_491521501654_item	2435396	et	3	main
kui	doc_491521501654_item	2435397	et	3	main
inimesed	doc_491521501654_item	2435398	et	3	main
ei	doc_491521501654_item	2435399	et	4	main
hoia	doc_491521501654_item	2435400	et	4	main
asju	doc_491521501654_item	2435401	et	3	main
korras	doc_491521501654_item	2435402	et	4	main
kontrolltöö	doc_491521501655_item	2435403	et	4	main
i	doc_491521501655_item	2435404	et	4	main
tõlkige	doc_491521501655_item	2435405	et	3	main
takistama	doc_491521501655_item	2435406	et	3	main
препятствовать	doc_491521501655_item	2435407	et	2	main
tuvastama	doc_491521501655_item	2435408	et	3	main
устанавливать	doc_491521501655_item	2435409	et	2	main
taipama	doc_491521501655_item	2435410	et	3	main
сомневаться	doc_491521501655_item	2435413	et	2	main
peibutama	doc_491521501655_item	2435416	et	3	main
välja	doc_491521501655_item	2435418	et	4	main
плесневеть	doc_491521501655_item	2435422	et	2	main
царапать	doc_491521501655_item	2435424	et	2	main
2	doc_491521501655_item	2435440	et	2	main
kui	doc_491521501655_item	2435441	et	3	main
asjatundja	doc_491521501655_item	2435448	et	4	main
vaatama	doc_491521501655_item	2435451	et	3	main
minnes	doc_491521501655_item	2435452	et	3	main
pakkumisi	doc_491521501655_item	2435476	et	4	main
ootamiseks	doc_491521501655_item	2435477	et	4	main
ka	doc_491521501655_item	2435479	et	3	main
remonti	doc_491521501655_item	2435491	et	4	main
iii	doc_491521501655_item	2435496	et	4	main
kuus	doc_491521501655_item	2435502	et	4	main
tundi	doc_491521501655_item	2435503	et	4	main
kroonine	doc_491521501655_item	2435513	et	4	main
moodustage	doc_491521501655_item	2435518	et	3	main
sünonüümid	doc_491521501655_item	2435520	et	3	main
saama	doc_491521501655_item	2435531	et	4	main
on	doc_491521501655_item	2435542	et	4	main
nõudma	doc_491521501655_item	2435547	et	3	main
vi	doc_491521501655_item	2435559	et	4	main
некоторые	doc_491521501655_item	2435561	et	2	main
ломаются	doc_491521501655_item	2435568	et	2	main
kehv	doc_491521501655_item	2435572	et	3	main
ja	doc_491521501655_item	2435574	et	3	main
у	doc_491521501655_item	2435579	et	2	main
дома	doc_491521501655_item	2435583	et	2	main
teil	doc_491521501655_item	2435587	et	4	main
võimalus	doc_491521501655_item	2435589	et	3	main
katalogi	doc_491521501655_item	2435590	et	4	main
rahul	doc_491521501655_item	2435591	et	4	main
uurida	doc_491521501655_item	2435592	et	3	main
püsiklientidel	doc_491521501655_item	2435602	et	3	main
õigus	doc_491521501655_item	2435604	et	4	main
vii	doc_491521501655_item	2435608	et	4	main
tõmmake	doc_491521501655_item	2435609	et	3	main
saagile	doc_491521501655_item	2435630	et	3	main
kohad	doc_491521501655_item	2435642	et	4	main
artiklid	doc_491521501655_item	2435643	et	3	main
viii	doc_491521501655_item	2435649	et	4	main
käitus	doc_491521501655_item	2435662	et	4	main
toit	doc_491521501655_item	2435668	et	3	main
ootamatu	doc_491521501655_item	2435689	et	4	main
on	doc_491521501655_item	2435701	et	4	main
piinlik	doc_491521501655_item	2435702	et	3	main
inimesed	doc_491521501655_item	2435704	et	3	main
i	doc_491521501656_item	2435710	et	4	main
takistama	doc_491521501656_item	2435712	et	3	main
taipama	doc_491521501656_item	2435716	et	3	main
обращаться	doc_491521501656_item	2435719	et	2	main
привлекать	doc_491521501656_item	2435722	et	2	main
venima	doc_491521501656_item	2435725	et	3	main
hallitama	doc_491521501656_item	2435727	et	3	main
принуждать	doc_491521501656_item	2435733	et	2	main
1	doc_491521501656_item	2435737	et	2	main
tähelepanelik	doc_491521501656_item	2435742	et	4	main
2	doc_491521501656_item	2435747	et	2	main
kaasa	doc_491521501656_item	2435754	et	4	main
asjatundja	doc_491521501656_item	2435755	et	4	main
korterit	doc_491521501656_item	2435756	et	3	main
üle	doc_491521501656_item	2435757	et	3	main
vaatama	doc_491521501656_item	2435758	et	3	main
minnes	doc_491521501656_item	2435759	et	3	main
kui	doc_491521501656_item	2435776	et	3	main
olge	doc_491521501656_item	2435785	et	3	main
ise	doc_491521501656_item	2435787	et	4	main
iii	doc_491521501656_item	2435802	et	4	main
liitsõnad	doc_491521501656_item	2435804	et	3	main
meetrit	doc_491521501656_item	2435806	et	3	main
viis	doc_491521501656_item	2435811	et	4	main
kakskümmend	doc_491521501656_item	2435820	et	4	main
ruutmeetrit	doc_491521501656_item	2435821	et	3	main
sünonüümid	doc_491521501656_item	2435827	et	3	main
saama	doc_491521501656_item	2435829	et	4	main
juurde	doc_491521501656_item	2435830	et	4	main
panema	doc_491521501656_item	2435831	et	3	main
ära	doc_491521501656_item	2435836	et	4	main
minema	doc_491521501656_item	2435837	et	3	main
küünistama	doc_491521501655_item	2435423	et	3	main
kasutage	doc_491521501655_item	2435428	et	3	main
kui	doc_491521501655_item	2435431	et	3	main
tähelepanelik	doc_491521501655_item	2435435	et	4	main
lepingu	doc_491521501655_item	2435436	et	3	main
sõlmides	doc_491521501655_item	2435437	et	4	main
olge	doc_491521501655_item	2435438	et	3	main
üle	doc_491521501655_item	2435444	et	3	main
suhtlete	doc_491521501655_item	2435458	et	3	main
ametnikega	doc_491521501655_item	2435459	et	3	main
on	doc_491521501655_item	2435460	et	4	main
abi	doc_491521501655_item	2435461	et	4	main
maaklerist	doc_491521501655_item	2435462	et	3	main
ametnikega	doc_491521501655_item	2435463	et	3	main
suhtlemiseks	doc_491521501655_item	2435464	et	4	main
abi	doc_491521501655_item	2435466	et	4	main
maaklerist	doc_491521501655_item	2435467	et	3	main
4	doc_491521501655_item	2435468	et	2	main
lähete	doc_491521501655_item	2435442	et	4	main
kui	doc_491521501655_item	2435469	et	3	main
ootate	doc_491521501655_item	2435470	et	3	main
olge	doc_491521501655_item	2435478	et	3	main
kui	doc_491521501655_item	2435483	et	3	main
ise	doc_491521501655_item	2435485	et	4	main
saate	doc_491521501655_item	2435493	et	4	main
liitsõnad	doc_491521501655_item	2435498	et	3	main
meetrit	doc_491521501655_item	2435500	et	3	main
viieliikmeline	doc_491521501655_item	2435507	et	4	main
sada	doc_491521501655_item	2435508	et	4	main
viis	doc_491521501655_item	2435509	et	4	main
kahekümneruutmeetrine	doc_491521501655_item	2435516	et	4	main
saama	doc_491521501655_item	2435522	et	4	main
paranema	doc_491521501655_item	2435523	et	3	main
taga	doc_491521501655_item	2435527	et	4	main
jälitama	doc_491521501655_item	2435529	et	3	main
minema	doc_491521501655_item	2435533	et	3	main
lugema	doc_491521501655_item	2435541	et	4	main
pakkutud	doc_491521501655_item	2435546	et	4	main
товары	doc_491521501655_item	2435562	et	2	main
качество	doc_491521501655_item	2435565	et	2	main
lähevad	doc_491521501655_item	2435576	et	3	main
есть	doc_491521501655_item	2435581	et	2	main
изучить	doc_491521501655_item	2435585	et	2	main
рассрочку	doc_491521501655_item	2435601	et	2	main
on	doc_491521501655_item	2435603	et	4	main
osta	doc_491521501655_item	2435605	et	4	main
kaup	doc_491521501655_item	2435606	et	3	main
järelmaksuga	doc_491521501655_item	2435607	et	3	main
kerkibkaasneb	doc_491521501655_item	2435615	et	4	main
haldab	doc_491521501655_item	2435616	et	3	main
vaeva	doc_491521501655_item	2435623	et	4	main
et	doc_491521501655_item	2435624	et	3	main
tulema	doc_491521501655_item	2435633	et	4	main
hiilima	doc_491521501655_item	2435635	et	3	main
firma	doc_491521501655_item	2435645	et	4	main
lünka	doc_491521501655_item	2435651	et	4	main
inimesed	doc_491521501655_item	2435654	et	3	main
seisid	doc_491521501655_item	2435655	et	4	main
järjekorras	doc_491521501655_item	2435656	et	3	main
pakkus	doc_491521501655_item	2435664	et	3	main
oma	doc_491521501655_item	2435665	et	4	main
kaupa	doc_491521501655_item	2435666	et	4	main
ootamatult	doc_491521501655_item	2435690	et	4	main
jookseb	doc_491521501655_item	2435692	et	3	main
juhtum	doc_491521501655_item	2435696	et	3	main
lihtsalt	doc_491521501655_item	2435698	et	4	main
hirmus	doc_491521501655_item	2435699	et	4	main
hirmus	doc_491521501655_item	2435700	et	4	main
kontrolltöö	doc_491521501656_item	2435709	et	4	main
tuvastama	doc_491521501656_item	2435714	et	3	main
peibutama	doc_491521501656_item	2435721	et	3	main
покрываться	doc_491521501656_item	2435728	et	2	main
küünistama	doc_491521501656_item	2435730	et	3	main
kasutage	doc_491521501656_item	2435735	et	3	main
olge	doc_491521501656_item	2435741	et	3	main
olge	doc_491521501656_item	2435745	et	3	main
vaatama	doc_491521501656_item	2435752	et	3	main
oodates	doc_491521501656_item	2435783	et	3	main
5	doc_491521501656_item	2435789	et	2	main
kui	doc_491521501656_item	2435790	et	3	main
ise	doc_491521501656_item	2435792	et	4	main
moodustage	doc_491521501656_item	2435803	et	3	main
poolteist	doc_491521501656_item	2435805	et	4	main
viieliigeline	doc_491521501656_item	2435813	et	4	main
sada	doc_491521501656_item	2435814	et	4	main
viis	doc_491521501656_item	2435815	et	4	main
viie	doc_491521501656_item	2435818	et	3	main
kahekümne	doc_491521501656_item	2435822	et	4	main
moodustage	doc_491521501656_item	2435825	et	3	main
terveks	doc_491521501656_item	2435828	et	4	main
aru	doc_491521501656_item	2435834	et	4	main
saama	doc_491521501656_item	2435835	et	4	main
loeti	doc_491521501656_item	2435844	et	3	main
pakkuma	doc_491521501656_item	2435845	et	3	main
pakuti	doc_491521501656_item	2435846	et	3	main
nõudma	doc_491521501656_item	2435847	et	3	main
nõudeti	doc_491521501656_item	2435848	et	4	main
vi	doc_491521501656_item	2435855	et	4	main
плохое	doc_491521501656_item	2435860	et	2	main
on	doc_491521501655_item	2435465	et	4	main
pakkumisi	doc_491521501655_item	2435471	et	4	main
olge	doc_491521501655_item	2435472	et	3	main
ka	doc_491521501655_item	2435473	et	3	main
5	doc_491521501655_item	2435482	et	2	main
remonti	doc_491521501655_item	2435486	et	4	main
saate	doc_491521501655_item	2435487	et	4	main
parima	doc_491521501655_item	2435488	et	4	main
tulemuse	doc_491521501655_item	2435489	et	3	main
tegemiseks	doc_491521501655_item	2435492	et	4	main
moodustage	doc_491521501655_item	2435497	et	3	main
viis	doc_491521501655_item	2435505	et	4	main
saja	doc_491521501655_item	2435511	et	4	main
viie	doc_491521501655_item	2435512	et	3	main
lisama	doc_491521501655_item	2435526	et	3	main
ära	doc_491521501655_item	2435532	et	4	main
v	doc_491521501655_item	2435535	et	4	main
saatma	doc_491521501655_item	2435538	et	3	main
pakkuma	doc_491521501655_item	2435544	et	3	main
on	doc_491521501655_item	2435545	et	4	main
olema	doc_491521501655_item	2435556	et	4	main
on	doc_491521501655_item	2435557	et	4	main
oldud	doc_491521501655_item	2435558	et	4	main
имеют	doc_491521501655_item	2435563	et	2	main
быстро	doc_491521501655_item	2435567	et	2	main
kaupadel	doc_491521501655_item	2435570	et	3	main
вас	doc_491521501655_item	2435580	et	2	main
возможность	doc_491521501655_item	2435582	et	2	main
kodus	doc_491521501655_item	2435593	et	4	main
клиенты	doc_491521501655_item	2435595	et	2	main
право	doc_491521501655_item	2435597	et	2	main
товар	doc_491521501655_item	2435599	et	2	main
valed	doc_491521501655_item	2435611	et	3	main
poolteist	doc_491521501655_item	2435499	et	4	main
pooleteistmeetrine	doc_491521501655_item	2435501	et	4	main
liiget	doc_491521501655_item	2435506	et	3	main
ruutmeetrit	doc_491521501655_item	2435515	et	3	main
iv	doc_491521501655_item	2435517	et	4	main
terveks	doc_491521501655_item	2435521	et	4	main
juurde	doc_491521501655_item	2435524	et	4	main
ajama	doc_491521501655_item	2435528	et	4	main
loetud	doc_491521501655_item	2435543	et	4	main
on	doc_491521501655_item	2435548	et	4	main
nõutud	doc_491521501655_item	2435549	et	4	main
on	doc_491521501655_item	2435551	et	4	main
и	doc_491521501655_item	2435566	et	2	main
mõnedel	doc_491521501655_item	2435569	et	3	main
on	doc_491521501655_item	2435571	et	4	main
kvaliteet	doc_491521501655_item	2435573	et	3	main
nad	doc_491521501655_item	2435575	et	3	main
katki	doc_491521501655_item	2435577	et	4	main
каталог	doc_491521501655_item	2435586	et	2	main
постоянные	doc_491521501655_item	2435594	et	2	main
имеют	doc_491521501655_item	2435596	et	2	main
покупать	doc_491521501655_item	2435598	et	2	main
maha	doc_491521501655_item	2435610	et	4	main
nägi	doc_491521501655_item	2435622	et	3	main
korterit	doc_491521501655_item	2435625	et	3	main
maha	doc_491521501655_item	2435626	et	4	main
müüa	doc_491521501655_item	2435627	et	3	main
käimatoime	doc_491521501655_item	2435632	et	4	main
kahjustasid	doc_491521501655_item	2435644	et	4	main
mainet	doc_491521501655_item	2435647	et	4	main
sobiv	doc_491521501655_item	2435652	et	4	main
määrsõna	doc_491521501655_item	2435653	et	4	main
müüja	doc_491521501655_item	2435663	et	4	main
tuli	doc_491521501655_item	2435688	et	4	main
see	doc_491521501655_item	2435695	et	3	main
kui	doc_491521501655_item	2435703	et	3	main
препятствовать	doc_491521501656_item	2435713	et	2	main
kohtlema	doc_491521501656_item	2435718	et	3	main
tehti	doc_491521501655_item	2435537	et	3	main
panema	doc_491521501655_item	2435525	et	3	main
aru	doc_491521501655_item	2435530	et	4	main
hülgima	doc_491521501655_item	2435534	et	4	main
mida	doc_491521501655_item	2435536	et	4	main
on	doc_491521501655_item	2435539	et	4	main
saatud	doc_491521501655_item	2435540	et	4	main
laskma	doc_491521501655_item	2435550	et	3	main
lastud	doc_491521501655_item	2435552	et	4	main
ostma	doc_491521501655_item	2435553	et	3	main
on	doc_491521501655_item	2435554	et	4	main
ostud	doc_491521501655_item	2435555	et	3	main
tõlkige	doc_491521501655_item	2435560	et	3	main
плохое	doc_491521501655_item	2435564	et	2	main
ruttu	doc_491521501655_item	2435578	et	4	main
спокойно	doc_491521501655_item	2435584	et	2	main
on	doc_491521501655_item	2435588	et	4	main
в	doc_491521501655_item	2435600	et	2	main
sõnad	doc_491521501655_item	2435612	et	4	main
seda	doc_491521501655_item	2435613	et	3	main
maja	doc_491521501655_item	2435614	et	4	main
korteriühistu	doc_491521501655_item	2435617	et	4	main
maakler	doc_491521501655_item	2435618	et	3	main
lasi	doc_491521501655_item	2435619	et	4	main
läbiajas	doc_491521501655_item	2435620	et	3	main
korda	doc_491521501655_item	2435621	et	4	main
lõvi	doc_491521501655_item	2435628	et	4	main
hakkas	doc_491521501655_item	2435629	et	3	main
peale	doc_491521501655_item	2435631	et	4	main
ligi	doc_491521501655_item	2435634	et	3	main
toote	doc_491521501655_item	2435636	et	4	main
kasutusjuhendis	doc_491521501655_item	2435637	et	3	main
puänti	doc_491521501655_item	2435648	et	4	main
neiu	doc_491521501655_item	2435661	et	4	main
pealetükkivalt	doc_491521501655_item	2435667	et	4	main
külm	doc_491521501655_item	2435687	et	3	main
ringi	doc_491521501655_item	2435694	et	4	main
ei	doc_491521501655_item	2435705	et	4	main
korras	doc_491521501655_item	2435708	et	4	main
tõlkige	doc_491521501656_item	2435711	et	3	main
устанавливать	doc_491521501656_item	2435715	et	2	main
приманивать	doc_491521501656_item	2435723	et	2	main
välja	doc_491521501656_item	2435724	et	4	main
вытягиваться	doc_491521501656_item	2435726	et	2	main
плесенью	doc_491521501656_item	2435729	et	2	main
царапать	doc_491521501656_item	2435731	et	2	main
sõlmite	doc_491521501656_item	2435739	et	3	main
tähelepanelik	doc_491521501656_item	2435746	et	4	main
korterit	doc_491521501656_item	2435750	et	3	main
aktiivne	doc_491521501656_item	2435782	et	3	main
ka	doc_491521501656_item	2435786	et	3	main
teete	doc_491521501656_item	2435791	et	3	main
remonti	doc_491521501656_item	2435793	et	4	main
saate	doc_491521501656_item	2435794	et	4	main
parima	doc_491521501656_item	2435800	et	4	main
poolteisemeetrine	doc_491521501656_item	2435807	et	4	main
kuus	doc_491521501656_item	2435808	et	4	main
liiget	doc_491521501656_item	2435812	et	3	main
iv	doc_491521501656_item	2435824	et	4	main
taga	doc_491521501656_item	2435832	et	4	main
laskma	doc_491521501656_item	2435849	et	3	main
tõlkige	doc_491521501656_item	2435856	et	3	main
и	doc_491521501656_item	2435862	et	2	main
дома	doc_491521501656_item	2435879	et	2	main
mõned	doc_491521501656_item	2435935	et	3	main
firma	doc_491521501656_item	2435942	et	4	main
mainet	doc_491521501656_item	2435944	et	4	main
puänti	doc_491521501656_item	2435945	et	4	main
viii	doc_491521501656_item	2435946	et	4	main
kirjutage	doc_491521501656_item	2435947	et	3	main
riietub	doc_491521501656_item	2435956	et	3	main
üsna	doc_491521501656_item	2435957	et	3	main
maitsetult	doc_491521501656_item	2435958	et	4	main
pakkus	doc_491521501656_item	2435963	et	3	main
oma	doc_491521501656_item	2435964	et	4	main
väljakutsuvalt	doc_491521501656_item	2435973	et	4	main
sulgudes	doc_491521501656_item	2435978	et	4	main
on	doc_491521501655_item	2435638	et	4	main
mõned	doc_491521501655_item	2435639	et	3	main
üleolevadeksitavad	doc_491521501655_item	2435640	et	4	main
kehtivad	doc_491521501655_item	2435641	et	4	main
olemust	doc_491521501655_item	2435646	et	3	main
kirjutage	doc_491521501655_item	2435650	et	3	main
ta	doc_491521501655_item	2435657	et	4	main
riietub	doc_491521501655_item	2435658	et	3	main
üsna	doc_491521501655_item	2435659	et	3	main
maitsetult	doc_491521501655_item	2435660	et	4	main
lõhnas	doc_491521501655_item	2435669	et	4	main
sõnad	doc_491521501655_item	2435670	et	4	main
isuäratavalt	doc_491521501655_item	2435671	et	4	main
väljakutsuvalt	doc_491521501655_item	2435673	et	4	main
pealetükkivalt	doc_491521501655_item	2435674	et	4	main
tüdinult	doc_491521501655_item	2435672	et	4	main
maitsetult	doc_491521501655_item	2435675	et	4	main
ix	doc_491521501655_item	2435676	et	4	main
pange	doc_491521501655_item	2435677	et	4	main
sulgudes	doc_491521501655_item	2435678	et	4	main
olevad	doc_491521501655_item	2435679	et	4	main
sõnad	doc_491521501655_item	2435680	et	4	main
õigesse	doc_491521501655_item	2435681	et	3	main
vormi	doc_491521501655_item	2435682	et	4	main
see	doc_491521501655_item	2435683	et	3	main
näeb	doc_491521501655_item	2435684	et	3	main
jube	doc_491521501655_item	2435685	et	4	main
välja	doc_491521501655_item	2435686	et	4	main
koer	doc_491521501655_item	2435691	et	3	main
lahtine	doc_491521501655_item	2435693	et	3	main
oli	doc_491521501655_item	2435697	et	3	main
hoia	doc_491521501655_item	2435706	et	4	main
asju	doc_491521501655_item	2435707	et	3	main
догадываться	doc_491521501656_item	2435717	et	2	main
umbusklik	doc_491521501656_item	2435720	et	3	main
ii	doc_491521501656_item	2435734	et	4	main
sõlmides	doc_491521501656_item	2435743	et	4	main
lepingut	doc_491521501656_item	2435744	et	3	main
pakkumisi	doc_491521501656_item	2435778	et	4	main
olge	doc_491521501656_item	2435779	et	3	main
ka	doc_491521501656_item	2435780	et	3	main
ise	doc_491521501656_item	2435781	et	4	main
aktiivne	doc_491521501656_item	2435788	et	3	main
remonti	doc_491521501656_item	2435798	et	4	main
saate	doc_491521501656_item	2435799	et	4	main
tundi	doc_491521501656_item	2435809	et	4	main
saja	doc_491521501656_item	2435817	et	4	main
sundima	doc_491521501656_item	2435732	et	4	main
des-vormi	doc_491521501656_item	2435736	et	4	main
kui	doc_491521501656_item	2435738	et	3	main
lepingut	doc_491521501656_item	2435740	et	3	main
kui	doc_491521501656_item	2435748	et	3	main
lähete	doc_491521501656_item	2435749	et	4	main
üle	doc_491521501656_item	2435751	et	3	main
võtke	doc_491521501656_item	2435753	et	3	main
võtke	doc_491521501656_item	2435760	et	3	main
kaasa	doc_491521501656_item	2435761	et	4	main
asjatundja	doc_491521501656_item	2435762	et	4	main
3	doc_491521501656_item	2435763	et	2	main
kui	doc_491521501656_item	2435764	et	3	main
suhtlete	doc_491521501656_item	2435765	et	3	main
ametnikega	doc_491521501656_item	2435766	et	3	main
on	doc_491521501656_item	2435767	et	4	main
abi	doc_491521501656_item	2435768	et	4	main
maaklerist	doc_491521501656_item	2435769	et	3	main
suheldes	doc_491521501656_item	2435770	et	3	main
ametnikega	doc_491521501656_item	2435771	et	3	main
on	doc_491521501656_item	2435772	et	4	main
abi	doc_491521501656_item	2435773	et	4	main
maaklerist	doc_491521501656_item	2435774	et	3	main
4	doc_491521501656_item	2435775	et	2	main
ootate	doc_491521501656_item	2435777	et	3	main
pakkumisi	doc_491521501656_item	2435784	et	4	main
parima	doc_491521501656_item	2435795	et	4	main
tulemuse	doc_491521501656_item	2435796	et	3	main
tehes	doc_491521501656_item	2435797	et	3	main
tulemuse	doc_491521501656_item	2435801	et	3	main
kuuetunnine	doc_491521501656_item	2435810	et	4	main
krooni	doc_491521501656_item	2435816	et	4	main
kroonine	doc_491521501656_item	2435819	et	4	main
ruutmeetriline	doc_491521501656_item	2435823	et	4	main
ajama	doc_491521501656_item	2435833	et	4	main
lasti	doc_491521501656_item	2435850	et	4	main
ostma	doc_491521501656_item	2435851	et	3	main
osteti	doc_491521501656_item	2435852	et	3	main
olema	doc_491521501656_item	2435853	et	4	main
товары	doc_491521501656_item	2435858	et	2	main
быстро	doc_491521501656_item	2435863	et	2	main
katki	doc_491521501656_item	2435874	et	4	main
возможность	doc_491521501656_item	2435878	et	2	main
korterit	doc_491521501656_item	2435921	et	3	main
müüa	doc_491521501656_item	2435923	et	3	main
saagile	doc_491521501656_item	2435926	et	3	main
ligi	doc_491521501656_item	2435930	et	3	main
üleolevad	doc_491521501656_item	2435936	et	3	main
kehtivad	doc_491521501656_item	2435938	et	4	main
kohad	doc_491521501656_item	2435939	et	4	main
artiklid	doc_491521501656_item	2435940	et	3	main
sobiv	doc_491521501656_item	2435949	et	4	main
inimesed	doc_491521501656_item	2435951	et	3	main
kaupa	doc_491521501656_item	2435965	et	4	main
isuäratavalt	doc_491521501656_item	2435969	et	4	main
isuäratavalt	doc_491521501656_item	2435971	et	4	main
tüdinult	doc_491521501656_item	2435972	et	4	main
ix	doc_491521501656_item	2435976	et	4	main
pange	doc_491521501656_item	2435977	et	4	main
ühesõnalised	doc_491521501656_item	2435826	et	4	main
oldi	doc_491521501656_item	2435854	et	3	main
имеют	doc_491521501656_item	2435859	et	2	main
ломаются	doc_491521501656_item	2435864	et	2	main
tootedel	doc_491521501656_item	2435866	et	4	main
kehv	doc_491521501656_item	2435868	et	3	main
nad	doc_491521501656_item	2435871	et	3	main
lähevad	doc_491521501656_item	2435873	et	3	main
вас	doc_491521501656_item	2435876	et	2	main
изучить	doc_491521501656_item	2435881	et	2	main
teil	doc_491521501656_item	2435883	et	4	main
on	doc_491521501656_item	2435884	et	4	main
võimalus	doc_491521501656_item	2435885	et	3	main
rahulikult	doc_491521501656_item	2435886	et	4	main
uurida	doc_491521501656_item	2435887	et	3	main
kataloogi	doc_491521501656_item	2435888	et	4	main
kodus	doc_491521501656_item	2435889	et	4	main
постоянные	doc_491521501656_item	2435890	et	2	main
клиенты	doc_491521501656_item	2435891	et	2	main
имеют	doc_491521501656_item	2435892	et	2	main
право	doc_491521501656_item	2435893	et	2	main
покупать	doc_491521501656_item	2435894	et	2	main
товар	doc_491521501656_item	2435895	et	2	main
в	doc_491521501656_item	2435896	et	2	main
рассрочку	doc_491521501656_item	2435897	et	2	main
püsiklientidel	doc_491521501656_item	2435898	et	3	main
on	doc_491521501656_item	2435899	et	4	main
õigus	doc_491521501656_item	2435900	et	4	main
osta	doc_491521501656_item	2435901	et	4	main
kaupu	doc_491521501656_item	2435902	et	3	main
järelmaksuga	doc_491521501656_item	2435903	et	3	main
vii	doc_491521501656_item	2435904	et	4	main
tõmmake	doc_491521501656_item	2435905	et	3	main
maha	doc_491521501656_item	2435906	et	4	main
valed	doc_491521501656_item	2435907	et	3	main
sõnad	doc_491521501656_item	2435908	et	4	main
seda	doc_491521501656_item	2435909	et	3	main
kerkibkaasneb	doc_491521501656_item	2435911	et	4	main
maja	doc_491521501656_item	2435910	et	4	main
haldab	doc_491521501656_item	2435912	et	3	main
korteriühisyu	doc_491521501656_item	2435913	et	4	main
maakler	doc_491521501656_item	2435914	et	3	main
v	doc_491521501656_item	2435838	et	4	main
mida	doc_491521501656_item	2435839	et	4	main
tehti	doc_491521501656_item	2435840	et	3	main
saatma	doc_491521501656_item	2435841	et	3	main
saadeti	doc_491521501656_item	2435842	et	3	main
lugema	doc_491521501656_item	2435843	et	4	main
некоторые	doc_491521501656_item	2435857	et	2	main
качество	doc_491521501656_item	2435861	et	2	main
on	doc_491521501656_item	2435867	et	4	main
ja	doc_491521501656_item	2435870	et	3	main
есть	doc_491521501656_item	2435877	et	2	main
спокойно	doc_491521501656_item	2435880	et	2	main
mõnedel	doc_491521501656_item	2435865	et	3	main
kvaliteet	doc_491521501656_item	2435869	et	3	main
kiresti	doc_491521501656_item	2435872	et	4	main
у	doc_491521501656_item	2435875	et	2	main
каталог	doc_491521501656_item	2435882	et	2	main
lasi	doc_491521501656_item	2435915	et	4	main
läbiajas	doc_491521501656_item	2435916	et	3	main
korda	doc_491521501656_item	2435917	et	4	main
tulema	doc_491521501656_item	2435929	et	4	main
kasutusjuhendis	doc_491521501656_item	2435933	et	3	main
eksitavad	doc_491521501656_item	2435937	et	4	main
lünka	doc_491521501656_item	2435948	et	4	main
neiu	doc_491521501656_item	2435959	et	4	main
käitus	doc_491521501656_item	2435960	et	4	main
lõhnas	doc_491521501656_item	2435968	et	4	main
pealetükkivalt	doc_491521501656_item	2435974	et	4	main
maitsetult	doc_491521501656_item	2435975	et	4	main
sõnad	doc_491521501656_item	2435980	et	4	main
vormi	doc_491521501656_item	2435982	et	4	main
näeb	doc_491521501656_item	2435984	et	3	main
tõlkige	doc_491521501658_item	2436319	et	3	main
неверующий	doc_491521501658_item	2436329	et	2	main
välja	doc_491521501658_item	2436333	et	4	main
sundima	doc_491521501658_item	2436340	et	4	main
ii	doc_491521501658_item	2436342	et	4	main
kasutage	doc_491521501658_item	2436343	et	3	main
des-vormi	doc_491521501658_item	2436344	et	4	main
nägi	doc_491521501656_item	2435918	et	3	main
vaeva	doc_491521501656_item	2435919	et	4	main
et	doc_491521501656_item	2435920	et	3	main
hakkas	doc_491521501656_item	2435925	et	3	main
hiilima	doc_491521501656_item	2435931	et	3	main
kahjustasid	doc_491521501656_item	2435941	et	4	main
järjekorras	doc_491521501656_item	2435954	et	3	main
ta	doc_491521501656_item	2435955	et	4	main
müüja	doc_491521501656_item	2435962	et	4	main
toit	doc_491521501656_item	2435967	et	3	main
olevad	doc_491521501656_item	2435979	et	4	main
jube	doc_491521501656_item	2435985	et	4	main
tuli	doc_491521501656_item	2435989	et	4	main
maha	doc_491521501656_item	2435922	et	4	main
lõvi	doc_491521501656_item	2435924	et	4	main
peale	doc_491521501656_item	2435927	et	4	main
käimatoime	doc_491521501656_item	2435928	et	4	main
toote	doc_491521501656_item	2435932	et	4	main
on	doc_491521501656_item	2435934	et	4	main
olemust	doc_491521501656_item	2435943	et	3	main
määrsõna	doc_491521501656_item	2435950	et	4	main
seisid	doc_491521501656_item	2435952	et	4	main
tüdinult	doc_491521501656_item	2435953	et	4	main
väljakutsuvalt	doc_491521501656_item	2435961	et	4	main
pealetükkivalt	doc_491521501656_item	2435966	et	4	main
sõnad	doc_491521501656_item	2435970	et	4	main
õigesse	doc_491521501656_item	2435981	et	3	main
see	doc_491521501656_item	2435983	et	3	main
välja	doc_491521501656_item	2435987	et	4	main
ootamatu	doc_491521501656_item	2435990	et	4	main
koer	doc_491521501656_item	2435992	et	3	main
ootamatult	doc_491521501656_item	2435991	et	4	main
jookseb	doc_491521501656_item	2435993	et	3	main
lahtine	doc_491521501656_item	2435994	et	3	main
lahtiselt	doc_491521501656_item	2435995	et	4	main
ringi	doc_491521501656_item	2435996	et	4	main
see	doc_491521501656_item	2435997	et	3	main
juhtum	doc_491521501656_item	2435998	et	3	main
oli	doc_491521501656_item	2435999	et	3	main
lihtsalt	doc_491521501656_item	2436000	et	4	main
hirmus	doc_491521501656_item	2436001	et	4	main
hirmuv	doc_491521501656_item	2436002	et	4	main
on	doc_491521501656_item	2436003	et	4	main
piinlik	doc_491521501656_item	2436004	et	3	main
piinlikult	doc_491521501656_item	2436005	et	4	main
kui	doc_491521501656_item	2436006	et	3	main
inimesed	doc_491521501656_item	2436007	et	3	main
ei	doc_491521501656_item	2436008	et	4	main
hoia	doc_491521501656_item	2436009	et	4	main
asju	doc_491521501656_item	2436010	et	3	main
korras	doc_491521501656_item	2436011	et	4	main
jubedalt	doc_491521501656_item	2435986	et	4	main
külm	doc_491521501656_item	2435988	et	3	main
takistama	doc_491521501658_item	2436320	et	3	main
tuvastama	doc_491521501658_item	2436323	et	3	main
taipama	doc_491521501658_item	2436324	et	3	main
относиться	doc_491521501658_item	2436327	et	2	main
vaatama	doc_491521501658_item	2436360	et	3	main
võtke	doc_491521501658_item	2436361	et	3	main
kaasa	doc_491521501658_item	2436362	et	4	main
asjatundja	doc_491521501658_item	2436363	et	4	main
korterit	doc_491521501658_item	2436364	et	3	main
abi	doc_491521501658_item	2436380	et	4	main
4	doc_491521501658_item	2436382	et	2	main
препядствовать	doc_491521501658_item	2436322	et	2	main
peibutama	doc_491521501658_item	2436330	et	3	main
растягиваться	doc_491521501658_item	2436335	et	2	main
hallitama	doc_491521501658_item	2436336	et	3	main
lepingut	doc_491521501658_item	2436351	et	3	main
sõlmides	doc_491521501658_item	2436352	et	4	main
üle	doc_491521501658_item	2436365	et	3	main
3	doc_491521501658_item	2436370	et	2	main
suhtlete	doc_491521501658_item	2436372	et	3	main
abi	doc_491521501658_item	2436375	et	4	main
kuuetunnine	doc_491521501658_item	2436418	et	4	main
krooni	doc_491521501658_item	2436424	et	4	main
kahekümneruutmeetriline	doc_491521501658_item	2436428	et	4	main
ühesõnalised	doc_491521501658_item	2436431	et	4	main
sünonüümid	doc_491521501658_item	2436432	et	3	main
terveks	doc_491521501658_item	2436433	et	4	main
juurde	doc_491521501658_item	2436436	et	4	main
taga	doc_491521501658_item	2436439	et	4	main
jälitama	doc_491521501658_item	2436441	et	3	main
saama	doc_491521501658_item	2436443	et	4	main
mõistma	doc_491521501658_item	2436444	et	3	main
saadeti	doc_491521501658_item	2436452	et	3	main
pakkuti	doc_491521501658_item	2436456	et	4	main
olema	doc_491521501658_item	2436463	et	4	main
vi	doc_491521501658_item	2436465	et	4	main
tõlkige	doc_491521501658_item	2436466	et	3	main
товары	doc_491521501658_item	2436468	et	2	main
плохое	doc_491521501658_item	2436470	et	2	main
kvaliteeti	doc_491521501658_item	2436480	et	4	main
lähevad	doc_491521501658_item	2436483	et	3	main
вас	doc_491521501658_item	2436486	et	2	main
дома	doc_491521501658_item	2436489	et	2	main
õigus	doc_491521501658_item	2436513	et	4	main
maakler	doc_491521501658_item	2436528	et	3	main
korterit	doc_491521501658_item	2436535	et	3	main
saagile	doc_491521501658_item	2436540	et	3	main
käimatoime	doc_491521501658_item	2436542	et	4	main
tulema	doc_491521501658_item	2436543	et	4	main
ligi	doc_491521501658_item	2436544	et	3	main
hiilima	doc_491521501658_item	2436545	et	3	main
kohad	doc_491521501658_item	2436553	et	4	main
firma	doc_491521501658_item	2436556	et	4	main
viii	doc_491521501658_item	2436560	et	4	main
kirjutage	doc_491521501658_item	2436561	et	3	main
lõhnas	doc_491521501658_item	2436582	et	4	main
ix	doc_491521501658_item	2436590	et	4	main
jube	doc_491521501658_item	2436600	et	4	main
välja	doc_491521501658_item	2436601	et	4	main
külm	doc_491521501658_item	2436602	et	3	main
ringi	doc_491521501658_item	2436610	et	4	main
kontrolltöö	doc_491521501658_item	2436317	et	4	main
i	doc_491521501658_item	2436318	et	4	main
мешать	doc_491521501658_item	2436321	et	2	main
догадываться	doc_491521501658_item	2436325	et	2	main
umbusklik	doc_491521501658_item	2436328	et	3	main
выпендриваться	doc_491521501658_item	2436332	et	2	main
царапать	doc_491521501658_item	2436339	et	2	main
olge	doc_491521501658_item	2436353	et	3	main
tähelepanelik	doc_491521501658_item	2436354	et	4	main
2	doc_491521501658_item	2436355	et	2	main
kui	doc_491521501658_item	2436356	et	3	main
lähete	doc_491521501658_item	2436357	et	4	main
korterit	doc_491521501658_item	2436358	et	3	main
üle	doc_491521501658_item	2436359	et	3	main
kaasa	doc_491521501658_item	2436368	et	4	main
kui	doc_491521501658_item	2436371	et	3	main
ametnikega	doc_491521501658_item	2436373	et	3	main
liiget	doc_491521501658_item	2436420	et	3	main
ruutmeetrit	doc_491521501658_item	2436427	et	3	main
moodustage	doc_491521501658_item	2436430	et	3	main
paranema	doc_491521501658_item	2436435	et	3	main
ära	doc_491521501658_item	2436445	et	4	main
minema	doc_491521501658_item	2436446	et	3	main
loeti	doc_491521501658_item	2436454	et	3	main
laskma	doc_491521501658_item	2436459	et	3	main
ostma	doc_491521501658_item	2436461	et	3	main
ломаются	doc_491521501658_item	2436474	et	2	main
tooted	doc_491521501658_item	2436476	et	3	main
üsna	doc_491521501658_item	2436478	et	3	main
halba	doc_491521501658_item	2436479	et	4	main
изучить	doc_491521501658_item	2436491	et	2	main
on	doc_491521501658_item	2436494	et	4	main
kodus	doc_491521501658_item	2436496	et	4	main
рассрочку	doc_491521501658_item	2436508	et	2	main
on	doc_491521501658_item	2436511	et	4	main
maha	doc_491521501658_item	2436519	et	4	main
alla	doc_491521501658_item	2436520	et	3	main
seda	doc_491521501658_item	2436523	et	3	main
maha	doc_491521501658_item	2436536	et	4	main
toote	doc_491521501658_item	2436546	et	4	main
kasutusjuhendis	doc_491521501658_item	2436547	et	3	main
kehtivad	doc_491521501658_item	2436552	et	4	main
mainet	doc_491521501658_item	2436558	et	4	main
puänti	doc_491521501658_item	2436559	et	4	main
isuäratavalt	doc_491521501658_item	2436583	et	4	main
sõnad	doc_491521501658_item	2436584	et	4	main
ootamatu	doc_491521501658_item	2436604	et	4	main
see	doc_491521501658_item	2436611	et	3	main
oli	doc_491521501658_item	2436613	et	3	main
hirmus	doc_491521501658_item	2436615	et	4	main
hoia	doc_491521501658_item	2436623	et	4	main
takistama	doc_491521501659_item	2436629	et	3	main
peibutama	doc_491521501659_item	2436639	et	3	main
hallitama	doc_491521501659_item	2436644	et	3	main
царапать	doc_491521501659_item	2436647	et	2	main
ii	doc_491521501659_item	2436650	et	4	main
kasutage	doc_491521501659_item	2436651	et	3	main
asjatundja	doc_491521501659_item	2436671	et	4	main
suheldes	doc_491521501659_item	2436687	et	3	main
abi	doc_491521501659_item	2436689	et	4	main
maaklerist	doc_491521501659_item	2436690	et	3	main
ise	doc_491521501659_item	2436703	et	4	main
teete	doc_491521501659_item	2436707	et	3	main
remonti	doc_491521501659_item	2436709	et	4	main
kohtlema	doc_491521501658_item	2436326	et	3	main
рисоваться	doc_491521501658_item	2436331	et	2	main
venima	doc_491521501658_item	2436334	et	3	main
плесневеть	doc_491521501658_item	2436337	et	2	main
küünistama	doc_491521501658_item	2436338	et	3	main
заставлять	doc_491521501658_item	2436341	et	2	main
vaadates	doc_491521501658_item	2436366	et	3	main
maaklerist	doc_491521501658_item	2436381	et	3	main
kui	doc_491521501658_item	2436383	et	3	main
ootate	doc_491521501658_item	2436384	et	3	main
pakkumisi	doc_491521501658_item	2436385	et	4	main
olge	doc_491521501658_item	2436386	et	3	main
ka	doc_491521501658_item	2436387	et	3	main
aktiivne	doc_491521501658_item	2436389	et	3	main
ise	doc_491521501658_item	2436388	et	4	main
pakkumisi	doc_491521501658_item	2436390	et	4	main
oodates	doc_491521501658_item	2436391	et	3	main
olge	doc_491521501658_item	2436392	et	3	main
ka	doc_491521501658_item	2436393	et	3	main
ise	doc_491521501658_item	2436394	et	4	main
aktiivne	doc_491521501658_item	2436395	et	3	main
kui	doc_491521501658_item	2436397	et	3	main
teete	doc_491521501658_item	2436398	et	3	main
5	doc_491521501658_item	2436396	et	2	main
ise	doc_491521501658_item	2436399	et	4	main
remonti	doc_491521501658_item	2436400	et	4	main
saate	doc_491521501658_item	2436401	et	4	main
parima	doc_491521501658_item	2436402	et	4	main
tulemuse	doc_491521501658_item	2436403	et	3	main
ise	doc_491521501658_item	2436404	et	4	main
remonti	doc_491521501658_item	2436405	et	4	main
tehtes	doc_491521501658_item	2436406	et	3	main
saate	doc_491521501658_item	2436407	et	4	main
parima	doc_491521501658_item	2436408	et	4	main
tulemuse	doc_491521501658_item	2436409	et	3	main
iii	doc_491521501658_item	2436410	et	4	main
moodustage	doc_491521501658_item	2436411	et	3	main
liitsõnad	doc_491521501658_item	2436412	et	3	main
poolteist	doc_491521501658_item	2436413	et	4	main
meetrit	doc_491521501658_item	2436414	et	3	main
pooleteistmeetrine	doc_491521501658_item	2436415	et	4	main
kuus	doc_491521501658_item	2436416	et	4	main
tundi	doc_491521501658_item	2436417	et	4	main
1	doc_491521501658_item	2436345	et	2	main
kui	doc_491521501658_item	2436346	et	3	main
sõlmite	doc_491521501658_item	2436347	et	3	main
lepingut	doc_491521501658_item	2436348	et	3	main
olge	doc_491521501658_item	2436349	et	3	main
tähelepanelik	doc_491521501658_item	2436350	et	4	main
võtke	doc_491521501658_item	2436367	et	3	main
asjatundja	doc_491521501658_item	2436369	et	4	main
on	doc_491521501658_item	2436374	et	4	main
maaklerist	doc_491521501658_item	2436376	et	3	main
ametnikega	doc_491521501658_item	2436377	et	3	main
suheldes	doc_491521501658_item	2436378	et	3	main
on	doc_491521501658_item	2436379	et	4	main
viis	doc_491521501658_item	2436419	et	4	main
sajaviiekrooniline	doc_491521501658_item	2436425	et	4	main
panema	doc_491521501658_item	2436437	et	3	main
saatma	doc_491521501658_item	2436451	et	3	main
lasti	doc_491521501658_item	2436460	et	4	main
osteti	doc_491521501658_item	2436462	et	3	main
oleti	doc_491521501658_item	2436464	et	4	main
некоторые	doc_491521501658_item	2436467	et	2	main
имеют	doc_491521501658_item	2436469	et	2	main
качество	doc_491521501658_item	2436471	et	2	main
mõned	doc_491521501658_item	2436475	et	3	main
omavad	doc_491521501658_item	2436477	et	4	main
kiiresti	doc_491521501658_item	2436482	et	3	main
у	doc_491521501658_item	2436485	et	2	main
возможность	doc_491521501658_item	2436488	et	2	main
katalogi	doc_491521501658_item	2436498	et	4	main
läbi	doc_491521501658_item	2436499	et	4	main
uurida	doc_491521501658_item	2436500	et	3	main
клиенты	doc_491521501658_item	2436502	et	2	main
право	doc_491521501658_item	2436504	et	2	main
товар	doc_491521501658_item	2436506	et	2	main
tõmmake	doc_491521501658_item	2436518	et	3	main
sada	doc_491521501658_item	2436422	et	4	main
viis	doc_491521501658_item	2436423	et	4	main
iv	doc_491521501658_item	2436429	et	4	main
viieliikmeline	doc_491521501658_item	2436421	et	4	main
kakskümmend	doc_491521501658_item	2436426	et	4	main
lisama	doc_491521501658_item	2436438	et	3	main
aru	doc_491521501658_item	2436442	et	4	main
lahkuma	doc_491521501658_item	2436447	et	3	main
lugema	doc_491521501658_item	2436453	et	4	main
pakkuma	doc_491521501658_item	2436455	et	3	main
nõuati	doc_491521501658_item	2436458	et	3	main
и	doc_491521501658_item	2436472	et	2	main
katki	doc_491521501658_item	2436484	et	4	main
есть	doc_491521501658_item	2436487	et	2	main
спокойно	doc_491521501658_item	2436490	et	2	main
teil	doc_491521501658_item	2436493	et	4	main
võimalus	doc_491521501658_item	2436495	et	3	main
постоянные	doc_491521501658_item	2436501	et	2	main
имеют	doc_491521501658_item	2436503	et	2	main
покупать	doc_491521501658_item	2436505	et	2	main
в	doc_491521501658_item	2436507	et	2	main
vii	doc_491521501658_item	2436517	et	4	main
sõnad	doc_491521501658_item	2436522	et	4	main
et	doc_491521501658_item	2436534	et	3	main
lõvi	doc_491521501658_item	2436538	et	4	main
kahjustasid	doc_491521501658_item	2436555	et	4	main
lünka	doc_491521501658_item	2436562	et	4	main
pealetükkivalt	doc_491521501658_item	2436580	et	4	main
toit	doc_491521501658_item	2436581	et	3	main
tüdinult	doc_491521501658_item	2436586	et	4	main
pange	doc_491521501658_item	2436591	et	4	main
lahtine	doc_491521501658_item	2436608	et	3	main
saama	doc_491521501658_item	2436434	et	4	main
ajama	doc_491521501658_item	2436440	et	4	main
v	doc_491521501658_item	2436448	et	4	main
mida	doc_491521501658_item	2436449	et	4	main
tehti	doc_491521501658_item	2436450	et	3	main
nõudma	doc_491521501658_item	2436457	et	3	main
быстро	doc_491521501658_item	2436473	et	2	main
ja	doc_491521501658_item	2436481	et	3	main
каталог	doc_491521501658_item	2436492	et	2	main
rahulikult	doc_491521501658_item	2436497	et	4	main
püsivatel	doc_491521501658_item	2436509	et	4	main
klientidel	doc_491521501658_item	2436510	et	3	main
võimalus	doc_491521501658_item	2436512	et	3	main
osta	doc_491521501658_item	2436514	et	4	main
tooteid	doc_491521501658_item	2436515	et	4	main
järelmaksuga	doc_491521501658_item	2436516	et	3	main
valed	doc_491521501658_item	2436521	et	3	main
korteriühistu	doc_491521501658_item	2436527	et	4	main
lasi	doc_491521501658_item	2436529	et	4	main
läbiajas	doc_491521501658_item	2436530	et	3	main
korda	doc_491521501658_item	2436531	et	4	main
nägi	doc_491521501658_item	2436532	et	3	main
hakkas	doc_491521501658_item	2436539	et	3	main
peale	doc_491521501658_item	2436541	et	4	main
eksitavad	doc_491521501658_item	2436551	et	4	main
väljakutsuvalt	doc_491521501658_item	2436587	et	4	main
pealetükkivalt	doc_491521501658_item	2436588	et	4	main
sulgudes	doc_491521501658_item	2436592	et	4	main
tuli	doc_491521501658_item	2436603	et	4	main
lahtiselt	doc_491521501658_item	2436609	et	4	main
hirmus	doc_491521501658_item	2436616	et	4	main
piinlik	doc_491521501658_item	2436619	et	3	main
kui	doc_491521501658_item	2436620	et	3	main
inimesed	doc_491521501658_item	2436621	et	3	main
i	doc_491521501659_item	2436627	et	4	main
обнаружить	doc_491521501659_item	2436632	et	2	main
понять	doc_491521501659_item	2436634	et	2	main
kohtlema	doc_491521501659_item	2436635	et	3	main
недоверчивый	doc_491521501659_item	2436638	et	2	main
venima	doc_491521501659_item	2436642	et	3	main
плесневеть	doc_491521501659_item	2436645	et	2	main
заставлять	doc_491521501659_item	2436649	et	2	main
1	doc_491521501659_item	2436653	et	2	main
kui	doc_491521501659_item	2436654	et	3	main
võtke	doc_491521501659_item	2436669	et	3	main
olge	doc_491521501659_item	2436701	et	3	main
5	doc_491521501659_item	2436705	et	2	main
saate	doc_491521501659_item	2436716	et	4	main
parima	doc_491521501659_item	2436717	et	4	main
tulemuse	doc_491521501659_item	2436718	et	3	main
iii	doc_491521501659_item	2436719	et	4	main
viis	doc_491521501659_item	2436728	et	4	main
sada	doc_491521501659_item	2436731	et	4	main
viis	doc_491521501659_item	2436732	et	4	main
moodustage	doc_491521501659_item	2436740	et	3	main
terveks	doc_491521501659_item	2436743	et	4	main
ajama	doc_491521501659_item	2436750	et	4	main
kiusama	doc_491521501659_item	2436751	et	3	main
aru	doc_491521501659_item	2436752	et	4	main
saama	doc_491521501659_item	2436753	et	4	main
minema	doc_491521501659_item	2436757	et	3	main
kehva	doc_491521501659_item	2436789	et	4	main
дома	doc_491521501659_item	2436799	et	2	main
maja	doc_491521501658_item	2436524	et	4	main
kerkibkaasneb	doc_491521501658_item	2436525	et	4	main
haldab	doc_491521501658_item	2436526	et	3	main
vaeva	doc_491521501658_item	2436533	et	4	main
müüa	doc_491521501658_item	2436537	et	3	main
on	doc_491521501658_item	2436548	et	4	main
mõned	doc_491521501658_item	2436549	et	3	main
üleolevad	doc_491521501658_item	2436550	et	3	main
artiklid	doc_491521501658_item	2436554	et	3	main
olemust	doc_491521501658_item	2436557	et	3	main
sobiv	doc_491521501658_item	2436563	et	4	main
määrsõna	doc_491521501658_item	2436564	et	4	main
inimesed	doc_491521501658_item	2436565	et	3	main
seisid	doc_491521501658_item	2436566	et	4	main
tüdinult	doc_491521501658_item	2436567	et	4	main
järjekorras	doc_491521501658_item	2436568	et	3	main
ta	doc_491521501658_item	2436569	et	4	main
riietub	doc_491521501658_item	2436570	et	3	main
üsna	doc_491521501658_item	2436571	et	3	main
maitsetult	doc_491521501658_item	2436572	et	4	main
neiu	doc_491521501658_item	2436573	et	4	main
käitus	doc_491521501658_item	2436574	et	4	main
väljakutsuvalt	doc_491521501658_item	2436575	et	4	main
müüja	doc_491521501658_item	2436576	et	4	main
pakkus	doc_491521501658_item	2436577	et	3	main
oma	doc_491521501658_item	2436578	et	4	main
kaupa	doc_491521501658_item	2436579	et	4	main
isuäratavalt	doc_491521501658_item	2436585	et	4	main
maitsetult	doc_491521501658_item	2436589	et	4	main
olevad	doc_491521501658_item	2436593	et	4	main
sõnad	doc_491521501658_item	2436594	et	4	main
õigesse	doc_491521501658_item	2436595	et	3	main
vormi	doc_491521501658_item	2436596	et	4	main
see	doc_491521501658_item	2436597	et	3	main
näeb	doc_491521501658_item	2436598	et	3	main
jube	doc_491521501658_item	2436599	et	4	main
ootamatult	doc_491521501658_item	2436605	et	4	main
koer	doc_491521501658_item	2436606	et	3	main
jookseb	doc_491521501658_item	2436607	et	3	main
lihtsalt	doc_491521501658_item	2436614	et	4	main
piinlik	doc_491521501658_item	2436618	et	3	main
korras	doc_491521501658_item	2436625	et	4	main
välja	doc_491521501659_item	2436641	et	4	main
kaasa	doc_491521501659_item	2436670	et	4	main
ametnikega	doc_491521501659_item	2436686	et	3	main
pakkumise	doc_491521501659_item	2436699	et	4	main
oodates	doc_491521501659_item	2436700	et	3	main
ka	doc_491521501659_item	2436702	et	3	main
remonti	doc_491521501659_item	2436714	et	4	main
tehes	doc_491521501659_item	2436715	et	3	main
liitsõnad	doc_491521501659_item	2436721	et	3	main
poolteistmeetrine	doc_491521501659_item	2436724	et	4	main
kuus	doc_491521501659_item	2436725	et	4	main
liiget	doc_491521501659_item	2436729	et	3	main
sajaviie	doc_491521501659_item	2436734	et	4	main
kroonine	doc_491521501659_item	2436735	et	4	main
kakskümmend	doc_491521501659_item	2436736	et	4	main
ruutmeetrit	doc_491521501659_item	2436737	et	3	main
kahekümmeruutmeetrine	doc_491521501659_item	2436738	et	4	main
on	doc_491521501659_item	2436788	et	4	main
ja	doc_491521501659_item	2436791	et	3	main
у	doc_491521501659_item	2436795	et	2	main
каталог	doc_491521501659_item	2436802	et	2	main
järelmaksuga	doc_491521501659_item	2436823	et	3	main
maja	doc_491521501659_item	2436831	et	4	main
kerkibkaasneb	doc_491521501659_item	2436832	et	4	main
haldab	doc_491521501659_item	2436833	et	3	main
maha	doc_491521501659_item	2436843	et	4	main
on	doc_491521501659_item	2436855	et	4	main
mõned	doc_491521501659_item	2436856	et	3	main
üleolevad	doc_491521501659_item	2436857	et	3	main
eksitavad	doc_491521501659_item	2436858	et	4	main
kehtivad	doc_491521501659_item	2436859	et	4	main
firma	doc_491521501659_item	2436863	et	4	main
seisid	doc_491521501659_item	2436873	et	4	main
tüdinult	doc_491521501659_item	2436874	et	4	main
järjekorras	doc_491521501659_item	2436875	et	3	main
müüja	doc_491521501659_item	2436883	et	4	main
oma	doc_491521501659_item	2436885	et	4	main
kaupa	doc_491521501659_item	2436886	et	4	main
sõnad	doc_491521501659_item	2436891	et	4	main
isuäratavalt	doc_491521501659_item	2436892	et	4	main
pealetükkivalt	doc_491521501659_item	2436895	et	4	main
see	doc_491521501659_item	2436904	et	3	main
koer	doc_491521501659_item	2436913	et	3	main
jookseb	doc_491521501659_item	2436914	et	3	main
lihtsalt	doc_491521501659_item	2436921	et	4	main
hirmus	doc_491521501659_item	2436923	et	4	main
ei	doc_491521501659_item	2436929	et	4	main
asju	doc_491521501659_item	2436931	et	3	main
клеить	doc_491521501660_item	2436939	et	2	main
umbusklik	doc_491521501660_item	2436941	et	3	main
ii	doc_491521501660_item	2436949	et	4	main
kasutage	doc_491521501660_item	2436950	et	3	main
des-vormi	doc_491521501660_item	2436951	et	4	main
1	doc_491521501660_item	2436952	et	2	main
kui	doc_491521501660_item	2436953	et	3	main
sõlmite	doc_491521501660_item	2436954	et	3	main
lepingut	doc_491521501660_item	2436955	et	3	main
olge	doc_491521501660_item	2436956	et	3	main
tähelepanelik	doc_491521501660_item	2436957	et	4	main
kui	doc_491521501660_item	2436958	et	3	main
sõlmite	doc_491521501660_item	2436959	et	3	main
lepingut	doc_491521501660_item	2436960	et	3	main
olgedes	doc_491521501660_item	2436961	et	4	main
2	doc_491521501660_item	2436963	et	2	main
korterit	doc_491521501660_item	2436966	et	3	main
juhtum	doc_491521501658_item	2436612	et	3	main
on	doc_491521501658_item	2436617	et	4	main
asju	doc_491521501658_item	2436624	et	3	main
kontrolltöö	doc_491521501659_item	2436626	et	4	main
tõlkige	doc_491521501659_item	2436628	et	3	main
предотвратить	doc_491521501659_item	2436630	et	2	main
tuvastama	doc_491521501659_item	2436631	et	3	main
taipama	doc_491521501659_item	2436633	et	3	main
общаться	doc_491521501659_item	2436636	et	2	main
umbusklik	doc_491521501659_item	2436637	et	3	main
küünistama	doc_491521501659_item	2436646	et	3	main
aktiivne	doc_491521501659_item	2436704	et	3	main
ise	doc_491521501659_item	2436713	et	4	main
moodustage	doc_491521501659_item	2436720	et	3	main
poolteist	doc_491521501659_item	2436722	et	4	main
sünonüümid	doc_491521501659_item	2436742	et	3	main
saama	doc_491521501659_item	2436744	et	4	main
tervenema	doc_491521501659_item	2436745	et	3	main
juurde	doc_491521501659_item	2436746	et	4	main
panema	doc_491521501659_item	2436747	et	3	main
ära	doc_491521501659_item	2436756	et	4	main
v	doc_491521501659_item	2436760	et	4	main
tehti	doc_491521501659_item	2436762	et	3	main
lugema	doc_491521501659_item	2436765	et	4	main
loeti	doc_491521501659_item	2436766	et	3	main
pakkuma	doc_491521501659_item	2436767	et	3	main
pakkuti	doc_491521501659_item	2436768	et	4	main
nõudma	doc_491521501659_item	2436769	et	3	main
nõuti	doc_491521501659_item	2436770	et	3	main
laskma	doc_491521501659_item	2436771	et	3	main
lasti	doc_491521501659_item	2436772	et	4	main
ostma	doc_491521501659_item	2436773	et	3	main
osteti	doc_491521501659_item	2436774	et	3	main
ruttu	doc_491521501659_item	2436792	et	4	main
вас	doc_491521501659_item	2436796	et	2	main
спокойно	doc_491521501659_item	2436800	et	2	main
osta	doc_491521501659_item	2436821	et	4	main
korteriühisyu	doc_491521501659_item	2436834	et	4	main
maakler	doc_491521501659_item	2436835	et	3	main
lasi	doc_491521501659_item	2436836	et	4	main
läbiajas	doc_491521501659_item	2436837	et	3	main
lõvi	doc_491521501659_item	2436845	et	4	main
olemust	doc_491521501659_item	2436864	et	3	main
kirjutage	doc_491521501659_item	2436868	et	3	main
sobiv	doc_491521501659_item	2436870	et	4	main
ta	doc_491521501659_item	2436876	et	4	main
riietub	doc_491521501659_item	2436877	et	3	main
üsna	doc_491521501659_item	2436878	et	3	main
maitsetult	doc_491521501659_item	2436879	et	4	main
väljakutsuvalt	doc_491521501659_item	2436882	et	4	main
pakkus	doc_491521501659_item	2436884	et	3	main
sõnad	doc_491521501659_item	2436901	et	4	main
ootamatu	doc_491521501659_item	2436911	et	4	main
ootamatult	doc_491521501659_item	2436912	et	4	main
lahtine	doc_491521501659_item	2436916	et	3	main
see	doc_491521501659_item	2436918	et	3	main
piinlik	doc_491521501659_item	2436926	et	3	main
i	doc_491521501660_item	2436934	et	4	main
tõlkige	doc_491521501660_item	2436935	et	3	main
takistama	doc_491521501660_item	2436936	et	3	main
kohtlema	doc_491521501660_item	2436940	et	3	main
hallitama	doc_491521501660_item	2436945	et	3	main
рождатся	doc_491521501660_item	2436948	et	2	main
kui	doc_491521501660_item	2436964	et	3	main
asjatundja	doc_491521501660_item	2436971	et	4	main
kui	doc_491521501660_item	2436972	et	3	main
lähete	doc_491521501660_item	2436973	et	4	main
korterit	doc_491521501660_item	2436974	et	3	main
üle	doc_491521501660_item	2436975	et	3	main
vaatama	doc_491521501660_item	2436976	et	3	main
võtkedes	doc_491521501660_item	2436977	et	4	main
ise	doc_491521501660_item	2436999	et	4	main
kui	doc_491521501660_item	2437001	et	3	main
ei	doc_491521501658_item	2436622	et	4	main
привлекать	doc_491521501659_item	2436640	et	2	main
вытягивать	doc_491521501659_item	2436643	et	2	main
sundima	doc_491521501659_item	2436648	et	4	main
des-vormi	doc_491521501659_item	2436652	et	4	main
sõlmite	doc_491521501659_item	2436655	et	3	main
lepingut	doc_491521501659_item	2436656	et	3	main
olge	doc_491521501659_item	2436657	et	3	main
tähelepanelik	doc_491521501659_item	2436658	et	4	main
lepingu	doc_491521501659_item	2436659	et	3	main
sõlmides	doc_491521501659_item	2436660	et	4	main
olge	doc_491521501659_item	2436661	et	3	main
tähelepanelik	doc_491521501659_item	2436662	et	4	main
2	doc_491521501659_item	2436663	et	2	main
kui	doc_491521501659_item	2436664	et	3	main
lähete	doc_491521501659_item	2436665	et	4	main
korterit	doc_491521501659_item	2436666	et	3	main
üle	doc_491521501659_item	2436667	et	3	main
vaatama	doc_491521501659_item	2436668	et	3	main
korterit	doc_491521501659_item	2436672	et	3	main
üle	doc_491521501659_item	2436673	et	3	main
vaatama	doc_491521501659_item	2436674	et	3	main
minnes	doc_491521501659_item	2436675	et	3	main
võtke	doc_491521501659_item	2436676	et	3	main
kaasa	doc_491521501659_item	2436677	et	4	main
asjatundja	doc_491521501659_item	2436678	et	4	main
3	doc_491521501659_item	2436679	et	2	main
suhtlete	doc_491521501659_item	2436681	et	3	main
kui	doc_491521501659_item	2436680	et	3	main
ametnikega	doc_491521501659_item	2436682	et	3	main
on	doc_491521501659_item	2436683	et	4	main
abi	doc_491521501659_item	2436684	et	4	main
maaklerist	doc_491521501659_item	2436685	et	3	main
on	doc_491521501659_item	2436688	et	4	main
4	doc_491521501659_item	2436691	et	2	main
kui	doc_491521501659_item	2436692	et	3	main
ootate	doc_491521501659_item	2436693	et	3	main
pakkumisi	doc_491521501659_item	2436694	et	4	main
olge	doc_491521501659_item	2436695	et	3	main
ka	doc_491521501659_item	2436696	et	3	main
ise	doc_491521501659_item	2436697	et	4	main
aktiivne	doc_491521501659_item	2436698	et	3	main
kui	doc_491521501659_item	2436706	et	3	main
ise	doc_491521501659_item	2436708	et	4	main
saate	doc_491521501659_item	2436710	et	4	main
parima	doc_491521501659_item	2436711	et	4	main
tulemuse	doc_491521501659_item	2436712	et	3	main
meetrit	doc_491521501659_item	2436723	et	3	main
tundi	doc_491521501659_item	2436726	et	4	main
iv	doc_491521501659_item	2436739	et	4	main
ühesõnalised	doc_491521501659_item	2436741	et	4	main
taga	doc_491521501659_item	2436749	et	4	main
äraminek	doc_491521501659_item	2436758	et	3	main
lahkuma	doc_491521501659_item	2436759	et	3	main
saatma	doc_491521501659_item	2436763	et	3	main
saadeti	doc_491521501659_item	2436764	et	3	main
tõlkige	doc_491521501659_item	2436777	et	3	main
товары	doc_491521501659_item	2436779	et	2	main
плохое	doc_491521501659_item	2436781	et	2	main
и	doc_491521501659_item	2436783	et	2	main
ломаются	doc_491521501659_item	2436785	et	2	main
mõned	doc_491521501659_item	2436786	et	3	main
kaubad	doc_491521501659_item	2436787	et	3	main
kvaliteetiga	doc_491521501659_item	2436790	et	4	main
katki	doc_491521501659_item	2436794	et	4	main
возможность	doc_491521501659_item	2436798	et	2	main
kaubad	doc_491521501659_item	2436822	et	3	main
alla	doc_491521501659_item	2436827	et	3	main
sõnad	doc_491521501659_item	2436829	et	4	main
korda	doc_491521501659_item	2436838	et	4	main
nägi	doc_491521501659_item	2436839	et	3	main
vaeva	doc_491521501659_item	2436840	et	4	main
et	doc_491521501659_item	2436841	et	3	main
korterit	doc_491521501659_item	2436842	et	3	main
hakkas	doc_491521501659_item	2436846	et	3	main
toit	doc_491521501659_item	2436888	et	3	main
tüdinult	doc_491521501659_item	2436893	et	4	main
vormi	doc_491521501659_item	2436903	et	4	main
jube	doc_491521501659_item	2436906	et	4	main
lahtine	doc_491521501659_item	2436915	et	3	main
piinlik	doc_491521501659_item	2436925	et	3	main
inimesed	doc_491521501659_item	2436928	et	3	main
korras	doc_491521501659_item	2436932	et	4	main
kontrolltöö	doc_491521501660_item	2436933	et	4	main
taipama	doc_491521501660_item	2436938	et	3	main
välja	doc_491521501660_item	2436943	et	4	main
sundima	doc_491521501660_item	2436947	et	4	main
tähelepanelik	doc_491521501660_item	2436962	et	4	main
võtke	doc_491521501660_item	2436969	et	3	main
pakkumisi	doc_491521501660_item	2436996	et	4	main
kui	doc_491521501660_item	2437009	et	3	main
saate	doc_491521501660_item	2437013	et	4	main
parima	doc_491521501660_item	2437014	et	4	main
tulemuse	doc_491521501660_item	2437022	et	3	main
moodustage	doc_491521501660_item	2437024	et	3	main
liitsõnad	doc_491521501660_item	2437025	et	3	main
viis	doc_491521501660_item	2437030	et	4	main
juurde	doc_491521501660_item	2437043	et	4	main
taga	doc_491521501660_item	2437045	et	4	main
ajama	doc_491521501660_item	2437046	et	4	main
aru	doc_491521501660_item	2437047	et	4	main
v	doc_491521501660_item	2437051	et	4	main
mida	doc_491521501660_item	2437052	et	4	main
saatis	doc_491521501660_item	2437055	et	3	main
lugema	doc_491521501660_item	2437056	et	4	main
looedes	doc_491521501660_item	2437057	et	3	main
pakkuma	doc_491521501660_item	2437058	et	3	main
имеют	doc_491521501660_item	2437072	et	2	main
есть	doc_491521501660_item	2437081	et	2	main
teil	doc_491521501660_item	2437087	et	4	main
товар	doc_491521501660_item	2437094	et	2	main
tõmmake	doc_491521501660_item	2437102	et	3	main
hiilima	doc_491521501660_item	2437128	et	3	main
kohad	doc_491521501660_item	2437135	et	4	main
kuuetunnine	doc_491521501659_item	2436727	et	4	main
viieliikmene	doc_491521501659_item	2436730	et	4	main
krooni	doc_491521501659_item	2436733	et	4	main
liisama	doc_491521501659_item	2436748	et	4	main
arusaamine	doc_491521501659_item	2436754	et	4	main
taipama	doc_491521501659_item	2436755	et	3	main
mida	doc_491521501659_item	2436761	et	4	main
olema	doc_491521501659_item	2436775	et	4	main
vi	doc_491521501659_item	2436776	et	4	main
некоторые	doc_491521501659_item	2436778	et	2	main
имеют	doc_491521501659_item	2436780	et	2	main
качество	doc_491521501659_item	2436782	et	2	main
быстро	doc_491521501659_item	2436784	et	2	main
lähevad	doc_491521501659_item	2436793	et	3	main
есть	doc_491521501659_item	2436797	et	2	main
изучить	doc_491521501659_item	2436801	et	2	main
on	doc_491521501659_item	2436804	et	4	main
võimalus	doc_491521501659_item	2436805	et	3	main
rahulikult	doc_491521501659_item	2436806	et	4	main
teil	doc_491521501659_item	2436803	et	4	main
kodus	doc_491521501659_item	2436807	et	4	main
kataloogi	doc_491521501659_item	2436808	et	4	main
uurida	doc_491521501659_item	2436809	et	3	main
постоянные	doc_491521501659_item	2436810	et	2	main
имеют	doc_491521501659_item	2436812	et	2	main
клиенты	doc_491521501659_item	2436811	et	2	main
право	doc_491521501659_item	2436813	et	2	main
покупать	doc_491521501659_item	2436814	et	2	main
товар	doc_491521501659_item	2436815	et	2	main
в	doc_491521501659_item	2436816	et	2	main
рассрочку	doc_491521501659_item	2436817	et	2	main
püsiklientidel	doc_491521501659_item	2436818	et	3	main
on	doc_491521501659_item	2436819	et	4	main
õigus	doc_491521501659_item	2436820	et	4	main
vii	doc_491521501659_item	2436824	et	4	main
valed	doc_491521501659_item	2436828	et	3	main
seda	doc_491521501659_item	2436830	et	3	main
saagile	doc_491521501659_item	2436847	et	3	main
peale	doc_491521501659_item	2436848	et	4	main
tulema	doc_491521501659_item	2436850	et	4	main
ligi	doc_491521501659_item	2436851	et	3	main
mainet	doc_491521501659_item	2436865	et	4	main
viii	doc_491521501659_item	2436867	et	4	main
käitus	doc_491521501659_item	2436881	et	4	main
isuäratavalt	doc_491521501659_item	2436890	et	4	main
maitsetult	doc_491521501659_item	2436896	et	4	main
pange	doc_491521501659_item	2436898	et	4	main
õigesse	doc_491521501659_item	2436902	et	3	main
näeb	doc_491521501659_item	2436905	et	3	main
tõmmake	doc_491521501659_item	2436825	et	3	main
maha	doc_491521501659_item	2436826	et	4	main
müüa	doc_491521501659_item	2436844	et	3	main
käimatoime	doc_491521501659_item	2436849	et	4	main
hiilima	doc_491521501659_item	2436852	et	3	main
toote	doc_491521501659_item	2436853	et	4	main
kasutusjuhendis	doc_491521501659_item	2436854	et	3	main
kohad	doc_491521501659_item	2436860	et	4	main
artiklid	doc_491521501659_item	2436861	et	3	main
kahjustasid	doc_491521501659_item	2436862	et	4	main
puänti	doc_491521501659_item	2436866	et	4	main
lünka	doc_491521501659_item	2436869	et	4	main
määrsõna	doc_491521501659_item	2436871	et	4	main
inimesed	doc_491521501659_item	2436872	et	3	main
neiu	doc_491521501659_item	2436880	et	4	main
pealetükkivalt	doc_491521501659_item	2436887	et	4	main
lõhnas	doc_491521501659_item	2436889	et	4	main
väljakutsuvalt	doc_491521501659_item	2436894	et	4	main
ix	doc_491521501659_item	2436897	et	4	main
sulgudes	doc_491521501659_item	2436899	et	4	main
olevad	doc_491521501659_item	2436900	et	4	main
jube	doc_491521501659_item	2436907	et	4	main
välja	doc_491521501659_item	2436908	et	4	main
külm	doc_491521501659_item	2436909	et	3	main
tuli	doc_491521501659_item	2436910	et	4	main
ringi	doc_491521501659_item	2436917	et	4	main
juhtum	doc_491521501659_item	2436919	et	3	main
oli	doc_491521501659_item	2436920	et	3	main
on	doc_491521501659_item	2436924	et	4	main
hoia	doc_491521501659_item	2436930	et	4	main
peibutama	doc_491521501660_item	2436942	et	3	main
küünistama	doc_491521501660_item	2436946	et	3	main
lähete	doc_491521501660_item	2436965	et	4	main
vaatama	doc_491521501660_item	2436968	et	3	main
kaasa	doc_491521501660_item	2436978	et	4	main
suhtlete	doc_491521501660_item	2436982	et	3	main
abi	doc_491521501660_item	2436985	et	4	main
pakkumisi	doc_491521501660_item	2437003	et	4	main
ise	doc_491521501660_item	2437011	et	4	main
terveks	doc_491521501660_item	2437041	et	4	main
saama	doc_491521501660_item	2437048	et	4	main
ostma	doc_491521501660_item	2437064	et	3	main
некоторые	doc_491521501660_item	2437070	et	2	main
качество	doc_491521501660_item	2437074	et	2	main
возможность	doc_491521501660_item	2437082	et	2	main
каталог	doc_491521501660_item	2437086	et	2	main
постоянные	doc_491521501660_item	2437089	et	2	main
имеют	doc_491521501660_item	2437091	et	2	main
покупать	doc_491521501660_item	2437093	et	2	main
рассрочку	doc_491521501660_item	2437096	et	2	main
kaupa	doc_491521501660_item	2437100	et	4	main
tulemaligi	doc_491521501660_item	2437127	et	4	main
kaupa	doc_491521501660_item	2437158	et	4	main
toit	doc_491521501660_item	2437159	et	3	main
lõhnas	doc_491521501660_item	2437160	et	4	main
väljakutsuvalt	doc_491521501660_item	2437164	et	4	main
pealetükkivalt	doc_491521501660_item	2437165	et	4	main
pange	doc_491521501660_item	2437168	et	4	main
olevad	doc_491521501660_item	2437170	et	4	main
ootamatu	doc_491521501660_item	2437180	et	4	main
koer	doc_491521501660_item	2437181	et	3	main
ringi	doc_491521501660_item	2437184	et	4	main
see	doc_491521501660_item	2437185	et	3	main
hirmus	doc_491521501660_item	2437189	et	4	main
piinlik	doc_491521501660_item	2437191	et	3	main
kui	doc_491521501660_item	2437192	et	3	main
tõlkige	doc_491521501661_item	2437200	et	3	main
takistama	doc_491521501661_item	2437201	et	3	main
taipama	doc_491521501661_item	2437204	et	3	main
peibutama	doc_491521501661_item	2437210	et	3	main
küünistama	doc_491521501661_item	2437216	et	3	main
des-vormi	doc_491521501661_item	2437221	et	4	main
lepingute	doc_491521501661_item	2437228	et	3	main
ametnikega	doc_491521501661_item	2437249	et	3	main
abi	doc_491521501661_item	2437256	et	4	main
maaklerist	doc_491521501661_item	2437257	et	3	main
4	doc_491521501661_item	2437258	et	2	main
saate	doc_491521501661_item	2437277	et	4	main
parima	doc_491521501661_item	2437278	et	4	main
hirmus	doc_491521501659_item	2436922	et	4	main
kui	doc_491521501659_item	2436927	et	3	main
tuvastama	doc_491521501660_item	2436937	et	3	main
venima	doc_491521501660_item	2436944	et	3	main
üle	doc_491521501660_item	2436967	et	3	main
kui	doc_491521501660_item	2436981	et	3	main
maaklerist	doc_491521501660_item	2436986	et	3	main
kui	doc_491521501660_item	2436987	et	3	main
suhtlete	doc_491521501660_item	2436988	et	3	main
ametnikega	doc_491521501660_item	2436989	et	3	main
olge	doc_491521501660_item	2436997	et	3	main
aktiivne	doc_491521501660_item	2437000	et	3	main
ootate	doc_491521501660_item	2437002	et	3	main
olgedes	doc_491521501660_item	2437004	et	4	main
ka	doc_491521501660_item	2437005	et	3	main
ise	doc_491521501660_item	2437006	et	4	main
aktiivne	doc_491521501660_item	2437007	et	3	main
5	doc_491521501660_item	2437008	et	2	main
tulemuse	doc_491521501660_item	2437015	et	3	main
kui	doc_491521501660_item	2437016	et	3	main
remonti	doc_491521501660_item	2437012	et	4	main
teete	doc_491521501660_item	2437017	et	3	main
ise	doc_491521501660_item	2437018	et	4	main
remoni	doc_491521501660_item	2437019	et	4	main
saades	doc_491521501660_item	2437020	et	3	main
tundi	doc_491521501660_item	2437029	et	4	main
viis	doc_491521501660_item	2437033	et	4	main
kakskümmend	doc_491521501660_item	2437035	et	4	main
ruutmeetrit	doc_491521501660_item	2437036	et	3	main
iv	doc_491521501660_item	2437037	et	4	main
moodustage	doc_491521501660_item	2437038	et	3	main
ühesõnalised	doc_491521501660_item	2437039	et	4	main
pakkumis	doc_491521501660_item	2437059	et	4	main
nõudma	doc_491521501660_item	2437060	et	3	main
nõudis	doc_491521501660_item	2437061	et	3	main
laskma	doc_491521501660_item	2437062	et	3	main
laskes	doc_491521501660_item	2437063	et	3	main
товары	doc_491521501660_item	2437071	et	2	main
быстро	doc_491521501660_item	2437076	et	2	main
вас	doc_491521501660_item	2437080	et	2	main
изучить	doc_491521501660_item	2437085	et	2	main
on	doc_491521501660_item	2437088	et	4	main
клиенты	doc_491521501660_item	2437090	et	2	main
право	doc_491521501660_item	2437092	et	2	main
в	doc_491521501660_item	2437095	et	2	main
kliendid	doc_491521501660_item	2437097	et	3	main
on	doc_491521501660_item	2437098	et	4	main
maha	doc_491521501660_item	2437103	et	4	main
sõnad	doc_491521501660_item	2437106	et	4	main
seda	doc_491521501660_item	2437107	et	3	main
maja	doc_491521501660_item	2437108	et	4	main
kaasa	doc_491521501660_item	2436970	et	4	main
asjatundja	doc_491521501660_item	2436979	et	4	main
3	doc_491521501660_item	2436980	et	2	main
ametnikega	doc_491521501660_item	2436983	et	3	main
on	doc_491521501660_item	2436984	et	4	main
oledes	doc_491521501660_item	2436990	et	4	main
abi	doc_491521501660_item	2436991	et	4	main
maaklerist	doc_491521501660_item	2436992	et	3	main
4	doc_491521501660_item	2436993	et	2	main
kui	doc_491521501660_item	2436994	et	3	main
ootate	doc_491521501660_item	2436995	et	3	main
ka	doc_491521501660_item	2436998	et	3	main
teete	doc_491521501660_item	2437010	et	3	main
parima	doc_491521501660_item	2437021	et	4	main
iii	doc_491521501660_item	2437023	et	4	main
poolteist	doc_491521501660_item	2437026	et	4	main
meetrit	doc_491521501660_item	2437027	et	3	main
kuus	doc_491521501660_item	2437028	et	4	main
sada	doc_491521501660_item	2437032	et	4	main
krooni	doc_491521501660_item	2437034	et	4	main
saama	doc_491521501660_item	2437042	et	4	main
tehti	doc_491521501660_item	2437053	et	3	main
saatma	doc_491521501660_item	2437054	et	3	main
olema	doc_491521501660_item	2437066	et	4	main
olis	doc_491521501660_item	2437067	et	4	main
tõlkige	doc_491521501660_item	2437069	et	3	main
плохое	doc_491521501660_item	2437073	et	2	main
ломаются	doc_491521501660_item	2437077	et	2	main
у	doc_491521501660_item	2437079	et	2	main
спокойно	doc_491521501660_item	2437084	et	2	main
või	doc_491521501660_item	2437099	et	4	main
hakkas	doc_491521501660_item	2437122	et	3	main
käima	doc_491521501660_item	2437125	et	4	main
toime	doc_491521501660_item	2437126	et	4	main
kehtivad	doc_491521501660_item	2437134	et	4	main
määrsõna	doc_491521501660_item	2437145	et	4	main
korglusse	doc_491521501660_item	2437154	et	4	main
müüja	doc_491521501660_item	2437155	et	4	main
tüdinult	doc_491521501660_item	2437163	et	4	main
sulgudes	doc_491521501660_item	2437169	et	4	main
hoia	doc_491521501660_item	2437195	et	4	main
asju	doc_491521501660_item	2437196	et	3	main
tuvastama	doc_491521501661_item	2437203	et	3	main
liiget	doc_491521501660_item	2437031	et	3	main
sünonüümid	doc_491521501660_item	2437040	et	3	main
panema	doc_491521501660_item	2437044	et	3	main
ära	doc_491521501660_item	2437049	et	4	main
minema	doc_491521501660_item	2437050	et	3	main
ostas	doc_491521501660_item	2437065	et	4	main
vi	doc_491521501660_item	2437068	et	4	main
и	doc_491521501660_item	2437075	et	2	main
samuti	doc_491521501660_item	2437078	et	3	main
дома	doc_491521501660_item	2437083	et	2	main
vii	doc_491521501660_item	2437101	et	4	main
alla	doc_491521501660_item	2437104	et	3	main
valed	doc_491521501660_item	2437105	et	3	main
kerkibkaasnebhaldab	doc_491521501660_item	2437109	et	4	main
korteriühistu	doc_491521501660_item	2437110	et	4	main
maakler	doc_491521501660_item	2437111	et	3	main
lasi	doc_491521501660_item	2437112	et	4	main
läbiajas	doc_491521501660_item	2437113	et	3	main
korda	doc_491521501660_item	2437114	et	4	main
nägi	doc_491521501660_item	2437115	et	3	main
vaeva	doc_491521501660_item	2437116	et	4	main
et	doc_491521501660_item	2437117	et	3	main
korterit	doc_491521501660_item	2437118	et	3	main
maha	doc_491521501660_item	2437119	et	4	main
müüa	doc_491521501660_item	2437120	et	3	main
lõvi	doc_491521501660_item	2437121	et	4	main
peale	doc_491521501660_item	2437124	et	4	main
mõned	doc_491521501660_item	2437132	et	3	main
üleolevadeksitavad	doc_491521501660_item	2437133	et	4	main
inimesed	doc_491521501660_item	2437146	et	3	main
seisid	doc_491521501660_item	2437147	et	4	main
järjekorras	doc_491521501660_item	2437148	et	3	main
ta	doc_491521501660_item	2437149	et	4	main
riietub	doc_491521501660_item	2437150	et	3	main
üsna	doc_491521501660_item	2437151	et	3	main
sõnad	doc_491521501660_item	2437161	et	4	main
maitsetult	doc_491521501660_item	2437166	et	4	main
välja	doc_491521501660_item	2437177	et	4	main
külm	doc_491521501660_item	2437178	et	3	main
tuli	doc_491521501660_item	2437179	et	4	main
oli	doc_491521501660_item	2437187	et	3	main
kontrolltöö	doc_491521501661_item	2437198	et	4	main
сомневаться	doc_491521501661_item	2437207	et	2	main
hallitama	doc_491521501661_item	2437214	et	3	main
lepingut	doc_491521501661_item	2437225	et	3	main
sõlmudes	doc_491521501661_item	2437229	et	3	main
tähelepanelik	doc_491521501661_item	2437231	et	4	main
kaasa	doc_491521501661_item	2437239	et	4	main
asjatundja	doc_491521501661_item	2437240	et	4	main
korterite	doc_491521501661_item	2437241	et	3	main
vaadates	doc_491521501661_item	2437242	et	3	main
võtke	doc_491521501661_item	2437243	et	3	main
kaasa	doc_491521501661_item	2437244	et	4	main
asjatundja	doc_491521501661_item	2437245	et	4	main
iii	doc_491521501661_item	2437286	et	4	main
liitsõnad	doc_491521501661_item	2437288	et	3	main
tundi	doc_491521501661_item	2437292	et	4	main
kakskümmend	doc_491521501661_item	2437298	et	4	main
iv	doc_491521501661_item	2437300	et	4	main
moodustage	doc_491521501661_item	2437301	et	3	main
ajama	doc_491521501661_item	2437309	et	4	main
mida	doc_491521501661_item	2437317	et	4	main
saagile	doc_491521501660_item	2437123	et	3	main
toote	doc_491521501660_item	2437129	et	4	main
kasutusjuhendis	doc_491521501660_item	2437130	et	3	main
on	doc_491521501660_item	2437131	et	4	main
firma	doc_491521501660_item	2437138	et	4	main
artiklid	doc_491521501660_item	2437136	et	3	main
kahjustasid	doc_491521501660_item	2437137	et	4	main
lünka	doc_491521501660_item	2437143	et	4	main
sobiv	doc_491521501660_item	2437144	et	4	main
neiu	doc_491521501660_item	2437152	et	4	main
isuäratavalt	doc_491521501660_item	2437162	et	4	main
näeb	doc_491521501660_item	2437175	et	3	main
jube	doc_491521501660_item	2437176	et	4	main
lihtsalt	doc_491521501660_item	2437188	et	4	main
on	doc_491521501660_item	2437190	et	4	main
inimesed	doc_491521501660_item	2437193	et	3	main
i	doc_491521501661_item	2437199	et	4	main
возникать	doc_491521501661_item	2437202	et	2	main
убивать	doc_491521501661_item	2437205	et	2	main
невероятно	doc_491521501661_item	2437209	et	2	main
välja	doc_491521501661_item	2437212	et	4	main
сереть	doc_491521501661_item	2437215	et	2	main
sundima	doc_491521501661_item	2437217	et	4	main
kasutage	doc_491521501661_item	2437220	et	3	main
sõlmite	doc_491521501661_item	2437224	et	3	main
olge	doc_491521501661_item	2437226	et	3	main
olge	doc_491521501661_item	2437230	et	3	main
2	doc_491521501661_item	2437232	et	2	main
kui	doc_491521501661_item	2437233	et	3	main
suhtlete	doc_491521501661_item	2437248	et	3	main
on	doc_491521501661_item	2437250	et	4	main
maaklerist	doc_491521501661_item	2437252	et	3	main
ametnikega	doc_491521501661_item	2437253	et	3	main
suheldes	doc_491521501661_item	2437254	et	3	main
on	doc_491521501661_item	2437255	et	4	main
moodustage	doc_491521501661_item	2437287	et	3	main
kuus	doc_491521501661_item	2437291	et	4	main
viis	doc_491521501661_item	2437293	et	4	main
sada	doc_491521501661_item	2437295	et	4	main
viis	doc_491521501661_item	2437296	et	4	main
ühesõnalised	doc_491521501661_item	2437302	et	4	main
sünonüümid	doc_491521501661_item	2437303	et	3	main
terveks	doc_491521501661_item	2437304	et	4	main
taga	doc_491521501661_item	2437308	et	4	main
v	doc_491521501661_item	2437316	et	4	main
saati	doc_491521501661_item	2437320	et	3	main
lugeti	doc_491521501661_item	2437322	et	4	main
laskma	doc_491521501661_item	2437327	et	3	main
mõned	doc_491521501661_item	2437343	et	3	main
halb	doc_491521501661_item	2437346	et	3	main
saavad	doc_491521501661_item	2437349	et	4	main
у	doc_491521501661_item	2437351	et	2	main
есть	doc_491521501661_item	2437353	et	2	main
teil	doc_491521501661_item	2437359	et	4	main
kudus	doc_491521501661_item	2437362	et	4	main
rahulikult	doc_491521501661_item	2437363	et	4	main
kataloogiga	doc_491521501661_item	2437364	et	3	main
tutvustama	doc_491521501661_item	2437365	et	3	main
постоянные	doc_491521501661_item	2437366	et	2	main
клиенты	doc_491521501661_item	2437367	et	2	main
kliendil	doc_491521501661_item	2437374	et	3	main
seda	doc_491521501661_item	2437385	et	3	main
nägi	doc_491521501661_item	2437394	et	3	main
inimesed	doc_491521501661_item	2437426	et	3	main
järjekorras	doc_491521501661_item	2437429	et	3	main
riietub	doc_491521501661_item	2437431	et	3	main
väljakutsuvalt	doc_491521501661_item	2437436	et	4	main
lõhnas	doc_491521501661_item	2437443	et	4	main
isuäratavalt	doc_491521501661_item	2437446	et	4	main
maitsetult	doc_491521501661_item	2437450	et	4	main
ix	doc_491521501661_item	2437451	et	4	main
sõnad	doc_491521501661_item	2437455	et	4	main
see	doc_491521501661_item	2437458	et	3	main
ootamatu	doc_491521501661_item	2437465	et	4	main
ootamatult	doc_491521501661_item	2437466	et	4	main
juhtum	doc_491521501661_item	2437473	et	3	main
lihtsalt	doc_491521501661_item	2437475	et	4	main
on	doc_491521501661_item	2437478	et	4	main
piinlik	doc_491521501661_item	2437479	et	3	main
piinlik	doc_491521501661_item	2437480	et	3	main
kui	doc_491521501661_item	2437481	et	3	main
inimesed	doc_491521501661_item	2437482	et	3	main
kontrolltöö	doc_491521501662_item	2437487	et	4	main
taipama	doc_491521501662_item	2437492	et	3	main
недоверчивый	doc_491521501662_item	2437496	et	2	main
olemust	doc_491521501660_item	2437139	et	3	main
mainetpuänti	doc_491521501660_item	2437140	et	4	main
viii	doc_491521501660_item	2437141	et	4	main
kirjutage	doc_491521501660_item	2437142	et	3	main
käitus	doc_491521501660_item	2437153	et	4	main
pakkus	doc_491521501660_item	2437156	et	3	main
oma	doc_491521501660_item	2437157	et	4	main
ix	doc_491521501660_item	2437167	et	4	main
sõnad	doc_491521501660_item	2437171	et	4	main
õigesse	doc_491521501660_item	2437172	et	3	main
vormi	doc_491521501660_item	2437173	et	4	main
see	doc_491521501660_item	2437174	et	3	main
jookseb	doc_491521501660_item	2437182	et	3	main
lahtine	doc_491521501660_item	2437183	et	3	main
juhtum	doc_491521501660_item	2437186	et	3	main
ei	doc_491521501660_item	2437194	et	4	main
korras	doc_491521501660_item	2437197	et	4	main
kohtlema	doc_491521501661_item	2437206	et	3	main
umbusklik	doc_491521501661_item	2437208	et	3	main
выбивать	doc_491521501661_item	2437211	et	2	main
venima	doc_491521501661_item	2437213	et	3	main
мочь	doc_491521501661_item	2437218	et	2	main
ii	doc_491521501661_item	2437219	et	4	main
kui	doc_491521501661_item	2437223	et	3	main
tähelepanelik	doc_491521501661_item	2437227	et	4	main
lähete	doc_491521501661_item	2437234	et	4	main
korterit	doc_491521501661_item	2437235	et	3	main
üle	doc_491521501661_item	2437236	et	3	main
vaatama	doc_491521501661_item	2437237	et	3	main
võtke	doc_491521501661_item	2437238	et	3	main
kui	doc_491521501661_item	2437247	et	3	main
remonti	doc_491521501661_item	2437280	et	4	main
ise	doc_491521501661_item	2437281	et	4	main
tehades	doc_491521501661_item	2437282	et	4	main
liiget	doc_491521501661_item	2437294	et	3	main
ruutmeetrit	doc_491521501661_item	2437299	et	3	main
panema	doc_491521501661_item	2437307	et	3	main
saama	doc_491521501661_item	2437311	et	4	main
lahtima	doc_491521501661_item	2437315	et	4	main
saatma	doc_491521501661_item	2437319	et	3	main
lugema	doc_491521501661_item	2437321	et	4	main
pakkuma	doc_491521501661_item	2437323	et	3	main
pakkuti	doc_491521501661_item	2437324	et	4	main
nõudma	doc_491521501661_item	2437325	et	3	main
olema	doc_491521501661_item	2437331	et	4	main
ollati	doc_491521501661_item	2437332	et	4	main
ломаются	doc_491521501661_item	2437342	et	2	main
kaubad	doc_491521501661_item	2437344	et	3	main
kiiresti	doc_491521501661_item	2437348	et	3	main
katki	doc_491521501661_item	2437350	et	4	main
вас	doc_491521501661_item	2437352	et	2	main
изучить	doc_491521501661_item	2437357	et	2	main
võimalus	doc_491521501661_item	2437361	et	3	main
товар	doc_491521501661_item	2437371	et	2	main
рассрочку	doc_491521501661_item	2437373	et	2	main
maha	doc_491521501661_item	2437381	et	4	main
maja	doc_491521501661_item	2437386	et	4	main
lasi	doc_491521501661_item	2437391	et	4	main
et	doc_491521501661_item	2437396	et	3	main
1	doc_491521501661_item	2437222	et	2	main
3	doc_491521501661_item	2437246	et	2	main
abi	doc_491521501661_item	2437251	et	4	main
kui	doc_491521501661_item	2437259	et	3	main
ootate	doc_491521501661_item	2437260	et	3	main
pakkumisi	doc_491521501661_item	2437261	et	4	main
olge	doc_491521501661_item	2437262	et	3	main
ka	doc_491521501661_item	2437263	et	3	main
ise	doc_491521501661_item	2437264	et	4	main
aktiivne	doc_491521501661_item	2437265	et	3	main
pakkumisi	doc_491521501661_item	2437266	et	4	main
ootades	doc_491521501661_item	2437267	et	4	main
olge	doc_491521501661_item	2437268	et	3	main
ka	doc_491521501661_item	2437269	et	3	main
ise	doc_491521501661_item	2437270	et	4	main
aktiivne	doc_491521501661_item	2437271	et	3	main
5	doc_491521501661_item	2437272	et	2	main
kui	doc_491521501661_item	2437273	et	3	main
teete	doc_491521501661_item	2437274	et	3	main
ise	doc_491521501661_item	2437275	et	4	main
remonti	doc_491521501661_item	2437276	et	4	main
saate	doc_491521501661_item	2437283	et	4	main
poolteist	doc_491521501661_item	2437289	et	4	main
krooni	doc_491521501661_item	2437297	et	4	main
saama	doc_491521501661_item	2437305	et	4	main
ära	doc_491521501661_item	2437313	et	4	main
minema	doc_491521501661_item	2437314	et	3	main
osti	doc_491521501661_item	2437330	et	4	main
vi	doc_491521501661_item	2437333	et	4	main
tõlkige	doc_491521501661_item	2437334	et	3	main
некоторые	doc_491521501661_item	2437335	et	2	main
товары	doc_491521501661_item	2437336	et	2	main
имеют	doc_491521501661_item	2437337	et	2	main
плохое	doc_491521501661_item	2437338	et	2	main
качество	doc_491521501661_item	2437339	et	2	main
и	doc_491521501661_item	2437340	et	2	main
on	doc_491521501661_item	2437345	et	4	main
ja	doc_491521501661_item	2437347	et	3	main
спокойно	doc_491521501661_item	2437356	et	2	main
каталог	doc_491521501661_item	2437358	et	2	main
on	doc_491521501661_item	2437360	et	4	main
покупать	doc_491521501661_item	2437370	et	2	main
on	doc_491521501661_item	2437375	et	4	main
võimalus	doc_491521501661_item	2437376	et	3	main
kauba	doc_491521501661_item	2437378	et	3	main
sõnad	doc_491521501661_item	2437384	et	4	main
korteriühistu	doc_491521501661_item	2437389	et	4	main
korda	doc_491521501661_item	2437393	et	4	main
maha	doc_491521501661_item	2437398	et	4	main
tulemaligi	doc_491521501661_item	2437406	et	4	main
hiilima	doc_491521501661_item	2437407	et	3	main
määrsõna	doc_491521501661_item	2437425	et	4	main
pealetükkivalt	doc_491521501661_item	2437449	et	4	main
olevad	doc_491521501661_item	2437454	et	4	main
tuli	doc_491521501661_item	2437464	et	4	main
ringi	doc_491521501661_item	2437471	et	4	main
takistama	doc_491521501662_item	2437490	et	3	main
tuvastama	doc_491521501662_item	2437491	et	3	main
kui	doc_491521501662_item	2437532	et	3	main
on	doc_491521501662_item	2437535	et	4	main
ametnikega	doc_491521501662_item	2437538	et	3	main
suhtlemides	doc_491521501662_item	2437539	et	4	main
ootate	doc_491521501662_item	2437542	et	3	main
pakkumisi	doc_491521501662_item	2437543	et	4	main
ise	doc_491521501662_item	2437562	et	4	main
remonti	doc_491521501662_item	2437563	et	4	main
tundi	doc_491521501662_item	2437571	et	4	main
ruutmeetrit	doc_491521501662_item	2437578	et	3	main
iv	doc_491521501662_item	2437579	et	4	main
ühesõnalised	doc_491521501662_item	2437581	et	4	main
sünonüümid	doc_491521501662_item	2437582	et	3	main
taga	doc_491521501662_item	2437587	et	4	main
v	doc_491521501662_item	2437594	et	4	main
kaubad	doc_491521501662_item	2437622	et	3	main
kvaliteetiga	doc_491521501662_item	2437625	et	4	main
возможность	doc_491521501662_item	2437631	et	2	main
kataloogi	doc_491521501662_item	2437641	et	4	main
kerkibkaasneb	doc_491521501662_item	2437665	et	4	main
vaeva	doc_491521501662_item	2437674	et	4	main
maha	doc_491521501662_item	2437677	et	4	main
müüa	doc_491521501662_item	2437678	et	3	main
peale	doc_491521501662_item	2437682	et	4	main
hiilima	doc_491521501662_item	2437687	et	3	main
kasutusjuhendis	doc_491521501662_item	2437689	et	3	main
viii	doc_491521501662_item	2437702	et	4	main
kirjutage	doc_491521501662_item	2437703	et	3	main
tulemuse	doc_491521501661_item	2437279	et	3	main
parima	doc_491521501661_item	2437284	et	4	main
tulemuse	doc_491521501661_item	2437285	et	3	main
meetrit	doc_491521501661_item	2437290	et	3	main
juurde	doc_491521501661_item	2437306	et	4	main
aru	doc_491521501661_item	2437310	et	4	main
selgitama	doc_491521501661_item	2437312	et	4	main
tehti	doc_491521501661_item	2437318	et	3	main
nõudi	doc_491521501661_item	2437326	et	4	main
быстро	doc_491521501661_item	2437341	et	2	main
дома	doc_491521501661_item	2437355	et	2	main
право	doc_491521501661_item	2437369	et	2	main
osta	doc_491521501661_item	2437377	et	4	main
vii	doc_491521501661_item	2437379	et	4	main
tõmmake	doc_491521501661_item	2437380	et	3	main
kerkibkaasneb	doc_491521501661_item	2437387	et	4	main
haldab	doc_491521501661_item	2437388	et	3	main
maakler	doc_491521501661_item	2437390	et	3	main
käima	doc_491521501661_item	2437404	et	4	main
toime	doc_491521501661_item	2437405	et	4	main
viii	doc_491521501661_item	2437421	et	4	main
käitus	doc_491521501661_item	2437435	et	4	main
tüdinult	doc_491521501661_item	2437441	et	4	main
toit	doc_491521501661_item	2437442	et	3	main
pange	doc_491521501661_item	2437452	et	4	main
välja	doc_491521501661_item	2437462	et	4	main
külm	doc_491521501661_item	2437463	et	3	main
oli	doc_491521501661_item	2437474	et	3	main
korras	doc_491521501661_item	2437486	et	4	main
sundima	doc_491521501662_item	2437502	et	4	main
ii	doc_491521501662_item	2437504	et	4	main
kasutage	doc_491521501662_item	2437505	et	3	main
des-vormi	doc_491521501662_item	2437506	et	4	main
1	doc_491521501662_item	2437507	et	2	main
kui	doc_491521501662_item	2437508	et	3	main
sõlmite	doc_491521501662_item	2437509	et	3	main
lepingut	doc_491521501662_item	2437510	et	3	main
olge	doc_491521501662_item	2437511	et	3	main
tähelepanelik	doc_491521501662_item	2437512	et	4	main
asjatundja	doc_491521501662_item	2437530	et	4	main
ametnikega	doc_491521501662_item	2437534	et	3	main
maaklerist	doc_491521501662_item	2437537	et	3	main
4	doc_491521501662_item	2437540	et	2	main
kui	doc_491521501662_item	2437541	et	3	main
ise	doc_491521501662_item	2437552	et	4	main
aktiivne	doc_491521501662_item	2437553	et	3	main
5	doc_491521501662_item	2437554	et	2	main
kui	doc_491521501662_item	2437555	et	3	main
teete	doc_491521501662_item	2437556	et	3	main
ise	doc_491521501662_item	2437557	et	4	main
remonti	doc_491521501662_item	2437558	et	4	main
te	doc_491521501662_item	2437564	et	4	main
kuus	doc_491521501662_item	2437570	et	4	main
viis	doc_491521501662_item	2437572	et	4	main
sada	doc_491521501662_item	2437574	et	4	main
krooni	doc_491521501662_item	2437576	et	4	main
terveks	doc_491521501662_item	2437583	et	4	main
mida	doc_491521501662_item	2437595	et	4	main
есть	doc_491521501662_item	2437630	et	2	main
каталог	doc_491521501662_item	2437635	et	2	main
võimalus	doc_491521501662_item	2437638	et	3	main
kodus	doc_491521501662_item	2437639	et	4	main
rahulikult	doc_491521501662_item	2437640	et	4	main
õigus	doc_491521501662_item	2437653	et	4	main
järelmaksudes	doc_491521501662_item	2437656	et	3	main
vii	doc_491521501662_item	2437657	et	4	main
tõmmake	doc_491521501662_item	2437658	et	3	main
maha	doc_491521501662_item	2437659	et	4	main
alla	doc_491521501662_item	2437660	et	3	main
valed	doc_491521501662_item	2437661	et	3	main
haldab	doc_491521501662_item	2437666	et	3	main
lasi	doc_491521501662_item	2437669	et	4	main
läbi	doc_491521501662_item	2437670	et	4	main
et	doc_491521501662_item	2437675	et	3	main
üleolevad	doc_491521501662_item	2437692	et	3	main
eksitavad	doc_491521501662_item	2437693	et	4	main
isuäratavalt	doc_491521501662_item	2437727	et	4	main
ix	doc_491521501662_item	2437732	et	4	main
näeb	doc_491521501662_item	2437740	et	3	main
lahtiselt	doc_491521501662_item	2437751	et	4	main
oli	doc_491521501662_item	2437755	et	3	main
lasti	doc_491521501661_item	2437328	et	4	main
ostma	doc_491521501661_item	2437329	et	3	main
возможность	doc_491521501661_item	2437354	et	2	main
имеют	doc_491521501661_item	2437368	et	2	main
в	doc_491521501661_item	2437372	et	2	main
alla	doc_491521501661_item	2437382	et	3	main
valed	doc_491521501661_item	2437383	et	3	main
läbiajas	doc_491521501661_item	2437392	et	3	main
vaeva	doc_491521501661_item	2437395	et	4	main
korterit	doc_491521501661_item	2437397	et	3	main
müüa	doc_491521501661_item	2437399	et	3	main
lõvi	doc_491521501661_item	2437400	et	4	main
hakkas	doc_491521501661_item	2437401	et	3	main
saagile	doc_491521501661_item	2437402	et	3	main
peale	doc_491521501661_item	2437403	et	4	main
toote	doc_491521501661_item	2437408	et	4	main
kasutusjuhendis	doc_491521501661_item	2437409	et	3	main
on	doc_491521501661_item	2437410	et	4	main
mõned	doc_491521501661_item	2437411	et	3	main
üleolevad	doc_491521501661_item	2437412	et	3	main
eksitavadkehtivad	doc_491521501661_item	2437413	et	4	main
kohad	doc_491521501661_item	2437414	et	4	main
artiklid	doc_491521501661_item	2437415	et	3	main
kahjustasid	doc_491521501661_item	2437416	et	4	main
firma	doc_491521501661_item	2437417	et	4	main
olemust	doc_491521501661_item	2437418	et	3	main
mainet	doc_491521501661_item	2437419	et	4	main
puänti	doc_491521501661_item	2437420	et	4	main
lünka	doc_491521501661_item	2437423	et	4	main
sobiv	doc_491521501661_item	2437424	et	4	main
pealetükkivalt	doc_491521501661_item	2437428	et	4	main
üsna	doc_491521501661_item	2437432	et	3	main
neiu	doc_491521501661_item	2437434	et	4	main
sõnad	doc_491521501661_item	2437445	et	4	main
tüdinult	doc_491521501661_item	2437447	et	4	main
väljakutsuvalt	doc_491521501661_item	2437448	et	4	main
õigesse	doc_491521501661_item	2437456	et	3	main
vormi	doc_491521501661_item	2437457	et	4	main
näeb	doc_491521501661_item	2437459	et	3	main
see	doc_491521501661_item	2437472	et	3	main
hirmus	doc_491521501661_item	2437476	et	4	main
hirmune	doc_491521501661_item	2437477	et	4	main
asju	doc_491521501661_item	2437485	et	3	main
tõlkige	doc_491521501662_item	2437489	et	3	main
выполнять	doc_491521501662_item	2437493	et	2	main
umbusklik	doc_491521501662_item	2437495	et	3	main
välja	doc_491521501662_item	2437498	et	4	main
lepingut	doc_491521501662_item	2437513	et	3	main
sõlmites	doc_491521501662_item	2437514	et	4	main
üle	doc_491521501662_item	2437521	et	3	main
võtke	doc_491521501662_item	2437523	et	3	main
korteri	doc_491521501662_item	2437526	et	3	main
vaatades	doc_491521501662_item	2437527	et	4	main
3	doc_491521501662_item	2437531	et	2	main
olge	doc_491521501662_item	2437544	et	3	main
ka	doc_491521501662_item	2437545	et	3	main
meetrit	doc_491521501662_item	2437569	et	3	main
moodustage	doc_491521501662_item	2437580	et	3	main
panema	doc_491521501662_item	2437586	et	3	main
ajama	doc_491521501662_item	2437588	et	4	main
saama	doc_491521501662_item	2437590	et	4	main
ära	doc_491521501662_item	2437591	et	4	main
minema	doc_491521501662_item	2437592	et	3	main
lahkuma	doc_491521501662_item	2437593	et	3	main
saatma	doc_491521501662_item	2437597	et	3	main
kirjutage	doc_491521501661_item	2437422	et	3	main
seisid	doc_491521501661_item	2437427	et	4	main
ta	doc_491521501661_item	2437430	et	4	main
maitsetult	doc_491521501661_item	2437433	et	4	main
müüja	doc_491521501661_item	2437437	et	4	main
pakkus	doc_491521501661_item	2437438	et	3	main
oma	doc_491521501661_item	2437439	et	4	main
kaupa	doc_491521501661_item	2437440	et	4	main
isuäratavalt	doc_491521501661_item	2437444	et	4	main
sulgudes	doc_491521501661_item	2437453	et	4	main
jube	doc_491521501661_item	2437460	et	4	main
jubedalt	doc_491521501661_item	2437461	et	4	main
koer	doc_491521501661_item	2437467	et	3	main
jookseb	doc_491521501661_item	2437468	et	3	main
lahtine	doc_491521501661_item	2437469	et	3	main
lahtiselt	doc_491521501661_item	2437470	et	4	main
ei	doc_491521501661_item	2437483	et	4	main
hoia	doc_491521501661_item	2437484	et	4	main
i	doc_491521501662_item	2437488	et	4	main
kohtlema	doc_491521501662_item	2437494	et	3	main
peibutama	doc_491521501662_item	2437497	et	3	main
venima	doc_491521501662_item	2437499	et	3	main
hallitama	doc_491521501662_item	2437500	et	3	main
küünistama	doc_491521501662_item	2437501	et	3	main
olge	doc_491521501662_item	2437515	et	3	main
2	doc_491521501662_item	2437517	et	2	main
vaatama	doc_491521501662_item	2437522	et	3	main
asjatundja	doc_491521501662_item	2437525	et	4	main
abi	doc_491521501662_item	2437536	et	4	main
saate	doc_491521501662_item	2437559	et	4	main
iii	doc_491521501662_item	2437565	et	4	main
moodustage	doc_491521501662_item	2437566	et	3	main
liitsõnad	doc_491521501662_item	2437567	et	3	main
poolteist	doc_491521501662_item	2437568	et	4	main
liiget	doc_491521501662_item	2437573	et	3	main
viis	doc_491521501662_item	2437575	et	4	main
saama	doc_491521501662_item	2437584	et	4	main
у	doc_491521501662_item	2437628	et	2	main
спокойно	doc_491521501662_item	2437633	et	2	main
teil	doc_491521501662_item	2437636	et	4	main
в	doc_491521501662_item	2437649	et	2	main
sõnad	doc_491521501662_item	2437662	et	4	main
korda	doc_491521501662_item	2437672	et	4	main
nägi	doc_491521501662_item	2437673	et	3	main
käima	doc_491521501662_item	2437683	et	4	main
tulema	doc_491521501662_item	2437685	et	4	main
toote	doc_491521501662_item	2437688	et	4	main
on	doc_491521501662_item	2437690	et	4	main
mõned	doc_491521501662_item	2437691	et	3	main
firma	doc_491521501662_item	2437698	et	4	main
olemust	doc_491521501662_item	2437699	et	3	main
sõnad	doc_491521501662_item	2437726	et	4	main
maitsetult	doc_491521501662_item	2437731	et	4	main
sõnad	doc_491521501662_item	2437736	et	4	main
ringi	doc_491521501662_item	2437752	et	4	main
on	doc_491521501662_item	2437759	et	4	main
ei	doc_491521501662_item	2437764	et	4	main
asju	doc_491521501662_item	2437766	et	3	main
kuidas	doc_491521501664_item	2437773	et	3	main
ma	doc_491521501664_item	2437776	et	3	main
sinu	doc_491521501664_item	2437778	et	3	main
avati	doc_491521501664_item	2437783	et	3	main
uus	doc_491521501664_item	2437784	et	3	main
suur	doc_491521501664_item	2437785	et	3	main
kauplus	doc_491521501664_item	2437786	et	3	main
tihti	doc_491521501664_item	2437796	et	3	main
ma	doc_491521501664_item	2437798	et	3	main
liha	doc_491521501664_item	2437805	et	4	main
kauplus	doc_491521501664_item	2437807	et	3	main
заставлять	doc_491521501662_item	2437503	et	2	main
tähelepanelik	doc_491521501662_item	2437516	et	4	main
kui	doc_491521501662_item	2437518	et	3	main
lähete	doc_491521501662_item	2437519	et	4	main
korterit	doc_491521501662_item	2437520	et	3	main
kaasa	doc_491521501662_item	2437524	et	4	main
võtke	doc_491521501662_item	2437528	et	3	main
kaasa	doc_491521501662_item	2437529	et	4	main
suhtlete	doc_491521501662_item	2437533	et	3	main
ise	doc_491521501662_item	2437546	et	4	main
aktiivne	doc_491521501662_item	2437547	et	3	main
pakkumisi	doc_491521501662_item	2437548	et	4	main
ootades	doc_491521501662_item	2437549	et	4	main
olge	doc_491521501662_item	2437550	et	3	main
ka	doc_491521501662_item	2437551	et	3	main
parima	doc_491521501662_item	2437560	et	4	main
tulemuse	doc_491521501662_item	2437561	et	3	main
kakskümmend	doc_491521501662_item	2437577	et	4	main
juurde	doc_491521501662_item	2437585	et	4	main
aru	doc_491521501662_item	2437589	et	4	main
tehti	doc_491521501662_item	2437596	et	3	main
saati	doc_491521501662_item	2437598	et	3	main
lugema	doc_491521501662_item	2437599	et	4	main
pakkuma	doc_491521501662_item	2437601	et	3	main
pakkuti	doc_491521501662_item	2437602	et	4	main
nõudma	doc_491521501662_item	2437603	et	3	main
nõudti	doc_491521501662_item	2437604	et	4	main
laskma	doc_491521501662_item	2437605	et	3	main
loeti	doc_491521501662_item	2437600	et	3	main
lasti	doc_491521501662_item	2437606	et	4	main
ostma	doc_491521501662_item	2437607	et	3	main
osti	doc_491521501662_item	2437608	et	4	main
olema	doc_491521501662_item	2437609	et	4	main
olti	doc_491521501662_item	2437610	et	4	main
vi	doc_491521501662_item	2437611	et	4	main
tõlkige	doc_491521501662_item	2437612	et	3	main
некоторые	doc_491521501662_item	2437613	et	2	main
товары	doc_491521501662_item	2437614	et	2	main
имеют	doc_491521501662_item	2437615	et	2	main
качество	doc_491521501662_item	2437617	et	2	main
плохое	doc_491521501662_item	2437616	et	2	main
быстро	doc_491521501662_item	2437619	et	2	main
и	doc_491521501662_item	2437618	et	2	main
ломаются	doc_491521501662_item	2437620	et	2	main
mõned	doc_491521501662_item	2437621	et	3	main
on	doc_491521501662_item	2437623	et	4	main
halba	doc_491521501662_item	2437624	et	4	main
ja	doc_491521501662_item	2437626	et	3	main
tihti	doc_491521501662_item	2437627	et	3	main
дома	doc_491521501662_item	2437632	et	2	main
lugema	doc_491521501662_item	2437642	et	4	main
постоянные	doc_491521501662_item	2437643	et	2	main
клиенты	doc_491521501662_item	2437644	et	2	main
имеют	doc_491521501662_item	2437645	et	2	main
право	doc_491521501662_item	2437646	et	2	main
покупать	doc_491521501662_item	2437647	et	2	main
товар	doc_491521501662_item	2437648	et	2	main
рассрочку	doc_491521501662_item	2437650	et	2	main
püsiklientidel	doc_491521501662_item	2437651	et	3	main
on	doc_491521501662_item	2437652	et	4	main
ostma	doc_491521501662_item	2437654	et	3	main
kaup	doc_491521501662_item	2437655	et	3	main
вас	doc_491521501662_item	2437629	et	2	main
изучить	doc_491521501662_item	2437634	et	2	main
on	doc_491521501662_item	2437637	et	4	main
seda	doc_491521501662_item	2437663	et	3	main
maakler	doc_491521501662_item	2437668	et	3	main
ajas	doc_491521501662_item	2437671	et	4	main
saagile	doc_491521501662_item	2437681	et	3	main
kehtivad	doc_491521501662_item	2437694	et	4	main
mainet	doc_491521501662_item	2437700	et	4	main
lünka	doc_491521501662_item	2437704	et	4	main
sobiv	doc_491521501662_item	2437705	et	4	main
määrsõna	doc_491521501662_item	2437706	et	4	main
inimesed	doc_491521501662_item	2437707	et	3	main
seisid	doc_491521501662_item	2437708	et	4	main
pealetükkivalt	doc_491521501662_item	2437709	et	4	main
järjekorras	doc_491521501662_item	2437710	et	3	main
ta	doc_491521501662_item	2437711	et	4	main
riietub	doc_491521501662_item	2437712	et	3	main
üsna	doc_491521501662_item	2437713	et	3	main
maitsetult	doc_491521501662_item	2437714	et	4	main
neiu	doc_491521501662_item	2437715	et	4	main
käitus	doc_491521501662_item	2437716	et	4	main
väljakutsuvalt	doc_491521501662_item	2437717	et	4	main
müüja	doc_491521501662_item	2437718	et	4	main
pakkus	doc_491521501662_item	2437719	et	3	main
oma	doc_491521501662_item	2437720	et	4	main
kaupa	doc_491521501662_item	2437721	et	4	main
toit	doc_491521501662_item	2437723	et	3	main
lõhnas	doc_491521501662_item	2437724	et	4	main
isuäratavalt	doc_491521501662_item	2437725	et	4	main
pealetükkivalt	doc_491521501662_item	2437730	et	4	main
olevad	doc_491521501662_item	2437735	et	4	main
see	doc_491521501662_item	2437739	et	3	main
ootamatu	doc_491521501662_item	2437746	et	4	main
ootamatult	doc_491521501662_item	2437747	et	4	main
koer	doc_491521501662_item	2437748	et	3	main
jookseb	doc_491521501662_item	2437749	et	3	main
see	doc_491521501662_item	2437753	et	3	main
hirmus	doc_491521501662_item	2437757	et	4	main
piinlik	doc_491521501662_item	2437760	et	3	main
kui	doc_491521501662_item	2437762	et	3	main
kristina	doc_491521501664_item	2437772	et	4	main
elad	doc_491521501664_item	2437775	et	3	main
kätte	doc_491521501664_item	2437780	et	4	main
kauplused	doc_491521501664_item	2437797	et	3	main
raske	doc_491521501664_item	2437814	et	4	main
kirjiuta	doc_491521501664_item	2437815	et	4	main
eesti	doc_491521501664_item	2437816	et	4	main
kingitus	doc_491521501664_item	2437828	et	4	main
taega	doc_491521501664_item	2437830	et	4	main
sõbranna	doc_491521501665_item	2437837	et	4	main
kirja	doc_491521501665_item	2437842	et	4	main
aitäh	doc_491521501665_item	2437844	et	3	main
väga	doc_491521501665_item	2437847	et	3	main
uus	doc_491521501665_item	2437853	et	3	main
see	doc_491521501665_item	2437856	et	3	main
seal	doc_491521501665_item	2437861	et	4	main
kodumasinad	doc_491521501665_item	2437863	et	3	main
uudis	doc_491521501666_item	2437880	et	3	main
minu	doc_491521501666_item	2437881	et	3	main
maja	doc_491521501666_item	2437882	et	4	main
avatud	doc_491521501666_item	2437883	et	4	main
kauplus	doc_491521501666_item	2437885	et	3	main
töötab	doc_491521501666_item	2437897	et	3	main
maja	doc_491521501662_item	2437664	et	4	main
korteriühistu	doc_491521501662_item	2437667	et	4	main
korterit	doc_491521501662_item	2437676	et	3	main
lõvi	doc_491521501662_item	2437679	et	4	main
hakkas	doc_491521501662_item	2437680	et	3	main
toime	doc_491521501662_item	2437684	et	4	main
ligi	doc_491521501662_item	2437686	et	3	main
kohad	doc_491521501662_item	2437695	et	4	main
artiklid	doc_491521501662_item	2437696	et	3	main
kahjustasid	doc_491521501662_item	2437697	et	4	main
puänti	doc_491521501662_item	2437701	et	4	main
tüdinult	doc_491521501662_item	2437722	et	4	main
tüdinult	doc_491521501662_item	2437728	et	4	main
pange	doc_491521501662_item	2437733	et	4	main
õigesse	doc_491521501662_item	2437737	et	3	main
jube	doc_491521501662_item	2437741	et	4	main
välja	doc_491521501662_item	2437743	et	4	main
külm	doc_491521501662_item	2437744	et	3	main
lahtine	doc_491521501662_item	2437750	et	3	main
hirmus	doc_491521501662_item	2437758	et	4	main
piinlik	doc_491521501662_item	2437761	et	3	main
inimesed	doc_491521501662_item	2437763	et	3	main
tere	doc_491521501664_item	2437771	et	3	main
sa	doc_491521501664_item	2437774	et	3	main
kirja	doc_491521501664_item	2437779	et	4	main
mikroraioni	doc_491521501664_item	2437782	et	4	main
kella	doc_491521501664_item	2437788	et	4	main
ostima	doc_491521501664_item	2437799	et	4	main
se	doc_491521501664_item	2437806	et	4	main
jüurvilid	doc_491521501664_item	2437810	et	4	main
jurde	doc_491521501664_item	2437821	et	4	main
sina	doc_491521501664_item	2437823	et	4	main
sinu	doc_491521501664_item	2437832	et	3	main
lilli	doc_491521501665_item	2437838	et	4	main
ma	doc_491521501665_item	2437839	et	3	main
sinu	doc_491521501665_item	2437841	et	3	main
sulle	doc_491521501665_item	2437845	et	3	main
huvitav	doc_491521501665_item	2437848	et	4	main
minu	doc_491521501665_item	2437849	et	3	main
maja	doc_491521501665_item	2437850	et	4	main
suur	doc_491521501665_item	2437854	et	3	main
elektroonika	doc_491521501665_item	2437864	et	4	main
mänguasjad	doc_491521501665_item	2437865	et	3	main
kantseleiklaubad	doc_491521501665_item	2437869	et	4	main
mari	doc_491521501666_item	2437875	et	4	main
hea	doc_491521501666_item	2437879	et	4	main
kauplus	doc_491521501666_item	2437887	et	3	main
ilus	doc_491521501666_item	2437891	et	4	main
on	doc_491521501666_item	2437893	et	4	main
viis	doc_491521501666_item	2437894	et	4	main
osakond	doc_491521501666_item	2437895	et	3	main
konditeri	doc_491521501666_item	2437903	et	3	main
osakond	doc_491521501666_item	2437904	et	3	main
osakond	doc_491521501666_item	2437906	et	3	main
juurvili	doc_491521501666_item	2437912	et	3	main
puuviljad	doc_491521501666_item	2437914	et	3	main
me	doc_491521501666_item	2437923	et	4	main
sa	doc_491521501666_item	2437928	et	3	main
suur	doc_491521501666_item	2437930	et	3	main
ja	doc_491521501666_item	2437931	et	3	main
kaupluses	doc_491521501666_item	2437933	et	3	main
hea	doc_491521501666_item	2437940	et	4	main
otan	doc_491521501666_item	2437945	et	4	main
sind	doc_491521501666_item	2437946	et	4	main
oma	doc_491521501666_item	2437949	et	4	main
kuidas	doc_491521501667_item	2437954	et	3	main
midagi	doc_491521501667_item	2437965	et	4	main
on	doc_491521501667_item	2437970	et	4	main
niisama	doc_491521501667_item	2437973	et	3	main
und	doc_491521501667_item	2437975	et	4	main
ilus	doc_491521501667_item	2437977	et	4	main
ma	doc_491521501667_item	2437978	et	3	main
soovitan	doc_491521501667_item	2437979	et	3	main
sul	doc_491521501667_item	2437980	et	3	main
suvel	doc_491521501667_item	2437981	et	3	main
küla	doc_491521501667_item	2437982	et	4	main
lähme	doc_491521501667_item	2437983	et	3	main
väljakutsuvalt	doc_491521501662_item	2437729	et	4	main
sulgudes	doc_491521501662_item	2437734	et	4	main
vormi	doc_491521501662_item	2437738	et	4	main
jube	doc_491521501662_item	2437742	et	4	main
tuli	doc_491521501662_item	2437745	et	4	main
juhtum	doc_491521501662_item	2437754	et	3	main
lihtsalt	doc_491521501662_item	2437756	et	4	main
hoia	doc_491521501662_item	2437765	et	4	main
korras	doc_491521501662_item	2437767	et	4	main
katse	doc_491521501663_item	2437768	et	4	main
sain	doc_491521501664_item	2437777	et	3	main
avatud	doc_491521501664_item	2437787	et	4	main
vieeni	doc_491521501664_item	2437790	et	4	main
töötab	doc_491521501664_item	2437793	et	3	main
ma	doc_491521501664_item	2437794	et	3	main
jüurvili	doc_491521501664_item	2437800	et	4	main
ja	doc_491521501664_item	2437801	et	3	main
puuvili	doc_491521501664_item	2437802	et	3	main
kala	doc_491521501664_item	2437803	et	4	main
ja	doc_491521501664_item	2437804	et	3	main
on	doc_491521501664_item	2437808	et	4	main
ilus	doc_491521501664_item	2437809	et	4	main
alati	doc_491521501664_item	2437811	et	4	main
värsked	doc_491521501664_item	2437812	et	4	main
kell	doc_491521501664_item	2437817	et	3	main
ma	doc_491521501664_item	2437818	et	3	main
ootame	doc_491521501664_item	2437819	et	3	main
sinu	doc_491521501664_item	2437820	et	3	main
sind	doc_491521501664_item	2437827	et	4	main
hea	doc_491521501664_item	2437829	et	4	main
tere	doc_491521501665_item	2437835	et	3	main
juures	doc_491521501665_item	2437851	et	4	main
valmisriided	doc_491521501665_item	2437866	et	3	main
parfümeeria	doc_491521501665_item	2437868	et	4	main
ja	doc_491521501665_item	2437870	et	3	main
tere	doc_491521501666_item	2437874	et	3	main
uudne	doc_491521501666_item	2437884	et	3	main
iga	doc_491521501666_item	2437898	et	4	main
on	doc_491521501666_item	2437901	et	4	main
suur	doc_491521501666_item	2437910	et	3	main
on	doc_491521501666_item	2437917	et	4	main
oma	doc_491521501666_item	2437921	et	4	main
vatad	doc_491521501666_item	2437929	et	4	main
on	doc_491521501666_item	2437939	et	4	main
taiga	doc_491521501666_item	2437943	et	4	main
ma	doc_491521501666_item	2437944	et	3	main
perekonda	doc_491521501666_item	2437950	et	4	main
mis	doc_491521501667_item	2437956	et	4	main
su	doc_491521501667_item	2437968	et	3	main
on	doc_491521501667_item	2437972	et	4	main
nägema	doc_491521501667_item	2437976	et	3	main
sind	doc_491521501667_item	2437987	et	4	main
fhdurjkv	doc_491521501663_item	2437769	et	4	main
kiri	doc_491521501664_item	2437770	et	3	main
meie	doc_491521501664_item	2437781	et	4	main
kaheksast	doc_491521501664_item	2437789	et	4	main
ilma	doc_491521501664_item	2437791	et	4	main
vaheajata	doc_491521501664_item	2437792	et	3	main
käin	doc_491521501664_item	2437795	et	3	main
mulle	doc_491521501664_item	2437813	et	4	main
millal	doc_491521501664_item	2437822	et	3	main
kohalen	doc_491521501664_item	2437824	et	4	main
olen	doc_491521501664_item	2437826	et	3	main
kristina	doc_491521501664_item	2437831	et	4	main
ema	doc_491521501664_item	2437833	et	4	main
kiri	doc_491521501665_item	2437834	et	3	main
minu	doc_491521501665_item	2437836	et	3	main
sain	doc_491521501665_item	2437840	et	3	main
kätta	doc_491521501665_item	2437843	et	4	main
oli	doc_491521501665_item	2437846	et	3	main
avati	doc_491521501665_item	2437852	et	3	main
kauplus	doc_491521501665_item	2437855	et	3	main
ilus	doc_491521501665_item	2437858	et	4	main
ehitis	doc_491521501665_item	2437860	et	3	main
müüakse	doc_491521501665_item	2437862	et	3	main
jalatsid	doc_491521501665_item	2437867	et	3	main
muidugi	doc_491521501665_item	2437871	et	4	main
kiri	doc_491521501666_item	2437873	et	3	main
mul	doc_491521501666_item	2437876	et	3	main
on	doc_491521501666_item	2437877	et	4	main
sulle	doc_491521501666_item	2437878	et	3	main
see	doc_491521501666_item	2437886	et	3	main
suur	doc_491521501666_item	2437889	et	3	main
kaupluses	doc_491521501666_item	2437892	et	3	main
päev	doc_491521501666_item	2437899	et	3	main
suur	doc_491521501666_item	2437902	et	3	main
liha	doc_491521501666_item	2437905	et	4	main
suur	doc_491521501666_item	2437907	et	3	main
välik	doc_491521501666_item	2437911	et	4	main
koos	doc_491521501666_item	2437925	et	4	main
kaupluses	doc_491521501666_item	2437927	et	3	main
mulle	doc_491521501666_item	2437934	et	4	main
meldib	doc_491521501666_item	2437935	et	4	main
see	doc_491521501666_item	2437936	et	3	main
siis	doc_491521501666_item	2437938	et	3	main
välik	doc_491521501666_item	2437941	et	4	main
hea	doc_491521501666_item	2437942	et	4	main
tere	doc_491521501667_item	2437952	et	3	main
uudist	doc_491521501667_item	2437957	et	3	main
juhtunud	doc_491521501667_item	2437966	et	4	main
kuidas	doc_491521501667_item	2437967	et	3	main
koos	doc_491521501667_item	2437984	et	4	main
ma	doc_491521501667_item	2437985	et	3	main
ma	doc_491521501664_item	2437825	et	3	main
on	doc_491521501665_item	2437857	et	4	main
moodne	doc_491521501665_item	2437859	et	3	main
toiduained	doc_491521501665_item	2437872	et	3	main
on	doc_491521501666_item	2437888	et	4	main
ja	doc_491521501666_item	2437890	et	3	main
kauplus	doc_491521501666_item	2437896	et	3	main
kaupluses	doc_491521501666_item	2437900	et	3	main
vorsti	doc_491521501666_item	2437908	et	4	main
ja	doc_491521501666_item	2437913	et	3	main
see	doc_491521501666_item	2437915	et	3	main
hea	doc_491521501666_item	2437918	et	4	main
sõidma	doc_491521501666_item	2437919	et	4	main
minu	doc_491521501666_item	2437920	et	3	main
osakond	doc_491521501666_item	2437909	et	3	main
kauplus	doc_491521501666_item	2437916	et	3	main
laheme	doc_491521501666_item	2437924	et	4	main
ilus	doc_491521501666_item	2437932	et	4	main
tervita	doc_491521501666_item	2437947	et	4	main
svetlana	doc_491521501667_item	2437953	et	4	main
kuulukse	doc_491521501667_item	2437959	et	4	main
kas	doc_491521501667_item	2437963	et	3	main
on	doc_491521501667_item	2437964	et	4	main
ma	doc_491521501667_item	2437971	et	3	main
ma	doc_491521501667_item	2437974	et	3	main
ootan	doc_491521501667_item	2437986	et	3	main
ja	doc_491521501666_item	2437922	et	3	main
seda	doc_491521501666_item	2437926	et	3	main
kauplus	doc_491521501666_item	2437937	et	3	main
sinu	doc_491521501666_item	2437948	et	3	main
kiri	doc_491521501667_item	2437951	et	3	main
läheb	doc_491521501667_item	2437955	et	3	main
mida	doc_491521501667_item	2437958	et	4	main
miks	doc_491521501667_item	2437960	et	4	main
sa	doc_491521501667_item	2437961	et	3	main
vaikid	doc_491521501667_item	2437962	et	3	main
tervis	doc_491521501667_item	2437969	et	3	main
ja	doc_491521501667_item	2437988	et	3	main
su	doc_491521501667_item	2437989	et	3	main
kirja	doc_491521501667_item	2437990	et	4	main
ma	doc_491521501667_item	2437991	et	3	main
avamine	doc_491521501667_item	2437992	et	4	main
kiosk	doc_491521501667_item	2437993	et	3	main
ma	doc_491521501667_item	2437994	et	3	main
teema	doc_491521501667_item	2437995	et	4	main
kioskus	doc_491521501667_item	2437996	et	4	main
mul	doc_491521501667_item	2437997	et	3	main
on	doc_491521501667_item	2437998	et	4	main
kõik	doc_491521501667_item	2437999	et	4	main
hästi	doc_491521501667_item	2438000	et	3	main
ja	doc_491521501667_item	2438001	et	3	main
kõik	doc_491521501667_item	2438002	et	4	main
on	doc_491521501667_item	2438003	et	4	main
korras	doc_491521501667_item	2438004	et	4	main
sellega	doc_491521501667_item	2438005	et	3	main
lõpetan	doc_491521501667_item	2438006	et	3	main
kirjutage	doc_491521501667_item	2438007	et	3	main
kalli-kalli	doc_491521501667_item	2438008	et	3	main
eesnimi	doc_491521501667_item	2438009	et	3	main
kontrolltöö	doc_491521501671_item	2438337	et	4	main
helisema	doc_491521501671_item	2438352	et	4	main
kui	doc_491521501671_item	2438353	et	3	main
olema	doc_491521501671_item	2438354	et	4	main
tualett	doc_491521501671_item	2438355	et	3	main
telefon	doc_491521501671_item	2438362	et	3	main
tualetis	doc_491521501671_item	2438366	et	3	main
sadama	doc_491521501671_item	2438375	et	4	main
ära	doc_491521501671_item	2438379	et	4	main
56	doc_491521501671_item	2438381	et	2	main
on	doc_491521501671_item	2438383	et	4	main
lõppenud	doc_491521501671_item	2438411	et	4	main
tavaliselt	doc_491521501671_item	2438415	et	4	main
õhtu	doc_491521501671_item	2438417	et	4	main
tavaliselt	doc_491521501671_item	2438422	et	4	main
kõik	doc_491521501671_item	2438425	et	4	main
59	doc_491521501671_item	2438431	et	2	main
hästi	doc_491521501671_item	2438435	et	3	main
need	doc_491521501671_item	2438438	et	3	main
olema	doc_491521501671_item	2438439	et	4	main
murphy	doc_491521501671_item	2438440	et	4	main
seadused	doc_491521501671_item	2438441	et	3	main
60	doc_491521501671_item	2438442	et	2	main
need	doc_491521501671_item	2438443	et	3	main
järgmist	doc_491521501672_item	2438449	et	3	main
ja	doc_491521501672_item	2438451	et	3	main
vastus	doc_491521501672_item	2438453	et	3	main
head	doc_491521501672_item	2438457	et	4	main
ootan	doc_491521501672_item	2438459	et	3	main
õpin	doc_491521501672_item	2438488	et	3	main
ma	doc_491521501672_item	2438491	et	3	main
koos	doc_491521501672_item	2438493	et	4	main
pärnus	doc_491521501672_item	2438495	et	3	main
hästi	doc_491521501672_item	2438499	et	3	main
sõidan	doc_491521501672_item	2438505	et	3	main
sügisel	doc_491521501672_item	2438507	et	3	main
kiri	doc_491521501673_item	2438508	et	3	main
järgmist	doc_491521501673_item	2438510	et	3	main
teksti	doc_491521501673_item	2438511	et	4	main
soovin	doc_491521501673_item	2438516	et	3	main
endale	doc_491521501673_item	2438522	et	4	main
külla	doc_491521501673_item	2438523	et	4	main
kirjuta	doc_491521501673_item	2438524	et	4	main
sõidad	doc_491521501673_item	2438532	et	3	main
vastus	doc_491521501673_item	2438535	et	3	main
hästi	doc_491521501673_item	2438550	et	3	main
õppib	doc_491521501673_item	2438554	et	4	main
viiendal	doc_491521501673_item	2438555	et	3	main
klassis	doc_491521501673_item	2438556	et	3	main
ga	doc_491521501671_item	2438345	et	4	main
telefon	doc_491521501671_item	2438351	et	3	main
on	doc_491521501671_item	2438361	et	4	main
olete	doc_491521501671_item	2438365	et	3	main
maha	doc_491521501671_item	2438367	et	4	main
aed	doc_491521501671_item	2438378	et	3	main
kas	doc_491521501671_item	2438382	et	3	main
vihm	doc_491521501671_item	2438384	et	3	main
ostma	doc_491521501671_item	2438397	et	3	main
vihmavari	doc_491521501671_item	2438407	et	4	main
kui	doc_491521501671_item	2438408	et	3	main
hakkama	doc_491521501671_item	2438413	et	3	main
laupäeva	doc_491521501671_item	2438416	et	4	main
58	doc_491521501671_item	2438418	et	2	main
hambad	doc_491521501671_item	2438419	et	3	main
hakkavad	doc_491521501671_item	2438420	et	4	main
etteantud	doc_491521501671_item	2438339	et	4	main
murphy	doc_491521501671_item	2438346	et	4	main
vihma	doc_491521501671_item	2438371	et	4	main
hakkama	doc_491521501671_item	2438372	et	3	main
just	doc_491521501671_item	2438373	et	3	main
siis	doc_491521501671_item	2438374	et	3	main
teie	doc_491521501671_item	2438395	et	4	main
kui	doc_491521501671_item	2438399	et	3	main
lõppema	doc_491521501671_item	2438401	et	4	main
vihm	doc_491521501671_item	2438409	et	3	main
on	doc_491521501671_item	2438410	et	4	main
valutama	doc_491521501671_item	2438414	et	4	main
valutama	doc_491521501671_item	2438421	et	4	main
laupäeva	doc_491521501671_item	2438423	et	4	main
õhtul	doc_491521501671_item	2438424	et	3	main
halvasti	doc_491521501671_item	2438430	et	3	main
mis	doc_491521501671_item	2438433	et	4	main
lõppetab	doc_491521501671_item	2438436	et	4	main
halvasti	doc_491521501671_item	2438437	et	3	main
kiri	doc_491521501672_item	2438447	et	3	main
tere	doc_491521501672_item	2438454	et	3	main
külla	doc_491521501672_item	2438462	et	4	main
kirjuta	doc_491521501672_item	2438463	et	4	main
puhkasin	doc_491521501672_item	2438492	et	3	main
pärnus	doc_491521501672_item	2438496	et	3	main
väga	doc_491521501672_item	2438498	et	3	main
ootan	doc_491521501673_item	2438520	et	3	main
mida	doc_491521501673_item	2438525	et	4	main
teed	doc_491521501673_item	2438526	et	4	main
kuidas	doc_491521501673_item	2438527	et	3	main
lapsed	doc_491521501673_item	2438528	et	3	main
elavad	doc_491521501673_item	2438529	et	4	main
tere	doc_491521501673_item	2438538	et	3	main
sõbranna	doc_491521501673_item	2438540	et	4	main
koolis	doc_491521501673_item	2438552	et	4	main
väga	doc_491521501673_item	2438564	et	3	main
töö	doc_491521501673_item	2438566	et	4	main
koju	doc_491521501673_item	2438567	et	3	main
venemaale	doc_491521501673_item	2438572	et	4	main
20-25	doc_491521501674_item	2438607	et	2	main
kijra	doc_491521501674_item	2438612	et	4	main
pansed	doc_491521501674_item	2438614	et	4	main
elavad	doc_491521501674_item	2438615	et	4	main
ei	doc_491521501674_item	2438626	et	4	main
vastus	doc_491521501676_item	2438706	et	3	main
head	doc_491521501676_item	2438710	et	4	main
sind	doc_491521501676_item	2438713	et	4	main
mida	doc_491521501676_item	2438717	et	4	main
tere	doc_491521501676_item	2438730	et	3	main
väga	doc_491521501676_item	2438733	et	3	main
mul	doc_491521501676_item	2438744	et	3	main
moodustage	doc_491521501671_item	2438338	et	3	main
sõnadest	doc_491521501671_item	2438340	et	3	main
näidis	doc_491521501671_item	2438342	et	4	main
on	doc_491521501671_item	2438343	et	4	main
tähistatud	doc_491521501671_item	2438344	et	4	main
istunud	doc_491521501671_item	2438368	et	4	main
kas	doc_491521501671_item	2438369	et	3	main
olema	doc_491521501671_item	2438370	et	4	main
olema	doc_491521501671_item	2438377	et	4	main
kastma	doc_491521501671_item	2438380	et	3	main
ära	doc_491521501671_item	2438392	et	4	main
kastanud	doc_491521501671_item	2438393	et	3	main
kas	doc_491521501671_item	2438394	et	3	main
vihmavari	doc_491521501671_item	2438398	et	4	main
olema	doc_491521501671_item	2438400	et	4	main
57	doc_491521501671_item	2438402	et	2	main
kas	doc_491521501671_item	2438403	et	3	main
teie	doc_491521501671_item	2438404	et	4	main
olete	doc_491521501671_item	2438405	et	3	main
osta	doc_491521501671_item	2438406	et	4	main
hambad	doc_491521501671_item	2438412	et	3	main
mis	doc_491521501671_item	2438426	et	4	main
kõik	doc_491521501671_item	2438432	et	4	main
algab	doc_491521501671_item	2438434	et	3	main
sulle	doc_491521501672_item	2438456	et	3	main
puhkust	doc_491521501672_item	2438458	et	4	main
sind	doc_491521501672_item	2438460	et	4	main
mida	doc_491521501672_item	2438464	et	4	main
hästi	doc_491521501672_item	2438490	et	3	main
ja	doc_491521501672_item	2438502	et	3	main
ja	doc_491521501673_item	2438512	et	3	main
kirjutage	doc_491521501673_item	2438513	et	3	main
vastus	doc_491521501673_item	2438514	et	3	main
tere	doc_491521501673_item	2438515	et	3	main
sind	doc_491521501673_item	2438521	et	4	main
ja	doc_491521501673_item	2438530	et	3	main
kirjutage	doc_491521501673_item	2438534	et	3	main
elavad	doc_491521501673_item	2438548	et	4	main
õppivad	doc_491521501673_item	2438551	et	4	main
tütar	doc_491521501673_item	2438553	et	3	main
mul	doc_491521501673_item	2438562	et	3	main
palju	doc_491521501673_item	2438565	et	4	main
ja	doc_491521501673_item	2438568	et	3	main
ma	doc_491521501673_item	2438570	et	3	main
kohtumiseni	doc_491521501673_item	2438575	et	4	main
mina	doc_491521501674_item	2438610	et	4	main
hea	doc_491521501674_item	2438617	et	4	main
sõida	doc_491521501674_item	2438627	et	4	main
lugege	doc_491521501676_item	2438701	et	3	main
teksti	doc_491521501676_item	2438703	et	4	main
soovin	doc_491521501676_item	2438708	et	3	main
kirjuta	doc_491521501676_item	2438716	et	4	main
laused	doc_491521501671_item	2438341	et	3	main
seadused	doc_491521501671_item	2438347	et	3	main
kas	doc_491521501671_item	2438348	et	3	main
teie	doc_491521501671_item	2438349	et	4	main
olema	doc_491521501671_item	2438350	et	4	main
maha	doc_491521501671_item	2438356	et	4	main
istuma	doc_491521501671_item	2438357	et	3	main
0	doc_491521501671_item	2438358	et	2	main
kas	doc_491521501671_item	2438359	et	3	main
teil	doc_491521501671_item	2438360	et	4	main
helisenud	doc_491521501671_item	2438363	et	4	main
kui	doc_491521501671_item	2438364	et	3	main
kui	doc_491521501671_item	2438376	et	3	main
hakkanud	doc_491521501671_item	2438385	et	4	main
just	doc_491521501671_item	2438386	et	3	main
siis	doc_491521501671_item	2438387	et	3	main
sadama	doc_491521501671_item	2438388	et	4	main
kui	doc_491521501671_item	2438389	et	3	main
on	doc_491521501671_item	2438390	et	4	main
aed	doc_491521501671_item	2438391	et	3	main
olema	doc_491521501671_item	2438396	et	4	main
hästi	doc_491521501671_item	2438428	et	3	main
on	doc_491521501671_item	2438444	et	4	main
mrphy	doc_491521501671_item	2438445	et	4	main
seadused	doc_491521501671_item	2438446	et	3	main
endale	doc_491521501672_item	2438461	et	4	main
hästi	doc_491521501672_item	2438486	et	3	main
ujume	doc_491521501672_item	2438501	et	3	main
ma	doc_491521501672_item	2438504	et	3	main
venemaale	doc_491521501672_item	2438506	et	4	main
lugege	doc_491521501673_item	2438509	et	3	main
head	doc_491521501673_item	2438518	et	4	main
algama	doc_491521501671_item	2438427	et	3	main
lõppema	doc_491521501671_item	2438429	et	4	main
lugege	doc_491521501672_item	2438448	et	3	main
teksti	doc_491521501672_item	2438450	et	4	main
kirjutage	doc_491521501672_item	2438452	et	3	main
soovin	doc_491521501672_item	2438455	et	3	main
teed	doc_491521501672_item	2438465	et	4	main
kuidas	doc_491521501672_item	2438466	et	3	main
lapsed	doc_491521501672_item	2438467	et	3	main
elavad	doc_491521501672_item	2438468	et	4	main
ja	doc_491521501672_item	2438469	et	3	main
millal	doc_491521501672_item	2438470	et	3	main
sõidad	doc_491521501672_item	2438471	et	3	main
kirjutage	doc_491521501672_item	2438473	et	3	main
vastus	doc_491521501672_item	2438474	et	3	main
20-25	doc_491521501672_item	2438475	et	2	main
sõnaga	doc_491521501672_item	2438476	et	3	main
ma	doc_491521501672_item	2438477	et	3	main
venemaale	doc_491521501672_item	2438472	et	4	main
töötan	doc_491521501672_item	2438478	et	3	main
koolus	doc_491521501672_item	2438479	et	4	main
ja	doc_491521501672_item	2438480	et	3	main
aias	doc_491521501672_item	2438481	et	4	main
märgin	doc_491521501672_item	2438482	et	3	main
lapsiga	doc_491521501672_item	2438483	et	4	main
lapsed	doc_491521501672_item	2438484	et	3	main
elavad	doc_491521501672_item	2438485	et	4	main
ja	doc_491521501672_item	2438487	et	3	main
ka	doc_491521501672_item	2438489	et	3	main
lapsidega	doc_491521501672_item	2438494	et	3	main
olin	doc_491521501672_item	2438497	et	3	main
me	doc_491521501672_item	2438500	et	4	main
päevatamine	doc_491521501672_item	2438503	et	4	main
sulle	doc_491521501673_item	2438517	et	3	main
puhkust	doc_491521501673_item	2438519	et	4	main
millal	doc_491521501673_item	2438531	et	3	main
20-25	doc_491521501673_item	2438536	et	2	main
kallis	doc_491521501673_item	2438539	et	4	main
mul	doc_491521501673_item	2438541	et	3	main
laheb	doc_491521501673_item	2438542	et	4	main
hästi	doc_491521501673_item	2438543	et	3	main
ma	doc_491521501673_item	2438544	et	3	main
töötan	doc_491521501673_item	2438545	et	3	main
rahvamajas	doc_491521501673_item	2438546	et	3	main
lapsed	doc_491521501673_item	2438547	et	3	main
on	doc_491521501673_item	2438563	et	4	main
sõidan	doc_491521501673_item	2438571	et	3	main
kuus	doc_491521501673_item	2438574	et	4	main
tere	doc_491521501674_item	2438609	et	3	main
kirijutan	doc_491521501674_item	2438611	et	4	main
minul	doc_491521501674_item	2438613	et	3	main
on	doc_491521501674_item	2438616	et	4	main
t	doc_491521501674_item	2438619	et	4	main
öötan	doc_491521501674_item	2438620	et	4	main
venemaale	doc_491521501673_item	2438533	et	4	main
sõnaga	doc_491521501673_item	2438537	et	3	main
ka	doc_491521501673_item	2438549	et	3	main
õppib	doc_491521501673_item	2438559	et	4	main
kuuendal	doc_491521501673_item	2438560	et	3	main
septembris	doc_491521501673_item	2438573	et	3	main
kõige	doc_491521501673_item	2438576	et	4	main
head	doc_491521501673_item	2438577	et	4	main
eesnimi	doc_491521501673_item	2438578	et	3	main
kiri	doc_491521501674_item	2438579	et	3	main
lugege	doc_491521501674_item	2438580	et	3	main
järgmist	doc_491521501674_item	2438581	et	3	main
teksti	doc_491521501674_item	2438582	et	4	main
ja	doc_491521501674_item	2438583	et	3	main
kirjutage	doc_491521501674_item	2438584	et	3	main
vastus	doc_491521501674_item	2438585	et	3	main
tere	doc_491521501674_item	2438586	et	3	main
soovin	doc_491521501674_item	2438587	et	3	main
sulle	doc_491521501674_item	2438588	et	3	main
head	doc_491521501674_item	2438589	et	4	main
puhkust	doc_491521501674_item	2438590	et	4	main
ootan	doc_491521501674_item	2438591	et	3	main
sind	doc_491521501674_item	2438592	et	4	main
endale	doc_491521501674_item	2438593	et	4	main
külla	doc_491521501674_item	2438594	et	4	main
kirjuta	doc_491521501674_item	2438595	et	4	main
mida	doc_491521501674_item	2438596	et	4	main
teed	doc_491521501674_item	2438597	et	4	main
kuidas	doc_491521501674_item	2438598	et	3	main
lapsed	doc_491521501674_item	2438599	et	3	main
elavad	doc_491521501674_item	2438600	et	4	main
ja	doc_491521501674_item	2438601	et	3	main
millal	doc_491521501674_item	2438602	et	3	main
sõidad	doc_491521501674_item	2438603	et	3	main
venemaale	doc_491521501674_item	2438604	et	4	main
kirjutage	doc_491521501674_item	2438605	et	3	main
vastus	doc_491521501674_item	2438606	et	3	main
aga	doc_491521501673_item	2438557	et	3	main
poeg	doc_491521501673_item	2438558	et	3	main
klassis	doc_491521501673_item	2438561	et	3	main
töölis	doc_491521501673_item	2438569	et	4	main
sõnaga	doc_491521501674_item	2438608	et	3	main
elavad	doc_491521501674_item	2438623	et	4	main
järgmist	doc_491521501676_item	2438702	et	3	main
sulle	doc_491521501676_item	2438709	et	3	main
ootan	doc_491521501676_item	2438712	et	3	main
kuidas	doc_491521501676_item	2438719	et	3	main
elavad	doc_491521501676_item	2438721	et	4	main
millal	doc_491521501676_item	2438723	et	3	main
venemaale	doc_491521501676_item	2438725	et	4	main
vastus	doc_491521501676_item	2438727	et	3	main
oltan	doc_491521501676_item	2438734	et	4	main
kui	doc_491521501676_item	2438736	et	3	main
eksamin	doc_491521501676_item	2438745	et	4	main
elavad	doc_491521501676_item	2438749	et	4	main
venemaale	doc_491521501676_item	2438751	et	4	main
me	doc_491521501676_item	2438752	et	4	main
kirjutage	doc_491521501677_item	2438760	et	3	main
tere	doc_491521501677_item	2438762	et	3	main
venemaale	doc_491521501677_item	2438780	et	4	main
minu	doc_491521501677_item	2438786	et	3	main
elavad	doc_491521501677_item	2438797	et	4	main
me	doc_491521501677_item	2438799	et	4	main
kino	doc_491521501677_item	2438802	et	4	main
töötan	doc_491521501677_item	2438807	et	3	main
sõidad	doc_491521501677_item	2438810	et	3	main
järgmist	doc_491521501678_item	2438815	et	3	main
soovin	doc_491521501678_item	2438821	et	3	main
kirjuta	doc_491521501678_item	2438829	et	4	main
ja	doc_491521501678_item	2438835	et	3	main
vastus	doc_491521501678_item	2438840	et	3	main
sõnaga	doc_491521501678_item	2438842	et	3	main
elame	doc_491521501678_item	2438844	et	3	main
on	doc_491521501678_item	2438847	et	4	main
päike	doc_491521501678_item	2438849	et	3	main
paistab	doc_491521501678_item	2438850	et	3	main
ja	doc_491521501678_item	2438851	et	3	main
on	doc_491521501678_item	2438852	et	4	main
seeni	doc_491521501678_item	2438866	et	3	main
puhkame	doc_491521501678_item	2438868	et	3	main
me	doc_491521501678_item	2438871	et	4	main
sõnaga	doc_491521501679_item	2438917	et	3	main
mina	doc_491521501674_item	2438618	et	4	main
mina	doc_491521501674_item	2438622	et	4	main
venemaa	doc_491521501674_item	2438628	et	4	main
kirjutage	doc_491521501676_item	2438705	et	3	main
puhkust	doc_491521501676_item	2438711	et	4	main
külla	doc_491521501676_item	2438715	et	4	main
ja	doc_491521501676_item	2438722	et	3	main
aitah	doc_491521501676_item	2438731	et	4	main
eesti	doc_491521501676_item	2438746	et	4	main
sõidame	doc_491521501676_item	2438754	et	3	main
lugege	doc_491521501677_item	2438756	et	3	main
head	doc_491521501677_item	2438765	et	4	main
ootan	doc_491521501677_item	2438767	et	3	main
endale	doc_491521501677_item	2438769	et	4	main
külla	doc_491521501677_item	2438770	et	4	main
lapsed	doc_491521501677_item	2438775	et	3	main
ja	doc_491521501677_item	2438777	et	3	main
20-25	doc_491521501677_item	2438783	et	2	main
kõige	doc_491521501677_item	2438787	et	4	main
elan	doc_491521501677_item	2438791	et	3	main
lapsed	doc_491521501677_item	2438793	et	3	main
abikaasa	doc_491521501677_item	2438806	et	4	main
me	doc_491521501677_item	2438808	et	4	main
lugege	doc_491521501678_item	2438814	et	3	main
külla	doc_491521501678_item	2438828	et	4	main
millal	doc_491521501678_item	2438836	et	3	main
kirjutage	doc_491521501678_item	2438839	et	3	main
ilm	doc_491521501678_item	2438846	et	3	main
ümber	doc_491521501678_item	2438854	et	3	main
me	doc_491521501678_item	2438863	et	4	main
marju	doc_491521501678_item	2438865	et	3	main
me	doc_491521501678_item	2438867	et	4	main
hästi	doc_491521501678_item	2438870	et	3	main
endale	doc_491521501679_item	2438902	et	4	main
millal	doc_491521501679_item	2438911	et	3	main
kallis	doc_491521501679_item	2438919	et	4	main
tööta	doc_491521501679_item	2438927	et	4	main
metsas	doc_491521501679_item	2438931	et	3	main
laps	doc_491521501679_item	2438938	et	4	main
nr1	doc_491521501681_item	2439055	et	4	main
kirjuta	doc_491521501681_item	2439056	et	4	main
kus	doc_491521501681_item	2439061	et	3	main
sa	doc_491521501681_item	2439062	et	3	main
käisid	doc_491521501681_item	2439063	et	4	main
praktikal	doc_491521501681_item	2439064	et	3	main
tegid	doc_491521501681_item	2439069	et	4	main
nr2	doc_491521501681_item	2439080	et	4	main
täida	doc_491521501681_item	2439081	et	4	main
ankeet	doc_491521501681_item	2439082	et	3	main
nimi	doc_491521501681_item	2439083	et	3	main
niina	doc_491521501681_item	2439084	et	4	main
vanus	doc_491521501681_item	2439085	et	4	main
tehases	doc_491521501674_item	2438621	et	3	main
head	doc_491521501674_item	2438624	et	4	main
mina	doc_491521501674_item	2438625	et	4	main
kiri	doc_491521501676_item	2438700	et	3	main
ja	doc_491521501676_item	2438704	et	3	main
tere	doc_491521501676_item	2438707	et	3	main
endale	doc_491521501676_item	2438714	et	4	main
teed	doc_491521501676_item	2438718	et	4	main
lapsed	doc_491521501676_item	2438720	et	3	main
kirjutage	doc_491521501676_item	2438726	et	3	main
sõnaga	doc_491521501676_item	2438729	et	3	main
ma	doc_491521501676_item	2438732	et	3	main
juba	doc_491521501676_item	2438738	et	3	main
aeg	doc_491521501676_item	2438740	et	3	main
keel	doc_491521501676_item	2438747	et	4	main
lapsed	doc_491521501676_item	2438748	et	3	main
hasti	doc_491521501676_item	2438750	et	4	main
järgmist	doc_491521501677_item	2438757	et	3	main
soovin	doc_491521501677_item	2438763	et	3	main
puhkust	doc_491521501677_item	2438766	et	4	main
sind	doc_491521501677_item	2438768	et	4	main
kuidas	doc_491521501677_item	2438774	et	3	main
vastus	doc_491521501677_item	2438782	et	3	main
tere	doc_491521501677_item	2438785	et	3	main
sober	doc_491521501677_item	2438789	et	4	main
hasti	doc_491521501677_item	2438792	et	4	main
õpivad	doc_491521501677_item	2438795	et	3	main
hästi	doc_491521501677_item	2438798	et	3	main
tuleme	doc_491521501677_item	2438800	et	3	main
millal	doc_491521501677_item	2438809	et	3	main
sulle	doc_491521501678_item	2438822	et	3	main
puhkust	doc_491521501678_item	2438824	et	4	main
ootan	doc_491521501678_item	2438825	et	3	main
sind	doc_491521501678_item	2438826	et	4	main
teed	doc_491521501678_item	2438831	et	4	main
kuidas	doc_491521501678_item	2438832	et	3	main
lapsed	doc_491521501678_item	2438833	et	3	main
venemaale	doc_491521501678_item	2438838	et	4	main
20-25	doc_491521501678_item	2438841	et	2	main
metsad	doc_491521501678_item	2438857	et	3	main
korjutame	doc_491521501678_item	2438864	et	4	main
elame	doc_491521501678_item	2438872	et	3	main
mida	doc_491521501679_item	2438905	et	4	main
teed	doc_491521501679_item	2438906	et	4	main
kuidas	doc_491521501679_item	2438907	et	3	main
tere	doc_491521501679_item	2438918	et	3	main
ei	doc_491521501679_item	2438926	et	4	main
ma	doc_491521501679_item	2438928	et	3	main
tulen	doc_491521501679_item	2438929	et	3	main
metsas	doc_491521501679_item	2438930	et	3	main
on	doc_491521501679_item	2438932	et	4	main
väga	doc_491521501679_item	2438940	et	3	main
tutar	doc_491521501679_item	2438942	et	4	main
sõidad	doc_491521501676_item	2438724	et	3	main
20-25	doc_491521501676_item	2438728	et	2	main
puhkus	doc_491521501676_item	2438735	et	3	main
olid	doc_491521501676_item	2438737	et	4	main
vaba	doc_491521501676_item	2438739	et	4	main
me	doc_491521501676_item	2438741	et	4	main
tuleme	doc_491521501676_item	2438742	et	3	main
teile	doc_491521501676_item	2438743	et	4	main
ei	doc_491521501676_item	2438753	et	4	main
kiri	doc_491521501677_item	2438755	et	3	main
teksti	doc_491521501677_item	2438758	et	4	main
sulle	doc_491521501677_item	2438764	et	3	main
kirjutage	doc_491521501677_item	2438781	et	3	main
ma	doc_491521501677_item	2438790	et	3	main
teater	doc_491521501677_item	2438801	et	3	main
ja	doc_491521501677_item	2438803	et	3	main
spordisaal	doc_491521501677_item	2438804	et	3	main
minu	doc_491521501677_item	2438805	et	3	main
aprillis	doc_491521501677_item	2438812	et	3	main
teksti	doc_491521501678_item	2438816	et	4	main
kirjutage	doc_491521501678_item	2438818	et	3	main
ja	doc_491521501678_item	2438817	et	3	main
vastus	doc_491521501678_item	2438819	et	3	main
tere	doc_491521501678_item	2438820	et	3	main
ja	doc_491521501677_item	2438759	et	3	main
vastus	doc_491521501677_item	2438761	et	3	main
kirjuta	doc_491521501677_item	2438771	et	4	main
mida	doc_491521501677_item	2438772	et	4	main
teed	doc_491521501677_item	2438773	et	4	main
elavad	doc_491521501677_item	2438776	et	4	main
millal	doc_491521501677_item	2438778	et	3	main
sõidad	doc_491521501677_item	2438779	et	3	main
sõnaga	doc_491521501677_item	2438784	et	3	main
parem	doc_491521501677_item	2438788	et	4	main
tubli	doc_491521501677_item	2438794	et	4	main
ja	doc_491521501677_item	2438796	et	3	main
venemeeale	doc_491521501677_item	2438811	et	4	main
kiri	doc_491521501678_item	2438813	et	3	main
head	doc_491521501678_item	2438823	et	4	main
endale	doc_491521501678_item	2438827	et	4	main
elavad	doc_491521501678_item	2438834	et	4	main
hea	doc_491521501678_item	2438848	et	4	main
küla	doc_491521501678_item	2438855	et	4	main
olusad	doc_491521501678_item	2438856	et	4	main
kus	doc_491521501678_item	2438858	et	3	main
seeni	doc_491521501678_item	2438862	et	3	main
ääres	doc_491521501678_item	2438874	et	4	main
lapsed	doc_491521501679_item	2438908	et	3	main
ja	doc_491521501679_item	2438910	et	3	main
venemaale	doc_491521501679_item	2438913	et	4	main
kirjutage	doc_491521501679_item	2438914	et	3	main
vastus	doc_491521501679_item	2438915	et	3	main
sõbrana	doc_491521501679_item	2438920	et	3	main
ma	doc_491521501679_item	2438921	et	3	main
väga	doc_491521501679_item	2438923	et	3	main
ma	doc_491521501679_item	2438925	et	3	main
seeni	doc_491521501679_item	2438934	et	3	main
on	doc_491521501679_item	2438939	et	4	main
eesnimi	doc_491521501679_item	2438956	et	3	main
ülesanne	doc_491521501681_item	2439054	et	4	main
sa	doc_491521501681_item	2439066	et	3	main
päev	doc_491521501681_item	2439068	et	3	main
perekonnaseis	doc_491521501681_item	2439093	et	4	main
diplomi	doc_491521501681_item	2439099	et	3	main
aadress	doc_491521501681_item	2439103	et	3	main
salu	doc_491521501681_item	2439105	et	4	main
oü	doc_491521501681_item	2439113	et	4	main
torhocet	doc_491521501681_item	2439114	et	4	main
allkiri	doc_491521501681_item	2439120	et	3	main
oma	doc_491521501682_item	2439127	et	4	main
käisid	doc_491521501682_item	2439132	et	4	main
iga	doc_491521501682_item	2439136	et	4	main
päev	doc_491521501682_item	2439137	et	3	main
seal	doc_491521501682_item	2439146	et	4	main
täida	doc_491521501682_item	2439150	et	4	main
olga	doc_491521501682_item	2439153	et	4	main
venemaa	doc_491521501682_item	2439157	et	4	main
naine	doc_491521501682_item	2439159	et	3	main
kesk-eri	doc_491521501682_item	2439163	et	4	main
eriala	doc_491521501682_item	2439164	et	4	main
diplomi	doc_491521501682_item	2439165	et	3	main
kodune	doc_491521501682_item	2439168	et	4	main
mida	doc_491521501678_item	2438830	et	4	main
sõidad	doc_491521501678_item	2438837	et	3	main
me	doc_491521501678_item	2438843	et	4	main
hästi	doc_491521501678_item	2438845	et	3	main
sooe	doc_491521501678_item	2438853	et	4	main
palju	doc_491521501678_item	2438859	et	4	main
marju	doc_491521501678_item	2438860	et	3	main
ja	doc_491521501678_item	2438861	et	3	main
väga	doc_491521501678_item	2438869	et	3	main
jarve	doc_491521501678_item	2438873	et	4	main
jarve	doc_491521501678_item	2438875	et	4	main
kalal	doc_491521501678_item	2438876	et	3	main
me	doc_491521501678_item	2438877	et	4	main
päivitame	doc_491521501678_item	2438878	et	4	main
ja	doc_491521501678_item	2438879	et	3	main
supleme	doc_491521501678_item	2438880	et	3	main
lugeme	doc_491521501678_item	2438881	et	4	main
ramatuid	doc_491521501678_item	2438882	et	4	main
ma	doc_491521501678_item	2438883	et	3	main
töötan	doc_491521501678_item	2438885	et	3	main
natukene	doc_491521501678_item	2438884	et	4	main
aias	doc_491521501678_item	2438886	et	4	main
kodus	doc_491521501678_item	2438887	et	4	main
kiri	doc_491521501679_item	2438888	et	3	main
lugege	doc_491521501679_item	2438889	et	3	main
järgmist	doc_491521501679_item	2438890	et	3	main
teksti	doc_491521501679_item	2438891	et	4	main
ja	doc_491521501679_item	2438892	et	3	main
kirjutage	doc_491521501679_item	2438893	et	3	main
vastus	doc_491521501679_item	2438894	et	3	main
tere	doc_491521501679_item	2438895	et	3	main
soovin	doc_491521501679_item	2438896	et	3	main
sulle	doc_491521501679_item	2438897	et	3	main
head	doc_491521501679_item	2438898	et	4	main
puhkust	doc_491521501679_item	2438899	et	4	main
ootan	doc_491521501679_item	2438900	et	3	main
sind	doc_491521501679_item	2438901	et	4	main
külla	doc_491521501679_item	2438903	et	4	main
kirjuta	doc_491521501679_item	2438904	et	4	main
elavad	doc_491521501679_item	2438909	et	4	main
sõidad	doc_491521501679_item	2438912	et	3	main
20-25	doc_491521501679_item	2438916	et	2	main
elad	doc_491521501679_item	2438922	et	3	main
hästi	doc_491521501679_item	2438924	et	3	main
palju	doc_491521501679_item	2438933	et	4	main
marju	doc_491521501679_item	2438936	et	3	main
meil	doc_491521501679_item	2438948	et	4	main
sõidab	doc_491521501679_item	2438949	et	3	main
venemaal	doc_491521501679_item	2438950	et	4	main
juuni-juuli	doc_491521501679_item	2438951	et	4	main
2001	doc_491521501679_item	2438952	et	2	main
kõik	doc_491521501679_item	2438954	et	4	main
sõbrale	doc_491521501681_item	2439057	et	3	main
oma	doc_491521501681_item	2439058	et	4	main
kursuse	doc_491521501681_item	2439059	et	3	main
praktikast	doc_491521501681_item	2439060	et	4	main
sulle	doc_491521501681_item	2439071	et	3	main
meeldis	doc_491521501681_item	2439072	et	3	main
kas	doc_491521501681_item	2439074	et	3	main
tahaksid	doc_491521501681_item	2439076	et	4	main
töötada	doc_491521501681_item	2439078	et	3	main
a	doc_491521501681_item	2439087	et	4	main
jõhvi	doc_491521501681_item	2439090	et	4	main
sugu	doc_491521501681_item	2439091	et	4	main
naine	doc_491521501681_item	2439092	et	3	main
eriala	doc_491521501681_item	2439098	et	4	main
kodune	doc_491521501681_item	2439102	et	4	main
kohtla-järve	doc_491521501681_item	2439104	et	4	main
7-18	doc_491521501681_item	2439106	et	2	main
töökoht	doc_491521501681_item	2439107	et	3	main
töötu	doc_491521501681_item	2439108	et	4	main
kus	doc_491521501681_item	2439109	et	3	main
ankeedi	doc_491521501681_item	2439115	et	4	main
kuupäev	doc_491521501681_item	2439117	et	3	main
ülesanne	doc_491521501682_item	2439123	et	4	main
nr1	doc_491521501682_item	2439124	et	4	main
kirjuta	doc_491521501682_item	2439125	et	4	main
sõbrale	doc_491521501682_item	2439126	et	3	main
praktikal	doc_491521501682_item	2439133	et	3	main
sulle	doc_491521501682_item	2439140	et	3	main
seal	doc_491521501682_item	2439142	et	4	main
tahaksid	doc_491521501682_item	2439145	et	4	main
nr2	doc_491521501682_item	2439149	et	4	main
ankeet	doc_491521501682_item	2439151	et	3	main
haridus	doc_491521501682_item	2439162	et	3	main
aadress	doc_491521501682_item	2439169	et	3	main
narva	doc_491521501682_item	2439171	et	4	main
80-11	doc_491521501682_item	2439173	et	2	main
töökoht	doc_491521501682_item	2439174	et	3	main
allkiri	doc_491521501682_item	2439187	et	3	main
nagemiseni	doc_491521501682_item	2439188	et	4	main
ülesanne	doc_491521501683_item	2439191	et	4	main
19	doc_491521501683_item	2439223	et	2	main
järgi	doc_491521501683_item	2439234	et	4	main
õppisin	doc_491521501683_item	2439249	et	3	main
allkiri	doc_491521501683_item	2439255	et	3	main
ja	doc_491521501679_item	2438935	et	3	main
minu	doc_491521501679_item	2438937	et	3	main
hea	doc_491521501679_item	2438941	et	4	main
katja	doc_491521501679_item	2438943	et	4	main
õppima	doc_491521501679_item	2438944	et	3	main
gümnaasiums	doc_491521501679_item	2438945	et	4	main
neli	doc_491521501679_item	2438946	et	3	main
klassis	doc_491521501679_item	2438947	et	3	main
a	doc_491521501679_item	2438953	et	4	main
head	doc_491521501679_item	2438955	et	4	main
1	doc_491521501681_item	2439053	et	2	main
iga	doc_491521501681_item	2439067	et	4	main
sünnikoht	doc_491521501681_item	2439088	et	3	main
tehnikum	doc_491521501681_item	2439096	et	3	main
tehnoloog	doc_491521501681_item	2439101	et	4	main
varem	doc_491521501681_item	2439111	et	4	main
töötasite	doc_491521501681_item	2439112	et	3	main
allkiri	doc_491521501681_item	2439119	et	3	main
praktikast	doc_491521501682_item	2439129	et	4	main
tegid	doc_491521501682_item	2439138	et	4	main
kas	doc_491521501682_item	2439139	et	3	main
töötada	doc_491521501682_item	2439147	et	3	main
nimi	doc_491521501682_item	2439152	et	3	main
sünnikoht	doc_491521501682_item	2439156	et	3	main
järgi	doc_491521501682_item	2439166	et	4	main
te	doc_491521501682_item	2439177	et	4	main
töötasite	doc_491521501682_item	2439179	et	3	main
sompa2	doc_491521501682_item	2439180	et	4	main
29082003	doc_491521501682_item	2439185	et	2	main
1	doc_491521501683_item	2439190	et	2	main
aleksandra	doc_491521501683_item	2439221	et	4	main
sugu	doc_491521501683_item	2439226	et	4	main
müüja	doc_491521501683_item	2439235	et	4	main
aadress	doc_491521501683_item	2439237	et	3	main
37-34	doc_491521501683_item	2439240	et	2	main
varem	doc_491521501683_item	2439246	et	4	main
töötasite	doc_491521501683_item	2439247	et	3	main
ankeedi	doc_491521501683_item	2439250	et	4	main
täitmise	doc_491521501683_item	2439251	et	4	main
oma	doc_491521501684_item	2439262	et	4	main
seal	doc_491521501684_item	2439281	et	4	main
töötada	doc_491521501684_item	2439282	et	3	main
ülesanne	doc_491521501684_item	2439283	et	4	main
36	doc_491521501684_item	2439290	et	2	main
oma	doc_491521501685_item	2439328	et	4	main
kursuse	doc_491521501685_item	2439329	et	3	main
päev	doc_491521501685_item	2439338	et	3	main
kas	doc_491521501685_item	2439340	et	3	main
seal	doc_491521501685_item	2439343	et	4	main
sa	doc_491521501685_item	2439345	et	3	main
46	doc_491521501685_item	2439356	et	2	main
perekonnaseis	doc_491521501685_item	2439364	et	4	main
päev	doc_491521501686_item	2439409	et	3	main
meeldis	doc_491521501686_item	2439413	et	3	main
olesja	doc_491521501686_item	2439425	et	4	main
eriala	doc_491521501686_item	2439437	et	4	main
diplomi	doc_491521501686_item	2439438	et	3	main
jõhvi	doc_491521501686_item	2439443	et	4	main
narva	doc_491521501686_item	2439444	et	4	main
töötasite	doc_491521501686_item	2439452	et	3	main
kuupäev	doc_491521501686_item	2439456	et	3	main
allkiri	doc_491521501686_item	2439459	et	3	main
praktikast	doc_491521501687_item	2439468	et	4	main
kus	doc_491521501687_item	2439469	et	3	main
mida	doc_491521501687_item	2439473	et	4	main
iga	doc_491521501687_item	2439475	et	4	main
kalevi	doc_491521501687_item	2439511	et	3	main
töötu	doc_491521501687_item	2439514	et	4	main
nv	doc_491521501687_item	2439519	et	4	main
allkiri	doc_491521501687_item	2439525	et	3	main
oma	doc_491521501688_item	2439533	et	4	main
kursuse	doc_491521501688_item	2439534	et	3	main
ülesanne	doc_491521501681_item	2439052	et	4	main
mida	doc_491521501681_item	2439065	et	4	main
kas	doc_491521501681_item	2439070	et	3	main
seal	doc_491521501681_item	2439073	et	4	main
sa	doc_491521501681_item	2439075	et	3	main
seal	doc_491521501681_item	2439077	et	4	main
ülesanne	doc_491521501681_item	2439079	et	4	main
te	doc_491521501681_item	2439110	et	4	main
täitmise	doc_491521501681_item	2439116	et	4	main
290803	doc_491521501681_item	2439118	et	2	main
47	doc_491521501681_item	2439086	et	2	main
eesti	doc_491521501681_item	2439089	et	4	main
abielus	doc_491521501681_item	2439094	et	4	main
haridus	doc_491521501681_item	2439095	et	3	main
keemia	doc_491521501681_item	2439097	et	4	main
järgi	doc_491521501681_item	2439100	et	4	main
1	doc_491521501682_item	2439122	et	2	main
kus	doc_491521501682_item	2439130	et	3	main
mida	doc_491521501682_item	2439134	et	4	main
sa	doc_491521501682_item	2439135	et	3	main
kas	doc_491521501682_item	2439143	et	3	main
ülesanne	doc_491521501682_item	2439148	et	4	main
25061953	doc_491521501682_item	2439155	et	2	main
sugu	doc_491521501682_item	2439158	et	4	main
tehnik-tehnoloog	doc_491521501682_item	2439167	et	4	main
varem	doc_491521501682_item	2439178	et	4	main
kuupäev	doc_491521501682_item	2439184	et	3	main
pärna	doc_491521501683_item	2439239	et	4	main
töökoht	doc_491521501683_item	2439241	et	3	main
ei	doc_491521501683_item	2439242	et	4	main
ma	doc_491521501683_item	2439248	et	3	main
allkiri	doc_491521501683_item	2439254	et	3	main
kursuse	doc_491521501684_item	2439263	et	3	main
iga	doc_491521501684_item	2439271	et	4	main
kas	doc_491521501684_item	2439274	et	3	main
meeldis	doc_491521501684_item	2439276	et	3	main
kas	doc_491521501684_item	2439278	et	3	main
irina	doc_491521501684_item	2439288	et	3	main
ülesanne	doc_491521501682_item	2439121	et	4	main
kursuse	doc_491521501682_item	2439128	et	3	main
sa	doc_491521501682_item	2439131	et	3	main
meeldis	doc_491521501682_item	2439141	et	3	main
sa	doc_491521501682_item	2439144	et	3	main
vanus	doc_491521501682_item	2439154	et	4	main
perekonnaseis	doc_491521501682_item	2439160	et	4	main
lesk	doc_491521501682_item	2439161	et	3	main
jõhvi	doc_491521501682_item	2439170	et	4	main
mnt	doc_491521501682_item	2439172	et	4	main
töötatu	doc_491521501682_item	2439175	et	4	main
kus	doc_491521501682_item	2439176	et	3	main
kaevandus	doc_491521501682_item	2439181	et	4	main
allkiri	doc_491521501682_item	2439186	et	3	main
ülesanne	doc_491521501683_item	2439189	et	4	main
nr1	doc_491521501683_item	2439192	et	4	main
kirjuta	doc_491521501683_item	2439193	et	4	main
sõbrale	doc_491521501683_item	2439194	et	3	main
oma	doc_491521501683_item	2439195	et	4	main
kursuse	doc_491521501683_item	2439196	et	3	main
praktikast	doc_491521501683_item	2439197	et	4	main
kus	doc_491521501683_item	2439198	et	3	main
sa	doc_491521501683_item	2439199	et	3	main
käisid	doc_491521501683_item	2439200	et	4	main
praktikal	doc_491521501683_item	2439201	et	3	main
mida	doc_491521501683_item	2439202	et	4	main
sa	doc_491521501683_item	2439203	et	3	main
iga	doc_491521501683_item	2439204	et	4	main
päev	doc_491521501683_item	2439205	et	3	main
tegid	doc_491521501683_item	2439206	et	4	main
kas	doc_491521501683_item	2439207	et	3	main
sulle	doc_491521501683_item	2439208	et	3	main
meeldis	doc_491521501683_item	2439209	et	3	main
seal	doc_491521501683_item	2439210	et	4	main
kas	doc_491521501683_item	2439211	et	3	main
sa	doc_491521501683_item	2439212	et	3	main
tahaksid	doc_491521501683_item	2439213	et	4	main
seal	doc_491521501683_item	2439214	et	4	main
töötada	doc_491521501683_item	2439215	et	3	main
ülesanne	doc_491521501683_item	2439216	et	4	main
nr2	doc_491521501683_item	2439217	et	4	main
ankeet	doc_491521501683_item	2439219	et	3	main
täida	doc_491521501683_item	2439218	et	4	main
nimi	doc_491521501683_item	2439220	et	3	main
naine	doc_491521501683_item	2439227	et	3	main
perekonnaseis	doc_491521501683_item	2439228	et	4	main
valaline	doc_491521501683_item	2439229	et	4	main
haridus	doc_491521501683_item	2439230	et	3	main
kesktase	doc_491521501683_item	2439231	et	3	main
eriala	doc_491521501683_item	2439232	et	4	main
kodune	doc_491521501683_item	2439236	et	4	main
kohtla-järve	doc_491521501683_item	2439238	et	4	main
tööta	doc_491521501683_item	2439243	et	4	main
kus	doc_491521501683_item	2439244	et	3	main
ankeedi	doc_491521501682_item	2439182	et	4	main
täitmise	doc_491521501682_item	2439183	et	4	main
vanus	doc_491521501683_item	2439222	et	4	main
sünnikoht	doc_491521501683_item	2439224	et	3	main
kohtla-järve	doc_491521501683_item	2439225	et	4	main
diplomi	doc_491521501683_item	2439233	et	3	main
te	doc_491521501683_item	2439245	et	4	main
290803	doc_491521501683_item	2439253	et	2	main
ülesanne	doc_491521501684_item	2439256	et	4	main
praktikast	doc_491521501684_item	2439264	et	4	main
kus	doc_491521501684_item	2439265	et	3	main
sa	doc_491521501684_item	2439266	et	3	main
käisid	doc_491521501684_item	2439267	et	4	main
praktikal	doc_491521501684_item	2439268	et	3	main
mida	doc_491521501684_item	2439269	et	4	main
tegid	doc_491521501684_item	2439273	et	4	main
sulle	doc_491521501684_item	2439275	et	3	main
tahaksid	doc_491521501684_item	2439280	et	4	main
venemaa	doc_491521501684_item	2439292	et	4	main
naine	doc_491521501684_item	2439294	et	3	main
abielus	doc_491521501684_item	2439296	et	4	main
haridus	doc_491521501684_item	2439297	et	3	main
kesk-	doc_491521501684_item	2439298	et	3	main
eriala	doc_491521501684_item	2439299	et	4	main
diplomi	doc_491521501684_item	2439300	et	3	main
järgi	doc_491521501684_item	2439301	et	4	main
kodune	doc_491521501684_item	2439302	et	4	main
aadress	doc_491521501684_item	2439303	et	3	main
maleva	doc_491521501684_item	2439304	et	3	main
15-26	doc_491521501684_item	2439305	et	2	main
kohtla-järve	doc_491521501684_item	2439306	et	4	main
töökoht	doc_491521501684_item	2439307	et	3	main
töötu	doc_491521501684_item	2439308	et	4	main
kus	doc_491521501684_item	2439309	et	3	main
te	doc_491521501684_item	2439310	et	4	main
varem	doc_491521501684_item	2439311	et	4	main
töötasite	doc_491521501684_item	2439312	et	3	main
as	doc_491521501684_item	2439313	et	4	main
balti	doc_491521501684_item	2439314	et	3	main
uniform	doc_491521501684_item	2439315	et	4	main
ankeedi	doc_491521501684_item	2439316	et	4	main
täitmise	doc_491521501684_item	2439317	et	4	main
kuupäev	doc_491521501684_item	2439318	et	3	main
290803	doc_491521501684_item	2439319	et	2	main
allkiri	doc_491521501684_item	2439320	et	3	main
allkiri	doc_491521501684_item	2439321	et	3	main
sa	doc_491521501685_item	2439336	et	3	main
tegid	doc_491521501685_item	2439339	et	4	main
sulle	doc_491521501685_item	2439341	et	3	main
nr2	doc_491521501685_item	2439350	et	4	main
vanus	doc_491521501685_item	2439355	et	4	main
sünnikoht	doc_491521501685_item	2439358	et	3	main
abielus	doc_491521501685_item	2439365	et	4	main
haridus	doc_491521501685_item	2439366	et	3	main
tehnik	doc_491521501685_item	2439372	et	3	main
iga	doc_491521501686_item	2439408	et	4	main
seal	doc_491521501686_item	2439418	et	4	main
töötada	doc_491521501686_item	2439419	et	3	main
täida	doc_491521501686_item	2439422	et	4	main
nimi	doc_491521501686_item	2439424	et	3	main
vanus	doc_491521501686_item	2439426	et	4	main
aastat	doc_491521501686_item	2439428	et	3	main
kuupäev	doc_491521501683_item	2439252	et	3	main
ülesanne	doc_491521501684_item	2439258	et	4	main
nr1	doc_491521501684_item	2439259	et	4	main
päev	doc_491521501684_item	2439272	et	3	main
seal	doc_491521501684_item	2439277	et	4	main
sa	doc_491521501684_item	2439279	et	3	main
täida	doc_491521501684_item	2439285	et	4	main
ankeet	doc_491521501684_item	2439286	et	3	main
nimi	doc_491521501684_item	2439287	et	3	main
vanus	doc_491521501684_item	2439289	et	4	main
sugu	doc_491521501684_item	2439293	et	4	main
perekonnaseis	doc_491521501684_item	2439295	et	4	main
ülesanne	doc_491521501685_item	2439324	et	4	main
käisid	doc_491521501685_item	2439333	et	4	main
praktikal	doc_491521501685_item	2439334	et	3	main
ülesanne	doc_491521501685_item	2439349	et	4	main
ida	doc_491521501685_item	2439359	et	4	main
kohtla-järve	doc_491521501685_item	2439361	et	4	main
sugu	doc_491521501685_item	2439362	et	4	main
naine	doc_491521501685_item	2439363	et	3	main
tehnoloog	doc_491521501685_item	2439373	et	4	main
kus	doc_491521501686_item	2439402	et	3	main
sa	doc_491521501686_item	2439403	et	3	main
tegid	doc_491521501686_item	2439410	et	4	main
kas	doc_491521501686_item	2439415	et	3	main
tahaksid	doc_491521501686_item	2439417	et	4	main
ülesanne	doc_491521501686_item	2439420	et	4	main
nr2	doc_491521501686_item	2439421	et	4	main
ankeet	doc_491521501686_item	2439423	et	3	main
kesk	doc_491521501686_item	2439436	et	3	main
järgi	doc_491521501686_item	2439439	et	4	main
40-20	doc_491521501686_item	2439446	et	2	main
töökoht	doc_491521501686_item	2439447	et	3	main
töötu	doc_491521501686_item	2439448	et	4	main
õpisin	doc_491521501686_item	2439453	et	4	main
290803	doc_491521501686_item	2439457	et	2	main
allkiri	doc_491521501686_item	2439458	et	3	main
ülesanne	doc_491521501687_item	2439460	et	4	main
ülesanne	doc_491521501687_item	2439462	et	4	main
praktikal	doc_491521501687_item	2439472	et	3	main
keskus	doc_491521501687_item	2439520	et	3	main
täitmise	doc_491521501687_item	2439522	et	4	main
1	doc_491521501688_item	2439528	et	2	main
nr1	doc_491521501688_item	2439530	et	4	main
kirjuta	doc_491521501688_item	2439531	et	4	main
sõbrale	doc_491521501688_item	2439532	et	3	main
sa	doc_491521501688_item	2439541	et	3	main
kas	doc_491521501688_item	2439545	et	3	main
nr2	doc_491521501688_item	2439555	et	4	main
vanus	doc_491521501688_item	2439560	et	4	main
eriala	doc_491521501688_item	2439570	et	4	main
diplomi	doc_491521501688_item	2439571	et	3	main
täida	doc_491521501689_item	2439624	et	4	main
svetlana	doc_491521501689_item	2439627	et	4	main
perekonnaseis	doc_491521501689_item	2439635	et	4	main
olevi	doc_491521501689_item	2439645	et	4	main
16-26	doc_491521501689_item	2439646	et	2	main
ei	doc_491521501689_item	2439649	et	4	main
te	doc_491521501689_item	2439652	et	4	main
töötasite	doc_491521501689_item	2439654	et	3	main
mida	doc_491521501690_item	2439675	et	4	main
kas	doc_491521501690_item	2439684	et	3	main
nr2	doc_491521501690_item	2439690	et	4	main
ankeet	doc_491521501690_item	2439692	et	3	main
kauplus	doc_491521501690_item	2439721	et	3	main
kuupäev	doc_491521501690_item	2439724	et	3	main
allkiri	doc_491521501690_item	2439726	et	3	main
allkiri	doc_491521501690_item	2439727	et	3	main
ülesanne	doc_491521501691_item	2439728	et	4	main
1	doc_491521501691_item	2439729	et	2	main
ülesanne	doc_491521501691_item	2439730	et	4	main
oma	doc_491521501691_item	2439734	et	4	main
praktikast	doc_491521501691_item	2439736	et	4	main
käisid	doc_491521501691_item	2439739	et	4	main
praktikal	doc_491521501691_item	2439740	et	3	main
mida	doc_491521501691_item	2439741	et	4	main
sa	doc_491521501691_item	2439742	et	3	main
iga	doc_491521501691_item	2439743	et	4	main
päev	doc_491521501691_item	2439744	et	3	main
sa	doc_491521501691_item	2439751	et	3	main
töötada	doc_491521501691_item	2439754	et	3	main
1	doc_491521501684_item	2439257	et	2	main
kirjuta	doc_491521501684_item	2439260	et	4	main
sõbrale	doc_491521501684_item	2439261	et	3	main
sa	doc_491521501684_item	2439270	et	3	main
nr2	doc_491521501684_item	2439284	et	4	main
sünnikoht	doc_491521501684_item	2439291	et	3	main
ülesanne	doc_491521501685_item	2439322	et	4	main
nr1	doc_491521501685_item	2439325	et	4	main
kirjuta	doc_491521501685_item	2439326	et	4	main
sõbrale	doc_491521501685_item	2439327	et	3	main
mida	doc_491521501685_item	2439335	et	4	main
meeldis	doc_491521501685_item	2439342	et	3	main
kas	doc_491521501685_item	2439344	et	3	main
tahaksid	doc_491521501685_item	2439346	et	4	main
seal	doc_491521501685_item	2439347	et	4	main
töötada	doc_491521501685_item	2439348	et	3	main
linda	doc_491521501685_item	2439354	et	4	main
virumaa	doc_491521501685_item	2439360	et	4	main
eri	doc_491521501685_item	2439368	et	4	main
eriala	doc_491521501685_item	2439369	et	4	main
diplomi	doc_491521501685_item	2439370	et	3	main
järgi	doc_491521501685_item	2439371	et	4	main
kodune	doc_491521501685_item	2439374	et	4	main
sulle	doc_491521501686_item	2439412	et	3	main
1	doc_491521501685_item	2439323	et	2	main
praktikast	doc_491521501685_item	2439330	et	4	main
kus	doc_491521501685_item	2439331	et	3	main
sa	doc_491521501685_item	2439332	et	3	main
iga	doc_491521501685_item	2439337	et	4	main
täida	doc_491521501685_item	2439351	et	4	main
ankeet	doc_491521501685_item	2439352	et	3	main
nimi	doc_491521501685_item	2439353	et	3	main
a	doc_491521501685_item	2439357	et	4	main
kesk	doc_491521501685_item	2439367	et	3	main
aadress	doc_491521501685_item	2439375	et	3	main
aru	doc_491521501685_item	2439376	et	4	main
7-12	doc_491521501685_item	2439377	et	2	main
töökoht	doc_491521501685_item	2439378	et	3	main
töötatu	doc_491521501685_item	2439379	et	4	main
kus	doc_491521501685_item	2439380	et	3	main
te	doc_491521501685_item	2439381	et	4	main
varem	doc_491521501685_item	2439382	et	4	main
töötasite	doc_491521501685_item	2439383	et	3	main
as	doc_491521501685_item	2439384	et	4	main
viru	doc_491521501685_item	2439385	et	4	main
kommunnalteenustes	doc_491521501685_item	2439386	et	4	main
ankeedi	doc_491521501685_item	2439387	et	4	main
täitmise	doc_491521501685_item	2439388	et	4	main
kuupäev	doc_491521501685_item	2439389	et	3	main
290803	doc_491521501685_item	2439390	et	2	main
allkiri	doc_491521501685_item	2439391	et	3	main
allkiri	doc_491521501685_item	2439392	et	3	main
ülesanne	doc_491521501686_item	2439393	et	4	main
1	doc_491521501686_item	2439394	et	2	main
ülesanne	doc_491521501686_item	2439395	et	4	main
nr1	doc_491521501686_item	2439396	et	4	main
kirjuta	doc_491521501686_item	2439397	et	4	main
sõbrale	doc_491521501686_item	2439398	et	3	main
oma	doc_491521501686_item	2439399	et	4	main
kursuse	doc_491521501686_item	2439400	et	3	main
praktikast	doc_491521501686_item	2439401	et	4	main
käisid	doc_491521501686_item	2439404	et	4	main
praktikal	doc_491521501686_item	2439405	et	3	main
mida	doc_491521501686_item	2439406	et	4	main
sa	doc_491521501686_item	2439407	et	3	main
kas	doc_491521501686_item	2439411	et	3	main
seal	doc_491521501686_item	2439414	et	4	main
sa	doc_491521501686_item	2439416	et	3	main
21	doc_491521501686_item	2439427	et	2	main
kohtla-järve	doc_491521501686_item	2439430	et	4	main
sugu	doc_491521501686_item	2439431	et	4	main
naine	doc_491521501686_item	2439432	et	3	main
perekonnaseis	doc_491521501686_item	2439433	et	4	main
kodumajandus	doc_491521501686_item	2439440	et	3	main
te	doc_491521501686_item	2439450	et	4	main
varem	doc_491521501686_item	2439451	et	4	main
täitmise	doc_491521501686_item	2439455	et	4	main
oma	doc_491521501687_item	2439466	et	4	main
kursuse	doc_491521501687_item	2439467	et	3	main
töökoht	doc_491521501687_item	2439513	et	3	main
vabaabielus	doc_491521501686_item	2439434	et	4	main
mnt	doc_491521501686_item	2439445	et	4	main
ankeedi	doc_491521501686_item	2439454	et	4	main
1	doc_491521501687_item	2439461	et	2	main
kirjuta	doc_491521501687_item	2439464	et	4	main
sõbrale	doc_491521501687_item	2439465	et	3	main
käisid	doc_491521501687_item	2439471	et	4	main
sa	doc_491521501687_item	2439474	et	3	main
päev	doc_491521501687_item	2439476	et	3	main
sulle	doc_491521501687_item	2439479	et	3	main
meeldis	doc_491521501687_item	2439480	et	3	main
seal	doc_491521501687_item	2439481	et	4	main
kas	doc_491521501687_item	2439482	et	3	main
sa	doc_491521501687_item	2439483	et	3	main
tahaksid	doc_491521501687_item	2439484	et	4	main
seal	doc_491521501687_item	2439485	et	4	main
töötada	doc_491521501687_item	2439486	et	3	main
ülesanne	doc_491521501687_item	2439487	et	4	main
nr2	doc_491521501687_item	2439488	et	4	main
täida	doc_491521501687_item	2439489	et	4	main
ankeet	doc_491521501687_item	2439490	et	3	main
nimi	doc_491521501687_item	2439491	et	3	main
maria	doc_491521501687_item	2439492	et	4	main
21	doc_491521501687_item	2439494	et	2	main
a	doc_491521501687_item	2439495	et	4	main
3051982	doc_491521501687_item	2439496	et	2	main
sünnikoht	doc_491521501687_item	2439497	et	3	main
eesti	doc_491521501687_item	2439498	et	4	main
vanus	doc_491521501687_item	2439493	et	4	main
sugu	doc_491521501687_item	2439499	et	4	main
neine	doc_491521501687_item	2439500	et	4	main
perekonnaseis	doc_491521501687_item	2439501	et	4	main
vallaline	doc_491521501687_item	2439502	et	4	main
haridus	doc_491521501687_item	2439503	et	3	main
kesk-eri	doc_491521501687_item	2439504	et	4	main
eriala	doc_491521501687_item	2439505	et	4	main
diplomi	doc_491521501687_item	2439506	et	3	main
järgi	doc_491521501687_item	2439507	et	4	main
kodumajandus	doc_491521501687_item	2439508	et	3	main
kodune	doc_491521501687_item	2439509	et	4	main
sünnikoht	doc_491521501686_item	2439429	et	3	main
haridus	doc_491521501686_item	2439435	et	3	main
kodune	doc_491521501686_item	2439441	et	4	main
aadress	doc_491521501686_item	2439442	et	3	main
kus	doc_491521501686_item	2439449	et	3	main
nr1	doc_491521501687_item	2439463	et	4	main
sa	doc_491521501687_item	2439470	et	3	main
tegid	doc_491521501687_item	2439477	et	4	main
kas	doc_491521501687_item	2439478	et	3	main
19-1	doc_491521501687_item	2439512	et	2	main
te	doc_491521501687_item	2439516	et	4	main
töötasite	doc_491521501687_item	2439518	et	3	main
ankeedi	doc_491521501687_item	2439521	et	4	main
ülesanne	doc_491521501688_item	2439529	et	4	main
päev	doc_491521501688_item	2439543	et	3	main
sulle	doc_491521501688_item	2439546	et	3	main
seal	doc_491521501688_item	2439548	et	4	main
tahaksid	doc_491521501688_item	2439551	et	4	main
seal	doc_491521501688_item	2439552	et	4	main
töötada	doc_491521501688_item	2439553	et	3	main
jelena	doc_491521501688_item	2439559	et	4	main
kesk	doc_491521501688_item	2439569	et	3	main
küla	doc_491521501688_item	2439577	et	4	main
9-11	doc_491521501688_item	2439578	et	2	main
jõhvi	doc_491521501688_item	2439579	et	4	main
vald	doc_491521501688_item	2439580	et	3	main
töökoht	doc_491521501688_item	2439581	et	3	main
ei	doc_491521501688_item	2439582	et	4	main
seal	doc_491521501689_item	2439620	et	4	main
ankeet	doc_491521501689_item	2439625	et	3	main
haridus	doc_491521501689_item	2439637	et	3	main
diplomi	doc_491521501689_item	2439640	et	3	main
järgi	doc_491521501689_item	2439641	et	4	main
tööta	doc_491521501689_item	2439650	et	4	main
kus	doc_491521501689_item	2439651	et	3	main
kohtla-järvel	doc_491521501689_item	2439655	et	4	main
ankeedi	doc_491521501689_item	2439656	et	4	main
nr1	doc_491521501690_item	2439665	et	4	main
sa	doc_491521501690_item	2439672	et	3	main
tahaksid	doc_491521501690_item	2439686	et	4	main
töötada	doc_491521501690_item	2439688	et	3	main
aadress	doc_491521501687_item	2439510	et	3	main
kus	doc_491521501687_item	2439515	et	3	main
varem	doc_491521501687_item	2439517	et	4	main
290803	doc_491521501687_item	2439524	et	2	main
ülesanne	doc_491521501688_item	2439527	et	4	main
kas	doc_491521501688_item	2439549	et	3	main
täida	doc_491521501688_item	2439556	et	4	main
ankeet	doc_491521501688_item	2439557	et	3	main
kohtla-jarvel	doc_491521501688_item	2439563	et	4	main
naine	doc_491521501688_item	2439565	et	3	main
perekonnaseis	doc_491521501688_item	2439566	et	4	main
abielus	doc_491521501688_item	2439567	et	4	main
ei	doc_491521501688_item	2439573	et	4	main
kodune	doc_491521501688_item	2439574	et	4	main
tööta	doc_491521501688_item	2439583	et	4	main
kas	doc_491521501689_item	2439617	et	3	main
sa	doc_491521501689_item	2439618	et	3	main
nr2	doc_491521501689_item	2439623	et	4	main
nimi	doc_491521501689_item	2439626	et	3	main
vanus	doc_491521501689_item	2439628	et	4	main
a	doc_491521501689_item	2439630	et	4	main
sünnikoht	doc_491521501689_item	2439631	et	3	main
tehnik-tehnoloog	doc_491521501689_item	2439642	et	4	main
kodune	doc_491521501689_item	2439643	et	4	main
aadress	doc_491521501689_item	2439644	et	3	main
täitmise	doc_491521501689_item	2439657	et	4	main
290803	doc_491521501689_item	2439659	et	2	main
1	doc_491521501690_item	2439663	et	2	main
sõbrale	doc_491521501690_item	2439667	et	3	main
iga	doc_491521501690_item	2439677	et	4	main
sa	doc_491521501690_item	2439685	et	3	main
ülesanne	doc_491521501690_item	2439689	et	4	main
täida	doc_491521501690_item	2439691	et	4	main
nr1	doc_491521501691_item	2439731	et	4	main
sa	doc_491521501691_item	2439738	et	3	main
sulle	doc_491521501691_item	2439747	et	3	main
tahaksid	doc_491521501691_item	2439752	et	4	main
290803	doc_491521501691_item	2439792	et	2	main
1	doc_491521501692_item	2439796	et	2	main
kirjuta	doc_491521501692_item	2439799	et	4	main
sõbrale	doc_491521501692_item	2439800	et	3	main
praktikast	doc_491521501692_item	2439803	et	4	main
sa	doc_491521501692_item	2439805	et	3	main
mida	doc_491521501692_item	2439808	et	4	main
tegid	doc_491521501692_item	2439812	et	4	main
ülesanne	doc_491521501692_item	2439822	et	4	main
täida	doc_491521501692_item	2439824	et	4	main
sugu	doc_491521501692_item	2439833	et	4	main
naine	doc_491521501692_item	2439834	et	3	main
perekonnaseis	doc_491521501692_item	2439835	et	4	main
eri	doc_491521501692_item	2439839	et	4	main
järgi	doc_491521501692_item	2439842	et	4	main
meditsinikool	doc_491521501692_item	2439844	et	4	main
kohtla-järve	doc_491521501692_item	2439849	et	4	main
töötasite	doc_491521501692_item	2439855	et	3	main
nr1	doc_491521501693_item	2439867	et	4	main
seal	doc_491521501693_item	2439889	et	4	main
perekonnaseis	doc_491521501693_item	2439906	et	4	main
abielus	doc_491521501693_item	2439907	et	4	main
kohtla-järve	doc_491521501693_item	2439917	et	4	main
töökoht	doc_491521501693_item	2439918	et	3	main
töötu	doc_491521501693_item	2439919	et	4	main
kus	doc_491521501693_item	2439920	et	3	main
te	doc_491521501693_item	2439921	et	4	main
viru	doc_491521501693_item	2439924	et	4	main
kirjuta	doc_491521501694_item	2439938	et	4	main
praktikast	doc_491521501694_item	2439942	et	4	main
kus	doc_491521501694_item	2439943	et	3	main
sulle	doc_491521501694_item	2439953	et	3	main
sugu	doc_491521501694_item	2439971	et	4	main
müüja	doc_491521501694_item	2439981	et	4	main
sugu	doc_491521501695_item	2440015	et	4	main
lõpputunnistus	doc_491521501695_item	2440024	et	4	main
töökoht	doc_491521501695_item	2440032	et	3	main
täitmise	doc_491521501695_item	2440041	et	4	main
290803	doc_491521501695_item	2440043	et	2	main
a	doc_491521501695_item	2440044	et	4	main
allkiri	doc_491521501695_item	2440045	et	3	main
allkiri	doc_491521501695_item	2440046	et	3	main
ülesanne	doc_491521501696_item	2440049	et	4	main
sõbrale	doc_491521501696_item	2440052	et	3	main
kuupäev	doc_491521501687_item	2439523	et	3	main
allkiri	doc_491521501687_item	2439526	et	3	main
sa	doc_491521501688_item	2439537	et	3	main
käisid	doc_491521501688_item	2439538	et	4	main
praktikal	doc_491521501688_item	2439539	et	3	main
mida	doc_491521501688_item	2439540	et	4	main
tegid	doc_491521501688_item	2439544	et	4	main
sa	doc_491521501688_item	2439550	et	3	main
nimi	doc_491521501688_item	2439558	et	3	main
sünnikoht	doc_491521501688_item	2439562	et	3	main
sugu	doc_491521501688_item	2439564	et	4	main
haridus	doc_491521501688_item	2439568	et	3	main
kus	doc_491521501688_item	2439584	et	3	main
te	doc_491521501688_item	2439585	et	4	main
varem	doc_491521501688_item	2439586	et	4	main
töötasite	doc_491521501688_item	2439587	et	3	main
õpetaja	doc_491521501688_item	2439588	et	4	main
ankeedi	doc_491521501688_item	2439589	et	4	main
täitmise	doc_491521501688_item	2439590	et	4	main
kuupäev	doc_491521501688_item	2439591	et	3	main
290803	doc_491521501688_item	2439592	et	2	main
allkiri	doc_491521501688_item	2439593	et	3	main
allkiri	doc_491521501688_item	2439594	et	3	main
ülesanne	doc_491521501689_item	2439595	et	4	main
1	doc_491521501689_item	2439596	et	2	main
ülesanne	doc_491521501689_item	2439597	et	4	main
nr1	doc_491521501689_item	2439598	et	4	main
kirjuta	doc_491521501689_item	2439599	et	4	main
sõbrale	doc_491521501689_item	2439600	et	3	main
oma	doc_491521501689_item	2439601	et	4	main
kursuse	doc_491521501689_item	2439602	et	3	main
praktikast	doc_491521501689_item	2439603	et	4	main
kus	doc_491521501689_item	2439604	et	3	main
sa	doc_491521501689_item	2439605	et	3	main
käisid	doc_491521501689_item	2439606	et	4	main
praktikal	doc_491521501689_item	2439607	et	3	main
mida	doc_491521501689_item	2439608	et	4	main
sa	doc_491521501689_item	2439609	et	3	main
iga	doc_491521501689_item	2439610	et	4	main
päev	doc_491521501689_item	2439611	et	3	main
tegid	doc_491521501689_item	2439612	et	4	main
kas	doc_491521501689_item	2439613	et	3	main
sulle	doc_491521501689_item	2439614	et	3	main
meeldis	doc_491521501689_item	2439615	et	3	main
seal	doc_491521501689_item	2439616	et	4	main
praktikast	doc_491521501688_item	2439535	et	4	main
kus	doc_491521501688_item	2439536	et	3	main
iga	doc_491521501688_item	2439542	et	4	main
meeldis	doc_491521501688_item	2439547	et	3	main
ülesanne	doc_491521501688_item	2439554	et	4	main
27	doc_491521501688_item	2439561	et	2	main
järgi	doc_491521501688_item	2439572	et	4	main
aadress	doc_491521501688_item	2439575	et	3	main
jõhvi	doc_491521501688_item	2439576	et	4	main
tahaksid	doc_491521501689_item	2439619	et	4	main
töötada	doc_491521501689_item	2439621	et	3	main
40	doc_491521501689_item	2439629	et	2	main
kasahstan	doc_491521501689_item	2439632	et	4	main
abielus	doc_491521501689_item	2439636	et	4	main
eriala	doc_491521501689_item	2439639	et	4	main
töökoht	doc_491521501689_item	2439648	et	3	main
kuupäev	doc_491521501689_item	2439658	et	3	main
allkiri	doc_491521501689_item	2439661	et	3	main
kirjuta	doc_491521501690_item	2439666	et	4	main
kursuse	doc_491521501690_item	2439669	et	3	main
kus	doc_491521501690_item	2439671	et	3	main
käisid	doc_491521501690_item	2439673	et	4	main
praktikal	doc_491521501690_item	2439674	et	3	main
sa	doc_491521501690_item	2439676	et	3	main
päev	doc_491521501690_item	2439678	et	3	main
tegid	doc_491521501690_item	2439679	et	4	main
kas	doc_491521501690_item	2439680	et	3	main
sulle	doc_491521501690_item	2439681	et	3	main
meeldis	doc_491521501690_item	2439682	et	3	main
seal	doc_491521501690_item	2439687	et	4	main
sõbrale	doc_491521501691_item	2439733	et	3	main
kas	doc_491521501691_item	2439746	et	3	main
meeldis	doc_491521501691_item	2439748	et	3	main
tanja	doc_491521501691_item	2439760	et	4	main
ei	doc_491521501691_item	2439782	et	4	main
abc	doc_491521501691_item	2439788	et	4	main
ankeedi	doc_491521501691_item	2439789	et	4	main
allkiri	doc_491521501691_item	2439794	et	3	main
ülesanne	doc_491521501692_item	2439797	et	4	main
nr1	doc_491521501692_item	2439798	et	4	main
seal	doc_491521501692_item	2439816	et	4	main
kas	doc_491521501692_item	2439817	et	3	main
tahaksid	doc_491521501692_item	2439819	et	4	main
ülesanne	doc_491521501689_item	2439622	et	4	main
sugu	doc_491521501689_item	2439633	et	4	main
naine	doc_491521501689_item	2439634	et	3	main
kesk-tehniline	doc_491521501689_item	2439638	et	3	main
kohtla-järve	doc_491521501689_item	2439647	et	4	main
varem	doc_491521501689_item	2439653	et	4	main
allkiri	doc_491521501689_item	2439660	et	3	main
ülesanne	doc_491521501690_item	2439662	et	4	main
ülesanne	doc_491521501690_item	2439664	et	4	main
oma	doc_491521501690_item	2439668	et	4	main
praktikast	doc_491521501690_item	2439670	et	4	main
seal	doc_491521501690_item	2439683	et	4	main
nimi	doc_491521501690_item	2439693	et	3	main
jelena	doc_491521501690_item	2439694	et	4	main
vanus	doc_491521501690_item	2439695	et	4	main
29	doc_491521501690_item	2439696	et	2	main
sünnikoht	doc_491521501690_item	2439697	et	3	main
kohtla-järve	doc_491521501690_item	2439698	et	4	main
sugu	doc_491521501690_item	2439699	et	4	main
naine	doc_491521501690_item	2439700	et	3	main
perekonnaseis	doc_491521501690_item	2439701	et	4	main
abielus	doc_491521501690_item	2439702	et	4	main
haridus	doc_491521501690_item	2439703	et	3	main
kesk	doc_491521501690_item	2439704	et	3	main
eriala	doc_491521501690_item	2439705	et	4	main
diplomi	doc_491521501690_item	2439706	et	3	main
järgi	doc_491521501690_item	2439707	et	4	main
ei	doc_491521501690_item	2439708	et	4	main
ole	doc_491521501690_item	2439709	et	4	main
aadress	doc_491521501690_item	2439711	et	3	main
kodune	doc_491521501690_item	2439710	et	4	main
tuuslari	doc_491521501690_item	2439712	et	4	main
10-2	doc_491521501690_item	2439713	et	2	main
töökoht	doc_491521501690_item	2439714	et	3	main
ei	doc_491521501690_item	2439715	et	4	main
tööta	doc_491521501690_item	2439716	et	4	main
kus	doc_491521501690_item	2439717	et	3	main
te	doc_491521501690_item	2439718	et	4	main
varem	doc_491521501690_item	2439719	et	4	main
töötasite	doc_491521501690_item	2439720	et	3	main
ankeedi	doc_491521501690_item	2439722	et	4	main
290803	doc_491521501690_item	2439725	et	2	main
kas	doc_491521501691_item	2439750	et	3	main
nr2	doc_491521501691_item	2439756	et	4	main
täida	doc_491521501691_item	2439757	et	4	main
ankeet	doc_491521501691_item	2439758	et	3	main
nimi	doc_491521501691_item	2439759	et	3	main
jõhvi	doc_491521501691_item	2439777	et	4	main
puru	doc_491521501691_item	2439778	et	4	main
kus	doc_491521501691_item	2439783	et	3	main
töötasite	doc_491521501691_item	2439786	et	3	main
allkiri	doc_491521501691_item	2439793	et	3	main
ülesanne	doc_491521501692_item	2439795	et	4	main
täitmise	doc_491521501690_item	2439723	et	4	main
kirjuta	doc_491521501691_item	2439732	et	4	main
kursuse	doc_491521501691_item	2439735	et	3	main
kus	doc_491521501691_item	2439737	et	3	main
tegid	doc_491521501691_item	2439745	et	4	main
seal	doc_491521501691_item	2439749	et	4	main
seal	doc_491521501691_item	2439753	et	4	main
ülesanne	doc_491521501691_item	2439755	et	4	main
43	doc_491521501691_item	2439762	et	2	main
sünnikoht	doc_491521501691_item	2439763	et	3	main
kohtla-järve	doc_491521501691_item	2439764	et	4	main
sugu	doc_491521501691_item	2439765	et	4	main
naine	doc_491521501691_item	2439766	et	3	main
perekonnaseis	doc_491521501691_item	2439767	et	4	main
abielus	doc_491521501691_item	2439768	et	4	main
haridus	doc_491521501691_item	2439769	et	3	main
kesk	doc_491521501691_item	2439770	et	3	main
eriala	doc_491521501691_item	2439771	et	4	main
diplomi	doc_491521501691_item	2439772	et	3	main
järgi	doc_491521501691_item	2439773	et	4	main
ei	doc_491521501691_item	2439774	et	4	main
kodune	doc_491521501691_item	2439775	et	4	main
aadress	doc_491521501691_item	2439776	et	3	main
vanus	doc_491521501691_item	2439761	et	4	main
20-49	doc_491521501691_item	2439780	et	2	main
töökoht	doc_491521501691_item	2439781	et	3	main
täitmise	doc_491521501691_item	2439790	et	4	main
kuupäev	doc_491521501691_item	2439791	et	3	main
käisid	doc_491521501692_item	2439806	et	4	main
päev	doc_491521501692_item	2439811	et	3	main
kas	doc_491521501692_item	2439813	et	3	main
sa	doc_491521501692_item	2439818	et	3	main
töötada	doc_491521501692_item	2439821	et	3	main
nr2	doc_491521501692_item	2439823	et	4	main
ankeet	doc_491521501692_item	2439825	et	3	main
nimi	doc_491521501692_item	2439826	et	3	main
valentina	doc_491521501692_item	2439827	et	4	main
eriala	doc_491521501692_item	2439840	et	4	main
varem	doc_491521501692_item	2439854	et	4	main
seal	doc_491521501693_item	2439885	et	4	main
kas	doc_491521501693_item	2439886	et	3	main
töötada	doc_491521501693_item	2439890	et	3	main
täida	doc_491521501693_item	2439893	et	4	main
eesti	doc_491521501693_item	2439903	et	4	main
varem	doc_491521501693_item	2439922	et	4	main
ankeedi	doc_491521501693_item	2439928	et	4	main
täitmise	doc_491521501693_item	2439929	et	4	main
kuupäev	doc_491521501693_item	2439930	et	3	main
290803	doc_491521501693_item	2439931	et	2	main
allkiri	doc_491521501693_item	2439932	et	3	main
allkiri	doc_491521501693_item	2439933	et	3	main
ülesanne	doc_491521501694_item	2439936	et	4	main
oma	doc_491521501694_item	2439940	et	4	main
sa	doc_491521501694_item	2439944	et	3	main
käisid	doc_491521501694_item	2439945	et	4	main
praktikal	doc_491521501694_item	2439946	et	3	main
mida	doc_491521501694_item	2439947	et	4	main
sa	doc_491521501694_item	2439948	et	3	main
kas	doc_491521501694_item	2439956	et	3	main
sa	doc_491521501694_item	2439957	et	3	main
ülesanne	doc_491521501694_item	2439961	et	4	main
nr2	doc_491521501694_item	2439962	et	4	main
40	doc_491521501694_item	2439968	et	2	main
sünnikoht	doc_491521501694_item	2439969	et	3	main
kiviõli	doc_491521501694_item	2439970	et	4	main
haridus	doc_491521501694_item	2439975	et	3	main
kodune	doc_491521501694_item	2439982	et	4	main
naine	doc_491521501695_item	2440016	et	3	main
eriala	doc_491521501695_item	2440021	et	4	main
järgi	doc_491521501695_item	2440023	et	4	main
kesk	doc_491521501695_item	2440025	et	3	main
kool	doc_491521501695_item	2440026	et	4	main
mnt	doc_491521501695_item	2440030	et	4	main
te	doc_491521501695_item	2440035	et	4	main
varem	doc_491521501695_item	2440036	et	4	main
töötasite	doc_491521501695_item	2440037	et	3	main
kauplus	doc_491521501695_item	2440038	et	3	main
nr1	doc_491521501696_item	2440050	et	4	main
oma	doc_491521501696_item	2440053	et	4	main
kas	doc_491521501696_item	2440069	et	3	main
naine	doc_491521501696_item	2440087	et	3	main
lahutatut	doc_491521501696_item	2440089	et	4	main
eriala	doc_491521501696_item	2440092	et	4	main
diplomi	doc_491521501696_item	2440093	et	3	main
järgi	doc_491521501696_item	2440094	et	4	main
töökoht	doc_491521501696_item	2440100	et	3	main
kus	doc_491521501697_item	2440123	et	3	main
käisid	doc_491521501697_item	2440125	et	4	main
seal	doc_491521501697_item	2440135	et	4	main
seal	doc_491521501697_item	2440139	et	4	main
17121961	doc_491521501697_item	2440148	et	2	main
järgi	doc_491521501697_item	2440160	et	4	main
kraanajuht	doc_491521501697_item	2440161	et	3	main
31-21	doc_491521501697_item	2440165	et	2	main
mida	doc_491521501698_item	2440193	et	4	main
iga	doc_491521501698_item	2440195	et	4	main
tegid	doc_491521501698_item	2440197	et	4	main
kas	doc_491521501698_item	2440198	et	3	main
sulle	doc_491521501698_item	2440199	et	3	main
seal	doc_491521501698_item	2440205	et	4	main
täida	doc_491521501698_item	2440209	et	4	main
nimi	doc_491521501698_item	2440211	et	3	main
18	doc_491521501698_item	2440214	et	2	main
aastat	doc_491521501698_item	2440215	et	3	main
kohtla-järve	doc_491521501698_item	2440218	et	4	main
tee	doc_491521501691_item	2439779	et	4	main
te	doc_491521501691_item	2439784	et	4	main
varem	doc_491521501691_item	2439785	et	4	main
ehituse	doc_491521501691_item	2439787	et	4	main
kursuse	doc_491521501692_item	2439802	et	3	main
iga	doc_491521501692_item	2439810	et	4	main
meeldis	doc_491521501692_item	2439815	et	3	main
47	doc_491521501692_item	2439829	et	2	main
haridus	doc_491521501692_item	2439837	et	3	main
aadress	doc_491521501692_item	2439846	et	3	main
virmalise	doc_491521501692_item	2439847	et	3	main
töötu	doc_491521501692_item	2439851	et	4	main
kus	doc_491521501692_item	2439852	et	3	main
te	doc_491521501692_item	2439853	et	4	main
täitmise	doc_491521501692_item	2439859	et	4	main
kuupäev	doc_491521501692_item	2439860	et	3	main
allkiri	doc_491521501692_item	2439863	et	3	main
1	doc_491521501693_item	2439865	et	2	main
ülesanne	doc_491521501693_item	2439866	et	4	main
ülesanne	doc_491521501693_item	2439891	et	4	main
ankeet	doc_491521501693_item	2439894	et	3	main
nimi	doc_491521501693_item	2439895	et	3	main
svetlana	doc_491521501693_item	2439896	et	4	main
sugu	doc_491521501693_item	2439904	et	4	main
naine	doc_491521501693_item	2439905	et	3	main
kodune	doc_491521501693_item	2439913	et	4	main
aadress	doc_491521501693_item	2439914	et	3	main
1	doc_491521501694_item	2439935	et	2	main
sõbrale	doc_491521501694_item	2439939	et	3	main
seal	doc_491521501694_item	2439955	et	4	main
täida	doc_491521501694_item	2439963	et	4	main
ankeet	doc_491521501694_item	2439964	et	3	main
naine	doc_491521501694_item	2439972	et	3	main
kohtla-järve	doc_491521501694_item	2439976	et	4	main
eriala	doc_491521501694_item	2439978	et	4	main
diplomi	doc_491521501694_item	2439979	et	3	main
järgi	doc_491521501694_item	2439980	et	4	main
haridus	doc_491521501695_item	2440019	et	3	main
kesk	doc_491521501695_item	2440020	et	3	main
kodune	doc_491521501695_item	2440027	et	4	main
aadress	doc_491521501695_item	2440028	et	3	main
ahtme	doc_491521501695_item	2440029	et	4	main
kus	doc_491521501695_item	2440034	et	3	main
onega	doc_491521501695_item	2440039	et	4	main
ülesanne	doc_491521501696_item	2440047	et	4	main
seal	doc_491521501696_item	2440068	et	4	main
täida	doc_491521501696_item	2440076	et	4	main
ankeet	doc_491521501696_item	2440077	et	3	main
nimi	doc_491521501696_item	2440078	et	3	main
kohtla-jarve	doc_491521501696_item	2440085	et	4	main
kesk	doc_491521501696_item	2440091	et	3	main
6-11	doc_491521501696_item	2440099	et	2	main
kursuse	doc_491521501697_item	2440121	et	3	main
sa	doc_491521501697_item	2440124	et	3	main
praktikal	doc_491521501697_item	2440126	et	3	main
mida	doc_491521501697_item	2440127	et	4	main
sa	doc_491521501697_item	2440128	et	3	main
kas	doc_491521501697_item	2440136	et	3	main
sa	doc_491521501698_item	2440190	et	3	main
päev	doc_491521501698_item	2440196	et	3	main
seal	doc_491521501698_item	2440201	et	4	main
kas	doc_491521501698_item	2440202	et	3	main
sa	doc_491521501698_item	2440203	et	3	main
ülesanne	doc_491521501698_item	2440207	et	4	main
vanus	doc_491521501698_item	2440213	et	4	main
sugu	doc_491521501698_item	2440219	et	4	main
naine	doc_491521501698_item	2440220	et	3	main
haridus	doc_491521501698_item	2440223	et	3	main
diplomi	doc_491521501698_item	2440226	et	3	main
te	doc_491521501698_item	2440238	et	4	main
ma	doc_491521501698_item	2440241	et	3	main
allkiri	doc_491521501698_item	2440252	et	3	main
kus	doc_491521501699_item	2440262	et	3	main
sa	doc_491521501699_item	2440276	et	3	main
tahaksid	doc_491521501699_item	2440277	et	4	main
seal	doc_491521501699_item	2440278	et	4	main
täida	doc_491521501699_item	2440282	et	4	main
nimi	doc_491521501699_item	2440284	et	3	main
venemaa	doc_491521501699_item	2440289	et	4	main
sugu	doc_491521501699_item	2440290	et	4	main
nr1	doc_491521501700_item	2440322	et	4	main
sõbrale	doc_491521501700_item	2440324	et	3	main
oma	doc_491521501692_item	2439801	et	4	main
kus	doc_491521501692_item	2439804	et	3	main
praktikal	doc_491521501692_item	2439807	et	3	main
sa	doc_491521501692_item	2439809	et	3	main
sulle	doc_491521501692_item	2439814	et	3	main
seal	doc_491521501692_item	2439820	et	4	main
abielus	doc_491521501692_item	2439836	et	4	main
virurand	doc_491521501692_item	2439857	et	3	main
290803	doc_491521501692_item	2439861	et	2	main
ülesanne	doc_491521501693_item	2439864	et	4	main
meeldis	doc_491521501693_item	2439884	et	3	main
sa	doc_491521501693_item	2439887	et	3	main
vana	doc_491521501693_item	2439900	et	4	main
06101969a	doc_491521501693_item	2439901	et	4	main
sünnikoht	doc_491521501693_item	2439902	et	3	main
haridus	doc_491521501693_item	2439908	et	3	main
kesk	doc_491521501693_item	2439909	et	3	main
eriala	doc_491521501693_item	2439910	et	4	main
diplomi	doc_491521501693_item	2439911	et	3	main
järgi	doc_491521501693_item	2439912	et	4	main
vanus	doc_491521501692_item	2439828	et	4	main
a	doc_491521501692_item	2439830	et	4	main
sünnikoht	doc_491521501692_item	2439831	et	3	main
venemaa	doc_491521501692_item	2439832	et	4	main
kesk	doc_491521501692_item	2439838	et	3	main
diplomi	doc_491521501692_item	2439841	et	3	main
kohtla-järve	doc_491521501692_item	2439843	et	4	main
kodune	doc_491521501692_item	2439845	et	4	main
9-19	doc_491521501692_item	2439848	et	2	main
töökoht	doc_491521501692_item	2439850	et	3	main
oü	doc_491521501692_item	2439856	et	4	main
ankeedi	doc_491521501692_item	2439858	et	4	main
allkiri	doc_491521501692_item	2439862	et	3	main
kirjuta	doc_491521501693_item	2439868	et	4	main
sõbrale	doc_491521501693_item	2439869	et	3	main
oma	doc_491521501693_item	2439870	et	4	main
kursuse	doc_491521501693_item	2439871	et	3	main
praktikast	doc_491521501693_item	2439872	et	4	main
kus	doc_491521501693_item	2439873	et	3	main
sa	doc_491521501693_item	2439874	et	3	main
käisid	doc_491521501693_item	2439875	et	4	main
praktikal	doc_491521501693_item	2439876	et	3	main
mida	doc_491521501693_item	2439877	et	4	main
sa	doc_491521501693_item	2439878	et	3	main
iga	doc_491521501693_item	2439879	et	4	main
päev	doc_491521501693_item	2439880	et	3	main
tegid	doc_491521501693_item	2439881	et	4	main
kas	doc_491521501693_item	2439882	et	3	main
sulle	doc_491521501693_item	2439883	et	3	main
tahaksid	doc_491521501693_item	2439888	et	4	main
nr2	doc_491521501693_item	2439892	et	4	main
vanus	doc_491521501693_item	2439897	et	4	main
33	doc_491521501693_item	2439898	et	2	main
aastat	doc_491521501693_item	2439899	et	3	main
keskallee	doc_491521501693_item	2439915	et	4	main
16-12	doc_491521501693_item	2439916	et	2	main
as	doc_491521501693_item	2439927	et	4	main
nr1	doc_491521501694_item	2439937	et	4	main
iga	doc_491521501694_item	2439949	et	4	main
päev	doc_491521501694_item	2439950	et	3	main
tegid	doc_491521501694_item	2439951	et	4	main
kas	doc_491521501694_item	2439952	et	3	main
seal	doc_491521501694_item	2439959	et	4	main
nimi	doc_491521501694_item	2439965	et	3	main
lahutatud	doc_491521501694_item	2439974	et	4	main
l	doc_491521501695_item	2440014	et	4	main
perekonnaseis	doc_491521501695_item	2440017	et	4	main
69-7	doc_491521501695_item	2440031	et	2	main
töötu	doc_491521501695_item	2440033	et	4	main
kuupäev	doc_491521501695_item	2440042	et	3	main
kirjuta	doc_491521501696_item	2440051	et	4	main
praktikast	doc_491521501696_item	2440055	et	4	main
kus	doc_491521501696_item	2440056	et	3	main
sa	doc_491521501696_item	2440057	et	3	main
meeldis	doc_491521501696_item	2440067	et	3	main
seal	doc_491521501696_item	2440072	et	4	main
ülesanne	doc_491521501696_item	2440074	et	4	main
nr2	doc_491521501696_item	2440075	et	4	main
a	doc_491521501696_item	2440082	et	4	main
sünnikoht	doc_491521501696_item	2440083	et	3	main
eesti	doc_491521501696_item	2440084	et	4	main
perekonnaseis	doc_491521501696_item	2440088	et	4	main
haridus	doc_491521501696_item	2440090	et	3	main
veski	doc_491521501696_item	2440098	et	4	main
töötu	doc_491521501696_item	2440101	et	4	main
töötasite	doc_491521501693_item	2439923	et	3	main
keemia	doc_491521501693_item	2439925	et	4	main
grupp	doc_491521501693_item	2439926	et	3	main
ülesanne	doc_491521501694_item	2439934	et	4	main
kursuse	doc_491521501694_item	2439941	et	3	main
meeldis	doc_491521501694_item	2439954	et	3	main
tahaksid	doc_491521501694_item	2439958	et	4	main
töötada	doc_491521501694_item	2439960	et	3	main
jelena	doc_491521501694_item	2439966	et	4	main
vanus	doc_491521501694_item	2439967	et	4	main
perekonnaseis	doc_491521501694_item	2439973	et	4	main
3keskool	doc_491521501694_item	2439977	et	4	main
aadress	doc_491521501694_item	2439983	et	3	main
eestonia	doc_491521501694_item	2439984	et	4	main
pst	doc_491521501694_item	2439985	et	3	main
44-35	doc_491521501694_item	2439986	et	2	main
kohtla-järve	doc_491521501694_item	2439987	et	4	main
töökoht	doc_491521501694_item	2439988	et	3	main
ei	doc_491521501694_item	2439989	et	4	main
töötan	doc_491521501694_item	2439990	et	3	main
kus	doc_491521501694_item	2439991	et	3	main
te	doc_491521501694_item	2439992	et	4	main
varem	doc_491521501694_item	2439993	et	4	main
töötasite	doc_491521501694_item	2439994	et	3	main
õkauplus	doc_491521501694_item	2439995	et	4	main
ankeedi	doc_491521501694_item	2439996	et	4	main
täitmise	doc_491521501694_item	2439997	et	4	main
kuupäev	doc_491521501694_item	2439998	et	3	main
290803	doc_491521501694_item	2439999	et	2	main
allkiri	doc_491521501694_item	2440000	et	3	main
allkiri	doc_491521501694_item	2440001	et	3	main
ankeet	doc_491521501695_item	2440002	et	3	main
ülesanne	doc_491521501695_item	2440003	et	4	main
nr2	doc_491521501695_item	2440004	et	4	main
ankeet	doc_491521501695_item	2440006	et	3	main
nimi	doc_491521501695_item	2440007	et	3	main
täida	doc_491521501695_item	2440005	et	4	main
svetlana	doc_491521501695_item	2440008	et	4	main
vanus	doc_491521501695_item	2440009	et	4	main
01061977a	doc_491521501695_item	2440010	et	4	main
sünnikoht	doc_491521501695_item	2440011	et	3	main
eesti	doc_491521501695_item	2440012	et	4	main
kohtla-järve	doc_491521501695_item	2440013	et	4	main
lahutatud	doc_491521501695_item	2440018	et	4	main
diplomi	doc_491521501695_item	2440022	et	3	main
ankeedi	doc_491521501695_item	2440040	et	4	main
1	doc_491521501696_item	2440048	et	2	main
kursuse	doc_491521501696_item	2440054	et	3	main
käisid	doc_491521501696_item	2440058	et	4	main
praktikal	doc_491521501696_item	2440059	et	3	main
sa	doc_491521501696_item	2440070	et	3	main
tahaksid	doc_491521501696_item	2440071	et	4	main
töötada	doc_491521501696_item	2440073	et	3	main
jelena	doc_491521501696_item	2440079	et	4	main
vanus	doc_491521501696_item	2440080	et	4	main
sugu	doc_491521501696_item	2440086	et	4	main
jõhvi	doc_491521501696_item	2440097	et	4	main
kus	doc_491521501696_item	2440102	et	3	main
te	doc_491521501696_item	2440103	et	4	main
varem	doc_491521501696_item	2440104	et	4	main
töötasite	doc_491521501696_item	2440105	et	3	main
ls	doc_491521501696_item	2440106	et	4	main
jänku	doc_491521501696_item	2440107	et	4	main
ankeedi	doc_491521501696_item	2440108	et	4	main
täitmise	doc_491521501696_item	2440109	et	4	main
kuupäev	doc_491521501696_item	2440110	et	3	main
29082003a	doc_491521501696_item	2440111	et	4	main
allkiri	doc_491521501696_item	2440112	et	3	main
allkiri	doc_491521501696_item	2440113	et	3	main
ülesanne	doc_491521501697_item	2440114	et	4	main
1	doc_491521501697_item	2440115	et	2	main
ülesanne	doc_491521501697_item	2440116	et	4	main
nr1	doc_491521501697_item	2440117	et	4	main
kirjuta	doc_491521501697_item	2440118	et	4	main
sõbrale	doc_491521501697_item	2440119	et	3	main
oma	doc_491521501697_item	2440120	et	4	main
iga	doc_491521501697_item	2440129	et	4	main
päev	doc_491521501697_item	2440130	et	3	main
tegid	doc_491521501697_item	2440131	et	4	main
kas	doc_491521501697_item	2440132	et	3	main
sulle	doc_491521501697_item	2440133	et	3	main
täida	doc_491521501697_item	2440143	et	4	main
ankeet	doc_491521501697_item	2440144	et	3	main
nimi	doc_491521501697_item	2440145	et	3	main
margarita	doc_491521501697_item	2440146	et	4	main
eesti	doc_491521501697_item	2440150	et	4	main
sugu	doc_491521501697_item	2440152	et	4	main
lahutatud	doc_491521501697_item	2440155	et	4	main
haridus	doc_491521501697_item	2440156	et	3	main
kesk	doc_491521501697_item	2440157	et	3	main
eriala	doc_491521501697_item	2440158	et	4	main
diplomi	doc_491521501697_item	2440159	et	3	main
käisid	doc_491521501698_item	2440191	et	4	main
sa	doc_491521501698_item	2440194	et	3	main
nr2	doc_491521501698_item	2440208	et	4	main
ankeet	doc_491521501698_item	2440210	et	3	main
ida-virumaa	doc_491521501698_item	2440217	et	4	main
perekonnaseis	doc_491521501698_item	2440221	et	4	main
kodune	doc_491521501698_item	2440228	et	4	main
ahtme	doc_491521501698_item	2440230	et	4	main
mnt	doc_491521501698_item	2440231	et	4	main
91-101	doc_491521501698_item	2440232	et	2	main
töökoht	doc_491521501698_item	2440233	et	3	main
ma	doc_491521501698_item	2440234	et	3	main
olen	doc_491521501698_item	2440235	et	3	main
õppisin	doc_491521501698_item	2440246	et	3	main
mida	doc_491521501696_item	2440060	et	4	main
sa	doc_491521501696_item	2440061	et	3	main
iga	doc_491521501696_item	2440062	et	4	main
päev	doc_491521501696_item	2440063	et	3	main
tegid	doc_491521501696_item	2440064	et	4	main
kas	doc_491521501696_item	2440065	et	3	main
sulle	doc_491521501696_item	2440066	et	3	main
05121967	doc_491521501696_item	2440081	et	2	main
kodune	doc_491521501696_item	2440095	et	4	main
aadress	doc_491521501696_item	2440096	et	3	main
praktikast	doc_491521501697_item	2440122	et	4	main
meeldis	doc_491521501697_item	2440134	et	3	main
tahaksid	doc_491521501697_item	2440138	et	4	main
töötada	doc_491521501697_item	2440140	et	3	main
ülesanne	doc_491521501697_item	2440141	et	4	main
nr2	doc_491521501697_item	2440142	et	4	main
sünnikoht	doc_491521501697_item	2440149	et	3	main
kodune	doc_491521501697_item	2440162	et	4	main
aadress	doc_491521501697_item	2440163	et	3	main
maleva	doc_491521501697_item	2440164	et	3	main
kus	doc_491521501698_item	2440189	et	3	main
tahaksid	doc_491521501698_item	2440204	et	4	main
põhi	doc_491521501698_item	2440224	et	3	main
veel	doc_491521501698_item	2440242	et	4	main
ole	doc_491521501698_item	2440244	et	4	main
töötanud	doc_491521501698_item	2440245	et	4	main
ankeedi	doc_491521501698_item	2440247	et	4	main
1	doc_491521501699_item	2440254	et	2	main
sa	doc_491521501699_item	2440263	et	3	main
iga	doc_491521501699_item	2440268	et	4	main
päev	doc_491521501699_item	2440269	et	3	main
sulle	doc_491521501699_item	2440272	et	3	main
meeldis	doc_491521501699_item	2440273	et	3	main
seal	doc_491521501699_item	2440274	et	4	main
kas	doc_491521501699_item	2440275	et	3	main
nr2	doc_491521501699_item	2440281	et	4	main
tatjana	doc_491521501699_item	2440285	et	4	main
25041978	doc_491521501699_item	2440287	et	2	main
naine	doc_491521501699_item	2440291	et	3	main
vabaabielus	doc_491521501699_item	2440293	et	4	main
haridus	doc_491521501699_item	2440294	et	3	main
kesk-eri	doc_491521501699_item	2440295	et	4	main
praktikast	doc_491521501700_item	2440327	et	4	main
kus	doc_491521501700_item	2440328	et	3	main
sa	doc_491521501700_item	2440329	et	3	main
käisid	doc_491521501700_item	2440330	et	4	main
praktikal	doc_491521501700_item	2440331	et	3	main
mida	doc_491521501700_item	2440332	et	4	main
tegid	doc_491521501700_item	2440336	et	4	main
täida	doc_491521501700_item	2440348	et	4	main
в	doc_491521501700_item	2440351	et	2	main
25061979	doc_491521501700_item	2440354	et	2	main
sünnikoht	doc_491521501700_item	2440355	et	3	main
diplomi	doc_491521501700_item	2440364	et	3	main
varem	doc_491521501700_item	2440376	et	4	main
ankeedi	doc_491521501700_item	2440379	et	4	main
sa	doc_491521501701_item	2440418	et	3	main
tegema	doc_491521501701_item	2440420	et	3	main
sa	doc_491521501697_item	2440137	et	3	main
vanus	doc_491521501697_item	2440147	et	4	main
kohtla-järve	doc_491521501697_item	2440151	et	4	main
naine	doc_491521501697_item	2440153	et	3	main
perekonnaseis	doc_491521501697_item	2440154	et	4	main
töökoht	doc_491521501697_item	2440166	et	3	main
töötu	doc_491521501697_item	2440167	et	4	main
kus	doc_491521501697_item	2440168	et	3	main
te	doc_491521501697_item	2440169	et	4	main
varem	doc_491521501697_item	2440170	et	4	main
töötasite	doc_491521501697_item	2440171	et	3	main
as	doc_491521501697_item	2440172	et	4	main
orti	doc_491521501697_item	2440173	et	4	main
ankeedi	doc_491521501697_item	2440174	et	4	main
täitmise	doc_491521501697_item	2440175	et	4	main
kuupäev	doc_491521501697_item	2440176	et	3	main
29082003	doc_491521501697_item	2440177	et	2	main
allkiri	doc_491521501697_item	2440178	et	3	main
allkiri	doc_491521501697_item	2440179	et	3	main
ülesanne	doc_491521501698_item	2440180	et	4	main
1	doc_491521501698_item	2440181	et	2	main
nr1	doc_491521501698_item	2440183	et	4	main
ülesanne	doc_491521501698_item	2440182	et	4	main
kirjuta	doc_491521501698_item	2440184	et	4	main
sõbrale	doc_491521501698_item	2440185	et	3	main
oma	doc_491521501698_item	2440186	et	4	main
kursuse	doc_491521501698_item	2440187	et	3	main
praktikast	doc_491521501698_item	2440188	et	4	main
praktikal	doc_491521501698_item	2440192	et	3	main
meeldis	doc_491521501698_item	2440200	et	3	main
töötada	doc_491521501698_item	2440206	et	3	main
marina	doc_491521501698_item	2440212	et	3	main
sünnikoht	doc_491521501698_item	2440216	et	3	main
eriala	doc_491521501698_item	2440225	et	4	main
töötu	doc_491521501698_item	2440236	et	4	main
kus	doc_491521501698_item	2440237	et	3	main
täitmise	doc_491521501698_item	2440248	et	4	main
kuupäev	doc_491521501698_item	2440249	et	3	main
29082003	doc_491521501698_item	2440250	et	2	main
allkiri	doc_491521501698_item	2440251	et	3	main
ülesanne	doc_491521501699_item	2440255	et	4	main
praktikal	doc_491521501699_item	2440265	et	3	main
sa	doc_491521501699_item	2440267	et	3	main
töötada	doc_491521501699_item	2440279	et	3	main
ülesanne	doc_491521501699_item	2440280	et	4	main
vanus	doc_491521501699_item	2440286	et	4	main
eriala	doc_491521501699_item	2440296	et	4	main
diplomi	doc_491521501699_item	2440297	et	3	main
järgi	doc_491521501699_item	2440298	et	4	main
vallaline	doc_491521501698_item	2440222	et	4	main
järgi	doc_491521501698_item	2440227	et	4	main
aadress	doc_491521501698_item	2440229	et	3	main
varem	doc_491521501698_item	2440239	et	4	main
töötasite	doc_491521501698_item	2440240	et	3	main
ei	doc_491521501698_item	2440243	et	4	main
oma	doc_491521501699_item	2440259	et	4	main
kursuse	doc_491521501699_item	2440260	et	3	main
praktikast	doc_491521501699_item	2440261	et	4	main
sünnikoht	doc_491521501699_item	2440288	et	3	main
pst	doc_491521501699_item	2440303	et	3	main
13-11	doc_491521501699_item	2440304	et	2	main
töökoht	doc_491521501699_item	2440305	et	3	main
töötatu	doc_491521501699_item	2440306	et	4	main
kus	doc_491521501699_item	2440307	et	3	main
varem	doc_491521501699_item	2440309	et	4	main
töötasite	doc_491521501699_item	2440310	et	3	main
maniküüriane	doc_491521501699_item	2440311	et	4	main
te	doc_491521501699_item	2440308	et	4	main
meister	doc_491521501699_item	2440312	et	3	main
ankeedi	doc_491521501699_item	2440313	et	4	main
täitmise	doc_491521501699_item	2440314	et	4	main
kuupäev	doc_491521501699_item	2440315	et	3	main
29082003	doc_491521501699_item	2440316	et	2	main
allkiri	doc_491521501699_item	2440317	et	3	main
allkiri	doc_491521501699_item	2440318	et	3	main
ülesanne	doc_491521501700_item	2440319	et	4	main
1	doc_491521501700_item	2440320	et	2	main
iga	doc_491521501700_item	2440334	et	4	main
sulle	doc_491521501700_item	2440338	et	3	main
sa	doc_491521501700_item	2440342	et	3	main
seal	doc_491521501700_item	2440344	et	4	main
perekonnaseis	doc_491521501700_item	2440359	et	4	main
eriala	doc_491521501700_item	2440363	et	4	main
järgi	doc_491521501700_item	2440365	et	4	main
õmleja-kursuse	doc_491521501700_item	2440366	et	3	main
kodune	doc_491521501700_item	2440367	et	4	main
aadress	doc_491521501700_item	2440368	et	3	main
narva	doc_491521501700_item	2440369	et	4	main
te	doc_491521501700_item	2440375	et	4	main
viru-rand	doc_491521501700_item	2440378	et	3	main
täitmise	doc_491521501700_item	2440380	et	4	main
ja	doc_491521501701_item	2440416	et	3	main
mida	doc_491521501701_item	2440417	et	4	main
ammu	doc_491521501701_item	2440425	et	4	main
kuidas	doc_491521501701_item	2440440	et	3	main
läin	doc_491521501701_item	2440451	et	4	main
kursusel	doc_491521501701_item	2440453	et	3	main
õppetasid	doc_491521501701_item	2440459	et	4	main
õppeaised	doc_491521501701_item	2440461	et	4	main
kui	doc_491521501701_item	2440462	et	3	main
alused	doc_491521501701_item	2440468	et	4	main
arvuti	doc_491521501701_item	2440480	et	4	main
alused	doc_491521501701_item	2440483	et	4	main
on	doc_491521501701_item	2440498	et	4	main
ehitusmaterjalid	doc_491521501701_item	2440499	et	3	main
hakkan	doc_491521501701_item	2440501	et	3	main
aga	doc_491521501701_item	2440514	et	3	main
mingisuguse	doc_491521501701_item	2440522	et	3	main
tööl	doc_491521501701_item	2440523	et	3	main
aitab	doc_491521501701_item	2440530	et	3	main
tervita	doc_491521501701_item	2440532	et	4	main
teie	doc_491521501701_item	2440539	et	4	main
ülesanne	doc_491521501699_item	2440253	et	4	main
nr1	doc_491521501699_item	2440256	et	4	main
kirjuta	doc_491521501699_item	2440257	et	4	main
sõbrale	doc_491521501699_item	2440258	et	3	main
käisid	doc_491521501699_item	2440264	et	4	main
mida	doc_491521501699_item	2440266	et	4	main
tegid	doc_491521501699_item	2440270	et	4	main
kas	doc_491521501699_item	2440271	et	3	main
ankeet	doc_491521501699_item	2440283	et	3	main
perekonnaseis	doc_491521501699_item	2440292	et	4	main
eetevõtja	doc_491521501699_item	2440299	et	4	main
kodune	doc_491521501699_item	2440300	et	4	main
aadress	doc_491521501699_item	2440301	et	3	main
estonia	doc_491521501699_item	2440302	et	4	main
ülesanne	doc_491521501700_item	2440321	et	4	main
kirjuta	doc_491521501700_item	2440323	et	4	main
oma	doc_491521501700_item	2440325	et	4	main
kursuse	doc_491521501700_item	2440326	et	3	main
sa	doc_491521501700_item	2440333	et	3	main
seal	doc_491521501700_item	2440340	et	4	main
kas	doc_491521501700_item	2440341	et	3	main
töötada	doc_491521501700_item	2440345	et	3	main
iktorika	doc_491521501700_item	2440352	et	4	main
kus	doc_491521501700_item	2440374	et	3	main
tere	doc_491521501701_item	2440422	et	3	main
pole	doc_491521501701_item	2440424	et	3	main
ja	doc_491521501701_item	2440428	et	3	main
vanemate	doc_491521501701_item	2440435	et	4	main
tervis	doc_491521501701_item	2440436	et	3	main
kuidas	doc_491521501701_item	2440437	et	3	main
saad	doc_491521501701_item	2440444	et	4	main
mul	doc_491521501701_item	2440445	et	3	main
ma	doc_491521501701_item	2440450	et	3	main
eriala	doc_491521501701_item	2440454	et	4	main
müügisekretär	doc_491521501701_item	2440456	et	3	main
arvuti	doc_491521501701_item	2440463	et	4	main
asjaajamise	doc_491521501701_item	2440469	et	4	main
turunduse	doc_491521501701_item	2440471	et	3	main
eesti	doc_491521501701_item	2440474	et	4	main
õpetus	doc_491521501701_item	2440481	et	4	main
meile	doc_491521501701_item	2440489	et	4	main
praktika	doc_491521501701_item	2440491	et	4	main
praktikale	doc_491521501701_item	2440494	et	3	main
töötama	doc_491521501701_item	2440502	et	3	main
müügisekretär	doc_491521501701_item	2440510	et	3	main
saan	doc_491521501701_item	2440521	et	4	main
kogemused	doc_491521501701_item	2440524	et	3	main
lobisemisest	doc_491521501701_item	2440531	et	4	main
oma	doc_491521501701_item	2440533	et	4	main
sinu	doc_491521501701_item	2440537	et	3	main
xxxxx	doc_491521501701_item	2440540	et	4	main
kas	doc_491521501700_item	2440337	et	3	main
tahaksid	doc_491521501700_item	2440343	et	4	main
ülesanne	doc_491521501700_item	2440346	et	4	main
nr2	doc_491521501700_item	2440347	et	4	main
eiole	doc_491521501700_item	2440360	et	4	main
haridus	doc_491521501700_item	2440361	et	3	main
mnt	doc_491521501700_item	2440370	et	4	main
töötasite	doc_491521501700_item	2440377	et	3	main
kuupäev	doc_491521501700_item	2440381	et	3	main
29082003	doc_491521501700_item	2440382	et	2	main
allkiri	doc_491521501700_item	2440383	et	3	main
allkiri	doc_491521501700_item	2440384	et	3	main
kiri	doc_491521501701_item	2440385	et	3	main
kiri	doc_491521501701_item	2440386	et	3	main
kirjuta	doc_491521501701_item	2440387	et	4	main
oma	doc_491521501701_item	2440388	et	4	main
eestlasest	doc_491521501701_item	2440389	et	3	main
sõbrale	doc_491521501701_item	2440390	et	3	main
et	doc_491521501701_item	2440391	et	3	main
saa	doc_491521501701_item	2440392	et	4	main
käid	doc_491521501701_item	2440393	et	3	main
kursustel	doc_491521501701_item	2440394	et	3	main
ja	doc_491521501701_item	2440395	et	3	main
varsti	doc_491521501701_item	2440396	et	3	main
lähed	doc_491521501701_item	2440397	et	3	main
praktikale	doc_491521501701_item	2440398	et	3	main
kirjuta	doc_491521501701_item	2440399	et	4	main
kuidas	doc_491521501701_item	2440400	et	3	main
sul	doc_491521501701_item	2440401	et	3	main
kursustel	doc_491521501701_item	2440402	et	3	main
läks	doc_491521501701_item	2440403	et	3	main
mida	doc_491521501701_item	2440404	et	4	main
sa	doc_491521501701_item	2440405	et	3	main
seal	doc_491521501701_item	2440406	et	4	main
õppisid	doc_491521501701_item	2440407	et	4	main
kuhu	doc_491521501701_item	2440408	et	3	main
sa	doc_491521501701_item	2440409	et	3	main
praktikale	doc_491521501701_item	2440410	et	3	main
lähed	doc_491521501701_item	2440411	et	3	main
millega	doc_491521501701_item	2440412	et	3	main
see	doc_491521501701_item	2440413	et	3	main
firma	doc_491521501701_item	2440414	et	4	main
päev	doc_491521501700_item	2440335	et	3	main
meeldis	doc_491521501700_item	2440339	et	3	main
ankeet	doc_491521501700_item	2440349	et	3	main
nimi	doc_491521501700_item	2440350	et	3	main
vanus	doc_491521501700_item	2440353	et	4	main
vanemaa	doc_491521501700_item	2440356	et	4	main
sugu	doc_491521501700_item	2440357	et	4	main
naine	doc_491521501700_item	2440358	et	3	main
põhi-haridus	doc_491521501700_item	2440362	et	3	main
28-1	doc_491521501700_item	2440371	et	2	main
töökoht	doc_491521501700_item	2440372	et	3	main
tööta	doc_491521501700_item	2440373	et	4	main
hakkad	doc_491521501701_item	2440421	et	3	main
ene	doc_491521501701_item	2440423	et	4	main
elavad	doc_491521501701_item	2440439	et	4	main
mehega	doc_491521501701_item	2440442	et	3	main
on	doc_491521501701_item	2440446	et	4	main
sulle	doc_491521501701_item	2440447	et	3	main
suur	doc_491521501701_item	2440448	et	3	main
uudis	doc_491521501701_item	2440449	et	3	main
järgi	doc_491521501701_item	2440455	et	4	main
meile	doc_491521501701_item	2440458	et	4	main
sellised	doc_491521501701_item	2440460	et	4	main
alused	doc_491521501701_item	2440466	et	4	main
ettevõtluse	doc_491521501701_item	2440467	et	3	main
alused	doc_491521501701_item	2440472	et	4	main
meeldis	doc_491521501701_item	2440479	et	3	main
lõpus	doc_491521501701_item	2440488	et	4	main
see	doc_491521501701_item	2440497	et	3	main
müüjana	doc_491521501701_item	2440504	et	4	main
mull	doc_491521501701_item	2440511	et	3	main
mulle	doc_491521501701_item	2440515	et	4	main
ma	doc_491521501701_item	2440525	et	3	main
saan	doc_491521501701_item	2440526	et	4	main
olema	doc_491521501701_item	2440527	et	4	main
ootan	doc_491521501701_item	2440536	et	3	main
kirja	doc_491521501701_item	2440538	et	4	main
tegeleb	doc_491521501701_item	2440415	et	3	main
seal	doc_491521501701_item	2440419	et	4	main
sinuga	doc_491521501701_item	2440426	et	3	main
midagi	doc_491521501701_item	2440429	et	4	main
sinust	doc_491521501701_item	2440430	et	3	main
sa	doc_491521501701_item	2440441	et	3	main
läbi	doc_491521501701_item	2440443	et	4	main
õppima	doc_491521501701_item	2440452	et	3	main
seal	doc_491521501701_item	2440457	et	4	main
õpetus	doc_491521501701_item	2440464	et	4	main
psühholoogia	doc_491521501701_item	2440465	et	4	main
ja	doc_491521501701_item	2440473	et	3	main
keel	doc_491521501701_item	2440475	et	4	main
rohkem	doc_491521501701_item	2440477	et	4	main
mulle	doc_491521501701_item	2440478	et	4	main
psühholoogia	doc_491521501701_item	2440482	et	4	main
ja	doc_491521501701_item	2440484	et	3	main
keel	doc_491521501701_item	2440486	et	4	main
õppimise	doc_491521501701_item	2440487	et	4	main
ma	doc_491521501701_item	2440492	et	3	main
poes	doc_491521501701_item	2440495	et	3	main
seal	doc_491521501701_item	2440503	et	4	main
selle	doc_491521501701_item	2440505	et	4	main
pärast	doc_491521501701_item	2440506	et	4	main
et	doc_491521501701_item	2440507	et	3	main
ei	doc_491521501701_item	2440512	et	4	main
kohtunud	doc_491521501701_item	2440427	et	4	main
ei	doc_491521501701_item	2440431	et	4	main
tea	doc_491521501701_item	2440432	et	4	main
kuidas	doc_491521501701_item	2440433	et	3	main
on	doc_491521501701_item	2440434	et	4	main
lapsed	doc_491521501701_item	2440438	et	3	main
tööotsimine	doc_491521501701_item	2440470	et	3	main
kõige	doc_491521501701_item	2440476	et	4	main
eesti	doc_491521501701_item	2440485	et	4	main
hakkab	doc_491521501701_item	2440490	et	3	main
lähen	doc_491521501701_item	2440493	et	3	main
evas	doc_491521501701_item	2440496	et	4	main
ma	doc_491521501701_item	2440500	et	3	main
eriala	doc_491521501701_item	2440508	et	4	main
järgi	doc_491521501701_item	2440509	et	4	main
võetud	doc_491521501701_item	2440513	et	4	main
hakkab	doc_491521501701_item	2440516	et	3	main
huvitav	doc_491521501701_item	2440517	et	4	main
töötama	doc_491521501701_item	2440518	et	3	main
müüjana	doc_491521501701_item	2440519	et	4	main
ma	doc_491521501701_item	2440520	et	3	main
peret	doc_491521501701_item	2440534	et	3	main
leidan	doc_491521501701_item	2440528	et	4	main
tööl	doc_491521501701_item	2440529	et	3	main
ma	doc_491521501701_item	2440535	et	3	main
lähed	doc_491521501705_item	2441045	et	3	main
lähed	doc_491521501705_item	2441059	et	3	main
millega	doc_491521501705_item	2441060	et	3	main
ei	doc_491521501705_item	2441072	et	4	main
sinuga	doc_491521501705_item	2441079	et	3	main
üldse	doc_491521501705_item	2441088	et	3	main
mul	doc_491521501705_item	2441090	et	3	main
praktikale	doc_491521501705_item	2441106	et	3	main
midagi	doc_491521501705_item	2441113	et	4	main
praktikat	doc_491521501705_item	2441118	et	3	main
ja	doc_491521501705_item	2441124	et	3	main
majapidamisinventari	doc_491521501705_item	2441126	et	4	main
käisin	doc_491521501705_item	2441128	et	3	main
sinna	doc_491521501705_item	2441130	et	3	main
oma	doc_491521501705_item	2441138	et	4	main
sa	doc_491521501705_item	2441159	et	3	main
kuidas	doc_491521501705_item	2441161	et	3	main
palju	doc_491521501705_item	2441179	et	4	main
ja	doc_491521501705_item	2441043	et	3	main
kirjuta	doc_491521501705_item	2441047	et	4	main
ja	doc_491521501705_item	2441064	et	3	main
kirja	doc_491521501705_item	2441076	et	4	main
tuju	doc_491521501705_item	2441091	et	4	main
ma	doc_491521501705_item	2441114	et	3	main
varsti	doc_491521501705_item	2441116	et	3	main
pärast	doc_491521501705_item	2441141	et	4	main
võttab	doc_491521501705_item	2441146	et	4	main
töötaja	doc_491521501705_item	2441158	et	4	main
küsid	doc_491521501705_item	2441160	et	3	main
seal	doc_491521501705_item	2441178	et	4	main
huvitavaid	doc_491521501705_item	2441180	et	4	main
tean	doc_491521501705_item	2441188	et	3	main
praegu	doc_491521501705_item	2441189	et	3	main
mulle	doc_491521501705_item	2441194	et	4	main
väga	doc_491521501705_item	2441207	et	3	main
kahjuks	doc_491521501705_item	2441209	et	4	main
eesti	doc_491521501705_item	2441213	et	4	main
kirja	doc_491521501705_item	2441225	et	4	main
pikemalt	doc_491521501705_item	2441228	et	4	main
oma	doc_491521501705_item	2441234	et	4	main
kõike	doc_491521501705_item	2441236	et	4	main
kirjuta	doc_491521501705_item	2441035	et	4	main
oma	doc_491521501705_item	2441036	et	4	main
eestlasest	doc_491521501705_item	2441037	et	3	main
sõbrale	doc_491521501705_item	2441038	et	3	main
et	doc_491521501705_item	2441039	et	3	main
kursustel	doc_491521501705_item	2441042	et	3	main
firma	doc_491521501705_item	2441062	et	4	main
anneli	doc_491521501705_item	2441071	et	4	main
saanud	doc_491521501705_item	2441077	et	4	main
kas	doc_491521501705_item	2441078	et	3	main
juhtunud	doc_491521501705_item	2441082	et	4	main
sinu	doc_491521501705_item	2441084	et	3	main
mures	doc_491521501705_item	2441086	et	3	main
on	doc_491521501705_item	2441089	et	4	main
nulis	doc_491521501705_item	2441092	et	4	main
küsid	doc_491521501705_item	2441093	et	3	main
eesti	doc_491521501705_item	2441098	et	4	main
müügisekretäri	doc_491521501705_item	2441100	et	4	main
leinud	doc_491521501705_item	2441111	et	4	main
ühe	doc_491521501705_item	2441119	et	4	main
fie	doc_491521501705_item	2441120	et	4	main
milline	doc_491521501705_item	2441121	et	3	main
jaemüük	doc_491521501705_item	2441123	et	3	main
juba	doc_491521501705_item	2441129	et	3	main
lubas	doc_491521501705_item	2441135	et	3	main
mind	doc_491521501705_item	2441136	et	4	main
ja	doc_491521501705_item	2441140	et	3	main
praktikat	doc_491521501705_item	2441142	et	3	main
võib	doc_491521501705_item	2441144	et	3	main
trükkimine	doc_491521501705_item	2441185	et	4	main
arvutil	doc_491521501705_item	2441186	et	4	main
ma	doc_491521501705_item	2441187	et	3	main
arvutioskus	doc_491521501705_item	2441190	et	3	main
excel	doc_491521501705_item	2441193	et	4	main
väga	doc_491521501705_item	2441196	et	3	main
kursustel	doc_491521501705_item	2441198	et	3	main
ma	doc_491521501705_item	2441199	et	3	main
õppisin	doc_491521501705_item	2441200	et	3	main
mulle	doc_491521501705_item	2441205	et	4	main
ja	doc_491521501705_item	2441212	et	3	main
keel	doc_491521501705_item	2441214	et	4	main
oli	doc_491521501705_item	2441215	et	3	main
väga	doc_491521501705_item	2441216	et	3	main
kirja	doc_491521501705_item	2441222	et	4	main
kirjuta	doc_491521501705_item	2441226	et	4	main
lõpetan	doc_491521501705_item	2441232	et	3	main
kiri	doc_491521501705_item	2441033	et	3	main
kiri	doc_491521501705_item	2441034	et	3	main
varsti	doc_491521501705_item	2441044	et	3	main
praktikale	doc_491521501705_item	2441046	et	3	main
kuidas	doc_491521501705_item	2441048	et	3	main
tegeleb	doc_491521501705_item	2441063	et	3	main
sa	doc_491521501705_item	2441066	et	3	main
seal	doc_491521501705_item	2441067	et	4	main
tegema	doc_491521501705_item	2441068	et	3	main
hakkad	doc_491521501705_item	2441069	et	3	main
kallis	doc_491521501705_item	2441070	et	4	main
midagi	doc_491521501705_item	2441081	et	4	main
olen	doc_491521501705_item	2441083	et	3	main
miks	doc_491521501705_item	2441094	et	4	main
praegu	doc_491521501705_item	2441095	et	3	main
õpin	doc_491521501705_item	2441097	et	3	main
ja	doc_491521501705_item	2441102	et	3	main
mitte	doc_491521501705_item	2441112	et	3	main
leia	doc_491521501705_item	2441117	et	4	main
saa	doc_491521501705_item	2441040	et	4	main
käid	doc_491521501705_item	2441041	et	3	main
sul	doc_491521501705_item	2441049	et	3	main
kursustel	doc_491521501705_item	2441050	et	3	main
läks	doc_491521501705_item	2441051	et	3	main
mida	doc_491521501705_item	2441052	et	4	main
sa	doc_491521501705_item	2441053	et	3	main
seal	doc_491521501705_item	2441054	et	4	main
õppisid	doc_491521501705_item	2441055	et	4	main
kuhu	doc_491521501705_item	2441056	et	3	main
sa	doc_491521501705_item	2441057	et	3	main
praktikale	doc_491521501705_item	2441058	et	3	main
see	doc_491521501705_item	2441061	et	3	main
mida	doc_491521501705_item	2441065	et	4	main
ole	doc_491521501705_item	2441073	et	4	main
sinult	doc_491521501705_item	2441074	et	3	main
ammu	doc_491521501705_item	2441075	et	4	main
on	doc_491521501705_item	2441080	et	4	main
pärast	doc_491521501705_item	2441085	et	4	main
ja	doc_491521501705_item	2441087	et	3	main
ma	doc_491521501705_item	2441096	et	3	main
kelle	doc_491521501705_item	2441099	et	4	main
kursusel	doc_491521501705_item	2441101	et	3	main
pean	doc_491521501705_item	2441103	et	4	main
ise	doc_491521501705_item	2441104	et	4	main
leidma	doc_491521501705_item	2441105	et	3	main
aga	doc_491521501705_item	2441107	et	3	main
praegu	doc_491521501705_item	2441108	et	3	main
ma	doc_491521501705_item	2441109	et	3	main
ei	doc_491521501705_item	2441110	et	4	main
loodan	doc_491521501705_item	2441115	et	3	main
tegeleb	doc_491521501705_item	2441122	et	3	main
hulgimüük	doc_491521501705_item	2441125	et	3	main
ma	doc_491521501705_item	2441127	et	3	main
ja	doc_491521501705_item	2441131	et	3	main
firma	doc_491521501705_item	2441139	et	4	main
ootan	doc_491521501705_item	2441150	et	3	main
homseni	doc_491521501705_item	2441151	et	3	main
tema	doc_491521501705_item	2441152	et	4	main
helisema	doc_491521501705_item	2441153	et	4	main
seal	doc_491521501705_item	2441154	et	4	main
ma	doc_491521501705_item	2441155	et	3	main
hakkan	doc_491521501705_item	2441156	et	3	main
mul	doc_491521501705_item	2441162	et	3	main
word	doc_491521501705_item	2441191	et	4	main
ja	doc_491521501705_item	2441192	et	3	main
see	doc_491521501705_item	2441195	et	3	main
meeldiv	doc_491521501705_item	2441197	et	4	main
ka	doc_491521501705_item	2441201	et	3	main
eesti	doc_491521501705_item	2441202	et	4	main
ka	doc_491521501705_item	2441206	et	3	main
meeldiv	doc_491521501705_item	2441208	et	4	main
et	doc_491521501705_item	2441210	et	3	main
arvutikursused	doc_491521501705_item	2441211	et	3	main
mulle	doc_491521501705_item	2441227	et	4	main
seekord	doc_491521501705_item	2441231	et	3	main
eestlasest	doc_491521501707_item	2441379	et	3	main
sõbrale	doc_491521501707_item	2441380	et	3	main
et	doc_491521501707_item	2441381	et	3	main
varsti	doc_491521501707_item	2441386	et	3	main
rääkisin	doc_491521501705_item	2441132	et	3	main
juhtajaga	doc_491521501705_item	2441133	et	3	main
ta	doc_491521501705_item	2441134	et	4	main
võtta	doc_491521501705_item	2441137	et	3	main
ta	doc_491521501705_item	2441143	et	4	main
olla	doc_491521501705_item	2441145	et	3	main
mind	doc_491521501705_item	2441147	et	4	main
tööle	doc_491521501705_item	2441148	et	3	main
ma	doc_491521501705_item	2441149	et	3	main
müüjaosakonna	doc_491521501705_item	2441157	et	4	main
kursustel	doc_491521501705_item	2441163	et	3	main
läks	doc_491521501705_item	2441164	et	3	main
mida	doc_491521501705_item	2441165	et	4	main
ma	doc_491521501705_item	2441166	et	3	main
seal	doc_491521501705_item	2441167	et	4	main
õppisin	doc_491521501705_item	2441168	et	3	main
ütlen	doc_491521501705_item	2441169	et	3	main
ainult	doc_491521501705_item	2441170	et	4	main
et	doc_491521501705_item	2441171	et	3	main
kursustel	doc_491521501705_item	2441172	et	3	main
mul	doc_491521501705_item	2441173	et	3	main
läks	doc_491521501705_item	2441174	et	3	main
hästi	doc_491521501705_item	2441175	et	3	main
ma	doc_491521501705_item	2441176	et	3	main
õppisin	doc_491521501705_item	2441177	et	3	main
näiteks	doc_491521501705_item	2441181	et	4	main
ma	doc_491521501705_item	2441182	et	3	main
õppisin	doc_491521501705_item	2441183	et	3	main
milline	doc_491521501705_item	2441204	et	3	main
lühike	doc_491521501705_item	2441217	et	4	main
teksti	doc_491521501705_item	2441184	et	4	main
keel	doc_491521501705_item	2441203	et	4	main
sellega	doc_491521501705_item	2441218	et	3	main
ma	doc_491521501705_item	2441219	et	3	main
lõpetan	doc_491521501705_item	2441220	et	3	main
oma	doc_491521501705_item	2441221	et	4	main
ootan	doc_491521501705_item	2441223	et	3	main
elust	doc_491521501705_item	2441230	et	3	main
poega	doc_491521501705_item	2441235	et	4	main
soovide	doc_491521501705_item	2441238	et	3	main
kursustel	doc_491521501707_item	2441384	et	3	main
eesti	doc_491521501707_item	2441431	et	4	main
asjaajamise	doc_491521501707_item	2441434	et	4	main
tööbtsimine	doc_491521501707_item	2441437	et	4	main
ei	doc_491521501707_item	2441443	et	4	main
mittevajalik	doc_491521501707_item	2441445	et	3	main
praktikale	doc_491521501707_item	2441449	et	3	main
on	doc_491521501707_item	2441457	et	4	main
ja	doc_491521501707_item	2441462	et	3	main
mul	doc_491521501707_item	2441479	et	3	main
abistavad	doc_491521501707_item	2441481	et	4	main
sul	doc_491521501708_item	2441501	et	3	main
läks	doc_491521501708_item	2441503	et	3	main
sinu	doc_491521501705_item	2441224	et	3	main
oma	doc_491521501705_item	2441229	et	4	main
tervita	doc_491521501705_item	2441233	et	4	main
head	doc_491521501705_item	2441237	et	4	main
oma	doc_491521501707_item	2441378	et	4	main
ja	doc_491521501707_item	2441385	et	3	main
praktikale	doc_491521501707_item	2441388	et	3	main
kuidas	doc_491521501707_item	2441390	et	3	main
praktikale	doc_491521501707_item	2441422	et	3	main
mul	doc_491521501707_item	2441424	et	3	main
keel	doc_491521501707_item	2441432	et	4	main
hakkan	doc_491521501707_item	2441447	et	3	main
on	doc_491521501707_item	2441451	et	4	main
ka	doc_491521501707_item	2441469	et	3	main
töötavad	doc_491521501707_item	2441471	et	4	main
huvitavad	doc_491521501707_item	2441472	et	4	main
saa	doc_491521501707_item	2441382	et	4	main
kirjuta	doc_491521501707_item	2441389	et	4	main
meeldis	doc_491521501707_item	2441426	et	3	main
loenged	doc_491521501707_item	2441428	et	4	main
psühholoogia	doc_491521501707_item	2441429	et	4	main
ja	doc_491521501707_item	2441430	et	3	main
ettevõtluse	doc_491521501707_item	2441435	et	3	main
meeldis	doc_491521501707_item	2441444	et	3	main
see	doc_491521501707_item	2441450	et	3	main
väga	doc_491521501707_item	2441452	et	3	main
firma	doc_491521501707_item	2441454	et	4	main
ja	doc_491521501707_item	2441460	et	3	main
müüd	doc_491521501707_item	2441464	et	4	main
produktsioon	doc_491521501707_item	2441466	et	3	main
kondisionerid	doc_491521501707_item	2441468	et	4	main
seal	doc_491521501707_item	2441470	et	4	main
olevad	doc_491521501707_item	2441478	et	4	main
kirjuta	doc_491521501708_item	2441487	et	4	main
oma	doc_491521501708_item	2441488	et	4	main
eestlasest	doc_491521501708_item	2441489	et	3	main
sõbrale	doc_491521501708_item	2441490	et	3	main
saa	doc_491521501708_item	2441492	et	4	main
praktikale	doc_491521501708_item	2441498	et	3	main
õppisid	doc_491521501708_item	2441507	et	4	main
sõber	doc_491521501708_item	2441524	et	3	main
sünnipäev	doc_491521501708_item	2441539	et	3	main
õnnitlemise	doc_491521501708_item	2441542	et	4	main
et	doc_491521501708_item	2441545	et	3	main
mul	doc_491521501708_item	2441550	et	3	main
seal	doc_491521501708_item	2441574	et	4	main
alused	doc_491521501708_item	2441577	et	4	main
alused	doc_491521501708_item	2441579	et	4	main
arvutiõpetus	doc_491521501708_item	2441591	et	3	main
varsti	doc_491521501708_item	2441595	et	3	main
lähen	doc_491521501708_item	2441597	et	3	main
as	doc_491521501708_item	2441609	et	4	main
jõhvis	doc_491521501708_item	2441615	et	3	main
mugav	doc_491521501708_item	2441618	et	3	main
elukoha	doc_491521501708_item	2441623	et	4	main
see	doc_491521501708_item	2441625	et	3	main
firma	doc_491521501708_item	2441626	et	4	main
müüb	doc_491521501708_item	2441627	et	3	main
ehitusmaterjalid	doc_491521501708_item	2441628	et	3	main
ja	doc_491521501708_item	2441629	et	3	main
praktikal	doc_491521501708_item	2441633	et	3	main
tervita	doc_491521501708_item	2441641	et	4	main
kõike	doc_491521501708_item	2441646	et	4	main
head	doc_491521501708_item	2441647	et	4	main
xxxxxxxx	doc_491521501708_item	2441649	et	4	main
24102003	doc_491521501708_item	2441650	et	2	main
kiri	doc_491521501710_item	2441794	et	3	main
kirjuta	doc_491521501710_item	2441795	et	4	main
kuidas	doc_491521501710_item	2441808	et	3	main
sul	doc_491521501710_item	2441809	et	3	main
läks	doc_491521501710_item	2441811	et	3	main
kiri	doc_491521501707_item	2441375	et	3	main
kiri	doc_491521501707_item	2441376	et	3	main
kirjuta	doc_491521501707_item	2441377	et	4	main
käid	doc_491521501707_item	2441383	et	3	main
lähed	doc_491521501707_item	2441387	et	3	main
sul	doc_491521501707_item	2441391	et	3	main
läks	doc_491521501707_item	2441393	et	3	main
kursustel	doc_491521501707_item	2441392	et	3	main
mida	doc_491521501707_item	2441394	et	4	main
sa	doc_491521501707_item	2441395	et	3	main
seal	doc_491521501707_item	2441396	et	4	main
õppisid	doc_491521501707_item	2441397	et	4	main
kuhu	doc_491521501707_item	2441398	et	3	main
sa	doc_491521501707_item	2441399	et	3	main
praktikale	doc_491521501707_item	2441400	et	3	main
lähed	doc_491521501707_item	2441401	et	3	main
millega	doc_491521501707_item	2441402	et	3	main
see	doc_491521501707_item	2441403	et	3	main
firma	doc_491521501707_item	2441404	et	4	main
tegeleb	doc_491521501707_item	2441405	et	3	main
ja	doc_491521501707_item	2441406	et	3	main
mida	doc_491521501707_item	2441407	et	4	main
sa	doc_491521501707_item	2441408	et	3	main
seal	doc_491521501707_item	2441409	et	4	main
tegema	doc_491521501707_item	2441410	et	3	main
hakkad	doc_491521501707_item	2441411	et	3	main
tere	doc_491521501707_item	2441412	et	3	main
liin	doc_491521501707_item	2441413	et	3	main
praegu	doc_491521501707_item	2441414	et	3	main
ma	doc_491521501707_item	2441415	et	3	main
lõpetasin	doc_491521501707_item	2441416	et	3	main
kursusel	doc_491521501707_item	2441417	et	3	main
müügisekretär	doc_491521501707_item	2441418	et	3	main
ja	doc_491521501707_item	2441419	et	3	main
hakkan	doc_491521501707_item	2441420	et	3	main
lähen	doc_491521501707_item	2441421	et	3	main
kursuses	doc_491521501707_item	2441423	et	3	main
midagi	doc_491521501707_item	2441442	et	4	main
on	doc_491521501707_item	2441425	et	4	main
ainult	doc_491521501707_item	2441427	et	4	main
arvutiõpetus	doc_491521501707_item	2441433	et	3	main
alused	doc_491521501707_item	2441436	et	4	main
turunduse	doc_491521501707_item	2441438	et	3	main
alused	doc_491521501707_item	2441439	et	4	main
aga	doc_491521501707_item	2441440	et	3	main
olen	doc_491521501707_item	2441441	et	3	main
nüüd	doc_491521501707_item	2441446	et	4	main
lähen	doc_491521501707_item	2441448	et	3	main
maha	doc_491521501707_item	2441458	et	4	main
jaemüük	doc_491521501707_item	2441459	et	3	main
elekter	doc_491521501707_item	2441465	et	3	main
ja	doc_491521501707_item	2441467	et	3	main
nägemiseni	doc_491521501707_item	2441483	et	4	main
kiri	doc_491521501708_item	2441485	et	3	main
kuidas	doc_491521501708_item	2441500	et	3	main
kursustel	doc_491521501708_item	2441502	et	3	main
sa	doc_491521501708_item	2441505	et	3	main
kuhu	doc_491521501708_item	2441508	et	3	main
sa	doc_491521501708_item	2441509	et	3	main
praktikale	doc_491521501708_item	2441510	et	3	main
lähed	doc_491521501708_item	2441511	et	3	main
millega	doc_491521501708_item	2441512	et	3	main
see	doc_491521501708_item	2441513	et	3	main
firma	doc_491521501708_item	2441514	et	4	main
tegeleb	doc_491521501708_item	2441515	et	3	main
ja	doc_491521501708_item	2441516	et	3	main
mida	doc_491521501708_item	2441517	et	4	main
sa	doc_491521501708_item	2441518	et	3	main
seal	doc_491521501708_item	2441519	et	4	main
tegema	doc_491521501708_item	2441520	et	3	main
hakkad	doc_491521501708_item	2441521	et	3	main
minu	doc_491521501708_item	2441523	et	3	main
monika	doc_491521501708_item	2441525	et	4	main
ma	doc_491521501708_item	2441526	et	3	main
sain	doc_491521501708_item	2441527	et	3	main
hiljutu	doc_491521501708_item	2441538	et	4	main
andesta	doc_491521501708_item	2441544	et	4	main
kirjutada	doc_491521501708_item	2441549	et	3	main
ma	doc_491521501708_item	2441564	et	3	main
lähen	doc_491521501708_item	2441565	et	3	main
läks	doc_491521501708_item	2441568	et	3	main
õppisin	doc_491521501708_item	2441573	et	3	main
mulle	doc_491521501708_item	2441588	et	4	main
väga	doc_491521501708_item	2441589	et	3	main
meeldis	doc_491521501708_item	2441590	et	3	main
teha	doc_491521501708_item	2441599	et	3	main
lähen	doc_491521501708_item	2441603	et	3	main
poodi	doc_491521501708_item	2441605	et	4	main
ida	doc_491521501708_item	2441611	et	4	main
pood	doc_491521501708_item	2441613	et	4	main
kauplus	doc_491521501708_item	2441620	et	3	main
hakkan	doc_491521501708_item	2441632	et	3	main
müüjale	doc_491521501708_item	2441635	et	4	main
sind	doc_491521501708_item	2441639	et	4	main
külla	doc_491521501708_item	2441640	et	4	main
ootan	doc_491521501708_item	2441644	et	3	main
jõhvi	doc_491521501708_item	2441651	et	4	main
hea	doc_491521501707_item	2441453	et	4	main
elektoskandia	doc_491521501707_item	2441455	et	4	main
firma	doc_491521501707_item	2441456	et	4	main
hulgimüük	doc_491521501707_item	2441461	et	3	main
järelmaksuga	doc_491521501707_item	2441463	et	3	main
nemad	doc_491521501707_item	2441477	et	3	main
seega	doc_491521501707_item	2441482	et	4	main
et	doc_491521501708_item	2441491	et	3	main
käid	doc_491521501708_item	2441493	et	3	main
kursustel	doc_491521501708_item	2441494	et	3	main
ja	doc_491521501708_item	2441495	et	3	main
varsti	doc_491521501708_item	2441496	et	3	main
lähed	doc_491521501708_item	2441497	et	3	main
mida	doc_491521501708_item	2441504	et	4	main
seal	doc_491521501708_item	2441506	et	4	main
sulle	doc_491521501708_item	2441532	et	3	main
aitäh	doc_491521501708_item	2441540	et	3	main
saanud	doc_491521501708_item	2441547	et	4	main
olnud	doc_491521501708_item	2441552	et	4	main
mul	doc_491521501708_item	2441567	et	3	main
väga	doc_491521501708_item	2441570	et	3	main
ma	doc_491521501708_item	2441572	et	3	main
keel	doc_491521501708_item	2441584	et	4	main
ja	doc_491521501708_item	2441585	et	3	main
palju	doc_491521501708_item	2441586	et	4	main
muud	doc_491521501708_item	2441587	et	4	main
eesti	doc_491521501708_item	2441593	et	4	main
ma	doc_491521501708_item	2441596	et	3	main
eksamit	doc_491521501708_item	2441598	et	3	main
taali	doc_491521501708_item	2441610	et	4	main
mulle	doc_491521501708_item	2441616	et	4	main
minu	doc_491521501708_item	2441622	et	3	main
majakabu	doc_491521501708_item	2441630	et	4	main
ma	doc_491521501708_item	2441631	et	3	main
abistama	doc_491521501708_item	2441634	et	3	main
ootan	doc_491521501708_item	2441638	et	3	main
vanemaid	doc_491521501708_item	2441643	et	4	main
soovides	doc_491521501708_item	2441648	et	4	main
4-d	doc_491521501707_item	2441473	et	4	main
mehed	doc_491521501707_item	2441474	et	3	main
ma	doc_491521501707_item	2441475	et	3	main
mõtlen	doc_491521501707_item	2441476	et	3	main
on	doc_491521501707_item	2441480	et	4	main
sõbranna	doc_491521501707_item	2441484	et	4	main
kiri	doc_491521501708_item	2441486	et	3	main
kirjuta	doc_491521501708_item	2441499	et	4	main
tere	doc_491521501708_item	2441522	et	3	main
kätte	doc_491521501708_item	2441530	et	4	main
oli	doc_491521501708_item	2441533	et	3	main
huvitav	doc_491521501708_item	2441535	et	4	main
mul	doc_491521501708_item	2441536	et	3	main
sulle	doc_491521501708_item	2441541	et	3	main
eest	doc_491521501708_item	2441543	et	4	main
ei	doc_491521501708_item	2441546	et	4	main
varsti	doc_491521501708_item	2441563	et	3	main
praktikale	doc_491521501708_item	2441566	et	3	main
kursustel	doc_491521501708_item	2441569	et	3	main
huvitav	doc_491521501708_item	2441571	et	4	main
ettevõtluse	doc_491521501708_item	2441576	et	3	main
psühholoogia	doc_491521501708_item	2441578	et	4	main
esmaabi	doc_491521501708_item	2441580	et	4	main
tööseadusandluse	doc_491521501708_item	2441581	et	3	main
keel	doc_491521501708_item	2441594	et	4	main
kohtla-järvel	doc_491521501708_item	2441600	et	4	main
ma	doc_491521501708_item	2441602	et	3	main
asub	doc_491521501708_item	2441614	et	3	main
sest	doc_491521501708_item	2441619	et	4	main
asub	doc_491521501708_item	2441621	et	3	main
lähedal	doc_491521501708_item	2441624	et	4	main
sellega	doc_491521501708_item	2441636	et	3	main
lõpetan	doc_491521501708_item	2441637	et	3	main
vastust	doc_491521501708_item	2441645	et	4	main
lähed	doc_491521501710_item	2441805	et	3	main
kuhu	doc_491521501710_item	2441816	et	3	main
praktikale	doc_491521501710_item	2441818	et	3	main
millega	doc_491521501710_item	2441820	et	3	main
firma	doc_491521501710_item	2441822	et	4	main
mida	doc_491521501710_item	2441825	et	4	main
sa	doc_491521501710_item	2441826	et	3	main
seal	doc_491521501710_item	2441827	et	4	main
tegema	doc_491521501710_item	2441828	et	3	main
oli	doc_491521501710_item	2441839	et	3	main
väga	doc_491521501710_item	2441840	et	3	main
huvitav	doc_491521501710_item	2441841	et	4	main
see	doc_491521501710_item	2441845	et	3	main
väga	doc_491521501710_item	2441847	et	3	main
tundi	doc_491521501710_item	2441880	et	4	main
alused	doc_491521501710_item	2441885	et	4	main
tööjõuturg	doc_491521501710_item	2441886	et	3	main
sinu	doc_491521501708_item	2441528	et	3	main
kirja	doc_491521501708_item	2441529	et	4	main
aitäh	doc_491521501708_item	2441531	et	3	main
väga	doc_491521501708_item	2441534	et	3	main
oli	doc_491521501708_item	2441537	et	3	main
kohe	doc_491521501708_item	2441548	et	4	main
ei	doc_491521501708_item	2441551	et	4	main
aega	doc_491521501708_item	2441553	et	4	main
mul	doc_491521501708_item	2441554	et	3	main
on	doc_491521501708_item	2441555	et	4	main
sulle	doc_491521501708_item	2441556	et	3	main
hea	doc_491521501708_item	2441557	et	4	main
uudis	doc_491521501708_item	2441558	et	3	main
ma	doc_491521501708_item	2441559	et	3	main
käin	doc_491521501708_item	2441560	et	3	main
müügisekretäri	doc_491521501708_item	2441561	et	4	main
kursustel	doc_491521501708_item	2441562	et	3	main
arvutiõpetus	doc_491521501708_item	2441575	et	3	main
alused	doc_491521501708_item	2441582	et	4	main
eesti	doc_491521501708_item	2441583	et	4	main
ja	doc_491521501708_item	2441592	et	3	main
algtase	doc_491521501708_item	2441601	et	3	main
praktikale	doc_491521501708_item	2441604	et	3	main
ehitusmaterjalid	doc_491521501708_item	2441606	et	3	main
ja	doc_491521501708_item	2441607	et	3	main
majakaup	doc_491521501708_item	2441608	et	3	main
see	doc_491521501708_item	2441612	et	3	main
väga	doc_491521501708_item	2441617	et	3	main
oma	doc_491521501708_item	2441642	et	4	main
kirjuta	doc_491521501710_item	2441807	et	4	main
mida	doc_491521501710_item	2441812	et	4	main
sa	doc_491521501710_item	2441817	et	3	main
tegeleb	doc_491521501710_item	2441823	et	3	main
sain	doc_491521501710_item	2441833	et	3	main
kiri	doc_491521501710_item	2441793	et	3	main
varsti	doc_491521501710_item	2441804	et	3	main
õppisid	doc_491521501710_item	2441815	et	4	main
ja	doc_491521501710_item	2441824	et	3	main
hakkad	doc_491521501710_item	2441829	et	3	main
tere	doc_491521501710_item	2441830	et	3	main
tiina	doc_491521501710_item	2441831	et	4	main
ma	doc_491521501710_item	2441832	et	3	main
ma	doc_491521501710_item	2441842	et	3	main
kea	doc_491521501710_item	2441858	et	4	main
tüdrukud	doc_491521501710_item	2441870	et	3	main
on	doc_491521501710_item	2441871	et	4	main
mul	doc_491521501710_item	2441873	et	3	main
on	doc_491521501710_item	2441874	et	4	main
uus	doc_491521501710_item	2441875	et	3	main
sõbrad	doc_491521501710_item	2441876	et	3	main
arvutiõpetus	doc_491521501710_item	2441881	et	3	main
psüholoogija	doc_491521501710_item	2441882	et	4	main
ettevõtluse	doc_491521501710_item	2441884	et	3	main
esmaabi	doc_491521501710_item	2441896	et	4	main
oma	doc_491521501710_item	2441796	et	4	main
eestlasest	doc_491521501710_item	2441797	et	3	main
sõbrale	doc_491521501710_item	2441798	et	3	main
et	doc_491521501710_item	2441799	et	3	main
saa	doc_491521501710_item	2441800	et	4	main
käid	doc_491521501710_item	2441801	et	3	main
kursustel	doc_491521501710_item	2441802	et	3	main
ja	doc_491521501710_item	2441803	et	3	main
praktikale	doc_491521501710_item	2441806	et	3	main
kursustel	doc_491521501710_item	2441810	et	3	main
seal	doc_491521501710_item	2441814	et	4	main
lähed	doc_491521501710_item	2441819	et	3	main
sinu	doc_491521501710_item	2441834	et	3	main
jõhvi	doc_491521501710_item	2441854	et	4	main
õpin	doc_491521501710_item	2441857	et	3	main
lõbus	doc_491521501710_item	2441868	et	4	main
seal	doc_491521501710_item	2441877	et	4	main
aktiivse	doc_491521501710_item	2441892	et	3	main
novembis	doc_491521501710_item	2441932	et	4	main
tahan	doc_491521501710_item	2441938	et	3	main
kursusel	doc_491521501710_item	2441944	et	3	main
palju	doc_491521501710_item	2441955	et	4	main
rääkida	doc_491521501710_item	2441956	et	3	main
kursetöö	doc_491521501710_item	2441958	et	4	main
äri-plaan	doc_491521501710_item	2441960	et	3	main
mul	doc_491521501710_item	2441961	et	3	main
ei	doc_491521501710_item	2441962	et	4	main
minu	doc_491521501710_item	2441970	et	3	main
evas	doc_491521501710_item	2441975	et	4	main
on	doc_491521501710_item	2442010	et	4	main
sind	doc_491521501710_item	2442018	et	4	main
helista	doc_491521501710_item	2442022	et	4	main
sa	doc_491521501710_item	2441813	et	3	main
see	doc_491521501710_item	2441821	et	3	main
aitah	doc_491521501710_item	2441837	et	4	main
sinule	doc_491521501710_item	2441838	et	3	main
kursusele	doc_491521501710_item	2441844	et	3	main
on	doc_491521501710_item	2441846	et	4	main
huvitav	doc_491521501710_item	2441848	et	4	main
kurs	doc_491521501710_item	2441849	et	4	main
müügisekretär	doc_491521501710_item	2441850	et	3	main
see	doc_491521501710_item	2441851	et	3	main
koht	doc_491521501710_item	2441852	et	3	main
on	doc_491521501710_item	2441853	et	4	main
ma	doc_491521501710_item	2441856	et	3	main
oli	doc_491521501710_item	2441878	et	3	main
alused	doc_491521501710_item	2441883	et	4	main
alused	doc_491521501710_item	2441894	et	4	main
eesti	doc_491521501710_item	2441897	et	4	main
ettevõttepraaktika	doc_491521501710_item	2441899	et	3	main
minu	doc_491521501710_item	2441900	et	3	main
tundid	doc_491521501710_item	2441902	et	4	main
on	doc_491521501710_item	2441903	et	4	main
arvutid	doc_491521501710_item	2441904	et	4	main
ja	doc_491521501710_item	2441905	et	3	main
eesti	doc_491521501710_item	2441906	et	4	main
keel	doc_491521501710_item	2441907	et	4	main
eesti	doc_491521501710_item	2441908	et	4	main
keel	doc_491521501710_item	2441909	et	4	main
mulle	doc_491521501710_item	2441910	et	4	main
meeldib	doc_491521501710_item	2441911	et	3	main
kõige	doc_491521501710_item	2441912	et	4	main
rohkem	doc_491521501710_item	2441913	et	4	main
õpetaja	doc_491521501710_item	2441914	et	4	main
xxxx	doc_491521501710_item	2441915	et	4	main
on	doc_491521501710_item	2441916	et	4	main
väga	doc_491521501710_item	2441917	et	3	main
huvitav	doc_491521501710_item	2441918	et	4	main
naine	doc_491521501710_item	2441919	et	3	main
ja	doc_491521501710_item	2441920	et	3	main
hea	doc_491521501710_item	2441922	et	4	main
praegu	doc_491521501710_item	2441924	et	3	main
mul	doc_491521501710_item	2441933	et	3	main
on	doc_491521501710_item	2441934	et	4	main
kvalifikatsiooni	doc_491521501710_item	2441935	et	4	main
edasines	doc_491521501710_item	2441942	et	3	main
on	doc_491521501710_item	2441950	et	4	main
enn	doc_491521501710_item	2441951	et	4	main
ta	doc_491521501710_item	2441953	et	4	main
nädalal	doc_491521501710_item	2441966	et	3	main
praaktika	doc_491521501710_item	2441969	et	3	main
lambid	doc_491521501710_item	2442006	et	4	main
seal	doc_491521501710_item	2442009	et	4	main
ja	doc_491521501710_item	2442012	et	3	main
kirjuta	doc_491521501710_item	2442020	et	4	main
soovides	doc_491521501710_item	2442026	et	4	main
xxxxx	doc_491521501710_item	2442027	et	4	main
kirja	doc_491521501710_item	2441835	et	4	main
kätte	doc_491521501710_item	2441836	et	4	main
käsin	doc_491521501710_item	2441843	et	3	main
kulturikeskuses	doc_491521501710_item	2441855	et	4	main
erakoolis	doc_491521501710_item	2441859	et	4	main
siin	doc_491521501710_item	2441860	et	4	main
õpivad	doc_491521501710_item	2441861	et	3	main
20	doc_491521501710_item	2441862	et	2	main
inimest	doc_491521501710_item	2441863	et	3	main
minu	doc_491521501710_item	2441864	et	3	main
grupp	doc_491521501710_item	2441865	et	3	main
on	doc_491521501710_item	2441866	et	4	main
väga	doc_491521501710_item	2441867	et	3	main
kõik	doc_491521501710_item	2441869	et	4	main
meeldiv	doc_491521501710_item	2441872	et	4	main
palju	doc_491521501710_item	2441879	et	4	main
asjaajamise	doc_491521501710_item	2441889	et	4	main
korraldamine	doc_491521501710_item	2441890	et	4	main
suhtlemistreening	doc_491521501710_item	2441891	et	3	main
müügi	doc_491521501710_item	2441893	et	4	main
keel	doc_491521501710_item	2441898	et	4	main
on	doc_491521501710_item	2441927	et	4	main
minu	doc_491521501710_item	2441928	et	3	main
lemmik	doc_491521501710_item	2441929	et	3	main
keel	doc_491521501710_item	2441930	et	4	main
2	doc_491521501710_item	2441931	et	2	main
imilikult	doc_491521501710_item	2441946	et	4	main
käis	doc_491521501710_item	2441952	et	4	main
armastab	doc_491521501710_item	2441954	et	3	main
minu	doc_491521501710_item	2441957	et	3	main
on	doc_491521501710_item	2441959	et	4	main
praaktika	doc_491521501710_item	2441971	et	3	main
on	doc_491521501710_item	2441973	et	4	main
ja	doc_491521501710_item	2442007	et	3	main
suhtlemine	doc_491521501710_item	2442013	et	4	main
sellega	doc_491521501710_item	2442015	et	3	main
ja	doc_491521501710_item	2442021	et	3	main
kõike	doc_491521501710_item	2442024	et	4	main
head	doc_491521501710_item	2442025	et	4	main
oktoober	doc_491521501710_item	2442029	et	3	main
turunduse	doc_491521501710_item	2441887	et	3	main
alused	doc_491521501710_item	2441888	et	4	main
töötervishoid	doc_491521501710_item	2441895	et	3	main
lemmik	doc_491521501710_item	2441901	et	3	main
õpetaja	doc_491521501710_item	2441923	et	4	main
eeksam	doc_491521501710_item	2441936	et	4	main
ma	doc_491521501710_item	2441937	et	3	main
õppida	doc_491521501710_item	2441939	et	3	main
keel	doc_491521501710_item	2441941	et	4	main
mees	doc_491521501710_item	2441947	et	4	main
nimi	doc_491521501710_item	2441949	et	3	main
järgmisel	doc_491521501710_item	2441965	et	3	main
hakkab	doc_491521501710_item	2441968	et	3	main
koht	doc_491521501710_item	2441972	et	3	main
kauplus	doc_491521501710_item	2441974	et	3	main
potid	doc_491521501710_item	2442004	et	4	main
aia-mööbel	doc_491521501710_item	2442005	et	3	main
teised	doc_491521501710_item	2442008	et	4	main
klientidega	doc_491521501710_item	2442014	et	3	main
lõpetan	doc_491521501710_item	2442016	et	3	main
külla	doc_491521501710_item	2442019	et	4	main
mulle	doc_491521501710_item	2442023	et	4	main
24	doc_491521501710_item	2442028	et	2	main
väga	doc_491521501710_item	2441921	et	3	main
eesti	doc_491521501710_item	2441925	et	4	main
keel	doc_491521501710_item	2441926	et	4	main
eesti	doc_491521501710_item	2441940	et	4	main
sellel	doc_491521501710_item	2441943	et	4	main
oli	doc_491521501710_item	2441945	et	3	main
tema	doc_491521501710_item	2441948	et	4	main
meeldi	doc_491521501710_item	2441963	et	4	main
see	doc_491521501710_item	2441964	et	3	main
mul	doc_491521501710_item	2441967	et	3	main
seal	doc_491521501710_item	2441976	et	4	main
ehitusmaterjaalid	doc_491521501710_item	2441978	et	4	main
minu	doc_491521501710_item	2441979	et	3	main
ei	doc_491521501710_item	2441980	et	4	main
on	doc_491521501710_item	2441977	et	4	main
võetud	doc_491521501710_item	2441981	et	4	main
müügisekretärina	doc_491521501710_item	2441982	et	3	main
ainult	doc_491521501710_item	2441983	et	4	main
müüjana	doc_491521501710_item	2441984	et	4	main
see	doc_491521501710_item	2441985	et	3	main
on	doc_491521501710_item	2441986	et	4	main
suur	doc_491521501710_item	2441987	et	3	main
pood	doc_491521501710_item	2441988	et	4	main
kaks	doc_491521501710_item	2441989	et	3	main
korrust	doc_491521501710_item	2441990	et	3	main
esimesel	doc_491521501710_item	2441991	et	3	main
korrusel	doc_491521501710_item	2441992	et	3	main
on	doc_491521501710_item	2441993	et	4	main
ehitusmaterjaalid	doc_491521501710_item	2441994	et	4	main
tapeedit	doc_491521501710_item	2441995	et	4	main
keraamilised	doc_491521501710_item	2441996	et	3	main
plaadit	doc_491521501710_item	2441997	et	4	main
värvid	doc_491521501710_item	2441998	et	4	main
santehnika	doc_491521501710_item	2441999	et	4	main
teisel	doc_491521501710_item	2442000	et	4	main
korrusel	doc_491521501710_item	2442001	et	3	main
aia	doc_491521501710_item	2442003	et	4	main
on	doc_491521501710_item	2442002	et	4	main
müügipraaktika	doc_491521501710_item	2442011	et	3	main
ootan	doc_491521501710_item	2442017	et	3	main
huvitavalt	doc_491521501715_item	2442539	et	4	main
ja	doc_491521501715_item	2442547	et	3	main
meeldis	doc_491521501715_item	2442549	et	3	main
kõige	doc_491521501715_item	2442550	et	4	main
eesti	doc_491521501715_item	2442554	et	4	main
kirja	doc_491521501715_item	2442562	et	4	main
tunni	doc_491521501715_item	2442565	et	3	main
praktikale	doc_491521501715_item	2442573	et	3	main
aga	doc_491521501715_item	2442576	et	3	main
kiri	doc_491521501715_item	2442475	et	3	main
käin	doc_491521501715_item	2442524	et	3	main
uus	doc_491521501715_item	2442542	et	3	main
palju	doc_491521501715_item	2442545	et	4	main
arvuti	doc_491521501715_item	2442552	et	4	main
kirjutan	doc_491521501715_item	2442560	et	3	main
eesti	doc_491521501715_item	2442563	et	4	main
keelest	doc_491521501715_item	2442564	et	4	main
minu	doc_491521501715_item	2442566	et	3	main
eriala	doc_491521501715_item	2442567	et	4	main
üks	doc_491521501715_item	2442574	et	3	main
oma	doc_491521501715_item	2442478	et	4	main
eestlasest	doc_491521501715_item	2442479	et	3	main
sõbrale	doc_491521501715_item	2442480	et	3	main
et	doc_491521501715_item	2442481	et	3	main
saa	doc_491521501715_item	2442482	et	4	main
käid	doc_491521501715_item	2442483	et	3	main
ja	doc_491521501715_item	2442485	et	3	main
varsti	doc_491521501715_item	2442486	et	3	main
öelda	doc_491521501715_item	2442521	et	4	main
värsti	doc_491521501715_item	2442527	et	4	main
kirjutan	doc_491521501715_item	2442531	et	3	main
kuidas	doc_491521501715_item	2442533	et	3	main
kursusel	doc_491521501715_item	2442535	et	3	main
ja	doc_491521501715_item	2442540	et	3	main
ja	doc_491521501715_item	2442553	et	3	main
prägu	doc_491521501715_item	2442558	et	4	main
lähen	doc_491521501715_item	2442572	et	3	main
seal	doc_491521501715_item	2442582	et	4	main
see	doc_491521501715_item	2442585	et	3	main
lõpetan	doc_491521501715_item	2442595	et	3	main
aega	doc_491521501715_item	2442599	et	4	main
sa	doc_491521501717_item	2442722	et	3	main
lähed	doc_491521501717_item	2442724	et	3	main
see	doc_491521501717_item	2442726	et	3	main
mida	doc_491521501717_item	2442730	et	4	main
sa	doc_491521501717_item	2442731	et	3	main
tegema	doc_491521501717_item	2442733	et	3	main
hakkad	doc_491521501717_item	2442734	et	3	main
oli	doc_491521501717_item	2442747	et	3	main
veel	doc_491521501717_item	2442758	et	4	main
varsti	doc_491521501717_item	2442761	et	3	main
as	doc_491521501717_item	2442767	et	4	main
seal	doc_491521501717_item	2442768	et	4	main
üks	doc_491521501717_item	2442778	et	3	main
saada	doc_491521501717_item	2442793	et	4	main
mina	doc_491521501717_item	2442796	et	4	main
palju	doc_491521501717_item	2442812	et	4	main
kirjuta	doc_491521501715_item	2442477	et	4	main
kursustel	doc_491521501715_item	2442484	et	3	main
lähed	doc_491521501715_item	2442487	et	3	main
praktikale	doc_491521501715_item	2442488	et	3	main
kirjuta	doc_491521501715_item	2442489	et	4	main
sul	doc_491521501715_item	2442491	et	3	main
kursustel	doc_491521501715_item	2442492	et	3	main
kuidas	doc_491521501715_item	2442490	et	3	main
läks	doc_491521501715_item	2442493	et	3	main
mida	doc_491521501715_item	2442494	et	4	main
seal	doc_491521501715_item	2442496	et	4	main
õppisid	doc_491521501715_item	2442497	et	4	main
kuhu	doc_491521501715_item	2442498	et	3	main
sa	doc_491521501715_item	2442499	et	3	main
sa	doc_491521501715_item	2442495	et	3	main
praktikale	doc_491521501715_item	2442500	et	3	main
lähed	doc_491521501715_item	2442501	et	3	main
millega	doc_491521501715_item	2442502	et	3	main
see	doc_491521501715_item	2442503	et	3	main
firma	doc_491521501715_item	2442504	et	4	main
tegeleb	doc_491521501715_item	2442505	et	3	main
ja	doc_491521501715_item	2442506	et	3	main
mida	doc_491521501715_item	2442507	et	4	main
sa	doc_491521501715_item	2442508	et	3	main
seal	doc_491521501715_item	2442509	et	4	main
tegema	doc_491521501715_item	2442510	et	3	main
hakkad	doc_491521501715_item	2442511	et	3	main
tere	doc_491521501715_item	2442512	et	3	main
kallis	doc_491521501715_item	2442513	et	4	main
sõber	doc_491521501715_item	2442514	et	3	main
kirjutan	doc_491521501715_item	2442515	et	3	main
sulle	doc_491521501715_item	2442516	et	3	main
eesti	doc_491521501715_item	2442517	et	4	main
keeles	doc_491521501715_item	2442518	et	4	main
tahan	doc_491521501715_item	2442519	et	3	main
sulle	doc_491521501715_item	2442520	et	3	main
kiri	doc_491521501715_item	2442476	et	3	main
ma	doc_491521501715_item	2442523	et	3	main
praktikale	doc_491521501715_item	2442529	et	3	main
ma	doc_491521501715_item	2442530	et	3	main
sulle	doc_491521501715_item	2442532	et	3	main
mul	doc_491521501715_item	2442534	et	3	main
läks	doc_491521501715_item	2442536	et	3	main
oli	doc_491521501715_item	2442538	et	3	main
palju	doc_491521501715_item	2442541	et	4	main
ma	doc_491521501715_item	2442543	et	3	main
tunni	doc_491521501715_item	2442546	et	3	main
mulle	doc_491521501715_item	2442548	et	4	main
rohkem	doc_491521501715_item	2442551	et	4	main
tund	doc_491521501715_item	2442556	et	3	main
ma	doc_491521501715_item	2442559	et	3	main
järgi	doc_491521501715_item	2442568	et	4	main
müügisekretär	doc_491521501715_item	2442569	et	3	main
värsti	doc_491521501715_item	2442570	et	4	main
ma	doc_491521501715_item	2442571	et	3	main
ei	doc_491521501715_item	2442578	et	4	main
ma	doc_491521501715_item	2442581	et	3	main
ma	doc_491521501715_item	2442594	et	3	main
kuhu	doc_491521501717_item	2442721	et	3	main
tahan	doc_491521501717_item	2442738	et	3	main
seal	doc_491521501717_item	2442746	et	4	main
huvitavad	doc_491521501717_item	2442749	et	4	main
eesti	doc_491521501717_item	2442754	et	4	main
palju	doc_491521501717_item	2442759	et	4	main
tööitama	doc_491521501717_item	2442771	et	4	main
ja	doc_491521501717_item	2442773	et	3	main
aga	doc_491521501717_item	2442775	et	3	main
mull	doc_491521501717_item	2442776	et	3	main
on	doc_491521501717_item	2442777	et	4	main
et	doc_491521501717_item	2442780	et	3	main
firmas	doc_491521501717_item	2442791	et	3	main
mina	doc_491521501717_item	2442799	et	4	main
arvan	doc_491521501717_item	2442800	et	3	main
mulle	doc_491521501717_item	2442805	et	4	main
huvitavad	doc_491521501717_item	2442807	et	4	main
mõtet	doc_491521501717_item	2442808	et	3	main
kohtume	doc_491521501717_item	2442809	et	3	main
varsti	doc_491521501717_item	2442810	et	3	main
et	doc_491521501715_item	2442522	et	3	main
kursusele	doc_491521501715_item	2442525	et	3	main
ja	doc_491521501715_item	2442526	et	3	main
lähen	doc_491521501715_item	2442528	et	3	main
seal	doc_491521501715_item	2442537	et	4	main
õppisin	doc_491521501715_item	2442544	et	3	main
keel	doc_491521501715_item	2442555	et	4	main
ja	doc_491521501715_item	2442557	et	3	main
sulle	doc_491521501715_item	2442561	et	3	main
büroose	doc_491521501715_item	2442575	et	4	main
meldima	doc_491521501715_item	2442593	et	3	main
kirja	doc_491521501715_item	2442597	et	4	main
firma	doc_491521501717_item	2442727	et	4	main
kuidas	doc_491521501717_item	2442741	et	3	main
müügisekretär	doc_491521501717_item	2442745	et	3	main
õppisin	doc_491521501717_item	2442753	et	3	main
arvuti	doc_491521501717_item	2442756	et	4	main
hakkan	doc_491521501717_item	2442770	et	3	main
firma	doc_491521501717_item	2442786	et	4	main
teib	doc_491521501717_item	2442787	et	3	main
rohkem	doc_491521501717_item	2442792	et	4	main
et	doc_491521501717_item	2442801	et	3	main
säilib	doc_491521501717_item	2442804	et	3	main
palju	doc_491521501717_item	2442806	et	4	main
kõigile	doc_491521501717_item	2442811	et	4	main
ma	doc_491521501715_item	2442577	et	3	main
tea	doc_491521501715_item	2442579	et	4	main
mida	doc_491521501715_item	2442580	et	4	main
tegema	doc_491521501715_item	2442584	et	3	main
büroo	doc_491521501715_item	2442586	et	4	main
mulle	doc_491521501715_item	2442591	et	4	main
head	doc_491521501715_item	2442598	et	4	main
akkan	doc_491521501715_item	2442583	et	4	main
tegelab	doc_491521501715_item	2442587	et	4	main
ettevõetluses	doc_491521501715_item	2442588	et	4	main
ma	doc_491521501715_item	2442589	et	3	main
mõtlen	doc_491521501715_item	2442590	et	3	main
seal	doc_491521501715_item	2442592	et	4	main
oma	doc_491521501715_item	2442596	et	4	main
praktikale	doc_491521501717_item	2442723	et	3	main
tegeleb	doc_491521501717_item	2442728	et	3	main
ja	doc_491521501717_item	2442729	et	3	main
seal	doc_491521501717_item	2442732	et	4	main
tere	doc_491521501717_item	2442735	et	3	main
kallis	doc_491521501717_item	2442736	et	4	main
sõber	doc_491521501717_item	2442737	et	3	main
mina	doc_491521501717_item	2442742	et	4	main
kursusele	doc_491521501717_item	2442744	et	3	main
vaga	doc_491521501717_item	2442748	et	4	main
tundid	doc_491521501717_item	2442750	et	4	main
seal	doc_491521501717_item	2442751	et	4	main
kell	doc_491521501717_item	2442755	et	3	main
ja	doc_491521501717_item	2442757	et	3	main
mina	doc_491521501717_item	2442762	et	4	main
lahen	doc_491521501717_item	2442763	et	4	main
viru	doc_491521501717_item	2442765	et	4	main
vell	doc_491521501717_item	2442782	et	4	main
eitja	doc_491521501717_item	2442783	et	4	main
mida	doc_491521501717_item	2442784	et	4	main
see	doc_491521501717_item	2442785	et	3	main
mina	doc_491521501717_item	2442788	et	4	main
firmas	doc_491521501717_item	2442795	et	3	main
pidama	doc_491521501717_item	2442797	et	4	main
osastav	doc_491521501717_item	2442798	et	4	main
firma	doc_491521501717_item	2442803	et	4	main
kiri	doc_491521501719_item	2442953	et	3	main
eestlasest	doc_491521501719_item	2442956	et	3	main
et	doc_491521501719_item	2442958	et	3	main
lähed	doc_491521501719_item	2442964	et	3	main
õppisid	doc_491521501719_item	2442974	et	4	main
kuhu	doc_491521501719_item	2442975	et	3	main
praktikale	doc_491521501719_item	2442977	et	3	main
millega	doc_491521501719_item	2442979	et	3	main
firma	doc_491521501719_item	2442981	et	4	main
kiri	doc_491521501717_item	2442698	et	3	main
kiri	doc_491521501717_item	2442699	et	3	main
kirjuta	doc_491521501717_item	2442700	et	4	main
oma	doc_491521501717_item	2442701	et	4	main
eestlasest	doc_491521501717_item	2442702	et	3	main
sõbrale	doc_491521501717_item	2442703	et	3	main
et	doc_491521501717_item	2442704	et	3	main
saa	doc_491521501717_item	2442705	et	4	main
käid	doc_491521501717_item	2442706	et	3	main
kursustel	doc_491521501717_item	2442707	et	3	main
ja	doc_491521501717_item	2442708	et	3	main
varsti	doc_491521501717_item	2442709	et	3	main
lähed	doc_491521501717_item	2442710	et	3	main
praktikale	doc_491521501717_item	2442711	et	3	main
kirjuta	doc_491521501717_item	2442712	et	4	main
kuidas	doc_491521501717_item	2442713	et	3	main
kursustel	doc_491521501717_item	2442715	et	3	main
sul	doc_491521501717_item	2442714	et	3	main
läks	doc_491521501717_item	2442716	et	3	main
mida	doc_491521501717_item	2442717	et	4	main
sa	doc_491521501717_item	2442718	et	3	main
seal	doc_491521501717_item	2442719	et	4	main
õppisid	doc_491521501717_item	2442720	et	4	main
millega	doc_491521501717_item	2442725	et	3	main
sulle	doc_491521501717_item	2442739	et	3	main
kirjutama	doc_491521501717_item	2442740	et	3	main
käisin	doc_491521501717_item	2442743	et	3	main
mina	doc_491521501717_item	2442752	et	4	main
tundeid	doc_491521501717_item	2442760	et	3	main
praktikase	doc_491521501717_item	2442764	et	4	main
liimid	doc_491521501717_item	2442766	et	4	main
ma	doc_491521501717_item	2442769	et	3	main
paberiga	doc_491521501717_item	2442772	et	4	main
arvutiga	doc_491521501717_item	2442774	et	4	main
kahjuks	doc_491521501717_item	2442779	et	4	main
mina	doc_491521501717_item	2442781	et	4	main
tahan	doc_491521501717_item	2442789	et	3	main
seele	doc_491521501717_item	2442790	et	4	main
seal	doc_491521501717_item	2442794	et	4	main
see	doc_491521501717_item	2442802	et	3	main
tervisi	doc_491521501717_item	2442813	et	3	main
xxxxxxx	doc_491521501717_item	2442814	et	4	main
xxxxxx	doc_491521501717_item	2442815	et	4	main
oma	doc_491521501719_item	2442955	et	4	main
kursustel	doc_491521501719_item	2442961	et	3	main
praktikale	doc_491521501719_item	2442965	et	3	main
kuidas	doc_491521501719_item	2442967	et	3	main
mida	doc_491521501719_item	2442971	et	4	main
ja	doc_491521501719_item	2443018	et	3	main
meile	doc_491521501719_item	2443021	et	4	main
arvitioski	doc_491521501719_item	2443023	et	4	main
esmaabi	doc_491521501719_item	2443026	et	4	main
kursuseid	doc_491521501719_item	2443027	et	3	main
seletati	doc_491521501719_item	2443028	et	3	main
seda	doc_491521501719_item	2443030	et	3	main
oma	doc_491521501719_item	2443033	et	4	main
eesti	doc_491521501719_item	2443046	et	4	main
keele	doc_491521501719_item	2443047	et	4	main
pärast	doc_491521501719_item	2443050	et	4	main
kursused	doc_491521501719_item	2443056	et	3	main
hakkama	doc_491521501719_item	2443064	et	3	main
eriala	doc_491521501719_item	2443067	et	4	main
tahan	doc_491521501719_item	2443075	et	3	main
kavatsen	doc_491521501719_item	2443076	et	3	main
head	doc_491521501719_item	2443086	et	4	main
xxxxxxxxx	doc_491521501719_item	2443087	et	4	main
24102003	doc_491521501719_item	2443088	et	2	main
saa	doc_491521501719_item	2442959	et	4	main
ja	doc_491521501719_item	2442962	et	3	main
sul	doc_491521501719_item	2442968	et	3	main
kursustel	doc_491521501719_item	2442969	et	3	main
seal	doc_491521501719_item	2442973	et	4	main
huvitavat	doc_491521501719_item	2443019	et	4	main
mul	doc_491521501719_item	2443045	et	3	main
tegelen	doc_491521501719_item	2443051	et	3	main
praktikaga	doc_491521501719_item	2443053	et	3	main
sellega	doc_491521501719_item	2443054	et	3	main
olen	doc_491521501719_item	2443058	et	3	main
kindel	doc_491521501719_item	2443059	et	3	main
selle	doc_491521501719_item	2443060	et	4	main
et	doc_491521501719_item	2443061	et	3	main
saan	doc_491521501719_item	2443062	et	4	main
kuidagi	doc_491521501719_item	2443063	et	3	main
huvitat	doc_491521501719_item	2443070	et	4	main
ma	doc_491521501719_item	2443074	et	3	main
jooksul	doc_491521501719_item	2443079	et	4	main
et	doc_491521501719_item	2443081	et	3	main
kiri	doc_491521501721_item	2443197	et	3	main
firma	doc_491521501721_item	2443225	et	4	main
ja	doc_491521501721_item	2443227	et	3	main
kallis	doc_491521501721_item	2443237	et	4	main
minema	doc_491521501721_item	2443243	et	3	main
ma	doc_491521501721_item	2443246	et	3	main
jõhvis	doc_491521501721_item	2443251	et	3	main
eesti	doc_491521501721_item	2443264	et	4	main
meeldivad	doc_491521501721_item	2443268	et	4	main
ja	doc_491521501721_item	2443276	et	3	main
aga	doc_491521501721_item	2443288	et	3	main
hakkasin	doc_491521501721_item	2443293	et	3	main
ehituskauplus	doc_491521501721_item	2443307	et	3	main
kliendi	doc_491521501721_item	2443316	et	3	main
töötan	doc_491521501721_item	2443320	et	3	main
lugupidamisega	doc_491521501721_item	2443322	et	3	main
kirjuta	doc_491521501719_item	2442954	et	4	main
käid	doc_491521501719_item	2442960	et	3	main
varsti	doc_491521501719_item	2442963	et	3	main
kirjuta	doc_491521501719_item	2442966	et	4	main
läks	doc_491521501719_item	2442970	et	3	main
palju	doc_491521501719_item	2443016	et	4	main
uut	doc_491521501719_item	2443017	et	3	main
kuidas	doc_491521501719_item	2443031	et	3	main
alustada	doc_491521501719_item	2443032	et	3	main
seadus	doc_491521501719_item	2443036	et	4	main
ja	doc_491521501719_item	2443038	et	3	main
kidas	doc_491521501719_item	2443039	et	3	main
raamatupidamis	doc_491521501719_item	2443040	et	4	main
eksamit	doc_491521501719_item	2443048	et	3	main
omandan	doc_491521501719_item	2443066	et	3	main
tõesti	doc_491521501719_item	2443069	et	3	main
ja	doc_491521501719_item	2443072	et	3	main
tegeleda	doc_491521501719_item	2443077	et	3	main
kõike	doc_491521501719_item	2443085	et	4	main
kiri	doc_491521501721_item	2443196	et	3	main
kiri	doc_491521501719_item	2442952	et	3	main
sõbrale	doc_491521501719_item	2442957	et	3	main
sa	doc_491521501719_item	2442972	et	3	main
sa	doc_491521501719_item	2442976	et	3	main
lähed	doc_491521501719_item	2442978	et	3	main
see	doc_491521501719_item	2442980	et	3	main
tegeleb	doc_491521501719_item	2442982	et	3	main
ja	doc_491521501719_item	2442983	et	3	main
mida	doc_491521501719_item	2442984	et	4	main
sa	doc_491521501719_item	2442985	et	3	main
seal	doc_491521501719_item	2442986	et	4	main
tegema	doc_491521501719_item	2442987	et	3	main
hakkad	doc_491521501719_item	2442988	et	3	main
tere	doc_491521501719_item	2442989	et	3	main
anena	doc_491521501719_item	2442990	et	4	main
kuidas	doc_491521501719_item	2442991	et	3	main
sul	doc_491521501719_item	2442992	et	3	main
läheb	doc_491521501719_item	2442993	et	3	main
millega	doc_491521501719_item	2442994	et	3	main
tegeled	doc_491521501719_item	2442995	et	3	main
kas	doc_491521501719_item	2442996	et	3	main
on	doc_491521501719_item	2442997	et	4	main
midagi	doc_491521501719_item	2442998	et	4	main
uut	doc_491521501719_item	2442999	et	3	main
mul	doc_491521501719_item	2443000	et	3	main
ei	doc_491521501719_item	2443001	et	4	main
ole	doc_491521501719_item	2443002	et	4	main
eriti	doc_491521501719_item	2443003	et	3	main
uudist	doc_491521501719_item	2443005	et	3	main
käin	doc_491521501719_item	2443006	et	3	main
juba	doc_491521501719_item	2443008	et	3	main
kolm	doc_491521501719_item	2443009	et	3	main
palju	doc_491521501719_item	2443004	et	4	main
kuud	doc_491521501719_item	2443010	et	4	main
börsikursule	doc_491521501719_item	2443007	et	4	main
müügisekretäri	doc_491521501719_item	2443011	et	4	main
erialal	doc_491521501719_item	2443012	et	3	main
olen	doc_491521501719_item	2443013	et	3	main
teada	doc_491521501719_item	2443014	et	3	main
informatsiooni	doc_491521501719_item	2443020	et	4	main
ja	doc_491521501719_item	2443025	et	3	main
ka	doc_491521501719_item	2443029	et	3	main
äri	doc_491521501719_item	2443034	et	4	main
toimivad	doc_491521501719_item	2443037	et	4	main
kuuaega	doc_491521501719_item	2443052	et	4	main
mis	doc_491521501719_item	2443068	et	4	main
mind	doc_491521501719_item	2443071	et	4	main
eluaja	doc_491521501719_item	2443078	et	3	main
loodan	doc_491521501719_item	2443080	et	3	main
saan	doc_491521501719_item	2443082	et	4	main
sinult	doc_491521501719_item	2443083	et	3	main
vastust	doc_491521501719_item	2443084	et	4	main
see	doc_491521501721_item	2443224	et	3	main
sa	doc_491521501721_item	2443229	et	3	main
tegema	doc_491521501721_item	2443231	et	3	main
hakkad	doc_491521501721_item	2443232	et	3	main
24	doc_491521501721_item	2443234	et	2	main
mulle	doc_491521501721_item	2443239	et	4	main
augustil	doc_491521501721_item	2443241	et	3	main
müügisekretär	doc_491521501721_item	2443245	et	3	main
iga	doc_491521501721_item	2443248	et	4	main
õpisin	doc_491521501721_item	2443253	et	4	main
mulle	doc_491521501721_item	2443266	et	4	main
ei	doc_491521501721_item	2443280	et	4	main
varem	doc_491521501721_item	2443282	et	4	main
räägida	doc_491521501721_item	2443287	et	4	main
ja	doc_491521501721_item	2443296	et	3	main
kirjutada	doc_491521501721_item	2443297	et	3	main
ma	doc_491521501721_item	2443298	et	3	main
praktikus	doc_491521501721_item	2443302	et	3	main
ma	doc_491521501721_item	2443308	et	3	main
vormistama	doc_491521501721_item	2443311	et	3	main
töötama	doc_491521501721_item	2443315	et	3	main
saanud	doc_491521501719_item	2443015	et	4	main
õpetatakse	doc_491521501719_item	2443022	et	3	main
klienditeenindust	doc_491521501719_item	2443024	et	3	main
millised	doc_491521501719_item	2443035	et	3	main
toime	doc_491521501719_item	2443041	et	4	main
tulla	doc_491521501719_item	2443042	et	3	main
varsti	doc_491521501719_item	2443043	et	3	main
tuleb	doc_491521501719_item	2443044	et	3	main
sooritada	doc_491521501719_item	2443049	et	3	main
minu	doc_491521501719_item	2443055	et	3	main
lõppevadki	doc_491521501719_item	2443057	et	4	main
ja	doc_491521501719_item	2443065	et	3	main
millega	doc_491521501719_item	2443073	et	3	main
oma	doc_491521501721_item	2443199	et	4	main
eestlasest	doc_491521501721_item	2443200	et	3	main
jõhvis	doc_491521501721_item	2443233	et	3	main
oktoobril	doc_491521501721_item	2443235	et	3	main
õppima	doc_491521501721_item	2443242	et	3	main
käisin	doc_491521501721_item	2443247	et	3	main
päev	doc_491521501721_item	2443249	et	3	main
kultuurikeskus	doc_491521501721_item	2443250	et	3	main
järgmisel	doc_491521501721_item	2443254	et	3	main
väga	doc_491521501721_item	2443267	et	3	main
tema	doc_491521501721_item	2443271	et	4	main
on	doc_491521501721_item	2443272	et	4	main
kirjuta	doc_491521501721_item	2443198	et	4	main
sõbrale	doc_491521501721_item	2443201	et	3	main
et	doc_491521501721_item	2443202	et	3	main
saa	doc_491521501721_item	2443203	et	4	main
käid	doc_491521501721_item	2443204	et	3	main
kursustel	doc_491521501721_item	2443205	et	3	main
ja	doc_491521501721_item	2443206	et	3	main
varsti	doc_491521501721_item	2443207	et	3	main
lähed	doc_491521501721_item	2443208	et	3	main
praktikale	doc_491521501721_item	2443209	et	3	main
kirjuta	doc_491521501721_item	2443210	et	4	main
kuidas	doc_491521501721_item	2443211	et	3	main
sul	doc_491521501721_item	2443212	et	3	main
kursustel	doc_491521501721_item	2443213	et	3	main
läks	doc_491521501721_item	2443214	et	3	main
sa	doc_491521501721_item	2443216	et	3	main
seal	doc_491521501721_item	2443217	et	4	main
mida	doc_491521501721_item	2443215	et	4	main
õppisid	doc_491521501721_item	2443218	et	4	main
kuhu	doc_491521501721_item	2443219	et	3	main
sa	doc_491521501721_item	2443220	et	3	main
lähed	doc_491521501721_item	2443222	et	3	main
millega	doc_491521501721_item	2443223	et	3	main
mida	doc_491521501721_item	2443228	et	4	main
pakkumis	doc_491521501721_item	2443240	et	4	main
õpetaja	doc_491521501721_item	2443269	et	4	main
arukas	doc_491521501721_item	2443275	et	4	main
hakka	doc_491521501721_item	2443281	et	4	main
eesti	doc_491521501721_item	2443283	et	4	main
kui	doc_491521501721_item	2443289	et	3	main
mind	doc_491521501721_item	2443291	et	4	main
see	doc_491521501721_item	2443305	et	3	main
dokumente	doc_491521501721_item	2443312	et	3	main
tulevikus	doc_491521501721_item	2443317	et	4	main
xxxxxx	doc_491521501721_item	2443323	et	4	main
praktikale	doc_491521501721_item	2443221	et	3	main
tegeleb	doc_491521501721_item	2443226	et	3	main
seal	doc_491521501721_item	2443230	et	4	main
tere	doc_491521501721_item	2443236	et	3	main
sõber	doc_491521501721_item	2443238	et	3	main
kursus	doc_491521501721_item	2443244	et	3	main
ma	doc_491521501721_item	2443252	et	3	main
õppeaine	doc_491521501721_item	2443255	et	4	main
arvutiõpetus	doc_491521501721_item	2443256	et	3	main
psühholoogia	doc_491521501721_item	2443257	et	4	main
alused	doc_491521501721_item	2443258	et	4	main
esmaabi	doc_491521501721_item	2443259	et	4	main
aktiivse	doc_491521501721_item	2443260	et	3	main
müügi	doc_491521501721_item	2443261	et	4	main
alused	doc_491521501721_item	2443262	et	4	main
ja	doc_491521501721_item	2443263	et	3	main
keel	doc_491521501721_item	2443265	et	4	main
irma	doc_491521501721_item	2443270	et	4	main
huvitav	doc_491521501721_item	2443274	et	4	main
naine	doc_491521501721_item	2443278	et	3	main
ma	doc_491521501721_item	2443279	et	3	main
mitte	doc_491521501721_item	2443285	et	3	main
ma	doc_491521501721_item	2443292	et	3	main
räägida	doc_491521501721_item	2443295	et	4	main
järgmine	doc_491521501721_item	2443300	et	3	main
abc	doc_491521501721_item	2443304	et	4	main
on	doc_491521501721_item	2443306	et	4	main
õppima	doc_491521501721_item	2443310	et	3	main
kirjutama	doc_491521501721_item	2443313	et	3	main
soovin	doc_491521501721_item	2443319	et	3	main
sponsor	doc_491521501724_item	2443584	et	3	main
käia	doc_491521501724_item	2443596	et	4	main
teatrisse	doc_491521501724_item	2443599	et	3	main
2122	doc_491521501724_item	2443602	et	2	main
30000	doc_491521501724_item	2443628	et	2	main
eek	doc_491521501724_item	2443629	et	4	main
hinna	doc_491521501724_item	2443630	et	3	main
aidake	doc_491521501724_item	2443650	et	4	main
meile	doc_491521501724_item	2443651	et	4	main
see	doc_491521501724_item	2443653	et	3	main
ettendusel	doc_491521501724_item	2443661	et	4	main
lapsepõlves	doc_491521501725_item	2443674	et	4	main
saada	doc_491521501725_item	2443677	et	4	main
ärritab	doc_491521501725_item	2443716	et	3	main
välja	doc_491521501725_item	2443726	et	4	main
väga	doc_491521501721_item	2443273	et	3	main
rahulik	doc_491521501721_item	2443277	et	3	main
keeles	doc_491521501721_item	2443284	et	4	main
midagi	doc_491521501721_item	2443286	et	4	main
kursuse	doc_491521501721_item	2443290	et	3	main
natuke	doc_491521501721_item	2443294	et	4	main
lähen	doc_491521501721_item	2443299	et	3	main
kuuendal	doc_491521501721_item	2443301	et	3	main
kaupluses	doc_491521501721_item	2443303	et	3	main
olen	doc_491521501721_item	2443309	et	3	main
kiri	doc_491521501721_item	2443314	et	3	main
ma	doc_491521501721_item	2443318	et	3	main
müügisekretärina	doc_491521501721_item	2443321	et	3	main
on	doc_491521501724_item	2443586	et	4	main
palve	doc_491521501724_item	2443588	et	4	main
meie	doc_491521501724_item	2443589	et	4	main
tahaksime	doc_491521501724_item	2443595	et	3	main
peterburi	doc_491521501724_item	2443597	et	4	main
juunil	doc_491521501724_item	2443603	et	3	main
aidata	doc_491521501724_item	2443621	et	4	main
on	doc_491521501724_item	2443633	et	4	main
edasi-tagasi	doc_491521501724_item	2443634	et	3	main
rongipilet	doc_491521501724_item	2443635	et	3	main
teatripiletid	doc_491521501724_item	2443636	et	3	main
hommiku-	doc_491521501724_item	2443637	et	3	main
ja	doc_491521501724_item	2443638	et	3	main
külastamine	doc_491521501724_item	2443648	et	4	main
on	doc_491521501724_item	2443654	et	4	main
väga	doc_491521501724_item	2443655	et	3	main
oluline	doc_491521501724_item	2443656	et	4	main
kultuuri	doc_491521501724_item	2443660	et	4	main
jääme	doc_491521501724_item	2443662	et	4	main
vastus	doc_491521501724_item	2443665	et	3	main
loodame	doc_491521501724_item	2443667	et	3	main
luurajaks	doc_491521501725_item	2443678	et	4	main
köitis	doc_491521501725_item	2443680	et	3	main
küll	doc_491521501725_item	2443721	et	4	main
ei	doc_491521501725_item	2443723	et	4	main
ütle	doc_491521501725_item	2443724	et	4	main
inimestele	doc_491521501725_item	2443725	et	3	main
kuid	doc_491521501725_item	2443732	et	4	main
hoidun	doc_491521501725_item	2443733	et	3	main
mul	doc_491521501724_item	2443585	et	3	main
grupp	doc_491521501724_item	2443590	et	3	main
teatrireisile	doc_491521501724_item	2443593	et	3	main
reis	doc_491521501724_item	2443600	et	4	main
sees	doc_491521501724_item	2443631	et	4	main
juba	doc_491521501724_item	2443632	et	3	main
linnaekskursioon	doc_491521501724_item	2443640	et	3	main
ermitaaži	doc_491521501724_item	2443644	et	2	main
peeter-pauli	doc_491521501724_item	2443646	et	4	main
kindluse	doc_491521501724_item	2443647	et	4	main
meile	doc_491521501724_item	2443657	et	4	main
jaoks	doc_491521501724_item	2443658	et	4	main
küsimusele	doc_491521501725_item	2443671	et	4	main
kelleks	doc_491521501725_item	2443672	et	4	main
tahtsite	doc_491521501725_item	2443673	et	3	main
reeturlus	doc_491521501725_item	2443717	et	4	main
valetamine	doc_491521501725_item	2443719	et	4	main
selliste	doc_491521501725_item	2443735	et	4	main
puutumast	doc_491521501725_item	2443738	et	4	main
on	doc_491521501725_item	2443740	et	4	main
olnud	doc_491521501725_item	2443741	et	4	main
praegune	doc_491521501725_item	2443750	et	3	main
kindlasti	doc_491521501725_item	2443768	et	3	main
lgp	doc_491521501724_item	2443583	et	4	main
sooviks	doc_491521501724_item	2443591	et	4	main
toimub	doc_491521501724_item	2443601	et	3	main
reisi	doc_491521501724_item	2443605	et	4	main
kiri	doc_491521501724_item	2443582	et	3	main
teile	doc_491521501724_item	2443587	et	4	main
sõita	doc_491521501724_item	2443592	et	3	main
me	doc_491521501724_item	2443594	et	4	main
maria	doc_491521501724_item	2443598	et	4	main
ja	doc_491521501724_item	2443604	et	3	main
hind	doc_491521501724_item	2443606	et	3	main
on	doc_491521501724_item	2443607	et	4	main
1500	doc_491521501724_item	2443608	et	2	main
eek	doc_491521501724_item	2443609	et	4	main
ühe	doc_491521501724_item	2443610	et	4	main
inimesele	doc_491521501724_item	2443611	et	3	main
meie	doc_491521501724_item	2443612	et	4	main
grupis	doc_491521501724_item	2443613	et	3	main
on	doc_491521501724_item	2443614	et	4	main
22	doc_491521501724_item	2443615	et	2	main
inimest	doc_491521501724_item	2443616	et	3	main
kui	doc_491521501724_item	2443617	et	3	main
te	doc_491521501724_item	2443618	et	4	main
saaksite	doc_491521501724_item	2443619	et	3	main
meile	doc_491521501724_item	2443620	et	4	main
kohaliku	doc_491521501724_item	2443641	et	3	main
giidi	doc_491521501724_item	2443642	et	4	main
palun	doc_491521501724_item	2443649	et	3	main
sest	doc_491521501724_item	2443652	et	4	main
olla	doc_491521501724_item	2443659	et	3	main
ootama	doc_491521501724_item	2443663	et	3	main
teie	doc_491521501724_item	2443664	et	4	main
ja	doc_491521501724_item	2443666	et	3	main
paremat	doc_491521501724_item	2443668	et	4	main
grupivanem	doc_491521501724_item	2443669	et	4	main
vastus	doc_491521501725_item	2443670	et	3	main
saada	doc_491521501725_item	2443675	et	4	main
mind	doc_491521501725_item	2443679	et	4	main
ja	doc_491521501725_item	2443718	et	3	main
me	doc_491521501724_item	2443622	et	4	main
oleksime	doc_491521501724_item	2443623	et	3	main
rõõmsaid	doc_491521501724_item	2443624	et	3	main
meil	doc_491521501724_item	2443625	et	4	main
on	doc_491521501724_item	2443626	et	4	main
vaja	doc_491521501724_item	2443627	et	4	main
lõunasöök	doc_491521501724_item	2443639	et	3	main
juhtimisel	doc_491521501724_item	2443643	et	4	main
ja	doc_491521501724_item	2443645	et	3	main
unistasin	doc_491521501725_item	2443676	et	3	main
ka	doc_491521501725_item	2443681	et	3	main
väga	doc_491521501725_item	2443682	et	3	main
tolleaegne	doc_491521501725_item	2443683	et	3	main
dessantväelastest	doc_491521501725_item	2443684	et	4	main
tehtud	doc_491521501725_item	2443685	et	4	main
film	doc_491521501725_item	2443686	et	3	main
sööst	doc_491521501725_item	2443687	et	3	main
eritsooni	doc_491521501725_item	2443688	et	4	main
ja	doc_491521501725_item	2443689	et	3	main
tahtsin	doc_491521501725_item	2443690	et	3	main
saada	doc_491521501725_item	2443691	et	4	main
samasuguseks	doc_491521501725_item	2443692	et	4	main
nemad	doc_491521501725_item	2443694	et	3	main
aga	doc_491521501725_item	2443695	et	3	main
nagu	doc_491521501725_item	2443693	et	3	main
hiljem	doc_491521501725_item	2443696	et	3	main
huvid	doc_491521501725_item	2443697	et	3	main
muutusid	doc_491521501725_item	2443698	et	4	main
mida	doc_491521501725_item	2443699	et	4	main
peate	doc_491521501725_item	2443700	et	4	main
oma	doc_491521501725_item	2443701	et	4	main
elu	doc_491521501725_item	2443702	et	4	main
suurimaks	doc_491521501725_item	2443703	et	4	main
saavutuseks	doc_491521501725_item	2443704	et	4	main
ma	doc_491521501725_item	2443705	et	3	main
loodan	doc_491521501725_item	2443706	et	3	main
et	doc_491521501725_item	2443707	et	3	main
selline	doc_491521501725_item	2443708	et	4	main
ootab	doc_491521501725_item	2443710	et	3	main
mind	doc_491521501725_item	2443711	et	4	main
saavutus	doc_491521501725_item	2443709	et	4	main
veel	doc_491521501725_item	2443712	et	4	main
ees	doc_491521501725_item	2443713	et	4	main
mis	doc_491521501725_item	2443714	et	4	main
teid	doc_491521501725_item	2443715	et	4	main
ma	doc_491521501725_item	2443720	et	3	main
nad	doc_491521501725_item	2443728	et	3	main
mind	doc_491521501725_item	2443730	et	4	main
petnud	doc_491521501725_item	2443731	et	4	main
inimestega	doc_491521501725_item	2443736	et	3	main
see	doc_491521501725_item	2443748	et	3	main
võitlus	doc_491521501725_item	2443751	et	3	main
tänapäeva	doc_491521501725_item	2443761	et	4	main
eestis	doc_491521501725_item	2443762	et	3	main
hea	doc_491521501725_item	2443763	et	4	main
ole	doc_491521501725_item	2443770	et	4	main
olevad	doc_491521501725_item	2443777	et	4	main
mida	doc_491521501725_item	2443780	et	4	main
võimu	doc_491521501725_item	2443784	et	4	main
seda	doc_491521501725_item	2443787	et	3	main
rohkem	doc_491521501725_item	2443797	et	4	main
osata	doc_491521501725_item	2443803	et	4	main
targemaks	doc_491521501725_item	2443811	et	4	main
mis	doc_491521501725_item	2443820	et	4	main
on	doc_491521501725_item	2443821	et	4	main
jaoks	doc_491521501725_item	2443823	et	4	main
parim	doc_491521501725_item	2443824	et	4	main
puhkus	doc_491521501725_item	2443825	et	3	main
olla	doc_491521501725_item	2443826	et	3	main
on	doc_491521501725_item	2443832	et	4	main
ida-virumaal	doc_491521501725_item	2443835	et	4	main
vasknarva	doc_491521501725_item	2443840	et	4	main
mille	doc_491521501725_item	2443841	et	3	main
kuna	doc_491521501725_item	2443846	et	3	main
võimalikult	doc_491521501725_item	2443850	et	4	main
aidata	doc_491521501725_item	2443852	et	4	main
et	doc_491521501725_item	2443856	et	3	main
oleks	doc_491521501725_item	2443857	et	3	main
paremini	doc_491521501725_item	2443864	et	4	main
olen	doc_491521501725_item	2443868	et	3	main
seetõttu	doc_491521501725_item	2443874	et	3	main
harjunud	doc_491521501725_item	2443876	et	4	main
tegema	doc_491521501725_item	2443878	et	3	main
üldiselt	doc_491521501725_item	2443722	et	4	main
kokku	doc_491521501725_item	2443737	et	3	main
teie	doc_491521501725_item	2443742	et	4	main
pööraseim	doc_491521501725_item	2443744	et	4	main
tegu	doc_491521501725_item	2443745	et	4	main
et	doc_491521501725_item	2443727	et	3	main
on	doc_491521501725_item	2443729	et	4	main
mis	doc_491521501725_item	2443739	et	4	main
elu	doc_491521501725_item	2443743	et	4	main
ongi	doc_491521501725_item	2443747	et	4	main
õhk	doc_491521501725_item	2443756	et	3	main
kellel	doc_491521501725_item	2443759	et	4	main
on	doc_491521501725_item	2443760	et	4	main
öelda	doc_491521501725_item	2443766	et	4	main
kuid	doc_491521501725_item	2443767	et	4	main
võimu	doc_491521501725_item	2443775	et	4	main
sest	doc_491521501725_item	2443779	et	4	main
rohkem	doc_491521501725_item	2443781	et	4	main
raha	doc_491521501725_item	2443782	et	4	main
ja	doc_491521501725_item	2443783	et	3	main
raha	doc_491521501725_item	2443798	et	4	main
tahaksite	doc_491521501725_item	2443802	et	3	main
tahan	doc_491521501725_item	2443805	et	3	main
saada	doc_491521501725_item	2443810	et	4	main
valitud	doc_491521501725_item	2443817	et	4	main
edaspidi	doc_491521501725_item	2443734	et	3	main
ilmselt	doc_491521501725_item	2443746	et	4	main
nimel	doc_491521501725_item	2443753	et	3	main
kohtla-järve	doc_491521501725_item	2443755	et	4	main
puhtaks	doc_491521501725_item	2443757	et	3	main
elada	doc_491521501725_item	2443764	et	3	main
ei	doc_491521501725_item	2443769	et	4	main
rikkad	doc_491521501725_item	2443773	et	4	main
inimesed	doc_491521501725_item	2443778	et	3	main
on	doc_491521501725_item	2443785	et	4	main
kõige	doc_491521501725_item	2443796	et	4	main
peale	doc_491521501725_item	2443800	et	4	main
et	doc_491521501725_item	2443809	et	3	main
tahaks	doc_491521501725_item	2443813	et	3	main
kusagil	doc_491521501725_item	2443829	et	3	main
milline	doc_491521501725_item	2443831	et	3	main
karjamaa	doc_491521501725_item	2443839	et	4	main
jaoks	doc_491521501725_item	2443842	et	4	main
siis	doc_491521501725_item	2443853	et	3	main
natukenegi	doc_491521501725_item	2443858	et	4	main
rohkem	doc_491521501725_item	2443859	et	4	main
valmistuda	doc_491521501725_item	2443865	et	3	main
loomult	doc_491521501725_item	2443869	et	3	main
tüüpi	doc_491521501725_item	2443871	et	4	main
inimene	doc_491521501725_item	2443872	et	3	main
tööd	doc_491521501725_item	2443877	et	4	main
hilistel	doc_491521501725_item	2443880	et	3	main
tundidel	doc_491521501725_item	2443881	et	3	main
millises	doc_491521501725_item	2443921	et	3	main
teinud	doc_491521501725_item	2443932	et	4	main
kui	doc_491521501725_item	2443936	et	3	main
kõige	doc_491521501725_item	2443943	et	4	main
öeldut	doc_491521501725_item	2443948	et	4	main
seal	doc_491521501725_item	2443950	et	4	main
sündisid	doc_491521501725_item	2443952	et	4	main
seal	doc_491521501725_item	2443953	et	4	main
elada	doc_491521501725_item	2443956	et	3	main
kas	doc_491521501725_item	2443957	et	3	main
loete	doc_491521501725_item	2443958	et	4	main
horoskoope	doc_491521501725_item	2443959	et	3	main
korralik	doc_491521501725_item	2443988	et	3	main
ta	doc_491521501725_item	2443998	et	4	main
võib	doc_491521501725_item	2443999	et	3	main
valitsuses	doc_491521501725_item	2444004	et	4	main
tugevamad	doc_491521501725_item	2444006	et	4	main
on	doc_491521501725_item	2444008	et	4	main
alguses	doc_491521501725_item	2444035	et	4	main
oli	doc_491521501725_item	2444036	et	3	main
lootnud	doc_491521501725_item	2444037	et	4	main
ei	doc_491521501725_item	2444045	et	4	main
esimene	doc_491521501726_item	2444055	et	3	main
vastake	doc_491521501726_item	2444071	et	3	main
vabariigis	doc_491521501726_item	2444080	et	3	main
2	doc_491521501726_item	2444084	et	2	main
perekonnanimi	doc_491521501726_item	2444085	et	3	main
3	doc_491521501726_item	2444087	et	2	main
teine	doc_491521501726_item	2444090	et	3	main
te	doc_491521501726_item	2444092	et	4	main
kolinud	doc_491521501726_item	2444094	et	4	main
uude	doc_491521501726_item	2444095	et	3	main
korterisse	doc_491521501726_item	2444096	et	3	main
ja	doc_491521501726_item	2444097	et	3	main
tahate	doc_491521501726_item	2444098	et	3	main
kirjutage	doc_491521501726_item	2444104	et	3	main
kolimine	doc_491521501726_item	2444108	et	4	main
teile	doc_491521501726_item	2444110	et	4	main
uues	doc_491521501726_item	2444112	et	3	main
elukohas	doc_491521501726_item	2444113	et	4	main
kas	doc_491521501726_item	2444114	et	3	main
ja	doc_491521501726_item	2444119	et	3	main
minu	doc_491521501725_item	2443749	et	3	main
selle	doc_491521501725_item	2443752	et	4	main
et	doc_491521501725_item	2443754	et	3	main
saaks	doc_491521501725_item	2443758	et	3	main
raske	doc_491521501725_item	2443765	et	4	main
need	doc_491521501725_item	2443771	et	3	main
juures	doc_491521501725_item	2443776	et	4	main
käes	doc_491521501725_item	2443786	et	4	main
rohkem	doc_491521501725_item	2443788	et	4	main
ka	doc_491521501725_item	2443790	et	3	main
probleeme	doc_491521501725_item	2443791	et	3	main
peale	doc_491521501725_item	2443793	et	4	main
kulub	doc_491521501725_item	2443794	et	3	main
teil	doc_491521501725_item	2443795	et	4	main
mida	doc_491521501725_item	2443801	et	4	main
ma	doc_491521501725_item	2443804	et	3	main
väga	doc_491521501725_item	2443806	et	3	main
palju	doc_491521501725_item	2443807	et	4	main
lugeda	doc_491521501725_item	2443808	et	3	main
erialal	doc_491521501725_item	2443818	et	3	main
õigusteaduses	doc_491521501725_item	2443819	et	3	main
perega	doc_491521501725_item	2443828	et	3	main
looduses	doc_491521501725_item	2443830	et	4	main
lemmikpaik	doc_491521501725_item	2443834	et	3	main
kant	doc_491521501725_item	2443837	et	3	main
aega	doc_491521501725_item	2443845	et	4	main
tahan	doc_491521501725_item	2443847	et	3	main
aega	doc_491521501725_item	2443860	et	4	main
siis	doc_491521501725_item	2443861	et	3	main
jõuaks	doc_491521501725_item	2443862	et	3	main
ma	doc_491521501725_item	2443867	et	3	main
peale	doc_491521501725_item	2443923	et	4	main
te	doc_491521501725_item	2443925	et	4	main
tahaksite	doc_491521501725_item	2443926	et	3	main
elanud	doc_491521501725_item	2443930	et	4	main
on	doc_491521501725_item	2443940	et	4	main
mul	doc_491521501725_item	2443942	et	3	main
tuleb	doc_491521501725_item	2443954	et	3	main
ka	doc_491521501725_item	2443955	et	3	main
või	doc_491521501725_item	2443983	et	4	main
see	doc_491521501725_item	2443985	et	3	main
mees	doc_491521501725_item	2443995	et	4	main
minu	doc_491521501725_item	2443996	et	3	main
või	doc_491521501725_item	2444002	et	4	main
tema	doc_491521501725_item	2444005	et	4	main
küljed	doc_491521501725_item	2444007	et	3	main
see	doc_491521501725_item	2444009	et	3	main
tööd	doc_491521501725_item	2444020	et	4	main
ainult	doc_491521501725_item	2443772	et	4	main
ja	doc_491521501725_item	2443774	et	3	main
on	doc_491521501725_item	2443789	et	4	main
mille	doc_491521501725_item	2443792	et	3	main
kommunaalkulude	doc_491521501725_item	2443799	et	3	main
eelkõige	doc_491521501725_item	2443812	et	3	main
tõsta	doc_491521501725_item	2443814	et	4	main
oma	doc_491521501725_item	2443815	et	4	main
taset	doc_491521501725_item	2443816	et	3	main
koos	doc_491521501725_item	2443827	et	4	main
alajõe	doc_491521501725_item	2443838	et	3	main
ei	doc_491521501725_item	2443843	et	4	main
jätku	doc_491521501725_item	2443844	et	4	main
inimesi	doc_491521501725_item	2443849	et	4	main
tundub	doc_491521501725_item	2443854	et	3	main
alati	doc_491521501725_item	2443855	et	4	main
öökulli	doc_491521501725_item	2443870	et	4	main
ja	doc_491521501725_item	2443873	et	3	main
olen	doc_491521501725_item	2443875	et	3	main
ka	doc_491521501725_item	2443879	et	3	main
millist	doc_491521501725_item	2443882	et	3	main
ja	doc_491521501725_item	2443931	et	3	main
venemaal	doc_491521501725_item	2443935	et	4	main
eestis	doc_491521501725_item	2443941	et	3	main
oma	doc_491521501725_item	2443946	et	4	main
et	doc_491521501725_item	2443949	et	3	main
kus	doc_491521501725_item	2443951	et	3	main
jurist	doc_491521501725_item	2443982	et	3	main
advokat	doc_491521501725_item	2443984	et	4	main
arvates	doc_491521501725_item	2443997	et	4	main
riigi	doc_491521501725_item	2444003	et	3	main
puhta	doc_491521501725_item	2444014	et	4	main
ta	doc_491521501725_item	2444038	et	4	main
usu	doc_491521501725_item	2444046	et	4	main
ole	doc_491521501725_item	2444052	et	4	main
selleks	doc_491521501726_item	2444064	et	4	main
te	doc_491521501726_item	2444065	et	4	main
ankeedi	doc_491521501726_item	2444069	et	4	main
eesti	doc_491521501726_item	2444079	et	4	main
olga	doc_491521501726_item	2444083	et	4	main
minejeva	doc_491521501726_item	2444086	et	4	main
sellest	doc_491521501726_item	2444100	et	4	main
oma	doc_491521501726_item	2444101	et	4	main
talle	doc_491521501726_item	2444105	et	4	main
kuidas	doc_491521501726_item	2444106	et	3	main
tööl	doc_491521501726_item	2444117	et	3	main
kutsuge	doc_491521501726_item	2444120	et	3	main
külla	doc_491521501726_item	2444122	et	4	main
nõutav	doc_491521501726_item	2444124	et	4	main
maria	doc_491521501726_item	2444131	et	4	main
kuidas	doc_491521501726_item	2444132	et	3	main
mul	doc_491521501726_item	2444143	et	3	main
sulle	doc_491521501726_item	2444150	et	3	main
praegu	doc_491521501726_item	2444153	et	3	main
läks	doc_491521501726_item	2444159	et	3	main
oli	doc_491521501726_item	2444162	et	3	main
on	doc_491521501726_item	2444166	et	4	main
onu	doc_491521501726_item	2444177	et	4	main
kahetoaline	doc_491521501726_item	2444182	et	4	main
korrusel	doc_491521501726_item	2444189	et	3	main
kuhu	doc_491521501726_item	2444192	et	3	main
oli	doc_491521501726_item	2444195	et	3	main
väga	doc_491521501726_item	2444197	et	3	main
remont	doc_491521501726_item	2444203	et	3	main
meeldib	doc_491521501726_item	2444206	et	3	main
rajoon	doc_491521501726_item	2444209	et	3	main
lähedal	doc_491521501726_item	2444213	et	4	main
asub	doc_491521501726_item	2444214	et	3	main
mida	doc_491521501726_item	2444222	et	4	main
mulle	doc_491521501726_item	2444223	et	4	main
väga	doc_491521501726_item	2444224	et	3	main
kus	doc_491521501726_item	2444231	et	3	main
et	doc_491521501726_item	2444237	et	3	main
sinu	doc_491521501726_item	2444254	et	3	main
enam	doc_491521501726_item	2444258	et	4	main
korter	doc_491521501726_item	2444262	et	3	main
sind	doc_491521501726_item	2444265	et	4	main
me	doc_491521501726_item	2444266	et	4	main
vabariigis	doc_491521501727_item	2444303	et	3	main
irina	doc_491521501727_item	2444306	et	3	main
3	doc_491521501727_item	2444310	et	2	main
linn	doc_491521501727_item	2444320	et	3	main
teie	doc_491521501725_item	2443822	et	4	main
teie	doc_491521501725_item	2443833	et	4	main
peipsi-äärne	doc_491521501725_item	2443836	et	3	main
kohtuasjades	doc_491521501725_item	2443848	et	3	main
hästi	doc_491521501725_item	2443851	et	3	main
veelgi	doc_491521501725_item	2443863	et	4	main
kuid	doc_491521501725_item	2443866	et	4	main
omadust	doc_491521501725_item	2443883	et	4	main
peate	doc_491521501725_item	2443884	et	4	main
oma	doc_491521501725_item	2443885	et	4	main
tugevaimaks	doc_491521501725_item	2443886	et	4	main
küljeks	doc_491521501725_item	2443887	et	3	main
ma	doc_491521501725_item	2443888	et	3	main
arvan	doc_491521501725_item	2443889	et	3	main
et	doc_491521501725_item	2443890	et	3	main
see	doc_491521501725_item	2443891	et	3	main
on	doc_491521501725_item	2443892	et	4	main
järjekindlus	doc_491521501725_item	2443893	et	4	main
asjad	doc_491521501725_item	2443895	et	3	main
viia	doc_491521501725_item	2443894	et	3	main
lõpuni	doc_491521501725_item	2443896	et	3	main
isegi	doc_491521501725_item	2443897	et	4	main
siis	doc_491521501725_item	2443898	et	3	main
kui	doc_491521501725_item	2443899	et	3	main
see	doc_491521501725_item	2443900	et	3	main
tulemus	doc_491521501725_item	2443901	et	3	main
ei	doc_491521501725_item	2443902	et	4	main
ole	doc_491521501725_item	2443903	et	4	main
iga	doc_491521501725_item	2443904	et	4	main
kord	doc_491521501725_item	2443905	et	4	main
päris	doc_491521501725_item	2443906	et	4	main
see	doc_491521501725_item	2443907	et	3	main
mida	doc_491521501725_item	2443908	et	4	main
ma	doc_491521501725_item	2443909	et	3	main
alguses	doc_491521501725_item	2443910	et	4	main
olin	doc_491521501725_item	2443911	et	3	main
lootnud	doc_491521501725_item	2443912	et	4	main
ei	doc_491521501725_item	2443913	et	4	main
ole	doc_491521501725_item	2443914	et	4	main
mul	doc_491521501725_item	2443915	et	3	main
kombeks	doc_491521501725_item	2443916	et	4	main
oma	doc_491521501725_item	2443917	et	4	main
ettevõtmisi	doc_491521501725_item	2443918	et	3	main
pooleli	doc_491521501725_item	2443919	et	3	main
jätta	doc_491521501725_item	2443920	et	3	main
tööd	doc_491521501725_item	2443933	et	4	main
siiski	doc_491521501725_item	2443939	et	4	main
isa	doc_491521501725_item	2443947	et	4	main
ma	doc_491521501725_item	2443961	et	3	main
ei	doc_491521501725_item	2443962	et	4	main
usu	doc_491521501725_item	2443963	et	4	main
neid	doc_491521501725_item	2443964	et	4	main
ega	doc_491521501725_item	2443965	et	3	main
huvitu	doc_491521501725_item	2443966	et	4	main
nendest	doc_491521501725_item	2443967	et	4	main
see	doc_491521501725_item	2443968	et	3	main
ei	doc_491521501725_item	2443969	et	4	main
ole	doc_491521501725_item	2443970	et	4	main
tõsine	doc_491521501725_item	2443971	et	4	main
asi	doc_491521501725_item	2443972	et	4	main
ma	doc_491521501725_item	2443973	et	3	main
arvan	doc_491521501725_item	2443974	et	3	main
et	doc_491521501725_item	2443975	et	3	main
intervjueeritav	doc_491521501725_item	2443976	et	4	main
on	doc_491521501725_item	2443977	et	4	main
mees	doc_491521501725_item	2443978	et	4	main
tema	doc_491521501725_item	2443979	et	4	main
eriala	doc_491521501725_item	2443980	et	4	main
on	doc_491521501725_item	2443981	et	4	main
riigis	doc_491521501725_item	2443922	et	3	main
eesti	doc_491521501725_item	2443924	et	4	main
elada	doc_491521501725_item	2443927	et	3	main
ma	doc_491521501725_item	2443928	et	3	main
olen	doc_491521501725_item	2443929	et	3	main
nii	doc_491521501725_item	2443934	et	3	main
saksamaal	doc_491521501725_item	2443937	et	4	main
kuid	doc_491521501725_item	2443938	et	4	main
parem	doc_491521501725_item	2443944	et	4	main
järgin	doc_491521501725_item	2443945	et	3	main
ei	doc_491521501725_item	2443960	et	4	main
mees	doc_491521501725_item	2443986	et	4	main
on	doc_491521501725_item	2443987	et	4	main
inimene	doc_491521501725_item	2443989	et	3	main
on	doc_491521501725_item	2443991	et	4	main
tõsine	doc_491521501725_item	2443994	et	4	main
ta	doc_491521501725_item	2444011	et	4	main
kohtla-järve	doc_491521501725_item	2444013	et	4	main
õhu	doc_491521501725_item	2444015	et	3	main
eest	doc_491521501725_item	2444016	et	4	main
ja	doc_491521501725_item	2444017	et	3	main
teeb	doc_491521501725_item	2444018	et	3	main
palju	doc_491521501725_item	2444019	et	4	main
viib	doc_491521501725_item	2444022	et	3	main
lõpunu	doc_491521501725_item	2444024	et	4	main
kui	doc_491521501725_item	2444027	et	3	main
ta	doc_491521501725_item	2444034	et	4	main
oma	doc_491521501725_item	2444041	et	4	main
ettevõtmise	doc_491521501725_item	2444042	et	3	main
arvates	doc_491521501725_item	2444049	et	4	main
tõsine	doc_491521501725_item	2444053	et	4	main
saatkonna	doc_491521501726_item	2444068	et	4	main
täna	doc_491521501726_item	2444073	et	4	main
küsimustele	doc_491521501726_item	2444075	et	4	main
eesnimi	doc_491521501726_item	2444082	et	3	main
osa	doc_491521501726_item	2444091	et	4	main
olete	doc_491521501726_item	2444093	et	3	main
läks	doc_491521501726_item	2444107	et	3	main
on	doc_491521501726_item	2444115	et	4	main
käia	doc_491521501726_item	2444118	et	4	main
ta	doc_491521501726_item	2444121	et	4	main
kirja	doc_491521501726_item	2444123	et	4	main
sõna	doc_491521501726_item	2444129	et	4	main
kallid	doc_491521501726_item	2444130	et	3	main
suur	doc_491521501726_item	2444145	et	3	main
ja	doc_491521501726_item	2444147	et	3	main
tahan	doc_491521501726_item	2444149	et	3	main
kolimine	doc_491521501726_item	2444158	et	4	main
meil	doc_491521501726_item	2444161	et	4	main
see	doc_491521501726_item	2444174	et	3	main
oli	doc_491521501726_item	2444175	et	3	main
auto	doc_491521501726_item	2444178	et	4	main
mis	doc_491521501726_item	2444184	et	4	main
majas	doc_491521501726_item	2444187	et	3	main
mulle	doc_491521501726_item	2444204	et	4	main
elukohas	doc_491521501726_item	2444208	et	4	main
on	doc_491521501726_item	2444210	et	4	main
üle	doc_491521501726_item	2444227	et	3	main
töötan	doc_491521501726_item	2444233	et	3	main
tean	doc_491521501726_item	2444236	et	3	main
on	doc_491521501726_item	2444240	et	4	main
ja	doc_491521501726_item	2444242	et	3	main
ma	doc_491521501726_item	2444243	et	3	main
kutsun	doc_491521501726_item	2444244	et	3	main
sind	doc_491521501726_item	2444245	et	4	main
külla	doc_491521501726_item	2444246	et	4	main
ma	doc_491521501726_item	2444247	et	3	main
olin	doc_491521501726_item	2444248	et	3	main
sul	doc_491521501726_item	2444249	et	3	main
küllas	doc_491521501726_item	2444250	et	3	main
ja	doc_491521501726_item	2444251	et	3	main
praegu	doc_491521501726_item	2444252	et	3	main
on	doc_491521501726_item	2444253	et	4	main
veedame	doc_491521501726_item	2444267	et	3	main
kuningriigi	doc_491521501727_item	2444300	et	3	main
sugu	doc_491521501727_item	2444322	et	4	main
7	doc_491521501727_item	2444325	et	2	main
kodakonsus	doc_491521501727_item	2444326	et	4	main
eesti	doc_491521501727_item	2444327	et	4	main
8	doc_491521501727_item	2444328	et	2	main
amet	doc_491521501727_item	2444329	et	3	main
9	doc_491521501727_item	2444331	et	2	main
olevi	doc_491521501727_item	2444335	et	4	main
ta	doc_491521501725_item	2443990	et	4	main
õiglane	doc_491521501725_item	2443992	et	3	main
ja	doc_491521501725_item	2443993	et	3	main
töötada	doc_491521501725_item	2444000	et	3	main
kohtus	doc_491521501725_item	2444001	et	4	main
et	doc_491521501725_item	2444010	et	3	main
võitleb	doc_491521501725_item	2444012	et	3	main
ta	doc_491521501725_item	2444021	et	4	main
asjad	doc_491521501725_item	2444023	et	3	main
päris	doc_491521501725_item	2444031	et	4	main
see	doc_491521501725_item	2444032	et	3	main
mida	doc_491521501725_item	2444033	et	4	main
ei	doc_491521501725_item	2444039	et	4	main
jätta	doc_491521501725_item	2444040	et	3	main
horoskoopidesse	doc_491521501725_item	2444047	et	3	main
tema	doc_491521501725_item	2444048	et	4	main
asi	doc_491521501725_item	2444054	et	4	main
täitma	doc_491521501726_item	2444067	et	3	main
palun	doc_491521501726_item	2444070	et	3	main
kõigile	doc_491521501726_item	2444074	et	4	main
norra	doc_491521501726_item	2444076	et	4	main
kuningriigi	doc_491521501726_item	2444077	et	3	main
suursaatkond	doc_491521501726_item	2444078	et	3	main
teatada	doc_491521501726_item	2444099	et	3	main
sõbrale	doc_491521501726_item	2444103	et	3	main
kauge	doc_491521501726_item	2444116	et	4	main
käsi	doc_491521501726_item	2444133	et	4	main
käib	doc_491521501726_item	2444134	et	3	main
kuidas	doc_491521501726_item	2444135	et	3	main
on	doc_491521501726_item	2444136	et	4	main
sinu	doc_491521501726_item	2444137	et	3	main
tervis	doc_491521501726_item	2444138	et	3	main
mul	doc_491521501726_item	2444139	et	3	main
on	doc_491521501726_item	2444140	et	4	main
kõik	doc_491521501726_item	2444141	et	4	main
hästi	doc_491521501726_item	2444142	et	3	main
sellest	doc_491521501726_item	2444151	et	4	main
mul	doc_491521501726_item	2444154	et	3	main
uus	doc_491521501726_item	2444156	et	3	main
mahtuvad	doc_491521501726_item	2444172	et	4	main
autos	doc_491521501726_item	2444173	et	3	main
minu	doc_491521501726_item	2444176	et	3	main
mul	doc_491521501726_item	2444180	et	3	main
üheksakorruselises	doc_491521501726_item	2444186	et	4	main
selles	doc_491521501726_item	2444190	et	4	main
ma	doc_491521501726_item	2444193	et	3	main
tehtud	doc_491521501726_item	2444196	et	4	main
hea	doc_491521501726_item	2444198	et	4	main
remont	doc_491521501726_item	2444199	et	3	main
ja	doc_491521501726_item	2444200	et	3	main
et	doc_491521501726_item	2444226	et	3	main
asub	doc_491521501726_item	2444229	et	3	main
maria	doc_491521501726_item	2444234	et	4	main
ja	doc_491521501726_item	2444256	et	3	main
sinu	doc_491521501726_item	2444268	et	3	main
küsimustele	doc_491521501727_item	2444298	et	4	main
norra	doc_491521501727_item	2444299	et	4	main
1	doc_491521501727_item	2444304	et	2	main
2	doc_491521501727_item	2444307	et	2	main
maspanova	doc_491521501727_item	2444309	et	4	main
5	doc_491521501727_item	2444316	et	2	main
eesti	doc_491521501727_item	2444318	et	4	main
6	doc_491521501727_item	2444321	et	2	main
aasta	doc_491521501727_item	2444324	et	4	main
kohtla-järve	doc_491521501727_item	2444334	et	4	main
teine	doc_491521501727_item	2444340	et	3	main
olete	doc_491521501727_item	2444343	et	3	main
uude	doc_491521501727_item	2444345	et	3	main
korterisse	doc_491521501727_item	2444346	et	3	main
ja	doc_491521501727_item	2444347	et	3	main
tahate	doc_491521501727_item	2444348	et	3	main
teatada	doc_491521501727_item	2444349	et	3	main
kirjutage	doc_491521501727_item	2444354	et	3	main
sõna	doc_491521501727_item	2444379	et	4	main
tere	doc_491521501727_item	2444380	et	3	main
jutustada	doc_491521501727_item	2444395	et	3	main
mulle	doc_491521501727_item	2444397	et	4	main
meie	doc_491521501727_item	2444399	et	4	main
sõbrad	doc_491521501727_item	2444400	et	3	main
kolisivad	doc_491521501727_item	2444408	et	4	main
uudel	doc_491521501727_item	2444411	et	4	main
mulle	doc_491521501727_item	2444413	et	4	main
isegi	doc_491521501725_item	2444025	et	4	main
siis	doc_491521501725_item	2444026	et	3	main
tulemus	doc_491521501725_item	2444028	et	3	main
ei	doc_491521501725_item	2444029	et	4	main
ole	doc_491521501725_item	2444030	et	4	main
pooleli	doc_491521501725_item	2444043	et	3	main
ta	doc_491521501725_item	2444044	et	4	main
see	doc_491521501725_item	2444050	et	3	main
ei	doc_491521501725_item	2444051	et	4	main
osa	doc_491521501726_item	2444056	et	4	main
1-10	doc_491521501726_item	2444058	et	2	main
te	doc_491521501726_item	2444059	et	4	main
soovite	doc_491521501726_item	2444060	et	3	main
küsimused	doc_491521501726_item	2444057	et	4	main
sõita	doc_491521501726_item	2444061	et	3	main
puhkusreisile	doc_491521501726_item	2444062	et	4	main
norrasse	doc_491521501726_item	2444063	et	4	main
peate	doc_491521501726_item	2444066	et	4	main
kohe	doc_491521501726_item	2444072	et	4	main
1	doc_491521501726_item	2444081	et	2	main
elukohariik	doc_491521501726_item	2444088	et	3	main
eesti	doc_491521501726_item	2444089	et	4	main
eestlasest	doc_491521501726_item	2444102	et	3	main
kuidas	doc_491521501726_item	2444109	et	3	main
meeldib	doc_491521501726_item	2444111	et	3	main
pikkus	doc_491521501726_item	2444125	et	4	main
on	doc_491521501726_item	2444126	et	4	main
umbes	doc_491521501726_item	2444127	et	4	main
80	doc_491521501726_item	2444128	et	2	main
on	doc_491521501726_item	2444144	et	4	main
ma	doc_491521501726_item	2444148	et	3	main
on	doc_491521501726_item	2444155	et	4	main
korter	doc_491521501726_item	2444157	et	3	main
suur	doc_491521501726_item	2444163	et	3	main
praegu	doc_491521501726_item	2444179	et	3	main
asub	doc_491521501726_item	2444185	et	3	main
mulle	doc_491521501726_item	2444201	et	4	main
väga	doc_491521501726_item	2444211	et	3	main
vaikne	doc_491521501726_item	2444212	et	3	main
veel	doc_491521501726_item	2444221	et	4	main
meeldib	doc_491521501726_item	2444225	et	3	main
firma	doc_491521501726_item	2444230	et	4	main
ma	doc_491521501726_item	2444235	et	3	main
kord	doc_491521501726_item	2444255	et	4	main
on	doc_491521501726_item	2444260	et	4	main
uus	doc_491521501726_item	2444261	et	3	main
ootan	doc_491521501726_item	2444264	et	3	main
väga	doc_491521501726_item	2444270	et	3	main
sinu	doc_491521501726_item	2444272	et	3	main
sõbranna	doc_491521501726_item	2444273	et	4	main
eesti	doc_491521501727_item	2444302	et	4	main
eesnimi	doc_491521501727_item	2444305	et	3	main
perekonnanimi	doc_491521501727_item	2444308	et	3	main
elukohariik	doc_491521501727_item	2444311	et	3	main
4	doc_491521501727_item	2444313	et	2	main
22111971	doc_491521501727_item	2444315	et	2	main
sünnikoht	doc_491521501727_item	2444317	et	3	main
uudis	doc_491521501726_item	2444146	et	3	main
kirjutada	doc_491521501726_item	2444152	et	3	main
hästi	doc_491521501726_item	2444160	et	3	main
auto	doc_491521501726_item	2444164	et	4	main
see	doc_491521501726_item	2444165	et	3	main
mugav	doc_491521501726_item	2444167	et	3	main
sellepärast	doc_491521501726_item	2444168	et	3	main
et	doc_491521501726_item	2444169	et	3	main
kõik	doc_491521501726_item	2444170	et	4	main
asjad	doc_491521501726_item	2444171	et	3	main
on	doc_491521501726_item	2444181	et	4	main
korter	doc_491521501726_item	2444183	et	3	main
teisel	doc_491521501726_item	2444188	et	4	main
korteris	doc_491521501726_item	2444191	et	3	main
kolisin	doc_491521501726_item	2444194	et	3	main
meeldis	doc_491521501726_item	2444202	et	3	main
väga	doc_491521501726_item	2444205	et	3	main
uues	doc_491521501726_item	2444207	et	3	main
toidupood	doc_491521501726_item	2444215	et	3	main
apteek	doc_491521501726_item	2444216	et	3	main
postkontor	doc_491521501726_item	2444217	et	3	main
ja	doc_491521501726_item	2444218	et	3	main
pankaautomaat	doc_491521501726_item	2444219	et	4	main
ja	doc_491521501726_item	2444220	et	3	main
tee	doc_491521501726_item	2444228	et	4	main
ma	doc_491521501726_item	2444232	et	3	main
varsti	doc_491521501726_item	2444238	et	3	main
sul	doc_491521501726_item	2444239	et	3	main
puhkus	doc_491521501726_item	2444241	et	3	main
seda	doc_491521501726_item	2444257	et	3	main
mul	doc_491521501726_item	2444259	et	3	main
ma	doc_491521501726_item	2444263	et	3	main
puhkus	doc_491521501726_item	2444269	et	3	main
hea	doc_491521501726_item	2444271	et	4	main
kirjadiv	doc_491521501727_item	2444274	et	4	main
esimene	doc_491521501727_item	2444275	et	3	main
test	doc_491521501727_item	2444276	et	3	main
kirjutamistest	doc_491521501727_item	2444277	et	4	main
esimene	doc_491521501727_item	2444278	et	3	main
osa	doc_491521501727_item	2444279	et	4	main
küsimused	doc_491521501727_item	2444280	et	4	main
1-10	doc_491521501727_item	2444281	et	2	main
te	doc_491521501727_item	2444282	et	4	main
soovite	doc_491521501727_item	2444283	et	3	main
sõita	doc_491521501727_item	2444284	et	3	main
norrasse	doc_491521501727_item	2444286	et	4	main
selleks	doc_491521501727_item	2444287	et	4	main
puhkusreisile	doc_491521501727_item	2444285	et	4	main
te	doc_491521501727_item	2444288	et	4	main
peate	doc_491521501727_item	2444289	et	4	main
täitma	doc_491521501727_item	2444290	et	3	main
saatkonna	doc_491521501727_item	2444291	et	4	main
ankeedi	doc_491521501727_item	2444292	et	4	main
palun	doc_491521501727_item	2444293	et	3	main
vastake	doc_491521501727_item	2444294	et	3	main
kohe	doc_491521501727_item	2444295	et	4	main
täna	doc_491521501727_item	2444296	et	4	main
kõigile	doc_491521501727_item	2444297	et	4	main
suursaatkond	doc_491521501727_item	2444301	et	3	main
eesti	doc_491521501727_item	2444312	et	4	main
sünniaeg	doc_491521501727_item	2444314	et	3	main
kohtla-järve	doc_491521501727_item	2444319	et	4	main
23-24	doc_491521501727_item	2444336	et	2	main
21022002	doc_491521501727_item	2444339	et	2	main
osa	doc_491521501727_item	2444341	et	4	main
oma	doc_491521501727_item	2444351	et	4	main
talle	doc_491521501727_item	2444355	et	4	main
kolimine	doc_491521501727_item	2444358	et	4	main
uues	doc_491521501727_item	2444362	et	3	main
katriin	doc_491521501727_item	2444381	et	4	main
ma	doc_491521501727_item	2444382	et	3	main
rõõmu	doc_491521501727_item	2444387	et	4	main
uude	doc_491521501727_item	2444391	et	3	main
minu	doc_491521501727_item	2444409	et	3	main
suur	doc_491521501727_item	2444420	et	3	main
väga	doc_491521501727_item	2444423	et	3	main
korter	doc_491521501727_item	2444428	et	3	main
oma	doc_491521501727_item	2444437	et	4	main
ta	doc_491521501727_item	2444440	et	4	main
vaatasid	doc_491521501727_item	2444441	et	4	main
ta	doc_491521501727_item	2444447	et	4	main
ootan	doc_491521501727_item	2444450	et	3	main
helista	doc_491521501727_item	2444453	et	4	main
on	doc_491521501727_item	2444456	et	4	main
uus	doc_491521501727_item	2444457	et	3	main
number	doc_491521501727_item	2444458	et	3	main
osa	doc_491521501728_item	2444465	et	4	main
küsimustele	doc_491521501728_item	2444482	et	4	main
2	doc_491521501728_item	2444486	et	2	main
sünniaeg	doc_491521501728_item	2444493	et	3	main
18	doc_491521501728_item	2444494	et	2	main
1980	doc_491521501728_item	2444496	et	2	main
korda	doc_491521501728_item	2444523	et	4	main
kas	doc_491521501728_item	2444526	et	3	main
tegelenud	doc_491521501728_item	2444530	et	4	main
muidugi	doc_491521501728_item	2444531	et	4	main
10	doc_491521501728_item	2444534	et	2	main
28022002	doc_491521501728_item	2444536	et	2	main
lähedal	doc_491521501728_item	2444541	et	4	main
tere	doc_491521501728_item	2444566	et	3	main
sa	doc_491521501728_item	2444569	et	3	main
korrusel	doc_491521501728_item	2444598	et	3	main
võid	doc_491521501728_item	2444608	et	4	main
teisel	doc_491521501728_item	2444615	et	4	main
on	doc_491521501728_item	2444617	et	4	main
kohvik	doc_491521501728_item	2444618	et	3	main
mina	doc_491521501728_item	2444619	et	4	main
üks	doc_491521501728_item	2444622	et	3	main
käime	doc_491521501728_item	2444625	et	4	main
sinna	doc_491521501728_item	2444626	et	3	main
osta	doc_491521501728_item	2444638	et	4	main
käin	doc_491521501728_item	2444641	et	3	main
kauplus	doc_491521501728_item	2444643	et	3	main
seal	doc_491521501728_item	2444645	et	4	main
ma	doc_491521501728_item	2444646	et	3	main
võin	doc_491521501728_item	2444647	et	3	main
head	doc_491521501728_item	2444653	et	4	main
ujula	doc_491521501728_item	2444656	et	4	main
l	doc_491521501728_item	2444667	et	4	main
ja	doc_491521501728_item	2444668	et	3	main
900-1700	doc_491521501728_item	2444670	et	2	main
l	doc_491521501728_item	2444678	et	4	main
ja	doc_491521501728_item	2444679	et	3	main
juuksur	doc_491521501728_item	2444685	et	3	main
solaarium	doc_491521501728_item	2444687	et	3	main
sekretär	doc_491521501727_item	2444330	et	3	main
kodune	doc_491521501727_item	2444332	et	4	main
aadress	doc_491521501727_item	2444333	et	3	main
10	doc_491521501727_item	2444337	et	2	main
te	doc_491521501727_item	2444342	et	4	main
kolinud	doc_491521501727_item	2444344	et	4	main
läks	doc_491521501727_item	2444357	et	3	main
teile	doc_491521501727_item	2444360	et	4	main
elukohas	doc_491521501727_item	2444363	et	4	main
kas	doc_491521501727_item	2444364	et	3	main
on	doc_491521501727_item	2444365	et	4	main
kauge	doc_491521501727_item	2444366	et	4	main
tööl	doc_491521501727_item	2444367	et	3	main
käia	doc_491521501727_item	2444368	et	4	main
ja	doc_491521501727_item	2444369	et	3	main
kutsuge	doc_491521501727_item	2444370	et	3	main
ta	doc_491521501727_item	2444371	et	4	main
külla	doc_491521501727_item	2444372	et	4	main
kirja	doc_491521501727_item	2444373	et	4	main
nõutav	doc_491521501727_item	2444374	et	4	main
pikkus	doc_491521501727_item	2444375	et	4	main
on	doc_491521501727_item	2444376	et	4	main
umbes	doc_491521501727_item	2444377	et	4	main
80	doc_491521501727_item	2444378	et	2	main
30	doc_491521501727_item	2444323	et	2	main
kuupäev	doc_491521501727_item	2444338	et	3	main
eestlastest	doc_491521501727_item	2444352	et	4	main
sõbrale	doc_491521501727_item	2444353	et	3	main
ma	doc_491521501727_item	2444388	et	3	main
ja	doc_491521501727_item	2444393	et	3	main
tomas	doc_491521501727_item	2444401	et	4	main
ja	doc_491521501727_item	2444402	et	3	main
mööbel	doc_491521501727_item	2444410	et	3	main
on	doc_491521501727_item	2444419	et	4	main
ja	doc_491521501727_item	2444421	et	3	main
et	doc_491521501727_item	2444425	et	3	main
kaugel	doc_491521501727_item	2444430	et	4	main
minu	doc_491521501727_item	2444431	et	3	main
töökohta	doc_491521501727_item	2444432	et	4	main
ma	doc_491521501727_item	2444433	et	3	main
tahan	doc_491521501727_item	2444434	et	3	main
kutsutama	doc_491521501727_item	2444435	et	3	main
ma	doc_491521501727_item	2444449	et	3	main
sinu	doc_491521501727_item	2444451	et	3	main
kirjadiv	doc_491521501728_item	2444462	et	4	main
küsimused	doc_491521501728_item	2444466	et	4	main
soovite	doc_491521501728_item	2444469	et	3	main
spordiklubi	doc_491521501728_item	2444483	et	4	main
tartu	doc_491521501728_item	2444487	et	4	main
ants	doc_491521501728_item	2444490	et	4	main
2	doc_491521501728_item	2444492	et	2	main
jaanuar	doc_491521501728_item	2444495	et	3	main
sellest	doc_491521501727_item	2444350	et	4	main
kuidas	doc_491521501727_item	2444356	et	3	main
kuidas	doc_491521501727_item	2444359	et	3	main
meeldib	doc_491521501727_item	2444361	et	3	main
tahan	doc_491521501727_item	2444383	et	3	main
kirjuta	doc_491521501727_item	2444384	et	4	main
olen	doc_491521501727_item	2444389	et	3	main
tahan	doc_491521501727_item	2444394	et	3	main
olivad	doc_491521501727_item	2444405	et	4	main
autol	doc_491521501727_item	2444406	et	3	main
ja	doc_491521501727_item	2444407	et	3	main
hele	doc_491521501727_item	2444422	et	3	main
on	doc_491521501727_item	2444429	et	4	main
meeldib	doc_491521501727_item	2444446	et	3	main
mulle	doc_491521501727_item	2444454	et	4	main
kirjutamistest	doc_491521501728_item	2444463	et	4	main
1-10	doc_491521501728_item	2444467	et	2	main
spordiklubis	doc_491521501728_item	2444472	et	3	main
kõigile	doc_491521501728_item	2444481	et	4	main
tervis	doc_491521501728_item	2444484	et	3	main
8	doc_491521501728_item	2444525	et	2	main
olete	doc_491521501728_item	2444527	et	3	main
spordiga	doc_491521501728_item	2444529	et	3	main
avati	doc_491521501728_item	2444542	et	3	main
suur	doc_491521501728_item	2444544	et	3	main
ja	doc_491521501728_item	2444555	et	3	main
umbes	doc_491521501728_item	2444563	et	4	main
on	doc_491521501728_item	2444572	et	4	main
kõik	doc_491521501728_item	2444573	et	4	main
müüakse	doc_491521501728_item	2444599	et	3	main
aga	doc_491521501728_item	2444601	et	3	main
osta	doc_491521501728_item	2444609	et	4	main
me	doc_491521501728_item	2444628	et	4	main
sööme	doc_491521501728_item	2444629	et	4	main
hamburger	doc_491521501728_item	2444630	et	3	main
liimonaadiga	doc_491521501728_item	2444631	et	4	main
ja	doc_491521501728_item	2444632	et	3	main
jäätis	doc_491521501728_item	2444633	et	3	main
kui	doc_491521501728_item	2444634	et	3	main
ma	doc_491521501728_item	2444635	et	3	main
tahan	doc_491521501728_item	2444636	et	3	main
ma	doc_491521501728_item	2444640	et	3	main
kõik	doc_491521501728_item	2444649	et	4	main
10	doc_491521501728_item	2444664	et	2	main
e-r	doc_491521501728_item	2444665	et	4	main
1200-2200	doc_491521501728_item	2444666	et	2	main
p	doc_491521501728_item	2444669	et	4	main
45	doc_491521501728_item	2444673	et	2	main
kr	doc_491521501728_item	2444674	et	4	main
pensionäridele	doc_491521501728_item	2444675	et	3	main
30	doc_491521501728_item	2444681	et	2	main
kr	doc_491521501728_item	2444682	et	4	main
teile	doc_491521501727_item	2444385	et	4	main
oma	doc_491521501727_item	2444386	et	4	main
kolisin	doc_491521501727_item	2444390	et	3	main
korterisse	doc_491521501727_item	2444392	et	3	main
teile	doc_491521501727_item	2444396	et	4	main
abivad	doc_491521501727_item	2444398	et	4	main
rein	doc_491521501727_item	2444403	et	4	main
nad	doc_491521501727_item	2444404	et	3	main
korterissel	doc_491521501727_item	2444412	et	4	main
hästi	doc_491521501727_item	2444424	et	3	main
uus	doc_491521501727_item	2444427	et	3	main
sinuga	doc_491521501727_item	2444436	et	3	main
mulle	doc_491521501727_item	2444445	et	4	main
esimene	doc_491521501728_item	2444464	et	3	main
spordiga	doc_491521501728_item	2444471	et	3	main
on	doc_491521501728_item	2444473	et	4	main
täita	doc_491521501728_item	2444475	et	4	main
palun	doc_491521501728_item	2444477	et	3	main
vastake	doc_491521501728_item	2444478	et	3	main
kohe	doc_491521501728_item	2444479	et	4	main
täna	doc_491521501728_item	2444480	et	4	main
tamme	doc_491521501728_item	2444485	et	4	main
nimi	doc_491521501728_item	2444489	et	3	main
karp	doc_491521501728_item	2444491	et	3	main
3	doc_491521501728_item	2444497	et	2	main
4	doc_491521501728_item	2444522	et	2	main
kuupäev	doc_491521501728_item	2444535	et	3	main
teine	doc_491521501728_item	2444537	et	3	main
uus	doc_491521501728_item	2444543	et	3	main
eestlasest	doc_491521501728_item	2444548	et	3	main
uus	doc_491521501728_item	2444551	et	3	main
välja	doc_491521501728_item	2444553	et	4	main
seal	doc_491521501728_item	2444557	et	4	main
kirja	doc_491521501728_item	2444559	et	4	main
80	doc_491521501728_item	2444564	et	2	main
sõna	doc_491521501728_item	2444565	et	4	main
mark	doc_491521501728_item	2444567	et	3	main
kuidas	doc_491521501728_item	2444568	et	3	main
korrusel	doc_491521501728_item	2444606	et	3	main
sa	doc_491521501728_item	2444607	et	3	main
elektrotehnikat	doc_491521501728_item	2444611	et	3	main
kingad	doc_491521501728_item	2444613	et	3	main
nädalas	doc_491521501728_item	2444624	et	3	main
seal	doc_491521501728_item	2444627	et	4	main
midagi	doc_491521501728_item	2444637	et	4	main
selle	doc_491521501728_item	2444642	et	4	main
vajalikku	doc_491521501728_item	2444650	et	4	main
asjad	doc_491521501728_item	2444651	et	3	main
korraga	doc_491521501728_item	2444652	et	4	main
küsimustekaart	doc_491521501728_item	2444655	et	4	main
aadress	doc_491521501728_item	2444657	et	3	main
45	doc_491521501728_item	2444671	et	2	main
õpilastele	doc_491521501728_item	2444677	et	4	main
ja	doc_491521501728_item	2444686	et	3	main
meeldib	doc_491521501727_item	2444414	et	3	main
minu	doc_491521501727_item	2444415	et	3	main
uus	doc_491521501727_item	2444416	et	3	main
korter	doc_491521501727_item	2444417	et	3	main
ta	doc_491521501727_item	2444418	et	4	main
minu	doc_491521501727_item	2444426	et	3	main
uude	doc_491521501727_item	2444438	et	3	main
kortirisse	doc_491521501727_item	2444439	et	4	main
teda	doc_491521501727_item	2444442	et	4	main
ja	doc_491521501727_item	2444443	et	3	main
ütled	doc_491521501727_item	2444444	et	3	main
sulle	doc_491521501727_item	2444448	et	3	main
vastus	doc_491521501727_item	2444452	et	3	main
mul	doc_491521501727_item	2444455	et	3	main
051338269	doc_491521501727_item	2444459	et	2	main
austusega	doc_491521501727_item	2444460	et	4	main
irina	doc_491521501727_item	2444461	et	3	main
te	doc_491521501728_item	2444468	et	4	main
tegeleda	doc_491521501728_item	2444470	et	3	main
vaja	doc_491521501728_item	2444474	et	4	main
ankeet	doc_491521501728_item	2444476	et	3	main
1	doc_491521501728_item	2444488	et	2	main
sugu	doc_491521501728_item	2444498	et	4	main
mees	doc_491521501728_item	2444499	et	4	main
4	doc_491521501728_item	2444500	et	2	main
aadress	doc_491521501728_item	2444502	et	3	main
kodune	doc_491521501728_item	2444501	et	4	main
tallinn	doc_491521501728_item	2444503	et	4	main
narva	doc_491521501728_item	2444504	et	4	main
mnt	doc_491521501728_item	2444505	et	4	main
35-18	doc_491521501728_item	2444506	et	2	main
5	doc_491521501728_item	2444507	et	2	main
telefoninumber	doc_491521501728_item	2444508	et	3	main
0	doc_491521501728_item	2444509	et	2	main
653853	doc_491521501728_item	2444510	et	2	main
6	doc_491521501728_item	2444511	et	2	main
teid	doc_491521501728_item	2444512	et	4	main
huvitav	doc_491521501728_item	2444513	et	4	main
spordiala	doc_491521501728_item	2444514	et	4	main
kergejõustik	doc_491521501728_item	2444515	et	3	main
7	doc_491521501728_item	2444516	et	2	main
mitu	doc_491521501728_item	2444517	et	4	main
korda	doc_491521501728_item	2444518	et	4	main
nädalas	doc_491521501728_item	2444519	et	3	main
soovite	doc_491521501728_item	2444520	et	3	main
treenida	doc_491521501728_item	2444521	et	3	main
nädalas	doc_491521501728_item	2444524	et	3	main
varem	doc_491521501728_item	2444528	et	4	main
elukoha	doc_491521501728_item	2444540	et	4	main
kauplus	doc_491521501728_item	2444545	et	3	main
oma	doc_491521501728_item	2444547	et	4	main
sõbrale	doc_491521501728_item	2444549	et	3	main
mida	doc_491521501728_item	2444556	et	4	main
on	doc_491521501728_item	2444562	et	4	main
mul	doc_491521501728_item	2444571	et	3	main
toitu	doc_491521501728_item	2444600	et	4	main
teisel	doc_491521501728_item	2444602	et	4	main
korrusel	doc_491521501728_item	2444603	et	3	main
riided	doc_491521501728_item	2444604	et	3	main
teisel	doc_491521501728_item	2444605	et	4	main
mänguasjad	doc_491521501728_item	2444610	et	3	main
koos	doc_491521501728_item	2444620	et	4	main
9	doc_491521501728_item	2444532	et	2	main
allkiri	doc_491521501728_item	2444533	et	3	main
osa	doc_491521501728_item	2444538	et	4	main
teie	doc_491521501728_item	2444539	et	4	main
kirjutage	doc_491521501728_item	2444546	et	3	main
milline	doc_491521501728_item	2444550	et	3	main
kauplus	doc_491521501728_item	2444552	et	3	main
näeb	doc_491521501728_item	2444554	et	3	main
müüjakse	doc_491521501728_item	2444558	et	4	main
nõutav	doc_491521501728_item	2444560	et	4	main
pikkus	doc_491521501728_item	2444561	et	4	main
elad	doc_491521501728_item	2444570	et	3	main
hästi	doc_491521501728_item	2444574	et	3	main
sellel	doc_491521501728_item	2444575	et	4	main
nädalal	doc_491521501728_item	2444576	et	3	main
minu	doc_491521501728_item	2444577	et	3	main
kodu	doc_491521501728_item	2444578	et	4	main
juures	doc_491521501728_item	2444579	et	4	main
avati	doc_491521501728_item	2444580	et	3	main
uus	doc_491521501728_item	2444581	et	3	main
suur	doc_491521501728_item	2444582	et	3	main
kauplus	doc_491521501728_item	2444583	et	3	main
see	doc_491521501728_item	2444584	et	3	main
kauplus	doc_491521501728_item	2444585	et	3	main
on	doc_491521501728_item	2444586	et	4	main
väga	doc_491521501728_item	2444587	et	3	main
suur	doc_491521501728_item	2444588	et	3	main
ja	doc_491521501728_item	2444589	et	3	main
moderniseeritud	doc_491521501728_item	2444590	et	4	main
seal	doc_491521501728_item	2444591	et	4	main
on	doc_491521501728_item	2444592	et	4	main
euroremont	doc_491521501728_item	2444593	et	3	main
ta	doc_491521501728_item	2444594	et	4	main
on	doc_491521501728_item	2444595	et	4	main
kahekorruseline	doc_491521501728_item	2444596	et	4	main
esimesel	doc_491521501728_item	2444597	et	3	main
kodutehnikat	doc_491521501728_item	2444612	et	3	main
veel	doc_491521501728_item	2444614	et	4	main
korrusel	doc_491521501728_item	2444616	et	3	main
sõbradega	doc_491521501728_item	2444621	et	4	main
kord	doc_491521501728_item	2444623	et	4	main
aega	doc_491521501728_item	2444654	et	4	main
avatud	doc_491521501728_item	2444658	et	4	main
hind	doc_491521501728_item	2444659	et	3	main
juuksur	doc_491521501728_item	2444660	et	3	main
vastustekaart	doc_491521501728_item	2444661	et	4	main
p	doc_491521501728_item	2444680	et	4	main
kohvik	doc_491521501728_item	2444683	et	3	main
väiteid	doc_491521501732_item	2445101	et	4	main
selle	doc_491521501732_item	2445109	et	4	main
nõus	doc_491521501732_item	2445111	et	4	main
mitte	doc_491521501732_item	2445113	et	3	main
esitage	doc_491521501732_item	2445114	et	3	main
poolt-	doc_491521501732_item	2445115	et	4	main
ja	doc_491521501732_item	2445116	et	3	main
vastuargumente	doc_491521501732_item	2445117	et	3	main
koolivorm	doc_491521501732_item	2445125	et	3	main
see	doc_491521501732_item	2445127	et	3	main
siis	doc_491521501728_item	2444639	et	3	main
sest	doc_491521501728_item	2444644	et	4	main
osta	doc_491521501728_item	2444648	et	4	main
linnaujula	doc_491521501728_item	2444662	et	4	main
vasara	doc_491521501728_item	2444663	et	3	main
min	doc_491521501728_item	2444672	et	4	main
ja	doc_491521501728_item	2444676	et	3	main
saun	doc_491521501728_item	2444684	et	3	main
väitega	doc_491521501732_item	2445110	et	3	main
1	doc_491521501732_item	2445119	et	2	main
sest	doc_491521501732_item	2445126	et	4	main
käivad	doc_491521501732_item	2445137	et	4	main
kasti	doc_491521501732_item	2445142	et	4	main
160	doc_491521501732_item	2445149	et	2	main
sõna	doc_491521501732_item	2445150	et	4	main
rikkus	doc_491521501732_item	2445151	et	4	main
ja	doc_491521501732_item	2445152	et	3	main
ma	doc_491521501732_item	2445157	et	3	main
ei	doc_491521501732_item	2445158	et	4	main
saavad	doc_491521501732_item	2445181	et	4	main
andekad	doc_491521501732_item	2445189	et	3	main
ja	doc_491521501732_item	2445196	et	3	main
nad	doc_491521501732_item	2445208	et	3	main
tea	doc_491521501732_item	2445210	et	4	main
inimesed	doc_491521501732_item	2445215	et	3	main
on	doc_491521501732_item	2445216	et	4	main
elu	doc_491521501732_item	2445224	et	4	main
igav	doc_491521501732_item	2445226	et	3	main
palju	doc_491521501732_item	2445229	et	4	main
on	doc_491521501732_item	2445235	et	4	main
ole	doc_491521501732_item	2445243	et	4	main
õppima	doc_491521501732_item	2445248	et	3	main
muidugi	doc_491521501732_item	2445251	et	4	main
on	doc_491521501732_item	2445253	et	4	main
kas	doc_491521501732_item	2445107	et	3	main
või	doc_491521501732_item	2445112	et	4	main
essee	doc_491521501732_item	2445099	et	4	main
lugege	doc_491521501732_item	2445100	et	3	main
valige	doc_491521501732_item	2445102	et	3	main
neist	doc_491521501732_item	2445103	et	4	main
üks	doc_491521501732_item	2445104	et	3	main
ning	doc_491521501732_item	2445105	et	3	main
kirjutage	doc_491521501732_item	2445106	et	3	main
väide	doc_491521501732_item	2445118	et	4	main
peaks	doc_491521501732_item	2445122	et	4	main
aitab	doc_491521501732_item	2445128	et	3	main
omakoolitunde	doc_491521501732_item	2445130	et	4	main
tekkimisele	doc_491521501732_item	2445131	et	4	main
tarkus	doc_491521501732_item	2445136	et	4	main
kirjutage	doc_491521501732_item	2445140	et	3	main
u	doc_491521501732_item	2445148	et	4	main
alati	doc_491521501732_item	2445155	et	4	main
koos	doc_491521501732_item	2445156	et	4	main
väitega	doc_491521501732_item	2445161	et	3	main
andekad	doc_491521501732_item	2445169	et	3	main
ja	doc_491521501732_item	2445171	et	3	main
paljud	doc_491521501732_item	2445180	et	3	main
aga	doc_491521501732_item	2445183	et	3	main
töötada	doc_491521501732_item	2445188	et	3	main
soovivad	doc_491521501732_item	2445191	et	4	main
õppida	doc_491521501732_item	2445192	et	3	main
niisugused	doc_491521501732_item	2445202	et	3	main
palju	doc_491521501732_item	2445205	et	4	main
laiad	doc_491521501732_item	2445217	et	4	main
nendel	doc_491521501732_item	2445218	et	4	main
ei	doc_491521501732_item	2445219	et	4	main
inimesi	doc_491521501732_item	2445230	et	4	main
kes	doc_491521501732_item	2445231	et	4	main
kõrgharidus	doc_491521501732_item	2445236	et	3	main
aga	doc_491521501732_item	2445237	et	3	main
raha	doc_491521501732_item	2445244	et	4	main
et	doc_491521501732_item	2445245	et	3	main
raske	doc_491521501732_item	2445252	et	4	main
nendele	doc_491521501732_item	2445254	et	4	main
ole	doc_491521501732_item	2445262	et	4	main
praktikat	doc_491521501732_item	2445263	et	3	main
ei	doc_491521501732_item	2445266	et	4	main
eesti	doc_491521501732_item	2445268	et	4	main
keelt	doc_491521501732_item	2445269	et	4	main
ja	doc_491521501732_item	2445278	et	3	main
saada	doc_491521501732_item	2445279	et	4	main
palju	doc_491521501732_item	2445280	et	4	main
rõõmus	doc_491521501732_item	2445323	et	4	main
hea	doc_491521501732_item	2445329	et	4	main
olete	doc_491521501732_item	2445108	et	3	main
igal	doc_491521501732_item	2445120	et	3	main
koolil	doc_491521501732_item	2445121	et	4	main
olema	doc_491521501732_item	2445123	et	4	main
oma	doc_491521501732_item	2445124	et	4	main
väide	doc_491521501732_item	2445132	et	4	main
2	doc_491521501732_item	2445133	et	2	main
pikkus	doc_491521501732_item	2445146	et	4	main
tarkus	doc_491521501732_item	2445153	et	4	main
ole	doc_491521501732_item	2445159	et	4	main
sest	doc_491521501732_item	2445163	et	4	main
inimesed	doc_491521501732_item	2445165	et	3	main
väga	doc_491521501732_item	2445167	et	3	main
otstarbekad	doc_491521501732_item	2445170	et	3	main
ei	doc_491521501732_item	2445173	et	4	main
ole	doc_491521501732_item	2445174	et	4	main
rikad	doc_491521501732_item	2445175	et	4	main
inimesed	doc_491521501732_item	2445176	et	3	main
erinevalt	doc_491521501732_item	2445179	et	4	main
leia	doc_491521501732_item	2445193	et	4	main
hea	doc_491521501732_item	2445194	et	4	main
töö	doc_491521501732_item	2445195	et	4	main
töötavad	doc_491521501732_item	2445199	et	4	main
kellel	doc_491521501732_item	2445203	et	4	main
ja	doc_491521501732_item	2445207	et	3	main
nendel	doc_491521501732_item	2445234	et	4	main
ei	doc_491521501732_item	2445242	et	4	main
edasi	doc_491521501732_item	2445249	et	3	main
ja	doc_491521501732_item	2445264	et	3	main
oska	doc_491521501732_item	2445267	et	4	main
on	doc_491521501732_item	2445283	et	4	main
töötus	doc_491521501732_item	2445285	et	4	main
lugu	doc_491521501732_item	2445330	et	4	main
rikkus	doc_491521501732_item	2445134	et	4	main
ja	doc_491521501732_item	2445135	et	3	main
alati	doc_491521501732_item	2445138	et	4	main
sisse	doc_491521501732_item	2445143	et	4	main
nõutav	doc_491521501732_item	2445145	et	4	main
kaasa	doc_491521501732_item	2445129	et	4	main
koos	doc_491521501732_item	2445139	et	4	main
joonitud	doc_491521501732_item	2445141	et	4	main
selle	doc_491521501732_item	2445160	et	4	main
saavad	doc_491521501732_item	2445177	et	4	main
palju	doc_491521501732_item	2445187	et	4	main
inimesed	doc_491521501732_item	2445190	et	3	main
nad	doc_491521501732_item	2445197	et	3	main
on	doc_491521501732_item	2445201	et	4	main
raha	doc_491521501732_item	2445206	et	4	main
mida	doc_491521501732_item	2445211	et	4	main
nendega	doc_491521501732_item	2445212	et	4	main
teha	doc_491521501732_item	2445213	et	3	main
need	doc_491521501732_item	2445214	et	3	main
ole	doc_491521501732_item	2445220	et	4	main
teksti	doc_491521501732_item	2445144	et	4	main
on	doc_491521501732_item	2445147	et	4	main
käivad	doc_491521501732_item	2445154	et	4	main
nõus	doc_491521501732_item	2445162	et	4	main
paljud	doc_491521501732_item	2445164	et	3	main
on	doc_491521501732_item	2445166	et	4	main
targad	doc_491521501732_item	2445168	et	3	main
nad	doc_491521501732_item	2445172	et	3	main
raha	doc_491521501732_item	2445178	et	4	main
lihtsalt	doc_491521501732_item	2445182	et	4	main
teisele	doc_491521501732_item	2445184	et	4	main
on	doc_491521501732_item	2445185	et	4	main
vaja	doc_491521501732_item	2445186	et	4	main
palju	doc_491521501732_item	2445198	et	4	main
aga	doc_491521501732_item	2445200	et	3	main
on	doc_491521501732_item	2445204	et	4	main
ei	doc_491521501732_item	2445209	et	4	main
nende	doc_491521501732_item	2445223	et	4	main
on	doc_491521501732_item	2445225	et	4	main
ma	doc_491521501732_item	2445227	et	3	main
tean	doc_491521501732_item	2445228	et	3	main
õppisid	doc_491521501732_item	2445233	et	4	main
ole	doc_491521501732_item	2445240	et	4	main
ja	doc_491521501732_item	2445241	et	3	main
ja	doc_491521501732_item	2445247	et	3	main
kes	doc_491521501732_item	2445255	et	4	main
valdab	doc_491521501732_item	2445256	et	3	main
raske	doc_491521501732_item	2445272	et	4	main
et	doc_491521501732_item	2445274	et	3	main
raha	doc_491521501732_item	2445281	et	4	main
muret	doc_491521501732_item	2445221	et	3	main
ja	doc_491521501732_item	2445222	et	3	main
palju	doc_491521501732_item	2445232	et	4	main
tööd	doc_491521501732_item	2445238	et	4	main
ei	doc_491521501732_item	2445239	et	4	main
minna	doc_491521501732_item	2445246	et	3	main
ja	doc_491521501732_item	2445250	et	3	main
ainult	doc_491521501732_item	2445257	et	4	main
praegu	doc_491521501732_item	2445270	et	3	main
on	doc_491521501732_item	2445271	et	4	main
suur	doc_491521501732_item	2445284	et	3	main
on	doc_491521501732_item	2445287	et	4	main
kellel	doc_491521501732_item	2445289	et	4	main
on	doc_491521501732_item	2445290	et	4	main
kõrg	doc_491521501732_item	2445291	et	4	main
haridus	doc_491521501732_item	2445292	et	3	main
ta	doc_491521501732_item	2445293	et	4	main
tundub	doc_491521501732_item	2445294	et	3	main
oma	doc_491521501732_item	2445295	et	4	main
töö	doc_491521501732_item	2445296	et	4	main
ja	doc_491521501732_item	2445297	et	3	main
ei	doc_491521501732_item	2445298	et	4	main
saa	doc_491521501732_item	2445299	et	4	main
kuskil	doc_491521501732_item	2445300	et	3	main
rakendada	doc_491521501732_item	2445301	et	3	main
kasutada	doc_491521501732_item	2445302	et	3	main
ja	doc_491521501732_item	2445303	et	3	main
istub	doc_491521501732_item	2445304	et	3	main
kodus	doc_491521501732_item	2445305	et	4	main
looduses	doc_491521501732_item	2445306	et	4	main
leida	doc_491521501732_item	2445307	et	3	main
töö	doc_491521501732_item	2445308	et	4	main
väga	doc_491521501732_item	2445309	et	3	main
vähe	doc_491521501732_item	2445310	et	3	main
on	doc_491521501732_item	2445311	et	4	main
neid	doc_491521501732_item	2445312	et	4	main
inimesi	doc_491521501732_item	2445313	et	4	main
kellel	doc_491521501732_item	2445314	et	4	main
rikkus	doc_491521501732_item	2445315	et	4	main
ja	doc_491521501732_item	2445316	et	3	main
tarkus	doc_491521501732_item	2445317	et	4	main
käivad	doc_491521501732_item	2445318	et	4	main
koos	doc_491521501732_item	2445319	et	4	main
ma	doc_491521501732_item	2445320	et	3	main
oleksin	doc_491521501732_item	2445321	et	3	main
oleks	doc_491521501732_item	2445325	et	3	main
kõikidel	doc_491521501732_item	2445326	et	4	main
inimestel	doc_491521501732_item	2445327	et	3	main
niisugune	doc_491521501732_item	2445328	et	3	main
teadmisega	doc_491521501732_item	2445258	et	4	main
ja	doc_491521501732_item	2445259	et	3	main
temal	doc_491521501732_item	2445260	et	3	main
ei	doc_491521501732_item	2445261	et	4	main
ta	doc_491521501732_item	2445265	et	4	main
aeg	doc_491521501732_item	2445273	et	3	main
leida	doc_491521501732_item	2445275	et	3	main
hea	doc_491521501732_item	2445276	et	4	main
töö	doc_491521501732_item	2445277	et	4	main
eestis	doc_491521501732_item	2445282	et	3	main
ja	doc_491521501732_item	2445286	et	3	main
inimesed	doc_491521501732_item	2445288	et	3	main
väga	doc_491521501732_item	2445322	et	3	main
et	doc_491521501732_item	2445324	et	3	main
tallinna	doc_491521501740_item	2446411	et	4	main
pedagoogika	doc_491521501740_item	2446412	et	4	main
võõrkeelena	doc_491521501740_item	2446418	et	3	main
vead	doc_491521501740_item	2446423	et	4	main
eesti	doc_491521501740_item	2446424	et	4	main
verschik	doc_491521501740_item	2446431	et	4	main
ja	doc_491521501740_item	2446439	et	3	main
2	doc_491521501740_item	2446442	et	2	main
3	doc_491521501740_item	2446446	et	2	main
põhjused	doc_491521501740_item	2446455	et	3	main
nii	doc_491521501740_item	2446467	et	3	main
ma-	doc_491521501740_item	2446468	et	3	main
tingitud	doc_491521501740_item	2446507	et	4	main
vigade	doc_491521501740_item	2446510	et	3	main
sagedus	doc_491521501740_item	2446512	et	4	main
kokkuvõte	doc_491521501740_item	2446513	et	3	main
lisa	doc_491521501740_item	2446517	et	4	main
eesti	doc_491521501740_item	2446408	et	4	main
filoloogia	doc_491521501740_item	2446414	et	4	main
darja	doc_491521501740_item	2446419	et	4	main
ev-31	doc_491521501740_item	2446421	et	4	main
tallinn	doc_491521501740_item	2446432	et	4	main
2004	doc_491521501740_item	2446433	et	2	main
sisukord	doc_491521501740_item	2446434	et	3	main
4	doc_491521501740_item	2446450	et	2	main
vigade	doc_491521501740_item	2446454	et	3	main
grammatilistest	doc_491521501740_item	2446457	et	3	main
tingitud	doc_491521501740_item	2446459	et	4	main
vead	doc_491521501740_item	2446460	et	4	main
412	doc_491521501740_item	2446463	et	2	main
verbid	doc_491521501740_item	2446464	et	3	main
mis	doc_491521501740_item	2446465	et	4	main
kategooriad	doc_491521501740_item	2446477	et	3	main
infinitiiviga	doc_491521501740_item	2446479	et	3	main
1	doc_491521501740_item	2446518	et	2	main
valikuga	doc_491521501740_item	2446521	et	3	main
põhjustatud	doc_491521501740_item	2446532	et	4	main
hulka	doc_491521501740_item	2446534	et	4	main
paljude	doc_491521501740_item	2446539	et	3	main
valikul	doc_491521501740_item	2446544	et	3	main
käsitlenud	doc_491521501740_item	2446551	et	4	main
infinitiiviga	doc_491521501740_item	2446552	et	3	main
vead	doc_491521501740_item	2446554	et	4	main
tingitud	doc_491521501740_item	2446565	et	4	main
ja	doc_491521501740_item	2446569	et	3	main
omandamisel	doc_491521501740_item	2446578	et	4	main
vigu	doc_491521501740_item	2446587	et	3	main
enamik	doc_491521501740_item	2446591	et	3	main
keele	doc_491521501740_item	2446593	et	4	main
õppijaid	doc_491521501740_item	2446594	et	4	main
infinitiiv	doc_491521501740_item	2446599	et	3	main
on	doc_491521501740_item	2446600	et	4	main
laialt	doc_491521501740_item	2446601	et	4	main
selle	doc_491521501740_item	2446618	et	4	main
ja	doc_491521501740_item	2446621	et	3	main
infinitiivide	doc_491521501740_item	2446636	et	3	main
saab	doc_491521501740_item	2446643	et	3	main
vältida	doc_491521501740_item	2446654	et	3	main
töö	doc_491521501740_item	2446656	et	4	main
ka	doc_491521501740_item	2446669	et	3	main
vene	doc_491521501740_item	2446674	et	4	main
on	doc_491521501740_item	2446677	et	4	main
grammatikad	doc_491521501740_item	2446685	et	3	main
keeleteaduse	doc_491521501740_item	2446698	et	3	main
vead	doc_491521501740_item	2446407	et	4	main
ülikool	doc_491521501740_item	2446413	et	4	main
infinitiivi	doc_491521501740_item	2446409	et	4	main
valikul	doc_491521501740_item	2446410	et	3	main
eesti	doc_491521501740_item	2446416	et	4	main
keel	doc_491521501740_item	2446417	et	4	main
fjodorova	doc_491521501740_item	2446420	et	4	main
juhendaja	doc_491521501740_item	2446428	et	4	main
vanemteadur	doc_491521501740_item	2446429	et	3	main
kõrvutavalt	doc_491521501740_item	2446437	et	4	main
eesti	doc_491521501740_item	2446440	et	4	main
lähemalt	doc_491521501740_item	2446447	et	4	main
vene	doc_491521501740_item	2446448	et	4	main
seotud	doc_491521501740_item	2446453	et	4	main
kui	doc_491521501740_item	2446469	et	3	main
da-infinitiivi	doc_491521501740_item	2446471	et	4	main
kasutust	doc_491521501740_item	2446472	et	4	main
413	doc_491521501740_item	2446473	et	2	main
vead	doc_491521501740_item	2446508	et	4	main
esinemise	doc_491521501740_item	2446511	et	4	main
kasutatud	doc_491521501740_item	2446514	et	4	main
kirjandus	doc_491521501740_item	2446515	et	3	main
lisad	doc_491521501740_item	2446516	et	4	main
seotud	doc_491521501740_item	2446522	et	4	main
ma-	doc_491521501740_item	2446525	et	3	main
kuuluvad	doc_491521501740_item	2446529	et	4	main
on	doc_491521501740_item	2446537	et	4	main
kuid	doc_491521501740_item	2446542	et	4	main
tehtud	doc_491521501740_item	2446545	et	4	main
keegi	doc_491521501740_item	2446549	et	4	main
seotud	doc_491521501740_item	2446553	et	4	main
sellest	doc_491521501740_item	2446566	et	4	main
sattub	doc_491521501740_item	2446571	et	3	main
tähendab	doc_491521501740_item	2446584	et	3	main
teeb	doc_491521501740_item	2446588	et	3	main
ellis	doc_491521501740_item	2446597	et	4	main
eesti	doc_491521501740_item	2446603	et	4	main
ma-	doc_491521501740_item	2446620	et	3	main
da-infinitiiv	doc_491521501740_item	2446622	et	3	main
keelekursuste	doc_491521501740_item	2446624	et	3	main
kasutusreegleid	doc_491521501740_item	2446626	et	3	main
õpetatakse	doc_491521501740_item	2446627	et	3	main
lastele	doc_491521501740_item	2446628	et	4	main
ja	doc_491521501740_item	2446629	et	3	main
täiskasvanutele	doc_491521501740_item	2446630	et	3	main
aidata	doc_491521501740_item	2446644	et	4	main
töötada	doc_491521501740_item	2446646	et	3	main
neid	doc_491521501740_item	2446649	et	4	main
vigu	doc_491521501740_item	2446650	et	3	main
kõnes	doc_491521501740_item	2446651	et	3	main
antud	doc_491521501740_item	2446655	et	4	main
teoreetiline	doc_491521501740_item	2446657	et	3	main
eraldi	doc_491521501740_item	2446671	et	4	main
eesti	doc_491521501740_item	2446672	et	4	main
ja	doc_491521501740_item	2446673	et	3	main
käsitlemine	doc_491521501740_item	2446676	et	4	main
ainukesed	doc_491521501740_item	2446681	et	4	main
eesti	doc_491521501740_item	2446682	et	4	main
vene	doc_491521501740_item	2446683	et	4	main
nõuab	doc_491521501740_item	2446700	et	3	main
vene	doc_491521501740_item	2446713	et	4	main
antud	doc_491521501740_item	2446725	et	4	main
töö	doc_491521501740_item	2446726	et	4	main
õpetajatele	doc_491521501740_item	2446731	et	4	main
õpetajatele	doc_491521501740_item	2446738	et	4	main
eesti	doc_491521501740_item	2446739	et	4	main
õppekeelega	doc_491521501740_item	2446740	et	3	main
koolides	doc_491521501740_item	2446741	et	3	main
kuna	doc_491521501740_item	2446742	et	3	main
aastatel	doc_491521501740_item	2446749	et	4	main
eestis	doc_491521501740_item	2446762	et	3	main
venelaste	doc_491521501740_item	2446406	et	4	main
teaduskond	doc_491521501740_item	2446415	et	3	main
infinitiivi	doc_491521501740_item	2446425	et	4	main
valikul	doc_491521501740_item	2446426	et	3	main
seminaritöö	doc_491521501740_item	2446427	et	4	main
sissejuhatus	doc_491521501740_item	2446435	et	4	main
1	doc_491521501740_item	2446436	et	2	main
lähemalt	doc_491521501740_item	2446443	et	4	main
infinitiividest	doc_491521501740_item	2446445	et	3	main
infinitiivist	doc_491521501740_item	2446449	et	3	main
infinitiivi	doc_491521501740_item	2446451	et	4	main
lubavad	doc_491521501740_item	2446466	et	4	main
ka	doc_491521501740_item	2446470	et	3	main
aktiivsuse	doc_491521501740_item	2446476	et	4	main
vigadest	doc_491521501740_item	2446523	et	3	main
sissejuhatus	doc_491521501740_item	2446524	et	4	main
ja	doc_491521501740_item	2446526	et	3	main
enamasti	doc_491521501740_item	2446530	et	4	main
poolt	doc_491521501740_item	2446541	et	4	main
vigu	doc_491521501740_item	2446546	et	3	main
põhjalikult	doc_491521501740_item	2446550	et	4	main
keele	doc_491521501740_item	2446577	et	4	main
neid	doc_491521501740_item	2446586	et	4	main
tõenäosusega	doc_491521501740_item	2446590	et	3	main
emakeelest	doc_491521501740_item	2446595	et	4	main
vorm	doc_491521501740_item	2446605	et	3	main
ning	doc_491521501740_item	2446606	et	3	main
õnelejel	doc_491521501740_item	2446608	et	4	main
venelaste	doc_491521501740_item	2446422	et	4	main
a	doc_491521501740_item	2446430	et	4	main
vene	doc_491521501740_item	2446438	et	4	main
infinitiividest	doc_491521501740_item	2446441	et	3	main
eesti	doc_491521501740_item	2446444	et	4	main
valikuga	doc_491521501740_item	2446452	et	3	main
41	doc_491521501740_item	2446456	et	2	main
erinevustest	doc_491521501740_item	2446458	et	4	main
411	doc_491521501740_item	2446461	et	2	main
aspekt	doc_491521501740_item	2446462	et	3	main
passiivsuse	doc_491521501740_item	2446474	et	4	main
ja	doc_491521501740_item	2446475	et	3	main
414	doc_491521501740_item	2446478	et	2	main
laiendatud	doc_491521501740_item	2446480	et	4	main
tegusõnade	doc_491521501740_item	2446481	et	3	main
tähendusest	doc_491521501740_item	2446482	et	4	main
tingitud	doc_491521501740_item	2446483	et	4	main
vead	doc_491521501740_item	2446484	et	4	main
415	doc_491521501740_item	2446485	et	2	main
infinitiivide	doc_491521501740_item	2446486	et	3	main
käändevormide	doc_491521501740_item	2446487	et	4	main
moodustamise	doc_491521501740_item	2446488	et	4	main
ja	doc_491521501740_item	2446489	et	3	main
kasutamise	doc_491521501740_item	2446490	et	4	main
416	doc_491521501740_item	2446492	et	2	main
verbid	doc_491521501740_item	2446493	et	3	main
mis	doc_491521501740_item	2446494	et	4	main
nõuavad	doc_491521501740_item	2446495	et	4	main
vead	doc_491521501740_item	2446491	et	4	main
kas	doc_491521501740_item	2446496	et	3	main
ma-	doc_491521501740_item	2446497	et	3	main
või	doc_491521501740_item	2446498	et	4	main
da-infinitiivi	doc_491521501740_item	2446499	et	4	main
ja	doc_491521501740_item	2446500	et	3	main
vead	doc_491521501740_item	2446501	et	4	main
verbide	doc_491521501740_item	2446502	et	3	main
püsiühenditega	doc_491521501740_item	2446503	et	3	main
42	doc_491521501740_item	2446504	et	2	main
sotsiolingvistilistest	doc_491521501740_item	2446505	et	4	main
faktoritest	doc_491521501740_item	2446506	et	4	main
5	doc_491521501740_item	2446509	et	2	main
näiteid	doc_491521501740_item	2446519	et	3	main
infinitiivi	doc_491521501740_item	2446520	et	4	main
uuritud	doc_491521501740_item	2446538	et	4	main
keeleteadlaste	doc_491521501740_item	2446540	et	3	main
ole	doc_491521501740_item	2446548	et	4	main
kõnes	doc_491521501740_item	2446562	et	3	main
see	doc_491521501740_item	2446563	et	3	main
on	doc_491521501740_item	2446564	et	4	main
et	doc_491521501740_item	2446567	et	3	main
da-infinitiiv	doc_491521501740_item	2446570	et	3	main
kui	doc_491521501740_item	2446573	et	3	main
või	doc_491521501740_item	2446575	et	4	main
teise	doc_491521501740_item	2446576	et	4	main
see	doc_491521501740_item	2446583	et	3	main
suure	doc_491521501740_item	2446589	et	3	main
olenemata	doc_491521501740_item	2446596	et	4	main
kasutatav	doc_491521501740_item	2446602	et	4	main
vahel	doc_491521501740_item	2446616	et	4	main
peale	doc_491521501740_item	2446617	et	4	main
kooliprogrammi	doc_491521501740_item	2446623	et	4	main
programmi	doc_491521501740_item	2446625	et	4	main
esmajärjekorras	doc_491521501740_item	2446631	et	4	main
samuti	doc_491521501740_item	2446634	et	3	main
analüüs	doc_491521501740_item	2446642	et	3	main
välja	doc_491521501740_item	2446645	et	4	main
strateegiaid	doc_491521501740_item	2446647	et	3	main
kuidas	doc_491521501740_item	2446648	et	3	main
ja	doc_491521501740_item	2446652	et	3	main
uurimisväärt	doc_491521501740_item	2446678	et	4	main
seetõttu	doc_491521501740_item	2446679	et	3	main
et	doc_491521501740_item	2446680	et	3	main
on	doc_491521501740_item	2446686	et	4	main
uurimist	doc_491521501740_item	2446704	et	4	main
kõrvutava	doc_491521501740_item	2446708	et	4	main
ülesandeks	doc_491521501740_item	2446710	et	4	main
õppijaid	doc_491521501740_item	2446717	et	4	main
mõistma	doc_491521501740_item	2446721	et	3	main
keeli	doc_491521501740_item	2446723	et	4	main
ning	doc_491521501740_item	2446734	et	3	main
eesti	doc_491521501740_item	2446743	et	4	main
kasvanud	doc_491521501740_item	2446750	et	4	main
kontrastiivse	doc_491521501740_item	2446754	et	4	main
venelased	doc_491521501740_item	2446766	et	3	main
jäävad	doc_491521501740_item	2446770	et	4	main
kõnelejad	doc_491521501740_item	2446774	et	4	main
kellele	doc_491521501740_item	2446775	et	4	main
õpetatakse	doc_491521501740_item	2446776	et	3	main
eesti	doc_491521501740_item	2446777	et	4	main
kõrgkoolis	doc_491521501740_item	2446780	et	4	main
valdkonnas	doc_491521501740_item	2446790	et	4	main
viieks	doc_491521501740_item	2446794	et	3	main
osaks	doc_491521501740_item	2446795	et	3	main
otstarbekas	doc_491521501740_item	2446821	et	4	main
ja	doc_491521501740_item	2446827	et	3	main
ka	doc_491521501740_item	2446837	et	3	main
sest	doc_491521501740_item	2446840	et	4	main
arvamus	doc_491521501740_item	2446846	et	3	main
äärmiselt	doc_491521501740_item	2446858	et	4	main
teises	doc_491521501740_item	2446864	et	4	main
käsitletakse	doc_491521501740_item	2446868	et	3	main
eesti	doc_491521501740_item	2446870	et	4	main
mõiste	doc_491521501740_item	2446882	et	4	main
tähendusi	doc_491521501740_item	2446887	et	4	main
ja	doc_491521501740_item	2446888	et	3	main
funktsioone	doc_491521501740_item	2446893	et	3	main
osas	doc_491521501740_item	2446895	et	4	main
teevad	doc_491521501740_item	2446899	et	3	main
da-infinitiivi	doc_491521501740_item	2446907	et	4	main
vigu	doc_491521501740_item	2446909	et	3	main
kahe	doc_491521501740_item	2446911	et	3	main
grammatika	doc_491521501740_item	2446913	et	4	main
ja	doc_491521501740_item	2446914	et	3	main
semantika	doc_491521501740_item	2446915	et	4	main
tegeldakse	doc_491521501740_item	2446920	et	3	main
veaanalüüsiga	doc_491521501740_item	2446921	et	4	main
kohta	doc_491521501740_item	2446929	et	4	main
ja	doc_491521501740_item	2446930	et	3	main
millega	doc_491521501740_item	2446933	et	3	main
kõige	doc_491521501740_item	2446934	et	4	main
da-infinitiivi	doc_491521501740_item	2446527	et	4	main
vead	doc_491521501740_item	2446528	et	4	main
interferentsist	doc_491521501740_item	2446531	et	3	main
vigade	doc_491521501740_item	2446533	et	3	main
interferentsi	doc_491521501740_item	2446535	et	4	main
nähtused	doc_491521501740_item	2446536	et	4	main
infinitiivi	doc_491521501740_item	2446543	et	4	main
ei	doc_491521501740_item	2446547	et	4	main
on	doc_491521501740_item	2446555	et	4	main
üks	doc_491521501740_item	2446556	et	3	main
kõige	doc_491521501740_item	2446557	et	4	main
sagedamini	doc_491521501740_item	2446558	et	4	main
esinevaid	doc_491521501740_item	2446559	et	4	main
vigu	doc_491521501740_item	2446560	et	3	main
venelaste	doc_491521501740_item	2446561	et	4	main
ma-	doc_491521501740_item	2446568	et	3	main
eesti	doc_491521501740_item	2446572	et	4	main
võõrkeele	doc_491521501740_item	2446574	et	4	main
nn	doc_491521501740_item	2446579	et	4	main
universaalsete	doc_491521501740_item	2446580	et	4	main
vigade	doc_491521501740_item	2446581	et	3	main
sekka	doc_491521501740_item	2446582	et	3	main
et	doc_491521501740_item	2446585	et	3	main
antud	doc_491521501740_item	2446592	et	4	main
2000	doc_491521501740_item	2446598	et	2	main
keele	doc_491521501740_item	2446604	et	4	main
k	doc_491521501740_item	2446607	et	4	main
ja	doc_491521501740_item	2446609	et	3	main
kirjutajal	doc_491521501740_item	2446610	et	4	main
tuleb	doc_491521501740_item	2446611	et	3	main
sageli	doc_491521501740_item	2446612	et	3	main
valida	doc_491521501740_item	2446613	et	3	main
kahe	doc_491521501740_item	2446614	et	3	main
infinitiivi	doc_491521501740_item	2446615	et	4	main
kuulub	doc_491521501740_item	2446619	et	3	main
uuritakse	doc_491521501740_item	2446633	et	3	main
selline	doc_491521501740_item	2446641	et	4	main
võrdlevad	doc_491521501740_item	2446684	et	4	main
ilmunud	doc_491521501740_item	2446687	et	4	main
väga	doc_491521501740_item	2446688	et	3	main
ammu	doc_491521501740_item	2446689	et	4	main
mölder	doc_491521501740_item	2446690	et	3	main
пялль	doc_491521501740_item	2446692	et	2	main
тукумцев	doc_491521501740_item	2446694	et	2	main
valdkond	doc_491521501740_item	2446699	et	3	main
põhjalikku	doc_491521501740_item	2446703	et	4	main
vene	doc_491521501740_item	2446707	et	4	main
grammatika	doc_491521501740_item	2446709	et	4	main
ja	doc_491521501740_item	2446714	et	3	main
eesti	doc_491521501740_item	2446715	et	4	main
keele	doc_491521501740_item	2446716	et	4	main
vene	doc_491521501740_item	2446732	et	4	main
vene	doc_491521501740_item	2446736	et	4	main
ei	doc_491521501740_item	2446751	et	4	main
analüüsi	doc_491521501740_item	2446755	et	4	main
vähenenud	doc_491521501740_item	2446757	et	4	main
suurem	doc_491521501740_item	2446759	et	4	main
etniline	doc_491521501740_item	2446760	et	3	main
eestlaste	doc_491521501740_item	2446764	et	4	main
on	doc_491521501740_item	2446765	et	4	main
põhiliseks	doc_491521501740_item	2446768	et	3	main
keelt	doc_491521501740_item	2446778	et	4	main
ja	doc_491521501740_item	2446781	et	3	main
vaja	doc_491521501740_item	2446785	et	4	main
mitmesuguseid	doc_491521501740_item	2446786	et	3	main
uurimusi	doc_491521501740_item	2446787	et	3	main
jagatud	doc_491521501740_item	2446793	et	4	main
esimeses	doc_491521501740_item	2446796	et	3	main
töös	doc_491521501740_item	2446632	et	3	main
eesti	doc_491521501740_item	2446635	et	4	main
kasutuses	doc_491521501740_item	2446637	et	4	main
tehtud	doc_491521501740_item	2446638	et	4	main
vigade	doc_491521501740_item	2446639	et	3	main
põhjusi	doc_491521501740_item	2446640	et	3	main
kirjas	doc_491521501740_item	2446653	et	4	main
osa	doc_491521501740_item	2446658	et	4	main
annab	doc_491521501740_item	2446659	et	3	main
põhilist	doc_491521501740_item	2446660	et	3	main
ülevaadet	doc_491521501740_item	2446661	et	3	main
vene	doc_491521501740_item	2446662	et	4	main
ja	doc_491521501740_item	2446663	et	3	main
eesti	doc_491521501740_item	2446664	et	4	main
infinitiividest	doc_491521501740_item	2446665	et	3	main
nii	doc_491521501740_item	2446666	et	3	main
kõrvutavalt	doc_491521501740_item	2446667	et	4	main
kui	doc_491521501740_item	2446668	et	3	main
üksteisest	doc_491521501740_item	2446670	et	4	main
kõrvutav	doc_491521501740_item	2446675	et	4	main
1967	doc_491521501740_item	2446691	et	2	main
тотсель	doc_491521501740_item	2446693	et	2	main
1962	doc_491521501740_item	2446695	et	2	main
ning	doc_491521501740_item	2446696	et	3	main
see	doc_491521501740_item	2446697	et	3	main
ja	doc_491521501740_item	2446702	et	3	main
eesti	doc_491521501740_item	2446705	et	4	main
on	doc_491521501740_item	2446711	et	4	main
abistada	doc_491521501740_item	2446712	et	3	main
mõlemaid	doc_491521501740_item	2446722	et	3	main
seega	doc_491521501740_item	2446724	et	4	main
eesti	doc_491521501740_item	2446729	et	4	main
keele	doc_491521501740_item	2446730	et	4	main
ka	doc_491521501740_item	2446735	et	3	main
keele	doc_491521501740_item	2446744	et	4	main
õppijate	doc_491521501740_item	2446745	et	4	main
arv	doc_491521501740_item	2446746	et	3	main
on	doc_491521501740_item	2446747	et	4	main
viimasel	doc_491521501740_item	2446748	et	3	main
eesti-vene	doc_491521501740_item	2446753	et	4	main
tähtsus	doc_491521501740_item	2446756	et	4	main
grupp	doc_491521501740_item	2446761	et	3	main
vene	doc_491521501740_item	2446772	et	4	main
keele	doc_491521501740_item	2446773	et	4	main
kursustel	doc_491521501740_item	2446782	et	3	main
oleks	doc_491521501740_item	2446784	et	3	main
on	doc_491521501740_item	2446792	et	4	main
sarnasustele	doc_491521501740_item	2446826	et	4	main
kaalutustel	doc_491521501740_item	2446839	et	4	main
paljude	doc_491521501740_item	2446841	et	3	main
mitte-eestlaste	doc_491521501740_item	2446842	et	4	main
hulgas	doc_491521501740_item	2446843	et	4	main
raske	doc_491521501740_item	2446859	et	4	main
ja	doc_491521501740_item	2446865	et	3	main
infinitiivide	doc_491521501740_item	2446886	et	3	main
ja	doc_491521501740_item	2446891	et	3	main
uuritakse	doc_491521501740_item	2446896	et	3	main
mida	doc_491521501740_item	2446898	et	4	main
venekeelsed	doc_491521501740_item	2446900	et	3	main
õppijad	doc_491521501740_item	2446903	et	4	main
ja	doc_491521501740_item	2446906	et	3	main
käesolevas	doc_491521501740_item	2446918	et	3	main
esinemissageduse	doc_491521501740_item	2446928	et	4	main
näidete	doc_491521501740_item	2446943	et	3	main
kokku	doc_491521501740_item	2446947	et	3	main
kõik	doc_491521501740_item	2446949	et	4	main
erinevad	doc_491521501740_item	2446957	et	4	main
valikus	doc_491521501740_item	2446973	et	3	main
ning	doc_491521501740_item	2446980	et	3	main
saada	doc_491521501740_item	2447011	et	4	main
kaasaegset	doc_491521501740_item	2446701	et	3	main
ja	doc_491521501740_item	2446706	et	3	main
sügavamalt	doc_491521501740_item	2446718	et	4	main
ja	doc_491521501740_item	2446719	et	3	main
teadlikumalt	doc_491521501740_item	2446720	et	4	main
on	doc_491521501740_item	2446727	et	4	main
kasuks	doc_491521501740_item	2446728	et	4	main
koolides	doc_491521501740_item	2446733	et	3	main
keele	doc_491521501740_item	2446737	et	4	main
ole	doc_491521501740_item	2446752	et	4	main
kõige	doc_491521501740_item	2446758	et	4	main
peale	doc_491521501740_item	2446763	et	4	main
ning	doc_491521501740_item	2446767	et	3	main
sihtrühmaks	doc_491521501740_item	2446769	et	3	main
ikka	doc_491521501740_item	2446771	et	4	main
kontrastiivse	doc_491521501740_item	2446788	et	4	main
grammatika	doc_491521501740_item	2446789	et	4	main
osas	doc_491521501740_item	2446797	et	4	main
on	doc_491521501740_item	2446798	et	4	main
vene	doc_491521501740_item	2446799	et	4	main
ja	doc_491521501740_item	2446800	et	3	main
eesti	doc_491521501740_item	2446801	et	4	main
infinitiivid	doc_491521501740_item	2446802	et	3	main
kirjeldatud	doc_491521501740_item	2446803	et	4	main
kõrvutavalt	doc_491521501740_item	2446804	et	4	main
välja	doc_491521501740_item	2446805	et	4	main
toodud	doc_491521501740_item	2446806	et	4	main
nende	doc_491521501740_item	2446807	et	4	main
sarnasusi	doc_491521501740_item	2446808	et	4	main
ja	doc_491521501740_item	2446809	et	3	main
erinevusi	doc_491521501740_item	2446810	et	4	main
kõrvutamine	doc_491521501740_item	2446811	et	4	main
on	doc_491521501740_item	2446812	et	4	main
tähtis	doc_491521501740_item	2446813	et	4	main
sellepärast	doc_491521501740_item	2446814	et	3	main
et	doc_491521501740_item	2446815	et	3	main
eesti	doc_491521501740_item	2446816	et	4	main
keele	doc_491521501740_item	2446817	et	4	main
õpetamisel	doc_491521501740_item	2446818	et	4	main
venelastele	doc_491521501740_item	2446819	et	4	main
oleks	doc_491521501740_item	2446820	et	3	main
juhtida	doc_491521501740_item	2446822	et	4	main
keele	doc_491521501740_item	2446825	et	4	main
kasulik	doc_491521501740_item	2446832	et	3	main
mitte	doc_491521501740_item	2446833	et	3	main
ainult	doc_491521501740_item	2446834	et	4	main
praktilistel	doc_491521501740_item	2446835	et	3	main
vaid	doc_491521501740_item	2446836	et	3	main
eesti	doc_491521501740_item	2446848	et	4	main
teistest	doc_491521501740_item	2446853	et	4	main
verschik	doc_491521501740_item	2446860	et	4	main
2004	doc_491521501740_item	2446861	et	2	main
140	doc_491521501740_item	2446862	et	2	main
kolmandas	doc_491521501740_item	2446866	et	3	main
vene	doc_491521501740_item	2446872	et	4	main
keele	doc_491521501740_item	2446873	et	4	main
infinitiive	doc_491521501740_item	2446874	et	3	main
infinitiivi	doc_491521501740_item	2446881	et	4	main
kirjeldatakse	doc_491521501740_item	2446884	et	3	main
kasutusreegleid	doc_491521501740_item	2446889	et	3	main
süntaktilisi	doc_491521501740_item	2446892	et	3	main
neljandas	doc_491521501740_item	2446894	et	3	main
koolis	doc_491521501740_item	2446779	et	4	main
selletõttu	doc_491521501740_item	2446783	et	4	main
töö	doc_491521501740_item	2446791	et	4	main
erinevustele	doc_491521501740_item	2446828	et	4	main
see	doc_491521501740_item	2446829	et	3	main
levinud	doc_491521501740_item	2446845	et	4	main
et	doc_491521501740_item	2446847	et	3	main
osas	doc_491521501740_item	2446867	et	4	main
põhjalikult	doc_491521501740_item	2446869	et	4	main
ja	doc_491521501740_item	2446871	et	3	main
käändelisi	doc_491521501740_item	2446878	et	4	main
vorme	doc_491521501740_item	2446879	et	3	main
antakse	doc_491521501740_item	2446880	et	3	main
seletus	doc_491521501740_item	2446883	et	4	main
detailselt	doc_491521501740_item	2446885	et	4	main
grammatilisi	doc_491521501740_item	2446890	et	3	main
eesti	doc_491521501740_item	2446901	et	4	main
erinevustest	doc_491521501740_item	2446916	et	4	main
lähtudes	doc_491521501740_item	2446917	et	3	main
tähelepanu	doc_491521501740_item	2446823	et	4	main
kahe	doc_491521501740_item	2446824	et	3	main
ei	doc_491521501740_item	2446830	et	4	main
ole	doc_491521501740_item	2446831	et	4	main
psühholoogilistel	doc_491521501740_item	2446838	et	4	main
on	doc_491521501740_item	2446844	et	4	main
keele	doc_491521501740_item	2446849	et	4	main
erineb	doc_491521501740_item	2446850	et	3	main
maksimaalselt	doc_491521501740_item	2446851	et	4	main
kõigist	doc_491521501740_item	2446852	et	4	main
keeltest	doc_491521501740_item	2446854	et	4	main
ja	doc_491521501740_item	2446855	et	3	main
on	doc_491521501740_item	2446856	et	4	main
seetõttu	doc_491521501740_item	2446857	et	3	main
töö	doc_491521501740_item	2446863	et	4	main
eraldi	doc_491521501740_item	2446875	et	4	main
ning	doc_491521501740_item	2446876	et	3	main
nende	doc_491521501740_item	2446877	et	4	main
eesti	doc_491521501740_item	2446904	et	4	main
ma-	doc_491521501740_item	2446905	et	3	main
vaadeldakse	doc_491521501740_item	2446910	et	3	main
keele	doc_491521501740_item	2446912	et	4	main
töös	doc_491521501740_item	2446919	et	3	main
vigade	doc_491521501740_item	2446927	et	3	main
kogutud	doc_491521501740_item	2446942	et	4	main
keeleõppijate	doc_491521501740_item	2446954	et	3	main
olid	doc_491521501740_item	2446956	et	4	main
algtasemest	doc_491521501740_item	2446958	et	3	main
kõrgtasemeni	doc_491521501740_item	2446960	et	3	main
välja	doc_491521501740_item	2446961	et	4	main
teadmisi	doc_491521501740_item	2446968	et	4	main
teatud	doc_491521501740_item	2446969	et	4	main
sealhulgas	doc_491521501740_item	2446971	et	3	main
keeleoskust	doc_491521501740_item	2446975	et	3	main
kindlal	doc_491521501740_item	2446978	et	3	main
pedagoogikaülikooli	doc_491521501740_item	2447014	et	4	main
välja	doc_491521501740_item	2447016	et	4	main
antud	doc_491521501740_item	2447017	et	4	main
keelehärm	doc_491521501740_item	2447018	et	3	main
eesti	doc_491521501740_item	2447019	et	4	main
pärineb	doc_491521501740_item	2447025	et	3	main
ja	doc_491521501740_item	2447027	et	3	main
vigade	doc_491521501740_item	2447062	et	3	main
peab	doc_491521501740_item	2447069	et	4	main
aitama	doc_491521501740_item	2447070	et	3	main
samuti	doc_491521501740_item	2447078	et	3	main
õrvutavalt	doc_491521501740_item	2447089	et	4	main
eesti	doc_491521501740_item	2447092	et	4	main
nii	doc_491521501740_item	2447103	et	3	main
mõlemas	doc_491521501740_item	2447104	et	3	main
kui	doc_491521501740_item	2447119	et	3	main
ega	doc_491521501740_item	2447139	et	3	main
suhtumist	doc_491521501740_item	2447142	et	4	main
infinitiivi	doc_491521501740_item	2447144	et	4	main
muid	doc_491521501740_item	2447156	et	4	main
täpsemaid	doc_491521501740_item	2447157	et	4	main
grammatilisi	doc_491521501740_item	2447158	et	3	main
või	doc_491521501740_item	2447160	et	4	main
teine	doc_491521501740_item	2447166	et	3	main
infinitiivi	doc_491521501740_item	2447175	et	4	main
ühiseid	doc_491521501740_item	2447206	et	3	main
funktsioone	doc_491521501740_item	2447210	et	3	main
1	doc_491521501740_item	2447216	et	2	main
ma-infinitiiv	doc_491521501740_item	2447217	et	3	main
vene	doc_491521501740_item	2447220	et	4	main
alustamist	doc_491521501740_item	2447228	et	4	main
jäi	doc_491521501740_item	2447241	et	3	main
комнате	doc_491521501740_item	2447247	et	2	main
2	doc_491521501740_item	2447249	et	2	main
ja	doc_491521501740_item	2447251	et	3	main
vene	doc_491521501740_item	2447253	et	4	main
tähistavad	doc_491521501740_item	2447255	et	4	main
või	doc_491521501740_item	2447263	et	4	main
see	doc_491521501740_item	2447267	et	3	main
этот	doc_491521501740_item	2447273	et	2	main
учиться	doc_491521501740_item	2447277	et	2	main
3	doc_491521501740_item	2447286	et	2	main
tegevust	doc_491521501740_item	2447293	et	4	main
книгу	doc_491521501740_item	2447324	et	2	main
objektilise	doc_491521501740_item	2447336	et	4	main
või	doc_491521501740_item	2447341	et	4	main
tegevust	doc_491521501740_item	2447343	et	4	main
lubas	doc_491521501740_item	2447357	et	3	main
мама	doc_491521501740_item	2447360	et	2	main
поиграть	doc_491521501740_item	2447363	et	2	main
oskame	doc_491521501740_item	2447365	et	3	main
петь	doc_491521501740_item	2447369	et	2	main
subjektina	doc_491521501740_item	2447374	et	3	main
seejuures	doc_491521501740_item	2447376	et	3	main
учиться	doc_491521501740_item	2447383	et	2	main
vigu	doc_491521501740_item	2446897	et	3	main
keele	doc_491521501740_item	2446902	et	4	main
valikul	doc_491521501740_item	2446908	et	3	main
viiendas	doc_491521501740_item	2446922	et	3	main
on	doc_491521501740_item	2446924	et	4	main
märgitud	doc_491521501740_item	2446931	et	4	main
tegusõnad	doc_491521501740_item	2446932	et	3	main
tehtud	doc_491521501740_item	2446939	et	4	main
autori	doc_491521501740_item	2446940	et	3	main
poolt	doc_491521501740_item	2446941	et	4	main
81	doc_491521501740_item	2446948	et	2	main
need	doc_491521501740_item	2446950	et	3	main
pärinevad	doc_491521501740_item	2446951	et	4	main
keeletasemed	doc_491521501740_item	2446955	et	3	main
alatest	doc_491521501740_item	2446959	et	3	main
kontrollida	doc_491521501740_item	2446966	et	4	main
keelevaldkondades	doc_491521501740_item	2446970	et	3	main
kirjandid	doc_491521501740_item	2446977	et	3	main
on	doc_491521501740_item	2447012	et	4	main
keele	doc_491521501740_item	2447020	et	4	main
probleemseid	doc_491521501740_item	2447021	et	3	main
materjal	doc_491521501740_item	2447024	et	3	main
tpü	doc_491521501740_item	2447026	et	4	main
arvulisi	doc_491521501740_item	2447034	et	4	main
andmeid	doc_491521501740_item	2447035	et	3	main
eksitatakse	doc_491521501740_item	2447040	et	3	main
sagedamini	doc_491521501740_item	2447042	et	4	main
eesti	doc_491521501740_item	2447046	et	4	main
infinitiivi	doc_491521501740_item	2447061	et	4	main
venekeelsete	doc_491521501740_item	2447075	et	4	main
teha	doc_491521501740_item	2447083	et	3	main
keeleõppinguid	doc_491521501740_item	2447084	et	4	main
vene	doc_491521501740_item	2447090	et	4	main
verb	doc_491521501740_item	2447094	et	3	main
eesti	doc_491521501740_item	2447096	et	4	main
vene	doc_491521501740_item	2447098	et	4	main
keeles	doc_491521501740_item	2447099	et	4	main
ühtseid	doc_491521501740_item	2447100	et	3	main
grammatilisi	doc_491521501740_item	2447101	et	3	main
kategooriaid	doc_491521501740_item	2447102	et	3	main
tähendust	doc_491521501740_item	2447115	et	4	main
vene	doc_491521501740_item	2447121	et	4	main
infinitiivi	doc_491521501740_item	2447123	et	4	main
tunnuseks	doc_491521501740_item	2447124	et	3	main
on	doc_491521501740_item	2447125	et	4	main
see	doc_491521501740_item	2447126	et	3	main
kohta	doc_491521501740_item	2447138	et	4	main
ei	doc_491521501740_item	2447153	et	4	main
edasta	doc_491521501740_item	2447154	et	4	main
mingeid	doc_491521501740_item	2447155	et	3	main
infinitiividel	doc_491521501740_item	2447201	et	3	main
mõlemas	doc_491521501740_item	2447203	et	3	main
infinitiivide	doc_491521501740_item	2447212	et	3	main
infinitiiv	doc_491521501740_item	2447219	et	3	main
keeles	doc_491521501740_item	2447221	et	4	main
liikumist	doc_491521501740_item	2447226	et	4	main
tuppa	doc_491521501740_item	2447242	et	3	main
брат	doc_491521501740_item	2447244	et	2	main
кушать	doc_491521501740_item	2447248	et	2	main
infinitiiv	doc_491521501740_item	2447252	et	3	main
võimeline	doc_491521501740_item	2447270	et	4	main
õppima	doc_491521501740_item	2447272	et	3	main
способен	doc_491521501740_item	2447275	et	2	main
kõlbab	doc_491521501740_item	2447279	et	3	main
годится	doc_491521501740_item	2447284	et	2	main
ja	doc_491521501740_item	2447288	et	3	main
või	doc_491521501740_item	2447294	et	4	main
эту	doc_491521501740_item	2447323	et	2	main
идите	doc_491521501740_item	2447327	et	2	main
da-infinitiiv	doc_491521501740_item	2447330	et	3	main
soovitavat	doc_491521501740_item	2447338	et	4	main
või	doc_491521501740_item	2447344	et	4	main
olemist	doc_491521501740_item	2447346	et	4	main
мы	doc_491521501740_item	2447367	et	2	main
mõlemad	doc_491521501740_item	2447371	et	3	main
esinevad	doc_491521501740_item	2447373	et	4	main
olles	doc_491521501740_item	2447375	et	3	main
1967	doc_491521501740_item	2447391	et	2	main
et	doc_491521501740_item	2447403	et	3	main
nende	doc_491521501740_item	2447414	et	4	main
üks	doc_491521501740_item	2447419	et	3	main
osas	doc_491521501740_item	2446923	et	4	main
esitatud	doc_491521501740_item	2446925	et	4	main
analüüs	doc_491521501740_item	2446926	et	3	main
sagedamini	doc_491521501740_item	2446935	et	4	main
eksitakse	doc_491521501740_item	2446936	et	4	main
analüüs	doc_491521501740_item	2446937	et	3	main
on	doc_491521501740_item	2446938	et	4	main
näidet	doc_491521501740_item	2446945	et	3	main
on	doc_491521501740_item	2446946	et	4	main
töödest	doc_491521501740_item	2446953	et	3	main
õpilaste	doc_491521501740_item	2446967	et	4	main
üldse	doc_491521501740_item	2446976	et	3	main
teemal	doc_491521501740_item	2446979	et	3	main
läbivaadatud	doc_491521501740_item	2446981	et	4	main
filmi	doc_491521501740_item	2446982	et	4	main
põhjal	doc_491521501740_item	2446983	et	4	main
tehtud	doc_491521501740_item	2446984	et	4	main
retsensioonid	doc_491521501740_item	2446985	et	3	main
tänapäeva	doc_491521501740_item	2446986	et	4	main
keeleteaduses	doc_491521501740_item	2446987	et	3	main
peaaegu	doc_491521501740_item	2446988	et	3	main
puuduvad	doc_491521501740_item	2446989	et	4	main
andmed	doc_491521501740_item	2446990	et	3	main
eesti	doc_491521501740_item	2446991	et	4	main
keele	doc_491521501740_item	2446992	et	4	main
peamistest	doc_491521501740_item	2446993	et	4	main
veaohtlikest	doc_491521501740_item	2446994	et	4	main
piirkondadest	doc_491521501740_item	2446995	et	3	main
ja	doc_491521501740_item	2446996	et	3	main
keelenditest	doc_491521501740_item	2446997	et	3	main
samuti	doc_491521501740_item	2446998	et	3	main
analüüsi	doc_491521501740_item	2446999	et	4	main
eesti	doc_491521501740_item	2447000	et	4	main
keele	doc_491521501740_item	2447001	et	4	main
õppijate	doc_491521501740_item	2447002	et	4	main
tüüpilistest	doc_491521501740_item	2447003	et	3	main
vigadest	doc_491521501740_item	2447004	et	3	main
üks	doc_491521501740_item	2447005	et	3	main
allikatest	doc_491521501740_item	2447006	et	4	main
kust	doc_491521501740_item	2447007	et	4	main
saab	doc_491521501740_item	2447008	et	3	main
alusel	doc_491521501740_item	2446944	et	4	main
kirjalikest	doc_491521501740_item	2446952	et	3	main
uuritud	doc_491521501740_item	2446962	et	4	main
tööde	doc_491521501740_item	2446963	et	3	main
eesmärgiks	doc_491521501740_item	2446964	et	3	main
on	doc_491521501740_item	2446965	et	4	main
infinitiivi	doc_491521501740_item	2446972	et	4	main
ning	doc_491521501740_item	2446974	et	3	main
sellist	doc_491521501740_item	2447009	et	4	main
informatsiooni	doc_491521501740_item	2447010	et	4	main
töödest	doc_491521501740_item	2447030	et	3	main
käesolev	doc_491521501740_item	2447031	et	3	main
mille	doc_491521501740_item	2447038	et	3	main
kõrvutavat	doc_491521501740_item	2447044	et	4	main
vene	doc_491521501740_item	2447048	et	4	main
esinemise	doc_491521501740_item	2447064	et	4	main
õppijate	doc_491521501740_item	2447076	et	4	main
ja	doc_491521501740_item	2447091	et	3	main
omab	doc_491521501740_item	2447095	et	3	main
keeles	doc_491521501740_item	2447105	et	4	main
verbikategoriaalset	doc_491521501740_item	2447114	et	4	main
kõneleja	doc_491521501740_item	2447141	et	4	main
aktisse	doc_491521501740_item	2447143	et	3	main
ei	doc_491521501740_item	2447146	et	4	main
viida	doc_491521501740_item	2447147	et	4	main
soole	doc_491521501740_item	2447149	et	4	main
ja	doc_491521501740_item	2447152	et	3	main
njuansse	doc_491521501740_item	2447162	et	4	main
käib	doc_491521501740_item	2447165	et	3	main
mis	doc_491521501740_item	2447168	et	4	main
väljendab	doc_491521501740_item	2447169	et	3	main
kõike	doc_491521501740_item	2447170	et	4	main
vajalikke	doc_491521501740_item	2447171	et	3	main
tunnuseid	doc_491521501740_item	2447172	et	3	main
mõnikord	doc_491521501740_item	2447173	et	3	main
võivad	doc_491521501740_item	2447174	et	4	main
on	doc_491521501740_item	2447202	et	4	main
alustame	doc_491521501740_item	2447211	et	3	main
kõrvutamist	doc_491521501740_item	2447213	et	4	main
joontest	doc_491521501740_item	2447215	et	3	main
ja	doc_491521501740_item	2447218	et	3	main
väljendavad	doc_491521501740_item	2447225	et	4	main
jätkamist	doc_491521501740_item	2447230	et	4	main
остался	doc_491521501740_item	2447245	et	2	main
või	doc_491521501740_item	2447257	et	4	main
olukorras	doc_491521501740_item	2447258	et	3	main
olemist	doc_491521501740_item	2447259	et	4	main
nt	doc_491521501740_item	2447266	et	4	main
valvama	doc_491521501740_item	2447281	et	3	main
охранять	doc_491521501740_item	2447285	et	2	main
vene	doc_491521501740_item	2447290	et	4	main
olukorras	doc_491521501740_item	2447295	et	3	main
olemist	doc_491521501740_item	2447296	et	4	main
tallinna	doc_491521501740_item	2447013	et	4	main
poolt	doc_491521501740_item	2447015	et	4	main
mille	doc_491521501740_item	2447023	et	3	main
kohta	doc_491521501740_item	2447037	et	4	main
kasutuses	doc_491521501740_item	2447039	et	4	main
kõige	doc_491521501740_item	2447041	et	4	main
ning	doc_491521501740_item	2447043	et	3	main
infinitiividest	doc_491521501740_item	2447049	et	3	main
töö	doc_491521501740_item	2447053	et	4	main
eesti	doc_491521501740_item	2447071	et	4	main
keele	doc_491521501740_item	2447072	et	4	main
õpikute	doc_491521501740_item	2447073	et	3	main
tõhusamateks	doc_491521501740_item	2447085	et	4	main
ja	doc_491521501740_item	2447086	et	3	main
tulemusrikkamateks	doc_491521501740_item	2447087	et	4	main
k	doc_491521501740_item	2447088	et	4	main
ja	doc_491521501740_item	2447097	et	3	main
esineb	doc_491521501740_item	2447106	et	3	main
infinitiivvormid	doc_491521501740_item	2447108	et	4	main
saa	doc_491521501740_item	2447110	et	4	main
lauses	doc_491521501740_item	2447111	et	3	main
iseseisvalt	doc_491521501740_item	2447112	et	4	main
mingit	doc_491521501740_item	2447113	et	3	main
ka	doc_491521501740_item	2447120	et	3	main
keele	doc_491521501740_item	2447122	et	4	main
mingit	doc_491521501740_item	2447132	et	3	main
infot	doc_491521501740_item	2447133	et	3	main
lõpp	doc_491521501740_item	2447145	et	3	main
arvule	doc_491521501740_item	2447151	et	3	main
infinitiiviga	doc_491521501740_item	2447163	et	3	main
koos	doc_491521501740_item	2447164	et	4	main
verb	doc_491521501740_item	2447167	et	3	main
õpitud	doc_491521501740_item	2447198	et	4	main
keeles	doc_491521501740_item	2447204	et	4	main
ka	doc_491521501740_item	2447208	et	3	main
predikaatverbidega	doc_491521501740_item	2447223	et	4	main
mis	doc_491521501740_item	2447224	et	4	main
tegevuse	doc_491521501740_item	2447227	et	4	main
või	doc_491521501740_item	2447229	et	4	main
nt	doc_491521501740_item	2447231	et	4	main
hakkasime	doc_491521501740_item	2447233	et	3	main
в	doc_491521501740_item	2447246	et	2	main
keeles	doc_491521501740_item	2447254	et	4	main
tegevust	doc_491521501740_item	2447256	et	4	main
kellelegi	doc_491521501740_item	2447262	et	4	main
omane	doc_491521501740_item	2447265	et	3	main
on	doc_491521501740_item	2447269	et	4	main
hästi	doc_491521501740_item	2447271	et	3	main
студент	doc_491521501740_item	2447274	et	2	main
хорошо	doc_491521501740_item	2447276	et	2	main
koer	doc_491521501740_item	2447278	et	3	main
собака	doc_491521501740_item	2447282	et	2	main
ma-infinitiiv	doc_491521501740_item	2447287	et	3	main
должен	doc_491521501740_item	2447321	et	2	main
tulge	doc_491521501740_item	2447325	et	3	main
кушать	doc_491521501740_item	2447328	et	2	main
tähendusega	doc_491521501740_item	2447337	et	4	main
võimalikku	doc_491521501740_item	2447342	et	4	main
увидеть	doc_491521501740_item	2447355	et	2	main
позволила	doc_491521501740_item	2447361	et	2	main
me	doc_491521501740_item	2447364	et	4	main
умеем	doc_491521501740_item	2447368	et	2	main
on	doc_491521501740_item	2447381	et	4	main
kasulik	doc_491521501740_item	2447382	et	3	main
vajalik	doc_491521501740_item	2447387	et	3	main
on	doc_491521501740_item	2447401	et	4	main
форма	doc_491521501740_item	2447421	et	2	main
vorm	doc_491521501740_item	2447440	et	3	main
prefiksi	doc_491521501740_item	2447442	et	3	main
abil	doc_491521501740_item	2447445	et	4	main
hakkas	doc_491521501740_item	2447448	et	3	main
nutma	doc_491521501740_item	2447449	et	3	main
uinus	doc_491521501740_item	2447453	et	3	main
мальчик	doc_491521501740_item	2447460	et	2	main
по-prefiksilisel	doc_491521501740_item	2447464	et	2	main
tähendus	doc_491521501740_item	2447468	et	4	main
ka	doc_491521501740_item	2447470	et	3	main
peamiselt	doc_491521501740_item	2447478	et	4	main
on	doc_491521501740_item	2447521	et	4	main
студент	doc_491521501740_item	2447525	et	2	main
piirkondi	doc_491521501740_item	2447022	et	4	main
tü	doc_491521501740_item	2447028	et	4	main
õliõpilaste	doc_491521501740_item	2447029	et	4	main
töö	doc_491521501740_item	2447032	et	4	main
sisaldab	doc_491521501740_item	2447033	et	3	main
verbide	doc_491521501740_item	2447036	et	3	main
ülevaadet	doc_491521501740_item	2447045	et	3	main
ja	doc_491521501740_item	2447047	et	3	main
saab	doc_491521501740_item	2447051	et	3	main
seega	doc_491521501740_item	2447050	et	4	main
see	doc_491521501740_item	2447052	et	3	main
olla	doc_491521501740_item	2447054	et	3	main
vajalik	doc_491521501740_item	2447055	et	3	main
nii	doc_491521501740_item	2447056	et	3	main
keeleõppijatele	doc_491521501740_item	2447057	et	3	main
kui	doc_491521501740_item	2447058	et	3	main
ka	doc_491521501740_item	2447059	et	3	main
õpetajatele	doc_491521501740_item	2447060	et	4	main
põhjuste	doc_491521501740_item	2447063	et	3	main
sageduse	doc_491521501740_item	2447065	et	4	main
ja	doc_491521501740_item	2447066	et	3	main
seaduspärasuste	doc_491521501740_item	2447067	et	4	main
väljaselgitamine	doc_491521501740_item	2447068	et	3	main
koostama	doc_491521501740_item	2447074	et	3	main
jaoks	doc_491521501740_item	2447077	et	4	main
välja	doc_491521501740_item	2447079	et	4	main
töötama	doc_491521501740_item	2447080	et	3	main
metoodeid	doc_491521501740_item	2447081	et	4	main
kuidas	doc_491521501740_item	2447082	et	3	main
infinitiividest	doc_491521501740_item	2447093	et	3	main
infinitiiv	doc_491521501740_item	2447107	et	3	main
ei	doc_491521501740_item	2447109	et	4	main
väljendada	doc_491521501740_item	2447116	et	3	main
nii	doc_491521501740_item	2447117	et	3	main
eesti	doc_491521501740_item	2447118	et	4	main
et	doc_491521501740_item	2447127	et	3	main
see	doc_491521501740_item	2447128	et	3	main
vorm	doc_491521501740_item	2447129	et	3	main
ei	doc_491521501740_item	2447130	et	4	main
kanna	doc_491521501740_item	2447131	et	4	main
tegevuse	doc_491521501740_item	2447134	et	4	main
aja	doc_491521501740_item	2447135	et	4	main
ja	doc_491521501740_item	2447136	et	3	main
tingimuste	doc_491521501740_item	2447137	et	3	main
väljenda	doc_491521501740_item	2447140	et	4	main
tegija	doc_491521501740_item	2447148	et	4	main
ega	doc_491521501740_item	2447150	et	3	main
tähendusi	doc_491521501740_item	2447159	et	4	main
tähenduslikke	doc_491521501740_item	2447161	et	3	main
vormid	doc_491521501740_item	2447176	et	4	main
sisaldada	doc_491521501740_item	2447177	et	3	main
aja	doc_491521501740_item	2447178	et	4	main
või	doc_491521501740_item	2447179	et	4	main
tegumoe	doc_491521501740_item	2447180	et	3	main
tunnust	doc_491521501740_item	2447181	et	3	main
kuid	doc_491521501740_item	2447182	et	4	main
peavad	doc_491521501740_item	2447183	et	4	main
sel	doc_491521501740_item	2447184	et	3	main
juhul	doc_491521501740_item	2447185	et	3	main
lauses	doc_491521501740_item	2447186	et	3	main
esinema	doc_491521501740_item	2447187	et	3	main
kas	doc_491521501740_item	2447188	et	3	main
verbifraasi	doc_491521501740_item	2447189	et	4	main
komponendina	doc_491521501740_item	2447190	et	3	main
pidavat	doc_491521501740_item	2447191	et	4	main
õpitama	doc_491521501740_item	2447192	et	3	main
või	doc_491521501740_item	2447193	et	4	main
finiitse	doc_491521501740_item	2447194	et	3	main
liitvormi	doc_491521501740_item	2447195	et	4	main
komponendina	doc_491521501740_item	2447196	et	3	main
on	doc_491521501740_item	2447197	et	4	main
ei	doc_491521501740_item	2447199	et	4	main
õpitud	doc_491521501740_item	2447200	et	4	main
nii	doc_491521501740_item	2447205	et	3	main
kui	doc_491521501740_item	2447207	et	3	main
erinevaid	doc_491521501740_item	2447209	et	4	main
ühistest	doc_491521501740_item	2447214	et	4	main
seostuvad	doc_491521501740_item	2447222	et	4	main
me	doc_491521501740_item	2447232	et	4	main
teed	doc_491521501740_item	2447234	et	4	main
jooma	doc_491521501740_item	2447235	et	4	main
мы	doc_491521501740_item	2447236	et	2	main
начали	doc_491521501740_item	2447237	et	2	main
пить	doc_491521501740_item	2447238	et	2	main
чай	doc_491521501740_item	2447239	et	2	main
vend	doc_491521501740_item	2447240	et	3	main
sööma	doc_491521501740_item	2447243	et	4	main
ma-infinitiiv	doc_491521501740_item	2447250	et	3	main
mis	doc_491521501740_item	2447260	et	4	main
on	doc_491521501740_item	2447261	et	4	main
millelegi	doc_491521501740_item	2447264	et	4	main
üliõpilane	doc_491521501740_item	2447268	et	3	main
juba	doc_491521501740_item	2447280	et	3	main
уже	doc_491521501740_item	2447283	et	2	main
infinitiiv	doc_491521501740_item	2447289	et	3	main
keeles	doc_491521501740_item	2447291	et	4	main
tähistavad	doc_491521501740_item	2447292	et	4	main
milleks	doc_491521501740_item	2447297	et	4	main
keegi	doc_491521501740_item	2447298	et	4	main
või	doc_491521501740_item	2447299	et	4	main
miski	doc_491521501740_item	2447300	et	4	main
on	doc_491521501740_item	2447301	et	4	main
sunnitud	doc_491521501740_item	2447303	et	4	main
kohustatud	doc_491521501740_item	2447302	et	4	main
või	doc_491521501740_item	2447304	et	4	main
palutud	doc_491521501740_item	2447305	et	4	main
predikaatverbina	doc_491521501740_item	2447306	et	4	main
esinevad	doc_491521501740_item	2447307	et	4	main
pidama	doc_491521501740_item	2447308	et	4	main
sundima	doc_491521501740_item	2447309	et	4	main
paluma	doc_491521501740_item	2447310	et	3	main
kutsuma	doc_491521501740_item	2447311	et	3	main
meelitama	doc_491521501740_item	2447312	et	3	main
nt	doc_491521501740_item	2447313	et	4	main
sa	doc_491521501740_item	2447314	et	3	main
pead	doc_491521501740_item	2447315	et	4	main
selle	doc_491521501740_item	2447316	et	4	main
raamatu	doc_491521501740_item	2447317	et	4	main
läbi	doc_491521501740_item	2447318	et	4	main
lugema	doc_491521501740_item	2447319	et	4	main
ты	doc_491521501740_item	2447320	et	2	main
прочесть	doc_491521501740_item	2447322	et	2	main
sööma	doc_491521501740_item	2447326	et	4	main
4	doc_491521501740_item	2447329	et	2	main
ja	doc_491521501740_item	2447331	et	3	main
infinitiiv	doc_491521501740_item	2447332	et	3	main
keeles	doc_491521501740_item	2447334	et	4	main
tähistavad	doc_491521501740_item	2447335	et	4	main
ema	doc_491521501740_item	2447356	et	4	main
mängida	doc_491521501740_item	2447359	et	3	main
laulda	doc_491521501740_item	2447366	et	4	main
5	doc_491521501740_item	2447370	et	2	main
tähenduses	doc_491521501740_item	2447378	et	4	main
nt	doc_491521501740_item	2447379	et	4	main
vene	doc_491521501740_item	2447333	et	4	main
lubatavat	doc_491521501740_item	2447339	et	4	main
vajatavad	doc_491521501740_item	2447340	et	4	main
olukorras	doc_491521501740_item	2447345	et	3	main
nt	doc_491521501740_item	2447347	et	4	main
me	doc_491521501740_item	2447348	et	4	main
soovime	doc_491521501740_item	2447349	et	4	main
seda	doc_491521501740_item	2447350	et	3	main
näha	doc_491521501740_item	2447351	et	3	main
мы	doc_491521501740_item	2447352	et	2	main
желаем	doc_491521501740_item	2447353	et	2	main
это	doc_491521501740_item	2447354	et	2	main
meil	doc_491521501740_item	2447358	et	4	main
нам	doc_491521501740_item	2447362	et	2	main
infinitiivid	doc_491521501740_item	2447372	et	3	main
teonime	doc_491521501740_item	2447377	et	4	main
полезно	doc_491521501740_item	2447384	et	2	main
mölder	doc_491521501740_item	2447390	et	3	main
erinevad	doc_491521501740_item	2447394	et	4	main
on	doc_491521501740_item	2447396	et	4	main
peamiseks	doc_491521501740_item	2447399	et	3	main
aga	doc_491521501740_item	2447418	et	3	main
käändevormide	doc_491521501740_item	2447425	et	4	main
mõisteid	doc_491521501740_item	2447426	et	3	main
leksikaalselt	doc_491521501740_item	2447428	et	4	main
on	doc_491521501740_item	2447431	et	4	main
pöördeline	doc_491521501740_item	2447439	et	4	main
moodustatud	doc_491521501740_item	2447441	et	4	main
за	doc_491521501740_item	2447443	et	2	main
он	doc_491521501740_item	2447455	et	2	main
pistis	doc_491521501740_item	2447458	et	4	main
побежал	doc_491521501740_item	2447461	et	2	main
за-	doc_491521501740_item	2447463	et	2	main
on	doc_491521501740_item	2447466	et	4	main
teine	doc_491521501740_item	2447467	et	3	main
esineb	doc_491521501740_item	2447469	et	3	main
vene	doc_491521501740_item	2447471	et	4	main
infinitiiv	doc_491521501740_item	2447473	et	3	main
predikaatverbina	doc_491521501740_item	2447477	et	4	main
adverbiga	doc_491521501740_item	2447542	et	3	main
sellele	doc_491521501740_item	2447550	et	4	main
infinitiivile	doc_491521501740_item	2447551	et	3	main
verbi	doc_491521501740_item	2447552	et	4	main
finiitne	doc_491521501740_item	2447553	et	3	main
будешь	doc_491521501740_item	2447564	et	2	main
keeles	doc_491521501740_item	2447575	et	4	main
tegemist	doc_491521501740_item	2447582	et	4	main
õppida	doc_491521501740_item	2447380	et	3	main
lugeda	doc_491521501740_item	2447385	et	3	main
читать	doc_491521501740_item	2447388	et	2	main
95-96	doc_491521501740_item	2447392	et	2	main
järgmised	doc_491521501740_item	2447397	et	3	main
erinevuseks	doc_491521501740_item	2447400	et	4	main
keeles	doc_491521501740_item	2447405	et	4	main
kaks	doc_491521501740_item	2447408	et	3	main
infinitiivi	doc_491521501740_item	2447409	et	4	main
ma-	doc_491521501740_item	2447410	et	3	main
ja	doc_491521501740_item	2447411	et	3	main
da-infinitiiv	doc_491521501740_item	2447412	et	3	main
ja	doc_491521501740_item	2447413	et	3	main
käändevormid	doc_491521501740_item	2447415	et	4	main
vene	doc_491521501740_item	2447416	et	4	main
keeles	doc_491521501740_item	2447417	et	4	main
ning	doc_491521501740_item	2447422	et	3	main
on	doc_491521501740_item	2447386	et	4	main
необходимо	doc_491521501740_item	2447389	et	2	main
infinitiivide	doc_491521501740_item	2447393	et	3	main
funktsioonid	doc_491521501740_item	2447395	et	3	main
1	doc_491521501740_item	2447398	et	2	main
see	doc_491521501740_item	2447402	et	3	main
eesti	doc_491521501740_item	2447404	et	4	main
on	doc_491521501740_item	2447406	et	4	main
verbil	doc_491521501740_item	2447407	et	3	main
неопределенная	doc_491521501740_item	2447420	et	2	main
infinitiivi	doc_491521501740_item	2447423	et	4	main
ma-infinitiiv	doc_491521501740_item	2447430	et	3	main
osaks	doc_491521501740_item	2447433	et	3	main
on	doc_491521501740_item	2447436	et	4	main
vasteks	doc_491521501740_item	2447437	et	3	main
predikaatverbi	doc_491521501740_item	2447438	et	4	main
nt	doc_491521501740_item	2447446	et	4	main
laps	doc_491521501740_item	2447447	et	4	main
ребенок	doc_491521501740_item	2447450	et	2	main
poiss	doc_491521501740_item	2447457	et	3	main
jooksma	doc_491521501740_item	2447459	et	3	main
verbil	doc_491521501740_item	2447465	et	3	main
keeles	doc_491521501740_item	2447475	et	4	main
vormi	doc_491521501740_item	2447546	et	4	main
vorm	doc_491521501740_item	2447554	et	3	main
буду	doc_491521501740_item	2447560	et	2	main
eesti	doc_491521501740_item	2447570	et	4	main
ei	doc_491521501740_item	2447572	et	4	main
pruugi	doc_491521501740_item	2447573	et	4	main
vene	doc_491521501740_item	2447574	et	4	main
da-infinitiiv	doc_491521501740_item	2447580	et	3	main
быть	doc_491521501740_item	2447630	et	2	main
juua	doc_491521501740_item	2447635	et	3	main
спать	doc_491521501740_item	2447646	et	2	main
õppima	doc_491521501740_item	2447649	et	3	main
tavaliselt	doc_491521501740_item	2447662	et	4	main
kõneleja	doc_491521501740_item	2447683	et	4	main
millega	doc_491521501740_item	2447694	et	3	main
verbid	doc_491521501740_item	2447698	et	3	main
seostuvad	doc_491521501740_item	2447711	et	4	main
ainult	doc_491521501740_item	2447712	et	4	main
ma-infinitiiviga	doc_491521501740_item	2447713	et	3	main
3	doc_491521501740_item	2447714	et	2	main
verbid	doc_491521501740_item	2447715	et	3	main
ma-infinitiivil	doc_491521501740_item	2447723	et	3	main
algvormi	doc_491521501740_item	2447728	et	4	main
aktiivis	doc_491521501740_item	2447729	et	3	main
käändelist	doc_491521501740_item	2447731	et	4	main
mas-	doc_491521501740_item	2447733	et	4	main
inessiiv	doc_491521501740_item	2447734	et	3	main
mast-	doc_491521501740_item	2447735	et	3	main
tegevuse	doc_491521501740_item	2447746	et	4	main
on	doc_491521501740_item	2447753	et	4	main
tavaliselt	doc_491521501740_item	2447755	et	4	main
määrusena	doc_491521501740_item	2447756	et	3	main
mingi	doc_491521501740_item	2447767	et	4	main
tegevuse	doc_491521501740_item	2447769	et	4	main
suhtes	doc_491521501740_item	2447770	et	4	main
samaaegset	doc_491521501740_item	2447771	et	3	main
väljas	doc_491521501740_item	2447777	et	4	main
nt	doc_491521501740_item	2447782	et	4	main
korjamas	doc_491521501740_item	2447785	et	3	main
tähistab	doc_491521501740_item	2447788	et	3	main
2	doc_491521501740_item	2447429	et	2	main
keeles	doc_491521501740_item	2447435	et	4	main
заплакал	doc_491521501740_item	2447451	et	2	main
заснул	doc_491521501740_item	2447456	et	2	main
kui	doc_491521501740_item	2447462	et	3	main
keeles	doc_491521501740_item	2447472	et	4	main
eesti	doc_491521501740_item	2447474	et	4	main
verb	doc_491521501740_item	2447479	et	3	main
hakkama	doc_491521501740_item	2447480	et	3	main
selle	doc_491521501740_item	2447482	et	4	main
tähenduses	doc_491521501740_item	2447483	et	4	main
mõne	doc_491521501740_item	2447484	et	3	main
teise	doc_491521501740_item	2447485	et	4	main
verbi	doc_491521501740_item	2447486	et	4	main
finiitne	doc_491521501740_item	2447487	et	3	main
vorm	doc_491521501740_item	2447488	et	3	main
ta	doc_491521501740_item	2447490	et	4	main
nt	doc_491521501740_item	2447489	et	4	main
hakkas	doc_491521501740_item	2447491	et	3	main
kirjutama	doc_491521501740_item	2447492	et	3	main
он	doc_491521501740_item	2447493	et	2	main
начал	doc_491521501740_item	2447494	et	2	main
писать	doc_491521501740_item	2447495	et	2	main
3	doc_491521501740_item	2447496	et	2	main
ma-infinitiiv	doc_491521501740_item	2447497	et	3	main
koos	doc_491521501740_item	2447498	et	4	main
adjektiiviga	doc_491521501740_item	2447499	et	3	main
tähistab	doc_491521501740_item	2447500	et	3	main
kellelegi	doc_491521501740_item	2447501	et	4	main
või	doc_491521501740_item	2447502	et	4	main
millelegi	doc_491521501740_item	2447503	et	4	main
omast	doc_491521501740_item	2447504	et	4	main
tegevust	doc_491521501740_item	2447505	et	4	main
predikaatverbina	doc_491521501740_item	2447506	et	4	main
esineb	doc_491521501740_item	2447507	et	3	main
olema	doc_491521501740_item	2447508	et	4	main
pöördeline	doc_491521501740_item	2447509	et	4	main
vorm	doc_491521501740_item	2447510	et	3	main
vene	doc_491521501740_item	2447511	et	4	main
keeles	doc_491521501740_item	2447512	et	4	main
vastab	doc_491521501740_item	2447513	et	3	main
sellele	doc_491521501740_item	2447514	et	4	main
verbi	doc_491521501740_item	2447515	et	4	main
pöördeline	doc_491521501740_item	2447516	et	4	main
vorm	doc_491521501740_item	2447517	et	3	main
puuduvate	doc_491521501740_item	2447424	et	4	main
väljendatakse	doc_491521501740_item	2447427	et	3	main
predikaadi	doc_491521501740_item	2447432	et	3	main
vene	doc_491521501740_item	2447434	et	4	main
по	doc_491521501740_item	2447444	et	2	main
ta	doc_491521501740_item	2447452	et	4	main
magama	doc_491521501740_item	2447454	et	3	main
esineb	doc_491521501740_item	2447476	et	3	main
või	doc_491521501740_item	2447481	et	4	main
nt	doc_491521501740_item	2447518	et	4	main
see	doc_491521501740_item	2447519	et	3	main
üliõpilane	doc_491521501740_item	2447520	et	3	main
usin	doc_491521501740_item	2447522	et	3	main
этот	doc_491521501740_item	2447524	et	2	main
прилежно	doc_491521501740_item	2447526	et	2	main
osav	doc_491521501740_item	2447531	et	3	main
брат	doc_491521501740_item	2447534	et	2	main
4	doc_491521501740_item	2447537	et	2	main
keeles	doc_491521501740_item	2447548	et	4	main
vastab	doc_491521501740_item	2447549	et	3	main
tähistava	doc_491521501740_item	2447557	et	4	main
vastama	doc_491521501740_item	2447577	et	3	main
infinitiiv	doc_491521501740_item	2447578	et	3	main
kui	doc_491521501740_item	2447579	et	3	main
või	doc_491521501740_item	2447583	et	4	main
olemist	doc_491521501740_item	2447585	et	4	main
või	doc_491521501740_item	2447588	et	4	main
on	doc_491521501740_item	2447590	et	4	main
määratud	doc_491521501740_item	2447591	et	4	main
siis	doc_491521501740_item	2447592	et	3	main
venekeelseks	doc_491521501740_item	2447593	et	4	main
vasteks	doc_491521501740_item	2447594	et	3	main
on	doc_491521501740_item	2447595	et	4	main
verbist	doc_491521501740_item	2447596	et	3	main
tuletatud	doc_491521501740_item	2447597	et	4	main
substantiiv	doc_491521501740_item	2447598	et	3	main
prepositsiooniga	doc_491521501740_item	2447599	et	4	main
для	doc_491521501740_item	2447600	et	2	main
nt	doc_491521501740_item	2447601	et	4	main
raamat	doc_491521501740_item	2447602	et	3	main
on	doc_491521501740_item	2447603	et	4	main
lugeda	doc_491521501740_item	2447604	et	3	main
книга	doc_491521501740_item	2447605	et	2	main
для	doc_491521501740_item	2447606	et	2	main
чтения	doc_491521501740_item	2447607	et	2	main
õun	doc_491521501740_item	2447608	et	3	main
süüa	doc_491521501740_item	2447610	et	3	main
яблоко	doc_491521501740_item	2447611	et	2	main
для	doc_491521501740_item	2447612	et	2	main
еды	doc_491521501740_item	2447613	et	2	main
mölder	doc_491521501740_item	2447614	et	3	main
1967	doc_491521501740_item	2447615	et	2	main
on	doc_491521501740_item	2447609	et	4	main
95-96	doc_491521501740_item	2447616	et	2	main
infinitiiv	doc_491521501740_item	2447617	et	3	main
olla	doc_491521501740_item	2447619	et	3	main
sõltumatu	doc_491521501740_item	2447620	et	4	main
võib	doc_491521501740_item	2447618	et	3	main
врачем	doc_491521501740_item	2447632	et	2	main
on	doc_491521501740_item	2447634	et	4	main
ma	doc_491521501740_item	2447647	et	3	main
lähemalt	doc_491521501740_item	2447650	et	4	main
õppima	doc_491521501740_item	2447523	et	3	main
учится	doc_491521501740_item	2447527	et	2	main
vend	doc_491521501740_item	2447529	et	3	main
ujuma	doc_491521501740_item	2447532	et	3	main
плавал	doc_491521501740_item	2447536	et	2	main
vene	doc_491521501740_item	2447539	et	4	main
eesti	doc_491521501740_item	2447547	et	4	main
ühes	doc_491521501740_item	2447555	et	4	main
sõnaga	doc_491521501740_item	2447558	et	3	main
читать	doc_491521501740_item	2447561	et	2	main
читать	doc_491521501740_item	2447565	et	2	main
loed	doc_491521501740_item	2447567	et	4	main
alati	doc_491521501740_item	2447576	et	4	main
või	doc_491521501740_item	2447621	et	4	main
sõltumatu	doc_491521501740_item	2447623	et	4	main
võib	doc_491521501740_item	2447625	et	3	main
esineda	doc_491521501740_item	2447626	et	3	main
omaette	doc_491521501740_item	2447627	et	3	main
infinitiiv	doc_491521501740_item	2447637	et	3	main
olla	doc_491521501740_item	2447639	et	3	main
verbikonstruktsiooni	doc_491521501740_item	2447641	et	4	main
nt	doc_491521501740_item	2447643	et	4	main
хочу	doc_491521501740_item	2447645	et	2	main
pean	doc_491521501740_item	2447648	et	4	main
eesti	doc_491521501740_item	2447653	et	4	main
infinitiivil	doc_491521501740_item	2447654	et	3	main
käivad	doc_491521501740_item	2447661	et	4	main
suhtumist	doc_491521501740_item	2447684	et	4	main
eesti	doc_491521501740_item	2447686	et	4	main
sõltuvalt	doc_491521501740_item	2447692	et	4	main
nad	doc_491521501740_item	2447695	et	3	main
1	doc_491521501740_item	2447697	et	2	main
mille	doc_491521501740_item	2447699	et	3	main
on	doc_491521501740_item	2447701	et	4	main
verbid	doc_491521501740_item	2447709	et	3	main
mis	doc_491521501740_item	2447716	et	4	main
käivad	doc_491521501740_item	2447717	et	4	main
on	doc_491521501740_item	2447726	et	4	main
vormi	doc_491521501740_item	2447732	et	4	main
mata-	doc_491521501740_item	2447739	et	4	main
muu	doc_491521501740_item	2447745	et	4	main
nt	doc_491521501740_item	2447761	et	4	main
mas-vorm	doc_491521501740_item	2447764	et	3	main
olevikku	doc_491521501740_item	2447774	et	4	main
nt	doc_491521501740_item	2447775	et	4	main
käisime	doc_491521501740_item	2447776	et	3	main
marju	doc_491521501740_item	2447784	et	3	main
inessiiv	doc_491521501740_item	2447787	et	3	main
leksikaalselt	doc_491521501740_item	2447797	et	4	main
keelde	doc_491521501740_item	2447833	et	4	main
nt	doc_491521501740_item	2447835	et	4	main
olen	doc_491521501740_item	2447836	et	3	main
metsas	doc_491521501740_item	2447837	et	3	main
jooksmas	doc_491521501740_item	2447838	et	3	main
бегаю	doc_491521501740_item	2447840	et	2	main
лесу	doc_491521501740_item	2447842	et	2	main
käin	doc_491521501740_item	2447843	et	3	main
в	doc_491521501740_item	2447847	et	2	main
minemas	doc_491521501740_item	2447854	et	3	main
переходил	doc_491521501740_item	2447858	et	2	main
на	doc_491521501740_item	2447877	et	2	main
петь	doc_491521501740_item	2447887	et	2	main
elatiiv	doc_491521501740_item	2447889	et	3	main
mast-vorm	doc_491521501740_item	2447890	et	3	main
minevikku	doc_491521501740_item	2447898	et	4	main
nt	doc_491521501740_item	2447899	et	4	main
söömas	doc_491521501740_item	2447900	et	4	main
sadama	doc_491521501740_item	2447905	et	4	main
lakatakse	doc_491521501740_item	2447917	et	3	main
leksikaalselt	doc_491521501740_item	2447922	et	4	main
niitmast	doc_491521501740_item	2447930	et	4	main
брат	doc_491521501740_item	2447931	et	2	main
пришел	doc_491521501740_item	2447932	et	2	main
с	doc_491521501740_item	2447933	et	2	main
сенокоса	doc_491521501740_item	2447934	et	2	main
vihm	doc_491521501740_item	2447935	et	3	main
lakkas	doc_491521501740_item	2447936	et	3	main
sadamast	doc_491521501740_item	2447937	et	4	main
л	doc_491521501740_item	2447940	et	2	main
keeldusin	doc_491521501740_item	2447944	et	3	main
говорить	doc_491521501740_item	2447948	et	2	main
tema	doc_491521501740_item	2447528	et	4	main
oli	doc_491521501740_item	2447530	et	3	main
его	doc_491521501740_item	2447533	et	2	main
ловко	doc_491521501740_item	2447535	et	2	main
infinitiiv	doc_491521501740_item	2447538	et	3	main
keeles	doc_491521501740_item	2447540	et	4	main
koos	doc_491521501740_item	2447541	et	4	main
быть	doc_491521501740_item	2447543	et	2	main
moodustab	doc_491521501740_item	2447544	et	3	main
tuleviku	doc_491521501740_item	2447545	et	4	main
tulevikku	doc_491521501740_item	2447556	et	4	main
nt	doc_491521501740_item	2447559	et	4	main
homme	doc_491521501740_item	2447562	et	3	main
loen	doc_491521501740_item	2447563	et	3	main
pärast	doc_491521501740_item	2447566	et	4	main
5	doc_491521501740_item	2447568	et	2	main
da-infinitiivile	doc_491521501740_item	2447569	et	3	main
keeles	doc_491521501740_item	2447571	et	4	main
tähistab	doc_491521501740_item	2447581	et	3	main
olukorras	doc_491521501740_item	2447584	et	3	main
milleks	doc_491521501740_item	2447586	et	4	main
olend	doc_491521501740_item	2447587	et	3	main
ese	doc_491521501740_item	2447589	et	3	main
sõltuv	doc_491521501740_item	2447622	et	4	main
infinitiiv	doc_491521501740_item	2447624	et	3	main
lauseliikmena	doc_491521501740_item	2447628	et	3	main
тебе	doc_491521501740_item	2447631	et	2	main
mahl	doc_491521501740_item	2447633	et	3	main
ainult	doc_491521501740_item	2447640	et	4	main
osaks	doc_491521501740_item	2447642	et	3	main
я	doc_491521501740_item	2447644	et	2	main
on	doc_491521501740_item	2447655	et	4	main
kaks	doc_491521501740_item	2447656	et	3	main
üleüldse	doc_491521501740_item	2447682	et	3	main
tegevusse	doc_491521501740_item	2447685	et	4	main
infinitiivist	doc_491521501740_item	2447693	et	3	main
võimalik	doc_491521501740_item	2447702	et	3	main
da-infinitiiv	doc_491521501740_item	2447707	et	3	main
mis	doc_491521501740_item	2447710	et	4	main
ainult	doc_491521501740_item	2447718	et	4	main
mölder	doc_491521501740_item	2447720	et	3	main
1967	doc_491521501740_item	2447721	et	2	main
ehk	doc_491521501740_item	2447724	et	3	main
peale	doc_491521501740_item	2447727	et	4	main
tulevikku	doc_491521501740_item	2447751	et	4	main
väljendab	doc_491521501740_item	2447765	et	3	main
muu	doc_491521501740_item	2447768	et	4	main
määrusena	doc_491521501740_item	2447781	et	3	main
ma-infinitiivi	doc_491521501740_item	2447786	et	4	main
või	doc_491521501740_item	2447790	et	4	main
olukorras	doc_491521501740_item	2447791	et	3	main
viibimist	doc_491521501740_item	2447792	et	4	main
on	doc_491521501740_item	2447825	et	4	main
olemas	doc_491521501740_item	2447826	et	4	main
mitu	doc_491521501740_item	2447827	et	4	main
võimalust	doc_491521501740_item	2447828	et	3	main
kuidas	doc_491521501740_item	2447829	et	3	main
jalutamas	doc_491521501740_item	2447845	et	3	main
парк	doc_491521501740_item	2447848	et	2	main
дорогу	doc_491521501740_item	2447859	et	2	main
tüdrukuid	doc_491521501740_item	2447861	et	4	main
слышал	doc_491521501740_item	2447864	et	2	main
девочки	doc_491521501740_item	2447866	et	2	main
в	doc_491521501740_item	2447868	et	2	main
брат	doc_491521501740_item	2447875	et	2	main
лугу	doc_491521501740_item	2447878	et	2	main
tagasi	doc_491521501740_item	2447901	et	3	main
tulles	doc_491521501740_item	2447902	et	4	main
hakkas	doc_491521501740_item	2447903	et	3	main
märgib	doc_491521501740_item	2447907	et	3	main
viibimist	doc_491521501740_item	2447911	et	4	main
loobutakse	doc_491521501740_item	2447915	et	3	main
nt	doc_491521501740_item	2447927	et	4	main
перестал	doc_491521501740_item	2447939	et	2	main
ma	doc_491521501740_item	2447943	et	3	main
kõnelemast	doc_491521501740_item	2447945	et	3	main
vastu	doc_491521501740_item	2447968	et	3	main
halvasti	doc_491521501740_item	2447971	et	3	main
vales	doc_491521501740_item	2447978	et	3	main
üle	doc_491521501740_item	2447980	et	3	main
minemast	doc_491521501740_item	2447982	et	3	main
nt	doc_491521501740_item	2447629	et	4	main
sõltuv	doc_491521501740_item	2447636	et	4	main
saab	doc_491521501740_item	2447638	et	3	main
põhivormi	doc_491521501740_item	2447657	et	4	main
infinitiivi	doc_491521501740_item	2447658	et	4	main
koos	doc_491521501740_item	2447663	et	4	main
teise	doc_491521501740_item	2447664	et	4	main
finiitse	doc_491521501740_item	2447665	et	3	main
tegusõnaga	doc_491521501740_item	2447666	et	3	main
mis	doc_491521501740_item	2447667	et	4	main
väljendab	doc_491521501740_item	2447668	et	3	main
kas	doc_491521501740_item	2447669	et	3	main
neutraalset	doc_491521501740_item	2447670	et	3	main
reaalset	doc_491521501740_item	2447671	et	3	main
tegevust	doc_491521501740_item	2447672	et	4	main
või	doc_491521501740_item	2447673	et	4	main
modaalse	doc_491521501740_item	2447674	et	3	main
värvinguga	doc_491521501740_item	2447675	et	3	main
tegevust	doc_491521501740_item	2447676	et	4	main
tegevuse	doc_491521501740_item	2447677	et	4	main
võimalikkust	doc_491521501740_item	2447678	et	4	main
vajalikkust	doc_491521501740_item	2447679	et	4	main
soovitatavust	doc_491521501740_item	2447680	et	4	main
eesti	doc_491521501740_item	2447651	et	4	main
infinitiividest	doc_491521501740_item	2447652	et	3	main
põhilised	doc_491521501740_item	2447659	et	3	main
vormid	doc_491521501740_item	2447660	et	4	main
ja	doc_491521501740_item	2447681	et	3	main
jagunevad	doc_491521501740_item	2447688	et	4	main
verbid	doc_491521501740_item	2447689	et	3	main
kolme	doc_491521501740_item	2447690	et	4	main
rühma	doc_491521501740_item	2447691	et	4	main
seostuvad	doc_491521501740_item	2447696	et	4	main
puhul	doc_491521501740_item	2447700	et	4	main
ma-infinitiiv	doc_491521501740_item	2447704	et	3	main
kui	doc_491521501740_item	2447705	et	3	main
2	doc_491521501740_item	2447708	et	2	main
98	doc_491521501740_item	2447722	et	2	main
supiinil	doc_491521501740_item	2447725	et	3	main
neli	doc_491521501740_item	2447730	et	3	main
elatiiv	doc_491521501740_item	2447736	et	3	main
maks-	doc_491521501740_item	2447737	et	3	main
vorm	doc_491521501740_item	2447741	et	3	main
ma-vorm	doc_491521501740_item	2447742	et	3	main
väljendab	doc_491521501740_item	2447743	et	3	main
mingi	doc_491521501740_item	2447744	et	4	main
järgnevat	doc_491521501740_item	2447748	et	4	main
suhtelist	doc_491521501740_item	2447750	et	4	main
ta	doc_491521501740_item	2447752	et	4	main
lauses	doc_491521501740_item	2447754	et	3	main
nt	doc_491521501740_item	2447757	et	4	main
läksime	doc_491521501740_item	2447758	et	3	main
sööma	doc_491521501740_item	2447759	et	4	main
öeldisena	doc_491521501740_item	2447760	et	3	main
tavaliselt	doc_491521501740_item	2447766	et	4	main
suhtelist	doc_491521501740_item	2447773	et	4	main
tavaliselt	doc_491521501740_item	2447780	et	4	main
tegevuses	doc_491521501740_item	2447789	et	4	main
vene	doc_491521501740_item	2447793	et	4	main
tõlkimisega	doc_491521501740_item	2447821	et	4	main
keelde	doc_491521501740_item	2447823	et	4	main
vene	doc_491521501740_item	2447832	et	4	main
tõlkida	doc_491521501740_item	2447834	et	3	main
гулять	doc_491521501740_item	2447849	et	2	main
üle	doc_491521501740_item	2447852	et	3	main
видел	doc_491521501740_item	2447855	et	2	main
друг	doc_491521501740_item	2447857	et	2	main
kuulsin	doc_491521501740_item	2447860	et	3	main
saalis	doc_491521501740_item	2447862	et	4	main
laulmas	doc_491521501740_item	2447863	et	3	main
как	doc_491521501740_item	2447865	et	2	main
пели	doc_491521501740_item	2447867	et	2	main
зале	doc_491521501740_item	2447869	et	2	main
vend	doc_491521501740_item	2447870	et	3	main
on	doc_491521501740_item	2447871	et	4	main
aasal	doc_491521501740_item	2447872	et	3	main
heina	doc_491521501740_item	2447873	et	4	main
niitmas	doc_491521501740_item	2447874	et	3	main
косит	doc_491521501740_item	2447880	et	2	main
käib	doc_491521501740_item	2447883	et	3	main
tantsimas	doc_491521501740_item	2447884	et	3	main
ma-infinitiivi	doc_491521501740_item	2447888	et	4	main
suhtelist	doc_491521501740_item	2447897	et	4	main
mast-vorm	doc_491521501740_item	2447906	et	3	main
või	doc_491521501740_item	2447909	et	4	main
vene	doc_491521501740_item	2447918	et	4	main
seda	doc_491521501740_item	2447921	et	3	main
loobumise	doc_491521501740_item	2447923	et	4	main
и	doc_491521501740_item	2447941	et	2	main
я	doc_491521501740_item	2447946	et	2	main
mast-vormiga	doc_491521501740_item	2447949	et	4	main
kasutada	doc_491521501740_item	2447951	et	3	main
tulema	doc_491521501740_item	2447953	et	4	main
tänama	doc_491521501740_item	2447954	et	3	main
hoiduma	doc_491521501740_item	2447956	et	3	main
hoiatama	doc_491521501740_item	2447959	et	3	main
võtmast	doc_491521501740_item	2447969	et	3	main
hoidus	doc_491521501740_item	2447970	et	3	main
kohas	doc_491521501740_item	2447979	et	4	main
lauses	doc_491521501740_item	2447983	et	3	main
söömast	doc_491521501740_item	2447991	et	4	main
maks-vorm	doc_491521501740_item	2447992	et	3	main
muidu	doc_491521501740_item	2448021	et	3	main
suvel	doc_491521501740_item	2448028	et	3	main
keeles	doc_491521501740_item	2447687	et	4	main
niihästi	doc_491521501740_item	2447703	et	3	main
ka	doc_491521501740_item	2447706	et	3	main
da-infinitiiviga	doc_491521501740_item	2447719	et	3	main
translatiiv	doc_491521501740_item	2447738	et	4	main
abessiiv	doc_491521501740_item	2447740	et	3	main
suhtes	doc_491521501740_item	2447747	et	4	main
tegevust	doc_491521501740_item	2447749	et	4	main
kähku	doc_491521501740_item	2447762	et	3	main
minema	doc_491521501740_item	2447763	et	3	main
tegevust	doc_491521501740_item	2447772	et	4	main
söömas	doc_491521501740_item	2447778	et	4	main
esineb	doc_491521501740_item	2447779	et	3	main
olime	doc_491521501740_item	2447783	et	3	main
keeles	doc_491521501740_item	2447794	et	4	main
väljendatakse	doc_491521501740_item	2447795	et	3	main
seda	doc_491521501740_item	2447796	et	3	main
infinitiiviga	doc_491521501740_item	2447799	et	3	main
harva	doc_491521501740_item	2447798	et	4	main
mas-vorm	doc_491521501740_item	2447800	et	3	main
seostub	doc_491521501740_item	2447801	et	3	main
mõne	doc_491521501740_item	2447802	et	3	main
üksiku	doc_491521501740_item	2447803	et	3	main
verbiga	doc_491521501740_item	2447804	et	3	main
nagu	doc_491521501740_item	2447805	et	3	main
käima	doc_491521501740_item	2447806	et	4	main
leidma	doc_491521501740_item	2447807	et	3	main
olema	doc_491521501740_item	2447808	et	4	main
pidama	doc_491521501740_item	2447809	et	4	main
püsima	doc_491521501740_item	2447810	et	3	main
viibima	doc_491521501740_item	2447811	et	3	main
seisma	doc_491521501740_item	2447812	et	3	main
istuma	doc_491521501740_item	2447813	et	3	main
nägema	doc_491521501740_item	2447814	et	3	main
kuulma	doc_491521501740_item	2447815	et	3	main
ja	doc_491521501740_item	2447816	et	3	main
märkama	doc_491521501740_item	2447817	et	3	main
raskusi	doc_491521501740_item	2447818	et	4	main
tekib	doc_491521501740_item	2447819	et	3	main
vormi	doc_491521501740_item	2447820	et	4	main
vene	doc_491521501740_item	2447822	et	4	main
sest	doc_491521501740_item	2447824	et	4	main
neid	doc_491521501740_item	2447830	et	4	main
хожу	doc_491521501740_item	2447846	et	2	main
nägin	doc_491521501740_item	2447850	et	3	main
tee	doc_491521501740_item	2447853	et	4	main
как	doc_491521501740_item	2447856	et	2	main
и	doc_491521501740_item	2447879	et	2	main
õde	doc_491521501740_item	2447882	et	4	main
ходит	doc_491521501740_item	2447886	et	2	main
väljendab	doc_491521501740_item	2447891	et	3	main
teisele	doc_491521501740_item	2447893	et	4	main
eelnenud	doc_491521501740_item	2447895	et	4	main
tegevust	doc_491521501740_item	2447896	et	4	main
tegevust	doc_491521501740_item	2447908	et	4	main
olukorras	doc_491521501740_item	2447910	et	3	main
millest	doc_491521501740_item	2447912	et	3	main
tullakse	doc_491521501740_item	2447913	et	3	main
väljutakse	doc_491521501740_item	2447914	et	3	main
või	doc_491521501740_item	2447916	et	4	main
konstruktsioone	doc_491521501740_item	2447831	et	3	main
я	doc_491521501740_item	2447839	et	2	main
в	doc_491521501740_item	2447841	et	2	main
pargis	doc_491521501740_item	2447844	et	3	main
sõpra	doc_491521501740_item	2447851	et	4	main
находится	doc_491521501740_item	2447876	et	2	main
сено	doc_491521501740_item	2447881	et	2	main
сестра	doc_491521501740_item	2447885	et	2	main
mingile	doc_491521501740_item	2447892	et	4	main
tegevusele	doc_491521501740_item	2447894	et	4	main
vihma	doc_491521501740_item	2447904	et	4	main
keeles	doc_491521501740_item	2447919	et	4	main
väljendatakse	doc_491521501740_item	2447920	et	3	main
lakkamise	doc_491521501740_item	2447924	et	4	main
puhul	doc_491521501740_item	2447925	et	4	main
infinitiiviga	doc_491521501740_item	2447926	et	3	main
дождь	doc_491521501740_item	2447938	et	2	main
отказался	doc_491521501740_item	2447947	et	2	main
saab	doc_491521501740_item	2447950	et	3	main
verbe	doc_491521501740_item	2447952	et	3	main
abi	doc_491521501740_item	2447967	et	4	main
ütlemast	doc_491521501740_item	2447972	et	3	main
hoiatati	doc_491521501740_item	2447977	et	3	main
on	doc_491521501740_item	2447984	et	4	main
tavaliselt	doc_491521501740_item	2447986	et	4	main
määrusena	doc_491521501740_item	2447987	et	3	main
nt	doc_491521501740_item	2447988	et	4	main
tegevust	doc_491521501740_item	2447994	et	4	main
teise	doc_491521501740_item	2447996	et	4	main
otstarvet	doc_491521501740_item	2447998	et	3	main
asendada	doc_491521501740_item	2448001	et	3	main
talvel	doc_491521501740_item	2448025	et	4	main
tuleb	doc_491521501740_item	2448027	et	3	main
töötada	doc_491521501740_item	2448035	et	3	main
suvel	doc_491521501740_item	2448037	et	3	main
nt	doc_491521501740_item	2448043	et	4	main
mari	doc_491521501740_item	2448044	et	4	main
varakul	doc_491521501740_item	2448046	et	4	main
osutab	doc_491521501740_item	2448055	et	3	main
või	doc_491521501740_item	2448057	et	4	main
esimesse	doc_491521501740_item	2448065	et	4	main
sõltuvusmäärusena	doc_491521501740_item	2448071	et	4	main
nt	doc_491521501740_item	2448072	et	4	main
jätsin	doc_491521501740_item	2448073	et	3	main
toa	doc_491521501740_item	2448074	et	3	main
ka	doc_491521501740_item	2448086	et	3	main
või	doc_491521501740_item	2448088	et	4	main
нескошенной	doc_491521501740_item	2448121	et	2	main
meile	doc_491521501740_item	2448133	et	4	main
ta	doc_491521501740_item	2448144	et	4	main
unustas	doc_491521501740_item	2448152	et	3	main
ученик	doc_491521501740_item	2448155	et	2	main
решить	doc_491521501740_item	2448157	et	2	main
saanud	doc_491521501740_item	2448166	et	4	main
мальчик	doc_491521501740_item	2448169	et	2	main
им	doc_491521501740_item	2448172	et	2	main
не	doc_491521501740_item	2448175	et	2	main
быка	doc_491521501740_item	2448177	et	2	main
2000	doc_491521501740_item	2448182	et	2	main
1967	doc_491521501740_item	2448185	et	2	main
väljendatud	doc_491521501740_item	2448221	et	4	main
põhjuseks	doc_491521501740_item	2448223	et	3	main
aitama	doc_491521501740_item	2448224	et	3	main
ajama	doc_491521501740_item	2448225	et	4	main
loomad	doc_491521501740_item	2448228	et	3	main
harjuma	doc_491521501740_item	2448238	et	3	main
kippuma	doc_491521501740_item	2448239	et	3	main
vilja	doc_491521501740_item	2448255	et	4	main
koristama	doc_491521501740_item	2448256	et	3	main
päll	doc_491521501740_item	2448257	et	3	main
178-180	doc_491521501740_item	2448259	et	2	main
passiivis	doc_491521501740_item	2448262	et	3	main
või	doc_491521501740_item	2448272	et	4	main
da	doc_491521501740_item	2448273	et	4	main
tunnuse	doc_491521501740_item	2448274	et	3	main
jutustatama	doc_491521501740_item	2448276	et	3	main
ostetama	doc_491521501740_item	2448278	et	3	main
harva	doc_491521501740_item	2448282	et	4	main
kaks	doc_491521501740_item	2448289	et	3	main
on	doc_491521501740_item	2448294	et	4	main
vend	doc_491521501740_item	2447928	et	3	main
tuli	doc_491521501740_item	2447929	et	4	main
ть	doc_491521501740_item	2447942	et	2	main
väsima	doc_491521501740_item	2447957	et	3	main
tüdima	doc_491521501740_item	2447958	et	3	main
jooksmast	doc_491521501740_item	2447962	et	3	main
külalisi	doc_491521501740_item	2447964	et	4	main
mängimast	doc_491521501740_item	2447974	et	3	main
ootamast	doc_491521501740_item	2447976	et	3	main
tee	doc_491521501740_item	2447981	et	4	main
mari	doc_491521501740_item	2447989	et	4	main
mis	doc_491521501740_item	2448003	et	4	main
algab	doc_491521501740_item	2448004	et	3	main
sidesõnaga	doc_491521501740_item	2448005	et	3	main
selleks	doc_491521501740_item	2448006	et	4	main
vormi	doc_491521501740_item	2448008	et	4	main
et	doc_491521501740_item	2448007	et	3	main
on	doc_491521501740_item	2448009	et	4	main
soovitav	doc_491521501740_item	2448010	et	4	main
kasutada	doc_491521501740_item	2448011	et	3	main
pikemate	doc_491521501740_item	2448012	et	4	main
lausete	doc_491521501740_item	2448013	et	4	main
asemel	doc_491521501740_item	2448014	et	4	main
eriti	doc_491521501740_item	2448015	et	3	main
siis	doc_491521501740_item	2448016	et	3	main
kui	doc_491521501740_item	2448017	et	3	main
mitu	doc_491521501740_item	2448018	et	4	main
et-lauset	doc_491521501740_item	2448019	et	3	main
satuks	doc_491521501740_item	2448020	et	3	main
nt	doc_491521501740_item	2448023	et	4	main
talvel	doc_491521501740_item	2448033	et	4	main
hästi	doc_491521501740_item	2448034	et	3	main
palju	doc_491521501740_item	2448038	et	4	main
puhata	doc_491521501740_item	2448039	et	4	main
esineb	doc_491521501740_item	2448041	et	3	main
endale	doc_491521501740_item	2448049	et	4	main
paremat	doc_491521501740_item	2448050	et	4	main
istekohta	doc_491521501740_item	2448051	et	4	main
toimumata	doc_491521501740_item	2448056	et	4	main
puuduvat	doc_491521501740_item	2448058	et	4	main
tegevust	doc_491521501740_item	2448059	et	4	main
olemist	doc_491521501740_item	2448062	et	4	main
jätsin	doc_491521501740_item	2448064	et	3	main
loengusse	doc_491521501740_item	2448066	et	4	main
minemata	doc_491521501740_item	2448067	et	4	main
lauses	doc_491521501740_item	2448068	et	3	main
koristamata	doc_491521501740_item	2448075	et	4	main
tuli	doc_491521501740_item	2448123	et	4	main
kutsumata	doc_491521501740_item	2448134	et	4	main
гость	doc_491521501740_item	2448135	et	2	main
пришел	doc_491521501740_item	2448136	et	2	main
к	doc_491521501740_item	2448137	et	2	main
нам	doc_491521501740_item	2448138	et	2	main
без	doc_491521501740_item	2448139	et	2	main
приглашения	doc_491521501740_item	2448140	et	2	main
tagasi	doc_491521501740_item	2448141	et	3	main
edasi	doc_491521501740_item	2448145	et	3	main
не	doc_491521501740_item	2448149	et	2	main
ei	doc_491521501740_item	2448161	et	4	main
härga	doc_491521501740_item	2448164	et	4	main
бы	doc_491521501740_item	2448168	et	2	main
помог	doc_491521501740_item	2448171	et	2	main
бы	doc_491521501740_item	2448174	et	2	main
metslang	doc_491521501740_item	2448178	et	3	main
keelduma	doc_491521501740_item	2447955	et	3	main
nt	doc_491521501740_item	2447960	et	4	main
tulime	doc_491521501740_item	2447961	et	3	main
tänasin	doc_491521501740_item	2447963	et	3	main
tulemast	doc_491521501740_item	2447965	et	4	main
keeldus	doc_491521501740_item	2447966	et	3	main
väsisime	doc_491521501740_item	2447973	et	3	main
tüdisin	doc_491521501740_item	2447975	et	3	main
ta	doc_491521501740_item	2447985	et	4	main
kui	doc_491521501740_item	2447995	et	3	main
tegevuse	doc_491521501740_item	2447997	et	4	main
saab	doc_491521501740_item	2448000	et	3	main
keeldus	doc_491521501740_item	2447990	et	3	main
väljendab	doc_491521501740_item	2447993	et	3	main
sellega	doc_491521501740_item	2447999	et	3	main
kõrvallauset	doc_491521501740_item	2448002	et	3	main
palju	doc_491521501740_item	2448029	et	4	main
selleks	doc_491521501740_item	2448031	et	4	main
et	doc_491521501740_item	2448032	et	3	main
läks	doc_491521501740_item	2448045	et	3	main
kohale	doc_491521501740_item	2448047	et	4	main
leidmaks	doc_491521501740_item	2448048	et	4	main
ma-infinitiivi	doc_491521501740_item	2448052	et	4	main
või	doc_491521501740_item	2448060	et	4	main
ta	doc_491521501740_item	2448070	et	4	main
vastab	doc_491521501740_item	2448078	et	3	main
või	doc_491521501740_item	2448081	et	4	main
eitav	doc_491521501740_item	2448083	et	4	main
vorm	doc_491521501740_item	2448084	et	3	main
väljendatakse	doc_491521501740_item	2448089	et	3	main
meile	doc_491521501740_item	2448122	et	4	main
kutsumata	doc_491521501740_item	2448124	et	4	main
külaline	doc_491521501740_item	2448125	et	4	main
к	doc_491521501740_item	2448126	et	2	main
нам	doc_491521501740_item	2448127	et	2	main
пришел	doc_491521501740_item	2448128	et	2	main
незванный	doc_491521501740_item	2448129	et	2	main
läks	doc_491521501740_item	2448143	et	3	main
дальше	doc_491521501740_item	2448148	et	2	main
õpilane	doc_491521501740_item	2448151	et	3	main
ülesande	doc_491521501740_item	2448153	et	4	main
забыл	doc_491521501740_item	2448156	et	2	main
задачу	doc_491521501740_item	2448158	et	2	main
poisi	doc_491521501740_item	2448159	et	3	main
aitamata	doc_491521501740_item	2448160	et	4	main
96-97	doc_491521501740_item	2448186	et	2	main
ühenduvad	doc_491521501740_item	2448188	et	4	main
põgenema	doc_491521501740_item	2448229	et	3	main
ja	doc_491521501740_item	2448231	et	3	main
väljendamist	doc_491521501740_item	2448233	et	4	main
veenmine	doc_491521501740_item	2448236	et	4	main
aimama	doc_491521501740_item	2448237	et	3	main
meelitama	doc_491521501740_item	2448240	et	3	main
mängima	doc_491521501740_item	2448243	et	3	main
ja	doc_491521501740_item	2448247	et	3	main
on	doc_491521501740_item	2448261	et	4	main
moodustatakse	doc_491521501740_item	2448266	et	3	main
ostma	doc_491521501740_item	2448277	et	3	main
seda	doc_491521501740_item	2448280	et	3	main
da-vorm	doc_491521501740_item	2448291	et	3	main
tunnusel	doc_491521501740_item	2448293	et	3	main
kolm	doc_491521501740_item	2448295	et	3	main
vihkama	doc_491521501740_item	2448325	et	3	main
tegevust	doc_491521501740_item	2448330	et	4	main
otsustama	doc_491521501740_item	2448331	et	3	main
määrama	doc_491521501740_item	2448333	et	3	main
püüdma	doc_491521501740_item	2448334	et	3	main
katsuma	doc_491521501740_item	2448335	et	3	main
keelama	doc_491521501740_item	2448336	et	3	main
takistama	doc_491521501740_item	2448337	et	3	main
ähvardama	doc_491521501740_item	2448338	et	3	main
julgima	doc_491521501740_item	2448339	et	4	main
mõtlema	doc_491521501740_item	2448347	et	3	main
179-180	doc_491521501740_item	2448354	et	2	main
nt	doc_491521501740_item	2448371	et	4	main
mida	doc_491521501740_item	2448378	et	4	main
metslang	doc_491521501740_item	2448386	et	3	main
da-infinitiivi	doc_491521501740_item	2448389	et	4	main
inessiiv	doc_491521501740_item	2448390	et	3	main
või	doc_491521501740_item	2448397	et	4	main
комнате	doc_491521501740_item	2448424	et	2	main
nt	doc_491521501740_item	2448454	et	4	main
selle	doc_491521501740_item	2448456	et	4	main
peale	doc_491521501740_item	2448457	et	4	main
nt	doc_491521501740_item	2448461	et	4	main
nt	doc_491521501740_item	2448466	et	4	main
jüri	doc_491521501740_item	2448467	et	4	main
jõuda	doc_491521501740_item	2448472	et	3	main
nt	doc_491521501740_item	2448474	et	4	main
panna	doc_491521501740_item	2448479	et	4	main
erelt	doc_491521501740_item	2448480	et	4	main
202	doc_491521501740_item	2448482	et	2	main
infinitiiv	doc_491521501740_item	2448487	et	3	main
kõrvuti	doc_491521501740_item	2448022	et	3	main
töötamaks	doc_491521501740_item	2448024	et	4	main
hästi	doc_491521501740_item	2448026	et	3	main
tuleb	doc_491521501740_item	2448036	et	3	main
otstarbemäärusena	doc_491521501740_item	2448042	et	3	main
mata-vorm	doc_491521501740_item	2448054	et	3	main
olukorras	doc_491521501740_item	2448061	et	3	main
nt	doc_491521501740_item	2448063	et	4	main
sellele	doc_491521501740_item	2448079	et	4	main
seda	doc_491521501740_item	2448090	et	3	main
mõistet	doc_491521501740_item	2448091	et	3	main
leksikaalselt	doc_491521501740_item	2448092	et	4	main
lauses	doc_491521501740_item	2448093	et	3	main
esineb	doc_491521501740_item	2448094	et	3	main
mata-vorm	doc_491521501740_item	2448095	et	3	main
peamiselt	doc_491521501740_item	2448096	et	4	main
absoluutse	doc_491521501740_item	2448097	et	3	main
kaasusena	doc_491521501740_item	2448098	et	3	main
seostub	doc_491521501740_item	2448099	et	3	main
aga	doc_491521501740_item	2448100	et	3	main
mõne	doc_491521501740_item	2448101	et	3	main
üksiku	doc_491521501740_item	2448102	et	3	main
verbiga	doc_491521501740_item	2448103	et	3	main
nagu	doc_491521501740_item	2448104	et	3	main
jätma	doc_491521501740_item	2448105	et	3	main
jääma	doc_491521501740_item	2448106	et	4	main
olema	doc_491521501740_item	2448107	et	4	main
pidama	doc_491521501740_item	2448108	et	4	main
unustama	doc_491521501740_item	2448109	et	3	main
nt	doc_491521501740_item	2448110	et	4	main
vennal	doc_491521501740_item	2448111	et	3	main
jäi	doc_491521501740_item	2448112	et	3	main
osa	doc_491521501740_item	2448113	et	4	main
heina	doc_491521501740_item	2448114	et	4	main
niitmata	doc_491521501740_item	2448115	et	4	main
у	doc_491521501740_item	2448116	et	2	main
брата	doc_491521501740_item	2448117	et	2	main
часть	doc_491521501740_item	2448118	et	2	main
сена	doc_491521501740_item	2448119	et	2	main
осталась	doc_491521501740_item	2448120	et	2	main
гость	doc_491521501740_item	2448130	et	2	main
vaatamata	doc_491521501740_item	2448142	et	4	main
пошел	doc_491521501740_item	2448147	et	2	main
lahendamata	doc_491521501740_item	2448154	et	4	main
nad	doc_491521501740_item	2448163	et	3	main
kinni	doc_491521501740_item	2448165	et	3	main
если	doc_491521501740_item	2448167	et	2	main
не	doc_491521501740_item	2448170	et	2	main
они	doc_491521501740_item	2448173	et	2	main
поймали	doc_491521501740_item	2448176	et	2	main
puhata	doc_491521501740_item	2448030	et	4	main
lauses	doc_491521501740_item	2448040	et	3	main
abessiiv	doc_491521501740_item	2448053	et	3	main
on	doc_491521501740_item	2448069	et	4	main
vene	doc_491521501740_item	2448076	et	4	main
keeles	doc_491521501740_item	2448077	et	4	main
partitsiibi	doc_491521501740_item	2448080	et	3	main
gerundiivi	doc_491521501740_item	2448082	et	4	main
harva	doc_491521501740_item	2448085	et	4	main
infinitiiv	doc_491521501740_item	2448087	et	3	main
külaline	doc_491521501740_item	2448131	et	4	main
tuli	doc_491521501740_item	2448132	et	4	main
он	doc_491521501740_item	2448146	et	2	main
оглядываясь	doc_491521501740_item	2448150	et	2	main
oleks	doc_491521501740_item	2448162	et	3	main
2003	doc_491521501740_item	2448179	et	2	main
mis	doc_491521501740_item	2448191	et	4	main
väljendavad	doc_491521501740_item	2448192	et	4	main
tegevuse	doc_491521501740_item	2448193	et	4	main
algust	doc_491521501740_item	2448194	et	4	main
asuma	doc_491521501740_item	2448195	et	3	main
hakkama	doc_491521501740_item	2448196	et	3	main
jääma	doc_491521501740_item	2448197	et	4	main
jäi	doc_491521501740_item	2448198	et	3	main
raadiot	doc_491521501740_item	2448199	et	3	main
kuulama	doc_491521501740_item	2448200	et	3	main
liikumist	doc_491521501740_item	2448201	et	4	main
või	doc_491521501740_item	2448202	et	4	main
asutust	doc_491521501740_item	2448203	et	4	main
ruumis	doc_491521501740_item	2448204	et	4	main
kui	doc_491521501740_item	2448205	et	3	main
infinitiiviga	doc_491521501740_item	2448206	et	3	main
väljendatud	doc_491521501740_item	2448207	et	4	main
tegevus	doc_491521501740_item	2448208	et	4	main
on	doc_491521501740_item	2448209	et	4	main
lõppeesmärgiks	doc_491521501740_item	2448210	et	3	main
astuma	doc_491521501740_item	2448211	et	3	main
lendama	doc_491521501740_item	2448213	et	3	main
hüppama	doc_491521501740_item	2448212	et	3	main
istuma	doc_491521501740_item	2448214	et	3	main
istus	doc_491521501740_item	2448215	et	4	main
puhkama	doc_491521501740_item	2448216	et	3	main
tegevust	doc_491521501740_item	2448217	et	4	main
mis	doc_491521501740_item	2448218	et	4	main
on	doc_491521501740_item	2448219	et	4	main
infinitiiviga	doc_491521501740_item	2448220	et	3	main
tahte	doc_491521501740_item	2448232	et	4	main
käsk	doc_491521501740_item	2448234	et	3	main
nõusolek	doc_491521501740_item	2448235	et	3	main
paratamatust	doc_491521501740_item	2448248	et	4	main
üks	doc_491521501740_item	2448263	et	3	main
mida	doc_491521501740_item	2448265	et	4	main
tunnuse	doc_491521501740_item	2448269	et	3	main
jutustama	doc_491521501740_item	2448275	et	3	main
aga	doc_491521501740_item	2448279	et	3	main
päll	doc_491521501740_item	2448283	et	3	main
176	doc_491521501740_item	2448285	et	2	main
on	doc_491521501740_item	2448287	et	4	main
himustama	doc_491521501740_item	2448322	et	3	main
tahtelist	doc_491521501740_item	2448329	et	4	main
käskima	doc_491521501740_item	2448332	et	4	main
107	doc_491521501740_item	2448180	et	2	main
203-204	doc_491521501740_item	2448183	et	2	main
tegevuse	doc_491521501740_item	2448222	et	4	main
ehmatama	doc_491521501740_item	2448226	et	3	main
ehmatas	doc_491521501740_item	2448227	et	3	main
meele	doc_491521501740_item	2448230	et	4	main
meelitas	doc_491521501740_item	2448241	et	4	main
vajalikkust	doc_491521501740_item	2448246	et	4	main
pääsema	doc_491521501740_item	2448250	et	4	main
sattuma	doc_491521501740_item	2448251	et	3	main
ette	doc_491521501740_item	2448252	et	4	main
aimamata	doc_491521501740_item	2448253	et	4	main
sattus	doc_491521501740_item	2448254	et	3	main
lisades	doc_491521501740_item	2448267	et	4	main
ma	doc_491521501740_item	2448268	et	3	main
ette	doc_491521501740_item	2448270	et	4	main
ta	doc_491521501740_item	2448271	et	4	main
kasutatakse	doc_491521501740_item	2448281	et	3	main
1962	doc_491521501740_item	2448284	et	2	main
da-infinitiivil	doc_491521501740_item	2448286	et	3	main
mille	doc_491521501740_item	2448292	et	3	main
julgustama	doc_491521501740_item	2448321	et	3	main
kartma	doc_491521501740_item	2448327	et	3	main
raatsima	doc_491521501740_item	2448328	et	3	main
mõttelist	doc_491521501740_item	2448341	et	4	main
mõistma	doc_491521501740_item	2448345	et	3	main
pärima	doc_491521501740_item	2448348	et	3	main
hinnangut	doc_491521501740_item	2448349	et	3	main
maksma	doc_491521501740_item	2448350	et	3	main
1962	doc_491521501740_item	2448353	et	2	main
kasutatakse	doc_491521501740_item	2448356	et	3	main
küsimuses	doc_491521501740_item	2448358	et	4	main
kuidas	doc_491521501740_item	2448364	et	3	main
kuhu	doc_491521501740_item	2448366	et	3	main
kust	doc_491521501740_item	2448372	et	4	main
nt	doc_491521501740_item	2448375	et	4	main
kuulata	doc_491521501740_item	2448381	et	4	main
nt	doc_491521501740_item	2448383	et	4	main
gerundiiv	doc_491521501740_item	2448391	et	4	main
tähistab	doc_491521501740_item	2448392	et	3	main
predikaadiga	doc_491521501740_item	2448393	et	3	main
samaaegselt	doc_491521501740_item	2448394	et	4	main
в	doc_491521501740_item	2448423	et	2	main
käändelised	doc_491521501740_item	2448440	et	4	main
vormid	doc_491521501740_item	2448441	et	4	main
võivad	doc_491521501740_item	2448442	et	4	main
esineda	doc_491521501740_item	2448443	et	3	main
alusena	doc_491521501740_item	2448448	et	4	main
määrusena	doc_491521501740_item	2448460	et	3	main
on	doc_491521501740_item	2448470	et	4	main
maris	doc_491521501740_item	2448475	et	3	main
tärkas	doc_491521501740_item	2448476	et	3	main
plehku	doc_491521501740_item	2448478	et	4	main
infinitiivist	doc_491521501740_item	2448485	et	3	main
või	doc_491521501740_item	2448496	et	4	main
vorm	doc_491521501740_item	2448503	et	3	main
kolmas	doc_491521501740_item	2448522	et	3	main
see	doc_491521501740_item	2448531	et	3	main
писать	doc_491521501740_item	2448537	et	2	main
tegumoe	doc_491521501740_item	2448542	et	3	main
näitab	doc_491521501740_item	2448547	et	3	main
verb	doc_491521501740_item	2448549	et	3	main
transitiivne	doc_491521501740_item	2448551	et	3	main
вести	doc_491521501740_item	2448554	et	2	main
intrasitiivne	doc_491521501740_item	2448556	et	4	main
смотреть	doc_491521501740_item	2448559	et	2	main
infinitiivi	doc_491521501740_item	2448563	et	4	main
tunnuseks	doc_491521501740_item	2448564	et	3	main
ть	doc_491521501740_item	2448565	et	2	main
ти	doc_491521501740_item	2448575	et	2	main
ja	doc_491521501740_item	2448577	et	3	main
järel	doc_491521501740_item	2448579	et	4	main
пеку	doc_491521501740_item	2448588	et	2	main
erelt	doc_491521501740_item	2448181	et	4	main
mölder	doc_491521501740_item	2448184	et	3	main
ma-infinitiiviga	doc_491521501740_item	2448187	et	3	main
tavaliselt	doc_491521501740_item	2448189	et	4	main
tegusõnad	doc_491521501740_item	2448190	et	3	main
lapsed	doc_491521501740_item	2448242	et	3	main
tegevuse	doc_491521501740_item	2448244	et	4	main
võimalikkust	doc_491521501740_item	2448245	et	4	main
pidama	doc_491521501740_item	2448249	et	4	main
1962	doc_491521501740_item	2448258	et	2	main
ma-infinitiivil	doc_491521501740_item	2448260	et	3	main
vorm	doc_491521501740_item	2448264	et	3	main
aktiivis	doc_491521501740_item	2448288	et	3	main
vormi	doc_491521501740_item	2448290	et	4	main
da	doc_491521501740_item	2448297	et	4	main
ta	doc_491521501740_item	2448298	et	4	main
ja	doc_491521501740_item	2448299	et	3	main
a	doc_491521501740_item	2448300	et	4	main
ja	doc_491521501740_item	2448301	et	3	main
des-vorm	doc_491521501740_item	2448302	et	3	main
da-infinitiiviga	doc_491521501740_item	2448303	et	3	main
koos	doc_491521501740_item	2448304	et	4	main
käivad	doc_491521501740_item	2448305	et	4	main
reeglina	doc_491521501740_item	2448306	et	3	main
tegusõnad	doc_491521501740_item	2448307	et	3	main
mis	doc_491521501740_item	2448308	et	4	main
väljendavad	doc_491521501740_item	2448309	et	4	main
tegevuse	doc_491521501740_item	2448310	et	4	main
võimalikkust	doc_491521501740_item	2448311	et	4	main
või	doc_491521501740_item	2448312	et	4	main
võimatust	doc_491521501740_item	2448313	et	4	main
võima	doc_491521501740_item	2448314	et	3	main
suutma	doc_491521501740_item	2448315	et	3	main
jäksama	doc_491521501740_item	2448316	et	4	main
kannatama	doc_491521501740_item	2448317	et	3	main
tundelist	doc_491521501740_item	2448318	et	4	main
tegevust	doc_491521501740_item	2448319	et	4	main
armastama	doc_491521501740_item	2448320	et	3	main
ihaldama	doc_491521501740_item	2448323	et	3	main
unistama	doc_491521501740_item	2448324	et	3	main
põlgama	doc_491521501740_item	2448326	et	3	main
tohtima	doc_491521501740_item	2448340	et	3	main
oskama	doc_491521501740_item	2448344	et	3	main
da-infinitiivi	doc_491521501740_item	2448355	et	4	main
koos	doc_491521501740_item	2448359	et	4	main
nagu	doc_491521501740_item	2448361	et	3	main
nt	doc_491521501740_item	2448367	et	4	main
kuhu	doc_491521501740_item	2448368	et	3	main
minna	doc_491521501740_item	2448369	et	3	main
kust	doc_491521501740_item	2448370	et	4	main
keda	doc_491521501740_item	2448374	et	4	main
keda	doc_491521501740_item	2448376	et	4	main
uskuda	doc_491521501740_item	2448377	et	3	main
mida	doc_491521501740_item	2448380	et	4	main
miks	doc_491521501740_item	2448382	et	4	main
105	doc_491521501740_item	2448388	et	2	main
vene	doc_491521501740_item	2448400	et	4	main
varianti	doc_491521501740_item	2448296	et	4	main
tegevust	doc_491521501740_item	2448343	et	4	main
päll	doc_491521501740_item	2448352	et	3	main
kaalutlevas-kavandavas	doc_491521501740_item	2448357	et	4	main
küsisõnadega	doc_491521501740_item	2448360	et	3	main
nt	doc_491521501740_item	2448363	et	4	main
vastata	doc_491521501740_item	2448365	et	4	main
otsida	doc_491521501740_item	2448373	et	4	main
miks	doc_491521501740_item	2448384	et	4	main
tegevust	doc_491521501740_item	2448396	et	4	main
olukorras	doc_491521501740_item	2448398	et	3	main
olemist	doc_491521501740_item	2448399	et	4	main
keeles	doc_491521501740_item	2448401	et	4	main
vastab	doc_491521501740_item	2448402	et	3	main
sellele	doc_491521501740_item	2448403	et	4	main
gerundiiv	doc_491521501740_item	2448404	et	4	main
деепричастие	doc_491521501740_item	2448405	et	2	main
nt	doc_491521501740_item	2448406	et	4	main
õues	doc_491521501740_item	2448407	et	4	main
olles	doc_491521501740_item	2448408	et	3	main
mängisid	doc_491521501740_item	2448409	et	4	main
lapsed	doc_491521501740_item	2448410	et	3	main
находясь	doc_491521501740_item	2448411	et	2	main
во	doc_491521501740_item	2448412	et	2	main
дворе	doc_491521501740_item	2448413	et	2	main
дети	doc_491521501740_item	2448414	et	2	main
игрили	doc_491521501740_item	2448415	et	2	main
istus	doc_491521501740_item	2448417	et	4	main
ta	doc_491521501740_item	2448416	et	4	main
toas	doc_491521501740_item	2448418	et	3	main
raamatut	doc_491521501740_item	2448419	et	3	main
lugemas	doc_491521501740_item	2448420	et	4	main
он	doc_491521501740_item	2448421	et	2	main
книгу	doc_491521501740_item	2448426	et	2	main
seismas	doc_491521501740_item	2448430	et	3	main
стоя	doc_491521501740_item	2448433	et	2	main
1967	doc_491521501740_item	2448435	et	2	main
da-infinitiiv	doc_491521501740_item	2448437	et	3	main
ja	doc_491521501740_item	2448438	et	3	main
nimisõnalise	doc_491521501740_item	2448446	et	4	main
lauseliikmena	doc_491521501740_item	2448447	et	3	main
kübar	doc_491521501740_item	2448462	et	3	main
kanda	doc_491521501740_item	2448464	et	4	main
ainus	doc_491521501740_item	2448468	et	4	main
kihk	doc_491521501740_item	2448477	et	3	main
vene	doc_491521501740_item	2448484	et	4	main
форма	doc_491521501740_item	2448490	et	2	main
mis	doc_491521501740_item	2448493	et	4	main
väljendab	doc_491521501740_item	2448494	et	3	main
tegevust	doc_491521501740_item	2448495	et	4	main
see	doc_491521501740_item	2448502	et	3	main
ei	doc_491521501740_item	2448504	et	4	main
tegevuse	doc_491521501740_item	2448506	et	4	main
hoopis	doc_491521501740_item	2448521	et	3	main
isik	doc_491521501740_item	2448523	et	3	main
näita	doc_491521501740_item	2448526	et	4	main
kõneviisi	doc_491521501740_item	2448527	et	4	main
isiku	doc_491521501740_item	2448528	et	3	main
soo	doc_491521501740_item	2448529	et	4	main
passiivse	doc_491521501740_item	2448541	et	3	main
kas	doc_491521501740_item	2448548	et	3	main
лежать	doc_491521501740_item	2448557	et	2	main
tegevust	doc_491521501740_item	2448342	et	4	main
taipama	doc_491521501740_item	2448346	et	3	main
tasuma	doc_491521501740_item	2448351	et	3	main
kuidas	doc_491521501740_item	2448362	et	3	main
nt	doc_491521501740_item	2448379	et	4	main
oodata	doc_491521501740_item	2448385	et	4	main
2003	doc_491521501740_item	2448387	et	2	main
toimuvat	doc_491521501740_item	2448395	et	4	main
сидел	doc_491521501740_item	2448422	et	2	main
lõunasime	doc_491521501740_item	2448428	et	4	main
обедали	doc_491521501740_item	2448432	et	2	main
97	doc_491521501740_item	2448436	et	2	main
mis	doc_491521501740_item	2448444	et	4	main
nt	doc_491521501740_item	2448449	et	4	main
katsu	doc_491521501740_item	2448455	et	4	main
mõelda	doc_491521501740_item	2448459	et	4	main
öeldistäietena	doc_491521501740_item	2448465	et	4	main
edasi	doc_491521501740_item	2448471	et	3	main
täiedina	doc_491521501740_item	2448473	et	4	main
2000	doc_491521501740_item	2448481	et	2	main
lähemalt	doc_491521501740_item	2448483	et	4	main
vene	doc_491521501740_item	2448486	et	4	main
ehk	doc_491521501740_item	2448488	et	3	main
on	doc_491521501740_item	2448491	et	4	main
бояться	doc_491521501740_item	2448501	et	2	main
määra	doc_491521501740_item	2448505	et	4	main
ei	doc_491521501740_item	2448525	et	4	main
aspekti	doc_491521501740_item	2448534	et	4	main
perfektiivset	doc_491521501740_item	2448535	et	3	main
написать	doc_491521501740_item	2448538	et	2	main
строить	doc_491521501740_item	2448543	et	2	main
samuti	doc_491521501740_item	2448546	et	3	main
красить	doc_491521501740_item	2448552	et	2	main
думать	doc_491521501740_item	2448558	et	2	main
kõige	doc_491521501740_item	2448560	et	4	main
играть	doc_491521501740_item	2448571	et	2	main
sufiks	doc_491521501740_item	2448574	et	3	main
konsonandi	doc_491521501740_item	2448576	et	3	main
идти	doc_491521501740_item	2448580	et	2	main
harva	doc_491521501740_item	2448583	et	4	main
tüvel	doc_491521501740_item	2448587	et	3	main
ja	doc_491521501740_item	2448592	et	3	main
язык	doc_491521501740_item	2448596	et	2	main
vene	doc_491521501740_item	2448622	et	4	main
on	doc_491521501740_item	2448624	et	4	main
aga	doc_491521501740_item	2448625	et	3	main
raskemaks	doc_491521501740_item	2448632	et	4	main
tõlge	doc_491521501740_item	2448638	et	3	main
tähelepanu	doc_491521501740_item	2448641	et	4	main
teadmisi	doc_491521501740_item	2448644	et	4	main
eesti	doc_491521501740_item	2448648	et	4	main
ja	doc_491521501740_item	2448650	et	3	main
ja	doc_491521501740_item	2448664	et	3	main
kumba	doc_491521501740_item	2448667	et	4	main
igas	doc_491521501740_item	2448670	et	3	main
видел	doc_491521501740_item	2448679	et	2	main
вернулись	doc_491521501740_item	2448688	et	2	main
забыл	doc_491521501740_item	2448697	et	2	main
keelde	doc_491521501740_item	2448704	et	4	main
teeb	doc_491521501740_item	2448721	et	3	main
keele	doc_491521501740_item	2448723	et	4	main
kõnelejale	doc_491521501740_item	2448724	et	4	main
raskeks	doc_491521501740_item	2448725	et	3	main
kokkulangevused	doc_491521501740_item	2448727	et	3	main
osalised	doc_491521501740_item	2448729	et	4	main
sõnade	doc_491521501740_item	2448733	et	3	main
tähendustes	doc_491521501740_item	2448736	et	4	main
ja	doc_491521501740_item	2448737	et	3	main
kasutamises	doc_491521501740_item	2448738	et	4	main
samuti	doc_491521501740_item	2448739	et	3	main
teiste	doc_491521501740_item	2448742	et	4	main
ekslik	doc_491521501740_item	2448745	et	3	main
üldistamine	doc_491521501740_item	2448748	et	4	main
võivad	doc_491521501740_item	2448751	et	4	main
nii	doc_491521501740_item	2448756	et	3	main
eesti	doc_491521501740_item	2448757	et	4	main
keeles	doc_491521501740_item	2448771	et	4	main
ühes	doc_491521501740_item	2448776	et	4	main
olemas	doc_491521501740_item	2448778	et	4	main
ning	doc_491521501740_item	2448779	et	3	main
keeles	doc_491521501740_item	2448784	et	4	main
читая	doc_491521501740_item	2448425	et	2	main
me	doc_491521501740_item	2448427	et	4	main
püsti	doc_491521501740_item	2448429	et	3	main
мы	doc_491521501740_item	2448431	et	2	main
mölder	doc_491521501740_item	2448434	et	3	main
selle	doc_491521501740_item	2448439	et	4	main
tahes	doc_491521501740_item	2448445	et	4	main
mõtelda	doc_491521501740_item	2448450	et	4	main
on	doc_491521501740_item	2448451	et	4	main
mõnus	doc_491521501740_item	2448452	et	4	main
sihitisena	doc_491521501740_item	2448453	et	3	main
mitte	doc_491521501740_item	2448458	et	3	main
kõlbab	doc_491521501740_item	2448463	et	3	main
siht	doc_491521501740_item	2448469	et	3	main
protsessi	doc_491521501740_item	2448497	et	4	main
читать	doc_491521501740_item	2448499	et	2	main
aega	doc_491521501740_item	2448507	et	4	main
tegevuse	doc_491521501740_item	2448508	et	4	main
suhtumist	doc_491521501740_item	2448509	et	4	main
tegelikkusega	doc_491521501740_item	2448510	et	4	main
tegijate	doc_491521501740_item	2448511	et	4	main
arvu	doc_491521501740_item	2448512	et	4	main
ega	doc_491521501740_item	2448513	et	3	main
seda	doc_491521501740_item	2448514	et	3	main
kas	doc_491521501740_item	2448515	et	3	main
subjekt	doc_491521501740_item	2448516	et	3	main
on	doc_491521501740_item	2448517	et	4	main
kõneleja	doc_491521501740_item	2448518	et	4	main
kuulaja	doc_491521501740_item	2448519	et	4	main
või	doc_491521501740_item	2448520	et	4	main
kategooriat	doc_491521501740_item	2448530	et	3	main
väljendab	doc_491521501740_item	2448532	et	3	main
ainult	doc_491521501740_item	2448533	et	4	main
ja	doc_491521501740_item	2448540	et	3	main
строиться	doc_491521501740_item	2448544	et	2	main
on	doc_491521501740_item	2448550	et	4	main
мыть	doc_491521501740_item	2448553	et	2	main
tihedamini	doc_491521501740_item	2448561	et	4	main
on	doc_491521501740_item	2448562	et	4	main
nt	doc_491521501740_item	2448568	et	4	main
уметь	doc_491521501740_item	2448570	et	2	main
esineb	doc_491521501740_item	2448573	et	3	main
нести	doc_491521501740_item	2448581	et	2	main
чь	doc_491521501740_item	2448584	et	2	main
могу	doc_491521501740_item	2448590	et	2	main
русский	doc_491521501740_item	2448595	et	2	main
infinitiivi	doc_491521501740_item	2448621	et	4	main
keeles	doc_491521501740_item	2448623	et	4	main
eesti	doc_491521501740_item	2448633	et	4	main
infinitiivide	doc_491521501740_item	2448634	et	3	main
käändevormid	doc_491521501740_item	2448635	et	4	main
täpne	doc_491521501740_item	2448637	et	3	main
erilist	doc_491521501740_item	2448640	et	4	main
ja	doc_491521501740_item	2448642	et	3	main
eesti	doc_491521501740_item	2448658	et	4	main
kasutusreegleid	doc_491521501740_item	2448663	et	3	main
otsustada	doc_491521501740_item	2448666	et	3	main
я	doc_491521501740_item	2448678	et	2	main
пользуется	doc_491521501740_item	2448682	et	2	main
работы	doc_491521501740_item	2448691	et	2	main
ученик	doc_491521501740_item	2448696	et	2	main
tõlkides	doc_491521501740_item	2448700	et	4	main
tohi	doc_491521501740_item	2448706	et	4	main
unustada	doc_491521501740_item	2448707	et	3	main
infinitiivi	doc_491521501740_item	2448708	et	4	main
неопределенная	doc_491521501740_item	2448489	et	2	main
verbivorm	doc_491521501740_item	2448492	et	4	main
смотреть	doc_491521501740_item	2448498	et	2	main
находиться	doc_491521501740_item	2448500	et	2	main
infinitiiv	doc_491521501740_item	2448524	et	3	main
imperfektiivset	doc_491521501740_item	2448536	et	3	main
aktiivse	doc_491521501740_item	2448539	et	3	main
see	doc_491521501740_item	2448545	et	3	main
või	doc_491521501740_item	2448555	et	4	main
vokaali	doc_491521501740_item	2448566	et	4	main
järel	doc_491521501740_item	2448567	et	4	main
samuti	doc_491521501740_item	2448572	et	3	main
й	doc_491521501740_item	2448578	et	2	main
выйти	doc_491521501740_item	2448582	et	2	main
к-	doc_491521501740_item	2448585	et	2	main
мочь	doc_491521501740_item	2448591	et	2	main
энциклопедия	doc_491521501740_item	2448594	et	2	main
1997	doc_491521501740_item	2448597	et	2	main
probleemid	doc_491521501740_item	2448598	et	3	main
ja	doc_491521501740_item	2448599	et	3	main
ebamugavused	doc_491521501740_item	2448600	et	4	main
infinitiivi	doc_491521501740_item	2448601	et	4	main
sisaldavate	doc_491521501740_item	2448602	et	4	main
fraaside	doc_491521501740_item	2448603	et	3	main
ja	doc_491521501740_item	2448604	et	3	main
lausete	doc_491521501740_item	2448605	et	4	main
tõlges	doc_491521501740_item	2448606	et	3	main
eesti	doc_491521501740_item	2448607	et	4	main
keelest	doc_491521501740_item	2448608	et	4	main
vene	doc_491521501740_item	2448609	et	4	main
keelde	doc_491521501740_item	2448610	et	4	main
ja	doc_491521501740_item	2448611	et	3	main
vastupidi	doc_491521501740_item	2448612	et	3	main
tekivad	doc_491521501740_item	2448613	et	3	main
selle	doc_491521501740_item	2448614	et	4	main
tõttu	doc_491521501740_item	2448615	et	4	main
et	doc_491521501740_item	2448616	et	3	main
eesti	doc_491521501740_item	2448617	et	4	main
keeles	doc_491521501740_item	2448618	et	4	main
on	doc_491521501740_item	2448619	et	4	main
kaks	doc_491521501740_item	2448620	et	3	main
ainult	doc_491521501740_item	2448626	et	4	main
üks	doc_491521501740_item	2448627	et	3	main
infinitiiv	doc_491521501740_item	2448628	et	3	main
olukorda	doc_491521501740_item	2448629	et	4	main
muudavad	doc_491521501740_item	2448630	et	4	main
veel	doc_491521501740_item	2448631	et	4	main
infinitiivi	doc_491521501740_item	2448646	et	4	main
tõlgija	doc_491521501740_item	2448656	et	4	main
tunneb	doc_491521501740_item	2448657	et	3	main
infinitiivi	doc_491521501740_item	2448659	et	4	main
vormide	doc_491521501740_item	2448660	et	3	main
tähendusi	doc_491521501740_item	2448661	et	4	main
oskab	doc_491521501740_item	2448665	et	3	main
ma	doc_491521501740_item	2448674	et	3	main
spikerdamas	doc_491521501740_item	2448677	et	3	main
шпоргалкой	doc_491521501740_item	2448683	et	2	main
tagasi	doc_491521501740_item	2448685	et	3	main
leidmata	doc_491521501740_item	2448687	et	4	main
ülesande	doc_491521501740_item	2448694	et	4	main
vene	doc_491521501740_item	2448701	et	4	main
писать	doc_491521501740_item	2448569	et	2	main
г-lõpulisel	doc_491521501740_item	2448586	et	2	main
печь	doc_491521501740_item	2448589	et	2	main
чи	doc_491521501740_item	2448593	et	2	main
nõuab	doc_491521501740_item	2448639	et	3	main
olemasolu	doc_491521501740_item	2448647	et	4	main
ühe	doc_491521501740_item	2448651	et	4	main
ja	doc_491521501740_item	2448662	et	3	main
olukorras	doc_491521501740_item	2448672	et	3	main
sõpra	doc_491521501740_item	2448676	et	4	main
как	doc_491521501740_item	2448680	et	2	main
pöördusime	doc_491521501740_item	2448684	et	3	main
найдя	doc_491521501740_item	2448690	et	2	main
unustas	doc_491521501740_item	2448693	et	3	main
lahendamata	doc_491521501740_item	2448695	et	4	main
задачу	doc_491521501740_item	2448699	et	2	main
ja	doc_491521501740_item	2448728	et	3	main
emakeele	doc_491521501740_item	2448740	et	4	main
keelte	doc_491521501740_item	2448743	et	3	main
vead	doc_491521501740_item	2448750	et	4	main
olla	doc_491521501740_item	2448752	et	3	main
asjaolust	doc_491521501740_item	2448754	et	3	main
erinevad	doc_491521501740_item	2448767	et	4	main
üksteisest	doc_491521501740_item	2448768	et	4	main
ning	doc_491521501740_item	2448772	et	3	main
keeles	doc_491521501740_item	2448782	et	4	main
leksikaalselt	doc_491521501740_item	2448793	et	4	main
või	doc_491521501740_item	2448794	et	4	main
süntaktiliselt	doc_491521501740_item	2448795	et	4	main
on	doc_491521501740_item	2448803	et	4	main
samuti	doc_491521501740_item	2448824	et	3	main
tähendus	doc_491521501740_item	2448830	et	4	main
infinitiivi	doc_491521501740_item	2448831	et	4	main
valik	doc_491521501740_item	2448832	et	3	main
tahetakse	doc_491521501740_item	2448836	et	4	main
ei	doc_491521501740_item	2448842	et	4	main
otstarbe	doc_491521501740_item	2448864	et	3	main
пришел	doc_491521501740_item	2448870	et	2	main
сказать	doc_491521501740_item	2448872	et	2	main
teistel	doc_491521501740_item	2448873	et	4	main
kandjaks	doc_491521501740_item	2448888	et	4	main
infinitiivid	doc_491521501740_item	2448902	et	3	main
modaalverbide	doc_491521501740_item	2448905	et	4	main
liikumist	doc_491521501740_item	2448906	et	4	main
tähistavate	doc_491521501740_item	2448907	et	4	main
verbide	doc_491521501740_item	2448908	et	3	main
nii	doc_491521501740_item	2448922	et	3	main
liikumise	doc_491521501740_item	2448933	et	4	main
väljendamine	doc_491521501740_item	2448934	et	4	main
ei	doc_491521501740_item	2448958	et	4	main
va	doc_491521501740_item	2448964	et	3	main
ja	doc_491521501740_item	2448967	et	3	main
eesti	doc_491521501740_item	2448973	et	4	main
sõidan	doc_491521501740_item	2448978	et	3	main
vene	doc_491521501740_item	2448986	et	4	main
keelde	doc_491521501740_item	2448987	et	4	main
leksikaalselt	doc_491521501740_item	2449022	et	4	main
vene	doc_491521501740_item	2449024	et	4	main
keeles	doc_491521501740_item	2449025	et	4	main
saab	doc_491521501740_item	2449026	et	3	main
juhul	doc_491521501740_item	2449028	et	3	main
või	doc_491521501740_item	2449032	et	4	main
nt	doc_491521501740_item	2449034	et	4	main
за	doc_491521501740_item	2449035	et	2	main
морозить	doc_491521501740_item	2449036	et	2	main
раз	doc_491521501740_item	2449037	et	2	main
за	doc_491521501740_item	2449039	et	2	main
рас	doc_491521501740_item	2449041	et	2	main
täistähenduslikust	doc_491521501740_item	2449054	et	4	main
omadussõnast	doc_491521501740_item	2449057	et	4	main
määrsõnast	doc_491521501740_item	2449058	et	4	main
vene	doc_491521501740_item	2449087	et	4	main
keeles	doc_491521501740_item	2449088	et	4	main
finiitse	doc_491521501740_item	2449093	et	3	main
verbi	doc_491521501740_item	2449094	et	4	main
vorm	doc_491521501740_item	2449095	et	3	main
kusjuures	doc_491521501740_item	2449096	et	3	main
algust	doc_491521501740_item	2449097	et	4	main
за	doc_491521501740_item	2449103	et	2	main
за	doc_491521501740_item	2449107	et	2	main
ainult	doc_491521501740_item	2449120	et	4	main
mille	doc_491521501740_item	2448636	et	3	main
sügavamaid	doc_491521501740_item	2448643	et	4	main
kahe	doc_491521501740_item	2448645	et	3	main
keeles	doc_491521501740_item	2448649	et	4	main
vene	doc_491521501740_item	2448652	et	4	main
keeles	doc_491521501740_item	2448653	et	4	main
eeldab	doc_491521501740_item	2448654	et	3	main
et	doc_491521501740_item	2448655	et	3	main
neist	doc_491521501740_item	2448668	et	4	main
kasutada	doc_491521501740_item	2448669	et	3	main
konkreetses	doc_491521501740_item	2448671	et	3	main
nt	doc_491521501740_item	2448673	et	4	main
nägin	doc_491521501740_item	2448675	et	3	main
друг	doc_491521501740_item	2448681	et	2	main
tööd	doc_491521501740_item	2448686	et	4	main
не	doc_491521501740_item	2448689	et	2	main
õpilane	doc_491521501740_item	2448692	et	3	main
решить	doc_491521501740_item	2448698	et	2	main
ei	doc_491521501740_item	2448705	et	4	main
käändevorme	doc_491521501740_item	2448709	et	4	main
muidu	doc_491521501740_item	2448710	et	3	main
tõlge	doc_491521501740_item	2448711	et	3	main
on	doc_491521501740_item	2448712	et	4	main
ebatäpne	doc_491521501740_item	2448713	et	3	main
või	doc_491521501740_item	2448714	et	4	main
hoopis	doc_491521501740_item	2448715	et	3	main
vigade	doc_491521501740_item	2448717	et	3	main
põhjused	doc_491521501740_item	2448718	et	3	main
eesti	doc_491521501740_item	2448719	et	4	main
vale	doc_491521501740_item	2448716	et	4	main
keele	doc_491521501740_item	2448720	et	4	main
vene	doc_491521501740_item	2448722	et	4	main
emakeelega	doc_491521501740_item	2448731	et	3	main
ja	doc_491521501740_item	2448734	et	3	main
põhjustatud	doc_491521501740_item	2448753	et	4	main
mis	doc_491521501740_item	2448766	et	4	main
mis	doc_491521501740_item	2448774	et	4	main
puuduvad	doc_491521501740_item	2448780	et	4	main
teises	doc_491521501740_item	2448781	et	4	main
peamiselt	doc_491521501740_item	2448792	et	4	main
kategooriate	doc_491521501740_item	2448799	et	3	main
tähendus	doc_491521501740_item	2448802	et	4	main
sõltub	doc_491521501740_item	2448833	et	3	main
et	doc_491521501740_item	2448868	et	3	main
öelda	doc_491521501740_item	2448869	et	4	main
чтобы	doc_491521501740_item	2448871	et	2	main
vene	doc_491521501740_item	2448876	et	4	main
kasutatakse	doc_491521501740_item	2448878	et	3	main
tõlgitakse	doc_491521501740_item	2448880	et	4	main
fraasi	doc_491521501740_item	2448881	et	4	main
kusjuures	doc_491521501740_item	2448885	et	3	main
tähenduse	doc_491521501740_item	2448887	et	4	main
on	doc_491521501740_item	2448889	et	4	main
172	doc_491521501740_item	2448895	et	2	main
et	doc_491521501740_item	2448898	et	3	main
ja	doc_491521501740_item	2448909	et	3	main
terve	doc_491521501740_item	2448917	et	4	main
aspektuaalne	doc_491521501740_item	2448919	et	4	main
ka	doc_491521501740_item	2448925	et	3	main
vene	doc_491521501740_item	2448926	et	4	main
keeles	doc_491521501740_item	2448927	et	4	main
keeles	doc_491521501740_item	2448936	et	4	main
eesti	doc_491521501740_item	2448947	et	4	main
ma-infinitiivi	doc_491521501740_item	2448953	et	4	main
suunitluse	doc_491521501740_item	2448962	et	4	main
koju	doc_491521501740_item	2448979	et	3	main
sellised	doc_491521501740_item	2448981	et	4	main
keele	doc_491521501740_item	2448983	et	4	main
tõlgitakse	doc_491521501740_item	2448985	et	4	main
keelest	doc_491521501740_item	2448702	et	4	main
eesti	doc_491521501740_item	2448703	et	4	main
ja	doc_491521501740_item	2448741	et	3	main
ja	doc_491521501740_item	2448747	et	3	main
et	doc_491521501740_item	2448755	et	3	main
ka	doc_491521501740_item	2448759	et	3	main
keele	doc_491521501740_item	2448761	et	4	main
grammatikas	doc_491521501740_item	2448762	et	3	main
on	doc_491521501740_item	2448763	et	4	main
mõned	doc_491521501740_item	2448764	et	3	main
kategooriad	doc_491521501740_item	2448765	et	3	main
kahes	doc_491521501740_item	2448770	et	4	main
eesti	doc_491521501740_item	2448783	et	4	main
aspekti	doc_491521501740_item	2448786	et	4	main
aspekti	doc_491521501740_item	2448789	et	4	main
mõistet	doc_491521501740_item	2448790	et	3	main
väljendatakse	doc_491521501740_item	2448791	et	3	main
aktiivsuse	doc_491521501740_item	2448796	et	4	main
ja	doc_491521501740_item	2448797	et	3	main
sisaldava	doc_491521501740_item	2448821	et	4	main
laiendatud	doc_491521501740_item	2448826	et	4	main
tähendus	doc_491521501740_item	2448828	et	4	main
tähendusest	doc_491521501740_item	2448834	et	4	main
sõltumatu	doc_491521501740_item	2448839	et	4	main
ole	doc_491521501740_item	2448843	et	4	main
sõltumatu	doc_491521501740_item	2448849	et	4	main
делать	doc_491521501740_item	2448856	et	2	main
kuhu	doc_491521501740_item	2448857	et	3	main
куда	doc_491521501740_item	2448859	et	2	main
põimlause	doc_491521501740_item	2448862	et	4	main
juhtumitel	doc_491521501740_item	2448874	et	3	main
keeles	doc_491521501740_item	2448877	et	4	main
infinitiivi	doc_491521501740_item	2448879	et	4	main
verbi	doc_491521501740_item	2448890	et	4	main
vorm	doc_491521501740_item	2448892	et	3	main
1994	doc_491521501740_item	2448894	et	2	main
analüüs	doc_491521501740_item	2448896	et	3	main
eesti	doc_491521501740_item	2448899	et	4	main
ja	doc_491521501740_item	2448900	et	3	main
vene	doc_491521501740_item	2448901	et	4	main
faasiverbidega	doc_491521501740_item	2448910	et	4	main
infinitiiviga	doc_491521501740_item	2448911	et	3	main
laiendatud	doc_491521501740_item	2448912	et	4	main
verbide	doc_491521501740_item	2448913	et	3	main
leksikaalne	doc_491521501740_item	2448914	et	3	main
tähendus	doc_491521501740_item	2448915	et	4	main
konstruktsiooni	doc_491521501740_item	2448918	et	4	main
infinitiivi	doc_491521501740_item	2448928	et	4	main
valikut	doc_491521501740_item	2448929	et	3	main
eslon	doc_491521501740_item	2448930	et	4	main
1990	doc_491521501740_item	2448931	et	2	main
40-41	doc_491521501740_item	2448932	et	2	main
näidata	doc_491521501740_item	2448939	et	4	main
infinitiivi	doc_491521501740_item	2448941	et	4	main
väljendamiseks	doc_491521501740_item	2448952	et	4	main
ning	doc_491521501740_item	2448955	et	3	main
kohta	doc_491521501740_item	2448963	et	4	main
идти	doc_491521501740_item	2448969	et	2	main
nt	doc_491521501740_item	2448976	et	4	main
verbi	doc_491521501740_item	2448988	et	4	main
finiitsete	doc_491521501740_item	2448989	et	3	main
vormidega	doc_491521501740_item	2448990	et	3	main
sel	doc_491521501740_item	2449027	et	3	main
keeles	doc_491521501740_item	2449044	et	4	main
sõnast	doc_491521501740_item	2449055	et	4	main
nimisõnast	doc_491521501740_item	2449056	et	4	main
või	doc_491521501740_item	2449059	et	4	main
sisaldav	doc_491521501740_item	2449090	et	4	main
või	doc_491521501740_item	2449098	et	4	main
горелся	doc_491521501740_item	2449104	et	2	main
снулся	doc_491521501740_item	2449110	et	2	main
пел	doc_491521501740_item	2449114	et	2	main
keeles	doc_491521501740_item	2449116	et	4	main
juhul	doc_491521501740_item	2449119	et	3	main
esimese	doc_491521501740_item	2449122	et	3	main
hakkama	doc_491521501740_item	2449126	et	3	main
направился	doc_491521501740_item	2449132	et	2	main
asus	doc_491521501740_item	2449136	et	4	main
принялась	doc_491521501740_item	2449138	et	2	main
vene	doc_491521501740_item	2449151	et	4	main
osalised	doc_491521501740_item	2448726	et	4	main
erinevused	doc_491521501740_item	2448730	et	4	main
võrreldes	doc_491521501740_item	2448732	et	3	main
vormide	doc_491521501740_item	2448735	et	3	main
mõju	doc_491521501740_item	2448744	et	4	main
lihtsustamine	doc_491521501740_item	2448746	et	4	main
infinitiivi	doc_491521501740_item	2448749	et	4	main
kui	doc_491521501740_item	2448758	et	3	main
vene	doc_491521501740_item	2448760	et	4	main
nenedes	doc_491521501740_item	2448769	et	4	main
kategooriad	doc_491521501740_item	2448773	et	3	main
on	doc_491521501740_item	2448775	et	4	main
keeles	doc_491521501740_item	2448777	et	4	main
puudub	doc_491521501740_item	2448785	et	3	main
morfoloogiline	doc_491521501740_item	2448787	et	4	main
kategooria	doc_491521501740_item	2448788	et	4	main
väljendusviisid	doc_491521501740_item	2448800	et	3	main
antud	doc_491521501740_item	2448804	et	4	main
keeltes	doc_491521501740_item	2448805	et	3	main
erinevad	doc_491521501740_item	2448806	et	4	main
eesti	doc_491521501740_item	2448807	et	4	main
keeles	doc_491521501740_item	2448808	et	4	main
on	doc_491521501740_item	2448809	et	4	main
hulk	doc_491521501740_item	2448810	et	3	main
verbe	doc_491521501740_item	2448811	et	3	main
mis	doc_491521501740_item	2448812	et	4	main
lubavad	doc_491521501740_item	2448813	et	4	main
mõlema	doc_491521501740_item	2448814	et	3	main
infinitiivi	doc_491521501740_item	2448815	et	4	main
kasutust	doc_491521501740_item	2448816	et	4	main
äärmiselt	doc_491521501740_item	2448817	et	4	main
tähtis	doc_491521501740_item	2448818	et	4	main
on	doc_491521501740_item	2448819	et	4	main
infinitiivi	doc_491521501740_item	2448820	et	4	main
passiivsuse	doc_491521501740_item	2448798	et	4	main
ja	doc_491521501740_item	2448801	et	3	main
tähendus	doc_491521501740_item	2448823	et	4	main
infintiiviga	doc_491521501740_item	2448825	et	4	main
verbi	doc_491521501740_item	2448827	et	4	main
mida	doc_491521501740_item	2448835	et	4	main
väljendada	doc_491521501740_item	2448838	et	3	main
infinitiivi	doc_491521501740_item	2448840	et	4	main
eesti	doc_491521501740_item	2448844	et	4	main
keelele	doc_491521501740_item	2448845	et	4	main
iseloomulik	doc_491521501740_item	2448846	et	3	main
tavaliselt	doc_491521501740_item	2448847	et	4	main
esineb	doc_491521501740_item	2448848	et	3	main
идти	doc_491521501740_item	2448860	et	2	main
kõrvallauses	doc_491521501740_item	2448863	et	3	main
eesti	doc_491521501740_item	2448882	et	4	main
finiitne	doc_491521501740_item	2448891	et	3	main
eslon	doc_491521501740_item	2448893	et	4	main
näitab	doc_491521501740_item	2448897	et	3	main
ühilduvad	doc_491521501740_item	2448903	et	4	main
tavaliselt	doc_491521501740_item	2448904	et	4	main
tähendus	doc_491521501740_item	2448920	et	4	main
liikumist	doc_491521501740_item	2448937	et	4	main
saab	doc_491521501740_item	2448938	et	3	main
kas	doc_491521501740_item	2448940	et	3	main
sisaldava	doc_491521501740_item	2448942	et	4	main
fraasiga	doc_491521501740_item	2448943	et	3	main
või	doc_491521501740_item	2448944	et	4	main
üksiku	doc_491521501740_item	2448945	et	3	main
verbiga	doc_491521501740_item	2448946	et	3	main
liikumise	doc_491521501740_item	2448951	et	4	main
kasutamine	doc_491521501740_item	2448954	et	4	main
see	doc_491521501740_item	2448956	et	3	main
vorm	doc_491521501740_item	2448957	et	3	main
kanna	doc_491521501740_item	2448959	et	4	main
informatsiooni	doc_491521501740_item	2448960	et	4	main
ходить	doc_491521501740_item	2448966	et	2	main
keeles	doc_491521501740_item	2448974	et	4	main
kontekst	doc_491521501740_item	2448975	et	3	main
konstruktsiooni	doc_491521501740_item	2448822	et	4	main
konstruktsiooni	doc_491521501740_item	2448829	et	4	main
verbikonstruktsiooniga	doc_491521501740_item	2448837	et	4	main
kasutamine	doc_491521501740_item	2448841	et	4	main
infinitiiv	doc_491521501740_item	2448850	et	3	main
küsimustes	doc_491521501740_item	2448851	et	4	main
nagu	doc_491521501740_item	2448852	et	3	main
mida	doc_491521501740_item	2448853	et	4	main
teha	doc_491521501740_item	2448854	et	3	main
что	doc_491521501740_item	2448855	et	2	main
minna	doc_491521501740_item	2448858	et	3	main
ja	doc_491521501740_item	2448861	et	3	main
tähendusega	doc_491521501740_item	2448865	et	4	main
nt	doc_491521501740_item	2448866	et	4	main
tulin	doc_491521501740_item	2448867	et	3	main
kui	doc_491521501740_item	2448875	et	3	main
keelde	doc_491521501740_item	2448883	et	4	main
tegusõnafraasiga	doc_491521501740_item	2448884	et	3	main
leksikaalse	doc_491521501740_item	2448886	et	3	main
ja	doc_491521501740_item	2448916	et	3	main
määravad	doc_491521501740_item	2448921	et	4	main
eesti	doc_491521501740_item	2448923	et	4	main
kui	doc_491521501740_item	2448924	et	3	main
vene	doc_491521501740_item	2448935	et	4	main
keelele	doc_491521501740_item	2448948	et	4	main
on	doc_491521501740_item	2448949	et	4	main
iseloomulik	doc_491521501740_item	2448950	et	3	main
liikumise	doc_491521501740_item	2448961	et	4	main
käima	doc_491521501740_item	2448965	et	4	main
minema	doc_491521501740_item	2448968	et	3	main
liikumise	doc_491521501740_item	2448970	et	4	main
suunda	doc_491521501740_item	2448971	et	4	main
näitab	doc_491521501740_item	2448972	et	3	main
ma	doc_491521501740_item	2448977	et	3	main
tööle	doc_491521501740_item	2448980	et	3	main
eesti	doc_491521501740_item	2448982	et	4	main
konstruktsioonid	doc_491521501740_item	2448984	et	3	main
prepositsiooni	doc_491521501740_item	2448991	et	4	main
abil	doc_491521501740_item	2448992	et	4	main
harva	doc_491521501740_item	2448993	et	4	main
infinitiivi	doc_491521501740_item	2448994	et	4	main
abil	doc_491521501740_item	2448995	et	4	main
nt	doc_491521501740_item	2448996	et	4	main
läks	doc_491521501740_item	2448997	et	3	main
viima	doc_491521501740_item	2448998	et	3	main
побежал	doc_491521501740_item	2448999	et	2	main
jooksim	doc_491521501740_item	2449000	et	4	main
е	doc_491521501740_item	2449001	et	2	main
minema	doc_491521501740_item	2449002	et	3	main
убежали	doc_491521501740_item	2449003	et	2	main
sõidan	doc_491521501740_item	2449004	et	3	main
vahetama	doc_491521501740_item	2449005	et	3	main
еду	doc_491521501740_item	2449006	et	2	main
менять	doc_491521501740_item	2449007	et	2	main
eslon	doc_491521501740_item	2449008	et	4	main
1990	doc_491521501740_item	2449009	et	2	main
50-51	doc_491521501740_item	2449010	et	2	main
konstruktsioonid	doc_491521501740_item	2449011	et	3	main
eesti	doc_491521501740_item	2449013	et	4	main
keeles	doc_491521501740_item	2449014	et	4	main
väljendatakse	doc_491521501740_item	2449015	et	3	main
seisundisse	doc_491521501740_item	2449016	et	3	main
faasiverbidega	doc_491521501740_item	2449012	et	4	main
sattumist	doc_491521501740_item	2449017	et	4	main
või	doc_491521501740_item	2449018	et	4	main
protsessi	doc_491521501740_item	2449019	et	4	main
algust	doc_491521501740_item	2449020	et	4	main
piirduda	doc_491521501740_item	2449029	et	3	main
väljendatakse	doc_491521501740_item	2449045	et	3	main
mis	doc_491521501740_item	2449048	et	4	main
kasutamise	doc_491521501740_item	2449031	et	4	main
vahetusega	doc_491521501740_item	2449033	et	4	main
морозить	doc_491521501740_item	2449038	et	2	main
крутить	doc_491521501740_item	2449040	et	2	main
крутить	doc_491521501740_item	2449042	et	2	main
eesti	doc_491521501740_item	2449043	et	4	main
sedasama	doc_491521501740_item	2449046	et	4	main
nt	doc_491521501740_item	2449061	et	4	main
lehte	doc_491521501740_item	2449062	et	4	main
minema	doc_491521501740_item	2449063	et	3	main
покрыться	doc_491521501740_item	2449064	et	2	main
raagu	doc_491521501740_item	2449066	et	4	main
листвой	doc_491521501740_item	2449065	et	2	main
jääma	doc_491521501740_item	2449067	et	4	main
облететь	doc_491521501740_item	2449068	et	2	main
pihlak	doc_491521501740_item	2449069	et	4	main
1991b	doc_491521501740_item	2449070	et	4	main
40	doc_491521501740_item	2449071	et	2	main
seisma	doc_491521501740_item	2449072	et	3	main
jääma	doc_491521501740_item	2449073	et	4	main
остановиться	doc_491521501740_item	2449074	et	2	main
peamiselt	doc_491521501740_item	2449021	et	4	main
kusjuures	doc_491521501740_item	2449023	et	3	main
prepositsiooni	doc_491521501740_item	2449030	et	4	main
sõnaühenditega	doc_491521501740_item	2449047	et	3	main
koosnevad	doc_491521501740_item	2449049	et	4	main
vormist	doc_491521501740_item	2449052	et	4	main
ja	doc_491521501740_item	2449053	et	3	main
infinitiivist	doc_491521501740_item	2449060	et	3	main
sõitma	doc_491521501740_item	2449075	et	3	main
hakkama	doc_491521501740_item	2449076	et	3	main
faasiverbidega	doc_491521501740_item	2449078	et	4	main
inhoatiivide	doc_491521501740_item	2449080	et	3	main
ja	doc_491521501740_item	2449081	et	3	main
ühineb	doc_491521501740_item	2449086	et	3	main
infinitiivi	doc_491521501740_item	2449089	et	4	main
nt	doc_491521501740_item	2449102	et	4	main
горел	doc_491521501740_item	2449106	et	2	main
начал	doc_491521501740_item	2449111	et	2	main
verbi	doc_491521501740_item	2449050	et	4	main
finiitsest	doc_491521501740_item	2449051	et	3	main
поехать	doc_491521501740_item	2449077	et	2	main
täpsemalt	doc_491521501740_item	2449079	et	4	main
tegevuse	doc_491521501740_item	2449082	et	4	main
lõppu	doc_491521501740_item	2449083	et	4	main
või	doc_491521501740_item	2449092	et	4	main
prepositsioon	doc_491521501740_item	2449101	et	4	main
с	doc_491521501740_item	2449105	et	2	main
снул	doc_491521501740_item	2449108	et	2	main
петь	doc_491521501740_item	2449112	et	2	main
eesti	doc_491521501740_item	2449115	et	4	main
kasutatakse	doc_491521501740_item	2449117	et	3	main
sel	doc_491521501740_item	2449118	et	3	main
komponendina	doc_491521501740_item	2449123	et	3	main
reeglina	doc_491521501740_item	2449125	et	3	main
jääma	doc_491521501740_item	2449128	et	4	main
nt	doc_491521501740_item	2449129	et	4	main
seisma	doc_491521501740_item	2449134	et	3	main
pesema	doc_491521501740_item	2449137	et	3	main
стирку	doc_491521501740_item	2449140	et	2	main
otsa	doc_491521501740_item	2449142	et	4	main
уставились	doc_491521501740_item	2449144	et	2	main
seoses	doc_491521501740_item	2449145	et	4	main
sellega	doc_491521501740_item	2449146	et	3	main
keelde	doc_491521501740_item	2449152	et	4	main
1	doc_491521501740_item	2449182	et	2	main
nt	doc_491521501740_item	2449218	et	4	main
mille	doc_491521501740_item	2449221	et	3	main
vormi	doc_491521501740_item	2449226	et	4	main
tähistades	doc_491521501740_item	2449229	et	3	main
tegevuse	doc_491521501740_item	2449231	et	4	main
algust	doc_491521501740_item	2449232	et	4	main
растить	doc_491521501740_item	2449241	et	2	main
52	doc_491521501740_item	2449244	et	2	main
modaalverbidega	doc_491521501740_item	2449246	et	4	main
vene	doc_491521501740_item	2449247	et	4	main
abil	doc_491521501740_item	2449257	et	4	main
harvem	doc_491521501740_item	2449264	et	4	main
kohustust	doc_491521501740_item	2449272	et	4	main
looma	doc_491521501740_item	2449277	et	4	main
nt	doc_491521501740_item	2449279	et	4	main
oskust	doc_491521501740_item	2449284	et	3	main
suutlikkustvõimetust	doc_491521501740_item	2449321	et	4	main
suudan	doc_491521501740_item	2449323	et	3	main
nt	doc_491521501740_item	2449337	et	4	main
püüan	doc_491521501740_item	2449338	et	3	main
naljatada	doc_491521501740_item	2449339	et	3	main
katsus	doc_491521501740_item	2449340	et	4	main
välja	doc_491521501740_item	2449341	et	4	main
minna	doc_491521501740_item	2449349	et	3	main
otsustada	doc_491521501740_item	2449351	et	3	main
lubamist	doc_491521501740_item	2449352	et	4	main
jääda	doc_491521501740_item	2449364	et	4	main
tahtmise	doc_491521501740_item	2449366	et	4	main
tahtmist	doc_491521501740_item	2449371	et	4	main
muuta	doc_491521501740_item	2449372	et	4	main
oli	doc_491521501740_item	2449373	et	3	main
ei	doc_491521501740_item	2449380	et	4	main
pesta	doc_491521501740_item	2449431	et	4	main
43	doc_491521501740_item	2449436	et	2	main
neist	doc_491521501740_item	2449449	et	4	main
tegevus	doc_491521501740_item	2449470	et	4	main
alguse	doc_491521501740_item	2449472	et	3	main
eelnenud	doc_491521501740_item	2449474	et	4	main
tegevuse	doc_491521501740_item	2449475	et	4	main
tarvitse	doc_491521501740_item	2449480	et	4	main
olla	doc_491521501740_item	2449490	et	3	main
õpetaja	doc_491521501740_item	2449500	et	4	main
laskis	doc_491521501740_item	2449518	et	4	main
mängida	doc_491521501740_item	2449522	et	3	main
на	doc_491521501740_item	2449526	et	2	main
дворе	doc_491521501740_item	2449530	et	2	main
tuppa	doc_491521501740_item	2449533	et	3	main
raamatut	doc_491521501740_item	2449534	et	3	main
оставлю	doc_491521501740_item	2449539	et	2	main
комнате	doc_491521501740_item	2449542	et	2	main
jätan	doc_491521501740_item	2449545	et	3	main
lugeda	doc_491521501740_item	2449548	et	3	main
почитать	doc_491521501740_item	2449552	et	2	main
õpetaja	doc_491521501740_item	2449557	et	4	main
väljendavate	doc_491521501740_item	2449084	et	4	main
verbidega	doc_491521501740_item	2449085	et	3	main
verbifraas	doc_491521501740_item	2449091	et	4	main
lõppu	doc_491521501740_item	2449099	et	4	main
näitab	doc_491521501740_item	2449100	et	3	main
про	doc_491521501740_item	2449109	et	2	main
за	doc_491521501740_item	2449113	et	2	main
ma-infinitiivi	doc_491521501740_item	2449121	et	4	main
hakkas	doc_491521501740_item	2449130	et	3	main
остановился	doc_491521501740_item	2449135	et	2	main
за	doc_491521501740_item	2449139	et	2	main
jäid	doc_491521501740_item	2449141	et	4	main
vahtima	doc_491521501740_item	2449143	et	3	main
keelest	doc_491521501740_item	2449150	et	4	main
tõlkida	doc_491521501740_item	2449166	et	3	main
ainult	doc_491521501740_item	2449169	et	4	main
koos	doc_491521501740_item	2449227	et	4	main
tuleva	doc_491521501740_item	2449230	et	4	main
будут	doc_491521501740_item	2449236	et	2	main
kasvatama	doc_491521501740_item	2449239	et	4	main
keeles	doc_491521501740_item	2449248	et	4	main
saab	doc_491521501740_item	2449249	et	3	main
modaalse	doc_491521501740_item	2449250	et	3	main
ma-infinitiiviga	doc_491521501740_item	2449265	et	3	main
verbidega	doc_491521501740_item	2449269	et	3	main
nt	doc_491521501740_item	2449273	et	4	main
sundisid	doc_491521501740_item	2449280	et	4	main
vastutama	doc_491521501740_item	2449283	et	3	main
saab	doc_491521501740_item	2449286	et	3	main
anda	doc_491521501740_item	2449328	et	3	main
puudumist	doc_491521501740_item	2449346	et	4	main
saame	doc_491521501740_item	2449350	et	4	main
nt	doc_491521501740_item	2449359	et	4	main
lugeda	doc_491521501740_item	2449361	et	3	main
tahtmist	doc_491521501740_item	2449365	et	4	main
puudu	doc_491521501740_item	2449367	et	4	main
ei	doc_491521501740_item	2449369	et	4	main
tahtmine	doc_491521501740_item	2449374	et	4	main
sünni	doc_491521501740_item	2449381	et	4	main
nt	doc_491521501740_item	2449386	et	4	main
laulda	doc_491521501740_item	2449422	et	4	main
halb	doc_491521501740_item	2449423	et	3	main
lugeda	doc_491521501740_item	2449424	et	3	main
töötada	doc_491521501740_item	2449426	et	3	main
magada	doc_491521501740_item	2449428	et	3	main
vara	doc_491521501740_item	2449432	et	4	main
1990	doc_491521501740_item	2449435	et	2	main
da-infinitiivi	doc_491521501740_item	2449477	et	4	main
puhul	doc_491521501740_item	2449478	et	4	main
ei	doc_491521501740_item	2449479	et	4	main
seotud	doc_491521501740_item	2449489	et	4	main
nendele	doc_491521501740_item	2449493	et	4	main
nt	doc_491521501740_item	2449496	et	4	main
õue	doc_491521501740_item	2449502	et	4	main
hakkasid	doc_491521501740_item	2449505	et	4	main
järel	doc_491521501740_item	2449507	et	4	main
mängima	doc_491521501740_item	2449508	et	3	main
урок	doc_491521501740_item	2449510	et	2	main
учеников	doc_491521501740_item	2449513	et	2	main
играть	doc_491521501740_item	2449516	et	2	main
õpetaja	doc_491521501740_item	2449519	et	4	main
õues	doc_491521501740_item	2449521	et	4	main
позволил	doc_491521501740_item	2449524	et	2	main
играть	doc_491521501740_item	2449528	et	2	main
vennale	doc_491521501740_item	2449546	et	3	main
брату	doc_491521501740_item	2449550	et	2	main
näiteks	doc_491521501740_item	2449556	et	4	main
ma-	doc_491521501740_item	2449565	et	3	main
ja	doc_491521501740_item	2449566	et	3	main
da-infinitiiv	doc_491521501740_item	2449567	et	3	main
verbidega	doc_491521501740_item	2449568	et	3	main
näitavad	doc_491521501740_item	2449570	et	4	main
tegevuse	doc_491521501740_item	2449571	et	4	main
kasutatakse	doc_491521501740_item	2449604	et	3	main
või	doc_491521501740_item	2449612	et	4	main
1985b	doc_491521501740_item	2449619	et	4	main
62-93	doc_491521501740_item	2449620	et	2	main
esinevad	doc_491521501740_item	2449124	et	4	main
ja	doc_491521501740_item	2449127	et	3	main
jäi	doc_491521501740_item	2449133	et	3	main
tekkivad	doc_491521501740_item	2449147	et	4	main
tõlges	doc_491521501740_item	2449148	et	3	main
eesti	doc_491521501740_item	2449149	et	4	main
1	doc_491521501740_item	2449157	et	2	main
verbiga	doc_491521501740_item	2449170	et	3	main
vene	doc_491521501740_item	2449183	et	4	main
finiitsete	doc_491521501740_item	2449184	et	3	main
verbide	doc_491521501740_item	2449185	et	3	main
vorme	doc_491521501740_item	2449186	et	3	main
mis	doc_491521501740_item	2449187	et	4	main
tähistavad	doc_491521501740_item	2449188	et	4	main
tegevuse	doc_491521501740_item	2449189	et	4	main
algust	doc_491521501740_item	2449190	et	4	main
või	doc_491521501740_item	2449191	et	4	main
lõppu	doc_491521501740_item	2449192	et	4	main
saab	doc_491521501740_item	2449193	et	3	main
tõlkida	doc_491521501740_item	2449194	et	3	main
analüütilise	doc_491521501740_item	2449195	et	3	main
konstruktsiooniga	doc_491521501740_item	2449196	et	3	main
hakkama	doc_491521501740_item	2449197	et	3	main
jääma	doc_491521501740_item	2449198	et	4	main
infinitiiv	doc_491521501740_item	2449199	et	3	main
nt	doc_491521501740_item	2449200	et	4	main
hakkas	doc_491521501740_item	2449201	et	3	main
armastama	doc_491521501740_item	2449202	et	3	main
полюбил	doc_491521501740_item	2449203	et	2	main
hakkas	doc_491521501740_item	2449204	et	3	main
kaarte	doc_491521501740_item	2449205	et	4	main
segama	doc_491521501740_item	2449206	et	3	main
перетасовал	doc_491521501740_item	2449207	et	2	main
jäi	doc_491521501740_item	2449208	et	3	main
magama	doc_491521501740_item	2449209	et	3	main
заснул	doc_491521501740_item	2449210	et	2	main
1	doc_491521501740_item	2449211	et	2	main
keeles	doc_491521501740_item	2449213	et	4	main
vene	doc_491521501740_item	2449212	et	4	main
on	doc_491521501740_item	2449214	et	4	main
analüütiline	doc_491521501740_item	2449215	et	3	main
tuleviku	doc_491521501740_item	2449216	et	4	main
vorm	doc_491521501740_item	2449217	et	3	main
astuma	doc_491521501740_item	2449131	et	3	main
ja	doc_491521501740_item	2449153	et	3	main
vastupidi	doc_491521501740_item	2449154	et	3	main
lahknevused	doc_491521501740_item	2449156	et	4	main
faasiverbid	doc_491521501740_item	2449159	et	4	main
начал	doc_491521501740_item	2449161	et	2	main
koos	doc_491521501740_item	2449163	et	4	main
infinitiiviga	doc_491521501740_item	2449164	et	3	main
saab	doc_491521501740_item	2449165	et	3	main
keelde	doc_491521501740_item	2449168	et	4	main
hakkama	doc_491521501740_item	2449171	et	3	main
puhuma	doc_491521501740_item	2449174	et	3	main
jooma	doc_491521501740_item	2449175	et	4	main
suitsetama	doc_491521501740_item	2449176	et	4	main
начал	doc_491521501740_item	2449177	et	2	main
дуть	doc_491521501740_item	2449178	et	2	main
пить	doc_491521501740_item	2449179	et	2	main
принялся	doc_491521501740_item	2449180	et	2	main
курить	doc_491521501740_item	2449181	et	2	main
kasutatakse	doc_491521501740_item	2449223	et	3	main
hakkama	doc_491521501740_item	2449225	et	3	main
nt	doc_491521501740_item	2449233	et	4	main
буду	doc_491521501740_item	2449240	et	2	main
eslon	doc_491521501740_item	2449242	et	4	main
konstruktsioonid	doc_491521501740_item	2449245	et	3	main
näidata	doc_491521501740_item	2449252	et	4	main
infinitiiviga	doc_491521501740_item	2449253	et	3	main
konteksti	doc_491521501740_item	2449254	et	4	main
või	doc_491521501740_item	2449255	et	4	main
eesti	doc_491521501740_item	2449258	et	4	main
tõlgitakse	doc_491521501740_item	2449260	et	4	main
neid	doc_491521501740_item	2449261	et	4	main
mis	doc_491521501740_item	2449270	et	4	main
väljendavad	doc_491521501740_item	2449271	et	4	main
ootama	doc_491521501740_item	2449281	et	3	main
nt	doc_491521501740_item	2449285	et	4	main
hakkama	doc_491521501740_item	2449287	et	3	main
nõudma	doc_491521501740_item	2449289	et	3	main
nt	doc_491521501740_item	2449291	et	4	main
nt	doc_491521501740_item	2449322	et	4	main
andeks	doc_491521501740_item	2449327	et	3	main
nt	doc_491521501740_item	2449330	et	4	main
saada	doc_491521501740_item	2449332	et	4	main
püüame	doc_491521501740_item	2449333	et	3	main
vahet	doc_491521501740_item	2449334	et	3	main
teha	doc_491521501740_item	2449335	et	3	main
püüdu	doc_491521501740_item	2449336	et	4	main
rabelda	doc_491521501740_item	2449342	et	4	main
õiguse	doc_491521501740_item	2449343	et	4	main
või	doc_491521501740_item	2449345	et	4	main
nt	doc_491521501740_item	2449353	et	4	main
võib	doc_491521501740_item	2449354	et	3	main
nt	doc_491521501740_item	2449368	et	4	main
öelda	doc_491521501740_item	2449375	et	4	main
lugeda	doc_491521501740_item	2449388	et	3	main
nt	doc_491521501740_item	2449390	et	4	main
mõned	doc_491521501740_item	2449155	et	3	main
vene	doc_491521501740_item	2449158	et	4	main
стал	doc_491521501740_item	2449160	et	2	main
принялся	doc_491521501740_item	2449162	et	2	main
eesti	doc_491521501740_item	2449167	et	4	main
nt	doc_491521501740_item	2449172	et	4	main
hakkas	doc_491521501740_item	2449173	et	3	main
буду	doc_491521501740_item	2449219	et	2	main
играть	doc_491521501740_item	2449220	et	2	main
faasiverbi	doc_491521501740_item	2449224	et	4	main
ma-infinitiiviga	doc_491521501740_item	2449228	et	3	main
hakkan	doc_491521501740_item	2449238	et	3	main
1990	doc_491521501740_item	2449243	et	2	main
rõhupartikli	doc_491521501740_item	2449256	et	3	main
keelde	doc_491521501740_item	2449259	et	4	main
ma-infinitiivi	doc_491521501740_item	2449266	et	4	main
kasutatakse	doc_491521501740_item	2449267	et	3	main
modaalsete	doc_491521501740_item	2449268	et	3	main
olema	doc_491521501740_item	2449275	et	4	main
tõlkes	doc_491521501740_item	2449222	et	3	main
hakkavad	doc_491521501740_item	2449234	et	4	main
heietama	doc_491521501740_item	2449235	et	3	main
вспоминать	doc_491521501740_item	2449237	et	2	main
tähenduse	doc_491521501740_item	2449251	et	4	main
tavaliselt	doc_491521501740_item	2449262	et	4	main
da-infinitiiviga	doc_491521501740_item	2449263	et	3	main
peab	doc_491521501740_item	2449274	et	4	main
peame	doc_491521501740_item	2449276	et	4	main
sunnitust	doc_491521501740_item	2449278	et	4	main
pandi	doc_491521501740_item	2449282	et	4	main
õppis	doc_491521501740_item	2449288	et	3	main
valmisolekut	doc_491521501740_item	2449290	et	3	main
valmis	doc_491521501740_item	2449292	et	4	main
peksma	doc_491521501740_item	2449293	et	3	main
valmistusid	doc_491521501740_item	2449294	et	4	main
sõitma	doc_491521501740_item	2449295	et	3	main
harjumust	doc_491521501740_item	2449296	et	4	main
nt	doc_491521501740_item	2449297	et	4	main
oli	doc_491521501740_item	2449298	et	3	main
harjunud	doc_491521501740_item	2449299	et	4	main
näivust	doc_491521501740_item	2449301	et	4	main
alistuma	doc_491521501740_item	2449300	et	3	main
nt	doc_491521501740_item	2449302	et	4	main
tundus	doc_491521501740_item	2449303	et	3	main
tühi	doc_491521501740_item	2449304	et	3	main
olema	doc_491521501740_item	2449305	et	4	main
da-infinitiiv	doc_491521501740_item	2449306	et	3	main
liidub	doc_491521501740_item	2449307	et	4	main
tavaliselt	doc_491521501740_item	2449308	et	4	main
modaalverbidega	doc_491521501740_item	2449309	et	4	main
mis	doc_491521501740_item	2449310	et	4	main
näitavad	doc_491521501740_item	2449311	et	4	main
võimalikkust	doc_491521501740_item	2449312	et	4	main
võimatust	doc_491521501740_item	2449313	et	4	main
nt	doc_491521501740_item	2449314	et	4	main
võivad	doc_491521501740_item	2449315	et	4	main
suurendada	doc_491521501740_item	2449316	et	3	main
oli	doc_491521501740_item	2449317	et	3	main
võimatu	doc_491521501740_item	2449318	et	4	main
aru	doc_491521501740_item	2449319	et	4	main
saada	doc_491521501740_item	2449320	et	4	main
ei	doc_491521501740_item	2449325	et	4	main
proovib	doc_491521501740_item	2449331	et	3	main
võite	doc_491521501740_item	2449348	et	4	main
tohi	doc_491521501740_item	2449363	et	4	main
tegevust	doc_491521501740_item	2449378	et	4	main
nt	doc_491521501740_item	2449379	et	4	main
ei	doc_491521501740_item	2449382	et	4	main
rääkida	doc_491521501740_item	2449384	et	3	main
tegelda	doc_491521501740_item	2449433	et	4	main
hulk	doc_491521501740_item	2449438	et	3	main
verbe	doc_491521501740_item	2449439	et	3	main
teha	doc_491521501740_item	2449324	et	3	main
suutnud	doc_491521501740_item	2449326	et	4	main
katset	doc_491521501740_item	2449329	et	3	main
olemasolu	doc_491521501740_item	2449344	et	4	main
nt	doc_491521501740_item	2449347	et	4	main
saada	doc_491521501740_item	2449355	et	4	main
lubati	doc_491521501740_item	2449356	et	3	main
tuua	doc_491521501740_item	2449357	et	3	main
keeldu	doc_491521501740_item	2449358	et	4	main
keelatakse	doc_491521501740_item	2449360	et	3	main
ei	doc_491521501740_item	2449362	et	4	main
olnud	doc_491521501740_item	2449370	et	4	main
soovitatavat	doc_491521501740_item	2449376	et	4	main
mittesoovitatavat	doc_491521501740_item	2449377	et	3	main
sobi	doc_491521501740_item	2449383	et	4	main
kartust	doc_491521501740_item	2449385	et	3	main
kartis	doc_491521501740_item	2449387	et	3	main
soovitust	doc_491521501740_item	2449389	et	4	main
katsuge	doc_491521501740_item	2449391	et	3	main
leida	doc_491521501740_item	2449392	et	3	main
palvet	doc_491521501740_item	2449393	et	3	main
nt	doc_491521501740_item	2449394	et	4	main
palusid	doc_491521501740_item	2449395	et	4	main
võtta	doc_491521501740_item	2449396	et	3	main
käsku	doc_491521501740_item	2449397	et	4	main
nt	doc_491521501740_item	2449398	et	4	main
käskis	doc_491521501740_item	2449399	et	4	main
teha	doc_491521501740_item	2449400	et	3	main
vajadust	doc_491521501740_item	2449401	et	4	main
nt	doc_491521501740_item	2449402	et	4	main
on	doc_491521501740_item	2449403	et	4	main
vaja	doc_491521501740_item	2449404	et	4	main
otsida	doc_491521501740_item	2449405	et	4	main
on	doc_491521501740_item	2449406	et	4	main
hädavajalik	doc_491521501740_item	2449407	et	3	main
aidata	doc_491521501740_item	2449408	et	4	main
kohustatus	doc_491521501740_item	2449409	et	4	main
nt	doc_491521501740_item	2449410	et	4	main
tuleb	doc_491521501740_item	2449411	et	3	main
alustada	doc_491521501740_item	2449412	et	3	main
samuti	doc_491521501740_item	2449413	et	3	main
kasutatakse	doc_491521501740_item	2449414	et	3	main
da-infinitiivi	doc_491521501740_item	2449415	et	4	main
sõnadega	doc_491521501740_item	2449416	et	3	main
mis	doc_491521501740_item	2449417	et	4	main
annavad	doc_491521501740_item	2449418	et	3	main
hinnangut	doc_491521501740_item	2449419	et	3	main
nt	doc_491521501740_item	2449420	et	4	main
hea	doc_491521501740_item	2449421	et	4	main
kasulik	doc_491521501740_item	2449429	et	3	main
ära	doc_491521501740_item	2449430	et	4	main
kehv	doc_491521501740_item	2449425	et	3	main
mugav	doc_491521501740_item	2449427	et	3	main
on	doc_491521501740_item	2449437	et	4	main
mida	doc_491521501740_item	2449440	et	4	main
ma-	doc_491521501740_item	2449444	et	3	main
da-infinitiiviga	doc_491521501740_item	2449447	et	3	main
eslon	doc_491521501740_item	2449434	et	4	main
kasutada	doc_491521501740_item	2449442	et	3	main
kui	doc_491521501740_item	2449445	et	3	main
millega	doc_491521501740_item	2449455	et	3	main
nii	doc_491521501740_item	2449457	et	3	main
tahetakse	doc_491521501740_item	2449465	et	4	main
näidata	doc_491521501740_item	2449466	et	4	main
et	doc_491521501740_item	2449467	et	3	main
ma-infinitiivis	doc_491521501740_item	2449468	et	3	main
sai	doc_491521501740_item	2449471	et	4	main
teineteisega	doc_491521501740_item	2449486	et	3	main
vene	doc_491521501740_item	2449491	et	4	main
õpilased	doc_491521501740_item	2449501	et	3	main
õpilastel	doc_491521501740_item	2449520	et	4	main
в	doc_491521501740_item	2449541	et	2	main
книгу	doc_491521501740_item	2449544	et	2	main
оставлю	doc_491521501740_item	2449549	et	2	main
98	doc_491521501740_item	2449555	et	2	main
kirjutama	doc_491521501740_item	2449561	et	3	main
tähendus	doc_491521501740_item	2449575	et	4	main
sel	doc_491521501740_item	2449605	et	3	main
verbe	doc_491521501740_item	2449607	et	3	main
tulemuse	doc_491521501740_item	2449613	et	3	main
järgi	doc_491521501740_item	2449614	et	4	main
a	doc_491521501740_item	2449616	et	4	main
pihlaku	doc_491521501740_item	2449617	et	4	main
ja	doc_491521501740_item	2449621	et	3	main
uurimustele	doc_491521501740_item	2449624	et	3	main
1990	doc_491521501740_item	2449626	et	2	main
konstruktsioonid	doc_491521501740_item	2449631	et	3	main
tegevusele	doc_491521501740_item	2449634	et	4	main
nt	doc_491521501740_item	2449639	et	4	main
hõõgus	doc_491521501740_item	2449641	et	4	main
догорал	doc_491521501740_item	2449644	et	2	main
1	doc_491521501740_item	2449648	et	2	main
resultatiivseid	doc_491521501740_item	2449649	et	3	main
ja	doc_491521501740_item	2449650	et	3	main
управились	doc_491521501740_item	2449664	et	2	main
смуул	doc_491521501740_item	2449668	et	2	main
nt	doc_491521501740_item	2449673	et	4	main
et	doc_491521501740_item	2449686	et	3	main
tulemuseks	doc_491521501740_item	2449688	et	3	main
nt	doc_491521501740_item	2449692	et	4	main
end	doc_491521501740_item	2449694	et	4	main
silma	doc_491521501740_item	2449703	et	4	main
идти	doc_491521501740_item	2449723	et	2	main
ekspressiivselt	doc_491521501740_item	2449733	et	4	main
seega	doc_491521501740_item	2449736	et	4	main
vene	doc_491521501740_item	2449738	et	4	main
sõltub	doc_491521501740_item	2449740	et	3	main
terve	doc_491521501740_item	2449741	et	4	main
analüütilise	doc_491521501740_item	2449742	et	3	main
siis	doc_491521501740_item	2449747	et	3	main
eesti	doc_491521501740_item	2449748	et	4	main
selle	doc_491521501740_item	2449766	et	4	main
1991	doc_491521501740_item	2449770	et	2	main
ja	doc_491521501740_item	2449805	et	3	main
kasutusreeglid	doc_491521501740_item	2449806	et	3	main
ei	doc_491521501740_item	2449807	et	4	main
lange	doc_491521501740_item	2449808	et	4	main
sageli	doc_491521501740_item	2449809	et	3	main
kuuluvad	doc_491521501740_item	2449817	et	4	main
neid	doc_491521501740_item	2449820	et	4	main
tihti	doc_491521501740_item	2449823	et	3	main
just	doc_491521501740_item	2449828	et	3	main
2003	doc_491521501740_item	2449835	et	2	main
mis	doc_491521501740_item	2449842	et	4	main
обязанным	doc_491521501740_item	2449849	et	2	main
väljendada	doc_491521501740_item	2449852	et	3	main
kohustuslikkust	doc_491521501740_item	2449862	et	4	main
näitavad	doc_491521501740_item	2449863	et	4	main
pidama	doc_491521501740_item	2449866	et	4	main
kohustatud	doc_491521501740_item	2449868	et	4	main
ei	doc_491521501740_item	2449874	et	4	main
erine	doc_491521501740_item	2449875	et	4	main
nt	doc_491521501740_item	2449880	et	4	main
обязан	doc_491521501740_item	2449888	et	2	main
keeles	doc_491521501740_item	2449892	et	4	main
tulema	doc_491521501740_item	2449899	et	4	main
näiteks	doc_491521501740_item	2449911	et	4	main
tööst	doc_491521501740_item	2449912	et	3	main
saab	doc_491521501740_item	2449441	et	3	main
nii	doc_491521501740_item	2449443	et	3	main
ka	doc_491521501740_item	2449446	et	3	main
kumba	doc_491521501740_item	2449448	et	4	main
valida	doc_491521501740_item	2449450	et	3	main
sõltub	doc_491521501740_item	2449451	et	3	main
erilistest	doc_491521501740_item	2449452	et	4	main
tähendusnjuanssidest	doc_491521501740_item	2449453	et	4	main
da-	doc_491521501740_item	2449458	et	4	main
kui	doc_491521501740_item	2449459	et	3	main
ka	doc_491521501740_item	2449460	et	3	main
kasutatakse	doc_491521501740_item	2449462	et	3	main
kui	doc_491521501740_item	2449464	et	3	main
lõpust	doc_491521501740_item	2449476	et	4	main
predikaatverbis	doc_491521501740_item	2449481	et	4	main
ja	doc_491521501740_item	2449482	et	3	main
da-infinitiivis	doc_491521501740_item	2449483	et	3	main
lõpetanud	doc_491521501740_item	2449497	et	4	main
tunni	doc_491521501740_item	2449498	et	3	main
laskis	doc_491521501740_item	2449499	et	4	main
mängima	doc_491521501740_item	2449503	et	3	main
õuelaskmise	doc_491521501740_item	2449506	et	3	main
отпустил	doc_491521501740_item	2449512	et	2	main
двор	doc_491521501740_item	2449515	et	2	main
vahetundidel	doc_491521501740_item	2449517	et	4	main
verbidega	doc_491521501740_item	2449454	et	3	main
seostub	doc_491521501740_item	2449456	et	3	main
ma-infinitiiv	doc_491521501740_item	2449461	et	3	main
ma-infinitiivi	doc_491521501740_item	2449463	et	4	main
väljendatud	doc_491521501740_item	2449469	et	4	main
vahetult	doc_491521501740_item	2449473	et	4	main
väljendatud	doc_491521501740_item	2449484	et	4	main
tegevused	doc_491521501740_item	2449485	et	4	main
ajaliselt	doc_491521501740_item	2449487	et	4	main
kuidagi	doc_491521501740_item	2449488	et	3	main
keeles	doc_491521501740_item	2449492	et	4	main
vastab	doc_491521501740_item	2449494	et	3	main
infinitiiv	doc_491521501740_item	2449495	et	3	main
õpilased	doc_491521501740_item	2449504	et	3	main
закончив	doc_491521501740_item	2449509	et	2	main
учитель	doc_491521501740_item	2449511	et	2	main
во	doc_491521501740_item	2449514	et	2	main
ученикам	doc_491521501740_item	2449525	et	2	main
переменах	doc_491521501740_item	2449527	et	2	main
jätan	doc_491521501740_item	2449531	et	3	main
lugema	doc_491521501740_item	2449535	et	4	main
vend	doc_491521501740_item	2449536	et	3	main
hakkab	doc_491521501740_item	2449537	et	3	main
lugema	doc_491521501740_item	2449538	et	4	main
брата	doc_491521501740_item	2449540	et	2	main
читать	doc_491521501740_item	2449543	et	2	main
книгу	doc_491521501740_item	2449551	et	2	main
1967	doc_491521501740_item	2449554	et	2	main
palus	doc_491521501740_item	2449558	et	4	main
kirjand	doc_491521501740_item	2449560	et	3	main
mis	doc_491521501740_item	2449569	et	4	main
see	doc_491521501740_item	2449574	et	3	main
keeles	doc_491521501740_item	2449603	et	4	main
toetudes	doc_491521501740_item	2449615	et	3	main
54	doc_491521501740_item	2449627	et	2	main
da-infinitiiviga	doc_491521501740_item	2449632	et	3	main
костер	doc_491521501740_item	2449643	et	2	main
konstruktsioonid	doc_491521501740_item	2449645	et	3	main
nt	doc_491521501740_item	2449654	et	4	main
naised	doc_491521501740_item	2449655	et	3	main
hakkama	doc_491521501740_item	2449659	et	3	main
женщины	doc_491521501740_item	2449662	et	2	main
сеном	doc_491521501740_item	2449666	et	2	main
intensiivset	doc_491521501740_item	2449671	et	3	main
algust	doc_491521501740_item	2449672	et	4	main
pistis	doc_491521501740_item	2449675	et	4	main
rädisema	doc_491521501740_item	2449677	et	4	main
звонко	doc_491521501740_item	2449679	et	2	main
pani	doc_491521501740_item	2449681	et	4	main
3	doc_491521501740_item	2449684	et	2	main
mingi	doc_491521501740_item	2449690	et	4	main
konstruktsioonid	doc_491521501740_item	2449701	et	3	main
готовиться	doc_491521501740_item	2449722	et	2	main
värvitud	doc_491521501740_item	2449734	et	4	main
tähendus	doc_491521501740_item	2449744	et	4	main
infinitiivi	doc_491521501740_item	2449745	et	4	main
ilma	doc_491521501740_item	2449753	et	4	main
andmata	doc_491521501740_item	2449755	et	4	main
hinnangulisust	doc_491521501740_item	2449756	et	4	main
kannab	doc_491521501740_item	2449757	et	3	main
tingitud	doc_491521501740_item	2449764	et	4	main
semantikast	doc_491521501740_item	2449768	et	4	main
on	doc_491521501740_item	2449776	et	4	main
verbide	doc_491521501740_item	2449803	et	3	main
kokku	doc_491521501740_item	2449814	et	3	main
kuna	doc_491521501740_item	2449815	et	3	main
verbid	doc_491521501740_item	2449816	et	3	main
kasutatakse	doc_491521501740_item	2449821	et	3	main
nende	doc_491521501740_item	2449829	et	4	main
modaalverbe	doc_491521501740_item	2449841	et	4	main
следует	doc_491521501740_item	2449847	et	2	main
saab	doc_491521501740_item	2449851	et	3	main
ka	doc_491521501740_item	2449853	et	3	main
тебе	doc_491521501740_item	2449856	et	2	main
в	doc_491521501740_item	2449858	et	2	main
verbid	doc_491521501740_item	2449864	et	3	main
olema	doc_491521501740_item	2449869	et	4	main
vaja	doc_491521501740_item	2449870	et	4	main
нужно	doc_491521501740_item	2449882	et	2	main
пойти	doc_491521501740_item	2449886	et	2	main
учитель	doc_491521501740_item	2449523	et	2	main
во	doc_491521501740_item	2449529	et	2	main
venna	doc_491521501740_item	2449532	et	3	main
raamatu	doc_491521501740_item	2449547	et	4	main
mölder	doc_491521501740_item	2449553	et	3	main
meil	doc_491521501740_item	2449559	et	4	main
eesti	doc_491521501740_item	2449562	et	4	main
keeles	doc_491521501740_item	2449563	et	4	main
aspektuaalse	doc_491521501740_item	2449572	et	4	main
määrab	doc_491521501740_item	2449576	et	3	main
ma-	doc_491521501740_item	2449577	et	3	main
ja	doc_491521501740_item	2449578	et	3	main
da-infinitiivi	doc_491521501740_item	2449579	et	4	main
tuleb	doc_491521501740_item	2449581	et	3	main
valikut	doc_491521501740_item	2449580	et	3	main
märkida	doc_491521501740_item	2449582	et	4	main
et	doc_491521501740_item	2449583	et	3	main
ma-infinitiivi	doc_491521501740_item	2449584	et	4	main
kasutusvõimalused	doc_491521501740_item	2449585	et	3	main
on	doc_491521501740_item	2449586	et	4	main
palju	doc_491521501740_item	2449587	et	4	main
laiemad	doc_491521501740_item	2449588	et	4	main
kui	doc_491521501740_item	2449589	et	3	main
da-infinitiivi	doc_491521501740_item	2449590	et	4	main
omad	doc_491521501740_item	2449591	et	4	main
enamasti	doc_491521501740_item	2449592	et	4	main
on	doc_491521501740_item	2449593	et	4	main
need	doc_491521501740_item	2449594	et	3	main
konstruktsioonid	doc_491521501740_item	2449595	et	3	main
emotsionaalselt	doc_491521501740_item	2449596	et	4	main
värvitud	doc_491521501740_item	2449597	et	4	main
püsiühendid	doc_491521501740_item	2449598	et	3	main
tihti	doc_491521501740_item	2449599	et	3	main
fraseoloogilise	doc_491521501740_item	2449600	et	3	main
iseloomuga	doc_491521501740_item	2449601	et	3	main
ühenduvad	doc_491521501740_item	2449564	et	4	main
tähenduse	doc_491521501740_item	2449573	et	4	main
juhul	doc_491521501740_item	2449606	et	3	main
mis	doc_491521501740_item	2449608	et	4	main
aja	doc_491521501740_item	2449611	et	4	main
pihlak	doc_491521501740_item	2449618	et	4	main
p	doc_491521501740_item	2449622	et	4	main
esloni	doc_491521501740_item	2449623	et	4	main
saab	doc_491521501740_item	2449628	et	3	main
et	doc_491521501740_item	2449630	et	3	main
põlema	doc_491521501740_item	2449642	et	4	main
ma-infinitiiviga	doc_491521501740_item	2449646	et	3	main
väljendavad	doc_491521501740_item	2449647	et	4	main
külviga	doc_491521501740_item	2449657	et	3	main
2	doc_491521501740_item	2449669	et	2	main
koer	doc_491521501740_item	2449674	et	3	main
tegevuse	doc_491521501740_item	2449687	et	4	main
on	doc_491521501740_item	2449689	et	4	main
asutas	doc_491521501740_item	2449693	et	3	main
sööma	doc_491521501740_item	2449695	et	4	main
собирается	doc_491521501740_item	2449696	et	2	main
поесть	doc_491521501740_item	2449697	et	2	main
lisaks	doc_491521501740_item	2449698	et	4	main
need	doc_491521501740_item	2449700	et	3	main
vene	doc_491521501740_item	2449602	et	4	main
iseloomustavad	doc_491521501740_item	2449609	et	4	main
tegevust	doc_491521501740_item	2449610	et	4	main
eslon	doc_491521501740_item	2449625	et	4	main
annavad	doc_491521501740_item	2449633	et	3	main
kestuse	doc_491521501740_item	2449635	et	3	main
ja	doc_491521501740_item	2449636	et	3	main
intensiivsuse	doc_491521501740_item	2449637	et	4	main
njuanssi	doc_491521501740_item	2449638	et	4	main
lõke	doc_491521501740_item	2449640	et	4	main
tegevusi	doc_491521501740_item	2449653	et	4	main
hästi	doc_491521501740_item	2449658	et	3	main
smuul	doc_491521501740_item	2449661	et	4	main
с	doc_491521501740_item	2449665	et	2	main
закричал	doc_491521501740_item	2449683	et	2	main
seda	doc_491521501740_item	2449685	et	3	main
seisund	doc_491521501740_item	2449691	et	3	main
sageli	doc_491521501740_item	2449702	et	3	main
keeles	doc_491521501740_item	2449725	et	4	main
nendele	doc_491521501740_item	2449727	et	4	main
kas	doc_491521501740_item	2449728	et	3	main
konstruktsioonid	doc_491521501740_item	2449735	et	3	main
valikust	doc_491521501740_item	2449746	et	4	main
hinnangut	doc_491521501740_item	2449754	et	3	main
sageli	doc_491521501740_item	2449777	et	3	main
eesti	doc_491521501740_item	2449810	et	4	main
ja	doc_491521501740_item	2449811	et	3	main
vene	doc_491521501740_item	2449812	et	4	main
keeles	doc_491521501740_item	2449813	et	4	main
sisse	doc_491521501740_item	2449819	et	4	main
on	doc_491521501740_item	2449825	et	4	main
miks	doc_491521501740_item	2449827	et	4	main
vigu	doc_491521501740_item	2449833	et	3	main
43	doc_491521501740_item	2449836	et	2	main
keeles	doc_491521501740_item	2449838	et	4	main
on	doc_491521501740_item	2449839	et	4	main
hulk	doc_491521501740_item	2449840	et	3	main
seda	doc_491521501740_item	2449850	et	3	main
nt	doc_491521501740_item	2449855	et	4	main
идти	doc_491521501740_item	2449857	et	2	main
солдаты	doc_491521501740_item	2449859	et	2	main
eesti	doc_491521501740_item	2449860	et	4	main
olema	doc_491521501740_item	2449871	et	4	main
vene	doc_491521501740_item	2449872	et	4	main
keeles	doc_491521501740_item	2449873	et	4	main
üksteisest	doc_491521501740_item	2449879	et	4	main
тебе	doc_491521501740_item	2449884	et	2	main
выполнить	doc_491521501740_item	2449889	et	2	main
modaalverbid	doc_491521501740_item	2449894	et	4	main
fraasid	doc_491521501740_item	2449896	et	3	main
infinitiive	doc_491521501740_item	2449898	et	3	main
olema	doc_491521501740_item	2449901	et	4	main
peab	doc_491521501740_item	2449913	et	4	main
siis	doc_491521501740_item	2449922	et	3	main
tuleb	doc_491521501740_item	2449923	et	3	main
kallist	doc_491521501740_item	2449925	et	4	main
väärt	doc_491521501740_item	2449934	et	4	main
ta	doc_491521501740_item	2449935	et	4	main
viis	doc_491521501740_item	2449940	et	4	main
ma	doc_491521501740_item	2449946	et	3	main
koguda	doc_491521501740_item	2449948	et	3	main
näiteid	doc_491521501740_item	2449949	et	3	main
üks	doc_491521501740_item	2449957	et	3	main
olema	doc_491521501740_item	2449961	et	4	main
modaalverb	doc_491521501740_item	2449963	et	4	main
nt	doc_491521501740_item	2449974	et	4	main
kategooria	doc_491521501740_item	2450020	et	4	main
järeldada	doc_491521501740_item	2449629	et	3	main
kõnehetkeks	doc_491521501740_item	2449651	et	4	main
lõppenuid	doc_491521501740_item	2449652	et	4	main
said	doc_491521501740_item	2449656	et	4	main
j	doc_491521501740_item	2449660	et	4	main
хорошо	doc_491521501740_item	2449663	et	2	main
ю	doc_491521501740_item	2449667	et	2	main
tegevuse	doc_491521501740_item	2449670	et	4	main
kiledalt	doc_491521501740_item	2449676	et	4	main
собачка	doc_491521501740_item	2449678	et	2	main
залилась	doc_491521501740_item	2449680	et	2	main
karjuma	doc_491521501740_item	2449682	et	3	main
paistavad	doc_491521501740_item	2449699	et	3	main
oma	doc_491521501740_item	2449704	et	4	main
emotsionaalse	doc_491521501740_item	2449705	et	3	main
värvinguga	doc_491521501740_item	2449706	et	3	main
kas	doc_491521501740_item	2449707	et	3	main
tugeva	doc_491521501740_item	2449708	et	4	main
või	doc_491521501740_item	2449709	et	4	main
nõrgaga	doc_491521501740_item	2449710	et	3	main
nt	doc_491521501740_item	2449711	et	4	main
pistis	doc_491521501740_item	2449712	et	4	main
töinama	doc_491521501740_item	2449713	et	3	main
разревелся	doc_491521501740_item	2449714	et	2	main
hakkas	doc_491521501740_item	2449715	et	3	main
nutma	doc_491521501740_item	2449716	et	3	main
заплакал	doc_491521501740_item	2449717	et	2	main
asutab	doc_491521501740_item	2449718	et	3	main
minema	doc_491521501740_item	2449719	et	3	main
valmistub	doc_491521501740_item	2449720	et	3	main
vene	doc_491521501740_item	2449724	et	4	main
vastavad	doc_491521501740_item	2449726	et	4	main
stiililiselt	doc_491521501740_item	2449729	et	4	main
absoluutselt	doc_491521501740_item	2449730	et	4	main
neutraalsed	doc_491521501740_item	2449731	et	3	main
kui	doc_491521501740_item	2449737	et	3	main
tegevust	doc_491521501740_item	2449752	et	4	main
esikomponent	doc_491521501740_item	2449759	et	3	main
järelikult	doc_491521501740_item	2449760	et	3	main
infinitiivi	doc_491521501740_item	2449761	et	4	main
valik	doc_491521501740_item	2449762	et	3	main
komponendi	doc_491521501740_item	2449767	et	3	main
eslon	doc_491521501740_item	2449769	et	4	main
75	doc_491521501740_item	2449771	et	2	main
põhiverbi	doc_491521501740_item	2449772	et	4	main
keeles	doc_491521501740_item	2449775	et	4	main
minema	doc_491521501740_item	2449721	et	3	main
või	doc_491521501740_item	2449732	et	4	main
keeles	doc_491521501740_item	2449739	et	4	main
konstruktsiooni	doc_491521501740_item	2449743	et	4	main
keeles	doc_491521501740_item	2449749	et	4	main
nimetab	doc_491521501740_item	2449750	et	3	main
infinitiiv	doc_491521501740_item	2449751	et	3	main
konstruktsiooni	doc_491521501740_item	2449758	et	4	main
on	doc_491521501740_item	2449763	et	4	main
just	doc_491521501740_item	2449765	et	3	main
tähendus	doc_491521501740_item	2449773	et	4	main
eesti	doc_491521501740_item	2449774	et	4	main
kasutatavaid	doc_491521501740_item	2449778	et	4	main
tegusõnu	doc_491521501740_item	2449779	et	3	main
mille	doc_491521501740_item	2449780	et	3	main
tähendussfäär	doc_491521501740_item	2449781	et	3	main
on	doc_491521501740_item	2449782	et	4	main
erakordselt	doc_491521501740_item	2449783	et	4	main
lai	doc_491521501740_item	2449784	et	3	main
ja	doc_491521501740_item	2449785	et	3	main
mida	doc_491521501740_item	2449786	et	4	main
kasutatakse	doc_491521501740_item	2449787	et	3	main
väga	doc_491521501740_item	2449788	et	3	main
mitmekesises	doc_491521501740_item	2449789	et	4	main
kontekstis	doc_491521501740_item	2449790	et	3	main
ja	doc_491521501740_item	2449791	et	3	main
erinevates	doc_491521501740_item	2449792	et	4	main
konstruktsioonides	doc_491521501740_item	2449793	et	3	main
neid	doc_491521501740_item	2449794	et	4	main
nimetatakse	doc_491521501740_item	2449795	et	3	main
tuumverbideks	doc_491521501740_item	2449796	et	4	main
on	doc_491521501740_item	2449798	et	4	main
need	doc_491521501740_item	2449799	et	3	main
morfoloogiliselt	doc_491521501740_item	2449797	et	4	main
sageli	doc_491521501740_item	2449800	et	3	main
erandlikud	doc_491521501740_item	2449801	et	3	main
nende	doc_491521501740_item	2449802	et	4	main
tähendus	doc_491521501740_item	2449804	et	4	main
põhisõnavara	doc_491521501740_item	2449818	et	4	main
eriti	doc_491521501740_item	2449822	et	3	main
see	doc_491521501740_item	2449824	et	3	main
põhjuseks	doc_491521501740_item	2449826	et	3	main
palju	doc_491521501740_item	2449832	et	4	main
metslang	doc_491521501740_item	2449834	et	3	main
kohustust	doc_491521501740_item	2449844	et	4	main
надо	doc_491521501740_item	2449845	et	2	main
нужно	doc_491521501740_item	2449846	et	2	main
tulema	doc_491521501740_item	2449865	et	4	main
modaalverbide	doc_491521501740_item	2449877	et	4	main
väljendusviisid	doc_491521501740_item	2449878	et	3	main
сделать	doc_491521501740_item	2449883	et	2	main
следует	doc_491521501740_item	2449885	et	2	main
eesti	doc_491521501740_item	2449891	et	4	main
ja	doc_491521501740_item	2449895	et	3	main
erinevaid	doc_491521501740_item	2449897	et	4	main
pidama	doc_491521501740_item	2449903	et	4	main
on	doc_491521501740_item	2449917	et	4	main
verbidega	doc_491521501740_item	2449830	et	3	main
tehakse	doc_491521501740_item	2449831	et	3	main
vene	doc_491521501740_item	2449837	et	4	main
väljendavad	doc_491521501740_item	2449843	et	4	main
быть	doc_491521501740_item	2449848	et	2	main
leksikaalselt	doc_491521501740_item	2449854	et	4	main
keeles	doc_491521501740_item	2449861	et	4	main
sõnaühendid	doc_491521501740_item	2449867	et	3	main
erinevate	doc_491521501740_item	2449876	et	4	main
мне	doc_491521501740_item	2449881	et	2	main
он	doc_491521501740_item	2449887	et	2	main
aga	doc_491521501740_item	2449890	et	3	main
da-infinitiivi	doc_491521501740_item	2449902	et	4	main
on	doc_491521501740_item	2449904	et	4	main
vaja	doc_491521501740_item	2449905	et	4	main
ma	doc_491521501740_item	2449906	et	3	main
infinitiivi	doc_491521501740_item	2449907	et	4	main
metslang	doc_491521501740_item	2449908	et	3	main
2003	doc_491521501740_item	2449909	et	2	main
46-47	doc_491521501740_item	2449910	et	2	main
mul	doc_491521501740_item	2449916	et	3	main
õppima	doc_491521501740_item	2449920	et	3	main
nii	doc_491521501740_item	2449924	et	3	main
maksma	doc_491521501740_item	2449926	et	3	main
tavaliselt	doc_491521501740_item	2449936	et	4	main
on	doc_491521501740_item	2449955	et	4	main
kasutatav	doc_491521501740_item	2449959	et	4	main
tõenäoliselt	doc_491521501740_item	2449972	et	4	main
juhtub	doc_491521501740_item	2449973	et	3	main
завтра	doc_491521501740_item	2449975	et	2	main
kui	doc_491521501740_item	2449979	et	3	main
suutma	doc_491521501740_item	2450015	et	3	main
struktuuri	doc_491521501740_item	2450039	et	4	main
ja	doc_491521501740_item	2450047	et	3	main
nüüd	doc_491521501740_item	2450050	et	4	main
ise	doc_491521501740_item	2450051	et	4	main
õlut	doc_491521501740_item	2450052	et	3	main
может	doc_491521501740_item	2450059	et	2	main
сам	doc_491521501740_item	2450061	et	2	main
me	doc_491521501740_item	2450064	et	4	main
мы	doc_491521501740_item	2450070	et	2	main
это	doc_491521501740_item	2450073	et	2	main
kirjutada	doc_491521501740_item	2450080	et	3	main
писать	doc_491521501740_item	2450084	et	2	main
не	doc_491521501740_item	2450094	et	2	main
2003	doc_491521501740_item	2450100	et	2	main
oskad	doc_491521501740_item	2450105	et	3	main
keelt	doc_491521501740_item	2450107	et	4	main
rääkima	doc_491521501740_item	2450108	et	3	main
99	doc_491521501740_item	2450113	et	2	main
krooni	doc_491521501740_item	2450114	et	4	main
väga	doc_491521501740_item	2450115	et	3	main
otsustama	doc_491521501740_item	2450127	et	3	main
lihtsalt	doc_491521501740_item	2450133	et	4	main
keeles	doc_491521501740_item	2450141	et	4	main
tähendus	doc_491521501740_item	2450150	et	4	main
need	doc_491521501740_item	2450151	et	3	main
laskma	doc_491521501740_item	2450155	et	3	main
keeles	doc_491521501740_item	2450158	et	4	main
prepositsioonide	doc_491521501740_item	2450171	et	4	main
käituvad	doc_491521501740_item	2450174	et	4	main
on	doc_491521501740_item	2450203	et	4	main
peaaegu	doc_491521501740_item	2450204	et	3	main
tõlkida	doc_491521501740_item	2450206	et	3	main
õmblejal	doc_491521501740_item	2450219	et	4	main
kleidi	doc_491521501740_item	2450220	et	3	main
õmmelda	doc_491521501740_item	2450221	et	4	main
себе	doc_491521501740_item	2450225	et	2	main
ajas	doc_491521501740_item	2450228	et	4	main
poisid	doc_491521501740_item	2450229	et	4	main
käia	doc_491521501740_item	2450238	et	4	main
он	doc_491521501740_item	2450239	et	2	main
мотор	doc_491521501740_item	2450241	et	2	main
metslang	doc_491521501740_item	2450242	et	3	main
2003	doc_491521501740_item	2450243	et	2	main
näiteks	doc_491521501740_item	2450245	et	4	main
tegutseda	doc_491521501740_item	2450249	et	3	main
soovimatu	doc_491521501740_item	2450254	et	4	main
pinge	doc_491521501740_item	2450260	et	4	main
paneb	doc_491521501740_item	2450263	et	3	main
nõuavad	doc_491521501740_item	2449893	et	4	main
kohustatud	doc_491521501740_item	2449900	et	4	main
saada	doc_491521501740_item	2449914	et	4	main
rahuldust	doc_491521501740_item	2449915	et	4	main
palju	doc_491521501740_item	2449919	et	4	main
eest	doc_491521501740_item	2449928	et	4	main
ja	doc_491521501740_item	2449929	et	3	main
kas	doc_491521501740_item	2449930	et	3	main
peab	doc_491521501740_item	2449937	et	4	main
kell	doc_491521501740_item	2449939	et	3	main
vaja	doc_491521501740_item	2449943	et	4	main
kursusetööga	doc_491521501740_item	2449945	et	3	main
pean	doc_491521501740_item	2449947	et	4	main
ja	doc_491521501740_item	2449950	et	3	main
neid	doc_491521501740_item	2449952	et	4	main
vene	doc_491521501740_item	2449953	et	4	main
laialt	doc_491521501740_item	2449958	et	4	main
tähendusega	doc_491521501740_item	2449962	et	4	main
мочь	doc_491521501740_item	2449964	et	2	main
mis	doc_491521501740_item	2449965	et	4	main
võib	doc_491521501740_item	2449966	et	3	main
tähendada	doc_491521501740_item	2449967	et	3	main
nii	doc_491521501740_item	2449968	et	3	main
seda	doc_491521501740_item	2449969	et	3	main
et	doc_491521501740_item	2449970	et	3	main
может	doc_491521501740_item	2449976	et	2	main
ka	doc_491521501740_item	2449980	et	3	main
mängu	doc_491521501740_item	2450017	et	4	main
astub	doc_491521501740_item	2450018	et	3	main
aspekti	doc_491521501740_item	2450019	et	4	main
verbiga	doc_491521501740_item	2450023	et	3	main
nii	doc_491521501740_item	2450027	et	3	main
perfektiivset	doc_491521501740_item	2450028	et	3	main
kõneleja	doc_491521501740_item	2450034	et	4	main
üle	doc_491521501740_item	2450035	et	3	main
kaheksateist	doc_491521501740_item	2450045	et	4	main
мальчику	doc_491521501740_item	2450054	et	2	main
восемнадцать	doc_491521501740_item	2450056	et	2	main
ära	doc_491521501740_item	2450068	et	4	main
можем	doc_491521501740_item	2450071	et	2	main
дело	doc_491521501740_item	2450074	et	2	main
kunagi	doc_491521501740_item	2450078	et	3	main
могу	doc_491521501740_item	2450083	et	2	main
ma	doc_491521501740_item	2450087	et	3	main
öelda	doc_491521501740_item	2450092	et	4	main
я	doc_491521501740_item	2450093	et	2	main
сказать	doc_491521501740_item	2450098	et	2	main
kas	doc_491521501740_item	2450103	et	3	main
näiteks	doc_491521501740_item	2450122	et	4	main
tema	doc_491521501740_item	2450131	et	4	main
verbe	doc_491521501740_item	2450144	et	3	main
millel	doc_491521501740_item	2450145	et	3	main
on	doc_491521501740_item	2450146	et	4	main
põhjustamise	doc_491521501740_item	2450147	et	4	main
ajama	doc_491521501740_item	2450153	et	4	main
заставить	doc_491521501740_item	2450163	et	2	main
väljendada	doc_491521501740_item	2450168	et	3	main
ka	doc_491521501740_item	2450169	et	3	main
morfoloogiliselt	doc_491521501740_item	2450170	et	4	main
keelest	doc_491521501740_item	2450208	et	4	main
keelde	doc_491521501740_item	2450210	et	4	main
vaja	doc_491521501740_item	2449918	et	4	main
miks	doc_491521501740_item	2449921	et	4	main
selle	doc_491521501740_item	2449927	et	4	main
on	doc_491521501740_item	2449932	et	4	main
seda	doc_491521501740_item	2449933	et	3	main
veel	doc_491521501740_item	2449941	et	4	main
keeles	doc_491521501740_item	2449954	et	4	main
võimeline	doc_491521501740_item	2449960	et	4	main
дождь	doc_491521501740_item	2449978	et	2	main
kasutada	doc_491521501740_item	2450026	et	3	main
imperfektiivset	doc_491521501740_item	2450031	et	3	main
püüab	doc_491521501740_item	2450033	et	3	main
kasutatud	doc_491521501740_item	2450038	et	4	main
keelde	doc_491521501740_item	2450041	et	4	main
poiss	doc_491521501740_item	2450043	et	3	main
on	doc_491521501740_item	2450044	et	4	main
osta	doc_491521501740_item	2450053	et	4	main
уже	doc_491521501740_item	2450055	et	2	main
теперь	doc_491521501740_item	2450060	et	2	main
saame	doc_491521501740_item	2450065	et	4	main
selle	doc_491521501740_item	2450066	et	4	main
ei	doc_491521501740_item	2450076	et	4	main
öösiti	doc_491521501740_item	2450079	et	4	main
ночам	doc_491521501740_item	2450086	et	2	main
могу	doc_491521501740_item	2450095	et	2	main
metslang	doc_491521501740_item	2450099	et	3	main
sa	doc_491521501740_item	2450104	et	3	main
eesti	doc_491521501740_item	2450106	et	4	main
tulema	doc_491521501740_item	2450121	et	4	main
kaua	doc_491521501740_item	2450124	et	3	main
ta	doc_491521501740_item	2450132	et	4	main
tavaliselt	doc_491521501740_item	2450162	et	4	main
lauses	doc_491521501740_item	2450173	et	3	main
võimatu	doc_491521501740_item	2450205	et	4	main
vene	doc_491521501740_item	2450209	et	4	main
fraasi	doc_491521501740_item	2450211	et	4	main
mis	doc_491521501740_item	2450212	et	4	main
sisaldab	doc_491521501740_item	2450213	et	3	main
kausatiivseid	doc_491521501740_item	2450214	et	3	main
verbe	doc_491521501740_item	2450215	et	3	main
sööma	doc_491521501740_item	2450230	et	4	main
она	doc_491521501740_item	2450231	et	2	main
отправила	doc_491521501740_item	2450232	et	2	main
мальчиков	doc_491521501740_item	2450233	et	2	main
кушать	doc_491521501740_item	2450234	et	2	main
tuua	doc_491521501740_item	2450253	et	3	main
ei	doc_491521501740_item	2450256	et	4	main
tohi	doc_491521501740_item	2450257	et	4	main
lugeja	doc_491521501740_item	2450265	et	4	main
oli	doc_491521501740_item	2450273	et	3	main
ka	doc_491521501740_item	2450279	et	3	main
aspekt	doc_491521501740_item	2450281	et	3	main
on	doc_491521501740_item	2450283	et	4	main
keele	doc_491521501740_item	2450285	et	4	main
kategooria	doc_491521501740_item	2450288	et	4	main
laadi	doc_491521501740_item	2450292	et	4	main
verbi	doc_491521501740_item	2450294	et	4	main
võib	doc_491521501740_item	2450298	et	3	main
õpetamatusele	doc_491521501740_item	2450312	et	4	main
või	doc_491521501740_item	2450318	et	4	main
bondarenko	doc_491521501740_item	2450320	et	4	main
perfektiivne	doc_491521501740_item	2450328	et	3	main
вид	doc_491521501740_item	2450331	et	2	main
või	doc_491521501740_item	2450338	et	4	main
nt	doc_491521501740_item	2450343	et	4	main
сказать	doc_491521501740_item	2450345	et	2	main
keelele	doc_491521501740_item	2450349	et	4	main
omane	doc_491521501740_item	2450351	et	3	main
väljendatakse	doc_491521501740_item	2450359	et	3	main
prefiksaalsõnade	doc_491521501740_item	2450360	et	4	main
sufiksite	doc_491521501740_item	2450361	et	3	main
ja	doc_491521501740_item	2450362	et	3	main
keeles	doc_491521501740_item	2450372	et	4	main
väljendatakse	doc_491521501740_item	2450373	et	3	main
skle-	doc_491521501740_item	2450409	et	4	main
adverbid	doc_491521501740_item	2450410	et	3	main
ning	doc_491521501740_item	2450411	et	3	main
tegevuse	doc_491521501740_item	2450416	et	4	main
puhkes	doc_491521501740_item	2450422	et	4	main
kõnelema	doc_491521501740_item	2450425	et	3	main
selle	doc_491521501740_item	2450437	et	4	main
see	doc_491521501740_item	2449931	et	3	main
lahkuda	doc_491521501740_item	2449938	et	3	main
on	doc_491521501740_item	2449942	et	4	main
tegelema	doc_491521501740_item	2449944	et	3	main
analüüsida	doc_491521501740_item	2449951	et	3	main
ainult	doc_491521501740_item	2449956	et	4	main
midagi	doc_491521501740_item	2449971	et	4	main
пойти	doc_491521501740_item	2449977	et	2	main
seda	doc_491521501740_item	2449981	et	3	main
et	doc_491521501740_item	2449982	et	3	main
toimumine	doc_491521501740_item	2449983	et	4	main
on	doc_491521501740_item	2449984	et	4	main
võimalik	doc_491521501740_item	2449985	et	3	main
nt	doc_491521501740_item	2449986	et	4	main
я	doc_491521501740_item	2449987	et	2	main
могу	doc_491521501740_item	2449988	et	2	main
играть	doc_491521501740_item	2449989	et	2	main
на	doc_491521501740_item	2449990	et	2	main
гитаре	doc_491521501740_item	2449991	et	2	main
sõnatähendus	doc_491521501740_item	2449992	et	3	main
on	doc_491521501740_item	2449993	et	4	main
laiem	doc_491521501740_item	2449994	et	4	main
eesti	doc_491521501740_item	2449995	et	4	main
keeles	doc_491521501740_item	2449996	et	4	main
vastavad	doc_491521501740_item	2449997	et	4	main
ühe	doc_491521501740_item	2449998	et	4	main
vene	doc_491521501740_item	2449999	et	4	main
sõna	doc_491521501740_item	2450000	et	4	main
mitmele	doc_491521501740_item	2450001	et	4	main
tähendusele	doc_491521501740_item	2450002	et	4	main
erinevad	doc_491521501740_item	2450003	et	4	main
sõnad	doc_491521501740_item	2450004	et	4	main
eesti	doc_491521501740_item	2450005	et	4	main
keeles	doc_491521501740_item	2450006	et	4	main
vastab	doc_491521501740_item	2450007	et	3	main
sellele	doc_491521501740_item	2450008	et	4	main
mitu	doc_491521501740_item	2450009	et	4	main
tegusõna	doc_491521501740_item	2450010	et	4	main
võima	doc_491521501740_item	2450011	et	3	main
saama	doc_491521501740_item	2450012	et	4	main
tohtima	doc_491521501740_item	2450013	et	3	main
oskama	doc_491521501740_item	2450014	et	3	main
siin	doc_491521501740_item	2450016	et	4	main
kuna	doc_491521501740_item	2450021	et	3	main
мочь	doc_491521501740_item	2450024	et	2	main
kui	doc_491521501740_item	2450029	et	3	main
ka	doc_491521501740_item	2450030	et	3	main
aspekti	doc_491521501740_item	2450032	et	4	main
kanda	doc_491521501740_item	2450036	et	4	main
eesti	doc_491521501740_item	2450040	et	4	main
nt	doc_491521501740_item	2450042	et	4	main
tohib	doc_491521501740_item	2450048	et	3	main
и	doc_491521501740_item	2450057	et	2	main
пиво	doc_491521501740_item	2450063	et	2	main
asja	doc_491521501740_item	2450067	et	4	main
ma	doc_491521501740_item	2450075	et	3	main
я	doc_491521501740_item	2450081	et	2	main
по	doc_491521501740_item	2450085	et	2	main
ei	doc_491521501740_item	2450088	et	4	main
вам	doc_491521501740_item	2450096	et	2	main
45-46	doc_491521501740_item	2450101	et	2	main
teile	doc_491521501740_item	2450109	et	4	main
võib	doc_491521501740_item	2450110	et	3	main
see	doc_491521501740_item	2450111	et	3	main
maksma	doc_491521501740_item	2450112	et	3	main
vene	doc_491521501740_item	2450022	et	4	main
saab	doc_491521501740_item	2450025	et	3	main
emakeeles	doc_491521501740_item	2450037	et	4	main
täis	doc_491521501740_item	2450046	et	4	main
võib	doc_491521501740_item	2450049	et	3	main
он	doc_491521501740_item	2450058	et	2	main
покупать	doc_491521501740_item	2450062	et	2	main
teha	doc_491521501740_item	2450069	et	3	main
уладить	doc_491521501740_item	2450072	et	2	main
suuda	doc_491521501740_item	2450077	et	4	main
не	doc_491521501740_item	2450082	et	2	main
oska	doc_491521501740_item	2450089	et	4	main
seda	doc_491521501740_item	2450090	et	3	main
teile	doc_491521501740_item	2450091	et	4	main
этого	doc_491521501740_item	2450097	et	2	main
näiteks	doc_491521501740_item	2450102	et	4	main
kahju	doc_491521501740_item	2450116	et	4	main
et	doc_491521501740_item	2450117	et	3	main
sina	doc_491521501740_item	2450118	et	4	main
ei	doc_491521501740_item	2450119	et	4	main
saanud	doc_491521501740_item	2450120	et	4	main
kangelane	doc_491521501740_item	2450123	et	3	main
ei	doc_491521501740_item	2450125	et	4	main
suutnud	doc_491521501740_item	2450126	et	4	main
kumma	doc_491521501740_item	2450128	et	3	main
poolel	doc_491521501740_item	2450129	et	4	main
on	doc_491521501740_item	2450130	et	4	main
on	doc_491521501740_item	2450142	et	4	main
hulk	doc_491521501740_item	2450143	et	3	main
on	doc_491521501740_item	2450152	et	4	main
verbid	doc_491521501740_item	2450156	et	3	main
tähenduses	doc_491521501740_item	2450161	et	4	main
приказать	doc_491521501740_item	2450164	et	2	main
saab	doc_491521501740_item	2450166	et	3	main
abil	doc_491521501740_item	2450172	et	4	main
tegusõnad	doc_491521501740_item	2450176	et	3	main
pisut	doc_491521501740_item	2450177	et	3	main
nt	doc_491521501740_item	2450216	et	4	main
lasksin	doc_491521501740_item	2450217	et	3	main
сшила	doc_491521501740_item	2450223	et	2	main
ta	doc_491521501740_item	2450227	et	4	main
meid	doc_491521501740_item	2450248	et	4	main
lisakoormus	doc_491521501740_item	2450251	et	3	main
selle	doc_491521501740_item	2450267	et	4	main
kas	doc_491521501740_item	2450269	et	3	main
paneb	doc_491521501740_item	2450278	et	3	main
vene	doc_491521501740_item	2450284	et	4	main
verbi	doc_491521501740_item	2450287	et	4	main
tegevuse	doc_491521501740_item	2450291	et	4	main
põhiliselt	doc_491521501740_item	2450300	et	4	main
несовершенный	doc_491521501740_item	2450307	et	2	main
tegevuse	doc_491521501740_item	2450310	et	4	main
piiritlematusele	doc_491521501740_item	2450313	et	4	main
mitteterviklikkusele	doc_491521501740_item	2450314	et	4	main
kestvusele	doc_491521501740_item	2450317	et	4	main
korduvusele	doc_491521501740_item	2450319	et	4	main
1971	doc_491521501740_item	2450321	et	2	main
armastama	doc_491521501740_item	2450324	et	3	main
kirjutama	doc_491521501740_item	2450326	et	3	main
piiritletusele	doc_491521501740_item	2450336	et	4	main
eesti	doc_491521501740_item	2450348	et	4	main
on	doc_491521501740_item	2450350	et	4	main
verbide	doc_491521501740_item	2450364	et	3	main
verbi	doc_491521501740_item	2450374	et	4	main
lõpetamise	doc_491521501740_item	2450419	et	4	main
nt	doc_491521501740_item	2450421	et	4	main
nutma	doc_491521501740_item	2450423	et	3	main
hakkas	doc_491521501740_item	2450424	et	3	main
145-163	doc_491521501740_item	2450430	et	2	main
sõnast	doc_491521501740_item	2450434	et	4	main
rühma	doc_491521501740_item	2450442	et	4	main
minema	doc_491521501740_item	2450447	et	3	main
hakkama	doc_491521501740_item	2450450	et	3	main
kihutas	doc_491521501740_item	2450452	et	3	main
pani	doc_491521501740_item	2450459	et	4	main
väljendtegusõnad	doc_491521501740_item	2450464	et	4	main
ei	doc_491521501740_item	2450134	et	4	main
suuda	doc_491521501740_item	2450135	et	4	main
võitlema	doc_491521501740_item	2450136	et	3	main
oma	doc_491521501740_item	2450137	et	4	main
rahva	doc_491521501740_item	2450138	et	3	main
vastu	doc_491521501740_item	2450139	et	3	main
eesti	doc_491521501740_item	2450140	et	4	main
e	doc_491521501740_item	2450148	et	4	main
kausatiivne	doc_491521501740_item	2450149	et	3	main
panema	doc_491521501740_item	2450154	et	3	main
vene	doc_491521501740_item	2450157	et	4	main
esinevad	doc_491521501740_item	2450159	et	4	main
selles	doc_491521501740_item	2450160	et	4	main
samuti	doc_491521501740_item	2450165	et	3	main
põhjust	doc_491521501740_item	2450167	et	4	main
need	doc_491521501740_item	2450175	et	3	main
erinevalt	doc_491521501740_item	2450178	et	4	main
a	doc_491521501740_item	2450179	et	4	main
jama	doc_491521501740_item	2450180	et	4	main
ja	doc_491521501740_item	2450181	et	3	main
panema	doc_491521501740_item	2450182	et	3	main
nõuavad	doc_491521501740_item	2450183	et	4	main
ma-infinitiivi	doc_491521501740_item	2450184	et	4	main
laskma	doc_491521501740_item	2450185	et	3	main
aga	doc_491521501740_item	2450186	et	3	main
da-infinitiivi	doc_491521501740_item	2450187	et	4	main
nt	doc_491521501740_item	2450188	et	4	main
ta	doc_491521501740_item	2450189	et	4	main
ajas	doc_491521501740_item	2450190	et	4	main
mind	doc_491521501740_item	2450191	et	4	main
naerma	doc_491521501740_item	2450192	et	3	main
ta	doc_491521501740_item	2450193	et	4	main
pani	doc_491521501740_item	2450194	et	4	main
mootori	doc_491521501740_item	2450195	et	3	main
käima	doc_491521501740_item	2450196	et	4	main
ta	doc_491521501740_item	2450197	et	4	main
lasi	doc_491521501740_item	2450198	et	4	main
mul	doc_491521501740_item	2450199	et	3	main
nutta	doc_491521501740_item	2450200	et	3	main
mõnel	doc_491521501740_item	2450201	et	3	main
juhul	doc_491521501740_item	2450202	et	3	main
eesti	doc_491521501740_item	2450207	et	4	main
endale	doc_491521501740_item	2450218	et	4	main
я	doc_491521501740_item	2450222	et	2	main
платье	doc_491521501740_item	2450226	et	2	main
paneb	doc_491521501740_item	2450247	et	3	main
aga	doc_491521501740_item	2450250	et	3	main
lasta	doc_491521501740_item	2450258	et	4	main
ülekoormust	doc_491521501740_item	2450259	et	4	main
mõelda	doc_491521501740_item	2450266	et	4	main
taoline	doc_491521501740_item	2450271	et	3	main
samaaegselt	doc_491521501740_item	2450277	et	4	main
aspekt	doc_491521501740_item	2450282	et	3	main
grammatikas	doc_491521501740_item	2450286	et	3	main
tähistab	doc_491521501740_item	2450290	et	3	main
milles	doc_491521501740_item	2450293	et	3	main
tegevus	doc_491521501740_item	2450295	et	4	main
areneb	doc_491521501740_item	2450296	et	3	main
aspektilt	doc_491521501740_item	2450299	et	3	main
ja	doc_491521501740_item	2450303	et	3	main
вид	doc_491521501740_item	2450308	et	2	main
selle	doc_491521501740_item	2450315	et	4	main
protsessuaalsele	doc_491521501740_item	2450316	et	3	main
пошила	doc_491521501740_item	2450224	et	2	main
ta	doc_491521501740_item	2450235	et	4	main
lasi	doc_491521501740_item	2450236	et	4	main
mootoril	doc_491521501740_item	2450237	et	3	main
завел	doc_491521501740_item	2450240	et	2	main
48-49	doc_491521501740_item	2450244	et	2	main
paras	doc_491521501740_item	2450246	et	3	main
võib	doc_491521501740_item	2450252	et	3	main
tagajärgi	doc_491521501740_item	2450255	et	4	main
tekkima	doc_491521501740_item	2450261	et	3	main
sellega	doc_491521501740_item	2450262	et	3	main
autor	doc_491521501740_item	2450264	et	3	main
üle	doc_491521501740_item	2450268	et	3	main
juhtivisiku	doc_491521501740_item	2450270	et	3	main
tegevus	doc_491521501740_item	2450272	et	4	main
aga	doc_491521501740_item	2450275	et	3	main
mis	doc_491521501740_item	2450289	et	4	main
olla	doc_491521501740_item	2450301	et	3	main
perfektiivne	doc_491521501740_item	2450304	et	3	main
aspekt	doc_491521501740_item	2450306	et	3	main
l	doc_491521501740_item	2450311	et	4	main
nt	doc_491521501740_item	2450323	et	4	main
совершенный	doc_491521501740_item	2450330	et	2	main
tegevuse	doc_491521501740_item	2450333	et	4	main
lõpetatusele	doc_491521501740_item	2450335	et	4	main
terviklikkusele	doc_491521501740_item	2450337	et	4	main
ühekordsusele	doc_491521501740_item	2450339	et	4	main
bondarenko	doc_491521501740_item	2450340	et	4	main
1971	doc_491521501740_item	2450341	et	2	main
8	doc_491521501740_item	2450342	et	2	main
küsima	doc_491521501740_item	2450346	et	3	main
eriline	doc_491521501740_item	2450355	et	4	main
väljendusviis	doc_491521501740_item	2450356	et	3	main
aspekti	doc_491521501740_item	2450357	et	4	main
mõistet	doc_491521501740_item	2450358	et	3	main
prefiksite	doc_491521501740_item	2450376	et	3	main
sufiksite	doc_491521501740_item	2450377	et	3	main
aga	doc_491521501740_item	2450414	et	3	main
väljendamiseks	doc_491521501740_item	2450420	et	4	main
vaiss	doc_491521501740_item	2450428	et	4	main
ühendverbid	doc_491521501740_item	2450431	et	3	main
koosnevad	doc_491521501740_item	2450432	et	4	main
verbist	doc_491521501740_item	2450435	et	3	main
tähendust	doc_491521501740_item	2450438	et	4	main
verb	doc_491521501740_item	2450446	et	3	main
seadis	doc_491521501740_item	2450460	et	4	main
hakkama	doc_491521501740_item	2450461	et	3	main
sai	doc_491521501740_item	2450462	et	4	main
nt	doc_491521501740_item	2450475	et	4	main
рассмеялся	doc_491521501740_item	2450503	et	2	main
päevavalgus	doc_491521501740_item	2450517	et	4	main
oleks	doc_491521501740_item	2450518	et	3	main
võimatu	doc_491521501740_item	2450521	et	4	main
saab	doc_491521501740_item	2450523	et	3	main
saama	doc_491521501740_item	2450536	et	4	main
on	doc_491521501740_item	2450540	et	4	main
nad	doc_491521501740_item	2450545	et	3	main
eesti	doc_491521501740_item	2450558	et	4	main
valikut	doc_491521501740_item	2450560	et	3	main
passiivsuse	doc_491521501740_item	2450565	et	4	main
kategooria	doc_491521501740_item	2450566	et	4	main
see	doc_491521501740_item	2450567	et	3	main
tähendab	doc_491521501740_item	2450568	et	3	main
et	doc_491521501740_item	2450569	et	3	main
sellest	doc_491521501740_item	2450576	et	4	main
või	doc_491521501740_item	2450579	et	4	main
millele	doc_491521501740_item	2450581	et	3	main
on	doc_491521501740_item	2450582	et	4	main
aktiivne	doc_491521501740_item	2450586	et	3	main
või	doc_491521501740_item	2450592	et	4	main
siis	doc_491521501740_item	2450597	et	3	main
põld	doc_491521501740_item	2450630	et	3	main
alus	doc_491521501740_item	2450633	et	4	main
põld	doc_491521501740_item	2450634	et	3	main
on	doc_491521501740_item	2450635	et	4	main
aga	doc_491521501740_item	2450638	et	3	main
teise	doc_491521501740_item	2450643	et	4	main
poolt	doc_491521501740_item	2450644	et	4	main
vene	doc_491521501740_item	2450645	et	4	main
tuletatud	doc_491521501740_item	2450653	et	4	main
substantiiv	doc_491521501740_item	2450654	et	3	main
годится	doc_491521501740_item	2450659	et	2	main
õige	doc_491521501740_item	2450274	et	4	main
armastus	doc_491521501740_item	2450276	et	4	main
kahelda	doc_491521501740_item	2450280	et	4	main
verb	doc_491521501740_item	2450297	et	3	main
imperfektiivne	doc_491521501740_item	2450302	et	3	main
imperfektiivne	doc_491521501740_item	2450305	et	3	main
osutab	doc_491521501740_item	2450309	et	3	main
8	doc_491521501740_item	2450322	et	2	main
любить	doc_491521501740_item	2450325	et	2	main
aspekt	doc_491521501740_item	2450329	et	3	main
näitab	doc_491521501740_item	2450332	et	3	main
resultatiivsusele	doc_491521501740_item	2450334	et	4	main
ütlema	doc_491521501740_item	2450344	et	3	main
спросить	doc_491521501740_item	2450347	et	2	main
verbi	doc_491521501740_item	2450352	et	4	main
aspekti	doc_491521501740_item	2450353	et	4	main
abil	doc_491521501740_item	2450365	et	4	main
ka	doc_491521501740_item	2450367	et	3	main
ja	doc_491521501740_item	2450369	et	3	main
aspekti	doc_491521501740_item	2450375	et	4	main
põhiliselt	doc_491521501740_item	2450413	et	4	main
faasiverbid	doc_491521501740_item	2450415	et	4	main
alustamise	doc_491521501740_item	2450417	et	4	main
ja	doc_491521501740_item	2450418	et	3	main
писать	doc_491521501740_item	2450327	et	2	main
mõiste	doc_491521501740_item	2450354	et	4	main
eritüveliste	doc_491521501740_item	2450363	et	4	main
samuti	doc_491521501740_item	2450366	et	3	main
süntaktiliselt	doc_491521501740_item	2450368	et	4	main
leksikaalselt	doc_491521501740_item	2450370	et	4	main
vene	doc_491521501740_item	2450371	et	4	main
eritüveliste	doc_491521501740_item	2450378	et	4	main
verbide	doc_491521501740_item	2450379	et	3	main
häälikuvahelduse	doc_491521501740_item	2450380	et	4	main
ja	doc_491521501740_item	2450381	et	3	main
aktsendi	doc_491521501740_item	2450382	et	3	main
abil	doc_491521501740_item	2450383	et	4	main
põhiliselt	doc_491521501740_item	2450384	et	4	main
aga	doc_491521501740_item	2450385	et	3	main
morfoloogiliselt	doc_491521501740_item	2450386	et	4	main
keele	doc_491521501740_item	2450388	et	4	main
eesti	doc_491521501740_item	2450387	et	4	main
aspektikategooria	doc_491521501740_item	2450389	et	4	main
leksikaalsete	doc_491521501740_item	2450390	et	3	main
väljendusvõimaluste	doc_491521501740_item	2450391	et	3	main
hulka	doc_491521501740_item	2450392	et	4	main
kuuluvad	doc_491521501740_item	2450393	et	4	main
ühend	doc_491521501740_item	2450394	et	3	main
ja	doc_491521501740_item	2450395	et	3	main
väljendverbid	doc_491521501740_item	2450396	et	4	main
mõnede	doc_491521501740_item	2450397	et	3	main
verbide	doc_491521501740_item	2450398	et	3	main
supletiivsed	doc_491521501740_item	2450399	et	3	main
vormid	doc_491521501740_item	2450400	et	4	main
nt	doc_491521501740_item	2450401	et	4	main
kõnelema	doc_491521501740_item	2450402	et	3	main
rääkima	doc_491521501740_item	2450403	et	3	main
ütlema	doc_491521501740_item	2450404	et	3	main
sufiksid	doc_491521501740_item	2450405	et	3	main
ahta-	doc_491521501740_item	2450406	et	4	main
ata-	doc_491521501740_item	2450407	et	4	main
le-	doc_491521501740_item	2450408	et	4	main
tegevuslaadid	doc_491521501740_item	2450412	et	3	main
armastamast	doc_491521501740_item	2450427	et	3	main
2004	doc_491521501740_item	2450429	et	2	main
ja	doc_491521501740_item	2450436	et	3	main
sai	doc_491521501740_item	2450457	et	4	main
hakkama	doc_491521501740_item	2450463	et	3	main
sõnast	doc_491521501740_item	2450467	et	4	main
noomeni	doc_491521501740_item	2450470	et	3	main
pani	doc_491521501740_item	2450476	et	4	main
заплакал	doc_491521501740_item	2450506	et	2	main
kuulda	doc_491521501740_item	2450509	et	4	main
missuguse	doc_491521501740_item	2450538	et	3	main
õpetajad	doc_491521501740_item	2450542	et	4	main
kaua	doc_491521501740_item	2450544	et	3	main
tahaksime	doc_491521501740_item	2450550	et	3	main
veel	doc_491521501740_item	2450551	et	4	main
teada	doc_491521501740_item	2450552	et	3	main
kategooria	doc_491521501740_item	2450557	et	4	main
infinitiivi	doc_491521501740_item	2450559	et	4	main
kas	doc_491521501740_item	2450577	et	3	main
asi	doc_491521501740_item	2450580	et	4	main
on	doc_491521501740_item	2450585	et	4	main
passiivne	doc_491521501740_item	2450588	et	3	main
kui	doc_491521501740_item	2450590	et	3	main
tegija	doc_491521501740_item	2450596	et	4	main
asi	doc_491521501740_item	2450621	et	4	main
passiivses	doc_491521501740_item	2450624	et	3	main
konstruktsioonis	doc_491521501740_item	2450625	et	3	main
passiivne	doc_491521501740_item	2450636	et	3	main
tegevus	doc_491521501740_item	2450639	et	4	main
on	doc_491521501740_item	2450640	et	4	main
infinitiiv	doc_491521501740_item	2450650	et	3	main
поле	doc_491521501740_item	2450658	et	2	main
годится	doc_491521501740_item	2450663	et	2	main
1962	doc_491521501740_item	2450667	et	2	main
kui	doc_491521501740_item	2450670	et	3	main
ka	doc_491521501740_item	2450676	et	3	main
pesema	doc_491521501740_item	2450680	et	3	main
aitan	doc_491521501740_item	2450682	et	3	main
eesti	doc_491521501740_item	2450723	et	4	main
levinum	doc_491521501740_item	2450734	et	4	main
kus	doc_491521501740_item	2450744	et	3	main
peaks	doc_491521501740_item	2450745	et	4	main
või	doc_491521501740_item	2450751	et	4	main
da-infinitiivi	doc_491521501740_item	2450752	et	4	main
keeldus	doc_491521501740_item	2450754	et	3	main
liituda	doc_491521501740_item	2450755	et	3	main
vrd	doc_491521501740_item	2450756	et	4	main
keeldus	doc_491521501740_item	2450757	et	3	main
seda	doc_491521501740_item	2450768	et	3	main
hoiatasime	doc_491521501740_item	2450770	et	3	main
üksi	doc_491521501740_item	2450772	et	4	main
pimedas	doc_491521501740_item	2450773	et	3	main
õue	doc_491521501740_item	2450774	et	4	main
minna	doc_491521501740_item	2450775	et	3	main
pimedas	doc_491521501740_item	2450780	et	3	main
peole	doc_491521501740_item	2450791	et	4	main
minemata	doc_491521501740_item	2450792	et	4	main
jätta	doc_491521501740_item	2450793	et	3	main
metslang	doc_491521501740_item	2450794	et	3	main
puuduvate	doc_491521501740_item	2450801	et	4	main
võitis	doc_491521501740_item	2450821	et	3	main
kui	doc_491521501740_item	2450842	et	3	main
ka	doc_491521501740_item	2450843	et	3	main
huvitava	doc_491521501740_item	2450847	et	4	main
tohi	doc_491521501740_item	2450852	et	4	main
lasta	doc_491521501740_item	2450853	et	4	main
puhkama	doc_491521501740_item	2450861	et	3	main
on	doc_491521501740_item	2450864	et	4	main
nt	doc_491521501740_item	2450873	et	4	main
selle	doc_491521501740_item	2450874	et	4	main
autor	doc_491521501740_item	2450876	et	3	main
moodustatud	doc_491521501740_item	2450915	et	4	main
otstarbekõrvallauses	doc_491521501740_item	2450922	et	3	main
leiba	doc_491521501740_item	2450927	et	4	main
osta	doc_491521501740_item	2450928	et	4	main
õues	doc_491521501740_item	2450942	et	4	main
kätes	doc_491521501740_item	2450949	et	3	main
рождены	doc_491521501740_item	2450952	et	2	main
открывать	doc_491521501740_item	2450957	et	2	main
некоторые	doc_491521501740_item	2450959	et	2	main
lakkas	doc_491521501740_item	2450426	et	3	main
kahest	doc_491521501740_item	2450433	et	4	main
sellesse	doc_491521501740_item	2450441	et	4	main
kuuluvad	doc_491521501740_item	2450443	et	4	main
verb	doc_491521501740_item	2450449	et	3	main
nt	doc_491521501740_item	2450451	et	4	main
läks	doc_491521501740_item	2450453	et	3	main
laskis	doc_491521501740_item	2450454	et	4	main
vedas	doc_491521501740_item	2450455	et	4	main
minema	doc_491521501740_item	2450456	et	3	main
koosnevad	doc_491521501740_item	2450465	et	4	main
või	doc_491521501740_item	2450472	et	4	main
lükkas	doc_491521501740_item	2450478	et	3	main
käima	doc_491521501740_item	2450479	et	4	main
vene	doc_491521501740_item	2450480	et	4	main
keelde	doc_491521501740_item	2450481	et	4	main
tõlgitakse	doc_491521501740_item	2450482	et	4	main
selliseid	doc_491521501740_item	2450483	et	4	main
fraseoloogilise	doc_491521501740_item	2450484	et	3	main
tähendusega	doc_491521501740_item	2450485	et	4	main
sõnaühendid	doc_491521501740_item	2450486	et	3	main
tihti	doc_491521501740_item	2450487	et	3	main
perfektiivse	doc_491521501740_item	2450488	et	3	main
aspekti	doc_491521501740_item	2450489	et	4	main
prefiksaalverbide	doc_491521501740_item	2450490	et	4	main
abil	doc_491521501740_item	2450491	et	4	main
nt	doc_491521501740_item	2450492	et	4	main
lõi	doc_491521501740_item	2450493	et	4	main
запустил	doc_491521501740_item	2450495	et	2	main
käima	doc_491521501740_item	2450494	et	4	main
uinus	doc_491521501740_item	2450496	et	3	main
jäi	doc_491521501740_item	2450497	et	3	main
magama	doc_491521501740_item	2450498	et	3	main
заснул	doc_491521501740_item	2450499	et	2	main
kihistas	doc_491521501740_item	2450500	et	3	main
naerda	doc_491521501740_item	2450501	et	4	main
засмеялся	doc_491521501740_item	2450502	et	2	main
muutvast	doc_491521501740_item	2450439	et	4	main
abimäärsõnast	doc_491521501740_item	2450440	et	4	main
ka	doc_491521501740_item	2450444	et	3	main
ühendid	doc_491521501740_item	2450445	et	3	main
tulema	doc_491521501740_item	2450448	et	4	main
tulema	doc_491521501740_item	2450458	et	4	main
ja	doc_491521501740_item	2450469	et	3	main
pronoomeni	doc_491521501740_item	2450471	et	3	main
infinitiivi	doc_491521501740_item	2450473	et	4	main
vormist	doc_491521501740_item	2450474	et	4	main
lõi	doc_491521501740_item	2450477	et	4	main
löristas	doc_491521501740_item	2450504	et	3	main
nutta	doc_491521501740_item	2450505	et	3	main
послушал	doc_491521501740_item	2450510	et	2	main
155-158	doc_491521501740_item	2450513	et	2	main
näiteks	doc_491521501740_item	2450514	et	4	main
vaipade	doc_491521501740_item	2450515	et	3	main
hea	doc_491521501740_item	2450519	et	4	main
ilma	doc_491521501740_item	2450524	et	4	main
vrd	doc_491521501740_item	2450548	et	4	main
aktiivsuse	doc_491521501740_item	2450563	et	4	main
ja	doc_491521501740_item	2450564	et	3	main
sõltub	doc_491521501740_item	2450575	et	3	main
tegija	doc_491521501740_item	2450589	et	4	main
isik	doc_491521501740_item	2450591	et	3	main
asi	doc_491521501740_item	2450593	et	4	main
on	doc_491521501740_item	2450594	et	4	main
aktiivne	doc_491521501740_item	2450595	et	3	main
künda	doc_491521501740_item	2450632	et	3	main
kellegi	doc_491521501740_item	2450642	et	4	main
neile	doc_491521501740_item	2450647	et	4	main
vastab	doc_491521501740_item	2450648	et	3	main
kas	doc_491521501740_item	2450649	et	3	main
või	doc_491521501740_item	2450651	et	4	main
verbist	doc_491521501740_item	2450652	et	3	main
nt	doc_491521501740_item	2450657	et	4	main
содака	doc_491521501740_item	2450662	et	2	main
näiteks	doc_491521501740_item	2450669	et	4	main
raamatu	doc_491521501740_item	2450673	et	4	main
sulle	doc_491521501740_item	2450677	et	3	main
lapsel	doc_491521501740_item	2450686	et	4	main
pesema	doc_491521501740_item	2450687	et	3	main
ta	doc_491521501740_item	2450688	et	4	main
keelest	doc_491521501740_item	2450724	et	4	main
väga	doc_491521501740_item	2450728	et	3	main
keeletundmist	doc_491521501740_item	2450732	et	3	main
kõige	doc_491521501740_item	2450733	et	4	main
kasutatakse	doc_491521501740_item	2450749	et	3	main
väsinud	doc_491521501740_item	2450766	et	4	main
kordamast	doc_491521501740_item	2450769	et	4	main
teda	doc_491521501740_item	2450771	et	4	main
üksi	doc_491521501740_item	2450779	et	4	main
õue	doc_491521501740_item	2450781	et	4	main
ta	doc_491521501740_item	2450783	et	4	main
soovitas	doc_491521501740_item	2450784	et	3	main
peole	doc_491521501740_item	2450785	et	4	main
minema	doc_491521501740_item	2450786	et	3	main
jätta	doc_491521501740_item	2450787	et	3	main
2003	doc_491521501740_item	2450795	et	2	main
oma	doc_491521501740_item	2450800	et	4	main
eestlastele	doc_491521501740_item	2450830	et	4	main
seda	doc_491521501740_item	2450831	et	3	main
emakeelt	doc_491521501740_item	2450832	et	4	main
õpetab	doc_491521501740_item	2450833	et	3	main
telesaade	doc_491521501740_item	2450848	et	4	main
vaatamise	doc_491521501740_item	2450849	et	4	main
ajal	doc_491521501740_item	2450850	et	4	main
ei	doc_491521501740_item	2450851	et	4	main
sportima	doc_491521501740_item	2450859	et	4	main
puhul	doc_491521501740_item	2450863	et	4	main
kõige	doc_491521501740_item	2450865	et	4	main
sagedamini	doc_491521501740_item	2450866	et	4	main
des-vormi	doc_491521501740_item	2450871	et	4	main
asemel	doc_491521501740_item	2450872	et	4	main
õnnelik	doc_491521501740_item	2450878	et	3	main
eriti	doc_491521501740_item	2450918	et	3	main
esineb	doc_491521501740_item	2450920	et	3	main
poodi	doc_491521501740_item	2450925	et	4	main
sündinud	doc_491521501740_item	2450933	et	4	main
et	doc_491521501740_item	2450934	et	3	main
nende	doc_491521501740_item	2450945	et	4	main
kahest	doc_491521501740_item	2450466	et	4	main
tegusõnast	doc_491521501740_item	2450468	et	4	main
võttis	doc_491521501740_item	2450508	et	3	main
pihlak	doc_491521501740_item	2450511	et	4	main
1985a	doc_491521501740_item	2450512	et	4	main
расплакался	doc_491521501740_item	2450507	et	2	main
pildistamiseks	doc_491521501740_item	2450516	et	4	main
kui	doc_491521501740_item	2450520	et	3	main
siis	doc_491521501740_item	2450522	et	3	main
ka	doc_491521501740_item	2450529	et	3	main
et	doc_491521501740_item	2450537	et	3	main
me	doc_491521501740_item	2450549	et	4	main
aktiivsuse	doc_491521501740_item	2450556	et	4	main
mõjutab	doc_491521501740_item	2450561	et	3	main
samuti	doc_491521501740_item	2450562	et	3	main
isik	doc_491521501740_item	2450578	et	3	main
tegevus	doc_491521501740_item	2450583	et	4	main
või	doc_491521501740_item	2450587	et	4	main
ka	doc_491521501740_item	2450525	et	3	main
hakata	doc_491521501740_item	2450526	et	4	main
vrd	doc_491521501740_item	2450527	et	4	main
saab	doc_491521501740_item	2450528	et	3	main
ilma	doc_491521501740_item	2450530	et	4	main
hakkama	doc_491521501740_item	2450531	et	3	main
me	doc_491521501740_item	2450532	et	4	main
tahaksime	doc_491521501740_item	2450533	et	3	main
veel	doc_491521501740_item	2450534	et	4	main
teada	doc_491521501740_item	2450535	et	3	main
töökogemusega	doc_491521501740_item	2450539	et	3	main
teie	doc_491521501740_item	2450541	et	4	main
kui	doc_491521501740_item	2450543	et	3	main
töötavad	doc_491521501740_item	2450546	et	4	main
keelekeskuses	doc_491521501740_item	2450547	et	4	main
saada	doc_491521501740_item	2450553	et	4	main
passiivsuse	doc_491521501740_item	2450554	et	4	main
ja	doc_491521501740_item	2450555	et	3	main
on	doc_491521501740_item	2450570	et	4	main
ma-	doc_491521501740_item	2450571	et	3	main
ja	doc_491521501740_item	2450572	et	3	main
da-infinitiivi	doc_491521501740_item	2450573	et	4	main
valik	doc_491521501740_item	2450574	et	3	main
suunatud	doc_491521501740_item	2450584	et	4	main
kasutatakse	doc_491521501740_item	2450598	et	3	main
ma-infinitiivi	doc_491521501740_item	2450599	et	4	main
nt	doc_491521501740_item	2450600	et	4	main
koer	doc_491521501740_item	2450601	et	3	main
kõlbab	doc_491521501740_item	2450602	et	3	main
valvama	doc_491521501740_item	2450603	et	3	main
alus	doc_491521501740_item	2450604	et	4	main
koer	doc_491521501740_item	2450605	et	3	main
tähendab	doc_491521501740_item	2450606	et	3	main
aktiivset	doc_491521501740_item	2450607	et	3	main
tegevuse	doc_491521501740_item	2450608	et	4	main
sooritajat	doc_491521501740_item	2450609	et	4	main
kui	doc_491521501740_item	2450610	et	3	main
asi	doc_491521501740_item	2450611	et	4	main
on	doc_491521501740_item	2450612	et	4	main
objekt	doc_491521501740_item	2450613	et	3	main
või	doc_491521501740_item	2450614	et	4	main
tegevuse	doc_491521501740_item	2450615	et	4	main
vahend	doc_491521501740_item	2450616	et	3	main
ja	doc_491521501740_item	2450617	et	3	main
tegevust	doc_491521501740_item	2450618	et	4	main
teine	doc_491521501740_item	2450620	et	3	main
sooritab	doc_491521501740_item	2450619	et	3	main
või	doc_491521501740_item	2450622	et	4	main
isik	doc_491521501740_item	2450623	et	3	main
kasutatakse	doc_491521501740_item	2450627	et	3	main
objekt	doc_491521501740_item	2450637	et	3	main
для	doc_491521501740_item	2450656	et	2	main
для	doc_491521501740_item	2450660	et	2	main
охраны	doc_491521501740_item	2450665	et	2	main
lugema	doc_491521501740_item	2450674	et	4	main
laps	doc_491521501740_item	2450679	et	4	main
last	doc_491521501740_item	2450683	et	4	main
pesta	doc_491521501740_item	2450684	et	4	main
aitan	doc_491521501740_item	2450685	et	3	main
siis	doc_491521501740_item	2450626	et	3	main
da-infinitiivi	doc_491521501740_item	2450628	et	4	main
nt	doc_491521501740_item	2450629	et	4	main
kõlbab	doc_491521501740_item	2450631	et	3	main
sooritatud	doc_491521501740_item	2450641	et	4	main
keeles	doc_491521501740_item	2450646	et	4	main
prepositsiooniga	doc_491521501740_item	2450655	et	4	main
пахоты	doc_491521501740_item	2450661	et	2	main
päll	doc_491521501740_item	2450666	et	3	main
vend	doc_491521501740_item	2450671	et	3	main
toon	doc_491521501740_item	2450675	et	4	main
aitan	doc_491521501740_item	2450678	et	3	main
vrd	doc_491521501740_item	2450681	et	4	main
pakkus	doc_491521501740_item	2450689	et	3	main
võimalust	doc_491521501740_item	2450690	et	3	main
ette	doc_491521501740_item	2450691	et	4	main
võtma	doc_491521501740_item	2450692	et	3	main
elu	doc_491521501740_item	2450693	et	4	main
näitab	doc_491521501740_item	2450694	et	3	main
et	doc_491521501740_item	2450695	et	3	main
mitte	doc_491521501740_item	2450696	et	3	main
alati	doc_491521501740_item	2450697	et	4	main
ülikooliharidus	doc_491521501740_item	2450698	et	3	main
aitab	doc_491521501740_item	2450699	et	3	main
inimesel	doc_491521501740_item	2450700	et	3	main
head	doc_491521501740_item	2450701	et	4	main
töökoha	doc_491521501740_item	2450702	et	4	main
leidma	doc_491521501740_item	2450703	et	3	main
grammatika	doc_491521501740_item	2450704	et	4	main
infinitiivide	doc_491521501740_item	2450705	et	3	main
käändevormide	doc_491521501740_item	2450706	et	4	main
moodustamise	doc_491521501740_item	2450707	et	4	main
ja	doc_491521501740_item	2450708	et	3	main
kasutamise	doc_491521501740_item	2450709	et	4	main
vead	doc_491521501740_item	2450710	et	4	main
infinitiivide	doc_491521501740_item	2450711	et	3	main
käändelised	doc_491521501740_item	2450712	et	4	main
vormid	doc_491521501740_item	2450713	et	4	main
on	doc_491521501740_item	2450714	et	4	main
eriti	doc_491521501740_item	2450715	et	3	main
keerulised	doc_491521501740_item	2450716	et	4	main
vene	doc_491521501740_item	2450717	et	4	main
keele	doc_491521501740_item	2450718	et	4	main
kõnelejatele	doc_491521501740_item	2450719	et	4	main
kuna	doc_491521501740_item	2450720	et	3	main
nende	doc_491521501740_item	2450721	et	4	main
keelde	doc_491521501740_item	2450726	et	4	main
sügavaid	doc_491521501740_item	2450729	et	4	main
для	doc_491521501740_item	2450664	et	2	main
178	doc_491521501740_item	2450668	et	2	main
toob	doc_491521501740_item	2450672	et	3	main
tõlge	doc_491521501740_item	2450722	et	3	main
nõuab	doc_491521501740_item	2450727	et	3	main
viga	doc_491521501740_item	2450735	et	4	main
on	doc_491521501740_item	2450736	et	4	main
ma-	doc_491521501740_item	2450737	et	3	main
käändevorm	doc_491521501740_item	2450748	et	4	main
väsinud	doc_491521501740_item	2450760	et	4	main
sulle	doc_491521501740_item	2450761	et	3	main
seda	doc_491521501740_item	2450762	et	3	main
sulle	doc_491521501740_item	2450767	et	3	main
teda	doc_491521501740_item	2450778	et	4	main
minemast	doc_491521501740_item	2450782	et	3	main
vrd	doc_491521501740_item	2450788	et	4	main
107	doc_491521501740_item	2450796	et	2	main
inimene	doc_491521501740_item	2450799	et	3	main
ja	doc_491521501740_item	2450823	et	3	main
nüüd	doc_491521501740_item	2450825	et	4	main
juba	doc_491521501740_item	2450826	et	3	main
sööma	doc_491521501740_item	2450844	et	4	main
ülekoormuse	doc_491521501740_item	2450854	et	3	main
tekkida	doc_491521501740_item	2450855	et	3	main
esinev	doc_491521501740_item	2450867	et	4	main
oli	doc_491521501740_item	2450877	et	3	main
vene	doc_491521501740_item	2450725	et	4	main
olema	doc_491521501740_item	2450746	et	4	main
mingisugune	doc_491521501740_item	2450747	et	3	main
liitumast	doc_491521501740_item	2450758	et	4	main
olen	doc_491521501740_item	2450759	et	3	main
olen	doc_491521501740_item	2450765	et	3	main
soovitas	doc_491521501740_item	2450790	et	3	main
mõnikord	doc_491521501740_item	2450797	et	3	main
teadmiste	doc_491521501740_item	2450802	et	4	main
tõttu	doc_491521501740_item	2450803	et	4	main
kasutama	doc_491521501740_item	2450804	et	3	main
vormi	doc_491521501740_item	2450805	et	4	main
mis	doc_491521501740_item	2450806	et	4	main
tuleb	doc_491521501740_item	2450807	et	3	main
meelde	doc_491521501740_item	2450808	et	3	main
esimesena	doc_491521501740_item	2450809	et	3	main
samuti	doc_491521501740_item	2450810	et	3	main
kasutatakse	doc_491521501740_item	2450811	et	3	main
infinitiive	doc_491521501740_item	2450812	et	3	main
seal	doc_491521501740_item	2450813	et	4	main
neid	doc_491521501740_item	2450815	et	4	main
kus	doc_491521501740_item	2450814	et	3	main
pole	doc_491521501740_item	2450816	et	3	main
üldse	doc_491521501740_item	2450817	et	3	main
vajagi	doc_491521501740_item	2450818	et	4	main
näiteks	doc_491521501740_item	2450819	et	4	main
piret	doc_491521501740_item	2450820	et	4	main
telefonihelin	doc_491521501740_item	2450834	et	3	main
katkestab	doc_491521501740_item	2450835	et	3	main
varahommikust	doc_491521501740_item	2450836	et	4	main
und	doc_491521501740_item	2450837	et	4	main
pahandab	doc_491521501740_item	2450845	et	3	main
pinge	doc_491521501740_item	2450856	et	4	main
saamisel	doc_491521501740_item	2450857	et	4	main
maandage	doc_491521501740_item	2450858	et	3	main
da-infinitiivi	doc_491521501740_item	2450862	et	4	main
mamardašvili	doc_491521501740_item	2450879	et	2	main
kuulata	doc_491521501740_item	2450881	et	4	main
selle	doc_491521501740_item	2450883	et	4	main
artikli	doc_491521501740_item	2450884	et	3	main
verbivormist	doc_491521501740_item	2450914	et	4	main
lekseemi	doc_491521501740_item	2450916	et	4	main
komponendina	doc_491521501740_item	2450917	et	3	main
tihti	doc_491521501740_item	2450919	et	3	main
nt	doc_491521501740_item	2450923	et	4	main
sündinud	doc_491521501740_item	2450940	et	4	main
et	doc_491521501740_item	2450941	et	3	main
arengutase	doc_491521501740_item	2450946	et	3	main
nende	doc_491521501740_item	2450948	et	4	main
люди	doc_491521501740_item	2450951	et	2	main
что-то	doc_491521501740_item	2450956	et	2	main
чтобы	doc_491521501740_item	2450961	et	2	main
развития	doc_491521501740_item	2450967	et	2	main
mõte	doc_491521501740_item	2450971	et	3	main
mõtelda	doc_491521501740_item	2451002	et	4	main
romaan	doc_491521501740_item	2451004	et	3	main
роман	doc_491521501740_item	2451006	et	2	main
задуматься	doc_491521501740_item	2451008	et	2	main
uskusid	doc_491521501740_item	2451010	et	4	main
pühalikult	doc_491521501740_item	2451011	et	4	main
lõpuks	doc_491521501740_item	2451015	et	4	main
iseseisvust	doc_491521501740_item	2451017	et	4	main
teadmisi	doc_491521501740_item	2450730	et	4	main
ja	doc_491521501740_item	2450731	et	3	main
ja	doc_491521501740_item	2450738	et	3	main
da-infinitiivi	doc_491521501740_item	2450739	et	4	main
kasutamine	doc_491521501740_item	2450740	et	4	main
vales	doc_491521501740_item	2450741	et	3	main
konstruktsioonis	doc_491521501740_item	2450742	et	3	main
fraasis	doc_491521501740_item	2450743	et	3	main
ma-	doc_491521501740_item	2450750	et	3	main
nt	doc_491521501740_item	2450753	et	4	main
korratakordama	doc_491521501740_item	2450763	et	4	main
vrd	doc_491521501740_item	2450764	et	4	main
vrd	doc_491521501740_item	2450776	et	4	main
hoiatasime	doc_491521501740_item	2450777	et	3	main
ta	doc_491521501740_item	2450789	et	4	main
kipub	doc_491521501740_item	2450798	et	3	main
konkurssi	doc_491521501740_item	2450822	et	4	main
on	doc_491521501740_item	2450824	et	4	main
üle	doc_491521501740_item	2450827	et	3	main
nädala	doc_491521501740_item	2450828	et	3	main
väikestele	doc_491521501740_item	2450829	et	4	main
segab	doc_491521501740_item	2450838	et	3	main
nii	doc_491521501740_item	2450839	et	3	main
lõunasööki	doc_491521501740_item	2450840	et	4	main
valmistama	doc_491521501740_item	2450841	et	3	main
inimest	doc_491521501740_item	2450846	et	3	main
ja	doc_491521501740_item	2450860	et	3	main
viga	doc_491521501740_item	2450868	et	4	main
da-infinitiivi	doc_491521501740_item	2450869	et	4	main
kasutamine	doc_491521501740_item	2450870	et	4	main
artikli	doc_491521501740_item	2450875	et	3	main
loenguid	doc_491521501740_item	2450880	et	4	main
vrd	doc_491521501740_item	2450882	et	4	main
autor	doc_491521501740_item	2450885	et	3	main
oli	doc_491521501740_item	2450886	et	3	main
õnnelik	doc_491521501740_item	2450887	et	3	main
mamardašvili	doc_491521501740_item	2450888	et	2	main
loenguid	doc_491521501740_item	2450889	et	4	main
kuulates	doc_491521501740_item	2450890	et	4	main
metslang	doc_491521501740_item	2450891	et	3	main
2003	doc_491521501740_item	2450892	et	2	main
108	doc_491521501740_item	2450893	et	2	main
da-infinitiiv	doc_491521501740_item	2450894	et	3	main
ei	doc_491521501740_item	2450895	et	4	main
pruugi	doc_491521501740_item	2450896	et	4	main
kuuluma	doc_491521501740_item	2450897	et	3	main
ainult	doc_491521501740_item	2450898	et	4	main
pealause	doc_491521501740_item	2450899	et	4	main
koosseisu	doc_491521501740_item	2450900	et	4	main
öeldist	doc_491521501740_item	2450901	et	3	main
äite	doc_491521501740_item	2450902	et	4	main
aluse	doc_491521501740_item	2450903	et	4	main
sihitise	doc_491521501740_item	2450904	et	3	main
määruse	doc_491521501740_item	2450905	et	3	main
või	doc_491521501740_item	2450906	et	4	main
täiendina	doc_491521501740_item	2450907	et	3	main
see	doc_491521501740_item	2450908	et	3	main
võib	doc_491521501740_item	2450909	et	3	main
esineda	doc_491521501740_item	2450910	et	3	main
ka	doc_491521501740_item	2450911	et	3	main
kõrvallause	doc_491521501740_item	2450912	et	4	main
või	doc_491521501740_item	2450913	et	4	main
näiteks	doc_491521501740_item	2450929	et	4	main
mõned	doc_491521501740_item	2450930	et	3	main
inimesed	doc_491521501740_item	2450931	et	3	main
on	doc_491521501740_item	2450932	et	4	main
on	doc_491521501740_item	2450939	et	4	main
aga	doc_491521501740_item	2450944	et	3	main
on	doc_491521501740_item	2450947	et	4	main
для	doc_491521501740_item	2450953	et	2	main
миру	doc_491521501740_item	2450958	et	2	main
двор	doc_491521501740_item	2450963	et	2	main
руках	doc_491521501740_item	2450970	et	2	main
vaatama	doc_491521501740_item	2450977	et	3	main
filmi	doc_491521501740_item	2450978	et	4	main
tekkis	doc_491521501740_item	2450979	et	3	main
mul	doc_491521501740_item	2450980	et	3	main
pärast	doc_491521501740_item	2450981	et	4	main
tpü	doc_491521501740_item	2450982	et	4	main
muuseumi	doc_491521501740_item	2450983	et	4	main
külastamist	doc_491521501740_item	2450984	et	4	main
идея	doc_491521501740_item	2450985	et	2	main
прочитать	doc_491521501740_item	2450986	et	2	main
или	doc_491521501740_item	2450988	et	2	main
посмотреть	doc_491521501740_item	2450989	et	2	main
фильм	doc_491521501740_item	2450990	et	2	main
роман	doc_491521501740_item	2450987	et	2	main
появилась	doc_491521501740_item	2450991	et	2	main
у	doc_491521501740_item	2450992	et	2	main
меня	doc_491521501740_item	2450993	et	2	main
после	doc_491521501740_item	2450994	et	2	main
посещения	doc_491521501740_item	2450995	et	2	main
музея	doc_491521501740_item	2450996	et	2	main
в	doc_491521501740_item	2450997	et	2	main
тпу	doc_491521501740_item	2450998	et	2	main
see	doc_491521501740_item	2450999	et	3	main
on	doc_491521501740_item	2451000	et	4	main
väga	doc_491521501740_item	2451001	et	3	main
da-infinitiiv	doc_491521501740_item	2450921	et	3	main
läksin	doc_491521501740_item	2450924	et	3	main
et	doc_491521501740_item	2450926	et	3	main
midagi	doc_491521501740_item	2450935	et	4	main
maailmale	doc_491521501740_item	2450936	et	4	main
avastama	doc_491521501740_item	2450937	et	3	main
mõned	doc_491521501740_item	2450938	et	3	main
koristama	doc_491521501740_item	2450943	et	3	main
того	doc_491521501740_item	2450954	et	2	main
убирать	doc_491521501740_item	2450962	et	2	main
их	doc_491521501740_item	2450966	et	2	main
lugema	doc_491521501740_item	2450972	et	4	main
nimed	doc_491521501740_item	2450974	et	3	main
või	doc_491521501740_item	2450976	et	4	main
этот	doc_491521501740_item	2451005	et	2	main
oma	doc_491521501740_item	2451012	et	4	main
eesmärkidesse	doc_491521501740_item	2451013	et	3	main
omandama	doc_491521501740_item	2451014	et	3	main
свято	doc_491521501740_item	2451019	et	2	main
в	doc_491521501740_item	2451021	et	2	main
võimalust	doc_491521501740_item	2451029	et	3	main
nõuavad	doc_491521501740_item	2451041	et	4	main
kas	doc_491521501740_item	2451042	et	3	main
ma-	doc_491521501740_item	2451043	et	3	main
järgi	doc_491521501740_item	2451054	et	4	main
kas	doc_491521501740_item	2451055	et	3	main
ma-	doc_491521501740_item	2451056	et	3	main
eesti	doc_491521501740_item	2451062	et	4	main
siis	doc_491521501740_item	2451078	et	3	main
sulle	doc_491521501740_item	2451081	et	3	main
kasulikku	doc_491521501740_item	2451083	et	4	main
99	doc_491521501740_item	2451088	et	2	main
eesti	doc_491521501740_item	2451093	et	4	main
tohtinud	doc_491521501740_item	2451124	et	4	main
miks	doc_491521501740_item	2451130	et	4	main
keegi	doc_491521501740_item	2451131	et	4	main
näiteks	doc_491521501740_item	2451137	et	4	main
kangelane	doc_491521501740_item	2451138	et	3	main
kaua	doc_491521501740_item	2451139	et	3	main
ei	doc_491521501740_item	2451140	et	4	main
ta	doc_491521501740_item	2451147	et	4	main
ei	doc_491521501740_item	2451149	et	4	main
võitlema	doc_491521501740_item	2451151	et	3	main
oma	doc_491521501740_item	2451152	et	4	main
rahva	doc_491521501740_item	2451153	et	3	main
õpima	doc_491521501740_item	2451159	et	4	main
vigade	doc_491521501740_item	2451165	et	3	main
on	doc_491521501740_item	2451170	et	4	main
milliste	doc_491521501740_item	2451177	et	3	main
tüüp	doc_491521501740_item	2451207	et	3	main
arv	doc_491521501740_item	2451208	et	3	main
protsent	doc_491521501740_item	2451209	et	3	main
ma-infinitiiv	doc_491521501740_item	2451210	et	3	main
da-infinitiivi	doc_491521501740_item	2451211	et	4	main
36	doc_491521501740_item	2451218	et	2	main
2	doc_491521501740_item	2451225	et	2	main
millega	doc_491521501740_item	2451227	et	3	main
tehakse	doc_491521501740_item	2451229	et	3	main
11	doc_491521501740_item	2451234	et	2	main
1111	doc_491521501740_item	2451238	et	2	main
panema	doc_491521501740_item	2451248	et	3	main
tabelitest	doc_491521501740_item	2451253	et	4	main
ma-infinitiiv	doc_491521501740_item	2451256	et	3	main
võrdse	doc_491521501740_item	2451264	et	3	main
põhiarvust	doc_491521501740_item	2451272	et	4	main
põhisõnavara	doc_491521501740_item	2451320	et	4	main
ja	doc_491521501740_item	2451322	et	3	main
seega	doc_491521501740_item	2451323	et	4	main
eriti	doc_491521501740_item	2451329	et	3	main
sageli	doc_491521501740_item	2451330	et	3	main
ja	doc_491521501740_item	2451339	et	3	main
nad	doc_491521501740_item	2451347	et	3	main
selles	doc_491521501740_item	2451353	et	4	main
analüüsis	doc_491521501740_item	2451354	et	4	main
ainult	doc_491521501740_item	2451358	et	4	main
uurimuse	doc_491521501740_item	2451361	et	3	main
ja	doc_491521501740_item	2451363	et	3	main
kasutatud	doc_491521501740_item	2451368	et	4	main
second	doc_491521501740_item	2451372	et	4	main
press	doc_491521501740_item	2451377	et	3	main
käsiraamat	doc_491521501740_item	2451384	et	3	main
некоторые	doc_491521501740_item	2450950	et	2	main
чтобы	doc_491521501740_item	2450955	et	2	main
рождены	doc_491521501740_item	2450960	et	2	main
уровень	doc_491521501740_item	2450965	et	2	main
их	doc_491521501740_item	2450969	et	2	main
romaani	doc_491521501740_item	2450973	et	4	main
marmortahvlil	doc_491521501740_item	2450975	et	3	main
gümnasistid	doc_491521501740_item	2451009	et	3	main
верили	doc_491521501740_item	2451020	et	2	main
свои	doc_491521501740_item	2451022	et	2	main
долгожданную	doc_491521501740_item	2451025	et	2	main
head	doc_491521501740_item	2451030	et	4	main
leidma	doc_491521501740_item	2451032	et	3	main
образование	doc_491521501740_item	2451033	et	2	main
дает	doc_491521501740_item	2451034	et	2	main
возможность	doc_491521501740_item	2451035	et	2	main
хорошую	doc_491521501740_item	2451037	et	2	main
eesti	doc_491521501740_item	2451046	et	4	main
keeles	doc_491521501740_item	2451047	et	4	main
hulk	doc_491521501740_item	2451049	et	3	main
verbe	doc_491521501740_item	2451050	et	3	main
mis	doc_491521501740_item	2451051	et	4	main
nõuavad	doc_491521501740_item	2451052	et	4	main
reeglite	doc_491521501740_item	2451053	et	3	main
õpetatakse	doc_491521501740_item	2451061	et	3	main
esmajärjekorras	doc_491521501740_item	2451065	et	4	main
reeglid	doc_491521501740_item	2451070	et	3	main
maksma	doc_491521501740_item	2451087	et	3	main
krooni	doc_491521501740_item	2451089	et	4	main
sa	doc_491521501740_item	2451091	et	3	main
oskad	doc_491521501740_item	2451092	et	3	main
keelt	doc_491521501740_item	2451094	et	4	main
rääkima	doc_491521501740_item	2451095	et	3	main
ma	doc_491521501740_item	2451096	et	3	main
oskan	doc_491521501740_item	2451097	et	3	main
õpetama	doc_491521501740_item	2451098	et	3	main
võõrkeelt	doc_491521501740_item	2451099	et	4	main
välismaalastele	doc_491521501740_item	2451100	et	4	main
ma	doc_491521501740_item	2451101	et	3	main
sees	doc_491521501740_item	2451121	et	4	main
tolla	doc_491521501740_item	2451126	et	4	main
inimesed	doc_491521501740_item	2451128	et	3	main
suutnud	doc_491521501740_item	2451141	et	4	main
otsustama	doc_491521501740_item	2451142	et	3	main
kumma	doc_491521501740_item	2451143	et	3	main
lihtsalt	doc_491521501740_item	2451148	et	4	main
vastu	doc_491521501740_item	2451154	et	3	main
mulle	doc_491521501740_item	2451155	et	4	main
mul	doc_491521501740_item	2451160	et	3	main
on	doc_491521501740_item	2451161	et	4	main
homseks	doc_491521501740_item	2451162	et	3	main
esinemise	doc_491521501740_item	2451166	et	4	main
allolevates	doc_491521501740_item	2451168	et	3	main
tabelites	doc_491521501740_item	2451169	et	3	main
märgitud	doc_491521501740_item	2451176	et	4	main
asemel	doc_491521501740_item	2451212	et	4	main
5061	doc_491521501740_item	2451214	et	2	main
4444	doc_491521501740_item	2451219	et	2	main
viga	doc_491521501740_item	2451221	et	4	main
tabel	doc_491521501740_item	2451224	et	3	main
vigu	doc_491521501740_item	2451228	et	3	main
arv	doc_491521501740_item	2451231	et	3	main
1358	doc_491521501740_item	2451235	et	2	main
tahtma	doc_491521501740_item	2451239	et	3	main
minema	doc_491521501740_item	2451242	et	3	main
3	doc_491521501740_item	2451246	et	2	main
näha	doc_491521501740_item	2451254	et	3	main
da-infinitiivi	doc_491521501740_item	2451267	et	4	main
но	doc_491521501740_item	2450964	et	2	main
в	doc_491521501740_item	2450968	et	2	main
annab	doc_491521501740_item	2451028	et	3	main
või	doc_491521501740_item	2451044	et	4	main
on	doc_491521501740_item	2451048	et	4	main
oskamine	doc_491521501740_item	2451079	et	4	main
võib	doc_491521501740_item	2451085	et	3	main
lugema	doc_491521501740_item	2451125	et	4	main
oma	doc_491521501740_item	2451132	et	4	main
eluga	doc_491521501740_item	2451133	et	3	main
riskides	doc_491521501740_item	2451134	et	4	main
varjas	doc_491521501740_item	2451135	et	4	main
seda	doc_491521501740_item	2451136	et	3	main
on	doc_491521501740_item	2451145	et	4	main
suuda	doc_491521501740_item	2451150	et	4	main
keel	doc_491521501740_item	2451158	et	4	main
õppima	doc_491521501740_item	2451164	et	3	main
kohta	doc_491521501740_item	2451174	et	4	main
ja	doc_491521501740_item	2451175	et	3	main
vea	doc_491521501740_item	2451206	et	4	main
ma-infinitiivi	doc_491521501740_item	2451216	et	4	main
panev	doc_491521501740_item	2451003	et	4	main
заставляет	doc_491521501740_item	2451007	et	2	main
kauaoodatud	doc_491521501740_item	2451016	et	3	main
гимназисты	doc_491521501740_item	2451018	et	2	main
получить	doc_491521501740_item	2451024	et	2	main
свободу	doc_491521501740_item	2451026	et	2	main
või	doc_491521501740_item	2451057	et	4	main
da-infinitiivi	doc_491521501740_item	2451058	et	4	main
neid	doc_491521501740_item	2451059	et	4	main
reegleid	doc_491521501740_item	2451060	et	3	main
õppijatele	doc_491521501740_item	2451064	et	4	main
vigu	doc_491521501740_item	2451066	et	3	main
tehakse	doc_491521501740_item	2451067	et	3	main
siis	doc_491521501740_item	2451068	et	3	main
kui	doc_491521501740_item	2451069	et	3	main
jäävad	doc_491521501740_item	2451071	et	4	main
omandamata	doc_491521501740_item	2451072	et	4	main
näiteks	doc_491521501740_item	2451073	et	4	main
kui	doc_491521501740_item	2451074	et	3	main
sa	doc_491521501740_item	2451075	et	3	main
armastad	doc_491521501740_item	2451076	et	3	main
matkama	doc_491521501740_item	2451077	et	3	main
see	doc_491521501740_item	2451086	et	3	main
kas	doc_491521501740_item	2451090	et	3	main
soovin	doc_491521501740_item	2451102	et	3	main
цели	doc_491521501740_item	2451023	et	2	main
haridus	doc_491521501740_item	2451027	et	3	main
tööd	doc_491521501740_item	2451031	et	4	main
найти	doc_491521501740_item	2451036	et	2	main
работу	doc_491521501740_item	2451038	et	2	main
verbid	doc_491521501740_item	2451039	et	3	main
mis	doc_491521501740_item	2451040	et	4	main
da-infinitiivi	doc_491521501740_item	2451045	et	4	main
keele	doc_491521501740_item	2451063	et	4	main
võõrkeelte	doc_491521501740_item	2451080	et	3	main
vaga	doc_491521501740_item	2451082	et	4	main
teile	doc_491521501740_item	2451084	et	4	main
kohe	doc_491521501740_item	2451103	et	4	main
alustama	doc_491521501740_item	2451104	et	3	main
kui	doc_491521501740_item	2451105	et	3	main
ma	doc_491521501740_item	2451106	et	3	main
nägin	doc_491521501740_item	2451107	et	3	main
raamatu	doc_491521501740_item	2451108	et	4	main
ilma	doc_491521501740_item	2451109	et	4	main
köiteta	doc_491521501740_item	2451110	et	4	main
punase	doc_491521501740_item	2451111	et	4	main
kirjaga	doc_491521501740_item	2451112	et	3	main
keelatud	doc_491521501740_item	2451113	et	4	main
mus	doc_491521501740_item	2451114	et	3	main
äratas	doc_491521501740_item	2451115	et	3	main
huvi	doc_491521501740_item	2451116	et	4	main
mis	doc_491521501740_item	2451117	et	4	main
on	doc_491521501740_item	2451118	et	4	main
selle	doc_491521501740_item	2451119	et	4	main
raamatu	doc_491521501740_item	2451120	et	4	main
mida	doc_491521501740_item	2451122	et	4	main
poolel	doc_491521501740_item	2451144	et	4	main
esitatud	doc_491521501740_item	2451171	et	4	main
41	doc_491521501740_item	2451213	et	2	main
da-infinitiiv	doc_491521501740_item	2451215	et	3	main
käändevormi	doc_491521501740_item	2451220	et	4	main
4	doc_491521501740_item	2451222	et	2	main
verb	doc_491521501740_item	2451230	et	3	main
5	doc_491521501740_item	2451243	et	2	main
37	doc_491521501740_item	2451247	et	2	main
nägu	doc_491521501740_item	2451251	et	4	main
umbes	doc_491521501740_item	2451263	et	4	main
sagedusega	doc_491521501740_item	2451265	et	4	main
5061	doc_491521501740_item	2451270	et	2	main
ma-infinitiivi	doc_491521501740_item	2451274	et	4	main
4444	doc_491521501740_item	2451277	et	2	main
kuna	doc_491521501740_item	2451278	et	3	main
vahe	doc_491521501740_item	2451279	et	4	main
kahe	doc_491521501740_item	2451280	et	3	main
et	doc_491521501740_item	2451315	et	3	main
need	doc_491521501740_item	2451316	et	3	main
verbid	doc_491521501740_item	2451317	et	3	main
sisse	doc_491521501740_item	2451321	et	4	main
ja	doc_491521501740_item	2451327	et	3	main
või	doc_491521501740_item	2451341	et	4	main
stabiilsed	doc_491521501740_item	2451345	et	3	main
esitatud	doc_491521501740_item	2451355	et	4	main
arvud	doc_491521501740_item	2451356	et	3	main
konkreetse	doc_491521501740_item	2451360	et	3	main
oxford	doc_491521501740_item	2451375	et	4	main
university	doc_491521501740_item	2451376	et	4	main
m	doc_491521501740_item	2451380	et	4	main
eesti	doc_491521501740_item	2451382	et	4	main
tallinn	doc_491521501740_item	2451385	et	4	main
ei	doc_491521501740_item	2451123	et	4	main
aja	doc_491521501740_item	2451127	et	4	main
ja	doc_491521501740_item	2451129	et	3	main
tema	doc_491521501740_item	2451146	et	4	main
meldib	doc_491521501740_item	2451156	et	4	main
eesti	doc_491521501740_item	2451157	et	4	main
veel	doc_491521501740_item	2451163	et	4	main
sagedus	doc_491521501740_item	2451167	et	4	main
statistika	doc_491521501740_item	2451172	et	4	main
vigade	doc_491521501740_item	2451173	et	3	main
verbidega	doc_491521501740_item	2451178	et	3	main
eksitakse	doc_491521501740_item	2451179	et	4	main
sagedamini	doc_491521501740_item	2451180	et	4	main
kui	doc_491521501740_item	2451181	et	3	main
teistega	doc_491521501740_item	2451182	et	4	main
antud	doc_491521501740_item	2451183	et	4	main
alanüüs	doc_491521501740_item	2451184	et	3	main
on	doc_491521501740_item	2451185	et	4	main
tehtud	doc_491521501740_item	2451186	et	4	main
autori	doc_491521501740_item	2451187	et	3	main
poolt	doc_491521501740_item	2451188	et	4	main
kogutud	doc_491521501740_item	2451189	et	4	main
näidete	doc_491521501740_item	2451190	et	3	main
põhjal	doc_491521501740_item	2451191	et	4	main
kokku	doc_491521501740_item	2451192	et	3	main
on	doc_491521501740_item	2451193	et	4	main
näidet	doc_491521501740_item	2451194	et	3	main
81	doc_491521501740_item	2451195	et	2	main
ja	doc_491521501740_item	2451196	et	3	main
need	doc_491521501740_item	2451197	et	3	main
tulevad	doc_491521501740_item	2451198	et	4	main
kirjalikest	doc_491521501740_item	2451199	et	3	main
töödest	doc_491521501740_item	2451200	et	3	main
tabel	doc_491521501740_item	2451201	et	3	main
1	doc_491521501740_item	2451202	et	2	main
vigade	doc_491521501740_item	2451203	et	3	main
esinemise	doc_491521501740_item	2451204	et	4	main
sagedus	doc_491521501740_item	2451205	et	4	main
asemel	doc_491521501740_item	2451217	et	4	main
pidama	doc_491521501740_item	2451233	et	4	main
9	doc_491521501740_item	2451237	et	2	main
8	doc_491521501740_item	2451240	et	2	main
617	doc_491521501740_item	2451244	et	2	main
37	doc_491521501740_item	2451250	et	2	main
esineb	doc_491521501740_item	2451255	et	3	main
da-infinitiivi	doc_491521501740_item	2451257	et	4	main
ja	doc_491521501740_item	2451259	et	3	main
da-infinitiiv	doc_491521501740_item	2451260	et	3	main
ma-infinitiivi	doc_491521501740_item	2451261	et	4	main
ma-infinitiiv	doc_491521501740_item	2451266	et	3	main
võtab	doc_491521501740_item	2451269	et	3	main
näitajate	doc_491521501740_item	2451281	et	4	main
sellest	doc_491521501740_item	2451314	et	4	main
kuuluvad	doc_491521501740_item	2451318	et	4	main
neid	doc_491521501740_item	2451324	et	4	main
ei	doc_491521501740_item	2451335	et	4	main
saa	doc_491521501740_item	2451336	et	4	main
olukorras	doc_491521501740_item	2451338	et	3	main
kõneleja	doc_491521501740_item	2451340	et	4	main
olla	doc_491521501740_item	2451344	et	3	main
paljudest	doc_491521501740_item	2451349	et	3	main
rõhutame	doc_491521501740_item	2451351	et	3	main
et	doc_491521501740_item	2451352	et	3	main
ühe	doc_491521501740_item	2451359	et	4	main
neid	doc_491521501740_item	2451365	et	4	main
r	doc_491521501740_item	2451371	et	4	main
acquisition	doc_491521501740_item	2451374	et	4	main
2000	doc_491521501740_item	2451378	et	2	main
jt	doc_491521501740_item	2451381	et	4	main
p	doc_491521501740_item	2451391	et	4	main
1994	doc_491521501740_item	2451403	et	2	main
lk	doc_491521501740_item	2451404	et	4	main
171-187	doc_491521501740_item	2451405	et	2	main
eslon	doc_491521501740_item	2451406	et	4	main
493	doc_491521501740_item	2451223	et	2	main
verbid	doc_491521501740_item	2451226	et	3	main
protsent	doc_491521501740_item	2451232	et	3	main
hakkama	doc_491521501740_item	2451236	et	3	main
987	doc_491521501740_item	2451241	et	2	main
tulema	doc_491521501740_item	2451245	et	4	main
3	doc_491521501740_item	2451249	et	2	main
on	doc_491521501740_item	2451252	et	4	main
asemel	doc_491521501740_item	2451258	et	4	main
asemel	doc_491521501740_item	2451262	et	4	main
asemel	doc_491521501740_item	2451268	et	4	main
vigade	doc_491521501740_item	2451271	et	3	main
da-infinitiiv	doc_491521501740_item	2451273	et	3	main
asemel	doc_491521501740_item	2451275	et	4	main
aga	doc_491521501740_item	2451276	et	3	main
vahel	doc_491521501740_item	2451282	et	4	main
on	doc_491521501740_item	2451283	et	4	main
üsna	doc_491521501740_item	2451284	et	3	main
väike	doc_491521501740_item	2451285	et	4	main
saab	doc_491521501740_item	2451286	et	3	main
järeldada	doc_491521501740_item	2451287	et	3	main
et	doc_491521501740_item	2451288	et	3	main
ei	doc_491521501740_item	2451289	et	4	main
ole	doc_491521501740_item	2451290	et	4	main
ühte	doc_491521501740_item	2451291	et	4	main
infinitiivi	doc_491521501740_item	2451292	et	4	main
mida	doc_491521501740_item	2451293	et	4	main
kiputakse	doc_491521501740_item	2451294	et	3	main
üldistama	doc_491521501740_item	2451295	et	3	main
ja	doc_491521501740_item	2451296	et	3	main
kasutama	doc_491521501740_item	2451297	et	3	main
teise	doc_491521501740_item	2451298	et	4	main
infinitiivi	doc_491521501740_item	2451299	et	4	main
asemel	doc_491521501740_item	2451300	et	4	main
verbidest	doc_491521501740_item	2451301	et	3	main
eksitakse	doc_491521501740_item	2451302	et	4	main
kõige	doc_491521501740_item	2451303	et	4	main
tihedamini	doc_491521501740_item	2451304	et	4	main
pidama	doc_491521501740_item	2451305	et	4	main
hakkama	doc_491521501740_item	2451306	et	3	main
tahtma	doc_491521501740_item	2451307	et	3	main
minema	doc_491521501740_item	2451308	et	3	main
verbidega	doc_491521501740_item	2451309	et	3	main
see	doc_491521501740_item	2451310	et	3	main
võib	doc_491521501740_item	2451311	et	3	main
olla	doc_491521501740_item	2451312	et	3	main
tingitud	doc_491521501740_item	2451313	et	4	main
kuuluvad	doc_491521501740_item	2451319	et	4	main
kasutatakse	doc_491521501740_item	2451325	et	3	main
märkame	doc_491521501740_item	2451331	et	3	main
arvud	doc_491521501740_item	2451334	et	3	main
igas	doc_491521501740_item	2451337	et	3	main
puhul	doc_491521501740_item	2451343	et	4	main
sõltuvad	doc_491521501740_item	2451348	et	4	main
puhul	doc_491521501740_item	2451362	et	4	main
üldistada	doc_491521501740_item	2451364	et	3	main
ei	doc_491521501740_item	2451366	et	4	main
tohi	doc_491521501740_item	2451367	et	4	main
language	doc_491521501740_item	2451373	et	4	main
erelt	doc_491521501740_item	2451379	et	4	main
keele	doc_491521501740_item	2451383	et	4	main
размышления	doc_491521501740_item	2451392	et	2	main
eslon	doc_491521501740_item	2451396	et	4	main
kõrvutav	doc_491521501740_item	2451398	et	4	main
keeleteadus	doc_491521501740_item	2451399	et	4	main
eslon	doc_491521501740_item	2451427	et	4	main
p	doc_491521501740_item	2451428	et	4	main
роль	doc_491521501740_item	2451429	et	2	main
определении	doc_491521501740_item	2451433	et	2	main
и	doc_491521501740_item	2451438	et	2	main
и	doc_491521501740_item	2451443	et	2	main
связи	doc_491521501740_item	2451449	et	2	main
и	doc_491521501740_item	2451452	et	2	main
языков	doc_491521501740_item	2451457	et	2	main
1991	doc_491521501740_item	2451460	et	2	main
70-76	doc_491521501740_item	2451462	et	2	main
kõrvutav	doc_491521501740_item	2451481	et	4	main
kirjastus	doc_491521501740_item	2451484	et	4	main
1967	doc_491521501740_item	2451486	et	2	main
pihlak	doc_491521501740_item	2451487	et	4	main
связи	doc_491521501740_item	2451501	et	2	main
и	doc_491521501740_item	2451504	et	2	main
a	doc_491521501740_item	2451516	et	4	main
tähelepanekuid	doc_491521501740_item	2451517	et	3	main
keeles	doc_491521501740_item	2451522	et	4	main
kirjandus	doc_491521501740_item	2451526	et	3	main
a	doc_491521501740_item	2451531	et	4	main
1985b	doc_491521501740_item	2451542	et	4	main
lk	doc_491521501740_item	2451543	et	4	main
62-93	doc_491521501740_item	2451544	et	2	main
päll	doc_491521501740_item	2451545	et	3	main
e	doc_491521501740_item	2451546	et	4	main
kõrvutav	doc_491521501740_item	2451552	et	4	main
eesti	doc_491521501740_item	2451555	et	4	main
vene	doc_491521501740_item	2451565	et	4	main
keel	doc_491521501740_item	2451570	et	4	main
tallinn	doc_491521501740_item	2451574	et	4	main
tpü	doc_491521501740_item	2451575	et	4	main
lk	doc_491521501740_item	2451578	et	4	main
kontrastiivsest	doc_491521501740_item	2451585	et	4	main
lk	doc_491521501740_item	2451621	et	4	main
näited	doc_491521501740_item	2451624	et	3	main
infinitiivi	doc_491521501740_item	2451629	et	4	main
ta	doc_491521501740_item	2451639	et	4	main
süüa	doc_491521501740_item	2451641	et	3	main
inglise	doc_491521501740_item	2451646	et	4	main
keelt	doc_491521501740_item	2451647	et	4	main
õppida	doc_491521501740_item	2451648	et	3	main
4	doc_491521501740_item	2451649	et	2	main
5	doc_491521501740_item	2451656	et	2	main
flmi	doc_491521501740_item	2451660	et	4	main
lõunasööki	doc_491521501740_item	2451669	et	4	main
ka	doc_491521501740_item	2451672	et	3	main
huvitava	doc_491521501740_item	2451676	et	4	main
telesaade	doc_491521501740_item	2451677	et	4	main
veel	doc_491521501740_item	2451690	et	4	main
õppima	doc_491521501740_item	2451691	et	3	main
9	doc_491521501740_item	2451692	et	2	main
tule	doc_491521501740_item	2451700	et	4	main
15	doc_491521501740_item	2451728	et	2	main
sportima	doc_491521501740_item	2451743	et	4	main
tohi	doc_491521501740_item	2451747	et	4	main
ülekoormuse	doc_491521501740_item	2451749	et	3	main
vigade	doc_491521501740_item	2451333	et	3	main
kõnes	doc_491521501740_item	2451326	et	3	main
kirjas	doc_491521501740_item	2451328	et	4	main
et	doc_491521501740_item	2451332	et	3	main
kirjutaja	doc_491521501740_item	2451342	et	4	main
kuna	doc_491521501740_item	2451346	et	3	main
faktoritest	doc_491521501740_item	2451350	et	4	main
kehtivad	doc_491521501740_item	2451357	et	4	main
kirjandus	doc_491521501740_item	2451369	et	3	main
ellis	doc_491521501740_item	2451370	et	4	main
sihtasutus	doc_491521501740_item	2451388	et	4	main
2000	doc_491521501740_item	2451389	et	2	main
eslon	doc_491521501740_item	2451390	et	4	main
предложениях	doc_491521501740_item	2451395	et	2	main
tallinn	doc_491521501740_item	2451400	et	4	main
p	doc_491521501740_item	2451407	et	4	main
расхождения	doc_491521501740_item	2451408	et	2	main
употреблении	doc_491521501740_item	2451410	et	2	main
в	doc_491521501740_item	2451412	et	2	main
русском	doc_491521501740_item	2451413	et	2	main
и	doc_491521501740_item	2451414	et	2	main
эстонском	doc_491521501740_item	2451415	et	2	main
языках	doc_491521501740_item	2451416	et	2	main
воросы	doc_491521501740_item	2451417	et	2	main
сопоставительного	doc_491521501740_item	2451418	et	2	main
исследования	doc_491521501740_item	2451419	et	2	main
языков	doc_491521501740_item	2451420	et	2	main
tallinna	doc_491521501740_item	2451422	et	4	main
1990	doc_491521501740_item	2451424	et	2	main
lk	doc_491521501740_item	2451425	et	4	main
28-58	doc_491521501740_item	2451426	et	2	main
отношений	doc_491521501740_item	2451431	et	2	main
языковых	doc_491521501740_item	2451436	et	2	main
на	doc_491521501740_item	2451440	et	2	main
инфинитива	doc_491521501740_item	2451445	et	2	main
парадигматические	doc_491521501740_item	2451448	et	2	main
на	doc_491521501740_item	2451454	et	2	main
pedagoogikainstitut	doc_491521501740_item	2451459	et	4	main
lk	doc_491521501740_item	2451461	et	4	main
metslang	doc_491521501740_item	2451463	et	3	main
a	doc_491521501740_item	2451488	et	4	main
об	doc_491521501740_item	2451489	et	2	main
одном	doc_491521501740_item	2451490	et	2	main
способе	doc_491521501740_item	2451491	et	2	main
обозначения	doc_491521501740_item	2451492	et	2	main
аномальных	doc_491521501740_item	2451493	et	2	main
состояний	doc_491521501740_item	2451494	et	2	main
в	doc_491521501740_item	2451495	et	2	main
эстонском	doc_491521501740_item	2451496	et	2	main
синтагматические	doc_491521501740_item	2451498	et	2	main
категорий	doc_491521501740_item	2451505	et	2	main
tallinn	doc_491521501740_item	2451523	et	4	main
1985a	doc_491521501740_item	2451527	et	4	main
149-158	doc_491521501740_item	2451529	et	2	main
pihlak	doc_491521501740_item	2451530	et	4	main
perifrastilised	doc_491521501740_item	2451535	et	4	main
aspektitähenduse	doc_491521501740_item	2451537	et	4	main
väljendajana	doc_491521501740_item	2451538	et	4	main
tallinn	doc_491521501740_item	2451539	et	4	main
keele	doc_491521501740_item	2451551	et	4	main
kirjastus	doc_491521501740_item	2451557	et	4	main
eesti	doc_491521501740_item	2451563	et	4	main
ja	doc_491521501740_item	2451564	et	3	main
eesti	doc_491521501740_item	2451569	et	4	main
2004	doc_491521501740_item	2451577	et	2	main
1	doc_491521501740_item	2451623	et	2	main
vene	doc_491521501740_item	2451625	et	4	main
kõnelejate	doc_491521501740_item	2451626	et	4	main
peab	doc_491521501740_item	2451635	et	4	main
te	doc_491521501740_item	2451650	et	4	main
lapsele	doc_491521501740_item	2451654	et	4	main
keele	doc_491521501740_item	2451387	et	4	main
об	doc_491521501740_item	2451393	et	2	main
tallinna	doc_491521501740_item	2451401	et	4	main
pedagoogikaülikool	doc_491521501740_item	2451402	et	4	main
в	doc_491521501740_item	2451432	et	2	main
едениц	doc_491521501740_item	2451437	et	2	main
русского	doc_491521501740_item	2451442	et	2	main
и	doc_491521501740_item	2451447	et	2	main
категорий	doc_491521501740_item	2451453	et	2	main
grammatika	doc_491521501740_item	2451482	et	4	main
и	doc_491521501740_item	2451499	et	2	main
на	doc_491521501740_item	2451506	et	2	main
tallinna	doc_491521501740_item	2451510	et	4	main
1991	doc_491521501740_item	2451512	et	2	main
eesti	doc_491521501740_item	2451386	et	4	main
инфинитивных	doc_491521501740_item	2451394	et	2	main
p	doc_491521501740_item	2451397	et	4	main
в	doc_491521501740_item	2451409	et	2	main
инфинитива	doc_491521501740_item	2451411	et	2	main
tallinn	doc_491521501740_item	2451421	et	4	main
pedagoogikainstitut	doc_491521501740_item	2451423	et	4	main
внутрисистемных	doc_491521501740_item	2451430	et	2	main
функционального	doc_491521501740_item	2451434	et	2	main
каткгорий	doc_491521501740_item	2451439	et	2	main
эстонского	doc_491521501740_item	2451444	et	2	main
едениц	doc_491521501740_item	2451451	et	2	main
разносистемных	doc_491521501740_item	2451456	et	2	main
tallinn	doc_491521501740_item	2451483	et	4	main
valgus	doc_491521501740_item	2451485	et	4	main
парадигматические	doc_491521501740_item	2451500	et	2	main
едениц	doc_491521501740_item	2451503	et	2	main
разносистемных	doc_491521501740_item	2451508	et	2	main
pedagoogikainstitut	doc_491521501740_item	2451511	et	4	main
40-44	doc_491521501740_item	2451514	et	2	main
pihlak	doc_491521501740_item	2451515	et	4	main
ja	doc_491521501740_item	2451519	et	3	main
eesti	doc_491521501740_item	2451521	et	4	main
lk	doc_491521501740_item	2451528	et	4	main
ühendverbid	doc_491521501740_item	2451533	et	3	main
ars	doc_491521501740_item	2451540	et	4	main
jt	doc_491521501740_item	2451547	et	4	main
eesti	doc_491521501740_item	2451548	et	4	main
ja	doc_491521501740_item	2451549	et	3	main
riiklik	doc_491521501740_item	2451556	et	3	main
vaiss	doc_491521501740_item	2451559	et	4	main
verbi	doc_491521501740_item	2451561	et	4	main
aspektikategooria	doc_491521501740_item	2451562	et	4	main
võõrkeelest	doc_491521501740_item	2451571	et	4	main
poolt	doc_491521501740_item	2451627	et	4	main
eesti	doc_491521501740_item	2451628	et	4	main
saada	doc_491521501740_item	2451636	et	4	main
peate	doc_491521501740_item	2451651	et	4	main
lähen	doc_491521501740_item	2451657	et	3	main
uut	doc_491521501740_item	2451659	et	3	main
praegu	doc_491521501740_item	2451682	et	3	main
8	doc_491521501740_item	2451686	et	2	main
on	doc_491521501740_item	2451688	et	4	main
teile	doc_491521501740_item	2451693	et	4	main
võib	doc_491521501740_item	2451694	et	3	main
see	doc_491521501740_item	2451695	et	3	main
maksma	doc_491521501740_item	2451696	et	3	main
minuga	doc_491521501740_item	2451701	et	3	main
потенциала	doc_491521501740_item	2451435	et	2	main
материале	doc_491521501740_item	2451441	et	2	main
синтагматические	doc_491521501740_item	2451446	et	2	main
языковых	doc_491521501740_item	2451450	et	2	main
материале	doc_491521501740_item	2451455	et	2	main
tallinna	doc_491521501740_item	2451458	et	4	main
h	doc_491521501740_item	2451464	et	4	main
jt	doc_491521501740_item	2451465	et	4	main
keelehärm	doc_491521501740_item	2451466	et	3	main
eesti	doc_491521501740_item	2451467	et	4	main
keele	doc_491521501740_item	2451468	et	4	main
probleemseid	doc_491521501740_item	2451469	et	3	main
piirkondi	doc_491521501740_item	2451470	et	4	main
tallinn	doc_491521501740_item	2451471	et	4	main
tallinna	doc_491521501740_item	2451472	et	4	main
pedagoogikaülikool	doc_491521501740_item	2451473	et	4	main
2003	doc_491521501740_item	2451474	et	2	main
mölder	doc_491521501740_item	2451475	et	3	main
a	doc_491521501740_item	2451476	et	4	main
eesti	doc_491521501740_item	2451477	et	4	main
ja	doc_491521501740_item	2451478	et	3	main
vene	doc_491521501740_item	2451479	et	4	main
keele	doc_491521501740_item	2451480	et	4	main
языке	doc_491521501740_item	2451497	et	2	main
языковых	doc_491521501740_item	2451502	et	2	main
материале	doc_491521501740_item	2451507	et	2	main
языков	doc_491521501740_item	2451509	et	2	main
lk	doc_491521501740_item	2451513	et	4	main
kursiivsusest	doc_491521501740_item	2451518	et	4	main
terminatiivsusest	doc_491521501740_item	2451520	et	4	main
ja	doc_491521501740_item	2451525	et	3	main
eesti	doc_491521501740_item	2451532	et	4	main
grammatika	doc_491521501740_item	2451541	et	4	main
grammatika	doc_491521501740_item	2451553	et	4	main
1962	doc_491521501740_item	2451558	et	2	main
teiseks	doc_491521501740_item	2451572	et	4	main
kirjastus	doc_491521501740_item	2451576	et	4	main
145-163	doc_491521501740_item	2451579	et	2	main
verschik	doc_491521501740_item	2451580	et	4	main
analüüsist	doc_491521501740_item	2451586	et	3	main
m	doc_491521501740_item	2451587	et	4	main
lisa	doc_491521501740_item	2451622	et	4	main
valikul	doc_491521501740_item	2451630	et	3	main
tehtud	doc_491521501740_item	2451631	et	4	main
vigadest	doc_491521501740_item	2451632	et	3	main
1	doc_491521501740_item	2451633	et	2	main
tööst	doc_491521501740_item	2451634	et	3	main
rahuldust	doc_491521501740_item	2451637	et	4	main
osta	doc_491521501740_item	2451642	et	4	main
3	doc_491521501740_item	2451643	et	2	main
ma	doc_491521501740_item	2451644	et	3	main
ei	doc_491521501740_item	2451652	et	4	main
maksta	doc_491521501740_item	2451653	et	4	main
homme	doc_491521501740_item	2451658	et	3	main
vaatamise	doc_491521501740_item	2451678	et	4	main
tööd	doc_491521501740_item	2451684	et	4	main
mul	doc_491521501740_item	2451687	et	3	main
koos	doc_491521501740_item	2451702	et	4	main
teha	doc_491521501740_item	2451721	et	3	main
palju	doc_491521501740_item	2451726	et	4	main
paras	doc_491521501740_item	2451729	et	3	main
aga	doc_491521501740_item	2451733	et	3	main
võib	doc_491521501740_item	2451735	et	3	main
puhkama	doc_491521501740_item	2451744	et	3	main
õpetab	doc_491521501740_item	2451778	et	3	main
mõned	doc_491521501740_item	2451780	et	3	main
et	doc_491521501740_item	2451784	et	3	main
on	doc_491521501740_item	2451789	et	4	main
21	doc_491521501740_item	2451800	et	2	main
elu	doc_491521501740_item	2451801	et	4	main
inimesel	doc_491521501740_item	2451808	et	3	main
22	doc_491521501740_item	2451812	et	2	main
luban	doc_491521501740_item	2451813	et	3	main
23	doc_491521501740_item	2451815	et	2	main
talle	doc_491521501740_item	2451818	et	4	main
seal	doc_491521501740_item	2451819	et	4	main
elada	doc_491521501740_item	2451827	et	3	main
jääda	doc_491521501740_item	2451828	et	4	main
sellepärast	doc_491521501740_item	2451829	et	3	main
armus	doc_491521501740_item	2451833	et	4	main
24	doc_491521501740_item	2451838	et	2	main
vaatama	doc_491521501740_item	2451845	et	3	main
tpü	doc_491521501740_item	2451850	et	4	main
muuseumi	doc_491521501740_item	2451851	et	4	main
ma	doc_491521501740_item	2451855	et	3	main
ei	doc_491521501740_item	2451872	et	4	main
oma	doc_491521501740_item	2451881	et	4	main
juhib	doc_491521501740_item	2451922	et	3	main
on	doc_491521501740_item	2451925	et	4	main
muidugi	doc_491521501740_item	2451926	et	4	main
ka	doc_491521501740_item	2451933	et	3	main
kangelane	doc_491521501740_item	2451937	et	3	main
lihtsalt	doc_491521501740_item	2451948	et	4	main
oma	doc_491521501740_item	2451952	et	4	main
on	doc_491521501740_item	2451957	et	4	main
mõtelda	doc_491521501740_item	2451959	et	4	main
34	doc_491521501740_item	2451962	et	2	main
ning	doc_491521501740_item	2451963	et	3	main
see	doc_491521501740_item	2451964	et	3	main
peaks	doc_491521501740_item	2451965	et	4	main
ka	doc_491521501740_item	2451970	et	3	main
kui	doc_491521501740_item	2451998	et	3	main
39	doc_491521501740_item	2452017	et	2	main
kuule	doc_491521501740_item	2452018	et	4	main
keele	doc_491521501740_item	2451524	et	4	main
ja	doc_491521501740_item	2451534	et	3	main
verbid	doc_491521501740_item	2451536	et	3	main
vene	doc_491521501740_item	2451550	et	4	main
tallinn	doc_491521501740_item	2451554	et	4	main
n	doc_491521501740_item	2451560	et	4	main
keeles	doc_491521501740_item	2451566	et	4	main
m	doc_491521501740_item	2451567	et	4	main
rannut	doc_491521501740_item	2451568	et	4	main
keeleks	doc_491521501740_item	2451573	et	4	main
a	doc_491521501740_item	2451581	et	4	main
mõnda	doc_491521501740_item	2451582	et	4	main
vahekeelest	doc_491521501740_item	2451583	et	4	main
ja	doc_491521501740_item	2451584	et	3	main
rannut	doc_491521501740_item	2451588	et	4	main
eesti	doc_491521501740_item	2451589	et	4	main
keel	doc_491521501740_item	2451590	et	4	main
võõrkeelest	doc_491521501740_item	2451591	et	4	main
teiseks	doc_491521501740_item	2451592	et	4	main
keeleks	doc_491521501740_item	2451593	et	4	main
tallinn	doc_491521501740_item	2451594	et	4	main
tpü	doc_491521501740_item	2451595	et	4	main
kirjastus	doc_491521501740_item	2451596	et	4	main
2004	doc_491521501740_item	2451597	et	2	main
lk	doc_491521501740_item	2451598	et	4	main
132-145	doc_491521501740_item	2451599	et	2	main
бондаренко	doc_491521501740_item	2451600	et	2	main
а	doc_491521501740_item	2451601	et	2	main
вид	doc_491521501740_item	2451602	et	2	main
и	doc_491521501740_item	2451603	et	2	main
русского	doc_491521501740_item	2451605	et	2	main
время	doc_491521501740_item	2451604	et	2	main
глагола	doc_491521501740_item	2451606	et	2	main
moskva	doc_491521501740_item	2451607	et	4	main
1971	doc_491521501740_item	2451608	et	2	main
lk	doc_491521501740_item	2451609	et	4	main
3-112	doc_491521501740_item	2451610	et	2	main
энциклопедия	doc_491521501740_item	2451611	et	2	main
русский	doc_491521501740_item	2451612	et	2	main
язык	doc_491521501740_item	2451613	et	2	main
moskva	doc_491521501740_item	2451614	et	4	main
большая	doc_491521501740_item	2451615	et	2	main
российская	doc_491521501740_item	2451616	et	2	main
энциклопедия	doc_491521501740_item	2451617	et	2	main
kirjastus	doc_491521501740_item	2451618	et	4	main
дрофа	doc_491521501740_item	2451619	et	2	main
1997	doc_491521501740_item	2451620	et	2	main
2	doc_491521501740_item	2451638	et	2	main
peab	doc_491521501740_item	2451640	et	4	main
läksin	doc_491521501740_item	2451645	et	3	main
raha	doc_491521501740_item	2451655	et	4	main
vaadata	doc_491521501740_item	2451661	et	4	main
6	doc_491521501740_item	2451662	et	2	main
telefonihelin	doc_491521501740_item	2451663	et	3	main
katkestab	doc_491521501740_item	2451664	et	3	main
und	doc_491521501740_item	2451666	et	4	main
nii	doc_491521501740_item	2451668	et	3	main
valmistama	doc_491521501740_item	2451670	et	3	main
kui	doc_491521501740_item	2451671	et	3	main
ajal	doc_491521501740_item	2451679	et	4	main
7	doc_491521501740_item	2451680	et	2	main
olen	doc_491521501740_item	2451681	et	3	main
tegedes	doc_491521501740_item	2451685	et	4	main
10	doc_491521501740_item	2451699	et	2	main
kingitusi	doc_491521501740_item	2451703	et	4	main
osta	doc_491521501740_item	2451704	et	4	main
11	doc_491521501740_item	2451705	et	2	main
ma	doc_491521501740_item	2451706	et	3	main
tahan	doc_491521501740_item	2451707	et	3	main
töötama	doc_491521501740_item	2451709	et	3	main
12	doc_491521501740_item	2451710	et	2	main
kas	doc_491521501740_item	2451711	et	3	main
sa	doc_491521501740_item	2451712	et	3	main
palju	doc_491521501740_item	2451708	et	4	main
oskad	doc_491521501740_item	2451713	et	3	main
eesti	doc_491521501740_item	2451714	et	4	main
keelt	doc_491521501740_item	2451715	et	4	main
rääkima	doc_491521501740_item	2451716	et	3	main
13	doc_491521501740_item	2451717	et	2	main
hakkame	doc_491521501740_item	2451718	et	3	main
nüüd	doc_491521501740_item	2451719	et	4	main
harjutust	doc_491521501740_item	2451720	et	4	main
vaja	doc_491521501740_item	2451725	et	4	main
meid	doc_491521501740_item	2451731	et	4	main
tuua	doc_491521501740_item	2451736	et	3	main
tagajärgi	doc_491521501740_item	2451738	et	4	main
lasta	doc_491521501740_item	2451748	et	4	main
pinge	doc_491521501740_item	2451751	et	4	main
tohi	doc_491521501740_item	2451759	et	4	main
lasta	doc_491521501740_item	2451760	et	4	main
19	doc_491521501740_item	2451764	et	2	main
võitis	doc_491521501740_item	2451766	et	3	main
seda	doc_491521501740_item	2451776	et	3	main
emakeelt	doc_491521501740_item	2451777	et	4	main
20	doc_491521501740_item	2451779	et	2	main
sündinud	doc_491521501740_item	2451783	et	4	main
sündinud	doc_491521501740_item	2451790	et	4	main
et	doc_491521501740_item	2451791	et	3	main
näitab	doc_491521501740_item	2451802	et	3	main
aitab	doc_491521501740_item	2451807	et	3	main
töökoha	doc_491521501740_item	2451810	et	4	main
parandama	doc_491521501740_item	2451814	et	3	main
kirjutab	doc_491521501740_item	2451816	et	3	main
meeldib	doc_491521501740_item	2451821	et	3	main
ta	doc_491521501740_item	2451831	et	4	main
lugeda	doc_491521501740_item	2451840	et	3	main
tekkis	doc_491521501740_item	2451847	et	3	main
mul	doc_491521501740_item	2451848	et	3	main
nägin	doc_491521501740_item	2451856	et	3	main
ilma	doc_491521501740_item	2451858	et	4	main
huvi	doc_491521501740_item	2451865	et	4	main
varahommikust	doc_491521501740_item	2451665	et	4	main
segab	doc_491521501740_item	2451667	et	3	main
sööma	doc_491521501740_item	2451673	et	4	main
pahandab	doc_491521501740_item	2451674	et	3	main
inimest	doc_491521501740_item	2451675	et	3	main
rasket	doc_491521501740_item	2451683	et	3	main
homseks	doc_491521501740_item	2451689	et	3	main
99	doc_491521501740_item	2451697	et	2	main
krooni	doc_491521501740_item	2451698	et	4	main
mul	doc_491521501740_item	2451723	et	3	main
õppima	doc_491521501740_item	2451727	et	3	main
paneb	doc_491521501740_item	2451730	et	3	main
tegutseda	doc_491521501740_item	2451732	et	3	main
17	doc_491521501740_item	2451745	et	2	main
18	doc_491521501740_item	2451757	et	2	main
pinge	doc_491521501740_item	2451762	et	4	main
eestlastele	doc_491521501740_item	2451775	et	4	main
on	doc_491521501740_item	2451782	et	4	main
maailmale	doc_491521501740_item	2451786	et	4	main
on	doc_491521501740_item	2451797	et	4	main
mitte	doc_491521501740_item	2451804	et	3	main
14	doc_491521501740_item	2451722	et	2	main
on	doc_491521501740_item	2451724	et	4	main
lisakoormus	doc_491521501740_item	2451734	et	3	main
soovimatu	doc_491521501740_item	2451737	et	4	main
16	doc_491521501740_item	2451739	et	2	main
sel	doc_491521501740_item	2451740	et	3	main
juhul	doc_491521501740_item	2451741	et	3	main
tuleb	doc_491521501740_item	2451742	et	3	main
ei	doc_491521501740_item	2451746	et	4	main
tekkida	doc_491521501740_item	2451750	et	3	main
saamisel	doc_491521501740_item	2451752	et	4	main
maandage	doc_491521501740_item	2451753	et	3	main
sportima	doc_491521501740_item	2451754	et	4	main
ja	doc_491521501740_item	2451755	et	3	main
puhkama	doc_491521501740_item	2451756	et	3	main
ei	doc_491521501740_item	2451758	et	4	main
tekkima	doc_491521501740_item	2451763	et	3	main
on	doc_491521501740_item	2451769	et	4	main
juba	doc_491521501740_item	2451771	et	3	main
üle	doc_491521501740_item	2451772	et	3	main
inimesed	doc_491521501740_item	2451781	et	3	main
midagi	doc_491521501740_item	2451785	et	4	main
mõned	doc_491521501740_item	2451788	et	3	main
õues	doc_491521501740_item	2451792	et	4	main
koristama	doc_491521501740_item	2451793	et	3	main
aga	doc_491521501740_item	2451794	et	3	main
nende	doc_491521501740_item	2451795	et	4	main
arengutase	doc_491521501740_item	2451796	et	3	main
et	doc_491521501740_item	2451803	et	3	main
väga	doc_491521501740_item	2451820	et	3	main
ja	doc_491521501740_item	2451822	et	3	main
ta	doc_491521501740_item	2451824	et	4	main
seal	doc_491521501740_item	2451826	et	4	main
arhitektuurisse	doc_491521501740_item	2451835	et	3	main
loodusse	doc_491521501740_item	2451837	et	4	main
nimed	doc_491521501740_item	2451842	et	3	main
marmortahvlil	doc_491521501740_item	2451843	et	3	main
või	doc_491521501740_item	2451844	et	4	main
filmi	doc_491521501740_item	2451846	et	4	main
pärast	doc_491521501740_item	2451849	et	4	main
külastamist	doc_491521501740_item	2451852	et	4	main
keelatud	doc_491521501740_item	2451862	et	4	main
mus	doc_491521501740_item	2451863	et	3	main
raamatu	doc_491521501740_item	2451869	et	4	main
sees	doc_491521501740_item	2451870	et	4	main
lugema	doc_491521501740_item	2451874	et	4	main
ja	doc_491521501740_item	2451878	et	3	main
miks	doc_491521501740_item	2451879	et	4	main
armastus	doc_491521501740_item	2451927	et	4	main
30	doc_491521501740_item	2451928	et	2	main
aga	doc_491521501740_item	2451929	et	3	main
armastus	doc_491521501740_item	2451930	et	4	main
kahelda	doc_491521501740_item	2451934	et	4	main
kaua	doc_491521501740_item	2451938	et	3	main
32	doc_491521501740_item	2451946	et	2	main
ta	doc_491521501740_item	2451947	et	4	main
vastu	doc_491521501740_item	2451954	et	3	main
meie	doc_491521501740_item	2451966	et	4	main
võimatu	doc_491521501740_item	2451999	et	4	main
siis	doc_491521501740_item	2452000	et	3	main
saab	doc_491521501740_item	2452001	et	3	main
ilma	doc_491521501740_item	2452002	et	4	main
ka	doc_491521501740_item	2452003	et	3	main
hakata	doc_491521501740_item	2452004	et	4	main
pole	doc_491521501740_item	2452010	et	3	main
miksida	doc_491521501740_item	2452015	et	4	main
välguga	doc_491521501740_item	2452016	et	3	main
juhul	doc_491521501740_item	2452022	et	3	main
panin	doc_491521501740_item	2452025	et	3	main
kinni	doc_491521501740_item	2452028	et	3	main
asja	doc_491521501740_item	2452041	et	4	main
ta	doc_491521501740_item	2452055	et	4	main
neid	doc_491521501740_item	2452069	et	4	main
päästa	doc_491521501740_item	2452079	et	4	main
45	doc_491521501740_item	2452080	et	2	main
haridus	doc_491521501740_item	2452081	et	3	main
head	doc_491521501740_item	2452084	et	4	main
head	doc_491521501740_item	2452121	et	4	main
eksamites	doc_491521501740_item	2452123	et	3	main
52	doc_491521501740_item	2452140	et	2	main
ta	doc_491521501740_item	2452141	et	4	main
pakkus	doc_491521501740_item	2452142	et	3	main
võimalust	doc_491521501740_item	2452143	et	3	main
natuke	doc_491521501740_item	2452162	et	4	main
mulle	doc_491521501740_item	2452167	et	4	main
augustil	doc_491521501740_item	2452169	et	3	main
õppima	doc_491521501740_item	2452170	et	3	main
55	doc_491521501740_item	2452174	et	2	main
eesti	doc_491521501740_item	2452177	et	4	main
tahan	doc_491521501740_item	2452181	et	3	main
eile	doc_491521501740_item	2452189	et	3	main
tegelema	doc_491521501740_item	2452223	et	3	main
abistada	doc_491521501740_item	2452228	et	3	main
sinu	doc_491521501740_item	2452232	et	3	main
ja	doc_491521501740_item	2452234	et	3	main
osata	doc_491521501740_item	2452245	et	4	main
ülekoormust	doc_491521501740_item	2451761	et	4	main
piret	doc_491521501740_item	2451765	et	4	main
konkurssi	doc_491521501740_item	2451767	et	4	main
ja	doc_491521501740_item	2451768	et	3	main
nüüd	doc_491521501740_item	2451770	et	4	main
nädala	doc_491521501740_item	2451773	et	3	main
väikestele	doc_491521501740_item	2451774	et	4	main
avastama	doc_491521501740_item	2451787	et	3	main
nende	doc_491521501740_item	2451798	et	4	main
kätes	doc_491521501740_item	2451799	et	3	main
alati	doc_491521501740_item	2451805	et	4	main
ülikooliharidus	doc_491521501740_item	2451806	et	3	main
head	doc_491521501740_item	2451809	et	4	main
leidma	doc_491521501740_item	2451811	et	3	main
et	doc_491521501740_item	2451817	et	3	main
et	doc_491521501740_item	2451823	et	3	main
tahab	doc_491521501740_item	2451825	et	3	main
et	doc_491521501740_item	2451830	et	3	main
ja	doc_491521501740_item	2451836	et	3	main
mõte	doc_491521501740_item	2451839	et	3	main
romaani	doc_491521501740_item	2451841	et	4	main
kui	doc_491521501740_item	2451854	et	3	main
äratas	doc_491521501740_item	2451864	et	3	main
mis	doc_491521501740_item	2451866	et	4	main
on	doc_491521501740_item	2451867	et	4	main
mida	doc_491521501740_item	2451871	et	4	main
tolla	doc_491521501740_item	2451875	et	4	main
aja	doc_491521501740_item	2451876	et	4	main
inimesed	doc_491521501740_item	2451877	et	3	main
minu	doc_491521501740_item	2451917	et	3	main
arvates	doc_491521501740_item	2451918	et	4	main
lausa	doc_491521501740_item	2451832	et	4	main
norra	doc_491521501740_item	2451834	et	4	main
25	doc_491521501740_item	2451853	et	2	main
raamatu	doc_491521501740_item	2451857	et	4	main
köiteta	doc_491521501740_item	2451859	et	4	main
punase	doc_491521501740_item	2451860	et	4	main
kirjaga	doc_491521501740_item	2451861	et	3	main
selle	doc_491521501740_item	2451868	et	4	main
tohtinud	doc_491521501740_item	2451873	et	4	main
eluga	doc_491521501740_item	2451882	et	3	main
riskides	doc_491521501740_item	2451883	et	4	main
varjas	doc_491521501740_item	2451884	et	4	main
seda	doc_491521501740_item	2451885	et	3	main
26	doc_491521501740_item	2451886	et	2	main
aitan	doc_491521501740_item	2451887	et	3	main
laps	doc_491521501740_item	2451888	et	4	main
pesema	doc_491521501740_item	2451889	et	3	main
27	doc_491521501740_item	2451890	et	2	main
miks	doc_491521501740_item	2451891	et	4	main
siis	doc_491521501740_item	2451892	et	3	main
tuleb	doc_491521501740_item	2451893	et	3	main
nii	doc_491521501740_item	2451894	et	3	main
kallist	doc_491521501740_item	2451895	et	4	main
maksma	doc_491521501740_item	2451896	et	3	main
selle	doc_491521501740_item	2451897	et	4	main
eest	doc_491521501740_item	2451898	et	4	main
ja	doc_491521501740_item	2451899	et	3	main
kas	doc_491521501740_item	2451900	et	3	main
see	doc_491521501740_item	2451901	et	3	main
on	doc_491521501740_item	2451902	et	4	main
seda	doc_491521501740_item	2451903	et	3	main
väärt	doc_491521501740_item	2451904	et	4	main
28	doc_491521501740_item	2451905	et	2	main
nad	doc_491521501740_item	2451906	et	3	main
olid	doc_491521501740_item	2451907	et	4	main
küll	doc_491521501740_item	2451908	et	4	main
nõus	doc_491521501740_item	2451909	et	4	main
ohverdama	doc_491521501740_item	2451910	et	3	main
oma	doc_491521501740_item	2451911	et	4	main
elu	doc_491521501740_item	2451912	et	4	main
isamaa	doc_491521501740_item	2451913	et	4	main
vabaduse	doc_491521501740_item	2451914	et	4	main
eest	doc_491521501740_item	2451915	et	4	main
29	doc_491521501740_item	2451916	et	2	main
keegi	doc_491521501740_item	2451880	et	4	main
31	doc_491521501740_item	2451935	et	2	main
ei	doc_491521501740_item	2451939	et	4	main
suutnud	doc_491521501740_item	2451940	et	4	main
otsustama	doc_491521501740_item	2451941	et	3	main
kumma	doc_491521501740_item	2451942	et	3	main
poolel	doc_491521501740_item	2451943	et	4	main
ei	doc_491521501740_item	2451949	et	4	main
rahva	doc_491521501740_item	2451953	et	3	main
see	doc_491521501740_item	2451956	et	3	main
väga	doc_491521501740_item	2451958	et	3	main
panev	doc_491521501740_item	2451960	et	4	main
romaan	doc_491521501740_item	2451961	et	3	main
ikka	doc_491521501740_item	2451969	et	4	main
kindlasti	doc_491521501740_item	2452007	et	3	main
nagu	doc_491521501740_item	2452008	et	3	main
päevavalgust	doc_491521501740_item	2452012	et	4	main
igal	doc_491521501740_item	2452021	et	3	main
ja	doc_491521501740_item	2452024	et	3	main
ei	doc_491521501740_item	2452033	et	4	main
40	doc_491521501740_item	2452037	et	2	main
sellega	doc_491521501740_item	2452038	et	3	main
tahetakse	doc_491521501740_item	2452039	et	4	main
näitama	doc_491521501740_item	2452040	et	3	main
minna	doc_491521501740_item	2452047	et	3	main
kilomeetrit	doc_491521501740_item	2452061	et	4	main
koguda	doc_491521501740_item	2452065	et	3	main
44	doc_491521501740_item	2452070	et	2	main
proovida	doc_491521501740_item	2452073	et	3	main
inimese	doc_491521501740_item	2452077	et	4	main
elu	doc_491521501740_item	2452078	et	4	main
50	doc_491521501740_item	2452124	et	2	main
kipuvad	doc_491521501740_item	2452126	et	3	main
ma	doc_491521501740_item	2452147	et	3	main
ei	doc_491521501740_item	2452148	et	4	main
eesti	doc_491521501740_item	2452151	et	4	main
mind	doc_491521501740_item	2452159	et	4	main
ma	doc_491521501740_item	2452160	et	3	main
hakkasin	doc_491521501740_item	2452161	et	3	main
54	doc_491521501740_item	2452166	et	2	main
minema	doc_491521501740_item	2452171	et	3	main
mina	doc_491521501740_item	2452185	et	4	main
peamiseks	doc_491521501740_item	2451919	et	3	main
jõuks	doc_491521501740_item	2451920	et	3	main
mis	doc_491521501740_item	2451921	et	4	main
inimesi	doc_491521501740_item	2451923	et	4	main
samaaegselt	doc_491521501740_item	2451931	et	4	main
on	doc_491521501740_item	2451944	et	4	main
tema	doc_491521501740_item	2451945	et	4	main
võitlema	doc_491521501740_item	2451951	et	3	main
tänapäeva	doc_491521501740_item	2451967	et	4	main
noortele	doc_491521501740_item	2451968	et	3	main
38	doc_491521501740_item	2452005	et	2	main
nii	doc_491521501740_item	2452009	et	3	main
ja	doc_491521501740_item	2452013	et	3	main
peab	doc_491521501740_item	2452014	et	4	main
ostsin	doc_491521501740_item	2452019	et	3	main
nüüd	doc_491521501740_item	2452020	et	4	main
tegutseda	doc_491521501740_item	2451924	et	3	main
paneb	doc_491521501740_item	2451932	et	3	main
näiteks	doc_491521501740_item	2451936	et	4	main
suuda	doc_491521501740_item	2451950	et	4	main
33	doc_491521501740_item	2451955	et	2	main
midagi	doc_491521501740_item	2451971	et	4	main
35	doc_491521501740_item	2451973	et	2	main
õpetada	doc_491521501740_item	2451972	et	3	main
peategelane	doc_491521501740_item	2451974	et	3	main
läks	doc_491521501740_item	2451975	et	3	main
oma	doc_491521501740_item	2451976	et	4	main
klassivendadega	doc_491521501740_item	2451977	et	3	main
sõtta	doc_491521501740_item	2451978	et	3	main
oma	doc_491521501740_item	2451979	et	4	main
kodumaad	doc_491521501740_item	2451980	et	4	main
kaitsta	doc_491521501740_item	2451981	et	4	main
36	doc_491521501740_item	2451982	et	2	main
gümnasistid	doc_491521501740_item	2451983	et	3	main
uskusid	doc_491521501740_item	2451984	et	4	main
pühalikult	doc_491521501740_item	2451985	et	4	main
oma	doc_491521501740_item	2451986	et	4	main
eesmärkidesse	doc_491521501740_item	2451987	et	3	main
omandama	doc_491521501740_item	2451988	et	3	main
lõpuks	doc_491521501740_item	2451989	et	4	main
kauaoodatud	doc_491521501740_item	2451990	et	3	main
37	doc_491521501740_item	2451992	et	2	main
iseseisvust	doc_491521501740_item	2451991	et	4	main
vaipade	doc_491521501740_item	2451993	et	3	main
pildistamiseks	doc_491521501740_item	2451994	et	4	main
päevavalgus	doc_491521501740_item	2451995	et	4	main
oleks	doc_491521501740_item	2451996	et	3	main
hea	doc_491521501740_item	2451997	et	4	main
interjööris	doc_491521501740_item	2452006	et	3	main
piisavalt	doc_491521501740_item	2452011	et	4	main
filmi	doc_491521501740_item	2452023	et	4	main
vist	doc_491521501740_item	2452031	et	4	main
me	doc_491521501740_item	2452044	et	4	main
tahame	doc_491521501740_item	2452045	et	3	main
etendusele	doc_491521501740_item	2452049	et	4	main
nautima	doc_491521501740_item	2452051	et	3	main
mängu	doc_491521501740_item	2452053	et	4	main
tahab	doc_491521501740_item	2452056	et	3	main
jooksta	doc_491521501740_item	2452057	et	4	main
igal	doc_491521501740_item	2452058	et	3	main
hommikul	doc_491521501740_item	2452059	et	3	main
kümme	doc_491521501740_item	2452060	et	3	main
ma	doc_491521501740_item	2452063	et	3	main
ja	doc_491521501740_item	2452067	et	3	main
annab	doc_491521501740_item	2452082	et	3	main
koolist	doc_491521501740_item	2452026	et	4	main
kaamera	doc_491521501740_item	2452027	et	4	main
kuna	doc_491521501740_item	2452029	et	3	main
enam	doc_491521501740_item	2452032	et	4	main
jõua	doc_491521501740_item	2452034	et	4	main
seda	doc_491521501740_item	2452035	et	3	main
tegema	doc_491521501740_item	2452036	et	3	main
kindlasti	doc_491521501740_item	2452046	et	3	main
pean	doc_491521501740_item	2452064	et	4	main
analüüsida	doc_491521501740_item	2452068	et	3	main
peab	doc_491521501740_item	2452072	et	4	main
kõike	doc_491521501740_item	2452075	et	4	main
võimalust	doc_491521501740_item	2452083	et	3	main
46	doc_491521501740_item	2452087	et	2	main
ma	doc_491521501740_item	2452088	et	3	main
pean	doc_491521501740_item	2452089	et	4	main
hakkama	doc_491521501740_item	2452090	et	3	main
õppida	doc_491521501740_item	2452091	et	3	main
pean	doc_491521501740_item	2452092	et	4	main
hakkama	doc_491521501740_item	2452093	et	3	main
hakkama	doc_491521501740_item	2452094	et	3	main
õppima	doc_491521501740_item	2452095	et	3	main
47	doc_491521501740_item	2452096	et	2	main
istuma	doc_491521501740_item	2452097	et	3	main
siin	doc_491521501740_item	2452098	et	4	main
ja	doc_491521501740_item	2452099	et	3	main
vaatama	doc_491521501740_item	2452100	et	3	main
aknast	doc_491521501740_item	2452101	et	4	main
välja	doc_491521501740_item	2452102	et	4	main
on	doc_491521501740_item	2452103	et	4	main
igav	doc_491521501740_item	2452104	et	3	main
48	doc_491521501740_item	2452105	et	2	main
mul	doc_491521501740_item	2452106	et	3	main
tuleb	doc_491521501740_item	2452107	et	3	main
minna	doc_491521501740_item	2452108	et	3	main
teha	doc_491521501740_item	2452109	et	3	main
eksamit	doc_491521501740_item	2452110	et	3	main
selle	doc_491521501740_item	2452111	et	4	main
nädala	doc_491521501740_item	2452112	et	3	main
lõpus	doc_491521501740_item	2452113	et	4	main
49	doc_491521501740_item	2452114	et	2	main
et	doc_491521501740_item	2452115	et	3	main
toetuse	doc_491521501740_item	2452116	et	4	main
ma	doc_491521501740_item	2452118	et	3	main
üritan	doc_491521501740_item	2452119	et	3	main
saama	doc_491521501740_item	2452120	et	4	main
saada	doc_491521501740_item	2452117	et	4	main
oma	doc_491521501740_item	2452127	et	4	main
liiga	doc_491521501740_item	2452130	et	4	main
homme	doc_491521501740_item	2452030	et	3	main
tähendust	doc_491521501740_item	2452042	et	4	main
41	doc_491521501740_item	2452043	et	2	main
sellele	doc_491521501740_item	2452048	et	4	main
ja	doc_491521501740_item	2452050	et	3	main
näitlejate	doc_491521501740_item	2452052	et	4	main
42	doc_491521501740_item	2452054	et	2	main
43	doc_491521501740_item	2452062	et	2	main
näiteid	doc_491521501740_item	2452066	et	3	main
arst	doc_491521501740_item	2452071	et	3	main
teha	doc_491521501740_item	2452074	et	3	main
et	doc_491521501740_item	2452076	et	3	main
tööd	doc_491521501740_item	2452085	et	4	main
leidma	doc_491521501740_item	2452086	et	3	main
vanemad	doc_491521501740_item	2452125	et	4	main
laste	doc_491521501740_item	2452128	et	4	main
palju	doc_491521501740_item	2452131	et	4	main
51	doc_491521501740_item	2452133	et	2	main
ma	doc_491521501740_item	2452134	et	3	main
tahan	doc_491521501740_item	2452135	et	3	main
ja	doc_491521501740_item	2452136	et	3	main
jäängi	doc_491521501740_item	2452137	et	3	main
siia	doc_491521501740_item	2452138	et	4	main
võtma	doc_491521501740_item	2452145	et	3	main
mitte	doc_491521501740_item	2452153	et	3	main
räägida	doc_491521501740_item	2452155	et	4	main
aga	doc_491521501740_item	2452156	et	3	main
kui	doc_491521501740_item	2452157	et	3	main
kursuse	doc_491521501740_item	2452158	et	3	main
ja	doc_491521501740_item	2452164	et	3	main
pakkusid	doc_491521501740_item	2452168	et	4	main
kursus	doc_491521501740_item	2452172	et	3	main
müügisekretär	doc_491521501740_item	2452173	et	3	main
mulle	doc_491521501740_item	2452175	et	4	main
õpima	doc_491521501740_item	2452179	et	4	main
sulle	doc_491521501740_item	2452182	et	3	main
vaja	doc_491521501740_item	2452222	et	4	main
63	doc_491521501740_item	2452230	et	2	main
kohe	doc_491521501740_item	2452235	et	4	main
hakkan	doc_491521501740_item	2452236	et	3	main
64	doc_491521501740_item	2452238	et	2	main
aga	doc_491521501740_item	2452239	et	3	main
et	doc_491521501740_item	2452240	et	3	main
seal	doc_491521501740_item	2452241	et	4	main
töötada	doc_491521501740_item	2452242	et	3	main
mina	doc_491521501740_item	2452243	et	4	main
oskamine	doc_491521501740_item	2452254	et	4	main
keelt	doc_491521501740_item	2452286	et	4	main
aga	doc_491521501740_item	2452287	et	3	main
endas	doc_491521501740_item	2452301	et	4	main
üle	doc_491521501740_item	2452315	et	3	main
taoline	doc_491521501740_item	2452318	et	3	main
oli	doc_491521501740_item	2452320	et	3	main
õige	doc_491521501740_item	2452321	et	4	main
suitsetama	doc_491521501740_item	2452344	et	4	main
palju	doc_491521501740_item	2452345	et	4	main
palus	doc_491521501740_item	2452353	et	4	main
töötama	doc_491521501740_item	2452360	et	3	main
76	doc_491521501740_item	2452363	et	2	main
ma	doc_491521501740_item	2452364	et	3	main
tahan	doc_491521501740_item	2452365	et	3	main
tuttavatele	doc_491521501740_item	2452369	et	3	main
me	doc_491521501740_item	2452371	et	4	main
78	doc_491521501740_item	2452375	et	2	main
ma	doc_491521501740_item	2452376	et	3	main
oskan	doc_491521501740_item	2452377	et	3	main
õpetama	doc_491521501740_item	2452378	et	3	main
võõrkeelt	doc_491521501740_item	2452379	et	4	main
lahkuda	doc_491521501740_item	2452385	et	3	main
töös	doc_491521501741_item	2452422	et	3	main
11	doc_491521501741_item	2452426	et	2	main
põhipraktika	doc_491521501741_item	2452436	et	4	main
erinevatel	doc_491521501741_item	2452444	et	4	main
10	doc_491521501741_item	2452449	et	2	main
kahjuks	doc_491521501741_item	2452454	et	4	main
keeleoskustase	doc_491521501741_item	2452456	et	3	main
vägagi	doc_491521501741_item	2452457	et	3	main
erinev	doc_491521501741_item	2452458	et	4	main
on	doc_491521501741_item	2452459	et	4	main
esinenud	doc_491521501741_item	2452466	et	4	main
olnud	doc_491521501741_item	2452474	et	4	main
tõlgib	doc_491521501741_item	2452502	et	3	main
ballid	doc_491521501740_item	2452122	et	3	main
eest	doc_491521501740_item	2452129	et	4	main
oodata	doc_491521501740_item	2452139	et	4	main
53	doc_491521501740_item	2452146	et	2	main
keeles	doc_491521501740_item	2452152	et	4	main
midagi	doc_491521501740_item	2452154	et	4	main
räägida	doc_491521501740_item	2452163	et	4	main
keel	doc_491521501740_item	2452178	et	4	main
kirjutama	doc_491521501740_item	2452183	et	3	main
käisin	doc_491521501740_item	2452186	et	3	main
kursusele	doc_491521501740_item	2452187	et	3	main
57	doc_491521501740_item	2452188	et	2	main
tegime	doc_491521501740_item	2452190	et	3	main
emaga	doc_491521501740_item	2452191	et	3	main
päeva	doc_491521501740_item	2452193	et	4	main
terve	doc_491521501740_item	2452192	et	4	main
sööma	doc_491521501740_item	2452194	et	4	main
58	doc_491521501740_item	2452195	et	2	main
väga	doc_491521501740_item	2452196	et	3	main
kahju	doc_491521501740_item	2452197	et	4	main
et	doc_491521501740_item	2452198	et	3	main
sina	doc_491521501740_item	2452199	et	4	main
ei	doc_491521501740_item	2452200	et	4	main
saanud	doc_491521501740_item	2452201	et	4	main
tulema	doc_491521501740_item	2452202	et	4	main
59	doc_491521501740_item	2452203	et	2	main
mul	doc_491521501740_item	2452204	et	3	main
on	doc_491521501740_item	2452205	et	4	main
väga	doc_491521501740_item	2452206	et	3	main
kahju	doc_491521501740_item	2452207	et	4	main
aga	doc_491521501740_item	2452208	et	3	main
ma	doc_491521501740_item	2452209	et	3	main
pean	doc_491521501740_item	2452210	et	4	main
ära	doc_491521501740_item	2452211	et	4	main
minna	doc_491521501740_item	2452212	et	3	main
60	doc_491521501740_item	2452213	et	2	main
ma	doc_491521501740_item	2452214	et	3	main
pean	doc_491521501740_item	2452215	et	4	main
õppida	doc_491521501740_item	2452216	et	3	main
et	doc_491521501740_item	2452217	et	3	main
töötada	doc_491521501740_item	2452218	et	3	main
61	doc_491521501740_item	2452219	et	2	main
veel	doc_491521501740_item	2452220	et	4	main
on	doc_491521501740_item	2452221	et	4	main
müüjale	doc_491521501740_item	2452229	et	4	main
sain	doc_491521501740_item	2452231	et	3	main
vastata	doc_491521501740_item	2452237	et	4	main
sulle	doc_491521501740_item	2452256	et	3	main
kasulikku	doc_491521501740_item	2452258	et	4	main
muretseda	doc_491521501740_item	2452132	et	3	main
ette	doc_491521501740_item	2452144	et	4	main
hakka	doc_491521501740_item	2452149	et	4	main
varem	doc_491521501740_item	2452150	et	4	main
kirjutada	doc_491521501740_item	2452165	et	3	main
meldib	doc_491521501740_item	2452176	et	4	main
56	doc_491521501740_item	2452180	et	2	main
kuidas	doc_491521501740_item	2452184	et	3	main
kursusetööga	doc_491521501740_item	2452224	et	3	main
hakkan	doc_491521501740_item	2452227	et	3	main
siis	doc_491521501740_item	2452253	et	3	main
vaga	doc_491521501740_item	2452257	et	4	main
keelekeskuses	doc_491521501740_item	2452280	et	4	main
õppima	doc_491521501740_item	2452284	et	3	main
eesti	doc_491521501740_item	2452285	et	4	main
69	doc_491521501740_item	2452291	et	2	main
vestlema	doc_491521501740_item	2452296	et	3	main
võõrkeelte	doc_491521501740_item	2452297	et	3	main
tunnevad	doc_491521501740_item	2452300	et	3	main
ja	doc_491521501740_item	2452303	et	3	main
ei	doc_491521501740_item	2452305	et	4	main
sellega	doc_491521501740_item	2452309	et	3	main
paneb	doc_491521501740_item	2452310	et	3	main
selle	doc_491521501740_item	2452314	et	4	main
juhtivisiku	doc_491521501740_item	2452317	et	3	main
71	doc_491521501740_item	2452322	et	2	main
on	doc_491521501740_item	2452324	et	4	main
sellega	doc_491521501740_item	2452326	et	3	main
kui	doc_491521501740_item	2452327	et	3	main
palju	doc_491521501740_item	2452328	et	4	main
ja	doc_491521501740_item	2452336	et	3	main
kus	doc_491521501740_item	2452337	et	3	main
seda	doc_491521501740_item	2452338	et	3	main
72	doc_491521501740_item	2452340	et	2	main
ta	doc_491521501740_item	2452341	et	4	main
73	doc_491521501740_item	2452346	et	2	main
te	doc_491521501740_item	2452347	et	4	main
õpetaja	doc_491521501740_item	2452352	et	4	main
meil	doc_491521501740_item	2452354	et	4	main
kirjutama	doc_491521501740_item	2452356	et	3	main
talle	doc_491521501740_item	2452358	et	4	main
meeldib	doc_491521501740_item	2452359	et	3	main
elada	doc_491521501740_item	2452373	et	3	main
peab	doc_491521501740_item	2452384	et	4	main
kell	doc_491521501740_item	2452386	et	3	main
antud	doc_491521501741_item	2452421	et	4	main
õpilaste	doc_491521501741_item	2452428	et	4	main
töid	doc_491521501741_item	2452430	et	3	main
teise	doc_491521501741_item	2452435	et	4	main
kasutatakse	doc_491521501741_item	2452439	et	3	main
klassi	doc_491521501741_item	2452441	et	4	main
õpilaste	doc_491521501741_item	2452442	et	4	main
esseid	doc_491521501741_item	2452443	et	3	main
iseenesest	doc_491521501741_item	2452472	et	4	main
ei	doc_491521501741_item	2452473	et	4	main
lauseid	doc_491521501741_item	2452500	et	3	main
väljendeid	doc_491521501741_item	2452511	et	3	main
ei	doc_491521501741_item	2452514	et	4	main
hästi	doc_491521501741_item	2452516	et	3	main
ei	doc_491521501741_item	2452519	et	4	main
62	doc_491521501740_item	2452225	et	2	main
ma	doc_491521501740_item	2452226	et	3	main
kirja	doc_491521501740_item	2452233	et	4	main
pean	doc_491521501740_item	2452244	et	4	main
võõrkeelte	doc_491521501740_item	2452255	et	3	main
66	doc_491521501740_item	2452259	et	2	main
nad	doc_491521501740_item	2452261	et	3	main
hakkavad	doc_491521501740_item	2452262	et	4	main
rääkida	doc_491521501740_item	2452263	et	3	main
67	doc_491521501740_item	2452264	et	2	main
me	doc_491521501740_item	2452265	et	4	main
tahaksime	doc_491521501740_item	2452266	et	3	main
veel	doc_491521501740_item	2452267	et	4	main
teada	doc_491521501740_item	2452268	et	3	main
saama	doc_491521501740_item	2452269	et	4	main
et	doc_491521501740_item	2452270	et	3	main
missuguse	doc_491521501740_item	2452271	et	3	main
töökogemusega	doc_491521501740_item	2452272	et	3	main
on	doc_491521501740_item	2452273	et	4	main
teie	doc_491521501740_item	2452274	et	4	main
õpetajad	doc_491521501740_item	2452275	et	4	main
kui	doc_491521501740_item	2452276	et	3	main
maksedokumendi	doc_491521501740_item	2452246	et	3	main
vormistada	doc_491521501740_item	2452247	et	3	main
65	doc_491521501740_item	2452248	et	2	main
kui	doc_491521501740_item	2452249	et	3	main
sa	doc_491521501740_item	2452250	et	3	main
armastad	doc_491521501740_item	2452251	et	3	main
matkama	doc_491521501740_item	2452252	et	3	main
töötavad	doc_491521501740_item	2452279	et	4	main
68	doc_491521501740_item	2452281	et	2	main
ma	doc_491521501740_item	2452282	et	3	main
püüan	doc_491521501740_item	2452283	et	3	main
raske	doc_491521501740_item	2452290	et	4	main
lugeja	doc_491521501740_item	2452312	et	4	main
kuidas	doc_491521501740_item	2452260	et	3	main
kaua	doc_491521501740_item	2452277	et	3	main
nad	doc_491521501740_item	2452278	et	3	main
ikkagi	doc_491521501740_item	2452288	et	4	main
väga	doc_491521501740_item	2452289	et	3	main
nendele	doc_491521501740_item	2452293	et	4	main
võimalusi	doc_491521501740_item	2452295	et	3	main
ja	doc_491521501740_item	2452298	et	3	main
parem	doc_491521501740_item	2452302	et	4	main
temal	doc_491521501740_item	2452304	et	3	main
ole	doc_491521501740_item	2452306	et	4	main
kompleksi	doc_491521501740_item	2452307	et	4	main
70	doc_491521501740_item	2452308	et	2	main
autor	doc_491521501740_item	2452311	et	3	main
kas	doc_491521501740_item	2452316	et	3	main
tegevus	doc_491521501740_item	2452319	et	4	main
pulmadele	doc_491521501740_item	2452332	et	3	main
kes	doc_491521501740_item	2452333	et	4	main
tahtnud	doc_491521501740_item	2452343	et	4	main
harjutust	doc_491521501740_item	2452350	et	4	main
kirjand	doc_491521501740_item	2452355	et	3	main
75	doc_491521501740_item	2452357	et	2	main
selles	doc_491521501740_item	2452361	et	4	main
ettevõttes	doc_491521501740_item	2452362	et	3	main
kirjutama	doc_491521501740_item	2452366	et	3	main
kirja	doc_491521501740_item	2452367	et	4	main
välismaalastele	doc_491521501740_item	2452380	et	4	main
ma	doc_491521501740_item	2452389	et	3	main
10	doc_491521501741_item	2452424	et	2	main
seal	doc_491521501740_item	2452292	et	4	main
on	doc_491521501740_item	2452294	et	4	main
nad	doc_491521501740_item	2452299	et	3	main
mõelda	doc_491521501740_item	2452313	et	4	main
raha	doc_491521501740_item	2452329	et	4	main
läks	doc_491521501740_item	2452330	et	3	main
maksta	doc_491521501740_item	2452331	et	4	main
ei	doc_491521501740_item	2452342	et	4	main
hakkate	doc_491521501740_item	2452348	et	3	main
kirjutada	doc_491521501740_item	2452349	et	3	main
oma	doc_491521501740_item	2452368	et	4	main
tallinnas	doc_491521501740_item	2452374	et	4	main
79	doc_491521501740_item	2452381	et	2	main
ta	doc_491521501740_item	2452382	et	4	main
viis	doc_491521501740_item	2452387	et	4	main
kogutud	doc_491521501741_item	2452434	et	4	main
ajal	doc_491521501741_item	2452437	et	4	main
10	doc_491521501741_item	2452440	et	2	main
teemadel	doc_491521501741_item	2452445	et	3	main
on	doc_491521501741_item	2452453	et	4	main
õpilaste	doc_491521501741_item	2452455	et	4	main
ning	doc_491521501741_item	2452467	et	3	main
ka	doc_491521501741_item	2452468	et	3	main
mis	doc_491521501741_item	2452471	et	4	main
moodusta	doc_491521501741_item	2452499	et	4	main
vaid	doc_491521501741_item	2452501	et	3	main
mis	doc_491521501741_item	2452512	et	4	main
mida	doc_491521501741_item	2452518	et	4	main
kasutata	doc_491521501741_item	2452520	et	3	main
sageli	doc_491521501741_item	2452530	et	3	main
miks	doc_491521501741_item	2452534	et	4	main
kas	doc_491521501741_item	2452540	et	3	main
ei	doc_491521501741_item	2452542	et	4	main
vigu	doc_491521501741_item	2452556	et	3	main
ning	doc_491521501741_item	2452558	et	3	main
ei	doc_491521501741_item	2452568	et	4	main
nõrga	doc_491521501741_item	2452570	et	3	main
keeleoskustasemega	doc_491521501741_item	2452571	et	3	main
õpilaste	doc_491521501741_item	2452572	et	4	main
töödes	doc_491521501741_item	2452573	et	3	main
esines	doc_491521501741_item	2452574	et	3	main
võimalus	doc_491521501741_item	2452583	et	3	main
palju	doc_491521501741_item	2452587	et	4	main
tehnikad	doc_491521501741_item	2452588	et	3	main
ta	doc_491521501741_item	2452589	et	4	main
inimesele	doc_491521501741_item	2452595	et	3	main
tehnika	doc_491521501741_item	2452596	et	4	main
ole	doc_491521501741_item	2452609	et	4	main
raha	doc_491521501741_item	2452616	et	4	main
põhjuseks	doc_491521501741_item	2452621	et	3	main
see	doc_491521501741_item	2452623	et	3	main
et	doc_491521501741_item	2452624	et	3	main
keeles	doc_491521501741_item	2452626	et	4	main
nõus	doc_491521501741_item	2452633	et	4	main
rikad	doc_491521501741_item	2452636	et	4	main
sõltub	doc_491521501741_item	2452639	et	3	main
töö	doc_491521501741_item	2452643	et	4	main
antud	doc_491521501741_item	2452644	et	4	main
juhtudel	doc_491521501741_item	2452645	et	3	main
sõnad	doc_491521501741_item	2452649	et	4	main
õige	doc_491521501741_item	2452660	et	4	main
kohakäänete	doc_491521501741_item	2452661	et	3	main
kuna	doc_491521501741_item	2452668	et	3	main
nevski	doc_491521501741_item	2452696	et	4	main
prospektis	doc_491521501741_item	2452697	et	3	main
ma	doc_491521501741_item	2452701	et	3	main
arvatavasti	doc_491521501741_item	2452704	et	3	main
mõjutada	doc_491521501741_item	2452706	et	3	main
muud	doc_491521501741_item	2452712	et	4	main
käändevead	doc_491521501741_item	2452713	et	4	main
заказать	doc_491521501741_item	2452721	et	2	main
palk	doc_491521501741_item	2452734	et	3	main
ilma	doc_491521501741_item	2452735	et	4	main
raha	doc_491521501741_item	2452736	et	4	main
kõrghariduse	doc_491521501741_item	2452741	et	3	main
firmad	doc_491521501741_item	2452743	et	3	main
kellel	doc_491521501741_item	2452746	et	4	main
sisseütlevat	doc_491521501741_item	2452787	et	3	main
palju	doc_491521501741_item	2452795	et	4	main
mulle	doc_491521501741_item	2452797	et	4	main
vaadata	doc_491521501741_item	2452799	et	4	main
poodides	doc_491521501741_item	2452808	et	3	main
need	doc_491521501740_item	2452323	et	3	main
seotud	doc_491521501740_item	2452325	et	4	main
seal	doc_491521501740_item	2452334	et	4	main
oli	doc_491521501740_item	2452335	et	3	main
peeti	doc_491521501740_item	2452339	et	4	main
74	doc_491521501740_item	2452351	et	2	main
77	doc_491521501740_item	2452370	et	2	main
hakkame	doc_491521501740_item	2452372	et	3	main
tavaliselt	doc_491521501740_item	2452383	et	4	main
80	doc_491521501740_item	2452388	et	2	main
kohe	doc_491521501740_item	2452391	et	4	main
soovin	doc_491521501740_item	2452390	et	3	main
alustama	doc_491521501740_item	2452392	et	3	main
81	doc_491521501740_item	2452393	et	2	main
kui	doc_491521501740_item	2452394	et	3	main
vend	doc_491521501740_item	2452395	et	3	main
toob	doc_491521501740_item	2452396	et	3	main
raamatu	doc_491521501740_item	2452397	et	4	main
lugema	doc_491521501740_item	2452398	et	4	main
toon	doc_491521501740_item	2452399	et	4	main
ka	doc_491521501740_item	2452400	et	3	main
sulle	doc_491521501740_item	2452401	et	3	main
veaanalüüs	doc_491521501741_item	2452402	et	4	main
tallinna	doc_491521501741_item	2452403	et	4	main
pedagoogikaülikool	doc_491521501741_item	2452404	et	4	main
filoloogiateaduskond	doc_491521501741_item	2452405	et	3	main
eesti	doc_491521501741_item	2452406	et	4	main
filoloogia	doc_491521501741_item	2452407	et	4	main
osakond	doc_491521501741_item	2452408	et	3	main
aleksandra	doc_491521501741_item	2452409	et	4	main
ev-51	doc_491521501741_item	2452411	et	4	main
šljušenkova	doc_491521501741_item	2452410	et	2	main
veaanalüüs	doc_491521501741_item	2452412	et	4	main
arvestustöö	doc_491521501741_item	2452413	et	4	main
õppejõud	doc_491521501741_item	2452414	et	4	main
anu-reet	doc_491521501741_item	2452415	et	4	main
hausenberg	doc_491521501741_item	2452416	et	4	main
tallinn	doc_491521501741_item	2452417	et	4	main
2003	doc_491521501741_item	2452418	et	2	main
materjali	doc_491521501741_item	2452419	et	4	main
kogumine	doc_491521501741_item	2452420	et	4	main
analüüsitakse	doc_491521501741_item	2452423	et	4	main
ja	doc_491521501741_item	2452425	et	3	main
kirjalikke	doc_491521501741_item	2452429	et	3	main
neid	doc_491521501741_item	2452432	et	4	main
samas	doc_491521501741_item	2452438	et	4	main
on	doc_491521501741_item	2452448	et	4	main
ja	doc_491521501741_item	2452450	et	3	main
klassiga	doc_491521501741_item	2452452	et	3	main
vigu	doc_491521501741_item	2452463	et	3	main
klassi	doc_491521501741_item	2452427	et	4	main
osa	doc_491521501741_item	2452431	et	4	main
on	doc_491521501741_item	2452433	et	4	main
kuigi	doc_491521501741_item	2452446	et	3	main
tegemist	doc_491521501741_item	2452447	et	4	main
11	doc_491521501741_item	2452451	et	2	main
olnud	doc_491521501741_item	2452460	et	4	main
töid	doc_491521501741_item	2452461	et	3	main
kus	doc_491521501741_item	2452462	et	3	main
paktiliselt	doc_491521501741_item	2452464	et	4	main
ei	doc_491521501741_item	2452465	et	4	main
selliseid	doc_491521501741_item	2452469	et	4	main
pikad	doc_491521501741_item	2452475	et	4	main
kuid	doc_491521501741_item	2452476	et	4	main
kus	doc_491521501741_item	2452477	et	3	main
peaaegu	doc_491521501741_item	2452478	et	3	main
igas	doc_491521501741_item	2452479	et	3	main
lauses	doc_491521501741_item	2452480	et	3	main
tuli	doc_491521501741_item	2452481	et	4	main
midagi	doc_491521501741_item	2452482	et	4	main
parandada	doc_491521501741_item	2452483	et	3	main
veaanalüüs	doc_491521501741_item	2452484	et	4	main
vigade	doc_491521501741_item	2452485	et	3	main
põhjused	doc_491521501741_item	2452486	et	3	main
ja	doc_491521501741_item	2452487	et	3	main
raskused	doc_491521501741_item	2452488	et	4	main
vigade	doc_491521501741_item	2452489	et	3	main
rühmitamisel	doc_491521501741_item	2452490	et	4	main
tihtipeale	doc_491521501741_item	2452491	et	3	main
on	doc_491521501741_item	2452492	et	4	main
vea	doc_491521501741_item	2452493	et	4	main
põhjuseks	doc_491521501741_item	2452494	et	3	main
et	doc_491521501741_item	2452496	et	3	main
see	doc_491521501741_item	2452495	et	3	main
keeleõppija	doc_491521501741_item	2452497	et	4	main
ei	doc_491521501741_item	2452498	et	4	main
töid	doc_491521501741_item	2452470	et	3	main
neid	doc_491521501741_item	2452503	et	4	main
sihtkeelde	doc_491521501741_item	2452505	et	4	main
tulemuseks	doc_491521501741_item	2452506	et	3	main
kõla	doc_491521501741_item	2452515	et	4	main
siit	doc_491521501741_item	2452522	et	3	main
ka	doc_491521501741_item	2452524	et	3	main
rektsioonivead	doc_491521501741_item	2452526	et	4	main
vigade	doc_491521501741_item	2452527	et	3	main
rühmitamisel	doc_491521501741_item	2452528	et	4	main
raske	doc_491521501741_item	2452531	et	4	main
antud	doc_491521501741_item	2452535	et	4	main
viga	doc_491521501741_item	2452536	et	4	main
või	doc_491521501741_item	2452547	et	4	main
tegemist	doc_491521501741_item	2452548	et	4	main
mõjuga	doc_491521501741_item	2452551	et	3	main
kui	doc_491521501741_item	2452553	et	3	main
väärisid	doc_491521501741_item	2452560	et	4	main
ühildumisvigu	doc_491521501741_item	2452567	et	4	main
esinenud	doc_491521501741_item	2452569	et	4	main
teaduse	doc_491521501741_item	2452578	et	3	main
saad	doc_491521501741_item	2452590	et	4	main
väga	doc_491521501741_item	2452591	et	3	main
head	doc_491521501741_item	2452592	et	4	main
õpilased	doc_491521501741_item	2452600	et	3	main
juba	doc_491521501741_item	2452602	et	3	main
väitega	doc_491521501741_item	2452612	et	3	main
inimesel	doc_491521501741_item	2452613	et	3	main
olla	doc_491521501741_item	2452615	et	3	main
emakeelest	doc_491521501741_item	2452504	et	4	main
on	doc_491521501741_item	2452507	et	4	main
see	doc_491521501741_item	2452508	et	3	main
et	doc_491521501741_item	2452509	et	3	main
moodustatakse	doc_491521501741_item	2452510	et	3	main
sihtkeeles	doc_491521501741_item	2452513	et	4	main
üldse	doc_491521501741_item	2452521	et	3	main
tehtud	doc_491521501741_item	2452538	et	4	main
ning	doc_491521501741_item	2452539	et	3	main
oli	doc_491521501741_item	2452555	et	3	main
vähem	doc_491521501741_item	2452557	et	4	main
nad	doc_491521501741_item	2452559	et	3	main
paremat	doc_491521501741_item	2452561	et	4	main
hinnet	doc_491521501741_item	2452562	et	3	main
siis	doc_491521501741_item	2452563	et	3	main
reeglina	doc_491521501741_item	2452564	et	3	main
nendes	doc_491521501741_item	2452565	et	4	main
palju	doc_491521501741_item	2452577	et	4	main
tööle	doc_491521501741_item	2452585	et	3	main
palka	doc_491521501741_item	2452593	et	4	main
keskkonda	doc_491521501741_item	2452598	et	4	main
mu	doc_491521501741_item	2452606	et	3	main
juhul	doc_491521501741_item	2452618	et	3	main
vea	doc_491521501741_item	2452620	et	4	main
ole	doc_491521501741_item	2452632	et	4	main
väidega	doc_491521501741_item	2452635	et	3	main
sugulased	doc_491521501741_item	2452637	et	3	main
arvestatud	doc_491521501741_item	2452647	et	4	main
et	doc_491521501741_item	2452648	et	3	main
ka	doc_491521501741_item	2452654	et	3	main
ettevaatlik	doc_491521501741_item	2452667	et	3	main
kellegi	doc_491521501741_item	2452669	et	4	main
asukoha	doc_491521501741_item	2452671	et	4	main
keeles	doc_491521501741_item	2452689	et	4	main
selle	doc_491521501741_item	2452698	et	4	main
otsustasin	doc_491521501741_item	2452702	et	3	main
millegi	doc_491521501741_item	2452710	et	4	main
või	doc_491521501741_item	2452517	et	4	main
tulenevad	doc_491521501741_item	2452523	et	4	main
erinevad	doc_491521501741_item	2452525	et	4	main
aru	doc_491521501741_item	2452532	et	4	main
on	doc_491521501741_item	2452537	et	4	main
on	doc_491521501741_item	2452549	et	4	main
ühildumisvead	doc_491521501741_item	2452552	et	4	main
neid	doc_491521501741_item	2452575	et	4	main
üsna	doc_491521501741_item	2452576	et	3	main
toovad	doc_491521501741_item	2452580	et	4	main
on	doc_491521501741_item	2452582	et	4	main
hea	doc_491521501741_item	2452584	et	4	main
minna	doc_491521501741_item	2452586	et	3	main
kõikidele	doc_491521501741_item	2452594	et	4	main
kui	doc_491521501741_item	2452599	et	3	main
nõus	doc_491521501741_item	2452610	et	4	main
sellega	doc_491521501741_item	2452611	et	3	main
võivad	doc_491521501741_item	2452614	et	4	main
on	doc_491521501741_item	2452619	et	4	main
arvatavasti	doc_491521501741_item	2452622	et	3	main
vene	doc_491521501741_item	2452625	et	4	main
on	doc_491521501741_item	2452627	et	4	main
raha	doc_491521501741_item	2452628	et	4	main
mitmuses	doc_491521501741_item	2452629	et	3	main
mõted	doc_491521501741_item	2452641	et	4	main
ning	doc_491521501741_item	2452652	et	3	main
seega	doc_491521501741_item	2452653	et	4	main
vead	doc_491521501741_item	2452662	et	4	main
kohakäänete	doc_491521501741_item	2452663	et	3	main
millegi	doc_491521501741_item	2452670	et	4	main
väljendamine	doc_491521501741_item	2452672	et	4	main
võis	doc_491521501741_item	2452705	et	4	main
algul	doc_491521501741_item	2452709	et	4	main
tellisin	doc_491521501741_item	2452714	et	3	main
aastale	doc_491521501741_item	2452717	et	3	main
vene	doc_491521501741_item	2452718	et	4	main
целый	doc_491521501741_item	2452724	et	2	main
ei	doc_491521501741_item	2452737	et	4	main
vajavad	doc_491521501741_item	2452744	et	4	main
sõna	doc_491521501741_item	2452750	et	4	main
rahat	doc_491521501741_item	2452760	et	4	main
me	doc_491521501741_item	2452761	et	4	main
töö	doc_491521501741_item	2452763	et	4	main
eest	doc_491521501741_item	2452764	et	4	main
rahakottisse	doc_491521501741_item	2452779	et	4	main
väga	doc_491521501741_item	2452780	et	3	main
taheti	doc_491521501741_item	2452784	et	3	main
lühikest	doc_491521501741_item	2452786	et	4	main
väga	doc_491521501741_item	2452788	et	3	main
tehakse	doc_491521501741_item	2452790	et	3	main
venekeelseid	doc_491521501741_item	2452803	et	3	main
käia	doc_491521501741_item	2452809	et	4	main
da	doc_491521501741_item	2452811	et	4	main
tegevusnimi	doc_491521501741_item	2452812	et	3	main
naine	doc_491521501741_item	2452815	et	3	main
suhtleda	doc_491521501741_item	2452825	et	4	main
on	doc_491521501741_item	2452829	et	4	main
võivad	doc_491521501741_item	2452831	et	4	main
segamini	doc_491521501741_item	2452838	et	4	main
vead	doc_491521501741_item	2452845	et	4	main
valmistab	doc_491521501741_item	2452850	et	3	main
tihtipeale	doc_491521501741_item	2452851	et	3	main
raskusi	doc_491521501741_item	2452852	et	4	main
tööst	doc_491521501741_item	2452853	et	3	main
ta	doc_491521501741_item	2452857	et	4	main
inglise	doc_491521501741_item	2452863	et	4	main
kontrolltööks	doc_491521501741_item	2452871	et	3	main
valmistama	doc_491521501741_item	2452876	et	3	main
городе	doc_491521501741_item	2452911	et	2	main
lastele	doc_491521501741_item	2452915	et	4	main
keeles	doc_491521501741_item	2452936	et	4	main
vead	doc_491521501741_item	2452940	et	4	main
seal	doc_491521501741_item	2452945	et	4	main
käinud	doc_491521501741_item	2452946	et	4	main
ei	doc_491521501741_item	2452947	et	4	main
sõnadel	doc_491521501741_item	2452950	et	3	main
tegemist	doc_491521501741_item	2452955	et	4	main
paronüümidega	doc_491521501741_item	2452957	et	3	main
võivad	doc_491521501741_item	2452959	et	4	main
segi	doc_491521501741_item	2452963	et	3	main
võimalik	doc_491521501741_item	2452971	et	3	main
on	doc_491521501741_item	2452529	et	4	main
saada	doc_491521501741_item	2452533	et	4	main
keeleõppija	doc_491521501741_item	2452541	et	4	main
tunne	doc_491521501741_item	2452543	et	4	main
reeglit	doc_491521501741_item	2452544	et	3	main
lihtsalt	doc_491521501741_item	2452545	et	4	main
eksis	doc_491521501741_item	2452546	et	3	main
emakeele	doc_491521501741_item	2452550	et	4	main
töödes	doc_491521501741_item	2452554	et	3	main
töödes	doc_491521501741_item	2452566	et	3	main
saavutus	doc_491521501741_item	2452579	et	4	main
inimkonnale	doc_491521501741_item	2452581	et	4	main
saastad	doc_491521501741_item	2452597	et	4	main
on	doc_491521501741_item	2452601	et	4	main
täiskasvanu	doc_491521501741_item	2452603	et	4	main
tööst	doc_491521501741_item	2452604	et	3	main
sõltub	doc_491521501741_item	2452605	et	3	main
mõted	doc_491521501741_item	2452607	et	4	main
ei	doc_491521501741_item	2452608	et	4	main
antud	doc_491521501741_item	2452617	et	4	main
selle	doc_491521501741_item	2452634	et	4	main
mu	doc_491521501741_item	2452640	et	3	main
kokka	doc_491521501741_item	2452642	et	4	main
ei	doc_491521501741_item	2452646	et	4	main
alluvad	doc_491521501741_item	2452650	et	4	main
vorm	doc_491521501741_item	2452657	et	3	main
aasta	doc_491521501741_item	2452699	et	4	main
et	doc_491521501741_item	2452703	et	3	main
sõna	doc_491521501741_item	2452707	et	4	main
algul	doc_491521501741_item	2452708	et	4	main
на	doc_491521501741_item	2452723	et	2	main
selle	doc_491521501741_item	2452726	et	4	main
ja	doc_491521501741_item	2452728	et	3	main
ostakse	doc_491521501741_item	2452729	et	4	main
makstakse	doc_491521501741_item	2452732	et	3	main
hea	doc_491521501741_item	2452733	et	4	main
ei	doc_491521501741_item	2452739	et	4	main
vormimoodustusvead	doc_491521501741_item	2452759	et	4	main
et	doc_491521501741_item	2452782	et	3	main
palju	doc_491521501741_item	2452789	et	4	main
vigu	doc_491521501741_item	2452791	et	3	main
osastava	doc_491521501741_item	2452793	et	4	main
moodustamisel	doc_491521501741_item	2452794	et	4	main
romantiliseid	doc_491521501741_item	2452800	et	4	main
ajalehte	doc_491521501741_item	2452804	et	4	main
verbivormide	doc_491521501741_item	2452805	et	4	main
moodustusvead	doc_491521501741_item	2452806	et	4	main
tahta	doc_491521501741_item	2452814	et	3	main
infinitiiv	doc_491521501741_item	2452828	et	3	main
verbid	doc_491521501741_item	2452839	et	3	main
võitma	doc_491521501741_item	2452842	et	3	main
rahuldust	doc_491521501741_item	2452856	et	4	main
osta	doc_491521501741_item	2452860	et	4	main
kasutamine	doc_491521501741_item	2452868	et	4	main
ma	doc_491521501741_item	2452869	et	3	main
ei	doc_491521501741_item	2452872	et	4	main
vahet	doc_491521501741_item	2452874	et	3	main
valmistuma	doc_491521501741_item	2452878	et	3	main
keeles	doc_491521501741_item	2452918	et	4	main
могут	doc_491521501741_item	2452919	et	2	main
помочь	doc_491521501741_item	2452920	et	2	main
детям	doc_491521501741_item	2452921	et	2	main
üsna	doc_491521501741_item	2452924	et	3	main
vead	doc_491521501741_item	2452926	et	4	main
vene	doc_491521501741_item	2452935	et	4	main
ennem	doc_491521501741_item	2452953	et	4	main
nad	doc_491521501741_item	2452960	et	3	main
minna	doc_491521501741_item	2452964	et	3	main
segamini	doc_491521501741_item	2452974	et	4	main
arvamine	doc_491521501741_item	2452976	et	4	main
moskvasse	doc_491521501741_item	2453008	et	4	main
жениться	doc_491521501741_item	2453026	et	2	main
ja	doc_491521501741_item	2453027	et	3	main
быть	doc_491521501741_item	2453029	et	2	main
день	doc_491521501741_item	2453041	et	2	main
on	doc_491521501741_item	2453053	et	4	main
midagi	doc_491521501741_item	2453057	et	4	main
pakup	doc_491521501741_item	2453059	et	4	main
ei	doc_491521501742_item	2453072	et	4	main
teksti	doc_491521501742_item	2453075	et	4	main
juhtivad	doc_491521501742_item	2453081	et	4	main
pikkus	doc_491521501742_item	2453092	et	4	main
on	doc_491521501742_item	2453094	et	4	main
1-2	doc_491521501742_item	2453097	et	2	main
kandis	doc_491521501742_item	2453129	et	4	main
astmevaheldus	doc_491521501741_item	2452630	et	4	main
ei	doc_491521501741_item	2452631	et	4	main
tööst	doc_491521501741_item	2452638	et	3	main
astmevaheldusele	doc_491521501741_item	2452651	et	4	main
kasutatav	doc_491521501741_item	2452655	et	4	main
omastava	doc_491521501741_item	2452656	et	4	main
ei	doc_491521501741_item	2452658	et	4	main
ole	doc_491521501741_item	2452659	et	4	main
kasutamisel	doc_491521501741_item	2452664	et	4	main
tuleb	doc_491521501741_item	2452665	et	3	main
olla	doc_491521501741_item	2452666	et	3	main
eesti	doc_491521501741_item	2452673	et	4	main
ja	doc_491521501741_item	2452674	et	3	main
vene	doc_491521501741_item	2452675	et	4	main
keeles	doc_491521501741_item	2452676	et	4	main
ei	doc_491521501741_item	2452677	et	4	main
pruugi	doc_491521501741_item	2452678	et	4	main
kokku	doc_491521501741_item	2452679	et	3	main
langeda	doc_491521501741_item	2452680	et	3	main
töödes	doc_491521501741_item	2452681	et	3	main
olid	doc_491521501741_item	2452682	et	4	main
järgmised	doc_491521501741_item	2452683	et	3	main
vead	doc_491521501741_item	2452684	et	4	main
meie	doc_491521501741_item	2452685	et	4	main
maas	doc_491521501741_item	2452686	et	4	main
elada	doc_491521501741_item	2452687	et	3	main
vene	doc_491521501741_item	2452688	et	4	main
öeldakse	doc_491521501741_item	2452690	et	3	main
жить	doc_491521501741_item	2452691	et	2	main
в	doc_491521501741_item	2452692	et	2	main
нашей	doc_491521501741_item	2452693	et	2	main
стране	doc_491521501741_item	2452694	et	2	main
jalutasime	doc_491521501741_item	2452695	et	3	main
algusel	doc_491521501741_item	2452700	et	4	main
alguses	doc_491521501741_item	2452711	et	4	main
ajakirja	doc_491521501741_item	2452715	et	4	main
tervele	doc_491521501741_item	2452716	et	4	main
keeles	doc_491521501741_item	2452719	et	4	main
öeldakse	doc_491521501741_item	2452720	et	3	main
журнал	doc_491521501741_item	2452722	et	2	main
kus	doc_491521501741_item	2452730	et	3	main
mulle	doc_491521501741_item	2452731	et	4	main
saa	doc_491521501741_item	2452738	et	4	main
inimesest	doc_491521501741_item	2452745	et	3	main
on	doc_491521501741_item	2452747	et	4	main
kõrgharidus	doc_491521501741_item	2452748	et	3	main
antud	doc_491521501741_item	2452749	et	4	main
saame	doc_491521501741_item	2452762	et	4	main
võimalik	doc_491521501741_item	2452781	et	3	main
asjaid	doc_491521501741_item	2452796	et	4	main
tahtakse	doc_491521501741_item	2452807	et	4	main
on	doc_491521501741_item	2452813	et	4	main
hea	doc_491521501741_item	2452817	et	4	main
mehele	doc_491521501741_item	2452819	et	3	main
aga	doc_491521501741_item	2452821	et	3	main
год	doc_491521501741_item	2452725	et	2	main
müüakse	doc_491521501741_item	2452727	et	3	main
eelda	doc_491521501741_item	2452740	et	4	main
head	doc_491521501741_item	2452742	et	4	main
puhul	doc_491521501741_item	2452751	et	4	main
ei	doc_491521501741_item	2452752	et	4	main
tehta	doc_491521501741_item	2452753	et	3	main
vahet	doc_491521501741_item	2452754	et	3	main
osastava	doc_491521501741_item	2452755	et	4	main
ja	doc_491521501741_item	2452756	et	3	main
seestütleva	doc_491521501741_item	2452757	et	3	main
vahel	doc_491521501741_item	2452758	et	4	main
heaolu	doc_491521501741_item	2452765	et	4	main
sõltub	doc_491521501741_item	2452766	et	3	main
suhtetest	doc_491521501741_item	2452767	et	4	main
inimestega	doc_491521501741_item	2452768	et	3	main
arvatavasti	doc_491521501741_item	2452769	et	3	main
on	doc_491521501741_item	2452770	et	4	main
mitmuse	doc_491521501741_item	2452771	et	3	main
omastav	doc_491521501741_item	2452772	et	4	main
moodustatud	doc_491521501741_item	2452773	et	4	main
ainsuse	doc_491521501741_item	2452774	et	4	main
omastavast	doc_491521501741_item	2452775	et	4	main
raha	doc_491521501741_item	2452776	et	4	main
tuleb	doc_491521501741_item	2452777	et	3	main
sinu	doc_491521501741_item	2452778	et	3	main
algul	doc_491521501741_item	2452783	et	4	main
kasutada	doc_491521501741_item	2452785	et	3	main
mitmuse	doc_491521501741_item	2452792	et	3	main
meeldib	doc_491521501741_item	2452798	et	3	main
filmesid	doc_491521501741_item	2452801	et	4	main
palju	doc_491521501741_item	2452802	et	4	main
läksida	doc_491521501741_item	2452818	et	4	main
lähen	doc_491521501741_item	2452820	et	3	main
minna	doc_491521501741_item	2452823	et	3	main
kuna	doc_491521501741_item	2452826	et	3	main
valiku	doc_491521501741_item	2452844	et	3	main
ma	doc_491521501741_item	2452846	et	3	main
ja	doc_491521501741_item	2452847	et	3	main
da	doc_491521501741_item	2452848	et	4	main
tegevusnimi	doc_491521501741_item	2452849	et	3	main
süüa	doc_491521501741_item	2452859	et	3	main
läksin	doc_491521501741_item	2452862	et	3	main
keelt	doc_491521501741_item	2452864	et	4	main
õppida	doc_491521501741_item	2452865	et	3	main
tehta	doc_491521501741_item	2452873	et	3	main
verbidel	doc_491521501741_item	2452875	et	3	main
lihtsalt	doc_491521501741_item	2452880	et	4	main
võivad	doc_491521501741_item	2452913	et	4	main
siis	doc_491521501741_item	2452916	et	3	main
kuna	doc_491521501741_item	2452810	et	3	main
võib	doc_491521501741_item	2452816	et	3	main
ma	doc_491521501741_item	2452827	et	3	main
suhtlema	doc_491521501741_item	2452830	et	3	main
võida	doc_491521501741_item	2452832	et	4	main
raha	doc_491521501741_item	2452833	et	4	main
ja	doc_491521501741_item	2452841	et	3	main
verbivormide	doc_491521501741_item	2452843	et	4	main
saada	doc_491521501741_item	2452855	et	4	main
peab	doc_491521501741_item	2452858	et	4	main
ma	doc_491521501741_item	2452861	et	3	main
valmistasin	doc_491521501741_item	2452870	et	3	main
ja	doc_491521501741_item	2452877	et	3	main
vanemad	doc_491521501741_item	2452912	et	4	main
on	doc_491521501741_item	2452923	et	4	main
tüüpilised	doc_491521501741_item	2452925	et	3	main
kuna	doc_491521501741_item	2452927	et	3	main
ei	doc_491521501741_item	2452942	et	4	main
tehta	doc_491521501741_item	2452948	et	3	main
vahet	doc_491521501741_item	2452949	et	3	main
arvamis	doc_491521501741_item	2452969	et	4	main
inglise	doc_491521501741_item	2453009	et	4	main
sõnast	doc_491521501741_item	2453020	et	4	main
vead	doc_491521501741_item	2453043	et	4	main
pelakirjad	doc_491521501742_item	2453082	et	4	main
lehekülgede	doc_491521501742_item	2453084	et	4	main
lühikesed	doc_491521501742_item	2453096	et	4	main
rida	doc_491521501742_item	2453098	et	4	main
on	doc_491521501742_item	2453134	et	4	main
tõmbab	doc_491521501742_item	2453145	et	3	main
narvas	doc_491521501742_item	2453148	et	4	main
heroiin	doc_491521501742_item	2453150	et	3	main
jõhvi	doc_491521501742_item	2453156	et	4	main
ära	doc_491521501742_item	2453157	et	4	main
ja	doc_491521501742_item	2453163	et	3	main
kui	doc_491521501742_item	2453164	et	3	main
kohtla-järvest	doc_491521501742_item	2453165	et	4	main
räägitakse	doc_491521501742_item	2453166	et	3	main
pealkiri	doc_491521501742_item	2453173	et	3	main
ajalehe	doc_491521501742_item	2453175	et	3	main
ühele	doc_491521501742_item	2453182	et	3	main
peaaegu	doc_491521501742_item	2453184	et	3	main
ulatavad	doc_491521501742_item	2453188	et	4	main
et	doc_491521501742_item	2453193	et	3	main
kipuvad	doc_491521501742_item	2453196	et	3	main
jaoks	doc_491521501742_item	2453198	et	4	main
seostuma	doc_491521501742_item	2453199	et	3	main
ülaloleva	doc_491521501742_item	2453200	et	3	main
vana	doc_491521501742_item	2453212	et	4	main
on	doc_491521501742_item	2453220	et	4	main
ja	doc_491521501742_item	2453222	et	3	main
pelkirjad	doc_491521501742_item	2453224	et	4	main
on	doc_491521501742_item	2453225	et	4	main
kuid	doc_491521501742_item	2453230	et	4	main
aga	doc_491521501742_item	2453231	et	3	main
ajalehe	doc_491521501742_item	2453232	et	3	main
spordiosas	doc_491521501742_item	2453238	et	3	main
kasutatud	doc_491521501742_item	2453240	et	4	main
halvetica	doc_491521501742_item	2453242	et	4	main
see	doc_491521501742_item	2453243	et	3	main
põhjendatut	doc_491521501742_item	2453258	et	4	main
kaheks	doc_491521501742_item	2453263	et	4	main
nii	doc_491521501742_item	2453265	et	3	main
kohe	doc_491521501742_item	2453270	et	4	main
nad	doc_491521501742_item	2453304	et	3	main
rangete	doc_491521501742_item	2453307	et	4	main
ja	doc_491521501742_item	2453308	et	3	main
allajoonistavad	doc_491521501742_item	2453323	et	4	main
korralikult	doc_491521501742_item	2453324	et	4	main
on	doc_491521501742_item	2453330	et	4	main
seda	doc_491521501742_item	2453333	et	3	main
lugeda	doc_491521501742_item	2453339	et	3	main
mõjuvad	doc_491521501742_item	2453342	et	4	main
mitteametliku	doc_491521501742_item	2453343	et	3	main
sellega	doc_491521501742_item	2453362	et	3	main
paksemas	doc_491521501742_item	2453370	et	4	main
kursiivis	doc_491521501742_item	2453371	et	3	main
kirjas	doc_491521501742_item	2453375	et	4	main
teksti	doc_491521501742_item	2453376	et	4	main
liiga	doc_491521501742_item	2453380	et	4	main
artikkel	doc_491521501742_item	2453391	et	3	main
aeg	doc_491521501742_item	2453393	et	3	main
minema	doc_491521501741_item	2452822	et	3	main
proovi	doc_491521501741_item	2452824	et	4	main
lotereejas	doc_491521501741_item	2452834	et	4	main
arvatavasti	doc_491521501741_item	2452835	et	3	main
on	doc_491521501741_item	2452836	et	4	main
aetud	doc_491521501741_item	2452837	et	4	main
võima	doc_491521501741_item	2452840	et	3	main
peab	doc_491521501741_item	2452854	et	4	main
vale	doc_491521501741_item	2452866	et	4	main
verbi	doc_491521501741_item	2452867	et	4	main
tahan	doc_491521501741_item	2452879	et	3	main
lõõgastada	doc_491521501741_item	2452881	et	3	main
ei	doc_491521501741_item	2452882	et	4	main
tehta	doc_491521501741_item	2452883	et	3	main
vahet	doc_491521501741_item	2452884	et	3	main
verbidel	doc_491521501741_item	2452885	et	3	main
lõõgastama	doc_491521501741_item	2452886	et	3	main
ja	doc_491521501741_item	2452887	et	3	main
lõõgastuma	doc_491521501741_item	2452888	et	3	main
üritus	doc_491521501741_item	2452889	et	4	main
lõpetas	doc_491521501741_item	2452890	et	3	main
matšiga	doc_491521501741_item	2452892	et	2	main
korvpalli	doc_491521501741_item	2452891	et	4	main
aeti	doc_491521501741_item	2452893	et	3	main
segamini	doc_491521501741_item	2452894	et	4	main
verbid	doc_491521501741_item	2452895	et	3	main
lõpetama	doc_491521501741_item	2452896	et	4	main
ja	doc_491521501741_item	2452897	et	3	main
lõppema	doc_491521501741_item	2452898	et	4	main
verbirektsioon	doc_491521501741_item	2452899	et	4	main
nii	doc_491521501741_item	2452900	et	3	main
me	doc_491521501741_item	2452901	et	4	main
jäime	doc_491521501741_item	2452902	et	3	main
tundmatus	doc_491521501741_item	2452903	et	4	main
linnas	doc_491521501741_item	2452904	et	4	main
vene	doc_491521501741_item	2452905	et	4	main
keeles	doc_491521501741_item	2452906	et	4	main
мы	doc_491521501741_item	2452907	et	2	main
остались	doc_491521501741_item	2452908	et	2	main
в	doc_491521501741_item	2452909	et	2	main
неизвестном	doc_491521501741_item	2452910	et	2	main
aidata	doc_491521501741_item	2452914	et	4	main
vene	doc_491521501741_item	2452917	et	4	main
need	doc_491521501741_item	2452922	et	3	main
unustatakse	doc_491521501741_item	2452928	et	3	main
et	doc_491521501741_item	2452929	et	3	main
verbirektsioonid	doc_491521501741_item	2452930	et	4	main
ei	doc_491521501741_item	2452931	et	4	main
langeda	doc_491521501741_item	2452938	et	3	main
sõnatasandi	doc_491521501741_item	2452939	et	3	main
ennem	doc_491521501741_item	2452941	et	4	main
ole	doc_491521501741_item	2452943	et	4	main
ma	doc_491521501741_item	2452944	et	3	main
enne	doc_491521501741_item	2452951	et	4	main
ja	doc_491521501741_item	2452952	et	3	main
on	doc_491521501741_item	2452956	et	4	main
siis	doc_491521501741_item	2452958	et	3	main
keeleõppijal	doc_491521501741_item	2452961	et	3	main
tihtipeale	doc_491521501741_item	2452962	et	3	main
sõnavaravead	doc_491521501741_item	2452965	et	3	main
see	doc_491521501741_item	2452966	et	3	main
on	doc_491521501741_item	2452967	et	4	main
minu	doc_491521501741_item	2452968	et	3	main
et	doc_491521501741_item	2452972	et	3	main
aeti	doc_491521501741_item	2452973	et	3	main
võivad	doc_491521501741_item	2453014	et	4	main
olla	doc_491521501741_item	2453015	et	3	main
abielutud	doc_491521501741_item	2453016	et	4	main
arvatavasti	doc_491521501741_item	2453017	et	3	main
taheti	doc_491521501741_item	2453018	et	3	main
vene	doc_491521501741_item	2453023	et	4	main
muud	doc_491521501741_item	2453042	et	4	main
asemel	doc_491521501741_item	2453051	et	4	main
tal	doc_491521501741_item	2453052	et	3	main
on	doc_491521501742_item	2453068	et	4	main
iseseisvad	doc_491521501742_item	2453069	et	3	main
või	doc_491521501742_item	2453076	et	4	main
pilku	doc_491521501742_item	2453083	et	4	main
suhteliselt	doc_491521501742_item	2453095	et	4	main
3-4	doc_491521501742_item	2453099	et	2	main
reas	doc_491521501742_item	2453101	et	3	main
selline	doc_491521501742_item	2453121	et	4	main
narvas	doc_491521501742_item	2453123	et	4	main
levib	doc_491521501742_item	2453124	et	3	main
jõhvi	doc_491521501742_item	2453126	et	4	main
ja	doc_491521501742_item	2453127	et	3	main
rida	doc_491521501742_item	2453133	et	4	main
oleks	doc_491521501742_item	2453147	et	3	main
levib	doc_491521501742_item	2453149	et	3	main
peakse	doc_491521501742_item	2453167	et	4	main
sellega	doc_491521501742_item	2453171	et	3	main
seotud	doc_491521501742_item	2453178	et	4	main
põhjarannik	doc_491521501742_item	2453205	et	3	main
on	doc_491521501742_item	2453209	et	4	main
baskerville	doc_491521501742_item	2453214	et	4	main
kenasti	doc_491521501742_item	2453217	et	3	main
välja	doc_491521501742_item	2453218	et	4	main
nad	doc_491521501742_item	2453219	et	3	main
väljendusrikkad	doc_491521501742_item	2453221	et	4	main
personaalsed	doc_491521501742_item	2453223	et	3	main
antiikva	doc_491521501742_item	2453228	et	4	main
kirjas	doc_491521501742_item	2453229	et	4	main
rubriigi	doc_491521501742_item	2453251	et	3	main
jõhvi	doc_491521501742_item	2453259	et	4	main
teataja	doc_491521501742_item	2453260	et	4	main
pärast	doc_491521501742_item	2453271	et	4	main
kohta	doc_491521501742_item	2453311	et	4	main
nt	doc_491521501742_item	2453312	et	4	main
antiikva	doc_491521501742_item	2453320	et	4	main
aga	doc_491521501742_item	2453321	et	3	main
pruugi	doc_491521501741_item	2452932	et	4	main
eesti	doc_491521501741_item	2452933	et	4	main
ja	doc_491521501741_item	2452934	et	3	main
kokku	doc_491521501741_item	2452937	et	3	main
kuna	doc_491521501741_item	2452954	et	3	main
väga	doc_491521501741_item	2452970	et	3	main
sõnaga	doc_491521501741_item	2452975	et	3	main
reisimine	doc_491521501741_item	2452977	et	4	main
on	doc_491521501741_item	2452978	et	4	main
hea	doc_491521501741_item	2452979	et	4	main
ajaviitmise	doc_491521501741_item	2452980	et	3	main
viis	doc_491521501741_item	2452981	et	4	main
võivad	doc_491521501741_item	2452982	et	4	main
võida	doc_491521501741_item	2452983	et	4	main
raha	doc_491521501741_item	2452984	et	4	main
lotereejas	doc_491521501741_item	2452985	et	4	main
vene	doc_491521501741_item	2452986	et	4	main
keeles	doc_491521501741_item	2452987	et	4	main
лотерея	doc_491521501741_item	2452988	et	2	main
emakeele	doc_491521501741_item	2452989	et	4	main
või	doc_491521501741_item	2452990	et	4	main
teise	doc_491521501741_item	2452991	et	4	main
mõju	doc_491521501741_item	2452993	et	4	main
võõrkeele	doc_491521501741_item	2452992	et	4	main
sõnaühendite	doc_491521501741_item	2452994	et	3	main
moodustamisel	doc_491521501741_item	2452995	et	4	main
läksin	doc_491521501741_item	2452996	et	3	main
dušši	doc_491521501741_item	2452997	et	2	main
võtma	doc_491521501741_item	2452998	et	3	main
inglise	doc_491521501741_item	2452999	et	4	main
keeles	doc_491521501741_item	2453000	et	4	main
take	doc_491521501741_item	2453001	et	4	main
a	doc_491521501741_item	2453002	et	4	main
shower	doc_491521501741_item	2453003	et	4	main
algul	doc_491521501741_item	2453004	et	4	main
me	doc_491521501741_item	2453005	et	4	main
võtsime	doc_491521501741_item	2453006	et	3	main
bussi	doc_491521501741_item	2453007	et	4	main
keeles	doc_491521501741_item	2453010	et	4	main
take	doc_491521501741_item	2453011	et	4	main
a	doc_491521501741_item	2453012	et	4	main
buss	doc_491521501741_item	2453013	et	3	main
abielluma	doc_491521501741_item	2453021	et	3	main
keeles	doc_491521501741_item	2453024	et	4	main
on	doc_491521501741_item	2453025	et	4	main
могут	doc_491521501741_item	2453028	et	2	main
женаты	doc_491521501741_item	2453030	et	2	main
ostab	doc_491521501741_item	2453031	et	3	main
ajalehti	doc_491521501741_item	2453032	et	4	main
päev	doc_491521501741_item	2453033	et	3	main
päeva	doc_491521501741_item	2453035	et	4	main
võib	doc_491521501741_item	2453045	et	3	main
läksida	doc_491521501741_item	2453047	et	4	main
omadussõna	doc_491521501741_item	2453049	et	4	main
määrsõna	doc_491521501741_item	2453050	et	4	main
ei	doc_491521501741_item	2453055	et	4	main
rahulolu	doc_491521501741_item	2453060	et	4	main
ajalehe	doc_491521501742_item	2453061	et	3	main
ajalehe	doc_491521501742_item	2453063	et	3	main
pealkirjad	doc_491521501742_item	2453065	et	3	main
pealkirjad	doc_491521501742_item	2453067	et	3	main
tervikud	doc_491521501742_item	2453070	et	3	main
vaja	doc_491521501742_item	2453073	et	4	main
mõistmiseks	doc_491521501742_item	2453074	et	4	main
kujundusest	doc_491521501742_item	2453079	et	4	main
lähtudes	doc_491521501742_item	2453080	et	3	main
ja	doc_491521501742_item	2453086	et	3	main
leheküljed	doc_491521501742_item	2453088	et	3	main
osadeks	doc_491521501742_item	2453090	et	3	main
sõna	doc_491521501742_item	2453100	et	4	main
pelkiri	doc_491521501742_item	2453122	et	4	main
heroiin	doc_491521501742_item	2453125	et	3	main
pealkirja	doc_491521501742_item	2453131	et	4	main
esimene	doc_491521501742_item	2453132	et	3	main
oma	doc_491521501742_item	2453139	et	4	main
ilmekuse	doc_491521501742_item	2453140	et	4	main
ja	doc_491521501742_item	2453141	et	3	main
teravuse	doc_491521501742_item	2453142	et	4	main
lugejat	doc_491521501742_item	2453144	et	4	main
kohtla-järve	doc_491521501742_item	2453151	et	4	main
sest	doc_491521501742_item	2453158	et	4	main
see	doc_491521501742_item	2453159	et	3	main
on	doc_491521501742_item	2453160	et	4	main
kohtla-järve	doc_491521501742_item	2453161	et	4	main
silmas	doc_491521501742_item	2453169	et	4	main
kaherealised	doc_491521501742_item	2453186	et	4	main
kohale	doc_491521501742_item	2453192	et	4	main
on	doc_491521501742_item	2453206	et	4	main
konservatiivne	doc_491521501742_item	2453207	et	3	main
ajaleht	doc_491521501742_item	2453208	et	3	main
domineerivalt	doc_491521501742_item	2453227	et	4	main
on	doc_491521501742_item	2453239	et	4	main
annab	doc_491521501742_item	2453244	et	3	main
lisale	doc_491521501742_item	2453245	et	3	main
isikupärasust	doc_491521501742_item	2453246	et	4	main
ja	doc_491521501742_item	2453247	et	3	main
eristamine	doc_491521501742_item	2453253	et	4	main
meelest	doc_491521501742_item	2453255	et	4	main
ajalehe	doc_491521501742_item	2453262	et	3	main
ei	doc_491521501742_item	2453268	et	4	main
tule	doc_491521501742_item	2453269	et	4	main
jätkamine	doc_491521501742_item	2453276	et	4	main
antiikva	doc_491521501742_item	2453277	et	4	main
kiriga	doc_491521501742_item	2453279	et	4	main
uudiste	doc_491521501742_item	2453310	et	3	main
kriminaalkroonika	doc_491521501742_item	2453315	et	4	main
kiri	doc_491521501742_item	2453317	et	3	main
on	doc_491521501742_item	2453318	et	4	main
ikka	doc_491521501742_item	2453319	et	4	main
plokk-kirjad	doc_491521501742_item	2453322	et	4	main
pealkirja	doc_491521501742_item	2453327	et	4	main
paigutamine	doc_491521501742_item	2453328	et	4	main
joondatud	doc_491521501742_item	2453331	et	4	main
on	doc_491521501742_item	2453348	et	4	main
peaaegu	doc_491521501742_item	2453349	et	3	main
samasuguse	doc_491521501742_item	2453350	et	3	main
ole	doc_491521501742_item	2453356	et	4	main
suhteliselt	doc_491521501742_item	2453359	et	4	main
on	doc_491521501742_item	2453369	et	4	main
moodustada	doc_491521501741_item	2453019	et	3	main
kuna	doc_491521501741_item	2453022	et	3	main
üle	doc_491521501741_item	2453034	et	3	main
vene	doc_491521501741_item	2453036	et	4	main
keeles	doc_491521501741_item	2453037	et	4	main
покупает	doc_491521501741_item	2453038	et	2	main
газеты	doc_491521501741_item	2453039	et	2	main
через	doc_491521501741_item	2453040	et	2	main
naine	doc_491521501741_item	2453044	et	3	main
hea	doc_491521501741_item	2453046	et	4	main
mehele	doc_491521501741_item	2453048	et	3	main
heaolu	doc_491521501741_item	2453054	et	4	main
too	doc_491521501741_item	2453056	et	4	main
paha	doc_491521501741_item	2453058	et	4	main
analüüs	doc_491521501742_item	2453062	et	3	main
analüüs	doc_491521501742_item	2453064	et	3	main
põhjaranniku	doc_491521501742_item	2453066	et	3	main
ning	doc_491521501742_item	2453071	et	3	main
lisapealkirja	doc_491521501742_item	2453077	et	4	main
lugemist	doc_491521501742_item	2453078	et	4	main
mööda	doc_491521501742_item	2453085	et	4	main
liigendavad	doc_491521501742_item	2453087	et	4	main
väiksemateks	doc_491521501742_item	2453089	et	4	main
pelkirja	doc_491521501742_item	2453091	et	4	main
pelkirjad	doc_491521501742_item	2453093	et	4	main
aga	doc_491521501742_item	2453102	et	3	main
on	doc_491521501742_item	2453103	et	4	main
ka	doc_491521501742_item	2453104	et	3	main
mõned	doc_491521501742_item	2453105	et	3	main
pikad	doc_491521501742_item	2453106	et	4	main
pelkirjad	doc_491521501742_item	2453107	et	4	main
mis	doc_491521501742_item	2453108	et	4	main
annavad	doc_491521501742_item	2453109	et	3	main
küll	doc_491521501742_item	2453110	et	4	main
rohkem	doc_491521501742_item	2453111	et	4	main
infot	doc_491521501742_item	2453112	et	3	main
kuid	doc_491521501742_item	2453113	et	4	main
on	doc_491521501742_item	2453114	et	4	main
raskemini	doc_491521501742_item	2453115	et	4	main
loetavad	doc_491521501742_item	2453116	et	4	main
näiteks	doc_491521501742_item	2453117	et	4	main
viiendal	doc_491521501742_item	2453118	et	3	main
leheküljel	doc_491521501742_item	2453119	et	3	main
on	doc_491521501742_item	2453120	et	4	main
kohtla-järve	doc_491521501742_item	2453128	et	4	main
ja	doc_491521501742_item	2453136	et	3	main
sellega	doc_491521501742_item	2453137	et	3	main
mis	doc_491521501742_item	2453143	et	4	main
ka	doc_491521501742_item	2453168	et	3	main
tegin	doc_491521501742_item	2453172	et	3	main
tugevalt	doc_491521501742_item	2453177	et	4	main
pelkirjafraasid	doc_491521501742_item	2453179	et	4	main
paigutatud	doc_491521501742_item	2453181	et	4	main
reale	doc_491521501742_item	2453183	et	3	main
pelkirjad	doc_491521501742_item	2453187	et	4	main
natukene	doc_491521501742_item	2453189	et	4	main
kõigi	doc_491521501742_item	2453190	et	4	main
tekstiveergude	doc_491521501742_item	2453191	et	3	main
veerud	doc_491521501742_item	2453195	et	4	main
lugeja	doc_491521501742_item	2453197	et	4	main
looga	doc_491521501742_item	2453201	et	4	main
klassikaline	doc_491521501742_item	2453211	et	4	main
plokk-kiri	doc_491521501742_item	2453241	et	3	main
formaalsema	doc_491521501742_item	2453248	et	4	main
spordi	doc_491521501742_item	2453250	et	4	main
pealkirjade	doc_491521501742_item	2453252	et	3	main
jagab	doc_491521501742_item	2453261	et	3	main
sport	doc_491521501742_item	2453267	et	3	main
alguse	doc_491521501742_item	2453275	et	3	main
pealkirja	doc_491521501742_item	2453278	et	4	main
tõsisemate	doc_491521501742_item	2453309	et	4	main
peetakse	doc_491521501742_item	2453334	et	3	main
artikklite	doc_491521501742_item	2453367	et	4	main
pealkirjad	doc_491521501742_item	2453368	et	3	main
suuremas	doc_491521501742_item	2453374	et	4	main
märts	doc_491521501742_item	2453396	et	3	main
tagasi	doc_491521501742_item	2453397	et	3	main
on	doc_491521501742_item	2453399	et	4	main
kui	doc_491521501742_item	2453403	et	3	main
jõhvi	doc_491521501742_item	2453407	et	4	main
veerudesse	doc_491521501742_item	2453422	et	3	main
on	doc_491521501742_item	2453425	et	4	main
seda	doc_491521501742_item	2453427	et	3	main
ei	doc_491521501742_item	2453440	et	4	main
lugeda	doc_491521501742_item	2453442	et	3	main
tohi	doc_491521501742_item	2453450	et	4	main
laiemas	doc_491521501742_item	2453455	et	4	main
on	doc_491521501742_item	2453459	et	4	main
suuruse	doc_491521501742_item	2453465	et	4	main
suhtes	doc_491521501742_item	2453466	et	4	main
on	doc_491521501742_item	2453467	et	4	main
suhteliselt	doc_491521501742_item	2453481	et	4	main
mitte	doc_491521501742_item	2453482	et	3	main
lugemisel	doc_491521501742_item	2453487	et	4	main
vahepealkirjad	doc_491521501742_item	2453491	et	3	main
on	doc_491521501742_item	2453526	et	4	main
anda	doc_491521501742_item	2453532	et	3	main
tekst	doc_491521501742_item	2453542	et	3	main
ainult	doc_491521501742_item	2453544	et	4	main
aga	doc_491521501742_item	2453547	et	3	main
olema	doc_491521501742_item	2453551	et	4	main
jõhvi	doc_491521501742_item	2453552	et	4	main
nende	doc_491521501742_item	2453558	et	4	main
mahuks	doc_491521501742_item	2453574	et	4	main
paremas	doc_491521501742_item	2453575	et	4	main
mis	doc_491521501742_item	2453579	et	4	main
ei	doc_491521501742_item	2453580	et	4	main
ilus	doc_491521501742_item	2453582	et	4	main
tähekesed	doc_491521501742_item	2453583	et	4	main
aga	doc_491521501742_item	2453584	et	3	main
ka	doc_491521501742_item	2453591	et	3	main
põhitekst	doc_491521501742_item	2453594	et	3	main
legejatest	doc_491521501742_item	2453597	et	4	main
plokk-kirja	doc_491521501742_item	2453612	et	4	main
lastele	doc_491521501742_item	2453623	et	4	main
paksemas	doc_491521501742_item	2453630	et	4	main
kirjas	doc_491521501742_item	2453631	et	4	main
samas	doc_491521501742_item	2453646	et	4	main
ta	doc_491521501742_item	2453648	et	4	main
vasaku	doc_491521501742_item	2453650	et	3	main
lehekülje	doc_491521501742_item	2453651	et	3	main
vasaku	doc_491521501742_item	2453652	et	3	main
ülemise	doc_491521501742_item	2453653	et	4	main
nurka	doc_491521501742_item	2453654	et	4	main
väga	doc_491521501742_item	2453655	et	3	main
moonilahus	doc_491521501742_item	2453130	et	4	main
ülipikk	doc_491521501742_item	2453135	et	4	main
kaotab	doc_491521501742_item	2453138	et	3	main
pigem	doc_491521501742_item	2453146	et	3	main
kandis	doc_491521501742_item	2453152	et	4	main
moonilahus	doc_491521501742_item	2453153	et	4	main
mina	doc_491521501742_item	2453154	et	4	main
võtsin	doc_491521501742_item	2453155	et	3	main
osa	doc_491521501742_item	2453162	et	4	main
jõhvit	doc_491521501742_item	2453170	et	4	main
lühemaks	doc_491521501742_item	2453174	et	4	main
sisult	doc_491521501742_item	2453176	et	3	main
on	doc_491521501742_item	2453180	et	4	main
kõik	doc_491521501742_item	2453185	et	4	main
alasti	doc_491521501742_item	2453194	et	3	main
pealkirja	doc_491521501742_item	2453202	et	4	main
kiri	doc_491521501742_item	2453203	et	3	main
kuna	doc_491521501742_item	2453204	et	3	main
kasutatud	doc_491521501742_item	2453210	et	4	main
antiikvakiri	doc_491521501742_item	2453213	et	4	main
pelkirjad	doc_491521501742_item	2453215	et	4	main
näevad	doc_491521501742_item	2453216	et	3	main
esitatud	doc_491521501742_item	2453226	et	4	main
lisas	doc_491521501742_item	2453233	et	4	main
jõhvi	doc_491521501742_item	2453234	et	4	main
teataja	doc_491521501742_item	2453235	et	4	main
ja	doc_491521501742_item	2453236	et	3	main
ka	doc_491521501742_item	2453237	et	3	main
mulje	doc_491521501742_item	2453249	et	4	main
minu	doc_491521501742_item	2453254	et	3	main
ei	doc_491521501742_item	2453256	et	4	main
ole	doc_491521501742_item	2453257	et	4	main
pooleks	doc_491521501742_item	2453264	et	4	main
et	doc_491521501742_item	2453266	et	3	main
lisat	doc_491521501742_item	2453272	et	4	main
aga	doc_491521501742_item	2453273	et	3	main
tuleb	doc_491521501742_item	2453274	et	3	main
spordi	doc_491521501742_item	2453280	et	4	main
rubriik	doc_491521501742_item	2453281	et	3	main
kuulub	doc_491521501742_item	2453282	et	3	main
põhja	doc_491521501742_item	2453283	et	4	main
ajalehele	doc_491521501742_item	2453284	et	3	main
vaid	doc_491521501742_item	2453285	et	3	main
mitte	doc_491521501742_item	2453286	et	3	main
lisale	doc_491521501742_item	2453287	et	3	main
sellega	doc_491521501742_item	2453288	et	3	main
peab	doc_491521501742_item	2453289	et	4	main
sama	doc_491521501742_item	2453290	et	4	main
pealkirja	doc_491521501742_item	2453291	et	4	main
kiri	doc_491521501742_item	2453292	et	3	main
olema	doc_491521501742_item	2453293	et	4	main
mõned	doc_491521501742_item	2453294	et	3	main
pelakirjad	doc_491521501742_item	2453295	et	4	main
ajalehes	doc_491521501742_item	2453296	et	3	main
on	doc_491521501742_item	2453297	et	4	main
plokk-kirjas	doc_491521501742_item	2453298	et	4	main
aga	doc_491521501742_item	2453299	et	3	main
see	doc_491521501742_item	2453300	et	3	main
on	doc_491521501742_item	2453301	et	4	main
täiesti	doc_491521501742_item	2453302	et	3	main
põhjendatud	doc_491521501742_item	2453303	et	4	main
on	doc_491521501742_item	2453305	et	4	main
kasutatud	doc_491521501742_item	2453306	et	4	main
viru	doc_491521501742_item	2453313	et	4	main
ringkonnakohtu	doc_491521501742_item	2453314	et	3	main
domineeriv	doc_491521501742_item	2453316	et	4	main
sisu	doc_491521501742_item	2453326	et	4	main
vasakule	doc_491521501742_item	2453332	et	4	main
neid	doc_491521501742_item	2453336	et	4	main
mugav	doc_491521501742_item	2453338	et	3	main
nad	doc_491521501742_item	2453341	et	3	main
sundimatu	doc_491521501742_item	2453344	et	4	main
ja	doc_491521501742_item	2453345	et	3	main
sõbralikuna	doc_491521501742_item	2453346	et	3	main
read	doc_491521501742_item	2453347	et	3	main
pealkirjad	doc_491521501742_item	2453357	et	3	main
on	doc_491521501742_item	2453358	et	4	main
väiksed	doc_491521501742_item	2453360	et	4	main
aga	doc_491521501742_item	2453361	et	3	main
kohe	doc_491521501742_item	2453364	et	4	main
tähtsamate	doc_491521501742_item	2453366	et	4	main
liigendamine	doc_491521501742_item	2453377	et	4	main
ajalehes	doc_491521501742_item	2453378	et	3	main
on	doc_491521501742_item	2453379	et	4	main
leheküljel	doc_491521501742_item	2453389	et	3	main
loetav	doc_491521501742_item	2453402	et	4	main
oma	doc_491521501742_item	2453406	et	4	main
akustika	doc_491521501742_item	2453409	et	4	main
ajalehe	doc_491521501742_item	2453415	et	3	main
kitsamate	doc_491521501742_item	2453421	et	4	main
aga	doc_491521501742_item	2453423	et	3	main
lõigud	doc_491521501742_item	2453424	et	4	main
pikk	doc_491521501742_item	2453435	et	4	main
mida	doc_491521501742_item	2453436	et	4	main
asuv	doc_491521501742_item	2453446	et	4	main
ei	doc_491521501742_item	2453449	et	4	main
võlgu	doc_491521501742_item	2453451	et	4	main
veergus	doc_491521501742_item	2453456	et	4	main
lõigud	doc_491521501742_item	2453458	et	4	main
lühikesed	doc_491521501742_item	2453460	et	4	main
artikklite	doc_491521501742_item	2453461	et	4	main
õieti	doc_491521501742_item	2453471	et	3	main
parem	doc_491521501742_item	2453476	et	4	main
veerud	doc_491521501742_item	2453479	et	4	main
on	doc_491521501742_item	2453480	et	4	main
artikkli	doc_491521501742_item	2453325	et	4	main
pelakirjad	doc_491521501742_item	2453329	et	4	main
parimaks	doc_491521501742_item	2453335	et	4	main
on	doc_491521501742_item	2453337	et	4	main
ja	doc_491521501742_item	2453340	et	3	main
pikkusega	doc_491521501742_item	2453351	et	4	main
eriti	doc_491521501742_item	2453352	et	3	main
suurt	doc_491521501742_item	2453353	et	3	main
vahet	doc_491521501742_item	2453354	et	3	main
ei	doc_491521501742_item	2453355	et	4	main
on	doc_491521501742_item	2453363	et	4	main
eristatavad	doc_491521501742_item	2453365	et	4	main
ning	doc_491521501742_item	2453372	et	3	main
mida	doc_491521501742_item	2453383	et	4	main
on	doc_491521501742_item	2453384	et	4	main
väga	doc_491521501742_item	2453385	et	3	main
raske	doc_491521501742_item	2453386	et	4	main
lugeda	doc_491521501742_item	2453387	et	3	main
asuv	doc_491521501742_item	2453390	et	4	main
on	doc_491521501742_item	2453392	et	4	main
8	doc_491521501742_item	2453395	et	2	main
lehekülje	doc_491521501742_item	2453405	et	3	main
modernseimale	doc_491521501742_item	2453413	et	4	main
kontserdisaalile	doc_491521501742_item	2453414	et	3	main
kõige	doc_491521501742_item	2453416	et	4	main
esimene	doc_491521501742_item	2453417	et	3	main
artikkel	doc_491521501742_item	2453418	et	3	main
on	doc_491521501742_item	2453419	et	4	main
kujundatud	doc_491521501742_item	2453420	et	4	main
ülipikkad	doc_491521501742_item	2453426	et	4	main
ise	doc_491521501742_item	2453432	et	4	main
artikkel	doc_491521501742_item	2453433	et	3	main
pikkuse	doc_491521501742_item	2453438	et	4	main
teisel	doc_491521501742_item	2453444	et	4	main
jääda	doc_491521501742_item	2453452	et	4	main
ning	doc_491521501742_item	2453457	et	3	main
suuri	doc_491521501742_item	2453488	et	3	main
ajalehe	doc_491521501742_item	2453522	et	3	main
leheküljel	doc_491521501742_item	2453524	et	3	main
8	doc_491521501742_item	2453529	et	2	main
teksti	doc_491521501742_item	2453536	et	4	main
ei	doc_491521501742_item	2453539	et	4	main
real	doc_491521501742_item	2453546	et	3	main
ole	doc_491521501742_item	2453555	et	4	main
vahepealkiri	doc_491521501742_item	2453578	et	3	main
on	doc_491521501742_item	2453585	et	4	main
lihtsad	doc_491521501742_item	2453586	et	3	main
ja	doc_491521501742_item	2453587	et	3	main
rahulikud	doc_491521501742_item	2453588	et	3	main
antiikvat	doc_491521501742_item	2453601	et	3	main
artikklit	doc_491521501742_item	2453615	et	4	main
esimeses	doc_491521501742_item	2453616	et	3	main
kaksikleheküljel	doc_491521501742_item	2453617	et	3	main
eristatud	doc_491521501742_item	2453619	et	4	main
ei	doc_491521501742_item	2453624	et	4	main
jääda	doc_491521501742_item	2453627	et	4	main
torkiv	doc_491521501742_item	2453637	et	4	main
huvitav	doc_491521501742_item	2453645	et	4	main
pea	doc_491521501742_item	2453663	et	4	main
asuv	doc_491521501742_item	2453665	et	4	main
leheküljel	doc_491521501742_item	2453667	et	3	main
kuhu	doc_491521501742_item	2453669	et	3	main
põhitekst	doc_491521501742_item	2453679	et	3	main
suurus	doc_491521501742_item	2453685	et	4	main
ja	doc_491521501742_item	2453686	et	3	main
reavahe	doc_491521501742_item	2453687	et	4	main
ei	doc_491521501742_item	2453688	et	4	main
tragöödia	doc_491521501742_item	2453691	et	4	main
kirjutatud	doc_491521501742_item	2453694	et	4	main
veerus	doc_491521501742_item	2453696	et	4	main
sellega	doc_491521501742_item	2453697	et	3	main
olema	doc_491521501742_item	2453726	et	4	main
jääb	doc_491521501742_item	2453737	et	3	main
variant	doc_491521501742_item	2453739	et	3	main
et	doc_491521501742_item	2453741	et	3	main
ei	doc_491521501742_item	2453743	et	4	main
ka	doc_491521501742_item	2453373	et	3	main
pikaveerulised	doc_491521501742_item	2453381	et	4	main
artiklid	doc_491521501742_item	2453382	et	3	main
teisel	doc_491521501742_item	2453388	et	4	main
naistele	doc_491521501742_item	2453394	et	3	main
esimese	doc_491521501742_item	2453404	et	3	main
anda	doc_491521501742_item	2453398	et	3	main
palju	doc_491521501742_item	2453400	et	4	main
kergem	doc_491521501742_item	2453401	et	4	main
kiriku	doc_491521501742_item	2453408	et	3	main
on	doc_491521501742_item	2453410	et	4	main
ligilähedane	doc_491521501742_item	2453411	et	3	main
eesti	doc_491521501742_item	2453412	et	4	main
tuleks	doc_491521501742_item	2453428	et	4	main
kolmaks	doc_491521501742_item	2453431	et	4	main
juba	doc_491521501742_item	2453437	et	3	main
vastupidi	doc_491521501742_item	2453443	et	3	main
artiikel	doc_491521501742_item	2453447	et	4	main
lastele	doc_491521501742_item	2453448	et	4	main
lause	doc_491521501742_item	2453462	et	4	main
ja	doc_491521501742_item	2453463	et	3	main
jõhvi	doc_491521501742_item	2453468	et	4	main
või	doc_491521501742_item	2453472	et	4	main
igas	doc_491521501742_item	2453474	et	3	main
kui	doc_491521501742_item	2453477	et	3	main
põhjarannik	doc_491521501742_item	2453478	et	3	main
raskusi	doc_491521501742_item	2453489	et	4	main
vahepealkiri	doc_491521501742_item	2453490	et	3	main
on	doc_491521501742_item	2453492	et	4	main
õieti	doc_491521501742_item	2453494	et	3	main
valesti	doc_491521501742_item	2453521	et	3	main
vahepealkiri	doc_491521501742_item	2453534	et	3	main
lõppus	doc_491521501742_item	2453537	et	4	main
järgnev	doc_491521501742_item	2453541	et	4	main
kol	doc_491521501742_item	2453550	et	4	main
asemel	doc_491521501742_item	2453559	et	4	main
juhus	doc_491521501742_item	2453576	et	4	main
ole	doc_491521501742_item	2453581	et	4	main
eristavad	doc_491521501742_item	2453590	et	4	main
suurem	doc_491521501742_item	2453595	et	4	main
osa	doc_491521501742_item	2453596	et	4	main
eelistab	doc_491521501742_item	2453598	et	3	main
põhireksi	doc_491521501742_item	2453599	et	4	main
kirjana	doc_491521501742_item	2453600	et	3	main
põhjaranniku	doc_491521501742_item	2453602	et	3	main
kasutus	doc_491521501742_item	2453613	et	4	main
kaks	doc_491521501742_item	2453614	et	3	main
artikkel	doc_491521501742_item	2453621	et	3	main
on	doc_491521501742_item	2453628	et	4	main
ja	doc_491521501742_item	2453632	et	3	main
on	doc_491521501742_item	2453634	et	4	main
kohe	doc_491521501742_item	2453635	et	4	main
silma	doc_491521501742_item	2453636	et	4	main
kohas	doc_491521501742_item	2453657	et	4	main
sellega	doc_491521501742_item	2453658	et	3	main
on	doc_491521501742_item	2453659	et	4	main
leheküljel	doc_491521501742_item	2453660	et	3	main
mitte	doc_491521501742_item	2453661	et	3	main
paremal	doc_491521501742_item	2453666	et	4	main
tavaliselt	doc_491521501742_item	2453670	et	4	main
langeb	doc_491521501742_item	2453671	et	3	main
esimene	doc_491521501742_item	2453672	et	3	main
pilk	doc_491521501742_item	2453673	et	3	main
vaid	doc_491521501742_item	2453674	et	3	main
ka	doc_491521501742_item	2453675	et	3	main
teine	doc_491521501742_item	2453676	et	3	main
on	doc_491521501742_item	2453680	et	4	main
ühes	doc_491521501742_item	2453682	et	4	main
kirjas	doc_491521501742_item	2453683	et	4	main
muutu	doc_491521501742_item	2453689	et	4	main
lugu	doc_491521501742_item	2453690	et	4	main
on	doc_491521501742_item	2453693	et	4	main
pehme	doc_491521501742_item	2453721	et	4	main
antiikvas	doc_491521501742_item	2453725	et	3	main
ei	doc_491521501742_item	2453728	et	4	main
sest	doc_491521501742_item	2453730	et	4	main
ajalehe	doc_491521501742_item	2453731	et	3	main
põhitekstide	doc_491521501742_item	2453732	et	3	main
üks	doc_491521501742_item	2453738	et	3	main
cic	doc_491521501742_item	2453753	et	4	main
see	doc_491521501742_item	2453754	et	3	main
ei	doc_491521501742_item	2453762	et	4	main
mõtet	doc_491521501742_item	2453766	et	3	main
on	doc_491521501742_item	2453769	et	4	main
keskmiselt	doc_491521501742_item	2453770	et	4	main
3-4	doc_491521501742_item	2453771	et	2	main
sõna	doc_491521501742_item	2453776	et	4	main
on	doc_491521501742_item	2453779	et	4	main
jagada	doc_491521501742_item	2453429	et	3	main
vähemalt	doc_491521501742_item	2453430	et	4	main
on	doc_491521501742_item	2453434	et	4	main
tõttu	doc_491521501742_item	2453439	et	4	main
tahaks	doc_491521501742_item	2453441	et	3	main
leheküljel	doc_491521501742_item	2453445	et	3	main
on	doc_491521501742_item	2453453	et	4	main
ühes	doc_491521501742_item	2453454	et	4	main
lõigu	doc_491521501742_item	2453464	et	4	main
teataja	doc_491521501742_item	2453469	et	4	main
vormistatud	doc_491521501742_item	2453470	et	4	main
siis	doc_491521501742_item	2453473	et	3	main
juhus	doc_491521501742_item	2453475	et	4	main
pikad	doc_491521501742_item	2453483	et	4	main
ja	doc_491521501742_item	2453484	et	3	main
ei	doc_491521501742_item	2453485	et	4	main
tekita	doc_491521501742_item	2453486	et	4	main
kasutatud	doc_491521501742_item	2453493	et	4	main
selgelt	doc_491521501742_item	2453495	et	4	main
eristatud	doc_491521501742_item	2453496	et	4	main
paksu	doc_491521501742_item	2453497	et	4	main
ning	doc_491521501742_item	2453498	et	3	main
suurema	doc_491521501742_item	2453499	et	4	main
plokk-kirjaga	doc_491521501742_item	2453500	et	3	main
antiikva	doc_491521501742_item	2453501	et	4	main
põhiteksti	doc_491521501742_item	2453502	et	4	main
taustal	doc_491521501742_item	2453503	et	3	main
nad	doc_491521501742_item	2453504	et	3	main
on	doc_491521501742_item	2453505	et	4	main
lühikesed	doc_491521501742_item	2453506	et	4	main
kõik	doc_491521501742_item	2453507	et	4	main
sama	doc_491521501742_item	2453508	et	4	main
pikkusega	doc_491521501742_item	2453509	et	4	main
ja	doc_491521501742_item	2453510	et	3	main
on	doc_491521501742_item	2453511	et	4	main
paigutatud	doc_491521501742_item	2453512	et	4	main
tekstiveergude	doc_491521501742_item	2453513	et	3	main
keskele	doc_491521501742_item	2453514	et	3	main
ühes	doc_491521501742_item	2453515	et	4	main
kohas	doc_491521501742_item	2453516	et	4	main
on	doc_491521501742_item	2453517	et	4	main
aga	doc_491521501742_item	2453518	et	3	main
kasutatud	doc_491521501742_item	2453519	et	4	main
vahepealkiri	doc_491521501742_item	2453520	et	3	main
teisel	doc_491521501742_item	2453523	et	4	main
artikklis	doc_491521501742_item	2453525	et	4	main
aeg	doc_491521501742_item	2453527	et	3	main
tagasi	doc_491521501742_item	2453531	et	3	main
seisab	doc_491521501742_item	2453535	et	3	main
nii	doc_491521501742_item	2453538	et	3	main
teatajas	doc_491521501742_item	2453553	et	4	main
üldse	doc_491521501742_item	2453556	et	3	main
lühikesed	doc_491521501742_item	2453571	et	4	main
ja	doc_491521501742_item	2453572	et	3	main
sinna	doc_491521501742_item	2453573	et	3	main
ning	doc_491521501742_item	2453589	et	3	main
artikklite	doc_491521501742_item	2453592	et	4	main
naistele	doc_491521501742_item	2453528	et	3	main
märts	doc_491521501742_item	2453530	et	3	main
teine	doc_491521501742_item	2453533	et	3	main
veeru	doc_491521501742_item	2453540	et	4	main
mahub	doc_491521501742_item	2453543	et	3	main
kahel	doc_491521501742_item	2453545	et	4	main
peab	doc_491521501742_item	2453548	et	4	main
vähemalt	doc_491521501742_item	2453549	et	4	main
ei	doc_491521501742_item	2453554	et	4	main
vahepealkirju	doc_491521501742_item	2453557	et	4	main
on	doc_491521501742_item	2453560	et	4	main
kasutatu	doc_491521501742_item	2453561	et	4	main
tähekesed	doc_491521501742_item	2453562	et	4	main
olen	doc_491521501742_item	2453563	et	3	main
sellega	doc_491521501742_item	2453564	et	3	main
täiesti	doc_491521501742_item	2453565	et	3	main
nõus	doc_491521501742_item	2453566	et	4	main
artikklid	doc_491521501742_item	2453567	et	4	main
on	doc_491521501742_item	2453568	et	4	main
seal	doc_491521501742_item	2453569	et	4	main
suhteliselt	doc_491521501742_item	2453570	et	4	main
ühs	doc_491521501742_item	2453577	et	4	main
mõtted	doc_491521501742_item	2453593	et	3	main
põhitekst	doc_491521501742_item	2453603	et	3	main
kirjutatud	doc_491521501742_item	2453605	et	4	main
plokk-kirjana	doc_491521501742_item	2453620	et	3	main
on	doc_491521501742_item	2453604	et	4	main
samuti	doc_491521501742_item	2453606	et	3	main
antiikva	doc_491521501742_item	2453607	et	4	main
kirjas	doc_491521501742_item	2453608	et	4	main
kohtub	doc_491521501742_item	2453609	et	3	main
aga	doc_491521501742_item	2453610	et	3	main
ka	doc_491521501742_item	2453611	et	3	main
on	doc_491521501742_item	2453618	et	4	main
tohi	doc_491521501742_item	2453625	et	4	main
isegi	doc_491521501742_item	2453629	et	4	main
see	doc_491521501742_item	2453638	et	3	main
uudis	doc_491521501742_item	2453639	et	3	main
kirja	doc_491521501742_item	2453684	et	4	main
kiri	doc_491521501742_item	2453733	et	3	main
ajalehe	doc_491521501742_item	2453747	et	3	main
veerud	doc_491521501742_item	2453749	et	4	main
kui	doc_491521501742_item	2453757	et	3	main
minimaalne	doc_491521501742_item	2453758	et	3	main
suurs	doc_491521501742_item	2453760	et	4	main
terviklikku	doc_491521501742_item	2453765	et	4	main
ühes	doc_491521501742_item	2453767	et	4	main
olema	doc_491521501742_item	2453777	et	4	main
veergu	doc_491521501742_item	2453787	et	4	main
kirju	doc_491521501742_item	2453792	et	4	main
segase	doc_491521501742_item	2453794	et	3	main
märgatavad	doc_491521501742_item	2453821	et	4	main
menetluses	doc_491521501742_item	2453845	et	4	main
on	doc_491521501742_item	2453846	et	4	main
500	doc_491521501742_item	2453847	et	2	main
elatise	doc_491521501742_item	2453848	et	3	main
need	doc_491521501742_item	2453854	et	3	main
on	doc_491521501742_item	2453867	et	4	main
algab	doc_491521501742_item	2453871	et	3	main
artikkli	doc_491521501742_item	2453873	et	4	main
all	doc_491521501742_item	2453874	et	3	main
nii	doc_491521501742_item	2453875	et	3	main
et	doc_491521501742_item	2453876	et	3	main
kohe	doc_491521501742_item	2453877	et	4	main
ei	doc_491521501742_item	2453878	et	4	main
ja	doc_491521501742_item	2453885	et	3	main
ei	doc_491521501742_item	2453889	et	4	main
autori	doc_491521501742_item	2453891	et	3	main
pealkirjaga	doc_491521501742_item	2453622	et	3	main
võlgu	doc_491521501742_item	2453626	et	4	main
sellega	doc_491521501742_item	2453633	et	3	main
on	doc_491521501742_item	2453640	et	4	main
tõesti	doc_491521501742_item	2453641	et	3	main
oluline	doc_491521501742_item	2453642	et	4	main
ning	doc_491521501742_item	2453643	et	3	main
inimestele	doc_491521501742_item	2453644	et	3	main
on	doc_491521501742_item	2453647	et	4	main
paigutatud	doc_491521501742_item	2453649	et	4	main
uudis	doc_491521501742_item	2453664	et	3	main
keskel	doc_491521501742_item	2453668	et	3	main
kirjas	doc_491521501742_item	2453678	et	4	main
ka	doc_491521501742_item	2453698	et	3	main
suuremas	doc_491521501742_item	2453699	et	4	main
kirjas	doc_491521501742_item	2453700	et	4	main
ja	doc_491521501742_item	2453701	et	3	main
suurema	doc_491521501742_item	2453702	et	4	main
reavahega	doc_491521501742_item	2453703	et	3	main
see	doc_491521501742_item	2453704	et	3	main
artikkel	doc_491521501742_item	2453705	et	3	main
on	doc_491521501742_item	2453706	et	4	main
ka	doc_491521501742_item	2453707	et	3	main
eristatud	doc_491521501742_item	2453708	et	4	main
plokk-kirjaga	doc_491521501742_item	2453709	et	3	main
sest	doc_491521501742_item	2453710	et	4	main
on	doc_491521501742_item	2453711	et	4	main
täiesti	doc_491521501742_item	2453712	et	3	main
erinev	doc_491521501742_item	2453713	et	4	main
teistest	doc_491521501742_item	2453714	et	4	main
artikklitset	doc_491521501742_item	2453715	et	4	main
sellel	doc_491521501742_item	2453716	et	4	main
kaksikleheküljel	doc_491521501742_item	2453717	et	3	main
kuna	doc_491521501742_item	2453718	et	3	main
on	doc_491521501742_item	2453719	et	4	main
see	doc_491521501742_item	2453720	et	3	main
lugu	doc_491521501742_item	2453722	et	4	main
võiks	doc_491521501742_item	2453723	et	4	main
ka	doc_491521501742_item	2453724	et	3	main
ongi	doc_491521501742_item	2453734	et	4	main
sellega	doc_491521501742_item	2453736	et	3	main
plokk-kiri	doc_491521501742_item	2453740	et	3	main
leht	doc_491521501742_item	2453742	et	3	main
oleks	doc_491521501742_item	2453744	et	3	main
põhiteksti	doc_491521501742_item	2453748	et	4	main
on	doc_491521501742_item	2453750	et	4	main
domineerivalt	doc_491521501742_item	2453751	et	4	main
10	doc_491521501742_item	2453752	et	2	main
võimalik	doc_491521501742_item	2453759	et	3	main
veerud	doc_491521501742_item	2453761	et	4	main
suuda	doc_491521501742_item	2453763	et	4	main
mahutada	doc_491521501742_item	2453764	et	3	main
tekstides	doc_491521501742_item	2453778	et	3	main
tekita	doc_491521501742_item	2453791	et	4	main
on	doc_491521501742_item	2453823	et	4	main
pikad	doc_491521501742_item	2453825	et	4	main
on	doc_491521501742_item	2453827	et	4	main
hallid	doc_491521501742_item	2453829	et	4	main
ja	doc_491521501742_item	2453830	et	3	main
heas	doc_491521501742_item	2453656	et	3	main
üks	doc_491521501742_item	2453662	et	3	main
paksemas	doc_491521501742_item	2453677	et	4	main
põhiliselt	doc_491521501742_item	2453681	et	4	main
arktikas	doc_491521501742_item	2453692	et	4	main
laiemas	doc_491521501742_item	2453695	et	4	main
aga	doc_491521501742_item	2453727	et	3	main
saa	doc_491521501742_item	2453729	et	4	main
antiikva	doc_491521501742_item	2453735	et	4	main
ühesugune	doc_491521501742_item	2453745	et	3	main
veerud	doc_491521501742_item	2453746	et	4	main
on	doc_491521501742_item	2453755	et	4	main
optimaalselt	doc_491521501742_item	2453773	et	4	main
peab	doc_491521501742_item	2453774	et	4	main
5-7	doc_491521501742_item	2453775	et	2	main
paljud	doc_491521501742_item	2453780	et	3	main
sõnad	doc_491521501742_item	2453781	et	4	main
mahutatud	doc_491521501742_item	2453785	et	4	main
6	doc_491521501742_item	2453786	et	2	main
kuna	doc_491521501742_item	2453796	et	3	main
pilte	doc_491521501742_item	2453797	et	3	main
ja	doc_491521501742_item	2453798	et	3	main
fotosid	doc_491521501742_item	2453799	et	3	main
on	doc_491521501742_item	2453800	et	4	main
hästi	doc_491521501742_item	2453801	et	3	main
vähe	doc_491521501742_item	2453802	et	3	main
narvas	doc_491521501742_item	2453804	et	4	main
artikklis	doc_491521501742_item	2453803	et	4	main
levib	doc_491521501742_item	2453805	et	3	main
heroiin	doc_491521501742_item	2453806	et	3	main
jõhvi	doc_491521501742_item	2453807	et	4	main
ja	doc_491521501742_item	2453808	et	3	main
kohtla-järve	doc_491521501742_item	2453809	et	4	main
kandis	doc_491521501742_item	2453810	et	4	main
moonilahus	doc_491521501742_item	2453811	et	4	main
suure	doc_491521501742_item	2453812	et	3	main
foto	doc_491521501742_item	2453813	et	4	main
lähedal	doc_491521501742_item	2453814	et	4	main
lühikesed	doc_491521501742_item	2453816	et	4	main
on	doc_491521501742_item	2453815	et	4	main
veerukesed	doc_491521501742_item	2453817	et	4	main
mis	doc_491521501742_item	2453818	et	4	main
on	doc_491521501742_item	2453819	et	4	main
raskesti	doc_491521501742_item	2453820	et	3	main
võib	doc_491521501742_item	2453838	et	3	main
keeruliseks	doc_491521501742_item	2453840	et	4	main
väga	doc_491521501742_item	2453852	et	3	main
et	doc_491521501742_item	2453865	et	3	main
põhiartikkli	doc_491521501742_item	2453869	et	4	main
teataja	doc_491521501742_item	2453928	et	4	main
võiksin	doc_491521501742_item	2453929	et	3	main
on	doc_491521501742_item	2453947	et	4	main
5	doc_491521501742_item	2453960	et	2	main
teataja	doc_491521501742_item	2453978	et	4	main
on	doc_491521501742_item	2453979	et	4	main
aga	doc_491521501742_item	2453985	et	3	main
harjusime	doc_491521501742_item	2453987	et	3	main
kiiresti	doc_491521501742_item	2453989	et	3	main
ühiskonnas	doc_491521501742_item	2453991	et	4	main
elada	doc_491521501742_item	2453992	et	3	main
ja	doc_491521501742_item	2453993	et	3	main
sellega	doc_491521501742_item	2453994	et	3	main
põhjaranniku	doc_491521501742_item	2453995	et	3	main
vähem	doc_491521501742_item	2453756	et	4	main
reas	doc_491521501742_item	2453768	et	3	main
sõna	doc_491521501742_item	2453772	et	4	main
aga	doc_491521501742_item	2453788	et	3	main
see	doc_491521501742_item	2453789	et	3	main
ei	doc_491521501742_item	2453790	et	4	main
poolitatud	doc_491521501742_item	2453782	et	4	main
leheküljel	doc_491521501742_item	2453783	et	3	main
on	doc_491521501742_item	2453784	et	4	main
ja	doc_491521501742_item	2453793	et	3	main
tunnet	doc_491521501742_item	2453795	et	3	main
suhteliselt	doc_491521501742_item	2453824	et	4	main
sellega	doc_491521501742_item	2453826	et	3	main
igavad	doc_491521501742_item	2453828	et	3	main
kolmanda	doc_491521501742_item	2453833	et	3	main
lehekülje	doc_491521501742_item	2453834	et	3	main
artikklid	doc_491521501742_item	2453835	et	4	main
elatise	doc_491521501742_item	2453836	et	3	main
kristel	doc_491521501742_item	2453843	et	4	main
paiguta-tud	doc_491521501742_item	2453851	et	4	main
imelikult	doc_491521501742_item	2453853	et	4	main
ole	doc_491521501742_item	2453856	et	4	main
kaks	doc_491521501742_item	2453857	et	3	main
artikklid	doc_491521501742_item	2453858	et	4	main
vaid	doc_491521501742_item	2453859	et	3	main
üks	doc_491521501742_item	2453860	et	3	main
aga	doc_491521501742_item	2453861	et	3	main
aru	doc_491521501742_item	2453880	et	4	main
tuleb	doc_491521501742_item	2453882	et	3	main
lõppus	doc_491521501742_item	2453888	et	4	main
kasti	doc_491521501742_item	2453921	et	4	main
vastupidine	doc_491521501742_item	2453923	et	3	main
on	doc_491521501742_item	2453924	et	4	main
lisa	doc_491521501742_item	2453926	et	4	main
ta	doc_491521501742_item	2453933	et	4	main
ühel	doc_491521501742_item	2453945	et	3	main
keskmiselt	doc_491521501742_item	2453948	et	4	main
ja	doc_491521501742_item	2453951	et	3	main
sõnu	doc_491521501742_item	2453953	et	4	main
on	doc_491521501742_item	2453954	et	4	main
vähe	doc_491521501742_item	2453955	et	3	main
võrreldes	doc_491521501742_item	2453956	et	3	main
põhjarannikuga	doc_491521501742_item	2453957	et	3	main
palju	doc_491521501742_item	2453980	et	4	main
annab	doc_491521501742_item	2454004	et	3	main
nautida	doc_491521501742_item	2454009	et	3	main
põhjarannikus	doc_491521501742_item	2454011	et	3	main
fotosid	doc_491521501742_item	2454013	et	3	main
vähe	doc_491521501742_item	2454014	et	3	main
on	doc_491521501742_item	2454017	et	4	main
veerud	doc_491521501742_item	2453822	et	4	main
kätte-saamine	doc_491521501742_item	2453837	et	4	main
osutada	doc_491521501742_item	2453839	et	3	main
ja	doc_491521501742_item	2453841	et	3	main
välja-nõudmist	doc_491521501742_item	2453849	et	4	main
on	doc_491521501742_item	2453850	et	4	main
esmapilgul	doc_491521501742_item	2453862	et	4	main
tekib	doc_491521501742_item	2453863	et	3	main
mulje	doc_491521501742_item	2453864	et	4	main
kaks	doc_491521501742_item	2453868	et	3	main
lõpp	doc_491521501742_item	2453870	et	3	main
saa	doc_491521501742_item	2453879	et	4	main
lugeda	doc_491521501742_item	2453884	et	3	main
ka	doc_491521501742_item	2453886	et	3	main
ole	doc_491521501742_item	2453890	et	4	main
kasti	doc_491521501742_item	2453897	et	4	main
sees	doc_491521501742_item	2453898	et	4	main
sellega	doc_491521501742_item	2453899	et	3	main
tekitab	doc_491521501742_item	2453900	et	3	main
lõpetamatuse	doc_491521501742_item	2453901	et	4	main
tunne	doc_491521501742_item	2453902	et	4	main
pigem	doc_491521501742_item	2453903	et	3	main
oleks	doc_491521501742_item	2453904	et	3	main
kastis	doc_491521501742_item	2453905	et	4	main
asuva	doc_491521501742_item	2453906	et	4	main
teksti	doc_491521501742_item	2453907	et	4	main
langetada	doc_491521501742_item	2453908	et	3	main
alla	doc_491521501742_item	2453909	et	3	main
poole	doc_491521501742_item	2453910	et	4	main
ja	doc_491521501742_item	2453911	et	3	main
põhiteksti	doc_491521501742_item	2453912	et	4	main
viimased	doc_491521501742_item	2453913	et	3	main
kolm	doc_491521501742_item	2453914	et	3	main
veerud	doc_491521501742_item	2453915	et	4	main
ülesse	doc_491521501742_item	2453916	et	4	main
tõsta	doc_491521501742_item	2453917	et	4	main
nii	doc_491521501742_item	2453918	et	3	main
et	doc_491521501742_item	2453919	et	3	main
oleksid	doc_491521501742_item	2453920	et	4	main
ees	doc_491521501742_item	2453922	et	4	main
on	doc_491521501742_item	2453934	et	4	main
kasutatud	doc_491521501742_item	2453938	et	4	main
real	doc_491521501742_item	2453946	et	3	main
leheküljel	doc_491521501742_item	2453958	et	3	main
on	doc_491521501742_item	2453959	et	4	main
jõhvi	doc_491521501742_item	2453977	et	4	main
kujundus	doc_491521501742_item	2453996	et	4	main
langeb	doc_491521501742_item	2453997	et	3	main
meie	doc_491521501742_item	2453998	et	4	main
elustiiliga	doc_491521501742_item	2453999	et	3	main
teataja	doc_491521501742_item	2454002	et	4	main
lugemisel	doc_491521501742_item	2454008	et	4	main
dokumentaal	doc_491521501742_item	2454019	et	4	main
foto	doc_491521501742_item	2454028	et	4	main
väga	doc_491521501742_item	2454030	et	3	main
aga	doc_491521501742_item	2454033	et	3	main
midagi	doc_491521501742_item	2454045	et	4	main
ei	doc_491521501742_item	2454046	et	4	main
rasked	doc_491521501742_item	2453831	et	3	main
lugeda	doc_491521501742_item	2453832	et	3	main
kohtutäitur	doc_491521501742_item	2453842	et	3	main
maalmani	doc_491521501742_item	2453844	et	4	main
ei	doc_491521501742_item	2453855	et	4	main
neid	doc_491521501742_item	2453866	et	4	main
teise	doc_491521501742_item	2453872	et	4	main
mis	doc_491521501742_item	2453881	et	4	main
järgmisena	doc_491521501742_item	2453883	et	3	main
teksti	doc_491521501742_item	2453887	et	4	main
nime	doc_491521501742_item	2453892	et	4	main
vaid	doc_491521501742_item	2453893	et	3	main
seisab	doc_491521501742_item	2453894	et	3	main
teise	doc_491521501742_item	2453895	et	4	main
teksti	doc_491521501742_item	2453896	et	4	main
jõhvi	doc_491521501742_item	2453927	et	4	main
siin	doc_491521501742_item	2453936	et	4	main
on	doc_491521501742_item	2453937	et	4	main
veeulaius	doc_491521501742_item	2453942	et	4	main
12	doc_491521501742_item	2453943	et	2	main
cic	doc_491521501742_item	2453944	et	4	main
5	doc_491521501742_item	2453949	et	2	main
poolitatud	doc_491521501742_item	2453952	et	4	main
kuid	doc_491521501742_item	2453984	et	4	main
kokku	doc_491521501742_item	2454000	et	3	main
ning	doc_491521501742_item	2454007	et	3	main
on	doc_491521501742_item	2454012	et	4	main
ja	doc_491521501742_item	2454015	et	3	main
peaaegu	doc_491521501742_item	2454016	et	3	main
fotod	doc_491521501742_item	2454020	et	3	main
leheküljel	doc_491521501742_item	2454022	et	3	main
hästi	doc_491521501742_item	2454031	et	3	main
tekstile	doc_491521501742_item	2454032	et	3	main
ei	doc_491521501742_item	2454034	et	4	main
suur	doc_491521501742_item	2454043	et	3	main
foto	doc_491521501742_item	2454048	et	4	main
lugeja	doc_491521501742_item	2454080	et	4	main
liikuvust	doc_491521501742_item	2454091	et	4	main
ega	doc_491521501742_item	2454092	et	3	main
huvitavust	doc_491521501742_item	2454093	et	4	main
neid	doc_491521501742_item	2454095	et	4	main
vähe	doc_491521501742_item	2454098	et	3	main
pigem	doc_491521501742_item	2454101	et	3	main
on	doc_491521501742_item	2454105	et	4	main
mitte	doc_491521501742_item	2454111	et	3	main
jõhvi	doc_491521501742_item	2454113	et	4	main
on	doc_491521501742_item	2454115	et	4	main
hästi	doc_491521501742_item	2454116	et	3	main
palju	doc_491521501742_item	2454117	et	4	main
fotod	doc_491521501742_item	2454118	et	3	main
esimene	doc_491521501742_item	2454119	et	3	main
portreefotoline	doc_491521501742_item	2454122	et	4	main
igal	doc_491521501742_item	2454139	et	3	main
mõjule	doc_491521501742_item	2454141	et	3	main
on	doc_491521501742_item	2454146	et	4	main
on	doc_491521501742_item	2454157	et	4	main
pigem	doc_491521501742_item	2454158	et	3	main
mitte	doc_491521501742_item	2454162	et	3	main
vajalikud	doc_491521501742_item	2454192	et	3	main
arusaamisel	doc_491521501742_item	2454203	et	4	main
kuhu	doc_491521501742_item	2454204	et	3	main
see	doc_491521501742_item	2454205	et	3	main
nt	doc_491521501742_item	2454212	et	4	main
ajalehe	doc_491521501742_item	2453925	et	3	main
isegi	doc_491521501742_item	2453930	et	4	main
öelad	doc_491521501742_item	2453931	et	4	main
et	doc_491521501742_item	2453932	et	3	main
ideaalne	doc_491521501742_item	2453935	et	3	main
üks	doc_491521501742_item	2453939	et	3	main
ja	doc_491521501742_item	2453940	et	3	main
sama	doc_491521501742_item	2453941	et	4	main
sõna	doc_491521501742_item	2453950	et	4	main
veergu	doc_491521501742_item	2453961	et	4	main
ja	doc_491521501742_item	2453962	et	3	main
sellega	doc_491521501742_item	2453963	et	3	main
ei	doc_491521501742_item	2453964	et	4	main
tekita	doc_491521501742_item	2453965	et	4	main
kirju	doc_491521501742_item	2453966	et	4	main
muljet	doc_491521501742_item	2453967	et	3	main
veerud	doc_491521501742_item	2453968	et	4	main
ei	doc_491521501742_item	2453969	et	4	main
ole	doc_491521501742_item	2453970	et	4	main
pikad	doc_491521501742_item	2453971	et	4	main
ega	doc_491521501742_item	2453972	et	3	main
lühikesed	doc_491521501742_item	2453973	et	4	main
lugeda	doc_491521501742_item	2453974	et	3	main
on	doc_491521501742_item	2453975	et	4	main
lihtne	doc_491521501742_item	2453976	et	3	main
rahulikum	doc_491521501742_item	2453981	et	4	main
kui	doc_491521501742_item	2453982	et	3	main
põhjarannik	doc_491521501742_item	2453983	et	3	main
me	doc_491521501742_item	2453986	et	4	main
juba	doc_491521501742_item	2453988	et	3	main
muutuvas	doc_491521501742_item	2453990	et	4	main
aga	doc_491521501742_item	2454003	et	3	main
võimalust	doc_491521501742_item	2454005	et	3	main
fotod	doc_491521501742_item	2454010	et	3	main
esimesel	doc_491521501742_item	2454021	et	3	main
paigutatud	doc_491521501742_item	2454024	et	4	main
suur	doc_491521501742_item	2454025	et	3	main
stamp	doc_491521501742_item	2454026	et	3	main
foto	doc_491521501742_item	2454027	et	4	main
enam	doc_491521501742_item	2454036	et	4	main
mingit	doc_491521501742_item	2454037	et	3	main
infot	doc_491521501742_item	2454038	et	3	main
kolmandal	doc_491521501742_item	2454039	et	3	main
leheküljel	doc_491521501742_item	2454040	et	3	main
samas	doc_491521501742_item	2454050	et	4	main
on	doc_491521501742_item	2454056	et	4	main
vist	doc_491521501742_item	2454057	et	4	main
asjakohane	doc_491521501742_item	2454058	et	4	main
sündmusfotod	doc_491521501742_item	2454085	et	3	main
aga	doc_491521501742_item	2454086	et	3	main
ei	doc_491521501742_item	2454088	et	4	main
tee	doc_491521501742_item	2454089	et	4	main
ajalehes	doc_491521501742_item	2454090	et	3	main
täiesti	doc_491521501742_item	2454097	et	3	main
stampfotod	doc_491521501742_item	2454106	et	3	main
igavad	doc_491521501742_item	2454109	et	3	main
lehekälg	doc_491521501742_item	2454120	et	4	main
jõhvi	doc_491521501742_item	2454001	et	4	main
nõrgestuma	doc_491521501742_item	2454006	et	3	main
nad	doc_491521501742_item	2454018	et	3	main
on	doc_491521501742_item	2454023	et	4	main
on	doc_491521501742_item	2454041	et	4	main
aga	doc_491521501742_item	2454049	et	3	main
teksti	doc_491521501742_item	2454052	et	4	main
foto	doc_491521501742_item	2454054	et	4	main
suuus	doc_491521501742_item	2454055	et	4	main
pealkijaga	doc_491521501742_item	2454074	et	4	main
suure	doc_491521501742_item	2454076	et	3	main
fotoga	doc_491521501742_item	2454077	et	3	main
sellega	doc_491521501742_item	2454078	et	3	main
köitab	doc_491521501742_item	2454079	et	4	main
tähelepanu	doc_491521501742_item	2454081	et	4	main
olemas	doc_491521501742_item	2454083	et	4	main
ka	doc_491521501742_item	2454084	et	3	main
nad	doc_491521501742_item	2454087	et	3	main
on	doc_491521501742_item	2454096	et	4	main
nad	doc_491521501742_item	2454107	et	3	main
ja	doc_491521501742_item	2454110	et	3	main
tähelepanuväärsed	doc_491521501742_item	2454112	et	3	main
teatajas	doc_491521501742_item	2454114	et	4	main
ja	doc_491521501742_item	2454124	et	3	main
on	doc_491521501742_item	2454134	et	4	main
fotol	doc_491521501742_item	2454140	et	3	main
põhjaranniku	doc_491521501742_item	2454144	et	3	main
piisavalt	doc_491521501742_item	2454147	et	4	main
kehvad	doc_491521501742_item	2454148	et	3	main
spordiosas	doc_491521501742_item	2454149	et	3	main
pildi	doc_491521501742_item	2454150	et	4	main
all	doc_491521501742_item	2454151	et	3	main
pisikene	doc_491521501742_item	2454159	et	3	main
artikkel	doc_491521501742_item	2454160	et	3	main
aga	doc_491521501742_item	2454161	et	3	main
pikat	doc_491521501742_item	2454165	et	4	main
üldse	doc_491521501742_item	2454196	et	3	main
allkirjadeta	doc_491521501742_item	2454198	et	3	main
mis	doc_491521501742_item	2454199	et	4	main
toob	doc_491521501742_item	2454200	et	3	main
endaga	doc_491521501742_item	2454201	et	4	main
foto	doc_491521501742_item	2454206	et	4	main
tuleb	doc_491521501742_item	2454210	et	3	main
spordi	doc_491521501742_item	2454218	et	4	main
fotod	doc_491521501742_item	2454219	et	3	main
fotoallkirjad	doc_491521501742_item	2454220	et	3	main
on	doc_491521501742_item	2454221	et	4	main
paksema	doc_491521501742_item	2454224	et	4	main
ei	doc_491521501742_item	2454227	et	4	main
ei	doc_491521501742_item	2454233	et	4	main
tühi	doc_491521501742_item	2454243	et	3	main
pöhjaranniku	doc_491521501742_item	2454252	et	4	main
pisiinfo	doc_491521501742_item	2454253	et	4	main
väikesed	doc_491521501742_item	2454266	et	4	main
on	doc_491521501742_item	2454268	et	4	main
teevad	doc_491521501742_item	2454272	et	3	main
mitmekesisem	doc_491521501742_item	2454275	et	4	main
erinevate	doc_491521501742_item	2454297	et	4	main
kirja	doc_491521501742_item	2454298	et	4	main
seisab	doc_491521501742_item	2454303	et	3	main
sobib	doc_491521501742_item	2454029	et	3	main
anna	doc_491521501742_item	2454035	et	4	main
jälle	doc_491521501742_item	2454042	et	3	main
mitte	doc_491521501742_item	2454044	et	3	main
meeleolu	doc_491521501742_item	2454053	et	4	main
sest	doc_491521501742_item	2454059	et	4	main
artikkel	doc_491521501742_item	2454060	et	3	main
millele	doc_491521501742_item	2454061	et	3	main
kuulub	doc_491521501742_item	2454062	et	3	main
foto	doc_491521501742_item	2454063	et	4	main
on	doc_491521501742_item	2454064	et	4	main
üks	doc_491521501742_item	2454065	et	3	main
tähtsamatest	doc_491521501742_item	2454066	et	4	main
ajalehes	doc_491521501742_item	2454067	et	3	main
artikkel	doc_491521501742_item	2454068	et	3	main
seisab	doc_491521501742_item	2454069	et	3	main
kõige	doc_491521501742_item	2454070	et	4	main
keskmises	doc_491521501742_item	2454071	et	3	main
osas	doc_491521501742_item	2454072	et	4	main
suure	doc_491521501742_item	2454073	et	3	main
ning	doc_491521501742_item	2454075	et	3	main
ütlev	doc_491521501742_item	2454047	et	4	main
toetab	doc_491521501742_item	2454051	et	3	main
on	doc_491521501742_item	2454100	et	4	main
staatiline	doc_491521501742_item	2454102	et	3	main
ülejäänud	doc_491521501742_item	2454103	et	4	main
on	doc_491521501742_item	2454108	et	4	main
on	doc_491521501742_item	2454121	et	4	main
kolmas	doc_491521501742_item	2454125	et	3	main
stampfotolised	doc_491521501742_item	2454127	et	4	main
viimane	doc_491521501742_item	2454128	et	3	main
et	doc_491521501742_item	2454136	et	3	main
lase	doc_491521501742_item	2454138	et	4	main
pääseda	doc_491521501742_item	2454142	et	3	main
fotoallkiri	doc_491521501742_item	2454163	et	3	main
mõned	doc_491521501742_item	2454193	et	3	main
ilma	doc_491521501742_item	2454197	et	4	main
kuulub	doc_491521501742_item	2454207	et	3	main
jõhvi	doc_491521501742_item	2454213	et	4	main
teataja	doc_491521501742_item	2454214	et	4	main
neljandal	doc_491521501742_item	2454215	et	3	main
leheküljel	doc_491521501742_item	2454216	et	3	main
kaks	doc_491521501742_item	2454217	et	3	main
eristatud	doc_491521501742_item	2454222	et	4	main
ja	doc_491521501742_item	2454231	et	3	main
mis	doc_491521501742_item	2454239	et	4	main
küll	doc_491521501742_item	2454240	et	4	main
natukene	doc_491521501742_item	2454247	et	4	main
iseseisva	doc_491521501742_item	2454248	et	3	main
väikeste	doc_491521501742_item	2454257	et	4	main
kohta	doc_491521501742_item	2454259	et	4	main
ajalehe	doc_491521501742_item	2454273	et	3	main
ei	doc_491521501742_item	2454277	et	4	main
aga	doc_491521501742_item	2454291	et	3	main
info	doc_491521501742_item	2454302	et	4	main
kindlal	doc_491521501742_item	2454305	et	3	main
eristuskirjaga	doc_491521501742_item	2454309	et	4	main
võtmesõna	doc_491521501742_item	2454311	et	4	main
üks	doc_491521501742_item	2454317	et	3	main
kiri	doc_491521501742_item	2454320	et	3	main
veerulaius	doc_491521501742_item	2454334	et	4	main
olema	doc_491521501742_item	2454338	et	4	main
ma	doc_491521501742_item	2454340	et	3	main
et	doc_491521501742_item	2454342	et	3	main
probleemi	doc_491521501742_item	2454344	et	4	main
siin	doc_491521501742_item	2454345	et	4	main
provintsiaalne	doc_491521501742_item	2454352	et	3	main
ja	doc_491521501742_item	2454354	et	3	main
mingil	doc_491521501742_item	2454370	et	4	main
ajalehel	doc_491521501742_item	2454372	et	3	main
suurema	doc_491521501742_item	2454382	et	4	main
lugeja	doc_491521501742_item	2454399	et	4	main
mis	doc_491521501742_item	2454404	et	4	main
korrastavad	doc_491521501742_item	2454406	et	4	main
ja	doc_491521501742_item	2454407	et	3	main
kirjas	doc_491521501742_item	2454440	et	4	main
nende	doc_491521501742_item	2454443	et	4	main
kuulub	doc_491521501742_item	2454445	et	3	main
foto	doc_491521501742_item	2454447	et	4	main
lehest	doc_491521501742_item	2454457	et	4	main
täna	doc_491521501742_item	2454468	et	4	main
sport	doc_491521501742_item	2454472	et	3	main
kui	doc_491521501743_item	2454484	et	3	main
mordvalaste	doc_491521501743_item	2454488	et	3	main
veaanalüüsi	doc_491521501743_item	2454496	et	4	main
aluseks	doc_491521501743_item	2454497	et	4	main
kirjalikest	doc_491521501743_item	2454499	et	3	main
pedagoogikaülikoolis	doc_491521501743_item	2454506	et	4	main
õppivad	doc_491521501743_item	2454507	et	4	main
õppimist	doc_491521501743_item	2454526	et	4	main
alustasid	doc_491521501743_item	2454527	et	4	main
nad	doc_491521501743_item	2454528	et	3	main
vene	doc_491521501743_item	2454529	et	4	main
eesti	doc_491521501743_item	2454534	et	4	main
õpetaja	doc_491521501743_item	2454540	et	4	main
ja	doc_491521501743_item	2454545	et	3	main
õppides	doc_491521501743_item	2454558	et	4	main
vene	doc_491521501743_item	2454559	et	4	main
keeles	doc_491521501743_item	2454560	et	4	main
sõnad	doc_491521501743_item	2454579	et	4	main
keelele	doc_491521501743_item	2454582	et	4	main
sarnane	doc_491521501743_item	2454592	et	4	main
on	doc_491521501742_item	2454082	et	4	main
sest	doc_491521501742_item	2454094	et	4	main
ajaleht	doc_491521501742_item	2454099	et	3	main
portreefotod	doc_491521501742_item	2454104	et	3	main
on	doc_491521501742_item	2454126	et	4	main
aga	doc_491521501742_item	2454129	et	3	main
on	doc_491521501742_item	2454130	et	4	main
eriti	doc_491521501742_item	2454131	et	3	main
liigutav	doc_491521501742_item	2454132	et	4	main
sündmusfotosid	doc_491521501742_item	2454133	et	3	main
palju	doc_491521501742_item	2454135	et	4	main
fotodeallkirjad	doc_491521501742_item	2454145	et	4	main
seitse	doc_491521501742_item	2454153	et	3	main
allkirja	doc_491521501742_item	2454166	et	4	main
ja	doc_491521501742_item	2454187	et	3	main
sellega	doc_491521501742_item	2454188	et	3	main
allkitjad	doc_491521501742_item	2454189	et	4	main
fotod	doc_491521501742_item	2454194	et	3	main
on	doc_491521501742_item	2454195	et	4	main
millest	doc_491521501742_item	2454209	et	3	main
jutt	doc_491521501742_item	2454211	et	3	main
jää	doc_491521501742_item	2454234	et	4	main
allkirjast	doc_491521501742_item	2454235	et	4	main
pisut	doc_491521501742_item	2454236	et	3	main
ruum	doc_491521501742_item	2454244	et	3	main
lugejale	doc_491521501742_item	2454246	et	4	main
on	doc_491521501742_item	2454254	et	4	main
kergesti	doc_491521501742_item	2454255	et	3	main
loetav	doc_491521501742_item	2454256	et	4	main
kuulutuste	doc_491521501742_item	2454258	et	4	main
on	doc_491521501742_item	2454260	et	4	main
kasutatud	doc_491521501742_item	2454261	et	4	main
plokk-kiri	doc_491521501742_item	2454262	et	3	main
antiikva	doc_491521501742_item	2454265	et	4	main
olnud	doc_491521501742_item	2454278	et	4	main
ühetaolise	doc_491521501742_item	2454279	et	3	main
tunnet	doc_491521501742_item	2454280	et	3	main
viimasel	doc_491521501742_item	2454281	et	3	main
lehel	doc_491521501742_item	2454282	et	3	main
on	doc_491521501742_item	2454283	et	4	main
hästi	doc_491521501742_item	2454284	et	3	main
tööpakkumised	doc_491521501742_item	2454288	et	3	main
jt	doc_491521501742_item	2454290	et	4	main
kõik	doc_491521501742_item	2454292	et	4	main
info	doc_491521501742_item	2454293	et	4	main
kasutamisel	doc_491521501742_item	2454299	et	4	main
ning	doc_491521501742_item	2454300	et	3	main
põhjarannikus	doc_491521501742_item	2454307	et	3	main
esile	doc_491521501742_item	2454310	et	3	main
või	doc_491521501742_item	2454312	et	4	main
fraas	doc_491521501742_item	2454313	et	3	main
selleks	doc_491521501742_item	2454314	et	4	main
on	doc_491521501742_item	2454315	et	4	main
eristuskirjaseeria	doc_491521501742_item	2454318	et	4	main
paks	doc_491521501742_item	2454319	et	3	main
on	doc_491521501742_item	2454322	et	4	main
kasutatud	doc_491521501742_item	2454323	et	4	main
vähemalt	doc_491521501742_item	2454331	et	4	main
8-9	doc_491521501742_item	2454336	et	2	main
suurt	doc_491521501742_item	2454343	et	3	main
kuna	doc_491521501742_item	2454348	et	3	main
ei	doc_491521501742_item	2454355	et	4	main
sellele	doc_491521501742_item	2454359	et	4	main
ajalehele	doc_491521501742_item	2454360	et	3	main
pole	doc_491521501742_item	2454361	et	3	main
vaja	doc_491521501742_item	2454362	et	4	main
mahutada	doc_491521501742_item	2454363	et	3	main
leheküljele	doc_491521501742_item	2454368	et	3	main
suurel	doc_491521501742_item	2454371	et	3	main
ruumi	doc_491521501742_item	2454375	et	4	main
on	doc_491521501742_item	2454385	et	4	main
täiesti	doc_491521501742_item	2454386	et	3	main
leheküljed	doc_491521501742_item	2454394	et	3	main
enda	doc_491521501742_item	2454409	et	4	main
kogumiks	doc_491521501742_item	2454418	et	4	main
on	doc_491521501742_item	2454420	et	4	main
teine	doc_491521501742_item	2454123	et	3	main
ei	doc_491521501742_item	2454137	et	4	main
fotoallkiri	doc_491521501742_item	2454143	et	3	main
on	doc_491521501742_item	2454152	et	4	main
rida	doc_491521501742_item	2454154	et	4	main
teksti	doc_491521501742_item	2454155	et	4	main
see	doc_491521501742_item	2454156	et	3	main
nii	doc_491521501742_item	2454164	et	3	main
lugeja	doc_491521501742_item	2454167	et	4	main
ei	doc_491521501742_item	2454168	et	4	main
viitsita	doc_491521501742_item	2454169	et	4	main
lugeda	doc_491521501742_item	2454170	et	3	main
mõned	doc_491521501742_item	2454171	et	3	main
allkirjad	doc_491521501742_item	2454172	et	3	main
jõhvi	doc_491521501742_item	2454173	et	4	main
teatajas	doc_491521501742_item	2454174	et	4	main
lihtsalt	doc_491521501742_item	2454175	et	4	main
ümberjutustavad	doc_491521501742_item	2454176	et	3	main
seda	doc_491521501742_item	2454177	et	3	main
mis	doc_491521501742_item	2454178	et	4	main
on	doc_491521501742_item	2454179	et	4	main
pildil	doc_491521501742_item	2454180	et	3	main
esitatud	doc_491521501742_item	2454181	et	4	main
kuigi	doc_491521501742_item	2454182	et	3	main
foto	doc_491521501742_item	2454183	et	4	main
räägib	doc_491521501742_item	2454184	et	3	main
seda	doc_491521501742_item	2454185	et	3	main
ise	doc_491521501742_item	2454186	et	4	main
on	doc_491521501742_item	2454190	et	4	main
mitte	doc_491521501742_item	2454191	et	3	main
raskusi	doc_491521501742_item	2454202	et	4	main
ja	doc_491521501742_item	2454208	et	3	main
ladunud	doc_491521501742_item	2454228	et	4	main
fotodest	doc_491521501742_item	2454229	et	3	main
kitsamalt	doc_491521501742_item	2454230	et	4	main
ruumi	doc_491521501742_item	2454238	et	4	main
olla	doc_491521501742_item	2454242	et	3	main
annab	doc_491521501742_item	2454245	et	3	main
mõtlemise	doc_491521501742_item	2454249	et	4	main
võimalust	doc_491521501742_item	2454250	et	3	main
pisiinfo	doc_491521501742_item	2454251	et	4	main
aga	doc_491521501742_item	2454264	et	3	main
tähed	doc_491521501742_item	2454267	et	3	main
kohe	doc_491521501742_item	2454269	et	4	main
arusaadavad	doc_491521501742_item	2454270	et	3	main
suured	doc_491521501742_item	2454271	et	3	main
palju	doc_491521501742_item	2454285	et	4	main
pisiinfot	doc_491521501742_item	2454286	et	3	main
ost-müük	doc_491521501742_item	2454289	et	3	main
on	doc_491521501742_item	2454294	et	4	main
hästi	doc_491521501742_item	2454295	et	3	main
iga	doc_491521501742_item	2454301	et	4	main
tõstetakse	doc_491521501742_item	2454308	et	4	main
veerulaius	doc_491521501742_item	2454324	et	4	main
10	doc_491521501742_item	2454325	et	2	main
peab	doc_491521501742_item	2454335	et	4	main
ei	doc_491521501742_item	2454346	et	4	main
väike	doc_491521501742_item	2454351	et	4	main
nõua	doc_491521501742_item	2454356	et	4	main
ranget	doc_491521501742_item	2454357	et	3	main
kriteeriume	doc_491521501742_item	2454358	et	3	main
ühele	doc_491521501742_item	2454367	et	3	main
vaid	doc_491521501742_item	2454373	et	3	main
veerulaiuse	doc_491521501742_item	2454383	et	4	main
põhjendatud	doc_491521501742_item	2454387	et	4	main
elemendid	doc_491521501742_item	2454403	et	3	main
haagivad	doc_491521501742_item	2454411	et	3	main
nähtav	doc_491521501742_item	2454421	et	4	main
on	doc_491521501742_item	2454423	et	4	main
oluline	doc_491521501742_item	2454424	et	4	main
on	doc_491521501742_item	2454427	et	4	main
oluline	doc_491521501742_item	2454429	et	4	main
lood	doc_491521501742_item	2454432	et	4	main
paksemas	doc_491521501742_item	2454439	et	4	main
jõhvi	doc_491521501742_item	2454448	et	4	main
puuduvad	doc_491521501742_item	2454451	et	4	main
koosneb	doc_491521501742_item	2454453	et	3	main
lisa	doc_491521501742_item	2454454	et	4	main
vaid	doc_491521501742_item	2454455	et	3	main
teda	doc_491521501742_item	2454466	et	4	main
kas	doc_491521501742_item	2454469	et	3	main
vead	doc_491521501743_item	2454475	et	4	main
keele	doc_491521501743_item	2454483	et	4	main
keelekasutuses	doc_491521501743_item	2454489	et	4	main
kodutöö	doc_491521501743_item	2454491	et	4	main
2001	doc_491521501743_item	2454493	et	2	main
on	doc_491521501743_item	2454498	et	4	main
ajalehes	doc_491521501742_item	2454223	et	3	main
plokk-kirjaga	doc_491521501742_item	2454225	et	3	main
allkirjad	doc_491521501742_item	2454226	et	3	main
seega	doc_491521501742_item	2454232	et	4	main
tühja	doc_491521501742_item	2454237	et	4	main
võiks	doc_491521501742_item	2454241	et	4	main
suuremate	doc_491521501742_item	2454263	et	4	main
ilusam	doc_491521501742_item	2454274	et	4	main
et	doc_491521501742_item	2454276	et	3	main
kuulutused	doc_491521501742_item	2454287	et	4	main
eristatud	doc_491521501742_item	2454296	et	4	main
oma	doc_491521501742_item	2454304	et	4	main
kohal	doc_491521501742_item	2454306	et	4	main
kasutatud	doc_491521501742_item	2454316	et	4	main
ajalehes	doc_491521501742_item	2454321	et	3	main
cic	doc_491521501742_item	2454326	et	4	main
10	doc_491521501742_item	2454329	et	2	main
cic	doc_491521501742_item	2454330	et	4	main
pisiinfo	doc_491521501742_item	2454333	et	4	main
cic	doc_491521501742_item	2454337	et	4	main
aga	doc_491521501742_item	2454339	et	3	main
arvan	doc_491521501742_item	2454341	et	3	main
on	doc_491521501742_item	2454350	et	4	main
palju	doc_491521501742_item	2454365	et	4	main
infot	doc_491521501742_item	2454366	et	3	main
aga	doc_491521501742_item	2454377	et	3	main
vähem	doc_491521501742_item	2454379	et	4	main
sellega	doc_491521501742_item	2454380	et	3	main
on	doc_491521501742_item	2454381	et	4	main
põhjaranniku	doc_491521501742_item	2454389	et	3	main
on	doc_491521501742_item	2454391	et	4	main
orienteeruda	doc_491521501742_item	2454393	et	3	main
kohe	doc_491521501742_item	2454400	et	4	main
leiab	doc_491521501742_item	2454401	et	3	main
pilgu	doc_491521501742_item	2454408	et	4	main
külge	doc_491521501742_item	2454410	et	4	main
ning	doc_491521501742_item	2454412	et	3	main
takistavad	doc_491521501742_item	2454413	et	4	main
lehtedel	doc_491521501742_item	2454414	et	4	main
kirevaks	doc_491521501742_item	2454416	et	4	main
kus	doc_491521501742_item	2454426	et	3	main
on	doc_491521501742_item	2454433	et	4	main
paigutatud	doc_491521501742_item	2454434	et	4	main
kaksiklehekülgede	doc_491521501742_item	2454435	et	4	main
või	doc_491521501742_item	2454441	et	4	main
suur	doc_491521501742_item	2454446	et	3	main
sest	doc_491521501742_item	2454452	et	4	main
kahest	doc_491521501742_item	2454456	et	4	main
ise	doc_491521501742_item	2454464	et	4	main
mordvalaste	doc_491521501743_item	2454476	et	3	main
keelekasutuses	doc_491521501743_item	2454477	et	4	main
pedagoogika	doc_491521501743_item	2454479	et	4	main
ü	doc_491521501743_item	2454480	et	4	main
vead	doc_491521501743_item	2454487	et	4	main
töödest	doc_491521501743_item	2454500	et	3	main
teinud	doc_491521501743_item	2454505	et	4	main
et	doc_491521501743_item	2454523	et	3	main
loomulikult	doc_491521501743_item	2454538	et	4	main
hakkas	doc_491521501743_item	2454539	et	3	main
rohkem	doc_491521501743_item	2454544	et	4	main
mõtlesid	doc_491521501743_item	2454554	et	4	main
nad	doc_491521501743_item	2454555	et	3	main
eesti	doc_491521501743_item	2454556	et	4	main
ja	doc_491521501743_item	2454561	et	3	main
see	doc_491521501743_item	2454562	et	3	main
on	doc_491521501743_item	2454563	et	4	main
nende	doc_491521501743_item	2454564	et	4	main
ersa	doc_491521501743_item	2454572	et	4	main
väga	doc_491521501743_item	2454583	et	3	main
samas	doc_491521501743_item	2454585	et	4	main
keelele	doc_491521501743_item	2454594	et	4	main
kui	doc_491521501743_item	2454595	et	3	main
vene	doc_491521501743_item	2454596	et	4	main
kirjutatud	doc_491521501743_item	2454601	et	4	main
väga	doc_491521501743_item	2454607	et	3	main
on	doc_491521501743_item	2454610	et	4	main
keelt	doc_491521501743_item	2454612	et	4	main
kasutanud	doc_491521501743_item	2454613	et	4	main
juba	doc_491521501743_item	2454614	et	3	main
3	doc_491521501743_item	2454615	et	2	main
aastat	doc_491521501743_item	2454616	et	3	main
ja	doc_491521501743_item	2454617	et	3	main
räägivad	doc_491521501743_item	2454618	et	3	main
ning	doc_491521501742_item	2454327	et	3	main
pisiinfos	doc_491521501742_item	2454328	et	3	main
tavaline	doc_491521501742_item	2454332	et	4	main
ole	doc_491521501742_item	2454347	et	4	main
põhjarannik	doc_491521501742_item	2454349	et	3	main
ajaleht	doc_491521501742_item	2454353	et	3	main
päris	doc_491521501742_item	2454364	et	4	main
nagu	doc_491521501742_item	2454369	et	3	main
vastupidi	doc_491521501742_item	2454374	et	3	main
on	doc_491521501742_item	2454376	et	4	main
infot	doc_491521501742_item	2454378	et	3	main
kasutamine	doc_491521501742_item	2454384	et	4	main
kokkuvõte	doc_491521501742_item	2454388	et	3	main
ajalehes	doc_491521501742_item	2454390	et	3	main
kerge	doc_491521501742_item	2454392	et	4	main
on	doc_491521501742_item	2454395	et	4	main
tervikuna	doc_491521501742_item	2454396	et	3	main
kergesti	doc_491521501742_item	2454397	et	3	main
haaratavad	doc_491521501742_item	2454398	et	4	main
domineerivad	doc_491521501742_item	2454402	et	4	main
lehekülge	doc_491521501742_item	2454405	et	4	main
hajumast	doc_491521501742_item	2454415	et	3	main
laikude	doc_491521501742_item	2454417	et	4	main
kohe	doc_491521501742_item	2454419	et	4	main
kus	doc_491521501742_item	2454422	et	3	main
vähem	doc_491521501742_item	2454428	et	4	main
tähtsamad	doc_491521501742_item	2454430	et	4	main
uudised	doc_491521501742_item	2454431	et	3	main
paremapoolsele	doc_491521501742_item	2454436	et	3	main
lehele	doc_491521501742_item	2454437	et	3	main
trükitud	doc_491521501742_item	2454438	et	4	main
siis	doc_491521501742_item	2454442	et	3	main
rubriigid	doc_491521501742_item	2454450	et	3	main
aga	doc_491521501742_item	2454458	et	3	main
põhjarannikus	doc_491521501742_item	2454459	et	3	main
on	doc_491521501742_item	2454461	et	4	main
mida	doc_491521501742_item	2454465	et	4	main
majandus	doc_491521501742_item	2454471	et	4	main
või	doc_491521501742_item	2454473	et	4	main
meelelahutus	doc_491521501742_item	2454474	et	4	main
likool	doc_491521501743_item	2454481	et	4	main
eesti	doc_491521501743_item	2454482	et	4	main
võõrkeele	doc_491521501743_item	2454485	et	4	main
kontrastiivlingvistika	doc_491521501743_item	2454490	et	4	main
tallinn	doc_491521501743_item	2454492	et	4	main
sissejuhatus	doc_491521501743_item	2454494	et	4	main
käesoleva	doc_491521501743_item	2454495	et	3	main
kogutud	doc_491521501743_item	2454501	et	4	main
mida	doc_491521501743_item	2454503	et	4	main
on	doc_491521501743_item	2454504	et	4	main
õpiti	doc_491521501743_item	2454533	et	3	main
niipea	doc_491521501743_item	2454541	et	3	main
õppijate	doc_491521501743_item	2454550	et	4	main
sõnade	doc_491521501743_item	2454552	et	3	main
järgi	doc_491521501743_item	2454553	et	4	main
kindlasti	doc_491521501743_item	2454566	et	3	main
mõjutanud	doc_491521501743_item	2454567	et	4	main
ka	doc_491521501743_item	2454568	et	3	main
märgata	doc_491521501743_item	2454576	et	4	main
et	doc_491521501743_item	2454577	et	3	main
paljud	doc_491521501743_item	2454578	et	3	main
ütlesid	doc_491521501743_item	2454586	et	4	main
nad	doc_491521501743_item	2454587	et	3	main
tööd	doc_491521501743_item	2454599	et	4	main
seega	doc_491521501743_item	2454606	et	4	main
nii	doc_491521501743_item	2454621	et	3	main
kirjutatud	doc_491521501743_item	2454632	et	4	main
kirjandid	doc_491521501743_item	2454633	et	3	main
ja	doc_491521501743_item	2454634	et	3	main
lühemad	doc_491521501743_item	2454635	et	4	main
jutud	doc_491521501743_item	2454636	et	3	main
jagatud	doc_491521501743_item	2454642	et	4	main
mida	doc_491521501743_item	2454648	et	4	main
paigutada	doc_491521501743_item	2454652	et	3	main
on	doc_491521501743_item	2454654	et	4	main
grupeerimise	doc_491521501743_item	2454659	et	4	main
järjekord	doc_491521501743_item	2454660	et	3	main
ei	doc_491521501743_item	2454661	et	4	main
palju	doc_491521501743_item	2454673	et	4	main
esinenud	doc_491521501743_item	2454675	et	4	main
ja	doc_491521501743_item	2454676	et	3	main
leitud	doc_491521501743_item	2454681	et	4	main
sest	doc_491521501743_item	2454693	et	4	main
üldjuhul	doc_491521501743_item	2454697	et	3	main
info	doc_491521501742_item	2454425	et	4	main
juurde	doc_491521501742_item	2454444	et	4	main
teatajas	doc_491521501742_item	2454449	et	4	main
nemad	doc_491521501742_item	2454460	et	3	main
lugeja	doc_491521501742_item	2454462	et	4	main
valib	doc_491521501742_item	2454463	et	3	main
huvitab	doc_491521501742_item	2454467	et	3	main
uudised	doc_491521501742_item	2454470	et	3	main
tallinna	doc_491521501743_item	2454478	et	4	main
õppetool	doc_491521501743_item	2454486	et	3	main
vead	doc_491521501743_item	2454502	et	4	main
mordvalased	doc_491521501743_item	2454508	et	3	main
ersad	doc_491521501743_item	2454509	et	4	main
ja	doc_491521501743_item	2454510	et	3	main
moksad	doc_491521501743_item	2454511	et	4	main
kelle	doc_491521501743_item	2454512	et	4	main
emakeel	doc_491521501743_item	2454513	et	4	main
on	doc_491521501743_item	2454514	et	4	main
ersa	doc_491521501743_item	2454515	et	4	main
keel	doc_491521501743_item	2454516	et	4	main
antud	doc_491521501743_item	2454517	et	4	main
juhul	doc_491521501743_item	2454518	et	3	main
on	doc_491521501743_item	2454519	et	4	main
oluline	doc_491521501743_item	2454520	et	4	main
ära	doc_491521501743_item	2454521	et	4	main
keele	doc_491521501743_item	2454530	et	4	main
kaudu	doc_491521501743_item	2454531	et	3	main
keelt	doc_491521501743_item	2454535	et	4	main
aasta	doc_491521501743_item	2454537	et	4	main
võimalik	doc_491521501743_item	2454543	et	3	main
eesti	doc_491521501743_item	2454547	et	4	main
keelt	doc_491521501743_item	2454548	et	4	main
kasutama	doc_491521501743_item	2454549	et	3	main
endi	doc_491521501743_item	2454551	et	4	main
keelekasutust	doc_491521501743_item	2454565	et	4	main
neid	doc_491521501743_item	2454570	et	4	main
omavahel	doc_491521501743_item	2454571	et	3	main
keeles	doc_491521501743_item	2454573	et	4	main
rääkimas	doc_491521501743_item	2454574	et	3	main
võis	doc_491521501743_item	2454575	et	4	main
vene	doc_491521501743_item	2454581	et	4	main
eesti	doc_491521501743_item	2454593	et	4	main
praeguseks	doc_491521501743_item	2454609	et	3	main
kui	doc_491521501743_item	2454623	et	3	main
töödeks	doc_491521501743_item	2454628	et	3	main
olid	doc_491521501743_item	2454629	et	4	main
on	doc_491521501743_item	2454641	et	4	main
ei	doc_491521501743_item	2454649	et	4	main
töö	doc_491521501743_item	2454657	et	4	main
ole	doc_491521501743_item	2454662	et	4	main
uuritud	doc_491521501743_item	2454670	et	4	main
väga	doc_491521501743_item	2454672	et	3	main
vead	doc_491521501743_item	2454682	et	4	main
pigem	doc_491521501743_item	2454684	et	3	main
juhuslikud	doc_491521501743_item	2454685	et	3	main
arvata	doc_491521501743_item	2454687	et	4	main
et	doc_491521501743_item	2454688	et	3	main
tihti	doc_491521501743_item	2454689	et	3	main
oli	doc_491521501743_item	2454690	et	3	main
tegemist	doc_491521501743_item	2454691	et	4	main
hooletusega	doc_491521501743_item	2454692	et	4	main
kordunud	doc_491521501743_item	2454696	et	4	main
kasutatud	doc_491521501743_item	2454730	et	4	main
sarnastes	doc_491521501743_item	2454734	et	4	main
lühikesi	doc_491521501743_item	2454737	et	4	main
pikki	doc_491521501743_item	2454739	et	4	main
vokaale	doc_491521501743_item	2454740	et	3	main
pastet	doc_491521501743_item	2454743	et	4	main
ersa	doc_491521501743_item	2454769	et	4	main
märkida	doc_491521501743_item	2454522	et	4	main
eesti	doc_491521501743_item	2454524	et	4	main
keele	doc_491521501743_item	2454525	et	4	main
nii	doc_491521501743_item	2454532	et	3	main
terve	doc_491521501743_item	2454536	et	4	main
kui	doc_491521501743_item	2454542	et	3	main
rohkem	doc_491521501743_item	2454546	et	4	main
keelt	doc_491521501743_item	2454557	et	4	main
kuuldes	doc_491521501743_item	2454569	et	4	main
olid	doc_491521501743_item	2454580	et	4	main
sarnased	doc_491521501743_item	2454584	et	4	main
et	doc_491521501743_item	2454588	et	3	main
grammatika	doc_491521501743_item	2454589	et	4	main
on	doc_491521501743_item	2454590	et	4	main
pigem	doc_491521501743_item	2454591	et	3	main
keelele	doc_491521501743_item	2454597	et	4	main
uuritud	doc_491521501743_item	2454598	et	4	main
keele	doc_491521501743_item	2454602	et	4	main
alguses	doc_491521501743_item	2454608	et	4	main
nad	doc_491521501743_item	2454611	et	3	main
grammatikat	doc_491521501743_item	2454622	et	3	main
pidades	doc_491521501743_item	2454627	et	3	main
mis	doc_491521501743_item	2454640	et	4	main
vigu	doc_491521501743_item	2454647	et	3	main
kusagile	doc_491521501743_item	2454651	et	3	main
need	doc_491521501743_item	2454653	et	3	main
seotud	doc_491521501743_item	2454663	et	4	main
vigade	doc_491521501743_item	2454664	et	3	main
vahe	doc_491521501743_item	2454680	et	4	main
ole	doc_491521501743_item	2454721	et	4	main
seetõttu	doc_491521501743_item	2454725	et	3	main
keelele	doc_491521501743_item	2454732	et	4	main
referat	doc_491521501743_item	2454742	et	4	main
sokolad	doc_491521501743_item	2454744	et	4	main
teiste	doc_491521501743_item	2454746	et	4	main
ta	doc_491521501743_item	2454750	et	4	main
korrusel	doc_491521501743_item	2454755	et	3	main
nende	doc_491521501743_item	2454763	et	4	main
mis	doc_491521501743_item	2454771	et	4	main
suhteliselt	doc_491521501743_item	2454780	et	4	main
ja	doc_491521501743_item	2454782	et	3	main
kogu	doc_491521501743_item	2454783	et	4	main
ja	doc_491521501743_item	2454787	et	3	main
on	doc_491521501743_item	2454798	et	4	main
siin	doc_491521501743_item	2454799	et	4	main
sõnavara	doc_491521501743_item	2454805	et	4	main
suhteliselt	doc_491521501743_item	2454808	et	4	main
õpitud	doc_491521501743_item	2454819	et	4	main
tehtud	doc_491521501743_item	2454833	et	4	main
enamgi	doc_491521501743_item	2454834	et	4	main
nimisõnades	doc_491521501743_item	2454835	et	3	main
olnud	doc_491521501743_item	2454842	et	4	main
uuritud	doc_491521501743_item	2454844	et	4	main
ja	doc_491521501743_item	2454854	et	3	main
suhteliselt	doc_491521501743_item	2454857	et	4	main
palju	doc_491521501743_item	2454858	et	4	main
siinkohal	doc_491521501743_item	2454859	et	3	main
võib	doc_491521501743_item	2454860	et	3	main
ka	doc_491521501743_item	2454861	et	3	main
keeles	doc_491521501743_item	2454866	et	4	main
vähem	doc_491521501743_item	2454869	et	4	main
kui	doc_491521501743_item	2454870	et	3	main
eesti	doc_491521501743_item	2454871	et	4	main
keeles	doc_491521501743_item	2454872	et	4	main
nimi	doc_491521501743_item	2454929	et	3	main
irina	doc_491521501743_item	2454937	et	3	main
ka	doc_491521501743_item	2454943	et	3	main
eesti	doc_491521501743_item	2454945	et	4	main
tehtud	doc_491521501743_item	2454952	et	4	main
ostsid	doc_491521501743_item	2454956	et	4	main
roosikimbi	doc_491521501743_item	2454958	et	3	main
sõi	doc_491521501743_item	2454959	et	3	main
kreemukooki	doc_491521501743_item	2454960	et	4	main
peale	doc_491521501743_item	2454961	et	4	main
selle	doc_491521501743_item	2454962	et	4	main
oli	doc_491521501743_item	2454963	et	3	main
kasutatud	doc_491521501743_item	2454968	et	4	main
mõjutused	doc_491521501743_item	2454974	et	4	main
ja	doc_491521501743_item	2455021	et	3	main
oli	doc_491521501743_item	2455026	et	3	main
aga	doc_491521501743_item	2455030	et	3	main
selles	doc_491521501743_item	2455039	et	4	main
käivad	doc_491521501743_item	2455041	et	4	main
panen	doc_491521501743_item	2455043	et	3	main
panis	doc_491521501743_item	2455045	et	4	main
kohakääne	doc_491521501743_item	2455046	et	3	main
ortograafia	doc_491521501743_item	2455047	et	4	main
on	doc_491521501743_item	2454600	et	4	main
õppimise	doc_491521501743_item	2454603	et	4	main
esimesel	doc_491521501743_item	2454604	et	3	main
aasta	doc_491521501743_item	2454605	et	4	main
väga	doc_491521501743_item	2454619	et	3	main
hästi	doc_491521501743_item	2454620	et	3	main
hääldust	doc_491521501743_item	2454625	et	4	main
silmas	doc_491521501743_item	2454626	et	4	main
põhiliselt	doc_491521501743_item	2454630	et	4	main
kodus	doc_491521501743_item	2454631	et	4	main
järgnevalt	doc_491521501743_item	2454637	et	4	main
leitud	doc_491521501743_item	2454638	et	4	main
8	doc_491521501743_item	2454643	et	2	main
gruppi	doc_491521501743_item	2454644	et	4	main
oli	doc_491521501743_item	2454645	et	3	main
teiste	doc_491521501743_item	2454655	et	4	main
töödes	doc_491521501743_item	2454671	et	3	main
vead	doc_491521501743_item	2454694	et	4	main
ei	doc_491521501743_item	2454695	et	4	main
võinud	doc_491521501743_item	2454699	et	4	main
töös	doc_491521501743_item	2454701	et	3	main
sõnades	doc_491521501743_item	2454735	et	4	main
kui	doc_491521501743_item	2454738	et	3	main
on	doc_491521501743_item	2454751	et	4	main
kaubamajjas	doc_491521501743_item	2454753	et	4	main
on	doc_491521501743_item	2454756	et	4	main
vestluses	doc_491521501743_item	2454757	et	3	main
mordvalastega	doc_491521501743_item	2454758	et	3	main
võis	doc_491521501743_item	2454759	et	4	main
tähele	doc_491521501743_item	2454760	et	3	main
panna	doc_491521501743_item	2454761	et	4	main
et	doc_491521501743_item	2454762	et	3	main
keele	doc_491521501743_item	2454765	et	4	main
on	doc_491521501743_item	2454767	et	4	main
mõjutanud	doc_491521501743_item	2454768	et	4	main
vene	doc_491521501743_item	2454775	et	4	main
tugevalt	doc_491521501743_item	2454781	et	4	main
sujuvam	doc_491521501743_item	2454786	et	4	main
pehmem	doc_491521501743_item	2454788	et	4	main
kui	doc_491521501743_item	2454789	et	3	main
eestlasel	doc_491521501743_item	2454790	et	3	main
astmevaheldus	doc_491521501743_item	2454791	et	4	main
vähe	doc_491521501743_item	2454796	et	3	main
on	doc_491521501743_item	2454806	et	4	main
olid	doc_491521501743_item	2454823	et	4	main
nt	doc_491521501743_item	2454826	et	4	main
keskkoolis	doc_491521501743_item	2454828	et	4	main
selle	doc_491521501743_item	2454829	et	4	main
verbiga	doc_491521501743_item	2454830	et	3	main
oli	doc_491521501743_item	2454831	et	3	main
vigu	doc_491521501743_item	2454832	et	3	main
tehtud	doc_491521501743_item	2454839	et	4	main
neid	doc_491521501743_item	2454843	et	4	main
objektivead	doc_491521501743_item	2454846	et	4	main
vorm	doc_491521501743_item	2454847	et	3	main
ja	doc_491521501743_item	2454848	et	3	main
käändevalik	doc_491521501743_item	2454849	et	4	main
erinevaid	doc_491521501743_item	2454853	et	4	main
neid	doc_491521501743_item	2454855	et	4	main
on	doc_491521501743_item	2454867	et	4	main
puhul	doc_491521501743_item	2454875	et	4	main
oli	doc_491521501743_item	2454876	et	3	main
moodustatud	doc_491521501743_item	2454879	et	4	main
ennekõike	doc_491521501743_item	2454883	et	3	main
jelena	doc_491521501743_item	2454924	et	4	main
on	doc_491521501743_item	2454926	et	4	main
pensionärid	doc_491521501743_item	2454927	et	3	main
on	doc_491521501743_item	2454930	et	4	main
jelena	doc_491521501743_item	2454931	et	4	main
minu	doc_491521501743_item	2454932	et	3	main
noorem	doc_491521501743_item	2454933	et	4	main
raskusi	doc_491521501743_item	2454948	et	4	main
nii	doc_491521501743_item	2454949	et	3	main
käändeid	doc_491521501743_item	2454966	et	3	main
võivad	doc_491521501743_item	2454970	et	4	main
taas	doc_491521501743_item	2454973	et	3	main
ka	doc_491521501743_item	2454624	et	3	main
vead	doc_491521501743_item	2454639	et	4	main
ka	doc_491521501743_item	2454646	et	3	main
osanud	doc_491521501743_item	2454650	et	4	main
seas	doc_491521501743_item	2454656	et	4	main
lõpus	doc_491521501743_item	2454658	et	4	main
olulisusega	doc_491521501743_item	2454665	et	4	main
hääldus	doc_491521501743_item	2454666	et	4	main
ja	doc_491521501743_item	2454667	et	3	main
õigekiri	doc_491521501743_item	2454668	et	3	main
õigekirjavigu	doc_491521501743_item	2454669	et	3	main
ei	doc_491521501743_item	2454674	et	4	main
sarnaseid	doc_491521501743_item	2454677	et	4	main
vigu	doc_491521501743_item	2454678	et	3	main
oli	doc_491521501743_item	2454679	et	3	main
olid	doc_491521501743_item	2454683	et	4	main
võib	doc_491521501743_item	2454686	et	3	main
ei	doc_491521501743_item	2454698	et	4	main
tehtud	doc_491521501743_item	2454702	et	4	main
viga	doc_491521501743_item	2454703	et	4	main
enam	doc_491521501743_item	2454705	et	4	main
teises	doc_491521501743_item	2454704	et	4	main
leida	doc_491521501743_item	2454706	et	3	main
märkida	doc_491521501743_item	2454707	et	4	main
võis	doc_491521501743_item	2454708	et	4	main
mõningaid	doc_491521501743_item	2454709	et	3	main
õigekirjavigu	doc_491521501743_item	2454710	et	3	main
mis	doc_491521501743_item	2454711	et	4	main
on	doc_491521501743_item	2454712	et	4	main
ilmselt	doc_491521501743_item	2454713	et	4	main
tehtud	doc_491521501743_item	2454714	et	4	main
vene	doc_491521501743_item	2454715	et	4	main
keele	doc_491521501743_item	2454716	et	4	main
mõjutusel	doc_491521501743_item	2454717	et	4	main
vene	doc_491521501743_item	2454718	et	4	main
keeles	doc_491521501743_item	2454719	et	4	main
ei	doc_491521501743_item	2454720	et	4	main
ühes	doc_491521501743_item	2454700	et	4	main
ja	doc_491521501743_item	2454724	et	3	main
ka	doc_491521501743_item	2454727	et	3	main
vene	doc_491521501743_item	2454731	et	4	main
väga	doc_491521501743_item	2454733	et	3	main
jt	doc_491521501743_item	2454745	et	4	main
leitud	doc_491521501743_item	2454747	et	4	main
näiteid	doc_491521501743_item	2454749	et	3	main
pensioner	doc_491521501743_item	2454752	et	4	main
esimesel	doc_491521501743_item	2454754	et	3	main
eesti	doc_491521501743_item	2454764	et	4	main
keel	doc_491521501743_item	2454770	et	4	main
õppurite	doc_491521501743_item	2454804	et	3	main
on	doc_491521501743_item	2454816	et	4	main
hästi	doc_491521501743_item	2454817	et	3	main
ära	doc_491521501743_item	2454818	et	4	main
verbides	doc_491521501743_item	2454825	et	3	main
õpisin	doc_491521501743_item	2454827	et	4	main
vähemalt	doc_491521501743_item	2454840	et	4	main
töödes	doc_491521501743_item	2454845	et	3	main
käändevigu	doc_491521501743_item	2454850	et	4	main
töödes	doc_491521501743_item	2454852	et	3	main
vead	doc_491521501743_item	2454873	et	4	main
mille	doc_491521501743_item	2454874	et	3	main
käände	doc_491521501743_item	2454885	et	4	main
pikki	doc_491521501743_item	2454722	et	4	main
vokaale	doc_491521501743_item	2454723	et	3	main
oli	doc_491521501743_item	2454726	et	3	main
eesti	doc_491521501743_item	2454728	et	4	main
keeles	doc_491521501743_item	2454729	et	4	main
pigem	doc_491521501743_item	2454736	et	3	main
nt	doc_491521501743_item	2454741	et	4	main
õigekirjavigade	doc_491521501743_item	2454748	et	3	main
hääldust	doc_491521501743_item	2454766	et	4	main
eestlasele	doc_491521501743_item	2454772	et	3	main
tundub	doc_491521501743_item	2454773	et	3	main
lihtsalt	doc_491521501743_item	2454774	et	4	main
kaashäälikuid	doc_491521501743_item	2454778	et	3	main
on	doc_491521501743_item	2454785	et	4	main
oli	doc_491521501743_item	2454794	et	3	main
ilmselt	doc_491521501743_item	2454797	et	4	main
oluliseks	doc_491521501743_item	2454800	et	4	main
teguriks	doc_491521501743_item	2454801	et	3	main
see	doc_491521501743_item	2454802	et	3	main
et	doc_491521501743_item	2454803	et	3	main
veel	doc_491521501743_item	2454807	et	4	main
väike	doc_491521501743_item	2454809	et	4	main
teine	doc_491521501743_item	2454810	et	3	main
võimalus	doc_491521501743_item	2454811	et	3	main
ainukesed	doc_491521501743_item	2454820	et	4	main
leitud	doc_491521501743_item	2454821	et	4	main
keele	doc_491521501743_item	2454776	et	4	main
aktsendina	doc_491521501743_item	2454777	et	3	main
hääldatakse	doc_491521501743_item	2454779	et	3	main
kõne	doc_491521501743_item	2454784	et	4	main
astmevahelduse	doc_491521501743_item	2454792	et	4	main
vigu	doc_491521501743_item	2454793	et	3	main
üllatavalt	doc_491521501743_item	2454795	et	4	main
on	doc_491521501743_item	2454812	et	4	main
see	doc_491521501743_item	2454813	et	3	main
et	doc_491521501743_item	2454814	et	3	main
astmevaheldus	doc_491521501743_item	2454815	et	4	main
vead	doc_491521501743_item	2454822	et	4	main
astmevahelduse	doc_491521501743_item	2454836	et	4	main
vigu	doc_491521501743_item	2454837	et	3	main
ei	doc_491521501743_item	2454838	et	4	main
ei	doc_491521501743_item	2454841	et	4	main
ära	doc_491521501743_item	2454862	et	4	main
märkida	doc_491521501743_item	2454863	et	4	main
et	doc_491521501743_item	2454864	et	3	main
valesti	doc_491521501743_item	2454878	et	3	main
siia	doc_491521501743_item	2454880	et	4	main
alla	doc_491521501743_item	2454881	et	3	main
käib	doc_491521501743_item	2454882	et	3	main
nimi	doc_491521501743_item	2454922	et	3	main
nainevanemad	doc_491521501743_item	2454925	et	4	main
õde	doc_491521501743_item	2454934	et	4	main
nimi	doc_491521501743_item	2454935	et	3	main
käändelõpu	doc_491521501743_item	2454939	et	4	main
valmistab	doc_491521501743_item	2454942	et	3	main
tihti	doc_491521501743_item	2454944	et	3	main
seas	doc_491521501743_item	2454954	et	4	main
olla	doc_491521501743_item	2454972	et	3	main
nt	doc_491521501743_item	2454977	et	4	main
kasutatud	doc_491521501743_item	2455013	et	4	main
kindlasti	doc_491521501743_item	2455014	et	3	main
võib	doc_491521501743_item	2455015	et	3	main
põhjusi	doc_491521501743_item	2455016	et	3	main
otsida	doc_491521501743_item	2455017	et	4	main
jälle	doc_491521501743_item	2455018	et	3	main
mordvalaste	doc_491521501743_item	2455019	et	3	main
emakeelest	doc_491521501743_item	2455020	et	4	main
vene	doc_491521501743_item	2455023	et	4	main
sõnale	doc_491521501743_item	2455027	et	3	main
oli	doc_491521501743_item	2455032	et	3	main
naudivad	doc_491521501743_item	2455038	et	3	main
elavad	doc_491521501743_item	2455049	et	4	main
saksamaas	doc_491521501743_item	2455050	et	3	main
väliskohakäänete	doc_491521501743_item	2455051	et	3	main
sõidan	doc_491521501743_item	2455054	et	3	main
rektsioonivigade	doc_491521501743_item	2455074	et	4	main
eelnevate	doc_491521501743_item	2455082	et	4	main
näidete	doc_491521501743_item	2455083	et	3	main
puhul	doc_491521501743_item	2455084	et	4	main
ühildumisvead	doc_491521501743_item	2455091	et	4	main
oli	doc_491521501743_item	2455093	et	3	main
ei	doc_491521501743_item	2455097	et	4	main
vigu	doc_491521501743_item	2455102	et	3	main
mõjutanud	doc_491521501743_item	2455104	et	4	main
nimisõna	doc_491521501743_item	2455123	et	4	main
keele	doc_491521501743_item	2455134	et	4	main
õppimisel	doc_491521501743_item	2455135	et	4	main
so	doc_491521501743_item	2455144	et	4	main
nö	doc_491521501743_item	2455146	et	4	main
ninataga	doc_491521501743_item	2455147	et	4	main
käänded	doc_491521501743_item	2455148	et	3	main
mis	doc_491521501743_item	2455149	et	4	main
kohta	doc_491521501743_item	2455155	et	4	main
ja	doc_491521501743_item	2455164	et	3	main
elavad	doc_491521501743_item	2455166	et	4	main
mordvas	doc_491521501743_item	2455167	et	4	main
kohas	doc_491521501743_item	2455172	et	4	main
nad	doc_491521501743_item	2455173	et	3	main
aastat	doc_491521501743_item	2455176	et	3	main
lauljad	doc_491521501743_item	2455181	et	4	main
mul	doc_491521501743_item	2455182	et	3	main
ja	doc_491521501743_item	2455183	et	3	main
inimesel	doc_491521501743_item	2455185	et	3	main
tehtud	doc_491521501743_item	2454824	et	4	main
oli	doc_491521501743_item	2454851	et	3	main
esines	doc_491521501743_item	2454856	et	3	main
ersa	doc_491521501743_item	2454865	et	4	main
käändeid	doc_491521501743_item	2454868	et	3	main
kääne	doc_491521501743_item	2454877	et	3	main
osastava	doc_491521501743_item	2454884	et	4	main
moodustamine	doc_491521501743_item	2454886	et	4	main
vaatasid	doc_491521501743_item	2454887	et	4	main
häid	doc_491521501743_item	2454888	et	3	main
etenduseid	doc_491521501743_item	2454889	et	4	main
samas	doc_491521501743_item	2454890	et	4	main
võis	doc_491521501743_item	2454891	et	4	main
ka	doc_491521501743_item	2454892	et	3	main
tähele	doc_491521501743_item	2454893	et	3	main
panna	doc_491521501743_item	2454894	et	4	main
et	doc_491521501743_item	2454895	et	3	main
mitmuse	doc_491521501743_item	2454896	et	3	main
osastava	doc_491521501743_item	2454897	et	4	main
kasutamist	doc_491521501743_item	2454898	et	4	main
on	doc_491521501743_item	2454899	et	4	main
puutud	doc_491521501743_item	2454900	et	4	main
pigem	doc_491521501743_item	2454901	et	3	main
vältida	doc_491521501743_item	2454902	et	3	main
selle	doc_491521501743_item	2454904	et	4	main
oli	doc_491521501743_item	2454905	et	3	main
peale	doc_491521501743_item	2454903	et	4	main
mitmes	doc_491521501743_item	2454906	et	4	main
kohas	doc_491521501743_item	2454907	et	4	main
valesti	doc_491521501743_item	2454908	et	3	main
moodustatud	doc_491521501743_item	2454909	et	4	main
omastav	doc_491521501743_item	2454910	et	4	main
kääne	doc_491521501743_item	2454911	et	3	main
eriti	doc_491521501743_item	2454912	et	3	main
sõnades	doc_491521501743_item	2454913	et	4	main
kus	doc_491521501743_item	2454914	et	3	main
sõnalõpuline	doc_491521501743_item	2454915	et	4	main
ne	doc_491521501743_item	2454916	et	4	main
muutub	doc_491521501743_item	2454917	et	3	main
omastavas	doc_491521501743_item	2454918	et	4	main
se	doc_491521501743_item	2454919	et	4	main
nt	doc_491521501743_item	2454920	et	4	main
naine	doc_491521501743_item	2454921	et	3	main
on	doc_491521501743_item	2454923	et	4	main
omastava	doc_491521501743_item	2454938	et	4	main
keele	doc_491521501743_item	2454946	et	4	main
tütar	doc_491521501743_item	2454928	et	3	main
on	doc_491521501743_item	2454936	et	4	main
vokaali	doc_491521501743_item	2454940	et	4	main
valimine	doc_491521501743_item	2454941	et	4	main
näiteks	doc_491521501743_item	2454950	et	4	main
olid	doc_491521501743_item	2454951	et	4	main
järgmised	doc_491521501743_item	2454955	et	3	main
mitmes	doc_491521501743_item	2454964	et	4	main
valesti	doc_491521501743_item	2454967	et	3	main
keelest	doc_491521501743_item	2454976	et	4	main
ta	doc_491521501743_item	2454978	et	4	main
mängib	doc_491521501743_item	2454979	et	3	main
klaveriga	doc_491521501743_item	2454980	et	3	main
ta	doc_491521501743_item	2454981	et	4	main
on	doc_491521501743_item	2454982	et	4	main
oli	doc_491521501743_item	2454984	et	3	main
autojuhina	doc_491521501743_item	2454983	et	3	main
ka	doc_491521501743_item	2454985	et	3	main
sõnu	doc_491521501743_item	2454986	et	4	main
kus	doc_491521501743_item	2454987	et	3	main
sisekohakääne	doc_491521501743_item	2454989	et	3	main
näiteks	doc_491521501743_item	2454988	et	4	main
oli	doc_491521501743_item	2454990	et	3	main
valesti	doc_491521501743_item	2454991	et	3	main
moodustatud	doc_491521501743_item	2454992	et	4	main
nt	doc_491521501743_item	2454993	et	4	main
õhtul	doc_491521501743_item	2454994	et	3	main
pere	doc_491521501743_item	2454995	et	4	main
koguneb	doc_491521501743_item	2454996	et	3	main
peretubas	doc_491521501743_item	2454997	et	4	main
kohakäänete	doc_491521501743_item	2454998	et	3	main
vead	doc_491521501743_item	2454999	et	4	main
kohakäänete	doc_491521501743_item	2455000	et	3	main
vead	doc_491521501743_item	2455001	et	4	main
olid	doc_491521501743_item	2455002	et	4	main
suuremalt	doc_491521501743_item	2455003	et	4	main
jaolt	doc_491521501743_item	2455004	et	4	main
seotud	doc_491521501743_item	2455005	et	4	main
õppijatele	doc_491521501743_item	2454947	et	4	main
vigade	doc_491521501743_item	2454953	et	3	main
endale	doc_491521501743_item	2454957	et	4	main
kohas	doc_491521501743_item	2454965	et	4	main
põhjusteks	doc_491521501743_item	2454969	et	3	main
siin	doc_491521501743_item	2454971	et	4	main
vene	doc_491521501743_item	2454975	et	4	main
just	doc_491521501743_item	2455006	et	3	main
sellega	doc_491521501743_item	2455007	et	3	main
et	doc_491521501743_item	2455008	et	3	main
neid	doc_491521501743_item	2455009	et	4	main
oli	doc_491521501743_item	2455010	et	3	main
vales	doc_491521501743_item	2455011	et	3	main
kohas	doc_491521501743_item	2455012	et	4	main
ka	doc_491521501743_item	2455022	et	3	main
käändelõpp	doc_491521501743_item	2455025	et	4	main
lisatud	doc_491521501743_item	2455029	et	4	main
kasutuskoht	doc_491521501743_item	2455031	et	3	main
valitud	doc_491521501743_item	2455034	et	4	main
sisekohakäänete	doc_491521501743_item	2455035	et	3	main
kartulid	doc_491521501743_item	2455044	et	3	main
turul	doc_491521501743_item	2455057	et	3	main
tehtud	doc_491521501743_item	2455068	et	4	main
oli	doc_491521501743_item	2455078	et	3	main
käima	doc_491521501743_item	2455087	et	4	main
kuhu	doc_491521501743_item	2455090	et	3	main
võrdlemisi	doc_491521501743_item	2455095	et	4	main
kas	doc_491521501743_item	2455100	et	3	main
ära	doc_491521501743_item	2455121	et	4	main
laiendav	doc_491521501743_item	2455124	et	4	main
omadussõna	doc_491521501743_item	2455125	et	4	main
on	doc_491521501743_item	2455133	et	4	main
tehakse	doc_491521501743_item	2455141	et	3	main
vastupidi	doc_491521501743_item	2455143	et	3	main
ühildatakse	doc_491521501743_item	2455145	et	3	main
ühildu	doc_491521501743_item	2455152	et	4	main
näited	doc_491521501743_item	2455153	et	3	main
ühildumisvigade	doc_491521501743_item	2455154	et	4	main
palju	doc_491521501743_item	2455162	et	4	main
lauad	doc_491521501743_item	2455163	et	3	main
ilusa	doc_491521501743_item	2455171	et	3	main
on	doc_491521501743_item	2455174	et	4	main
oma	doc_491521501743_item	2455187	et	4	main
puhul	doc_491521501743_item	2455226	et	4	main
käändsõna	doc_491521501743_item	2455228	et	4	main
kääne	doc_491521501743_item	2455229	et	3	main
sõna	doc_491521501743_item	2455230	et	4	main
leksikaalsest	doc_491521501743_item	2455231	et	3	main
siin	doc_491521501743_item	2455241	et	4	main
vigu	doc_491521501743_item	2455242	et	3	main
tehakse	doc_491521501743_item	2455243	et	3	main
sest	doc_491521501743_item	2455244	et	4	main
kuulama	doc_491521501743_item	2455257	et	3	main
kus	doc_491521501743_item	2455262	et	3	main
mida	doc_491521501743_item	2455271	et	4	main
ema	doc_491521501743_item	2455272	et	4	main
jooma	doc_491521501743_item	2455281	et	4	main
sõitma	doc_491521501743_item	2455289	et	3	main
teadma	doc_491521501743_item	2455297	et	3	main
ja	doc_491521501743_item	2455306	et	3	main
mida	doc_491521501743_item	2455331	et	4	main
vead	doc_491521501743_item	2455343	et	4	main
väga	doc_491521501743_item	2455348	et	3	main
lapsepõlves	doc_491521501743_item	2455362	et	4	main
tahaksin	doc_491521501743_item	2455363	et	3	main
olla	doc_491521501743_item	2455364	et	3	main
esimesel	doc_491521501743_item	2455369	et	3	main
tahetud	doc_491521501743_item	2455373	et	4	main
kasutada	doc_491521501743_item	2455374	et	3	main
lihtminevikku	doc_491521501743_item	2455375	et	4	main
kõneviisi	doc_491521501743_item	2455381	et	4	main
järelduse	doc_491521501743_item	2455383	et	4	main
võis	doc_491521501743_item	2455384	et	4	main
teha	doc_491521501743_item	2455385	et	3	main
lugedes	doc_491521501743_item	2455386	et	3	main
konkreetset	doc_491521501743_item	2455387	et	3	main
kirjandit	doc_491521501743_item	2455388	et	3	main
arusaamatu	doc_491521501743_item	2455433	et	4	main
sõna	doc_491521501743_item	2455437	et	4	main
vales	doc_491521501743_item	2455439	et	3	main
vt	doc_491521501743_item	2455441	et	4	main
keelest	doc_491521501743_item	2455024	et	4	main
õigesti	doc_491521501743_item	2455028	et	3	main
valesti	doc_491521501743_item	2455033	et	3	main
vead	doc_491521501743_item	2455036	et	4	main
atmosfääris	doc_491521501743_item	2455040	et	3	main
sõidan	doc_491521501743_item	2455056	et	3	main
ei	doc_491521501743_item	2455070	et	4	main
sest	doc_491521501743_item	2455076	et	4	main
valitud	doc_491521501743_item	2455079	et	4	main
vale	doc_491521501743_item	2455080	et	4	main
kääne	doc_491521501743_item	2455081	et	3	main
mida	doc_491521501743_item	2455086	et	4	main
kus	doc_491521501743_item	2455088	et	3	main
töödes	doc_491521501743_item	2455094	et	3	main
on	doc_491521501743_item	2455103	et	4	main
teised	doc_491521501743_item	2455105	et	4	main
keeled	doc_491521501743_item	2455106	et	3	main
sest	doc_491521501743_item	2455107	et	4	main
ühildumine	doc_491521501743_item	2455108	et	4	main
on	doc_491521501743_item	2455109	et	4	main
eesti	doc_491521501743_item	2455110	et	4	main
keele	doc_491521501743_item	2455111	et	4	main
õppijatele	doc_491521501743_item	2455112	et	4	main
alati	doc_491521501743_item	2455113	et	4	main
raskusi	doc_491521501743_item	2455114	et	4	main
valmistanud	doc_491521501743_item	2455115	et	4	main
emakeelest	doc_491521501743_item	2455116	et	4	main
hoolimata	doc_491521501743_item	2455117	et	4	main
tihti	doc_491521501743_item	2455118	et	3	main
unustatakse	doc_491521501743_item	2455119	et	3	main
lihtsalt	doc_491521501743_item	2455120	et	4	main
et	doc_491521501743_item	2455122	et	3	main
see	doc_491521501743_item	2455132	et	3	main
viga	doc_491521501743_item	2455139	et	4	main
vigu	doc_491521501743_item	2455142	et	3	main
teatreid	doc_491521501743_item	2455160	et	3	main
külas	doc_491521501743_item	2455169	et	3	main
vana	doc_491521501743_item	2455177	et	4	main
mulle	doc_491521501743_item	2455178	et	4	main
on	doc_491521501743_item	2455186	et	4	main
suurema	doc_491521501743_item	2455221	et	4	main
rektsiooni	doc_491521501743_item	2455225	et	4	main
tähendusest	doc_491521501743_item	2455232	et	4	main
rektsioon	doc_491521501743_item	2455245	et	3	main
on	doc_491521501743_item	2455246	et	4	main
sageli	doc_491521501743_item	2455247	et	3	main
komistuskiviks	doc_491521501743_item	2455248	et	3	main
ka	doc_491521501743_item	2455249	et	3	main
näited	doc_491521501743_item	2455251	et	3	main
restoranisse	doc_491521501743_item	2455260	et	3	main
mida	doc_491521501743_item	2455266	et	4	main
ettekandja	doc_491521501743_item	2455267	et	4	main
kannab	doc_491521501743_item	2455268	et	3	main
toit	doc_491521501743_item	2455269	et	3	main
kandma	doc_491521501743_item	2455270	et	3	main
oma	doc_491521501743_item	2455274	et	4	main
mida	doc_491521501743_item	2455282	et	4	main
kuulavad	doc_491521501743_item	2455283	et	4	main
tean	doc_491521501743_item	2455292	et	3	main
seitse	doc_491521501743_item	2455295	et	3	main
muusika	doc_491521501743_item	2455305	et	4	main
müüma	doc_491521501743_item	2455321	et	3	main
seened-korjama	doc_491521501743_item	2455330	et	3	main
verbivormi	doc_491521501743_item	2455344	et	4	main
on	doc_491521501743_item	2455351	et	4	main
olin	doc_491521501743_item	2455367	et	3	main
oli	doc_491521501743_item	2455371	et	3	main
ekslikult	doc_491521501743_item	2455377	et	4	main
nt	doc_491521501743_item	2455037	et	4	main
restoranisse	doc_491521501743_item	2455042	et	3	main
vanemad	doc_491521501743_item	2455048	et	4	main
vead	doc_491521501743_item	2455052	et	4	main
nendel	doc_491521501743_item	2455058	et	4	main
meeldib	doc_491521501743_item	2455060	et	3	main
kasutamise	doc_491521501743_item	2455062	et	4	main
vead	doc_491521501743_item	2455069	et	4	main
sobiks	doc_491521501743_item	2455071	et	4	main
teisalt	doc_491521501743_item	2455072	et	4	main
ka	doc_491521501743_item	2455073	et	3	main
ühildumisvigu	doc_491521501743_item	2455092	et	4	main
palju	doc_491521501743_item	2455096	et	4	main
oska	doc_491521501743_item	2455098	et	4	main
öelda	doc_491521501743_item	2455099	et	4	main
nt	doc_491521501743_item	2455053	et	4	main
turul	doc_491521501743_item	2455055	et	3	main
väga	doc_491521501743_item	2455059	et	3	main
kohakäänete	doc_491521501743_item	2455061	et	3	main
puhul	doc_491521501743_item	2455063	et	4	main
tekkis	doc_491521501743_item	2455064	et	3	main
küsimus	doc_491521501743_item	2455065	et	4	main
et	doc_491521501743_item	2455066	et	3	main
kas	doc_491521501743_item	2455067	et	3	main
alla	doc_491521501743_item	2455075	et	3	main
põhjale	doc_491521501743_item	2455077	et	3	main
nautima	doc_491521501743_item	2455085	et	3	main
sõitma	doc_491521501743_item	2455089	et	3	main
neid	doc_491521501743_item	2455101	et	4	main
on	doc_491521501743_item	2455126	et	4	main
tehtav	doc_491521501743_item	2455136	et	4	main
täiesti	doc_491521501743_item	2455137	et	3	main
samamoodi	doc_491521501743_item	2455140	et	3	main
tegelikult	doc_491521501743_item	2455150	et	4	main
mulle	doc_491521501743_item	2455156	et	4	main
ka	doc_491521501743_item	2455157	et	3	main
on	doc_491521501743_item	2455161	et	4	main
toolid	doc_491521501743_item	2455165	et	3	main
palju	doc_491521501743_item	2455180	et	4	main
osa	doc_491521501743_item	2455222	et	4	main
leitud	doc_491521501743_item	2455223	et	4	main
vigadest	doc_491521501743_item	2455224	et	3	main
nt	doc_491521501743_item	2455233	et	4	main
heitma	doc_491521501743_item	2455234	et	3	main
kuhu	doc_491521501743_item	2455235	et	3	main
pole	doc_491521501743_item	2455238	et	3	main
üllatus	doc_491521501743_item	2455239	et	4	main
et	doc_491521501743_item	2455240	et	3	main
käivad	doc_491521501743_item	2455259	et	4	main
tellima	doc_491521501743_item	2455265	et	3	main
keda	doc_491521501743_item	2455277	et	4	main
joob	doc_491521501743_item	2455279	et	3	main
tee	doc_491521501743_item	2455280	et	4	main
tema	doc_491521501743_item	2455293	et	4	main
keda	doc_491521501743_item	2455298	et	4	main
meelsasti	doc_491521501743_item	2455301	et	3	main
müüdi	doc_491521501743_item	2455323	et	4	main
müüma	doc_491521501743_item	2455325	et	3	main
korjasid	doc_491521501743_item	2455327	et	4	main
ilmselt	doc_491521501743_item	2455350	et	4	main
lihtsamini	doc_491521501743_item	2455354	et	4	main
õpitavaid	doc_491521501743_item	2455355	et	4	main
asju	doc_491521501743_item	2455356	et	3	main
sõjaväelaseks	doc_491521501743_item	2455365	et	3	main
sündinud	doc_491521501743_item	2455368	et	4	main
juhul	doc_491521501743_item	2455370	et	3	main
ilmselt	doc_491521501743_item	2455372	et	4	main
kasutatus	doc_491521501743_item	2455379	et	4	main
probleemiks	doc_491521501743_item	2455422	et	4	main
olevat	doc_491521501743_item	2455424	et	4	main
sõnajärg	doc_491521501743_item	2455425	et	3	main
sageli	doc_491521501743_item	2455426	et	3	main
lause	doc_491521501743_item	2455428	et	4	main
sisu	doc_491521501743_item	2455429	et	4	main
selle	doc_491521501743_item	2455430	et	4	main
samuti	doc_491521501743_item	2455434	et	3	main
paigutasin	doc_491521501743_item	2455448	et	3	main
sest	doc_491521501743_item	2455451	et	4	main
kasutamine	doc_491521501743_item	2455458	et	4	main
mida	doc_491521501743_item	2455459	et	4	main
erinevaid	doc_491521501743_item	2455466	et	4	main
naited	doc_491521501743_item	2455469	et	4	main
huvitada	doc_491521501743_item	2455471	et	3	main
täiskasvanuid	doc_491521501743_item	2455473	et	3	main
lapsi	doc_491521501743_item	2455475	et	4	main
tantsivad	doc_491521501743_item	2455479	et	4	main
näitlejad	doc_491521501743_item	2455480	et	4	main
meie	doc_491521501743_item	2455481	et	4	main
etendused	doc_491521501743_item	2455484	et	4	main
midagi	doc_491521501743_item	2455491	et	4	main
enda	doc_491521501743_item	2455493	et	4	main
jaoks	doc_491521501743_item	2455494	et	4	main
pärast	doc_491521501743_item	2455499	et	4	main
ostan	doc_491521501743_item	2455500	et	3	main
kingid	doc_491521501743_item	2455501	et	4	main
näha	doc_491521501743_item	2455506	et	3	main
nimisõnaga	doc_491521501743_item	2455127	et	3	main
samas	doc_491521501743_item	2455128	et	4	main
käändes	doc_491521501743_item	2455129	et	3	main
ja	doc_491521501743_item	2455130	et	3	main
arvus	doc_491521501743_item	2455131	et	3	main
tavaline	doc_491521501743_item	2455138	et	4	main
ei	doc_491521501743_item	2455151	et	4	main
väga	doc_491521501743_item	2455158	et	3	main
meeldib	doc_491521501743_item	2455159	et	3	main
väike	doc_491521501743_item	2455168	et	4	main
asub	doc_491521501743_item	2455170	et	3	main
15	doc_491521501743_item	2455175	et	2	main
meeldivad	doc_491521501743_item	2455179	et	4	main
iga	doc_491521501743_item	2455184	et	4	main
elutee	doc_491521501743_item	2455188	et	4	main
selle	doc_491521501743_item	2455189	et	4	main
ajal	doc_491521501743_item	2455190	et	4	main
huvitasin	doc_491521501743_item	2455191	et	3	main
ka	doc_491521501743_item	2455192	et	3	main
kirjandusest	doc_491521501743_item	2455193	et	4	main
sai	doc_491521501743_item	2455194	et	4	main
kaheteistkümneks	doc_491521501743_item	2455195	et	4	main
aastaseks	doc_491521501743_item	2455196	et	4	main
tehtud	doc_491521501743_item	2455197	et	4	main
vead	doc_491521501743_item	2455198	et	4	main
on	doc_491521501743_item	2455199	et	4	main
väga	doc_491521501743_item	2455200	et	3	main
tüüpilised	doc_491521501743_item	2455201	et	3	main
ja	doc_491521501743_item	2455202	et	3	main
nende	doc_491521501743_item	2455203	et	4	main
vältimiseks	doc_491521501743_item	2455204	et	4	main
oleks	doc_491521501743_item	2455205	et	3	main
vaja	doc_491521501743_item	2455206	et	4	main
oma	doc_491521501743_item	2455207	et	4	main
keelekasutust	doc_491521501743_item	2455208	et	4	main
väga	doc_491521501743_item	2455209	et	3	main
hoolikalt	doc_491521501743_item	2455210	et	4	main
jälgida	doc_491521501743_item	2455211	et	3	main
ja	doc_491521501743_item	2455212	et	3	main
tähele	doc_491521501743_item	2455213	et	3	main
panna	doc_491521501743_item	2455214	et	4	main
et	doc_491521501743_item	2455215	et	3	main
ühildumist	doc_491521501743_item	2455216	et	4	main
kasutataks	doc_491521501743_item	2455217	et	3	main
rektsioonivead	doc_491521501743_item	2455218	et	4	main
rektsioonivead	doc_491521501743_item	2455219	et	4	main
moodustasid	doc_491521501743_item	2455220	et	4	main
oleneb	doc_491521501743_item	2455227	et	3	main
osalema	doc_491521501743_item	2455236	et	3	main
emakeelekõnelejatele	doc_491521501743_item	2455250	et	3	main
mida	doc_491521501743_item	2455258	et	4	main
käima	doc_491521501743_item	2455261	et	4	main
tellib	doc_491521501743_item	2455263	et	3	main
toit	doc_491521501743_item	2455264	et	3	main
toidab	doc_491521501743_item	2455273	et	3	main
toitma	doc_491521501743_item	2455276	et	3	main
pere	doc_491521501743_item	2455278	et	4	main
muusika	doc_491521501743_item	2455284	et	4	main
kuulama	doc_491521501743_item	2455285	et	3	main
mida	doc_491521501743_item	2455286	et	4	main
sõidan	doc_491521501743_item	2455287	et	3	main
turul	doc_491521501743_item	2455288	et	3	main
kuhu	doc_491521501743_item	2455290	et	3	main
ma	doc_491521501743_item	2455300	et	3	main
kuulan	doc_491521501743_item	2455302	et	3	main
rahvalik	doc_491521501743_item	2455307	et	3	main
muusika	doc_491521501743_item	2455308	et	4	main
kuulama	doc_491521501743_item	2455309	et	3	main
mida	doc_491521501743_item	2455310	et	4	main
ei	doc_491521501743_item	2455311	et	4	main
armasta	doc_491521501743_item	2455312	et	4	main
rokk	doc_491521501743_item	2455313	et	3	main
muusika	doc_491521501743_item	2455314	et	4	main
armastama	doc_491521501743_item	2455315	et	3	main
keda	doc_491521501743_item	2455316	et	4	main
mida	doc_491521501743_item	2455317	et	4	main
müüdi	doc_491521501743_item	2455318	et	4	main
erinevad	doc_491521501743_item	2455319	et	4	main
lilled	doc_491521501743_item	2455320	et	3	main
erinevad	doc_491521501743_item	2455328	et	4	main
marjad	doc_491521501743_item	2455329	et	3	main
tehti	doc_491521501743_item	2455346	et	3	main
vähe	doc_491521501743_item	2455349	et	3	main
üks	doc_491521501743_item	2455353	et	3	main
grammatikas	doc_491521501743_item	2455357	et	3	main
töödest	doc_491521501743_item	2455358	et	3	main
leidsin	doc_491521501743_item	2455359	et	3	main
kaks	doc_491521501743_item	2455360	et	3	main
viga	doc_491521501743_item	2455361	et	4	main
ma	doc_491521501743_item	2455366	et	3	main
kuid	doc_491521501743_item	2455376	et	4	main
tingivat	doc_491521501743_item	2455380	et	4	main
sellise	doc_491521501743_item	2455382	et	4	main
kus	doc_491521501743_item	2455237	et	3	main
leitud	doc_491521501743_item	2455252	et	4	main
vigadest	doc_491521501743_item	2455253	et	3	main
kuulavad	doc_491521501743_item	2455254	et	4	main
ilusad	doc_491521501743_item	2455255	et	3	main
laulud	doc_491521501743_item	2455256	et	3	main
tütar	doc_491521501743_item	2455275	et	3	main
ma	doc_491521501743_item	2455291	et	3	main
juba	doc_491521501743_item	2455294	et	3	main
aastat	doc_491521501743_item	2455296	et	3	main
mida	doc_491521501743_item	2455299	et	4	main
estraadimuusika	doc_491521501743_item	2455303	et	4	main
klassikaline	doc_491521501743_item	2455304	et	4	main
mida	doc_491521501743_item	2455322	et	4	main
kommid	doc_491521501743_item	2455324	et	3	main
mida	doc_491521501743_item	2455326	et	4	main
metsale	doc_491521501743_item	2455332	et	4	main
viiv	doc_491521501743_item	2455333	et	4	main
tee	doc_491521501743_item	2455334	et	4	main
oli	doc_491521501743_item	2455335	et	3	main
kuiv	doc_491521501743_item	2455336	et	3	main
ja	doc_491521501743_item	2455337	et	3	main
lai	doc_491521501743_item	2455338	et	3	main
viima	doc_491521501743_item	2455339	et	3	main
kuhu	doc_491521501743_item	2455340	et	3	main
verbivormide	doc_491521501743_item	2455341	et	4	main
valiku	doc_491521501743_item	2455342	et	3	main
kasutamisel	doc_491521501743_item	2455345	et	4	main
vigu	doc_491521501743_item	2455347	et	3	main
see	doc_491521501743_item	2455352	et	3	main
kus	doc_491521501743_item	2455389	et	3	main
see	doc_491521501743_item	2455390	et	3	main
kontekstist	doc_491521501743_item	2455391	et	3	main
välja	doc_491521501743_item	2455392	et	4	main
tuli	doc_491521501743_item	2455393	et	4	main
teisel	doc_491521501743_item	2455394	et	4	main
juhul	doc_491521501743_item	2455395	et	3	main
on	doc_491521501743_item	2455396	et	4	main
täismineviku	doc_491521501743_item	2455397	et	3	main
asemel	doc_491521501743_item	2455398	et	4	main
kasutatud	doc_491521501743_item	2455399	et	4	main
enneminevikku	doc_491521501743_item	2455400	et	4	main
kuid	doc_491521501743_item	2455401	et	4	main
eesti	doc_491521501743_item	2455402	et	4	main
keeles	doc_491521501743_item	2455403	et	4	main
öeldakse	doc_491521501743_item	2455404	et	3	main
ma	doc_491521501743_item	2455405	et	3	main
olen	doc_491521501743_item	2455406	et	3	main
sündinud	doc_491521501743_item	2455407	et	4	main
sõnatasandi	doc_491521501743_item	2455408	et	3	main
sõnatasandil	doc_491521501743_item	2455410	et	3	main
tehti	doc_491521501743_item	2455411	et	3	main
ka	doc_491521501743_item	2455412	et	3	main
suhteliselt	doc_491521501743_item	2455413	et	4	main
vead	doc_491521501743_item	2455409	et	4	main
palju	doc_491521501743_item	2455414	et	4	main
vigu	doc_491521501743_item	2455415	et	3	main
vead	doc_491521501743_item	2455416	et	4	main
siin	doc_491521501743_item	2455417	et	4	main
olid	doc_491521501743_item	2455418	et	4	main
erinevad	doc_491521501743_item	2455419	et	4	main
kõige	doc_491521501743_item	2455420	et	4	main
oli	doc_491521501743_item	2455435	et	3	main
on	doc_491521501743_item	2455378	et	4	main
suuremaks	doc_491521501743_item	2455421	et	4	main
tundub	doc_491521501743_item	2455423	et	3	main
tõttu	doc_491521501743_item	2455431	et	4	main
kasutatud	doc_491521501743_item	2455438	et	4	main
gruppi	doc_491521501743_item	2455450	et	4	main
ei	doc_491521501743_item	2455453	et	4	main
olnud	doc_491521501743_item	2455454	et	4	main
sõna	doc_491521501743_item	2455456	et	4	main
pikemad	doc_491521501743_item	2455460	et	4	main
olid	doc_491521501743_item	2455461	et	4	main
laused	doc_491521501743_item	2455462	et	3	main
seda	doc_491521501743_item	2455463	et	3	main
vigu	doc_491521501743_item	2455467	et	3	main
nii	doc_491521501743_item	2455474	et	3	main
jaoks	doc_491521501743_item	2455482	et	4	main
huvitavad	doc_491521501743_item	2455486	et	4	main
avame	doc_491521501743_item	2455490	et	3	main
ainult	doc_491521501743_item	2455498	et	4	main
suurenes	doc_491521501743_item	2455508	et	4	main
elanikuarv	doc_491521501743_item	2455509	et	4	main
minu	doc_491521501743_item	2455510	et	3	main
juhul	doc_491521501743_item	2455516	et	3	main
oli	doc_491521501743_item	2455427	et	3	main
peaaegu	doc_491521501743_item	2455432	et	3	main
mingit	doc_491521501743_item	2455436	et	3	main
kontekstis	doc_491521501743_item	2455440	et	3	main
alles	doc_491521501743_item	2455444	et	3	main
näide	doc_491521501743_item	2455442	et	3	main
ainult	doc_491521501743_item	2455443	et	4	main
ka	doc_491521501743_item	2455445	et	3	main
ainukese	doc_491521501743_item	2455446	et	4	main
asesõnavea	doc_491521501743_item	2455447	et	3	main
see	doc_491521501743_item	2455452	et	3	main
vale	doc_491521501743_item	2455457	et	4	main
rohkem	doc_491521501743_item	2455464	et	4	main
kõik	doc_491521501743_item	2455483	et	4	main
ilusad	doc_491521501743_item	2455487	et	3	main
hea	doc_491521501743_item	2455504	et	4	main
on	doc_491521501743_item	2455505	et	4	main
kui	doc_491521501743_item	2455507	et	3	main
on	doc_491521501743_item	2455514	et	4	main
esimesel	doc_491521501743_item	2455515	et	3	main
õige	doc_491521501743_item	2455522	et	4	main
öelda	doc_491521501743_item	2455524	et	4	main
võib	doc_491521501743_item	2455525	et	3	main
juhul	doc_491521501743_item	2455533	et	3	main
vale	doc_491521501743_item	2455535	et	4	main
kolmandal	doc_491521501743_item	2455537	et	3	main
põhjuseks	doc_491521501743_item	2455545	et	3	main
hääldus	doc_491521501743_item	2455552	et	4	main
on	doc_491521501743_item	2455554	et	4	main
kaunitar	doc_491521501743_item	2455555	et	3	main
on	doc_491521501743_item	2455556	et	4	main
kuulnud	doc_491521501743_item	2455562	et	4	main
venelasi	doc_491521501743_item	2455563	et	3	main
seda	doc_491521501743_item	2455564	et	3	main
jaoks	doc_491521501743_item	2455568	et	4	main
täiesti	doc_491521501743_item	2455570	et	3	main
nii	doc_491521501743_item	2455572	et	3	main
öelda	doc_491521501743_item	2455573	et	4	main
eestlane	doc_491521501743_item	2455574	et	3	main
ütleks	doc_491521501743_item	2455575	et	3	main
siin	doc_491521501743_item	2455615	et	4	main
kuidas	doc_491521501743_item	2455620	et	3	main
vea	doc_491521501743_item	2455624	et	4	main
võib	doc_491521501743_item	2455627	et	3	main
minu	doc_491521501743_item	2455635	et	3	main
komistuskiviks	doc_491521501743_item	2455644	et	3	main
moodustamine	doc_491521501743_item	2455677	et	4	main
huvitavad	doc_491521501743_item	2455706	et	4	main
lapsi	doc_491521501743_item	2455712	et	4	main
tantsivad	doc_491521501743_item	2455719	et	4	main
siia	doc_491521501743_item	2455449	et	4	main
tehtud	doc_491521501743_item	2455468	et	4	main
kui	doc_491521501743_item	2455472	et	3	main
vaatavad	doc_491521501743_item	2455476	et	4	main
mängivad	doc_491521501743_item	2455478	et	4	main
ja	doc_491521501743_item	2455488	et	3	main
uut	doc_491521501743_item	2455492	et	3	main
õde	doc_491521501743_item	2455495	et	4	main
siin	doc_491521501743_item	2455502	et	4	main
väga	doc_491521501743_item	2455503	et	3	main
jaoks	doc_491521501743_item	2455511	et	4	main
järjekord	doc_491521501743_item	2455519	et	3	main
segamini	doc_491521501743_item	2455520	et	4	main
aetud	doc_491521501743_item	2455521	et	4	main
on	doc_491521501743_item	2455523	et	4	main
teisel	doc_491521501743_item	2455532	et	4	main
sõnajärg	doc_491521501743_item	2455536	et	3	main
juhul	doc_491521501743_item	2455538	et	3	main
ilmselt	doc_491521501743_item	2455546	et	4	main
sõnade	doc_491521501743_item	2455547	et	3	main
ortograafiline	doc_491521501743_item	2455548	et	4	main
õde	doc_491521501743_item	2455553	et	4	main
ja	doc_491521501743_item	2455566	et	3	main
õde	doc_491521501743_item	2455577	et	4	main
hea	doc_491521501743_item	2455618	et	4	main
elanike	doc_491521501743_item	2455622	et	3	main
oma	doc_491521501743_item	2455638	et	4	main
pronoomenite	doc_491521501743_item	2455639	et	3	main
lühidalt	doc_491521501743_item	2455647	et	4	main
vigu	doc_491521501743_item	2455654	et	3	main
tegemine	doc_491521501743_item	2455658	et	4	main
paljuski	doc_491521501743_item	2455660	et	4	main
emakeelemõjutustest	doc_491521501743_item	2455661	et	4	main
oluline	doc_491521501743_item	2455665	et	4	main
valmistab	doc_491521501743_item	2455670	et	3	main
teisele	doc_491521501743_item	2455673	et	4	main
kui	doc_491521501743_item	2455709	et	3	main
nii	doc_491521501743_item	2455711	et	3	main
kuulavad	doc_491521501743_item	2455713	et	4	main
ilusad	doc_491521501743_item	2455714	et	3	main
laulud	doc_491521501743_item	2455715	et	3	main
vaatavad	doc_491521501743_item	2455716	et	4	main
kuidas	doc_491521501743_item	2455717	et	3	main
on	doc_491521501743_item	2455724	et	4	main
ja	doc_491521501743_item	2455727	et	3	main
avame	doc_491521501743_item	2455729	et	3	main
uut	doc_491521501743_item	2455731	et	3	main
enda	doc_491521501743_item	2455732	et	4	main
jaoks	doc_491521501743_item	2455733	et	4	main
kuulavad	doc_491521501743_item	2455744	et	4	main
saksamaas	doc_491521501743_item	2455779	et	3	main
põrandal	doc_491521501743_item	2455795	et	3	main
on	doc_491521501743_item	2455796	et	4	main
jana	doc_491521501743_item	2455800	et	4	main
lai	doc_491521501743_item	2455811	et	3	main
õppisin	doc_491521501743_item	2455818	et	3	main
ta	doc_491521501743_item	2455820	et	4	main
noorem	doc_491521501743_item	2455824	et	4	main
pärast	doc_491521501743_item	2455835	et	4	main
vana	doc_491521501743_item	2455848	et	4	main
klassikaline	doc_491521501743_item	2455853	et	4	main
rahvalik	doc_491521501743_item	2455856	et	3	main
muusika	doc_491521501743_item	2455857	et	4	main
ei	doc_491521501743_item	2455862	et	4	main
meeldis	doc_491521501743_item	2455875	et	3	main
muinasjutul	doc_491521501743_item	2455882	et	3	main
selle	doc_491521501743_item	2455921	et	4	main
huvitasin	doc_491521501743_item	2455923	et	3	main
kaheteistkümneks	doc_491521501743_item	2455930	et	4	main
meile	doc_491521501743_item	2455934	et	4	main
ärge	doc_491521501743_item	2455936	et	3	main
jätkuv	doc_491521501743_item	2455455	et	4	main
oli	doc_491521501743_item	2455465	et	3	main
võib	doc_491521501743_item	2455470	et	3	main
kuidas	doc_491521501743_item	2455477	et	3	main
on	doc_491521501743_item	2455485	et	4	main
me	doc_491521501743_item	2455489	et	4	main
on	doc_491521501743_item	2455496	et	4	main
kaunitar	doc_491521501743_item	2455497	et	3	main
oma	doc_491521501743_item	2455512	et	4	main
on	doc_491521501743_item	2455517	et	4	main
huvitada	doc_491521501743_item	2455526	et	3	main
nii	doc_491521501743_item	2455527	et	3	main
kui	doc_491521501743_item	2455529	et	3	main
lapsi	doc_491521501743_item	2455531	et	4	main
on	doc_491521501743_item	2455539	et	4	main
sõna	doc_491521501743_item	2455540	et	4	main
avastame	doc_491521501743_item	2455541	et	3	main
ka	doc_491521501743_item	2455551	et	3	main
keelest	doc_491521501743_item	2455560	et	4	main
olen	doc_491521501743_item	2455561	et	3	main
on	doc_491521501743_item	2455569	et	4	main
on	doc_491521501743_item	2455578	et	4	main
ilus	doc_491521501743_item	2455579	et	4	main
on	doc_491521501743_item	2455616	et	4	main
väga	doc_491521501743_item	2455617	et	3	main
elutee	doc_491521501743_item	2455513	et	4	main
sõnade	doc_491521501743_item	2455518	et	3	main
on	doc_491521501743_item	2455534	et	4	main
asemel	doc_491521501743_item	2455542	et	4	main
sarnasus	doc_491521501743_item	2455549	et	4	main
ilmne	doc_491521501743_item	2455557	et	4	main
mõju	doc_491521501743_item	2455558	et	4	main
vene	doc_491521501743_item	2455559	et	4	main
kasutavat	doc_491521501743_item	2455565	et	4	main
nende	doc_491521501743_item	2455567	et	4	main
tavaline	doc_491521501743_item	2455571	et	4	main
suurenes	doc_491521501743_item	2455621	et	4	main
on	doc_491521501743_item	2455634	et	4	main
asemel	doc_491521501743_item	2455636	et	4	main
kasutatud	doc_491521501743_item	2455637	et	4	main
olnud	doc_491521501743_item	2455645	et	4	main
kokkuvote	doc_491521501743_item	2455646	et	4	main
oli	doc_491521501743_item	2455653	et	3	main
määral	doc_491521501743_item	2455656	et	3	main
sõltub	doc_491521501743_item	2455659	et	3	main
kuid	doc_491521501743_item	2455662	et	4	main
samuti	doc_491521501743_item	2455663	et	3	main
inimene	doc_491521501743_item	2455667	et	3	main
eraldi	doc_491521501743_item	2455668	et	4	main
sõnajärg	doc_491521501743_item	2455672	et	3	main
on	doc_491521501743_item	2455674	et	4	main
probleemne	doc_491521501743_item	2455675	et	3	main
käänete	doc_491521501743_item	2455676	et	3	main
huvitada	doc_491521501743_item	2455708	et	3	main
täiskasvanuid	doc_491521501743_item	2455710	et	3	main
meie	doc_491521501743_item	2455720	et	4	main
jaoks	doc_491521501743_item	2455721	et	4	main
ilusad	doc_491521501743_item	2455726	et	3	main
me	doc_491521501743_item	2455728	et	4	main
häid	doc_491521501743_item	2455740	et	3	main
käivad	doc_491521501743_item	2455742	et	4	main
on	doc_491521501743_item	2455746	et	4	main
palju	doc_491521501743_item	2455747	et	4	main
lauad	doc_491521501743_item	2455748	et	3	main
ja	doc_491521501743_item	2455749	et	3	main
toolid	doc_491521501743_item	2455750	et	3	main
ema	doc_491521501743_item	2455751	et	4	main
toidab	doc_491521501743_item	2455752	et	3	main
oma	doc_491521501743_item	2455753	et	4	main
tütar	doc_491521501743_item	2455754	et	3	main
on	doc_491521501743_item	2455757	et	4	main
elavad	doc_491521501743_item	2455778	et	4	main
tubas	doc_491521501743_item	2455790	et	4	main
on	doc_491521501743_item	2455791	et	4	main
klaver	doc_491521501743_item	2455792	et	3	main
klaver	doc_491521501743_item	2455793	et	3	main
kõrval	doc_491521501743_item	2455794	et	4	main
klaveriga	doc_491521501743_item	2455802	et	3	main
asub	doc_491521501743_item	2455815	et	3	main
kohas	doc_491521501743_item	2455817	et	4	main
on	doc_491521501743_item	2455821	et	4	main
irina	doc_491521501743_item	2455828	et	3	main
kingid	doc_491521501743_item	2455837	et	4	main
ma	doc_491521501743_item	2455838	et	3	main
tean	doc_491521501743_item	2455839	et	3	main
tema	doc_491521501743_item	2455840	et	4	main
juba	doc_491521501743_item	2455841	et	3	main
seitse	doc_491521501743_item	2455842	et	3	main
aastat	doc_491521501743_item	2455843	et	3	main
meelsasti	doc_491521501743_item	2455850	et	3	main
meeldivad	doc_491521501743_item	2455859	et	4	main
palju	doc_491521501743_item	2455860	et	4	main
muusika	doc_491521501743_item	2455865	et	4	main
ostsid	doc_491521501743_item	2455869	et	4	main
roosikimbi	doc_491521501743_item	2455871	et	3	main
kommid	doc_491521501743_item	2455873	et	3	main
kirjaid	doc_491521501743_item	2455938	et	4	main
valmis	doc_491521501743_item	2455939	et	4	main
tee	doc_491521501743_item	2455942	et	4	main
lai	doc_491521501743_item	2455946	et	3	main
täiskasvanuid	doc_491521501743_item	2455528	et	3	main
ka	doc_491521501743_item	2455530	et	3	main
kasutatud	doc_491521501743_item	2455543	et	4	main
avame	doc_491521501743_item	2455544	et	3	main
ja	doc_491521501743_item	2455550	et	3	main
pigem	doc_491521501743_item	2455576	et	3	main
teatud	doc_491521501743_item	2455580	et	4	main
olukorras	doc_491521501743_item	2455581	et	3	main
võib	doc_491521501743_item	2455582	et	3	main
kaunitar	doc_491521501743_item	2455583	et	3	main
olla	doc_491521501743_item	2455584	et	3	main
isegi	doc_491521501743_item	2455585	et	4	main
negatiivse	doc_491521501743_item	2455586	et	3	main
varjundiga	doc_491521501743_item	2455587	et	3	main
järgmine	doc_491521501743_item	2455588	et	3	main
näide	doc_491521501743_item	2455589	et	3	main
on	doc_491521501743_item	2455590	et	4	main
taas	doc_491521501743_item	2455591	et	3	main
tüüpiline	doc_491521501743_item	2455592	et	3	main
viga	doc_491521501743_item	2455593	et	4	main
mis	doc_491521501743_item	2455594	et	4	main
tuleneb	doc_491521501743_item	2455595	et	3	main
vene	doc_491521501743_item	2455596	et	4	main
keelest	doc_491521501743_item	2455597	et	4	main
sest	doc_491521501743_item	2455598	et	4	main
vene	doc_491521501743_item	2455599	et	4	main
keeles	doc_491521501743_item	2455600	et	4	main
on	doc_491521501743_item	2455601	et	4	main
sõnade	doc_491521501743_item	2455602	et	3	main
ainult	doc_491521501743_item	2455603	et	4	main
ja	doc_491521501743_item	2455604	et	3	main
alles	doc_491521501743_item	2455605	et	3	main
vasteks	doc_491521501743_item	2455606	et	3	main
üks	doc_491521501743_item	2455607	et	3	main
sõna	doc_491521501743_item	2455608	et	4	main
järgmise	doc_491521501743_item	2455609	et	3	main
näite	doc_491521501743_item	2455610	et	4	main
ütleks	doc_491521501743_item	2455611	et	3	main
eestlane	doc_491521501743_item	2455612	et	3	main
ilmselt	doc_491521501743_item	2455613	et	4	main
järgmiselt	doc_491521501743_item	2455614	et	4	main
näha	doc_491521501743_item	2455619	et	3	main
arv	doc_491521501743_item	2455623	et	3	main
vene	doc_491521501743_item	2455630	et	4	main
keelest	doc_491521501743_item	2455631	et	4	main
viimasel	doc_491521501743_item	2455632	et	3	main
juhul	doc_491521501743_item	2455633	et	3	main
kasutamine	doc_491521501743_item	2455640	et	4	main
võib	doc_491521501743_item	2455648	et	3	main
öelda	doc_491521501743_item	2455649	et	4	main
et	doc_491521501743_item	2455650	et	3	main
oodatud	doc_491521501743_item	2455655	et	4	main
on	doc_491521501743_item	2455664	et	4	main
iga	doc_491521501743_item	2455666	et	4	main
mõnele	doc_491521501743_item	2455669	et	3	main
huvitavad	doc_491521501743_item	2455725	et	4	main
mulle	doc_491521501743_item	2455734	et	4	main
teatreid	doc_491521501743_item	2455738	et	3	main
etenduseid	doc_491521501743_item	2455741	et	4	main
muusika	doc_491521501743_item	2455745	et	4	main
on	doc_491521501743_item	2455773	et	4	main
tütar	doc_491521501743_item	2455780	et	3	main
jelena	doc_491521501743_item	2455783	et	4	main
mängib	doc_491521501743_item	2455785	et	3	main
klaveriga	doc_491521501743_item	2455786	et	3	main
nad	doc_491521501743_item	2455787	et	3	main
palju	doc_491521501743_item	2455788	et	4	main
matkavad	doc_491521501743_item	2455789	et	4	main
põrandalamp	doc_491521501743_item	2455797	et	3	main
joob	doc_491521501743_item	2455804	et	3	main
tee	doc_491521501743_item	2455807	et	4	main
oh	doc_491521501743_item	2455808	et	3	main
kuiv	doc_491521501743_item	2455809	et	3	main
ja	doc_491521501743_item	2455810	et	3	main
ma	doc_491521501743_item	2455812	et	3	main
ilusa	doc_491521501743_item	2455816	et	3	main
minu	doc_491521501743_item	2455823	et	3	main
nimi	doc_491521501743_item	2455826	et	3	main
õde	doc_491521501743_item	2455829	et	4	main
on	doc_491521501743_item	2455830	et	4	main
kaunitar	doc_491521501743_item	2455831	et	3	main
sõidan	doc_491521501743_item	2455832	et	3	main
turul	doc_491521501743_item	2455833	et	3	main
nad	doc_491521501743_item	2455844	et	3	main
15	doc_491521501743_item	2455846	et	2	main
aastat	doc_491521501743_item	2455847	et	3	main
estraadimuusika	doc_491521501743_item	2455852	et	4	main
muusika	doc_491521501743_item	2455854	et	4	main
ja	doc_491521501743_item	2455855	et	3	main
lauljad	doc_491521501743_item	2455861	et	4	main
müüdi	doc_491521501743_item	2455866	et	4	main
mulle	doc_491521501743_item	2455874	et	4	main
olid	doc_491521501743_item	2455880	et	4	main
jutustatkse	doc_491521501743_item	2455883	et	4	main
metsanainest	doc_491521501743_item	2455884	et	4	main
sõidan	doc_491521501743_item	2455885	et	3	main
turul	doc_491521501743_item	2455886	et	3	main
aastaseks	doc_491521501743_item	2455931	et	4	main
viiv	doc_491521501743_item	2455941	et	4	main
ja	doc_491521501743_item	2455945	et	3	main
tegemise	doc_491521501743_item	2455625	et	4	main
põhjust	doc_491521501743_item	2455626	et	4	main
taas	doc_491521501743_item	2455628	et	3	main
otsida	doc_491521501743_item	2455629	et	4	main
on	doc_491521501743_item	2455641	et	4	main
samuti	doc_491521501743_item	2455642	et	3	main
sageli	doc_491521501743_item	2455643	et	3	main
uuritud	doc_491521501743_item	2455651	et	4	main
töödes	doc_491521501743_item	2455652	et	3	main
vigade	doc_491521501743_item	2455657	et	3	main
raskusi	doc_491521501743_item	2455671	et	4	main
põhjapanevaid	doc_491521501743_item	2455678	et	3	main
järeldusi	doc_491521501743_item	2455679	et	4	main
antud	doc_491521501743_item	2455680	et	4	main
väikese	doc_491521501743_item	2455681	et	4	main
uurimuse	doc_491521501743_item	2455682	et	3	main
põhjal	doc_491521501743_item	2455683	et	4	main
teha	doc_491521501743_item	2455684	et	3	main
ei	doc_491521501743_item	2455685	et	4	main
saa	doc_491521501743_item	2455686	et	4	main
kuid	doc_491521501743_item	2455687	et	4	main
alati	doc_491521501743_item	2455688	et	4	main
on	doc_491521501743_item	2455689	et	4	main
võimalik	doc_491521501743_item	2455690	et	3	main
midagi	doc_491521501743_item	2455691	et	4	main
prognoosida	doc_491521501743_item	2455692	et	4	main
leitud	doc_491521501743_item	2455693	et	4	main
vigade	doc_491521501743_item	2455694	et	3	main
loend	doc_491521501743_item	2455695	et	3	main
naudivad	doc_491521501743_item	2455696	et	3	main
selles	doc_491521501743_item	2455697	et	4	main
atmosfääris	doc_491521501743_item	2455698	et	3	main
eestis	doc_491521501743_item	2455699	et	3	main
on	doc_491521501743_item	2455700	et	4	main
kaksteist	doc_491521501743_item	2455701	et	4	main
teatreid	doc_491521501743_item	2455702	et	3	main
pakub	doc_491521501743_item	2455703	et	3	main
mõnusad	doc_491521501743_item	2455704	et	3	main
ja	doc_491521501743_item	2455705	et	3	main
võib	doc_491521501743_item	2455707	et	3	main
mängivad	doc_491521501743_item	2455718	et	4	main
etendused	doc_491521501743_item	2455723	et	4	main
midagi	doc_491521501743_item	2455730	et	4	main
meeldib	doc_491521501743_item	2455737	et	3	main
restoranisse	doc_491521501743_item	2455743	et	3	main
naine	doc_491521501743_item	2455755	et	3	main
nimi	doc_491521501743_item	2455756	et	3	main
on	doc_491521501743_item	2455782	et	4	main
ta	doc_491521501743_item	2455784	et	4	main
õhtul	doc_491521501743_item	2455799	et	3	main
mängib	doc_491521501743_item	2455801	et	3	main
olin	doc_491521501743_item	2455813	et	3	main
osakondas	doc_491521501743_item	2455819	et	4	main
kõik	doc_491521501743_item	2455722	et	4	main
ka	doc_491521501743_item	2455735	et	3	main
väga	doc_491521501743_item	2455736	et	3	main
vaatasid	doc_491521501743_item	2455739	et	4	main
jelena	doc_491521501743_item	2455758	et	4	main
elavad	doc_491521501743_item	2455759	et	4	main
mordvas	doc_491521501743_item	2455760	et	4	main
väike	doc_491521501743_item	2455761	et	4	main
külas	doc_491521501743_item	2455762	et	3	main
naine	doc_491521501743_item	2455763	et	3	main
isa	doc_491521501743_item	2455764	et	4	main
72	doc_491521501743_item	2455766	et	2	main
on	doc_491521501743_item	2455765	et	4	main
aastat	doc_491521501743_item	2455767	et	3	main
vana	doc_491521501743_item	2455768	et	4	main
nainevanemad	doc_491521501743_item	2455769	et	4	main
on	doc_491521501743_item	2455770	et	4	main
pensionärid	doc_491521501743_item	2455771	et	3	main
talle	doc_491521501743_item	2455772	et	4	main
51	doc_491521501743_item	2455774	et	2	main
aastat	doc_491521501743_item	2455775	et	3	main
vana	doc_491521501743_item	2455776	et	4	main
vanemad	doc_491521501743_item	2455777	et	4	main
nimi	doc_491521501743_item	2455781	et	3	main
laupäeval	doc_491521501743_item	2455798	et	3	main
pere	doc_491521501743_item	2455803	et	4	main
metsale	doc_491521501743_item	2455805	et	4	main
viiv	doc_491521501743_item	2455806	et	4	main
sündinud	doc_491521501743_item	2455814	et	4	main
autojuhina	doc_491521501743_item	2455822	et	3	main
ainult	doc_491521501743_item	2455834	et	4	main
on	doc_491521501743_item	2455845	et	4	main
kuulan	doc_491521501743_item	2455851	et	3	main
erinevad	doc_491521501743_item	2455867	et	4	main
endale	doc_491521501743_item	2455870	et	4	main
2	doc_491521501743_item	2455876	et	2	main
mille	doc_491521501743_item	2455878	et	3	main
korjasid	doc_491521501743_item	2455887	et	4	main
õde	doc_491521501743_item	2455825	et	4	main
on	doc_491521501743_item	2455827	et	4	main
ostan	doc_491521501743_item	2455836	et	3	main
ma	doc_491521501743_item	2455849	et	3	main
mulle	doc_491521501743_item	2455858	et	4	main
armasta	doc_491521501743_item	2455863	et	4	main
rokk	doc_491521501743_item	2455864	et	3	main
lilled	doc_491521501743_item	2455868	et	3	main
müüdi	doc_491521501743_item	2455872	et	4	main
skulptuuri	doc_491521501743_item	2455877	et	4	main
nimi	doc_491521501743_item	2455879	et	3	main
sellel	doc_491521501743_item	2455881	et	4	main
erinevad	doc_491521501743_item	2455888	et	4	main
marjad	doc_491521501743_item	2455889	et	3	main
seened	doc_491521501743_item	2455890	et	3	main
kaks	doc_491521501743_item	2455891	et	3	main
küla	doc_491521501743_item	2455892	et	4	main
olid	doc_491521501743_item	2455893	et	4	main
nimetatud	doc_491521501743_item	2455894	et	4	main
ühe	doc_491521501743_item	2455895	et	4	main
nimega	doc_491521501743_item	2455896	et	3	main
siin	doc_491521501743_item	2455897	et	4	main
väga	doc_491521501743_item	2455898	et	3	main
hea	doc_491521501743_item	2455899	et	4	main
on	doc_491521501743_item	2455900	et	4	main
näha	doc_491521501743_item	2455901	et	3	main
kui	doc_491521501743_item	2455902	et	3	main
suurenes	doc_491521501743_item	2455903	et	4	main
elanikuarv	doc_491521501743_item	2455904	et	4	main
mul	doc_491521501743_item	2455905	et	3	main
ja	doc_491521501743_item	2455906	et	3	main
iga	doc_491521501743_item	2455907	et	4	main
inimesel	doc_491521501743_item	2455908	et	3	main
on	doc_491521501743_item	2455909	et	4	main
oma	doc_491521501743_item	2455910	et	4	main
elutee	doc_491521501743_item	2455911	et	4	main
minu	doc_491521501743_item	2455912	et	3	main
jaoks	doc_491521501743_item	2455913	et	4	main
oma	doc_491521501743_item	2455914	et	4	main
elutee	doc_491521501743_item	2455915	et	4	main
on	doc_491521501743_item	2455916	et	4	main
tahaksin	doc_491521501743_item	2455918	et	3	main
olla	doc_491521501743_item	2455919	et	3	main
sõjaväelaseks	doc_491521501743_item	2455920	et	3	main
lapsepõlves	doc_491521501743_item	2455917	et	4	main
ajal	doc_491521501743_item	2455922	et	4	main
kirjandusest	doc_491521501743_item	2455925	et	4	main
panen	doc_491521501743_item	2455926	et	3	main
ärge	doc_491521501743_item	2455932	et	3	main
ka	doc_491521501743_item	2455924	et	3	main
kartulid	doc_491521501743_item	2455927	et	3	main
panis	doc_491521501743_item	2455928	et	4	main
sai	doc_491521501743_item	2455929	et	4	main
andke	doc_491521501743_item	2455933	et	3	main
metsale	doc_491521501743_item	2455940	et	4	main
kuiv	doc_491521501743_item	2455944	et	3	main
võileivaid	doc_491521501743_item	2455935	et	4	main
kirjutage	doc_491521501743_item	2455937	et	3	main
oli	doc_491521501743_item	2455943	et	3	main
arvamus	doc_491521501745_item	2457656	et	3	main
artikli	doc_491521501745_item	2457657	et	3	main
kohta	doc_491521501745_item	2457658	et	4	main
sirvides	doc_491521501745_item	2457663	et	3	main
esimeseks	doc_491521501745_item	2457668	et	3	main
ühe	doc_491521501745_item	2457694	et	4	main
selle	doc_491521501745_item	2457697	et	4	main
on	doc_491521501745_item	2457700	et	4	main
lai	doc_491521501745_item	2457702	et	3	main
mis	doc_491521501745_item	2457709	et	4	main
järgneda	doc_491521501745_item	2457711	et	3	main
niisugust	doc_491521501745_item	2457713	et	3	main
võib	doc_491521501745_item	2457716	et	3	main
võib	doc_491521501745_item	2457737	et	3	main
peaminister	doc_491521501745_item	2457743	et	3	main
kust	doc_491521501745_item	2457758	et	4	main
meelest	doc_491521501745_item	2457769	et	4	main
ootushorisont	doc_491521501745_item	2457699	et	3	main
ei	doc_491521501745_item	2457707	et	4	main
pühendatud	doc_491521501745_item	2457728	et	4	main
aastale	doc_491521501745_item	2457730	et	3	main
sel	doc_491521501745_item	2457733	et	3	main
niisugune	doc_491521501745_item	2457735	et	3	main
meelitada	doc_491521501745_item	2457738	et	3	main
lugejaskonna	doc_491521501745_item	2457740	et	3	main
vea	doc_491521501745_item	2457745	et	4	main
oma	doc_491521501745_item	2457747	et	4	main
kitsendab	doc_491521501745_item	2457752	et	3	main
ning	doc_491521501745_item	2457754	et	3	main
võimalik	doc_491521501745_item	2457756	et	3	main
pealkiri	doc_491521501745_item	2457770	et	3	main
selle	doc_491521501745_item	2457776	et	4	main
pandud	doc_491521501745_item	2457785	et	4	main
kutsub	doc_491521501745_item	2457790	et	3	main
lugeda	doc_491521501745_item	2457792	et	3	main
seda	doc_491521501745_item	2457793	et	3	main
lugu	doc_491521501745_item	2457794	et	4	main
ja	doc_491521501745_item	2457795	et	3	main
leida	doc_491521501745_item	2457815	et	3	main
või	doc_491521501745_item	2457819	et	4	main
ajalehti	doc_491521501745_item	2457664	et	4	main
midagi	doc_491521501745_item	2457666	et	4	main
lugeda	doc_491521501745_item	2457667	et	3	main
asjaks	doc_491521501745_item	2457669	et	3	main
lugeme	doc_491521501745_item	2457670	et	4	main
kas	doc_491521501745_item	2457693	et	3	main
lõpp	doc_491521501745_item	2457696	et	3	main
pealkiri	doc_491521501745_item	2457698	et	3	main
päris	doc_491521501745_item	2457701	et	4	main
ausalt	doc_491521501745_item	2457704	et	4	main
öeldes	doc_491521501745_item	2457705	et	3	main
isegi	doc_491521501745_item	2457706	et	4	main
see	doc_491521501745_item	2457715	et	3	main
olla	doc_491521501745_item	2457717	et	3	main
mingi	doc_491521501745_item	2457719	et	4	main
artikkel	doc_491521501745_item	2457720	et	3	main
uuele	doc_491521501745_item	2457729	et	3	main
ajakirjast	doc_491521501745_item	2457732	et	4	main
alapealkiri	doc_491521501745_item	2457741	et	3	main
pulmad	doc_491521501745_item	2457750	et	3	main
niisugune	doc_491521501745_item	2457760	et	3	main
on	doc_491521501745_item	2457766	et	4	main
kirjutatud	doc_491521501745_item	2457767	et	4	main
minu	doc_491521501745_item	2457768	et	3	main
mainitud	doc_491521501745_item	2457774	et	4	main
peaminister	doc_491521501745_item	2457775	et	3	main
lugejaid	doc_491521501745_item	2457781	et	4	main
küljelt	doc_491521501745_item	2457783	et	3	main
pealkiri	doc_491521501745_item	2457784	et	3	main
mitteametlik	doc_491521501745_item	2457801	et	3	main
ole	doc_491521501745_item	2457808	et	4	main
ajakirjade	doc_491521501745_item	2457817	et	3	main
lõdvestamiseks	doc_491521501745_item	2457831	et	4	main
fun	doc_491521501745_item	2457836	et	4	main
niisugust	doc_491521501745_item	2457837	et	3	main
tüüpartikleid	doc_491521501745_item	2457838	et	3	main
naised	doc_491521501745_item	2457842	et	3	main
kelle	doc_491521501745_item	2457854	et	4	main
jaoks	doc_491521501745_item	2457855	et	4	main
või	doc_491521501745_item	2457861	et	4	main
kaua	doc_491521501745_item	2457870	et	3	main
et	doc_491521501745_item	2457874	et	3	main
arvates	doc_491521501745_item	2457883	et	4	main
kohta	doc_491521501745_item	2457662	et	4	main
et	doc_491521501745_item	2457665	et	3	main
ajastu	doc_491521501745_item	2457695	et	4	main
võib	doc_491521501745_item	2457710	et	3	main
pealkirja	doc_491521501745_item	2457714	et	4	main
nii	doc_491521501745_item	2457718	et	3	main
minu	doc_491521501745_item	2457659	et	3	main
arvamus	doc_491521501745_item	2457660	et	3	main
artikli	doc_491521501745_item	2457661	et	3	main
pealkirju	doc_491521501745_item	2457671	et	4	main
lõpuks	doc_491521501745_item	2457672	et	4	main
valides	doc_491521501745_item	2457673	et	3	main
kõige	doc_491521501745_item	2457674	et	4	main
meelitava	doc_491521501745_item	2457675	et	4	main
meie	doc_491521501745_item	2457676	et	4	main
jacks	doc_491521501745_item	2457677	et	4	main
hakkame	doc_491521501745_item	2457678	et	3	main
seda	doc_491521501745_item	2457679	et	3	main
lugema	doc_491521501745_item	2457680	et	4	main
antud	doc_491521501745_item	2457681	et	4	main
koju	doc_491521501745_item	2457682	et	3	main
artiklis	doc_491521501745_item	2457683	et	3	main
loo	doc_491521501745_item	2457684	et	4	main
pealkiri	doc_491521501745_item	2457685	et	3	main
oli	doc_491521501745_item	2457686	et	3	main
pandud	doc_491521501745_item	2457687	et	4	main
küsimuse	doc_491521501745_item	2457688	et	4	main
vormis	doc_491521501745_item	2457689	et	4	main
ja	doc_491521501745_item	2457690	et	3	main
kõõlas	doc_491521501745_item	2457691	et	4	main
nii	doc_491521501745_item	2457692	et	3	main
ning	doc_491521501745_item	2457703	et	3	main
tea	doc_491521501745_item	2457708	et	4	main
pärast	doc_491521501745_item	2457712	et	4	main
teaduslikust	doc_491521501745_item	2457722	et	4	main
naiste	doc_491521501745_item	2457731	et	3	main
tegi	doc_491521501745_item	2457744	et	4	main
grandioossed	doc_491521501745_item	2457749	et	3	main
võetud	doc_491521501745_item	2457759	et	4	main
ja	doc_491521501745_item	2457762	et	3	main
jaoks	doc_491521501745_item	2457764	et	4	main
on	doc_491521501745_item	2457771	et	4	main
päris	doc_491521501745_item	2457772	et	4	main
valisest	doc_491521501745_item	2457773	et	4	main
see	doc_491521501745_item	2457778	et	3	main
meelitada	doc_491521501745_item	2457780	et	3	main
mis	doc_491521501745_item	2457788	et	4	main
inimesi	doc_491521501745_item	2457791	et	4	main
on	doc_491521501745_item	2457800	et	4	main
pandud	doc_491521501745_item	2457809	et	4	main
auton	doc_491521501745_item	2457810	et	4	main
nimi	doc_491521501745_item	2457811	et	3	main
mis	doc_491521501745_item	2457812	et	4	main
tihti	doc_491521501745_item	2457813	et	3	main
saab	doc_491521501745_item	2457814	et	3	main
arvates	doc_491521501745_item	2457840	et	4	main
noor	doc_491521501745_item	2457852	et	3	main
neiud	doc_491521501745_item	2457853	et	4	main
teema	doc_491521501745_item	2457857	et	4	main
huvi	doc_491521501745_item	2457860	et	4	main
üldse	doc_491521501745_item	2457862	et	3	main
saavad	doc_491521501745_item	2457867	et	4	main
seda	doc_491521501745_item	2457868	et	3	main
aega	doc_491521501745_item	2457871	et	4	main
selline	doc_491521501745_item	2457875	et	4	main
pakkuks	doc_491521501745_item	2457877	et	4	main
enda	doc_491521501745_item	2457890	et	4	main
on	doc_491521501745_item	2457894	et	4	main
lugemist	doc_491521501745_item	2457899	et	4	main
et	doc_491521501745_item	2457903	et	3	main
on	doc_491521501745_item	2457905	et	4	main
see	doc_491521501745_item	2457907	et	3	main
keerulised	doc_491521501745_item	2457915	et	4	main
kui	doc_491521501745_item	2457916	et	3	main
ka	doc_491521501745_item	2457917	et	3	main
lihtsad	doc_491521501745_item	2457918	et	3	main
laused	doc_491521501745_item	2457919	et	3	main
ole	doc_491521501745_item	2457922	et	4	main
ja	doc_491521501745_item	2457923	et	3	main
on	doc_491521501745_item	2457932	et	4	main
kergesti	doc_491521501745_item	2457933	et	3	main
meelest	doc_491521501745_item	2457936	et	4	main
pandud	doc_491521501745_item	2457950	et	4	main
näidata	doc_491521501745_item	2457952	et	4	main
tihti	doc_491521501745_item	2457954	et	3	main
eriti	doc_491521501745_item	2457957	et	3	main
numbreid	doc_491521501745_item	2457960	et	3	main
näiteks	doc_491521501745_item	2457961	et	4	main
ainult	doc_491521501745_item	2457980	et	4	main
kindalsti	doc_491521501745_item	2457983	et	4	main
rääkida	doc_491521501745_item	2457985	et	3	main
tavalises	doc_491521501745_item	2458005	et	4	main
viiest	doc_491521501745_item	2458009	et	4	main
3	doc_491521501745_item	2458015	et	2	main
iõigud	doc_491521501745_item	2458017	et	4	main
mis	doc_491521501745_item	2458021	et	4	main
seotud	doc_491521501745_item	2458023	et	4	main
üksteisega	doc_491521501745_item	2458024	et	3	main
loogiliselt	doc_491521501745_item	2458028	et	4	main
tekst	doc_491521501745_item	2458030	et	3	main
ta	doc_491521501745_item	2458044	et	4	main
mida	doc_491521501745_item	2458059	et	4	main
ei	doc_491521501745_item	2458064	et	4	main
tekst	doc_491521501745_item	2458080	et	3	main
seda	doc_491521501745_item	2458089	et	3	main
arvan	doc_491521501745_item	2458093	et	3	main
kosmosest	doc_491521501745_item	2457721	et	4	main
ajalehest	doc_491521501745_item	2457723	et	4	main
kui	doc_491521501745_item	2457724	et	3	main
ka	doc_491521501745_item	2457725	et	3	main
pidulik	doc_491521501745_item	2457726	et	3	main
lugu	doc_491521501745_item	2457727	et	4	main
juhul	doc_491521501745_item	2457734	et	3	main
pealkiri	doc_491521501745_item	2457736	et	3	main
laia	doc_491521501745_item	2457739	et	4	main
kas	doc_491521501745_item	2457742	et	3	main
korraldades	doc_491521501745_item	2457746	et	3	main
tütrele	doc_491521501745_item	2457748	et	3	main
juba	doc_491521501745_item	2457751	et	3	main
ootushorisont	doc_491521501745_item	2457753	et	3	main
on	doc_491521501745_item	2457755	et	4	main
oletada	doc_491521501745_item	2457757	et	3	main
artikkel	doc_491521501745_item	2457761	et	3	main
kelle	doc_491521501745_item	2457763	et	4	main
see	doc_491521501745_item	2457765	et	3	main
vormis	doc_491521501745_item	2457787	et	4	main
kuidagi	doc_491521501745_item	2457789	et	3	main
küsimusele	doc_491521501745_item	2457798	et	4	main
see	doc_491521501745_item	2457799	et	3	main
lugu	doc_491521501745_item	2457802	et	4	main
sest	doc_491521501745_item	2457805	et	4	main
kollase	doc_491521501745_item	2457816	et	4	main
ajakirjadest	doc_491521501745_item	2457821	et	3	main
see	doc_491521501745_item	2457823	et	3	main
lugemiseks	doc_491521501745_item	2457833	et	4	main
just	doc_491521501745_item	2457834	et	3	main
pärast	doc_491521501745_item	2457844	et	4	main
tööpäeva	doc_491521501745_item	2457845	et	4	main
koju	doc_491521501745_item	2457846	et	3	main
tulnud	doc_491521501745_item	2457847	et	4	main
ja	doc_491521501745_item	2457848	et	3	main
tahavad	doc_491521501745_item	2457849	et	3	main
pakkub	doc_491521501745_item	2457858	et	4	main
pensionäärid	doc_491521501745_item	2457863	et	4	main
kes	doc_491521501745_item	2457864	et	4	main
arutleda	doc_491521501745_item	2457869	et	3	main
usu	doc_491521501745_item	2457873	et	4	main
inimene	doc_491521501745_item	2457887	et	3	main
ei	doc_491521501745_item	2457896	et	4	main
ole	doc_491521501745_item	2457897	et	4	main
seoses	doc_491521501745_item	2457901	et	4	main
mitteametlik	doc_491521501745_item	2457906	et	3	main
kirjutatud	doc_491521501745_item	2457909	et	4	main
lihtsa	doc_491521501745_item	2457910	et	3	main
keelega	doc_491521501745_item	2457911	et	3	main
on	doc_491521501745_item	2457912	et	4	main
pärast	doc_491521501745_item	2457777	et	4	main
võib	doc_491521501745_item	2457779	et	3	main
teiselt	doc_491521501745_item	2457782	et	4	main
küsimuse	doc_491521501745_item	2457786	et	4	main
ise	doc_491521501745_item	2457796	et	4	main
vastata	doc_491521501745_item	2457797	et	4	main
pigem	doc_491521501745_item	2457803	et	3	main
kuulajutud	doc_491521501745_item	2457804	et	4	main
isegi	doc_491521501745_item	2457806	et	4	main
ei	doc_491521501745_item	2457807	et	4	main
lehekülgedelt	doc_491521501745_item	2457818	et	4	main
naiste	doc_491521501745_item	2457820	et	3	main
ning	doc_491521501745_item	2457822	et	3	main
ei	doc_491521501745_item	2457824	et	4	main
tõsisele	doc_491521501745_item	2457826	et	4	main
probeemile	doc_491521501745_item	2457827	et	4	main
vaid	doc_491521501745_item	2457828	et	3	main
viitab	doc_491521501745_item	2457829	et	3	main
hoopis	doc_491521501745_item	2457830	et	3	main
loevad	doc_491521501745_item	2457841	et	3	main
kes	doc_491521501745_item	2457843	et	4	main
või	doc_491521501745_item	2457851	et	4	main
erilist	doc_491521501745_item	2457859	et	4	main
lugemist	doc_491521501745_item	2457866	et	4	main
või	doc_491521501745_item	2457880	et	4	main
ärimeestele	doc_491521501745_item	2457881	et	4	main
minu	doc_491521501745_item	2457882	et	3	main
iugemist	doc_491521501745_item	2457886	et	4	main
tekst	doc_491521501745_item	2457904	et	3	main
on	doc_491521501745_item	2457908	et	4	main
ei	doc_491521501745_item	2457921	et	4	main
sobib	doc_491521501745_item	2457938	et	3	main
autorideta	doc_491521501745_item	2457947	et	4	main
keelt	doc_491521501745_item	2457977	et	4	main
leidsin	doc_491521501745_item	2457979	et	3	main
ühe	doc_491521501745_item	2457981	et	4	main
kui	doc_491521501745_item	2457984	et	3	main
teksti	doc_491521501745_item	2457986	et	4	main
stiilist	doc_491521501745_item	2457987	et	4	main
ja	doc_491521501745_item	2457988	et	3	main
ülesehitusest	doc_491521501745_item	2457989	et	4	main
arvan	doc_491521501745_item	2457990	et	3	main
et	doc_491521501745_item	2457991	et	3	main
kirjutatud	doc_491521501745_item	2458004	et	4	main
lõikidestsissejuhatus-1ne	doc_491521501745_item	2458010	et	4	main
teema	doc_491521501745_item	2458012	et	4	main
2	doc_491521501745_item	2458014	et	2	main
on	doc_491521501745_item	2458022	et	4	main
ja	doc_491521501745_item	2458025	et	3	main
et	doc_491521501745_item	2458036	et	3	main
loeb	doc_491521501745_item	2458045	et	3	main
minu	doc_491521501745_item	2458048	et	3	main
selle	doc_491521501745_item	2458050	et	4	main
vaid	doc_491521501745_item	2458054	et	3	main
lihtsalt	doc_491521501745_item	2458057	et	4	main
näidata	doc_491521501745_item	2458058	et	4	main
sest	doc_491521501745_item	2458063	et	4	main
et	doc_491521501745_item	2458066	et	3	main
külmaks	doc_491521501745_item	2458082	et	4	main
sest	doc_491521501745_item	2458083	et	4	main
ja	doc_491521501745_item	2458085	et	3	main
ajakirjades	doc_491521501745_item	2458086	et	3	main
on	doc_491521501745_item	2458087	et	4	main
tüüpi	doc_491521501745_item	2458090	et	4	main
lugema	doc_491521501745_item	2458096	et	4	main
asja	doc_491521501745_item	2458098	et	4	main
viita	doc_491521501745_item	2457825	et	4	main
ja	doc_491521501745_item	2457832	et	3	main
for	doc_491521501745_item	2457835	et	4	main
minu	doc_491521501745_item	2457839	et	3	main
puhata	doc_491521501745_item	2457850	et	4	main
pulomade	doc_491521501745_item	2457856	et	4	main
pärast	doc_491521501745_item	2457865	et	4	main
ei	doc_491521501745_item	2457872	et	4	main
artikkel	doc_491521501745_item	2457876	et	3	main
huvi	doc_491521501745_item	2457878	et	4	main
haritlastele	doc_491521501745_item	2457879	et	3	main
pealkirja	doc_491521501745_item	2457885	et	4	main
või	doc_491521501745_item	2457895	et	4	main
jätkata	doc_491521501745_item	2457900	et	4	main
olemas	doc_491521501745_item	2457913	et	4	main
nii	doc_491521501745_item	2457914	et	3	main
võõrsõnu	doc_491521501745_item	2457920	et	3	main
minu	doc_491521501745_item	2457935	et	3	main
adressaadile	doc_491521501745_item	2457939	et	3	main
on	doc_491521501745_item	2457941	et	4	main
tükk	doc_491521501745_item	2457944	et	3	main
tsitaate	doc_491521501745_item	2457945	et	3	main
mis	doc_491521501745_item	2457948	et	4	main
et	doc_491521501745_item	2457951	et	3	main
kasutatakse	doc_491521501745_item	2457955	et	3	main
mis	doc_491521501745_item	2457958	et	4	main
puudutab	doc_491521501745_item	2457959	et	3	main
emakeelena	doc_491521501745_item	2457978	et	3	main
stiili	doc_491521501745_item	2457996	et	4	main
eraldaks	doc_491521501745_item	2457998	et	3	main
autori	doc_491521501745_item	2457999	et	3	main
atikkel	doc_491521501745_item	2458007	et	4	main
areng	doc_491521501745_item	2458013	et	3	main
4jas	doc_491521501745_item	2458016	et	4	main
ning	doc_491521501745_item	2458018	et	3	main
lõpp-5es	doc_491521501745_item	2458019	et	4	main
lõik	doc_491521501745_item	2458020	et	3	main
pärast	doc_491521501745_item	2457884	et	4	main
saab	doc_491521501745_item	2457888	et	3	main
kohe	doc_491521501745_item	2457889	et	4	main
jaoks	doc_491521501745_item	2457891	et	4	main
otsustada	doc_491521501745_item	2457892	et	3	main
kas	doc_491521501745_item	2457893	et	3	main
väärt	doc_491521501745_item	2457898	et	4	main
sellega	doc_491521501745_item	2457902	et	3	main
selle	doc_491521501745_item	2457927	et	4	main
teksti	doc_491521501745_item	2457928	et	4	main
zanrile	doc_491521501745_item	2457929	et	4	main
ning	doc_491521501745_item	2457930	et	3	main
tekst	doc_491521501745_item	2457931	et	3	main
tekst	doc_491521501745_item	2457937	et	3	main
on	doc_491521501745_item	2457949	et	4	main
meelepaha	doc_491521501745_item	2457953	et	4	main
fakte	doc_491521501745_item	2457956	et	3	main
eesti	doc_491521501745_item	2457976	et	4	main
trükkiveo-	doc_491521501745_item	2457982	et	3	main
ei	doc_491521501745_item	2457992	et	4	main
erilist	doc_491521501745_item	2457995	et	4	main
mis	doc_491521501745_item	2457997	et	4	main
teistest	doc_491521501745_item	2458000	et	4	main
ajakirjanikkudest	doc_491521501745_item	2458001	et	3	main
tekst	doc_491521501745_item	2458002	et	3	main
on	doc_491521501745_item	2458003	et	4	main
koosneb	doc_491521501745_item	2458008	et	3	main
lõik	doc_491521501745_item	2458011	et	3	main
tundub	doc_491521501745_item	2458035	et	3	main
lugeja	doc_491521501745_item	2458038	et	4	main
seda	doc_491521501745_item	2458040	et	3	main
seda	doc_491521501745_item	2458046	et	3	main
palju	doc_491521501745_item	2458088	et	4	main
hakkan	doc_491521501745_item	2458095	et	3	main
sõnavara	doc_491521501745_item	2457924	et	4	main
on	doc_491521501745_item	2457925	et	4	main
sobilik	doc_491521501745_item	2457926	et	3	main
loetav	doc_491521501745_item	2457934	et	4	main
loos	doc_491521501745_item	2457940	et	4	main
olemas	doc_491521501745_item	2457942	et	4	main
paar	doc_491521501745_item	2457943	et	3	main
ilma	doc_491521501745_item	2457946	et	4	main
külaliste	doc_491521501745_item	2457962	et	4	main
arv	doc_491521501745_item	2457963	et	3	main
või	doc_491521501745_item	2457964	et	4	main
tohutud	doc_491521501745_item	2457965	et	4	main
kahjuks	doc_491521501745_item	2457967	et	4	main
rahasummad	doc_491521501745_item	2457966	et	4	main
grammatikat	doc_491521501745_item	2457968	et	3	main
mul	doc_491521501745_item	2457969	et	3	main
on	doc_491521501745_item	2457970	et	4	main
raske	doc_491521501745_item	2457971	et	4	main
hinnata	doc_491521501745_item	2457972	et	4	main
sest	doc_491521501745_item	2457973	et	4	main
ei	doc_491521501745_item	2457974	et	4	main
räägi	doc_491521501745_item	2457975	et	4	main
ole	doc_491521501745_item	2457993	et	4	main
mingit	doc_491521501745_item	2457994	et	3	main
vormis	doc_491521501745_item	2458006	et	4	main
päris	doc_491521501745_item	2458027	et	4	main
sellepärast	doc_491521501745_item	2458029	et	3	main
lõppuni	doc_491521501745_item	2458047	et	3	main
meelest	doc_491521501745_item	2458049	et	4	main
artikli	doc_491521501745_item	2458051	et	3	main
informatiivne	doc_491521501745_item	2458053	et	3	main
ametlik	doc_491521501745_item	2458056	et	3	main
maailmas	doc_491521501745_item	2458062	et	3	main
artikleid	doc_491521501745_item	2458091	et	3	main
et	doc_491521501745_item	2458094	et	3	main
pärast	doc_491521501745_item	2458101	et	4	main
pandud	doc_491521501745_item	2458026	et	4	main
on	doc_491521501745_item	2458031	et	4	main
kergesti	doc_491521501745_item	2458032	et	3	main
loetav	doc_491521501745_item	2458033	et	4	main
ja	doc_491521501745_item	2458034	et	3	main
kui	doc_491521501745_item	2458037	et	3	main
algas	doc_491521501745_item	2458039	et	3	main
juba	doc_491521501745_item	2458041	et	3	main
lugema	doc_491521501745_item	2458042	et	4	main
siis	doc_491521501745_item	2458043	et	3	main
eesmärk	doc_491521501745_item	2458052	et	3	main
mitte	doc_491521501745_item	2458055	et	3	main
huvitavat	doc_491521501745_item	2458060	et	4	main
toimub	doc_491521501745_item	2458061	et	3	main
arva	doc_491521501745_item	2458065	et	4	main
need	doc_491521501745_item	2458067	et	3	main
pulmad	doc_491521501745_item	2458068	et	3	main
võivad	doc_491521501745_item	2458069	et	4	main
meie	doc_491521501745_item	2458070	et	4	main
riiki	doc_491521501745_item	2458071	et	4	main
kuidagi	doc_491521501745_item	2458072	et	3	main
puutuda	doc_491521501745_item	2458073	et	3	main
või	doc_491521501745_item	2458074	et	4	main
mõõjutada	doc_491521501745_item	2458075	et	4	main
meie	doc_491521501745_item	2458076	et	4	main
lu	doc_491521501745_item	2458077	et	4	main
mind	doc_491521501745_item	2458078	et	4	main
see	doc_491521501745_item	2458079	et	3	main
jätab	doc_491521501745_item	2458081	et	3	main
ajalehtedes	doc_491521501745_item	2458084	et	4	main
ning	doc_491521501745_item	2458092	et	3	main
niisugust	doc_491521501745_item	2458097	et	3	main
ainult	doc_491521501745_item	2458099	et	4	main
uudishimu	doc_491521501745_item	2458100	et	4	main
kas	doc_491521501747_item	2467443	et	3	main
mina	doc_491521501747_item	2467447	et	4	main
5	doc_491521501747_item	2467455	et	2	main
õpetajana	doc_491521501747_item	2467459	et	4	main
see	doc_491521501747_item	2467462	et	3	main
vend	doc_491521501747_item	2467465	et	3	main
lähen	doc_491521501747_item	2467468	et	3	main
elada	doc_491521501747_item	2467477	et	3	main
10	doc_491521501747_item	2467486	et	2	main
me	doc_491521501747_item	2467487	et	4	main
vestleme	doc_491521501747_item	2467488	et	3	main
11	doc_491521501747_item	2467491	et	2	main
ajaleht	doc_491521501747_item	2467496	et	3	main
on	doc_491521501747_item	2467499	et	4	main
siia	doc_491521501747_item	2467522	et	4	main
esmaspäev	doc_491521501747_item	2467524	et	3	main
toast	doc_491521501747_item	2467532	et	3	main
ehitatud	doc_491521501747_item	2467542	et	4	main
kinos	doc_491521501747_item	2467564	et	3	main
millal	doc_491521501747_item	2467566	et	3	main
3	doc_491521501747_item	2467571	et	2	main
eile	doc_491521501747_item	2467576	et	3	main
ka	doc_491521501747_item	2467577	et	3	main
ta	doc_491521501747_item	2467580	et	4	main
raamatu	doc_491521501747_item	2467583	et	4	main
tartus	doc_491521501747_item	2467589	et	3	main
6	doc_491521501747_item	2467592	et	2	main
on	doc_491521501747_item	2467594	et	4	main
söönud	doc_491521501747_item	2467595	et	4	main
siis	doc_491521501747_item	2467603	et	3	main
nemad	doc_491521501747_item	2467605	et	3	main
oli	doc_491521501747_item	2467607	et	3	main
ipane	doc_491521501747_item	2467426	et	4	main
vormi	doc_491521501747_item	2467429	et	4	main
2	doc_491521501747_item	2467435	et	2	main
minuga	doc_491521501747_item	2467438	et	3	main
said	doc_491521501747_item	2467445	et	4	main
sõber	doc_491521501747_item	2467457	et	3	main
venna	doc_491521501747_item	2467464	et	3	main
koos	doc_491521501747_item	2467470	et	4	main
raske	doc_491521501747_item	2467475	et	4	main
rahata	doc_491521501747_item	2467479	et	4	main
armastust	doc_491521501747_item	2467489	et	4	main
12	doc_491521501747_item	2467497	et	2	main
vähe	doc_491521501747_item	2467500	et	3	main
eksamitöö	doc_491521501747_item	2467425	et	4	main
ma	doc_491521501747_item	2467431	et	3	main
elan	doc_491521501747_item	2467432	et	3	main
pealinn	doc_491521501747_item	2467434	et	3	main
kas	doc_491521501747_item	2467436	et	3	main
tahad	doc_491521501747_item	2467437	et	3	main
3	doc_491521501747_item	2467442	et	2	main
aru	doc_491521501747_item	2467448	et	4	main
ta	doc_491521501747_item	2467450	et	4	main
on	doc_491521501747_item	2467463	et	4	main
7	doc_491521501747_item	2467467	et	2	main
on	doc_491521501747_item	2467476	et	4	main
küsimus	doc_491521501747_item	2467485	et	4	main
armastus	doc_491521501747_item	2467490	et	4	main
mul	doc_491521501747_item	2467498	et	3	main
jääb	doc_491521501747_item	2467521	et	3	main
raamatud	doc_491521501747_item	2467527	et	4	main
riiule	doc_491521501747_item	2467528	et	3	main
tuba	doc_491521501747_item	2467533	et	4	main
come	doc_491521501747_item	2467536	et	4	main
room	doc_491521501747_item	2467538	et	3	main
maja	doc_491521501747_item	2467540	et	4	main
on	doc_491521501747_item	2467541	et	4	main
kivist	doc_491521501747_item	2467543	et	4	main
armunud	doc_491521501747_item	2467548	et	4	main
ma	doc_491521501747_item	2467560	et	3	main
sündima	doc_491521501747_item	2467570	et	3	main
sa	doc_491521501747_item	2467573	et	3	main
lugema	doc_491521501747_item	2467582	et	4	main
palju	doc_491521501747_item	2467598	et	4	main
võileibu	doc_491521501747_item	2467599	et	3	main
tulime	doc_491521501747_item	2467602	et	3	main
lahkunud	doc_491521501747_item	2467608	et	4	main
filmi	doc_491521501747_item	2467618	et	4	main
ei	doc_491521501747_item	2467630	et	4	main
10	doc_491521501747_item	2467634	et	2	main
1	doc_491521501747_item	2467644	et	2	main
sul	doc_491521501747_item	2467647	et	3	main
on	doc_491521501747_item	2467650	et	4	main
mix	doc_491521501747_item	2467651	et	4	main
2	doc_491521501747_item	2467652	et	2	main
kuhu	doc_491521501747_item	2467653	et	3	main
sa	doc_491521501747_item	2467674	et	3	main
sõidad	doc_491521501747_item	2467676	et	3	main
kell	doc_491521501747_item	2467679	et	3	main
on	doc_491521501747_item	2467691	et	4	main
lähen	doc_491521501747_item	2467709	et	3	main
peal	doc_491521501747_item	2467722	et	4	main
on	doc_491521501747_item	2467723	et	4	main
5poeg	doc_491521501747_item	2467726	et	3	main
ema	doc_491521501747_item	2467728	et	4	main
isa	doc_491521501747_item	2467730	et	4	main
kohal	doc_491521501747_item	2467731	et	4	main
ees	doc_491521501747_item	2467735	et	4	main
8koer	doc_491521501747_item	2467741	et	3	main
tooli	doc_491521501747_item	2467743	et	4	main
9sõidame	doc_491521501747_item	2467745	et	3	main
üheksakümnekaheksas	doc_491521501747_item	2467758	et	4	main
165	doc_491521501747_item	2467759	et	2	main
tuhande	doc_491521501747_item	2467781	et	3	main
mata	doc_491521501747_item	2467791	et	4	main
mast	doc_491521501747_item	2467792	et	3	main
või	doc_491521501747_item	2467793	et	4	main
ma	doc_491521501747_item	2467794	et	3	main
homme	doc_491521501747_item	2467797	et	3	main
vaatama	doc_491521501747_item	2467800	et	3	main
olen	doc_491521501747_item	2467803	et	3	main
rasket	doc_491521501747_item	2467805	et	3	main
kirjuta	doc_491521501747_item	2467829	et	4	main
ema	doc_491521501747_item	2467839	et	4	main
isa	doc_491521501747_item	2467845	et	4	main
kallim	doc_491521501747_item	2467849	et	4	main
auto	doc_491521501747_item	2467852	et	4	main
on	doc_491521501747_item	2467855	et	4	main
targem	doc_491521501747_item	2467856	et	4	main
tark	doc_491521501747_item	2467857	et	3	main
5	doc_491521501747_item	2467860	et	2	main
õigesse	doc_491521501747_item	2467428	et	3	main
1	doc_491521501747_item	2467430	et	2	main
pealinnas	doc_491521501747_item	2467433	et	4	main
kinno	doc_491521501747_item	2467439	et	3	main
kino	doc_491521501747_item	2467440	et	4	main
minna	doc_491521501747_item	2467441	et	3	main
minust	doc_491521501747_item	2467446	et	3	main
4	doc_491521501747_item	2467449	et	2	main
tahab	doc_491521501747_item	2467451	et	3	main
saada	doc_491521501747_item	2467452	et	4	main
õpetaja	doc_491521501747_item	2467460	et	4	main
8	doc_491521501747_item	2467474	et	2	main
raha	doc_491521501747_item	2467480	et	4	main
küsimule	doc_491521501747_item	2467484	et	4	main
laual	doc_491521501747_item	2467492	et	3	main
on	doc_491521501747_item	2467493	et	4	main
ajalehti	doc_491521501747_item	2467495	et	4	main
esmaspäevaks	doc_491521501747_item	2467523	et	3	main
17	doc_491521501747_item	2467525	et	2	main
or	doc_491521501747_item	2467534	et	4	main
20	doc_491521501747_item	2467545	et	2	main
on	doc_491521501747_item	2467547	et	4	main
käisin	doc_491521501747_item	2467561	et	3	main
eile	doc_491521501747_item	2467563	et	3	main
2	doc_491521501747_item	2467565	et	2	main
oled	doc_491521501747_item	2467568	et	3	main
olema	doc_491521501747_item	2467575	et	4	main
4	doc_491521501747_item	2467579	et	2	main
juba	doc_491521501747_item	2467606	et	3	main
lahkuma	doc_491521501747_item	2467609	et	3	main
oled	doc_491521501747_item	2467613	et	3	main
nägema	doc_491521501747_item	2467615	et	3	main
uut	doc_491521501747_item	2467617	et	3	main
ma	doc_491521501747_item	2467620	et	3	main
eile	doc_491521501747_item	2467623	et	3	main
külla	doc_491521501747_item	2467625	et	4	main
olid	doc_491521501747_item	2467631	et	4	main
säin	doc_491521501747_item	2467636	et	4	main
küsisõnad	doc_491521501747_item	2467643	et	3	main
sul	doc_491521501747_item	2467654	et	3	main
4	doc_491521501747_item	2467661	et	2	main
kust	doc_491521501747_item	2467668	et	4	main
sa	doc_491521501747_item	2467669	et	3	main
tuled	doc_491521501747_item	2467670	et	4	main
6	doc_491521501747_item	2467671	et	2	main
mis	doc_491521501747_item	2467678	et	4	main
on	doc_491521501747_item	2467680	et	4	main
ta	doc_491521501747_item	2467684	et	4	main
räägib	doc_491521501747_item	2467685	et	3	main
millest	doc_491521501747_item	2467686	et	3	main
9	doc_491521501747_item	2467687	et	2	main
tundi	doc_491521501747_item	2467707	et	4	main
2	doc_491521501747_item	2467711	et	2	main
palju	doc_491521501747_item	2467724	et	4	main
6ta	doc_491521501747_item	2467732	et	4	main
kuuekümneviies	doc_491521501747_item	2467761	et	4	main
30	doc_491521501747_item	2467773	et	2	main
seitsmesaja	doc_491521501747_item	2467782	et	4	main
76	doc_491521501747_item	2467785	et	2	main
kuuendal	doc_491521501747_item	2467787	et	3	main
flmi	doc_491521501747_item	2467799	et	4	main
2	doc_491521501747_item	2467802	et	2	main
tegemas	doc_491521501747_item	2467807	et	3	main
keskvõrre	doc_491521501747_item	2467830	et	4	main
on	doc_491521501747_item	2467848	et	4	main
4	doc_491521501747_item	2467891	et	2	main
ei	doc_491521501747_item	2467893	et	4	main
sõnu	doc_491521501747_item	2467895	et	4	main
kirjutada	doc_491521501747_item	2467896	et	3	main
kirjutama	doc_491521501747_item	2467897	et	3	main
5	doc_491521501747_item	2467898	et	2	main
sõna	doc_491521501747_item	2467427	et	4	main
sa	doc_491521501747_item	2467444	et	3	main
arstiks	doc_491521501747_item	2467453	et	4	main
arst	doc_491521501747_item	2467454	et	3	main
mu	doc_491521501747_item	2467456	et	3	main
töötab	doc_491521501747_item	2467458	et	3	main
6	doc_491521501747_item	2467461	et	2	main
raamat	doc_491521501747_item	2467466	et	3	main
teatrisse	doc_491521501747_item	2467469	et	3	main
oma	doc_491521501747_item	2467471	et	4	main
pojaga	doc_491521501747_item	2467472	et	4	main
poeg	doc_491521501747_item	2467473	et	3	main
ilma	doc_491521501747_item	2467478	et	4	main
9	doc_491521501747_item	2467481	et	2	main
vasta	doc_491521501747_item	2467482	et	4	main
minu	doc_491521501747_item	2467483	et	3	main
palju	doc_491521501747_item	2467494	et	4	main
sõpru	doc_491521501747_item	2467501	et	3	main
sõber	doc_491521501747_item	2467502	et	3	main
13	doc_491521501747_item	2467504	et	2	main
sõpra	doc_491521501747_item	2467503	et	4	main
kuulan	doc_491521501747_item	2467505	et	3	main
raadiost	doc_491521501747_item	2467506	et	3	main
muusikat	doc_491521501747_item	2467507	et	3	main
14	doc_491521501747_item	2467509	et	2	main
muusika	doc_491521501747_item	2467508	et	4	main
poiss	doc_491521501747_item	2467510	et	3	main
tuleb	doc_491521501747_item	2467511	et	3	main
koolist	doc_491521501747_item	2467512	et	4	main
kool	doc_491521501747_item	2467513	et	4	main
15	doc_491521501747_item	2467514	et	2	main
jõin	doc_491521501747_item	2467515	et	3	main
mahla	doc_491521501747_item	2467516	et	4	main
mahl	doc_491521501747_item	2467517	et	3	main
ära	doc_491521501747_item	2467518	et	4	main
16	doc_491521501747_item	2467519	et	2	main
ta	doc_491521501747_item	2467520	et	4	main
pane	doc_491521501747_item	2467526	et	4	main
riiul	doc_491521501747_item	2467529	et	4	main
18	doc_491521501747_item	2467530	et	2	main
tuppa	doc_491521501747_item	2467535	et	3	main
in	doc_491521501747_item	2467537	et	4	main
19	doc_491521501747_item	2467539	et	2	main
kivi	doc_491521501747_item	2467544	et	4	main
tüdrukusse	doc_491521501747_item	2467549	et	4	main
sündinud	doc_491521501747_item	2467569	et	4	main
kas	doc_491521501747_item	2467572	et	3	main
läbi	doc_491521501747_item	2467584	et	4	main
elasime	doc_491521501747_item	2467587	et	3	main
kaks	doc_491521501747_item	2467590	et	3	main
nad	doc_491521501747_item	2467593	et	3	main
sööma	doc_491521501747_item	2467596	et	4	main
juba	doc_491521501747_item	2467597	et	3	main
me	doc_491521501747_item	2467601	et	4	main
tule	doc_491521501747_item	2467531	et	4	main
poiss	doc_491521501747_item	2467546	et	3	main
tüdruk	doc_491521501747_item	2467550	et	3	main
ii	doc_491521501747_item	2467551	et	4	main
pane	doc_491521501747_item	2467552	et	4	main
sõnad	doc_491521501747_item	2467553	et	4	main
lihtminevikku	doc_491521501747_item	2467554	et	4	main
imperfekti	doc_491521501747_item	2467555	et	4	main
täis-	doc_491521501747_item	2467556	et	4	main
või	doc_491521501747_item	2467557	et	4	main
enneminevikku	doc_491521501747_item	2467558	et	4	main
1	doc_491521501747_item	2467559	et	2	main
käima	doc_491521501747_item	2467562	et	4	main
sa	doc_491521501747_item	2467567	et	3	main
olid	doc_491521501747_item	2467574	et	4	main
siin	doc_491521501747_item	2467578	et	4	main
lugi	doc_491521501747_item	2467581	et	4	main
5	doc_491521501747_item	2467585	et	2	main
me	doc_491521501747_item	2467586	et	4	main
elama	doc_491521501747_item	2467588	et	3	main
aastat	doc_491521501747_item	2467591	et	3	main
7	doc_491521501747_item	2467600	et	2	main
kui	doc_491521501747_item	2467604	et	3	main
8	doc_491521501747_item	2467610	et	2	main
sa	doc_491521501747_item	2467612	et	3	main
juba	doc_491521501747_item	2467616	et	3	main
tahtsin	doc_491521501747_item	2467621	et	3	main
sulle	doc_491521501747_item	2467624	et	3	main
aga	doc_491521501747_item	2467627	et	3	main
sind	doc_491521501747_item	2467629	et	4	main
kodus	doc_491521501747_item	2467633	et	4	main
saama	doc_491521501747_item	2467637	et	4	main
endale	doc_491521501747_item	2467638	et	4	main
uue	doc_491521501747_item	2467639	et	3	main
auto	doc_491521501747_item	2467640	et	4	main
kui	doc_491521501747_item	2467645	et	3	main
vaja	doc_491521501747_item	2467649	et	4	main
3	doc_491521501747_item	2467656	et	2	main
sa	doc_491521501747_item	2467658	et	3	main
lähed	doc_491521501747_item	2467660	et	3	main
kas	doc_491521501747_item	2467662	et	3	main
sulle	doc_491521501747_item	2467663	et	3	main
meeldib	doc_491521501747_item	2467664	et	3	main
muusikat	doc_491521501747_item	2467665	et	3	main
kuulata	doc_491521501747_item	2467666	et	4	main
5	doc_491521501747_item	2467667	et	2	main
millepa	doc_491521501747_item	2467673	et	4	main
tartusse	doc_491521501747_item	2467675	et	3	main
mitu	doc_491521501747_item	2467688	et	4	main
10	doc_491521501747_item	2467692	et	2	main
iv	doc_491521501747_item	2467697	et	4	main
pane	doc_491521501747_item	2467698	et	4	main
õiged	doc_491521501747_item	2467699	et	3	main
kas	doc_491521501747_item	2467611	et	3	main
näinud	doc_491521501747_item	2467614	et	4	main
9	doc_491521501747_item	2467619	et	2	main
tahtma	doc_491521501747_item	2467622	et	3	main
tulla	doc_491521501747_item	2467626	et	3	main
olema	doc_491521501747_item	2467632	et	4	main
ma	doc_491521501747_item	2467635	et	3	main
iii	doc_491521501747_item	2467641	et	4	main
läheb	doc_491521501747_item	2467655	et	3	main
kust	doc_491521501747_item	2467657	et	4	main
ära	doc_491521501747_item	2467659	et	4	main
8	doc_491521501747_item	2467681	et	2	main
mis	doc_491521501747_item	2467682	et	4	main
kellega	doc_491521501747_item	2467683	et	3	main
sul	doc_491521501747_item	2467690	et	3	main
ees-	doc_491521501747_item	2467700	et	4	main
ja	doc_491521501747_item	2467701	et	3	main
tagasõnad	doc_491521501747_item	2467702	et	3	main
1	doc_491521501747_item	2467703	et	2	main
pärast	doc_491521501747_item	2467704	et	4	main
eesti	doc_491521501747_item	2467705	et	4	main
keele	doc_491521501747_item	2467706	et	4	main
koju	doc_491521501747_item	2467710	et	3	main
ukse	doc_491521501747_item	2467734	et	3	main
koputab	doc_491521501747_item	2467737	et	3	main
minu	doc_491521501747_item	2467739	et	3	main
istub	doc_491521501747_item	2467742	et	3	main
all	doc_491521501747_item	2467744	et	3	main
mere	doc_491521501747_item	2467746	et	3	main
ülle	doc_491521501747_item	2467749	et	4	main
kaheteistkümnes	doc_491521501747_item	2467754	et	4	main
56	doc_491521501747_item	2467755	et	2	main
viiekümnekuues	doc_491521501747_item	2467756	et	3	main
98	doc_491521501747_item	2467757	et	2	main
esimendal	doc_491521501747_item	2467778	et	4	main
8765	doc_491521501747_item	2467779	et	2	main
vi	doc_491521501747_item	2467788	et	4	main
kas	doc_491521501747_item	2467789	et	3	main
mas	doc_491521501747_item	2467790	et	4	main
vaatama	doc_491521501747_item	2467801	et	3	main
tööd	doc_491521501747_item	2467806	et	4	main
mul	doc_491521501747_item	2467810	et	3	main
homseks	doc_491521501747_item	2467812	et	3	main
4	doc_491521501747_item	2467816	et	2	main
suusatamast	doc_491521501747_item	2467819	et	3	main
suusatama	doc_491521501747_item	2467820	et	3	main
tule	doc_491521501747_item	2467822	et	4	main
1	doc_491521501747_item	2467831	et	2	main
poeg	doc_491521501747_item	2467832	et	3	main
on	doc_491521501747_item	2467833	et	4	main
on	doc_491521501747_item	2467840	et	4	main
mulle	doc_491521501747_item	2467841	et	4	main
3	doc_491521501747_item	2467846	et	2	main
kui	doc_491521501747_item	2467851	et	3	main
töötama	doc_491521501747_item	2467876	et	3	main
eesti	doc_491521501747_item	2467881	et	4	main
keelt	doc_491521501747_item	2467882	et	4	main
rääkima	doc_491521501747_item	2467884	et	3	main
tegema	doc_491521501747_item	2467890	et	3	main
õppima	doc_491521501747_item	2467904	et	3	main
kahjuks	doc_491521501747_item	2467628	et	4	main
pane	doc_491521501747_item	2467642	et	4	main
palju	doc_491521501747_item	2467646	et	4	main
seda	doc_491521501747_item	2467648	et	3	main
millal	doc_491521501747_item	2467672	et	3	main
7	doc_491521501747_item	2467677	et	2	main
last	doc_491521501747_item	2467689	et	4	main
mis	doc_491521501747_item	2467693	et	4	main
on	doc_491521501747_item	2467694	et	4	main
sinu	doc_491521501747_item	2467695	et	3	main
aadress	doc_491521501747_item	2467696	et	3	main
ma	doc_491521501747_item	2467708	et	3	main
me	doc_491521501747_item	2467712	et	4	main
jalutame	doc_491521501747_item	2467713	et	3	main
läbi	doc_491521501747_item	2467714	et	4	main
pargi	doc_491521501747_item	2467715	et	4	main
3	doc_491521501747_item	2467716	et	2	main
lennuk	doc_491521501747_item	2467717	et	3	main
lendab	doc_491521501747_item	2467718	et	3	main
linna	doc_491521501747_item	2467719	et	4	main
ülle	doc_491521501747_item	2467720	et	4	main
4laua	doc_491521501747_item	2467721	et	3	main
ja	doc_491521501747_item	2467729	et	3	main
mitmes	doc_491521501747_item	2467752	et	4	main
12	doc_491521501747_item	2467753	et	2	main
kolmekümnendal	doc_491521501747_item	2467774	et	4	main
kahesaja	doc_491521501747_item	2467776	et	4	main
neljakümne	doc_491521501747_item	2467777	et	4	main
kuuekümne	doc_491521501747_item	2467783	et	4	main
uut	doc_491521501747_item	2467798	et	3	main
tegema	doc_491521501747_item	2467808	et	3	main
on	doc_491521501747_item	2467811	et	4	main
veel	doc_491521501747_item	2467813	et	4	main
õppima	doc_491521501747_item	2467814	et	3	main
raamatuid	doc_491521501747_item	2467725	et	3	main
istub	doc_491521501747_item	2467727	et	3	main
seisab	doc_491521501747_item	2467733	et	3	main
ja	doc_491521501747_item	2467736	et	3	main
7tule	doc_491521501747_item	2467738	et	4	main
juurde	doc_491521501747_item	2467740	et	4	main
ärde	doc_491521501747_item	2467747	et	4	main
10jalutame	doc_491521501747_item	2467748	et	3	main
silla	doc_491521501747_item	2467750	et	3	main
v	doc_491521501747_item	2467751	et	4	main
saja	doc_491521501747_item	2467760	et	4	main
1453	doc_491521501747_item	2467762	et	2	main
tuhande	doc_491521501747_item	2467763	et	3	main
neljasaja	doc_491521501747_item	2467764	et	4	main
viiekümnekolmas	doc_491521501747_item	2467765	et	4	main
mitmendal	doc_491521501747_item	2467766	et	3	main
1987a	doc_491521501747_item	2467767	et	4	main
tuhande	doc_491521501747_item	2467768	et	3	main
üheksasaja	doc_491521501747_item	2467769	et	4	main
kaheksakümne	doc_491521501747_item	2467770	et	4	main
seitsmendal	doc_491521501747_item	2467771	et	3	main
a	doc_491521501747_item	2467772	et	4	main
241	doc_491521501747_item	2467775	et	2	main
kaheksa	doc_491521501747_item	2467780	et	4	main
viiendal	doc_491521501747_item	2467784	et	3	main
seitsmekümne	doc_491521501747_item	2467786	et	4	main
1	doc_491521501747_item	2467795	et	2	main
lähen	doc_491521501747_item	2467796	et	3	main
praegu	doc_491521501747_item	2467804	et	3	main
3	doc_491521501747_item	2467809	et	2	main
õppima	doc_491521501747_item	2467815	et	3	main
poiss	doc_491521501747_item	2467817	et	3	main
tuleb	doc_491521501747_item	2467818	et	3	main
5	doc_491521501747_item	2467821	et	2	main
minuga	doc_491521501747_item	2467823	et	3	main
kingitusi	doc_491521501747_item	2467825	et	4	main
ostma	doc_491521501747_item	2467826	et	3	main
ostma	doc_491521501747_item	2467827	et	3	main
vii	doc_491521501747_item	2467828	et	4	main
vana	doc_491521501747_item	2467835	et	4	main
kui	doc_491521501747_item	2467836	et	3	main
tütar	doc_491521501747_item	2467837	et	3	main
2	doc_491521501747_item	2467838	et	2	main
kui	doc_491521501747_item	2467844	et	3	main
kallis	doc_491521501747_item	2467850	et	4	main
poiss	doc_491521501747_item	2467854	et	3	main
kas	doc_491521501747_item	2467878	et	3	main
oskad	doc_491521501747_item	2467880	et	3	main
rääkida	doc_491521501747_item	2467883	et	3	main
3	doc_491521501747_item	2467885	et	2	main
hakkame	doc_491521501747_item	2467886	et	3	main
nüüd	doc_491521501747_item	2467887	et	4	main
mulle	doc_491521501747_item	2467892	et	4	main
palju	doc_491521501747_item	2467902	et	4	main
õppida	doc_491521501747_item	2467903	et	3	main
eesti	doc_491521501749_item	2468135	et	4	main
veaanalüüs	doc_491521501749_item	2468146	et	4	main
on	doc_491521501749_item	2468147	et	4	main
abivahend	doc_491521501749_item	2468149	et	3	main
keele	doc_491521501749_item	2468150	et	4	main
õppijale	doc_491521501749_item	2468151	et	4	main
ja	doc_491521501749_item	2468152	et	3	main
ka	doc_491521501749_item	2468153	et	3	main
põhjal	doc_491521501749_item	2468159	et	4	main
keeleoskusest	doc_491521501749_item	2468162	et	4	main
saavutustest	doc_491521501749_item	2468164	et	4	main
selle	doc_491521501749_item	2468167	et	4	main
kohta	doc_491521501749_item	2468168	et	4	main
millele	doc_491521501749_item	2468169	et	3	main
edasises	doc_491521501749_item	2468170	et	3	main
tähelepanu	doc_491521501749_item	2468173	et	4	main
enda	doc_491521501749_item	2468188	et	4	main
tööd	doc_491521501749_item	2468189	et	4	main
milliste	doc_491521501749_item	2468190	et	3	main
koos	doc_491521501747_item	2467824	et	4	main
vanem	doc_491521501747_item	2467834	et	4	main
armsam	doc_491521501747_item	2467842	et	4	main
armas	doc_491521501747_item	2467843	et	3	main
maja	doc_491521501747_item	2467847	et	4	main
4	doc_491521501747_item	2467853	et	2	main
kui	doc_491521501747_item	2467858	et	3	main
tüdruk	doc_491521501747_item	2467859	et	3	main
raamat	doc_491521501747_item	2467861	et	3	main
on	doc_491521501747_item	2467862	et	4	main
parem	doc_491521501747_item	2467863	et	4	main
hea	doc_491521501747_item	2467864	et	4	main
kui	doc_491521501747_item	2467865	et	3	main
film	doc_491521501747_item	2467866	et	3	main
viii	doc_491521501747_item	2467867	et	4	main
kas	doc_491521501747_item	2467868	et	3	main
ma-	doc_491521501747_item	2467869	et	3	main
või	doc_491521501747_item	2467870	et	4	main
da-infinitiv	doc_491521501747_item	2467871	et	4	main
1ma	doc_491521501747_item	2467872	et	3	main
palju	doc_491521501747_item	2467874	et	4	main
tahan	doc_491521501747_item	2467873	et	3	main
töötada	doc_491521501747_item	2467875	et	3	main
2	doc_491521501747_item	2467877	et	2	main
sa	doc_491521501747_item	2467879	et	3	main
harjutust	doc_491521501747_item	2467888	et	4	main
meeldi	doc_491521501747_item	2467894	et	4	main
mul	doc_491521501747_item	2467899	et	3	main
on	doc_491521501747_item	2467900	et	4	main
õppetool	doc_491521501749_item	2468139	et	3	main
veaanalüüs	doc_491521501749_item	2468142	et	4	main
õppija	doc_491521501749_item	2468156	et	4	main
saab	doc_491521501749_item	2468157	et	3	main
selle	doc_491521501749_item	2468158	et	4	main
oma	doc_491521501749_item	2468161	et	4	main
infot	doc_491521501749_item	2468166	et	3	main
rohkem	doc_491521501749_item	2468172	et	4	main
õpetaja	doc_491521501749_item	2468175	et	4	main
põhjal	doc_491521501749_item	2468178	et	4	main
ühe	doc_491521501749_item	2468203	et	4	main
e	doc_491521501749_item	2468209	et	4	main
on	doc_491521501749_item	2468214	et	4	main
kirjeldusi	doc_491521501749_item	2468221	et	4	main
klassist	doc_491521501749_item	2468231	et	3	main
välja	doc_491521501749_item	2468235	et	4	main
erinevat	doc_491521501749_item	2468236	et	4	main
rühmitatud	doc_491521501749_item	2468241	et	4	main
keeletasandite	doc_491521501749_item	2468242	et	3	main
kaupa	doc_491521501749_item	2468243	et	4	main
1	doc_491521501749_item	2468244	et	2	main
kuna	doc_491521501749_item	2468253	et	3	main
tegemist	doc_491521501749_item	2468254	et	4	main
on	doc_491521501749_item	2468255	et	4	main
veatüübid	doc_491521501749_item	2468284	et	4	main
ja	doc_491521501749_item	2468287	et	3	main
vea	doc_491521501749_item	2468310	et	4	main
intralingvaalseteks	doc_491521501749_item	2468318	et	4	main
on	doc_491521501749_item	2468320	et	4	main
õpitava	doc_491521501749_item	2468322	et	4	main
keele	doc_491521501749_item	2468323	et	4	main
teised	doc_491521501749_item	2468325	et	4	main
mitu	doc_491521501749_item	2468335	et	4	main
osas	doc_491521501749_item	2468344	et	4	main
häälikutasandi	doc_491521501749_item	2468345	et	4	main
suurema	doc_491521501749_item	2468349	et	4	main
vale	doc_491521501749_item	2468351	et	4	main
pensionäär	doc_491521501749_item	2468357	et	4	main
rõhk	doc_491521501749_item	2468358	et	3	main
on	doc_491521501749_item	2468359	et	4	main
sarnaselt	doc_491521501749_item	2468360	et	4	main
tegema	doc_491521501747_item	2467889	et	3	main
vaja	doc_491521501747_item	2467901	et	4	main
võõrkeele	doc_491521501749_item	2468138	et	4	main
keele	doc_491521501749_item	2468136	et	4	main
kui	doc_491521501749_item	2468137	et	3	main
2003	doc_491521501749_item	2468144	et	2	main
oluline	doc_491521501749_item	2468148	et	4	main
ja	doc_491521501749_item	2468163	et	3	main
ning	doc_491521501749_item	2468165	et	3	main
keeleõppimises	doc_491521501749_item	2468171	et	3	main
veaanalüüsi	doc_491521501749_item	2468177	et	4	main
mida	doc_491521501749_item	2468194	et	4	main
analüüsitakse	doc_491521501749_item	2468202	et	4	main
klassi	doc_491521501749_item	2468208	et	4	main
eri	doc_491521501749_item	2468215	et	4	main
muinasjutte	doc_491521501749_item	2468217	et	3	main
analüüs	doc_491521501749_item	2468132	et	3	main
tallinna	doc_491521501749_item	2468133	et	4	main
pedagoogikaülikool	doc_491521501749_item	2468134	et	4	main
sissejuhatus	doc_491521501749_item	2468145	et	4	main
õpetajale	doc_491521501749_item	2468155	et	4	main
pöörata	doc_491521501749_item	2468174	et	4	main
hinnata	doc_491521501749_item	2468179	et	4	main
nii	doc_491521501749_item	2468180	et	3	main
rühma	doc_491521501749_item	2468181	et	4	main
kui	doc_491521501749_item	2468182	et	3	main
ka	doc_491521501749_item	2468183	et	3	main
tegelda	doc_491521501749_item	2468193	et	4	main
halvemini	doc_491521501749_item	2468198	et	4	main
õpetatud	doc_491521501749_item	2468199	et	4	main
käesolevas	doc_491521501749_item	2468200	et	3	main
töös	doc_491521501749_item	2468201	et	3	main
kooli	doc_491521501749_item	2468206	et	4	main
46	doc_491521501749_item	2468207	et	2	main
töid	doc_491521501749_item	2468213	et	3	main
kirju	doc_491521501749_item	2468218	et	4	main
lühikirjandeid	doc_491521501749_item	2468219	et	3	main
ja	doc_491521501749_item	2468220	et	3	main
on	doc_491521501749_item	2468223	et	4	main
eesti	doc_491521501749_item	2468224	et	4	main
keelt	doc_491521501749_item	2468225	et	4	main
käigus	doc_491521501749_item	2468233	et	4	main
need	doc_491521501749_item	2468239	et	3	main
ortograafiavead	doc_491521501749_item	2468249	et	4	main
eristatud	doc_491521501749_item	2468252	et	4	main
küll	doc_491521501749_item	2468258	et	4	main
on	doc_491521501749_item	2468280	et	4	main
tähenduse	doc_491521501749_item	2468286	et	4	main
või	doc_491521501749_item	2468295	et	4	main
uusmoodustis	doc_491521501749_item	2468296	et	4	main
vigade	doc_491521501749_item	2468299	et	3	main
oletada	doc_491521501749_item	2468307	et	3	main
vigade	doc_491521501749_item	2468312	et	3	main
on	doc_491521501749_item	2468314	et	4	main
jaotatud	doc_491521501749_item	2468315	et	4	main
emakeele	doc_491521501749_item	2468326	et	4	main
eri	doc_491521501749_item	2468336	et	4	main
viga	doc_491521501749_item	2468338	et	4	main
vead	doc_491521501749_item	2468346	et	4	main
silbile	doc_491521501749_item	2468365	et	3	main
keeles	doc_491521501749_item	2468376	et	4	main
tuleb	doc_491521501749_item	2468413	et	3	main
kirjutusviis	doc_491521501749_item	2468418	et	3	main
see	doc_491521501749_item	2468419	et	3	main
emakeelega	doc_491521501749_item	2468422	et	3	main
keele	doc_491521501749_item	2468424	et	4	main
õppijate	doc_491521501749_item	2468425	et	4	main
üks	doc_491521501749_item	2468426	et	3	main
järgsilbi	doc_491521501749_item	2468433	et	4	main
a	doc_491521501749_item	2468434	et	4	main
kirjutatud	doc_491521501749_item	2468437	et	4	main
eesti	doc_491521501749_item	2468443	et	4	main
nö	doc_491521501749_item	2468452	et	4	main
on	doc_491521501749_item	2468457	et	4	main
ja	doc_491521501749_item	2468468	et	3	main
kirjapilt	doc_491521501749_item	2468472	et	3	main
sihitisekäände	doc_491521501749_item	2468506	et	4	main
tekitab	doc_491521501749_item	2468508	et	3	main
kauem	doc_491521501749_item	2468512	et	4	main
eesti	doc_491521501749_item	2468513	et	4	main
ehitab	doc_491521501749_item	2468518	et	3	main
ilmselt	doc_491521501749_item	2468533	et	4	main
õpitud	doc_491521501749_item	2468539	et	4	main
käände	doc_491521501749_item	2468548	et	4	main
on	doc_491521501749_item	2468553	et	4	main
laiendid	doc_491521501749_item	2468565	et	3	main
pidada	doc_491521501749_item	2468582	et	4	main
emakeele	doc_491521501749_item	2468583	et	4	main
ole	doc_491521501749_item	2468597	et	4	main
süstemaatilised	doc_491521501749_item	2468598	et	3	main
seega	doc_491521501749_item	2468599	et	4	main
eesnimi	doc_491521501749_item	2468140	et	3	main
perekonnanimi	doc_491521501749_item	2468141	et	3	main
tallinn	doc_491521501749_item	2468143	et	4	main
keele	doc_491521501749_item	2468154	et	4	main
tagasisidet	doc_491521501749_item	2468160	et	4	main
saab	doc_491521501749_item	2468176	et	3	main
iga	doc_491521501749_item	2468184	et	4	main
õpilase	doc_491521501749_item	2468185	et	3	main
keeleoskust	doc_491521501749_item	2468186	et	3	main
ning	doc_491521501749_item	2468187	et	3	main
on	doc_491521501749_item	2468195	et	4	main
hästi	doc_491521501749_item	2468196	et	3	main
väikse	doc_491521501749_item	2468204	et	4	main
ida-virumaa	doc_491521501749_item	2468205	et	4	main
kooliastme	doc_491521501749_item	2468211	et	3	main
loovtöid	doc_491521501749_item	2468212	et	3	main
õpilased	doc_491521501749_item	2468222	et	3	main
esimesest	doc_491521501749_item	2468230	et	3	main
tüüpi	doc_491521501749_item	2468237	et	4	main
vead	doc_491521501749_item	2468238	et	4	main
on	doc_491521501749_item	2468240	et	4	main
välja	doc_491521501749_item	2468247	et	4	main
hääldusvigu	doc_491521501749_item	2468250	et	3	main
nii	doc_491521501749_item	2468261	et	3	main
vormivalikuvigu	doc_491521501749_item	2468277	et	3	main
segunemine	doc_491521501749_item	2468290	et	4	main
on	doc_491521501749_item	2468301	et	4	main
mis	doc_491521501749_item	2468308	et	4	main
põhjuseks	doc_491521501749_item	2468311	et	3	main
põhjused	doc_491521501749_item	2468313	et	3	main
inter-	doc_491521501749_item	2468316	et	3	main
tekkinud	doc_491521501749_item	2468321	et	4	main
ja	doc_491521501749_item	2468324	et	3	main
selliseid	doc_491521501749_item	2468339	et	4	main
vigu	doc_491521501749_item	2468340	et	3	main
analüüsitakse	doc_491521501749_item	2468341	et	4	main
ortograafiavigadest	doc_491521501749_item	2468347	et	4	main
häälduse	doc_491521501749_item	2468352	et	4	main
tekkinud	doc_491521501749_item	2468354	et	4	main
viimasele	doc_491521501749_item	2468364	et	3	main
kirjutatud	doc_491521501749_item	2468377	et	4	main
omase	doc_491521501749_item	2468409	et	3	main
rõhuga	doc_491521501749_item	2468411	et	3	main
vale	doc_491521501749_item	2468415	et	4	main
hääldus	doc_491521501749_item	2468416	et	4	main
on	doc_491521501749_item	2468420	et	4	main
vene	doc_491521501749_item	2468421	et	4	main
eesti	doc_491521501749_item	2468423	et	4	main
jts	doc_491521501749_item	2468432	et	4	main
e	doc_491521501749_item	2468438	et	4	main
võib	doc_491521501749_item	2468440	et	3	main
järgsilbi	doc_491521501749_item	2468449	et	4	main
ebamääraseks	doc_491521501749_item	2468451	et	4	main
ei	doc_491521501749_item	2468453	et	4	main
jätku	doc_491521501749_item	2468454	et	4	main
hääldusenergiat	doc_491521501749_item	2468455	et	3	main
vene	doc_491521501749_item	2468467	et	4	main
erinev	doc_491521501749_item	2468471	et	4	main
ekslikult	doc_491521501749_item	2468473	et	4	main
ka	doc_491521501749_item	2468510	et	3	main
õppinud	doc_491521501749_item	2468515	et	4	main
lumememm	doc_491521501749_item	2468519	et	3	main
ei	doc_491521501749_item	2468521	et	4	main
vene	doc_491521501749_item	2468530	et	4	main
ole	doc_491521501749_item	2468535	et	4	main
nende	doc_491521501749_item	2468541	et	4	main
on	doc_491521501749_item	2468543	et	4	main
juhuslik	doc_491521501749_item	2468544	et	3	main
hirmutab	doc_491521501749_item	2468545	et	3	main
esineb	doc_491521501749_item	2468556	et	3	main
laiendi	doc_491521501749_item	2468558	et	3	main
käändevaliku	doc_491521501749_item	2468559	et	4	main
vigu	doc_491521501749_item	2468560	et	3	main
palju	doc_491521501749_item	2468561	et	4	main
pandud	doc_491521501749_item	2468567	et	4	main
osastavasse	doc_491521501749_item	2468572	et	4	main
ka	doc_491521501749_item	2468574	et	3	main
tarindite	doc_491521501749_item	2468576	et	3	main
mõju	doc_491521501749_item	2468584	et	4	main
sest	doc_491521501749_item	2468585	et	4	main
vene	doc_491521501749_item	2468586	et	4	main
keelenähtustega	doc_491521501749_item	2468191	et	3	main
rohkem	doc_491521501749_item	2468192	et	4	main
mida	doc_491521501749_item	2468197	et	4	main
teise	doc_491521501749_item	2468210	et	4	main
tüüpi	doc_491521501749_item	2468216	et	4	main
õppinud	doc_491521501749_item	2468226	et	4	main
häälikutasandil	doc_491521501749_item	2468245	et	4	main
pole	doc_491521501749_item	2468251	et	3	main
töödega	doc_491521501749_item	2468257	et	3	main
aga	doc_491521501749_item	2468259	et	3	main
võib	doc_491521501749_item	2468260	et	3	main
3	doc_491521501749_item	2468278	et	2	main
lähedase	doc_491521501749_item	2468285	et	3	main
vormiga	doc_491521501749_item	2468288	et	4	main
vale	doc_491521501749_item	2468291	et	4	main
tuletusliite	doc_491521501749_item	2468292	et	4	main
valik	doc_491521501749_item	2468293	et	3	main
toorlaen	doc_491521501749_item	2468294	et	3	main
iga	doc_491521501749_item	2468297	et	4	main
püütud	doc_491521501749_item	2468306	et	4	main
ja	doc_491521501749_item	2468317	et	3	main
4-6	doc_491521501749_item	2468227	et	2	main
aastat	doc_491521501749_item	2468228	et	3	main
alates	doc_491521501749_item	2468229	et	3	main
analüüsi	doc_491521501749_item	2468232	et	4	main
tuuakse	doc_491521501749_item	2468234	et	3	main
on	doc_491521501749_item	2468246	et	4	main
toodud	doc_491521501749_item	2468248	et	4	main
kirjalike	doc_491521501749_item	2468256	et	3	main
mõnegi	doc_491521501749_item	2468262	et	3	main
vea	doc_491521501749_item	2468263	et	4	main
puhul	doc_491521501749_item	2468264	et	4	main
oletada	doc_491521501749_item	2468265	et	3	main
et	doc_491521501749_item	2468266	et	3	main
selle	doc_491521501749_item	2468267	et	4	main
on	doc_491521501749_item	2468268	et	4	main
põhjustanud	doc_491521501749_item	2468269	et	4	main
hääldusviga	doc_491521501749_item	2468270	et	4	main
2	doc_491521501749_item	2468271	et	2	main
grammatikatasandil	doc_491521501749_item	2468272	et	3	main
on	doc_491521501749_item	2468273	et	4	main
eristatud	doc_491521501749_item	2468274	et	4	main
vormimoodustus-	doc_491521501749_item	2468275	et	3	main
ja	doc_491521501749_item	2468276	et	3	main
sõnatasandil	doc_491521501749_item	2468279	et	3	main
välja	doc_491521501749_item	2468281	et	4	main
toodud	doc_491521501749_item	2468282	et	4	main
järgmised	doc_491521501749_item	2468283	et	3	main
sõnade	doc_491521501749_item	2468289	et	3	main
tasandi	doc_491521501749_item	2468298	et	3	main
kirjeldamisel	doc_491521501749_item	2468300	et	4	main
toodud	doc_491521501749_item	2468302	et	4	main
paar	doc_491521501749_item	2468303	et	3	main
näidet	doc_491521501749_item	2468304	et	3	main
ning	doc_491521501749_item	2468305	et	3	main
on	doc_491521501749_item	2468309	et	4	main
esimesed	doc_491521501749_item	2468319	et	3	main
mõjul	doc_491521501749_item	2468327	et	4	main
analüüsitud	doc_491521501749_item	2468328	et	4	main
töödes	doc_491521501749_item	2468329	et	3	main
leidub	doc_491521501749_item	2468330	et	3	main
keelendeid	doc_491521501749_item	2468331	et	4	main
kus	doc_491521501749_item	2468332	et	3	main
on	doc_491521501749_item	2468333	et	4	main
tõttu	doc_491521501749_item	2468353	et	4	main
vead	doc_491521501749_item	2468355	et	4	main
kuna	doc_491521501749_item	2468367	et	3	main
eesti	doc_491521501749_item	2468375	et	4	main
nii	doc_491521501749_item	2468414	et	3	main
kui	doc_491521501749_item	2468417	et	3	main
tehtud	doc_491521501749_item	2468334	et	4	main
keeletasandi	doc_491521501749_item	2468337	et	3	main
töö	doc_491521501749_item	2468342	et	4	main
viimases	doc_491521501749_item	2468343	et	3	main
moodustavad	doc_491521501749_item	2468348	et	4	main
osa	doc_491521501749_item	2468350	et	4	main
nt	doc_491521501749_item	2468356	et	4	main
sõnale	doc_491521501749_item	2468362	et	3	main
vene	doc_491521501749_item	2468368	et	4	main
rõhk	doc_491521501749_item	2468370	et	3	main
on	doc_491521501749_item	2468371	et	4	main
kvantitatiivne	doc_491521501749_item	2468372	et	3	main
siis	doc_491521501749_item	2468373	et	3	main
on	doc_491521501749_item	2468374	et	4	main
ehtima	doc_491521501749_item	2468381	et	4	main
vene	doc_491521501749_item	2468382	et	4	main
keelele	doc_491521501749_item	2468383	et	4	main
on	doc_491521501749_item	2468384	et	4	main
võõras	doc_491521501749_item	2468385	et	4	main
lühikeste	doc_491521501749_item	2468386	et	4	main
ja	doc_491521501749_item	2468387	et	3	main
pikkade	doc_491521501749_item	2468388	et	4	main
häälikute	doc_491521501749_item	2468389	et	3	main
opositsioon	doc_491521501749_item	2468390	et	3	main
see	doc_491521501749_item	2468391	et	3	main
on	doc_491521501749_item	2468392	et	4	main
põhjustanud	doc_491521501749_item	2468394	et	4	main
nii	doc_491521501749_item	2468395	et	3	main
ilmselt	doc_491521501749_item	2468393	et	4	main
lühikese	doc_491521501749_item	2468396	et	4	main
häälduse	doc_491521501749_item	2468397	et	4	main
kui	doc_491521501749_item	2468398	et	3	main
ka	doc_491521501749_item	2468399	et	3	main
kirjutuse	doc_491521501749_item	2468400	et	4	main
tüütter	doc_491521501749_item	2468401	et	4	main
tütar	doc_491521501749_item	2468402	et	3	main
ka	doc_491521501749_item	2468403	et	3	main
siin	doc_491521501749_item	2468404	et	4	main
on	doc_491521501749_item	2468405	et	4	main
tegemist	doc_491521501749_item	2468406	et	4	main
vene	doc_491521501749_item	2468407	et	4	main
keelele	doc_491521501749_item	2468408	et	4	main
vene	doc_491521501749_item	2468361	et	4	main
pandud	doc_491521501749_item	2468363	et	4	main
ning	doc_491521501749_item	2468366	et	3	main
keele	doc_491521501749_item	2468369	et	4	main
pikk	doc_491521501749_item	2468378	et	4	main
ä	doc_491521501749_item	2468379	et	4	main
kuske	doc_491521501749_item	2468380	et	3	main
kvantitatiivse	doc_491521501749_item	2468410	et	3	main
millest	doc_491521501749_item	2468412	et	3	main
iisa	doc_491521501749_item	2468430	et	4	main
teere	doc_491521501749_item	2468431	et	4	main
mille	doc_491521501749_item	2468439	et	3	main
olla	doc_491521501749_item	2468441	et	3	main
keelele	doc_491521501749_item	2468444	et	4	main
omane	doc_491521501749_item	2468445	et	3	main
hääldus	doc_491521501749_item	2468446	et	4	main
vokaalid	doc_491521501749_item	2468450	et	3	main
sõna	doc_491521501749_item	2468458	et	4	main
jäänud	doc_491521501749_item	2468462	et	4	main
eesti	doc_491521501749_item	2468469	et	4	main
tähtede	doc_491521501749_item	2468470	et	4	main
kasutatakse	doc_491521501749_item	2468474	et	3	main
vead	doc_491521501749_item	2468505	et	4	main
raskusi	doc_491521501749_item	2468509	et	4	main
palju	doc_491521501749_item	2468511	et	4	main
keelt	doc_491521501749_item	2468514	et	4	main
selles	doc_491521501749_item	2468526	et	4	main
tarindis	doc_491521501749_item	2468527	et	3	main
ei	doc_491521501749_item	2468528	et	4	main
kasutata	doc_491521501749_item	2468529	et	3	main
ei	doc_491521501749_item	2468534	et	4	main
veel	doc_491521501749_item	2468537	et	4	main
põhjus	doc_491521501749_item	2468550	et	4	main
antud	doc_491521501749_item	2468551	et	4	main
tarindis	doc_491521501749_item	2468552	et	3	main
palju	doc_491521501749_item	2468555	et	4	main
hulgafraasi	doc_491521501749_item	2468557	et	4	main
mitmusesse	doc_491521501749_item	2468569	et	4	main
mitte	doc_491521501749_item	2468571	et	3	main
puhul	doc_491521501749_item	2468577	et	4	main
saa	doc_491521501749_item	2468579	et	4	main
põhjuseks	doc_491521501749_item	2468581	et	3	main
konstruktsioonides	doc_491521501749_item	2468590	et	3	main
nimetatud	doc_491521501749_item	2468594	et	4	main
neid	doc_491521501749_item	2468600	et	4	main
ole	doc_491521501749_item	2468629	et	4	main
see	doc_491521501749_item	2468635	et	3	main
sõna	doc_491521501749_item	2468636	et	4	main
narvas	doc_491521501749_item	2468645	et	4	main
ilmselt	doc_491521501749_item	2468650	et	4	main
et	doc_491521501749_item	2468658	et	3	main
reeglit	doc_491521501749_item	2468671	et	3	main
pargist	doc_491521501749_item	2468680	et	3	main
põhjus	doc_491521501749_item	2468684	et	4	main
keeles	doc_491521501749_item	2468695	et	4	main
põhilisi	doc_491521501749_item	2468427	et	3	main
hääldusvigu	doc_491521501749_item	2468428	et	3	main
mis	doc_491521501749_item	2468447	et	4	main
õppijale	doc_491521501749_item	2468456	et	4	main
valesti	doc_491521501749_item	2468460	et	3	main
eestikeelses	doc_491521501749_item	2468475	et	3	main
tekstis	doc_491521501749_item	2468476	et	3	main
vene	doc_491521501749_item	2468477	et	4	main
tähti	doc_491521501749_item	2468478	et	4	main
nt	doc_491521501749_item	2468479	et	4	main
kaebur	doc_491521501749_item	2468480	et	4	main
kaevur	doc_491521501749_item	2468481	et	3	main
see	doc_491521501749_item	2468482	et	3	main
on	doc_491521501749_item	2468483	et	4	main
aga	doc_491521501749_item	2468484	et	3	main
rohkem	doc_491521501749_item	2468485	et	4	main
eksitus	doc_491521501749_item	2468486	et	4	main
kui	doc_491521501749_item	2468487	et	3	main
ränk	doc_491521501749_item	2468488	et	3	main
viga	doc_491521501749_item	2468489	et	4	main
sest	doc_491521501749_item	2468490	et	4	main
ei	doc_491521501749_item	2468491	et	4	main
takista	doc_491521501749_item	2468492	et	4	main
arusaamist	doc_491521501749_item	2468493	et	4	main
grammatikatasandi	doc_491521501749_item	2468494	et	3	main
vead	doc_491521501749_item	2468495	et	4	main
grammatikatasandi	doc_491521501749_item	2468496	et	3	main
vead	doc_491521501749_item	2468497	et	4	main
analüüsitud	doc_491521501749_item	2468499	et	4	main
töödes	doc_491521501749_item	2468500	et	3	main
on	doc_491521501749_item	2468498	et	4	main
kõige	doc_491521501749_item	2468501	et	4	main
sagedasemad	doc_491521501749_item	2468502	et	4	main
1	doc_491521501749_item	2468503	et	2	main
vormivaliku	doc_491521501749_item	2468504	et	3	main
eema	doc_491521501749_item	2468429	et	4	main
asemel	doc_491521501749_item	2468435	et	4	main
on	doc_491521501749_item	2468436	et	4	main
põhjustanud	doc_491521501749_item	2468442	et	4	main
jätab	doc_491521501749_item	2468448	et	3	main
ilmselt	doc_491521501749_item	2468459	et	4	main
meelde	doc_491521501749_item	2468461	et	3	main
ortograafiavigu	doc_491521501749_item	2468463	et	4	main
võib	doc_491521501749_item	2468464	et	3	main
põhjustada	doc_491521501749_item	2468465	et	3	main
ka	doc_491521501749_item	2468466	et	3	main
valik	doc_491521501749_item	2468507	et	3	main
inimestel	doc_491521501749_item	2468516	et	3	main
põhjus	doc_491521501749_item	2468520	et	4	main
sest	doc_491521501749_item	2468525	et	4	main
nominatiivi	doc_491521501749_item	2468532	et	4	main
sihitisekäändeid	doc_491521501749_item	2468536	et	4	main
valiku	doc_491521501749_item	2468549	et	3	main
kingitused	doc_491521501749_item	2468562	et	4	main
raamatud	doc_491521501749_item	2468564	et	4	main
küll	doc_491521501749_item	2468568	et	4	main
kuid	doc_491521501749_item	2468570	et	4	main
käändesse	doc_491521501749_item	2468573	et	4	main
ei	doc_491521501749_item	2468578	et	4	main
vea	doc_491521501749_item	2468580	et	4	main
keeles	doc_491521501749_item	2468587	et	4	main
kasutatakse	doc_491521501749_item	2468588	et	3	main
genitiivi	doc_491521501749_item	2468591	et	4	main
nominatiivi	doc_491521501749_item	2468593	et	4	main
jõulud	doc_491521501749_item	2468622	et	3	main
õpilane	doc_491521501749_item	2468626	et	3	main
mitmuses	doc_491521501749_item	2468637	et	3	main
mõjul	doc_491521501749_item	2468641	et	4	main
ainuslikku	doc_491521501749_item	2468643	et	4	main
vormi	doc_491521501749_item	2468644	et	4	main
on	doc_491521501749_item	2468648	et	4	main
eesti	doc_491521501749_item	2468651	et	4	main
tekkinud	doc_491521501749_item	2468654	et	4	main
teab	doc_491521501749_item	2468657	et	3	main
keeles	doc_491521501749_item	2468660	et	4	main
näitena	doc_491521501749_item	2468673	et	3	main
tuua	doc_491521501749_item	2468675	et	3	main
sellest	doc_491521501749_item	2468679	et	4	main
tarindis	doc_491521501749_item	2468686	et	3	main
sest	doc_491521501749_item	2468690	et	4	main
eesti	doc_491521501749_item	2468694	et	4	main
võib	doc_491521501749_item	2468721	et	3	main
võib	doc_491521501749_item	2468736	et	3	main
ka	doc_491521501749_item	2468739	et	3	main
hääldusest	doc_491521501749_item	2468743	et	4	main
pikkad	doc_491521501749_item	2468744	et	4	main
kardas	doc_491521501749_item	2468748	et	3	main
samuti	doc_491521501749_item	2468750	et	3	main
mineviku	doc_491521501749_item	2468752	et	3	main
tüvele	doc_491521501749_item	2468757	et	3	main
asemel	doc_491521501749_item	2468767	et	4	main
on	doc_491521501749_item	2468768	et	4	main
sisseütlevat	doc_491521501749_item	2468771	et	3	main
näites	doc_491521501749_item	2468775	et	3	main
vale	doc_491521501749_item	2468783	et	4	main
teisalt	doc_491521501749_item	2468785	et	4	main
vormi	doc_491521501749_item	2468797	et	4	main
sarnase	doc_491521501749_item	2468802	et	4	main
lähevad	doc_491521501749_item	2468816	et	3	main
tehtud	doc_491521501749_item	2468828	et	4	main
ei	doc_491521501749_item	2468832	et	4	main
ja	doc_491521501749_item	2468836	et	3	main
erinevust	doc_491521501749_item	2468839	et	4	main
sest	doc_491521501749_item	2468840	et	4	main
mõlema	doc_491521501749_item	2468841	et	3	main
on	doc_491521501749_item	2468849	et	4	main
tekkinud	doc_491521501749_item	2468864	et	4	main
kõrge	doc_491521501749_item	2468868	et	4	main
ka	doc_491521501749_item	2468878	et	3	main
keeles	doc_491521501749_item	2468880	et	4	main
dlinnyj	doc_491521501749_item	2468888	et	4	main
tõttu	doc_491521501749_item	2468893	et	4	main
vead	doc_491521501749_item	2468898	et	4	main
enesekohase	doc_491521501749_item	2468903	et	4	main
aetud	doc_491521501749_item	2468908	et	4	main
sõnaga	doc_491521501749_item	2468922	et	3	main
nt	doc_491521501749_item	2468517	et	4	main
ole	doc_491521501749_item	2468522	et	4	main
emakeele	doc_491521501749_item	2468523	et	4	main
mõju	doc_491521501749_item	2468524	et	4	main
keeles	doc_491521501749_item	2468531	et	4	main
süstemaatiliselt	doc_491521501749_item	2468538	et	4	main
ning	doc_491521501749_item	2468540	et	3	main
kasutus	doc_491521501749_item	2468542	et	4	main
inimeselt	doc_491521501749_item	2468546	et	3	main
alaltütleva	doc_491521501749_item	2468547	et	4	main
ebaselge	doc_491521501749_item	2468554	et	4	main
palju	doc_491521501749_item	2468563	et	4	main
on	doc_491521501749_item	2468566	et	4	main
nende	doc_491521501749_item	2468575	et	4	main
sellistes	doc_491521501749_item	2468589	et	4	main
mitte	doc_491521501749_item	2468592	et	3	main
vead	doc_491521501749_item	2468595	et	4	main
ei	doc_491521501749_item	2468596	et	4	main
konstruktsioone	doc_491521501749_item	2468601	et	3	main
ilmselt	doc_491521501749_item	2468602	et	4	main
parasjagu	doc_491521501749_item	2468603	et	3	main
õpitakse	doc_491521501749_item	2468604	et	4	main
ning	doc_491521501749_item	2468605	et	3	main
nad	doc_491521501749_item	2468606	et	3	main
pole	doc_491521501749_item	2468607	et	3	main
veel	doc_491521501749_item	2468608	et	4	main
täiesti	doc_491521501749_item	2468609	et	3	main
kinnistunud	doc_491521501749_item	2468610	et	4	main
vormivaliku	doc_491521501749_item	2468611	et	3	main
vigade	doc_491521501749_item	2468612	et	3	main
seas	doc_491521501749_item	2468613	et	4	main
on	doc_491521501749_item	2468614	et	4	main
ka	doc_491521501749_item	2468615	et	3	main
ühildumisvigu	doc_491521501749_item	2468616	et	4	main
meeldib	doc_491521501749_item	2468617	et	3	main
jõulud	doc_491521501749_item	2468618	et	3	main
vene	doc_491521501749_item	2468619	et	4	main
keeles	doc_491521501749_item	2468620	et	4	main
on	doc_491521501749_item	2468621	et	4	main
roždestvo	doc_491521501749_item	2468624	et	2	main
ilmselt	doc_491521501749_item	2468627	et	4	main
ei	doc_491521501749_item	2468628	et	4	main
on	doc_491521501749_item	2468634	et	4	main
emakeele	doc_491521501749_item	2468640	et	4	main
tegusõna	doc_491521501749_item	2468642	et	4	main
linnuses	doc_491521501749_item	2468646	et	4	main
siin	doc_491521501749_item	2468647	et	4	main
keele	doc_491521501749_item	2468652	et	4	main
ühte	doc_491521501749_item	2468665	et	4	main
seda	doc_491521501749_item	2468670	et	3	main
seestütleva	doc_491521501749_item	2468681	et	3	main
selge	doc_491521501749_item	2468689	et	4	main
nii	doc_491521501749_item	2468691	et	3	main
kui	doc_491521501749_item	2468693	et	3	main
verbi	doc_491521501749_item	2468698	et	4	main
rektsioon	doc_491521501749_item	2468699	et	3	main
ühesugune	doc_491521501749_item	2468700	et	3	main
ilmselt	doc_491521501749_item	2468701	et	4	main
on	doc_491521501749_item	2468702	et	4	main
lõpuvalikuvigu	doc_491521501749_item	2468725	et	3	main
mis	doc_491521501749_item	2468741	et	4	main
on	doc_491521501749_item	2468749	et	4	main
märganud	doc_491521501749_item	2468630	et	4	main
et	doc_491521501749_item	2468631	et	3	main
mistõttu	doc_491521501749_item	2468638	et	3	main
tegemist	doc_491521501749_item	2468649	et	4	main
veaga	doc_491521501749_item	2468655	et	3	main
eesti	doc_491521501749_item	2468659	et	4	main
tuleb	doc_491521501749_item	2468661	et	3	main
paljud	doc_491521501749_item	2468662	et	3	main
sõnad	doc_491521501749_item	2468663	et	4	main
lauses	doc_491521501749_item	2468664	et	3	main
laiendanud	doc_491521501749_item	2468669	et	4	main
võib	doc_491521501749_item	2468674	et	3	main
vigu	doc_491521501749_item	2468677	et	3	main
selles	doc_491521501749_item	2468685	et	4	main
pole	doc_491521501749_item	2468687	et	3	main
selle	doc_491521501749_item	2468697	et	4	main
õpilast	doc_491521501749_item	2468703	et	4	main
mõjutanud	doc_491521501749_item	2468704	et	4	main
pealkiri	doc_491521501749_item	2468705	et	3	main
minu	doc_491521501749_item	2468706	et	3	main
kodukoha	doc_491521501749_item	2468707	et	4	main
loodusest	doc_491521501749_item	2468708	et	4	main
sest	doc_491521501749_item	2468709	et	4	main
ta	doc_491521501749_item	2468710	et	4	main
kasutab	doc_491521501749_item	2468711	et	3	main
ka	doc_491521501749_item	2468712	et	3	main
teistes	doc_491521501749_item	2468713	et	4	main
konstruktsioonides	doc_491521501749_item	2468714	et	3	main
seestütlevat	doc_491521501749_item	2468715	et	3	main
käänet	doc_491521501749_item	2468716	et	3	main
väga	doc_491521501749_item	2468717	et	3	main
palju	doc_491521501749_item	2468718	et	4	main
1	doc_491521501749_item	2468719	et	2	main
vormimoodustusvigadest	doc_491521501749_item	2468720	et	4	main
tüvevalikuvigu	doc_491521501749_item	2468723	et	4	main
ja	doc_491521501749_item	2468724	et	3	main
kasutatakse	doc_491521501749_item	2468732	et	3	main
nominatiivi	doc_491521501749_item	2468733	et	4	main
see	doc_491521501749_item	2468737	et	3	main
on	doc_491521501749_item	2468745	et	4	main
lühikese	doc_491521501749_item	2468765	et	4	main
sisseütleva	doc_491521501749_item	2468766	et	3	main
poolt	doc_491521501749_item	2468780	et	4	main
tüvevariant	doc_491521501749_item	2468784	et	4	main
on	doc_491521501749_item	2468786	et	4	main
mineviku	doc_491521501749_item	2468787	et	3	main
vormile	doc_491521501749_item	2468788	et	3	main
lisatud	doc_491521501749_item	2468794	et	4	main
1	doc_491521501749_item	2468801	et	2	main
vormiga	doc_491521501749_item	2468805	et	4	main
segunemise	doc_491521501749_item	2468807	et	4	main
näitena	doc_491521501749_item	2468808	et	3	main
võib	doc_491521501749_item	2468809	et	3	main
välja	doc_491521501749_item	2468810	et	4	main
tuua	doc_491521501749_item	2468811	et	3	main
järgmised	doc_491521501749_item	2468812	et	3	main
õige	doc_491521501749_item	2468820	et	4	main
ainsuses	doc_491521501749_item	2468623	et	4	main
ning	doc_491521501749_item	2468625	et	3	main
eesti	doc_491521501749_item	2468632	et	4	main
keeles	doc_491521501749_item	2468633	et	4	main
kasutab	doc_491521501749_item	2468639	et	3	main
mõjul	doc_491521501749_item	2468653	et	4	main
õpilane	doc_491521501749_item	2468656	et	3	main
käändesse	doc_491521501749_item	2468666	et	4	main
panna	doc_491521501749_item	2468667	et	4	main
ning	doc_491521501749_item	2468668	et	3	main
rektsioonivigade	doc_491521501749_item	2468672	et	4	main
järgmisi	doc_491521501749_item	2468676	et	3	main
kohtuda	doc_491521501749_item	2468678	et	3	main
käände	doc_491521501749_item	2468682	et	4	main
kasutamise	doc_491521501749_item	2468683	et	4	main
päris	doc_491521501749_item	2468688	et	4	main
vene	doc_491521501749_item	2468692	et	4	main
on	doc_491521501749_item	2468696	et	4	main
tüvevalikuvigu	doc_491521501749_item	2468726	et	4	main
üsna	doc_491521501749_item	2468728	et	3	main
tüve	doc_491521501749_item	2468734	et	4	main
olla	doc_491521501749_item	2468738	et	3	main
ortograafiaviga	doc_491521501749_item	2468740	et	4	main
tuleb	doc_491521501749_item	2468742	et	3	main
eelmisega	doc_491521501749_item	2468746	et	3	main
nõrgale	doc_491521501749_item	2468756	et	3	main
moodustatud	doc_491521501749_item	2468760	et	4	main
oleviku	doc_491521501749_item	2468761	et	3	main
eeskujul	doc_491521501749_item	2468762	et	3	main
lõpuvalikuvigu	doc_491521501749_item	2468763	et	3	main
lasteaijasse	doc_491521501749_item	2468764	et	4	main
kasutatud	doc_491521501749_item	2468769	et	4	main
lisandub	doc_491521501749_item	2468773	et	3	main
selles	doc_491521501749_item	2468774	et	4	main
ühelt	doc_491521501749_item	2468779	et	3	main
valitud	doc_491521501749_item	2468782	et	4	main
veel	doc_491521501749_item	2468790	et	4	main
isikulõpp	doc_491521501749_item	2468791	et	3	main
mis	doc_491521501749_item	2468792	et	4	main
sõnatasandi	doc_491521501749_item	2468799	et	3	main
vead	doc_491521501749_item	2468800	et	4	main
millal	doc_491521501749_item	2468814	et	3	main
nad	doc_491521501749_item	2468815	et	3	main
lause	doc_491521501749_item	2468821	et	4	main
kui	doc_491521501749_item	2468823	et	3	main
sõnade	doc_491521501749_item	2468834	et	3	main
erinevuse	doc_491521501749_item	2468857	et	4	main
loss	doc_491521501749_item	2468858	et	3	main
on	doc_491521501749_item	2468859	et	4	main
väga	doc_491521501749_item	2468860	et	3	main
pikk	doc_491521501749_item	2468861	et	4	main
viga	doc_491521501749_item	2468862	et	4	main
ja	doc_491521501749_item	2468867	et	3	main
ilmselt	doc_491521501749_item	2468871	et	4	main
vene	doc_491521501749_item	2468879	et	4	main
mõisteid	doc_491521501749_item	2468883	et	3	main
2	doc_491521501749_item	2468889	et	2	main
valiku	doc_491521501749_item	2468892	et	3	main
on	doc_491521501749_item	2468894	et	4	main
tekkinud	doc_491521501749_item	2468895	et	4	main
üllatus	doc_491521501749_item	2468900	et	4	main
töötud	doc_491521501749_item	2468923	et	4	main
selles	doc_491521501749_item	2468925	et	4	main
on	doc_491521501749_item	2468927	et	4	main
väga	doc_491521501749_item	2468928	et	3	main
levinud	doc_491521501749_item	2468929	et	4	main
asemel	doc_491521501749_item	2468938	et	4	main
ilmselt	doc_491521501749_item	2468942	et	4	main
ta	doc_491521501749_item	2468948	et	4	main
v	doc_491521501749_item	2468974	et	4	main
snežki	doc_491521501749_item	2468975	et	2	main
ei	doc_491521501749_item	2468978	et	4	main
mitme	doc_491521501749_item	2468991	et	4	main
tasandi	doc_491521501749_item	2468992	et	3	main
vead	doc_491521501749_item	2468993	et	4	main
osa	doc_491521501749_item	2468994	et	4	main
peleta	doc_491521501749_item	2469025	et	4	main
selles	doc_491521501749_item	2469026	et	4	main
lauses	doc_491521501749_item	2469027	et	3	main
on	doc_491521501749_item	2469028	et	4	main
sõna	doc_491521501749_item	2469033	et	4	main
mis	doc_491521501749_item	2469035	et	4	main
eristada	doc_491521501749_item	2468722	et	3	main
koolikottis	doc_491521501749_item	2468727	et	4	main
tüüpiline	doc_491521501749_item	2468729	et	3	main
viga	doc_491521501749_item	2468730	et	4	main
kus	doc_491521501749_item	2468731	et	3	main
samas	doc_491521501749_item	2468735	et	4	main
sarnane	doc_491521501749_item	2468747	et	4	main
tüvevalikuviga	doc_491521501749_item	2468751	et	4	main
on	doc_491521501749_item	2468754	et	4	main
lisatud	doc_491521501749_item	2468755	et	4	main
pikka	doc_491521501749_item	2468770	et	4	main
lõpuvalikuveale	doc_491521501749_item	2468772	et	3	main
ka	doc_491521501749_item	2468776	et	3	main
on	doc_491521501749_item	2468781	et	4	main
on	doc_491521501749_item	2468793	et	4	main
mõjul	doc_491521501749_item	2468798	et	4	main
tähenduse	doc_491521501749_item	2468803	et	4	main
või	doc_491521501749_item	2468804	et	4	main
sõnade	doc_491521501749_item	2468806	et	3	main
järgi	doc_491521501749_item	2468818	et	4	main
peaks	doc_491521501749_item	2468819	et	4	main
kaks	doc_491521501749_item	2468829	et	3	main
tea	doc_491521501749_item	2468833	et	4	main
millal	doc_491521501749_item	2468835	et	3	main
vene	doc_491521501749_item	2468844	et	4	main
samuti	doc_491521501749_item	2468848	et	3	main
segi	doc_491521501749_item	2468851	et	3	main
ja	doc_491521501749_item	2468854	et	3	main
sõnade	doc_491521501749_item	2468865	et	3	main
sest	doc_491521501749_item	2468877	et	4	main
sellised	doc_491521501749_item	2468897	et	4	main
sõna	doc_491521501749_item	2468930	et	4	main
lumiinimene	doc_491521501749_item	2468931	et	3	main
liitmisel	doc_491521501749_item	2468935	et	4	main
nimetavalist	doc_491521501749_item	2468941	et	4	main
on	doc_491521501749_item	2468949	et	4	main
elefantid	doc_491521501749_item	2468976	et	4	main
ole	doc_491521501749_item	2468979	et	4	main
keele	doc_491521501749_item	2468981	et	4	main
moodustatud	doc_491521501749_item	2468988	et	4	main
vea	doc_491521501749_item	2469006	et	4	main
olla	doc_491521501749_item	2469014	et	3	main
vead	doc_491521501749_item	2469022	et	4	main
konteksti	doc_491521501749_item	2469041	et	4	main
da-infinitiivi	doc_491521501749_item	2469047	et	4	main
tunnuseks	doc_491521501749_item	2469048	et	3	main
ning	doc_491521501749_item	2469049	et	3	main
jäetud	doc_491521501749_item	2469053	et	4	main
sõna	doc_491521501749_item	2469055	et	4	main
kasutus	doc_491521501749_item	2469056	et	4	main
ei	doc_491521501749_item	2469057	et	4	main
korda	doc_491521501749_item	2469065	et	4	main
samal	doc_491521501749_item	2469066	et	3	main
kujul	doc_491521501749_item	2469067	et	4	main
välja	doc_491521501749_item	2469070	et	4	main
selge	doc_491521501749_item	2469073	et	4	main
tegemist	doc_491521501749_item	2469075	et	4	main
on	doc_491521501749_item	2469076	et	4	main
vormivalikuveaga	doc_491521501749_item	2469077	et	3	main
loomaaia	doc_491521501749_item	2469109	et	4	main
skulptuurilt	doc_491521501749_item	2469112	et	3	main
sellist	doc_491521501749_item	2469115	et	4	main
ja	doc_491521501749_item	2469121	et	3	main
ei	doc_491521501749_item	2469123	et	4	main
õige	doc_491521501749_item	2469145	et	4	main
ja	doc_491521501749_item	2469146	et	3	main
paljalt	doc_491521501749_item	2469153	et	4	main
oska	doc_491521501749_item	2469160	et	4	main
keeleõppija	doc_491521501749_item	2469161	et	4	main
järeldusi	doc_491521501749_item	2469164	et	4	main
lõpp	doc_491521501749_item	2468753	et	3	main
vorm	doc_491521501749_item	2468758	et	3	main
on	doc_491521501749_item	2468759	et	4	main
ortograafiaviga	doc_491521501749_item	2468777	et	4	main
õpisib	doc_491521501749_item	2468778	et	4	main
lisatud	doc_491521501749_item	2468789	et	4	main
ilmselt	doc_491521501749_item	2468795	et	4	main
oleviku	doc_491521501749_item	2468796	et	3	main
vead	doc_491521501749_item	2468813	et	4	main
konteksti	doc_491521501749_item	2468817	et	4	main
nad	doc_491521501749_item	2468824	et	3	main
tulevad	doc_491521501749_item	2468825	et	4	main
lauses	doc_491521501749_item	2468826	et	3	main
on	doc_491521501749_item	2468827	et	4	main
õpilane	doc_491521501749_item	2468831	et	3	main
kui	doc_491521501749_item	2468837	et	3	main
tähenduse	doc_491521501749_item	2468838	et	4	main
keeles	doc_491521501749_item	2468845	et	4	main
sama	doc_491521501749_item	2468846	et	4	main
ta	doc_491521501749_item	2468850	et	4	main
minema	doc_491521501749_item	2468853	et	3	main
tähenduse	doc_491521501749_item	2468856	et	4	main
on	doc_491521501749_item	2468863	et	4	main
lähedasest	doc_491521501749_item	2468869	et	3	main
pole	doc_491521501749_item	2468872	et	3	main
see	doc_491521501749_item	2468873	et	3	main
tingitud	doc_491521501749_item	2468874	et	4	main
neid	doc_491521501749_item	2468882	et	4	main
sõnad	doc_491521501749_item	2468885	et	4	main
vysokij	doc_491521501749_item	2468886	et	4	main
ja	doc_491521501749_item	2468887	et	3	main
vale	doc_491521501749_item	2468890	et	4	main
tuletusliite	doc_491521501749_item	2468891	et	4	main
mind	doc_491521501749_item	2468899	et	4	main
liitega	doc_491521501749_item	2468904	et	3	main
verbi	doc_491521501749_item	2468905	et	4	main
segi	doc_491521501749_item	2468906	et	3	main
on	doc_491521501749_item	2468907	et	4	main
analoogia	doc_491521501749_item	2468921	et	4	main
mis	doc_491521501749_item	2468924	et	4	main
viga	doc_491521501749_item	2468933	et	4	main
ning	doc_491521501749_item	2468947	et	3	main
ise	doc_491521501749_item	2468951	et	4	main
3	doc_491521501749_item	2468953	et	2	main
võib	doc_491521501749_item	2468956	et	3	main
igrat	doc_491521501749_item	2468973	et	4	main
see	doc_491521501749_item	2468977	et	3	main
vene	doc_491521501749_item	2468980	et	4	main
vaid	doc_491521501749_item	2468982	et	3	main
ilmselt	doc_491521501749_item	2468983	et	4	main
hoopis	doc_491521501749_item	2468984	et	3	main
sõna	doc_491521501749_item	2468989	et	4	main
raske	doc_491521501749_item	2468997	et	4	main
kuna	doc_491521501749_item	2468999	et	3	main
kuuluvad	doc_491521501749_item	2469001	et	4	main
väga	doc_491521501749_item	2469012	et	3	main
välja	doc_491521501749_item	2469017	et	4	main
haruldasemat	doc_491521501749_item	2469032	et	4	main
lisaks	doc_491521501749_item	2469042	et	4	main
sellele	doc_491521501749_item	2469043	et	4	main
tegelik	doc_491521501749_item	2469050	et	3	main
seda	doc_491521501749_item	2469060	et	3	main
kummitused	doc_491521501749_item	2469068	et	4	main
lendama	doc_491521501749_item	2469071	et	3	main
on	doc_491521501749_item	2469079	et	4	main
lausest	doc_491521501749_item	2469080	et	4	main
nähtud	doc_491521501749_item	2469111	et	4	main
märka	doc_491521501749_item	2469120	et	4	main
olema	doc_491521501749_item	2468822	et	4	main
sõnavalikuviga	doc_491521501749_item	2468830	et	4	main
tähenduses	doc_491521501749_item	2468842	et	4	main
kasutatakse	doc_491521501749_item	2468843	et	3	main
sõna	doc_491521501749_item	2468847	et	4	main
ajanud	doc_491521501749_item	2468852	et	4	main
tulema	doc_491521501749_item	2468855	et	4	main
pikk	doc_491521501749_item	2468866	et	4	main
tähendusest	doc_491521501749_item	2468870	et	4	main
emakeele	doc_491521501749_item	2468875	et	4	main
mõjust	doc_491521501749_item	2468876	et	3	main
tähistavad	doc_491521501749_item	2468881	et	4	main
erinevad	doc_491521501749_item	2468884	et	4	main
näiteks	doc_491521501749_item	2468896	et	4	main
on	doc_491521501749_item	2468901	et	4	main
kasutatud	doc_491521501749_item	2468902	et	4	main
väljendid	doc_491521501749_item	2468909	et	3	main
ma	doc_491521501749_item	2468910	et	3	main
üllatusin	doc_491521501749_item	2468911	et	3	main
ning	doc_491521501749_item	2468912	et	3	main
mind	doc_491521501749_item	2468913	et	4	main
üllatas	doc_491521501749_item	2468914	et	3	main
töötinimesed	doc_491521501749_item	2468915	et	4	main
viga	doc_491521501749_item	2468916	et	4	main
sõnade	doc_491521501749_item	2468917	et	3	main
liitmisel	doc_491521501749_item	2468918	et	4	main
ilmselt	doc_491521501749_item	2468919	et	4	main
mõjutab	doc_491521501749_item	2468920	et	3	main
piirkonnas	doc_491521501749_item	2468926	et	4	main
sõnade	doc_491521501749_item	2468934	et	3	main
liitumise	doc_491521501749_item	2468937	et	4	main
on	doc_491521501749_item	2468939	et	4	main
on	doc_491521501749_item	2468943	et	4	main
sõna	doc_491521501749_item	2468944	et	4	main
õpilasele	doc_491521501749_item	2468945	et	3	main
välja	doc_491521501749_item	2468957	et	4	main
tuua	doc_491521501749_item	2468958	et	3	main
järgmised	doc_491521501749_item	2468959	et	3	main
keelendid	doc_491521501749_item	2468960	et	3	main
mängib	doc_491521501749_item	2468961	et	3	main
lumepalle	doc_491521501749_item	2468962	et	3	main
eestikeelne	doc_491521501749_item	2468963	et	3	main
väljend	doc_491521501749_item	2468964	et	3	main
on	doc_491521501749_item	2468965	et	4	main
mängima	doc_491521501749_item	2468966	et	3	main
lumesõda	doc_491521501749_item	2468967	et	4	main
lumepall	doc_491521501749_item	2468968	et	3	main
on	doc_491521501749_item	2468969	et	4	main
toorlaen	doc_491521501749_item	2468970	et	3	main
vene	doc_491521501749_item	2468971	et	4	main
keelest	doc_491521501749_item	2468972	et	4	main
samuti	doc_491521501749_item	2468932	et	3	main
omastavalise	doc_491521501749_item	2468936	et	3	main
kasutatud	doc_491521501749_item	2468940	et	4	main
võõras	doc_491521501749_item	2468946	et	4	main
selle	doc_491521501749_item	2468950	et	4	main
moodustanud	doc_491521501749_item	2468952	et	4	main
uusmoodustiste	doc_491521501749_item	2468954	et	3	main
näitena	doc_491521501749_item	2468955	et	3	main
inglise	doc_491521501749_item	2468985	et	4	main
elefant	doc_491521501749_item	2468990	et	4	main
vigu	doc_491521501749_item	2468995	et	3	main
analüüsida	doc_491521501749_item	2468998	et	3	main
tekke	doc_491521501749_item	2469007	et	4	main
põhjus	doc_491521501749_item	2469008	et	4	main
ei	doc_491521501749_item	2469009	et	4	main
selge	doc_491521501749_item	2469013	et	4	main
on	doc_491521501749_item	2469016	et	4	main
toodud	doc_491521501749_item	2469018	et	4	main
mõned	doc_491521501749_item	2469019	et	3	main
sellist	doc_491521501749_item	2469020	et	4	main
keele	doc_491521501749_item	2468986	et	4	main
mõjul	doc_491521501749_item	2468987	et	4	main
on	doc_491521501749_item	2468996	et	4	main
need	doc_491521501749_item	2469000	et	3	main
korraga	doc_491521501749_item	2469002	et	4	main
mitmele	doc_491521501749_item	2469003	et	4	main
keeletasandile	doc_491521501749_item	2469004	et	3	main
ning	doc_491521501749_item	2469005	et	3	main
pruugi	doc_491521501749_item	2469010	et	4	main
samuti	doc_491521501749_item	2469011	et	3	main
järgnevalt	doc_491521501749_item	2469015	et	4	main
laadi	doc_491521501749_item	2469021	et	4	main
kummitused	doc_491521501749_item	2469023	et	4	main
armastavad	doc_491521501749_item	2469024	et	4	main
peletama	doc_491521501749_item	2469034	et	3	main
tunnus	doc_491521501749_item	2469051	et	3	main
selle	doc_491521501749_item	2469054	et	4	main
või	doc_491521501749_item	2469078	et	4	main
kui	doc_491521501749_item	2469113	et	3	main
seleta	doc_491521501749_item	2469124	et	4	main
siis	doc_491521501749_item	2469125	et	3	main
see	doc_491521501749_item	2469126	et	3	main
sõna	doc_491521501749_item	2469127	et	4	main
kinnistub	doc_491521501749_item	2469128	et	3	main
õpetaja	doc_491521501749_item	2469135	et	4	main
tähelepanu	doc_491521501749_item	2469139	et	4	main
õige	doc_491521501749_item	2469150	et	4	main
on	doc_491521501749_item	2469151	et	4	main
õpilane	doc_491521501749_item	2469029	et	3	main
tahtnud	doc_491521501749_item	2469030	et	4	main
kasutada	doc_491521501749_item	2469031	et	3	main
ei	doc_491521501749_item	2469036	et	4	main
sobi	doc_491521501749_item	2469037	et	4	main
eriti	doc_491521501749_item	2469038	et	3	main
hästi	doc_491521501749_item	2469039	et	3	main
on	doc_491521501749_item	2469044	et	4	main
ta-liidet	doc_491521501749_item	2469045	et	3	main
peetud	doc_491521501749_item	2469046	et	4	main
ära	doc_491521501749_item	2469052	et	4	main
ole	doc_491521501749_item	2469058	et	4	main
juhuslik	doc_491521501749_item	2469059	et	3	main
kasutatakse	doc_491521501749_item	2469061	et	3	main
samas	doc_491521501749_item	2469062	et	4	main
tekstis	doc_491521501749_item	2469063	et	3	main
jäänud	doc_491521501749_item	2469082	et	4	main
sõna	doc_491521501749_item	2469083	et	4	main
hakkama	doc_491521501749_item	2469084	et	3	main
eesti	doc_491521501749_item	2469085	et	4	main
keele	doc_491521501749_item	2469086	et	4	main
õppija	doc_491521501749_item	2469087	et	4	main
ammutab	doc_491521501749_item	2469088	et	3	main
infot	doc_491521501749_item	2469089	et	3	main
kogu	doc_491521501749_item	2469090	et	4	main
keelekeskkonnast	doc_491521501749_item	2469091	et	4	main
kuid	doc_491521501749_item	2469092	et	4	main
selle	doc_491521501749_item	2469093	et	4	main
lahtiseletamise	doc_491521501749_item	2469094	et	3	main
ülesanne	doc_491521501749_item	2469095	et	4	main
on	doc_491521501749_item	2469096	et	4	main
õpetajal	doc_491521501749_item	2469097	et	4	main
näiteks	doc_491521501749_item	2469098	et	4	main
lauses	doc_491521501749_item	2469099	et	3	main
me	doc_491521501749_item	2469101	et	4	main
nägime	doc_491521501749_item	2469102	et	3	main
zoos	doc_491521501749_item	2469100	et	4	main
loomi	doc_491521501749_item	2469103	et	4	main
tuleb	doc_491521501749_item	2469104	et	3	main
sõna	doc_491521501749_item	2469105	et	4	main
zoo	doc_491521501749_item	2469106	et	4	main
kasutamine	doc_491521501749_item	2469107	et	4	main
antud	doc_491521501749_item	2469040	et	4	main
mitu	doc_491521501749_item	2469064	et	4	main
majast	doc_491521501749_item	2469069	et	4	main
pole	doc_491521501749_item	2469072	et	3	main
kas	doc_491521501749_item	2469074	et	3	main
välja	doc_491521501749_item	2469081	et	4	main
lahti	doc_491521501749_item	2469122	et	4	main
teiste	doc_491521501749_item	2469132	et	4	main
vigade	doc_491521501749_item	2469133	et	3	main
puhul	doc_491521501749_item	2469134	et	4	main
nendele	doc_491521501749_item	2469138	et	4	main
juhtida	doc_491521501749_item	2469140	et	4	main
ja	doc_491521501749_item	2469141	et	3	main
seletada	doc_491521501749_item	2469142	et	3	main
kuidas	doc_491521501749_item	2469143	et	3	main
on	doc_491521501749_item	2469144	et	4	main
sest	doc_491521501749_item	2469152	et	4	main
ilmselt	doc_491521501749_item	2469108	et	4	main
ees	doc_491521501749_item	2469110	et	4	main
õpetaja	doc_491521501749_item	2469114	et	4	main
sõnakasutust	doc_491521501749_item	2469116	et	4	main
õpilase	doc_491521501749_item	2469117	et	3	main
töös	doc_491521501749_item	2469118	et	3	main
ei	doc_491521501749_item	2469119	et	4	main
sama	doc_491521501749_item	2469129	et	4	main
kehtib	doc_491521501749_item	2469130	et	3	main
on	doc_491521501749_item	2469137	et	4	main
miks	doc_491521501749_item	2469147	et	4	main
just	doc_491521501749_item	2469148	et	3	main
nii	doc_491521501749_item	2469149	et	3	main
pastakaga	doc_491521501749_item	2469155	et	3	main
paranduste	doc_491521501749_item	2469157	et	4	main
enda	doc_491521501749_item	2469162	et	4	main
teha	doc_491521501749_item	2469165	et	3	main
ka	doc_491521501749_item	2469131	et	3	main
ülesanne	doc_491521501749_item	2469136	et	4	main
punase	doc_491521501749_item	2469154	et	4	main
tehtud	doc_491521501749_item	2469156	et	4	main
põhjal	doc_491521501749_item	2469158	et	4	main
ei	doc_491521501749_item	2469159	et	4	main
jaoks	doc_491521501749_item	2469163	et	4	main
essee	doc_491521501751_item	2470394	et	4	main
minu	doc_491521501751_item	2470395	et	3	main
arvates	doc_491521501751_item	2470396	et	4	main
see	doc_491521501751_item	2470397	et	3	main
loeng	doc_491521501751_item	2470398	et	3	main
terminid	doc_491521501751_item	2470417	et	3	main
olla	doc_491521501751_item	2470420	et	3	main
muidugi	doc_491521501751_item	2470422	et	4	main
asi	doc_491521501751_item	2470428	et	4	main
näiteks	doc_491521501751_item	2470433	et	4	main
aru	doc_491521501751_item	2470440	et	4	main
pidin	doc_491521501751_item	2470444	et	3	main
või	doc_491521501751_item	2470453	et	4	main
ma	doc_491521501751_item	2470455	et	3	main
tulin	doc_491521501751_item	2470456	et	3	main
hästi	doc_491521501751_item	2470463	et	3	main
et	doc_491521501751_item	2470473	et	3	main
teadus	doc_491521501751_item	2470475	et	4	main
vajalik	doc_491521501751_item	2470478	et	3	main
tähtsaim	doc_491521501751_item	2470401	et	4	main
minu	doc_491521501751_item	2470402	et	3	main
kontroltöös	doc_491521501751_item	2470421	et	4	main
võib	doc_491521501751_item	2470423	et	3	main
õpida	doc_491521501751_item	2470424	et	4	main
neid	doc_491521501751_item	2470430	et	4	main
peab	doc_491521501751_item	2470439	et	4	main
tooma	doc_491521501751_item	2470446	et	3	main
näidendeid	doc_491521501751_item	2470447	et	3	main
raamatus	doc_491521501751_item	2470454	et	4	main
kontroltööle	doc_491521501751_item	2470457	et	4	main
teised	doc_491521501751_item	2470464	et	4	main
aru	doc_491521501751_item	2470472	et	4	main
see	doc_491521501751_item	2470474	et	3	main
tähtsus	doc_491521501751_item	2470485	et	4	main
on	doc_491521501751_item	2470486	et	4	main
grammatikas	doc_491521501751_item	2470488	et	3	main
õppija	doc_491521501751_item	2470489	et	4	main
küsida	doc_491521501751_item	2470524	et	3	main
vaenelaps	doc_491521501751_item	2470535	et	4	main
meeldis	doc_491521501751_item	2470536	et	3	main
mitte	doc_491521501751_item	2470538	et	3	main
võõrasemale	doc_491521501751_item	2470539	et	4	main
eesti	doc_491521501752_item	2470544	et	4	main
muutuvas	doc_491521501752_item	2470546	et	4	main
rahvakultuuri	doc_491521501752_item	2470548	et	4	main
mõiste	doc_491521501752_item	2470549	et	4	main
koosneb	doc_491521501752_item	2470550	et	3	main
paljudest	doc_491521501752_item	2470551	et	3	main
komponentidest	doc_491521501752_item	2470552	et	3	main
ja	doc_491521501752_item	2470560	et	3	main
riided	doc_491521501752_item	2470564	et	3	main
võiks	doc_491521501752_item	2470569	et	4	main
nagu	doc_491521501752_item	2470588	et	3	main
teatud	doc_491521501752_item	2470601	et	4	main
vanu	doc_491521501752_item	2470603	et	4	main
teiselt	doc_491521501752_item	2470605	et	4	main
toimima	doc_491521501752_item	2470622	et	3	main
selline	doc_491521501752_item	2470641	et	4	main
mis	doc_491521501752_item	2470646	et	4	main
on	doc_491521501752_item	2470647	et	4	main
kui	doc_491521501752_item	2470664	et	3	main
hamburger	doc_491521501752_item	2470675	et	3	main
neile	doc_491521501752_item	2470677	et	4	main
aga	doc_491521501752_item	2470681	et	3	main
on	doc_491521501752_item	2470690	et	4	main
välja	doc_491521501752_item	2470692	et	4	main
valitud	doc_491521501752_item	2470693	et	4	main
võtsid	doc_491521501752_item	2470696	et	4	main
kommetest	doc_491521501752_item	2470714	et	4	main
nende	doc_491521501752_item	2470725	et	4	main
võõraid	doc_491521501752_item	2470730	et	3	main
näiteks	doc_491521501752_item	2470732	et	4	main
õigeusulised	doc_491521501752_item	2470733	et	4	main
asi	doc_491521501751_item	2470405	et	4	main
on	doc_491521501751_item	2470406	et	4	main
on	doc_491521501751_item	2470399	et	4	main
kõige	doc_491521501751_item	2470400	et	4	main
teine	doc_491521501751_item	2470404	et	3	main
kuidas	doc_491521501751_item	2470408	et	3	main
suhten	doc_491521501751_item	2470410	et	4	main
selles	doc_491521501751_item	2470411	et	4	main
mis	doc_491521501751_item	2470418	et	4	main
terminite	doc_491521501751_item	2470442	et	3	main
oma	doc_491521501751_item	2470449	et	4	main
kui	doc_491521501751_item	2470450	et	3	main
konspektist	doc_491521501751_item	2470452	et	3	main
et	doc_491521501751_item	2470459	et	3	main
kirjutan	doc_491521501751_item	2470461	et	3	main
arvavad	doc_491521501751_item	2470465	et	4	main
ma	doc_491521501751_item	2470467	et	3	main
õppimist	doc_491521501751_item	2470469	et	4	main
on	doc_491521501751_item	2470476	et	4	main
tulevikutöös	doc_491521501751_item	2470480	et	3	main
leian	doc_491521501751_item	2470482	et	3	main
kohtus	doc_491521501751_item	2470528	et	4	main
mait	doc_491521501751_item	2470529	et	3	main
ja	doc_491521501751_item	2470530	et	3	main
temale	doc_491521501751_item	2470532	et	3	main
kõigile	doc_491521501751_item	2470537	et	4	main
ajas	doc_491521501752_item	2470547	et	4	main
esemed	doc_491521501752_item	2470562	et	3	main
loetelu	doc_491521501752_item	2470568	et	4	main
peale	doc_491521501752_item	2470572	et	4	main
selle	doc_491521501752_item	2470573	et	4	main
päevast	doc_491521501752_item	2470579	et	4	main
päevasse	doc_491521501752_item	2470580	et	4	main
teeme	doc_491521501752_item	2470581	et	3	main
me	doc_491521501752_item	2470582	et	4	main
mingisuguseid	doc_491521501752_item	2470583	et	3	main
toiminguid	doc_491521501752_item	2470584	et	3	main
säilitame	doc_491521501752_item	2470600	et	3	main
kombeid	doc_491521501752_item	2470604	et	4	main
õppimises	doc_491521501751_item	2470403	et	4	main
see	doc_491521501751_item	2470407	et	3	main
ma	doc_491521501751_item	2470409	et	3	main
kõik	doc_491521501751_item	2470412	et	4	main
vabapäevad	doc_491521501751_item	2470413	et	3	main
ma	doc_491521501751_item	2470414	et	3	main
õppisin	doc_491521501751_item	2470415	et	3	main
need	doc_491521501751_item	2470416	et	3	main
võiksid	doc_491521501751_item	2470419	et	4	main
teine	doc_491521501751_item	2470427	et	3	main
aru	doc_491521501751_item	2470431	et	4	main
morfeemide	doc_491521501751_item	2470434	et	3	main
või	doc_491521501751_item	2470436	et	4	main
palatalisatsioon	doc_491521501751_item	2470437	et	3	main
ma	doc_491521501751_item	2470445	et	3	main
nii	doc_491521501751_item	2470448	et	3	main
ka	doc_491521501751_item	2470451	et	3	main
tunnega	doc_491521501751_item	2470458	et	4	main
ma	doc_491521501751_item	2470460	et	3	main
ma	doc_491521501751_item	2470470	et	3	main
väga	doc_491521501751_item	2470477	et	3	main
minu	doc_491521501751_item	2470479	et	3	main
siiski	doc_491521501751_item	2470481	et	4	main
õppejõu	doc_491521501751_item	2470521	et	3	main
et	doc_491521501751_item	2470523	et	3	main
oma	doc_491521501751_item	2470525	et	4	main
vigadest	doc_491521501751_item	2470526	et	3	main
teel	doc_491521501751_item	2470527	et	4	main
muutuvas	doc_491521501752_item	2470542	et	4	main
traditsioonid	doc_491521501752_item	2470561	et	3	main
ja	doc_491521501752_item	2470566	et	3	main
lõpmatu	doc_491521501752_item	2470571	et	4	main
te	doc_491521501752_item	2470574	et	4	main
midagi	doc_491521501752_item	2470585	et	4	main
niiviisi	doc_491521501752_item	2470587	et	3	main
tegid	doc_491521501752_item	2470589	et	4	main
nende	doc_491521501752_item	2470595	et	4	main
tähendab	doc_491521501752_item	2470599	et	3	main
toome	doc_491521501752_item	2470607	et	4	main
meid	doc_491521501752_item	2470621	et	4	main
teist	doc_491521501752_item	2470624	et	4	main
toimisid	doc_491521501752_item	2470627	et	4	main
kõigile	doc_491521501752_item	2470643	et	4	main
rahvastele	doc_491521501752_item	2470644	et	4	main
kultuuriga	doc_491521501752_item	2470650	et	4	main
arhaiiist	doc_491521501752_item	2470659	et	4	main
vaid	doc_491521501752_item	2470660	et	3	main
midagi	doc_491521501752_item	2470661	et	4	main
näiteks	doc_491521501752_item	2470663	et	4	main
itaaliast	doc_491521501752_item	2470682	et	4	main
ei	doc_491521501752_item	2470684	et	4	main
sobivad	doc_491521501752_item	2470702	et	4	main
toimub	doc_491521501752_item	2470706	et	3	main
või	doc_491521501752_item	2470715	et	4	main
omaks	doc_491521501752_item	2470724	et	4	main
rahvusele	doc_491521501752_item	2470728	et	3	main
täiesti	doc_491521501752_item	2470729	et	3	main
elemente	doc_491521501752_item	2470731	et	3	main
esivanemate	doc_491521501752_item	2470738	et	4	main
essees	doc_491521501752_item	2470745	et	3	main
rahvas	doc_491521501752_item	2470756	et	4	main
keel	doc_491521501752_item	2470763	et	4	main
ja	doc_491521501752_item	2470767	et	3	main
keel	doc_491521501752_item	2470769	et	4	main
eestlastel	doc_491521501752_item	2470770	et	4	main
kujunes	doc_491521501752_item	2470771	et	3	main
aeglane	doc_491521501752_item	2470778	et	3	main
vene	doc_491521501752_item	2470787	et	4	main
omadest	doc_491521501752_item	2470788	et	3	main
üldised	doc_491521501752_item	2470827	et	3	main
rahvas	doc_491521501752_item	2470836	et	4	main
ja	doc_491521501752_item	2470843	et	3	main
põllutööd	doc_491521501752_item	2470844	et	4	main
aitas	doc_491521501752_item	2470845	et	3	main
jagada	doc_491521501752_item	2470846	et	3	main
kurbust	doc_491521501752_item	2470849	et	4	main
võeti	doc_491521501752_item	2470851	et	3	main
vastsündinu	doc_491521501752_item	2470852	et	4	main
viimsele	doc_491521501752_item	2470859	et	3	main
põlvest	doc_491521501752_item	2470863	et	4	main
ilmus	doc_491521501752_item	2470870	et	4	main
kujul	doc_491521501752_item	2470875	et	4	main
pähe	doc_491521501751_item	2470425	et	4	main
aga	doc_491521501751_item	2470426	et	3	main
on	doc_491521501751_item	2470429	et	4	main
saada	doc_491521501751_item	2470432	et	4	main
õppetus	doc_491521501751_item	2470435	et	4	main
seda	doc_491521501751_item	2470438	et	3	main
saada	doc_491521501751_item	2470441	et	4	main
juurde	doc_491521501751_item	2470443	et	4	main
seda	doc_491521501751_item	2470462	et	3	main
et	doc_491521501751_item	2470466	et	3	main
ülepingutan	doc_491521501751_item	2470468	et	4	main
saan	doc_491521501751_item	2470471	et	4	main
et	doc_491521501751_item	2470483	et	3	main
keele	doc_491521501751_item	2470487	et	4	main
unustab	doc_491521501751_item	2470490	et	3	main
mõiste	doc_491521501751_item	2470491	et	4	main
olemasolust	doc_491521501751_item	2470492	et	3	main
ei	doc_491521501751_item	2470493	et	4	main
te	doc_491521501751_item	2470494	et	4	main
kus	doc_491521501751_item	2470495	et	3	main
ja	doc_491521501751_item	2470496	et	3	main
millal	doc_491521501751_item	2470497	et	3	main
kasutada	doc_491521501751_item	2470498	et	3	main
teatuid	doc_491521501751_item	2470499	et	4	main
vorme	doc_491521501751_item	2470500	et	3	main
vaatamata	doc_491521501751_item	2470501	et	4	main
sellele	doc_491521501751_item	2470502	et	4	main
ma	doc_491521501751_item	2470503	et	3	main
õpisin	doc_491521501751_item	2470504	et	4	main
seda	doc_491521501751_item	2470505	et	3	main
pähe	doc_491521501751_item	2470506	et	4	main
ja	doc_491521501751_item	2470507	et	3	main
hindan	doc_491521501751_item	2470508	et	3	main
et	doc_491521501751_item	2470509	et	3	main
saan	doc_491521501751_item	2470510	et	4	main
rahuldavat	doc_491521501751_item	2470511	et	4	main
hinnet	doc_491521501751_item	2470512	et	3	main
sellest	doc_491521501751_item	2470513	et	4	main
peale	doc_491521501751_item	2470514	et	4	main
oma	doc_491521501751_item	2470515	et	4	main
kontrolltöö	doc_491521501751_item	2470516	et	4	main
saamist	doc_491521501751_item	2470517	et	4	main
ma	doc_491521501751_item	2470518	et	3	main
kohe	doc_491521501751_item	2470519	et	4	main
pöördusin	doc_491521501751_item	2470520	et	4	main
suurem	doc_491521501751_item	2470484	et	4	main
juurde	doc_491521501751_item	2470522	et	4	main
oma	doc_491521501751_item	2470533	et	4	main
murele	doc_491521501751_item	2470534	et	3	main
rahvakultuur	doc_491521501752_item	2470545	et	3	main
siia	doc_491521501752_item	2470553	et	4	main
kuuluvad	doc_491521501752_item	2470554	et	4	main
läbi	doc_491521501752_item	2470555	et	4	main
aegade	doc_491521501752_item	2470556	et	3	main
ja	doc_491521501752_item	2470563	et	3	main
laulud	doc_491521501752_item	2470565	et	3	main
olete	doc_491521501752_item	2470576	et	3	main
loojad	doc_491521501752_item	2470578	et	4	main
meie	doc_491521501752_item	2470590	et	4	main
vanaisad	doc_491521501752_item	2470591	et	3	main
ja	doc_491521501752_item	2470592	et	3	main
vanaemad	doc_491521501752_item	2470593	et	3	main
ning	doc_491521501752_item	2470594	et	3	main
vanaisad	doc_491521501752_item	2470596	et	3	main
ja	doc_491521501752_item	2470597	et	3	main
vanaemad	doc_491521501752_item	2470598	et	3	main
määral	doc_491521501752_item	2470602	et	3	main
meie	doc_491521501752_item	2470628	et	4	main
eelkäijad	doc_491521501752_item	2470629	et	3	main
minu	doc_491521501752_item	2470630	et	3	main
mis	doc_491521501752_item	2470642	et	4	main
ameerika	doc_491521501752_item	2470649	et	3	main
kus	doc_491521501752_item	2470651	et	3	main
ole	doc_491521501752_item	2470653	et	4	main
midagi	doc_491521501752_item	2470654	et	4	main
omapärast	doc_491521501752_item	2470655	et	4	main
arhailist	doc_491521501752_item	2470656	et	3	main
tulnud	doc_491521501752_item	2470678	et	4	main
hästi	doc_491521501752_item	2470691	et	3	main
mida	doc_491521501752_item	2470695	et	4	main
omaks	doc_491521501752_item	2470698	et	4	main
ja	doc_491521501752_item	2470699	et	3	main
mis	doc_491521501752_item	2470700	et	4	main
hästi	doc_491521501752_item	2470701	et	3	main
kahjuks	doc_491521501752_item	2470705	et	4	main
loobuvad	doc_491521501752_item	2470712	et	4	main
asjadest	doc_491521501752_item	2470716	et	3	main
ei	doc_491521501752_item	2470719	et	4	main
praktilised	doc_491521501752_item	2470721	et	3	main
võtavad	doc_491521501752_item	2470723	et	3	main
iseloomule	doc_491521501752_item	2470726	et	3	main
ja	doc_491521501752_item	2470727	et	3	main
oma	doc_491521501752_item	2470737	et	4	main
ma	doc_491521501752_item	2470748	et	3	main
mõtiskleda	doc_491521501752_item	2470750	et	3	main
väga	doc_491521501752_item	2470765	et	3	main
meloodiline	doc_491521501752_item	2470768	et	3	main
laulmise	doc_491521501752_item	2470774	et	4	main
ja	doc_491521501752_item	2470779	et	3	main
rahvalaule	doc_491521501752_item	2470782	et	4	main
näiteks	doc_491521501752_item	2470786	et	4	main
valjud	doc_491521501752_item	2470823	et	3	main
kuid	doc_491521501752_item	2470826	et	4	main
on	doc_491521501752_item	2470829	et	4	main
sellised	doc_491521501752_item	2470831	et	4	main
muistsest	doc_491521501752_item	2470832	et	3	main
ajast	doc_491521501752_item	2470833	et	4	main
alates	doc_491521501752_item	2470834	et	3	main
laulis	doc_491521501752_item	2470835	et	4	main
aitas	doc_491521501752_item	2470840	et	3	main
teha	doc_491521501752_item	2470841	et	3	main
kodu-	doc_491521501752_item	2470842	et	4	main
ilmale	doc_491521501752_item	2470854	et	4	main
saadeti	doc_491521501752_item	2470857	et	3	main
toimuval	doc_491521501752_item	2470867	et	4	main
küpsetatud	doc_491521501752_item	2470874	et	4	main
reegivärss	doc_491521501752_item	2470882	et	4	main
mis	doc_491521501752_item	2470883	et	4	main
sellele	doc_491521501752_item	2470887	et	4	main
seega	doc_491521501752_item	2470896	et	4	main
eesti	doc_491521501752_item	2470900	et	4	main
20	doc_491521501752_item	2470905	et	2	main
rahvalaulu	doc_491521501752_item	2470914	et	4	main
edasisele	doc_491521501752_item	2470915	et	3	main
ja	doc_491521501752_item	2470922	et	3	main
saamine	doc_491521501752_item	2470924	et	4	main
nõukogude	doc_491521501752_item	2470925	et	3	main
kaebas	doc_491521501751_item	2470531	et	3	main
eesti	doc_491521501752_item	2470540	et	4	main
rahvakultuur	doc_491521501752_item	2470541	et	3	main
ajas	doc_491521501752_item	2470543	et	4	main
säilinud	doc_491521501752_item	2470557	et	4	main
vanad	doc_491521501752_item	2470558	et	3	main
kombed	doc_491521501752_item	2470559	et	3	main
muinasjutud	doc_491521501752_item	2470567	et	3	main
olla	doc_491521501752_item	2470570	et	3	main
ise	doc_491521501752_item	2470575	et	4	main
rahvakultuur	doc_491521501752_item	2470577	et	3	main
teeme	doc_491521501752_item	2470586	et	3	main
poolt	doc_491521501752_item	2470606	et	4	main
midagi	doc_491521501752_item	2470608	et	4	main
juurde	doc_491521501752_item	2470609	et	4	main
sest	doc_491521501752_item	2470610	et	4	main
elu	doc_491521501752_item	2470611	et	4	main
muutub	doc_491521501752_item	2470612	et	3	main
iga	doc_491521501752_item	2470613	et	4	main
päevaga	doc_491521501752_item	2470614	et	3	main
ümbritsev	doc_491521501752_item	2470615	et	4	main
maailm	doc_491521501752_item	2470616	et	3	main
täpsemalt	doc_491521501752_item	2470617	et	4	main
tehnliine	doc_491521501752_item	2470618	et	4	main
progress	doc_491521501752_item	2470619	et	3	main
paneb	doc_491521501752_item	2470620	et	3	main
meelest	doc_491521501752_item	2470631	et	4	main
praegu	doc_491521501752_item	2470632	et	3	main
on	doc_491521501752_item	2470633	et	4	main
näha	doc_491521501752_item	2470634	et	3	main
ei	doc_491521501752_item	2470652	et	4	main
pitsa	doc_491521501752_item	2470680	et	4	main
nende	doc_491521501752_item	2470703	et	4	main
meilgi	doc_491521501752_item	2470707	et	4	main
paljud	doc_491521501752_item	2470710	et	3	main
vanadest	doc_491521501752_item	2470713	et	3	main
sest	doc_491521501752_item	2470717	et	4	main
nad	doc_491521501752_item	2470718	et	3	main
ole	doc_491521501752_item	2470720	et	4	main
katoliiklased	doc_491521501752_item	2470735	et	3	main
ja	doc_491521501752_item	2470741	et	3	main
pöörduvad	doc_491521501752_item	2470742	et	4	main
sektidesse	doc_491521501752_item	2470743	et	3	main
selles	doc_491521501752_item	2470744	et	4	main
on	doc_491521501752_item	2470757	et	4	main
ammusest	doc_491521501752_item	2470758	et	4	main
eesti	doc_491521501752_item	2470762	et	4	main
on	doc_491521501752_item	2470764	et	4	main
pehme	doc_491521501752_item	2470766	et	4	main
nende	doc_491521501752_item	2470781	et	4	main
võib	doc_491521501752_item	2470783	et	3	main
kohe	doc_491521501752_item	2470784	et	4	main
eristada	doc_491521501752_item	2470785	et	3	main
hoopis	doc_491521501752_item	2470623	et	3	main
moodi	doc_491521501752_item	2470625	et	4	main
kui	doc_491521501752_item	2470626	et	3	main
sellist	doc_491521501752_item	2470635	et	4	main
tendentsi	doc_491521501752_item	2470636	et	4	main
et	doc_491521501752_item	2470637	et	3	main
hakkab	doc_491521501752_item	2470638	et	3	main
kujunema	doc_491521501752_item	2470639	et	3	main
üldkultuur	doc_491521501752_item	2470640	et	3	main
midagi	doc_491521501752_item	2470645	et	4	main
sarnane	doc_491521501752_item	2470648	et	4	main
isegi	doc_491521501752_item	2470657	et	4	main
mitte	doc_491521501752_item	2470658	et	3	main
oma	doc_491521501752_item	2470662	et	4	main
rääkida	doc_491521501752_item	2470665	et	3	main
rahvatoidust	doc_491521501752_item	2470666	et	4	main
ameeriklased	doc_491521501752_item	2470667	et	3	main
peavad	doc_491521501752_item	2470668	et	4	main
oma	doc_491521501752_item	2470669	et	4	main
hamburgereid	doc_491521501752_item	2470671	et	3	main
ja	doc_491521501752_item	2470672	et	3	main
rahvatoiduks	doc_491521501752_item	2470670	et	3	main
pitsaid	doc_491521501752_item	2470673	et	4	main
tegelikult	doc_491521501752_item	2470674	et	4	main
on	doc_491521501752_item	2470676	et	4	main
saksamaalt	doc_491521501752_item	2470679	et	3	main
need	doc_491521501752_item	2470683	et	3	main
ole	doc_491521501752_item	2470685	et	4	main
ju	doc_491521501752_item	2470686	et	3	main
ameeriklaste	doc_491521501752_item	2470687	et	3	main
omad	doc_491521501752_item	2470688	et	4	main
need	doc_491521501752_item	2470689	et	3	main
road	doc_491521501752_item	2470694	et	4	main
nad	doc_491521501752_item	2470697	et	3	main
eluviisile	doc_491521501752_item	2470704	et	3	main
selline	doc_491521501752_item	2470708	et	4	main
selekteerimine	doc_491521501752_item	2470709	et	4	main
inimesed	doc_491521501752_item	2470711	et	3	main
ja	doc_491521501752_item	2470722	et	3	main
või	doc_491521501752_item	2470734	et	4	main
loobuvad	doc_491521501752_item	2470736	et	4	main
tahaksin	doc_491521501752_item	2470747	et	3	main
eesti	doc_491521501752_item	2470755	et	4	main
välja	doc_491521501752_item	2470772	et	4	main
pühalik	doc_491521501752_item	2470780	et	3	main
ausalt	doc_491521501752_item	2470789	et	4	main
öeldes	doc_491521501752_item	2470790	et	3	main
meeldib	doc_491521501752_item	2470791	et	3	main
mulle	doc_491521501752_item	2470792	et	4	main
rohkem	doc_491521501752_item	2470793	et	4	main
just	doc_491521501752_item	2470794	et	3	main
eesti	doc_491521501752_item	2470795	et	4	main
rahvalaul	doc_491521501752_item	2470796	et	4	main
oma	doc_491521501752_item	2470797	et	4	main
rahuliku	doc_491521501752_item	2470798	et	3	main
ja	doc_491521501752_item	2470799	et	3	main
kurvameelse	doc_491521501752_item	2470800	et	3	main
viisiga	doc_491521501752_item	2470801	et	4	main
kui	doc_491521501752_item	2470802	et	3	main
vene	doc_491521501752_item	2470804	et	4	main
temperamentne	doc_491521501752_item	2470803	et	3	main
rahvalaul	doc_491521501752_item	2470805	et	4	main
loomulikult	doc_491521501752_item	2470806	et	4	main
ei	doc_491521501752_item	2470807	et	4	main
tohi	doc_491521501752_item	2470808	et	4	main
öelda	doc_491521501752_item	2470809	et	4	main
et	doc_491521501752_item	2470810	et	3	main
kõik	doc_491521501752_item	2470811	et	4	main
eesti	doc_491521501752_item	2470812	et	4	main
rahvalaulud	doc_491521501752_item	2470813	et	3	main
on	doc_491521501752_item	2470814	et	4	main
kurvad	doc_491521501752_item	2470815	et	3	main
ja	doc_491521501752_item	2470816	et	3	main
rahulikud	doc_491521501752_item	2470817	et	3	main
ninq	doc_491521501752_item	2470818	et	4	main
kõik	doc_491521501752_item	2470819	et	4	main
vene	doc_491521501752_item	2470820	et	4	main
rahvalaulud	doc_491521501752_item	2470821	et	3	main
on	doc_491521501752_item	2470822	et	4	main
ja	doc_491521501752_item	2470824	et	3	main
laul	doc_491521501752_item	2470839	et	4	main
vastu	doc_491521501752_item	2470855	et	3	main
teele	doc_491521501752_item	2470860	et	3	main
säilis	doc_491521501752_item	2470862	et	4	main
põlvesse	doc_491521501752_item	2470864	et	4	main
l869a	doc_491521501752_item	2470865	et	4	main
tartus	doc_491521501752_item	2470866	et	3	main
kahtlemata	doc_491521501752_item	2470876	et	4	main
traditsioonilisest	doc_491521501752_item	2470739	et	4	main
usust	doc_491521501752_item	2470740	et	3	main
aga	doc_491521501752_item	2470746	et	3	main
natuke	doc_491521501752_item	2470749	et	4	main
eesti	doc_491521501752_item	2470751	et	4	main
rahvalaulude	doc_491521501752_item	2470752	et	3	main
traditsiooni	doc_491521501752_item	2470753	et	4	main
üle	doc_491521501752_item	2470754	et	3	main
ajast	doc_491521501752_item	2470759	et	4	main
tuntud	doc_491521501752_item	2470760	et	4	main
laulurahvana	doc_491521501752_item	2470761	et	3	main
iseäralik	doc_491521501752_item	2470773	et	3	main
viis	doc_491521501752_item	2470775	et	4	main
rahulik	doc_491521501752_item	2470776	et	3	main
vaikne	doc_491521501752_item	2470777	et	3	main
rõõmu	doc_491521501752_item	2470847	et	4	main
lauluga	doc_491521501752_item	2470850	et	4	main
siia	doc_491521501752_item	2470853	et	4	main
lauluga	doc_491521501752_item	2470856	et	4	main
ka	doc_491521501752_item	2470858	et	3	main
laulutraditsioon	doc_491521501752_item	2470861	et	3	main
rahvalaul	doc_491521501752_item	2470872	et	4	main
juba	doc_491521501752_item	2470873	et	3	main
on	doc_491521501752_item	2470884	et	4	main
sajandi	doc_491521501752_item	2470898	et	3	main
kuldne	doc_491521501752_item	2470903	et	3	main
nimelt	doc_491521501752_item	2470917	et	4	main
rahvuslilkku	doc_491521501752_item	2470933	et	4	main
kultuuri	doc_491521501752_item	2470934	et	4	main
loodi	doc_491521501752_item	2470937	et	4	main
nõukogulikku	doc_491521501752_item	2470938	et	4	main
iseisvuse	doc_491521501752_item	2470941	et	4	main
rahvuskultuur	doc_491521501752_item	2470943	et	3	main
peale	doc_491521501752_item	2470946	et	4	main
palju	doc_491521501752_item	2470954	et	4	main
see	doc_491521501752_item	2470958	et	3	main
iseseivumise	doc_491521501752_item	2470962	et	4	main
ka	doc_491521501752_item	2470968	et	3	main
siis	doc_491521501752_item	2470974	et	3	main
igasugused	doc_491521501752_item	2470978	et	3	main
kes	doc_491521501752_item	2470982	et	4	main
neid	doc_491521501752_item	2470986	et	4	main
lauludes	doc_491521501752_item	2471021	et	3	main
ansambleid	doc_491521501752_item	2471032	et	3	main
veel	doc_491521501752_item	2471039	et	4	main
aga	doc_491521501752_item	2471052	et	3	main
keelele	doc_491521501752_item	2471056	et	4	main
kultuur	doc_491521501752_item	2471068	et	3	main
üldkultuurile	doc_491521501752_item	2471071	et	3	main
tõestavad	doc_491521501752_item	2471073	et	4	main
eurovisiooni	doc_491521501752_item	2471075	et	4	main
võistlused	doc_491521501752_item	2471076	et	3	main
eurovisioonil	doc_491521501752_item	2471077	et	3	main
aru	doc_491521501752_item	2471087	et	4	main
noorte	doc_491521501752_item	2471129	et	3	main
viimasel	doc_491521501752_item	2471132	et	3	main
huvi	doc_491521501752_item	2471135	et	4	main
vana	doc_491521501752_item	2471136	et	4	main
rahvuslikku	doc_491521501752_item	2471149	et	4	main
kultuuri	doc_491521501752_item	2471150	et	4	main
olen	doc_491521501752_item	2471151	et	3	main
kaua-kaua	doc_491521501752_item	2471164	et	3	main
nimi	doc_491521501752_item	2471168	et	3	main
ajaks	doc_491521501752_item	2471177	et	4	main
essed	doc_491521501752_item	2471178	et	4	main
tuua	doc_491521501752_item	2471179	et	3	main
loodan	doc_491521501752_item	2471180	et	3	main
et	doc_491521501752_item	2471181	et	3	main
nimi	doc_491521501752_item	2471188	et	3	main
lõbusad	doc_491521501752_item	2470825	et	3	main
jooned	doc_491521501752_item	2470828	et	3	main
just	doc_491521501752_item	2470830	et	3	main
oma	doc_491521501752_item	2470837	et	4	main
laule	doc_491521501752_item	2470838	et	4	main
ja	doc_491521501752_item	2470848	et	3	main
esimesel	doc_491521501752_item	2470868	et	3	main
üldlaulupeol	doc_491521501752_item	2470869	et	4	main
4esti	doc_491521501752_item	2470871	et	4	main
eesti	doc_491521501752_item	2470880	et	4	main
ajal	doc_491521501752_item	2470889	et	4	main
20	doc_491521501752_item	2470897	et	2	main
kultuuri	doc_491521501752_item	2470901	et	4	main
toimus	doc_491521501752_item	2470907	et	3	main
igasuguseid	doc_491521501752_item	2470909	et	3	main
mis	doc_491521501752_item	2470911	et	4	main
eesti	doc_491521501752_item	2470913	et	4	main
iseseisvuse	doc_491521501752_item	2470918	et	4	main
saamine	doc_491521501752_item	2470919	et	4	main
mitmed	doc_491521501752_item	2470920	et	4	main
jõuda	doc_491521501752_item	2470928	et	3	main
üldisele	doc_491521501752_item	2470929	et	3	main
kultuurile	doc_491521501752_item	2470930	et	3	main
st	doc_491521501752_item	2470931	et	3	main
suruti	doc_491521501752_item	2470932	et	3	main
ja	doc_491521501752_item	2470936	et	3	main
ajal	doc_491521501752_item	2470942	et	4	main
aga	doc_491521501752_item	2470944	et	3	main
arenes	doc_491521501752_item	2470945	et	3	main
rahvuslikule	doc_491521501752_item	2470952	et	3	main
pöörama	doc_491521501752_item	2470956	et	3	main
puudutab	doc_491521501752_item	2470970	et	3	main
laulusse	doc_491521501752_item	2470972	et	3	main
laulavad	doc_491521501752_item	2470983	et	4	main
näiteks	doc_491521501752_item	2471031	et	4	main
oli	doc_491521501752_item	2471038	et	3	main
mingisuguseid	doc_491521501752_item	2471040	et	3	main
eesti	doc_491521501752_item	2471044	et	4	main
teatud	doc_491521501752_item	2471047	et	4	main
ajajärgu	doc_491521501752_item	2471048	et	3	main
bändid	doc_491521501752_item	2471051	et	4	main
juba	doc_491521501752_item	2471054	et	3	main
sellele	doc_491521501752_item	2471065	et	4	main
et	doc_491521501752_item	2471066	et	3	main
maailma	doc_491521501752_item	2471067	et	4	main
teel	doc_491521501752_item	2471070	et	4	main
seda	doc_491521501752_item	2471072	et	3	main
ka	doc_491521501752_item	2471074	et	3	main
iga	doc_491521501752_item	2471079	et	4	main
riik	doc_491521501752_item	2471080	et	3	main
oma	doc_491521501752_item	2471081	et	4	main
see	doc_491521501752_item	2471088	et	3	main
laul	doc_491521501752_item	2471089	et	4	main
erilist	doc_491521501752_item	2470877	et	4	main
andis	doc_491521501752_item	2470879	et	3	main
rahvalaulule	doc_491521501752_item	2470881	et	3	main
just	doc_491521501752_item	2470886	et	3	main
tol	doc_491521501752_item	2470888	et	3	main
rahvusärkami	doc_491521501752_item	2470890	et	4	main
rahvakultuuri	doc_491521501752_item	2470891	et	4	main
arengule	doc_491521501752_item	2470892	et	3	main
pöörati	doc_491521501752_item	2470893	et	3	main
suurt	doc_491521501752_item	2470894	et	3	main
tähelepanu	doc_491521501752_item	2470895	et	4	main
algus	doc_491521501752_item	2470899	et	4	main
arengu	doc_491521501752_item	2470902	et	3	main
sajandil	doc_491521501752_item	2470906	et	3	main
palju	doc_491521501752_item	2470908	et	4	main
värvingut	doc_491521501752_item	2470878	et	3	main
omane	doc_491521501752_item	2470885	et	3	main
aeg	doc_491521501752_item	2470904	et	3	main
sündmusi	doc_491521501752_item	2470910	et	3	main
mõjutasid	doc_491521501752_item	2470912	et	4	main
arengule	doc_491521501752_item	2470916	et	3	main
okupatsioonid	doc_491521501752_item	2470921	et	3	main
taasiseisvuse	doc_491521501752_item	2470923	et	4	main
alla	doc_491521501752_item	2470935	et	3	main
mõlema	doc_491521501752_item	2470940	et	3	main
eesti	doc_491521501752_item	2470947	et	4	main
iseisvuse	doc_491521501752_item	2470948	et	4	main
oli	doc_491521501752_item	2470959	et	3	main
aga	doc_491521501752_item	2470961	et	3	main
saamisega	doc_491521501752_item	2470963	et	4	main
tuli	doc_491521501752_item	2470964	et	4	main
üks	doc_491521501752_item	2470965	et	3	main
probleem	doc_491521501752_item	2470966	et	3	main
konkreetselt	doc_491521501752_item	2470973	et	4	main
ilmuma	doc_491521501752_item	2470977	et	3	main
kaasaegseid	doc_491521501752_item	2470984	et	3	main
muusikas	doc_491521501752_item	2471023	et	3	main
rahvuslikke	doc_491521501752_item	2471026	et	3	main
võrrelda	doc_491521501752_item	2471029	et	4	main
isegi	doc_491521501752_item	2471030	et	4	main
märgata	doc_491521501752_item	2471035	et	4	main
esimestes	doc_491521501752_item	2471037	et	4	main
eriliseid	doc_491521501752_item	2471041	et	4	main
silmapaistvaid	doc_491521501752_item	2471043	et	3	main
laulu	doc_491521501752_item	2471045	et	4	main
arengu	doc_491521501752_item	2471046	et	3	main
tänased	doc_491521501752_item	2471050	et	3	main
valivad	doc_491521501752_item	2471053	et	4	main
esitleb	doc_491521501752_item	2471078	et	3	main
saan	doc_491521501752_item	2471086	et	4	main
peab	doc_491521501752_item	2471090	et	4	main
olema	doc_491521501752_item	2471091	et	4	main
selle	doc_491521501752_item	2471092	et	4	main
üldistamisega	doc_491521501752_item	2471121	et	4	main
vastu	doc_491521501752_item	2471140	et	3	main
inimesed	doc_491521501752_item	2471142	et	3	main
aru	doc_491521501752_item	2471144	et	4	main
entusiastidele	doc_491521501752_item	2471156	et	3	main
eesti	doc_491521501752_item	2471158	et	4	main
traditsiooniline	doc_491521501752_item	2471159	et	4	main
ei	doc_491521501752_item	2471173	et	4	main
ka	doc_491521501752_item	2471184	et	3	main
perekonnanimi	doc_491521501752_item	2471189	et	3	main
kultuuri	doc_491521501752_item	2470939	et	4	main
hakati	doc_491521501752_item	2470950	et	3	main
juurde	doc_491521501752_item	2470967	et	4	main
mis	doc_491521501752_item	2470969	et	4	main
eesti	doc_491521501752_item	2470971	et	4	main
nüüd	doc_491521501752_item	2470975	et	4	main
hakkasid	doc_491521501752_item	2470976	et	4	main
bändid	doc_491521501752_item	2470979	et	4	main
ja	doc_491521501752_item	2470980	et	3	main
poplauljad	doc_491521501752_item	2470981	et	3	main
ei	doc_491521501752_item	2470987	et	4	main
tohi	doc_491521501752_item	2470988	et	4	main
ette	doc_491521501752_item	2470989	et	4	main
heita	doc_491521501752_item	2470990	et	3	main
mood	doc_491521501752_item	2470991	et	3	main
ja	doc_491521501752_item	2470992	et	3	main
rahvas	doc_491521501752_item	2470993	et	4	main
nõuavad	doc_491521501752_item	2470994	et	4	main
sedalaadi	doc_491521501752_item	2470995	et	4	main
esitajaid	doc_491521501752_item	2470996	et	4	main
kuid	doc_491521501752_item	2470997	et	4	main
midagi	doc_491521501752_item	2470998	et	4	main
me	doc_491521501752_item	2470999	et	4	main
oleme	doc_491521501752_item	2471000	et	3	main
kaotanud	doc_491521501752_item	2471001	et	4	main
praegune	doc_491521501752_item	2471002	et	3	main
muusika	doc_491521501752_item	2471003	et	4	main
on	doc_491521501752_item	2471004	et	4	main
väga	doc_491521501752_item	2471005	et	3	main
ühetaoline	doc_491521501752_item	2471006	et	3	main
mõnikord	doc_491521501752_item	2471007	et	3	main
ei	doc_491521501752_item	2471008	et	4	main
saagi	doc_491521501752_item	2471009	et	4	main
eristada	doc_491521501752_item	2471010	et	3	main
kas	doc_491521501752_item	2471011	et	3	main
laulab	doc_491521501752_item	2471012	et	3	main
eesti	doc_491521501752_item	2471013	et	4	main
või	doc_491521501752_item	2471014	et	4	main
ütleme	doc_491521501752_item	2471015	et	3	main
mingi	doc_491521501752_item	2471016	et	4	main
inglise	doc_491521501752_item	2471017	et	4	main
bänd	doc_491521501752_item	2471018	et	3	main
meie	doc_491521501752_item	2471019	et	4	main
oleme	doc_491521501752_item	2471020	et	3	main
kaotamas	doc_491521501752_item	2471024	et	3	main
jooni	doc_491521501752_item	2471027	et	4	main
võib	doc_491521501752_item	2471034	et	3	main
eesti	doc_491521501752_item	2471055	et	4	main
ajal	doc_491521501752_item	2470926	et	4	main
püüti	doc_491521501752_item	2470927	et	3	main
taassündi	doc_491521501752_item	2470949	et	4	main
jälle	doc_491521501752_item	2470951	et	3	main
kultuurile	doc_491521501752_item	2470953	et	3	main
tähelepanu	doc_491521501752_item	2470955	et	4	main
nagu	doc_491521501752_item	2470957	et	3	main
rahvusärkamisajal	doc_491521501752_item	2470960	et	3	main
laule	doc_491521501752_item	2470985	et	4	main
ja	doc_491521501752_item	2471022	et	3	main
põliseid	doc_491521501752_item	2471025	et	4	main
kui	doc_491521501752_item	2471028	et	3	main
siis	doc_491521501752_item	2471033	et	3	main
et	doc_491521501752_item	2471036	et	3	main
ja	doc_491521501752_item	2471042	et	3	main
jooni	doc_491521501752_item	2471049	et	4	main
nimetusi	doc_491521501752_item	2471058	et	4	main
laulja	doc_491521501752_item	2471082	et	4	main
ning	doc_491521501752_item	2471083	et	3	main
nagu	doc_491521501752_item	2471084	et	3	main
riigi	doc_491521501752_item	2471093	et	3	main
kultuuri	doc_491521501752_item	2471094	et	4	main
esindaja	doc_491521501752_item	2471095	et	4	main
kes	doc_491521501752_item	2471096	et	4	main
tuleb	doc_491521501752_item	2471097	et	3	main
võistlustele	doc_491521501752_item	2471098	et	3	main
ja	doc_491521501752_item	2471099	et	3	main
näitab	doc_491521501752_item	2471100	et	3	main
oma	doc_491521501752_item	2471101	et	4	main
rahvuskultuuri	doc_491521501752_item	2471102	et	4	main
iseloomustavaid	doc_491521501752_item	2471103	et	4	main
jooni	doc_491521501752_item	2471104	et	4	main
miks	doc_491521501752_item	2471105	et	4	main
siis	doc_491521501752_item	2471106	et	3	main
kõik	doc_491521501752_item	2471107	et	4	main
laulavad	doc_491521501752_item	2471108	et	4	main
inglise	doc_491521501752_item	2471109	et	4	main
keeles	doc_491521501752_item	2471110	et	4	main
eesti	doc_491521501752_item	2471111	et	4	main
lauljade	doc_491521501752_item	2471112	et	4	main
kõrged	doc_491521501752_item	2471113	et	3	main
kohad	doc_491521501752_item	2471114	et	4	main
euroviisionil	doc_491521501752_item	2471115	et	4	main
näitavad	doc_491521501752_item	2471116	et	4	main
et	doc_491521501752_item	2471117	et	3	main
eesti	doc_491521501752_item	2471118	et	4	main
kohaneb	doc_491521501752_item	2471119	et	3	main
kultuuri	doc_491521501752_item	2471120	et	4	main
traditsioonilise	doc_491521501752_item	2471137	et	4	main
paljud	doc_491521501752_item	2471141	et	3	main
tänu	doc_491521501752_item	2471154	et	4	main
laul	doc_491521501752_item	2471160	et	4	main
ning	doc_491521501752_item	2471161	et	3	main
elab	doc_491521501752_item	2471162	et	3	main
lugupeetud	doc_491521501752_item	2471167	et	4	main
saan	doc_491521501752_item	2471182	et	4	main
arvestuse	doc_491521501752_item	2471183	et	4	main
parimate	doc_491521501752_item	2471186	et	4	main
võõrapäraseid	doc_491521501752_item	2471057	et	4	main
mis	doc_491521501752_item	2471059	et	4	main
siis	doc_491521501752_item	2471060	et	3	main
rääkida	doc_491521501752_item	2471061	et	3	main
muust	doc_491521501752_item	2471062	et	4	main
see	doc_491521501752_item	2471063	et	3	main
viitab	doc_491521501752_item	2471064	et	3	main
on	doc_491521501752_item	2471069	et	4	main
ma	doc_491521501752_item	2471085	et	3	main
hästi	doc_491521501752_item	2471122	et	3	main
seas	doc_491521501752_item	2471130	et	4	main
ajal	doc_491521501752_item	2471133	et	4	main
kasvab	doc_491521501752_item	2471134	et	3	main
laulu	doc_491521501752_item	2471139	et	4	main
popkultuuri	doc_491521501752_item	2471146	et	4	main
jälgimine	doc_491521501752_item	2471147	et	4	main
hävitab	doc_491521501752_item	2471148	et	3	main
et	doc_491521501752_item	2471153	et	3	main
veel	doc_491521501752_item	2471163	et	4	main
perekonnanimi	doc_491521501752_item	2471169	et	3	main
seoses	doc_491521501752_item	2471171	et	4	main
mina	doc_491521501752_item	2471175	et	4	main
määratud	doc_491521501752_item	2471176	et	4	main
soovidega	doc_491521501752_item	2471187	et	3	main
kuid	doc_491521501752_item	2471123	et	4	main
rõõmu	doc_491521501752_item	2471124	et	4	main
pakub	doc_491521501752_item	2471125	et	3	main
kahtlemata	doc_491521501752_item	2471126	et	4	main
see	doc_491521501752_item	2471127	et	3	main
et	doc_491521501752_item	2471128	et	3	main
just	doc_491521501752_item	2471131	et	3	main
reegivärsilise	doc_491521501752_item	2471138	et	4	main
saavad	doc_491521501752_item	2471143	et	4	main
et	doc_491521501752_item	2471145	et	3	main
kindel	doc_491521501752_item	2471152	et	3	main
sellistele	doc_491521501752_item	2471155	et	4	main
säilib	doc_491521501752_item	2471157	et	3	main
aega	doc_491521501752_item	2471165	et	4	main
ps	doc_491521501752_item	2471166	et	4	main
kahjuks	doc_491521501752_item	2471170	et	4	main
haigusega	doc_491521501752_item	2471172	et	4	main
saanud	doc_491521501752_item	2471174	et	4	main
hiljem	doc_491521501752_item	2471185	et	3	main
perekonnanimi	doc_491521501754_item	2472015	et	3	main
keelt	doc_491521501754_item	2472043	et	4	main
oli	doc_491521501754_item	2472049	et	3	main
ai	doc_491521501754_item	2472062	et	4	main
on	doc_491521501754_item	2472072	et	4	main
vene	doc_491521501754_item	2472104	et	4	main
lapsepõlves	doc_491521501754_item	2472118	et	4	main
keelt	doc_491521501754_item	2472128	et	4	main
eesti	doc_491521501754_item	2472132	et	4	main
õppima	doc_491521501754_item	2472136	et	3	main
sõnu	doc_491521501754_item	2472140	et	4	main
ja	doc_491521501754_item	2472141	et	3	main
30-aastasena	doc_491521501754_item	2472151	et	4	main
pool	doc_491521501754_item	2472154	et	4	main
tunni	doc_491521501754_item	2472163	et	3	main
kursus	doc_491521501754_item	2472168	et	3	main
ai	doc_491521501754_item	2472029	et	4	main
spontaanset	doc_491521501754_item	2472030	et	3	main
kõnet	doc_491521501754_item	2472031	et	3	main
otsuse	doc_491521501754_item	2472033	et	3	main
aitas	doc_491521501754_item	2472035	et	3	main
asjaolu	doc_491521501754_item	2472037	et	4	main
et	doc_491521501754_item	2472038	et	3	main
hakkasin	doc_491521501754_item	2472039	et	3	main
õpetama	doc_491521501754_item	2472040	et	3	main
talle	doc_491521501754_item	2472041	et	4	main
ning	doc_491521501754_item	2472047	et	3	main
endal	doc_491521501754_item	2472050	et	4	main
huvitav	doc_491521501754_item	2472051	et	4	main
korraldada	doc_491521501754_item	2472061	et	3	main
keeleoskus	doc_491521501754_item	2472065	et	3	main
a	doc_491521501754_item	2472066	et	4	main
47-aastane	doc_491521501754_item	2472068	et	4	main
keel	doc_491521501754_item	2472105	et	4	main
ta	doc_491521501754_item	2472109	et	4	main
iseseisvalt	doc_491521501754_item	2472131	et	4	main
iseseisvalt	doc_491521501754_item	2472138	et	4	main
keele	doc_491521501754_item	2472157	et	4	main
intensiivkursustel	doc_491521501754_item	2472158	et	3	main
kus	doc_491521501754_item	2472159	et	3	main
õpiti	doc_491521501754_item	2472160	et	3	main
tööpäeviti	doc_491521501754_item	2472161	et	4	main
kaupa	doc_491521501754_item	2472164	et	4	main
sõnul	doc_491521501754_item	2472166	et	3	main
grammatika	doc_491521501754_item	2472171	et	4	main
eratunde	doc_491521501754_item	2472199	et	4	main
aastal	doc_491521501754_item	2472201	et	3	main
õppis	doc_491521501754_item	2472208	et	3	main
tõlkis	doc_491521501754_item	2472210	et	3	main
lühikesi	doc_491521501754_item	2472211	et	4	main
jutustusi	doc_491521501754_item	2472212	et	4	main
sõnaraamutu	doc_491521501754_item	2472213	et	4	main
talle	doc_491521501754_item	2472232	et	4	main
tellijatega	doc_491521501754_item	2472247	et	4	main
meie	doc_491521501754_item	2472250	et	4	main
tuttavad	doc_491521501754_item	2472252	et	4	main
eesti	doc_491521501754_item	2472259	et	4	main
õpetama	doc_491521501754_item	2472261	et	3	main
tallinna	doc_491521501754_item	2472009	et	4	main
eesnimi	doc_491521501754_item	2472014	et	3	main
2001	doc_491521501754_item	2472017	et	2	main
analüüs	doc_491521501754_item	2472008	et	3	main
kontrastiivlingvistikas	doc_491521501754_item	2472013	et	4	main
tallinn	doc_491521501754_item	2472016	et	4	main
teha	doc_491521501754_item	2472020	et	3	main
lindistada	doc_491521501754_item	2472024	et	3	main
ühe	doc_491521501754_item	2472025	et	4	main
kaasa	doc_491521501754_item	2472036	et	4	main
alles	doc_491521501754_item	2472044	et	3	main
algusest	doc_491521501754_item	2472046	et	4	main
mul	doc_491521501754_item	2472048	et	3	main
et	doc_491521501754_item	2472057	et	3	main
õppetööd	doc_491521501754_item	2472059	et	4	main
ukraina	doc_491521501754_item	2472069	et	4	main
venelane	doc_491521501754_item	2472070	et	3	main
kuid	doc_491521501754_item	2472106	et	4	main
vabalt	doc_491521501754_item	2472110	et	4	main
keelt	doc_491521501754_item	2472112	et	4	main
ülikooli	doc_491521501754_item	2472121	et	4	main
õppis	doc_491521501754_item	2472123	et	3	main
õppis	doc_491521501754_item	2472129	et	3	main
a	doc_491521501754_item	2472130	et	4	main
a	doc_491521501754_item	2472135	et	4	main
oma	doc_491521501754_item	2472148	et	4	main
kõnes	doc_491521501754_item	2472149	et	3	main
kasutada	doc_491521501754_item	2472150	et	3	main
a	doc_491521501754_item	2472153	et	4	main
aastat	doc_491521501754_item	2472155	et	3	main
eesti	doc_491521501754_item	2472197	et	4	main
keele	doc_491521501754_item	2472198	et	4	main
kaks	doc_491521501754_item	2472203	et	3	main
kursust	doc_491521501754_item	2472205	et	3	main
telerist	doc_491521501754_item	2472217	et	4	main
pedagoogikaülikool	doc_491521501754_item	2472010	et	4	main
veaanalüüs	doc_491521501754_item	2472011	et	4	main
kodutöö	doc_491521501754_item	2472012	et	4	main
kommentaar	doc_491521501754_item	2472018	et	3	main
et	doc_491521501754_item	2472019	et	3	main
olen	doc_491521501754_item	2472022	et	3	main
otsustanud	doc_491521501754_item	2472023	et	4	main
sellise	doc_491521501754_item	2472032	et	4	main
langetamisele	doc_491521501754_item	2472034	et	4	main
novembri	doc_491521501754_item	2472045	et	3	main
tema	doc_491521501754_item	2472052	et	4	main
vigu	doc_491521501754_item	2472053	et	3	main
rühmitada	doc_491521501754_item	2472054	et	3	main
ja	doc_491521501754_item	2472055	et	3	main
analüüsida	doc_491521501754_item	2472056	et	3	main
edaspidist	doc_491521501754_item	2472058	et	3	main
paremini	doc_491521501754_item	2472060	et	4	main
ja	doc_491521501754_item	2472064	et	3	main
on	doc_491521501754_item	2472103	et	4	main
räägib	doc_491521501754_item	2472108	et	3	main
kooli	doc_491521501754_item	2472119	et	4	main
ja	doc_491521501754_item	2472120	et	3	main
veaanalüüsi	doc_491521501754_item	2472021	et	4	main
oma	doc_491521501754_item	2472026	et	4	main
eraõpilase	doc_491521501754_item	2472027	et	3	main
edaspidi	doc_491521501754_item	2472028	et	3	main
eesti	doc_491521501754_item	2472042	et	4	main
iseloomustus	doc_491521501754_item	2472063	et	4	main
on	doc_491521501754_item	2472067	et	4	main
ta	doc_491521501754_item	2472071	et	4	main
sündinud	doc_491521501754_item	2472073	et	4	main
1955	doc_491521501754_item	2472074	et	2	main
aastal	doc_491521501754_item	2472075	et	3	main
harkovis	doc_491521501754_item	2472076	et	4	main
lõpetades	doc_491521501754_item	2472077	et	3	main
ülikooli	doc_491521501754_item	2472078	et	4	main
1978	doc_491521501754_item	2472079	et	2	main
aastal	doc_491521501754_item	2472080	et	3	main
tuli	doc_491521501754_item	2472081	et	4	main
ta	doc_491521501754_item	2472082	et	4	main
23-aastasena	doc_491521501754_item	2472083	et	4	main
eestisse	doc_491521501754_item	2472084	et	4	main
kolm	doc_491521501754_item	2472085	et	3	main
aastat	doc_491521501754_item	2472086	et	3	main
elas	doc_491521501754_item	2472087	et	3	main
ja	doc_491521501754_item	2472088	et	3	main
töötas	doc_491521501754_item	2472089	et	3	main
ta	doc_491521501754_item	2472090	et	4	main
ks	doc_491521501754_item	2472091	et	4	main
seejärel	doc_491521501754_item	2472092	et	3	main
kolis	doc_491521501754_item	2472093	et	4	main
ta	doc_491521501754_item	2472094	et	4	main
praegu	doc_491521501754_item	2472095	et	3	main
ta	doc_491521501754_item	2472096	et	4	main
on	doc_491521501754_item	2472097	et	4	main
väikese	doc_491521501754_item	2472098	et	4	main
ehitusfirma	doc_491521501754_item	2472099	et	4	main
direktor	doc_491521501754_item	2472100	et	3	main
ai	doc_491521501754_item	2472101	et	4	main
emakeel	doc_491521501754_item	2472102	et	4	main
samuti	doc_491521501754_item	2472107	et	3	main
ukraina	doc_491521501754_item	2472111	et	4	main
kuna	doc_491521501754_item	2472113	et	3	main
õppis	doc_491521501754_item	2472114	et	3	main
selle	doc_491521501754_item	2472115	et	4	main
selgeks	doc_491521501754_item	2472116	et	3	main
juba	doc_491521501754_item	2472117	et	3	main
keelt	doc_491521501754_item	2472126	et	4	main
inglise	doc_491521501754_item	2472127	et	4	main
keelt	doc_491521501754_item	2472133	et	4	main
samuti	doc_491521501754_item	2472137	et	3	main
nelja	doc_491521501754_item	2472162	et	4	main
eriti	doc_491521501754_item	2472170	et	3	main
mõistmisel	doc_491521501754_item	2472172	et	4	main
tagasi	doc_491521501754_item	2472191	et	3	main
ning	doc_491521501754_item	2472192	et	3	main
2001	doc_491521501754_item	2472206	et	2	main
võttis	doc_491521501754_item	2472222	et	3	main
tänavu	doc_491521501754_item	2472224	et	3	main
ta	doc_491521501754_item	2472227	et	4	main
jälle	doc_491521501754_item	2472228	et	3	main
saaks	doc_491521501754_item	2472246	et	3	main
suhelda	doc_491521501754_item	2472249	et	4	main
soovitasid	doc_491521501754_item	2472253	et	4	main
talle	doc_491521501754_item	2472254	et	4	main
talle	doc_491521501754_item	2472258	et	4	main
meie	doc_491521501754_item	2472262	et	4	main
tund	doc_491521501754_item	2472263	et	3	main
on	doc_491521501754_item	2472264	et	4	main
korraldatud	doc_491521501754_item	2472265	et	4	main
mis	doc_491521501754_item	2472274	et	4	main
päevade	doc_491521501754_item	2472277	et	3	main
läks	doc_491521501754_item	2472281	et	3	main
seejärel	doc_491521501754_item	2472284	et	3	main
on	doc_491521501754_item	2472290	et	4	main
loeme	doc_491521501754_item	2472297	et	3	main
al	doc_491521501754_item	2472306	et	4	main
üsna	doc_491521501754_item	2472308	et	3	main
tugev	doc_491521501754_item	2472309	et	4	main
ta	doc_491521501754_item	2472315	et	4	main
keeleoskuse	doc_491521501754_item	2472317	et	3	main
vene	doc_491521501754_item	2472343	et	4	main
keelt	doc_491521501754_item	2472344	et	4	main
ta	doc_491521501754_item	2472346	et	4	main
nendega	doc_491521501754_item	2472347	et	4	main
ta	doc_491521501754_item	2472352	et	4	main
arvab	doc_491521501754_item	2472353	et	3	main
et	doc_491521501754_item	2472354	et	3	main
eestis	doc_491521501754_item	2472355	et	3	main
eesti	doc_491521501754_item	2472359	et	4	main
keeleoskuse	doc_491521501754_item	2472362	et	3	main
tase	doc_491521501754_item	2472363	et	3	main
a	doc_491521501754_item	2472367	et	4	main
üsna	doc_491521501754_item	2472368	et	3	main
hästi	doc_491521501754_item	2472369	et	3	main
grammatikaülesandeid	doc_491521501754_item	2472370	et	3	main
mis	doc_491521501754_item	2472405	et	4	main
on	doc_491521501754_item	2472406	et	4	main
kasutab	doc_491521501754_item	2472410	et	3	main
vot	doc_491521501754_item	2472412	et	3	main
vrd	doc_491521501754_item	2472414	et	4	main
emotsionaalseks	doc_491521501754_item	2472421	et	3	main
on	doc_491521501754_item	2472429	et	4	main
keele	doc_491521501754_item	2472432	et	4	main
puhul	doc_491521501754_item	2472440	et	4	main
tema	doc_491521501754_item	2472445	et	4	main
on	doc_491521501754_item	2472447	et	4	main
üsna	doc_491521501754_item	2472448	et	3	main
rikkalik	doc_491521501754_item	2472449	et	3	main
ajab	doc_491521501754_item	2472450	et	3	main
ta	doc_491521501754_item	2472451	et	4	main
segi	doc_491521501754_item	2472452	et	3	main
me	doc_491521501754_item	2472488	et	4	main
kell	doc_491521501754_item	2472500	et	3	main
pärast	doc_491521501754_item	2472509	et	4	main
loodan	doc_491521501754_item	2472514	et	3	main
jõuan	doc_491521501754_item	2472517	et	3	main
midagi	doc_491521501754_item	2472523	et	4	main
ajal	doc_491521501754_item	2472122	et	4	main
ta	doc_491521501754_item	2472124	et	4	main
saksa	doc_491521501754_item	2472125	et	4	main
hakkas	doc_491521501754_item	2472134	et	3	main
õppis	doc_491521501754_item	2472139	et	3	main
fraase	doc_491521501754_item	2472142	et	3	main
õpiku	doc_491521501754_item	2472143	et	3	main
järgi	doc_491521501754_item	2472144	et	4	main
ja	doc_491521501754_item	2472145	et	3	main
püüdis	doc_491521501754_item	2472146	et	3	main
neid	doc_491521501754_item	2472147	et	4	main
käis	doc_491521501754_item	2472152	et	4	main
eesti	doc_491521501754_item	2472156	et	4	main
ai	doc_491521501754_item	2472165	et	4	main
oli	doc_491521501754_item	2472167	et	3	main
kasulik	doc_491521501754_item	2472169	et	3	main
järgnevatel	doc_491521501754_item	2472173	et	4	main
aastatel	doc_491521501754_item	2472174	et	4	main
ei	doc_491521501754_item	2472175	et	4	main
tegelenud	doc_491521501754_item	2472176	et	4	main
ta	doc_491521501754_item	2472177	et	4	main
eesti	doc_491521501754_item	2472178	et	4	main
keelega	doc_491521501754_item	2472179	et	3	main
üldse	doc_491521501754_item	2472180	et	3	main
kuna	doc_491521501754_item	2472181	et	3	main
elas	doc_491521501754_item	2472182	et	3	main
ja	doc_491521501754_item	2472183	et	3	main
töötas	doc_491521501754_item	2472184	et	3	main
venemaal	doc_491521501754_item	2472185	et	4	main
1997	doc_491521501754_item	2472186	et	2	main
aastal	doc_491521501754_item	2472187	et	3	main
tuli	doc_491521501754_item	2472188	et	4	main
ta	doc_491521501754_item	2472189	et	4	main
eestisse	doc_491521501754_item	2472190	et	4	main
1998	doc_491521501754_item	2472193	et	2	main
aastal	doc_491521501754_item	2472194	et	3	main
hakkas	doc_491521501754_item	2472195	et	3	main
võtma	doc_491521501754_item	2472196	et	3	main
läbis	doc_491521501754_item	2472202	et	3	main
prossumi	doc_491521501754_item	2472204	et	4	main
aastast	doc_491521501754_item	2472207	et	4	main
iseseisvalt	doc_491521501754_item	2472209	et	4	main
eestikeelseid	doc_491521501754_item	2472218	et	3	main
saateid	doc_491521501754_item	2472219	et	3	main
ning	doc_491521501754_item	2472220	et	3	main
et	doc_491521501754_item	2472235	et	3	main
õpetatakse	doc_491521501754_item	2472237	et	3	main
ainult	doc_491521501754_item	2472238	et	4	main
tasemeeksamiteks	doc_491521501754_item	2472239	et	3	main
tema	doc_491521501754_item	2472240	et	4	main
on	doc_491521501754_item	2472242	et	4	main
rääkima	doc_491521501754_item	2472243	et	3	main
õppida	doc_491521501754_item	2472244	et	3	main
et	doc_491521501754_item	2472245	et	3	main
hakkasingi	doc_491521501754_item	2472257	et	3	main
järgnevalt	doc_491521501754_item	2472266	et	4	main
ta	doc_491521501754_item	2472271	et	4	main
seejärel	doc_491521501754_item	2472294	et	3	main
grammatikaga	doc_491521501754_item	2472296	et	3	main
eesti	doc_491521501754_item	2472310	et	4	main
on	doc_491521501754_item	2472314	et	4	main
enda	doc_491521501754_item	2472316	et	4	main
väga	doc_491521501754_item	2472319	et	3	main
2000	doc_491521501754_item	2472200	et	2	main
abil	doc_491521501754_item	2472214	et	4	main
ja	doc_491521501754_item	2472215	et	3	main
vaatas	doc_491521501754_item	2472216	et	3	main
sügisel	doc_491521501754_item	2472225	et	3	main
ei	doc_491521501754_item	2472233	et	4	main
seal	doc_491521501754_item	2472236	et	4	main
ühised	doc_491521501754_item	2472251	et	3	main
umbes	doc_491521501754_item	2472268	et	4	main
pool	doc_491521501754_item	2472269	et	4	main
tundi	doc_491521501754_item	2472270	et	4	main
juhtus	doc_491521501754_item	2472275	et	3	main
möödunud	doc_491521501754_item	2472276	et	4	main
jooksul	doc_491521501754_item	2472278	et	4	main
ning	doc_491521501754_item	2472279	et	3	main
kuidas	doc_491521501754_item	2472280	et	3	main
ta	doc_491521501754_item	2472286	et	4	main
mida	doc_491521501754_item	2472288	et	4	main
huvitavat	doc_491521501754_item	2472289	et	4	main
viimati	doc_491521501754_item	2472292	et	3	main
enesehinnang	doc_491521501754_item	2472304	et	3	main
õppimise	doc_491521501754_item	2472312	et	4	main
räägib	doc_491521501754_item	2472322	et	3	main
ta	doc_491521501754_item	2472324	et	4	main
on	doc_491521501754_item	2472325	et	4	main
keeltes	doc_491521501754_item	2472326	et	3	main
täiesti	doc_491521501754_item	2472327	et	3	main
andetu	doc_491521501754_item	2472328	et	4	main
tellijatest	doc_491521501754_item	2472341	et	4	main
osata	doc_491521501754_item	2472358	et	4	main
grammatikareegleid	doc_491521501754_item	2472365	et	3	main
tunneb	doc_491521501754_item	2472366	et	3	main
teeb	doc_491521501754_item	2472371	et	3	main
alustab	doc_491521501754_item	2472397	et	3	main
et	doc_491521501754_item	2472404	et	3	main
vene	doc_491521501754_item	2472407	et	4	main
parasiitsõnu	doc_491521501754_item	2472411	et	3	main
no	doc_491521501754_item	2472413	et	3	main
jutt	doc_491521501754_item	2472418	et	3	main
aeg-ajalt	doc_491521501754_item	2472221	et	4	main
eratunde	doc_491521501754_item	2472223	et	4	main
tahtis	doc_491521501754_item	2472226	et	3	main
kursustele	doc_491521501754_item	2472229	et	3	main
minna	doc_491521501754_item	2472230	et	3	main
kuid	doc_491521501754_item	2472231	et	4	main
sobinud	doc_491521501754_item	2472234	et	4	main
eesmärk	doc_491521501754_item	2472241	et	3	main
vabalt	doc_491521501754_item	2472248	et	4	main
mind	doc_491521501754_item	2472255	et	4	main
nii	doc_491521501754_item	2472256	et	3	main
keelt	doc_491521501754_item	2472260	et	4	main
räägib	doc_491521501754_item	2472272	et	3	main
tööpäev	doc_491521501754_item	2472283	et	3	main
küsib	doc_491521501754_item	2472285	et	3	main
minuga	doc_491521501754_item	2472291	et	3	main
tegeleme	doc_491521501754_item	2472295	et	3	main
ja	doc_491521501754_item	2472299	et	3	main
ai	doc_491521501754_item	2472301	et	4	main
keele	doc_491521501754_item	2472311	et	4	main
eesti	doc_491521501754_item	2472330	et	4	main
keelt	doc_491521501754_item	2472331	et	4	main
ta	doc_491521501754_item	2472372	et	4	main
peaaegu	doc_491521501754_item	2472373	et	3	main
lauset	doc_491521501754_item	2472399	et	3	main
sidesõnadest	doc_491521501754_item	2472400	et	3	main
ning	doc_491521501754_item	2472402	et	3	main
nu	doc_491521501754_item	2472416	et	4	main
väga	doc_491521501754_item	2472420	et	3	main
vene	doc_491521501754_item	2472424	et	4	main
üle	doc_491521501754_item	2472426	et	3	main
leksikaalsed	doc_491521501754_item	2472442	et	3	main
hääldusvigu	doc_491521501754_item	2472460	et	3	main
praegu	doc_491521501754_item	2472483	et	3	main
sõiduks	doc_491521501754_item	2472486	et	3	main
kohal	doc_491521501754_item	2472498	et	4	main
juba	doc_491521501754_item	2472499	et	3	main
pärast	doc_491521501754_item	2472503	et	4	main
ma	doc_491521501754_item	2472513	et	3	main
ma	doc_491521501754_item	2472516	et	3	main
aga	doc_491521501754_item	2472521	et	3	main
helistan	doc_491521501754_item	2472527	et	3	main
teile	doc_491521501754_item	2472528	et	4	main
mul	doc_491521501754_item	2472558	et	3	main
võimalust	doc_491521501754_item	2472561	et	3	main
pean	doc_491521501754_item	2472610	et	4	main
ma	doc_491521501754_item	2472614	et	3	main
on	doc_491521501754_item	2472618	et	4	main
jõudne	doc_491521501754_item	2472621	et	4	main
ma	doc_491521501754_item	2472624	et	3	main
tulevad	doc_491521501754_item	2472628	et	4	main
ja	doc_491521501754_item	2472631	et	3	main
et	doc_491521501754_item	2472638	et	3	main
ma	doc_491521501754_item	2472639	et	3	main
tagasi	doc_491521501754_item	2472644	et	3	main
korteris	doc_491521501754_item	2472646	et	3	main
lõppenud	doc_491521501754_item	2472650	et	4	main
sellepärast	doc_491521501754_item	2472651	et	3	main
mul	doc_491521501754_item	2472652	et	3	main
ei	doc_491521501754_item	2472653	et	4	main
mis	doc_491521501754_item	2472676	et	4	main
on	doc_491521501754_item	2472679	et	4	main
elu	doc_491521501754_item	2472680	et	4	main
üldse	doc_491521501754_item	2472684	et	3	main
aega	doc_491521501754_item	2472686	et	4	main
töötada	doc_491521501754_item	2472698	et	3	main
kiiresti	doc_491521501754_item	2472721	et	3	main
üks	doc_491521501754_item	2472724	et	3	main
see	doc_491521501754_item	2472726	et	3	main
on	doc_491521501754_item	2472727	et	4	main
küsib	doc_491521501754_item	2472740	et	3	main
saa	doc_491521501754_item	2472754	et	4	main
esiteks	doc_491521501754_item	2472755	et	3	main
võimalust	doc_491521501754_item	2472770	et	3	main
teha	doc_491521501754_item	2472774	et	3	main
nad	doc_491521501754_item	2472775	et	3	main
et	doc_491521501754_item	2472777	et	3	main
жалко	doc_491521501754_item	2472788	et	2	main
ei	doc_491521501754_item	2472791	et	4	main
no	doc_491521501754_item	2472793	et	3	main
midagi	doc_491521501754_item	2472794	et	4	main
teha	doc_491521501754_item	2472795	et	3	main
ei	doc_491521501754_item	2472796	et	4	main
alguses	doc_491521501754_item	2472267	et	4	main
sellest	doc_491521501754_item	2472273	et	4	main
tänane	doc_491521501754_item	2472282	et	3	main
minult	doc_491521501754_item	2472287	et	3	main
juhtunud	doc_491521501754_item	2472293	et	4	main
tekste	doc_491521501754_item	2472298	et	3	main
vestleme	doc_491521501754_item	2472300	et	3	main
õpimotivatsioon	doc_491521501754_item	2472302	et	3	main
ja	doc_491521501754_item	2472303	et	3	main
kuigi	doc_491521501754_item	2472305	et	3	main
on	doc_491521501754_item	2472307	et	4	main
motivatsioon	doc_491521501754_item	2472313	et	3	main
suhtes	doc_491521501754_item	2472318	et	4	main
kriitiline	doc_491521501754_item	2472320	et	3	main
ta	doc_491521501754_item	2472321	et	4	main
et	doc_491521501754_item	2472323	et	3	main
on	doc_491521501754_item	2472332	et	4	main
tal	doc_491521501754_item	2472333	et	3	main
hädasti	doc_491521501754_item	2472334	et	3	main
tarvis	doc_491521501754_item	2472335	et	3	main
vaatamata	doc_491521501754_item	2472336	et	4	main
oskab	doc_491521501754_item	2472342	et	3	main
tahab	doc_491521501754_item	2472345	et	3	main
eesti	doc_491521501754_item	2472348	et	4	main
elades	doc_491521501754_item	2472356	et	4	main
tuleb	doc_491521501754_item	2472357	et	3	main
keelele	doc_491521501754_item	2472408	et	4	main
vene	doc_491521501754_item	2472415	et	4	main
muutub	doc_491521501754_item	2472419	et	3	main
läheb	doc_491521501754_item	2472422	et	3	main
a	doc_491521501754_item	2472423	et	4	main
keelele	doc_491521501754_item	2472425	et	4	main
vene	doc_491521501754_item	2472431	et	4	main
sõnajärg	doc_491521501754_item	2472433	et	3	main
kõnes	doc_491521501754_item	2472434	et	3	main
domineerivad	doc_491521501754_item	2472435	et	4	main
lihtlaused	doc_491521501754_item	2472436	et	3	main
sagedased	doc_491521501754_item	2472437	et	3	main
ka	doc_491521501754_item	2472441	et	3	main
kõlaliselt	doc_491521501754_item	2472453	et	4	main
mõningaid	doc_491521501754_item	2472459	et	3	main
a	doc_491521501754_item	2472463	et	4	main
valmistan	doc_491521501754_item	2472485	et	3	main
eesmaspäeval	doc_491521501754_item	2472487	et	4	main
väga	doc_491521501754_item	2472490	et	3	main
kell	doc_491521501754_item	2472493	et	3	main
neli	doc_491521501754_item	2472494	et	3	main
seda	doc_491521501754_item	2472504	et	3	main
võrru	doc_491521501754_item	2472507	et	3	main
me	doc_491521501754_item	2472510	et	4	main
tallinna	doc_491521501754_item	2472512	et	4	main
tagasi	doc_491521501754_item	2472520	et	3	main
juhtub	doc_491521501754_item	2472524	et	3	main
ma	doc_491521501754_item	2472526	et	3	main
ei	doc_491521501754_item	2472535	et	4	main
teha	doc_491521501754_item	2472536	et	3	main
vahet	doc_491521501754_item	2472537	et	3	main
sellepärast	doc_491521501754_item	2472538	et	3	main
et	doc_491521501754_item	2472539	et	3	main
see	doc_491521501754_item	2472550	et	3	main
annab	doc_491521501754_item	2472551	et	3	main
mulle	doc_491521501754_item	2472552	et	4	main
tunnen	doc_491521501754_item	2472555	et	3	main
ole	doc_491521501754_item	2472560	et	4	main
sellepärast	doc_491521501754_item	2472565	et	3	main
no	doc_491521501754_item	2472566	et	3	main
ole	doc_491521501754_item	2472569	et	4	main
plitka	doc_491521501754_item	2472611	et	4	main
võtma	doc_491521501754_item	2472612	et	3	main
haamri	doc_491521501754_item	2472630	et	3	main
kõik	doc_491521501754_item	2472633	et	4	main
ära	doc_491521501754_item	2472634	et	4	main
asi	doc_491521501754_item	2472635	et	4	main
ei	doc_491521501754_item	2472648	et	4	main
ja	doc_491521501754_item	2472661	et	3	main
tegi	doc_491521501754_item	2472663	et	4	main
ja	doc_491521501754_item	2472666	et	3	main
köögis	doc_491521501754_item	2472667	et	3	main
ja	doc_491521501754_item	2472668	et	3	main
praegu	doc_491521501754_item	2472681	et	3	main
meil	doc_491521501754_item	2472687	et	4	main
on	doc_491521501754_item	2472688	et	4	main
kuid	doc_491521501754_item	2472329	et	4	main
sellele	doc_491521501754_item	2472337	et	4	main
et	doc_491521501754_item	2472338	et	3	main
enamik	doc_491521501754_item	2472339	et	3	main
tema	doc_491521501754_item	2472340	et	4	main
keeles	doc_491521501754_item	2472349	et	4	main
suhelda	doc_491521501754_item	2472350	et	4	main
sest	doc_491521501754_item	2472351	et	4	main
keelt	doc_491521501754_item	2472360	et	4	main
ai	doc_491521501754_item	2472361	et	4	main
kuigi	doc_491521501754_item	2472364	et	3	main
vigadeta	doc_491521501754_item	2472374	et	3	main
esineb	doc_491521501754_item	2472375	et	3	main
tema	doc_491521501754_item	2472376	et	4	main
kõnes	doc_491521501754_item	2472377	et	3	main
palju	doc_491521501754_item	2472378	et	4	main
grammatikavigu	doc_491521501754_item	2472379	et	3	main
eriti	doc_491521501754_item	2472380	et	3	main
ühildumis-	doc_491521501754_item	2472381	et	4	main
ja	doc_491521501754_item	2472382	et	3	main
rektsioonivigu	doc_491521501754_item	2472383	et	4	main
verbivormide	doc_491521501754_item	2472384	et	4	main
kasutamise	doc_491521501754_item	2472385	et	4	main
ja	doc_491521501754_item	2472386	et	3	main
infinitiivi	doc_491521501754_item	2472387	et	4	main
ning	doc_491521501754_item	2472388	et	3	main
sisekohakäänete	doc_491521501754_item	2472389	et	3	main
valiku	doc_491521501754_item	2472390	et	3	main
vigu	doc_491521501754_item	2472391	et	3	main
tihti	doc_491521501754_item	2472392	et	3	main
esineb	doc_491521501754_item	2472393	et	3	main
ka	doc_491521501754_item	2472394	et	3	main
interferentsivigu	doc_491521501754_item	2472395	et	4	main
sageli	doc_491521501754_item	2472396	et	3	main
a	doc_491521501754_item	2472398	et	4	main
ja	doc_491521501754_item	2472401	et	3	main
sellepärast	doc_491521501754_item	2472403	et	3	main
tüüpiline	doc_491521501754_item	2472409	et	3	main
kui	doc_491521501754_item	2472417	et	3	main
tema	doc_491521501754_item	2472427	et	4	main
omane	doc_491521501754_item	2472430	et	3	main
a	doc_491521501754_item	2472439	et	4	main
sõnavara	doc_491521501754_item	2472446	et	4	main
paronüümivead	doc_491521501754_item	2472456	et	4	main
esineb	doc_491521501754_item	2472457	et	3	main
ka	doc_491521501754_item	2472458	et	3	main
on	doc_491521501754_item	2472462	et	4	main
lindilt	doc_491521501754_item	2472482	et	3	main
ma	doc_491521501754_item	2472484	et	3	main
väljume	doc_491521501754_item	2472489	et	3	main
vara	doc_491521501754_item	2472491	et	4	main
juba	doc_491521501754_item	2472492	et	3	main
sellepärast	doc_491521501754_item	2472495	et	3	main
peame	doc_491521501754_item	2472496	et	4	main
olema	doc_491521501754_item	2472497	et	4	main
ja	doc_491521501754_item	2472502	et	3	main
sõidame	doc_491521501754_item	2472506	et	3	main
võru	doc_491521501754_item	2472508	et	4	main
tagastame	doc_491521501754_item	2472511	et	3	main
kell	doc_491521501754_item	2472518	et	3	main
kuueks	doc_491521501754_item	2472519	et	4	main
kõnele	doc_491521501754_item	2472428	et	4	main
on	doc_491521501754_item	2472438	et	4	main
vead	doc_491521501754_item	2472443	et	4	main
kuigi	doc_491521501754_item	2472444	et	3	main
sarnaseid	doc_491521501754_item	2472454	et	4	main
sõnu	doc_491521501754_item	2472455	et	4	main
probleemsed	doc_491521501754_item	2472461	et	3	main
jaoks	doc_491521501754_item	2472464	et	4	main
häälikuühendid	doc_491521501754_item	2472465	et	4	main
jõu-	doc_491521501754_item	2472466	et	3	main
ja	doc_491521501754_item	2472467	et	3	main
õu-	doc_491521501754_item	2472468	et	4	main
mõnikord	doc_491521501754_item	2472469	et	3	main
on	doc_491521501754_item	2472470	et	4	main
tal	doc_491521501754_item	2472471	et	3	main
vale	doc_491521501754_item	2472472	et	4	main
intonatsioon	doc_491521501754_item	2472473	et	3	main
ning	doc_491521501754_item	2472474	et	3	main
rõhk	doc_491521501754_item	2472475	et	3	main
ei	doc_491521501754_item	2472476	et	4	main
ole	doc_491521501754_item	2472477	et	4	main
alati	doc_491521501754_item	2472478	et	4	main
esimesel	doc_491521501754_item	2472479	et	3	main
silbil	doc_491521501754_item	2472480	et	3	main
tekst	doc_491521501754_item	2472481	et	3	main
kaheksa	doc_491521501754_item	2472501	et	4	main
me	doc_491521501754_item	2472505	et	4	main
et	doc_491521501754_item	2472515	et	3	main
äkki	doc_491521501754_item	2472522	et	3	main
ei	doc_491521501754_item	2472531	et	4	main
jõua	doc_491521501754_item	2472532	et	4	main
tahaksin	doc_491521501754_item	2472534	et	3	main
me	doc_491521501754_item	2472541	et	4	main
tegeleme	doc_491521501754_item	2472542	et	3	main
palju	doc_491521501754_item	2472553	et	4	main
ma	doc_491521501754_item	2472554	et	3	main
seda	doc_491521501754_item	2472556	et	3	main
teha	doc_491521501754_item	2472564	et	3	main
ei	doc_491521501754_item	2472568	et	4	main
aega	doc_491521501754_item	2472570	et	4	main
selleks	doc_491521501754_item	2472571	et	4	main
üldse	doc_491521501754_item	2472572	et	3	main
vot	doc_491521501754_item	2472573	et	3	main
kui	doc_491521501754_item	2472574	et	3	main
eile	doc_491521501754_item	2472575	et	3	main
kinni	doc_491521501754_item	2472606	et	3	main
keeraamiplitkaga	doc_491521501754_item	2472607	et	4	main
ja	doc_491521501754_item	2472608	et	3	main
ma	doc_491521501754_item	2472609	et	3	main
proovisin	doc_491521501754_item	2472615	et	3	main
see	doc_491521501754_item	2472617	et	3	main
õudne	doc_491521501754_item	2472619	et	3	main
tee	doc_491521501754_item	2472626	et	4	main
võtavad	doc_491521501754_item	2472629	et	3	main
on	doc_491521501754_item	2472636	et	4	main
viis	doc_491521501754_item	2472642	et	4	main
jõudu	doc_491521501754_item	2472655	et	4	main
hääldus	doc_491521501754_item	2472656	et	4	main
ta	doc_491521501754_item	2472662	et	4	main
plitka	doc_491521501754_item	2472664	et	4	main
vannas	doc_491521501754_item	2472665	et	3	main
nüüd	doc_491521501754_item	2472669	et	4	main
pean	doc_491521501754_item	2472670	et	4	main
lammutama	doc_491521501754_item	2472671	et	4	main
see	doc_491521501754_item	2472672	et	3	main
on	doc_491521501754_item	2472673	et	4	main
ei	doc_491521501754_item	2472682	et	4	main
minul	doc_491521501754_item	2472685	et	3	main
on	doc_491521501754_item	2472701	et	4	main
tuled	doc_491521501754_item	2472745	et	4	main
külla	doc_491521501754_item	2472746	et	4	main
ma	doc_491521501754_item	2472747	et	3	main
vaatan	doc_491521501754_item	2472748	et	3	main
et	doc_491521501754_item	2472752	et	3	main
aega	doc_491521501754_item	2472761	et	4	main
ole	doc_491521501754_item	2472769	et	4	main
ootavad	doc_491521501754_item	2472782	et	4	main
ну	doc_491521501754_item	2472786	et	2	main
прям	doc_491521501754_item	2472790	et	2	main
saa	doc_491521501754_item	2472792	et	4	main
la	doc_491521501754_item	2472802	et	4	main
lehte	doc_491521501754_item	2472822	et	4	main
pärast	doc_491521501754_item	2472827	et	4	main
ma	doc_491521501754_item	2472829	et	3	main
me	doc_491521501754_item	2472837	et	4	main
kuhugi	doc_491521501754_item	2472840	et	4	main
ma	doc_491521501754_item	2472844	et	3	main
ukraina	doc_491521501754_item	2472849	et	4	main
ei	doc_491521501754_item	2472850	et	4	main
seda	doc_491521501754_item	2472855	et	3	main
kolm	doc_491521501754_item	2472859	et	3	main
sõit	doc_491521501754_item	2472868	et	3	main
vot	doc_491521501754_item	2472871	et	3	main
siin	doc_491521501754_item	2472872	et	4	main
a	doc_491521501754_item	2472873	et	4	main
näitab	doc_491521501754_item	2472874	et	3	main
esimene	doc_491521501754_item	2472890	et	3	main
tallinnast	doc_491521501754_item	2472895	et	3	main
ja	doc_491521501754_item	2472899	et	3	main
lapimaa	doc_491521501754_item	2472901	et	4	main
terve	doc_491521501754_item	2472902	et	4	main
päev	doc_491521501754_item	2472903	et	3	main
sõidus	doc_491521501754_item	2472904	et	3	main
teine	doc_491521501754_item	2472905	et	3	main
päev	doc_491521501754_item	2472906	et	3	main
posti	doc_491521501754_item	2472921	et	4	main
poijari	doc_491521501754_item	2472924	et	4	main
ringist	doc_491521501754_item	2472925	et	3	main
ma	doc_491521501754_item	2472533	et	3	main
korda	doc_491521501754_item	2472547	et	4	main
nädalas	doc_491521501754_item	2472548	et	3	main
ükskõik	doc_491521501754_item	2472549	et	3	main
kahjuks	doc_491521501754_item	2472557	et	4	main
kodus	doc_491521501754_item	2472562	et	4	main
vot	doc_491521501754_item	2472567	et	3	main
me	doc_491521501754_item	2472576	et	4	main
tulime	doc_491521501754_item	2472577	et	3	main
abikaasaga	doc_491521501754_item	2472578	et	3	main
võimlast	doc_491521501754_item	2472579	et	4	main
kell	doc_491521501754_item	2472580	et	3	main
kuus	doc_491521501754_item	2472581	et	4	main
no	doc_491521501754_item	2472582	et	3	main
natuke	doc_491521501754_item	2472583	et	4	main
sõime	doc_491521501754_item	2472584	et	4	main
mina	doc_491521501754_item	2472585	et	4	main
püüdsin	doc_491521501754_item	2472586	et	3	main
midagi	doc_491521501754_item	2472587	et	4	main
teha	doc_491521501754_item	2472588	et	3	main
vahetasin	doc_491521501754_item	2472589	et	3	main
elektripirnid	doc_491521501754_item	2472590	et	3	main
võtsin	doc_491521501754_item	2472591	et	3	main
veenäiteid	doc_491521501754_item	2472592	et	3	main
ja	doc_491521501754_item	2472593	et	3	main
vormistasin	doc_491521501754_item	2472594	et	3	main
kahekümne	doc_491521501754_item	2472595	et	4	main
kaheksandal	doc_491521501754_item	2472596	et	3	main
novembris	doc_491521501754_item	2472597	et	3	main
tulevad	doc_491521501754_item	2472598	et	4	main
santehnikud	doc_491521501754_item	2472599	et	4	main
torude	doc_491521501754_item	2472600	et	3	main
vahetada	doc_491521501754_item	2472601	et	3	main
meie	doc_491521501754_item	2472602	et	4	main
torud	doc_491521501754_item	2472603	et	3	main
on	doc_491521501754_item	2472604	et	4	main
no	doc_491521501754_item	2472525	et	3	main
kui	doc_491521501754_item	2472529	et	3	main
ma	doc_491521501754_item	2472530	et	3	main
kui	doc_491521501754_item	2472540	et	3	main
eesti	doc_491521501754_item	2472543	et	4	main
keeles	doc_491521501754_item	2472544	et	4	main
kuigi	doc_491521501754_item	2472545	et	3	main
kaks	doc_491521501754_item	2472546	et	3	main
ei	doc_491521501754_item	2472559	et	4	main
midagi	doc_491521501754_item	2472563	et	4	main
pandud	doc_491521501754_item	2472605	et	4	main
eile	doc_491521501754_item	2472616	et	3	main
aga	doc_491521501754_item	2472622	et	3	main
kui	doc_491521501754_item	2472623	et	3	main
ei	doc_491521501754_item	2472625	et	4	main
ta	doc_491521501754_item	2472627	et	4	main
selles	doc_491521501754_item	2472637	et	4	main
tegi	doc_491521501754_item	2472640	et	4	main
remonti	doc_491521501754_item	2472641	et	4	main
meie	doc_491521501754_item	2472645	et	4	main
remont	doc_491521501754_item	2472647	et	3	main
ole	doc_491521501754_item	2472649	et	4	main
õudu	doc_491521501754_item	2472657	et	4	main
ma	doc_491521501754_item	2472658	et	3	main
võtsin	doc_491521501754_item	2472659	et	3	main
kohutav	doc_491521501754_item	2472674	et	4	main
teha	doc_491521501754_item	2472677	et	3	main
objekt	doc_491521501754_item	2472690	et	3	main
valgas	doc_491521501754_item	2472691	et	4	main
homme	doc_491521501754_item	2472692	et	3	main
sõidan	doc_491521501754_item	2472693	et	3	main
sinna	doc_491521501754_item	2472694	et	3	main
ja	doc_491521501754_item	2472695	et	3	main
kahjuks	doc_491521501754_item	2472699	et	4	main
üldse	doc_491521501754_item	2472722	et	3	main
vot	doc_491521501754_item	2472733	et	3	main
ma	doc_491521501754_item	2472734	et	3	main
helistan	doc_491521501754_item	2472735	et	3	main
kalendrit	doc_491521501754_item	2472749	et	3	main
ja	doc_491521501754_item	2472750	et	3	main
ei	doc_491521501754_item	2472757	et	4	main
teiseks	doc_491521501754_item	2472760	et	4	main
ei	doc_491521501754_item	2472768	et	4	main
ma	doc_491521501754_item	2472778	et	3	main
ootavad	doc_491521501754_item	2472780	et	4	main
mind	doc_491521501754_item	2472781	et	4	main
läheme	doc_491521501754_item	2472801	et	3	main
viisa	doc_491521501754_item	2472825	et	4	main
solvusin	doc_491521501754_item	2472831	et	3	main
käinud	doc_491521501754_item	2472839	et	4	main
praegu	doc_491521501754_item	2472842	et	3	main
lootsin	doc_491521501754_item	2472845	et	4	main
et	doc_491521501754_item	2472846	et	3	main
sõidame	doc_491521501754_item	2472848	et	3	main
siin	doc_491521501754_item	2472857	et	4	main
endale	doc_491521501754_item	2472867	et	4	main
keelest	doc_491521501754_item	2472880	et	4	main
keelde	doc_491521501754_item	2472882	et	4	main
kell	doc_491521501754_item	2472892	et	3	main
ära	doc_491521501754_item	2472613	et	4	main
hääldus	doc_491521501754_item	2472620	et	4	main
lammutavad	doc_491521501754_item	2472632	et	4	main
aastat	doc_491521501754_item	2472643	et	3	main
ole	doc_491521501754_item	2472654	et	4	main
tööline	doc_491521501754_item	2472660	et	4	main
no	doc_491521501754_item	2472675	et	3	main
see	doc_491521501754_item	2472678	et	3	main
ole	doc_491521501754_item	2472683	et	4	main
detsembris	doc_491521501754_item	2472696	et	3	main
hakkame	doc_491521501754_item	2472697	et	3	main
tööd	doc_491521501754_item	2472700	et	4	main
palju	doc_491521501754_item	2472702	et	4	main
aga	doc_491521501754_item	2472703	et	3	main
raha	doc_491521501754_item	2472704	et	4	main
praegu	doc_491521501754_item	2472705	et	3	main
ei	doc_491521501754_item	2472706	et	4	main
ole	doc_491521501754_item	2472707	et	4	main
vot	doc_491521501754_item	2472708	et	3	main
detsembris	doc_491521501754_item	2472709	et	3	main
rahad	doc_491521501754_item	2472710	et	4	main
tulevad	doc_491521501754_item	2472711	et	4	main
on	doc_491521501754_item	2472712	et	4	main
vaja	doc_491521501754_item	2472713	et	4	main
detsembris	doc_491521501754_item	2472714	et	3	main
palju	doc_491521501754_item	2472715	et	4	main
töötada	doc_491521501754_item	2472716	et	3	main
detsember	doc_491521501754_item	2472717	et	3	main
läheb	doc_491521501754_item	2472718	et	3	main
minule	doc_491521501754_item	2472719	et	3	main
nii	doc_491521501754_item	2472720	et	3	main
vanematele	doc_491521501754_item	2472737	et	4	main
ja	doc_491521501754_item	2472738	et	3	main
ema	doc_491521501754_item	2472739	et	4	main
et	doc_491521501754_item	2472741	et	3	main
sa	doc_491521501754_item	2472742	et	3	main
lubas	doc_491521501754_item	2472743	et	3	main
et	doc_491521501754_item	2472744	et	3	main
ei	doc_491521501754_item	2472753	et	4	main
ei	doc_491521501754_item	2472762	et	4	main
ole	doc_491521501754_item	2472763	et	4	main
ma	doc_491521501754_item	2472764	et	3	main
ütlesin	doc_491521501754_item	2472765	et	3	main
et	doc_491521501754_item	2472766	et	3	main
kahjuks	doc_491521501754_item	2472767	et	4	main
midagi	doc_491521501754_item	2472771	et	4	main
saa	doc_491521501754_item	2472773	et	4	main
loodavad	doc_491521501754_item	2472776	et	4	main
tulen	doc_491521501754_item	2472779	et	3	main
никак	doc_491521501754_item	2472789	et	2	main
et	doc_491521501754_item	2472800	et	3	main
vaba	doc_491521501754_item	2472821	et	4	main
et	doc_491521501754_item	2472823	et	3	main
panna	doc_491521501754_item	2472826	et	4	main
ei	doc_491521501754_item	2472833	et	4	main
ei	doc_491521501754_item	2472838	et	4	main
ja	doc_491521501754_item	2472841	et	3	main
vot	doc_491521501754_item	2472843	et	3	main
me	doc_491521501754_item	2472847	et	4	main
leidsin	doc_491521501754_item	2472854	et	3	main
oli	doc_491521501754_item	2472861	et	3	main
kolm	doc_491521501754_item	2472862	et	3	main
pakkusid	doc_491521501754_item	2472863	et	4	main
valisin	doc_491521501754_item	2472866	et	3	main
lapimaa	doc_491521501754_item	2472870	et	4	main
suur	doc_491521501754_item	2472689	et	3	main
nagu	doc_491521501754_item	2472723	et	3	main
nädalat	doc_491521501754_item	2472725	et	3	main
kõige	doc_491521501754_item	2472728	et	4	main
kiirem	doc_491521501754_item	2472729	et	4	main
kuu	doc_491521501754_item	2472730	et	4	main
minu	doc_491521501754_item	2472731	et	3	main
jaoks	doc_491521501754_item	2472732	et	4	main
eile	doc_491521501754_item	2472736	et	3	main
näen	doc_491521501754_item	2472751	et	3	main
raha	doc_491521501754_item	2472756	et	4	main
ole	doc_491521501754_item	2472758	et	4	main
ja	doc_491521501754_item	2472759	et	3	main
ei	doc_491521501754_item	2472772	et	4	main
kui	doc_491521501754_item	2472783	et	3	main
ma	doc_491521501754_item	2472784	et	3	main
helistaks	doc_491521501754_item	2472785	et	3	main
так	doc_491521501754_item	2472787	et	2	main
ole	doc_491521501754_item	2472797	et	4	main
otsustasime	doc_491521501754_item	2472798	et	3	main
abikaasaga	doc_491521501754_item	2472799	et	3	main
pimaa	doc_491521501754_item	2472803	et	4	main
jõulu	doc_491521501754_item	2472804	et	4	main
ajal	doc_491521501754_item	2472805	et	4	main
ma	doc_491521501754_item	2472806	et	3	main
tahtsin	doc_491521501754_item	2472807	et	3	main
juba	doc_491521501754_item	2472808	et	3	main
varem	doc_491521501754_item	2472809	et	4	main
lapimaa	doc_491521501754_item	2472810	et	4	main
minema	doc_491521501754_item	2472811	et	3	main
aga	doc_491521501754_item	2472812	et	3	main
esimene	doc_491521501754_item	2472813	et	3	main
kord	doc_491521501754_item	2472814	et	4	main
kui	doc_491521501754_item	2472815	et	3	main
ma	doc_491521501754_item	2472816	et	3	main
tahaksin	doc_491521501754_item	2472817	et	3	main
ei	doc_491521501754_item	2472818	et	4	main
ole	doc_491521501754_item	2472819	et	4	main
passis	doc_491521501754_item	2472820	et	4	main
püüdsi	doc_491521501754_item	2472834	et	4	main
rohkem	doc_491521501754_item	2472835	et	4	main
välja	doc_491521501754_item	2472852	et	4	main
ma	doc_491521501754_item	2472853	et	3	main
on	doc_491521501754_item	2472858	et	4	main
ma	doc_491521501754_item	2472865	et	3	main
vene	doc_491521501754_item	2472879	et	4	main
kahekümne	doc_491521501754_item	2472885	et	4	main
kahekümne	doc_491521501754_item	2472887	et	4	main
üheksandani	doc_491521501754_item	2472888	et	3	main
detsembrini	doc_491521501754_item	2472889	et	3	main
tulek	doc_491521501754_item	2472897	et	3	main
ja	doc_491521501754_item	2472928	et	3	main
hommikusöök	doc_491521501754_item	2472936	et	3	main
neliteist	doc_491521501754_item	2472945	et	4	main
akvaparki	doc_491521501754_item	2472948	et	4	main
kell	doc_491521501754_item	2472950	et	3	main
bussis	doc_491521501754_item	2472956	et	3	main
tallinna	doc_491521501754_item	2472963	et	4	main
tallinnas	doc_491521501754_item	2472968	et	4	main
hea	doc_491521501754_item	2472976	et	4	main
sest	doc_491521501754_item	2472977	et	4	main
et	doc_491521501754_item	2472978	et	3	main
on	doc_491521501754_item	2472994	et	4	main
öö	doc_491521501754_item	2473000	et	4	main
parem	doc_491521501754_item	2473006	et	4	main
soome	doc_491521501754_item	2472824	et	3	main
seda	doc_491521501754_item	2472828	et	3	main
nagu	doc_491521501754_item	2472830	et	3	main
sellesse	doc_491521501754_item	2472832	et	4	main
sügisel	doc_491521501754_item	2472836	et	3	main
tule	doc_491521501754_item	2472851	et	4	main
reisi	doc_491521501754_item	2472856	et	4	main
päeva	doc_491521501754_item	2472860	et	4	main
ja	doc_491521501754_item	2472864	et	3	main
bussiga	doc_491521501754_item	2472869	et	3	main
eesti	doc_491521501754_item	2472881	et	4	main
see	doc_491521501754_item	2472883	et	3	main
on	doc_491521501754_item	2472884	et	4	main
kuuendal	doc_491521501754_item	2472886	et	3	main
seitse	doc_491521501754_item	2472893	et	3	main
paroomiga	doc_491521501754_item	2472896	et	4	main
kell	doc_491521501754_item	2472907	et	3	main
kaheksa	doc_491521501754_item	2472908	et	4	main
on	doc_491521501754_item	2472909	et	4	main
hotellis	doc_491521501754_item	2472910	et	3	main
hommikusöök	doc_491521501754_item	2472911	et	3	main
kell	doc_491521501754_item	2472912	et	3	main
üheteist	doc_491521501754_item	2472913	et	4	main
kell	doc_491521501754_item	2472914	et	3	main
kaheteistkümneni	doc_491521501754_item	2472915	et	4	main
santa	doc_491521501754_item	2472917	et	4	main
on	doc_491521501754_item	2472916	et	4	main
klausi	doc_491521501754_item	2472918	et	4	main
maja	doc_491521501754_item	2472919	et	4	main
külastamine	doc_491521501754_item	2472920	et	4	main
külastamine	doc_491521501754_item	2472922	et	4	main
kolmas	doc_491521501754_item	2472934	et	3	main
lossi	doc_491521501754_item	2472939	et	4	main
helsingi	doc_491521501754_item	2472954	et	4	main
kell	doc_491521501754_item	2472960	et	3	main
paroomiga	doc_491521501754_item	2472962	et	4	main
juba	doc_491521501754_item	2472967	et	3	main
see	doc_491521501754_item	2472986	et	3	main
kahekümne	doc_491521501754_item	2472990	et	4	main
on	doc_491521501754_item	2473004	et	4	main
seal	doc_491521501754_item	2473007	et	4	main
ja	doc_491521501754_item	2473010	et	3	main
variant	doc_491521501754_item	2473013	et	3	main
meelega	doc_491521501754_item	2473019	et	4	main
rongiga	doc_491521501754_item	2473021	et	4	main
kahjuks	doc_491521501754_item	2473023	et	4	main
seal	doc_491521501754_item	2473024	et	4	main
helsingi	doc_491521501754_item	2473034	et	4	main
ekskursioon	doc_491521501754_item	2473035	et	3	main
see	doc_491521501754_item	2473036	et	3	main
on	doc_491521501754_item	2473037	et	4	main
on	doc_491521501754_item	2473041	et	4	main
mulle	doc_491521501754_item	2473043	et	4	main
väga	doc_491521501754_item	2473045	et	3	main
ma	doc_491521501754_item	2473048	et	3	main
venemaal	doc_491521501754_item	2473060	et	4	main
ka	doc_491521501754_item	2473062	et	3	main
ja	doc_491521501754_item	2473064	et	3	main
nad	doc_491521501754_item	2473066	et	3	main
no	doc_491521501754_item	2473082	et	3	main
mis	doc_491521501754_item	2473083	et	4	main
siis	doc_491521501754_item	2473093	et	3	main
vigade	doc_491521501754_item	2473097	et	3	main
nende	doc_491521501754_item	2473102	et	4	main
häälikuühendite	doc_491521501754_item	2473107	et	4	main
jõu-	doc_491521501754_item	2473108	et	3	main
õudu	doc_491521501754_item	2473121	et	4	main
õu-	doc_491521501754_item	2473123	et	4	main
jõu-	doc_491521501754_item	2473125	et	3	main
reklaamteksti	doc_491521501754_item	2472875	et	4	main
ja	doc_491521501754_item	2472876	et	3	main
tõlgib	doc_491521501754_item	2472877	et	3	main
seda	doc_491521501754_item	2472878	et	3	main
päev	doc_491521501754_item	2472891	et	3	main
väljumine	doc_491521501754_item	2472894	et	4	main
helsingi	doc_491521501754_item	2472898	et	4	main
väljumine	doc_491521501754_item	2472900	et	4	main
üheksateist	doc_491521501754_item	2472930	et	4	main
hotelli	doc_491521501754_item	2472931	et	4	main
tulek	doc_491521501754_item	2472932	et	3	main
puhkus	doc_491521501754_item	2472933	et	3	main
kell	doc_491521501754_item	2472946	et	3	main
seitse	doc_491521501754_item	2472959	et	3	main
kell	doc_491521501754_item	2472964	et	3	main
kaksteist	doc_491521501754_item	2472966	et	4	main
asi	doc_491521501754_item	2472969	et	4	main
selles	doc_491521501754_item	2472971	et	4	main
kaks	doc_491521501754_item	2472979	et	3	main
öö	doc_491521501754_item	2472980	et	4	main
bussis	doc_491521501754_item	2472981	et	3	main
on	doc_491521501754_item	2472987	et	4	main
kolmandal	doc_491521501754_item	2472989	et	3	main
kaheksandani	doc_491521501754_item	2472991	et	3	main
detsembrini	doc_491521501754_item	2472992	et	3	main
pidu	doc_491521501754_item	2472996	et	4	main
ükskoik	doc_491521501754_item	2472998	et	4	main
kaks	doc_491521501754_item	2472999	et	3	main
bussis	doc_491521501754_item	2473001	et	3	main
hotell	doc_491521501754_item	2473003	et	3	main
on	doc_491521501754_item	2473008	et	4	main
bassein	doc_491521501754_item	2473009	et	3	main
sauna	doc_491521501754_item	2473011	et	4	main
kolmas	doc_491521501754_item	2473012	et	3	main
on	doc_491521501754_item	2473014	et	4	main
juba	doc_491521501754_item	2473015	et	3	main
ka	doc_491521501754_item	2472923	et	3	main
läbi	doc_491521501754_item	2472927	et	4	main
kell	doc_491521501754_item	2472929	et	3	main
loomaaeda	doc_491521501754_item	2472937	et	4	main
külastamine	doc_491521501754_item	2472938	et	4	main
käimine	doc_491521501754_item	2472926	et	4	main
päev	doc_491521501754_item	2472935	et	3	main
kompveki	doc_491521501754_item	2472941	et	4	main
vabariigi	doc_491521501754_item	2472942	et	3	main
külastamine	doc_491521501754_item	2472943	et	4	main
kell	doc_491521501754_item	2472944	et	3	main
kuueteistkümneni	doc_491521501754_item	2472947	et	4	main
külastamine	doc_491521501754_item	2472949	et	4	main
öö	doc_491521501754_item	2472955	et	4	main
tulek	doc_491521501754_item	2472957	et	3	main
kaheksa	doc_491521501754_item	2472961	et	4	main
pool	doc_491521501754_item	2472965	et	4	main
on	doc_491521501754_item	2472970	et	4	main
et	doc_491521501754_item	2472972	et	3	main
see	doc_491521501754_item	2472973	et	3	main
ei	doc_491521501754_item	2472974	et	4	main
ole	doc_491521501754_item	2472975	et	4	main
suur	doc_491521501754_item	2472995	et	3	main
aga	doc_491521501754_item	2472997	et	3	main
ka	doc_491521501754_item	2473005	et	3	main
sõidaksin	doc_491521501754_item	2473020	et	3	main
huvitav	doc_491521501754_item	2473039	et	4	main
mulle	doc_491521501754_item	2473052	et	4	main
veel	doc_491521501754_item	2473084	et	4	main
natuke	doc_491521501754_item	2473095	et	4	main
ü	doc_491521501754_item	2473099	et	4	main
hääldus	doc_491521501754_item	2473112	et	4	main
jõu-	doc_491521501754_item	2473113	et	3	main
asemel	doc_491521501754_item	2473114	et	4	main
hääldab	doc_491521501754_item	2473115	et	3	main
a	doc_491521501754_item	2473116	et	4	main
õu-	doc_491521501754_item	2473117	et	4	main
asemel	doc_491521501754_item	2473124	et	4	main
on	doc_491521501754_item	2473128	et	4	main
võimalikud	doc_491521501754_item	2473130	et	3	main
häälikuühendite	doc_491521501754_item	2473132	et	4	main
häälikuühendid	doc_491521501754_item	2473142	et	4	main
neid	doc_491521501754_item	2473148	et	4	main
raske	doc_491521501754_item	2473153	et	4	main
interferentsiviga	doc_491521501754_item	2473164	et	4	main
analoogia	doc_491521501754_item	2473165	et	4	main
arvas	doc_491521501754_item	2473176	et	3	main
tugev	doc_491521501754_item	2473216	et	4	main
on	doc_491521501754_item	2473224	et	4	main
ühesuguse	doc_491521501754_item	2473225	et	3	main
kujuga	doc_491521501754_item	2473226	et	3	main
käbi	doc_491521501754_item	2473234	et	4	main
veepargi	doc_491521501754_item	2473240	et	3	main
külastamine	doc_491521501754_item	2473241	et	4	main
nõrga	doc_491521501754_item	2473242	et	3	main
astme	doc_491521501754_item	2473243	et	3	main
asemel	doc_491521501754_item	2473244	et	4	main
loomaaeda	doc_491521501754_item	2473248	et	4	main
asemel	doc_491521501754_item	2473254	et	4	main
tugev	doc_491521501754_item	2473256	et	4	main
ajas	doc_491521501754_item	2473261	et	4	main
ta	doc_491521501754_item	2473273	et	4	main
nt	doc_491521501754_item	2473278	et	4	main
verbirektsioon	doc_491521501754_item	2473286	et	4	main
ma	doc_491521501754_item	2473287	et	3	main
paljudel	doc_491521501754_item	2473333	et	3	main
käändega	doc_491521501754_item	2473336	et	3	main
2	doc_491521501754_item	2473344	et	2	main
põhjus	doc_491521501754_item	2473352	et	4	main
kuna	doc_491521501754_item	2473366	et	3	main
on	doc_491521501754_item	2473369	et	4	main
ta	doc_491521501754_item	2473370	et	4	main
ilmselt	doc_491521501754_item	2473371	et	4	main
kuulnud	doc_491521501754_item	2473376	et	4	main
sõnaühendit	doc_491521501754_item	2473377	et	3	main
muu	doc_491521501754_item	2473381	et	4	main
tööline	doc_491521501754_item	2473385	et	4	main
võtsin	doc_491521501754_item	2473386	et	3	main
valisin	doc_491521501754_item	2473388	et	3	main
tegevuse	doc_491521501754_item	2473400	et	4	main
lühikese	doc_491521501754_item	2473415	et	4	main
ole	doc_491521501754_item	2473424	et	4	main
lapimaa	doc_491521501754_item	2473438	et	4	main
helsingist	doc_491521501754_item	2473440	et	4	main
väljumine	doc_491521501754_item	2473446	et	4	main
helsingi	doc_491521501754_item	2473447	et	4	main
ja	doc_491521501754_item	2472940	et	3	main
kakskümmend	doc_491521501754_item	2472951	et	4	main
kaks	doc_491521501754_item	2472952	et	3	main
väljumine	doc_491521501754_item	2472953	et	4	main
kell	doc_491521501754_item	2472958	et	3	main
aga	doc_491521501754_item	2472982	et	3	main
on	doc_491521501754_item	2472983	et	4	main
veel	doc_491521501754_item	2472984	et	4	main
variant	doc_491521501754_item	2472985	et	3	main
kahekümne	doc_491521501754_item	2472988	et	4	main
seal	doc_491521501754_item	2472993	et	4	main
ja	doc_491521501754_item	2473002	et	3	main
rongiga	doc_491521501754_item	2473016	et	4	main
ma	doc_491521501754_item	2473017	et	3	main
hea	doc_491521501754_item	2473018	et	4	main
kolmandas	doc_491521501754_item	2473030	et	3	main
variandis	doc_491521501754_item	2473031	et	3	main
ka	doc_491521501754_item	2473033	et	3	main
soome	doc_491521501754_item	2473058	et	3	main
наверное	doc_491521501754_item	2473086	et	2	main
tegeleme	doc_491521501754_item	2473094	et	3	main
r	doc_491521501754_item	2473098	et	4	main
ja	doc_491521501754_item	2473101	et	3	main
ei	doc_491521501754_item	2473119	et	4	main
ole	doc_491521501754_item	2473120	et	4	main
sarnasuse	doc_491521501754_item	2473139	et	4	main
ei	doc_491521501754_item	2473143	et	4	main
on	doc_491521501754_item	2473149	et	4	main
moodustada	doc_491521501754_item	2473154	et	3	main
pikkus	doc_491521501754_item	2473158	et	4	main
ee	doc_491521501754_item	2473160	et	3	main
vene	doc_491521501754_item	2473166	et	4	main
keelega	doc_491521501754_item	2473167	et	3	main
kus	doc_491521501754_item	2473168	et	3	main
lahtine	doc_491521501754_item	2473169	et	3	main
a	doc_491521501754_item	2473174	et	4	main
sõna	doc_491521501754_item	2473179	et	4	main
aste	doc_491521501754_item	2473217	et	4	main
võimalik	doc_491521501754_item	2473218	et	3	main
nimetavas	doc_491521501754_item	2473227	et	4	main
ja	doc_491521501754_item	2473229	et	3	main
osastavas	doc_491521501754_item	2473230	et	4	main
jne	doc_491521501754_item	2473236	et	4	main
2	doc_491521501754_item	2473237	et	2	main
akvaparki	doc_491521501754_item	2473238	et	4	main
loomaaia	doc_491521501754_item	2473250	et	4	main
nõrga	doc_491521501754_item	2473252	et	3	main
aste	doc_491521501754_item	2473257	et	4	main
sõnade	doc_491521501754_item	2473263	et	3	main
ja	doc_491521501754_item	2473267	et	3	main
käände	doc_491521501754_item	2473269	et	4	main
kuna	doc_491521501754_item	2473270	et	3	main
teistel	doc_491521501754_item	2473271	et	4	main
kordadel	doc_491521501754_item	2473272	et	3	main
teinud	doc_491521501754_item	2473277	et	4	main
mida	doc_491521501754_item	2473289	et	4	main
i	doc_491521501754_item	2473293	et	4	main
assotsieerub	doc_491521501754_item	2473332	et	3	main
osastava	doc_491521501754_item	2473335	et	4	main
vorm	doc_491521501754_item	2473341	et	3	main
sõnast	doc_491521501754_item	2473342	et	4	main
vene	doc_491521501754_item	2473354	et	4	main
põhjus	doc_491521501754_item	2473365	et	4	main
või	doc_491521501754_item	2473375	et	4	main
põhjus	doc_491521501754_item	2473396	et	4	main
mõelnud	doc_491521501754_item	2473399	et	4	main
lõpetatusele	doc_491521501754_item	2473401	et	4	main
vaid	doc_491521501754_item	2473402	et	3	main
lihtsalt	doc_491521501754_item	2473403	et	4	main
kasutas	doc_491521501754_item	2473404	et	3	main
vead	doc_491521501754_item	2473413	et	4	main
vormi	doc_491521501754_item	2473422	et	4	main
lapimaa	doc_491521501754_item	2473428	et	4	main
lapimaale	doc_491521501754_item	2473441	et	4	main
tulek	doc_491521501754_item	2473442	et	3	main
helsingisse	doc_491521501754_item	2473445	et	4	main
väljasõit	doc_491521501754_item	2473448	et	4	main
sisseütleva	doc_491521501754_item	2473454	et	3	main
käände	doc_491521501754_item	2473455	et	4	main
kell	doc_491521501754_item	2473473	et	3	main
neliteist	doc_491521501754_item	2473474	et	4	main
neljateistkümnest	doc_491521501754_item	2473478	et	3	main
aga	doc_491521501754_item	2473022	et	3	main
on	doc_491521501754_item	2473025	et	4	main
ka	doc_491521501754_item	2473038	et	3	main
üldse	doc_491521501754_item	2473042	et	3	main
meeldib	doc_491521501754_item	2473044	et	3	main
linn	doc_491521501754_item	2473047	et	3	main
meeldivad	doc_491521501754_item	2473053	et	4	main
soomlased	doc_491521501754_item	2473054	et	3	main
vale	doc_491521501754_item	2473055	et	4	main
rõhk	doc_491521501754_item	2473056	et	3	main
ja	doc_491521501754_item	2473057	et	3	main
elavad	doc_491521501754_item	2473061	et	4	main
karjalased	doc_491521501754_item	2473063	et	3	main
on	doc_491521501754_item	2473067	et	4	main
soomlastega	doc_491521501754_item	2473068	et	3	main
sugulased	doc_491521501754_item	2473069	et	3	main
mulle	doc_491521501754_item	2473070	et	4	main
üldse	doc_491521501754_item	2473071	et	3	main
meeldivad	doc_491521501754_item	2473072	et	4	main
talvised	doc_491521501754_item	2473073	et	4	main
pidud	doc_491521501754_item	2473074	et	3	main
jõulud	doc_491521501754_item	2473075	et	3	main
ja	doc_491521501754_item	2473076	et	3	main
uus	doc_491521501754_item	2473077	et	3	main
aasta	doc_491521501754_item	2473078	et	4	main
see	doc_491521501754_item	2473079	et	3	main
on	doc_491521501754_item	2473080	et	4	main
lapsepõlvest	doc_491521501754_item	2473081	et	4	main
ainult	doc_491521501754_item	2473026	et	4	main
üks	doc_491521501754_item	2473027	et	3	main
päev	doc_491521501754_item	2473028	et	3	main
lapimaal	doc_491521501754_item	2473029	et	4	main
on	doc_491521501754_item	2473032	et	4	main
helsingi	doc_491521501754_item	2473040	et	4	main
see	doc_491521501754_item	2473046	et	3	main
ei	doc_491521501754_item	2473049	et	4	main
tea	doc_491521501754_item	2473050	et	4	main
miks	doc_491521501754_item	2473051	et	4	main
üldse	doc_491521501754_item	2473059	et	3	main
vepsad	doc_491521501754_item	2473065	et	4	main
kõik	doc_491521501754_item	2473085	et	4	main
täna	doc_491521501754_item	2473089	et	4	main
põhjuste	doc_491521501754_item	2473103	et	3	main
1	doc_491521501754_item	2473106	et	2	main
ja	doc_491521501754_item	2473109	et	3	main
mida	doc_491521501754_item	2473087	et	4	main
tahtsin	doc_491521501754_item	2473088	et	3	main
rääkida	doc_491521501754_item	2473090	et	3	main
kas	doc_491521501754_item	2473091	et	3	main
me	doc_491521501754_item	2473092	et	4	main
grammatikaga	doc_491521501754_item	2473096	et	3	main
hmitamine	doc_491521501754_item	2473100	et	4	main
seletamine	doc_491521501754_item	2473104	et	4	main
hääldusvead	doc_491521501754_item	2473105	et	3	main
õu-	doc_491521501754_item	2473110	et	4	main
vale	doc_491521501754_item	2473111	et	4	main
nt	doc_491521501754_item	2473118	et	4	main
ning	doc_491521501754_item	2473122	et	3	main
see	doc_491521501754_item	2473127	et	3	main
segiajamine	doc_491521501754_item	2473133	et	4	main
need	doc_491521501754_item	2473141	et	3	main
esine	doc_491521501754_item	2473144	et	4	main
vene	doc_491521501754_item	2473145	et	4	main
venelastest	doc_491521501754_item	2473150	et	4	main
kõnelejal	doc_491521501754_item	2473151	et	4	main
väga	doc_491521501754_item	2473152	et	3	main
nt	doc_491521501754_item	2473159	et	4	main
esisilp	doc_491521501754_item	2473170	et	3	main
hääldatakse	doc_491521501754_item	2473171	et	3	main
alati	doc_491521501754_item	2473172	et	4	main
millegipärast	doc_491521501754_item	2473175	et	3	main
et	doc_491521501754_item	2473177	et	3	main
kirjutatakse	doc_491521501754_item	2473180	et	3	main
e-ga	doc_491521501754_item	2473182	et	3	main
vale	doc_491521501754_item	2473184	et	4	main
analoogia	doc_491521501754_item	2473220	et	4	main
kahesilbiliste	doc_491521501754_item	2473221	et	4	main
mis	doc_491521501754_item	2473223	et	4	main
tädi	doc_491521501754_item	2473233	et	4	main
külastamine	doc_491521501754_item	2473239	et	4	main
aste	doc_491521501754_item	2473247	et	4	main
külastamine	doc_491521501754_item	2473251	et	4	main
põhjused	doc_491521501754_item	2473259	et	3	main
ja	doc_491521501754_item	2473265	et	3	main
osastava	doc_491521501754_item	2473268	et	4	main
ei	doc_491521501754_item	2473276	et	4	main
külastamine	doc_491521501754_item	2473283	et	4	main
viga	doc_491521501754_item	2473284	et	4	main
põhjustas	doc_491521501754_item	2473285	et	3	main
loomaaeda	doc_491521501754_item	2473291	et	4	main
nt	doc_491521501754_item	2473126	et	4	main
põhjused	doc_491521501754_item	2473131	et	3	main
sõnade	doc_491521501754_item	2473134	et	3	main
jõudu	doc_491521501754_item	2473135	et	4	main
ja	doc_491521501754_item	2473136	et	3	main
õudne	doc_491521501754_item	2473137	et	3	main
kirjapildi	doc_491521501754_item	2473138	et	4	main
keeles	doc_491521501754_item	2473146	et	4	main
ning	doc_491521501754_item	2473147	et	3	main
2	doc_491521501754_item	2473155	et	2	main
häälikute	doc_491521501754_item	2473157	et	3	main
smaspäeval	doc_491521501754_item	2473161	et	4	main
võimalikud	doc_491521501754_item	2473162	et	3	main
kahe	doc_491521501754_item	2473181	et	3	main
3	doc_491521501754_item	2473183	et	2	main
rõhk	doc_491521501754_item	2473185	et	3	main
soomlased	doc_491521501754_item	2473186	et	3	main
pearõhk	doc_491521501754_item	2473187	et	3	main
on	doc_491521501754_item	2473188	et	4	main
teisel	doc_491521501754_item	2473189	et	4	main
silbil	doc_491521501754_item	2473190	et	3	main
see	doc_491521501754_item	2473191	et	3	main
on	doc_491521501754_item	2473192	et	4	main
korduv	doc_491521501754_item	2473193	et	4	main
viga	doc_491521501754_item	2473194	et	4	main
hääldab	doc_491521501754_item	2473196	et	3	main
ta	doc_491521501754_item	2473197	et	4	main
venela	doc_491521501754_item	2473198	et	4	main
samuti	doc_491521501754_item	2473195	et	3	main
ne	doc_491521501754_item	2473199	et	4	main
eestla	doc_491521501754_item	2473200	et	4	main
ne	doc_491521501754_item	2473201	et	4	main
nagu	doc_491521501754_item	2473202	et	3	main
nimi	doc_491521501754_item	2473204	et	3	main
vene	doc_491521501754_item	2473203	et	4	main
светла	doc_491521501754_item	2473205	et	2	main
на	doc_491521501754_item	2473206	et	2	main
astmevahelduse	doc_491521501754_item	2473207	et	4	main
1	doc_491521501754_item	2473209	et	2	main
vead	doc_491521501754_item	2473208	et	4	main
pidud	doc_491521501754_item	2473210	et	3	main
peod	doc_491521501754_item	2473211	et	4	main
nõrga	doc_491521501754_item	2473212	et	3	main
astme	doc_491521501754_item	2473213	et	3	main
asemel	doc_491521501754_item	2473214	et	4	main
on	doc_491521501754_item	2473215	et	4	main
jõudne	doc_491521501754_item	2473129	et	4	main
tõttu	doc_491521501754_item	2473140	et	4	main
vale	doc_491521501754_item	2473156	et	4	main
põhjused	doc_491521501754_item	2473163	et	3	main
pikalt	doc_491521501754_item	2473173	et	4	main
see	doc_491521501754_item	2473178	et	3	main
põhjus	doc_491521501754_item	2473219	et	4	main
sõnadega	doc_491521501754_item	2473222	et	3	main
käändes	doc_491521501754_item	2473231	et	3	main
nt	doc_491521501754_item	2473232	et	4	main
on	doc_491521501754_item	2473245	et	4	main
tugev	doc_491521501754_item	2473246	et	4	main
külastamine	doc_491521501754_item	2473249	et	4	main
astme	doc_491521501754_item	2473253	et	3	main
on	doc_491521501754_item	2473255	et	4	main
võimalikud	doc_491521501754_item	2473258	et	3	main
segi	doc_491521501754_item	2473262	et	3	main
sellist	doc_491521501754_item	2473274	et	4	main
lossi	doc_491521501754_item	2473279	et	4	main
külastan	doc_491521501754_item	2473288	et	3	main
objektivead	doc_491521501754_item	2473292	et	4	main
võtsin	doc_491521501754_item	2473294	et	3	main
vene	doc_491521501754_item	2473322	et	4	main
esineb	doc_491521501754_item	2473324	et	3	main
venelastel	doc_491521501754_item	2473334	et	4	main
on	doc_491521501754_item	2473338	et	4	main
tihti	doc_491521501754_item	2473339	et	3	main
kasutatav	doc_491521501754_item	2473340	et	4	main
seda	doc_491521501754_item	2473346	et	3	main
leidsin	doc_491521501754_item	2473348	et	3	main
reisi	doc_491521501754_item	2473350	et	4	main
käändega	doc_491521501754_item	2473356	et	3	main
mitu	doc_491521501754_item	2473372	et	4	main
torude	doc_491521501754_item	2473378	et	3	main
vahetamine	doc_491521501754_item	2473382	et	4	main
võtsin	doc_491521501754_item	2473384	et	3	main
töölise	doc_491521501754_item	2473387	et	3	main
endale	doc_491521501754_item	2473389	et	4	main
sõit	doc_491521501754_item	2473390	et	3	main
bussiga	doc_491521501754_item	2473391	et	3	main
valisin	doc_491521501754_item	2473392	et	3	main
endale	doc_491521501754_item	2473393	et	4	main
bussisõidu	doc_491521501754_item	2473394	et	3	main
ei	doc_491521501754_item	2473398	et	4	main
on	doc_491521501754_item	2473408	et	4	main
pidžinkeeltele	doc_491521501754_item	2473410	et	2	main
omane	doc_491521501754_item	2473411	et	3	main
sisseütleva	doc_491521501754_item	2473416	et	3	main
käände	doc_491521501754_item	2473417	et	4	main
sõnadel	doc_491521501754_item	2473419	et	3	main
kus	doc_491521501754_item	2473420	et	3	main
omastavas	doc_491521501754_item	2473228	et	4	main
karu	doc_491521501754_item	2473235	et	4	main
aleksandr	doc_491521501754_item	2473260	et	4	main
park	doc_491521501754_item	2473264	et	3	main
loomaaedomastava	doc_491521501754_item	2473266	et	3	main
viga	doc_491521501754_item	2473275	et	4	main
ja	doc_491521501754_item	2473280	et	3	main
kompveki	doc_491521501754_item	2473281	et	4	main
vabariigi	doc_491521501754_item	2473282	et	3	main
parki	doc_491521501754_item	2473290	et	4	main
veenäiteid	doc_491521501754_item	2473295	et	3	main
võtsin	doc_491521501754_item	2473296	et	3	main
veenäidud	doc_491521501754_item	2473297	et	4	main
vale	doc_491521501754_item	2473298	et	4	main
sõna	doc_491521501754_item	2473299	et	4	main
ja	doc_491521501754_item	2473300	et	3	main
vale	doc_491521501754_item	2473301	et	4	main
vorm	doc_491521501754_item	2473302	et	3	main
tegevus	doc_491521501754_item	2473303	et	4	main
on	doc_491521501754_item	2473304	et	4	main
lühiajaline	doc_491521501754_item	2473305	et	4	main
ja	doc_491521501754_item	2473306	et	3	main
ajas	doc_491521501754_item	2473307	et	4	main
lõpetatud	doc_491521501754_item	2473308	et	4	main
objekt	doc_491521501754_item	2473310	et	3	main
ning	doc_491521501754_item	2473309	et	3	main
on	doc_491521501754_item	2473311	et	4	main
mitmuses	doc_491521501754_item	2473312	et	3	main
järelikult	doc_491521501754_item	2473313	et	3	main
objekt	doc_491521501754_item	2473314	et	3	main
peab	doc_491521501754_item	2473315	et	4	main
olema	doc_491521501754_item	2473316	et	4	main
mitmuse	doc_491521501754_item	2473317	et	3	main
nimetavas	doc_491521501754_item	2473318	et	4	main
käändes	doc_491521501754_item	2473319	et	3	main
võimalikud	doc_491521501754_item	2473320	et	3	main
põhjused	doc_491521501754_item	2473321	et	3	main
objekt	doc_491521501754_item	2473325	et	3	main
alati	doc_491521501754_item	2473326	et	4	main
винительный	doc_491521501754_item	2473330	et	2	main
kääne	doc_491521501754_item	2473331	et	3	main
näide	doc_491521501754_item	2473343	et	3	main
analoogia	doc_491521501754_item	2473353	et	4	main
ehitusfirmas	doc_491521501754_item	2473368	et	3	main
millegi	doc_491521501754_item	2473380	et	4	main
võimalik	doc_491521501754_item	2473395	et	3	main
nominatiivi	doc_491521501754_item	2473406	et	4	main
see	doc_491521501754_item	2473407	et	3	main
ka	doc_491521501754_item	2473409	et	3	main
kohakäänete	doc_491521501754_item	2473412	et	3	main
1	doc_491521501754_item	2473414	et	2	main
moodustamine	doc_491521501754_item	2473418	et	4	main
ei	doc_491521501754_item	2473423	et	4	main
läheme	doc_491521501754_item	2473427	et	3	main
lapimaale	doc_491521501754_item	2473430	et	4	main
lapimaa	doc_491521501754_item	2473432	et	4	main
keeles	doc_491521501754_item	2473323	et	4	main
винительный	doc_491521501754_item	2473327	et	2	main
käändes	doc_491521501754_item	2473328	et	3	main
aga	doc_491521501754_item	2473329	et	3	main
näiteid	doc_491521501754_item	2473337	et	3	main
leidsin	doc_491521501754_item	2473345	et	3	main
reisi	doc_491521501754_item	2473347	et	4	main
selle	doc_491521501754_item	2473349	et	4	main
võimalik	doc_491521501754_item	2473351	et	3	main
винительный	doc_491521501754_item	2473355	et	2	main
3	doc_491521501754_item	2473357	et	2	main
vahetama	doc_491521501754_item	2473360	et	3	main
torude	doc_491521501754_item	2473359	et	3	main
tulevad	doc_491521501754_item	2473361	et	4	main
tulevad	doc_491521501754_item	2473358	et	4	main
torusid	doc_491521501754_item	2473362	et	3	main
vahetama	doc_491521501754_item	2473363	et	3	main
võimalik	doc_491521501754_item	2473364	et	3	main
töötab	doc_491521501754_item	2473367	et	3	main
korda	doc_491521501754_item	2473373	et	4	main
näinud	doc_491521501754_item	2473374	et	4	main
või	doc_491521501754_item	2473379	et	4	main
4	doc_491521501754_item	2473383	et	2	main
a	doc_491521501754_item	2473397	et	4	main
sõna	doc_491521501754_item	2473405	et	4	main
seda	doc_491521501754_item	2473421	et	3	main
viga	doc_491521501754_item	2473426	et	4	main
läheme	doc_491521501754_item	2473429	et	3	main
tahtsin	doc_491521501754_item	2473431	et	3	main
väljasõit	doc_491521501754_item	2473439	et	4	main
saabumine	doc_491521501754_item	2473444	et	4	main
kell	doc_491521501754_item	2473475	et	3	main
kuuenda	doc_491521501754_item	2473485	et	3	main
l	doc_491521501754_item	2473486	et	4	main
kahekümne	doc_491521501754_item	2473487	et	4	main
üheksanda	doc_491521501754_item	2473488	et	3	main
ni	doc_491521501754_item	2473489	et	4	main
detsembrini	doc_491521501754_item	2473490	et	3	main
üheksanda	doc_491521501754_item	2473494	et	3	main
kolmanda	doc_491521501754_item	2473497	et	3	main
ni	doc_491521501754_item	2473501	et	4	main
detsembrini	doc_491521501754_item	2473502	et	3	main
korduv	doc_491521501754_item	2473508	et	4	main
1	doc_491521501754_item	2473511	et	2	main
tegeleme	doc_491521501754_item	2473513	et	3	main
eesti	doc_491521501754_item	2473517	et	4	main
на	doc_491521501754_item	2473527	et	2	main
языке	doc_491521501754_item	2473529	et	2	main
eesti	doc_491521501754_item	2473532	et	4	main
keeles	doc_491521501754_item	2473533	et	4	main
ei	doc_491521501754_item	2473534	et	4	main
kuskil	doc_491521501754_item	2473539	et	3	main
tõenäoliselt	doc_491521501754_item	2473540	et	4	main
on	doc_491521501754_item	2473549	et	4	main
kõik	doc_491521501754_item	2473550	et	4	main
on	doc_491521501754_item	2473555	et	4	main
rääkida	doc_491521501754_item	2473559	et	3	main
on	doc_491521501754_item	2473562	et	4	main
samuti	doc_491521501754_item	2473564	et	3	main
interferentsiviga	doc_491521501754_item	2473565	et	4	main
сказать	doc_491521501754_item	2473573	et	2	main
selle	doc_491521501754_item	2473577	et	4	main
2	doc_491521501754_item	2473579	et	2	main
arvsõna	doc_491521501754_item	2473580	et	4	main
rektsioon	doc_491521501754_item	2473581	et	3	main
nädal	doc_491521501754_item	2473585	et	3	main
kolm	doc_491521501754_item	2473588	et	3	main
kaks	doc_491521501754_item	2473590	et	3	main
korduv	doc_491521501754_item	2473425	et	4	main
väljumine	doc_491521501754_item	2473437	et	4	main
helsingisse	doc_491521501754_item	2473450	et	4	main
põhjus	doc_491521501754_item	2473452	et	4	main
absolutiseerimine	doc_491521501754_item	2473457	et	4	main
muud	doc_491521501754_item	2473458	et	4	main
käändevead	doc_491521501754_item	2473459	et	4	main
1	doc_491521501754_item	2473460	et	2	main
kell	doc_491521501754_item	2473461	et	3	main
kuueks	doc_491521501754_item	2473462	et	4	main
kella	doc_491521501754_item	2473463	et	4	main
kuueks	doc_491521501754_item	2473464	et	4	main
kell	doc_491521501754_item	2473465	et	3	main
üheksateist	doc_491521501754_item	2473466	et	4	main
kell	doc_491521501754_item	2473467	et	3	main
kaheteistkümneni	doc_491521501754_item	2473468	et	4	main
minema	doc_491521501754_item	2473433	et	3	main
tahtsin	doc_491521501754_item	2473434	et	3	main
lapimaale	doc_491521501754_item	2473435	et	4	main
minna	doc_491521501754_item	2473436	et	3	main
helsingi	doc_491521501754_item	2473443	et	4	main
lühikese	doc_491521501754_item	2473453	et	4	main
kella	doc_491521501754_item	2473471	et	4	main
kaheteistkümneni	doc_491521501754_item	2473472	et	4	main
kahekümne	doc_491521501754_item	2473484	et	4	main
detsembrini	doc_491521501754_item	2473495	et	3	main
keeles	doc_491521501754_item	2473515	et	4	main
käinud	doc_491521501754_item	2473535	et	4	main
on	doc_491521501754_item	2473541	et	4	main
see	doc_491521501754_item	2473542	et	3	main
interferentsiviga	doc_491521501754_item	2473543	et	4	main
käima	doc_491521501754_item	2473544	et	4	main
kus	doc_491521501754_item	2473545	et	3	main
ходить	doc_491521501754_item	2473546	et	2	main
куда	doc_491521501754_item	2473547	et	2	main
see	doc_491521501754_item	2473548	et	3	main
kõik	doc_491521501754_item	2473556	et	4	main
jutustada	doc_491521501754_item	2473560	et	3	main
хотел	doc_491521501754_item	2473572	et	2	main
nädalat	doc_491521501754_item	2473583	et	3	main
isikus	doc_491521501754_item	2473646	et	3	main
ta	doc_491521501754_item	2473649	et	4	main
tulevad	doc_491521501754_item	2473650	et	4	main
vead	doc_491521501754_item	2473663	et	4	main
l	doc_491521501754_item	2473664	et	4	main
mineviku	doc_491521501754_item	2473665	et	3	main
tingiva	doc_491521501754_item	2473669	et	4	main
ema	doc_491521501754_item	2473681	et	4	main
omane	doc_491521501754_item	2473691	et	3	main
oleviku	doc_491521501754_item	2473693	et	3	main
звоню	doc_491521501754_item	2473697	et	2	main
спрашивает	doc_491521501754_item	2473701	et	2	main
kord	doc_491521501754_item	2473703	et	4	main
ma	doc_491521501754_item	2473705	et	3	main
tahaksin	doc_491521501754_item	2473706	et	3	main
ei	doc_491521501754_item	2473707	et	4	main
ole	doc_491521501754_item	2473708	et	4	main
passis	doc_491521501754_item	2473709	et	4	main
tahtsin	doc_491521501754_item	2473716	et	3	main
mul	doc_491521501754_item	2473720	et	3	main
verbivormide	doc_491521501754_item	2473732	et	4	main
sarnasuse	doc_491521501754_item	2473734	et	4	main
tõttu	doc_491521501754_item	2473735	et	4	main
ei	doc_491521501754_item	2473736	et	4	main
tulnud	doc_491521501754_item	2473740	et	4	main
või	doc_491521501754_item	2473750	et	4	main
põhjus	doc_491521501754_item	2473759	et	4	main
vene	doc_491521501754_item	2473760	et	4	main
infinitiivivorm	doc_491521501754_item	2473765	et	4	main
ei	doc_491521501754_item	2473768	et	4	main
enam	doc_491521501754_item	2473770	et	4	main
ei	doc_491521501754_item	2473771	et	4	main
jaatava	doc_491521501754_item	2473777	et	4	main
sauna	doc_491521501754_item	2473822	et	4	main
вепсы	doc_491521501754_item	2473831	et	2	main
põhjus	doc_491521501754_item	2473832	et	4	main
sarnasuse	doc_491521501754_item	2473839	et	4	main
2	doc_491521501754_item	2473854	et	2	main
parafaasia	doc_491521501754_item	2473867	et	4	main
sõiduks	doc_491521501754_item	2473871	et	3	main
tallinna	doc_491521501754_item	2473875	et	4	main
võtsin	doc_491521501754_item	2473877	et	3	main
pakkumist	doc_491521501754_item	2473884	et	4	main
valiku	doc_491521501754_item	2473887	et	3	main
üht-teist	doc_491521501754_item	2473921	et	4	main
interferentsiviga	doc_491521501754_item	2473923	et	4	main
plitka	doc_491521501754_item	2473926	et	4	main
pani	doc_491521501754_item	2473928	et	4	main
plaate	doc_491521501754_item	2473929	et	3	main
detsember	doc_491521501754_item	2473930	et	3	main
läheb	doc_491521501754_item	2473931	et	3	main
minule	doc_491521501754_item	2473932	et	3	main
nii	doc_491521501754_item	2473933	et	3	main
minu	doc_491521501754_item	2473936	et	3	main
jaoks	doc_491521501754_item	2473945	et	4	main
väljasõit	doc_491521501754_item	2473958	et	4	main
on	doc_491521501754_item	2473966	et	4	main
lapimaalt	doc_491521501754_item	2473449	et	3	main
võimalik	doc_491521501754_item	2473451	et	3	main
funktsiooni	doc_491521501754_item	2473456	et	4	main
kella	doc_491521501754_item	2473477	et	4	main
kella	doc_491521501754_item	2473479	et	4	main
viga	doc_491521501754_item	2473482	et	4	main
2	doc_491521501754_item	2473483	et	2	main
kahekümne	doc_491521501754_item	2473491	et	4	main
kahekümne	doc_491521501754_item	2473503	et	4	main
kolmandast	doc_491521501754_item	2473504	et	4	main
kahekümne	doc_491521501754_item	2473505	et	4	main
kaheksanda	doc_491521501754_item	2473506	et	3	main
rektsioonivead	doc_491521501754_item	2473510	et	4	main
tegeleme	doc_491521501754_item	2473516	et	3	main
et	doc_491521501754_item	2473520	et	3	main
on	doc_491521501754_item	2473522	et	4	main
vrd	doc_491521501754_item	2473524	et	4	main
vene	doc_491521501754_item	2473525	et	4	main
заниматься	doc_491521501754_item	2473526	et	2	main
эстонском	doc_491521501754_item	2473528	et	2	main
tähenduses	doc_491521501754_item	2473530	et	4	main
mida	doc_491521501754_item	2473551	et	4	main
tahtsin	doc_491521501754_item	2473552	et	3	main
что	doc_491521501754_item	2473570	et	2	main
üks	doc_491521501754_item	2473582	et	3	main
kolm	doc_491521501754_item	2473586	et	3	main
pakkumist	doc_491521501754_item	2473589	et	4	main
1	doc_491521501754_item	2473622	et	2	main
kaheksandal	doc_491521501754_item	2473632	et	3	main
segiajamine	doc_491521501754_item	2473636	et	4	main
novembril	doc_491521501754_item	2473640	et	3	main
aluse	doc_491521501754_item	2473642	et	4	main
ja	doc_491521501754_item	2473643	et	3	main
öeldise	doc_491521501754_item	2473644	et	3	main
ühildumine	doc_491521501754_item	2473645	et	4	main
ja	doc_491521501754_item	2473647	et	3	main
et	doc_491521501754_item	2473684	et	3	main
on	doc_491521501754_item	2473690	et	4	main
вчера	doc_491521501754_item	2473696	et	2	main
esimene	doc_491521501754_item	2473702	et	3	main
olnud	doc_491521501754_item	2473719	et	4	main
kõlalise	doc_491521501754_item	2473733	et	4	main
välja	doc_491521501754_item	2473738	et	4	main
välja	doc_491521501754_item	2473741	et	4	main
hakkame	doc_491521501754_item	2473746	et	3	main
lapimaa	doc_491521501754_item	2473754	et	4	main
on	doc_491521501754_item	2473762	et	4	main
ainult	doc_491521501754_item	2473763	et	4	main
üks	doc_491521501754_item	2473764	et	3	main
moodustamisvead	doc_491521501754_item	2473767	et	4	main
eitava	doc_491521501754_item	2473779	et	4	main
vene	doc_491521501754_item	2473830	et	4	main
otsetõlge	doc_491521501754_item	2473842	et	3	main
poljari	doc_491521501754_item	2473843	et	4	main
vene	doc_491521501754_item	2473851	et	4	main
võru	doc_491521501754_item	2473856	et	4	main
pärast	doc_491521501754_item	2473858	et	4	main
sõiduks	doc_491521501754_item	2473869	et	3	main
tuleme	doc_491521501754_item	2473874	et	3	main
tagasi	doc_491521501754_item	2473876	et	3	main
võtsin	doc_491521501754_item	2473879	et	3	main
kirja	doc_491521501754_item	2473894	et	4	main
väljume	doc_491521501754_item	2473895	et	3	main
sõidame	doc_491521501754_item	2473896	et	3	main
tallinnast	doc_491521501754_item	2473897	et	3	main
välja	doc_491521501754_item	2473898	et	4	main
ta	doc_491521501754_item	2473924	et	4	main
kiiresti	doc_491521501754_item	2473938	et	3	main
torud	doc_491521501754_item	2473946	et	3	main
peale	doc_491521501754_item	2473976	et	4	main
või	doc_491521501754_item	2473977	et	4	main
et	doc_491521501754_item	2473986	et	3	main
ma	doc_491521501754_item	2473987	et	3	main
külastamine	doc_491521501754_item	2473990	et	4	main
kolmas	doc_491521501754_item	2473998	et	3	main
vahet	doc_491521501754_item	2474007	et	3	main
taha	doc_491521501754_item	2474010	et	4	main
tundi	doc_491521501754_item	2474011	et	4	main
saa	doc_491521501754_item	2474016	et	4	main
teha	doc_491521501754_item	2474017	et	3	main
pole	doc_491521501754_item	2474018	et	3	main
kella	doc_491521501754_item	2473469	et	4	main
üheteistkümnest	doc_491521501754_item	2473470	et	3	main
kuueteistkümneni	doc_491521501754_item	2473476	et	4	main
kuuendast	doc_491521501754_item	2473492	et	3	main
kahekümne	doc_491521501754_item	2473496	et	4	main
l	doc_491521501754_item	2473498	et	4	main
kahekümne	doc_491521501754_item	2473499	et	4	main
kaheksandake	doc_491521501754_item	2473500	et	4	main
viga	doc_491521501754_item	2473509	et	4	main
keelega	doc_491521501754_item	2473518	et	3	main
kuueteistkümneni	doc_491521501754_item	2473480	et	4	main
korduv	doc_491521501754_item	2473481	et	4	main
kahekümne	doc_491521501754_item	2473493	et	4	main
detsembrini	doc_491521501754_item	2473507	et	3	main
verbirektsioon	doc_491521501754_item	2473512	et	4	main
eesti	doc_491521501754_item	2473514	et	4	main
võimalik	doc_491521501754_item	2473519	et	3	main
see	doc_491521501754_item	2473521	et	3	main
interferentsiviga	doc_491521501754_item	2473523	et	4	main
käinud	doc_491521501754_item	2473538	et	4	main
see	doc_491521501754_item	2473554	et	3	main
tahtsin	doc_491521501754_item	2473558	et	3	main
vene	doc_491521501754_item	2473567	et	4	main
это	doc_491521501754_item	2473568	et	2	main
все	doc_491521501754_item	2473569	et	2	main
я	doc_491521501754_item	2473571	et	2	main
sellesse	doc_491521501754_item	2473575	et	4	main
üks	doc_491521501754_item	2473584	et	3	main
ja	doc_491521501754_item	2473624	et	3	main
käändes	doc_491521501754_item	2473627	et	3	main
novembris	doc_491521501754_item	2473630	et	3	main
kahekümne	doc_491521501754_item	2473631	et	4	main
grammatikareeglite	doc_491521501754_item	2473635	et	3	main
vrd	doc_491521501754_item	2473637	et	4	main
novembris	doc_491521501754_item	2473638	et	3	main
esimesel	doc_491521501754_item	2473639	et	3	main
verbivormide	doc_491521501754_item	2473661	et	4	main
valiku	doc_491521501754_item	2473662	et	3	main
ja	doc_491521501754_item	2473668	et	3	main
vormi	doc_491521501754_item	2473671	et	4	main
võimalik	doc_491521501754_item	2473683	et	3	main
see	doc_491521501754_item	2473685	et	3	main
kaudse	doc_491521501754_item	2473692	et	3	main
мама	doc_491521501754_item	2473700	et	2	main
kui	doc_491521501754_item	2473704	et	3	main
kord	doc_491521501754_item	2473713	et	4	main
ma	doc_491521501754_item	2473715	et	3	main
minna	doc_491521501754_item	2473717	et	3	main
vaba	doc_491521501754_item	2473722	et	4	main
lehte	doc_491521501754_item	2473723	et	4	main
põhjus	doc_491521501754_item	2473724	et	4	main
mineviku	doc_491521501754_item	2473725	et	3	main
ja	doc_491521501754_item	2473726	et	3	main
nende	doc_491521501754_item	2473731	et	4	main
tule	doc_491521501754_item	2473737	et	4	main
infinitiivi	doc_491521501754_item	2473743	et	4	main
töötama	doc_491521501754_item	2473749	et	3	main
tööle	doc_491521501754_item	2473752	et	3	main
minema	doc_491521501754_item	2473755	et	3	main
lapimaale	doc_491521501754_item	2473757	et	4	main
minna	doc_491521501754_item	2473758	et	3	main
olevikuvormi	doc_491521501754_item	2473780	et	4	main
püüa	doc_491521501754_item	2473784	et	4	main
püüdsin	doc_491521501754_item	2473785	et	3	main
vrd	doc_491521501754_item	2473829	et	4	main
segiajamine	doc_491521501754_item	2473837	et	4	main
kõlalise	doc_491521501754_item	2473838	et	4	main
ringist	doc_491521501754_item	2473844	et	3	main
läbi	doc_491521501754_item	2473846	et	4	main
полярный	doc_491521501754_item	2473852	et	2	main
homonüümia	doc_491521501754_item	2473855	et	4	main
3paronüümia	doc_491521501754_item	2473865	et	4	main
valmistun	doc_491521501754_item	2473870	et	3	main
tagastame	doc_491521501754_item	2473872	et	3	main
veenäidud	doc_491521501754_item	2473880	et	4	main
teha	doc_491521501754_item	2473922	et	3	main
tegi	doc_491521501754_item	2473925	et	4	main
jaoks	doc_491521501754_item	2473937	et	4	main
viisa	doc_491521501754_item	2473941	et	4	main
viisa	doc_491521501754_item	2473944	et	4	main
saabumine	doc_491521501754_item	2473962	et	4	main
karjalased	doc_491521501754_item	2473963	et	3	main
ja	doc_491521501754_item	2473964	et	3	main
vepslased	doc_491521501754_item	2473965	et	3	main
on	doc_491521501754_item	2473971	et	4	main
lapsepõlvest	doc_491521501754_item	2473972	et	4	main
nii	doc_491521501754_item	2473973	et	3	main
saadik	doc_491521501754_item	2473978	et	4	main
nad	doc_491521501754_item	2473979	et	3	main
ootavad	doc_491521501754_item	2473980	et	4	main
kui	doc_491521501754_item	2473981	et	3	main
õppima	doc_491521501754_item	2473531	et	3	main
kuhugi	doc_491521501754_item	2473536	et	4	main
ei	doc_491521501754_item	2473537	et	4	main
rääkida	doc_491521501754_item	2473553	et	3	main
millest	doc_491521501754_item	2473557	et	3	main
ilmselt	doc_491521501754_item	2473561	et	4	main
see	doc_491521501754_item	2473563	et	3	main
vrd	doc_491521501754_item	2473566	et	4	main
solvusin	doc_491521501754_item	2473574	et	3	main
solvusin	doc_491521501754_item	2473576	et	3	main
peale	doc_491521501754_item	2473578	et	4	main
pakkusid	doc_491521501754_item	2473587	et	4	main
öö	doc_491521501754_item	2473591	et	4	main
kaks	doc_491521501754_item	2473592	et	3	main
ööd	doc_491521501754_item	2473593	et	4	main
põhjus	doc_491521501754_item	2473594	et	4	main
reegli	doc_491521501754_item	2473595	et	3	main
unustamine	doc_491521501754_item	2473596	et	4	main
arvsõna	doc_491521501754_item	2473597	et	4	main
käänamine	doc_491521501754_item	2473598	et	4	main
1	doc_491521501754_item	2473599	et	2	main
järgarvsõna	doc_491521501754_item	2473600	et	4	main
vale	doc_491521501754_item	2473601	et	4	main
käänamine	doc_491521501754_item	2473602	et	4	main
kell	doc_491521501754_item	2473603	et	3	main
üheteist	doc_491521501754_item	2473604	et	4	main
kell	doc_491521501754_item	2473605	et	3	main
kaheteistkümneni	doc_491521501754_item	2473606	et	4	main
kella	doc_491521501754_item	2473607	et	4	main
üheteistkümnest	doc_491521501754_item	2473608	et	3	main
kella	doc_491521501754_item	2473609	et	4	main
kaheteistkümneni	doc_491521501754_item	2473610	et	4	main
kell	doc_491521501754_item	2473611	et	3	main
neliteist	doc_491521501754_item	2473612	et	4	main
kell	doc_491521501754_item	2473613	et	3	main
kuueteistkümneni	doc_491521501754_item	2473614	et	4	main
kella	doc_491521501754_item	2473615	et	4	main
neljateistkümnest	doc_491521501754_item	2473616	et	3	main
kella	doc_491521501754_item	2473617	et	4	main
kuueteistkümneni	doc_491521501754_item	2473618	et	4	main
korduv	doc_491521501754_item	2473619	et	4	main
viga	doc_491521501754_item	2473620	et	4	main
ühildumisvead	doc_491521501754_item	2473621	et	4	main
nimisõna	doc_491521501754_item	2473625	et	4	main
kahekümne	doc_491521501754_item	2473628	et	4	main
kaheksandal	doc_491521501754_item	2473629	et	3	main
põhjus	doc_491521501754_item	2473634	et	4	main
2	doc_491521501754_item	2473641	et	2	main
lubasid	doc_491521501754_item	2473660	et	4	main
oleviku	doc_491521501754_item	2473667	et	3	main
küsis	doc_491521501754_item	2473682	et	3	main
täiendi	doc_491521501754_item	2473623	et	3	main
ühildumine	doc_491521501754_item	2473626	et	4	main
novembril	doc_491521501754_item	2473633	et	3	main
arvus	doc_491521501754_item	2473648	et	3	main
nad	doc_491521501754_item	2473651	et	3	main
tulevad	doc_491521501754_item	2473652	et	4	main
ma	doc_491521501754_item	2473653	et	3	main
tegi	doc_491521501754_item	2473654	et	4	main
ma	doc_491521501754_item	2473655	et	3	main
tegin	doc_491521501754_item	2473656	et	3	main
sa	doc_491521501754_item	2473657	et	3	main
lubas	doc_491521501754_item	2473658	et	3	main
sa	doc_491521501754_item	2473659	et	3	main
asemel	doc_491521501754_item	2473666	et	4	main
kõneviisi	doc_491521501754_item	2473670	et	4	main
kasutamine	doc_491521501754_item	2473672	et	4	main
helistan	doc_491521501754_item	2473673	et	3	main
eile	doc_491521501754_item	2473674	et	3	main
ja	doc_491521501754_item	2473675	et	3	main
ema	doc_491521501754_item	2473676	et	4	main
küsib	doc_491521501754_item	2473677	et	3	main
helistasin	doc_491521501754_item	2473678	et	3	main
eile	doc_491521501754_item	2473679	et	3	main
ja	doc_491521501754_item	2473680	et	3	main
interferentsiviga	doc_491521501754_item	2473687	et	4	main
vrd	doc_491521501754_item	2473695	et	4	main
родителям	doc_491521501754_item	2473698	et	2	main
vaba	doc_491521501754_item	2473710	et	4	main
on	doc_491521501754_item	2473686	et	4	main
vene	doc_491521501754_item	2473688	et	4	main
keelele	doc_491521501754_item	2473689	et	4	main
kasutamine	doc_491521501754_item	2473694	et	4	main
и	doc_491521501754_item	2473699	et	2	main
lehte	doc_491521501754_item	2473711	et	4	main
esimene	doc_491521501754_item	2473712	et	3	main
kui	doc_491521501754_item	2473714	et	3	main
ei	doc_491521501754_item	2473718	et	4	main
tingiva	doc_491521501754_item	2473727	et	4	main
kõneviisi	doc_491521501754_item	2473728	et	4	main
vormi	doc_491521501754_item	2473729	et	4	main
segiajamine	doc_491521501754_item	2473730	et	4	main
2	doc_491521501754_item	2473742	et	2	main
töötada	doc_491521501754_item	2473747	et	3	main
asume	doc_491521501754_item	2473751	et	3	main
keeles	doc_491521501754_item	2473761	et	4	main
verbivormi	doc_491521501754_item	2473766	et	4	main
püüdsi	doc_491521501754_item	2473769	et	4	main
ja	doc_491521501754_item	2473778	et	3	main
moodustamisega	doc_491521501754_item	2473781	et	4	main
ei	doc_491521501754_item	2473783	et	4	main
паром	doc_491521501754_item	2473821	et	2	main
vrd	doc_491521501754_item	2473824	et	4	main
сауна	doc_491521501754_item	2473826	et	2	main
vepsad	doc_491521501754_item	2473827	et	4	main
vepslased	doc_491521501754_item	2473828	et	3	main
vene	doc_491521501754_item	2473835	et	4	main
sõnade	doc_491521501754_item	2473836	et	3	main
b	doc_491521501754_item	2473841	et	4	main
käimine	doc_491521501754_item	2473845	et	4	main
me	doc_491521501754_item	2473847	et	4	main
läbime	doc_491521501754_item	2473848	et	3	main
polaarjoone	doc_491521501754_item	2473849	et	3	main
vrd	doc_491521501754_item	2473850	et	4	main
pärast	doc_491521501754_item	2473857	et	4	main
võrut	doc_491521501754_item	2473859	et	4	main
põhjus	doc_491521501754_item	2473860	et	4	main
taga-	doc_491521501754_item	2473861	et	4	main
ja	doc_491521501754_item	2473862	et	3	main
homonüümia	doc_491521501754_item	2473864	et	4	main
ja	doc_491521501754_item	2473866	et	3	main
valmistan	doc_491521501754_item	2473868	et	3	main
kolm	doc_491521501754_item	2473881	et	3	main
4	doc_491521501754_item	2473885	et	2	main
vead	doc_491521501754_item	2473888	et	4	main
ja	doc_491521501754_item	2473889	et	3	main
stiilivead	doc_491521501754_item	2473890	et	3	main
vormistasin	doc_491521501754_item	2473891	et	3	main
veenäidud	doc_491521501754_item	2473892	et	4	main
panin	doc_491521501754_item	2473893	et	3	main
passis	doc_491521501754_item	2473721	et	4	main
ei	doc_491521501754_item	2473739	et	4	main
valiku	doc_491521501754_item	2473744	et	3	main
vead	doc_491521501754_item	2473745	et	4	main
hakkame	doc_491521501754_item	2473748	et	3	main
tahtsin	doc_491521501754_item	2473753	et	3	main
tahtsin	doc_491521501754_item	2473756	et	3	main
püüdnud	doc_491521501754_item	2473772	et	4	main
enam	doc_491521501754_item	2473773	et	4	main
võimalikud	doc_491521501754_item	2473774	et	3	main
põhjused	doc_491521501754_item	2473775	et	3	main
analoogia	doc_491521501754_item	2473776	et	4	main
püüan	doc_491521501754_item	2473782	et	3	main
ei	doc_491521501754_item	2473786	et	4	main
püüdsi	doc_491521501754_item	2473787	et	4	main
võru	doc_491521501754_item	2473788	et	4	main
murde	doc_491521501754_item	2473789	et	4	main
taust	doc_491521501754_item	2473790	et	4	main
aleksandr	doc_491521501754_item	2473791	et	4	main
suhtleb	doc_491521501754_item	2473792	et	3	main
aeg-ajalt	doc_491521501754_item	2473793	et	4	main
võrus	doc_491521501754_item	2473794	et	3	main
elavate	doc_491521501754_item	2473795	et	4	main
tellijatega	doc_491521501754_item	2473796	et	4	main
leksikaalsed	doc_491521501754_item	2473797	et	3	main
vead	doc_491521501754_item	2473798	et	4	main
1	doc_491521501754_item	2473799	et	2	main
a	doc_491521501754_item	2473800	et	4	main
tõlkelaenud	doc_491521501754_item	2473801	et	3	main
vene	doc_491521501754_item	2473802	et	4	main
keelest	doc_491521501754_item	2473803	et	4	main
plitka	doc_491521501754_item	2473804	et	4	main
plaat	doc_491521501754_item	2473805	et	3	main
keraamiline	doc_491521501754_item	2473807	et	3	main
keraamiplitka	doc_491521501754_item	2473806	et	4	main
plaat	doc_491521501754_item	2473808	et	3	main
vrd	doc_491521501754_item	2473809	et	4	main
vene	doc_491521501754_item	2473810	et	4	main
плитка	doc_491521501754_item	2473811	et	2	main
vannas	doc_491521501754_item	2473812	et	3	main
vannitoas	doc_491521501754_item	2473813	et	3	main
vrd	doc_491521501754_item	2473814	et	4	main
vene	doc_491521501754_item	2473815	et	4	main
ванная	doc_491521501754_item	2473816	et	2	main
paroomiga	doc_491521501754_item	2473817	et	4	main
praamiga	doc_491521501754_item	2473818	et	4	main
vrd	doc_491521501754_item	2473819	et	4	main
vene	doc_491521501754_item	2473820	et	4	main
saun	doc_491521501754_item	2473823	et	3	main
vene	doc_491521501754_item	2473825	et	4	main
eesti	doc_491521501754_item	2473833	et	4	main
ja	doc_491521501754_item	2473834	et	3	main
tõttu	doc_491521501754_item	2473840	et	4	main
круг	doc_491521501754_item	2473853	et	2	main
eessõna	doc_491521501754_item	2473863	et	4	main
tallinna	doc_491521501754_item	2473873	et	4	main
veenäiteid	doc_491521501754_item	2473878	et	3	main
pakkusid	doc_491521501754_item	2473882	et	4	main
kolm	doc_491521501754_item	2473883	et	3	main
sõna	doc_491521501754_item	2473886	et	4	main
sellepärast	doc_491521501754_item	2473899	et	3	main
peame	doc_491521501754_item	2473900	et	4	main
olema	doc_491521501754_item	2473901	et	4	main
kohal	doc_491521501754_item	2473902	et	4	main
kell	doc_491521501754_item	2473903	et	3	main
kaheksa	doc_491521501754_item	2473904	et	4	main
sellepärast	doc_491521501754_item	2473905	et	3	main
et	doc_491521501754_item	2473906	et	3	main
või	doc_491521501754_item	2473907	et	4	main
sest	doc_491521501754_item	2473908	et	4	main
kuigi	doc_491521501754_item	2473909	et	3	main
kaks	doc_491521501754_item	2473910	et	3	main
korda	doc_491521501754_item	2473911	et	4	main
nädalas	doc_491521501754_item	2473912	et	3	main
kasvõi	doc_491521501754_item	2473913	et	3	main
kaks	doc_491521501754_item	2473914	et	3	main
korda	doc_491521501754_item	2473915	et	4	main
nädalas	doc_491521501754_item	2473916	et	3	main
püüdsin	doc_491521501754_item	2473917	et	3	main
midagi	doc_491521501754_item	2473918	et	4	main
teha	doc_491521501754_item	2473919	et	3	main
püüdsin	doc_491521501754_item	2473920	et	3	main
ta	doc_491521501754_item	2473927	et	4	main
kiiresti	doc_491521501754_item	2473934	et	3	main
et	doc_491521501754_item	2473939	et	3	main
panna	doc_491521501754_item	2473942	et	4	main
soome	doc_491521501754_item	2473943	et	3	main
pandud	doc_491521501754_item	2473948	et	4	main
keraamiplitkaga	doc_491521501754_item	2473950	et	4	main
sugulasrahvad	doc_491521501754_item	2473969	et	3	main
lapsepõlvest	doc_491521501754_item	2473975	et	4	main
helistaksin	doc_491521501754_item	2473983	et	3	main
teha	doc_491521501754_item	2474006	et	3	main
ära	doc_491521501754_item	2474012	et	4	main
jätta	doc_491521501754_item	2474013	et	3	main
tehaparata	doc_491521501754_item	2474020	et	4	main
läheb	doc_491521501754_item	2473935	et	3	main
soome	doc_491521501754_item	2473940	et	3	main
on	doc_491521501754_item	2473947	et	4	main
kinni	doc_491521501754_item	2473949	et	3	main
torud	doc_491521501754_item	2473951	et	3	main
on	doc_491521501754_item	2473952	et	4	main
kinni	doc_491521501754_item	2473953	et	3	main
kaetud	doc_491521501754_item	2473954	et	4	main
keraamilise	doc_491521501754_item	2473955	et	3	main
plaadiga	doc_491521501754_item	2473956	et	3	main
väljumine	doc_491521501754_item	2473957	et	4	main
kust	doc_491521501754_item	2473959	et	4	main
kuhu	doc_491521501754_item	2473960	et	3	main
tulek	doc_491521501754_item	2473961	et	3	main
on	doc_491521501754_item	2473974	et	4	main
ootavad	doc_491521501754_item	2473985	et	4	main
on	doc_491521501754_item	2473995	et	4	main
juba	doc_491521501754_item	2473996	et	3	main
rongiga	doc_491521501754_item	2473997	et	4	main
on	doc_491521501754_item	2474000	et	4	main
rongireis	doc_491521501754_item	2474001	et	4	main
ma	doc_491521501754_item	2474003	et	3	main
tahaksin	doc_491521501754_item	2474004	et	3	main
ei	doc_491521501754_item	2474015	et	4	main
ничего	doc_491521501754_item	2474022	et	2	main
selline	doc_491521501754_item	2474030	et	4	main
interferentsiviga	doc_491521501754_item	2474031	et	4	main
aega	doc_491521501754_item	2474047	et	4	main
meie	doc_491521501754_item	2474048	et	4	main
meie	doc_491521501754_item	2474054	et	4	main
korteris	doc_491521501754_item	2474055	et	3	main
lõppenud	doc_491521501754_item	2474058	et	4	main
on	doc_491521501754_item	2474061	et	4	main
tööd	doc_491521501754_item	2474066	et	4	main
praegu	doc_491521501754_item	2474067	et	3	main
muud	doc_491521501754_item	2474082	et	4	main
on	doc_491521501754_item	2474094	et	4	main
sõna	doc_491521501754_item	2474103	et	4	main
soomlastega	doc_491521501754_item	2473967	et	3	main
sugulased	doc_491521501754_item	2473968	et	3	main
see	doc_491521501754_item	2473970	et	3	main
nad	doc_491521501754_item	2473984	et	3	main
helistaksin	doc_491521501754_item	2473988	et	3	main
variant	doc_491521501754_item	2473999	et	3	main
pragmaatikavead	doc_491521501754_item	2474002	et	4	main
ma	doc_491521501754_item	2474008	et	3	main
ei	doc_491521501754_item	2474009	et	4	main
midagi	doc_491521501754_item	2474014	et	4	main
on	doc_491521501754_item	2474029	et	4	main
жизнь	doc_491521501754_item	2474035	et	2	main
sõnajärg	doc_491521501754_item	2474036	et	3	main
no	doc_491521501754_item	2474037	et	3	main
vot	doc_491521501754_item	2474038	et	3	main
ei	doc_491521501754_item	2474039	et	4	main
ole	doc_491521501754_item	2474040	et	4	main
aega	doc_491521501754_item	2474041	et	4	main
korteris	doc_491521501754_item	2474049	et	3	main
remont	doc_491521501754_item	2474050	et	3	main
pole	doc_491521501754_item	2474056	et	3	main
ei	doc_491521501754_item	2474068	et	4	main
aega	doc_491521501754_item	2474078	et	4	main
need	doc_491521501754_item	2474079	et	3	main
tulevad	doc_491521501754_item	2474085	et	4	main
keeles	doc_491521501754_item	2474093	et	4	main
keeles	doc_491521501754_item	2474100	et	4	main
ma	doc_491521501754_item	2473982	et	3	main
posti	doc_491521501754_item	2473989	et	4	main
postkontori	doc_491521501754_item	2473991	et	4	main
külastamine	doc_491521501754_item	2473992	et	4	main
kolmas	doc_491521501754_item	2473993	et	3	main
variant	doc_491521501754_item	2473994	et	3	main
ei	doc_491521501754_item	2474005	et	4	main
не	doc_491521501754_item	2474023	et	2	main
see	doc_491521501754_item	2474025	et	3	main
ole	doc_491521501754_item	2474052	et	4	main
remont	doc_491521501754_item	2474057	et	3	main
kahjuks	doc_491521501754_item	2474063	et	4	main
üldse	doc_491521501754_item	2474070	et	3	main
on	doc_491521501754_item	2474080	et	4	main
interferentsivead	doc_491521501754_item	2474081	et	4	main
raha	doc_491521501754_item	2474086	et	4	main
tuleb	doc_491521501754_item	2474087	et	3	main
on	doc_491521501754_item	2474089	et	4	main
on	doc_491521501754_item	2474101	et	4	main
midagi	doc_491521501754_item	2474019	et	4	main
interferentsiviga	doc_491521501754_item	2474021	et	4	main
elu	doc_491521501754_item	2474027	et	4	main
elu	doc_491521501754_item	2474028	et	4	main
vene	doc_491521501754_item	2474033	et	4	main
это	doc_491521501754_item	2474034	et	2	main
selleks	doc_491521501754_item	2474046	et	4	main
lõppenud	doc_491521501754_item	2474053	et	4	main
kahjuks	doc_491521501754_item	2474059	et	4	main
tööd	doc_491521501754_item	2474060	et	4	main
on	doc_491521501754_item	2474064	et	4	main
palju	doc_491521501754_item	2474065	et	4	main
aega	doc_491521501754_item	2474072	et	4	main
praegu	doc_491521501754_item	2474073	et	3	main
ei	doc_491521501754_item	2474074	et	4	main
ole	doc_491521501754_item	2474075	et	4	main
minul	doc_491521501754_item	2474076	et	3	main
üldse	doc_491521501754_item	2474077	et	3	main
rahad	doc_491521501754_item	2474084	et	4	main
interferentsiviga	doc_491521501754_item	2474090	et	4	main
kuna	doc_491521501754_item	2474091	et	3	main
vene	doc_491521501754_item	2474092	et	4	main
aga	doc_491521501754_item	2474102	et	3	main
alati	doc_491521501754_item	2474105	et	4	main
поделаешь	doc_491521501754_item	2474024	et	2	main
on	doc_491521501754_item	2474026	et	4	main
vrd	doc_491521501754_item	2474032	et	4	main
selleks	doc_491521501754_item	2474042	et	4	main
üldse	doc_491521501754_item	2474043	et	3	main
pole	doc_491521501754_item	2474044	et	3	main
üldse	doc_491521501754_item	2474045	et	3	main
ei	doc_491521501754_item	2474051	et	4	main
palju	doc_491521501754_item	2474062	et	4	main
ole	doc_491521501754_item	2474069	et	4	main
minul	doc_491521501754_item	2474071	et	3	main
vead	doc_491521501754_item	2474083	et	4	main
see	doc_491521501754_item	2474088	et	3	main
sõna	doc_491521501754_item	2474095	et	4	main
деньги	doc_491521501754_item	2474096	et	2	main
alati	doc_491521501754_item	2474097	et	4	main
mitmuses	doc_491521501754_item	2474098	et	3	main
eesti	doc_491521501754_item	2474099	et	4	main
raha	doc_491521501754_item	2474104	et	4	main
ainsuses	doc_491521501754_item	2474106	et	4	main
filmi	doc_491521501758_item	2478669	et	4	main
aastal	doc_491521501758_item	2478684	et	3	main
nüganeni	doc_491521501758_item	2478686	et	4	main
nimed	doc_491521501758_item	2478688	et	3	main
on	doc_491521501758_item	2478690	et	4	main
eestlaste	doc_491521501758_item	2478706	et	4	main
kui	doc_491521501758_item	2478707	et	3	main
ka	doc_491521501758_item	2478708	et	3	main
riigi	doc_491521501758_item	2478712	et	3	main
tõsi	doc_491521501758_item	2478714	et	4	main
akivikase	doc_491521501758_item	2478716	et	4	main
oli	doc_491521501758_item	2478725	et	3	main
essee	doc_491521501758_item	2478668	et	4	main
2000	doc_491521501758_item	2478683	et	2	main
marmortahvlil	doc_491521501758_item	2478689	et	3	main
rohkem	doc_491521501758_item	2478691	et	4	main
kui	doc_491521501758_item	2478692	et	3	main
üks	doc_491521501758_item	2478693	et	3	main
kirjandusteos	doc_491521501758_item	2478694	et	4	main
lihtsalt	doc_491521501758_item	2478709	et	4	main
sünniaega	doc_491521501758_item	2478713	et	4	main
mitte	doc_491521501758_item	2478734	et	3	main
rõhutada	doc_491521501758_item	2478736	et	3	main
sajandi	doc_491521501758_item	2478742	et	3	main
oskasid	doc_491521501758_item	2478745	et	4	main
olid	doc_491521501758_item	2478749	et	4	main
oma	doc_491521501758_item	2478754	et	4	main
õigsuses	doc_491521501758_item	2478755	et	3	main
hullumeelsel	doc_491521501758_item	2478758	et	3	main
revolutsioonidel	doc_491521501758_item	2478761	et	3	main
isehakanud	doc_491521501758_item	2478764	et	3	main
lömitamise	doc_491521501758_item	2478777	et	4	main
ja	doc_491521501758_item	2478778	et	3	main
vihkamise	doc_491521501758_item	2478779	et	4	main
hambad	doc_491521501758_item	2478782	et	3	main
talupojad	doc_491521501758_item	2478785	et	4	main
oma	doc_491521501758_item	2478786	et	4	main
mõõkadeks	doc_491521501758_item	2478788	et	3	main
välja	doc_491521501758_item	2478793	et	4	main
parimaks	doc_491521501758_item	2478804	et	4	main
aastad	doc_491521501758_item	2478824	et	3	main
au	doc_491521501758_item	2478842	et	4	main
ja	doc_491521501758_item	2478848	et	3	main
veel	doc_491521501758_item	2478850	et	4	main
tähtsus	doc_491521501758_item	2478674	et	4	main
eestis	doc_491521501758_item	2478676	et	3	main
aastal	doc_491521501758_item	2478678	et	3	main
ilmunud	doc_491521501758_item	2478681	et	4	main
elmo	doc_491521501758_item	2478685	et	4	main
lavastatud	doc_491521501758_item	2478687	et	4	main
palju	doc_491521501758_item	2478696	et	4	main
see	doc_491521501758_item	2478700	et	3	main
ajaloopeegel	doc_491521501758_item	2478702	et	3	main
mis	doc_491521501758_item	2478703	et	4	main
kajastab	doc_491521501758_item	2478704	et	3	main
nii	doc_491521501758_item	2478705	et	3	main
oma	doc_491521501758_item	2478711	et	4	main
enüganeni	doc_491521501758_item	2478721	et	4	main
suurfilmile	doc_491521501758_item	2478723	et	3	main
kirjandusklassikul	doc_491521501758_item	2478724	et	3	main
eesmärgiks	doc_491521501758_item	2478728	et	3	main
maailmapilti	doc_491521501758_item	2478733	et	4	main
ja	doc_491521501758_item	2478670	et	3	main
nimed	doc_491521501758_item	2478672	et	3	main
tänapäeva	doc_491521501758_item	2478675	et	4	main
1935	doc_491521501758_item	2478677	et	2	main
kivikase	doc_491521501758_item	2478680	et	3	main
ja	doc_491521501758_item	2478682	et	3	main
ja	doc_491521501758_item	2478695	et	3	main
suurem	doc_491521501758_item	2478697	et	4	main
eestimaalaste	doc_491521501758_item	2478710	et	4	main
romaan	doc_491521501758_item	2478717	et	3	main
on	doc_491521501758_item	2478718	et	4	main
suureks	doc_491521501758_item	2478719	et	4	main
kontrastiks	doc_491521501758_item	2478720	et	4	main
rahvuslikule	doc_491521501758_item	2478722	et	3	main
näidata	doc_491521501758_item	2478729	et	4	main
tõetruult	doc_491521501758_item	2478730	et	4	main
tundeid	doc_491521501758_item	2478737	et	3	main
samas	doc_491521501758_item	2478756	et	4	main
tehnikal	doc_491521501758_item	2478759	et	3	main
sõdadel	doc_491521501758_item	2478763	et	3	main
ning	doc_491521501758_item	2478766	et	3	main
üldisest	doc_491521501758_item	2478791	et	3	main
öeldule	doc_491521501758_item	2478807	et	4	main
klassivendade	doc_491521501758_item	2478822	et	3	main
vabadussõja	doc_491521501758_item	2478823	et	3	main
lugedes	doc_491521501758_item	2478826	et	3	main
selgeks	doc_491521501758_item	2478829	et	3	main
kõlanud	doc_491521501758_item	2478837	et	4	main
sellised	doc_491521501758_item	2478838	et	4	main
kooli	doc_491521501758_item	2478845	et	4	main
üle	doc_491521501758_item	2478846	et	3	main
teos	doc_491521501758_item	2478864	et	4	main
tagasi	doc_491521501758_item	2478879	et	3	main
paremini	doc_491521501758_item	2478885	et	4	main
ajaloolist	doc_491521501758_item	2478927	et	4	main
suutsid	doc_491521501758_item	2478929	et	4	main
kuidagi	doc_491521501758_item	2478945	et	3	main
on	doc_491521501758_item	2478954	et	4	main
üldhäälestatud	doc_491521501758_item	2478969	et	3	main
ning	doc_491521501758_item	2478974	et	3	main
marta	doc_491521501758_item	2478980	et	4	main
minus	doc_491521501758_item	2478983	et	3	main
sooje	doc_491521501758_item	2478987	et	3	main
et	doc_491521501758_item	2478997	et	3	main
maha	doc_491521501758_item	2479027	et	4	main
mõned	doc_491521501758_item	2479028	et	3	main
halvasti	doc_491521501758_item	2479029	et	3	main
kõlavad	doc_491521501758_item	2479030	et	4	main
read	doc_491521501758_item	2479031	et	3	main
on	doc_491521501758_item	2479032	et	4	main
võimatu	doc_491521501758_item	2479033	et	4	main
meie	doc_491521501758_item	2479040	et	4	main
kellel	doc_491521501758_item	2479077	et	4	main
oma	doc_491521501758_item	2479085	et	4	main
et	doc_491521501758_item	2479095	et	3	main
riigi	doc_491521501758_item	2479097	et	3	main
kindlasti	doc_491521501758_item	2479100	et	3	main
selliseid	doc_491521501758_item	2479102	et	4	main
teoseid	doc_491521501758_item	2479103	et	3	main
mis	doc_491521501758_item	2479104	et	4	main
paneksid	doc_491521501758_item	2479105	et	4	main
filmist	doc_491521501759_item	2479128	et	4	main
koostaja	doc_491521501759_item	2479131	et	4	main
marmortahvlil	doc_491521501759_item	2479141	et	3	main
päevaga	doc_491521501759_item	2479144	et	3	main
muutunud	doc_491521501759_item	2479145	et	4	main
peaaegu	doc_491521501759_item	2479148	et	3	main
essee	doc_491521501758_item	2478667	et	4	main
kirjandusteose	doc_491521501758_item	2478671	et	3	main
marmortahvlil	doc_491521501758_item	2478673	et	3	main
albert	doc_491521501758_item	2478679	et	4	main
kui	doc_491521501758_item	2478698	et	3	main
film	doc_491521501758_item	2478699	et	3	main
on	doc_491521501758_item	2478701	et	4	main
küll	doc_491521501758_item	2478715	et	4	main
minu	doc_491521501758_item	2478726	et	3	main
niivõrd	doc_491521501758_item	2478735	et	3	main
näitab	doc_491521501758_item	2478739	et	3	main
valitsejad	doc_491521501758_item	2478744	et	4	main
võimetud	doc_491521501758_item	2478750	et	4	main
veenva	doc_491521501758_item	2478751	et	4	main
kõiki	doc_491521501758_item	2478752	et	4	main
rahvaid	doc_491521501758_item	2478753	et	3	main
õnnestus	doc_491521501758_item	2478757	et	4	main
jõetul	doc_491521501758_item	2478768	et	4	main
oma	doc_491521501758_item	2478770	et	4	main
ära	doc_491521501758_item	2478773	et	4	main
teha	doc_491521501758_item	2478774	et	3	main
intelligents	doc_491521501758_item	2478775	et	3	main
sirbid	doc_491521501758_item	2478787	et	3	main
ning	doc_491521501758_item	2478789	et	3	main
püüdsid	doc_491521501758_item	2478790	et	4	main
eespool	doc_491521501758_item	2478806	et	3	main
teose	doc_491521501758_item	2478809	et	3	main
võitlevate	doc_491521501758_item	2478821	et	4	main
mulle	doc_491521501758_item	2478828	et	4	main
ahase	doc_491521501758_item	2478831	et	4	main
ja	doc_491521501758_item	2478832	et	3	main
tema	doc_491521501758_item	2478833	et	4	main
koolivelide	doc_491521501758_item	2478834	et	4	main
jaoks	doc_491521501758_item	2478835	et	4	main
ei	doc_491521501758_item	2478836	et	4	main
oma	doc_491521501758_item	2478844	et	4	main
ennastsalgavus	doc_491521501758_item	2478849	et	4	main
juhtub	doc_491521501758_item	2478854	et	3	main
tihti	doc_491521501758_item	2478856	et	3	main
tänapäeva	doc_491521501758_item	2478857	et	4	main
noorte	doc_491521501758_item	2478858	et	3	main
seas	doc_491521501758_item	2478859	et	4	main
isamaalisuse	doc_491521501758_item	2478860	et	4	main
nimed	doc_491521501758_item	2478865	et	3	main
teisigi	doc_491521501758_item	2478867	et	4	main
see	doc_491521501758_item	2478869	et	3	main
nii	doc_491521501758_item	2478872	et	3	main
mõnelgi	doc_491521501758_item	2478873	et	3	main
noorel	doc_491521501758_item	2478874	et	3	main
inimesel	doc_491521501758_item	2478875	et	3	main
loodetavasti	doc_491521501758_item	2478884	et	3	main
mõista	doc_491521501758_item	2478886	et	4	main
tõusu	doc_491521501758_item	2478921	et	4	main
hukkumist	doc_491521501758_item	2478923	et	4	main
eesti	doc_491521501758_item	2478933	et	4	main
taassündi	doc_491521501758_item	2478934	et	4	main
raamatut	doc_491521501758_item	2478936	et	3	main
mulle	doc_491521501758_item	2478938	et	4	main
siiski	doc_491521501758_item	2478939	et	4	main
et	doc_491521501758_item	2478940	et	3	main
võrreldes	doc_491521501758_item	2478941	et	3	main
filmiga	doc_491521501758_item	2478942	et	3	main
mõjub	doc_491521501758_item	2478943	et	3	main
see	doc_491521501758_item	2478944	et	3	main
et	doc_491521501758_item	2478952	et	3	main
nüganeni	doc_491521501758_item	2478965	et	4	main
muusika	doc_491521501758_item	2478973	et	4	main
küljeks	doc_491521501758_item	2478991	et	3	main
võrreldes	doc_491521501758_item	2478992	et	3	main
raamatuga	doc_491521501758_item	2478993	et	4	main
ta	doc_491521501758_item	2478998	et	4	main
kellegi	doc_491521501758_item	2479000	et	4	main
film	doc_491521501758_item	2479002	et	3	main
arvates	doc_491521501758_item	2478727	et	4	main
tolleaegsete	doc_491521501758_item	2478731	et	4	main
inimeste	doc_491521501758_item	2478732	et	3	main
kuidas	doc_491521501758_item	2478740	et	3	main
keskpärased	doc_491521501758_item	2478743	et	4	main
kõike	doc_491521501758_item	2478746	et	4	main
ent	doc_491521501758_item	2478748	et	3	main
nurjunud	doc_491521501758_item	2478760	et	4	main
ja	doc_491521501758_item	2478762	et	3	main
nende	doc_491521501758_item	2478767	et	4	main
langes	doc_491521501758_item	2478776	et	4	main
ees	doc_491521501758_item	2478780	et	4	main
haosest	doc_491521501758_item	2478792	et	4	main
rabeleda	doc_491521501758_item	2478794	et	3	main
aga	doc_491521501758_item	2478796	et	3	main
kõige	doc_491521501758_item	2478797	et	4	main
ahastavam	doc_491521501758_item	2478798	et	4	main
inimene	doc_491521501758_item	2478799	et	3	main
ja	doc_491521501758_item	2478800	et	3	main
sõda	doc_491521501758_item	2478801	et	4	main
sammusid	doc_491521501758_item	2478802	et	4	main
käsikäes	doc_491521501758_item	2478803	et	3	main
tartu	doc_491521501758_item	2478811	et	4	main
kommertskooli	doc_491521501758_item	2478812	et	4	main
7	doc_491521501758_item	2478813	et	2	main
klassi	doc_491521501758_item	2478814	et	4	main
õpilase	doc_491521501758_item	2478815	et	3	main
henn	doc_491521501758_item	2478816	et	4	main
ahase	doc_491521501758_item	2478817	et	4	main
ja	doc_491521501758_item	2478818	et	3	main
temaga	doc_491521501758_item	2478819	et	3	main
ühes	doc_491521501758_item	2478820	et	4	main
sai	doc_491521501758_item	2478827	et	4	main
uhkus	doc_491521501758_item	2478843	et	4	main
teenib	doc_491521501758_item	2478862	et	3	main
marmortahvlil	doc_491521501758_item	2478866	et	3	main
eesmärke	doc_491521501758_item	2478868	et	4	main
tahet	doc_491521501758_item	2478871	et	3	main
pöörduda	doc_491521501758_item	2478876	et	3	main
juurde	doc_491521501758_item	2478878	et	4	main
ta	doc_491521501758_item	2478883	et	4	main
ja	doc_491521501758_item	2478922	et	3	main
kuid	doc_491521501758_item	2478924	et	4	main
kes	doc_491521501758_item	2478925	et	4	main
ülekohut	doc_491521501758_item	2478928	et	3	main
usu	doc_491521501758_item	2478932	et	4	main
tundus	doc_491521501758_item	2478937	et	3	main
raskepäraselt	doc_491521501758_item	2478946	et	4	main
räägitakse	doc_491521501758_item	2478950	et	3	main
alati	doc_491521501758_item	2478955	et	4	main
filmiversioon	doc_491521501758_item	2478958	et	3	main
oli	doc_491521501758_item	2478960	et	3	main
lihtne	doc_491521501758_item	2478963	et	3	main
film	doc_491521501758_item	2478966	et	3	main
romantiliselt	doc_491521501758_item	2478968	et	4	main
ka	doc_491521501758_item	2478970	et	3	main
sinna	doc_491521501758_item	2478975	et	3	main
põimitud	doc_491521501758_item	2478977	et	4	main
hennu	doc_491521501758_item	2478978	et	4	main
ja	doc_491521501758_item	2478979	et	3	main
armastuslugu	doc_491521501758_item	2478981	et	4	main
õrnu	doc_491521501758_item	2478985	et	4	main
tundeid	doc_491521501758_item	2478988	et	3	main
filmi	doc_491521501758_item	2478989	et	4	main
tugevaks	doc_491521501758_item	2478990	et	4	main
vastu	doc_491521501758_item	2479001	et	3	main
kirjanik	doc_491521501758_item	2478738	et	3	main
20	doc_491521501758_item	2478741	et	2	main
purustada	doc_491521501758_item	2478747	et	3	main
jumalustel	doc_491521501758_item	2478765	et	3	main
ideoloogial	doc_491521501758_item	2478769	et	3	main
must	doc_491521501758_item	2478771	et	4	main
töö	doc_491521501758_item	2478772	et	4	main
põlvili	doc_491521501758_item	2478781	et	3	main
ristis	doc_491521501758_item	2478783	et	4	main
tagusid	doc_491521501758_item	2478784	et	4	main
mis	doc_491521501758_item	2478795	et	4	main
näiteks	doc_491521501758_item	2478805	et	4	main
on	doc_491521501758_item	2478808	et	4	main
peategelase	doc_491521501758_item	2478810	et	3	main
raamatut	doc_491521501758_item	2478825	et	3	main
et	doc_491521501758_item	2478830	et	3	main
sõnad	doc_491521501758_item	2478839	et	4	main
nagu	doc_491521501758_item	2478840	et	3	main
aatelisus	doc_491521501758_item	2478841	et	4	main
vaprus	doc_491521501758_item	2478847	et	4	main
naeruväärsetena	doc_491521501758_item	2478851	et	3	main
seda	doc_491521501758_item	2478853	et	3	main
paha	doc_491521501758_item	2478855	et	4	main
aga	doc_491521501758_item	2478863	et	3	main
tekitab	doc_491521501758_item	2478870	et	3	main
kirjanduse	doc_491521501758_item	2478877	et	3	main
abil	doc_491521501758_item	2478881	et	4	main
vanaisade	doc_491521501758_item	2478888	et	3	main
ja	doc_491521501758_item	2478889	et	3	main
emade	doc_491521501758_item	2478890	et	3	main
noorpõlve	doc_491521501758_item	2478891	et	4	main
elu	doc_491521501758_item	2478892	et	4	main
ja	doc_491521501758_item	2478893	et	3	main
väärtushoiakuid	doc_491521501758_item	2478894	et	3	main
öeldakse	doc_491521501758_item	2478895	et	3	main
ju	doc_491521501758_item	2478896	et	3	main
et	doc_491521501758_item	2478897	et	3	main
patriatismini	doc_491521501758_item	2478898	et	4	main
jõutakse	doc_491521501758_item	2478899	et	4	main
eeskujude	doc_491521501758_item	2478900	et	3	main
kaudu	doc_491521501758_item	2478901	et	3	main
arvan	doc_491521501758_item	2478902	et	3	main
et	doc_491521501758_item	2478903	et	3	main
eestis	doc_491521501758_item	2478905	et	3	main
vajatakse	doc_491521501758_item	2478906	et	4	main
tänapäeva	doc_491521501758_item	2478904	et	4	main
just	doc_491521501758_item	2478907	et	3	main
selliseid	doc_491521501758_item	2478908	et	4	main
käspereid	doc_491521501758_item	2478909	et	4	main
ja	doc_491521501758_item	2478910	et	3	main
ahaseid	doc_491521501758_item	2478912	et	4	main
tääkereid	doc_491521501758_item	2478911	et	4	main
ja	doc_491521501758_item	2478913	et	3	main
kohlapuusid	doc_491521501758_item	2478914	et	4	main
kelle	doc_491521501758_item	2478915	et	4	main
saatuseks	doc_491521501758_item	2478916	et	4	main
oli	doc_491521501758_item	2478917	et	3	main
näha	doc_491521501758_item	2478918	et	3	main
oma	doc_491521501758_item	2478919	et	4	main
riigi	doc_491521501758_item	2478920	et	3	main
nagu	doc_491521501758_item	2478852	et	3	main
kõrval	doc_491521501758_item	2478861	et	4	main
mille	doc_491521501758_item	2478880	et	3	main
saab	doc_491521501758_item	2478882	et	3	main
oma	doc_491521501758_item	2478887	et	4	main
pärast	doc_491521501758_item	2478926	et	4	main
säilitada	doc_491521501758_item	2478931	et	3	main
lugedes	doc_491521501758_item	2478935	et	3	main
endalt	doc_491521501758_item	2478948	et	4	main
parem	doc_491521501758_item	2478956	et	4	main
aga	doc_491521501758_item	2478961	et	3	main
elmo	doc_491521501758_item	2478964	et	4	main
kõlari	doc_491521501758_item	2478972	et	3	main
sisse	doc_491521501758_item	2478976	et	4	main
kutsus	doc_491521501758_item	2478982	et	4	main
esile	doc_491521501758_item	2478984	et	3	main
ja	doc_491521501758_item	2478986	et	3	main
on	doc_491521501758_item	2478994	et	4	main
ka	doc_491521501758_item	2478995	et	3	main
pole	doc_491521501758_item	2478999	et	3	main
tõmmaks	doc_491521501758_item	2479026	et	4	main
on	doc_491521501758_item	2479036	et	4	main
et	doc_491521501758_item	2479037	et	3	main
on	doc_491521501758_item	2479039	et	4	main
kirjutada	doc_491521501758_item	2479042	et	3	main
meie	doc_491521501758_item	2479044	et	4	main
ellu	doc_491521501758_item	2479046	et	4	main
viia	doc_491521501758_item	2479047	et	3	main
oma	doc_491521501758_item	2479048	et	4	main
eespool	doc_491521501758_item	2479049	et	3	main
ka	doc_491521501758_item	2479053	et	3	main
lõppedes	doc_491521501758_item	2479058	et	4	main
tõusis	doc_491521501758_item	2479059	et	4	main
aega	doc_491521501758_item	2479067	et	4	main
teosed	doc_491521501758_item	2479071	et	3	main
too	doc_491521501758_item	2479073	et	4	main
suur	doc_491521501758_item	2479092	et	3	main
arvan	doc_491521501758_item	2479094	et	3	main
inimesi	doc_491521501758_item	2479106	et	4	main
õppejõud	doc_491521501759_item	2479134	et	4	main
eperekonnanimi	doc_491521501759_item	2479135	et	4	main
populaarseks	doc_491521501759_item	2479146	et	4	main
vestlusteemaks	doc_491521501759_item	2479147	et	4	main
oled	doc_491521501759_item	2479152	et	3	main
seoses	doc_491521501759_item	2479166	et	4	main
kuuleb	doc_491521501759_item	2479167	et	3	main
muidugi	doc_491521501759_item	2479189	et	4	main
meedias	doc_491521501759_item	2479190	et	4	main
vallapästetud	doc_491521501759_item	2479191	et	4	main
haibil	doc_491521501759_item	2479192	et	4	main
teist	doc_491521501759_item	2479196	et	4	main
tutvustatud	doc_491521501759_item	2479206	et	4	main
kiidetud	doc_491521501759_item	2479207	et	4	main
oodatud	doc_491521501759_item	2479209	et	4	main
just	doc_491521501759_item	2479215	et	3	main
lavastada	doc_491521501759_item	2479225	et	3	main
siis	doc_491521501759_item	2479227	et	3	main
talle	doc_491521501759_item	2479246	et	4	main
ida-virumaalt	doc_491521501759_item	2479252	et	3	main
piir	doc_491521501759_item	2479257	et	3	main
eesti	doc_491521501759_item	2479259	et	4	main
nii	doc_491521501759_item	2479262	et	3	main
harva	doc_491521501759_item	2479263	et	4	main
ning	doc_491521501759_item	2479264	et	3	main
film	doc_491521501759_item	2479293	et	3	main
kelle	doc_491521501759_item	2479295	et	4	main
olla	doc_491521501759_item	2479297	et	3	main
seda	doc_491521501759_item	2479305	et	3	main
võitlust	doc_491521501759_item	2479307	et	3	main
enesemüümise	doc_491521501759_item	2479319	et	3	main
eetilise	doc_491521501759_item	2479321	et	3	main
sõnumiga	doc_491521501759_item	2479328	et	3	main
mida	doc_491521501759_item	2479330	et	4	main
veel	doc_491521501759_item	2479331	et	4	main
mees	doc_491521501759_item	2479341	et	4	main
seda	doc_491521501759_item	2479342	et	3	main
nüganen	doc_491521501759_item	2479343	et	4	main
õiged	doc_491521501759_item	2479360	et	3	main
ja	doc_491521501759_item	2479379	et	3	main
hoopis	doc_491521501759_item	2479383	et	3	main
enamat	doc_491521501759_item	2479385	et	3	main
kunagi	doc_491521501759_item	2479386	et	3	main
siiski	doc_491521501758_item	2478930	et	4	main
küsisin	doc_491521501758_item	2478947	et	3	main
miks	doc_491521501758_item	2478949	et	4	main
ju	doc_491521501758_item	2478951	et	3	main
originaalteos	doc_491521501758_item	2478953	et	4	main
kui	doc_491521501758_item	2478957	et	3	main
vastus	doc_491521501758_item	2478959	et	3	main
väga	doc_491521501758_item	2478962	et	3	main
oli	doc_491521501758_item	2478967	et	3	main
margo	doc_491521501758_item	2478971	et	4	main
see	doc_491521501758_item	2478996	et	3	main
on	doc_491521501758_item	2479003	et	4	main
eesti	doc_491521501758_item	2479004	et	4	main
eest	doc_491521501758_item	2479005	et	4	main
tundus	doc_491521501758_item	2479006	et	3	main
et	doc_491521501758_item	2479007	et	3	main
filmi	doc_491521501758_item	2479008	et	4	main
idee	doc_491521501758_item	2479009	et	4	main
oli	doc_491521501758_item	2479010	et	3	main
otsida	doc_491521501758_item	2479011	et	4	main
vabadussõjale	doc_491521501758_item	2479012	et	3	main
tähendust	doc_491521501758_item	2479013	et	4	main
arvan	doc_491521501758_item	2479014	et	3	main
et	doc_491521501758_item	2479015	et	3	main
film	doc_491521501758_item	2479016	et	3	main
pani	doc_491521501758_item	2479017	et	4	main
nii	doc_491521501758_item	2479018	et	3	main
mõndagi	doc_491521501758_item	2479019	et	4	main
mõtlema	doc_491521501758_item	2479020	et	3	main
üle	doc_491521501758_item	2479022	et	3	main
mineviku	doc_491521501758_item	2479024	et	3	main
see-eest	doc_491521501758_item	2479034	et	4	main
ja	doc_491521501758_item	2479043	et	3	main
leidsin	doc_491521501758_item	2479052	et	3	main
kinosaalist	doc_491521501758_item	2479054	et	4	main
kinnituse	doc_491521501758_item	2479056	et	4	main
filmi	doc_491521501758_item	2479057	et	4	main
täis	doc_491521501758_item	2479060	et	4	main
kinosaal	doc_491521501758_item	2479061	et	3	main
püsti	doc_491521501758_item	2479062	et	3	main
ning	doc_491521501758_item	2479063	et	3	main
aplodeeris	doc_491521501758_item	2479064	et	3	main
rahvuslikud	doc_491521501758_item	2479068	et	3	main
ja	doc_491521501758_item	2479070	et	3	main
ja	doc_491521501758_item	2479081	et	3	main
kultuuriline	doc_491521501758_item	2479082	et	4	main
vaatajaile	doc_491521501758_item	2479087	et	4	main
on	doc_491521501758_item	2479090	et	4	main
tähtsus	doc_491521501758_item	2479093	et	4	main
rahval	doc_491521501758_item	2479098	et	3	main
mõtlema	doc_491521501758_item	2479107	et	3	main
selle	doc_491521501758_item	2479021	et	4	main
et	doc_491521501758_item	2479023	et	3	main
ümberkirjutamine	doc_491521501758_item	2479025	et	3	main
lastel	doc_491521501758_item	2479045	et	4	main
sõnadele	doc_491521501758_item	2479051	et	3	main
lahkudest	doc_491521501758_item	2479055	et	3	main
veel	doc_491521501758_item	2479065	et	4	main
suurfilmid	doc_491521501758_item	2479069	et	3	main
ei	doc_491521501758_item	2479072	et	4	main
liigutuspisarat	doc_491521501758_item	2479074	et	3	main
rahvaste	doc_491521501758_item	2479075	et	4	main
silma	doc_491521501758_item	2479076	et	4	main
side	doc_491521501758_item	2479083	et	4	main
see-eest	doc_491521501758_item	2479084	et	4	main
ja	doc_491521501758_item	2479088	et	3	main
rahvuslikust	doc_491521501758_item	2479108	et	4	main
uhkusest	doc_491521501758_item	2479109	et	4	main
oma	doc_491521501758_item	2479111	et	4	main
ja	doc_491521501758_item	2479110	et	3	main
ajaloost	doc_491521501758_item	2479112	et	4	main
sest	doc_491521501758_item	2479113	et	4	main
tarkus	doc_491521501758_item	2479114	et	4	main
kuulub	doc_491521501758_item	2479115	et	3	main
minevikule	doc_491521501758_item	2479116	et	3	main
toimekus	doc_491521501758_item	2479117	et	4	main
olevikule	doc_491521501758_item	2479118	et	3	main
rõõm	doc_491521501758_item	2479119	et	3	main
tulevikule	doc_491521501758_item	2479120	et	4	main
nimed	doc_491521501759_item	2479129	et	3	main
2003a	doc_491521501759_item	2479137	et	4	main
poeetiline	doc_491521501759_item	2479138	et	3	main
sõjadraama	doc_491521501759_item	2479139	et	4	main
nimed	doc_491521501759_item	2479140	et	3	main
juba	doc_491521501759_item	2479153	et	3	main
ka	doc_491521501759_item	2479159	et	3	main
minema	doc_491521501759_item	2479161	et	3	main
fraasid	doc_491521501759_item	2479163	et	3	main
mida	doc_491521501759_item	2479164	et	4	main
filmiga	doc_491521501759_item	2479165	et	3	main
koolikaslaste	doc_491521501759_item	2479170	et	4	main
kui	doc_491521501759_item	2479171	et	3	main
sugulaste	doc_491521501759_item	2479173	et	4	main
mida	doc_491521501759_item	2479175	et	4	main
mina	doc_491521501759_item	2479176	et	4	main
selles	doc_491521501759_item	2479187	et	4	main
et	doc_491521501759_item	2479194	et	3	main
aastate	doc_491521501759_item	2479198	et	3	main
filmi	doc_491521501759_item	2479200	et	4	main
ette	doc_491521501759_item	2479203	et	4	main
massiivselt	doc_491521501759_item	2479205	et	4	main
mõistus	doc_491521501759_item	2479213	et	4	main
ju	doc_491521501759_item	2479231	et	3	main
tema	doc_491521501759_item	2479232	et	4	main
teatrilavastused	doc_491521501759_item	2479233	et	3	main
analüütiline	doc_491521501759_item	2479242	et	3	main
ei	doc_491521501759_item	2479244	et	4	main
pärit	doc_491521501759_item	2479251	et	3	main
oleks	doc_491521501759_item	2479288	et	3	main
hoopis	doc_491521501759_item	2479291	et	3	main
lapsepõlves	doc_491521501759_item	2479301	et	4	main
kui	doc_491521501759_item	2479311	et	3	main
meie	doc_491521501759_item	2479317	et	4	main
selge	doc_491521501758_item	2479035	et	4	main
tulevikustsenaarium	doc_491521501758_item	2479038	et	3	main
põlvkonnal	doc_491521501758_item	2479041	et	4	main
öeldud	doc_491521501758_item	2479050	et	4	main
tükk	doc_491521501758_item	2479066	et	3	main
puudub	doc_491521501758_item	2479078	et	3	main
nendega	doc_491521501758_item	2479079	et	4	main
emotsionaalne	doc_491521501758_item	2479080	et	3	main
rahva	doc_491521501758_item	2479086	et	3	main
lugejaile	doc_491521501758_item	2479089	et	4	main
neil	doc_491521501758_item	2479091	et	4	main
meie	doc_491521501758_item	2479096	et	4	main
oleks	doc_491521501758_item	2479099	et	3	main
vaja	doc_491521501758_item	2479101	et	4	main
essee	doc_491521501759_item	2479121	et	4	main
pedagoogika	doc_491521501759_item	2479123	et	4	main
ülikool	doc_491521501759_item	2479124	et	4	main
esse	doc_491521501759_item	2479125	et	3	main
minu	doc_491521501759_item	2479126	et	3	main
arvamus	doc_491521501759_item	2479127	et	3	main
tallinn	doc_491521501759_item	2479136	et	4	main
on	doc_491521501759_item	2479142	et	4	main
mõne	doc_491521501759_item	2479143	et	3	main
kuidas	doc_491521501759_item	2479155	et	3	main
ja	doc_491521501759_item	2479157	et	3	main
ikka	doc_491521501759_item	2479160	et	4	main
sellest	doc_491521501759_item	2479177	et	4	main
arvan	doc_491521501759_item	2479178	et	3	main
ma	doc_491521501759_item	2479179	et	3	main
ootasin	doc_491521501759_item	2479180	et	3	main
paljut	doc_491521501759_item	2479184	et	3	main
kodumaist	doc_491521501759_item	2479199	et	4	main
on	doc_491521501759_item	2479201	et	4	main
terve	doc_491521501759_item	2479212	et	4	main
sedasama	doc_491521501759_item	2479216	et	4	main
tallinna	doc_491521501759_item	2479122	et	4	main
marmortahvlil	doc_491521501759_item	2479130	et	3	main
eesnimi	doc_491521501759_item	2479132	et	3	main
perekonnanimi	doc_491521501759_item	2479133	et	3	main
näinud	doc_491521501759_item	2479154	et	4	main
nii	doc_491521501759_item	2479168	et	3	main
sellest	doc_491521501759_item	2479181	et	4	main
filmist	doc_491521501759_item	2479182	et	4	main
päris	doc_491521501759_item	2479183	et	4	main
vaevalt	doc_491521501759_item	2479193	et	4	main
ühtki	doc_491521501759_item	2479195	et	4	main
kuid	doc_491521501759_item	2479210	et	4	main
ka	doc_491521501759_item	2479211	et	3	main
kui	doc_491521501759_item	2479217	et	3	main
eestis	doc_491521501759_item	2479218	et	3	main
keegi	doc_491521501759_item	2479219	et	4	main
üleüldse	doc_491521501759_item	2479220	et	3	main
filmi	doc_491521501759_item	2479224	et	4	main
suudaks	doc_491521501759_item	2479226	et	3	main
nüganen	doc_491521501759_item	2479229	et	4	main
rahvusvahelisel	doc_491521501759_item	2479234	et	4	main
tasemel	doc_491521501759_item	2479235	et	3	main
ja	doc_491521501759_item	2479236	et	3	main
ka	doc_491521501759_item	2479237	et	3	main
tõsiseltvõetava	doc_491521501759_item	2479238	et	3	main
mõttetöö	doc_491521501759_item	2479243	et	4	main
tundu	doc_491521501759_item	2479245	et	4	main
minagi	doc_491521501759_item	2479254	et	4	main
läheb	doc_491521501759_item	2479256	et	3	main
iga	doc_491521501759_item	2479265	et	4	main
ilmselt	doc_491521501759_item	2479287	et	4	main
ka	doc_491521501759_item	2479290	et	3	main
jaoks	doc_491521501759_item	2479296	et	4	main
eestlane	doc_491521501759_item	2479298	et	3	main
on	doc_491521501759_item	2479299	et	4	main
vähemalt	doc_491521501759_item	2479300	et	4	main
ka	doc_491521501759_item	2479309	et	3	main
võtab	doc_491521501759_item	2479313	et	3	main
vaevaks	doc_491521501759_item	2479314	et	4	main
teeb	doc_491521501759_item	2479316	et	3	main
praegusel	doc_491521501759_item	2479318	et	3	main
ja	doc_491521501759_item	2479320	et	3	main
kriisi	doc_491521501759_item	2479322	et	4	main
sellise	doc_491521501759_item	2479324	et	4	main
vaadata	doc_491521501759_item	2479335	et	4	main
on	doc_491521501759_item	2479337	et	4	main
ta	doc_491521501759_item	2479338	et	4	main
ongi	doc_491521501759_item	2479344	et	4	main
meeldetuletust	doc_491521501759_item	2479355	et	4	main
mehed	doc_491521501759_item	2479361	et	3	main
auto	doc_491521501759_item	2479378	et	4	main
midagi	doc_491521501759_item	2479384	et	4	main
kaitsta	doc_491521501759_item	2479391	et	4	main
mitte	doc_491521501759_item	2479397	et	3	main
olid	doc_491521501759_item	2479407	et	4	main
on	doc_491521501759_item	2479424	et	4	main
olla	doc_491521501759_item	2479427	et	3	main
filmi	doc_491521501759_item	2479437	et	4	main
see	doc_491521501759_item	2479442	et	3	main
ka	doc_491521501759_item	2479443	et	3	main
marmortahvlilpeamõte	doc_491521501759_item	2479457	et	4	main
nüganen	doc_491521501759_item	2479462	et	4	main
arvamusküljel	doc_491521501759_item	2479465	et	3	main
filmi	doc_491521501759_item	2479469	et	4	main
ajaloo	doc_491521501759_item	2479479	et	4	main
ja	doc_491521501759_item	2479480	et	3	main
käinud	doc_491521501759_item	2479488	et	4	main
ega	doc_491521501759_item	2479489	et	3	main
see	doc_491521501759_item	2479495	et	3	main
perioodil	doc_491521501760_item	2479521	et	3	main
a	doc_491521501760_item	2479524	et	4	main
maha	doc_491521501760_item	2479526	et	4	main
klassikuteks	doc_491521501760_item	2479541	et	3	main
maria	doc_491521501760_item	2479545	et	4	main
gustav	doc_491521501760_item	2479547	et	4	main
suits	doc_491521501760_item	2479548	et	3	main
iivaste	doc_491521501760_item	2479571	et	4	main
igas	doc_491521501759_item	2479149	et	3	main
seltskonnas	doc_491521501759_item	2479150	et	3	main
kas	doc_491521501759_item	2479151	et	3	main
meeldis	doc_491521501759_item	2479156	et	3	main
peaks	doc_491521501759_item	2479158	et	4	main
on	doc_491521501759_item	2479162	et	4	main
sõprade	doc_491521501759_item	2479169	et	3	main
ka	doc_491521501759_item	2479172	et	3	main
suust	doc_491521501759_item	2479174	et	3	main
omajagu	doc_491521501759_item	2479185	et	3	main
osa	doc_491521501759_item	2479186	et	4	main
oli	doc_491521501759_item	2479188	et	3	main
viimaste	doc_491521501759_item	2479197	et	3	main
juba	doc_491521501759_item	2479202	et	3	main
niivõrd	doc_491521501759_item	2479204	et	3	main
ja	doc_491521501759_item	2479208	et	3	main
ütles	doc_491521501759_item	2479214	et	3	main
normaalse	doc_491521501759_item	2479221	et	3	main
värske	doc_491521501759_item	2479223	et	4	main
loomiseks	doc_491521501759_item	2479240	et	4	main
võõras	doc_491521501759_item	2479247	et	4	main
olema	doc_491521501759_item	2479248	et	4	main
poleks	doc_491521501759_item	2479249	et	3	main
nagu	doc_491521501759_item	2479253	et	3	main
kust	doc_491521501759_item	2479255	et	4	main
ja	doc_491521501759_item	2479258	et	3	main
hetk	doc_491521501759_item	2479266	et	3	main
ja	doc_491521501759_item	2479286	et	3	main
teine	doc_491521501759_item	2479292	et	3	main
väärtustada	doc_491521501759_item	2479308	et	3	main
keegi	doc_491521501759_item	2479312	et	4	main
ja	doc_491521501759_item	2479315	et	3	main
ka	doc_491521501759_item	2479334	et	3	main
kannatab	doc_491521501759_item	2479336	et	3	main
olid	doc_491521501759_item	2479359	et	4	main
tea	doc_491521501759_item	2479363	et	4	main
on	doc_491521501759_item	2479365	et	4	main
tänapäeval	doc_491521501759_item	2479368	et	3	main
et	doc_491521501759_item	2479371	et	3	main
noor	doc_491521501759_item	2479380	et	3	main
seda	doc_491521501759_item	2479393	et	3	main
vinguma	doc_491521501759_item	2479398	et	3	main
et	doc_491521501759_item	2479399	et	3	main
koolipoisid	doc_491521501759_item	2479409	et	4	main
kas	doc_491521501759_item	2479422	et	3	main
just	doc_491521501759_item	2479447	et	3	main
see	doc_491521501759_item	2479448	et	3	main
ongi	doc_491521501759_item	2479449	et	4	main
kui	doc_491521501759_item	2479450	et	3	main
ma	doc_491521501759_item	2479451	et	3	main
õigesti	doc_491521501759_item	2479452	et	3	main
aru	doc_491521501759_item	2479453	et	4	main
elmo	doc_491521501759_item	2479461	et	4	main
eesmärk	doc_491521501759_item	2479466	et	3	main
uhke	doc_491521501759_item	2479477	et	4	main
on	doc_491521501759_item	2479485	et	4	main
vabadussõjast	doc_491521501759_item	2479486	et	3	main
läbi	doc_491521501759_item	2479487	et	4	main
ajalugu	doc_491521501759_item	2479491	et	4	main
kinolinal	doc_491521501759_item	2479496	et	3	main
kuni	doc_491521501760_item	2479522	et	3	main
pagulaskirjandust	doc_491521501760_item	2479528	et	3	main
pagulaskirjandus	doc_491521501760_item	2479535	et	3	main
kuuluvad	doc_491521501760_item	2479544	et	4	main
jlaatan	doc_491521501760_item	2479561	et	4	main
ole	doc_491521501760_item	2479564	et	4	main
saanud	doc_491521501760_item	2479569	et	4	main
paguluseks	doc_491521501760_item	2479570	et	4	main
eksiilluuletajate	doc_491521501760_item	2479573	et	3	main
e	doc_491521501760_item	2479579	et	4	main
essee	doc_491521501761_item	2479588	et	4	main
eesti	doc_491521501761_item	2479589	et	4	main
eile	doc_491521501761_item	2479590	et	3	main
täna	doc_491521501761_item	2479591	et	4	main
homme	doc_491521501761_item	2479592	et	3	main
kiirelt	doc_491521501761_item	2479599	et	4	main
ajalugu	doc_491521501761_item	2479605	et	4	main
aastatuhandeid	doc_491521501761_item	2479609	et	4	main
ja	doc_491521501759_item	2479222	et	3	main
elmo	doc_491521501759_item	2479228	et	4	main
on	doc_491521501759_item	2479230	et	4	main
filmi	doc_491521501759_item	2479239	et	4	main
hädavajalik	doc_491521501759_item	2479241	et	3	main
nüganen	doc_491521501759_item	2479250	et	4	main
keelt	doc_491521501759_item	2479260	et	4	main
kuuleb	doc_491521501759_item	2479261	et	3	main
on	doc_491521501759_item	2479267	et	4	main
vaja	doc_491521501759_item	2479268	et	4	main
valmis	doc_491521501759_item	2479269	et	4	main
olla	doc_491521501759_item	2479270	et	3	main
võitluseks	doc_491521501759_item	2479271	et	3	main
oma	doc_491521501759_item	2479272	et	4	main
olemasolu	doc_491521501759_item	2479273	et	4	main
eest	doc_491521501759_item	2479274	et	4	main
vähemalt	doc_491521501759_item	2479275	et	4	main
eestlasest	doc_491521501759_item	2479276	et	3	main
koolipoisil	doc_491521501759_item	2479277	et	3	main
ilmselt	doc_491521501759_item	2479278	et	4	main
poleks	doc_491521501759_item	2479279	et	3	main
tunnetanud	doc_491521501759_item	2479280	et	4	main
nii	doc_491521501759_item	2479281	et	3	main
teravalt	doc_491521501759_item	2479282	et	4	main
sellise	doc_491521501759_item	2479283	et	4	main
linateose	doc_491521501759_item	2479284	et	3	main
vajalikkust	doc_491521501759_item	2479285	et	4	main
sündinud	doc_491521501759_item	2479289	et	4	main
inimene	doc_491521501759_item	2479294	et	3	main
peaaegu	doc_491521501759_item	2479302	et	3	main
kangelastegu	doc_491521501759_item	2479303	et	4	main
oskab	doc_491521501759_item	2479304	et	3	main
kangelasliku	doc_491521501759_item	2479306	et	3	main
kinolinal	doc_491521501759_item	2479310	et	3	main
ajal	doc_491521501759_item	2479323	et	4	main
selgete	doc_491521501759_item	2479325	et	4	main
väärtushinnangu	doc_491521501759_item	2479326	et	3	main
lisaks	doc_491521501759_item	2479333	et	4	main
tubli	doc_491521501759_item	2479340	et	4	main
ja	doc_491521501759_item	2479350	et	3	main
keskealised	doc_491521501759_item	2479351	et	4	main
vajavad	doc_491521501759_item	2479352	et	4	main
minu	doc_491521501759_item	2479353	et	3	main
meelest	doc_491521501759_item	2479354	et	4	main
et	doc_491521501759_item	2479356	et	3	main
eesti	doc_491521501759_item	2479357	et	4	main
mehed	doc_491521501759_item	2479358	et	3	main
ei	doc_491521501759_item	2479362	et	4	main
kas	doc_491521501759_item	2479364	et	3	main
seda	doc_491521501759_item	2479366	et	3	main
tahaks	doc_491521501759_item	2479369	et	3	main
mehe	doc_491521501759_item	2479372	et	3	main
vaid	doc_491521501759_item	2479382	et	3	main
peab	doc_491521501759_item	2479394	et	4	main
ka	doc_491521501759_item	2479395	et	3	main
nagunii	doc_491521501759_item	2479400	et	3	main
saa	doc_491521501759_item	2479402	et	4	main
mis	doc_491521501759_item	2479404	et	4	main
nüüd	doc_491521501759_item	2479405	et	4	main
võidu	doc_491521501759_item	2479421	et	4	main
praegused	doc_491521501759_item	2479423	et	3	main
ei	doc_491521501759_item	2479428	et	4	main
olegi	doc_491521501759_item	2479429	et	4	main
on	doc_491521501759_item	2479432	et	4	main
kuidagi	doc_491521501759_item	2479433	et	3	main
nihkunud	doc_491521501759_item	2479434	et	4	main
kui	doc_491521501759_item	2479435	et	3	main
nimed	doc_491521501759_item	2479456	et	3	main
filmi	doc_491521501759_item	2479459	et	4	main
eesti	doc_491521501759_item	2479478	et	4	main
ega	doc_491521501759_item	2479492	et	3	main
kuidas	doc_491521501759_item	2479494	et	3	main
see	doc_491521501759_item	2479499	et	3	main
kogu	doc_491521501760_item	2479527	et	4	main
pagulas	doc_491521501760_item	2479530	et	4	main
aastani	doc_491521501760_item	2479533	et	3	main
oli	doc_491521501760_item	2479536	et	3	main
pagulasluuletajad	doc_491521501760_item	2479538	et	3	main
1	doc_491521501760_item	2479540	et	2	main
kelle	doc_491521501760_item	2479542	et	4	main
hulka	doc_491521501760_item	2479543	et	4	main
under	doc_491521501760_item	2479546	et	4	main
2	doc_491521501760_item	2479549	et	2	main
klassikute	doc_491521501760_item	2479550	et	3	main
kaasaegsed	doc_491521501760_item	2479551	et	3	main
fgrünthal	doc_491521501760_item	2479560	et	4	main
ei	doc_491521501760_item	2479563	et	4	main
eestis	doc_491521501760_item	2479565	et	3	main
sündinud	doc_491521501760_item	2479566	et	4	main
ja	doc_491521501760_item	2479567	et	3	main
hariduse	doc_491521501760_item	2479568	et	3	main
ülesandeks	doc_491521501760_item	2479574	et	4	main
kirjanduse	doc_491521501760_item	2479581	et	3	main
säilitamine	doc_491521501760_item	2479582	et	4	main
püütakse	doc_491521501760_item	2479583	et	3	main
säilitada	doc_491521501760_item	2479584	et	3	main
on	doc_491521501761_item	2479595	et	4	main
praeguses	doc_491521501761_item	2479596	et	3	main
ajajärgus	doc_491521501761_item	2479597	et	4	main
mitmeid	doc_491521501761_item	2479608	et	4	main
tagasi	doc_491521501761_item	2479610	et	3	main
eesti	doc_491521501761_item	2479611	et	4	main
riik	doc_491521501761_item	2479612	et	3	main
kui	doc_491521501761_item	2479613	et	3	main
riik	doc_491521501761_item	2479614	et	3	main
lahingute	doc_491521501761_item	2479619	et	4	main
vene	doc_491521501761_item	2479621	et	4	main
saksa	doc_491521501761_item	2479623	et	4	main
ja	doc_491521501759_item	2479327	et	3	main
filmi	doc_491521501759_item	2479329	et	4	main
kõigele	doc_491521501759_item	2479332	et	4	main
lihtsalt	doc_491521501759_item	2479339	et	4	main
eesti	doc_491521501759_item	2479345	et	4	main
noored	doc_491521501759_item	2479346	et	3	main
aga	doc_491521501759_item	2479347	et	3	main
ka	doc_491521501759_item	2479348	et	3	main
vanad	doc_491521501759_item	2479349	et	3	main
ka	doc_491521501759_item	2479367	et	3	main
uskuda	doc_491521501759_item	2479370	et	3	main
ainus	doc_491521501759_item	2479373	et	4	main
väärtus	doc_491521501759_item	2479374	et	3	main
pole	doc_491521501759_item	2479375	et	3	main
vaid	doc_491521501759_item	2479376	et	3	main
uus	doc_491521501759_item	2479377	et	3	main
blondiin	doc_491521501759_item	2479381	et	3	main
võidetud	doc_491521501759_item	2479388	et	4	main
vabadust	doc_491521501759_item	2479389	et	4	main
tuleb	doc_491521501759_item	2479390	et	3	main
julgema	doc_491521501759_item	2479396	et	4	main
ei	doc_491521501759_item	2479401	et	4	main
ja	doc_491521501759_item	2479403	et	3	main
ju	doc_491521501759_item	2479408	et	3	main
kes	doc_491521501759_item	2479410	et	4	main
panid	doc_491521501759_item	2479411	et	4	main
vastu	doc_491521501759_item	2479412	et	3	main
kahele	doc_491521501759_item	2479413	et	4	main
tugevale	doc_491521501759_item	2479414	et	4	main
armeele	doc_491521501759_item	2479415	et	3	main
ja	doc_491521501759_item	2479416	et	3	main
julgesid	doc_491521501759_item	2479417	et	4	main
uskuda	doc_491521501759_item	2479418	et	3	main
ja	doc_491521501759_item	2479419	et	3	main
tõidki	doc_491521501759_item	2479420	et	4	main
poisid	doc_491521501759_item	2479436	et	4	main
paneb	doc_491521501759_item	2479441	et	3	main
neis	doc_491521501759_item	2479444	et	4	main
midagi	doc_491521501759_item	2479445	et	4	main
liikuma	doc_491521501759_item	2479446	et	3	main
filmi	doc_491521501759_item	2479455	et	4	main
lavastaja	doc_491521501759_item	2479460	et	4	main
päevalehe	doc_491521501759_item	2479464	et	3	main
oli	doc_491521501759_item	2479467	et	3	main
vanaisa	doc_491521501759_item	2479472	et	4	main
lapselaps	doc_491521501759_item	2479474	et	4	main
kes	doc_491521501759_item	2479475	et	4	main
oleks	doc_491521501759_item	2479476	et	3	main
vanaisa	doc_491521501759_item	2479484	et	4	main
häbene	doc_491521501759_item	2479490	et	4	main
seda	doc_491521501759_item	2479493	et	3	main
võetud	doc_491521501759_item	2479498	et	4	main
1988	doc_491521501760_item	2479523	et	2	main
vaikiti	doc_491521501760_item	2479525	et	3	main
ei	doc_491521501760_item	2479529	et	4	main
kuni	doc_491521501760_item	2479532	et	3	main
1988	doc_491521501760_item	2479534	et	2	main
kadunud	doc_491521501760_item	2479556	et	4	main
põlvkond	doc_491521501760_item	2479557	et	3	main
kolk	doc_491521501760_item	2479558	et	3	main
klepik	doc_491521501760_item	2479559	et	4	main
4	doc_491521501760_item	2479562	et	2	main
ukaruks	doc_491521501760_item	2479572	et	4	main
eesti	doc_491521501760_item	2479576	et	4	main
eesti	doc_491521501761_item	2479593	et	4	main
riik	doc_491521501761_item	2479594	et	3	main
riik	doc_491521501761_item	2479603	et	3	main
aasta	doc_491521501761_item	2479618	et	4	main
vastu	doc_491521501761_item	2479625	et	3	main
see	doc_491521501761_item	2479641	et	3	main
endla	doc_491521501761_item	2479648	et	4	main
kätte	doc_491521501759_item	2479387	et	4	main
ja	doc_491521501759_item	2479392	et	3	main
meie	doc_491521501759_item	2479406	et	4	main
viletsamad	doc_491521501759_item	2479425	et	4	main
võib	doc_491521501759_item	2479426	et	3	main
ainult	doc_491521501759_item	2479430	et	4	main
väärtushinnangud	doc_491521501759_item	2479431	et	3	main
ära	doc_491521501759_item	2479438	et	4	main
vaatavad	doc_491521501759_item	2479439	et	4	main
ehk	doc_491521501759_item	2479440	et	3	main
saan	doc_491521501759_item	2479454	et	4	main
ise	doc_491521501759_item	2479458	et	4	main
kirjutas	doc_491521501759_item	2479463	et	3	main
et	doc_491521501759_item	2479468	et	3	main
tuleks	doc_491521501759_item	2479470	et	4	main
vaatama	doc_491521501759_item	2479471	et	3	main
ja	doc_491521501759_item	2479473	et	3	main
selle	doc_491521501759_item	2479481	et	4	main
üle	doc_491521501759_item	2479482	et	3	main
et	doc_491521501759_item	2479483	et	3	main
üles	doc_491521501759_item	2479497	et	3	main
eesmärk	doc_491521501759_item	2479500	et	3	main
on	doc_491521501759_item	2479501	et	4	main
minu	doc_491521501759_item	2479502	et	3	main
arvates	doc_491521501759_item	2479503	et	4	main
kindlasti	doc_491521501759_item	2479504	et	3	main
saavutatud	doc_491521501759_item	2479505	et	4	main
tublid	doc_491521501759_item	2479506	et	3	main
filmitegijad	doc_491521501759_item	2479507	et	3	main
vastus	doc_491521501760_item	2479508	et	3	main
küsimusele	doc_491521501760_item	2479509	et	4	main
1eesti	doc_491521501760_item	2479510	et	4	main
kultuur	doc_491521501760_item	2479511	et	3	main
eksiilis	doc_491521501760_item	2479512	et	4	main
konfrontatsioon	doc_491521501760_item	2479513	et	4	main
e	doc_491521501760_item	2479514	et	4	main
vastandus	doc_491521501760_item	2479515	et	4	main
oli	doc_491521501760_item	2479516	et	3	main
omane	doc_491521501760_item	2479517	et	3	main
eesti	doc_491521501760_item	2479518	et	4	main
kirjandusele	doc_491521501760_item	2479519	et	3	main
sel	doc_491521501760_item	2479520	et	3	main
kirjandusele	doc_491521501760_item	2479531	et	3	main
keelatud	doc_491521501760_item	2479537	et	4	main
jagunevad	doc_491521501760_item	2479539	et	4	main
b	doc_491521501760_item	2479552	et	4	main
kangro	doc_491521501760_item	2479553	et	4	main
kristikivi	doc_491521501760_item	2479554	et	4	main
3	doc_491521501760_item	2479555	et	2	main
eesti	doc_491521501760_item	2479580	et	4	main
arenev	doc_491521501761_item	2479600	et	4	main
väike	doc_491521501761_item	2479601	et	4	main
eestlaste	doc_491521501761_item	2479604	et	4	main
algas	doc_491521501761_item	2479606	et	3	main
juba	doc_491521501761_item	2479607	et	3	main
tulemusena	doc_491521501761_item	2479620	et	3	main
purustati	doc_491521501761_item	2479626	et	3	main
02021918a	doc_491521501761_item	2479631	et	4	main
esmakordselt	doc_491521501761_item	2479642	et	4	main
teatri	doc_491521501761_item	2479649	et	3	main
toimus	doc_491521501761_item	2479663	et	3	main
pätsi	doc_491521501761_item	2479668	et	4	main
demokraatias	doc_491521501761_item	2479672	et	3	main
ja	doc_491521501761_item	2479675	et	3	main
ja	doc_491521501761_item	2479686	et	3	main
eesti	doc_491521501761_item	2479699	et	4	main
saksa	doc_491521501761_item	2479727	et	4	main
sõjajõud	doc_491521501761_item	2479728	et	4	main
2	doc_491521501761_item	2479748	et	2	main
aega	doc_491521501761_item	2479750	et	4	main
sõda	doc_491521501761_item	2479762	et	4	main
eestlased	doc_491521501761_item	2479764	et	3	main
kahte	doc_491521501761_item	2479765	et	4	main
vend	doc_491521501761_item	2479776	et	3	main
oli	doc_491521501760_item	2479575	et	3	main
järjepidevuse	doc_491521501760_item	2479577	et	4	main
säilitamine	doc_491521501760_item	2479578	et	4	main
eesti	doc_491521501760_item	2479585	et	4	main
kirjanduse	doc_491521501760_item	2479586	et	3	main
traditsioone	doc_491521501760_item	2479587	et	3	main
väga	doc_491521501761_item	2479598	et	3	main
demokratlik	doc_491521501761_item	2479602	et	4	main
sai	doc_491521501761_item	2479615	et	4	main
alguse	doc_491521501761_item	2479616	et	3	main
1918	doc_491521501761_item	2479617	et	2	main
riigi	doc_491521501761_item	2479624	et	3	main
rahu	doc_491521501761_item	2479633	et	4	main
loeti	doc_491521501761_item	2479643	et	3	main
aastal	doc_491521501761_item	2479646	et	3	main
raske	doc_491521501761_item	2479652	et	4	main
riigi	doc_491521501761_item	2479654	et	3	main
jagati	doc_491521501761_item	2479658	et	3	main
areng	doc_491521501761_item	2479662	et	3	main
tõusude	doc_491521501761_item	2479664	et	3	main
pakt	doc_491521501761_item	2479690	et	3	main
malatov	doc_491521501761_item	2479692	et	4	main
pakt	doc_491521501761_item	2479694	et	3	main
tulemusena	doc_491521501761_item	2479696	et	3	main
riigid	doc_491521501761_item	2479698	et	3	main
läti	doc_491521501761_item	2479700	et	4	main
leedu	doc_491521501761_item	2479701	et	4	main
anti	doc_491521501761_item	2479702	et	3	main
mõjusfääri	doc_491521501761_item	2479705	et	4	main
a	doc_491521501761_item	2479721	et	4	main
suuri	doc_491521501761_item	2479730	et	3	main
ettevalmistusi	doc_491521501761_item	2479731	et	3	main
vastastikuse	doc_491521501761_item	2479732	et	4	main
alustamiseks	doc_491521501761_item	2479734	et	4	main
14061941a	doc_491521501761_item	2479735	et	4	main
korjamiseks	doc_491521501761_item	2479747	et	4	main
ruttu	doc_491521501761_item	2479753	et	4	main
kodud	doc_491521501761_item	2479755	et	3	main
leeri	doc_491521501761_item	2479766	et	4	main
sõdis	doc_491521501761_item	2479773	et	3	main
sõja	doc_491521501761_item	2479780	et	3	main
okupeeriti	doc_491521501761_item	2479787	et	3	main
praktiliselt	doc_491521501761_item	2479822	et	4	main
eesti	doc_491521501761_item	2479827	et	4	main
sai	doc_491521501761_item	2479841	et	4	main
suhteliselt	doc_491521501761_item	2479842	et	4	main
oma	doc_491521501761_item	2479857	et	4	main
mõtteid	doc_491521501761_item	2479858	et	3	main
ja	doc_491521501761_item	2479859	et	3	main
tegusid	doc_491521501761_item	2479860	et	4	main
muinsuskaitse	doc_491521501761_item	2479869	et	4	main
et	doc_491521501761_item	2479896	et	3	main
võetakse	doc_491521501761_item	2479898	et	3	main
eesti	doc_491521501761_item	2479900	et	4	main
seadused	doc_491521501761_item	2479902	et	3	main
mis	doc_491521501761_item	2479903	et	4	main
otsustas	doc_491521501761_item	2479910	et	3	main
organ	doc_491521501761_item	2479914	et	3	main
taastada	doc_491521501761_item	2479915	et	3	main
riik	doc_491521501761_item	2479917	et	3	main
ja	doc_491521501761_item	2479918	et	3	main
lugeda	doc_491521501761_item	2479919	et	3	main
praegust	doc_491521501761_item	2479920	et	3	main
ja	doc_491521501761_item	2479622	et	3	main
saksa	doc_491521501761_item	2479627	et	4	main
ja	doc_491521501761_item	2479629	et	3	main
tartu	doc_491521501761_item	2479632	et	4	main
eesti	doc_491521501761_item	2479634	et	4	main
riik	doc_491521501761_item	2479635	et	3	main
kuulutati	doc_491521501761_item	2479636	et	4	main
23021918	doc_491521501761_item	2479645	et	2	main
algas	doc_491521501761_item	2479651	et	3	main
ülesehitamise	doc_491521501761_item	2479655	et	3	main
talupoegadele	doc_491521501761_item	2479659	et	3	main
mõõnadega	doc_491521501761_item	2479665	et	3	main
kuni	doc_491521501761_item	2479666	et	3	main
presidendi	doc_491521501761_item	2479678	et	4	main
vaheline	doc_491521501761_item	2479689	et	4	main
ribbendropi	doc_491521501761_item	2479693	et	4	main
vene	doc_491521501761_item	2479703	et	4	main
alla	doc_491521501761_item	2479706	et	3	main
ja	doc_491521501761_item	2479707	et	3	main
balti	doc_491521501761_item	2479708	et	3	main
riikidesse	doc_491521501761_item	2479709	et	3	main
marssisid	doc_491521501761_item	2479710	et	4	main
sisse	doc_491521501761_item	2479711	et	4	main
vene	doc_491521501761_item	2479712	et	4	main
väed	doc_491521501761_item	2479713	et	3	main
algas	doc_491521501761_item	2479714	et	3	main
raske	doc_491521501761_item	2479715	et	4	main
vene	doc_491521501761_item	2479716	et	4	main
okupatsiooni	doc_491521501761_item	2479717	et	4	main
aeg	doc_491521501761_item	2479718	et	3	main
1septembril	doc_491521501761_item	2479719	et	3	main
1939	doc_491521501761_item	2479720	et	2	main
algas	doc_491521501761_item	2479722	et	3	main
ii	doc_491521501761_item	2479723	et	4	main
vene	doc_491521501761_item	2479725	et	4	main
ja	doc_491521501761_item	2479726	et	3	main
loomavagunites	doc_491521501761_item	2479739	et	3	main
anti	doc_491521501761_item	2479745	et	3	main
asjade	doc_491521501761_item	2479746	et	3	main
minema	doc_491521501761_item	2479760	et	3	main
alanud	doc_491521501761_item	2479761	et	4	main
poolel	doc_491521501761_item	2479770	et	4	main
tulemusena	doc_491521501761_item	2479772	et	3	main
venna	doc_491521501761_item	2479777	et	3	main
peale	doc_491521501761_item	2479779	et	4	main
lõppemist	doc_491521501761_item	2479781	et	4	main
vabariik	doc_491521501761_item	2479825	et	3	main
pööre	doc_491521501761_item	2479835	et	4	main
kui	doc_491521501761_item	2479838	et	3	main
kompartei	doc_491521501761_item	2479839	et	4	main
sõltuvatel	doc_491521501761_item	2479852	et	4	main
hakata	doc_491521501761_item	2479854	et	4	main
viima	doc_491521501761_item	2479856	et	3	main
ajakirjanduses	doc_491521501761_item	2479861	et	3	main
hakkasid	doc_491521501761_item	2479862	et	4	main
ilmuma	doc_491521501761_item	2479863	et	3	main
esimesed	doc_491521501761_item	2479864	et	3	main
tõed	doc_491521501761_item	2479865	et	4	main
eesti	doc_491521501761_item	2479868	et	4	main
selts	doc_491521501761_item	2479870	et	3	main
vastu	doc_491521501761_item	2479899	et	3	main
enda	doc_491521501761_item	2479901	et	4	main
2008	doc_491521501761_item	2479909	et	2	main
seega	doc_491521501761_item	2479928	et	4	main
või	doc_491521501761_item	2479936	et	4	main
riigi	doc_491521501761_item	2479938	et	3	main
sõjavägi	doc_491521501761_item	2479628	et	3	main
sõlmiti	doc_491521501761_item	2479630	et	3	main
välja	doc_491521501761_item	2479637	et	4	main
24021918	doc_491521501761_item	2479638	et	2	main
aastal	doc_491521501761_item	2479639	et	3	main
kusjuures	doc_491521501761_item	2479640	et	3	main
ette	doc_491521501761_item	2479644	et	4	main
pärnus	doc_491521501761_item	2479647	et	3	main
maa	doc_491521501761_item	2479657	et	4	main
vabadusvõitlejatele	doc_491521501761_item	2479660	et	3	main
konstantin	doc_491521501761_item	2479667	et	4	main
valimiseni	doc_491521501761_item	2479669	et	4	main
siis	doc_491521501761_item	2479670	et	3	main
toimus	doc_491521501761_item	2479671	et	3	main
kaugenemine	doc_491521501761_item	2479674	et	4	main
võim	doc_491521501761_item	2479676	et	3	main
saksa	doc_491521501761_item	2479685	et	4	main
vene	doc_491521501761_item	2479687	et	4	main
riikide	doc_491521501761_item	2479688	et	3	main
nn	doc_491521501761_item	2479691	et	4	main
riigi	doc_491521501761_item	2479704	et	3	main
tegid	doc_491521501761_item	2479729	et	4	main
veeti	doc_491521501761_item	2479738	et	3	main
eestlasi	doc_491521501761_item	2479743	et	3	main
neile	doc_491521501761_item	2479744	et	4	main
tundi	doc_491521501761_item	2479749	et	4	main
ning	doc_491521501761_item	2479751	et	3	main
maha	doc_491521501761_item	2479756	et	4	main
jätma	doc_491521501761_item	2479757	et	3	main
ja	doc_491521501761_item	2479758	et	3	main
venemaale	doc_491521501761_item	2479759	et	4	main
ühed	doc_491521501761_item	2479767	et	3	main
venelaste	doc_491521501761_item	2479769	et	4	main
mille	doc_491521501761_item	2479771	et	3	main
vahel	doc_491521501761_item	2479774	et	4	main
venelaste	doc_491521501761_item	2479785	et	4	main
võiduga	doc_491521501761_item	2479786	et	4	main
oli	doc_491521501761_item	2479821	et	3	main
kus	doc_491521501761_item	2479826	et	3	main
jäetud	doc_491521501761_item	2479830	et	4	main
väike	doc_491521501761_item	2479832	et	4	main
osatähtsus	doc_491521501761_item	2479833	et	4	main
suur	doc_491521501761_item	2479834	et	3	main
eesotsa	doc_491521501761_item	2479840	et	4	main
gorbatšov	doc_491521501761_item	2479844	et	2	main
vabam	doc_491521501761_item	2479849	et	4	main
lasi	doc_491521501761_item	2479851	et	4	main
ellu	doc_491521501761_item	2479855	et	4	main
ajaloost	doc_491521501761_item	2479866	et	4	main
raadio	doc_491521501761_item	2479871	et	4	main
eestimaal	doc_491521501761_item	2479897	et	4	main
kõrgemad	doc_491521501761_item	2479905	et	4	main
eesti	doc_491521501761_item	2479911	et	4	main
eesti	doc_491521501761_item	2479916	et	4	main
riigi	doc_491521501761_item	2479924	et	3	main
oli	doc_491521501761_item	2479927	et	3	main
riik	doc_491521501761_item	2479930	et	3	main
mille	doc_491521501761_item	2479947	et	3	main
valib	doc_491521501761_item	2479954	et	3	main
oma	doc_491521501761_item	2479955	et	4	main
esindusorganiks	doc_491521501761_item	2479956	et	3	main
riigikogu	doc_491521501761_item	2479957	et	4	main
liikmeline	doc_491521501761_item	2479961	et	4	main
on	doc_491521501761_item	2479963	et	4	main
eelduseks	doc_491521501761_item	2479972	et	4	main
astumise	doc_491521501761_item	2479974	et	4	main
nato	doc_491521501761_item	2479978	et	4	main
eesti	doc_491521501761_item	2479981	et	4	main
on	doc_491521501761_item	2479983	et	4	main
ainuõige	doc_491521501761_item	2479985	et	4	main
et	doc_491521501761_item	2479993	et	3	main
olemas	doc_491521501761_item	2480001	et	4	main
majandus	doc_491521501761_item	2480005	et	4	main
et	doc_491521501761_item	2480008	et	3	main
et	doc_491521501761_item	2480016	et	3	main
laiskusest	doc_491521501761_item	2480043	et	4	main
õppida	doc_491521501761_item	2480047	et	3	main
viitsi	doc_491521501761_item	2480056	et	4	main
levib	doc_491521501761_item	2480064	et	3	main
selleks	doc_491521501761_item	2480067	et	4	main
luua	doc_491521501761_item	2480077	et	4	main
rõdult	doc_491521501761_item	2479650	et	3	main
eesti	doc_491521501761_item	2479653	et	4	main
aeg	doc_491521501761_item	2479656	et	3	main
riigi	doc_491521501761_item	2479661	et	3	main
presidendiks	doc_491521501761_item	2479673	et	4	main
koondus	doc_491521501761_item	2479677	et	4	main
kätte	doc_491521501761_item	2479679	et	4	main
lõpptulemusena	doc_491521501761_item	2479680	et	3	main
kirjutati	doc_491521501761_item	2479681	et	3	main
õnnetuseks	doc_491521501761_item	2479682	et	4	main
alla	doc_491521501761_item	2479683	et	3	main
23081939	doc_491521501761_item	2479684	et	2	main
mille	doc_491521501761_item	2479695	et	3	main
balti	doc_491521501761_item	2479697	et	3	main
maailmasõda	doc_491521501761_item	2479724	et	4	main
sõja	doc_491521501761_item	2479733	et	3	main
küüditati	doc_491521501761_item	2479736	et	3	main
st	doc_491521501761_item	2479737	et	3	main
venemaale	doc_491521501761_item	2479740	et	4	main
väga	doc_491521501761_item	2479741	et	3	main
paljusid	doc_491521501761_item	2479742	et	3	main
pidid	doc_491521501761_item	2479752	et	4	main
oma	doc_491521501761_item	2479754	et	4	main
jaotas	doc_491521501761_item	2479763	et	3	main
sõdisid	doc_491521501761_item	2479768	et	4	main
ka	doc_491521501761_item	2479775	et	3	main
vastu	doc_491521501761_item	2479778	et	3	main
mis	doc_491521501761_item	2479782	et	4	main
teatavasti	doc_491521501761_item	2479783	et	3	main
lõppes	doc_491521501761_item	2479784	et	4	main
pool	doc_491521501761_item	2479788	et	4	main
euroopat	doc_491521501761_item	2479789	et	3	main
vene	doc_491521501761_item	2479790	et	4	main
riigi	doc_491521501761_item	2479791	et	3	main
võimu	doc_491521501761_item	2479792	et	4	main
alla	doc_491521501761_item	2479793	et	3	main
kõige	doc_491521501761_item	2479794	et	4	main
raskem	doc_491521501761_item	2479795	et	4	main
aeg	doc_491521501761_item	2479796	et	3	main
saabus	doc_491521501761_item	2479797	et	3	main
eesti	doc_491521501761_item	2479798	et	4	main
riiki	doc_491521501761_item	2479799	et	4	main
1978	doc_491521501761_item	2479800	et	2	main
aastal	doc_491521501761_item	2479801	et	3	main
kui	doc_491521501761_item	2479802	et	3	main
nõukogude	doc_491521501761_item	2479803	et	3	main
liidu	doc_491521501761_item	2479804	et	3	main
kommunistlik	doc_491521501761_item	2479805	et	3	main
partei	doc_491521501761_item	2479806	et	4	main
saatis	doc_491521501761_item	2479807	et	3	main
eestimaa	doc_491521501761_item	2479808	et	4	main
parteid	doc_491521501761_item	2479810	et	4	main
kommunistlikku	doc_491521501761_item	2479809	et	4	main
juhtima	doc_491521501761_item	2479811	et	4	main
karl	doc_491521501761_item	2479812	et	4	main
vaino	doc_491521501761_item	2479813	et	4	main
siis	doc_491521501761_item	2479814	et	3	main
toimus	doc_491521501761_item	2479815	et	3	main
järsk	doc_491521501761_item	2479816	et	3	main
venestuspoliitika	doc_491521501761_item	2479817	et	4	main
kasv	doc_491521501761_item	2479818	et	3	main
riik	doc_491521501761_item	2479820	et	3	main
eesti	doc_491521501761_item	2479819	et	4	main
kahekeelne	doc_491521501761_item	2479823	et	3	main
keelele	doc_491521501761_item	2479828	et	4	main
oli	doc_491521501761_item	2479829	et	3	main
väga	doc_491521501761_item	2479831	et	3	main
venemaal	doc_491521501761_item	2479845	et	4	main
algas	doc_491521501761_item	2479846	et	3	main
uus	doc_491521501761_item	2479847	et	3	main
riigikord	doc_491521501761_item	2479850	et	3	main
kui	doc_491521501761_item	2479906	et	3	main
vene	doc_491521501761_item	2479907	et	4	main
seadused	doc_491521501761_item	2479908	et	3	main
kõrgeim	doc_491521501761_item	2479912	et	4	main
võimu	doc_491521501761_item	2479913	et	4	main
eesti	doc_491521501761_item	2479923	et	4	main
loodud	doc_491521501761_item	2479931	et	4	main
eesti	doc_491521501761_item	2479942	et	4	main
riik	doc_491521501761_item	2479943	et	3	main
rahvas	doc_491521501761_item	2479952	et	4	main
mis	doc_491521501761_item	2479958	et	4	main
eesti	doc_491521501761_item	2479968	et	4	main
on	doc_491521501761_item	2479969	et	4	main
seadnud	doc_491521501761_item	2479973	et	4	main
ja	doc_491521501761_item	2479977	et	3	main
edasine	doc_491521501761_item	2479988	et	4	main
oleks	doc_491521501761_item	2479990	et	3	main
vajalik	doc_491521501761_item	2480000	et	3	main
oleksid	doc_491521501761_item	2480011	et	4	main
suuremad	doc_491521501761_item	2480012	et	4	main
kui	doc_491521501761_item	2480013	et	3	main
kõik	doc_491521501761_item	2480017	et	4	main
ole	doc_491521501761_item	2480023	et	4	main
veel	doc_491521501761_item	2480027	et	4	main
kõige	doc_491521501761_item	2480031	et	4	main
kannatab	doc_491521501761_item	2480033	et	3	main
suurenenud	doc_491521501761_item	2480038	et	4	main
töötute	doc_491521501761_item	2480040	et	4	main
ole	doc_491521501761_item	2480045	et	4	main
ja	doc_491521501761_item	2480062	et	3	main
aids	doc_491521501761_item	2480063	et	4	main
meeletul	doc_491521501761_item	2480065	et	4	main
kuhugi	doc_491521501761_item	2480069	et	4	main
osata	doc_491521501761_item	2480072	et	4	main
millestki	doc_491521501761_item	2480073	et	4	main
noorest	doc_491521501761_item	2480080	et	3	main
romaani	doc_491521501762_item	2480115	et	4	main
koha	doc_491521501762_item	2480123	et	4	main
ning	doc_491521501762_item	2480126	et	3	main
annab	doc_491521501762_item	2480128	et	3	main
ning	doc_491521501762_item	2480130	et	3	main
oma	doc_491521501762_item	2480144	et	4	main
riigi	doc_491521501762_item	2480145	et	3	main
iseseisvuse	doc_491521501762_item	2480146	et	4	main
kivikas	doc_491521501762_item	2480151	et	4	main
tema	doc_491521501762_item	2480160	et	4	main
olustvere	doc_491521501762_item	2480163	et	4	main
mõisas	doc_491521501762_item	2480164	et	3	main
tema	doc_491521501762_item	2480177	et	4	main
käia	doc_491521501762_item	2480185	et	4	main
ja	doc_491521501762_item	2480191	et	3	main
liikus	doc_491521501762_item	2480193	et	3	main
võitlusse	doc_491521501762_item	2480221	et	3	main
kaitstes	doc_491521501762_item	2480224	et	3	main
ja	doc_491521501762_item	2480227	et	3	main
kui	doc_491521501762_item	2480229	et	3	main
peategelane	doc_491521501762_item	2480244	et	3	main
henn	doc_491521501762_item	2480245	et	4	main
kõige	doc_491521501762_item	2480249	et	4	main
jaoks	doc_491521501762_item	2480253	et	4	main
meeldis	doc_491521501762_item	2480256	et	3	main
marmortahvlil	doc_491521501762_item	2480259	et	3	main
räägib	doc_491521501762_item	2480262	et	3	main
kaheksast	doc_491521501762_item	2480263	et	4	main
koolipoisist	doc_491521501762_item	2480264	et	3	main
ühel	doc_491521501762_item	2480269	et	3	main
ja	doc_491521501762_item	2480274	et	3	main
nende	doc_491521501762_item	2480284	et	4	main
ja	doc_491521501762_item	2480291	et	3	main
jooksid	doc_491521501762_item	2480293	et	4	main
ära	doc_491521501762_item	2480294	et	4	main
olid	doc_491521501762_item	2480297	et	4	main
vapralt	doc_491521501762_item	2480303	et	4	main
nõukogude	doc_491521501761_item	2479824	et	3	main
toimus	doc_491521501761_item	2479836	et	3	main
1985a	doc_491521501761_item	2479837	et	4	main
noor	doc_491521501761_item	2479843	et	3	main
ajajärk	doc_491521501761_item	2479848	et	3	main
vabariikidel	doc_491521501761_item	2479853	et	3	main
aktiviseerus	doc_491521501761_item	2479867	et	3	main
televisiooni	doc_491521501761_item	2479872	et	4	main
eetrisse	doc_491521501761_item	2479873	et	3	main
hakkasid	doc_491521501761_item	2479874	et	4	main
jõudma	doc_491521501761_item	2479875	et	3	main
mitmed	doc_491521501761_item	2479876	et	4	main
avalikud	doc_491521501761_item	2479877	et	3	main
mõttevahetused	doc_491521501761_item	2479878	et	4	main
väga	doc_491521501761_item	2479879	et	3	main
populaarseks	doc_491521501761_item	2479880	et	4	main
muutusid	doc_491521501761_item	2479881	et	4	main
tartu	doc_491521501761_item	2479882	et	4	main
muusikapäevad	doc_491521501761_item	2479883	et	3	main
tallinnas	doc_491521501761_item	2479884	et	4	main
vanalinnapäevad	doc_491521501761_item	2479885	et	3	main
suuri	doc_491521501761_item	2479886	et	3	main
rahvamasse	doc_491521501761_item	2479887	et	3	main
haarasid	doc_491521501761_item	2479888	et	4	main
juunikuised	doc_491521501761_item	2479889	et	4	main
öölaulupeod	doc_491521501761_item	2479890	et	4	main
lauluväljakul	doc_491521501761_item	2479891	et	3	main
16novembril	doc_491521501761_item	2479892	et	3	main
otsustas	doc_491521501761_item	2479893	et	3	main
kohalik	doc_491521501761_item	2479894	et	3	main
võim	doc_491521501761_item	2479895	et	3	main
on	doc_491521501761_item	2479904	et	4	main
riiki	doc_491521501761_item	2479921	et	4	main
jätkuks	doc_491521501761_item	2479925	et	4	main
eesti	doc_491521501761_item	2479929	et	4	main
tuli	doc_491521501761_item	2479933	et	4	main
hakata	doc_491521501761_item	2479934	et	4	main
on	doc_491521501761_item	2479944	et	4	main
võimu	doc_491521501761_item	2479949	et	4	main
on	doc_491521501761_item	2479959	et	4	main
eestil	doc_491521501761_item	2479962	et	3	main
oma	doc_491521501761_item	2479970	et	4	main
eksisteerimise	doc_491521501761_item	2479971	et	4	main
euroopa	doc_491521501761_item	2479975	et	4	main
sõjalistesse	doc_491521501761_item	2479979	et	4	main
valinud	doc_491521501761_item	2479984	et	4	main
tee	doc_491521501761_item	2479986	et	4	main
et	doc_491521501761_item	2479987	et	3	main
kõik	doc_491521501761_item	2479998	et	4	main
eluks	doc_491521501761_item	2479999	et	3	main
selleks	doc_491521501761_item	2480015	et	4	main
saaksid	doc_491521501761_item	2480019	et	4	main
endise	doc_491521501761_item	2479922	et	3	main
faktiliselt	doc_491521501761_item	2479926	et	4	main
nüüd	doc_491521501761_item	2479932	et	4	main
looma	doc_491521501761_item	2479935	et	4	main
taastama	doc_491521501761_item	2479937	et	3	main
vajalikku	doc_491521501761_item	2479940	et	4	main
seadusandlust	doc_491521501761_item	2479941	et	3	main
riik	doc_491521501761_item	2479946	et	3	main
kõrgemaiks	doc_491521501761_item	2479948	et	4	main
kandjaks	doc_491521501761_item	2479950	et	4	main
on	doc_491521501761_item	2479951	et	4	main
101	doc_491521501761_item	2479960	et	2	main
oma	doc_491521501761_item	2479964	et	4	main
kohtu-	doc_491521501761_item	2479965	et	4	main
valitsemisorganid	doc_491521501761_item	2479967	et	3	main
liitu	doc_491521501761_item	2479976	et	4	main
struktuuridesse	doc_491521501761_item	2479980	et	3	main
riik	doc_491521501761_item	2479982	et	3	main
eksisteerimine	doc_491521501761_item	2479989	et	4	main
selleks	doc_491521501761_item	2479992	et	4	main
korda	doc_491521501761_item	2480003	et	4	main
tähendab	doc_491521501761_item	2480007	et	3	main
tulud	doc_491521501761_item	2480010	et	3	main
eluvaldkonnad	doc_491521501761_item	2480018	et	4	main
normaalselt	doc_491521501761_item	2480020	et	4	main
ei	doc_491521501761_item	2480022	et	4	main
eesti	doc_491521501761_item	2480024	et	4	main
riigis	doc_491521501761_item	2480025	et	3	main
paraku	doc_491521501761_item	2480026	et	3	main
tugevat	doc_491521501761_item	2480029	et	4	main
käesoleval	doc_491521501761_item	2480034	et	3	main
inimene	doc_491521501761_item	2480050	et	3	main
loomult	doc_491521501761_item	2480052	et	3	main
laisk	doc_491521501761_item	2480053	et	3	main
narkomaania	doc_491521501761_item	2480061	et	4	main
et	doc_491521501761_item	2480068	et	3	main
midagi	doc_491521501761_item	2480071	et	4	main
midagi	doc_491521501761_item	2480076	et	4	main
on	doc_491521501762_item	2480110	et	4	main
emotsionaalne	doc_491521501762_item	2480111	et	3	main
eesti	doc_491521501762_item	2480124	et	4	main
eesti	doc_491521501762_item	2480136	et	4	main
poisid	doc_491521501762_item	2480137	et	4	main
jaanuaril	doc_491521501762_item	2480155	et	3	main
suur-jaani	doc_491521501762_item	2480157	et	4	main
põhja-viljandimaal	doc_491521501762_item	2480159	et	4	main
asuvas	doc_491521501762_item	2480168	et	4	main
moonamajas	doc_491521501762_item	2480170	et	3	main
vanem	doc_491521501762_item	2480178	et	4	main
aitas	doc_491521501762_item	2480180	et	3	main
koolis	doc_491521501762_item	2480184	et	4	main
1917a	doc_491521501762_item	2480187	et	4	main
sõdurid	doc_491521501762_item	2480235	et	3	main
poole	doc_491521501762_item	2480238	et	4	main
sai	doc_491521501762_item	2480242	et	4	main
olid	doc_491521501762_item	2480266	et	4	main
eesti	doc_491521501762_item	2480273	et	4	main
maad	doc_491521501762_item	2480280	et	4	main
esimene	doc_491521501762_item	2480281	et	3	main
lahing	doc_491521501762_item	2480282	et	3	main
oli	doc_491521501762_item	2480283	et	3	main
sest	doc_491521501762_item	2480287	et	4	main
lihtsalt	doc_491521501762_item	2480292	et	4	main
teised	doc_491521501762_item	2480295	et	4	main
nad	doc_491521501762_item	2480301	et	3	main
ka	doc_491521501762_item	2480314	et	3	main
punaarmeenlased	doc_491521501762_item	2480321	et	3	main
ellu	doc_491521501762_item	2480323	et	4	main
nägi	doc_491521501762_item	2480329	et	3	main
oma	doc_491521501762_item	2480332	et	4	main
läks	doc_491521501762_item	2480344	et	3	main
reaalsuse	doc_491521501762_item	2480348	et	4	main
teise	doc_491521501762_item	2480361	et	4	main
jääb	doc_491521501762_item	2480372	et	3	main
lahingud	doc_491521501762_item	2480375	et	3	main
jõuavad	doc_491521501762_item	2480378	et	4	main
liitub	doc_491521501762_item	2480388	et	3	main
boheemkonnaga	doc_491521501762_item	2480389	et	3	main
temast	doc_491521501762_item	2480391	et	3	main
peamiselt	doc_491521501762_item	2480407	et	4	main
eksisteerimiseks	doc_491521501761_item	2479939	et	4	main
demokraatlik	doc_491521501761_item	2479945	et	3	main
kes	doc_491521501761_item	2479953	et	4	main
ja	doc_491521501761_item	2479966	et	3	main
võimalik	doc_491521501761_item	2479991	et	3	main
kõigil	doc_491521501761_item	2479994	et	4	main
eesti	doc_491521501761_item	2479995	et	4	main
kodanikel	doc_491521501761_item	2479996	et	3	main
oleks	doc_491521501761_item	2479997	et	3	main
tuleb	doc_491521501761_item	2480002	et	3	main
seada	doc_491521501761_item	2480004	et	3	main
see	doc_491521501761_item	2480006	et	3	main
riigi	doc_491521501761_item	2480009	et	3	main
kulud	doc_491521501761_item	2480014	et	4	main
eksisteerida	doc_491521501761_item	2480021	et	3	main
majandust	doc_491521501761_item	2480030	et	4	main
sotsiaalsfäär	doc_491521501761_item	2480037	et	3	main
on	doc_491521501761_item	2480039	et	4	main
armee	doc_491521501761_item	2480041	et	4	main
kes	doc_491521501761_item	2480042	et	4	main
ei	doc_491521501761_item	2480044	et	4	main
eriala	doc_491521501761_item	2480049	et	4	main
ennast	doc_491521501761_item	2480057	et	4	main
liiguta	doc_491521501761_item	2480058	et	4	main
kuritegevus	doc_491521501761_item	2480059	et	4	main
kiirusel	doc_491521501761_item	2480066	et	4	main
albert	doc_491521501762_item	2480113	et	4	main
ainetel	doc_491521501762_item	2480116	et	3	main
tänaseks	doc_491521501762_item	2480118	et	4	main
on	doc_491521501762_item	2480119	et	4	main
sisse	doc_491521501762_item	2480121	et	4	main
kirjandusklassikas	doc_491521501762_item	2480125	et	3	main
kaasakiskuva	doc_491521501762_item	2480131	et	3	main
ajast	doc_491521501762_item	2480133	et	4	main
mil	doc_491521501762_item	2480134	et	4	main
paljud	doc_491521501762_item	2480135	et	3	main
haarasid	doc_491521501762_item	2480142	et	4	main
ja	doc_491521501762_item	2480143	et	3	main
albert	doc_491521501762_item	2480150	et	4	main
18	doc_491521501762_item	2480154	et	2	main
alevis	doc_491521501762_item	2480158	et	3	main
lapsepõlv	doc_491521501762_item	2480161	et	3	main
ja	doc_491521501762_item	2480165	et	3	main
sännu	doc_491521501762_item	2480169	et	4	main
teda	doc_491521501762_item	2480181	et	4	main
nimed	doc_491521501762_item	2480196	et	3	main
koolinoored	doc_491521501762_item	2480223	et	3	main
oma	doc_491521501762_item	2480225	et	4	main
sattusid	doc_491521501762_item	2480231	et	4	main
punaarmeenlased	doc_491521501762_item	2480232	et	3	main
siis	doc_491521501762_item	2480233	et	3	main
ahas	doc_491521501762_item	2480246	et	4	main
see	doc_491521501762_item	2480247	et	3	main
lahing	doc_491521501762_item	2480251	et	3	main
kes	doc_491521501762_item	2480265	et	4	main
päeval	doc_491521501762_item	2480270	et	3	main
valutasid	doc_491521501762_item	2480272	et	4	main
otsustasid	doc_491521501762_item	2480276	et	4	main
raske	doc_491521501762_item	2480286	et	4	main
kartma	doc_491521501762_item	2480290	et	3	main
ka	doc_491521501762_item	2480298	et	3	main
rasked	doc_491521501762_item	2480299	et	3	main
jäid	doc_491521501762_item	2480307	et	4	main
seas	doc_491521501762_item	2480313	et	4	main
arenenud	doc_491521501761_item	2480028	et	4	main
rohkem	doc_491521501761_item	2480032	et	4	main
ajal	doc_491521501761_item	2480035	et	4	main
madalapalgaline	doc_491521501761_item	2480036	et	4	main
viitsinud	doc_491521501761_item	2480046	et	4	main
uut	doc_491521501761_item	2480048	et	3	main
on	doc_491521501761_item	2480051	et	4	main
kes	doc_491521501761_item	2480054	et	4	main
ei	doc_491521501761_item	2480055	et	4	main
lokkab	doc_491521501761_item	2480060	et	3	main
jõuda	doc_491521501761_item	2480070	et	3	main
aru	doc_491521501761_item	2480074	et	4	main
saada	doc_491521501761_item	2480075	et	4	main
peast	doc_491521501761_item	2480081	et	4	main
koolis	doc_491521501761_item	2480082	et	4	main
hoolega	doc_491521501761_item	2480083	et	3	main
õppida	doc_491521501761_item	2480084	et	3	main
õpitust	doc_491521501761_item	2480085	et	4	main
aru	doc_491521501761_item	2480086	et	4	main
saada	doc_491521501761_item	2480087	et	4	main
ja	doc_491521501761_item	2480088	et	3	main
saadud	doc_491521501761_item	2480089	et	4	main
teadmisi	doc_491521501761_item	2480090	et	4	main
praktikas	doc_491521501761_item	2480091	et	3	main
ellu	doc_491521501761_item	2480092	et	4	main
viia	doc_491521501761_item	2480093	et	3	main
kes	doc_491521501761_item	2480094	et	4	main
sellega	doc_491521501761_item	2480095	et	3	main
edukamalt	doc_491521501761_item	2480096	et	4	main
hakkama	doc_491521501761_item	2480097	et	3	main
saab	doc_491521501761_item	2480098	et	3	main
see	doc_491521501761_item	2480099	et	3	main
seda	doc_491521501761_item	2480100	et	3	main
kõrgemale	doc_491521501761_item	2480101	et	4	main
astmele	doc_491521501761_item	2480103	et	3	main
jõuab	doc_491521501761_item	2480104	et	3	main
essee	doc_491521501762_item	2480105	et	4	main
nimed	doc_491521501762_item	2480106	et	3	main
marmortahvlil	doc_491521501762_item	2480107	et	3	main
nimed	doc_491521501762_item	2480108	et	3	main
marmortahvlil	doc_491521501762_item	2480109	et	3	main
ühiskonna	doc_491521501761_item	2480102	et	4	main
tuleb	doc_491521501761_item	2480078	et	3	main
juba	doc_491521501761_item	2480079	et	3	main
sõjadraama	doc_491521501762_item	2480112	et	4	main
mis	doc_491521501762_item	2480117	et	4	main
võtnud	doc_491521501762_item	2480120	et	4	main
kivikase	doc_491521501762_item	2480114	et	3	main
pildi	doc_491521501762_item	2480132	et	4	main
tõusid	doc_491521501762_item	2480140	et	4	main
relvad	doc_491521501762_item	2480141	et	3	main
astusid	doc_491521501762_item	2480149	et	4	main
on	doc_491521501762_item	2480152	et	4	main
mõõdus	doc_491521501762_item	2480162	et	3	main
selle	doc_491521501762_item	2480166	et	4	main
vend	doc_491521501762_item	2480179	et	3	main
palgast	doc_491521501762_item	2480183	et	4	main
sai	doc_491521501762_item	2480188	et	4	main
temast	doc_491521501762_item	2480189	et	3	main
ta	doc_491521501762_item	2480192	et	4	main
ka	doc_491521501762_item	2480222	et	3	main
maad	doc_491521501762_item	2480226	et	4	main
aateid	doc_491521501762_item	2480228	et	3	main
tartusse	doc_491521501762_item	2480230	et	3	main
taganesid	doc_491521501762_item	2480236	et	4	main
viljandi	doc_491521501762_item	2480237	et	4	main
külmal	doc_491521501762_item	2480239	et	3	main
jaanuaril	doc_491521501762_item	2480240	et	3	main
1919a	doc_491521501762_item	2480241	et	4	main
oli	doc_491521501762_item	2480248	et	3	main
mulle	doc_491521501762_item	2480254	et	4	main
film	doc_491521501762_item	2480257	et	3	main
nimed	doc_491521501762_item	2480258	et	3	main
film	doc_491521501762_item	2480261	et	3	main
sõbrad	doc_491521501762_item	2480268	et	3	main
punaarmeenlased	doc_491521501762_item	2480271	et	3	main
nad	doc_491521501762_item	2480288	et	3	main
aga	doc_491521501762_item	2480300	et	3	main
võitlesid	doc_491521501762_item	2480302	et	4	main
kodumaa	doc_491521501762_item	2480304	et	4	main
kolm	doc_491521501762_item	2480310	et	3	main
sõpra	doc_491521501762_item	2480311	et	4	main
ainult	doc_491521501762_item	2480325	et	4	main
kui	doc_491521501762_item	2480327	et	3	main
punaarmeenlaste	doc_491521501762_item	2480330	et	3	main
tema	doc_491521501762_item	2480339	et	4	main
vend	doc_491521501762_item	2480340	et	3	main
pettis	doc_491521501762_item	2480341	et	3	main
eestit	doc_491521501762_item	2480342	et	3	main
ja	doc_491521501762_item	2480343	et	3	main
ja	doc_491521501762_item	2480354	et	3	main
marta	doc_491521501762_item	2480355	et	4	main
1948a	doc_491521501762_item	2480359	et	4	main
sõda	doc_491521501762_item	2480377	et	4	main
lugejani	doc_491521501762_item	2480379	et	4	main
ahase	doc_491521501762_item	2480380	et	4	main
sõprade	doc_491521501762_item	2480381	et	3	main
kirjade	doc_491521501762_item	2480382	et	3	main
kaudu	doc_491521501762_item	2480383	et	3	main
langenute	doc_491521501762_item	2480384	et	4	main
ahase	doc_491521501762_item	2480394	et	4	main
tegutsevas	doc_491521501762_item	2480396	et	4	main
rühmituses	doc_491521501762_item	2480398	et	4	main
raske	doc_491521501762_item	2480400	et	4	main
teine	doc_491521501762_item	2480404	et	3	main
kõide	doc_491521501762_item	2480405	et	4	main
film	doc_491521501762_item	2480429	et	3	main
sest	doc_491521501762_item	2480433	et	4	main
film	doc_491521501762_item	2480435	et	3	main
nende	doc_491521501762_item	2480441	et	4	main
oma	doc_491521501762_item	2480451	et	4	main
lähedaste	doc_491521501762_item	2480452	et	3	main
vastu	doc_491521501762_item	2480453	et	3	main
essee	doc_491521501763_item	2480454	et	4	main
see	doc_491521501763_item	2480455	et	3	main
oli	doc_491521501763_item	2480456	et	3	main
ma	doc_491521501763_item	2480473	et	3	main
ta	doc_491521501763_item	2480504	et	4	main
ohvitser	doc_491521501763_item	2480510	et	3	main
vabandab	doc_491521501763_item	2480512	et	3	main
ära	doc_491521501763_item	2480515	et	4	main
kõik	doc_491521501763_item	2480516	et	4	main
teavad	doc_491521501763_item	2480517	et	3	main
et	doc_491521501763_item	2480518	et	3	main
professor	doc_491521501763_item	2480519	et	3	main
apolitiline	doc_491521501763_item	2480521	et	4	main
professor	doc_491521501763_item	2480523	et	3	main
poliitikast	doc_491521501763_item	2480527	et	4	main
reeglid	doc_491521501763_item	2480532	et	3	main
kindla	doc_491521501762_item	2480122	et	3	main
mis	doc_491521501762_item	2480127	et	4	main
tõetruu	doc_491521501762_item	2480129	et	4	main
otse	doc_491521501762_item	2480138	et	4	main
koolipingist	doc_491521501762_item	2480139	et	3	main
eest	doc_491521501762_item	2480147	et	4	main
võitlusse	doc_491521501762_item	2480148	et	3	main
sündinud	doc_491521501762_item	2480153	et	4	main
1898a	doc_491521501762_item	2480156	et	4	main
lähedal	doc_491521501762_item	2480167	et	4	main
tema	doc_491521501762_item	2480171	et	4	main
ema	doc_491521501762_item	2480172	et	4	main
tõõtas	doc_491521501762_item	2480173	et	4	main
teenijana	doc_491521501762_item	2480174	et	4	main
ja	doc_491521501762_item	2480175	et	3	main
kongruna	doc_491521501762_item	2480176	et	4	main
oma	doc_491521501762_item	2480182	et	4	main
kuid	doc_491521501762_item	2480186	et	4	main
punaarmeenlane	doc_491521501762_item	2480190	et	3	main
venemaale	doc_491521501762_item	2480194	et	4	main
romaanis	doc_491521501762_item	2480195	et	3	main
marmortahvlil	doc_491521501762_item	2480197	et	3	main
kirjanik	doc_491521501762_item	2480198	et	3	main
oli	doc_491521501762_item	2480199	et	3	main
ennast	doc_491521501762_item	2480200	et	4	main
kujutanud	doc_491521501762_item	2480201	et	4	main
henn	doc_491521501762_item	2480202	et	4	main
ahase	doc_491521501762_item	2480203	et	4	main
nime	doc_491521501762_item	2480204	et	4	main
all	doc_491521501762_item	2480205	et	3	main
aasta	doc_491521501762_item	2480206	et	4	main
1918a	doc_491521501762_item	2480207	et	4	main
euroopa	doc_491521501762_item	2480208	et	4	main
kaardile	doc_491521501762_item	2480209	et	3	main
on	doc_491521501762_item	2480210	et	4	main
sündinud	doc_491521501762_item	2480211	et	4	main
uus	doc_491521501762_item	2480212	et	3	main
riik	doc_491521501762_item	2480213	et	3	main
eesti	doc_491521501762_item	2480214	et	4	main
vabariik	doc_491521501762_item	2480215	et	3	main
sõdurite	doc_491521501762_item	2480216	et	3	main
kõrval	doc_491521501762_item	2480217	et	4	main
asuvad	doc_491521501762_item	2480218	et	4	main
selle	doc_491521501762_item	2480219	et	4	main
nimel	doc_491521501762_item	2480220	et	3	main
eesti	doc_491521501762_item	2480234	et	4	main
haavata	doc_491521501762_item	2480243	et	4	main
raskem	doc_491521501762_item	2480250	et	4	main
noorte	doc_491521501762_item	2480252	et	3	main
väga	doc_491521501762_item	2480255	et	3	main
see	doc_491521501762_item	2480260	et	3	main
omavahel	doc_491521501762_item	2480267	et	3	main
koolipoisid	doc_491521501762_item	2480275	et	4	main
minna	doc_491521501762_item	2480277	et	3	main
kaitsma	doc_491521501762_item	2480278	et	3	main
oma	doc_491521501762_item	2480279	et	4	main
jaoks	doc_491521501762_item	2480285	et	4	main
lõid	doc_491521501762_item	2480289	et	4	main
lahingud	doc_491521501762_item	2480296	et	3	main
ellu	doc_491521501762_item	2480308	et	4	main
ainult	doc_491521501762_item	2480309	et	4	main
peategelane	doc_491521501762_item	2480315	et	3	main
ahas	doc_491521501762_item	2480316	et	4	main
sõites	doc_491521501762_item	2480317	et	3	main
koju	doc_491521501762_item	2480318	et	3	main
neid	doc_491521501762_item	2480319	et	4	main
ründasid	doc_491521501762_item	2480320	et	4	main
jäi	doc_491521501762_item	2480324	et	3	main
ahas	doc_491521501762_item	2480326	et	4	main
seas	doc_491521501762_item	2480331	et	4	main
venda	doc_491521501762_item	2480333	et	4	main
ta	doc_491521501762_item	2480334	et	4	main
oli	doc_491521501762_item	2480335	et	3	main
väga	doc_491521501762_item	2480336	et	3	main
pettunud	doc_491521501762_item	2480337	et	4	main
sest	doc_491521501762_item	2480338	et	4	main
poolele	doc_491521501762_item	2480346	et	4	main
on	doc_491521501762_item	2480350	et	4	main
armulugu	doc_491521501762_item	2480356	et	4	main
järel	doc_491521501762_item	2480371	et	4	main
teenima	doc_491521501762_item	2480374	et	3	main
riitadena	doc_491521501762_item	2480385	et	3	main
ning	doc_491521501762_item	2480390	et	3	main
saab	doc_491521501762_item	2480392	et	3	main
kirjanike	doc_491521501762_item	2480397	et	3	main
ja	doc_491521501762_item	2480410	et	3	main
huvitavaks	doc_491521501762_item	2480416	et	4	main
kuid	doc_491521501762_item	2480417	et	4	main
sündmuste	doc_491521501762_item	2480418	et	3	main
toob	doc_491521501762_item	2480421	et	3	main
paneb	doc_491521501762_item	2480436	et	3	main
tähtis	doc_491521501762_item	2480443	et	4	main
armastus	doc_491521501762_item	2480444	et	4	main
vaba	doc_491521501762_item	2480449	et	4	main
oma	doc_491521501763_item	2480470	et	4	main
kui	doc_491521501763_item	2480497	et	3	main
teada	doc_491521501763_item	2480500	et	3	main
kellega	doc_491521501763_item	2480503	et	3	main
professor	doc_491521501763_item	2480507	et	3	main
siis	doc_491521501763_item	2480509	et	3	main
on	doc_491521501763_item	2480520	et	4	main
rääkida	doc_491521501763_item	2480526	et	3	main
tema	doc_491521501763_item	2480528	et	4	main
ei	doc_491521501763_item	2480534	et	4	main
majast	doc_491521501763_item	2480537	et	4	main
pärast	doc_491521501763_item	2480538	et	4	main
kaheksat	doc_491521501763_item	2480539	et	3	main
teadlasel	doc_491521501763_item	2480540	et	3	main
lydia	doc_491521501763_item	2480543	et	4	main
ja	doc_491521501763_item	2480549	et	3	main
vanem	doc_491521501763_item	2480550	et	4	main
sakslased	doc_491521501763_item	2480555	et	3	main
majast	doc_491521501763_item	2480559	et	4	main
karl	doc_491521501763_item	2480574	et	4	main
aitasid	doc_491521501763_item	2480575	et	4	main
ants	doc_491521501763_item	2480580	et	4	main
lydia	doc_491521501763_item	2480582	et	4	main
armanud	doc_491521501763_item	2480584	et	4	main
ainult	doc_491521501763_item	2480620	et	4	main
ralf	doc_491521501763_item	2480621	et	4	main
teadusega	doc_491521501763_item	2480628	et	3	main
oli	doc_491521501763_item	2480638	et	3	main
eest	doc_491521501762_item	2480305	et	4	main
lõppuks	doc_491521501762_item	2480306	et	3	main
nende	doc_491521501762_item	2480312	et	4	main
ja	doc_491521501762_item	2480322	et	3	main
ta	doc_491521501762_item	2480328	et	4	main
vaenlase	doc_491521501762_item	2480345	et	3	main
karmi	doc_491521501762_item	2480347	et	4	main
taustal	doc_491521501762_item	2480349	et	3	main
liigutav	doc_491521501762_item	2480352	et	4	main
henn	doc_491521501762_item	2480353	et	4	main
marmortahvlil	doc_491521501762_item	2480358	et	3	main
ilmunud	doc_491521501762_item	2480360	et	4	main
osa	doc_491521501762_item	2480362	et	4	main
sündmustele	doc_491521501762_item	2480363	et	3	main
kulgeb	doc_491521501762_item	2480364	et	3	main
vabadussõjaaegades	doc_491521501762_item	2480365	et	3	main
tartus	doc_491521501762_item	2480366	et	3	main
kuhu	doc_491521501762_item	2480367	et	3	main
ahas	doc_491521501762_item	2480368	et	4	main
haavadest	doc_491521501762_item	2480369	et	3	main
staabikirjutajana	doc_491521501762_item	2480373	et	3	main
ta	doc_491521501762_item	2480387	et	4	main
kirjanik	doc_491521501762_item	2480393	et	3	main
pole	doc_491521501762_item	2480399	et	3	main
ära	doc_491521501762_item	2480401	et	4	main
tunda	doc_491521501762_item	2480402	et	3	main
siurut	doc_491521501762_item	2480403	et	4	main
on	doc_491521501762_item	2480406	et	4	main
kultuuri-	doc_491521501762_item	2480409	et	4	main
väga	doc_491521501762_item	2480351	et	3	main
nimed	doc_491521501762_item	2480357	et	3	main
paranemise	doc_491521501762_item	2480370	et	4	main
ja	doc_491521501762_item	2480376	et	3	main
ülikooli	doc_491521501762_item	2480386	et	4	main
vaateväljas	doc_491521501762_item	2480395	et	3	main
1919a	doc_491521501762_item	2480408	et	4	main
kajastus	doc_491521501762_item	2480412	et	4	main
ainestik	doc_491521501762_item	2480413	et	3	main
teeb	doc_491521501762_item	2480414	et	3	main
urooninalik	doc_491521501762_item	2480419	et	4	main
edasiandmine	doc_491521501762_item	2480420	et	3	main
stililise	doc_491521501762_item	2480423	et	4	main
arvan	doc_491521501762_item	2480426	et	3	main
noori	doc_491521501762_item	2480437	et	3	main
on	doc_491521501762_item	2480440	et	4	main
kaheksa	doc_491521501763_item	2480463	et	4	main
ma	doc_491521501763_item	2480464	et	3	main
istun	doc_491521501763_item	2480465	et	3	main
mugavas	doc_491521501763_item	2480466	et	3	main
toolis	doc_491521501763_item	2480467	et	3	main
avaras	doc_491521501763_item	2480468	et	3	main
toas	doc_491521501763_item	2480469	et	3	main
vaid	doc_491521501763_item	2480496	et	3	main
ohvitser	doc_491521501763_item	2480498	et	3	main
saab	doc_491521501763_item	2480499	et	3	main
inimene	doc_491521501763_item	2480502	et	3	main
on	doc_491521501763_item	2480506	et	4	main
miilas	doc_491521501763_item	2480508	et	3	main
kohe	doc_491521501763_item	2480511	et	4	main
läheb	doc_491521501763_item	2480514	et	3	main
ei	doc_491521501763_item	2480524	et	4	main
kodus	doc_491521501763_item	2480529	et	4	main
on	doc_491521501763_item	2480530	et	4	main
on	doc_491521501763_item	2480541	et	4	main
teine	doc_491521501763_item	2480546	et	3	main
eva	doc_491521501763_item	2480548	et	4	main
poeg	doc_491521501763_item	2480551	et	3	main
major	doc_491521501763_item	2480565	et	3	main
on	doc_491521501763_item	2480567	et	4	main
anna	doc_491521501763_item	2480569	et	4	main
poeg	doc_491521501763_item	2480570	et	3	main
tegelikult	doc_491521501763_item	2480571	et	4	main
antsit	doc_491521501763_item	2480576	et	4	main
peita	doc_491521501763_item	2480577	et	3	main
ära	doc_491521501763_item	2480578	et	4	main
tahtis	doc_491521501763_item	2480625	et	3	main
oma	doc_491521501763_item	2480627	et	4	main
ei	doc_491521501763_item	2480629	et	4	main
ta	doc_491521501763_item	2480631	et	4	main
maast	doc_491521501763_item	2480632	et	3	main
põgeneda	doc_491521501763_item	2480633	et	3	main
arvas	doc_491521501763_item	2480634	et	3	main
et	doc_491521501763_item	2480635	et	3	main
kui	doc_491521501763_item	2480636	et	3	main
karl	doc_491521501763_item	2480646	et	4	main
on	doc_491521501763_item	2480647	et	4	main
poolel	doc_491521501763_item	2480650	et	4	main
ta	doc_491521501763_item	2480652	et	4	main
on	doc_491521501763_item	2480662	et	4	main
ära	doc_491521501763_item	2480665	et	4	main
lydia	doc_491521501763_item	2480668	et	4	main
tänuseks	doc_491521501763_item	2480669	et	3	main
tuleb	doc_491521501763_item	2480678	et	3	main
on	doc_491521501763_item	2480683	et	4	main
vabastatud	doc_491521501763_item	2480684	et	4	main
rõõmsad	doc_491521501763_item	2480688	et	3	main
et	doc_491521501763_item	2480689	et	3	main
on	doc_491521501763_item	2480691	et	4	main
ka	doc_491521501763_item	2480692	et	3	main
vabastajate	doc_491521501763_item	2480693	et	4	main
sakslasi	doc_491521501763_item	2480724	et	3	main
oma	doc_491521501763_item	2480727	et	4	main
kui	doc_491521501763_item	2480734	et	3	main
ohvitserid	doc_491521501763_item	2480738	et	3	main
filmi	doc_491521501763_item	2480739	et	4	main
lõpus	doc_491521501763_item	2480740	et	4	main
miilas	doc_491521501763_item	2480743	et	3	main
ma	doc_491521501763_item	2480748	et	3	main
lapsepõlves	doc_491521501763_item	2480753	et	4	main
poliitika	doc_491521501762_item	2480411	et	4	main
teose	doc_491521501762_item	2480415	et	3	main
ma	doc_491521501762_item	2480425	et	3	main
et	doc_491521501762_item	2480427	et	3	main
rohkem	doc_491521501762_item	2480431	et	4	main
mõtlema	doc_491521501762_item	2480438	et	3	main
jaoks	doc_491521501762_item	2480442	et	4	main
oma	doc_491521501762_item	2480445	et	4	main
kodumaa	doc_491521501762_item	2480446	et	4	main
vastu	doc_491521501762_item	2480447	et	3	main
olla	doc_491521501762_item	2480448	et	3	main
tavaline	doc_491521501763_item	2480457	et	4	main
sügispäev	doc_491521501763_item	2480458	et	3	main
kell	doc_491521501763_item	2480459	et	3	main
kodus	doc_491521501763_item	2480471	et	4	main
räägib	doc_491521501763_item	2480505	et	3	main
ja	doc_491521501763_item	2480513	et	3	main
kaasa	doc_491521501762_item	2480422	et	4	main
ühekülgsuse	doc_491521501762_item	2480424	et	4	main
see	doc_491521501762_item	2480428	et	3	main
on	doc_491521501762_item	2480430	et	4	main
noortele	doc_491521501762_item	2480432	et	3	main
see	doc_491521501762_item	2480434	et	3	main
mis	doc_491521501762_item	2480439	et	4	main
armastus	doc_491521501762_item	2480450	et	4	main
on	doc_491521501763_item	2480460	et	4	main
juba	doc_491521501763_item	2480461	et	3	main
pool	doc_491521501763_item	2480462	et	4	main
kohtla-järvel	doc_491521501763_item	2480472	et	4	main
vaatan	doc_491521501763_item	2480474	et	3	main
telerit	doc_491521501763_item	2480475	et	3	main
filminimetus	doc_491521501763_item	2480476	et	4	main
on	doc_491521501763_item	2480477	et	4	main
elu	doc_491521501763_item	2480478	et	4	main
tsitadellis	doc_491521501763_item	2480479	et	3	main
film	doc_491521501763_item	2480480	et	3	main
algab	doc_491521501763_item	2480481	et	3	main
saksa	doc_491521501763_item	2480482	et	4	main
ohvitseride	doc_491521501763_item	2480483	et	3	main
tungimisega	doc_491521501763_item	2480484	et	4	main
professori	doc_491521501763_item	2480485	et	3	main
miilase	doc_491521501763_item	2480486	et	4	main
majja	doc_491521501763_item	2480487	et	3	main
loomulikult	doc_491521501763_item	2480488	et	4	main
saksa	doc_491521501763_item	2480489	et	4	main
vägilane	doc_491521501763_item	2480490	et	3	main
ohvitser	doc_491521501763_item	2480491	et	3	main
räägib	doc_491521501763_item	2480492	et	3	main
professoriga	doc_491521501763_item	2480493	et	3	main
üsna	doc_491521501763_item	2480494	et	3	main
rangelt	doc_491521501763_item	2480495	et	4	main
et	doc_491521501763_item	2480501	et	3	main
armasta	doc_491521501763_item	2480525	et	4	main
ranged	doc_491521501763_item	2480531	et	3	main
väljuda	doc_491521501763_item	2480536	et	3	main
poeg	doc_491521501763_item	2480544	et	3	main
karl	doc_491521501763_item	2480545	et	4	main
sõjavägede	doc_491521501763_item	2480564	et	3	main
lydia	doc_491521501763_item	2480572	et	4	main
ja	doc_491521501763_item	2480573	et	3	main
ohvitseridest	doc_491521501763_item	2480579	et	3	main
on	doc_491521501763_item	2480583	et	4	main
teineteist	doc_491521501763_item	2480585	et	4	main
miilas	doc_491521501763_item	2480624	et	3	main
tegeleda	doc_491521501763_item	2480626	et	3	main
ta	doc_491521501763_item	2480637	et	4	main
siin	doc_491521501763_item	2480644	et	4	main
nõukogude	doc_491521501763_item	2480648	et	3	main
ja	doc_491521501763_item	2480651	et	3	main
sõidab	doc_491521501763_item	2480653	et	3	main
läbi	doc_491521501763_item	2480656	et	4	main
vaatamata	doc_491521501763_item	2480658	et	4	main
sellele	doc_491521501763_item	2480659	et	4	main
et	doc_491521501763_item	2480660	et	3	main
hospital	doc_491521501763_item	2480673	et	3	main
haavatuteks	doc_491521501763_item	2480675	et	4	main
kõik	doc_491521501763_item	2480686	et	4	main
ralf	doc_491521501763_item	2480700	et	4	main
ei	doc_491521501763_item	2480701	et	4	main
ralf	doc_491521501763_item	2480729	et	4	main
appi	doc_491521501763_item	2480735	et	4	main
nõukogude	doc_491521501763_item	2480737	et	3	main
on	doc_491521501763_item	2480741	et	4	main
prof	doc_491521501763_item	2480742	et	4	main
armastan	doc_491521501763_item	2480749	et	3	main
sest	doc_491521501763_item	2480755	et	4	main
on	doc_491521501763_item	2480761	et	4	main
paha	doc_491521501763_item	2480762	et	4	main
aga	doc_491521501763_item	2480763	et	3	main
kes	doc_491521501763_item	2480764	et	4	main
meenutan	doc_491521501763_item	2480772	et	3	main
oma	doc_491521501763_item	2480773	et	4	main
vanaisa	doc_491521501763_item	2480776	et	4	main
õpetas	doc_491521501763_item	2480777	et	3	main
mind	doc_491521501763_item	2480778	et	4	main
ole	doc_491521501763_item	2480787	et	4	main
teadlane	doc_491521501763_item	2480522	et	3	main
keegi	doc_491521501763_item	2480533	et	4	main
tütar	doc_491521501763_item	2480542	et	3	main
naine	doc_491521501763_item	2480547	et	3	main
ralf	doc_491521501763_item	2480552	et	4	main
abielust	doc_491521501763_item	2480554	et	3	main
tahtsid	doc_491521501763_item	2480556	et	4	main
leida	doc_491521501763_item	2480557	et	3	main
professori	doc_491521501763_item	2480558	et	3	main
antsi	doc_491521501763_item	2480560	et	4	main
ant	doc_491521501763_item	2480561	et	4	main
nõukogude	doc_491521501763_item	2480563	et	3	main
ja	doc_491521501763_item	2480581	et	3	main
esimesest	doc_491521501763_item	2480586	et	3	main
silmapilgust	doc_491521501763_item	2480587	et	4	main
ühel	doc_491521501763_item	2480588	et	3	main
päeval	doc_491521501763_item	2480589	et	3	main
ralf	doc_491521501763_item	2480590	et	4	main
kes	doc_491521501763_item	2480591	et	4	main
on	doc_491521501763_item	2480592	et	4	main
lõpetanud	doc_491521501763_item	2480593	et	4	main
ülikooli	doc_491521501763_item	2480594	et	4	main
tuleb	doc_491521501763_item	2480595	et	3	main
isa	doc_491521501763_item	2480596	et	4	main
koju	doc_491521501763_item	2480597	et	3	main
tagasi	doc_491521501763_item	2480598	et	3	main
koos	doc_491521501763_item	2480599	et	4	main
vennapojaga	doc_491521501763_item	2480600	et	4	main
richardiga	doc_491521501763_item	2480601	et	4	main
loomulikult	doc_491521501763_item	2480602	et	4	main
professor	doc_491521501763_item	2480603	et	3	main
miilas	doc_491521501763_item	2480604	et	3	main
oli	doc_491521501763_item	2480605	et	3	main
üsna	doc_491521501763_item	2480606	et	3	main
rõõm	doc_491521501763_item	2480607	et	3	main
ja	doc_491521501763_item	2480608	et	3	main
õnnelik	doc_491521501763_item	2480609	et	3	main
et	doc_491521501763_item	2480610	et	3	main
vanem	doc_491521501763_item	2480612	et	4	main
poeg	doc_491521501763_item	2480613	et	3	main
tuli	doc_491521501763_item	2480614	et	4	main
koju	doc_491521501763_item	2480615	et	3	main
tema	doc_491521501763_item	2480611	et	4	main
tagasi	doc_491521501763_item	2480616	et	3	main
teadlane	doc_491521501763_item	2480617	et	3	main
arvas	doc_491521501763_item	2480618	et	3	main
et	doc_491521501763_item	2480619	et	3	main
tohi	doc_491521501763_item	2480535	et	4	main
esimesest	doc_491521501763_item	2480553	et	3	main
on	doc_491521501763_item	2480562	et	4	main
ta	doc_491521501763_item	2480566	et	4	main
koduperenaise	doc_491521501763_item	2480568	et	3	main
teda	doc_491521501763_item	2480623	et	4	main
soovinud	doc_491521501763_item	2480630	et	4	main
ka	doc_491521501763_item	2480645	et	3	main
isa	doc_491521501763_item	2480661	et	4	main
talle	doc_491521501763_item	2480664	et	4	main
minna	doc_491521501763_item	2480666	et	3	main
nõukogude	doc_491521501763_item	2480674	et	3	main
professor	doc_491521501763_item	2480676	et	3	main
eestimaa	doc_491521501763_item	2480682	et	4	main
sakslastest	doc_491521501763_item	2480685	et	3	main
mõistis	doc_491521501763_item	2480622	et	4	main
sureb	doc_491521501763_item	2480643	et	3	main
sõjavägede	doc_491521501763_item	2480649	et	3	main
sõjaväelastega	doc_491521501763_item	2480655	et	4	main
sood	doc_491521501763_item	2480657	et	4	main
keelanud	doc_491521501763_item	2480663	et	4	main
hiljem	doc_491521501763_item	2480667	et	3	main
saab	doc_491521501763_item	2480670	et	3	main
miilase	doc_491521501763_item	2480671	et	4	main
sünnipäeval	doc_491521501763_item	2480677	et	3	main
uudisega	doc_491521501763_item	2480680	et	3	main
armastanud	doc_491521501763_item	2480702	et	4	main
oma	doc_491521501763_item	2480703	et	4	main
isa	doc_491521501763_item	2480704	et	4	main
ta	doc_491521501763_item	2480705	et	4	main
püüdis	doc_491521501763_item	2480706	et	3	main
kontakti	doc_491521501763_item	2480707	et	4	main
saada	doc_491521501763_item	2480708	et	4	main
tema	doc_491521501763_item	2480709	et	4	main
teise	doc_491521501763_item	2480710	et	4	main
naisega	doc_491521501763_item	2480711	et	3	main
hiljem	doc_491521501763_item	2480712	et	3	main
miilas	doc_491521501763_item	2480713	et	3	main
saa	doc_491521501763_item	2480714	et	4	main
aru	doc_491521501763_item	2480715	et	4	main
sellest	doc_491521501763_item	2480716	et	4	main
et	doc_491521501763_item	2480717	et	3	main
tema	doc_491521501763_item	2480718	et	4	main
armaspoeg	doc_491521501763_item	2480719	et	4	main
ralf	doc_491521501763_item	2480720	et	4	main
toetab	doc_491521501763_item	2480721	et	3	main
aitab	doc_491521501763_item	2480723	et	3	main
pettub	doc_491521501763_item	2480726	et	3	main
pojas	doc_491521501763_item	2480728	et	4	main
püüab	doc_491521501763_item	2480730	et	3	main
isa	doc_491521501763_item	2480733	et	4	main
tulevad	doc_491521501763_item	2480736	et	4	main
oma	doc_491521501763_item	2480745	et	4	main
vanu	doc_491521501763_item	2480751	et	4	main
on	doc_491521501763_item	2480758	et	4	main
kes	doc_491521501763_item	2480760	et	4	main
hea	doc_491521501763_item	2480766	et	4	main
minu	doc_491521501763_item	2480775	et	3	main
ma	doc_491521501763_item	2480783	et	3	main
tean	doc_491521501763_item	2480784	et	3	main
filmis	doc_491521501763_item	2480832	et	4	main
näitljaid	doc_491521501763_item	2480836	et	4	main
armee	doc_491521501764_item	2480885	et	4	main
major	doc_491521501764_item	2480886	et	3	main
anna	doc_491521501764_item	2480887	et	4	main
poeg	doc_491521501764_item	2480888	et	3	main
saksa	doc_491521501764_item	2480892	et	4	main
professoriga	doc_491521501764_item	2480904	et	3	main
jämedalt	doc_491521501764_item	2480906	et	4	main
perekonnanimi	doc_491521501764_item	2480913	et	3	main
professoriga	doc_491521501764_item	2480924	et	3	main
on	doc_491521501764_item	2480931	et	4	main
kaks	doc_491521501764_item	2480932	et	3	main
poega	doc_491521501764_item	2480933	et	4	main
lydia	doc_491521501764_item	2480940	et	4	main
kuskil	doc_491521501764_item	2480953	et	3	main
keegi	doc_491521501764_item	2480960	et	4	main
professor	doc_491521501764_item	2480970	et	3	main
ohvitserid	doc_491521501764_item	2480983	et	3	main
sündinud	doc_491521501763_item	2480639	et	4	main
siin	doc_491521501763_item	2480640	et	4	main
siis	doc_491521501763_item	2480641	et	3	main
ta	doc_491521501763_item	2480642	et	4	main
nõukogude	doc_491521501763_item	2480654	et	3	main
majast	doc_491521501763_item	2480672	et	4	main
ants	doc_491521501763_item	2480679	et	4	main
et	doc_491521501763_item	2480681	et	3	main
olid	doc_491521501763_item	2480687	et	4	main
karl	doc_491521501763_item	2480690	et	4	main
hulgas	doc_491521501763_item	2480694	et	4	main
kõige	doc_491521501763_item	2480695	et	4	main
jõudsam	doc_491521501763_item	2480696	et	4	main
oli	doc_491521501763_item	2480697	et	3	main
see	doc_491521501763_item	2480698	et	3	main
et	doc_491521501763_item	2480699	et	3	main
tulistada	doc_491521501763_item	2480731	et	3	main
koos	doc_491521501763_item	2480744	et	4	main
vaadata	doc_491521501763_item	2480750	et	4	main
armastasin	doc_491521501763_item	2480754	et	3	main
kõik	doc_491521501763_item	2480757	et	4	main
arusaadav	doc_491521501763_item	2480759	et	4	main
on	doc_491521501763_item	2480765	et	4	main
lapsepõlve	doc_491521501763_item	2480774	et	4	main
sest	doc_491521501763_item	2480821	et	4	main
näitanud	doc_491521501763_item	2480834	et	4	main
eestimaa	doc_491521501763_item	2480838	et	4	main
see	doc_491521501763_item	2480839	et	3	main
film	doc_491521501763_item	2480840	et	3	main
on	doc_491521501763_item	2480841	et	4	main
kultuuriks	doc_491521501763_item	2480844	et	4	main
esimene	doc_491521501763_item	2480847	et	3	main
peategelased	doc_491521501764_item	2480852	et	3	main
teadlane	doc_491521501764_item	2480855	et	3	main
miilas	doc_491521501764_item	2480875	et	3	main
vennapoeg	doc_491521501764_item	2480877	et	3	main
sisu	doc_491521501764_item	2480889	et	4	main
saksa	doc_491521501764_item	2480901	et	4	main
ohvitser	doc_491521501764_item	2480902	et	3	main
väga	doc_491521501764_item	2480905	et	3	main
et	doc_491521501764_item	2480911	et	3	main
on	doc_491521501764_item	2480914	et	4	main
on	doc_491521501764_item	2480919	et	4	main
väga	doc_491521501764_item	2480920	et	3	main
ja	doc_491521501764_item	2480925	et	3	main
ja	doc_491521501764_item	2480935	et	3	main
tütar	doc_491521501764_item	2480939	et	3	main
ralf	doc_491521501764_item	2480941	et	4	main
on	doc_491521501764_item	2480942	et	4	main
ülikooli	doc_491521501764_item	2480950	et	4	main
ja	doc_491521501764_item	2480951	et	3	main
elab	doc_491521501764_item	2480952	et	3	main
mitte	doc_491521501764_item	2480959	et	3	main
ei	doc_491521501764_item	2480961	et	4	main
väljuda	doc_491521501764_item	2480963	et	3	main
majast	doc_491521501764_item	2480964	et	4	main
ja	doc_491521501764_item	2480965	et	3	main
siseneda	doc_491521501764_item	2480966	et	3	main
majja	doc_491521501764_item	2480967	et	3	main
armastanud	doc_491521501764_item	2480972	et	4	main
on	doc_491521501764_item	2480976	et	4	main
saksa	doc_491521501764_item	2480982	et	4	main
ja	doc_491521501763_item	2480722	et	3	main
professor	doc_491521501763_item	2480725	et	3	main
oma	doc_491521501763_item	2480732	et	4	main
noorema	doc_491521501763_item	2480746	et	4	main
pojaga	doc_491521501763_item	2480747	et	4	main
filme	doc_491521501763_item	2480752	et	3	main
et	doc_491521501763_item	2480756	et	3	main
vanu	doc_491521501763_item	2480779	et	4	main
ei	doc_491521501763_item	2480786	et	4	main
kõik	doc_491521501763_item	2480788	et	4	main
õigust	doc_491521501763_item	2480789	et	4	main
mis	doc_491521501763_item	2480790	et	4	main
on	doc_491521501763_item	2480791	et	4	main
näidanud	doc_491521501763_item	2480792	et	4	main
tean	doc_491521501763_item	2480793	et	3	main
et	doc_491521501763_item	2480794	et	3	main
kõik	doc_491521501763_item	2480795	et	4	main
inimesed	doc_491521501763_item	2480796	et	3	main
on	doc_491521501763_item	2480797	et	4	main
erinevad	doc_491521501763_item	2480798	et	4	main
ja	doc_491521501763_item	2480799	et	3	main
pole	doc_491521501763_item	2480800	et	3	main
tähtis	doc_491521501763_item	2480801	et	4	main
kes	doc_491521501763_item	2480802	et	4	main
sa	doc_491521501763_item	2480803	et	3	main
oled	doc_491521501763_item	2480804	et	3	main
rahvusest	doc_491521501763_item	2480805	et	4	main
vaid	doc_491521501763_item	2480806	et	3	main
tähtis	doc_491521501763_item	2480807	et	4	main
missugune	doc_491521501763_item	2480808	et	3	main
inimene	doc_491521501763_item	2480809	et	3	main
sa	doc_491521501763_item	2480810	et	3	main
oled	doc_491521501763_item	2480811	et	3	main
arvan	doc_491521501763_item	2480812	et	3	main
et	doc_491521501763_item	2480813	et	3	main
tool	doc_491521501763_item	2480814	et	3	main
ajal	doc_491521501763_item	2480815	et	4	main
oli	doc_491521501763_item	2480816	et	3	main
kõige	doc_491521501763_item	2480817	et	4	main
raskem	doc_491521501763_item	2480818	et	4	main
töö	doc_491521501763_item	2480819	et	4	main
näitlejatel	doc_491521501763_item	2480820	et	4	main
palju	doc_491521501763_item	2480827	et	4	main
tööd	doc_491521501763_item	2480828	et	4	main
teeb	doc_491521501763_item	2480829	et	3	main
näitleja	doc_491521501763_item	2480830	et	4	main
on	doc_491521501763_item	2480833	et	4	main
essee	doc_491521501764_item	2480848	et	4	main
tsitadellis	doc_491521501764_item	2480851	et	3	main
nüüd	doc_491521501763_item	2480767	et	4	main
vaatan	doc_491521501763_item	2480768	et	3	main
must-valgeid	doc_491521501763_item	2480769	et	3	main
filme	doc_491521501763_item	2480770	et	3	main
ja	doc_491521501763_item	2480771	et	3	main
filme	doc_491521501763_item	2480780	et	3	main
vaadata	doc_491521501763_item	2480781	et	4	main
nüüd	doc_491521501763_item	2480782	et	4	main
et	doc_491521501763_item	2480785	et	3	main
ei	doc_491521501763_item	2480822	et	4	main
olnud	doc_491521501763_item	2480823	et	4	main
kõik	doc_491521501763_item	2480824	et	4	main
seadmeid	doc_491521501763_item	2480825	et	3	main
ja	doc_491521501763_item	2480826	et	3	main
eesti	doc_491521501763_item	2480835	et	4	main
ja	doc_491521501763_item	2480837	et	3	main
eesti	doc_491521501763_item	2480843	et	4	main
ta	doc_491521501763_item	2480845	et	4	main
ongi	doc_491521501763_item	2480846	et	4	main
elu	doc_491521501764_item	2480850	et	4	main
professor	doc_491521501764_item	2480853	et	3	main
abielust	doc_491521501764_item	2480872	et	3	main
richard	doc_491521501764_item	2480874	et	4	main
anna	doc_491521501764_item	2480878	et	4	main
ohvitseride	doc_491521501764_item	2480893	et	3	main
räägib	doc_491521501764_item	2480903	et	3	main
teada	doc_491521501764_item	2480910	et	3	main
meeldiv	doc_491521501764_item	2480921	et	4	main
karl	doc_491521501764_item	2480934	et	4	main
ralf	doc_491521501764_item	2480936	et	4	main
ja	doc_491521501764_item	2480937	et	3	main
üks	doc_491521501764_item	2480938	et	3	main
on	doc_491521501764_item	2480948	et	4	main
lõpetanud	doc_491521501764_item	2480949	et	4	main
on	doc_491521501764_item	2480956	et	4	main
ranged	doc_491521501764_item	2480957	et	3	main
2000	doc_491521501764_item	2480969	et	2	main
rääkida	doc_491521501764_item	2480973	et	3	main
toimuva	doc_491521501764_item	2480978	et	4	main
tegelikult	doc_491521501764_item	2480981	et	4	main
antsi	doc_491521501764_item	2480987	et	4	main
kes	doc_491521501764_item	2480988	et	4	main
oli	doc_491521501764_item	2480989	et	3	main
nõukogude	doc_491521501764_item	2480990	et	3	main
sõjavägede	doc_491521501764_item	2480991	et	3	main
major	doc_491521501764_item	2480992	et	3	main
olema	doc_491521501764_item	2481034	et	4	main
mitte	doc_491521501764_item	2481036	et	3	main
vaatas	doc_491521501764_item	2481040	et	3	main
inimesi	doc_491521501764_item	2481048	et	4	main
ka	doc_491521501764_item	2481049	et	3	main
tuleb	doc_491521501764_item	2481073	et	3	main
mõistis	doc_491521501764_item	2481091	et	4	main
teda	doc_491521501764_item	2481092	et	4	main
ülikoolist	doc_491521501764_item	2481102	et	4	main
soo	doc_491521501764_item	2481119	et	4	main
et	doc_491521501764_item	2481122	et	3	main
on	doc_491521501764_item	2481124	et	4	main
keelanud	doc_491521501764_item	2481125	et	4	main
isa	doc_491521501764_item	2481140	et	4	main
ta	doc_491521501764_item	2481142	et	4	main
ravida	doc_491521501764_item	2481144	et	3	main
nende	doc_491521501764_item	2481145	et	4	main
ta	doc_491521501764_item	2481153	et	4	main
ütles	doc_491521501764_item	2481154	et	3	main
isale	doc_491521501764_item	2481156	et	3	main
maja	doc_491521501764_item	2481165	et	4	main
hospital	doc_491521501764_item	2481169	et	3	main
koos	doc_491521501764_item	2481227	et	4	main
emaga	doc_491521501764_item	2481228	et	3	main
sõidavad	doc_491521501764_item	2481229	et	3	main
tartu	doc_491521501764_item	2481230	et	4	main
konfiskeerisid	doc_491521501764_item	2481244	et	4	main
poeg	doc_491521501764_item	2481253	et	3	main
sp	doc_491521501764_item	2481257	et	4	main
hävitanud	doc_491521501764_item	2481261	et	4	main
nende	doc_491521501764_item	2481262	et	4	main
ta	doc_491521501764_item	2481271	et	4	main
jutustada	doc_491521501764_item	2481274	et	3	main
soode	doc_491521501764_item	2481299	et	3	main
kuivatamise	doc_491521501764_item	2481300	et	4	main
et	doc_491521501764_item	2481305	et	3	main
ise	doc_491521501763_item	2480831	et	4	main
väärtuslik	doc_491521501763_item	2480842	et	3	main
film	doc_491521501764_item	2480849	et	3	main
miilas	doc_491521501764_item	2480854	et	3	main
eeva	doc_491521501764_item	2480857	et	4	main
miilas	doc_491521501764_item	2480858	et	3	main
professori	doc_491521501764_item	2480859	et	3	main
teine	doc_491521501764_item	2480860	et	3	main
abikaasa	doc_491521501764_item	2480861	et	4	main
nende	doc_491521501764_item	2480863	et	4	main
lydia	doc_491521501764_item	2480862	et	4	main
tütar	doc_491521501764_item	2480864	et	3	main
karl	doc_491521501764_item	2480865	et	4	main
nende	doc_491521501764_item	2480866	et	4	main
poeg	doc_491521501764_item	2480867	et	3	main
ralf	doc_491521501764_item	2480868	et	4	main
professori	doc_491521501764_item	2480869	et	3	main
poeg	doc_491521501764_item	2480870	et	3	main
esimesest	doc_491521501764_item	2480871	et	3	main
botaanik	doc_491521501764_item	2480856	et	3	main
doktor	doc_491521501764_item	2480873	et	3	main
professori	doc_491521501764_item	2480876	et	3	main
perenaine	doc_491521501764_item	2480879	et	3	main
majas	doc_491521501764_item	2480882	et	3	main
ants	doc_491521501764_item	2480883	et	4	main
nõukogude	doc_491521501764_item	2480884	et	3	main
algab	doc_491521501764_item	2480891	et	3	main
tungimisega	doc_491521501764_item	2480894	et	4	main
miilase	doc_491521501764_item	2480896	et	4	main
majja	doc_491521501764_item	2480897	et	3	main
ja	doc_491521501764_item	2480898	et	3	main
läbiotsivad	doc_491521501764_item	2480899	et	4	main
ohvitser	doc_491521501764_item	2480908	et	3	main
ta	doc_491521501764_item	2480916	et	4	main
räägib	doc_491521501764_item	2480917	et	3	main
kuulsa	doc_491521501764_item	2480923	et	3	main
ohvitser	doc_491521501764_item	2480927	et	3	main
ära	doc_491521501764_item	2480929	et	4	main
vanem	doc_491521501764_item	2480943	et	4	main
poeg	doc_491521501764_item	2480944	et	3	main
esimesest	doc_491521501764_item	2480945	et	3	main
kes	doc_491521501764_item	2480947	et	4	main
majas	doc_491521501764_item	2480955	et	3	main
pärast	doc_491521501764_item	2480968	et	4	main
ei	doc_491521501764_item	2480971	et	4	main
ta	doc_491521501764_item	2480975	et	4	main
ükskõikne	doc_491521501764_item	2480977	et	3	main
vastu	doc_491521501764_item	2480980	et	3	main
otsisid	doc_491521501764_item	2480984	et	4	main
majas	doc_491521501764_item	2480986	et	3	main
luuletajale	doc_491521501764_item	2481029	et	4	main
hea	doc_491521501764_item	2481030	et	4	main
vaimule	doc_491521501764_item	2481035	et	4	main
professor	doc_491521501764_item	2481039	et	3	main
aastatel	doc_491521501764_item	2481046	et	4	main
palju	doc_491521501764_item	2481047	et	4	main
tahtnud	doc_491521501764_item	2481057	et	4	main
põgeneda	doc_491521501764_item	2481058	et	3	main
koju	doc_491521501764_item	2481076	et	3	main
koos	doc_491521501764_item	2481077	et	4	main
õnnelik	doc_491521501764_item	2481082	et	3	main
et	doc_491521501764_item	2481083	et	3	main
tuli	doc_491521501764_item	2481084	et	4	main
ainult	doc_491521501764_item	2481089	et	4	main
prof	doc_491521501764_item	2481099	et	4	main
miilas	doc_491521501764_item	2481100	et	3	main
lahkus	doc_491521501764_item	2481101	et	4	main
teadust	doc_491521501764_item	2481107	et	4	main
lydia	doc_491521501764_item	2481110	et	4	main
et	doc_491521501764_item	2481113	et	3	main
sõitis	doc_491521501764_item	2481115	et	3	main
isa	doc_491521501764_item	2481123	et	4	main
lydia	doc_491521501764_item	2481129	et	4	main
lydia	doc_491521501764_item	2481138	et	4	main
haavatuid	doc_491521501764_item	2481147	et	4	main
ralf	doc_491521501764_item	2481148	et	4	main
töötada	doc_491521501764_item	2481160	et	3	main
professor	doc_491521501764_item	2481161	et	3	main
aga	doc_491521501764_item	2481162	et	3	main
andis	doc_491521501764_item	2481163	et	3	main
nõu	doc_491521501764_item	2481164	et	4	main
et	doc_491521501764_item	2481178	et	3	main
õnneks	doc_491521501764_item	2481221	et	4	main
leidis	doc_491521501764_item	2481237	et	4	main
ralfil	doc_491521501764_item	2481238	et	4	main
kuldhambad	doc_491521501764_item	2481241	et	3	main
sakslased	doc_491521501764_item	2481243	et	3	main
neid	doc_491521501764_item	2481245	et	4	main
vangidest	doc_491521501764_item	2481246	et	3	main
ta	doc_491521501764_item	2481247	et	4	main
saab	doc_491521501764_item	2481248	et	3	main
aru	doc_491521501764_item	2481249	et	4	main
et	doc_491521501764_item	2481250	et	3	main
toetab	doc_491521501764_item	2481254	et	3	main
ohvitserid	doc_491521501764_item	2481259	et	3	main
ei	doc_491521501764_item	2481260	et	4	main
prof	doc_491521501764_item	2481264	et	4	main
tahtis	doc_491521501764_item	2481272	et	3	main
lõpeb	doc_491521501764_item	2481303	et	4	main
on	doc_491521501764_item	2481308	et	4	main
tema	doc_491521501764_item	2481310	et	4	main
prof	doc_491521501764_item	2480880	et	4	main
miilase	doc_491521501764_item	2480881	et	4	main
film	doc_491521501764_item	2480890	et	3	main
prof	doc_491521501764_item	2480895	et	4	main
seal	doc_491521501764_item	2480900	et	4	main
kui	doc_491521501764_item	2480907	et	3	main
saab	doc_491521501764_item	2480909	et	3	main
professori	doc_491521501764_item	2480912	et	3	main
miilas	doc_491521501764_item	2480915	et	3	main
et	doc_491521501764_item	2480918	et	3	main
tutvuda	doc_491521501764_item	2480922	et	3	main
kohe	doc_491521501764_item	2480926	et	4	main
läheb	doc_491521501764_item	2480928	et	3	main
professoril	doc_491521501764_item	2480930	et	3	main
abielust	doc_491521501764_item	2480946	et	3	main
professori	doc_491521501764_item	2480954	et	3	main
reeglid	doc_491521501764_item	2480958	et	3	main
tohi	doc_491521501764_item	2480962	et	4	main
poliitikast	doc_491521501764_item	2480974	et	4	main
sõja	doc_491521501764_item	2480979	et	3	main
ants	doc_491521501764_item	2480993	et	4	main
on	doc_491521501764_item	2480994	et	4	main
perenaise	doc_491521501764_item	2480995	et	3	main
anna	doc_491521501764_item	2480996	et	4	main
poeg	doc_491521501764_item	2480997	et	3	main
karl	doc_491521501764_item	2480998	et	4	main
ja	doc_491521501764_item	2480999	et	3	main
lydia	doc_491521501764_item	2481000	et	4	main
peita	doc_491521501764_item	2481002	et	3	main
antsit	doc_491521501764_item	2481003	et	4	main
aitasid	doc_491521501764_item	2481001	et	4	main
ära	doc_491521501764_item	2481004	et	4	main
sakslastest	doc_491521501764_item	2481005	et	3	main
lydia	doc_491521501764_item	2481006	et	4	main
oli	doc_491521501764_item	2481007	et	3	main
armunud	doc_491521501764_item	2481008	et	4	main
antsile	doc_491521501764_item	2481009	et	4	main
karl	doc_491521501764_item	2481010	et	4	main
oli	doc_491521501764_item	2481011	et	3	main
nõukogude	doc_491521501764_item	2481012	et	3	main
sõjavägede	doc_491521501764_item	2481013	et	3	main
poolel	doc_491521501764_item	2481014	et	4	main
sel	doc_491521501764_item	2481015	et	3	main
kui	doc_491521501764_item	2481017	et	3	main
ajal	doc_491521501764_item	2481016	et	4	main
väljas	doc_491521501764_item	2481018	et	4	main
olid	doc_491521501764_item	2481019	et	4	main
pommid	doc_491521501764_item	2481020	et	4	main
prof	doc_491521501764_item	2481021	et	4	main
ühe	doc_491521501764_item	2481023	et	4	main
mängib	doc_491521501764_item	2481025	et	3	main
malet	doc_491521501764_item	2481026	et	3	main
peavad	doc_491521501764_item	2481033	et	4	main
aga	doc_491521501764_item	2481037	et	3	main
nendel	doc_491521501764_item	2481045	et	4	main
sõitsid	doc_491521501764_item	2481051	et	4	main
läände	doc_491521501764_item	2481052	et	3	main
aga	doc_491521501764_item	2481053	et	3	main
prof	doc_491521501764_item	2481054	et	4	main
miilas	doc_491521501764_item	2481055	et	3	main
ma	doc_491521501764_item	2481063	et	3	main
olen	doc_491521501764_item	2481064	et	3	main
siin	doc_491521501764_item	2481065	et	4	main
kuskilt	doc_491521501764_item	2481074	et	4	main
professori	doc_491521501764_item	2480985	et	3	main
rahulikult	doc_491521501764_item	2481022	et	4	main
luuletajaga	doc_491521501764_item	2481024	et	4	main
ta	doc_491521501764_item	2481027	et	4	main
ütles	doc_491521501764_item	2481028	et	3	main
ei	doc_491521501764_item	2481056	et	4	main
sündinud	doc_491521501764_item	2481066	et	4	main
ma	doc_491521501764_item	2481067	et	3	main
suren	doc_491521501764_item	2481068	et	3	main
ka	doc_491521501764_item	2481069	et	3	main
siin	doc_491521501764_item	2481070	et	4	main
ühel	doc_491521501764_item	2481071	et	3	main
päeval	doc_491521501764_item	2481072	et	3	main
tema	doc_491521501764_item	2481085	et	4	main
vanem	doc_491521501764_item	2481086	et	4	main
ralf	doc_491521501764_item	2481090	et	4	main
nagu	doc_491521501764_item	2481093	et	3	main
1938	doc_491521501764_item	2481097	et	2	main
a	doc_491521501764_item	2481098	et	4	main
kavandama	doc_491521501764_item	2481108	et	3	main
räägib	doc_491521501764_item	2481112	et	3	main
karl	doc_491521501764_item	2481114	et	4	main
sõjaväelastega	doc_491521501764_item	2481117	et	4	main
läbi	doc_491521501764_item	2481118	et	4	main
sellele	doc_491521501764_item	2481121	et	4	main
minna	doc_491521501764_item	2481128	et	3	main
emaga	doc_491521501764_item	2481130	et	3	main
karl	doc_491521501764_item	2481134	et	4	main
palus	doc_491521501764_item	2481139	et	4	main
majas	doc_491521501764_item	2481146	et	3	main
selle	doc_491521501764_item	2481150	et	4	main
on	doc_491521501764_item	2481157	et	4	main
vaja	doc_491521501764_item	2481158	et	4	main
esimesest	doc_491521501764_item	2481166	et	3	main
jaoks	doc_491521501764_item	2481172	et	4	main
teade	doc_491521501764_item	2481177	et	4	main
vabastatud	doc_491521501764_item	2481181	et	4	main
kõik	doc_491521501764_item	2481183	et	4	main
prof	doc_491521501764_item	2481236	et	4	main
sakslasi	doc_491521501764_item	2481255	et	3	main
et	doc_491521501764_item	2481266	et	3	main
pole	doc_491521501764_item	2481268	et	3	main
minna	doc_491521501764_item	2481273	et	3	main
filmist	doc_491521501764_item	2481318	et	4	main
arvan	doc_491521501764_item	2481319	et	3	main
et	doc_491521501764_item	2481320	et	3	main
hea	doc_491521501764_item	2481323	et	4	main
ülevaade	doc_491521501764_item	2481324	et	3	main
oma	doc_491521501764_item	2481334	et	4	main
elu	doc_491521501764_item	2481337	et	4	main
võitlema	doc_491521501764_item	2481341	et	3	main
miinase	doc_491521501764_item	2481348	et	4	main
perekonnas	doc_491521501764_item	2481349	et	4	main
põrkasid	doc_491521501764_item	2481350	et	4	main
seisukohad	doc_491521501764_item	2481353	et	4	main
võib	doc_491521501764_item	2481355	et	3	main
väärilisteks	doc_491521501764_item	2481365	et	4	main
korratus	doc_491521501764_item	2481369	et	4	main
selgitatakse	doc_491521501764_item	2481370	et	3	main
filmist	doc_491521501764_item	2481384	et	4	main
rahatähel	doc_491521501765_item	2481421	et	3	main
1teisel	doc_491521501765_item	2481431	et	4	main
leheküljel	doc_491521501765_item	2481432	et	3	main
konkreetsem	doc_491521501765_item	2481434	et	4	main
vastus	doc_491521501765_item	2481435	et	3	main
hakkasid	doc_491521501765_item	2481436	et	4	main
tuleb	doc_491521501765_item	2481452	et	3	main
võõrtöölisi	doc_491521501765_item	2481454	et	3	main
rahvuspark	doc_491521501765_item	2481469	et	3	main
segakoolid	doc_491521501765_item	2481472	et	3	main
eesti	doc_491521501765_item	2481477	et	4	main
vene	doc_491521501765_item	2481481	et	4	main
keeles	doc_491521501765_item	2481482	et	4	main
vene	doc_491521501765_item	2481483	et	4	main
üks	doc_491521501765_item	2481496	et	3	main
ohus	doc_491521501765_item	2481524	et	3	main
oli	doc_491521501765_item	2481527	et	3	main
maainimesed	doc_491521501765_item	2481543	et	3	main
aprillis	doc_491521501765_item	2481560	et	3	main
gorbatšovi	doc_491521501765_item	2481569	et	2	main
tartu	doc_491521501765_item	2481572	et	4	main
fraasi	doc_491521501764_item	2481031	et	4	main
luuletused	doc_491521501764_item	2481032	et	4	main
võimule	doc_491521501764_item	2481038	et	3	main
toimuva	doc_491521501764_item	2481041	et	4	main
peale	doc_491521501764_item	2481042	et	4	main
nagu	doc_491521501764_item	2481043	et	3	main
kõrvalt	doc_491521501764_item	2481044	et	4	main
intelligentid	doc_491521501764_item	2481050	et	4	main
oma	doc_491521501764_item	2481059	et	4	main
maast	doc_491521501764_item	2481060	et	3	main
ta	doc_491521501764_item	2481061	et	4	main
ütles	doc_491521501764_item	2481062	et	3	main
ralf	doc_491521501764_item	2481075	et	4	main
vennapoja	doc_491521501764_item	2481078	et	4	main
richardiga	doc_491521501764_item	2481079	et	4	main
poeg	doc_491521501764_item	2481087	et	3	main
sest	doc_491521501764_item	2481088	et	4	main
tuleb	doc_491521501764_item	2481109	et	3	main
vaatamata	doc_491521501764_item	2481120	et	4	main
prof	doc_491521501764_item	2481080	et	4	main
oli	doc_491521501764_item	2481081	et	3	main
ta	doc_491521501764_item	2481094	et	4	main
ise	doc_491521501764_item	2481095	et	4	main
arvas	doc_491521501764_item	2481096	et	3	main
sest	doc_491521501764_item	2481103	et	4	main
need	doc_491521501764_item	2481104	et	3	main
pangahärrad	doc_491521501764_item	2481105	et	3	main
hakkasid	doc_491521501764_item	2481106	et	4	main
ja	doc_491521501764_item	2481111	et	3	main
nõukogude	doc_491521501764_item	2481116	et	3	main
olid	doc_491521501764_item	2481131	et	4	main
rõõmsad	doc_491521501764_item	2481132	et	3	main
et	doc_491521501764_item	2481133	et	3	main
läks	doc_491521501764_item	2481135	et	3	main
päästma	doc_491521501764_item	2481136	et	3	main
linna	doc_491521501764_item	2481137	et	4	main
oli	doc_491521501764_item	2481149	et	3	main
sest	doc_491521501764_item	2481152	et	4	main
et	doc_491521501764_item	2481155	et	3	main
korrusest	doc_491521501764_item	2481167	et	4	main
saab	doc_491521501764_item	2481168	et	3	main
nõukogude	doc_491521501764_item	2481170	et	3	main
linnast	doc_491521501764_item	2481175	et	4	main
tuli	doc_491521501764_item	2481176	et	4	main
on	doc_491521501764_item	2481180	et	4	main
rõõmsad	doc_491521501764_item	2481185	et	3	main
tulistatakse	doc_491521501764_item	2481220	et	3	main
talle	doc_491521501764_item	2481126	et	4	main
sõdima	doc_491521501764_item	2481127	et	3	main
et	doc_491521501764_item	2481141	et	3	main
lubas	doc_491521501764_item	2481143	et	3	main
vastu	doc_491521501764_item	2481151	et	3	main
rahulikult	doc_491521501764_item	2481159	et	4	main
haavatute	doc_491521501764_item	2481171	et	4	main
ühel	doc_491521501764_item	2481173	et	3	main
päeval	doc_491521501764_item	2481174	et	3	main
linn	doc_491521501764_item	2481179	et	3	main
sakslastest	doc_491521501764_item	2481182	et	3	main
olid	doc_491521501764_item	2481184	et	4	main
et	doc_491521501764_item	2481186	et	3	main
nende	doc_491521501764_item	2481187	et	4	main
karl	doc_491521501764_item	2481188	et	4	main
on	doc_491521501764_item	2481189	et	4	main
ka	doc_491521501764_item	2481190	et	3	main
vabastajate	doc_491521501764_item	2481191	et	4	main
hulgas	doc_491521501764_item	2481192	et	4	main
professori	doc_491521501764_item	2481193	et	3	main
sünnipäeval	doc_491521501764_item	2481194	et	3	main
tuleb	doc_491521501764_item	2481195	et	3	main
ants	doc_491521501764_item	2481196	et	4	main
ja	doc_491521501764_item	2481197	et	3	main
ütleb	doc_491521501764_item	2481198	et	3	main
et	doc_491521501764_item	2481199	et	3	main
eesti	doc_491521501764_item	2481200	et	4	main
on	doc_491521501764_item	2481201	et	4	main
vabastatud	doc_491521501764_item	2481202	et	4	main
sakslastest	doc_491521501764_item	2481203	et	3	main
kõik	doc_491521501764_item	2481204	et	4	main
olid	doc_491521501764_item	2481205	et	4	main
õnnelikud	doc_491521501764_item	2481206	et	3	main
prof	doc_491521501764_item	2481207	et	4	main
ei	doc_491521501764_item	2481208	et	4	main
tahtnud	doc_491521501764_item	2481209	et	4	main
oma	doc_491521501764_item	2481210	et	4	main
sünnipäeval	doc_491521501764_item	2481211	et	3	main
rääkida	doc_491521501764_item	2481212	et	3	main
poliitikast	doc_491521501764_item	2481213	et	4	main
kui	doc_491521501764_item	2481214	et	3	main
rahvas	doc_491521501764_item	2481215	et	4	main
pidutseb	doc_491521501764_item	2481216	et	3	main
võidu	doc_491521501764_item	2481217	et	4	main
puhul	doc_491521501764_item	2481218	et	4	main
antsule	doc_491521501764_item	2481219	et	4	main
sest	doc_491521501764_item	2481231	et	4	main
lydia	doc_491521501764_item	2481232	et	4	main
tahab	doc_491521501764_item	2481233	et	3	main
õppida	doc_491521501764_item	2481234	et	3	main
ülikoolis	doc_491521501764_item	2481235	et	4	main
erinevad	doc_491521501764_item	2481239	et	4	main
rahad	doc_491521501764_item	2481242	et	4	main
vanem	doc_491521501764_item	2481252	et	4	main
ja	doc_491521501764_item	2481256	et	3	main
ütles	doc_491521501764_item	2481265	et	3	main
ralf	doc_491521501764_item	2481267	et	4	main
tema	doc_491521501764_item	2481269	et	4	main
sellest	doc_491521501764_item	2481275	et	4	main
nõukogude	doc_491521501764_item	2481276	et	3	main
ohvitseridele	doc_491521501764_item	2481277	et	3	main
ralf	doc_491521501764_item	2481278	et	4	main
oli	doc_491521501764_item	2481279	et	3	main
valmis	doc_491521501764_item	2481280	et	4	main
juba	doc_491521501764_item	2481281	et	3	main
tulistada	doc_491521501764_item	2481282	et	3	main
oma	doc_491521501764_item	2481283	et	4	main
isa	doc_491521501764_item	2481284	et	4	main
kui	doc_491521501764_item	2481285	et	3	main
sel	doc_491521501764_item	2481286	et	3	main
ajal	doc_491521501764_item	2481287	et	4	main
tulevad	doc_491521501764_item	2481288	et	4	main
nõukogude	doc_491521501764_item	2481289	et	3	main
ohvitserid	doc_491521501764_item	2481290	et	3	main
filmi	doc_491521501764_item	2481291	et	4	main
lõpus	doc_491521501764_item	2481292	et	4	main
professori	doc_491521501764_item	2481293	et	3	main
õpilane	doc_491521501764_item	2481294	et	3	main
sander	doc_491521501764_item	2481295	et	4	main
palub	doc_491521501764_item	2481296	et	3	main
teda	doc_491521501764_item	2481297	et	4	main
olla	doc_491521501764_item	2481298	et	3	main
ta	doc_491521501764_item	2481222	et	4	main
saab	doc_491521501764_item	2481223	et	3	main
varsti	doc_491521501764_item	2481224	et	3	main
terveks	doc_491521501764_item	2481225	et	4	main
lydia	doc_491521501764_item	2481226	et	4	main
kuldehted	doc_491521501764_item	2481240	et	3	main
tema	doc_491521501764_item	2481251	et	4	main
saksa	doc_491521501764_item	2481258	et	4	main
maja	doc_491521501764_item	2481263	et	4	main
poeg	doc_491521501764_item	2481270	et	3	main
juhiks	doc_491521501764_item	2481301	et	4	main
film	doc_491521501764_item	2481302	et	3	main
prof	doc_491521501764_item	2481306	et	4	main
arvamus	doc_491521501764_item	2481317	et	3	main
filmis	doc_491521501764_item	2481321	et	4	main
sellega	doc_491521501764_item	2481304	et	3	main
õnnelik	doc_491521501764_item	2481309	et	3	main
kõrval	doc_491521501764_item	2481311	et	4	main
sellest	doc_491521501764_item	2481325	et	4	main
varanduse	doc_491521501764_item	2481335	et	3	main
teised	doc_491521501764_item	2481339	et	4	main
eest	doc_491521501764_item	2481343	et	4	main
kolmandad	doc_491521501764_item	2481344	et	3	main
jäävad	doc_491521501764_item	2481345	et	4	main
ükskõikseteks	doc_491521501764_item	2481346	et	4	main
ümber	doc_491521501764_item	2481367	et	3	main
kes	doc_491521501764_item	2481372	et	4	main
on	doc_491521501764_item	2481378	et	4	main
on	doc_491521501764_item	2481381	et	4	main
eksamitöö	doc_491521501765_item	2481385	et	4	main
tekkima	doc_491521501765_item	2481437	et	3	main
sest	doc_491521501765_item	2481440	et	4	main
ühes	doc_491521501765_item	2481449	et	4	main
kohas	doc_491521501765_item	2481450	et	4	main
inimesed	doc_491521501765_item	2481455	et	3	main
1980ndate	doc_491521501765_item	2481461	et	4	main
propagandeeritakse	doc_491521501765_item	2481471	et	4	main
ja	doc_491521501765_item	2481473	et	3	main
koolilapsed	doc_491521501765_item	2481484	et	3	main
lõpetasid	doc_491521501765_item	2481485	et	4	main
1980-ndatel	doc_491521501765_item	2481493	et	4	main
kaitstumatuid	doc_491521501765_item	2481497	et	4	main
kontseptsioon	doc_491521501765_item	2481505	et	3	main
oli	doc_491521501765_item	2481522	et	3	main
võimatu	doc_491521501765_item	2481529	et	4	main
1980-ndatel	doc_491521501765_item	2481539	et	4	main
dotseeritud	doc_491521501765_item	2481542	et	4	main
planeerida	doc_491521501765_item	2481546	et	3	main
oli	doc_491521501765_item	2481548	et	3	main
talu	doc_491521501765_item	2481550	et	4	main
idee	doc_491521501765_item	2481566	et	4	main
1988a	doc_491521501765_item	2481571	et	4	main
kasutada	doc_491521501765_item	2481575	et	3	main
lippu	doc_491521501765_item	2481577	et	4	main
ekp	doc_491521501765_item	2481580	et	4	main
kus	doc_491521501765_item	2481582	et	3	main
rahvarinne	doc_491521501765_item	2481584	et	3	main
11	doc_491521501765_item	2481587	et	2	main
isamaalaule	doc_491521501765_item	2481596	et	4	main
3	doc_491521501765_item	2481597	et	2	main
maaleja	doc_491521501765_item	2481603	et	4	main
tõi	doc_491521501765_item	2481607	et	3	main
miinas	doc_491521501764_item	2481307	et	4	main
karl	doc_491521501764_item	2481315	et	4	main
minu	doc_491521501764_item	2481316	et	3	main
inimestega	doc_491521501764_item	2481328	et	3	main
selles	doc_491521501764_item	2481329	et	4	main
ühed	doc_491521501764_item	2481332	et	3	main
ja	doc_491521501764_item	2481336	et	3	main
lähevad	doc_491521501764_item	2481340	et	3	main
kodumaa	doc_491521501764_item	2481342	et	4	main
kokku	doc_491521501764_item	2481351	et	3	main
mis	doc_491521501764_item	2481354	et	4	main
isegi	doc_491521501764_item	2481357	et	4	main
oma	doc_491521501764_item	2481358	et	4	main
sugulaste	doc_491521501764_item	2481359	et	4	main
tapmiseni	doc_491521501764_item	2481360	et	4	main
näidatakse	doc_491521501764_item	2481361	et	3	main
kuidas	doc_491521501764_item	2481362	et	3	main
inimesed	doc_491521501764_item	2481363	et	3	main
on	doc_491521501764_item	2481373	et	4	main
eesti	doc_491521501765_item	2481429	et	4	main
kultuuriloos	doc_491521501765_item	2481430	et	4	main
püsi	doc_491521501765_item	2481448	et	4	main
paremat	doc_491521501765_item	2481457	et	4	main
1970ndate	doc_491521501765_item	2481459	et	4	main
lõpp	doc_491521501765_item	2481460	et	3	main
algus	doc_491521501765_item	2481462	et	4	main
venestuspoliitika	doc_491521501765_item	2481463	et	4	main
läbiviimine	doc_491521501765_item	2481464	et	3	main
1974	doc_491521501765_item	2481465	et	2	main
segalasteaiad	doc_491521501765_item	2481474	et	4	main
et	doc_491521501765_item	2481476	et	3	main
suhelda	doc_491521501765_item	2481480	et	4	main
ehitatakse	doc_491521501765_item	2481490	et	3	main
purjespordikeskus	doc_491521501765_item	2481491	et	3	main
pirita	doc_491521501765_item	2481492	et	4	main
eesti	doc_491521501765_item	2481495	et	4	main
tõesti	doc_491521501765_item	2481523	et	3	main
kultuuril	doc_491521501765_item	2481526	et	3	main
oskasid	doc_491521501765_item	2481544	et	4	main
väike	doc_491521501765_item	2481549	et	4	main
kõrgem	doc_491521501765_item	2481555	et	4	main
kui	doc_491521501765_item	2481556	et	3	main
mis	doc_491521501765_item	2481567	et	4	main
sept	doc_491521501765_item	2481579	et	4	main
1988a	doc_491521501765_item	2481586	et	4	main
üritus	doc_491521501765_item	2481590	et	4	main
laul	doc_491521501765_item	2481592	et	4	main
tuntud	doc_491521501765_item	2481601	et	4	main
au	doc_491521501765_item	2481612	et	4	main
tema	doc_491521501765_item	2481613	et	4	main
oli	doc_491521501765_item	2481614	et	3	main
tema	doc_491521501765_item	2481618	et	4	main
sai	doc_491521501765_item	2481620	et	4	main
kool	doc_491521501765_item	2481621	et	4	main
harrastataksegi	doc_491521501765_item	2481623	et	3	main
pärast	doc_491521501765_item	2481625	et	4	main
suurt	doc_491521501765_item	2481634	et	3	main
mängis	doc_491521501765_item	2481636	et	3	main
kultuuriloos	doc_491521501765_item	2481640	et	4	main
2	doc_491521501765_item	2481641	et	2	main
rahvus	doc_491521501765_item	2481642	et	3	main
tähendab	doc_491521501765_item	2481643	et	3	main
inimeste	doc_491521501765_item	2481644	et	3	main
üks	doc_491521501765_item	2481650	et	3	main
ja	doc_491521501765_item	2481654	et	3	main
objektiivseid	doc_491521501765_item	2481688	et	3	main
ning	doc_491521501765_item	2481690	et	3	main
seal	doc_491521501765_item	2481701	et	4	main
ühiskonda	doc_491521501765_item	2481703	et	4	main
1kultuuritarbimisetunnused	doc_491521501765_item	2481708	et	4	main
teatrid	doc_491521501765_item	2481717	et	3	main
on	doc_491521501764_item	2481312	et	4	main
noorem	doc_491521501764_item	2481313	et	4	main
poeg	doc_491521501764_item	2481314	et	3	main
on	doc_491521501764_item	2481322	et	4	main
mis	doc_491521501764_item	2481326	et	4	main
perioodis	doc_491521501764_item	2481331	et	3	main
eest	doc_491521501764_item	2481338	et	4	main
prof	doc_491521501764_item	2481347	et	4	main
erinevad	doc_491521501764_item	2481352	et	4	main
jäävad	doc_491521501764_item	2481364	et	4	main
on	doc_491521501764_item	2481368	et	4	main
välja	doc_491521501764_item	2481371	et	4	main
tõelised	doc_491521501764_item	2481374	et	4	main
sõbrad	doc_491521501764_item	2481375	et	3	main
ja	doc_491521501764_item	2481376	et	3	main
reeturid	doc_491521501764_item	2481379	et	3	main
1	doc_491521501765_item	2481386	et	2	main
rahva	doc_491521501765_item	2481387	et	3	main
kujutatud	doc_491521501765_item	2481423	et	4	main
kerest	doc_491521501765_item	2481425	et	4	main
1916-1975	doc_491521501765_item	2481426	et	2	main
on	doc_491521501765_item	2481433	et	4	main
loodusvaradega	doc_491521501765_item	2481439	et	3	main
tarbimine	doc_491521501765_item	2481442	et	4	main
ei	doc_491521501765_item	2481447	et	4	main
palju	doc_491521501765_item	2481453	et	4	main
rajatakse	doc_491521501765_item	2481466	et	4	main
eestis	doc_491521501765_item	2481467	et	3	main
lahemere	doc_491521501765_item	2481470	et	3	main
lapsed	doc_491521501765_item	2481478	et	3	main
varem	doc_491521501765_item	2481487	et	4	main
1980a	doc_491521501765_item	2481488	et	4	main
eestis	doc_491521501765_item	2481489	et	3	main
on	doc_491521501765_item	2481494	et	4	main
siin	doc_491521501765_item	2481500	et	4	main
kultuur	doc_491521501765_item	2481521	et	3	main
kuna	doc_491521501765_item	2481525	et	3	main
areneda	doc_491521501765_item	2481530	et	3	main
eestlased	doc_491521501765_item	2481531	et	3	main
samas	doc_491521501765_item	2481533	et	4	main
on	doc_491521501765_item	2481540	et	4	main
maapidamist	doc_491521501765_item	2481545	et	3	main
ideaaliks	doc_491521501765_item	2481547	et	4	main
linna	doc_491521501765_item	2481557	et	4	main
inimestel	doc_491521501765_item	2481558	et	3	main
toetab	doc_491521501765_item	2481568	et	3	main
linnavalitsus	doc_491521501765_item	2481573	et	3	main
sini-must-valget	doc_491521501765_item	2481576	et	3	main
1988a	doc_491521501765_item	2481578	et	4	main
mitu	doc_491521501765_item	2481605	et	4	main
korda	doc_491521501765_item	2481606	et	4	main
eestisse	doc_491521501765_item	2481608	et	4	main
sellega	doc_491521501765_item	2481611	et	3	main
ning	doc_491521501765_item	2481617	et	3	main
maalemiskunsti	doc_491521501765_item	2481624	et	4	main
kui	doc_491521501765_item	2481633	et	3	main
rühma	doc_491521501765_item	2481645	et	4	main
keda	doc_491521501765_item	2481646	et	4	main
ühindab	doc_491521501765_item	2481647	et	4	main
üks	doc_491521501765_item	2481648	et	3	main
keel	doc_491521501765_item	2481649	et	4	main
sakalas	doc_491521501765_item	2481667	et	4	main
1869a	doc_491521501765_item	2481668	et	4	main
ning	doc_491521501765_item	2481669	et	3	main
see	doc_491521501765_item	2481670	et	3	main
muutus	doc_491521501765_item	2481671	et	4	main
igas	doc_491521501765_item	2481680	et	3	main
ähmased	doc_491521501765_item	2481683	et	4	main
võimalik	doc_491521501765_item	2481685	et	3	main
rahvuste	doc_491521501765_item	2481692	et	3	main
ette	doc_491521501765_item	2481698	et	4	main
kommunikatsioon	doc_491521501765_item	2481707	et	3	main
a	doc_491521501765_item	2481709	et	4	main
professionaalse	doc_491521501765_item	2481711	et	3	main
vastu	doc_491521501765_item	2481713	et	3	main
muuseumid	doc_491521501765_item	2481716	et	3	main
küla	doc_491521501765_item	2481720	et	4	main
ausamblite	doc_491521501765_item	2481723	et	4	main
iseseisev	doc_491521501765_item	2481726	et	3	main
c	doc_491521501765_item	2481728	et	4	main
massmeedia	doc_491521501765_item	2481729	et	4	main
toimus	doc_491521501764_item	2481327	et	3	main
raskes	doc_491521501764_item	2481330	et	3	main
muretsevad	doc_491521501764_item	2481333	et	4	main
viia	doc_491521501764_item	2481356	et	3	main
kui	doc_491521501764_item	2481366	et	3	main
kes	doc_491521501764_item	2481377	et	4	main
selline	doc_491521501764_item	2481380	et	4	main
minu	doc_491521501764_item	2481382	et	3	main
mulje	doc_491521501764_item	2481383	et	4	main
kultuuritarbimist	doc_491521501765_item	2481388	et	3	main
iseloomustavad	doc_491521501765_item	2481389	et	4	main
üldised	doc_491521501765_item	2481390	et	3	main
tunnused	doc_491521501765_item	2481391	et	3	main
19701980ndate	doc_491521501765_item	2481392	et	4	main
ii	doc_491521501765_item	2481393	et	4	main
poolel	doc_491521501765_item	2481394	et	4	main
2	doc_491521501765_item	2481395	et	2	main
sõnal	doc_491521501765_item	2481396	et	3	main
rahvus	doc_491521501765_item	2481397	et	3	main
on	doc_491521501765_item	2481398	et	4	main
eesti	doc_491521501765_item	2481399	et	4	main
keeles	doc_491521501765_item	2481400	et	4	main
teistsugune	doc_491521501765_item	2481401	et	3	main
tähendus	doc_491521501765_item	2481402	et	4	main
kui	doc_491521501765_item	2481403	et	3	main
sellel	doc_491521501765_item	2481404	et	4	main
sõnal	doc_491521501765_item	2481405	et	3	main
nation	doc_491521501765_item	2481406	et	4	main
teistes	doc_491521501765_item	2481407	et	4	main
euroopa	doc_491521501765_item	2481408	et	4	main
keeltes	doc_491521501765_item	2481409	et	3	main
kus	doc_491521501765_item	2481410	et	3	main
see	doc_491521501765_item	2481411	et	3	main
on	doc_491521501765_item	2481412	et	4	main
valdavalt	doc_491521501765_item	2481413	et	4	main
seotud	doc_491521501765_item	2481414	et	4	main
riikluse	doc_491521501765_item	2481415	et	4	main
ja	doc_491521501765_item	2481416	et	3	main
kodakondsusega	doc_491521501765_item	2481417	et	3	main
missugune	doc_491521501765_item	2481418	et	3	main
3	doc_491521501765_item	2481419	et	2	main
viiekroonilisel	doc_491521501765_item	2481420	et	4	main
tema	doc_491521501765_item	2481427	et	4	main
on	doc_491521501765_item	2481422	et	4	main
paul	doc_491521501765_item	2481424	et	4	main
roll	doc_491521501765_item	2481428	et	3	main
probleemid	doc_491521501765_item	2481438	et	3	main
nende	doc_491521501765_item	2481441	et	4	main
oli	doc_491521501765_item	2481443	et	3	main
väga	doc_491521501765_item	2481444	et	3	main
intensiivne	doc_491521501765_item	2481445	et	3	main
inimesed	doc_491521501765_item	2481446	et	3	main
kaua	doc_491521501765_item	2481451	et	3	main
otsisid	doc_491521501765_item	2481456	et	4	main
elupaika	doc_491521501765_item	2481458	et	4	main
esimene	doc_491521501765_item	2481468	et	3	main
selleks	doc_491521501765_item	2481475	et	4	main
saaksid	doc_491521501765_item	2481479	et	4	main
aasta	doc_491521501765_item	2481486	et	4	main
riike	doc_491521501765_item	2481498	et	3	main
sest	doc_491521501765_item	2481499	et	4	main
oli	doc_491521501765_item	2481501	et	3	main
väga	doc_491521501765_item	2481502	et	3	main
tihe	doc_491521501765_item	2481503	et	3	main
sõjaväebaaside	doc_491521501765_item	2481504	et	3	main
toimub	doc_491521501765_item	2481506	et	3	main
keskkonna	doc_491521501765_item	2481507	et	3	main
reostusoht	doc_491521501765_item	2481508	et	3	main
fosforväetised	doc_491521501765_item	2481509	et	3	main
fosforiidikaevanduse	doc_491521501765_item	2481510	et	3	main
vastu	doc_491521501765_item	2481511	et	3	main
protesteeriti	doc_491521501765_item	2481512	et	3	main
toidukaupade	doc_491521501765_item	2481513	et	3	main
defitsiit	doc_491521501765_item	2481514	et	3	main
toidu	doc_491521501765_item	2481515	et	3	main
kvaliteet	doc_491521501765_item	2481516	et	3	main
on	doc_491521501765_item	2481517	et	4	main
madal	doc_491521501765_item	2481518	et	3	main
oma	doc_491521501765_item	2481519	et	4	main
eesti	doc_491521501765_item	2481520	et	4	main
peaaegu	doc_491521501765_item	2481528	et	3	main
kuid	doc_491521501765_item	2481532	et	4	main
ilmusid	doc_491521501765_item	2481534	et	4	main
teatrid	doc_491521501765_item	2481535	et	3	main
ja	doc_491521501765_item	2481536	et	3	main
kinod	doc_491521501765_item	2481537	et	3	main
maaelu	doc_491521501765_item	2481538	et	4	main
suuresti	doc_491521501765_item	2481541	et	4	main
maa	doc_491521501765_item	2481551	et	4	main
inimeste	doc_491521501765_item	2481552	et	3	main
palk	doc_491521501765_item	2481553	et	3	main
oli	doc_491521501765_item	2481554	et	3	main
1988a	doc_491521501765_item	2481559	et	4	main
seoses	doc_491521501765_item	2481561	et	4	main
isemajandava	doc_491521501765_item	2481562	et	3	main
eestiga	doc_491521501765_item	2481563	et	4	main
sünnib	doc_491521501765_item	2481564	et	3	main
rahvarinne	doc_491521501765_item	2481565	et	3	main
poliitikat	doc_491521501765_item	2481570	et	3	main
toimub	doc_491521501765_item	2481589	et	3	main
eestimaa	doc_491521501765_item	2481591	et	4	main
tallinna	doc_491521501765_item	2481593	et	4	main
lauluväljakul	doc_491521501765_item	2481594	et	3	main
lauldakse	doc_491521501765_item	2481595	et	3	main
eesti	doc_491521501765_item	2481602	et	4	main
auhindu	doc_491521501765_item	2481609	et	4	main
ja	doc_491521501765_item	2481610	et	3	main
kultuuritegelane	doc_491521501765_item	2481616	et	3	main
nime	doc_491521501765_item	2481619	et	4	main
teda	doc_491521501765_item	2481626	et	4	main
kujundati	doc_491521501765_item	2481627	et	3	main
viiekroonilisel	doc_491521501765_item	2481628	et	4	main
rahatähel	doc_491521501765_item	2481629	et	3	main
rolli	doc_491521501765_item	2481635	et	4	main
paul	doc_491521501765_item	2481637	et	4	main
traditsioonid	doc_491521501765_item	2481653	et	3	main
kohe	doc_491521501765_item	2481672	et	4	main
üldkasutatavaks	doc_491521501765_item	2481673	et	3	main
tavakeele	doc_491521501765_item	2481674	et	4	main
sõnadena	doc_491521501765_item	2481675	et	3	main
keeles	doc_491521501765_item	2481681	et	4	main
üsna	doc_491521501765_item	2481682	et	3	main
pole	doc_491521501765_item	2481684	et	3	main
ühise	doc_491521501765_item	2481694	et	3	main
keeleta	doc_491521501765_item	2481695	et	3	main
tuleb	doc_491521501765_item	2481697	et	3	main
sagedamini	doc_491521501765_item	2481699	et	4	main
eriti	doc_491521501765_item	2481700	et	3	main
kus	doc_491521501765_item	2481702	et	3	main
huvi	doc_491521501765_item	2481710	et	4	main
külastati	doc_491521501765_item	2481714	et	4	main
rohkesti	doc_491521501765_item	2481715	et	3	main
lai	doc_491521501765_item	2481719	et	3	main
levik	doc_491521501765_item	2481724	et	3	main
rolli	doc_491521501765_item	2481730	et	4	main
sügavnemine	doc_491521501765_item	2481734	et	4	main
vastu	doc_491521501765_item	2481738	et	3	main
loodusest	doc_491521501765_item	2481744	et	4	main
elanikud	doc_491521501765_item	2481752	et	3	main
soome	doc_491521501765_item	2481755	et	3	main
mille	doc_491521501765_item	2481757	et	3	main
rahvusluse	doc_491521501765_item	2481774	et	4	main
tegevust	doc_491521501765_item	2481780	et	4	main
tekkimisel	doc_491521501765_item	2481795	et	4	main
obligatoorne	doc_491521501765_item	2481796	et	3	main
rahvuse	doc_491521501765_item	2481802	et	3	main
usku	doc_491521501765_item	2481823	et	4	main
tegemist	doc_491521501765_item	2481830	et	4	main
konfliktiga	doc_491521501765_item	2481832	et	3	main
eri	doc_491521501765_item	2481833	et	4	main
luges	doc_491521501766_item	2481841	et	3	main
semestris	doc_491521501766_item	2481846	et	3	main
2003a	doc_491521501766_item	2481847	et	4	main
arvestustöö	doc_491521501766_item	2481852	et	4	main
prof	doc_491521501766_item	2481854	et	4	main
ära	doc_491521501766_item	2481857	et	4	main
minu	doc_491521501766_item	2481858	et	3	main
iga	doc_491521501766_item	2481870	et	4	main
saanud	doc_491521501766_item	2481900	et	4	main
taotleda	doc_491521501766_item	2481904	et	3	main
2	doc_491521501766_item	2481908	et	2	main
ainepunkte	doc_491521501766_item	2481910	et	3	main
pavlenko	doc_491521501766_item	2481912	et	4	main
lubab	doc_491521501765_item	2481574	et	3	main
pleenum	doc_491521501765_item	2481581	et	3	main
avaldakse	doc_491521501765_item	2481583	et	4	main
toetamist	doc_491521501765_item	2481585	et	4	main
sept	doc_491521501765_item	2481588	et	4	main
paul	doc_491521501765_item	2481598	et	4	main
kerest	doc_491521501765_item	2481599	et	4	main
oli	doc_491521501765_item	2481600	et	3	main
kes	doc_491521501765_item	2481604	et	4	main
tuntud	doc_491521501765_item	2481615	et	4	main
selleks	doc_491521501765_item	2481630	et	4	main
et	doc_491521501765_item	2481631	et	3	main
kerest	doc_491521501765_item	2481638	et	4	main
eesti	doc_491521501765_item	2481639	et	4	main
ühised	doc_491521501765_item	2481652	et	3	main
on	doc_491521501765_item	2481676	et	4	main
rahvas	doc_491521501765_item	2481677	et	4	main
ja	doc_491521501765_item	2481678	et	3	main
tuua	doc_491521501765_item	2481686	et	3	main
määratlemiseks	doc_491521501765_item	2481693	et	4	main
organiseeri	doc_491521501765_item	2481705	et	4	main
kirjakeelne	doc_491521501765_item	2481706	et	3	main
b	doc_491521501765_item	2481718	et	4	main
ja	doc_491521501765_item	2481722	et	3	main
traditsiooniline	doc_491521501765_item	2481725	et	4	main
differentsiooni	doc_491521501765_item	2481733	et	4	main
rohkem	doc_491521501765_item	2481741	et	4	main
mitteeestlased	doc_491521501765_item	2481745	et	3	main
põhja	doc_491521501765_item	2481750	et	4	main
orienteeritud	doc_491521501765_item	2481754	et	4	main
saated	doc_491521501765_item	2481758	et	3	main
maailmatajumist	doc_491521501765_item	2481760	et	3	main
lääne	doc_491521501765_item	2481761	et	4	main
eluviisi	doc_491521501765_item	2481762	et	4	main
kultus	doc_491521501765_item	2481763	et	3	main
2	doc_491521501765_item	2481764	et	2	main
jätkub	doc_491521501765_item	2481765	et	3	main
peetakse	doc_491521501765_item	2481771	et	3	main
ning	doc_491521501765_item	2481775	et	3	main
kas	doc_491521501765_item	2481778	et	3	main
eelmodernsete	doc_491521501765_item	2481788	et	4	main
loomine	doc_491521501765_item	2481803	et	4	main
rahvus	doc_491521501765_item	2481806	et	3	main
seotud	doc_491521501765_item	2481808	et	4	main
ta	doc_491521501765_item	2481810	et	4	main
rahvusi	doc_491521501765_item	2481821	et	3	main
religioonide	doc_491521501765_item	2481834	et	3	main
osakonna	doc_491521501766_item	2481837	et	4	main
avaldus	doc_491521501766_item	2481839	et	4	main
meil	doc_491521501766_item	2481850	et	4	main
mida	doc_491521501766_item	2481860	et	4	main
ma	doc_491521501766_item	2481861	et	3	main
kirjutasin	doc_491521501766_item	2481862	et	3	main
ja	doc_491521501766_item	2481864	et	3	main
telefoninumber	doc_491521501766_item	2481894	et	3	main
korda	doc_491521501766_item	2481896	et	4	main
sellepärast	doc_491521501766_item	2481897	et	3	main
ma	doc_491521501766_item	2481898	et	3	main
ei	doc_491521501766_item	2481899	et	4	main
kus	doc_491521501765_item	2481622	et	3	main
mäletada	doc_491521501765_item	2481632	et	3	main
kultuur	doc_491521501765_item	2481651	et	3	main
seadused	doc_491521501765_item	2481655	et	3	main
see	doc_491521501765_item	2481656	et	3	main
on	doc_491521501765_item	2481657	et	4	main
omane	doc_491521501765_item	2481658	et	3	main
ainult	doc_491521501765_item	2481659	et	4	main
väikestele	doc_491521501765_item	2481660	et	4	main
rahvadele	doc_491521501765_item	2481661	et	4	main
uudissõna	doc_491521501765_item	2481662	et	4	main
rahvus	doc_491521501765_item	2481663	et	3	main
võttis	doc_491521501765_item	2481664	et	3	main
jakobson	doc_491521501765_item	2481665	et	4	main
kasutusele	doc_491521501765_item	2481666	et	4	main
rahvus	doc_491521501765_item	2481679	et	3	main
välja	doc_491521501765_item	2481687	et	4	main
kriteeriume	doc_491521501765_item	2481689	et	3	main
potentsiaalsete	doc_491521501765_item	2481691	et	3	main
etnosi	doc_491521501765_item	2481696	et	4	main
ei	doc_491521501765_item	2481704	et	4	main
loomingu	doc_491521501765_item	2481712	et	3	main
kapellide	doc_491521501765_item	2481721	et	3	main
d	doc_491521501765_item	2481732	et	4	main
eestlaste	doc_491521501765_item	2481735	et	4	main
huvitatud	doc_491521501765_item	2481742	et	4	main
kinost	doc_491521501765_item	2481747	et	3	main
lugemisest	doc_491521501765_item	2481748	et	4	main
e	doc_491521501765_item	2481749	et	4	main
televisioonile	doc_491521501765_item	2481756	et	4	main
olulisimaks	doc_491521501765_item	2481772	et	4	main
rahvuste	doc_491521501765_item	2481776	et	3	main
väljamõtlemisel	doc_491521501765_item	2481782	et	3	main
ja	doc_491521501765_item	2481783	et	3	main
interpreteerimisel	doc_491521501765_item	2481784	et	4	main
sotsiaalmajanduslikke	doc_491521501765_item	2481785	et	3	main
või	doc_491521501765_item	2481787	et	4	main
etnoste	doc_491521501765_item	2481789	et	4	main
tegur	doc_491521501765_item	2481797	et	3	main
rahvusluse	doc_491521501765_item	2481798	et	4	main
eesmärk	doc_491521501765_item	2481799	et	3	main
on	doc_491521501765_item	2481800	et	4	main
rahvuse	doc_491521501765_item	2481825	et	3	main
kõigepealt	doc_491521501765_item	2481827	et	3	main
kui	doc_491521501765_item	2481829	et	3	main
vahel	doc_491521501765_item	2481835	et	4	main
õppejõud	doc_491521501766_item	2481840	et	4	main
lõppus	doc_491521501766_item	2481849	et	4	main
essee	doc_491521501766_item	2481853	et	4	main
eperekonnanimi	doc_491521501766_item	2481855	et	4	main
kaotas	doc_491521501766_item	2481856	et	3	main
1901	doc_491521501766_item	2481863	et	2	main
peaaegu	doc_491521501766_item	2481869	et	3	main
toetuse	doc_491521501766_item	2481902	et	4	main
22042004a	doc_491521501766_item	2481913	et	4	main
täiesti	doc_491521501768_item	2482034	et	3	main
silmadega	doc_491521501768_item	2482036	et	3	main
ma	doc_491521501768_item	2482045	et	3	main
propaganda	doc_491521501768_item	2482059	et	4	main
ja	doc_491521501768_item	2482060	et	3	main
agiteerimine	doc_491521501768_item	2482061	et	4	main
saab	doc_491521501768_item	2482071	et	3	main
elu	doc_491521501768_item	2482076	et	4	main
muutub	doc_491521501768_item	2482078	et	3	main
on	doc_491521501768_item	2482081	et	4	main
tol	doc_491521501768_item	2482082	et	3	main
ajal	doc_491521501768_item	2482083	et	4	main
eestis	doc_491521501768_item	2482087	et	3	main
kogu	doc_491521501768_item	2482090	et	4	main
ilus	doc_491521501768_item	2482096	et	4	main
tõsielule	doc_491521501768_item	2482098	et	3	main
selles	doc_491521501768_item	2482103	et	4	main
selles	doc_491521501768_item	2482125	et	4	main
moodustamine	doc_491521501768_item	2482128	et	4	main
ja	doc_491521501768_item	2482133	et	3	main
neist	doc_491521501768_item	2482135	et	4	main
kunst	doc_491521501765_item	2481727	et	3	main
kasv	doc_491521501765_item	2481731	et	3	main
ja	doc_491521501765_item	2481736	et	3	main
mitteeestlaste	doc_491521501765_item	2481737	et	4	main
on	doc_491521501765_item	2481740	et	4	main
on	doc_491521501765_item	2481753	et	4	main
mõjutasid	doc_491521501765_item	2481759	et	4	main
sellest	doc_491521501765_item	2481769	et	4	main
põhjuseks	doc_491521501765_item	2481773	et	3	main
protsesse	doc_491521501765_item	2481786	et	3	main
ja	doc_491521501765_item	2481804	et	3	main
on	doc_491521501765_item	2481811	et	4	main
poliitiline	doc_491521501765_item	2481812	et	3	main
võim	doc_491521501765_item	2481813	et	3	main
staatiline	doc_491521501765_item	2481814	et	3	main
ja	doc_491521501765_item	2481815	et	3	main
vähe	doc_491521501765_item	2481816	et	3	main
liigendatud	doc_491521501765_item	2481817	et	4	main
agraarimiskord	doc_491521501765_item	2481818	et	4	main
ei	doc_491521501765_item	2481819	et	4	main
vaja	doc_491521501765_item	2481820	et	4	main
eestlased	doc_491521501765_item	2481739	et	3	main
teatridest	doc_491521501765_item	2481743	et	4	main
aga	doc_491521501765_item	2481746	et	3	main
eesti	doc_491521501765_item	2481751	et	4	main
teadlaste	doc_491521501765_item	2481766	et	3	main
definitsioonid	doc_491521501765_item	2481767	et	3	main
sõltuvad	doc_491521501765_item	2481768	et	4	main
mida	doc_491521501765_item	2481770	et	4	main
tekkimisel	doc_491521501765_item	2481777	et	4	main
inimeste	doc_491521501765_item	2481779	et	3	main
ideede	doc_491521501765_item	2481781	et	3	main
olemasolu	doc_491521501765_item	2481790	et	4	main
religioon	doc_491521501765_item	2481791	et	3	main
ei	doc_491521501765_item	2481792	et	4	main
ole	doc_491521501765_item	2481793	et	4	main
rahvuse	doc_491521501765_item	2481794	et	3	main
oma	doc_491521501765_item	2481801	et	4	main
kaitsmine	doc_491521501765_item	2481805	et	4	main
on	doc_491521501765_item	2481807	et	4	main
riigiga	doc_491521501765_item	2481809	et	3	main
oma	doc_491521501765_item	2481822	et	4	main
konstrueerimiseks	doc_491521501765_item	2481826	et	4	main
siis	doc_491521501765_item	2481828	et	3	main
avaldus	doc_491521501766_item	2481836	et	4	main
juhatajale	doc_491521501766_item	2481838	et	4	main
esimeses	doc_491521501766_item	2481845	et	3	main
oli	doc_491521501766_item	2481851	et	3	main
hinnata	doc_491521501766_item	2481868	et	4	main
stipendiumi	doc_491521501766_item	2481901	et	4	main
sest	doc_491521501766_item	2481905	et	4	main
puudus	doc_491521501766_item	2481907	et	4	main
vajalikke	doc_491521501766_item	2481909	et	3	main
alla	doc_491521501766_item	2481911	et	3	main
kasutatakse	doc_491521501765_item	2481824	et	3	main
on	doc_491521501765_item	2481831	et	4	main
meile	doc_491521501766_item	2481842	et	4	main
esteetika	doc_491521501766_item	2481843	et	4	main
kursuse	doc_491521501766_item	2481844	et	3	main
kursuse	doc_491521501766_item	2481848	et	3	main
töö	doc_491521501766_item	2481859	et	4	main
mina	doc_491521501766_item	2481865	et	4	main
jäin	doc_491521501766_item	2481866	et	3	main
ilma	doc_491521501766_item	2481867	et	4	main
kolmapäev	doc_491521501766_item	2481871	et	3	main
ma	doc_491521501766_item	2481872	et	3	main
käen	doc_491521501766_item	2481873	et	4	main
tema	doc_491521501766_item	2481874	et	4	main
juurde	doc_491521501766_item	2481875	et	4	main
ta	doc_491521501766_item	2481876	et	4	main
ütleb	doc_491521501766_item	2481877	et	3	main
et	doc_491521501766_item	2481878	et	3	main
leiab	doc_491521501766_item	2481879	et	3	main
minu	doc_491521501766_item	2481880	et	3	main
tööd	doc_491521501766_item	2481881	et	4	main
ja	doc_491521501766_item	2481882	et	3	main
ma	doc_491521501766_item	2481883	et	3	main
pean	doc_491521501766_item	2481884	et	4	main
järgmisel	doc_491521501766_item	2481885	et	3	main
kolmapäeval	doc_491521501766_item	2481886	et	3	main
tulema	doc_491521501766_item	2481887	et	4	main
ta	doc_491521501766_item	2481888	et	4	main
isegi	doc_491521501766_item	2481889	et	4	main
minu	doc_491521501766_item	2481891	et	3	main
nimi	doc_491521501766_item	2481892	et	3	main
kirjutas	doc_491521501766_item	2481890	et	3	main
ja	doc_491521501766_item	2481893	et	3	main
mitu	doc_491521501766_item	2481895	et	4	main
saamisest	doc_491521501766_item	2481903	et	4	main
mul	doc_491521501766_item	2481906	et	3	main
esse	doc_491521501768_item	2482025	et	3	main
teiste	doc_491521501768_item	2482035	et	4	main
ajal	doc_491521501768_item	2482041	et	4	main
ikkagi	doc_491521501768_item	2482043	et	4	main
mida	doc_491521501768_item	2482044	et	4	main
on	doc_491521501768_item	2482057	et	4	main
nõukogude	doc_491521501768_item	2482058	et	3	main
on	doc_491521501768_item	2482063	et	4	main
kolhoos	doc_491521501768_item	2482072	et	3	main
palju	doc_491521501768_item	2482084	et	4	main
liidus	doc_491521501768_item	2482092	et	4	main
ei	doc_491521501768_item	2482094	et	4	main
abil	doc_491521501768_item	2482109	et	4	main
võib	doc_491521501768_item	2482110	et	3	main
saada	doc_491521501768_item	2482111	et	4	main
ettekujutust	doc_491521501768_item	2482112	et	4	main
tolleaegse	doc_491521501768_item	2482113	et	3	main
elu	doc_491521501768_item	2482114	et	4	main
kuid	doc_491521501768_item	2482117	et	4	main
filmi	doc_491521501768_item	2482033	et	4	main
filmi	doc_491521501768_item	2482039	et	4	main
film	doc_491521501768_item	2482048	et	3	main
pole	doc_491521501768_item	2482049	et	3	main
halb	doc_491521501768_item	2482051	et	3	main
selle	doc_491521501768_item	2482055	et	4	main
eesmärgiks	doc_491521501768_item	2482056	et	3	main
näidatud	doc_491521501768_item	2482064	et	4	main
hea	doc_491521501768_item	2482066	et	4	main
kui	doc_491521501768_item	2482074	et	3	main
filme	doc_491521501768_item	2482080	et	3	main
nii	doc_491521501768_item	2482086	et	3	main
ka	doc_491521501768_item	2482089	et	3	main
nõukogude	doc_491521501768_item	2482091	et	3	main
kahjuks	doc_491521501768_item	2482093	et	4	main
film	doc_491521501768_item	2482099	et	3	main
lavastatud	doc_491521501768_item	2482102	et	4	main
näitlejad	doc_491521501768_item	2482106	et	4	main
filmi	doc_491521501768_item	2482108	et	4	main
eelkõige	doc_491521501768_item	2482115	et	3	main
vaimust	doc_491521501768_item	2482116	et	4	main
situatsioon	doc_491521501768_item	2482122	et	3	main
vastu	doc_491521501768_item	2482130	et	3	main
talupoegade	doc_491521501768_item	2482131	et	3	main
mõned	doc_491521501768_item	2482134	et	3	main
suhtumist	doc_491521501768_item	2482139	et	4	main
koordis	doc_491521501769_item	2482145	et	4	main
inimestevaheliste	doc_491521501769_item	2482150	et	4	main
nii	doc_491521501769_item	2482178	et	3	main
jäänudki	doc_491521501769_item	2482184	et	4	main
suurt	doc_491521501769_item	2482188	et	3	main
meeldi	doc_491521501769_item	2482205	et	4	main
sealt	doc_491521501769_item	2482210	et	4	main
meelde	doc_491521501769_item	2482217	et	3	main
harjumus	doc_491521501769_item	2482220	et	4	main
sisse	doc_491521501769_item	2482229	et	4	main
elada	doc_491521501769_item	2482230	et	3	main
lugenud	doc_491521501769_item	2482241	et	4	main
meeldis	doc_491521501769_item	2482248	et	3	main
paljudest	doc_491521501769_item	2482251	et	3	main
mille	doc_491521501769_item	2482254	et	3	main
samuti	doc_491521501769_item	2482258	et	3	main
kuid	doc_491521501769_item	2482260	et	4	main
milledes	doc_491521501769_item	2482261	et	3	main
tegevused	doc_491521501769_item	2482262	et	4	main
ei	doc_491521501769_item	2482263	et	4	main
rõõmus	doc_491521501769_item	2482294	et	4	main
oli	doc_491521501769_item	2482296	et	3	main
siiski	doc_491521501769_item	2482297	et	4	main
filmi	doc_491521501769_item	2482302	et	4	main
tooksin	doc_491521501769_item	2482305	et	3	main
ajas	doc_491521501769_item	2482308	et	4	main
segadusse	doc_491521501769_item	2482310	et	3	main
asjaolu	doc_491521501769_item	2482311	et	4	main
et	doc_491521501769_item	2482312	et	3	main
filmis	doc_491521501769_item	2482313	et	4	main
sõitsid	doc_491521501769_item	2482323	et	4	main
sinna	doc_491521501769_item	2482331	et	3	main
nimelt	doc_491521501769_item	2482335	et	4	main
semidor	doc_491521501769_item	2482337	et	4	main
esse	doc_491521501768_item	2482026	et	3	main
valgus	doc_491521501768_item	2482028	et	4	main
kui	doc_491521501768_item	2482037	et	3	main
valmimise	doc_491521501768_item	2482040	et	4	main
öelda	doc_491521501768_item	2482047	et	4	main
sugugi	doc_491521501768_item	2482050	et	4	main
on	doc_491521501768_item	2482067	et	4	main
kui	doc_491521501768_item	2482068	et	3	main
tavalisest	doc_491521501768_item	2482069	et	4	main
külast	doc_491521501768_item	2482070	et	4	main
paremaks	doc_491521501768_item	2482075	et	4	main
kohe	doc_491521501768_item	2482077	et	4	main
niisuguseid	doc_491521501768_item	2482079	et	3	main
tehtud	doc_491521501768_item	2482085	et	4	main
ekraanipilt	doc_491521501768_item	2482097	et	3	main
on	doc_491521501768_item	2482100	et	4	main
hästi	doc_491521501768_item	2482101	et	3	main
tuntud	doc_491521501768_item	2482105	et	4	main
selle	doc_491521501768_item	2482107	et	4	main
alati	doc_491521501768_item	2482119	et	4	main
on	doc_491521501768_item	2482123	et	4	main
kolhooside	doc_491521501768_item	2482127	et	3	main
sabotaaži	doc_491521501768_item	2482141	et	2	main
abil	doc_491521501768_item	2482142	et	4	main
on	doc_491521501769_item	2482148	et	4	main
sõjajärgses	doc_491521501769_item	2482155	et	3	main
võrsetest	doc_491521501769_item	2482161	et	3	main
seal	doc_491521501769_item	2482177	et	4	main
ei	doc_491521501769_item	2482183	et	4	main
mulle	doc_491521501769_item	2482185	et	4	main
meelde	doc_491521501769_item	2482190	et	3	main
häbi	doc_491521501769_item	2482192	et	4	main
tunnistada	doc_491521501769_item	2482193	et	3	main
ma	doc_491521501769_item	2482194	et	3	main
eesti	doc_491521501769_item	2482195	et	4	main
filme	doc_491521501769_item	2482196	et	3	main
ei	doc_491521501769_item	2482200	et	4	main
miks-	doc_491521501769_item	2482202	et	4	main
võibolla	doc_491521501769_item	2482203	et	4	main
ei	doc_491521501769_item	2482204	et	4	main
vaatab	doc_491521501769_item	2482212	et	3	main
võibolla	doc_491521501769_item	2482218	et	4	main
võõramaiste	doc_491521501769_item	2482221	et	4	main
seega	doc_491521501769_item	2482223	et	4	main
ka	doc_491521501769_item	2482225	et	3	main
kui	doc_491521501769_item	2482231	et	3	main
mulle	doc_491521501769_item	2482246	et	4	main
väga	doc_491521501769_item	2482247	et	3	main
erinevalt	doc_491521501769_item	2482250	et	4	main
on	doc_491521501769_item	2482256	et	4	main
võetud	doc_491521501769_item	2482257	et	4	main
paljus	doc_491521501769_item	2482265	et	4	main
ja	doc_491521501769_item	2482293	et	3	main
vahel	doc_491521501769_item	2482303	et	4	main
olid	doc_491521501769_item	2482314	et	4	main
paul	doc_491521501769_item	2482315	et	4	main
runge	doc_491521501769_item	2482316	et	3	main
ja	doc_491521501769_item	2482317	et	3	main
filmist	doc_491521501768_item	2482027	et	4	main
koordis	doc_491521501768_item	2482029	et	4	main
muidugi	doc_491521501768_item	2482030	et	4	main
vaatasin	doc_491521501768_item	2482031	et	3	main
seda	doc_491521501768_item	2482032	et	3	main
inimesed	doc_491521501768_item	2482038	et	3	main
kuid	doc_491521501768_item	2482042	et	4	main
võin	doc_491521501768_item	2482046	et	3	main
kuid	doc_491521501768_item	2482052	et	4	main
naiivne	doc_491521501768_item	2482053	et	3	main
ja	doc_491521501768_item	2482054	et	3	main
filmis	doc_491521501768_item	2482062	et	4	main
kui	doc_491521501768_item	2482065	et	3	main
ja	doc_491521501768_item	2482073	et	3	main
kui	doc_491521501768_item	2482088	et	3	main
vastanud	doc_491521501768_item	2482095	et	4	main
mängivad	doc_491521501768_item	2482104	et	4	main
mitte	doc_491521501768_item	2482118	et	3	main
tegelikkusest	doc_491521501768_item	2482120	et	4	main
reaalne	doc_491521501768_item	2482121	et	3	main
et	doc_491521501768_item	2482126	et	3	main
toimuvasse	doc_491521501768_item	2482140	et	4	main
valgus	doc_491521501769_item	2482146	et	4	main
suhete	doc_491521501769_item	2482151	et	3	main
jutustus	doc_491521501769_item	2482158	et	4	main
tundus	doc_491521501769_item	2482176	et	3	main
raskesti	doc_491521501769_item	2482179	et	3	main
midagi	doc_491521501769_item	2482189	et	4	main
ma	doc_491521501769_item	2482199	et	3	main
tea	doc_491521501769_item	2482201	et	4	main
vastu	doc_491521501769_item	2482211	et	3	main
tuletab	doc_491521501769_item	2482214	et	3	main
aga	doc_491521501769_item	2482219	et	3	main
kajastatud	doc_491521501768_item	2482124	et	4	main
läks	doc_491521501768_item	2482129	et	3	main
meelt	doc_491521501768_item	2482132	et	4	main
oma	doc_491521501768_item	2482137	et	4	main
negatiivset	doc_491521501768_item	2482138	et	3	main
valgus	doc_491521501769_item	2482144	et	4	main
jutustus	doc_491521501769_item	2482149	et	4	main
elulaadi	doc_491521501769_item	2482153	et	4	main
elu	doc_491521501769_item	2482160	et	4	main
leberecht	doc_491521501769_item	2482162	et	4	main
196312	doc_491521501769_item	2482163	et	2	main
vaadanud	doc_491521501769_item	2482164	et	4	main
filmi	doc_491521501769_item	2482165	et	4	main
esimest	doc_491521501769_item	2482166	et	4	main
korda	doc_491521501769_item	2482167	et	4	main
ei	doc_491521501769_item	2482168	et	4	main
avaldanud	doc_491521501769_item	2482169	et	4	main
see	doc_491521501769_item	2482170	et	3	main
mulle	doc_491521501769_item	2482171	et	4	main
mingit	doc_491521501769_item	2482172	et	3	main
muljet	doc_491521501769_item	2482173	et	3	main
kuna	doc_491521501769_item	2482174	et	3	main
kõik	doc_491521501769_item	2482175	et	4	main
avaldasid	doc_491521501768_item	2482136	et	4	main
essee	doc_491521501769_item	2482143	et	4	main
koordis	doc_491521501769_item	2482147	et	4	main
ja	doc_491521501769_item	2482152	et	3	main
muutumisest	doc_491521501769_item	2482154	et	4	main
eesti	doc_491521501769_item	2482156	et	4	main
külas	doc_491521501769_item	2482157	et	3	main
uue	doc_491521501769_item	2482159	et	3	main
arusaadav	doc_491521501769_item	2482180	et	4	main
olevat-	doc_491521501769_item	2482181	et	4	main
süzeest	doc_491521501769_item	2482187	et	4	main
üldjuhul	doc_491521501769_item	2482191	et	3	main
vaata	doc_491521501769_item	2482198	et	4	main
mulle	doc_491521501769_item	2482206	et	4	main
see	doc_491521501769_item	2482207	et	3	main
viletsus	doc_491521501769_item	2482208	et	4	main
mis	doc_491521501769_item	2482209	et	4	main
ja	doc_491521501769_item	2482213	et	3	main
minu	doc_491521501769_item	2482215	et	3	main
filmi	doc_491521501769_item	2482227	et	4	main
aga	doc_491521501769_item	2482233	et	3	main
läbi	doc_491521501769_item	2482240	et	4	main
kõik	doc_491521501769_item	2482243	et	4	main
selgemaks	doc_491521501769_item	2482245	et	4	main
filmidest	doc_491521501769_item	2482253	et	3	main
kattu	doc_491521501769_item	2482264	et	4	main
on	doc_491521501769_item	2482266	et	4	main
film	doc_491521501769_item	2482267	et	3	main
paul	doc_491521501769_item	2482289	et	4	main
nägu	doc_491521501769_item	2482295	et	4	main
paar	doc_491521501769_item	2482298	et	3	main
erinevust	doc_491521501769_item	2482299	et	4	main
mille	doc_491521501769_item	2482304	et	3	main
esiteks	doc_491521501769_item	2482307	et	3	main
vao	doc_491521501769_item	2482319	et	3	main
saadeti	doc_491521501769_item	2482330	et	3	main
peeti	doc_491521501769_item	2482341	et	4	main
koori	doc_491521501769_item	2482345	et	4	main
sulitempude	doc_491521501769_item	2482346	et	3	main
maksudest	doc_491521501769_item	2482347	et	3	main
kurvest	doc_491521501769_item	2482372	et	3	main
oli	doc_491521501769_item	2482380	et	3	main
hämmastas	doc_491521501769_item	2482391	et	3	main
tulise	doc_491521501769_item	2482394	et	4	main
stalinliku	doc_491521501769_item	2482395	et	4	main
vene	doc_491521501769_item	2482396	et	4	main
liigitatud-	doc_491521501769_item	2482404	et	4	main
oli	doc_491521501769_item	2482406	et	3	main
selle	doc_491521501769_item	2482415	et	4	main
kolhooside	doc_491521501769_item	2482418	et	3	main
maha	doc_491521501769_item	2482423	et	4	main
olid	doc_491521501769_item	2482442	et	4	main
saksa	doc_491521501769_item	2482443	et	4	main
okupatsiooni	doc_491521501769_item	2482444	et	4	main
kartes	doc_491521501769_item	2482454	et	3	main
redus	doc_491521501769_item	2482459	et	3	main
unistused	doc_491521501769_item	2482483	et	4	main
lootused	doc_491521501769_item	2482484	et	4	main
tuuakse	doc_491521501769_item	2482485	et	3	main
sitkust	doc_491521501769_item	2482498	et	4	main
mingil	doc_491521501769_item	2482499	et	4	main
uusrikaste	doc_491521501769_item	2482502	et	4	main
neile	doc_491521501769_item	2482507	et	4	main
nii	doc_491521501769_item	2482182	et	3	main
filmi	doc_491521501769_item	2482186	et	4	main
ei	doc_491521501769_item	2482197	et	4	main
lapsepõlve	doc_491521501769_item	2482216	et	4	main
olin	doc_491521501769_item	2482232	et	3	main
teist	doc_491521501769_item	2482235	et	4	main
näinud	doc_491521501769_item	2482237	et	4	main
ja	doc_491521501769_item	2482238	et	3	main
raamatugi	doc_491521501769_item	2482239	et	4	main
muutus	doc_491521501769_item	2482242	et	4	main
palju	doc_491521501769_item	2482244	et	4	main
süzee	doc_491521501769_item	2482255	et	4	main
rungegeorg	doc_491521501769_item	2482290	et	4	main
kindlameelne	doc_491521501769_item	2482292	et	3	main
ja	doc_491521501769_item	2482301	et	3	main
need	doc_491521501769_item	2482320	et	3	main
kes	doc_491521501769_item	2482322	et	4	main
raamatus	doc_491521501769_item	2482329	et	4	main
üksainus	doc_491521501769_item	2482333	et	4	main
paul	doc_491521501769_item	2482356	et	4	main
runge	doc_491521501769_item	2482357	et	3	main
võis	doc_491521501769_item	2482360	et	4	main
filmis	doc_491521501769_item	2482363	et	4	main
mitme	doc_491521501769_item	2482367	et	4	main
koor	doc_491521501769_item	2482371	et	4	main
teised	doc_491521501769_item	2482374	et	4	main
olid	doc_491521501769_item	2482376	et	4	main
seal	doc_491521501769_item	2482379	et	4	main
kõigile	doc_491521501769_item	2482383	et	4	main
mind	doc_491521501769_item	2482392	et	4	main
propagandaga	doc_491521501769_item	2482397	et	3	main
seal	doc_491521501769_item	2482398	et	4	main
olid	doc_491521501769_item	2482399	et	4	main
paha	doc_491521501769_item	2482407	et	4	main
kes	doc_491521501769_item	2482409	et	4	main
hea	doc_491521501769_item	2482410	et	4	main
ülistati	doc_491521501769_item	2482411	et	3	main
nõukogude	doc_491521501769_item	2482412	et	3	main
liitu	doc_491521501769_item	2482413	et	4	main
ja	doc_491521501769_item	2482414	et	3	main
rajamist	doc_491521501769_item	2482419	et	4	main
filmidega	doc_491521501769_item	2482222	et	3	main
oli	doc_491521501769_item	2482224	et	3	main
sellesse	doc_491521501769_item	2482226	et	4	main
raske	doc_491521501769_item	2482228	et	4	main
filmi	doc_491521501769_item	2482234	et	4	main
korda	doc_491521501769_item	2482236	et	4	main
et	doc_491521501769_item	2482249	et	3	main
teistest	doc_491521501769_item	2482252	et	4	main
teostest	doc_491521501769_item	2482259	et	3	main
valgus	doc_491521501769_item	2482268	et	4	main
koordis	doc_491521501769_item	2482269	et	4	main
väga	doc_491521501769_item	2482270	et	3	main
sarnane	doc_491521501769_item	2482271	et	4	main
algallikale-	doc_491521501769_item	2482273	et	4	main
hans	doc_491521501769_item	2482274	et	4	main
leberechti	doc_491521501769_item	2482275	et	4	main
samanimelisele	doc_491521501769_item	2482276	et	4	main
teosele	doc_491521501769_item	2482277	et	3	main
lugedes	doc_491521501769_item	2482278	et	3	main
oma	doc_491521501769_item	2482272	et	4	main
raamatut	doc_491521501769_item	2482279	et	3	main
oli	doc_491521501769_item	2482280	et	3	main
mul	doc_491521501769_item	2482281	et	3	main
kogu	doc_491521501769_item	2482282	et	4	main
aeg	doc_491521501769_item	2482283	et	3	main
silme	doc_491521501769_item	2482284	et	4	main
ees	doc_491521501769_item	2482285	et	4	main
filmis	doc_491521501769_item	2482286	et	4	main
toimuv	doc_491521501769_item	2482287	et	4	main
tegevus	doc_491521501769_item	2482288	et	4	main
ots	doc_491521501769_item	2482291	et	3	main
teose	doc_491521501769_item	2482300	et	3	main
välja	doc_491521501769_item	2482306	et	4	main
mind	doc_491521501769_item	2482309	et	4	main
johannes	doc_491521501769_item	2482318	et	4	main
külaelanikud	doc_491521501769_item	2482321	et	3	main
nõukogude	doc_491521501769_item	2482324	et	3	main
liitu	doc_491521501769_item	2482325	et	4	main
vaatama	doc_491521501769_item	2482326	et	3	main
kolhoosi	doc_491521501769_item	2482327	et	4	main
kohust	doc_491521501769_item	2482342	et	3	main
vaid	doc_491521501769_item	2482343	et	3	main
mihkel	doc_491521501769_item	2482344	et	3	main
maja	doc_491521501769_item	2482358	et	4	main
kahtlustad	doc_491521501769_item	2482362	et	3	main
toimus	doc_491521501769_item	2482365	et	3	main
kohus	doc_491521501769_item	2482366	et	4	main
mehe	doc_491521501769_item	2482368	et	3	main
üle	doc_491521501769_item	2482369	et	3	main
samaaegselt-	doc_491521501769_item	2482370	et	4	main
süüpingis	doc_491521501769_item	2482378	et	3	main
moel	doc_491521501769_item	2482382	et	4	main
selge	doc_491521501769_item	2482384	et	4	main
et	doc_491521501769_item	2482385	et	3	main
need	doc_491521501769_item	2482386	et	3	main
mehed	doc_491521501769_item	2482387	et	3	main
hoiavad	doc_491521501769_item	2482388	et	3	main
film	doc_491521501769_item	2482390	et	3	main
ära	doc_491521501769_item	2482403	et	4	main
ja	doc_491521501769_item	2482408	et	3	main
elukorraldust	doc_491521501769_item	2482416	et	3	main
töölisrahvast	doc_491521501769_item	2482417	et	4	main
sakslastega	doc_491521501769_item	2482427	et	3	main
riigiga	doc_491521501769_item	2482431	et	3	main
peast	doc_491521501769_item	2482432	et	4	main
käis	doc_491521501769_item	2482433	et	4	main
kes	doc_491521501769_item	2482441	et	4	main
oma	doc_491521501769_item	2482447	et	4	main
nüüd	doc_491521501769_item	2482451	et	4	main
on	doc_491521501769_item	2482452	et	4	main
karistust	doc_491521501769_item	2482453	et	4	main
hundid	doc_491521501769_item	2482457	et	3	main
paneb	doc_491521501769_item	2482460	et	3	main
väga	doc_491521501769_item	2482476	et	3	main
tuuakse	doc_491521501769_item	2482478	et	3	main
ja	doc_491521501769_item	2482487	et	3	main
eeskujuks	doc_491521501769_item	2482489	et	3	main
raske	doc_491521501769_item	2482491	et	4	main
ja	doc_491521501769_item	2482493	et	3	main
vaev	doc_491521501769_item	2482494	et	3	main
ahnus	doc_491521501769_item	2482513	et	4	main
isoleeritus	doc_491521501769_item	2482515	et	4	main
neid	doc_491521501769_item	2482517	et	4	main
võrreldakse	doc_491521501769_item	2482518	et	3	main
kuid	doc_491521501769_item	2482520	et	4	main
talupoegadega	doc_491521501769_item	2482525	et	3	main
on	doc_491521501769_item	2482527	et	4	main
töökad	doc_491521501769_item	2482528	et	3	main
head	doc_491521501769_item	2482529	et	4	main
ausad	doc_491521501769_item	2482530	et	3	main
siiski-	doc_491521501769_item	2482531	et	4	main
olla	doc_491521501769_item	2482535	et	3	main
väga	doc_491521501769_item	2482546	et	3	main
kuigi	doc_491521501769_item	2482549	et	3	main
elatustaseme	doc_491521501769_item	2482560	et	3	main
suutnud	doc_491521501769_item	2482568	et	4	main
tööga	doc_491521501769_item	2482571	et	3	main
motiveerimaks	doc_491521501769_item	2482581	et	3	main
kolhoose	doc_491521501769_item	2482584	et	3	main
ka	doc_491521501769_item	2482586	et	3	main
ju	doc_491521501769_item	2482598	et	3	main
sealjuures	doc_491521501769_item	2482603	et	3	main
oma	doc_491521501769_item	2482611	et	4	main
kes	doc_491521501769_item	2482619	et	4	main
ja	doc_491521501769_item	2482624	et	3	main
saadi	doc_491521501769_item	2482626	et	4	main
astus	doc_491521501769_item	2482632	et	3	main
elu	doc_491521501769_item	2482328	et	4	main
aga	doc_491521501769_item	2482332	et	3	main
inimene	doc_491521501769_item	2482334	et	3	main
talupoeg	doc_491521501769_item	2482336	et	3	main
kõrvalehiilimise	doc_491521501769_item	2482348	et	3	main
tema	doc_491521501769_item	2482350	et	4	main
aga	doc_491521501769_item	2482364	et	3	main
ja	doc_491521501769_item	2482373	et	3	main
kõik	doc_491521501769_item	2482377	et	4	main
mingil	doc_491521501769_item	2482381	et	4	main
kõik	doc_491521501769_item	2482400	et	4	main
tegelaskujud	doc_491521501769_item	2482401	et	3	main
kes	doc_491521501769_item	2482405	et	4	main
samas	doc_491521501769_item	2482420	et	4	main
tehti	doc_491521501769_item	2482422	et	3	main
mis	doc_491521501769_item	2482425	et	4	main
seotud	doc_491521501769_item	2482426	et	4	main
eesti	doc_491521501769_item	2482430	et	4	main
põlastusväärseistinimestest	doc_491521501769_item	2482438	et	4	main
nagu	doc_491521501769_item	2482456	et	3	main
rahvuskangelased	doc_491521501769_item	2482475	et	3	main
filmis	doc_491521501769_item	2482479	et	4	main
rahva	doc_491521501769_item	2482481	et	3	main
elu-olu	doc_491521501769_item	2482482	et	4	main
seatakse	doc_491521501769_item	2482488	et	4	main
igapäevane	doc_491521501769_item	2482490	et	4	main
määral	doc_491521501769_item	2482500	et	3	main
ja	doc_491521501769_item	2482503	et	3	main
talupoegade	doc_491521501769_item	2482505	et	3	main
märkamatult	doc_491521501769_item	2482521	et	4	main
omada	doc_491521501769_item	2482538	et	3	main
raha	doc_491521501769_item	2482540	et	4	main
küll	doc_491521501769_item	2482545	et	4	main
ning	doc_491521501769_item	2482548	et	3	main
nõukogude	doc_491521501769_item	2482550	et	3	main
pidid	doc_491521501769_item	2482552	et	4	main
kõik	doc_491521501769_item	2482553	et	4	main
siis	doc_491521501769_item	2482558	et	3	main
kõrgema	doc_491521501769_item	2482559	et	4	main
poole	doc_491521501769_item	2482561	et	4	main
need	doc_491521501769_item	2482562	et	3	main
saavutada	doc_491521501769_item	2482569	et	3	main
elu	doc_491521501769_item	2482570	et	4	main
saavutavad	doc_491521501769_item	2482572	et	4	main
selle	doc_491521501769_item	2482573	et	4	main
nii	doc_491521501769_item	2482576	et	3	main
neid	doc_491521501769_item	2482582	et	4	main
sovhoose	doc_491521501769_item	2482587	et	3	main
välja	doc_491521501769_item	2482591	et	4	main
ainult	doc_491521501769_item	2482592	et	4	main
positiivsed	doc_491521501769_item	2482593	et	3	main
küljed	doc_491521501769_item	2482594	et	3	main
kolhooside	doc_491521501769_item	2482595	et	3	main
teame	doc_491521501769_item	2482597	et	3	main
polnud	doc_491521501769_item	2482602	et	3	main
meelakkumine-	doc_491521501769_item	2482604	et	3	main
talupoegadelt	doc_491521501769_item	2482606	et	3	main
karja	doc_491521501769_item	2482612	et	4	main
ära	doc_491521501769_item	2482616	et	4	main
vabatahtlikke	doc_491521501769_item	2482618	et	3	main
polnud	doc_491521501769_item	2482622	et	3	main
palju	doc_491521501769_item	2482623	et	4	main
propaganda	doc_491521501769_item	2482628	et	4	main
talupoegi	doc_491521501769_item	2482631	et	4	main
aga	doc_491521501769_item	2482637	et	3	main
keeldus	doc_491521501769_item	2482638	et	3	main
seda	doc_491521501769_item	2482639	et	3	main
hakkasid	doc_491521501769_item	2482640	et	4	main
tabama	doc_491521501769_item	2482641	et	3	main
repressioonid	doc_491521501769_item	2482642	et	3	main
teiseks-	doc_491521501769_item	2482338	et	4	main
kohus	doc_491521501769_item	2482339	et	4	main
raamatus	doc_491521501769_item	2482340	et	4	main
üle	doc_491521501769_item	2482349	et	3	main
seotust	doc_491521501769_item	2482351	et	4	main
aga	doc_491521501769_item	2482352	et	3	main
robert	doc_491521501769_item	2482353	et	4	main
kurvestiga	doc_491521501769_item	2482354	et	4	main
ja	doc_491521501769_item	2482355	et	3	main
põletamisega	doc_491521501769_item	2482359	et	4	main
üksnes	doc_491521501769_item	2482361	et	3	main
asjamehed	doc_491521501769_item	2482375	et	3	main
ühte	doc_491521501769_item	2482389	et	4	main
oma	doc_491521501769_item	2482393	et	4	main
mustvalgelt	doc_491521501769_item	2482402	et	4	main
aga	doc_491521501769_item	2482421	et	3	main
kõike	doc_491521501769_item	2482424	et	4	main
vaba	doc_491521501769_item	2482429	et	4	main
sakslaste	doc_491521501769_item	2482439	et	3	main
ajal	doc_491521501769_item	2482445	et	4	main
käed	doc_491521501769_item	2482448	et	3	main
vennaverega	doc_491521501769_item	2482449	et	3	main
ja	doc_491521501769_item	2482450	et	3	main
üksikuina	doc_491521501769_item	2482455	et	3	main
metsades	doc_491521501769_item	2482458	et	3	main
ilmekalt	doc_491521501769_item	2482477	et	4	main
välja	doc_491521501769_item	2482480	et	4	main
töö	doc_491521501769_item	2482492	et	4	main
hinnatakse	doc_491521501769_item	2482495	et	4	main
naerdakse	doc_491521501769_item	2482501	et	3	main
jõukate	doc_491521501769_item	2482504	et	4	main
üle	doc_491521501769_item	2482506	et	3	main
sellised	doc_491521501769_item	2482509	et	4	main
iseloomujooned	doc_491521501769_item	2482510	et	3	main
nagu	doc_491521501769_item	2482511	et	3	main
ning	doc_491521501769_item	2482516	et	3	main
sageli	doc_491521501769_item	2482519	et	3	main
ei	doc_491521501769_item	2482533	et	4	main
ja	doc_491521501769_item	2482537	et	3	main
see	doc_491521501769_item	2482541	et	3	main
küsimus	doc_491521501769_item	2482542	et	4	main
kaua	doc_491521501769_item	2482547	et	3	main
ajal	doc_491521501769_item	2482551	et	4	main
ka	doc_491521501769_item	2482557	et	3	main
talupojad	doc_491521501769_item	2482563	et	4	main
kes	doc_491521501769_item	2482564	et	4	main
pole	doc_491521501769_item	2482565	et	3	main
keskpärast	doc_491521501769_item	2482566	et	4	main
kolhoosidesse	doc_491521501769_item	2482574	et	3	main
liitumisega	doc_491521501769_item	2482575	et	4	main
lubasid	doc_491521501769_item	2482577	et	4	main
hiljem	doc_491521501769_item	2482585	et	3	main
tuuakse	doc_491521501769_item	2482590	et	3	main
siiski	doc_491521501769_item	2482599	et	4	main
rahvalt	doc_491521501769_item	2482605	et	3	main
olid	doc_491521501769_item	2482608	et	4	main
harjunud	doc_491521501769_item	2482609	et	4	main
võeti	doc_491521501769_item	2482615	et	3	main
kõik	doc_491521501769_item	2482617	et	4	main
astusid	doc_491521501769_item	2482620	et	4	main
tulemusena	doc_491521501769_item	2482629	et	3	main
lõpuks	doc_491521501769_item	2482644	et	4	main
ja	doc_491521501769_item	2482428	et	3	main
läbi	doc_491521501769_item	2482434	et	4	main
mõte	doc_491521501769_item	2482435	et	3	main
metsavendadest	doc_491521501769_item	2482436	et	3	main
hirmsaist	doc_491521501769_item	2482437	et	3	main
käsilastest	doc_491521501769_item	2482440	et	4	main
määrinud	doc_491521501769_item	2482446	et	4	main
imestama	doc_491521501769_item	2482461	et	3	main
kuivõrd	doc_491521501769_item	2482462	et	3	main
palju	doc_491521501769_item	2482463	et	4	main
on	doc_491521501769_item	2482464	et	4	main
arusaamad	doc_491521501769_item	2482465	et	3	main
tänaseks	doc_491521501769_item	2482466	et	4	main
muutunud-	doc_491521501769_item	2482467	et	4	main
onju	doc_491521501769_item	2482468	et	4	main
vennad	doc_491521501769_item	2482469	et	3	main
voitkad	doc_491521501769_item	2482470	et	4	main
praeguseks	doc_491521501769_item	2482471	et	3	main
vaata	doc_491521501769_item	2482472	et	4	main
et	doc_491521501769_item	2482473	et	3	main
eesti	doc_491521501769_item	2482474	et	4	main
esile	doc_491521501769_item	2482486	et	3	main
sihikindlust	doc_491521501769_item	2482496	et	4	main
ja	doc_491521501769_item	2482497	et	3	main
omistatakse	doc_491521501769_item	2482508	et	3	main
kõrkus	doc_491521501769_item	2482512	et	4	main
valelikkus	doc_491521501769_item	2482514	et	4	main
sulaste	doc_491521501769_item	2482522	et	3	main
kes	doc_491521501769_item	2482532	et	4	main
rikas	doc_491521501769_item	2482536	et	4	main
vaba	doc_491521501769_item	2482539	et	4	main
on	doc_491521501769_item	2482543	et	4	main
püüdleti	doc_491521501769_item	2482556	et	4	main
vene	doc_491521501769_item	2482578	et	4	main
võimud	doc_491521501769_item	2482579	et	3	main
talupoegadele	doc_491521501769_item	2482580	et	3	main
filmis	doc_491521501769_item	2482589	et	4	main
rajamisel	doc_491521501769_item	2482596	et	4	main
kasvatama	doc_491521501769_item	2482610	et	4	main
vilja	doc_491521501769_item	2482614	et	4	main
kolhoosidesse	doc_491521501769_item	2482621	et	3	main
nemadki	doc_491521501769_item	2482625	et	3	main
ja	doc_491521501769_item	2482643	et	3	main
ja	doc_491521501769_item	2482523	et	3	main
vaeste	doc_491521501769_item	2482524	et	4	main
kes	doc_491521501769_item	2482526	et	4	main
tahaks	doc_491521501769_item	2482534	et	3	main
eksisteerinud	doc_491521501769_item	2482544	et	4	main
olema	doc_491521501769_item	2482554	et	4	main
võrdsed	doc_491521501769_item	2482555	et	3	main
elatustaset	doc_491521501769_item	2482567	et	3	main
rajama	doc_491521501769_item	2482583	et	3	main
kuigi	doc_491521501769_item	2482588	et	3	main
et	doc_491521501769_item	2482600	et	3	main
kõik	doc_491521501769_item	2482601	et	4	main
kes	doc_491521501769_item	2482607	et	4	main
ja	doc_491521501769_item	2482613	et	3	main
suure	doc_491521501769_item	2482627	et	3	main
enamus	doc_491521501769_item	2482630	et	4	main
ju	doc_491521501769_item	2482633	et	3	main
sinna	doc_491521501769_item	2482634	et	3	main
sunniviisiselt	doc_491521501769_item	2482635	et	3	main
kes	doc_491521501769_item	2482636	et	4	main
sibergi	doc_491521501769_item	2482645	et	4	main
2000	doc_491521501771_item	2484318	et	2	main
näitab	doc_491521501771_item	2484330	et	3	main
on	doc_491521501771_item	2484333	et	4	main
eesti	doc_491521501771_item	2484336	et	4	main
muistsest	doc_491521501771_item	2484337	et	3	main
seotud	doc_491521501771_item	2484343	et	4	main
aladega	doc_491521501771_item	2484347	et	3	main
inimene	doc_491521501771_item	2484349	et	3	main
pilte	doc_491521501771_item	2484354	et	3	main
sellega	doc_491521501771_item	2484355	et	3	main
mida	doc_491521501771_item	2484356	et	4	main
et	doc_491521501771_item	2484362	et	3	main
varem	doc_491521501771_item	2484372	et	4	main
oli	doc_491521501771_item	2484373	et	3	main
ja	doc_491521501771_item	2484375	et	3	main
palju	doc_491521501771_item	2484380	et	4	main
tunne	doc_491521501771_item	2484387	et	4	main
on	doc_491521501771_item	2484394	et	4	main
näed	doc_491521501771_item	2484400	et	3	main
kuuled	doc_491521501771_item	2484403	et	3	main
väga	doc_491521501771_item	2484408	et	3	main
vaataja	doc_491521501771_item	2484410	et	4	main
satu	doc_491521501771_item	2484412	et	4	main
pedagoogikaülikool	doc_491521501771_item	2484314	et	4	main
filmijärgsed	doc_491521501771_item	2484315	et	3	main
mõtted	doc_491521501771_item	2484316	et	3	main
tallinn	doc_491521501771_item	2484317	et	4	main
essee	doc_491521501771_item	2484312	et	4	main
film	doc_491521501771_item	2484319	et	3	main
tehtud	doc_491521501771_item	2484321	et	4	main
romantilises	doc_491521501771_item	2484323	et	3	main
õhkkonnas	doc_491521501771_item	2484324	et	4	main
seda	doc_491521501771_item	2484331	et	3	main
antud	doc_491521501771_item	2484344	et	4	main
võrdleb	doc_491521501771_item	2484348	et	3	main
järgneb	doc_491521501771_item	2484360	et	3	main
varemetes	doc_491521501771_item	2484364	et	4	main
elav	doc_491521501771_item	2484376	et	4	main
kui	doc_491521501771_item	2484377	et	3	main
filmi	doc_491521501771_item	2484382	et	4	main
väga	doc_491521501771_item	2484385	et	3	main
nood	doc_491521501771_item	2484389	et	3	main
inimesed	doc_491521501771_item	2484390	et	3	main
kedagi	doc_491521501771_item	2484402	et	4	main
positiivne	doc_491521501771_item	2484409	et	3	main
ei	doc_491521501771_item	2484411	et	4	main
ajaloofilmide	doc_491521501771_item	2484419	et	3	main
vaadatavat	doc_491521501771_item	2484428	et	4	main
on	doc_491521501771_item	2484438	et	4	main
kurbus	doc_491521501771_item	2484443	et	4	main
juhtub	doc_491521501771_item	2484447	et	3	main
me	doc_491521501771_item	2484453	et	4	main
elame	doc_491521501771_item	2484455	et	3	main
kas	doc_491521501771_item	2484457	et	3	main
on	doc_491521501771_item	2484459	et	4	main
mingi	doc_491521501771_item	2484460	et	4	main
selles	doc_491521501771_item	2484465	et	4	main
värvikas	doc_491521501771_item	2484468	et	4	main
selleks	doc_491521501771_item	2484474	et	4	main
filmist	doc_491521501771_item	2484476	et	4	main
võõrkeelne	doc_491521501771_item	2484487	et	3	main
arvamus	doc_491521501771_item	2484488	et	3	main
puid	doc_491521501771_item	2484522	et	3	main
liiguvad	doc_491521501771_item	2484527	et	3	main
vaataja	doc_491521501771_item	2484546	et	4	main
äärmiselt	doc_491521501771_item	2484547	et	4	main
enam	doc_491521501771_item	2484556	et	4	main
uus	doc_491521501771_item	2484565	et	3	main
talupoegi	doc_491521501771_item	2484592	et	4	main
iganes	doc_491521501771_item	2484597	et	4	main
kohas	doc_491521501771_item	2484608	et	4	main
sarnaseks	doc_491521501771_item	2484615	et	4	main
filmi	doc_491521501771_item	2484628	et	4	main
essee	doc_491521501772_item	2484632	et	4	main
tsitadellis	doc_491521501772_item	2484634	et	3	main
essee	doc_491521501772_item	2484635	et	4	main
seda	doc_491521501772_item	2484644	et	3	main
mitmel	doc_491521501772_item	2484648	et	4	main
abielluda	doc_491521501772_item	2484650	et	3	main
enesekaitseks	doc_491521501772_item	2484659	et	3	main
et	doc_491521501772_item	2484664	et	3	main
nii	doc_491521501772_item	2484667	et	3	main
oleks	doc_491521501772_item	2484675	et	3	main
ainult	doc_491521501772_item	2484684	et	4	main
saame	doc_491521501772_item	2484688	et	4	main
filmis	doc_491521501772_item	2484691	et	4	main
elu	doc_491521501772_item	2484692	et	4	main
tsitadellis	doc_491521501772_item	2484693	et	3	main
positiivsuse	doc_491521501772_item	2484715	et	4	main
mõõdupuu	doc_491521501772_item	2484718	et	4	main
üles	doc_491521501772_item	2484723	et	3	main
juba	doc_491521501772_item	2484726	et	3	main
esimesena	doc_491521501772_item	2484728	et	3	main
tõsta	doc_491521501772_item	2484731	et	4	main
poole	doc_491521501772_item	2484733	et	4	main
tahetakse	doc_491521501772_item	2484738	et	4	main
kaitseefektile	doc_491521501772_item	2484752	et	3	main
tegelikkuses	doc_491521501772_item	2484764	et	4	main
miilasel	doc_491521501772_item	2484772	et	4	main
külgedest	doc_491521501772_item	2484801	et	4	main
juures	doc_491521501772_item	2484803	et	4	main
vangistus	doc_491521501772_item	2484809	et	4	main
just	doc_491521501772_item	2484811	et	3	main
ei	doc_491521501772_item	2484813	et	4	main
see	doc_491521501772_item	2484815	et	3	main
ahistatuse	doc_491521501772_item	2484821	et	4	main
tallinna	doc_491521501771_item	2484313	et	4	main
on	doc_491521501771_item	2484320	et	4	main
film	doc_491521501771_item	2484329	et	3	main
legende	doc_491521501771_item	2484340	et	3	main
mis	doc_491521501771_item	2484341	et	4	main
on	doc_491521501771_item	2484342	et	4	main
järeldus	doc_491521501771_item	2484361	et	4	main
tühjades	doc_491521501771_item	2484363	et	3	main
on	doc_491521501771_item	2484365	et	4	main
nüüd	doc_491521501771_item	2484366	et	4	main
niivõrd	doc_491521501771_item	2484367	et	3	main
rahulik	doc_491521501771_item	2484368	et	3	main
ja	doc_491521501771_item	2484369	et	3	main
vaikne	doc_491521501771_item	2484370	et	3	main
kuivõrd	doc_491521501771_item	2484371	et	3	main
seal	doc_491521501771_item	2484378	et	4	main
inimesi	doc_491521501771_item	2484381	et	4	main
reaalne	doc_491521501771_item	2484386	et	3	main
elu	doc_491521501771_item	2484392	et	4	main
siin	doc_491521501771_item	2484396	et	4	main
midagi	doc_491521501771_item	2484401	et	4	main
kuna	doc_491521501771_item	2484405	et	3	main
mulje	doc_491521501771_item	2484406	et	4	main
nähtus	doc_491521501771_item	2484418	et	4	main
on	doc_491521501771_item	2484423	et	4	main
romantikaga	doc_491521501771_item	2484425	et	3	main
mõttele	doc_491521501771_item	2484445	et	3	main
kohtade	doc_491521501771_item	2484449	et	3	main
kultuuriline	doc_491521501771_item	2484461	et	4	main
väärtus	doc_491521501771_item	2484462	et	3	main
elav	doc_491521501771_item	2484467	et	4	main
ühest	doc_491521501771_item	2484469	et	4	main
ülevaatamisest	doc_491521501771_item	2484470	et	3	main
aga	doc_491521501771_item	2484472	et	3	main
täiesti	doc_491521501771_item	2484477	et	3	main
soojas	doc_491521501771_item	2484322	et	3	main
mis	doc_491521501771_item	2484325	et	4	main
meelestab	doc_491521501771_item	2484326	et	3	main
vaatajat	doc_491521501771_item	2484327	et	4	main
positiivselt	doc_491521501771_item	2484328	et	4	main
mis	doc_491521501771_item	2484332	et	4	main
saanud	doc_491521501771_item	2484334	et	4	main
mõnest	doc_491521501771_item	2484335	et	3	main
kohast	doc_491521501771_item	2484338	et	4	main
kuulates	doc_491521501771_item	2484339	et	4	main
hoonete	doc_491521501771_item	2484345	et	4	main
oma	doc_491521501771_item	2484351	et	4	main
sellele	doc_491521501771_item	2484359	et	4	main
vaadates	doc_491521501771_item	2484383	et	3	main
äkki	doc_491521501771_item	2484393	et	3	main
et	doc_491521501771_item	2484399	et	3	main
on	doc_491521501771_item	2484407	et	4	main
mis	doc_491521501771_item	2484414	et	4	main
on	doc_491521501771_item	2484415	et	4	main
üsna	doc_491521501771_item	2484416	et	3	main
sagedane	doc_491521501771_item	2484417	et	3	main
ja	doc_491521501771_item	2484346	et	3	main
teadvuslikult	doc_491521501771_item	2484350	et	4	main
kujutluses	doc_491521501771_item	2484352	et	4	main
tekkinud	doc_491521501771_item	2484353	et	4	main
ta	doc_491521501771_item	2484357	et	4	main
näeb	doc_491521501771_item	2484358	et	3	main
mürarikas	doc_491521501771_item	2484374	et	4	main
viibis	doc_491521501771_item	2484379	et	3	main
tekib	doc_491521501771_item	2484384	et	3	main
et	doc_491521501771_item	2484388	et	3	main
too	doc_491521501771_item	2484391	et	4	main
veel	doc_491521501771_item	2484395	et	4	main
kuskil	doc_491521501771_item	2484397	et	3	main
tuntub	doc_491521501771_item	2484398	et	4	main
hääli	doc_491521501771_item	2484404	et	4	main
vaatamise	doc_491521501771_item	2484420	et	4	main
vaid	doc_491521501771_item	2484422	et	3	main
aeg	doc_491521501771_item	2484437	et	3	main
ja	doc_491521501771_item	2484440	et	3	main
paljudega	doc_491521501771_item	2484441	et	3	main
unustutud	doc_491521501771_item	2484442	et	4	main
viib	doc_491521501771_item	2484444	et	3	main
mis	doc_491521501771_item	2484446	et	4	main
nendel	doc_491521501771_item	2484458	et	4	main
on	doc_491521501771_item	2484471	et	4	main
on	doc_491521501771_item	2484484	et	4	main
minu	doc_491521501771_item	2484485	et	3	main
isiklik	doc_491521501771_item	2484486	et	3	main
maju	doc_491521501771_item	2484524	et	3	main
nad	doc_491521501771_item	2484526	et	3	main
on	doc_491521501771_item	2484531	et	4	main
siis	doc_491521501771_item	2484544	et	3	main
sest	doc_491521501771_item	2484549	et	4	main
huvitavuseprintsiip	doc_491521501771_item	2484550	et	4	main
filmi	doc_491521501771_item	2484552	et	4	main
on	doc_491521501771_item	2484558	et	4	main
hästi	doc_491521501771_item	2484559	et	3	main
taastatud	doc_491521501771_item	2484560	et	4	main
õhkkond	doc_491521501771_item	2484563	et	3	main
võivad	doc_491521501771_item	2484594	et	4	main
seda	doc_491521501771_item	2484605	et	3	main
elu	doc_491521501771_item	2484610	et	4	main
või	doc_491521501771_item	2484613	et	4	main
endisega	doc_491521501771_item	2484614	et	3	main
täiendab	doc_491521501771_item	2484617	et	3	main
filmi	doc_491521501771_item	2484618	et	4	main
üldist	doc_491521501771_item	2484619	et	3	main
atmosfääri	doc_491521501771_item	2484620	et	4	main
ja	doc_491521501771_item	2484621	et	3	main
depressiooni	doc_491521501771_item	2484413	et	4	main
puhul	doc_491521501771_item	2484421	et	4	main
hõivatud	doc_491521501771_item	2484424	et	4	main
mis	doc_491521501771_item	2484426	et	4	main
ümbritseb	doc_491521501771_item	2484427	et	3	main
objekti	doc_491521501771_item	2484429	et	4	main
too	doc_491521501771_item	2484436	et	4	main
kadunud	doc_491521501771_item	2484439	et	4	main
ja	doc_491521501771_item	2484450	et	3	main
kus	doc_491521501771_item	2484452	et	3	main
ja	doc_491521501771_item	2484456	et	3	main
filmis	doc_491521501771_item	2484466	et	4	main
vähe	doc_491521501771_item	2484473	et	3	main
et	doc_491521501771_item	2484475	et	3	main
aru	doc_491521501771_item	2484478	et	4	main
saada	doc_491521501771_item	2484479	et	4	main
ja	doc_491521501771_item	2484480	et	3	main
meeles	doc_491521501771_item	2484481	et	3	main
pidada	doc_491521501771_item	2484482	et	4	main
see	doc_491521501771_item	2484483	et	3	main
kiiresti	doc_491521501771_item	2484529	et	3	main
tegemist	doc_491521501771_item	2484532	et	4	main
efektiga	doc_491521501771_item	2484534	et	3	main
kui	doc_491521501771_item	2484535	et	3	main
toimib	doc_491521501771_item	2484551	et	3	main
filmis	doc_491521501771_item	2484557	et	4	main
kaasaegne	doc_491521501771_item	2484566	et	3	main
ajastusse	doc_491521501771_item	2484598	et	4	main
ja	doc_491521501771_item	2484600	et	3	main
vaatega	doc_491521501771_item	2484604	et	3	main
võib	doc_491521501771_item	2484609	et	3	main
terviklikkust	doc_491521501771_item	2484629	et	4	main
midagi	doc_491521501772_item	2484640	et	4	main
püsivat	doc_491521501772_item	2484641	et	4	main
inimene	doc_491521501772_item	2484665	et	3	main
ka	doc_491521501772_item	2484670	et	3	main
kindlustunnet	doc_491521501772_item	2484672	et	3	main
kõige	doc_491521501772_item	2484676	et	4	main
ja	doc_491521501772_item	2484682	et	3	main
vaimset	doc_491521501772_item	2484686	et	3	main
kaitsta	doc_491521501772_item	2484689	et	4	main
kindlusega	doc_491521501772_item	2484690	et	4	main
sõjaolukorrast	doc_491521501772_item	2484701	et	4	main
kõike	doc_491521501772_item	2484713	et	4	main
mõõta	doc_491521501772_item	2484714	et	3	main
ja	doc_491521501772_item	2484716	et	3	main
negatiivsuse	doc_491521501772_item	2484717	et	4	main
järgi	doc_491521501772_item	2484719	et	4	main
kumb	doc_491521501772_item	2484720	et	3	main
kumma	doc_491521501772_item	2484721	et	3	main
headuse	doc_491521501772_item	2484732	et	4	main
et	doc_491521501772_item	2484735	et	3	main
olukorras	doc_491521501772_item	2484737	et	3	main
mõte	doc_491521501772_item	2484745	et	3	main
rajada	doc_491521501772_item	2484747	et	3	main
eriline	doc_491521501772_item	2484749	et	4	main
oleks	doc_491521501772_item	2484753	et	3	main
on	doc_491521501772_item	2484761	et	4	main
kuidas	doc_491521501772_item	2484762	et	3	main
midagi	doc_491521501772_item	2484826	et	4	main
annab	doc_491521501772_item	2484828	et	3	main
peaks	doc_491521501772_item	2484833	et	4	main
sinu	doc_491521501772_item	2484835	et	3	main
mitte	doc_491521501772_item	2484837	et	3	main
elada	doc_491521501772_item	2484851	et	3	main
nagu	doc_491521501772_item	2484852	et	3	main
vastu	doc_491521501772_item	2484869	et	3	main
oma	doc_491521501772_item	2484874	et	4	main
ja	doc_491521501772_item	2484890	et	3	main
maailma	doc_491521501772_item	2484892	et	4	main
see	doc_491521501772_item	2484897	et	3	main
justkui	doc_491521501772_item	2484899	et	3	main
nagu	doc_491521501772_item	2484900	et	3	main
saab	doc_491521501772_item	2484917	et	3	main
tasutud	doc_491521501772_item	2484918	et	4	main
heaga	doc_491521501772_item	2484919	et	3	main
aastal	doc_491521501773_item	2484925	et	3	main
tallinnas	doc_491521501773_item	2484927	et	4	main
meres	doc_491521501773_item	2484948	et	3	main
muutus	doc_491521501773_item	2484954	et	4	main
a	doc_491521501773_item	2484960	et	4	main
tegutsema	doc_491521501773_item	2484962	et	3	main
ajalugu	doc_491521501771_item	2484430	et	4	main
ja	doc_491521501771_item	2484431	et	3	main
tunneb	doc_491521501771_item	2484432	et	3	main
kerget	doc_491521501771_item	2484433	et	4	main
kurbust	doc_491521501771_item	2484434	et	4	main
et	doc_491521501771_item	2484435	et	3	main
nende	doc_491521501771_item	2484448	et	4	main
majadega	doc_491521501771_item	2484451	et	3	main
praegu	doc_491521501771_item	2484454	et	3	main
keel	doc_491521501771_item	2484463	et	4	main
on	doc_491521501771_item	2484464	et	4	main
varjaagid	doc_491521501771_item	2484489	et	3	main
viikingid	doc_491521501771_item	2484490	et	3	main
äärmiselt	doc_491521501771_item	2484491	et	4	main
huvitavad	doc_491521501771_item	2484492	et	4	main
teemad	doc_491521501771_item	2484493	et	3	main
millistel	doc_491521501771_item	2484494	et	3	main
peaks	doc_491521501771_item	2484495	et	4	main
rääkima	doc_491521501771_item	2484496	et	3	main
just	doc_491521501771_item	2484497	et	3	main
samamoodi	doc_491521501771_item	2484498	et	3	main
nagu	doc_491521501771_item	2484499	et	3	main
see	doc_491521501771_item	2484500	et	3	main
on	doc_491521501771_item	2484501	et	4	main
tehtud	doc_491521501771_item	2484502	et	4	main
filmis	doc_491521501771_item	2484503	et	4	main
aga	doc_491521501771_item	2484504	et	3	main
kasvõi	doc_491521501771_item	2484505	et	3	main
natuke	doc_491521501771_item	2484506	et	4	main
aeglasemalt	doc_491521501771_item	2484507	et	4	main
kui	doc_491521501771_item	2484508	et	3	main
istud	doc_491521501771_item	2484509	et	4	main
rongis	doc_491521501771_item	2484510	et	4	main
mis	doc_491521501771_item	2484511	et	4	main
sõidab	doc_491521501771_item	2484512	et	3	main
väga	doc_491521501771_item	2484513	et	3	main
suure	doc_491521501771_item	2484514	et	3	main
kiirusega	doc_491521501771_item	2484515	et	4	main
ja	doc_491521501771_item	2484516	et	3	main
aknast	doc_491521501771_item	2484517	et	4	main
ei	doc_491521501771_item	2484518	et	4	main
ole	doc_491521501771_item	2484519	et	4	main
näha	doc_491521501771_item	2484520	et	3	main
nt	doc_491521501771_item	2484521	et	4	main
ja	doc_491521501771_item	2484523	et	3	main
siis	doc_491521501771_item	2484530	et	3	main
sama	doc_491521501771_item	2484533	et	4	main
räägitakse	doc_491521501771_item	2484536	et	3	main
ibroska	doc_491521501771_item	2484537	et	4	main
kindlusest	doc_491521501771_item	2484538	et	4	main
surmakoridorist	doc_491521501771_item	2484539	et	3	main
sest	doc_491521501771_item	2484525	et	4	main
liiga	doc_491521501771_item	2484528	et	4	main
linnusest	doc_491521501771_item	2484541	et	4	main
kellatornist	doc_491521501771_item	2484543	et	3	main
on	doc_491521501771_item	2484545	et	4	main
tähelepanelik	doc_491521501771_item	2484548	et	4	main
aegade	doc_491521501771_item	2484562	et	3	main
ei	doc_491521501771_item	2484567	et	4	main
häiri	doc_491521501771_item	2484568	et	4	main
mõtteid	doc_491521501771_item	2484569	et	3	main
ja	doc_491521501771_item	2484570	et	3	main
ettekujutusi	doc_491521501771_item	2484571	et	4	main
ole	doc_491521501771_item	2484573	et	4	main
autosid	doc_491521501771_item	2484574	et	3	main
lennuke	doc_491521501771_item	2484575	et	4	main
ei	doc_491521501771_item	2484572	et	4	main
inimesi	doc_491521501771_item	2484576	et	4	main
peaaegu	doc_491521501771_item	2484577	et	3	main
ei	doc_491521501771_item	2484578	et	4	main
ole	doc_491521501771_item	2484579	et	4	main
ka	doc_491521501771_item	2484580	et	3	main
paar	doc_491521501771_item	2484581	et	3	main
inimest	doc_491521501771_item	2484582	et	3	main
keda	doc_491521501771_item	2484583	et	4	main
võib	doc_491521501771_item	2484584	et	3	main
näha	doc_491521501771_item	2484585	et	3	main
juba	doc_491521501771_item	2484586	et	3	main
lõpuosas	doc_491521501771_item	2484588	et	3	main
kujutavad	doc_491521501771_item	2484589	et	4	main
raudsest	doc_491521501771_item	2484540	et	3	main
väravast	doc_491521501771_item	2484542	et	4	main
antud	doc_491521501771_item	2484553	et	4	main
osas	doc_491521501771_item	2484554	et	4	main
kõige	doc_491521501771_item	2484555	et	4	main
muistsete	doc_491521501771_item	2484561	et	3	main
miski	doc_491521501771_item	2484564	et	4	main
kes	doc_491521501771_item	2484593	et	4	main
mis	doc_491521501771_item	2484596	et	4	main
majad	doc_491521501771_item	2484599	et	3	main
hobused	doc_491521501771_item	2484601	et	4	main
oma	doc_491521501771_item	2484603	et	4	main
et	doc_491521501771_item	2484606	et	3	main
jääda	doc_491521501771_item	2484611	et	4	main
arfimuusika	doc_491521501771_item	2484616	et	4	main
meelestab	doc_491521501771_item	2484622	et	3	main
kõik	doc_491521501772_item	2484636	et	4	main
võimalik	doc_491521501772_item	2484646	et	3	main
mehenaisega	doc_491521501772_item	2484652	et	3	main
jne	doc_491521501772_item	2484661	et	4	main
siit	doc_491521501772_item	2484662	et	3	main
vaimset	doc_491521501772_item	2484671	et	3	main
füüsilise	doc_491521501772_item	2484673	et	3	main
kindlus	doc_491521501772_item	2484681	et	4	main
kindlustunnet	doc_491521501772_item	2484687	et	3	main
nii	doc_491521501772_item	2484695	et	3	main
talitatigi	doc_491521501772_item	2484696	et	4	main
filmi	doc_491521501771_item	2484587	et	4	main
endast	doc_491521501771_item	2484590	et	4	main
tüüpilisi	doc_491521501771_item	2484591	et	3	main
kuuluda	doc_491521501771_item	2484595	et	4	main
rõhutavad	doc_491521501771_item	2484602	et	4	main
mõnes	doc_491521501771_item	2484607	et	3	main
endiseks	doc_491521501771_item	2484612	et	3	main
vaatajat	doc_491521501771_item	2484623	et	4	main
mis	doc_491521501771_item	2484625	et	4	main
omakorda	doc_491521501771_item	2484626	et	3	main
tõestab	doc_491521501771_item	2484627	et	3	main
omapära	doc_491521501771_item	2484631	et	4	main
elu	doc_491521501772_item	2484633	et	4	main
on	doc_491521501772_item	2484645	et	4	main
hea	doc_491521501772_item	2484651	et	4	main
omandada	doc_491521501772_item	2484653	et	3	main
relv	doc_491521501772_item	2484660	et	3	main
vajab	doc_491521501772_item	2484666	et	3	main
füüsilist	doc_491521501772_item	2484668	et	3	main
puhul	doc_491521501772_item	2484674	et	4	main
mõttekam	doc_491521501772_item	2484677	et	4	main
rajada	doc_491521501772_item	2484678	et	3	main
enesele	doc_491521501772_item	2484679	et	4	main
mitte	doc_491521501772_item	2484683	et	3	main
täpselt	doc_491521501772_item	2484694	et	4	main
kuid	doc_491521501772_item	2484697	et	4	main
on	doc_491521501772_item	2484698	et	4	main
see	doc_491521501772_item	2484699	et	3	main
väljapääsväljund	doc_491521501772_item	2484700	et	3	main
elu	doc_491521501772_item	2484702	et	4	main
tsitadellis	doc_491521501772_item	2484703	et	3	main
võib	doc_491521501772_item	2484704	et	3	main
olla	doc_491521501772_item	2484705	et	3	main
hea	doc_491521501772_item	2484706	et	4	main
aga	doc_491521501772_item	2484707	et	3	main
ka	doc_491521501772_item	2484708	et	3	main
halb	doc_491521501772_item	2484709	et	3	main
kaalub	doc_491521501772_item	2484724	et	3	main
esile	doc_491521501772_item	2484730	et	3	main
end	doc_491521501772_item	2484739	et	4	main
loogiline	doc_491521501772_item	2484743	et	4	main
pole	doc_491521501772_item	2484748	et	3	main
mõttehiiglus	doc_491521501772_item	2484750	et	4	main
lisaks	doc_491521501772_item	2484751	et	4	main
tema	doc_491521501772_item	2484754	et	4	main
ka	doc_491521501772_item	2484756	et	3	main
veel	doc_491521501772_item	2484757	et	4	main
kindlustamine	doc_491521501772_item	2484759	et	4	main
iseasi	doc_491521501772_item	2484760	et	3	main
see	doc_491521501772_item	2484763	et	3	main
filmist	doc_491521501772_item	2484766	et	4	main
põhjal	doc_491521501772_item	2484768	et	4	main
perekond	doc_491521501772_item	2484771	et	3	main
õnnestus	doc_491521501772_item	2484773	et	4	main
sõna	doc_491521501772_item	2484808	et	4	main
miilase	doc_491521501772_item	2484818	et	4	main
nooremad	doc_491521501772_item	2484819	et	4	main
vastavalt	doc_491521501771_item	2484624	et	4	main
ja	doc_491521501771_item	2484630	et	3	main
me	doc_491521501772_item	2484637	et	4	main
vajame	doc_491521501772_item	2484638	et	3	main
kindlustunnet	doc_491521501772_item	2484639	et	3	main
stabiilset	doc_491521501772_item	2484642	et	3	main
kaitsvat	doc_491521501772_item	2484643	et	4	main
saavutada	doc_491521501772_item	2484647	et	3	main
moel	doc_491521501772_item	2484649	et	4	main
kõrgharidus	doc_491521501772_item	2484654	et	3	main
leidmaks	doc_491521501772_item	2484655	et	4	main
tasuv	doc_491521501772_item	2484656	et	4	main
töökoht	doc_491521501772_item	2484657	et	3	main
muretseda	doc_491521501772_item	2484658	et	3	main
järeldub	doc_491521501772_item	2484663	et	3	main
kui	doc_491521501772_item	2484669	et	3	main
ehk	doc_491521501772_item	2484680	et	3	main
ka	doc_491521501772_item	2484685	et	3	main
alati	doc_491521501772_item	2484710	et	4	main
on	doc_491521501772_item	2484711	et	4	main
võimalik	doc_491521501772_item	2484712	et	3	main
fakt	doc_491521501772_item	2484734	et	3	main
sõja	doc_491521501772_item	2484736	et	3	main
on	doc_491521501772_item	2484741	et	4	main
rolliks	doc_491521501772_item	2484755	et	4	main
puutumatuse	doc_491521501772_item	2484758	et	4	main
õnnestub	doc_491521501772_item	2484765	et	3	main
selgus	doc_491521501772_item	2484769	et	4	main
et	doc_491521501772_item	2484770	et	3	main
negatiivsetest	doc_491521501772_item	2484800	et	3	main
tsitadelli	doc_491521501772_item	2484802	et	4	main
siis	doc_491521501772_item	2484804	et	3	main
esimena	doc_491521501772_item	2484805	et	4	main
tuleb	doc_491521501772_item	2484806	et	3	main
pähe	doc_491521501772_item	2484807	et	4	main
kas	doc_491521501772_item	2484810	et	3	main
see	doc_491521501772_item	2484812	et	3	main
mida	doc_491521501772_item	2484816	et	4	main
tundsid	doc_491521501772_item	2484817	et	4	main
oma	doc_491521501772_item	2484824	et	4	main
kodus	doc_491521501772_item	2484825	et	4	main
teadis	doc_491521501772_item	2484859	et	4	main
mitte	doc_491521501772_item	2484864	et	3	main
karl	doc_491521501772_item	2484865	et	4	main
ka	doc_491521501772_item	2484872	et	3	main
vastu	doc_491521501772_item	2484876	et	3	main
nagu	doc_491521501772_item	2484878	et	3	main
sai	doc_491521501772_item	2484880	et	4	main
pole	doc_491521501772_item	2484888	et	3	main
valitseb	doc_491521501772_item	2484893	et	3	main
hea	doc_491521501772_item	2484905	et	4	main
iga	doc_491521501772_item	2484910	et	4	main
oma	doc_491521501772_item	2484913	et	4	main
palga	doc_491521501772_item	2484914	et	3	main
ka	doc_491521501772_item	2484915	et	3	main
hea	doc_491521501772_item	2484916	et	4	main
eestimaale	doc_491521501773_item	2484921	et	4	main
tartus	doc_491521501773_item	2484929	et	3	main
näha	doc_491521501773_item	2484937	et	3	main
suplust	doc_491521501773_item	2484947	et	3	main
tuli	doc_491521501773_item	2484950	et	4	main
1947	doc_491521501773_item	2484959	et	2	main
hakkab	doc_491521501773_item	2484961	et	3	main
eesti	doc_491521501773_item	2484976	et	4	main
lenfilmi	doc_491521501773_item	2484982	et	4	main
esimene	doc_491521501773_item	2484984	et	3	main
muutuvad	doc_491521501773_item	2485025	et	4	main
otsuste	doc_491521501773_item	2485028	et	4	main
kampaaniatega	doc_491521501773_item	2485030	et	3	main
näidendite	doc_491521501773_item	2485031	et	3	main
teoseid	doc_491521501773_item	2485039	et	3	main
remarkides	doc_491521501773_item	2485055	et	3	main
esimesed	doc_491521501773_item	2485080	et	3	main
tegelevad	doc_491521501773_item	2485084	et	4	main
ja	doc_491521501773_item	2485086	et	3	main
okupatsiooniga	doc_491521501773_item	2485088	et	3	main
mart	doc_491521501773_item	2485089	et	3	main
raua	doc_491521501773_item	2485090	et	3	main
1945	doc_491521501773_item	2485092	et	2	main
1946	doc_491521501773_item	2485096	et	2	main
aja	doc_491521501773_item	2485099	et	4	main
1946	doc_491521501773_item	2485101	et	2	main
jt	doc_491521501773_item	2485102	et	4	main
jakobsoni	doc_491521501773_item	2485103	et	4	main
karjäärile	doc_491521501773_item	2485104	et	3	main
paneb	doc_491521501773_item	2485105	et	3	main
elu	doc_491521501773_item	2485108	et	4	main
sõjajärgseist	doc_491521501773_item	2485113	et	3	main
epp	doc_491521501773_item	2485125	et	4	main
ja	doc_491521501773_item	2485132	et	3	main
vanade	doc_491521501773_item	2485137	et	3	main
professor	doc_491521501773_item	2485139	et	3	main
miilas	doc_491521501773_item	2485141	et	3	main
tuglast	doc_491521501773_item	2485145	et	4	main
sõja	doc_491521501773_item	2485147	et	3	main
eirates	doc_491521501773_item	2485154	et	3	main
aga	doc_491521501772_item	2484722	et	3	main
oleneb	doc_491521501772_item	2484725	et	3	main
mõõtjast	doc_491521501772_item	2484727	et	4	main
tahaksin	doc_491521501772_item	2484729	et	3	main
kaitsta	doc_491521501772_item	2484740	et	4	main
vägagi	doc_491521501772_item	2484742	et	3	main
seepärast	doc_491521501772_item	2484744	et	3	main
tsitadell	doc_491521501772_item	2484746	et	3	main
nähtu	doc_491521501772_item	2484767	et	4	main
viimane	doc_491521501772_item	2484774	et	3	main
edukalt	doc_491521501772_item	2484775	et	4	main
kuid	doc_491521501772_item	2484776	et	4	main
millistel	doc_491521501772_item	2484777	et	3	main
kaalutlustel	doc_491521501772_item	2484778	et	4	main
kas	doc_491521501772_item	2484779	et	3	main
professoristaatuse	doc_491521501772_item	2484780	et	4	main
selgus	doc_491521501772_item	2484782	et	4	main
pärast	doc_491521501772_item	2484781	et	4	main
et	doc_491521501772_item	2484783	et	3	main
hoopis	doc_491521501772_item	2484784	et	3	main
professor	doc_491521501772_item	2484785	et	3	main
miilase	doc_491521501772_item	2484786	et	4	main
reetmist	doc_491521501772_item	2484787	et	4	main
poja	doc_491521501772_item	2484788	et	4	main
pärast	doc_491521501772_item	2484789	et	4	main
see	doc_491521501772_item	2484790	et	3	main
halb	doc_491521501772_item	2484791	et	3	main
tõde	doc_491521501772_item	2484792	et	4	main
varjutas	doc_491521501772_item	2484793	et	3	main
kogu	doc_491521501772_item	2484794	et	4	main
tsitadelli	doc_491521501772_item	2484796	et	4	main
hea	doc_491521501772_item	2484795	et	4	main
juures	doc_491521501772_item	2484797	et	4	main
kui	doc_491521501772_item	2484798	et	3	main
rääkida	doc_491521501772_item	2484799	et	3	main
olnudki	doc_491521501772_item	2484814	et	4	main
lapsed	doc_491521501772_item	2484820	et	3	main
tunne	doc_491521501772_item	2484822	et	4	main
ebameeldivamat	doc_491521501772_item	2484827	et	4	main
välja	doc_491521501772_item	2484830	et	4	main
mõelda	doc_491521501772_item	2484831	et	4	main
olema	doc_491521501772_item	2484834	et	4	main
vangla	doc_491521501772_item	2484838	et	4	main
siiski	doc_491521501772_item	2484839	et	4	main
tuleb	doc_491521501772_item	2484840	et	3	main
pöörduda	doc_491521501772_item	2484841	et	3	main
tagasi	doc_491521501772_item	2484842	et	3	main
asjaolule	doc_491521501772_item	2484843	et	3	main
siis	doc_491521501772_item	2484848	et	3	main
professor	doc_491521501772_item	2484854	et	3	main
poeg	doc_491521501772_item	2484857	et	3	main
karl	doc_491521501772_item	2484858	et	4	main
küsimusele	doc_491521501772_item	2484862	et	4	main
situatsiooni	doc_491521501772_item	2484868	et	4	main
st	doc_491521501772_item	2484871	et	3	main
kurjuse	doc_491521501772_item	2484882	et	4	main
üle	doc_491521501772_item	2484883	et	3	main
võidu	doc_491521501772_item	2484884	et	4	main
mitte	doc_491521501772_item	2484885	et	3	main
halvata	doc_491521501772_item	2484889	et	4	main
lõpuks	doc_491521501772_item	2484907	et	4	main
essee	doc_491521501773_item	2484920	et	4	main
kino	doc_491521501773_item	2484923	et	4	main
mil	doc_491521501773_item	2484926	et	4	main
eestlane	doc_491521501773_item	2484935	et	3	main
sensatsiooni	doc_491521501773_item	2484939	et	4	main
tekitanud	doc_491521501773_item	2484940	et	4	main
elavaid	doc_491521501773_item	2484941	et	4	main
pilte	doc_491521501773_item	2484942	et	3	main
ameerika	doc_491521501773_item	2484943	et	3	main
kiirrongi	doc_491521501773_item	2484944	et	4	main
pariisi	doc_491521501773_item	2484945	et	4	main
laadapalagani	doc_491521501773_item	2484956	et	4	main
üheks	doc_491521501773_item	2484957	et	3	main
aastast	doc_491521501773_item	2484966	et	4	main
nimeks	doc_491521501773_item	2484969	et	3	main
tsitadellis	doc_491521501773_item	2484979	et	3	main
valmib	doc_491521501773_item	2484981	et	3	main
kiitust	doc_491521501773_item	2485018	et	4	main
alles	doc_491521501772_item	2484829	et	3	main
kindlus	doc_491521501772_item	2484836	et	4	main
et	doc_491521501772_item	2484844	et	3	main
oli	doc_491521501772_item	2484845	et	3	main
sõjaolukord	doc_491521501772_item	2484846	et	3	main
kas	doc_491521501772_item	2484847	et	3	main
nende	doc_491521501772_item	2484823	et	4	main
kodu	doc_491521501772_item	2484832	et	4	main
tuleb	doc_491521501772_item	2484850	et	3	main
vangis	doc_491521501772_item	2484853	et	3	main
vastust	doc_491521501772_item	2484860	et	4	main
sellele	doc_491521501772_item	2484861	et	4	main
asus	doc_491521501772_item	2484866	et	4	main
võitlema	doc_491521501772_item	2484870	et	3	main
venna	doc_491521501772_item	2484875	et	3	main
ja	doc_491521501772_item	2484877	et	3	main
ühtki	doc_491521501772_item	2484886	et	4	main
head	doc_491521501772_item	2484887	et	4	main
pandud	doc_491521501772_item	2484903	et	4	main
et	doc_491521501772_item	2484904	et	3	main
kurja	doc_491521501772_item	2484908	et	4	main
kurikael	doc_491521501772_item	2484911	et	4	main
saab	doc_491521501772_item	2484912	et	3	main
1896	doc_491521501773_item	2484924	et	2	main
korraldati	doc_491521501773_item	2484930	et	3	main
avalikke	doc_491521501773_item	2484932	et	3	main
sai	doc_491521501773_item	2484936	et	4	main
maailmas	doc_491521501773_item	2484938	et	3	main
kino	doc_491521501773_item	2484949	et	4	main
ja	doc_491521501773_item	2484951	et	3	main
võitis	doc_491521501773_item	2484952	et	3	main
ta	doc_491521501773_item	2484953	et	4	main
osaks	doc_491521501773_item	2484958	et	3	main
kinostuudio	doc_491521501773_item	2484964	et	4	main
saab	doc_491521501773_item	2484968	et	3	main
samuti	doc_491521501773_item	2484972	et	3	main
elu	doc_491521501773_item	2484978	et	4	main
nõutavate	doc_491521501773_item	2485019	et	4	main
kajastamisega	doc_491521501773_item	2485021	et	4	main
oma	doc_491521501773_item	2485038	et	4	main
arvukas	doc_491521501773_item	2485047	et	4	main
jutustavad	doc_491521501773_item	2485049	et	4	main
arv	doc_491521501773_item	2485071	et	3	main
konflikte	doc_491521501773_item	2485073	et	3	main
väikeste	doc_491521501773_item	2485076	et	4	main
variatsioonidega	doc_491521501773_item	2485077	et	3	main
näidendist	doc_491521501773_item	2485078	et	3	main
näidendid	doc_491521501773_item	2485083	et	3	main
saksa	doc_491521501773_item	2485087	et	4	main
karastus	doc_491521501773_item	2485091	et	4	main
raudsepa	doc_491521501773_item	2485094	et	3	main
1946	doc_491521501773_item	2485110	et	2	main
hiljemgi	doc_491521501773_item	2485121	et	3	main
kaidu	doc_491521501773_item	2485126	et	4	main
see	doc_491521501773_item	2485127	et	3	main
omamoodi	doc_491521501773_item	2485129	et	3	main
väliseid	doc_491521501773_item	2485152	et	4	main
kuid	doc_491521501773_item	2485157	et	4	main
sümboolseks	doc_491521501773_item	2485172	et	3	main
eramut	doc_491521501773_item	2485174	et	3	main
elu	doc_491521501773_item	2485225	et	4	main
ja	doc_491521501773_item	2485228	et	3	main
poega	doc_491521501773_item	2485237	et	4	main
ralf	doc_491521501773_item	2485238	et	4	main
ja	doc_491521501773_item	2485239	et	3	main
nendega	doc_491521501773_item	2485244	et	4	main
elavad	doc_491521501773_item	2485246	et	4	main
professori	doc_491521501773_item	2485248	et	3	main
filmi	doc_491521501773_item	2485274	et	4	main
alguses	doc_491521501773_item	2485275	et	4	main
et	doc_491521501773_item	2485313	et	3	main
aitab	doc_491521501773_item	2485315	et	3	main
tema	doc_491521501773_item	2485317	et	4	main
teadusetöös	doc_491521501773_item	2485318	et	3	main
sest	doc_491521501773_item	2485319	et	4	main
nagu	doc_491521501773_item	2485320	et	3	main
sõjaolukorras	doc_491521501772_item	2484849	et	3	main
miilase	doc_491521501772_item	2484855	et	4	main
noorem	doc_491521501772_item	2484856	et	4	main
loomulikult	doc_491521501772_item	2484863	et	4	main
tekkinud	doc_491521501772_item	2484867	et	4	main
võitlema	doc_491521501772_item	2484873	et	3	main
muinasjuttudeski	doc_491521501772_item	2484879	et	3	main
headus	doc_491521501772_item	2484881	et	4	main
vastupidi	doc_491521501772_item	2484891	et	3	main
alati	doc_491521501772_item	2484894	et	4	main
kakspoolsus	doc_491521501772_item	2484895	et	4	main
aga	doc_491521501772_item	2484896	et	3	main
on	doc_491521501772_item	2484898	et	4	main
seadustega	doc_491521501772_item	2484901	et	3	main
paika	doc_491521501772_item	2484902	et	4	main
kaalub	doc_491521501772_item	2484906	et	3	main
üles	doc_491521501772_item	2484909	et	3	main
jõudis	doc_491521501773_item	2484922	et	3	main
ja	doc_491521501773_item	2484928	et	3	main
esimesi	doc_491521501773_item	2484931	et	4	main
kinoseansse	doc_491521501773_item	2484933	et	3	main
ning	doc_491521501773_item	2484934	et	3	main
tänavapilti	doc_491521501773_item	2484946	et	4	main
aastateks	doc_491521501773_item	2484955	et	4	main
tallinna	doc_491521501773_item	2484963	et	4	main
mis	doc_491521501773_item	2484965	et	4	main
ning	doc_491521501773_item	2484971	et	3	main
valmib	doc_491521501773_item	2484973	et	3	main
sõjajärgne	doc_491521501773_item	2484975	et	3	main
eesti	doc_491521501773_item	2484985	et	4	main
värviline	doc_491521501773_item	2484986	et	4	main
mängufilm	doc_491521501773_item	2484987	et	3	main
valgus	doc_491521501773_item	2484988	et	4	main
koordis	doc_491521501773_item	2484989	et	4	main
hans	doc_491521501773_item	2484990	et	4	main
leberechti	doc_491521501773_item	2484991	et	4	main
romaani	doc_491521501773_item	2484992	et	4	main
põhjal	doc_491521501773_item	2484993	et	4	main
peaosas	doc_491521501773_item	2484994	et	3	main
georg	doc_491521501773_item	2484995	et	4	main
ots	doc_491521501773_item	2484996	et	3	main
jakobsoni	doc_491521501773_item	2484997	et	4	main
näidend	doc_491521501773_item	2484998	et	3	main
elu	doc_491521501773_item	2484999	et	4	main
tsitadellis	doc_491521501773_item	2485000	et	3	main
ja	doc_491521501773_item	2485001	et	3	main
h	doc_491521501773_item	2485002	et	4	main
leberechti	doc_491521501773_item	2485003	et	4	main
jutustus	doc_491521501773_item	2485004	et	4	main
valgus	doc_491521501773_item	2485005	et	4	main
koordis	doc_491521501773_item	2485006	et	4	main
said	doc_491521501773_item	2485007	et	4	main
stalini	doc_491521501773_item	2485008	et	4	main
preemia	doc_491521501773_item	2485009	et	4	main
tolleaegne	doc_491521501773_item	2485010	et	3	main
näitekirjandus	doc_491521501773_item	2485011	et	3	main
on	doc_491521501773_item	2485012	et	4	main
lausa	doc_491521501773_item	2485013	et	4	main
eeskujuandvalt	doc_491521501773_item	2485014	et	4	main
aktuaalne	doc_491521501773_item	2485015	et	3	main
teenides	doc_491521501773_item	2485016	et	3	main
kriitika	doc_491521501773_item	2485017	et	4	main
1963	doc_491521501773_item	2484967	et	2	main
tallinnfilm	doc_491521501773_item	2484970	et	3	main
esimene	doc_491521501773_item	2484974	et	3	main
mängufilm	doc_491521501773_item	2484977	et	3	main
1951a	doc_491521501773_item	2484980	et	4	main
baasil	doc_491521501773_item	2484983	et	3	main
teemade	doc_491521501773_item	2485020	et	4	main
kusjuures	doc_491521501773_item	2485022	et	3	main
rõhuasetused	doc_491521501773_item	2485024	et	3	main
ja	doc_491521501773_item	2485029	et	3	main
poeetika	doc_491521501773_item	2485032	et	4	main
on	doc_491521501773_item	2485033	et	4	main
eepilise	doc_491521501773_item	2485034	et	3	main
ilmega	doc_491521501773_item	2485035	et	3	main
jakobson	doc_491521501773_item	2485036	et	4	main
nimetabki	doc_491521501773_item	2485037	et	3	main
dramaatilisteks	doc_491521501773_item	2485040	et	3	main
on	doc_491521501773_item	2485043	et	4	main
tegevusliinid	doc_491521501773_item	2485046	et	3	main
kommenteerivad	doc_491521501773_item	2485051	et	4	main
teemasid	doc_491521501773_item	2485072	et	3	main
rändab	doc_491521501773_item	2485075	et	3	main
näidendisse	doc_491521501773_item	2485079	et	3	main
sõjasündmuste	doc_491521501773_item	2485085	et	3	main
rotid	doc_491521501773_item	2485095	et	3	main
semperi	doc_491521501773_item	2485098	et	4	main
käsk	doc_491521501773_item	2485100	et	3	main
draama	doc_491521501773_item	2485107	et	4	main
vanemuine	doc_491521501773_item	2485122	et	4	main
ibsenliku	doc_491521501773_item	2485130	et	4	main
marksistliku	doc_491521501773_item	2485133	et	3	main
peategelane	doc_491521501773_item	2485136	et	3	main
keelte	doc_491521501773_item	2485138	et	3	main
august	doc_491521501773_item	2485140	et	4	main
tema	doc_491521501773_item	2485142	et	4	main
prototüübiks	doc_491521501773_item	2485143	et	3	main
sulgub	doc_491521501773_item	2485146	et	3	main
oma	doc_491521501773_item	2485149	et	4	main
võitlusi	doc_491521501773_item	2485153	et	3	main
jookseb	doc_491521501773_item	2485159	et	3	main
ta	doc_491521501773_item	2485161	et	4	main
enese	doc_491521501773_item	2485162	et	4	main
tegevus	doc_491521501773_item	2485180	et	4	main
väikeses	doc_491521501773_item	2485182	et	4	main
elukohas	doc_491521501773_item	2485183	et	4	main
professor	doc_491521501773_item	2485222	et	3	main
kogu	doc_491521501773_item	2485224	et	4	main
huvita	doc_491521501773_item	2485232	et	4	main
karl	doc_491521501773_item	2485240	et	4	main
ja	doc_491521501773_item	2485241	et	3	main
tütar	doc_491521501773_item	2485242	et	3	main
anna	doc_491521501773_item	2485253	et	4	main
ta	doc_491521501773_item	2485266	et	4	main
teenib	doc_491521501773_item	2485267	et	3	main
nõukogude	doc_491521501773_item	2485268	et	3	main
armees	doc_491521501773_item	2485269	et	3	main
seda	doc_491521501773_item	2485270	et	3	main
me	doc_491521501773_item	2485271	et	4	main
saime	doc_491521501773_item	2485272	et	3	main
teada	doc_491521501773_item	2485273	et	3	main
professori	doc_491521501773_item	2485278	et	3	main
professor	doc_491521501773_item	2485321	et	3	main
on	doc_491521501773_item	2485326	et	4	main
pühendanud	doc_491521501773_item	2485327	et	4	main
mille	doc_491521501773_item	2485338	et	3	main
teineteisest	doc_491521501773_item	2485342	et	4	main
kord	doc_491521501773_item	2485345	et	4	main
kohtusid	doc_491521501773_item	2485348	et	4	main
liidia	doc_491521501773_item	2485349	et	4	main
oli	doc_491521501773_item	2485350	et	3	main
väga	doc_491521501773_item	2485351	et	3	main
ja	doc_491521501773_item	2485373	et	3	main
professoril	doc_491521501773_item	2485375	et	3	main
õpilane	doc_491521501773_item	2485387	et	3	main
samuti	doc_491521501773_item	2485399	et	3	main
nõukogude	doc_491521501773_item	2485403	et	3	main
august	doc_491521501773_item	2485410	et	4	main
sest	doc_491521501773_item	2485424	et	4	main
oma	doc_491521501773_item	2485427	et	4	main
peres	doc_491521501773_item	2485439	et	3	main
kõige	doc_491521501773_item	2485443	et	4	main
sünkroonselt	doc_491521501773_item	2485026	et	4	main
proosapärased	doc_491521501773_item	2485053	et	4	main
dramaatilise	doc_491521501773_item	2485057	et	3	main
jutustuse	doc_491521501773_item	2485058	et	4	main
kõrvalt	doc_491521501773_item	2485059	et	4	main
kaob	doc_491521501773_item	2485060	et	3	main
1950-ndateks	doc_491521501773_item	2485061	et	4	main
komöödia	doc_491521501773_item	2485062	et	4	main
žanr	doc_491521501773_item	2485063	et	2	main
sõjajärgne	doc_491521501773_item	2485064	et	3	main
draamakirjandus	doc_491521501773_item	2485065	et	3	main
on	doc_491521501773_item	2485066	et	4	main
võrdlemisi	doc_491521501773_item	2485067	et	4	main
üheülbaline	doc_491521501773_item	2485068	et	3	main
suhteliselt	doc_491521501773_item	2485069	et	4	main
piiratud	doc_491521501773_item	2485070	et	4	main
temaatilised	doc_491521501773_item	2485023	et	4	main
partei	doc_491521501773_item	2485027	et	4	main
jutustusteks	doc_491521501773_item	2485041	et	4	main
iseloomulikud	doc_491521501773_item	2485042	et	3	main
paljud	doc_491521501773_item	2485044	et	3	main
hargnevad	doc_491521501773_item	2485045	et	4	main
tegelaskond	doc_491521501773_item	2485048	et	3	main
ja	doc_491521501773_item	2485050	et	3	main
monoloogid	doc_491521501773_item	2485052	et	4	main
kirjeldused	doc_491521501773_item	2485054	et	4	main
jakobsonliku	doc_491521501773_item	2485056	et	4	main
nõukogude	doc_491521501773_item	2485082	et	3	main
johannes	doc_491521501773_item	2485097	et	4	main
aluse	doc_491521501773_item	2485106	et	4	main
ainus	doc_491521501773_item	2485111	et	4	main
tema	doc_491521501773_item	2485112	et	4	main
näidendeist	doc_491521501773_item	2485114	et	3	main
tüüpe	doc_491521501773_item	2485074	et	3	main
eesti	doc_491521501773_item	2485081	et	4	main
hugo	doc_491521501773_item	2485093	et	4	main
tsitadellis	doc_491521501773_item	2485109	et	3	main
mida	doc_491521501773_item	2485115	et	4	main
kannatas	doc_491521501773_item	2485116	et	3	main
lavale	doc_491521501773_item	2485117	et	3	main
tuua	doc_491521501773_item	2485118	et	3	main
kolmkümmend	doc_491521501773_item	2485119	et	4	main
aastat	doc_491521501773_item	2485120	et	3	main
perekonnadraama	doc_491521501773_item	2485131	et	4	main
ideoloogia	doc_491521501773_item	2485134	et	4	main
amalgaam	doc_491521501773_item	2485135	et	3	main
peeti	doc_491521501773_item	2485144	et	4	main
pühenduda	doc_491521501773_item	2485155	et	3	main
perekonnast	doc_491521501773_item	2485163	et	4	main
nii	doc_491521501773_item	2485164	et	3	main
et	doc_491521501773_item	2485165	et	3	main
professori	doc_491521501773_item	2485166	et	3	main
püüd	doc_491521501773_item	2485167	et	4	main
säilitada	doc_491521501773_item	2485169	et	3	main
läbi	doc_491521501773_item	2485178	et	4	main
tema	doc_491521501773_item	2485218	et	4	main
1976	doc_491521501773_item	2485123	et	2	main
lav	doc_491521501773_item	2485124	et	4	main
on	doc_491521501773_item	2485128	et	4	main
lõpupäevil	doc_491521501773_item	2485148	et	4	main
tsitadelli	doc_491521501773_item	2485150	et	4	main
et	doc_491521501773_item	2485151	et	3	main
rindejoon	doc_491521501773_item	2485158	et	3	main
läbi	doc_491521501773_item	2485160	et	4	main
püüd	doc_491521501773_item	2485168	et	4	main
erapooletus	doc_491521501773_item	2485170	et	4	main
tara	doc_491521501773_item	2485176	et	4	main
filmi	doc_491521501773_item	2485179	et	4	main
kus	doc_491521501773_item	2485184	et	3	main
elab	doc_491521501773_item	2485185	et	3	main
intelligents	doc_491521501773_item	2485186	et	3	main
seal	doc_491521501773_item	2485187	et	4	main
asub	doc_491521501773_item	2485188	et	3	main
üks	doc_491521501773_item	2485189	et	3	main
puumaja	doc_491521501773_item	2485190	et	4	main
mis	doc_491521501773_item	2485191	et	4	main
on	doc_491521501773_item	2485192	et	4	main
ringi	doc_491521501773_item	2485193	et	4	main
kõrge	doc_491521501773_item	2485194	et	4	main
taraga	doc_491521501773_item	2485195	et	3	main
piiratud	doc_491521501773_item	2485196	et	4	main
majas	doc_491521501773_item	2485197	et	3	main
elab	doc_491521501773_item	2485198	et	3	main
professor	doc_491521501773_item	2485199	et	3	main
august	doc_491521501773_item	2485200	et	4	main
miilas	doc_491521501773_item	2485201	et	3	main
oma	doc_491521501773_item	2485202	et	4	main
perega	doc_491521501773_item	2485203	et	3	main
ta	doc_491521501773_item	2485204	et	4	main
kujundas	doc_491521501773_item	2485205	et	3	main
oma	doc_491521501773_item	2485206	et	4	main
maailma	doc_491521501773_item	2485207	et	4	main
milles	doc_491521501773_item	2485208	et	3	main
ta	doc_491521501773_item	2485209	et	4	main
elab	doc_491521501773_item	2485210	et	3	main
oma	doc_491521501773_item	2485211	et	4	main
reeglite	doc_491521501773_item	2485212	et	3	main
järgi	doc_491521501773_item	2485213	et	4	main
ja	doc_491521501773_item	2485214	et	3	main
soovib	doc_491521501773_item	2485215	et	3	main
et	doc_491521501773_item	2485216	et	3	main
vaimutööle	doc_491521501773_item	2485156	et	3	main
luhtub	doc_491521501773_item	2485171	et	3	main
võimendatuna	doc_491521501773_item	2485173	et	4	main
ümbritseva	doc_491521501773_item	2485175	et	4	main
kokkuvarisemise	doc_491521501773_item	2485177	et	3	main
toimub	doc_491521501773_item	2485181	et	3	main
perekonnaliikmed	doc_491521501773_item	2485219	et	3	main
miilas	doc_491521501773_item	2485223	et	3	main
üldse	doc_491521501773_item	2485230	et	3	main
poliitika	doc_491521501773_item	2485233	et	4	main
professoril	doc_491521501773_item	2485234	et	3	main
ja	doc_491521501773_item	2485251	et	3	main
koduabiline	doc_491521501773_item	2485252	et	4	main
guslap	doc_491521501773_item	2485259	et	4	main
rääkinud	doc_491521501773_item	2485263	et	4	main
mitte	doc_491521501773_item	2485264	et	3	main
naabrid	doc_491521501773_item	2485279	et	3	main
kohtumine	doc_491521501773_item	2485337	et	4	main
olid	doc_491521501773_item	2485341	et	4	main
on	doc_491521501773_item	2485358	et	4	main
havatud	doc_491521501773_item	2485370	et	4	main
opereerida	doc_491521501773_item	2485374	et	3	main
ei	doc_491521501773_item	2485376	et	4	main
sõdurite	doc_491521501773_item	2485383	et	3	main
sander	doc_491521501773_item	2485389	et	4	main
opereerib	doc_491521501773_item	2485391	et	3	main
luges	doc_491521501773_item	2485400	et	3	main
selle	doc_491521501773_item	2485408	et	4	main
miilas	doc_491521501773_item	2485411	et	3	main
ka	doc_491521501773_item	2485217	et	3	main
jälgiksid	doc_491521501773_item	2485220	et	4	main
neid	doc_491521501773_item	2485221	et	4	main
teadusega	doc_491521501773_item	2485227	et	3	main
ta	doc_491521501773_item	2485229	et	4	main
ei	doc_491521501773_item	2485231	et	4	main
kaks	doc_491521501773_item	2485236	et	3	main
koos	doc_491521501773_item	2485245	et	4	main
on	doc_491521501773_item	2485255	et	4	main
poeg	doc_491521501773_item	2485256	et	3	main
major	doc_491521501773_item	2485257	et	3	main
ants	doc_491521501773_item	2485258	et	4	main
ta	doc_491521501773_item	2485261	et	4	main
ei	doc_491521501773_item	2485262	et	4	main
kunagi	doc_491521501773_item	2485265	et	3	main
sõjategevuse	doc_491521501773_item	2485276	et	4	main
ralf	doc_491521501773_item	2485314	et	4	main
teadusele	doc_491521501773_item	2485328	et	3	main
guslapi	doc_491521501773_item	2485335	et	4	main
äkiline	doc_491521501773_item	2485336	et	3	main
nad	doc_491521501773_item	2485340	et	3	main
tähelepanulik	doc_491521501773_item	2485352	et	4	main
linnas	doc_491521501773_item	2485355	et	4	main
puhul	doc_491521501773_item	2485357	et	4	main
havatuid	doc_491521501773_item	2485360	et	4	main
paigutada	doc_491521501773_item	2485372	et	3	main
midagi	doc_491521501773_item	2485380	et	4	main
vastu	doc_491521501773_item	2485381	et	3	main
havatud	doc_491521501773_item	2485382	et	4	main
jaan	doc_491521501773_item	2485388	et	3	main
professor	doc_491521501773_item	2485392	et	3	main
kes	doc_491521501773_item	2485394	et	4	main
kuulis	doc_491521501773_item	2485396	et	4	main
prof	doc_491521501773_item	2485397	et	4	main
miilasest	doc_491521501773_item	2485398	et	4	main
vabastas	doc_491521501773_item	2485405	et	3	main
peab	doc_491521501773_item	2485425	et	4	main
ei	doc_491521501773_item	2485440	et	4	main
sõdurit	doc_491521501773_item	2485442	et	3	main
kallim	doc_491521501773_item	2485444	et	4	main
otsustuse	doc_491521501773_item	2485450	et	4	main
pärast	doc_491521501773_item	2485451	et	4	main
liidia	doc_491521501773_item	2485458	et	4	main
otsustab	doc_491521501773_item	2485469	et	3	main
eest	doc_491521501773_item	2485472	et	4	main
palju	doc_491521501773_item	2485504	et	4	main
ei	doc_491521501773_item	2485509	et	4	main
ralfi	doc_491521501773_item	2485514	et	4	main
isa	doc_491521501773_item	2485515	et	4	main
on	doc_491521501773_item	2485520	et	4	main
õiges	doc_491521501773_item	2485531	et	3	main
lõpus	doc_491521501773_item	2485536	et	4	main
miilas	doc_491521501773_item	2485538	et	3	main
aru	doc_491521501773_item	2485540	et	4	main
alati	doc_491521501774_item	2485558	et	4	main
kui	doc_491521501774_item	2485561	et	3	main
ei	doc_491521501774_item	2485588	et	4	main
ja	doc_491521501774_item	2485595	et	3	main
sellepärast	doc_491521501774_item	2485598	et	3	main
uskuda	doc_491521501774_item	2485614	et	3	main
võõrast	doc_491521501774_item	2485615	et	4	main
ja	doc_491521501774_item	2485617	et	3	main
tegeleb	doc_491521501773_item	2485226	et	3	main
on	doc_491521501773_item	2485235	et	4	main
liidia	doc_491521501773_item	2485243	et	4	main
veel	doc_491521501773_item	2485247	et	4	main
naine	doc_491521501773_item	2485249	et	3	main
eva	doc_491521501773_item	2485250	et	4	main
annal	doc_491521501773_item	2485254	et	3	main
kellest	doc_491521501773_item	2485260	et	4	main
puhul	doc_491521501773_item	2485277	et	4	main
on	doc_491521501773_item	2485280	et	4	main
väga	doc_491521501773_item	2485281	et	3	main
erutanud	doc_491521501773_item	2485282	et	4	main
ja	doc_491521501773_item	2485283	et	3	main
nad	doc_491521501773_item	2485284	et	3	main
mõtlevad	doc_491521501773_item	2485285	et	4	main
et	doc_491521501773_item	2485286	et	3	main
oleks	doc_491521501773_item	2485287	et	3	main
parem	doc_491521501773_item	2485288	et	4	main
välismaale	doc_491521501773_item	2485289	et	4	main
kolima	doc_491521501773_item	2485290	et	3	main
professori	doc_491521501773_item	2485291	et	3	main
vanem	doc_491521501773_item	2485292	et	4	main
poeg	doc_491521501773_item	2485293	et	3	main
ralf	doc_491521501773_item	2485294	et	4	main
onupoeg	doc_491521501773_item	2485296	et	3	main
rihard	doc_491521501773_item	2485297	et	4	main
tulevad	doc_491521501773_item	2485298	et	4	main
ja	doc_491521501773_item	2485295	et	3	main
professori	doc_491521501773_item	2485299	et	3	main
külla	doc_491521501773_item	2485300	et	4	main
august	doc_491521501773_item	2485301	et	4	main
miilas	doc_491521501773_item	2485302	et	3	main
on	doc_491521501773_item	2485303	et	4	main
väga	doc_491521501773_item	2485304	et	3	main
rõõm	doc_491521501773_item	2485305	et	3	main
et	doc_491521501773_item	2485306	et	3	main
ralf	doc_491521501773_item	2485307	et	4	main
tuli	doc_491521501773_item	2485308	et	4	main
tema	doc_491521501773_item	2485309	et	4	main
juurde	doc_491521501773_item	2485310	et	4	main
ta	doc_491521501773_item	2485311	et	4	main
loodab	doc_491521501773_item	2485312	et	3	main
teda	doc_491521501773_item	2485316	et	4	main
mõtleb	doc_491521501773_item	2485322	et	3	main
vanem	doc_491521501773_item	2485324	et	4	main
filmi	doc_491521501773_item	2485329	et	4	main
alguses	doc_491521501773_item	2485330	et	4	main
liidia	doc_491521501773_item	2485332	et	4	main
ja	doc_491521501773_item	2485333	et	3	main
iga	doc_491521501773_item	2485344	et	4	main
kui	doc_491521501773_item	2485346	et	3	main
vastu	doc_491521501773_item	2485354	et	3	main
sõdurid	doc_491521501773_item	2485371	et	3	main
ole	doc_491521501773_item	2485377	et	4	main
selle	doc_491521501773_item	2485378	et	4	main
kohta	doc_491521501773_item	2485379	et	4	main
on	doc_491521501773_item	2485385	et	4	main
palju	doc_491521501773_item	2485395	et	4	main
tema	doc_491521501773_item	2485401	et	4	main
saklastest	doc_491521501773_item	2485407	et	4	main
uudise	doc_491521501773_item	2485409	et	3	main
otsustab	doc_491521501773_item	2485421	et	3	main
seda	doc_491521501773_item	2485426	et	3	main
kodanikukohuks	doc_491521501773_item	2485428	et	4	main
tema	doc_491521501773_item	2485430	et	4	main
oli	doc_491521501773_item	2485432	et	3	main
selle	doc_491521501773_item	2485433	et	4	main
vastu	doc_491521501773_item	2485434	et	3	main
ta	doc_491521501773_item	2485435	et	4	main
ütles	doc_491521501773_item	2485436	et	3	main
et	doc_491521501773_item	2485437	et	3	main
nende	doc_491521501773_item	2485438	et	4	main
professori	doc_491521501773_item	2485445	et	3	main
on	doc_491521501773_item	2485447	et	4	main
professor	doc_491521501773_item	2485455	et	3	main
oma	doc_491521501773_item	2485470	et	4	main
eest	doc_491521501773_item	2485503	et	4	main
jaoks	doc_491521501773_item	2485508	et	4	main
sai	doc_491521501773_item	2485516	et	4	main
tema	doc_491521501773_item	2485323	et	4	main
poeg	doc_491521501773_item	2485325	et	3	main
toimub	doc_491521501773_item	2485331	et	3	main
ants	doc_491521501773_item	2485334	et	4	main
pärast	doc_491521501773_item	2485339	et	4	main
huvitanud	doc_491521501773_item	2485343	et	4	main
nad	doc_491521501773_item	2485347	et	3	main
tema	doc_491521501773_item	2485353	et	4	main
sõjategevuse	doc_491521501773_item	2485356	et	4	main
palju	doc_491521501773_item	2485359	et	4	main
liidia	doc_491521501773_item	2485361	et	4	main
küsib	doc_491521501773_item	2485362	et	3	main
isalt	doc_491521501773_item	2485363	et	3	main
lubadust	doc_491521501773_item	2485364	et	4	main
kas	doc_491521501773_item	2485365	et	3	main
on	doc_491521501773_item	2485366	et	4	main
võimalik	doc_491521501773_item	2485367	et	3	main
nendes	doc_491521501773_item	2485368	et	4	main
majas	doc_491521501773_item	2485369	et	3	main
seas	doc_491521501773_item	2485384	et	4	main
professori	doc_491521501773_item	2485386	et	3	main
keda	doc_491521501773_item	2485390	et	4	main
golovin	doc_491521501773_item	2485393	et	4	main
artikleid	doc_491521501773_item	2485402	et	3	main
armee	doc_491521501773_item	2485404	et	4	main
eesti	doc_491521501773_item	2485406	et	4	main
sai	doc_491521501773_item	2485412	et	4	main
teada	doc_491521501773_item	2485413	et	3	main
oma	doc_491521501773_item	2485414	et	4	main
sünnipäeva	doc_491521501773_item	2485415	et	4	main
ajal	doc_491521501773_item	2485416	et	4	main
koos	doc_491521501773_item	2485417	et	4	main
oma	doc_491521501773_item	2485418	et	4	main
külalistega	doc_491521501773_item	2485419	et	4	main
karl	doc_491521501773_item	2485420	et	4	main
minna	doc_491521501773_item	2485423	et	3	main
muidugi	doc_491521501773_item	2485429	et	4	main
isa	doc_491521501773_item	2485431	et	4	main
vabadus	doc_491521501773_item	2485448	et	4	main
karli	doc_491521501773_item	2485449	et	4	main
ja	doc_491521501773_item	2485454	et	3	main
tülitsevad	doc_491521501773_item	2485457	et	4	main
muretseb	doc_491521501773_item	2485459	et	3	main
ta	doc_491521501773_item	2485460	et	4	main
kogu	doc_491521501773_item	2485467	et	4	main
laste	doc_491521501773_item	2485471	et	4	main
kätte	doc_491521501773_item	2485506	et	4	main
midagi	doc_491521501773_item	2485511	et	4	main
et	doc_491521501773_item	2485518	et	3	main
kuritegijad	doc_491521501773_item	2485521	et	3	main
guslap	doc_491521501773_item	2485529	et	4	main
et	doc_491521501773_item	2485541	et	3	main
valik	doc_491521501773_item	2485544	et	3	main
essee	doc_491521501774_item	2485553	et	4	main
elu	doc_491521501774_item	2485554	et	4	main
tsitadellis	doc_491521501774_item	2485555	et	3	main
sõda	doc_491521501774_item	2485556	et	4	main
on	doc_491521501774_item	2485557	et	4	main
isegi	doc_491521501774_item	2485560	et	4	main
me	doc_491521501774_item	2485582	et	4	main
elame	doc_491521501774_item	2485583	et	3	main
ühise	doc_491521501774_item	2485584	et	3	main
maailmas	doc_491521501774_item	2485585	et	3	main
ja	doc_491521501774_item	2485586	et	3	main
keegi	doc_491521501774_item	2485587	et	4	main
sinu	doc_491521501774_item	2485593	et	3	main
me	doc_491521501774_item	2485599	et	4	main
saa	doc_491521501774_item	2485601	et	4	main
olla	doc_491521501774_item	2485602	et	3	main
tuleb	doc_491521501774_item	2485613	et	3	main
inimest	doc_491521501774_item	2485616	et	3	main
ütelda	doc_491521501774_item	2485619	et	4	main
kuigi	doc_491521501774_item	2485622	et	3	main
oli	doc_491521501774_item	2485628	et	3	main
ka	doc_491521501774_item	2485631	et	3	main
sõjaväkke	doc_491521501773_item	2485422	et	3	main
olnud	doc_491521501773_item	2485441	et	4	main
guslap	doc_491521501773_item	2485453	et	4	main
sellest	doc_491521501773_item	2485464	et	4	main
et	doc_491521501773_item	2485465	et	3	main
isa	doc_491521501773_item	2485466	et	4	main
ta	doc_491521501773_item	2485473	et	4	main
mõtleb	doc_491521501773_item	2485474	et	3	main
et	doc_491521501773_item	2485475	et	3	main
tema	doc_491521501773_item	2485476	et	4	main
jaoks	doc_491521501773_item	2485477	et	4	main
on	doc_491521501773_item	2485478	et	4	main
parem	doc_491521501773_item	2485479	et	4	main
tartu	doc_491521501773_item	2485480	et	4	main
ülikooli	doc_491521501773_item	2485481	et	4	main
õppida	doc_491521501773_item	2485482	et	3	main
minna	doc_491521501773_item	2485483	et	3	main
major	doc_491521501773_item	2485484	et	3	main
guslap	doc_491521501773_item	2485485	et	4	main
on	doc_491521501773_item	2485486	et	4	main
nõus	doc_491521501773_item	2485487	et	4	main
temaga	doc_491521501773_item	2485488	et	3	main
ralf	doc_491521501773_item	2485489	et	4	main
ja	doc_491521501773_item	2485490	et	3	main
rihard	doc_491521501773_item	2485491	et	4	main
terve	doc_491521501773_item	2485492	et	4	main
sõja	doc_491521501773_item	2485493	et	3	main
ajal	doc_491521501773_item	2485494	et	4	main
kaasaitasid	doc_491521501773_item	2485495	et	3	main
sakslasi	doc_491521501773_item	2485496	et	3	main
nad	doc_491521501773_item	2485497	et	3	main
varastasid	doc_491521501773_item	2485498	et	4	main
tapsid	doc_491521501773_item	2485499	et	4	main
ja	doc_491521501773_item	2485500	et	3	main
jaoks	doc_491521501773_item	2485446	et	4	main
major	doc_491521501773_item	2485452	et	3	main
miilas	doc_491521501773_item	2485456	et	3	main
on	doc_491521501773_item	2485461	et	4	main
juba	doc_491521501773_item	2485462	et	3	main
tüdinenud	doc_491521501773_item	2485463	et	4	main
aeg	doc_491521501773_item	2485468	et	3	main
raha	doc_491521501773_item	2485505	et	4	main
olnud	doc_491521501773_item	2485510	et	4	main
teada	doc_491521501773_item	2485517	et	3	main
sattus	doc_491521501773_item	2485530	et	3	main
kohas	doc_491521501773_item	2485532	et	4	main
õigel	doc_491521501773_item	2485533	et	3	main
ajal	doc_491521501773_item	2485534	et	4	main
puuduta	doc_491521501774_item	2485564	et	4	main
meid	doc_491521501774_item	2485565	et	4	main
et	doc_491521501774_item	2485581	et	3	main
majja	doc_491521501774_item	2485594	et	3	main
perre	doc_491521501774_item	2485597	et	3	main
ei	doc_491521501774_item	2485600	et	4	main
teiste	doc_491521501774_item	2485603	et	4	main
riikide	doc_491521501774_item	2485604	et	3	main
sündmuste	doc_491521501774_item	2485605	et	3	main
ja	doc_491521501774_item	2485606	et	3	main
isegi	doc_491521501774_item	2485612	et	4	main
on	doc_491521501774_item	2485624	et	4	main
tegema	doc_491521501774_item	2485630	et	3	main
peategelastest	doc_491521501774_item	2485635	et	4	main
ta	doc_491521501774_item	2485643	et	4	main
elas	doc_491521501774_item	2485644	et	3	main
austatud	doc_491521501774_item	2485663	et	4	main
professor	doc_491521501774_item	2485664	et	3	main
kes	doc_491521501774_item	2485665	et	4	main
kogu	doc_491521501774_item	2485666	et	4	main
oma	doc_491521501774_item	2485667	et	4	main
teadusega	doc_491521501774_item	2485672	et	3	main
igasugustest	doc_491521501774_item	2485679	et	3	main
sõja	doc_491521501774_item	2485680	et	3	main
sündmustest	doc_491521501774_item	2485681	et	4	main
eemal	doc_491521501774_item	2485682	et	3	main
lõpus	doc_491521501774_item	2485686	et	4	main
sõjaväelasse	doc_491521501774_item	2485700	et	4	main
katsub	doc_491521501774_item	2485702	et	3	main
teine	doc_491521501774_item	2485707	et	3	main
sõna	doc_491521501774_item	2485716	et	4	main
majas	doc_491521501774_item	2485718	et	3	main
ole	doc_491521501774_item	2485720	et	4	main
enam	doc_491521501774_item	2485721	et	4	main
nii	doc_491521501774_item	2485722	et	3	main
nagu	doc_491521501774_item	2485724	et	3	main
et	doc_491521501774_item	2485737	et	3	main
see	doc_491521501774_item	2485738	et	3	main
on	doc_491521501774_item	2485739	et	4	main
pärast	doc_491521501774_item	2485743	et	4	main
poleks	doc_491521501774_item	2485749	et	3	main
aru	doc_491521501774_item	2485756	et	4	main
et	doc_491521501774_item	2485757	et	3	main
unistused	doc_491521501774_item	2485765	et	4	main
ta	doc_491521501774_item	2485767	et	4	main
pidas	doc_491521501774_item	2485768	et	3	main
rumalaks	doc_491521501774_item	2485769	et	3	main
asjaks	doc_491521501774_item	2485770	et	3	main
ükskord	doc_491521501774_item	2485771	et	3	main
ants	doc_491521501774_item	2485796	et	4	main
kes	doc_491521501774_item	2485797	et	4	main
uut	doc_491521501774_item	2485822	et	3	main
et	doc_491521501774_item	2485832	et	3	main
ole	doc_491521501774_item	2485836	et	4	main
tegevus	doc_491521501774_item	2485841	et	4	main
toimub	doc_491521501774_item	2485842	et	3	main
huvitav	doc_491521501774_item	2485848	et	4	main
on	doc_491521501774_item	2485853	et	4	main
eriti	doc_491521501774_item	2485857	et	3	main
nende	doc_491521501774_item	2485860	et	4	main
tohi	doc_491521501774_item	2485903	et	4	main
tuleb	doc_491521501774_item	2485906	et	3	main
kannatlik	doc_491521501774_item	2485908	et	3	main
lahendada	doc_491521501774_item	2485910	et	3	main
oleks	doc_491521501774_item	2485915	et	3	main
filmis	doc_491521501774_item	2485923	et	4	main
see	doc_491521501774_item	2485925	et	3	main
jaoks	doc_491521501774_item	2485932	et	4	main
said	doc_491521501773_item	2485501	et	4	main
selle	doc_491521501773_item	2485502	et	4	main
nende	doc_491521501773_item	2485507	et	4	main
püha	doc_491521501773_item	2485512	et	4	main
kui	doc_491521501773_item	2485513	et	3	main
nad	doc_491521501773_item	2485519	et	3	main
lihtsalt	doc_491521501773_item	2485523	et	4	main
teda	doc_491521501773_item	2485525	et	4	main
professor	doc_491521501773_item	2485537	et	3	main
tema	doc_491521501773_item	2485542	et	4	main
vabaduse	doc_491521501773_item	2485552	et	4	main
inimesed	doc_491521501774_item	2485575	et	3	main
on	doc_491521501774_item	2485576	et	4	main
tea	doc_491521501774_item	2485589	et	4	main
millal	doc_491521501774_item	2485590	et	3	main
sinu	doc_491521501774_item	2485596	et	3	main
inimeste	doc_491521501774_item	2485607	et	3	main
valu	doc_491521501774_item	2485608	et	4	main
vastu	doc_491521501774_item	2485609	et	3	main
mõnikord	doc_491521501774_item	2485611	et	3	main
oma	doc_491521501774_item	2485620	et	4	main
sugulasetest	doc_491521501774_item	2485621	et	3	main
see	doc_491521501774_item	2485623	et	3	main
nii	doc_491521501774_item	2485627	et	3	main
tsitadellis	doc_491521501774_item	2485638	et	3	main
oma	doc_491521501774_item	2485645	et	4	main
majas	doc_491521501774_item	2485646	et	3	main
kus	doc_491521501774_item	2485647	et	3	main
ta	doc_491521501774_item	2485654	et	4	main
mitte	doc_491521501774_item	2485655	et	3	main
jooksul	doc_491521501774_item	2485669	et	4	main
tegeles	doc_491521501774_item	2485670	et	3	main
ainult	doc_491521501774_item	2485671	et	4	main
ja	doc_491521501774_item	2485673	et	3	main
oma	doc_491521501774_item	2485684	et	4	main
armub	doc_491521501774_item	2485699	et	3	main
lõhutud	doc_491521501774_item	2485714	et	4	main
kõik	doc_491521501774_item	2485726	et	4	main
liigub	doc_491521501774_item	2485727	et	3	main
selle	doc_491521501774_item	2485728	et	4	main
on	doc_491521501774_item	2485736	et	4	main
vabadus	doc_491521501774_item	2485741	et	4	main
üksindus	doc_491521501774_item	2485745	et	3	main
kui	doc_491521501774_item	2485747	et	3	main
elus	doc_491521501774_item	2485758	et	4	main
asju	doc_491521501774_item	2485761	et	3	main
et	doc_491521501774_item	2485764	et	3	main
mida	doc_491521501774_item	2485766	et	4	main
kelle	doc_491521501774_item	2485808	et	4	main
eestit	doc_491521501774_item	2485824	et	3	main
vaatamata	doc_491521501774_item	2485830	et	4	main
selles	doc_491521501774_item	2485833	et	4	main
filmis	doc_491521501774_item	2485834	et	4	main
ja	doc_491521501774_item	2485839	et	3	main
ühes	doc_491521501774_item	2485843	et	4	main
kohas	doc_491521501774_item	2485844	et	4	main
seda	doc_491521501774_item	2485845	et	3	main
sest	doc_491521501774_item	2485850	et	4	main
kõik	doc_491521501774_item	2485851	et	4	main
tegelased	doc_491521501774_item	2485852	et	3	main
on	doc_491521501774_item	2485888	et	4	main
tähtsad	doc_491521501774_item	2485890	et	3	main
asjad	doc_491521501774_item	2485891	et	3	main
ja	doc_491521501774_item	2485892	et	3	main
me	doc_491521501774_item	2485893	et	4	main
teistest	doc_491521501774_item	2485898	et	4	main
inimestest	doc_491521501774_item	2485899	et	3	main
aga	doc_491521501774_item	2485900	et	3	main
samuti	doc_491521501774_item	2485901	et	3	main
ei	doc_491521501774_item	2485902	et	4	main
rahulikult	doc_491521501774_item	2485912	et	4	main
ei	doc_491521501774_item	2485914	et	4	main
unistus	doc_491521501774_item	2485927	et	4	main
iga	doc_491521501774_item	2485930	et	4	main
saavad	doc_491521501774_item	2485937	et	4	main
olema	doc_491521501774_item	2485938	et	4	main
kuna	doc_491521501774_item	2485939	et	3	main
mõnikord	doc_491521501774_item	2485946	et	3	main
väga	doc_491521501774_item	2485955	et	3	main
nad	doc_491521501773_item	2485522	et	3	main
otsustasid	doc_491521501773_item	2485524	et	4	main
tappa	doc_491521501773_item	2485526	et	4	main
aga	doc_491521501773_item	2485527	et	3	main
major	doc_491521501773_item	2485528	et	3	main
filmi	doc_491521501773_item	2485535	et	4	main
saab	doc_491521501773_item	2485539	et	3	main
laste	doc_491521501773_item	2485543	et	4	main
on	doc_491521501773_item	2485545	et	4	main
õige	doc_491521501773_item	2485546	et	4	main
sest	doc_491521501773_item	2485547	et	4	main
just	doc_491521501773_item	2485548	et	3	main
see	doc_491521501773_item	2485549	et	3	main
annab	doc_491521501773_item	2485550	et	3	main
talle	doc_491521501773_item	2485551	et	4	main
tragöödia	doc_491521501774_item	2485559	et	4	main
ta	doc_491521501774_item	2485562	et	4	main
ei	doc_491521501774_item	2485563	et	4	main
isiklikult	doc_491521501774_item	2485566	et	4	main
ka	doc_491521501774_item	2485567	et	3	main
selle	doc_491521501774_item	2485568	et	4	main
sündmused	doc_491521501774_item	2485569	et	3	main
ei	doc_491521501774_item	2485570	et	4	main
lähe	doc_491521501774_item	2485571	et	4	main
meist	doc_491521501774_item	2485572	et	3	main
mööda	doc_491521501774_item	2485573	et	4	main
kõik	doc_491521501774_item	2485574	et	4	main
omavahel	doc_491521501774_item	2485577	et	3	main
seotud	doc_491521501774_item	2485578	et	4	main
kasvõi	doc_491521501774_item	2485579	et	3	main
sellepärast	doc_491521501774_item	2485580	et	3	main
sõda	doc_491521501774_item	2485591	et	4	main
tuleb	doc_491521501774_item	2485592	et	3	main
ükskõiksed	doc_491521501774_item	2485610	et	3	main
lahti	doc_491521501774_item	2485618	et	4	main
raske	doc_491521501774_item	2485626	et	4	main
sunnitud	doc_491521501774_item	2485629	et	4	main
professor	doc_491521501774_item	2485632	et	3	main
filmis	doc_491521501774_item	2485636	et	4	main
kogu	doc_491521501774_item	2485639	et	4	main
elu	doc_491521501774_item	2485641	et	4	main
kõik	doc_491521501774_item	2485648	et	4	main
elasid	doc_491521501774_item	2485649	et	4	main
kunagi	doc_491521501774_item	2485656	et	3	main
mõelnud	doc_491521501774_item	2485658	et	4	main
selle	doc_491521501774_item	2485659	et	4	main
hoidis	doc_491521501774_item	2485674	et	4	main
end	doc_491521501774_item	2485675	et	4	main
ja	doc_491521501774_item	2485676	et	3	main
tuleb	doc_491521501774_item	2485683	et	3	main
elada	doc_491521501774_item	2485688	et	3	main
tema	doc_491521501774_item	2485692	et	4	main
poeg	doc_491521501774_item	2485693	et	3	main
kes	doc_491521501774_item	2485701	et	4	main
poeg	doc_491521501774_item	2485708	et	3	main
koos	doc_491521501774_item	2485710	et	4	main
vaenlastega	doc_491521501774_item	2485711	et	3	main
väljakannatamatult	doc_491521501774_item	2485625	et	4	main
üks	doc_491521501774_item	2485634	et	3	main
miilas	doc_491521501774_item	2485633	et	3	main
oma	doc_491521501774_item	2485640	et	4	main
jooksul	doc_491521501774_item	2485642	et	4	main
tema	doc_491521501774_item	2485650	et	4	main
reeglite	doc_491521501774_item	2485651	et	3	main
peale	doc_491521501774_item	2485660	et	4	main
et	doc_491521501774_item	2485661	et	3	main
tema-	doc_491521501774_item	2485662	et	4	main
elu	doc_491521501774_item	2485668	et	4	main
oma	doc_491521501774_item	2485677	et	4	main
elu	doc_491521501774_item	2485685	et	4	main
kõige	doc_491521501774_item	2485689	et	4	main
hetki	doc_491521501774_item	2485691	et	4	main
karl	doc_491521501774_item	2485694	et	4	main
astub	doc_491521501774_item	2485695	et	3	main
vabadusvõitlejate	doc_491521501774_item	2485696	et	3	main
ridadesse	doc_491521501774_item	2485697	et	3	main
tütar	doc_491521501774_item	2485698	et	3	main
tõestada	doc_491521501774_item	2485703	et	3	main
et	doc_491521501774_item	2485705	et	3	main
on	doc_491521501774_item	2485709	et	4	main
tsitadell	doc_491521501774_item	2485712	et	3	main
on	doc_491521501774_item	2485713	et	4	main
selles	doc_491521501774_item	2485717	et	4	main
ei	doc_491521501774_item	2485719	et	4	main
tunne	doc_491521501774_item	2485735	et	4	main
tuleb	doc_491521501774_item	2485744	et	3	main
täituvad	doc_491521501774_item	2485772	et	4	main
karl	doc_491521501774_item	2485794	et	4	main
silmad	doc_491521501774_item	2485800	et	4	main
ja	doc_491521501774_item	2485807	et	3	main
vaatavad	doc_491521501774_item	2485821	et	4	main
ei	doc_491521501774_item	2485835	et	4	main
vaadata	doc_491521501774_item	2485849	et	4	main
erinevad	doc_491521501774_item	2485854	et	4	main
miilase	doc_491521501774_item	2485865	et	4	main
teadus	doc_491521501774_item	2485870	et	4	main
alati	doc_491521501774_item	2485896	et	4	main
mõelda	doc_491521501774_item	2485897	et	4	main
unustada	doc_491521501774_item	2485904	et	3	main
ja	doc_491521501774_item	2485909	et	3	main
probleeme	doc_491521501774_item	2485911	et	3	main
tüdruk	doc_491521501774_item	2485921	et	3	main
muidugi	doc_491521501774_item	2485924	et	4	main
on	doc_491521501774_item	2485926	et	4	main
inimese	doc_491521501774_item	2485931	et	4	main
sõjad	doc_491521501774_item	2485934	et	3	main
ja	doc_491521501774_item	2485936	et	3	main
ebaõiglus	doc_491521501774_item	2485944	et	4	main
aga	doc_491521501774_item	2485945	et	3	main
täidab	doc_491521501774_item	2485950	et	3	main
see	doc_491521501774_item	2485952	et	3	main
unistus	doc_491521501774_item	2485957	et	4	main
xxxxx	doc_491521501774_item	2485958	et	4	main
xx-xx	doc_491521501774_item	2485960	et	4	main
elu	doc_491521501774_item	2485637	et	4	main
järgi	doc_491521501774_item	2485652	et	4	main
ja	doc_491521501774_item	2485653	et	3	main
pole	doc_491521501774_item	2485657	et	3	main
pere	doc_491521501774_item	2485678	et	4	main
läbi	doc_491521501774_item	2485687	et	4	main
dramaatilisemaid	doc_491521501774_item	2485690	et	4	main
professorile	doc_491521501774_item	2485704	et	3	main
tema	doc_491521501774_item	2485706	et	4	main
tema	doc_491521501774_item	2485715	et	4	main
tähtis	doc_491521501774_item	2485723	et	4	main
enne	doc_491521501774_item	2485725	et	4	main
aga	doc_491521501774_item	2485742	et	3	main
võib-olla	doc_491521501774_item	2485751	et	3	main
siis	doc_491521501774_item	2485753	et	3	main
teisi	doc_491521501774_item	2485760	et	4	main
peale	doc_491521501774_item	2485762	et	4	main
poeg	doc_491521501774_item	2485793	et	3	main
ja	doc_491521501774_item	2485795	et	3	main
lahti	doc_491521501774_item	2485801	et	4	main
et	doc_491521501774_item	2485802	et	3	main
ralf	doc_491521501774_item	2485803	et	4	main
oli	doc_491521501774_item	2485804	et	3	main
sakslastega	doc_491521501774_item	2485805	et	3	main
tõttu	doc_491521501774_item	2485809	et	4	main
nüüd	doc_491521501774_item	2485814	et	4	main
aga	doc_491521501774_item	2485815	et	3	main
seisavad	doc_491521501774_item	2485816	et	3	main
nad	doc_491521501774_item	2485817	et	3	main
akna	doc_491521501774_item	2485818	et	3	main
ees	doc_491521501774_item	2485819	et	4	main
ja	doc_491521501774_item	2485820	et	3	main
poole	doc_491521501774_item	2485729	et	4	main
et	doc_491521501774_item	2485730	et	3	main
ta	doc_491521501774_item	2485731	et	4	main
jääb	doc_491521501774_item	2485732	et	3	main
üksi	doc_491521501774_item	2485733	et	4	main
esimene	doc_491521501774_item	2485734	et	3	main
tõeline	doc_491521501774_item	2485740	et	4	main
aga	doc_491521501774_item	2485746	et	3	main
seda	doc_491521501774_item	2485748	et	3	main
juhtunud	doc_491521501774_item	2485750	et	4	main
poleks	doc_491521501774_item	2485752	et	3	main
professor	doc_491521501774_item	2485754	et	3	main
saanudki	doc_491521501774_item	2485755	et	4	main
on	doc_491521501774_item	2485759	et	4	main
teaduse	doc_491521501774_item	2485763	et	3	main
ja	doc_491521501774_item	2485773	et	3	main
vaatamata	doc_491521501774_item	2485774	et	4	main
sellele	doc_491521501774_item	2485775	et	4	main
et	doc_491521501774_item	2485776	et	3	main
tal	doc_491521501774_item	2485777	et	3	main
tuli	doc_491521501774_item	2485778	et	4	main
lahti	doc_491521501774_item	2485779	et	4	main
ütelda	doc_491521501774_item	2485780	et	4	main
ühest	doc_491521501774_item	2485781	et	4	main
oma	doc_491521501774_item	2485782	et	4	main
pojast	doc_491521501774_item	2485783	et	4	main
elu	doc_491521501774_item	2485784	et	4	main
ei	doc_491521501774_item	2485785	et	4	main
lõppenud	doc_491521501774_item	2485786	et	4	main
sest	doc_491521501774_item	2485787	et	4	main
temaga	doc_491521501774_item	2485788	et	3	main
koos	doc_491521501774_item	2485789	et	4	main
olid	doc_491521501774_item	2485790	et	4	main
tema	doc_491521501774_item	2485791	et	4	main
teine	doc_491521501774_item	2485792	et	3	main
tegid	doc_491521501774_item	2485798	et	4	main
ta	doc_491521501774_item	2485799	et	4	main
koos	doc_491521501774_item	2485806	et	4	main
said	doc_491521501774_item	2485810	et	4	main
surma	doc_491521501774_item	2485811	et	4	main
paljud	doc_491521501774_item	2485812	et	3	main
inimesed	doc_491521501774_item	2485813	et	3	main
ja	doc_491521501774_item	2485825	et	3	main
unistavad	doc_491521501774_item	2485826	et	4	main
õnnelikust	doc_491521501774_item	2485828	et	4	main
tegelasi	doc_491521501774_item	2485838	et	3	main
kogu	doc_491521501774_item	2485840	et	4	main
oma	doc_491521501774_item	2485855	et	4	main
paistab	doc_491521501774_item	2485858	et	3	main
jaoks	doc_491521501774_item	2485866	et	4	main
kõige	doc_491521501774_item	2485867	et	4	main
tähtsam	doc_491521501774_item	2485868	et	4	main
saa	doc_491521501774_item	2485895	et	4	main
neid	doc_491521501774_item	2485905	et	4	main
olla	doc_491521501774_item	2485907	et	3	main
et	doc_491521501774_item	2485913	et	3	main
süütuid	doc_491521501774_item	2485916	et	4	main
ohvreid	doc_491521501774_item	2485917	et	3	main
näiteks	doc_491521501774_item	2485918	et	4	main
nagu	doc_491521501774_item	2485919	et	3	main
selles	doc_491521501774_item	2485922	et	4	main
ma	doc_491521501774_item	2485928	et	3	main
maailmas	doc_491521501774_item	2485940	et	3	main
ka	doc_491521501774_item	2485949	et	3	main
kuid	doc_491521501774_item	2485951	et	4	main
mulle	doc_491521501774_item	2485954	et	4	main
vabastatud	doc_491521501774_item	2485823	et	4	main
uuest	doc_491521501774_item	2485827	et	3	main
elust	doc_491521501774_item	2485829	et	3	main
sellele	doc_491521501774_item	2485831	et	4	main
palju	doc_491521501774_item	2485837	et	4	main
on	doc_491521501774_item	2485846	et	4	main
väga	doc_491521501774_item	2485847	et	3	main
iseloomult	doc_491521501774_item	2485856	et	3	main
silma	doc_491521501774_item	2485859	et	4	main
suhtumine	doc_491521501774_item	2485861	et	4	main
elusse	doc_491521501774_item	2485862	et	3	main
näiteks	doc_491521501774_item	2485863	et	4	main
professor	doc_491521501774_item	2485864	et	3	main
on	doc_491521501774_item	2485869	et	4	main
tütrele-riigi	doc_491521501774_item	2485871	et	3	main
vabadus	doc_491521501774_item	2485872	et	4	main
ja	doc_491521501774_item	2485873	et	3	main
tahtmine	doc_491521501774_item	2485874	et	4	main
edasi	doc_491521501774_item	2485875	et	3	main
õppida	doc_491521501774_item	2485876	et	3	main
aga	doc_491521501774_item	2485877	et	3	main
nende	doc_491521501774_item	2485878	et	4	main
naabritele	doc_491521501774_item	2485879	et	4	main
materiaalsed	doc_491521501774_item	2485880	et	3	main
asjad	doc_491521501774_item	2485881	et	3	main
nagu	doc_491521501774_item	2485882	et	3	main
serviisid	doc_491521501774_item	2485883	et	3	main
kleidid	doc_491521501774_item	2485884	et	3	main
jne	doc_491521501774_item	2485885	et	4	main
loomulikult	doc_491521501774_item	2485886	et	4	main
igaühel	doc_491521501774_item	2485887	et	3	main
omad	doc_491521501774_item	2485889	et	4	main
ei	doc_491521501774_item	2485894	et	4	main
väike	doc_491521501774_item	2485920	et	4	main
arvan	doc_491521501774_item	2485929	et	3	main
sest	doc_491521501774_item	2485933	et	4	main
olid	doc_491521501774_item	2485935	et	4	main
on	doc_491521501774_item	2485941	et	4	main
vihkamine	doc_491521501774_item	2485943	et	4	main
see	doc_491521501774_item	2485947	et	3	main
tundub	doc_491521501774_item	2485953	et	3	main
ebavõrdsus	doc_491521501774_item	2485942	et	4	main
unistus	doc_491521501774_item	2485948	et	4	main
irooniline	doc_491521501774_item	2485956	et	3	main
xxxx	doc_491521501774_item	2485959	et	4	main
filoloogia	doc_491521501776_item	2486854	et	4	main
osakond	doc_491521501776_item	2486855	et	3	main
ajalehe	doc_491521501776_item	2486856	et	3	main
on	doc_491521501776_item	2486877	et	4	main
suures	doc_491521501776_item	2486886	et	3	main
põhilised	doc_491521501776_item	2486891	et	3	main
on	doc_491521501776_item	2486902	et	4	main
ei	doc_491521501776_item	2486910	et	4	main
teistes	doc_491521501776_item	2486922	et	4	main
pealkirjade	doc_491521501776_item	2486935	et	3	main
kujundamisel	doc_491521501776_item	2486945	et	4	main
hoiduda	doc_491521501776_item	2486946	et	3	main
korrastada	doc_491521501776_item	2486950	et	3	main
pealkirjad	doc_491521501776_item	2486960	et	3	main
teistele	doc_491521501776_item	2486967	et	4	main
1	doc_491521501776_item	2486972	et	2	main
näiteks	doc_491521501776_item	2487002	et	4	main
asutuste	doc_491521501776_item	2487005	et	4	main
on	doc_491521501776_item	2487030	et	4	main
lehekülje	doc_491521501776_item	2487035	et	3	main
tallinna	doc_491521501776_item	2486849	et	4	main
ajalehes	doc_491521501776_item	2486876	et	3	main
lihtne	doc_491521501776_item	2486878	et	3	main
nimi	doc_491521501776_item	2486890	et	3	main
olen	doc_491521501776_item	2486895	et	3	main
järgmised	doc_491521501776_item	2486898	et	3	main
puudub	doc_491521501776_item	2486925	et	3	main
üldse	doc_491521501776_item	2486926	et	3	main
vaja	doc_491521501776_item	2486928	et	4	main
jaotada	doc_491521501776_item	2486929	et	3	main
pealkirjade	doc_491521501776_item	2486947	et	3	main
sest	doc_491521501776_item	2486951	et	4	main
praegu	doc_491521501776_item	2486952	et	3	main
nende	doc_491521501776_item	2486953	et	4	main
kohe	doc_491521501776_item	2486965	et	4	main
ürituste	doc_491521501776_item	2487007	et	4	main
paiguldatud	doc_491521501776_item	2487009	et	4	main
koos	doc_491521501776_item	2487010	et	4	main
on	doc_491521501776_item	2487012	et	4	main
kuulutused	doc_491521501776_item	2487019	et	4	main
nende	doc_491521501776_item	2487020	et	4	main
vahel	doc_491521501776_item	2487021	et	4	main
lehekülg	doc_491521501776_item	2487023	et	3	main
väga	doc_491521501776_item	2487025	et	3	main
raske	doc_491521501776_item	2487032	et	4	main
on	doc_491521501776_item	2487037	et	4	main
kuigi	doc_491521501776_item	2487039	et	3	main
see	doc_491521501776_item	2487042	et	3	main
rohkem	doc_491521501776_item	2487044	et	4	main
on	doc_491521501776_item	2487052	et	4	main
ainult	doc_491521501776_item	2487053	et	4	main
kahe	doc_491521501776_item	2487054	et	3	main
põhilugude	doc_491521501776_item	2487055	et	3	main
pealkirja	doc_491521501776_item	2487056	et	4	main
kus	doc_491521501776_item	2487066	et	3	main
vaja	doc_491521501776_item	2487068	et	4	main
see	doc_491521501776_item	2487072	et	3	main
ajalehes	doc_491521501776_item	2487075	et	3	main
analüüs	doc_491521501776_item	2486848	et	3	main
korrastatud	doc_491521501776_item	2486873	et	4	main
ja	doc_491521501776_item	2486874	et	3	main
rahulik	doc_491521501776_item	2486875	et	3	main
olemas	doc_491521501776_item	2486885	et	4	main
kirjas	doc_491521501776_item	2486888	et	4	main
mida	doc_491521501776_item	2486893	et	4	main
on	doc_491521501776_item	2486897	et	4	main
1	doc_491521501776_item	2486899	et	2	main
reklaami	doc_491521501776_item	2486900	et	4	main
ole	doc_491521501776_item	2486911	et	4	main
paiguldada	doc_491521501776_item	2486913	et	4	main
nii	doc_491521501776_item	2486914	et	3	main
reklaame	doc_491521501776_item	2486916	et	3	main
sest	doc_491521501776_item	2486921	et	4	main
osakondades	doc_491521501776_item	2486923	et	3	main
see	doc_491521501776_item	2486924	et	3	main
oleks	doc_491521501776_item	2486927	et	3	main
kuulutused	doc_491521501776_item	2486930	et	4	main
osakonnade	doc_491521501776_item	2486932	et	3	main
vahel	doc_491521501776_item	2486933	et	4	main
kirjatüüp	doc_491521501776_item	2486936	et	3	main
on	doc_491521501776_item	2486937	et	4	main
liiga	doc_491521501776_item	2486938	et	4	main
mitmekesine	doc_491521501776_item	2486939	et	4	main
aga	doc_491521501776_item	2486940	et	3	main
liiga	doc_491521501776_item	2486956	et	4	main
silma	doc_491521501776_item	2486966	et	4	main
pane	doc_491521501776_item	2486970	et	4	main
võib	doc_491521501776_item	2486974	et	3	main
vaja	doc_491521501776_item	2486998	et	4	main
korrastada	doc_491521501776_item	2486999	et	3	main
praegu	doc_491521501776_item	2487000	et	3	main
on	doc_491521501776_item	2487001	et	4	main
reaklaamid	doc_491521501776_item	2487008	et	4	main
kui	doc_491521501776_item	2487011	et	3	main
siis	doc_491521501776_item	2487015	et	3	main
on	doc_491521501776_item	2487016	et	4	main
jagada	doc_491521501776_item	2487018	et	3	main
kirju	doc_491521501776_item	2487026	et	4	main
välja	doc_491521501776_item	2487027	et	4	main
ja	doc_491521501776_item	2487028	et	3	main
seal	doc_491521501776_item	2487029	et	4	main
esimese	doc_491521501776_item	2487034	et	3	main
et	doc_491521501776_item	2487041	et	3	main
sisaldaks	doc_491521501776_item	2487043	et	3	main
päistmikus	doc_491521501776_item	2487051	et	4	main
all	doc_491521501776_item	2487061	et	3	main
ka	doc_491521501776_item	2487063	et	3	main
number	doc_491521501776_item	2487065	et	3	main
on	doc_491521501776_item	2487067	et	4	main
orienteeruda	doc_491521501776_item	2487074	et	3	main
peabki	doc_491521501776_item	2487118	et	4	main
fotosid	doc_491521501776_item	2487124	et	3	main
ülesehitus	doc_491521501776_item	2487129	et	4	main
jaotud	doc_491521501776_item	2487132	et	4	main
majandus	doc_491521501776_item	2487151	et	4	main
päeva	doc_491521501776_item	2487152	et	4	main
osakondade	doc_491521501776_item	2487159	et	3	main
on	doc_491521501776_item	2487166	et	4	main
uudised	doc_491521501776_item	2487175	et	3	main
majandus	doc_491521501776_item	2487179	et	4	main
teema	doc_491521501776_item	2487183	et	4	main
viru	doc_491521501776_item	2487184	et	4	main
pedagoogikaülikool	doc_491521501776_item	2486850	et	4	main
filoloogia	doc_491521501776_item	2486851	et	4	main
teaduskond	doc_491521501776_item	2486852	et	3	main
selge	doc_491521501776_item	2486872	et	4	main
orienteeruda	doc_491521501776_item	2486879	et	3	main
iga	doc_491521501776_item	2486881	et	4	main
lehekülje	doc_491521501776_item	2486882	et	3	main
päistmikus	doc_491521501776_item	2486883	et	4	main
rasvases	doc_491521501776_item	2486887	et	4	main
puudused	doc_491521501776_item	2486892	et	3	main
ajalehes	doc_491521501776_item	2486903	et	3	main
terve	doc_491521501776_item	2486904	et	4	main
osakond	doc_491521501776_item	2486905	et	3	main
reklaam	doc_491521501776_item	2486906	et	3	main
ja	doc_491521501776_item	2486907	et	3	main
kuulutused	doc_491521501776_item	2486908	et	4	main
seega	doc_491521501776_item	2486909	et	4	main
mõttet	doc_491521501776_item	2486912	et	4	main
palju	doc_491521501776_item	2486915	et	4	main
just	doc_491521501776_item	2486917	et	3	main
osakonasse	doc_491521501776_item	2486920	et	4	main
eesti	doc_491521501776_item	2486853	et	4	main
analüüs	doc_491521501776_item	2486857	et	3	main
tallinn	doc_491521501776_item	2486858	et	4	main
2004a	doc_491521501776_item	2486859	et	4	main
ajalehe	doc_491521501776_item	2486860	et	3	main
põhjaraanik	doc_491521501776_item	2486861	et	4	main
analüüs	doc_491521501776_item	2486862	et	3	main
üldmulje	doc_491521501776_item	2486863	et	4	main
üldiselt	doc_491521501776_item	2486864	et	4	main
mulle	doc_491521501776_item	2486865	et	4	main
väga	doc_491521501776_item	2486866	et	3	main
meeldis	doc_491521501776_item	2486867	et	3	main
antud	doc_491521501776_item	2486868	et	4	main
ajaleht	doc_491521501776_item	2486869	et	3	main
kujundus	doc_491521501776_item	2486870	et	4	main
on	doc_491521501776_item	2486871	et	4	main
sest	doc_491521501776_item	2486880	et	4	main
on	doc_491521501776_item	2486884	et	4	main
osakonna	doc_491521501776_item	2486889	et	4	main
ma	doc_491521501776_item	2486894	et	3	main
märkanud	doc_491521501776_item	2486896	et	4	main
jaoks	doc_491521501776_item	2486901	et	4	main
päeva	doc_491521501776_item	2486918	et	4	main
teema	doc_491521501776_item	2486919	et	4	main
just	doc_491521501776_item	2486941	et	3	main
sellest	doc_491521501776_item	2486942	et	4	main
tuleb	doc_491521501776_item	2486943	et	3	main
ajalehtede	doc_491521501776_item	2486944	et	4	main
kujundamiseks	doc_491521501776_item	2486954	et	4	main
erinevaid	doc_491521501776_item	2486958	et	4	main
kirjastiile	doc_491521501776_item	2486959	et	3	main
ei	doc_491521501776_item	2486969	et	4	main
ning	doc_491521501776_item	2487004	et	3	main
ja	doc_491521501776_item	2487006	et	3	main
alaosakonnad	doc_491521501776_item	2487014	et	4	main
erinavate	doc_491521501776_item	2486931	et	4	main
2	doc_491521501776_item	2486934	et	2	main
kirjatüüpi	doc_491521501776_item	2486948	et	4	main
tuleb	doc_491521501776_item	2486949	et	3	main
kasutatakse	doc_491521501776_item	2486955	et	3	main
palju	doc_491521501776_item	2486957	et	4	main
mis	doc_491521501776_item	2486961	et	4	main
on	doc_491521501776_item	2486962	et	4	main
rasvasemad	doc_491521501776_item	2486963	et	4	main
torkavad	doc_491521501776_item	2486964	et	4	main
aga	doc_491521501776_item	2486968	et	3	main
tähelepanu	doc_491521501776_item	2486971	et	4	main
ajaleht	doc_491521501776_item	2486973	et	3	main
tunduda	doc_491521501776_item	2486975	et	3	main
natuke	doc_491521501776_item	2486976	et	4	main
igavana	doc_491521501776_item	2486977	et	4	main
sest	doc_491521501776_item	2486978	et	4	main
kujundus	doc_491521501776_item	2486979	et	4	main
ei	doc_491521501776_item	2486980	et	4	main
varieeru	doc_491521501776_item	2486981	et	4	main
ja	doc_491521501776_item	2486982	et	3	main
on	doc_491521501776_item	2486983	et	4	main
natuke	doc_491521501776_item	2486984	et	4	main
ükskülgne	doc_491521501776_item	2486985	et	3	main
tahaks	doc_491521501776_item	2486986	et	3	main
näha	doc_491521501776_item	2486987	et	3	main
rohkem	doc_491521501776_item	2486988	et	4	main
pilte	doc_491521501776_item	2486989	et	3	main
ja	doc_491521501776_item	2486990	et	3	main
2	doc_491521501776_item	2486992	et	2	main
kujunduselemente	doc_491521501776_item	2486991	et	3	main
kuulutuste	doc_491521501776_item	2486993	et	4	main
ja	doc_491521501776_item	2486994	et	3	main
reklaami	doc_491521501776_item	2486995	et	4	main
lehekülge	doc_491521501776_item	2486996	et	4	main
on	doc_491521501776_item	2486997	et	4	main
töökuulutused	doc_491521501776_item	2487003	et	4	main
olemas	doc_491521501776_item	2487013	et	4	main
vaja	doc_491521501776_item	2487017	et	4	main
orienteeruda	doc_491521501776_item	2487033	et	3	main
antud	doc_491521501776_item	2487048	et	4	main
koos	doc_491521501776_item	2487057	et	4	main
illustratsiionidega	doc_491521501776_item	2487058	et	4	main
pealkirjade	doc_491521501776_item	2487060	et	3	main
seda	doc_491521501776_item	2487069	et	3	main
kohe	doc_491521501776_item	2487076	et	4	main
vastab	doc_491521501776_item	2487111	et	3	main
pehmete	doc_491521501776_item	2487114	et	3	main
osakonna	doc_491521501776_item	2487116	et	4	main
kujundus	doc_491521501776_item	2487117	et	4	main
olema	doc_491521501776_item	2487120	et	4	main
siin	doc_491521501776_item	2487121	et	4	main
igasuguseid	doc_491521501776_item	2487126	et	3	main
kujunduselemente	doc_491521501776_item	2487127	et	3	main
ajaleht	doc_491521501776_item	2487130	et	3	main
sektsiooniks	doc_491521501776_item	2487134	et	3	main
ajaleht	doc_491521501776_item	2487135	et	3	main
ise	doc_491521501776_item	2487136	et	4	main
ja	doc_491521501776_item	2487137	et	3	main
lisa	doc_491521501776_item	2487140	et	4	main
teataja	doc_491521501776_item	2487142	et	4	main
ajalehes	doc_491521501776_item	2487143	et	3	main
on	doc_491521501776_item	2487144	et	4	main
seitse	doc_491521501776_item	2487145	et	3	main
reklaam	doc_491521501776_item	2487156	et	3	main
ja	doc_491521501776_item	2487157	et	3	main
loogiline	doc_491521501776_item	2487162	et	4	main
jaotud	doc_491521501776_item	2487167	et	4	main
päevalause	doc_491521501776_item	2487170	et	4	main
lehed	doc_491521501776_item	2487172	et	3	main
eile	doc_491521501776_item	2487173	et	3	main
politsei	doc_491521501776_item	2487178	et	4	main
pole	doc_491521501776_item	2487181	et	3	main
mikser	doc_491521501776_item	2487191	et	3	main
aja	doc_491521501776_item	2487195	et	4	main
pealirju	doc_491521501776_item	2487225	et	4	main
tüüpi	doc_491521501776_item	2487228	et	4	main
pealkiri	doc_491521501776_item	2487232	et	3	main
on	doc_491521501776_item	2487233	et	4	main
lihtsalt	doc_491521501776_item	2487242	et	4	main
suures	doc_491521501776_item	2487243	et	3	main
time	doc_491521501776_item	2487259	et	4	main
vahelpealkirjad	doc_491521501776_item	2487268	et	4	main
ja	doc_491521501776_item	2487269	et	3	main
rasvases	doc_491521501776_item	2487280	et	4	main
kiri	doc_491521501776_item	2487312	et	3	main
esiletõstmiseks	doc_491521501776_item	2487313	et	3	main
kasutatakse	doc_491521501776_item	2487314	et	3	main
niimodi	doc_491521501776_item	2487317	et	4	main
kujundatud	doc_491521501776_item	2487319	et	4	main
kulutuste	doc_491521501776_item	2487022	et	4	main
näeb	doc_491521501776_item	2487024	et	3	main
natuke	doc_491521501776_item	2487031	et	4	main
kujundus	doc_491521501776_item	2487036	et	4	main
tahaks	doc_491521501776_item	2487040	et	3	main
informatsiooni	doc_491521501776_item	2487045	et	4	main
ajalehe	doc_491521501776_item	2487046	et	3	main
sisust	doc_491521501776_item	2487047	et	4	main
artiklit	doc_491521501776_item	2487070	et	3	main
esilehel	doc_491521501776_item	2487077	et	3	main
algab	doc_491521501776_item	2487078	et	3	main
artikkel	doc_491521501776_item	2487079	et	3	main
võiks	doc_491521501776_item	2487081	et	4	main
kujundada	doc_491521501776_item	2487082	et	3	main
esilehe	doc_491521501776_item	2487083	et	3	main
teistmoodi	doc_491521501776_item	2487084	et	3	main
näiteks	doc_491521501776_item	2487085	et	4	main
paigulada	doc_491521501776_item	2487086	et	4	main
sinna	doc_491521501776_item	2487087	et	3	main
rohkem	doc_491521501776_item	2487088	et	4	main
fotosid	doc_491521501776_item	2487089	et	3	main
ja	doc_491521501776_item	2487090	et	3	main
intrigeerivaid	doc_491521501776_item	2487091	et	4	main
lugude	doc_491521501776_item	2487092	et	3	main
pealkirju	doc_491521501776_item	2487093	et	4	main
arvan	doc_491521501776_item	2487094	et	3	main
et	doc_491521501776_item	2487095	et	3	main
see	doc_491521501776_item	2487096	et	3	main
ärataks	doc_491521501776_item	2487097	et	4	main
parem	doc_491521501776_item	2487098	et	4	main
lugejate	doc_491521501776_item	2487099	et	4	main
huvi	doc_491521501776_item	2487100	et	4	main
sektsiooni	doc_491521501776_item	2487101	et	4	main
jõhvi	doc_491521501776_item	2487102	et	4	main
teataja	doc_491521501776_item	2487103	et	4	main
kujundus	doc_491521501776_item	2487104	et	4	main
on	doc_491521501776_item	2487105	et	4	main
vabam	doc_491521501776_item	2487106	et	4	main
ja	doc_491521501776_item	2487107	et	3	main
mitmekesisem	doc_491521501776_item	2487108	et	4	main
ning	doc_491521501776_item	2487109	et	3	main
seega	doc_491521501776_item	2487110	et	4	main
kujundusreeglitele	doc_491521501776_item	2487112	et	3	main
hea	doc_491521501776_item	2487038	et	4	main
numbri	doc_491521501776_item	2487049	et	3	main
lehekülje	doc_491521501776_item	2487050	et	3	main
lugude	doc_491521501776_item	2487059	et	3	main
on	doc_491521501776_item	2487062	et	4	main
lehe	doc_491521501776_item	2487064	et	3	main
otsida	doc_491521501776_item	2487071	et	4	main
aitab	doc_491521501776_item	2487073	et	3	main
selline	doc_491521501776_item	2487119	et	4	main
rohkem	doc_491521501776_item	2487123	et	4	main
osakonda	doc_491521501776_item	2487146	et	4	main
need	doc_491521501776_item	2487147	et	3	main
teema	doc_491521501776_item	2487153	et	4	main
on	doc_491521501776_item	2487161	et	4	main
ja	doc_491521501776_item	2487163	et	3	main
arusaadav	doc_491521501776_item	2487164	et	4	main
tabloo	doc_491521501776_item	2487190	et	4	main
muidugi	doc_491521501776_item	2487080	et	4	main
sest	doc_491521501776_item	2487113	et	4	main
lugude	doc_491521501776_item	2487115	et	3	main
kasutatakase	doc_491521501776_item	2487122	et	4	main
ja	doc_491521501776_item	2487125	et	3	main
eraldi	doc_491521501776_item	2487138	et	4	main
jõhvi	doc_491521501776_item	2487141	et	4	main
mikser	doc_491521501776_item	2487155	et	3	main
osakonnad	doc_491521501776_item	2487165	et	4	main
alaosakondadeks	doc_491521501776_item	2487168	et	3	main
kirjakast	doc_491521501776_item	2487171	et	3	main
ida-virumaa	doc_491521501776_item	2487177	et	4	main
päeva	doc_491521501776_item	2487182	et	4	main
kriminaalkroonika	doc_491521501776_item	2487186	et	4	main
sport	doc_491521501776_item	2487187	et	3	main
kuhu	doc_491521501776_item	2487188	et	3	main
minna	doc_491521501776_item	2487189	et	3	main
kirjud	doc_491521501776_item	2487193	et	4	main
teated	doc_491521501776_item	2487198	et	3	main
eristatakse	doc_491521501776_item	2487222	et	3	main
on	doc_491521501776_item	2487241	et	4	main
rasvased	doc_491521501776_item	2487249	et	4	main
on	doc_491521501776_item	2487251	et	4	main
lehtede	doc_491521501776_item	2487253	et	4	main
lisapealkirjad	doc_491521501776_item	2487256	et	3	main
varieerub	doc_491521501776_item	2487265	et	3	main
kõik	doc_491521501776_item	2487283	et	4	main
kirja	doc_491521501776_item	2487316	et	4	main
näiteks	doc_491521501776_item	2487320	et	4	main
keelekasutus	doc_491521501776_item	2487331	et	4	main
põhjaranniku	doc_491521501776_item	2487332	et	3	main
ainult	doc_491521501776_item	2487339	et	4	main
see	doc_491521501776_item	2487340	et	3	main
see	doc_491521501776_item	2487341	et	3	main
mõned	doc_491521501776_item	2487342	et	3	main
laused	doc_491521501776_item	2487343	et	3	main
on	doc_491521501776_item	2487344	et	4	main
liiga	doc_491521501776_item	2487345	et	4	main
emotsioonid	doc_491521501776_item	2487352	et	3	main
kirjeldamisele	doc_491521501776_item	2487359	et	4	main
formaalsem	doc_491521501776_item	2487367	et	4	main
rohkem	doc_491521501776_item	2487377	et	4	main
sõnu	doc_491521501776_item	2487379	et	4	main
ja	doc_491521501776_item	2487380	et	3	main
fraase	doc_491521501776_item	2487381	et	3	main
sektsioon	doc_491521501776_item	2487388	et	3	main
kohata	doc_491521501776_item	2487412	et	4	main
artikleid	doc_491521501776_item	2487413	et	3	main
nii	doc_491521501776_item	2487414	et	3	main
üheveerulises	doc_491521501776_item	2487415	et	4	main
formaadis	doc_491521501776_item	2487426	et	3	main
ja	doc_491521501776_item	2487432	et	3	main
veerud	doc_491521501776_item	2487435	et	4	main
seetõttu	doc_491521501776_item	2487441	et	3	main
näeb	doc_491521501776_item	2487442	et	3	main
korrastatud	doc_491521501776_item	2487445	et	4	main
seega	doc_491521501776_item	2487454	et	4	main
lõigud	doc_491521501776_item	2487457	et	4	main
ajalehe	doc_491521501776_item	2487458	et	3	main
jaotud	doc_491521501776_item	2487461	et	4	main
mis	doc_491521501776_item	2487465	et	4	main
tõepoolest	doc_491521501776_item	2487466	et	3	main
lihtsustab	doc_491521501776_item	2487467	et	3	main
lugemist	doc_491521501776_item	2487468	et	4	main
suurus	doc_491521501776_item	2487477	et	4	main
ei	doc_491521501776_item	2487478	et	4	main
mis	doc_491521501776_item	2487486	et	4	main
on	doc_491521501776_item	2487487	et	4	main
ajalehe	doc_491521501776_item	2487488	et	3	main
kujunduse	doc_491521501776_item	2487489	et	4	main
ajalehe	doc_491521501776_item	2487128	et	3	main
on	doc_491521501776_item	2487131	et	4	main
kaheks	doc_491521501776_item	2487133	et	4	main
köidetud	doc_491521501776_item	2487139	et	4	main
on	doc_491521501776_item	2487148	et	4	main
arvamus	doc_491521501776_item	2487149	et	3	main
uudised	doc_491521501776_item	2487150	et	3	main
sport	doc_491521501776_item	2487154	et	3	main
kuulutus	doc_491521501776_item	2487158	et	4	main
järjekord	doc_491521501776_item	2487160	et	3	main
arvamus	doc_491521501776_item	2487169	et	3	main
põhjarannik	doc_491521501776_item	2487174	et	3	main
eesti	doc_491521501776_item	2487176	et	4	main
alaosakondeid	doc_491521501776_item	2487180	et	4	main
ilm	doc_491521501776_item	2487192	et	3	main
uudised	doc_491521501776_item	2487194	et	3	main
kiriklikud	doc_491521501776_item	2487197	et	4	main
igapäevane	doc_491521501776_item	2487199	et	4	main
katkend	doc_491521501776_item	2487200	et	3	main
mingist	doc_491521501776_item	2487201	et	4	main
raamatust	doc_491521501776_item	2487202	et	4	main
trükikiri	doc_491521501776_item	2487203	et	3	main
ajalehe	doc_491521501776_item	2487204	et	3	main
põhikiri	doc_491521501776_item	2487205	et	3	main
on	doc_491521501776_item	2487206	et	4	main
standartne	doc_491521501776_item	2487207	et	4	main
antiikva	doc_491521501776_item	2487208	et	4	main
times	doc_491521501776_item	2487209	et	4	main
roman	doc_491521501776_item	2487211	et	4	main
new	doc_491521501776_item	2487210	et	4	main
kuid	doc_491521501776_item	2487212	et	4	main
kirjasuurus	doc_491521501776_item	2487213	et	4	main
varieerub	doc_491521501776_item	2487214	et	3	main
mõnede	doc_491521501776_item	2487215	et	3	main
artiklite	doc_491521501776_item	2487216	et	3	main
kiri	doc_491521501776_item	2487217	et	3	main
on	doc_491521501776_item	2487218	et	4	main
suurem	doc_491521501776_item	2487219	et	4	main
arvatavasti	doc_491521501776_item	2487220	et	3	main
niimodi	doc_491521501776_item	2487221	et	4	main
üksteiselt	doc_491521501776_item	2487224	et	3	main
rasvases	doc_491521501776_item	2487235	et	4	main
antiikva	doc_491521501776_item	2487236	et	4	main
kirjas	doc_491521501776_item	2487244	et	4	main
kolmanda	doc_491521501776_item	2487245	et	3	main
tüüpi	doc_491521501776_item	2487246	et	4	main
nad	doc_491521501776_item	2487250	et	3	main
pisilugudel	doc_491521501776_item	2487252	et	3	main
on	doc_491521501776_item	2487257	et	4	main
rasvases	doc_491521501776_item	2487258	et	4	main
nimelt	doc_491521501776_item	2487266	et	4	main
on	doc_491521501776_item	2487267	et	4	main
artiklite	doc_491521501776_item	2487275	et	3	main
on	doc_491521501776_item	2487278	et	4	main
kujundatud	doc_491521501776_item	2487279	et	4	main
tähed	doc_491521501776_item	2487284	et	3	main
on	doc_491521501776_item	2487318	et	4	main
küsimused	doc_491521501776_item	2487322	et	4	main
esitatud	doc_491521501776_item	2487329	et	4	main
piisavalt	doc_491521501776_item	2487335	et	4	main
pikkad	doc_491521501776_item	2487346	et	4	main
ringkonnakohtu	doc_491521501776_item	2487185	et	3	main
leht	doc_491521501776_item	2487196	et	3	main
suuremas	doc_491521501776_item	2487234	et	4	main
tüüpi	doc_491521501776_item	2487239	et	4	main
pealkirjad	doc_491521501776_item	2487240	et	3	main
pealkirjad	doc_491521501776_item	2487247	et	3	main
new	doc_491521501776_item	2487260	et	4	main
romansi	doc_491521501776_item	2487261	et	3	main
piltide	doc_491521501776_item	2487270	et	3	main
allkirjad	doc_491521501776_item	2487271	et	3	main
rasvases	doc_491521501776_item	2487272	et	4	main
kirjas	doc_491521501776_item	2487281	et	4	main
ja	doc_491521501776_item	2487282	et	3	main
rasvast	doc_491521501776_item	2487315	et	4	main
intervjuu	doc_491521501776_item	2487321	et	4	main
mõningad	doc_491521501776_item	2487323	et	3	main
tsitaatsõnad	doc_491521501776_item	2487324	et	3	main
kursiivkirjas	doc_491521501776_item	2487330	et	4	main
formaalne	doc_491521501776_item	2487336	et	3	main
mind	doc_491521501776_item	2487337	et	4	main
häiris	doc_491521501776_item	2487338	et	3	main
ja	doc_491521501776_item	2487353	et	3	main
autorid	doc_491521501776_item	2487355	et	3	main
pigem	doc_491521501776_item	2487357	et	3	main
juhtunu	doc_491521501776_item	2487361	et	4	main
on	doc_491521501776_item	2487365	et	4	main
on	doc_491521501776_item	2487373	et	4	main
sest	doc_491521501776_item	2487382	et	4	main
ju	doc_491521501776_item	2487385	et	3	main
on	doc_491521501776_item	2487390	et	4	main
lugeda	doc_491521501776_item	2487393	et	3	main
ei	doc_491521501776_item	2487396	et	4	main
leidnud	doc_491521501776_item	2487397	et	4	main
artiklid	doc_491521501776_item	2487401	et	3	main
veerude	doc_491521501776_item	2487406	et	4	main
number	doc_491521501776_item	2487407	et	3	main
varieerub	doc_491521501776_item	2487408	et	3	main
nimelt	doc_491521501776_item	2487409	et	4	main
võib	doc_491521501776_item	2487410	et	3	main
nn	doc_491521501776_item	2487417	et	4	main
raamatu	doc_491521501776_item	2487421	et	4	main
teeb	doc_491521501776_item	2487429	et	3	main
kõik	doc_491521501776_item	2487434	et	4	main
poolt	doc_491521501776_item	2487439	et	4	main
väga	doc_491521501776_item	2487444	et	3	main
välja	doc_491521501776_item	2487446	et	4	main
veerude	doc_491521501776_item	2487447	et	4	main
laius	doc_491521501776_item	2487448	et	4	main
varieerub	doc_491521501776_item	2487449	et	3	main
4-45	doc_491521501776_item	2487450	et	2	main
vastab	doc_491521501776_item	2487455	et	3	main
reeglitele	doc_491521501776_item	2487456	et	3	main
mõnungad	doc_491521501776_item	2487469	et	4	main
lõigud	doc_491521501776_item	2487470	et	4	main
lühikesed	doc_491521501776_item	2487474	et	4	main
nende	doc_491521501776_item	2487476	et	4	main
reeglite	doc_491521501776_item	2487490	et	3	main
nagu	doc_491521501776_item	2487525	et	3	main
pikkad	doc_491521501776_item	2487542	et	4	main
seitse	doc_491521501776_item	2487547	et	3	main
kuigi	doc_491521501776_item	2487549	et	3	main
järgi	doc_491521501776_item	2487551	et	4	main
vaatamata	doc_491521501776_item	2487554	et	4	main
arvan	doc_491521501776_item	2487556	et	3	main
löövad	doc_491521501776_item	2487562	et	4	main
peegeldavad	doc_491521501776_item	2487566	et	4	main
kõik	doc_491521501776_item	2487569	et	4	main
pealkirjad	doc_491521501776_item	2487570	et	3	main
esitatud	doc_491521501776_item	2487576	et	4	main
nende	doc_491521501776_item	2487580	et	4	main
alla	doc_491521501776_item	2487583	et	3	main
jäetud	doc_491521501776_item	2487585	et	4	main
piisavalt	doc_491521501776_item	2487586	et	4	main
kuus	doc_491521501776_item	2487594	et	4	main
ja	doc_491521501776_item	2487595	et	3	main
vaba	doc_491521501776_item	2487596	et	4	main
on	doc_491521501776_item	2487599	et	4	main
artikleid	doc_491521501776_item	2487223	et	3	main
on	doc_491521501776_item	2487226	et	4	main
kolm	doc_491521501776_item	2487227	et	3	main
iga	doc_491521501776_item	2487229	et	4	main
lehekülje	doc_491521501776_item	2487230	et	3	main
pealugu	doc_491521501776_item	2487231	et	4	main
kirjas	doc_491521501776_item	2487237	et	4	main
teise	doc_491521501776_item	2487238	et	4	main
on	doc_491521501776_item	2487248	et	4	main
servades	doc_491521501776_item	2487254	et	3	main
ka	doc_491521501776_item	2487255	et	3	main
kirjas	doc_491521501776_item	2487262	et	4	main
pealkirjade	doc_491521501776_item	2487263	et	3	main
kirjatüüp	doc_491521501776_item	2487264	et	3	main
plokk	doc_491521501776_item	2487273	et	3	main
kirjas	doc_491521501776_item	2487274	et	4	main
autorite	doc_491521501776_item	2487276	et	3	main
nimed	doc_491521501776_item	2487277	et	3	main
on	doc_491521501776_item	2487285	et	4	main
tiiteltähed	doc_491521501776_item	2487286	et	3	main
märkasin	doc_491521501776_item	2487287	et	3	main
et	doc_491521501776_item	2487288	et	3	main
spordi	doc_491521501776_item	2487289	et	4	main
osakonna	doc_491521501776_item	2487290	et	4	main
pealkirjade	doc_491521501776_item	2487291	et	3	main
erineb	doc_491521501776_item	2487293	et	3	main
kujundus	doc_491521501776_item	2487292	et	4	main
teistest	doc_491521501776_item	2487294	et	4	main
osakondadest	doc_491521501776_item	2487295	et	3	main
selle	doc_491521501776_item	2487296	et	4	main
osakonna	doc_491521501776_item	2487297	et	4	main
pealkirjad	doc_491521501776_item	2487298	et	3	main
ja	doc_491521501776_item	2487299	et	3	main
alapealkirjad	doc_491521501776_item	2487300	et	3	main
on	doc_491521501776_item	2487301	et	4	main
block	doc_491521501776_item	2487302	et	4	main
kirjas	doc_491521501776_item	2487303	et	4	main
ka	doc_491521501776_item	2487304	et	3	main
spordi	doc_491521501776_item	2487305	et	4	main
osakonna	doc_491521501776_item	2487306	et	4	main
alaosakonna	doc_491521501776_item	2487307	et	4	main
tabloo	doc_491521501776_item	2487308	et	4	main
trükikiri	doc_491521501776_item	2487309	et	3	main
on	doc_491521501776_item	2487310	et	4	main
plokk	doc_491521501776_item	2487311	et	3	main
nn	doc_491521501776_item	2487325	et	4	main
conference	doc_491521501776_item	2487326	et	4	main
play-off	doc_491521501776_item	2487327	et	4	main
keelekasutus	doc_491521501776_item	2487333	et	4	main
komplitseeritud	doc_491521501776_item	2487348	et	4	main
artiklitest	doc_491521501776_item	2487349	et	4	main
on	doc_491521501776_item	2487350	et	4	main
välistatud	doc_491521501776_item	2487351	et	4	main
on	doc_491521501776_item	2487328	et	4	main
on	doc_491521501776_item	2487334	et	4	main
kui	doc_491521501776_item	2487360	et	3	main
hindamisele	doc_491521501776_item	2487362	et	4	main
kõige	doc_491521501776_item	2487366	et	4	main
tõsisem	doc_491521501776_item	2487369	et	4	main
teataja	doc_491521501776_item	2487371	et	4	main
keelekasutus	doc_491521501776_item	2487372	et	4	main
sisaldab	doc_491521501776_item	2487376	et	3	main
kõnekeelseid	doc_491521501776_item	2487378	et	3	main
on	doc_491521501776_item	2487384	et	4	main
lugude	doc_491521501776_item	2487387	et	3	main
on	doc_491521501776_item	2487402	et	4	main
formaadis	doc_491521501776_item	2487416	et	3	main
või	doc_491521501776_item	2487420	et	4	main
kuueveerulises	doc_491521501776_item	2487425	et	4	main
lihtsaks	doc_491521501776_item	2487431	et	4	main
on	doc_491521501776_item	2487436	et	4	main
joondetud	doc_491521501776_item	2487437	et	4	main
sm	doc_491521501776_item	2487451	et	4	main
piire	doc_491521501776_item	2487452	et	4	main
ja	doc_491521501776_item	2487453	et	3	main
lõikudeks	doc_491521501776_item	2487464	et	3	main
liiga	doc_491521501776_item	2487473	et	4	main
mõnikord	doc_491521501776_item	2487482	et	3	main
isegi	doc_491521501776_item	2487483	et	4	main
rida	doc_491521501776_item	2487485	et	4	main
tavaliselt	doc_491521501776_item	2487492	et	4	main
peab	doc_491521501776_item	2487493	et	4	main
on	doc_491521501776_item	2487516	et	4	main
kirjas	doc_491521501776_item	2487524	et	4	main
enne	doc_491521501776_item	2487528	et	4	main
kirjatüüp	doc_491521501776_item	2487534	et	3	main
pealkirjad	doc_491521501776_item	2487539	et	3	main
arv	doc_491521501776_item	2487545	et	3	main
ja	doc_491521501776_item	2487563	et	3	main
täpselt	doc_491521501776_item	2487565	et	4	main
artiklite	doc_491521501776_item	2487567	et	3	main
põhiidee	doc_491521501776_item	2487568	et	4	main
kirjas	doc_491521501776_item	2487579	et	4	main
rida	doc_491521501776_item	2487587	et	4	main
tekste	doc_491521501776_item	2487588	et	3	main
reeglite	doc_491521501776_item	2487589	et	3	main
ruumi	doc_491521501776_item	2487597	et	4	main
selged	doc_491521501776_item	2487602	et	3	main
koosnevad	doc_491521501776_item	2487609	et	4	main
nimesõnadest	doc_491521501776_item	2487611	et	3	main
ja	doc_491521501776_item	2487612	et	3	main
mõned	doc_491521501776_item	2487613	et	3	main
jooneid	doc_491521501776_item	2487621	et	4	main
on	doc_491521501776_item	2487626	et	4	main
iga	doc_491521501776_item	2487640	et	4	main
põhitekstist	doc_491521501776_item	2487650	et	3	main
näha	doc_491521501776_item	2487654	et	3	main
sest	doc_491521501776_item	2487657	et	4	main
rohkem	doc_491521501776_item	2487670	et	4	main
kujundusvahendeid	doc_491521501776_item	2487671	et	3	main
olemas	doc_491521501776_item	2487677	et	4	main
fakte	doc_491521501776_item	2487689	et	3	main
ornamendid	doc_491521501776_item	2487697	et	4	main
ja	doc_491521501776_item	2487698	et	3	main
nn	doc_491521501776_item	2487700	et	4	main
lilled	doc_491521501776_item	2487701	et	3	main
mis	doc_491521501776_item	2487724	et	4	main
on	doc_491521501776_item	2487729	et	4	main
spordi	doc_491521501776_item	2487732	et	4	main
on	doc_491521501776_item	2487735	et	4	main
intrigeerivad	doc_491521501776_item	2487737	et	4	main
majandusosakonnas	doc_491521501776_item	2487740	et	4	main
on	doc_491521501776_item	2487741	et	4	main
olemas	doc_491521501776_item	2487742	et	4	main
üks	doc_491521501776_item	2487743	et	3	main
statiistika	doc_491521501776_item	2487744	et	4	main
mis	doc_491521501776_item	2487745	et	4	main
on	doc_491521501776_item	2487746	et	4	main
väga	doc_491521501776_item	2487747	et	3	main
kirjas	doc_491521501776_item	2487765	et	4	main
mõningad	doc_491521501776_item	2487772	et	3	main
koosnevad	doc_491521501776_item	2487781	et	4	main
isega	doc_491521501776_item	2487782	et	4	main
seismest	doc_491521501776_item	2487783	et	4	main
ja	doc_491521501776_item	2487347	et	3	main
faktide	doc_491521501776_item	2487358	et	3	main
ja	doc_491521501776_item	2487368	et	3	main
veerud	doc_491521501776_item	2487398	et	4	main
kõik	doc_491521501776_item	2487399	et	4	main
jaotud	doc_491521501776_item	2487403	et	4	main
ajalehes	doc_491521501776_item	2487411	et	3	main
kui	doc_491521501776_item	2487423	et	3	main
nad	doc_491521501776_item	2487354	et	3	main
keskenduvad	doc_491521501776_item	2487356	et	4	main
majandusosakonna	doc_491521501776_item	2487363	et	4	main
keelekasutus	doc_491521501776_item	2487364	et	4	main
jõhvi	doc_491521501776_item	2487370	et	4	main
vabam	doc_491521501776_item	2487374	et	4	main
ja	doc_491521501776_item	2487375	et	3	main
see	doc_491521501776_item	2487383	et	3	main
pehmete	doc_491521501776_item	2487386	et	3	main
teksti	doc_491521501776_item	2487389	et	4	main
väga	doc_491521501776_item	2487391	et	3	main
lihtne	doc_491521501776_item	2487392	et	3	main
keelevigu	doc_491521501776_item	2487394	et	3	main
ma	doc_491521501776_item	2487395	et	3	main
ajalehe	doc_491521501776_item	2487400	et	3	main
korrastatud	doc_491521501776_item	2487404	et	4	main
veerudeks	doc_491521501776_item	2487405	et	3	main
igasugune	doc_491521501776_item	2487418	et	3	main
pisiinfo	doc_491521501776_item	2487419	et	4	main
katkend	doc_491521501776_item	2487422	et	3	main
jaotus	doc_491521501776_item	2487428	et	4	main
mugavaks	doc_491521501776_item	2487433	et	3	main
mõlemalt	doc_491521501776_item	2487438	et	3	main
lood	doc_491521501776_item	2487459	et	4	main
piisavalt	doc_491521501776_item	2487462	et	4	main
lühesteks	doc_491521501776_item	2487463	et	4	main
ületa	doc_491521501776_item	2487479	et	4	main
kolm	doc_491521501776_item	2487480	et	3	main
ja	doc_491521501776_item	2487481	et	3	main
kaks	doc_491521501776_item	2487484	et	3	main
üks	doc_491521501776_item	2487494	et	3	main
juba	doc_491521501776_item	2487527	et	3	main
varieerub	doc_491521501776_item	2487530	et	3	main
trükikiri	doc_491521501776_item	2487532	et	3	main
on	doc_491521501776_item	2487540	et	4	main
väga	doc_491521501776_item	2487541	et	3	main
sõna	doc_491521501776_item	2487548	et	4	main
peaks	doc_491521501776_item	2487553	et	4	main
sellele	doc_491521501776_item	2487555	et	4	main
et	doc_491521501776_item	2487557	et	3	main
kõik	doc_491521501776_item	2487558	et	4	main
pealkirjad	doc_491521501776_item	2487559	et	3	main
on	doc_491521501776_item	2487560	et	4	main
selged	doc_491521501776_item	2487561	et	3	main
sisaldavad	doc_491521501776_item	2487571	et	4	main
sihitist	doc_491521501776_item	2487572	et	3	main
verbi	doc_491521501776_item	2487573	et	4	main
vahelpealkirjad	doc_491521501776_item	2487574	et	4	main
on	doc_491521501776_item	2487575	et	4	main
kohale	doc_491521501776_item	2487581	et	4	main
järgi	doc_491521501776_item	2487590	et	4	main
ja	doc_491521501776_item	2487601	et	3	main
nede	doc_491521501776_item	2487604	et	4	main
vorm	doc_491521501776_item	2487606	et	3	main
raame	doc_491521501776_item	2487623	et	3	main
jooneid	doc_491521501776_item	2487638	et	4	main
kasutatakse	doc_491521501776_item	2487639	et	3	main
osakonna	doc_491521501776_item	2487645	et	4	main
nagu	doc_491521501776_item	2487658	et	3	main
ka	doc_491521501776_item	2487678	et	3	main
ja	doc_491521501776_item	2487681	et	3	main
eristatakse	doc_491521501776_item	2487686	et	3	main
igasuguseid	doc_491521501776_item	2487688	et	3	main
erinevad	doc_491521501776_item	2487696	et	4	main
on	doc_491521501776_item	2487721	et	4	main
pildid	doc_491521501776_item	2487723	et	3	main
osutavad	doc_491521501776_item	2487725	et	4	main
inimestele	doc_491521501776_item	2487726	et	3	main
artiklis	doc_491521501776_item	2487730	et	3	main
pildid	doc_491521501776_item	2487734	et	3	main
põhjendavad	doc_491521501776_item	2487767	et	4	main
väga	doc_491521501776_item	2487768	et	3	main
juhtunu	doc_491521501776_item	2487771	et	4	main
spordiosakonna	doc_491521501776_item	2487775	et	4	main
on	doc_491521501776_item	2487777	et	4	main
liiga	doc_491521501776_item	2487778	et	4	main
reast	doc_491521501776_item	2487784	et	3	main
kokkuvõte	doc_491521501776_item	2487795	et	3	main
sisaldab	doc_491521501776_item	2487797	et	3	main
ilmumispiirkonna	doc_491521501776_item	2487801	et	4	main
välismaa	doc_491521501776_item	2487810	et	4	main
ka	doc_491521501776_item	2487424	et	3	main
selline	doc_491521501776_item	2487427	et	4	main
lugemist	doc_491521501776_item	2487430	et	4	main
ning	doc_491521501776_item	2487440	et	3	main
tekst	doc_491521501776_item	2487443	et	3	main
on	doc_491521501776_item	2487460	et	4	main
on	doc_491521501776_item	2487471	et	4	main
aga	doc_491521501776_item	2487472	et	3	main
sest	doc_491521501776_item	2487475	et	4	main
rikkumine	doc_491521501776_item	2487491	et	4	main
lõik	doc_491521501776_item	2487495	et	3	main
sisaldama	doc_491521501776_item	2487496	et	3	main
vähemalt	doc_491521501776_item	2487497	et	4	main
kuus	doc_491521501776_item	2487498	et	4	main
rida	doc_491521501776_item	2487499	et	4	main
teksti	doc_491521501776_item	2487500	et	4	main
lõigud	doc_491521501776_item	2487501	et	4	main
ei	doc_491521501776_item	2487502	et	4	main
ületa	doc_491521501776_item	2487503	et	4	main
kümme	doc_491521501776_item	2487504	et	3	main
sentimetri	doc_491521501776_item	2487505	et	4	main
ja	doc_491521501776_item	2487506	et	3	main
seega	doc_491521501776_item	2487507	et	4	main
on	doc_491521501776_item	2487508	et	4	main
hästi	doc_491521501776_item	2487509	et	3	main
ja	doc_491521501776_item	2487510	et	3	main
mugavalt	doc_491521501776_item	2487511	et	4	main
loetavad	doc_491521501776_item	2487512	et	4	main
pealkirjad	doc_491521501776_item	2487513	et	3	main
lugude	doc_491521501776_item	2487514	et	3	main
pealkirjad	doc_491521501776_item	2487515	et	3	main
joondetud	doc_491521501776_item	2487517	et	4	main
vasakult	doc_491521501776_item	2487518	et	4	main
poolt	doc_491521501776_item	2487519	et	4	main
ja	doc_491521501776_item	2487520	et	3	main
on	doc_491521501776_item	2487521	et	4	main
rasvases	doc_491521501776_item	2487523	et	4	main
ja	doc_491521501776_item	2487533	et	3	main
sõltuvalt	doc_491521501776_item	2487535	et	4	main
artikli	doc_491521501776_item	2487536	et	3	main
tähtsusest	doc_491521501776_item	2487537	et	4	main
mõned	doc_491521501776_item	2487538	et	3	main
sõnade	doc_491521501776_item	2487544	et	3	main
ei	doc_491521501776_item	2487552	et	4	main
väga	doc_491521501776_item	2487564	et	3	main
rasvases	doc_491521501776_item	2487577	et	4	main
plokk	doc_491521501776_item	2487578	et	3	main
ja	doc_491521501776_item	2487582	et	3	main
mitte	doc_491521501776_item	2487591	et	3	main
vähem	doc_491521501776_item	2487592	et	4	main
vahelpealkirjad	doc_491521501776_item	2487598	et	4	main
varieerub	doc_491521501776_item	2487607	et	3	main
ainult	doc_491521501776_item	2487610	et	4	main
esitatud	doc_491521501776_item	2487627	et	4	main
lehekülje	doc_491521501776_item	2487641	et	3	main
päistmes	doc_491521501776_item	2487642	et	4	main
suures	doc_491521501776_item	2487522	et	3	main
oli	doc_491521501776_item	2487526	et	3	main
mainitud	doc_491521501776_item	2487529	et	4	main
pealkirjade	doc_491521501776_item	2487531	et	3	main
ning	doc_491521501776_item	2487543	et	3	main
ületab	doc_491521501776_item	2487546	et	3	main
reegli	doc_491521501776_item	2487550	et	3	main
on	doc_491521501776_item	2487584	et	4	main
kui	doc_491521501776_item	2487593	et	3	main
lühikesed	doc_491521501776_item	2487600	et	4	main
kuigi	doc_491521501776_item	2487603	et	3	main
grammaatiline	doc_491521501776_item	2487605	et	4	main
mõned	doc_491521501776_item	2487608	et	3	main
on	doc_491521501776_item	2487614	et	4	main
pigem	doc_491521501776_item	2487615	et	3	main
lausekujulised	doc_491521501776_item	2487616	et	4	main
kujunduselementid	doc_491521501776_item	2487617	et	4	main
kujunduselementidest	doc_491521501776_item	2487618	et	3	main
kasutatakse	doc_491521501776_item	2487619	et	3	main
ajalehes	doc_491521501776_item	2487620	et	3	main
artikleid	doc_491521501776_item	2487625	et	3	main
mis	doc_491521501776_item	2487629	et	4	main
neid	doc_491521501776_item	2487631	et	4	main
väga	doc_491521501776_item	2487632	et	3	main
hästi	doc_491521501776_item	2487633	et	3	main
üksteiselt	doc_491521501776_item	2487634	et	3	main
ja	doc_491521501776_item	2487635	et	3	main
korrastab	doc_491521501776_item	2487636	et	3	main
et	doc_491521501776_item	2487643	et	3	main
ja	doc_491521501776_item	2487647	et	3	main
number	doc_491521501776_item	2487649	et	3	main
juba	doc_491521501776_item	2487660	et	3	main
ajaleht	doc_491521501776_item	2487663	et	3	main
igavana	doc_491521501776_item	2487665	et	4	main
teataja	doc_491521501776_item	2487667	et	4	main
kujundamisel	doc_491521501776_item	2487668	et	4	main
kasutatakse	doc_491521501776_item	2487669	et	3	main
seal	doc_491521501776_item	2487676	et	4	main
tärni	doc_491521501776_item	2487680	et	4	main
tärnikesed	doc_491521501776_item	2487683	et	4	main
abil	doc_491521501776_item	2487685	et	4	main
piltid	doc_491521501776_item	2487699	et	4	main
jne	doc_491521501776_item	2487703	et	4	main
arvamus	doc_491521501776_item	2487728	et	3	main
osakonna	doc_491521501776_item	2487733	et	4	main
dramaatilised	doc_491521501776_item	2487739	et	3	main
selgelt	doc_491521501776_item	2487748	et	4	main
sisaldab	doc_491521501776_item	2487757	et	3	main
allkirjad	doc_491521501776_item	2487773	et	3	main
näiteks	doc_491521501776_item	2487774	et	4	main
foto	doc_491521501776_item	2487776	et	4	main
j	doc_491521501776_item	2487780	et	4	main
palju	doc_491521501776_item	2487792	et	4	main
uudiseid	doc_491521501776_item	2487800	et	3	main
kohta	doc_491521501776_item	2487802	et	4	main
annab	doc_491521501776_item	2487804	et	3	main
ka	doc_491521501776_item	2487806	et	3	main
uudistest	doc_491521501776_item	2487811	et	4	main
mille	doc_491521501776_item	2487816	et	3	main
on	doc_491521501776_item	2487818	et	4	main
ei	doc_491521501776_item	2487823	et	4	main
mingeid	doc_491521501776_item	2487828	et	3	main
põhjalikke	doc_491521501776_item	2487829	et	3	main
veaanalüüs	doc_491521501777_item	2487840	et	4	main
irina	doc_491521501777_item	2487841	et	3	main
volkova	doc_491521501777_item	2487842	et	4	main
on	doc_491521501777_item	2487845	et	4	main
keelt	doc_491521501777_item	2487855	et	4	main
8	doc_491521501777_item	2487859	et	2	main
emakeelena	doc_491521501777_item	2487865	et	3	main
lapsed	doc_491521501777_item	2487867	et	3	main
mõned	doc_491521501777_item	2487868	et	3	main
on	doc_491521501777_item	2487869	et	4	main
k	doc_491521501777_item	2487919	et	4	main
ja	doc_491521501776_item	2487622	et	3	main
enamik	doc_491521501776_item	2487624	et	3	main
raamides	doc_491521501776_item	2487628	et	4	main
eristab	doc_491521501776_item	2487630	et	3	main
teksti	doc_491521501776_item	2487637	et	4	main
eristada	doc_491521501776_item	2487644	et	3	main
nimi	doc_491521501776_item	2487646	et	3	main
lehekülje	doc_491521501776_item	2487648	et	3	main
mulle	doc_491521501776_item	2487652	et	4	main
tahaks	doc_491521501776_item	2487653	et	3	main
kujunduselemente	doc_491521501776_item	2487656	et	3	main
mainitud	doc_491521501776_item	2487661	et	4	main
tundub	doc_491521501776_item	2487662	et	3	main
peale	doc_491521501776_item	2487672	et	4	main
nimetatud	doc_491521501776_item	2487673	et	4	main
elemente	doc_491521501776_item	2487674	et	3	main
on	doc_491521501776_item	2487675	et	4	main
kolm	doc_491521501776_item	2487679	et	3	main
üksikud	doc_491521501776_item	2487682	et	3	main
ja	doc_491521501776_item	2487691	et	3	main
kujundamiseks	doc_491521501776_item	2487693	et	4	main
linnud	doc_491521501776_item	2487702	et	3	main
minu	doc_491521501776_item	2487704	et	3	main
see	doc_491521501776_item	2487706	et	3	main
teeb	doc_491521501776_item	2487707	et	3	main
teksti	doc_491521501776_item	2487708	et	4	main
ilusaks	doc_491521501776_item	2487709	et	4	main
ja	doc_491521501776_item	2487710	et	3	main
lugemiseks	doc_491521501776_item	2487711	et	4	main
mõnusaks	doc_491521501776_item	2487712	et	4	main
illustratsioonid	doc_491521501776_item	2487713	et	3	main
enamik	doc_491521501776_item	2487714	et	3	main
ajalehe	doc_491521501776_item	2487715	et	3	main
piltedest	doc_491521501776_item	2487716	et	4	main
on	doc_491521501776_item	2487717	et	4	main
portreefotod	doc_491521501776_item	2487718	et	3	main
paljud	doc_491521501776_item	2487719	et	3	main
neist	doc_491521501776_item	2487720	et	4	main
üldiselt	doc_491521501776_item	2487651	et	4	main
rohem	doc_491521501776_item	2487655	et	4	main
oli	doc_491521501776_item	2487659	et	3	main
veidi	doc_491521501776_item	2487664	et	3	main
jõhvi	doc_491521501776_item	2487666	et	4	main
nenede	doc_491521501776_item	2487684	et	4	main
üksteiselt	doc_491521501776_item	2487687	et	3	main
õnnitluste	doc_491521501776_item	2487690	et	4	main
kuulutuste	doc_491521501776_item	2487692	et	4	main
on	doc_491521501776_item	2487694	et	4	main
kasutatud	doc_491521501776_item	2487695	et	4	main
meelest	doc_491521501776_item	2487705	et	4	main
kelle	doc_491521501776_item	2487727	et	4	main
piisavalt	doc_491521501776_item	2487736	et	4	main
ja	doc_491521501776_item	2487738	et	3	main
nad	doc_491521501776_item	2487766	et	3	main
täpselt	doc_491521501776_item	2487769	et	4	main
pikkad	doc_491521501776_item	2487779	et	4	main
infot	doc_491521501776_item	2487794	et	3	main
tähtsamaid	doc_491521501776_item	2487799	et	4	main
ja	doc_491521501776_item	2487803	et	3	main
teada	doc_491521501776_item	2487805	et	3	main
eesti	doc_491521501776_item	2487808	et	4	main
ja	doc_491521501776_item	2487809	et	3	main
informatiivne	doc_491521501776_item	2487814	et	3	main
väikesed	doc_491521501776_item	2487722	et	4	main
esitatud	doc_491521501776_item	2487731	et	4	main
ja	doc_491521501776_item	2487749	et	3	main
arusaadavalt	doc_491521501776_item	2487750	et	4	main
esitatud	doc_491521501776_item	2487751	et	4	main
pehmete	doc_491521501776_item	2487752	et	3	main
lugude	doc_491521501776_item	2487753	et	3	main
sektsioon	doc_491521501776_item	2487754	et	3	main
jõhvi	doc_491521501776_item	2487755	et	4	main
teataja	doc_491521501776_item	2487756	et	4	main
rohkem	doc_491521501776_item	2487758	et	4	main
igasuguseid	doc_491521501776_item	2487759	et	3	main
fotosid	doc_491521501776_item	2487760	et	3	main
piltide	doc_491521501776_item	2487761	et	3	main
allkirjad	doc_491521501776_item	2487762	et	3	main
on	doc_491521501776_item	2487763	et	4	main
plokk	doc_491521501776_item	2487764	et	3	main
piltidel	doc_491521501776_item	2487770	et	3	main
lugejale	doc_491521501776_item	2487790	et	4	main
liiga	doc_491521501776_item	2487791	et	4	main
kõik	doc_491521501776_item	2487798	et	4	main
tähtsamates	doc_491521501776_item	2487807	et	4	main
põhjarannik	doc_491521501776_item	2487812	et	3	main
ajaleht	doc_491521501776_item	2487815	et	3	main
ma	doc_491521501776_item	2487822	et	3	main
ev-51	doc_491521501777_item	2487843	et	4	main
vead	doc_491521501777_item	2487844	et	4	main
x	doc_491521501777_item	2487847	et	4	main
eesti	doc_491521501777_item	2487854	et	4	main
õpivad	doc_491521501777_item	2487856	et	3	main
juba	doc_491521501777_item	2487858	et	3	main
aastat	doc_491521501777_item	2487860	et	3	main
vene	doc_491521501777_item	2487863	et	4	main
in	doc_491521501777_item	2487912	et	4	main
mene	doc_491521501777_item	2487914	et	4	main
kontrolltöö	doc_491521501777_item	2487915	et	4	main
ma	doc_491521501776_item	2487785	et	3	main
arvan	doc_491521501776_item	2487786	et	3	main
et	doc_491521501776_item	2487787	et	3	main
nad	doc_491521501776_item	2487788	et	3	main
annavad	doc_491521501776_item	2487789	et	3	main
ebaolulist	doc_491521501776_item	2487793	et	4	main
ajaleht	doc_491521501776_item	2487796	et	3	main
on	doc_491521501776_item	2487813	et	4	main
kujundus	doc_491521501776_item	2487817	et	4	main
üsna	doc_491521501776_item	2487819	et	3	main
heal	doc_491521501776_item	2487820	et	3	main
tasemel	doc_491521501776_item	2487821	et	3	main
see	doc_491521501776_item	2487826	et	3	main
vajaks	doc_491521501776_item	2487827	et	4	main
muutusi	doc_491521501776_item	2487830	et	4	main
kuigi	doc_491521501776_item	2487831	et	3	main
kontrastiivne	doc_491521501777_item	2487838	et	4	main
essee	doc_491521501777_item	2487853	et	4	main
nad	doc_491521501777_item	2487857	et	3	main
tihti	doc_491521501777_item	2487911	et	3	main
e	doc_491521501777_item	2487913	et	4	main
к	doc_491521501777_item	2487925	et	2	main
работа	doc_491521501777_item	2487928	et	2	main
нтрольная	doc_491521501777_item	2487932	et	2	main
nagu	doc_491521501777_item	2487943	et	3	main
sõ	doc_491521501777_item	2487974	et	4	main
väga	doc_491521501777_item	2488011	et	3	main
pidada	doc_491521501777_item	2488017	et	4	main
hammasid	doc_491521501777_item	2488018	et	4	main
nii	doc_491521501777_item	2488021	et	3	main
tugevas	doc_491521501777_item	2488029	et	4	main
astmes	doc_491521501777_item	2488030	et	3	main
ha	doc_491521501777_item	2488032	et	4	main
amosha	doc_491521501777_item	2488038	et	4	main
tavaliselt	doc_491521501777_item	2488041	et	4	main
algperiooldil	doc_491521501777_item	2488043	et	4	main
tehta	doc_491521501777_item	2488045	et	3	main
kirjutan	doc_491521501777_item	2488054	et	3	main
praegu	doc_491521501777_item	2488055	et	3	main
kirja	doc_491521501777_item	2488056	et	4	main
ühtemoodi	doc_491521501777_item	2488078	et	3	main
ja	doc_491521501777_item	2488082	et	3	main
luges	doc_491521501777_item	2488085	et	3	main
õpilased	doc_491521501777_item	2488097	et	3	main
juures	doc_491521501777_item	2488104	et	4	main
käänet	doc_491521501777_item	2488106	et	3	main
ma	doc_491521501777_item	2488107	et	3	main
loen	doc_491521501777_item	2488108	et	3	main
raamatut	doc_491521501777_item	2488109	et	3	main
ega	doc_491521501777_item	2488110	et	3	main
pane	doc_491521501777_item	2488111	et	4	main
tähele	doc_491521501777_item	2488112	et	3	main
jne	doc_491521501777_item	2488120	et	4	main
või	doc_491521501777_item	2488121	et	4	main
keelesisene	doc_491521501777_item	2488128	et	3	main
t	doc_491521501777_item	2488137	et	4	main
on	doc_491521501777_item	2488142	et	4	main
tulemusliku	doc_491521501777_item	2488144	et	3	main
ära	doc_491521501777_item	2488152	et	4	main
4	doc_491521501777_item	2488153	et	2	main
kohakäänete	doc_491521501777_item	2488154	et	3	main
vead	doc_491521501777_item	2488155	et	4	main
lasnamäe	doc_491521501777_item	2488156	et	3	main
viga	doc_491521501777_item	2488159	et	4	main
mina	doc_491521501777_item	2488162	et	4	main
ootasin	doc_491521501777_item	2488163	et	3	main
l	doc_491521501777_item	2488165	et	4	main
чем	doc_491521501777_item	2488174	et	2	main
l	doc_491521501777_item	2488177	et	4	main
l	doc_491521501777_item	2488179	et	4	main
mina	doc_491521501777_item	2488180	et	4	main
lähen	doc_491521501777_item	2488181	et	3	main
kinosse	doc_491521501777_item	2488182	et	3	main
aru	doc_491521501777_item	2488189	et	4	main
miks	doc_491521501777_item	2488191	et	4	main
muud	doc_491521501777_item	2488221	et	4	main
a	doc_491521501777_item	2488223	et	4	main
poolakas	doc_491521501777_item	2488226	et	4	main
poolaka	doc_491521501777_item	2488234	et	4	main
se	doc_491521501777_item	2488235	et	4	main
et	doc_491521501777_item	2488239	et	3	main
ga	doc_491521501777_item	2488254	et	4	main
arva	doc_491521501776_item	2487824	et	4	main
lingvistika	doc_491521501777_item	2487837	et	4	main
on	doc_491521501777_item	2487862	et	4	main
kõnelevad	doc_491521501777_item	2487866	et	4	main
tajuvad	doc_491521501777_item	2487877	et	4	main
juba	doc_491521501777_item	2487878	et	3	main
natukene	doc_491521501777_item	2487879	et	4	main
eesti	doc_491521501777_item	2487880	et	4	main
keelt	doc_491521501777_item	2487881	et	4	main
selle	doc_491521501777_item	2487882	et	4	main
reegleid	doc_491521501777_item	2487883	et	3	main
ja	doc_491521501777_item	2487884	et	3	main
struktuuri	doc_491521501777_item	2487885	et	4	main
mis	doc_491521501777_item	2487886	et	4	main
puudutab	doc_491521501777_item	2487887	et	3	main
teisi	doc_491521501777_item	2487888	et	4	main
tekib	doc_491521501777_item	2487889	et	3	main
selline	doc_491521501777_item	2487890	et	4	main
tunne	doc_491521501777_item	2487891	et	4	main
et	doc_491521501777_item	2487892	et	3	main
neil	doc_491521501777_item	2487893	et	4	main
on	doc_491521501777_item	2487894	et	4	main
vilets	doc_491521501777_item	2487895	et	3	main
sõnavara	doc_491521501777_item	2487896	et	4	main
ning	doc_491521501777_item	2487897	et	3	main
puuduvad	doc_491521501777_item	2487898	et	4	main
elementaarsed	doc_491521501777_item	2487899	et	3	main
grammatika	doc_491521501777_item	2487900	et	4	main
reeglid	doc_491521501777_item	2487901	et	3	main
1h	doc_491521501777_item	2487902	et	4	main
ää	doc_491521501777_item	2487903	et	4	main
ldus	doc_491521501777_item	2487904	et	4	main
ja	doc_491521501777_item	2487905	et	3	main
õigekiri	doc_491521501777_item	2487906	et	3	main
pedagoo	doc_491521501777_item	2487907	et	4	main
k	doc_491521501777_item	2487908	et	4	main
inimene	doc_491521501777_item	2487909	et	3	main
hääldatakse	doc_491521501777_item	2487910	et	3	main
et	doc_491521501776_item	2487825	et	3	main
väiksed	doc_491521501776_item	2487832	et	4	main
parandused	doc_491521501776_item	2487833	et	4	main
saab	doc_491521501776_item	2487834	et	3	main
teha	doc_491521501776_item	2487835	et	3	main
kontrastiivne	doc_491521501777_item	2487836	et	4	main
lingvistika	doc_491521501777_item	2487839	et	4	main
võetud	doc_491521501777_item	2487846	et	4	main
klassi	doc_491521501777_item	2487848	et	4	main
õpilaste	doc_491521501777_item	2487849	et	4	main
töödest	doc_491521501777_item	2487850	et	3	main
kontrolltööd	doc_491521501777_item	2487851	et	4	main
ja	doc_491521501777_item	2487852	et	3	main
kõik	doc_491521501777_item	2487861	et	4	main
keelt	doc_491521501777_item	2487864	et	4	main
tugevad	doc_491521501777_item	2487870	et	4	main
ja	doc_491521501777_item	2487871	et	3	main
väga	doc_491521501777_item	2487872	et	3	main
tublid	doc_491521501777_item	2487873	et	3	main
nähtub	doc_491521501777_item	2487874	et	3	main
et	doc_491521501777_item	2487875	et	3	main
nad	doc_491521501777_item	2487876	et	3	main
õpilased	doc_491521501777_item	2487916	et	3	main
hääldavad	doc_491521501777_item	2487917	et	4	main
a	doc_491521501777_item	2487920	et	4	main
kirjutatakse	doc_491521501777_item	2487924	et	3	main
нтрольная	doc_491521501777_item	2487927	et	2	main
а	doc_491521501777_item	2487931	et	2	main
f	doc_491521501777_item	2487934	et	4	main
üks	doc_491521501777_item	2487939	et	3	main
ü	doc_491521501777_item	2487944	et	4	main
ü	doc_491521501777_item	2487949	et	4	main
ю	doc_491521501777_item	2487952	et	2	main
ga	doc_491521501777_item	2487953	et	4	main
kirjavahemärgid	doc_491521501777_item	2487954	et	3	main
liitlauses	doc_491521501777_item	2487955	et	3	main
unustatakse	doc_491521501777_item	2487956	et	3	main
sest	doc_491521501777_item	2487962	et	4	main
pi	doc_491521501777_item	2488005	et	4	main
vigu	doc_491521501777_item	2488009	et	3	main
vead	doc_491521501777_item	2488019	et	4	main
vahel	doc_491521501777_item	2487918	et	4	main
ntrolltöö	doc_491521501777_item	2487921	et	4	main
mõju	doc_491521501777_item	2487923	et	4	main
mõju	doc_491521501777_item	2487937	et	4	main
oleks	doc_491521501777_item	2487946	et	3	main
koma	doc_491521501777_item	2487957	et	4	main
et	doc_491521501777_item	2487960	et	3	main
jne	doc_491521501777_item	2487964	et	4	main
võib	doc_491521501777_item	2487967	et	3	main
ainult	doc_491521501777_item	2487969	et	4	main
reeglite	doc_491521501777_item	2487970	et	3	main
mittetundmine	doc_491521501777_item	2487971	et	3	main
tu	doc_491521501777_item	2488002	et	4	main
sääraseid	doc_491521501777_item	2488008	et	3	main
on	doc_491521501777_item	2488020	et	4	main
astmevahelduses	doc_491521501777_item	2488025	et	4	main
mosastav	doc_491521501777_item	2488028	et	4	main
as	doc_491521501777_item	2488034	et	4	main
aid	doc_491521501777_item	2488040	et	4	main
vahet	doc_491521501777_item	2488046	et	3	main
ii	doc_491521501777_item	2488048	et	4	main
iii	doc_491521501777_item	2488050	et	4	main
välte	doc_491521501777_item	2488051	et	3	main
hääldamisel	doc_491521501777_item	2488052	et	4	main
välde	doc_491521501777_item	2488058	et	3	main
vorm	doc_491521501777_item	2488081	et	3	main
tegevus	doc_491521501777_item	2488090	et	4	main
antud	doc_491521501777_item	2488091	et	4	main
aga	doc_491521501777_item	2488099	et	3	main
nt	doc_491521501777_item	2488116	et	4	main
valmis	doc_491521501777_item	2488119	et	4	main
mitte	doc_491521501777_item	2488122	et	3	main
сов	doc_491521501777_item	2488126	et	2	main
interferents	doc_491521501777_item	2488129	et	3	main
pu	doc_491521501777_item	2488131	et	4	main
või	doc_491521501777_item	2488134	et	4	main
söön	doc_491521501777_item	2488135	et	3	main
teises	doc_491521501777_item	2488140	et	4	main
emakeele	doc_491521501777_item	2488166	et	4	main
kus	doc_491521501777_item	2488175	et	3	main
näitusesse	doc_491521501777_item	2488185	et	4	main
õpilastel	doc_491521501777_item	2488186	et	4	main
eesti	doc_491521501777_item	2488197	et	4	main
emakeele	doc_491521501777_item	2487922	et	4	main
о	doc_491521501777_item	2487926	et	2	main
к	doc_491521501777_item	2487930	et	2	main
африка	doc_491521501777_item	2487938	et	2	main
nii	doc_491521501777_item	2487942	et	3	main
ees	doc_491521501777_item	2487945	et	4	main
vene	doc_491521501777_item	2487951	et	4	main
mis	doc_491521501777_item	2487963	et	4	main
põhjuseks	doc_491521501777_item	2487966	et	3	main
b	doc_491521501777_item	2487975	et	4	main
radel	doc_491521501777_item	2487976	et	4	main
vormi	doc_491521501777_item	2487977	et	4	main
moodustamist	doc_491521501777_item	2487978	et	4	main
on	doc_491521501777_item	2487979	et	4	main
mõjutanud	doc_491521501777_item	2487980	et	4	main
mitmuse	doc_491521501777_item	2487981	et	3	main
nimetav	doc_491521501777_item	2487982	et	4	main
sõbradsõbrade	doc_491521501777_item	2487983	et	4	main
l	doc_491521501777_item	2487984	et	4	main
sõ	doc_491521501777_item	2487985	et	4	main
b	doc_491521501777_item	2487986	et	4	main
radel	doc_491521501777_item	2487987	et	4	main
õm	doc_491521501777_item	2487988	et	4	main
ble	doc_491521501777_item	2487989	et	4	main
takse	doc_491521501777_item	2487990	et	3	main
tegelikult	doc_491521501777_item	2487991	et	4	main
on	doc_491521501777_item	2487992	et	4	main
vorm	doc_491521501777_item	2487993	et	3	main
moodustatud	doc_491521501777_item	2487994	et	4	main
järgi	doc_491521501777_item	2487996	et	4	main
kuid	doc_491521501777_item	2487997	et	4	main
av	doc_491521501777_item	2487998	et	4	main
reeglite	doc_491521501777_item	2487995	et	3	main
ei	doc_491521501777_item	2487999	et	4	main
ole	doc_491521501777_item	2488000	et	4	main
arvestatud	doc_491521501777_item	2488001	et	4	main
hääldatakse	doc_491521501777_item	2487929	et	3	main
a	doc_491521501777_item	2487933	et	4	main
rika	doc_491521501777_item	2487935	et	4	main
emakeele	doc_491521501777_item	2487936	et	4	main
vahel	doc_491521501777_item	2487940	et	4	main
hääldatakse	doc_491521501777_item	2487941	et	3	main
j	doc_491521501777_item	2487947	et	4	main
eesti	doc_491521501777_item	2487948	et	4	main
sarnaneb	doc_491521501777_item	2487950	et	3	main
panna	doc_491521501777_item	2487958	et	4	main
alistussidendite	doc_491521501777_item	2487959	et	4	main
siis	doc_491521501777_item	2487961	et	3	main
ette	doc_491521501777_item	2487965	et	4	main
olla	doc_491521501777_item	2487968	et	3	main
2	doc_491521501777_item	2487972	et	2	main
astmevaheldus	doc_491521501777_item	2487973	et	4	main
b	doc_491521501777_item	2488003	et	4	main
ad	doc_491521501777_item	2488004	et	4	main
ud	doc_491521501777_item	2488007	et	4	main
on	doc_491521501777_item	2488010	et	4	main
palju	doc_491521501777_item	2488012	et	4	main
neid	doc_491521501777_item	2488013	et	4	main
võib	doc_491521501777_item	2488014	et	3	main
ka	doc_491521501777_item	2488015	et	3	main
vormimoodustusveaks	doc_491521501777_item	2488016	et	4	main
mb	doc_491521501777_item	2488037	et	4	main
ei	doc_491521501777_item	2488044	et	4	main
kirjutan	doc_491521501777_item	2488060	et	3	main
objektivead	doc_491521501777_item	2488080	et	4	main
isa	doc_491521501777_item	2488084	et	4	main
raamatu	doc_491521501777_item	2488086	et	4	main
t	doc_491521501777_item	2488087	et	4	main
juhul	doc_491521501777_item	2488092	et	3	main
peab	doc_491521501777_item	2488093	et	4	main
kasutama	doc_491521501777_item	2488094	et	3	main
omastavat	doc_491521501777_item	2488095	et	4	main
käänet	doc_491521501777_item	2488096	et	3	main
harjunud	doc_491521501777_item	2488100	et	4	main
lugema	doc_491521501777_item	2488102	et	4	main
tegusõna	doc_491521501777_item	2488103	et	4	main
perfektiivsusadverb	doc_491521501777_item	2488115	et	4	main
keeles	doc_491521501777_item	2488124	et	4	main
ru	doc_491521501777_item	2488138	et	4	main
pu	doc_491521501777_item	2488149	et	4	main
s	doc_491521501777_item	2488157	et	4	main
в	doc_491521501777_item	2488160	et	2	main
õ	doc_491521501777_item	2488168	et	4	main
ju	doc_491521501777_item	2488169	et	3	main
остановке	doc_491521501777_item	2488171	et	2	main
на	doc_491521501777_item	2488173	et	2	main
kohvikusse	doc_491521501777_item	2488183	et	4	main
maasse	doc_491521501777_item	2488184	et	3	main
raske	doc_491521501777_item	2488188	et	4	main
poolaka	doc_491521501777_item	2488227	et	4	main
d	doc_491521501777_item	2488236	et	4	main
mõjutas	doc_491521501777_item	2488241	et	3	main
nt	doc_491521501777_item	2488242	et	4	main
küsimuse	doc_491521501777_item	2488244	et	4	main
küsimu	doc_491521501777_item	2488245	et	4	main
ga	doc_491521501777_item	2488259	et	4	main
järgi	doc_491521501777_item	2488279	et	4	main
järgi	doc_491521501777_item	2488293	et	4	main
kohalikud	doc_491521501777_item	2488294	et	3	main
gru	doc_491521501777_item	2488295	et	4	main
gru	doc_491521501777_item	2488300	et	4	main
sid	doc_491521501777_item	2488314	et	4	main
mos	doc_491521501777_item	2488316	et	4	main
lõppe	doc_491521501777_item	2488317	et	4	main
nt	doc_491521501777_item	2488320	et	4	main
pesa	doc_491521501777_item	2488321	et	4	main
õpilane	doc_491521501777_item	2488323	et	3	main
sid	doc_491521501777_item	2488324	et	4	main
tunne	doc_491521501777_item	2488330	et	4	main
ka	doc_491521501777_item	2488339	et	3	main
moodustamist	doc_491521501777_item	2488352	et	4	main
armastusest	doc_491521501777_item	2488368	et	4	main
linna	doc_491521501777_item	2488373	et	4	main
велосипеде	doc_491521501777_item	2488387	et	2	main
чем	doc_491521501777_item	2488390	et	2	main
l	doc_491521501777_item	2488396	et	4	main
õpilastel	doc_491521501777_item	2488422	et	4	main
raske	doc_491521501777_item	2488424	et	4	main
d	doc_491521501777_item	2488006	et	4	main
ka	doc_491521501777_item	2488024	et	3	main
reeglina	doc_491521501777_item	2488026	et	3	main
on	doc_491521501777_item	2488027	et	4	main
om	doc_491521501777_item	2488035	et	4	main
ha	doc_491521501777_item	2488036	et	4	main
eriti	doc_491521501777_item	2488042	et	3	main
ka	doc_491521501777_item	2488047	et	3	main
ja	doc_491521501777_item	2488049	et	3	main
nt	doc_491521501777_item	2488053	et	4	main
ja	doc_491521501777_item	2488059	et	3	main
käändevalik	doc_491521501777_item	2488083	et	4	main
on	doc_491521501777_item	2488098	et	4	main
kasutama	doc_491521501777_item	2488101	et	3	main
on	doc_491521501777_item	2488113	et	4	main
läbi	doc_491521501777_item	2488117	et	4	main
ära	doc_491521501777_item	2488118	et	4	main
несов	doc_491521501777_item	2488125	et	2	main
söön	doc_491521501777_item	2488130	et	3	main
pu	doc_491521501777_item	2488136	et	4	main
lauses	doc_491521501777_item	2488141	et	3	main
tegevusega	doc_491521501777_item	2488145	et	4	main
õige	doc_491521501777_item	2488146	et	4	main
oleks	doc_491521501777_item	2488147	et	3	main
söön	doc_491521501777_item	2488148	et	3	main
interferentne	doc_491521501777_item	2488158	et	4	main
m	doc_491521501777_item	2488167	et	4	main
mille	doc_491521501777_item	2488176	et	3	main
peatuse	doc_491521501777_item	2488178	et	4	main
on	doc_491521501777_item	2488187	et	4	main
käändevead	doc_491521501777_item	2488222	et	4	main
s	doc_491521501777_item	2488231	et	4	main
poolaka	doc_491521501777_item	2488232	et	4	main
se	doc_491521501777_item	2488233	et	4	main
arvata	doc_491521501777_item	2488238	et	4	main
d	doc_491521501777_item	2488247	et	4	main
vormi	doc_491521501777_item	2488248	et	4	main
moodustamine	doc_491521501777_item	2488249	et	4	main
maale	doc_491521501777_item	2488250	et	4	main
sõidame	doc_491521501777_item	2488251	et	3	main
jalgrata	doc_491521501777_item	2488252	et	4	main
jalgrata	doc_491521501777_item	2488255	et	4	main
jalgrata	doc_491521501777_item	2488257	et	4	main
se	doc_491521501777_item	2488258	et	4	main
moodustatud	doc_491521501777_item	2488277	et	4	main
reeglite	doc_491521501777_item	2488278	et	3	main
i	doc_491521501777_item	2488287	et	4	main
d	doc_491521501777_item	2488288	et	4	main
tegutsetakse	doc_491521501777_item	2488289	et	3	main
pp	doc_491521501777_item	2488296	et	4	main
i	doc_491521501777_item	2488302	et	4	main
pp	doc_491521501777_item	2488305	et	4	main
ei	doc_491521501777_item	2488307	et	4	main
õpilane	doc_491521501777_item	2488310	et	3	main
mos	doc_491521501777_item	2488311	et	4	main
õpila	doc_491521501777_item	2488312	et	4	main
on	doc_491521501777_item	2488318	et	4	main
tunne	doc_491521501777_item	2488325	et	4	main
d	doc_491521501777_item	2488331	et	4	main
rääkisin	doc_491521501777_item	2488332	et	3	main
st	doc_491521501777_item	2488336	et	3	main
võiks	doc_491521501777_item	2488338	et	4	main
ühildumisveaks	doc_491521501777_item	2488340	et	4	main
seestütleva	doc_491521501777_item	2488350	et	3	main
s	doc_491521501777_item	2488354	et	4	main
s	doc_491521501777_item	2488356	et	4	main
segi	doc_491521501777_item	2488366	et	3	main
b	doc_491521501777_item	2488370	et	4	main
trammi	doc_491521501777_item	2488375	et	4	main
l	doc_491521501777_item	2488376	et	4	main
l	doc_491521501777_item	2488379	et	4	main
и	doc_491521501777_item	2488385	et	2	main
на	doc_491521501777_item	2488389	et	2	main
ga	doc_491521501777_item	2488404	et	4	main
jne	doc_491521501777_item	2488409	et	4	main
mida	doc_491521501777_item	2488421	et	4	main
on	doc_491521501777_item	2488423	et	4	main
omastava	doc_491521501777_item	2488431	et	4	main
õpitav	doc_491521501777_item	2488435	et	4	main
seal	doc_491521501777_item	2488449	et	4	main
d	doc_491521501777_item	2488455	et	4	main
interferents	doc_491521501777_item	2488480	et	3	main
vormimoodustuses	doc_491521501777_item	2488022	et	3	main
kui	doc_491521501777_item	2488023	et	3	main
nim	doc_491521501777_item	2488031	et	4	main
mm	doc_491521501777_item	2488033	et	4	main
mb	doc_491521501777_item	2488039	et	4	main
iii	doc_491521501777_item	2488057	et	4	main
kirja	doc_491521501777_item	2488061	et	4	main
ja	doc_491521501777_item	2488062	et	3	main
lähen	doc_491521501777_item	2488063	et	3	main
postkontorisse	doc_491521501777_item	2488064	et	3	main
ii	doc_491521501777_item	2488065	et	4	main
välde	doc_491521501777_item	2488066	et	3	main
söön	doc_491521501777_item	2488067	et	3	main
õuna	doc_491521501777_item	2488068	et	4	main
või	doc_491521501777_item	2488069	et	4	main
söön	doc_491521501777_item	2488070	et	3	main
õuna	doc_491521501777_item	2488071	et	4	main
ära	doc_491521501777_item	2488072	et	4	main
ja	doc_491521501777_item	2488073	et	3	main
lähen	doc_491521501777_item	2488074	et	3	main
õue	doc_491521501777_item	2488075	et	4	main
õpilased	doc_491521501777_item	2488076	et	3	main
hääldavad	doc_491521501777_item	2488077	et	4	main
3	doc_491521501777_item	2488079	et	2	main
läbi	doc_491521501777_item	2488088	et	4	main
lõpetatud	doc_491521501777_item	2488089	et	4	main
osastavat	doc_491521501777_item	2488105	et	4	main
seal	doc_491521501777_item	2488114	et	4	main
vene	doc_491521501777_item	2488123	et	4	main
вид	doc_491521501777_item	2488127	et	2	main
t	doc_491521501777_item	2488132	et	4	main
ru	doc_491521501777_item	2488133	et	4	main
ära	doc_491521501777_item	2488139	et	4	main
tegemist	doc_491521501777_item	2488143	et	4	main
d	doc_491521501777_item	2488150	et	4	main
ru	doc_491521501777_item	2488151	et	4	main
ласнамяэ	doc_491521501777_item	2488161	et	2	main
peatuse	doc_491521501777_item	2488164	et	4	main
на	doc_491521501777_item	2488170	et	2	main
где	doc_491521501777_item	2488172	et	2	main
saada	doc_491521501777_item	2488190	et	4	main
vene	doc_491521501777_item	2488192	et	4	main
keeles	doc_491521501777_item	2488193	et	4	main
kasutatakse	doc_491521501777_item	2488194	et	3	main
väliskoha-	doc_491521501777_item	2488195	et	4	main
ja	doc_491521501777_item	2488196	et	3	main
keeles	doc_491521501777_item	2488198	et	4	main
sisekohakäänet	doc_491521501777_item	2488199	et	3	main
ja	doc_491521501777_item	2488200	et	3	main
vastupidi	doc_491521501777_item	2488201	et	3	main
nt	doc_491521501777_item	2488202	et	4	main
на	doc_491521501777_item	2488203	et	2	main
остановке	doc_491521501777_item	2488204	et	2	main
peatuse	doc_491521501777_item	2488205	et	4	main
s	doc_491521501777_item	2488206	et	4	main
в	doc_491521501777_item	2488207	et	2	main
кохтла	doc_491521501777_item	2488208	et	2	main
ярве	doc_491521501777_item	2488209	et	2	main
kohtlajärve	doc_491521501777_item	2488210	et	4	main
l	doc_491521501777_item	2488211	et	4	main
на	doc_491521501777_item	2488212	et	2	main
даче	doc_491521501777_item	2488213	et	2	main
suvila	doc_491521501777_item	2488214	et	4	main
s	doc_491521501777_item	2488215	et	4	main
seda	doc_491521501777_item	2488216	et	3	main
peab	doc_491521501777_item	2488217	et	4	main
meelde	doc_491521501777_item	2488218	et	3	main
jätma	doc_491521501777_item	2488219	et	3	main
5	doc_491521501777_item	2488220	et	2	main
span	doc_491521501777_item	2488225	et	4	main
se	doc_491521501777_item	2488228	et	4	main
seda	doc_491521501777_item	2488240	et	3	main
küsimus	doc_491521501777_item	2488243	et	4	main
se	doc_491521501777_item	2488246	et	4	main
id	doc_491521501777_item	2488282	et	4	main
t	doc_491521501777_item	2488284	et	4	main
reegli	doc_491521501777_item	2488292	et	3	main
gru	doc_491521501777_item	2488298	et	4	main
gru	doc_491521501777_item	2488304	et	4	main
üks	doc_491521501777_item	2488315	et	3	main
vormimoodustus	doc_491521501777_item	2488224	et	3	main
d	doc_491521501777_item	2488229	et	4	main
poolaka	doc_491521501777_item	2488230	et	4	main
võib	doc_491521501777_item	2488237	et	3	main
se	doc_491521501777_item	2488253	et	4	main
jalgrata	doc_491521501777_item	2488260	et	4	main
se	doc_491521501777_item	2488261	et	4	main
ga	doc_491521501777_item	2488262	et	4	main
kaunis	doc_491521501777_item	2488263	et	4	main
kauni	doc_491521501777_item	2488264	et	4	main
se	doc_491521501777_item	2488265	et	4	main
l	doc_491521501777_item	2488266	et	4	main
kauni	doc_491521501777_item	2488267	et	4	main
s	doc_491521501777_item	2488268	et	4	main
kauni	doc_491521501777_item	2488269	et	4	main
se	doc_491521501777_item	2488270	et	4	main
l	doc_491521501777_item	2488271	et	4	main
nb	doc_491521501777_item	2488272	et	4	main
tegelikult	doc_491521501777_item	2488273	et	4	main
on	doc_491521501777_item	2488274	et	4	main
need	doc_491521501777_item	2488275	et	3	main
vormid	doc_491521501777_item	2488276	et	4	main
s	doc_491521501777_item	2488256	et	4	main
t	doc_491521501777_item	2488281	et	4	main
kaar	doc_491521501777_item	2488283	et	3	main
kaar	doc_491521501777_item	2488285	et	3	main
t	doc_491521501777_item	2488286	et	4	main
õpitud	doc_491521501777_item	2488291	et	4	main
pp	doc_491521501777_item	2488299	et	4	main
pp	doc_491521501777_item	2488301	et	4	main
sid	doc_491521501777_item	2488322	et	4	main
selle	doc_491521501777_item	2488333	et	4	main
kuid	doc_491521501777_item	2488342	et	4	main
ga	doc_491521501777_item	2488357	et	4	main
ja	doc_491521501777_item	2488358	et	3	main
seestütlev	doc_491521501777_item	2488359	et	3	main
ga	doc_491521501777_item	2488361	et	4	main
aetud	doc_491521501777_item	2488367	et	4	main
ja	doc_491521501777_item	2488377	et	3	main
jalgratta	doc_491521501777_item	2488378	et	4	main
трамвае	doc_491521501777_item	2488384	et	2	main
peaks	doc_491521501777_item	2488398	et	4	main
s	doc_491521501777_item	2488400	et	4	main
õ	doc_491521501777_item	2488401	et	4	main
itma	doc_491521501777_item	2488402	et	4	main
mille	doc_491521501777_item	2488403	et	3	main
ga	doc_491521501777_item	2488408	et	4	main
auto	doc_491521501777_item	2488430	et	4	main
osastav	doc_491521501777_item	2488434	et	4	main
reegel	doc_491521501777_item	2488436	et	3	main
arvsõna	doc_491521501777_item	2488438	et	4	main
inimesi	doc_491521501777_item	2488443	et	4	main
mõju	doc_491521501777_item	2488445	et	4	main
двести	doc_491521501777_item	2488446	et	2	main
человек	doc_491521501777_item	2488447	et	2	main
mitmus	doc_491521501777_item	2488448	et	3	main
lap	doc_491521501777_item	2488472	et	4	main
si	doc_491521501777_item	2488473	et	4	main
keelesisene	doc_491521501777_item	2488479	et	3	main
mitme	doc_491521501777_item	2488485	et	4	main
nt	doc_491521501777_item	2488490	et	4	main
kolmas	doc_491521501777_item	2488491	et	3	main
kolma	doc_491521501777_item	2488494	et	4	main
tehtud	doc_491521501777_item	2488502	et	4	main
ka	doc_491521501777_item	2488503	et	3	main
teine	doc_491521501777_item	2488504	et	3	main
teisenda	doc_491521501777_item	2488505	et	4	main
lubatud	doc_491521501777_item	2488512	et	4	main
kirjas	doc_491521501777_item	2488517	et	4	main
eristata	doc_491521501777_item	2488519	et	3	main
tavaliselt	doc_491521501777_item	2488520	et	4	main
põhi-	doc_491521501777_item	2488521	et	3	main
4	doc_491521501777_item	2488537	et	2	main
4	doc_491521501777_item	2488542	et	2	main
mitte	doc_491521501777_item	2488554	et	3	main
ühildumisvead	doc_491521501777_item	2488572	et	4	main
nimisõnafraasi	doc_491521501777_item	2488576	et	4	main
ajaleht	doc_491521501777_item	2488586	et	3	main
osastavas	doc_491521501777_item	2488628	et	4	main
käändes	doc_491521501777_item	2488629	et	3	main
ja	doc_491521501777_item	2488630	et	3	main
täiendid	doc_491521501777_item	2488631	et	3	main
predikatsioon	doc_491521501777_item	2488640	et	4	main
omadussõna	doc_491521501777_item	2488642	et	4	main
võrdlusastmed	doc_491521501777_item	2488643	et	3	main
pidulik	doc_491521501777_item	2488651	et	3	main
eelneva	doc_491521501777_item	2488654	et	4	main
a	doc_491521501777_item	2488660	et	4	main
m	doc_491521501777_item	2488661	et	4	main
ilus	doc_491521501777_item	2488662	et	4	main
m	doc_491521501777_item	2488668	et	4	main
10	doc_491521501777_item	2488672	et	2	main
ma	doc_491521501777_item	2488723	et	3	main
on	doc_491521501777_item	2488726	et	4	main
kardama	doc_491521501777_item	2488730	et	3	main
siin	doc_491521501777_item	2488743	et	4	main
moodustatud	doc_491521501777_item	2488749	et	4	main
moodustub	doc_491521501777_item	2488758	et	3	main
lihtminevik	doc_491521501777_item	2488759	et	3	main
moodustatud	doc_491521501777_item	2488777	et	4	main
tunnus	doc_491521501777_item	2488781	et	3	main
kaar	doc_491521501777_item	2488280	et	3	main
pähe	doc_491521501777_item	2488290	et	4	main
id	doc_491521501777_item	2488297	et	4	main
d	doc_491521501777_item	2488303	et	4	main
id	doc_491521501777_item	2488306	et	4	main
tajuta	doc_491521501777_item	2488308	et	4	main
avst	doc_491521501777_item	2488309	et	4	main
ne	doc_491521501777_item	2488313	et	4	main
sid	doc_491521501777_item	2488319	et	4	main
nn	doc_491521501777_item	2488327	et	4	main
ed	doc_491521501777_item	2488328	et	4	main
tunne	doc_491521501777_item	2488329	et	4	main
st	doc_491521501777_item	2488334	et	3	main
hulka	doc_491521501777_item	2488347	et	4	main
nimetav	doc_491521501777_item	2488348	et	4	main
mõjutas	doc_491521501777_item	2488349	et	3	main
armastu	doc_491521501777_item	2488353	et	4	main
lõpeb	doc_491521501777_item	2488355	et	4	main
ning	doc_491521501777_item	2488362	et	3	main
vormikasutus	doc_491521501777_item	2488371	et	4	main
vene	doc_491521501777_item	2488380	et	4	main
на	doc_491521501777_item	2488386	et	2	main
mille	doc_491521501777_item	2488391	et	3	main
trammi	doc_491521501777_item	2488393	et	4	main
l	doc_491521501777_item	2488394	et	4	main
tegelikult	doc_491521501777_item	2488397	et	4	main
olema	doc_491521501777_item	2488399	et	4	main
ga	doc_491521501777_item	2488406	et	4	main
jalgratta	doc_491521501777_item	2488407	et	4	main
pronoomenivead	doc_491521501777_item	2488428	et	4	main
teda	doc_491521501777_item	2488429	et	4	main
käänamine	doc_491521501777_item	2488439	et	4	main
kakssada	doc_491521501777_item	2488442	et	4	main
emakeele	doc_491521501777_item	2488444	et	4	main
v	doc_491521501777_item	2488452	et	4	main
ä	doc_491521501777_item	2488453	et	4	main
ikese	doc_491521501777_item	2488454	et	4	main
si	doc_491521501777_item	2488457	et	4	main
mos	doc_491521501777_item	2488474	et	4	main
küünlapäev	doc_491521501777_item	2488475	et	3	main
on	doc_491521501777_item	2488476	et	4	main
käändub	doc_491521501777_item	2488483	et	3	main
nda	doc_491521501777_item	2488493	et	4	main
nda	doc_491521501777_item	2488495	et	4	main
sama	doc_491521501777_item	2488498	et	4	main
on	doc_491521501777_item	2488511	et	4	main
го	doc_491521501777_item	2488515	et	2	main
ei	doc_491521501777_item	2488518	et	4	main
ei	doc_491521501777_item	2488530	et	4	main
saada	doc_491521501777_item	2488531	et	4	main
aru	doc_491521501777_item	2488532	et	4	main
lehel	doc_491521501777_item	2488540	et	3	main
lehel	doc_491521501777_item	2488543	et	3	main
lehel	doc_491521501777_item	2488545	et	3	main
enamus	doc_491521501777_item	2488546	et	4	main
kasutatud	doc_491521501777_item	2488552	et	4	main
on	doc_491521501777_item	2488561	et	4	main
tahetud	doc_491521501777_item	2488562	et	4	main
id	doc_491521501777_item	2488570	et	4	main
ja	doc_491521501777_item	2488578	et	3	main
ühildumine	doc_491521501777_item	2488580	et	4	main
uu	doc_491521501777_item	2488581	et	3	main
e	doc_491521501777_item	2488582	et	4	main
i	doc_491521501777_item	2488587	et	4	main
m	doc_491521501777_item	2488588	et	4	main
keda	doc_491521501777_item	2488622	et	4	main
kasutatud	doc_491521501777_item	2488624	et	4	main
õigesti	doc_491521501777_item	2488625	et	3	main
kuid	doc_491521501777_item	2488626	et	4	main
omastavas	doc_491521501777_item	2488632	et	4	main
terve	doc_491521501777_item	2488638	et	4	main
d	doc_491521501777_item	2488639	et	4	main
m	doc_491521501777_item	2488647	et	4	main
päev	doc_491521501777_item	2488648	et	3	main
a	doc_491521501777_item	2488652	et	4	main
a	doc_491521501777_item	2488663	et	4	main
pidulik	doc_491521501777_item	2488669	et	3	main
verbivormide	doc_491521501777_item	2488673	et	4	main
oleb	doc_491521501777_item	2488676	et	4	main
tööga	doc_491521501777_item	2488678	et	3	main
rahul	doc_491521501777_item	2488679	et	4	main
õpilased	doc_491521501777_item	2488719	et	3	main
tu	doc_491521501777_item	2488326	et	4	main
armastu	doc_491521501777_item	2488335	et	4	main
seda	doc_491521501777_item	2488337	et	3	main
pidada	doc_491521501777_item	2488341	et	4	main
see	doc_491521501777_item	2488343	et	3	main
kuulub	doc_491521501777_item	2488344	et	3	main
pigem	doc_491521501777_item	2488345	et	3	main
vormimoodustusvigade	doc_491521501777_item	2488346	et	4	main
käände	doc_491521501777_item	2488351	et	4	main
st	doc_491521501777_item	2488360	et	3	main
armastu	doc_491521501777_item	2488363	et	4	main
st	doc_491521501777_item	2488364	et	3	main
on	doc_491521501777_item	2488365	et	4	main
ga	doc_491521501777_item	2488369	et	4	main
span	doc_491521501777_item	2488372	et	4	main
sõidame	doc_491521501777_item	2488374	et	3	main
keele	doc_491521501777_item	2488381	et	4	main
mõju	doc_491521501777_item	2488382	et	4	main
на	doc_491521501777_item	2488383	et	2	main
ехать	doc_491521501777_item	2488388	et	2	main
l	doc_491521501777_item	2488392	et	4	main
jalgratta	doc_491521501777_item	2488395	et	4	main
trammi	doc_491521501777_item	2488405	et	4	main
mööda	doc_491521501777_item	2488410	et	4	main
tänava	doc_491521501777_item	2488411	et	4	main
по	doc_491521501777_item	2488412	et	2	main
улице	doc_491521501777_item	2488413	et	2	main
по	doc_491521501777_item	2488414	et	2	main
чему	doc_491521501777_item	2488415	et	2	main
предл	doc_491521501777_item	2488416	et	2	main
п	doc_491521501777_item	2488417	et	2	main
eesti	doc_491521501777_item	2488418	et	4	main
keeles	doc_491521501777_item	2488419	et	4	main
mööda	doc_491521501777_item	2488420	et	4	main
asemel	doc_491521501777_item	2488432	et	4	main
kasutamine	doc_491521501777_item	2488441	et	4	main
oli	doc_491521501777_item	2488450	et	3	main
mitu	doc_491521501777_item	2488451	et	4	main
lap	doc_491521501777_item	2488456	et	4	main
emakeele	doc_491521501777_item	2488458	et	4	main
mõju	doc_491521501777_item	2488459	et	4	main
несколько	doc_491521501777_item	2488460	et	2	main
детей	doc_491521501777_item	2488462	et	2	main
маленьких	doc_491521501777_item	2488461	et	2	main
несколько	doc_491521501777_item	2488463	et	2	main
mitmus	doc_491521501777_item	2488464	et	3	main
teine	doc_491521501777_item	2488465	et	3	main
on	doc_491521501777_item	2488466	et	4	main
ühildumisviga	doc_491521501777_item	2488467	et	4	main
väikes	doc_491521501777_item	2488468	et	4	main
e	doc_491521501777_item	2488469	et	4	main
d	doc_491521501777_item	2488470	et	4	main
seost	doc_491521501777_item	2488425	et	3	main
leida	doc_491521501777_item	2488426	et	3	main
6	doc_491521501777_item	2488427	et	2	main
on	doc_491521501777_item	2488433	et	4	main
7	doc_491521501777_item	2488437	et	2	main
ja	doc_491521501777_item	2488440	et	3	main
veebruaril	doc_491521501777_item	2488478	et	3	main
enamik	doc_491521501777_item	2488481	et	3	main
t	doc_491521501777_item	2488489	et	4	main
l	doc_491521501777_item	2488496	et	4	main
on	doc_491521501777_item	2488501	et	4	main
kirjutada	doc_491521501777_item	2488513	et	3	main
июня	doc_491521501777_item	2488516	et	2	main
mnim	doc_491521501777_item	2488471	et	4	main
teisendal	doc_491521501777_item	2488477	et	4	main
järgarvsõnu	doc_491521501777_item	2488482	et	4	main
mitmes	doc_491521501777_item	2488484	et	4	main
nda	doc_491521501777_item	2488486	et	4	main
mitme	doc_491521501777_item	2488487	et	4	main
kolma	doc_491521501777_item	2488492	et	4	main
veebruaril	doc_491521501777_item	2488497	et	3	main
skeemi	doc_491521501777_item	2488499	et	4	main
järgi	doc_491521501777_item	2488500	et	4	main
l	doc_491521501777_item	2488506	et	4	main
7-l	doc_491521501777_item	2488507	et	3	main
juunil	doc_491521501777_item	2488508	et	3	main
vene	doc_491521501777_item	2488509	et	4	main
keeles	doc_491521501777_item	2488510	et	4	main
panda	doc_491521501777_item	2488524	et	4	main
punkti	doc_491521501777_item	2488525	et	4	main
nt	doc_491521501777_item	2488526	et	4	main
4	doc_491521501777_item	2488527	et	2	main
lehel	doc_491521501777_item	2488528	et	3	main
siit	doc_491521501777_item	2488529	et	3	main
on	doc_491521501777_item	2488534	et	4	main
lehel	doc_491521501777_item	2488538	et	3	main
pühendatud	doc_491521501777_item	2488550	et	4	main
valesti	doc_491521501777_item	2488551	et	3	main
teiseks	doc_491521501777_item	2488560	et	4	main
lause	doc_491521501777_item	2488569	et	4	main
ajalehti	doc_491521501777_item	2488575	et	4	main
täiendi	doc_491521501777_item	2488577	et	3	main
omastavas	doc_491521501777_item	2488584	et	4	main
ei	doc_491521501777_item	2488634	et	4	main
kõik	doc_491521501777_item	2488636	et	4	main
kõige	doc_491521501777_item	2488644	et	4	main
õnneliku	doc_491521501777_item	2488645	et	3	main
i	doc_491521501777_item	2488646	et	4	main
mõju	doc_491521501777_item	2488657	et	4	main
a	doc_491521501777_item	2488670	et	4	main
moodustusvead	doc_491521501777_item	2488674	et	4	main
sõnajärj	doc_491521501777_item	2488717	et	4	main
da	doc_491521501777_item	2488722	et	4	main
ma	doc_491521501777_item	2488729	et	3	main
võib	doc_491521501777_item	2488735	et	3	main
nimisõna	doc_491521501777_item	2488738	et	4	main
vorm	doc_491521501777_item	2488739	et	3	main
valesti	doc_491521501777_item	2488748	et	3	main
osastav	doc_491521501777_item	2488750	et	4	main
sid	doc_491521501777_item	2488756	et	4	main
si-	doc_491521501777_item	2488764	et	4	main
laulsid	doc_491521501777_item	2488766	et	4	main
laulavad	doc_491521501777_item	2488769	et	4	main
asin	doc_491521501777_item	2488775	et	3	main
vorm	doc_491521501777_item	2488776	et	3	main
lihtmineviku	doc_491521501777_item	2488780	et	3	main
minu	doc_491521501777_item	2488783	et	3	main
nägi	doc_491521501777_item	2488828	et	3	main
tean	doc_491521501777_item	2488833	et	3	main
s	doc_491521501777_item	2488836	et	4	main
lähema	doc_491521501777_item	2488838	et	4	main
pöörde	doc_491521501777_item	2488844	et	3	main
tihti	doc_491521501777_item	2488851	et	3	main
valiku	doc_491521501777_item	2488854	et	3	main
maailma	doc_491521501777_item	2488862	et	4	main
ei	doc_491521501777_item	2488882	et	4	main
kasutatakse	doc_491521501777_item	2488891	et	3	main
nda	doc_491521501777_item	2488488	et	4	main
7-	doc_491521501777_item	2488514	et	4	main
ega	doc_491521501777_item	2488523	et	3	main
tahetud	doc_491521501777_item	2488535	et	4	main
neljal	doc_491521501777_item	2488539	et	4	main
voi	doc_491521501777_item	2488541	et	4	main
neljandal	doc_491521501777_item	2488544	et	3	main
laus	doc_491521501777_item	2488547	et	3	main
on	doc_491521501777_item	2488549	et	4	main
hulgasõna	doc_491521501777_item	2488553	et	4	main
klassi	doc_491521501777_item	2488556	et	4	main
vaid	doc_491521501777_item	2488557	et	3	main
klassi	doc_491521501777_item	2488558	et	4	main
arvatavasti	doc_491521501777_item	2488563	et	3	main
kasutada	doc_491521501777_item	2488564	et	3	main
mitmuse	doc_491521501777_item	2488565	et	3	main
osastavat	doc_491521501777_item	2488566	et	4	main
8	doc_491521501777_item	2488571	et	2	main
a	doc_491521501777_item	2488583	et	4	main
osastavas	doc_491521501777_item	2488589	et	4	main
järgarvsõna	doc_491521501777_item	2488522	et	4	main
mida	doc_491521501777_item	2488533	et	4	main
öelda	doc_491521501777_item	2488536	et	4	main
u	doc_491521501777_item	2488548	et	4	main
enamus	doc_491521501777_item	2488555	et	4	main
enamus	doc_491521501777_item	2488559	et	4	main
õige	doc_491521501777_item	2488567	et	4	main
vorm	doc_491521501777_item	2488568	et	3	main
vaatasin	doc_491521501777_item	2488573	et	3	main
uue	doc_491521501777_item	2488574	et	3	main
põhisõna	doc_491521501777_item	2488579	et	4	main
ja	doc_491521501777_item	2488585	et	3	main
käändes	doc_491521501777_item	2488590	et	3	main
näeb	doc_491521501777_item	2488591	et	3	main
kuri	doc_491521501777_item	2488592	et	4	main
koerat	doc_491521501777_item	2488593	et	4	main
täiend	doc_491521501777_item	2488594	et	3	main
on	doc_491521501777_item	2488595	et	4	main
nimetavas	doc_491521501777_item	2488596	et	4	main
käändes	doc_491521501777_item	2488597	et	3	main
põhisõna	doc_491521501777_item	2488598	et	4	main
koerat	doc_491521501777_item	2488599	et	4	main
osastavas	doc_491521501777_item	2488600	et	4	main
käändes	doc_491521501777_item	2488601	et	3	main
õige	doc_491521501777_item	2488602	et	4	main
koera	doc_491521501777_item	2488603	et	4	main
pärast	doc_491521501777_item	2488604	et	4	main
ma	doc_491521501777_item	2488605	et	3	main
tuli	doc_491521501777_item	2488606	et	4	main
d	doc_491521501777_item	2488607	et	4	main
koju	doc_491521501777_item	2488608	et	3	main
predikatsioon	doc_491521501777_item	2488609	et	4	main
ma	doc_491521501777_item	2488610	et	3	main
ela	doc_491521501777_item	2488611	et	4	main
s	doc_491521501777_item	2488612	et	4	main
lasnamäel	doc_491521501777_item	2488613	et	3	main
nägin	doc_491521501777_item	2488614	et	3	main
ühe	doc_491521501777_item	2488615	et	4	main
imeliku	doc_491521501777_item	2488616	et	3	main
tüdrukut	doc_491521501777_item	2488617	et	3	main
nägin	doc_491521501777_item	2488618	et	3	main
tüdruku	doc_491521501777_item	2488619	et	3	main
t	doc_491521501777_item	2488620	et	4	main
nägin	doc_491521501777_item	2488621	et	3	main
9	doc_491521501777_item	2488641	et	2	main
ilusam	doc_491521501777_item	2488649	et	4	main
m	doc_491521501777_item	2488653	et	4	main
sõna	doc_491521501777_item	2488655	et	4	main
vormi	doc_491521501777_item	2488656	et	4	main
pidulik	doc_491521501777_item	2488665	et	3	main
rektsioon	doc_491521501777_item	2488623	et	3	main
põhisõna	doc_491521501777_item	2488627	et	4	main
käändes	doc_491521501777_item	2488633	et	3	main
ühildu	doc_491521501777_item	2488635	et	4	main
oli	doc_491521501777_item	2488637	et	3	main
ja	doc_491521501777_item	2488650	et	3	main
ilus	doc_491521501777_item	2488658	et	4	main
ilus	doc_491521501777_item	2488659	et	4	main
m	doc_491521501777_item	2488664	et	4	main
m	doc_491521501777_item	2488671	et	4	main
mõju	doc_491521501777_item	2488682	et	4	main
keelesisene	doc_491521501777_item	2488683	et	3	main
interferents	doc_491521501777_item	2488684	et	3	main
ole	doc_491521501777_item	2488685	et	4	main
n	doc_491521501777_item	2488686	et	4	main
ole	doc_491521501777_item	2488687	et	4	main
d	doc_491521501777_item	2488688	et	4	main
ole	doc_491521501777_item	2488689	et	4	main
b	doc_491521501777_item	2488690	et	4	main
ole	doc_491521501777_item	2488691	et	4	main
me	doc_491521501777_item	2488692	et	4	main
jne	doc_491521501777_item	2488693	et	4	main
õpitav	doc_491521501777_item	2488694	et	4	main
reegel	doc_491521501777_item	2488695	et	3	main
vanaema	doc_491521501777_item	2488696	et	4	main
nägeb	doc_491521501777_item	2488697	et	4	main
kuri	doc_491521501777_item	2488698	et	4	main
koerat	doc_491521501777_item	2488699	et	4	main
eile	doc_491521501777_item	2488700	et	3	main
sõnavormi	doc_491521501777_item	2488701	et	4	main
kasutus-	doc_491521501777_item	2488702	et	4	main
ja	doc_491521501777_item	2488703	et	3	main
modustusvead	doc_491521501777_item	2488704	et	4	main
nägema	doc_491521501777_item	2488705	et	3	main
kedamida	doc_491521501777_item	2488706	et	4	main
kuri	doc_491521501777_item	2488707	et	4	main
kurja	doc_491521501777_item	2488708	et	4	main
kur	doc_491521501777_item	2488709	et	4	main
ja	doc_491521501777_item	2488710	et	3	main
koera	doc_491521501777_item	2488712	et	4	main
koer	doc_491521501777_item	2488711	et	3	main
koer	doc_491521501777_item	2488713	et	3	main
a	doc_491521501777_item	2488714	et	4	main
os	doc_491521501777_item	2488715	et	4	main
pidulik	doc_491521501777_item	2488666	et	3	main
a	doc_491521501777_item	2488667	et	4	main
mari	doc_491521501777_item	2488675	et	4	main
oma	doc_491521501777_item	2488677	et	4	main
teiste	doc_491521501777_item	2488680	et	4	main
vormide	doc_491521501777_item	2488681	et	3	main
kääne	doc_491521501777_item	2488716	et	3	main
evead	doc_491521501777_item	2488718	et	4	main
peavad	doc_491521501777_item	2488720	et	4	main
õpetaja	doc_491521501777_item	2488724	et	4	main
ma-inf	doc_491521501777_item	2488725	et	4	main
moodustatud	doc_491521501777_item	2488727	et	4	main
rektsiooniviga	doc_491521501777_item	2488731	et	4	main
kuigi	doc_491521501777_item	2488734	et	3	main
et	doc_491521501777_item	2488737	et	3	main
aga	doc_491521501777_item	2488745	et	3	main
vormimoodustusviga	doc_491521501777_item	2488746	et	4	main
a	doc_491521501777_item	2488755	et	4	main
kõne	doc_491521501777_item	2488761	et	4	main
d	doc_491521501777_item	2488765	et	4	main
d	doc_491521501777_item	2488771	et	4	main
laulasid	doc_491521501777_item	2488772	et	4	main
sõi	doc_491521501777_item	2488773	et	3	main
eb	doc_491521501777_item	2488787	et	4	main
süüa	doc_491521501777_item	2488788	et	3	main
te	doc_491521501777_item	2488789	et	4	main
g	doc_491521501777_item	2488790	et	4	main
nägi	doc_491521501777_item	2488822	et	3	main
lm	doc_491521501777_item	2488834	et	4	main
teas	doc_491521501777_item	2488837	et	4	main
vormi	doc_491521501777_item	2488839	et	4	main
lähen	doc_491521501777_item	2488846	et	3	main
kalevipoeg	doc_491521501777_item	2488856	et	3	main
hakkas	doc_491521501777_item	2488857	et	3	main
t	doc_491521501777_item	2488859	et	4	main
lõppu	doc_491521501777_item	2488863	et	4	main
t	doc_491521501777_item	2488865	et	4	main
b	doc_491521501777_item	2488867	et	4	main
küünlad	doc_491521501777_item	2488877	et	3	main
interferentne	doc_491521501777_item	2488878	et	4	main
viga	doc_491521501777_item	2488879	et	4	main
ole	doc_491521501777_item	2488883	et	4	main
vahet	doc_491521501777_item	2488884	et	3	main
kas	doc_491521501777_item	2488885	et	3	main
lause	doc_491521501777_item	2488886	et	4	main
lause	doc_491521501777_item	2488902	et	4	main
свечи	doc_491521501777_item	2488904	et	2	main
ka	doc_491521501777_item	2488921	et	3	main
tuli	doc_491521501777_item	2488928	et	4	main
õpilane	doc_491521501777_item	2488933	et	3	main
ega	doc_491521501777_item	2488938	et	3	main
võimalusi	doc_491521501777_item	2488943	et	3	main
tulema	doc_491521501777_item	2488947	et	4	main
ei	doc_491521501777_item	2488955	et	4	main
saa	doc_491521501777_item	2488956	et	4	main
da-	doc_491521501777_item	2488960	et	4	main
ole	doc_491521501777_item	2488968	et	4	main
pes	doc_491521501777_item	2488971	et	4	main
on	doc_491521501777_item	2488976	et	4	main
da-	doc_491521501777_item	2488985	et	4	main
tuletised	doc_491521501777_item	2488992	et	3	main
odava	doc_491521501777_item	2489003	et	3	main
sti	doc_491521501777_item	2489007	et	4	main
roheline	doc_491521501777_item	2489008	et	4	main
rohe	doc_491521501777_item	2489009	et	4	main
selle	doc_491521501777_item	2489014	et	4	main
järgi	doc_491521501777_item	2489016	et	4	main
roheline	doc_491521501777_item	2489017	et	4	main
liide	doc_491521501777_item	2489021	et	4	main
m	doc_491521501777_item	2489028	et	4	main
a	doc_491521501777_item	2489029	et	4	main
sõnaühend	doc_491521501777_item	2489035	et	3	main
suvilinn	doc_491521501777_item	2489036	et	3	main
ja	doc_491521501777_item	2489040	et	3	main
страха	doc_491521501777_item	2489045	et	2	main
п	doc_491521501777_item	2489050	et	2	main
toas	doc_491521501777_item	2489053	et	3	main
vene	doc_491521501777_item	2489061	et	4	main
c	doc_491521501777_item	2489063	et	4	main
uusmoodustised	doc_491521501777_item	2489064	et	3	main
kassi	doc_491521501777_item	2489067	et	4	main
span	doc_491521501777_item	2489079	et	4	main
konflikt	doc_491521501777_item	2489081	et	3	main
on	doc_491521501777_item	2489092	et	4	main
pidu	doc_491521501777_item	2489111	et	4	main
etas	doc_491521501777_item	2489114	et	4	main
viga	doc_491521501777_item	2489127	et	4	main
et	doc_491521501777_item	2489133	et	3	main
rektsioonivead	doc_491521501777_item	2489146	et	4	main
sa	doc_491521501777_item	2489151	et	3	main
kar	doc_491521501777_item	2488721	et	4	main
kardan	doc_491521501777_item	2488728	et	4	main
kartma	doc_491521501777_item	2488732	et	3	main
kedamida	doc_491521501777_item	2488733	et	4	main
oletada	doc_491521501777_item	2488736	et	3	main
on	doc_491521501777_item	2488744	et	4	main
kääne	doc_491521501777_item	2488751	et	3	main
alguses	doc_491521501777_item	2488753	et	4	main
laul	doc_491521501777_item	2488754	et	4	main
jaatav	doc_491521501777_item	2488760	et	4	main
laulma	doc_491521501777_item	2488763	et	3	main
si-	doc_491521501777_item	2488770	et	4	main
sõidan	doc_491521501777_item	2488778	et	3	main
n	doc_491521501777_item	2488782	et	4	main
õde	doc_491521501777_item	2488784	et	4	main
g	doc_491521501777_item	2488786	et	4	main
b	doc_491521501777_item	2488795	et	4	main
te	doc_491521501777_item	2488796	et	4	main
g	doc_491521501777_item	2488797	et	4	main
eb	doc_491521501777_item	2488798	et	4	main
ta	doc_491521501777_item	2488799	et	4	main
nägi	doc_491521501777_item	2488800	et	3	main
s	doc_491521501777_item	2488801	et	4	main
mõned	doc_491521501777_item	2488802	et	3	main
on	doc_491521501777_item	2488803	et	4	main
selgeks	doc_491521501777_item	2488804	et	3	main
õppinud	doc_491521501777_item	2488805	et	4	main
et	doc_491521501777_item	2488806	et	3	main
lihtminevikus	doc_491521501777_item	2488807	et	3	main
lm	doc_491521501777_item	2488808	et	4	main
on	doc_491521501777_item	2488809	et	4	main
3	doc_491521501777_item	2488810	et	2	main
isiku	doc_491521501777_item	2488811	et	3	main
tunnus	doc_491521501777_item	2488812	et	3	main
s	doc_491521501777_item	2488813	et	4	main
ja	doc_491521501777_item	2488814	et	3	main
kasutavad	doc_491521501777_item	2488815	et	4	main
seda	doc_491521501777_item	2488816	et	3	main
pöördelõpuna	doc_491521501777_item	2488817	et	3	main
igat	doc_491521501777_item	2488818	et	3	main
vormi	doc_491521501777_item	2488819	et	4	main
moodustades	doc_491521501777_item	2488820	et	3	main
ma	doc_491521501777_item	2488821	et	3	main
ta	doc_491521501777_item	2488827	et	4	main
teas	doc_491521501777_item	2488832	et	4	main
mõjutas	doc_491521501777_item	2488841	et	3	main
see	doc_491521501777_item	2488849	et	3	main
vead	doc_491521501777_item	2488855	et	4	main
b	doc_491521501777_item	2488861	et	4	main
ma	doc_491521501777_item	2488873	et	3	main
keeles	doc_491521501777_item	2488881	et	4	main
voi	doc_491521501777_item	2488889	et	4	main
umbisikuline	doc_491521501777_item	2488890	et	4	main
sama	doc_491521501777_item	2488894	et	4	main
делали	doc_491521501777_item	2488897	et	2	main
предложение	doc_491521501777_item	2488900	et	2	main
on	doc_491521501777_item	2488740	et	4	main
kasutatud	doc_491521501777_item	2488741	et	4	main
õigesti	doc_491521501777_item	2488742	et	3	main
st	doc_491521501777_item	2488747	et	3	main
õpetaja	doc_491521501777_item	2488752	et	4	main
reeglina	doc_491521501777_item	2488757	et	3	main
ma-infinitiivist	doc_491521501777_item	2488762	et	3	main
siin	doc_491521501777_item	2488767	et	4	main
aga	doc_491521501777_item	2488768	et	3	main
d	doc_491521501777_item	2488774	et	4	main
si-	doc_491521501777_item	2488779	et	4	main
te	doc_491521501777_item	2488785	et	4	main
ema	doc_491521501777_item	2488791	et	4	main
3	doc_491521501777_item	2488792	et	2	main
isiku	doc_491521501777_item	2488793	et	3	main
pöördelõpp	doc_491521501777_item	2488794	et	3	main
n	doc_491521501777_item	2488823	et	4	main
nägi	doc_491521501777_item	2488825	et	3	main
s	doc_491521501777_item	2488829	et	4	main
jne	doc_491521501777_item	2488830	et	4	main
tunnus	doc_491521501777_item	2488835	et	3	main
moodustamist	doc_491521501777_item	2488840	et	4	main
l	doc_491521501777_item	2488843	et	4	main
vorm	doc_491521501777_item	2488845	et	3	main
juhtub	doc_491521501777_item	2488848	et	3	main
väga	doc_491521501777_item	2488850	et	3	main
verbivormide	doc_491521501777_item	2488853	et	4	main
mõjutas	doc_491521501777_item	2488868	et	3	main
eelmine	doc_491521501777_item	2488869	et	3	main
sõnavorm	doc_491521501777_item	2488870	et	3	main
õige	doc_491521501777_item	2488871	et	4	main
hakkama	doc_491521501777_item	2488872	et	3	main
küünlapäeval	doc_491521501777_item	2488875	et	3	main
ja	doc_491521501777_item	2488893	et	3	main
они	doc_491521501777_item	2488896	et	2	main
свечи	doc_491521501777_item	2488898	et	2	main
isikuline	doc_491521501777_item	2488901	et	4	main
делали	doc_491521501777_item	2488903	et	2	main
безличное	doc_491521501777_item	2488905	et	2	main
infinitiivi	doc_491521501777_item	2488925	et	4	main
ma	doc_491521501777_item	2488931	et	3	main
lausest	doc_491521501777_item	2488936	et	4	main
kasutamise	doc_491521501777_item	2488942	et	4	main
ela	doc_491521501777_item	2488957	et	4	main
ma	doc_491521501777_item	2488958	et	3	main
inf	doc_491521501777_item	2488961	et	4	main
saama	doc_491521501777_item	2488965	et	4	main
ei	doc_491521501777_item	2488967	et	4	main
ta	doc_491521501777_item	2488972	et	4	main
tegusõnade	doc_491521501777_item	2488983	et	3	main
juures	doc_491521501777_item	2488984	et	4	main
vead	doc_491521501777_item	2488990	et	4	main
töö	doc_491521501777_item	2488993	et	4	main
ö	doc_491521501777_item	2488995	et	4	main
ö	doc_491521501777_item	2488999	et	4	main
sti	doc_491521501777_item	2489004	et	4	main
lise	doc_491521501777_item	2489010	et	3	main
po	doc_491521501777_item	2489030	et	4	main
pühitsema	doc_491521501777_item	2489031	et	3	main
комната	doc_491521501777_item	2489044	et	2	main
комнате	doc_491521501777_item	2489047	et	2	main
ää	doc_491521501777_item	2489056	et	4	main
otsene	doc_491521501777_item	2489059	et	3	main
viskas	doc_491521501777_item	2489066	et	3	main
keegi	doc_491521501777_item	2489069	et	4	main
elab	doc_491521501777_item	2489070	et	3	main
meeiga	doc_491521501777_item	2489071	et	4	main
kaasa	doc_491521501777_item	2489075	et	4	main
d	doc_491521501777_item	2489076	et	4	main
tegusõna	doc_491521501777_item	2489083	et	4	main
lause	doc_491521501777_item	2489091	et	4	main
selgub	doc_491521501777_item	2489096	et	3	main
konflikt	doc_491521501777_item	2489102	et	3	main
oletada	doc_491521501777_item	2489132	et	3	main
sellele	doc_491521501777_item	2489134	et	4	main
tegusõna	doc_491521501777_item	2489136	et	4	main
tegusõnu	doc_491521501777_item	2489141	et	3	main
on	doc_491521501777_item	2489142	et	4	main
väga	doc_491521501777_item	2489143	et	3	main
palju	doc_491521501777_item	2489144	et	4	main
13	doc_491521501777_item	2489145	et	2	main
sa	doc_491521501777_item	2488824	et	3	main
d	doc_491521501777_item	2488826	et	4	main
isa	doc_491521501777_item	2488831	et	4	main
oleviku	doc_491521501777_item	2488842	et	3	main
algperioodil	doc_491521501777_item	2488847	et	3	main
11	doc_491521501777_item	2488852	et	2	main
sõi	doc_491521501777_item	2488858	et	3	main
a	doc_491521501777_item	2488860	et	4	main
sõi	doc_491521501777_item	2488864	et	3	main
a	doc_491521501777_item	2488866	et	4	main
inf	doc_491521501777_item	2488874	et	4	main
tegid	doc_491521501777_item	2488876	et	4	main
vene	doc_491521501777_item	2488880	et	4	main
on	doc_491521501777_item	2488887	et	4	main
isikuline	doc_491521501777_item	2488888	et	4	main
ühte	doc_491521501777_item	2488892	et	4	main
vormi	doc_491521501777_item	2488895	et	4	main
личное	doc_491521501777_item	2488899	et	2	main
предложение	doc_491521501777_item	2488906	et	2	main
umbisikuline	doc_491521501777_item	2488907	et	4	main
eesti	doc_491521501777_item	2488908	et	4	main
keeles	doc_491521501777_item	2488909	et	4	main
nad	doc_491521501777_item	2488910	et	3	main
tegid	doc_491521501777_item	2488911	et	4	main
ja	doc_491521501777_item	2488912	et	3	main
üü	doc_491521501777_item	2488914	et	4	main
nlapäeval	doc_491521501777_item	2488915	et	4	main
tehti	doc_491521501777_item	2488916	et	3	main
k	doc_491521501777_item	2488913	et	4	main
span	doc_491521501777_item	2488917	et	4	main
sellel	doc_491521501777_item	2488918	et	4	main
päeval	doc_491521501777_item	2488919	et	3	main
on	doc_491521501777_item	2488920	et	4	main
tegelevad	doc_491521501777_item	2488922	et	4	main
temal	doc_491521501777_item	2488927	et	3	main
kui	doc_491521501777_item	2488932	et	3	main
saa	doc_491521501777_item	2488935	et	4	main
tegusõna	doc_491521501777_item	2488941	et	4	main
automaatselt	doc_491521501777_item	2488946	et	4	main
ela	doc_491521501777_item	2488950	et	4	main
saama	doc_491521501777_item	2488959	et	4	main
ma	doc_491521501777_item	2488964	et	3	main
raske	doc_491521501777_item	2488977	et	4	main
on	doc_491521501777_item	2488980	et	4	main
vaja	doc_491521501777_item	2488981	et	4	main
sõnatasandi	doc_491521501777_item	2488989	et	3	main
a	doc_491521501777_item	2488997	et	4	main
a	doc_491521501777_item	2489001	et	4	main
rõõmu	doc_491521501777_item	2489006	et	4	main
moodustatud	doc_491521501777_item	2489013	et	4	main
rohelise	doc_491521501777_item	2489018	et	4	main
hoolitsemisega	doc_491521501777_item	2488924	et	4	main
juuste	doc_491521501777_item	2488923	et	4	main
kasutamine	doc_491521501777_item	2488926	et	4	main
tagasi	doc_491521501777_item	2488929	et	3	main
ei	doc_491521501777_item	2488934	et	4	main
tea	doc_491521501777_item	2488939	et	4	main
teeb	doc_491521501777_item	2488944	et	3	main
ta	doc_491521501777_item	2488945	et	4	main
virgutab	doc_491521501777_item	2488949	et	3	main
virgutab	doc_491521501777_item	2488952	et	3	main
nii	doc_491521501777_item	2488954	et	3	main
aga	doc_491521501777_item	2488962	et	3	main
i	doc_491521501777_item	2488966	et	4	main
pesu	doc_491521501777_item	2488970	et	4	main
on	doc_491521501777_item	2488974	et	4	main
on	doc_491521501777_item	2488978	et	4	main
inf	doc_491521501777_item	2488986	et	4	main
kasutama	doc_491521501777_item	2488987	et	3	main
12	doc_491521501777_item	2488988	et	2	main
m	doc_491521501777_item	2488996	et	4	main
rõõmus	doc_491521501777_item	2489005	et	4	main
vorm	doc_491521501777_item	2489012	et	3	main
om	doc_491521501777_item	2489019	et	4	main
kas	doc_491521501777_item	2489020	et	3	main
kas	doc_491521501777_item	2489024	et	3	main
püha	doc_491521501777_item	2489025	et	4	main
a	doc_491521501777_item	2489027	et	4	main
b	doc_491521501777_item	2489032	et	4	main
toas	doc_491521501777_item	2489038	et	3	main
restoranis	doc_491521501777_item	2489041	et	3	main
род	doc_491521501777_item	2489049	et	2	main
kus	doc_491521501777_item	2489052	et	3	main
mille	doc_491521501777_item	2489054	et	3	main
ne	doc_491521501777_item	2489057	et	4	main
tõlge	doc_491521501777_item	2489060	et	3	main
võtsime	doc_491521501777_item	2489073	et	3	main
kasse	doc_491521501777_item	2489074	et	3	main
tegusõnad	doc_491521501777_item	2489078	et	3	main
alustab	doc_491521501777_item	2489080	et	3	main
kättemaksuga	doc_491521501777_item	2489082	et	3	main
sõltub	doc_491521501777_item	2489085	et	3	main
on	doc_491521501777_item	2489088	et	4	main
võetud	doc_491521501777_item	2489093	et	4	main
et	doc_491521501777_item	2489097	et	3	main
pidi	doc_491521501777_item	2489099	et	4	main
algab	doc_491521501777_item	2489101	et	3	main
mis	doc_491521501777_item	2489104	et	4	main
lõ	doc_491521501777_item	2489112	et	4	main
lõppema	doc_491521501777_item	2489117	et	4	main
keegi	doc_491521501777_item	2489122	et	4	main
lõ	doc_491521501777_item	2489128	et	4	main
pp	doc_491521501777_item	2489129	et	4	main
pp	doc_491521501777_item	2489138	et	4	main
ema	doc_491521501777_item	2489139	et	4	main
selliseid	doc_491521501777_item	2489140	et	4	main
ja	doc_491521501777_item	2489149	et	3	main
ta	doc_491521501777_item	2489208	et	4	main
rõõmustab	doc_491521501777_item	2489214	et	3	main
mine	doc_491521501777_item	2488930	et	3	main
aru	doc_491521501777_item	2488937	et	4	main
selle	doc_491521501777_item	2488940	et	4	main
ma-infinitiiv	doc_491521501777_item	2488948	et	3	main
da	doc_491521501777_item	2488951	et	4	main
ma-inf	doc_491521501777_item	2488953	et	4	main
hakka	doc_491521501777_item	2488963	et	4	main
nõus	doc_491521501777_item	2488969	et	4	main
õpilased	doc_491521501777_item	2488973	et	3	main
harjunud	doc_491521501777_item	2488975	et	4	main
keeruline	doc_491521501777_item	2488979	et	4	main
jne	doc_491521501777_item	2488982	et	4	main
a	doc_491521501777_item	2488991	et	4	main
tö	doc_491521501777_item	2488994	et	4	main
tö	doc_491521501777_item	2488998	et	4	main
j	doc_491521501777_item	2489000	et	4	main
odav	doc_491521501777_item	2489002	et	3	main
kas	doc_491521501777_item	2489011	et	3	main
skeemi	doc_491521501777_item	2489015	et	4	main
rohe	doc_491521501777_item	2489022	et	4	main
ja	doc_491521501777_item	2489034	et	3	main
hirmu	doc_491521501777_item	2489039	et	4	main
viga	doc_491521501777_item	2489043	et	4	main
в	doc_491521501777_item	2489046	et	2	main
страха	doc_491521501777_item	2489051	et	2	main
keelest	doc_491521501777_item	2489062	et	4	main
välja	doc_491521501777_item	2489068	et	4	main
enesekohased	doc_491521501777_item	2489077	et	4	main
mida	doc_491521501777_item	2489087	et	4	main
tahetud	doc_491521501777_item	2489089	et	4	main
öelda	doc_491521501777_item	2489090	et	4	main
essees	doc_491521501777_item	2489094	et	3	main
mida	doc_491521501777_item	2489110	et	4	main
pp	doc_491521501777_item	2489113	et	4	main
samuti	doc_491521501777_item	2489116	et	3	main
lise	doc_491521501777_item	2489023	et	3	main
püh	doc_491521501777_item	2489026	et	4	main
liitsõna	doc_491521501777_item	2489033	et	4	main
olime	doc_491521501777_item	2489037	et	3	main
interferentne	doc_491521501777_item	2489042	et	4	main
чего	doc_491521501777_item	2489048	et	2	main
omk	doc_491521501777_item	2489055	et	4	main
hirmu-	doc_491521501777_item	2489058	et	4	main
keki	doc_491521501777_item	2489065	et	3	main
meiega	doc_491521501777_item	2489072	et	4	main
valik	doc_491521501777_item	2489084	et	3	main
kontekstist	doc_491521501777_item	2489086	et	3	main
kust	doc_491521501777_item	2489095	et	4	main
see	doc_491521501777_item	2489098	et	3	main
olema	doc_491521501777_item	2489100	et	4	main
kättemaksuga	doc_491521501777_item	2489103	et	3	main
algab	doc_491521501777_item	2489105	et	3	main
aga	doc_491521501777_item	2489106	et	3	main
alustama	doc_491521501777_item	2489107	et	3	main
nõuab	doc_491521501777_item	2489108	et	3	main
objekti	doc_491521501777_item	2489109	et	4	main
tulestikuga	doc_491521501777_item	2489115	et	3	main
miski	doc_491521501777_item	2489118	et	4	main
lõpeb	doc_491521501777_item	2489119	et	4	main
ja	doc_491521501777_item	2489120	et	3	main
lõpetama	doc_491521501777_item	2489121	et	4	main
lõpetab	doc_491521501777_item	2489123	et	3	main
midagi	doc_491521501777_item	2489124	et	4	main
etama	doc_491521501777_item	2489130	et	4	main
mõjus	doc_491521501777_item	2489135	et	4	main
lõ	doc_491521501777_item	2489137	et	4	main
kas	doc_491521501777_item	2489150	et	3	main
tahad	doc_491521501777_item	2489152	et	3	main
aidata	doc_491521501777_item	2489154	et	4	main
aitama	doc_491521501777_item	2489155	et	3	main
verb	doc_491521501777_item	2489156	et	3	main
nõuab	doc_491521501777_item	2489157	et	3	main
osastavat	doc_491521501777_item	2489158	et	4	main
käänet	doc_491521501777_item	2489159	et	3	main
aitama	doc_491521501777_item	2489160	et	3	main
keda	doc_491521501777_item	2489161	et	4	main
kodus	doc_491521501777_item	2489167	et	4	main
le	doc_491521501777_item	2489195	et	4	main
mu	doc_491521501777_item	2489196	et	3	main
lle	doc_491521501777_item	2489197	et	4	main
otset	doc_491521501777_item	2489198	et	4	main
õ	doc_491521501777_item	2489199	et	4	main
minu	doc_491521501777_item	2489203	et	3	main
jääb	doc_491521501777_item	2489205	et	3	main
haige	doc_491521501777_item	2489210	et	4	main
kuhu	doc_491521501777_item	2489212	et	3	main
rõõmustama	doc_491521501777_item	2489216	et	3	main
mille	doc_491521501777_item	2489217	et	3	main
verbirektsioone	doc_491521501777_item	2489226	et	4	main
isa	doc_491521501777_item	2489230	et	4	main
kellel	doc_491521501777_item	2489236	et	4	main
esinevad	doc_491521501777_item	2489245	et	4	main
14	doc_491521501777_item	2489255	et	2	main
eriti	doc_491521501777_item	2489259	et	3	main
mulle	doc_491521501777_item	2489265	et	4	main
võib	doc_491521501777_item	2489268	et	3	main
tegema	doc_491521501777_item	2489270	et	3	main
võib	doc_491521501777_item	2489277	et	3	main
igast	doc_491521501777_item	2489279	et	3	main
leida	doc_491521501777_item	2489281	et	3	main
keele	doc_491521501777_item	2489289	et	4	main
eesti	doc_491521501777_item	2489291	et	4	main
keeles	doc_491521501777_item	2489292	et	4	main
reegel	doc_491521501777_item	2489296	et	3	main
reegleid	doc_491521501777_item	2489307	et	3	main
seda	doc_491521501777_item	2489316	et	3	main
kus	doc_491521501777_item	2489322	et	3	main
seda	doc_491521501777_item	2489333	et	3	main
мне	doc_491521501777_item	2489348	et	2	main
lle	doc_491521501777_item	2489352	et	4	main
но	doc_491521501777_item	2489356	et	2	main
kuidas	doc_491521501777_item	2489358	et	3	main
kord	doc_491521501777_item	2489364	et	4	main
pärast	doc_491521501777_item	2489388	et	4	main
kooli	doc_491521501777_item	2489395	et	4	main
veel	doc_491521501777_item	2489125	et	4	main
üks	doc_491521501777_item	2489126	et	3	main
võib	doc_491521501777_item	2489131	et	3	main
aita	doc_491521501777_item	2489147	et	4	main
mulle	doc_491521501777_item	2489153	et	4	main
käima	doc_491521501777_item	2489168	et	4	main
kus	doc_491521501777_item	2489169	et	3	main
minema	doc_491521501777_item	2489170	et	3	main
kuhu	doc_491521501777_item	2489171	et	3	main
õpilased	doc_491521501777_item	2489172	et	3	main
tihti	doc_491521501777_item	2489174	et	3	main
ajavad	doc_491521501777_item	2489173	et	4	main
segi	doc_491521501777_item	2489175	et	3	main
minema	doc_491521501777_item	2489176	et	3	main
käima	doc_491521501777_item	2489177	et	4	main
tulema	doc_491521501777_item	2489178	et	4	main
tegusõnad	doc_491521501777_item	2489179	et	3	main
ja	doc_491521501777_item	2489180	et	3	main
nende	doc_491521501777_item	2489181	et	4	main
rektsioonid	doc_491521501777_item	2489182	et	3	main
ei	doc_491521501777_item	2489184	et	4	main
mulle	doc_491521501777_item	2489183	et	4	main
vaja	doc_491521501777_item	2489185	et	4	main
vene	doc_491521501777_item	2489186	et	4	main
keele	doc_491521501777_item	2489187	et	4	main
mõju	doc_491521501777_item	2489188	et	4	main
мне	doc_491521501777_item	2489189	et	2	main
не	doc_491521501777_item	2489190	et	2	main
надо	doc_491521501777_item	2489191	et	2	main
mulle	doc_491521501777_item	2489148	et	4	main
aita	doc_491521501777_item	2489162	et	4	main
mind	doc_491521501777_item	2489163	et	4	main
käisin	doc_491521501777_item	2489164	et	3	main
мне	doc_491521501777_item	2489193	et	2	main
keelest	doc_491521501777_item	2489202	et	4	main
kodu	doc_491521501777_item	2489206	et	4	main
inimene	doc_491521501777_item	2489219	et	3	main
kõik	doc_491521501777_item	2489222	et	4	main
saama	doc_491521501777_item	2489224	et	4	main
kellestmillest	doc_491521501777_item	2489225	et	4	main
mulle	doc_491521501777_item	2489232	et	4	main
kaua	doc_491521501777_item	2489234	et	3	main
tegusõnad	doc_491521501777_item	2489243	et	3	main
mis	doc_491521501777_item	2489244	et	4	main
käskima	doc_491521501777_item	2489252	et	4	main
jt	doc_491521501777_item	2489254	et	4	main
sõnajärjevead	doc_491521501777_item	2489256	et	3	main
võib	doc_491521501777_item	2489257	et	3	main
jälgida	doc_491521501777_item	2489258	et	3	main
meeldis	doc_491521501777_item	2489264	et	3	main
kahtlemata	doc_491521501777_item	2489267	et	4	main
hommikul	doc_491521501777_item	2489271	et	3	main
lähen	doc_491521501777_item	2489273	et	3	main
kusjuures	doc_491521501777_item	2489282	et	3	main
jälgitav	doc_491521501777_item	2489287	et	4	main
mõju	doc_491521501777_item	2489290	et	4	main
vene	doc_491521501777_item	2489297	et	4	main
ega	doc_491521501777_item	2489303	et	3	main
rangeid	doc_491521501777_item	2489306	et	3	main
vene	doc_491521501777_item	2489310	et	4	main
15	doc_491521501777_item	2489318	et	2	main
kooli	doc_491521501777_item	2489165	et	4	main
lähevad	doc_491521501777_item	2489166	et	3	main
vene	doc_491521501777_item	2489201	et	4	main
vend	doc_491521501777_item	2489204	et	3	main
on	doc_491521501777_item	2489209	et	4	main
elu	doc_491521501777_item	2489215	et	4	main
üle	doc_491521501777_item	2489218	et	3	main
span	doc_491521501777_item	2489229	et	4	main
on	doc_491521501777_item	2489241	et	4	main
keerulised	doc_491521501777_item	2489242	et	4	main
see	doc_491521501777_item	2489262	et	3	main
armastus	doc_491521501777_item	2489266	et	4	main
ma	doc_491521501777_item	2489272	et	3	main
kooli	doc_491521501777_item	2489274	et	4	main
peaaegu	doc_491521501777_item	2489278	et	3	main
hästi	doc_491521501777_item	2489286	et	3	main
on	doc_491521501777_item	2489299	et	4	main
inimestel	doc_491521501777_item	2489314	et	3	main
jälgida	doc_491521501777_item	2489317	et	3	main
lausedsõnaühendid	doc_491521501777_item	2489321	et	4	main
leidub	doc_491521501777_item	2489323	et	3	main
väga	doc_491521501777_item	2489324	et	3	main
erinevaid	doc_491521501777_item	2489326	et	4	main
vigu	doc_491521501777_item	2489327	et	3	main
väga	doc_491521501777_item	2489330	et	3	main
huvitava	doc_491521501777_item	2489331	et	4	main
kelle	doc_491521501777_item	2489349	et	4	main
было	doc_491521501777_item	2489353	et	2	main
huvitava	doc_491521501777_item	2489359	et	4	main
üks	doc_491521501777_item	2489363	et	3	main
mina	doc_491521501777_item	2489365	et	4	main
ja	doc_491521501777_item	2489366	et	3	main
minu	doc_491521501777_item	2489367	et	3	main
sõbraga	doc_491521501777_item	2489368	et	3	main
ma	doc_491521501777_item	2489389	et	3	main
käisin	doc_491521501777_item	2489394	et	3	main
meres	doc_491521501777_item	2489398	et	3	main
emakeelest	doc_491521501777_item	2489404	et	4	main
põhjustatud	doc_491521501777_item	2489405	et	4	main
ka	doc_491521501777_item	2489410	et	3	main
öelda	doc_491521501777_item	2489413	et	4	main
частота	doc_491521501777_item	2489416	et	2	main
kohta	doc_491521501777_item	2489422	et	4	main
mõtleb	doc_491521501777_item	2489433	et	3	main
ja	doc_491521501777_item	2489445	et	3	main
nüüd	doc_491521501777_item	2489446	et	4	main
vaatab	doc_491521501777_item	2489447	et	3	main
on	doc_491521501777_item	2489456	et	4	main
uue	doc_491521501777_item	2489460	et	3	main
järjekorrad	doc_491521501777_item	2489470	et	3	main
keeles	doc_491521501777_item	2489472	et	4	main
длинные	doc_491521501777_item	2489479	et	2	main
pikad	doc_491521501777_item	2489485	et	4	main
sellest	doc_491521501777_item	2489491	et	4	main
кому	doc_491521501777_item	2489192	et	2	main
kelle	doc_491521501777_item	2489194	et	4	main
lge	doc_491521501777_item	2489200	et	4	main
sest	doc_491521501777_item	2489207	et	4	main
jääma	doc_491521501777_item	2489211	et	4	main
inimene	doc_491521501777_item	2489213	et	3	main
sai	doc_491521501777_item	2489220	et	4	main
aru	doc_491521501777_item	2489221	et	4	main
aru	doc_491521501777_item	2489223	et	4	main
õppima	doc_491521501777_item	2489228	et	3	main
keelab	doc_491521501777_item	2489231	et	3	main
keelab	doc_491521501777_item	2489235	et	3	main
da-	doc_491521501777_item	2489237	et	4	main
inf	doc_491521501777_item	2489238	et	4	main
õpilase	doc_491521501777_item	2489239	et	3	main
jaoks	doc_491521501777_item	2489240	et	4	main
selles	doc_491521501777_item	2489246	et	4	main
paluma	doc_491521501777_item	2489253	et	3	main
interferentsiooni	doc_491521501777_item	2489261	et	4	main
veatüüpi	doc_491521501777_item	2489276	et	4	main
on	doc_491521501777_item	2489283	et	4	main
siin	doc_491521501777_item	2489284	et	4	main
väga	doc_491521501777_item	2489285	et	3	main
vene	doc_491521501777_item	2489288	et	4	main
palju	doc_491521501777_item	2489300	et	4	main
ole	doc_491521501777_item	2489304	et	4	main
nii	doc_491521501777_item	2489305	et	3	main
on	doc_491521501777_item	2489309	et	4	main
keelt	doc_491521501777_item	2489311	et	4	main
emakeelena	doc_491521501777_item	2489312	et	3	main
kõnelevatel	doc_491521501777_item	2489313	et	4	main
huvitavad	doc_491521501777_item	2489320	et	4	main
lugeda	doc_491521501777_item	2489334	et	3	main
venekeelse	doc_491521501777_item	2489337	et	3	main
мне	doc_491521501777_item	2489339	et	2	main
очень	doc_491521501777_item	2489341	et	2	main
но	doc_491521501777_item	2489343	et	2	main
читать	doc_491521501777_item	2489345	et	2	main
otsene	doc_491521501777_item	2489346	et	3	main
это	doc_491521501777_item	2489361	et	2	main
tulid	doc_491521501777_item	2489390	et	4	main
hästi	doc_491521501777_item	2489396	et	3	main
oli	doc_491521501777_item	2489399	et	3	main
maardust	doc_491521501777_item	2489401	et	4	main
vene	doc_491521501777_item	2489407	et	4	main
raadio	doc_491521501777_item	2489411	et	4	main
liigutuste	doc_491521501777_item	2489424	et	4	main
saa	doc_491521501777_item	2489428	et	4	main
sõna	doc_491521501777_item	2489430	et	4	main
mõtleja	doc_491521501777_item	2489432	et	4	main
ta	doc_491521501777_item	2489435	et	4	main
hea	doc_491521501777_item	2489439	et	4	main
homme	doc_491521501777_item	2489441	et	3	main
uue	doc_491521501777_item	2489443	et	3	main
teda	doc_491521501777_item	2489448	et	4	main
valesti	doc_491521501777_item	2489449	et	3	main
teiseks	doc_491521501777_item	2489455	et	4	main
suured	doc_491521501777_item	2489469	et	3	main
vene	doc_491521501777_item	2489471	et	4	main
võib	doc_491521501777_item	2489473	et	3	main
vene	doc_491521501777_item	2489521	et	4	main
женщиной	doc_491521501777_item	2489525	et	2	main
peaks	doc_491521501777_item	2489528	et	4	main
vahel	doc_491521501777_item	2489534	et	4	main
teised	doc_491521501777_item	2489536	et	4	main
suulises	doc_491521501777_item	2489538	et	4	main
õpilased	doc_491521501777_item	2489541	et	3	main
rohkem	doc_491521501777_item	2489543	et	4	main
nad	doc_491521501777_item	2489566	et	3	main
näiteks	doc_491521501777_item	2489568	et	4	main
jälle	doc_491521501777_item	2489576	et	3	main
tingitud	doc_491521501777_item	2489583	et	4	main
mõjust	doc_491521501777_item	2489585	et	3	main
morfoloogias	doc_491521501777_item	2489588	et	3	main
oma	doc_491521501777_item	2489597	et	4	main
kaob	doc_491521501777_item	2489600	et	3	main
ühe	doc_491521501778_item	2489619	et	4	main
teksti	doc_491521501778_item	2489628	et	4	main
täiskasvanud	doc_491521501778_item	2489630	et	4	main
inimene	doc_491521501778_item	2489631	et	3	main
järgi	doc_491521501778_item	2489637	et	4	main
omapoolsete	doc_491521501778_item	2489652	et	4	main
peab	doc_491521501777_item	2489227	et	4	main
jalutada	doc_491521501777_item	2489233	et	3	main
konstruktsioonis	doc_491521501777_item	2489247	et	3	main
nt	doc_491521501777_item	2489248	et	4	main
keelama	doc_491521501777_item	2489249	et	3	main
lubama	doc_491521501777_item	2489250	et	3	main
soovitama	doc_491521501777_item	2489251	et	4	main
tugevat	doc_491521501777_item	2489260	et	4	main
väga	doc_491521501777_item	2489263	et	3	main
imet	doc_491521501777_item	2489269	et	3	main
seda	doc_491521501777_item	2489275	et	3	main
lausest	doc_491521501777_item	2489280	et	4	main
on	doc_491521501777_item	2489293	et	4	main
tavaline	doc_491521501777_item	2489294	et	4	main
v2	doc_491521501777_item	2489295	et	4	main
keeles	doc_491521501777_item	2489298	et	4	main
vabam	doc_491521501777_item	2489301	et	4	main
sõnajärg	doc_491521501777_item	2489302	et	3	main
seetõttu	doc_491521501777_item	2489308	et	3	main
raske	doc_491521501777_item	2489315	et	4	main
muud	doc_491521501777_item	2489319	et	4	main
lt	doc_491521501777_item	2489332	et	4	main
le	doc_491521501777_item	2489350	et	4	main
интерес	doc_491521501777_item	2489355	et	2	main
määrsona	doc_491521501777_item	2489357	et	4	main
lt	doc_491521501777_item	2489360	et	4	main
kord	doc_491521501777_item	2489387	et	4	main
riietun	doc_491521501777_item	2489392	et	3	main
mees	doc_491521501777_item	2489400	et	4	main
raadio	doc_491521501777_item	2489402	et	4	main
tihedus	doc_491521501777_item	2489403	et	4	main
keeles	doc_491521501777_item	2489408	et	4	main
kohta	doc_491521501777_item	2489412	et	4	main
радио	doc_491521501777_item	2489415	et	2	main
kohta	doc_491521501777_item	2489425	et	4	main
kasutada	doc_491521501777_item	2489431	et	3	main
et	doc_491521501777_item	2489434	et	3	main
on	doc_491521501777_item	2489436	et	4	main
ajalehte	doc_491521501777_item	2489444	et	4	main
siin	doc_491521501777_item	2489457	et	4	main
seda	doc_491521501777_item	2489465	et	3	main
on	doc_491521501777_item	2489467	et	4	main
keeles	doc_491521501777_item	2489482	et	4	main
on	doc_491521501777_item	2489483	et	4	main
pigem	doc_491521501777_item	2489484	et	3	main
andsid	doc_491521501777_item	2489488	et	4	main
keelest	doc_491521501777_item	2489522	et	4	main
и	doc_491521501777_item	2489526	et	2	main
mehe	doc_491521501777_item	2489533	et	3	main
märkusedtähelepanekud	doc_491521501777_item	2489537	et	4	main
vigu	doc_491521501777_item	2489544	et	3	main
kui	doc_491521501777_item	2489550	et	3	main
20	doc_491521501777_item	2489553	et	2	main
kõiki	doc_491521501777_item	2489557	et	4	main
alustavad	doc_491521501777_item	2489567	et	4	main
jutustada	doc_491521501777_item	2489569	et	3	main
siis	doc_491521501777_item	2489571	et	3	main
olevikus	doc_491521501777_item	2489574	et	3	main
kõige	doc_491521501777_item	2489579	et	4	main
vigu	doc_491521501777_item	2489581	et	3	main
kui	doc_491521501777_item	2489590	et	3	main
kui	doc_491521501777_item	2489594	et	3	main
vigukõnet	doc_491521501777_item	2489598	et	4	main
või	doc_491521501777_item	2489602	et	4	main
veelgi	doc_491521501777_item	2489605	et	4	main
rohkem	doc_491521501777_item	2489606	et	4	main
analüüs	doc_491521501778_item	2489607	et	3	main
vigade	doc_491521501778_item	2489608	et	3	main
anal	doc_491521501778_item	2489609	et	4	main
analüüsis	doc_491521501778_item	2489617	et	4	main
tallinna	doc_491521501778_item	2489620	et	4	main
pedagoogikaülikooli	doc_491521501778_item	2489621	et	4	main
analüüsitava	doc_491521501778_item	2489627	et	4	main
kirjutas	doc_491521501778_item	2489629	et	3	main
kelle	doc_491521501778_item	2489632	et	4	main
perekonnanime	doc_491521501778_item	2489633	et	4	main
ja	doc_491521501778_item	2489634	et	3	main
teha	doc_491521501778_item	2489639	et	3	main
kujutab	doc_491521501778_item	2489647	et	3	main
endast	doc_491521501778_item	2489648	et	4	main
kommentaaridega	doc_491521501778_item	2489653	et	3	main
tallinnan	doc_491521501778_item	2489655	et	4	main
parim	doc_491521501778_item	2489657	et	4	main
see	doc_491521501778_item	2489674	et	3	main
tüüpilised	doc_491521501778_item	2489686	et	3	main
veinkelder	doc_491521501778_item	2489693	et	4	main
ja	doc_491521501778_item	2489694	et	3	main
veineja	doc_491521501778_item	2489699	et	4	main
palju	doc_491521501777_item	2489325	et	4	main
mulle	doc_491521501777_item	2489328	et	4	main
oli	doc_491521501777_item	2489329	et	3	main
emakeele	doc_491521501777_item	2489335	et	4	main
mõju	doc_491521501777_item	2489336	et	4	main
lause	doc_491521501777_item	2489338	et	4	main
было	doc_491521501777_item	2489340	et	2	main
интерес	doc_491521501777_item	2489342	et	2	main
это	doc_491521501777_item	2489344	et	2	main
tõlge	doc_491521501777_item	2489347	et	3	main
mu	doc_491521501777_item	2489351	et	3	main
очень	doc_491521501777_item	2489354	et	2	main
читать	doc_491521501777_item	2489362	et	2	main
jalutada	doc_491521501777_item	2489369	et	3	main
õues	doc_491521501777_item	2489370	et	4	main
ja	doc_491521501777_item	2489371	et	3	main
vaata	doc_491521501777_item	2489372	et	4	main
autoga	doc_491521501777_item	2489373	et	3	main
hommes	doc_491521501777_item	2489374	et	4	main
päeval	doc_491521501777_item	2489375	et	3	main
ma	doc_491521501777_item	2489376	et	3	main
käin	doc_491521501777_item	2489377	et	3	main
ja	doc_491521501777_item	2489380	et	3	main
ema	doc_491521501777_item	2489379	et	4	main
õue	doc_491521501777_item	2489378	et	4	main
isa	doc_491521501777_item	2489381	et	4	main
käivad	doc_491521501777_item	2489382	et	4	main
tööle	doc_491521501777_item	2489383	et	3	main
ma	doc_491521501777_item	2489384	et	3	main
algan	doc_491521501777_item	2489385	et	3	main
tegin	doc_491521501777_item	2489386	et	3	main
koju	doc_491521501777_item	2489391	et	3	main
ja	doc_491521501777_item	2489393	et	3	main
võib	doc_491521501777_item	2489409	et	3	main
частота	doc_491521501777_item	2489414	et	2	main
движений	doc_491521501777_item	2489417	et	2	main
eesti	doc_491521501777_item	2489418	et	4	main
keeles	doc_491521501777_item	2489419	et	4	main
öeldakse	doc_491521501777_item	2489420	et	3	main
et	doc_491521501777_item	2489397	et	3	main
viga	doc_491521501777_item	2489406	et	4	main
raado	doc_491521501777_item	2489421	et	4	main
laine	doc_491521501777_item	2489423	et	4	main
ei	doc_491521501777_item	2489427	et	4	main
seda	doc_491521501777_item	2489429	et	3	main
töötab	doc_491521501777_item	2489437	et	3	main
sõber	doc_491521501777_item	2489440	et	3	main
ostis	doc_491521501777_item	2489442	et	4	main
tegusõna	doc_491521501777_item	2489453	et	4	main
ajavorm	doc_491521501777_item	2489454	et	3	main
ka	doc_491521501777_item	2489458	et	3	main
ja	doc_491521501777_item	2489462	et	3	main
vaatab	doc_491521501777_item	2489464	et	3	main
öelda	doc_491521501777_item	2489474	et	4	main
nii	doc_491521501777_item	2489475	et	3	main
большие	doc_491521501777_item	2489476	et	2	main
kui	doc_491521501777_item	2489477	et	3	main
ka	doc_491521501777_item	2489478	et	3	main
очереди	doc_491521501777_item	2489480	et	2	main
eesti	doc_491521501777_item	2489481	et	4	main
järjekorrad	doc_491521501777_item	2489486	et	3	main
kondid	doc_491521501777_item	2489490	et	3	main
et	doc_491521501777_item	2489492	et	3	main
kelle	doc_491521501777_item	2489493	et	4	main
naise	doc_491521501777_item	2489531	et	3	main
seda	doc_491521501777_item	2489545	et	3	main
seletada	doc_491521501777_item	2489547	et	3	main
et	doc_491521501777_item	2489549	et	3	main
jõutagi	doc_491521501777_item	2489556	et	4	main
on	doc_491521501777_item	2489560	et	4	main
et	doc_491521501777_item	2489565	et	3	main
minevikus	doc_491521501777_item	2489570	et	3	main
paar-kolm	doc_491521501777_item	2489572	et	3	main
minevikus	doc_491521501777_item	2489577	et	3	main
on	doc_491521501777_item	2489582	et	4	main
emakeele	doc_491521501777_item	2489584	et	4	main
nii	doc_491521501777_item	2489586	et	3	main
foneetikasfonoloogias	doc_491521501777_item	2489587	et	4	main
jt	doc_491521501777_item	2489593	et	4	main
s	doc_491521501778_item	2489611	et	4	main
millele	doc_491521501778_item	2489614	et	3	main
pärineb	doc_491521501778_item	2489618	et	3	main
aga	doc_491521501777_item	2489426	et	3	main
väga	doc_491521501777_item	2489438	et	3	main
kasutatud	doc_491521501777_item	2489450	et	4	main
määrus	doc_491521501777_item	2489451	et	3	main
ja	doc_491521501777_item	2489452	et	3	main
ühildumisviga	doc_491521501777_item	2489459	et	4	main
ajalehte	doc_491521501777_item	2489461	et	4	main
pronoomenivigaõige	doc_491521501777_item	2489463	et	4	main
kolmandaks	doc_491521501777_item	2489466	et	4	main
sõnajärjeviga	doc_491521501777_item	2489468	et	4	main
tüdrukud	doc_491521501777_item	2489487	et	3	main
koerale	doc_491521501777_item	2489489	et	3	main
kond	doc_491521501777_item	2489494	et	4	main
koer	doc_491521501777_item	2489495	et	3	main
võtab	doc_491521501777_item	2489496	et	3	main
see	doc_491521501777_item	2489497	et	3	main
tüdruk	doc_491521501777_item	2489498	et	3	main
oli	doc_491521501777_item	2489499	et	3	main
esimene	doc_491521501777_item	2489500	et	3	main
kes	doc_491521501777_item	2489501	et	4	main
valib	doc_491521501777_item	2489502	et	3	main
oma	doc_491521501777_item	2489503	et	4	main
mehi	doc_491521501777_item	2489504	et	3	main
armastus	doc_491521501777_item	2489505	et	4	main
alati	doc_491521501777_item	2489506	et	4	main
elab	doc_491521501777_item	2489507	et	3	main
teda	doc_491521501777_item	2489508	et	4	main
südas	doc_491521501777_item	2489509	et	4	main
sõnajärje-	doc_491521501777_item	2489510	et	3	main
vormimoodustus-	doc_491521501777_item	2489511	et	3	main
ja	doc_491521501777_item	2489512	et	3	main
pronoomeniviga	doc_491521501777_item	2489513	et	4	main
tekkis	doc_491521501777_item	2489514	et	3	main
vahel	doc_491521501777_item	2489515	et	4	main
naist	doc_491521501777_item	2489516	et	3	main
ja	doc_491521501777_item	2489517	et	3	main
meest	doc_491521501777_item	2489518	et	4	main
otsene	doc_491521501777_item	2489519	et	3	main
tõlge	doc_491521501777_item	2489520	et	3	main
ja	doc_491521501777_item	2489532	et	3	main
teevad	doc_491521501777_item	2489540	et	3	main
on	doc_491521501777_item	2489552	et	4	main
õpilast	doc_491521501777_item	2489554	et	4	main
ei	doc_491521501777_item	2489555	et	4	main
õpilastel	doc_491521501777_item	2489559	et	4	main
raske	doc_491521501777_item	2489561	et	4	main
jälgida	doc_491521501777_item	2489562	et	3	main
aegaajavorme	doc_491521501777_item	2489563	et	3	main
st	doc_491521501777_item	2489564	et	3	main
pärast	doc_491521501777_item	2489575	et	4	main
jne	doc_491521501777_item	2489578	et	4	main
süntaksis	doc_491521501777_item	2489589	et	3	main
ka	doc_491521501777_item	2489591	et	3	main
õpilased	doc_491521501777_item	2489595	et	3	main
возникло	doc_491521501777_item	2489523	et	2	main
между	doc_491521501777_item	2489524	et	2	main
мужчиной	doc_491521501777_item	2489527	et	2	main
olema	doc_491521501777_item	2489529	et	4	main
tekkis	doc_491521501777_item	2489530	et	3	main
16	doc_491521501777_item	2489535	et	2	main
kõnes	doc_491521501777_item	2489539	et	3	main
palju	doc_491521501777_item	2489542	et	4	main
nii	doc_491521501777_item	2489548	et	3	main
võiks	doc_491521501777_item	2489546	et	4	main
rühmas	doc_491521501777_item	2489551	et	4	main
küsida	doc_491521501777_item	2489558	et	3	main
lauset	doc_491521501777_item	2489573	et	3	main
rohkem	doc_491521501777_item	2489580	et	4	main
semantikas	doc_491521501777_item	2489592	et	3	main
hakkavad	doc_491521501777_item	2489596	et	4	main
tehakse	doc_491521501777_item	2489604	et	3	main
õpilase	doc_491521501778_item	2489612	et	3	main
töö	doc_491521501778_item	2489613	et	4	main
toetusin	doc_491521501778_item	2489615	et	3	main
oma	doc_491521501778_item	2489616	et	4	main
korraldatava	doc_491521501778_item	2489624	et	4	main
materjalidest	doc_491521501778_item	2489626	et	3	main
järelduse	doc_491521501778_item	2489640	et	4	main
kirjeldust	doc_491521501778_item	2489650	et	4	main
originaaltekst	doc_491521501778_item	2489654	et	3	main
kiire	doc_491521501778_item	2489678	et	4	main
plaanitud	doc_491521501778_item	2489682	et	4	main
menüült	doc_491521501778_item	2489684	et	3	main
leitub	doc_491521501778_item	2489685	et	4	main
oma	doc_491521501778_item	2489691	et	4	main
on	doc_491521501778_item	2489696	et	4	main
teenindamine	doc_491521501778_item	2489703	et	4	main
seal	doc_491521501778_item	2489704	et	4	main
kõrgklassist	doc_491521501778_item	2489708	et	3	main
nendel	doc_491521501778_item	2489710	et	4	main
täis	doc_491521501778_item	2489715	et	4	main
kui	doc_491521501778_item	2489716	et	3	main
sealt	doc_491521501778_item	2489720	et	4	main
jälgima	doc_491521501777_item	2489599	et	4	main
mõte	doc_491521501777_item	2489601	et	3	main
vigu	doc_491521501777_item	2489603	et	3	main
üü	doc_491521501778_item	2489610	et	4	main
õppejõu	doc_491521501778_item	2489622	et	3	main
saab	doc_491521501778_item	2489638	et	3	main
tegemist	doc_491521501778_item	2489642	et	4	main
soomlasega	doc_491521501778_item	2489644	et	3	main
see	doc_491521501778_item	2489645	et	3	main
tekst	doc_491521501778_item	2489646	et	3	main
koos	doc_491521501778_item	2489651	et	4	main
kõige	doc_491521501778_item	2489656	et	4	main
restoranin	doc_491521501778_item	2489658	et	4	main
ühke	doc_491521501778_item	2489672	et	3	main
restoranin	doc_491521501778_item	2489675	et	4	main
itaalia	doc_491521501778_item	2489677	et	4	main
menüü	doc_491521501778_item	2489680	et	4	main
seal	doc_491521501778_item	2489695	et	4	main
peaasjalikult	doc_491521501778_item	2489697	et	4	main
italialaasia	doc_491521501778_item	2489698	et	4	main
on	doc_491521501778_item	2489705	et	4	main
kõku	doc_491521501778_item	2489706	et	4	main
just	doc_491521501778_item	2489709	et	3	main
teie	doc_491521501778_item	2489721	et	4	main
see	doc_491521501778_item	2489724	et	3	main
õigekirja-	doc_491521501778_item	2489732	et	4	main
et	doc_491521501778_item	2489741	et	3	main
tingitud	doc_491521501778_item	2489745	et	4	main
keele	doc_491521501778_item	2489747	et	4	main
ja	doc_491521501778_item	2489749	et	3	main
ka	doc_491521501778_item	2489750	et	3	main
sellest	doc_491521501778_item	2489751	et	4	main
et	doc_491521501778_item	2489752	et	3	main
õpilane	doc_491521501778_item	2489753	et	3	main
ja	doc_491521501778_item	2489757	et	3	main
vahel	doc_491521501778_item	2489759	et	4	main
ühke	doc_491521501778_item	2489763	et	3	main
sõna	doc_491521501778_item	2489765	et	4	main
seisab	doc_491521501778_item	2489767	et	3	main
peale	doc_491521501778_item	2489768	et	4	main
levinud	doc_491521501778_item	2489801	et	4	main
nimi	doc_491521501778_item	2489810	et	3	main
soome	doc_491521501778_item	2489818	et	3	main
või	doc_491521501778_item	2489821	et	4	main
hoolimatusega	doc_491521501778_item	2489823	et	4	main
kogu	doc_491521501778_item	2489828	et	4	main
ilmselt	doc_491521501778_item	2489830	et	4	main
õpilane	doc_491521501778_item	2489831	et	3	main
helituna	doc_491521501778_item	2489834	et	4	main
asjatuntlikult	doc_491521501778_item	2489835	et	4	main
kuulis	doc_491521501778_item	2489840	et	4	main
konsonandi	doc_491521501778_item	2489845	et	3	main
helituna	doc_491521501778_item	2489847	et	4	main
vale	doc_491521501778_item	2489859	et	4	main
välte	doc_491521501778_item	2489860	et	3	main
õige	doc_491521501778_item	2489864	et	4	main
menüüst	doc_491521501778_item	2489866	et	3	main
jällegi	doc_491521501778_item	2489868	et	4	main
konsonandiga	doc_491521501778_item	2489872	et	3	main
võimalik	doc_491521501778_item	2489879	et	3	main
on	doc_491521501778_item	2489882	et	4	main
te	doc_491521501778_item	2489917	et	4	main
tga	doc_491521501778_item	2489926	et	4	main
peaks	doc_491521501778_item	2489934	et	4	main
eestlase	doc_491521501778_item	2489939	et	3	main
on	doc_491521501778_item	2489941	et	4	main
loomulk	doc_491521501778_item	2489942	et	3	main
et	doc_491521501778_item	2489943	et	3	main
mitu	doc_491521501778_item	2489944	et	4	main
td	doc_491521501778_item	2489950	et	4	main
kuid	doc_491521501778_item	2489954	et	4	main
peegeldu	doc_491521501778_item	2489959	et	4	main
jaoks	doc_491521501778_item	2489962	et	4	main
veineja	doc_491521501778_item	2489965	et	4	main
selle	doc_491521501778_item	2489966	et	4	main
tegemist	doc_491521501778_item	2489996	et	4	main
mille	doc_491521501778_item	2490000	et	3	main
on	doc_491521501778_item	2490010	et	4	main
see	doc_491521501778_item	2490015	et	3	main
objektivead	doc_491521501778_item	2490020	et	4	main
vorm	doc_491521501778_item	2490021	et	3	main
käändevalik	doc_491521501778_item	2490023	et	4	main
poolt	doc_491521501778_item	2489623	et	4	main
keelekursuse	doc_491521501778_item	2489625	et	3	main
tehtud	doc_491521501778_item	2489635	et	4	main
vigade	doc_491521501778_item	2489636	et	3	main
et	doc_491521501778_item	2489641	et	3	main
on	doc_491521501778_item	2489643	et	4	main
pildi	doc_491521501778_item	2489649	et	4	main
nimi	doc_491521501778_item	2489659	et	3	main
on	doc_491521501778_item	2489660	et	4	main
amadeus	doc_491521501778_item	2489661	et	4	main
ja	doc_491521501778_item	2489662	et	3	main
see	doc_491521501778_item	2489663	et	3	main
on	doc_491521501778_item	2489664	et	4	main
siin	doc_491521501778_item	2489665	et	4	main
bildil	doc_491521501778_item	2489666	et	4	main
amadeus	doc_491521501778_item	2489667	et	4	main
restoran	doc_491521501778_item	2489668	et	3	main
on	doc_491521501778_item	2489669	et	4	main
hea	doc_491521501778_item	2489670	et	4	main
ja	doc_491521501778_item	2489671	et	3	main
restoran	doc_491521501778_item	2489673	et	3	main
koku	doc_491521501778_item	2489679	et	4	main
itaaliapäraseid	doc_491521501778_item	2489687	et	4	main
restoranil	doc_491521501778_item	2489689	et	3	main
on	doc_491521501778_item	2489690	et	4	main
restoranis	doc_491521501778_item	2489700	et	3	main
hea	doc_491521501778_item	2489702	et	4	main
personal	doc_491521501778_item	2489707	et	3	main
on	doc_491521501778_item	2489713	et	4	main
see	doc_491521501778_item	2489736	et	3	main
siin	doc_491521501778_item	2489738	et	4	main
on	doc_491521501778_item	2489744	et	4	main
soome	doc_491521501778_item	2489746	et	3	main
mõjust	doc_491521501778_item	2489748	et	3	main
ni	doc_491521501778_item	2489756	et	4	main
on	doc_491521501778_item	2489799	et	4	main
parim	doc_491521501778_item	2489808	et	4	main
on	doc_491521501778_item	2489813	et	4	main
ilmselt	doc_491521501778_item	2489815	et	4	main
ka	doc_491521501778_item	2489816	et	3	main
on	doc_491521501778_item	2489676	et	4	main
on	doc_491521501778_item	2489681	et	4	main
asjatuntlikult	doc_491521501778_item	2489683	et	4	main
toitu	doc_491521501778_item	2489688	et	4	main
spetsiaalne	doc_491521501778_item	2489692	et	3	main
põhjustel	doc_491521501778_item	2489711	et	3	main
te	doc_491521501778_item	2489717	et	4	main
tahate	doc_491521501778_item	2489718	et	3	main
lauta	doc_491521501778_item	2489719	et	4	main
peate	doc_491521501778_item	2489722	et	4	main
mittu	doc_491521501778_item	2489725	et	4	main
nädalad	doc_491521501778_item	2489726	et	3	main
ette	doc_491521501778_item	2489727	et	4	main
astmevaheldusvead	doc_491521501778_item	2489734	et	4	main
oletan	doc_491521501778_item	2489740	et	3	main
i	doc_491521501778_item	2489758	et	4	main
helilisena	doc_491521501778_item	2489760	et	4	main
restoran	doc_491521501778_item	2489764	et	3	main
uhke	doc_491521501778_item	2489766	et	4	main
väga	doc_491521501778_item	2489800	et	3	main
kõige	doc_491521501778_item	2489807	et	4	main
põhjendatav	doc_491521501778_item	2489817	et	4	main
koku	doc_491521501778_item	2489824	et	4	main
olema	doc_491521501778_item	2489827	et	4	main
kuulis	doc_491521501778_item	2489832	et	4	main
õpilane	doc_491521501778_item	2489839	et	3	main
ka	doc_491521501778_item	2489849	et	3	main
kuid	doc_491521501778_item	2489852	et	4	main
et	doc_491521501778_item	2489854	et	3	main
menüült	doc_491521501778_item	2489862	et	3	main
oleks	doc_491521501778_item	2489865	et	3	main
helituna	doc_491521501778_item	2489876	et	4	main
on	doc_491521501778_item	2489701	et	4	main
amadeus	doc_491521501778_item	2489712	et	4	main
alati	doc_491521501778_item	2489714	et	4	main
registreeritud	doc_491521501778_item	2489728	et	4	main
vead	doc_491521501778_item	2489729	et	4	main
ja	doc_491521501778_item	2489733	et	3	main
hääldusviga	doc_491521501778_item	2489743	et	4	main
kuulis	doc_491521501778_item	2489754	et	4	main
pd	doc_491521501778_item	2489755	et	4	main
ja	doc_491521501778_item	2489762	et	3	main
sidesõna	doc_491521501778_item	2489769	et	4	main
ja	doc_491521501778_item	2489770	et	3	main
nähtus	doc_491521501778_item	2489803	et	4	main
korduvalt	doc_491521501778_item	2489804	et	4	main
see	doc_491521501778_item	2489811	et	3	main
restoranin	doc_491521501778_item	2489812	et	4	main
on	doc_491521501778_item	2489814	et	4	main
keele	doc_491521501778_item	2489819	et	4	main
menüü	doc_491521501778_item	2489825	et	4	main
gd	doc_491521501778_item	2489833	et	4	main
mis	doc_491521501778_item	2489842	et	4	main
kahe	doc_491521501778_item	2489844	et	3	main
vahel	doc_491521501778_item	2489846	et	4	main
vale	doc_491521501778_item	2489850	et	4	main
võimalik	doc_491521501778_item	2489853	et	3	main
viga	doc_491521501778_item	2489855	et	4	main
tingitud	doc_491521501778_item	2489857	et	4	main
ka	doc_491521501778_item	2489858	et	3	main
leitub	doc_491521501778_item	2489863	et	4	main
tegemist	doc_491521501778_item	2489870	et	4	main
helilise	doc_491521501778_item	2489871	et	4	main
kuid	doc_491521501778_item	2489877	et	4	main
tahate	doc_491521501778_item	2489918	et	3	main
d	doc_491521501778_item	2489922	et	4	main
tellima	doc_491521501778_item	2489929	et	3	main
ette	doc_491521501778_item	2489933	et	4	main
on	doc_491521501778_item	2489945	et	4	main
hääldatakse	doc_491521501778_item	2489951	et	3	main
kirjapildis	doc_491521501778_item	2489955	et	3	main
välismaalase	doc_491521501778_item	2489961	et	3	main
puhul	doc_491521501778_item	2489968	et	4	main
lihtlausega	doc_491521501778_item	2489999	et	3	main
hea	doc_491521501778_item	2490007	et	4	main
vajab	doc_491521501778_item	2490017	et	3	main
2	doc_491521501778_item	2490019	et	2	main
tellima	doc_491521501778_item	2489723	et	3	main
1	doc_491521501778_item	2489730	et	2	main
hääldus-	doc_491521501778_item	2489731	et	4	main
ja	doc_491521501778_item	2489735	et	3	main
on	doc_491521501778_item	2489737	et	4	main
bildil	doc_491521501778_item	2489739	et	4	main
selline	doc_491521501778_item	2489742	et	4	main
hea	doc_491521501778_item	2489761	et	4	main
mis	doc_491521501778_item	2489771	et	4	main
ilmselt	doc_491521501778_item	2489772	et	4	main
mõjutas	doc_491521501778_item	2489773	et	3	main
u	doc_491521501778_item	2489774	et	4	main
hääldust	doc_491521501778_item	2489775	et	4	main
mis	doc_491521501778_item	2489776	et	4	main
peaks	doc_491521501778_item	2489777	et	4	main
eesti	doc_491521501778_item	2489778	et	4	main
keeles	doc_491521501778_item	2489779	et	4	main
olema	doc_491521501778_item	2489780	et	4	main
kõrge	doc_491521501778_item	2489781	et	4	main
tagavokaal	doc_491521501778_item	2489782	et	3	main
kuid	doc_491521501778_item	2489783	et	4	main
naabruses	doc_491521501778_item	2489784	et	3	main
sidesõnaga	doc_491521501778_item	2489785	et	3	main
ja	doc_491521501778_item	2489786	et	3	main
muutub	doc_491521501778_item	2489787	et	3	main
kõrgeks	doc_491521501778_item	2489788	et	4	main
eesvokaaliks	doc_491521501778_item	2489789	et	4	main
oletan	doc_491521501778_item	2489790	et	3	main
et	doc_491521501778_item	2489791	et	3	main
tegemist	doc_491521501778_item	2489792	et	4	main
on	doc_491521501778_item	2489793	et	4	main
jällegi	doc_491521501778_item	2489794	et	4	main
soome	doc_491521501778_item	2489795	et	3	main
keele	doc_491521501778_item	2489796	et	4	main
mõjuga	doc_491521501778_item	2489797	et	3	main
kus	doc_491521501778_item	2489798	et	3	main
vokaalharmoonia	doc_491521501778_item	2489802	et	4	main
esinev	doc_491521501778_item	2489805	et	4	main
viga	doc_491521501778_item	2489806	et	4	main
restoranin	doc_491521501778_item	2489809	et	4	main
mõjuga	doc_491521501778_item	2489820	et	3	main
õpilase	doc_491521501778_item	2489822	et	3	main
peaks	doc_491521501778_item	2489826	et	4	main
menüü	doc_491521501778_item	2489829	et	4	main
peaks	doc_491521501778_item	2489836	et	4	main
olema	doc_491521501778_item	2489837	et	4	main
asjatundlikud	doc_491521501778_item	2489838	et	3	main
on	doc_491521501778_item	2489856	et	4	main
on	doc_491521501778_item	2489869	et	4	main
ilmselt	doc_491521501778_item	2489874	et	4	main
kuuldi	doc_491521501778_item	2489875	et	4	main
see	doc_491521501778_item	2489881	et	3	main
sealt	doc_491521501778_item	2489920	et	4	main
heliline	doc_491521501778_item	2489921	et	4	main
on	doc_491521501778_item	2489923	et	4	main
asendatud	doc_491521501778_item	2489924	et	4	main
helitu	doc_491521501778_item	2489925	et	4	main
mittu	doc_491521501778_item	2489931	et	4	main
see	doc_491521501778_item	2489937	et	3	main
jaoks	doc_491521501778_item	2489940	et	4	main
seega	doc_491521501778_item	2489949	et	4	main
kuidagi	doc_491521501778_item	2489957	et	3	main
itaalia	doc_491521501778_item	2489989	et	4	main
kiire	doc_491521501778_item	2489990	et	4	main
asjatuntlikult	doc_491521501778_item	2489995	et	4	main
vahel	doc_491521501778_item	2490001	et	4	main
seisma	doc_491521501778_item	2490003	et	3	main
teenindamine	doc_491521501778_item	2490008	et	4	main
kõku	doc_491521501778_item	2490011	et	4	main
kõrgklassist	doc_491521501778_item	2490013	et	3	main
lause	doc_491521501778_item	2490016	et	4	main
itaaliapäraseid	doc_491521501778_item	2490027	et	4	main
toitu	doc_491521501778_item	2490028	et	4	main
etmenüüst	doc_491521501778_item	2490034	et	4	main
kuid	doc_491521501778_item	2490047	et	4	main
teadnud	doc_491521501778_item	2490052	et	4	main
omadussõna	doc_491521501778_item	2490054	et	4	main
sai	doc_491521501778_item	2490056	et	4	main
ja	doc_491521501778_item	2490069	et	3	main
italialaasia	doc_491521501778_item	2490081	et	4	main
on	doc_491521501778_item	2490086	et	4	main
et	doc_491521501778_item	2490088	et	3	main
peamiselt	doc_491521501778_item	2490091	et	4	main
veinid	doc_491521501778_item	2490093	et	3	main
vale	doc_491521501778_item	2490098	et	4	main
sõnamoodustusviis	doc_491521501778_item	2490099	et	4	main
kui	doc_491521501778_item	2490100	et	3	main
te	doc_491521501778_item	2490101	et	4	main
tahate	doc_491521501778_item	2490102	et	3	main
kui	doc_491521501778_item	2490115	et	3	main
te	doc_491521501778_item	2490116	et	4	main
tahate	doc_491521501778_item	2490117	et	3	main
tellida	doc_491521501778_item	2490118	et	3	main
lauda	doc_491521501778_item	2490119	et	4	main
siis	doc_491521501778_item	2490120	et	3	main
ette	doc_491521501778_item	2490123	et	4	main
kirjutanud	doc_491521501778_item	2490144	et	4	main
menüült	doc_491521501778_item	2490148	et	3	main
kirjutada	doc_491521501778_item	2490152	et	3	main
menüüst	doc_491521501778_item	2490153	et	3	main
leidub	doc_491521501778_item	2490154	et	3	main
vea	doc_491521501778_item	2490155	et	4	main
eestlane	doc_491521501778_item	2490165	et	3	main
seal	doc_491521501778_item	2490168	et	4	main
sest	doc_491521501778_item	2490169	et	4	main
aga	doc_491521501778_item	2490180	et	3	main
asukohta	doc_491521501778_item	2490182	et	4	main
sellega	doc_491521501778_item	2490215	et	3	main
esimeses	doc_491521501778_item	2490217	et	3	main
5	doc_491521501778_item	2490224	et	2	main
itaaliapäraseid	doc_491521501778_item	2490229	et	4	main
nimisõna	doc_491521501778_item	2490231	et	4	main
itaaliapäraseid	doc_491521501778_item	2490239	et	4	main
ainsuses	doc_491521501778_item	2490243	et	4	main
dd	doc_491521501778_item	2489841	et	4	main
seisab	doc_491521501778_item	2489843	et	3	main
sellest	doc_491521501778_item	2489848	et	4	main
kirjutusviis	doc_491521501778_item	2489851	et	3	main
kasutusest	doc_491521501778_item	2489861	et	4	main
leiab	doc_491521501778_item	2489867	et	3	main
mida	doc_491521501778_item	2489873	et	4	main
on	doc_491521501778_item	2489878	et	4	main
et	doc_491521501778_item	2489880	et	3	main
lihtsalt	doc_491521501778_item	2489883	et	4	main
ortograafiline	doc_491521501778_item	2489884	et	4	main
viga	doc_491521501778_item	2489885	et	4	main
kõku	doc_491521501778_item	2489886	et	4	main
personal	doc_491521501778_item	2489887	et	3	main
võimalik	doc_491521501778_item	2489888	et	3	main
et	doc_491521501778_item	2489889	et	3	main
õpilane	doc_491521501778_item	2489890	et	3	main
on	doc_491521501778_item	2489891	et	4	main
varem	doc_491521501778_item	2489892	et	4	main
sõna	doc_491521501778_item	2489893	et	4	main
kogu	doc_491521501778_item	2489894	et	4	main
kuulnud	doc_491521501778_item	2489895	et	4	main
väga	doc_491521501778_item	2489896	et	3	main
tempokalt	doc_491521501778_item	2489897	et	4	main
hääldatuna	doc_491521501778_item	2489898	et	4	main
mille	doc_491521501778_item	2489899	et	3	main
tulemusena	doc_491521501778_item	2489900	et	3	main
o	doc_491521501778_item	2489901	et	4	main
keskkõrge	doc_491521501778_item	2489902	et	4	main
tagavokaal	doc_491521501778_item	2489903	et	3	main
muutus	doc_491521501778_item	2489904	et	4	main
õks	doc_491521501778_item	2489905	et	4	main
on	doc_491521501778_item	2489907	et	4	main
millel	doc_491521501778_item	2489906	et	3	main
eesti	doc_491521501778_item	2489908	et	4	main
keeles	doc_491521501778_item	2489909	et	4	main
eriline	doc_491521501778_item	2489910	et	4	main
koht	doc_491521501778_item	2489911	et	3	main
ees-	doc_491521501778_item	2489912	et	4	main
ja	doc_491521501778_item	2489913	et	3	main
tagavokaalide	doc_491521501778_item	2489914	et	3	main
vahel	doc_491521501778_item	2489915	et	4	main
kui	doc_491521501778_item	2489916	et	3	main
lauta	doc_491521501778_item	2489919	et	4	main
nädalad	doc_491521501778_item	2489932	et	3	main
mitu	doc_491521501778_item	2489936	et	4	main
mis	doc_491521501778_item	2489938	et	4	main
rõhuga	doc_491521501778_item	2489953	et	3	main
vea	doc_491521501778_item	2489967	et	4	main
koku	doc_491521501778_item	2489991	et	4	main
menüü	doc_491521501778_item	2489992	et	4	main
on	doc_491521501778_item	2489993	et	4	main
plaanitud	doc_491521501778_item	2489994	et	4	main
kahe	doc_491521501778_item	2489998	et	3	main
koma	doc_491521501778_item	2490004	et	4	main
restoranis	doc_491521501778_item	2490005	et	3	main
on	doc_491521501778_item	2490006	et	4	main
koma	doc_491521501778_item	2490018	et	4	main
ilmselt	doc_491521501778_item	2490029	et	4	main
leidub	doc_491521501778_item	2490035	et	3	main
ei	doc_491521501778_item	2490051	et	4	main
samas	doc_491521501778_item	2490061	et	4	main
erinevates	doc_491521501778_item	2490067	et	4	main
ühtu	doc_491521501778_item	2490071	et	4	main
käändes	doc_491521501778_item	2490074	et	3	main
seal	doc_491521501778_item	2490078	et	4	main
on	doc_491521501778_item	2490079	et	4	main
selle	doc_491521501778_item	2490084	et	4	main
on	doc_491521501778_item	2490090	et	4	main
on	doc_491521501778_item	2490096	et	4	main
lauta	doc_491521501778_item	2490103	et	4	main
teie	doc_491521501778_item	2490105	et	4	main
ette	doc_491521501778_item	2490111	et	4	main
eestlane	doc_491521501778_item	2490112	et	3	main
oleks	doc_491521501778_item	2490113	et	3	main
teatage	doc_491521501778_item	2490121	et	3	main
esiteks	doc_491521501778_item	2490130	et	3	main
kohakäänete	doc_491521501778_item	2490146	et	3	main
te	doc_491521501778_item	2490161	et	4	main
tahate	doc_491521501778_item	2490162	et	3	main
sealt	doc_491521501778_item	2490164	et	4	main
pigem	doc_491521501778_item	2490167	et	3	main
kas	doc_491521501778_item	2490173	et	3	main
asja	doc_491521501778_item	2490177	et	4	main
väljendab	doc_491521501778_item	2490184	et	3	main
vormi	doc_491521501778_item	2490223	et	4	main
ei	doc_491521501778_item	2490232	et	4	main
toite	doc_491521501778_item	2490240	et	4	main
toit	doc_491521501778_item	2490241	et	3	main
itaaliapäraseid	doc_491521501778_item	2490255	et	4	main
osastavas	doc_491521501778_item	2490256	et	4	main
6	doc_491521501778_item	2490257	et	2	main
kõige	doc_491521501778_item	2490261	et	4	main
restoranin	doc_491521501778_item	2490263	et	4	main
amadeus	doc_491521501778_item	2490266	et	4	main
peaks	doc_491521501778_item	2490267	et	4	main
menüü	doc_491521501778_item	2490291	et	4	main
siin	doc_491521501778_item	2490302	et	4	main
tuletada	doc_491521501778_item	2490305	et	3	main
et	doc_491521501778_item	2490312	et	3	main
on	doc_491521501778_item	2490314	et	4	main
võõrtüvelise	doc_491521501778_item	2490318	et	4	main
sõnaga	doc_491521501778_item	2490319	et	3	main
pikema	doc_491521501778_item	2490321	et	4	main
kasutamine	doc_491521501778_item	2490323	et	4	main
on	doc_491521501778_item	2490324	et	4	main
rohkem	doc_491521501778_item	2490325	et	4	main
on	doc_491521501778_item	2490339	et	4	main
plaanitud	doc_491521501778_item	2490345	et	4	main
asjatuntlikult	doc_491521501778_item	2490346	et	4	main
üsna	doc_491521501778_item	2490347	et	3	main
selle	doc_491521501778_item	2490354	et	4	main
minu	doc_491521501778_item	2490357	et	3	main
öelda	doc_491521501778_item	2490366	et	4	main
sõnamoodustuse	doc_491521501778_item	2490376	et	3	main
omadussõna	doc_491521501778_item	2490379	et	4	main
ja	doc_491521501778_item	2490384	et	3	main
oleks	doc_491521501778_item	2490397	et	3	main
hea	doc_491521501778_item	2490422	et	4	main
teenindamine	doc_491521501778_item	2490423	et	4	main
seal	doc_491521501778_item	2490424	et	4	main
et	doc_491521501778_item	2490441	et	3	main
kõrgel	doc_491521501778_item	2490455	et	4	main
tasemel	doc_491521501778_item	2490456	et	3	main
vale	doc_491521501778_item	2490457	et	4	main
teie	doc_491521501778_item	2489927	et	4	main
peate	doc_491521501778_item	2489928	et	4	main
see	doc_491521501778_item	2489930	et	3	main
olema	doc_491521501778_item	2489935	et	4	main
teise	doc_491521501778_item	2489946	et	4	main
välte	doc_491521501778_item	2489947	et	3	main
sõna	doc_491521501778_item	2489948	et	4	main
kerge	doc_491521501778_item	2489952	et	4	main
see	doc_491521501778_item	2489956	et	3	main
ei	doc_491521501778_item	2489958	et	4	main
on	doc_491521501778_item	2489960	et	4	main
võõras	doc_491521501778_item	2489963	et	4	main
italialaasia	doc_491521501778_item	2489964	et	4	main
olen	doc_491521501778_item	2489969	et	3	main
täiesti	doc_491521501778_item	2489970	et	3	main
nõutu	doc_491521501778_item	2489971	et	4	main
oletan	doc_491521501778_item	2489972	et	3	main
et	doc_491521501778_item	2489973	et	3	main
tegu	doc_491521501778_item	2489974	et	4	main
on	doc_491521501778_item	2489975	et	4	main
soome	doc_491521501778_item	2489976	et	3	main
keele	doc_491521501778_item	2489977	et	4	main
mõjuga	doc_491521501778_item	2489978	et	3	main
ehk	doc_491521501778_item	2489979	et	3	main
emakeele	doc_491521501778_item	2489980	et	4	main
interferentsiga	doc_491521501778_item	2489981	et	3	main
esineb	doc_491521501778_item	2489982	et	3	main
ka	doc_491521501778_item	2489983	et	3	main
punktuatsioonivigu	doc_491521501778_item	2489984	et	4	main
näiteks	doc_491521501778_item	2489985	et	4	main
see	doc_491521501778_item	2489986	et	3	main
restoranin	doc_491521501778_item	2489987	et	4	main
on	doc_491521501778_item	2489988	et	4	main
on	doc_491521501778_item	2489997	et	4	main
peaks	doc_491521501778_item	2490002	et	4	main
seal	doc_491521501778_item	2490009	et	4	main
personal	doc_491521501778_item	2490012	et	3	main
ka	doc_491521501778_item	2490014	et	3	main
menüült	doc_491521501778_item	2490024	et	3	main
tüüpilised	doc_491521501778_item	2490026	et	3	main
mõeldud	doc_491521501778_item	2490033	et	4	main
osastavas	doc_491521501778_item	2490045	et	4	main
käändes	doc_491521501778_item	2490046	et	3	main
seda	doc_491521501778_item	2490050	et	3	main
ja	doc_491521501778_item	2490053	et	3	main
on	doc_491521501778_item	2490066	et	4	main
ei	doc_491521501778_item	2490070	et	4	main
nimisõnaga	doc_491521501778_item	2490072	et	3	main
arvus	doc_491521501778_item	2490076	et	3	main
lausega	doc_491521501778_item	2490085	et	3	main
mõeldud	doc_491521501778_item	2490087	et	4	main
veinikelder	doc_491521501778_item	2490097	et	3	main
öelnud	doc_491521501778_item	2490114	et	4	main
ette	doc_491521501778_item	2490129	et	4	main
õpilane	doc_491521501778_item	2490143	et	3	main
vead	doc_491521501778_item	2490147	et	4	main
2	doc_491521501778_item	2490158	et	2	main
punktis	doc_491521501778_item	2490159	et	4	main
kääne	doc_491521501778_item	2490171	et	3	main
teate	doc_491521501778_item	2490175	et	4	main
allikat	doc_491521501778_item	2490178	et	3	main
mõeldakse	doc_491521501778_item	2490181	et	3	main
kasutas	doc_491521501778_item	2490219	et	3	main
ja	doc_491521501778_item	2490022	et	3	main
selle	doc_491521501778_item	2490030	et	4	main
lausega	doc_491521501778_item	2490031	et	3	main
tüüpilisi	doc_491521501778_item	2490036	et	3	main
tegemist	doc_491521501778_item	2490039	et	4	main
mis	doc_491521501778_item	2490042	et	4	main
nõuab	doc_491521501778_item	2490043	et	3	main
sihitist	doc_491521501778_item	2490044	et	3	main
õpilane	doc_491521501778_item	2490049	et	3	main
itaaliapäraseid	doc_491521501778_item	2490055	et	4	main
endale	doc_491521501778_item	2490057	et	4	main
õige	doc_491521501778_item	2490058	et	4	main
käände	doc_491521501778_item	2490059	et	4	main
kogemata	doc_491521501778_item	2490060	et	4	main
on	doc_491521501778_item	2490062	et	4	main
näha	doc_491521501778_item	2490063	et	3	main
et	doc_491521501778_item	2490064	et	3	main
omadussõnad	doc_491521501778_item	2490065	et	3	main
leitub	doc_491521501778_item	2490025	et	4	main
on	doc_491521501778_item	2490032	et	4	main
itaaliapäraseid	doc_491521501778_item	2490037	et	4	main
toite	doc_491521501778_item	2490038	et	4	main
on	doc_491521501778_item	2490040	et	4	main
partitiivverbiga	doc_491521501778_item	2490041	et	4	main
ilmselt	doc_491521501778_item	2490048	et	4	main
käänetes	doc_491521501778_item	2490068	et	3	main
ei	doc_491521501778_item	2490073	et	4	main
peaasjalikult	doc_491521501778_item	2490080	et	4	main
ilmselt	doc_491521501778_item	2490083	et	4	main
seal	doc_491521501778_item	2490089	et	4	main
itaalia	doc_491521501778_item	2490092	et	4	main
veinkelder	doc_491521501778_item	2490094	et	4	main
tellima	doc_491521501778_item	2490107	et	3	main
see	doc_491521501778_item	2490108	et	3	main
mittu	doc_491521501778_item	2490109	et	4	main
nädalad	doc_491521501778_item	2490110	et	3	main
ega	doc_491521501778_item	2490075	et	3	main
ja	doc_491521501778_item	2490077	et	3	main
veineja	doc_491521501778_item	2490082	et	4	main
õige	doc_491521501778_item	2490095	et	4	main
sealt	doc_491521501778_item	2490104	et	4	main
peate	doc_491521501778_item	2490106	et	4	main
sellest	doc_491521501778_item	2490122	et	4	main
või	doc_491521501778_item	2490124	et	4	main
siis	doc_491521501778_item	2490125	et	3	main
reserveerige	doc_491521501778_item	2490126	et	3	main
see	doc_491521501778_item	2490127	et	3	main
eelnevalt	doc_491521501778_item	2490128	et	4	main
seda	doc_491521501778_item	2490138	et	3	main
mitte	doc_491521501778_item	2490139	et	3	main
see	doc_491521501778_item	2490140	et	3	main
nagu	doc_491521501778_item	2490141	et	3	main
on	doc_491521501778_item	2490142	et	4	main
seletus	doc_491521501778_item	2490156	et	4	main
on	doc_491521501778_item	2490157	et	4	main
alaltütlev	doc_491521501778_item	2490170	et	4	main
lähtekohta	doc_491521501778_item	2490174	et	4	main
või	doc_491521501778_item	2490176	et	4	main
mida	doc_491521501778_item	2490183	et	4	main
lauses	doc_491521501778_item	2490218	et	3	main
selle	doc_491521501778_item	2490220	et	4	main
asesõna	doc_491521501778_item	2490221	et	4	main
toitu	doc_491521501778_item	2490230	et	4	main
on	doc_491521501778_item	2490242	et	4	main
on	doc_491521501778_item	2490246	et	4	main
käänded	doc_491521501778_item	2490248	et	3	main
valed	doc_491521501778_item	2490251	et	3	main
võrdlusastmed	doc_491521501778_item	2490259	et	3	main
olema	doc_491521501778_item	2490268	et	4	main
menüü	doc_491521501778_item	2490298	et	4	main
on	doc_491521501778_item	2490299	et	4	main
püüdis	doc_491521501778_item	2490304	et	3	main
tähele	doc_491521501778_item	2490311	et	3	main
keele	doc_491521501778_item	2490316	et	4	main
ka	doc_491521501778_item	2490330	et	3	main
8	doc_491521501778_item	2490334	et	2	main
see	doc_491521501778_item	2490337	et	3	main
restoranin	doc_491521501778_item	2490338	et	4	main
koku	doc_491521501778_item	2490342	et	4	main
menüü	doc_491521501778_item	2490343	et	4	main
on	doc_491521501778_item	2490349	et	4	main
analüüsida	doc_491521501778_item	2490350	et	3	main
seda	doc_491521501778_item	2490351	et	3	main
jäi	doc_491521501778_item	2490356	et	3	main
ei	doc_491521501778_item	2490372	et	4	main
seda	doc_491521501778_item	2490374	et	3	main
ja	doc_491521501778_item	2490380	et	3	main
liitmise	doc_491521501778_item	2490382	et	4	main
siis	doc_491521501778_item	2490385	et	3	main
kergema	doc_491521501778_item	2490387	et	4	main
itaaliapäraseid	doc_491521501778_item	2490393	et	4	main
kahtlemata	doc_491521501778_item	2490395	et	4	main
siin	doc_491521501778_item	2490396	et	4	main
on	doc_491521501778_item	2490425	et	4	main
välja	doc_491521501778_item	2490430	et	4	main
lause	doc_491521501778_item	2490434	et	4	main
kui	doc_491521501778_item	2490436	et	3	main
arvata	doc_491521501778_item	2490440	et	4	main
kelneritega	doc_491521501778_item	2490445	et	3	main
on	doc_491521501778_item	2490454	et	4	main
te	doc_491521501778_item	2490463	et	4	main
sealt	doc_491521501778_item	2490466	et	4	main
peate	doc_491521501778_item	2490468	et	4	main
tellima	doc_491521501778_item	2490469	et	3	main
öelda	doc_491521501778_item	2490476	et	4	main
reserveerida	doc_491521501778_item	2490477	et	3	main
voi	doc_491521501778_item	2490478	et	4	main
roogasid	doc_491521501778_item	2490482	et	3	main
sõna	doc_491521501778_item	2490491	et	4	main
peamiselt	doc_491521501778_item	2490496	et	4	main
oletan	doc_491521501778_item	2490497	et	3	main
ka	doc_491521501778_item	2490499	et	3	main
võis	doc_491521501778_item	2490502	et	4	main
selle	doc_491521501778_item	2490519	et	4	main
vaatamata	doc_491521501778_item	2490528	et	4	main
loogiliselt	doc_491521501778_item	2490537	et	4	main
ülesehitatud	doc_491521501778_item	2490538	et	4	main
õpilane	doc_491521501778_item	2490549	et	3	main
sealt	doc_491521501778_item	2490131	et	4	main
eestlane	doc_491521501778_item	2490132	et	3	main
ütleks	doc_491521501778_item	2490133	et	3	main
pigem	doc_491521501778_item	2490134	et	3	main
seal	doc_491521501778_item	2490135	et	4	main
tellima	doc_491521501778_item	2490136	et	3	main
mida	doc_491521501778_item	2490137	et	4	main
3	doc_491521501778_item	2490145	et	2	main
leitub	doc_491521501778_item	2490149	et	4	main
õige	doc_491521501778_item	2490150	et	4	main
oleks	doc_491521501778_item	2490151	et	3	main
kui	doc_491521501778_item	2490160	et	3	main
lauta	doc_491521501778_item	2490163	et	4	main
ütleks	doc_491521501778_item	2490166	et	3	main
väljendab	doc_491521501778_item	2490172	et	3	main
siin	doc_491521501778_item	2490179	et	4	main
alalütlev	doc_491521501778_item	2490185	et	3	main
kääne	doc_491521501778_item	2490186	et	3	main
4	doc_491521501778_item	2490187	et	2	main
pronoomenivead	doc_491521501778_item	2490188	et	4	main
kui	doc_491521501778_item	2490189	et	3	main
te	doc_491521501778_item	2490190	et	4	main
tahate	doc_491521501778_item	2490191	et	3	main
lauta	doc_491521501778_item	2490192	et	4	main
sealt	doc_491521501778_item	2490193	et	4	main
teie	doc_491521501778_item	2490194	et	4	main
peate	doc_491521501778_item	2490195	et	4	main
tellima	doc_491521501778_item	2490196	et	3	main
see	doc_491521501778_item	2490197	et	3	main
mittu	doc_491521501778_item	2490198	et	4	main
nädalad	doc_491521501778_item	2490199	et	3	main
ette	doc_491521501778_item	2490200	et	4	main
oleks	doc_491521501778_item	2490201	et	3	main
parem	doc_491521501778_item	2490202	et	4	main
loobuda	doc_491521501778_item	2490203	et	3	main
kahekordsest	doc_491521501778_item	2490204	et	3	main
asesõnast	doc_491521501778_item	2490205	et	4	main
teie	doc_491521501778_item	2490206	et	4	main
paistab	doc_491521501778_item	2490207	et	3	main
et	doc_491521501778_item	2490208	et	3	main
õpilane	doc_491521501778_item	2490209	et	3	main
püüdis	doc_491521501778_item	2490210	et	3	main
kompenseerida	doc_491521501778_item	2490211	et	3	main
asesõna	doc_491521501778_item	2490212	et	4	main
topelt	doc_491521501778_item	2490213	et	4	main
et	doc_491521501778_item	2490216	et	3	main
kasutamist	doc_491521501778_item	2490214	et	4	main
ühildumisvead	doc_491521501778_item	2490225	et	4	main
leitub	doc_491521501778_item	2490227	et	4	main
tüüpilised	doc_491521501778_item	2490228	et	3	main
omadussõnad	doc_491521501778_item	2490245	et	3	main
parim	doc_491521501778_item	2490262	et	4	main
nimi	doc_491521501778_item	2490264	et	3	main
on	doc_491521501778_item	2490265	et	4	main
koku	doc_491521501778_item	2490290	et	4	main
on	doc_491521501778_item	2490292	et	4	main
oleks	doc_491521501778_item	2490295	et	3	main
öelda	doc_491521501778_item	2490296	et	4	main
ilmselt	doc_491521501778_item	2490301	et	4	main
verbi	doc_491521501778_item	2490306	et	4	main
ja	doc_491521501778_item	2490308	et	3	main
eesti	doc_491521501778_item	2490315	et	4	main
jaoks	doc_491521501778_item	2490317	et	4	main
kus	doc_491521501778_item	2490320	et	3	main
tüvevariandi	doc_491521501778_item	2490322	et	4	main
nagu	doc_491521501778_item	2490329	et	3	main
tsementeerima	doc_491521501778_item	2490332	et	3	main
sõnatasandi	doc_491521501778_item	2490335	et	3	main
raske	doc_491521501778_item	2490348	et	4	main
mõte	doc_491521501778_item	2490355	et	3	main
jaoks	doc_491521501778_item	2490358	et	4	main
ähmaseks	doc_491521501778_item	2490360	et	4	main
oletan	doc_491521501778_item	2490361	et	3	main
taheti	doc_491521501778_item	2490365	et	3	main
et	doc_491521501778_item	2490367	et	3	main
on	doc_491521501778_item	2490369	et	4	main
osatud	doc_491521501778_item	2490373	et	4	main
abil	doc_491521501778_item	2490378	et	4	main
tüüpilised	doc_491521501778_item	2490392	et	3	main
personal	doc_491521501778_item	2490427	et	3	main
lõigatuna	doc_491521501778_item	2490431	et	4	main
imelikult	doc_491521501778_item	2490437	et	4	main
sest	doc_491521501778_item	2490438	et	4	main
võib	doc_491521501778_item	2490439	et	3	main
oleks	doc_491521501778_item	2490447	et	3	main
või	doc_491521501778_item	2490452	et	4	main
personal	doc_491521501778_item	2490453	et	3	main
lauta	doc_491521501778_item	2490465	et	4	main
teie	doc_491521501778_item	2490467	et	4	main
panna	doc_491521501778_item	2490480	et	4	main
itaalialaasia	doc_491521501778_item	2490486	et	4	main
olema	doc_491521501778_item	2490495	et	4	main
õpilane	doc_491521501778_item	2490501	et	3	main
mingist	doc_491521501778_item	2490504	et	4	main
talle	doc_491521501778_item	2490506	et	4	main
omasest	doc_491521501778_item	2490507	et	3	main
on	doc_491521501778_item	2490518	et	4	main
lühikest	doc_491521501778_item	2490222	et	4	main
menüült	doc_491521501778_item	2490226	et	3	main
ühtu	doc_491521501778_item	2490233	et	4	main
omadussõnadega	doc_491521501778_item	2490234	et	3	main
peaks	doc_491521501778_item	2490235	et	4	main
olema	doc_491521501778_item	2490236	et	4	main
leidub	doc_491521501778_item	2490237	et	3	main
tüüpilisi	doc_491521501778_item	2490238	et	3	main
kuid	doc_491521501778_item	2490244	et	4	main
mitmuses	doc_491521501778_item	2490247	et	3	main
on	doc_491521501778_item	2490249	et	4	main
omadussõna	doc_491521501778_item	2490258	et	4	main
kõige	doc_491521501778_item	2490269	et	4	main
kuid	doc_491521501778_item	2490271	et	4	main
õpilane	doc_491521501778_item	2490272	et	3	main
kasutas	doc_491521501778_item	2490273	et	3	main
2	doc_491521501778_item	2490274	et	2	main
korda	doc_491521501778_item	2490275	et	4	main
ülivõrret	doc_491521501778_item	2490276	et	3	main
vaatamata	doc_491521501778_item	2490277	et	4	main
sellele	doc_491521501778_item	2490278	et	4	main
et	doc_491521501778_item	2490279	et	3	main
sõna	doc_491521501778_item	2490280	et	4	main
parim	doc_491521501778_item	2490281	et	4	main
ütleb	doc_491521501778_item	2490282	et	3	main
niigi	doc_491521501778_item	2490283	et	4	main
kõik	doc_491521501778_item	2490284	et	4	main
ära	doc_491521501778_item	2490285	et	4	main
7	doc_491521501778_item	2490286	et	2	main
verbivormide	doc_491521501778_item	2490287	et	4	main
valiku	doc_491521501778_item	2490288	et	3	main
vead	doc_491521501778_item	2490289	et	4	main
ka	doc_491521501778_item	2490250	et	3	main
tüüpilised	doc_491521501778_item	2490252	et	3	main
on	doc_491521501778_item	2490253	et	4	main
nimetavas	doc_491521501778_item	2490254	et	4	main
tallinnan	doc_491521501778_item	2490260	et	4	main
parem	doc_491521501778_item	2490270	et	4	main
plaanitud	doc_491521501778_item	2490293	et	4	main
õigem	doc_491521501778_item	2490294	et	4	main
planeeritud	doc_491521501778_item	2490300	et	4	main
pannud	doc_491521501778_item	2490310	et	4	main
tegemist	doc_491521501778_item	2490313	et	4	main
levinud	doc_491521501778_item	2490326	et	4	main
planeerima	doc_491521501778_item	2490328	et	3	main
tsementima	doc_491521501778_item	2490331	et	4	main
puhul	doc_491521501778_item	2490333	et	4	main
on	doc_491521501778_item	2490344	et	4	main
lauset	doc_491521501778_item	2490352	et	3	main
natuke	doc_491521501778_item	2490359	et	4	main
et	doc_491521501778_item	2490362	et	3	main
lausega	doc_491521501778_item	2490364	et	3	main
kiirrestoraniga	doc_491521501778_item	2490370	et	4	main
väljendada	doc_491521501778_item	2490375	et	3	main
vahendite	doc_491521501778_item	2490377	et	3	main
nimisõna	doc_491521501778_item	2490381	et	4	main
teel	doc_491521501778_item	2490383	et	4	main
mindi	doc_491521501778_item	2490386	et	3	main
toitu	doc_491521501778_item	2490394	et	4	main
kõrgklassist	doc_491521501778_item	2490428	et	3	main
see	doc_491521501778_item	2490433	et	3	main
rohkem	doc_491521501778_item	2490435	et	4	main
aadlisoost	doc_491521501778_item	2490444	et	4	main
kõrgema	doc_491521501778_item	2490449	et	4	main
klassi	doc_491521501778_item	2490450	et	4	main
personal	doc_491521501778_item	2490451	et	3	main
see	doc_491521501778_item	2490470	et	3	main
mittu	doc_491521501778_item	2490471	et	4	main
nädalad	doc_491521501778_item	2490472	et	3	main
kinni	doc_491521501778_item	2490479	et	3	main
mitte	doc_491521501778_item	2490483	et	3	main
selle	doc_491521501778_item	2490492	et	4	main
asemel	doc_491521501778_item	2490493	et	4	main
ainult	doc_491521501778_item	2490505	et	4	main
loogikast	doc_491521501778_item	2490508	et	4	main
järgmisi	doc_491521501778_item	2490514	et	3	main
autori	doc_491521501778_item	2490521	et	3	main
tekst	doc_491521501778_item	2490530	et	3	main
väga	doc_491521501778_item	2490532	et	3	main
mulje	doc_491521501778_item	2490534	et	4	main
ja	doc_491521501778_item	2490539	et	3	main
veel	doc_491521501778_item	2490556	et	4	main
grammatikat	doc_491521501778_item	2490557	et	3	main
lihvima	doc_491521501778_item	2490558	et	3	main
analüüs	doc_491521501779_item	2490559	et	3	main
kontrastiivlingvistika	doc_491521501779_item	2490560	et	4	main
veaanal	doc_491521501779_item	2490561	et	4	main
ühildumisvead	doc_491521501779_item	2490564	et	4	main
sõnad	doc_491521501779_item	2490571	et	4	main
kinos	doc_491521501779_item	2490576	et	3	main
nad	doc_491521501779_item	2490577	et	3	main
on	doc_491521501779_item	2490578	et	4	main
võimalus	doc_491521501779_item	2490579	et	3	main
kolm	doc_491521501779_item	2490586	et	3	main
filmis	doc_491521501779_item	2490588	et	4	main
tõeline	doc_491521501779_item	2490593	et	4	main
on	doc_491521501779_item	2490605	et	4	main
teises	doc_491521501779_item	2490609	et	4	main
juttu	doc_491521501779_item	2490617	et	4	main
kasutus	doc_491521501779_item	2490634	et	4	main
lisaks	doc_491521501779_item	2490636	et	4	main
sõnatasandi	doc_491521501779_item	2490637	et	3	main
da-infinitiivi	doc_491521501779_item	2490654	et	4	main
vead	doc_491521501779_item	2490664	et	4	main
ja	doc_491521501779_item	2490675	et	3	main
hooletusviga	doc_491521501779_item	2490676	et	4	main
pildis	doc_491521501779_item	2490677	et	3	main
vaiba	doc_491521501779_item	2490684	et	3	main
vene	doc_491521501779_item	2490722	et	4	main
tekisid	doc_491521501779_item	2490726	et	4	main
vahel	doc_491521501779_item	2490728	et	4	main
peaksin	doc_491521501779_item	2490730	et	4	main
kõiketega	doc_491521501779_item	2490732	et	3	main
kogu	doc_491521501778_item	2490297	et	4	main
õpilane	doc_491521501778_item	2490303	et	3	main
nimisõnast	doc_491521501778_item	2490307	et	4	main
ei	doc_491521501778_item	2490309	et	4	main
plaanima	doc_491521501778_item	2490327	et	3	main
vead	doc_491521501778_item	2490336	et	4	main
itaalia	doc_491521501778_item	2490340	et	4	main
kiire	doc_491521501778_item	2490341	et	4	main
kuna	doc_491521501778_item	2490353	et	3	main
selle	doc_491521501778_item	2490363	et	4	main
tegemist	doc_491521501778_item	2490368	et	4	main
kuid	doc_491521501778_item	2490371	et	4	main
vastupanu	doc_491521501778_item	2490388	et	4	main
teed	doc_491521501778_item	2490389	et	4	main
menüült	doc_491521501778_item	2490390	et	3	main
leitub	doc_491521501778_item	2490391	et	4	main
parem	doc_491521501778_item	2490398	et	4	main
kasutada	doc_491521501778_item	2490399	et	3	main
sõna	doc_491521501778_item	2490400	et	4	main
toit	doc_491521501778_item	2490401	et	3	main
asemel	doc_491521501778_item	2490402	et	4	main
roogasid	doc_491521501778_item	2490403	et	3	main
mis	doc_491521501778_item	2490404	et	4	main
rohkem	doc_491521501778_item	2490405	et	4	main
vastab	doc_491521501778_item	2490406	et	3	main
kontekstile	doc_491521501778_item	2490407	et	3	main
sõna	doc_491521501778_item	2490408	et	4	main
toit	doc_491521501778_item	2490409	et	3	main
on	doc_491521501778_item	2490410	et	4	main
liiga	doc_491521501778_item	2490411	et	4	main
üldine	doc_491521501778_item	2490412	et	4	main
sest	doc_491521501778_item	2490413	et	4	main
siin	doc_491521501778_item	2490414	et	4	main
mõeldakse	doc_491521501778_item	2490415	et	3	main
ikka	doc_491521501778_item	2490416	et	4	main
konkreetseid	doc_491521501778_item	2490417	et	3	main
itaaliapäraseid	doc_491521501778_item	2490418	et	4	main
roogasid	doc_491521501778_item	2490419	et	3	main
restoranis	doc_491521501778_item	2490420	et	3	main
on	doc_491521501778_item	2490421	et	4	main
kõku	doc_491521501778_item	2490426	et	4	main
kontekstist	doc_491521501778_item	2490429	et	3	main
kõlab	doc_491521501778_item	2490432	et	3	main
tegemist	doc_491521501778_item	2490442	et	4	main
on	doc_491521501778_item	2490443	et	4	main
õigem	doc_491521501778_item	2490446	et	4	main
öelda	doc_491521501778_item	2490448	et	4	main
tahate	doc_491521501778_item	2490464	et	3	main
oleks	doc_491521501778_item	2490475	et	3	main
peaasjalikult	doc_491521501778_item	2490485	et	4	main
peaasjalikult	doc_491521501778_item	2490488	et	4	main
on	doc_491521501778_item	2490489	et	4	main
et	doc_491521501778_item	2490498	et	3	main
lähtuda	doc_491521501778_item	2490503	et	3	main
pakutakse	doc_491521501778_item	2490511	et	3	main
asju	doc_491521501778_item	2490515	et	3	main
see	doc_491521501778_item	2490517	et	3	main
töö	doc_491521501778_item	2490520	et	4	main
arvamus	doc_491521501778_item	2490523	et	3	main
et	doc_491521501778_item	2490527	et	3	main
ta	doc_491521501778_item	2490535	et	4	main
on	doc_491521501778_item	2490536	et	4	main
kirjutatud	doc_491521501778_item	2490540	et	4	main
keeles	doc_491521501778_item	2490542	et	4	main
keelt	doc_491521501778_item	2490550	et	4	main
saates	doc_491521501779_item	2490566	et	4	main
koosnevad	doc_491521501779_item	2490572	et	4	main
naljakat	doc_491521501779_item	2490573	et	3	main
teksti	doc_491521501779_item	2490574	et	4	main
millest	doc_491521501779_item	2490575	et	3	main
kolmest	doc_491521501779_item	2490583	et	4	main
läbi	doc_491521501779_item	2490600	et	4	main
igasuguseid	doc_491521501779_item	2490601	et	3	main
muudatusi	doc_491521501779_item	2490602	et	3	main
esimeses	doc_491521501779_item	2490603	et	3	main
lausepooles	doc_491521501779_item	2490604	et	3	main
ei	doc_491521501779_item	2490613	et	4	main
mingisugust	doc_491521501779_item	2490615	et	3	main
vaatan	doc_491521501779_item	2490621	et	3	main
da-infinitiivi	doc_491521501779_item	2490632	et	4	main
viga	doc_491521501779_item	2490638	et	4	main
adjektiivi	doc_491521501779_item	2490641	et	4	main
milline	doc_491521501779_item	2490642	et	3	main
võimalus	doc_491521501779_item	2490648	et	3	main
ja	doc_491521501779_item	2490653	et	3	main
ta	doc_491521501779_item	2490656	et	4	main
kohakäänete	doc_491521501779_item	2490663	et	3	main
teemal	doc_491521501779_item	2490671	et	3	main
samas	doc_491521501779_item	2490672	et	4	main
ka	doc_491521501779_item	2490673	et	3	main
ühildumis-	doc_491521501779_item	2490674	et	4	main
tuba	doc_491521501779_item	2490680	et	4	main
ajavad	doc_491521501779_item	2490686	et	4	main
minuutit	doc_491521501779_item	2490721	et	4	main
keele	doc_491521501779_item	2490723	et	4	main
kirjapilt	doc_491521501779_item	2490725	et	3	main
astmevaheldusviga	doc_491521501779_item	2490729	et	4	main
proffessorid	doc_491521501779_item	2490740	et	4	main
rezisöörina	doc_491521501779_item	2490742	et	4	main
kutsuta	doc_491521501779_item	2490744	et	4	main
oma	doc_491521501779_item	2490745	et	4	main
teada	doc_491521501779_item	2490759	et	3	main
teise	doc_491521501779_item	2490761	et	4	main
sõja	doc_491521501779_item	2490763	et	3	main
ajal	doc_491521501779_item	2490764	et	4	main
siis	doc_491521501779_item	2490766	et	3	main
puhul	doc_491521501779_item	2490773	et	4	main
partitiivivormi	doc_491521501779_item	2490775	et	4	main
uut	doc_491521501779_item	2490778	et	3	main
tegevuse	doc_491521501779_item	2490786	et	4	main
verbivormide	doc_491521501779_item	2490790	et	4	main
et	doc_491521501779_item	2490807	et	3	main
ikka	doc_491521501779_item	2490819	et	4	main
kõlaliselt	doc_491521501779_item	2490823	et	4	main
ta	doc_491521501779_item	2490834	et	4	main
kütta	doc_491521501779_item	2490850	et	3	main
mida	doc_491521501779_item	2490851	et	4	main
sõprust	doc_491521501779_item	2490853	et	3	main
parem	doc_491521501779_item	2490854	et	4	main
vorm	doc_491521501779_item	2490855	et	3	main
kümme	doc_491521501779_item	2490858	et	3	main
aasta	doc_491521501779_item	2490859	et	4	main
olid	doc_491521501779_item	2490863	et	4	main
vaadata	doc_491521501779_item	2490869	et	4	main
ebaõnnetu	doc_491521501779_item	2490910	et	4	main
kääne	doc_491521501778_item	2490458	et	3	main
põhjustab	doc_491521501778_item	2490459	et	3	main
valesti	doc_491521501778_item	2490460	et	3	main
mõistmist	doc_491521501778_item	2490461	et	4	main
kui	doc_491521501778_item	2490462	et	3	main
ette	doc_491521501778_item	2490473	et	4	main
parem	doc_491521501778_item	2490474	et	4	main
tellitakse	doc_491521501778_item	2490481	et	3	main
laudasid	doc_491521501778_item	2490484	et	3	main
veineja	doc_491521501778_item	2490487	et	4	main
vale	doc_491521501778_item	2490490	et	4	main
peaks	doc_491521501778_item	2490494	et	4	main
siin	doc_491521501778_item	2490500	et	4	main
ala	doc_491521501778_item	2490509	et	4	main
peamiselt	doc_491521501778_item	2490510	et	4	main
selles	doc_491521501778_item	2490512	et	4	main
restoranis	doc_491521501778_item	2490513	et	3	main
kuid	doc_491521501778_item	2490516	et	4	main
lõpetuseks	doc_491521501778_item	2490524	et	4	main
öelda	doc_491521501778_item	2490526	et	4	main
jätab	doc_491521501778_item	2490531	et	3	main
rikas	doc_491521501778_item	2490541	et	4	main
selleks	doc_491521501778_item	2490543	et	4	main
et	doc_491521501778_item	2490544	et	3	main
suuliselt	doc_491521501778_item	2490545	et	4	main
üü	doc_491521501779_item	2490562	et	4	main
selles	doc_491521501779_item	2490565	et	4	main
kellel	doc_491521501779_item	2490580	et	4	main
ülikooliõpilastest	doc_491521501779_item	2490584	et	4	main
kahe	doc_491521501779_item	2490591	et	3	main
inimese	doc_491521501779_item	2490592	et	4	main
armastus	doc_491521501779_item	2490594	et	4	main
mida	doc_491521501779_item	2490595	et	4	main
kui	doc_491521501779_item	2490596	et	3	main
kasutatud	doc_491521501779_item	2490606	et	4	main
käändevormi	doc_491521501779_item	2490608	et	4	main
pooles	doc_491521501779_item	2490610	et	4	main
on	doc_491521501779_item	2490611	et	4	main
naljaka	doc_491521501779_item	2490616	et	3	main
partitiiv	doc_491521501779_item	2490619	et	3	main
vaatamamida	doc_491521501779_item	2490623	et	4	main
kui	doc_491521501779_item	2490624	et	3	main
peab	doc_491521501779_item	2490627	et	4	main
olla	doc_491521501779_item	2490628	et	3	main
leidlikkus	doc_491521501779_item	2490629	et	4	main
ma-	doc_491521501779_item	2490630	et	3	main
vale	doc_491521501779_item	2490639	et	4	main
sõnavalik	doc_491521501779_item	2490640	et	3	main
asemel	doc_491521501779_item	2490643	et	4	main
on	doc_491521501779_item	2490644	et	4	main
kasutatud	doc_491521501779_item	2490645	et	4	main
oma	doc_491521501779_item	2490649	et	4	main
parandama	doc_491521501779_item	2490651	et	3	main
viga	doc_491521501779_item	2490655	et	4	main
peab	doc_491521501779_item	2490657	et	4	main
kõik	doc_491521501779_item	2490658	et	4	main
vastu	doc_491521501779_item	2490659	et	3	main
millele	doc_491521501779_item	2490660	et	3	main
vastu	doc_491521501779_item	2490661	et	3	main
ei	doc_491521501779_item	2490665	et	4	main
kirjutada	doc_491521501779_item	2490667	et	3	main
muud	doc_491521501779_item	2490668	et	4	main
huvitavat	doc_491521501779_item	2490669	et	4	main
suure	doc_491521501779_item	2490683	et	3	main
subjektiivne	doc_491521501778_item	2490522	et	3	main
tahan	doc_491521501778_item	2490525	et	3	main
vigadele	doc_491521501778_item	2490529	et	3	main
hea	doc_491521501778_item	2490533	et	4	main
suhelda	doc_491521501778_item	2490546	et	4	main
valdab	doc_491521501778_item	2490547	et	3	main
see	doc_491521501778_item	2490548	et	3	main
piisavalt	doc_491521501778_item	2490551	et	4	main
heal	doc_491521501778_item	2490552	et	3	main
tasemel	doc_491521501778_item	2490553	et	3	main
kuid	doc_491521501778_item	2490554	et	4	main
peab	doc_491521501778_item	2490555	et	4	main
s	doc_491521501779_item	2490563	et	4	main
võtavad	doc_491521501779_item	2490567	et	3	main
millest	doc_491521501779_item	2490569	et	3	main
filmis	doc_491521501779_item	2490581	et	4	main
räägitakse	doc_491521501779_item	2490582	et	3	main
kujutatud	doc_491521501779_item	2490590	et	4	main
õiget	doc_491521501779_item	2490607	et	3	main
ma	doc_491521501779_item	2490620	et	3	main
kanal	doc_491521501779_item	2490622	et	4	main
ja	doc_491521501779_item	2490631	et	3	main
on	doc_491521501779_item	2490647	et	4	main
vigu	doc_491521501779_item	2490650	et	3	main
pidama	doc_491521501779_item	2490662	et	4	main
saa	doc_491521501779_item	2490666	et	4	main
kaks	doc_491521501779_item	2490679	et	3	main
elutoas	doc_491521501779_item	2490681	et	3	main
mitte-eestlased	doc_491521501779_item	2490685	et	3	main
nende	doc_491521501779_item	2490727	et	4	main
vanemad	doc_491521501779_item	2490737	et	4	main
mõju	doc_491521501779_item	2490752	et	4	main
kord	doc_491521501779_item	2490756	et	4	main
ei	doc_491521501779_item	2490768	et	4	main
teleri	doc_491521501779_item	2490770	et	3	main
telerit	doc_491521501779_item	2490779	et	3	main
sünnitab	doc_491521501779_item	2490780	et	3	main
genitiivi	doc_491521501779_item	2490788	et	4	main
et	doc_491521501779_item	2490801	et	3	main
kui	doc_491521501779_item	2490802	et	3	main
saada	doc_491521501779_item	2490803	et	4	main
autori	doc_491521501779_item	2490804	et	3	main
mõtteid	doc_491521501779_item	2490805	et	3	main
armastust	doc_491521501779_item	2490815	et	4	main
ma	doc_491521501779_item	2490816	et	3	main
vaimustan	doc_491521501779_item	2490817	et	3	main
erinevate	doc_491521501779_item	2490827	et	4	main
rektsiooniviga	doc_491521501779_item	2490833	et	4	main
tugevam	doc_491521501779_item	2490837	et	4	main
ruumid	doc_491521501779_item	2490846	et	4	main
ka	doc_491521501779_item	2490847	et	3	main
pidavad	doc_491521501779_item	2490852	et	4	main
pärast	doc_491521501779_item	2490860	et	4	main
kümne	doc_491521501779_item	2490861	et	4	main
tunned	doc_491521501779_item	2490862	et	3	main
tahtnud	doc_491521501779_item	2490872	et	4	main
isal	doc_491521501779_item	2490873	et	3	main
vead	doc_491521501779_item	2490909	et	4	main
sõna-sõnaline	doc_491521501779_item	2490912	et	4	main
keelest	doc_491521501779_item	2490915	et	4	main
aega	doc_491521501779_item	2490927	et	4	main
võtma	doc_491521501779_item	2490928	et	3	main
loovus	doc_491521501779_item	2490929	et	4	main
vale	doc_491521501779_item	2490935	et	4	main
sõnavalik	doc_491521501779_item	2490936	et	3	main
sõnaühendit	doc_491521501779_item	2490954	et	3	main
teises	doc_491521501779_item	2490957	et	4	main
siin	doc_491521501779_item	2490959	et	4	main
sobiks	doc_491521501779_item	2490960	et	4	main
vaatasin	doc_491521501779_item	2490961	et	3	main
sh	doc_491521501779_item	2490973	et	4	main
koos	doc_491521501779_item	2491013	et	4	main
see	doc_491521501779_item	2491018	et	3	main
film	doc_491521501779_item	2491020	et	3	main
ühildu	doc_491521501779_item	2491030	et	4	main
verbi	doc_491521501779_item	2491042	et	4	main
sõnaühendis	doc_491521501779_item	2491058	et	3	main
inglise	doc_491521501779_item	2491060	et	4	main
mõju	doc_491521501779_item	2491069	et	4	main
l0ja	doc_491521501779_item	2491077	et	4	main
tegemist	doc_491521501779_item	2491080	et	4	main
keeleklassidega	doc_491521501779_item	2491084	et	3	main
esineb	doc_491521501779_item	2491094	et	3	main
ja	doc_491521501779_item	2491096	et	3	main
sõnavalikuvigu	doc_491521501779_item	2491097	et	3	main
kontrastiivlingvistika	doc_491521501780_item	2491106	et	4	main
veaanalüüs	doc_491521501780_item	2491107	et	4	main
koormusega	doc_491521501780_item	2491116	et	3	main
sellest	doc_491521501780_item	2491125	et	4	main
vead	doc_491521501780_item	2491134	et	4	main
kutsekoolis	doc_491521501780_item	2491143	et	4	main
kus	doc_491521501780_item	2491144	et	3	main
osa	doc_491521501779_item	2490568	et	4	main
need	doc_491521501779_item	2490570	et	3	main
arvsõna	doc_491521501779_item	2490585	et	4	main
ainsus	doc_491521501779_item	2490587	et	4	main
on	doc_491521501779_item	2490589	et	4	main
läbi	doc_491521501779_item	2490597	et	4	main
aegade	doc_491521501779_item	2490598	et	3	main
kui	doc_491521501779_item	2490599	et	3	main
eksitud	doc_491521501779_item	2490612	et	4	main
ole	doc_491521501779_item	2490614	et	4	main
eitus	doc_491521501779_item	2490618	et	4	main
vaatate	doc_491521501779_item	2490625	et	3	main
film	doc_491521501779_item	2490626	et	3	main
ebaõige	doc_491521501779_item	2490633	et	4	main
ja	doc_491521501779_item	2490635	et	3	main
substantiivi	doc_491521501779_item	2490646	et	4	main
ma-	doc_491521501779_item	2490652	et	3	main
selles	doc_491521501779_item	2490670	et	4	main
on	doc_491521501779_item	2490678	et	4	main
paneksin	doc_491521501779_item	2490682	et	3	main
segamini	doc_491521501779_item	2490687	et	4	main
kohakäänete	doc_491521501779_item	2490688	et	3	main
küsimused	doc_491521501779_item	2490689	et	4	main
kuhu	doc_491521501779_item	2490690	et	3	main
ja	doc_491521501779_item	2490691	et	3	main
kus	doc_491521501779_item	2490692	et	3	main
muud	doc_491521501779_item	2490693	et	4	main
käändevead	doc_491521501779_item	2490694	et	4	main
mida	doc_491521501779_item	2490695	et	4	main
i	doc_491521501779_item	2490696	et	4	main
uhtus	doc_491521501779_item	2490697	et	4	main
edasi	doc_491521501779_item	2490698	et	3	main
hääldus-	doc_491521501779_item	2490699	et	4	main
ja	doc_491521501779_item	2490700	et	3	main
ortograafiavead	doc_491521501779_item	2490701	et	4	main
teatris	doc_491521501779_item	2490702	et	3	main
mängivad	doc_491521501779_item	2490703	et	4	main
inimeset	doc_491521501779_item	2490704	et	3	main
kui	doc_491521501779_item	2490705	et	3	main
sa	doc_491521501779_item	2490706	et	3	main
hakkad	doc_491521501779_item	2490707	et	3	main
kiiresti	doc_491521501779_item	2490708	et	3	main
kanaale	doc_491521501779_item	2490709	et	4	main
vahetama	doc_491521501779_item	2490710	et	3	main
otsene	doc_491521501779_item	2490711	et	3	main
vene	doc_491521501779_item	2490712	et	4	main
moju	doc_491521501779_item	2490713	et	4	main
austata	doc_491521501779_item	2490714	et	3	main
inimesi	doc_491521501779_item	2490715	et	4	main
kujutad	doc_491521501779_item	2490716	et	3	main
mõttetes	doc_491521501779_item	2490717	et	4	main
midagi	doc_491521501779_item	2490718	et	4	main
omapärast	doc_491521501779_item	2490719	et	4	main
viis	doc_491521501779_item	2490720	et	4	main
arvestama	doc_491521501779_item	2490731	et	3	main
asjatega	doc_491521501779_item	2490733	et	4	main
ka	doc_491521501779_item	2490734	et	3	main
on	doc_491521501779_item	2490738	et	4	main
otsustavad	doc_491521501779_item	2490743	et	4	main
s	doc_491521501779_item	2490746	et	4	main
õudsalt	doc_491521501779_item	2490749	et	4	main
ta	doc_491521501779_item	2490757	et	4	main
objektivead	doc_491521501779_item	2490767	et	4	main
eituse	doc_491521501779_item	2490772	et	4	main
häälduspärane	doc_491521501779_item	2490724	et	4	main
töötab	doc_491521501779_item	2490741	et	3	main
õbraid	doc_491521501779_item	2490747	et	4	main
minule	doc_491521501779_item	2490748	et	3	main
kõnekeele	doc_491521501779_item	2490751	et	4	main
üks	doc_491521501779_item	2490755	et	3	main
koguaeg	doc_491521501779_item	2490760	et	3	main
nii	doc_491521501779_item	2490765	et	3	main
lülitanud	doc_491521501779_item	2490769	et	4	main
valja	doc_491521501779_item	2490771	et	3	main
isa	doc_491521501779_item	2490776	et	4	main
eesti	doc_491521501779_item	2490782	et	4	main
keeles	doc_491521501779_item	2490783	et	4	main
kasutatakse	doc_491521501779_item	2490784	et	3	main
lõpetatud	doc_491521501779_item	2490785	et	4	main
vead	doc_491521501779_item	2490792	et	4	main
aga	doc_491521501779_item	2490793	et	3	main
väita	doc_491521501779_item	2490795	et	4	main
ma	doc_491521501779_item	2490798	et	3	main
ei	doc_491521501779_item	2490799	et	4	main
eita	doc_491521501779_item	2490800	et	4	main
aru	doc_491521501779_item	2490808	et	4	main
autori	doc_491521501779_item	2490810	et	3	main
kohtub	doc_491521501779_item	2490812	et	3	main
esimest	doc_491521501779_item	2490814	et	4	main
rohkem	doc_491521501779_item	2490820	et	4	main
käände	doc_491521501779_item	2490735	et	4	main
ühildumisviga	doc_491521501779_item	2490736	et	4	main
kuulsad	doc_491521501779_item	2490739	et	3	main
meeldis	doc_491521501779_item	2490750	et	3	main
kokku-lahku	doc_491521501779_item	2490753	et	4	main
kirjutamisvead	doc_491521501779_item	2490754	et	3	main
saab	doc_491521501779_item	2490758	et	3	main
maailma	doc_491521501779_item	2490762	et	4	main
last	doc_491521501779_item	2490781	et	4	main
vormi	doc_491521501779_item	2490789	et	4	main
selleks	doc_491521501779_item	2490806	et	4	main
oma	doc_491521501779_item	2490813	et	4	main
katjaga	doc_491521501779_item	2490818	et	4	main
aga	doc_491521501779_item	2490825	et	3	main
valikul	doc_491521501779_item	2490829	et	3	main
ka	doc_491521501779_item	2490832	et	3	main
olema	doc_491521501779_item	2490836	et	4	main
targem	doc_491521501779_item	2490839	et	4	main
vormimoodustusvead	doc_491521501779_item	2490840	et	4	main
andaksin	doc_491521501779_item	2490841	et	4	main
verbi	doc_491521501779_item	2490848	et	4	main
sõbrustavad	doc_491521501779_item	2490857	et	4	main
verbivormide	doc_491521501779_item	2490866	et	4	main
moodustusvead	doc_491521501779_item	2490867	et	4	main
kartsin	doc_491521501779_item	2490868	et	3	main
kasutus	doc_491521501779_item	2490901	et	4	main
ühes	doc_491521501779_item	2490902	et	4	main
on	doc_491521501779_item	2490917	et	4	main
vaheaeg	doc_491521501779_item	2490919	et	3	main
15	doc_491521501779_item	2490923	et	2	main
tingimused	doc_491521501779_item	2490932	et	3	main
midagi	doc_491521501779_item	2490933	et	4	main
võime	doc_491521501779_item	2490938	et	4	main
saada	doc_491521501779_item	2490942	et	4	main
hulluks	doc_491521501779_item	2490945	et	4	main
minema	doc_491521501779_item	2490946	et	3	main
filmi	doc_491521501779_item	2490949	et	4	main
kasutatakse	doc_491521501779_item	2490953	et	3	main
vaatama	doc_491521501779_item	2490956	et	3	main
tähenduses	doc_491521501779_item	2490958	et	4	main
võis	doc_491521501779_item	2490965	et	4	main
olla	doc_491521501779_item	2490966	et	3	main
nii	doc_491521501779_item	2490967	et	3	main
tugev	doc_491521501779_item	2490968	et	4	main
isik	doc_491521501779_item	2490969	et	3	main
sõnamoodustusvead	doc_491521501779_item	2490974	et	4	main
neljajalguline	doc_491521501779_item	2490975	et	4	main
sõber	doc_491521501779_item	2490976	et	3	main
aega	doc_491521501779_item	2491015	et	4	main
on	doc_491521501779_item	2491017	et	4	main
kasutatakse	doc_491521501779_item	2490774	et	3	main
ostis	doc_491521501779_item	2490777	et	4	main
puhul	doc_491521501779_item	2490787	et	4	main
valiku	doc_491521501779_item	2490791	et	3	main
ei	doc_491521501779_item	2490794	et	4	main
et	doc_491521501779_item	2490796	et	3	main
aga	doc_491521501779_item	2490797	et	3	main
saada	doc_491521501779_item	2490809	et	4	main
mõtteist	doc_491521501779_item	2490811	et	3	main
mitte-eestlased	doc_491521501779_item	2490821	et	3	main
sarnaste	doc_491521501779_item	2490824	et	4	main
tähenduselt	doc_491521501779_item	2490826	et	4	main
siin	doc_491521501779_item	2490830	et	4	main
hakkas	doc_491521501779_item	2490835	et	3	main
ja	doc_491521501779_item	2490838	et	3	main
ühildumisviga	doc_491521501779_item	2490849	et	4	main
pühendatud	doc_491521501779_item	2490864	et	4	main
väga	doc_491521501779_item	2490871	et	3	main
ei	doc_491521501779_item	2490874	et	4	main
vene	doc_491521501779_item	2490914	et	4	main
antrakt	doc_491521501779_item	2490918	et	3	main
eksivad	doc_491521501779_item	2490822	et	4	main
sõnade	doc_491521501779_item	2490828	et	3	main
on	doc_491521501779_item	2490831	et	4	main
laenu	doc_491521501779_item	2490842	et	4	main
tahaksin	doc_491521501779_item	2490843	et	3	main
ise	doc_491521501779_item	2490844	et	4	main
köetma	doc_491521501779_item	2490845	et	4	main
oleks	doc_491521501779_item	2490856	et	3	main
tunded	doc_491521501779_item	2490865	et	3	main
aga	doc_491521501779_item	2490870	et	3	main
olnud	doc_491521501779_item	2490875	et	4	main
aega	doc_491521501779_item	2490876	et	4	main
ja	doc_491521501779_item	2490877	et	3	main
ta	doc_491521501779_item	2490878	et	4	main
lubas	doc_491521501779_item	2490879	et	3	main
seda	doc_491521501779_item	2490880	et	3	main
teha	doc_491521501779_item	2490881	et	3	main
kui	doc_491521501779_item	2490882	et	3	main
ta	doc_491521501779_item	2490883	et	4	main
tuli	doc_491521501779_item	2490884	et	4	main
töölt	doc_491521501779_item	2490885	et	3	main
tagasi	doc_491521501779_item	2490886	et	3	main
kui	doc_491521501779_item	2490887	et	3	main
ta	doc_491521501779_item	2490888	et	4	main
tuleb	doc_491521501779_item	2490889	et	3	main
töölt	doc_491521501779_item	2490890	et	3	main
tagasi	doc_491521501779_item	2490891	et	3	main
eesti	doc_491521501779_item	2490892	et	4	main
keeles	doc_491521501779_item	2490893	et	4	main
tekitab	doc_491521501779_item	2490894	et	3	main
segadust	doc_491521501779_item	2490895	et	4	main
mineviku	doc_491521501779_item	2490896	et	3	main
ja	doc_491521501779_item	2490897	et	3	main
oleviku	doc_491521501779_item	2490898	et	3	main
vormi	doc_491521501779_item	2490899	et	4	main
paralleelne	doc_491521501779_item	2490900	et	3	main
lauses	doc_491521501779_item	2490903	et	3	main
kui	doc_491521501779_item	2490904	et	3	main
on	doc_491521501779_item	2490905	et	4	main
mängus	doc_491521501779_item	2490906	et	3	main
tulevikuaspekt	doc_491521501779_item	2490907	et	3	main
sõnatasandi	doc_491521501779_item	2490908	et	3	main
saade	doc_491521501779_item	2490911	et	4	main
tõlkelaen	doc_491521501779_item	2490913	et	3	main
see	doc_491521501779_item	2490921	et	3	main
inimese	doc_491521501779_item	2490931	et	4	main
oskus	doc_491521501779_item	2490937	et	3	main
viga	doc_491521501779_item	2490944	et	4	main
vaatasin	doc_491521501779_item	2490948	et	3	main
keeles	doc_491521501779_item	2490952	et	4	main
filmi	doc_491521501779_item	2490962	et	4	main
hästi	doc_491521501779_item	2490980	et	3	main
muud	doc_491521501779_item	2491021	et	4	main
tee	doc_491521501779_item	2491027	et	4	main
ühes	doc_491521501779_item	2491031	et	4	main
teises	doc_491521501779_item	2491034	et	4	main
kasutata	doc_491521501779_item	2491037	et	3	main
esimese	doc_491521501779_item	2491038	et	3	main
isiku	doc_491521501779_item	2491039	et	3	main
pöördelõppu	doc_491521501779_item	2491040	et	4	main
arvestatud	doc_491521501779_item	2491048	et	4	main
käändeviga	doc_491521501779_item	2491051	et	4	main
kasutatud	doc_491521501779_item	2491052	et	4	main
keelest	doc_491521501779_item	2491061	et	4	main
on	doc_491521501779_item	2491064	et	4	main
anglitsisme	doc_491521501779_item	2491066	et	3	main
materjal	doc_491521501779_item	2491071	et	3	main
praktikatundidest	doc_491521501779_item	2491074	et	3	main
on	doc_491521501779_item	2491081	et	4	main
õpilased	doc_491521501779_item	2491085	et	3	main
on	doc_491521501779_item	2491086	et	4	main
huvidega	doc_491521501779_item	2491088	et	3	main
tunnis	doc_491521501779_item	2491090	et	3	main
aktiivselt	doc_491521501779_item	2491091	et	4	main
analüüs	doc_491521501780_item	2491098	et	3	main
võõrkeele	doc_491521501780_item	2491104	et	4	main
tallinn	doc_491521501780_item	2491108	et	4	main
väikese	doc_491521501780_item	2491115	et	4	main
veaanalüüsiks	doc_491521501780_item	2491122	et	4	main
olengi	doc_491521501780_item	2491123	et	4	main
saanud	doc_491521501780_item	2491124	et	4	main
vaid	doc_491521501780_item	2491130	et	3	main
kirjalikes	doc_491521501780_item	2491131	et	3	main
töödes	doc_491521501780_item	2491132	et	3	main
tehtud	doc_491521501780_item	2491133	et	4	main
terve	doc_491521501780_item	2491153	et	4	main
õppima	doc_491521501780_item	2491158	et	3	main
seega	doc_491521501780_item	2491166	et	4	main
õpilastele	doc_491521501780_item	2491178	et	4	main
vead	doc_491521501780_item	2491216	et	4	main
siin	doc_491521501780_item	2491220	et	4	main
vigu	doc_491521501780_item	2491230	et	3	main
vene	doc_491521501780_item	2491232	et	4	main
keeles	doc_491521501780_item	2491233	et	4	main
siis	doc_491521501780_item	2491238	et	3	main
nad	doc_491521501780_item	2491239	et	3	main
tajuma	doc_491521501780_item	2491247	et	3	main
on	doc_491521501780_item	2491249	et	4	main
keeles	doc_491521501780_item	2491251	et	4	main
tegemist	doc_491521501780_item	2491252	et	4	main
hulgas	doc_491521501780_item	2491257	et	4	main
mida	doc_491521501780_item	2491261	et	4	main
juhul	doc_491521501780_item	2491274	et	3	main
saja	doc_491521501780_item	2491303	et	4	main
sai	doc_491521501780_item	2491307	et	4	main
müüja	doc_491521501780_item	2491312	et	4	main
sõita	doc_491521501780_item	2491315	et	3	main
remontib	doc_491521501780_item	2491317	et	4	main
õppilane	doc_491521501780_item	2491318	et	4	main
akken	doc_491521501780_item	2491319	et	4	main
lemik	doc_491521501780_item	2491324	et	4	main
keelt	doc_491521501780_item	2491336	et	4	main
antud	doc_491521501780_item	2491338	et	4	main
juhul	doc_491521501780_item	2491339	et	3	main
kuid	doc_491521501780_item	2491357	et	4	main
jäta	doc_491521501780_item	2491367	et	4	main
nad	doc_491521501780_item	2491368	et	3	main
teatris	doc_491521501779_item	2490916	et	3	main
tõlkelaen	doc_491521501779_item	2490920	et	3	main
tundi	doc_491521501779_item	2490924	et	4	main
sõnaühendi	doc_491521501779_item	2490925	et	3	main
luua	doc_491521501779_item	2490934	et	4	main
et	doc_491521501779_item	2490939	et	3	main
kui	doc_491521501779_item	2490947	et	3	main
läbi	doc_491521501779_item	2490950	et	4	main
läbi	doc_491521501779_item	2490955	et	4	main
ära	doc_491521501779_item	2490963	et	4	main
kuidas	doc_491521501779_item	2490964	et	3	main
viga	doc_491521501779_item	2490971	et	4	main
kumbkil	doc_491521501779_item	2490977	et	4	main
läheks	doc_491521501779_item	2490979	et	3	main
tõepoolest	doc_491521501779_item	2491016	et	3	main
fantastiline	doc_491521501779_item	2491019	et	4	main
vaatan	doc_491521501779_item	2491023	et	3	main
televiisorit	doc_491521501779_item	2491024	et	3	main
jõi	doc_491521501779_item	2491026	et	3	main
ei	doc_491521501779_item	2491029	et	4	main
ühildumisviga	doc_491521501779_item	2491043	et	4	main
jooma	doc_491521501779_item	2491044	et	4	main
lisaks	doc_491521501779_item	2491067	et	4	main
vene	doc_491521501779_item	2491068	et	4	main
on	doc_491521501779_item	2491072	et	4	main
kooli	doc_491521501779_item	2491082	et	4	main
tugevate	doc_491521501779_item	2491083	et	4	main
suhtlevad	doc_491521501779_item	2491089	et	4	main
pedagoogikaülikool	doc_491521501780_item	2491100	et	4	main
eesti	doc_491521501780_item	2491101	et	4	main
keele	doc_491521501780_item	2491102	et	4	main
kui	doc_491521501780_item	2491103	et	3	main
hetkel	doc_491521501780_item	2491112	et	4	main
keele	doc_491521501780_item	2491118	et	4	main
materjali	doc_491521501780_item	2491121	et	4	main
välja	doc_491521501780_item	2491128	et	4	main
toonud	doc_491521501780_item	2491129	et	4	main
ülesmärkimiseks	doc_491521501780_item	2491139	et	3	main
vaid	doc_491521501780_item	2491156	et	3	main
on	doc_491521501780_item	2491159	et	4	main
tallinna	doc_491521501780_item	2491163	et	4	main
vaga	doc_491521501780_item	2491171	et	4	main
madala	doc_491521501780_item	2491183	et	3	main
õigekirja	doc_491521501780_item	2491215	et	4	main
konsonantühendi	doc_491521501780_item	2491229	et	4	main
kahekordselt	doc_491521501780_item	2491237	et	4	main
teadma	doc_491521501780_item	2491242	et	3	main
hiljem	doc_491521501780_item	2491244	et	3	main
ka	doc_491521501780_item	2491246	et	3	main
kus	doc_491521501780_item	2491248	et	3	main
eesti	doc_491521501780_item	2491250	et	4	main
parema	doc_491521501780_item	2491262	et	4	main
keele	doc_491521501780_item	2491263	et	4	main
oskusega	doc_491521501780_item	2491264	et	3	main
antud	doc_491521501780_item	2491273	et	4	main
saija	doc_491521501780_item	2491302	et	4	main
sõna	doc_491521501780_item	2491306	et	4	main
pastaplijats	doc_491521501780_item	2491310	et	4	main
ei	doc_491521501780_item	2491314	et	4	main
poliklinika	doc_491521501780_item	2491332	et	4	main
inglis	doc_491521501780_item	2491335	et	3	main
astmevaheldus	doc_491521501780_item	2491337	et	4	main
ei	doc_491521501780_item	2491340	et	4	main
rääkinud	doc_491521501780_item	2491356	et	4	main
ei	doc_491521501780_item	2491360	et	4	main
eesti	doc_491521501780_item	2491362	et	4	main
õppimine	doc_491521501780_item	2491364	et	4	main
ei	doc_491521501780_item	2491366	et	4	main
tegusõna	doc_491521501780_item	2491374	et	4	main
nt	doc_491521501780_item	2491375	et	4	main
lisanud	doc_491521501780_item	2491387	et	4	main
õpisin	doc_491521501780_item	2491395	et	4	main
raskusi	doc_491521501780_item	2491422	et	4	main
kasutamine	doc_491521501780_item	2491425	et	4	main
asemel	doc_491521501780_item	2491431	et	4	main
nimetavat	doc_491521501780_item	2491432	et	4	main
käänet	doc_491521501780_item	2491433	et	3	main
sa	doc_491521501780_item	2491446	et	3	main
sõbrad	doc_491521501780_item	2491455	et	3	main
inimesed	doc_491521501780_item	2491467	et	3	main
õpetab	doc_491521501780_item	2491469	et	3	main
võtab	doc_491521501779_item	2490922	et	3	main
viga	doc_491521501779_item	2490926	et	4	main
on	doc_491521501779_item	2490930	et	4	main
mitte	doc_491521501779_item	2490940	et	3	main
hulluks	doc_491521501779_item	2490941	et	4	main
sõnaühendi	doc_491521501779_item	2490943	et	3	main
eesti	doc_491521501779_item	2490951	et	4	main
sõnavaliku	doc_491521501779_item	2490970	et	3	main
isiksus	doc_491521501779_item	2490972	et	3	main
neist	doc_491521501779_item	2490978	et	4	main
kummagil	doc_491521501779_item	2490981	et	4	main
või	doc_491521501779_item	2490982	et	4	main
mõlemal	doc_491521501779_item	2490983	et	3	main
pronoomenivead	doc_491521501779_item	2490984	et	4	main
see	doc_491521501779_item	2490985	et	3	main
film	doc_491521501779_item	2490986	et	3	main
on	doc_491521501779_item	2490987	et	4	main
eluline	doc_491521501779_item	2490988	et	4	main
lugu	doc_491521501779_item	2490989	et	4	main
ta	doc_491521501779_item	2490990	et	4	main
tabas	doc_491521501779_item	2490991	et	4	main
mind	doc_491521501779_item	2490992	et	4	main
väga	doc_491521501779_item	2490993	et	3	main
kasutatud	doc_491521501779_item	2490994	et	4	main
asesõna	doc_491521501779_item	2490995	et	4	main
ta	doc_491521501779_item	2490996	et	4	main
elutu	doc_491521501779_item	2490997	et	4	main
nähtuse	doc_491521501779_item	2490998	et	4	main
kohta	doc_491521501779_item	2490999	et	4	main
ta	doc_491521501779_item	2491000	et	4	main
saa	doc_491521501779_item	2491002	et	4	main
ei	doc_491521501779_item	2491001	et	4	main
andestada	doc_491521501779_item	2491003	et	3	main
tema	doc_491521501779_item	2491004	et	4	main
petmist-	doc_491521501779_item	2491005	et	4	main
pole	doc_491521501779_item	2491006	et	3	main
kasutatud	doc_491521501779_item	2491007	et	4	main
enesekohast	doc_491521501779_item	2491008	et	4	main
pronoomenit	doc_491521501779_item	2491009	et	3	main
enda	doc_491521501779_item	2491010	et	4	main
sõnajärjevead	doc_491521501779_item	2491011	et	3	main
alati	doc_491521501779_item	2491012	et	4	main
veedavad	doc_491521501779_item	2491014	et	3	main
lauses	doc_491521501779_item	2491032	et	3	main
osas	doc_491521501779_item	2491035	et	4	main
ei	doc_491521501779_item	2491036	et	4	main
on	doc_491521501779_item	2491047	et	4	main
inimestele	doc_491521501779_item	2491050	et	3	main
mitte-eestlaste	doc_491521501779_item	2491062	et	4	main
l	doc_491521501779_item	2491078	et	4	main
lklassist	doc_491521501779_item	2491079	et	4	main
kirjalikes	doc_491521501779_item	2491092	et	3	main
tallinna	doc_491521501780_item	2491099	et	4	main
2001	doc_491521501780_item	2491109	et	2	main
sissejuhatus	doc_491521501780_item	2491110	et	4	main
töötan	doc_491521501780_item	2491111	et	3	main
kutsekoolis	doc_491521501780_item	2491114	et	4	main
eesti	doc_491521501780_item	2491117	et	4	main
õpetajana	doc_491521501780_item	2491119	et	4	main
oma	doc_491521501780_item	2491120	et	4	main
vead	doc_491521501779_item	2491022	et	4	main
ja	doc_491521501779_item	2491025	et	3	main
ajad	doc_491521501779_item	2491028	et	4	main
lause	doc_491521501779_item	2491033	et	4	main
lisaks	doc_491521501779_item	2491041	et	4	main
mida	doc_491521501779_item	2491045	et	4	main
kunstid	doc_491521501779_item	2491046	et	3	main
kreativsele	doc_491521501779_item	2491049	et	4	main
ainsust	doc_491521501779_item	2491053	et	4	main
ja	doc_491521501779_item	2491054	et	3	main
mitmust	doc_491521501779_item	2491055	et	3	main
koos	doc_491521501779_item	2491056	et	4	main
ühes	doc_491521501779_item	2491057	et	4	main
tõlkelaen	doc_491521501779_item	2491059	et	3	main
kõnepruugis	doc_491521501779_item	2491063	et	3	main
palju	doc_491521501779_item	2491065	et	4	main
arvestatud-mõeldud	doc_491521501779_item	2491070	et	4	main
kogutud	doc_491521501779_item	2491073	et	4	main
vene	doc_491521501779_item	2491075	et	4	main
gümnaasiumi	doc_491521501779_item	2491076	et	4	main
laialdaste	doc_491521501779_item	2491087	et	3	main
töödes	doc_491521501779_item	2491093	et	3	main
grammatika-	doc_491521501779_item	2491095	et	4	main
õppetool	doc_491521501780_item	2491105	et	3	main
venekeelses	doc_491521501780_item	2491113	et	3	main
koolist	doc_491521501780_item	2491126	et	4	main
olen	doc_491521501780_item	2491127	et	3	main
tehtud	doc_491521501780_item	2491137	et	4	main
vigade	doc_491521501780_item	2491138	et	3	main
pole	doc_491521501780_item	2491140	et	3	main
jätkunud	doc_491521501780_item	2491141	et	4	main
aega	doc_491521501780_item	2491142	et	4	main
kooli	doc_491521501780_item	2491154	et	4	main
tuldud	doc_491521501780_item	2491160	et	4	main
erinev	doc_491521501780_item	2491172	et	4	main
mina	doc_491521501780_item	2491173	et	4	main
annan	doc_491521501780_item	2491174	et	3	main
rohkem	doc_491521501780_item	2491218	et	4	main
kuna	doc_491521501780_item	2491135	et	3	main
suuliselt	doc_491521501780_item	2491136	et	4	main
on	doc_491521501780_item	2491147	et	4	main
valdav	doc_491521501780_item	2491148	et	4	main
enamus	doc_491521501780_item	2491149	et	4	main
noormehed	doc_491521501780_item	2491150	et	3	main
tütarlapsi	doc_491521501780_item	2491151	et	4	main
põhikooli	doc_491521501780_item	2491162	et	4	main
erinevatest	doc_491521501780_item	2491164	et	4	main
koolidest	doc_491521501780_item	2491165	et	3	main
on	doc_491521501780_item	2491167	et	4	main
ka	doc_491521501780_item	2491168	et	3	main
tunde	doc_491521501780_item	2491175	et	4	main
esimese	doc_491521501780_item	2491176	et	3	main
ühes	doc_491521501780_item	2491179	et	4	main
kesktasemega	doc_491521501780_item	2491184	et	3	main
ja	doc_491521501780_item	2491185	et	3	main
neidki	doc_491521501780_item	2491186	et	4	main
kes	doc_491521501780_item	2491187	et	4	main
ei	doc_491521501780_item	2491188	et	4	main
suuda	doc_491521501780_item	2491189	et	4	main
lihtlauseid	doc_491521501780_item	2491190	et	3	main
moodustada	doc_491521501780_item	2491191	et	3	main
samas	doc_491521501780_item	2491192	et	4	main
on	doc_491521501780_item	2491193	et	4	main
üks	doc_491521501780_item	2491194	et	3	main
poiss	doc_491521501780_item	2491195	et	3	main
kes	doc_491521501780_item	2491196	et	4	main
valdab	doc_491521501780_item	2491197	et	3	main
keelt	doc_491521501780_item	2491198	et	4	main
väga	doc_491521501780_item	2491199	et	3	main
hästi	doc_491521501780_item	2491200	et	3	main
seega	doc_491521501780_item	2491201	et	4	main
on	doc_491521501780_item	2491202	et	4	main
klassi	doc_491521501780_item	2491203	et	4	main
tase	doc_491521501780_item	2491204	et	3	main
tõesti	doc_491521501780_item	2491205	et	3	main
väga	doc_491521501780_item	2491206	et	3	main
erinev	doc_491521501780_item	2491207	et	4	main
kuid	doc_491521501780_item	2491208	et	4	main
enamus	doc_491521501780_item	2491209	et	4	main
õpilasi	doc_491521501780_item	2491210	et	3	main
valdab	doc_491521501780_item	2491211	et	3	main
eesti	doc_491521501780_item	2491212	et	4	main
keelt	doc_491521501780_item	2491213	et	4	main
ma	doc_491521501780_item	2491145	et	3	main
töötan	doc_491521501780_item	2491146	et	3	main
on	doc_491521501780_item	2491152	et	4	main
peale	doc_491521501780_item	2491155	et	4	main
viis-kuus	doc_491521501780_item	2491157	et	4	main
peale	doc_491521501780_item	2491161	et	4	main
õpilaste	doc_491521501780_item	2491169	et	4	main
tase	doc_491521501780_item	2491170	et	3	main
kursuse	doc_491521501780_item	2491177	et	3	main
rühmas	doc_491521501780_item	2491180	et	4	main
on	doc_491521501780_item	2491181	et	4	main
poisse	doc_491521501780_item	2491182	et	4	main
on	doc_491521501780_item	2491219	et	4	main
eksitud	doc_491521501780_item	2491221	et	4	main
ja	doc_491521501780_item	2491223	et	3	main
lihtsalt	doc_491521501780_item	2491241	et	4	main
juba	doc_491521501780_item	2491245	et	3	main
on	doc_491521501780_item	2491258	et	4	main
vigu	doc_491521501780_item	2491260	et	3	main
juba	doc_491521501780_item	2491266	et	3	main
nt	doc_491521501780_item	2491268	et	4	main
meeldima	doc_491521501780_item	2491271	et	3	main
on	doc_491521501780_item	2491304	et	4	main
osast	doc_491521501780_item	2491308	et	4	main
müja	doc_491521501780_item	2491311	et	4	main
hammbad	doc_491521501780_item	2491313	et	4	main
mehannika	doc_491521501780_item	2491320	et	4	main
mehaanika	doc_491521501780_item	2491321	et	4	main
aprilis	doc_491521501780_item	2491323	et	4	main
mõeldud	doc_491521501780_item	2491326	et	4	main
on	doc_491521501780_item	2491327	et	4	main
trennis	doc_491521501780_item	2491328	et	3	main
sinnililled	doc_491521501780_item	2491329	et	4	main
praigu	doc_491521501780_item	2491331	et	4	main
lihtsalt	doc_491521501780_item	2491343	et	4	main
suutnud	doc_491521501780_item	2491344	et	4	main
ära	doc_491521501780_item	2491345	et	4	main
õppida	doc_491521501780_item	2491346	et	3	main
kuidas	doc_491521501780_item	2491347	et	3	main
antud	doc_491521501780_item	2491348	et	4	main
tegusõnad	doc_491521501780_item	2491349	et	3	main
palju	doc_491521501780_item	2491354	et	4	main
minu	doc_491521501780_item	2491358	et	3	main
huvita	doc_491521501780_item	2491361	et	4	main
seega	doc_491521501780_item	2491365	et	4	main
olev	doc_491521501780_item	2491373	et	4	main
on	doc_491521501780_item	2491385	et	4	main
osastava	doc_491521501780_item	2491423	et	4	main
käände	doc_491521501780_item	2491424	et	4	main
osastava	doc_491521501780_item	2491430	et	4	main
on	doc_491521501780_item	2491436	et	4	main
fotod	doc_491521501780_item	2491440	et	3	main
majad	doc_491521501780_item	2491444	et	3	main
palju	doc_491521501780_item	2491454	et	4	main
armastan	doc_491521501780_item	2491456	et	3	main
arst	doc_491521501780_item	2491465	et	3	main
õpetaja	doc_491521501780_item	2491468	et	4	main
lihtsamates	doc_491521501780_item	2491483	et	4	main
nt	doc_491521501780_item	2491487	et	4	main
algtasemel	doc_491521501780_item	2491214	et	3	main
kõige	doc_491521501780_item	2491217	et	4	main
pika	doc_491521501780_item	2491222	et	4	main
lühikese	doc_491521501780_item	2491224	et	4	main
hääliku	doc_491521501780_item	2491225	et	3	main
ei	doc_491521501780_item	2491234	et	4	main
kirjutata	doc_491521501780_item	2491235	et	3	main
ja	doc_491521501780_item	2491243	et	3	main
häälikuga	doc_491521501780_item	2491254	et	3	main
vigade	doc_491521501780_item	2491256	et	3	main
palju	doc_491521501780_item	2491259	et	4	main
väldivad	doc_491521501780_item	2491267	et	3	main
raamat	doc_491521501780_item	2491270	et	3	main
kasutatakse	doc_491521501780_item	2491275	et	3	main
mõeldud	doc_491521501780_item	2491305	et	4	main
käänet	doc_491521501780_item	2491309	et	3	main
sõbradega	doc_491521501780_item	2491316	et	4	main
treenis	doc_491521501780_item	2491325	et	3	main
ekskursiole	doc_491521501780_item	2491333	et	4	main
ole	doc_491521501780_item	2491341	et	4	main
õpilased	doc_491521501780_item	2491342	et	3	main
tunnis	doc_491521501780_item	2491355	et	3	main
õpilasi	doc_491521501780_item	2491359	et	3	main
keele	doc_491521501780_item	2491363	et	4	main
pööramisel	doc_491521501780_item	2491378	et	4	main
minevikus	doc_491521501780_item	2491383	et	3	main
algvormile	doc_491521501780_item	2491386	et	3	main
pöördelõpu	doc_491521501780_item	2491388	et	3	main
õppib	doc_491521501780_item	2491397	et	4	main
ei	doc_491521501780_item	2491399	et	4	main
tunta	doc_491521501780_item	2491400	et	3	main
valmistab	doc_491521501780_item	2491421	et	3	main
autod	doc_491521501780_item	2491435	et	3	main
tegema	doc_491521501780_item	2491441	et	3	main
aitad	doc_491521501780_item	2491447	et	3	main
oma	doc_491521501780_item	2491457	et	4	main
perekond	doc_491521501780_item	2491458	et	3	main
mulle	doc_491521501780_item	2491460	et	4	main
vaadata	doc_491521501780_item	2491464	et	4	main
vead	doc_491521501780_item	2491472	et	4	main
eksitakse	doc_491521501780_item	2491481	et	4	main
elan	doc_491521501780_item	2491488	et	3	main
palju	doc_491521501780_item	2491490	et	4	main
selles	doc_491521501780_item	2491493	et	4	main
tundidel	doc_491521501780_item	2491526	et	3	main
massiliselt	doc_491521501780_item	2491538	et	4	main
keele	doc_491521501780_item	2491548	et	4	main
eesti	doc_491521501780_item	2491553	et	4	main
võib-olla	doc_491521501780_item	2491558	et	3	main
lause	doc_491521501780_item	2491561	et	4	main
научи	doc_491521501780_item	2491564	et	2	main
klaasist	doc_491521501780_item	2491575	et	4	main
sina	doc_491521501780_item	2491579	et	4	main
mind	doc_491521501780_item	2491582	et	4	main
eesti	doc_491521501780_item	2491583	et	4	main
uuele	doc_491521501780_item	2491590	et	3	main
sõber	doc_491521501780_item	2491592	et	3	main
majani	doc_491521501780_item	2491596	et	3	main
palju	doc_491521501780_item	2491604	et	4	main
on	doc_491521501780_item	2491608	et	4	main
viga	doc_491521501780_item	2491610	et	4	main
on	doc_491521501780_item	2491611	et	4	main
ka	doc_491521501780_item	2491612	et	3	main
sõnade	doc_491521501780_item	2491613	et	3	main
järjekorras	doc_491521501780_item	2491614	et	3	main
see	doc_491521501780_item	2491615	et	3	main
on	doc_491521501780_item	2491616	et	4	main
kirjutamisel	doc_491521501780_item	2491226	et	4	main
esineb	doc_491521501780_item	2491227	et	3	main
ka	doc_491521501780_item	2491228	et	3	main
kuna	doc_491521501780_item	2491231	et	3	main
häälikuid	doc_491521501780_item	2491236	et	3	main
peavad	doc_491521501780_item	2491240	et	4	main
pika	doc_491521501780_item	2491253	et	4	main
alljärgnevate	doc_491521501780_item	2491255	et	3	main
õppijad	doc_491521501780_item	2491265	et	4	main
rääkima	doc_491521501780_item	2491269	et	3	main
jne	doc_491521501780_item	2491272	et	4	main
eestikeelseid	doc_491521501780_item	2491276	et	3	main
sõnu	doc_491521501780_item	2491277	et	4	main
vähem	doc_491521501780_item	2491278	et	4	main
seega	doc_491521501780_item	2491279	et	4	main
pole	doc_491521501780_item	2491280	et	3	main
selgeks	doc_491521501780_item	2491281	et	3	main
saanud	doc_491521501780_item	2491282	et	4	main
ka	doc_491521501780_item	2491283	et	3	main
õigekiri	doc_491521501780_item	2491284	et	3	main
spetsialne	doc_491521501780_item	2491285	et	4	main
suret	doc_491521501780_item	2491286	et	4	main
suured	doc_491521501780_item	2491287	et	3	main
ramatu	doc_491521501780_item	2491288	et	4	main
rägib	doc_491521501780_item	2491289	et	4	main
kevitaja	doc_491521501780_item	2491290	et	4	main
automaler	doc_491521501780_item	2491291	et	4	main
automaaler	doc_491521501780_item	2491292	et	3	main
gimnasium	doc_491521501780_item	2491293	et	4	main
gümnaasium	doc_491521501780_item	2491294	et	3	main
juksed	doc_491521501780_item	2491295	et	4	main
meldib	doc_491521501780_item	2491296	et	4	main
venemal	doc_491521501780_item	2491297	et	4	main
saksamal	doc_491521501780_item	2491298	et	4	main
vadata	doc_491521501780_item	2491299	et	4	main
saarema	doc_491521501780_item	2491300	et	4	main
arbus	doc_491521501780_item	2491301	et	4	main
perekonanimi	doc_491521501780_item	2491322	et	4	main
taivas	doc_491521501780_item	2491330	et	4	main
õpitaja	doc_491521501780_item	2491334	et	4	main
muutuvad	doc_491521501780_item	2491350	et	4	main
oleme	doc_491521501780_item	2491351	et	3	main
nendest	doc_491521501780_item	2491352	et	4	main
tegusõnadest	doc_491521501780_item	2491353	et	3	main
endale	doc_491521501780_item	2491369	et	4	main
meelde	doc_491521501780_item	2491370	et	3	main
kuidas	doc_491521501780_item	2491371	et	3	main
algvormis	doc_491521501780_item	2491372	et	3	main
muutub	doc_491521501780_item	2491377	et	3	main
olvikus	doc_491521501780_item	2491379	et	4	main
kuidas	doc_491521501780_item	2491381	et	3	main
õpilane	doc_491521501780_item	2491384	et	3	main
teged	doc_491521501780_item	2491390	et	4	main
lugen	doc_491521501780_item	2491392	et	4	main
enne	doc_491521501780_item	2491394	et	4	main
ta	doc_491521501780_item	2491396	et	4	main
kolme	doc_491521501780_item	2491401	et	4	main
esimest	doc_491521501780_item	2491402	et	4	main
käänet	doc_491521501780_item	2491403	et	3	main
neist	doc_491521501780_item	2491404	et	4	main
sõnadest	doc_491521501780_item	2491405	et	3	main
rattas	doc_491521501780_item	2491406	et	3	main
objektivead	doc_491521501780_item	2491407	et	4	main
mulle	doc_491521501780_item	2491408	et	4	main
tundub	doc_491521501780_item	2491409	et	3	main
et	doc_491521501780_item	2491410	et	3	main
minu	doc_491521501780_item	2491411	et	3	main
õpilased	doc_491521501780_item	2491412	et	3	main
pole	doc_491521501780_item	2491413	et	3	main
sihitisest	doc_491521501780_item	2491414	et	4	main
kui	doc_491521501780_item	2491415	et	3	main
sellisest	doc_491521501780_item	2491416	et	4	main
midagi	doc_491521501780_item	2491417	et	4	main
kuulnud	doc_491521501780_item	2491418	et	4	main
paljudele	doc_491521501780_item	2491419	et	3	main
muulastele	doc_491521501780_item	2491420	et	4	main
kõige	doc_491521501780_item	2491426	et	4	main
enam	doc_491521501780_item	2491427	et	4	main
kasutataksegi	doc_491521501780_item	2491428	et	3	main
siin	doc_491521501780_item	2491429	et	4	main
palju	doc_491521501780_item	2491437	et	4	main
kurjategejad	doc_491521501780_item	2491438	et	4	main
ehitavad	doc_491521501780_item	2491442	et	4	main
mulle	doc_491521501780_item	2491448	et	4	main
kuulata	doc_491521501780_item	2491450	et	4	main
väga	doc_491521501780_item	2491459	et	3	main
meeldib	doc_491521501780_item	2491461	et	3	main
hea	doc_491521501780_item	2491462	et	4	main
filmi	doc_491521501780_item	2491463	et	4	main
lühikese	doc_491521501780_item	2491477	et	4	main
kasutades	doc_491521501780_item	2491486	et	3	main
kus	doc_491521501780_item	2491489	et	3	main
võtsime	doc_491521501780_item	2491527	et	3	main
tegime	doc_491521501780_item	2491532	et	3	main
kasutamisel	doc_491521501780_item	2491540	et	4	main
mõjul	doc_491521501780_item	2491549	et	4	main
õpilane	doc_491521501780_item	2491556	et	3	main
õpeta	doc_491521501780_item	2491581	et	4	main
tegema	doc_491521501780_item	2491376	et	3	main
ja	doc_491521501780_item	2491380	et	3	main
pööratakse	doc_491521501780_item	2491382	et	3	main
sa	doc_491521501780_item	2491389	et	3	main
ma	doc_491521501780_item	2491391	et	3	main
näged	doc_491521501780_item	2491393	et	4	main
sokkid	doc_491521501780_item	2491398	et	4	main
peatab	doc_491521501780_item	2491434	et	3	main
sõidan	doc_491521501780_item	2491439	et	3	main
uued	doc_491521501780_item	2491443	et	3	main
kas	doc_491521501780_item	2491445	et	3	main
meeldib	doc_491521501780_item	2491449	et	3	main
muusika	doc_491521501780_item	2491451	et	4	main
mul	doc_491521501780_item	2491452	et	3	main
on	doc_491521501780_item	2491453	et	4	main
ravib	doc_491521501780_item	2491466	et	3	main
lapsed	doc_491521501780_item	2491470	et	3	main
sisseütleva	doc_491521501780_item	2491478	et	3	main
kasutamisega	doc_491521501780_item	2491479	et	4	main
samas	doc_491521501780_item	2491480	et	4	main
küsimustes	doc_491521501780_item	2491484	et	4	main
eksitakse	doc_491521501780_item	2491491	et	4	main
osas	doc_491521501780_item	2491494	et	4	main
millal	doc_491521501780_item	2491495	et	3	main
kasutada	doc_491521501780_item	2491496	et	3	main
väliskohakäändeid	doc_491521501780_item	2491497	et	3	main
millal	doc_491521501780_item	2491498	et	3	main
sisekohakäändeid	doc_491521501780_item	2491499	et	3	main
lilleosakonnasse	doc_491521501780_item	2491500	et	4	main
külma	doc_491521501780_item	2491501	et	4	main
veesse	doc_491521501780_item	2491502	et	3	main
toasse	doc_491521501780_item	2491503	et	3	main
uue	doc_491521501780_item	2491504	et	3	main
majasse	doc_491521501780_item	2491505	et	3	main
diskosse	doc_491521501780_item	2491506	et	4	main
me	doc_491521501780_item	2491507	et	4	main
elame	doc_491521501780_item	2491508	et	3	main
maardu	doc_491521501780_item	2491509	et	4	main
elan	doc_491521501780_item	2491510	et	3	main
tallinast	doc_491521501780_item	2491511	et	4	main
seinas	doc_491521501780_item	2491512	et	3	main
on	doc_491521501780_item	2491513	et	4	main
tehtud	doc_491521501780_item	2491514	et	4	main
auk	doc_491521501780_item	2491515	et	3	main
kuhu	doc_491521501780_item	2491516	et	3	main
kutsun	doc_491521501780_item	2491517	et	3	main
teatris	doc_491521501780_item	2491518	et	3	main
kuhu	doc_491521501780_item	2491519	et	3	main
läheb	doc_491521501780_item	2491520	et	3	main
läbi	doc_491521501780_item	2491528	et	4	main
selliseid	doc_491521501780_item	2491543	et	4	main
nt	doc_491521501780_item	2491550	et	4	main
keelt	doc_491521501780_item	2491554	et	4	main
tõlkinud	doc_491521501780_item	2491559	et	4	main
heast	doc_491521501780_item	2491574	et	3	main
töötada-	doc_491521501780_item	2491577	et	3	main
on	doc_491521501780_item	2491586	et	4	main
mulle	doc_491521501780_item	2491594	et	4	main
last	doc_491521501780_item	2491605	et	4	main
töö	doc_491521501780_item	2491618	et	4	main
suhtub	doc_491521501780_item	2491623	et	3	main
eestis	doc_491521501780_item	2491626	et	3	main
kohakäänete	doc_491521501780_item	2491471	et	3	main
enamus	doc_491521501780_item	2491473	et	4	main
vigu	doc_491521501780_item	2491474	et	3	main
tekib	doc_491521501780_item	2491475	et	3	main
seoses	doc_491521501780_item	2491476	et	4	main
ka	doc_491521501780_item	2491482	et	3	main
kohakäändeid	doc_491521501780_item	2491485	et	3	main
ka	doc_491521501780_item	2491492	et	3	main
soomele	doc_491521501780_item	2491521	et	4	main
käändevead	doc_491521501780_item	2491523	et	4	main
14	doc_491521501780_item	2491530	et	2	main
käänet	doc_491521501780_item	2491531	et	3	main
piisavalt	doc_491521501780_item	2491533	et	4	main
kuid	doc_491521501780_item	2491535	et	4	main
ikka	doc_491521501780_item	2491536	et	4	main
käänete	doc_491521501780_item	2491539	et	3	main
on	doc_491521501780_item	2491542	et	4	main
vigu	doc_491521501780_item	2491544	et	3	main
õpeta	doc_491521501780_item	2491551	et	4	main
kus	doc_491521501780_item	2491555	et	3	main
on	doc_491521501780_item	2491573	et	4	main
keevitajaks	doc_491521501780_item	2491576	et	4	main
kellena	doc_491521501780_item	2491578	et	3	main
vihikud	doc_491521501780_item	2491588	et	3	main
telerile	doc_491521501780_item	2491591	et	3	main
lapst	doc_491521501780_item	2491603	et	4	main
peale	doc_491521501780_item	2491619	et	4	main
ma	doc_491521501780_item	2491621	et	3	main
nimetavst	doc_491521501780_item	2491631	et	4	main
moodustatud	doc_491521501780_item	2491634	et	4	main
omastav	doc_491521501780_item	2491636	et	4	main
kääne	doc_491521501780_item	2491637	et	3	main
terast	doc_491521501780_item	2491638	et	4	main
kauplusse	doc_491521501780_item	2491643	et	3	main
arvsõna	doc_491521501780_item	2491653	et	4	main
arvsõnu	doc_491521501780_item	2491657	et	3	main
oma	doc_491521501780_item	2491669	et	4	main
esmast-ühekseni	doc_491521501780_item	2491672	et	4	main
üheksandani	doc_491521501780_item	2491674	et	3	main
korruselises	doc_491521501780_item	2491677	et	4	main
valitud	doc_491521501780_item	2491685	et	4	main
käände	doc_491521501780_item	2491687	et	4	main
lõputäishäälik	doc_491521501780_item	2491688	et	3	main
politseinikud	doc_491521501780_item	2491707	et	4	main
kuulus	doc_491521501780_item	2491728	et	4	main
on	doc_491521501780_item	2491742	et	4	main
kasutamise	doc_491521501780_item	2491745	et	4	main
ma	doc_491521501780_item	2491750	et	3	main
ma	doc_491521501780_item	2491754	et	3	main
tegelen	doc_491521501780_item	2491757	et	3	main
olen	doc_491521501780_item	2491764	et	3	main
kirjutasib	doc_491521501780_item	2491785	et	4	main
ma	doc_491521501780_item	2491809	et	3	main
tahan	doc_491521501780_item	2491814	et	3	main
töötama	doc_491521501780_item	2491816	et	3	main
majas	doc_491521501780_item	2491817	et	3	main
võib	doc_491521501780_item	2491818	et	3	main
olema	doc_491521501780_item	2491819	et	4	main
mulle	doc_491521501780_item	2491820	et	4	main
muud	doc_491521501780_item	2491522	et	4	main
kohe	doc_491521501780_item	2491524	et	4	main
esimestel	doc_491521501780_item	2491525	et	4	main
kõik	doc_491521501780_item	2491529	et	4	main
harjutusi	doc_491521501780_item	2491534	et	4	main
eksitakse	doc_491521501780_item	2491537	et	4	main
palju	doc_491521501780_item	2491541	et	4	main
mis	doc_491521501780_item	2491545	et	4	main
tekivad	doc_491521501780_item	2491546	et	3	main
vene	doc_491521501780_item	2491547	et	4	main
mind	doc_491521501780_item	2491552	et	4	main
on	doc_491521501780_item	2491557	et	4	main
selle	doc_491521501780_item	2491560	et	4	main
endale	doc_491521501780_item	2491562	et	4	main
nii	doc_491521501780_item	2491563	et	3	main
меня	doc_491521501780_item	2491565	et	2	main
sõber	doc_491521501780_item	2491566	et	3	main
aitab	doc_491521501780_item	2491567	et	3	main
mulle	doc_491521501780_item	2491568	et	4	main
поможет	doc_491521501780_item	2491569	et	2	main
мне	doc_491521501780_item	2491570	et	2	main
see	doc_491521501780_item	2491571	et	3	main
nõud	doc_491521501780_item	2491572	et	3	main
telefoninumber	doc_491521501780_item	2491580	et	3	main
minuga	doc_491521501780_item	2491587	et	3	main
aitab	doc_491521501780_item	2491593	et	3	main
on	doc_491521501780_item	2491598	et	4	main
suur	doc_491521501780_item	2491599	et	3	main
tal	doc_491521501780_item	2491606	et	3	main
suur	doc_491521501780_item	2491609	et	3	main
tööle	doc_491521501780_item	2491620	et	3	main
töötajasse	doc_491521501780_item	2491625	et	4	main
on	doc_491521501780_item	2491627	et	4	main
käändest	doc_491521501780_item	2491632	et	4	main
kurbusse	doc_491521501780_item	2491641	et	4	main
esimesest	doc_491521501780_item	2491673	et	3	main
et	doc_491521501780_item	2491681	et	3	main
eksitud	doc_491521501780_item	2491691	et	4	main
verbi	doc_491521501780_item	2491700	et	4	main
meeldib	doc_491521501780_item	2491710	et	3	main
lühike	doc_491521501780_item	2491722	et	4	main
vaba	doc_491521501780_item	2491724	et	4	main
kus	doc_491521501780_item	2491739	et	3	main
eksitud	doc_491521501780_item	2491747	et	4	main
spordiga	doc_491521501780_item	2491756	et	3	main
taheti	doc_491521501780_item	2491762	et	3	main
minevik	doc_491521501780_item	2491793	et	3	main
sõnatasand	doc_491521501780_item	2491823	et	3	main
pidamistarvete	doc_491521501780_item	2491826	et	4	main
selle	doc_491521501780_item	2491827	et	4	main
pärast	doc_491521501780_item	2491828	et	4	main
puhata	doc_491521501780_item	2491834	et	4	main
alles	doc_491521501780_item	2491835	et	3	main
kolm	doc_491521501780_item	2491836	et	3	main
selles	doc_491521501780_item	2491847	et	4	main
aeg	doc_491521501780_item	2491850	et	3	main
tahaks	doc_491521501780_item	2491854	et	3	main
aastat	doc_491521501780_item	2491862	et	3	main
õppisin	doc_491521501780_item	2491864	et	3	main
lapsepõlv	doc_491521501780_item	2491869	et	3	main
jäänud	doc_491521501780_item	2491883	et	4	main
sõnajärg	doc_491521501780_item	2491884	et	3	main
minu	doc_491521501780_item	2491885	et	3	main
nimi	doc_491521501780_item	2491886	et	3	main
isa	doc_491521501780_item	2491887	et	4	main
koer	doc_491521501780_item	2491892	et	3	main
autojuht	doc_491521501780_item	2491893	et	3	main
iga	doc_491521501780_item	2491894	et	4	main
päev	doc_491521501780_item	2491895	et	3	main
käib	doc_491521501780_item	2491896	et	3	main
konteksti	doc_491521501780_item	2491909	et	4	main
arvan	doc_491521501780_item	2491910	et	3	main
et	doc_491521501780_item	2491911	et	3	main
on	doc_491521501780_item	2491912	et	4	main
tahetud	doc_491521501780_item	2491913	et	4	main
ta	doc_491521501780_item	2491916	et	4	main
on	doc_491521501780_item	2491922	et	4	main
sõna	doc_491521501780_item	2491924	et	4	main
neljakesi	doc_491521501780_item	2491925	et	3	main
asemel	doc_491521501780_item	2491945	et	4	main
tegusõnast	doc_491521501780_item	2491960	et	4	main
keelt	doc_491521501780_item	2491584	et	4	main
need	doc_491521501780_item	2491585	et	3	main
ostis	doc_491521501780_item	2491589	et	4	main
see	doc_491521501780_item	2491595	et	3	main
ta	doc_491521501780_item	2491597	et	4	main
pea	doc_491521501780_item	2491600	et	4	main
millega	doc_491521501780_item	2491601	et	3	main
neli	doc_491521501780_item	2491602	et	3	main
perekond	doc_491521501780_item	2491607	et	3	main
neid	doc_491521501780_item	2491617	et	4	main
töötajale	doc_491521501780_item	2491624	et	4	main
kurbusesse	doc_491521501780_item	2491642	et	4	main
omastava	doc_491521501780_item	2491645	et	4	main
valesti	doc_491521501780_item	2491647	et	3	main
tüdruku	doc_491521501780_item	2491651	et	3	main
detsembrul	doc_491521501780_item	2491652	et	4	main
kasutamine	doc_491521501780_item	2491656	et	4	main
enamasti	doc_491521501780_item	2491658	et	4	main
paljudel	doc_491521501780_item	2491663	et	3	main
on	doc_491521501780_item	2491664	et	4	main
selge	doc_491521501780_item	2491665	et	4	main
kuidas	doc_491521501780_item	2491666	et	3	main
üheksasaia	doc_491521501780_item	2491671	et	4	main
nelja-	doc_491521501780_item	2491679	et	4	main
siin	doc_491521501780_item	2491682	et	4	main
eksitakse	doc_491521501780_item	2491698	et	4	main
nimisõna	doc_491521501780_item	2491702	et	4	main
me	doc_491521501780_item	2491704	et	4	main
oleme	doc_491521501780_item	2491705	et	3	main
tugev	doc_491521501780_item	2491706	et	4	main
mulle	doc_491521501780_item	2491709	et	4	main
luuletused	doc_491521501780_item	2491712	et	4	main
ja	doc_491521501780_item	2491714	et	3	main
tiit	doc_491521501780_item	2491715	et	4	main
arvutimängud	doc_491521501780_item	2491721	et	3	main
juuksed	doc_491521501780_item	2491723	et	3	main
autona	doc_491521501780_item	2491731	et	3	main
eksitud	doc_491521501780_item	2491732	et	4	main
nelja	doc_491521501780_item	2491733	et	4	main
vastu	doc_491521501780_item	2491738	et	3	main
täiend	doc_491521501780_item	2491741	et	3	main
verbi	doc_491521501780_item	2491748	et	4	main
kutsekoolis	doc_491521501780_item	2491752	et	4	main
ma	doc_491521501780_item	2491758	et	3	main
kontekstile	doc_491521501780_item	2491761	et	3	main
käinud	doc_491521501780_item	2491765	et	4	main
on	doc_491521501780_item	2491787	et	4	main
pandud	doc_491521501780_item	2491788	et	4	main
nii	doc_491521501780_item	2491789	et	3	main
olevik	doc_491521501780_item	2491790	et	3	main
kui	doc_491521501780_item	2491791	et	3	main
ma	doc_491521501780_item	2491794	et	3	main
ei	doc_491521501780_item	2491801	et	4	main
töötab	doc_491521501780_item	2491802	et	3	main
aeg	doc_491521501780_item	2491803	et	3	main
maardu	doc_491521501780_item	2491806	et	4	main
gümnaasiumi	doc_491521501780_item	2491807	et	4	main
lõpetasin	doc_491521501780_item	2491808	et	3	main
infinitiivi	doc_491521501780_item	2491812	et	4	main
maja	doc_491521501780_item	2491825	et	4	main
valikul	doc_491521501780_item	2491831	et	3	main
ei	doc_491521501780_item	2491832	et	4	main
saa	doc_491521501780_item	2491833	et	4	main
juhtkonda	doc_491521501780_item	2491846	et	4	main
kõik	doc_491521501780_item	2491849	et	4	main
koguaeg	doc_491521501780_item	2491851	et	3	main
venemaale	doc_491521501780_item	2491856	et	4	main
10	doc_491521501780_item	2491861	et	2	main
muud	doc_491521501780_item	2491866	et	4	main
möödas	doc_491521501780_item	2491870	et	3	main
möödus	doc_491521501780_item	2491872	et	3	main
suitsutada	doc_491521501780_item	2491875	et	3	main
suitsetada	doc_491521501780_item	2491876	et	3	main
mul	doc_491521501780_item	2491877	et	3	main
sünnipäev	doc_491521501780_item	2491878	et	3	main
aprillis	doc_491521501780_item	2491879	et	3	main
tegusõna	doc_491521501780_item	2491880	et	4	main
on	doc_491521501780_item	2491888	et	4	main
tööl	doc_491521501780_item	2491897	et	3	main
osanud	doc_491521501780_item	2491902	et	4	main
öelda	doc_491521501780_item	2491914	et	4	main
armastan	doc_491521501780_item	2491622	et	3	main
koolid	doc_491521501780_item	2491629	et	3	main
tehnikumid	doc_491521501780_item	2491630	et	3	main
vale	doc_491521501780_item	2491635	et	4	main
katus	doc_491521501780_item	2491639	et	4	main
terasest	doc_491521501780_item	2491640	et	4	main
lõpp	doc_491521501780_item	2491646	et	3	main
käänamine	doc_491521501780_item	2491654	et	4	main
öelda	doc_491521501780_item	2491667	et	4	main
sõnadega	doc_491521501780_item	2491668	et	3	main
elan	doc_491521501780_item	2491675	et	3	main
valesti	doc_491521501780_item	2491684	et	3	main
omastava	doc_491521501780_item	2491686	et	4	main
kahekümmne	doc_491521501780_item	2491689	et	4	main
on	doc_491521501780_item	2491692	et	4	main
vastu	doc_491521501780_item	2491694	et	3	main
ühildumisvead	doc_491521501780_item	2491695	et	4	main
väga	doc_491521501780_item	2491696	et	3	main
palju	doc_491521501780_item	2491697	et	4	main
ja	doc_491521501780_item	2491701	et	3	main
ühildamises	doc_491521501780_item	2491703	et	4	main
peatab	doc_491521501780_item	2491708	et	3	main
need	doc_491521501780_item	2491711	et	3	main
ott	doc_491521501780_item	2491713	et	3	main
seisab	doc_491521501780_item	2491716	et	3	main
meie	doc_491521501780_item	2491717	et	4	main
ees	doc_491521501780_item	2491718	et	4	main
mulle	doc_491521501780_item	2491719	et	4	main
meeldib	doc_491521501780_item	2491720	et	3	main
palju	doc_491521501780_item	2491628	et	4	main
on	doc_491521501780_item	2491633	et	4	main
kauplusesse	doc_491521501780_item	2491644	et	4	main
valitud	doc_491521501780_item	2491648	et	4	main
lillekimpedes	doc_491521501780_item	2491649	et	4	main
iluse	doc_491521501780_item	2491650	et	3	main
ja	doc_491521501780_item	2491655	et	3	main
minu	doc_491521501780_item	2491659	et	3	main
õpilased	doc_491521501780_item	2491660	et	3	main
väldivad	doc_491521501780_item	2491661	et	3	main
kuid	doc_491521501780_item	2491662	et	4	main
sünniaasta	doc_491521501780_item	2491670	et	4	main
nelji	doc_491521501780_item	2491676	et	4	main
majas	doc_491521501780_item	2491678	et	3	main
arvan	doc_491521501780_item	2491680	et	3	main
on	doc_491521501780_item	2491683	et	4	main
viiendal	doc_491521501780_item	2491690	et	3	main
konsonantühendi	doc_491521501780_item	2491693	et	4	main
just	doc_491521501780_item	2491699	et	3	main
lauljaks	doc_491521501780_item	2491729	et	4	main
kiirena	doc_491521501780_item	2491730	et	4	main
reegli	doc_491521501780_item	2491737	et	3	main
käändelõputa	doc_491521501780_item	2491743	et	4	main
verbi	doc_491521501780_item	2491744	et	4	main
valikul	doc_491521501780_item	2491749	et	3	main
tegeb	doc_491521501780_item	2491755	et	4	main
rootsis-vastavalt	doc_491521501780_item	2491760	et	4	main
eksitud	doc_491521501780_item	2491766	et	4	main
pööramisel	doc_491521501780_item	2491767	et	4	main
ka	doc_491521501780_item	2491792	et	3	main
minen	doc_491521501780_item	2491795	et	4	main
eitus	doc_491521501780_item	2491796	et	4	main
ma	doc_491521501780_item	2491804	et	3	main
õppinud	doc_491521501780_item	2491810	et	4	main
meeldib	doc_491521501780_item	2491821	et	3	main
liitsõna	doc_491521501780_item	2491824	et	4	main
oli	doc_491521501780_item	2491845	et	3	main
kasumita	doc_491521501780_item	2491853	et	4	main
seisid	doc_491521501780_item	2491855	et	4	main
sõita	doc_491521501780_item	2491857	et	3	main
riide	doc_491521501780_item	2491858	et	4	main
paides	doc_491521501780_item	2491871	et	4	main
ei	doc_491521501780_item	2491873	et	4	main
on	doc_491521501780_item	2491881	et	4	main
veel	doc_491521501780_item	2491889	et	4	main
meil	doc_491521501780_item	2491890	et	4	main
vead	doc_491521501780_item	2491898	et	4	main
ei	doc_491521501780_item	2491901	et	4	main
liigitada	doc_491521501780_item	2491903	et	3	main
pärast	doc_491521501780_item	2491904	et	4	main
ta	doc_491521501780_item	2491905	et	4	main
tuleb	doc_491521501780_item	2491906	et	3	main
töötab	doc_491521501780_item	2491907	et	3	main
arvestades	doc_491521501780_item	2491908	et	3	main
läheb	doc_491521501780_item	2491917	et	3	main
ja	doc_491521501780_item	2491926	et	3	main
arvatavasti	doc_491521501780_item	2491927	et	3	main
põhjal	doc_491521501780_item	2491931	et	4	main
on	doc_491521501780_item	2491946	et	4	main
viima	doc_491521501780_item	2491961	et	3	main
ajal	doc_491521501780_item	2491725	et	4	main
tahab	doc_491521501780_item	2491726	et	3	main
saada	doc_491521501780_item	2491727	et	4	main
viimast	doc_491521501780_item	2491734	et	4	main
käänet	doc_491521501780_item	2491735	et	3	main
puudutava	doc_491521501780_item	2491736	et	4	main
nimisõna	doc_491521501780_item	2491740	et	4	main
vead	doc_491521501780_item	2491746	et	4	main
õpetan	doc_491521501780_item	2491751	et	3	main
õpin	doc_491521501780_item	2491753	et	3	main
sõitsin	doc_491521501780_item	2491759	et	3	main
öelda	doc_491521501780_item	2491763	et	4	main
ta	doc_491521501780_item	2491768	et	4	main
oleb	doc_491521501780_item	2491769	et	4	main
ma	doc_491521501780_item	2491770	et	3	main
on	doc_491521501780_item	2491771	et	4	main
fotograaf	doc_491521501780_item	2491772	et	4	main
väga	doc_491521501780_item	2491773	et	3	main
massiliselt	doc_491521501780_item	2491774	et	4	main
esinev	doc_491521501780_item	2491775	et	4	main
eksimus	doc_491521501780_item	2491776	et	4	main
ma	doc_491521501780_item	2491777	et	3	main
on	doc_491521501780_item	2491778	et	4	main
ma	doc_491521501780_item	2491779	et	3	main
lõpetas	doc_491521501780_item	2491780	et	3	main
eksitud	doc_491521501780_item	2491781	et	4	main
vormi	doc_491521501780_item	2491782	et	4	main
valikul	doc_491521501780_item	2491783	et	3	main
ta	doc_491521501780_item	2491784	et	4	main
kokku	doc_491521501780_item	2491786	et	3	main
ei	doc_491521501780_item	2491797	et	4	main
meeldib	doc_491521501780_item	2491798	et	3	main
ei	doc_491521501780_item	2491799	et	4	main
tahan	doc_491521501780_item	2491800	et	3	main
lõpetan	doc_491521501780_item	2491805	et	3	main
õppisin	doc_491521501780_item	2491811	et	3	main
valikul	doc_491521501780_item	2491813	et	3	main
keevitajana	doc_491521501780_item	2491815	et	4	main
joonistama	doc_491521501780_item	2491822	et	3	main
eksitud	doc_491521501780_item	2491829	et	4	main
sõna	doc_491521501780_item	2491830	et	4	main
mõeldud	doc_491521501780_item	2491844	et	4	main
oblastis	doc_491521501780_item	2491848	et	3	main
kasuta	doc_491521501780_item	2491852	et	4	main
järgmine	doc_491521501780_item	2491860	et	3	main
ma	doc_491521501780_item	2491863	et	3	main
sõnatasandi	doc_491521501780_item	2491867	et	3	main
tohi	doc_491521501780_item	2491874	et	4	main
on	doc_491521501780_item	2491891	et	4	main
ma	doc_491521501780_item	2491900	et	3	main
pärast	doc_491521501780_item	2491915	et	4	main
mustamää	doc_491521501780_item	2491919	et	4	main
korda	doc_491521501780_item	2491837	et	4	main
aastas	doc_491521501780_item	2491838	et	3	main
ainult	doc_491521501780_item	2491839	et	4	main
juhtimine	doc_491521501780_item	2491840	et	4	main
suhtub	doc_491521501780_item	2491841	et	3	main
hästi	doc_491521501780_item	2491842	et	3	main
kellesse	doc_491521501780_item	2491843	et	4	main
riietus	doc_491521501780_item	2491859	et	4	main
eelmised	doc_491521501780_item	2491865	et	3	main
vead	doc_491521501780_item	2491868	et	4	main
ära	doc_491521501780_item	2491882	et	4	main
mida	doc_491521501780_item	2491899	et	4	main
neli	doc_491521501780_item	2491920	et	3	main
on	doc_491521501780_item	2491928	et	4	main
keegi	doc_491521501780_item	2491932	et	4	main
selle	doc_491521501780_item	2491934	et	4	main
kasutatud	doc_491521501780_item	2491947	et	4	main
ingliskeelset	doc_491521501780_item	2491948	et	3	main
ainsuse	doc_491521501780_item	2491956	et	4	main
vorm	doc_491521501780_item	2491957	et	3	main
autojuhid	doc_491521501780_item	2491958	et	3	main
viip	doc_491521501780_item	2491959	et	4	main
tööle	doc_491521501780_item	2491918	et	3	main
käsi	doc_491521501780_item	2491921	et	4	main
mõeldud	doc_491521501780_item	2491923	et	4	main
kuulduse	doc_491521501780_item	2491930	et	4	main
sõna	doc_491521501780_item	2491944	et	4	main
hamb	doc_491521501780_item	2491950	et	4	main
nii	doc_491521501780_item	2491951	et	3	main
on	doc_491521501780_item	2491952	et	4	main
moodustatud	doc_491521501780_item	2491953	et	4	main
sõnast	doc_491521501780_item	2491954	et	4	main
hambad	doc_491521501780_item	2491955	et	3	main
kirjutatud	doc_491521501780_item	2491929	et	4	main
ütles	doc_491521501780_item	2491933	et	3	main
sõna	doc_491521501780_item	2491935	et	4	main
ja	doc_491521501780_item	2491936	et	3	main
autor	doc_491521501780_item	2491937	et	3	main
kirjutas	doc_491521501780_item	2491938	et	3	main
nii	doc_491521501780_item	2491939	et	3	main
nagu	doc_491521501780_item	2491940	et	3	main
kuulis	doc_491521501780_item	2491941	et	4	main
football	doc_491521501780_item	2491942	et	4	main
eestikeelse	doc_491521501780_item	2491943	et	3	main
varianti	doc_491521501780_item	2491949	et	4	main
on	doc_491521501780_item	2491962	et	4	main
moodustatud	doc_491521501780_item	2491963	et	4	main
ains	doc_491521501780_item	2491964	et	4	main
3	doc_491521501780_item	2491965	et	2	main
pööre	doc_491521501780_item	2491966	et	4	main
meie	doc_491521501784_item	2494275	et	4	main
tulemused	doc_491521501784_item	2494287	et	3	main
need	doc_491521501784_item	2494293	et	3	main
kes	doc_491521501784_item	2494295	et	4	main
saanud	doc_491521501784_item	2494297	et	4	main
arvestust	doc_491521501784_item	2494298	et	4	main
ei	doc_491521501784_item	2494299	et	4	main
eesti	doc_491521501784_item	2494270	et	4	main
osakonna	doc_491521501784_item	2494272	et	4	main
teada	doc_491521501784_item	2494280	et	3	main
et	doc_491521501784_item	2494281	et	3	main
õppejõud	doc_491521501784_item	2494282	et	4	main
eksamiajal	doc_491521501784_item	2494289	et	3	main
üliõpilased	doc_491521501784_item	2494294	et	3	main
ei	doc_491521501784_item	2494296	et	4	main
teemad	doc_491521501784_item	2494303	et	3	main
olevat	doc_491521501784_item	2494304	et	4	main
valed	doc_491521501784_item	2494305	et	3	main
kuid	doc_491521501784_item	2494306	et	4	main
eelneval	doc_491521501784_item	2494307	et	4	main
tunniajal	doc_491521501784_item	2494308	et	3	main
hr	doc_491521501784_item	2494309	et	4	main
perekonnanimi	doc_491521501784_item	2494310	et	3	main
ütles	doc_491521501784_item	2494311	et	3	main
et	doc_491521501784_item	2494312	et	3	main
raamatu	doc_491521501784_item	2494313	et	4	main
väljaanne	doc_491521501784_item	2494314	et	4	main
peaks	doc_491521501784_item	2494315	et	4	main
olema	doc_491521501784_item	2494316	et	4	main
2003	doc_491521501784_item	2494317	et	2	main
ja	doc_491521501784_item	2494318	et	3	main
see	doc_491521501784_item	2494319	et	3	main
võib	doc_491521501784_item	2494320	et	3	main
lugupidamisega	doc_491521501784_item	2494323	et	3	main
avaldus	doc_491521501784_item	2494269	et	4	main
filoloogia	doc_491521501784_item	2494276	et	4	main
teaduskonna	doc_491521501784_item	2494277	et	4	main
üliõpilased	doc_491521501784_item	2494278	et	3	main
anname	doc_491521501784_item	2494279	et	3	main
kell	doc_491521501784_item	2494291	et	3	main
üliõpilased	doc_491521501784_item	2494326	et	3	main
vaid	doc_491521501784_item	2494288	et	3	main
1010	doc_491521501784_item	2494292	et	2	main
olla	doc_491521501784_item	2494321	et	3	main
filoloogia	doc_491521501784_item	2494271	et	4	main
juhatajale	doc_491521501784_item	2494273	et	4	main
avaldus	doc_491521501784_item	2494274	et	4	main
eesnimi	doc_491521501784_item	2494283	et	3	main
perekonnanimi	doc_491521501784_item	2494284	et	3	main
teatas	doc_491521501784_item	2494285	et	3	main
arvestustööde	doc_491521501784_item	2494286	et	3	main
07062004	doc_491521501784_item	2494290	et	2	main
saanud	doc_491521501784_item	2494300	et	4	main
eksamile	doc_491521501784_item	2494301	et	3	main
arvestuse	doc_491521501784_item	2494302	et	4	main
kordustrükkis	doc_491521501784_item	2494322	et	4	main
filoloogia	doc_491521501784_item	2494324	et	4	main
teaduskonna	doc_491521501784_item	2494325	et	4	main
ersa	doc_491521501787_item	2494929	et	4	main
keele	doc_491521501787_item	2494930	et	4	main
paastmise	doc_491521501787_item	2494931	et	4	main
fondi	doc_491521501787_item	2494932	et	4	main
ja	doc_491521501787_item	2494933	et	3	main
rahvust	doc_491521501787_item	2494942	et	3	main
mordva	doc_491521501787_item	2494944	et	3	main
motlevate	doc_491521501787_item	2494952	et	4	main
kelle	doc_491521501787_item	2494954	et	4	main
viimase	doc_491521501787_item	2494956	et	3	main
mordva	doc_491521501787_item	2494962	et	3	main
esimesed	doc_491521501787_item	2494964	et	3	main
sellest	doc_491521501787_item	2494966	et	4	main
kaks	doc_491521501787_item	2494969	et	3	main
keelt	doc_491521501787_item	2494971	et	4	main
eri	doc_491521501787_item	2494973	et	4	main
ja	doc_491521501787_item	2494975	et	3	main
kaks	doc_491521501787_item	2494976	et	3	main
eri	doc_491521501787_item	2494977	et	4	main
tuleks	doc_491521501787_item	2494981	et	4	main
rahvusi	doc_491521501787_item	2494982	et	3	main
koos	doc_491521501787_item	2494996	et	4	main
ja	doc_491521501787_item	2494999	et	3	main
psuholoogiline	doc_491521501787_item	2495001	et	4	main
moksad	doc_491521501787_item	2495007	et	4	main
eriti	doc_491521501787_item	2495009	et	3	main
ersad	doc_491521501787_item	2495010	et	4	main
rohutavad	doc_491521501787_item	2495011	et	3	main
ka	doc_491521501787_item	2495029	et	3	main
kohta	doc_491521501787_item	2495033	et	4	main
ometigi	doc_491521501787_item	2495035	et	4	main
ja	doc_491521501787_item	2495041	et	3	main
ei	doc_491521501787_item	2495043	et	4	main
saa	doc_491521501787_item	2495044	et	4	main
ent	doc_491521501787_item	2495048	et	3	main
voitlus	doc_491521501787_item	2494922	et	4	main
uhed	doc_491521501787_item	2494923	et	4	main
ersad	doc_491521501787_item	2494925	et	4	main
mastor	doc_491521501787_item	2494937	et	4	main
teised	doc_491521501787_item	2494943	et	4	main
vabariigi	doc_491521501787_item	2494945	et	3	main
reaalpolotiliselt	doc_491521501787_item	2494951	et	4	main
ersadega	doc_491521501787_item	2494953	et	4	main
nelja	doc_491521501787_item	2494957	et	4	main
aasta	doc_491521501787_item	2494958	et	4	main
kaks	doc_491521501787_item	2494972	et	3	main
kultuuri	doc_491521501787_item	2494974	et	4	main
ehitama	doc_491521501787_item	2494983	et	4	main
sellest	doc_491521501787_item	2494987	et	4	main
et	doc_491521501787_item	2494988	et	3	main
kohaliku	doc_491521501787_item	2494997	et	3	main
voimu	doc_491521501787_item	2494998	et	4	main
eelarvega	doc_491521501787_item	2495000	et	3	main
niipea	doc_491521501787_item	2495014	et	3	main
ules	doc_491521501787_item	2495017	et	3	main
ersa	doc_491521501787_item	2495019	et	4	main
ja	doc_491521501787_item	2495020	et	3	main
moksa	doc_491521501787_item	2495021	et	4	main
on	doc_491521501787_item	2495023	et	4	main
ent	doc_491521501787_item	2495026	et	3	main
ersad	doc_491521501787_item	2495040	et	4	main
moksad	doc_491521501787_item	2495042	et	4	main
eirata	doc_491521501787_item	2495047	et	4	main
on	doc_491521501787_item	2495053	et	4	main
sama	doc_491521501787_item	2495054	et	4	main
esimees	doc_491521501787_item	2495072	et	4	main
panevad	doc_491521501787_item	2495080	et	4	main
kes	doc_491521501787_item	2495098	et	4	main
keelt	doc_491521501787_item	2495101	et	4	main
end	doc_491521501787_item	2495103	et	4	main
makslateks	doc_491521501787_item	2495104	et	4	main
inimesed	doc_491521501787_item	2495108	et	3	main
kutsuvad	doc_491521501787_item	2495109	et	4	main
mordvalasteks	doc_491521501787_item	2495111	et	3	main
erzan	doc_491521501787_item	2495112	et	4	main
on	doc_491521501787_item	2495119	et	4	main
etnost	doc_491521501787_item	2495123	et	4	main
pole	doc_491521501787_item	2495124	et	3	main
on	doc_491521501787_item	2495126	et	4	main
ulitohus	doc_491521501787_item	2495127	et	4	main
venestamise	doc_491521501787_item	2495128	et	4	main
katalusaator	doc_491521501787_item	2495129	et	4	main
tseremissid	doc_491521501787_item	2495135	et	4	main
jne	doc_491521501787_item	2495137	et	4	main
pokuv	doc_491521501787_item	2495145	et	4	main
toimimise	doc_491521501787_item	2495162	et	4	main
ei	doc_491521501787_item	2495165	et	4	main
rakendava	doc_491521501787_item	2495168	et	4	main
oldi	doc_491521501787_item	2495175	et	3	main
vastu	doc_491521501787_item	2495176	et	3	main
keelte	doc_491521501787_item	2495181	et	3	main
keele	doc_491521501787_item	2495188	et	4	main
ruhma	doc_491521501787_item	2494921	et	4	main
koondunud	doc_491521501787_item	2494928	et	4	main
ajalehe	doc_491521501787_item	2494935	et	3	main
on	doc_491521501787_item	2494939	et	4	main
ersa	doc_491521501787_item	2494941	et	4	main
arv	doc_491521501787_item	2494955	et	3	main
aga	doc_491521501787_item	2494961	et	3	main
rahvust	doc_491521501787_item	2494963	et	3	main
lahtuvad	doc_491521501787_item	2494965	et	4	main
et	doc_491521501787_item	2494967	et	3	main
mille	doc_491521501787_item	2494979	et	3	main
hakata	doc_491521501787_item	2494984	et	4	main
teised	doc_491521501787_item	2494985	et	4	main
aga	doc_491521501787_item	2494986	et	3	main
subjekt	doc_491521501787_item	2494993	et	3	main
vabariik	doc_491521501787_item	2494995	et	3	main
kaugus	doc_491521501787_item	2495002	et	4	main
oma	doc_491521501787_item	2495012	et	4	main
teema	doc_491521501787_item	2495016	et	4	main
kerkib	doc_491521501787_item	2495018	et	3	main
seminaritöö	doc_491521501787_item	2494894	et	4	main
traks	doc_491521501787_item	2494895	et	4	main
skal	doc_491521501787_item	2494896	et	4	main
lehm	doc_491521501787_item	2494897	et	3	main
moksa	doc_491521501787_item	2494898	et	4	main
ja	doc_491521501787_item	2494899	et	3	main
ersa	doc_491521501787_item	2494900	et	4	main
keeles	doc_491521501787_item	2494901	et	4	main
aavai	doc_491521501787_item	2494902	et	4	main
tadaze	doc_491521501787_item	2494903	et	4	main
ema	doc_491521501787_item	2494904	et	4	main
esimene	doc_491521501787_item	2494905	et	3	main
ersa	doc_491521501787_item	2494906	et	4	main
keeles	doc_491521501787_item	2494907	et	4	main
ja	doc_491521501787_item	2494908	et	3	main
tadaze	doc_491521501787_item	2494909	et	4	main
moksa	doc_491521501787_item	2494910	et	4	main
keeles	doc_491521501787_item	2494911	et	4	main
nuudiskusimused	doc_491521501787_item	2494912	et	4	main
ja	doc_491521501787_item	2494913	et	3	main
tulevikuvaljavaated	doc_491521501787_item	2494914	et	4	main
praegu	doc_491521501787_item	2494915	et	3	main
on	doc_491521501787_item	2494916	et	4	main
mordvamaal	doc_491521501787_item	2494917	et	4	main
kahe	doc_491521501787_item	2494918	et	3	main
rahvust	doc_491521501787_item	2494919	et	3	main
loova	doc_491521501787_item	2494920	et	4	main
nimelt	doc_491521501787_item	2494924	et	4	main
kes	doc_491521501787_item	2494926	et	4	main
erzan	doc_491521501787_item	2494936	et	4	main
umber	doc_491521501787_item	2494938	et	3	main
on	doc_491521501787_item	2494927	et	4	main
selle	doc_491521501787_item	2494934	et	4	main
loomas	doc_491521501787_item	2494940	et	4	main
juhtkonnale	doc_491521501787_item	2494946	et	4	main
lahedal	doc_491521501787_item	2494947	et	3	main
seisvad	doc_491521501787_item	2494948	et	4	main
moksad	doc_491521501787_item	2494949	et	4	main
koos	doc_491521501787_item	2494950	et	4	main
jooksul	doc_491521501787_item	2494959	et	4	main
eksisteerib	doc_491521501787_item	2494968	et	3	main
pohjalt	doc_491521501787_item	2494980	et	4	main
on	doc_491521501787_item	2494989	et	4	main
uks	doc_491521501787_item	2494990	et	3	main
venemaa	doc_491521501787_item	2494991	et	4	main
foderatsiooni	doc_491521501787_item	2494992	et	4	main
mordva	doc_491521501787_item	2494994	et	3	main
ehk	doc_491521501787_item	2495004	et	3	main
keelelist	doc_491521501787_item	2495005	et	4	main
kui	doc_491521501787_item	2495015	et	3	main
usna	doc_491521501787_item	2495024	et	4	main
saarnased	doc_491521501787_item	2495025	et	4	main
sama	doc_491521501787_item	2495027	et	4	main
kehtib	doc_491521501787_item	2495028	et	3	main
erinevaiks	doc_491521501787_item	2495038	et	4	main
olemasolu	doc_491521501787_item	2495046	et	4	main
nad	doc_491521501787_item	2495052	et	3	main
rahvas	doc_491521501787_item	2495055	et	4	main
professor	doc_491521501787_item	2495073	et	3	main
neid	doc_491521501787_item	2495076	et	4	main
lahutamatuteks	doc_491521501787_item	2495077	et	4	main
kaksikuteks	doc_491521501787_item	2495078	et	4	main
kultuuriaktivistid	doc_491521501787_item	2495079	et	3	main
sageli	doc_491521501787_item	2495081	et	3	main
vene	doc_491521501787_item	2495083	et	4	main
ja	doc_491521501787_item	2495086	et	3	main
oeldes	doc_491521501787_item	2495089	et	4	main
kes	doc_491521501787_item	2495091	et	4	main
ersat	doc_491521501787_item	2495093	et	4	main
nimetavad	doc_491521501787_item	2495094	et	4	main
konelevad	doc_491521501787_item	2495099	et	4	main
nimetavad	doc_491521501787_item	2495102	et	4	main
ainult	doc_491521501787_item	2495105	et	4	main
end	doc_491521501787_item	2495110	et	4	main
endised	doc_491521501787_item	2495130	et	3	main
maride	doc_491521501787_item	2495132	et	3	main
nimed	doc_491521501787_item	2495134	et	3	main
mordva	doc_491521501787_item	2495147	et	3	main
esimesest	doc_491521501787_item	2495171	et	3	main
sest	doc_491521501787_item	2495174	et	4	main
suurenenud	doc_491521501787_item	2494960	et	4	main
eri	doc_491521501787_item	2494970	et	4	main
identiteeti	doc_491521501787_item	2494978	et	4	main
uletab	doc_491521501787_item	2495003	et	4	main
mitmedki	doc_491521501787_item	2495006	et	4	main
ja	doc_491521501787_item	2495008	et	3	main
erinevusi	doc_491521501787_item	2495013	et	4	main
soome	doc_491521501787_item	2495030	et	3	main
on	doc_491521501787_item	2495036	et	4	main
kultuurikeeliks	doc_491521501787_item	2495039	et	4	main
teineteise	doc_491521501787_item	2495045	et	4	main
vaidlus	doc_491521501787_item	2495049	et	3	main
kas	doc_491521501787_item	2495051	et	3	main
kasutamist	doc_491521501787_item	2495088	et	4	main
end	doc_491521501787_item	2495095	et	4	main
erslaseks	doc_491521501787_item	2495096	et	4	main
need	doc_491521501787_item	2495097	et	3	main
arvates	doc_491521501787_item	2495118	et	4	main
mordva	doc_491521501787_item	2495120	et	3	main
pseudoetnonuum	doc_491521501787_item	2495121	et	3	main
olemasmordva	doc_491521501787_item	2495125	et	4	main
on	doc_491521501787_item	2495138	et	4	main
ammu	doc_491521501787_item	2495139	et	4	main
asendatud	doc_491521501787_item	2495140	et	4	main
omakeelstega	doc_491521501787_item	2495141	et	4	main
mordva	doc_491521501787_item	2495142	et	3	main
mordva	doc_491521501787_item	2495149	et	3	main
garanteeris	doc_491521501787_item	2495154	et	3	main
moksa	doc_491521501787_item	2495156	et	4	main
keele	doc_491521501787_item	2495160	et	4	main
vordlus	doc_491521501787_item	2495161	et	4	main
seda	doc_491521501787_item	2495167	et	3	main
lugemises	doc_491521501787_item	2495172	et	4	main
mordva	doc_491521501787_item	2495180	et	3	main
koigis	doc_491521501787_item	2495183	et	4	main
ja	doc_491521501787_item	2495185	et	3	main
mordva	doc_491521501787_item	2495187	et	3	main
seminaritöö	doc_491521501788_item	2495221	et	4	main
kirjakeel	doc_491521501788_item	2495223	et	4	main
meie	doc_491521501788_item	2495224	et	4	main
paevil	doc_491521501788_item	2495225	et	4	main
ilmuvad	doc_491521501788_item	2495232	et	4	main
ajakirjad	doc_491521501788_item	2495235	et	3	main
ersakeelsed	doc_491521501788_item	2495237	et	4	main
teevad	doc_491521501788_item	2495253	et	3	main
eduga	doc_491521501788_item	2495256	et	3	main
teadlased	doc_491521501788_item	2495258	et	3	main
mordva	doc_491521501788_item	2495260	et	3	main
jm	doc_491521501788_item	2495281	et	4	main
lapi	doc_491521501788_item	2495287	et	4	main
teadlaste	doc_491521501788_item	2495289	et	3	main
meile	doc_491521501788_item	2495291	et	4	main
sonarohk	doc_491521501788_item	2495299	et	4	main
peamiselt	doc_491521501788_item	2495302	et	4	main
ja	doc_491521501788_item	2495304	et	3	main
silbi	doc_491521501788_item	2495306	et	3	main
vahel	doc_491521501788_item	2495307	et	4	main
kaas	doc_491521501788_item	2495308	et	3	main
haalikuuhendeid	doc_491521501788_item	2495309	et	4	main
on	doc_491521501788_item	2495312	et	4	main
kaashaalikuid	doc_491521501788_item	2495323	et	4	main
esineb	doc_491521501788_item	2495330	et	3	main
voib	doc_491521501788_item	2495336	et	4	main
sest	doc_491521501788_item	2495343	et	4	main
liituma	doc_491521501788_item	2495348	et	4	main
ersa	doc_491521501788_item	2495349	et	4	main
ja	doc_491521501788_item	2495356	et	3	main
omadussonad	doc_491521501788_item	2495358	et	4	main
ees	doc_491521501788_item	2495360	et	4	main
kaandu	doc_491521501788_item	2495362	et	4	main
esineb	doc_491521501788_item	2495372	et	3	main
nii	doc_491521501788_item	2495375	et	3	main
nimisonule	doc_491521501788_item	2495396	et	4	main
kodus-oled	doc_491521501788_item	2495401	et	3	main
peab	doc_491521501788_item	2495425	et	4	main
lahendama	doc_491521501788_item	2495426	et	3	main
mordva	doc_491521501788_item	2495427	et	3	main
teadlaste	doc_491521501788_item	2495428	et	3	main
ainult	doc_491521501788_item	2495432	et	4	main
ajaloolased	doc_491521501788_item	2495436	et	3	main
kirjakeele	doc_491521501788_item	2495453	et	4	main
pohisonavara	doc_491521501787_item	2495022	et	4	main
ja	doc_491521501787_item	2495031	et	3	main
eesti	doc_491521501787_item	2495032	et	4	main
mis	doc_491521501787_item	2495034	et	4	main
kujunenud	doc_491521501787_item	2495037	et	4	main
voi	doc_491521501787_item	2495056	et	4	main
kaks	doc_491521501787_item	2495057	et	3	main
hoimurahvast	doc_491521501787_item	2495058	et	4	main
oma	doc_491521501787_item	2495059	et	4	main
ettekandes	doc_491521501787_item	2495060	et	4	main
esimesel	doc_491521501787_item	2495061	et	3	main
ersa	doc_491521501787_item	2495062	et	4	main
ja	doc_491521501787_item	2495063	et	3	main
moksa	doc_491521501787_item	2495064	et	4	main
konverentsil	doc_491521501787_item	2495066	et	3	main
14031992	doc_491521501787_item	2495067	et	2	main
pidas	doc_491521501787_item	2495068	et	3	main
rahvaste	doc_491521501787_item	2495065	et	4	main
mastorava	doc_491521501787_item	2495069	et	4	main
maaema	doc_491521501787_item	2495070	et	4	main
kestab	doc_491521501787_item	2495050	et	4	main
uhingu	doc_491521501787_item	2495071	et	4	main
dmitri	doc_491521501787_item	2495074	et	4	main
terminite	doc_491521501787_item	2495084	et	3	main
need	doc_491521501787_item	2495090	et	3	main
konelevad	doc_491521501787_item	2495092	et	4	main
moksa	doc_491521501787_item	2495100	et	4	main
minetanud	doc_491521501787_item	2495107	et	4	main
esindaja	doc_491521501787_item	2495115	et	4	main
jevgeni	doc_491521501787_item	2495116	et	4	main
chetvergovi	doc_491521501787_item	2495117	et	4	main
sellist	doc_491521501787_item	2495122	et	4	main
venekeelsed	doc_491521501787_item	2495131	et	3	main
udmurtide	doc_491521501787_item	2495133	et	3	main
votjakid	doc_491521501787_item	2495136	et	3	main
on	doc_491521501787_item	2495143	et	4	main
erand	doc_491521501787_item	2495146	et	3	main
riigipoliitika	doc_491521501787_item	2495148	et	4	main
uemnoukogu	doc_491521501787_item	2495150	et	4	main
detsembris	doc_491521501787_item	2495152	et	3	main
formaalselt	doc_491521501787_item	2495155	et	4	main
ersa	doc_491521501787_item	2495157	et	4	main
ja	doc_491521501787_item	2495158	et	3	main
vene	doc_491521501787_item	2495159	et	4	main
joudnud	doc_491521501787_item	2495166	et	4	main
eelnou	doc_491521501787_item	2495170	et	4	main
kohustuslik	doc_491521501787_item	2495179	et	3	main
valdamine	doc_491521501787_item	2495189	et	4	main
olemise	doc_491521501787_item	2495191	et	4	main
kargin	doc_491521501787_item	2495193	et	4	main
moksa	doc_491521501788_item	2495222	et	4	main
koigis	doc_491521501788_item	2495228	et	4	main
zanrides	doc_491521501788_item	2495229	et	4	main
rohkesti	doc_491521501788_item	2495230	et	3	main
erzjanj	doc_491521501788_item	2495238	et	4	main
mordvalastel	doc_491521501788_item	2495241	et	3	main
ja	doc_491521501788_item	2495248	et	3	main
tanapaeval	doc_491521501788_item	2495252	et	4	main
esimene	doc_491521501788_item	2495259	et	3	main
karjala	doc_491521501788_item	2495280	et	4	main
keeltele	doc_491521501788_item	2495283	et	3	main
on	doc_491521501788_item	2495297	et	4	main
vahe	doc_491521501788_item	2495313	et	4	main
peenendet	doc_491521501788_item	2495322	et	4	main
vokaalharmoonia	doc_491521501788_item	2495329	et	4	main
moksas	doc_491521501788_item	2495333	et	4	main
voib-olla	doc_491521501788_item	2495341	et	3	main
on	doc_491521501788_item	2495351	et	4	main
3	doc_491521501788_item	2495352	et	2	main
nimisona	doc_491521501788_item	2495359	et	4	main
ning	doc_491521501788_item	2495366	et	3	main
ja	doc_491521501788_item	2495377	et	3	main
koneviis	doc_491521501788_item	2495379	et	4	main
kui	doc_491521501788_item	2495380	et	3	main
ergutav	doc_491521501788_item	2495383	et	4	main
minevikus	doc_491521501788_item	2495391	et	3	main
lisada	doc_491521501788_item	2495394	et	3	main
kudosan	doc_491521501788_item	2495397	et	4	main
vaid	doc_491521501788_item	2495434	et	3	main
opetada	doc_491521501788_item	2495443	et	4	main
keelt	doc_491521501788_item	2495445	et	4	main
ning	doc_491521501788_item	2495446	et	3	main
tulevikus	doc_491521501788_item	2495447	et	4	main
basil	doc_491521501788_item	2495449	et	4	main
valja	doc_491521501788_item	2495450	et	3	main
tootada	doc_491521501788_item	2495451	et	4	main
vastased	doc_491521501788_item	2495457	et	3	main
leksikaalsed	doc_491521501788_item	2495460	et	3	main
moksa	doc_491521501788_item	2495466	et	4	main
keeles	doc_491521501788_item	2495467	et	4	main
nadkin	doc_491521501787_item	2495075	et	4	main
pahaks	doc_491521501787_item	2495082	et	4	main
mordva	doc_491521501787_item	2495085	et	3	main
mordovia	doc_491521501787_item	2495087	et	4	main
emakeele	doc_491521501787_item	2495106	et	4	main
mastori	doc_491521501787_item	2495113	et	4	main
uhingu	doc_491521501787_item	2495114	et	4	main
normist	doc_491521501787_item	2495144	et	4	main
deklaratsioon	doc_491521501787_item	2495151	et	3	main
1990	doc_491521501787_item	2495153	et	2	main
riigikeeltena	doc_491521501787_item	2495163	et	3	main
paraku	doc_491521501787_item	2495164	et	3	main
keeleseaduse	doc_491521501787_item	2495169	et	3	main
kaugemale	doc_491521501787_item	2495173	et	4	main
kahele	doc_491521501787_item	2495177	et	4	main
sattele	doc_491521501787_item	2495178	et	4	main
ope	doc_491521501787_item	2495182	et	4	main
koolides	doc_491521501787_item	2495184	et	3	main
uhe	doc_491521501787_item	2495186	et	4	main
mordva	doc_491521501787_item	2495195	et	3	main
oli	doc_491521501787_item	2495196	et	3	main
ainus	doc_491521501787_item	2495197	et	4	main
soomeugri	doc_491521501787_item	2495198	et	4	main
vabariik	doc_491521501787_item	2495199	et	3	main
ei	doc_491521501787_item	2495201	et	4	main
mis	doc_491521501787_item	2495200	et	4	main
kuulutanud	doc_491521501787_item	2495202	et	4	main
end	doc_491521501787_item	2495203	et	4	main
suveraanseks	doc_491521501787_item	2495204	et	4	main
otsesed	doc_491521501787_item	2495205	et	3	main
presidendivalimised	doc_491521501787_item	2495206	et	3	main
detsembris	doc_491521501787_item	2495207	et	3	main
1991	doc_491521501787_item	2495208	et	2	main
voitis	doc_491521501787_item	2495209	et	4	main
noor	doc_491521501787_item	2495210	et	3	main
venelane	doc_491521501787_item	2495211	et	3	main
vassili	doc_491521501787_item	2495212	et	4	main
gusljannikov	doc_491521501787_item	2495213	et	4	main
kes	doc_491521501787_item	2495214	et	4	main
majanduskusimustes	doc_491521501787_item	2495215	et	4	main
oli	doc_491521501787_item	2495216	et	3	main
liberaal	doc_491521501787_item	2495217	et	3	main
rahvuskusimustes	doc_491521501787_item	2495218	et	4	main
aga	doc_491521501787_item	2495219	et	3	main
reaktsionaar	doc_491521501787_item	2495220	et	4	main
ajalehed	doc_491521501788_item	2495233	et	3	main
mastor	doc_491521501788_item	2495239	et	4	main
moksakeelne	doc_491521501788_item	2495240	et	4	main
kogusid	doc_491521501788_item	2495247	et	4	main
eriti	doc_491521501788_item	2495250	et	3	main
mordva	doc_491521501788_item	2495257	et	3	main
laanemeresoome	doc_491521501788_item	2495282	et	3	main
on	doc_491521501788_item	2495284	et	4	main
keeled	doc_491521501788_item	2495288	et	3	main
meelest	doc_491521501788_item	2495290	et	4	main
mordva	doc_491521501788_item	2495292	et	3	main
keeltest	doc_491521501788_item	2495293	et	4	main
ligemadmoned	doc_491521501788_item	2495294	et	4	main
sona	doc_491521501788_item	2495310	et	4	main
esineb	doc_491521501788_item	2495315	et	3	main
ka	doc_491521501788_item	2495317	et	3	main
uhendeid	doc_491521501788_item	2495319	et	4	main
riigiteenistuses	doc_491521501787_item	2495190	et	3	main
eeltingimusena	doc_491521501787_item	2495192	et	3	main
1995	doc_491521501787_item	2495194	et	2	main
on	doc_491521501788_item	2495226	et	4	main
mordvalastel	doc_491521501788_item	2495227	et	3	main
ilukirjandus	doc_491521501788_item	2495231	et	3	main
naiteks	doc_491521501788_item	2495236	et	4	main
on	doc_491521501788_item	2495242	et	4	main
rohkesti	doc_491521501788_item	2495243	et	3	main
rahvaluulet	doc_491521501788_item	2495244	et	3	main
mida	doc_491521501788_item	2495245	et	4	main
uurisid	doc_491521501788_item	2495249	et	4	main
seda	doc_491521501788_item	2495254	et	3	main
suure	doc_491521501788_item	2495255	et	3	main
keele	doc_491521501788_item	2495295	et	4	main
omaparad	doc_491521501788_item	2495296	et	4	main
seda	doc_491521501788_item	2495301	et	3	main
teise	doc_491521501788_item	2495305	et	4	main
alguses	doc_491521501788_item	2495311	et	4	main
kuid	doc_491521501788_item	2495314	et	4	main
raud	doc_491521501788_item	2495321	et	3	main
sona	doc_491521501788_item	2495327	et	4	main
ersa	doc_491521501788_item	2495331	et	4	main
kaanet	doc_491521501788_item	2495339	et	4	main
jargsonad	doc_491521501788_item	2495345	et	4	main
kipuvad	doc_491521501788_item	2495346	et	3	main
possessivdeklinatsioon	doc_491521501788_item	2495357	et	4	main
see	doc_491521501788_item	2495363	et	3	main
eesti	doc_491521501788_item	2495365	et	4	main
rohkesti	doc_491521501788_item	2495373	et	3	main
soovov	doc_491521501788_item	2495382	et	4	main
kolm	doc_491521501788_item	2495385	et	3	main
kudosat	doc_491521501788_item	2495400	et	4	main
on	doc_491521501788_item	2495421	et	4	main
ulesanne	doc_491521501788_item	2495423	et	4	main
kirjanikud	doc_491521501788_item	2495438	et	3	main
molemat	doc_491521501788_item	2495444	et	4	main
uhtsed	doc_491521501788_item	2495452	et	4	main
pohjenduseks	doc_491521501788_item	2495459	et	4	main
ja	doc_491521501788_item	2495234	et	3	main
minevikus	doc_491521501788_item	2495246	et	3	main
soomlased	doc_491521501788_item	2495251	et	3	main
keeleteadlane	doc_491521501788_item	2495261	et	3	main
folklorist	doc_491521501788_item	2495262	et	4	main
ja	doc_491521501788_item	2495263	et	3	main
etnograf	doc_491521501788_item	2495264	et	4	main
oli	doc_491521501788_item	2495265	et	3	main
ulikooli	doc_491521501788_item	2495267	et	4	main
professor	doc_491521501788_item	2495268	et	3	main
kaasani	doc_491521501788_item	2495266	et	3	main
m	doc_491521501788_item	2495269	et	4	main
jevsevjev1864	doc_491521501788_item	2495270	et	4	main
1931	doc_491521501788_item	2495271	et	2	main
keelelt	doc_491521501788_item	2495273	et	4	main
on	doc_491521501788_item	2495274	et	4	main
keel	doc_491521501788_item	2495272	et	4	main
ersad	doc_491521501788_item	2495275	et	4	main
eestlastele	doc_491521501788_item	2495276	et	4	main
lahedased	doc_491521501788_item	2495277	et	4	main
lisaks	doc_491521501788_item	2495278	et	4	main
some	doc_491521501788_item	2495279	et	4	main
ainult	doc_491521501788_item	2495285	et	4	main
saami	doc_491521501788_item	2495286	et	4	main
jargmised	doc_491521501788_item	2495298	et	4	main
vaheldub	doc_491521501788_item	2495300	et	3	main
esimese	doc_491521501788_item	2495303	et	3	main
siiski	doc_491521501788_item	2495316	et	4	main
kolmekordseid	doc_491521501788_item	2495318	et	3	main
ksni	doc_491521501788_item	2495320	et	4	main
on	doc_491521501788_item	2495324	et	4	main
palju	doc_491521501788_item	2495325	et	4	main
eriti	doc_491521501788_item	2495326	et	3	main
keeles	doc_491521501788_item	2495332	et	4	main
mitte	doc_491521501788_item	2495334	et	3	main
10	doc_491521501788_item	2495338	et	2	main
ja	doc_491521501788_item	2495340	et	3	main
rohkemgi	doc_491521501788_item	2495342	et	4	main
moned	doc_491521501788_item	2495344	et	4	main
nimisonadega	doc_491521501788_item	2495347	et	4	main
deklinatsiooni	doc_491521501788_item	2495353	et	4	main
maaratud	doc_491521501788_item	2495355	et	4	main
erineb	doc_491521501788_item	2495364	et	3	main
keelest	doc_491521501788_item	2495368	et	4	main
ja	doc_491521501788_item	2495369	et	3	main
sarnaneb	doc_491521501788_item	2495370	et	3	main
ungarile	doc_491521501788_item	2495371	et	4	main
ja	doc_491521501788_item	2495384	et	3	main
tingivat	doc_491521501788_item	2495386	et	4	main
eitussona	doc_491521501788_item	2495388	et	4	main
esineb	doc_491521501788_item	2495389	et	3	main
poordeloppe	doc_491521501788_item	2495392	et	4	main
saab	doc_491521501788_item	2495393	et	3	main
kodus-olen	doc_491521501788_item	2495398	et	3	main
alguses	doc_491521501788_item	2495328	et	4	main
nimisonul	doc_491521501788_item	2495335	et	4	main
olla	doc_491521501788_item	2495337	et	3	main
keeles	doc_491521501788_item	2495350	et	4	main
maaramata	doc_491521501788_item	2495354	et	4	main
ei	doc_491521501788_item	2495361	et	4	main
some	doc_491521501788_item	2495367	et	4	main
koneviise	doc_491521501788_item	2495374	et	4	main
kindle	doc_491521501788_item	2495376	et	4	main
kaskiv	doc_491521501788_item	2495378	et	4	main
ka	doc_491521501788_item	2495381	et	3	main
koneviisi	doc_491521501788_item	2495387	et	4	main
ainult	doc_491521501788_item	2495390	et	4	main
ka	doc_491521501788_item	2495395	et	3	main
ja	doc_491521501788_item	2495399	et	3	main
praegu	doc_491521501788_item	2495402	et	3	main
ersade	doc_491521501788_item	2495403	et	4	main
ja	doc_491521501788_item	2495404	et	3	main
moksade	doc_491521501788_item	2495405	et	4	main
teadvusse	doc_491521501788_item	2495406	et	4	main
juurutakse	doc_491521501788_item	2495407	et	4	main
motet	doc_491521501788_item	2495408	et	4	main
uhismordva	doc_491521501788_item	2495409	et	4	main
keelele	doc_491521501788_item	2495410	et	4	main
ulemineku	doc_491521501788_item	2495411	et	4	main
voimalikkusest	doc_491521501788_item	2495412	et	4	main
uhe	doc_491521501788_item	2495413	et	4	main
keele	doc_491521501788_item	2495414	et	4	main
pooldajad	doc_491521501788_item	2495415	et	4	main
arvavad	doc_491521501788_item	2495416	et	4	main
et	doc_491521501788_item	2495417	et	3	main
uhtse	doc_491521501788_item	2495418	et	4	main
kirjakeele	doc_491521501788_item	2495419	et	4	main
loomine	doc_491521501788_item	2495420	et	4	main
tahtis	doc_491521501788_item	2495422	et	3	main
mille	doc_491521501788_item	2495424	et	3	main
kaisolev	doc_491521501788_item	2495429	et	4	main
polvkond	doc_491521501788_item	2495430	et	4	main
mitte	doc_491521501788_item	2495431	et	3	main
keeleteadlased	doc_491521501788_item	2495433	et	3	main
ka	doc_491521501788_item	2495435	et	3	main
ja	doc_491521501788_item	2495437	et	3	main
kirjandusteadlased	doc_491521501788_item	2495439	et	3	main
mordvalastele	doc_491521501788_item	2495441	et	3	main
uhtse	doc_491521501788_item	2495455	et	4	main
toovad	doc_491521501788_item	2495458	et	4	main
vastavalt	doc_491521501788_item	2495468	et	4	main
koduloolased	doc_491521501788_item	2495440	et	3	main
tuleb	doc_491521501788_item	2495442	et	3	main
nende	doc_491521501788_item	2495448	et	4	main
normid	doc_491521501788_item	2495454	et	4	main
keele	doc_491521501788_item	2495456	et	4	main
nagu	doc_491521501788_item	2495462	et	3	main
puder	doc_491521501788_item	2495469	et	3	main
ja	doc_491521501788_item	2495470	et	3	main
kapsasupp	doc_491521501788_item	2495471	et	3	main
ersa	doc_491521501788_item	2495472	et	4	main
keeles	doc_491521501788_item	2495473	et	4	main
on	doc_491521501788_item	2495474	et	4	main
esimene	doc_491521501788_item	2495475	et	3	main
supp	doc_491521501788_item	2495476	et	3	main
kutsju	doc_491521501788_item	2495477	et	4	main
pents	doc_491521501788_item	2495478	et	4	main
lusikas	doc_491521501788_item	2495479	et	4	main
erinevusi	doc_491521501788_item	2495461	et	4	main
naiteks	doc_491521501788_item	2495463	et	4	main
jam	doc_491521501788_item	2495464	et	4	main
ljam	doc_491521501788_item	2495465	et	4	main
analüüs	doc_491521501790_item	2495682	et	3	main
teksti	doc_491521501790_item	2495685	et	4	main
on	doc_491521501790_item	2495687	et	4	main
sellele	doc_491521501790_item	2495695	et	4	main
selles	doc_491521501790_item	2495698	et	4	main
toimub	doc_491521501790_item	2495700	et	3	main
et	doc_491521501790_item	2495712	et	3	main
hispaania	doc_491521501790_item	2495713	et	4	main
peaminister	doc_491521501790_item	2495714	et	3	main
korraldas	doc_491521501790_item	2495715	et	3	main
autor	doc_491521501790_item	2495722	et	3	main
mõeldud	doc_491521501790_item	2495738	et	4	main
tavalisele	doc_491521501790_item	2495739	et	4	main
lugejaskonnale	doc_491521501790_item	2495740	et	3	main
stiilis	doc_491521501790_item	2495758	et	4	main
artikli	doc_491521501790_item	2495765	et	3	main
on	doc_491521501790_item	2495767	et	4	main
kus	doc_491521501790_item	2495771	et	3	main
sellest	doc_491521501790_item	2495773	et	4	main
hirmutavast	doc_491521501790_item	2495774	et	4	main
on	doc_491521501790_item	2495786	et	4	main
toonud	doc_491521501790_item	2495787	et	4	main
on	doc_491521501790_item	2495790	et	4	main
lugejat	doc_491521501790_item	2495798	et	4	main
oma	doc_491521501790_item	2495805	et	4	main
kavatsenud	doc_491521501790_item	2495820	et	4	main
jõutakse	doc_491521501790_item	2495822	et	4	main
punkt	doc_491521501790_item	2495826	et	4	main
tema	doc_491521501790_item	2495827	et	4	main
valitsusajale	doc_491521501790_item	2495828	et	3	main
näiteid	doc_491521501790_item	2495830	et	3	main
kes	doc_491521501790_item	2495844	et	4	main
autor	doc_491521501790_item	2495857	et	3	main
tegu	doc_491521501790_item	2495862	et	4	main
küljest	doc_491521501790_item	2495864	et	4	main
nt	doc_491521501790_item	2495874	et	4	main
pulmad	doc_491521501790_item	2495878	et	3	main
ole	doc_491521501790_item	2495881	et	4	main
pole	doc_491521501790_item	2495893	et	3	main
keerulised	doc_491521501790_item	2495895	et	4	main
eesmärk	doc_491521501790_item	2495897	et	3	main
on	doc_491521501790_item	2495898	et	4	main
panna	doc_491521501790_item	2495899	et	4	main
mõjutada	doc_491521501790_item	2495909	et	3	main
mulle	doc_491521501790_item	2495913	et	4	main
tundub	doc_491521501790_item	2495914	et	3	main
tegemist	doc_491521501790_item	2495922	et	4	main
on	doc_491521501790_item	2495923	et	4	main
tavalise	doc_491521501790_item	2495924	et	4	main
artikliga	doc_491521501790_item	2495925	et	3	main
ei	doc_491521501790_item	2495930	et	4	main
ajakirjandusteksti	doc_491521501790_item	2495683	et	4	main
pealkirjaks	doc_491521501790_item	2495686	et	3	main
ühe	doc_491521501790_item	2495689	et	4	main
ajastu	doc_491521501790_item	2495690	et	4	main
lõpp	doc_491521501790_item	2495691	et	3	main
mis	doc_491521501790_item	2495692	et	4	main
et	doc_491521501790_item	2495696	et	3	main
artiklis	doc_491521501790_item	2495699	et	3	main
muutus	doc_491521501790_item	2495702	et	4	main
mis	doc_491521501790_item	2495703	et	4	main
oma	doc_491521501790_item	2495716	et	4	main
tütrele	doc_491521501790_item	2495717	et	3	main
viitab	doc_491521501790_item	2495694	et	3	main
võib	doc_491521501790_item	2495704	et	3	main
teatud	doc_491521501790_item	2495707	et	4	main
ajastu	doc_491521501790_item	2495708	et	4	main
alapealkirjast	doc_491521501790_item	2495709	et	4	main
sellega	doc_491521501790_item	2495720	et	3	main
mõtlema	doc_491521501790_item	2495724	et	3	main
sest	doc_491521501790_item	2495741	et	4	main
poolt	doc_491521501790_item	2495744	et	4	main
maailmast	doc_491521501790_item	2495746	et	4	main
teiselt	doc_491521501790_item	2495747	et	4	main
ning	doc_491521501790_item	2495759	et	3	main
endast	doc_491521501790_item	2495761	et	4	main
ja	doc_491521501790_item	2495763	et	3	main
teema	doc_491521501790_item	2495777	et	4	main
selles	doc_491521501790_item	2495795	et	4	main
artiklis	doc_491521501790_item	2495796	et	3	main
suunatakse	doc_491521501790_item	2495797	et	4	main
analüüs	doc_491521501790_item	2495684	et	3	main
kas	doc_491521501790_item	2495688	et	3	main
arvatavasti	doc_491521501790_item	2495697	et	3	main
mingisugune	doc_491521501790_item	2495701	et	3	main
ühe	doc_491521501790_item	2495706	et	4	main
grandioossed	doc_491521501790_item	2495718	et	3	main
pulmad	doc_491521501790_item	2495719	et	3	main
paneb	doc_491521501790_item	2495721	et	3	main
juhtivisiku	doc_491521501790_item	2495728	et	3	main
tegevus	doc_491521501790_item	2495730	et	4	main
õige	doc_491521501790_item	2495732	et	4	main
minu	doc_491521501790_item	2495733	et	3	main
arvates	doc_491521501790_item	2495734	et	4	main
on	doc_491521501790_item	2495735	et	4	main
see	doc_491521501790_item	2495736	et	3	main
artikkel	doc_491521501790_item	2495737	et	3	main
see	doc_491521501790_item	2495742	et	3	main
selle	doc_491521501790_item	2495750	et	4	main
publitsistlikus	doc_491521501790_item	2495757	et	4	main
arvamust	doc_491521501790_item	2495762	et	3	main
olemaslugu	doc_491521501790_item	2495764	et	4	main
kompositsioon	doc_491521501790_item	2495766	et	4	main
kultuurist	doc_491521501790_item	2495776	et	3	main
mis	doc_491521501790_item	2495779	et	4	main
kirjeldatud	doc_491521501790_item	2495782	et	4	main
ning	doc_491521501790_item	2495783	et	3	main
kokkuvõte	doc_491521501790_item	2495784	et	3	main
kus	doc_491521501790_item	2495785	et	3	main
loogiliselt	doc_491521501790_item	2495794	et	4	main
et	doc_491521501790_item	2495800	et	3	main
valesti	doc_491521501790_item	2495803	et	3	main
nii	doc_491521501790_item	2495807	et	3	main
pulmad	doc_491521501790_item	2495809	et	3	main
kohe	doc_491521501790_item	2495693	et	4	main
lõpetada	doc_491521501790_item	2495705	et	3	main
saame	doc_491521501790_item	2495710	et	4	main
teada	doc_491521501790_item	2495711	et	3	main
lugeja	doc_491521501790_item	2495723	et	4	main
kas	doc_491521501790_item	2495727	et	3	main
taoline	doc_491521501790_item	2495729	et	3	main
mõju	doc_491521501790_item	2495751	et	4	main
kujutab	doc_491521501790_item	2495760	et	3	main
tavaline	doc_491521501790_item	2495769	et	4	main
sissejuhatus	doc_491521501790_item	2495770	et	4	main
räägitakse	doc_491521501790_item	2495772	et	3	main
lõigud	doc_491521501790_item	2495789	et	4	main
seotud	doc_491521501790_item	2495791	et	4	main
sisuliselt	doc_491521501790_item	2495792	et	4	main
väga	doc_491521501790_item	2495793	et	3	main
sellele	doc_491521501790_item	2495799	et	4	main
korraldades	doc_491521501790_item	2495804	et	3	main
ta	doc_491521501790_item	2495810	et	4	main
teha	doc_491521501790_item	2495813	et	3	main
et	doc_491521501790_item	2495815	et	3	main
enam	doc_491521501790_item	2495817	et	4	main
kandideerida	doc_491521501790_item	2495818	et	3	main
ei	doc_491521501790_item	2495819	et	4	main
oli	doc_491521501790_item	2495825	et	3	main
läks	doc_491521501790_item	2495841	et	3	main
kus	doc_491521501790_item	2495848	et	3	main
püüab	doc_491521501790_item	2495858	et	3	main
kasutatud	doc_491521501790_item	2495865	et	4	main
sõnad	doc_491521501790_item	2495866	et	4	main
on	doc_491521501790_item	2495867	et	4	main
üsna	doc_491521501790_item	2495868	et	3	main
lihtsad	doc_491521501790_item	2495869	et	3	main
aga	doc_491521501790_item	2495870	et	3	main
mõned	doc_491521501790_item	2495871	et	3	main
keelestruktuurid	doc_491521501790_item	2495892	et	3	main
nii	doc_491521501790_item	2495894	et	3	main
selle	doc_491521501790_item	2495902	et	4	main
isiklikud	doc_491521501790_item	2495906	et	3	main
asjad	doc_491521501790_item	2495907	et	3	main
demagoogiat	doc_491521501790_item	2495935	et	3	main
deklaratiivsust	doc_491521501790_item	2495937	et	4	main
tekst	doc_491521501790_item	2495941	et	3	main
maailmas	doc_491521501790_item	2495950	et	3	main
toimuvate	doc_491521501790_item	2495951	et	4	main
palju	doc_491521501791_item	2495982	et	4	main
arutatakse	doc_491521501791_item	2495983	et	3	main
tv-programmides	doc_491521501791_item	2495984	et	4	main
on	doc_491521501791_item	2495989	et	4	main
teisi	doc_491521501791_item	2495996	et	4	main
midagi	doc_491521501791_item	2496008	et	4	main
vägivald	doc_491521501791_item	2496009	et	3	main
hirmutav	doc_491521501791_item	2496012	et	4	main
see	doc_491521501791_item	2496023	et	3	main
vägivald	doc_491521501791_item	2496026	et	3	main
tehti	doc_491521501791_item	2496032	et	3	main
hirmsat	doc_491521501791_item	2496034	et	3	main
ei	doc_491521501791_item	2496040	et	4	main
vastu	doc_491521501791_item	2496043	et	3	main
on	doc_491521501791_item	2496055	et	4	main
üks	doc_491521501791_item	2496056	et	3	main
sünnib	doc_491521501791_item	2496060	et	3	main
tekib	doc_491521501791_item	2496082	et	3	main
ei	doc_491521501791_item	2496086	et	4	main
üks	doc_491521501791_item	2496090	et	3	main
hakkab	doc_491521501791_item	2496091	et	3	main
lõppeda	doc_491521501791_item	2496100	et	3	main
juhul	doc_491521501791_item	2496102	et	3	main
inimene	doc_491521501791_item	2496104	et	3	main
teist	doc_491521501791_item	2496107	et	4	main
selle	doc_491521501790_item	2495725	et	4	main
üle	doc_491521501790_item	2495726	et	3	main
oli	doc_491521501790_item	2495731	et	3	main
ühelt	doc_491521501790_item	2495743	et	3	main
uudist	doc_491521501790_item	2495745	et	3	main
poolt	doc_491521501790_item	2495748	et	4	main
aga	doc_491521501790_item	2495749	et	3	main
kohalikule	doc_491521501790_item	2495752	et	3	main
ühiskonnale	doc_491521501790_item	2495753	et	4	main
tekst	doc_491521501790_item	2495754	et	3	main
on	doc_491521501790_item	2495755	et	4	main
kirjutatud	doc_491521501790_item	2495756	et	4	main
üsna	doc_491521501790_item	2495768	et	3	main
näitest	doc_491521501790_item	2495775	et	4	main
arendus	doc_491521501790_item	2495778	et	4	main
on	doc_491521501790_item	2495780	et	4	main
põhjalikult	doc_491521501790_item	2495781	et	4	main
järeldused	doc_491521501790_item	2495788	et	4	main
peaminister	doc_491521501790_item	2495801	et	3	main
uhked	doc_491521501790_item	2495808	et	4	main
seda	doc_491521501790_item	2495812	et	3	main
ta	doc_491521501790_item	2495816	et	4	main
põhiideeni	doc_491521501790_item	2495821	et	3	main
otseselt	doc_491521501790_item	2495823	et	4	main
see	doc_491521501790_item	2495824	et	3	main
on	doc_491521501790_item	2495835	et	4	main
seotud	doc_491521501790_item	2495836	et	4	main
sellega	doc_491521501790_item	2495837	et	3	main
kui	doc_491521501790_item	2495838	et	3	main
seal	doc_491521501790_item	2495845	et	4	main
ja	doc_491521501790_item	2495847	et	3	main
seda	doc_491521501790_item	2495849	et	3	main
näidata	doc_491521501790_item	2495860	et	4	main
negatiivselt	doc_491521501790_item	2495863	et	4	main
irooniat	doc_491521501790_item	2495873	et	3	main
või	doc_491521501790_item	2495876	et	4	main
ei	doc_491521501790_item	2495880	et	4	main
pikad	doc_491521501790_item	2495883	et	4	main
need	doc_491521501790_item	2495884	et	3	main
on	doc_491521501790_item	2495885	et	4	main
kergesti	doc_491521501790_item	2495886	et	3	main
jälgitavad	doc_491521501790_item	2495887	et	4	main
kõrvallaused	doc_491521501790_item	2495888	et	3	main
teksti	doc_491521501790_item	2495896	et	4	main
üle	doc_491521501790_item	2495903	et	3	main
peaministri	doc_491521501790_item	2495905	et	3	main
tema	doc_491521501790_item	2495910	et	4	main
staatust	doc_491521501790_item	2495912	et	3	main
autor	doc_491521501790_item	2495916	et	3	main
eesmärgi	doc_491521501790_item	2495918	et	4	main
on	doc_491521501790_item	2495919	et	4	main
hästi	doc_491521501790_item	2495920	et	3	main
käitus	doc_491521501790_item	2495802	et	4	main
tütrele	doc_491521501790_item	2495806	et	3	main
julges	doc_491521501790_item	2495811	et	4	main
sellepärast	doc_491521501790_item	2495814	et	3	main
palju	doc_491521501790_item	2495839	et	4	main
raha	doc_491521501790_item	2495840	et	4	main
pulmadele	doc_491521501790_item	2495843	et	3	main
oli	doc_491521501790_item	2495846	et	3	main
lugejale	doc_491521501790_item	2495859	et	4	main
grandioossed	doc_491521501790_item	2495875	et	3	main
laused	doc_491521501790_item	2495879	et	3	main
väga	doc_491521501790_item	2495882	et	3	main
palju	doc_491521501790_item	2495891	et	4	main
lugejat	doc_491521501790_item	2495900	et	4	main
mõtlema	doc_491521501790_item	2495901	et	3	main
kuidas	doc_491521501790_item	2495904	et	3	main
võivad	doc_491521501790_item	2495908	et	4	main
poliitilist	doc_491521501790_item	2495911	et	3	main
et	doc_491521501790_item	2495915	et	3	main
oma	doc_491521501790_item	2495917	et	4	main
on	doc_491521501790_item	2495927	et	4	main
kõike	doc_491521501790_item	2495928	et	4	main
ega	doc_491521501790_item	2495933	et	3	main
mind	doc_491521501790_item	2495944	et	4	main
infot	doc_491521501790_item	2495949	et	3	main
kohta	doc_491521501790_item	2495953	et	4	main
avardab	doc_491521501790_item	2495954	et	3	main
silmaringi	doc_491521501790_item	2495955	et	4	main
aga	doc_491521501790_item	2495956	et	3	main
mul	doc_491521501790_item	2495957	et	3	main
on	doc_491521501790_item	2495958	et	4	main
sellest	doc_491521501791_item	2495979	et	4	main
ning	doc_491521501791_item	2495994	et	3	main
aidata	doc_491521501791_item	2495997	et	4	main
nõuannetega	doc_491521501791_item	2495999	et	3	main
räägitakse	doc_491521501791_item	2496001	et	3	main
sest	doc_491521501791_item	2496018	et	4	main
see	doc_491521501791_item	2496019	et	3	main
alati	doc_491521501791_item	2496020	et	4	main
ministeeriumis	doc_491521501790_item	2495829	et	3	main
on	doc_491521501790_item	2495831	et	4	main
tekstis	doc_491521501790_item	2495832	et	3	main
piisavalt	doc_491521501790_item	2495833	et	4	main
need	doc_491521501790_item	2495834	et	3	main
maksma	doc_491521501790_item	2495842	et	3	main
peeti	doc_491521501790_item	2495850	et	4	main
nad	doc_491521501790_item	2495851	et	3	main
sobivad	doc_491521501790_item	2495852	et	4	main
siia	doc_491521501790_item	2495853	et	4	main
sest	doc_491521501790_item	2495856	et	4	main
päris	doc_491521501790_item	2495854	et	4	main
hästi	doc_491521501790_item	2495855	et	3	main
peaministri	doc_491521501790_item	2495861	et	3	main
sisaldavad	doc_491521501790_item	2495872	et	4	main
kuninglikud	doc_491521501790_item	2495877	et	3	main
ei	doc_491521501790_item	2495889	et	4	main
ole	doc_491521501790_item	2495890	et	4	main
siin	doc_491521501790_item	2495926	et	4	main
ole	doc_491521501790_item	2495931	et	4	main
lünklikkust	doc_491521501790_item	2495932	et	4	main
võõrsõnu	doc_491521501790_item	2495938	et	3	main
see	doc_491521501790_item	2495940	et	3	main
lihtsalt	doc_491521501790_item	2495947	et	4	main
alati	doc_491521501790_item	2495959	et	4	main
huvitav	doc_491521501790_item	2495960	et	4	main
lugeda	doc_491521501790_item	2495961	et	3	main
selliseid	doc_491521501790_item	2495962	et	4	main
väga	doc_491521501791_item	2495981	et	3	main
koolis	doc_491521501791_item	2495985	et	4	main
inimesed	doc_491521501791_item	2495988	et	3	main
sellest	doc_491521501791_item	2496002	et	4	main
küll	doc_491521501791_item	2496003	et	4	main
peaasi	doc_491521501791_item	2496004	et	3	main
tõeliselt	doc_491521501791_item	2496011	et	4	main
saa	doc_491521501791_item	2496016	et	4	main
olla	doc_491521501791_item	2496017	et	3	main
et	doc_491521501791_item	2496025	et	3	main
teise	doc_491521501791_item	2496028	et	4	main
ja	doc_491521501791_item	2496038	et	3	main
sees	doc_491521501791_item	2496048	et	4	main
kaasnähtusest	doc_491521501791_item	2496057	et	4	main
vägivald	doc_491521501791_item	2496081	et	3	main
siis	doc_491521501791_item	2496083	et	3	main
vihata	doc_491521501791_item	2496093	et	4	main
nõrk	doc_491521501791_item	2496110	et	3	main
tahab	doc_491521501791_item	2496112	et	3	main
tõestada	doc_491521501791_item	2496114	et	3	main
selline	doc_491521501791_item	2496120	et	4	main
teine	doc_491521501791_item	2496121	et	3	main
peab	doc_491521501791_item	2496123	et	4	main
inimesed	doc_491521501791_item	2496128	et	3	main
ei	doc_491521501791_item	2496129	et	4	main
ole	doc_491521501791_item	2496130	et	4	main
tea	doc_491521501791_item	2496141	et	4	main
mis	doc_491521501791_item	2496142	et	4	main
teha	doc_491521501791_item	2496143	et	3	main
ja	doc_491521501791_item	2496144	et	3	main
kuhu	doc_491521501791_item	2496145	et	3	main
minna	doc_491521501791_item	2496146	et	3	main
sel	doc_491521501791_item	2496147	et	3	main
juhul	doc_491521501791_item	2496148	et	3	main
peab	doc_491521501791_item	2496149	et	4	main
asi	doc_491521501791_item	2496156	et	4	main
pöörduma	doc_491521501791_item	2496161	et	3	main
nemad	doc_491521501791_item	2496163	et	3	main
mina	doc_491521501791_item	2496173	et	4	main
mõtlen	doc_491521501791_item	2496174	et	3	main
et	doc_491521501791_item	2496175	et	3	main
vägivald	doc_491521501791_item	2496176	et	3	main
algab	doc_491521501791_item	2496177	et	3	main
tihti	doc_491521501791_item	2496178	et	3	main
koolis	doc_491521501791_item	2496179	et	4	main
ning	doc_491521501791_item	2496184	et	3	main
täitnud	doc_491521501790_item	2495921	et	4	main
piisavalt	doc_491521501790_item	2495929	et	4	main
jne	doc_491521501790_item	2495939	et	4	main
ei	doc_491521501790_item	2495942	et	4	main
puuduta	doc_491521501790_item	2495943	et	4	main
annab	doc_491521501790_item	2495948	et	3	main
sündmuste	doc_491521501790_item	2495952	et	3	main
põnevaid	doc_491521501790_item	2495963	et	3	main
lugusid	doc_491521501790_item	2495964	et	3	main
vägivald	doc_491521501791_item	2495965	et	3	main
sünnitab	doc_491521501791_item	2495966	et	3	main
vägivalda	doc_491521501791_item	2495967	et	4	main
kirjand	doc_491521501791_item	2495968	et	3	main
vägivald	doc_491521501791_item	2495969	et	3	main
sünnitab	doc_491521501791_item	2495970	et	3	main
vägivalda	doc_491521501791_item	2495971	et	4	main
tänapäeval	doc_491521501791_item	2495972	et	3	main
me	doc_491521501791_item	2495973	et	4	main
väga	doc_491521501791_item	2495974	et	3	main
tihti	doc_491521501791_item	2495975	et	3	main
kuuleme	doc_491521501791_item	2495976	et	3	main
sõna	doc_491521501791_item	2495977	et	4	main
vägivald	doc_491521501791_item	2495978	et	3	main
liiasust	doc_491521501790_item	2495934	et	4	main
või	doc_491521501790_item	2495936	et	4	main
otseselt	doc_491521501790_item	2495945	et	4	main
vaid	doc_491521501790_item	2495946	et	3	main
jne	doc_491521501791_item	2495986	et	4	main
nähtust	doc_491521501791_item	2495991	et	4	main
elanud	doc_491521501791_item	2495993	et	4	main
et	doc_491521501791_item	2496005	et	3	main
teeks	doc_491521501791_item	2496006	et	4	main
ka	doc_491521501791_item	2496007	et	3	main
see	doc_491521501791_item	2496014	et	3	main
kaasakõrvalmõjusid	doc_491521501791_item	2496022	et	4	main
tähendab	doc_491521501791_item	2496024	et	3	main
vägivalda	doc_491521501791_item	2496029	et	4	main
sind	doc_491521501791_item	2496036	et	4	main
selle	doc_491521501791_item	2496042	et	4	main
vihkamine	doc_491521501791_item	2496054	et	4	main
see	doc_491521501791_item	2496062	et	3	main
teist	doc_491521501791_item	2496092	et	4	main
vihastest	doc_491521501791_item	2496097	et	4	main
kas	doc_491521501791_item	2496105	et	3	main
tõenäoliselt	doc_491521501791_item	2496109	et	4	main
ta	doc_491521501791_item	2496119	et	4	main
tugevad	doc_491521501791_item	2496131	et	4	main
et	doc_491521501791_item	2496133	et	3	main
või	doc_491521501791_item	2496151	et	4	main
kindlasti	doc_491521501791_item	2496153	et	3	main
aga	doc_491521501791_item	2496158	et	3	main
sellega	doc_491521501791_item	2496165	et	3	main
on	doc_491521501791_item	2496168	et	4	main
ainult	doc_491521501791_item	2496182	et	4	main
vägivald	doc_491521501791_item	2496222	et	3	main
levinud	doc_491521501791_item	2496224	et	4	main
praegu	doc_491521501791_item	2496225	et	3	main
see	doc_491521501791_item	2496228	et	3	main
sõltub	doc_491521501791_item	2496229	et	3	main
vist	doc_491521501791_item	2496230	et	4	main
eluarenemisest	doc_491521501791_item	2496232	et	3	main
selline	doc_491521501791_item	2496243	et	4	main
peab	doc_491521501791_item	2496254	et	4	main
keegi	doc_491521501791_item	2496257	et	4	main
tea	doc_491521501791_item	2496259	et	4	main
mis	doc_491521501791_item	2496260	et	4	main
homme	doc_491521501791_item	2496261	et	3	main
juhtub	doc_491521501791_item	2496262	et	3	main
tahaks	doc_491521501791_item	2496263	et	3	main
ära	doc_491521501791_item	2496271	et	4	main
alati	doc_491521501791_item	2496277	et	4	main
ela	doc_491521501791_item	2496280	et	4	main
surnud	doc_491521501791_item	2496283	et	4	main
essee	doc_491521501792_item	2496284	et	4	main
ma	doc_491521501792_item	2496285	et	3	main
olen	doc_491521501792_item	2496286	et	3	main
on	doc_491521501792_item	2496294	et	4	main
koolivorm	doc_491521501792_item	2496295	et	3	main
siis	doc_491521501792_item	2496296	et	3	main
ei	doc_491521501792_item	2496303	et	4	main
kalleid	doc_491521501792_item	2496308	et	3	main
lapsed	doc_491521501792_item	2496312	et	3	main
hommikul	doc_491521501792_item	2496323	et	3	main
koolivorm	doc_491521501792_item	2496329	et	3	main
ja	doc_491521501792_item	2496333	et	3	main
mugava	doc_491521501792_item	2496334	et	3	main
ta	doc_491521501792_item	2496335	et	4	main
peab	doc_491521501792_item	2496336	et	4	main
meeldima	doc_491521501792_item	2496337	et	3	main
võib	doc_491521501792_item	2496343	et	3	main
must	doc_491521501792_item	2496345	et	4	main
ja	doc_491521501792_item	2496347	et	3	main
poistel	doc_491521501792_item	2496352	et	3	main
koolivorm	doc_491521501792_item	2496361	et	3	main
kui	doc_491521501792_item	2496383	et	3	main
on	doc_491521501792_item	2496385	et	4	main
me	doc_491521501792_item	2496388	et	4	main
sobime	doc_491521501792_item	2496389	et	3	main
ühte	doc_491521501793_item	2496407	et	4	main
peavad	doc_491521501793_item	2496415	et	4	main
räägitakse	doc_491521501791_item	2495980	et	3	main
paljud	doc_491521501791_item	2495987	et	3	main
seda	doc_491521501791_item	2495990	et	3	main
üle	doc_491521501791_item	2495992	et	3	main
tahavad	doc_491521501791_item	2495995	et	3	main
oma	doc_491521501791_item	2495998	et	4	main
aga	doc_491521501791_item	2496000	et	3	main
on	doc_491521501791_item	2496010	et	4	main
asi	doc_491521501791_item	2496013	et	4	main
ei	doc_491521501791_item	2496015	et	4	main
toob	doc_491521501791_item	2496021	et	3	main
sünnitab	doc_491521501791_item	2496027	et	3	main
kui	doc_491521501791_item	2496030	et	3	main
tüliti	doc_491521501791_item	2496037	et	4	main
saanud	doc_491521501791_item	2496041	et	4	main
seista	doc_491521501791_item	2496044	et	4	main
siis	doc_491521501791_item	2496045	et	3	main
tekib	doc_491521501791_item	2496046	et	3	main
sinu	doc_491521501791_item	2496047	et	3	main
tavaliselt	doc_491521501791_item	2496059	et	4	main
andestada	doc_491521501791_item	2496078	et	3	main
arvates	doc_491521501791_item	2496080	et	4	main
ole	doc_491521501791_item	2496087	et	4	main
võrdsed	doc_491521501791_item	2496088	et	3	main
ja	doc_491521501791_item	2496089	et	3	main
see	doc_491521501791_item	2496094	et	3	main
alustada	doc_491521501791_item	2496096	et	3	main
silmapilgudest	doc_491521501791_item	2496098	et	4	main
ja	doc_491521501791_item	2496099	et	3	main
parimal	doc_491521501791_item	2496101	et	4	main
kaklusega	doc_491521501791_item	2496103	et	3	main
tülitab	doc_491521501791_item	2496106	et	3	main
teistele	doc_491521501791_item	2496113	et	4	main
tegelikult	doc_491521501791_item	2496116	et	4	main
ei	doc_491521501791_item	2496117	et	4	main
ole	doc_491521501791_item	2496118	et	4	main
kõike	doc_491521501791_item	2496125	et	4	main
kannatama	doc_491521501791_item	2496126	et	3	main
mõned	doc_491521501791_item	2496127	et	3	main
tõsine	doc_491521501791_item	2496136	et	4	main
probleem	doc_491521501791_item	2496137	et	3	main
ei	doc_491521501791_item	2496140	et	4	main
vanematele	doc_491521501791_item	2496150	et	4	main
kui	doc_491521501791_item	2496155	et	3	main
tõsisem	doc_491521501791_item	2496159	et	4	main
kuid	doc_491521501791_item	2496180	et	4	main
mitte	doc_491521501791_item	2496181	et	3	main
mina	doc_491521501791_item	2496185	et	4	main
ei	doc_491521501791_item	2496186	et	4	main
olnud	doc_491521501791_item	2496221	et	4	main
nendest	doc_491521501791_item	2496236	et	4	main
suhetest	doc_491521501791_item	2496237	et	3	main
siin	doc_491521501791_item	2496244	et	4	main
saama	doc_491521501791_item	2496256	et	4	main
ju	doc_491521501791_item	2496275	et	3	main
me	doc_491521501792_item	2496297	et	4	main
tunneme	doc_491521501792_item	2496298	et	3	main
end	doc_491521501792_item	2496299	et	4	main
mõnusalt	doc_491521501792_item	2496300	et	4	main
mõnusad	doc_491521501792_item	2496301	et	3	main
ja	doc_491521501792_item	2496310	et	3	main
end	doc_491521501792_item	2496314	et	4	main
selga	doc_491521501792_item	2496326	et	4	main
ja	doc_491521501792_item	2496339	et	3	main
õpitajatele	doc_491521501792_item	2496340	et	4	main
olla	doc_491521501792_item	2496344	et	3	main
võib	doc_491521501792_item	2496354	et	3	main
teksapüksid	doc_491521501792_item	2496356	et	3	main
moodne	doc_491521501792_item	2496358	et	3	main
siis	doc_491521501792_item	2496364	et	3	main
ehted	doc_491521501792_item	2496392	et	3	main
meeldi	doc_491521501793_item	2496397	et	4	main
lihtsalt	doc_491521501793_item	2496417	et	4	main
kõik	doc_491521501793_item	2496423	et	4	main
ei	doc_491521501793_item	2496425	et	4	main
selga	doc_491521501793_item	2496432	et	4	main
et	doc_491521501793_item	2496437	et	3	main
riided	doc_491521501793_item	2496443	et	3	main
võimalik	doc_491521501793_item	2496446	et	3	main
stiili	doc_491521501793_item	2496448	et	4	main
välja	doc_491521501793_item	2496449	et	4	main
arendada	doc_491521501793_item	2496450	et	3	main
sulle	doc_491521501791_item	2496031	et	3	main
midagi	doc_491521501791_item	2496033	et	4	main
kui	doc_491521501791_item	2496035	et	3	main
sa	doc_491521501791_item	2496039	et	3	main
tunne	doc_491521501791_item	2496049	et	4	main
et	doc_491521501791_item	2496050	et	3	main
hakkad	doc_491521501791_item	2496051	et	3	main
kätte	doc_491521501791_item	2496052	et	4	main
maksma	doc_491521501791_item	2496053	et	3	main
mis	doc_491521501791_item	2496058	et	4	main
inimeses	doc_491521501791_item	2496061	et	3	main
on	doc_491521501791_item	2496063	et	4	main
ju	doc_491521501791_item	2496064	et	3	main
loomulik	doc_491521501791_item	2496065	et	3	main
asi	doc_491521501791_item	2496066	et	4	main
ainult	doc_491521501791_item	2496067	et	4	main
väike	doc_491521501791_item	2496068	et	4	main
grupp	doc_491521501791_item	2496069	et	3	main
inimesest	doc_491521501791_item	2496070	et	3	main
võib	doc_491521501791_item	2496071	et	3	main
sellest	doc_491521501791_item	2496072	et	4	main
üle	doc_491521501791_item	2496073	et	3	main
saada	doc_491521501791_item	2496074	et	4	main
ja	doc_491521501791_item	2496075	et	3	main
oma	doc_491521501791_item	2496076	et	4	main
südames	doc_491521501791_item	2496077	et	3	main
minu	doc_491521501791_item	2496079	et	3	main
kui	doc_491521501791_item	2496084	et	3	main
inimesed	doc_491521501791_item	2496085	et	3	main
võib	doc_491521501791_item	2496095	et	3	main
on	doc_491521501791_item	2496108	et	4	main
ning	doc_491521501791_item	2496111	et	3	main
et	doc_491521501791_item	2496115	et	3	main
inimene	doc_491521501791_item	2496122	et	3	main
seda	doc_491521501791_item	2496124	et	3	main
iseendas	doc_491521501791_item	2496138	et	3	main
klassijuhatajale	doc_491521501791_item	2496152	et	3	main
siis	doc_491521501791_item	2496160	et	3	main
politseisse	doc_491521501791_item	2496162	et	3	main
elus	doc_491521501791_item	2496167	et	4	main
juhte	doc_491521501791_item	2496170	et	4	main
seal	doc_491521501791_item	2496183	et	4	main
ole	doc_491521501791_item	2496187	et	4	main
õnneks	doc_491521501791_item	2496188	et	4	main
puutunud	doc_491521501791_item	2496190	et	4	main
on	doc_491521501791_item	2496195	et	4	main
vastutav	doc_491521501791_item	2496196	et	4	main
selle	doc_491521501791_item	2496197	et	4	main
nähtuse	doc_491521501791_item	2496198	et	4	main
eest	doc_491521501791_item	2496199	et	4	main
ja	doc_491521501791_item	2496200	et	3	main
sellesse	doc_491521501791_item	2496201	et	4	main
suhtutakse	doc_491521501791_item	2496202	et	3	main
alati	doc_491521501791_item	2496203	et	4	main
negatiivselt	doc_491521501791_item	2496204	et	4	main
on	doc_491521501791_item	2496205	et	4	main
koostatud	doc_491521501791_item	2496206	et	4	main
paljud	doc_491521501791_item	2496207	et	3	main
seadused	doc_491521501791_item	2496208	et	3	main
ja	doc_491521501791_item	2496209	et	3	main
normid	doc_491521501791_item	2496210	et	4	main
et	doc_491521501791_item	2496211	et	3	main
vägivalda	doc_491521501791_item	2496212	et	4	main
tahistada	doc_491521501791_item	2496213	et	4	main
olen	doc_491521501791_item	2496214	et	3	main
veendunud	doc_491521501791_item	2496215	et	4	main
et	doc_491521501791_item	2496216	et	3	main
näiteks	doc_491521501791_item	2496217	et	4	main
1950	doc_491521501791_item	2496218	et	2	main
aastatel	doc_491521501791_item	2496219	et	4	main
ei	doc_491521501791_item	2496220	et	4	main
nii	doc_491521501791_item	2496223	et	3	main
aga	doc_491521501791_item	2496226	et	3	main
väärtus	doc_491521501791_item	2496240	et	3	main
elu	doc_491521501791_item	2496241	et	4	main
nii	doc_491521501791_item	2496246	et	3	main
valgeid	doc_491521501791_item	2496247	et	3	main
ja	doc_491521501791_item	2496252	et	3	main
aja	doc_491521501791_item	2496266	et	4	main
jooksuga	doc_491521501791_item	2496267	et	3	main
need	doc_491521501791_item	2496268	et	3	main
probleemid	doc_491521501791_item	2496269	et	3	main
oleksid	doc_491521501791_item	2496270	et	4	main
elab	doc_491521501791_item	2496274	et	3	main
ei	doc_491521501791_item	2496279	et	4	main
siis	doc_491521501791_item	2496281	et	3	main
et	doc_491521501792_item	2496291	et	3	main
meil	doc_491521501792_item	2496293	et	4	main
saa	doc_491521501792_item	2496304	et	4	main
nii	doc_491521501791_item	2496132	et	3	main
tekib	doc_491521501791_item	2496134	et	3	main
teine	doc_491521501791_item	2496135	et	3	main
siis	doc_491521501791_item	2496139	et	3	main
ütlema	doc_491521501791_item	2496154	et	3	main
on	doc_491521501791_item	2496157	et	4	main
tegelevadki	doc_491521501791_item	2496164	et	4	main
ja	doc_491521501791_item	2496166	et	3	main
selliseid	doc_491521501791_item	2496169	et	4	main
palju	doc_491521501791_item	2496171	et	4	main
olnud	doc_491521501791_item	2496172	et	4	main
sellega	doc_491521501791_item	2496189	et	3	main
arvan	doc_491521501791_item	2496191	et	3	main
et	doc_491521501791_item	2496192	et	3	main
terve	doc_491521501791_item	2496193	et	4	main
ühiskond	doc_491521501791_item	2496194	et	3	main
inimeste	doc_491521501791_item	2496233	et	3	main
suhetest	doc_491521501791_item	2496234	et	3	main
ja	doc_491521501791_item	2496235	et	3	main
arusaamine	doc_491521501791_item	2496238	et	4	main
ning	doc_491521501791_item	2496239	et	3	main
on	doc_491521501791_item	2496245	et	4	main
kui	doc_491521501791_item	2496248	et	3	main
ka	doc_491521501791_item	2496249	et	3	main
musti	doc_491521501791_item	2496250	et	4	main
sündmusi	doc_491521501791_item	2496251	et	3	main
üle	doc_491521501791_item	2496255	et	3	main
muidugi	doc_491521501791_item	2496264	et	4	main
et	doc_491521501791_item	2496265	et	3	main
läinud	doc_491521501791_item	2496272	et	4	main
kui	doc_491521501791_item	2496278	et	3	main
oled	doc_491521501791_item	2496282	et	3	main
ma	doc_491521501792_item	2496289	et	3	main
mõtlen	doc_491521501792_item	2496290	et	3	main
vanemad	doc_491521501792_item	2496302	et	4	main
meil	doc_491521501792_item	2496317	et	4	main
koolivorm	doc_491521501792_item	2496319	et	3	main
väga	doc_491521501791_item	2496227	et	3	main
ka	doc_491521501791_item	2496231	et	3	main
on	doc_491521501791_item	2496242	et	4	main
nendest	doc_491521501791_item	2496253	et	4	main
ei	doc_491521501791_item	2496258	et	4	main
lootus	doc_491521501791_item	2496273	et	4	main
inimeses	doc_491521501791_item	2496276	et	3	main
koolivormi	doc_491521501792_item	2496287	et	4	main
poolt	doc_491521501792_item	2496288	et	4	main
kui	doc_491521501792_item	2496292	et	3	main
osta	doc_491521501792_item	2496305	et	4	main
temale	doc_491521501792_item	2496306	et	3	main
lastele	doc_491521501792_item	2496307	et	4	main
tunnevad	doc_491521501792_item	2496313	et	3	main
alaväärsena	doc_491521501792_item	2496315	et	3	main
kui	doc_491521501792_item	2496316	et	3	main
on	doc_491521501792_item	2496318	et	4	main
siis	doc_491521501792_item	2496320	et	3	main
vaja	doc_491521501792_item	2496322	et	4	main
mõelda	doc_491521501792_item	2496324	et	4	main
mida	doc_491521501792_item	2496325	et	4	main
õpilastele	doc_491521501792_item	2496338	et	4	main
džemper	doc_491521501792_item	2496350	et	2	main
see	doc_491521501792_item	2496353	et	3	main
õpilastele	doc_491521501792_item	2496363	et	4	main
temaga	doc_491521501792_item	2496390	et	3	main
mulle	doc_491521501793_item	2496394	et	4	main
hall	doc_491521501793_item	2496402	et	4	main
moodsalt	doc_491521501793_item	2496419	et	4	main
arvan	doc_491521501793_item	2496421	et	3	main
taha	doc_491521501793_item	2496426	et	4	main
kogu	doc_491521501793_item	2496427	et	4	main
aeg	doc_491521501793_item	2496428	et	3	main
üht	doc_491521501793_item	2496429	et	3	main
ja	doc_491521501793_item	2496430	et	3	main
panna	doc_491521501793_item	2496433	et	4	main
erinevad	doc_491521501793_item	2496442	et	4	main
sobi	doc_491521501793_item	2496453	et	4	main
ehted	doc_491521501793_item	2496455	et	3	main
ei	doc_491521501793_item	2496457	et	4	main
on	doc_491521501793_item	2496462	et	4	main
kehaline	doc_491521501793_item	2496466	et	4	main
koolivorm	doc_491521501793_item	2496470	et	3	main
veel	doc_491521501793_item	2496472	et	4	main
raamidesse	doc_491521501793_item	2496474	et	3	main
essee	doc_491521501794_item	2496475	et	4	main
mina	doc_491521501794_item	2496476	et	4	main
olen	doc_491521501794_item	2496477	et	3	main
koolivorm	doc_491521501794_item	2496483	et	3	main
ei	doc_491521501794_item	2496488	et	4	main
võimalik	doc_491521501794_item	2496490	et	3	main
stiili	doc_491521501794_item	2496492	et	4	main
ei	doc_491521501794_item	2496496	et	4	main
võivad	doc_491521501794_item	2496507	et	4	main
rõivad	doc_491521501792_item	2496309	et	3	main
need	doc_491521501792_item	2496311	et	3	main
pole	doc_491521501792_item	2496321	et	3	main
panna	doc_491521501792_item	2496327	et	4	main
peab	doc_491521501792_item	2496330	et	4	main
see	doc_491521501792_item	2496342	et	3	main
lubuv	doc_491521501792_item	2496349	et	4	main
olla	doc_491521501792_item	2496355	et	3	main
kui	doc_491521501792_item	2496360	et	3	main
meeldib	doc_491521501792_item	2496362	et	3	main
siis	doc_491521501792_item	2496387	et	3	main
koolivormi	doc_491521501793_item	2496398	et	4	main
koolivorm	doc_491521501793_item	2496399	et	3	main
tekib	doc_491521501793_item	2496400	et	3	main
ühesugune	doc_491521501793_item	2496401	et	3	main
nägu	doc_491521501793_item	2496408	et	4	main
ei	doc_491521501793_item	2496410	et	4	main
riietuma	doc_491521501793_item	2496416	et	3	main
mugavalt	doc_491521501793_item	2496418	et	4	main
ma	doc_491521501793_item	2496420	et	3	main
et	doc_491521501793_item	2496422	et	3	main
ja	doc_491521501793_item	2496434	et	3	main
peaks	doc_491521501793_item	2496440	et	4	main
ei	doc_491521501793_item	2496444	et	4	main
oma	doc_491521501793_item	2496447	et	4	main
uhked	doc_491521501793_item	2496454	et	4	main
lapsel	doc_491521501793_item	2496456	et	4	main
aktiivsus	doc_491521501793_item	2496467	et	4	main
sureuks	doc_491521501793_item	2496471	et	4	main
enam	doc_491521501793_item	2496473	et	4	main
tekib	doc_491521501794_item	2496484	et	3	main
hall	doc_491521501794_item	2496486	et	4	main
kõigile	doc_491521501794_item	2496495	et	4	main
pruugi	doc_491521501794_item	2496497	et	4	main
koolivorm	doc_491521501794_item	2496498	et	3	main
sobida	doc_491521501794_item	2496499	et	3	main
aga	doc_491521501794_item	2496500	et	3	main
see	doc_491521501794_item	2496501	et	3	main
saa	doc_491521501794_item	2496522	et	4	main
koolis	doc_491521501794_item	2496524	et	4	main
šortis	doc_491521501794_item	2496525	et	2	main
ei	doc_491521501794_item	2496538	et	4	main
mina	doc_491521501794_item	2496541	et	4	main
kõigil	doc_491521501794_item	2496544	et	4	main
moodsal	doc_491521501794_item	2496545	et	3	main
õpilasel	doc_491521501794_item	2496546	et	3	main
peab	doc_491521501794_item	2496547	et	4	main
kui	doc_491521501794_item	2496559	et	3	main
koolivorm	doc_491521501794_item	2496562	et	3	main
vaja	doc_491521501795_item	2496586	et	4	main
ma	doc_491521501795_item	2496587	et	3	main
arvan	doc_491521501795_item	2496588	et	3	main
et	doc_491521501795_item	2496589	et	3	main
käima	doc_491521501795_item	2496593	et	4	main
mis	doc_491521501795_item	2496595	et	4	main
me	doc_491521501795_item	2496596	et	4	main
tahame	doc_491521501795_item	2496597	et	3	main
t-särk	doc_491521501795_item	2496601	et	3	main
botased	doc_491521501795_item	2496602	et	3	main
vaja	doc_491521501795_item	2496608	et	4	main
ei	doc_491521501795_item	2496612	et	4	main
koolivorm	doc_491521501795_item	2496614	et	3	main
sobida	doc_491521501795_item	2496615	et	3	main
ei	doc_491521501795_item	2496616	et	4	main
hall	doc_491521501795_item	2496623	et	4	main
ole	doc_491521501795_item	2496626	et	4	main
uhked	doc_491521501795_item	2496636	et	4	main
ehted	doc_491521501795_item	2496637	et	3	main
tunned	doc_491521501795_item	2496642	et	3	main
selga	doc_491521501795_item	2496651	et	4	main
aga	doc_491521501792_item	2496328	et	3	main
olema	doc_491521501792_item	2496331	et	4	main
moodse	doc_491521501792_item	2496332	et	3	main
tüdrukutel	doc_491521501792_item	2496341	et	4	main
selik	doc_491521501792_item	2496346	et	4	main
meresinine	doc_491521501792_item	2496348	et	4	main
aga	doc_491521501792_item	2496351	et	3	main
ja	doc_491521501792_item	2496357	et	3	main
sviiter	doc_491521501792_item	2496359	et	3	main
nad	doc_491521501792_item	2496365	et	3	main
tahavad	doc_491521501792_item	2496366	et	3	main
kanna	doc_491521501792_item	2496367	et	4	main
teda	doc_491521501792_item	2496368	et	4	main
aga	doc_491521501792_item	2496369	et	3	main
kui	doc_491521501792_item	2496370	et	3	main
ta	doc_491521501792_item	2496371	et	4	main
ei	doc_491521501792_item	2496372	et	4	main
meeldi	doc_491521501792_item	2496373	et	4	main
siis	doc_491521501792_item	2496374	et	3	main
nad	doc_491521501792_item	2496375	et	3	main
mõtlevad	doc_491521501792_item	2496376	et	4	main
et	doc_491521501792_item	2496377	et	3	main
kõigele	doc_491521501792_item	2496378	et	4	main
ei	doc_491521501792_item	2496379	et	4	main
pruugi	doc_491521501792_item	2496380	et	4	main
koolivorm	doc_491521501792_item	2496381	et	3	main
sobida	doc_491521501792_item	2496382	et	3	main
koolivorm	doc_491521501792_item	2496384	et	3	main
moodne	doc_491521501792_item	2496386	et	3	main
uhked	doc_491521501792_item	2496391	et	4	main
essee	doc_491521501793_item	2496393	et	4	main
väga	doc_491521501793_item	2496395	et	3	main
ei	doc_491521501793_item	2496396	et	4	main
mass	doc_491521501793_item	2496403	et	3	main
kõik	doc_491521501793_item	2496404	et	4	main
kooliõpilased	doc_491521501793_item	2496405	et	3	main
on	doc_491521501793_item	2496406	et	4	main
kõigile	doc_491521501793_item	2496409	et	4	main
pruugi	doc_491521501793_item	2496411	et	4	main
koolivorm	doc_491521501793_item	2496412	et	3	main
sobida	doc_491521501793_item	2496413	et	3	main
kõik	doc_491521501793_item	2496414	et	4	main
õpilased	doc_491521501793_item	2496424	et	3	main
ma	doc_491521501793_item	2496435	et	3	main
arvan	doc_491521501793_item	2496436	et	3	main
igal	doc_491521501793_item	2496438	et	3	main
ole	doc_491521501793_item	2496458	et	4	main
vormis	doc_491521501793_item	2496459	et	4	main
mugav	doc_491521501793_item	2496460	et	3	main
jätab	doc_491521501793_item	2496468	et	3	main
koolivormi	doc_491521501794_item	2496478	et	4	main
vastu	doc_491521501794_item	2496479	et	3	main
selle	doc_491521501794_item	2496480	et	4	main
pärast	doc_491521501794_item	2496481	et	4	main
välja	doc_491521501794_item	2496493	et	4	main
mulle	doc_491521501794_item	2496526	et	4	main
meeldib	doc_491521501794_item	2496527	et	3	main
riided	doc_491521501794_item	2496531	et	3	main
ta	doc_491521501794_item	2496537	et	4	main
ole	doc_491521501794_item	2496539	et	4	main
riides	doc_491521501794_item	2496558	et	4	main
tahab	doc_491521501794_item	2496561	et	3	main
ta	doc_491521501794_item	2496564	et	4	main
peab	doc_491521501794_item	2496565	et	4	main
teha	doc_491521501794_item	2496566	et	3	main
kavandit	doc_491521501794_item	2496567	et	3	main
õpilased	doc_491521501794_item	2496574	et	3	main
ma	doc_491521501795_item	2496603	et	3	main
koolivorm	doc_491521501795_item	2496606	et	3	main
et	doc_491521501795_item	2496610	et	3	main
mass	doc_491521501795_item	2496624	et	3	main
kõik	doc_491521501795_item	2496638	et	4	main
teavad	doc_491521501795_item	2496639	et	3	main
mida	doc_491521501795_item	2496650	et	4	main
vaja	doc_491521501795_item	2496660	et	4	main
samat	doc_491521501793_item	2496431	et	4	main
lapsel	doc_491521501793_item	2496439	et	4	main
olema	doc_491521501793_item	2496441	et	4	main
ole	doc_491521501793_item	2496445	et	4	main
ei	doc_491521501793_item	2496452	et	4	main
kõigile	doc_491521501793_item	2496461	et	4	main
et	doc_491521501794_item	2496482	et	3	main
mass	doc_491521501794_item	2496487	et	3	main
ei	doc_491521501794_item	2496502	et	4	main
tähenda	doc_491521501794_item	2496503	et	4	main
et	doc_491521501794_item	2496504	et	3	main
kandma	doc_491521501794_item	2496508	et	3	main
mida	doc_491521501794_item	2496509	et	4	main
nad	doc_491521501794_item	2496510	et	3	main
tahavad	doc_491521501794_item	2496511	et	3	main
näiteks	doc_491521501794_item	2496512	et	4	main
tüdrukud	doc_491521501794_item	2496513	et	3	main
ei	doc_491521501794_item	2496514	et	4	main
saa	doc_491521501794_item	2496515	et	4	main
kanna	doc_491521501794_item	2496516	et	4	main
väljakutsuva	doc_491521501794_item	2496517	et	3	main
riided	doc_491521501794_item	2496518	et	3	main
poisid	doc_491521501794_item	2496519	et	4	main
ka	doc_491521501794_item	2496520	et	3	main
kandma	doc_491521501794_item	2496528	et	3	main
ilusat	doc_491521501794_item	2496529	et	3	main
aga	doc_491521501794_item	2496532	et	3	main
vorm	doc_491521501794_item	2496534	et	3	main
olema	doc_491521501794_item	2496548	et	4	main
moodne	doc_491521501794_item	2496549	et	3	main
riided	doc_491521501794_item	2496550	et	3	main
kool	doc_491521501794_item	2496560	et	4	main
siis	doc_491521501794_item	2496563	et	3	main
pärast	doc_491521501794_item	2496572	et	4	main
teadma	doc_491521501794_item	2496576	et	3	main
peame	doc_491521501795_item	2496592	et	4	main
dž	doc_491521501795_item	2496598	et	2	main
emper	doc_491521501795_item	2496599	et	4	main
triiksärk	doc_491521501795_item	2496600	et	3	main
ei	doc_491521501795_item	2496607	et	4	main
seest	doc_491521501795_item	2496609	et	3	main
pruugi	doc_491521501795_item	2496613	et	4	main
tekib	doc_491521501795_item	2496621	et	3	main
ei	doc_491521501795_item	2496634	et	4	main
sobi	doc_491521501795_item	2496635	et	4	main
koolivormis	doc_491521501795_item	2496641	et	3	main
mõnusalt	doc_491521501795_item	2496644	et	4	main
pole	doc_491521501795_item	2496646	et	3	main
mõelda	doc_491521501795_item	2496649	et	4	main
koolivorm	doc_491521501795_item	2496658	et	3	main
ei	doc_491521501795_item	2496659	et	4	main
koolivormiga	doc_491521501793_item	2496451	et	4	main
teada	doc_491521501793_item	2496463	et	3	main
et	doc_491521501793_item	2496464	et	3	main
koolilaste	doc_491521501793_item	2496465	et	4	main
soovida	doc_491521501793_item	2496469	et	4	main
ühesugune	doc_491521501794_item	2496485	et	3	main
ole	doc_491521501794_item	2496489	et	4	main
oma	doc_491521501794_item	2496491	et	4	main
arendada	doc_491521501794_item	2496494	et	3	main
kõik	doc_491521501794_item	2496505	et	4	main
õppilased	doc_491521501794_item	2496506	et	4	main
ei	doc_491521501794_item	2496521	et	4	main
käima	doc_491521501794_item	2496523	et	4	main
kooli	doc_491521501794_item	2496533	et	4	main
mõtlen	doc_491521501794_item	2496542	et	3	main
ja	doc_491521501794_item	2496568	et	3	main
rääkida	doc_491521501794_item	2496569	et	3	main
et	doc_491521501794_item	2496573	et	3	main
mida	doc_491521501794_item	2496577	et	4	main
koolis	doc_491521501795_item	2496590	et	4	main
riidest	doc_491521501795_item	2496594	et	4	main
et	doc_491521501795_item	2496605	et	3	main
ole	doc_491521501795_item	2496617	et	4	main
võimalik	doc_491521501795_item	2496618	et	3	main
teistest	doc_491521501795_item	2496619	et	4	main
erineda	doc_491521501795_item	2496620	et	3	main
moodsat	doc_491521501794_item	2496530	et	3	main
on	doc_491521501794_item	2496535	et	4	main
inetu	doc_491521501794_item	2496536	et	4	main
moodne	doc_491521501794_item	2496540	et	3	main
et	doc_491521501794_item	2496543	et	3	main
ja	doc_491521501794_item	2496551	et	3	main
kõik	doc_491521501794_item	2496552	et	4	main
nad	doc_491521501794_item	2496553	et	3	main
tahavad	doc_491521501794_item	2496554	et	3	main
olla	doc_491521501794_item	2496555	et	3	main
erilised	doc_491521501794_item	2496556	et	4	main
nendes	doc_491521501794_item	2496557	et	4	main
õpilastega	doc_491521501794_item	2496570	et	4	main
selle	doc_491521501794_item	2496571	et	4	main
peavad	doc_491521501794_item	2496575	et	4	main
koolijuhatajad	doc_491521501794_item	2496578	et	3	main
tahavad	doc_491521501794_item	2496579	et	3	main
essee	doc_491521501795_item	2496580	et	4	main
ma	doc_491521501795_item	2496581	et	3	main
arvan	doc_491521501795_item	2496582	et	3	main
et	doc_491521501795_item	2496583	et	3	main
koolivorm	doc_491521501795_item	2496584	et	3	main
ei	doc_491521501795_item	2496585	et	4	main
me	doc_491521501795_item	2496591	et	4	main
arvan	doc_491521501795_item	2496604	et	3	main
kõigile	doc_491521501795_item	2496611	et	4	main
ei	doc_491521501795_item	2496625	et	4	main
ja	doc_491521501795_item	2496645	et	3	main
vaja	doc_491521501795_item	2496647	et	4	main
hommikul	doc_491521501795_item	2496648	et	3	main
ühesugune	doc_491521501795_item	2496622	et	3	main
võimalik	doc_491521501795_item	2496627	et	3	main
oma	doc_491521501795_item	2496628	et	4	main
stiil	doc_491521501795_item	2496629	et	3	main
välja	doc_491521501795_item	2496630	et	4	main
arendada	doc_491521501795_item	2496631	et	3	main
ja	doc_491521501795_item	2496632	et	3	main
koolivormiga	doc_491521501795_item	2496633	et	4	main
et	doc_491521501795_item	2496640	et	3	main
end	doc_491521501795_item	2496643	et	4	main
panna	doc_491521501795_item	2496652	et	4	main
aga	doc_491521501795_item	2496653	et	3	main
minu	doc_491521501795_item	2496654	et	3	main
positsioon	doc_491521501795_item	2496655	et	3	main
on	doc_491521501795_item	2496656	et	4	main
täielik	doc_491521501795_item	2496657	et	3	main
seas	doc_491521501799_item	2497121	et	4	main
haridus	doc_491521501799_item	2497125	et	3	main
selles	doc_491521501799_item	2497131	et	4	main
ainult	doc_491521501799_item	2497139	et	4	main
ka	doc_491521501799_item	2497150	et	3	main
aga	doc_491521501799_item	2497154	et	3	main
väga	doc_491521501799_item	2497173	et	3	main
edukas	doc_491521501799_item	2497174	et	4	main
ja	doc_491521501799_item	2497175	et	3	main
jõukas	doc_491521501799_item	2497176	et	4	main
et	doc_491521501799_item	2497183	et	3	main
ülikooliharidus	doc_491521501799_item	2497186	et	3	main
mees	doc_491521501799_item	2497199	et	4	main
elus	doc_491521501799_item	2497207	et	4	main
et	doc_491521501799_item	2497210	et	3	main
kes	doc_491521501799_item	2497212	et	4	main
usun	doc_491521501799_item	2497220	et	3	main
hea	doc_491521501799_item	2497229	et	4	main
on	doc_491521501799_item	2497135	et	4	main
inimene	doc_491521501799_item	2497136	et	3	main
kes	doc_491521501799_item	2497137	et	4	main
ta	doc_491521501799_item	2497142	et	4	main
üldse	doc_491521501799_item	2497143	et	3	main
ei	doc_491521501799_item	2497144	et	4	main
tea	doc_491521501799_item	2497145	et	4	main
nii	doc_491521501799_item	2497146	et	3	main
eesti	doc_491521501799_item	2497152	et	4	main
ja	doc_491521501799_item	2497178	et	3	main
taha	doc_491521501799_item	2497181	et	4	main
kodutu	doc_491521501799_item	2497198	et	4	main
kaks	doc_491521501799_item	2497203	et	3	main
nii	doc_491521501799_item	2497209	et	3	main
sellesse	doc_491521501799_item	2497221	et	4	main
kõik	doc_491521501799_item	2497223	et	4	main
infoallikad	doc_491521501799_item	2497224	et	3	main
ülikooli	doc_491521501799_item	2497226	et	4	main
haridusse	doc_491521501799_item	2497230	et	3	main
valdamist	doc_491521501799_item	2497246	et	4	main
teadusel	doc_491521501800_item	2497258	et	3	main
mitte	doc_491521501800_item	2497272	et	3	main
ükski	doc_491521501800_item	2497273	et	4	main
täiuslikult	doc_491521501800_item	2497277	et	4	main
teada	doc_491521501800_item	2497279	et	3	main
ainult	doc_491521501800_item	2497309	et	4	main
essee	doc_491521501799_item	2497107	et	4	main
kas	doc_491521501799_item	2497108	et	3	main
ülikooliharidus	doc_491521501799_item	2497109	et	3	main
on	doc_491521501799_item	2497110	et	4	main
vajalik	doc_491521501799_item	2497111	et	3	main
ma	doc_491521501799_item	2497112	et	3	main
olen	doc_491521501799_item	2497113	et	3	main
selle	doc_491521501799_item	2497114	et	4	main
väitega	doc_491521501799_item	2497115	et	3	main
osaliselt	doc_491521501799_item	2497116	et	4	main
nõus	doc_491521501799_item	2497117	et	4	main
sest	doc_491521501799_item	2497118	et	4	main
minu	doc_491521501799_item	2497119	et	3	main
sõbrades	doc_491521501799_item	2497120	et	4	main
kõige	doc_491521501799_item	2497128	et	4	main
tähtsam	doc_491521501799_item	2497129	et	4	main
lõpetanud	doc_491521501799_item	2497141	et	4	main
keelt	doc_491521501799_item	2497148	et	4	main
kui	doc_491521501799_item	2497149	et	3	main
isegi	doc_491521501799_item	2497151	et	4	main
ajal	doc_491521501799_item	2497156	et	4	main
palju	doc_491521501799_item	2497180	et	4	main
elunäitab	doc_491521501799_item	2497182	et	4	main
inimesel	doc_491521501799_item	2497188	et	3	main
head	doc_491521501799_item	2497189	et	4	main
töökoha	doc_491521501799_item	2497190	et	4	main
leida	doc_491521501799_item	2497191	et	3	main
kuulsin	doc_491521501799_item	2497192	et	3	main
et	doc_491521501799_item	2497195	et	3	main
mustamäel	doc_491521501799_item	2497196	et	3	main
elab	doc_491521501799_item	2497197	et	3	main
kellel	doc_491521501799_item	2497200	et	4	main
aga	doc_491521501799_item	2497202	et	3	main
on	doc_491521501799_item	2497205	et	4	main
on	doc_491521501799_item	2497213	et	4	main
paremaid	doc_491521501799_item	2497217	et	4	main
astumist	doc_491521501799_item	2497227	et	4	main
ülikooliharidus	doc_491521501799_item	2497235	et	3	main
vajalik	doc_491521501799_item	2497237	et	3	main
sest	doc_491521501799_item	2497238	et	4	main
tänapäeval	doc_491521501799_item	2497239	et	3	main
sõltub	doc_491521501799_item	2497240	et	3	main
töökoha	doc_491521501799_item	2497241	et	4	main
leitmine	doc_491521501799_item	2497242	et	4	main
kas	doc_491521501800_item	2497257	et	3	main
on	doc_491521501800_item	2497259	et	4	main
väga	doc_491521501800_item	2497263	et	3	main
on	doc_491521501800_item	2497269	et	4	main
ei	doc_491521501800_item	2497275	et	4	main
kõike	doc_491521501800_item	2497278	et	4	main
ja	doc_491521501800_item	2497311	et	3	main
on	doc_491521501799_item	2497122	et	4	main
näited	doc_491521501799_item	2497123	et	3	main
ei	doc_491521501799_item	2497126	et	4	main
ole	doc_491521501799_item	2497127	et	4	main
küsimuses	doc_491521501799_item	2497132	et	4	main
minu	doc_491521501799_item	2497133	et	3	main
sõbrannamees	doc_491521501799_item	2497134	et	4	main
põhikooli	doc_491521501799_item	2497140	et	4	main
inglise	doc_491521501799_item	2497147	et	4	main
samal	doc_491521501799_item	2497155	et	3	main
ta	doc_491521501799_item	2497157	et	4	main
ärimees	doc_491521501799_item	2497177	et	4	main
mitte	doc_491521501799_item	2497184	et	3	main
ühelt	doc_491521501799_item	2497193	et	3	main
tuttaialt	doc_491521501799_item	2497194	et	4	main
on	doc_491521501799_item	2497201	et	4	main
ülikooliharidust	doc_491521501799_item	2497204	et	4	main
ju	doc_491521501799_item	2497206	et	3	main
lõpetanud	doc_491521501799_item	2497215	et	4	main
töökohti	doc_491521501799_item	2497218	et	4	main
et	doc_491521501799_item	2497124	et	3	main
punkt	doc_491521501799_item	2497130	et	4	main
on	doc_491521501799_item	2497138	et	4	main
keelt	doc_491521501799_item	2497153	et	4	main
on	doc_491521501799_item	2497158	et	4	main
väga	doc_491521501799_item	2497159	et	3	main
ettevõtlik	doc_491521501799_item	2497160	et	3	main
ja	doc_491521501799_item	2497161	et	3	main
julge	doc_491521501799_item	2497162	et	4	main
minu	doc_491521501799_item	2497163	et	3	main
arvates	doc_491521501799_item	2497164	et	4	main
need	doc_491521501799_item	2497165	et	3	main
iseloomujooned	doc_491521501799_item	2497166	et	3	main
teda	doc_491521501799_item	2497168	et	4	main
aitasid	doc_491521501799_item	2497167	et	4	main
elus	doc_491521501799_item	2497169	et	4	main
praegu	doc_491521501799_item	2497170	et	3	main
ta	doc_491521501799_item	2497171	et	4	main
on	doc_491521501799_item	2497172	et	4	main
teenib	doc_491521501799_item	2497179	et	3	main
alati	doc_491521501799_item	2497185	et	4	main
aitab	doc_491521501799_item	2497187	et	3	main
ikka	doc_491521501799_item	2497208	et	4	main
inimesed	doc_491521501799_item	2497211	et	3	main
ülikooli	doc_491521501799_item	2497214	et	4	main
savad	doc_491521501799_item	2497216	et	4	main
ma	doc_491521501799_item	2497219	et	3	main
ma	doc_491521501799_item	2497232	et	3	main
et	doc_491521501799_item	2497234	et	3	main
keeltte	doc_491521501799_item	2497245	et	4	main
oskusest	doc_491521501799_item	2497248	et	4	main
essee	doc_491521501800_item	2497256	et	4	main
piire	doc_491521501800_item	2497260	et	4	main
on	doc_491521501800_item	2497262	et	4	main
huvitav	doc_491521501800_item	2497264	et	4	main
olemas	doc_491521501800_item	2497270	et	4	main
aga	doc_491521501800_item	2497271	et	3	main
arenevad	doc_491521501800_item	2497308	et	4	main
rohkem	doc_491521501800_item	2497310	et	4	main
lõpuni	doc_491521501800_item	2497314	et	3	main
male	doc_491521501800_item	2497321	et	4	main
kogu	doc_491521501800_item	2497330	et	4	main
üheksakümmend	doc_491521501800_item	2497333	et	4	main
jääb	doc_491521501800_item	2497337	et	3	main
tase	doc_491521501800_item	2497341	et	3	main
inimesest	doc_491521501800_item	2497343	et	3	main
mõned	doc_491521501800_item	2497345	et	3	main
maailmale	doc_491521501800_item	2497351	et	4	main
on	doc_491521501800_item	2497354	et	4	main
et	doc_491521501800_item	2497356	et	3	main
raamatuid	doc_491521501800_item	2497367	et	3	main
lugeda	doc_491521501800_item	2497368	et	3	main
ei	doc_491521501800_item	2497375	et	4	main
kavalust	doc_491521501800_item	2497378	et	4	main
panna	doc_491521501800_item	2497384	et	4	main
ütles	doc_491521501800_item	2497387	et	3	main
õpilastele	doc_491521501800_item	2497389	et	4	main
et	doc_491521501800_item	2497392	et	3	main
mitte	doc_491521501800_item	2497421	et	3	main
osaliselt	doc_491521501800_item	2497428	et	4	main
piire	doc_491521501800_item	2497434	et	4	main
minu	doc_491521501800_item	2497440	et	3	main
piire	doc_491521501800_item	2497442	et	4	main
ole	doc_491521501800_item	2497444	et	4	main
sest	doc_491521501799_item	2497222	et	4	main
propogerivad	doc_491521501799_item	2497225	et	4	main
ja	doc_491521501799_item	2497228	et	3	main
heast	doc_491521501799_item	2497243	et	3	main
ja	doc_491521501799_item	2497247	et	3	main
ja	doc_491521501799_item	2497249	et	3	main
arvuti	doc_491521501799_item	2497250	et	4	main
kasutamine	doc_491521501799_item	2497251	et	4	main
oskusest	doc_491521501799_item	2497252	et	4	main
ka	doc_491521501799_item	2497253	et	3	main
ja	doc_491521501799_item	2497254	et	3	main
see	doc_491521501800_item	2497261	et	3	main
piired	doc_491521501800_item	2497268	et	4	main
saa	doc_491521501800_item	2497276	et	4	main
saada	doc_491521501800_item	2497280	et	4	main
kunagi	doc_491521501800_item	2497281	et	3	main
ammu	doc_491521501800_item	2497282	et	4	main
inimestega	doc_491521501800_item	2497283	et	3	main
oli	doc_491521501800_item	2497284	et	3	main
loodud	doc_491521501800_item	2497285	et	4	main
ratas	doc_491521501800_item	2497286	et	3	main
ja	doc_491521501800_item	2497287	et	3	main
see	doc_491521501800_item	2497288	et	3	main
looja	doc_491521501800_item	2497289	et	4	main
oli	doc_491521501800_item	2497290	et	3	main
tunnistatud	doc_491521501800_item	2497291	et	4	main
targemaiks	doc_491521501800_item	2497292	et	4	main
inimeseks	doc_491521501800_item	2497293	et	3	main
nüüd	doc_491521501800_item	2497294	et	4	main
loo	doc_491521501800_item	2497296	et	4	main
kas	doc_491521501800_item	2497297	et	3	main
aga	doc_491521501800_item	2497295	et	3	main
või	doc_491521501800_item	2497298	et	4	main
midagi	doc_491521501800_item	2497299	et	4	main
sa	doc_491521501800_item	2497300	et	3	main
ikkagi	doc_491521501800_item	2497301	et	4	main
jääd	doc_491521501800_item	2497302	et	4	main
eikellgiks	doc_491521501800_item	2497303	et	4	main
tavaliseks	doc_491521501800_item	2497304	et	4	main
inimeseks	doc_491521501800_item	2497305	et	3	main
inimeste	doc_491521501800_item	2497306	et	3	main
saamist	doc_491521501799_item	2497231	et	4	main
arvan	doc_491521501799_item	2497233	et	3	main
on	doc_491521501799_item	2497236	et	4	main
haridusest	doc_491521501799_item	2497244	et	4	main
muidugi	doc_491521501799_item	2497255	et	4	main
küsimus	doc_491521501800_item	2497265	et	4	main
vist	doc_491521501800_item	2497266	et	4	main
teadused	doc_491521501800_item	2497267	et	3	main
inimene	doc_491521501800_item	2497274	et	3	main
teadused	doc_491521501800_item	2497307	et	3	main
arenevad	doc_491521501800_item	2497312	et	4	main
kui	doc_491521501800_item	2497316	et	3	main
raskematele	doc_491521501800_item	2497322	et	4	main
vastuste	doc_491521501800_item	2497324	et	4	main
kasutab	doc_491521501800_item	2497326	et	3	main
resursiks	doc_491521501800_item	2497338	et	4	main
arengu	doc_491521501800_item	2497340	et	3	main
on	doc_491521501800_item	2497347	et	4	main
avastada	doc_491521501800_item	2497352	et	3	main
hommikust	doc_491521501800_item	2497370	et	4	main
kui	doc_491521501800_item	2497373	et	3	main
võrreldes	doc_491521501800_item	2497423	et	3	main
nõus	doc_491521501800_item	2497429	et	4	main
väljendiga	doc_491521501800_item	2497430	et	3	main
teadustel	doc_491521501800_item	2497441	et	3	main
maailma	doc_491521501800_item	2497313	et	4	main
aga	doc_491521501800_item	2497315	et	3	main
teiselt	doc_491521501800_item	2497318	et	4	main
inimese	doc_491521501800_item	2497320	et	4	main
vaadata	doc_491521501800_item	2497317	et	4	main
poolt	doc_491521501800_item	2497319	et	4	main
küsimustele	doc_491521501800_item	2497323	et	4	main
ainult	doc_491521501800_item	2497327	et	4	main
üheksa	doc_491521501800_item	2497328	et	4	main
protsenti	doc_491521501800_item	2497329	et	4	main
protsent	doc_491521501800_item	2497335	et	3	main
inimese	doc_491521501800_item	2497339	et	4	main
mõned	doc_491521501800_item	2497353	et	3	main
kätes	doc_491521501800_item	2497364	et	3	main
sa	doc_491521501800_item	2497365	et	3	main
võid	doc_491521501800_item	2497366	et	4	main
õppida	doc_491521501800_item	2497369	et	3	main
ei	doc_491521501800_item	2497379	et	4	main
saa	doc_491521501800_item	2497380	et	4	main
sa	doc_491521501800_item	2497381	et	3	main
enne	doc_491521501800_item	2497385	et	4	main
oma	doc_491521501800_item	2497388	et	4	main
ma	doc_491521501800_item	2497390	et	3	main
ma	doc_491521501800_item	2497393	et	3	main
midagi	doc_491521501800_item	2497422	et	4	main
ma	doc_491521501800_item	2497426	et	3	main
loodan	doc_491521501800_item	2497436	et	3	main
et	doc_491521501800_item	2497437	et	3	main
elu	doc_491521501800_item	2497438	et	4	main
ajudest	doc_491521501800_item	2497336	et	3	main
midagi	doc_491521501800_item	2497350	et	4	main
sündinud	doc_491521501800_item	2497355	et	4	main
õues	doc_491521501800_item	2497357	et	4	main
koristada	doc_491521501800_item	2497358	et	3	main
aga	doc_491521501800_item	2497359	et	3	main
nende	doc_491521501800_item	2497360	et	4	main
arengutase	doc_491521501800_item	2497361	et	3	main
aga	doc_491521501800_item	2497372	et	3	main
sul	doc_491521501800_item	2497374	et	3	main
ole	doc_491521501800_item	2497376	et	4	main
loogikat	doc_491521501800_item	2497377	et	3	main
aristootel	doc_491521501800_item	2497386	et	4	main
midagi	doc_491521501800_item	2497397	et	4	main
ja	doc_491521501800_item	2497398	et	3	main
see	doc_491521501800_item	2497399	et	3	main
on	doc_491521501800_item	2497400	et	4	main
tõesti	doc_491521501800_item	2497401	et	3	main
ta	doc_491521501800_item	2497402	et	4	main
oli	doc_491521501800_item	2497403	et	3	main
tark	doc_491521501800_item	2497404	et	3	main
inimene	doc_491521501800_item	2497405	et	3	main
ja	doc_491521501800_item	2497406	et	3	main
ta	doc_491521501800_item	2497407	et	4	main
sai	doc_491521501800_item	2497408	et	4	main
aru	doc_491521501800_item	2497409	et	4	main
sellest	doc_491521501800_item	2497410	et	4	main
et	doc_491521501800_item	2497411	et	3	main
tema	doc_491521501800_item	2497412	et	4	main
teadmised	doc_491521501800_item	2497413	et	4	main
olid	doc_491521501800_item	2497414	et	4	main
väikesed	doc_491521501800_item	2497415	et	4	main
et	doc_491521501800_item	2497416	et	3	main
tema	doc_491521501800_item	2497417	et	4	main
ei	doc_491521501800_item	2497418	et	4	main
tea	doc_491521501800_item	2497419	et	4	main
tegelt	doc_491521501800_item	2497420	et	4	main
otsimisel	doc_491521501800_item	2497325	et	4	main
informatsioonist	doc_491521501800_item	2497331	et	3	main
järelikult	doc_491521501800_item	2497332	et	3	main
üks	doc_491521501800_item	2497334	et	3	main
sõltub	doc_491521501800_item	2497342	et	3	main
iseendast	doc_491521501800_item	2497344	et	3	main
inimesed	doc_491521501800_item	2497346	et	3	main
sündinud	doc_491521501800_item	2497348	et	4	main
et	doc_491521501800_item	2497349	et	3	main
on	doc_491521501800_item	2497362	et	4	main
nende	doc_491521501800_item	2497363	et	4	main
õhtuni	doc_491521501800_item	2497371	et	3	main
maailma	doc_491521501800_item	2497382	et	4	main
imestama	doc_491521501800_item	2497383	et	3	main
tean	doc_491521501800_item	2497391	et	3	main
ei	doc_491521501800_item	2497394	et	4	main
tea	doc_491521501800_item	2497395	et	4	main
mitte	doc_491521501800_item	2497396	et	3	main
maailma	doc_491521501800_item	2497424	et	4	main
olen	doc_491521501800_item	2497427	et	3	main
et	doc_491521501800_item	2497431	et	3	main
teadusel	doc_491521501800_item	2497432	et	3	main
on	doc_491521501800_item	2497433	et	4	main
lõpuks	doc_491521501800_item	2497439	et	4	main
teadmistega	doc_491521501800_item	2497425	et	4	main
kuid	doc_491521501800_item	2497435	et	4	main
ei	doc_491521501800_item	2497443	et	4	main
leidnud	doc_491521501802_item	2498944	et	4	main
piilub	doc_491521501802_item	2498957	et	3	main
tagant	doc_491521501802_item	2498959	et	3	main
tal	doc_491521501802_item	2498964	et	3	main
hüpata	doc_491521501802_item	2498966	et	4	main
kaks	doc_491521501802_item	2498969	et	3	main
poisid	doc_491521501802_item	2498978	et	4	main
on	doc_491521501802_item	2498979	et	4	main
puhkamas	doc_491521501802_item	2498935	et	3	main
päike	doc_491521501802_item	2498936	et	3	main
ja	doc_491521501802_item	2498938	et	3	main
endale	doc_491521501802_item	2498945	et	4	main
puu	doc_491521501802_item	2498952	et	4	main
puu	doc_491521501802_item	2498958	et	4	main
tahab	doc_491521501802_item	2498961	et	3	main
vee	doc_491521501802_item	2498968	et	3	main
kaklevad	doc_491521501802_item	2498971	et	4	main
mis	doc_491521501802_item	2498972	et	4	main
koerale	doc_491521501802_item	2498973	et	3	main
ültse	doc_491521501802_item	2498974	et	4	main
teised	doc_491521501802_item	2498977	et	4	main
taevale	doc_491521501802_item	2498985	et	3	main
tabada	doc_491521501802_item	2498990	et	3	main
jäänud	doc_491521501802_item	2498996	et	4	main
väikest	doc_491521501802_item	2499028	et	4	main
söövad	doc_491521501802_item	2499030	et	4	main
võileibi	doc_491521501802_item	2499031	et	4	main
oma	doc_491521501802_item	2499039	et	4	main
kõhu	doc_491521501802_item	2499040	et	3	main
mis	doc_491521501802_item	2499046	et	4	main
natuke	doc_491521501802_item	2499061	et	4	main
seisab	doc_491521501802_item	2499065	et	3	main
vahib	doc_491521501802_item	2499069	et	3	main
lastest	doc_491521501802_item	2499072	et	4	main
teeks	doc_491521501802_item	2499075	et	4	main
on	doc_491521501802_item	2499088	et	4	main
kuidas	doc_491521501802_item	2499095	et	3	main
oma	doc_491521501802_item	2499098	et	4	main
vaba	doc_491521501802_item	2499099	et	4	main
veedavad	doc_491521501802_item	2499101	et	3	main
suvepäeval	doc_491521501802_item	2498932	et	3	main
jõe	doc_491521501802_item	2498933	et	3	main
linnud	doc_491521501802_item	2498939	et	3	main
huvitavat	doc_491521501802_item	2498947	et	4	main
tegevust	doc_491521501802_item	2498948	et	4	main
otsa	doc_491521501802_item	2498953	et	4	main
kolmas	doc_491521501802_item	2498960	et	3	main
ei	doc_491521501802_item	2498975	et	4	main
et	doc_491521501802_item	2498986	et	3	main
harvaesineva	doc_491521501802_item	2498988	et	3	main
on	doc_491521501802_item	2498992	et	4	main
ajalehte	doc_491521501802_item	2498993	et	4	main
lugedes	doc_491521501802_item	2498994	et	3	main
pere	doc_491521501802_item	2498999	et	4	main
vanim	doc_491521501802_item	2499000	et	3	main
pildi	doc_491521501802_item	2498926	et	4	main
perekond	doc_491521501802_item	2498928	et	3	main
on	doc_491521501802_item	2498930	et	4	main
ilusal	doc_491521501802_item	2498931	et	3	main
ääres	doc_491521501802_item	2498934	et	4	main
paistab	doc_491521501802_item	2498937	et	3	main
laulavad	doc_491521501802_item	2498940	et	4	main
ning	doc_491521501802_item	2498941	et	3	main
kõik	doc_491521501802_item	2498942	et	4	main
on	doc_491521501802_item	2498943	et	4	main
üks	doc_491521501802_item	2498949	et	3	main
poiss	doc_491521501802_item	2498950	et	3	main
on	doc_491521501802_item	2498951	et	4	main
ja	doc_491521501802_item	2498955	et	3	main
teine	doc_491521501802_item	2498956	et	3	main
üle	doc_491521501802_item	2498967	et	3	main
rahulikumad	doc_491521501802_item	2498981	et	4	main
vaatab	doc_491521501802_item	2498983	et	3	main
mõne	doc_491521501802_item	2498987	et	3	main
teine	doc_491521501802_item	2498991	et	3	main
ja	doc_491521501802_item	2498998	et	3	main
tüdrukut	doc_491521501802_item	2499029	et	3	main
kõrval	doc_491521501802_item	2499032	et	4	main
istub	doc_491521501802_item	2499033	et	3	main
täis	doc_491521501802_item	2499041	et	4	main
seisab	doc_491521501802_item	2499047	et	3	main
saaks	doc_491521501802_item	2499054	et	3	main
seda	doc_491521501802_item	2499056	et	3	main
suuremaks	doc_491521501802_item	2499062	et	4	main
keskel	doc_491521501802_item	2499067	et	3	main
ei	doc_491521501802_item	2499074	et	4	main
oma	doc_491521501802_item	2499079	et	4	main
suure	doc_491521501802_item	2499080	et	3	main
pere	doc_491521501802_item	2499081	et	4	main
üle	doc_491521501802_item	2499082	et	3	main
väga	doc_491521501802_item	2499083	et	3	main
kohale	doc_491521501802_item	2499090	et	4	main
imetlevad	doc_491521501802_item	2499103	et	4	main
ka	doc_491521501802_item	2499104	et	3	main
kirjeldus	doc_491521501802_item	2498927	et	4	main
saar	doc_491521501802_item	2498929	et	3	main
mingit	doc_491521501802_item	2498946	et	3	main
roninud	doc_491521501802_item	2498954	et	4	main
proovida	doc_491521501802_item	2498962	et	3	main
kas	doc_491521501802_item	2498963	et	3	main
õnnestub	doc_491521501802_item	2498965	et	3	main
poissi	doc_491521501802_item	2498970	et	4	main
meeldi	doc_491521501802_item	2498976	et	4	main
palju	doc_491521501802_item	2498980	et	4	main
ema	doc_491521501802_item	2498997	et	4	main
tütar	doc_491521501802_item	2499001	et	3	main
istuvad	doc_491521501802_item	2499002	et	4	main
mõnusalt	doc_491521501802_item	2499003	et	4	main
toolides	doc_491521501802_item	2499004	et	3	main
ema	doc_491521501802_item	2499005	et	4	main
loeb	doc_491521501802_item	2499006	et	3	main
põnevat	doc_491521501802_item	2499007	et	3	main
romaani	doc_491521501802_item	2499008	et	4	main
ja	doc_491521501802_item	2499009	et	3	main
tütar	doc_491521501802_item	2499010	et	3	main
koob	doc_491521501802_item	2499011	et	3	main
ja	doc_491521501802_item	2499013	et	3	main
kampsunit	doc_491521501802_item	2499012	et	3	main
vaatab	doc_491521501802_item	2499014	et	3	main
imikut	doc_491521501802_item	2499015	et	3	main
kes	doc_491521501802_item	2499016	et	4	main
karjub	doc_491521501802_item	2499017	et	3	main
vaiba	doc_491521501802_item	2499019	et	3	main
peal	doc_491521501802_item	2499020	et	4	main
peale	doc_491521501802_item	2499022	et	4	main
söönud	doc_491521501802_item	2499038	et	4	main
ja	doc_491521501802_item	2499050	et	3	main
et	doc_491521501802_item	2499052	et	3	main
kui	doc_491521501802_item	2499059	et	3	main
isa	doc_491521501802_item	2499064	et	4	main
on	doc_491521501802_item	2499077	et	4	main
ta	doc_491521501802_item	2499078	et	4	main
mõned	doc_491521501802_item	2499085	et	3	main
kõrvalt	doc_491521501802_item	2499094	et	4	main
perekond	doc_491521501802_item	2499096	et	3	main
nad	doc_491521501802_item	2499102	et	3	main
juuksed	doc_491521501803_item	2499121	et	3	main
tuules	doc_491521501803_item	2499123	et	3	main
puu	doc_491521501803_item	2499130	et	4	main
ja	doc_491521501803_item	2499134	et	3	main
pilkudelt	doc_491521501803_item	2499136	et	3	main
tahab	doc_491521501803_item	2499138	et	3	main
tükk	doc_491521501803_item	2499140	et	3	main
üksinda	doc_491521501803_item	2499142	et	4	main
rahus	doc_491521501803_item	2499145	et	4	main
siit	doc_491521501803_item	2499151	et	3	main
nii	doc_491521501803_item	2499152	et	3	main
tore	doc_491521501803_item	2499153	et	3	main
vaade	doc_491521501803_item	2499154	et	3	main
tüdrukutele	doc_491521501803_item	2499155	et	4	main
on	doc_491521501803_item	2499160	et	4	main
meele	doc_491521501803_item	2499166	et	4	main
selle	doc_491521501803_item	2499173	et	4	main
väikse	doc_491521501803_item	2499174	et	4	main
herman	doc_491521501803_item	2499182	et	4	main
kõik	doc_491521501803_item	2499194	et	4	main
üks	doc_491521501802_item	2498982	et	3	main
binokliga	doc_491521501802_item	2498984	et	3	main
linnu	doc_491521501802_item	2498989	et	4	main
magama	doc_491521501802_item	2498995	et	3	main
maas	doc_491521501802_item	2499018	et	4	main
muru	doc_491521501802_item	2499021	et	4	main
on	doc_491521501802_item	2499023	et	4	main
kaetud	doc_491521501802_item	2499024	et	4	main
piknik	doc_491521501802_item	2499025	et	3	main
kus	doc_491521501802_item	2499026	et	3	main
kaks	doc_491521501802_item	2499027	et	3	main
on	doc_491521501802_item	2499036	et	4	main
juba	doc_491521501802_item	2499037	et	3	main
isa	doc_491521501802_item	2499044	et	4	main
vintpüssi	doc_491521501802_item	2499045	et	4	main
puud	doc_491521501802_item	2499049	et	4	main
proovida	doc_491521501802_item	2499058	et	3	main
ta	doc_491521501802_item	2499060	et	4	main
pere	doc_491521501802_item	2499066	et	4	main
et	doc_491521501802_item	2499070	et	3	main
keegi	doc_491521501802_item	2499071	et	4	main
rumalusi	doc_491521501802_item	2499073	et	4	main
uhke	doc_491521501802_item	2499084	et	4	main
inimesed	doc_491521501802_item	2499087	et	3	main
ka	doc_491521501802_item	2499089	et	3	main
sattunud	doc_491521501802_item	2499091	et	4	main
ja	doc_491521501802_item	2499092	et	3	main
vaatavad	doc_491521501802_item	2499093	et	4	main
päeva	doc_491521501802_item	2499100	et	4	main
ilusat	doc_491521501802_item	2499106	et	3	main
aga	doc_491521501803_item	2499124	et	3	main
tuul	doc_491521501803_item	2499126	et	3	main
meeldivalt	doc_491521501803_item	2499128	et	4	main
oksad	doc_491521501803_item	2499131	et	3	main
teiste	doc_491521501803_item	2499135	et	4	main
mõelda	doc_491521501803_item	2499144	et	4	main
oma	doc_491521501803_item	2499146	et	4	main
elu	doc_491521501803_item	2499147	et	4	main
peale	doc_491521501803_item	2499148	et	4	main
tüdrukud	doc_491521501803_item	2499157	et	3	main
ununevad	doc_491521501803_item	2499158	et	4	main
saab	doc_491521501803_item	2499168	et	3	main
hermani	doc_491521501803_item	2499170	et	4	main
viimane	doc_491521501803_item	2499171	et	3	main
nende	doc_491521501803_item	2499177	et	4	main
armsate	doc_491521501803_item	2499178	et	3	main
inimestega	doc_491521501803_item	2499179	et	3	main
haridust	doc_491521501803_item	2499191	et	4	main
kõige	doc_491521501803_item	2499201	et	4	main
tüüpi	doc_491521501803_item	2499203	et	4	main
näiteks	doc_491521501803_item	2499204	et	4	main
lahkuminek	doc_491521501803_item	2499205	et	3	main
sellest	doc_491521501803_item	2499206	et	4	main
millega	doc_491521501803_item	2499207	et	3	main
on	doc_491521501803_item	2499208	et	4	main
saaks	doc_491521501803_item	2499217	et	3	main
on	doc_491521501803_item	2499225	et	4	main
mängivad	doc_491521501803_item	2499241	et	4	main
peab	doc_491521501803_item	2499253	et	4	main
loobuma	doc_491521501803_item	2499254	et	3	main
kui	doc_491521501803_item	2499262	et	3	main
eri	doc_491521501803_item	2499274	et	4	main
ja	doc_491521501803_item	2499281	et	3	main
garantiit	doc_491521501803_item	2499292	et	4	main
ise	doc_491521501803_item	2499295	et	4	main
all	doc_491521501803_item	2499301	et	3	main
ta	doc_491521501803_item	2499306	et	4	main
poiss	doc_491521501802_item	2499034	et	3	main
kes	doc_491521501802_item	2499035	et	4	main
ta	doc_491521501802_item	2499042	et	4	main
vaatab	doc_491521501802_item	2499043	et	3	main
vastu	doc_491521501802_item	2499048	et	3	main
loodab	doc_491521501802_item	2499051	et	3	main
ta	doc_491521501802_item	2499053	et	4	main
ka	doc_491521501802_item	2499055	et	3	main
mõnikord	doc_491521501802_item	2499057	et	3	main
kasvab	doc_491521501802_item	2499063	et	3	main
ja	doc_491521501802_item	2499068	et	3	main
tegelikult	doc_491521501802_item	2499076	et	4	main
suvalised	doc_491521501802_item	2499086	et	4	main
saar	doc_491521501802_item	2499097	et	3	main
pere	doc_491521501802_item	2499105	et	4	main
hobust	doc_491521501802_item	2499107	et	4	main
kes	doc_491521501802_item	2499108	et	4	main
arutab	doc_491521501802_item	2499109	et	3	main
miks	doc_491521501802_item	2499110	et	4	main
keegi	doc_491521501802_item	2499111	et	4	main
temaga	doc_491521501802_item	2499112	et	3	main
ei	doc_491521501802_item	2499113	et	4	main
ratsuta	doc_491521501802_item	2499114	et	4	main
ümberjutustus	doc_491521501803_item	2499115	et	3	main
herman	doc_491521501803_item	2499116	et	4	main
on	doc_491521501803_item	2499117	et	4	main
roninud	doc_491521501803_item	2499118	et	4	main
otsa	doc_491521501803_item	2499120	et	4	main
puu	doc_491521501803_item	2499119	et	4	main
kuid	doc_491521501803_item	2499156	et	4	main
muud	doc_491521501803_item	2499162	et	4	main
mis	doc_491521501803_item	2499164	et	4	main
järve	doc_491521501803_item	2499175	et	4	main
peab	doc_491521501803_item	2499181	et	4	main
üksinda	doc_491521501803_item	2499185	et	4	main
noorel	doc_491521501803_item	2499186	et	3	main
inimesel	doc_491521501803_item	2499187	et	3	main
on	doc_491521501803_item	2499188	et	4	main
ju	doc_491521501803_item	2499189	et	3	main
vaja	doc_491521501803_item	2499190	et	4	main
ainult	doc_491521501803_item	2499216	et	4	main
see	doc_491521501803_item	2499125	et	3	main
on	doc_491521501803_item	2499127	et	4	main
soe	doc_491521501803_item	2499129	et	4	main
päikeselt	doc_491521501803_item	2499133	et	4	main
lehvivad	doc_491521501803_item	2499122	et	4	main
kaitsevad	doc_491521501803_item	2499132	et	4	main
olla	doc_491521501803_item	2499139	et	3	main
aega	doc_491521501803_item	2499141	et	4	main
ja	doc_491521501803_item	2499143	et	3	main
on	doc_491521501803_item	2499150	et	4	main
midagi	doc_491521501803_item	2499161	et	4	main
see	doc_491521501803_item	2499167	et	3	main
ääres	doc_491521501803_item	2499176	et	4	main
kolima	doc_491521501803_item	2499183	et	3	main
ära	doc_491521501803_item	2499184	et	4	main
ootavad	doc_491521501803_item	2499196	et	4	main
kogemused	doc_491521501803_item	2499197	et	3	main
ei	doc_491521501803_item	2499198	et	4	main
loobuda	doc_491521501803_item	2499214	et	3	main
nüüd	doc_491521501803_item	2499221	et	4	main
küll	doc_491521501803_item	2499252	et	4	main
on	doc_491521501803_item	2499263	et	4	main
tahakski	doc_491521501803_item	2499267	et	3	main
otsustada	doc_491521501803_item	2499273	et	3	main
otsustadki	doc_491521501803_item	2499286	et	3	main
poisse	doc_491521501803_item	2499303	et	4	main
tüdrukuid	doc_491521501803_item	2499305	et	4	main
ja	doc_491521501803_item	2499310	et	3	main
heas	doc_491521501803_item	2499314	et	3	main
herman	doc_491521501803_item	2499137	et	4	main
pealegi	doc_491521501803_item	2499149	et	4	main
ruttu	doc_491521501803_item	2499159	et	4	main
tähtsamat	doc_491521501803_item	2499163	et	4	main
kõidab	doc_491521501803_item	2499165	et	4	main
olema	doc_491521501803_item	2499169	et	4	main
suvi	doc_491521501803_item	2499172	et	3	main
sügisel	doc_491521501803_item	2499180	et	3	main
ja	doc_491521501803_item	2499192	et	3	main
kogemusi	doc_491521501803_item	2499193	et	3	main
ole	doc_491521501803_item	2499199	et	4	main
meeldivamat	doc_491521501803_item	2499202	et	4	main
tahaks	doc_491521501803_item	2499213	et	3	main
peatada	doc_491521501803_item	2499218	et	3	main
just	doc_491521501803_item	2499220	et	3	main
siin	doc_491521501803_item	2499224	et	4	main
nii	doc_491521501803_item	2499226	et	3	main
ei	doc_491521501803_item	2499230	et	4	main
tahaks	doc_491521501803_item	2499231	et	3	main
kuhugi	doc_491521501803_item	2499232	et	4	main
minna	doc_491521501803_item	2499233	et	3	main
aga	doc_491521501803_item	2499234	et	3	main
kell	doc_491521501803_item	2499235	et	3	main
muudkui	doc_491521501803_item	2499236	et	3	main
tiksub	doc_491521501803_item	2499237	et	3	main
edasi	doc_491521501803_item	2499238	et	3	main
võimalikkudest	doc_491521501803_item	2499246	et	3	main
midagi	doc_491521501803_item	2499258	et	4	main
teist	doc_491521501803_item	2499259	et	4	main
eriti	doc_491521501803_item	2499260	et	3	main
siis	doc_491521501803_item	2499261	et	3	main
kõike	doc_491521501803_item	2499268	et	4	main
vähemalt	doc_491521501803_item	2499270	et	4	main
ei	doc_491521501803_item	2499271	et	4	main
võimaluste	doc_491521501803_item	2499275	et	3	main
valesti	doc_491521501803_item	2499287	et	3	main
ei	doc_491521501803_item	2499289	et	4	main
ju	doc_491521501803_item	2499291	et	3	main
vastutad	doc_491521501803_item	2499296	et	3	main
kõige	doc_491521501803_item	2499297	et	4	main
eest	doc_491521501803_item	2499298	et	4	main
herman	doc_491521501803_item	2499299	et	4	main
kisavaid	doc_491521501803_item	2499302	et	4	main
ronida	doc_491521501803_item	2499308	et	3	main
liituda	doc_491521501803_item	2499311	et	3	main
hulka	doc_491521501803_item	2499313	et	4	main
ees	doc_491521501803_item	2499195	et	4	main
just	doc_491521501803_item	2499200	et	3	main
harjunud	doc_491521501803_item	2499209	et	4	main
ja	doc_491521501803_item	2499210	et	3	main
millest	doc_491521501803_item	2499211	et	3	main
ei	doc_491521501803_item	2499212	et	4	main
kui	doc_491521501803_item	2499215	et	3	main
aja	doc_491521501803_item	2499219	et	4	main
just	doc_491521501803_item	2499223	et	3	main
hea	doc_491521501803_item	2499227	et	4	main
et	doc_491521501803_item	2499229	et	3	main
ja	doc_491521501803_item	2499239	et	3	main
lapsed	doc_491521501803_item	2499240	et	3	main
midagi	doc_491521501803_item	2499244	et	4	main
elu	doc_491521501803_item	2499245	et	4	main
ühest	doc_491521501803_item	2499255	et	4	main
et	doc_491521501803_item	2499256	et	3	main
saada	doc_491521501803_item	2499257	et	4	main
alles	doc_491521501803_item	2499264	et	3	main
ja	doc_491521501803_item	2499266	et	3	main
või	doc_491521501803_item	2499269	et	4	main
vahel	doc_491521501803_item	2499276	et	4	main
sind	doc_491521501803_item	2499278	et	4	main
otsustama	doc_491521501803_item	2499280	et	3	main
tulevikul	doc_491521501803_item	2499288	et	4	main
ole	doc_491521501803_item	2499290	et	4	main
kuid	doc_491521501803_item	2499293	et	4	main
siiski	doc_491521501803_item	2499294	et	4	main
kadestab	doc_491521501803_item	2499300	et	3	main
ja	doc_491521501803_item	2499304	et	3	main
alla	doc_491521501803_item	2499309	et	3	main
korraks	doc_491521501803_item	2499318	et	4	main
sest	doc_491521501803_item	2499222	et	4	main
olla	doc_491521501803_item	2499228	et	3	main
murul	doc_491521501803_item	2499242	et	3	main
teadmata	doc_491521501803_item	2499243	et	4	main
mustadest	doc_491521501803_item	2499247	et	3	main
külgedest	doc_491521501803_item	2499248	et	4	main
herman	doc_491521501803_item	2499249	et	4	main
ohkab	doc_491521501803_item	2499250	et	3	main
miks	doc_491521501803_item	2499251	et	4	main
noor	doc_491521501803_item	2499265	et	3	main
oska	doc_491521501803_item	2499272	et	4	main
siis	doc_491521501803_item	2499277	et	3	main
sunnitakse	doc_491521501803_item	2499279	et	4	main
mis	doc_491521501803_item	2499282	et	4	main
siis	doc_491521501803_item	2499283	et	3	main
saab	doc_491521501803_item	2499284	et	3	main
kui	doc_491521501803_item	2499285	et	3	main
otsustab	doc_491521501803_item	2499307	et	3	main
nende	doc_491521501803_item	2499312	et	4	main
seltsis	doc_491521501803_item	2499315	et	4	main
mured	doc_491521501803_item	2499316	et	3	main
ununevad	doc_491521501803_item	2499317	et	4	main
kirjeldus	doc_491521501808_item	2499998	et	4	main
üks	doc_491521501808_item	2499999	et	3	main
pere	doc_491521501808_item	2500000	et	4	main
äärde	doc_491521501808_item	2500004	et	4	main
mail	doc_491521501808_item	2500013	et	4	main
ei	doc_491521501808_item	2500015	et	4	main
olid	doc_491521501808_item	2500026	et	4	main
kohta	doc_491521501808_item	2500030	et	4	main
mitte	doc_491521501808_item	2500031	et	3	main
inimesi	doc_491521501808_item	2500039	et	4	main
peoks	doc_491521501808_item	2500056	et	4	main
lastele	doc_491521501808_item	2500057	et	4	main
söömist	doc_491521501808_item	2500064	et	4	main
kõigidel	doc_491521501808_item	2500065	et	4	main
oli	doc_491521501808_item	2500066	et	3	main
sealt	doc_491521501808_item	2500090	et	4	main
poiss	doc_491521501808_item	2500095	et	3	main
oli	doc_491521501808_item	2500097	et	3	main
piilus	doc_491521501808_item	2500099	et	4	main
teisi	doc_491521501808_item	2500104	et	4	main
tõsiselt	doc_491521501808_item	2500107	et	4	main
mis	doc_491521501808_item	2500109	et	4	main
teeb	doc_491521501808_item	2500110	et	3	main
lapselaps	doc_491521501808_item	2500115	et	4	main
mängis	doc_491521501808_item	2500116	et	3	main
koer	doc_491521501808_item	2500127	et	3	main
kes	doc_491521501808_item	2500137	et	4	main
magas	doc_491521501808_item	2500138	et	4	main
maal	doc_491521501808_item	2500139	et	4	main
naerma	doc_491521501808_item	2500150	et	3	main
pildi	doc_491521501808_item	2499997	et	4	main
jõe	doc_491521501808_item	2500003	et	3	main
ja	doc_491521501808_item	2500008	et	3	main
paistis	doc_491521501808_item	2500010	et	3	main
esimesel	doc_491521501808_item	2500012	et	3	main
tavaliselt	doc_491521501808_item	2500014	et	4	main
mets	doc_491521501808_item	2500024	et	3	main
nad	doc_491521501808_item	2500029	et	3	main
palju	doc_491521501808_item	2500038	et	4	main
kus	doc_491521501808_item	2500047	et	3	main
jõgi	doc_491521501808_item	2500048	et	3	main
ühendust	doc_491521501808_item	2500050	et	4	main
oma	doc_491521501808_item	2500067	et	4	main
otsa	doc_491521501808_item	2500087	et	4	main
mis	doc_491521501808_item	2500096	et	4	main
noorem	doc_491521501808_item	2500098	et	4	main
kõige	doc_491521501808_item	2500112	et	4	main
armsam	doc_491521501808_item	2500113	et	4	main
kaks	doc_491521501808_item	2500120	et	3	main
vahel	doc_491521501808_item	2500125	et	4	main
nende	doc_491521501808_item	2500129	et	4	main
esimest	doc_491521501808_item	2500143	et	4	main
korda	doc_491521501808_item	2500144	et	4	main
nägi	doc_491521501808_item	2500145	et	3	main
hakkas	doc_491521501808_item	2500148	et	3	main
noorem	doc_491521501808_item	2500151	et	4	main
kaks	doc_491521501808_item	2500164	et	3	main
tüdrukut	doc_491521501808_item	2500165	et	3	main
söövad	doc_491521501808_item	2500166	et	4	main
kooke	doc_491521501808_item	2500167	et	4	main
vaatama	doc_491521501808_item	2500179	et	3	main
kolmas	doc_491521501808_item	2500185	et	3	main
ja	doc_491521501808_item	2500190	et	3	main
sest	doc_491521501808_item	2500192	et	4	main
temal	doc_491521501808_item	2500193	et	3	main
on	doc_491521501809_item	2500223	et	4	main
ei	doc_491521501809_item	2500227	et	4	main
lisapealkirja	doc_491521501809_item	2500232	et	4	main
ilm	doc_491521501808_item	2500005	et	3	main
päike	doc_491521501808_item	2500009	et	3	main
sõitis	doc_491521501808_item	2500001	et	3	main
ilus	doc_491521501808_item	2500007	et	4	main
önneks	doc_491521501808_item	2500021	et	4	main
peres	doc_491521501808_item	2500023	et	3	main
on	doc_491521501808_item	2500037	et	4	main
pere	doc_491521501808_item	2500041	et	4	main
endale	doc_491521501808_item	2500044	et	4	main
läks	doc_491521501808_item	2500054	et	3	main
kõige	doc_491521501808_item	2500058	et	4	main
rohkem	doc_491521501808_item	2500059	et	4	main
meeldis	doc_491521501808_item	2500060	et	3	main
väike	doc_491521501808_item	2500061	et	4	main
puhkus	doc_491521501808_item	2500062	et	3	main
tegevus	doc_491521501808_item	2500068	et	4	main
nagu	doc_491521501808_item	2500091	et	3	main
ümbrust	doc_491521501808_item	2500093	et	3	main
teine	doc_491521501808_item	2500094	et	3	main
puu	doc_491521501808_item	2500100	et	4	main
tagant	doc_491521501808_item	2500101	et	3	main
ja	doc_491521501808_item	2500102	et	3	main
ääres	doc_491521501808_item	2500119	et	4	main
venda	doc_491521501808_item	2500122	et	4	main
oma	doc_491521501808_item	2500124	et	4	main
päikese	doc_491521501808_item	2500140	et	4	main
lindu	doc_491521501808_item	2500146	et	4	main
ja	doc_491521501808_item	2500147	et	3	main
pärast	doc_491521501808_item	2500160	et	4	main
järgib	doc_491521501808_item	2500161	et	3	main
see	doc_491521501808_item	2500182	et	3	main
jäoks	doc_491521501808_item	2500199	et	4	main
või	doc_491521501809_item	2500231	et	4	main
pelakirjad	doc_491521501809_item	2500237	et	4	main
pilku	doc_491521501809_item	2500238	et	4	main
väiksemateks	doc_491521501809_item	2500244	et	4	main
suhteliselt	doc_491521501809_item	2500250	et	4	main
reas	doc_491521501809_item	2500256	et	3	main
näiteks	doc_491521501809_item	2500272	et	4	main
selline	doc_491521501809_item	2500276	et	4	main
narvas	doc_491521501809_item	2500278	et	4	main
levib	doc_491521501809_item	2500279	et	3	main
heroiin	doc_491521501809_item	2500280	et	3	main
jõhvi	doc_491521501809_item	2500281	et	4	main
räägitakse	doc_491521501809_item	2500321	et	3	main
on	doc_491521501809_item	2500335	et	4	main
kõigi	doc_491521501809_item	2500345	et	4	main
tekstiveergude	doc_491521501809_item	2500346	et	3	main
kasutatud	doc_491521501809_item	2500365	et	4	main
klassikaline	doc_491521501809_item	2500366	et	4	main
kenasti	doc_491521501809_item	2500372	et	3	main
domineerivalt	doc_491521501809_item	2500382	et	4	main
halvetica	doc_491521501809_item	2500397	et	4	main
lisat	doc_491521501809_item	2500427	et	4	main
aga	doc_491521501809_item	2500428	et	3	main
tuleb	doc_491521501809_item	2500429	et	3	main
spordi	doc_491521501809_item	2500435	et	4	main
rubriik	doc_491521501809_item	2500436	et	3	main
sama	doc_491521501809_item	2500445	et	4	main
mõned	doc_491521501809_item	2500449	et	3	main
on	doc_491521501809_item	2500452	et	4	main
plokk-kirjas	doc_491521501809_item	2500453	et	4	main
aga	doc_491521501809_item	2500454	et	3	main
see	doc_491521501809_item	2500455	et	3	main
puhkama	doc_491521501808_item	2500002	et	3	main
oli	doc_491521501808_item	2500006	et	3	main
eredalt	doc_491521501808_item	2500011	et	4	main
ole	doc_491521501808_item	2500016	et	4	main
nii	doc_491521501808_item	2500017	et	3	main
soe	doc_491521501808_item	2500018	et	4	main
sellel	doc_491521501808_item	2500019	et	4	main
päeval	doc_491521501808_item	2500020	et	3	main
kõik	doc_491521501808_item	2500025	et	4	main
ääres	doc_491521501808_item	2500036	et	4	main
lõpude-lõpuks	doc_491521501808_item	2500042	et	4	main
leidsid	doc_491521501808_item	2500043	et	4	main
kohta	doc_491521501808_item	2500045	et	4	main
suureks	doc_491521501808_item	2500055	et	4	main
vanemad	doc_491521501808_item	2500069	et	4	main
vaatas	doc_491521501808_item	2500089	et	3	main
tornist	doc_491521501808_item	2500092	et	3	main
salaja	doc_491521501808_item	2500105	et	3	main
vanaisa	doc_491521501808_item	2500106	et	4	main
vaatas	doc_491521501808_item	2500108	et	3	main
tema	doc_491521501808_item	2500111	et	4	main
anedega	doc_491521501808_item	2500117	et	4	main
järve	doc_491521501808_item	2500118	et	4	main
teist	doc_491521501808_item	2500121	et	4	main
kaklesid	doc_491521501808_item	2500123	et	4	main
ja	doc_491521501808_item	2500126	et	3	main
tunneb	doc_491521501808_item	2500154	et	3	main
tüdrukud	doc_491521501808_item	2500175	et	3	main
mis	doc_491521501808_item	2500180	et	4	main
suur	doc_491521501808_item	2500183	et	3	main
poeg	doc_491521501808_item	2500186	et	3	main
on	doc_491521501808_item	2500188	et	4	main
teksti	doc_491521501809_item	2500230	et	4	main
juhtivad	doc_491521501809_item	2500236	et	4	main
liigendavad	doc_491521501809_item	2500242	et	4	main
leheküljed	doc_491521501809_item	2500243	et	3	main
on	doc_491521501809_item	2500249	et	4	main
sõna	doc_491521501809_item	2500255	et	4	main
mõned	doc_491521501809_item	2500260	et	3	main
kuid	doc_491521501809_item	2500268	et	4	main
on	doc_491521501809_item	2500269	et	4	main
leheküljel	doc_491521501809_item	2500274	et	3	main
pelkiri	doc_491521501809_item	2500277	et	4	main
peakse	doc_491521501809_item	2500322	et	4	main
tegin	doc_491521501809_item	2500327	et	3	main
ajalehe	doc_491521501809_item	2500330	et	3	main
tugevalt	doc_491521501809_item	2500332	et	4	main
pelkirjafraasid	doc_491521501809_item	2500334	et	4	main
kohale	doc_491521501809_item	2500347	et	4	main
et	doc_491521501809_item	2500348	et	3	main
alasti	doc_491521501809_item	2500349	et	3	main
veerud	doc_491521501809_item	2500350	et	4	main
on	doc_491521501809_item	2500361	et	4	main
konservatiivne	doc_491521501809_item	2500362	et	3	main
ajaleht	doc_491521501809_item	2500363	et	3	main
on	doc_491521501809_item	2500364	et	4	main
baskerville	doc_491521501809_item	2500369	et	4	main
nad	doc_491521501809_item	2500374	et	3	main
esitatud	doc_491521501809_item	2500381	et	4	main
kirjas	doc_491521501809_item	2500384	et	4	main
ajalehe	doc_491521501809_item	2500387	et	3	main
jõhvi	doc_491521501809_item	2500389	et	4	main
see	doc_491521501809_item	2500398	et	3	main
sport	doc_491521501809_item	2500422	et	3	main
alguse	doc_491521501809_item	2500430	et	3	main
antiikva	doc_491521501809_item	2500432	et	4	main
pealkirja	doc_491521501809_item	2500433	et	4	main
lisale	doc_491521501809_item	2500442	et	3	main
oli	doc_491521501808_item	2500022	et	3	main
rõõmsad	doc_491521501808_item	2500027	et	3	main
leidsid	doc_491521501808_item	2500028	et	4	main
kohe	doc_491521501808_item	2500032	et	4	main
sest	doc_491521501808_item	2500033	et	4	main
pühapäeval	doc_491521501808_item	2500034	et	3	main
jõe	doc_491521501808_item	2500035	et	3	main
suur	doc_491521501808_item	2500040	et	3	main
seal	doc_491521501808_item	2500046	et	4	main
võtab	doc_491521501808_item	2500049	et	3	main
järvega	doc_491521501808_item	2500051	et	3	main
väike	doc_491521501808_item	2500052	et	4	main
piknik	doc_491521501808_item	2500053	et	3	main
peale	doc_491521501808_item	2500063	et	4	main
inimesed	doc_491521501808_item	2500070	et	3	main
olid	doc_491521501808_item	2500071	et	4	main
väsind	doc_491521501808_item	2500072	et	4	main
ja	doc_491521501808_item	2500073	et	3	main
puhkasid	doc_491521501808_item	2500074	et	4	main
natuke	doc_491521501808_item	2500075	et	4	main
eemal	doc_491521501808_item	2500076	et	3	main
nii	doc_491521501808_item	2500077	et	3	main
kaua	doc_491521501808_item	2500078	et	3	main
kui	doc_491521501808_item	2500079	et	3	main
lapsed	doc_491521501808_item	2500080	et	3	main
mürasid	doc_491521501808_item	2500081	et	4	main
kõige	doc_491521501808_item	2500082	et	4	main
poiss	doc_491521501808_item	2500084	et	3	main
vanem	doc_491521501808_item	2500083	et	4	main
ronis	doc_491521501808_item	2500085	et	4	main
puu	doc_491521501808_item	2500086	et	4	main
ja	doc_491521501808_item	2500088	et	3	main
jälgis	doc_491521501808_item	2500103	et	4	main
lapselaps	doc_491521501808_item	2500114	et	4	main
haukus	doc_491521501808_item	2500128	et	3	main
peale	doc_491521501808_item	2500130	et	4	main
koer	doc_491521501808_item	2500131	et	3	main
kõva	doc_491521501808_item	2500132	et	4	main
hälega	doc_491521501808_item	2500133	et	4	main
häiris	doc_491521501808_item	2500134	et	3	main
vanaisa	doc_491521501808_item	2500135	et	4	main
tuttavat	doc_491521501808_item	2500136	et	3	main
käes	doc_491521501808_item	2500141	et	4	main
imik	doc_491521501808_item	2500142	et	3	main
rõõmsalt	doc_491521501808_item	2500149	et	4	main
lapsepõlvest	doc_491521501808_item	2500153	et	4	main
neid	doc_491521501808_item	2500162	et	4	main
binookliga	doc_491521501808_item	2500163	et	4	main
tulid	doc_491521501808_item	2500177	et	4	main
teeb	doc_491521501808_item	2500181	et	3	main
peres	doc_491521501808_item	2500187	et	3	main
kurb	doc_491521501808_item	2500189	et	3	main
tõsine	doc_491521501808_item	2500191	et	4	main
on	doc_491521501808_item	2500194	et	4	main
esmaspäeval	doc_491521501808_item	2500195	et	3	main
eksam	doc_491521501808_item	2500196	et	3	main
see	doc_491521501808_item	2500200	et	3	main
päev	doc_491521501808_item	2500201	et	3	main
oli	doc_491521501808_item	2500202	et	3	main
pikk	doc_491521501808_item	2500203	et	4	main
ja	doc_491521501808_item	2500204	et	3	main
armas	doc_491521501808_item	2500205	et	3	main
puhkasid	doc_491521501808_item	2500206	et	4	main
nad	doc_491521501808_item	2500207	et	3	main
hea	doc_491521501808_item	2500208	et	4	main
meelege	doc_491521501808_item	2500209	et	4	main
ja	doc_491521501808_item	2500210	et	3	main
tuled	doc_491521501808_item	2500211	et	4	main
järdmisel	doc_491521501808_item	2500212	et	4	main
pühapäeval	doc_491521501808_item	2500213	et	3	main
jälle	doc_491521501808_item	2500214	et	3	main
siia	doc_491521501808_item	2500215	et	4	main
analüüs	doc_491521501809_item	2500216	et	3	main
põhjarannik	doc_491521501809_item	2500217	et	3	main
ajalehe	doc_491521501809_item	2500218	et	3	main
analüüs	doc_491521501809_item	2500219	et	3	main
pealkirjad	doc_491521501809_item	2500220	et	3	main
põhjaranniku	doc_491521501809_item	2500221	et	3	main
ning	doc_491521501809_item	2500226	et	3	main
osadeks	doc_491521501809_item	2500245	et	3	main
pelkirja	doc_491521501809_item	2500246	et	4	main
pikkus	doc_491521501809_item	2500247	et	4	main
rida	doc_491521501809_item	2500253	et	4	main
3-4	doc_491521501809_item	2500254	et	2	main
pelkirjad	doc_491521501809_item	2500262	et	4	main
küll	doc_491521501809_item	2500265	et	4	main
ja	doc_491521501809_item	2500282	et	3	main
kohtla-järve	doc_491521501809_item	2500283	et	4	main
kohtla-järve	doc_491521501809_item	2500316	et	4	main
ka	doc_491521501809_item	2500323	et	3	main
sellega	doc_491521501809_item	2500326	et	3	main
ühele	doc_491521501809_item	2500337	et	3	main
natukene	doc_491521501809_item	2500344	et	4	main
seostuma	doc_491521501809_item	2500354	et	3	main
vend	doc_491521501808_item	2500152	et	3	main
huvi	doc_491521501808_item	2500155	et	4	main
linnude	doc_491521501808_item	2500156	et	3	main
vastu	doc_491521501808_item	2500157	et	3	main
ja	doc_491521501808_item	2500158	et	3	main
selle	doc_491521501808_item	2500159	et	4	main
ja	doc_491521501808_item	2500168	et	3	main
ei	doc_491521501808_item	2500169	et	4	main
lähegi	doc_491521501808_item	2500170	et	4	main
mängima	doc_491521501808_item	2500171	et	3	main
ratsutasid	doc_491521501808_item	2500172	et	4	main
mitte	doc_491521501808_item	2500173	et	3	main
kaugel	doc_491521501808_item	2500174	et	4	main
ja	doc_491521501808_item	2500176	et	3	main
ka	doc_491521501808_item	2500178	et	3	main
pere	doc_491521501808_item	2500184	et	4	main
nende	doc_491521501808_item	2500197	et	4	main
inimeste	doc_491521501808_item	2500198	et	3	main
pealkirjad	doc_491521501809_item	2500222	et	3	main
iseseisvad	doc_491521501809_item	2500224	et	3	main
tervikud	doc_491521501809_item	2500225	et	3	main
vaja	doc_491521501809_item	2500228	et	4	main
mõistmiseks	doc_491521501809_item	2500229	et	4	main
kujundusest	doc_491521501809_item	2500234	et	4	main
lähtudes	doc_491521501809_item	2500235	et	3	main
mööda	doc_491521501809_item	2500240	et	4	main
ja	doc_491521501809_item	2500241	et	3	main
pelkirjad	doc_491521501809_item	2500248	et	4	main
on	doc_491521501809_item	2500258	et	4	main
rohkem	doc_491521501809_item	2500266	et	4	main
infot	doc_491521501809_item	2500267	et	3	main
viiendal	doc_491521501809_item	2500273	et	3	main
kandis	doc_491521501809_item	2500284	et	4	main
moonilahus	doc_491521501809_item	2500285	et	4	main
pealkirja	doc_491521501809_item	2500286	et	4	main
esimene	doc_491521501809_item	2500287	et	3	main
rida	doc_491521501809_item	2500288	et	4	main
on	doc_491521501809_item	2500289	et	4	main
ülipikk	doc_491521501809_item	2500290	et	4	main
ja	doc_491521501809_item	2500291	et	3	main
sellega	doc_491521501809_item	2500292	et	3	main
kaotab	doc_491521501809_item	2500293	et	3	main
oma	doc_491521501809_item	2500294	et	4	main
ilmekuse	doc_491521501809_item	2500295	et	4	main
ja	doc_491521501809_item	2500296	et	3	main
teravuse	doc_491521501809_item	2500297	et	4	main
mis	doc_491521501809_item	2500298	et	4	main
lugejat	doc_491521501809_item	2500299	et	4	main
tõmbab	doc_491521501809_item	2500300	et	3	main
pigem	doc_491521501809_item	2500301	et	3	main
oleks	doc_491521501809_item	2500302	et	3	main
narvas	doc_491521501809_item	2500303	et	4	main
levib	doc_491521501809_item	2500304	et	3	main
heroiin	doc_491521501809_item	2500305	et	3	main
kohtla-järve	doc_491521501809_item	2500306	et	4	main
kandis	doc_491521501809_item	2500307	et	4	main
moonilahus	doc_491521501809_item	2500308	et	4	main
mina	doc_491521501809_item	2500309	et	4	main
võtsin	doc_491521501809_item	2500310	et	3	main
jõhvi	doc_491521501809_item	2500311	et	4	main
ära	doc_491521501809_item	2500312	et	4	main
sest	doc_491521501809_item	2500313	et	4	main
see	doc_491521501809_item	2500314	et	3	main
lugemist	doc_491521501809_item	2500233	et	4	main
lehekülgede	doc_491521501809_item	2500239	et	4	main
lühikesed	doc_491521501809_item	2500251	et	4	main
1-2	doc_491521501809_item	2500252	et	2	main
aga	doc_491521501809_item	2500257	et	3	main
ka	doc_491521501809_item	2500259	et	3	main
pikad	doc_491521501809_item	2500261	et	4	main
mis	doc_491521501809_item	2500263	et	4	main
annavad	doc_491521501809_item	2500264	et	3	main
raskemini	doc_491521501809_item	2500270	et	4	main
loetavad	doc_491521501809_item	2500271	et	4	main
on	doc_491521501809_item	2500275	et	4	main
on	doc_491521501809_item	2500315	et	4	main
osa	doc_491521501809_item	2500317	et	4	main
ja	doc_491521501809_item	2500318	et	3	main
kui	doc_491521501809_item	2500319	et	3	main
kohtla-järvest	doc_491521501809_item	2500320	et	4	main
silmas	doc_491521501809_item	2500324	et	4	main
lühemaks	doc_491521501809_item	2500329	et	4	main
sisult	doc_491521501809_item	2500331	et	3	main
seotud	doc_491521501809_item	2500333	et	4	main
paigutatud	doc_491521501809_item	2500336	et	4	main
peaaegu	doc_491521501809_item	2500339	et	3	main
kaherealised	doc_491521501809_item	2500341	et	4	main
pelkirjad	doc_491521501809_item	2500342	et	4	main
jaoks	doc_491521501809_item	2500353	et	4	main
looga	doc_491521501809_item	2500356	et	4	main
pealkirja	doc_491521501809_item	2500357	et	4	main
kiri	doc_491521501809_item	2500358	et	3	main
kuna	doc_491521501809_item	2500359	et	3	main
põhjarannik	doc_491521501809_item	2500360	et	3	main
antiikvakiri	doc_491521501809_item	2500368	et	4	main
välja	doc_491521501809_item	2500373	et	4	main
väljendusrikkad	doc_491521501809_item	2500376	et	4	main
ja	doc_491521501809_item	2500377	et	3	main
personaalsed	doc_491521501809_item	2500378	et	3	main
antiikva	doc_491521501809_item	2500383	et	4	main
aga	doc_491521501809_item	2500386	et	3	main
lisas	doc_491521501809_item	2500388	et	4	main
teataja	doc_491521501809_item	2500390	et	4	main
ja	doc_491521501809_item	2500391	et	3	main
ka	doc_491521501809_item	2500392	et	3	main
spordiosas	doc_491521501809_item	2500393	et	3	main
on	doc_491521501809_item	2500394	et	4	main
annab	doc_491521501809_item	2500399	et	3	main
jõhvit	doc_491521501809_item	2500325	et	4	main
pealkiri	doc_491521501809_item	2500328	et	3	main
reale	doc_491521501809_item	2500338	et	3	main
kõik	doc_491521501809_item	2500340	et	4	main
ulatavad	doc_491521501809_item	2500343	et	4	main
kipuvad	doc_491521501809_item	2500351	et	3	main
lugeja	doc_491521501809_item	2500352	et	4	main
vana	doc_491521501809_item	2500367	et	4	main
pelkirjad	doc_491521501809_item	2500379	et	4	main
on	doc_491521501809_item	2500380	et	4	main
kuid	doc_491521501809_item	2500385	et	4	main
plokk-kiri	doc_491521501809_item	2500396	et	3	main
isikupärasust	doc_491521501809_item	2500401	et	4	main
ja	doc_491521501809_item	2500402	et	3	main
formaalsema	doc_491521501809_item	2500403	et	4	main
mulje	doc_491521501809_item	2500404	et	4	main
spordi	doc_491521501809_item	2500405	et	4	main
rubriigi	doc_491521501809_item	2500406	et	3	main
pealkirjade	doc_491521501809_item	2500407	et	3	main
eristamine	doc_491521501809_item	2500408	et	4	main
minu	doc_491521501809_item	2500409	et	3	main
meelest	doc_491521501809_item	2500410	et	4	main
ei	doc_491521501809_item	2500411	et	4	main
ole	doc_491521501809_item	2500412	et	4	main
põhjendatut	doc_491521501809_item	2500413	et	4	main
jõhvi	doc_491521501809_item	2500414	et	4	main
teataja	doc_491521501809_item	2500415	et	4	main
jagab	doc_491521501809_item	2500416	et	3	main
ajalehe	doc_491521501809_item	2500417	et	3	main
kaheks	doc_491521501809_item	2500418	et	4	main
pooleks	doc_491521501809_item	2500419	et	4	main
nii	doc_491521501809_item	2500420	et	3	main
et	doc_491521501809_item	2500421	et	3	main
põhja	doc_491521501809_item	2500438	et	4	main
mitte	doc_491521501809_item	2500441	et	3	main
kiri	doc_491521501809_item	2500447	et	3	main
domineeriv	doc_491521501809_item	2500471	et	4	main
on	doc_491521501809_item	2500473	et	4	main
ikka	doc_491521501809_item	2500474	et	4	main
antiikva	doc_491521501809_item	2500475	et	4	main
aga	doc_491521501809_item	2500476	et	3	main
plokk-kirjad	doc_491521501809_item	2500477	et	4	main
sisu	doc_491521501809_item	2500481	et	4	main
pelakirjad	doc_491521501809_item	2500484	et	4	main
sundimatu	doc_491521501809_item	2500499	et	4	main
peaaegu	doc_491521501809_item	2500504	et	3	main
pikkusega	doc_491521501809_item	2500506	et	4	main
vahet	doc_491521501809_item	2500509	et	3	main
sellega	doc_491521501809_item	2500517	et	3	main
on	doc_491521501809_item	2500524	et	4	main
kursiivis	doc_491521501809_item	2500526	et	3	main
mida	doc_491521501809_item	2500538	et	4	main
akustika	doc_491521501809_item	2500564	et	4	main
on	doc_491521501809_item	2500565	et	4	main
ligilähedane	doc_491521501809_item	2500566	et	3	main
kujundatud	doc_491521501809_item	2500575	et	4	main
aga	doc_491521501809_item	2500578	et	3	main
ülipikkad	doc_491521501809_item	2500581	et	4	main
seda	doc_491521501809_item	2500582	et	3	main
ülaloleva	doc_491521501809_item	2500355	et	3	main
pelkirjad	doc_491521501809_item	2500370	et	4	main
näevad	doc_491521501809_item	2500371	et	3	main
on	doc_491521501809_item	2500375	et	4	main
kasutatud	doc_491521501809_item	2500395	et	4	main
lisale	doc_491521501809_item	2500400	et	3	main
ei	doc_491521501809_item	2500423	et	4	main
kohe	doc_491521501809_item	2500425	et	4	main
pärast	doc_491521501809_item	2500426	et	4	main
kiriga	doc_491521501809_item	2500434	et	4	main
sellega	doc_491521501809_item	2500443	et	3	main
on	doc_491521501809_item	2500456	et	4	main
täiesti	doc_491521501809_item	2500457	et	3	main
kiri	doc_491521501809_item	2500472	et	3	main
pealkirja	doc_491521501809_item	2500482	et	4	main
parimaks	doc_491521501809_item	2500490	et	4	main
neid	doc_491521501809_item	2500491	et	4	main
ja	doc_491521501809_item	2500500	et	3	main
eriti	doc_491521501809_item	2500507	et	3	main
suurt	doc_491521501809_item	2500508	et	3	main
väiksed	doc_491521501809_item	2500515	et	4	main
aga	doc_491521501809_item	2500516	et	3	main
eristatavad	doc_491521501809_item	2500520	et	4	main
tähtsamate	doc_491521501809_item	2500521	et	4	main
kirjas	doc_491521501809_item	2500530	et	4	main
pikaveerulised	doc_491521501809_item	2500536	et	4	main
väga	doc_491521501809_item	2500540	et	3	main
on	doc_491521501809_item	2500547	et	4	main
aeg	doc_491521501809_item	2500548	et	3	main
naistele	doc_491521501809_item	2500549	et	3	main
8	doc_491521501809_item	2500550	et	2	main
märts	doc_491521501809_item	2500551	et	3	main
tagasi	doc_491521501809_item	2500552	et	3	main
kergem	doc_491521501809_item	2500556	et	4	main
kui	doc_491521501809_item	2500558	et	3	main
lehekülje	doc_491521501809_item	2500560	et	3	main
jõhvi	doc_491521501809_item	2500562	et	4	main
ajalehe	doc_491521501809_item	2500570	et	3	main
artikkel	doc_491521501809_item	2500573	et	3	main
veerudesse	doc_491521501809_item	2500577	et	3	main
vähemalt	doc_491521501809_item	2500585	et	4	main
kolmaks	doc_491521501809_item	2500586	et	4	main
mida	doc_491521501809_item	2500591	et	4	main
suhtes	doc_491521501809_item	2500621	et	4	main
jõhvi	doc_491521501809_item	2500623	et	4	main
juhus	doc_491521501809_item	2500630	et	4	main
parem	doc_491521501809_item	2500631	et	4	main
kui	doc_491521501809_item	2500632	et	3	main
põhjarannik	doc_491521501809_item	2500633	et	3	main
veerud	doc_491521501809_item	2500634	et	4	main
ja	doc_491521501809_item	2500639	et	3	main
vahepealkirjad	doc_491521501809_item	2500646	et	3	main
selgelt	doc_491521501809_item	2500650	et	4	main
nad	doc_491521501809_item	2500659	et	3	main
paigutatud	doc_491521501809_item	2500667	et	4	main
tekstiveergude	doc_491521501809_item	2500668	et	3	main
ühes	doc_491521501809_item	2500670	et	4	main
kohas	doc_491521501809_item	2500671	et	4	main
aga	doc_491521501809_item	2500673	et	3	main
lõppus	doc_491521501809_item	2500692	et	4	main
real	doc_491521501809_item	2500701	et	3	main
vähemalt	doc_491521501809_item	2500704	et	4	main
ja	doc_491521501809_item	2500727	et	3	main
ilus	doc_491521501809_item	2500737	et	4	main
tähekesed	doc_491521501809_item	2500738	et	4	main
aga	doc_491521501809_item	2500739	et	3	main
on	doc_491521501809_item	2500740	et	4	main
lihtsad	doc_491521501809_item	2500741	et	3	main
mõtted	doc_491521501809_item	2500748	et	3	main
suurem	doc_491521501809_item	2500750	et	4	main
esimeses	doc_491521501809_item	2500771	et	3	main
ei	doc_491521501809_item	2500779	et	4	main
on	doc_491521501809_item	2500783	et	4	main
kohe	doc_491521501809_item	2500790	et	4	main
tule	doc_491521501809_item	2500424	et	4	main
jätkamine	doc_491521501809_item	2500431	et	4	main
kuulub	doc_491521501809_item	2500437	et	3	main
ajalehele	doc_491521501809_item	2500439	et	3	main
vaid	doc_491521501809_item	2500440	et	3	main
pealkirja	doc_491521501809_item	2500446	et	4	main
ajalehes	doc_491521501809_item	2500451	et	3	main
põhjendatud	doc_491521501809_item	2500458	et	4	main
nad	doc_491521501809_item	2500459	et	3	main
on	doc_491521501809_item	2500460	et	4	main
kasutatud	doc_491521501809_item	2500461	et	4	main
rangete	doc_491521501809_item	2500462	et	4	main
ja	doc_491521501809_item	2500463	et	3	main
tõsisemate	doc_491521501809_item	2500464	et	4	main
uudiste	doc_491521501809_item	2500465	et	3	main
kohta	doc_491521501809_item	2500466	et	4	main
nt	doc_491521501809_item	2500467	et	4	main
viru	doc_491521501809_item	2500468	et	4	main
peab	doc_491521501809_item	2500444	et	4	main
olema	doc_491521501809_item	2500448	et	4	main
pelakirjad	doc_491521501809_item	2500450	et	4	main
on	doc_491521501809_item	2500492	et	4	main
mugav	doc_491521501809_item	2500493	et	3	main
lugeda	doc_491521501809_item	2500494	et	3	main
ja	doc_491521501809_item	2500495	et	3	main
nad	doc_491521501809_item	2500496	et	3	main
mõjuvad	doc_491521501809_item	2500497	et	4	main
mitteametliku	doc_491521501809_item	2500498	et	3	main
on	doc_491521501809_item	2500518	et	4	main
ringkonnakohtu	doc_491521501809_item	2500469	et	3	main
kriminaalkroonika	doc_491521501809_item	2500470	et	4	main
vasakule	doc_491521501809_item	2500487	et	4	main
seda	doc_491521501809_item	2500488	et	3	main
peetakse	doc_491521501809_item	2500489	et	3	main
read	doc_491521501809_item	2500502	et	3	main
on	doc_491521501809_item	2500513	et	4	main
suhteliselt	doc_491521501809_item	2500514	et	4	main
artikklite	doc_491521501809_item	2500522	et	4	main
ka	doc_491521501809_item	2500528	et	3	main
teksti	doc_491521501809_item	2500531	et	4	main
liigendamine	doc_491521501809_item	2500532	et	4	main
ajalehes	doc_491521501809_item	2500533	et	3	main
artiklid	doc_491521501809_item	2500537	et	3	main
anda	doc_491521501809_item	2500553	et	3	main
palju	doc_491521501809_item	2500555	et	4	main
on	doc_491521501809_item	2500574	et	4	main
kitsamate	doc_491521501809_item	2500576	et	4	main
lõigud	doc_491521501809_item	2500579	et	4	main
on	doc_491521501809_item	2500635	et	4	main
ei	doc_491521501809_item	2500640	et	4	main
sama	doc_491521501809_item	2500663	et	4	main
valesti	doc_491521501809_item	2500676	et	3	main
artikklis	doc_491521501809_item	2500680	et	4	main
on	doc_491521501809_item	2500681	et	4	main
aeg	doc_491521501809_item	2500682	et	3	main
8	doc_491521501809_item	2500684	et	2	main
märts	doc_491521501809_item	2500685	et	3	main
tagasi	doc_491521501809_item	2500686	et	3	main
anda	doc_491521501809_item	2500687	et	3	main
teine	doc_491521501809_item	2500688	et	3	main
vahepealkiri	doc_491521501809_item	2500689	et	3	main
seisab	doc_491521501809_item	2500690	et	3	main
teksti	doc_491521501809_item	2500691	et	4	main
järgnev	doc_491521501809_item	2500696	et	4	main
mahub	doc_491521501809_item	2500698	et	3	main
kahel	doc_491521501809_item	2500700	et	4	main
nõus	doc_491521501809_item	2500721	et	4	main
on	doc_491521501809_item	2500723	et	4	main
seal	doc_491521501809_item	2500724	et	4	main
mis	doc_491521501809_item	2500734	et	4	main
ei	doc_491521501809_item	2500735	et	4	main
ja	doc_491521501809_item	2500742	et	3	main
rahulikud	doc_491521501809_item	2500743	et	3	main
ning	doc_491521501809_item	2500744	et	3	main
eristavad	doc_491521501809_item	2500745	et	4	main
põhitekst	doc_491521501809_item	2500749	et	3	main
legejatest	doc_491521501809_item	2500752	et	4	main
kaksikleheküljel	doc_491521501809_item	2500772	et	3	main
võlgu	doc_491521501809_item	2500781	et	4	main
ja	doc_491521501809_item	2500787	et	3	main
tõesti	doc_491521501809_item	2500796	et	3	main
ning	doc_491521501809_item	2500798	et	3	main
ta	doc_491521501809_item	2500803	et	4	main
ülemise	doc_491521501809_item	2500808	et	4	main
tavaliselt	doc_491521501809_item	2500825	et	4	main
ühes	doc_491521501809_item	2500837	et	4	main
tragöödia	doc_491521501809_item	2500846	et	4	main
reavahega	doc_491521501809_item	2500858	et	3	main
see	doc_491521501809_item	2500859	et	3	main
artikkel	doc_491521501809_item	2500860	et	3	main
on	doc_491521501809_item	2500861	et	4	main
teistest	doc_491521501809_item	2500869	et	4	main
see	doc_491521501809_item	2500875	et	3	main
ei	doc_491521501809_item	2500883	et	4	main
põhitekstide	doc_491521501809_item	2500887	et	3	main
kiri	doc_491521501809_item	2500888	et	3	main
ongi	doc_491521501809_item	2500889	et	4	main
antiikva	doc_491521501809_item	2500890	et	4	main
sellega	doc_491521501809_item	2500891	et	3	main
jääb	doc_491521501809_item	2500892	et	3	main
üks	doc_491521501809_item	2500893	et	3	main
variant	doc_491521501809_item	2500894	et	3	main
plokk-kiri	doc_491521501809_item	2500895	et	3	main
ajalehe	doc_491521501809_item	2500902	et	3	main
10	doc_491521501809_item	2500907	et	2	main
ühes	doc_491521501809_item	2500922	et	4	main
veergu	doc_491521501809_item	2500942	et	4	main
aga	doc_491521501809_item	2500943	et	3	main
see	doc_491521501809_item	2500944	et	3	main
ja	doc_491521501809_item	2500953	et	3	main
artikklis	doc_491521501809_item	2500958	et	4	main
allajoonistavad	doc_491521501809_item	2500478	et	4	main
korralikult	doc_491521501809_item	2500479	et	4	main
artikkli	doc_491521501809_item	2500480	et	4	main
paigutamine	doc_491521501809_item	2500483	et	4	main
on	doc_491521501809_item	2500485	et	4	main
joondatud	doc_491521501809_item	2500486	et	4	main
sõbralikuna	doc_491521501809_item	2500501	et	3	main
on	doc_491521501809_item	2500503	et	4	main
samasuguse	doc_491521501809_item	2500505	et	3	main
ei	doc_491521501809_item	2500510	et	4	main
ole	doc_491521501809_item	2500511	et	4	main
pealkirjad	doc_491521501809_item	2500512	et	3	main
kohe	doc_491521501809_item	2500519	et	4	main
paksemas	doc_491521501809_item	2500525	et	4	main
suuremas	doc_491521501809_item	2500529	et	4	main
on	doc_491521501809_item	2500534	et	4	main
liiga	doc_491521501809_item	2500535	et	4	main
lugeda	doc_491521501809_item	2500542	et	3	main
on	doc_491521501809_item	2500554	et	4	main
eesti	doc_491521501809_item	2500567	et	4	main
modernseimale	doc_491521501809_item	2500568	et	4	main
kontserdisaalile	doc_491521501809_item	2500569	et	3	main
on	doc_491521501809_item	2500580	et	4	main
ise	doc_491521501809_item	2500587	et	4	main
artikkel	doc_491521501809_item	2500588	et	3	main
on	doc_491521501809_item	2500589	et	4	main
vormistatud	doc_491521501809_item	2500625	et	4	main
õieti	doc_491521501809_item	2500626	et	3	main
või	doc_491521501809_item	2500627	et	4	main
suhteliselt	doc_491521501809_item	2500636	et	4	main
on	doc_491521501809_item	2500647	et	4	main
antiikva	doc_491521501809_item	2500656	et	4	main
põhiteksti	doc_491521501809_item	2500657	et	4	main
taustal	doc_491521501809_item	2500658	et	3	main
lühikesed	doc_491521501809_item	2500661	et	4	main
keskele	doc_491521501809_item	2500669	et	3	main
kasutatud	doc_491521501809_item	2500674	et	4	main
naistele	doc_491521501809_item	2500683	et	3	main
ei	doc_491521501809_item	2500694	et	4	main
tekst	doc_491521501809_item	2500697	et	3	main
ainult	doc_491521501809_item	2500699	et	4	main
pealkirjad	doc_491521501809_item	2500523	et	3	main
ning	doc_491521501809_item	2500527	et	3	main
on	doc_491521501809_item	2500539	et	4	main
raske	doc_491521501809_item	2500541	et	4	main
teisel	doc_491521501809_item	2500543	et	4	main
leheküljel	doc_491521501809_item	2500544	et	3	main
asuv	doc_491521501809_item	2500545	et	4	main
artikkel	doc_491521501809_item	2500546	et	3	main
loetav	doc_491521501809_item	2500557	et	4	main
esimese	doc_491521501809_item	2500559	et	3	main
oma	doc_491521501809_item	2500561	et	4	main
kiriku	doc_491521501809_item	2500563	et	3	main
kõige	doc_491521501809_item	2500571	et	4	main
esimene	doc_491521501809_item	2500572	et	3	main
tuleks	doc_491521501809_item	2500583	et	4	main
jagada	doc_491521501809_item	2500584	et	3	main
pikk	doc_491521501809_item	2500590	et	4	main
juba	doc_491521501809_item	2500592	et	3	main
pikkuse	doc_491521501809_item	2500593	et	4	main
tõttu	doc_491521501809_item	2500594	et	4	main
ei	doc_491521501809_item	2500595	et	4	main
tahaks	doc_491521501809_item	2500596	et	3	main
lugeda	doc_491521501809_item	2500597	et	3	main
vastupidi	doc_491521501809_item	2500598	et	3	main
teisel	doc_491521501809_item	2500599	et	4	main
leheküljel	doc_491521501809_item	2500600	et	3	main
asuv	doc_491521501809_item	2500601	et	4	main
artiikel	doc_491521501809_item	2500602	et	4	main
lastele	doc_491521501809_item	2500603	et	4	main
tohi	doc_491521501809_item	2500605	et	4	main
ei	doc_491521501809_item	2500604	et	4	main
võlgu	doc_491521501809_item	2500606	et	4	main
jääda	doc_491521501809_item	2500607	et	4	main
on	doc_491521501809_item	2500608	et	4	main
ühes	doc_491521501809_item	2500609	et	4	main
laiemas	doc_491521501809_item	2500610	et	4	main
veergus	doc_491521501809_item	2500611	et	4	main
ning	doc_491521501809_item	2500612	et	3	main
lõigud	doc_491521501809_item	2500613	et	4	main
on	doc_491521501809_item	2500614	et	4	main
lühikesed	doc_491521501809_item	2500615	et	4	main
artikklite	doc_491521501809_item	2500616	et	4	main
lause	doc_491521501809_item	2500617	et	4	main
ja	doc_491521501809_item	2500618	et	3	main
lõigu	doc_491521501809_item	2500619	et	4	main
suuruse	doc_491521501809_item	2500620	et	4	main
siis	doc_491521501809_item	2500628	et	3	main
igas	doc_491521501809_item	2500629	et	3	main
mitte	doc_491521501809_item	2500637	et	3	main
pikad	doc_491521501809_item	2500638	et	4	main
lugemisel	doc_491521501809_item	2500642	et	4	main
raskusi	doc_491521501809_item	2500644	et	4	main
kasutatud	doc_491521501809_item	2500648	et	4	main
on	doc_491521501809_item	2500622	et	4	main
teataja	doc_491521501809_item	2500624	et	4	main
tekita	doc_491521501809_item	2500641	et	4	main
suuri	doc_491521501809_item	2500643	et	3	main
vahepealkiri	doc_491521501809_item	2500645	et	3	main
on	doc_491521501809_item	2500666	et	4	main
on	doc_491521501809_item	2500672	et	4	main
ajalehe	doc_491521501809_item	2500677	et	3	main
leheküljel	doc_491521501809_item	2500679	et	3	main
nii	doc_491521501809_item	2500693	et	3	main
aga	doc_491521501809_item	2500702	et	3	main
kol	doc_491521501809_item	2500705	et	4	main
olema	doc_491521501809_item	2500706	et	4	main
jõhvi	doc_491521501809_item	2500707	et	4	main
teatajas	doc_491521501809_item	2500708	et	4	main
ei	doc_491521501809_item	2500709	et	4	main
ole	doc_491521501809_item	2500710	et	4	main
üldse	doc_491521501809_item	2500711	et	3	main
vahepealkirju	doc_491521501809_item	2500712	et	4	main
nende	doc_491521501809_item	2500713	et	4	main
asemel	doc_491521501809_item	2500714	et	4	main
on	doc_491521501809_item	2500715	et	4	main
kasutatu	doc_491521501809_item	2500716	et	4	main
tähekesed	doc_491521501809_item	2500717	et	4	main
olen	doc_491521501809_item	2500718	et	3	main
sellega	doc_491521501809_item	2500719	et	3	main
täiesti	doc_491521501809_item	2500720	et	3	main
suhteliselt	doc_491521501809_item	2500725	et	4	main
mahuks	doc_491521501809_item	2500729	et	4	main
juhus	doc_491521501809_item	2500731	et	4	main
ühs	doc_491521501809_item	2500732	et	4	main
vahepealkiri	doc_491521501809_item	2500733	et	3	main
on	doc_491521501809_item	2500759	et	4	main
kirjutatud	doc_491521501809_item	2500760	et	4	main
on	doc_491521501809_item	2500773	et	4	main
eristatud	doc_491521501809_item	2500774	et	4	main
plokk-kirjana	doc_491521501809_item	2500775	et	3	main
artikkel	doc_491521501809_item	2500776	et	3	main
pealkirjaga	doc_491521501809_item	2500777	et	3	main
tohi	doc_491521501809_item	2500780	et	4	main
jääda	doc_491521501809_item	2500782	et	4	main
paksemas	doc_491521501809_item	2500785	et	4	main
on	doc_491521501809_item	2500795	et	4	main
inimestele	doc_491521501809_item	2500799	et	3	main
pea	doc_491521501809_item	2500818	et	4	main
uudis	doc_491521501809_item	2500819	et	3	main
asuv	doc_491521501809_item	2500820	et	4	main
leheküljel	doc_491521501809_item	2500822	et	3	main
pilk	doc_491521501809_item	2500828	et	3	main
kirjas	doc_491521501809_item	2500838	et	4	main
ja	doc_491521501809_item	2500841	et	3	main
ei	doc_491521501809_item	2500843	et	4	main
muutu	doc_491521501809_item	2500844	et	4	main
on	doc_491521501809_item	2500848	et	4	main
suurema	doc_491521501809_item	2500857	et	4	main
sest	doc_491521501809_item	2500865	et	4	main
täiesti	doc_491521501809_item	2500867	et	3	main
kaksikleheküljel	doc_491521501809_item	2500872	et	3	main
on	doc_491521501809_item	2500874	et	4	main
olema	doc_491521501809_item	2500881	et	4	main
sest	doc_491521501809_item	2500885	et	4	main
ajalehe	doc_491521501809_item	2500886	et	3	main
ei	doc_491521501809_item	2500898	et	4	main
ühesugune	doc_491521501809_item	2500900	et	3	main
cic	doc_491521501809_item	2500908	et	4	main
see	doc_491521501809_item	2500909	et	3	main
õieti	doc_491521501809_item	2500649	et	3	main
eristatud	doc_491521501809_item	2500651	et	4	main
paksu	doc_491521501809_item	2500652	et	4	main
ning	doc_491521501809_item	2500653	et	3	main
suurema	doc_491521501809_item	2500654	et	4	main
plokk-kirjaga	doc_491521501809_item	2500655	et	3	main
on	doc_491521501809_item	2500660	et	4	main
kõik	doc_491521501809_item	2500662	et	4	main
pikkusega	doc_491521501809_item	2500664	et	4	main
ja	doc_491521501809_item	2500665	et	3	main
vahepealkiri	doc_491521501809_item	2500675	et	3	main
teisel	doc_491521501809_item	2500678	et	4	main
veeru	doc_491521501809_item	2500695	et	4	main
peab	doc_491521501809_item	2500703	et	4	main
lühikesed	doc_491521501809_item	2500726	et	4	main
paremas	doc_491521501809_item	2500730	et	4	main
artikklite	doc_491521501809_item	2500747	et	4	main
lastele	doc_491521501809_item	2500778	et	4	main
kirjas	doc_491521501809_item	2500786	et	4	main
on	doc_491521501809_item	2500789	et	4	main
oluline	doc_491521501809_item	2500797	et	4	main
huvitav	doc_491521501809_item	2500800	et	4	main
samas	doc_491521501809_item	2500801	et	4	main
on	doc_491521501809_item	2500802	et	4	main
vasaku	doc_491521501809_item	2500805	et	3	main
vasaku	doc_491521501809_item	2500807	et	3	main
nurka	doc_491521501809_item	2500809	et	4	main
väga	doc_491521501809_item	2500810	et	3	main
heas	doc_491521501809_item	2500811	et	3	main
kohas	doc_491521501809_item	2500812	et	4	main
sellega	doc_491521501809_item	2500813	et	3	main
on	doc_491521501809_item	2500814	et	4	main
leheküljel	doc_491521501809_item	2500815	et	3	main
keskel	doc_491521501809_item	2500823	et	3	main
esimene	doc_491521501809_item	2500827	et	3	main
vaid	doc_491521501809_item	2500829	et	3	main
teine	doc_491521501809_item	2500831	et	3	main
kirjas	doc_491521501809_item	2500833	et	4	main
põhitekst	doc_491521501809_item	2500834	et	3	main
on	doc_491521501809_item	2500835	et	4	main
põhiliselt	doc_491521501809_item	2500836	et	4	main
lugu	doc_491521501809_item	2500845	et	4	main
kirjutatud	doc_491521501809_item	2500849	et	4	main
veerus	doc_491521501809_item	2500851	et	4	main
ka	doc_491521501809_item	2500862	et	3	main
plokk-kirjaga	doc_491521501809_item	2500864	et	3	main
erinev	doc_491521501809_item	2500868	et	4	main
kuna	doc_491521501809_item	2500873	et	3	main
pehme	doc_491521501809_item	2500876	et	4	main
aga	doc_491521501809_item	2500882	et	3	main
saa	doc_491521501809_item	2500884	et	4	main
veerud	doc_491521501809_item	2500901	et	4	main
põhiteksti	doc_491521501809_item	2500903	et	4	main
veerud	doc_491521501809_item	2500904	et	4	main
artikklid	doc_491521501809_item	2500722	et	4	main
sinna	doc_491521501809_item	2500728	et	3	main
ole	doc_491521501809_item	2500736	et	4	main
ka	doc_491521501809_item	2500746	et	3	main
osa	doc_491521501809_item	2500751	et	4	main
eelistab	doc_491521501809_item	2500753	et	3	main
põhireksi	doc_491521501809_item	2500754	et	4	main
kirjana	doc_491521501809_item	2500755	et	3	main
antiikvat	doc_491521501809_item	2500756	et	3	main
põhjaranniku	doc_491521501809_item	2500757	et	3	main
põhitekst	doc_491521501809_item	2500758	et	3	main
samuti	doc_491521501809_item	2500761	et	3	main
antiikva	doc_491521501809_item	2500762	et	4	main
kirjas	doc_491521501809_item	2500763	et	4	main
kohtub	doc_491521501809_item	2500764	et	3	main
aga	doc_491521501809_item	2500765	et	3	main
ka	doc_491521501809_item	2500766	et	3	main
plokk-kirja	doc_491521501809_item	2500767	et	4	main
kasutus	doc_491521501809_item	2500768	et	4	main
kaks	doc_491521501809_item	2500769	et	3	main
artikklit	doc_491521501809_item	2500770	et	4	main
isegi	doc_491521501809_item	2500784	et	4	main
sellega	doc_491521501809_item	2500788	et	3	main
silma	doc_491521501809_item	2500791	et	4	main
torkiv	doc_491521501809_item	2500792	et	4	main
see	doc_491521501809_item	2500793	et	3	main
uudis	doc_491521501809_item	2500794	et	3	main
paigutatud	doc_491521501809_item	2500804	et	4	main
lehekülje	doc_491521501809_item	2500806	et	3	main
mitte	doc_491521501809_item	2500816	et	3	main
üks	doc_491521501809_item	2500817	et	3	main
paremal	doc_491521501809_item	2500821	et	4	main
langeb	doc_491521501809_item	2500826	et	3	main
suurus	doc_491521501809_item	2500840	et	4	main
kirjas	doc_491521501809_item	2500855	et	4	main
ja	doc_491521501809_item	2500856	et	3	main
on	doc_491521501809_item	2500866	et	4	main
artikklitset	doc_491521501809_item	2500870	et	4	main
lugu	doc_491521501809_item	2500877	et	4	main
võiks	doc_491521501809_item	2500878	et	4	main
ka	doc_491521501809_item	2500879	et	3	main
leht	doc_491521501809_item	2500897	et	3	main
domineerivalt	doc_491521501809_item	2500906	et	4	main
mõtet	doc_491521501809_item	2500921	et	3	main
on	doc_491521501809_item	2500924	et	4	main
3-4	doc_491521501809_item	2500926	et	2	main
sõna	doc_491521501809_item	2500927	et	4	main
tekstides	doc_491521501809_item	2500933	et	3	main
ei	doc_491521501809_item	2500945	et	4	main
on	doc_491521501809_item	2500970	et	4	main
artikklid	doc_491521501809_item	2500990	et	4	main
elatise	doc_491521501809_item	2500991	et	3	main
keeruliseks	doc_491521501809_item	2500995	et	4	main
kohtutäitur	doc_491521501809_item	2500997	et	3	main
maalmani	doc_491521501809_item	2500999	et	4	main
menetluses	doc_491521501809_item	2501000	et	4	main
ole	doc_491521501809_item	2501011	et	4	main
artikklid	doc_491521501809_item	2501013	et	4	main
üks	doc_491521501809_item	2501015	et	3	main
esmapilgul	doc_491521501809_item	2501017	et	4	main
põhiartikkli	doc_491521501809_item	2501024	et	4	main
saa	doc_491521501809_item	2501034	et	4	main
ei	doc_491521501809_item	2501044	et	4	main
seisab	doc_491521501809_item	2501049	et	3	main
teksti	doc_491521501809_item	2501051	et	4	main
lõpetamatuse	doc_491521501809_item	2501056	et	4	main
põhiteksti	doc_491521501809_item	2501067	et	4	main
kasti	doc_491521501809_item	2501076	et	4	main
on	doc_491521501809_item	2501114	et	4	main
5	doc_491521501809_item	2501115	et	2	main
veergu	doc_491521501809_item	2501116	et	4	main
ei	doc_491521501809_item	2501119	et	4	main
lihtne	doc_491521501809_item	2501131	et	3	main
kiiresti	doc_491521501809_item	2501144	et	3	main
muutuvas	doc_491521501809_item	2501145	et	4	main
ning	doc_491521501809_item	2501162	et	3	main
peaaegu	doc_491521501809_item	2501171	et	3	main
ei	doc_491521501809_item	2501201	et	4	main
ütlev	doc_491521501809_item	2501202	et	4	main
teksti	doc_491521501809_item	2501207	et	4	main
meeleolu	doc_491521501809_item	2501208	et	4	main
asjakohane	doc_491521501809_item	2501213	et	4	main
foto	doc_491521501809_item	2501218	et	4	main
kuhu	doc_491521501809_item	2500824	et	3	main
ka	doc_491521501809_item	2500830	et	3	main
paksemas	doc_491521501809_item	2500832	et	4	main
kirja	doc_491521501809_item	2500839	et	4	main
reavahe	doc_491521501809_item	2500842	et	4	main
arktikas	doc_491521501809_item	2500847	et	4	main
laiemas	doc_491521501809_item	2500850	et	4	main
sellega	doc_491521501809_item	2500852	et	3	main
ka	doc_491521501809_item	2500853	et	3	main
suuremas	doc_491521501809_item	2500854	et	4	main
eristatud	doc_491521501809_item	2500863	et	4	main
sellel	doc_491521501809_item	2500871	et	4	main
antiikvas	doc_491521501809_item	2500880	et	3	main
et	doc_491521501809_item	2500896	et	3	main
oleks	doc_491521501809_item	2500899	et	3	main
on	doc_491521501809_item	2500905	et	4	main
on	doc_491521501809_item	2500910	et	4	main
vähem	doc_491521501809_item	2500911	et	4	main
kui	doc_491521501809_item	2500912	et	3	main
minimaalne	doc_491521501809_item	2500913	et	3	main
võimalik	doc_491521501809_item	2500914	et	3	main
suurs	doc_491521501809_item	2500915	et	4	main
veerud	doc_491521501809_item	2500916	et	4	main
ei	doc_491521501809_item	2500917	et	4	main
suuda	doc_491521501809_item	2500918	et	4	main
mahutada	doc_491521501809_item	2500919	et	3	main
terviklikku	doc_491521501809_item	2500920	et	4	main
reas	doc_491521501809_item	2500923	et	3	main
keskmiselt	doc_491521501809_item	2500925	et	4	main
paljud	doc_491521501809_item	2500935	et	3	main
on	doc_491521501809_item	2500939	et	4	main
mahutatud	doc_491521501809_item	2500940	et	4	main
6	doc_491521501809_item	2500941	et	2	main
pilte	doc_491521501809_item	2500952	et	3	main
vähe	doc_491521501809_item	2500957	et	3	main
levib	doc_491521501809_item	2500960	et	3	main
heroiin	doc_491521501809_item	2500961	et	3	main
jõhvi	doc_491521501809_item	2500962	et	4	main
ja	doc_491521501809_item	2500963	et	3	main
lähedal	doc_491521501809_item	2500969	et	4	main
veerukesed	doc_491521501809_item	2500972	et	4	main
märgatavad	doc_491521501809_item	2500976	et	4	main
on	doc_491521501809_item	2500982	et	4	main
võib	doc_491521501809_item	2500993	et	3	main
on	doc_491521501809_item	2501005	et	4	main
paiguta-tud	doc_491521501809_item	2501006	et	4	main
väga	doc_491521501809_item	2501007	et	3	main
imelikult	doc_491521501809_item	2501008	et	4	main
need	doc_491521501809_item	2501009	et	3	main
neid	doc_491521501809_item	2501021	et	4	main
ei	doc_491521501809_item	2501033	et	4	main
teksti	doc_491521501809_item	2501042	et	4	main
lõppus	doc_491521501809_item	2501043	et	4	main
vaid	doc_491521501809_item	2501048	et	3	main
kasti	doc_491521501809_item	2501052	et	4	main
sees	doc_491521501809_item	2501053	et	4	main
sellega	doc_491521501809_item	2501054	et	3	main
tekitab	doc_491521501809_item	2501055	et	3	main
teksti	doc_491521501809_item	2501062	et	4	main
langetada	doc_491521501809_item	2501063	et	3	main
alla	doc_491521501809_item	2501064	et	3	main
ees	doc_491521501809_item	2501077	et	4	main
sõna	doc_491521501809_item	2501105	et	4	main
tekita	doc_491521501809_item	2501120	et	4	main
veerud	doc_491521501809_item	2501123	et	4	main
pikad	doc_491521501809_item	2501126	et	4	main
teataja	doc_491521501809_item	2501133	et	4	main
palju	doc_491521501809_item	2501135	et	4	main
rahulikum	doc_491521501809_item	2501136	et	4	main
kui	doc_491521501809_item	2501137	et	3	main
põhjarannik	doc_491521501809_item	2501138	et	3	main
5-7	doc_491521501809_item	2500930	et	2	main
sõna	doc_491521501809_item	2500931	et	4	main
olema	doc_491521501809_item	2500932	et	4	main
sõnad	doc_491521501809_item	2500936	et	4	main
leheküljel	doc_491521501809_item	2500938	et	3	main
kirju	doc_491521501809_item	2500947	et	4	main
ja	doc_491521501809_item	2500948	et	3	main
segase	doc_491521501809_item	2500949	et	3	main
tunnet	doc_491521501809_item	2500950	et	3	main
optimaalselt	doc_491521501809_item	2500928	et	4	main
peab	doc_491521501809_item	2500929	et	4	main
on	doc_491521501809_item	2500934	et	4	main
poolitatud	doc_491521501809_item	2500937	et	4	main
tekita	doc_491521501809_item	2500946	et	4	main
fotosid	doc_491521501809_item	2500954	et	3	main
hästi	doc_491521501809_item	2500956	et	3	main
narvas	doc_491521501809_item	2500959	et	4	main
kohtla-järve	doc_491521501809_item	2500964	et	4	main
raskesti	doc_491521501809_item	2500975	et	3	main
veerud	doc_491521501809_item	2500977	et	4	main
hallid	doc_491521501809_item	2500984	et	4	main
ja	doc_491521501809_item	2500985	et	3	main
rasked	doc_491521501809_item	2500986	et	3	main
lugeda	doc_491521501809_item	2500987	et	3	main
lehekülje	doc_491521501809_item	2500989	et	3	main
osutada	doc_491521501809_item	2500994	et	3	main
ja	doc_491521501809_item	2500996	et	3	main
kristel	doc_491521501809_item	2500998	et	4	main
ei	doc_491521501809_item	2501010	et	4	main
vaid	doc_491521501809_item	2501014	et	3	main
aga	doc_491521501809_item	2501016	et	3	main
tekib	doc_491521501809_item	2501018	et	3	main
kuna	doc_491521501809_item	2500951	et	3	main
on	doc_491521501809_item	2500955	et	4	main
kandis	doc_491521501809_item	2500965	et	4	main
moonilahus	doc_491521501809_item	2500966	et	4	main
suure	doc_491521501809_item	2500967	et	3	main
foto	doc_491521501809_item	2500968	et	4	main
lühikesed	doc_491521501809_item	2500971	et	4	main
mis	doc_491521501809_item	2500973	et	4	main
igavad	doc_491521501809_item	2500983	et	3	main
kolmanda	doc_491521501809_item	2500988	et	3	main
on	doc_491521501809_item	2501001	et	4	main
500	doc_491521501809_item	2501002	et	2	main
elatise	doc_491521501809_item	2501003	et	3	main
kaks	doc_491521501809_item	2501012	et	3	main
mulje	doc_491521501809_item	2501019	et	4	main
et	doc_491521501809_item	2501020	et	3	main
on	doc_491521501809_item	2501022	et	4	main
aru	doc_491521501809_item	2501035	et	4	main
mis	doc_491521501809_item	2501036	et	4	main
lugeda	doc_491521501809_item	2501039	et	3	main
ja	doc_491521501809_item	2501040	et	3	main
ka	doc_491521501809_item	2501041	et	3	main
nime	doc_491521501809_item	2501047	et	4	main
pigem	doc_491521501809_item	2501058	et	3	main
oleks	doc_491521501809_item	2501059	et	3	main
ja	doc_491521501809_item	2501066	et	3	main
veerud	doc_491521501809_item	2501070	et	4	main
vastupidine	doc_491521501809_item	2501078	et	3	main
on	doc_491521501809_item	2501079	et	4	main
ja	doc_491521501809_item	2501117	et	3	main
on	doc_491521501809_item	2500974	et	4	main
on	doc_491521501809_item	2500978	et	4	main
suhteliselt	doc_491521501809_item	2500979	et	4	main
pikad	doc_491521501809_item	2500980	et	4	main
sellega	doc_491521501809_item	2500981	et	3	main
kätte-saamine	doc_491521501809_item	2500992	et	4	main
välja-nõudmist	doc_491521501809_item	2501004	et	4	main
lõpp	doc_491521501809_item	2501025	et	3	main
teise	doc_491521501809_item	2501027	et	4	main
ole	doc_491521501809_item	2501045	et	4	main
autori	doc_491521501809_item	2501046	et	3	main
tunne	doc_491521501809_item	2501057	et	4	main
kastis	doc_491521501809_item	2501060	et	4	main
asuva	doc_491521501809_item	2501061	et	4	main
viimased	doc_491521501809_item	2501068	et	3	main
ülesse	doc_491521501809_item	2501071	et	4	main
ja	doc_491521501809_item	2501106	et	3	main
sõnu	doc_491521501809_item	2501108	et	4	main
on	doc_491521501809_item	2501109	et	4	main
vähe	doc_491521501809_item	2501110	et	3	main
võrreldes	doc_491521501809_item	2501111	et	3	main
põhjarannikuga	doc_491521501809_item	2501112	et	3	main
leheküljel	doc_491521501809_item	2501113	et	3	main
ei	doc_491521501809_item	2501124	et	4	main
ega	doc_491521501809_item	2501127	et	3	main
lühikesed	doc_491521501809_item	2501128	et	4	main
lugeda	doc_491521501809_item	2501129	et	3	main
me	doc_491521501809_item	2501141	et	4	main
harjusime	doc_491521501809_item	2501142	et	3	main
juba	doc_491521501809_item	2501143	et	3	main
kujundus	doc_491521501809_item	2501151	et	4	main
teataja	doc_491521501809_item	2501157	et	4	main
aga	doc_491521501809_item	2501158	et	3	main
annab	doc_491521501809_item	2501159	et	3	main
võimalust	doc_491521501809_item	2501160	et	3	main
lugemisel	doc_491521501809_item	2501163	et	4	main
nautida	doc_491521501809_item	2501164	et	3	main
fotod	doc_491521501809_item	2501165	et	3	main
põhjarannikus	doc_491521501809_item	2501166	et	3	main
on	doc_491521501809_item	2501167	et	4	main
foto	doc_491521501809_item	2501209	et	4	main
vist	doc_491521501809_item	2501212	et	4	main
millele	doc_491521501809_item	2501216	et	3	main
on	doc_491521501809_item	2501219	et	4	main
üks	doc_491521501809_item	2501220	et	3	main
suure	doc_491521501809_item	2501231	et	3	main
olemas	doc_491521501809_item	2501238	et	4	main
sest	doc_491521501809_item	2501249	et	4	main
on	doc_491521501809_item	2501251	et	4	main
täiesti	doc_491521501809_item	2501252	et	3	main
vähe	doc_491521501809_item	2501253	et	3	main
ajaleht	doc_491521501809_item	2501254	et	3	main
tähelepanuväärsed	doc_491521501809_item	2501267	et	3	main
fotod	doc_491521501809_item	2501273	et	3	main
portreefotoline	doc_491521501809_item	2501277	et	4	main
teine	doc_491521501809_item	2501278	et	3	main
ja	doc_491521501809_item	2501279	et	3	main
eriti	doc_491521501809_item	2501286	et	3	main
palju	doc_491521501809_item	2501290	et	4	main
ei	doc_491521501809_item	2501292	et	4	main
on	doc_491521501809_item	2501307	et	4	main
fotoallkiri	doc_491521501809_item	2501318	et	3	main
allkirja	doc_491521501809_item	2501321	et	4	main
ei	doc_491521501809_item	2501323	et	4	main
viitsita	doc_491521501809_item	2501324	et	4	main
lugeda	doc_491521501809_item	2501325	et	3	main
mõned	doc_491521501809_item	2501326	et	3	main
allkirjad	doc_491521501809_item	2501327	et	3	main
on	doc_491521501809_item	2501334	et	4	main
seda	doc_491521501809_item	2501340	et	3	main
mis	doc_491521501809_item	2501354	et	4	main
ei	doc_491521501809_item	2501388	et	4	main
lugejale	doc_491521501809_item	2501401	et	4	main
pisiinfo	doc_491521501809_item	2501406	et	4	main
loetav	doc_491521501809_item	2501411	et	4	main
väikeste	doc_491521501809_item	2501412	et	4	main
kuulutuste	doc_491521501809_item	2501413	et	4	main
tähed	doc_491521501809_item	2501422	et	3	main
eristatud	doc_491521501809_item	2501451	et	4	main
info	doc_491521501809_item	2501457	et	4	main
seisab	doc_491521501809_item	2501458	et	3	main
kaks	doc_491521501809_item	2501023	et	3	main
algab	doc_491521501809_item	2501026	et	3	main
artikkli	doc_491521501809_item	2501028	et	4	main
all	doc_491521501809_item	2501029	et	3	main
nii	doc_491521501809_item	2501030	et	3	main
et	doc_491521501809_item	2501031	et	3	main
kohe	doc_491521501809_item	2501032	et	4	main
tuleb	doc_491521501809_item	2501037	et	3	main
järgmisena	doc_491521501809_item	2501038	et	3	main
teise	doc_491521501809_item	2501050	et	4	main
poole	doc_491521501809_item	2501065	et	4	main
kolm	doc_491521501809_item	2501069	et	3	main
tõsta	doc_491521501809_item	2501072	et	4	main
nii	doc_491521501809_item	2501073	et	3	main
et	doc_491521501809_item	2501074	et	3	main
oleksid	doc_491521501809_item	2501075	et	4	main
ajalehe	doc_491521501809_item	2501080	et	3	main
lisa	doc_491521501809_item	2501081	et	4	main
jõhvi	doc_491521501809_item	2501082	et	4	main
teataja	doc_491521501809_item	2501083	et	4	main
võiksin	doc_491521501809_item	2501084	et	3	main
isegi	doc_491521501809_item	2501085	et	4	main
öelad	doc_491521501809_item	2501086	et	4	main
et	doc_491521501809_item	2501087	et	3	main
ta	doc_491521501809_item	2501088	et	4	main
on	doc_491521501809_item	2501089	et	4	main
ideaalne	doc_491521501809_item	2501090	et	3	main
siin	doc_491521501809_item	2501091	et	4	main
on	doc_491521501809_item	2501092	et	4	main
kasutatud	doc_491521501809_item	2501093	et	4	main
üks	doc_491521501809_item	2501094	et	3	main
ja	doc_491521501809_item	2501095	et	3	main
sama	doc_491521501809_item	2501096	et	4	main
veeulaius	doc_491521501809_item	2501097	et	4	main
12	doc_491521501809_item	2501098	et	2	main
cic	doc_491521501809_item	2501099	et	4	main
ühel	doc_491521501809_item	2501100	et	3	main
real	doc_491521501809_item	2501101	et	3	main
on	doc_491521501809_item	2501102	et	4	main
keskmiselt	doc_491521501809_item	2501103	et	4	main
5	doc_491521501809_item	2501104	et	2	main
poolitatud	doc_491521501809_item	2501107	et	4	main
sellega	doc_491521501809_item	2501118	et	3	main
kirju	doc_491521501809_item	2501121	et	4	main
ole	doc_491521501809_item	2501125	et	4	main
on	doc_491521501809_item	2501130	et	4	main
on	doc_491521501809_item	2501134	et	4	main
ühiskonnas	doc_491521501809_item	2501146	et	4	main
elada	doc_491521501809_item	2501147	et	3	main
ja	doc_491521501809_item	2501148	et	3	main
sellega	doc_491521501809_item	2501149	et	3	main
meie	doc_491521501809_item	2501153	et	4	main
kokku	doc_491521501809_item	2501155	et	3	main
vähe	doc_491521501809_item	2501169	et	3	main
on	doc_491521501809_item	2501172	et	4	main
samas	doc_491521501809_item	2501205	et	4	main
toetab	doc_491521501809_item	2501206	et	3	main
on	doc_491521501809_item	2501211	et	4	main
osas	doc_491521501809_item	2501227	et	4	main
köitab	doc_491521501809_item	2501234	et	4	main
tee	doc_491521501809_item	2501244	et	4	main
ajalehes	doc_491521501809_item	2501245	et	3	main
liikuvust	doc_491521501809_item	2501246	et	4	main
lehekälg	doc_491521501809_item	2501275	et	4	main
on	doc_491521501809_item	2501276	et	4	main
kolmas	doc_491521501809_item	2501280	et	3	main
on	doc_491521501809_item	2501281	et	4	main
et	doc_491521501809_item	2501291	et	3	main
lase	doc_491521501809_item	2501293	et	4	main
igal	doc_491521501809_item	2501294	et	3	main
fotol	doc_491521501809_item	2501295	et	3	main
mõjule	doc_491521501809_item	2501296	et	3	main
pääseda	doc_491521501809_item	2501297	et	3	main
fotoallkiri	doc_491521501809_item	2501298	et	3	main
põhjaranniku	doc_491521501809_item	2501299	et	3	main
fotodeallkirjad	doc_491521501809_item	2501300	et	4	main
seitse	doc_491521501809_item	2501308	et	3	main
rida	doc_491521501809_item	2501309	et	4	main
pikat	doc_491521501809_item	2501320	et	4	main
jõhvi	doc_491521501809_item	2501328	et	4	main
teatajas	doc_491521501809_item	2501329	et	4	main
pildil	doc_491521501809_item	2501335	et	3	main
ilma	doc_491521501809_item	2501352	et	4	main
allkirjadeta	doc_491521501809_item	2501353	et	3	main
raskusi	doc_491521501809_item	2501357	et	4	main
kuhu	doc_491521501809_item	2501359	et	3	main
see	doc_491521501809_item	2501360	et	3	main
foto	doc_491521501809_item	2501361	et	4	main
kuulub	doc_491521501809_item	2501362	et	3	main
ja	doc_491521501809_item	2501363	et	3	main
millest	doc_491521501809_item	2501364	et	3	main
fotodest	doc_491521501809_item	2501384	et	3	main
tühja	doc_491521501809_item	2501392	et	4	main
natukene	doc_491521501809_item	2501402	et	4	main
võimalust	doc_491521501809_item	2501405	et	3	main
pöhjaranniku	doc_491521501809_item	2501407	et	4	main
kasutatud	doc_491521501809_item	2501416	et	4	main
plokk-kiri	doc_491521501809_item	2501417	et	3	main
kohe	doc_491521501809_item	2501424	et	4	main
on	doc_491521501809_item	2501438	et	4	main
hästi	doc_491521501809_item	2501439	et	3	main
info	doc_491521501809_item	2501448	et	4	main
kasutamisel	doc_491521501809_item	2501454	et	4	main
ning	doc_491521501809_item	2501455	et	3	main
tõstetakse	doc_491521501809_item	2501463	et	4	main
selleks	doc_491521501809_item	2501469	et	4	main
paks	doc_491521501809_item	2501474	et	3	main
ajalehes	doc_491521501809_item	2501476	et	3	main
päris	doc_491521501809_item	2501519	et	4	main
ühele	doc_491521501809_item	2501522	et	3	main
nagu	doc_491521501809_item	2501524	et	3	main
mingil	doc_491521501809_item	2501525	et	4	main
kasutamine	doc_491521501809_item	2501539	et	4	main
leheküljed	doc_491521501809_item	2501549	et	3	main
on	doc_491521501809_item	2501550	et	4	main
tervikuna	doc_491521501809_item	2501551	et	3	main
kergesti	doc_491521501809_item	2501552	et	3	main
haaratavad	doc_491521501809_item	2501553	et	4	main
enda	doc_491521501809_item	2501564	et	4	main
külge	doc_491521501809_item	2501565	et	4	main
haagivad	doc_491521501809_item	2501566	et	3	main
ning	doc_491521501809_item	2501567	et	3	main
muljet	doc_491521501809_item	2501122	et	3	main
jõhvi	doc_491521501809_item	2501132	et	4	main
langeb	doc_491521501809_item	2501152	et	3	main
elustiiliga	doc_491521501809_item	2501154	et	3	main
jõhvi	doc_491521501809_item	2501156	et	4	main
nõrgestuma	doc_491521501809_item	2501161	et	3	main
ja	doc_491521501809_item	2501170	et	3	main
nad	doc_491521501809_item	2501173	et	3	main
dokumentaal	doc_491521501809_item	2501174	et	4	main
fotod	doc_491521501809_item	2501175	et	3	main
esimesel	doc_491521501809_item	2501176	et	3	main
leheküljel	doc_491521501809_item	2501177	et	3	main
on	doc_491521501809_item	2501178	et	4	main
paigutatud	doc_491521501809_item	2501179	et	4	main
suur	doc_491521501809_item	2501180	et	3	main
stamp	doc_491521501809_item	2501181	et	3	main
foto	doc_491521501809_item	2501182	et	4	main
foto	doc_491521501809_item	2501183	et	4	main
sobib	doc_491521501809_item	2501184	et	3	main
väga	doc_491521501809_item	2501185	et	3	main
hästi	doc_491521501809_item	2501186	et	3	main
tekstile	doc_491521501809_item	2501187	et	3	main
aga	doc_491521501809_item	2501188	et	3	main
ei	doc_491521501809_item	2501189	et	4	main
anna	doc_491521501809_item	2501190	et	4	main
enam	doc_491521501809_item	2501191	et	4	main
mingit	doc_491521501809_item	2501192	et	3	main
infot	doc_491521501809_item	2501193	et	3	main
kolmandal	doc_491521501809_item	2501194	et	3	main
leheküljel	doc_491521501809_item	2501195	et	3	main
on	doc_491521501809_item	2501196	et	4	main
suur	doc_491521501809_item	2501198	et	3	main
jälle	doc_491521501809_item	2501197	et	3	main
mitte	doc_491521501809_item	2501199	et	3	main
kuid	doc_491521501809_item	2501139	et	4	main
aga	doc_491521501809_item	2501140	et	3	main
põhjaranniku	doc_491521501809_item	2501150	et	3	main
fotosid	doc_491521501809_item	2501168	et	3	main
midagi	doc_491521501809_item	2501200	et	4	main
foto	doc_491521501809_item	2501203	et	4	main
aga	doc_491521501809_item	2501204	et	3	main
suuus	doc_491521501809_item	2501210	et	4	main
ajalehes	doc_491521501809_item	2501222	et	3	main
kõige	doc_491521501809_item	2501225	et	4	main
ning	doc_491521501809_item	2501230	et	3	main
fotoga	doc_491521501809_item	2501232	et	3	main
ka	doc_491521501809_item	2501239	et	3	main
sündmusfotod	doc_491521501809_item	2501240	et	3	main
nad	doc_491521501809_item	2501242	et	3	main
huvitavust	doc_491521501809_item	2501248	et	4	main
on	doc_491521501809_item	2501260	et	4	main
stampfotod	doc_491521501809_item	2501261	et	3	main
nad	doc_491521501809_item	2501262	et	3	main
on	doc_491521501809_item	2501263	et	4	main
igavad	doc_491521501809_item	2501264	et	3	main
ja	doc_491521501809_item	2501265	et	3	main
mitte	doc_491521501809_item	2501266	et	3	main
palju	doc_491521501809_item	2501272	et	4	main
stampfotolised	doc_491521501809_item	2501282	et	4	main
viimane	doc_491521501809_item	2501283	et	3	main
aga	doc_491521501809_item	2501284	et	3	main
sündmusfotosid	doc_491521501809_item	2501288	et	3	main
on	doc_491521501809_item	2501301	et	4	main
piisavalt	doc_491521501809_item	2501302	et	4	main
kehvad	doc_491521501809_item	2501303	et	3	main
see	doc_491521501809_item	2501311	et	3	main
on	doc_491521501809_item	2501312	et	4	main
pigem	doc_491521501809_item	2501313	et	3	main
pisikene	doc_491521501809_item	2501314	et	3	main
artikkel	doc_491521501809_item	2501315	et	3	main
aga	doc_491521501809_item	2501316	et	3	main
mitte	doc_491521501809_item	2501317	et	3	main
sest	doc_491521501809_item	2501214	et	4	main
artikkel	doc_491521501809_item	2501215	et	3	main
kuulub	doc_491521501809_item	2501217	et	3	main
tähtsamatest	doc_491521501809_item	2501221	et	4	main
artikkel	doc_491521501809_item	2501223	et	3	main
pealkijaga	doc_491521501809_item	2501229	et	4	main
aga	doc_491521501809_item	2501241	et	3	main
ei	doc_491521501809_item	2501243	et	4	main
on	doc_491521501809_item	2501255	et	4	main
pigem	doc_491521501809_item	2501256	et	3	main
staatiline	doc_491521501809_item	2501257	et	3	main
ülejäänud	doc_491521501809_item	2501258	et	4	main
portreefotod	doc_491521501809_item	2501259	et	3	main
on	doc_491521501809_item	2501270	et	4	main
hästi	doc_491521501809_item	2501271	et	3	main
liigutav	doc_491521501809_item	2501287	et	4	main
spordiosas	doc_491521501809_item	2501304	et	3	main
pildi	doc_491521501809_item	2501305	et	4	main
all	doc_491521501809_item	2501306	et	3	main
nii	doc_491521501809_item	2501319	et	3	main
lugeja	doc_491521501809_item	2501322	et	4	main
kuigi	doc_491521501809_item	2501337	et	3	main
ise	doc_491521501809_item	2501341	et	4	main
sellega	doc_491521501809_item	2501343	et	3	main
on	doc_491521501809_item	2501345	et	4	main
mitte	doc_491521501809_item	2501346	et	3	main
vajalikud	doc_491521501809_item	2501347	et	3	main
mõned	doc_491521501809_item	2501348	et	3	main
fotod	doc_491521501809_item	2501349	et	3	main
on	doc_491521501809_item	2501350	et	4	main
üldse	doc_491521501809_item	2501351	et	3	main
kitsamalt	doc_491521501809_item	2501385	et	4	main
seega	doc_491521501809_item	2501387	et	4	main
jää	doc_491521501809_item	2501389	et	4	main
allkirjast	doc_491521501809_item	2501390	et	4	main
pisut	doc_491521501809_item	2501391	et	3	main
küll	doc_491521501809_item	2501395	et	4	main
võiks	doc_491521501809_item	2501396	et	4	main
olla	doc_491521501809_item	2501397	et	3	main
tühi	doc_491521501809_item	2501398	et	3	main
ruum	doc_491521501809_item	2501399	et	3	main
annab	doc_491521501809_item	2501400	et	3	main
mõtlemise	doc_491521501809_item	2501404	et	4	main
on	doc_491521501809_item	2501415	et	4	main
mitmekesisem	doc_491521501809_item	2501430	et	4	main
et	doc_491521501809_item	2501431	et	3	main
ei	doc_491521501809_item	2501432	et	4	main
olnud	doc_491521501809_item	2501433	et	4	main
ühetaolise	doc_491521501809_item	2501434	et	3	main
tunnet	doc_491521501809_item	2501435	et	3	main
viimasel	doc_491521501809_item	2501436	et	3	main
lehel	doc_491521501809_item	2501437	et	3	main
kõik	doc_491521501809_item	2501447	et	4	main
kirja	doc_491521501809_item	2501453	et	4	main
kohal	doc_491521501809_item	2501461	et	4	main
põhjarannikus	doc_491521501809_item	2501462	et	3	main
üks	doc_491521501809_item	2501472	et	3	main
ajaleht	doc_491521501809_item	2501508	et	3	main
ja	doc_491521501809_item	2501509	et	3	main
ei	doc_491521501809_item	2501510	et	4	main
palju	doc_491521501809_item	2501520	et	4	main
seisab	doc_491521501809_item	2501224	et	3	main
keskmises	doc_491521501809_item	2501226	et	3	main
suure	doc_491521501809_item	2501228	et	3	main
sellega	doc_491521501809_item	2501233	et	3	main
lugeja	doc_491521501809_item	2501235	et	4	main
tähelepanu	doc_491521501809_item	2501236	et	4	main
on	doc_491521501809_item	2501237	et	4	main
ega	doc_491521501809_item	2501247	et	3	main
neid	doc_491521501809_item	2501250	et	4	main
jõhvi	doc_491521501809_item	2501268	et	4	main
teatajas	doc_491521501809_item	2501269	et	4	main
esimene	doc_491521501809_item	2501274	et	3	main
on	doc_491521501809_item	2501285	et	4	main
on	doc_491521501809_item	2501289	et	4	main
teksti	doc_491521501809_item	2501310	et	4	main
esitatud	doc_491521501809_item	2501336	et	4	main
räägib	doc_491521501809_item	2501339	et	3	main
endaga	doc_491521501809_item	2501356	et	4	main
arusaamisel	doc_491521501809_item	2501358	et	4	main
ei	doc_491521501809_item	2501382	et	4	main
ja	doc_491521501809_item	2501386	et	3	main
iseseisva	doc_491521501809_item	2501403	et	3	main
suuremate	doc_491521501809_item	2501418	et	4	main
aga	doc_491521501809_item	2501419	et	3	main
lihtsalt	doc_491521501809_item	2501330	et	4	main
ümberjutustavad	doc_491521501809_item	2501331	et	3	main
seda	doc_491521501809_item	2501332	et	3	main
mis	doc_491521501809_item	2501333	et	4	main
foto	doc_491521501809_item	2501338	et	4	main
ja	doc_491521501809_item	2501342	et	3	main
allkitjad	doc_491521501809_item	2501344	et	4	main
toob	doc_491521501809_item	2501355	et	3	main
tuleb	doc_491521501809_item	2501365	et	3	main
jutt	doc_491521501809_item	2501366	et	3	main
nt	doc_491521501809_item	2501367	et	4	main
jõhvi	doc_491521501809_item	2501368	et	4	main
teataja	doc_491521501809_item	2501369	et	4	main
neljandal	doc_491521501809_item	2501370	et	3	main
leheküljel	doc_491521501809_item	2501371	et	3	main
kaks	doc_491521501809_item	2501372	et	3	main
spordi	doc_491521501809_item	2501373	et	4	main
fotod	doc_491521501809_item	2501374	et	3	main
fotoallkirjad	doc_491521501809_item	2501375	et	3	main
on	doc_491521501809_item	2501376	et	4	main
eristatud	doc_491521501809_item	2501377	et	4	main
ajalehes	doc_491521501809_item	2501378	et	3	main
paksema	doc_491521501809_item	2501379	et	4	main
plokk-kirjaga	doc_491521501809_item	2501380	et	3	main
allkirjad	doc_491521501809_item	2501381	et	3	main
ladunud	doc_491521501809_item	2501383	et	4	main
ruumi	doc_491521501809_item	2501393	et	4	main
mis	doc_491521501809_item	2501394	et	4	main
pisiinfo	doc_491521501809_item	2501408	et	4	main
on	doc_491521501809_item	2501409	et	4	main
kergesti	doc_491521501809_item	2501410	et	3	main
kohta	doc_491521501809_item	2501414	et	4	main
antiikva	doc_491521501809_item	2501420	et	4	main
väikesed	doc_491521501809_item	2501421	et	4	main
on	doc_491521501809_item	2501423	et	4	main
arusaadavad	doc_491521501809_item	2501425	et	3	main
suured	doc_491521501809_item	2501426	et	3	main
teevad	doc_491521501809_item	2501427	et	3	main
ajalehe	doc_491521501809_item	2501428	et	3	main
ilusam	doc_491521501809_item	2501429	et	4	main
palju	doc_491521501809_item	2501440	et	4	main
pisiinfot	doc_491521501809_item	2501441	et	3	main
on	doc_491521501809_item	2501449	et	4	main
hästi	doc_491521501809_item	2501450	et	3	main
iga	doc_491521501809_item	2501456	et	4	main
esile	doc_491521501809_item	2501465	et	3	main
võtmesõna	doc_491521501809_item	2501466	et	4	main
on	doc_491521501809_item	2501470	et	4	main
kiri	doc_491521501809_item	2501475	et	3	main
on	doc_491521501809_item	2501477	et	4	main
vähem	doc_491521501809_item	2501534	et	4	main
sellega	doc_491521501809_item	2501535	et	3	main
on	doc_491521501809_item	2501536	et	4	main
on	doc_491521501809_item	2501546	et	4	main
korrastavad	doc_491521501809_item	2501561	et	4	main
ja	doc_491521501809_item	2501562	et	3	main
pilgu	doc_491521501809_item	2501563	et	4	main
hajumast	doc_491521501809_item	2501570	et	3	main
kirevaks	doc_491521501809_item	2501571	et	4	main
nähtav	doc_491521501809_item	2501576	et	4	main
oluline	doc_491521501809_item	2501584	et	4	main
tähtsamad	doc_491521501809_item	2501585	et	4	main
uudised	doc_491521501809_item	2501586	et	3	main
lood	doc_491521501809_item	2501587	et	4	main
nende	doc_491521501809_item	2501598	et	4	main
juurde	doc_491521501809_item	2501599	et	4	main
kuulub	doc_491521501809_item	2501600	et	3	main
suur	doc_491521501809_item	2501601	et	3	main
foto	doc_491521501809_item	2501602	et	4	main
koosneb	doc_491521501809_item	2501608	et	3	main
aga	doc_491521501809_item	2501613	et	3	main
põhjarannikus	doc_491521501809_item	2501614	et	3	main
või	doc_491521501809_item	2501628	et	4	main
meelelahutus	doc_491521501809_item	2501629	et	4	main
põhjarannik	doc_491521501809_item	2501630	et	3	main
eksamitöö	doc_491521501810_item	2501631	et	4	main
1	doc_491521501810_item	2501632	et	2	main
täitke	doc_491521501810_item	2501633	et	3	main
jalgadele	doc_491521501810_item	2501651	et	3	main
tuub	doc_491521501810_item	2501658	et	3	main
150	doc_491521501810_item	2501660	et	2	main
jäätmeid	doc_491521501810_item	2501670	et	3	main
tänases	doc_491521501810_item	2501672	et	3	main
sorteerida	doc_491521501810_item	2501674	et	3	main
jäätmekäitlusfirma	doc_491521501810_item	2501675	et	4	main
väitel	doc_491521501810_item	2501677	et	3	main
hoida	doc_491521501810_item	2501712	et	3	main
эстонии	doc_491521501810_item	2501718	et	2	main
окружающей	doc_491521501810_item	2501723	et	2	main
мусора	doc_491521501810_item	2501728	et	2	main
который	doc_491521501810_item	2501733	et	2	main
сдать	doc_491521501810_item	2501737	et	2	main
у	doc_491521501810_item	2501741	et	2	main
государством	doc_491521501810_item	2501746	et	2	main
ситуация	doc_491521501810_item	2501750	et	2	main
как	doc_491521501810_item	2501754	et	2	main
природных	doc_491521501810_item	2501759	et	2	main
kasutades	doc_491521501810_item	2501769	et	3	main
korgiga	doc_491521501810_item	2501801	et	3	main
kergesti	doc_491521501810_item	2501804	et	3	main
tihti	doc_491521501810_item	2501816	et	3	main
toodetakse	doc_491521501810_item	2501831	et	3	main
tasu	doc_491521501810_item	2501834	et	4	main
loosisedelitega	doc_491521501810_item	2501846	et	3	main
vahel	doc_491521501810_item	2501852	et	4	main
asju	doc_491521501810_item	2501854	et	3	main
kuulutused	doc_491521501809_item	2501442	et	4	main
tööpakkumised	doc_491521501809_item	2501443	et	3	main
ost-müük	doc_491521501809_item	2501444	et	3	main
jt	doc_491521501809_item	2501445	et	4	main
aga	doc_491521501809_item	2501446	et	3	main
erinevate	doc_491521501809_item	2501452	et	4	main
eristuskirjaga	doc_491521501809_item	2501464	et	4	main
kasutatud	doc_491521501809_item	2501471	et	4	main
eristuskirjaseeria	doc_491521501809_item	2501473	et	4	main
kasutatud	doc_491521501809_item	2501478	et	4	main
veerulaius	doc_491521501809_item	2501479	et	4	main
10	doc_491521501809_item	2501480	et	2	main
cic	doc_491521501809_item	2501481	et	4	main
ning	doc_491521501809_item	2501482	et	3	main
pisiinfos	doc_491521501809_item	2501483	et	3	main
10	doc_491521501809_item	2501484	et	2	main
cic	doc_491521501809_item	2501485	et	4	main
vähemalt	doc_491521501809_item	2501486	et	4	main
tavaline	doc_491521501809_item	2501487	et	4	main
pisiinfo	doc_491521501809_item	2501488	et	4	main
veerulaius	doc_491521501809_item	2501489	et	4	main
8-9	doc_491521501809_item	2501491	et	2	main
peab	doc_491521501809_item	2501490	et	4	main
cic	doc_491521501809_item	2501492	et	4	main
olema	doc_491521501809_item	2501493	et	4	main
aga	doc_491521501809_item	2501494	et	3	main
ma	doc_491521501809_item	2501495	et	3	main
arvan	doc_491521501809_item	2501496	et	3	main
et	doc_491521501809_item	2501497	et	3	main
suurt	doc_491521501809_item	2501498	et	3	main
probleemi	doc_491521501809_item	2501499	et	4	main
siin	doc_491521501809_item	2501500	et	4	main
ei	doc_491521501809_item	2501501	et	4	main
ole	doc_491521501809_item	2501502	et	4	main
kuna	doc_491521501809_item	2501503	et	3	main
põhjarannik	doc_491521501809_item	2501504	et	3	main
on	doc_491521501809_item	2501505	et	4	main
väike	doc_491521501809_item	2501506	et	4	main
provintsiaalne	doc_491521501809_item	2501507	et	3	main
oma	doc_491521501809_item	2501459	et	4	main
kindlal	doc_491521501809_item	2501460	et	3	main
või	doc_491521501809_item	2501467	et	4	main
fraas	doc_491521501809_item	2501468	et	3	main
sellele	doc_491521501809_item	2501514	et	4	main
ajalehele	doc_491521501809_item	2501515	et	3	main
pole	doc_491521501809_item	2501516	et	3	main
vaja	doc_491521501809_item	2501517	et	4	main
mahutada	doc_491521501809_item	2501518	et	3	main
leheküljele	doc_491521501809_item	2501523	et	3	main
vastupidi	doc_491521501809_item	2501529	et	3	main
ruumi	doc_491521501809_item	2501530	et	4	main
on	doc_491521501809_item	2501531	et	4	main
aga	doc_491521501809_item	2501532	et	3	main
infot	doc_491521501809_item	2501533	et	3	main
on	doc_491521501809_item	2501540	et	4	main
täiesti	doc_491521501809_item	2501541	et	3	main
elemendid	doc_491521501809_item	2501558	et	3	main
mis	doc_491521501809_item	2501559	et	4	main
lehekülge	doc_491521501809_item	2501560	et	4	main
kogumiks	doc_491521501809_item	2501573	et	4	main
vähem	doc_491521501809_item	2501583	et	4	main
kaksiklehekülgede	doc_491521501809_item	2501590	et	4	main
paremapoolsele	doc_491521501809_item	2501591	et	3	main
lehele	doc_491521501809_item	2501592	et	3	main
kahest	doc_491521501809_item	2501611	et	4	main
teda	doc_491521501809_item	2501621	et	4	main
täna	doc_491521501809_item	2501623	et	4	main
lüngad	doc_491521501810_item	2501634	et	3	main
kergesti	doc_491521501810_item	2501635	et	3	main
määritav	doc_491521501810_item	2501636	et	4	main
naha	doc_491521501810_item	2501644	et	3	main
eemaldatavaks	doc_491521501810_item	2501648	et	4	main
higistavatele	doc_491521501810_item	2501650	et	4	main
määrige	doc_491521501810_item	2501652	et	3	main
õhtul	doc_491521501810_item	2501655	et	3	main
tervisekaitseinspektsiooni	doc_491521501810_item	2501665	et	4	main
missuguseid	doc_491521501810_item	2501669	et	3	main
keskkonnanõuniku	doc_491521501810_item	2501676	et	3	main
teadvustama	doc_491521501810_item	2501708	et	3	main
loodusressursse	doc_491521501810_item	2501710	et	3	main
какие	doc_491521501810_item	2501713	et	2	main
в	doc_491521501810_item	2501717	et	2	main
фирмы	doc_491521501810_item	2501725	et	2	main
есть	doc_491521501810_item	2501729	et	2	main
к	doc_491521501810_item	2501739	et	2	main
нас	doc_491521501810_item	2501742	et	2	main
система	doc_491521501810_item	2501747	et	2	main
начинают	doc_491521501810_item	2501755	et	2	main
ресурсов	doc_491521501810_item	2501760	et	2	main
a	doc_491521501810_item	2501763	et	4	main
lauseosa	doc_491521501810_item	2501767	et	4	main
tav-	doc_491521501810_item	2501770	et	4	main
pöörake	doc_491521501810_item	2501772	et	4	main
šampoonipudel	doc_491521501810_item	2501798	et	2	main
mida	doc_491521501810_item	2501802	et	4	main
saab	doc_491521501810_item	2501803	et	3	main
keemiavahendeid	doc_491521501810_item	2501814	et	3	main
tasub	doc_491521501810_item	2501818	et	3	main
tagavaraks	doc_491521501810_item	2501820	et	3	main
keemiavahendeid	doc_491521501810_item	2501824	et	3	main
välismaal	doc_491521501810_item	2501832	et	4	main
kulutada	doc_491521501810_item	2501836	et	3	main
toodetavatele	doc_491521501810_item	2501839	et	4	main
kreemidele	doc_491521501810_item	2501840	et	3	main
5	doc_491521501810_item	2501845	et	2	main
mis	doc_491521501810_item	2501847	et	4	main
lisatakse	doc_491521501810_item	2501849	et	4	main
võidavad	doc_491521501810_item	2501850	et	4	main
kaupadesse	doc_491521501810_item	2501865	et	3	main
tasub	doc_491521501810_item	2501876	et	3	main
7	doc_491521501810_item	2501879	et	2	main
turul	doc_491521501810_item	2501886	et	3	main
ma	doc_491521501810_item	2501888	et	3	main
tihti	doc_491521501810_item	2501890	et	3	main
pesu	doc_491521501810_item	2501895	et	4	main
kulu	doc_491521501810_item	2501900	et	4	main
nii	doc_491521501810_item	2501901	et	3	main
kiiresti	doc_491521501810_item	2501902	et	3	main
ei	doc_491521501810_item	2501907	et	4	main
nõua	doc_491521501809_item	2501511	et	4	main
ranget	doc_491521501809_item	2501512	et	3	main
kriteeriume	doc_491521501809_item	2501513	et	3	main
infot	doc_491521501809_item	2501521	et	3	main
suurel	doc_491521501809_item	2501526	et	3	main
ajalehel	doc_491521501809_item	2501527	et	3	main
vaid	doc_491521501809_item	2501528	et	3	main
põhjendatud	doc_491521501809_item	2501542	et	4	main
kokkuvõte	doc_491521501809_item	2501543	et	3	main
põhjaranniku	doc_491521501809_item	2501544	et	3	main
ajalehes	doc_491521501809_item	2501545	et	3	main
lugeja	doc_491521501809_item	2501554	et	4	main
kohe	doc_491521501809_item	2501555	et	4	main
leiab	doc_491521501809_item	2501556	et	3	main
lehtedel	doc_491521501809_item	2501569	et	4	main
kohe	doc_491521501809_item	2501574	et	4	main
paigutatud	doc_491521501809_item	2501589	et	4	main
või	doc_491521501809_item	2501596	et	4	main
siis	doc_491521501809_item	2501597	et	3	main
teatajas	doc_491521501809_item	2501604	et	4	main
rubriigid	doc_491521501809_item	2501605	et	3	main
puuduvad	doc_491521501809_item	2501606	et	4	main
ise	doc_491521501809_item	2501619	et	4	main
mida	doc_491521501809_item	2501620	et	4	main
suurema	doc_491521501809_item	2501537	et	4	main
veerulaiuse	doc_491521501809_item	2501538	et	4	main
kerge	doc_491521501809_item	2501547	et	4	main
orienteeruda	doc_491521501809_item	2501548	et	3	main
domineerivad	doc_491521501809_item	2501557	et	4	main
laikude	doc_491521501809_item	2501572	et	4	main
on	doc_491521501809_item	2501575	et	4	main
on	doc_491521501809_item	2501578	et	4	main
info	doc_491521501809_item	2501580	et	4	main
kus	doc_491521501809_item	2501581	et	3	main
trükitud	doc_491521501809_item	2501593	et	4	main
paksemas	doc_491521501809_item	2501594	et	4	main
sest	doc_491521501809_item	2501607	et	4	main
lehest	doc_491521501809_item	2501612	et	4	main
nemad	doc_491521501809_item	2501615	et	3	main
lugeja	doc_491521501809_item	2501617	et	4	main
uudised	doc_491521501809_item	2501625	et	3	main
sport	doc_491521501809_item	2501627	et	3	main
jalakreem	doc_491521501810_item	2501637	et	3	main
ja	doc_491521501810_item	2501639	et	3	main
kreem	doc_491521501810_item	2501641	et	3	main
sisaldab	doc_491521501810_item	2501659	et	3	main
kreemi	doc_491521501810_item	2501662	et	4	main
soovitatud	doc_491521501810_item	2501663	et	4	main
riigi	doc_491521501810_item	2501664	et	3	main
2	doc_491521501810_item	2501667	et	2	main
отходы	doc_491521501810_item	2501714	et	2	main
по	doc_491521501810_item	2501719	et	2	main
по	doc_491521501810_item	2501722	et	2	main
занимающейся	doc_491521501810_item	2501726	et	2	main
собирать	doc_491521501810_item	2501731	et	2	main
продать	doc_491521501810_item	2501735	et	2	main
сожалению	doc_491521501810_item	2501740	et	2	main
установленная	doc_491521501810_item	2501745	et	2	main
неприменно	doc_491521501810_item	2501751	et	2	main
осознавать	doc_491521501810_item	2501756	et	2	main
grammatika	doc_491521501810_item	2501761	et	4	main
kirjutage	doc_491521501810_item	2501764	et	3	main
paksus	doc_491521501810_item	2501765	et	4	main
kesksõna	doc_491521501810_item	2501771	et	4	main
peab	doc_491521501810_item	2501799	et	4	main
olema	doc_491521501810_item	2501800	et	4	main
šampoonipudel	doc_491521501810_item	2501807	et	2	main
olema	doc_491521501810_item	2501809	et	4	main
3	doc_491521501810_item	2501813	et	2	main
osta	doc_491521501810_item	2501819	et	4	main
takistavad	doc_491521501809_item	2501568	et	4	main
kus	doc_491521501809_item	2501577	et	3	main
oluline	doc_491521501809_item	2501579	et	4	main
on	doc_491521501809_item	2501582	et	4	main
on	doc_491521501809_item	2501588	et	4	main
kirjas	doc_491521501809_item	2501595	et	4	main
jõhvi	doc_491521501809_item	2501603	et	4	main
lisa	doc_491521501809_item	2501609	et	4	main
vaid	doc_491521501809_item	2501610	et	3	main
on	doc_491521501809_item	2501616	et	4	main
valib	doc_491521501809_item	2501618	et	3	main
huvitab	doc_491521501809_item	2501622	et	3	main
kas	doc_491521501809_item	2501624	et	3	main
majandus	doc_491521501809_item	2501626	et	4	main
toitev	doc_491521501810_item	2501640	et	4	main
muudab	doc_491521501810_item	2501642	et	3	main
kergesti	doc_491521501810_item	2501647	et	3	main
palju	doc_491521501810_item	2501649	et	4	main
kreemi	doc_491521501810_item	2501653	et	4	main
igal	doc_491521501810_item	2501654	et	3	main
poolt	doc_491521501810_item	2501666	et	4	main
tõlkige	doc_491521501810_item	2501668	et	3	main
eestis	doc_491521501810_item	2501673	et	3	main
vajadust	doc_491521501810_item	2501709	et	4	main
kokku	doc_491521501810_item	2501711	et	3	main
сортировать	doc_491521501810_item	2501716	et	2	main
niisutav	doc_491521501810_item	2501638	et	4	main
kõvenenud	doc_491521501810_item	2501643	et	4	main
pehmeks	doc_491521501810_item	2501645	et	3	main
ja	doc_491521501810_item	2501646	et	3	main
antibakteriaalse	doc_491521501810_item	2501656	et	4	main
toimega	doc_491521501810_item	2501657	et	4	main
ml	doc_491521501810_item	2501661	et	4	main
tasub	doc_491521501810_item	2501671	et	3	main
on	doc_491521501810_item	2501678	et	4	main
lisaks	doc_491521501810_item	2501679	et	4	main
ohtlikele	doc_491521501810_item	2501680	et	3	main
jäätmetele	doc_491521501810_item	2501681	et	4	main
mõtet	doc_491521501810_item	2501682	et	3	main
välja	doc_491521501810_item	2501683	et	4	main
korjata	doc_491521501810_item	2501684	et	4	main
praht	doc_491521501810_item	2501685	et	3	main
mida	doc_491521501810_item	2501686	et	4	main
saab	doc_491521501810_item	2501687	et	3	main
kas	doc_491521501810_item	2501688	et	3	main
tagasi	doc_491521501810_item	2501689	et	3	main
müüa	doc_491521501810_item	2501690	et	3	main
või	doc_491521501810_item	2501691	et	4	main
eraldi	doc_491521501810_item	2501692	et	4	main
ära	doc_491521501810_item	2501693	et	4	main
anda	doc_491521501810_item	2501694	et	3	main
praegu	doc_491521501810_item	2501695	et	3	main
puudub	doc_491521501810_item	2501696	et	3	main
meil	doc_491521501810_item	2501697	et	4	main
veel	doc_491521501810_item	2501698	et	4	main
kahjuks	doc_491521501810_item	2501699	et	4	main
riiklikult	doc_491521501810_item	2501700	et	4	main
korraldatud	doc_491521501810_item	2501701	et	4	main
taaskasutussüsteem	doc_491521501810_item	2501702	et	3	main
olukord	doc_491521501810_item	2501703	et	3	main
kindlasti	doc_491521501810_item	2501704	et	3	main
muutub	doc_491521501810_item	2501705	et	3	main
kui	doc_491521501810_item	2501706	et	3	main
hakatakse	doc_491521501810_item	2501707	et	3	main
надо	doc_491521501810_item	2501715	et	2	main
утверждению	doc_491521501810_item	2501720	et	2	main
советника	doc_491521501810_item	2501721	et	2	main
сбытом	doc_491521501810_item	2501727	et	2	main
впоследствие	doc_491521501810_item	2501734	et	2	main
или	doc_491521501810_item	2501736	et	2	main
еще	doc_491521501810_item	2501743	et	2	main
мусора	doc_491521501810_item	2501749	et	2	main
изменится	doc_491521501810_item	2501752	et	2	main
сохранения	doc_491521501810_item	2501758	et	2	main
11	doc_491521501810_item	2501762	et	2	main
ümber	doc_491521501810_item	2501768	et	3	main
2	doc_491521501810_item	2501797	et	2	main
avada	doc_491521501810_item	2501805	et	3	main
peab	doc_491521501810_item	2501808	et	4	main
kergesti	doc_491521501810_item	2501810	et	3	main
avatava	doc_491521501810_item	2501811	et	4	main
korgiga	doc_491521501810_item	2501812	et	3	main
mida	doc_491521501810_item	2501830	et	4	main
ei	doc_491521501810_item	2501841	et	4	main
tasu	doc_491521501810_item	2501842	et	4	main
kaubale	doc_491521501810_item	2501848	et	3	main
hinnalisi	doc_491521501810_item	2501853	et	4	main
reklaamitakse	doc_491521501810_item	2501868	et	4	main
tasub	doc_491521501810_item	2501869	et	3	main
suhtuda	doc_491521501810_item	2501870	et	3	main
umbusklikult	doc_491521501810_item	2501871	et	4	main
suhtuda	doc_491521501810_item	2501877	et	3	main
mida	doc_491521501810_item	2501884	et	4	main
kaupu	doc_491521501810_item	2501893	et	3	main
a	doc_491521501810_item	2501903	et	4	main
nii	doc_491521501810_item	2501909	et	3	main
grammatika	doc_491521501810_item	2501911	et	4	main
põhjendage	doc_491521501810_item	2501915	et	3	main
parandust	doc_491521501810_item	2501916	et	4	main
minu	doc_491521501810_item	2501918	et	3	main
juurde	doc_491521501810_item	2501923	et	4	main
läheb	doc_491521501810_item	2501926	et	3	main
saanud	doc_491521501810_item	2501934	et	4	main
millal	doc_491521501810_item	2501942	et	3	main
sinu	doc_491521501810_item	2501949	et	3	main
haigeks	doc_491521501810_item	2501951	et	4	main
see	doc_491521501810_item	2501953	et	3	main
tuleb	doc_491521501810_item	2501958	et	3	main
see	doc_491521501810_item	2501962	et	3	main
5	doc_491521501810_item	2501971	et	2	main
kõige	doc_491521501810_item	2501972	et	4	main
raskem	doc_491521501810_item	2501973	et	4	main
on	doc_491521501810_item	2501976	et	4	main
on	doc_491521501810_item	2501985	et	4	main
välja	doc_491521501810_item	2501996	et	4	main
среды	doc_491521501810_item	2501724	et	2	main
смысл	doc_491521501810_item	2501730	et	2	main
мусор	doc_491521501810_item	2501732	et	2	main
сейчас	doc_491521501810_item	2501738	et	2	main
отсуствует	doc_491521501810_item	2501744	et	2	main
переработки	doc_491521501810_item	2501748	et	2	main
так	doc_491521501810_item	2501753	et	2	main
необходимость	doc_491521501810_item	2501757	et	2	main
kirjas	doc_491521501810_item	2501766	et	4	main
tähelepanu	doc_491521501810_item	2501773	et	4	main
sõnajärjele	doc_491521501810_item	2501774	et	3	main
1	doc_491521501810_item	2501775	et	2	main
põrand	doc_491521501810_item	2501776	et	3	main
mida	doc_491521501810_item	2501777	et	4	main
tihti	doc_491521501810_item	2501778	et	3	main
puhastatakse	doc_491521501810_item	2501779	et	3	main
kauem	doc_491521501810_item	2501781	et	4	main
vastu	doc_491521501810_item	2501782	et	3	main
a	doc_491521501810_item	2501783	et	4	main
tihti	doc_491521501810_item	2501784	et	3	main
peab	doc_491521501810_item	2501780	et	4	main
puhastatav	doc_491521501810_item	2501785	et	4	main
põrand	doc_491521501810_item	2501786	et	3	main
peab	doc_491521501810_item	2501787	et	4	main
kauem	doc_491521501810_item	2501788	et	4	main
vastu	doc_491521501810_item	2501789	et	3	main
b	doc_491521501810_item	2501790	et	4	main
puhastatav	doc_491521501810_item	2501792	et	4	main
põrand	doc_491521501810_item	2501793	et	3	main
tihti	doc_491521501810_item	2501791	et	3	main
kulub	doc_491521501810_item	2501794	et	3	main
rutem	doc_491521501810_item	2501795	et	3	main
ära	doc_491521501810_item	2501796	et	4	main
a	doc_491521501810_item	2501806	et	4	main
mida	doc_491521501810_item	2501815	et	4	main
kasutatakse	doc_491521501810_item	2501817	et	3	main
a	doc_491521501810_item	2501821	et	4	main
kasutatavaid	doc_491521501810_item	2501823	et	4	main
osta	doc_491521501810_item	2501826	et	4	main
tagavaraks	doc_491521501810_item	2501827	et	3	main
raha	doc_491521501810_item	2501835	et	4	main
raha	doc_491521501810_item	2501843	et	4	main
inimesed	doc_491521501810_item	2501851	et	3	main
a	doc_491521501810_item	2501855	et	4	main
pidevalt	doc_491521501810_item	2501873	et	4	main
reklaamitavatesse	doc_491521501810_item	2501874	et	4	main
umusklikult	doc_491521501810_item	2501878	et	4	main
ostan	doc_491521501810_item	2501881	et	3	main
müüdavaid	doc_491521501810_item	2501892	et	4	main
pestakse	doc_491521501810_item	2501897	et	3	main
pesu	doc_491521501810_item	2501906	et	4	main
kiiresti	doc_491521501810_item	2501910	et	3	main
parandage	doc_491521501810_item	2501913	et	3	main
homme	doc_491521501810_item	2501920	et	3	main
terveks	doc_491521501810_item	2501933	et	4	main
terveks	doc_491521501810_item	2501939	et	4	main
jäi	doc_491521501810_item	2501944	et	3	main
tütar	doc_491521501810_item	2501946	et	3	main
jäi	doc_491521501810_item	2501948	et	3	main
haigus	doc_491521501810_item	2501954	et	4	main
on	doc_491521501810_item	2501955	et	4	main
teie	doc_491521501810_item	2501959	et	4	main
koju	doc_491521501810_item	2501961	et	3	main
juurde	doc_491521501810_item	2501969	et	4	main
koju	doc_491521501810_item	2501970	et	3	main
ta	doc_491521501810_item	2501979	et	4	main
lamama	doc_491521501810_item	2501982	et	4	main
see	doc_491521501810_item	2501988	et	3	main
et	doc_491521501810_item	2501989	et	3	main
ta	doc_491521501810_item	2501990	et	4	main
arst	doc_491521501810_item	2501995	et	3	main
retsepti	doc_491521501810_item	2501998	et	4	main
retsepti	doc_491521501810_item	2502001	et	4	main
sõnad	doc_491521501810_item	2502021	et	4	main
alla	doc_491521501810_item	2502023	et	3	main
a	doc_491521501810_item	2502024	et	4	main
visake	doc_491521501810_item	2502025	et	4	main
läbi	doc_491521501810_item	2502028	et	4	main
põlenud	doc_491521501810_item	2502029	et	4	main
ravimid	doc_491521501810_item	2502030	et	3	main
ära	doc_491521501810_item	2502031	et	4	main
täpselt	doc_491521501810_item	2502037	et	4	main
peate	doc_491521501810_item	2502046	et	4	main
c	doc_491521501810_item	2502047	et	4	main
mahaviskamise	doc_491521501810_item	2502049	et	3	main
eest	doc_491521501810_item	2502050	et	4	main
vaev	doc_491521501810_item	2502058	et	3	main
viil	doc_491521501810_item	2502060	et	3	main
endale	doc_491521501810_item	2502073	et	4	main
f	doc_491521501810_item	2502081	et	4	main
ma	doc_491521501810_item	2502082	et	3	main
plaani	doc_491521501810_item	2502086	et	4	main
raske	doc_491521501810_item	2502088	et	4	main
heakord	doc_491521501810_item	2502094	et	3	main
röster	doc_491521501810_item	2502121	et	3	main
sidur	doc_491521501810_item	2502125	et	3	main
printima	doc_491521501810_item	2502127	et	3	main
skännima	doc_491521501810_item	2502133	et	4	main
skänner	doc_491521501810_item	2502134	et	4	main
puhuma	doc_491521501810_item	2502136	et	3	main
обогревающее	doc_491521501810_item	2502138	et	2	main
eksamitöö	doc_491521501811_item	2502142	et	4	main
viimaks	doc_491521501811_item	2502144	et	4	main
tulevik	doc_491521501811_item	2502150	et	3	main
lähevad	doc_491521501811_item	2502157	et	3	main
astuda	doc_491521501811_item	2502178	et	3	main
ja	doc_491521501811_item	2502179	et	3	main
kaminas	doc_491521501811_item	2502180	et	3	main
süüdatud	doc_491521501811_item	2502187	et	4	main
kuid	doc_491521501811_item	2502188	et	4	main
ei	doc_491521501811_item	2502190	et	4	main
pole	doc_491521501811_item	2502206	et	3	main
светлое	doc_491521501811_item	2502212	et	2	main
прибыв	doc_491521501811_item	2502218	et	2	main
домой	doc_491521501811_item	2502221	et	2	main
tihti	doc_491521501810_item	2501822	et	3	main
tasub	doc_491521501810_item	2501825	et	3	main
4	doc_491521501810_item	2501828	et	2	main
kreemidele	doc_491521501810_item	2501829	et	3	main
ei	doc_491521501810_item	2501833	et	4	main
a	doc_491521501810_item	2501837	et	4	main
välismaal	doc_491521501810_item	2501838	et	4	main
kulutada	doc_491521501810_item	2501844	et	3	main
kaubale	doc_491521501810_item	2501856	et	3	main
lisatavate	doc_491521501810_item	2501857	et	4	main
loosisedelitega	doc_491521501810_item	2501858	et	3	main
võidavad	doc_491521501810_item	2501859	et	4	main
inimesed	doc_491521501810_item	2501860	et	3	main
vahel	doc_491521501810_item	2501861	et	4	main
hinnalisi	doc_491521501810_item	2501862	et	4	main
6	doc_491521501810_item	2501864	et	2	main
asju	doc_491521501810_item	2501863	et	3	main
mida	doc_491521501810_item	2501866	et	4	main
pidevalt	doc_491521501810_item	2501867	et	4	main
kaupadesse	doc_491521501810_item	2501875	et	3	main
ma	doc_491521501810_item	2501880	et	3	main
kaupu	doc_491521501810_item	2501883	et	3	main
turul	doc_491521501810_item	2501891	et	3	main
8	doc_491521501810_item	2501894	et	2	main
mida	doc_491521501810_item	2501896	et	4	main
käsitsi	doc_491521501810_item	2501898	et	3	main
ei	doc_491521501810_item	2501899	et	4	main
kulu	doc_491521501810_item	2501908	et	4	main
arsti	doc_491521501810_item	2501922	et	4	main
minu	doc_491521501810_item	2501924	et	3	main
arsti	doc_491521501810_item	2501928	et	4	main
juba	doc_491521501810_item	2501935	et	3	main
saanud	doc_491521501810_item	2501940	et	4	main
millal	doc_491521501810_item	2501947	et	3	main
tütar	doc_491521501810_item	2501950	et	3	main
4	doc_491521501810_item	2501952	et	2	main
nakkav	doc_491521501810_item	2501964	et	4	main
haigus	doc_491521501810_item	2501965	et	4	main
arst	doc_491521501810_item	2501966	et	3	main
tuleb	doc_491521501810_item	2501967	et	3	main
voodis	doc_491521501810_item	2501980	et	3	main
tema	doc_491521501810_item	2501986	et	4	main
jaoks	doc_491521501810_item	2501987	et	4	main
b	doc_491521501810_item	2502032	et	4	main
ma	doc_491521501810_item	2502033	et	3	main
aru	doc_491521501810_item	2502038	et	4	main
lahti	doc_491521501810_item	2502043	et	4	main
prügi	doc_491521501810_item	2502048	et	4	main
on	doc_491521501810_item	2502061	et	4	main
väga	doc_491521501810_item	2502062	et	3	main
ja	doc_491521501810_item	2502064	et	3	main
rohkem	doc_491521501810_item	2502074	et	4	main
teadvustama	doc_491521501810_item	2502075	et	3	main
looduskeskkonna	doc_491521501810_item	2502076	et	3	main
reostamise	doc_491521501810_item	2502077	et	4	main
sisaldada	doc_491521501810_item	2502090	et	3	main
g	doc_491521501810_item	2502092	et	4	main
vedur	doc_491521501810_item	2502108	et	3	main
kallur	doc_491521501810_item	2502113	et	3	main
kuvar	doc_491521501810_item	2502115	et	3	main
рестер	doc_491521501810_item	2502122	et	2	main
принтер	doc_491521501810_item	2502129	et	2	main
puhur	doc_491521501810_item	2502137	et	3	main
ometi	doc_491521501811_item	2502145	et	3	main
ees	doc_491521501811_item	2502148	et	4	main
koju	doc_491521501811_item	2502155	et	3	main
ees	doc_491521501811_item	2502159	et	4	main
näe	doc_491521501811_item	2502181	et	4	main
imet	doc_491521501811_item	2502182	et	3	main
põlema	doc_491521501811_item	2502186	et	4	main
hõrgutav	doc_491521501811_item	2502198	et	4	main
õhtu	doc_491521501811_item	2502204	et	4	main
всё	doc_491521501811_item	2502209	et	2	main
после	doc_491521501811_item	2502214	et	2	main
на	doc_491521501811_item	2502219	et	2	main
сами	doc_491521501811_item	2502222	et	2	main
огни	doc_491521501811_item	2502226	et	2	main
дверь	doc_491521501811_item	2502233	et	2	main
сама	doc_491521501811_item	2502236	et	2	main
выходить	doc_491521501811_item	2502241	et	2	main
дождь	doc_491521501811_item	2502246	et	2	main
огонь	doc_491521501811_item	2502251	et	2	main
ещё	doc_491521501811_item	2502256	et	2	main
кухне	doc_491521501811_item	2502263	et	2	main
яблочный	doc_491521501811_item	2502267	et	2	main
venima	doc_491521501811_item	2502293	et	3	main
jahtuma	doc_491521501811_item	2502297	et	3	main
toetuma	doc_491521501811_item	2502299	et	4	main
nakkama	doc_491521501811_item	2502309	et	3	main
leidke	doc_491521501811_item	2502312	et	3	main
väljendite	doc_491521501811_item	2502314	et	3	main
2	doc_491521501811_item	2502321	et	2	main
juurde	doc_491521501811_item	2502324	et	4	main
jätab	doc_491521501811_item	2502329	et	3	main
hobune	doc_491521501811_item	2502343	et	4	main
suurus	doc_491521501811_item	2502346	et	4	main
taks	doc_491521501811_item	2502350	et	3	main
f	doc_491521501811_item	2502351	et	4	main
a	doc_491521501810_item	2501872	et	4	main
tihti	doc_491521501810_item	2501882	et	3	main
müüakse	doc_491521501810_item	2501885	et	3	main
a	doc_491521501810_item	2501887	et	4	main
ostan	doc_491521501810_item	2501889	et	3	main
käsitsi	doc_491521501810_item	2501904	et	3	main
pestav	doc_491521501810_item	2501905	et	4	main
1	doc_491521501810_item	2501917	et	2	main
tütar	doc_491521501810_item	2501919	et	3	main
läheb	doc_491521501810_item	2501921	et	3	main
tütar	doc_491521501810_item	2501925	et	3	main
2	doc_491521501810_item	2501930	et	2	main
ta	doc_491521501810_item	2501936	et	4	main
3	doc_491521501810_item	2501941	et	2	main
haigeks	doc_491521501810_item	2501943	et	4	main
sinu	doc_491521501810_item	2501945	et	3	main
arst	doc_491521501810_item	2501957	et	3	main
juurde	doc_491521501810_item	2501960	et	4	main
on	doc_491521501810_item	2501963	et	4	main
jaoks	doc_491521501810_item	2501975	et	4	main
et	doc_491521501810_item	2501978	et	3	main
6	doc_491521501810_item	2501994	et	2	main
kirjutab	doc_491521501810_item	2501997	et	3	main
arst	doc_491521501810_item	2501999	et	3	main
ei	doc_491521501810_item	2502034	et	4	main
mida	doc_491521501810_item	2502039	et	4	main
silmas	doc_491521501810_item	2502045	et	4	main
tõhus	doc_491521501810_item	2502063	et	4	main
saate	doc_491521501810_item	2502066	et	4	main
järeldusi	doc_491521501810_item	2502078	et	4	main
tagajärgi	doc_491521501810_item	2502079	et	4	main
et	doc_491521501810_item	2502084	et	3	main
teostada	doc_491521501810_item	2502091	et	3	main
on	doc_491521501810_item	2502095	et	4	main
viimase	doc_491521501810_item	2502096	et	3	main
tunduvalt	doc_491521501810_item	2502098	et	4	main
esialgu	doc_491521501810_item	2502100	et	3	main
kõlar-	doc_491521501810_item	2502110	et	3	main
грузовая	doc_491521501810_item	2502116	et	2	main
helkima	doc_491521501810_item	2502118	et	3	main
17	doc_491521501810_item	2501912	et	2	main
sõnajärjevead	doc_491521501810_item	2501914	et	3	main
homme	doc_491521501810_item	2501927	et	3	main
juurde	doc_491521501810_item	2501929	et	4	main
ta	doc_491521501810_item	2501931	et	4	main
on	doc_491521501810_item	2501932	et	4	main
on	doc_491521501810_item	2501937	et	4	main
juba	doc_491521501810_item	2501938	et	3	main
nakkav	doc_491521501810_item	2501956	et	4	main
teie	doc_491521501810_item	2501968	et	4	main
tema	doc_491521501810_item	2501974	et	4	main
see	doc_491521501810_item	2501977	et	3	main
peab	doc_491521501810_item	2501981	et	4	main
kõige	doc_491521501810_item	2501983	et	4	main
raskem	doc_491521501810_item	2501984	et	4	main
peab	doc_491521501810_item	2501991	et	4	main
voodis	doc_491521501810_item	2501992	et	3	main
lamama	doc_491521501810_item	2501993	et	4	main
kirjutab	doc_491521501810_item	2502000	et	3	main
välja	doc_491521501810_item	2502002	et	4	main
7	doc_491521501810_item	2502003	et	2	main
nad	doc_491521501810_item	2502004	et	3	main
saavad	doc_491521501810_item	2502005	et	4	main
hakkama	doc_491521501810_item	2502006	et	3	main
sellega	doc_491521501810_item	2502007	et	3	main
nad	doc_491521501810_item	2502008	et	3	main
saavad	doc_491521501810_item	2502009	et	4	main
sellega	doc_491521501810_item	2502010	et	3	main
hakkama	doc_491521501810_item	2502011	et	3	main
12	doc_491521501810_item	2502012	et	2	main
missugune	doc_491521501810_item	2502013	et	3	main
paksus	doc_491521501810_item	2502014	et	4	main
sõna	doc_491521501810_item	2502016	et	4	main
kirjas	doc_491521501810_item	2502015	et	4	main
sobib	doc_491521501810_item	2502017	et	3	main
lausesse	doc_491521501810_item	2502018	et	4	main
kriipsutage	doc_491521501810_item	2502019	et	3	main
sobimatud	doc_491521501810_item	2502020	et	4	main
maha	doc_491521501810_item	2502022	et	4	main
lagunenud	doc_491521501810_item	2502027	et	4	main
päris	doc_491521501810_item	2502036	et	4	main
pilku	doc_491521501810_item	2502041	et	4	main
püüate	doc_491521501810_item	2502042	et	3	main
vahend	doc_491521501810_item	2502059	et	3	main
sellega	doc_491521501810_item	2502065	et	3	main
vaiba	doc_491521501810_item	2502067	et	3	main
kindlasti	doc_491521501810_item	2502068	et	3	main
puhtaks	doc_491521501810_item	2502069	et	3	main
e	doc_491521501810_item	2502070	et	4	main
inimesed	doc_491521501810_item	2502071	et	3	main
kardan	doc_491521501810_item	2502083	et	4	main
on	doc_491521501810_item	2502087	et	4	main
liigitada	doc_491521501810_item	2502089	et	3	main
aastaga	doc_491521501810_item	2502097	et	3	main
muutunud	doc_491521501810_item	2502101	et	4	main
22	doc_491521501810_item	2502102	et	2	main
moodustage	doc_491521501810_item	2502103	et	3	main
r-liitelisi	doc_491521501810_item	2502104	et	4	main
vedama	doc_491521501810_item	2502107	et	3	main
колонка	doc_491521501810_item	2502111	et	2	main
kuvama	doc_491521501810_item	2502114	et	4	main
машина	doc_491521501810_item	2502117	et	2	main
helkur-светоотражатель	doc_491521501810_item	2502119	et	2	main
siduma	doc_491521501810_item	2502124	et	3	main
aegunud	doc_491521501810_item	2502026	et	4	main
saanud	doc_491521501810_item	2502035	et	4	main
te	doc_491521501810_item	2502040	et	4	main
saate	doc_491521501810_item	2502044	et	4	main
keelustatakse	doc_491521501810_item	2502051	et	3	main
kehtestatakse	doc_491521501810_item	2502052	et	3	main
kahjustatakse	doc_491521501810_item	2502053	et	3	main
rangemad	doc_491521501810_item	2502054	et	4	main
trahvid	doc_491521501810_item	2502055	et	4	main
d	doc_491521501810_item	2502056	et	4	main
see	doc_491521501810_item	2502057	et	3	main
peaksid	doc_491521501810_item	2502072	et	4	main
tulemusi	doc_491521501810_item	2502080	et	4	main
seda	doc_491521501810_item	2502085	et	3	main
linna	doc_491521501810_item	2502093	et	4	main
ohtralt	doc_491521501810_item	2502099	et	4	main
nimisõnu	doc_491521501810_item	2502105	et	3	main
tõlkige	doc_491521501810_item	2502106	et	3	main
kõlama	doc_491521501810_item	2502109	et	3	main
kallama	doc_491521501810_item	2502112	et	3	main
röstima	doc_491521501810_item	2502120	et	3	main
тостер	doc_491521501810_item	2502123	et	2	main
или	doc_491521501810_item	2502139	et	2	main
1tõlkige	doc_491521501811_item	2502143	et	3	main
meid	doc_491521501811_item	2502147	et	4	main
pärast	doc_491521501811_item	2502151	et	4	main
teatrietendust	doc_491521501811_item	2502153	et	3	main
veel	doc_491521501811_item	2502192	et	4	main
kõik	doc_491521501811_item	2502193	et	4	main
ootab	doc_491521501811_item	2502195	et	3	main
ka	doc_491521501811_item	2502196	et	3	main
köögis	doc_491521501811_item	2502197	et	3	main
ahjusoe	doc_491521501811_item	2502199	et	4	main
õunakook	doc_491521501811_item	2502200	et	3	main
tõotab	doc_491521501811_item	2502201	et	3	main
tulla	doc_491521501811_item	2502202	et	3	main
нас	doc_491521501811_item	2502208	et	2	main
будущее	doc_491521501811_item	2502213	et	2	main
представления	doc_491521501811_item	2502217	et	2	main
по	doc_491521501811_item	2502223	et	2	main
руль	doc_491521501810_item	2502126	et	2	main
printer	doc_491521501810_item	2502128	et	3	main
pidama	doc_491521501810_item	2502130	et	4	main
устройство	doc_491521501810_item	2502141	et	2	main
ootab	doc_491521501811_item	2502146	et	3	main
saabudes	doc_491521501811_item	2502156	et	3	main
põlema	doc_491521501811_item	2502162	et	4	main
et	doc_491521501811_item	2502163	et	3	main
me	doc_491521501811_item	2502164	et	4	main
kibuvitsapõõsale	doc_491521501811_item	2502165	et	4	main
otsa	doc_491521501811_item	2502166	et	4	main
ei	doc_491521501811_item	2502167	et	4	main
sõidaks	doc_491521501811_item	2502168	et	3	main
garaaži	doc_491521501811_item	2502169	et	2	main
uks	doc_491521501811_item	2502170	et	3	main
avaneb	doc_491521501811_item	2502171	et	3	main
ilma	doc_491521501811_item	2502172	et	4	main
et	doc_491521501811_item	2502173	et	3	main
tuleks	doc_491521501811_item	2502174	et	4	main
õue	doc_491521501811_item	2502175	et	4	main
paduvihma	doc_491521501811_item	2502176	et	4	main
kätte	doc_491521501811_item	2502177	et	4	main
pidur	doc_491521501810_item	2502131	et	3	main
тормоз	doc_491521501810_item	2502132	et	2	main
сканер	doc_491521501810_item	2502135	et	2	main
охлаждающее	doc_491521501810_item	2502140	et	2	main
helge	doc_491521501811_item	2502149	et	4	main
õhtust	doc_491521501811_item	2502152	et	4	main
autoga	doc_491521501811_item	2502154	et	3	main
maja	doc_491521501811_item	2502158	et	4	main
iseenesest	doc_491521501811_item	2502160	et	4	main
tuled	doc_491521501811_item	2502161	et	4	main
tuli	doc_491521501811_item	2502184	et	4	main
mahedalt	doc_491521501811_item	2502185	et	4	main
ole	doc_491521501811_item	2502191	et	4	main
üllatus	doc_491521501811_item	2502194	et	4	main
romantiline	doc_491521501811_item	2502203	et	3	main
kas	doc_491521501811_item	2502205	et	3	main
таки	doc_491521501811_item	2502210	et	2	main
театрального	doc_491521501811_item	2502216	et	2	main
мы	doc_491521501811_item	2502228	et	2	main
шиповник	doc_491521501811_item	2502230	et	2	main
гаража	doc_491521501811_item	2502234	et	2	main
нужно	doc_491521501811_item	2502240	et	2	main
проливной	doc_491521501811_item	2502245	et	2	main
видим	doc_491521501811_item	2502249	et	2	main
разажён	doc_491521501811_item	2502253	et	2	main
всё	doc_491521501811_item	2502258	et	2	main
на	doc_491521501811_item	2502262	et	2	main
пирог	doc_491521501811_item	2502268	et	2	main
venitama	doc_491521501811_item	2502294	et	4	main
aeglustama	doc_491521501811_item	2502296	et	3	main
tekitama	doc_491521501811_item	2502306	et	4	main
paarid	doc_491521501811_item	2502315	et	4	main
a	doc_491521501811_item	2502319	et	4	main
asja	doc_491521501811_item	2502323	et	4	main
b	doc_491521501811_item	2502325	et	4	main
astub	doc_491521501811_item	2502326	et	3	main
külmaks	doc_491521501811_item	2502330	et	4	main
harilik	doc_491521501811_item	2502345	et	3	main
tavaline	doc_491521501811_item	2502349	et	4	main
5-c	doc_491521501811_item	2502359	et	4	main
4	doc_491521501811_item	2502361	et	2	main
tatjana	doc_491521501811_item	2502367	et	4	main
otsustas	doc_491521501811_item	2502378	et	3	main
minna	doc_491521501811_item	2502381	et	3	main
nad	doc_491521501811_item	2502383	et	3	main
juba	doc_491521501811_item	2502418	et	3	main
on	doc_491521501811_item	2502183	et	4	main
see	doc_491521501811_item	2502189	et	3	main
ждёт	doc_491521501811_item	2502207	et	2	main
впереди	doc_491521501811_item	2502211	et	2	main
вечерного	doc_491521501811_item	2502215	et	2	main
машине	doc_491521501811_item	2502220	et	2	main
себе	doc_491521501811_item	2502224	et	2	main
на	doc_491521501811_item	2502229	et	2	main
что	doc_491521501811_item	2502238	et	2	main
улицу	doc_491521501811_item	2502243	et	2	main
приглушенно	doc_491521501811_item	2502252	et	2	main
не	doc_491521501811_item	2502257	et	2	main
и	doc_491521501811_item	2502261	et	2	main
духовки	doc_491521501811_item	2502266	et	2	main
aeglustuma	doc_491521501811_item	2502295	et	3	main
avastama	doc_491521501811_item	2502308	et	3	main
lõdvestab	doc_491521501811_item	2502320	et	3	main
käib	doc_491521501811_item	2502322	et	3	main
5	doc_491521501811_item	2502340	et	2	main
nagu	doc_491521501811_item	2502341	et	3	main
äraaetud	doc_491521501811_item	2502342	et	4	main
summa	doc_491521501811_item	2502347	et	4	main
6	doc_491521501811_item	2502348	et	2	main
3-f	doc_491521501811_item	2502357	et	4	main
6-e	doc_491521501811_item	2502360	et	3	main
sõnajärje	doc_491521501811_item	2502363	et	3	main
köhis	doc_491521501811_item	2502377	et	3	main
tööle	doc_491521501811_item	2502380	et	3	main
9	doc_491521501811_item	2502382	et	2	main
kiiresti	doc_491521501811_item	2502384	et	3	main
olin	doc_491521501811_item	2502429	et	3	main
olin	doc_491521501811_item	2502442	et	3	main
sooja	doc_491521501811_item	2502447	et	4	main
14	doc_491521501811_item	2502451	et	2	main
kasutamine	doc_491521501811_item	2502453	et	4	main
tervis	doc_491521501811_item	2502466	et	3	main
elustiilist	doc_491521501811_item	2502469	et	4	main
veel	doc_491521501811_item	2502470	et	4	main
sõltub	doc_491521501811_item	2502471	et	3	main
tervis	doc_491521501811_item	2502472	et	3	main
meie	doc_491521501811_item	2502473	et	4	main
ootab	doc_491521501812_item	2502479	et	3	main
õhtust	doc_491521501812_item	2502485	et	4	main
ees	doc_491521501812_item	2502492	et	4	main
sõidaks	doc_491521501812_item	2502501	et	3	main
tuli	doc_491521501812_item	2502517	et	4	main
kõik	doc_491521501812_item	2502526	et	4	main
õunakook	doc_491521501812_item	2502533	et	3	main
õhtu	doc_491521501812_item	2502537	et	4	main
в	doc_491521501812_item	2502542	et	2	main
будущее	doc_491521501812_item	2502548	et	2	main
машине	doc_491521501812_item	2502553	et	2	main
представления	doc_491521501812_item	2502557	et	2	main
чтобы	doc_491521501812_item	2502575	et	2	main
машины	doc_491521501812_item	2502579	et	2	main
и	doc_491521501812_item	2502583	et	2	main
тихонько	doc_491521501812_item	2502589	et	2	main
это	doc_491521501812_item	2502593	et	2	main
ждёт	doc_491521501812_item	2502598	et	2	main
ещё	doc_491521501812_item	2502603	et	2	main
яблочный	doc_491521501812_item	2502607	et	2	main
это	doc_491521501812_item	2502609	et	2	main
неправда	doc_491521501812_item	2502614	et	2	main
sihilised	doc_491521501812_item	2502618	et	4	main
tegusõnad	doc_491521501812_item	2502619	et	3	main
включаться	doc_491521501811_item	2502225	et	2	main
наехали	doc_491521501811_item	2502232	et	2	main
так	doc_491521501811_item	2502237	et	2	main
не	doc_491521501811_item	2502239	et	2	main
под	doc_491521501811_item	2502244	et	2	main
камине	doc_491521501811_item	2502248	et	2	main
хотя	doc_491521501811_item	2502254	et	2	main
сюрприз	doc_491521501811_item	2502259	et	2	main
из	doc_491521501811_item	2502265	et	2	main
вечер	doc_491521501811_item	2502271	et	2	main
романтичный	doc_491521501811_item	2502270	et	2	main
22	doc_491521501811_item	2502274	et	2	main
нет	doc_491521501811_item	2502273	et	2	main
täitke	doc_491521501811_item	2502275	et	3	main
разве	doc_491521501811_item	2502272	et	2	main
tabeli	doc_491521501811_item	2502276	et	3	main
teine	doc_491521501811_item	2502277	et	3	main
pool	doc_491521501811_item	2502278	et	4	main
kiirenema	doc_491521501811_item	2502279	et	3	main
kiirendama	doc_491521501811_item	2502280	et	3	main
innustuma	doc_491521501811_item	2502281	et	3	main
innustama	doc_491521501811_item	2502282	et	3	main
arendama	doc_491521501811_item	2502284	et	3	main
kosuma	doc_491521501811_item	2502285	et	3	main
kosutama	doc_491521501811_item	2502286	et	4	main
halvenema	doc_491521501811_item	2502287	et	3	main
halvendama	doc_491521501811_item	2502288	et	3	main
langema	doc_491521501811_item	2502289	et	3	main
langetama	doc_491521501811_item	2502290	et	4	main
rahunema	doc_491521501811_item	2502291	et	3	main
rahustama	doc_491521501811_item	2502292	et	3	main
чтоб	doc_491521501811_item	2502227	et	2	main
не	doc_491521501811_item	2502231	et	2	main
откроется	doc_491521501811_item	2502235	et	2	main
на	doc_491521501811_item	2502242	et	2	main
в	doc_491521501811_item	2502247	et	2	main
диво	doc_491521501811_item	2502250	et	2	main
это	doc_491521501811_item	2502255	et	2	main
ждет	doc_491521501811_item	2502260	et	2	main
пышущий	doc_491521501811_item	2502264	et	2	main
торопиться	doc_491521501811_item	2502269	et	2	main
arenema	doc_491521501811_item	2502283	et	3	main
jahutama	doc_491521501811_item	2502298	et	3	main
toetama	doc_491521501811_item	2502300	et	3	main
meenutama	doc_491521501811_item	2502302	et	4	main
lõõgastama	doc_491521501811_item	2502304	et	3	main
nakatama	doc_491521501811_item	2502310	et	4	main
sünonüümsete	doc_491521501811_item	2502313	et	3	main
meenuma	doc_491521501811_item	2502301	et	3	main
lõõgastuma	doc_491521501811_item	2502303	et	3	main
tekkima	doc_491521501811_item	2502305	et	3	main
avalduma	doc_491521501811_item	2502307	et	3	main
21	doc_491521501811_item	2502311	et	2	main
1	doc_491521501811_item	2502316	et	2	main
tuleb	doc_491521501811_item	2502317	et	3	main
mängu	doc_491521501811_item	2502318	et	4	main
3	doc_491521501811_item	2502328	et	2	main
4	doc_491521501811_item	2502334	et	2	main
e	doc_491521501811_item	2502344	et	4	main
parandage	doc_491521501811_item	2502362	et	3	main
8	doc_491521501811_item	2502365	et	2	main
veel	doc_491521501811_item	2502376	et	4	main
tervis	doc_491521501811_item	2502417	et	3	main
parem	doc_491521501811_item	2502420	et	4	main
tema	doc_491521501811_item	2502421	et	4	main
väike	doc_491521501811_item	2502430	et	4	main
paljudel	doc_491521501811_item	2502454	et	3	main
paljudel	doc_491521501811_item	2502458	et	3	main
keemiatoodete	doc_491521501811_item	2502460	et	3	main
tekitab	doc_491521501811_item	2502462	et	3	main
15	doc_491521501811_item	2502464	et	2	main
eksamitöö	doc_491521501812_item	2502475	et	4	main
1tõlkige	doc_491521501812_item	2502476	et	3	main
viimaks	doc_491521501812_item	2502477	et	4	main
ometi	doc_491521501812_item	2502478	et	3	main
teatrietendust	doc_491521501812_item	2502486	et	3	main
autoga	doc_491521501812_item	2502487	et	3	main
koju	doc_491521501812_item	2502488	et	3	main
saabudes	doc_491521501812_item	2502489	et	3	main
lähevad	doc_491521501812_item	2502490	et	3	main
maja	doc_491521501812_item	2502491	et	4	main
et	doc_491521501812_item	2502496	et	3	main
me	doc_491521501812_item	2502497	et	4	main
garaaži	doc_491521501812_item	2502502	et	2	main
õue	doc_491521501812_item	2502508	et	4	main
astuda	doc_491521501812_item	2502511	et	3	main
imet	doc_491521501812_item	2502515	et	3	main
on	doc_491521501812_item	2502516	et	4	main
kuid	doc_491521501812_item	2502521	et	4	main
tegevusse	doc_491521501811_item	2502327	et	4	main
c	doc_491521501811_item	2502331	et	4	main
täiesti	doc_491521501811_item	2502332	et	3	main
kurnatud	doc_491521501811_item	2502333	et	4	main
maandab	doc_491521501811_item	2502335	et	3	main
pingeid	doc_491521501811_item	2502336	et	3	main
d	doc_491521501811_item	2502337	et	4	main
kuulub	doc_491521501811_item	2502338	et	3	main
kokku	doc_491521501811_item	2502339	et	3	main
ei	doc_491521501811_item	2502352	et	4	main
huvita	doc_491521501811_item	2502353	et	4	main
üldse	doc_491521501811_item	2502354	et	3	main
1-b	doc_491521501811_item	2502355	et	4	main
4-a	doc_491521501811_item	2502358	et	4	main
tatjana	doc_491521501811_item	2502375	et	4	main
ta	doc_491521501811_item	2502379	et	4	main
saavad	doc_491521501811_item	2502385	et	4	main
kõigest	doc_491521501811_item	2502386	et	4	main
nad	doc_491521501811_item	2502388	et	3	main
aru	doc_491521501811_item	2502387	et	4	main
kõigest	doc_491521501811_item	2502389	et	4	main
kiiresti	doc_491521501811_item	2502390	et	3	main
saavad	doc_491521501811_item	2502391	et	4	main
aru	doc_491521501811_item	2502392	et	4	main
10	doc_491521501811_item	2502393	et	2	main
ta	doc_491521501811_item	2502394	et	4	main
tugevasti	doc_491521501811_item	2502395	et	3	main
külmetas	doc_491521501811_item	2502396	et	3	main
ja	doc_491521501811_item	2502397	et	3	main
jäi	doc_491521501811_item	2502398	et	3	main
haigeks	doc_491521501811_item	2502399	et	4	main
11	doc_491521501811_item	2502400	et	2	main
kui	doc_491521501811_item	2502401	et	3	main
sa	doc_491521501811_item	2502402	et	3	main
saad	doc_491521501811_item	2502404	et	4	main
mulle	doc_491521501811_item	2502405	et	4	main
terveks	doc_491521501811_item	2502403	et	4	main
külla	doc_491521501811_item	2502406	et	4	main
tule	doc_491521501811_item	2502407	et	4	main
kui	doc_491521501811_item	2502408	et	3	main
sa	doc_491521501811_item	2502409	et	3	main
terveks	doc_491521501811_item	2502410	et	4	main
saad	doc_491521501811_item	2502411	et	4	main
tule	doc_491521501811_item	2502412	et	4	main
mulle	doc_491521501811_item	2502413	et	4	main
külla	doc_491521501811_item	2502414	et	4	main
12	doc_491521501811_item	2502415	et	2	main
tema	doc_491521501811_item	2502416	et	4	main
2-d	doc_491521501811_item	2502356	et	4	main
vead	doc_491521501811_item	2502364	et	4	main
kuigi	doc_491521501811_item	2502366	et	3	main
veel	doc_491521501811_item	2502368	et	4	main
köhis	doc_491521501811_item	2502369	et	3	main
ta	doc_491521501811_item	2502370	et	4	main
otsustas	doc_491521501811_item	2502371	et	3	main
tööle	doc_491521501811_item	2502372	et	3	main
minna	doc_491521501811_item	2502373	et	3	main
kuigi	doc_491521501811_item	2502374	et	3	main
kui	doc_491521501811_item	2502427	et	3	main
minu	doc_491521501811_item	2502431	et	3	main
sooja	doc_491521501811_item	2502435	et	4	main
väike	doc_491521501811_item	2502441	et	4	main
piimaga	doc_491521501811_item	2502448	et	3	main
meega	doc_491521501811_item	2502450	et	3	main
veel	doc_491521501811_item	2502465	et	4	main
meid	doc_491521501812_item	2502480	et	4	main
kibuvitsapõõsale	doc_491521501812_item	2502498	et	4	main
uks	doc_491521501812_item	2502503	et	3	main
tuleks	doc_491521501812_item	2502507	et	4	main
kätte	doc_491521501812_item	2502510	et	4	main
ka	doc_491521501812_item	2502529	et	3	main
tõotab	doc_491521501812_item	2502534	et	3	main
pole	doc_491521501812_item	2502539	et	3	main
конце	doc_491521501812_item	2502543	et	2	main
по	doc_491521501812_item	2502549	et	2	main
на	doc_491521501812_item	2502552	et	2	main
перед	doc_491521501812_item	2502559	et	2	main
открывается	doc_491521501812_item	2502574	et	2	main
из	doc_491521501812_item	2502578	et	2	main
за	doc_491521501812_item	2502587	et	2	main
но	doc_491521501812_item	2502592	et	2	main
сюрприз	doc_491521501812_item	2502597	et	2	main
дымящийся	doc_491521501812_item	2502602	et	2	main
действительно	doc_491521501812_item	2502611	et	2	main
ли	doc_491521501812_item	2502615	et	2	main
kiirenema	doc_491521501812_item	2502625	et	3	main
kiirendama	doc_491521501812_item	2502626	et	3	main
rahunema	doc_491521501812_item	2502637	et	3	main
jahutama	doc_491521501812_item	2502644	et	3	main
lõõgastama	doc_491521501812_item	2502650	et	3	main
21	doc_491521501812_item	2502658	et	2	main
sünonüümsete	doc_491521501812_item	2502660	et	3	main
juurde	doc_491521501812_item	2502671	et	4	main
3	doc_491521501812_item	2502675	et	2	main
äraaetud	doc_491521501812_item	2502689	et	4	main
suurus	doc_491521501812_item	2502693	et	4	main
6	doc_491521501812_item	2502695	et	2	main
f	doc_491521501812_item	2502698	et	4	main
ei	doc_491521501812_item	2502699	et	4	main
4-d	doc_491521501812_item	2502705	et	4	main
köhis	doc_491521501812_item	2502716	et	3	main
ta	doc_491521501812_item	2502717	et	4	main
veel	doc_491521501812_item	2502723	et	4	main
tööle	doc_491521501812_item	2502727	et	3	main
külmetas	doc_491521501812_item	2502743	et	3	main
tule	doc_491521501812_item	2502760	et	4	main
saad	doc_491521501812_item	2502764	et	4	main
tule	doc_491521501812_item	2502765	et	4	main
tervis	doc_491521501812_item	2502770	et	3	main
juba	doc_491521501812_item	2502771	et	3	main
parem	doc_491521501812_item	2502778	et	4	main
olin	doc_491521501812_item	2502782	et	3	main
sooja	doc_491521501812_item	2502788	et	4	main
meega	doc_491521501812_item	2502791	et	3	main
väike	doc_491521501812_item	2502794	et	4	main
ema	doc_491521501812_item	2502798	et	4	main
sooja	doc_491521501812_item	2502800	et	4	main
tekitab	doc_491521501812_item	2502813	et	3	main
1tõlkige	doc_491521501813_item	2502829	et	3	main
viimaks	doc_491521501813_item	2502830	et	4	main
ometi	doc_491521501813_item	2502831	et	3	main
ootab	doc_491521501813_item	2502832	et	3	main
pärast	doc_491521501813_item	2502837	et	4	main
põlema	doc_491521501813_item	2502848	et	4	main
kaminas	doc_491521501813_item	2502866	et	3	main
see	doc_491521501813_item	2502875	et	3	main
ole	doc_491521501813_item	2502877	et	4	main
ahjusoe	doc_491521501813_item	2502885	et	4	main
romantiline	doc_491521501813_item	2502889	et	3	main
on	doc_491521501811_item	2502419	et	4	main
ma	doc_491521501811_item	2502428	et	3	main
ema	doc_491521501811_item	2502432	et	4	main
ravis	doc_491521501811_item	2502433	et	4	main
mind	doc_491521501811_item	2502446	et	4	main
keemiatoodete	doc_491521501811_item	2502452	et	3	main
kasutamine	doc_491521501811_item	2502461	et	4	main
sõltub	doc_491521501811_item	2502467	et	3	main
meie	doc_491521501811_item	2502468	et	4	main
elustiilist	doc_491521501811_item	2502474	et	4	main
helge	doc_491521501812_item	2502482	et	4	main
pärast	doc_491521501812_item	2502484	et	4	main
põlema	doc_491521501812_item	2502495	et	4	main
otsa	doc_491521501812_item	2502499	et	4	main
avaneb	doc_491521501812_item	2502504	et	3	main
et	doc_491521501812_item	2502506	et	3	main
mahedalt	doc_491521501812_item	2502518	et	4	main
põlema	doc_491521501812_item	2502519	et	4	main
üllatus	doc_491521501812_item	2502527	et	4	main
köögis	doc_491521501812_item	2502530	et	3	main
hõrgutav	doc_491521501812_item	2502531	et	4	main
romantiline	doc_491521501812_item	2502536	et	3	main
вечер	doc_491521501812_item	2502541	et	2	main
ждёт	doc_491521501812_item	2502546	et	2	main
после	doc_491521501812_item	2502554	et	2	main
театрального	doc_491521501812_item	2502556	et	2	main
домом	doc_491521501812_item	2502560	et	2	main
гаража	doc_491521501812_item	2502573	et	2	main
выходить	doc_491521501812_item	2502577	et	2	main
дождь	doc_491521501812_item	2502582	et	2	main
что	doc_491521501812_item	2502586	et	2	main
огонь	doc_491521501812_item	2502591	et	2	main
все	doc_491521501812_item	2502596	et	2	main
кухне	doc_491521501812_item	2502601	et	2	main
печи	doc_491521501812_item	2502606	et	2	main
пирог	doc_491521501812_item	2502608	et	2	main
вечер	doc_491521501812_item	2502613	et	2	main
ja	doc_491521501812_item	2502617	et	3	main
22	doc_491521501812_item	2502620	et	2	main
teine	doc_491521501812_item	2502623	et	3	main
innustuma	doc_491521501812_item	2502627	et	3	main
arenema	doc_491521501812_item	2502629	et	3	main
kosuma	doc_491521501812_item	2502631	et	3	main
halvendama	doc_491521501812_item	2502634	et	3	main
aeglustuma	doc_491521501812_item	2502641	et	3	main
toetuma	doc_491521501812_item	2502645	et	4	main
meenuma	doc_491521501812_item	2502647	et	3	main
tekkima	doc_491521501812_item	2502651	et	3	main
tekitama	doc_491521501812_item	2502652	et	4	main
avalduma	doc_491521501812_item	2502653	et	3	main
avaldama	doc_491521501812_item	2502654	et	3	main
nakkama	doc_491521501812_item	2502655	et	3	main
2	doc_491521501812_item	2502668	et	2	main
käib	doc_491521501812_item	2502669	et	3	main
asja	doc_491521501812_item	2502670	et	4	main
tegevusse	doc_491521501812_item	2502674	et	4	main
c	doc_491521501812_item	2502678	et	4	main
hobune	doc_491521501812_item	2502690	et	4	main
summa	doc_491521501812_item	2502694	et	4	main
taks	doc_491521501812_item	2502697	et	3	main
1-b	doc_491521501812_item	2502702	et	4	main
3-f	doc_491521501812_item	2502704	et	4	main
5-c	doc_491521501812_item	2502706	et	4	main
4	doc_491521501812_item	2502708	et	2	main
parandage	doc_491521501812_item	2502709	et	3	main
tatjana	doc_491521501812_item	2502722	et	4	main
ta	doc_491521501812_item	2502726	et	4	main
9	doc_491521501812_item	2502729	et	2	main
saavad	doc_491521501812_item	2502732	et	4	main
ja	doc_491521501812_item	2502744	et	3	main
saad	doc_491521501812_item	2502757	et	4	main
mulle	doc_491521501812_item	2502758	et	4	main
on	doc_491521501812_item	2502776	et	4	main
juba	doc_491521501812_item	2502777	et	3	main
minu	doc_491521501812_item	2502784	et	3	main
ravis	doc_491521501812_item	2502786	et	4	main
kui	doc_491521501812_item	2502792	et	3	main
minu	doc_491521501812_item	2502797	et	3	main
piima	doc_491521501812_item	2502801	et	4	main
paljudel	doc_491521501812_item	2502807	et	3	main
tekitab	doc_491521501812_item	2502809	et	3	main
tervis	doc_491521501811_item	2502422	et	3	main
on	doc_491521501811_item	2502423	et	4	main
parem	doc_491521501811_item	2502424	et	4	main
juba	doc_491521501811_item	2502425	et	3	main
13	doc_491521501811_item	2502426	et	2	main
mind	doc_491521501811_item	2502434	et	4	main
piima	doc_491521501811_item	2502436	et	4	main
ja	doc_491521501811_item	2502437	et	3	main
meega	doc_491521501811_item	2502438	et	3	main
kui	doc_491521501811_item	2502439	et	3	main
ma	doc_491521501811_item	2502440	et	3	main
ravis	doc_491521501811_item	2502443	et	4	main
minu	doc_491521501811_item	2502444	et	3	main
ema	doc_491521501811_item	2502445	et	4	main
ja	doc_491521501811_item	2502449	et	3	main
inimestel	doc_491521501811_item	2502455	et	3	main
tekitab	doc_491521501811_item	2502456	et	3	main
allergiat	doc_491521501811_item	2502457	et	3	main
inimestel	doc_491521501811_item	2502459	et	3	main
allergiat	doc_491521501811_item	2502463	et	3	main
ees	doc_491521501812_item	2502481	et	4	main
tulevik	doc_491521501812_item	2502483	et	3	main
iseenesest	doc_491521501812_item	2502493	et	4	main
tuled	doc_491521501812_item	2502494	et	4	main
ei	doc_491521501812_item	2502500	et	4	main
ilma	doc_491521501812_item	2502505	et	4	main
paduvihma	doc_491521501812_item	2502509	et	4	main
ja	doc_491521501812_item	2502512	et	3	main
kaminas	doc_491521501812_item	2502513	et	3	main
näe	doc_491521501812_item	2502514	et	4	main
süüdatud	doc_491521501812_item	2502520	et	4	main
ei	doc_491521501812_item	2502523	et	4	main
ootab	doc_491521501812_item	2502528	et	3	main
tulla	doc_491521501812_item	2502535	et	3	main
романтический	doc_491521501812_item	2502540	et	2	main
всегда	doc_491521501812_item	2502545	et	2	main
приезде	doc_491521501812_item	2502550	et	2	main
вечернего	doc_491521501812_item	2502555	et	2	main
куст	doc_491521501812_item	2502571	et	2	main
под	doc_491521501812_item	2502580	et	2	main
камине	doc_491521501812_item	2502585	et	2	main
горит	doc_491521501812_item	2502590	et	2	main
не	doc_491521501812_item	2502595	et	2	main
и	doc_491521501812_item	2502599	et	2	main
хранящий	doc_491521501812_item	2502604	et	2	main
романтический	doc_491521501812_item	2502612	et	2	main
sihitud	doc_491521501812_item	2502616	et	4	main
pool	doc_491521501812_item	2502624	et	4	main
kosutama	doc_491521501812_item	2502632	et	4	main
rahustama	doc_491521501812_item	2502638	et	3	main
venitama	doc_491521501812_item	2502640	et	4	main
nakkatama	doc_491521501812_item	2502656	et	4	main
1	doc_491521501812_item	2502663	et	2	main
mängu	doc_491521501812_item	2502665	et	4	main
a	doc_491521501812_item	2502666	et	4	main
lõdvestab	doc_491521501812_item	2502667	et	3	main
jätab	doc_491521501812_item	2502676	et	3	main
d	doc_491521501812_item	2502684	et	4	main
kuulub	doc_491521501812_item	2502685	et	3	main
kokku	doc_491521501812_item	2502686	et	3	main
5	doc_491521501812_item	2502687	et	2	main
harilik	doc_491521501812_item	2502692	et	3	main
üldse	doc_491521501812_item	2502701	et	3	main
tatjana	doc_491521501812_item	2502714	et	4	main
see	doc_491521501812_item	2502522	et	3	main
ole	doc_491521501812_item	2502524	et	4	main
veel	doc_491521501812_item	2502525	et	4	main
ahjusoe	doc_491521501812_item	2502532	et	4	main
kas	doc_491521501812_item	2502538	et	3	main
нас	doc_491521501812_item	2502544	et	2	main
светлое	doc_491521501812_item	2502547	et	2	main
домой	doc_491521501812_item	2502551	et	2	main
спектакля	doc_491521501812_item	2502558	et	2	main
автоматически	doc_491521501812_item	2502561	et	2	main
зажигаются	doc_491521501812_item	2502562	et	2	main
огни	doc_491521501812_item	2502563	et	2	main
не	doc_491521501812_item	2502566	et	2	main
мы	doc_491521501812_item	2502565	et	2	main
въехали	doc_491521501812_item	2502567	et	2	main
чтобы	doc_491521501812_item	2502564	et	2	main
прямо	doc_491521501812_item	2502568	et	2	main
в	doc_491521501812_item	2502569	et	2	main
шиповниковый	doc_491521501812_item	2502570	et	2	main
дверь	doc_491521501812_item	2502572	et	2	main
не	doc_491521501812_item	2502576	et	2	main
проливной	doc_491521501812_item	2502581	et	2	main
в	doc_491521501812_item	2502584	et	2	main
чудо	doc_491521501812_item	2502588	et	2	main
ещё	doc_491521501812_item	2502594	et	2	main
в	doc_491521501812_item	2502600	et	2	main
тепло	doc_491521501812_item	2502605	et	2	main
будет	doc_491521501812_item	2502610	et	2	main
täitke	doc_491521501812_item	2502621	et	3	main
innustama	doc_491521501812_item	2502628	et	3	main
halvenema	doc_491521501812_item	2502633	et	3	main
langema	doc_491521501812_item	2502635	et	3	main
venima	doc_491521501812_item	2502639	et	3	main
jahtuma	doc_491521501812_item	2502643	et	3	main
toetama	doc_491521501812_item	2502646	et	3	main
meenutama	doc_491521501812_item	2502648	et	4	main
lõõgastuma	doc_491521501812_item	2502649	et	3	main
leidke	doc_491521501812_item	2502659	et	3	main
paarid	doc_491521501812_item	2502662	et	4	main
tuleb	doc_491521501812_item	2502664	et	3	main
astub	doc_491521501812_item	2502673	et	3	main
külmaks	doc_491521501812_item	2502677	et	4	main
täiesti	doc_491521501812_item	2502679	et	3	main
kurnatud	doc_491521501812_item	2502680	et	4	main
4	doc_491521501812_item	2502681	et	2	main
maandab	doc_491521501812_item	2502682	et	3	main
pingeid	doc_491521501812_item	2502683	et	3	main
e	doc_491521501812_item	2502691	et	4	main
tavaline	doc_491521501812_item	2502696	et	4	main
2-a	doc_491521501812_item	2502703	et	4	main
6-e	doc_491521501812_item	2502707	et	3	main
sõnajärje	doc_491521501812_item	2502710	et	3	main
vead	doc_491521501812_item	2502711	et	4	main
8	doc_491521501812_item	2502712	et	2	main
kuigi	doc_491521501812_item	2502713	et	3	main
kuigi	doc_491521501812_item	2502721	et	3	main
saavad	doc_491521501812_item	2502736	et	4	main
kiiresti	doc_491521501812_item	2502737	et	3	main
tugevasti	doc_491521501812_item	2502742	et	3	main
haigeks	doc_491521501812_item	2502746	et	4	main
ja	doc_491521501812_item	2502750	et	3	main
kui	doc_491521501812_item	2502761	et	3	main
ma	doc_491521501812_item	2502781	et	3	main
ravis	doc_491521501812_item	2502796	et	4	main
ja	doc_491521501812_item	2502802	et	3	main
keemiatoodete	doc_491521501812_item	2502805	et	3	main
paljudel	doc_491521501812_item	2502814	et	3	main
allergiat	doc_491521501812_item	2502816	et	3	main
tabeli	doc_491521501812_item	2502622	et	3	main
arendama	doc_491521501812_item	2502630	et	3	main
langetama	doc_491521501812_item	2502636	et	4	main
aeglustama	doc_491521501812_item	2502642	et	3	main
väljendid	doc_491521501812_item	2502657	et	3	main
väljendite	doc_491521501812_item	2502661	et	3	main
b	doc_491521501812_item	2502672	et	4	main
nagu	doc_491521501812_item	2502688	et	3	main
huvita	doc_491521501812_item	2502700	et	4	main
veel	doc_491521501812_item	2502715	et	4	main
otsustas	doc_491521501812_item	2502718	et	3	main
tööle	doc_491521501812_item	2502719	et	3	main
minna	doc_491521501812_item	2502720	et	3	main
köhis	doc_491521501812_item	2502724	et	3	main
nad	doc_491521501812_item	2502730	et	3	main
kõigest	doc_491521501812_item	2502738	et	4	main
aru	doc_491521501812_item	2502739	et	4	main
10	doc_491521501812_item	2502740	et	2	main
jäi	doc_491521501812_item	2502751	et	3	main
külla	doc_491521501812_item	2502759	et	4	main
terveks	doc_491521501812_item	2502763	et	4	main
mulle	doc_491521501812_item	2502766	et	4	main
tema	doc_491521501812_item	2502774	et	4	main
tervis	doc_491521501812_item	2502775	et	3	main
kui	doc_491521501812_item	2502780	et	3	main
väike	doc_491521501812_item	2502783	et	4	main
piima	doc_491521501812_item	2502789	et	4	main
ja	doc_491521501812_item	2502790	et	3	main
ma	doc_491521501812_item	2502793	et	3	main
olin	doc_491521501812_item	2502795	et	3	main
mind	doc_491521501812_item	2502799	et	4	main
14	doc_491521501812_item	2502804	et	2	main
keemiatoodete	doc_491521501812_item	2502811	et	3	main
15	doc_491521501812_item	2502817	et	2	main
tervis	doc_491521501812_item	2502819	et	3	main
elustiilist	doc_491521501812_item	2502827	et	4	main
eksamitöö	doc_491521501813_item	2502828	et	4	main
tulevik	doc_491521501813_item	2502836	et	3	main
autoga	doc_491521501813_item	2502840	et	3	main
avaneb	doc_491521501813_item	2502857	et	3	main
et	doc_491521501813_item	2502859	et	3	main
paduvihma	doc_491521501813_item	2502862	et	4	main
mahedalt	doc_491521501813_item	2502871	et	4	main
kuid	doc_491521501813_item	2502874	et	4	main
hõrgutav	doc_491521501813_item	2502884	et	4	main
представления	doc_491521501813_item	2502901	et	2	main
домой	doc_491521501813_item	2502905	et	2	main
не	doc_491521501813_item	2502911	et	2	main
смородины	doc_491521501813_item	2502915	et	2	main
не	doc_491521501813_item	2502920	et	2	main
под	doc_491521501813_item	2502923	et	2	main
чудо	doc_491521501813_item	2502930	et	2	main
но	doc_491521501813_item	2502933	et	2	main
также	doc_491521501813_item	2502939	et	2	main
тёплый	doc_491521501813_item	2502944	et	2	main
вечер	doc_491521501813_item	2502949	et	2	main
pool	doc_491521501813_item	2502957	et	4	main
arenema	doc_491521501813_item	2502962	et	3	main
kosuma	doc_491521501813_item	2502964	et	3	main
langema	doc_491521501813_item	2502968	et	3	main
venima	doc_491521501813_item	2502972	et	3	main
juurde	doc_491521501813_item	2503003	et	4	main
3	doc_491521501813_item	2503007	et	2	main
kokku	doc_491521501813_item	2503018	et	3	main
nagu	doc_491521501813_item	2503020	et	3	main
1-b	doc_491521501813_item	2503034	et	4	main
tatjana	doc_491521501813_item	2503046	et	4	main
köhis	doc_491521501813_item	2503048	et	3	main
otsustas	doc_491521501813_item	2503050	et	3	main
kuigi	doc_491521501813_item	2503053	et	3	main
veel	doc_491521501813_item	2503056	et	4	main
ta	doc_491521501813_item	2503057	et	4	main
otsustas	doc_491521501813_item	2503058	et	3	main
tööle	doc_491521501813_item	2503059	et	3	main
minna	doc_491521501813_item	2503060	et	3	main
9	doc_491521501813_item	2503061	et	2	main
kõigest	doc_491521501813_item	2503065	et	4	main
nad	doc_491521501813_item	2503067	et	3	main
otsustas	doc_491521501812_item	2502725	et	3	main
minna	doc_491521501812_item	2502728	et	3	main
kiiresti	doc_491521501812_item	2502731	et	3	main
kõigest	doc_491521501812_item	2502733	et	4	main
aru	doc_491521501812_item	2502734	et	4	main
nad	doc_491521501812_item	2502735	et	3	main
ta	doc_491521501812_item	2502741	et	4	main
jäi	doc_491521501812_item	2502745	et	3	main
ta	doc_491521501812_item	2502747	et	4	main
tugevasti	doc_491521501812_item	2502748	et	3	main
külmetas	doc_491521501812_item	2502749	et	3	main
haigeks	doc_491521501812_item	2502752	et	4	main
11	doc_491521501812_item	2502753	et	2	main
kui	doc_491521501812_item	2502754	et	3	main
sa	doc_491521501812_item	2502755	et	3	main
terveks	doc_491521501812_item	2502756	et	4	main
sa	doc_491521501812_item	2502762	et	3	main
külla	doc_491521501812_item	2502767	et	4	main
12	doc_491521501812_item	2502768	et	2	main
tema	doc_491521501812_item	2502769	et	4	main
on	doc_491521501812_item	2502772	et	4	main
parem	doc_491521501812_item	2502773	et	4	main
13	doc_491521501812_item	2502779	et	2	main
ema	doc_491521501812_item	2502785	et	4	main
mind	doc_491521501812_item	2502787	et	4	main
meega	doc_491521501812_item	2502803	et	3	main
kasutamine	doc_491521501812_item	2502806	et	4	main
inimestel	doc_491521501812_item	2502808	et	3	main
allergiat	doc_491521501812_item	2502810	et	3	main
helge	doc_491521501813_item	2502835	et	4	main
saabudes	doc_491521501813_item	2502842	et	3	main
maja	doc_491521501813_item	2502844	et	4	main
iseenesest	doc_491521501813_item	2502846	et	4	main
tuled	doc_491521501813_item	2502847	et	4	main
kätte	doc_491521501813_item	2502863	et	4	main
imet	doc_491521501813_item	2502868	et	3	main
süüdatud	doc_491521501813_item	2502873	et	4	main
õunakook	doc_491521501813_item	2502886	et	3	main
kas	doc_491521501813_item	2502891	et	3	main
pole	doc_491521501813_item	2502892	et	3	main
светлое	doc_491521501813_item	2502897	et	2	main
в	doc_491521501813_item	2502902	et	2	main
включается	doc_491521501813_item	2502907	et	2	main
мы	doc_491521501813_item	2502910	et	2	main
гаража	doc_491521501813_item	2502917	et	2	main
дождь	doc_491521501813_item	2502925	et	2	main
камине	doc_491521501813_item	2502928	et	2	main
всё	doc_491521501813_item	2502937	et	2	main
ждёт	doc_491521501813_item	2502940	et	2	main
яблочный	doc_491521501813_item	2502945	et	2	main
не	doc_491521501813_item	2502950	et	2	main
täitke	doc_491521501813_item	2502954	et	3	main
kiirendama	doc_491521501813_item	2502959	et	3	main
innustama	doc_491521501813_item	2502961	et	3	main
arendama	doc_491521501813_item	2502963	et	3	main
halvenema	doc_491521501813_item	2502966	et	3	main
rahustama	doc_491521501813_item	2502971	et	3	main
lõdvestab	doc_491521501813_item	2502999	et	3	main
2	doc_491521501813_item	2503000	et	2	main
käib	doc_491521501813_item	2503001	et	3	main
asja	doc_491521501813_item	2503002	et	4	main
tegevusse	doc_491521501813_item	2503006	et	4	main
c	doc_491521501813_item	2503010	et	4	main
täiesti	doc_491521501813_item	2503011	et	3	main
4	doc_491521501813_item	2503013	et	2	main
maandab	doc_491521501813_item	2503014	et	3	main
pingeid	doc_491521501813_item	2503015	et	3	main
summa	doc_491521501813_item	2503026	et	4	main
2-d	doc_491521501813_item	2503035	et	4	main
3-f	doc_491521501813_item	2503036	et	4	main
kuigi	doc_491521501813_item	2503045	et	3	main
nad	doc_491521501813_item	2503062	et	3	main
saavad	doc_491521501813_item	2503068	et	4	main
kiiresti	doc_491521501813_item	2503069	et	3	main
tema	doc_491521501813_item	2503101	et	4	main
juba	doc_491521501813_item	2503103	et	3	main
on	doc_491521501813_item	2503104	et	4	main
on	doc_491521501813_item	2503108	et	4	main
parem	doc_491521501813_item	2503110	et	4	main
olin	doc_491521501813_item	2503114	et	3	main
väike	doc_491521501813_item	2503115	et	4	main
minu	doc_491521501813_item	2503116	et	3	main
piima	doc_491521501813_item	2503121	et	4	main
mind	doc_491521501813_item	2503131	et	4	main
meega	doc_491521501813_item	2503135	et	3	main
kasutamine	doc_491521501813_item	2503138	et	4	main
allergiat	doc_491521501813_item	2503142	et	3	main
inimestel	doc_491521501813_item	2503147	et	3	main
15	doc_491521501813_item	2503149	et	2	main
tervis	doc_491521501813_item	2503151	et	3	main
meie	doc_491521501813_item	2503158	et	4	main
elustiilist	doc_491521501813_item	2503159	et	4	main
kasutamine	doc_491521501812_item	2502812	et	4	main
inimestel	doc_491521501812_item	2502815	et	3	main
veel	doc_491521501812_item	2502818	et	4	main
sõltub	doc_491521501812_item	2502820	et	3	main
meie	doc_491521501812_item	2502821	et	4	main
veel	doc_491521501812_item	2502823	et	4	main
sõltub	doc_491521501812_item	2502824	et	3	main
tervis	doc_491521501812_item	2502825	et	3	main
meid	doc_491521501813_item	2502833	et	4	main
ees	doc_491521501813_item	2502834	et	4	main
teatrietendust	doc_491521501813_item	2502839	et	3	main
me	doc_491521501813_item	2502850	et	4	main
otsa	doc_491521501813_item	2502852	et	4	main
astuda	doc_491521501813_item	2502864	et	3	main
ja	doc_491521501813_item	2502865	et	3	main
põlema	doc_491521501813_item	2502872	et	4	main
ei	doc_491521501813_item	2502876	et	4	main
veel	doc_491521501813_item	2502878	et	4	main
kõik	doc_491521501813_item	2502879	et	4	main
tõotab	doc_491521501813_item	2502887	et	3	main
tulla	doc_491521501813_item	2502888	et	3	main
õhtu	doc_491521501813_item	2502890	et	4	main
ждёт	doc_491521501813_item	2502895	et	2	main
вечернего	doc_491521501813_item	2502900	et	2	main
приезжая	doc_491521501813_item	2502904	et	2	main
наехали	doc_491521501813_item	2502912	et	2	main
дверь	doc_491521501813_item	2502916	et	2	main
elustiilist	doc_491521501812_item	2502822	et	4	main
meie	doc_491521501812_item	2502826	et	4	main
õhtust	doc_491521501813_item	2502838	et	4	main
koju	doc_491521501813_item	2502841	et	3	main
lähevad	doc_491521501813_item	2502843	et	3	main
ees	doc_491521501813_item	2502845	et	4	main
et	doc_491521501813_item	2502849	et	3	main
kibuvitsapõõsale	doc_491521501813_item	2502851	et	4	main
ei	doc_491521501813_item	2502853	et	4	main
sõidaks	doc_491521501813_item	2502854	et	3	main
garaaži	doc_491521501813_item	2502855	et	2	main
uks	doc_491521501813_item	2502856	et	3	main
ilma	doc_491521501813_item	2502858	et	4	main
tuleks	doc_491521501813_item	2502860	et	4	main
õue	doc_491521501813_item	2502861	et	4	main
näe	doc_491521501813_item	2502867	et	4	main
on	doc_491521501813_item	2502869	et	4	main
tuli	doc_491521501813_item	2502870	et	4	main
üllatus	doc_491521501813_item	2502880	et	4	main
ootab	doc_491521501813_item	2502881	et	3	main
ka	doc_491521501813_item	2502882	et	3	main
köögis	doc_491521501813_item	2502883	et	3	main
наконец-то	doc_491521501813_item	2502893	et	2	main
будущее	doc_491521501813_item	2502898	et	2	main
театре	doc_491521501813_item	2502903	et	2	main
свет	doc_491521501813_item	2502908	et	2	main
на	doc_491521501813_item	2502913	et	2	main
и	doc_491521501813_item	2502919	et	2	main
нужно	doc_491521501813_item	2502921	et	2	main
и	doc_491521501813_item	2502926	et	2	main
раззожён	doc_491521501813_item	2502931	et	2	main
не	doc_491521501813_item	2502936	et	2	main
кухне	doc_491521501813_item	2502942	et	2	main
романтический	doc_491521501813_item	2502948	et	2	main
22	doc_491521501813_item	2502953	et	2	main
tabeli	doc_491521501813_item	2502955	et	3	main
kiirenema	doc_491521501813_item	2502958	et	3	main
innustuma	doc_491521501813_item	2502960	et	3	main
kosutama	doc_491521501813_item	2502965	et	4	main
halvendama	doc_491521501813_item	2502967	et	3	main
b	doc_491521501813_item	2503004	et	4	main
5	doc_491521501813_item	2503019	et	2	main
нас	doc_491521501813_item	2502894	et	2	main
впереди	doc_491521501813_item	2502896	et	2	main
после	doc_491521501813_item	2502899	et	2	main
автоматически	doc_491521501813_item	2502906	et	2	main
чтобы	doc_491521501813_item	2502909	et	2	main
кусты	doc_491521501813_item	2502914	et	2	main
открывается	doc_491521501813_item	2502918	et	2	main
выходить	doc_491521501813_item	2502922	et	2	main
в	doc_491521501813_item	2502927	et	2	main
огонь	doc_491521501813_item	2502932	et	2	main
это	doc_491521501813_item	2502934	et	2	main
сюрприз	doc_491521501813_item	2502938	et	2	main
вкусный	doc_491521501813_item	2502943	et	2	main
намечается	doc_491521501813_item	2502947	et	2	main
ли	doc_491521501813_item	2502952	et	2	main
rahunema	doc_491521501813_item	2502970	et	3	main
jätab	doc_491521501813_item	2503008	et	3	main
külmaks	doc_491521501813_item	2503009	et	4	main
kurnatud	doc_491521501813_item	2503012	et	4	main
d	doc_491521501813_item	2503016	et	4	main
kuulub	doc_491521501813_item	2503017	et	3	main
suurus	doc_491521501813_item	2503025	et	4	main
taks	doc_491521501813_item	2503029	et	3	main
huvita	doc_491521501813_item	2503032	et	4	main
üldse	doc_491521501813_item	2503033	et	3	main
köhis	doc_491521501813_item	2503055	et	3	main
saavad	doc_491521501813_item	2503064	et	4	main
parem	doc_491521501813_item	2503105	et	4	main
juba	doc_491521501813_item	2503109	et	3	main
ema	doc_491521501813_item	2503117	et	4	main
ma	doc_491521501813_item	2503125	et	3	main
sooja	doc_491521501813_item	2503132	et	4	main
14	doc_491521501813_item	2503136	et	2	main
inimestel	doc_491521501813_item	2503140	et	3	main
keemiatoodete	doc_491521501813_item	2503144	et	3	main
allergiat	doc_491521501813_item	2503148	et	3	main
veel	doc_491521501813_item	2503150	et	4	main
проливной	doc_491521501813_item	2502924	et	2	main
какое	doc_491521501813_item	2502929	et	2	main
ещё	doc_491521501813_item	2502935	et	2	main
в	doc_491521501813_item	2502941	et	2	main
пирог	doc_491521501813_item	2502946	et	2	main
так	doc_491521501813_item	2502951	et	2	main
teine	doc_491521501813_item	2502956	et	3	main
langetama	doc_491521501813_item	2502969	et	4	main
venitama	doc_491521501813_item	2502973	et	4	main
aeglustuma	doc_491521501813_item	2502974	et	3	main
aeglustama	doc_491521501813_item	2502975	et	3	main
jahtuma	doc_491521501813_item	2502976	et	3	main
jahutama	doc_491521501813_item	2502977	et	3	main
toetuma	doc_491521501813_item	2502978	et	4	main
toetama	doc_491521501813_item	2502979	et	3	main
meenuma	doc_491521501813_item	2502980	et	3	main
meenutama	doc_491521501813_item	2502981	et	4	main
lõõgastuma	doc_491521501813_item	2502982	et	3	main
lõõgastama	doc_491521501813_item	2502983	et	3	main
tekkima	doc_491521501813_item	2502984	et	3	main
tekitama	doc_491521501813_item	2502985	et	4	main
avalduma	doc_491521501813_item	2502986	et	3	main
avaldama	doc_491521501813_item	2502987	et	3	main
nakkama	doc_491521501813_item	2502988	et	3	main
nakkatama	doc_491521501813_item	2502989	et	4	main
21	doc_491521501813_item	2502990	et	2	main
leidke	doc_491521501813_item	2502991	et	3	main
sünonüümsete	doc_491521501813_item	2502992	et	3	main
väljendite	doc_491521501813_item	2502993	et	3	main
paarid	doc_491521501813_item	2502994	et	4	main
1	doc_491521501813_item	2502995	et	2	main
tuleb	doc_491521501813_item	2502996	et	3	main
mängu	doc_491521501813_item	2502997	et	4	main
a	doc_491521501813_item	2502998	et	4	main
astub	doc_491521501813_item	2503005	et	3	main
äraaetud	doc_491521501813_item	2503021	et	4	main
e	doc_491521501813_item	2503023	et	4	main
harilik	doc_491521501813_item	2503024	et	3	main
tavaline	doc_491521501813_item	2503028	et	4	main
f	doc_491521501813_item	2503030	et	4	main
ei	doc_491521501813_item	2503031	et	4	main
4-a	doc_491521501813_item	2503037	et	4	main
5-c	doc_491521501813_item	2503038	et	4	main
6-e	doc_491521501813_item	2503039	et	3	main
4	doc_491521501813_item	2503040	et	2	main
parandage	doc_491521501813_item	2503041	et	3	main
sõnajärje	doc_491521501813_item	2503042	et	3	main
vead	doc_491521501813_item	2503043	et	4	main
veel	doc_491521501813_item	2503047	et	4	main
ta	doc_491521501813_item	2503049	et	4	main
minna	doc_491521501813_item	2503052	et	3	main
kiiresti	doc_491521501813_item	2503063	et	3	main
aru	doc_491521501813_item	2503066	et	4	main
ravis	doc_491521501813_item	2503118	et	4	main
kui	doc_491521501813_item	2503124	et	3	main
väike	doc_491521501813_item	2503127	et	4	main
ja	doc_491521501813_item	2503134	et	3	main
sõltub	doc_491521501813_item	2503152	et	3	main
elustiilist	doc_491521501813_item	2503154	et	4	main
veel	doc_491521501813_item	2503155	et	4	main
sõltub	doc_491521501813_item	2503156	et	3	main
tervis	doc_491521501813_item	2503157	et	3	main
hobune	doc_491521501813_item	2503022	et	4	main
6	doc_491521501813_item	2503027	et	2	main
8	doc_491521501813_item	2503044	et	2	main
tööle	doc_491521501813_item	2503051	et	3	main
tatjana	doc_491521501813_item	2503054	et	4	main
aru	doc_491521501813_item	2503071	et	4	main
10	doc_491521501813_item	2503072	et	2	main
ta	doc_491521501813_item	2503073	et	4	main
tugevasti	doc_491521501813_item	2503074	et	3	main
külmetas	doc_491521501813_item	2503075	et	3	main
ja	doc_491521501813_item	2503076	et	3	main
jäi	doc_491521501813_item	2503077	et	3	main
haigeks	doc_491521501813_item	2503078	et	4	main
ta	doc_491521501813_item	2503079	et	4	main
külmetas	doc_491521501813_item	2503080	et	3	main
tugevasti	doc_491521501813_item	2503081	et	3	main
ja	doc_491521501813_item	2503082	et	3	main
jäi	doc_491521501813_item	2503083	et	3	main
11	doc_491521501813_item	2503085	et	2	main
haigeks	doc_491521501813_item	2503084	et	4	main
kui	doc_491521501813_item	2503086	et	3	main
sa	doc_491521501813_item	2503087	et	3	main
terveks	doc_491521501813_item	2503088	et	4	main
mulle	doc_491521501813_item	2503090	et	4	main
saad	doc_491521501813_item	2503089	et	4	main
külla	doc_491521501813_item	2503091	et	4	main
tule	doc_491521501813_item	2503092	et	4	main
kui	doc_491521501813_item	2503093	et	3	main
sa	doc_491521501813_item	2503094	et	3	main
saad	doc_491521501813_item	2503095	et	4	main
terveks	doc_491521501813_item	2503096	et	4	main
tule	doc_491521501813_item	2503097	et	4	main
mulle	doc_491521501813_item	2503098	et	4	main
külla	doc_491521501813_item	2503099	et	4	main
12	doc_491521501813_item	2503100	et	2	main
kõigest	doc_491521501813_item	2503070	et	4	main
tervis	doc_491521501813_item	2503107	et	3	main
mind	doc_491521501813_item	2503119	et	4	main
ja	doc_491521501813_item	2503122	et	3	main
piima	doc_491521501813_item	2503133	et	4	main
keemiatoodete	doc_491521501813_item	2503137	et	3	main
tekitab	doc_491521501813_item	2503141	et	3	main
tekitab	doc_491521501813_item	2503143	et	3	main
kes	doc_491521501815_item	2503520	et	4	main
varsti	doc_491521501815_item	2503526	et	3	main
meid	doc_491521501815_item	2503528	et	4	main
see	doc_491521501815_item	2503537	et	3	main
korraldab	doc_491521501815_item	2503538	et	3	main
ja	doc_491521501815_item	2503545	et	3	main
muru	doc_491521501815_item	2503546	et	4	main
ette	doc_491521501815_item	2503558	et	4	main
однако	doc_491521501815_item	2503559	et	2	main
кого	doc_491521501815_item	2503560	et	2	main
благодарить	doc_491521501815_item	2503561	et	2	main
за	doc_491521501815_item	2503562	et	2	main
нет	doc_491521501815_item	2503565	et	2	main
или	doc_491521501815_item	2503570	et	2	main
посткомпьютерного	doc_491521501815_item	2503589	et	2	main
жизнь	doc_491521501815_item	2503594	et	2	main
все	doc_491521501815_item	2503601	et	2	main
кофе	doc_491521501815_item	2503608	et	2	main
еды	doc_491521501815_item	2503614	et	2	main
о	doc_491521501815_item	2503619	et	2	main
по-желанию	doc_491521501815_item	2503624	et	2	main
põhjendage	doc_491521501815_item	2503631	et	3	main
arsti	doc_491521501815_item	2503638	et	4	main
minu	doc_491521501815_item	2503640	et	3	main
tütar	doc_491521501815_item	2503641	et	3	main
arsti	doc_491521501815_item	2503644	et	4	main
tervis	doc_491521501813_item	2503102	et	3	main
tema	doc_491521501813_item	2503106	et	4	main
13	doc_491521501813_item	2503111	et	2	main
kui	doc_491521501813_item	2503112	et	3	main
ma	doc_491521501813_item	2503113	et	3	main
sooja	doc_491521501813_item	2503120	et	4	main
meega	doc_491521501813_item	2503123	et	3	main
olin	doc_491521501813_item	2503126	et	3	main
ravis	doc_491521501813_item	2503128	et	4	main
minu	doc_491521501813_item	2503129	et	3	main
ema	doc_491521501813_item	2503130	et	4	main
paljudel	doc_491521501813_item	2503139	et	3	main
kasutamine	doc_491521501813_item	2503145	et	4	main
paljudel	doc_491521501813_item	2503146	et	3	main
meie	doc_491521501813_item	2503153	et	4	main
arhitektidele	doc_491521501815_item	2503519	et	3	main
on	doc_491521501815_item	2503521	et	4	main
inimkonda	doc_491521501815_item	2503523	et	4	main
ootab	doc_491521501815_item	2503527	et	3	main
kodus	doc_491521501815_item	2503531	et	4	main
asju	doc_491521501815_item	2503534	et	3	main
arvutivõrk	doc_491521501815_item	2503536	et	3	main
hommikukohvi	doc_491521501815_item	2503539	et	4	main
keetmise	doc_491521501815_item	2503540	et	4	main
teie	doc_491521501815_item	2503549	et	4	main
ajalehti	doc_491521501815_item	2503557	et	4	main
что	doc_491521501815_item	2503568	et	2	main
нового	doc_491521501815_item	2503588	et	2	main
нас	doc_491521501815_item	2503593	et	2	main
компьютер	doc_491521501815_item	2503598	et	2	main
он	doc_491521501815_item	2503603	et	2	main
утреннего	doc_491521501815_item	2503607	et	2	main
заказе	doc_491521501815_item	2503613	et	2	main
заботится	doc_491521501815_item	2503618	et	2	main
даже	doc_491521501815_item	2503623	et	2	main
газеты	doc_491521501815_item	2503627	et	2	main
sõnajärjevead	doc_491521501815_item	2503630	et	3	main
parandust	doc_491521501815_item	2503632	et	4	main
ta	doc_491521501815_item	2503647	et	4	main
juba	doc_491521501815_item	2503651	et	3	main
juba	doc_491521501815_item	2503654	et	3	main
see	doc_491521501815_item	2503669	et	3	main
arst	doc_491521501815_item	2503715	et	3	main
välja	doc_491521501815_item	2503718	et	4	main
nad	doc_491521501815_item	2503720	et	3	main
nad	doc_491521501815_item	2503724	et	3	main
sobiv	doc_491521501815_item	2503731	et	4	main
sõna	doc_491521501815_item	2503732	et	4	main
saavas	doc_491521501815_item	2503733	et	4	main
käändes	doc_491521501815_item	2503734	et	3	main
a	doc_491521501815_item	2503735	et	4	main
õpilased	doc_491521501815_item	2503736	et	3	main
tahtsid	doc_491521501815_item	2503741	et	4	main
minna	doc_491521501815_item	2503742	et	3	main
kontserdile	doc_491521501815_item	2503743	et	3	main
eelistasid	doc_491521501815_item	2503747	et	4	main
muutub	doc_491521501815_item	2503752	et	3	main
halvemaks	doc_491521501815_item	2503755	et	4	main
tore	doc_491521501815_item	2503765	et	3	main
et	doc_491521501815_item	2503767	et	3	main
toredaks	doc_491521501815_item	2503773	et	3	main
kõige	doc_491521501815_item	2503780	et	4	main
riided	doc_491521501815_item	2503784	et	3	main
ei	doc_491521501815_item	2503790	et	4	main
osale	doc_491521501815_item	2503791	et	4	main
võistlustel	doc_491521501815_item	2503792	et	3	main
sest	doc_491521501815_item	2503793	et	4	main
eksamitöö	doc_491521501815_item	2503492	et	4	main
tõlkige	doc_491521501815_item	2503494	et	3	main
1	doc_491521501815_item	2503493	et	2	main
kuid	doc_491521501815_item	2503495	et	4	main
keda	doc_491521501815_item	2503496	et	4	main
nende	doc_491521501815_item	2503497	et	4	main
ettevalmistuste	doc_491521501815_item	2503498	et	4	main
eest	doc_491521501815_item	2503499	et	4	main
tänada	doc_491521501815_item	2503500	et	3	main
ei	doc_491521501815_item	2503501	et	4	main
ärge	doc_491521501815_item	2503502	et	3	main
arvake	doc_491521501815_item	2503503	et	3	main
et	doc_491521501815_item	2503504	et	3	main
teenijannat	doc_491521501815_item	2503505	et	4	main
või	doc_491521501815_item	2503506	et	4	main
virka	doc_491521501815_item	2503507	et	4	main
ämma	doc_491521501815_item	2503508	et	4	main
saatke	doc_491521501815_item	2503509	et	3	main
tänuavaldused	doc_491521501815_item	2503510	et	3	main
bill	doc_491521501815_item	2503511	et	3	main
gatesile	doc_491521501815_item	2503512	et	4	main
andrew	doc_491521501815_item	2503513	et	4	main
grove	doc_491521501815_item	2503514	et	4	main
ile	doc_491521501815_item	2503515	et	4	main
ja	doc_491521501815_item	2503516	et	3	main
teistele	doc_491521501815_item	2503517	et	4	main
kübermaailma	doc_491521501815_item	2503518	et	4	main
uude	doc_491521501815_item	2503524	et	3	main
maja	doc_491521501815_item	2503541	et	4	main
kastmise	doc_491521501815_item	2503547	et	4	main
eest	doc_491521501815_item	2503551	et	4	main
soovi	doc_491521501815_item	2503554	et	4	main
их	doc_491521501815_item	2503563	et	2	main
думайте	doc_491521501815_item	2503567	et	2	main
скоро	doc_491521501815_item	2503591	et	2	main
когда	doc_491521501815_item	2503595	et	2	main
будет	doc_491521501815_item	2503599	et	2	main
заботится	doc_491521501815_item	2503604	et	2	main
об	doc_491521501815_item	2503609	et	2	main
о	doc_491521501815_item	2503612	et	2	main
газона	doc_491521501815_item	2503617	et	2	main
postkompuutriajastusse	doc_491521501815_item	2503525	et	4	main
kus	doc_491521501815_item	2503530	et	3	main
ajab	doc_491521501815_item	2503532	et	3	main
enamiku	doc_491521501815_item	2503533	et	3	main
joonde	doc_491521501815_item	2503535	et	4	main
hoolitseb	doc_491521501815_item	2503548	et	3	main
tervise	doc_491521501815_item	2503550	et	3	main
ning	doc_491521501815_item	2503552	et	3	main
loeb	doc_491521501815_item	2503553	et	3	main
korral	doc_491521501815_item	2503555	et	4	main
isegi	doc_491521501815_item	2503556	et	4	main
не	doc_491521501815_item	2503566	et	2	main
прилежную	doc_491521501815_item	2503571	et	2	main
тещу	doc_491521501815_item	2503572	et	2	main
пошлите	doc_491521501815_item	2503573	et	2	main
письмо	doc_491521501815_item	2503574	et	2	main
благодарности	doc_491521501815_item	2503575	et	2	main
биллу	doc_491521501815_item	2503576	et	2	main
гейтсу	doc_491521501815_item	2503577	et	2	main
эндрю	doc_491521501815_item	2503578	et	2	main
груву	doc_491521501815_item	2503579	et	2	main
и	doc_491521501815_item	2503580	et	2	main
другим	doc_491521501815_item	2503581	et	2	main
архитекторам	doc_491521501815_item	2503582	et	2	main
кибер-мира	doc_491521501815_item	2503583	et	2	main
кто	doc_491521501815_item	2503584	et	2	main
у	doc_491521501815_item	2503586	et	2	main
стоит	doc_491521501815_item	2503585	et	2	main
juhtimas	doc_491521501815_item	2503522	et	4	main
elu	doc_491521501815_item	2503529	et	4	main
kütmise	doc_491521501815_item	2503542	et	4	main
toidu	doc_491521501815_item	2503543	et	3	main
tellimise	doc_491521501815_item	2503544	et	4	main
подготовку	doc_491521501815_item	2503564	et	2	main
обслуживающего	doc_491521501815_item	2503569	et	2	main
руля	doc_491521501815_item	2503587	et	2	main
ждет	doc_491521501815_item	2503592	et	2	main
доме	doc_491521501815_item	2503597	et	2	main
вещи	doc_491521501815_item	2503602	et	2	main
приготовлении	doc_491521501815_item	2503606	et	2	main
дома	doc_491521501815_item	2503611	et	2	main
поливке	doc_491521501815_item	2503616	et	2	main
здоровье	doc_491521501815_item	2503621	et	2	main
17	doc_491521501815_item	2503628	et	2	main
minu	doc_491521501815_item	2503634	et	3	main
läheb	doc_491521501815_item	2503637	et	3	main
homme	doc_491521501815_item	2503643	et	3	main
ta	doc_491521501815_item	2503652	et	4	main
terveks	doc_491521501815_item	2503655	et	4	main
3	doc_491521501815_item	2503657	et	2	main
millal	doc_491521501815_item	2503658	et	3	main
haigeks	doc_491521501815_item	2503659	et	4	main
jäi	doc_491521501815_item	2503660	et	3	main
sinu	doc_491521501815_item	2503661	et	3	main
tütar	doc_491521501815_item	2503662	et	3	main
millal	doc_491521501815_item	2503663	et	3	main
jäi	doc_491521501815_item	2503664	et	3	main
sinu	doc_491521501815_item	2503665	et	3	main
haigus	doc_491521501815_item	2503670	et	4	main
arst	doc_491521501815_item	2503673	et	3	main
välja	doc_491521501815_item	2503712	et	4	main
kirjutab	doc_491521501815_item	2503713	et	3	main
retsepti	doc_491521501815_item	2503717	et	4	main
hakkama	doc_491521501815_item	2503727	et	3	main
kirjutage	doc_491521501815_item	2503729	et	3	main
jagunesid	doc_491521501815_item	2503737	et	4	main
kes	doc_491521501815_item	2503746	et	4	main
kooli	doc_491521501815_item	2503749	et	4	main
kogu	doc_491521501815_item	2503753	et	4	main
tervist	doc_491521501815_item	2503760	et	4	main
c	doc_491521501815_item	2503761	et	4	main
temaga	doc_491521501815_item	2503768	et	3	main
muutud	doc_491521501815_item	2503770	et	4	main
ise	doc_491521501815_item	2503772	et	4	main
prestiižimaks	doc_491521501815_item	2503781	et	2	main
ta	doc_491521501815_item	2503789	et	4	main
на	doc_491521501815_item	2503824	et	2	main
elektritööd	doc_491521501815_item	2503828	et	4	main
spetsialistile	doc_491521501815_item	2503829	et	3	main
мира	doc_491521501815_item	2503590	et	2	main
в	doc_491521501815_item	2503596	et	2	main
организовывать	doc_491521501815_item	2503600	et	2	main
о	doc_491521501815_item	2503605	et	2	main
отоплении	doc_491521501815_item	2503610	et	2	main
и	doc_491521501815_item	2503615	et	2	main
вашем	doc_491521501815_item	2503620	et	2	main
и	doc_491521501815_item	2503622	et	2	main
вам	doc_491521501815_item	2503626	et	2	main
1	doc_491521501815_item	2503633	et	2	main
homme	doc_491521501815_item	2503636	et	3	main
juurde	doc_491521501815_item	2503639	et	4	main
läheb	doc_491521501815_item	2503642	et	3	main
terveks	doc_491521501815_item	2503649	et	4	main
tütar	doc_491521501815_item	2503666	et	3	main
haigeks	doc_491521501815_item	2503667	et	4	main
nakkav	doc_491521501815_item	2503672	et	4	main
tuleb	doc_491521501815_item	2503674	et	3	main
teie	doc_491521501815_item	2503675	et	4	main
juurde	doc_491521501815_item	2503676	et	4	main
koju	doc_491521501815_item	2503677	et	3	main
retsepti	doc_491521501815_item	2503714	et	4	main
hakkama	doc_491521501815_item	2503722	et	3	main
saavad	doc_491521501815_item	2503725	et	4	main
ja	doc_491521501815_item	2503744	et	3	main
b	doc_491521501815_item	2503750	et	4	main
kahjustab	doc_491521501815_item	2503758	et	3	main
nii	doc_491521501815_item	2503764	et	3	main
e	doc_491521501815_item	2503782	et	4	main
работы	doc_491521501815_item	2503821	et	2	main
специалиста	doc_491521501815_item	2503825	et	2	main
читает	doc_491521501815_item	2503625	et	2	main
parandage	doc_491521501815_item	2503629	et	3	main
tütar	doc_491521501815_item	2503635	et	3	main
on	doc_491521501815_item	2503648	et	4	main
saanud	doc_491521501815_item	2503656	et	4	main
on	doc_491521501815_item	2503671	et	4	main
see	doc_491521501815_item	2503678	et	3	main
haigus	doc_491521501815_item	2503679	et	4	main
on	doc_491521501815_item	2503680	et	4	main
nakkav	doc_491521501815_item	2503681	et	4	main
arst	doc_491521501815_item	2503682	et	3	main
tuleb	doc_491521501815_item	2503683	et	3	main
teie	doc_491521501815_item	2503684	et	4	main
koju	doc_491521501815_item	2503685	et	3	main
juurde	doc_491521501815_item	2503686	et	4	main
5	doc_491521501815_item	2503687	et	2	main
kõige	doc_491521501815_item	2503688	et	4	main
raskem	doc_491521501815_item	2503689	et	4	main
tema	doc_491521501815_item	2503690	et	4	main
jaoks	doc_491521501815_item	2503691	et	4	main
on	doc_491521501815_item	2503692	et	4	main
see	doc_491521501815_item	2503693	et	3	main
et	doc_491521501815_item	2503694	et	3	main
ta	doc_491521501815_item	2503695	et	4	main
voodis	doc_491521501815_item	2503696	et	3	main
peab	doc_491521501815_item	2503697	et	4	main
lamama	doc_491521501815_item	2503698	et	4	main
kõige	doc_491521501815_item	2503699	et	4	main
raskem	doc_491521501815_item	2503700	et	4	main
on	doc_491521501815_item	2503701	et	4	main
tema	doc_491521501815_item	2503702	et	4	main
jaoks	doc_491521501815_item	2503703	et	4	main
see	doc_491521501815_item	2503704	et	3	main
et	doc_491521501815_item	2503705	et	3	main
ta	doc_491521501815_item	2503706	et	4	main
peab	doc_491521501815_item	2503707	et	4	main
voodis	doc_491521501815_item	2503708	et	3	main
lamama	doc_491521501815_item	2503709	et	4	main
6	doc_491521501815_item	2503710	et	2	main
arst	doc_491521501815_item	2503711	et	3	main
juurde	doc_491521501815_item	2503645	et	4	main
2	doc_491521501815_item	2503646	et	2	main
saanud	doc_491521501815_item	2503650	et	4	main
on	doc_491521501815_item	2503653	et	4	main
4	doc_491521501815_item	2503668	et	2	main
kirjutab	doc_491521501815_item	2503716	et	3	main
7	doc_491521501815_item	2503719	et	2	main
saavad	doc_491521501815_item	2503721	et	4	main
sellega	doc_491521501815_item	2503726	et	3	main
lünkadesse	doc_491521501815_item	2503730	et	3	main
kaheks	doc_491521501815_item	2503738	et	4	main
nendeks	doc_491521501815_item	2503739	et	4	main
nendeks	doc_491521501815_item	2503745	et	4	main
elu	doc_491521501815_item	2503751	et	4	main
ta	doc_491521501815_item	2503762	et	4	main
linnas	doc_491521501815_item	2503779	et	4	main
f	doc_491521501815_item	2503788	et	4	main
kardab	doc_491521501815_item	2503794	et	4	main
jälle	doc_491521501815_item	2503795	et	3	main
viimaseks	doc_491521501815_item	2503796	et	3	main
по	doc_491521501815_item	2503822	et	2	main
jätke	doc_491521501815_item	2503826	et	4	main
sellega	doc_491521501815_item	2503723	et	3	main
4	doc_491521501815_item	2503728	et	2	main
kes	doc_491521501815_item	2503740	et	4	main
jääda	doc_491521501815_item	2503748	et	4	main
aeg	doc_491521501815_item	2503754	et	3	main
ja	doc_491521501815_item	2503756	et	3	main
see	doc_491521501815_item	2503757	et	3	main
inimeste	doc_491521501815_item	2503759	et	3	main
on	doc_491521501815_item	2503763	et	4	main
inimene	doc_491521501815_item	2503766	et	3	main
suheldes	doc_491521501815_item	2503769	et	3	main
ka	doc_491521501815_item	2503771	et	3	main
d	doc_491521501815_item	2503774	et	4	main
seda	doc_491521501815_item	2503775	et	3	main
haiglat	doc_491521501815_item	2503776	et	3	main
peetakse	doc_491521501815_item	2503777	et	3	main
meie	doc_491521501815_item	2503778	et	4	main
need	doc_491521501815_item	2503783	et	3	main
ei	doc_491521501815_item	2503785	et	4	main
sobi	doc_491521501815_item	2503786	et	4	main
kooliks	doc_491521501815_item	2503787	et	4	main
jääda	doc_491521501815_item	2503797	et	4	main
tõlkige	doc_491521501815_item	2503798	et	3	main
d	doc_491521501815_item	2503799	et	4	main
не	doc_491521501815_item	2503800	et	2	main
пользуйтесь	doc_491521501815_item	2503801	et	2	main
мобильным	doc_491521501815_item	2503802	et	2	main
телефоном	doc_491521501815_item	2503803	et	2	main
на	doc_491521501815_item	2503804	et	2	main
заправке	doc_491521501815_item	2503805	et	2	main
ärge	doc_491521501815_item	2503806	et	3	main
kasutage	doc_491521501815_item	2503807	et	3	main
mobiiltelefooni	doc_491521501815_item	2503808	et	4	main
tanklas	doc_491521501815_item	2503809	et	3	main
e	doc_491521501815_item	2503810	et	4	main
расход	doc_491521501815_item	2503811	et	2	main
электричества	doc_491521501815_item	2503812	et	2	main
измеряет	doc_491521501815_item	2503813	et	2	main
электросчетчик	doc_491521501815_item	2503814	et	2	main
elektrikulu	doc_491521501815_item	2503815	et	4	main
mõõdetakse	doc_491521501815_item	2503816	et	3	main
elektrimõõtjaga	doc_491521501815_item	2503817	et	3	main
f	doc_491521501815_item	2503818	et	4	main
оставьте	doc_491521501815_item	2503819	et	2	main
большие	doc_491521501815_item	2503820	et	2	main
электричеству	doc_491521501815_item	2503823	et	2	main
suured	doc_491521501815_item	2503827	et	3	main
viimaks	doc_491521501818_item	2504497	et	4	main
täitumas	doc_491521501818_item	2504498	et	4	main
mis	doc_491521501818_item	2504510	et	4	main
töötab	doc_491521501818_item	2504511	et	3	main
suulise	doc_491521501818_item	2504512	et	4	main
käskluse	doc_491521501818_item	2504513	et	3	main
näitab	doc_491521501818_item	2504517	et	3	main
taga	doc_491521501818_item	2504522	et	4	main
eksamitöö	doc_491521501818_item	2504491	et	4	main
need	doc_491521501818_item	2504495	et	3	main
tänu	doc_491521501818_item	2504500	et	4	main
mikroprotsessoreile	doc_491521501818_item	2504501	et	3	main
ja	doc_491521501818_item	2504502	et	3	main
digitaaltehnoloogiale	doc_491521501818_item	2504503	et	3	main
võite	doc_491521501818_item	2504504	et	4	main
juba	doc_491521501818_item	2504505	et	3	main
praegu	doc_491521501818_item	2504506	et	3	main
paigutada	doc_491521501818_item	2504507	et	3	main
koju	doc_491521501818_item	2504508	et	3	main
valgustuse	doc_491521501818_item	2504509	et	4	main
kes	doc_491521501818_item	2504518	et	4	main
tõmmata	doc_491521501818_item	2504523	et	4	main
abil	doc_491521501818_item	2504530	et	4	main
sisse	doc_491521501818_item	2504533	et	4	main
rääkimata	doc_491521501818_item	2504536	et	4	main
koduse	doc_491521501818_item	2504537	et	4	main
arvutivõrgu	doc_491521501818_item	2504538	et	3	main
и	doc_491521501818_item	2504550	et	2	main
технологии	doc_491521501818_item	2504552	et	2	main
можете	doc_491521501818_item	2504556	et	2	main
освещение	doc_491521501818_item	2504559	et	2	main
приказам	doc_491521501818_item	2504564	et	2	main
звонит	doc_491521501818_item	2504571	et	2	main
дверь	doc_491521501818_item	2504575	et	2	main
температуру	doc_491521501818_item	2504582	et	2	main
ещё	doc_491521501818_item	2504590	et	2	main
основании	doc_491521501818_item	2504598	et	2	main
enesekohast	doc_491521501818_item	2504605	et	4	main
tegevust	doc_491521501818_item	2504606	et	4	main
lünka	doc_491521501818_item	2504615	et	4	main
jahtuma	doc_491521501818_item	2504621	et	3	main
tee	doc_491521501818_item	2504633	et	4	main
venima	doc_491521501818_item	2504640	et	3	main
tuleb	doc_491521501818_item	2504645	et	3	main
mõnikord	doc_491521501818_item	2504647	et	3	main
lendab	doc_491521501818_item	2504648	et	3	main
kord	doc_491521501818_item	2504653	et	4	main
äraminekuga	doc_491521501818_item	2504659	et	3	main
kui	doc_491521501818_item	2504662	et	3	main
c	doc_491521501818_item	2504669	et	4	main
kes	doc_491521501818_item	2504676	et	4	main
toetab	doc_491521501818_item	2504677	et	3	main
ma	doc_491521501818_item	2504682	et	3	main
see	doc_491521501818_item	2504723	et	3	main
talle	doc_491521501818_item	2504726	et	4	main
kergelt	doc_491521501818_item	2504727	et	4	main
3	doc_491521501818_item	2504728	et	2	main
kirub	doc_491521501818_item	2504729	et	3	main
ennast	doc_491521501818_item	2504730	et	4	main
luubi	doc_491521501818_item	2504737	et	3	main
all	doc_491521501818_item	2504738	et	3	main
d	doc_491521501818_item	2504739	et	4	main
mind	doc_491521501818_item	2504746	et	4	main
inimesed	doc_491521501818_item	2504753	et	3	main
väga	doc_491521501818_item	2504769	et	3	main
23	doc_491521501818_item	2504777	et	2	main
näpitstangid	doc_491521501818_item	2504791	et	3	main
akulaadija	doc_491521501818_item	2504796	et	4	main
ketassaag	doc_491521501818_item	2504805	et	3	main
nüüd	doc_491521501818_item	2504493	et	4	main
mis	doc_491521501818_item	2504516	et	4	main
toatemperatuuri	doc_491521501818_item	2504528	et	4	main
ehitamisest	doc_491521501818_item	2504539	et	4	main
эти	doc_491521501818_item	2504541	et	2	main
могут	doc_491521501818_item	2504543	et	2	main
первую	doc_491521501818_item	2504546	et	2	main
дигитальной	doc_491521501818_item	2504551	et	2	main
разместить	doc_491521501818_item	2504557	et	2	main
подчиняясь	doc_491521501818_item	2504562	et	2	main
кто	doc_491521501818_item	2504570	et	2	main
в	doc_491521501818_item	2504574	et	2	main
можете	doc_491521501818_item	2504576	et	2	main
регулировать	doc_491521501818_item	2504581	et	2	main
нажатием	doc_491521501818_item	2504586	et	2	main
не	doc_491521501818_item	2504594	et	2	main
построении	doc_491521501818_item	2504599	et	2	main
kas	doc_491521501818_item	2504604	et	3	main
väljendav	doc_491521501818_item	2504612	et	4	main
jahutama	doc_491521501818_item	2504622	et	3	main
kõrvetad	doc_491521501818_item	2504636	et	3	main
venitama	doc_491521501818_item	2504641	et	4	main
väga	doc_491521501818_item	2504650	et	3	main
teine	doc_491521501818_item	2504652	et	3	main
kaua	doc_491521501818_item	2504661	et	3	main
oskasin	doc_491521501818_item	2504663	et	3	main
lahkuma	doc_491521501818_item	2504668	et	3	main
ta	doc_491521501818_item	2504672	et	4	main
raskel	doc_491521501818_item	2504680	et	3	main
luust	doc_491521501818_item	2504718	et	4	main
inimesed	doc_491521501818_item	2504721	et	3	main
tulnud	doc_491521501818_item	2504725	et	4	main
on	doc_491521501818_item	2504736	et	4	main
mulle	doc_491521501818_item	2504750	et	4	main
peale	doc_491521501818_item	2504768	et	4	main
2-e	doc_491521501818_item	2504772	et	3	main
5-d	doc_491521501818_item	2504775	et	4	main
sõnad	doc_491521501818_item	2504779	et	4	main
lood	doc_491521501818_item	2504802	et	4	main
prits	doc_491521501818_item	2504803	et	3	main
jootekolb	doc_491521501818_item	2504807	et	4	main
näpitstangid	doc_491521501818_item	2504809	et	3	main
pump	doc_491521501818_item	2504820	et	3	main
muruniiduk	doc_491521501818_item	2504824	et	3	main
täitumas	doc_491521501819_item	2504835	et	4	main
eeskätt	doc_491521501819_item	2504836	et	3	main
tänu	doc_491521501819_item	2504837	et	4	main
mikroprotsessoreile	doc_491521501819_item	2504838	et	3	main
ja	doc_491521501819_item	2504839	et	3	main
koju	doc_491521501819_item	2504845	et	3	main
mis	doc_491521501819_item	2504847	et	4	main
ja	doc_491521501819_item	2504863	et	3	main
наконец-то	doc_491521501819_item	2504877	et	2	main
сбылись	doc_491521501819_item	2504880	et	2	main
вы	doc_491521501819_item	2504886	et	2	main
разместить	doc_491521501819_item	2504891	et	2	main
от	doc_491521501819_item	2504896	et	2	main
голосом	doc_491521501819_item	2504900	et	2	main
звонит	doc_491521501819_item	2504906	et	2	main
дверь	doc_491521501819_item	2504909	et	2	main
комнате	doc_491521501819_item	2504917	et	2	main
домой	doc_491521501819_item	2504925	et	2	main
себя	doc_491521501819_item	2504933	et	2	main
sobiv	doc_491521501819_item	2504948	et	4	main
a	doc_491521501819_item	2504952	et	4	main
ära	doc_491521501819_item	2504963	et	4	main
keele	doc_491521501819_item	2504969	et	4	main
ta	doc_491521501819_item	2505004	et	4	main
toetub	doc_491521501819_item	2505009	et	3	main
raskel	doc_491521501819_item	2505012	et	3	main
ma	doc_491521501819_item	2505014	et	3	main
et	doc_491521501819_item	2505016	et	3	main
1tõlkige	doc_491521501818_item	2504492	et	3	main
on	doc_491521501818_item	2504494	et	4	main
eeskätt	doc_491521501818_item	2504499	et	3	main
peale	doc_491521501818_item	2504514	et	4	main
helistab	doc_491521501818_item	2504519	et	3	main
nuppude	doc_491521501818_item	2504529	et	3	main
теперь	doc_491521501818_item	2504540	et	2	main
мечты	doc_491521501818_item	2504542	et	2	main
исполниться	doc_491521501818_item	2504544	et	2	main
очередь	doc_491521501818_item	2504547	et	2	main
уже	doc_491521501818_item	2504554	et	2	main
которое	doc_491521501818_item	2504560	et	2	main
охранную	doc_491521501818_item	2504565	et	2	main
которая	doc_491521501818_item	2504568	et	2	main
к	doc_491521501818_item	2504572	et	2	main
сдвигать	doc_491521501818_item	2504577	et	2	main
и	doc_491521501818_item	2504580	et	2	main
лишь	doc_491521501818_item	2504585	et	2	main
кондиционер	doc_491521501818_item	2504589	et	2	main
дороге	doc_491521501818_item	2504592	et	2	main
говоря	doc_491521501818_item	2504595	et	2	main
домашней	doc_491521501818_item	2504600	et	2	main
сети	doc_491521501818_item	2504602	et	2	main
väljendav	doc_491521501818_item	2504607	et	4	main
või	doc_491521501818_item	2504608	et	4	main
väljapoole	doc_491521501818_item	2504609	et	3	main
suunatud	doc_491521501818_item	2504610	et	4	main
sobiv	doc_491521501818_item	2504616	et	4	main
oota	doc_491521501818_item	2504623	et	4	main
jahtub	doc_491521501818_item	2504627	et	3	main
muidu	doc_491521501818_item	2504628	et	3	main
kõrvetad	doc_491521501818_item	2504629	et	3	main
keele	doc_491521501818_item	2504630	et	4	main
muidu	doc_491521501818_item	2504635	et	3	main
keele	doc_491521501818_item	2504637	et	4	main
ära	doc_491521501818_item	2504638	et	4	main
millest	doc_491521501818_item	2504642	et	3	main
küll	doc_491521501818_item	2504644	et	4	main
et	doc_491521501818_item	2504646	et	3	main
aeg	doc_491521501818_item	2504649	et	3	main
kiiresti	doc_491521501818_item	2504651	et	3	main
aga	doc_491521501818_item	2504654	et	3	main
nii	doc_491521501818_item	2504660	et	3	main
lõpuks	doc_491521501818_item	2504665	et	4	main
siiski	doc_491521501818_item	2504667	et	4	main
mind	doc_491521501818_item	2504678	et	4	main
tean	doc_491521501818_item	2504683	et	3	main
unistused	doc_491521501818_item	2504496	et	4	main
valvekaamera	doc_491521501818_item	2504515	et	4	main
teie	doc_491521501818_item	2504520	et	4	main
koduteel	doc_491521501818_item	2504535	et	3	main
благодаря	doc_491521501818_item	2504548	et	2	main
вы	doc_491521501818_item	2504553	et	2	main
работает	doc_491521501818_item	2504561	et	2	main
дежурную	doc_491521501818_item	2504566	et	2	main
показывает	doc_491521501818_item	2504569	et	2	main
отодвигать	doc_491521501818_item	2504578	et	2	main
в	doc_491521501818_item	2504583	et	2	main
кнопки	doc_491521501818_item	2504587	et	2	main
по	doc_491521501818_item	2504591	et	2	main
об	doc_491521501818_item	2504597	et	2	main
5	doc_491521501818_item	2504603	et	2	main
tegusõna	doc_491521501818_item	2504613	et	4	main
kirjutage	doc_491521501818_item	2504614	et	3	main
a	doc_491521501818_item	2504620	et	4	main
ukse	doc_491521501818_item	2504521	et	3	main
kardinad	doc_491521501818_item	2504524	et	4	main
ette	doc_491521501818_item	2504525	et	4	main
ja	doc_491521501818_item	2504526	et	3	main
reguleerida	doc_491521501818_item	2504527	et	3	main
lülitada	doc_491521501818_item	2504531	et	3	main
õhukonditsioneeri	doc_491521501818_item	2504532	et	4	main
juba	doc_491521501818_item	2504534	et	3	main
в	doc_491521501818_item	2504545	et	2	main
микропроцессорам	doc_491521501818_item	2504549	et	2	main
теперь	doc_491521501818_item	2504555	et	2	main
дома	doc_491521501818_item	2504558	et	2	main
устным	doc_491521501818_item	2504563	et	2	main
камеру	doc_491521501818_item	2504567	et	2	main
вам	doc_491521501818_item	2504573	et	2	main
шторы	doc_491521501818_item	2504579	et	2	main
комнате	doc_491521501818_item	2504584	et	2	main
включать	doc_491521501818_item	2504588	et	2	main
домой	doc_491521501818_item	2504593	et	2	main
уже	doc_491521501818_item	2504596	et	2	main
компьютерной	doc_491521501818_item	2504601	et	2	main
tegevust	doc_491521501818_item	2504611	et	4	main
sõna	doc_491521501818_item	2504617	et	4	main
õiges	doc_491521501818_item	2504618	et	3	main
vormis	doc_491521501818_item	2504619	et	4	main
tee	doc_491521501818_item	2504625	et	4	main
ära	doc_491521501818_item	2504631	et	4	main
jahuta	doc_491521501818_item	2504632	et	4	main
b	doc_491521501818_item	2504639	et	4	main
venitab	doc_491521501818_item	2504655	et	3	main
ma	doc_491521501818_item	2504657	et	3	main
toetama	doc_491521501818_item	2504671	et	3	main
igal	doc_491521501818_item	2504679	et	3	main
erilist	doc_491521501818_item	2504715	et	4	main
lihast	doc_491521501818_item	2504720	et	4	main
b	doc_491521501818_item	2504722	et	4	main
mulle	doc_491521501818_item	2504742	et	4	main
ülekohut	doc_491521501818_item	2504743	et	3	main
kiusab	doc_491521501818_item	2504745	et	3	main
5	doc_491521501818_item	2504747	et	2	main
ta	doc_491521501818_item	2504748	et	4	main
teeb	doc_491521501818_item	2504749	et	3	main
vaeva	doc_491521501818_item	2504764	et	4	main
on	doc_491521501818_item	2504766	et	4	main
enda	doc_491521501818_item	2504767	et	4	main
6-b	doc_491521501818_item	2504776	et	4	main
kolme	doc_491521501818_item	2504780	et	4	main
rühma	doc_491521501818_item	2504781	et	4	main
töötavad	doc_491521501818_item	2504782	et	4	main
elektriga	doc_491521501818_item	2504783	et	3	main
haamer	doc_491521501818_item	2504794	et	3	main
mutrivõti	doc_491521501818_item	2504798	et	4	main
tolmuimeja	doc_491521501818_item	2504799	et	4	main
höövel	doc_491521501818_item	2504806	et	3	main
prits	doc_491521501818_item	2504812	et	3	main
kohviveski	doc_491521501818_item	2504814	et	4	main
juukseföön	doc_491521501818_item	2504815	et	3	main
kuni	doc_491521501818_item	2504624	et	3	main
ära	doc_491521501818_item	2504626	et	4	main
ära	doc_491521501818_item	2504634	et	4	main
see	doc_491521501818_item	2504643	et	3	main
teosammul	doc_491521501818_item	2504656	et	4	main
venisin	doc_491521501818_item	2504658	et	3	main
aga	doc_491521501818_item	2504664	et	3	main
pidin	doc_491521501818_item	2504666	et	3	main
toetuma	doc_491521501818_item	2504670	et	4	main
on	doc_491521501818_item	2504673	et	4	main
tõeline	doc_491521501818_item	2504674	et	4	main
sõber	doc_491521501818_item	2504675	et	3	main
hetkel	doc_491521501818_item	2504681	et	4	main
et	doc_491521501818_item	2504684	et	3	main
võin	doc_491521501818_item	2504685	et	3	main
raskel	doc_491521501818_item	2504686	et	3	main
hetkel	doc_491521501818_item	2504687	et	4	main
talle	doc_491521501818_item	2504688	et	4	main
toetuda	doc_491521501818_item	2504689	et	3	main
d	doc_491521501818_item	2504690	et	4	main
aeglustuma	doc_491521501818_item	2504691	et	3	main
aeglustama	doc_491521501818_item	2504692	et	3	main
selle	doc_491521501818_item	2504693	et	4	main
rohu	doc_491521501818_item	2504694	et	4	main
tarvitamine	doc_491521501818_item	2504695	et	4	main
aeglustab	doc_491521501818_item	2504696	et	3	main
pulssi	doc_491521501818_item	2504697	et	4	main
selle	doc_491521501818_item	2504698	et	4	main
rohu	doc_491521501818_item	2504699	et	4	main
tarvitamisel	doc_491521501818_item	2504700	et	4	main
pulss	doc_491521501818_item	2504702	et	3	main
teie	doc_491521501818_item	2504701	et	4	main
aeglustub	doc_491521501818_item	2504703	et	3	main
20	doc_491521501818_item	2504704	et	2	main
leidke	doc_491521501818_item	2504705	et	3	main
sünonüümsete	doc_491521501818_item	2504706	et	3	main
paarid	doc_491521501818_item	2504708	et	4	main
väljendite	doc_491521501818_item	2504707	et	3	main
1	doc_491521501818_item	2504709	et	2	main
ajab	doc_491521501818_item	2504710	et	3	main
asjad	doc_491521501818_item	2504711	et	3	main
joonde	doc_491521501818_item	2504712	et	4	main
a	doc_491521501818_item	2504713	et	4	main
pälvib	doc_491521501818_item	2504714	et	3	main
2	doc_491521501818_item	2504717	et	2	main
tähelepanu	doc_491521501818_item	2504716	et	4	main
ja	doc_491521501818_item	2504719	et	3	main
ei	doc_491521501818_item	2504724	et	4	main
korraldab	doc_491521501818_item	2504733	et	3	main
ära	doc_491521501818_item	2504734	et	4	main
4	doc_491521501818_item	2504735	et	2	main
teeb	doc_491521501818_item	2504741	et	3	main
liiga	doc_491521501818_item	2504751	et	4	main
sellega	doc_491521501818_item	2504763	et	3	main
1-c	doc_491521501818_item	2504771	et	4	main
4-f	doc_491521501818_item	2504774	et	4	main
töötavad	doc_491521501818_item	2504784	et	4	main
elektrita	doc_491521501818_item	2504785	et	3	main
nii	doc_491521501818_item	2504786	et	3	main
see	doc_491521501818_item	2504787	et	3	main
kui	doc_491521501818_item	2504788	et	3	main
teine	doc_491521501818_item	2504789	et	3	main
prits	doc_491521501818_item	2504792	et	3	main
pardel	doc_491521501818_item	2504795	et	4	main
muruniiduk	doc_491521501818_item	2504804	et	3	main
lood	doc_491521501818_item	2504810	et	4	main
pardel	doc_491521501818_item	2504813	et	4	main
kirves	doc_491521501818_item	2504816	et	4	main
akulaadija	doc_491521501818_item	2504817	et	4	main
viil	doc_491521501818_item	2504822	et	3	main
unistused	doc_491521501819_item	2504833	et	4	main
viimaks	doc_491521501819_item	2504834	et	4	main
praegu	doc_491521501819_item	2504843	et	3	main
tõmmata	doc_491521501819_item	2504860	et	4	main
rääkimata	doc_491521501819_item	2504873	et	4	main
koduse	doc_491521501819_item	2504874	et	4	main
arvutivõrgu	doc_491521501819_item	2504875	et	3	main
ehitamisest	doc_491521501819_item	2504876	et	4	main
мечты	doc_491521501819_item	2504879	et	2	main
технологиям	doc_491521501819_item	2504885	et	2	main
расположить	doc_491521501819_item	2504890	et	2	main
которое	doc_491521501819_item	2504894	et	2	main
включается	doc_491521501819_item	2504899	et	2	main
кто	doc_491521501819_item	2504905	et	2	main
заранее	doc_491521501819_item	2504910	et	2	main
и	doc_491521501819_item	2504913	et	2	main
нажатием	doc_491521501819_item	2504918	et	2	main
дороге	doc_491521501819_item	2504924	et	2	main
говоря	doc_491521501819_item	2504927	et	2	main
у	doc_491521501819_item	2504932	et	2	main
kas	doc_491521501819_item	2504936	et	3	main
jahtuma	doc_491521501819_item	2504953	et	3	main
b	doc_491521501819_item	2504971	et	4	main
venitama	doc_491521501819_item	2504973	et	4	main
sõber	doc_491521501819_item	2505007	et	3	main
selle	doc_491521501819_item	2505025	et	4	main
pulssi	doc_491521501819_item	2505029	et	4	main
selle	doc_491521501819_item	2505030	et	4	main
pulss	doc_491521501819_item	2505034	et	3	main
ajab	doc_491521501819_item	2505042	et	3	main
luust	doc_491521501819_item	2505050	et	4	main
ja	doc_491521501819_item	2505051	et	3	main
lihast	doc_491521501819_item	2505052	et	4	main
inimesed	doc_491521501819_item	2505053	et	3	main
kirub	doc_491521501819_item	2505061	et	3	main
kiusab	doc_491521501819_item	2505077	et	3	main
kes	doc_491521501819_item	2505086	et	4	main
f	doc_491521501819_item	2505097	et	4	main
jukseföön	doc_491521501819_item	2505122	et	4	main
pump	doc_491521501819_item	2505124	et	3	main
lood	doc_491521501819_item	2505139	et	4	main
kirves	doc_491521501819_item	2505141	et	4	main
höövel	doc_491521501819_item	2505143	et	3	main
näpitstangid	doc_491521501819_item	2505144	et	3	main
lood	doc_491521501819_item	2505145	et	4	main
ketassaag	doc_491521501819_item	2505146	et	3	main
tolmuimeja	doc_491521501819_item	2505153	et	4	main
puur	doc_491521501819_item	2505158	et	3	main
eksamitöö	doc_491521501820_item	2505163	et	4	main
tõlkige	doc_491521501820_item	2505165	et	3	main
tõusete	doc_491521501820_item	2505175	et	4	main
kell	doc_491521501820_item	2505176	et	3	main
just	doc_491521501820_item	2505179	et	3	main
läinud	doc_491521501820_item	2505229	et	4	main
кофеварка	doc_491521501820_item	2505232	et	2	main
будильника	doc_491521501820_item	2505237	et	2	main
maapõhja	doc_491521501818_item	2504731	et	4	main
c	doc_491521501818_item	2504732	et	4	main
ta	doc_491521501818_item	2504740	et	4	main
ta	doc_491521501818_item	2504744	et	4	main
e	doc_491521501818_item	2504752	et	4	main
kes	doc_491521501818_item	2504754	et	4	main
on	doc_491521501818_item	2504755	et	4	main
päriselt	doc_491521501818_item	2504756	et	3	main
olemas	doc_491521501818_item	2504757	et	4	main
mitte	doc_491521501818_item	2504758	et	3	main
raamatutegelased	doc_491521501818_item	2504759	et	3	main
6	doc_491521501818_item	2504760	et	2	main
ta	doc_491521501818_item	2504761	et	4	main
nägi	doc_491521501818_item	2504762	et	3	main
f	doc_491521501818_item	2504765	et	4	main
tige	doc_491521501818_item	2504770	et	3	main
3-a	doc_491521501818_item	2504773	et	4	main
jagage	doc_491521501818_item	2504778	et	3	main
kohviveski	doc_491521501818_item	2504790	et	4	main
juukseföön	doc_491521501818_item	2504793	et	3	main
kirves	doc_491521501818_item	2504797	et	4	main
kruvikeeraja	doc_491521501818_item	2504800	et	4	main
puur	doc_491521501818_item	2504801	et	3	main
ketassaag	doc_491521501818_item	2504811	et	3	main
tolmuimeja	doc_491521501818_item	2504818	et	4	main
puur	doc_491521501818_item	2504823	et	3	main
juba	doc_491521501819_item	2504842	et	3	main
suulise	doc_491521501819_item	2504849	et	4	main
reguleerida	doc_491521501819_item	2504864	et	3	main
благодаря	doc_491521501819_item	2504881	et	2	main
дигитальным	doc_491521501819_item	2504884	et	2	main
сейчас	doc_491521501819_item	2504889	et	2	main
дома	doc_491521501819_item	2504892	et	2	main
приказа	doc_491521501819_item	2504898	et	2	main
наблюдения	doc_491521501819_item	2504902	et	2	main
вам	doc_491521501819_item	2504907	et	2	main
регулировать	doc_491521501819_item	2504914	et	2	main
pump	doc_491521501818_item	2504808	et	3	main
kruvikeeraja	doc_491521501818_item	2504819	et	4	main
haamer	doc_491521501818_item	2504825	et	3	main
höövel	doc_491521501818_item	2504827	et	3	main
eksamitöö	doc_491521501819_item	2504828	et	4	main
1tõlkige	doc_491521501819_item	2504829	et	3	main
nüüd	doc_491521501819_item	2504830	et	4	main
on	doc_491521501819_item	2504831	et	4	main
need	doc_491521501819_item	2504832	et	3	main
digitaaltehnoloogiale	doc_491521501819_item	2504840	et	3	main
võite	doc_491521501819_item	2504841	et	4	main
valvekaamera	doc_491521501819_item	2504852	et	4	main
mis	doc_491521501819_item	2504853	et	4	main
näitab	doc_491521501819_item	2504854	et	3	main
kes	doc_491521501819_item	2504855	et	4	main
kardinad	doc_491521501819_item	2504861	et	4	main
nuppude	doc_491521501819_item	2504866	et	3	main
микропроцессорам	doc_491521501819_item	2504882	et	2	main
можете	doc_491521501819_item	2504887	et	2	main
освещение	doc_491521501819_item	2504893	et	2	main
голосового	doc_491521501819_item	2504897	et	2	main
камеру	doc_491521501819_item	2504901	et	2	main
которая	doc_491521501819_item	2504903	et	2	main
в	doc_491521501819_item	2504908	et	2	main
данные	doc_491521501819_item	2504912	et	2	main
температуру	doc_491521501819_item	2504915	et	2	main
кнопки	doc_491521501819_item	2504919	et	2	main
уже	doc_491521501819_item	2504922	et	2	main
не	doc_491521501819_item	2504926	et	2	main
о	doc_491521501819_item	2504929	et	2	main
дома	doc_491521501819_item	2504934	et	2	main
suunatud	doc_491521501819_item	2504942	et	4	main
tegevust	doc_491521501819_item	2504943	et	4	main
sõna	doc_491521501819_item	2504949	et	4	main
õiges	doc_491521501819_item	2504950	et	3	main
kuni	doc_491521501819_item	2504956	et	3	main
ära	doc_491521501819_item	2504958	et	4	main
keele	doc_491521501819_item	2504962	et	4	main
see	doc_491521501819_item	2504975	et	3	main
tuleb	doc_491521501819_item	2504977	et	3	main
on	doc_491521501819_item	2505005	et	4	main
tõeline	doc_491521501819_item	2505006	et	4	main
mind	doc_491521501819_item	2505010	et	4	main
igal	doc_491521501819_item	2505011	et	3	main
hetkel	doc_491521501819_item	2505013	et	4	main
raskel	doc_491521501819_item	2505018	et	3	main
talle	doc_491521501819_item	2505020	et	4	main
aeglustuma	doc_491521501819_item	2505023	et	3	main
20	doc_491521501819_item	2505036	et	2	main
paarid	doc_491521501819_item	2505040	et	4	main
asjad	doc_491521501819_item	2505043	et	3	main
a	doc_491521501819_item	2505045	et	4	main
pälvib	doc_491521501819_item	2505046	et	3	main
talle	doc_491521501819_item	2505058	et	4	main
maapõhja	doc_491521501819_item	2505063	et	4	main
ära	doc_491521501819_item	2505066	et	4	main
4	doc_491521501819_item	2505067	et	2	main
mind	doc_491521501819_item	2505078	et	4	main
on	doc_491521501819_item	2505087	et	4	main
päriselt	doc_491521501819_item	2505088	et	3	main
olemas	doc_491521501819_item	2505089	et	4	main
mitte	doc_491521501819_item	2505090	et	3	main
6	doc_491521501819_item	2505092	et	2	main
sellega	doc_491521501819_item	2505095	et	3	main
näpitstangid	doc_491521501819_item	2505123	et	3	main
elektriga	doc_491521501819_item	2505133	et	3	main
jootekolb	doc_491521501819_item	2505136	et	4	main
1	doc_491521501820_item	2505164	et	2	main
kööki	doc_491521501820_item	2505167	et	4	main
kohvimasin	doc_491521501820_item	2505168	et	3	main
teate	doc_491521501820_item	2505173	et	4	main
on	doc_491521501820_item	2505178	et	4	main
kohvi	doc_491521501820_item	2505182	et	4	main
mutrivõti	doc_491521501818_item	2504821	et	4	main
jootekolb	doc_491521501818_item	2504826	et	4	main
paigutada	doc_491521501819_item	2504844	et	3	main
valgustuse	doc_491521501819_item	2504846	et	4	main
töötab	doc_491521501819_item	2504848	et	3	main
käskluse	doc_491521501819_item	2504850	et	3	main
peale	doc_491521501819_item	2504851	et	4	main
helistab	doc_491521501819_item	2504856	et	3	main
teie	doc_491521501819_item	2504857	et	4	main
ukse	doc_491521501819_item	2504858	et	3	main
taga	doc_491521501819_item	2504859	et	4	main
ette	doc_491521501819_item	2504862	et	4	main
toatemperatuuri	doc_491521501819_item	2504865	et	4	main
abil	doc_491521501819_item	2504867	et	4	main
lülitada	doc_491521501819_item	2504868	et	3	main
õhukonditsioneeri	doc_491521501819_item	2504869	et	4	main
sisse	doc_491521501819_item	2504870	et	4	main
juba	doc_491521501819_item	2504871	et	3	main
koduteel	doc_491521501819_item	2504872	et	3	main
эти	doc_491521501819_item	2504878	et	2	main
и	doc_491521501819_item	2504883	et	2	main
уже	doc_491521501819_item	2504888	et	2	main
работает	doc_491521501819_item	2504895	et	2	main
покажет	doc_491521501819_item	2504904	et	2	main
запрограмировать	doc_491521501819_item	2504911	et	2	main
в	doc_491521501819_item	2504916	et	2	main
включать	doc_491521501819_item	2504920	et	2	main
по	doc_491521501819_item	2504923	et	2	main
уже	doc_491521501819_item	2504928	et	2	main
сети	doc_491521501819_item	2504931	et	2	main
tegevust	doc_491521501819_item	2504938	et	4	main
või	doc_491521501819_item	2504940	et	4	main
väljapoole	doc_491521501819_item	2504941	et	3	main
lünka	doc_491521501819_item	2504947	et	4	main
jahutama	doc_491521501819_item	2504954	et	3	main
tee	doc_491521501819_item	2504957	et	4	main
jahtub	doc_491521501819_item	2504959	et	3	main
muidu	doc_491521501819_item	2504960	et	3	main
kõrvetad	doc_491521501819_item	2504961	et	3	main
ära	doc_491521501819_item	2504966	et	4	main
muidu	doc_491521501819_item	2504967	et	3	main
kõrvetad	doc_491521501819_item	2504968	et	3	main
millest	doc_491521501819_item	2504974	et	3	main
tean	doc_491521501819_item	2505015	et	3	main
hetkel	doc_491521501819_item	2505019	et	4	main
toetama	doc_491521501819_item	2505021	et	3	main
rohu	doc_491521501819_item	2505031	et	4	main
tarvitamisel	doc_491521501819_item	2505032	et	4	main
teie	doc_491521501819_item	2505033	et	4	main
1	doc_491521501819_item	2505041	et	2	main
3	doc_491521501819_item	2505060	et	2	main
ta	doc_491521501819_item	2505076	et	4	main
ta	doc_491521501819_item	2505080	et	4	main
teeb	doc_491521501819_item	2505081	et	3	main
liiga	doc_491521501819_item	2505083	et	4	main
e	doc_491521501819_item	2505084	et	4	main
inimesed	doc_491521501819_item	2505085	et	3	main
raamatutegelased	doc_491521501819_item	2505091	et	3	main
ta	doc_491521501819_item	2505093	et	4	main
nägi	doc_491521501819_item	2505094	et	3	main
on	doc_491521501819_item	2505098	et	4	main
peale	doc_491521501819_item	2505100	et	4	main
väga	doc_491521501819_item	2505101	et	3	main
tige	doc_491521501819_item	2505102	et	3	main
1-c	doc_491521501819_item	2505103	et	4	main
2-e	doc_491521501819_item	2505104	et	3	main
3-a	doc_491521501819_item	2505105	et	4	main
akulaadija	doc_491521501819_item	2505125	et	4	main
muruniiduk	doc_491521501819_item	2505127	et	3	main
kruvikeeraja	doc_491521501819_item	2505129	et	4	main
tolmuimeja	doc_491521501819_item	2505130	et	4	main
autos	doc_491521501819_item	2505131	et	3	main
töötab	doc_491521501819_item	2505132	et	3	main
ketassaag	doc_491521501819_item	2505134	et	3	main
puur	doc_491521501819_item	2505135	et	3	main
pardel	doc_491521501819_item	2505137	et	4	main
kohviveski	doc_491521501819_item	2505149	et	4	main
juukseföön	doc_491521501819_item	2505150	et	3	main
kirves	doc_491521501819_item	2505151	et	4	main
viil	doc_491521501819_item	2505157	et	3	main
muruniiduk	doc_491521501819_item	2505159	et	3	main
jootekolb	doc_491521501819_item	2505161	et	4	main
saanud	doc_491521501820_item	2505171	et	4	main
äratuskellalt	doc_491521501820_item	2505172	et	3	main
uksel	doc_491521501820_item	2505221	et	3	main
kas	doc_491521501820_item	2505224	et	3	main
mitte	doc_491521501820_item	2505227	et	3	main
кухня	doc_491521501820_item	2505231	et	2	main
кондиционер	doc_491521501819_item	2504921	et	2	main
компьютерной	doc_491521501819_item	2504930	et	2	main
5	doc_491521501819_item	2504935	et	2	main
enesekohast	doc_491521501819_item	2504937	et	4	main
väljendav	doc_491521501819_item	2504939	et	4	main
väljendav	doc_491521501819_item	2504944	et	4	main
tegusõna	doc_491521501819_item	2504945	et	4	main
kirjutage	doc_491521501819_item	2504946	et	3	main
vormis	doc_491521501819_item	2504951	et	4	main
oota	doc_491521501819_item	2504955	et	4	main
jahuta	doc_491521501819_item	2504964	et	4	main
tee	doc_491521501819_item	2504965	et	4	main
ära	doc_491521501819_item	2504970	et	4	main
venima	doc_491521501819_item	2504972	et	3	main
küll	doc_491521501819_item	2504976	et	4	main
et	doc_491521501819_item	2504978	et	3	main
mõnikord	doc_491521501819_item	2504979	et	3	main
lendab	doc_491521501819_item	2504980	et	3	main
aeg	doc_491521501819_item	2504981	et	3	main
väga	doc_491521501819_item	2504982	et	3	main
kiiresti	doc_491521501819_item	2504983	et	3	main
teine	doc_491521501819_item	2504984	et	3	main
kord	doc_491521501819_item	2504985	et	4	main
aga	doc_491521501819_item	2504986	et	3	main
venitab	doc_491521501819_item	2504987	et	3	main
teosammul	doc_491521501819_item	2504988	et	4	main
ma	doc_491521501819_item	2504989	et	3	main
venin	doc_491521501819_item	2504990	et	3	main
äraminekuga	doc_491521501819_item	2504991	et	3	main
nii	doc_491521501819_item	2504992	et	3	main
kaua	doc_491521501819_item	2504993	et	3	main
kui	doc_491521501819_item	2504994	et	3	main
oskasin	doc_491521501819_item	2504995	et	3	main
aga	doc_491521501819_item	2504996	et	3	main
lõpuks	doc_491521501819_item	2504997	et	4	main
pidin	doc_491521501819_item	2504998	et	3	main
siiski	doc_491521501819_item	2504999	et	4	main
lahkuma	doc_491521501819_item	2505000	et	3	main
c	doc_491521501819_item	2505001	et	4	main
toetuma	doc_491521501819_item	2505002	et	4	main
toetama	doc_491521501819_item	2505003	et	3	main
kes	doc_491521501819_item	2505008	et	4	main
võin	doc_491521501819_item	2505017	et	3	main
d	doc_491521501819_item	2505022	et	4	main
rohu	doc_491521501819_item	2505026	et	4	main
aeglustab	doc_491521501819_item	2505028	et	3	main
leidke	doc_491521501819_item	2505037	et	3	main
väljendite	doc_491521501819_item	2505039	et	3	main
joonde	doc_491521501819_item	2505044	et	4	main
tähelepanu	doc_491521501819_item	2505048	et	4	main
2	doc_491521501819_item	2505049	et	2	main
tulnud	doc_491521501819_item	2505057	et	4	main
on	doc_491521501819_item	2505068	et	4	main
luubi	doc_491521501819_item	2505069	et	3	main
all	doc_491521501819_item	2505070	et	3	main
d	doc_491521501819_item	2505071	et	4	main
mulle	doc_491521501819_item	2505082	et	4	main
aeglustama	doc_491521501819_item	2505024	et	3	main
tarvitamine	doc_491521501819_item	2505027	et	4	main
aeglustab	doc_491521501819_item	2505035	et	3	main
sünonüümsete	doc_491521501819_item	2505038	et	3	main
erilist	doc_491521501819_item	2505047	et	4	main
b	doc_491521501819_item	2505054	et	4	main
see	doc_491521501819_item	2505055	et	3	main
ei	doc_491521501819_item	2505056	et	4	main
kergelt	doc_491521501819_item	2505059	et	4	main
ennast	doc_491521501819_item	2505062	et	4	main
c	doc_491521501819_item	2505064	et	4	main
korraldab	doc_491521501819_item	2505065	et	3	main
ta	doc_491521501819_item	2505072	et	4	main
teeb	doc_491521501819_item	2505073	et	3	main
mulle	doc_491521501819_item	2505074	et	4	main
ülekohut	doc_491521501819_item	2505075	et	3	main
5	doc_491521501819_item	2505079	et	2	main
vaeva	doc_491521501819_item	2505096	et	4	main
enda	doc_491521501819_item	2505099	et	4	main
4-f	doc_491521501819_item	2505106	et	4	main
5-d	doc_491521501819_item	2505107	et	4	main
6-b	doc_491521501819_item	2505108	et	4	main
23	doc_491521501819_item	2505109	et	2	main
jagage	doc_491521501819_item	2505110	et	3	main
sõnad	doc_491521501819_item	2505111	et	4	main
kolme	doc_491521501819_item	2505112	et	4	main
rühma	doc_491521501819_item	2505113	et	4	main
töötavad	doc_491521501819_item	2505114	et	4	main
elektriga	doc_491521501819_item	2505115	et	3	main
töötavad	doc_491521501819_item	2505116	et	4	main
elektrita	doc_491521501819_item	2505117	et	3	main
nii	doc_491521501819_item	2505118	et	3	main
see	doc_491521501819_item	2505119	et	3	main
kui	doc_491521501819_item	2505120	et	3	main
teine	doc_491521501819_item	2505121	et	3	main
viil	doc_491521501819_item	2505126	et	3	main
kohviveski	doc_491521501819_item	2505128	et	4	main
prits	doc_491521501819_item	2505147	et	3	main
pardel	doc_491521501819_item	2505148	et	4	main
kruvikeeraja	doc_491521501819_item	2505154	et	4	main
pump	doc_491521501819_item	2505155	et	3	main
on	doc_491521501820_item	2505170	et	4	main
seitse	doc_491521501820_item	2505177	et	3	main
ajaks	doc_491521501820_item	2505181	et	4	main
keetnud	doc_491521501820_item	2505183	et	4	main
seejärel	doc_491521501820_item	2505184	et	3	main
külmiku	doc_491521501820_item	2505220	et	3	main
pole	doc_491521501820_item	2505226	et	3	main
далее	doc_491521501820_item	2505230	et	2	main
которая	doc_491521501820_item	2505233	et	2	main
что	doc_491521501820_item	2505238	et	2	main
часов	doc_491521501820_item	2505242	et	2	main
затем	doc_491521501820_item	2505248	et	2	main
микроволновую	doc_491521501820_item	2505252	et	2	main
сколько	doc_491521501820_item	2505258	et	2	main
вещь	doc_491521501820_item	2505262	et	2	main
также	doc_491521501820_item	2505266	et	2	main
ли	doc_491521501820_item	2505272	et	2	main
в	doc_491521501820_item	2505277	et	2	main
монитор	doc_491521501820_item	2505281	et	2	main
холодильника	doc_491521501820_item	2505284	et	2	main
ли	doc_491521501820_item	2505290	et	2	main
vastupidi	doc_491521501820_item	2505302	et	3	main
tervist	doc_491521501820_item	2505321	et	4	main
te	doc_491521501820_item	2505323	et	4	main
spordiga	doc_491521501820_item	2505325	et	3	main
haamer	doc_491521501819_item	2505138	et	3	main
prits	doc_491521501819_item	2505140	et	3	main
mutrivõti	doc_491521501819_item	2505142	et	4	main
akulaadija	doc_491521501819_item	2505152	et	4	main
mutrivõti	doc_491521501819_item	2505156	et	4	main
haamer	doc_491521501819_item	2505160	et	3	main
höövel	doc_491521501819_item	2505162	et	3	main
edasi	doc_491521501820_item	2505166	et	3	main
mis	doc_491521501820_item	2505169	et	4	main
et	doc_491521501820_item	2505174	et	3	main
selleks	doc_491521501820_item	2505180	et	4	main
pistke	doc_491521501820_item	2505185	et	3	main
toit	doc_491521501820_item	2505186	et	3	main
mikrolaineahju	doc_491521501820_item	2505187	et	4	main
küll	doc_491521501820_item	2505188	et	4	main
tark	doc_491521501820_item	2505189	et	3	main
masin	doc_491521501820_item	2505190	et	3	main
ära	doc_491521501820_item	2505191	et	4	main
tunneb	doc_491521501820_item	2505192	et	3	main
kui	doc_491521501820_item	2505193	et	3	main
kaua	doc_491521501820_item	2505194	et	3	main
üht	doc_491521501820_item	2505195	et	3	main
või	doc_491521501820_item	2505196	et	4	main
teist	doc_491521501820_item	2505197	et	4	main
asja	doc_491521501820_item	2505198	et	4	main
valmistada	doc_491521501820_item	2505199	et	3	main
või	doc_491521501820_item	2505200	et	4	main
soojendada	doc_491521501820_item	2505201	et	3	main
samuti	doc_491521501820_item	2505202	et	3	main
ei	doc_491521501820_item	2505203	et	4	main
ole	doc_491521501820_item	2505204	et	4	main
vaja	doc_491521501820_item	2505205	et	4	main
muretseda	doc_491521501820_item	2505206	et	3	main
ega	doc_491521501820_item	2505207	et	3	main
rõõsk	doc_491521501820_item	2505208	et	3	main
koor	doc_491521501820_item	2505209	et	4	main
hapu	doc_491521501820_item	2505210	et	4	main
ole	doc_491521501820_item	2505211	et	4	main
ega	doc_491521501820_item	2505212	et	3	main
kohvi	doc_491521501820_item	2505213	et	4	main
peal	doc_491521501820_item	2505214	et	4	main
tõmbu	doc_491521501820_item	2505216	et	4	main
kokku	doc_491521501820_item	2505215	et	3	main
seda	doc_491521501820_item	2505217	et	3	main
teatab	doc_491521501820_item	2505218	et	3	main
monitor	doc_491521501820_item	2505219	et	3	main
nagu	doc_491521501820_item	2505222	et	3	main
vorst	doc_491521501820_item	2505225	et	3	main
получила	doc_491521501820_item	2505234	et	2	main
встаете	doc_491521501820_item	2505239	et	2	main
этому	doc_491521501820_item	2505244	et	2	main
сунте	doc_491521501820_item	2505249	et	2	main
умная	doc_491521501820_item	2505254	et	2	main
одну	doc_491521501820_item	2505259	et	2	main
или	doc_491521501820_item	2505264	et	2	main
не	doc_491521501820_item	2505267	et	2	main
ни	doc_491521501820_item	2505274	et	2	main
распознает	doc_491521501820_item	2505280	et	2	main
двери	doc_491521501820_item	2505283	et	2	main
не	doc_491521501820_item	2505288	et	2	main
laused	doc_491521501820_item	2505294	et	3	main
kasutades	doc_491521501820_item	2505296	et	3	main
tegusõna	doc_491521501820_item	2505298	et	4	main
asemel	doc_491521501820_item	2505299	et	4	main
pidev	doc_491521501820_item	2505304	et	3	main
riski	doc_491521501820_item	2505308	et	4	main
inimestel	doc_491521501820_item	2505309	et	3	main
kes	doc_491521501820_item	2505310	et	4	main
on	doc_491521501820_item	2505311	et	4	main
pidevas	doc_491521501820_item	2505312	et	3	main
stressis	doc_491521501820_item	2505313	et	3	main
suureneb	doc_491521501820_item	2505314	et	3	main
haigestumise	doc_491521501820_item	2505315	et	4	main
risk	doc_491521501820_item	2505316	et	3	main
2	doc_491521501820_item	2505317	et	2	main
tegelemine	doc_491521501820_item	2505319	et	4	main
spordiga	doc_491521501820_item	2505318	et	3	main
parandab	doc_491521501820_item	2505320	et	3	main
tervis	doc_491521501820_item	2505328	et	3	main
eluiga	doc_491521501820_item	2505332	et	4	main
jooksul	doc_491521501820_item	2505335	et	4	main
inimesed	doc_491521501820_item	2505346	et	3	main
ja	doc_491521501820_item	2505349	et	3	main
tekitavad	doc_491521501820_item	2505350	et	4	main
uued	doc_491521501820_item	2505359	et	3	main
tekivad	doc_491521501820_item	2505363	et	3	main
tegurite	doc_491521501820_item	2505365	et	3	main
haigusi	doc_491521501820_item	2505371	et	4	main
r-liitelisi	doc_491521501820_item	2505374	et	4	main
helkima	doc_491521501820_item	2505379	et	3	main
rikkis	doc_491521501820_item	2505427	et	3	main
в	doc_491521501820_item	2505433	et	2	main
к	doc_491521501820_item	2505439	et	2	main
лампочка	doc_491521501820_item	2505443	et	2	main
для	doc_491521501820_item	2505446	et	2	main
лампы	doc_491521501820_item	2505449	et	2	main
see	doc_491521501820_item	2505450	et	3	main
selle	doc_491521501820_item	2505455	et	4	main
jaoks	doc_491521501820_item	2505457	et	4	main
edasi	doc_491521501821_item	2505461	et	3	main
kööki	doc_491521501821_item	2505462	et	4	main
kohvimasin	doc_491521501821_item	2505463	et	3	main
teate	doc_491521501821_item	2505468	et	4	main
ole	doc_491521501821_item	2505499	et	4	main
vaja	doc_491521501821_item	2505500	et	4	main
ega	doc_491521501821_item	2505502	et	3	main
tõmbu	doc_491521501821_item	2505511	et	4	main
nagu	doc_491521501821_item	2505517	et	3	main
kas	doc_491521501821_item	2505519	et	3	main
läinud	doc_491521501821_item	2505524	et	4	main
на	doc_491521501821_item	2505528	et	2	main
от	doc_491521501821_item	2505534	et	2	main
встаете	doc_491521501821_item	2505538	et	2	main
этому	doc_491521501821_item	2505543	et	2	main
sedagi	doc_491521501820_item	2505223	et	3	main
vanaks	doc_491521501820_item	2505228	et	3	main
известие	doc_491521501820_item	2505235	et	2	main
в	doc_491521501820_item	2505240	et	2	main
кофе	doc_491521501820_item	2505247	et	2	main
печь	doc_491521501820_item	2505253	et	2	main
знает	doc_491521501820_item	2505257	et	2	main
другую	doc_491521501820_item	2505261	et	2	main
беспокоться	doc_491521501820_item	2505269	et	2	main
сливки	doc_491521501820_item	2505273	et	2	main
кофе	doc_491521501820_item	2505278	et	2	main
на	doc_491521501820_item	2505282	et	2	main
и	doc_491521501820_item	2505286	et	2	main
колбаса	doc_491521501820_item	2505291	et	2	main
ümber	doc_491521501820_item	2505295	et	3	main
sihitu	doc_491521501820_item	2505297	et	4	main
1	doc_491521501820_item	2505303	et	2	main
haigestumise	doc_491521501820_item	2505307	et	4	main
от	doc_491521501820_item	2505236	et	2	main
к	doc_491521501820_item	2505243	et	2	main
сварила	doc_491521501820_item	2505246	et	2	main
еду	doc_491521501820_item	2505250	et	2	main
машина	doc_491521501820_item	2505255	et	2	main
готовить	doc_491521501820_item	2505263	et	2	main
надо	doc_491521501820_item	2505268	et	2	main
прокисли	doc_491521501820_item	2505271	et	2	main
ли	doc_491521501820_item	2505276	et	2	main
как	doc_491521501820_item	2505285	et	2	main
11	doc_491521501820_item	2505292	et	2	main
sihilist	doc_491521501820_item	2505300	et	4	main
suurendab	doc_491521501820_item	2505306	et	3	main
teil	doc_491521501820_item	2505326	et	4	main
on	doc_491521501820_item	2505333	et	4	main
aja	doc_491521501820_item	2505334	et	4	main
tsivilisatsiooni	doc_491521501820_item	2505338	et	4	main
areng	doc_491521501820_item	2505339	et	3	main
on	doc_491521501820_item	2505340	et	4	main
inimeste	doc_491521501820_item	2505341	et	3	main
keskmist	doc_491521501820_item	2505342	et	3	main
eluiga	doc_491521501820_item	2505343	et	4	main
5	doc_491521501820_item	2505361	et	2	main
tekitab	doc_491521501820_item	2505370	et	3	main
tõlkige	doc_491521501820_item	2505376	et	3	main
siduma	doc_491521501820_item	2505380	et	3	main
для	doc_491521501820_item	2505423	et	2	main
elektriseadmeid	doc_491521501820_item	2505428	et	3	main
произошло	doc_491521501820_item	2505435	et	2	main
on	doc_491521501820_item	2505452	et	4	main
1	doc_491521501821_item	2505459	et	2	main
mis	doc_491521501821_item	2505464	et	4	main
et	doc_491521501821_item	2505469	et	3	main
koor	doc_491521501821_item	2505504	et	4	main
seda	doc_491521501821_item	2505512	et	3	main
7	doc_491521501820_item	2505241	et	2	main
времени	doc_491521501820_item	2505245	et	2	main
в	doc_491521501820_item	2505251	et	2	main
обязательно	doc_491521501820_item	2505256	et	2	main
или	doc_491521501820_item	2505260	et	2	main
согревать	doc_491521501820_item	2505265	et	2	main
ни	doc_491521501820_item	2505270	et	2	main
свернутся	doc_491521501820_item	2505275	et	2	main
это	doc_491521501820_item	2505279	et	2	main
то	doc_491521501820_item	2505287	et	2	main
испортилась	doc_491521501820_item	2505289	et	2	main
kirjutage	doc_491521501820_item	2505293	et	3	main
ja	doc_491521501820_item	2505301	et	3	main
stress	doc_491521501820_item	2505305	et	3	main
paraneb	doc_491521501820_item	2505327	et	3	main
inimeste	doc_491521501820_item	2505330	et	3	main
pidevalt	doc_491521501820_item	2505336	et	4	main
probleemid	doc_491521501820_item	2505360	et	3	main
paljude	doc_491521501820_item	2505364	et	3	main
paljude	doc_491521501820_item	2505367	et	3	main
22	doc_491521501820_item	2505372	et	2	main
nimisõnu	doc_491521501820_item	2505375	et	3	main
vedur	doc_491521501820_item	2505383	et	3	main
keelde	doc_491521501820_item	2505415	et	4	main
a	doc_491521501820_item	2505416	et	4	main
не	doc_491521501820_item	2505417	et	2	main
пользуйтесь	doc_491521501820_item	2505418	et	2	main
неисправными	doc_491521501820_item	2505419	et	2	main
электроприборами	doc_491521501820_item	2505420	et	2	main
kui	doc_491521501820_item	2505322	et	3	main
tegelete	doc_491521501820_item	2505324	et	3	main
3	doc_491521501820_item	2505329	et	2	main
keskmine	doc_491521501820_item	2505331	et	3	main
4	doc_491521501820_item	2505345	et	2	main
looduskeskkonda	doc_491521501820_item	2505348	et	4	main
haigused	doc_491521501820_item	2505362	et	4	main
koosmõjul	doc_491521501820_item	2505366	et	3	main
koosmõju	doc_491521501820_item	2505369	et	4	main
kallama	doc_491521501820_item	2505378	et	3	main
puhuma	doc_491521501820_item	2505382	et	3	main
проводящий	doc_491521501820_item	2505384	et	2	main
рыбак	doc_491521501820_item	2505386	et	2	main
helkur	doc_491521501820_item	2505387	et	4	main
kallur	doc_491521501820_item	2505385	et	3	main
отражатель	doc_491521501820_item	2505388	et	2	main
sidur	doc_491521501820_item	2505389	et	3	main
связующий	doc_491521501820_item	2505390	et	2	main
тормоз	doc_491521501820_item	2505392	et	2	main
pidur	doc_491521501820_item	2505391	et	3	main
puhur	doc_491521501820_item	2505393	et	3	main
вентилятор	doc_491521501820_item	2505394	et	2	main
kõlama	doc_491521501820_item	2505395	et	3	main
kuvama	doc_491521501820_item	2505396	et	4	main
röstima	doc_491521501820_item	2505397	et	3	main
printima	doc_491521501820_item	2505398	et	3	main
skännima	doc_491521501820_item	2505399	et	4	main
kõlar	doc_491521501820_item	2505400	et	3	main
колонка	doc_491521501820_item	2505401	et	2	main
kuvar	doc_491521501820_item	2505402	et	3	main
монитор	doc_491521501820_item	2505403	et	2	main
röster	doc_491521501820_item	2505404	et	3	main
хлеб	doc_491521501820_item	2505407	et	2	main
делать	doc_491521501820_item	2505406	et	2	main
тостер	doc_491521501820_item	2505405	et	2	main
printer	doc_491521501820_item	2505408	et	3	main
принтер	doc_491521501820_item	2505409	et	2	main
skänner	doc_491521501820_item	2505410	et	4	main
сканер	doc_491521501820_item	2505411	et	2	main
2	doc_491521501820_item	2505412	et	2	main
tõlkige	doc_491521501820_item	2505413	et	3	main
eesti	doc_491521501820_item	2505414	et	4	main
pikenenud	doc_491521501820_item	2505337	et	4	main
pikendanud	doc_491521501820_item	2505344	et	4	main
muudavad	doc_491521501820_item	2505347	et	4	main
sellega	doc_491521501820_item	2505351	et	3	main
uusi	doc_491521501820_item	2505352	et	3	main
probleeme	doc_491521501820_item	2505353	et	3	main
kui	doc_491521501820_item	2505354	et	3	main
looduskeskkond	doc_491521501820_item	2505355	et	3	main
muutub	doc_491521501820_item	2505356	et	3	main
siis	doc_491521501820_item	2505357	et	3	main
tekivad	doc_491521501820_item	2505358	et	3	main
tegurite	doc_491521501820_item	2505368	et	3	main
moodustage	doc_491521501820_item	2505373	et	3	main
vedama	doc_491521501820_item	2505377	et	3	main
pidama	doc_491521501820_item	2505381	et	4	main
это	doc_491521501820_item	2505421	et	2	main
kasutage	doc_491521501820_item	2505426	et	3	main
b	doc_491521501820_item	2505432	et	4	main
привело	doc_491521501820_item	2505438	et	2	main
эта	doc_491521501820_item	2505442	et	2	main
мощная	doc_491521501820_item	2505445	et	2	main
настольной	doc_491521501820_item	2505448	et	2	main
võimas	doc_491521501820_item	2505454	et	4	main
eksamitöö	doc_491521501821_item	2505458	et	4	main
tõlkige	doc_491521501821_item	2505460	et	3	main
tõusete	doc_491521501821_item	2505470	et	4	main
muretseda	doc_491521501821_item	2505501	et	3	main
hapu	doc_491521501821_item	2505505	et	4	main
peal	doc_491521501821_item	2505509	et	4	main
kokku	doc_491521501821_item	2505510	et	3	main
vorst	doc_491521501821_item	2505520	et	3	main
кухню	doc_491521501821_item	2505529	et	2	main
которая	doc_491521501821_item	2505531	et	2	main
будильника	doc_491521501821_item	2505535	et	2	main
в	doc_491521501821_item	2505539	et	2	main
времени	doc_491521501821_item	2505544	et	2	main
кофе	doc_491521501821_item	2505546	et	2	main
этим	doc_491521501821_item	2505550	et	2	main
печь	doc_491521501821_item	2505555	et	2	main
сколько	doc_491521501821_item	2505559	et	2	main
готовить	doc_491521501821_item	2505564	et	2	main
кофе	doc_491521501821_item	2505583	et	2	main
двери	doc_491521501821_item	2505588	et	2	main
даже	doc_491521501821_item	2505590	et	2	main
колбаса	doc_491521501821_item	2505595	et	2	main
laused	doc_491521501821_item	2505598	et	3	main
ja	doc_491521501821_item	2505605	et	3	main
pidev	doc_491521501821_item	2505608	et	3	main
опасно	doc_491521501820_item	2505422	et	2	main
on	doc_491521501820_item	2505430	et	4	main
проводке	doc_491521501820_item	2505434	et	2	main
замыкание	doc_491521501820_item	2505436	et	2	main
c	doc_491521501820_item	2505441	et	4	main
lambipirn	doc_491521501820_item	2505451	et	3	main
liiga	doc_491521501820_item	2505453	et	4	main
kell	doc_491521501821_item	2505471	et	3	main
seitse	doc_491521501821_item	2505472	et	3	main
on	doc_491521501821_item	2505473	et	4	main
just	doc_491521501821_item	2505474	et	3	main
selleks	doc_491521501821_item	2505475	et	4	main
ajaks	doc_491521501821_item	2505476	et	4	main
kohvi	doc_491521501821_item	2505477	et	4	main
keetnud	doc_491521501821_item	2505478	et	4	main
seejärel	doc_491521501821_item	2505479	et	3	main
pistke	doc_491521501821_item	2505480	et	3	main
toit	doc_491521501821_item	2505481	et	3	main
mikrolaineahju	doc_491521501821_item	2505482	et	4	main
küll	doc_491521501821_item	2505483	et	4	main
tark	doc_491521501821_item	2505484	et	3	main
masin	doc_491521501821_item	2505485	et	3	main
ära	doc_491521501821_item	2505486	et	4	main
tunneb	doc_491521501821_item	2505487	et	3	main
kui	doc_491521501821_item	2505488	et	3	main
kaua	doc_491521501821_item	2505489	et	3	main
üht	doc_491521501821_item	2505490	et	3	main
või	doc_491521501821_item	2505491	et	4	main
teist	doc_491521501821_item	2505492	et	4	main
asja	doc_491521501821_item	2505493	et	4	main
valmistada	doc_491521501821_item	2505494	et	3	main
või	doc_491521501821_item	2505495	et	4	main
soojendada	doc_491521501821_item	2505496	et	3	main
samuti	doc_491521501821_item	2505497	et	3	main
жизни	doc_491521501820_item	2505424	et	2	main
ärge	doc_491521501820_item	2505425	et	3	main
see	doc_491521501820_item	2505429	et	3	main
eluohtlik	doc_491521501820_item	2505431	et	3	main
что	doc_491521501820_item	2505437	et	2	main
пожару	doc_491521501820_item	2505440	et	2	main
слишком	doc_491521501820_item	2505444	et	2	main
этой	doc_491521501820_item	2505447	et	2	main
laualambi	doc_491521501820_item	2505456	et	3	main
on	doc_491521501821_item	2505465	et	4	main
saanud	doc_491521501821_item	2505466	et	4	main
äratuskellalt	doc_491521501821_item	2505467	et	3	main
ei	doc_491521501821_item	2505498	et	4	main
monitor	doc_491521501821_item	2505514	et	3	main
külmiku	doc_491521501821_item	2505515	et	3	main
обратно	doc_491521501821_item	2505526	et	2	main
получила	doc_491521501821_item	2505532	et	2	main
вы	doc_491521501821_item	2505537	et	2	main
часов	doc_491521501821_item	2505541	et	2	main
след	doc_491521501821_item	2505548	et	2	main
в	doc_491521501821_item	2505553	et	2	main
ту	doc_491521501821_item	2505560	et	2	main
или	doc_491521501821_item	2505565	et	2	main
в	doc_491521501821_item	2505582	et	2	main
монитор	doc_491521501821_item	2505586	et	2	main
не	doc_491521501821_item	2505592	et	2	main
ümber	doc_491521501821_item	2505599	et	3	main
sihitu	doc_491521501821_item	2505601	et	4	main
sihilist	doc_491521501821_item	2505604	et	4	main
haigestumise	doc_491521501821_item	2505619	et	4	main
risk	doc_491521501821_item	2505620	et	3	main
2	doc_491521501821_item	2505621	et	2	main
spordiga	doc_491521501821_item	2505629	et	3	main
pidevalt	doc_491521501821_item	2505640	et	4	main
keskmist	doc_491521501821_item	2505646	et	3	main
inimesed	doc_491521501821_item	2505650	et	3	main
looduskeskkonda	doc_491521501821_item	2505652	et	4	main
ja	doc_491521501821_item	2505653	et	3	main
tekkib	doc_491521501821_item	2505662	et	3	main
sellega	doc_491521501821_item	2505663	et	3	main
tekivad	doc_491521501821_item	2505668	et	3	main
tekitavad	doc_491521501821_item	2505675	et	4	main
moodustage	doc_491521501821_item	2505678	et	3	main
r-liitelisi	doc_491521501821_item	2505679	et	4	main
nimisõnu	doc_491521501821_item	2505680	et	3	main
tõlkige	doc_491521501821_item	2505681	et	3	main
vedama	doc_491521501821_item	2505682	et	3	main
kallama	doc_491521501821_item	2505683	et	3	main
puhuma	doc_491521501821_item	2505687	et	3	main
kõlama	doc_491521501821_item	2505694	et	3	main
röstima	doc_491521501821_item	2505696	et	3	main
kuvar	doc_491521501821_item	2505700	et	3	main
röster	doc_491521501821_item	2505701	et	3	main
2	doc_491521501821_item	2505704	et	2	main
tõlkige	doc_491521501821_item	2505705	et	3	main
eesti	doc_491521501821_item	2505706	et	4	main
seadmeid	doc_491521501821_item	2505720	et	3	main
on	doc_491521501821_item	2505722	et	4	main
произошло	doc_491521501821_item	2505728	et	2	main
пожару	doc_491521501821_item	2505733	et	2	main
jaoks	doc_491521501821_item	2505756	et	4	main
õhtul	doc_491521501822_item	2505781	et	3	main
sisaldab	doc_491521501822_item	2505785	et	3	main
ml	doc_491521501822_item	2505787	et	4	main
soovitatud	doc_491521501822_item	2505789	et	4	main
riigi	doc_491521501822_item	2505790	et	3	main
eestis	doc_491521501822_item	2505799	et	3	main
keskkonnanõuniku	doc_491521501822_item	2505802	et	3	main
korjata	doc_491521501822_item	2505810	et	4	main
või	doc_491521501822_item	2505817	et	4	main
puudub	doc_491521501822_item	2505822	et	3	main
kui	doc_491521501822_item	2505832	et	3	main
vajadust	doc_491521501822_item	2505835	et	4	main
kokku	doc_491521501822_item	2505837	et	3	main
надо	doc_491521501822_item	2505841	et	2	main
эстонии	doc_491521501822_item	2505844	et	2	main
советника	doc_491521501822_item	2505847	et	2	main
среды	doc_491521501822_item	2505850	et	2	main
к	doc_491521501822_item	2505865	et	2	main
государством	doc_491521501822_item	2505872	et	2	main
rõõsk	doc_491521501821_item	2505503	et	3	main
ole	doc_491521501821_item	2505506	et	4	main
ega	doc_491521501821_item	2505507	et	3	main
kohvi	doc_491521501821_item	2505508	et	4	main
teatab	doc_491521501821_item	2505513	et	3	main
uksel	doc_491521501821_item	2505516	et	3	main
sedagi	doc_491521501821_item	2505518	et	3	main
pole	doc_491521501821_item	2505521	et	3	main
vanaks	doc_491521501821_item	2505523	et	3	main
назад	doc_491521501821_item	2505525	et	2	main
сообщение	doc_491521501821_item	2505533	et	2	main
7	doc_491521501821_item	2505540	et	2	main
сварила	doc_491521501821_item	2505545	et	2	main
положите	doc_491521501821_item	2505551	et	2	main
умная	doc_491521501821_item	2505556	et	2	main
иную	doc_491521501821_item	2505562	et	2	main
покажет	doc_491521501821_item	2505585	et	2	main
то	doc_491521501821_item	2505591	et	2	main
11	doc_491521501821_item	2505596	et	2	main
asemel	doc_491521501821_item	2505603	et	4	main
1	doc_491521501821_item	2505607	et	2	main
haigestumise	doc_491521501821_item	2505611	et	4	main
inimestel	doc_491521501821_item	2505613	et	3	main
tegelemine	doc_491521501821_item	2505623	et	4	main
paraneb	doc_491521501821_item	2505630	et	3	main
tervis	doc_491521501821_item	2505632	et	3	main
keskmine	doc_491521501821_item	2505635	et	3	main
pikenenud	doc_491521501821_item	2505641	et	4	main
uusi	doc_491521501821_item	2505664	et	3	main
paljude	doc_491521501821_item	2505669	et	3	main
paljude	doc_491521501821_item	2505672	et	3	main
siduma	doc_491521501821_item	2505685	et	3	main
helkur	doc_491521501821_item	2505690	et	4	main
a	doc_491521501821_item	2505708	et	4	main
не	doc_491521501821_item	2505709	et	2	main
пользуйтесь	doc_491521501821_item	2505710	et	2	main
неисправными	doc_491521501821_item	2505711	et	2	main
электроприборами	doc_491521501821_item	2505712	et	2	main
опасно	doc_491521501821_item	2505714	et	2	main
жизни	doc_491521501821_item	2505716	et	2	main
ärge	doc_491521501821_item	2505717	et	3	main
rikkis	doc_491521501821_item	2505719	et	3	main
mitte	doc_491521501821_item	2505522	et	3	main
дальше	doc_491521501821_item	2505527	et	2	main
кофеварка	doc_491521501821_item	2505530	et	2	main
что	doc_491521501821_item	2505536	et	2	main
к	doc_491521501821_item	2505542	et	2	main
в	doc_491521501821_item	2505547	et	2	main
еду	doc_491521501821_item	2505552	et	2	main
машина	doc_491521501821_item	2505557	et	2	main
или	doc_491521501821_item	2505561	et	2	main
подогревать	doc_491521501821_item	2505566	et	2	main
тому	doc_491521501821_item	2505568	et	2	main
к	doc_491521501821_item	2505567	et	2	main
же	doc_491521501821_item	2505569	et	2	main
не	doc_491521501821_item	2505570	et	2	main
нужно	doc_491521501821_item	2505571	et	2	main
беспокоиться	doc_491521501821_item	2505572	et	2	main
не	doc_491521501821_item	2505573	et	2	main
скисли	doc_491521501821_item	2505574	et	2	main
ли	doc_491521501821_item	2505575	et	2	main
сливки	doc_491521501821_item	2505576	et	2	main
не	doc_491521501821_item	2505578	et	2	main
и	doc_491521501821_item	2505577	et	2	main
ли	doc_491521501821_item	2505580	et	2	main
свернутся	doc_491521501821_item	2505579	et	2	main
они	doc_491521501821_item	2505581	et	2	main
за	doc_491521501821_item	2505549	et	2	main
микроволновую	doc_491521501821_item	2505554	et	2	main
распознает	doc_491521501821_item	2505558	et	2	main
вещь	doc_491521501821_item	2505563	et	2	main
на	doc_491521501821_item	2505587	et	2	main
испортилась	doc_491521501821_item	2505593	et	2	main
kirjutage	doc_491521501821_item	2505597	et	3	main
kasutades	doc_491521501821_item	2505600	et	3	main
suurendab	doc_491521501821_item	2505610	et	3	main
kes	doc_491521501821_item	2505614	et	4	main
on	doc_491521501821_item	2505615	et	4	main
pidevas	doc_491521501821_item	2505616	et	3	main
stressis	doc_491521501821_item	2505617	et	3	main
suureneb	doc_491521501821_item	2505618	et	3	main
spordiga	doc_491521501821_item	2505622	et	3	main
te	doc_491521501821_item	2505627	et	4	main
eluiga	doc_491521501821_item	2505636	et	4	main
aja	doc_491521501821_item	2505638	et	4	main
tsivilisatsiooni	doc_491521501821_item	2505642	et	4	main
on	doc_491521501821_item	2505644	et	4	main
inimeste	doc_491521501821_item	2505645	et	3	main
pikendanud	doc_491521501821_item	2505648	et	4	main
muudavad	doc_491521501821_item	2505651	et	4	main
haigused	doc_491521501821_item	2505667	et	4	main
tegurite	doc_491521501821_item	2505670	et	3	main
koosmõju	doc_491521501821_item	2505674	et	4	main
haigusi	doc_491521501821_item	2505676	et	4	main
22	doc_491521501821_item	2505677	et	2	main
pidama	doc_491521501821_item	2505686	et	4	main
vedur	doc_491521501821_item	2505688	et	3	main
sidur	doc_491521501821_item	2505691	et	3	main
keelde	doc_491521501821_item	2505707	et	4	main
see	doc_491521501821_item	2505721	et	3	main
в	doc_491521501821_item	2505726	et	2	main
что	doc_491521501821_item	2505730	et	2	main
mis	doc_491521501821_item	2505737	et	4	main
võimas	doc_491521501821_item	2505753	et	4	main
selle	doc_491521501821_item	2505754	et	4	main
laualambi	doc_491521501821_item	2505755	et	3	main
2	doc_491521501822_item	2505793	et	2	main
tänases	doc_491521501822_item	2505798	et	3	main
jäätmekäitlusfirma	doc_491521501822_item	2505801	et	4	main
väitel	doc_491521501822_item	2505803	et	3	main
lisaks	doc_491521501822_item	2505805	et	4	main
ohtlikele	doc_491521501822_item	2505806	et	3	main
jäätmetele	doc_491521501822_item	2505807	et	4	main
mõtet	doc_491521501822_item	2505808	et	3	main
tagasi	doc_491521501822_item	2505815	et	3	main
praegu	doc_491521501822_item	2505821	et	3	main
veel	doc_491521501822_item	2505824	et	4	main
kahjuks	doc_491521501822_item	2505825	et	4	main
olukord	doc_491521501822_item	2505829	et	3	main
loodusressursse	doc_491521501822_item	2505836	et	3	main
hoida	doc_491521501822_item	2505838	et	3	main
отходы	doc_491521501822_item	2505840	et	2	main
в	doc_491521501822_item	2505843	et	2	main
окружающей	doc_491521501822_item	2505849	et	2	main
продать	doc_491521501822_item	2505861	et	2	main
у	doc_491521501822_item	2505867	et	2	main
установленная	doc_491521501822_item	2505871	et	2	main
ситуация	doc_491521501822_item	2505876	et	2	main
начинают	doc_491521501822_item	2505881	et	2	main
ресурсов	doc_491521501822_item	2505886	et	2	main
lauseosa	doc_491521501822_item	2505892	et	4	main
ümber	doc_491521501822_item	2505893	et	3	main
kasutades	doc_491521501822_item	2505894	et	3	main
это	doc_491521501821_item	2505584	et	2	main
холодильника	doc_491521501821_item	2505589	et	2	main
ли	doc_491521501821_item	2505594	et	2	main
tegusõna	doc_491521501821_item	2505602	et	4	main
vastupidi	doc_491521501821_item	2505606	et	3	main
stress	doc_491521501821_item	2505609	et	3	main
riski	doc_491521501821_item	2505612	et	4	main
parandab	doc_491521501821_item	2505624	et	3	main
kui	doc_491521501821_item	2505626	et	3	main
tegelete	doc_491521501821_item	2505628	et	3	main
inimeste	doc_491521501821_item	2505634	et	3	main
areng	doc_491521501821_item	2505643	et	3	main
4	doc_491521501821_item	2505649	et	2	main
5	doc_491521501821_item	2505666	et	2	main
helkima	doc_491521501821_item	2505684	et	3	main
puhur	doc_491521501821_item	2505693	et	3	main
skännima	doc_491521501821_item	2505698	et	4	main
printer	doc_491521501821_item	2505702	et	3	main
это	doc_491521501821_item	2505713	et	2	main
для	doc_491521501821_item	2505715	et	2	main
ohtlik	doc_491521501821_item	2505724	et	3	main
проводке	doc_491521501821_item	2505727	et	2	main
к	doc_491521501821_item	2505732	et	2	main
oli	doc_491521501821_item	2505735	et	3	main
tulekahju	doc_491521501821_item	2505739	et	4	main
c	doc_491521501821_item	2505740	et	4	main
эта	doc_491521501821_item	2505741	et	2	main
лампочка	doc_491521501821_item	2505742	et	2	main
слишком	doc_491521501821_item	2505743	et	2	main
мощная	doc_491521501821_item	2505744	et	2	main
для	doc_491521501821_item	2505745	et	2	main
этой	doc_491521501821_item	2505746	et	2	main
настольной	doc_491521501821_item	2505747	et	2	main
лампы	doc_491521501821_item	2505748	et	2	main
see	doc_491521501821_item	2505749	et	3	main
pirn	doc_491521501821_item	2505750	et	3	main
on	doc_491521501821_item	2505751	et	4	main
eksamitöö	doc_491521501822_item	2505757	et	4	main
1	doc_491521501822_item	2505758	et	2	main
kreemi	doc_491521501822_item	2505779	et	4	main
toimega	doc_491521501822_item	2505783	et	4	main
poolt	doc_491521501822_item	2505792	et	4	main
tõlkige	doc_491521501822_item	2505794	et	3	main
tasub	doc_491521501822_item	2505797	et	3	main
on	doc_491521501822_item	2505804	et	4	main
müüa	doc_491521501822_item	2505816	et	3	main
ära	doc_491521501822_item	2505819	et	4	main
tervist	doc_491521501821_item	2505625	et	4	main
teie	doc_491521501821_item	2505631	et	4	main
3	doc_491521501821_item	2505633	et	2	main
on	doc_491521501821_item	2505637	et	4	main
jooksul	doc_491521501821_item	2505639	et	4	main
eluiga	doc_491521501821_item	2505647	et	4	main
tekitavad	doc_491521501821_item	2505654	et	4	main
sellega	doc_491521501821_item	2505655	et	3	main
uusi	doc_491521501821_item	2505656	et	3	main
probleeme	doc_491521501821_item	2505657	et	3	main
kui	doc_491521501821_item	2505658	et	3	main
looduskeskkond	doc_491521501821_item	2505659	et	3	main
muutub	doc_491521501821_item	2505660	et	3	main
siis	doc_491521501821_item	2505661	et	3	main
probleeme	doc_491521501821_item	2505665	et	3	main
koosmõjul	doc_491521501821_item	2505671	et	3	main
tegurite	doc_491521501821_item	2505673	et	3	main
kallur	doc_491521501821_item	2505689	et	3	main
pidur	doc_491521501821_item	2505692	et	3	main
kuvama	doc_491521501821_item	2505695	et	4	main
printima	doc_491521501821_item	2505697	et	3	main
kõlar	doc_491521501821_item	2505699	et	3	main
skänner	doc_491521501821_item	2505703	et	4	main
kasutage	doc_491521501821_item	2505718	et	3	main
elu	doc_491521501821_item	2505723	et	4	main
привело	doc_491521501821_item	2505731	et	2	main
juhtmes	doc_491521501821_item	2505734	et	3	main
liiga	doc_491521501821_item	2505752	et	4	main
täitke	doc_491521501822_item	2505759	et	3	main
higistavatele	doc_491521501822_item	2505776	et	4	main
jalgadele	doc_491521501822_item	2505777	et	3	main
määrige	doc_491521501822_item	2505778	et	3	main
antibakteriaalse	doc_491521501822_item	2505782	et	4	main
tuub	doc_491521501822_item	2505784	et	3	main
150	doc_491521501822_item	2505786	et	2	main
kreemi	doc_491521501822_item	2505788	et	4	main
missuguseid	doc_491521501822_item	2505795	et	3	main
jäätmeid	doc_491521501822_item	2505796	et	3	main
välja	doc_491521501822_item	2505809	et	4	main
korraldatud	doc_491521501822_item	2505827	et	4	main
taaskasutussüsteem	doc_491521501822_item	2505828	et	3	main
hakatakse	doc_491521501822_item	2505833	et	3	main
какие	doc_491521501822_item	2505839	et	2	main
сортировать	doc_491521501822_item	2505842	et	2	main
утверждению	doc_491521501822_item	2505846	et	2	main
сбытом	doc_491521501822_item	2505853	et	2	main
сейчас	doc_491521501822_item	2505864	et	2	main
еще	doc_491521501822_item	2505869	et	2	main
переработки	doc_491521501822_item	2505874	et	2	main
изменится	doc_491521501822_item	2505878	et	2	main
осознавать	doc_491521501822_item	2505882	et	2	main
tav-	doc_491521501822_item	2505895	et	4	main
kesksõna	doc_491521501822_item	2505896	et	4	main
pöörake	doc_491521501822_item	2505897	et	4	main
tähelepanu	doc_491521501822_item	2505898	et	4	main
sõnajärjele	doc_491521501822_item	2505899	et	3	main
1	doc_491521501822_item	2505900	et	2	main
põrand	doc_491521501822_item	2505901	et	3	main
peab	doc_491521501822_item	2505905	et	4	main
vastu	doc_491521501822_item	2505907	et	3	main
a	doc_491521501822_item	2505908	et	4	main
tihti	doc_491521501822_item	2505909	et	3	main
puhastatav	doc_491521501822_item	2505910	et	4	main
põrand	doc_491521501822_item	2505911	et	3	main
peab	doc_491521501822_item	2505912	et	4	main
2	doc_491521501822_item	2505922	et	2	main
peab	doc_491521501822_item	2505924	et	4	main
olema	doc_491521501822_item	2505925	et	4	main
korgiga	doc_491521501822_item	2505926	et	3	main
šampoonipudel	doc_491521501822_item	2505932	et	2	main
tagavaraks	doc_491521501822_item	2505945	et	3	main
a	doc_491521501822_item	2505946	et	4	main
tihti	doc_491521501822_item	2505947	et	3	main
kasutatavaid	doc_491521501822_item	2505948	et	4	main
keemiavahendeid	doc_491521501822_item	2505949	et	3	main
tasub	doc_491521501822_item	2505950	et	3	main
osta	doc_491521501822_item	2505951	et	4	main
tagavaraks	doc_491521501822_item	2505952	et	3	main
4	doc_491521501822_item	2505953	et	2	main
kreemidele	doc_491521501822_item	2505954	et	3	main
mida	doc_491521501822_item	2505955	et	4	main
toodetakse	doc_491521501822_item	2505956	et	3	main
tasu	doc_491521501822_item	2505959	et	4	main
a	doc_491521501822_item	2505980	et	4	main
inimesed	doc_491521501822_item	2505985	et	3	main
mida	doc_491521501822_item	2505991	et	4	main
kaupadesse	doc_491521501822_item	2506000	et	3	main
suhtuda	doc_491521501822_item	2506002	et	3	main
kaupu	doc_491521501822_item	2506008	et	3	main
ostan	doc_491521501822_item	2506014	et	3	main
mida	doc_491521501822_item	2506021	et	4	main
käsitsi	doc_491521501822_item	2506023	et	3	main
pestav	doc_491521501822_item	2506030	et	4	main
ei	doc_491521501822_item	2506032	et	4	main
b	doc_491521501821_item	2505725	et	4	main
замыкание	doc_491521501821_item	2505729	et	2	main
lühis	doc_491521501821_item	2505736	et	4	main
tekitas	doc_491521501821_item	2505738	et	3	main
lüngad	doc_491521501822_item	2505760	et	3	main
kergesti	doc_491521501822_item	2505761	et	3	main
määritav	doc_491521501822_item	2505762	et	4	main
jalakreem	doc_491521501822_item	2505763	et	3	main
niisutav	doc_491521501822_item	2505764	et	4	main
toitev	doc_491521501822_item	2505766	et	4	main
ja	doc_491521501822_item	2505765	et	3	main
kreem	doc_491521501822_item	2505767	et	3	main
muudab	doc_491521501822_item	2505768	et	3	main
kõvenenud	doc_491521501822_item	2505769	et	4	main
naha	doc_491521501822_item	2505770	et	3	main
pehmeks	doc_491521501822_item	2505771	et	3	main
ja	doc_491521501822_item	2505772	et	3	main
kergesti	doc_491521501822_item	2505773	et	3	main
eemaldatavaks	doc_491521501822_item	2505774	et	4	main
palju	doc_491521501822_item	2505775	et	4	main
igal	doc_491521501822_item	2505780	et	3	main
tervisekaitseinspektsiooni	doc_491521501822_item	2505791	et	4	main
sorteerida	doc_491521501822_item	2505800	et	3	main
praht	doc_491521501822_item	2505811	et	3	main
mida	doc_491521501822_item	2505812	et	4	main
saab	doc_491521501822_item	2505813	et	3	main
kas	doc_491521501822_item	2505814	et	3	main
eraldi	doc_491521501822_item	2505818	et	4	main
anda	doc_491521501822_item	2505820	et	3	main
meil	doc_491521501822_item	2505823	et	4	main
muutub	doc_491521501822_item	2505831	et	3	main
teadvustama	doc_491521501822_item	2505834	et	3	main
по	doc_491521501822_item	2505845	et	2	main
занимающейся	doc_491521501822_item	2505852	et	2	main
или	doc_491521501822_item	2505862	et	2	main
сожалению	doc_491521501822_item	2505866	et	2	main
отсуствует	doc_491521501822_item	2505870	et	2	main
мусора	doc_491521501822_item	2505875	et	2	main
так	doc_491521501822_item	2505879	et	2	main
необходимость	doc_491521501822_item	2505883	et	2	main
kirjutage	doc_491521501822_item	2505889	et	3	main
tihti	doc_491521501822_item	2505903	et	3	main
kauem	doc_491521501822_item	2505906	et	4	main
kergesti	doc_491521501822_item	2505929	et	3	main
kergesti	doc_491521501822_item	2505935	et	3	main
3	doc_491521501822_item	2505938	et	2	main
keemiavahendeid	doc_491521501822_item	2505939	et	3	main
mida	doc_491521501822_item	2505940	et	4	main
tihti	doc_491521501822_item	2505941	et	3	main
kasutatakse	doc_491521501822_item	2505942	et	3	main
tasub	doc_491521501822_item	2505943	et	3	main
raha	doc_491521501822_item	2505960	et	4	main
välismaal	doc_491521501822_item	2505963	et	4	main
kreemidele	doc_491521501822_item	2505965	et	3	main
kulutada	doc_491521501822_item	2505969	et	3	main
loosisedelitega	doc_491521501822_item	2505971	et	3	main
kaubale	doc_491521501822_item	2505973	et	3	main
võidavad	doc_491521501822_item	2505975	et	4	main
inimesed	doc_491521501822_item	2505976	et	3	main
kaubale	doc_491521501822_item	2505981	et	3	main
võidavad	doc_491521501822_item	2505984	et	4	main
tasub	doc_491521501822_item	2505994	et	3	main
suhtuda	doc_491521501822_item	2505995	et	3	main
umbusklikult	doc_491521501822_item	2505996	et	4	main
reklaamitavatesse	doc_491521501822_item	2505999	et	4	main
7	doc_491521501822_item	2506004	et	2	main
ostan	doc_491521501822_item	2506006	et	3	main
riiklikult	doc_491521501822_item	2505826	et	4	main
kindlasti	doc_491521501822_item	2505830	et	3	main
по	doc_491521501822_item	2505848	et	2	main
фирмы	doc_491521501822_item	2505851	et	2	main
мусора	doc_491521501822_item	2505854	et	2	main
есть	doc_491521501822_item	2505855	et	2	main
смысл	doc_491521501822_item	2505856	et	2	main
мусор	doc_491521501822_item	2505858	et	2	main
собирать	doc_491521501822_item	2505857	et	2	main
который	doc_491521501822_item	2505859	et	2	main
впоследствие	doc_491521501822_item	2505860	et	2	main
сдать	doc_491521501822_item	2505863	et	2	main
нас	doc_491521501822_item	2505868	et	2	main
система	doc_491521501822_item	2505873	et	2	main
как	doc_491521501822_item	2505880	et	2	main
природных	doc_491521501822_item	2505885	et	2	main
a	doc_491521501822_item	2505888	et	4	main
mida	doc_491521501822_item	2505902	et	4	main
šampoonipudel	doc_491521501822_item	2505923	et	2	main
avada	doc_491521501822_item	2505930	et	3	main
osta	doc_491521501822_item	2505944	et	4	main
välismaal	doc_491521501822_item	2505957	et	4	main
a	doc_491521501822_item	2505962	et	4	main
ei	doc_491521501822_item	2505966	et	4	main
tasu	doc_491521501822_item	2505967	et	4	main
asju	doc_491521501822_item	2505979	et	3	main
pidevalt	doc_491521501822_item	2505992	et	4	main
pidevalt	doc_491521501822_item	2505998	et	4	main
tasub	doc_491521501822_item	2506001	et	3	main
umusklikult	doc_491521501822_item	2506003	et	4	main
müüakse	doc_491521501822_item	2506010	et	3	main
turul	doc_491521501822_item	2506011	et	3	main
käsitsi	doc_491521501822_item	2506029	et	3	main
kulu	doc_491521501822_item	2506033	et	4	main
arsti	doc_491521501822_item	2506046	et	4	main
millal	doc_491521501822_item	2506066	et	3	main
millal	doc_491521501822_item	2506071	et	3	main
sinu	doc_491521501822_item	2506073	et	3	main
tuleb	doc_491521501822_item	2506091	et	3	main
tema	doc_491521501822_item	2506098	et	4	main
on	doc_491521501822_item	2506109	et	4	main
tema	doc_491521501822_item	2506110	et	4	main
jaoks	doc_491521501822_item	2506111	et	4	main
see	doc_491521501822_item	2506112	et	3	main
arst	doc_491521501822_item	2506123	et	3	main
retsepti	doc_491521501822_item	2506125	et	4	main
7	doc_491521501822_item	2506127	et	2	main
nad	doc_491521501822_item	2506128	et	3	main
saavad	doc_491521501822_item	2506129	et	4	main
hakkama	doc_491521501822_item	2506130	et	3	main
sellega	doc_491521501822_item	2506131	et	3	main
nad	doc_491521501822_item	2506132	et	3	main
saavad	doc_491521501822_item	2506133	et	4	main
sobimatud	doc_491521501822_item	2506144	et	4	main
lagunenud	doc_491521501822_item	2506151	et	4	main
mida	doc_491521501822_item	2506163	et	4	main
eest	doc_491521501822_item	2506174	et	4	main
keelustatakse	doc_491521501822_item	2506175	et	3	main
kehtestatakse	doc_491521501822_item	2506176	et	3	main
tõhus	doc_491521501822_item	2506187	et	4	main
kindlasti	doc_491521501822_item	2506192	et	3	main
teadvustama	doc_491521501822_item	2506199	et	3	main
tulemusi	doc_491521501822_item	2506204	et	4	main
kardan	doc_491521501822_item	2506207	et	4	main
et	doc_491521501822_item	2506208	et	3	main
raske	doc_491521501822_item	2506212	et	4	main
teostada	doc_491521501822_item	2506215	et	3	main
vedama	doc_491521501822_item	2506231	et	3	main
kõlar-	doc_491521501822_item	2506234	et	3	main
helkima	doc_491521501822_item	2506242	et	3	main
рестер	doc_491521501822_item	2506246	et	2	main
siduma	doc_491521501822_item	2506248	et	3	main
printima	doc_491521501822_item	2506251	et	3	main
pidama	doc_491521501822_item	2506254	et	4	main
skännima	doc_491521501822_item	2506257	et	4	main
ootab	doc_491521501823_item	2506270	et	3	main
ees	doc_491521501823_item	2506272	et	4	main
õhtust	doc_491521501823_item	2506276	et	4	main
kibuvitsapõõsale	doc_491521501823_item	2506289	et	4	main
uks	doc_491521501823_item	2506294	et	3	main
on	doc_491521501823_item	2506307	et	4	main
mahedalt	doc_491521501823_item	2506309	et	4	main
ei	doc_491521501823_item	2506314	et	4	main
ahjusoe	doc_491521501823_item	2506323	et	4	main
õhtu	doc_491521501823_item	2506328	et	4	main
pole	doc_491521501823_item	2506330	et	3	main
нас	doc_491521501823_item	2506332	et	2	main
таки	doc_491521501823_item	2506334	et	2	main
светлое	doc_491521501823_item	2506336	et	2	main
представления	doc_491521501823_item	2506341	et	2	main
по	doc_491521501823_item	2506347	et	2	main
на	doc_491521501823_item	2506353	et	2	main
неприменно	doc_491521501822_item	2505877	et	2	main
сохранения	doc_491521501822_item	2505884	et	2	main
11	doc_491521501822_item	2505887	et	2	main
paksus	doc_491521501822_item	2505890	et	4	main
kirjas	doc_491521501822_item	2505891	et	4	main
puhastatakse	doc_491521501822_item	2505904	et	3	main
kauem	doc_491521501822_item	2505913	et	4	main
vastu	doc_491521501822_item	2505914	et	3	main
b	doc_491521501822_item	2505915	et	4	main
tihti	doc_491521501822_item	2505916	et	3	main
puhastatav	doc_491521501822_item	2505917	et	4	main
põrand	doc_491521501822_item	2505918	et	3	main
kulub	doc_491521501822_item	2505919	et	3	main
rutem	doc_491521501822_item	2505920	et	3	main
ära	doc_491521501822_item	2505921	et	4	main
mida	doc_491521501822_item	2505927	et	4	main
a	doc_491521501822_item	2505931	et	4	main
olema	doc_491521501822_item	2505934	et	4	main
kulutada	doc_491521501822_item	2505961	et	3	main
raha	doc_491521501822_item	2505968	et	4	main
5	doc_491521501822_item	2505970	et	2	main
mis	doc_491521501822_item	2505972	et	4	main
lisatakse	doc_491521501822_item	2505974	et	4	main
vahel	doc_491521501822_item	2505977	et	4	main
loosisedelitega	doc_491521501822_item	2505983	et	3	main
vahel	doc_491521501822_item	2505986	et	4	main
hinnalisi	doc_491521501822_item	2505987	et	4	main
asju	doc_491521501822_item	2505988	et	3	main
6	doc_491521501822_item	2505989	et	2	main
kaupadesse	doc_491521501822_item	2505990	et	3	main
a	doc_491521501822_item	2505997	et	4	main
mida	doc_491521501822_item	2506009	et	4	main
a	doc_491521501822_item	2506012	et	4	main
pesu	doc_491521501822_item	2506031	et	4	main
läheb	doc_491521501822_item	2506045	et	3	main
3	doc_491521501822_item	2506065	et	2	main
4	doc_491521501822_item	2506076	et	2	main
juurde	doc_491521501822_item	2506084	et	4	main
nakkav	doc_491521501822_item	2506088	et	4	main
teie	doc_491521501822_item	2506092	et	4	main
juurde	doc_491521501822_item	2506093	et	4	main
koju	doc_491521501822_item	2506094	et	3	main
5	doc_491521501822_item	2506095	et	2	main
jaoks	doc_491521501822_item	2506099	et	4	main
voodis	doc_491521501822_item	2506104	et	3	main
peab	doc_491521501822_item	2506115	et	4	main
voodis	doc_491521501822_item	2506116	et	3	main
6	doc_491521501822_item	2506118	et	2	main
arst	doc_491521501822_item	2506119	et	3	main
välja	doc_491521501822_item	2506120	et	4	main
saab	doc_491521501822_item	2505928	et	3	main
peab	doc_491521501822_item	2505933	et	4	main
avatava	doc_491521501822_item	2505936	et	4	main
korgiga	doc_491521501822_item	2505937	et	3	main
ei	doc_491521501822_item	2505958	et	4	main
toodetavatele	doc_491521501822_item	2505964	et	4	main
hinnalisi	doc_491521501822_item	2505978	et	4	main
lisatavate	doc_491521501822_item	2505982	et	4	main
reklaamitakse	doc_491521501822_item	2505993	et	4	main
ma	doc_491521501822_item	2506005	et	3	main
tihti	doc_491521501822_item	2506007	et	3	main
ma	doc_491521501822_item	2506013	et	3	main
tihti	doc_491521501822_item	2506015	et	3	main
turul	doc_491521501822_item	2506016	et	3	main
müüdavaid	doc_491521501822_item	2506017	et	4	main
8	doc_491521501822_item	2506019	et	2	main
pesu	doc_491521501822_item	2506020	et	4	main
kaupu	doc_491521501822_item	2506018	et	3	main
kulu	doc_491521501822_item	2506025	et	4	main
sõnajärjevead	doc_491521501822_item	2506038	et	3	main
põhjendage	doc_491521501822_item	2506039	et	3	main
parandust	doc_491521501822_item	2506040	et	4	main
1	doc_491521501822_item	2506041	et	2	main
minu	doc_491521501822_item	2506042	et	3	main
tütar	doc_491521501822_item	2506043	et	3	main
homme	doc_491521501822_item	2506044	et	3	main
tütar	doc_491521501822_item	2506049	et	3	main
arsti	doc_491521501822_item	2506052	et	4	main
2	doc_491521501822_item	2506054	et	2	main
sinu	doc_491521501822_item	2506069	et	3	main
teie	doc_491521501822_item	2506083	et	4	main
on	doc_491521501822_item	2506087	et	4	main
haigus	doc_491521501822_item	2506089	et	4	main
arst	doc_491521501822_item	2506090	et	3	main
see	doc_491521501822_item	2506101	et	3	main
kõige	doc_491521501822_item	2506107	et	4	main
et	doc_491521501822_item	2506113	et	3	main
ta	doc_491521501822_item	2506114	et	4	main
kirjutab	doc_491521501822_item	2506121	et	3	main
hakkama	doc_491521501822_item	2506135	et	3	main
aegunud	doc_491521501822_item	2506150	et	4	main
saate	doc_491521501822_item	2506168	et	4	main
silmas	doc_491521501822_item	2506169	et	4	main
rangemad	doc_491521501822_item	2506178	et	4	main
sellega	doc_491521501822_item	2506189	et	3	main
e	doc_491521501822_item	2506194	et	4	main
peaksid	doc_491521501822_item	2506196	et	4	main
rohkem	doc_491521501822_item	2506198	et	4	main
seda	doc_491521501822_item	2506209	et	3	main
liigitada	doc_491521501822_item	2506213	et	3	main
g	doc_491521501822_item	2506216	et	4	main
linna	doc_491521501822_item	2506217	et	4	main
heakord	doc_491521501822_item	2506218	et	3	main
on	doc_491521501822_item	2506219	et	4	main
viimase	doc_491521501822_item	2506220	et	3	main
pestakse	doc_491521501822_item	2506022	et	3	main
ei	doc_491521501822_item	2506024	et	4	main
nii	doc_491521501822_item	2506026	et	3	main
kiiresti	doc_491521501822_item	2506027	et	3	main
a	doc_491521501822_item	2506028	et	4	main
minu	doc_491521501822_item	2506048	et	3	main
läheb	doc_491521501822_item	2506050	et	3	main
ta	doc_491521501822_item	2506055	et	4	main
on	doc_491521501822_item	2506056	et	4	main
terveks	doc_491521501822_item	2506057	et	4	main
saanud	doc_491521501822_item	2506058	et	4	main
juba	doc_491521501822_item	2506059	et	3	main
ta	doc_491521501822_item	2506060	et	4	main
on	doc_491521501822_item	2506061	et	4	main
juba	doc_491521501822_item	2506062	et	3	main
terveks	doc_491521501822_item	2506063	et	4	main
saanud	doc_491521501822_item	2506064	et	4	main
nii	doc_491521501822_item	2506034	et	3	main
kiiresti	doc_491521501822_item	2506035	et	3	main
17	doc_491521501822_item	2506036	et	2	main
parandage	doc_491521501822_item	2506037	et	3	main
juurde	doc_491521501822_item	2506047	et	4	main
homme	doc_491521501822_item	2506051	et	3	main
juurde	doc_491521501822_item	2506053	et	4	main
haigeks	doc_491521501822_item	2506067	et	4	main
tütar	doc_491521501822_item	2506070	et	3	main
jäi	doc_491521501822_item	2506072	et	3	main
tütar	doc_491521501822_item	2506074	et	3	main
see	doc_491521501822_item	2506077	et	3	main
on	doc_491521501822_item	2506079	et	4	main
nakkav	doc_491521501822_item	2506080	et	4	main
arst	doc_491521501822_item	2506081	et	3	main
tuleb	doc_491521501822_item	2506082	et	3	main
see	doc_491521501822_item	2506086	et	3	main
raskem	doc_491521501822_item	2506097	et	4	main
on	doc_491521501822_item	2506100	et	4	main
ta	doc_491521501822_item	2506103	et	4	main
peab	doc_491521501822_item	2506105	et	4	main
lamama	doc_491521501822_item	2506106	et	4	main
missugune	doc_491521501822_item	2506137	et	3	main
sõnad	doc_491521501822_item	2506145	et	4	main
maha	doc_491521501822_item	2506146	et	4	main
läbi	doc_491521501822_item	2506152	et	4	main
peate	doc_491521501822_item	2506170	et	4	main
kahjustatakse	doc_491521501822_item	2506177	et	3	main
ja	doc_491521501822_item	2506188	et	3	main
inimesed	doc_491521501822_item	2506195	et	3	main
endale	doc_491521501822_item	2506197	et	4	main
reostamise	doc_491521501822_item	2506201	et	4	main
tagajärgi	doc_491521501822_item	2506203	et	4	main
f	doc_491521501822_item	2506205	et	4	main
ma	doc_491521501822_item	2506206	et	3	main
aastaga	doc_491521501822_item	2506221	et	3	main
r-liitelisi	doc_491521501822_item	2506228	et	4	main
nimisõnu	doc_491521501822_item	2506229	et	3	main
vedur	doc_491521501822_item	2506232	et	3	main
kallama	doc_491521501822_item	2506236	et	3	main
kuvar	doc_491521501822_item	2506239	et	3	main
helkur-светоотражатель	doc_491521501822_item	2506243	et	2	main
руль	doc_491521501822_item	2506250	et	2	main
pidur	doc_491521501822_item	2506255	et	3	main
skänner	doc_491521501822_item	2506258	et	4	main
сканер	doc_491521501822_item	2506259	et	2	main
puhuma	doc_491521501822_item	2506260	et	3	main
puhur	doc_491521501822_item	2506261	et	3	main
обогревающее	doc_491521501822_item	2506262	et	2	main
охлаждающее	doc_491521501822_item	2506264	et	2	main
eksamitöö	doc_491521501823_item	2506266	et	4	main
1tõlkige	doc_491521501823_item	2506267	et	3	main
meid	doc_491521501823_item	2506271	et	4	main
helge	doc_491521501823_item	2506273	et	4	main
tuled	doc_491521501823_item	2506285	et	4	main
ei	doc_491521501823_item	2506291	et	4	main
ja	doc_491521501823_item	2506303	et	3	main
süüdatud	doc_491521501823_item	2506311	et	4	main
kuid	doc_491521501823_item	2506312	et	4	main
see	doc_491521501823_item	2506313	et	3	main
veel	doc_491521501823_item	2506316	et	4	main
kas	doc_491521501823_item	2506329	et	3	main
jäi	doc_491521501822_item	2506068	et	3	main
haigeks	doc_491521501822_item	2506075	et	4	main
haigus	doc_491521501822_item	2506078	et	4	main
koju	doc_491521501822_item	2506085	et	3	main
kõige	doc_491521501822_item	2506096	et	4	main
et	doc_491521501822_item	2506102	et	3	main
raskem	doc_491521501822_item	2506108	et	4	main
lamama	doc_491521501822_item	2506117	et	4	main
retsepti	doc_491521501822_item	2506122	et	4	main
kirjutab	doc_491521501822_item	2506124	et	3	main
välja	doc_491521501822_item	2506126	et	4	main
12	doc_491521501822_item	2506136	et	2	main
paksus	doc_491521501822_item	2506138	et	4	main
sõna	doc_491521501822_item	2506140	et	4	main
sobib	doc_491521501822_item	2506141	et	3	main
lausesse	doc_491521501822_item	2506142	et	4	main
kriipsutage	doc_491521501822_item	2506143	et	3	main
visake	doc_491521501822_item	2506149	et	4	main
te	doc_491521501822_item	2506164	et	4	main
pilku	doc_491521501822_item	2506165	et	4	main
püüate	doc_491521501822_item	2506166	et	3	main
lahti	doc_491521501822_item	2506167	et	4	main
prügi	doc_491521501822_item	2506172	et	4	main
mahaviskamise	doc_491521501822_item	2506173	et	3	main
vaev	doc_491521501822_item	2506182	et	3	main
vahend	doc_491521501822_item	2506183	et	3	main
viil	doc_491521501822_item	2506184	et	3	main
on	doc_491521501822_item	2506185	et	4	main
väga	doc_491521501822_item	2506186	et	3	main
vaiba	doc_491521501822_item	2506191	et	3	main
puhtaks	doc_491521501822_item	2506193	et	3	main
looduskeskkonna	doc_491521501822_item	2506200	et	3	main
on	doc_491521501822_item	2506211	et	4	main
sisaldada	doc_491521501822_item	2506214	et	3	main
tõlkige	doc_491521501822_item	2506230	et	3	main
kõlama	doc_491521501822_item	2506233	et	3	main
колонка	doc_491521501822_item	2506235	et	2	main
röster	doc_491521501822_item	2506245	et	3	main
принтер	doc_491521501822_item	2506253	et	2	main
ometi	doc_491521501823_item	2506269	et	3	main
pärast	doc_491521501823_item	2506275	et	4	main
teatrietendust	doc_491521501823_item	2506277	et	3	main
autoga	doc_491521501823_item	2506278	et	3	main
koju	doc_491521501823_item	2506279	et	3	main
saabudes	doc_491521501823_item	2506280	et	3	main
põlema	doc_491521501823_item	2506286	et	4	main
et	doc_491521501823_item	2506287	et	3	main
garaaži	doc_491521501823_item	2506293	et	2	main
kätte	doc_491521501823_item	2506301	et	4	main
kaminas	doc_491521501823_item	2506304	et	3	main
tuli	doc_491521501823_item	2506308	et	4	main
põlema	doc_491521501823_item	2506310	et	4	main
üllatus	doc_491521501823_item	2506318	et	4	main
köögis	doc_491521501823_item	2506321	et	3	main
tõotab	doc_491521501823_item	2506325	et	3	main
tulla	doc_491521501823_item	2506326	et	3	main
театрального	doc_491521501823_item	2506340	et	2	main
на	doc_491521501823_item	2506343	et	2	main
сами	doc_491521501823_item	2506346	et	2	main
включаться	doc_491521501823_item	2506349	et	2	main
не	doc_491521501823_item	2506355	et	2	main
сама	doc_491521501823_item	2506360	et	2	main
не	doc_491521501823_item	2506363	et	2	main
улицу	doc_491521501823_item	2506367	et	2	main
дождь	doc_491521501823_item	2506370	et	2	main
огонь	doc_491521501823_item	2506375	et	2	main
это	doc_491521501823_item	2506379	et	2	main
и	doc_491521501823_item	2506385	et	2	main
духовки	doc_491521501823_item	2506390	et	2	main
вечер	doc_491521501823_item	2506395	et	2	main
kiirendama	doc_491521501823_item	2506404	et	3	main
innustama	doc_491521501823_item	2506406	et	3	main
jahutama	doc_491521501823_item	2506423	et	3	main
lõõgastama	doc_491521501823_item	2506429	et	3	main
tekitama	doc_491521501823_item	2506431	et	4	main
avalduma	doc_491521501823_item	2506432	et	3	main
väljendite	doc_491521501823_item	2506439	et	3	main
tuleb	doc_491521501823_item	2506442	et	3	main
2	doc_491521501823_item	2506446	et	2	main
käib	doc_491521501823_item	2506447	et	3	main
asja	doc_491521501823_item	2506448	et	4	main
sellega	doc_491521501822_item	2506134	et	3	main
kirjas	doc_491521501822_item	2506139	et	4	main
alla	doc_491521501822_item	2506147	et	3	main
a	doc_491521501822_item	2506148	et	4	main
põlenud	doc_491521501822_item	2506153	et	4	main
ravimid	doc_491521501822_item	2506154	et	3	main
ära	doc_491521501822_item	2506155	et	4	main
b	doc_491521501822_item	2506156	et	4	main
ma	doc_491521501822_item	2506157	et	3	main
ei	doc_491521501822_item	2506158	et	4	main
saanud	doc_491521501822_item	2506159	et	4	main
päris	doc_491521501822_item	2506160	et	4	main
täpselt	doc_491521501822_item	2506161	et	4	main
aru	doc_491521501822_item	2506162	et	4	main
c	doc_491521501822_item	2506171	et	4	main
trahvid	doc_491521501822_item	2506179	et	4	main
d	doc_491521501822_item	2506180	et	4	main
see	doc_491521501822_item	2506181	et	3	main
saate	doc_491521501822_item	2506190	et	4	main
järeldusi	doc_491521501822_item	2506202	et	4	main
plaani	doc_491521501822_item	2506210	et	4	main
ohtralt	doc_491521501822_item	2506223	et	4	main
esialgu	doc_491521501822_item	2506224	et	3	main
muutunud	doc_491521501822_item	2506225	et	4	main
22	doc_491521501822_item	2506226	et	2	main
moodustage	doc_491521501822_item	2506227	et	3	main
kuvama	doc_491521501822_item	2506238	et	4	main
машина	doc_491521501822_item	2506241	et	2	main
röstima	doc_491521501822_item	2506244	et	3	main
printer	doc_491521501822_item	2506252	et	3	main
viimaks	doc_491521501823_item	2506268	et	4	main
maja	doc_491521501823_item	2506282	et	4	main
iseenesest	doc_491521501823_item	2506284	et	4	main
otsa	doc_491521501823_item	2506290	et	4	main
avaneb	doc_491521501823_item	2506295	et	3	main
ilma	doc_491521501823_item	2506296	et	4	main
tuleks	doc_491521501823_item	2506298	et	4	main
astuda	doc_491521501823_item	2506302	et	3	main
näe	doc_491521501823_item	2506305	et	4	main
ole	doc_491521501823_item	2506315	et	4	main
ka	doc_491521501823_item	2506320	et	3	main
hõrgutav	doc_491521501823_item	2506322	et	4	main
õunakook	doc_491521501823_item	2506324	et	3	main
romantiline	doc_491521501823_item	2506327	et	3	main
ждёт	doc_491521501823_item	2506331	et	2	main
всё	doc_491521501823_item	2506333	et	2	main
впереди	doc_491521501823_item	2506335	et	2	main
будущее	doc_491521501823_item	2506337	et	2	main
машине	doc_491521501823_item	2506344	et	2	main
чтоб	doc_491521501823_item	2506351	et	2	main
дверь	doc_491521501823_item	2506357	et	2	main
что	doc_491521501823_item	2506362	et	2	main
под	doc_491521501823_item	2506368	et	2	main
камине	doc_491521501823_item	2506372	et	2	main
хотя	doc_491521501823_item	2506378	et	2	main
ждет	doc_491521501823_item	2506384	et	2	main
яблочный	doc_491521501823_item	2506391	et	2	main
разве	doc_491521501823_item	2506396	et	2	main
tabeli	doc_491521501823_item	2506400	et	3	main
arendama	doc_491521501823_item	2506408	et	3	main
aeglustama	doc_491521501823_item	2506421	et	3	main
toetuma	doc_491521501823_item	2506424	et	4	main
toetama	doc_491521501823_item	2506425	et	3	main
21	doc_491521501823_item	2506436	et	2	main
leidke	doc_491521501823_item	2506437	et	3	main
paarid	doc_491521501823_item	2506440	et	4	main
b	doc_491521501823_item	2506450	et	4	main
astub	doc_491521501823_item	2506451	et	3	main
külmaks	doc_491521501823_item	2506455	et	4	main
täiesti	doc_491521501823_item	2506457	et	3	main
vead	doc_491521501823_item	2506489	et	4	main
nad	doc_491521501823_item	2506508	et	3	main
kiiresti	doc_491521501823_item	2506509	et	3	main
nad	doc_491521501823_item	2506513	et	3	main
tunduvalt	doc_491521501822_item	2506222	et	4	main
kallur	doc_491521501822_item	2506237	et	3	main
грузовая	doc_491521501822_item	2506240	et	2	main
тостер	doc_491521501822_item	2506247	et	2	main
sidur	doc_491521501822_item	2506249	et	3	main
тормоз	doc_491521501822_item	2506256	et	2	main
или	doc_491521501822_item	2506263	et	2	main
устройство	doc_491521501822_item	2506265	et	2	main
tulevik	doc_491521501823_item	2506274	et	3	main
lähevad	doc_491521501823_item	2506281	et	3	main
ees	doc_491521501823_item	2506283	et	4	main
me	doc_491521501823_item	2506288	et	4	main
sõidaks	doc_491521501823_item	2506292	et	3	main
et	doc_491521501823_item	2506297	et	3	main
õue	doc_491521501823_item	2506299	et	4	main
paduvihma	doc_491521501823_item	2506300	et	4	main
imet	doc_491521501823_item	2506306	et	3	main
kõik	doc_491521501823_item	2506317	et	4	main
ootab	doc_491521501823_item	2506319	et	3	main
после	doc_491521501823_item	2506338	et	2	main
прибыв	doc_491521501823_item	2506342	et	2	main
огни	doc_491521501823_item	2506350	et	2	main
шиповник	doc_491521501823_item	2506354	et	2	main
откроется	doc_491521501823_item	2506359	et	2	main
нужно	doc_491521501823_item	2506364	et	2	main
проливной	doc_491521501823_item	2506369	et	2	main
диво	doc_491521501823_item	2506374	et	2	main
разажён	doc_491521501823_item	2506377	et	2	main
всё	doc_491521501823_item	2506382	et	2	main
на	doc_491521501823_item	2506386	et	2	main
из	doc_491521501823_item	2506389	et	2	main
романтичный	doc_491521501823_item	2506394	et	2	main
22	doc_491521501823_item	2506398	et	2	main
kiirenema	doc_491521501823_item	2506403	et	3	main
innustuma	doc_491521501823_item	2506405	et	3	main
вечерного	doc_491521501823_item	2506339	et	2	main
домой	doc_491521501823_item	2506345	et	2	main
себе	doc_491521501823_item	2506348	et	2	main
мы	doc_491521501823_item	2506352	et	2	main
гаража	doc_491521501823_item	2506358	et	2	main
выходить	doc_491521501823_item	2506365	et	2	main
в	doc_491521501823_item	2506371	et	2	main
приглушенно	doc_491521501823_item	2506376	et	2	main
не	doc_491521501823_item	2506381	et	2	main
пышущий	doc_491521501823_item	2506388	et	2	main
торопиться	doc_491521501823_item	2506393	et	2	main
täitke	doc_491521501823_item	2506399	et	3	main
teine	doc_491521501823_item	2506401	et	3	main
arenema	doc_491521501823_item	2506407	et	3	main
kosutama	doc_491521501823_item	2506410	et	4	main
h	doc_491521501823_item	2506412	et	4	main
alvendama	doc_491521501823_item	2506413	et	4	main
langema	doc_491521501823_item	2506414	et	3	main
venima	doc_491521501823_item	2506418	et	3	main
venitama	doc_491521501823_item	2506419	et	4	main
aeglustuma	doc_491521501823_item	2506420	et	3	main
jahtuma	doc_491521501823_item	2506422	et	3	main
nakkama	doc_491521501823_item	2506434	et	3	main
mängu	doc_491521501823_item	2506443	et	4	main
a	doc_491521501823_item	2506444	et	4	main
lõdvestab	doc_491521501823_item	2506445	et	3	main
tegevusse	doc_491521501823_item	2506452	et	4	main
c	doc_491521501823_item	2506456	et	4	main
4	doc_491521501823_item	2506459	et	2	main
d	doc_491521501823_item	2506462	et	4	main
nagu	doc_491521501823_item	2506466	et	3	main
äraaetud	doc_491521501823_item	2506467	et	4	main
hobune	doc_491521501823_item	2506468	et	4	main
köhis	doc_491521501823_item	2506494	et	3	main
otsustas	doc_491521501823_item	2506496	et	3	main
tatjana	doc_491521501823_item	2506500	et	4	main
ta	doc_491521501823_item	2506519	et	4	main
külmetas	doc_491521501823_item	2506521	et	3	main
külla	doc_491521501823_item	2506531	et	4	main
mulle	doc_491521501823_item	2506538	et	4	main
parem	doc_491521501823_item	2506545	et	4	main
tema	doc_491521501823_item	2506546	et	4	main
väike	doc_491521501823_item	2506555	et	4	main
meega	doc_491521501823_item	2506563	et	3	main
väike	doc_491521501823_item	2506566	et	4	main
olin	doc_491521501823_item	2506567	et	3	main
14	doc_491521501823_item	2506576	et	2	main
inimestel	doc_491521501823_item	2506580	et	3	main
allergiat	doc_491521501823_item	2506582	et	3	main
inimestel	doc_491521501823_item	2506584	et	3	main
allergiat	doc_491521501823_item	2506588	et	3	main
sõltub	doc_491521501823_item	2506592	et	3	main
tervis	doc_491521501823_item	2506597	et	3	main
koju	doc_491521501824_item	2506613	et	3	main
ees	doc_491521501824_item	2506617	et	4	main
avaneb	doc_491521501824_item	2506629	et	3	main
on	doc_491521501824_item	2506641	et	4	main
ole	doc_491521501824_item	2506649	et	4	main
üllatus	doc_491521501824_item	2506652	et	4	main
въехали	doc_491521501824_item	2506692	et	2	main
куст	doc_491521501824_item	2506696	et	2	main
чтобы	doc_491521501824_item	2506700	et	2	main
машины	doc_491521501824_item	2506704	et	2	main
и	doc_491521501824_item	2506708	et	2	main
тихонько	doc_491521501824_item	2506714	et	2	main
ещё	doc_491521501824_item	2506719	et	2	main
и	doc_491521501824_item	2506724	et	2	main
хранящий	doc_491521501824_item	2506729	et	2	main
это	doc_491521501824_item	2506734	et	2	main
неправда	doc_491521501824_item	2506739	et	2	main
halvenema	doc_491521501824_item	2506754	et	3	main
venima	doc_491521501824_item	2506761	et	3	main
21	doc_491521501824_item	2506780	et	2	main
väljendite	doc_491521501824_item	2506783	et	3	main
paarid	doc_491521501824_item	2506784	et	4	main
2	doc_491521501824_item	2506790	et	2	main
tegevusse	doc_491521501824_item	2506796	et	4	main
3	doc_491521501824_item	2506797	et	2	main
jätab	doc_491521501824_item	2506798	et	3	main
наехали	doc_491521501823_item	2506356	et	2	main
так	doc_491521501823_item	2506361	et	2	main
на	doc_491521501823_item	2506366	et	2	main
видим	doc_491521501823_item	2506373	et	2	main
ещё	doc_491521501823_item	2506380	et	2	main
сюрприз	doc_491521501823_item	2506383	et	2	main
кухне	doc_491521501823_item	2506387	et	2	main
пирог	doc_491521501823_item	2506392	et	2	main
нет	doc_491521501823_item	2506397	et	2	main
pool	doc_491521501823_item	2506402	et	4	main
kosuma	doc_491521501823_item	2506409	et	3	main
halvenema	doc_491521501823_item	2506411	et	3	main
langetama	doc_491521501823_item	2506415	et	4	main
rahunema	doc_491521501823_item	2506416	et	3	main
rahustama	doc_491521501823_item	2506417	et	3	main
meenuma	doc_491521501823_item	2506426	et	3	main
lõõgastuma	doc_491521501823_item	2506428	et	3	main
nakatama	doc_491521501823_item	2506435	et	4	main
juurde	doc_491521501823_item	2506449	et	4	main
jätab	doc_491521501823_item	2506454	et	3	main
tatjana	doc_491521501823_item	2506492	et	4	main
ta	doc_491521501823_item	2506495	et	4	main
tööle	doc_491521501823_item	2506497	et	3	main
minna	doc_491521501823_item	2506498	et	3	main
saavad	doc_491521501823_item	2506510	et	4	main
kõigest	doc_491521501823_item	2506514	et	4	main
tugevasti	doc_491521501823_item	2506520	et	3	main
ja	doc_491521501823_item	2506522	et	3	main
11	doc_491521501823_item	2506525	et	2	main
saad	doc_491521501823_item	2506529	et	4	main
mulle	doc_491521501823_item	2506530	et	4	main
tule	doc_491521501823_item	2506537	et	4	main
tervis	doc_491521501823_item	2506542	et	3	main
ma	doc_491521501823_item	2506553	et	3	main
ravis	doc_491521501823_item	2506558	et	4	main
sooja	doc_491521501823_item	2506560	et	4	main
kui	doc_491521501823_item	2506564	et	3	main
mind	doc_491521501823_item	2506571	et	4	main
kasutamine	doc_491521501823_item	2506578	et	4	main
tekitab	doc_491521501823_item	2506581	et	3	main
kasutamine	doc_491521501823_item	2506586	et	4	main
15	doc_491521501823_item	2506589	et	2	main
tervis	doc_491521501823_item	2506591	et	3	main
veel	doc_491521501823_item	2506595	et	4	main
elustiilist	doc_491521501823_item	2506599	et	4	main
eksamitöö	doc_491521501824_item	2506600	et	4	main
1tõlkige	doc_491521501824_item	2506601	et	3	main
tulevik	doc_491521501824_item	2506608	et	3	main
pärast	doc_491521501824_item	2506609	et	4	main
lähevad	doc_491521501824_item	2506615	et	3	main
kibuvitsapõõsale	doc_491521501824_item	2506623	et	4	main
ilma	doc_491521501824_item	2506630	et	4	main
kuid	doc_491521501824_item	2506646	et	4	main
veel	doc_491521501824_item	2506650	et	4	main
hõrgutav	doc_491521501824_item	2506656	et	4	main
tõotab	doc_491521501824_item	2506659	et	3	main
romantiline	doc_491521501824_item	2506661	et	3	main
романтический	doc_491521501824_item	2506665	et	2	main
в	doc_491521501824_item	2506667	et	2	main
не	doc_491521501824_item	2506691	et	2	main
открывается	doc_491521501824_item	2506699	et	2	main
под	doc_491521501824_item	2506705	et	2	main
камине	doc_491521501824_item	2506710	et	2	main
горит	doc_491521501824_item	2506715	et	2	main
не	doc_491521501824_item	2506720	et	2	main
все	doc_491521501824_item	2506721	et	2	main
кухне	doc_491521501824_item	2506726	et	2	main
печи	doc_491521501824_item	2506731	et	2	main
будет	doc_491521501824_item	2506735	et	2	main
täitke	doc_491521501824_item	2506742	et	3	main
kiirendama	doc_491521501824_item	2506747	et	3	main
innustama	doc_491521501824_item	2506749	et	3	main
kosutama	doc_491521501824_item	2506753	et	4	main
l	doc_491521501824_item	2506757	et	4	main
rahunema	doc_491521501824_item	2506759	et	3	main
aeglustuma	doc_491521501824_item	2506763	et	3	main
leidke	doc_491521501824_item	2506781	et	3	main
1	doc_491521501824_item	2506785	et	2	main
tuleb	doc_491521501824_item	2506786	et	3	main
mängu	doc_491521501824_item	2506787	et	4	main
c	doc_491521501824_item	2506800	et	4	main
meenutama	doc_491521501823_item	2506427	et	4	main
tekkima	doc_491521501823_item	2506430	et	3	main
avastama	doc_491521501823_item	2506433	et	3	main
sünonüümsete	doc_491521501823_item	2506438	et	3	main
1	doc_491521501823_item	2506441	et	2	main
kurnatud	doc_491521501823_item	2506458	et	4	main
maandab	doc_491521501823_item	2506460	et	3	main
pingeid	doc_491521501823_item	2506461	et	3	main
kuulub	doc_491521501823_item	2506463	et	3	main
kokku	doc_491521501823_item	2506464	et	3	main
5	doc_491521501823_item	2506465	et	2	main
e	doc_491521501823_item	2506469	et	4	main
harilik	doc_491521501823_item	2506470	et	3	main
suurus	doc_491521501823_item	2506471	et	4	main
summa	doc_491521501823_item	2506472	et	4	main
6	doc_491521501823_item	2506473	et	2	main
taks	doc_491521501823_item	2506475	et	3	main
tavaline	doc_491521501823_item	2506474	et	4	main
f	doc_491521501823_item	2506476	et	4	main
ei	doc_491521501823_item	2506477	et	4	main
huvita	doc_491521501823_item	2506478	et	4	main
üldse	doc_491521501823_item	2506479	et	3	main
1-b	doc_491521501823_item	2506480	et	4	main
2-d	doc_491521501823_item	2506481	et	4	main
3-f	doc_491521501823_item	2506482	et	4	main
4-a	doc_491521501823_item	2506483	et	4	main
5-c	doc_491521501823_item	2506484	et	4	main
6-e	doc_491521501823_item	2506485	et	3	main
4	doc_491521501823_item	2506486	et	2	main
parandage	doc_491521501823_item	2506487	et	3	main
8	doc_491521501823_item	2506490	et	2	main
3	doc_491521501823_item	2506453	et	2	main
veel	doc_491521501823_item	2506493	et	4	main
veel	doc_491521501823_item	2506501	et	4	main
köhis	doc_491521501823_item	2506502	et	3	main
otsustas	doc_491521501823_item	2506503	et	3	main
ta	doc_491521501823_item	2506504	et	4	main
tööle	doc_491521501823_item	2506505	et	3	main
minna	doc_491521501823_item	2506506	et	3	main
9	doc_491521501823_item	2506507	et	2	main
aru	doc_491521501823_item	2506512	et	4	main
kiiresti	doc_491521501823_item	2506515	et	3	main
sa	doc_491521501823_item	2506527	et	3	main
terveks	doc_491521501823_item	2506528	et	4	main
terveks	doc_491521501823_item	2506535	et	4	main
saad	doc_491521501823_item	2506536	et	4	main
12	doc_491521501823_item	2506540	et	2	main
on	doc_491521501823_item	2506544	et	4	main
tervis	doc_491521501823_item	2506547	et	3	main
on	doc_491521501823_item	2506548	et	4	main
mind	doc_491521501823_item	2506559	et	4	main
piima	doc_491521501823_item	2506561	et	4	main
ja	doc_491521501823_item	2506562	et	3	main
ma	doc_491521501823_item	2506565	et	3	main
ravis	doc_491521501823_item	2506568	et	4	main
minu	doc_491521501823_item	2506569	et	3	main
keemiatoodete	doc_491521501823_item	2506577	et	3	main
elustiilist	doc_491521501823_item	2506594	et	4	main
sõltub	doc_491521501823_item	2506596	et	3	main
meie	doc_491521501823_item	2506598	et	4	main
ees	doc_491521501824_item	2506606	et	4	main
helge	doc_491521501824_item	2506607	et	4	main
maja	doc_491521501824_item	2506616	et	4	main
iseenesest	doc_491521501824_item	2506618	et	4	main
tuled	doc_491521501824_item	2506619	et	4	main
põlema	doc_491521501824_item	2506620	et	4	main
sõnajärje	doc_491521501823_item	2506488	et	3	main
kuigi	doc_491521501823_item	2506491	et	3	main
kuigi	doc_491521501823_item	2506499	et	3	main
kõigest	doc_491521501823_item	2506511	et	4	main
saavad	doc_491521501823_item	2506516	et	4	main
aru	doc_491521501823_item	2506517	et	4	main
10	doc_491521501823_item	2506518	et	2	main
haigeks	doc_491521501823_item	2506524	et	4	main
tule	doc_491521501823_item	2506532	et	4	main
tema	doc_491521501823_item	2506541	et	4	main
juba	doc_491521501823_item	2506543	et	3	main
juba	doc_491521501823_item	2506550	et	3	main
kui	doc_491521501823_item	2506552	et	3	main
olin	doc_491521501823_item	2506554	et	3	main
minu	doc_491521501823_item	2506556	et	3	main
ema	doc_491521501823_item	2506570	et	4	main
paljudel	doc_491521501823_item	2506579	et	3	main
tekitab	doc_491521501823_item	2506587	et	3	main
viimaks	doc_491521501824_item	2506602	et	4	main
ometi	doc_491521501824_item	2506603	et	3	main
ootab	doc_491521501824_item	2506604	et	3	main
õhtust	doc_491521501824_item	2506610	et	4	main
teatrietendust	doc_491521501824_item	2506611	et	3	main
autoga	doc_491521501824_item	2506612	et	3	main
et	doc_491521501824_item	2506621	et	3	main
et	doc_491521501824_item	2506631	et	3	main
õue	doc_491521501824_item	2506633	et	4	main
tuli	doc_491521501824_item	2506642	et	4	main
mahedalt	doc_491521501824_item	2506643	et	4	main
see	doc_491521501824_item	2506647	et	3	main
kõik	doc_491521501824_item	2506651	et	4	main
tulla	doc_491521501824_item	2506660	et	3	main
мы	doc_491521501824_item	2506690	et	2	main
шиповниковый	doc_491521501824_item	2506695	et	2	main
выходить	doc_491521501824_item	2506702	et	2	main
что	doc_491521501824_item	2506711	et	2	main
но	doc_491521501824_item	2506717	et	2	main
jäi	doc_491521501823_item	2506523	et	3	main
kui	doc_491521501823_item	2506526	et	3	main
kui	doc_491521501823_item	2506533	et	3	main
sa	doc_491521501823_item	2506534	et	3	main
külla	doc_491521501823_item	2506539	et	4	main
parem	doc_491521501823_item	2506549	et	4	main
13	doc_491521501823_item	2506551	et	2	main
ema	doc_491521501823_item	2506557	et	4	main
sooja	doc_491521501823_item	2506572	et	4	main
piimaga	doc_491521501823_item	2506573	et	3	main
ja	doc_491521501823_item	2506574	et	3	main
meega	doc_491521501823_item	2506575	et	3	main
paljudel	doc_491521501823_item	2506583	et	3	main
keemiatoodete	doc_491521501823_item	2506585	et	3	main
veel	doc_491521501823_item	2506590	et	4	main
meie	doc_491521501823_item	2506593	et	4	main
meid	doc_491521501824_item	2506605	et	4	main
saabudes	doc_491521501824_item	2506614	et	3	main
me	doc_491521501824_item	2506622	et	4	main
otsa	doc_491521501824_item	2506624	et	4	main
ei	doc_491521501824_item	2506625	et	4	main
sõidaks	doc_491521501824_item	2506626	et	3	main
garaaži	doc_491521501824_item	2506627	et	2	main
uks	doc_491521501824_item	2506628	et	3	main
tuleks	doc_491521501824_item	2506632	et	4	main
paduvihma	doc_491521501824_item	2506634	et	4	main
kätte	doc_491521501824_item	2506635	et	4	main
astuda	doc_491521501824_item	2506636	et	3	main
ja	doc_491521501824_item	2506637	et	3	main
kaminas	doc_491521501824_item	2506638	et	3	main
põlema	doc_491521501824_item	2506644	et	4	main
ei	doc_491521501824_item	2506648	et	4	main
ka	doc_491521501824_item	2506654	et	3	main
köögis	doc_491521501824_item	2506655	et	3	main
ahjusoe	doc_491521501824_item	2506657	et	4	main
õunakook	doc_491521501824_item	2506658	et	3	main
õhtu	doc_491521501824_item	2506662	et	4	main
kas	doc_491521501824_item	2506663	et	3	main
pole	doc_491521501824_item	2506664	et	3	main
вечер	doc_491521501824_item	2506666	et	2	main
чтобы	doc_491521501824_item	2506689	et	2	main
прямо	doc_491521501824_item	2506693	et	2	main
гаража	doc_491521501824_item	2506698	et	2	main
из	doc_491521501824_item	2506703	et	2	main
дождь	doc_491521501824_item	2506707	et	2	main
за	doc_491521501824_item	2506712	et	2	main
огонь	doc_491521501824_item	2506716	et	2	main
ждёт	doc_491521501824_item	2506723	et	2	main
ещё	doc_491521501824_item	2506728	et	2	main
пирог	doc_491521501824_item	2506733	et	2	main
вечер	doc_491521501824_item	2506738	et	2	main
22	doc_491521501824_item	2506741	et	2	main
kiirenema	doc_491521501824_item	2506746	et	3	main
arenema	doc_491521501824_item	2506750	et	3	main
kosuma	doc_491521501824_item	2506752	et	3	main
langema	doc_491521501824_item	2506756	et	3	main
rahustama	doc_491521501824_item	2506760	et	3	main
a	doc_491521501824_item	2506788	et	4	main
juurde	doc_491521501824_item	2506793	et	4	main
b	doc_491521501824_item	2506794	et	4	main
astub	doc_491521501824_item	2506795	et	3	main
5	doc_491521501824_item	2506809	et	2	main
äraaetud	doc_491521501824_item	2506811	et	4	main
6	doc_491521501824_item	2506817	et	2	main
4	doc_491521501824_item	2506830	et	2	main
vead	doc_491521501824_item	2506833	et	4	main
tööle	doc_491521501824_item	2506849	et	3	main
kõigest	doc_491521501824_item	2506860	et	4	main
aru	doc_491521501824_item	2506861	et	4	main
külmetas	doc_491521501824_item	2506871	et	3	main
haigeks	doc_491521501824_item	2506874	et	4	main
terveks	doc_491521501824_item	2506878	et	4	main
terveks	doc_491521501824_item	2506885	et	4	main
külla	doc_491521501824_item	2506889	et	4	main
näe	doc_491521501824_item	2506639	et	4	main
imet	doc_491521501824_item	2506640	et	3	main
süüdatud	doc_491521501824_item	2506645	et	4	main
ootab	doc_491521501824_item	2506653	et	3	main
конце	doc_491521501824_item	2506668	et	2	main
нас	doc_491521501824_item	2506669	et	2	main
всегда	doc_491521501824_item	2506670	et	2	main
ждёт	doc_491521501824_item	2506671	et	2	main
светлое	doc_491521501824_item	2506672	et	2	main
по	doc_491521501824_item	2506674	et	2	main
будущее	doc_491521501824_item	2506673	et	2	main
приезде	doc_491521501824_item	2506675	et	2	main
на	doc_491521501824_item	2506677	et	2	main
домой	doc_491521501824_item	2506676	et	2	main
машине	doc_491521501824_item	2506678	et	2	main
после	doc_491521501824_item	2506679	et	2	main
вечернего	doc_491521501824_item	2506680	et	2	main
театрального	doc_491521501824_item	2506681	et	2	main
спектакля	doc_491521501824_item	2506683	et	2	main
представления	doc_491521501824_item	2506682	et	2	main
перед	doc_491521501824_item	2506684	et	2	main
домом	doc_491521501824_item	2506685	et	2	main
автоматически	doc_491521501824_item	2506686	et	2	main
зажигаются	doc_491521501824_item	2506687	et	2	main
огни	doc_491521501824_item	2506688	et	2	main
в	doc_491521501824_item	2506694	et	2	main
дверь	doc_491521501824_item	2506697	et	2	main
не	doc_491521501824_item	2506701	et	2	main
проливной	doc_491521501824_item	2506706	et	2	main
в	doc_491521501824_item	2506709	et	2	main
чудо	doc_491521501824_item	2506713	et	2	main
это	doc_491521501824_item	2506718	et	2	main
сюрприз	doc_491521501824_item	2506722	et	2	main
тепло	doc_491521501824_item	2506730	et	2	main
действительно	doc_491521501824_item	2506736	et	2	main
teine	doc_491521501824_item	2506744	et	3	main
arendama	doc_491521501824_item	2506751	et	3	main
angetama	doc_491521501824_item	2506758	et	4	main
venitama	doc_491521501824_item	2506762	et	4	main
nakkatama	doc_491521501824_item	2506779	et	4	main
sünonüümsete	doc_491521501824_item	2506782	et	3	main
lõdvestab	doc_491521501824_item	2506789	et	3	main
asja	doc_491521501824_item	2506792	et	4	main
kokku	doc_491521501824_item	2506808	et	3	main
ei	doc_491521501824_item	2506821	et	4	main
üldse	doc_491521501824_item	2506823	et	3	main
1-b	doc_491521501824_item	2506824	et	4	main
5-c	doc_491521501824_item	2506828	et	4	main
tatjana	doc_491521501824_item	2506844	et	4	main
veel	doc_491521501824_item	2506845	et	4	main
köhis	doc_491521501824_item	2506846	et	3	main
9	doc_491521501824_item	2506851	et	2	main
nad	doc_491521501824_item	2506852	et	3	main
kõigest	doc_491521501824_item	2506855	et	4	main
saavad	doc_491521501824_item	2506858	et	4	main
kiiresti	doc_491521501824_item	2506859	et	3	main
jäi	doc_491521501824_item	2506873	et	3	main
11	doc_491521501824_item	2506875	et	2	main
sa	doc_491521501824_item	2506877	et	3	main
saad	doc_491521501824_item	2506879	et	4	main
mulle	doc_491521501824_item	2506880	et	4	main
juba	doc_491521501824_item	2506893	et	3	main
parem	doc_491521501824_item	2506895	et	4	main
tema	doc_491521501824_item	2506896	et	4	main
tervis	doc_491521501824_item	2506897	et	3	main
paljudel	doc_491521501824_item	2506929	et	3	main
pärast	doc_491521501825_item	2506959	et	4	main
õhtust	doc_491521501825_item	2506960	et	4	main
saabudes	doc_491521501825_item	2506964	et	3	main
me	doc_491521501825_item	2506972	et	4	main
kibuvitsapõõsale	doc_491521501825_item	2506973	et	4	main
et	doc_491521501825_item	2506981	et	3	main
astuda	doc_491521501825_item	2506986	et	3	main
on	doc_491521501825_item	2506991	et	4	main
tuli	doc_491521501825_item	2506992	et	4	main
kuid	doc_491521501825_item	2506996	et	4	main
ahjusoe	doc_491521501825_item	2507007	et	4	main
õhtu	doc_491521501825_item	2507012	et	4	main
вечернего	doc_491521501825_item	2507022	et	2	main
приезжая	doc_491521501825_item	2507026	et	2	main
на	doc_491521501825_item	2507035	et	2	main
гаража	doc_491521501825_item	2507039	et	2	main
не	doc_491521501825_item	2507042	et	2	main
дождь	doc_491521501825_item	2507047	et	2	main
какое	doc_491521501825_item	2507051	et	2	main
но	doc_491521501825_item	2507055	et	2	main
романтический	doc_491521501825_item	2507070	et	2	main
22	doc_491521501825_item	2507075	et	2	main
halvendama	doc_491521501825_item	2507089	et	3	main
venima	doc_491521501825_item	2507094	et	3	main
aeglustuma	doc_491521501825_item	2507096	et	3	main
jahutama	doc_491521501825_item	2507099	et	3	main
toetama	doc_491521501825_item	2507101	et	3	main
nakkama	doc_491521501825_item	2507110	et	3	main
21	doc_491521501825_item	2507112	et	2	main
lõdvestab	doc_491521501825_item	2507121	et	3	main
asja	doc_491521501825_item	2507124	et	4	main
b	doc_491521501825_item	2507126	et	4	main
pingeid	doc_491521501825_item	2507137	et	3	main
hobune	doc_491521501825_item	2507144	et	4	main
6	doc_491521501825_item	2507149	et	2	main
üldse	doc_491521501825_item	2507155	et	3	main
5-c	doc_491521501825_item	2507160	et	4	main
6-e	doc_491521501825_item	2507161	et	3	main
parandage	doc_491521501825_item	2507163	et	3	main
vead	doc_491521501825_item	2507165	et	4	main
в	doc_491521501824_item	2506725	et	2	main
дымящийся	doc_491521501824_item	2506727	et	2	main
яблочный	doc_491521501824_item	2506732	et	2	main
романтический	doc_491521501824_item	2506737	et	2	main
ли	doc_491521501824_item	2506740	et	2	main
tabeli	doc_491521501824_item	2506743	et	3	main
pool	doc_491521501824_item	2506745	et	4	main
innustuma	doc_491521501824_item	2506748	et	3	main
halvendama	doc_491521501824_item	2506755	et	3	main
aeglustama	doc_491521501824_item	2506764	et	3	main
jahtuma	doc_491521501824_item	2506765	et	3	main
jahutama	doc_491521501824_item	2506766	et	3	main
toetuma	doc_491521501824_item	2506767	et	4	main
toetama	doc_491521501824_item	2506768	et	3	main
meenuma	doc_491521501824_item	2506769	et	3	main
meenutama	doc_491521501824_item	2506770	et	4	main
lõõgastuma	doc_491521501824_item	2506771	et	3	main
l	doc_491521501824_item	2506772	et	4	main
tekkima	doc_491521501824_item	2506774	et	3	main
õõgastama	doc_491521501824_item	2506773	et	4	main
tekitama	doc_491521501824_item	2506775	et	4	main
avalduma	doc_491521501824_item	2506776	et	3	main
nakkama	doc_491521501824_item	2506778	et	3	main
avaldama	doc_491521501824_item	2506777	et	3	main
käib	doc_491521501824_item	2506791	et	3	main
külmaks	doc_491521501824_item	2506799	et	4	main
kuulub	doc_491521501824_item	2506807	et	3	main
nagu	doc_491521501824_item	2506810	et	3	main
hobune	doc_491521501824_item	2506812	et	4	main
harilik	doc_491521501824_item	2506814	et	3	main
f	doc_491521501824_item	2506820	et	4	main
2-a	doc_491521501824_item	2506825	et	4	main
6-e	doc_491521501824_item	2506829	et	3	main
8	doc_491521501824_item	2506834	et	2	main
tatjana	doc_491521501824_item	2506836	et	4	main
köhis	doc_491521501824_item	2506838	et	3	main
ta	doc_491521501824_item	2506839	et	4	main
otsustas	doc_491521501824_item	2506840	et	3	main
tööle	doc_491521501824_item	2506841	et	3	main
minna	doc_491521501824_item	2506842	et	3	main
kuigi	doc_491521501824_item	2506843	et	3	main
ta	doc_491521501824_item	2506848	et	4	main
saavad	doc_491521501824_item	2506854	et	4	main
10	doc_491521501824_item	2506862	et	2	main
ta	doc_491521501824_item	2506863	et	4	main
ja	doc_491521501824_item	2506872	et	3	main
kui	doc_491521501824_item	2506876	et	3	main
sa	doc_491521501824_item	2506884	et	3	main
saad	doc_491521501824_item	2506886	et	4	main
tule	doc_491521501824_item	2506887	et	4	main
on	doc_491521501824_item	2506898	et	4	main
juba	doc_491521501824_item	2506899	et	3	main
inimestel	doc_491521501824_item	2506930	et	3	main
keemiatoodete	doc_491521501824_item	2506933	et	3	main
allergiat	doc_491521501824_item	2506938	et	3	main
tervis	doc_491521501824_item	2506941	et	3	main
eksamitöö	doc_491521501825_item	2506950	et	4	main
ees	doc_491521501825_item	2506967	et	4	main
tuled	doc_491521501825_item	2506969	et	4	main
sõidaks	doc_491521501825_item	2506976	et	3	main
avaneb	doc_491521501825_item	2506979	et	3	main
tuleks	doc_491521501825_item	2506982	et	4	main
õue	doc_491521501825_item	2506983	et	4	main
ja	doc_491521501825_item	2506987	et	3	main
imet	doc_491521501825_item	2506990	et	3	main
mahedalt	doc_491521501825_item	2506993	et	4	main
see	doc_491521501825_item	2506997	et	3	main
veel	doc_491521501825_item	2507000	et	4	main
õunakook	doc_491521501825_item	2507008	et	3	main
в	doc_491521501825_item	2507024	et	2	main
включается	doc_491521501825_item	2507029	et	2	main
чтобы	doc_491521501825_item	2507031	et	2	main
кусты	doc_491521501825_item	2507036	et	2	main
и	doc_491521501825_item	2507041	et	2	main
проливной	doc_491521501825_item	2507046	et	2	main
раззожён	doc_491521501825_item	2507053	et	2	main
это	doc_491521501825_item	2507056	et	2	main
пирог	doc_491521501825_item	2507068	et	2	main
ли	doc_491521501825_item	2507074	et	2	main
tabeli	doc_491521501825_item	2507077	et	3	main
arendama	doc_491521501825_item	2507085	et	3	main
kosutama	doc_491521501825_item	2507087	et	4	main
langetama	doc_491521501825_item	2507091	et	4	main
rahustama	doc_491521501825_item	2507093	et	3	main
lõõgastuma	doc_491521501825_item	2507104	et	3	main
tekitama	doc_491521501825_item	2507107	et	4	main
väljendite	doc_491521501825_item	2507115	et	3	main
tuleb	doc_491521501825_item	2507118	et	3	main
juurde	doc_491521501825_item	2507125	et	4	main
astub	doc_491521501825_item	2507127	et	3	main
tegevusse	doc_491521501825_item	2507128	et	4	main
3	doc_491521501825_item	2507129	et	2	main
jätab	doc_491521501825_item	2507130	et	3	main
kokku	doc_491521501825_item	2507140	et	3	main
nagu	doc_491521501825_item	2507142	et	3	main
4	doc_491521501825_item	2507162	et	2	main
sõnajärje	doc_491521501825_item	2507164	et	3	main
kuigi	doc_491521501825_item	2507167	et	3	main
veel	doc_491521501825_item	2507169	et	4	main
otsustas	doc_491521501825_item	2507172	et	3	main
ta	doc_491521501825_item	2507179	et	4	main
otsustas	doc_491521501825_item	2507180	et	3	main
tööle	doc_491521501825_item	2507181	et	3	main
minna	doc_491521501825_item	2507182	et	3	main
aru	doc_491521501825_item	2507188	et	4	main
külla	doc_491521501825_item	2507221	et	4	main
täiesti	doc_491521501824_item	2506801	et	3	main
kurnatud	doc_491521501824_item	2506802	et	4	main
4	doc_491521501824_item	2506803	et	2	main
maandab	doc_491521501824_item	2506804	et	3	main
pingeid	doc_491521501824_item	2506805	et	3	main
e	doc_491521501824_item	2506813	et	4	main
suurus	doc_491521501824_item	2506815	et	4	main
3-f	doc_491521501824_item	2506826	et	4	main
4-d	doc_491521501824_item	2506827	et	4	main
veel	doc_491521501824_item	2506837	et	4	main
minna	doc_491521501824_item	2506850	et	3	main
kiiresti	doc_491521501824_item	2506853	et	3	main
aru	doc_491521501824_item	2506856	et	4	main
nad	doc_491521501824_item	2506857	et	3	main
tugevasti	doc_491521501824_item	2506864	et	3	main
külmetas	doc_491521501824_item	2506865	et	3	main
ja	doc_491521501824_item	2506866	et	3	main
jäi	doc_491521501824_item	2506867	et	3	main
haigeks	doc_491521501824_item	2506868	et	4	main
ta	doc_491521501824_item	2506869	et	4	main
külla	doc_491521501824_item	2506881	et	4	main
12	doc_491521501824_item	2506890	et	2	main
tervis	doc_491521501824_item	2506892	et	3	main
on	doc_491521501824_item	2506894	et	4	main
kasutamine	doc_491521501824_item	2506928	et	4	main
allergiat	doc_491521501824_item	2506932	et	3	main
tekitab	doc_491521501824_item	2506935	et	3	main
inimestel	doc_491521501824_item	2506937	et	3	main
meie	doc_491521501824_item	2506943	et	4	main
elustiilist	doc_491521501824_item	2506944	et	4	main
elustiilist	doc_491521501824_item	2506949	et	4	main
1tõlkige	doc_491521501825_item	2506951	et	3	main
ometi	doc_491521501825_item	2506953	et	3	main
ootab	doc_491521501825_item	2506954	et	3	main
teatrietendust	doc_491521501825_item	2506961	et	3	main
koju	doc_491521501825_item	2506963	et	3	main
maja	doc_491521501825_item	2506966	et	4	main
põlema	doc_491521501825_item	2506970	et	4	main
et	doc_491521501825_item	2506971	et	3	main
kaminas	doc_491521501825_item	2506988	et	3	main
põlema	doc_491521501825_item	2506994	et	4	main
hõrgutav	doc_491521501825_item	2507006	et	4	main
romantiline	doc_491521501825_item	2507011	et	3	main
d	doc_491521501824_item	2506806	et	4	main
summa	doc_491521501824_item	2506816	et	4	main
tavaline	doc_491521501824_item	2506818	et	4	main
taks	doc_491521501824_item	2506819	et	3	main
huvita	doc_491521501824_item	2506822	et	4	main
parandage	doc_491521501824_item	2506831	et	3	main
sõnajärje	doc_491521501824_item	2506832	et	3	main
kuigi	doc_491521501824_item	2506835	et	3	main
otsustas	doc_491521501824_item	2506847	et	3	main
tugevasti	doc_491521501824_item	2506870	et	3	main
tule	doc_491521501824_item	2506882	et	4	main
kui	doc_491521501824_item	2506883	et	3	main
mulle	doc_491521501824_item	2506888	et	4	main
tema	doc_491521501824_item	2506891	et	4	main
parem	doc_491521501824_item	2506900	et	4	main
13	doc_491521501824_item	2506901	et	2	main
kui	doc_491521501824_item	2506902	et	3	main
ma	doc_491521501824_item	2506903	et	3	main
olin	doc_491521501824_item	2506904	et	3	main
väike	doc_491521501824_item	2506905	et	4	main
minu	doc_491521501824_item	2506906	et	3	main
ema	doc_491521501824_item	2506907	et	4	main
ravis	doc_491521501824_item	2506908	et	4	main
mind	doc_491521501824_item	2506909	et	4	main
sooja	doc_491521501824_item	2506910	et	4	main
piima	doc_491521501824_item	2506911	et	4	main
ja	doc_491521501824_item	2506912	et	3	main
meega	doc_491521501824_item	2506913	et	3	main
kui	doc_491521501824_item	2506914	et	3	main
ma	doc_491521501824_item	2506915	et	3	main
väike	doc_491521501824_item	2506916	et	4	main
olin	doc_491521501824_item	2506917	et	3	main
ravis	doc_491521501824_item	2506918	et	4	main
minu	doc_491521501824_item	2506919	et	3	main
ema	doc_491521501824_item	2506920	et	4	main
mind	doc_491521501824_item	2506921	et	4	main
piima	doc_491521501824_item	2506923	et	4	main
ja	doc_491521501824_item	2506924	et	3	main
keemiatoodete	doc_491521501824_item	2506927	et	3	main
kasutamine	doc_491521501824_item	2506934	et	4	main
15	doc_491521501824_item	2506939	et	2	main
meie	doc_491521501824_item	2506948	et	4	main
viimaks	doc_491521501825_item	2506952	et	4	main
ees	doc_491521501825_item	2506956	et	4	main
helge	doc_491521501825_item	2506957	et	4	main
tulevik	doc_491521501825_item	2506958	et	3	main
iseenesest	doc_491521501825_item	2506968	et	4	main
paduvihma	doc_491521501825_item	2506984	et	4	main
süüdatud	doc_491521501825_item	2506995	et	4	main
ole	doc_491521501825_item	2506999	et	4	main
kõik	doc_491521501825_item	2507001	et	4	main
üllatus	doc_491521501825_item	2507002	et	4	main
ootab	doc_491521501825_item	2507003	et	3	main
ka	doc_491521501825_item	2507004	et	3	main
köögis	doc_491521501825_item	2507005	et	3	main
tõotab	doc_491521501825_item	2507009	et	3	main
kas	doc_491521501825_item	2507013	et	3	main
после	doc_491521501825_item	2507021	et	2	main
автоматически	doc_491521501825_item	2507028	et	2	main
наехали	doc_491521501825_item	2507034	et	2	main
смородины	doc_491521501825_item	2507037	et	2	main
нужно	doc_491521501825_item	2507043	et	2	main
в	doc_491521501825_item	2507049	et	2	main
огонь	doc_491521501825_item	2507054	et	2	main
намечается	doc_491521501825_item	2507069	et	2	main
sooja	doc_491521501824_item	2506922	et	4	main
meega	doc_491521501824_item	2506925	et	3	main
14	doc_491521501824_item	2506926	et	2	main
tekitab	doc_491521501824_item	2506931	et	3	main
paljudel	doc_491521501824_item	2506936	et	3	main
veel	doc_491521501824_item	2506940	et	4	main
sõltub	doc_491521501824_item	2506942	et	3	main
veel	doc_491521501824_item	2506945	et	4	main
sõltub	doc_491521501824_item	2506946	et	3	main
tervis	doc_491521501824_item	2506947	et	3	main
meid	doc_491521501825_item	2506955	et	4	main
autoga	doc_491521501825_item	2506962	et	3	main
lähevad	doc_491521501825_item	2506965	et	3	main
otsa	doc_491521501825_item	2506974	et	4	main
ei	doc_491521501825_item	2506975	et	4	main
garaaži	doc_491521501825_item	2506977	et	2	main
uks	doc_491521501825_item	2506978	et	3	main
ilma	doc_491521501825_item	2506980	et	4	main
kätte	doc_491521501825_item	2506985	et	4	main
näe	doc_491521501825_item	2506989	et	4	main
ei	doc_491521501825_item	2506998	et	4	main
tulla	doc_491521501825_item	2507010	et	3	main
pole	doc_491521501825_item	2507014	et	3	main
наконец-то	doc_491521501825_item	2507015	et	2	main
нас	doc_491521501825_item	2507016	et	2	main
ждёт	doc_491521501825_item	2507017	et	2	main
впереди	doc_491521501825_item	2507018	et	2	main
светлое	doc_491521501825_item	2507019	et	2	main
будущее	doc_491521501825_item	2507020	et	2	main
представления	doc_491521501825_item	2507023	et	2	main
домой	doc_491521501825_item	2507027	et	2	main
мы	doc_491521501825_item	2507032	et	2	main
дверь	doc_491521501825_item	2507038	et	2	main
выходить	doc_491521501825_item	2507044	et	2	main
и	doc_491521501825_item	2507048	et	2	main
чудо	doc_491521501825_item	2507052	et	2	main
не	doc_491521501825_item	2507072	et	2	main
täitke	doc_491521501825_item	2507076	et	3	main
halvenema	doc_491521501825_item	2507088	et	3	main
venitama	doc_491521501825_item	2507095	et	4	main
jahtuma	doc_491521501825_item	2507098	et	3	main
meenutama	doc_491521501825_item	2507103	et	4	main
avalduma	doc_491521501825_item	2507108	et	3	main
2	doc_491521501825_item	2507122	et	2	main
d	doc_491521501825_item	2507138	et	4	main
summa	doc_491521501825_item	2507148	et	4	main
huvita	doc_491521501825_item	2507154	et	4	main
1-b	doc_491521501825_item	2507156	et	4	main
3-f	doc_491521501825_item	2507158	et	4	main
4-a	doc_491521501825_item	2507159	et	4	main
tatjana	doc_491521501825_item	2507168	et	4	main
minna	doc_491521501825_item	2507174	et	3	main
tatjana	doc_491521501825_item	2507176	et	4	main
veel	doc_491521501825_item	2507178	et	4	main
9	doc_491521501825_item	2507183	et	2	main
nad	doc_491521501825_item	2507184	et	3	main
kiiresti	doc_491521501825_item	2507185	et	3	main
saavad	doc_491521501825_item	2507186	et	4	main
12	doc_491521501825_item	2507222	et	2	main
tervis	doc_491521501825_item	2507224	et	3	main
juba	doc_491521501825_item	2507225	et	3	main
väike	doc_491521501825_item	2507237	et	4	main
ema	doc_491521501825_item	2507239	et	4	main
mind	doc_491521501825_item	2507253	et	4	main
inimestel	doc_491521501825_item	2507269	et	3	main
15	doc_491521501825_item	2507271	et	2	main
tervis	doc_491521501825_item	2507273	et	3	main
veel	doc_491521501825_item	2507277	et	4	main
inimkonda	doc_491521501826_item	2507313	et	4	main
uude	doc_491521501826_item	2507314	et	3	main
ootab	doc_491521501826_item	2507317	et	3	main
elu	doc_491521501826_item	2507319	et	4	main
ajab	doc_491521501826_item	2507322	et	3	main
asju	doc_491521501826_item	2507324	et	3	main
see	doc_491521501826_item	2507327	et	3	main
театре	doc_491521501825_item	2507025	et	2	main
свет	doc_491521501825_item	2507030	et	2	main
не	doc_491521501825_item	2507033	et	2	main
открывается	doc_491521501825_item	2507040	et	2	main
под	doc_491521501825_item	2507045	et	2	main
камине	doc_491521501825_item	2507050	et	2	main
ещё	doc_491521501825_item	2507057	et	2	main
не	doc_491521501825_item	2507058	et	2	main
всё	doc_491521501825_item	2507059	et	2	main
сюрприз	doc_491521501825_item	2507060	et	2	main
также	doc_491521501825_item	2507061	et	2	main
ждёт	doc_491521501825_item	2507062	et	2	main
в	doc_491521501825_item	2507063	et	2	main
кухне	doc_491521501825_item	2507064	et	2	main
вкусный	doc_491521501825_item	2507065	et	2	main
тёплый	doc_491521501825_item	2507066	et	2	main
яблочный	doc_491521501825_item	2507067	et	2	main
вечер	doc_491521501825_item	2507071	et	2	main
pool	doc_491521501825_item	2507079	et	4	main
arenema	doc_491521501825_item	2507084	et	3	main
langema	doc_491521501825_item	2507090	et	3	main
rahunema	doc_491521501825_item	2507092	et	3	main
aeglustama	doc_491521501825_item	2507097	et	3	main
toetuma	doc_491521501825_item	2507100	et	4	main
lõõgastama	doc_491521501825_item	2507105	et	3	main
avaldama	doc_491521501825_item	2507109	et	3	main
leidke	doc_491521501825_item	2507113	et	3	main
sünonüümsete	doc_491521501825_item	2507114	et	3	main
paarid	doc_491521501825_item	2507116	et	4	main
käib	doc_491521501825_item	2507123	et	3	main
kuulub	doc_491521501825_item	2507139	et	3	main
äraaetud	doc_491521501825_item	2507143	et	4	main
e	doc_491521501825_item	2507145	et	4	main
suurus	doc_491521501825_item	2507147	et	4	main
tavaline	doc_491521501825_item	2507150	et	4	main
ei	doc_491521501825_item	2507153	et	4	main
2-d	doc_491521501825_item	2507157	et	4	main
8	doc_491521501825_item	2507166	et	2	main
nad	doc_491521501825_item	2507189	et	3	main
так	doc_491521501825_item	2507073	et	2	main
teine	doc_491521501825_item	2507078	et	3	main
kiirenema	doc_491521501825_item	2507080	et	3	main
kiirendama	doc_491521501825_item	2507081	et	3	main
innustuma	doc_491521501825_item	2507082	et	3	main
innustama	doc_491521501825_item	2507083	et	3	main
kosuma	doc_491521501825_item	2507086	et	3	main
meenuma	doc_491521501825_item	2507102	et	3	main
tekkima	doc_491521501825_item	2507106	et	3	main
nakkatama	doc_491521501825_item	2507111	et	4	main
1	doc_491521501825_item	2507117	et	2	main
mängu	doc_491521501825_item	2507119	et	4	main
a	doc_491521501825_item	2507120	et	4	main
külmaks	doc_491521501825_item	2507131	et	4	main
c	doc_491521501825_item	2507132	et	4	main
täiesti	doc_491521501825_item	2507133	et	3	main
kurnatud	doc_491521501825_item	2507134	et	4	main
4	doc_491521501825_item	2507135	et	2	main
maandab	doc_491521501825_item	2507136	et	3	main
5	doc_491521501825_item	2507141	et	2	main
harilik	doc_491521501825_item	2507146	et	3	main
taks	doc_491521501825_item	2507151	et	3	main
f	doc_491521501825_item	2507152	et	4	main
köhis	doc_491521501825_item	2507170	et	3	main
tööle	doc_491521501825_item	2507173	et	3	main
köhis	doc_491521501825_item	2507177	et	3	main
saavad	doc_491521501825_item	2507190	et	4	main
kiiresti	doc_491521501825_item	2507191	et	3	main
kõigest	doc_491521501825_item	2507192	et	4	main
aru	doc_491521501825_item	2507193	et	4	main
10	doc_491521501825_item	2507194	et	2	main
ta	doc_491521501825_item	2507195	et	4	main
tugevasti	doc_491521501825_item	2507196	et	3	main
külmetas	doc_491521501825_item	2507197	et	3	main
ja	doc_491521501825_item	2507198	et	3	main
jäi	doc_491521501825_item	2507199	et	3	main
haigeks	doc_491521501825_item	2507200	et	4	main
ta	doc_491521501825_item	2507201	et	4	main
külmetas	doc_491521501825_item	2507202	et	3	main
tugevasti	doc_491521501825_item	2507203	et	3	main
ja	doc_491521501825_item	2507204	et	3	main
jäi	doc_491521501825_item	2507205	et	3	main
haigeks	doc_491521501825_item	2507206	et	4	main
11	doc_491521501825_item	2507207	et	2	main
kui	doc_491521501825_item	2507208	et	3	main
sa	doc_491521501825_item	2507209	et	3	main
terveks	doc_491521501825_item	2507210	et	4	main
saad	doc_491521501825_item	2507211	et	4	main
mulle	doc_491521501825_item	2507212	et	4	main
külla	doc_491521501825_item	2507213	et	4	main
tule	doc_491521501825_item	2507214	et	4	main
kui	doc_491521501825_item	2507215	et	3	main
sa	doc_491521501825_item	2507216	et	3	main
saad	doc_491521501825_item	2507217	et	4	main
terveks	doc_491521501825_item	2507218	et	4	main
tule	doc_491521501825_item	2507219	et	4	main
mulle	doc_491521501825_item	2507220	et	4	main
tema	doc_491521501825_item	2507228	et	4	main
olin	doc_491521501825_item	2507236	et	3	main
meega	doc_491521501825_item	2507257	et	3	main
keemiatoodete	doc_491521501825_item	2507259	et	3	main
keemiatoodete	doc_491521501825_item	2507266	et	3	main
allergiat	doc_491521501825_item	2507270	et	3	main
sõltub	doc_491521501825_item	2507274	et	3	main
ta	doc_491521501825_item	2507171	et	4	main
kuigi	doc_491521501825_item	2507175	et	3	main
kõigest	doc_491521501825_item	2507187	et	4	main
tema	doc_491521501825_item	2507223	et	4	main
on	doc_491521501825_item	2507226	et	4	main
kui	doc_491521501825_item	2507234	et	3	main
ravis	doc_491521501825_item	2507240	et	4	main
piima	doc_491521501825_item	2507243	et	4	main
kui	doc_491521501825_item	2507246	et	3	main
väike	doc_491521501825_item	2507249	et	4	main
ravis	doc_491521501825_item	2507250	et	4	main
minu	doc_491521501825_item	2507251	et	3	main
ema	doc_491521501825_item	2507252	et	4	main
kasutamine	doc_491521501825_item	2507260	et	4	main
paljudel	doc_491521501825_item	2507261	et	3	main
inimestel	doc_491521501825_item	2507262	et	3	main
tekitab	doc_491521501825_item	2507263	et	3	main
allergiat	doc_491521501825_item	2507264	et	3	main
tekitab	doc_491521501825_item	2507265	et	3	main
elustiilist	doc_491521501825_item	2507276	et	4	main
sõltub	doc_491521501825_item	2507278	et	3	main
kes	doc_491521501826_item	2507310	et	4	main
on	doc_491521501826_item	2507311	et	4	main
juhtimas	doc_491521501826_item	2507312	et	4	main
toidu	doc_491521501826_item	2507333	et	3	main
soovi	doc_491521501826_item	2507344	et	4	main
за	doc_491521501826_item	2507352	et	2	main
или	doc_491521501826_item	2507360	et	2	main
благодарности	doc_491521501826_item	2507365	et	2	main
груву	doc_491521501826_item	2507369	et	2	main
которые	doc_491521501826_item	2507374	et	2	main
новую	doc_491521501826_item	2507378	et	2	main
нас	doc_491521501826_item	2507382	et	2	main
большинством	doc_491521501826_item	2507387	et	2	main
сеть	doc_491521501826_item	2507392	et	2	main
утреннего	doc_491521501826_item	2507398	et	2	main
tütar	doc_491521501826_item	2507423	et	3	main
läheb	doc_491521501826_item	2507430	et	3	main
2	doc_491521501826_item	2507434	et	2	main
3	doc_491521501826_item	2507445	et	2	main
sinu	doc_491521501826_item	2507452	et	3	main
haigus	doc_491521501826_item	2507458	et	4	main
nakkav	doc_491521501826_item	2507460	et	4	main
arst	doc_491521501826_item	2507461	et	3	main
tuleb	doc_491521501826_item	2507462	et	3	main
tema	doc_491521501826_item	2507469	et	4	main
lamama	doc_491521501826_item	2507477	et	4	main
jaoks	doc_491521501826_item	2507482	et	4	main
see	doc_491521501826_item	2507483	et	3	main
et	doc_491521501826_item	2507484	et	3	main
ja	doc_491521501826_item	2507523	et	3	main
sobi	doc_491521501826_item	2507565	et	4	main
suve	doc_491521501826_item	2507566	et	4	main
ajaks	doc_491521501826_item	2507567	et	4	main
elektrikulud	doc_491521501826_item	2507597	et	4	main
f	doc_491521501826_item	2507600	et	4	main
большие	doc_491521501826_item	2507602	et	2	main
по	doc_491521501826_item	2507604	et	2	main
kuid	doc_491521501827_item	2507616	et	4	main
keda	doc_491521501827_item	2507617	et	4	main
tänada	doc_491521501827_item	2507621	et	3	main
teistele	doc_491521501827_item	2507638	et	4	main
inimkonda	doc_491521501827_item	2507644	et	4	main
kus	doc_491521501827_item	2507651	et	3	main
asju	doc_491521501827_item	2507655	et	3	main
hommikukohvi	doc_491521501827_item	2507660	et	4	main
ja	doc_491521501827_item	2507666	et	3	main
teie	doc_491521501827_item	2507670	et	4	main
isegi	doc_491521501827_item	2507677	et	4	main
нас	doc_491521501827_item	2507714	et	2	main
в	doc_491521501827_item	2507717	et	2	main
организовывать	doc_491521501827_item	2507721	et	2	main
о	doc_491521501827_item	2507726	et	2	main
дома	doc_491521501827_item	2507732	et	2	main
о	doc_491521501827_item	2507740	et	2	main
по-желанию	doc_491521501827_item	2507745	et	2	main
põhjendage	doc_491521501827_item	2507752	et	3	main
minu	doc_491521501827_item	2507755	et	3	main
homme	doc_491521501827_item	2507757	et	3	main
terveks	doc_491521501827_item	2507776	et	4	main
saanud	doc_491521501827_item	2507777	et	4	main
tervis	doc_491521501825_item	2507229	et	3	main
on	doc_491521501825_item	2507230	et	4	main
juba	doc_491521501825_item	2507231	et	3	main
parem	doc_491521501825_item	2507232	et	4	main
13	doc_491521501825_item	2507233	et	2	main
minu	doc_491521501825_item	2507238	et	3	main
sooja	doc_491521501825_item	2507242	et	4	main
ja	doc_491521501825_item	2507244	et	3	main
ma	doc_491521501825_item	2507247	et	3	main
sooja	doc_491521501825_item	2507254	et	4	main
piima	doc_491521501825_item	2507255	et	4	main
ja	doc_491521501825_item	2507256	et	3	main
14	doc_491521501825_item	2507258	et	2	main
paljudel	doc_491521501825_item	2507268	et	3	main
meie	doc_491521501825_item	2507280	et	4	main
elustiilist	doc_491521501825_item	2507281	et	4	main
eksamitöö	doc_491521501826_item	2507282	et	4	main
1	doc_491521501826_item	2507283	et	2	main
tõlkige	doc_491521501826_item	2507284	et	3	main
kuid	doc_491521501826_item	2507285	et	4	main
keda	doc_491521501826_item	2507286	et	4	main
nende	doc_491521501826_item	2507287	et	4	main
ettevalmistuste	doc_491521501826_item	2507288	et	4	main
eest	doc_491521501826_item	2507289	et	4	main
tänada	doc_491521501826_item	2507290	et	3	main
ei	doc_491521501826_item	2507291	et	4	main
ärge	doc_491521501826_item	2507292	et	3	main
arvake	doc_491521501826_item	2507293	et	3	main
et	doc_491521501826_item	2507294	et	3	main
teenijannat	doc_491521501826_item	2507295	et	4	main
või	doc_491521501826_item	2507296	et	4	main
virka	doc_491521501826_item	2507297	et	4	main
ämma	doc_491521501826_item	2507298	et	4	main
saatke	doc_491521501826_item	2507299	et	3	main
tänuavaldused	doc_491521501826_item	2507300	et	3	main
bill	doc_491521501826_item	2507301	et	3	main
gatesile	doc_491521501826_item	2507302	et	4	main
andrew	doc_491521501826_item	2507303	et	4	main
grove	doc_491521501826_item	2507304	et	4	main
ile	doc_491521501826_item	2507305	et	4	main
ja	doc_491521501826_item	2507306	et	3	main
teistele	doc_491521501826_item	2507307	et	4	main
parem	doc_491521501825_item	2507227	et	4	main
ma	doc_491521501825_item	2507235	et	3	main
mind	doc_491521501825_item	2507241	et	4	main
meega	doc_491521501825_item	2507245	et	3	main
olin	doc_491521501825_item	2507248	et	3	main
kasutamine	doc_491521501825_item	2507267	et	4	main
veel	doc_491521501825_item	2507272	et	4	main
meie	doc_491521501825_item	2507275	et	4	main
tervis	doc_491521501825_item	2507279	et	3	main
kübermaailma	doc_491521501826_item	2507308	et	4	main
arhitektidele	doc_491521501826_item	2507309	et	3	main
postkompuutriajastusse	doc_491521501826_item	2507315	et	4	main
arvutivõrk	doc_491521501826_item	2507326	et	3	main
korraldab	doc_491521501826_item	2507328	et	3	main
kütmise	doc_491521501826_item	2507332	et	4	main
isegi	doc_491521501826_item	2507346	et	4	main
приготавления	doc_491521501826_item	2507354	et	2	main
служанку	doc_491521501826_item	2507359	et	2	main
изъявления	doc_491521501826_item	2507364	et	2	main
другим	doc_491521501826_item	2507371	et	2	main
человечество	doc_491521501826_item	2507376	et	2	main
скоро	doc_491521501826_item	2507381	et	2	main
дома	doc_491521501826_item	2507386	et	2	main
управлять	doc_491521501826_item	2507390	et	2	main
за	doc_491521501826_item	2507396	et	2	main
läheb	doc_491521501826_item	2507425	et	3	main
minu	doc_491521501826_item	2507428	et	3	main
juurde	doc_491521501826_item	2507433	et	4	main
on	doc_491521501826_item	2507436	et	4	main
haigeks	doc_491521501826_item	2507447	et	4	main
tütar	doc_491521501826_item	2507450	et	3	main
tütar	doc_491521501826_item	2507453	et	3	main
jäi	doc_491521501826_item	2507455	et	3	main
see	doc_491521501826_item	2507457	et	3	main
on	doc_491521501826_item	2507459	et	4	main
on	doc_491521501826_item	2507471	et	4	main
raskem	doc_491521501826_item	2507479	et	4	main
minna	doc_491521501826_item	2507521	et	3	main
nendeks	doc_491521501826_item	2507524	et	4	main
kogu	doc_491521501826_item	2507532	et	4	main
aeg	doc_491521501826_item	2507533	et	3	main
muutud	doc_491521501826_item	2507549	et	4	main
ka	doc_491521501826_item	2507550	et	3	main
ise	doc_491521501826_item	2507551	et	4	main
toredamaks	doc_491521501826_item	2507552	et	4	main
d	doc_491521501826_item	2507553	et	4	main
seda	doc_491521501826_item	2507554	et	3	main
haiglat	doc_491521501826_item	2507555	et	3	main
peetakse	doc_491521501826_item	2507556	et	3	main
e	doc_491521501826_item	2507561	et	4	main
need	doc_491521501826_item	2507562	et	3	main
riided	doc_491521501826_item	2507563	et	3	main
f	doc_491521501826_item	2507568	et	4	main
электросчетчик	doc_491521501826_item	2507596	et	2	main
оставьте	doc_491521501826_item	2507601	et	2	main
работы	doc_491521501826_item	2507603	et	2	main
электричеству	doc_491521501826_item	2507605	et	2	main
arvake	doc_491521501827_item	2507624	et	3	main
teenijannat	doc_491521501827_item	2507626	et	4	main
arhitektidele	doc_491521501827_item	2507640	et	3	main
kes	doc_491521501827_item	2507641	et	4	main
varsti	doc_491521501827_item	2507647	et	3	main
maja	doc_491521501827_item	2507662	et	4	main
kütmise	doc_491521501827_item	2507663	et	4	main
toidu	doc_491521501827_item	2507664	et	3	main
kastmise	doc_491521501827_item	2507668	et	4	main
ning	doc_491521501827_item	2507673	et	3	main
жизнь	doc_491521501827_item	2507715	et	2	main
varsti	doc_491521501826_item	2507316	et	3	main
kus	doc_491521501826_item	2507320	et	3	main
kodus	doc_491521501826_item	2507321	et	4	main
enamiku	doc_491521501826_item	2507323	et	3	main
joonde	doc_491521501826_item	2507325	et	4	main
ja	doc_491521501826_item	2507335	et	3	main
kastmise	doc_491521501826_item	2507337	et	4	main
korral	doc_491521501826_item	2507345	et	4	main
эти	doc_491521501826_item	2507353	et	2	main
думайте	doc_491521501826_item	2507357	et	2	main
усердную	doc_491521501826_item	2507361	et	2	main
биллу	doc_491521501826_item	2507366	et	2	main
и	doc_491521501826_item	2507370	et	2	main
ввели	doc_491521501826_item	2507375	et	2	main
эпоху	doc_491521501826_item	2507380	et	2	main
где	doc_491521501826_item	2507385	et	2	main
будет	doc_491521501826_item	2507389	et	2	main
будет	doc_491521501826_item	2507394	et	2	main
meid	doc_491521501826_item	2507318	et	4	main
maja	doc_491521501826_item	2507331	et	4	main
muru	doc_491521501826_item	2507336	et	4	main
hoolitseb	doc_491521501826_item	2507338	et	3	main
tervise	doc_491521501826_item	2507340	et	3	main
ajalehti	doc_491521501826_item	2507347	et	4	main
нет	doc_491521501826_item	2507355	et	2	main
что	doc_491521501826_item	2507358	et	2	main
пошлите	doc_491521501826_item	2507363	et	2	main
гатешлу	doc_491521501826_item	2507367	et	2	main
архитекторам	doc_491521501826_item	2507372	et	2	main
посткомпьютерную	doc_491521501826_item	2507379	et	2	main
жизнь	doc_491521501826_item	2507384	et	2	main
вещей	doc_491521501826_item	2507388	et	2	main
отвечать	doc_491521501826_item	2507395	et	2	main
кофе	doc_491521501826_item	2507399	et	2	main
за	doc_491521501826_item	2507400	et	2	main
топление	doc_491521501826_item	2507401	et	2	main
обогревание	doc_491521501826_item	2507402	et	2	main
дома	doc_491521501826_item	2507403	et	2	main
будет	doc_491521501826_item	2507404	et	2	main
вашем	doc_491521501826_item	2507407	et	2	main
заботиться	doc_491521501826_item	2507405	et	2	main
здоровье	doc_491521501826_item	2507408	et	2	main
о	doc_491521501826_item	2507406	et	2	main
и	doc_491521501826_item	2507409	et	2	main
будет	doc_491521501826_item	2507410	et	2	main
по	doc_491521501826_item	2507411	et	2	main
читать	doc_491521501826_item	2507413	et	2	main
желанию	doc_491521501826_item	2507412	et	2	main
газеты	doc_491521501826_item	2507414	et	2	main
17	doc_491521501826_item	2507416	et	2	main
вслух	doc_491521501826_item	2507415	et	2	main
parandage	doc_491521501826_item	2507417	et	3	main
sõnajärjevead	doc_491521501826_item	2507418	et	3	main
põhjendage	doc_491521501826_item	2507419	et	3	main
parandust	doc_491521501826_item	2507420	et	4	main
minu	doc_491521501826_item	2507422	et	3	main
homme	doc_491521501826_item	2507424	et	3	main
tütar	doc_491521501826_item	2507429	et	3	main
ta	doc_491521501826_item	2507435	et	4	main
terveks	doc_491521501826_item	2507437	et	4	main
saanud	doc_491521501826_item	2507438	et	4	main
juba	doc_491521501826_item	2507439	et	3	main
saanud	doc_491521501826_item	2507444	et	4	main
millal	doc_491521501826_item	2507446	et	3	main
4	doc_491521501826_item	2507456	et	2	main
juurde	doc_491521501826_item	2507464	et	4	main
5	doc_491521501826_item	2507466	et	2	main
kõige	doc_491521501826_item	2507467	et	4	main
raskem	doc_491521501826_item	2507468	et	4	main
ta	doc_491521501826_item	2507474	et	4	main
voodis	doc_491521501826_item	2507475	et	3	main
peab	doc_491521501826_item	2507476	et	4	main
tema	doc_491521501826_item	2507481	et	4	main
kontserdile	doc_491521501826_item	2507522	et	3	main
kooli	doc_491521501826_item	2507528	et	4	main
b	doc_491521501826_item	2507529	et	4	main
hommikukohvi	doc_491521501826_item	2507329	et	4	main
keetmise	doc_491521501826_item	2507330	et	4	main
tellimise	doc_491521501826_item	2507334	et	4	main
teie	doc_491521501826_item	2507339	et	4	main
eest	doc_491521501826_item	2507341	et	4	main
ning	doc_491521501826_item	2507342	et	3	main
loeb	doc_491521501826_item	2507343	et	3	main
ette	doc_491521501826_item	2507348	et	4	main
кого	doc_491521501826_item	2507349	et	2	main
же	doc_491521501826_item	2507350	et	2	main
благодарить	doc_491521501826_item	2507351	et	2	main
не	doc_491521501826_item	2507356	et	2	main
свекровь	doc_491521501826_item	2507362	et	2	main
андрею	doc_491521501826_item	2507368	et	2	main
кубернет-мира	doc_491521501826_item	2507373	et	2	main
в	doc_491521501826_item	2507377	et	2	main
ждёт	doc_491521501826_item	2507383	et	2	main
компьютерная	doc_491521501826_item	2507391	et	2	main
она	doc_491521501826_item	2507393	et	2	main
приготовление	doc_491521501826_item	2507397	et	2	main
1	doc_491521501826_item	2507421	et	2	main
arsti	doc_491521501826_item	2507426	et	4	main
homme	doc_491521501826_item	2507431	et	3	main
on	doc_491521501826_item	2507441	et	4	main
juba	doc_491521501826_item	2507442	et	3	main
terveks	doc_491521501826_item	2507443	et	4	main
jäi	doc_491521501826_item	2507448	et	3	main
millal	doc_491521501826_item	2507451	et	3	main
haigeks	doc_491521501826_item	2507454	et	4	main
koju	doc_491521501826_item	2507465	et	3	main
see	doc_491521501826_item	2507472	et	3	main
et	doc_491521501826_item	2507473	et	3	main
on	doc_491521501826_item	2507480	et	4	main
juurde	doc_491521501826_item	2507427	et	4	main
arsti	doc_491521501826_item	2507432	et	4	main
ta	doc_491521501826_item	2507440	et	4	main
sinu	doc_491521501826_item	2507449	et	3	main
teie	doc_491521501826_item	2507463	et	4	main
jaoks	doc_491521501826_item	2507470	et	4	main
kõige	doc_491521501826_item	2507478	et	4	main
ta	doc_491521501826_item	2507485	et	4	main
peab	doc_491521501826_item	2507486	et	4	main
voodis	doc_491521501826_item	2507487	et	3	main
lamama	doc_491521501826_item	2507488	et	4	main
6	doc_491521501826_item	2507489	et	2	main
arst	doc_491521501826_item	2507490	et	3	main
välja	doc_491521501826_item	2507491	et	4	main
kirjutab	doc_491521501826_item	2507492	et	3	main
retsepti	doc_491521501826_item	2507493	et	4	main
arst	doc_491521501826_item	2507494	et	3	main
kirjutab	doc_491521501826_item	2507495	et	3	main
retsepti	doc_491521501826_item	2507496	et	4	main
välja	doc_491521501826_item	2507497	et	4	main
7	doc_491521501826_item	2507498	et	2	main
nad	doc_491521501826_item	2507499	et	3	main
saavad	doc_491521501826_item	2507500	et	4	main
hakkama	doc_491521501826_item	2507501	et	3	main
sellega	doc_491521501826_item	2507502	et	3	main
nad	doc_491521501826_item	2507503	et	3	main
saavad	doc_491521501826_item	2507504	et	4	main
sellega	doc_491521501826_item	2507505	et	3	main
hakkama	doc_491521501826_item	2507506	et	3	main
kirjutage	doc_491521501826_item	2507508	et	3	main
4	doc_491521501826_item	2507507	et	2	main
lünkadesse	doc_491521501826_item	2507509	et	3	main
sõna	doc_491521501826_item	2507511	et	4	main
sobiv	doc_491521501826_item	2507510	et	4	main
saavas	doc_491521501826_item	2507512	et	4	main
käändes	doc_491521501826_item	2507513	et	3	main
a	doc_491521501826_item	2507514	et	4	main
õpilased	doc_491521501826_item	2507515	et	3	main
jagunesid	doc_491521501826_item	2507516	et	4	main
kaheks	doc_491521501826_item	2507517	et	4	main
nendeks	doc_491521501826_item	2507518	et	4	main
kes	doc_491521501826_item	2507519	et	4	main
tahtsid	doc_491521501826_item	2507520	et	4	main
kes	doc_491521501826_item	2507525	et	4	main
eelistasid	doc_491521501826_item	2507526	et	4	main
jääda	doc_491521501826_item	2507527	et	4	main
linnas	doc_491521501826_item	2507558	et	4	main
kõige	doc_491521501826_item	2507559	et	4	main
paremaks	doc_491521501826_item	2507560	et	4	main
ei	doc_491521501826_item	2507570	et	4	main
osale	doc_491521501826_item	2507571	et	4	main
võistlustel	doc_491521501826_item	2507572	et	3	main
sest	doc_491521501826_item	2507573	et	4	main
kardab	doc_491521501826_item	2507574	et	4	main
jälle	doc_491521501826_item	2507575	et	3	main
viimaks	doc_491521501826_item	2507576	et	4	main
jääda	doc_491521501826_item	2507577	et	4	main
tõlkige	doc_491521501826_item	2507578	et	3	main
d	doc_491521501826_item	2507579	et	4	main
не	doc_491521501826_item	2507580	et	2	main
пользуйтесь	doc_491521501826_item	2507581	et	2	main
мобильным	doc_491521501826_item	2507582	et	2	main
телефоном	doc_491521501826_item	2507583	et	2	main
на	doc_491521501826_item	2507584	et	2	main
заправке	doc_491521501826_item	2507585	et	2	main
ära	doc_491521501826_item	2507586	et	4	main
kasuta	doc_491521501826_item	2507587	et	4	main
mobiil	doc_491521501826_item	2507588	et	3	main
telefon	doc_491521501826_item	2507589	et	3	main
bensiini	doc_491521501826_item	2507590	et	4	main
jaamal	doc_491521501826_item	2507591	et	3	main
e	doc_491521501826_item	2507592	et	4	main
расход	doc_491521501826_item	2507593	et	2	main
электричества	doc_491521501826_item	2507594	et	2	main
elu	doc_491521501826_item	2507530	et	4	main
muutub	doc_491521501826_item	2507531	et	3	main
on	doc_491521501826_item	2507542	et	4	main
nii	doc_491521501826_item	2507543	et	3	main
tore	doc_491521501826_item	2507544	et	3	main
inimene	doc_491521501826_item	2507545	et	3	main
et	doc_491521501826_item	2507546	et	3	main
temaga	doc_491521501826_item	2507547	et	3	main
suheldes	doc_491521501826_item	2507548	et	3	main
meie	doc_491521501826_item	2507557	et	4	main
ei	doc_491521501826_item	2507564	et	4	main
mõõdab	doc_491521501826_item	2507598	et	3	main
специалиста	doc_491521501826_item	2507607	et	2	main
jätke	doc_491521501826_item	2507608	et	4	main
ettevalmistuste	doc_491521501827_item	2507619	et	4	main
ei	doc_491521501827_item	2507622	et	4	main
ärge	doc_491521501827_item	2507623	et	3	main
et	doc_491521501827_item	2507625	et	3	main
või	doc_491521501827_item	2507627	et	4	main
virka	doc_491521501827_item	2507628	et	4	main
ile	doc_491521501827_item	2507636	et	4	main
ja	doc_491521501827_item	2507637	et	3	main
juhtimas	doc_491521501827_item	2507643	et	4	main
meid	doc_491521501827_item	2507649	et	4	main
see	doc_491521501827_item	2507658	et	3	main
tellimise	doc_491521501827_item	2507665	et	4	main
hoolitseb	doc_491521501827_item	2507669	et	3	main
ajalehti	doc_491521501827_item	2507678	et	4	main
ждет	doc_491521501827_item	2507713	et	2	main
доме	doc_491521501827_item	2507718	et	2	main
он	doc_491521501827_item	2507724	et	2	main
утреннего	doc_491521501827_item	2507728	et	2	main
еды	doc_491521501827_item	2507735	et	2	main
заботится	doc_491521501827_item	2507739	et	2	main
и	doc_491521501827_item	2507743	et	2	main
газеты	doc_491521501827_item	2507748	et	2	main
sõnajärjevead	doc_491521501827_item	2507751	et	3	main
parandust	doc_491521501827_item	2507753	et	4	main
tütar	doc_491521501827_item	2507756	et	3	main
arsti	doc_491521501827_item	2507765	et	4	main
ta	doc_491521501827_item	2507768	et	4	main
saanud	doc_491521501827_item	2507771	et	4	main
juba	doc_491521501827_item	2507772	et	3	main
haigeks	doc_491521501827_item	2507780	et	4	main
jäi	doc_491521501827_item	2507781	et	3	main
sinu	doc_491521501827_item	2507782	et	3	main
haigus	doc_491521501827_item	2507791	et	4	main
on	doc_491521501827_item	2507792	et	4	main
nakkav	doc_491521501827_item	2507793	et	4	main
arst	doc_491521501827_item	2507794	et	3	main
tuleb	doc_491521501827_item	2507795	et	3	main
nakkav	doc_491521501827_item	2507802	et	4	main
arst	doc_491521501827_item	2507803	et	3	main
tuleb	doc_491521501827_item	2507804	et	3	main
juurde	doc_491521501827_item	2507807	et	4	main
ebatervislikuks	doc_491521501826_item	2507534	et	3	main
ja	doc_491521501826_item	2507535	et	3	main
see	doc_491521501826_item	2507536	et	3	main
kahjustab	doc_491521501826_item	2507537	et	3	main
inimeste	doc_491521501826_item	2507538	et	3	main
tervist	doc_491521501826_item	2507539	et	4	main
c	doc_491521501826_item	2507540	et	4	main
ta	doc_491521501826_item	2507541	et	4	main
ta	doc_491521501826_item	2507569	et	4	main
elektromeeter	doc_491521501826_item	2507599	et	3	main
maha	doc_491521501826_item	2507609	et	4	main
elektritööd	doc_491521501826_item	2507611	et	4	main
spetsialistile	doc_491521501826_item	2507612	et	3	main
eksamitöö	doc_491521501827_item	2507613	et	4	main
1	doc_491521501827_item	2507614	et	2	main
tõlkige	doc_491521501827_item	2507615	et	3	main
eest	doc_491521501827_item	2507620	et	4	main
измеряет	doc_491521501826_item	2507595	et	2	main
на	doc_491521501826_item	2507606	et	2	main
suured	doc_491521501826_item	2507610	et	3	main
nende	doc_491521501827_item	2507618	et	4	main
ämma	doc_491521501827_item	2507629	et	4	main
saatke	doc_491521501827_item	2507630	et	3	main
tänuavaldused	doc_491521501827_item	2507631	et	3	main
bill	doc_491521501827_item	2507632	et	3	main
gatesile	doc_491521501827_item	2507633	et	4	main
kübermaailma	doc_491521501827_item	2507639	et	4	main
uude	doc_491521501827_item	2507645	et	3	main
postkompuutriajastusse	doc_491521501827_item	2507646	et	4	main
elu	doc_491521501827_item	2507650	et	4	main
kodus	doc_491521501827_item	2507652	et	4	main
enamiku	doc_491521501827_item	2507654	et	3	main
eest	doc_491521501827_item	2507672	et	4	main
loeb	doc_491521501827_item	2507674	et	3	main
soovi	doc_491521501827_item	2507675	et	4	main
korral	doc_491521501827_item	2507676	et	4	main
кого	doc_491521501827_item	2507681	et	2	main
за	doc_491521501827_item	2507683	et	2	main
когда	doc_491521501827_item	2507716	et	2	main
будет	doc_491521501827_item	2507720	et	2	main
все	doc_491521501827_item	2507722	et	2	main
приготовлении	doc_491521501827_item	2507727	et	2	main
отоплении	doc_491521501827_item	2507731	et	2	main
поливке	doc_491521501827_item	2507737	et	2	main
здоровье	doc_491521501827_item	2507742	et	2	main
17	doc_491521501827_item	2507749	et	2	main
arsti	doc_491521501827_item	2507759	et	4	main
homme	doc_491521501827_item	2507764	et	3	main
tütar	doc_491521501827_item	2507783	et	3	main
4	doc_491521501827_item	2507789	et	2	main
juurde	doc_491521501827_item	2507797	et	4	main
koju	doc_491521501827_item	2507798	et	3	main
see	doc_491521501827_item	2507799	et	3	main
teie	doc_491521501827_item	2507805	et	4	main
kõige	doc_491521501827_item	2507809	et	4	main
tema	doc_491521501827_item	2507823	et	4	main
voodis	doc_491521501827_item	2507829	et	3	main
retsepti	doc_491521501827_item	2507835	et	4	main
retsepti	doc_491521501827_item	2507838	et	4	main
välja	doc_491521501827_item	2507839	et	4	main
7	doc_491521501827_item	2507840	et	2	main
nad	doc_491521501827_item	2507841	et	3	main
sellega	doc_491521501827_item	2507847	et	3	main
kaheks	doc_491521501827_item	2507859	et	4	main
nendeks	doc_491521501827_item	2507860	et	4	main
kontserdile	doc_491521501827_item	2507864	et	3	main
c	doc_491521501827_item	2507882	et	4	main
linnas	doc_491521501827_item	2507900	et	4	main
d	doc_491521501827_item	2507920	et	4	main
мобильным	doc_491521501827_item	2507923	et	2	main
tanklas	doc_491521501827_item	2507930	et	3	main
измеряет	doc_491521501827_item	2507934	et	2	main
elektrikulu	doc_491521501827_item	2507936	et	4	main
f	doc_491521501827_item	2507939	et	4	main
большие	doc_491521501827_item	2507941	et	2	main
электричеству	doc_491521501827_item	2507944	et	2	main
keda	doc_491521501828_item	2507955	et	4	main
ei	doc_491521501828_item	2507960	et	4	main
ärge	doc_491521501828_item	2507961	et	3	main
arvake	doc_491521501828_item	2507962	et	3	main
et	doc_491521501828_item	2507963	et	3	main
tänuavaldused	doc_491521501828_item	2507969	et	3	main
ning	doc_491521501828_item	2508011	et	3	main
loeb	doc_491521501828_item	2508012	et	3	main
soovi	doc_491521501828_item	2508013	et	4	main
хотя	doc_491521501828_item	2508018	et	2	main
за	doc_491521501828_item	2508020	et	2	main
благодарить	doc_491521501828_item	2508023	et	2	main
или	doc_491521501828_item	2508029	et	2	main
свекровь	doc_491521501828_item	2508031	et	2	main
гатеси	doc_491521501828_item	2508036	et	2	main
и	doc_491521501828_item	2508039	et	2	main
кибернетического	doc_491521501828_item	2508042	et	2	main
главе	doc_491521501828_item	2508046	et	2	main
посткомпьютерного	doc_491521501828_item	2508050	et	2	main
жизнь	doc_491521501828_item	2508055	et	2	main
выполнять	doc_491521501828_item	2508060	et	2	main
andrew	doc_491521501827_item	2507634	et	4	main
grove	doc_491521501827_item	2507635	et	4	main
on	doc_491521501827_item	2507642	et	4	main
ootab	doc_491521501827_item	2507648	et	3	main
ajab	doc_491521501827_item	2507653	et	3	main
joonde	doc_491521501827_item	2507656	et	4	main
arvutivõrk	doc_491521501827_item	2507657	et	3	main
korraldab	doc_491521501827_item	2507659	et	3	main
keetmise	doc_491521501827_item	2507661	et	4	main
muru	doc_491521501827_item	2507667	et	4	main
tervise	doc_491521501827_item	2507671	et	3	main
ette	doc_491521501827_item	2507679	et	4	main
однако	doc_491521501827_item	2507680	et	2	main
благодарить	doc_491521501827_item	2507682	et	2	main
их	doc_491521501827_item	2507684	et	2	main
подготовку	doc_491521501827_item	2507685	et	2	main
нет	doc_491521501827_item	2507686	et	2	main
не	doc_491521501827_item	2507687	et	2	main
думайте	doc_491521501827_item	2507688	et	2	main
что	doc_491521501827_item	2507689	et	2	main
обслуживающего	doc_491521501827_item	2507690	et	2	main
или	doc_491521501827_item	2507691	et	2	main
прилежную	doc_491521501827_item	2507692	et	2	main
тещу	doc_491521501827_item	2507693	et	2	main
пошлите	doc_491521501827_item	2507694	et	2	main
письмо	doc_491521501827_item	2507695	et	2	main
благодарности	doc_491521501827_item	2507696	et	2	main
биллу	doc_491521501827_item	2507697	et	2	main
гейтсу	doc_491521501827_item	2507698	et	2	main
эндрю	doc_491521501827_item	2507699	et	2	main
груву	doc_491521501827_item	2507700	et	2	main
и	doc_491521501827_item	2507701	et	2	main
другим	doc_491521501827_item	2507702	et	2	main
архитекторам	doc_491521501827_item	2507703	et	2	main
кибер-мира	doc_491521501827_item	2507704	et	2	main
стоит	doc_491521501827_item	2507706	et	2	main
у	doc_491521501827_item	2507707	et	2	main
кто	doc_491521501827_item	2507705	et	2	main
руля	doc_491521501827_item	2507708	et	2	main
нового	doc_491521501827_item	2507709	et	2	main
посткомпьютерного	doc_491521501827_item	2507710	et	2	main
скоро	doc_491521501827_item	2507712	et	2	main
мира	doc_491521501827_item	2507711	et	2	main
компьютер	doc_491521501827_item	2507719	et	2	main
заботится	doc_491521501827_item	2507725	et	2	main
об	doc_491521501827_item	2507730	et	2	main
заказе	doc_491521501827_item	2507734	et	2	main
газона	doc_491521501827_item	2507738	et	2	main
даже	doc_491521501827_item	2507744	et	2	main
вам	doc_491521501827_item	2507747	et	2	main
parandage	doc_491521501827_item	2507750	et	3	main
juurde	doc_491521501827_item	2507766	et	4	main
ta	doc_491521501827_item	2507773	et	4	main
on	doc_491521501827_item	2507774	et	4	main
jäi	doc_491521501827_item	2507785	et	3	main
tütar	doc_491521501827_item	2507787	et	3	main
haigus	doc_491521501827_item	2507800	et	4	main
on	doc_491521501827_item	2507801	et	4	main
koju	doc_491521501827_item	2507806	et	3	main
on	doc_491521501827_item	2507813	et	4	main
see	doc_491521501827_item	2507814	et	3	main
see	doc_491521501827_item	2507825	et	3	main
lamama	doc_491521501827_item	2507830	et	4	main
saavad	doc_491521501827_item	2507842	et	4	main
hakkama	doc_491521501827_item	2507843	et	3	main
sellega	doc_491521501827_item	2507844	et	3	main
jagunesid	doc_491521501827_item	2507858	et	4	main
ja	doc_491521501827_item	2507865	et	3	main
elu	doc_491521501827_item	2507872	et	4	main
muutub	doc_491521501827_item	2507873	et	3	main
on	doc_491521501827_item	2507884	et	4	main
tore	doc_491521501827_item	2507886	et	3	main
suheldes	doc_491521501827_item	2507890	et	3	main
ka	doc_491521501827_item	2507892	et	3	main
toredaks	doc_491521501827_item	2507894	et	3	main
prestiižimaks	doc_491521501827_item	2507902	et	2	main
ta	doc_491521501827_item	2507910	et	4	main
ei	doc_491521501827_item	2507911	et	4	main
tõlkige	doc_491521501827_item	2507919	et	3	main
на	doc_491521501827_item	2507925	et	2	main
mobiiltelefooni	doc_491521501827_item	2507929	et	4	main
elektrimõõtjaga	doc_491521501827_item	2507938	et	3	main
оставьте	doc_491521501827_item	2507940	et	2	main
работы	doc_491521501827_item	2507942	et	2	main
на	doc_491521501827_item	2507945	et	2	main
jätke	doc_491521501827_item	2507947	et	4	main
suured	doc_491521501827_item	2507948	et	3	main
elektritööd	doc_491521501827_item	2507949	et	4	main
spetsialistile	doc_491521501827_item	2507950	et	3	main
kübermaailma	doc_491521501828_item	2507977	et	4	main
arhitektidele	doc_491521501828_item	2507978	et	3	main
isegi	doc_491521501828_item	2508015	et	4	main
не	doc_491521501828_item	2508025	et	2	main
усердную	doc_491521501828_item	2508030	et	2	main
биллу	doc_491521501828_item	2508035	et	2	main
кто	doc_491521501828_item	2508044	et	2	main
новшеств	doc_491521501828_item	2508048	et	2	main
ожидает	doc_491521501828_item	2508053	et	2	main
будет	doc_491521501828_item	2508059	et	2	main
которая	doc_491521501828_item	2508063	et	2	main
уборкой	doc_491521501828_item	2508069	et	2	main
травы	doc_491521501828_item	2508075	et	2	main
заботиться	doc_491521501828_item	2508077	et	2	main
читать	doc_491521501828_item	2508084	et	2	main
põhjendage	doc_491521501828_item	2508090	et	3	main
homme	doc_491521501828_item	2508095	et	3	main
arsti	doc_491521501828_item	2508097	et	4	main
minu	doc_491521501828_item	2508099	et	3	main
tütar	doc_491521501828_item	2508100	et	3	main
läheb	doc_491521501828_item	2508101	et	3	main
homme	doc_491521501828_item	2508102	et	3	main
sinu	doc_491521501828_item	2508123	et	3	main
see	doc_491521501828_item	2508128	et	3	main
on	doc_491521501828_item	2508130	et	4	main
tema	doc_491521501828_item	2508140	et	4	main
voodis	doc_491521501828_item	2508146	et	3	main
peab	doc_491521501828_item	2508147	et	4	main
kõige	doc_491521501828_item	2508149	et	4	main
raskem	doc_491521501828_item	2508150	et	4	main
on	doc_491521501828_item	2508153	et	4	main
retsepti	doc_491521501828_item	2508167	et	4	main
nii	doc_491521501828_item	2508214	et	3	main
tore	doc_491521501828_item	2508215	et	3	main
вещи	doc_491521501827_item	2507723	et	2	main
кофе	doc_491521501827_item	2507729	et	2	main
о	doc_491521501827_item	2507733	et	2	main
и	doc_491521501827_item	2507736	et	2	main
вашем	doc_491521501827_item	2507741	et	2	main
читает	doc_491521501827_item	2507746	et	2	main
1	doc_491521501827_item	2507754	et	2	main
läheb	doc_491521501827_item	2507758	et	3	main
juurde	doc_491521501827_item	2507760	et	4	main
minu	doc_491521501827_item	2507761	et	3	main
tütar	doc_491521501827_item	2507762	et	3	main
läheb	doc_491521501827_item	2507763	et	3	main
2	doc_491521501827_item	2507767	et	2	main
on	doc_491521501827_item	2507769	et	4	main
terveks	doc_491521501827_item	2507770	et	4	main
juba	doc_491521501827_item	2507775	et	3	main
millal	doc_491521501827_item	2507784	et	3	main
haigeks	doc_491521501827_item	2507788	et	4	main
see	doc_491521501827_item	2507790	et	3	main
tema	doc_491521501827_item	2507811	et	4	main
jaoks	doc_491521501827_item	2507812	et	4	main
et	doc_491521501827_item	2507815	et	3	main
ta	doc_491521501827_item	2507816	et	4	main
voodis	doc_491521501827_item	2507817	et	3	main
peab	doc_491521501827_item	2507818	et	4	main
lamama	doc_491521501827_item	2507819	et	4	main
kõige	doc_491521501827_item	2507820	et	4	main
on	doc_491521501827_item	2507822	et	4	main
ta	doc_491521501827_item	2507827	et	4	main
välja	doc_491521501827_item	2507833	et	4	main
saavas	doc_491521501827_item	2507854	et	4	main
käändes	doc_491521501827_item	2507855	et	3	main
a	doc_491521501827_item	2507856	et	4	main
õpilased	doc_491521501827_item	2507857	et	3	main
nendeks	doc_491521501827_item	2507866	et	4	main
eelistasid	doc_491521501827_item	2507868	et	4	main
kogu	doc_491521501827_item	2507874	et	4	main
aeg	doc_491521501827_item	2507875	et	3	main
inimeste	doc_491521501827_item	2507880	et	3	main
ta	doc_491521501827_item	2507883	et	4	main
nii	doc_491521501827_item	2507885	et	3	main
inimene	doc_491521501827_item	2507887	et	3	main
temaga	doc_491521501827_item	2507889	et	3	main
muutud	doc_491521501827_item	2507891	et	4	main
e	doc_491521501827_item	2507903	et	4	main
riided	doc_491521501827_item	2507905	et	3	main
sobi	doc_491521501827_item	2507907	et	4	main
osale	doc_491521501827_item	2507912	et	4	main
võistlustel	doc_491521501827_item	2507913	et	3	main
sest	doc_491521501827_item	2507914	et	4	main
пользуйтесь	doc_491521501827_item	2507922	et	2	main
kasutage	doc_491521501827_item	2507928	et	3	main
расход	doc_491521501827_item	2507932	et	2	main
mõõdetakse	doc_491521501827_item	2507937	et	3	main
ettevalmistuste	doc_491521501828_item	2507957	et	4	main
tänada	doc_491521501828_item	2507959	et	3	main
ämma	doc_491521501828_item	2507967	et	4	main
saatke	doc_491521501828_item	2507968	et	3	main
andrew	doc_491521501828_item	2507972	et	4	main
on	doc_491521501828_item	2507980	et	4	main
eest	doc_491521501828_item	2508010	et	4	main
ette	doc_491521501828_item	2508017	et	4	main
кого	doc_491521501828_item	2508019	et	2	main
3	doc_491521501827_item	2507778	et	2	main
millal	doc_491521501827_item	2507779	et	3	main
sinu	doc_491521501827_item	2507786	et	3	main
teie	doc_491521501827_item	2507796	et	4	main
5	doc_491521501827_item	2507808	et	2	main
raskem	doc_491521501827_item	2507810	et	4	main
raskem	doc_491521501827_item	2507821	et	4	main
et	doc_491521501827_item	2507826	et	3	main
6	doc_491521501827_item	2507831	et	2	main
kirjutab	doc_491521501827_item	2507834	et	3	main
arst	doc_491521501827_item	2507836	et	3	main
kirjutab	doc_491521501827_item	2507837	et	3	main
saavad	doc_491521501827_item	2507846	et	4	main
minna	doc_491521501827_item	2507863	et	3	main
kes	doc_491521501827_item	2507867	et	4	main
jääda	doc_491521501827_item	2507869	et	4	main
kooli	doc_491521501827_item	2507870	et	4	main
halvemaks	doc_491521501827_item	2507876	et	4	main
ja	doc_491521501827_item	2507877	et	3	main
kahjustab	doc_491521501827_item	2507879	et	3	main
kõige	doc_491521501827_item	2507901	et	4	main
jääda	doc_491521501827_item	2507918	et	4	main
не	doc_491521501827_item	2507921	et	2	main
заправке	doc_491521501827_item	2507926	et	2	main
ärge	doc_491521501827_item	2507927	et	3	main
e	doc_491521501827_item	2507931	et	4	main
электросчетчик	doc_491521501827_item	2507935	et	2	main
по	doc_491521501827_item	2507943	et	2	main
специалиста	doc_491521501827_item	2507946	et	2	main
nende	doc_491521501828_item	2507956	et	4	main
teenijannat	doc_491521501828_item	2507964	et	4	main
bill	doc_491521501828_item	2507970	et	3	main
kes	doc_491521501828_item	2507979	et	4	main
korral	doc_491521501828_item	2508014	et	4	main
их	doc_491521501828_item	2508021	et	2	main
думайте	doc_491521501828_item	2508026	et	2	main
письмо	doc_491521501828_item	2508034	et	2	main
другим	doc_491521501828_item	2508040	et	2	main
человеческих	doc_491521501828_item	2508047	et	2	main
скоро	doc_491521501828_item	2508052	et	2	main
дел	doc_491521501828_item	2508058	et	2	main
управлять	doc_491521501828_item	2508065	et	2	main
заказом	doc_491521501828_item	2508071	et	2	main
здоровье	doc_491521501828_item	2508080	et	2	main
желании	doc_491521501828_item	2508083	et	2	main
1	doc_491521501828_item	2508092	et	2	main
tütar	doc_491521501828_item	2508094	et	3	main
terveks	doc_491521501828_item	2508108	et	4	main
saanud	doc_491521501828_item	2508109	et	4	main
juba	doc_491521501828_item	2508110	et	3	main
tütar	doc_491521501828_item	2508124	et	3	main
haigus	doc_491521501828_item	2508129	et	4	main
koju	doc_491521501828_item	2508136	et	3	main
kõige	doc_491521501828_item	2508138	et	4	main
raskem	doc_491521501828_item	2508139	et	4	main
see	doc_491521501828_item	2508143	et	3	main
jaoks	doc_491521501828_item	2508152	et	4	main
voodis	doc_491521501828_item	2508158	et	3	main
välja	doc_491521501828_item	2508162	et	4	main
kirjutab	doc_491521501828_item	2508163	et	3	main
retsepti	doc_491521501828_item	2508164	et	4	main
arst	doc_491521501828_item	2508165	et	3	main
kirjutab	doc_491521501828_item	2508166	et	3	main
saavad	doc_491521501828_item	2508175	et	4	main
sellega	doc_491521501828_item	2508176	et	3	main
hakkama	doc_491521501828_item	2508177	et	3	main
on	doc_491521501828_item	2508213	et	4	main
suheldes	doc_491521501828_item	2508219	et	3	main
meie	doc_491521501828_item	2508228	et	4	main
sest	doc_491521501828_item	2508243	et	4	main
kurdiks	doc_491521501828_item	2508247	et	4	main
jääda	doc_491521501828_item	2508248	et	4	main
tõlkige	doc_491521501828_item	2508249	et	3	main
d	doc_491521501828_item	2508250	et	4	main
не	doc_491521501828_item	2508251	et	2	main
e	doc_491521501828_item	2508261	et	4	main
электросчетчик	doc_491521501828_item	2508265	et	2	main
voolumõõtja	doc_491521501828_item	2508269	et	4	main
большие	doc_491521501828_item	2508272	et	2	main
электричеству	doc_491521501828_item	2508275	et	2	main
jaoks	doc_491521501827_item	2507824	et	4	main
peab	doc_491521501827_item	2507828	et	4	main
arst	doc_491521501827_item	2507832	et	3	main
nad	doc_491521501827_item	2507845	et	3	main
hakkama	doc_491521501827_item	2507848	et	3	main
4	doc_491521501827_item	2507849	et	2	main
kirjutage	doc_491521501827_item	2507850	et	3	main
lünkadesse	doc_491521501827_item	2507851	et	3	main
sobiv	doc_491521501827_item	2507852	et	4	main
sõna	doc_491521501827_item	2507853	et	4	main
kes	doc_491521501827_item	2507861	et	4	main
tahtsid	doc_491521501827_item	2507862	et	4	main
b	doc_491521501827_item	2507871	et	4	main
see	doc_491521501827_item	2507878	et	3	main
tervist	doc_491521501827_item	2507881	et	4	main
et	doc_491521501827_item	2507888	et	3	main
ise	doc_491521501827_item	2507893	et	4	main
d	doc_491521501827_item	2507895	et	4	main
seda	doc_491521501827_item	2507896	et	3	main
haiglat	doc_491521501827_item	2507897	et	3	main
peetakse	doc_491521501827_item	2507898	et	3	main
meie	doc_491521501827_item	2507899	et	4	main
need	doc_491521501827_item	2507904	et	3	main
ei	doc_491521501827_item	2507906	et	4	main
kooliks	doc_491521501827_item	2507908	et	4	main
f	doc_491521501827_item	2507909	et	4	main
kardab	doc_491521501827_item	2507915	et	4	main
jälle	doc_491521501827_item	2507916	et	3	main
viimaseks	doc_491521501827_item	2507917	et	3	main
телефоном	doc_491521501827_item	2507924	et	2	main
электричества	doc_491521501827_item	2507933	et	2	main
eksamitöö	doc_491521501828_item	2507951	et	4	main
1	doc_491521501828_item	2507952	et	2	main
tõlkige	doc_491521501828_item	2507953	et	3	main
kuid	doc_491521501828_item	2507954	et	4	main
eest	doc_491521501828_item	2507958	et	4	main
või	doc_491521501828_item	2507965	et	4	main
virka	doc_491521501828_item	2507966	et	4	main
gatesile	doc_491521501828_item	2507971	et	4	main
grove	doc_491521501828_item	2507973	et	4	main
ile	doc_491521501828_item	2507974	et	4	main
ja	doc_491521501828_item	2507975	et	3	main
teistele	doc_491521501828_item	2507976	et	4	main
juhtimas	doc_491521501828_item	2507981	et	4	main
inimkonda	doc_491521501828_item	2507982	et	4	main
uude	doc_491521501828_item	2507983	et	3	main
postkompuutriajastusse	doc_491521501828_item	2507984	et	4	main
varsti	doc_491521501828_item	2507985	et	3	main
ootab	doc_491521501828_item	2507986	et	3	main
meid	doc_491521501828_item	2507987	et	4	main
elu	doc_491521501828_item	2507988	et	4	main
kus	doc_491521501828_item	2507989	et	3	main
kodus	doc_491521501828_item	2507990	et	4	main
ajab	doc_491521501828_item	2507991	et	3	main
enamiku	doc_491521501828_item	2507992	et	3	main
asju	doc_491521501828_item	2507993	et	3	main
joonde	doc_491521501828_item	2507994	et	4	main
arvutivõrk	doc_491521501828_item	2507995	et	3	main
see	doc_491521501828_item	2507996	et	3	main
korraldab	doc_491521501828_item	2507997	et	3	main
hommikukohvi	doc_491521501828_item	2507998	et	4	main
keetmise	doc_491521501828_item	2507999	et	4	main
maja	doc_491521501828_item	2508000	et	4	main
kütmise	doc_491521501828_item	2508001	et	4	main
toidu	doc_491521501828_item	2508002	et	3	main
tellimise	doc_491521501828_item	2508003	et	4	main
ja	doc_491521501828_item	2508004	et	3	main
muru	doc_491521501828_item	2508005	et	4	main
kastmise	doc_491521501828_item	2508006	et	4	main
hoolitseb	doc_491521501828_item	2508007	et	3	main
teie	doc_491521501828_item	2508008	et	4	main
tervise	doc_491521501828_item	2508009	et	3	main
ajalehti	doc_491521501828_item	2508016	et	4	main
нет	doc_491521501828_item	2508024	et	2	main
что	doc_491521501828_item	2508027	et	2	main
благодарственное	doc_491521501828_item	2508033	et	2	main
грови	doc_491521501828_item	2508038	et	2	main
мира	doc_491521501828_item	2508043	et	2	main
и	doc_491521501828_item	2508049	et	2	main
нас	doc_491521501828_item	2508054	et	2	main
большинство	doc_491521501828_item	2508057	et	2	main
связь	doc_491521501828_item	2508062	et	2	main
утреннего	doc_491521501828_item	2508067	et	2	main
еды	doc_491521501828_item	2508072	et	2	main
о	doc_491521501828_item	2508078	et	2	main
даже	doc_491521501828_item	2508085	et	2	main
sõnajärjevead	doc_491521501828_item	2508089	et	3	main
läheb	doc_491521501828_item	2508096	et	3	main
juurde	doc_491521501828_item	2508098	et	4	main
2	doc_491521501828_item	2508105	et	2	main
подготовку	doc_491521501828_item	2508022	et	2	main
служанку	doc_491521501828_item	2508028	et	2	main
пошлите	doc_491521501828_item	2508032	et	2	main
эндрю	doc_491521501828_item	2508037	et	2	main
архитекторам	doc_491521501828_item	2508041	et	2	main
во	doc_491521501828_item	2508045	et	2	main
века	doc_491521501828_item	2508051	et	2	main
где	doc_491521501828_item	2508056	et	2	main
компьютерная	doc_491521501828_item	2508061	et	2	main
приготовлением	doc_491521501828_item	2508066	et	2	main
кофе	doc_491521501828_item	2508068	et	2	main
и	doc_491521501828_item	2508073	et	2	main
будет	doc_491521501828_item	2508076	et	2	main
и	doc_491521501828_item	2508081	et	2	main
газеты	doc_491521501828_item	2508086	et	2	main
parandust	doc_491521501828_item	2508091	et	4	main
minu	doc_491521501828_item	2508093	et	3	main
juurde	doc_491521501828_item	2508104	et	4	main
on	doc_491521501828_item	2508107	et	4	main
ta	doc_491521501828_item	2508111	et	4	main
on	doc_491521501828_item	2508112	et	4	main
juba	doc_491521501828_item	2508113	et	3	main
terveks	doc_491521501828_item	2508114	et	4	main
saanud	doc_491521501828_item	2508115	et	4	main
3	doc_491521501828_item	2508116	et	2	main
millal	doc_491521501828_item	2508117	et	3	main
haigeks	doc_491521501828_item	2508118	et	4	main
jäi	doc_491521501828_item	2508119	et	3	main
sinu	doc_491521501828_item	2508120	et	3	main
haigeks	doc_491521501828_item	2508126	et	4	main
nakkav	doc_491521501828_item	2508131	et	4	main
arst	doc_491521501828_item	2508132	et	3	main
tuleb	doc_491521501828_item	2508133	et	3	main
teie	doc_491521501828_item	2508134	et	4	main
jaoks	doc_491521501828_item	2508141	et	4	main
ta	doc_491521501828_item	2508145	et	4	main
lamama	doc_491521501828_item	2508148	et	4	main
peab	doc_491521501828_item	2508156	et	4	main
6	doc_491521501828_item	2508160	et	2	main
nad	doc_491521501828_item	2508170	et	3	main
inimene	doc_491521501828_item	2508216	et	3	main
будет	doc_491521501828_item	2508064	et	2	main
дома	doc_491521501828_item	2508070	et	2	main
поливкой	doc_491521501828_item	2508074	et	2	main
вашем	doc_491521501828_item	2508079	et	2	main
при	doc_491521501828_item	2508082	et	2	main
17	doc_491521501828_item	2508087	et	2	main
parandage	doc_491521501828_item	2508088	et	3	main
arsti	doc_491521501828_item	2508103	et	4	main
ta	doc_491521501828_item	2508106	et	4	main
tütar	doc_491521501828_item	2508121	et	3	main
jäi	doc_491521501828_item	2508125	et	3	main
juurde	doc_491521501828_item	2508135	et	4	main
5	doc_491521501828_item	2508137	et	2	main
et	doc_491521501828_item	2508144	et	3	main
et	doc_491521501828_item	2508155	et	3	main
ta	doc_491521501828_item	2508157	et	4	main
lamama	doc_491521501828_item	2508159	et	4	main
arst	doc_491521501828_item	2508161	et	3	main
7	doc_491521501828_item	2508169	et	2	main
ta	doc_491521501828_item	2508212	et	4	main
muutud	doc_491521501828_item	2508220	et	4	main
ise	doc_491521501828_item	2508222	et	4	main
toredaks	doc_491521501828_item	2508223	et	3	main
seda	doc_491521501828_item	2508225	et	3	main
ei	doc_491521501828_item	2508235	et	4	main
f	doc_491521501828_item	2508238	et	4	main
ta	doc_491521501828_item	2508239	et	4	main
kulu	doc_491521501828_item	2508267	et	4	main
оставьте	doc_491521501828_item	2508271	et	2	main
по	doc_491521501828_item	2508274	et	2	main
специалиста	doc_491521501828_item	2508277	et	2	main
elektri	doc_491521501828_item	2508279	et	3	main
suured	doc_491521501828_item	2508280	et	3	main
tööd	doc_491521501828_item	2508281	et	4	main
spetsialistile	doc_491521501828_item	2508282	et	3	main
millal	doc_491521501828_item	2508122	et	3	main
4	doc_491521501828_item	2508127	et	2	main
on	doc_491521501828_item	2508142	et	4	main
tema	doc_491521501828_item	2508151	et	4	main
see	doc_491521501828_item	2508154	et	3	main
välja	doc_491521501828_item	2508168	et	4	main
saavad	doc_491521501828_item	2508171	et	4	main
hakkama	doc_491521501828_item	2508172	et	3	main
sellega	doc_491521501828_item	2508173	et	3	main
nad	doc_491521501828_item	2508174	et	3	main
4	doc_491521501828_item	2508178	et	2	main
kirjutage	doc_491521501828_item	2508179	et	3	main
lünkadesse	doc_491521501828_item	2508180	et	3	main
sobiv	doc_491521501828_item	2508181	et	4	main
sõna	doc_491521501828_item	2508182	et	4	main
saavas	doc_491521501828_item	2508183	et	4	main
käändes	doc_491521501828_item	2508184	et	3	main
a	doc_491521501828_item	2508185	et	4	main
õpilased	doc_491521501828_item	2508186	et	3	main
jagunesid	doc_491521501828_item	2508187	et	4	main
kaheks	doc_491521501828_item	2508188	et	4	main
nendeks	doc_491521501828_item	2508189	et	4	main
kes	doc_491521501828_item	2508190	et	4	main
tahtsid	doc_491521501828_item	2508191	et	4	main
minna	doc_491521501828_item	2508192	et	3	main
kontserdile	doc_491521501828_item	2508193	et	3	main
ja	doc_491521501828_item	2508194	et	3	main
nendeks	doc_491521501828_item	2508195	et	4	main
kes	doc_491521501828_item	2508196	et	4	main
eelistasid	doc_491521501828_item	2508197	et	4	main
jääda	doc_491521501828_item	2508198	et	4	main
kooli	doc_491521501828_item	2508199	et	4	main
b	doc_491521501828_item	2508200	et	4	main
elu	doc_491521501828_item	2508201	et	4	main
muutub	doc_491521501828_item	2508202	et	3	main
kogu	doc_491521501828_item	2508203	et	4	main
rahutuks	doc_491521501828_item	2508205	et	4	main
ja	doc_491521501828_item	2508206	et	3	main
aeg	doc_491521501828_item	2508204	et	3	main
see	doc_491521501828_item	2508207	et	3	main
kahjustab	doc_491521501828_item	2508208	et	3	main
inimeste	doc_491521501828_item	2508209	et	3	main
tervist	doc_491521501828_item	2508210	et	4	main
c	doc_491521501828_item	2508211	et	4	main
et	doc_491521501828_item	2508217	et	3	main
haiglat	doc_491521501828_item	2508226	et	3	main
kõige	doc_491521501828_item	2508230	et	4	main
e	doc_491521501828_item	2508232	et	4	main
need	doc_491521501828_item	2508233	et	3	main
riided	doc_491521501828_item	2508234	et	3	main
ei	doc_491521501828_item	2508240	et	4	main
kardab	doc_491521501828_item	2508244	et	4	main
tanklas	doc_491521501828_item	2508260	et	3	main
измеряет	doc_491521501828_item	2508264	et	2	main
elektri	doc_491521501828_item	2508266	et	3	main
temaga	doc_491521501828_item	2508218	et	3	main
ka	doc_491521501828_item	2508221	et	3	main
peetakse	doc_491521501828_item	2508227	et	3	main
linnas	doc_491521501828_item	2508229	et	4	main
paremaks	doc_491521501828_item	2508231	et	4	main
õhtusöögiks	doc_491521501828_item	2508237	et	3	main
võistlustel	doc_491521501828_item	2508242	et	3	main
haigeks	doc_491521501828_item	2508246	et	4	main
mobiiltelefoni	doc_491521501828_item	2508259	et	4	main
электричества	doc_491521501828_item	2508263	et	2	main
d	doc_491521501828_item	2508224	et	4	main
sobi	doc_491521501828_item	2508236	et	4	main
osale	doc_491521501828_item	2508241	et	4	main
jälle	doc_491521501828_item	2508245	et	3	main
пользуйтесь	doc_491521501828_item	2508252	et	2	main
мобильным	doc_491521501828_item	2508253	et	2	main
телефоном	doc_491521501828_item	2508254	et	2	main
на	doc_491521501828_item	2508255	et	2	main
заправке	doc_491521501828_item	2508256	et	2	main
ärge	doc_491521501828_item	2508257	et	3	main
kasutage	doc_491521501828_item	2508258	et	3	main
расход	doc_491521501828_item	2508262	et	2	main
mõõdab	doc_491521501828_item	2508268	et	3	main
f	doc_491521501828_item	2508270	et	4	main
работы	doc_491521501828_item	2508273	et	2	main
на	doc_491521501828_item	2508276	et	2	main
unistused	doc_491521501830_item	2508621	et	4	main
täitumas	doc_491521501830_item	2508623	et	4	main
eeskätt	doc_491521501830_item	2508624	et	3	main
käskluse	doc_491521501830_item	2508638	et	3	main
peale	doc_491521501830_item	2508639	et	4	main
valvekaamera	doc_491521501830_item	2508640	et	4	main
helistab	doc_491521501830_item	2508644	et	3	main
toatemperatuuri	doc_491521501830_item	2508653	et	4	main
õhukonditsioneeri	doc_491521501830_item	2508657	et	4	main
мечты	doc_491521501830_item	2508667	et	2	main
в	doc_491521501830_item	2508670	et	2	main
благодаря	doc_491521501830_item	2508673	et	2	main
уже	doc_491521501830_item	2508679	et	2	main
дома	doc_491521501830_item	2508683	et	2	main
по	doc_491521501830_item	2508716	et	2	main
говоря	doc_491521501830_item	2508720	et	2	main
уже	doc_491521501830_item	2508721	et	2	main
jätke	doc_491521501828_item	2508278	et	4	main
juba	doc_491521501830_item	2508630	et	3	main
praegu	doc_491521501830_item	2508631	et	3	main
mis	doc_491521501830_item	2508635	et	4	main
suulise	doc_491521501830_item	2508637	et	4	main
kes	doc_491521501830_item	2508643	et	4	main
ette	doc_491521501830_item	2508650	et	4	main
reguleerida	doc_491521501830_item	2508652	et	3	main
ehitamisest	doc_491521501830_item	2508664	et	4	main
теперь	doc_491521501830_item	2508665	et	2	main
эти	doc_491521501830_item	2508666	et	2	main
могут	doc_491521501830_item	2508668	et	2	main
очередь	doc_491521501830_item	2508672	et	2	main
дигитальной	doc_491521501830_item	2508676	et	2	main
теперь	doc_491521501830_item	2508680	et	2	main
кондиционер	doc_491521501830_item	2508714	et	2	main
домашней	doc_491521501830_item	2508725	et	2	main
kas	doc_491521501830_item	2508729	et	3	main
tegevust	doc_491521501830_item	2508736	et	4	main
sobiv	doc_491521501830_item	2508741	et	4	main
a	doc_491521501830_item	2508745	et	4	main
jahutama	doc_491521501830_item	2508747	et	3	main
oota	doc_491521501830_item	2508748	et	4	main
kuni	doc_491521501830_item	2508749	et	3	main
jahuta	doc_491521501830_item	2508757	et	4	main
kõrvetad	doc_491521501830_item	2508761	et	3	main
mõnikord	doc_491521501830_item	2508772	et	3	main
venisin	doc_491521501830_item	2508783	et	3	main
eksamitöö	doc_491521501830_item	2508616	et	4	main
1tõlkige	doc_491521501830_item	2508617	et	3	main
nüüd	doc_491521501830_item	2508618	et	4	main
on	doc_491521501830_item	2508619	et	4	main
need	doc_491521501830_item	2508620	et	3	main
viimaks	doc_491521501830_item	2508622	et	4	main
tänu	doc_491521501830_item	2508625	et	4	main
mikroprotsessoreile	doc_491521501830_item	2508626	et	3	main
ja	doc_491521501830_item	2508627	et	3	main
digitaaltehnoloogiale	doc_491521501830_item	2508628	et	3	main
valgustuse	doc_491521501830_item	2508634	et	4	main
töötab	doc_491521501830_item	2508636	et	3	main
teie	doc_491521501830_item	2508645	et	4	main
taga	doc_491521501830_item	2508647	et	4	main
tõmmata	doc_491521501830_item	2508648	et	4	main
nuppude	doc_491521501830_item	2508654	et	3	main
juba	doc_491521501830_item	2508659	et	3	main
koduse	doc_491521501830_item	2508662	et	4	main
võite	doc_491521501830_item	2508629	et	4	main
paigutada	doc_491521501830_item	2508632	et	3	main
ukse	doc_491521501830_item	2508646	et	3	main
ja	doc_491521501830_item	2508651	et	3	main
abil	doc_491521501830_item	2508655	et	4	main
первую	doc_491521501830_item	2508671	et	2	main
и	doc_491521501830_item	2508675	et	2	main
ещё	doc_491521501830_item	2508715	et	2	main
домой	doc_491521501830_item	2508718	et	2	main
построении	doc_491521501830_item	2508724	et	2	main
5	doc_491521501830_item	2508728	et	2	main
suunatud	doc_491521501830_item	2508735	et	4	main
õiges	doc_491521501830_item	2508743	et	3	main
keele	doc_491521501830_item	2508762	et	4	main
ära	doc_491521501830_item	2508763	et	4	main
venima	doc_491521501830_item	2508765	et	3	main
millest	doc_491521501830_item	2508767	et	3	main
see	doc_491521501830_item	2508768	et	3	main
aeg	doc_491521501830_item	2508774	et	3	main
kiiresti	doc_491521501830_item	2508776	et	3	main
kord	doc_491521501830_item	2508778	et	4	main
ma	doc_491521501830_item	2508782	et	3	main
kaua	doc_491521501830_item	2508786	et	3	main
kui	doc_491521501830_item	2508787	et	3	main
aeglustab	doc_491521501830_item	2508821	et	3	main
selle	doc_491521501830_item	2508823	et	4	main
20	doc_491521501830_item	2508829	et	2	main
asjad	doc_491521501830_item	2508836	et	3	main
b	doc_491521501830_item	2508847	et	4	main
ei	doc_491521501830_item	2508849	et	4	main
tulnud	doc_491521501830_item	2508850	et	4	main
talle	doc_491521501830_item	2508851	et	4	main
ennast	doc_491521501830_item	2508855	et	4	main
c	doc_491521501830_item	2508857	et	4	main
korraldab	doc_491521501830_item	2508858	et	3	main
ära	doc_491521501830_item	2508859	et	4	main
4	doc_491521501830_item	2508860	et	2	main
5	doc_491521501830_item	2508872	et	2	main
mulle	doc_491521501830_item	2508875	et	4	main
liiga	doc_491521501830_item	2508876	et	4	main
on	doc_491521501830_item	2508880	et	4	main
raamatutegelased	doc_491521501830_item	2508884	et	3	main
ta	doc_491521501830_item	2508886	et	4	main
nägi	doc_491521501830_item	2508887	et	3	main
enda	doc_491521501830_item	2508892	et	4	main
peale	doc_491521501830_item	2508893	et	4	main
4-f	doc_491521501830_item	2508899	et	4	main
masinad	doc_491521501830_item	2508904	et	3	main
jagage	doc_491521501830_item	2508906	et	3	main
kolme	doc_491521501830_item	2508908	et	4	main
kohviveski	doc_491521501830_item	2508918	et	4	main
prits	doc_491521501830_item	2508920	et	3	main
puur	doc_491521501830_item	2508929	et	3	main
prits	doc_491521501830_item	2508931	et	3	main
jootekolb	doc_491521501830_item	2508935	et	4	main
lood	doc_491521501830_item	2508938	et	4	main
muruniiduk	doc_491521501830_item	2508952	et	3	main
eksamitöö	doc_491521501831_item	2508956	et	4	main
nüüd	doc_491521501831_item	2508958	et	4	main
paigutada	doc_491521501831_item	2508972	et	3	main
sisse	doc_491521501831_item	2508998	et	4	main
juba	doc_491521501831_item	2508999	et	3	main
koduteel	doc_491521501831_item	2509000	et	3	main
rääkimata	doc_491521501831_item	2509001	et	4	main
сбылись	doc_491521501831_item	2509008	et	2	main
koju	doc_491521501830_item	2508633	et	3	main
mis	doc_491521501830_item	2508641	et	4	main
näitab	doc_491521501830_item	2508642	et	3	main
kardinad	doc_491521501830_item	2508649	et	4	main
lülitada	doc_491521501830_item	2508656	et	3	main
sisse	doc_491521501830_item	2508658	et	4	main
koduteel	doc_491521501830_item	2508660	et	3	main
rääkimata	doc_491521501830_item	2508661	et	4	main
исполниться	doc_491521501830_item	2508669	et	2	main
технологии	doc_491521501830_item	2508677	et	2	main
можете	doc_491521501830_item	2508681	et	2	main
освещение	doc_491521501830_item	2508684	et	2	main
которое	doc_491521501830_item	2508685	et	2	main
подчиняясь	doc_491521501830_item	2508687	et	2	main
работает	doc_491521501830_item	2508686	et	2	main
устным	doc_491521501830_item	2508688	et	2	main
приказам	doc_491521501830_item	2508689	et	2	main
охранную	doc_491521501830_item	2508690	et	2	main
дежурную	doc_491521501830_item	2508691	et	2	main
камеру	doc_491521501830_item	2508692	et	2	main
которая	doc_491521501830_item	2508693	et	2	main
показывает	doc_491521501830_item	2508694	et	2	main
кто	doc_491521501830_item	2508695	et	2	main
звонит	doc_491521501830_item	2508696	et	2	main
к	doc_491521501830_item	2508697	et	2	main
вам	doc_491521501830_item	2508698	et	2	main
в	doc_491521501830_item	2508699	et	2	main
дверь	doc_491521501830_item	2508700	et	2	main
можете	doc_491521501830_item	2508701	et	2	main
сдвигать	doc_491521501830_item	2508702	et	2	main
отодвигать	doc_491521501830_item	2508703	et	2	main
шторы	doc_491521501830_item	2508704	et	2	main
и	doc_491521501830_item	2508705	et	2	main
регулировать	doc_491521501830_item	2508706	et	2	main
температуру	doc_491521501830_item	2508707	et	2	main
в	doc_491521501830_item	2508708	et	2	main
комнате	doc_491521501830_item	2508709	et	2	main
лишь	doc_491521501830_item	2508710	et	2	main
нажатием	doc_491521501830_item	2508711	et	2	main
кнопки	doc_491521501830_item	2508712	et	2	main
включать	doc_491521501830_item	2508713	et	2	main
arvutivõrgu	doc_491521501830_item	2508663	et	3	main
микропроцессорам	doc_491521501830_item	2508674	et	2	main
вы	doc_491521501830_item	2508678	et	2	main
разместить	doc_491521501830_item	2508682	et	2	main
дороге	doc_491521501830_item	2508717	et	2	main
не	doc_491521501830_item	2508719	et	2	main
об	doc_491521501830_item	2508722	et	2	main
tegevust	doc_491521501830_item	2508731	et	4	main
või	doc_491521501830_item	2508733	et	4	main
väljapoole	doc_491521501830_item	2508734	et	3	main
lünka	doc_491521501830_item	2508740	et	4	main
vormis	doc_491521501830_item	2508744	et	4	main
jahtuma	doc_491521501830_item	2508746	et	3	main
ära	doc_491521501830_item	2508756	et	4	main
muidu	doc_491521501830_item	2508760	et	3	main
b	doc_491521501830_item	2508764	et	4	main
venitama	doc_491521501830_item	2508766	et	4	main
küll	doc_491521501830_item	2508769	et	4	main
tuleb	doc_491521501830_item	2508770	et	3	main
teine	doc_491521501830_item	2508777	et	3	main
venitab	doc_491521501830_item	2508780	et	3	main
oskasin	doc_491521501830_item	2508788	et	3	main
pidin	doc_491521501830_item	2508791	et	3	main
lahkuma	doc_491521501830_item	2508793	et	3	main
c	doc_491521501830_item	2508794	et	4	main
toetuma	doc_491521501830_item	2508795	et	4	main
toetama	doc_491521501830_item	2508796	et	3	main
teie	doc_491521501830_item	2508826	et	4	main
pulss	doc_491521501830_item	2508827	et	3	main
aeglustub	doc_491521501830_item	2508828	et	3	main
pälvib	doc_491521501830_item	2508839	et	3	main
tähelepanu	doc_491521501830_item	2508841	et	4	main
luust	doc_491521501830_item	2508843	et	4	main
ja	doc_491521501830_item	2508844	et	3	main
kirub	doc_491521501830_item	2508854	et	3	main
maapõhja	doc_491521501830_item	2508856	et	4	main
teeb	doc_491521501830_item	2508866	et	3	main
mulle	doc_491521501830_item	2508867	et	4	main
ülekohut	doc_491521501830_item	2508868	et	3	main
ta	doc_491521501830_item	2508869	et	4	main
päriselt	doc_491521501830_item	2508881	et	3	main
mitte	doc_491521501830_item	2508883	et	3	main
3-a	doc_491521501830_item	2508898	et	4	main
5-d	doc_491521501830_item	2508900	et	4	main
23	doc_491521501830_item	2508905	et	2	main
elektrita	doc_491521501830_item	2508913	et	3	main
teine	doc_491521501830_item	2508917	et	3	main
näpitstangid	doc_491521501830_item	2508919	et	3	main
основании	doc_491521501830_item	2508723	et	2	main
сети	doc_491521501830_item	2508727	et	2	main
enesekohast	doc_491521501830_item	2508730	et	4	main
väljendav	doc_491521501830_item	2508732	et	4	main
tee	doc_491521501830_item	2508750	et	4	main
ära	doc_491521501830_item	2508751	et	4	main
jahtub	doc_491521501830_item	2508752	et	3	main
muidu	doc_491521501830_item	2508753	et	3	main
kõrvetad	doc_491521501830_item	2508754	et	3	main
tee	doc_491521501830_item	2508758	et	4	main
et	doc_491521501830_item	2508771	et	3	main
väga	doc_491521501830_item	2508775	et	3	main
aga	doc_491521501830_item	2508779	et	3	main
äraminekuga	doc_491521501830_item	2508784	et	3	main
aga	doc_491521501830_item	2508789	et	3	main
ta	doc_491521501830_item	2508797	et	4	main
on	doc_491521501830_item	2508798	et	4	main
tõeline	doc_491521501830_item	2508799	et	4	main
sõber	doc_491521501830_item	2508800	et	3	main
kes	doc_491521501830_item	2508801	et	4	main
toetab	doc_491521501830_item	2508802	et	3	main
mind	doc_491521501830_item	2508803	et	4	main
igal	doc_491521501830_item	2508804	et	3	main
raskel	doc_491521501830_item	2508805	et	3	main
hetkel	doc_491521501830_item	2508806	et	4	main
ma	doc_491521501830_item	2508807	et	3	main
tean	doc_491521501830_item	2508808	et	3	main
et	doc_491521501830_item	2508809	et	3	main
võin	doc_491521501830_item	2508810	et	3	main
raskel	doc_491521501830_item	2508811	et	3	main
hetkel	doc_491521501830_item	2508812	et	4	main
talle	doc_491521501830_item	2508813	et	4	main
toetuda	doc_491521501830_item	2508814	et	3	main
d	doc_491521501830_item	2508815	et	4	main
aeglustuma	doc_491521501830_item	2508816	et	3	main
aeglustama	doc_491521501830_item	2508817	et	3	main
selle	doc_491521501830_item	2508818	et	4	main
rohu	doc_491521501830_item	2508819	et	4	main
tarvitamine	doc_491521501830_item	2508820	et	4	main
компьютерной	doc_491521501830_item	2508726	et	2	main
väljendav	doc_491521501830_item	2508737	et	4	main
tegusõna	doc_491521501830_item	2508738	et	4	main
kirjutage	doc_491521501830_item	2508739	et	3	main
sõna	doc_491521501830_item	2508742	et	4	main
keele	doc_491521501830_item	2508755	et	4	main
ära	doc_491521501830_item	2508759	et	4	main
lendab	doc_491521501830_item	2508773	et	3	main
teosammul	doc_491521501830_item	2508781	et	4	main
pulssi	doc_491521501830_item	2508822	et	4	main
rohu	doc_491521501830_item	2508824	et	4	main
tarvitamisel	doc_491521501830_item	2508825	et	4	main
väljendite	doc_491521501830_item	2508832	et	3	main
1	doc_491521501830_item	2508834	et	2	main
erilist	doc_491521501830_item	2508840	et	4	main
see	doc_491521501830_item	2508848	et	3	main
3	doc_491521501830_item	2508853	et	2	main
d	doc_491521501830_item	2508864	et	4	main
ta	doc_491521501830_item	2508865	et	4	main
mind	doc_491521501830_item	2508871	et	4	main
teeb	doc_491521501830_item	2508874	et	3	main
on	doc_491521501830_item	2508891	et	4	main
2-e	doc_491521501830_item	2508897	et	3	main
6-b	doc_491521501830_item	2508901	et	4	main
töötavad	doc_491521501830_item	2508912	et	4	main
see	doc_491521501830_item	2508915	et	3	main
haamer	doc_491521501830_item	2508922	et	3	main
akulaadija	doc_491521501830_item	2508924	et	4	main
kruvikeeraja	doc_491521501830_item	2508928	et	4	main
höövel	doc_491521501830_item	2508934	et	3	main
prits	doc_491521501830_item	2508940	et	3	main
pardel	doc_491521501830_item	2508941	et	4	main
kohviveski	doc_491521501830_item	2508942	et	4	main
juukseföön	doc_491521501830_item	2508943	et	3	main
kirves	doc_491521501830_item	2508944	et	4	main
puur	doc_491521501830_item	2508951	et	3	main
peale	doc_491521501831_item	2508979	et	4	main
kardinad	doc_491521501831_item	2508989	et	4	main
toatemperatuuri	doc_491521501831_item	2508993	et	4	main
nuppude	doc_491521501831_item	2508994	et	3	main
abil	doc_491521501831_item	2508995	et	4	main
lülitada	doc_491521501831_item	2508996	et	3	main
õhukonditsioneeri	doc_491521501831_item	2508997	et	4	main
эти	doc_491521501831_item	2509006	et	2	main
дигитальным	doc_491521501831_item	2509012	et	2	main
сейчас	doc_491521501831_item	2509017	et	2	main
которое	doc_491521501831_item	2509022	et	2	main
голосом	doc_491521501831_item	2509028	et	2	main
звонит	doc_491521501831_item	2509034	et	2	main
запрограмировать	doc_491521501831_item	2509039	et	2	main
в	doc_491521501831_item	2509044	et	2	main
дороге	doc_491521501831_item	2509052	et	2	main
о	doc_491521501831_item	2509057	et	2	main
5	doc_491521501831_item	2509063	et	2	main
enesekohast	doc_491521501831_item	2509065	et	4	main
väljapoole	doc_491521501831_item	2509069	et	3	main
tegevust	doc_491521501831_item	2509071	et	4	main
väljendav	doc_491521501831_item	2509072	et	4	main
tegusõna	doc_491521501831_item	2509073	et	4	main
kirjutage	doc_491521501831_item	2509074	et	3	main
a	doc_491521501831_item	2509080	et	4	main
jahtuma	doc_491521501831_item	2509081	et	3	main
jahutama	doc_491521501831_item	2509082	et	3	main
kõrvetad	doc_491521501831_item	2509089	et	3	main
jahuta	doc_491521501831_item	2509092	et	4	main
nii	doc_491521501830_item	2508785	et	3	main
lõpuks	doc_491521501830_item	2508790	et	4	main
siiski	doc_491521501830_item	2508792	et	4	main
sünonüümsete	doc_491521501830_item	2508831	et	3	main
paarid	doc_491521501830_item	2508833	et	4	main
joonde	doc_491521501830_item	2508837	et	4	main
kergelt	doc_491521501830_item	2508852	et	4	main
e	doc_491521501830_item	2508877	et	4	main
inimesed	doc_491521501830_item	2508878	et	3	main
olemas	doc_491521501830_item	2508882	et	4	main
6	doc_491521501830_item	2508885	et	2	main
vaeva	doc_491521501830_item	2508889	et	4	main
f	doc_491521501830_item	2508890	et	4	main
1-c	doc_491521501830_item	2508896	et	4	main
ja	doc_491521501830_item	2508903	et	3	main
nii	doc_491521501830_item	2508914	et	3	main
kui	doc_491521501830_item	2508916	et	3	main
tolmuimeja	doc_491521501830_item	2508927	et	4	main
ketassaag	doc_491521501830_item	2508933	et	3	main
akulaadija	doc_491521501830_item	2508945	et	4	main
haamer	doc_491521501830_item	2508953	et	3	main
höövel	doc_491521501830_item	2508955	et	3	main
praegu	doc_491521501831_item	2508971	et	3	main
valgustuse	doc_491521501831_item	2508974	et	4	main
töötab	doc_491521501831_item	2508976	et	3	main
suulise	doc_491521501831_item	2508977	et	4	main
käskluse	doc_491521501831_item	2508978	et	3	main
arvutivõrgu	doc_491521501831_item	2509003	et	3	main
ehitamisest	doc_491521501831_item	2509004	et	4	main
наконец-то	doc_491521501831_item	2509005	et	2	main
микропроцессорам	doc_491521501831_item	2509010	et	2	main
можете	doc_491521501831_item	2509015	et	2	main
дома	doc_491521501831_item	2509020	et	2	main
от	doc_491521501831_item	2509024	et	2	main
наблюдения	doc_491521501831_item	2509030	et	2	main
покажет	doc_491521501831_item	2509032	et	2	main
заранее	doc_491521501831_item	2509038	et	2	main
температуру	doc_491521501831_item	2509043	et	2	main
включать	doc_491521501831_item	2509048	et	2	main
домой	doc_491521501831_item	2509053	et	2	main
себя	doc_491521501831_item	2509061	et	2	main
tegevust	doc_491521501831_item	2509066	et	4	main
lünka	doc_491521501831_item	2509075	et	4	main
sobiv	doc_491521501831_item	2509076	et	4	main
sõna	doc_491521501831_item	2509077	et	4	main
õiges	doc_491521501831_item	2509078	et	3	main
jahtub	doc_491521501831_item	2509087	et	3	main
siiski	doc_491521501831_item	2509127	et	4	main
c	doc_491521501831_item	2509129	et	4	main
toetuma	doc_491521501831_item	2509130	et	4	main
toetama	doc_491521501831_item	2509131	et	3	main
ta	doc_491521501831_item	2509132	et	4	main
raskel	doc_491521501831_item	2509140	et	3	main
tarvitamisel	doc_491521501831_item	2509160	et	4	main
erilist	doc_491521501831_item	2509175	et	4	main
b	doc_491521501831_item	2509182	et	4	main
see	doc_491521501831_item	2509183	et	3	main
ei	doc_491521501831_item	2509184	et	4	main
ära	doc_491521501831_item	2509194	et	4	main
all	doc_491521501831_item	2509198	et	3	main
inimesed	doc_491521501831_item	2509213	et	3	main
enda	doc_491521501831_item	2509227	et	4	main
4-f	doc_491521501831_item	2509234	et	4	main
6-b	doc_491521501831_item	2509236	et	4	main
jukseföön	doc_491521501831_item	2509250	et	4	main
muruniiduk	doc_491521501831_item	2509255	et	3	main
kruvikeeraja	doc_491521501831_item	2509257	et	4	main
mutrivõti	doc_491521501831_item	2509270	et	4	main
kirves	doc_491521501831_item	2509279	et	4	main
akulaadija	doc_491521501831_item	2509280	et	4	main
haamer	doc_491521501831_item	2509288	et	3	main
teate	doc_491521501832_item	2509301	et	4	main
et	doc_491521501832_item	2509302	et	3	main
tõusete	doc_491521501832_item	2509303	et	4	main
kell	doc_491521501832_item	2509304	et	3	main
kaua	doc_491521501832_item	2509322	et	3	main
üht	doc_491521501832_item	2509323	et	3	main
teist	doc_491521501832_item	2509325	et	4	main
asja	doc_491521501832_item	2509326	et	4	main
seda	doc_491521501832_item	2509345	et	3	main
nagu	doc_491521501832_item	2509350	et	3	main
leidke	doc_491521501830_item	2508830	et	3	main
ajab	doc_491521501830_item	2508835	et	3	main
a	doc_491521501830_item	2508838	et	4	main
2	doc_491521501830_item	2508842	et	2	main
lihast	doc_491521501830_item	2508845	et	4	main
inimesed	doc_491521501830_item	2508846	et	3	main
on	doc_491521501830_item	2508861	et	4	main
luubi	doc_491521501830_item	2508862	et	3	main
all	doc_491521501830_item	2508863	et	3	main
kiusab	doc_491521501830_item	2508870	et	3	main
ta	doc_491521501830_item	2508873	et	4	main
kes	doc_491521501830_item	2508879	et	4	main
sellega	doc_491521501830_item	2508888	et	3	main
väga	doc_491521501830_item	2508894	et	3	main
tige	doc_491521501830_item	2508895	et	3	main
tööriistad	doc_491521501830_item	2508902	et	3	main
sõnad	doc_491521501830_item	2508907	et	4	main
rühma	doc_491521501830_item	2508909	et	4	main
töötavad	doc_491521501830_item	2508910	et	4	main
elektriga	doc_491521501830_item	2508911	et	3	main
juukseföön	doc_491521501830_item	2508921	et	3	main
pardel	doc_491521501830_item	2508923	et	4	main
kirves	doc_491521501830_item	2508925	et	4	main
mutrivõti	doc_491521501830_item	2508926	et	4	main
lood	doc_491521501830_item	2508930	et	4	main
muruniiduk	doc_491521501830_item	2508932	et	3	main
näpitstangid	doc_491521501830_item	2508937	et	3	main
mutrivõti	doc_491521501830_item	2508949	et	4	main
viil	doc_491521501830_item	2508950	et	3	main
jootekolb	doc_491521501830_item	2508954	et	4	main
1tõlkige	doc_491521501831_item	2508957	et	3	main
mis	doc_491521501831_item	2508975	et	4	main
kes	doc_491521501831_item	2508983	et	4	main
helistab	doc_491521501831_item	2508984	et	3	main
teie	doc_491521501831_item	2508985	et	4	main
ukse	doc_491521501831_item	2508986	et	3	main
taga	doc_491521501831_item	2508987	et	4	main
ette	doc_491521501831_item	2508990	et	4	main
reguleerida	doc_491521501831_item	2508992	et	3	main
koduse	doc_491521501831_item	2509002	et	4	main
благодаря	doc_491521501831_item	2509009	et	2	main
вы	doc_491521501831_item	2509014	et	2	main
уже	doc_491521501831_item	2509016	et	2	main
работает	doc_491521501831_item	2509023	et	2	main
приказа	doc_491521501831_item	2509026	et	2	main
которая	doc_491521501831_item	2509031	et	2	main
в	doc_491521501831_item	2509036	et	2	main
данные	doc_491521501831_item	2509040	et	2	main
комнате	doc_491521501831_item	2509045	et	2	main
кондиционер	doc_491521501831_item	2509049	et	2	main
говоря	doc_491521501831_item	2509055	et	2	main
сети	doc_491521501831_item	2509059	et	2	main
kas	doc_491521501831_item	2509064	et	3	main
või	doc_491521501831_item	2509068	et	4	main
kuni	doc_491521501831_item	2509084	et	3	main
keele	doc_491521501831_item	2509090	et	4	main
ära	doc_491521501831_item	2509091	et	4	main
tee	doc_491521501831_item	2509093	et	4	main
ära	doc_491521501831_item	2509094	et	4	main
muidu	doc_491521501831_item	2509095	et	3	main
kõrvetad	doc_491521501831_item	2509096	et	3	main
kui	doc_491521501831_item	2509122	et	3	main
oskasin	doc_491521501831_item	2509123	et	3	main
mind	doc_491521501831_item	2509138	et	4	main
võin	doc_491521501831_item	2509145	et	3	main
talle	doc_491521501831_item	2509148	et	4	main
teie	doc_491521501831_item	2509161	et	4	main
pulss	doc_491521501831_item	2509162	et	3	main
20	doc_491521501831_item	2509164	et	2	main
leidke	doc_491521501831_item	2509165	et	3	main
paarid	doc_491521501831_item	2509168	et	4	main
tähelepanu	doc_491521501831_item	2509176	et	4	main
talle	doc_491521501831_item	2509186	et	4	main
on	doc_491521501831_item	2509196	et	4	main
luubi	doc_491521501831_item	2509197	et	3	main
mulle	doc_491521501831_item	2509202	et	4	main
liiga	doc_491521501831_item	2509211	et	4	main
päriselt	doc_491521501831_item	2509216	et	3	main
mitte	doc_491521501831_item	2509218	et	3	main
pump	doc_491521501830_item	2508936	et	3	main
ketassaag	doc_491521501830_item	2508939	et	3	main
tolmuimeja	doc_491521501830_item	2508946	et	4	main
kruvikeeraja	doc_491521501830_item	2508947	et	4	main
pump	doc_491521501830_item	2508948	et	3	main
on	doc_491521501831_item	2508959	et	4	main
need	doc_491521501831_item	2508960	et	3	main
unistused	doc_491521501831_item	2508961	et	4	main
viimaks	doc_491521501831_item	2508962	et	4	main
täitumas	doc_491521501831_item	2508963	et	4	main
eeskätt	doc_491521501831_item	2508964	et	3	main
tänu	doc_491521501831_item	2508965	et	4	main
mikroprotsessoreile	doc_491521501831_item	2508966	et	3	main
ja	doc_491521501831_item	2508967	et	3	main
digitaaltehnoloogiale	doc_491521501831_item	2508968	et	3	main
võite	doc_491521501831_item	2508969	et	4	main
juba	doc_491521501831_item	2508970	et	3	main
koju	doc_491521501831_item	2508973	et	3	main
valvekaamera	doc_491521501831_item	2508980	et	4	main
mis	doc_491521501831_item	2508981	et	4	main
näitab	doc_491521501831_item	2508982	et	3	main
tõmmata	doc_491521501831_item	2508988	et	4	main
ja	doc_491521501831_item	2508991	et	3	main
мечты	doc_491521501831_item	2509007	et	2	main
и	doc_491521501831_item	2509011	et	2	main
разместить	doc_491521501831_item	2509019	et	2	main
освещение	doc_491521501831_item	2509021	et	2	main
камеру	doc_491521501831_item	2509029	et	2	main
кто	doc_491521501831_item	2509033	et	2	main
дверь	doc_491521501831_item	2509037	et	2	main
и	doc_491521501831_item	2509041	et	2	main
нажатием	doc_491521501831_item	2509046	et	2	main
уже	doc_491521501831_item	2509050	et	2	main
не	doc_491521501831_item	2509054	et	2	main
компьютерной	doc_491521501831_item	2509058	et	2	main
дома	doc_491521501831_item	2509062	et	2	main
väljendav	doc_491521501831_item	2509067	et	4	main
suunatud	doc_491521501831_item	2509070	et	4	main
oota	doc_491521501831_item	2509083	et	4	main
ära	doc_491521501831_item	2509086	et	4	main
kaua	doc_491521501831_item	2509121	et	3	main
lõpuks	doc_491521501831_item	2509125	et	4	main
lahkuma	doc_491521501831_item	2509128	et	3	main
ma	doc_491521501831_item	2509142	et	3	main
tean	doc_491521501831_item	2509143	et	3	main
toetama	doc_491521501831_item	2509149	et	3	main
selle	doc_491521501831_item	2509158	et	4	main
aeglustab	doc_491521501831_item	2509163	et	3	main
väljendite	doc_491521501831_item	2509167	et	3	main
1	doc_491521501831_item	2509169	et	2	main
ajab	doc_491521501831_item	2509170	et	3	main
asjad	doc_491521501831_item	2509171	et	3	main
joonde	doc_491521501831_item	2509172	et	4	main
a	doc_491521501831_item	2509173	et	4	main
pälvib	doc_491521501831_item	2509174	et	3	main
tulnud	doc_491521501831_item	2509185	et	4	main
on	doc_491521501831_item	2509215	et	4	main
f	doc_491521501831_item	2509225	et	4	main
jagage	doc_491521501831_item	2509238	et	3	main
pump	doc_491521501831_item	2509252	et	3	main
lood	doc_491521501831_item	2509267	et	4	main
prits	doc_491521501831_item	2509268	et	3	main
kirves	doc_491521501831_item	2509269	et	4	main
lood	doc_491521501831_item	2509273	et	4	main
prits	doc_491521501831_item	2509275	et	3	main
kohviveski	doc_491521501831_item	2509277	et	4	main
pump	doc_491521501831_item	2509283	et	3	main
muruniiduk	doc_491521501831_item	2509287	et	3	main
eksamitöö	doc_491521501832_item	2509291	et	4	main
mis	doc_491521501832_item	2509297	et	4	main
on	doc_491521501832_item	2509298	et	4	main
kui	doc_491521501832_item	2509321	et	3	main
või	doc_491521501832_item	2509328	et	4	main
ole	doc_491521501832_item	2509332	et	4	main
peal	doc_491521501832_item	2509342	et	4	main
külmiku	doc_491521501832_item	2509348	et	3	main
vorst	doc_491521501832_item	2509353	et	3	main
встаете	doc_491521501832_item	2509367	et	2	main
часов	doc_491521501832_item	2509370	et	2	main
сунте	doc_491521501832_item	2509377	et	2	main
не	doc_491521501832_item	2509395	et	2	main
не	doc_491521501832_item	2509416	et	2	main
kirjutage	doc_491521501832_item	2509421	et	3	main
asemel	doc_491521501832_item	2509427	et	4	main
haigestumise	doc_491521501832_item	2509435	et	4	main
inimestel	doc_491521501832_item	2509437	et	3	main
spordiga	doc_491521501832_item	2509446	et	3	main
spordiga	doc_491521501832_item	2509453	et	3	main
paraneb	doc_491521501832_item	2509455	et	3	main
3	doc_491521501832_item	2509457	et	2	main
eluiga	doc_491521501832_item	2509460	et	4	main
on	doc_491521501832_item	2509461	et	4	main
on	doc_491521501832_item	2509468	et	4	main
keskmist	doc_491521501832_item	2509470	et	3	main
pikendanud	doc_491521501832_item	2509472	et	4	main
inimesed	doc_491521501832_item	2509474	et	3	main
probleeme	doc_491521501832_item	2509481	et	3	main
5	doc_491521501832_item	2509489	et	2	main
tekivad	doc_491521501832_item	2509491	et	3	main
технологиям	doc_491521501831_item	2509013	et	2	main
расположить	doc_491521501831_item	2509018	et	2	main
голосового	doc_491521501831_item	2509025	et	2	main
включается	doc_491521501831_item	2509027	et	2	main
вам	doc_491521501831_item	2509035	et	2	main
регулировать	doc_491521501831_item	2509042	et	2	main
кнопки	doc_491521501831_item	2509047	et	2	main
по	doc_491521501831_item	2509051	et	2	main
уже	doc_491521501831_item	2509056	et	2	main
у	doc_491521501831_item	2509060	et	2	main
vormis	doc_491521501831_item	2509079	et	4	main
tee	doc_491521501831_item	2509085	et	4	main
muidu	doc_491521501831_item	2509088	et	3	main
keele	doc_491521501831_item	2509097	et	4	main
ära	doc_491521501831_item	2509098	et	4	main
b	doc_491521501831_item	2509099	et	4	main
venima	doc_491521501831_item	2509100	et	3	main
venitama	doc_491521501831_item	2509101	et	4	main
millest	doc_491521501831_item	2509102	et	3	main
see	doc_491521501831_item	2509103	et	3	main
küll	doc_491521501831_item	2509104	et	4	main
tuleb	doc_491521501831_item	2509105	et	3	main
et	doc_491521501831_item	2509106	et	3	main
mõnikord	doc_491521501831_item	2509107	et	3	main
lendab	doc_491521501831_item	2509108	et	3	main
aeg	doc_491521501831_item	2509109	et	3	main
väga	doc_491521501831_item	2509110	et	3	main
kiiresti	doc_491521501831_item	2509111	et	3	main
teine	doc_491521501831_item	2509112	et	3	main
kord	doc_491521501831_item	2509113	et	4	main
aga	doc_491521501831_item	2509114	et	3	main
venitab	doc_491521501831_item	2509115	et	3	main
teosammul	doc_491521501831_item	2509116	et	4	main
ma	doc_491521501831_item	2509117	et	3	main
venin	doc_491521501831_item	2509118	et	3	main
äraminekuga	doc_491521501831_item	2509119	et	3	main
nii	doc_491521501831_item	2509120	et	3	main
aga	doc_491521501831_item	2509124	et	3	main
pidin	doc_491521501831_item	2509126	et	3	main
tõeline	doc_491521501831_item	2509134	et	4	main
sõber	doc_491521501831_item	2509135	et	3	main
kes	doc_491521501831_item	2509136	et	4	main
toetub	doc_491521501831_item	2509137	et	3	main
hetkel	doc_491521501831_item	2509141	et	4	main
et	doc_491521501831_item	2509144	et	3	main
raskel	doc_491521501831_item	2509146	et	3	main
rohu	doc_491521501831_item	2509154	et	4	main
tarvitamine	doc_491521501831_item	2509155	et	4	main
aeglustab	doc_491521501831_item	2509156	et	3	main
pulssi	doc_491521501831_item	2509157	et	4	main
sünonüümsete	doc_491521501831_item	2509166	et	3	main
luust	doc_491521501831_item	2509178	et	4	main
lihast	doc_491521501831_item	2509180	et	4	main
kergelt	doc_491521501831_item	2509187	et	4	main
3	doc_491521501831_item	2509188	et	2	main
kirub	doc_491521501831_item	2509189	et	3	main
ennast	doc_491521501831_item	2509190	et	4	main
maapõhja	doc_491521501831_item	2509191	et	4	main
c	doc_491521501831_item	2509192	et	4	main
korraldab	doc_491521501831_item	2509193	et	3	main
on	doc_491521501831_item	2509133	et	4	main
igal	doc_491521501831_item	2509139	et	3	main
hetkel	doc_491521501831_item	2509147	et	4	main
d	doc_491521501831_item	2509150	et	4	main
aeglustuma	doc_491521501831_item	2509151	et	3	main
aeglustama	doc_491521501831_item	2509152	et	3	main
selle	doc_491521501831_item	2509153	et	4	main
rohu	doc_491521501831_item	2509159	et	4	main
2	doc_491521501831_item	2509177	et	2	main
ja	doc_491521501831_item	2509179	et	3	main
inimesed	doc_491521501831_item	2509181	et	3	main
4	doc_491521501831_item	2509195	et	2	main
d	doc_491521501831_item	2509199	et	4	main
ta	doc_491521501831_item	2509200	et	4	main
teeb	doc_491521501831_item	2509201	et	3	main
ülekohut	doc_491521501831_item	2509203	et	3	main
ta	doc_491521501831_item	2509204	et	4	main
kiusab	doc_491521501831_item	2509205	et	3	main
e	doc_491521501831_item	2509212	et	4	main
olemas	doc_491521501831_item	2509217	et	4	main
6	doc_491521501831_item	2509220	et	2	main
raamatutegelased	doc_491521501831_item	2509219	et	3	main
ta	doc_491521501831_item	2509221	et	4	main
vaeva	doc_491521501831_item	2509224	et	4	main
peale	doc_491521501831_item	2509228	et	4	main
tige	doc_491521501831_item	2509230	et	3	main
2-e	doc_491521501831_item	2509232	et	3	main
23	doc_491521501831_item	2509237	et	2	main
kolme	doc_491521501831_item	2509240	et	4	main
töötavad	doc_491521501831_item	2509244	et	4	main
elektrita	doc_491521501831_item	2509245	et	3	main
nii	doc_491521501831_item	2509246	et	3	main
see	doc_491521501831_item	2509247	et	3	main
kui	doc_491521501831_item	2509248	et	3	main
teine	doc_491521501831_item	2509249	et	3	main
viil	doc_491521501831_item	2509254	et	3	main
kohviveski	doc_491521501831_item	2509256	et	4	main
tolmuimeja	doc_491521501831_item	2509258	et	4	main
autos	doc_491521501831_item	2509259	et	3	main
töötab	doc_491521501831_item	2509260	et	3	main
elektriga	doc_491521501831_item	2509261	et	3	main
ketassaag	doc_491521501831_item	2509262	et	3	main
puur	doc_491521501831_item	2509263	et	3	main
jootekolb	doc_491521501831_item	2509264	et	4	main
höövel	doc_491521501831_item	2509271	et	3	main
höövel	doc_491521501831_item	2509290	et	3	main
edasi	doc_491521501832_item	2509294	et	3	main
valmistada	doc_491521501832_item	2509327	et	3	main
ei	doc_491521501832_item	2509331	et	4	main
vaja	doc_491521501832_item	2509333	et	4	main
muretseda	doc_491521501832_item	2509334	et	3	main
ega	doc_491521501832_item	2509335	et	3	main
rõõsk	doc_491521501832_item	2509336	et	3	main
koor	doc_491521501832_item	2509337	et	4	main
kokku	doc_491521501832_item	2509343	et	3	main
tõmbu	doc_491521501832_item	2509344	et	4	main
uksel	doc_491521501832_item	2509349	et	3	main
sedagi	doc_491521501832_item	2509351	et	3	main
далее	doc_491521501832_item	2509358	et	2	main
известие	doc_491521501832_item	2509363	et	2	main
в	doc_491521501832_item	2509368	et	2	main
этому	doc_491521501832_item	2509372	et	2	main
затем	doc_491521501832_item	2509376	et	2	main
печь	doc_491521501832_item	2509381	et	2	main
и	doc_491521501832_item	2509414	et	2	main
испортилась	doc_491521501832_item	2509417	et	2	main
mind	doc_491521501831_item	2509206	et	4	main
5	doc_491521501831_item	2509207	et	2	main
ta	doc_491521501831_item	2509208	et	4	main
teeb	doc_491521501831_item	2509209	et	3	main
mulle	doc_491521501831_item	2509210	et	4	main
kes	doc_491521501831_item	2509214	et	4	main
sellega	doc_491521501831_item	2509223	et	3	main
3-a	doc_491521501831_item	2509233	et	4	main
sõnad	doc_491521501831_item	2509239	et	4	main
rühma	doc_491521501831_item	2509241	et	4	main
töötavad	doc_491521501831_item	2509242	et	4	main
elektriga	doc_491521501831_item	2509243	et	3	main
näpitstangid	doc_491521501831_item	2509251	et	3	main
pardel	doc_491521501831_item	2509265	et	4	main
haamer	doc_491521501831_item	2509266	et	3	main
ketassaag	doc_491521501831_item	2509274	et	3	main
tolmuimeja	doc_491521501831_item	2509281	et	4	main
kruvikeeraja	doc_491521501831_item	2509282	et	4	main
1	doc_491521501832_item	2509292	et	2	main
kohvimasin	doc_491521501832_item	2509296	et	3	main
nägi	doc_491521501831_item	2509222	et	3	main
on	doc_491521501831_item	2509226	et	4	main
väga	doc_491521501831_item	2509229	et	3	main
1-c	doc_491521501831_item	2509231	et	4	main
5-d	doc_491521501831_item	2509235	et	4	main
akulaadija	doc_491521501831_item	2509253	et	4	main
näpitstangid	doc_491521501831_item	2509272	et	3	main
pardel	doc_491521501831_item	2509276	et	4	main
juukseföön	doc_491521501831_item	2509278	et	3	main
mutrivõti	doc_491521501831_item	2509284	et	4	main
viil	doc_491521501831_item	2509285	et	3	main
puur	doc_491521501831_item	2509286	et	3	main
jootekolb	doc_491521501831_item	2509289	et	4	main
tõlkige	doc_491521501832_item	2509293	et	3	main
kööki	doc_491521501832_item	2509295	et	4	main
saanud	doc_491521501832_item	2509299	et	4	main
äratuskellalt	doc_491521501832_item	2509300	et	3	main
seitse	doc_491521501832_item	2509305	et	3	main
on	doc_491521501832_item	2509306	et	4	main
just	doc_491521501832_item	2509307	et	3	main
selleks	doc_491521501832_item	2509308	et	4	main
ajaks	doc_491521501832_item	2509309	et	4	main
kohvi	doc_491521501832_item	2509310	et	4	main
keetnud	doc_491521501832_item	2509311	et	4	main
seejärel	doc_491521501832_item	2509312	et	3	main
pistke	doc_491521501832_item	2509313	et	3	main
toit	doc_491521501832_item	2509314	et	3	main
mikrolaineahju	doc_491521501832_item	2509315	et	4	main
küll	doc_491521501832_item	2509316	et	4	main
tark	doc_491521501832_item	2509317	et	3	main
masin	doc_491521501832_item	2509318	et	3	main
ära	doc_491521501832_item	2509319	et	4	main
tunneb	doc_491521501832_item	2509320	et	3	main
või	doc_491521501832_item	2509324	et	4	main
soojendada	doc_491521501832_item	2509329	et	3	main
hapu	doc_491521501832_item	2509338	et	4	main
ole	doc_491521501832_item	2509339	et	4	main
teatab	doc_491521501832_item	2509346	et	3	main
kas	doc_491521501832_item	2509352	et	3	main
vanaks	doc_491521501832_item	2509356	et	3	main
кофеварка	doc_491521501832_item	2509360	et	2	main
от	doc_491521501832_item	2509364	et	2	main
7	doc_491521501832_item	2509369	et	2	main
сварила	doc_491521501832_item	2509374	et	2	main
еду	doc_491521501832_item	2509378	et	2	main
то	doc_491521501832_item	2509415	et	2	main
ли	doc_491521501832_item	2509418	et	2	main
ümber	doc_491521501832_item	2509423	et	3	main
sihitu	doc_491521501832_item	2509425	et	4	main
tegusõna	doc_491521501832_item	2509426	et	4	main
vastupidi	doc_491521501832_item	2509430	et	3	main
pidev	doc_491521501832_item	2509432	et	3	main
suurendab	doc_491521501832_item	2509434	et	3	main
risk	doc_491521501832_item	2509444	et	3	main
tervist	doc_491521501832_item	2509449	et	4	main
aja	doc_491521501832_item	2509462	et	4	main
tsivilisatsiooni	doc_491521501832_item	2509466	et	4	main
eluiga	doc_491521501832_item	2509471	et	4	main
muudavad	doc_491521501832_item	2509475	et	4	main
looduskeskkonda	doc_491521501832_item	2509476	et	4	main
ja	doc_491521501832_item	2509477	et	3	main
koosmõjul	doc_491521501832_item	2509494	et	3	main
tegurite	doc_491521501832_item	2509496	et	3	main
haigusi	doc_491521501832_item	2509499	et	4	main
moodustage	doc_491521501832_item	2509501	et	3	main
samuti	doc_491521501832_item	2509330	et	3	main
ega	doc_491521501832_item	2509340	et	3	main
kohvi	doc_491521501832_item	2509341	et	4	main
monitor	doc_491521501832_item	2509347	et	3	main
pole	doc_491521501832_item	2509354	et	3	main
läinud	doc_491521501832_item	2509357	et	4	main
которая	doc_491521501832_item	2509361	et	2	main
будильника	doc_491521501832_item	2509365	et	2	main
к	doc_491521501832_item	2509371	et	2	main
кофе	doc_491521501832_item	2509375	et	2	main
микроволновую	doc_491521501832_item	2509380	et	2	main
умная	doc_491521501832_item	2509382	et	2	main
машина	doc_491521501832_item	2509383	et	2	main
обязательно	doc_491521501832_item	2509384	et	2	main
знает	doc_491521501832_item	2509385	et	2	main
сколько	doc_491521501832_item	2509386	et	2	main
одну	doc_491521501832_item	2509387	et	2	main
или	doc_491521501832_item	2509388	et	2	main
другую	doc_491521501832_item	2509389	et	2	main
вещь	doc_491521501832_item	2509390	et	2	main
готовить	doc_491521501832_item	2509391	et	2	main
или	doc_491521501832_item	2509392	et	2	main
также	doc_491521501832_item	2509394	et	2	main
согревать	doc_491521501832_item	2509393	et	2	main
надо	doc_491521501832_item	2509396	et	2	main
беспокоться	doc_491521501832_item	2509397	et	2	main
ни	doc_491521501832_item	2509398	et	2	main
ли	doc_491521501832_item	2509400	et	2	main
прокисли	doc_491521501832_item	2509399	et	2	main
сливки	doc_491521501832_item	2509401	et	2	main
ни	doc_491521501832_item	2509402	et	2	main
свернутся	doc_491521501832_item	2509403	et	2	main
ли	doc_491521501832_item	2509404	et	2	main
в	doc_491521501832_item	2509405	et	2	main
это	doc_491521501832_item	2509407	et	2	main
кофе	doc_491521501832_item	2509406	et	2	main
распознает	doc_491521501832_item	2509408	et	2	main
монитор	doc_491521501832_item	2509409	et	2	main
на	doc_491521501832_item	2509410	et	2	main
холодильника	doc_491521501832_item	2509412	et	2	main
двери	doc_491521501832_item	2509411	et	2	main
mitte	doc_491521501832_item	2509355	et	3	main
кухня	doc_491521501832_item	2509359	et	2	main
получила	doc_491521501832_item	2509362	et	2	main
что	doc_491521501832_item	2509366	et	2	main
времени	doc_491521501832_item	2509373	et	2	main
в	doc_491521501832_item	2509379	et	2	main
как	doc_491521501832_item	2509413	et	2	main
11	doc_491521501832_item	2509420	et	2	main
ja	doc_491521501832_item	2509429	et	3	main
riski	doc_491521501832_item	2509436	et	4	main
kes	doc_491521501832_item	2509438	et	4	main
on	doc_491521501832_item	2509439	et	4	main
pidevas	doc_491521501832_item	2509440	et	3	main
stressis	doc_491521501832_item	2509441	et	3	main
suureneb	doc_491521501832_item	2509442	et	3	main
parandab	doc_491521501832_item	2509448	et	3	main
te	doc_491521501832_item	2509451	et	4	main
jooksul	doc_491521501832_item	2509463	et	4	main
areng	doc_491521501832_item	2509467	et	3	main
tekitavad	doc_491521501832_item	2509478	et	4	main
kui	doc_491521501832_item	2509482	et	3	main
siis	doc_491521501832_item	2509485	et	3	main
paljude	doc_491521501832_item	2509492	et	3	main
tekitab	doc_491521501832_item	2509498	et	3	main
22	doc_491521501832_item	2509500	et	2	main
vedur	doc_491521501832_item	2509511	et	3	main
вентилятор	doc_491521501832_item	2509522	et	2	main
printima	doc_491521501832_item	2509526	et	3	main
kõlar	doc_491521501832_item	2509528	et	3	main
kuvar	doc_491521501832_item	2509530	et	3	main
делать	doc_491521501832_item	2509534	et	2	main
keelde	doc_491521501832_item	2509543	et	4	main
опасно	doc_491521501832_item	2509550	et	2	main
ärge	doc_491521501832_item	2509553	et	3	main
rikkis	doc_491521501832_item	2509555	et	3	main
see	doc_491521501832_item	2509557	et	3	main
eluohtlik	doc_491521501832_item	2509559	et	3	main
в	doc_491521501832_item	2509561	et	2	main
привело	doc_491521501832_item	2509566	et	2	main
эта	doc_491521501832_item	2509570	et	2	main
мощная	doc_491521501832_item	2509573	et	2	main
настольной	doc_491521501832_item	2509576	et	2	main
lambipirn	doc_491521501832_item	2509579	et	3	main
võimas	doc_491521501832_item	2509582	et	4	main
asja	doc_491521501833_item	2509621	et	4	main
või	doc_491521501833_item	2509623	et	4	main
ei	doc_491521501833_item	2509626	et	4	main
kokku	doc_491521501833_item	2509638	et	3	main
seda	doc_491521501833_item	2509640	et	3	main
teatab	doc_491521501833_item	2509641	et	3	main
külmiku	doc_491521501833_item	2509643	et	3	main
sedagi	doc_491521501833_item	2509646	et	3	main
läinud	doc_491521501833_item	2509652	et	4	main
кофеварка	doc_491521501833_item	2509658	et	2	main
будильника	doc_491521501833_item	2509663	et	2	main
7	doc_491521501833_item	2509668	et	2	main
кофе	doc_491521501833_item	2509674	et	2	main
этим	doc_491521501833_item	2509678	et	2	main
11	doc_491521501833_item	2509724	et	2	main
ümber	doc_491521501833_item	2509727	et	3	main
asemel	doc_491521501833_item	2509731	et	4	main
ja	doc_491521501833_item	2509733	et	3	main
1	doc_491521501833_item	2509735	et	2	main
suurendab	doc_491521501833_item	2509738	et	3	main
2	doc_491521501833_item	2509749	et	2	main
tsivilisatsiooni	doc_491521501833_item	2509770	et	4	main
areng	doc_491521501833_item	2509771	et	3	main
looduskeskkonda	doc_491521501833_item	2509780	et	4	main
ja	doc_491521501833_item	2509781	et	3	main
kui	doc_491521501833_item	2509786	et	3	main
looduskeskkond	doc_491521501833_item	2509787	et	3	main
tekkib	doc_491521501833_item	2509790	et	3	main
koosmõjul	doc_491521501833_item	2509799	et	3	main
колбаса	doc_491521501832_item	2509419	et	2	main
sihilist	doc_491521501832_item	2509428	et	4	main
haigestumise	doc_491521501832_item	2509443	et	4	main
2	doc_491521501832_item	2509445	et	2	main
tegelete	doc_491521501832_item	2509452	et	3	main
teil	doc_491521501832_item	2509454	et	4	main
inimeste	doc_491521501832_item	2509458	et	3	main
pidevalt	doc_491521501832_item	2509464	et	4	main
pikenenud	doc_491521501832_item	2509465	et	4	main
4	doc_491521501832_item	2509473	et	2	main
muutub	doc_491521501832_item	2509484	et	3	main
uued	doc_491521501832_item	2509487	et	3	main
tõlkige	doc_491521501832_item	2509504	et	3	main
siduma	doc_491521501832_item	2509508	et	3	main
puhuma	doc_491521501832_item	2509510	et	3	main
проводящий	doc_491521501832_item	2509512	et	2	main
kallur	doc_491521501832_item	2509513	et	3	main
puhur	doc_491521501832_item	2509521	et	3	main
röster	doc_491521501832_item	2509532	et	3	main
printer	doc_491521501832_item	2509536	et	3	main
электроприборами	doc_491521501832_item	2509548	et	2	main
жизни	doc_491521501832_item	2509552	et	2	main
замыкание	doc_491521501832_item	2509564	et	2	main
пожару	doc_491521501832_item	2509568	et	2	main
слишком	doc_491521501832_item	2509572	et	2	main
для	doc_491521501832_item	2509574	et	2	main
лампы	doc_491521501832_item	2509577	et	2	main
liiga	doc_491521501832_item	2509581	et	4	main
mis	doc_491521501833_item	2509592	et	4	main
muretseda	doc_491521501833_item	2509629	et	3	main
peal	doc_491521501833_item	2509637	et	4	main
tõmbu	doc_491521501833_item	2509639	et	4	main
monitor	doc_491521501833_item	2509642	et	3	main
kas	doc_491521501833_item	2509647	et	3	main
назад	doc_491521501833_item	2509653	et	2	main
кухню	doc_491521501833_item	2509657	et	2	main
сообщение	doc_491521501833_item	2509661	et	2	main
вы	doc_491521501833_item	2509665	et	2	main
к	doc_491521501833_item	2509670	et	2	main
этому	doc_491521501833_item	2509671	et	2	main
след	doc_491521501833_item	2509676	et	2	main
положите	doc_491521501833_item	2509679	et	2	main
печь	doc_491521501833_item	2509683	et	2	main
не	doc_491521501833_item	2509720	et	2	main
laused	doc_491521501833_item	2509726	et	3	main
sihitu	doc_491521501833_item	2509729	et	4	main
on	doc_491521501833_item	2509743	et	4	main
pidevas	doc_491521501833_item	2509744	et	3	main
stressis	doc_491521501833_item	2509745	et	3	main
eluiga	doc_491521501833_item	2509764	et	4	main
pidevalt	doc_491521501833_item	2509768	et	4	main
pikenenud	doc_491521501833_item	2509769	et	4	main
muudavad	doc_491521501833_item	2509779	et	4	main
probleeme	doc_491521501833_item	2509785	et	3	main
uusi	doc_491521501833_item	2509792	et	3	main
puhur	doc_491521501833_item	2509821	et	3	main
röstima	doc_491521501833_item	2509824	et	3	main
пользуйтесь	doc_491521501833_item	2509838	et	2	main
для	doc_491521501833_item	2509843	et	2	main
see	doc_491521501833_item	2509849	et	3	main
привело	doc_491521501833_item	2509859	et	2	main
mis	doc_491521501833_item	2509865	et	4	main
tekitas	doc_491521501833_item	2509866	et	3	main
tulekahju	doc_491521501833_item	2509867	et	4	main
pirn	doc_491521501833_item	2509878	et	3	main
on	doc_491521501833_item	2509879	et	4	main
meeldivalt	doc_491521501834_item	2509898	et	4	main
teiste	doc_491521501834_item	2509905	et	4	main
nii	doc_491521501834_item	2509922	et	3	main
on	doc_491521501834_item	2509930	et	4	main
midagi	doc_491521501834_item	2509931	et	4	main
väikse	doc_491521501834_item	2509944	et	4	main
herman	doc_491521501834_item	2509952	et	4	main
just	doc_491521501834_item	2509990	et	3	main
nüüd	doc_491521501834_item	2509991	et	4	main
mängivad	doc_491521501834_item	2510011	et	4	main
teadmata	doc_491521501834_item	2510013	et	4	main
elu	doc_491521501834_item	2510015	et	4	main
võimalikkudest	doc_491521501834_item	2510016	et	3	main
mustadest	doc_491521501834_item	2510017	et	3	main
laused	doc_491521501832_item	2509422	et	3	main
kasutades	doc_491521501832_item	2509424	et	3	main
1	doc_491521501832_item	2509431	et	2	main
stress	doc_491521501832_item	2509433	et	3	main
tegelemine	doc_491521501832_item	2509447	et	4	main
kui	doc_491521501832_item	2509450	et	3	main
tervis	doc_491521501832_item	2509456	et	3	main
keskmine	doc_491521501832_item	2509459	et	3	main
inimeste	doc_491521501832_item	2509469	et	3	main
sellega	doc_491521501832_item	2509479	et	3	main
uusi	doc_491521501832_item	2509480	et	3	main
looduskeskkond	doc_491521501832_item	2509483	et	3	main
tekivad	doc_491521501832_item	2509486	et	3	main
probleemid	doc_491521501832_item	2509488	et	3	main
haigused	doc_491521501832_item	2509490	et	4	main
tegurite	doc_491521501832_item	2509493	et	3	main
paljude	doc_491521501832_item	2509495	et	3	main
r-liitelisi	doc_491521501832_item	2509502	et	4	main
helkur	doc_491521501832_item	2509515	et	4	main
отражатель	doc_491521501832_item	2509516	et	2	main
sidur	doc_491521501832_item	2509517	et	3	main
связующий	doc_491521501832_item	2509518	et	2	main
pidur	doc_491521501832_item	2509519	et	3	main
тормоз	doc_491521501832_item	2509520	et	2	main
kõlama	doc_491521501832_item	2509523	et	3	main
колонка	doc_491521501832_item	2509529	et	2	main
хлеб	doc_491521501832_item	2509535	et	2	main
2	doc_491521501832_item	2509540	et	2	main
не	doc_491521501832_item	2509545	et	2	main
неисправными	doc_491521501832_item	2509547	et	2	main
произошло	doc_491521501832_item	2509563	et	2	main
c	doc_491521501832_item	2509569	et	4	main
selle	doc_491521501832_item	2509583	et	4	main
eksamitöö	doc_491521501833_item	2509586	et	4	main
1	doc_491521501833_item	2509587	et	2	main
tõlkige	doc_491521501833_item	2509588	et	3	main
kööki	doc_491521501833_item	2509590	et	4	main
kohvimasin	doc_491521501833_item	2509591	et	3	main
ole	doc_491521501833_item	2509627	et	4	main
rõõsk	doc_491521501833_item	2509631	et	3	main
hapu	doc_491521501833_item	2509633	et	4	main
kohvi	doc_491521501833_item	2509636	et	4	main
nagu	doc_491521501833_item	2509645	et	3	main
mitte	doc_491521501833_item	2509650	et	3	main
на	doc_491521501833_item	2509656	et	2	main
от	doc_491521501833_item	2509662	et	2	main
в	doc_491521501833_item	2509667	et	2	main
времени	doc_491521501833_item	2509672	et	2	main
за	doc_491521501833_item	2509677	et	2	main
в	doc_491521501833_item	2509681	et	2	main
холодильника	doc_491521501833_item	2509717	et	2	main
испортилась	doc_491521501833_item	2509721	et	2	main
kasutades	doc_491521501833_item	2509728	et	3	main
vastupidi	doc_491521501833_item	2509734	et	3	main
pidev	doc_491521501833_item	2509736	et	3	main
haigestumise	doc_491521501833_item	2509739	et	4	main
riski	doc_491521501833_item	2509740	et	4	main
inimestel	doc_491521501833_item	2509741	et	3	main
kes	doc_491521501833_item	2509742	et	4	main
risk	doc_491521501833_item	2509748	et	3	main
spordiga	doc_491521501833_item	2509750	et	3	main
parandab	doc_491521501833_item	2509752	et	3	main
kui	doc_491521501833_item	2509754	et	3	main
te	doc_491521501833_item	2509755	et	4	main
tegelete	doc_491521501833_item	2509756	et	3	main
on	doc_491521501833_item	2509765	et	4	main
keskmist	doc_491521501833_item	2509774	et	3	main
sellega	doc_491521501833_item	2509783	et	3	main
probleeme	doc_491521501833_item	2509793	et	3	main
tekivad	doc_491521501833_item	2509796	et	3	main
paljude	doc_491521501833_item	2509800	et	3	main
printima	doc_491521501833_item	2509825	et	3	main
kõlar	doc_491521501833_item	2509827	et	3	main
kuvar	doc_491521501833_item	2509828	et	3	main
koosmõju	doc_491521501832_item	2509497	et	4	main
nimisõnu	doc_491521501832_item	2509503	et	3	main
kallama	doc_491521501832_item	2509506	et	3	main
vedama	doc_491521501832_item	2509505	et	3	main
helkima	doc_491521501832_item	2509507	et	3	main
pidama	doc_491521501832_item	2509509	et	4	main
рыбак	doc_491521501832_item	2509514	et	2	main
kuvama	doc_491521501832_item	2509524	et	4	main
skännima	doc_491521501832_item	2509527	et	4	main
монитор	doc_491521501832_item	2509531	et	2	main
skänner	doc_491521501832_item	2509538	et	4	main
tõlkige	doc_491521501832_item	2509541	et	3	main
a	doc_491521501832_item	2509544	et	4	main
это	doc_491521501832_item	2509549	et	2	main
elektriseadmeid	doc_491521501832_item	2509556	et	3	main
on	doc_491521501832_item	2509558	et	4	main
b	doc_491521501832_item	2509560	et	4	main
что	doc_491521501832_item	2509565	et	2	main
edasi	doc_491521501833_item	2509589	et	3	main
teate	doc_491521501833_item	2509596	et	4	main
röstima	doc_491521501832_item	2509525	et	3	main
тостер	doc_491521501832_item	2509533	et	2	main
принтер	doc_491521501832_item	2509537	et	2	main
сканер	doc_491521501832_item	2509539	et	2	main
eesti	doc_491521501832_item	2509542	et	4	main
пользуйтесь	doc_491521501832_item	2509546	et	2	main
для	doc_491521501832_item	2509551	et	2	main
kasutage	doc_491521501832_item	2509554	et	3	main
проводке	doc_491521501832_item	2509562	et	2	main
к	doc_491521501832_item	2509567	et	2	main
лампочка	doc_491521501832_item	2509571	et	2	main
этой	doc_491521501832_item	2509575	et	2	main
see	doc_491521501832_item	2509578	et	3	main
on	doc_491521501832_item	2509580	et	4	main
laualambi	doc_491521501832_item	2509584	et	3	main
jaoks	doc_491521501832_item	2509585	et	4	main
on	doc_491521501833_item	2509593	et	4	main
saanud	doc_491521501833_item	2509594	et	4	main
äratuskellalt	doc_491521501833_item	2509595	et	3	main
et	doc_491521501833_item	2509597	et	3	main
tõusete	doc_491521501833_item	2509598	et	4	main
kell	doc_491521501833_item	2509599	et	3	main
seitse	doc_491521501833_item	2509600	et	3	main
on	doc_491521501833_item	2509601	et	4	main
just	doc_491521501833_item	2509602	et	3	main
selleks	doc_491521501833_item	2509603	et	4	main
ajaks	doc_491521501833_item	2509604	et	4	main
kohvi	doc_491521501833_item	2509605	et	4	main
keetnud	doc_491521501833_item	2509606	et	4	main
seejärel	doc_491521501833_item	2509607	et	3	main
pistke	doc_491521501833_item	2509608	et	3	main
toit	doc_491521501833_item	2509609	et	3	main
mikrolaineahju	doc_491521501833_item	2509610	et	4	main
küll	doc_491521501833_item	2509611	et	4	main
tark	doc_491521501833_item	2509612	et	3	main
masin	doc_491521501833_item	2509613	et	3	main
ära	doc_491521501833_item	2509614	et	4	main
tunneb	doc_491521501833_item	2509615	et	3	main
kui	doc_491521501833_item	2509616	et	3	main
kaua	doc_491521501833_item	2509617	et	3	main
üht	doc_491521501833_item	2509618	et	3	main
või	doc_491521501833_item	2509619	et	4	main
teist	doc_491521501833_item	2509620	et	4	main
vaja	doc_491521501833_item	2509628	et	4	main
ega	doc_491521501833_item	2509630	et	3	main
koor	doc_491521501833_item	2509632	et	4	main
ole	doc_491521501833_item	2509634	et	4	main
ega	doc_491521501833_item	2509635	et	3	main
uksel	doc_491521501833_item	2509644	et	3	main
pole	doc_491521501833_item	2509649	et	3	main
обратно	doc_491521501833_item	2509654	et	2	main
которая	doc_491521501833_item	2509659	et	2	main
что	doc_491521501833_item	2509664	et	2	main
часов	doc_491521501833_item	2509669	et	2	main
сварила	doc_491521501833_item	2509673	et	2	main
микроволновую	doc_491521501833_item	2509682	et	2	main
то	doc_491521501833_item	2509719	et	2	main
valmistada	doc_491521501833_item	2509622	et	3	main
soojendada	doc_491521501833_item	2509624	et	3	main
samuti	doc_491521501833_item	2509625	et	3	main
vorst	doc_491521501833_item	2509648	et	3	main
vanaks	doc_491521501833_item	2509651	et	3	main
дальше	doc_491521501833_item	2509655	et	2	main
получила	doc_491521501833_item	2509660	et	2	main
встаете	doc_491521501833_item	2509666	et	2	main
в	doc_491521501833_item	2509675	et	2	main
еду	doc_491521501833_item	2509680	et	2	main
умная	doc_491521501833_item	2509684	et	2	main
машина	doc_491521501833_item	2509685	et	2	main
сколько	doc_491521501833_item	2509687	et	2	main
распознает	doc_491521501833_item	2509686	et	2	main
ту	doc_491521501833_item	2509688	et	2	main
или	doc_491521501833_item	2509689	et	2	main
иную	doc_491521501833_item	2509690	et	2	main
вещь	doc_491521501833_item	2509691	et	2	main
готовить	doc_491521501833_item	2509692	et	2	main
или	doc_491521501833_item	2509693	et	2	main
подогревать	doc_491521501833_item	2509694	et	2	main
к	doc_491521501833_item	2509695	et	2	main
тому	doc_491521501833_item	2509696	et	2	main
же	doc_491521501833_item	2509697	et	2	main
не	doc_491521501833_item	2509698	et	2	main
нужно	doc_491521501833_item	2509699	et	2	main
беспокоиться	doc_491521501833_item	2509700	et	2	main
не	doc_491521501833_item	2509701	et	2	main
скисли	doc_491521501833_item	2509702	et	2	main
сливки	doc_491521501833_item	2509704	et	2	main
ли	doc_491521501833_item	2509703	et	2	main
и	doc_491521501833_item	2509705	et	2	main
не	doc_491521501833_item	2509706	et	2	main
свернутся	doc_491521501833_item	2509707	et	2	main
они	doc_491521501833_item	2509709	et	2	main
ли	doc_491521501833_item	2509708	et	2	main
кофе	doc_491521501833_item	2509711	et	2	main
в	doc_491521501833_item	2509710	et	2	main
это	doc_491521501833_item	2509712	et	2	main
покажет	doc_491521501833_item	2509713	et	2	main
монитор	doc_491521501833_item	2509714	et	2	main
на	doc_491521501833_item	2509715	et	2	main
двери	doc_491521501833_item	2509716	et	2	main
даже	doc_491521501833_item	2509718	et	2	main
колбаса	doc_491521501833_item	2509723	et	2	main
haigestumise	doc_491521501833_item	2509747	et	4	main
tegelemine	doc_491521501833_item	2509751	et	4	main
tervist	doc_491521501833_item	2509753	et	4	main
aja	doc_491521501833_item	2509766	et	4	main
jooksul	doc_491521501833_item	2509767	et	4	main
eluiga	doc_491521501833_item	2509775	et	4	main
pikendanud	doc_491521501833_item	2509776	et	4	main
4	doc_491521501833_item	2509777	et	2	main
inimesed	doc_491521501833_item	2509778	et	3	main
uusi	doc_491521501833_item	2509784	et	3	main
muutub	doc_491521501833_item	2509788	et	3	main
sellega	doc_491521501833_item	2509791	et	3	main
5	doc_491521501833_item	2509794	et	2	main
paljude	doc_491521501833_item	2509797	et	3	main
koosmõju	doc_491521501833_item	2509802	et	4	main
tekitavad	doc_491521501833_item	2509803	et	4	main
haigusi	doc_491521501833_item	2509804	et	4	main
22	doc_491521501833_item	2509805	et	2	main
moodustage	doc_491521501833_item	2509806	et	3	main
r-liitelisi	doc_491521501833_item	2509807	et	4	main
nimisõnu	doc_491521501833_item	2509808	et	3	main
tõlkige	doc_491521501833_item	2509809	et	3	main
vedama	doc_491521501833_item	2509810	et	3	main
kallama	doc_491521501833_item	2509811	et	3	main
helkima	doc_491521501833_item	2509812	et	3	main
siduma	doc_491521501833_item	2509813	et	3	main
pidama	doc_491521501833_item	2509814	et	4	main
puhuma	doc_491521501833_item	2509815	et	3	main
vedur	doc_491521501833_item	2509816	et	3	main
kallur	doc_491521501833_item	2509817	et	3	main
helkur	doc_491521501833_item	2509818	et	4	main
sidur	doc_491521501833_item	2509819	et	3	main
pidur	doc_491521501833_item	2509820	et	3	main
kuvama	doc_491521501833_item	2509823	et	4	main
keelde	doc_491521501833_item	2509835	et	4	main
a	doc_491521501833_item	2509836	et	4	main
это	doc_491521501833_item	2509841	et	2	main
seadmeid	doc_491521501833_item	2509848	et	3	main
что	doc_491521501833_item	2509858	et	2	main
пожару	doc_491521501833_item	2509861	et	2	main
лампы	doc_491521501833_item	2509876	et	2	main
liiga	doc_491521501833_item	2509880	et	4	main
võimas	doc_491521501833_item	2509881	et	4	main
on	doc_491521501834_item	2509887	et	4	main
roninud	doc_491521501834_item	2509888	et	4	main
tuules	doc_491521501834_item	2509893	et	3	main
on	doc_491521501834_item	2509897	et	4	main
puu	doc_491521501834_item	2509900	et	4	main
pilkudelt	doc_491521501834_item	2509906	et	3	main
olla	doc_491521501834_item	2509909	et	3	main
ununevad	doc_491521501834_item	2509928	et	4	main
ruttu	doc_491521501834_item	2509929	et	4	main
mis	doc_491521501834_item	2509934	et	4	main
selle	doc_491521501834_item	2509943	et	4	main
sügisel	doc_491521501834_item	2509950	et	3	main
peab	doc_491521501834_item	2509951	et	4	main
inimesel	doc_491521501834_item	2509957	et	3	main
vaja	doc_491521501834_item	2509960	et	4	main
sest	doc_491521501834_item	2509992	et	4	main
ei	doc_491521501834_item	2510000	et	4	main
loobuma	doc_491521501834_item	2510024	et	3	main
ли	doc_491521501833_item	2509722	et	2	main
kirjutage	doc_491521501833_item	2509725	et	3	main
tegusõna	doc_491521501833_item	2509730	et	4	main
sihilist	doc_491521501833_item	2509732	et	4	main
stress	doc_491521501833_item	2509737	et	3	main
suureneb	doc_491521501833_item	2509746	et	3	main
spordiga	doc_491521501833_item	2509757	et	3	main
paraneb	doc_491521501833_item	2509758	et	3	main
teie	doc_491521501833_item	2509759	et	4	main
tervis	doc_491521501833_item	2509760	et	3	main
3	doc_491521501833_item	2509761	et	2	main
inimeste	doc_491521501833_item	2509762	et	3	main
keskmine	doc_491521501833_item	2509763	et	3	main
on	doc_491521501833_item	2509772	et	4	main
inimeste	doc_491521501833_item	2509773	et	3	main
tekitavad	doc_491521501833_item	2509782	et	4	main
siis	doc_491521501833_item	2509789	et	3	main
haigused	doc_491521501833_item	2509795	et	4	main
tegurite	doc_491521501833_item	2509798	et	3	main
tegurite	doc_491521501833_item	2509801	et	3	main
kõlama	doc_491521501833_item	2509822	et	3	main
skännima	doc_491521501833_item	2509826	et	4	main
не	doc_491521501833_item	2509837	et	2	main
жизни	doc_491521501833_item	2509844	et	2	main
kasutage	doc_491521501833_item	2509846	et	3	main
on	doc_491521501833_item	2509850	et	4	main
b	doc_491521501833_item	2509853	et	4	main
в	doc_491521501833_item	2509854	et	2	main
проводке	doc_491521501833_item	2509855	et	2	main
произошло	doc_491521501833_item	2509856	et	2	main
к	doc_491521501833_item	2509860	et	2	main
oli	doc_491521501833_item	2509863	et	3	main
see	doc_491521501833_item	2509877	et	3	main
selle	doc_491521501833_item	2509882	et	4	main
laualambi	doc_491521501833_item	2509883	et	3	main
puu	doc_491521501834_item	2509889	et	4	main
tuul	doc_491521501834_item	2509896	et	3	main
soe	doc_491521501834_item	2509899	et	4	main
oksad	doc_491521501834_item	2509901	et	3	main
kaitsevad	doc_491521501834_item	2509902	et	4	main
tahab	doc_491521501834_item	2509908	et	3	main
siit	doc_491521501834_item	2509921	et	3	main
vaade	doc_491521501834_item	2509924	et	3	main
kuid	doc_491521501834_item	2509926	et	4	main
tüdrukud	doc_491521501834_item	2509927	et	3	main
muud	doc_491521501834_item	2509932	et	4	main
tähtsamat	doc_491521501834_item	2509933	et	4	main
olema	doc_491521501834_item	2509939	et	4	main
hermani	doc_491521501834_item	2509940	et	4	main
viimane	doc_491521501834_item	2509941	et	3	main
suvi	doc_491521501834_item	2509942	et	3	main
nende	doc_491521501834_item	2509947	et	4	main
armsate	doc_491521501834_item	2509948	et	3	main
inimestega	doc_491521501834_item	2509949	et	3	main
noorel	doc_491521501834_item	2509956	et	3	main
ju	doc_491521501834_item	2509959	et	3	main
tahaks	doc_491521501834_item	2509983	et	3	main
loobuda	doc_491521501834_item	2509984	et	3	main
kui	doc_491521501834_item	2509985	et	3	main
ainult	doc_491521501834_item	2509986	et	4	main
saaks	doc_491521501834_item	2509987	et	3	main
peatada	doc_491521501834_item	2509988	et	3	main
on	doc_491521501834_item	2509995	et	4	main
nii	doc_491521501834_item	2509996	et	3	main
olla	doc_491521501834_item	2509998	et	3	main
külgedest	doc_491521501834_item	2510018	et	4	main
herman	doc_491521501834_item	2510019	et	4	main
ohkab	doc_491521501834_item	2510020	et	3	main
miks	doc_491521501834_item	2510021	et	4	main
peab	doc_491521501834_item	2510023	et	4	main
saada	doc_491521501834_item	2510027	et	4	main
on	doc_491521501834_item	2510033	et	4	main
alles	doc_491521501834_item	2510034	et	3	main
noor	doc_491521501834_item	2510035	et	3	main
võimaluste	doc_491521501834_item	2510045	et	3	main
ole	doc_491521501834_item	2510060	et	4	main
ju	doc_491521501834_item	2510061	et	3	main
электроприборами	doc_491521501833_item	2509840	et	2	main
elu	doc_491521501833_item	2509851	et	4	main
ohtlik	doc_491521501833_item	2509852	et	3	main
juhtmes	doc_491521501833_item	2509862	et	3	main
lühis	doc_491521501833_item	2509864	et	4	main
c	doc_491521501833_item	2509868	et	4	main
эта	doc_491521501833_item	2509869	et	2	main
лампочка	doc_491521501833_item	2509870	et	2	main
слишком	doc_491521501833_item	2509871	et	2	main
мощная	doc_491521501833_item	2509872	et	2	main
для	doc_491521501833_item	2509873	et	2	main
этой	doc_491521501833_item	2509874	et	2	main
jaoks	doc_491521501833_item	2509884	et	4	main
ümberjutustus	doc_491521501834_item	2509885	et	3	main
herman	doc_491521501834_item	2509886	et	4	main
lehvivad	doc_491521501834_item	2509892	et	4	main
see	doc_491521501834_item	2509895	et	3	main
herman	doc_491521501834_item	2509907	et	4	main
tükk	doc_491521501834_item	2509910	et	3	main
aega	doc_491521501834_item	2509911	et	4	main
üksinda	doc_491521501834_item	2509912	et	4	main
ja	doc_491521501834_item	2509913	et	3	main
mõelda	doc_491521501834_item	2509914	et	4	main
rahus	doc_491521501834_item	2509915	et	4	main
oma	doc_491521501834_item	2509916	et	4	main
elu	doc_491521501834_item	2509917	et	4	main
peale	doc_491521501834_item	2509918	et	4	main
pealegi	doc_491521501834_item	2509919	et	4	main
on	doc_491521501834_item	2509920	et	4	main
röster	doc_491521501833_item	2509829	et	3	main
printer	doc_491521501833_item	2509830	et	3	main
skänner	doc_491521501833_item	2509831	et	4	main
2	doc_491521501833_item	2509832	et	2	main
tõlkige	doc_491521501833_item	2509833	et	3	main
eesti	doc_491521501833_item	2509834	et	4	main
неисправными	doc_491521501833_item	2509839	et	2	main
опасно	doc_491521501833_item	2509842	et	2	main
ärge	doc_491521501833_item	2509845	et	3	main
rikkis	doc_491521501833_item	2509847	et	3	main
замыкание	doc_491521501833_item	2509857	et	2	main
настольной	doc_491521501833_item	2509875	et	2	main
otsa	doc_491521501834_item	2509890	et	4	main
juuksed	doc_491521501834_item	2509891	et	3	main
aga	doc_491521501834_item	2509894	et	3	main
päikeselt	doc_491521501834_item	2509903	et	4	main
ja	doc_491521501834_item	2509904	et	3	main
tore	doc_491521501834_item	2509923	et	3	main
kõidab	doc_491521501834_item	2509935	et	4	main
meele	doc_491521501834_item	2509936	et	4	main
kolima	doc_491521501834_item	2509953	et	3	main
ära	doc_491521501834_item	2509954	et	4	main
üksinda	doc_491521501834_item	2509955	et	4	main
haridust	doc_491521501834_item	2509961	et	4	main
ja	doc_491521501834_item	2509962	et	3	main
millest	doc_491521501834_item	2509981	et	3	main
ei	doc_491521501834_item	2509982	et	4	main
just	doc_491521501834_item	2509993	et	3	main
ja	doc_491521501834_item	2510009	et	3	main
lapsed	doc_491521501834_item	2510010	et	3	main
tüdrukutele	doc_491521501834_item	2509925	et	4	main
see	doc_491521501834_item	2509937	et	3	main
saab	doc_491521501834_item	2509938	et	3	main
järve	doc_491521501834_item	2509945	et	4	main
ääres	doc_491521501834_item	2509946	et	4	main
on	doc_491521501834_item	2509958	et	4	main
kogemusi	doc_491521501834_item	2509963	et	3	main
kõik	doc_491521501834_item	2509964	et	4	main
ees	doc_491521501834_item	2509965	et	4	main
ootavad	doc_491521501834_item	2509966	et	4	main
kogemused	doc_491521501834_item	2509967	et	3	main
ei	doc_491521501834_item	2509968	et	4	main
ole	doc_491521501834_item	2509969	et	4	main
just	doc_491521501834_item	2509970	et	3	main
kõige	doc_491521501834_item	2509971	et	4	main
meeldivamat	doc_491521501834_item	2509972	et	4	main
tüüpi	doc_491521501834_item	2509973	et	4	main
näiteks	doc_491521501834_item	2509974	et	4	main
lahkuminek	doc_491521501834_item	2509975	et	3	main
sellest	doc_491521501834_item	2509976	et	4	main
millega	doc_491521501834_item	2509977	et	3	main
on	doc_491521501834_item	2509978	et	4	main
harjunud	doc_491521501834_item	2509979	et	4	main
ja	doc_491521501834_item	2509980	et	3	main
aja	doc_491521501834_item	2509989	et	4	main
siin	doc_491521501834_item	2509994	et	4	main
hea	doc_491521501834_item	2509997	et	4	main
et	doc_491521501834_item	2509999	et	3	main
tahaks	doc_491521501834_item	2510001	et	3	main
kuhugi	doc_491521501834_item	2510002	et	4	main
minna	doc_491521501834_item	2510003	et	3	main
aga	doc_491521501834_item	2510004	et	3	main
kell	doc_491521501834_item	2510005	et	3	main
muudkui	doc_491521501834_item	2510006	et	3	main
tiksub	doc_491521501834_item	2510007	et	3	main
edasi	doc_491521501834_item	2510008	et	3	main
murul	doc_491521501834_item	2510012	et	3	main
midagi	doc_491521501834_item	2510014	et	4	main
et	doc_491521501834_item	2510026	et	3	main
oska	doc_491521501834_item	2510042	et	4	main
eri	doc_491521501834_item	2510044	et	4	main
garantiit	doc_491521501834_item	2510062	et	4	main
kuid	doc_491521501834_item	2510063	et	4	main
kõige	doc_491521501834_item	2510067	et	4	main
herman	doc_491521501834_item	2510069	et	4	main
ühest	doc_491521501834_item	2510025	et	4	main
tahakski	doc_491521501834_item	2510037	et	3	main
või	doc_491521501834_item	2510039	et	4	main
vähemalt	doc_491521501834_item	2510040	et	4	main
sind	doc_491521501834_item	2510048	et	4	main
valesti	doc_491521501834_item	2510057	et	3	main
vastutad	doc_491521501834_item	2510066	et	3	main
poisse	doc_491521501834_item	2510073	et	4	main
ja	doc_491521501834_item	2510074	et	3	main
tüdrukuid	doc_491521501834_item	2510075	et	4	main
ta	doc_491521501834_item	2510076	et	4	main
otsustab	doc_491521501834_item	2510077	et	3	main
ronida	doc_491521501834_item	2510078	et	3	main
alla	doc_491521501834_item	2510079	et	3	main
ja	doc_491521501834_item	2510080	et	3	main
liituda	doc_491521501834_item	2510081	et	3	main
nende	doc_491521501834_item	2510082	et	4	main
hulka	doc_491521501834_item	2510083	et	4	main
heas	doc_491521501834_item	2510084	et	3	main
seltsis	doc_491521501834_item	2510085	et	4	main
mured	doc_491521501834_item	2510086	et	3	main
ununevad	doc_491521501834_item	2510087	et	4	main
korraks	doc_491521501834_item	2510088	et	4	main
küll	doc_491521501834_item	2510022	et	4	main
ja	doc_491521501834_item	2510036	et	3	main
kõike	doc_491521501834_item	2510038	et	4	main
otsustada	doc_491521501834_item	2510043	et	3	main
siis	doc_491521501834_item	2510047	et	3	main
otsustama	doc_491521501834_item	2510050	et	3	main
siis	doc_491521501834_item	2510053	et	3	main
saab	doc_491521501834_item	2510054	et	3	main
otsustadki	doc_491521501834_item	2510056	et	3	main
ise	doc_491521501834_item	2510065	et	4	main
midagi	doc_491521501834_item	2510028	et	4	main
teist	doc_491521501834_item	2510029	et	4	main
eriti	doc_491521501834_item	2510030	et	3	main
siis	doc_491521501834_item	2510031	et	3	main
kui	doc_491521501834_item	2510032	et	3	main
ei	doc_491521501834_item	2510041	et	4	main
vahel	doc_491521501834_item	2510046	et	4	main
sunnitakse	doc_491521501834_item	2510049	et	4	main
ja	doc_491521501834_item	2510051	et	3	main
mis	doc_491521501834_item	2510052	et	4	main
kui	doc_491521501834_item	2510055	et	3	main
tulevikul	doc_491521501834_item	2510058	et	4	main
ei	doc_491521501834_item	2510059	et	4	main
siiski	doc_491521501834_item	2510064	et	4	main
eest	doc_491521501834_item	2510068	et	4	main
kadestab	doc_491521501834_item	2510070	et	3	main
all	doc_491521501834_item	2510071	et	3	main
kisavaid	doc_491521501834_item	2510072	et	4	main
vitae	doc_491521501839_item	2510766	et	4	main
curriculum	doc_491521501839_item	2510767	et	4	main
koht	doc_491521501839_item	2510774	et	3	main
karu	doc_491521501839_item	2510779	et	4	main
051925813	doc_491521501839_item	2510782	et	2	main
e-mail	doc_491521501839_item	2510783	et	4	main
marikatpuee	doc_491521501839_item	2510784	et	4	main
töökoht	doc_491521501839_item	2510785	et	3	main
keel	doc_491521501839_item	2510820	et	4	main
word	doc_491521501839_item	2510823	et	4	main
keskharidus	doc_491521501839_item	2510787	et	3	main
23061980a	doc_491521501839_item	2510775	et	4	main
haridus	doc_491521501839_item	2510786	et	3	main
hobid	doc_491521501839_item	2510824	et	3	main
tantsimine	doc_491521501839_item	2510825	et	4	main
muusika	doc_491521501839_item	2510826	et	4	main
kuulamine	doc_491521501839_item	2510827	et	4	main
tegelen	doc_491521501839_item	2510828	et	3	main
kinnitan	doc_491521501839_item	2510831	et	3	main
andmed	doc_491521501839_item	2510834	et	3	main
tanvel	doc_491521501839_item	2510838	et	4	main
30042003a	doc_491521501839_item	2510839	et	4	main
üks	doc_491521501839_item	2510840	et	3	main
ei	doc_491521501839_item	2510856	et	4	main
rõõmsad	doc_491521501839_item	2510868	et	3	main
nad	doc_491521501839_item	2510870	et	3	main
kohta	doc_491521501839_item	2510871	et	4	main
mitte	doc_491521501839_item	2510872	et	3	main
palju	doc_491521501839_item	2510879	et	4	main
ühendust	doc_491521501839_item	2510891	et	4	main
läks	doc_491521501839_item	2510895	et	3	main
olid	doc_491521501839_item	2510912	et	4	main
vanem	doc_491521501839_item	2510924	et	4	main
aadress	doc_491521501839_item	2510777	et	3	main
algtasemel	doc_491521501839_item	2510818	et	3	main
algtasemel	doc_491521501839_item	2510821	et	3	main
pere	doc_491521501839_item	2510841	et	4	main
jõe	doc_491521501839_item	2510844	et	3	main
ilm	doc_491521501839_item	2510846	et	3	main
esimesel	doc_491521501839_item	2510853	et	3	main
ole	doc_491521501839_item	2510857	et	4	main
soe	doc_491521501839_item	2510859	et	4	main
sellel	doc_491521501839_item	2510860	et	4	main
päeval	doc_491521501839_item	2510861	et	3	main
pere	doc_491521501839_item	2510882	et	4	main
seal	doc_491521501839_item	2510887	et	4	main
söömist	doc_491521501839_item	2510905	et	4	main
oli	doc_491521501839_item	2510907	et	3	main
tegevus	doc_491521501839_item	2510909	et	4	main
vanemad	doc_491521501839_item	2510910	et	4	main
inimesed	doc_491521501839_item	2510911	et	3	main
natuke	doc_491521501839_item	2510916	et	4	main
eemal	doc_491521501839_item	2510917	et	3	main
nii	doc_491521501839_item	2510918	et	3	main
ronis	doc_491521501839_item	2510926	et	4	main
noorem	doc_491521501839_item	2510939	et	4	main
mis	doc_491521501839_item	2510950	et	4	main
teist	doc_491521501839_item	2510962	et	4	main
koer	doc_491521501839_item	2510968	et	3	main
nende	doc_491521501839_item	2510970	et	4	main
koer	doc_491521501839_item	2510972	et	3	main
kõva	doc_491521501839_item	2510973	et	4	main
hälega	doc_491521501839_item	2510974	et	4	main
häiris	doc_491521501839_item	2510975	et	3	main
maal	doc_491521501839_item	2510980	et	4	main
kaugel	doc_491521501839_item	2511015	et	4	main
tulid	doc_491521501839_item	2511018	et	4	main
ka	doc_491521501839_item	2511019	et	3	main
curriculum	doc_491521501839_item	2510765	et	4	main
vitae	doc_491521501839_item	2510768	et	4	main
nimi	doc_491521501839_item	2510769	et	3	main
marika	doc_491521501839_item	2510770	et	4	main
tanvel	doc_491521501839_item	2510771	et	4	main
sünniaeg	doc_491521501839_item	2510772	et	3	main
ja	doc_491521501839_item	2510773	et	3	main
gruusia	doc_491521501839_item	2510776	et	4	main
tallinn	doc_491521501839_item	2510778	et	4	main
17-68a-3	doc_491521501839_item	2510780	et	4	main
telefon	doc_491521501839_item	2510781	et	3	main
veltsker	doc_491521501839_item	2510788	et	4	main
täiendharidus	doc_491521501839_item	2510789	et	3	main
2002a	doc_491521501839_item	2510790	et	4	main
tallinna	doc_491521501839_item	2510791	et	4	main
pedagoogikaülikool	doc_491521501839_item	2510792	et	4	main
välisõpilane	doc_491521501839_item	2510793	et	3	main
1997-2000a	doc_491521501839_item	2510794	et	4	main
mediciinitehnikakool	doc_491521501839_item	2510795	et	4	main
veltsker	doc_491521501839_item	2510796	et	4	main
töökäik	doc_491521501839_item	2510797	et	3	main
2000-2002a	doc_491521501839_item	2510798	et	4	main
keskkool	doc_491521501839_item	2510799	et	4	main
2	doc_491521501839_item	2510801	et	2	main
gagra	doc_491521501839_item	2510802	et	4	main
õpetaja	doc_491521501839_item	2510803	et	4	main
ja	doc_491521501839_item	2510804	et	3	main
n	doc_491521501839_item	2510800	et	4	main
klassijuhataja	doc_491521501839_item	2510805	et	4	main
keelteoskus	doc_491521501839_item	2510806	et	3	main
vene	doc_491521501839_item	2510807	et	4	main
keel	doc_491521501839_item	2510808	et	4	main
valdan	doc_491521501839_item	2510809	et	3	main
kirjas	doc_491521501839_item	2510810	et	4	main
ja	doc_491521501839_item	2510811	et	3	main
kõnes	doc_491521501839_item	2510812	et	3	main
eesti	doc_491521501839_item	2510813	et	4	main
keel	doc_491521501839_item	2510814	et	4	main
emakeel	doc_491521501839_item	2510815	et	4	main
inglise	doc_491521501839_item	2510816	et	4	main
keel	doc_491521501839_item	2510817	et	4	main
türgi	doc_491521501839_item	2510819	et	4	main
arvutikasutamisoskus	doc_491521501839_item	2510822	et	3	main
käesolevaga	doc_491521501839_item	2510830	et	3	main
esitatud	doc_491521501839_item	2510833	et	4	main
on	doc_491521501839_item	2510835	et	4	main
õiged	doc_491521501839_item	2510836	et	3	main
marika	doc_491521501839_item	2510837	et	4	main
äärde	doc_491521501839_item	2510845	et	4	main
ilus	doc_491521501839_item	2510848	et	4	main
ja	doc_491521501839_item	2510849	et	3	main
päike	doc_491521501839_item	2510850	et	3	main
mail	doc_491521501839_item	2510854	et	4	main
nii	doc_491521501839_item	2510858	et	3	main
sest	doc_491521501839_item	2510874	et	4	main
pühapäeval	doc_491521501839_item	2510875	et	3	main
jõe	doc_491521501839_item	2510876	et	3	main
ääres	doc_491521501839_item	2510877	et	4	main
on	doc_491521501839_item	2510878	et	4	main
leidsid	doc_491521501839_item	2510884	et	4	main
järvega	doc_491521501839_item	2510892	et	3	main
piknik	doc_491521501839_item	2510894	et	3	main
rohkem	doc_491521501839_item	2510900	et	4	main
meeldis	doc_491521501839_item	2510901	et	3	main
väike	doc_491521501839_item	2510902	et	4	main
kõigidel	doc_491521501839_item	2510906	et	4	main
oma	doc_491521501839_item	2510908	et	4	main
mürasid	doc_491521501839_item	2510922	et	4	main
piilus	doc_491521501839_item	2510940	et	4	main
jälgis	doc_491521501839_item	2510944	et	4	main
teeb	doc_491521501839_item	2510951	et	3	main
armsam	doc_491521501839_item	2510954	et	4	main
lapselaps	doc_491521501839_item	2510955	et	4	main
lapselaps	doc_491521501839_item	2510956	et	4	main
mängis	doc_491521501839_item	2510957	et	3	main
kaks	doc_491521501839_item	2510961	et	3	main
kaklesid	doc_491521501839_item	2510964	et	4	main
peale	doc_491521501839_item	2510971	et	4	main
käes	doc_491521501839_item	2510982	et	4	main
tüdrukud	doc_491521501839_item	2511016	et	3	main
ja	doc_491521501839_item	2511017	et	3	main
tõsine	doc_491521501839_item	2511032	et	4	main
ääres	doc_491521501840_item	2511065	et	4	main
on	doc_491521501840_item	2511074	et	4	main
leidnud	doc_491521501840_item	2511075	et	4	main
puu	doc_491521501840_item	2511083	et	4	main
teine	doc_491521501840_item	2511087	et	3	main
puu	doc_491521501840_item	2511089	et	4	main
tahab	doc_491521501840_item	2511092	et	3	main
proovida	doc_491521501840_item	2511093	et	3	main
mis	doc_491521501840_item	2511103	et	4	main
ei	doc_491521501840_item	2511106	et	4	main
teised	doc_491521501840_item	2511108	et	4	main
rahulikumad	doc_491521501840_item	2511112	et	4	main
üks	doc_491521501840_item	2511113	et	3	main
linnu	doc_491521501840_item	2511120	et	4	main
teine	doc_491521501840_item	2511122	et	3	main
on	doc_491521501840_item	2511123	et	4	main
ajalehte	doc_491521501840_item	2511124	et	4	main
magama	doc_491521501840_item	2511126	et	3	main
jäänud	doc_491521501840_item	2511127	et	4	main
ema	doc_491521501840_item	2511128	et	4	main
ja	doc_491521501840_item	2511129	et	3	main
mõnusalt	doc_491521501840_item	2511134	et	4	main
loeb	doc_491521501840_item	2511137	et	3	main
ja	doc_491521501840_item	2511144	et	3	main
imikut	doc_491521501840_item	2511146	et	3	main
muru	doc_491521501840_item	2511152	et	4	main
kõrval	doc_491521501840_item	2511163	et	4	main
istub	doc_491521501840_item	2511164	et	3	main
poiss	doc_491521501840_item	2511165	et	3	main
kes	doc_491521501840_item	2511166	et	4	main
on	doc_491521501840_item	2511167	et	4	main
juba	doc_491521501840_item	2511168	et	3	main
mis	doc_491521501840_item	2511177	et	4	main
seisab	doc_491521501840_item	2511178	et	3	main
vastu	doc_491521501840_item	2511179	et	3	main
kui	doc_491521501840_item	2511190	et	3	main
sattunud	doc_491521501840_item	2511222	et	4	main
imetlevad	doc_491521501840_item	2511234	et	4	main
ilusat	doc_491521501840_item	2511237	et	3	main
hobust	doc_491521501840_item	2511238	et	4	main
arutab	doc_491521501840_item	2511240	et	3	main
et	doc_491521501839_item	2510832	et	3	main
sõitis	doc_491521501839_item	2510842	et	3	main
puhkama	doc_491521501839_item	2510843	et	3	main
eredalt	doc_491521501839_item	2510852	et	4	main
tavaliselt	doc_491521501839_item	2510855	et	4	main
kõik	doc_491521501839_item	2510866	et	4	main
olid	doc_491521501839_item	2510867	et	4	main
leidsid	doc_491521501839_item	2510869	et	4	main
lõpude-lõpuks	doc_491521501839_item	2510883	et	4	main
kohta	doc_491521501839_item	2510886	et	4	main
jõgi	doc_491521501839_item	2510889	et	3	main
lastele	doc_491521501839_item	2510898	et	4	main
kõige	doc_491521501839_item	2510899	et	4	main
peale	doc_491521501839_item	2510904	et	4	main
kaua	doc_491521501839_item	2510919	et	3	main
kui	doc_491521501839_item	2510920	et	3	main
spordiga	doc_491521501839_item	2510829	et	3	main
oli	doc_491521501839_item	2510847	et	3	main
paistis	doc_491521501839_item	2510851	et	3	main
önneks	doc_491521501839_item	2510862	et	4	main
oli	doc_491521501839_item	2510863	et	3	main
peres	doc_491521501839_item	2510864	et	3	main
mets	doc_491521501839_item	2510865	et	3	main
kohe	doc_491521501839_item	2510873	et	4	main
inimesi	doc_491521501839_item	2510880	et	4	main
suur	doc_491521501839_item	2510881	et	3	main
endale	doc_491521501839_item	2510885	et	4	main
kus	doc_491521501839_item	2510888	et	3	main
võtab	doc_491521501839_item	2510890	et	3	main
väike	doc_491521501839_item	2510893	et	4	main
suureks	doc_491521501839_item	2510896	et	4	main
peoks	doc_491521501839_item	2510897	et	4	main
puhkus	doc_491521501839_item	2510903	et	3	main
väsind	doc_491521501839_item	2510913	et	4	main
ja	doc_491521501839_item	2510914	et	3	main
puhkasid	doc_491521501839_item	2510915	et	4	main
lapsed	doc_491521501839_item	2510921	et	3	main
kõige	doc_491521501839_item	2510923	et	4	main
otsa	doc_491521501839_item	2510928	et	4	main
poiss	doc_491521501839_item	2510936	et	3	main
mis	doc_491521501839_item	2510937	et	4	main
oli	doc_491521501839_item	2510938	et	3	main
ja	doc_491521501839_item	2510943	et	3	main
anedega	doc_491521501839_item	2510958	et	4	main
oma	doc_491521501839_item	2510965	et	4	main
vanaisa	doc_491521501839_item	2510976	et	4	main
esimest	doc_491521501839_item	2510984	et	4	main
ratsutasid	doc_491521501839_item	2511013	et	4	main
mitte	doc_491521501839_item	2511014	et	3	main
poeg	doc_491521501839_item	2511027	et	3	main
peres	doc_491521501839_item	2511028	et	3	main
on	doc_491521501839_item	2511029	et	4	main
kurb	doc_491521501839_item	2511030	et	3	main
ja	doc_491521501839_item	2511031	et	3	main
on	doc_491521501839_item	2511035	et	4	main
eksam	doc_491521501839_item	2511037	et	3	main
inimeste	doc_491521501839_item	2511039	et	3	main
jäoks	doc_491521501839_item	2511040	et	4	main
see	doc_491521501839_item	2511041	et	3	main
päev	doc_491521501839_item	2511042	et	3	main
oli	doc_491521501839_item	2511043	et	3	main
pikk	doc_491521501839_item	2511044	et	4	main
ja	doc_491521501839_item	2511045	et	3	main
armas	doc_491521501839_item	2511046	et	3	main
puhkasid	doc_491521501839_item	2511047	et	4	main
nad	doc_491521501839_item	2511048	et	3	main
jälle	doc_491521501839_item	2511055	et	3	main
kirjeldus	doc_491521501840_item	2511058	et	4	main
perekond	doc_491521501840_item	2511059	et	3	main
saar	doc_491521501840_item	2511060	et	3	main
on	doc_491521501840_item	2511061	et	4	main
ilusal	doc_491521501840_item	2511062	et	3	main
suvepäeval	doc_491521501840_item	2511063	et	3	main
jõe	doc_491521501840_item	2511064	et	3	main
kõik	doc_491521501840_item	2511073	et	4	main
huvitavat	doc_491521501840_item	2511078	et	4	main
tegevust	doc_491521501840_item	2511079	et	4	main
õnnestub	doc_491521501840_item	2511096	et	3	main
üle	doc_491521501840_item	2511098	et	3	main
kaks	doc_491521501840_item	2511100	et	3	main
kaklevad	doc_491521501840_item	2511102	et	4	main
ültse	doc_491521501840_item	2511105	et	4	main
meeldi	doc_491521501840_item	2511107	et	4	main
tabada	doc_491521501840_item	2511121	et	3	main
lugedes	doc_491521501840_item	2511125	et	3	main
ema	doc_491521501840_item	2511136	et	4	main
põnevat	doc_491521501840_item	2511138	et	3	main
kampsunit	doc_491521501840_item	2511143	et	3	main
võileibi	doc_491521501840_item	2511162	et	4	main
täis	doc_491521501840_item	2511172	et	4	main
vaatab	doc_491521501840_item	2511174	et	3	main
isa	doc_491521501840_item	2511175	et	4	main
suuremaks	doc_491521501840_item	2511193	et	4	main
nad	doc_491521501840_item	2511233	et	3	main
pere	doc_491521501840_item	2511236	et	4	main
väga	doc_491521501841_item	2511253	et	3	main
nii	doc_491521501841_item	2511256	et	3	main
igaüks	doc_491521501841_item	2511258	et	3	main
poiss	doc_491521501839_item	2510925	et	3	main
puu	doc_491521501839_item	2510927	et	4	main
ja	doc_491521501839_item	2510929	et	3	main
vaatas	doc_491521501839_item	2510930	et	3	main
sealt	doc_491521501839_item	2510931	et	4	main
nagu	doc_491521501839_item	2510932	et	3	main
tornist	doc_491521501839_item	2510933	et	3	main
ümbrust	doc_491521501839_item	2510934	et	3	main
teine	doc_491521501839_item	2510935	et	3	main
tagant	doc_491521501839_item	2510942	et	3	main
salaja	doc_491521501839_item	2510946	et	3	main
tema	doc_491521501839_item	2510952	et	4	main
järve	doc_491521501839_item	2510959	et	4	main
vahel	doc_491521501839_item	2510966	et	4	main
tuttavat	doc_491521501839_item	2510977	et	3	main
kes	doc_491521501839_item	2510978	et	4	main
magas	doc_491521501839_item	2510979	et	4	main
imik	doc_491521501839_item	2510983	et	3	main
korda	doc_491521501839_item	2510985	et	4	main
nägi	doc_491521501839_item	2510986	et	3	main
lindu	doc_491521501839_item	2510987	et	4	main
ja	doc_491521501839_item	2510988	et	3	main
hakkas	doc_491521501839_item	2510989	et	3	main
rõõmsalt	doc_491521501839_item	2510990	et	4	main
naerma	doc_491521501839_item	2510991	et	3	main
noorem	doc_491521501839_item	2510992	et	4	main
vend	doc_491521501839_item	2510993	et	3	main
lapsepõlvest	doc_491521501839_item	2510994	et	4	main
tunneb	doc_491521501839_item	2510995	et	3	main
huvi	doc_491521501839_item	2510996	et	4	main
linnude	doc_491521501839_item	2510997	et	3	main
vastu	doc_491521501839_item	2510998	et	3	main
ja	doc_491521501839_item	2510999	et	3	main
selle	doc_491521501839_item	2511000	et	4	main
pärast	doc_491521501839_item	2511001	et	4	main
järgib	doc_491521501839_item	2511002	et	3	main
neid	doc_491521501839_item	2511003	et	4	main
binookliga	doc_491521501839_item	2511004	et	4	main
kaks	doc_491521501839_item	2511005	et	3	main
tüdrukut	doc_491521501839_item	2511006	et	3	main
söövad	doc_491521501839_item	2511007	et	4	main
kooke	doc_491521501839_item	2511008	et	4	main
ja	doc_491521501839_item	2511009	et	3	main
ei	doc_491521501839_item	2511010	et	4	main
lähegi	doc_491521501839_item	2511011	et	4	main
mängima	doc_491521501839_item	2511012	et	3	main
puu	doc_491521501839_item	2510941	et	4	main
teisi	doc_491521501839_item	2510945	et	4	main
vanaisa	doc_491521501839_item	2510947	et	4	main
tõsiselt	doc_491521501839_item	2510948	et	4	main
vaatas	doc_491521501839_item	2510949	et	3	main
kõige	doc_491521501839_item	2510953	et	4	main
ääres	doc_491521501839_item	2510960	et	4	main
venda	doc_491521501839_item	2510963	et	4	main
ja	doc_491521501839_item	2510967	et	3	main
haukus	doc_491521501839_item	2510969	et	3	main
päikese	doc_491521501839_item	2510981	et	4	main
vaatama	doc_491521501839_item	2511020	et	3	main
mis	doc_491521501839_item	2511021	et	4	main
see	doc_491521501839_item	2511023	et	3	main
pere	doc_491521501839_item	2511025	et	4	main
sest	doc_491521501839_item	2511033	et	4	main
pildi	doc_491521501840_item	2511057	et	4	main
puhkamas	doc_491521501840_item	2511066	et	3	main
ja	doc_491521501840_item	2511069	et	3	main
laulavad	doc_491521501840_item	2511071	et	4	main
otsa	doc_491521501840_item	2511084	et	4	main
ja	doc_491521501840_item	2511086	et	3	main
piilub	doc_491521501840_item	2511088	et	3	main
tagant	doc_491521501840_item	2511090	et	3	main
kas	doc_491521501840_item	2511094	et	3	main
koerale	doc_491521501840_item	2511104	et	3	main
on	doc_491521501840_item	2511110	et	4	main
palju	doc_491521501840_item	2511111	et	4	main
pere	doc_491521501840_item	2511130	et	4	main
toolides	doc_491521501840_item	2511135	et	3	main
romaani	doc_491521501840_item	2511139	et	4	main
tütar	doc_491521501840_item	2511141	et	3	main
koob	doc_491521501840_item	2511142	et	3	main
kes	doc_491521501840_item	2511147	et	4	main
karjub	doc_491521501840_item	2511148	et	3	main
kaks	doc_491521501840_item	2511158	et	3	main
kõhu	doc_491521501840_item	2511171	et	3	main
ta	doc_491521501840_item	2511173	et	4	main
et	doc_491521501840_item	2511183	et	3	main
seda	doc_491521501840_item	2511187	et	3	main
ta	doc_491521501840_item	2511191	et	4	main
kasvab	doc_491521501840_item	2511194	et	3	main
filme	doc_491521501841_item	2511255	et	3	main
saab	doc_491521501841_item	2511259	et	3	main
küll	doc_491521501841_item	2511270	et	4	main
marmortahvlil	doc_491521501841_item	2511297	et	3	main
peaaegu	doc_491521501841_item	2511302	et	3	main
mitmekülgne	doc_491521501841_item	2511313	et	3	main
ilus	doc_491521501841_item	2511317	et	4	main
tõeline	doc_491521501841_item	2511319	et	4	main
suur	doc_491521501839_item	2511024	et	3	main
kolmas	doc_491521501839_item	2511026	et	3	main
temal	doc_491521501839_item	2511034	et	3	main
esmaspäeval	doc_491521501839_item	2511036	et	3	main
nende	doc_491521501839_item	2511038	et	4	main
hea	doc_491521501839_item	2511049	et	4	main
meelege	doc_491521501839_item	2511050	et	4	main
ja	doc_491521501839_item	2511051	et	3	main
tuled	doc_491521501839_item	2511052	et	4	main
järdmisel	doc_491521501839_item	2511053	et	4	main
pühapäeval	doc_491521501839_item	2511054	et	3	main
teeb	doc_491521501839_item	2511022	et	3	main
siia	doc_491521501839_item	2511056	et	4	main
päike	doc_491521501840_item	2511067	et	3	main
linnud	doc_491521501840_item	2511070	et	3	main
ning	doc_491521501840_item	2511072	et	3	main
endale	doc_491521501840_item	2511076	et	4	main
poiss	doc_491521501840_item	2511081	et	3	main
on	doc_491521501840_item	2511082	et	4	main
roninud	doc_491521501840_item	2511085	et	4	main
kolmas	doc_491521501840_item	2511091	et	3	main
tal	doc_491521501840_item	2511095	et	3	main
vee	doc_491521501840_item	2511099	et	3	main
vaatab	doc_491521501840_item	2511114	et	3	main
binokliga	doc_491521501840_item	2511115	et	3	main
taevale	doc_491521501840_item	2511116	et	3	main
et	doc_491521501840_item	2511117	et	3	main
mõne	doc_491521501840_item	2511118	et	3	main
istuvad	doc_491521501840_item	2511133	et	4	main
peal	doc_491521501840_item	2511151	et	4	main
on	doc_491521501840_item	2511154	et	4	main
kaetud	doc_491521501840_item	2511155	et	4	main
piknik	doc_491521501840_item	2511156	et	3	main
kus	doc_491521501840_item	2511157	et	3	main
oma	doc_491521501840_item	2511170	et	4	main
vintpüssi	doc_491521501840_item	2511176	et	4	main
loodab	doc_491521501840_item	2511182	et	3	main
ta	doc_491521501840_item	2511184	et	4	main
saaks	doc_491521501840_item	2511185	et	3	main
proovida	doc_491521501840_item	2511189	et	3	main
isa	doc_491521501840_item	2511195	et	4	main
paistab	doc_491521501840_item	2511068	et	3	main
mingit	doc_491521501840_item	2511077	et	3	main
üks	doc_491521501840_item	2511080	et	3	main
hüpata	doc_491521501840_item	2511097	et	4	main
poissi	doc_491521501840_item	2511101	et	4	main
poisid	doc_491521501840_item	2511109	et	4	main
harvaesineva	doc_491521501840_item	2511119	et	3	main
vanim	doc_491521501840_item	2511131	et	3	main
tütar	doc_491521501840_item	2511132	et	3	main
ja	doc_491521501840_item	2511140	et	3	main
vaatab	doc_491521501840_item	2511145	et	3	main
maas	doc_491521501840_item	2511149	et	4	main
vaiba	doc_491521501840_item	2511150	et	3	main
peale	doc_491521501840_item	2511153	et	4	main
väikest	doc_491521501840_item	2511159	et	4	main
tüdrukut	doc_491521501840_item	2511160	et	3	main
söövad	doc_491521501840_item	2511161	et	4	main
söönud	doc_491521501840_item	2511169	et	4	main
puud	doc_491521501840_item	2511180	et	4	main
ja	doc_491521501840_item	2511181	et	3	main
ka	doc_491521501840_item	2511186	et	3	main
mõnikord	doc_491521501840_item	2511188	et	3	main
natuke	doc_491521501840_item	2511192	et	4	main
seisab	doc_491521501840_item	2511196	et	3	main
pere	doc_491521501840_item	2511197	et	4	main
keskel	doc_491521501840_item	2511198	et	3	main
ja	doc_491521501840_item	2511199	et	3	main
vahib	doc_491521501840_item	2511200	et	3	main
et	doc_491521501840_item	2511201	et	3	main
keegi	doc_491521501840_item	2511202	et	4	main
lastest	doc_491521501840_item	2511203	et	4	main
rumalusi	doc_491521501840_item	2511204	et	4	main
ei	doc_491521501840_item	2511205	et	4	main
teeks	doc_491521501840_item	2511206	et	4	main
tegelikult	doc_491521501840_item	2511207	et	4	main
on	doc_491521501840_item	2511208	et	4	main
ta	doc_491521501840_item	2511209	et	4	main
oma	doc_491521501840_item	2511210	et	4	main
suure	doc_491521501840_item	2511211	et	3	main
pere	doc_491521501840_item	2511212	et	4	main
üle	doc_491521501840_item	2511213	et	3	main
väga	doc_491521501840_item	2511214	et	3	main
uhke	doc_491521501840_item	2511215	et	4	main
mõned	doc_491521501840_item	2511216	et	3	main
suvalised	doc_491521501840_item	2511217	et	4	main
inimesed	doc_491521501840_item	2511218	et	3	main
on	doc_491521501840_item	2511219	et	4	main
ka	doc_491521501840_item	2511220	et	3	main
kohale	doc_491521501840_item	2511221	et	4	main
ja	doc_491521501840_item	2511223	et	3	main
vaatavad	doc_491521501840_item	2511224	et	4	main
kõrvalt	doc_491521501840_item	2511225	et	4	main
kuidas	doc_491521501840_item	2511226	et	3	main
perekond	doc_491521501840_item	2511227	et	3	main
saar	doc_491521501840_item	2511228	et	3	main
oma	doc_491521501840_item	2511229	et	4	main
vaba	doc_491521501840_item	2511230	et	4	main
päeva	doc_491521501840_item	2511231	et	4	main
ka	doc_491521501840_item	2511235	et	3	main
kes	doc_491521501840_item	2511239	et	4	main
miks	doc_491521501840_item	2511241	et	4	main
tehakse	doc_491521501841_item	2511252	et	3	main
et	doc_491521501841_item	2511257	et	3	main
valida	doc_491521501841_item	2511260	et	3	main
veedavad	doc_491521501840_item	2511232	et	3	main
keegi	doc_491521501840_item	2511242	et	4	main
temaga	doc_491521501840_item	2511243	et	3	main
ei	doc_491521501840_item	2511244	et	4	main
ratsuta	doc_491521501840_item	2511245	et	4	main
palju	doc_491521501841_item	2511254	et	4	main
enda	doc_491521501841_item	2511261	et	4	main
järgi	doc_491521501841_item	2511263	et	4	main
mida	doc_491521501841_item	2511264	et	4	main
tal	doc_491521501841_item	2511265	et	3	main
tasub	doc_491521501841_item	2511266	et	3	main
filmidest	doc_491521501841_item	2511273	et	3	main
tehakse	doc_491521501841_item	2511274	et	3	main
kindla	doc_491521501841_item	2511275	et	3	main
vaatajaskonna	doc_491521501841_item	2511276	et	3	main
jaoks	doc_491521501841_item	2511277	et	4	main
väga	doc_491521501841_item	2511278	et	3	main
vähe	doc_491521501841_item	2511279	et	3	main
on	doc_491521501841_item	2511280	et	4	main
neid	doc_491521501841_item	2511281	et	4	main
filme	doc_491521501841_item	2511282	et	3	main
mida	doc_491521501841_item	2511283	et	4	main
saaksid	doc_491521501841_item	2511284	et	4	main
vaadata	doc_491521501841_item	2511285	et	4	main
kõik	doc_491521501841_item	2511286	et	4	main
sõltumata	doc_491521501841_item	2511287	et	4	main
vanusest	doc_491521501841_item	2511288	et	4	main
huvidest	doc_491521501841_item	2511289	et	3	main
ja	doc_491521501841_item	2511290	et	3	main
teistest	doc_491521501841_item	2511291	et	4	main
teguritest	doc_491521501841_item	2511292	et	3	main
ma	doc_491521501841_item	2511293	et	3	main
arvan	doc_491521501841_item	2511294	et	3	main
et	doc_491521501841_item	2511295	et	3	main
nimed	doc_491521501841_item	2511246	et	3	main
marmortahvlil	doc_491521501841_item	2511247	et	3	main
essee	doc_491521501841_item	2511248	et	4	main
nimed	doc_491521501841_item	2511249	et	3	main
marmortahvlil	doc_491521501841_item	2511250	et	3	main
tänapäeval	doc_491521501841_item	2511251	et	3	main
kuid	doc_491521501841_item	2511268	et	4	main
tundub	doc_491521501841_item	2511269	et	3	main
et	doc_491521501841_item	2511271	et	3	main
enamik	doc_491521501841_item	2511272	et	3	main
viimaste	doc_491521501841_item	2511300	et	3	main
leiab	doc_491521501841_item	2511304	et	3	main
midagi	doc_491521501841_item	2511307	et	4	main
enda	doc_491521501841_item	2511308	et	4	main
väga	doc_491521501841_item	2511312	et	3	main
armastuslugu	doc_491521501841_item	2511318	et	4	main
sõprus	doc_491521501841_item	2511320	et	3	main
marmortahvlil	doc_491521501841_item	2511343	et	3	main
et	doc_491521501841_item	2511360	et	3	main
noori	doc_491521501841_item	2511366	et	3	main
noormehed	doc_491521501841_item	2511369	et	3	main
püüavad	doc_491521501841_item	2511371	et	3	main
kohustusest	doc_491521501841_item	2511374	et	4	main
kõrvale	doc_491521501841_item	2511375	et	4	main
kes	doc_491521501841_item	2511380	et	4	main
filmi	doc_491521501841_item	2511394	et	4	main
põhjal	doc_491521501841_item	2511395	et	4	main
vastuse	doc_491521501841_item	2511398	et	3	main
on	doc_491521501841_item	2511400	et	4	main
et	doc_491521501841_item	2511402	et	3	main
ajaloo	doc_491521501841_item	2511409	et	4	main
vastu	doc_491521501841_item	2511410	et	3	main
seni	doc_491521501841_item	2511414	et	3	main
romaan	doc_491521501841_item	2511422	et	3	main
seda	doc_491521501841_item	2511434	et	3	main
lugeda	doc_491521501841_item	2511437	et	3	main
tähtsam	doc_491521501841_item	2511454	et	4	main
pani	doc_491521501841_item	2511456	et	4	main
mind	doc_491521501841_item	2511457	et	4	main
näidatud	doc_491521501841_item	2511470	et	4	main
vapraid	doc_491521501841_item	2511474	et	3	main
oma	doc_491521501841_item	2511514	et	4	main
vist	doc_491521501841_item	2511519	et	4	main
on	doc_491521501841_item	2511530	et	4	main
see	doc_491521501841_item	2511543	et	3	main
film	doc_491521501841_item	2511544	et	3	main
korra	doc_491521501841_item	2511548	et	4	main
selle	doc_491521501841_item	2511550	et	4	main
kohta	doc_491521501841_item	2511551	et	4	main
et	doc_491521501841_item	2511552	et	3	main
ja	doc_491521501841_item	2511563	et	3	main
arusaamatus	doc_491521501841_item	2511594	et	4	main
ja	doc_491521501841_item	2511595	et	3	main
olukord	doc_491521501841_item	2511596	et	3	main
kus	doc_491521501841_item	2511597	et	3	main
inimene	doc_491521501841_item	2511598	et	3	main
siin	doc_491521501841_item	2511599	et	4	main
üks	doc_491521501841_item	2511613	et	3	main
hea	doc_491521501841_item	2511614	et	4	main
film	doc_491521501841_item	2511615	et	3	main
igaühel	doc_491521501841_item	2511616	et	3	main
on	doc_491521501841_item	2511617	et	4	main
oma	doc_491521501841_item	2511618	et	4	main
arvamus	doc_491521501841_item	2511619	et	3	main
seda	doc_491521501841_item	2511622	et	3	main
ei	doc_491521501841_item	2511624	et	4	main
ei	doc_491521501841_item	2511630	et	4	main
film	doc_491521501841_item	2511633	et	3	main
sarnast	doc_491521501841_item	2511640	et	4	main
vaid	doc_491521501841_item	2511641	et	3	main
see	doc_491521501841_item	2511642	et	3	main
mis	doc_491521501841_item	2511643	et	4	main
paneb	doc_491521501841_item	2511644	et	3	main
see	doc_491521501841_item	2511652	et	3	main
ma	doc_491521501842_item	2511675	et	3	main
raamatu	doc_491521501842_item	2511677	et	4	main
köiteta	doc_491521501842_item	2511679	et	4	main
mida	doc_491521501842_item	2511691	et	4	main
inimesed	doc_491521501842_item	2511697	et	3	main
ja	doc_491521501842_item	2511698	et	3	main
miks	doc_491521501842_item	2511699	et	4	main
meelest	doc_491521501842_item	2511707	et	4	main
maitse	doc_491521501841_item	2511262	et	4	main
nimed	doc_491521501841_item	2511296	et	3	main
kuulub	doc_491521501841_item	2511298	et	3	main
hulka	doc_491521501841_item	2511301	et	4	main
on	doc_491521501841_item	2511311	et	4	main
filmis	doc_491521501841_item	2511314	et	4	main
on	doc_491521501841_item	2511315	et	4	main
ka	doc_491521501841_item	2511333	et	3	main
kurb	doc_491521501841_item	2511335	et	3	main
isegi	doc_491521501841_item	2511337	et	4	main
nimed	doc_491521501841_item	2511342	et	3	main
just	doc_491521501841_item	2511347	et	3	main
selline	doc_491521501841_item	2511348	et	4	main
film	doc_491521501841_item	2511349	et	3	main
paneb	doc_491521501841_item	2511350	et	3	main
jätta	doc_491521501841_item	2511364	et	3	main
ning	doc_491521501841_item	2511367	et	3	main
kooliga	doc_491521501841_item	2511372	et	4	main
sõjaväe	doc_491521501841_item	2511373	et	3	main
küsimuse	doc_491521501841_item	2511379	et	4	main
ja	doc_491521501841_item	2511392	et	3	main
näinud	doc_491521501841_item	2511393	et	4	main
erilist	doc_491521501841_item	2511407	et	4	main
huvi	doc_491521501841_item	2511408	et	4	main
põhikooli	doc_491521501841_item	2511415	et	4	main
nimekirja	doc_491521501841_item	2511418	et	4	main
läbi	doc_491521501841_item	2511436	et	4	main
et	doc_491521501841_item	2511438	et	3	main
huvitav	doc_491521501841_item	2511449	et	4	main
vaadata	doc_491521501841_item	2511450	et	4	main
ja	doc_491521501841_item	2511451	et	3	main
jalgida	doc_491521501841_item	2511465	et	4	main
inimtüüpe	doc_491521501841_item	2511473	et	3	main
argpükse	doc_491521501841_item	2511476	et	3	main
külmaverelisi	doc_491521501841_item	2511479	et	4	main
vanemaid	doc_491521501841_item	2511515	et	4	main
pidi	doc_491521501841_item	2511517	et	4	main
vaadata	doc_491521501841_item	2511267	et	4	main
selles	doc_491521501841_item	2511305	et	4	main
ta	doc_491521501841_item	2511310	et	4	main
kõik	doc_491521501841_item	2511316	et	4	main
tolle	doc_491521501841_item	2511321	et	4	main
olukord	doc_491521501841_item	2511324	et	3	main
jooksul	doc_491521501841_item	2511327	et	4	main
saab	doc_491521501841_item	2511328	et	3	main
nalja	doc_491521501841_item	2511329	et	4	main
ja	doc_491521501841_item	2511330	et	3	main
või	doc_491521501841_item	2511336	et	4	main
hirmus	doc_491521501841_item	2511338	et	4	main
selliseid	doc_491521501841_item	2511339	et	4	main
meid	doc_491521501841_item	2511351	et	4	main
mõtlema	doc_491521501841_item	2511352	et	3	main
film	doc_491521501841_item	2511362	et	3	main
ükskõikseks	doc_491521501841_item	2511365	et	4	main
kes	doc_491521501841_item	2511370	et	4	main
hiilida	doc_491521501841_item	2511376	et	3	main
esitaksid	doc_491521501841_item	2511377	et	4	main
eest	doc_491521501841_item	2511383	et	4	main
võitlema	doc_491521501841_item	2511384	et	3	main
läheb	doc_491521501841_item	2511385	et	3	main
kui	doc_491521501841_item	2511386	et	3	main
meie	doc_491521501841_item	2511387	et	4	main
õige	doc_491521501841_item	2511397	et	4	main
leiavad	doc_491521501841_item	2511399	et	3	main
näha	doc_491521501841_item	2511401	et	3	main
ei	doc_491521501841_item	2511405	et	4	main
tunne	doc_491521501841_item	2511406	et	4	main
pärast	doc_491521501841_item	2511424	et	4	main
võib-olla	doc_491521501841_item	2511429	et	3	main
film	doc_491521501841_item	2511430	et	3	main
tekitab	doc_491521501841_item	2511431	et	3	main
raamatut	doc_491521501841_item	2511435	et	3	main
oma	doc_491521501841_item	2511439	et	4	main
paremini	doc_491521501841_item	2511441	et	4	main
tundma	doc_491521501841_item	2511442	et	3	main
õppida	doc_491521501841_item	2511443	et	3	main
vähemalt	doc_491521501841_item	2511444	et	4	main
mul	doc_491521501841_item	2511445	et	3	main
oli	doc_491521501841_item	2511446	et	3	main
seda	doc_491521501841_item	2511447	et	3	main
mis	doc_491521501841_item	2511452	et	4	main
ta	doc_491521501841_item	2511455	et	4	main
tegelaste	doc_491521501841_item	2511466	et	3	main
palju	doc_491521501841_item	2511471	et	4	main
ja	doc_491521501841_item	2511475	et	3	main
ühe	doc_491521501841_item	2511520	et	4	main
elu	doc_491521501841_item	2511522	et	4	main
kes	doc_491521501841_item	2511553	et	4	main
on	doc_491521501841_item	2511565	et	4	main
vabadust	doc_491521501841_item	2511586	et	4	main
selget	doc_491521501841_item	2511588	et	3	main
on	doc_491521501841_item	2511602	et	4	main
ajal	doc_491521501841_item	2511606	et	4	main
film	doc_491521501841_item	2511629	et	3	main
mis	doc_491521501841_item	2511634	et	4	main
meeldib	doc_491521501841_item	2511636	et	3	main
veel	doc_491521501841_item	2511638	et	4	main
mõtlema	doc_491521501841_item	2511645	et	3	main
vaidlusi	doc_491521501841_item	2511649	et	3	main
mis	doc_491521501841_item	2511653	et	4	main
keelatud	doc_491521501842_item	2511682	et	4	main
mus	doc_491521501842_item	2511683	et	3	main
äratas	doc_491521501842_item	2511684	et	3	main
huvi	doc_491521501842_item	2511685	et	4	main
mis	doc_491521501842_item	2511686	et	4	main
on	doc_491521501842_item	2511687	et	4	main
ei	doc_491521501842_item	2511692	et	4	main
tohtinud	doc_491521501842_item	2511693	et	4	main
lugeda	doc_491521501842_item	2511694	et	3	main
riskides	doc_491521501842_item	2511703	et	4	main
suurepärane	doc_491521501842_item	2511710	et	4	main
romaan	doc_491521501842_item	2511711	et	3	main
fakte	doc_491521501842_item	2511716	et	3	main
ka	doc_491521501842_item	2511718	et	3	main
just	doc_491521501841_item	2511299	et	3	main
igaüks	doc_491521501841_item	2511303	et	3	main
filmis	doc_491521501841_item	2511306	et	4	main
jaoks	doc_491521501841_item	2511309	et	4	main
aja	doc_491521501841_item	2511322	et	4	main
poliitiline	doc_491521501841_item	2511323	et	3	main
vahel	doc_491521501841_item	2511331	et	4	main
väga	doc_491521501841_item	2511334	et	3	main
nägu	doc_491521501841_item	2511341	et	4	main
on	doc_491521501841_item	2511344	et	4	main
ei	doc_491521501841_item	2511363	et	4	main
need	doc_491521501841_item	2511368	et	3	main
kodumaad	doc_491521501841_item	2511388	et	4	main
mingi	doc_491521501841_item	2511389	et	4	main
oht	doc_491521501841_item	2511390	et	3	main
ähvardab	doc_491521501841_item	2511391	et	3	main
ikka	doc_491521501841_item	2511396	et	4	main
tänapäeva	doc_491521501841_item	2511403	et	4	main
noored	doc_491521501841_item	2511404	et	3	main
samas	doc_491521501841_item	2511411	et	4	main
loodan	doc_491521501841_item	2511412	et	3	main
et	doc_491521501841_item	2511413	et	3	main
kirjanduse	doc_491521501841_item	2511417	et	3	main
sõjalahingud	doc_491521501841_item	2511325	et	3	main
filmi	doc_491521501841_item	2511326	et	4	main
on	doc_491521501841_item	2511332	et	4	main
linastuseid	doc_491521501841_item	2511340	et	4	main
vaja	doc_491521501841_item	2511345	et	4	main
sest	doc_491521501841_item	2511346	et	4	main
ajaloost	doc_491521501841_item	2511353	et	4	main
rahvuslikust	doc_491521501841_item	2511354	et	4	main
uhkusest	doc_491521501841_item	2511355	et	4	main
ja	doc_491521501841_item	2511356	et	3	main
ühtsusest	doc_491521501841_item	2511357	et	4	main
tahaks	doc_491521501841_item	2511358	et	3	main
loota	doc_491521501841_item	2511359	et	4	main
see	doc_491521501841_item	2511361	et	3	main
endale	doc_491521501841_item	2511378	et	4	main
tänapäeva	doc_491521501841_item	2511381	et	4	main
eesti	doc_491521501841_item	2511382	et	4	main
kohustusliku	doc_491521501841_item	2511416	et	3	main
kuulunud	doc_491521501841_item	2511419	et	4	main
a	doc_491521501841_item	2511420	et	4	main
saab	doc_491521501841_item	2511423	et	3	main
näinud	doc_491521501841_item	2511425	et	4	main
filmi	doc_491521501841_item	2511426	et	4	main
õppurite	doc_491521501841_item	2511427	et	3	main
lemmikteoseks	doc_491521501841_item	2511428	et	4	main
neis	doc_491521501841_item	2511432	et	4	main
ajalugu	doc_491521501841_item	2511440	et	4	main
paljude	doc_491521501841_item	2511458	et	3	main
asjade	doc_491521501841_item	2511459	et	3	main
üle	doc_491521501841_item	2511460	et	3	main
mõelda	doc_491521501841_item	2511461	et	4	main
eriti	doc_491521501841_item	2511462	et	3	main
põnev	doc_491521501841_item	2511463	et	3	main
oli	doc_491521501841_item	2511464	et	3	main
erinevaid	doc_491521501841_item	2511472	et	4	main
rahulikke	doc_491521501841_item	2511477	et	4	main
ja	doc_491521501841_item	2511478	et	3	main
oma	doc_491521501841_item	2511521	et	4	main
otsuse	doc_491521501841_item	2511524	et	3	main
sõdivad	doc_491521501841_item	2511526	et	4	main
vanemad	doc_491521501841_item	2511529	et	4	main
venelased	doc_491521501841_item	2511532	et	3	main
mina	doc_491521501841_item	2511533	et	4	main
olen	doc_491521501841_item	2511534	et	3	main
sündinud	doc_491521501841_item	2511535	et	4	main
ja	doc_491521501841_item	2511536	et	3	main
tekitas	doc_491521501841_item	2511545	et	3	main
ma	doc_491521501841_item	2511554	et	3	main
eestlane	doc_491521501841_item	2511560	et	3	main
venelane	doc_491521501841_item	2511562	et	3	main
miks	doc_491521501841_item	2511590	et	4	main
siis	doc_491521501841_item	2511591	et	3	main
tekivad	doc_491521501841_item	2511592	et	3	main
sõjad	doc_491521501841_item	2511593	et	3	main
selle	doc_491521501841_item	2511620	et	4	main
kivikase	doc_491521501841_item	2511421	et	3	main
soovi	doc_491521501841_item	2511433	et	4	main
filmi	doc_491521501841_item	2511448	et	4	main
kõige	doc_491521501841_item	2511453	et	4	main
karaktereid	doc_491521501841_item	2511467	et	3	main
filmis	doc_491521501841_item	2511468	et	4	main
oli	doc_491521501841_item	2511469	et	3	main
meie	doc_491521501841_item	2511480	et	4	main
silmades	doc_491521501841_item	2511481	et	3	main
muutusid	doc_491521501841_item	2511482	et	4	main
koolipoisid	doc_491521501841_item	2511483	et	4	main
meesteks	doc_491521501841_item	2511484	et	4	main
mind	doc_491521501841_item	2511485	et	4	main
ei	doc_491521501841_item	2511486	et	4	main
jatnud	doc_491521501841_item	2511487	et	4	main
külmaks	doc_491521501841_item	2511488	et	4	main
marta	doc_491521501841_item	2511489	et	4	main
ja	doc_491521501841_item	2511490	et	3	main
ahase	doc_491521501841_item	2511491	et	4	main
kaunis	doc_491521501841_item	2511492	et	4	main
armastuslugu	doc_491521501841_item	2511493	et	4	main
väga	doc_491521501841_item	2511494	et	3	main
hea	doc_491521501841_item	2511495	et	4	main
muusika	doc_491521501841_item	2511496	et	4	main
ja	doc_491521501841_item	2511497	et	3	main
tegelaste	doc_491521501841_item	2511498	et	3	main
oskuslik	doc_491521501841_item	2511499	et	3	main
näitemäng	doc_491521501841_item	2511500	et	3	main
mulle	doc_491521501841_item	2511501	et	4	main
jai	doc_491521501841_item	2511502	et	4	main
kõige	doc_491521501841_item	2511503	et	4	main
rohkem	doc_491521501841_item	2511504	et	4	main
meelde	doc_491521501841_item	2511505	et	3	main
emotsionaalne	doc_491521501841_item	2511506	et	3	main
moment	doc_491521501841_item	2511507	et	3	main
kus	doc_491521501841_item	2511508	et	3	main
ahas	doc_491521501841_item	2511509	et	4	main
seisis	doc_491521501841_item	2511510	et	4	main
akna	doc_491521501841_item	2511511	et	3	main
taga	doc_491521501841_item	2511512	et	4	main
vaatles	doc_491521501841_item	2511513	et	3	main
ja	doc_491521501841_item	2511516	et	3	main
tegema	doc_491521501841_item	2511518	et	3	main
minu	doc_491521501841_item	2511528	et	3	main
rahvusest	doc_491521501841_item	2511531	et	4	main
elanud	doc_491521501841_item	2511537	et	4	main
eestis	doc_491521501841_item	2511538	et	3	main
see	doc_491521501841_item	2511539	et	3	main
on	doc_491521501841_item	2511540	et	4	main
mu	doc_491521501841_item	2511541	et	3	main
kodumaa	doc_491521501841_item	2511542	et	4	main
mus	doc_491521501841_item	2511546	et	3	main
siis	doc_491521501841_item	2511556	et	3	main
olen	doc_491521501841_item	2511558	et	3	main
või	doc_491521501841_item	2511561	et	4	main
kus	doc_491521501841_item	2511564	et	3	main
ja	doc_491521501841_item	2511600	et	3	main
oma	doc_491521501841_item	2511603	et	4	main
kohta	doc_491521501841_item	2511621	et	4	main
ma	doc_491521501841_item	2511623	et	3	main
tea	doc_491521501841_item	2511625	et	4	main
minu	doc_491521501841_item	2511626	et	3	main
jaoks	doc_491521501841_item	2511627	et	4	main
või	doc_491521501841_item	2511637	et	4	main
tekkitab	doc_491521501841_item	2511646	et	4	main
essee	doc_491521501842_item	2511659	et	4	main
mõte	doc_491521501842_item	2511660	et	3	main
punase	doc_491521501842_item	2511680	et	4	main
kirjaga	doc_491521501842_item	2511681	et	3	main
selle	doc_491521501842_item	2511688	et	4	main
keegi	doc_491521501842_item	2511700	et	4	main
mis	doc_491521501842_item	2511712	et	4	main
kajastab	doc_491521501842_item	2511713	et	3	main
hingeelu	doc_491521501842_item	2511720	et	4	main
ja	doc_491521501842_item	2511721	et	3	main
tekkinud	doc_491521501842_item	2511723	et	4	main
alati	doc_491521501842_item	2511729	et	4	main
toimub	doc_491521501842_item	2511730	et	3	main
sõja	doc_491521501842_item	2511731	et	3	main
miks	doc_491521501842_item	2511733	et	4	main
siis	doc_491521501842_item	2511734	et	3	main
tuleb	doc_491521501842_item	2511735	et	3	main
see	doc_491521501842_item	2511743	et	3	main
seda	doc_491521501842_item	2511745	et	3	main
väärt	doc_491521501842_item	2511756	et	4	main
olnud	doc_491521501842_item	2511768	et	4	main
kelle	doc_491521501842_item	2511777	et	4	main
ja	doc_491521501842_item	2511778	et	3	main
sõdima	doc_491521501842_item	2511784	et	3	main
oma	doc_491521501842_item	2511790	et	4	main
elu	doc_491521501842_item	2511791	et	4	main
võib	doc_491521501842_item	2511796	et	3	main
noortele	doc_491521501842_item	2511799	et	3	main
sõda	doc_491521501842_item	2511801	et	4	main
oli	doc_491521501842_item	2511802	et	3	main
järg-järgult	doc_491521501842_item	2511821	et	3	main
muidugi	doc_491521501842_item	2511823	et	4	main
sellega	doc_491521501842_item	2511826	et	3	main
inimese	doc_491521501842_item	2511832	et	4	main
inimesi	doc_491521501842_item	2511843	et	4	main
tegutsema	doc_491521501842_item	2511844	et	3	main
nii	doc_491521501842_item	2511848	et	3	main
isamaa	doc_491521501842_item	2511850	et	4	main
kui	doc_491521501842_item	2511852	et	3	main
aga	doc_491521501842_item	2511856	et	3	main
ei	doc_491521501842_item	2511865	et	4	main
isa	doc_491521501842_item	2511875	et	4	main
ikka	doc_491521501842_item	2511918	et	4	main
essee	doc_491521501843_item	2511922	et	4	main
nimed	doc_491521501843_item	2511924	et	3	main
vähestest	doc_491521501843_item	2511929	et	3	main
nimed	doc_491521501843_item	2511934	et	3	main
tähelepanu	doc_491521501843_item	2511937	et	4	main
kriitikute	doc_491521501843_item	2511939	et	3	main
sulest	doc_491521501843_item	2511940	et	4	main
kui	doc_491521501843_item	2511945	et	3	main
positiivset	doc_491521501843_item	2511947	et	3	main
et	doc_491521501843_item	2511950	et	3	main
tegemine	doc_491521501843_item	2511953	et	4	main
on	doc_491521501843_item	2511954	et	4	main
eelkõige	doc_491521501843_item	2511955	et	3	main
et	doc_491521501843_item	2511961	et	3	main
eesti	doc_491521501843_item	2511964	et	4	main
raskeima	doc_491521501841_item	2511523	et	4	main
eestlased	doc_491521501841_item	2511525	et	3	main
venelastega	doc_491521501841_item	2511527	et	4	main
veel	doc_491521501841_item	2511547	et	4	main
küsimuse	doc_491521501841_item	2511549	et	4	main
ma	doc_491521501841_item	2511555	et	3	main
rohkem	doc_491521501841_item	2511557	et	4	main
kas	doc_491521501841_item	2511559	et	3	main
mu	doc_491521501841_item	2511566	et	3	main
mõeldes	doc_491521501841_item	2511568	et	3	main
isamaa	doc_491521501841_item	2511567	et	4	main
küsimusele	doc_491521501841_item	2511570	et	4	main
sellele	doc_491521501841_item	2511569	et	4	main
hakkas	doc_491521501841_item	2511571	et	3	main
mul	doc_491521501841_item	2511572	et	3	main
isegi	doc_491521501841_item	2511573	et	4	main
hirm	doc_491521501841_item	2511574	et	3	main
me	doc_491521501841_item	2511575	et	4	main
oleme	doc_491521501841_item	2511576	et	3	main
kõik	doc_491521501841_item	2511577	et	4	main
ju	doc_491521501841_item	2511578	et	3	main
inimesed	doc_491521501841_item	2511579	et	3	main
sõltumata	doc_491521501841_item	2511580	et	4	main
rahvusest	doc_491521501841_item	2511581	et	4	main
ja	doc_491521501841_item	2511582	et	3	main
tahame	doc_491521501841_item	2511583	et	3	main
kõik	doc_491521501841_item	2511584	et	4	main
ühte	doc_491521501841_item	2511585	et	4	main
ja	doc_491521501841_item	2511587	et	3	main
taevast	doc_491521501841_item	2511589	et	4	main
seal	doc_491521501841_item	2511601	et	4	main
ja	doc_491521501841_item	2511604	et	3	main
samal	doc_491521501841_item	2511605	et	3	main
võõras	doc_491521501841_item	2511607	et	4	main
kas	doc_491521501841_item	2511608	et	3	main
siis	doc_491521501841_item	2511609	et	3	main
on	doc_491521501841_item	2511610	et	4	main
nimed	doc_491521501841_item	2511611	et	3	main
marmortahvlil	doc_491521501841_item	2511612	et	3	main
hea	doc_491521501841_item	2511628	et	4	main
midagi	doc_491521501841_item	2511639	et	4	main
küsimusi	doc_491521501841_item	2511647	et	4	main
on	doc_491521501841_item	2511651	et	4	main
jatta	doc_491521501841_item	2511655	et	4	main
nägin	doc_491521501842_item	2511676	et	3	main
ilma	doc_491521501842_item	2511678	et	4	main
sees	doc_491521501842_item	2511690	et	4	main
aja	doc_491521501842_item	2511696	et	4	main
eluga	doc_491521501842_item	2511702	et	3	main
seda	doc_491521501842_item	2511705	et	3	main
nii	doc_491521501842_item	2511714	et	3	main
vastu	doc_491521501842_item	2511725	et	3	main
saavutamine	doc_491521501842_item	2511727	et	4	main
maksta	doc_491521501842_item	2511738	et	4	main
kas	doc_491521501842_item	2511742	et	3	main
väärt	doc_491521501842_item	2511746	et	4	main
romaan	doc_491521501842_item	2511748	et	3	main
et	doc_491521501842_item	2511750	et	3	main
keerulisesse	doc_491521501842_item	2511757	et	4	main
olukorda	doc_491521501842_item	2511758	et	4	main
peategelased	doc_491521501842_item	2511761	et	3	main
õpilased	doc_491521501842_item	2511763	et	3	main
kellel	doc_491521501842_item	2511766	et	4	main
ei	doc_491521501842_item	2511767	et	4	main
otsuse	doc_491521501842_item	2511773	et	3	main
mille	doc_491521501842_item	2511779	et	3	main
olid	doc_491521501842_item	2511786	et	4	main
küll	doc_491521501842_item	2511787	et	4	main
ohverdama	doc_491521501842_item	2511789	et	3	main
vabaduse	doc_491521501842_item	2511793	et	4	main
mis	doc_491521501842_item	2511807	et	4	main
kuid	doc_491521501842_item	2511827	et	4	main
elu	doc_491521501842_item	2511833	et	4	main
eest	doc_491521501842_item	2511834	et	4	main
on	doc_491521501842_item	2511845	et	4	main
ahas	doc_491521501842_item	2511863	et	4	main
kaua	doc_491521501842_item	2511864	et	3	main
poolel	doc_491521501842_item	2511869	et	4	main
ja	doc_491521501842_item	2511876	et	3	main
teiselt	doc_491521501842_item	2511878	et	4	main
arusaam	doc_491521501842_item	2511879	et	3	main
et	doc_491521501842_item	2511880	et	3	main
õpetama	doc_491521501842_item	2511921	et	3	main
marmortahvlil	doc_491521501843_item	2511925	et	3	main
viimase	doc_491521501843_item	2511927	et	3	main
eesti	doc_491521501843_item	2511930	et	4	main
pälvis	doc_491521501843_item	2511932	et	3	main
nii	doc_491521501843_item	2511943	et	3	main
ka	doc_491521501843_item	2511946	et	3	main
hinnangut	doc_491521501843_item	2511948	et	3	main
ainult	doc_491521501843_item	2511956	et	4	main
kasu	doc_491521501843_item	2511957	et	4	main
toonud	doc_491521501843_item	2511958	et	4	main
eelkõige	doc_491521501843_item	2511959	et	3	main
andis	doc_491521501843_item	2511973	et	3	main
kerge	doc_491521501843_item	2511987	et	4	main
valikut	doc_491521501843_item	2511989	et	3	main
teha	doc_491521501843_item	2511990	et	3	main
sõda	doc_491521501843_item	2511991	et	4	main
teinud	doc_491521501843_item	2512021	et	4	main
minnes	doc_491521501843_item	2512024	et	3	main
punaste	doc_491521501843_item	2512028	et	4	main
ta	doc_491521501843_item	2512033	et	4	main
ei	doc_491521501843_item	2512034	et	4	main
seetõttu	doc_491521501843_item	2512043	et	3	main
nolgid	doc_491521501843_item	2512052	et	3	main
sinna	doc_491521501843_item	2512053	et	3	main
henn	doc_491521501843_item	2512064	et	4	main
pere	doc_491521501843_item	2512069	et	4	main
ole	doc_491521501841_item	2511631	et	4	main
see	doc_491521501841_item	2511632	et	3	main
kõigile	doc_491521501841_item	2511635	et	4	main
ja	doc_491521501841_item	2511648	et	3	main
hea	doc_491521501841_item	2511650	et	4	main
ei	doc_491521501841_item	2511654	et	4	main
meid	doc_491521501841_item	2511656	et	4	main
ükskõikseks	doc_491521501841_item	2511657	et	4	main
essee	doc_491521501842_item	2511658	et	4	main
lugeda	doc_491521501842_item	2511661	et	3	main
romaani	doc_491521501842_item	2511662	et	4	main
nimed	doc_491521501842_item	2511663	et	3	main
marmortahvlil	doc_491521501842_item	2511664	et	3	main
või	doc_491521501842_item	2511665	et	4	main
vaadata	doc_491521501842_item	2511666	et	4	main
filmi	doc_491521501842_item	2511667	et	4	main
tekkis	doc_491521501842_item	2511668	et	3	main
mul	doc_491521501842_item	2511669	et	3	main
pärast	doc_491521501842_item	2511670	et	4	main
tpü	doc_491521501842_item	2511671	et	4	main
muuseumi	doc_491521501842_item	2511672	et	4	main
külastamist	doc_491521501842_item	2511673	et	4	main
kui	doc_491521501842_item	2511674	et	3	main
raamatu	doc_491521501842_item	2511689	et	4	main
tolla	doc_491521501842_item	2511695	et	4	main
oma	doc_491521501842_item	2511701	et	4	main
varjas	doc_491521501842_item	2511704	et	4	main
minu	doc_491521501842_item	2511706	et	3	main
ajaloolisi	doc_491521501842_item	2511715	et	4	main
suhtumist	doc_491521501842_item	2511722	et	4	main
iseseisvuse	doc_491521501842_item	2511726	et	4	main
peaaegu	doc_491521501842_item	2511728	et	3	main
selle	doc_491521501842_item	2511739	et	4	main
on	doc_491521501842_item	2511744	et	4	main
küll	doc_491521501842_item	2511754	et	4	main
seda	doc_491521501842_item	2511755	et	3	main
sattusid	doc_491521501842_item	2511759	et	4	main
mingi	doc_491521501842_item	2511769	et	4	main
sõltus	doc_491521501842_item	2511776	et	4	main
nad	doc_491521501842_item	2511781	et	3	main
nad	doc_491521501842_item	2511785	et	3	main
isamaa	doc_491521501842_item	2511792	et	4	main
romaantika	doc_491521501842_item	2511806	et	4	main
see	doc_491521501842_item	2511708	et	3	main
on	doc_491521501842_item	2511709	et	4	main
kui	doc_491521501842_item	2511717	et	3	main
inimeste	doc_491521501842_item	2511719	et	3	main
olukorra	doc_491521501842_item	2511724	et	3	main
nii	doc_491521501842_item	2511736	et	3	main
kallist	doc_491521501842_item	2511737	et	4	main
ja	doc_491521501842_item	2511741	et	3	main
vabadus	doc_491521501842_item	2511752	et	4	main
on	doc_491521501842_item	2511753	et	4	main
romaani	doc_491521501842_item	2511760	et	4	main
kommertskooli	doc_491521501842_item	2511762	et	4	main
inimestele	doc_491521501842_item	2511765	et	3	main
hakkavad	doc_491521501842_item	2511783	et	4	main
aga	doc_491521501842_item	2511795	et	3	main
et	doc_491521501842_item	2511798	et	3	main
koolipoistele	doc_491521501842_item	2511800	et	3	main
nad	doc_491521501842_item	2511822	et	3	main
hakkasid	doc_491521501842_item	2511824	et	4	main
harjuma	doc_491521501842_item	2511825	et	3	main
oma	doc_491521501842_item	2511829	et	4	main
armastus	doc_491521501842_item	2511849	et	4	main
vastu	doc_491521501842_item	2511851	et	3	main
inimeste	doc_491521501842_item	2511854	et	3	main
samaaegselt	doc_491521501842_item	2511858	et	4	main
paneb	doc_491521501842_item	2511859	et	3	main
ka	doc_491521501842_item	2511860	et	3	main
kahtlema	doc_491521501842_item	2511861	et	3	main
näiteks	doc_491521501842_item	2511862	et	4	main
suutnud	doc_491521501842_item	2511866	et	4	main
vend	doc_491521501842_item	2511877	et	3	main
ta	doc_491521501842_item	2511881	et	4	main
peaks	doc_491521501842_item	2511914	et	4	main
aja	doc_491521501843_item	2511928	et	4	main
filmidest	doc_491521501843_item	2511931	et	3	main
marmortahvlil	doc_491521501843_item	2511935	et	3	main
leian	doc_491521501843_item	2511949	et	3	main
see	doc_491521501843_item	2511962	et	3	main
ajalugu	doc_491521501843_item	2511965	et	4	main
raamatus	doc_491521501843_item	2511975	et	4	main
mis	doc_491521501843_item	2511979	et	4	main
valitsesid	doc_491521501843_item	2511982	et	4	main
noortel	doc_491521501843_item	2511984	et	3	main
teadmata	doc_491521501843_item	2512026	et	4	main
ega	doc_491521501843_item	2512036	et	3	main
tohi	doc_491521501843_item	2512037	et	4	main
mis	doc_491521501843_item	2512050	et	4	main
käsib	doc_491521501843_item	2512056	et	3	main
hoopis	doc_491521501843_item	2512057	et	3	main
isa	doc_491521501843_item	2512060	et	4	main
arvates	doc_491521501843_item	2512067	et	4	main
vend	doc_491521501843_item	2512073	et	3	main
ei	doc_491521501843_item	2512078	et	4	main
ole	doc_491521501843_item	2512079	et	4	main
just	doc_491521501843_item	2512080	et	3	main
sellise	doc_491521501843_item	2512087	et	4	main
minu	doc_491521501843_item	2512092	et	3	main
selle	doc_491521501843_item	2512094	et	4	main
loo	doc_491521501843_item	2512095	et	4	main
kõige	doc_491521501843_item	2512096	et	4	main
see	doc_491521501843_item	2512106	et	3	main
aga	doc_491521501843_item	2512109	et	3	main
jaoks	doc_491521501843_item	2512111	et	4	main
siiski	doc_491521501843_item	2512114	et	4	main
suur	doc_491521501843_item	2512115	et	3	main
hulk	doc_491521501843_item	2512116	et	3	main
inimesi	doc_491521501843_item	2512117	et	4	main
noored	doc_491521501843_item	2512121	et	3	main
filmi	doc_491521501843_item	2512133	et	4	main
muuta	doc_491521501843_item	2512139	et	4	main
ahas	doc_491521501843_item	2512147	et	4	main
isik	doc_491521501843_item	2512151	et	3	main
mõisas	doc_491521501843_item	2512157	et	3	main
punaste	doc_491521501843_item	2512158	et	4	main
äkkrünnaku	doc_491521501843_item	2512159	et	3	main
sõjavõitlejate	doc_491521501843_item	2512165	et	3	main
maksis	doc_491521501843_item	2512226	et	4	main
nad	doc_491521501843_item	2512227	et	3	main
ei	doc_491521501843_item	2512228	et	4	main
kogenud	doc_491521501843_item	2512233	et	4	main
elu	doc_491521501843_item	2512243	et	4	main
ei	doc_491521501843_item	2512248	et	4	main
abil	doc_491521501842_item	2511732	et	4	main
eest	doc_491521501842_item	2511740	et	4	main
kivikase	doc_491521501842_item	2511747	et	3	main
näitab	doc_491521501842_item	2511749	et	3	main
isamaa	doc_491521501842_item	2511751	et	4	main
noortele	doc_491521501842_item	2511764	et	3	main
elukogemust	doc_491521501842_item	2511770	et	3	main
tuli	doc_491521501842_item	2511771	et	4	main
teha	doc_491521501842_item	2511772	et	3	main
sellest	doc_491521501842_item	2511774	et	4	main
otsusest	doc_491521501842_item	2511775	et	4	main
eest	doc_491521501842_item	2511780	et	4	main
hakkavad	doc_491521501842_item	2511782	et	4	main
nõus	doc_491521501842_item	2511788	et	4	main
eest	doc_491521501842_item	2511794	et	4	main
öelda	doc_491521501842_item	2511797	et	4	main
mingi	doc_491521501842_item	2511803	et	4	main
moel	doc_491521501842_item	2511804	et	4	main
nagu	doc_491521501842_item	2511805	et	3	main
hajus	doc_491521501842_item	2511808	et	4	main
kui	doc_491521501842_item	2511809	et	3	main
nad	doc_491521501842_item	2511810	et	3	main
tundsid	doc_491521501842_item	2511811	et	4	main
surma	doc_491521501842_item	2511812	et	4	main
reaalsust	doc_491521501842_item	2511813	et	4	main
et	doc_491521501842_item	2511814	et	3	main
surm	doc_491521501842_item	2511815	et	3	main
on	doc_491521501842_item	2511816	et	4	main
ja	doc_491521501842_item	2511818	et	3	main
nii	doc_491521501842_item	2511819	et	3	main
vältimatu	doc_491521501842_item	2511817	et	4	main
lähedal	doc_491521501842_item	2511820	et	4	main
hirm	doc_491521501842_item	2511828	et	3	main
lähedase	doc_491521501842_item	2511831	et	3	main
ikka	doc_491521501842_item	2511835	et	4	main
säilis	doc_491521501842_item	2511836	et	4	main
minu	doc_491521501842_item	2511837	et	3	main
arvates	doc_491521501842_item	2511838	et	4	main
peamiseks	doc_491521501842_item	2511839	et	3	main
jõuks	doc_491521501842_item	2511840	et	3	main
muidugi	doc_491521501842_item	2511846	et	4	main
otsustada	doc_491521501842_item	2511867	et	3	main
kumma	doc_491521501842_item	2511868	et	3	main
on	doc_491521501842_item	2511870	et	4	main
tänapäeva	doc_491521501842_item	2511916	et	4	main
essee	doc_491521501843_item	2511923	et	4	main
ühest	doc_491521501843_item	2511926	et	4	main
negatiivset	doc_491521501843_item	2511944	et	3	main
sellise	doc_491521501843_item	2511951	et	4	main
filmi	doc_491521501843_item	2511952	et	4	main
seetõttu	doc_491521501843_item	2511960	et	3	main
kivikas	doc_491521501843_item	2511972	et	4	main
oma	doc_491521501843_item	2511974	et	4	main
olnud	doc_491521501843_item	2511986	et	4	main
seda	doc_491521501843_item	2511988	et	3	main
venna	doc_491521501843_item	2512025	et	3	main
taha	doc_491521501843_item	2512035	et	4	main
öeldes	doc_491521501843_item	2512049	et	3	main
ning	doc_491521501843_item	2512055	et	3	main
on	doc_491521501843_item	2512065	et	4	main
ainus	doc_491521501843_item	2512070	et	4	main
et	doc_491521501843_item	2512075	et	3	main
siis	doc_491521501843_item	2512083	et	3	main
keerulisem	doc_491521501843_item	2512097	et	4	main
osa	doc_491521501843_item	2512098	et	4	main
vabadussõjas	doc_491521501843_item	2512099	et	3	main
hukkus	doc_491521501843_item	2512100	et	3	main
üle	doc_491521501843_item	2512101	et	3	main
200	doc_491521501843_item	2512102	et	2	main
ja	doc_491521501842_item	2511830	et	3	main
mis	doc_491521501842_item	2511841	et	4	main
juhib	doc_491521501842_item	2511842	et	3	main
armastus	doc_491521501842_item	2511847	et	4	main
ka	doc_491521501842_item	2511853	et	3	main
vastu	doc_491521501842_item	2511855	et	3	main
armastus	doc_491521501842_item	2511857	et	4	main
tema	doc_491521501842_item	2511871	et	4	main
ühelt	doc_491521501842_item	2511872	et	3	main
poolt	doc_491521501842_item	2511873	et	4	main
punasemeelsed	doc_491521501842_item	2511874	et	3	main
lihtsalt	doc_491521501842_item	2511882	et	4	main
ei	doc_491521501842_item	2511883	et	4	main
suuda	doc_491521501842_item	2511884	et	4	main
võidelda	doc_491521501842_item	2511885	et	4	main
oma	doc_491521501842_item	2511886	et	4	main
rahva	doc_491521501842_item	2511887	et	3	main
vastu	doc_491521501842_item	2511888	et	3	main
just	doc_491521501842_item	2511889	et	3	main
niisuguste	doc_491521501842_item	2511890	et	3	main
nagu	doc_491521501842_item	2511891	et	3	main
kivikase	doc_491521501842_item	2511892	et	3	main
noorte	doc_491521501842_item	2511893	et	3	main
koolipoiste	doc_491521501842_item	2511894	et	3	main
otsus	doc_491521501842_item	2511895	et	3	main
ja	doc_491521501842_item	2511896	et	3	main
sõjas	doc_491521501842_item	2511897	et	3	main
osavõtmine	doc_491521501842_item	2511898	et	3	main
mõjutasid	doc_491521501842_item	2511899	et	4	main
vabadussõja	doc_491521501842_item	2511900	et	3	main
tulemust	doc_491521501842_item	2511901	et	4	main
ning	doc_491521501842_item	2511902	et	3	main
eesti	doc_491521501842_item	2511903	et	4	main
tervikuna	doc_491521501842_item	2511905	et	3	main
see	doc_491521501842_item	2511906	et	3	main
ajalugu	doc_491521501842_item	2511904	et	4	main
on	doc_491521501842_item	2511907	et	4	main
väga	doc_491521501842_item	2511908	et	3	main
mõtlema	doc_491521501842_item	2511909	et	3	main
panev	doc_491521501842_item	2511910	et	4	main
romaan	doc_491521501842_item	2511911	et	3	main
ning	doc_491521501842_item	2511912	et	3	main
see	doc_491521501842_item	2511913	et	3	main
meie	doc_491521501842_item	2511915	et	4	main
noortele	doc_491521501842_item	2511917	et	3	main
ka	doc_491521501842_item	2511919	et	3	main
midagi	doc_491521501842_item	2511920	et	4	main
just	doc_491521501843_item	2511933	et	3	main
laialdast	doc_491521501843_item	2511936	et	3	main
kuigi	doc_491521501843_item	2511938	et	3	main
on	doc_491521501843_item	2511941	et	4	main
tulnud	doc_491521501843_item	2511942	et	4	main
tutvustab	doc_491521501843_item	2511963	et	3	main
ülevaate	doc_491521501843_item	2511977	et	4	main
valikutest	doc_491521501843_item	2511978	et	4	main
tol	doc_491521501843_item	2511980	et	3	main
tolleaegsetel	doc_491521501843_item	2511983	et	4	main
viis	doc_491521501843_item	2511992	et	4	main
paljud	doc_491521501843_item	2511993	et	3	main
otseselt	doc_491521501843_item	2511997	et	4	main
surma	doc_491521501843_item	2511998	et	4	main
või	doc_491521501843_item	2511999	et	4	main
siis	doc_491521501843_item	2512000	et	3	main
vaimselt	doc_491521501843_item	2512001	et	4	main
rivist	doc_491521501843_item	2512002	et	3	main
välja	doc_491521501843_item	2512003	et	4	main
filmi	doc_491521501843_item	2512004	et	4	main
peategelane	doc_491521501843_item	2512005	et	3	main
henn	doc_491521501843_item	2512006	et	4	main
ahas	doc_491521501843_item	2512007	et	4	main
kõhkleb	doc_491521501843_item	2512008	et	3	main
kaua	doc_491521501843_item	2512009	et	3	main
kas	doc_491521501843_item	2512010	et	3	main
minna	doc_491521501843_item	2512011	et	3	main
sõtta	doc_491521501843_item	2512012	et	3	main
või	doc_491521501843_item	2512013	et	4	main
mitte	doc_491521501843_item	2512014	et	3	main
hennu	doc_491521501843_item	2512015	et	4	main
veli	doc_491521501843_item	2512016	et	3	main
läheb	doc_491521501843_item	2512017	et	3	main
ning	doc_491521501843_item	2512018	et	3	main
ta	doc_491521501843_item	2512019	et	4	main
on	doc_491521501843_item	2512020	et	4	main
ning	doc_491521501843_item	2511966	et	3	main
eesti	doc_491521501843_item	2511967	et	4	main
vabariigi	doc_491521501843_item	2511968	et	3	main
sündimise	doc_491521501843_item	2511969	et	4	main
tagamaid	doc_491521501843_item	2511970	et	4	main
albert	doc_491521501843_item	2511971	et	4	main
põhjaliku	doc_491521501843_item	2511976	et	3	main
ajal	doc_491521501843_item	2511981	et	4	main
ei	doc_491521501843_item	2511985	et	4	main
hukatusse	doc_491521501843_item	2511994	et	4	main
kas	doc_491521501843_item	2511995	et	3	main
siis	doc_491521501843_item	2511996	et	3	main
raske	doc_491521501843_item	2512022	et	4	main
hoopis	doc_491521501843_item	2512027	et	3	main
vend	doc_491521501843_item	2512030	et	3	main
tunneb	doc_491521501843_item	2512031	et	3	main
kunagi	doc_491521501843_item	2512038	et	3	main
keelabki	doc_491521501843_item	2512044	et	3	main
te	doc_491521501843_item	2512051	et	4	main
ja	doc_491521501843_item	2512059	et	3	main
eest	doc_491521501843_item	2512061	et	4	main
hoolitseda	doc_491521501843_item	2512062	et	3	main
sest	doc_491521501843_item	2512063	et	4	main
nende	doc_491521501843_item	2512068	et	4	main
kui	doc_491521501843_item	2512072	et	3	main
ta	doc_491521501843_item	2512076	et	4	main
kõige	doc_491521501843_item	2512081	et	4	main
valiku	doc_491521501843_item	2512088	et	3	main
tegi	doc_491521501843_item	2512089	et	4	main
arvates	doc_491521501843_item	2512093	et	4	main
on	doc_491521501843_item	2512105	et	4	main
see	doc_491521501843_item	2512113	et	3	main
ka	doc_491521501843_item	2512120	et	3	main
erineb	doc_491521501843_item	2512124	et	3	main
filmitegijad	doc_491521501843_item	2512132	et	3	main
kaasahaaravamaks	doc_491521501843_item	2512136	et	4	main
üldse	doc_491521501843_item	2512143	et	3	main
ning	doc_491521501843_item	2512145	et	3	main
aru	doc_491521501843_item	2512163	et	4	main
meeleheitest	doc_491521501843_item	2512166	et	4	main
hetked	doc_491521501843_item	2512171	et	3	main
ka	doc_491521501843_item	2512173	et	3	main
filmi	doc_491521501843_item	2512174	et	4	main
väga	doc_491521501843_item	2512176	et	3	main
melanhoolset	doc_491521501843_item	2512177	et	3	main
ka	doc_491521501843_item	2512219	et	3	main
mida	doc_491521501843_item	2512222	et	4	main
eesti	doc_491521501843_item	2512223	et	4	main
ole	doc_491521501843_item	2512229	et	4	main
omal	doc_491521501843_item	2512231	et	3	main
tunne	doc_491521501843_item	2512235	et	4	main
rahvale	doc_491521501843_item	2512239	et	3	main
nad	doc_491521501843_item	2512240	et	3	main
ei	doc_491521501843_item	2512241	et	4	main
nad	doc_491521501843_item	2512247	et	3	main
seda	doc_491521501843_item	2512250	et	3	main
teeks	doc_491521501843_item	2512261	et	4	main
noored	doc_491521501843_item	2512262	et	3	main
tänapäeval	doc_491521501843_item	2512263	et	3	main
samu	doc_491521501843_item	2512264	et	3	main
nimed	doc_491521501844_item	2512271	et	3	main
ajalugu	doc_491521501844_item	2512287	et	4	main
alevis	doc_491521501844_item	2512324	et	3	main
olustvere	doc_491521501844_item	2512327	et	4	main
vend	doc_491521501844_item	2512344	et	3	main
vennal	doc_491521501844_item	2512347	et	3	main
käia	doc_491521501844_item	2512351	et	4	main
1917a	doc_491521501844_item	2512353	et	4	main
sai	doc_491521501844_item	2512354	et	4	main
temast	doc_491521501844_item	2512355	et	3	main
punaarmeelane	doc_491521501844_item	2512356	et	3	main
liidu	doc_491521501844_item	2512379	et	3	main
liikmed	doc_491521501844_item	2512380	et	3	main
ning	doc_491521501844_item	2512388	et	3	main
sinna	doc_491521501844_item	2512389	et	3	main
kivikas	doc_491521501844_item	2512392	et	4	main
kirjanik	doc_491521501844_item	2512393	et	3	main
ahase	doc_491521501844_item	2512398	et	4	main
avaldatud	doc_491521501844_item	2512402	et	4	main
romaan	doc_491521501844_item	2512405	et	3	main
psühholoogiliselt	doc_491521501844_item	2512407	et	4	main
otsuse	doc_491521501843_item	2512023	et	3	main
poolele	doc_491521501843_item	2512029	et	4	main
et	doc_491521501843_item	2512032	et	3	main
enam	doc_491521501843_item	2512039	et	4	main
koju	doc_491521501843_item	2512040	et	3	main
tulla	doc_491521501843_item	2512041	et	3	main
ning	doc_491521501843_item	2512042	et	3	main
ta	doc_491521501843_item	2512045	et	4	main
vennal	doc_491521501843_item	2512046	et	3	main
sõtta	doc_491521501843_item	2512047	et	3	main
tulemast	doc_491521501843_item	2512048	et	4	main
ronite	doc_491521501843_item	2512054	et	3	main
ema	doc_491521501843_item	2512058	et	4	main
tema	doc_491521501843_item	2512066	et	4	main
lootus	doc_491521501843_item	2512071	et	4	main
õigem	doc_491521501843_item	2512082	et	4	main
miks	doc_491521501843_item	2512084	et	4	main
ta	doc_491521501843_item	2512085	et	4	main
üldse	doc_491521501843_item	2512086	et	3	main
ongi	doc_491521501843_item	2512091	et	4	main
maailmamastaabis	doc_491521501843_item	2512104	et	3	main
arv	doc_491521501843_item	2512108	et	3	main
eesti	doc_491521501843_item	2512110	et	4	main
oli	doc_491521501843_item	2512112	et	3	main
hulgas	doc_491521501843_item	2512119	et	4	main
tundis	doc_491521501843_item	2512074	et	3	main
valik	doc_491521501843_item	2512077	et	3	main
see	doc_491521501843_item	2512090	et	3	main
väike	doc_491521501843_item	2512107	et	4	main
nende	doc_491521501843_item	2512118	et	4	main
gümnaasiumipoisid	doc_491521501843_item	2512122	et	4	main
film	doc_491521501843_item	2512123	et	3	main
nii	doc_491521501843_item	2512126	et	3	main
koha	doc_491521501843_item	2512128	et	4	main
põnevamaks	doc_491521501843_item	2512134	et	4	main
martast	doc_491521501843_item	2512140	et	4	main
pole	doc_491521501843_item	2512141	et	3	main
kirjutatud	doc_491521501843_item	2512144	et	4	main
henn	doc_491521501843_item	2512146	et	4	main
ajalooline	doc_491521501843_item	2512150	et	4	main
kes	doc_491521501843_item	2512152	et	4	main
punaarmeelaste	doc_491521501843_item	2512154	et	4	main
juba	doc_491521501843_item	2512156	et	3	main
tunnetest	doc_491521501843_item	2512168	et	3	main
need	doc_491521501843_item	2512170	et	3	main
vaadates	doc_491521501843_item	2512175	et	3	main
neid	doc_491521501843_item	2512180	et	4	main
ei	doc_491521501843_item	2512182	et	4	main
seda	doc_491521501843_item	2512220	et	3	main
seda	doc_491521501843_item	2512230	et	3	main
nõukogude	doc_491521501843_item	2512244	et	3	main
liidus	doc_491521501843_item	2512245	et	4	main
oska	doc_491521501843_item	2512249	et	4	main
hinnata	doc_491521501843_item	2512257	et	4	main
minu	doc_491521501843_item	2512258	et	3	main
arvates	doc_491521501843_item	2512259	et	4	main
marmortahvlil	doc_491521501844_item	2512272	et	3	main
film	doc_491521501844_item	2512277	et	3	main
tuletab	doc_491521501844_item	2512278	et	3	main
lapsepõlv	doc_491521501844_item	2512325	et	3	main
tulevase	doc_491521501844_item	2512335	et	4	main
ema	doc_491521501844_item	2512337	et	4	main
teenis	doc_491521501844_item	2512338	et	3	main
nooremal	doc_491521501844_item	2512346	et	4	main
palgast	doc_491521501844_item	2512349	et	4	main
bolševikega	doc_491521501844_item	2512359	et	2	main
kadus	doc_491521501844_item	2512360	et	3	main
ta	doc_491521501844_item	2512361	et	4	main
eesti	doc_491521501844_item	2512381	et	4	main
moodustati	doc_491521501844_item	2512385	et	3	main
löögisalu	doc_491521501844_item	2512387	et	4	main
nime	doc_491521501844_item	2512399	et	4	main
1936a	doc_491521501844_item	2512401	et	4	main
ja	doc_491521501844_item	2512426	et	3	main
koolinoorte	doc_491521501844_item	2512427	et	3	main
väesalgad	doc_491521501844_item	2512428	et	3	main
kooliõpilaste	doc_491521501844_item	2512433	et	4	main
võrtsjärve	doc_491521501844_item	2512435	et	4	main
kirdekaldal	doc_491521501844_item	2512436	et	3	main
punaarmeed	doc_491521501844_item	2512438	et	4	main
lõuna	doc_491521501844_item	2512440	et	4	main
mõisas	doc_491521501844_item	2512447	et	3	main
valgutas	doc_491521501844_item	2512449	et	4	main
noortele	doc_491521501844_item	2512453	et	3	main
1919a	doc_491521501844_item	2512455	et	4	main
koolipoisid	doc_491521501844_item	2512464	et	4	main
neist	doc_491521501844_item	2512469	et	4	main
läheb	doc_491521501844_item	2512470	et	3	main
sõdima	doc_491521501844_item	2512471	et	3	main
esimene	doc_491521501844_item	2512492	et	3	main
taustal	doc_491521501844_item	2512522	et	3	main
väga	doc_491521501844_item	2512524	et	3	main
lippu	doc_491521501844_item	2512544	et	4	main
kujundavad	doc_491521501844_item	2512545	et	4	main
lõppenud	doc_491521501844_item	2512565	et	4	main
ahas	doc_491521501844_item	2512569	et	4	main
selles	doc_491521501844_item	2512573	et	4	main
viimases	doc_491521501844_item	2512574	et	3	main
lahingus	doc_491521501844_item	2512575	et	3	main
ahas	doc_491521501844_item	2512585	et	4	main
esimesele	doc_491521501844_item	2512586	et	3	main
osale	doc_491521501844_item	2512587	et	4	main
1951a	doc_491521501844_item	2512593	et	4	main
1954a	doc_491521501844_item	2512597	et	4	main
elmo	doc_491521501844_item	2512609	et	4	main
hingeminev	doc_491521501844_item	2512620	et	3	main
mehe	doc_491521501843_item	2512103	et	3	main
raamatust	doc_491521501843_item	2512125	et	4	main
mõnegi	doc_491521501843_item	2512127	et	3	main
pealt	doc_491521501843_item	2512129	et	4	main
kindlasti	doc_491521501843_item	2512130	et	3	main
üritasid	doc_491521501843_item	2512131	et	4	main
enam	doc_491521501843_item	2512135	et	4	main
teadukohaselt	doc_491521501843_item	2512149	et	4	main
poolt	doc_491521501843_item	2512155	et	4	main
ajal	doc_491521501843_item	2512160	et	4	main
film	doc_491521501843_item	2512161	et	3	main
aitas	doc_491521501843_item	2512162	et	3	main
ja	doc_491521501843_item	2512167	et	3	main
aga	doc_491521501843_item	2512179	et	3	main
hetki	doc_491521501843_item	2512181	et	4	main
ja	doc_491521501843_item	2512137	et	3	main
intrigeerivamaks	doc_491521501843_item	2512138	et	4	main
raamatus	doc_491521501843_item	2512142	et	4	main
oli	doc_491521501843_item	2512148	et	3	main
tapeti	doc_491521501843_item	2512153	et	3	main
saada	doc_491521501843_item	2512164	et	4	main
ning	doc_491521501843_item	2512169	et	3	main
tekitasid	doc_491521501843_item	2512172	et	4	main
tunnet	doc_491521501843_item	2512178	et	3	main
oldud	doc_491521501843_item	2512183	et	4	main
üle	doc_491521501843_item	2512184	et	3	main
dramatiseeritud	doc_491521501843_item	2512185	et	4	main
nimed	doc_491521501843_item	2512186	et	3	main
marmortahvlil	doc_491521501843_item	2512187	et	3	main
võib	doc_491521501843_item	2512188	et	3	main
hästi	doc_491521501843_item	2512189	et	3	main
kasutada	doc_491521501843_item	2512190	et	3	main
noorte	doc_491521501843_item	2512191	et	3	main
harimiseks	doc_491521501843_item	2512192	et	4	main
sest	doc_491521501843_item	2512193	et	4	main
praegusel	doc_491521501843_item	2512194	et	3	main
hetkel	doc_491521501843_item	2512195	et	4	main
ning	doc_491521501843_item	2512197	et	3	main
mõnel	doc_491521501843_item	2512198	et	3	main
põhikoolis	doc_491521501843_item	2512196	et	4	main
juhul	doc_491521501843_item	2512199	et	3	main
ka	doc_491521501843_item	2512200	et	3	main
gümnaasiumis	doc_491521501843_item	2512201	et	3	main
õppijail	doc_491521501843_item	2512202	et	4	main
pole	doc_491521501843_item	2512203	et	3	main
tegelikult	doc_491521501843_item	2512204	et	4	main
õrna	doc_491521501843_item	2512205	et	4	main
aimugi	doc_491521501843_item	2512206	et	4	main
sellest	doc_491521501843_item	2512207	et	4	main
kui	doc_491521501843_item	2512208	et	3	main
raske	doc_491521501843_item	2512209	et	4	main
oli	doc_491521501843_item	2512210	et	3	main
ajal	doc_491521501843_item	2512212	et	4	main
sõda	doc_491521501843_item	2512213	et	4	main
omal	doc_491521501843_item	2512211	et	3	main
ning	doc_491521501843_item	2512214	et	3	main
nad	doc_491521501843_item	2512215	et	3	main
ei	doc_491521501843_item	2512216	et	4	main
oska	doc_491521501843_item	2512217	et	4	main
aimata	doc_491521501843_item	2512218	et	4	main
hinda	doc_491521501843_item	2512221	et	4	main
aastail	doc_491521501843_item	2512224	et	4	main
1940-1992	doc_491521501843_item	2512225	et	2	main
mis	doc_491521501843_item	2512234	et	4	main
on	doc_491521501843_item	2512236	et	4	main
alluda	doc_491521501843_item	2512237	et	3	main
võõrale	doc_491521501843_item	2512238	et	4	main
ning	doc_491521501843_item	2512246	et	3	main
ka	doc_491521501843_item	2512251	et	3	main
ning	doc_491521501843_item	2512254	et	3	main
vabadust	doc_491521501843_item	2512256	et	4	main
otsuseid	doc_491521501843_item	2512265	et	3	main
85	doc_491521501843_item	2512267	et	2	main
aastat	doc_491521501843_item	2512268	et	3	main
meile	doc_491521501844_item	2512279	et	4	main
jaoks	doc_491521501844_item	2512283	et	4	main
on	doc_491521501844_item	2512284	et	4	main
aasta	doc_491521501844_item	2512285	et	4	main
1919	doc_491521501844_item	2512286	et	2	main
jaanuaril	doc_491521501844_item	2512321	et	3	main
ja	doc_491521501844_item	2512329	et	3	main
lähedal	doc_491521501844_item	2512331	et	4	main
vanem	doc_491521501844_item	2512343	et	4	main
koolis	doc_491521501844_item	2512350	et	4	main
kuid	doc_491521501844_item	2512352	et	4	main
okupandid	doc_491521501844_item	2512368	et	3	main
ning	doc_491521501844_item	2512370	et	3	main
asusid	doc_491521501844_item	2512372	et	4	main
bolševikud	doc_491521501844_item	2512374	et	2	main
arutasid	doc_491521501844_item	2512375	et	4	main
kaitsmise	doc_491521501844_item	2512382	et	4	main
koolipoistest	doc_491521501844_item	2512386	et	3	main
ka	doc_491521501844_item	2512391	et	3	main
on	doc_491521501844_item	2512394	et	4	main
all	doc_491521501844_item	2512400	et	3	main
kujutav	doc_491521501844_item	2512404	et	4	main
on	doc_491521501844_item	2512406	et	4	main
veenev	doc_491521501844_item	2512408	et	4	main
punaste	doc_491521501844_item	2512421	et	4	main
võttis	doc_491521501844_item	2512432	et	3	main
raskem	doc_491521501844_item	2512451	et	4	main
kaheksa	doc_491521501844_item	2512465	et	4	main
sõpra	doc_491521501844_item	2512466	et	4	main
üks	doc_491521501844_item	2512475	et	3	main
neist	doc_491521501844_item	2512476	et	4	main
kõikide	doc_491521501844_item	2512480	et	4	main
nimed	doc_491521501844_item	2512481	et	3	main
lõpuks	doc_491521501844_item	2512482	et	4	main
minna	doc_491521501844_item	2512487	et	3	main
kaitsma	doc_491521501844_item	2512488	et	3	main
eestit	doc_491521501844_item	2512489	et	3	main
poisid	doc_491521501844_item	2512496	et	4	main
nahal	doc_491521501843_item	2512232	et	3	main
näinud	doc_491521501843_item	2512242	et	4	main
ette	doc_491521501843_item	2512252	et	4	main
eesti	doc_491521501843_item	2512255	et	4	main
essee	doc_491521501844_item	2512270	et	4	main
kivikase	doc_491521501844_item	2512274	et	3	main
meelde	doc_491521501844_item	2512280	et	3	main
minu	doc_491521501844_item	2512282	et	3	main
olles	doc_491521501844_item	2512288	et	3	main
sündinud	doc_491521501844_item	2512289	et	4	main
ja	doc_491521501844_item	2512290	et	3	main
kasvanud	doc_491521501844_item	2512291	et	4	main
koolis	doc_491521501844_item	2512292	et	4	main
käinud	doc_491521501844_item	2512293	et	4	main
hoopis	doc_491521501844_item	2512294	et	3	main
teisel	doc_491521501844_item	2512295	et	4	main
ajaperioodil	doc_491521501844_item	2512296	et	3	main
kuna	doc_491521501844_item	2512297	et	3	main
käisin	doc_491521501844_item	2512298	et	3	main
vene	doc_491521501844_item	2512299	et	4	main
koolis	doc_491521501844_item	2512300	et	4	main
siis	doc_491521501844_item	2512301	et	3	main
vabadussõjast	doc_491521501844_item	2512302	et	3	main
teadsin	doc_491521501844_item	2512303	et	3	main
väga	doc_491521501844_item	2512304	et	3	main
vähe	doc_491521501844_item	2512305	et	3	main
romaani	doc_491521501844_item	2512306	et	4	main
autor	doc_491521501844_item	2512307	et	3	main
albert	doc_491521501844_item	2512308	et	4	main
kivika	doc_491521501844_item	2512309	et	4	main
kirjandusse	doc_491521501844_item	2512310	et	3	main
astumine	doc_491521501844_item	2512311	et	4	main
vabadussõja	doc_491521501844_item	2512312	et	3	main
ajal	doc_491521501844_item	2512313	et	4	main
kirjanik	doc_491521501844_item	2512314	et	3	main
ise	doc_491521501844_item	2512315	et	4	main
pärineb	doc_491521501844_item	2512316	et	3	main
põhja-viljandimaalt	doc_491521501844_item	2512317	et	3	main
ta	doc_491521501844_item	2512318	et	4	main
18	doc_491521501844_item	2512320	et	2	main
sündis	doc_491521501844_item	2512319	et	3	main
kujutada	doc_491521501843_item	2512253	et	3	main
ei	doc_491521501843_item	2512260	et	4	main
mis	doc_491521501843_item	2512266	et	4	main
tagasi	doc_491521501843_item	2512269	et	3	main
albert	doc_491521501844_item	2512273	et	4	main
järgi	doc_491521501844_item	2512275	et	4	main
vändatud	doc_491521501844_item	2512276	et	4	main
vabadussõda	doc_491521501844_item	2512281	et	4	main
1898a	doc_491521501844_item	2512322	et	4	main
suure-jaani	doc_491521501844_item	2512323	et	4	main
möödus	doc_491521501844_item	2512326	et	3	main
kirjaniku	doc_491521501844_item	2512336	et	3	main
leiba	doc_491521501844_item	2512339	et	4	main
teenijatüdrukuna	doc_491521501844_item	2512340	et	3	main
ja	doc_491521501844_item	2512341	et	3	main
kangruna	doc_491521501844_item	2512342	et	3	main
venemaale	doc_491521501844_item	2512362	et	4	main
kui	doc_491521501844_item	2512363	et	3	main
1918	doc_491521501844_item	2512364	et	2	main
aasta	doc_491521501844_item	2512365	et	4	main
lõpul	doc_491521501844_item	2512366	et	3	main
lahkusid	doc_491521501844_item	2512369	et	4	main
eesti	doc_491521501844_item	2512376	et	4	main
noorsoo	doc_491521501844_item	2512377	et	4	main
rahvusliku	doc_491521501844_item	2512378	et	3	main
võimalusi	doc_491521501844_item	2512383	et	3	main
henn	doc_491521501844_item	2512397	et	4	main
vabadussõda	doc_491521501844_item	2512403	et	4	main
võimu	doc_491521501844_item	2512422	et	4	main
alla	doc_491521501844_item	2512423	et	3	main
taganesid	doc_491521501844_item	2512424	et	4	main
kaitseliidu	doc_491521501844_item	2512425	et	3	main
viljandisse	doc_491521501844_item	2512429	et	4	main
pataljon	doc_491521501844_item	2512434	et	3	main
jõesuus	doc_491521501844_item	2512437	et	3	main
rannu	doc_491521501844_item	2512446	et	4	main
jaanuarikuul	doc_491521501844_item	2512457	et	4	main
sai	doc_491521501844_item	2512459	et	4	main
peategelane	doc_491521501844_item	2512462	et	3	main
henn	doc_491521501844_item	2512463	et	4	main
kes	doc_491521501844_item	2512468	et	4	main
mitte	doc_491521501844_item	2512474	et	3	main
kirjutas	doc_491521501844_item	2512477	et	3	main
otsustasid	doc_491521501844_item	2512483	et	4	main
punaste	doc_491521501844_item	2512490	et	4	main
täis	doc_491521501844_item	2512500	et	4	main
on	doc_491521501844_item	2512523	et	4	main
ja	doc_491521501844_item	2512528	et	3	main
armastuslugu	doc_491521501844_item	2512530	et	4	main
filmi	doc_491521501844_item	2512531	et	4	main
lõpus	doc_491521501844_item	2512532	et	4	main
kolm	doc_491521501844_item	2512536	et	3	main
nad	doc_491521501844_item	2512539	et	3	main
eesti	doc_491521501844_item	2512543	et	4	main
jaoks	doc_491521501844_item	2512548	et	4	main
ja	doc_491521501844_item	2512568	et	3	main
oma	doc_491521501844_item	2512571	et	4	main
henn	doc_491521501844_item	2512584	et	4	main
1948a	doc_491521501844_item	2512590	et	4	main
teine	doc_491521501844_item	2512591	et	3	main
osa	doc_491521501844_item	2512595	et	4	main
nüganen	doc_491521501844_item	2512610	et	4	main
oli	doc_491521501844_item	2512612	et	3	main
tema	doc_491521501844_item	2512614	et	4	main
oskus	doc_491521501844_item	2512615	et	3	main
teha	doc_491521501844_item	2512616	et	3	main
selline	doc_491521501844_item	2512617	et	4	main
tuhandetele	doc_491521501844_item	2512618	et	3	main
inimestele	doc_491521501844_item	2512619	et	3	main
mõisas	doc_491521501844_item	2512328	et	3	main
selle	doc_491521501844_item	2512330	et	4	main
asuvas	doc_491521501844_item	2512332	et	4	main
sännu	doc_491521501844_item	2512333	et	4	main
moonamajas	doc_491521501844_item	2512334	et	3	main
aitas	doc_491521501844_item	2512345	et	3	main
oma	doc_491521501844_item	2512348	et	4	main
ning	doc_491521501844_item	2512357	et	3	main
koos	doc_491521501844_item	2512358	et	4	main
saksa	doc_491521501844_item	2512367	et	4	main
eestit	doc_491521501844_item	2512371	et	3	main
vallutama	doc_491521501844_item	2512373	et	3	main
tartus	doc_491521501844_item	2512384	et	3	main
astus	doc_491521501844_item	2512390	et	3	main
endast	doc_491521501844_item	2512395	et	4	main
pajatanud	doc_491521501844_item	2512396	et	4	main
ja	doc_491521501844_item	2512409	et	3	main
stiililt	doc_491521501844_item	2512410	et	3	main
viimistletud	doc_491521501844_item	2512411	et	4	main
teos	doc_491521501844_item	2512412	et	4	main
ning	doc_491521501844_item	2512413	et	3	main
on	doc_491521501844_item	2512414	et	4	main
pälvinud	doc_491521501844_item	2512415	et	4	main
teenitult	doc_491521501844_item	2512416	et	4	main
kiidusõnu	doc_491521501844_item	2512417	et	3	main
kui	doc_491521501844_item	2512418	et	3	main
tartu	doc_491521501844_item	2512419	et	4	main
sattus	doc_491521501844_item	2512420	et	3	main
1919	doc_491521501844_item	2512431	et	2	main
ründama	doc_491521501844_item	2512439	et	3	main
suunas	doc_491521501844_item	2512441	et	4	main
sattusid	doc_491521501844_item	2512444	et	4	main
ja	doc_491521501844_item	2512448	et	3	main
kõige	doc_491521501844_item	2512450	et	4	main
külmal	doc_491521501844_item	2512456	et	3	main
ja	doc_491521501844_item	2512472	et	3	main
üles	doc_491521501844_item	2512479	et	3	main
koos	doc_491521501844_item	2512486	et	4	main
lahing	doc_491521501844_item	2512493	et	3	main
oli	doc_491521501844_item	2512494	et	3	main
olid	doc_491521501844_item	2512497	et	4	main
noored	doc_491521501844_item	2512498	et	3	main
ja	doc_491521501844_item	2512499	et	3	main
indu	doc_491521501844_item	2512501	et	4	main
reaalsuse	doc_491521501844_item	2512521	et	4	main
hennu	doc_491521501844_item	2512527	et	4	main
on	doc_491521501844_item	2512533	et	4	main
elus	doc_491521501844_item	2512534	et	4	main
endale	doc_491521501844_item	2512541	et	4	main
nende	doc_491521501844_item	2512547	et	4	main
vabadusvõitluse	doc_491521501844_item	2512558	et	3	main
ei	doc_491521501844_item	2512562	et	4	main
vennaga	doc_491521501844_item	2512572	et	3	main
ja	doc_491521501844_item	2512580	et	3	main
jääb	doc_491521501844_item	2512582	et	3	main
üksinda	doc_491521501844_item	2512583	et	4	main
veel	doc_491521501844_item	2512589	et	4	main
peanäitejuht	doc_491521501844_item	2512608	et	3	main
film	doc_491521501844_item	2512628	et	3	main
noortele	doc_491521501844_item	2512636	et	3	main
pani	doc_491521501844_item	2512639	et	4	main
mõtlema	doc_491521501844_item	2512642	et	3	main
oma	doc_491521501844_item	2512651	et	4	main
kodumaad	doc_491521501844_item	2512652	et	4	main
kui	doc_491521501844_item	2512653	et	3	main
tähtis	doc_491521501844_item	2512654	et	4	main
nimed	doc_491521501845_item	2512662	et	3	main
marmortahvlil	doc_491521501845_item	2512663	et	3	main
on	doc_491521501845_item	2512664	et	4	main
oli	doc_491521501845_item	2512671	et	3	main
jaanuaris	doc_491521501844_item	2512430	et	3	main
rasketesse	doc_491521501844_item	2512442	et	3	main
lahingutesse	doc_491521501844_item	2512443	et	4	main
noorukid	doc_491521501844_item	2512445	et	3	main
oli	doc_491521501844_item	2512452	et	3	main
lahing	doc_491521501844_item	2512454	et	3	main
kus	doc_491521501844_item	2512458	et	3	main
ka	doc_491521501844_item	2512460	et	3	main
haavata	doc_491521501844_item	2512461	et	4	main
arutasid	doc_491521501844_item	2512467	et	4	main
kes	doc_491521501844_item	2512473	et	4	main
tahvlile	doc_491521501844_item	2512478	et	3	main
poisid	doc_491521501844_item	2512484	et	4	main
kõik	doc_491521501844_item	2512485	et	4	main
vastu	doc_491521501844_item	2512491	et	3	main
raske	doc_491521501844_item	2512495	et	4	main
kuid	doc_491521501844_item	2512502	et	4	main
jäi	doc_491521501844_item	2512503	et	3	main
puudu	doc_491521501844_item	2512504	et	4	main
kogemustest	doc_491521501844_item	2512505	et	4	main
ja	doc_491521501844_item	2512506	et	3	main
julgusest	doc_491521501844_item	2512507	et	4	main
teistes	doc_491521501844_item	2512508	et	4	main
lahingutes	doc_491521501844_item	2512509	et	4	main
on	doc_491521501844_item	2512510	et	4	main
nad	doc_491521501844_item	2512511	et	3	main
juba	doc_491521501844_item	2512512	et	3	main
üle	doc_491521501844_item	2512513	et	3	main
saanud	doc_491521501844_item	2512514	et	4	main
oma	doc_491521501844_item	2512515	et	4	main
argusest	doc_491521501844_item	2512516	et	4	main
ja	doc_491521501844_item	2512517	et	3	main
võitlevad	doc_491521501844_item	2512518	et	4	main
vapralt	doc_491521501844_item	2512519	et	4	main
karmi	doc_491521501844_item	2512520	et	4	main
liigutav	doc_491521501844_item	2512525	et	4	main
marta	doc_491521501844_item	2512529	et	4	main
veel	doc_491521501844_item	2512535	et	4	main
kaheksast	doc_491521501844_item	2512538	et	4	main
rinda	doc_491521501844_item	2512542	et	4	main
märgid	doc_491521501844_item	2512546	et	4	main
ole	doc_491521501844_item	2512563	et	4	main
veel	doc_491521501844_item	2512564	et	4	main
kojusõit	doc_491521501844_item	2512567	et	3	main
saavad	doc_491521501844_item	2512576	et	4	main
ta	doc_491521501844_item	2512578	et	4	main
osa	doc_491521501844_item	2512592	et	4	main
ja	doc_491521501844_item	2512596	et	3	main
neljas	doc_491521501844_item	2512598	et	4	main
kõige	doc_491521501844_item	2512600	et	4	main
südamelähedasem	doc_491521501844_item	2512601	et	4	main
vapustav	doc_491521501844_item	2512613	et	4	main
on	doc_491521501844_item	2512622	et	4	main
enamat	doc_491521501844_item	2512624	et	3	main
kui	doc_491521501844_item	2512625	et	3	main
film	doc_491521501844_item	2512635	et	3	main
meist	doc_491521501844_item	2512641	et	3	main
on	doc_491521501844_item	2512645	et	4	main
meile	doc_491521501844_item	2512646	et	4	main
tähtis	doc_491521501844_item	2512647	et	4	main
lugu	doc_491521501845_item	2512669	et	4	main
tegevusajaks	doc_491521501845_item	2512670	et	3	main
tegelasteks	doc_491521501845_item	2512674	et	3	main
noorukid	doc_491521501845_item	2512677	et	3	main
noorte	doc_491521501844_item	2512526	et	3	main
sõpra	doc_491521501844_item	2512537	et	4	main
saavad	doc_491521501844_item	2512540	et	4	main
on	doc_491521501844_item	2512549	et	4	main
see	doc_491521501844_item	2512550	et	3	main
ülev	doc_491521501844_item	2512551	et	3	main
hetk	doc_491521501844_item	2512552	et	3	main
neile	doc_491521501844_item	2512553	et	4	main
on	doc_491521501844_item	2512554	et	4	main
tasutud	doc_491521501844_item	2512555	et	4	main
kodumaarmastuse	doc_491521501844_item	2512556	et	4	main
ja	doc_491521501844_item	2512557	et	3	main
eest	doc_491521501844_item	2512559	et	4	main
kuid	doc_491521501844_item	2512560	et	4	main
sõda	doc_491521501844_item	2512561	et	4	main
algab	doc_491521501844_item	2512566	et	3	main
kohtub	doc_491521501844_item	2512570	et	3	main
surma	doc_491521501844_item	2512577	et	4	main
sõbrad	doc_491521501844_item	2512579	et	3	main
ellu	doc_491521501844_item	2512581	et	4	main
järgnesid	doc_491521501844_item	2512588	et	4	main
kolmas	doc_491521501844_item	2512594	et	3	main
osa	doc_491521501844_item	2512599	et	4	main
ja	doc_491521501844_item	2512602	et	3	main
köitvam	doc_491521501844_item	2512603	et	4	main
oli	doc_491521501844_item	2512604	et	3	main
esimene	doc_491521501844_item	2512605	et	3	main
raamat	doc_491521501844_item	2512606	et	3	main
linnateatri	doc_491521501844_item	2512607	et	3	main
lavastajana	doc_491521501844_item	2512611	et	4	main
see	doc_491521501844_item	2512632	et	3	main
eelkõige	doc_491521501844_item	2512634	et	3	main
see	doc_491521501844_item	2512638	et	3	main
mis	doc_491521501844_item	2512644	et	4	main
miks	doc_491521501844_item	2512648	et	4	main
on	doc_491521501844_item	2512655	et	4	main
albert	doc_491521501845_item	2512665	et	4	main
kivikase	doc_491521501845_item	2512666	et	3	main
romaanil	doc_491521501845_item	2512667	et	3	main
vabadussõda	doc_491521501845_item	2512672	et	4	main
hoolimata	doc_491521501845_item	2512683	et	4	main
looma	doc_491521501845_item	2512688	et	4	main
teisel	doc_491521501845_item	2512699	et	4	main
aga	doc_491521501845_item	2512700	et	3	main
suutsin	doc_491521501845_item	2512701	et	3	main
kriitilisem	doc_491521501845_item	2512704	et	4	main
klassiruumi	doc_491521501845_item	2512726	et	4	main
kaotust	doc_491521501845_item	2512728	et	4	main
samas	doc_491521501845_item	2512735	et	4	main
läinud	doc_491521501845_item	2512737	et	4	main
tahvlil	doc_491521501845_item	2512740	et	3	main
asi	doc_491521501845_item	2512752	et	4	main
muusika	doc_491521501845_item	2512764	et	4	main
marmortahvlil	doc_491521501845_item	2512772	et	3	main
igati	doc_491521501845_item	2512778	et	3	main
tegi	doc_491521501845_item	2512781	et	4	main
terviklikuks	doc_491521501845_item	2512784	et	3	main
selleta	doc_491521501845_item	2512785	et	3	main
jäänud	doc_491521501845_item	2512789	et	4	main
võib-olla	doc_491521501845_item	2512791	et	3	main
nii	doc_491521501845_item	2512823	et	3	main
tümitama	doc_491521501845_item	2512829	et	3	main
filmi	doc_491521501845_item	2512840	et	4	main
pikkust	doc_491521501845_item	2512841	et	4	main
kiiresti	doc_491521501845_item	2512845	et	3	main
iva	doc_491521501845_item	2512847	et	4	main
lahtiseletamatuks	doc_491521501845_item	2512850	et	3	main
näha	doc_491521501845_item	2512852	et	3	main
sellist	doc_491521501845_item	2512870	et	4	main
väga	doc_491521501845_item	2512872	et	3	main
et	doc_491521501845_item	2512877	et	3	main
ei	doc_491521501845_item	2512879	et	4	main
tegu	doc_491521501845_item	2512882	et	4	main
koju	doc_491521501845_item	2512889	et	3	main
ja	doc_491521501845_item	2512895	et	3	main
rongi	doc_491521501845_item	2512897	et	4	main
katusel	doc_491521501845_item	2512898	et	3	main
julges	doc_491521501845_item	2512904	et	4	main
selliseid	doc_491521501845_item	2512911	et	4	main
möödalaskmisi	doc_491521501845_item	2512912	et	3	main
oli	doc_491521501845_item	2512913	et	3	main
veelgi	doc_491521501845_item	2512914	et	4	main
vähe	doc_491521501845_item	2512921	et	3	main
süžee	doc_491521501845_item	2512926	et	2	main
vähe	doc_491521501845_item	2512936	et	3	main
praegu	doc_491521501845_item	2512938	et	3	main
vaba	doc_491521501845_item	2512940	et	4	main
maadriiki	doc_491521501845_item	2512941	et	4	main
hindame	doc_491521501845_item	2512942	et	3	main
arvan	doc_491521501845_item	2512943	et	3	main
albert	doc_491521501846_item	2512961	et	4	main
leian	doc_491521501844_item	2512630	et	3	main
et	doc_491521501844_item	2512631	et	3	main
on	doc_491521501844_item	2512633	et	4	main
sest	doc_491521501844_item	2512637	et	4	main
paljusid	doc_491521501844_item	2512640	et	3	main
analüüsima	doc_491521501844_item	2512643	et	3	main
essee	doc_491521501845_item	2512658	et	4	main
nimed	doc_491521501845_item	2512659	et	3	main
marmortahvlil	doc_491521501845_item	2512660	et	3	main
essee	doc_491521501845_item	2512661	et	4	main
rindele	doc_491521501845_item	2512684	et	3	main
lähevad	doc_491521501845_item	2512685	et	3	main
käisin	doc_491521501845_item	2512689	et	3	main
korda	doc_491521501845_item	2512693	et	4	main
korral	doc_491521501845_item	2512695	et	4	main
olin	doc_491521501845_item	2512696	et	3	main
sellest	doc_491521501845_item	2512697	et	4	main
lõpp	doc_491521501845_item	2512711	et	3	main
eelnenu	doc_491521501845_item	2512715	et	4	main
raamidesse	doc_491521501845_item	2512716	et	3	main
nimed	doc_491521501845_item	2512717	et	3	main
marmortahvlil	doc_491521501845_item	2512718	et	3	main
oli	doc_491521501845_item	2512719	et	3	main
see	doc_491521501845_item	2512720	et	3	main
poisi	doc_491521501845_item	2512723	et	3	main
tühja	doc_491521501845_item	2512725	et	4	main
kaasnes	doc_491521501845_item	2512734	et	3	main
rindele	doc_491521501845_item	2512736	et	3	main
meenutasid	doc_491521501845_item	2512741	et	4	main
ja	doc_491521501845_item	2512743	et	3	main
mis	doc_491521501845_item	2512753	et	4	main
filmis	doc_491521501845_item	2512756	et	4	main
meeldis	doc_491521501845_item	2512758	et	3	main
muusika	doc_491521501845_item	2512760	et	4	main
nimed	doc_491521501845_item	2512771	et	3	main
oli	doc_491521501845_item	2512774	et	3	main
köitev	doc_491521501845_item	2512776	et	4	main
heli	doc_491521501845_item	2512780	et	4	main
pildi	doc_491521501845_item	2512783	et	4	main
oleks	doc_491521501845_item	2512786	et	3	main
isegi	doc_491521501845_item	2512792	et	4	main
film	doc_491521501844_item	2512621	et	3	main
midagi	doc_491521501844_item	2512623	et	4	main
lihtsalt	doc_491521501844_item	2512626	et	4	main
üks	doc_491521501844_item	2512627	et	3	main
mina	doc_491521501844_item	2512629	et	4	main
me	doc_491521501844_item	2512649	et	4	main
armastame	doc_491521501844_item	2512650	et	3	main
inimestele	doc_491521501844_item	2512656	et	3	main
vabadus	doc_491521501844_item	2512657	et	4	main
põhinev	doc_491521501845_item	2512668	et	4	main
ja	doc_491521501845_item	2512673	et	3	main
tartu	doc_491521501845_item	2512675	et	4	main
eesti	doc_491521501845_item	2512686	et	4	main
vaatamas	doc_491521501845_item	2512691	et	3	main
vaimustuses	doc_491521501845_item	2512698	et	4	main
et	doc_491521501845_item	2512708	et	3	main
filmil	doc_491521501845_item	2512709	et	3	main
paneks	doc_491521501845_item	2512713	et	4	main
sisenemine	doc_491521501845_item	2512724	et	4	main
valu	doc_491521501845_item	2512730	et	4	main
lõpuga	doc_491521501845_item	2512733	et	3	main
noormeeste	doc_491521501845_item	2512738	et	4	main
lootust	doc_491521501845_item	2512742	et	4	main
indu	doc_491521501845_item	2512744	et	4	main
mis	doc_491521501845_item	2512745	et	4	main
poistel	doc_491521501845_item	2512746	et	3	main
oli	doc_491521501845_item	2512747	et	3	main
selles	doc_491521501845_item	2512755	et	4	main
väga	doc_491521501845_item	2512757	et	3	main
oli	doc_491521501845_item	2512759	et	3	main
tavaliselt	doc_491521501845_item	2512761	et	4	main
eesti	doc_491521501845_item	2512762	et	4	main
filmide	doc_491521501845_item	2512763	et	3	main
pakkuv	doc_491521501845_item	2512770	et	4	main
taustamuusika	doc_491521501845_item	2512775	et	4	main
vaatepilt	doc_491521501845_item	2512788	et	3	main
poolikuks	doc_491521501845_item	2512790	et	3	main
innukalt	doc_491521501845_item	2512824	et	4	main
vastast	doc_491521501845_item	2512828	et	4	main
joostaks	doc_491521501845_item	2512830	et	3	main
ning	doc_491521501845_item	2512846	et	3	main
sõda	doc_491521501845_item	2512868	et	4	main
kui	doc_491521501845_item	2512869	et	3	main
mulje	doc_491521501845_item	2512876	et	4	main
näiteks	doc_491521501845_item	2512887	et	4	main
keegi	doc_491521501845_item	2512901	et	4	main
seda	doc_491521501845_item	2512902	et	3	main
teha	doc_491521501845_item	2512903	et	3	main
lõppe	doc_491521501845_item	2512907	et	4	main
öö	doc_491521501845_item	2512910	et	4	main
mõtlema	doc_491521501845_item	2512932	et	3	main
kui	doc_491521501845_item	2512935	et	3	main
aastakümneid	doc_491521501845_item	2512959	et	4	main
marmortahvlil	doc_491521501846_item	2512964	et	3	main
essee	doc_491521501846_item	2512965	et	4	main
olen	doc_491521501846_item	2512966	et	3	main
et	doc_491521501846_item	2512968	et	3	main
tänapäeva	doc_491521501846_item	2512969	et	4	main
puudutab	doc_491521501846_item	2512976	et	3	main
noorte	doc_491521501846_item	2512983	et	3	main
hulka	doc_491521501846_item	2512984	et	4	main
mälu	doc_491521501846_item	2512993	et	4	main
mingisuguste	doc_491521501846_item	2512995	et	3	main
paremat	doc_491521501846_item	2513022	et	4	main
on	doc_491521501846_item	2513032	et	4	main
öelnud	doc_491521501846_item	2513033	et	4	main
et	doc_491521501846_item	2513034	et	3	main
inimene	doc_491521501846_item	2513035	et	3	main
kes	doc_491521501846_item	2513036	et	4	main
elab	doc_491521501846_item	2513040	et	3	main
võidetud	doc_491521501846_item	2513053	et	4	main
ning	doc_491521501846_item	2513054	et	3	main
millist	doc_491521501846_item	2513055	et	3	main
mäletan	doc_491521501846_item	2513080	et	3	main
see	doc_491521501846_item	2513083	et	3	main
poolt	doc_491521501846_item	2513093	et	4	main
tänada	doc_491521501846_item	2513095	et	3	main
selle	doc_491521501846_item	2513100	et	4	main
teha	doc_491521501846_item	2513104	et	3	main
tunnistada	doc_491521501846_item	2513106	et	3	main
iialgi	doc_491521501846_item	2513111	et	4	main
sellest	doc_491521501846_item	2513112	et	4	main
koolipoisid	doc_491521501845_item	2512676	et	4	main
kes	doc_491521501845_item	2512678	et	4	main
oma	doc_491521501845_item	2512679	et	4	main
klassivahedest	doc_491521501845_item	2512680	et	3	main
ja	doc_491521501845_item	2512681	et	3	main
kõhklustest	doc_491521501845_item	2512682	et	3	main
filmi	doc_491521501845_item	2512690	et	4	main
olla	doc_491521501845_item	2512702	et	3	main
oleks	doc_491521501845_item	2512710	et	3	main
olemas	doc_491521501845_item	2512721	et	4	main
mis	doc_491521501845_item	2512731	et	4	main
nimed	doc_491521501845_item	2512739	et	3	main
enne	doc_491521501845_item	2512748	et	4	main
sõtta	doc_491521501845_item	2512749	et	3	main
minekut	doc_491521501845_item	2512750	et	3	main
teine	doc_491521501845_item	2512751	et	3	main
mulle	doc_491521501845_item	2512754	et	4	main
naudingut	doc_491521501845_item	2512769	et	3	main
puhul	doc_491521501845_item	2512773	et	4	main
kohana	doc_491521501845_item	2512779	et	4	main
kogu	doc_491521501845_item	2512787	et	4	main
ma	doc_491521501845_item	2512821	et	3	main
tõustaks	doc_491521501845_item	2512826	et	3	main
toimus	doc_491521501845_item	2512843	et	3	main
jäi	doc_491521501845_item	2512848	et	3	main
soovinud	doc_491521501845_item	2512853	et	4	main
sõit	doc_491521501845_item	2512888	et	3	main
just	doc_491521501845_item	2512892	et	3	main
vaevalt	doc_491521501845_item	2512899	et	4	main
tegelikult	doc_491521501845_item	2512900	et	4	main
sõda	doc_491521501845_item	2512905	et	4	main
kunagi	doc_491521501845_item	2512908	et	3	main
üle	doc_491521501845_item	2512909	et	3	main
film	doc_491521501845_item	2512923	et	3	main
nautitav	doc_491521501845_item	2512925	et	4	main
läks	doc_491521501845_item	2512927	et	3	main
hoolega	doc_491521501845_item	2512931	et	3	main
üle	doc_491521501845_item	2512934	et	3	main
viimne	doc_491521501845_item	2512951	et	3	main
armastatakse	doc_491521501845_item	2512958	et	3	main
vähe	doc_491521501846_item	2512972	et	3	main
mina	doc_491521501846_item	2512979	et	4	main
vahel	doc_491521501846_item	2512986	et	4	main
ekslikult	doc_491521501846_item	2512987	et	4	main
asjatult	doc_491521501846_item	2512991	et	4	main
ajalooliste	doc_491521501846_item	2512996	et	4	main
riiki	doc_491521501845_item	2512687	et	4	main
kaks	doc_491521501845_item	2512692	et	3	main
esimesel	doc_491521501845_item	2512694	et	3	main
veidi	doc_491521501845_item	2512703	et	3	main
mulle	doc_491521501845_item	2512705	et	4	main
on	doc_491521501845_item	2512706	et	4	main
tähtis	doc_491521501845_item	2512707	et	4	main
mis	doc_491521501845_item	2512712	et	4	main
kogu	doc_491521501845_item	2512714	et	4	main
ja	doc_491521501845_item	2512729	et	3	main
väikse	doc_491521501845_item	2512722	et	4	main
sümboliseeris	doc_491521501845_item	2512727	et	4	main
sõja	doc_491521501845_item	2512732	et	3	main
on	doc_491521501845_item	2512765	et	4	main
pigem	doc_491521501845_item	2512766	et	3	main
häiriv	doc_491521501845_item	2512767	et	4	main
kui	doc_491521501845_item	2512768	et	3	main
ja	doc_491521501845_item	2512777	et	3	main
nähtud	doc_491521501845_item	2512782	et	4	main
arusaamatuks	doc_491521501845_item	2512793	et	4	main
eriti	doc_491521501845_item	2512794	et	3	main
hinge	doc_491521501845_item	2512795	et	4	main
läks	doc_491521501845_item	2512796	et	3	main
süžee	doc_491521501845_item	2512798	et	2	main
mõte	doc_491521501845_item	2512799	et	3	main
mulle	doc_491521501845_item	2512797	et	4	main
sellest	doc_491521501845_item	2512800	et	4	main
kuidas	doc_491521501845_item	2512801	et	3	main
poisikesed	doc_491521501845_item	2512802	et	4	main
sõtta	doc_491521501845_item	2512803	et	3	main
tormasid	doc_491521501845_item	2512804	et	4	main
et	doc_491521501845_item	2512805	et	3	main
eestit	doc_491521501845_item	2512806	et	3	main
vabaks	doc_491521501845_item	2512807	et	3	main
saada	doc_491521501845_item	2512808	et	4	main
tõi	doc_491521501845_item	2512809	et	3	main
mitmel	doc_491521501845_item	2512810	et	4	main
korral	doc_491521501845_item	2512811	et	4	main
pisarad	doc_491521501845_item	2512812	et	3	main
silma	doc_491521501845_item	2512813	et	4	main
kui	doc_491521501845_item	2512814	et	3	main
praegu	doc_491521501845_item	2512815	et	3	main
peaks	doc_491521501845_item	2512816	et	4	main
sõda	doc_491521501845_item	2512817	et	4	main
puhkema	doc_491521501845_item	2512818	et	4	main
ei	doc_491521501845_item	2512819	et	4	main
usu	doc_491521501845_item	2512820	et	4	main
et	doc_491521501845_item	2512822	et	3	main
kuid	doc_491521501845_item	2512831	et	4	main
või	doc_491521501845_item	2512834	et	4	main
iial	doc_491521501845_item	2512835	et	3	main
teada	doc_491521501845_item	2512836	et	3	main
negatiivseks	doc_491521501845_item	2512837	et	3	main
pean	doc_491521501845_item	2512838	et	4	main
ma	doc_491521501845_item	2512839	et	3	main
väga	doc_491521501845_item	2512844	et	3	main
pisut	doc_491521501845_item	2512849	et	3	main
oleks	doc_491521501845_item	2512851	et	3	main
rohkem	doc_491521501845_item	2512855	et	4	main
vähe	doc_491521501845_item	2512873	et	3	main
jäi	doc_491521501845_item	2512875	et	3	main
sõda	doc_491521501845_item	2512878	et	4	main
toimunudki	doc_491521501845_item	2512880	et	4	main
vaid	doc_491521501845_item	2512881	et	3	main
koolipingist	doc_491521501845_item	2512825	et	3	main
ja	doc_491521501845_item	2512827	et	3	main
samas	doc_491521501845_item	2512832	et	4	main
ei	doc_491521501845_item	2512833	et	4	main
kõik	doc_491521501845_item	2512842	et	4	main
veidi	doc_491521501845_item	2512854	et	3	main
tegelaskujudele	doc_491521501845_item	2512857	et	3	main
ja	doc_491521501845_item	2512858	et	3	main
keskendumist	doc_491521501845_item	2512856	et	4	main
filmi	doc_491521501845_item	2512859	et	4	main
umbes	doc_491521501845_item	2512860	et	4	main
pool	doc_491521501845_item	2512861	et	4	main
tundi	doc_491521501845_item	2512862	et	4	main
pikemana	doc_491521501845_item	2512863	et	4	main
veel	doc_491521501845_item	2512864	et	4	main
oli	doc_491521501845_item	2512865	et	3	main
kummaline	doc_491521501845_item	2512866	et	3	main
et	doc_491521501845_item	2512867	et	3	main
näidati	doc_491521501845_item	2512871	et	3	main
kohati	doc_491521501845_item	2512874	et	4	main
noormehed	doc_491521501845_item	2512890	et	3	main
olid	doc_491521501845_item	2512891	et	4	main
lahingust	doc_491521501845_item	2512893	et	4	main
tulnud	doc_491521501845_item	2512894	et	4	main
istusid	doc_491521501845_item	2512896	et	4	main
õnneks	doc_491521501845_item	2512915	et	4	main
oli	doc_491521501845_item	2512916	et	3	main
negatiivset	doc_491521501845_item	2512917	et	3	main
ja	doc_491521501845_item	2512918	et	3	main
ebatäpsusi	doc_491521501845_item	2512919	et	4	main
väga	doc_491521501845_item	2512920	et	3	main
ning	doc_491521501845_item	2512922	et	3	main
tervikuna	doc_491521501845_item	2512924	et	3	main
hinge	doc_491521501845_item	2512928	et	4	main
pani	doc_491521501845_item	2512930	et	4	main
selle	doc_491521501845_item	2512933	et	4	main
essee	doc_491521501846_item	2512960	et	4	main
nimed	doc_491521501846_item	2512963	et	3	main
täheldanud	doc_491521501846_item	2512967	et	4	main
kirjandusest	doc_491521501846_item	2512973	et	4	main
milleks	doc_491521501846_item	2512990	et	4	main
astumist	doc_491521501846_item	2513021	et	4	main
tulevikku	doc_491521501846_item	2513023	et	4	main
ning	doc_491521501846_item	2513024	et	3	main
sõdade	doc_491521501846_item	2513025	et	3	main
eest	doc_491521501846_item	2513026	et	4	main
meie	doc_491521501846_item	2513044	et	4	main
teadma	doc_491521501846_item	2513045	et	3	main
hinda	doc_491521501846_item	2513056	et	4	main
noored	doc_491521501846_item	2513070	et	3	main
hulka	doc_491521501846_item	2513086	et	4	main
omalt	doc_491521501846_item	2513092	et	4	main
tahaksin	doc_491521501846_item	2513094	et	3	main
ainetel	doc_491521501846_item	2513102	et	3	main
kuid	doc_491521501846_item	2513107	et	4	main
ma	doc_491521501846_item	2513108	et	3	main
poleks	doc_491521501846_item	2513109	et	3	main
ehk	doc_491521501846_item	2513110	et	3	main
on	doc_491521501846_item	2513126	et	4	main
populaarsust	doc_491521501846_item	2513135	et	4	main
seda	doc_491521501846_item	2513139	et	3	main
ka	doc_491521501846_item	2513145	et	3	main
tänu	doc_491521501846_item	2513148	et	4	main
end	doc_491521501846_item	2513154	et	4	main
igaüks	doc_491521501846_item	2513159	et	3	main
asju	doc_491521501846_item	2513164	et	3	main
varem	doc_491521501846_item	2513167	et	4	main
tegelikult	doc_491521501846_item	2513173	et	4	main
kui	doc_491521501846_item	2513176	et	3	main
räägiti	doc_491521501846_item	2513179	et	3	main
film	doc_491521501846_item	2513184	et	3	main
head	doc_491521501846_item	2513188	et	4	main
seda	doc_491521501846_item	2513194	et	3	main
et	doc_491521501846_item	2513199	et	3	main
avastasin	doc_491521501846_item	2513203	et	3	main
nn	doc_491521501846_item	2513222	et	4	main
ridade	doc_491521501846_item	2513223	et	3	main
siiamaani	doc_491521501846_item	2513229	et	3	main
kes	doc_491521501846_item	2513240	et	4	main
poeg	doc_491521501846_item	2513252	et	3	main
see	doc_491521501846_item	2513255	et	3	main
teine	doc_491521501846_item	2513257	et	3	main
jääbki	doc_491521501846_item	2513258	et	3	main
minu	doc_491521501846_item	2513259	et	3	main
peale	doc_491521501846_item	2513262	et	4	main
nii	doc_491521501846_item	2513267	et	3	main
tõusta	doc_491521501846_item	2513270	et	4	main
ja	doc_491521501846_item	2513271	et	3	main
öelda	doc_491521501846_item	2513272	et	4	main
kellelegi	doc_491521501846_item	2513273	et	4	main
vot	doc_491521501846_item	2513274	et	3	main
eesti	doc_491521501846_item	2513278	et	4	main
poisid	doc_491521501846_item	2513279	et	4	main
oli	doc_491521501845_item	2512883	et	3	main
lihtsalt	doc_491521501845_item	2512884	et	4	main
hetkelise	doc_491521501845_item	2512885	et	4	main
kriisiseisuga	doc_491521501845_item	2512886	et	3	main
ei	doc_491521501845_item	2512906	et	4	main
ja	doc_491521501845_item	2512929	et	3	main
me	doc_491521501845_item	2512937	et	4	main
oma	doc_491521501845_item	2512939	et	4	main
et	doc_491521501845_item	2512944	et	3	main
nimed	doc_491521501845_item	2512945	et	3	main
marmortahvlil	doc_491521501845_item	2512946	et	3	main
saab	doc_491521501845_item	2512947	et	3	main
samasuguseks	doc_491521501845_item	2512948	et	4	main
rahvalemmikuks	doc_491521501845_item	2512949	et	4	main
nagu	doc_491521501845_item	2512950	et	3	main
reliikvia	doc_491521501845_item	2512952	et	4	main
ja	doc_491521501845_item	2512953	et	3	main
sedagi	doc_491521501845_item	2512954	et	3	main
tsiteeritakse	doc_491521501845_item	2512955	et	3	main
koosviibimistel	doc_491521501845_item	2512956	et	3	main
ning	doc_491521501845_item	2512957	et	3	main
noored	doc_491521501846_item	2512970	et	3	main
huvituvad	doc_491521501846_item	2512971	et	4	main
mis	doc_491521501846_item	2512975	et	4	main
ajaloolist	doc_491521501846_item	2512977	et	4	main
kes	doc_491521501846_item	2512985	et	4	main
koormata	doc_491521501846_item	2512994	et	4	main
faktidega	doc_491521501846_item	2512997	et	3	main
mis	doc_491521501846_item	2512998	et	4	main
pealegi	doc_491521501846_item	2512999	et	4	main
toimusid	doc_491521501846_item	2513000	et	4	main
mitusada	doc_491521501846_item	2513001	et	4	main
aastat	doc_491521501846_item	2513002	et	3	main
tagasi	doc_491521501846_item	2513003	et	3	main
samas	doc_491521501846_item	2513004	et	4	main
aga	doc_491521501846_item	2513005	et	3	main
leian	doc_491521501846_item	2513006	et	3	main
et	doc_491521501846_item	2513007	et	3	main
iga	doc_491521501846_item	2513008	et	4	main
inimene	doc_491521501846_item	2513009	et	3	main
peab	doc_491521501846_item	2513010	et	4	main
teadma	doc_491521501846_item	2513011	et	3	main
vähemalt	doc_491521501846_item	2513012	et	4	main
oma	doc_491521501846_item	2513013	et	4	main
kodumaa	doc_491521501846_item	2513014	et	4	main
ajalugu	doc_491521501846_item	2513015	et	4	main
kõik	doc_491521501846_item	2513016	et	4	main
me	doc_491521501846_item	2513017	et	4	main
ootame	doc_491521501846_item	2513018	et	3	main
euroopa	doc_491521501846_item	2513019	et	4	main
liitu	doc_491521501846_item	2513020	et	4	main
nii	doc_491521501846_item	2513029	et	3	main
ei	doc_491521501846_item	2513037	et	4	main
ei	doc_491521501846_item	2513081	et	4	main
kohustusliku	doc_491521501846_item	2513084	et	3	main
võiks	doc_491521501846_item	2513088	et	4	main
peaks	doc_491521501846_item	2513090	et	4	main
mina	doc_491521501846_item	2513091	et	4	main
kes	doc_491521501846_item	2513098	et	4	main
romaani	doc_491521501846_item	2513101	et	4	main
kivikas	doc_491521501846_item	2512962	et	4	main
eriti	doc_491521501846_item	2512974	et	3	main
kirjandust	doc_491521501846_item	2512978	et	3	main
kuulun	doc_491521501846_item	2512980	et	3	main
samuti	doc_491521501846_item	2512981	et	3	main
nende	doc_491521501846_item	2512982	et	4	main
arvavad	doc_491521501846_item	2512988	et	4	main
et	doc_491521501846_item	2512989	et	3	main
oma	doc_491521501846_item	2512992	et	4	main
kaitstud	doc_491521501846_item	2513027	et	4	main
nagu	doc_491521501846_item	2513030	et	3	main
tulevikuta	doc_491521501846_item	2513041	et	4	main
ka	doc_491521501846_item	2513043	et	3	main
on	doc_491521501846_item	2513047	et	4	main
see	doc_491521501846_item	2513048	et	3	main
kodumaa	doc_491521501846_item	2513049	et	4	main
millel	doc_491521501846_item	2513050	et	3	main
me	doc_491521501846_item	2513051	et	4	main
elame	doc_491521501846_item	2513052	et	3	main
õigesti	doc_491521501846_item	2513079	et	3	main
kirjanduse	doc_491521501846_item	2513085	et	3	main
kuigi	doc_491521501846_item	2513087	et	3	main
isegi	doc_491521501846_item	2513089	et	4	main
neid	doc_491521501846_item	2513096	et	4	main
inimesi	doc_491521501846_item	2513097	et	4	main
filmi	doc_491521501846_item	2513103	et	4	main
häbi	doc_491521501846_item	2513105	et	4	main
poleks	doc_491521501846_item	2513117	et	3	main
seda	doc_491521501846_item	2513118	et	3	main
veel	doc_491521501846_item	2513127	et	4	main
selliseid	doc_491521501846_item	2513129	et	4	main
nimed	doc_491521501846_item	2513130	et	3	main
marmortahvlil	doc_491521501846_item	2513131	et	3	main
kogus	doc_491521501846_item	2513132	et	4	main
väga	doc_491521501846_item	2513133	et	3	main
palju	doc_491521501846_item	2513134	et	4	main
läksid	doc_491521501846_item	2513138	et	4	main
kindlasti	doc_491521501846_item	2513140	et	3	main
pärast	doc_491521501846_item	2513143	et	4	main
on	doc_491521501846_item	2513150	et	4	main
sest	doc_491521501846_item	2513156	et	4	main
sellest	doc_491521501846_item	2513161	et	4	main
ta	doc_491521501846_item	2513166	et	4	main
pole	doc_491521501846_item	2513171	et	3	main
sel	doc_491521501846_item	2513174	et	3	main
sellest	doc_491521501846_item	2513177	et	4	main
ta	doc_491521501846_item	2513180	et	4	main
nimed	doc_491521501846_item	2513185	et	3	main
muljet	doc_491521501846_item	2513189	et	3	main
käisin	doc_491521501846_item	2513193	et	3	main
üllatav	doc_491521501846_item	2513198	et	4	main
natuke	doc_491521501846_item	2513221	et	4	main
lugema	doc_491521501846_item	2513225	et	4	main
piinab	doc_491521501846_item	2513227	et	3	main
tea	doc_491521501846_item	2513234	et	4	main
täpselt	doc_491521501846_item	2513235	et	4	main
lõpus	doc_491521501846_item	2513242	et	4	main
klassiuksest	doc_491521501846_item	2513243	et	4	main
hennu	doc_491521501846_item	2513249	et	4	main
või	doc_491521501846_item	2513253	et	4	main
keegi	doc_491521501846_item	2513256	et	4	main
ma	doc_491521501846_item	2513266	et	3	main
väga	doc_491521501846_item	2513268	et	3	main
sellised	doc_491521501846_item	2513275	et	4	main
tuli	doc_491521501846_item	2513283	et	4	main
sellele	doc_491521501846_item	2513319	et	4	main
iseseisvunud	doc_491521501846_item	2513328	et	4	main
inimesi	doc_491521501846_item	2513336	et	4	main
neile	doc_491521501846_item	2513339	et	4	main
loodan	doc_491521501846_item	2513349	et	3	main
suurele	doc_491521501846_item	2513353	et	4	main
eesti	doc_491521501846_item	2513358	et	4	main
sellega	doc_491521501846_item	2513370	et	3	main
tänapäeva	doc_491521501846_item	2513372	et	4	main
elutempo	doc_491521501846_item	2513374	et	4	main
inimestel	doc_491521501846_item	2513377	et	3	main
raamatuid	doc_491521501846_item	2513379	et	3	main
ajaloolised	doc_491521501846_item	2513385	et	4	main
korvavad	doc_491521501846_item	2513387	et	4	main
veidigi	doc_491521501846_item	2513389	et	3	main
teadmatuse	doc_491521501846_item	2513391	et	4	main
eestit	doc_491521501846_item	2513028	et	3	main
keegi	doc_491521501846_item	2513031	et	4	main
mäleta	doc_491521501846_item	2513038	et	4	main
minevikku	doc_491521501846_item	2513039	et	4	main
peame	doc_491521501846_item	2513042	et	4	main
kuidas	doc_491521501846_item	2513046	et	3	main
pidi	doc_491521501846_item	2513057	et	4	main
keegi	doc_491521501846_item	2513058	et	4	main
kunagi	doc_491521501846_item	2513059	et	3	main
selle	doc_491521501846_item	2513060	et	4	main
eest	doc_491521501846_item	2513061	et	4	main
maksma	doc_491521501846_item	2513062	et	3	main
usun	doc_491521501846_item	2513063	et	3	main
et	doc_491521501846_item	2513064	et	3	main
paar	doc_491521501846_item	2513065	et	3	main
kuud	doc_491521501846_item	2513066	et	4	main
tagasi	doc_491521501846_item	2513067	et	3	main
teadsid	doc_491521501846_item	2513068	et	4	main
vähesed	doc_491521501846_item	2513069	et	3	main
midagi	doc_491521501846_item	2513071	et	4	main
albert	doc_491521501846_item	2513072	et	4	main
kivikase	doc_491521501846_item	2513073	et	3	main
romaanist	doc_491521501846_item	2513074	et	3	main
nimed	doc_491521501846_item	2513075	et	3	main
marmortahvlil	doc_491521501846_item	2513076	et	3	main
kui	doc_491521501846_item	2513077	et	3	main
ma	doc_491521501846_item	2513078	et	3	main
kuulu	doc_491521501846_item	2513082	et	4	main
otsustasid	doc_491521501846_item	2513099	et	4	main
midagi	doc_491521501846_item	2513114	et	4	main
teadnud	doc_491521501846_item	2513115	et	4	main
kui	doc_491521501846_item	2513116	et	3	main
filmi	doc_491521501846_item	2513119	et	4	main
läinud	doc_491521501846_item	2513121	et	4	main
et	doc_491521501846_item	2513123	et	3	main
minu	doc_491521501846_item	2513125	et	3	main
teisigi	doc_491521501846_item	2513128	et	4	main
ning	doc_491521501846_item	2513136	et	3	main
suure	doc_491521501846_item	2513141	et	3	main
vaatama	doc_491521501846_item	2513144	et	3	main
kindlasti	doc_491521501846_item	2513147	et	3	main
mõte	doc_491521501846_item	2513153	et	3	main
arvan	doc_491521501846_item	2513157	et	3	main
filmist	doc_491521501846_item	2513162	et	4	main
kuulnudki	doc_491521501846_item	2513170	et	4	main
ajal	doc_491521501846_item	2513175	et	4	main
minule	doc_491521501846_item	2513182	et	3	main
lausa	doc_491521501846_item	2513190	et	4	main
kaks	doc_491521501846_item	2513195	et	3	main
teisel	doc_491521501846_item	2513201	et	4	main
asjaolu	doc_491521501846_item	2513230	et	4	main
ma	doc_491521501846_item	2513232	et	3	main
sisse	doc_491521501846_item	2513244	et	4	main
see	doc_491521501846_item	2513247	et	3	main
mõistmatuks	doc_491521501846_item	2513261	et	4	main
tahtsin	doc_491521501846_item	2513265	et	3	main
olid	doc_491521501846_item	2513276	et	4	main
tunne	doc_491521501846_item	2513282	et	4	main
maksid	doc_491521501846_item	2513322	et	4	main
kunagi	doc_491521501846_item	2513323	et	3	main
me	doc_491521501846_item	2513326	et	4	main
oma	doc_491521501846_item	2513342	et	4	main
ka	doc_491521501846_item	2513346	et	3	main
samuti	doc_491521501846_item	2513348	et	3	main
et	doc_491521501846_item	2513350	et	3	main
tänu	doc_491521501846_item	2513351	et	4	main
otsustavad	doc_491521501846_item	2513357	et	4	main
rezissöörid	doc_491521501846_item	2513359	et	4	main
kodumaa	doc_491521501846_item	2513365	et	4	main
arvestada	doc_491521501846_item	2513369	et	3	main
juures	doc_491521501846_item	2513375	et	4	main
oma	doc_491521501846_item	2513392	et	4	main
essee	doc_491521501847_item	2513395	et	4	main
käinud	doc_491521501847_item	2513399	et	4	main
romaanil	doc_491521501847_item	2513408	et	3	main
kohal	doc_491521501847_item	2513425	et	4	main
tema	doc_491521501847_item	2513428	et	4	main
on	doc_491521501847_item	2513430	et	4	main
nimed	doc_491521501847_item	2513431	et	3	main
marmortahvlil	doc_491521501847_item	2513432	et	3	main
mis	doc_491521501847_item	2513433	et	4	main
pataljoni	doc_491521501847_item	2513438	et	4	main
hennu	doc_491521501847_item	2513457	et	4	main
näitab	doc_491521501847_item	2513461	et	3	main
sõda	doc_491521501847_item	2513464	et	4	main
muserdab	doc_491521501847_item	2513466	et	3	main
koos	doc_491521501847_item	2513518	et	4	main
jooksul	doc_491521501847_item	2513522	et	4	main
mina	doc_491521501847_item	2513523	et	4	main
arvan	doc_491521501847_item	2513524	et	3	main
edukas	doc_491521501847_item	2513529	et	4	main
toimuva	doc_491521501847_item	2513540	et	4	main
filmilindile	doc_491521501847_item	2513542	et	3	main
operaator	doc_491521501847_item	2513544	et	3	main
2	doc_491521501847_item	2513550	et	2	main
ahas	doc_491521501847_item	2513554	et	4	main
konsap	doc_491521501847_item	2513557	et	4	main
aardam	doc_491521501847_item	2513559	et	4	main
käsper	doc_491521501847_item	2513566	et	4	main
tääker	doc_491521501847_item	2513569	et	4	main
sepp	doc_491521501847_item	2513571	et	3	main
vabadussõjast	doc_491521501846_item	2513113	et	3	main
vaatama	doc_491521501846_item	2513120	et	3	main
usun	doc_491521501846_item	2513122	et	3	main
paljud	doc_491521501846_item	2513137	et	3	main
meediakära	doc_491521501846_item	2513142	et	4	main
mina	doc_491521501846_item	2513146	et	4	main
filmi	doc_491521501846_item	2513151	et	4	main
ammutanud	doc_491521501846_item	2513155	et	4	main
et	doc_491521501846_item	2513158	et	3	main
mida	doc_491521501846_item	2513165	et	4	main
enda	doc_491521501846_item	2513168	et	4	main
koolitunnis	doc_491521501846_item	2513178	et	3	main
magas	doc_491521501846_item	2513181	et	4	main
marmortahvlil	doc_491521501846_item	2513186	et	3	main
et	doc_491521501846_item	2513192	et	3	main
vaatamas	doc_491521501846_item	2513197	et	3	main
korral	doc_491521501846_item	2513202	et	4	main
enda	doc_491521501846_item	2513204	et	4	main
peale	doc_491521501846_item	2513124	et	4	main
sellele	doc_491521501846_item	2513149	et	4	main
tegemise	doc_491521501846_item	2513152	et	4	main
sai	doc_491521501846_item	2513160	et	4	main
teada	doc_491521501846_item	2513163	et	3	main
arvates	doc_491521501846_item	2513169	et	4	main
kuid	doc_491521501846_item	2513172	et	4	main
avaldas	doc_491521501846_item	2513183	et	3	main
väga	doc_491521501846_item	2513187	et	3	main
nii	doc_491521501846_item	2513191	et	3	main
korda	doc_491521501846_item	2513196	et	4	main
isegi	doc_491521501846_item	2513200	et	4	main
jaoks	doc_491521501846_item	2513205	et	4	main
asju	doc_491521501846_item	2513206	et	3	main
mis	doc_491521501846_item	2513207	et	4	main
esmakordsel	doc_491521501846_item	2513208	et	3	main
vaatamisel	doc_491521501846_item	2513209	et	4	main
kahe	doc_491521501846_item	2513210	et	3	main
silma	doc_491521501846_item	2513211	et	4	main
vahele	doc_491521501846_item	2513212	et	4	main
jäid	doc_491521501846_item	2513213	et	4	main
mulle	doc_491521501846_item	2513214	et	4	main
meeldis	doc_491521501846_item	2513215	et	3	main
et	doc_491521501846_item	2513216	et	3	main
selles	doc_491521501846_item	2513217	et	4	main
filmis	doc_491521501846_item	2513218	et	4	main
pidi	doc_491521501846_item	2513219	et	4	main
ka	doc_491521501846_item	2513220	et	3	main
näiteks	doc_491521501846_item	2513226	et	4	main
mind	doc_491521501846_item	2513228	et	4	main
et	doc_491521501846_item	2513231	et	3	main
ei	doc_491521501846_item	2513233	et	4	main
filmi	doc_491521501846_item	2513241	et	4	main
astus	doc_491521501846_item	2513245	et	3	main
marta	doc_491521501846_item	2513251	et	4	main
oli	doc_491521501846_item	2513254	et	3	main
jaoks	doc_491521501846_item	2513260	et	4	main
filmi	doc_491521501846_item	2513263	et	4	main
püsti	doc_491521501846_item	2513269	et	3	main
meie	doc_491521501846_item	2513277	et	4	main
nemad	doc_491521501846_item	2513321	et	3	main
verehinda	doc_491521501846_item	2513324	et	4	main
arvan	doc_491521501846_item	2513331	et	3	main
et	doc_491521501846_item	2513332	et	3	main
mälestama	doc_491521501846_item	2513334	et	3	main
kuna	doc_491521501846_item	2513337	et	3	main
vabaduse	doc_491521501846_item	2513343	et	4	main
olemasolu	doc_491521501846_item	2513347	et	4	main
veel	doc_491521501846_item	2513360	et	4	main
filme	doc_491521501846_item	2513363	et	3	main
ajaloost	doc_491521501846_item	2513366	et	4	main
kiire	doc_491521501846_item	2513373	et	4	main
aega	doc_491521501846_item	2513378	et	4	main
lugeda	doc_491521501846_item	2513380	et	3	main
võiks	doc_491521501846_item	2513382	et	4	main
loota	doc_491521501846_item	2513383	et	4	main
et	doc_491521501846_item	2513384	et	3	main
olen	doc_491521501847_item	2513398	et	3	main
marmortahvlil	doc_491521501847_item	2513403	et	3	main
mis	doc_491521501847_item	2513404	et	4	main
albert	doc_491521501847_item	2513406	et	4	main
loomingus	doc_491521501847_item	2513422	et	3	main
vabatahtlike	doc_491521501847_item	2513437	et	3	main
lahinguteed	doc_491521501847_item	2513439	et	4	main
tartu	doc_491521501847_item	2513448	et	4	main
keskkooliõpilastest	doc_491521501847_item	2513449	et	4	main
kes	doc_491521501847_item	2513452	et	4	main
vahelt	doc_491521501846_item	2513224	et	4	main
kes	doc_491521501846_item	2513236	et	4	main
oli	doc_491521501846_item	2513237	et	3	main
see	doc_491521501846_item	2513238	et	3	main
poiss	doc_491521501846_item	2513239	et	3	main
kas	doc_491521501846_item	2513246	et	3	main
oli	doc_491521501846_item	2513248	et	3	main
ja	doc_491521501846_item	2513250	et	3	main
lõppu	doc_491521501846_item	2513264	et	4	main
nii	doc_491521501846_item	2513280	et	3	main
uhke	doc_491521501846_item	2513281	et	4	main
kohe	doc_491521501846_item	2513284	et	4	main
peale	doc_491521501846_item	2513285	et	4	main
kui	doc_491521501846_item	2513286	et	3	main
mõni	doc_491521501846_item	2513287	et	3	main
mitteeestlane	doc_491521501846_item	2513288	et	3	main
seda	doc_491521501846_item	2513289	et	3	main
filmi	doc_491521501846_item	2513290	et	4	main
vaatab	doc_491521501846_item	2513291	et	3	main
peaks	doc_491521501846_item	2513292	et	4	main
tal	doc_491521501846_item	2513293	et	3	main
kadedustunne	doc_491521501846_item	2513294	et	4	main
peale	doc_491521501846_item	2513295	et	4	main
tulema	doc_491521501846_item	2513296	et	4	main
vähemalt	doc_491521501846_item	2513297	et	4	main
nii	doc_491521501846_item	2513298	et	3	main
loodan	doc_491521501846_item	2513300	et	3	main
vabadussõda	doc_491521501846_item	2513301	et	4	main
ma	doc_491521501846_item	2513299	et	3	main
algas	doc_491521501846_item	2513302	et	3	main
28	doc_491521501846_item	2513303	et	2	main
novembril	doc_491521501846_item	2513304	et	3	main
1918	doc_491521501846_item	2513305	et	2	main
aastal	doc_491521501846_item	2513306	et	3	main
punaarmee	doc_491521501846_item	2513307	et	4	main
pealetungiga	doc_491521501846_item	2513308	et	4	main
eestile	doc_491521501846_item	2513309	et	3	main
vabatahtlikult	doc_491521501846_item	2513310	et	4	main
läksid	doc_491521501846_item	2513311	et	4	main
oma	doc_491521501846_item	2513312	et	4	main
eest	doc_491521501846_item	2513314	et	4	main
sõdima	doc_491521501846_item	2513315	et	3	main
vaprad	doc_491521501846_item	2513316	et	3	main
kodumaa	doc_491521501846_item	2513313	et	4	main
koolipoisid	doc_491521501846_item	2513317	et	4	main
et	doc_491521501846_item	2513320	et	3	main
tänu	doc_491521501846_item	2513318	et	4	main
eesti	doc_491521501846_item	2513329	et	4	main
peaksime	doc_491521501846_item	2513333	et	4	main
neid	doc_491521501846_item	2513335	et	4	main
just	doc_491521501846_item	2513338	et	3	main
oleme	doc_491521501846_item	2513340	et	3	main
võlgu	doc_491521501846_item	2513341	et	4	main
ja	doc_491521501846_item	2513344	et	3	main
populaarsusele	doc_491521501846_item	2513356	et	4	main
taolisi	doc_491521501846_item	2513362	et	3	main
meie	doc_491521501846_item	2513364	et	4	main
pole	doc_491521501846_item	2513376	et	3	main
kuid	doc_491521501846_item	2513381	et	4	main
filmidki	doc_491521501846_item	2513386	et	4	main
kasvõi	doc_491521501846_item	2513388	et	3	main
eluloost	doc_491521501846_item	2513394	et	4	main
nimed	doc_491521501847_item	2513396	et	3	main
filmi	doc_491521501847_item	2513401	et	4	main
on	doc_491521501847_item	2513405	et	4	main
elame	doc_491521501846_item	2513325	et	3	main
praegu	doc_491521501846_item	2513327	et	3	main
vabariigis	doc_491521501846_item	2513330	et	3	main
võib-olla	doc_491521501846_item	2513345	et	3	main
nii	doc_491521501846_item	2513352	et	3	main
nimed	doc_491521501846_item	2513354	et	3	main
marmortahvlil	doc_491521501846_item	2513355	et	3	main
teisigi	doc_491521501846_item	2513361	et	4	main
luua	doc_491521501846_item	2513367	et	4	main
tuleb	doc_491521501846_item	2513368	et	3	main
et	doc_491521501846_item	2513371	et	3	main
selle	doc_491521501846_item	2513390	et	4	main
kodumaa	doc_491521501846_item	2513393	et	4	main
nimed	doc_491521501847_item	2513402	et	3	main
kivikase	doc_491521501847_item	2513407	et	3	main
põhinev	doc_491521501847_item	2513409	et	4	main
lugu	doc_491521501847_item	2513410	et	4	main
albert	doc_491521501847_item	2513411	et	4	main
kivikas	doc_491521501847_item	2513412	et	4	main
oli	doc_491521501847_item	2513413	et	3	main
eesti	doc_491521501847_item	2513414	et	4	main
iseseisvusaja	doc_491521501847_item	2513415	et	3	main
kirjanikest	doc_491521501847_item	2513416	et	3	main
üks	doc_491521501847_item	2513417	et	3	main
viljakamaid	doc_491521501847_item	2513418	et	4	main
ja	doc_491521501847_item	2513419	et	3	main
andekamaid	doc_491521501847_item	2513420	et	4	main
tartu	doc_491521501847_item	2513436	et	4	main
1919	doc_491521501847_item	2513440	et	2	main
selle	doc_491521501847_item	2513443	et	4	main
koosseisu	doc_491521501847_item	2513445	et	4	main
kuulus	doc_491521501847_item	2513446	et	4	main
ka	doc_491521501847_item	2513447	et	3	main
vaprust	doc_491521501847_item	2513455	et	4	main
autor	doc_491521501847_item	2513462	et	3	main
kuidas	doc_491521501847_item	2513463	et	3	main
murdab	doc_491521501847_item	2513465	et	4	main
muudab	doc_491521501847_item	2513468	et	3	main
kivikat	doc_491521501847_item	2513470	et	4	main
sõja	doc_491521501847_item	2513477	et	3	main
noore	doc_491521501847_item	2513479	et	3	main
vabariigi	doc_491521501847_item	2513481	et	3	main
film	doc_491521501847_item	2513526	et	3	main
filmi	doc_491521501847_item	2513536	et	4	main
kogenud	doc_491521501847_item	2513543	et	4	main
vend	doc_491521501847_item	2513547	et	3	main
ja	doc_491521501847_item	2513548	et	3	main
priit	doc_491521501847_item	2513552	et	3	main
aadli	doc_491521501847_item	2513556	et	3	main
ott	doc_491521501847_item	2513558	et	3	main
karol	doc_491521501847_item	2513561	et	4	main
martinson	doc_491521501847_item	2513563	et	4	main
nagu	doc_491521501847_item	2513582	et	3	main
kivikase	doc_491521501847_item	2513583	et	3	main
raamatki	doc_491521501847_item	2513584	et	3	main
saades	doc_491521501847_item	2513600	et	3	main
öelda	doc_491521501847_item	2513621	et	4	main
ühtsustunnet	doc_491521501847_item	2513623	et	3	main
on	doc_491521501847_item	2513625	et	4	main
rahvuslikule	doc_491521501847_item	2513626	et	3	main
kinokultuurile	doc_491521501847_item	2513627	et	3	main
vaprus	doc_491521501847_item	2513640	et	4	main
ebakindlus	doc_491521501847_item	2513646	et	4	main
on	doc_491521501847_item	2513650	et	4	main
raha	doc_491521501847_item	2513670	et	4	main
kus	doc_491521501847_item	2513672	et	3	main
kõrgeid	doc_491521501847_item	2513677	et	3	main
meelelahutused	doc_491521501847_item	2513686	et	4	main
tavaliselt	doc_491521501847_item	2513690	et	4	main
marmortahvlil	doc_491521501847_item	2513397	et	3	main
vaatamas	doc_491521501847_item	2513400	et	3	main
kelle	doc_491521501847_item	2513421	et	4	main
on	doc_491521501847_item	2513423	et	4	main
erilisel	doc_491521501847_item	2513424	et	4	main
teema	doc_491521501847_item	2513427	et	4	main
jaanuaris	doc_491521501847_item	2513442	et	3	main
pataljoni	doc_491521501847_item	2513444	et	4	main
moodustatud	doc_491521501847_item	2513450	et	4	main
näitas	doc_491521501847_item	2513453	et	3	main
teoses	doc_491521501847_item	2513456	et	3	main
ahase	doc_491521501847_item	2513458	et	4	main
kõrval	doc_491521501847_item	2513460	et	4	main
niisugused	doc_491521501847_item	2513472	et	3	main
nagu	doc_491521501847_item	2513474	et	3	main
eesti	doc_491521501847_item	2513480	et	4	main
otsustaksime	doc_491521501847_item	2513517	et	3	main
peategelastega	doc_491521501847_item	2513519	et	3	main
aja	doc_491521501847_item	2513521	et	4	main
et	doc_491521501847_item	2513525	et	3	main
ta	doc_491521501847_item	2513530	et	4	main
väga	doc_491521501847_item	2513532	et	3	main
nüganen	doc_491521501847_item	2513539	et	4	main
astahov	doc_491521501847_item	2513546	et	4	main
vend	doc_491521501847_item	2513549	et	3	main
kuntsel	doc_491521501847_item	2513562	et	3	main
alo	doc_491521501847_item	2513564	et	4	main
anti	doc_491521501847_item	2513567	et	3	main
mart	doc_491521501847_item	2513572	et	3	main
hele	doc_491521501847_item	2513574	et	3	main
film	doc_491521501847_item	2513577	et	3	main
tõetruu	doc_491521501847_item	2513586	et	4	main
ajast	doc_491521501847_item	2513590	et	4	main
ja	doc_491521501847_item	2513597	et	3	main
üle	doc_491521501847_item	2513599	et	3	main
rindele	doc_491521501847_item	2513601	et	3	main
rahva	doc_491521501847_item	2513622	et	3	main
kinnitav	doc_491521501847_item	2513624	et	4	main
armastus	doc_491521501847_item	2513638	et	4	main
sõprus	doc_491521501847_item	2513642	et	3	main
inimkond	doc_491521501847_item	2513649	et	3	main
juba	doc_491521501847_item	2513651	et	3	main
või	doc_491521501847_item	2513666	et	4	main
tihtipeale	doc_491521501847_item	2513667	et	3	main
narkootikumite	doc_491521501847_item	2513668	et	4	main
taustaks	doc_491521501847_item	2513688	et	3	main
reaalne	doc_491521501847_item	2513695	et	3	main
vabaduse	doc_491521501847_item	2513705	et	4	main
nimel	doc_491521501847_item	2513708	et	3	main
tapetakse	doc_491521501847_item	2513710	et	3	main
et	doc_491521501847_item	2513714	et	3	main
sõja	doc_491521501847_item	2513716	et	3	main
nad	doc_491521501847_item	2513722	et	3	main
ju	doc_491521501847_item	2513724	et	3	main
ja	doc_491521501847_item	2513732	et	3	main
mille	doc_491521501847_item	2513734	et	3	main
olemas	doc_491521501847_item	2513740	et	4	main
arusaamatuks	doc_491521501847_item	2513744	et	4	main
peab	doc_491521501847_item	2513746	et	4	main
võitlema	doc_491521501847_item	2513747	et	3	main
ja	doc_491521501847_item	2513748	et	3	main
tapma	doc_491521501847_item	2513749	et	3	main
kui	doc_491521501847_item	2513750	et	3	main
eriarvamusi	doc_491521501847_item	2513751	et	3	main
ületada	doc_491521501847_item	2513753	et	3	main
kokkulepe	doc_491521501847_item	2513754	et	3	main
ka	doc_491521501847_item	2513759	et	3	main
annab	doc_491521501847_item	2513800	et	3	main
teemat	doc_491521501847_item	2513802	et	3	main
ütles	doc_491521501847_item	2513806	et	3	main
võitlus	doc_491521501847_item	2513810	et	3	main
võimalik	doc_491521501847_item	2513812	et	3	main
teadmatust	doc_491521501847_item	2513817	et	4	main
laiskust	doc_491521501847_item	2513820	et	4	main
tartu	doc_491521501847_item	2513821	et	4	main
kangelased	doc_491521501847_item	2513827	et	3	main
film	doc_491521501847_item	2513830	et	3	main
meeldis	doc_491521501847_item	2513832	et	3	main
valima	doc_491521501847_item	2513842	et	3	main
keskkooli	doc_491521501847_item	2513852	et	4	main
eest	doc_491521501847_item	2513856	et	4	main
vabadussõja	doc_491521501847_item	2513426	et	3	main
peateos	doc_491521501847_item	2513429	et	4	main
kujutab	doc_491521501847_item	2513434	et	3	main
faktitruult	doc_491521501847_item	2513435	et	4	main
aasta	doc_491521501847_item	2513441	et	4	main
üksus	doc_491521501847_item	2513451	et	3	main
arenguloo	doc_491521501847_item	2513459	et	4	main
teemad	doc_491521501847_item	2513473	et	3	main
inimese	doc_491521501847_item	2513475	et	4	main
vahekord	doc_491521501847_item	2513478	et	3	main
poliitiline	doc_491521501847_item	2513483	et	3	main
ja	doc_491521501847_item	2513484	et	3	main
kultuuriline	doc_491521501847_item	2513485	et	4	main
areng	doc_491521501847_item	2513486	et	3	main
filmi	doc_491521501847_item	2513487	et	4	main
pikkus	doc_491521501847_item	2513488	et	4	main
on	doc_491521501847_item	2513489	et	4	main
1	doc_491521501847_item	2513490	et	2	main
tund	doc_491521501847_item	2513491	et	3	main
ja	doc_491521501847_item	2513492	et	3	main
30	doc_491521501847_item	2513493	et	2	main
minutit	doc_491521501847_item	2513494	et	3	main
ja	doc_491521501847_item	2513495	et	3	main
minu	doc_491521501847_item	2513496	et	3	main
arvates	doc_491521501847_item	2513497	et	4	main
režissöör	doc_491521501847_item	2513498	et	2	main
ja	doc_491521501847_item	2513499	et	3	main
teised	doc_491521501847_item	2513500	et	4	main
filmi	doc_491521501847_item	2513501	et	4	main
loomisest	doc_491521501847_item	2513502	et	4	main
osavõtjad	doc_491521501847_item	2513503	et	3	main
tegid	doc_491521501847_item	2513504	et	4	main
kõik	doc_491521501847_item	2513505	et	4	main
et	doc_491521501847_item	2513506	et	3	main
meie	doc_491521501847_item	2513507	et	4	main
tunneksime	doc_491521501847_item	2513508	et	3	main
too	doc_491521501847_item	2513509	et	4	main
aja	doc_491521501847_item	2513510	et	4	main
ja	doc_491521501847_item	2513511	et	3	main
rahva	doc_491521501847_item	2513512	et	3	main
meeleolu	doc_491521501847_item	2513513	et	4	main
võitleksime	doc_491521501847_item	2513514	et	3	main
kõiguksime	doc_491521501847_item	2513515	et	3	main
ning	doc_491521501847_item	2513516	et	3	main
lahingutes	doc_491521501847_item	2513454	et	4	main
ja	doc_491521501847_item	2513467	et	3	main
inimesi	doc_491521501847_item	2513469	et	4	main
huvitavad	doc_491521501847_item	2513471	et	4	main
ja	doc_491521501847_item	2513476	et	3	main
sünd	doc_491521501847_item	2513482	et	3	main
selle	doc_491521501847_item	2513520	et	4	main
väga	doc_491521501847_item	2513528	et	3	main
sai	doc_491521501847_item	2513531	et	4	main
populaarseks	doc_491521501847_item	2513533	et	4	main
rahva	doc_491521501847_item	2513534	et	3	main
hulgas	doc_491521501847_item	2513535	et	4	main
elmo	doc_491521501847_item	2513538	et	4	main
jäädvustas	doc_491521501847_item	2513541	et	3	main
sergei	doc_491521501847_item	2513545	et	4	main
peaosades	doc_491521501847_item	2513551	et	3	main
kõrve	doc_491521501847_item	2513565	et	4	main
reinthal	doc_491521501847_item	2513568	et	4	main
ott	doc_491521501847_item	2513570	et	3	main
marta	doc_491521501847_item	2513576	et	4	main
on	doc_491521501847_item	2513578	et	4	main
emotsionaalne	doc_491521501847_item	2513579	et	3	main
sõjadraama	doc_491521501847_item	2513580	et	4	main
ja	doc_491521501847_item	2513581	et	3	main
kaasakiskuva	doc_491521501847_item	2513588	et	3	main
tülidest	doc_491521501847_item	2513598	et	3	main
tähtis	doc_491521501847_item	2513630	et	4	main
see	doc_491521501847_item	2513632	et	3	main
kavalus	doc_491521501847_item	2513639	et	4	main
ustavus	doc_491521501847_item	2513643	et	4	main
armastust	doc_491521501847_item	2513675	et	4	main
niisugustes	doc_491521501847_item	2513679	et	3	main
filmides	doc_491521501847_item	2513680	et	4	main
ainult	doc_491521501847_item	2513682	et	4	main
on	doc_491521501847_item	2513689	et	4	main
ebareaalsed	doc_491521501847_item	2513691	et	3	main
aga	doc_491521501847_item	2513693	et	3	main
film	doc_491521501847_item	2513700	et	3	main
on	doc_491521501847_item	2513702	et	4	main
kellel	doc_491521501847_item	2513726	et	4	main
tõttu	doc_491521501847_item	2513735	et	4	main
ka	doc_491521501847_item	2513737	et	3	main
sisekonflikt	doc_491521501847_item	2513739	et	3	main
paljudele	doc_491521501847_item	2513741	et	3	main
toimub	doc_491521501847_item	2513766	et	3	main
priit	doc_491521501847_item	2513767	et	3	main
hind	doc_491521501847_item	2513776	et	3	main
kõikjal	doc_491521501847_item	2513807	et	3	main
elus	doc_491521501847_item	2513808	et	4	main
tähendab	doc_491521501847_item	2513813	et	3	main
alistumine	doc_491521501847_item	2513814	et	4	main
või	doc_491521501847_item	2513819	et	4	main
võitlesid	doc_491521501847_item	2513823	et	4	main
mulle	doc_491521501847_item	2513828	et	4	main
on	doc_491521501847_item	2513835	et	4	main
eesti	doc_491521501847_item	2513837	et	4	main
peaksin	doc_491521501847_item	2513841	et	4	main
kodumaa	doc_491521501847_item	2513855	et	4	main
siis	doc_491521501847_item	2513859	et	3	main
essee	doc_491521501848_item	2513872	et	4	main
siis	doc_491521501848_item	2513885	et	3	main
kirjutada	doc_491521501848_item	2513887	et	3	main
minu	doc_491521501848_item	2513889	et	3	main
vaprusstseenid	doc_491521501848_item	2513926	et	4	main
on	doc_491521501848_item	2513928	et	4	main
noortele	doc_491521501848_item	2513937	et	3	main
sõda	doc_491521501848_item	2513939	et	4	main
kohutav	doc_491521501848_item	2513941	et	4	main
mille	doc_491521501848_item	2513947	et	3	main
põgenetakse	doc_491521501848_item	2513949	et	3	main
süžees	doc_491521501848_item	2513960	et	2	main
armastus	doc_491521501848_item	2513965	et	4	main
neiule	doc_491521501848_item	2513966	et	4	main
jaoks	doc_491521501848_item	2513972	et	4	main
teha	doc_491521501848_item	2513980	et	3	main
ja	doc_491521501848_item	2513983	et	3	main
kuidas	doc_491521501848_item	2513985	et	3	main
elada	doc_491521501848_item	2513986	et	3	main
arvan	doc_491521501848_item	2513987	et	3	main
et	doc_491521501848_item	2513988	et	3	main
tolleaegse	doc_491521501848_item	2513992	et	3	main
on	doc_491521501847_item	2513527	et	4	main
lavastas	doc_491521501847_item	2513537	et	3	main
võigemast	doc_491521501847_item	2513553	et	4	main
argo	doc_491521501847_item	2513555	et	4	main
kohlapuu	doc_491521501847_item	2513560	et	4	main
toome	doc_491521501847_item	2513573	et	4	main
ning	doc_491521501847_item	2513587	et	3	main
oma	doc_491521501847_item	2513595	et	4	main
kõhklustest	doc_491521501847_item	2513596	et	3	main
looma	doc_491521501847_item	2513603	et	4	main
läksid	doc_491521501847_item	2513604	et	4	main
romaan	doc_491521501847_item	2513605	et	3	main
nimed	doc_491521501847_item	2513606	et	3	main
marmortahvlil	doc_491521501847_item	2513607	et	3	main
on	doc_491521501847_item	2513608	et	4	main
tänaseks	doc_491521501847_item	2513609	et	4	main
kindla	doc_491521501847_item	2513611	et	3	main
võtnud	doc_491521501847_item	2513610	et	4	main
koha	doc_491521501847_item	2513612	et	4	main
eesti	doc_491521501847_item	2513613	et	4	main
kirjandusklassikas	doc_491521501847_item	2513614	et	3	main
säärase	doc_491521501847_item	2513615	et	3	main
raamatu	doc_491521501847_item	2513616	et	4	main
põhjal	doc_491521501847_item	2513617	et	4	main
tehtud	doc_491521501847_item	2513618	et	4	main
film	doc_491521501847_item	2513619	et	3	main
võib	doc_491521501847_item	2513620	et	3	main
kõrve	doc_491521501847_item	2513575	et	4	main
annab	doc_491521501847_item	2513585	et	3	main
pildi	doc_491521501847_item	2513589	et	4	main
mil	doc_491521501847_item	2513591	et	4	main
paljud	doc_491521501847_item	2513592	et	3	main
eesti	doc_491521501847_item	2513593	et	4	main
inimesed	doc_491521501847_item	2513594	et	3	main
rahvusriiki	doc_491521501847_item	2513602	et	4	main
väga	doc_491521501847_item	2513628	et	3	main
on	doc_491521501847_item	2513631	et	4	main
et	doc_491521501847_item	2513633	et	3	main
on	doc_491521501847_item	2513635	et	4	main
kõik	doc_491521501847_item	2513636	et	4	main
surm	doc_491521501847_item	2513637	et	3	main
usk	doc_491521501847_item	2513645	et	3	main
sisekonflikt	doc_491521501847_item	2513648	et	3	main
filmidest	doc_491521501847_item	2513654	et	3	main
või	doc_491521501847_item	2513669	et	4	main
ega	doc_491521501847_item	2513676	et	3	main
ja	doc_491521501847_item	2513687	et	3	main
iseseisvuse	doc_491521501847_item	2513707	et	4	main
võideldakse	doc_491521501847_item	2513709	et	3	main
sõditakse	doc_491521501847_item	2513711	et	3	main
vaatajale	doc_491521501847_item	2513712	et	4	main
näidatakse	doc_491521501847_item	2513713	et	3	main
ole	doc_491521501847_item	2513719	et	4	main
oluline	doc_491521501847_item	2513629	et	4	main
filmis	doc_491521501847_item	2513634	et	4	main
truudus	doc_491521501847_item	2513641	et	4	main
lootus	doc_491521501847_item	2513644	et	4	main
ning	doc_491521501847_item	2513647	et	3	main
liiga	doc_491521501847_item	2513652	et	4	main
väsinud	doc_491521501847_item	2513653	et	4	main
kus	doc_491521501847_item	2513655	et	3	main
relvastatud	doc_491521501847_item	2513656	et	4	main
mehed	doc_491521501847_item	2513657	et	3	main
ja	doc_491521501847_item	2513658	et	3	main
naised	doc_491521501847_item	2513659	et	3	main
tülitsevad	doc_491521501847_item	2513660	et	4	main
kogu	doc_491521501847_item	2513661	et	4	main
aeg	doc_491521501847_item	2513662	et	3	main
mitte	doc_491521501847_item	2513663	et	3	main
millegi	doc_491521501847_item	2513664	et	4	main
eest	doc_491521501847_item	2513665	et	4	main
pärast	doc_491521501847_item	2513671	et	4	main
ei	doc_491521501847_item	2513673	et	4	main
ole	doc_491521501847_item	2513674	et	4	main
tundeid	doc_491521501847_item	2513678	et	3	main
on	doc_491521501847_item	2513681	et	4	main
odavad	doc_491521501847_item	2513683	et	3	main
ja	doc_491521501847_item	2513684	et	3	main
mõttetud	doc_491521501847_item	2513685	et	4	main
mitte	doc_491521501847_item	2513694	et	3	main
elu	doc_491521501847_item	2513696	et	4	main
marmortahvlil	doc_491521501847_item	2513698	et	3	main
on	doc_491521501847_item	2513699	et	4	main
milles	doc_491521501847_item	2513701	et	3	main
vääriline	doc_491521501847_item	2513703	et	4	main
eesmärk	doc_491521501847_item	2513704	et	3	main
sõduritel	doc_491521501847_item	2513715	et	3	main
ei	doc_491521501847_item	2513718	et	4	main
ka	doc_491521501847_item	2513720	et	3	main
kerge	doc_491521501847_item	2513721	et	4	main
inimesed	doc_491521501847_item	2513725	et	3	main
teistel	doc_491521501847_item	2513730	et	4	main
on	doc_491521501847_item	2513736	et	4	main
neil	doc_491521501847_item	2513738	et	4	main
jääb	doc_491521501847_item	2513743	et	3	main
abil	doc_491521501847_item	2513755	et	4	main
niisugune	doc_491521501847_item	2513756	et	3	main
inimen	doc_491521501847_item	2513757	et	4	main
meie	doc_491521501847_item	2513761	et	4	main
mis	doc_491521501847_item	2513763	et	4	main
mõtlemiseks	doc_491521501847_item	2513803	et	4	main
maurice	doc_491521501847_item	2513804	et	4	main
maeterlinck	doc_491521501847_item	2513805	et	4	main
kus	doc_491521501847_item	2513809	et	3	main
on	doc_491521501847_item	2513811	et	4	main
vaid	doc_491521501847_item	2513815	et	3	main
on	doc_491521501847_item	2513826	et	4	main
ja	doc_491521501847_item	2513838	et	3	main
tartu	doc_491521501847_item	2513851	et	4	main
jääks	doc_491521501847_item	2513863	et	4	main
essee	doc_491521501848_item	2513873	et	4	main
nimed	doc_491521501848_item	2513874	et	3	main
marmortahvlil	doc_491521501848_item	2513875	et	3	main
läbi	doc_491521501848_item	2513880	et	4	main
ja	doc_491521501848_item	2513884	et	3	main
tahaks	doc_491521501848_item	2513886	et	3	main
puuduvad	doc_491521501848_item	2513924	et	4	main
eluvõõrad	doc_491521501848_item	2513925	et	3	main
sõdurid	doc_491521501848_item	2513927	et	3	main
nendele	doc_491521501848_item	2513935	et	4	main
koolipoistele	doc_491521501848_item	2513938	et	3	main
on	doc_491521501848_item	2513940	et	4	main
haarab	doc_491521501848_item	2513944	et	3	main
kuidas	doc_491521501848_item	2513959	et	3	main
väga	doc_491521501848_item	2513969	et	3	main
tähtsad	doc_491521501848_item	2513970	et	3	main
just	doc_491521501848_item	2513974	et	3	main
mis	doc_491521501848_item	2513979	et	4	main
kuidas	doc_491521501848_item	2513981	et	3	main
tõesti	doc_491521501848_item	2514023	et	3	main
armastama	doc_491521501848_item	2514025	et	3	main
isamaad	doc_491521501848_item	2514027	et	4	main
et	doc_491521501848_item	2514028	et	3	main
olla	doc_491521501848_item	2514029	et	3	main
valmis	doc_491521501848_item	2514030	et	4	main
sõdima	doc_491521501848_item	2514031	et	3	main
ja	doc_491521501848_item	2514032	et	3	main
surema	doc_491521501848_item	2514033	et	3	main
seal	doc_491521501848_item	2514047	et	4	main
alati	doc_491521501848_item	2514049	et	4	main
tapmine	doc_491521501848_item	2514052	et	4	main
vaatamata	doc_491521501848_item	2514053	et	4	main
nimed	doc_491521501848_item	2514057	et	3	main
arvan	doc_491521501848_item	2514062	et	3	main
esiplaanil	doc_491521501848_item	2514064	et	4	main
niisugused	doc_491521501848_item	2514067	et	3	main
asjad	doc_491521501848_item	2514068	et	3	main
nagu	doc_491521501848_item	2514069	et	3	main
sõprus	doc_491521501848_item	2514070	et	3	main
teist	doc_491521501848_item	2514098	et	4	main
filmiga	doc_491521501848_item	2514102	et	3	main
ei	doc_491521501848_item	2514105	et	4	main
seda	doc_491521501848_item	2514111	et	3	main
sündmused	doc_491521501847_item	2513692	et	3	main
nimed	doc_491521501847_item	2513697	et	3	main
ja	doc_491521501847_item	2513706	et	3	main
ajal	doc_491521501847_item	2513717	et	4	main
on	doc_491521501847_item	2513727	et	4	main
nagu	doc_491521501847_item	2513729	et	3	main
tunded	doc_491521501847_item	2513731	et	3	main
on	doc_491521501847_item	2513758	et	4	main
näeme	doc_491521501847_item	2513762	et	3	main
ta	doc_491521501847_item	2513764	et	4	main
on	doc_491521501847_item	2513774	et	4	main
kõrge	doc_491521501847_item	2513775	et	4	main
meile	doc_491521501847_item	2513801	et	4	main
on	doc_491521501847_item	2513723	et	4	main
samuti	doc_491521501847_item	2513728	et	3	main
heasüdamlikkus	doc_491521501847_item	2513733	et	4	main
neist	doc_491521501847_item	2513742	et	4	main
miks	doc_491521501847_item	2513745	et	4	main
võiks	doc_491521501847_item	2513752	et	4	main
ahas	doc_491521501847_item	2513760	et	4	main
hinges	doc_491521501847_item	2513765	et	4	main
võigemas	doc_491521501847_item	2513768	et	4	main
on	doc_491521501847_item	2513769	et	4	main
tõesti	doc_491521501847_item	2513770	et	3	main
andekas	doc_491521501847_item	2513771	et	4	main
näitleja	doc_491521501847_item	2513772	et	4	main
vabadusel	doc_491521501847_item	2513773	et	4	main
paljud	doc_491521501847_item	2513777	et	3	main
surevad	doc_491521501847_item	2513778	et	4	main
tekkib	doc_491521501847_item	2513779	et	3	main
küsimus	doc_491521501847_item	2513780	et	4	main
kas	doc_491521501847_item	2513781	et	3	main
saavad	doc_491521501847_item	2513782	et	4	main
need	doc_491521501847_item	2513783	et	3	main
inimesed	doc_491521501847_item	2513784	et	3	main
kes	doc_491521501847_item	2513785	et	4	main
võitlevad	doc_491521501847_item	2513786	et	4	main
tasuks	doc_491521501847_item	2513787	et	4	main
armastuse	doc_491521501847_item	2513788	et	4	main
isamaa	doc_491521501847_item	2513789	et	4	main
või	doc_491521501847_item	2513790	et	4	main
jäävad	doc_491521501847_item	2513791	et	4	main
neist	doc_491521501847_item	2513792	et	4	main
mälestuseks	doc_491521501847_item	2513793	et	4	main
vaid	doc_491521501847_item	2513794	et	3	main
nimed	doc_491521501847_item	2513795	et	3	main
marmortahvlil	doc_491521501847_item	2513796	et	3	main
film	doc_491521501847_item	2513797	et	3	main
nagu	doc_491521501847_item	2513798	et	3	main
raamatki	doc_491521501847_item	2513799	et	3	main
varjutud	doc_491521501847_item	2513816	et	4	main
võimetust	doc_491521501847_item	2513818	et	4	main
minu	doc_491521501847_item	2513833	et	3	main
kodumaa	doc_491521501847_item	2513834	et	4	main
ka	doc_491521501847_item	2513836	et	3	main
mina	doc_491521501847_item	2513840	et	4	main
mille	doc_491521501847_item	2513843	et	3	main
poistega	doc_491521501847_item	2513853	et	3	main
sõdima	doc_491521501847_item	2513857	et	3	main
mu	doc_491521501847_item	2513861	et	3	main
ainult	doc_491521501847_item	2513864	et	4	main
sest	doc_491521501847_item	2513866	et	4	main
elame	doc_491521501847_item	2513868	et	3	main
kuni	doc_491521501847_item	2513869	et	3	main
filmi	doc_491521501848_item	2513876	et	4	main
järgi	doc_491521501848_item	2513877	et	4	main
sõda	doc_491521501848_item	2513922	et	4	main
tavalised	doc_491521501848_item	2513929	et	4	main
inimesed	doc_491521501848_item	2513930	et	3	main
hirm	doc_491521501848_item	2513931	et	3	main
ja	doc_491521501848_item	2513932	et	3	main
reaalsus	doc_491521501848_item	2513942	et	4	main
ja	doc_491521501848_item	2513951	et	3	main
maha	doc_491521501848_item	2513953	et	4	main
lahingust	doc_491521501848_item	2513955	et	4	main
armastus	doc_491521501848_item	2513962	et	4	main
ja	doc_491521501848_item	2513964	et	3	main
on	doc_491521501848_item	2513968	et	4	main
ja	doc_491521501848_item	2513973	et	3	main
nende	doc_491521501848_item	2513975	et	4	main
otsustab	doc_491521501848_item	2513978	et	3	main
käituda	doc_491521501848_item	2513982	et	3	main
poisid	doc_491521501847_item	2513822	et	4	main
lõpuni	doc_491521501847_item	2513824	et	3	main
nad	doc_491521501847_item	2513825	et	3	main
see	doc_491521501847_item	2513829	et	3	main
väga	doc_491521501847_item	2513831	et	3	main
kui	doc_491521501847_item	2513839	et	3	main
eest	doc_491521501847_item	2513844	et	4	main
ja	doc_491521501847_item	2513845	et	3	main
kellega	doc_491521501847_item	2513846	et	3	main
võidelda	doc_491521501847_item	2513847	et	4	main
siis	doc_491521501847_item	2513848	et	3	main
läheksin	doc_491521501847_item	2513849	et	3	main
koos	doc_491521501847_item	2513850	et	4	main
oma	doc_491521501847_item	2513854	et	4	main
nimi	doc_491521501847_item	2513862	et	3	main
vaatasin	doc_491521501848_item	2513879	et	3	main
filmi	doc_491521501848_item	2513881	et	4	main
marmortahvlil	doc_491521501848_item	2513883	et	3	main
natuke	doc_491521501848_item	2513888	et	4	main
muljedest	doc_491521501848_item	2513890	et	4	main
see	doc_491521501848_item	2513891	et	3	main
film	doc_491521501848_item	2513892	et	3	main
meeldis	doc_491521501848_item	2513893	et	3	main
mulle	doc_491521501848_item	2513894	et	4	main
väga	doc_491521501848_item	2513895	et	3	main
ma	doc_491521501848_item	2513897	et	3	main
arvasin	doc_491521501848_item	2513898	et	3	main
et	doc_491521501848_item	2513899	et	3	main
alguses	doc_491521501848_item	2513896	et	4	main
filmis	doc_491521501848_item	2513900	et	4	main
vabadussõda	doc_491521501848_item	2513901	et	4	main
on	doc_491521501848_item	2513902	et	4	main
idealiseeritud	doc_491521501848_item	2513903	et	4	main
ja	doc_491521501848_item	2513904	et	3	main
eesti	doc_491521501848_item	2513905	et	4	main
sõdurid	doc_491521501848_item	2513906	et	3	main
on	doc_491521501848_item	2513907	et	4	main
näidatud	doc_491521501848_item	2513908	et	4	main
nagu	doc_491521501848_item	2513909	et	3	main
kõige	doc_491521501848_item	2513910	et	4	main
julgemad	doc_491521501848_item	2513911	et	4	main
ja	doc_491521501848_item	2513912	et	3	main
kartmatud	doc_491521501848_item	2513913	et	4	main
tegelikult	doc_491521501848_item	2513914	et	4	main
see	doc_491521501848_item	2513915	et	3	main
pole	doc_491521501848_item	2513916	et	3	main
üldse	doc_491521501848_item	2513917	et	3	main
nii	doc_491521501848_item	2513918	et	3	main
režissöör	doc_491521501848_item	2513919	et	2	main
ei	doc_491521501848_item	2513920	et	4	main
heroiseeri	doc_491521501848_item	2513921	et	4	main
ka	doc_491521501847_item	2513858	et	3	main
kui	doc_491521501847_item	2513860	et	3	main
marmortahvlil	doc_491521501847_item	2513865	et	3	main
meie	doc_491521501847_item	2513867	et	4	main
meid	doc_491521501847_item	2513870	et	4	main
mäletatakse	doc_491521501847_item	2513871	et	3	main
ma	doc_491521501848_item	2513878	et	3	main
nimed	doc_491521501848_item	2513882	et	3	main
filmis	doc_491521501848_item	2513923	et	4	main
on	doc_491521501848_item	2513934	et	4	main
neid	doc_491521501848_item	2513943	et	4	main
meeletu	doc_491521501848_item	2513945	et	4	main
surmahirm	doc_491521501848_item	2513946	et	3	main
jättes	doc_491521501848_item	2513954	et	4	main
mulle	doc_491521501848_item	2513956	et	4	main
samuti	doc_491521501848_item	2513957	et	3	main
põimuvad	doc_491521501848_item	2513961	et	4	main
isamaale	doc_491521501848_item	2513963	et	4	main
need	doc_491521501848_item	2513967	et	3	main
peategelase	doc_491521501848_item	2513971	et	3	main
mõjul	doc_491521501848_item	2513976	et	4	main
armastus	doc_491521501848_item	2513989	et	4	main
üldse	doc_491521501848_item	2513990	et	3	main
inimeste	doc_491521501848_item	2513993	et	3	main
peamine	doc_491521501848_item	2513995	et	3	main
tegur	doc_491521501848_item	2513996	et	3	main
see	doc_491521501848_item	2513997	et	3	main
mõjus	doc_491521501848_item	2513998	et	4	main
neid	doc_491521501848_item	2513999	et	4	main
palju	doc_491521501848_item	2514000	et	4	main
rohkem	doc_491521501848_item	2514001	et	4	main
kui	doc_491521501848_item	2514002	et	3	main
tänapäeval	doc_491521501848_item	2514003	et	3	main
paljud	doc_491521501848_item	2514004	et	3	main
inimesed	doc_491521501848_item	2514005	et	3	main
elasid	doc_491521501848_item	2514006	et	4	main
armastuse	doc_491521501848_item	2514007	et	4	main
nimel	doc_491521501848_item	2514008	et	3	main
ja	doc_491521501848_item	2514009	et	3	main
see	doc_491521501848_item	2514010	et	3	main
võiks	doc_491521501848_item	2514011	et	4	main
olla	doc_491521501848_item	2514012	et	3	main
kas	doc_491521501848_item	2514013	et	3	main
isamaa	doc_491521501848_item	2514014	et	4	main
jumala	doc_491521501848_item	2514015	et	3	main
või	doc_491521501848_item	2514016	et	4	main
lihtsalt	doc_491521501848_item	2514017	et	4	main
armastus	doc_491521501848_item	2514018	et	4	main
teise	doc_491521501848_item	2514019	et	4	main
inimese	doc_491521501848_item	2514020	et	4	main
peaks	doc_491521501848_item	2514022	et	4	main
tavaliselt	doc_491521501848_item	2514036	et	4	main
esiplaanil	doc_491521501848_item	2514046	et	4	main
on	doc_491521501848_item	2514048	et	4	main
surm	doc_491521501848_item	2514050	et	3	main
ja	doc_491521501848_item	2514051	et	3	main
on	doc_491521501848_item	2514059	et	4	main
ja	doc_491521501848_item	2514104	et	3	main
nüüd	doc_491521501848_item	2514107	et	4	main
noortele	doc_491521501848_item	2514110	et	3	main
häid	doc_491521501848_item	2514118	et	3	main
filmil	doc_491521501848_item	2514120	et	3	main
meie	doc_491521501848_item	2514130	et	4	main
ajalugu	doc_491521501848_item	2514131	et	4	main
kartus	doc_491521501848_item	2513933	et	3	main
iseloomulikud	doc_491521501848_item	2513936	et	3	main
ajel	doc_491521501848_item	2513948	et	4	main
püsse	doc_491521501848_item	2513950	et	3	main
varustust	doc_491521501848_item	2513952	et	4	main
meeldis	doc_491521501848_item	2513958	et	3	main
ta	doc_491521501848_item	2513977	et	4	main
isegi	doc_491521501848_item	2513984	et	4	main
oli	doc_491521501848_item	2513991	et	3	main
elu	doc_491521501848_item	2513994	et	4	main
selle	doc_491521501848_item	2514034	et	4	main
nimel	doc_491521501848_item	2514035	et	3	main
sõjast	doc_491521501848_item	2514038	et	3	main
filmide	doc_491521501848_item	2514039	et	3	main
vaatamist	doc_491521501848_item	2514040	et	4	main
jääb	doc_491521501848_item	2514041	et	3	main
inimestel	doc_491521501848_item	2514042	et	3	main
ebameeldiv	doc_491521501848_item	2514043	et	3	main
marmortahvlil	doc_491521501848_item	2514058	et	3	main
samuti	doc_491521501848_item	2514060	et	3	main
selles	doc_491521501848_item	2514065	et	4	main
on	doc_491521501848_item	2514066	et	4	main
jäin	doc_491521501848_item	2514101	et	3	main
rahule	doc_491521501848_item	2514103	et	4	main
soovitan	doc_491521501848_item	2514108	et	3	main
kõigile	doc_491521501848_item	2514109	et	4	main
sest	doc_491521501848_item	2514113	et	4	main
õppida	doc_491521501848_item	2514117	et	3	main
siiralt	doc_491521501848_item	2514024	et	4	main
oma	doc_491521501848_item	2514026	et	4	main
pärast	doc_491521501848_item	2514037	et	4	main
sest	doc_491521501848_item	2514045	et	4	main
film	doc_491521501848_item	2514056	et	3	main
armastus	doc_491521501848_item	2514071	et	4	main
ja	doc_491521501848_item	2514072	et	3	main
ennastsalgavus	doc_491521501848_item	2514073	et	4	main
see	doc_491521501848_item	2514074	et	3	main
on	doc_491521501848_item	2514075	et	4	main
mingis	doc_491521501848_item	2514076	et	4	main
mõttes	doc_491521501848_item	2514077	et	3	main
helde	doc_491521501848_item	2514078	et	4	main
film	doc_491521501848_item	2514079	et	3	main
ausalt	doc_491521501848_item	2514080	et	4	main
öeldes	doc_491521501848_item	2514081	et	3	main
kui	doc_491521501848_item	2514082	et	3	main
ma	doc_491521501848_item	2514083	et	3	main
tulin	doc_491521501848_item	2514084	et	3	main
kinosse	doc_491521501848_item	2514085	et	3	main
siis	doc_491521501848_item	2514086	et	3	main
tahtnud	doc_491521501848_item	2514088	et	4	main
vaadata	doc_491521501848_item	2514089	et	4	main
seda	doc_491521501848_item	2514090	et	3	main
ei	doc_491521501848_item	2514087	et	4	main
filmi	doc_491521501848_item	2514091	et	4	main
ma	doc_491521501848_item	2514092	et	3	main
vaataks	doc_491521501848_item	2514093	et	3	main
parem	doc_491521501848_item	2514094	et	4	main
mingit	doc_491521501848_item	2514095	et	3	main
komöödiat	doc_491521501848_item	2514096	et	3	main
või	doc_491521501848_item	2514097	et	4	main
vastu	doc_491521501848_item	2514021	et	3	main
mulje	doc_491521501848_item	2514044	et	4	main
sellele	doc_491521501848_item	2514054	et	4	main
et	doc_491521501848_item	2514055	et	3	main
sõjast	doc_491521501848_item	2514061	et	3	main
et	doc_491521501848_item	2514063	et	3	main
aga	doc_491521501848_item	2514100	et	3	main
kahetsenud	doc_491521501848_item	2514106	et	4	main
ka	doc_491521501848_item	2514122	et	3	main
külg	doc_491521501848_item	2514124	et	3	main
see	doc_491521501848_item	2514125	et	3	main
meid	doc_491521501848_item	2514127	et	4	main
sündmustest	doc_491521501848_item	2514135	et	4	main
filmi	doc_491521501848_item	2514136	et	4	main
kui	doc_491521501848_item	2514141	et	3	main
õpiku	doc_491521501848_item	2514142	et	3	main
lugemine	doc_491521501848_item	2514143	et	4	main
tõesti	doc_491521501848_item	2514144	et	3	main
on	doc_491521501848_item	2514145	et	4	main
filmi	doc_491521501848_item	2514099	et	4	main
filmi	doc_491521501848_item	2514112	et	4	main
tõesti	doc_491521501848_item	2514116	et	3	main
asju	doc_491521501848_item	2514119	et	3	main
on	doc_491521501848_item	2514121	et	4	main
praktiline	doc_491521501848_item	2514123	et	3	main
aitab	doc_491521501848_item	2514126	et	3	main
paremini	doc_491521501848_item	2514128	et	4	main
vaatamine	doc_491521501848_item	2514137	et	4	main
filmi	doc_491521501848_item	2514150	et	4	main
vastu	doc_491521501848_item	2514151	et	3	main
inimestel	doc_491521501848_item	2514155	et	3	main
mina	doc_491521501848_item	2514157	et	4	main
see	doc_491521501848_item	2514114	et	3	main
võib	doc_491521501848_item	2514115	et	3	main
tunda	doc_491521501848_item	2514129	et	3	main
on	doc_491521501848_item	2514138	et	4	main
kahju	doc_491521501848_item	2514146	et	4	main
et	doc_491521501848_item	2514147	et	3	main
on	doc_491521501848_item	2514152	et	4	main
sest	doc_491521501848_item	2514156	et	4	main
koos	doc_491521501848_item	2514158	et	4	main
kaasõpilastega	doc_491521501848_item	2514159	et	4	main
olime	doc_491521501848_item	2514160	et	3	main
ainsad	doc_491521501848_item	2514161	et	3	main
noored	doc_491521501848_item	2514162	et	3	main
isiklikult	doc_491521501850_item	2514442	et	4	main
raamatu	doc_491521501850_item	2514452	et	4	main
aga	doc_491521501850_item	2514455	et	3	main
väga	doc_491521501850_item	2514468	et	3	main
teiseks	doc_491521501850_item	2514476	et	4	main
oli	doc_491521501850_item	2514477	et	3	main
see	doc_491521501850_item	2514478	et	3	main
mu	doc_491521501850_item	2514479	et	3	main
alati	doc_491521501850_item	2514486	et	4	main
ajaloolisi	doc_491521501850_item	2514490	et	4	main
inimesed	doc_491521501850_item	2514521	et	3	main
neid	doc_491521501850_item	2514530	et	4	main
ma	doc_491521501850_item	2514543	et	3	main
koolipinkidest	doc_491521501850_item	2514552	et	3	main
haarata	doc_491521501850_item	2514555	et	4	main
filmi	doc_491521501850_item	2514564	et	4	main
et	doc_491521501850_item	2514571	et	3	main
hoidsid	doc_491521501850_item	2514574	et	4	main
padrunid	doc_491521501850_item	2514576	et	3	main
relvad	doc_491521501850_item	2514577	et	3	main
olid	doc_491521501850_item	2514578	et	4	main
mõtlema	doc_491521501850_item	2514589	et	3	main
eest	doc_491521501850_item	2514600	et	4	main
veel	doc_491521501850_item	2514606	et	4	main
noorelt	doc_491521501850_item	2514608	et	4	main
on	doc_491521501850_item	2514610	et	4	main
kõrge	doc_491521501850_item	2514611	et	4	main
hind	doc_491521501850_item	2514612	et	3	main
isegi	doc_491521501850_item	2514616	et	4	main
palju	doc_491521501848_item	2514139	et	4	main
huvitavam	doc_491521501848_item	2514140	et	4	main
selle	doc_491521501848_item	2514149	et	4	main
peamiselt	doc_491521501848_item	2514153	et	4	main
annab	doc_491521501848_item	2514132	et	3	main
ülevaade	doc_491521501848_item	2514133	et	3	main
mineviku	doc_491521501848_item	2514134	et	3	main
huvi	doc_491521501848_item	2514148	et	4	main
pensiooniealistel	doc_491521501848_item	2514154	et	4	main
kinosaalis	doc_491521501848_item	2514163	et	3	main
läbi	doc_491521501850_item	2514450	et	4	main
marmortahvlil	doc_491521501850_item	2514454	et	3	main
raiskasin	doc_491521501850_item	2514460	et	3	main
seda	doc_491521501850_item	2514464	et	3	main
näitlejad	doc_491521501850_item	2514475	et	4	main
minu	doc_491521501850_item	2514484	et	3	main
huvitav	doc_491521501850_item	2514488	et	4	main
essee	doc_491521501850_item	2514438	et	4	main
nimed	doc_491521501850_item	2514439	et	3	main
marmortahvlil	doc_491521501850_item	2514440	et	3	main
mina	doc_491521501850_item	2514443	et	4	main
lugeda	doc_491521501850_item	2514451	et	3	main
nimed	doc_491521501850_item	2514453	et	3	main
poolteist	doc_491521501850_item	2514456	et	4	main
filmi	doc_491521501850_item	2514461	et	4	main
vaatamisele	doc_491521501850_item	2514462	et	4	main
film	doc_491521501850_item	2514466	et	3	main
meeldis	doc_491521501850_item	2514469	et	3	main
isamaaga	doc_491521501850_item	2514480	et	3	main
ja	doc_491521501850_item	2514482	et	3	main
rahvast	doc_491521501850_item	2514527	et	4	main
aga	doc_491521501850_item	2514528	et	3	main
ilusaks	doc_491521501850_item	2514534	et	4	main
sama	doc_491521501850_item	2514536	et	4	main
kaitsta	doc_491521501850_item	2514540	et	4	main
et	doc_491521501850_item	2514545	et	3	main
iseseisvuse	doc_491521501850_item	2514559	et	4	main
eest	doc_491521501850_item	2514560	et	4	main
võitlusse	doc_491521501850_item	2514561	et	3	main
asuda	doc_491521501850_item	2514562	et	3	main
sõdurid	doc_491521501850_item	2514573	et	3	main
olemas	doc_491521501850_item	2514579	et	4	main
igaühel	doc_491521501850_item	2514580	et	3	main
aga	doc_491521501850_item	2514581	et	3	main
padruneid	doc_491521501850_item	2514582	et	3	main
polnud	doc_491521501850_item	2514583	et	3	main
näha	doc_491521501850_item	2514584	et	3	main
lugu	doc_491521501850_item	2514587	et	4	main
kui	doc_491521501850_item	2514591	et	3	main
oma	doc_491521501850_item	2514597	et	4	main
ja	doc_491521501850_item	2514605	et	3	main
see	doc_491521501850_item	2514615	et	3	main
olla	doc_491521501850_item	2514617	et	3	main
vaatavad	doc_491521501850_item	2514626	et	4	main
läbi	doc_491521501850_item	2514627	et	4	main
võib-	doc_491521501850_item	2514635	et	3	main
olla	doc_491521501850_item	2514636	et	3	main
teistmoodi	doc_491521501850_item	2514638	et	3	main
lõppude	doc_491521501850_item	2514643	et	4	main
võib-olla	doc_491521501850_item	2514645	et	3	main
väheneb	doc_491521501850_item	2514647	et	3	main
paremat	doc_491521501850_item	2514654	et	4	main
ei	doc_491521501850_item	2514444	et	4	main
kahjuks	doc_491521501850_item	2514446	et	4	main
oli	doc_491521501850_item	2514463	et	3	main
väärt	doc_491521501850_item	2514465	et	4	main
seal	doc_491521501850_item	2514471	et	4	main
kolmandaks	doc_491521501850_item	2514483	et	4	main
vaadata	doc_491521501850_item	2514489	et	4	main
olid	doc_491521501850_item	2514522	et	4	main
palju	doc_491521501850_item	2514524	et	4	main
tänapäeva	doc_491521501850_item	2514526	et	4	main
jäi	doc_491521501850_item	2514532	et	3	main
ja	doc_491521501850_item	2514535	et	3	main
väärtuslikuks	doc_491521501850_item	2514537	et	3	main
seda	doc_491521501850_item	2514539	et	3	main
venelaste	doc_491521501850_item	2514541	et	4	main
täna	doc_491521501850_item	2514546	et	4	main
vähe	doc_491521501850_item	2514548	et	3	main
kes	doc_491521501850_item	2514551	et	4	main
relvi	doc_491521501850_item	2514554	et	4	main
ja	doc_491521501850_item	2514556	et	3	main
riigi	doc_491521501850_item	2514558	et	3	main
kus	doc_491521501850_item	2514572	et	3	main
see	doc_491521501850_item	2514586	et	3	main
võimalus	doc_491521501850_item	2514593	et	3	main
mina	doc_491521501850_item	2514595	et	4	main
läheksin	doc_491521501850_item	2514596	et	3	main
riigi	doc_491521501850_item	2514598	et	3	main
iseseisvuse	doc_491521501850_item	2514599	et	4	main
nii	doc_491521501850_item	2514607	et	3	main
tihti	doc_491521501850_item	2514613	et	3	main
inimeste	doc_491521501850_item	2514619	et	3	main
mida	doc_491521501850_item	2514623	et	4	main
selle	doc_491521501850_item	2514628	et	4	main
oma	doc_491521501850_item	2514640	et	4	main
ja	doc_491521501850_item	2514642	et	3	main
inimeste	doc_491521501850_item	2514649	et	3	main
arv	doc_491521501850_item	2514650	et	3	main
oma	doc_491521501850_item	2514660	et	4	main
eesti	doc_491521501850_item	2514665	et	4	main
marmortahvlil	doc_491521501851_item	2514669	et	3	main
lisaks	doc_491521501851_item	2514688	et	4	main
neli	doc_491521501851_item	2514696	et	3	main
mälestusi	doc_491521501851_item	2514699	et	4	main
ja	doc_491521501851_item	2514721	et	3	main
arvud	doc_491521501851_item	2514725	et	3	main
nimed	doc_491521501851_item	2514729	et	3	main
000	doc_491521501851_item	2514733	et	2	main
troonilt	doc_491521501851_item	2514736	et	3	main
titanicu	doc_491521501851_item	2514738	et	4	main
aastaid	doc_491521501851_item	2514741	et	4	main
suutnud	doc_491521501851_item	2514755	et	4	main
märk	doc_491521501851_item	2514761	et	3	main
äratas	doc_491521501851_item	2514765	et	3	main
hea	doc_491521501851_item	2514772	et	4	main
loonud	doc_491521501851_item	2514790	et	4	main
selle	doc_491521501851_item	2514821	et	4	main
mis	doc_491521501851_item	2514823	et	4	main
vahepeal	doc_491521501851_item	2514824	et	3	main
toimunud	doc_491521501851_item	2514825	et	4	main
raske	doc_491521501851_item	2514833	et	4	main
oli	doc_491521501851_item	2514834	et	3	main
parajasti	doc_491521501851_item	2514839	et	3	main
jätab	doc_491521501851_item	2514845	et	3	main
soomusrogi	doc_491521501851_item	2514856	et	4	main
huilgama	doc_491521501851_item	2514858	et	3	main
hetk	doc_491521501851_item	2514864	et	3	main
et	doc_491521501851_item	2514868	et	3	main
kuhugi	doc_491521501851_item	2514871	et	4	main
ja	doc_491521501851_item	2514873	et	3	main
olnuks	doc_491521501851_item	2514876	et	4	main
nä	doc_491521501851_item	2514877	et	4	main
soomusrong	doc_491521501851_item	2514881	et	3	main
kujutades	doc_491521501851_item	2514889	et	3	main
et	doc_491521501851_item	2514893	et	3	main
essee	doc_491521501850_item	2514441	et	4	main
leidnud	doc_491521501850_item	2514445	et	4	main
vaba	doc_491521501850_item	2514447	et	4	main
aega	doc_491521501850_item	2514448	et	4	main
et	doc_491521501850_item	2514449	et	3	main
tundi	doc_491521501850_item	2514457	et	4	main
mida	doc_491521501850_item	2514458	et	4	main
ma	doc_491521501850_item	2514459	et	3	main
mulle	doc_491521501850_item	2514467	et	4	main
esiteks	doc_491521501850_item	2514470	et	3	main
mängisid	doc_491521501850_item	2514472	et	4	main
minu	doc_491521501850_item	2514473	et	3	main
vanuse	doc_491521501850_item	2514474	et	4	main
seotud	doc_491521501850_item	2514481	et	4	main
meelest	doc_491521501850_item	2514485	et	4	main
on	doc_491521501850_item	2514487	et	4	main
mis	doc_491521501850_item	2514492	et	4	main
filme	doc_491521501850_item	2514491	et	3	main
annavad	doc_491521501850_item	2514493	et	3	main
sulle	doc_491521501850_item	2514494	et	3	main
kas	doc_491521501850_item	2514495	et	3	main
või	doc_491521501850_item	2514496	et	4	main
väiksegi	doc_491521501850_item	2514497	et	4	main
ettekujutuse	doc_491521501850_item	2514498	et	4	main
oma	doc_491521501850_item	2514499	et	4	main
eelkäiatest	doc_491521501850_item	2514500	et	4	main
sellest	doc_491521501850_item	2514501	et	4	main
mis	doc_491521501850_item	2514502	et	4	main
ja	doc_491521501850_item	2514503	et	3	main
kuidas	doc_491521501850_item	2514504	et	3	main
oli	doc_491521501850_item	2514505	et	3	main
ennem	doc_491521501850_item	2514506	et	4	main
see	doc_491521501850_item	2514507	et	3	main
oli	doc_491521501850_item	2514509	et	3	main
sõjadraama	doc_491521501850_item	2514508	et	4	main
lavastatud	doc_491521501850_item	2514510	et	4	main
albert	doc_491521501850_item	2514511	et	4	main
kivikase	doc_491521501850_item	2514512	et	3	main
romaani	doc_491521501850_item	2514513	et	4	main
järgi	doc_491521501850_item	2514514	et	4	main
mis	doc_491521501850_item	2514515	et	4	main
oli	doc_491521501850_item	2514516	et	3	main
seotud	doc_491521501850_item	2514517	et	4	main
päris	doc_491521501850_item	2514518	et	4	main
sündmustega	doc_491521501850_item	2514519	et	3	main
tollaaegsed	doc_491521501850_item	2514520	et	4	main
väga	doc_491521501850_item	2514523	et	3	main
erinevamad	doc_491521501850_item	2514525	et	4	main
loodus	doc_491521501850_item	2514531	et	4	main
et	doc_491521501850_item	2514538	et	3	main
ümbritsev	doc_491521501850_item	2514529	et	4	main
sama	doc_491521501850_item	2514533	et	4	main
eest	doc_491521501850_item	2514542	et	4	main
neid	doc_491521501850_item	2514549	et	4	main
tõusta	doc_491521501850_item	2514553	et	4	main
oma	doc_491521501850_item	2514557	et	4	main
vaatamise	doc_491521501850_item	2514565	et	4	main
jooksul	doc_491521501850_item	2514566	et	4	main
mul	doc_491521501850_item	2514567	et	3	main
tekkis	doc_491521501850_item	2514568	et	3	main
üks	doc_491521501850_item	2514569	et	3	main
kusagil	doc_491521501850_item	2514585	et	3	main
et	doc_491521501850_item	2514590	et	3	main
kas	doc_491521501850_item	2514594	et	3	main
koolipingist	doc_491521501850_item	2514603	et	3	main
tõustes	doc_491521501850_item	2514604	et	3	main
elud	doc_491521501850_item	2514620	et	3	main
kes	doc_491521501850_item	2514634	et	4	main
hakkavad	doc_491521501850_item	2514637	et	4	main
isamaasse	doc_491521501850_item	2514641	et	3	main
lõppuks	doc_491521501850_item	2514644	et	3	main
ka	doc_491521501850_item	2514646	et	3	main
nende	doc_491521501850_item	2514648	et	4	main
kes	doc_491521501850_item	2514651	et	4	main
põgenevad	doc_491521501850_item	2514652	et	4	main
muuta	doc_491521501850_item	2514663	et	4	main
miinused	doc_491521501851_item	2514670	et	3	main
nimed	doc_491521501851_item	2514674	et	3	main
põhineb	doc_491521501851_item	2514676	et	3	main
baseerub	doc_491521501851_item	2514683	et	3	main
esimesel	doc_491521501851_item	2514686	et	3	main
ülejäänud	doc_491521501851_item	2514693	et	4	main
osadest	doc_491521501851_item	2514694	et	3	main
materdavad	doc_491521501851_item	2514723	et	4	main
maatasa	doc_491521501851_item	2514724	et	3	main
kõnekad	doc_491521501851_item	2514728	et	3	main
umbes	doc_491521501851_item	2514731	et	4	main
tõukas	doc_491521501851_item	2514735	et	3	main
vaadatuim	doc_491521501851_item	2514742	et	4	main
eestis	doc_491521501851_item	2514744	et	3	main
on	doc_491521501851_item	2514747	et	4	main
see	doc_491521501851_item	2514748	et	3	main
ainult	doc_491521501851_item	2514749	et	4	main
on	doc_491521501851_item	2514754	et	4	main
selge	doc_491521501851_item	2514760	et	4	main
et	doc_491521501851_item	2514763	et	3	main
tähelepanu	doc_491521501851_item	2514766	et	4	main
on	doc_491521501851_item	2514775	et	4	main
oma	doc_491521501851_item	2514777	et	4	main
kahe	doc_491521501851_item	2514782	et	3	main
ajamomenti	doc_491521501851_item	2514784	et	4	main
kirjeldava	doc_491521501851_item	2514785	et	4	main
vahele	doc_491521501851_item	2514787	et	4	main
praeguses	doc_491521501851_item	2514791	et	3	main
on	doc_491521501851_item	2514826	et	4	main
aru	doc_491521501851_item	2514835	et	4	main
saada	doc_491521501851_item	2514836	et	4	main
pealetungil	doc_491521501851_item	2514840	et	4	main
lääneliku	doc_491521501851_item	2514843	et	4	main
külge	doc_491521501851_item	2514847	et	4	main
kus	doc_491521501851_item	2514849	et	3	main
sõprade	doc_491521501851_item	2514852	et	3	main
elavaks	doc_491521501851_item	2514859	et	4	main
vaenlasele	doc_491521501851_item	2514861	et	3	main
mõni	doc_491521501851_item	2514863	et	3	main
selgub	doc_491521501851_item	2514866	et	3	main
pole	doc_491521501851_item	2514870	et	3	main
kui	doc_491521501851_item	2514874	et	3	main
olukord	doc_491521501851_item	2514875	et	3	main
vist	doc_491521501851_item	2514883	et	4	main
vabadusetunnet	doc_491521501851_item	2514885	et	3	main
mitu	doc_491521501851_item	2514894	et	4	main
veel	doc_491521501851_item	2514903	et	4	main
surma	doc_491521501851_item	2514906	et	4	main
eufooriasse	doc_491521501851_item	2514911	et	3	main
kestis	doc_491521501851_item	2514921	et	4	main
arvan	doc_491521501850_item	2514544	et	3	main
oleks	doc_491521501850_item	2514547	et	3	main
poisse	doc_491521501850_item	2514550	et	4	main
selle	doc_491521501850_item	2514563	et	4	main
küsimus	doc_491521501850_item	2514570	et	4	main
oma	doc_491521501850_item	2514575	et	4	main
paneb	doc_491521501850_item	2514588	et	3	main
tuleks	doc_491521501850_item	2514592	et	4	main
võitlema	doc_491521501850_item	2514601	et	3	main
kohe	doc_491521501850_item	2514602	et	4	main
vabadusel	doc_491521501850_item	2514609	et	4	main
võib	doc_491521501850_item	2514614	et	3	main
paljude	doc_491521501850_item	2514618	et	3	main
minu	doc_491521501850_item	2514621	et	3	main
filmi	doc_491521501850_item	2514629	et	4	main
seda	doc_491521501850_item	2514630	et	3	main
suureneb	doc_491521501850_item	2514631	et	3	main
arv	doc_491521501850_item	2514632	et	3	main
inimesi	doc_491521501850_item	2514633	et	4	main
otsides	doc_491521501850_item	2514653	et	4	main
proovida	doc_491521501850_item	2514659	et	3	main
elu	doc_491521501850_item	2514661	et	4	main
paremaks	doc_491521501850_item	2514662	et	4	main
nimed	doc_491521501851_item	2514668	et	3	main
plussid	doc_491521501851_item	2514672	et	3	main
marmortahvlil	doc_491521501851_item	2514675	et	3	main
kivikase	doc_491521501851_item	2514678	et	3	main
samanimelisel	doc_491521501851_item	2514679	et	4	main
filmi	doc_491521501851_item	2514681	et	4	main
katkendeid	doc_491521501851_item	2514691	et	3	main
ja	doc_491521501851_item	2514697	et	3	main
alustaksin	doc_491521501851_item	2514700	et	3	main
muidugi	doc_491521501851_item	2514727	et	4	main
150	doc_491521501851_item	2514732	et	2	main
vaatajat	doc_491521501851_item	2514734	et	4	main
legendaarse	doc_491521501851_item	2514737	et	3	main
film	doc_491521501851_item	2514743	et	3	main
meelest	doc_491521501851_item	2514746	et	4	main
et	doc_491521501851_item	2514751	et	3	main
eesti	doc_491521501851_item	2514752	et	4	main
nii	doc_491521501851_item	2514756	et	3	main
kõneainet	doc_491521501851_item	2514758	et	3	main
ütleksin	doc_491521501851_item	2514768	et	3	main
on	doc_491521501851_item	2514771	et	4	main
aga	doc_491521501851_item	2514773	et	3	main
teostusel	doc_491521501851_item	2514774	et	4	main
oleksin	doc_491521501851_item	2514780	et	3	main
lõigu	doc_491521501851_item	2514786	et	4	main
teostuses	doc_491521501851_item	2514792	et	4	main
sattusin	doc_491521501851_item	2514827	et	3	main
algul	doc_491521501851_item	2514828	et	4	main
hetk	doc_491521501851_item	2514850	et	3	main
surma	doc_491521501851_item	2514853	et	4	main
ronivad	doc_491521501851_item	2514854	et	4	main
noored	doc_491521501851_item	2514855	et	3	main
juba	doc_491521501851_item	2514862	et	3	main
ju	doc_491521501851_item	2514867	et	3	main
ennast	doc_491521501851_item	2514886	et	4	main
sellisesse	doc_491521501851_item	2514887	et	4	main
piisaks	doc_491521501851_item	2514890	et	4	main
ainüksi	doc_491521501851_item	2514891	et	4	main
endist	doc_491521501851_item	2514895	et	4	main
ja	doc_491521501851_item	2514900	et	3	main
еlu	doc_491521501851_item	2514904	et	2	main
ja	doc_491521501851_item	2514905	et	3	main
vahel	doc_491521501851_item	2514907	et	4	main
et	doc_491521501851_item	2514908	et	3	main
tutvustust	doc_491521501851_item	2514930	et	4	main
klassitäis	doc_491521501851_item	2514934	et	4	main
jäi	doc_491521501851_item	2514937	et	3	main
neile	doc_491521501851_item	2514946	et	4	main
tuua	doc_491521501851_item	2514956	et	3	main
filmi	doc_491521501851_item	2514959	et	4	main
avastasin	doc_491521501851_item	2514961	et	3	main
nime	doc_491521501851_item	2514963	et	4	main
omanikke	doc_491521501851_item	2514965	et	3	main
poleks	doc_491521501851_item	2514972	et	3	main
neist	doc_491521501851_item	2514977	et	4	main
jäänud	doc_491521501851_item	2514979	et	4	main
muljet	doc_491521501851_item	2514981	et	3	main
näiteks	doc_491521501851_item	2514982	et	4	main
arvates	doc_491521501850_item	2514622	et	4	main
rohkem	doc_491521501850_item	2514624	et	4	main
inimesi	doc_491521501850_item	2514625	et	4	main
suhtuma	doc_491521501850_item	2514639	et	3	main
kohta	doc_491521501850_item	2514655	et	4	main
mitte	doc_491521501850_item	2514657	et	3	main
siin-	doc_491521501850_item	2514664	et	4	main
essee	doc_491521501851_item	2514667	et	4	main
versus	doc_491521501851_item	2514671	et	4	main
film	doc_491521501851_item	2514673	et	3	main
romaani	doc_491521501851_item	2514680	et	4	main
osal	doc_491521501851_item	2514687	et	3	main
kasutatud	doc_491521501851_item	2514690	et	4	main
romaani	doc_491521501851_item	2514692	et	4	main
sõjasosalenute	doc_491521501851_item	2514698	et	4	main
sellest	doc_491521501851_item	2514701	et	4	main
otsides	doc_491521501851_item	2514703	et	4	main
jutuksoleva	doc_491521501851_item	2514704	et	4	main
linateose	doc_491521501851_item	2514705	et	3	main
kohta	doc_491521501851_item	2514706	et	4	main
internetist	doc_491521501851_item	2514707	et	4	main
kommentaare	doc_491521501851_item	2514708	et	3	main
jõudsin	doc_491521501851_item	2514709	et	3	main
järeldusele	doc_491521501851_item	2514710	et	4	main
seal	doc_491521501851_item	2514712	et	4	main
arvamuse	doc_491521501851_item	2514713	et	3	main
avaldanud	doc_491521501851_item	2514714	et	4	main
et	doc_491521501851_item	2514711	et	3	main
jagunevad	doc_491521501851_item	2514715	et	4	main
kahte	doc_491521501851_item	2514716	et	4	main
leeri	doc_491521501851_item	2514717	et	4	main
ühed	doc_491521501851_item	2514718	et	3	main
kiidavad	doc_491521501851_item	2514719	et	4	main
taevani	doc_491521501851_item	2514720	et	3	main
marmortahvlil	doc_491521501851_item	2514730	et	3	main
mis	doc_491521501851_item	2514739	et	4	main
hea	doc_491521501851_item	2514750	et	4	main
mina	doc_491521501851_item	2514767	et	4	main
puudujäägid	doc_491521501851_item	2514778	et	3	main
eri	doc_491521501851_item	2514783	et	4	main
mingi	doc_491521501851_item	2514788	et	4	main
isegi	doc_491521501851_item	2514829	et	4	main
kes	doc_491521501851_item	2514837	et	4	main
on	doc_491521501851_item	2514838	et	4	main
stseen	doc_491521501851_item	2514848	et	3	main
pärast	doc_491521501851_item	2514851	et	4	main
hiljem	doc_491521501851_item	2514865	et	3	main
kadunud	doc_491521501851_item	2514872	et	4	main
milleks	doc_491521501851_item	2514879	et	4	main
sümboliseerida	doc_491521501851_item	2514884	et	4	main
kirstudes	doc_491521501851_item	2514899	et	3	main
vaagub	doc_491521501851_item	2514902	et	3	main
miinuseks	doc_491521501851_item	2514923	et	3	main
mееldе	doc_491521501851_item	2514936	et	2	main
üksik	doc_491521501851_item	2514941	et	3	main
filmi	doc_491521501851_item	2514942	et	4	main
oleks	doc_491521501851_item	2514944	et	3	main
pidanud	doc_491521501851_item	2514945	et	4	main
rohkem	doc_491521501851_item	2514949	et	4	main
eripärad	doc_491521501851_item	2514952	et	3	main
ei	doc_491521501851_item	2514967	et	4	main
neid	doc_491521501851_item	2514973	et	4	main
keda	doc_491521501851_item	2514986	et	4	main
välismaale	doc_491521501850_item	2514656	et	4	main
et	doc_491521501850_item	2514658	et	3	main
vabariigis	doc_491521501850_item	2514666	et	3	main
albert	doc_491521501851_item	2514677	et	4	main
süzee	doc_491521501851_item	2514682	et	4	main
põhiliselt	doc_491521501851_item	2514684	et	4	main
romaani	doc_491521501851_item	2514685	et	4	main
on	doc_491521501851_item	2514689	et	4	main
kokku	doc_491521501851_item	2514695	et	3	main
et	doc_491521501851_item	2514702	et	3	main
teised	doc_491521501851_item	2514722	et	4	main
on	doc_491521501851_item	2514726	et	4	main
oli	doc_491521501851_item	2514740	et	3	main
minu	doc_491521501851_item	2514745	et	3	main
linateos	doc_491521501851_item	2514753	et	4	main
palju	doc_491521501851_item	2514757	et	4	main
pakkuda	doc_491521501851_item	2514759	et	3	main
sellest	doc_491521501851_item	2514762	et	4	main
film	doc_491521501851_item	2514764	et	3	main
et	doc_491521501851_item	2514769	et	3	main
film	doc_491521501851_item	2514770	et	3	main
ka	doc_491521501851_item	2514776	et	3	main
näiteks	doc_491521501851_item	2514779	et	4	main
mа	doc_491521501851_item	2514781	et	2	main
seose	doc_491521501851_item	2514789	et	3	main
hüppab	doc_491521501851_item	2514793	et	3	main
tegevustik	doc_491521501851_item	2514794	et	3	main
ühest	doc_491521501851_item	2514796	et	4	main
aastast	doc_491521501851_item	2514797	et	4	main
järsult	doc_491521501851_item	2514795	et	4	main
teise	doc_491521501851_item	2514798	et	4	main
ja	doc_491521501851_item	2514799	et	3	main
inimene	doc_491521501851_item	2514800	et	3	main
kes	doc_491521501851_item	2514801	et	4	main
ei	doc_491521501851_item	2514802	et	4	main
ole	doc_491521501851_item	2514803	et	4	main
väga	doc_491521501851_item	2514804	et	3	main
hästi	doc_491521501851_item	2514805	et	3	main
kursis	doc_491521501851_item	2514806	et	3	main
eesti	doc_491521501851_item	2514807	et	4	main
ajalooga	doc_491521501851_item	2514808	et	4	main
võib	doc_491521501851_item	2514809	et	3	main
sattuda	doc_491521501851_item	2514810	et	3	main
segadusse	doc_491521501851_item	2514811	et	3	main
kahe	doc_491521501851_item	2514812	et	3	main
lõigu	doc_491521501851_item	2514813	et	4	main
vahel	doc_491521501851_item	2514814	et	4	main
võiks	doc_491521501851_item	2514815	et	4	main
olla	doc_491521501851_item	2514816	et	3	main
kasvõi	doc_491521501851_item	2514817	et	3	main
lühike	doc_491521501851_item	2514818	et	4	main
kokkuvõtlik	doc_491521501851_item	2514819	et	3	main
tekst	doc_491521501851_item	2514820	et	3	main
sest	doc_491521501851_item	2514832	et	4	main
kohta	doc_491521501851_item	2514822	et	4	main
veidi	doc_491521501851_item	2514830	et	3	main
segadusse	doc_491521501851_item	2514831	et	3	main
kes	doc_491521501851_item	2514841	et	4	main
taandumas	doc_491521501851_item	2514842	et	3	main
maigu	doc_491521501851_item	2514844	et	3	main
filmile	doc_491521501851_item	2514846	et	3	main
katusele	doc_491521501851_item	2514857	et	3	main
sihtmärgiks	doc_491521501851_item	2514860	et	3	main
vaenlane	doc_491521501851_item	2514869	et	3	main
turvaline	doc_491521501851_item	2514878	et	4	main
siis	doc_491521501851_item	2514880	et	3	main
taheti	doc_491521501851_item	2514882	et	3	main
olukorda	doc_491521501851_item	2514888	et	4	main
teadmisest	doc_491521501851_item	2514892	et	4	main
sõidavad	doc_491521501851_item	2514897	et	3	main
koju	doc_491521501851_item	2514898	et	3	main
mõni	doc_491521501851_item	2514901	et	3	main
mitte	doc_491521501851_item	2514909	et	3	main
pealegi	doc_491521501851_item	2514912	et	4	main
ju	doc_491521501851_item	2514914	et	3	main
vabadus	doc_491521501851_item	2514915	et	4	main
polnud	doc_491521501851_item	2514913	et	3	main
veel	doc_491521501851_item	2514916	et	4	main
päriselt	doc_491521501851_item	2514917	et	3	main
käes	doc_491521501851_item	2514918	et	4	main
sõda	doc_491521501851_item	2514919	et	4	main
alles	doc_491521501851_item	2514920	et	3	main
kindlaks	doc_491521501851_item	2514922	et	3	main
juures	doc_491521501851_item	2514925	et	4	main
loen	doc_491521501851_item	2514926	et	3	main
tegelaskujude	doc_491521501851_item	2514927	et	3	main
on	doc_491521501851_item	2514932	et	4	main
neist	doc_491521501851_item	2514938	et	4	main
mõni	doc_491521501851_item	2514940	et	3	main
algul	doc_491521501851_item	2514943	et	4	main
pühendama	doc_491521501851_item	2514948	et	3	main
ja	doc_491521501851_item	2514953	et	3	main
välja	doc_491521501851_item	2514955	et	4	main
infot	doc_491521501851_item	2514958	et	3	main
kohta	doc_491521501851_item	2514960	et	4	main
kelle	doc_491521501851_item	2514964	et	4	main
mа	doc_491521501851_item	2514966	et	2	main
enam	doc_491521501851_item	2514969	et	4	main
ekraanil	doc_491521501851_item	2514974	et	3	main
ainult	doc_491521501851_item	2514988	et	4	main
filmi	doc_491521501851_item	2514989	et	4	main
ei	doc_491521501851_item	2514993	et	4	main
oskaks	doc_491521501851_item	2514994	et	3	main
siis	doc_491521501851_item	2514995	et	3	main
see	doc_491521501851_item	2515001	et	3	main
eriti	doc_491521501851_item	2515007	et	3	main
taust	doc_491521501851_item	2515010	et	4	main
vaesest	doc_491521501851_item	2515030	et	4	main
õppisid	doc_491521501851_item	2515046	et	4	main
gümnaasiumis	doc_491521501851_item	2515047	et	3	main
need	doc_491521501851_item	2515052	et	3	main
kus	doc_491521501851_item	2515054	et	3	main
ahase	doc_491521501851_item	2515055	et	4	main
kodutare	doc_491521501851_item	2515058	et	4	main
teistest	doc_491521501851_item	2515066	et	4	main
kellegagi	doc_491521501851_item	2515071	et	4	main
küsimus	doc_491521501851_item	2515074	et	4	main
kunagi	doc_491521501851_item	2515092	et	3	main
oli	doc_491521501851_item	2515093	et	3	main
see	doc_491521501851_item	2515094	et	3	main
vabadussõjas	doc_491521501851_item	2515095	et	3	main
hukkunute	doc_491521501851_item	2515096	et	4	main
klassivenda	doc_491521501851_item	2514896	et	4	main
sattuda	doc_491521501851_item	2514910	et	3	main
peategelasteks	doc_491521501851_item	2514931	et	3	main
vaid	doc_491521501851_item	2514939	et	3	main
kõigile	doc_491521501851_item	2514947	et	4	main
ekraaniaega	doc_491521501851_item	2514950	et	4	main
mitu	doc_491521501851_item	2514962	et	4	main
suutnud	doc_491521501851_item	2514968	et	4	main
tuvastada	doc_491521501851_item	2514970	et	3	main
olnudki	doc_491521501851_item	2514976	et	4	main
võib	doc_491521501851_item	2514983	et	3	main
tuua	doc_491521501851_item	2514984	et	3	main
kohlapuu	doc_491521501851_item	2514985	et	4	main
küll	doc_491521501851_item	2514991	et	4	main
keegi	doc_491521501851_item	2514997	et	4	main
martinson	doc_491521501851_item	2514998	et	4	main
filmis	doc_491521501851_item	2515004	et	4	main
saadud	doc_491521501851_item	2515021	et	4	main
põhjal	doc_491521501851_item	2515023	et	4	main
sain	doc_491521501851_item	2515024	et	3	main
teada	doc_491521501851_item	2515025	et	3	main
et	doc_491521501851_item	2515026	et	3	main
alias	doc_491521501851_item	2515027	et	4	main
oli	doc_491521501851_item	2515028	et	3	main
filmist	doc_491521501851_item	2515032	et	4	main
mа	doc_491521501851_item	2515033	et	2	main
ainult	doc_491521501851_item	2515048	et	4	main
еlu-olu	doc_491521501851_item	2515056	et	2	main
ei	doc_491521501851_item	2515060	et	4	main
ta	doc_491521501851_item	2515065	et	4	main
võrreldagi	doc_491521501851_item	2515072	et	4	main
ei	doc_491521501851_item	2515089	et	4	main
tea	doc_491521501851_item	2515090	et	4	main
et	doc_491521501851_item	2515091	et	3	main
nimedega	doc_491521501851_item	2515097	et	3	main
tahvel	doc_491521501851_item	2515098	et	3	main
tegelikult	doc_491521501851_item	2515099	et	4	main
vene	doc_491521501851_item	2515121	et	4	main
lugu	doc_491521501851_item	2515134	et	4	main
üks	doc_491521501851_item	2515136	et	3	main
suur	doc_491521501851_item	2515137	et	3	main
kaheksakümmend	doc_491521501851_item	2515143	et	4	main
nii	doc_491521501851_item	2515149	et	3	main
puudusi	doc_491521501851_item	2515152	et	3	main
mа	doc_491521501851_item	2515157	et	2	main
ei	doc_491521501851_item	2515158	et	4	main
kes	doc_491521501851_item	2515163	et	4	main
aina	doc_491521501851_item	2515165	et	4	main
мullе	doc_491521501851_item	2515175	et	2	main
armastuse	doc_491521501851_item	2515187	et	4	main
sõjafilmi	doc_491521501851_item	2515189	et	4	main
ei	doc_491521501851_item	2515194	et	4	main
see	doc_491521501851_item	2515197	et	3	main
topitud	doc_491521501851_item	2515206	et	4	main
pealegi	doc_491521501851_item	2515222	et	4	main
vähemalt	doc_491521501851_item	2515231	et	4	main
üksi	doc_491521501851_item	2515244	et	4	main
olukorda	doc_491521501851_item	2515267	et	4	main
ju	doc_491521501851_item	2515269	et	3	main
iga	doc_491521501851_item	2515270	et	4	main
eestlane	doc_491521501851_item	2515271	et	3	main
otsustama	doc_491521501851_item	2515272	et	3	main
kas	doc_491521501851_item	2515273	et	3	main
minna	doc_491521501851_item	2515274	et	3	main
kodumaa	doc_491521501851_item	2515275	et	4	main
kelle	doc_491521501851_item	2515282	et	4	main
üldmobilisatsioon	doc_491521501851_item	2515285	et	3	main
1äbi	doc_491521501851_item	2515287	et	4	main
muutus	doc_491521501851_item	2515290	et	4	main
vabatahtlikuna	doc_491521501851_item	2515300	et	3	main
patriotismile	doc_491521501851_item	2515311	et	3	main
nii	doc_491521501851_item	2515312	et	3	main
praegu	doc_491521501851_item	2515314	et	3	main
okupeerija	doc_491521501851_item	2515328	et	4	main
uskuvad	doc_491521501851_item	2515330	et	4	main
stseen	doc_491521501851_item	2515346	et	3	main
kus	doc_491521501851_item	2515349	et	3	main
kohtab	doc_491521501851_item	2515351	et	3	main
vaenlaseks	doc_491521501851_item	2515358	et	3	main
alguses	doc_491521501851_item	2515360	et	4	main
mida	doc_491521501851_item	2515376	et	4	main
filmi	doc_491521501851_item	2514924	et	4	main
liiga	doc_491521501851_item	2514928	et	4	main
pealiskaudset	doc_491521501851_item	2514929	et	3	main
terve	doc_491521501851_item	2514933	et	4	main
poisse	doc_491521501851_item	2514935	et	4	main
et	doc_491521501851_item	2514951	et	3	main
iseloom	doc_491521501851_item	2514954	et	3	main
hiljemlugedes	doc_491521501851_item	2514957	et	4	main
nagu	doc_491521501851_item	2514971	et	3	main
üldse	doc_491521501851_item	2514975	et	3	main
ei	doc_491521501851_item	2514978	et	4	main
mingit	doc_491521501851_item	2514980	et	3	main
veel	doc_491521501851_item	2514996	et	4	main
tegelane	doc_491521501851_item	2515002	et	3	main
tegi	doc_491521501851_item	2515005	et	4	main
sotsiaalne	doc_491521501851_item	2515009	et	3	main
jäi	doc_491521501851_item	2515011	et	3	main
minu	doc_491521501851_item	2515012	et	3	main
jaoks	doc_491521501851_item	2515013	et	4	main
kõigi	doc_491521501851_item	2515014	et	4	main
puhul	doc_491521501851_item	2515015	et	4	main
arusaamatuks	doc_491521501851_item	2515016	et	4	main
alles	doc_491521501851_item	2515017	et	3	main
hiljem	doc_491521501851_item	2515018	et	3	main
järjekordselt	doc_491521501851_item	2515019	et	4	main
internetist	doc_491521501851_item	2515020	et	4	main
perest	doc_491521501851_item	2515031	et	4	main
seda	doc_491521501851_item	2515034	et	3	main
küll	doc_491521501851_item	2515035	et	4	main
välja	doc_491521501851_item	2515036	et	4	main
lugeda	doc_491521501851_item	2515037	et	3	main
kodanlaste	doc_491521501851_item	2515050	et	3	main
et	doc_491521501851_item	2515064	et	3	main
paremini	doc_491521501851_item	2515067	et	4	main
polnud	doc_491521501851_item	2515069	et	3	main
ju	doc_491521501851_item	2515070	et	3	main
kerkis	doc_491521501851_item	2515073	et	3	main
kus	doc_491521501851_item	2515124	et	3	main
ei	doc_491521501851_item	2515127	et	4	main
oluliseks	doc_491521501851_item	2515129	et	4	main
arvas	doc_491521501851_item	2515130	et	3	main
et	doc_491521501851_item	2515131	et	3	main
ei	doc_491521501851_item	2515140	et	4	main
tagasi	doc_491521501851_item	2515145	et	3	main
koolipoisid	doc_491521501851_item	2515148	et	4	main
meelestatud	doc_491521501851_item	2515151	et	4	main
leiaks	doc_491521501851_item	2515153	et	3	main
ilmselt	doc_491521501851_item	2515154	et	4	main
eestlane	doc_491521501851_item	2515162	et	3	main
midagi	doc_491521501851_item	2515168	et	4	main
külgedest	doc_491521501851_item	2515174	et	4	main
toodud	doc_491521501851_item	2515178	et	4	main
vastupidiselt	doc_491521501851_item	2515181	et	4	main
viitavad	doc_491521501851_item	2515191	et	4	main
mina	doc_491521501851_item	2515193	et	4	main
väida	doc_491521501851_item	2515195	et	4	main
osa	doc_491521501851_item	2515198	et	4	main
muudab	doc_491521501851_item	2515199	et	3	main
filmi	doc_491521501851_item	2515200	et	4	main
filmi	doc_491521501851_item	2515205	et	4	main
hukuvad	doc_491521501851_item	2515230	et	3	main
vaatajale	doc_491521501851_item	2515233	et	4	main
lõpustseenist	doc_491521501851_item	2515234	et	3	main
et	doc_491521501851_item	2515237	et	3	main
pidi	doc_491521501851_item	2515268	et	4	main
vastu	doc_491521501851_item	2515283	et	3	main
kukkus	doc_491521501851_item	2515286	et	3	main
tähtsamaks	doc_491521501851_item	2515289	et	4	main
kaitsel	doc_491521501851_item	2515299	et	3	main
eest	doc_491521501851_item	2515302	et	4	main
ei	doc_491521501851_item	2515304	et	4	main
mа	doc_491521501851_item	2514987	et	2	main
iseloomustada	doc_491521501851_item	2514992	et	4	main
huvitav	doc_491521501851_item	2514999	et	4	main
mis	doc_491521501851_item	2515006	et	4	main
oluline	doc_491521501851_item	2515008	et	4	main
pärit	doc_491521501851_item	2515029	et	3	main
ei	doc_491521501851_item	2515038	et	4	main
suutnud	doc_491521501851_item	2515039	et	4	main
ma	doc_491521501851_item	2515040	et	3	main
ei	doc_491521501851_item	2515041	et	4	main
rikaste	doc_491521501851_item	2515049	et	4	main
on	doc_491521501851_item	2515076	et	4	main
pealkiri	doc_491521501851_item	2515078	et	3	main
nimed	doc_491521501851_item	2515079	et	3	main
marmortahvlil	doc_491521501851_item	2515080	et	3	main
tahvel	doc_491521501851_item	2515084	et	3	main
aga	doc_491521501851_item	2515085	et	3	main
marmor	doc_491521501851_item	2515086	et	3	main
filmivaatajad	doc_491521501851_item	2515087	et	3	main
keelse	doc_491521501851_item	2515122	et	3	main
olid	doc_491521501851_item	2515146	et	4	main
patriotistlikult	doc_491521501851_item	2515150	et	4	main
tüüpiline	doc_491521501851_item	2515161	et	3	main
story	doc_491521501851_item	2515180	et	4	main
rõhutavad	doc_491521501851_item	2515186	et	4	main
õnneks	doc_491521501851_item	2515203	et	4	main
inimesed	doc_491521501851_item	2515221	et	3	main
lõpeb	doc_491521501851_item	2515223	et	4	main
lugu	doc_491521501851_item	2515224	et	4	main
väga	doc_491521501851_item	2515225	et	3	main
dramaatiiiselt	doc_491521501851_item	2515226	et	4	main
kõik	doc_491521501851_item	2515228	et	4	main
lohutav	doc_491521501851_item	2515235	et	4	main
ahas	doc_491521501851_item	2515238	et	4	main
hästi	doc_491521501851_item	2515245	et	3	main
välja	doc_491521501851_item	2515247	et	4	main
toodud	doc_491521501851_item	2515248	et	4	main
tegelaskujude	doc_491521501851_item	2515249	et	3	main
sisemine	doc_491521501851_item	2515250	et	3	main
heitlus	doc_491521501851_item	2515251	et	3	main
punasevõitu	doc_491521501851_item	2515254	et	4	main
ja	doc_491521501851_item	2515278	et	3	main
minna	doc_491521501851_item	2515280	et	3	main
riiklik	doc_491521501851_item	2515284	et	3	main
või	doc_491521501851_item	2515295	et	4	main
vabariigi	doc_491521501851_item	2515301	et	3	main
loota	doc_491521501851_item	2515309	et	4	main
nagu	doc_491521501851_item	2515313	et	3	main
kahest	doc_491521501851_item	2515316	et	4	main
ka	doc_491521501851_item	2515319	et	3	main
kahte	doc_491521501851_item	2515322	et	4	main
leeri	doc_491521501851_item	2515323	et	4	main
omariiklust	doc_491521501851_item	2515324	et	4	main
headusesse	doc_491521501851_item	2515329	et	4	main
absurdne	doc_491521501851_item	2515333	et	3	main
sõdima	doc_491521501851_item	2515340	et	3	main
seda	doc_491521501851_item	2515342	et	3	main
situatsiooni	doc_491521501851_item	2515343	et	4	main
kajastab	doc_491521501851_item	2515344	et	3	main
filmi	doc_491521501851_item	2515347	et	4	main
seiskamise	doc_491521501851_item	2515362	et	4	main
on	doc_491521501851_item	2515364	et	4	main
sakslaste	doc_491521501851_item	2515368	et	3	main
kus	doc_491521501851_item	2515372	et	3	main
peab	doc_491521501851_item	2515374	et	4	main
inimene	doc_491521501851_item	2515383	et	3	main
ei	doc_491521501851_item	2515384	et	4	main
põhjal	doc_491521501851_item	2514990	et	4	main
mida	doc_491521501851_item	2515000	et	4	main
seal	doc_491521501851_item	2515003	et	4	main
info	doc_491521501851_item	2515022	et	4	main
usu	doc_491521501851_item	2515042	et	4	main
et	doc_491521501851_item	2515043	et	3	main
tol	doc_491521501851_item	2515044	et	3	main
ajal	doc_491521501851_item	2515045	et	4	main
lapsed	doc_491521501851_item	2515051	et	3	main
stseenid	doc_491521501851_item	2515053	et	3	main
ja	doc_491521501851_item	2515057	et	3	main
näidati	doc_491521501851_item	2515059	et	3	main
kinnitanud	doc_491521501851_item	2515061	et	4	main
küll	doc_491521501851_item	2515062	et	4	main
väidet	doc_491521501851_item	2515063	et	3	main
elas	doc_491521501851_item	2515068	et	3	main
miks	doc_491521501851_item	2515075	et	4	main
filmi	doc_491521501851_item	2515077	et	4	main
olid	doc_491521501851_item	2515081	et	4	main
nimed	doc_491521501851_item	2515082	et	3	main
oli	doc_491521501851_item	2515083	et	3	main
kes	doc_491521501851_item	2515088	et	4	main
tartus	doc_491521501851_item	2515100	et	3	main
olemas	doc_491521501851_item	2515101	et	4	main
võivad	doc_491521501851_item	2515102	et	4	main
sattuda	doc_491521501851_item	2515103	et	3	main
segadusse	doc_491521501851_item	2515104	et	3	main
oleks	doc_491521501851_item	2515105	et	3	main
võinud	doc_491521501851_item	2515106	et	4	main
ju	doc_491521501851_item	2515107	et	3	main
linateose	doc_491521501851_item	2515108	et	3	main
lõррu	doc_491521501851_item	2515109	et	2	main
kasvõi	doc_491521501851_item	2515110	et	3	main
paar	doc_491521501851_item	2515111	et	3	main
rida	doc_491521501851_item	2515112	et	4	main
selgitavat	doc_491521501851_item	2515113	et	4	main
teksti	doc_491521501851_item	2515114	et	4	main
tekitada	doc_491521501851_item	2515115	et	3	main
sõber	doc_491521501851_item	2515116	et	3	main
kellega	doc_491521501851_item	2515117	et	3	main
kinos	doc_491521501851_item	2515118	et	3	main
käisin	doc_491521501851_item	2515119	et	3	main
lõpetas	doc_491521501851_item	2515120	et	3	main
eesti	doc_491521501851_item	2515125	et	4	main
kogu	doc_491521501851_item	2515132	et	4	main
see	doc_491521501851_item	2515133	et	3	main
on	doc_491521501851_item	2515135	et	4	main
muinasjutt	doc_491521501851_item	2515138	et	3	main
ta	doc_491521501851_item	2515139	et	4	main
aastat	doc_491521501851_item	2515144	et	3	main
veelgi	doc_491521501851_item	2515155	et	4	main
aga	doc_491521501851_item	2515156	et	3	main
teha	doc_491521501851_item	2515169	et	3	main
julgemata	doc_491521501851_item	2515170	et	4	main
edasi	doc_491521501851_item	2515171	et	3	main
linateose	doc_491521501851_item	2515172	et	3	main
positiivsetest	doc_491521501851_item	2515173	et	3	main
filmi	doc_491521501851_item	2515177	et	4	main
paljudele	doc_491521501851_item	2515182	et	3	main
avaldajatele	doc_491521501851_item	2515184	et	4	main
kes	doc_491521501851_item	2515185	et	4	main
romaanile	doc_491521501851_item	2515192	et	3	main
et	doc_491521501851_item	2515196	et	3	main
pole	doc_491521501851_item	2515204	et	3	main
kooli	doc_491521501851_item	2515123	et	4	main
ajalugu	doc_491521501851_item	2515126	et	4	main
peetud	doc_491521501851_item	2515128	et	4	main
uskunud	doc_491521501851_item	2515141	et	4	main
et	doc_491521501851_item	2515142	et	3	main
tavalised	doc_491521501851_item	2515147	et	4	main
taha	doc_491521501851_item	2515159	et	4	main
olla	doc_491521501851_item	2515160	et	3	main
teisi	doc_491521501851_item	2515164	et	4	main
kritiseerib	doc_491521501851_item	2515166	et	3	main
ise	doc_491521501851_item	2515167	et	4	main
meeldis	doc_491521501851_item	2515176	et	3	main
love	doc_491521501851_item	2515179	et	4	main
arvamuse	doc_491521501851_item	2515183	et	3	main
poogitust	doc_491521501851_item	2515188	et	4	main
ja	doc_491521501851_item	2515190	et	3	main
liiga	doc_491521501851_item	2515201	et	4	main
hollywoodlikuks	doc_491521501851_item	2515202	et	4	main
tiiüpilisi	doc_491521501851_item	2515207	et	4	main
läänelikke	doc_491521501851_item	2515208	et	4	main
pisaratest	doc_491521501851_item	2515209	et	4	main
ja	doc_491521501851_item	2515210	et	3	main
lembehetkedest	doc_491521501851_item	2515211	et	3	main
stseene	doc_491521501851_item	2515213	et	3	main
nõretavaid	doc_491521501851_item	2515212	et	4	main
lõppude	doc_491521501851_item	2515214	et	4	main
lõpuks	doc_491521501851_item	2515215	et	4	main
on	doc_491521501851_item	2515216	et	4	main
filmi	doc_491521501851_item	2515217	et	4	main
kangelasteks	doc_491521501851_item	2515218	et	4	main
ikkagi	doc_491521501851_item	2515219	et	4	main
noored	doc_491521501851_item	2515220	et	3	main
peategelased	doc_491521501851_item	2515229	et	3	main
jääb	doc_491521501851_item	2515232	et	3	main
tedmine	doc_491521501851_item	2515236	et	4	main
oli	doc_491521501851_item	2515246	et	3	main
eriti	doc_491521501851_item	2515253	et	3	main
käämeri	doc_491521501851_item	2515256	et	3	main
ja	doc_491521501851_item	2515257	et	3	main
ahase	doc_491521501851_item	2515258	et	4	main
vahelises	doc_491521501851_item	2515259	et	4	main
tänavavaidluses	doc_491521501851_item	2515260	et	3	main
see	doc_491521501851_item	2515261	et	3	main
stseen	doc_491521501851_item	2515262	et	3	main
ilmestab	doc_491521501851_item	2515263	et	3	main
hästi	doc_491521501851_item	2515264	et	3	main
tolleaegset	doc_491521501851_item	2515265	et	3	main
segast	doc_491521501851_item	2515266	et	3	main
peaaegu	doc_491521501851_item	2515227	et	3	main
pole	doc_491521501851_item	2515239	et	3	main
kogu	doc_491521501851_item	2515240	et	4	main
oma	doc_491521501851_item	2515241	et	4	main
traagikas	doc_491521501851_item	2515242	et	3	main
päris	doc_491521501851_item	2515243	et	4	main
seda	doc_491521501851_item	2515252	et	3	main
maailmavaadetega	doc_491521501851_item	2515255	et	3	main
eest	doc_491521501851_item	2515276	et	4	main
kui	doc_491521501851_item	2515279	et	3	main
seda	doc_491521501851_item	2515288	et	3	main
iga	doc_491521501851_item	2515291	et	4	main
otsus	doc_491521501851_item	2515293	et	3	main
osaleda	doc_491521501851_item	2515294	et	3	main
mitte	doc_491521501851_item	2515296	et	3	main
osaleda	doc_491521501851_item	2515297	et	3	main
kodumaa	doc_491521501851_item	2515298	et	4	main
sõdijatel	doc_491521501851_item	2515303	et	4	main
jagunes	doc_491521501851_item	2515318	et	3	main
siis	doc_491521501851_item	2515320	et	3	main
rahvas	doc_491521501851_item	2515321	et	4	main
toetavad	doc_491521501851_item	2515325	et	4	main
kodanlased	doc_491521501851_item	2515326	et	3	main
ja	doc_491521501851_item	2515327	et	3	main
kus	doc_491521501851_item	2515335	et	3	main
võis	doc_491521501851_item	2515337	et	4	main
venda	doc_491521501851_item	2515353	et	4	main
osutub	doc_491521501851_item	2515356	et	3	main
kella	doc_491521501851_item	2515361	et	4	main
stseenis	doc_491521501851_item	2515363	et	3	main
vastu	doc_491521501851_item	2515369	et	3	main
ükski	doc_491521501851_item	2515381	et	4	main
normaalne	doc_491521501851_item	2515382	et	3	main
tappa	doc_491521501851_item	2515387	et	4	main
pereliiget	doc_491521501851_item	2515389	et	3	main
hennu	doc_491521501851_item	2515392	et	4	main
käitumine	doc_491521501851_item	2515393	et	4	main
kuidas	doc_491521501851_item	2515394	et	3	main
hunt	doc_491521501851_item	2515425	et	3	main
fiimitegijatele	doc_491521501851_item	2515429	et	4	main
heidetud	doc_491521501851_item	2515432	et	4	main
kasutamist	doc_491521501851_item	2515436	et	4	main
vääratusi	doc_491521501851_item	2515441	et	4	main
ei	doc_491521501851_item	2515445	et	4	main
et	doc_491521501851_item	2515448	et	3	main
tagasi	doc_491521501851_item	2515451	et	3	main
eesmärgina	doc_491521501851_item	2515464	et	3	main
vaatajas	doc_491521501851_item	2515466	et	4	main
emotsioone	doc_491521501851_item	2515468	et	3	main
naljakas	doc_491521501851_item	2515481	et	4	main
naerda	doc_491521501851_item	2515485	et	4	main
selles	doc_491521501851_item	2515500	et	4	main
siiski	doc_491521501851_item	2515510	et	4	main
end	doc_491521501851_item	2515526	et	4	main
ja	doc_491521501851_item	2515527	et	3	main
oma	doc_491521501851_item	2515528	et	4	main
väärtushinnanguid	doc_491521501851_item	2515529	et	3	main
eelmise	doc_491521501851_item	2515530	et	3	main
sajandi	doc_491521501851_item	2515531	et	3	main
alguse	doc_491521501851_item	2515532	et	3	main
noortega	doc_491521501851_item	2515533	et	3	main
tõenäoliselt	doc_491521501851_item	2515534	et	4	main
nä	doc_491521501851_item	2515540	et	4	main
lugejani	doc_491521501851_item	2515542	et	4	main
et	doc_491521501851_item	2515553	et	3	main
on	doc_491521501851_item	2515559	et	4	main
juba	doc_491521501851_item	2515575	et	3	main
neiu	doc_491521501851_item	2515579	et	4	main
praegused	doc_491521501851_item	2515585	et	3	main
ei	doc_491521501851_item	2515587	et	4	main
maailmas	doc_491521501851_item	2515590	et	3	main
nendе	doc_491521501851_item	2515592	et	2	main
keel	doc_491521501851_item	2515621	et	4	main
vahepeal	doc_491521501851_item	2515624	et	3	main
inimene	doc_491521501851_item	2515634	et	3	main
tsivilisatsioonide	doc_491521501851_item	2515636	et	3	main
muutunud	doc_491521501851_item	2515640	et	4	main
ta	doc_491521501851_item	2515645	et	4	main
masinad	doc_491521501851_item	2515647	et	3	main
teise	doc_491521501851_item	2515649	et	4	main
рuudub	doc_491521501851_item	2515652	et	2	main
lahingusse	doc_491521501851_item	2515277	et	4	main
siis	doc_491521501851_item	2515281	et	3	main
mehe	doc_491521501851_item	2515292	et	3	main
muud	doc_491521501851_item	2515306	et	4	main
ü1е	doc_491521501851_item	2515307	et	2	main
kui	doc_491521501851_item	2515308	et	3	main
eestist	doc_491521501851_item	2515317	et	3	main
jäänud	doc_491521501851_item	2515305	et	4	main
rahva	doc_491521501851_item	2515310	et	3	main
räägitakse	doc_491521501851_item	2515315	et	3	main
kehvikud	doc_491521501851_item	2515331	et	3	main
olukord	doc_491521501851_item	2515334	et	3	main
vend	doc_491521501851_item	2515336	et	3	main
venna	doc_491521501851_item	2515338	et	3	main
vastu	doc_491521501851_item	2515339	et	3	main
sattuda	doc_491521501851_item	2515341	et	3	main
lõpuosast	doc_491521501851_item	2515348	et	4	main
oma	doc_491521501851_item	2515352	et	4	main
antsu	doc_491521501851_item	2515354	et	4	main
meelestatud	doc_491521501851_item	2515370	et	4	main
henn	doc_491521501851_item	2515373	et	4	main
valima	doc_491521501851_item	2515375	et	3	main
teha	doc_491521501851_item	2515378	et	3	main
on	doc_491521501851_item	2515379	et	4	main
dramaatiline	doc_491521501851_item	2515380	et	3	main
oma	doc_491521501851_item	2515388	et	4	main
samas	doc_491521501851_item	2515390	et	4	main
on	doc_491521501851_item	2515430	et	4	main
sobimatute	doc_491521501851_item	2515434	et	4	main
et	doc_491521501851_item	2515439	et	3	main
hästi	doc_491521501851_item	2515444	et	3	main
uskuda	doc_491521501851_item	2515447	et	3	main
kinni	doc_491521501851_item	2515455	et	3	main
oma	doc_491521501851_item	2515463	et	4	main
mingeidki	doc_491521501851_item	2515467	et	3	main
poleks	doc_491521501851_item	2515471	et	3	main
terve	doc_491521501851_item	2515482	et	4	main
saal	doc_491521501851_item	2515483	et	3	main
näe	doc_491521501851_item	2515499	et	4	main
on	doc_491521501851_item	2515505	et	4	main
tegu	doc_491521501851_item	2515509	et	4	main
teos	doc_491521501851_item	2515537	et	4	main
vaatajani	doc_491521501851_item	2515545	et	4	main
raamatu	doc_491521501851_item	2515546	et	4	main
vaja	doc_491521501851_item	2515549	et	4	main
rakendada	doc_491521501851_item	2515550	et	3	main
filmi	doc_491521501851_item	2515557	et	4	main
lihtsam	doc_491521501851_item	2515561	et	4	main
see	doc_491521501851_item	2515563	et	3	main
filmi	doc_491521501851_item	2515567	et	4	main
teinud	doc_491521501851_item	2515576	et	4	main
et	doc_491521501851_item	2515584	et	3	main
valitses	doc_491521501851_item	2515332	et	3	main
hästi	doc_491521501851_item	2515345	et	3	main
henn	doc_491521501851_item	2515350	et	4	main
kes	doc_491521501851_item	2515355	et	4	main
ootamatult	doc_491521501851_item	2515357	et	4	main
filmi	doc_491521501851_item	2515359	et	4	main
nad	doc_491521501851_item	2515365	et	3	main
alles	doc_491521501851_item	2515366	et	3	main
üksmeelselt	doc_491521501851_item	2515367	et	4	main
hetk	doc_491521501851_item	2515371	et	3	main
suuda	doc_491521501851_item	2515385	et	4	main
arrmutult	doc_491521501851_item	2515386	et	4	main
sõda	doc_491521501851_item	2515395	et	4	main
inimesi	doc_491521501851_item	2515396	et	4	main
julmaks	doc_491521501851_item	2515397	et	3	main
muudab	doc_491521501851_item	2515398	et	3	main
kes	doc_491521501851_item	2515399	et	4	main
teab	doc_491521501851_item	2515400	et	3	main
võib	doc_491521501851_item	2515401	et	3	main
olla	doc_491521501851_item	2515402	et	3	main
oleks	doc_491521501851_item	2515403	et	3	main
ants	doc_491521501851_item	2515404	et	4	main
hennu	doc_491521501851_item	2515405	et	4	main
vennalikkust	doc_491521501851_item	2515406	et	4	main
ära	doc_491521501851_item	2515407	et	4	main
kasutades	doc_491521501851_item	2515408	et	3	main
ise	doc_491521501851_item	2515409	et	4	main
talle	doc_491521501851_item	2515410	et	4	main
otsa	doc_491521501851_item	2515411	et	4	main
реаlе	doc_491521501851_item	2515412	et	2	main
teinud	doc_491521501851_item	2515413	et	4	main
мuud	doc_491521501851_item	2515414	et	2	main
võimalust	doc_491521501851_item	2515415	et	3	main
ei	doc_491521501851_item	2515416	et	4	main
jäänud	doc_491521501851_item	2515417	et	4	main
kui	doc_491521501851_item	2515418	et	3	main
ants	doc_491521501851_item	2515419	et	4	main
kahjutuks	doc_491521501851_item	2515420	et	4	main
teha	doc_491521501851_item	2515421	et	3	main
inimesele	doc_491521501851_item	2515424	et	3	main
seda	doc_491521501851_item	2515426	et	3	main
fraaside	doc_491521501851_item	2515435	et	3	main
väikeseid	doc_491521501851_item	2515440	et	4	main
esineb	doc_491521501851_item	2515442	et	3	main
ega	doc_491521501851_item	2515443	et	3	main
tahaks	doc_491521501851_item	2515446	et	3	main
kaheksakümmend	doc_491521501851_item	2515449	et	4	main
mõni	doc_491521501851_item	2515452	et	3	main
pani	doc_491521501851_item	2515456	et	4	main
on	doc_491521501851_item	2515458	et	4	main
nüganen	doc_491521501851_item	2515459	et	4	main
ise	doc_491521501851_item	2515460	et	4	main
tekitada	doc_491521501851_item	2515465	et	3	main
meelest	doc_491521501851_item	2515470	et	4	main
sellesse	doc_491521501851_item	2515472	et	4	main
seika	doc_491521501851_item	2515473	et	4	main
edasi	doc_491521501851_item	2515377	et	3	main
näitas	doc_491521501851_item	2515391	et	3	main
on	doc_491521501851_item	2515423	et	4	main
eriti	doc_491521501851_item	2515427	et	3	main
olen	doc_491521501851_item	2515437	et	3	main
nõus	doc_491521501851_item	2515438	et	4	main
jooksu	doc_491521501851_item	2515454	et	4	main
nimetanud	doc_491521501851_item	2515461	et	4	main
paremini	doc_491521501851_item	2515478	et	4	main
tõesti	doc_491521501851_item	2515479	et	3	main
oli	doc_491521501851_item	2515480	et	3	main
ühes	doc_491521501851_item	2515495	et	4	main
sellega	doc_491521501851_item	2515496	et	3	main
ma	doc_491521501851_item	2515497	et	3	main
ei	doc_491521501851_item	2515498	et	4	main
kui	doc_491521501851_item	2515503	et	3	main
inimestel	doc_491521501851_item	2515504	et	3	main
meelelahutusega	doc_491521501851_item	2515511	et	4	main
saavad	doc_491521501851_item	2515522	et	4	main
kujul	doc_491521501851_item	2515539	et	4	main
kui	doc_491521501851_item	2515543	et	3	main
rohkem	doc_491521501851_item	2515551	et	4	main
samastada	doc_491521501851_item	2515554	et	3	main
seda	doc_491521501851_item	2515560	et	3	main
teha	doc_491521501851_item	2515562	et	3	main
võiks	doc_491521501851_item	2515564	et	4	main
üks	doc_491521501851_item	2515566	et	3	main
eesmärkidest	doc_491521501851_item	2515568	et	3	main
muide	doc_491521501851_item	2515569	et	3	main
mõned	doc_491521501851_item	2515570	et	3	main
gümnasistid	doc_491521501851_item	2515571	et	3	main
on	doc_491521501851_item	2515572	et	4	main
taolisi	doc_491521501851_item	2515573	et	3	main
võrdlusi	doc_491521501851_item	2515574	et	3	main
ühe	doc_491521501851_item	2515578	et	4	main
kirjutist	doc_491521501851_item	2515580	et	4	main
lugedes	doc_491521501851_item	2515581	et	3	main
teismelised	doc_491521501851_item	2515586	et	3	main
üldiselt	doc_491521501851_item	2515627	et	4	main
olen	doc_491521501851_item	2515628	et	3	main
arvamusel	doc_491521501851_item	2515629	et	3	main
et	doc_491521501851_item	2515630	et	3	main
oma	doc_491521501851_item	2515631	et	4	main
pole	doc_491521501851_item	2515633	et	3	main
on	doc_491521501851_item	2515644	et	4	main
neiti	doc_491521501851_item	2515650	et	4	main
on	doc_491521501851_item	2515686	et	4	main
ju	doc_491521501851_item	2515687	et	3	main
igavates	doc_491521501851_item	2515693	et	4	main
olid	doc_491521501851_item	2515696	et	4	main
filmiski	doc_491521501851_item	2515698	et	4	main
kodumaa	doc_491521501851_item	2515700	et	4	main
pealehakkamist	doc_491521501851_item	2515704	et	3	main
kiiresti	doc_491521501851_item	2515711	et	3	main
ideaalid	doc_491521501851_item	2515713	et	3	main
kokkupuudet	doc_491521501851_item	2515716	et	3	main
õuduste	doc_491521501851_item	2515718	et	3	main
arvan	doc_491521501851_item	2515722	et	3	main
samasugune	doc_491521501851_item	2515724	et	3	main
toosama	doc_491521501851_item	2515730	et	4	main
et	doc_491521501851_item	2515734	et	3	main
telcita	doc_491521501851_item	2515738	et	4	main
koolilastes	doc_491521501851_item	2515746	et	4	main
vastumeelt	doc_491521501851_item	2515749	et	3	main
lugemise	doc_491521501851_item	2515751	et	4	main
arvab	doc_491521501851_item	2515754	et	3	main
on	doc_491521501851_item	2515758	et	4	main
võrrelda	doc_491521501851_item	2515770	et	4	main
mõte	doc_491521501851_item	2515781	et	3	main
mina	doc_491521501851_item	2515789	et	4	main
pidin	doc_491521501851_item	2515790	et	3	main
põhikoolis	doc_491521501851_item	2515791	et	4	main
inimene	doc_491521501851_item	2515422	et	3	main
sõjas	doc_491521501851_item	2515428	et	3	main
ette	doc_491521501851_item	2515431	et	4	main
kontekstiga	doc_491521501851_item	2515433	et	3	main
aastat	doc_491521501851_item	2515450	et	3	main
noor	doc_491521501851_item	2515453	et	3	main
samas	doc_491521501851_item	2515457	et	4	main
ühe	doc_491521501851_item	2515462	et	4	main
minu	doc_491521501851_item	2515469	et	3	main
sobinud	doc_491521501851_item	2515474	et	4	main
ükski	doc_491521501851_item	2515475	et	4	main
teine	doc_491521501851_item	2515476	et	3	main
fraas	doc_491521501851_item	2515477	et	3	main
midagi	doc_491521501851_item	2515486	et	4	main
parata	doc_491521501851_item	2515488	et	3	main
meie	doc_491521501851_item	2515490	et	4	main
ümber	doc_491521501851_item	2515491	et	3	main
muutub	doc_491521501851_item	2515492	et	3	main
kiiresti	doc_491521501851_item	2515493	et	3	main
keel	doc_491521501851_item	2515494	et	4	main
midagi	doc_491521501851_item	2515501	et	4	main
lõbus	doc_491521501851_item	2515506	et	4	main
on	doc_491521501851_item	2515508	et	4	main
film	doc_491521501851_item	2515512	et	3	main
rahvale	doc_491521501851_item	2515514	et	3	main
üksikutele	doc_491521501851_item	2515516	et	4	main
nostalgiat	doc_491521501851_item	2515517	et	3	main
tagaigatsevatele	doc_491521501851_item	2515518	et	3	main
kriitikutele	doc_491521501851_item	2515519	et	3	main
läbi	doc_491521501851_item	2515520	et	4	main
filmi	doc_491521501851_item	2515521	et	4	main
tänapäeva	doc_491521501851_item	2515523	et	4	main
teismelised	doc_491521501851_item	2515524	et	3	main
võrrelda	doc_491521501851_item	2515525	et	4	main
ei	doc_491521501851_item	2515535	et	4	main
jõua	doc_491521501851_item	2515536	et	4	main
otseselt	doc_491521501851_item	2515541	et	4	main
film	doc_491521501851_item	2515544	et	3	main
lugemisel	doc_491521501851_item	2515547	et	4	main
on	doc_491521501851_item	2515548	et	4	main
kujutlusvõimet	doc_491521501851_item	2515552	et	3	main
end	doc_491521501851_item	2515555	et	4	main
tunne	doc_491521501851_item	2515583	et	4	main
samas	doc_491521501851_item	2515589	et	4	main
oma	doc_491521501851_item	2515594	et	4	main
on	doc_491521501851_item	2515622	et	4	main
tõesti	doc_491521501851_item	2515623	et	3	main
muutunud	doc_491521501851_item	2515625	et	4	main
kuid	doc_491521501851_item	2515626	et	4	main
tekkest	doc_491521501851_item	2515637	et	4	main
alates	doc_491521501851_item	2515638	et	3	main
eriti	doc_491521501851_item	2515639	et	3	main
arvates	doc_491521501851_item	2515651	et	4	main
praegustel	doc_491521501851_item	2515653	et	3	main
noortel	doc_491521501851_item	2515654	et	3	main
tolle	doc_491521501851_item	2515672	et	4	main
puudus	doc_491521501851_item	2515675	et	4	main
ettekujutus	doc_491521501851_item	2515677	et	4	main
nii	doc_491521501851_item	2515679	et	3	main
ju	doc_491521501851_item	2515697	et	3	main
noored	doc_491521501851_item	2515699	et	3	main
kaitsmisest	doc_491521501851_item	2515701	et	4	main
vaimustuses	doc_491521501851_item	2515702	et	4	main
tahtmist	doc_491521501851_item	2515705	et	4	main
saada	doc_491521501851_item	2515707	et	4	main
hiljeni	doc_491521501851_item	2515708	et	4	main
kõik	doc_491521501851_item	2515712	et	4	main
sõja	doc_491521501851_item	2515717	et	3	main
ja	doc_491521501851_item	2515719	et	3	main
et	doc_491521501851_item	2515723	et	3	main
filmile	doc_491521501851_item	2515736	et	3	main
kohustusliku	doc_491521501851_item	2515740	et	3	main
hulka	doc_491521501851_item	2515742	et	4	main
alateadlikku	doc_491521501851_item	2515748	et	4	main
suhtes	doc_491521501851_item	2515752	et	4	main
noortes	doc_491521501851_item	2515756	et	3	main
olla	doc_491521501851_item	2515778	et	3	main
rõkkas	doc_491521501851_item	2515484	et	3	main
pole	doc_491521501851_item	2515487	et	3	main
maailm	doc_491521501851_item	2515489	et	3	main
halba	doc_491521501851_item	2515502	et	4	main
eelkõige	doc_491521501851_item	2515507	et	3	main
tehti	doc_491521501851_item	2515513	et	3	main
mitte	doc_491521501851_item	2515515	et	3	main
raarnatu	doc_491521501851_item	2515538	et	4	main
tegelasega	doc_491521501851_item	2515556	et	3	main
kaudu	doc_491521501851_item	2515558	et	3	main
olla	doc_491521501851_item	2515565	et	3	main
ja	doc_491521501851_item	2515577	et	3	main
tekkis	doc_491521501851_item	2515582	et	3	main
еlа	doc_491521501851_item	2515588	et	2	main
kus	doc_491521501851_item	2515591	et	3	main
esiisad	doc_491521501851_item	2515593	et	3	main
nooruspõlves	doc_491521501851_item	2515595	et	4	main
tütarlaps	doc_491521501851_item	2515596	et	4	main
arvas	doc_491521501851_item	2515597	et	3	main
et	doc_491521501851_item	2515598	et	3	main
tõenäoliselt	doc_491521501851_item	2515599	et	4	main
ei	doc_491521501851_item	2515600	et	4	main
leiaks	doc_491521501851_item	2515601	et	3	main
henn	doc_491521501851_item	2515602	et	4	main
alias	doc_491521501851_item	2515603	et	4	main
21	doc_491521501851_item	2515604	et	2	main
sajandi	doc_491521501851_item	2515605	et	3	main
teismelistega	doc_491521501851_item	2515606	et	3	main
ühist	doc_491521501851_item	2515607	et	3	main
keelt	doc_491521501851_item	2515608	et	4	main
kartа	doc_491521501851_item	2515609	et	2	main
on	doc_491521501851_item	2515610	et	4	main
et	doc_491521501851_item	2515611	et	3	main
ültsе	doc_491521501851_item	2515612	et	2	main
keele	doc_491521501851_item	2515613	et	4	main
leidmine	doc_491521501851_item	2515614	et	4	main
tekitaks	doc_491521501851_item	2515615	et	4	main
sõna	doc_491521501851_item	2515616	et	4	main
otses	doc_491521501851_item	2515617	et	3	main
mõttes	doc_491521501851_item	2515618	et	3	main
рrоblееmе	doc_491521501851_item	2515619	et	2	main
eesti	doc_491521501851_item	2515620	et	4	main
olemuselt	doc_491521501851_item	2515632	et	3	main
esimeste	doc_491521501851_item	2515635	et	4	main
asemele	doc_491521501851_item	2515643	et	4	main
patriotism	doc_491521501851_item	2515655	et	3	main
on	doc_491521501851_item	2515680	et	4	main
see	doc_491521501851_item	2515681	et	3	main
ka	doc_491521501851_item	2515682	et	3	main
tänapäeva	doc_491521501851_item	2515683	et	4	main
teismelistega	doc_491521501851_item	2515684	et	3	main
sõdida	doc_491521501851_item	2515685	et	3	main
huvitavam	doc_491521501851_item	2515689	et	4	main
kaupa	doc_491521501851_item	2515692	et	4	main
istuda	doc_491521501851_item	2515695	et	3	main
mõjuga	doc_491521501851_item	2515721	et	3	main
psühholoogiline	doc_491521501851_item	2515725	et	4	main
toimiks	doc_491521501851_item	2515727	et	4	main
väitis	doc_491521501851_item	2515732	et	3	main
ka	doc_491521501851_item	2515733	et	3	main
ei	doc_491521501851_item	2515737	et	4	main
romaan	doc_491521501851_item	2515745	et	3	main
ainult	doc_491521501851_item	2515641	et	4	main
orjade	doc_491521501851_item	2515642	et	3	main
vahepeal	doc_491521501851_item	2515646	et	3	main
leiutanud	doc_491521501851_item	2515648	et	4	main
olemise	doc_491521501851_item	2515658	et	4	main
üle	doc_491521501851_item	2515659	et	3	main
nad	doc_491521501851_item	2515660	et	3	main
ei	doc_491521501851_item	2515661	et	4	main
oleks	doc_491521501851_item	2515662	et	3	main
nõus	doc_491521501851_item	2515663	et	4	main
vabatahtlikena	doc_491521501851_item	2515664	et	3	main
sõtta	doc_491521501851_item	2515665	et	3	main
minema	doc_491521501851_item	2515666	et	3	main
mina	doc_491521501851_item	2515667	et	4	main
arvan	doc_491521501851_item	2515668	et	3	main
vastupidi	doc_491521501851_item	2515669	et	3	main
nii	doc_491521501851_item	2515670	et	3	main
nagu	doc_491521501851_item	2515671	et	3	main
uhkus	doc_491521501851_item	2515656	et	4	main
eestlaseks	doc_491521501851_item	2515657	et	3	main
noortel	doc_491521501851_item	2515674	et	3	main
adekvaatne	doc_491521501851_item	2515676	et	3	main
sõjast	doc_491521501851_item	2515678	et	3	main
hulga	doc_491521501851_item	2515688	et	4	main
päevade	doc_491521501851_item	2515691	et	3	main
tundides	doc_491521501851_item	2515694	et	3	main
täis	doc_491521501851_item	2515703	et	4	main
kangelasteks	doc_491521501851_item	2515706	et	4	main
lahinguväljal	doc_491521501851_item	2515709	et	3	main
reaalset	doc_491521501851_item	2515715	et	3	main
laastava	doc_491521501851_item	2515720	et	4	main
faktor	doc_491521501851_item	2515726	et	3	main
ka	doc_491521501851_item	2515728	et	3	main
põhikooli	doc_491521501851_item	2515739	et	4	main
kirjanduse	doc_491521501851_item	2515741	et	3	main
kuuluv	doc_491521501851_item	2515743	et	4	main
kivikase	doc_491521501851_item	2515744	et	3	main
enam	doc_491521501851_item	2515747	et	4	main
neid	doc_491521501851_item	2515767	et	4	main
kahte	doc_491521501851_item	2515768	et	4	main
omavahel	doc_491521501851_item	2515769	et	3	main
seegi	doc_491521501851_item	2515773	et	4	main
üks	doc_491521501851_item	2515775	et	3	main
filmi	doc_491521501851_item	2515776	et	4	main
eesmärkidest	doc_491521501851_item	2515777	et	3	main
tutvust	doc_491521501851_item	2515783	et	3	main
juba	doc_491521501851_item	2515785	et	3	main
et	doc_491521501851_item	2515788	et	3	main
igasugu	doc_491521501851_item	2515794	et	3	main
lugema	doc_491521501851_item	2515796	et	4	main
registreerimaraamat	doc_491521501851_item	2515821	et	4	main
küll	doc_491521501851_item	2515823	et	4	main
mееl	doc_491521501851_item	2515830	et	2	main
rahva	doc_491521501851_item	2515850	et	3	main
kivikase	doc_491521501851_item	2515853	et	3	main
romaani	doc_491521501851_item	2515854	et	4	main
vabadussõja	doc_491521501851_item	2515855	et	3	main
ja	doc_491521501851_item	2515856	et	3	main
üldse	doc_491521501851_item	2515857	et	3	main
eesti	doc_491521501851_item	2515858	et	4	main
teame	doc_491521501851_item	2515865	et	3	main
oma	doc_491521501851_item	2515866	et	4	main
ajaloost	doc_491521501851_item	2515868	et	4	main
häbiväärselt	doc_491521501851_item	2515869	et	4	main
tõsta	doc_491521501851_item	2515876	et	4	main
ei	doc_491521501851_item	2515882	et	4	main
aga	doc_491521501851_item	2515890	et	3	main
eespool	doc_491521501851_item	2515894	et	3	main
ülе	doc_491521501851_item	2515903	et	2	main
aja	doc_491521501851_item	2515673	et	4	main
kui	doc_491521501851_item	2515690	et	3	main
purunesid	doc_491521501851_item	2515710	et	4	main
pärast	doc_491521501851_item	2515714	et	4	main
tänapäeval	doc_491521501851_item	2515729	et	3	main
neiu	doc_491521501851_item	2515731	et	4	main
tänu	doc_491521501851_item	2515735	et	4	main
teose	doc_491521501851_item	2515750	et	3	main
та	doc_491521501851_item	2515753	et	2	main
analüüsida	doc_491521501851_item	2515772	et	3	main
minulgi	doc_491521501851_item	2515779	et	3	main
kohustuslikus	doc_491521501851_item	2515792	et	4	main
huvi	doc_491521501851_item	2515798	et	4	main
võrrelda	doc_491521501851_item	2515799	et	4	main
kümme	doc_491521501851_item	2515800	et	3	main
aastat	doc_491521501851_item	2515801	et	3	main
koolis	doc_491521501851_item	2515803	et	4	main
loetavat	doc_491521501851_item	2515804	et	4	main
kirjandust	doc_491521501851_item	2515805	et	3	main
hiljem	doc_491521501851_item	2515802	et	3	main
tolleaegsega	doc_491521501851_item	2515806	et	3	main
mini	doc_491521501851_item	2515808	et	4	main
ootustele	doc_491521501851_item	2515809	et	3	main
vastupidiselt	doc_491521501851_item	2515807	et	4	main
osutus	doc_491521501851_item	2515810	et	4	main
raamat	doc_491521501851_item	2515811	et	3	main
nä	doc_491521501851_item	2515812	et	4	main
рориlааrseks	doc_491521501851_item	2515813	et	2	main
et	doc_491521501851_item	2515814	et	3	main
raamatukogust	doc_491521501851_item	2515815	et	4	main
laenutamiseks	doc_491521501851_item	2515816	et	4	main
peab	doc_491521501851_item	2515817	et	4	main
end	doc_491521501851_item	2515818	et	4	main
lausa	doc_491521501851_item	2515819	et	4	main
järjekorda	doc_491521501851_item	2515820	et	4	main
on	doc_491521501851_item	2515827	et	4	main
mul	doc_491521501851_item	2515828	et	3	main
on	doc_491521501851_item	2515836	et	4	main
tuletatud	doc_491521501851_item	2515840	et	4	main
peakski	doc_491521501851_item	2515843	et	4	main
ainult	doc_491521501851_item	2515846	et	4	main
mе	doc_491521501851_item	2515864	et	2	main
tegelikkuses	doc_491521501851_item	2515879	et	4	main
mа	doc_491521501851_item	2515880	et	2	main
muidugi	doc_491521501851_item	2515881	et	4	main
kõigist	doc_491521501851_item	2515885	et	4	main
siiski	doc_491521501851_item	2515891	et	4	main
nagu	doc_491521501851_item	2515892	et	3	main
juba	doc_491521501851_item	2515893	et	3	main
mainitud	doc_491521501851_item	2515895	et	4	main
on	doc_491521501851_item	2515896	et	4	main
arutеlu	doc_491521501851_item	2515897	et	2	main
nüganen	doc_491521501851_item	2515922	et	4	main
naerda	doc_491521501851_item	2515930	et	4	main
kui	doc_491521501851_item	2515931	et	3	main
silmi	doc_491521501851_item	2515932	et	4	main
pühkida	doc_491521501851_item	2515933	et	3	main
ja	doc_491521501851_item	2515934	et	3	main
mõtlema	doc_491521501851_item	2515935	et	3	main
vaatamas	doc_491521501851_item	2515941	et	3	main
film	doc_491521501851_item	2515947	et	3	main
akivikase	doc_491521501852_item	2515958	et	4	main
et	doc_491521501851_item	2515755	et	3	main
kes	doc_491521501851_item	2515757	et	4	main
filmi	doc_491521501851_item	2515759	et	4	main
näinud	doc_491521501851_item	2515760	et	4	main
tärkab	doc_491521501851_item	2515761	et	3	main
soov	doc_491521501851_item	2515762	et	3	main
raamat	doc_491521501851_item	2515763	et	3	main
ü1е	doc_491521501851_item	2515764	et	2	main
lugeda	doc_491521501851_item	2515765	et	3	main
ja	doc_491521501851_item	2515766	et	3	main
ja	doc_491521501851_item	2515771	et	3	main
võiks	doc_491521501851_item	2515774	et	4	main
tekkis	doc_491521501851_item	2515780	et	3	main
raamatuga	doc_491521501851_item	2515782	et	4	main
teha	doc_491521501851_item	2515784	et	3	main
ainuüksi	doc_491521501851_item	2515786	et	3	main
põhjusel	doc_491521501851_item	2515787	et	3	main
korras	doc_491521501851_item	2515793	et	4	main
tekkis	doc_491521501851_item	2515797	et	3	main
hetkel	doc_491521501851_item	2515824	et	4	main
ühte	doc_491521501851_item	2515832	et	4	main
meie	doc_491521501851_item	2515833	et	4	main
rahvale	doc_491521501851_item	2515838	et	3	main
teismeliste	doc_491521501851_item	2515847	et	3	main
мullе	doc_491521501851_item	2515861	et	2	main
filmi	doc_491521501851_item	2515873	et	4	main
vaatamine	doc_491521501851_item	2515874	et	4	main
usu	doc_491521501851_item	2515883	et	4	main
linateose	doc_491521501851_item	2515898	et	3	main
nä	doc_491521501851_item	2515928	et	4	main
käisin	doc_491521501851_item	2515942	et	3	main
et	doc_491521501851_item	2515945	et	3	main
ei	doc_491521501851_item	2515948	et	4	main
marmortahvlil	doc_491521501852_item	2515960	et	3	main
selle	doc_491521501852_item	2515962	et	4	main
raamatu	doc_491521501852_item	2515963	et	4	main
sündmusi	doc_491521501852_item	2515970	et	3	main
mis	doc_491521501852_item	2515971	et	4	main
toimusid	doc_491521501852_item	2515972	et	4	main
eestis	doc_491521501852_item	2515973	et	3	main
i	doc_491521501852_item	2515974	et	4	main
maailmasõja	doc_491521501852_item	2515975	et	3	main
kuin	doc_491521501852_item	2515982	et	4	main
venemaa	doc_491521501852_item	2515987	et	4	main
poolt	doc_491521501852_item	2515988	et	4	main
näitab	doc_491521501852_item	2515998	et	3	main
hoiduvad	doc_491521501852_item	2516000	et	4	main
meile	doc_491521501852_item	2516012	et	4	main
meie	doc_491521501852_item	2516014	et	4	main
mis	doc_491521501852_item	2516018	et	4	main
vabadussõja	doc_491521501852_item	2516029	et	3	main
seepärast	doc_491521501852_item	2516040	et	3	main
teose	doc_491521501852_item	2516042	et	3	main
taustast	doc_491521501852_item	2516044	et	4	main
vabadussõja	doc_491521501852_item	2516047	et	3	main
tartus	doc_491521501852_item	2516049	et	3	main
iga	doc_491521501852_item	2516071	et	4	main
tähendust	doc_491521501852_item	2516082	et	4	main
rahva	doc_491521501852_item	2516084	et	3	main
romaan	doc_491521501852_item	2516092	et	3	main
milles	doc_491521501852_item	2516095	et	3	main
isiklike	doc_491521501852_item	2516098	et	3	main
võitlust	doc_491521501852_item	2516108	et	3	main
mааlе	doc_491521501852_item	2516111	et	2	main
vaenlasega	doc_491521501852_item	2516113	et	3	main
marmortahvlil	doc_491521501852_item	2516118	et	3	main
muutus	doc_491521501852_item	2516125	et	4	main
tollastest	doc_491521501852_item	2516135	et	3	main
sündmustest	doc_491521501852_item	2516136	et	4	main
ning	doc_491521501852_item	2516137	et	3	main
oli	doc_491521501852_item	2516138	et	3	main
kirjutatud	doc_491521501852_item	2516139	et	4	main
sel	doc_491521501852_item	2516140	et	3	main
ei	doc_491521501852_item	2516144	et	4	main
arvata	doc_491521501852_item	2516146	et	4	main
et	doc_491521501852_item	2516147	et	3	main
eesti	doc_491521501852_item	2516148	et	4	main
riigil	doc_491521501852_item	2516149	et	3	main
tulevad	doc_491521501852_item	2516150	et	4	main
kui	doc_491521501852_item	2516154	et	3	main
raamatus	doc_491521501852_item	2516157	et	4	main
jama	doc_491521501851_item	2515795	et	4	main
lugemata	doc_491521501851_item	2515825	et	4	main
siiski	doc_491521501851_item	2515826	et	4	main
oma	doc_491521501851_item	2515834	et	4	main
kirjanikest	doc_491521501851_item	2515835	et	3	main
оlеmа	doc_491521501851_item	2515844	et	2	main
vaid	doc_491521501851_item	2515848	et	3	main
kogu	doc_491521501851_item	2515849	et	4	main
huvi	doc_491521501851_item	2515851	et	4	main
äratamine	doc_491521501851_item	2515852	et	4	main
et	doc_491521501851_item	2515863	et	3	main
oluliselt	doc_491521501851_item	2515875	et	4	main
et	doc_491521501851_item	2515884	et	3	main
kinoskäinutest	doc_491521501851_item	2515886	et	4	main
saavad	doc_491521501851_item	2515887	et	4	main
kõvad	doc_491521501851_item	2515888	et	3	main
patrioodid	doc_491521501851_item	2515889	et	3	main
ja	doc_491521501851_item	2515899	et	3	main
käsitletava	doc_491521501851_item	2515901	et	4	main
elav	doc_491521501851_item	2515904	et	4	main
on	doc_491521501851_item	2515906	et	4	main
hea	doc_491521501851_item	2515908	et	4	main
märk	doc_491521501851_item	2515909	et	3	main
südamest	doc_491521501851_item	2515929	et	4	main
kahetse	doc_491521501851_item	2515939	et	4	main
loodan	doc_491521501851_item	2515944	et	3	main
jää	doc_491521501851_item	2515949	et	4	main
erandiks	doc_491521501851_item	2515950	et	4	main
reeglite	doc_491521501851_item	2515951	et	3	main
filmi	doc_491521501852_item	2515965	et	4	main
nimed	doc_491521501852_item	2515966	et	3	main
marmortahvlil	doc_491521501852_item	2515967	et	3	main
ja	doc_491521501852_item	2515968	et	3	main
lõppemisega	doc_491521501852_item	2515976	et	4	main
saksa	doc_491521501852_item	2515980	et	4	main
eesti	doc_491521501852_item	2515983	et	4	main
okupeerimiseni	doc_491521501852_item	2515985	et	4	main
inimestes	doc_491521501852_item	2515999	et	3	main
kõrvale	doc_491521501852_item	2516001	et	4	main
põhinev	doc_491521501852_item	2516008	et	4	main
annab	doc_491521501852_item	2516011	et	3	main
ülevaadet	doc_491521501852_item	2516013	et	3	main
et	doc_491521501851_item	2515831	et	3	main
jäi	doc_491521501851_item	2515822	et	3	main
hea	doc_491521501851_item	2515829	et	4	main
jä11e	doc_491521501851_item	2515837	et	4	main
тееldе	doc_491521501851_item	2515839	et	2	main
filmi	doc_491521501851_item	2515841	et	4	main
peaeesmärgiks	doc_491521501851_item	2515842	et	3	main
mitte	doc_491521501851_item	2515845	et	3	main
ajaloo	doc_491521501851_item	2515859	et	4	main
vastu	doc_491521501851_item	2515860	et	3	main
tundub	doc_491521501851_item	2515862	et	3	main
maa	doc_491521501851_item	2515867	et	4	main
vähe	doc_491521501851_item	2515870	et	3	main
ideaalis	doc_491521501851_item	2515871	et	3	main
võiks	doc_491521501851_item	2515872	et	4	main
meie	doc_491521501851_item	2515877	et	4	main
eneseteadvust	doc_491521501851_item	2515878	et	4	main
selles	doc_491521501851_item	2515900	et	4	main
teema	doc_491521501851_item	2515902	et	4	main
see	doc_491521501851_item	2515905	et	3	main
juba	doc_491521501851_item	2515907	et	3	main
äratas	doc_491521501851_item	2515911	et	3	main
järelikult	doc_491521501851_item	2515910	et	3	main
tähelepanu	doc_491521501851_item	2515912	et	4	main
ja	doc_491521501851_item	2515913	et	3	main
tekitas	doc_491521501851_item	2515914	et	3	main
tundeid	doc_491521501851_item	2515915	et	3	main
ning	doc_491521501851_item	2515916	et	3	main
arvamusi	doc_491521501851_item	2515917	et	3	main
igatahes	doc_491521501851_item	2515918	et	3	main
minu	doc_491521501851_item	2515919	et	3	main
puhul	doc_491521501851_item	2515920	et	4	main
oma	doc_491521501851_item	2515923	et	4	main
eesmärgini	doc_491521501851_item	2515924	et	3	main
seansi	doc_491521501851_item	2515925	et	3	main
et	doc_491521501851_item	2515940	et	3	main
see	doc_491521501851_item	2515946	et	3	main
romaani	doc_491521501852_item	2515957	et	4	main
tehtud	doc_491521501852_item	2515961	et	4	main
põhjal	doc_491521501852_item	2515964	et	4	main
aastani	doc_491521501852_item	2515979	et	3	main
romaan	doc_491521501852_item	2515989	et	3	main
nimed	doc_491521501852_item	2515990	et	3	main
eesti	doc_491521501852_item	2515993	et	4	main
kultuuri-	doc_491521501852_item	2515994	et	4	main
ja	doc_491521501852_item	2515995	et	3	main
surmaohus	doc_491521501852_item	2516002	et	3	main
romaantiline	doc_491521501852_item	2516009	et	4	main
näidatud	doc_491521501852_item	2516019	et	4	main
saavutusi	doc_491521501852_item	2516028	et	4	main
ajaloolisest	doc_491521501852_item	2516043	et	4	main
sündmustik	doc_491521501852_item	2516045	et	3	main
kus	doc_491521501852_item	2516050	et	3	main
omavad	doc_491521501852_item	2516078	et	4	main
marmortahvlil	doc_491521501852_item	2516094	et	3	main
põhjal	doc_491521501852_item	2516100	et	4	main
vabaduse	doc_491521501852_item	2516102	et	4	main
eest	doc_491521501852_item	2516103	et	4	main
ja	doc_491521501852_item	2516110	et	3	main
а	doc_491521501852_item	2516114	et	2	main
1936	doc_491521501852_item	2516120	et	2	main
eraldi	doc_491521501852_item	2516122	et	4	main
ning	doc_491521501852_item	2516124	et	3	main
kõhe	doc_491521501852_item	2516126	et	3	main
väga	doc_491521501852_item	2516129	et	3	main
raamat	doc_491521501852_item	2516131	et	3	main
meile	doc_491521501852_item	2516133	et	4	main
katsumused	doc_491521501852_item	2516153	et	3	main
ja	doc_491521501852_item	2516164	et	3	main
maailmavaadete	doc_491521501852_item	2516167	et	3	main
konflikt	doc_491521501852_item	2516170	et	3	main
eesti	doc_491521501852_item	2516180	et	4	main
jõudis	doc_491521501851_item	2515921	et	3	main
ajal	doc_491521501851_item	2515926	et	4	main
sai	doc_491521501851_item	2515927	et	4	main
pani	doc_491521501851_item	2515936	et	4	main
ka	doc_491521501851_item	2515937	et	3	main
ei	doc_491521501851_item	2515938	et	4	main
ja	doc_491521501851_item	2515943	et	3	main
hulgas	doc_491521501851_item	2515952	et	4	main
essee	doc_491521501852_item	2515953	et	4	main
oli	doc_491521501852_item	2515954	et	3	main
huvitav	doc_491521501852_item	2515955	et	4	main
võrrelda	doc_491521501852_item	2515956	et	4	main
nimed	doc_491521501852_item	2515959	et	3	main
neid	doc_491521501852_item	2515969	et	4	main
kuni	doc_491521501852_item	2515977	et	3	main
poliitikaelu	doc_491521501852_item	2515996	et	4	main
kaitsmisest	doc_491521501852_item	2516004	et	4	main
filmis	doc_491521501852_item	2516020	et	4	main
kõige	doc_491521501852_item	2516021	et	4	main
iseloomustavad	doc_491521501852_item	2516023	et	4	main
eestlaste	doc_491521501852_item	2516024	et	4	main
еlu	doc_491521501852_item	2516025	et	2	main
ootusi	doc_491521501852_item	2516026	et	3	main
ja	doc_491521501852_item	2516027	et	3	main
ajal	doc_491521501852_item	2516030	et	4	main
allpoollähemalt	doc_491521501852_item	2516041	et	4	main
tartu	doc_491521501852_item	2516051	et	4	main
koolipoisid	doc_491521501852_item	2516052	et	4	main
ота	doc_491521501852_item	2516053	et	2	main
kõhklustest	doc_491521501852_item	2516054	et	3	main
ja	doc_491521501852_item	2516055	et	3	main
klassivahedest	doc_491521501852_item	2516056	et	3	main
ülе	doc_491521501852_item	2516057	et	2	main
saades	doc_491521501852_item	2516058	et	3	main
rindele	doc_491521501852_item	2516059	et	3	main
rahva	doc_491521501852_item	2516072	et	3	main
on	doc_491521501852_item	2516074	et	4	main
mis	doc_491521501852_item	2516077	et	4	main
erilist	doc_491521501852_item	2516081	et	4	main
jaoks	doc_491521501852_item	2516085	et	4	main
üheks	doc_491521501852_item	2516087	et	3	main
kivikase	doc_491521501852_item	2516091	et	3	main
kirjeldatakse	doc_491521501852_item	2516096	et	3	main
kogemuste	doc_491521501852_item	2516099	et	3	main
eesti	doc_491521501852_item	2516101	et	4	main
läinud	doc_491521501852_item	2516106	et	4	main
romaan	doc_491521501852_item	2516116	et	3	main
raamatuna	doc_491521501852_item	2516123	et	4	main
ajal	doc_491521501852_item	2516141	et	4	main
ajal	doc_491521501852_item	2516156	et	4	main
rahvuslase	doc_491521501852_item	2516165	et	3	main
mis	doc_491521501852_item	2516172	et	4	main
toimus	doc_491521501852_item	2516174	et	3	main
ja	doc_491521501852_item	2516176	et	3	main
eesti	doc_491521501852_item	2516186	et	4	main
päästmise	doc_491521501852_item	2516187	et	4	main
küll	doc_491521501852_item	2516224	et	4	main
kõnelda	doc_491521501852_item	2516230	et	4	main
kui	doc_491521501852_item	2516232	et	3	main
riigist	doc_491521501852_item	2516236	et	3	main
riikide	doc_491521501852_item	2516238	et	3	main
1918	doc_491521501852_item	2516241	et	2	main
ei	doc_491521501852_item	2516250	et	4	main
venemaa	doc_491521501852_item	2516254	et	4	main
1918	doc_491521501852_item	2516259	et	2	main
valitsus	doc_491521501852_item	2516262	et	4	main
kuid	doc_491521501852_item	2516286	et	4	main
sattus	doc_491521501852_item	2516287	et	3	main
suurte	doc_491521501852_item	2516292	et	3	main
kaotustega	doc_491521501852_item	2516293	et	4	main
vabadussõda	doc_491521501852_item	2516297	et	4	main
novembril	doc_491521501852_item	2516299	et	3	main
detsembrikuu	doc_491521501852_item	2516310	et	4	main
jõudes	doc_491521501852_item	2516311	et	3	main
aastavahetuseks	doc_491521501852_item	2516312	et	4	main
30	doc_491521501852_item	2516313	et	2	main
vastupanu	doc_491521501852_item	2516323	et	4	main
saksa	doc_491521501852_item	2516325	et	4	main
takistas	doc_491521501852_item	2516327	et	3	main
jа	doc_491521501852_item	2516337	et	2	main
narvas	doc_491521501852_item	2516347	et	4	main
eesti	doc_491521501852_item	2516352	et	4	main
ei	doc_491521501852_item	2516366	et	4	main
suutnud	doc_491521501852_item	2516367	et	4	main
kõikidel	doc_491521501852_item	2516374	et	4	main
rinnetel	doc_491521501852_item	2516375	et	3	main
1919	doc_491521501852_item	2516383	et	2	main
eesti	doc_491521501852_item	2516421	et	4	main
vabariigi	doc_491521501852_item	2516440	et	3	main
paraadil	doc_491521501852_item	2516443	et	3	main
laidoner	doc_491521501852_item	2516446	et	4	main
võimule	doc_491521501852_item	2516468	et	3	main
valitsuse	doc_491521501852_item	2516470	et	4	main
1940	doc_491521501852_item	2515978	et	2	main
okupatsioonist	doc_491521501852_item	2515981	et	3	main
vabariigi	doc_491521501852_item	2515984	et	3	main
nõukogude	doc_491521501852_item	2515986	et	3	main
marmortahvlil	doc_491521501852_item	2515991	et	3	main
kajastab	doc_491521501852_item	2515992	et	3	main
mis	doc_491521501852_item	2515997	et	4	main
isamaa	doc_491521501852_item	2516003	et	4	main
albert	doc_491521501852_item	2516005	et	4	main
kivikase	doc_491521501852_item	2516006	et	3	main
romaanil	doc_491521501852_item	2516007	et	3	main
seiklusfilm	doc_491521501852_item	2516010	et	3	main
ajaloost	doc_491521501852_item	2516015	et	4	main
need	doc_491521501852_item	2516016	et	3	main
sündmused	doc_491521501852_item	2516017	et	3	main
asetleidnud	doc_491521501852_item	2516039	et	4	main
rahva	doc_491521501852_item	2516069	et	3	main
nende	doc_491521501852_item	2516079	et	4	main
eesti	doc_491521501852_item	2516083	et	4	main
on	doc_491521501852_item	2516086	et	4	main
selliseks	doc_491521501852_item	2516088	et	4	main
nimed	doc_491521501852_item	2516093	et	3	main
autori	doc_491521501852_item	2516097	et	3	main
lootusetusse	doc_491521501852_item	2516104	et	4	main
tungiva	doc_491521501852_item	2516112	et	4	main
nimed	doc_491521501852_item	2516117	et	3	main
ilmus	doc_491521501852_item	2516119	et	4	main
aastal	doc_491521501852_item	2516121	et	3	main
seas	doc_491521501852_item	2516128	et	4	main
populaarseks	doc_491521501852_item	2516130	et	4	main
annab	doc_491521501852_item	2516132	et	3	main
ülevaadet	doc_491521501852_item	2516134	et	3	main
millal	doc_491521501852_item	2516142	et	3	main
osanud	doc_491521501852_item	2516145	et	4	main
rängemad	doc_491521501852_item	2516152	et	4	main
vabadussõja	doc_491521501852_item	2516155	et	3	main
on	doc_491521501852_item	2516158	et	4	main
lahknevusel	doc_491521501852_item	2516168	et	4	main
19	doc_491521501852_item	2516184	et	2	main
paremini	doc_491521501852_item	2516022	et	4	main
albert	doc_491521501852_item	2516031	et	4	main
kivikase	doc_491521501852_item	2516032	et	3	main
romaan	doc_491521501852_item	2516033	et	3	main
nimed	doc_491521501852_item	2516034	et	3	main
marmortahvlil	doc_491521501852_item	2516035	et	3	main
tugineb	doc_491521501852_item	2516036	et	3	main
põhijoontes	doc_491521501852_item	2516037	et	3	main
tegelikult	doc_491521501852_item	2516038	et	4	main
kulgeb	doc_491521501852_item	2516046	et	3	main
aegses	doc_491521501852_item	2516048	et	3	main
lооmа	doc_491521501852_item	2516061	et	2	main
lähevad	doc_491521501852_item	2516062	et	3	main
minu	doc_491521501852_item	2516063	et	3	main
arvates	doc_491521501852_item	2516064	et	4	main
filmi	doc_491521501852_item	2516065	et	4	main
vaadates	doc_491521501852_item	2516066	et	3	main
tekib	doc_491521501852_item	2516067	et	3	main
rahvusriiki	doc_491521501852_item	2516060	et	4	main
eestlaste	doc_491521501852_item	2516068	et	4	main
ühtsustunne	doc_491521501852_item	2516070	et	3	main
jaoks	doc_491521501852_item	2516073	et	4	main
olemas	doc_491521501852_item	2516075	et	4	main
raamatud	doc_491521501852_item	2516076	et	4	main
ajaloos	doc_491521501852_item	2516080	et	4	main
teoseks	doc_491521501852_item	2516089	et	4	main
albert	doc_491521501852_item	2516090	et	4	main
heitlusse	doc_491521501852_item	2516105	et	3	main
koolipoiste	doc_491521501852_item	2516107	et	3	main
iseenda	doc_491521501852_item	2516109	et	3	main
kivikase	doc_491521501852_item	2516115	et	3	main
rahva	doc_491521501852_item	2516127	et	3	main
keegi	doc_491521501852_item	2516143	et	4	main
veelgi	doc_491521501852_item	2516151	et	4	main
põhinev	doc_491521501852_item	2516169	et	4	main
moodustasid	doc_491521501852_item	2516182	et	4	main
juba	doc_491521501852_item	2516183	et	3	main
veebruaril	doc_491521501852_item	2516185	et	3	main
manifesti	doc_491521501852_item	2516191	et	4	main
selles	doc_491521501852_item	2516192	et	4	main
teatati	doc_491521501852_item	2516193	et	3	main
demokraatliku	doc_491521501852_item	2516194	et	3	main
eesti	doc_491521501852_item	2516195	et	4	main
vabariigi	doc_491521501852_item	2516196	et	3	main
loomisest	doc_491521501852_item	2516197	et	4	main
veel	doc_491521501852_item	2516198	et	4	main
enne	doc_491521501852_item	2516199	et	4	main
sakslaste	doc_491521501852_item	2516200	et	3	main
saabumist	doc_491521501852_item	2516201	et	4	main
võeti	doc_491521501852_item	2516202	et	3	main
võim	doc_491521501852_item	2516203	et	3	main
rahvusväeosade	doc_491521501852_item	2516204	et	3	main
abil	doc_491521501852_item	2516205	et	4	main
enamlastelt	doc_491521501852_item	2516206	et	4	main
ülе	doc_491521501852_item	2516207	et	2	main
24	doc_491521501852_item	2516208	et	2	main
veebruaril	doc_491521501852_item	2516209	et	3	main
1918	doc_491521501852_item	2516210	et	2	main
moodustas	doc_491521501852_item	2516211	et	3	main
päästekomitee	doc_491521501852_item	2516212	et	4	main
ajutise	doc_491521501852_item	2516213	et	3	main
valitsuse	doc_491521501852_item	2516214	et	4	main
mille	doc_491521501852_item	2516215	et	3	main
peaministriks	doc_491521501852_item	2516216	et	3	main
sai	doc_491521501852_item	2516217	et	4	main
konstantin	doc_491521501852_item	2516218	et	4	main
päts	doc_491521501852_item	2516219	et	3	main
päev	doc_491521501852_item	2516220	et	3	main
iiksused	doc_491521501852_item	2516226	et	4	main
lubas	doc_491521501852_item	2516229	et	3	main
iseseisvust	doc_491521501852_item	2516249	et	4	main
tühistas	doc_491521501852_item	2516260	et	3	main
novembril	doc_491521501852_item	2516280	et	3	main
punaarmee	doc_491521501852_item	2516283	et	4	main
siseneda	doc_491521501852_item	2516284	et	3	main
saksa	doc_491521501852_item	2516288	et	4	main
vägedele	doc_491521501852_item	2516289	et	3	main
ning	doc_491521501852_item	2516290	et	3	main
tõmbus	doc_491521501852_item	2516291	et	4	main
28	doc_491521501852_item	2516298	et	2	main
punaarmee	doc_491521501852_item	2516301	et	4	main
näidatud	doc_491521501852_item	2516159	et	4	main
kahe	doc_491521501852_item	2516160	et	3	main
õpilase	doc_491521501852_item	2516161	et	3	main
kommunisti	doc_491521501852_item	2516162	et	4	main
käämeri	doc_491521501852_item	2516163	et	3	main
käsperi	doc_491521501852_item	2516166	et	4	main
aga	doc_491521501852_item	2516171	et	3	main
tegelikult	doc_491521501852_item	2516173	et	4	main
enne	doc_491521501852_item	2516175	et	4	main
pärast	doc_491521501852_item	2516177	et	4	main
vabadussõja	doc_491521501852_item	2516178	et	3	main
eestis	doc_491521501852_item	2516179	et	3	main
komitee	doc_491521501852_item	2516188	et	4	main
ja	doc_491521501852_item	2516189	et	3	main
marssisid	doc_491521501852_item	2516222	et	4	main
kuid	doc_491521501852_item	2516227	et	4	main
iseseisvast	doc_491521501852_item	2516235	et	3	main
rahvusvaheline	doc_491521501852_item	2516239	et	4	main
а	doc_491521501852_item	2516242	et	2	main
oli	doc_491521501852_item	2516244	et	3	main
ebakindel	doc_491521501852_item	2516246	et	3	main
ning	doc_491521501852_item	2516247	et	3	main
ka	doc_491521501852_item	2516252	et	3	main
ja	doc_491521501852_item	2516255	et	3	main
13	doc_491521501852_item	2516257	et	2	main
novebril	doc_491521501852_item	2516258	et	4	main
vene	doc_491521501852_item	2516261	et	4	main
baltimaid	doc_491521501852_item	2516278	et	4	main
algas	doc_491521501852_item	2516296	et	3	main
uuе	doc_491521501852_item	2516302	et	2	main
narvale	doc_491521501852_item	2516304	et	4	main
ja	doc_491521501852_item	2516305	et	3	main
edasitung	doc_491521501852_item	2516306	et	3	main
põhja-eestis	doc_491521501852_item	2516307	et	3	main
jätkus	doc_491521501852_item	2516308	et	4	main
esialgu	doc_491521501852_item	2516321	et	3	main
sest	doc_491521501852_item	2516324	et	4	main
väejuhatus	doc_491521501852_item	2516326	et	4	main
rahvuslike	doc_491521501852_item	2516328	et	3	main
relvajõudude	doc_491521501852_item	2516329	et	3	main
loomist	doc_491521501852_item	2516330	et	4	main
loodi	doc_491521501852_item	2516348	et	4	main
kommuni	doc_491521501852_item	2516354	et	4	main
jaan	doc_491521501852_item	2516356	et	3	main
juhtimisel	doc_491521501852_item	2516358	et	4	main
ründajatele	doc_491521501852_item	2516368	et	4	main
poliitikud	doc_491521501852_item	2516181	et	3	main
koostasid	doc_491521501852_item	2516190	et	4	main
hiljem	doc_491521501852_item	2516221	et	3	main
tallinna	doc_491521501852_item	2516223	et	4	main
saksa	doc_491521501852_item	2516225	et	4	main
eestist	doc_491521501852_item	2516231	et	3	main
vägivaldselt	doc_491521501852_item	2516233	et	4	main
okupeeritud	doc_491521501852_item	2516234	et	4	main
seisund	doc_491521501852_item	2516240	et	3	main
lõрul	doc_491521501852_item	2516243	et	2	main
tunnustanud	doc_491521501852_item	2516251	et	4	main
üritas	doc_491521501852_item	2516282	et	3	main
tagasi	doc_491521501852_item	2516294	et	3	main
kogu	doc_491521501852_item	2516309	et	4	main
avaldatud	doc_491521501852_item	2516319	et	4	main
punaarmeele	doc_491521501852_item	2516320	et	3	main
toimunu	doc_491521501852_item	2516228	et	4	main
balti	doc_491521501852_item	2516237	et	3	main
äärmiselt	doc_491521501852_item	2516245	et	4	main
nende	doc_491521501852_item	2516248	et	4	main
nõukogude	doc_491521501852_item	2516253	et	3	main
saksamaa	doc_491521501852_item	2516256	et	4	main
saksamaaga	doc_491521501852_item	2516263	et	3	main
sõlmitud	doc_491521501852_item	2516264	et	4	main
lepingud	doc_491521501852_item	2516265	et	3	main
ning	doc_491521501852_item	2516266	et	3	main
alustas	doc_491521501852_item	2516267	et	3	main
ettevalmistusi	doc_491521501852_item	2516268	et	3	main
pealetungiks	doc_491521501852_item	2516269	et	4	main
rünnak	doc_491521501852_item	2516270	et	3	main
mille	doc_491521501852_item	2516271	et	3	main
eesmärgiks	doc_491521501852_item	2516272	et	3	main
oli	doc_491521501852_item	2516273	et	3	main
maailmarevolutsiooni	doc_491521501852_item	2516274	et	4	main
ohustas	doc_491521501852_item	2516276	et	3	main
vallandamine	doc_491521501852_item	2516275	et	4	main
esmajoones	doc_491521501852_item	2516277	et	3	main
22	doc_491521501852_item	2516279	et	2	main
1918	doc_491521501852_item	2516281	et	2	main
narva	doc_491521501852_item	2516285	et	4	main
eestis	doc_491521501852_item	2516295	et	3	main
1918	doc_491521501852_item	2516300	et	2	main
mingit	doc_491521501852_item	2516322	et	3	main
tartu	doc_491521501852_item	2516336	et	4	main
vastupanuta	doc_491521501852_item	2516339	et	3	main
vallutatud	doc_491521501852_item	2516341	et	4	main
aladel	doc_491521501852_item	2516342	et	3	main
välja	doc_491521501852_item	2516344	et	4	main
nõukogude	doc_491521501852_item	2516345	et	3	main
novembril	doc_491521501852_item	2516350	et	3	main
töörahva	doc_491521501852_item	2516353	et	3	main
anvelti	doc_491521501852_item	2516357	et	4	main
kuni	doc_491521501852_item	2516359	et	3	main
aasta	doc_491521501852_item	2516361	et	4	main
vastu	doc_491521501852_item	2516369	et	3	main
eestis	doc_491521501852_item	2516377	et	3	main
6	doc_491521501852_item	2516381	et	2	main
algas	doc_491521501852_item	2516384	et	3	main
et	doc_491521501852_item	2516420	et	3	main
ei	doc_491521501852_item	2516422	et	4	main
ole	doc_491521501852_item	2516423	et	4	main
üksi-	doc_491521501852_item	2516424	et	4	main
eesti	doc_491521501852_item	2516439	et	4	main
eesti	doc_491521501852_item	2516482	et	4	main
et	doc_491521501852_item	2516495	et	3	main
tartu	doc_491521501852_item	2516496	et	4	main
tartu	doc_491521501852_item	2516507	et	4	main
12	doc_491521501852_item	2516511	et	2	main
saksa	doc_491521501852_item	2516514	et	4	main
järel	doc_491521501852_item	2516516	et	4	main
hulk	doc_491521501852_item	2516523	et	3	main
viljandisse	doc_491521501852_item	2516530	et	4	main
koolipoiste	doc_491521501852_item	2516532	et	3	main
baasil	doc_491521501852_item	2516533	et	3	main
moodustatakse	doc_491521501852_item	2516534	et	3	main
ümber	doc_491521501852_item	2516541	et	3	main
vallutavad	doc_491521501852_item	2516552	et	4	main
valguta	doc_491521501852_item	2516555	et	4	main
pikasilla26	doc_491521501852_item	2516557	et	3	main
1919	doc_491521501852_item	2516559	et	2	main
saabunud	doc_491521501852_item	2516564	et	4	main
abivägede	doc_491521501852_item	2516565	et	3	main
raskes	doc_491521501852_item	2516567	et	3	main
lahingus	doc_491521501852_item	2516568	et	3	main
tagasi	doc_491521501852_item	2516569	et	3	main
vastase	doc_491521501852_item	2516570	et	4	main
vastupealetungi	doc_491521501852_item	2516571	et	4	main
helme-tõrva-hummuli	doc_491521501852_item	2516576	et	4	main
ei	doc_491521501852_item	2516611	et	4	main
kes	doc_491521501852_item	2516617	et	4	main
eesti	doc_491521501852_item	2516620	et	4	main
võimalustesse	doc_491521501852_item	2516621	et	3	main
ning	doc_491521501852_item	2516626	et	3	main
poisid	doc_491521501852_item	2516638	et	4	main
tõusid	doc_491521501852_item	2516641	et	4	main
haarasid	doc_491521501852_item	2516643	et	4	main
oma	doc_491521501852_item	2516645	et	4	main
iseseisvuse	doc_491521501852_item	2516647	et	4	main
selle	doc_491521501852_item	2516655	et	4	main
nimel	doc_491521501852_item	2516656	et	3	main
võitlusse	doc_491521501852_item	2516657	et	3	main
ka	doc_491521501852_item	2516658	et	3	main
paraku	doc_491521501852_item	2516665	et	3	main
kõrge	doc_491521501852_item	2516668	et	4	main
hind	doc_491521501852_item	2516669	et	3	main
tasuks	doc_491521501852_item	2516670	et	4	main
nad	doc_491521501852_item	2516671	et	3	main
nimed	doc_491521501852_item	2516679	et	3	main
emotsionaalne	doc_491521501852_item	2516682	et	3	main
läbi	doc_491521501852_item	2516684	et	4	main
see	doc_491521501852_item	2516708	et	3	main
kätte	doc_491521501852_item	2516711	et	4	main
sõjamees	doc_491521501852_item	2516718	et	4	main
võitlema	doc_491521501852_item	2516720	et	3	main
samuti	doc_491521501852_item	2516725	et	3	main
eesti	doc_491521501852_item	2516726	et	4	main
vabadussõjas	doc_491521501852_item	2516727	et	3	main
ajutine	doc_491521501852_item	2516728	et	4	main
isamaa	doc_491521501852_item	2516735	et	4	main
pealetungiga	doc_491521501852_item	2516303	et	4	main
km	doc_491521501852_item	2516314	et	4	main
kaugusele	doc_491521501852_item	2516315	et	4	main
tallinnast	doc_491521501852_item	2516316	et	3	main
lõuna-eestis	doc_491521501852_item	2516317	et	3	main
ei	doc_491521501852_item	2516318	et	4	main
andis	doc_491521501852_item	2516332	et	3	main
võru	doc_491521501852_item	2516334	et	4	main
тара	doc_491521501852_item	2516338	et	2	main
29	doc_491521501852_item	2516349	et	2	main
valitsus	doc_491521501852_item	2516355	et	4	main
1919	doc_491521501852_item	2516360	et	2	main
alguseni	doc_491521501852_item	2516362	et	3	main
nõrk	doc_491521501852_item	2516363	et	3	main
eesti	doc_491521501852_item	2516364	et	4	main
kaitsevägi	doc_491521501852_item	2516365	et	3	main
seisma	doc_491521501852_item	2516370	et	3	main
oli	doc_491521501852_item	2516372	et	3	main
taanduma	doc_491521501852_item	2516376	et	3	main
edasitung	doc_491521501852_item	2516379	et	3	main
jaanuaril	doc_491521501852_item	2516382	et	3	main
rahvaväe	doc_491521501852_item	2516385	et	3	main
saabus	doc_491521501852_item	2516426	et	3	main
aastapäeva	doc_491521501852_item	2516442	et	4	main
ülemjuhataja	doc_491521501852_item	2516445	et	4	main
et	doc_491521501852_item	2516447	et	3	main
algab	doc_491521501852_item	2516454	et	3	main
landsveeri	doc_491521501852_item	2516455	et	4	main
landeswehri	doc_491521501852_item	2516464	et	4	main
ja	doc_491521501852_item	2516465	et	3	main
seavad	doc_491521501852_item	2516466	et	3	main
1920	doc_491521501852_item	2516473	et	2	main
alla	doc_491521501852_item	2516476	et	3	main
rahulepinguga	doc_491521501852_item	2516478	et	3	main
tunnustab	doc_491521501852_item	2516479	et	3	main
iseseisvust	doc_491521501852_item	2516483	et	4	main
on	doc_491521501852_item	2516485	et	4	main
tuleb	doc_491521501852_item	2516489	et	3	main
omakaitsesse	doc_491521501852_item	2516499	et	4	main
nad	doc_491521501852_item	2516501	et	3	main
võimu	doc_491521501852_item	2516503	et	4	main
1918	doc_491521501852_item	2516513	et	2	main
peetud	doc_491521501852_item	2516519	et	4	main
koosolekul	doc_491521501852_item	2516520	et	3	main
kaitseliitu	doc_491521501852_item	2516525	et	4	main
aastal	doc_491521501852_item	2516529	et	3	main
nimetatakse	doc_491521501852_item	2516540	et	3	main
vabatahtlike	doc_491521501852_item	2516543	et	3	main
mõisa	doc_491521501852_item	2516554	et	3	main
löövad	doc_491521501852_item	2516561	et	4	main
pataljon	doc_491521501852_item	2516574	et	3	main
alguses	doc_491521501852_item	2516610	et	4	main
olnud	doc_491521501852_item	2516612	et	4	main
eestis	doc_491521501852_item	2516613	et	3	main
just	doc_491521501852_item	2516614	et	3	main
oleks	doc_491521501852_item	2516618	et	3	main
ja	doc_491521501852_item	2516331	et	3	main
linnad	doc_491521501852_item	2516333	et	3	main
valgarakvere	doc_491521501852_item	2516335	et	4	main
punaarmeele	doc_491521501852_item	2516340	et	3	main
kuulutati	doc_491521501852_item	2516343	et	4	main
võim	doc_491521501852_item	2516346	et	3	main
1918	doc_491521501852_item	2516351	et	2	main
ning	doc_491521501852_item	2516371	et	3	main
sunnitud	doc_491521501852_item	2516373	et	4	main
peatati	doc_491521501852_item	2516378	et	4	main
aastavahetusel	doc_491521501852_item	2516380	et	4	main
vastupealetung	doc_491521501852_item	2516386	et	3	main
ja	doc_491521501852_item	2516387	et	3	main
vabastati	doc_491521501852_item	2516388	et	3	main
rakvere	doc_491521501852_item	2516389	et	4	main
va1ga	doc_491521501852_item	2516391	et	4	main
tartu	doc_491521501852_item	2516390	et	4	main
ja	doc_491521501852_item	2516392	et	3	main
võru	doc_491521501852_item	2516393	et	4	main
juba	doc_491521501852_item	2516394	et	3	main
1	doc_491521501852_item	2516395	et	2	main
veebruariks	doc_491521501852_item	2516396	et	3	main
paistati	doc_491521501852_item	2516397	et	4	main
vastane	doc_491521501852_item	2516398	et	3	main
eesti	doc_491521501852_item	2516399	et	4	main
piiridest	doc_491521501852_item	2516400	et	3	main
edulе	doc_491521501852_item	2516402	et	2	main
välja	doc_491521501852_item	2516401	et	4	main
aitas	doc_491521501852_item	2516403	et	3	main
kaasa	doc_491521501852_item	2516404	et	4	main
polkovnik	doc_491521501852_item	2516406	et	3	main
johan	doc_491521501852_item	2516407	et	4	main
laidoneri	doc_491521501852_item	2516408	et	4	main
nimetamine	doc_491521501852_item	2516409	et	4	main
sundmobilatsioon	doc_491521501852_item	2516405	et	4	main
ülemjuhatajaks	doc_491521501852_item	2516410	et	3	main
ja	doc_491521501852_item	2516411	et	3	main
vägede	doc_491521501852_item	2516412	et	3	main
varustuse	doc_491521501852_item	2516413	et	4	main
tänu	doc_491521501852_item	2516415	et	4	main
rekvisitsioonidele	doc_491521501852_item	2516416	et	3	main
võitlusmoraali	doc_491521501852_item	2516417	et	4	main
paranemine	doc_491521501852_item	2516414	et	4	main
tugevdas	doc_491521501852_item	2516418	et	3	main
teadmine	doc_491521501852_item	2516419	et	4	main
tallinna	doc_491521501852_item	2516427	et	4	main
inglise	doc_491521501852_item	2516428	et	4	main
aastavahetusel	doc_491521501852_item	2516430	et	4	main
jõudsid	doc_491521501852_item	2516431	et	4	main
rindele	doc_491521501852_item	2516432	et	3	main
soome	doc_491521501852_item	2516433	et	3	main
1919	doc_491521501852_item	2516437	et	2	main
aastal	doc_491521501852_item	2516438	et	3	main
eesti	doc_491521501852_item	2516448	et	4	main
sõda	doc_491521501852_item	2516456	et	4	main
mille	doc_491521501852_item	2516457	et	3	main
käigus	doc_491521501852_item	2516458	et	4	main
üksused	doc_491521501852_item	2516460	et	3	main
eesti-läti	doc_491521501852_item	2516459	et	4	main
löövad	doc_491521501852_item	2516461	et	4	main
puruks	doc_491521501852_item	2516462	et	4	main
detsembris	doc_491521501852_item	2516425	et	3	main
laevastikueskaader	doc_491521501852_item	2516429	et	3	main
vabatahtlikud	doc_491521501852_item	2516434	et	3	main
24	doc_491521501852_item	2516435	et	2	main
veebruaril	doc_491521501852_item	2516436	et	3	main
i	doc_491521501852_item	2516441	et	4	main
raporteerib	doc_491521501852_item	2516444	et	3	main
on	doc_491521501852_item	2516449	et	4	main
vaenuvägedest	doc_491521501852_item	2516450	et	3	main
vaba	doc_491521501852_item	2516451	et	4	main
19	doc_491521501852_item	2516452	et	2	main
juunil	doc_491521501852_item	2516453	et	3	main
lätis	doc_491521501852_item	2516467	et	4	main
2	doc_491521501852_item	2516471	et	2	main
tartus	doc_491521501852_item	2516475	et	3	main
võiduga	doc_491521501852_item	2516487	et	4	main
ka	doc_491521501852_item	2516490	et	3	main
kuulusid	doc_491521501852_item	2516498	et	4	main
ning	doc_491521501852_item	2516500	et	3	main
veebruar	doc_491521501852_item	2516509	et	3	main
novembril	doc_491521501852_item	2516512	et	3	main
okupatsiooni	doc_491521501852_item	2516515	et	4	main
kommertskoolis	doc_491521501852_item	2516518	et	4	main
suur	doc_491521501852_item	2516522	et	3	main
saksa	doc_491521501852_item	2516463	et	4	main
rahvusliku	doc_491521501852_item	2516469	et	3	main
veebruaril	doc_491521501852_item	2516472	et	3	main
aastal	doc_491521501852_item	2516474	et	3	main
kirjutatud	doc_491521501852_item	2516477	et	4	main
nõukogude	doc_491521501852_item	2516480	et	3	main
venemaa	doc_491521501852_item	2516481	et	4	main
lõppenud	doc_491521501852_item	2516486	et	4	main
kuid	doc_491521501852_item	2516488	et	4	main
tahelepanu	doc_491521501852_item	2516491	et	4	main
pöörama	doc_491521501852_item	2516492	et	3	main
ka	doc_491521501852_item	2516493	et	3	main
sellele	doc_491521501852_item	2516494	et	4	main
osalevad	doc_491521501852_item	2516502	et	4	main
võtmisel	doc_491521501852_item	2516504	et	4	main
enamlaselt	doc_491521501852_item	2516505	et	3	main
kaitsel20-24	doc_491521501852_item	2516508	et	3	main
astub	doc_491521501852_item	2516521	et	3	main
koolipoisse	doc_491521501852_item	2516524	et	4	main
jaanuaril	doc_491521501852_item	2516527	et	3	main
moodustatud	doc_491521501852_item	2516531	et	4	main
pataljon	doc_491521501852_item	2516537	et	3	main
mis	doc_491521501852_item	2516538	et	4	main
tartu	doc_491521501852_item	2516545	et	4	main
osalevad	doc_491521501852_item	2516547	et	4	main
kärstna	doc_491521501852_item	2516549	et	4	main
rõngu	doc_491521501852_item	2516556	et	4	main
tartu	doc_491521501852_item	2516572	et	4	main
1	doc_491521501852_item	2516577	et	2	main
kooliõpilaste	doc_491521501852_item	2516605	et	4	main
osa	doc_491521501852_item	2516606	et	4	main
sõja	doc_491521501852_item	2516607	et	3	main
võitmisessest	doc_491521501852_item	2516608	et	4	main
palju	doc_491521501852_item	2516616	et	4	main
seista	doc_491521501852_item	2516622	et	4	main
maailma	doc_491521501852_item	2516624	et	4	main
suurvõimudele	doc_491521501852_item	2516625	et	3	main
tegelikkust	doc_491521501852_item	2516635	et	4	main
kuidas	doc_491521501852_item	2516636	et	3	main
ja	doc_491521501852_item	2516644	et	3	main
kõrval	doc_491521501852_item	2516653	et	4	main
asuvad	doc_491521501852_item	2516654	et	4	main
oma	doc_491521501852_item	2516661	et	4	main
ja	doc_491521501852_item	2516663	et	3	main
saavad	doc_491521501852_item	2516672	et	4	main
jäävad	doc_491521501852_item	2516677	et	4	main
marmortahvlil	doc_491521501852_item	2516680	et	3	main
on	doc_491521501852_item	2516681	et	4	main
eesti	doc_491521501852_item	2516687	et	4	main
võidelnud	doc_491521501852_item	2516689	et	4	main
vastu	doc_491521501852_item	2516692	et	3	main
ju	doc_491521501852_item	2516699	et	3	main
teada	doc_491521501852_item	2516703	et	3	main
et	doc_491521501852_item	2516704	et	3	main
aastasadade	doc_491521501852_item	2516715	et	4	main
ka	doc_491521501852_item	2516721	et	3	main
kallaletungi	doc_491521501852_item	2516733	et	4	main
linna-	doc_491521501852_item	2516750	et	4	main
valitsuse	doc_491521501852_item	2516760	et	4	main
kaitse	doc_491521501852_item	2516764	et	4	main
enesealgatust	doc_491521501852_item	2516767	et	4	main
aitas	doc_491521501852_item	2516795	et	3	main
piire	doc_491521501852_item	2516798	et	4	main
andis	doc_491521501852_item	2516800	et	3	main
tunginud	doc_491521501852_item	2516813	et	4	main
kallale	doc_491521501852_item	2516815	et	4	main
vabadussõja	doc_491521501852_item	2516816	et	3	main
võit	doc_491521501852_item	2516821	et	3	main
seepärast	doc_491521501852_item	2516831	et	3	main
võidelnud	doc_491521501852_item	2516838	et	4	main
nagu	doc_491521501852_item	2516839	et	3	main
marmortahvlil	doc_491521501852_item	2516847	et	3	main
pühendatud	doc_491521501852_item	2516854	et	4	main
eesti	doc_491521501852_item	2516856	et	4	main
kellel	doc_491521501852_item	2516858	et	4	main
koolides	doc_491521501852_item	2516882	et	3	main
aukohal	doc_491521501852_item	2516884	et	4	main
marmortahvlitele	doc_491521501852_item	2516886	et	3	main
tihti	doc_491521501852_item	2516890	et	3	main
nende	doc_491521501852_item	2516893	et	4	main
vabadussõda	doc_491521501852_item	2516484	et	4	main
kooliopisid	doc_491521501852_item	2516497	et	4	main
ja	doc_491521501852_item	2516506	et	3	main
1918	doc_491521501852_item	2516510	et	2	main
tartu	doc_491521501852_item	2516517	et	4	main
hiljem	doc_491521501852_item	2516539	et	3	main
pataljoniks	doc_491521501852_item	2516544	et	3	main
rannu	doc_491521501852_item	2516553	et	4	main
ning	doc_491521501852_item	2516560	et	3	main
viimasel	doc_491521501852_item	2516562	et	3	main
vabatahtlik	doc_491521501852_item	2516573	et	3	main
tähtsus	doc_491521501852_item	2516603	et	4	main
vabadussõja	doc_491521501852_item	2516609	et	3	main
iseseisvust	doc_491521501852_item	2516629	et	4	main
film	doc_491521501852_item	2516630	et	3	main
otse	doc_491521501852_item	2516639	et	4	main
koolipingist	doc_491521501852_item	2516640	et	3	main
asusid	doc_491521501852_item	2516650	et	4	main
ja	doc_491521501852_item	2516651	et	3	main
sõdurite	doc_491521501852_item	2516652	et	3	main
maad	doc_491521501852_item	2516662	et	4	main
on	doc_491521501852_item	2516666	et	4	main
armastuse	doc_491521501852_item	2516673	et	4	main
isamaa	doc_491521501852_item	2516674	et	4	main
mälestused	doc_491521501852_item	2516678	et	4	main
sõjadraama	doc_491521501852_item	2516683	et	4	main
aastasadade	doc_491521501852_item	2516685	et	4	main
võimu	doc_491521501852_item	2516691	et	4	main
rahvuse	doc_491521501852_item	2516695	et	3	main
ajaloost	doc_491521501852_item	2516702	et	4	main
relvaga	doc_491521501852_item	2516710	et	3	main
on	doc_491521501852_item	2516716	et	4	main
pidanud	doc_491521501852_item	2516719	et	4	main
1	doc_491521501852_item	2516526	et	2	main
1919	doc_491521501852_item	2516528	et	2	main
tartu	doc_491521501852_item	2516535	et	4	main
kaitseliidu	doc_491521501852_item	2516536	et	3	main
tartu	doc_491521501852_item	2516542	et	4	main
koolipoisid	doc_491521501852_item	2516546	et	4	main
murdelahingutes	doc_491521501852_item	2516548	et	4	main
аll	doc_491521501852_item	2516550	et	2	main
ja	doc_491521501852_item	2516551	et	3	main
jaanuar	doc_491521501852_item	2516558	et	3	main
hetkel	doc_491521501852_item	2516563	et	4	main
toel	doc_491521501852_item	2516566	et	4	main
vallutab	doc_491521501852_item	2516575	et	3	main
veebruaril	doc_491521501852_item	2516578	et	3	main
tartu	doc_491521501852_item	2516579	et	4	main
koolipoisid	doc_491521501852_item	2516580	et	4	main
marsivad	doc_491521501852_item	2516581	et	3	main
sisse	doc_491521501852_item	2516582	et	4	main
vabastatud	doc_491521501852_item	2516583	et	4	main
valga	doc_491521501852_item	2516584	et	4	main
linna	doc_491521501852_item	2516585	et	4	main
3	doc_491521501852_item	2516586	et	2	main
veebruaril	doc_491521501852_item	2516587	et	3	main
1919	doc_491521501852_item	2516588	et	2	main
aastal	doc_491521501852_item	2516589	et	3	main
koolipoiste	doc_491521501852_item	2516590	et	3	main
pataljon	doc_491521501852_item	2516591	et	3	main
likvideeritakse	doc_491521501852_item	2516592	et	3	main
ja	doc_491521501852_item	2516593	et	3	main
poisid	doc_491521501852_item	2516594	et	4	main
saabuvad	doc_491521501852_item	2516595	et	4	main
tagasi	doc_491521501852_item	2516596	et	3	main
tartusse	doc_491521501852_item	2516597	et	3	main
vabadussõja	doc_491521501852_item	2516599	et	3	main
eesti	doc_491521501852_item	2516598	et	4	main
ajaloos	doc_491521501852_item	2516600	et	4	main
suur	doc_491521501852_item	2516602	et	3	main
on	doc_491521501852_item	2516601	et	4	main
eesti	doc_491521501852_item	2516604	et	4	main
neid	doc_491521501852_item	2516615	et	4	main
uskunud	doc_491521501852_item	2516619	et	4	main
vastu	doc_491521501852_item	2516623	et	3	main
kaitsta	doc_491521501852_item	2516627	et	4	main
oma	doc_491521501852_item	2516628	et	4	main
eesti	doc_491521501852_item	2516637	et	4	main
eest	doc_491521501852_item	2516648	et	4	main
võitlusesse	doc_491521501852_item	2516649	et	4	main
koolinoored	doc_491521501852_item	2516659	et	3	main
sõjamees	doc_491521501852_item	2516688	et	4	main
oma	doc_491521501852_item	2516694	et	4	main
eest	doc_491521501852_item	2516697	et	4	main
on	doc_491521501852_item	2516698	et	4	main
sajanditepikkusest	doc_491521501852_item	2516700	et	4	main
rahvaste	doc_491521501852_item	2516701	et	4	main
tuleb	doc_491521501852_item	2516709	et	3	main
kuulutas	doc_491521501852_item	2516730	et	3	main
venelaste	doc_491521501852_item	2516731	et	4	main
hädaohus	doc_491521501852_item	2516736	et	3	main
olevaks	doc_491521501852_item	2516737	et	4	main
otsustas	doc_491521501852_item	2516739	et	3	main
ja	doc_491521501852_item	2516742	et	3	main
rahvaväe	doc_491521501852_item	2516744	et	3	main
muuta	doc_491521501852_item	2516746	et	4	main
alevi-	doc_491521501852_item	2516749	et	3	main
ei	doc_491521501852_item	2516756	et	4	main
käske	doc_491521501852_item	2516761	et	3	main
läti	doc_491521501852_item	2516792	et	4	main
kaitsta	doc_491521501852_item	2516796	et	4	main
та	doc_491521501852_item	2516799	et	2	main
olid	doc_491521501852_item	2516806	et	4	main
meie	doc_491521501852_item	2516808	et	4	main
naabri	doc_491521501852_item	2516809	et	3	main
demokraatliku	doc_491521501852_item	2516810	et	3	main
valitsuse	doc_491521501852_item	2516811	et	4	main
meile	doc_491521501852_item	2516814	et	4	main
kangelaste	doc_491521501852_item	2516817	et	4	main
veri	doc_491521501852_item	2516818	et	3	main
ja	doc_491521501852_item	2516819	et	3	main
saavutatud	doc_491521501852_item	2516820	et	4	main
nimed	doc_491521501852_item	2516631	et	3	main
marmortahvlil	doc_491521501852_item	2516632	et	3	main
näitab	doc_491521501852_item	2516633	et	3	main
meile	doc_491521501852_item	2516634	et	4	main
relvad	doc_491521501852_item	2516642	et	3	main
riigi	doc_491521501852_item	2516646	et	3	main
kaitstes	doc_491521501852_item	2516660	et	3	main
aateid	doc_491521501852_item	2516664	et	3	main
vabadusel	doc_491521501852_item	2516667	et	4	main
ja	doc_491521501852_item	2516675	et	3	main
neist	doc_491521501852_item	2516676	et	4	main
on	doc_491521501852_item	2516686	et	4	main
võõra	doc_491521501852_item	2516690	et	3	main
ja	doc_491521501852_item	2516693	et	3	main
püsimajäämise	doc_491521501852_item	2516696	et	4	main
vabadust	doc_491521501852_item	2516705	et	4	main
ei	doc_491521501852_item	2516706	et	4	main
kingita	doc_491521501852_item	2516707	et	4	main
võidelda	doc_491521501852_item	2516712	et	4	main
kuid	doc_491521501852_item	2516713	et	4	main
läbi	doc_491521501852_item	2516714	et	4	main
eesti	doc_491521501852_item	2516717	et	4	main
koos	doc_491521501852_item	2516722	et	4	main
võõraste	doc_491521501852_item	2516723	et	4	main
vägedega	doc_491521501852_item	2516724	et	3	main
ootamatu	doc_491521501852_item	2516732	et	4	main
läbiviimiseks	doc_491521501852_item	2516741	et	3	main
kõik	doc_491521501852_item	2516747	et	4	main
ootama	doc_491521501852_item	2516759	et	3	main
korraldamisel	doc_491521501852_item	2516765	et	4	main
üles	doc_491521501852_item	2516766	et	3	main
noor	doc_491521501852_item	2516789	et	3	main
kaitsevägi	doc_491521501852_item	2516790	et	3	main
vabastas	doc_491521501852_item	2516791	et	3	main
aidati	doc_491521501852_item	2516827	et	3	main
mullе	doc_491521501852_item	2516840	et	2	main
nimed	doc_491521501852_item	2516846	et	3	main
omab	doc_491521501852_item	2516848	et	3	main
meie	doc_491521501852_item	2516851	et	4	main
ning	doc_491521501852_item	2516853	et	3	main
kõigile	doc_491521501852_item	2516855	et	4	main
põlvkondadele	doc_491521501852_item	2516857	et	3	main
raiutud	doc_491521501852_item	2516881	et	4	main
hauad	doc_491521501852_item	2516895	et	3	main
on	doc_491521501852_item	2516911	et	4	main
võitle	doc_491521501852_item	2516916	et	4	main
rahvas	doc_491521501852_item	2516922	et	4	main
unustab	doc_491521501852_item	2516924	et	3	main
vabadussõja	doc_491521501853_item	2516942	et	3	main
esimese	doc_491521501853_item	2516946	et	3	main
kommertsgümnaasiumi	doc_491521501853_item	2516952	et	4	main
seas	doc_491521501853_item	2516954	et	4	main
peategelane	doc_491521501853_item	2516964	et	3	main
ahas	doc_491521501853_item	2516966	et	4	main
suuda	doc_491521501853_item	2516968	et	4	main
otsustada	doc_491521501853_item	2516969	et	3	main
punaseid	doc_491521501853_item	2516976	et	4	main
nende	doc_491521501853_item	2516980	et	4	main
vanem	doc_491521501853_item	2516983	et	4	main
ning	doc_491521501853_item	2516985	et	3	main
teiselt	doc_491521501853_item	2516986	et	4	main
arusaam	doc_491521501853_item	2516988	et	3	main
vabadust	doc_491521501853_item	2517027	et	4	main
kui	doc_491521501853_item	2517028	et	3	main
kultuuri	doc_491521501853_item	2517032	et	4	main
keelt	doc_491521501853_item	2517034	et	4	main
ja	doc_491521501853_item	2517046	et	3	main
kohal	doc_491521501853_item	2517051	et	4	main
inimese	doc_491521501853_item	2517054	et	4	main
alguses	doc_491521501853_item	2517069	et	4	main
nendel	doc_491521501853_item	2517075	et	4	main
ei	doc_491521501853_item	2517077	et	4	main
arenguloos	doc_491521501853_item	2517086	et	4	main
terve	doc_491521501853_item	2517089	et	4	main
veel	doc_491521501853_item	2517091	et	4	main
ilusamaks	doc_491521501853_item	2517092	et	4	main
marta	doc_491521501853_item	2517100	et	4	main
oli	doc_491521501853_item	2517104	et	3	main
selle	doc_491521501853_item	2517106	et	4	main
eest	doc_491521501853_item	2517107	et	4	main
ka	doc_491521501853_item	2517108	et	3	main
jätis	doc_491521501853_item	2517117	et	4	main
kustumatu	doc_491521501853_item	2517120	et	4	main
ja	doc_491521501853_item	2517122	et	3	main
eestimaa	doc_491521501853_item	2517132	et	4	main
marmortahvlil	doc_491521501854_item	2517142	et	3	main
eestit	doc_491521501854_item	2517151	et	3	main
valitsus	doc_491521501852_item	2516729	et	4	main
tõttu	doc_491521501852_item	2516734	et	4	main
mobilisatsiooni	doc_491521501852_item	2516740	et	4	main
tugeva	doc_491521501852_item	2516743	et	4	main
valla-	doc_491521501852_item	2516748	et	4	main
maakonnavalitsused	doc_491521501852_item	2516752	et	3	main
vaid	doc_491521501852_item	2516762	et	3	main
noor	doc_491521501852_item	2516768	et	3	main
eesti	doc_491521501852_item	2516769	et	4	main
kaitsevägi	doc_491521501852_item	2516770	et	3	main
täitis	doc_491521501852_item	2516771	et	3	main
auga	doc_491521501852_item	2516772	et	3	main
oma	doc_491521501852_item	2516773	et	4	main
ülesande	doc_491521501852_item	2516774	et	4	main
та	doc_491521501852_item	2516775	et	2	main
löi	doc_491521501852_item	2516776	et	4	main
enamlaste	doc_491521501852_item	2516777	et	4	main
anarhistliku	doc_491521501852_item	2516778	et	3	main
punaarmee	doc_491521501852_item	2516779	et	4	main
kodumaa	doc_491521501852_item	2516780	et	4	main
piiridest	doc_491521501852_item	2516781	et	3	main
välja	doc_491521501852_item	2516782	et	4	main
ja	doc_491521501852_item	2516783	et	3	main
viis	doc_491521501852_item	2516784	et	4	main
kaitsevõitluse	doc_491521501852_item	2516785	et	3	main
venemaa	doc_491521501852_item	2516786	et	4	main
pinnale	doc_491521501852_item	2516787	et	3	main
eesti	doc_491521501852_item	2516788	et	4	main
ning	doc_491521501852_item	2516738	et	3	main
moodustamiseks	doc_491521501852_item	2516745	et	4	main
ja	doc_491521501852_item	2516751	et	3	main
ajutiselt	doc_491521501852_item	2516753	et	4	main
sõjaväevalitsusteks	doc_491521501852_item	2516754	et	3	main
need	doc_491521501852_item	2516755	et	3	main
pidanud	doc_491521501852_item	2516757	et	4	main
enam	doc_491521501852_item	2516758	et	4	main
näitama	doc_491521501852_item	2516763	et	3	main
ja	doc_491521501852_item	2516794	et	3	main
landeswehri	doc_491521501852_item	2516803	et	4	main
jõududele	doc_491521501852_item	2516805	et	3	main
ja	doc_491521501852_item	2516812	et	3	main
tunnustamise	doc_491521501852_item	2516825	et	4	main
et	doc_491521501852_item	2516832	et	3	main
ise	doc_491521501852_item	2516834	et	4	main
vabaduse	doc_491521501852_item	2516836	et	4	main
kätte	doc_491521501852_item	2516837	et	4	main
film	doc_491521501852_item	2516843	et	3	main
romaan	doc_491521501852_item	2516845	et	3	main
tähsust	doc_491521501852_item	2516850	et	4	main
tulnud	doc_491521501852_item	2516860	et	4	main
ja	doc_491521501852_item	2516876	et	3	main
taas	doc_491521501852_item	2516883	et	3	main
seisvatele	doc_491521501852_item	2516885	et	4	main
on	doc_491521501852_item	2516889	et	4	main
ning	doc_491521501852_item	2516892	et	3	main
tundrani	doc_491521501852_item	2516901	et	3	main
eest	doc_491521501852_item	2516908	et	4	main
langenuile	doc_491521501852_item	2516909	et	4	main
rahvas	doc_491521501852_item	2516913	et	4	main
kes	doc_491521501852_item	2516914	et	4	main
kunagi	doc_491521501852_item	2516919	et	3	main
ning	doc_491521501852_item	2516921	et	3	main
kes	doc_491521501852_item	2516923	et	4	main
võitluse	doc_491521501852_item	2516925	et	3	main
vabaduse	doc_491521501852_item	2516926	et	4	main
eest	doc_491521501852_item	2516927	et	4	main
võib	doc_491521501852_item	2516928	et	3	main
romaani	doc_491521501853_item	2516937	et	4	main
tegevustik	doc_491521501853_item	2516948	et	3	main
lahknemist	doc_491521501853_item	2516963	et	4	main
tema	doc_491521501853_item	2516973	et	4	main
ühelt	doc_491521501853_item	2516974	et	3	main
poolt	doc_491521501853_item	2516975	et	4	main
ja	doc_491521501853_item	2516979	et	3	main
võitlev	doc_491521501853_item	2516982	et	4	main
poolt	doc_491521501853_item	2516987	et	4	main
põhjaosa	doc_491521501852_item	2516793	et	4	main
selle	doc_491521501852_item	2516797	et	4	main
surmava	doc_491521501852_item	2516801	et	4	main
hoobi	doc_491521501852_item	2516802	et	4	main
tagurlikele	doc_491521501852_item	2516804	et	3	main
kõrvaldanud	doc_491521501852_item	2516807	et	4	main
tõid	doc_491521501852_item	2516822	et	4	main
meie	doc_491521501852_item	2516823	et	4	main
iseseisvuse	doc_491521501852_item	2516824	et	4	main
tunnustati	doc_491521501852_item	2516829	et	4	main
olime	doc_491521501852_item	2516833	et	3	main
endale	doc_491521501852_item	2516835	et	4	main
tundub	doc_491521501852_item	2516841	et	3	main
ja	doc_491521501852_item	2516844	et	3	main
nimed	doc_491521501852_item	2516888	et	3	main
mälestusmärk	doc_491521501852_item	2516905	et	3	main
ei	doc_491521501852_item	2516917	et	4	main
vabadust	doc_491521501852_item	2516920	et	4	main
selle	doc_491521501852_item	2516929	et	4	main
kergelt	doc_491521501852_item	2516930	et	4	main
kaotada	doc_491521501852_item	2516931	et	3	main
nimed	doc_491521501853_item	2516932	et	3	main
marmortahvlil	doc_491521501853_item	2516933	et	3	main
esse	doc_491521501853_item	2516934	et	3	main
1920ndatel	doc_491521501853_item	2516944	et	4	main
aastatel	doc_491521501853_item	2516945	et	4	main
ме	doc_491521501853_item	2516955	et	2	main
näeme	doc_491521501853_item	2516956	et	3	main
rahvuslase	doc_491521501853_item	2516957	et	3	main
käsperi	doc_491521501853_item	2516958	et	4	main
ja	doc_491521501853_item	2516959	et	3	main
kommunist	doc_491521501853_item	2516960	et	3	main
käämeri	doc_491521501853_item	2516961	et	3	main
henn	doc_491521501853_item	2516965	et	4	main
ei	doc_491521501853_item	2516967	et	4	main
kelle	doc_491521501853_item	2516970	et	4	main
рооlеl	doc_491521501853_item	2516971	et	2	main
ootav	doc_491521501853_item	2516977	et	4	main
vend	doc_491521501853_item	2516984	et	3	main
kes	doc_491521501853_item	2517022	et	4	main
säilida	doc_491521501853_item	2517024	et	3	main
mul	doc_491521501853_item	2517025	et	3	main
eesti	doc_491521501853_item	2517030	et	4	main
ja	doc_491521501853_item	2517033	et	3	main
ei	doc_491521501853_item	2517035	et	4	main
tähtsal	doc_491521501853_item	2517050	et	3	main
on	doc_491521501853_item	2517052	et	4	main
näidatud	doc_491521501853_item	2517053	et	4	main
surmahirm	doc_491521501853_item	2517074	et	3	main
nüüd	doc_491521501853_item	2517093	et	4	main
tundis	doc_491521501853_item	2517094	et	3	main
armastatu	doc_491521501853_item	2517099	et	4	main
eest	doc_491521501853_item	2517102	et	4	main
kokkuvõtteks	doc_491521501853_item	2517112	et	3	main
et	doc_491521501853_item	2517115	et	3	main
kõike	doc_491521501853_item	2517125	et	4	main
eest	doc_491521501853_item	2517134	et	4	main
nimed	doc_491521501854_item	2517135	et	3	main
nimed	doc_491521501854_item	2517141	et	3	main
mis	doc_491521501854_item	2517145	et	4	main
kirjeldab	doc_491521501854_item	2517150	et	3	main
sellele	doc_491521501854_item	2517161	et	4	main
et	doc_491521501854_item	2517162	et	3	main
film	doc_491521501854_item	2517163	et	3	main
tehtud	doc_491521501854_item	2517165	et	4	main
väga	doc_491521501854_item	2517166	et	3	main
mis	doc_491521501854_item	2517173	et	4	main
mulle	doc_491521501854_item	2517174	et	4	main
teine	doc_491521501854_item	2517192	et	3	main
ja	doc_491521501854_item	2517200	et	3	main
kaitsmises	doc_491521501854_item	2517201	et	4	main
kas	doc_491521501854_item	2517224	et	3	main
või	doc_491521501854_item	2517226	et	4	main
ja	doc_491521501854_item	2517228	et	3	main
otsuse	doc_491521501854_item	2517231	et	3	main
läheb	doc_491521501854_item	2517240	et	3	main
koos	doc_491521501854_item	2517242	et	4	main
kui	doc_491521501854_item	2517252	et	3	main
seda	doc_491521501854_item	2517254	et	3	main
minna	doc_491521501854_item	2517263	et	3	main
tagasi	doc_491521501854_item	2517264	et	3	main
tema	doc_491521501854_item	2517281	et	4	main
meid	doc_491521501852_item	2516826	et	4	main
ja	doc_491521501852_item	2516828	et	3	main
just	doc_491521501852_item	2516830	et	3	main
et	doc_491521501852_item	2516842	et	3	main
erlist	doc_491521501852_item	2516849	et	4	main
jaoks	doc_491521501852_item	2516852	et	4	main
on	doc_491521501852_item	2516859	et	4	main
teha	doc_491521501852_item	2516861	et	3	main
valik	doc_491521501852_item	2516862	et	3	main
alistumise	doc_491521501852_item	2516863	et	4	main
ja	doc_491521501852_item	2516864	et	3	main
vastupanu	doc_491521501852_item	2516865	et	4	main
vahel	doc_491521501852_item	2516866	et	4	main
ма	doc_491521501852_item	2516867	et	2	main
pooldan	doc_491521501852_item	2516868	et	3	main
mart	doc_491521501852_item	2516869	et	3	main
laari	doc_491521501852_item	2516870	et	4	main
arvamust	doc_491521501852_item	2516871	et	3	main
et	doc_491521501852_item	2516872	et	3	main
kõigi	doc_491521501852_item	2516873	et	4	main
vastupanu	doc_491521501852_item	2516874	et	4	main
valinute	doc_491521501852_item	2516875	et	4	main
võitluses	doc_491521501852_item	2516877	et	3	main
langenute	doc_491521501852_item	2516878	et	4	main
nimesid	doc_491521501852_item	2516879	et	3	main
pole	doc_491521501852_item	2516880	et	3	main
nende	doc_491521501852_item	2516887	et	4	main
teadmata	doc_491521501852_item	2516891	et	4	main
laiali	doc_491521501852_item	2516897	et	3	main
kõigile	doc_491521501852_item	2516906	et	4	main
öeldud	doc_491521501852_item	2516912	et	4	main
saavuta	doc_491521501852_item	2516918	et	4	main
albert	doc_491521501853_item	2516935	et	4	main
kivika	doc_491521501853_item	2516936	et	4	main
ajal	doc_491521501853_item	2516943	et	4	main
рооlе	doc_491521501853_item	2516947	et	2	main
sealse	doc_491521501853_item	2516951	et	3	main
õpilaste	doc_491521501853_item	2516953	et	4	main
maailmavaadete	doc_491521501853_item	2516962	et	3	main
on	doc_491521501853_item	2516972	et	4	main
sellest	doc_491521501853_item	2516989	et	4	main
et	doc_491521501853_item	2516990	et	3	main
inimene	doc_491521501853_item	2517021	et	3	main
soovis	doc_491521501853_item	2517023	et	4	main
rahva	doc_491521501853_item	2517031	et	3	main
isamaa	doc_491521501853_item	2517040	et	4	main
kaitsmisest	doc_491521501853_item	2517041	et	4	main
samamoodi	doc_491521501853_item	2517042	et	3	main
mõtles	doc_491521501853_item	2517043	et	3	main
ka	doc_491521501853_item	2517044	et	3	main
henn	doc_491521501853_item	2517045	et	4	main
pataljoni	doc_491521501853_item	2517049	et	4	main
väljakannatamatu	doc_491521501853_item	2517070	et	4	main
kunagi	doc_491521501853_item	2517076	et	3	main
kao	doc_491521501853_item	2517078	et	4	main
armastuse	doc_491521501853_item	2517079	et	4	main
liin	doc_491521501853_item	2517080	et	3	main
mängib	doc_491521501853_item	2517081	et	3	main
ka	doc_491521501853_item	2517082	et	3	main
suurt	doc_491521501853_item	2517083	et	3	main
ning	doc_491521501853_item	2517087	et	3	main
teeb	doc_491521501853_item	2517088	et	3	main
vastutust	doc_491521501853_item	2517096	et	4	main
ja	doc_491521501853_item	2517103	et	3	main
nõus	doc_491521501853_item	2517105	et	4	main
makst	doc_491521501853_item	2517111	et	4	main
tahan	doc_491521501853_item	2517113	et	3	main
mu	doc_491521501853_item	2517118	et	3	main
soovi	doc_491521501853_item	2517123	et	4	main
olid	doc_491521501853_item	2517130	et	4	main
iseseisvuse	doc_491521501853_item	2517133	et	4	main
marmortahvlil	doc_491521501854_item	2517136	et	3	main
on	doc_491521501854_item	2517143	et	4	main
tegelikult	doc_491521501854_item	2517147	et	4	main
asetleidnule	doc_491521501854_item	2517148	et	3	main
oli	doc_491521501854_item	2517164	et	3	main
see	doc_491521501854_item	2517168	et	3	main
ei	doc_491521501854_item	2517182	et	4	main
olnud	doc_491521501854_item	2517183	et	4	main
näidatud	doc_491521501854_item	2517184	et	4	main
on	doc_491521501854_item	2517188	et	4	main
ja	doc_491521501854_item	2517190	et	3	main
arvan	doc_491521501854_item	2517203	et	3	main
on	doc_491521501854_item	2517222	et	4	main
lõppuks	doc_491521501854_item	2517229	et	3	main
teeb	doc_491521501854_item	2517230	et	3	main
sõdima	doc_491521501854_item	2517241	et	3	main
otsus	doc_491521501854_item	2517251	et	3	main
võiks	doc_491521501854_item	2517257	et	4	main
jääda	doc_491521501854_item	2517258	et	4	main
ka	doc_491521501854_item	2517259	et	3	main
muidigi	doc_491521501854_item	2517269	et	4	main
henni	doc_491521501854_item	2517277	et	4	main
on	doc_491521501854_item	2517283	et	4	main
sammuti	doc_491521501854_item	2517284	et	3	main
ja	doc_491521501854_item	2517290	et	3	main
siin	doc_491521501854_item	2517328	et	4	main
valu	doc_491521501854_item	2517334	et	4	main
valu	doc_491521501854_item	2517335	et	4	main
sellest	doc_491521501854_item	2517336	et	4	main
et	doc_491521501854_item	2517337	et	3	main
kodumaa	doc_491521501854_item	2517338	et	4	main
jäi	doc_491521501854_item	2517339	et	3	main
nii	doc_491521501854_item	2517347	et	3	main
ristideta	doc_491521501852_item	2516894	et	4	main
on	doc_491521501852_item	2516896	et	4	main
eesti	doc_491521501852_item	2516898	et	4	main
soodest-metsadest	doc_491521501852_item	2516899	et	3	main
siberi	doc_491521501852_item	2516900	et	4	main
nimed	doc_491521501852_item	2516902	et	3	main
marmortahvlil	doc_491521501852_item	2516903	et	3	main
on	doc_491521501852_item	2516904	et	4	main
eesti	doc_491521501852_item	2516907	et	4	main
sest	doc_491521501852_item	2516910	et	4	main
ei	doc_491521501852_item	2516915	et	4	main
nimed	doc_491521501853_item	2516938	et	3	main
marmortahvlil	doc_491521501853_item	2516939	et	3	main
süzee	doc_491521501853_item	2516940	et	4	main
toimub	doc_491521501853_item	2516941	et	3	main
hargneb	doc_491521501853_item	2516949	et	3	main
tartus	doc_491521501853_item	2516950	et	3	main
isa	doc_491521501853_item	2516978	et	4	main
рооlеl	doc_491521501853_item	2516981	et	2	main
ta	doc_491521501853_item	2516991	et	4	main
iialgi	doc_491521501853_item	2516992	et	4	main
ei	doc_491521501853_item	2516993	et	4	main
suudaks	doc_491521501853_item	2516994	et	3	main
võidelda	doc_491521501853_item	2516995	et	4	main
oma	doc_491521501853_item	2516996	et	4	main
rahva	doc_491521501853_item	2516997	et	3	main
vastu	doc_491521501853_item	2516998	et	3	main
kas	doc_491521501853_item	2516999	et	3	main
olla	doc_491521501853_item	2517000	et	3	main
või	doc_491521501853_item	2517001	et	4	main
mitte	doc_491521501853_item	2517002	et	3	main
olla	doc_491521501853_item	2517003	et	3	main
ja	doc_491521501853_item	2517004	et	3	main
kui	doc_491521501853_item	2517005	et	3	main
olla	doc_491521501853_item	2517006	et	3	main
siis	doc_491521501853_item	2517007	et	3	main
kuidas	doc_491521501853_item	2517008	et	3	main
sellele	doc_491521501853_item	2517009	et	4	main
küsimusele	doc_491521501853_item	2517010	et	4	main
pidi	doc_491521501853_item	2517011	et	4	main
leidma	doc_491521501853_item	2517012	et	3	main
iga	doc_491521501853_item	2517014	et	4	main
vastust	doc_491521501853_item	2517013	et	4	main
eestimaa	doc_491521501853_item	2517015	et	4	main
elanik	doc_491521501853_item	2517016	et	3	main
ma	doc_491521501853_item	2517017	et	3	main
usun	doc_491521501853_item	2517018	et	3	main
et	doc_491521501853_item	2517019	et	3	main
iga	doc_491521501853_item	2517020	et	4	main
isikliku	doc_491521501853_item	2517026	et	3	main
saanud	doc_491521501853_item	2517036	et	4	main
kõrvale	doc_491521501853_item	2517037	et	4	main
hoiduda	doc_491521501853_item	2517038	et	3	main
surmaohus	doc_491521501853_item	2517039	et	3	main
astus	doc_491521501853_item	2517047	et	3	main
isegi	doc_491521501853_item	2517071	et	4	main
harjudes	doc_491521501853_item	2517073	et	3	main
peategelane	doc_491521501853_item	2517095	et	3	main
oma	doc_491521501853_item	2517098	et	4	main
oma	doc_491521501853_item	2517109	et	4	main
eluga	doc_491521501853_item	2517110	et	3	main
ka	doc_491521501853_item	2517029	et	3	main
vabatahtlike	doc_491521501853_item	2517048	et	3	main
muutmist	doc_491521501853_item	2517055	et	4	main
sõjas	doc_491521501853_item	2517056	et	3	main
ja	doc_491521501853_item	2517057	et	3	main
kuidas	doc_491521501853_item	2517058	et	3	main
inimene	doc_491521501853_item	2517059	et	3	main
sunnitakse	doc_491521501853_item	2517060	et	4	main
harjuma	doc_491521501853_item	2517061	et	3	main
sõjaga	doc_491521501853_item	2517062	et	3	main
sest	doc_491521501853_item	2517063	et	4	main
noortele	doc_491521501853_item	2517064	et	3	main
poistele	doc_491521501853_item	2517065	et	3	main
see	doc_491521501853_item	2517066	et	3	main
reaalsus	doc_491521501853_item	2517067	et	4	main
oli	doc_491521501853_item	2517068	et	3	main
lahingutega	doc_491521501853_item	2517072	et	4	main
rolli	doc_491521501853_item	2517084	et	4	main
henni	doc_491521501853_item	2517085	et	4	main
romaani	doc_491521501853_item	2517090	et	4	main
ka	doc_491521501853_item	2517097	et	3	main
еlu	doc_491521501853_item	2517101	et	2	main
öеldа	doc_491521501853_item	2517114	et	2	main
romaan	doc_491521501853_item	2517116	et	3	main
südames	doc_491521501853_item	2517119	et	3	main
muljet	doc_491521501853_item	2517121	et	3	main
tänada	doc_491521501853_item	2517124	et	3	main
neid	doc_491521501853_item	2517126	et	4	main
kes	doc_491521501853_item	2517127	et	4	main
maksnud	doc_491521501853_item	2517131	et	4	main
albert	doc_491521501854_item	2517137	et	4	main
kivikas	doc_491521501854_item	2517138	et	4	main
nimed	doc_491521501854_item	2517139	et	3	main
tugineb	doc_491521501854_item	2517146	et	3	main
vaimustatud	doc_491521501854_item	2517159	et	4	main
lisaks	doc_491521501854_item	2517160	et	4	main
professionaalselt	doc_491521501854_item	2517167	et	4	main
väga	doc_491521501854_item	2517171	et	3	main
emotsionaalne	doc_491521501854_item	2517172	et	3	main
kõige	doc_491521501854_item	2517175	et	4	main
rohkem	doc_491521501854_item	2517176	et	4	main
meeldis	doc_491521501854_item	2517177	et	3	main
oli	doc_491521501854_item	2517178	et	3	main
see	doc_491521501854_item	2517179	et	3	main
et	doc_491521501854_item	2517180	et	3	main
et	doc_491521501854_item	2517185	et	3	main
mingi	doc_491521501854_item	2517191	et	4	main
on	doc_491521501854_item	2517193	et	4	main
hea	doc_491521501854_item	2517194	et	4	main
ma	doc_491521501854_item	2517202	et	3	main
venna	doc_491521501854_item	2517237	et	3	main
omast	doc_491521501854_item	2517238	et	4	main
ja	doc_491521501854_item	2517239	et	3	main
oma	doc_491521501854_item	2517243	et	4	main
klassivendadega	doc_491521501854_item	2517244	et	3	main
see	doc_491521501854_item	2517245	et	3	main
ma	doc_491521501854_item	2517246	et	3	main
arvan	doc_491521501854_item	2517247	et	3	main
on	doc_491521501854_item	2517248	et	4	main
väga	doc_491521501854_item	2517249	et	3	main
et	doc_491521501854_item	2517255	et	3	main
erapooletuks	doc_491521501854_item	2517260	et	4	main
ja	doc_491521501854_item	2517261	et	3	main
juurde	doc_491521501854_item	2517268	et	4	main
romaan	doc_491521501854_item	2517271	et	3	main
saa	doc_491521501854_item	2517273	et	4	main
olla	doc_491521501854_item	2517274	et	3	main
armsam	doc_491521501854_item	2517278	et	4	main
marta	doc_491521501854_item	2517291	et	4	main
ainult	doc_491521501854_item	2517321	et	4	main
on	doc_491521501854_item	2517325	et	4	main
palju	doc_491521501854_item	2517331	et	4	main
emotsioone	doc_491521501854_item	2517332	et	3	main
ja	doc_491521501854_item	2517333	et	3	main
teise	doc_491521501854_item	2517340	et	4	main
riigi	doc_491521501854_item	2517341	et	3	main
paljud	doc_491521501854_item	2517348	et	3	main
ei	doc_491521501854_item	2517358	et	4	main
võitlesid	doc_491521501854_item	2517373	et	4	main
oma	doc_491521501853_item	2517128	et	4	main
eluga	doc_491521501853_item	2517129	et	3	main
marmortahvlil	doc_491521501854_item	2517140	et	3	main
romaan	doc_491521501854_item	2517144	et	3	main
see	doc_491521501854_item	2517149	et	3	main
ajal	doc_491521501854_item	2517153	et	4	main
filmi	doc_491521501854_item	2517155	et	4	main
rahvus	doc_491521501854_item	2517187	et	3	main
paha	doc_491521501854_item	2517189	et	4	main
oma	doc_491521501854_item	2517197	et	4	main
isamaa	doc_491521501854_item	2517198	et	4	main
armastamises	doc_491521501854_item	2517199	et	4	main
romaani	doc_491521501854_item	2517205	et	4	main
autor	doc_491521501854_item	2517206	et	3	main
a	doc_491521501854_item	2517207	et	4	main
kivikas	doc_491521501854_item	2517208	et	4	main
väljendas	doc_491521501854_item	2517209	et	3	main
seda	doc_491521501854_item	2517210	et	3	main
väga	doc_491521501854_item	2517211	et	3	main
hästi	doc_491521501854_item	2517212	et	3	main
see	doc_491521501854_item	2517213	et	3	main
kuidas	doc_491521501854_item	2517214	et	3	main
peategelane	doc_491521501854_item	2517215	et	3	main
henn	doc_491521501854_item	2517216	et	4	main
ahas	doc_491521501854_item	2517217	et	4	main
püüab	doc_491521501854_item	2517218	et	3	main
otsustada	doc_491521501854_item	2517219	et	3	main
kumma	doc_491521501854_item	2517220	et	3	main
poolel	doc_491521501854_item	2517221	et	4	main
puneste	doc_491521501854_item	2517225	et	4	main
rahvuslaste	doc_491521501854_item	2517227	et	4	main
mis	doc_491521501854_item	2517232	et	4	main
erineb	doc_491521501854_item	2517233	et	3	main
tema	doc_491521501854_item	2517234	et	4	main
vapper	doc_491521501854_item	2517250	et	3	main
lihtsalt	doc_491521501854_item	2517262	et	4	main
koju	doc_491521501854_item	2517265	et	3	main
vanemate	doc_491521501854_item	2517267	et	4	main
ilma	doc_491521501854_item	2517275	et	4	main
armastuseta	doc_491521501854_item	2517276	et	4	main
ja	doc_491521501854_item	2517280	et	3	main
küll	doc_491521501854_item	2517326	et	4	main
teada	doc_491521501854_item	2517327	et	3	main
võimu	doc_491521501854_item	2517342	et	4	main
noored	doc_491521501854_item	2517349	et	3	main
kes	doc_491521501854_item	2517351	et	4	main
võinud	doc_491521501854_item	2517353	et	4	main
päikesevalgust	doc_491521501854_item	2517361	et	4	main
mäletavad	doc_491521501854_item	2517365	et	4	main
neid	doc_491521501854_item	2517366	et	4	main
nad	doc_491521501854_item	2517372	et	3	main
vabadussõja	doc_491521501854_item	2517152	et	3	main
vaadates	doc_491521501854_item	2517154	et	3	main
ma	doc_491521501854_item	2517156	et	3	main
olin	doc_491521501854_item	2517157	et	3	main
väga	doc_491521501854_item	2517158	et	3	main
on	doc_491521501854_item	2517169	et	4	main
ka	doc_491521501854_item	2517170	et	3	main
filmis	doc_491521501854_item	2517181	et	4	main
üks	doc_491521501854_item	2517186	et	3	main
põhiidee	doc_491521501854_item	2517195	et	4	main
oli	doc_491521501854_item	2517196	et	3	main
et	doc_491521501854_item	2517204	et	3	main
tema	doc_491521501854_item	2517223	et	4	main
isa	doc_491521501854_item	2517235	et	4	main
ja	doc_491521501854_item	2517236	et	3	main
arvestada	doc_491521501854_item	2517253	et	3	main
ta	doc_491521501854_item	2517256	et	4	main
oma	doc_491521501854_item	2517266	et	4	main
ükski	doc_491521501854_item	2517270	et	4	main
ei	doc_491521501854_item	2517272	et	4	main
marta	doc_491521501854_item	2517279	et	4	main
surma	doc_491521501854_item	2517289	et	4	main
jääb	doc_491521501854_item	2517292	et	3	main
üksi	doc_491521501854_item	2517293	et	4	main
no	doc_491521501854_item	2517294	et	3	main
aga	doc_491521501854_item	2517295	et	3	main
loomulikult	doc_491521501854_item	2517296	et	4	main
henn	doc_491521501854_item	2517297	et	4	main
leiab	doc_491521501854_item	2517298	et	3	main
üles	doc_491521501854_item	2517299	et	3	main
oma	doc_491521501854_item	2517300	et	4	main
armsama	doc_491521501854_item	2517301	et	4	main
ja	doc_491521501854_item	2517302	et	3	main
nad	doc_491521501854_item	2517303	et	3	main
astuvad	doc_491521501854_item	2517304	et	4	main
teel	doc_491521501854_item	2517305	et	4	main
kodu	doc_491521501854_item	2517306	et	4	main
poole	doc_491521501854_item	2517307	et	4	main
mis	doc_491521501854_item	2517308	et	4	main
nende	doc_491521501854_item	2517309	et	4	main
jaoks	doc_491521501854_item	2517310	et	4	main
on	doc_491521501854_item	2517311	et	4	main
nüüd	doc_491521501854_item	2517312	et	4	main
tartu	doc_491521501854_item	2517313	et	4	main
minu	doc_491521501854_item	2517314	et	3	main
meelest	doc_491521501854_item	2517315	et	4	main
on	doc_491521501854_item	2517316	et	4	main
see	doc_491521501854_item	2517317	et	3	main
romaan	doc_491521501854_item	2517318	et	3	main
autobiograafiline	doc_491521501854_item	2517319	et	4	main
mitte	doc_491521501854_item	2517320	et	3	main
onu	doc_491521501854_item	2517282	et	4	main
rahvuslased	doc_491521501854_item	2517285	et	3	main
kuid	doc_491521501854_item	2517286	et	4	main
onu	doc_491521501854_item	2517287	et	4	main
saab	doc_491521501854_item	2517288	et	3	main
minu	doc_491521501854_item	2517322	et	3	main
meelest	doc_491521501854_item	2517323	et	4	main
seda	doc_491521501854_item	2517324	et	3	main
nä	doc_491521501854_item	2517330	et	4	main
sellest	doc_491521501854_item	2517345	et	4	main
et	doc_491521501854_item	2517346	et	3	main
näe	doc_491521501854_item	2517359	et	4	main
ja	doc_491521501854_item	2517367	et	3	main
selle	doc_491521501854_item	2517369	et	4	main
eest	doc_491521501854_item	2517370	et	4	main
et	doc_491521501854_item	2517371	et	3	main
isamaa	doc_491521501854_item	2517375	et	4	main
on	doc_491521501854_item	2517329	et	4	main
ala	doc_491521501854_item	2517343	et	4	main
ja	doc_491521501854_item	2517344	et	3	main
poisid	doc_491521501854_item	2517350	et	4	main
kuid	doc_491521501854_item	2517362	et	4	main
järeltulijad	doc_491521501854_item	2517364	et	3	main
oma	doc_491521501854_item	2517374	et	4	main
eest	doc_491521501854_item	2517376	et	4	main
oleksid	doc_491521501854_item	2517352	et	4	main
veel	doc_491521501854_item	2517354	et	4	main
elada	doc_491521501854_item	2517355	et	3	main
ja	doc_491521501854_item	2517356	et	3	main
elada	doc_491521501854_item	2517357	et	3	main
enam	doc_491521501854_item	2517360	et	4	main
nende	doc_491521501854_item	2517363	et	4	main
tänavad	doc_491521501854_item	2517368	et	4	main
kodutoo	doc_491521501856_item	2518805	et	4	main
ev-51	doc_491521501856_item	2518808	et	4	main
toos	doc_491521501856_item	2518811	et	3	main
eesti	doc_491521501856_item	2518813	et	4	main
kirjakeeiest	doc_491521501856_item	2518823	et	4	main
keelt	doc_491521501856_item	2518831	et	4	main
keelt	doc_491521501856_item	2518840	et	4	main
on	doc_491521501856_item	2518841	et	4	main
moningates	doc_491521501856_item	2518847	et	4	main
tahes	doc_491521501856_item	2518853	et	4	main
selliseid	doc_491521501856_item	2518860	et	4	main
ka	doc_491521501856_item	2518871	et	3	main
toonud	doc_491521501856_item	2518874	et	4	main
tapselt	doc_491521501856_item	2518883	et	4	main
kontroltoo	doc_491521501856_item	2518893	et	4	main
veaanaliiiisi	doc_491521501856_item	2518804	et	4	main
maret	doc_491521501856_item	2518806	et	4	main
toodud	doc_491521501856_item	2518812	et	4	main
naited	doc_491521501856_item	2518817	et	4	main
nii	doc_491521501856_item	2518820	et	3	main
kone-	doc_491521501856_item	2518821	et	4	main
tahelepanekud	doc_491521501856_item	2518824	et	4	main
kus	doc_491521501856_item	2518827	et	3	main
klass	doc_491521501856_item	2518834	et	3	main
kuna	doc_491521501856_item	2518835	et	3	main
opetan	doc_491521501856_item	2518836	et	4	main
taiskasvanutele	doc_491521501856_item	2518837	et	4	main
eesti	doc_491521501856_item	2518839	et	4	main
naiteid	doc_491521501856_item	2518843	et	4	main
it	doc_491521501856_item	2518846	et	4	main
kirjutamise	doc_491521501856_item	2518864	et	4	main
vigu	doc_491521501856_item	2518865	et	3	main
esines	doc_491521501856_item	2518866	et	3	main
olen	doc_491521501856_item	2518870	et	3	main
need	doc_491521501856_item	2518872	et	3	main
haaldus	doc_491521501856_item	2518878	et	4	main
oigekiri	doc_491521501856_item	2518879	et	4	main
tjudruk	doc_491521501856_item	2518880	et	4	main
aias	doc_491521501856_item	2518886	et	4	main
ise	doc_491521501856_item	2518921	et	4	main
artiklit	doc_491521501856_item	2518923	et	3	main
lahme	doc_491521501856_item	2518928	et	4	main
tubasse	doc_491521501856_item	2518929	et	4	main
olen	doc_491521501856_item	2518931	et	3	main
muutu	doc_491521501856_item	2518938	et	4	main
ei	doc_491521501856_item	2518941	et	4	main
taba	doc_491521501856_item	2518942	et	4	main
muutust	doc_491521501856_item	2518945	et	4	main
eesti	doc_491521501856_item	2518947	et	4	main
ara	doc_491521501856_item	2518949	et	3	main
omadussona	doc_491521501856_item	2518955	et	4	main
ikkagi	doc_491521501856_item	2518960	et	4	main
vaga	doc_491521501856_item	2518962	et	4	main
palju	doc_491521501856_item	2518963	et	4	main
vigu	doc_491521501856_item	2518964	et	3	main
bligzna	doc_491521501856_item	2518807	et	4	main
veaanaliiiisi	doc_491521501856_item	2518809	et	4	main
kui	doc_491521501856_item	2518822	et	3	main
koolist	doc_491521501856_item	2518826	et	4	main
eesti	doc_491521501856_item	2518830	et	4	main
algtasemel	doc_491521501856_item	2518838	et	3	main
par	doc_491521501856_item	2518845	et	4	main
on	doc_491521501856_item	2518849	et	4	main
viga	doc_491521501856_item	2518850	et	4	main
vaid	doc_491521501856_item	2518851	et	3	main
kohati	doc_491521501856_item	2518855	et	4	main
see	doc_491521501856_item	2518857	et	3	main
mitmel	doc_491521501856_item	2518867	et	4	main
ja	doc_491521501856_item	2518876	et	3	main
tudruk	doc_491521501856_item	2518881	et	4	main
tjapselt	doc_491521501856_item	2518882	et	4	main
tjana	doc_491521501856_item	2518888	et	4	main
tjootan	doc_491521501856_item	2518890	et	4	main
nad	doc_491521501856_item	2518943	et	3	main
keeles	doc_491521501856_item	2518948	et	4	main
omadussona	doc_491521501856_item	2518950	et	4	main
vordlusastmed	doc_491521501856_item	2518951	et	4	main
j	doc_491521501856_item	2518952	et	4	main
klassis	doc_491521501856_item	2518953	et	3	main
vahel	doc_491521501856_item	2518969	et	4	main
parem	doc_491521501856_item	2518981	et	4	main
vormid	doc_491521501856_item	2518988	et	4	main
kulmim	doc_491521501856_item	2518999	et	4	main
maitsavam	doc_491521501856_item	2519001	et	4	main
vead	doc_491521501856_item	2519004	et	4	main
on	doc_491521501856_item	2519005	et	4	main
taiskasvanute	doc_491521501856_item	2519006	et	4	main
vanemuise	doc_491521501856_item	2519014	et	4	main
seinas	doc_491521501856_item	2519016	et	3	main
kaks	doc_491521501856_item	2519022	et	3	main
on	doc_491521501856_item	2519025	et	4	main
vaja	doc_491521501856_item	2519026	et	4	main
keele	doc_491521501856_item	2519031	et	4	main
kokkuleppeni	doc_491521501856_item	2519036	et	3	main
ks	doc_491521501856_item	2519042	et	4	main
laheb	doc_491521501856_item	2519050	et	4	main
kui	doc_491521501856_item	2519058	et	3	main
saarte	doc_491521501856_item	2519063	et	3	main
1	doc_491521501856_item	2519066	et	2	main
s	doc_491521501856_item	2519070	et	4	main
siis	doc_491521501856_item	2519071	et	3	main
miks	doc_491521501856_item	2519072	et	4	main
jne	doc_491521501856_item	2519076	et	4	main
ainult	doc_491521501856_item	2519085	et	4	main
kas	doc_491521501856_item	2519091	et	3	main
kodutoo	doc_491521501856_item	2518810	et	4	main
kirjakeelest	doc_491521501856_item	2518814	et	4	main
halbiva	doc_491521501856_item	2518815	et	4	main
keelekasutuse	doc_491521501856_item	2518816	et	4	main
kogutud	doc_491521501856_item	2518819	et	4	main
parinevad	doc_491521501856_item	2518825	et	4	main
l	doc_491521501856_item	2518832	et	4	main
5	doc_491521501856_item	2518833	et	2	main
sealt	doc_491521501856_item	2518844	et	4	main
sonades	doc_491521501856_item	2518848	et	4	main
ja	doc_491521501856_item	2518854	et	3	main
tundub	doc_491521501856_item	2518856	et	3	main
opilasel	doc_491521501856_item	2518868	et	4	main
valja	doc_491521501856_item	2518873	et	3	main
ajas	doc_491521501856_item	2518887	et	4	main
kursuse	doc_491521501856_item	2518926	et	3	main
vene	doc_491521501856_item	2518933	et	4	main
keeles	doc_491521501856_item	2518934	et	4	main
sona	doc_491521501856_item	2518935	et	4	main
ja	doc_491521501856_item	2518939	et	3	main
selleparast	doc_491521501856_item	2518940	et	3	main
on	doc_491521501856_item	2518954	et	4	main
moodustamisel	doc_491521501856_item	2518968	et	4	main
sest	doc_491521501856_item	2518973	et	4	main
n	doc_491521501856_item	2518979	et	4	main
kuigi	doc_491521501856_item	2518982	et	3	main
vene	doc_491521501856_item	2518984	et	4	main
on	doc_491521501856_item	2518986	et	4	main
vastavad	doc_491521501856_item	2518987	et	4	main
tarkem	doc_491521501856_item	2518995	et	4	main
ma	doc_491521501856_item	2519009	et	3	main
tanavas	doc_491521501856_item	2519015	et	4	main
iseloomulik	doc_491521501856_item	2519030	et	3	main
voib	doc_491521501856_item	2519039	et	4	main
jaada	doc_491521501856_item	2519040	et	4	main
igauhe	doc_491521501856_item	2519044	et	4	main
oli	doc_491521501856_item	2519045	et	3	main
kohakaanete	doc_491521501856_item	2519047	et	4	main
vead	doc_491521501856_item	2519048	et	4	main
pidevalt	doc_491521501856_item	2519049	et	4	main
jaab	doc_491521501856_item	2519060	et	4	main
puhul	doc_491521501856_item	2519064	et	4	main
mitte	doc_491521501856_item	2519069	et	3	main
tapal	doc_491521501856_item	2519075	et	3	main
on	doc_491521501856_item	2519078	et	4	main
keeles	doc_491521501856_item	2519083	et	4	main
on	doc_491521501856_item	2519084	et	4	main
ja	doc_491521501856_item	2519088	et	3	main
keeles	doc_491521501856_item	2519121	et	4	main
pole	doc_491521501856_item	2519124	et	3	main
ja	doc_491521501856_item	2519125	et	3	main
tekitab	doc_491521501856_item	2519127	et	3	main
kasutamine	doc_491521501856_item	2519132	et	4	main
arvsona	doc_491521501856_item	2519134	et	4	main
antud	doc_491521501856_item	2519142	et	4	main
mitmendaks	doc_491521501856_item	2519145	et	3	main
esimese	doc_491521501856_item	2519166	et	3	main
viis	doc_491521501856_item	2519173	et	4	main
novembril	doc_491521501856_item	2519174	et	3	main
kakskumnendal	doc_491521501856_item	2519178	et	4	main
kaandub	doc_491521501856_item	2519191	et	4	main
keeruliselt	doc_491521501856_item	2519193	et	4	main
tulebki	doc_491521501856_item	2519196	et	3	main
koikvoimalikke	doc_491521501856_item	2519198	et	4	main
saa	doc_491521501856_item	2519202	et	4	main
aru	doc_491521501856_item	2519204	et	4	main
muutu	doc_491521501856_item	2519211	et	4	main
eesti	doc_491521501856_item	2519226	et	4	main
keeles	doc_491521501856_item	2519227	et	4	main
on	doc_491521501856_item	2518818	et	4	main
opetan	doc_491521501856_item	2518828	et	4	main
ise	doc_491521501856_item	2518829	et	4	main
osa	doc_491521501856_item	2518842	et	4	main
iihes	doc_491521501856_item	2518852	et	4	main
lohakusena	doc_491521501856_item	2518858	et	4	main
aga	doc_491521501856_item	2518859	et	3	main
uhe	doc_491521501856_item	2518861	et	4	main
tahe	doc_491521501856_item	2518862	et	4	main
valesti	doc_491521501856_item	2518863	et	3	main
selleparast	doc_491521501856_item	2518869	et	3	main
haaldus	doc_491521501856_item	2518875	et	4	main
oigekiri	doc_491521501856_item	2518877	et	4	main
siia	doc_491521501856_item	2518884	et	4	main
sija	doc_491521501856_item	2518885	et	4	main
tana	doc_491521501856_item	2518889	et	4	main
tootan	doc_491521501856_item	2518891	et	4	main
kantrolltoo	doc_491521501856_item	2518892	et	4	main
taivas	doc_491521501856_item	2518894	et	4	main
taivas	doc_491521501856_item	2518895	et	4	main
taevas	doc_491521501856_item	2518896	et	4	main
vis	doc_491521501856_item	2518897	et	4	main
vis	doc_491521501856_item	2518898	et	4	main
viis	doc_491521501856_item	2518899	et	4	main
kus	doc_491521501856_item	2518900	et	3	main
kus	doc_491521501856_item	2518901	et	3	main
kuus	doc_491521501856_item	2518902	et	4	main
insenar	doc_491521501856_item	2518903	et	4	main
inseneer	doc_491521501856_item	2518904	et	4	main
astmevaheldusvead	doc_491521501856_item	2518905	et	4	main
tutipiline	doc_491521501856_item	2518906	et	4	main
viga	doc_491521501856_item	2518907	et	4	main
ma	doc_491521501856_item	2518908	et	3	main
oppin	doc_491521501856_item	2518909	et	4	main
eesti	doc_491521501856_item	2518910	et	4	main
keelt	doc_491521501856_item	2518911	et	4	main
aga	doc_491521501856_item	2518912	et	3	main
eile	doc_491521501856_item	2518913	et	3	main
ma	doc_491521501856_item	2518914	et	3	main
ei	doc_491521501856_item	2518915	et	4	main
opinud	doc_491521501856_item	2518916	et	4	main
ma	doc_491521501856_item	2518917	et	3	main
hiipan	doc_491521501856_item	2518918	et	4	main
kui	doc_491521501856_item	2518919	et	3	main
te	doc_491521501856_item	2518920	et	4	main
tudeng	doc_491521501856_item	2518927	et	3	main
tuvi	doc_491521501856_item	2518936	et	4	main
ei	doc_491521501856_item	2518937	et	4	main
vordlusastmed	doc_491521501856_item	2518956	et	4	main
osana	doc_491521501856_item	2518958	et	3	main
tehakse	doc_491521501856_item	2518961	et	3	main
eriti	doc_491521501856_item	2518965	et	3	main
algvordest	doc_491521501856_item	2518966	et	4	main
on	doc_491521501856_item	2518970	et	4	main
loomulik	doc_491521501856_item	2518972	et	3	main
eesti	doc_491521501856_item	2518974	et	4	main
keeles	doc_491521501856_item	2518975	et	4	main
hea	doc_491521501856_item	2518980	et	4	main
seda	doc_491521501856_item	2518922	et	3	main
lugeksite	doc_491521501856_item	2518924	et	4	main
v	doc_491521501856_item	2518925	et	4	main
ma	doc_491521501856_item	2518930	et	3	main
tubas	doc_491521501856_item	2518932	et	4	main
seda	doc_491521501856_item	2518944	et	3	main
ka	doc_491521501856_item	2518946	et	3	main
kordava	doc_491521501856_item	2518957	et	4	main
ja	doc_491521501856_item	2518959	et	3	main
keskvorde	doc_491521501856_item	2518967	et	4	main
see	doc_491521501856_item	2518971	et	3	main
ebareegliparaseid	doc_491521501856_item	2518977	et	3	main
jordlusastmeid	doc_491521501856_item	2518978	et	4	main
tark	doc_491521501856_item	2518994	et	3	main
halb	doc_491521501856_item	2518996	et	3	main
kaandevead	doc_491521501856_item	2519002	et	4	main
parit	doc_491521501856_item	2519008	et	4	main
olen	doc_491521501856_item	2519010	et	3	main
elab	doc_491521501856_item	2519013	et	3	main
kaks	doc_491521501856_item	2519018	et	3	main
seinalambid	doc_491521501856_item	2519019	et	3	main
tubas	doc_491521501856_item	2519020	et	4	main
tudengite	doc_491521501856_item	2519028	et	3	main
jaoks	doc_491521501856_item	2519033	et	4	main
oleme	doc_491521501856_item	2519034	et	3	main
joudnud	doc_491521501856_item	2519035	et	4	main
le	doc_491521501856_item	2519037	et	4	main
pohjus	doc_491521501856_item	2519038	et	4	main
peaaegu	doc_491521501856_item	2519043	et	3	main
kas	doc_491521501856_item	2519052	et	3	main
on	doc_491521501856_item	2519053	et	4	main
meelde	doc_491521501856_item	2519061	et	3	main
on	doc_491521501856_item	2519065	et	4	main
lopus	doc_491521501856_item	2519067	et	4	main
ja	doc_491521501856_item	2519068	et	3	main
vead	doc_491521501856_item	2519077	et	4	main
tingitud	doc_491521501856_item	2519079	et	4	main
sellest	doc_491521501856_item	2519080	et	4	main
et	doc_491521501856_item	2519081	et	3	main
eessona	doc_491521501856_item	2519086	et	4	main
otsest	doc_491521501856_item	2519122	et	4	main
vastet	doc_491521501856_item	2519123	et	3	main
seega	doc_491521501856_item	2519126	et	4	main
eesti	doc_491521501856_item	2519128	et	4	main
sonade	doc_491521501856_item	2519131	et	4	main
kusimus	doc_491521501856_item	2519139	et	3	main
siis	doc_491521501856_item	2519159	et	3	main
kui	doc_491521501856_item	2519164	et	3	main
ikka	doc_491521501856_item	2519170	et	4	main
oeldakse	doc_491521501856_item	2519171	et	4	main
kahekummend	doc_491521501856_item	2519172	et	4	main
november	doc_491521501856_item	2519177	et	3	main
nagu	doc_491521501856_item	2519184	et	3	main
teatakse	doc_491521501856_item	2519189	et	3	main
nad	doc_491521501856_item	2519200	et	3	main
ei	doc_491521501856_item	2519210	et	4	main
lugu	doc_491521501856_item	2519221	et	4	main
oma	doc_491521501856_item	2519223	et	4	main
vanuse	doc_491521501856_item	2519224	et	4	main
utlemisega	doc_491521501856_item	2519225	et	4	main
varianti	doc_491521501856_item	2519230	et	4	main
kuidas	doc_491521501856_item	2519231	et	3	main
aastane	doc_491521501856_item	2519238	et	4	main
kumme	doc_491521501856_item	2519241	et	3	main
vene	doc_491521501856_item	2519245	et	4	main
keeles	doc_491521501856_item	2519246	et	4	main
mxe	doc_491521501856_item	2519253	et	4	main
ja	doc_491521501856_item	2519268	et	3	main
novemberil	doc_491521501856_item	2519275	et	3	main
on	doc_491521501856_item	2519277	et	4	main
kolmkummenes	doc_491521501856_item	2519278	et	4	main
kusida	doc_491521501856_item	2519281	et	4	main
juhul	doc_491521501856_item	2519289	et	3	main
esimese	doc_491521501856_item	2519293	et	3	main
tahendus	doc_491521501856_item	2519326	et	4	main
jargnevad	doc_491521501856_item	2519332	et	4	main
ilusalt	doc_491521501856_item	2519337	et	4	main
mida	doc_491521501856_item	2519342	et	4	main
mojust	doc_491521501856_item	2519355	et	4	main
tundi	doc_491521501856_item	2519372	et	4	main
poorata	doc_491521501856_item	2519377	et	4	main
keelepraktikat	doc_491521501856_item	2519391	et	3	main
rohkem	doc_491521501856_item	2519393	et	4	main
tallinna	doc_491521501857_item	2519396	et	4	main
eperekonnanimi	doc_491521501857_item	2519405	et	4	main
teeb	doc_491521501857_item	2519409	et	3	main
meistriks	doc_491521501857_item	2519410	et	3	main
see	doc_491521501857_item	2519412	et	3	main
meeleolu	doc_491521501857_item	2519436	et	4	main
on	doc_491521501856_item	2518976	et	4	main
olemas	doc_491521501856_item	2518989	et	4	main
xopomo	doc_491521501856_item	2518990	et	4	main
jiykue	doc_491521501856_item	2518991	et	4	main
hea	doc_491521501856_item	2518992	et	4	main
heam	doc_491521501856_item	2518993	et	4	main
kulm	doc_491521501856_item	2518998	et	3	main
maitsev	doc_491521501856_item	2519000	et	4	main
keelekasutusest	doc_491521501856_item	2519007	et	4	main
ta	doc_491521501856_item	2519012	et	4	main
on	doc_491521501856_item	2519017	et	4	main
ka	doc_491521501856_item	2518983	et	3	main
keeles	doc_491521501856_item	2518985	et	4	main
halbem	doc_491521501856_item	2518997	et	4	main
jargnevad	doc_491521501856_item	2519003	et	4	main
rodus	doc_491521501856_item	2519011	et	3	main
on	doc_491521501856_item	2519021	et	4	main
laud	doc_491521501856_item	2519023	et	4	main
mul	doc_491521501856_item	2519024	et	3	main
toodest	doc_491521501856_item	2519029	et	3	main
kasutamise	doc_491521501856_item	2519032	et	4	main
ebaselgena	doc_491521501856_item	2519041	et	3	main
segamini	doc_491521501856_item	2519051	et	4	main
see	doc_491521501856_item	2519059	et	3	main
kohtla-jarvel	doc_491521501856_item	2519073	et	4	main
poltsamaal	doc_491521501856_item	2519074	et	4	main
vene	doc_491521501856_item	2519082	et	4	main
kaandelopp	doc_491521501856_item	2519089	et	4	main
secia	doc_491521501856_item	2519090	et	4	main
keeles	doc_491521501856_item	2519129	et	4	main
raskusi	doc_491521501856_item	2519133	et	4	main
kaanamine	doc_491521501856_item	2519135	et	4	main
kui	doc_491521501856_item	2519138	et	3	main
on	doc_491521501856_item	2519140	et	4	main
arvsona	doc_491521501856_item	2519151	et	4	main
esineb	doc_491521501856_item	2519152	et	3	main
n	doc_491521501856_item	2519154	et	4	main
on	doc_491521501856_item	2519160	et	4	main
harv	doc_491521501856_item	2519162	et	3	main
novemril	doc_491521501856_item	2519180	et	4	main
arvsona	doc_491521501856_item	2519190	et	4	main
kuidagi	doc_491521501856_item	2519192	et	3	main
ja	doc_491521501856_item	2519194	et	3	main
ei	doc_491521501856_item	2519201	et	4	main
susteemist	doc_491521501856_item	2519203	et	4	main
arvsona	doc_491521501856_item	2519206	et	4	main
ma	doc_491521501856_item	2519239	et	3	main
vana	doc_491521501856_item	2519243	et	4	main
mxe	doc_491521501856_item	2519264	et	4	main
kirjutamine	doc_491521501856_item	2519269	et	4	main
raskusi	doc_491521501856_item	2519271	et	4	main
kui	doc_491521501856_item	2519280	et	3	main
tegemist	doc_491521501856_item	2519292	et	4	main
vead	doc_491521501856_item	2519321	et	4	main
vahel	doc_491521501856_item	2519323	et	4	main
arusaamatuks	doc_491521501856_item	2519327	et	4	main
kus	doc_491521501856_item	2519339	et	3	main
palju	doc_491521501856_item	2519343	et	4	main
et	doc_491521501856_item	2519349	et	3	main
vead	doc_491521501856_item	2519351	et	4	main
lauseehitus	doc_491521501856_item	2519356	et	4	main
on	doc_491521501856_item	2519359	et	4	main
pohjuseks	doc_491521501856_item	2519363	et	4	main
ongi	doc_491521501856_item	2519364	et	4	main
see	doc_491521501856_item	2519365	et	3	main
et	doc_491521501856_item	2519366	et	3	main
venelane	doc_491521501856_item	2519367	et	3	main
kasutab	doc_491521501856_item	2519368	et	3	main
eesti	doc_491521501856_item	2519369	et	4	main
keelt	doc_491521501856_item	2519370	et	4	main
ta	doc_491521501856_item	2519376	et	4	main
ikkagi	doc_491521501856_item	2519387	et	4	main
valesti	doc_491521501856_item	2519388	et	3	main
pedagoogikaülikool	doc_491521501857_item	2519397	et	4	main
veaanalüüs	doc_491521501857_item	2519398	et	4	main
rebane	doc_491521501857_item	2519399	et	4	main
ja	doc_491521501857_item	2519400	et	3	main
jänes	doc_491521501857_item	2519401	et	3	main
eesnimi	doc_491521501857_item	2519402	et	3	main
perekonnanimi	doc_491521501857_item	2519403	et	3	main
juhendaja	doc_491521501857_item	2519404	et	4	main
harjutamine	doc_491521501857_item	2519408	et	4	main
iga	doc_491521501857_item	2519415	et	4	main
kõige	doc_491521501857_item	2519417	et	4	main
raskem	doc_491521501857_item	2519418	et	4	main
on	doc_491521501857_item	2519422	et	4	main
koostamiseks	doc_491521501857_item	2519432	et	4	main
liikumapanevaks	doc_491521501857_item	2519439	et	3	main
sundus	doc_491521501857_item	2519443	et	3	main
ette	doc_491521501857_item	2519447	et	4	main
taga	doc_491521501857_item	2519450	et	4	main
paberileht	doc_491521501857_item	2519453	et	3	main
ja	doc_491521501857_item	2519454	et	3	main
pastapliiats	doc_491521501856_item	2519027	et	4	main
vaja	doc_491521501856_item	2519046	et	4	main
hiiumaal	doc_491521501856_item	2519054	et	4	main
voi	doc_491521501856_item	2519055	et	4	main
hiiumaas	doc_491521501856_item	2519056	et	3	main
ja	doc_491521501856_item	2519057	et	3	main
et	doc_491521501856_item	2519062	et	3	main
b	doc_491521501856_item	2519087	et	4	main
on	doc_491521501856_item	2519092	et	4	main
saaremaal	doc_491521501856_item	2519093	et	4	main
voi	doc_491521501856_item	2519094	et	4	main
saaremaas	doc_491521501856_item	2519095	et	3	main
utleb	doc_491521501856_item	2519096	et	4	main
eestlasele	doc_491521501856_item	2519097	et	3	main
keeievaist	doc_491521501856_item	2519098	et	4	main
kohtla-jarves	doc_491521501856_item	2519099	et	4	main
saaremaas	doc_491521501856_item	2519100	et	3	main
noes	doc_491521501856_item	2519101	et	4	main
piritas	doc_491521501856_item	2519102	et	4	main
miits	doc_491521501856_item	2519103	et	4	main
on	doc_491521501856_item	2519104	et	4	main
peas	doc_491521501856_item	2519105	et	4	main
aga	doc_491521501856_item	2519106	et	3	main
vene	doc_491521501856_item	2519107	et	4	main
ha	doc_491521501856_item	2519109	et	4	main
keeles	doc_491521501856_item	2519108	et	4	main
ronobe	doc_491521501856_item	2519110	et	4	main
sall	doc_491521501856_item	2519111	et	3	main
on	doc_491521501856_item	2519112	et	4	main
kaelas	doc_491521501856_item	2519113	et	4	main
saabas	doc_491521501856_item	2519114	et	3	main
on	doc_491521501856_item	2519115	et	4	main
jalas	doc_491521501856_item	2519116	et	4	main
kinnas	doc_491521501856_item	2519117	et	3	main
on	doc_491521501856_item	2519118	et	4	main
kaes	doc_491521501856_item	2519119	et	4	main
vene	doc_491521501856_item	2519120	et	4	main
kasutamine	doc_491521501856_item	2519137	et	4	main
mitu	doc_491521501856_item	2519143	et	4	main
natuke	doc_491521501856_item	2519147	et	4	main
kui	doc_491521501856_item	2519150	et	3	main
tekstis	doc_491521501856_item	2519153	et	3	main
novembril	doc_491521501856_item	2519158	et	3	main
usna	doc_491521501856_item	2519161	et	4	main
see	doc_491521501856_item	2519165	et	3	main
korraga	doc_491521501856_item	2519167	et	4	main
oeldakse	doc_491521501856_item	2519169	et	4	main
viiendal	doc_491521501856_item	2519176	et	3	main
viiel	doc_491521501856_item	2519179	et	3	main
jne	doc_491521501856_item	2519181	et	4	main
tundub	doc_491521501856_item	2519183	et	3	main
siis	doc_491521501856_item	2519195	et	3	main
vastuseks	doc_491521501856_item	2519197	et	4	main
nendes	doc_491521501856_item	2519130	et	4	main
ja	doc_491521501856_item	2519136	et	3	main
ette	doc_491521501856_item	2519141	et	4	main
mitmes	doc_491521501856_item	2519144	et	4	main
on	doc_491521501856_item	2519146	et	4	main
lihsam	doc_491521501856_item	2519148	et	4	main
aga	doc_491521501856_item	2519149	et	3	main
kadripaev	doc_491521501856_item	2519155	et	4	main
on	doc_491521501856_item	2519156	et	4	main
25	doc_491521501856_item	2519157	et	2	main
juhus	doc_491521501856_item	2519163	et	4	main
oigesti	doc_491521501856_item	2519168	et	4	main
kakskummend	doc_491521501856_item	2519175	et	4	main
kohati	doc_491521501856_item	2519182	et	4	main
pohjuseks	doc_491521501856_item	2519185	et	4	main
oleks	doc_491521501856_item	2519186	et	3	main
see	doc_491521501856_item	2519187	et	3	main
et	doc_491521501856_item	2519188	et	3	main
pealegi	doc_491521501856_item	2519205	et	4	main
vene	doc_491521501856_item	2519208	et	4	main
nagu	doc_491521501856_item	2519212	et	3	main
eesti	doc_491521501856_item	2519213	et	4	main
keeles	doc_491521501856_item	2519214	et	4	main
kahekumne	doc_491521501856_item	2519215	et	4	main
viiendal	doc_491521501856_item	2519216	et	3	main
abaauatb	doc_491521501856_item	2519217	et	4	main
nutoro	doc_491521501856_item	2519218	et	4	main
xorbpu	doc_491521501856_item	2519219	et	4	main
sama	doc_491521501856_item	2519220	et	4	main
oma	doc_491521501856_item	2519232	et	4	main
oeldakse	doc_491521501856_item	2519234	et	4	main
ma	doc_491521501856_item	2519235	et	3	main
olen	doc_491521501856_item	2519236	et	3	main
kumne	doc_491521501856_item	2519237	et	4	main
aga	doc_491521501856_item	2519244	et	3	main
on	doc_491521501856_item	2519247	et	4	main
vaid	doc_491521501856_item	2519248	et	3	main
uks	doc_491521501856_item	2519249	et	3	main
ja	doc_491521501856_item	2519250	et	3	main
ka	doc_491521501856_item	2519265	et	3	main
valmistab	doc_491521501856_item	2519270	et	3	main
tana	doc_491521501856_item	2519272	et	4	main
on	doc_491521501856_item	2519273	et	4	main
november	doc_491521501856_item	2519279	et	3	main
et	doc_491521501856_item	2519282	et	3	main
tuleb	doc_491521501856_item	2519285	et	3	main
et	doc_491521501856_item	2519287	et	3	main
on	doc_491521501856_item	2519291	et	4	main
teise	doc_491521501856_item	2519295	et	4	main
variante	doc_491521501856_item	2519199	et	3	main
ise	doc_491521501856_item	2519207	et	4	main
keeles	doc_491521501856_item	2519209	et	4	main
on	doc_491521501856_item	2519222	et	4	main
mitu	doc_491521501856_item	2519229	et	4	main
olen	doc_491521501856_item	2519240	et	3	main
aastat	doc_491521501856_item	2519242	et	3	main
variant	doc_491521501856_item	2519252	et	3	main
iet	doc_491521501856_item	2519255	et	4	main
on	doc_491521501856_item	2519258	et	4	main
voimalik	doc_491521501856_item	2519261	et	4	main
variant	doc_491521501856_item	2519262	et	3	main
mul	doc_491521501856_item	2519263	et	3	main
kuupaeva	doc_491521501856_item	2519266	et	4	main
kolmkummend	doc_491521501856_item	2519274	et	4	main
tana	doc_491521501856_item	2519276	et	4	main
mitmes	doc_491521501856_item	2519283	et	4	main
voi	doc_491521501856_item	2519294	et	4	main
kuupaevaga	doc_491521501856_item	2519296	et	4	main
ei	doc_491521501856_item	2519297	et	4	main
aita	doc_491521501856_item	2519298	et	4	main
kusimus	doc_491521501856_item	2519301	et	3	main
kuigi	doc_491521501856_item	2519302	et	3	main
vene	doc_491521501856_item	2519303	et	4	main
keeles	doc_491521501856_item	2519304	et	4	main
on	doc_491521501856_item	2519305	et	4	main
vaste	doc_491521501856_item	2519306	et	4	main
olemas	doc_491521501856_item	2519307	et	4	main
oaxx	doc_491521501856_item	2519308	et	4	main
x	doc_491521501856_item	2519309	et	4	main
nepbbzn	doc_491521501856_item	2519310	et	4	main
uhildumisvead	doc_491521501856_item	2519311	et	4	main
neid	doc_491521501856_item	2519312	et	4	main
vigu	doc_491521501856_item	2519313	et	3	main
esineb	doc_491521501856_item	2519314	et	3	main
koige	doc_491521501856_item	2519315	et	4	main
sagedamini	doc_491521501856_item	2519316	et	4	main
uhtlasi	doc_491521501856_item	2519317	et	4	main
on	doc_491521501856_item	2519318	et	4	main
need	doc_491521501856_item	2519319	et	3	main
olulised	doc_491521501856_item	2519320	et	4	main
sest	doc_491521501856_item	2519322	et	4	main
voib	doc_491521501856_item	2519324	et	4	main
just	doc_491521501856_item	2519328	et	3	main
korteris	doc_491521501856_item	2519338	et	3	main
voib	doc_491521501856_item	2519347	et	4	main
kaanded	doc_491521501856_item	2519358	et	4	main
oskab	doc_491521501856_item	2519375	et	3	main
loen	doc_491521501856_item	2519379	et	3	main
loed	doc_491521501856_item	2519381	et	4	main
jne	doc_491521501856_item	2519382	et	4	main
aga	doc_491521501856_item	2519383	et	3	main
kones	doc_491521501856_item	2519384	et	3	main
kasutab	doc_491521501856_item	2519385	et	3	main
tema	doc_491521501856_item	2519389	et	4	main
2001	doc_491521501857_item	2519407	et	2	main
kirjutamine	doc_491521501857_item	2519411	et	4	main
osa	doc_491521501857_item	2519419	et	4	main
inimesed	doc_491521501857_item	2519420	et	3	main
on	doc_491521501856_item	2519228	et	4	main
vanust	doc_491521501856_item	2519233	et	4	main
oige	doc_491521501856_item	2519251	et	3	main
aecat	doc_491521501856_item	2519254	et	4	main
sest	doc_491521501856_item	2519256	et	4	main
neil	doc_491521501856_item	2519257	et	4	main
vaid	doc_491521501856_item	2519259	et	3	main
uks	doc_491521501856_item	2519260	et	3	main
utlemine	doc_491521501856_item	2519267	et	4	main
siis	doc_491521501856_item	2519284	et	3	main
meelde	doc_491521501856_item	2519286	et	3	main
kolmekumnes	doc_491521501856_item	2519288	et	4	main
kui	doc_491521501856_item	2519290	et	3	main
ka	doc_491521501856_item	2519299	et	3	main
see	doc_491521501856_item	2519300	et	3	main
jaada	doc_491521501856_item	2519325	et	4	main
parast	doc_491521501856_item	2519331	et	3	main
vead	doc_491521501856_item	2519333	et	4	main
parinevad	doc_491521501856_item	2519334	et	4	main
tudengite	doc_491521501856_item	2519335	et	3	main
toodest	doc_491521501856_item	2519336	et	3	main
kokkuvotteks	doc_491521501856_item	2519346	et	4	main
oelda	doc_491521501856_item	2519348	et	4	main
paljud	doc_491521501856_item	2519350	et	3	main
on	doc_491521501856_item	2519352	et	4	main
tingitud	doc_491521501856_item	2519353	et	4	main
ja	doc_491521501856_item	2519357	et	3	main
erinevad	doc_491521501856_item	2519361	et	4	main
valjapool	doc_491521501856_item	2519371	et	4	main
naiteks	doc_491521501856_item	2519374	et	4	main
ta	doc_491521501856_item	2519386	et	4	main
loed	doc_491521501856_item	2519390	et	4	main
on	doc_491521501856_item	2519392	et	4	main
vaja	doc_491521501856_item	2519394	et	4	main
analüüs	doc_491521501857_item	2519395	et	3	main
vist	doc_491521501857_item	2519414	et	4	main
keele	doc_491521501857_item	2519416	et	4	main
kes	doc_491521501857_item	2519421	et	4	main
kunagi	doc_491521501857_item	2519423	et	3	main
kujutamisega	doc_491521501857_item	2519424	et	4	main
kirja	doc_491521501857_item	2519431	et	4	main
on	doc_491521501857_item	2519433	et	4	main
vajadus	doc_491521501857_item	2519441	et	3	main
istumine	doc_491521501857_item	2519448	et	4	main
kohal	doc_491521501857_item	2519456	et	4	main
teised	doc_491521501857_item	2519467	et	4	main
piisa	doc_491521501857_item	2519482	et	4	main
eneseväljendamiseks	doc_491521501857_item	2519483	et	3	main
või	doc_491521501857_item	2519484	et	4	main
kurdavad	doc_491521501857_item	2519492	et	3	main
et	doc_491521501857_item	2519494	et	3	main
nõuab	doc_491521501857_item	2519496	et	3	main
kirjutatuga	doc_491521501857_item	2519500	et	4	main
aga	doc_491521501857_item	2519501	et	3	main
sageli	doc_491521501857_item	2519502	et	3	main
rahule	doc_491521501857_item	2519505	et	4	main
tagasi	doc_491521501857_item	2519508	et	3	main
huvituta	doc_491521501857_item	2519523	et	4	main
enam	doc_491521501857_item	2519525	et	4	main
kuidas	doc_491521501857_item	2519527	et	3	main
kiriutada	doc_491521501857_item	2519528	et	4	main
veel	doc_491521501857_item	2519537	et	4	main
ka	doc_491521501857_item	2519538	et	3	main
saades	doc_491521501857_item	2519551	et	3	main
tööde	doc_491521501857_item	2519552	et	3	main
on	doc_491521501857_item	2519568	et	4	main
kasvõi	doc_491521501857_item	2519572	et	3	main
see	doc_491521501857_item	2519575	et	3	main
mida	doc_491521501857_item	2519582	et	4	main
õpetama	doc_491521501857_item	2519586	et	3	main
varem	doc_491521501857_item	2519590	et	4	main
olevad	doc_491521501857_item	2519622	et	4	main
hobutsema	doc_491521501857_item	2519624	et	4	main
või	doc_491521501857_item	2519626	et	4	main
õppima	doc_491521501857_item	2519628	et	3	main
istun	doc_491521501857_item	2519641	et	3	main
näiteks	doc_491521501857_item	2519646	et	4	main
sooja	doc_491521501857_item	2519648	et	4	main
kusk	doc_491521501857_item	2519649	et	4	main
kuusk	doc_491521501857_item	2519650	et	3	main
vatan	doc_491521501857_item	2519651	et	4	main
vaatan	doc_491521501857_item	2519652	et	3	main
selliste	doc_491521501856_item	2519329	et	4	main
vigade	doc_491521501856_item	2519330	et	3	main
suurt	doc_491521501856_item	2519340	et	3	main
kortereid	doc_491521501856_item	2519341	et	3	main
ilus	doc_491521501856_item	2519344	et	4	main
kasse	doc_491521501856_item	2519345	et	3	main
emakeele	doc_491521501856_item	2519354	et	4	main
ju	doc_491521501856_item	2519360	et	3	main
pohiliseks	doc_491521501856_item	2519362	et	4	main
harva	doc_491521501856_item	2519373	et	4	main
mina	doc_491521501856_item	2519378	et	4	main
sina	doc_491521501856_item	2519380	et	4	main
tallinn	doc_491521501857_item	2519406	et	4	main
on	doc_491521501857_item	2519413	et	4	main
öelda	doc_491521501857_item	2519427	et	4	main
et	doc_491521501857_item	2519428	et	3	main
isegi	doc_491521501857_item	2519429	et	4	main
lihtsa	doc_491521501857_item	2519430	et	3	main
või	doc_491521501857_item	2519442	et	4	main
tuleb	doc_491521501857_item	2519445	et	3	main
kirjutada	doc_491521501857_item	2519459	et	3	main
on	doc_491521501857_item	2519461	et	4	main
teada	doc_491521501857_item	2519462	et	3	main
aga	doc_491521501857_item	2519463	et	3	main
peas	doc_491521501857_item	2519464	et	4	main
hiilib	doc_491521501857_item	2519473	et	3	main
paanika	doc_491521501857_item	2519475	et	4	main
hullem	doc_491521501857_item	2519477	et	4	main
aga	doc_491521501857_item	2519478	et	3	main
sõnavarast	doc_491521501857_item	2519480	et	4	main
uue	doc_491521501857_item	2519486	et	3	main
sõna	doc_491521501857_item	2519487	et	4	main
kirjapanek	doc_491521501857_item	2519488	et	3	main
tekitab	doc_491521501857_item	2519489	et	3	main
jääda	doc_491521501857_item	2519504	et	4	main
õpetaja	doc_491521501857_item	2519506	et	4	main
pedagooge	doc_491521501857_item	2519534	et	3	main
lisaks	doc_491521501857_item	2519535	et	4	main
raskusi	doc_491521501857_item	2519541	et	4	main
võtab	doc_491521501857_item	2519554	et	3	main
peegeldub	doc_491521501857_item	2519560	et	3	main
vaja	doc_491521501857_item	2519569	et	4	main
on	doc_491521501857_item	2519576	et	4	main
testide	doc_491521501857_item	2519578	et	3	main
rigieksamite	doc_491521501857_item	2519579	et	4	main
rnängima	doc_491521501857_item	2519631	et	4	main
koristada	doc_491521501857_item	2519633	et	3	main
ja	doc_491521501857_item	2519644	et	3	main
jurde	doc_491521501857_item	2519656	et	4	main
õigekirjas	doc_491521501857_item	2519658	et	3	main
tunni	doc_491521501857_item	2519668	et	3	main
ajal	doc_491521501857_item	2519669	et	4	main
lisaülesandeid	doc_491521501857_item	2519673	et	3	main
harjutades	doc_491521501857_item	2519675	et	3	main
teatud	doc_491521501857_item	2519678	et	4	main
mudeleid	doc_491521501857_item	2519681	et	3	main
õige	doc_491521501857_item	2519685	et	4	main
tuleb	doc_491521501857_item	2519690	et	3	main
kui	doc_491521501857_item	2519693	et	3	main
lahendada	doc_491521501857_item	2519696	et	3	main
ülesandeid	doc_491521501857_item	2519698	et	3	main
reegli	doc_491521501857_item	2519700	et	3	main
eksib	doc_491521501857_item	2519702	et	3	main
ta	doc_491521501857_item	2519703	et	4	main
märksa	doc_491521501857_item	2519704	et	3	main
tüüpväljenditega	doc_491521501857_item	2519725	et	3	main
piirduma	doc_491521501857_item	2519726	et	3	main
tuleb	doc_491521501857_item	2519729	et	3	main
et	doc_491521501857_item	2519731	et	3	main
jättes	doc_491521501857_item	2519747	et	4	main
praovin	doc_491521501857_item	2519752	et	4	main
mis	doc_491521501857_item	2519755	et	4	main
kaugelt	doc_491521501857_item	2519781	et	4	main
pea	doc_491521501857_item	2519794	et	4	main
18-ks	doc_491521501857_item	2519796	et	3	main
mõelda	doc_491521501857_item	2519802	et	4	main
lemmikuks	doc_491521501857_item	2519807	et	4	main
jutud	doc_491521501857_item	2519810	et	3	main
kus	doc_491521501857_item	2519811	et	3	main
lähtudest	doc_491521501857_item	2519812	et	4	main
oma	doc_491521501857_item	2519813	et	4	main
parandama	doc_491521501857_item	2519820	et	3	main
tublim	doc_491521501857_item	2519832	et	4	main
käigus	doc_491521501857_item	2519845	et	4	main
luban	doc_491521501857_item	2519846	et	3	main
kasutada	doc_491521501857_item	2519847	et	3	main
arvan	doc_491521501857_item	2519851	et	3	main
tegelenud	doc_491521501857_item	2519425	et	4	main
võivad	doc_491521501857_item	2519426	et	4	main
vaja	doc_491521501857_item	2519434	et	4	main
aiget	doc_491521501857_item	2519435	et	4	main
kas	doc_491521501857_item	2519444	et	3	main
tuttav	doc_491521501857_item	2519446	et	3	main
laua	doc_491521501857_item	2519449	et	3	main
ees	doc_491521501857_item	2519451	et	4	main
puhas	doc_491521501857_item	2519452	et	3	main
kummitamas	doc_491521501857_item	2519457	et	3	main
mõtted	doc_491521501857_item	2519468	et	3	main
aeg	doc_491521501857_item	2519469	et	3	main
läheb	doc_491521501857_item	2519470	et	3	main
ning	doc_491521501857_item	2519471	et	3	main
pikapeale	doc_491521501857_item	2519472	et	3	main
veel	doc_491521501857_item	2519476	et	4	main
kui	doc_491521501857_item	2519479	et	3	main
iga	doc_491521501857_item	2519485	et	4	main
õppijad	doc_491521501857_item	2519491	et	4	main
kirjutamine	doc_491521501857_item	2519495	et	4	main
ei	doc_491521501857_item	2519503	et	4	main
punasekirju	doc_491521501857_item	2519509	et	4	main
töö	doc_491521501857_item	2519510	et	4	main
viletsa	doc_491521501857_item	2519511	et	3	main
või	doc_491521501857_item	2519512	et	4	main
keskpärase	doc_491521501857_item	2519513	et	4	main
hindega	doc_491521501857_item	2519514	et	3	main
mis	doc_491521501857_item	2519515	et	4	main
annab	doc_491521501857_item	2519516	et	3	main
õppijale	doc_491521501857_item	2519517	et	4	main
aimu	doc_491521501857_item	2519518	et	4	main
tema	doc_491521501857_item	2519519	et	4	main
võimetusest	doc_491521501857_item	2519520	et	4	main
et	doc_491521501857_item	2519522	et	3	main
on	doc_491521501857_item	2519536	et	4	main
teisi	doc_491521501857_item	2519540	et	4	main
parandamine	doc_491521501857_item	2519553	et	4	main
ja	doc_491521501857_item	2519557	et	3	main
õpetajate	doc_491521501857_item	2519562	et	4	main
ja	doc_491521501857_item	2519570	et	3	main
osa	doc_491521501857_item	2519580	et	4	main
õppija	doc_491521501857_item	2519593	et	4	main
nagu	doc_491521501857_item	2519621	et	3	main
meeldib	doc_491521501857_item	2519623	et	3	main
ratsutada	doc_491521501857_item	2519625	et	3	main
tahan	doc_491521501857_item	2519627	et	3	main
klusiilide	doc_491521501857_item	2519635	et	3	main
vihikud	doc_491521501857_item	2519638	et	3	main
pinkis	doc_491521501857_item	2519643	et	4	main
soja	doc_491521501857_item	2519647	et	4	main
toomingas	doc_491521501857_item	2519654	et	4	main
juurde	doc_491521501857_item	2519657	et	4	main
nõnda	doc_491521501857_item	2519659	et	3	main
antud	doc_491521501857_item	2519662	et	4	main
seotud	doc_491521501857_item	2519672	et	4	main
ja	doc_491521501857_item	2519674	et	3	main
või	doc_491521501857_item	2519680	et	4	main
nt	doc_491521501857_item	2519682	et	4	main
verb	doc_491521501857_item	2519684	et	3	main
lõpus	doc_491521501857_item	2519687	et	4	main
samas	doc_491521501857_item	2519688	et	4	main
tuleb	doc_491521501857_item	2519695	et	3	main
konkreetseid	doc_491521501857_item	2519697	et	3	main
esseedekirjandite	doc_491521501857_item	2519707	et	3	main
ehk	doc_491521501857_item	2519735	et	3	main
pole	doc_491521501857_item	2519739	et	3	main
ise	doc_491521501857_item	2519741	et	4	main
ajal	doc_491521501857_item	2519743	et	4	main
rohkem	doc_491521501857_item	2519749	et	4	main
kodutööks	doc_491521501857_item	2519750	et	3	main
mõnikord	doc_491521501857_item	2519437	et	3	main
on	doc_491521501857_item	2519438	et	4	main
jõuks	doc_491521501857_item	2519440	et	3	main
liikuvad	doc_491521501857_item	2519465	et	4	main
hoopis	doc_491521501857_item	2519466	et	3	main
lähemale	doc_491521501857_item	2519474	et	4	main
ei	doc_491521501857_item	2519481	et	4	main
annab	doc_491521501857_item	2519507	et	3	main
nii	doc_491521501857_item	2519521	et	3	main
pea	doc_491521501857_item	2519455	et	4	main
kohustus	doc_491521501857_item	2519458	et	4	main
teema	doc_491521501857_item	2519460	et	4	main
raskusi	doc_491521501857_item	2519490	et	4	main
alati	doc_491521501857_item	2519493	et	4	main
aega	doc_491521501857_item	2519497	et	4	main
ja	doc_491521501857_item	2519498	et	3	main
pingutust	doc_491521501857_item	2519499	et	4	main
lõpuks	doc_491521501857_item	2519524	et	4	main
mis	doc_491521501857_item	2519529	et	4	main
häid	doc_491521501857_item	2519542	et	3	main
teemasid	doc_491521501857_item	2519544	et	3	main
raske	doc_491521501857_item	2519546	et	4	main
leida	doc_491521501857_item	2519547	et	3	main
õpilased	doc_491521501857_item	2519548	et	3	main
nurisevad	doc_491521501857_item	2519549	et	4	main
palju	doc_491521501857_item	2519555	et	4	main
ka	doc_491521501857_item	2519561	et	3	main
endi	doc_491521501857_item	2519563	et	4	main
möödalaskmistes	doc_491521501857_item	2519564	et	3	main
samas	doc_491521501857_item	2519565	et	4	main
aga	doc_491521501857_item	2519566	et	3	main
kirjutada	doc_491521501857_item	2519567	et	3	main
et	doc_491521501857_item	2519574	et	3	main
ja	doc_491521501857_item	2519581	et	3	main
varem	doc_491521501857_item	2519583	et	4	main
seda	doc_491521501857_item	2519584	et	3	main
ning	doc_491521501857_item	2519587	et	3	main
harjutama	doc_491521501857_item	2519588	et	4	main
seda	doc_491521501857_item	2519589	et	3	main
hakkab	doc_491521501857_item	2519591	et	3	main
ka	doc_491521501857_item	2519592	et	3	main
pilisima	doc_491521501857_item	2519629	et	4	main
pilliga	doc_491521501857_item	2519630	et	3	main
ning	doc_491521501857_item	2519634	et	3	main
võtan	doc_491521501857_item	2519637	et	3	main
raamatud	doc_491521501857_item	2519639	et	4	main
joonlautu	doc_491521501857_item	2519640	et	4	main
neljantas	doc_491521501857_item	2519642	et	4	main
diftongide	doc_491521501857_item	2519645	et	3	main
andes	doc_491521501857_item	2519667	et	4	main
sabloonilauseid	doc_491521501857_item	2519679	et	4	main
aga	doc_491521501857_item	2519689	et	3	main
elus	doc_491521501857_item	2519709	et	4	main
palju	doc_491521501857_item	2519712	et	4	main
sellest	doc_491521501857_item	2519526	et	4	main
omakorda	doc_491521501857_item	2519530	et	3	main
eriti	doc_491521501857_item	2519531	et	3	main
ei	doc_491521501857_item	2519532	et	4	main
rõõmusta	doc_491521501857_item	2519533	et	4	main
paliu	doc_491521501857_item	2519539	et	4	main
eakohaseid	doc_491521501857_item	2519543	et	4	main
on	doc_491521501857_item	2519545	et	4	main
ülesannet	doc_491521501857_item	2519550	et	4	main
aega	doc_491521501857_item	2519556	et	4	main
nendega	doc_491521501857_item	2519558	et	4	main
rahulolematuses	doc_491521501857_item	2519559	et	4	main
tuleb	doc_491521501857_item	2519571	et	3	main
seetõttu	doc_491521501857_item	2519573	et	3	main
tähtis	doc_491521501857_item	2519577	et	4	main
hakatakse	doc_491521501857_item	2519585	et	3	main
ladusamalt	doc_491521501857_item	2519594	et	4	main
kirjutama	doc_491521501857_item	2519595	et	3	main
töötades	doc_491521501857_item	2519596	et	3	main
koolis	doc_491521501857_item	2519597	et	4	main
eesti	doc_491521501857_item	2519598	et	4	main
keele	doc_491521501857_item	2519599	et	4	main
õpetajana	doc_491521501857_item	2519600	et	4	main
olen	doc_491521501857_item	2519601	et	3	main
tähele	doc_491521501857_item	2519602	et	3	main
pannud	doc_491521501857_item	2519603	et	4	main
et	doc_491521501857_item	2519604	et	3	main
kõige	doc_491521501857_item	2519605	et	4	main
rohkem	doc_491521501857_item	2519606	et	4	main
eksitakse	doc_491521501857_item	2519607	et	4	main
ma-	doc_491521501857_item	2519608	et	3	main
i	doc_491521501857_item	2519609	et	4	main
da-infinitiivi	doc_491521501857_item	2519610	et	4	main
verbi	doc_491521501857_item	2519611	et	4	main
põhivormide	doc_491521501857_item	2519612	et	3	main
kasutuses	doc_491521501857_item	2519613	et	4	main
nii	doc_491521501857_item	2519614	et	3	main
näiteks	doc_491521501857_item	2519615	et	4	main
võib	doc_491521501857_item	2519616	et	3	main
tihti	doc_491521501857_item	2519617	et	3	main
näha	doc_491521501857_item	2519618	et	3	main
selliseid	doc_491521501857_item	2519619	et	4	main
vorme	doc_491521501857_item	2519620	et	3	main
pean	doc_491521501857_item	2519632	et	4	main
näiteks	doc_491521501857_item	2519636	et	4	main
tema	doc_491521501857_item	2519655	et	4	main
proovisin	doc_491521501857_item	2519660	et	3	main
nende	doc_491521501857_item	2519670	et	4	main
suulises	doc_491521501857_item	2519676	et	4	main
infinitiiviga	doc_491521501857_item	2519686	et	3	main
et	doc_491521501857_item	2519692	et	3	main
õppijal	doc_491521501857_item	2519694	et	4	main
ühekahe	doc_491521501857_item	2519699	et	4	main
peal	doc_491521501857_item	2519701	et	4	main
vähem	doc_491521501857_item	2519705	et	4	main
kirjutamisega	doc_491521501857_item	2519708	et	4	main
aga	doc_491521501857_item	2519710	et	3	main
rohkem	doc_491521501857_item	2519713	et	4	main
selliseid	doc_491521501857_item	2519714	et	4	main
situatsioone	doc_491521501857_item	2519715	et	3	main
ette	doc_491521501857_item	2519716	et	4	main
kus	doc_491521501857_item	2519717	et	3	main
pead	doc_491521501857_item	2519718	et	4	main
just	doc_491521501857_item	2519719	et	3	main
spontaanse	doc_491521501857_item	2519720	et	3	main
teksti	doc_491521501857_item	2519721	et	4	main
siinkohal	doc_491521501857_item	2519727	et	3	main
teises	doc_491521501857_item	2519733	et	4	main
vahetuses	doc_491521501857_item	2519734	et	4	main
14-st	doc_491521501857_item	2519737	et	3	main
ma	doc_491521501857_item	2519740	et	3	main
tunni	doc_491521501857_item	2519742	et	3	main
kirjandite	doc_491521501857_item	2519744	et	3	main
ning	doc_491521501857_item	2519751	et	3	main
isegi	doc_491521501857_item	2519774	et	4	main
oled	doc_491521501857_item	2519776	et	3	main
poolpaeva	doc_491521501857_item	2519778	et	4	main
pruugi	doc_491521501857_item	2519783	et	4	main
nii	doc_491521501857_item	2519784	et	3	main
kooli	doc_491521501857_item	2519787	et	4	main
väsinuna	doc_491521501857_item	2519789	et	4	main
ning	doc_491521501857_item	2519790	et	3	main
kaasa	doc_491521501857_item	2519801	et	4	main
peavad	doc_491521501857_item	2519818	et	4	main
õigekirja-	doc_491521501857_item	2519821	et	4	main
grammatikavigu	doc_491521501857_item	2519823	et	3	main
me	doc_491521501857_item	2519826	et	4	main
seda	doc_491521501857_item	2519827	et	3	main
võistluse	doc_491521501857_item	2519828	et	3	main
kuna	doc_491521501857_item	2519850	et	3	main
nii	doc_491521501857_item	2519853	et	3	main
õppematerjaliga	doc_491521501857_item	2519857	et	3	main
isegi	doc_491521501857_item	2519861	et	4	main
gümnaasiumis	doc_491521501857_item	2519862	et	3	main
ei	doc_491521501857_item	2519863	et	4	main
jätta	doc_491521501857_item	2519870	et	3	main
meelde	doc_491521501857_item	2519872	et	3	main
kirjapilti	doc_491521501857_item	2519874	et	4	main
saadud	doc_491521501857_item	2519885	et	4	main
teksti	doc_491521501857_item	2519886	et	4	main
kuna	doc_491521501857_item	2519892	et	3	main
kontrollides	doc_491521501857_item	2519921	et	4	main
neid	doc_491521501857_item	2519924	et	4	main
mis	doc_491521501857_item	2519926	et	4	main
grammatika	doc_491521501857_item	2519929	et	4	main
millega	doc_491521501857_item	2519931	et	3	main
polnud	doc_491521501857_item	2519933	et	3	main
allakriipsutamisega	doc_491521501857_item	2519941	et	3	main
võivad	doc_491521501857_item	2519953	et	4	main
nad	doc_491521501857_item	2519954	et	3	main
saadud	doc_491521501857_item	2519955	et	4	main
kokkuvõteks	doc_491521501857_item	2519959	et	3	main
nimetust	doc_491521501857_item	2519979	et	4	main
lõpus	doc_491521501857_item	2519989	et	4	main
hulka	doc_491521501857_item	2520009	et	4	main
on	doc_491521501857_item	2520020	et	4	main
tomingas	doc_491521501857_item	2519653	et	4	main
just	doc_491521501857_item	2519661	et	3	main
grammatika	doc_491521501857_item	2519663	et	4	main
osa	doc_491521501857_item	2519664	et	4	main
eriti	doc_491521501857_item	2519665	et	3	main
rõhutada	doc_491521501857_item	2519666	et	3	main
teemadega	doc_491521501857_item	2519671	et	3	main
kõnes	doc_491521501857_item	2519677	et	3	main
hakkamatulema-	doc_491521501857_item	2519683	et	3	main
mainida	doc_491521501857_item	2519691	et	3	main
võrreldes	doc_491521501857_item	2519706	et	3	main
tuleb	doc_491521501857_item	2519711	et	3	main
produtseerima	doc_491521501857_item	2519722	et	3	main
mitte	doc_491521501857_item	2519723	et	3	main
aga	doc_491521501857_item	2519724	et	3	main
mainida	doc_491521501857_item	2519730	et	3	main
tötades	doc_491521501857_item	2519732	et	4	main
kella	doc_491521501857_item	2519736	et	4	main
koostamise	doc_491521501857_item	2519745	et	4	main
pooldaja	doc_491521501857_item	2519746	et	4	main
et	doc_491521501857_item	2519773	et	3	main
looderdanud	doc_491521501857_item	2519779	et	4	main
mis	doc_491521501857_item	2519780	et	4	main
ei	doc_491521501857_item	2519782	et	4	main
olla	doc_491521501857_item	2519785	et	3	main
jaksa	doc_491521501857_item	2519793	et	4	main
mu	doc_491521501857_item	2519805	et	3	main
õpilaste	doc_491521501857_item	2519806	et	4	main
on	doc_491521501857_item	2519808	et	4	main
vigased	doc_491521501857_item	2519809	et	4	main
õpitud	doc_491521501857_item	2519816	et	4	main
et	doc_491521501857_item	2519852	et	3	main
töötama	doc_491521501857_item	2519856	et	3	main
tänu	doc_491521501857_item	2519867	et	4	main
aeg-ajalt	doc_491521501857_item	2519881	et	4	main
või	doc_491521501857_item	2519888	et	4	main
kohtunud	doc_491521501857_item	2519894	et	4	main
aga	doc_491521501857_item	2519728	et	3	main
20-ni	doc_491521501857_item	2519738	et	3	main
neid	doc_491521501857_item	2519748	et	4	main
kasutada	doc_491521501857_item	2519753	et	3	main
vähem	doc_491521501857_item	2519757	et	4	main
aega	doc_491521501857_item	2519758	et	4	main
ning	doc_491521501857_item	2519759	et	3	main
on	doc_491521501857_item	2519760	et	4	main
ka	doc_491521501857_item	2519761	et	3	main
natuke	doc_491521501857_item	2519762	et	4	main
põnevamad	doc_491521501857_item	2519763	et	4	main
selleks	doc_491521501857_item	2519764	et	4	main
on	doc_491521501857_item	2519765	et	4	main
ka	doc_491521501857_item	2519766	et	3	main
oma	doc_491521501857_item	2519767	et	4	main
põhjus	doc_491521501857_item	2519768	et	4	main
isikliku	doc_491521501857_item	2519769	et	3	main
kogemuse	doc_491521501857_item	2519770	et	3	main
ülesandeid	doc_491521501857_item	2519754	et	3	main
võtavad	doc_491521501857_item	2519756	et	3	main
põhjal	doc_491521501857_item	2519771	et	4	main
tean	doc_491521501857_item	2519772	et	3	main
tuled	doc_491521501857_item	2519786	et	4	main
pisut	doc_491521501857_item	2519788	et	3	main
siis	doc_491521501857_item	2519791	et	3	main
või	doc_491521501857_item	2519797	et	4	main
19-ks	doc_491521501857_item	2519798	et	3	main
paiku	doc_491521501857_item	2519799	et	4	main
absaluutselt	doc_491521501857_item	2519800	et	4	main
üheks	doc_491521501857_item	2519804	et	3	main
kogemusest	doc_491521501857_item	2519814	et	4	main
varem	doc_491521501857_item	2519815	et	4	main
nad	doc_491521501857_item	2519819	et	3	main
korraldame	doc_491521501857_item	2519825	et	3	main
vormis	doc_491521501857_item	2519829	et	4	main
kusjuures	doc_491521501857_item	2519830	et	3	main
kõige	doc_491521501857_item	2519831	et	4	main
ja	doc_491521501857_item	2519833	et	3	main
kiirem	doc_491521501857_item	2519834	et	4	main
õpilane	doc_491521501857_item	2519835	et	3	main
pärib	doc_491521501857_item	2519836	et	3	main
kirjatarga	doc_491521501857_item	2519837	et	3	main
tiitli	doc_491521501857_item	2519838	et	3	main
ja	doc_491521501857_item	2519839	et	3	main
ka	doc_491521501857_item	2519840	et	3	main
eesti-vene	doc_491521501857_item	2519848	et	4	main
harjuda	doc_491521501857_item	2519855	et	3	main
teatud	doc_491521501857_item	2519859	et	4	main
sõna	doc_491521501857_item	2519879	et	4	main
suuliselt	doc_491521501857_item	2519889	et	4	main
emakeelde	doc_491521501857_item	2519890	et	4	main
tõlkida	doc_491521501857_item	2519891	et	3	main
vigu	doc_491521501857_item	2519925	et	3	main
puudutavad	doc_491521501857_item	2519927	et	4	main
neid	doc_491521501857_item	2519940	et	4	main
sümbolitega	doc_491521501857_item	2519943	et	3	main
ikkagi	doc_491521501857_item	2519945	et	4	main
tulernust	doc_491521501857_item	2519956	et	4	main
kõik	doc_491521501857_item	2519961	et	4	main
kandis	doc_491521501857_item	2519978	et	4	main
rebane	doc_491521501857_item	2519980	et	4	main
ja	doc_491521501857_item	2519981	et	3	main
jänes	doc_491521501857_item	2519982	et	3	main
vt	doc_491521501857_item	2519983	et	4	main
kahes	doc_491521501857_item	2519990	et	4	main
viiendas	doc_491521501857_item	2519991	et	3	main
5	doc_491521501857_item	2519992	et	2	main
b	doc_491521501857_item	2520000	et	4	main
parimate	doc_491521501857_item	2520008	et	4	main
aeliitklassi	doc_491521501857_item	2520012	et	4	main
kõige	doc_491521501857_item	2520017	et	4	main
nõrgemad	doc_491521501857_item	2520018	et	4	main
huvitatuse	doc_491521501857_item	2520039	et	4	main
kahjuks	doc_491521501857_item	2520044	et	4	main
lemmikaine	doc_491521501857_item	2520046	et	4	main
kuid	doc_491521501857_item	2520047	et	4	main
väga	doc_491521501857_item	2520053	et	3	main
kellega	doc_491521501857_item	2520056	et	3	main
meeldiv	doc_491521501857_item	2520058	et	4	main
ülesandest	doc_491521501857_item	2520064	et	4	main
3	doc_491521501857_item	2520074	et	2	main
mis	doc_491521501857_item	2520076	et	4	main
minutit	doc_491521501857_item	2520085	et	3	main
1	doc_491521501857_item	2520089	et	2	main
sõnastikku	doc_491521501857_item	2520093	et	4	main
tekstis	doc_491521501857_item	2520095	et	3	main
vigadeta	doc_491521501857_item	2520101	et	3	main
kui	doc_491521501857_item	2519775	et	3	main
esimese	doc_491521501857_item	2519777	et	3	main
ei	doc_491521501857_item	2519792	et	4	main
kella	doc_491521501857_item	2519795	et	4	main
nõnda	doc_491521501857_item	2519803	et	3	main
matetjalist	doc_491521501857_item	2519817	et	4	main
jaõi	doc_491521501857_item	2519822	et	4	main
tavaliselt	doc_491521501857_item	2519824	et	4	main
hea	doc_491521501857_item	2519841	et	4	main
hinde	doc_491521501857_item	2519842	et	4	main
paevikusse	doc_491521501857_item	2519843	et	3	main
töö	doc_491521501857_item	2519844	et	4	main
õppesõnastike	doc_491521501857_item	2519849	et	3	main
võib	doc_491521501857_item	2519854	et	3	main
oska	doc_491521501857_item	2519864	et	4	main
teha	doc_491521501857_item	2519865	et	3	main
ning	doc_491521501857_item	2519866	et	3	main
kiiremini	doc_491521501857_item	2519871	et	4	main
tähenduse	doc_491521501857_item	2519880	et	4	main
lisaks	doc_491521501857_item	2519884	et	4	main
olen	doc_491521501857_item	2519893	et	3	main
et	doc_491521501857_item	2519896	et	3	main
paljud	doc_491521501857_item	2519898	et	3	main
ei	doc_491521501857_item	2519899	et	4	main
põhikoolis	doc_491521501857_item	2519897	et	4	main
ole	doc_491521501857_item	2519900	et	4	main
suutelised	doc_491521501857_item	2519901	et	4	main
eri	doc_491521501857_item	2519902	et	4	main
võõrkeelseid	doc_491521501857_item	2519904	et	3	main
sõnu	doc_491521501857_item	2519905	et	4	main
omavahel	doc_491521501857_item	2519906	et	3	main
tähendusega	doc_491521501857_item	2519903	et	4	main
siduma	doc_491521501857_item	2519907	et	3	main
tõlkides	doc_491521501857_item	2519908	et	4	main
neid	doc_491521501857_item	2519909	et	4	main
sõna-sõnaliselt	doc_491521501857_item	2519910	et	4	main
ja	doc_491521501857_item	2519911	et	3	main
saades	doc_491521501857_item	2519912	et	3	main
isegi	doc_491521501857_item	2519913	et	4	main
enda	doc_491521501857_item	2519914	et	4	main
jaoks	doc_491521501857_item	2519915	et	4	main
arusaamatu	doc_491521501857_item	2519916	et	4	main
kalambuuri	doc_491521501857_item	2519917	et	4	main
nagu	doc_491521501857_item	2519918	et	3	main
näiteks	doc_491521501857_item	2519919	et	4	main
töid	doc_491521501857_item	2519920	et	3	main
parandan	doc_491521501857_item	2519922	et	3	main
vaid	doc_491521501857_item	2519923	et	3	main
õpilased	doc_491521501857_item	2519932	et	3	main
varem	doc_491521501857_item	2519935	et	4	main
kokku	doc_491521501857_item	2519936	et	3	main
puutunud	doc_491521501857_item	2519937	et	4	main
b	doc_491521501857_item	2519993	et	4	main
ei	doc_491521501857_item	2520006	et	4	main
kuulu	doc_491521501857_item	2520007	et	4	main
õppinud	doc_491521501857_item	2520027	et	4	main
alates	doc_491521501857_item	2520030	et	3	main
või	doc_491521501857_item	2520032	et	4	main
tõttu	doc_491521501857_item	2520040	et	4	main
nad	doc_491521501857_item	2520050	et	3	main
endale	doc_491521501857_item	2520071	et	4	main
kirjutatud	doc_491521501857_item	2520078	et	4	main
mida	doc_491521501857_item	2519858	et	4	main
õpilased	doc_491521501857_item	2519860	et	3	main
visuaalsele	doc_491521501857_item	2519868	et	3	main
mälule	doc_491521501857_item	2519869	et	3	main
õiget	doc_491521501857_item	2519873	et	3	main
ja	doc_491521501857_item	2519875	et	3	main
ka	doc_491521501857_item	2519876	et	3	main
tihti	doc_491521501857_item	2519877	et	3	main
kohatava	doc_491521501857_item	2519878	et	4	main
palun	doc_491521501857_item	2519882	et	3	main
ka	doc_491521501857_item	2519883	et	3	main
kirjalikult	doc_491521501857_item	2519887	et	4	main
sellega	doc_491521501857_item	2519895	et	3	main
asa	doc_491521501857_item	2519930	et	3	main
pannes	doc_491521501857_item	2519944	et	4	main
hinde	doc_491521501857_item	2519946	et	4	main
välja	doc_491521501857_item	2519947	et	4	main
korral	doc_491521501857_item	2519952	et	4	main
parandada	doc_491521501857_item	2519958	et	3	main
arutleme	doc_491521501857_item	2519960	et	3	main
lisa	doc_491521501857_item	2519984	et	4	main
1korraldasin	doc_491521501857_item	2519985	et	3	main
v	doc_491521501857_item	2519995	et	4	main
kahes	doc_491521501857_item	2519997	et	4	main
7	doc_491521501857_item	2519999	et	2	main
7	doc_491521501857_item	2520001	et	2	main
c	doc_491521501857_item	2520002	et	4	main
klassis	doc_491521501857_item	2520003	et	3	main
kelle	doc_491521501857_item	2520004	et	4	main
õpilased	doc_491521501857_item	2520005	et	3	main
kes	doc_491521501857_item	2520010	et	4	main
kuid	doc_491521501857_item	2520013	et	4	main
ole	doc_491521501857_item	2520015	et	4	main
kogunenud	doc_491521501857_item	2520021	et	4	main
eesti	doc_491521501857_item	2520023	et	4	main
klassist	doc_491521501857_item	2520029	et	3	main
4	doc_491521501857_item	2520031	et	2	main
5	doc_491521501857_item	2520033	et	2	main
korda	doc_491521501857_item	2520034	et	4	main
pole	doc_491521501857_item	2520041	et	3	main
üldiselt	doc_491521501857_item	2520048	et	4	main
aktiivsed	doc_491521501857_item	2520054	et	3	main
lapsed	doc_491521501857_item	2520055	et	3	main
on	doc_491521501857_item	2520057	et	4	main
tööd	doc_491521501857_item	2520059	et	4	main
teha	doc_491521501857_item	2520060	et	3	main
lähemalt	doc_491521501857_item	2520063	et	4	main
endast	doc_491521501857_item	2520065	et	4	main
ning	doc_491521501857_item	2520073	et	3	main
klassitahvlile	doc_491521501857_item	2520079	et	3	main
lahenduseks	doc_491521501857_item	2520080	et	4	main
kirjuta	doc_491521501857_item	2520099	et	4	main
eksimuste	doc_491521501857_item	2520128	et	4	main
põhjusi	doc_491521501857_item	2520129	et	3	main
ei	doc_491521501857_item	2520130	et	4	main
ole	doc_491521501857_item	2520131	et	4	main
ka	doc_491521501857_item	2520132	et	3	main
esineb	doc_491521501857_item	2520139	et	3	main
vene	doc_491521501857_item	2520149	et	4	main
ning	doc_491521501857_item	2520156	et	3	main
ole	doc_491521501857_item	2520159	et	4	main
2	doc_491521501857_item	2520175	et	2	main
keeles	doc_491521501857_item	2520178	et	4	main
diftonge	doc_491521501857_item	2520180	et	3	main
tuleb	doc_491521501857_item	2520183	et	3	main
järgi	doc_491521501857_item	2520197	et	4	main
häälikud	doc_491521501857_item	2520210	et	3	main
selle	doc_491521501857_item	2519928	et	4	main
veel	doc_491521501857_item	2519934	et	4	main
üldiselt	doc_491521501857_item	2519938	et	4	main
märgistan	doc_491521501857_item	2519939	et	3	main
või	doc_491521501857_item	2519942	et	4	main
soovi	doc_491521501857_item	2519948	et	4	main
hea	doc_491521501857_item	2519949	et	4	main
vigade	doc_491521501857_item	2519950	et	3	main
paranduse	doc_491521501857_item	2519951	et	4	main
ka	doc_491521501857_item	2519957	et	3	main
vead	doc_491521501857_item	2519962	et	4	main
üle	doc_491521501857_item	2519963	et	3	main
vajaduse	doc_491521501857_item	2519964	et	3	main
korral	doc_491521501857_item	2519965	et	4	main
tehes	doc_491521501857_item	2519966	et	3	main
veel	doc_491521501857_item	2519967	et	4	main
mõningaid	doc_491521501857_item	2519968	et	3	main
harjutusi	doc_491521501857_item	2519969	et	4	main
analoogiliste	doc_491521501857_item	2519970	et	4	main
vigade	doc_491521501857_item	2519971	et	3	main
vältimiseks	doc_491521501857_item	2519972	et	4	main
tulevikus	doc_491521501857_item	2519973	et	4	main
viimane	doc_491521501857_item	2519974	et	3	main
antud	doc_491521501857_item	2519975	et	4	main
tüüpi	doc_491521501857_item	2519976	et	4	main
minikontrolltöö	doc_491521501857_item	2519977	et	4	main
selle	doc_491521501857_item	2519986	et	4	main
esimese	doc_491521501857_item	2519987	et	3	main
veerandi	doc_491521501857_item	2519988	et	4	main
ja	doc_491521501857_item	2519994	et	3	main
ning	doc_491521501857_item	2519996	et	3	main
seitsmendas	doc_491521501857_item	2519998	et	3	main
moodustavad	doc_491521501857_item	2520011	et	4	main
ei	doc_491521501857_item	2520014	et	4	main
ka	doc_491521501857_item	2520016	et	3	main
kes	doc_491521501857_item	2520019	et	4	main
teisest	doc_491521501857_item	2520028	et	4	main
aga	doc_491521501857_item	2520042	et	3	main
nende	doc_491521501857_item	2520045	et	4	main
rõõmsameelsed	doc_491521501857_item	2520051	et	3	main
aga	doc_491521501857_item	2520062	et	3	main
õpilane	doc_491521501857_item	2520067	et	3	main
tunni	doc_491521501857_item	2520069	et	3	main
ülesannet	doc_491521501857_item	2520075	et	4	main
aega	doc_491521501857_item	2520082	et	4	main
25	doc_491521501857_item	2520084	et	2	main
kalasid	doc_491521501857_item	2520087	et	4	main
järgmiselt	doc_491521501857_item	2520088	et	4	main
kasutades	doc_491521501857_item	2520090	et	3	main
paranda	doc_491521501857_item	2520094	et	4	main
õige	doc_491521501857_item	2520100	et	4	main
esitatud	doc_491521501857_item	2520121	et	4	main
tabelis	doc_491521501857_item	2520126	et	3	main
nr1	doc_491521501857_item	2520127	et	4	main
ära	doc_491521501857_item	2520134	et	4	main
seletada	doc_491521501857_item	2520135	et	3	main
1	doc_491521501857_item	2520136	et	2	main
eesti	doc_491521501857_item	2520137	et	4	main
keeles	doc_491521501857_item	2520138	et	4	main
neil	doc_491521501857_item	2520146	et	4	main
iiks	doc_491521501857_item	2520154	et	4	main
3	doc_491521501857_item	2520168	et	2	main
ka	doc_491521501857_item	2520172	et	3	main
kuna	doc_491521501857_item	2520176	et	3	main
keeletundidest	doc_491521501857_item	2520186	et	3	main
panna	doc_491521501857_item	2520188	et	4	main
sõnu	doc_491521501857_item	2520198	et	4	main
õigesti	doc_491521501857_item	2520199	et	3	main
kirjutada	doc_491521501857_item	2520200	et	3	main
3	doc_491521501857_item	2520201	et	2	main
klusiilide	doc_491521501857_item	2520202	et	3	main
p	doc_491521501857_item	2520212	et	4	main
vähem	doc_491521501857_item	2520232	et	4	main
ka	doc_491521501857_item	2520234	et	3	main
silmad	doc_491521501857_item	2520239	et	4	main
eksitakse	doc_491521501857_item	2520248	et	4	main
vähe	doc_491521501857_item	2520251	et	3	main
klassis	doc_491521501857_item	2520259	et	3	main
sagedasemate	doc_491521501857_item	2520266	et	4	main
tavaliselt	doc_491521501857_item	2520285	et	4	main
otsivad	doc_491521501857_item	2520286	et	4	main
algvorrnis	doc_491521501857_item	2520295	et	4	main
väga	doc_491521501857_item	2520302	et	3	main
lisama	doc_491521501857_item	2520307	et	3	main
vt	doc_491521501857_item	2520315	et	4	main
isegi	doc_491521501857_item	2520340	et	4	main
muinasjutu	doc_491521501857_item	2520341	et	3	main
tegelasi	doc_491521501857_item	2520342	et	3	main
kirjutada	doc_491521501857_item	2520343	et	3	main
suure	doc_491521501857_item	2520344	et	3	main
algustähega	doc_491521501857_item	2520345	et	3	main
nii	doc_491521501857_item	2520346	et	3	main
et	doc_491521501857_item	2520347	et	3	main
tööd	doc_491521501857_item	2520348	et	4	main
naljakaid	doc_491521501857_item	2520353	et	4	main
väga	doc_491521501857_item	2520375	et	3	main
kuna	doc_491521501857_item	2520393	et	3	main
väga	doc_491521501857_item	2520395	et	3	main
sellest	doc_491521501857_item	2520403	et	4	main
tal	doc_491521501857_item	2520407	et	3	main
omandada	doc_491521501857_item	2520409	et	3	main
usin	doc_491521501857_item	2520411	et	3	main
on	doc_491521501857_item	2520413	et	4	main
pole	doc_491521501857_item	2520424	et	3	main
kõige	doc_491521501857_item	2520426	et	4	main
ja	doc_491521501857_item	2520428	et	3	main
kuid	doc_491521501857_item	2520432	et	4	main
esse	doc_491521501857_item	2520022	et	3	main
keelt	doc_491521501857_item	2520024	et	4	main
on	doc_491521501857_item	2520025	et	4	main
nad	doc_491521501857_item	2520026	et	3	main
nädalas	doc_491521501857_item	2520035	et	3	main
kunstist	doc_491521501857_item	2520036	et	4	main
tantsimisest	doc_491521501857_item	2520037	et	4	main
suure	doc_491521501857_item	2520038	et	3	main
see	doc_491521501857_item	2520043	et	3	main
on	doc_491521501857_item	2520049	et	4	main
ning	doc_491521501857_item	2520052	et	3	main
nüüd	doc_491521501857_item	2520061	et	4	main
iga	doc_491521501857_item	2520066	et	4	main
sai	doc_491521501857_item	2520068	et	4	main
alguses	doc_491521501857_item	2520070	et	4	main
paljunduse	doc_491521501857_item	2520072	et	4	main
olid	doc_491521501857_item	2520077	et	4	main
oli	doc_491521501857_item	2520081	et	3	main
ca	doc_491521501857_item	2520083	et	4	main
ülesanded	doc_491521501857_item	2520086	et	3	main
olev	doc_491521501857_item	2520092	et	4	main
oma	doc_491521501857_item	2520103	et	4	main
vihikusse	doc_491521501857_item	2520104	et	3	main
ümber	doc_491521501857_item	2520105	et	3	main
3	doc_491521501857_item	2520106	et	2	main
tekst	doc_491521501857_item	2520108	et	3	main
vene	doc_491521501857_item	2520109	et	4	main
tõlgi	doc_491521501857_item	2520107	et	4	main
keelde	doc_491521501857_item	2520110	et	4	main
vead	doc_491521501857_item	2520111	et	4	main
mis	doc_491521501857_item	2520112	et	4	main
jäid	doc_491521501857_item	2520113	et	4	main
õpilaste	doc_491521501857_item	2520114	et	4	main
töödes	doc_491521501857_item	2520115	et	3	main
märkamata	doc_491521501857_item	2520116	et	4	main
ja	doc_491521501857_item	2520117	et	3	main
ka	doc_491521501857_item	2520118	et	3	main
parandamata	doc_491521501857_item	2520119	et	4	main
on	doc_491521501857_item	2520120	et	4	main
lähtudes	doc_491521501857_item	2520122	et	3	main
infinitiivi	doc_491521501857_item	2520141	et	4	main
on	doc_491521501857_item	2520151	et	4	main
vaid	doc_491521501857_item	2520153	et	3	main
infinitiiv	doc_491521501857_item	2520155	et	3	main
verbi	doc_491521501857_item	2520169	et	4	main
on	doc_491521501857_item	2520179	et	4	main
suhteliselt	doc_491521501857_item	2520181	et	4	main
esimesest	doc_491521501857_item	2520185	et	3	main
alates	doc_491521501857_item	2520187	et	3	main
õigele	doc_491521501857_item	2520189	et	3	main
see	doc_491521501857_item	2520192	et	3	main
aitab	doc_491521501857_item	2520193	et	3	main
edaspidi	doc_491521501857_item	2520194	et	3	main
oma	doc_491521501857_item	2520195	et	4	main
tekitab	doc_491521501857_item	2520204	et	3	main
raskusi	doc_491521501857_item	2520205	et	4	main
need	doc_491521501857_item	2520209	et	3	main
tugevad	doc_491521501857_item	2520222	et	4	main
samas	doc_491521501857_item	2520223	et	4	main
et	doc_491521501857_item	2520226	et	3	main
mida	doc_491521501857_item	2520227	et	4	main
tuttavam	doc_491521501857_item	2520228	et	4	main
nii	doc_491521501857_item	2520236	et	3	main
keeletundidest	doc_491521501857_item	2520245	et	3	main
laual	doc_491521501857_item	2520091	et	3	main
olevad	doc_491521501857_item	2520096	et	4	main
vead	doc_491521501857_item	2520097	et	4	main
2	doc_491521501857_item	2520098	et	2	main
tekst	doc_491521501857_item	2520102	et	3	main
esinemise	doc_491521501857_item	2520123	et	4	main
sageduse	doc_491521501857_item	2520124	et	4	main
järjekorrast	doc_491521501857_item	2520125	et	4	main
raske	doc_491521501857_item	2520133	et	4	main
2	doc_491521501857_item	2520140	et	2	main
ja	doc_491521501857_item	2520143	et	3	main
ja	doc_491521501857_item	2520145	et	3	main
on	doc_491521501857_item	2520147	et	4	main
käändevormi	doc_491521501857_item	2520148	et	4	main
aga	doc_491521501857_item	2520152	et	3	main
põhivormi	doc_491521501857_item	2520170	et	4	main
meeldejätmist	doc_491521501857_item	2520174	et	3	main
vähe	doc_491521501857_item	2520182	et	3	main
juba	doc_491521501857_item	2520184	et	3	main
hääldusele	doc_491521501857_item	2520190	et	4	main
rõhku	doc_491521501857_item	2520191	et	4	main
puhul	doc_491521501857_item	2520203	et	4	main
k	doc_491521501857_item	2520211	et	4	main
mis	doc_491521501857_item	2520214	et	4	main
on	doc_491521501857_item	2520229	et	4	main
selles	doc_491521501857_item	2520233	et	4	main
eksitakse	doc_491521501857_item	2520235	et	4	main
näiteks	doc_491521501857_item	2520237	et	4	main
sõna	doc_491521501857_item	2520238	et	4	main
juba	doc_491521501857_item	2520243	et	3	main
ka	doc_491521501857_item	2520250	et	3	main
kes	doc_491521501857_item	2520257	et	4	main
viiendas	doc_491521501857_item	2520258	et	3	main
vigade	doc_491521501857_item	2520267	et	3	main
nii	doc_491521501857_item	2520272	et	3	main
raskem	doc_491521501857_item	2520280	et	4	main
on	doc_491521501857_item	2520281	et	4	main
tal	doc_491521501857_item	2520282	et	3	main
proovides	doc_491521501857_item	2520292	et	4	main
ehk	doc_491521501857_item	2520294	et	3	main
lause	doc_491521501857_item	2520298	et	4	main
tulemuseks	doc_491521501857_item	2520299	et	3	main
kohmakad	doc_491521501857_item	2520303	et	3	main
midagi	doc_491521501857_item	2520308	et	4	main
poolt	doc_491521501857_item	2520310	et	4	main
saades	doc_491521501857_item	2520311	et	3	main
omapärase	doc_491521501857_item	2520312	et	4	main
lisa	doc_491521501857_item	2520316	et	4	main
aga	doc_491521501857_item	2520321	et	3	main
ma-	doc_491521501857_item	2520142	et	3	main
da-tegevusm	doc_491521501857_item	2520144	et	4	main
keeles	doc_491521501857_item	2520150	et	4	main
tal	doc_491521501857_item	2520157	et	3	main
ei	doc_491521501857_item	2520158	et	4	main
käändevormi	doc_491521501857_item	2520160	et	4	main
nõnda	doc_491521501857_item	2520161	et	3	main
tegeles	doc_491521501857_item	2520162	et	3	main
uue	doc_491521501857_item	2520163	et	3	main
sõnavara	doc_491521501857_item	2520164	et	4	main
omandamisega	doc_491521501857_item	2520165	et	4	main
tuleb	doc_491521501857_item	2520166	et	3	main
anda	doc_491521501857_item	2520167	et	3	main
nõudes	doc_491521501857_item	2520171	et	4	main
nende	doc_491521501857_item	2520173	et	4	main
vene	doc_491521501857_item	2520177	et	4	main
kõrva	doc_491521501857_item	2520196	et	4	main
aga	doc_491521501857_item	2520206	et	3	main
see	doc_491521501857_item	2520207	et	3	main
et	doc_491521501857_item	2520208	et	3	main
t	doc_491521501857_item	2520213	et	4	main
on	doc_491521501857_item	2520215	et	4	main
vene	doc_491521501857_item	2520216	et	4	main
keeles	doc_491521501857_item	2520217	et	4	main
nõrgad	doc_491521501857_item	2520218	et	3	main
on	doc_491521501857_item	2520219	et	4	main
eesti	doc_491521501857_item	2520220	et	4	main
sõna	doc_491521501857_item	2520230	et	4	main
esimestest	doc_491521501857_item	2520244	et	4	main
alates	doc_491521501857_item	2520246	et	3	main
vormiga	doc_491521501857_item	2520253	et	4	main
aga	doc_491521501857_item	2520255	et	3	main
harva	doc_491521501857_item	2520256	et	4	main
hulgas	doc_491521501857_item	2520268	et	4	main
tõlgetest	doc_491521501857_item	2520270	et	3	main
seda	doc_491521501857_item	2520297	et	3	main
on	doc_491521501857_item	2520300	et	4	main
siis	doc_491521501857_item	2520305	et	3	main
enda	doc_491521501857_item	2520309	et	4	main
stiili	doc_491521501857_item	2520323	et	4	main
poolest	doc_491521501857_item	2520324	et	4	main
pööratakse	doc_491521501857_item	2520329	et	3	main
tähelepanu	doc_491521501857_item	2520330	et	4	main
kontekstile	doc_491521501857_item	2520331	et	3	main
erinevustele	doc_491521501857_item	2520336	et	4	main
mõningad	doc_491521501857_item	2520337	et	3	main
taipavad	doc_491521501857_item	2520338	et	4	main
palju	doc_491521501857_item	2520350	et	4	main
aga	doc_491521501857_item	2520374	et	3	main
spetsiaalselt	doc_491521501857_item	2520387	et	4	main
kartes	doc_491521501857_item	2520388	et	3	main
isikust	doc_491521501857_item	2520402	et	4	main
on	doc_491521501857_item	2520406	et	4	main
kui	doc_491521501857_item	2520410	et	3	main
ja	doc_491521501857_item	2520414	et	3	main
on	doc_491521501857_item	2520416	et	4	main
tal	doc_491521501857_item	2520417	et	3	main
võimalused	doc_491521501857_item	2520418	et	3	main
keelekasutamiseks	doc_491521501857_item	2520419	et	3	main
ka	doc_491521501857_item	2520420	et	3	main
ilusam	doc_491521501857_item	2520427	et	4	main
ka	doc_491521501857_item	2520429	et	3	main
viisakam	doc_491521501857_item	2520430	et	4	main
väljend	doc_491521501857_item	2520431	et	3	main
pedagoogidega	doc_491521501857_item	2520437	et	3	main
nõus	doc_491521501857_item	2520438	et	4	main
on	doc_491521501857_item	2520443	et	4	main
tööd	doc_491521501857_item	2520446	et	4	main
ja	doc_491521501857_item	2520447	et	3	main
leidub	doc_491521501857_item	2520448	et	3	main
kes	doc_491521501857_item	2520454	et	4	main
seletamise	doc_491521501857_item	2520456	et	4	main
silmat	doc_491521501857_item	2520496	et	4	main
ei	doc_491521501857_item	2520497	et	4	main
on	doc_491521501857_item	2520512	et	4	main
üppan	doc_491521501857_item	2520517	et	4	main
keeles	doc_491521501857_item	2520221	et	4	main
tuleb	doc_491521501857_item	2520224	et	3	main
mainida	doc_491521501857_item	2520225	et	3	main
seda	doc_491521501857_item	2520231	et	3	main
on	doc_491521501857_item	2520240	et	4	main
paljudele	doc_491521501857_item	2520241	et	3	main
tuttav	doc_491521501857_item	2520242	et	3	main
sellega	doc_491521501857_item	2520249	et	3	main
varem	doc_491521501857_item	2520260	et	4	main
kohtunud	doc_491521501857_item	2520261	et	4	main
nõnda	doc_491521501857_item	2520262	et	3	main
on	doc_491521501857_item	2520263	et	4	main
see	doc_491521501857_item	2520264	et	3	main
ka	doc_491521501857_item	2520265	et	3	main
palju	doc_491521501857_item	2520273	et	4	main
mida	doc_491521501857_item	2520275	et	4	main
teksti	doc_491521501857_item	2520283	et	4	main
tähenduse	doc_491521501857_item	2520289	et	4	main
sõnastikest	doc_491521501857_item	2520290	et	3	main
välja	doc_491521501857_item	2520291	et	4	main
paigutada	doc_491521501857_item	2520296	et	3	main
sageli	doc_491521501857_item	2520301	et	3	main
laused	doc_491521501857_item	2520304	et	3	main
jutustuse	doc_491521501857_item	2520313	et	4	main
variandi	doc_491521501857_item	2520314	et	4	main
2	doc_491521501857_item	2520317	et	2	main
klassides	doc_491521501857_item	2520319	et	3	main
vanemates	doc_491521501857_item	2520318	et	4	main
on	doc_491521501857_item	2520320	et	4	main
tööd	doc_491521501857_item	2520327	et	4	main
siin	doc_491521501857_item	2520328	et	4	main
seda	doc_491521501857_item	2520362	et	3	main
väiksem	doc_491521501857_item	2520368	et	4	main
vigade	doc_491521501857_item	2520369	et	3	main
arv	doc_491521501857_item	2520370	et	3	main
mõningaid	doc_491521501857_item	2520371	et	3	main
vigu	doc_491521501857_item	2520372	et	3	main
kirjutamist	doc_491521501857_item	2520386	et	4	main
või	doc_491521501857_item	2520390	et	4	main
hästi	doc_491521501857_item	2520396	et	3	main
keelt	doc_491521501857_item	2520397	et	4	main
üldiselt	doc_491521501857_item	2520398	et	4	main
sõltub	doc_491521501857_item	2520399	et	3	main
ained	doc_491521501857_item	2520405	et	3	main
lisada	doc_491521501857_item	2520441	et	3	main
leiavad	doc_491521501857_item	2520458	et	3	main
kus	doc_491521501857_item	2520460	et	3	main
et	doc_491521501857_item	2520494	et	3	main
otsas	doc_491521501857_item	2520500	et	4	main
miks	doc_491521501857_item	2520505	et	4	main
te	doc_491521501857_item	2520509	et	4	main
imestab	doc_491521501857_item	2520518	et	3	main
ald	doc_491521501857_item	2520524	et	4	main
läpi	doc_491521501857_item	2520527	et	4	main
hüpada	doc_491521501857_item	2520528	et	4	main
kasutatud	doc_491521501857_item	2520529	et	4	main
kirjandus	doc_491521501857_item	2520530	et	3	main
maisla	doc_491521501857_item	2520548	et	4	main
d	doc_491521501857_item	2520549	et	4	main
2000	doc_491521501857_item	2520550	et	2	main
vigade	doc_491521501857_item	2520551	et	3	main
lk	doc_491521501857_item	2520554	et	4	main
tallinna	doc_491521501858_item	2520558	et	4	main
eesti	doc_491521501858_item	2520560	et	4	main
tallinn	doc_491521501858_item	2520566	et	4	main
kommentaar	doc_491521501858_item	2520568	et	3	main
minna	doc_491521501858_item	2520574	et	3	main
keele	doc_491521501858_item	2520582	et	4	main
mulle	doc_491521501858_item	2520592	et	4	main
klassist	doc_491521501858_item	2520629	et	3	main
veel	doc_491521501858_item	2520636	et	4	main
õpib	doc_491521501858_item	2520637	et	3	main
talle	doc_491521501858_item	2520644	et	4	main
sõnade	doc_491521501858_item	2520652	et	3	main
le	doc_491521501858_item	2520657	et	4	main
kes	doc_491521501858_item	2520658	et	4	main
pole	doc_491521501858_item	2520663	et	3	main
ainus	doc_491521501858_item	2520668	et	4	main
keelt	doc_491521501858_item	2520674	et	4	main
seepärast	doc_491521501857_item	2520247	et	3	main
hüpata	doc_491521501857_item	2520252	et	4	main
on	doc_491521501857_item	2520254	et	4	main
4	doc_491521501857_item	2520269	et	2	main
aga	doc_491521501857_item	2520271	et	3	main
et	doc_491521501857_item	2520274	et	3	main
noorem	doc_491521501857_item	2520276	et	4	main
on	doc_491521501857_item	2520277	et	4	main
õpilane	doc_491521501857_item	2520278	et	3	main
seda	doc_491521501857_item	2520279	et	3	main
tõlkida	doc_491521501857_item	2520284	et	3	main
nad	doc_491521501857_item	2520287	et	3	main
täpse	doc_491521501857_item	2520288	et	3	main
muutumatuna	doc_491521501857_item	2520293	et	4	main
hakatakse	doc_491521501857_item	2520306	et	3	main
juba	doc_491521501857_item	2520322	et	3	main
palju	doc_491521501857_item	2520325	et	4	main
paremad	doc_491521501857_item	2520326	et	4	main
ka	doc_491521501857_item	2520333	et	3	main
kahe	doc_491521501857_item	2520334	et	3	main
keelte	doc_491521501857_item	2520335	et	3	main
näiteks	doc_491521501857_item	2520339	et	4	main
tõsisemad	doc_491521501857_item	2520351	et	4	main
ja	doc_491521501857_item	2520352	et	3	main
öelda	doc_491521501857_item	2520380	et	4	main
kas	doc_491521501857_item	2520381	et	3	main
õpilane	doc_491521501857_item	2520382	et	3	main
väldib	doc_491521501857_item	2520383	et	3	main
eksida	doc_491521501857_item	2520389	et	4	main
aga	doc_491521501857_item	2520400	et	3	main
palju	doc_491521501857_item	2520401	et	4	main
lihtsam	doc_491521501857_item	2520408	et	4	main
ta	doc_491521501857_item	2520412	et	4	main
kas	doc_491521501857_item	2520415	et	3	main
ja	doc_491521501857_item	2520332	et	3	main
on	doc_491521501857_item	2520349	et	4	main
variante	doc_491521501857_item	2520354	et	3	main
praktiliselt	doc_491521501857_item	2520355	et	4	main
ei	doc_491521501857_item	2520356	et	4	main
ole	doc_491521501857_item	2520357	et	4	main
niisiis	doc_491521501857_item	2520358	et	3	main
mida	doc_491521501857_item	2520359	et	4	main
vanemad	doc_491521501857_item	2520360	et	4	main
lapsed	doc_491521501857_item	2520361	et	3	main
suurem	doc_491521501857_item	2520363	et	4	main
on	doc_491521501857_item	2520364	et	4	main
nende	doc_491521501857_item	2520365	et	4	main
keelepädevus	doc_491521501857_item	2520366	et	4	main
ja	doc_491521501857_item	2520367	et	3	main
on	doc_491521501857_item	2520373	et	4	main
raske	doc_491521501857_item	2520376	et	4	main
klassifitseerida	doc_491521501857_item	2520377	et	3	main
nagu	doc_491521501857_item	2520378	et	3	main
ka	doc_491521501857_item	2520379	et	3	main
teatud	doc_491521501857_item	2520384	et	4	main
sõnade	doc_491521501857_item	2520385	et	3	main
asendab	doc_491521501857_item	2520391	et	3	main
neid	doc_491521501857_item	2520392	et	4	main
oskab	doc_491521501857_item	2520394	et	3	main
mis	doc_491521501857_item	2520404	et	4	main
väljaspool	doc_491521501857_item	2520421	et	3	main
võib-olla	doc_491521501857_item	2520423	et	3	main
kellele	doc_491521501857_item	2520439	et	4	main
ikkagi	doc_491521501857_item	2520449	et	4	main
andekat	doc_491521501857_item	2520451	et	3	main
tegijat	doc_491521501857_item	2520452	et	4	main
teha	doc_491521501857_item	2520462	et	3	main
rebane	doc_491521501857_item	2520466	et	4	main
ja	doc_491521501857_item	2520467	et	3	main
jänes	doc_491521501857_item	2520468	et	3	main
mul	doc_491521501857_item	2520495	et	3	main
nüüt	doc_491521501857_item	2520502	et	4	main
sa	doc_491521501857_item	2520506	et	3	main
üle	doc_491521501857_item	2520508	et	3	main
vastutulijaid	doc_491521501857_item	2520513	et	3	main
üle	doc_491521501857_item	2520515	et	3	main
ei	doc_491521501857_item	2520525	et	4	main
sa	doc_491521501857_item	2520526	et	3	main
a	doc_491521501857_item	2520532	et	4	main
2000	doc_491521501857_item	2520541	et	2	main
arendamine	doc_491521501857_item	2520543	et	4	main
tallinn	doc_491521501857_item	2520553	et	4	main
veaanalüüs	doc_491521501858_item	2520563	et	4	main
perekonnanimi	doc_491521501858_item	2520565	et	3	main
teha	doc_491521501858_item	2520570	et	3	main
eesti	doc_491521501858_item	2520581	et	4	main
keelt	doc_491521501858_item	2520624	et	4	main
õpib	doc_491521501858_item	2520625	et	3	main
ta	doc_491521501858_item	2520626	et	4	main
alates	doc_491521501858_item	2520627	et	3	main
ning	doc_491521501858_item	2520630	et	3	main
eesti	doc_491521501858_item	2520647	et	4	main
keele	doc_491521501858_item	2520648	et	4	main
ja	doc_491521501858_item	2520654	et	3	main
eesnim	doc_491521501858_item	2520656	et	4	main
elab	doc_491521501858_item	2520659	et	3	main
kel	doc_491521501858_item	2520662	et	3	main
koht	doc_491521501858_item	2520669	et	3	main
eesti	doc_491521501858_item	2520673	et	4	main
seda	doc_491521501858_item	2520678	et	3	main
segi	doc_491521501858_item	2520714	et	3	main
on	doc_491521501858_item	2520722	et	4	main
puhul	doc_491521501858_item	2520724	et	4	main
ortograafilised	doc_491521501858_item	2520725	et	4	main
morfoloogilisi	doc_491521501858_item	2520731	et	4	main
ning	doc_491521501858_item	2520732	et	3	main
on	doc_491521501858_item	2520743	et	4	main
teadlikumaks	doc_491521501858_item	2520750	et	4	main
tulevikus	doc_491521501858_item	2520757	et	4	main
töötama	doc_491521501858_item	2520758	et	3	main
tegelikkuses	doc_491521501858_item	2520759	et	4	main
on	doc_491521501858_item	2520760	et	4	main
on	doc_491521501858_item	2520768	et	4	main
suured	doc_491521501858_item	2520769	et	3	main
mis	doc_491521501858_item	2520771	et	4	main
väärtust	doc_491521501858_item	2520776	et	4	main
kui	doc_491521501858_item	2520781	et	3	main
või	doc_491521501858_item	2520786	et	4	main
pangadirektorina	doc_491521501858_item	2520787	et	3	main
populaarne	doc_491521501858_item	2520797	et	3	main
ei	doc_491521501858_item	2520801	et	4	main
kooli	doc_491521501857_item	2520422	et	4	main
see	doc_491521501857_item	2520425	et	3	main
paar	doc_491521501857_item	2520450	et	3	main
klassis	doc_491521501857_item	2520453	et	3	main
1	doc_491521501857_item	2520464	et	2	main
repane	doc_491521501857_item	2520469	et	4	main
ja	doc_491521501857_item	2520470	et	3	main
jäänes	doc_491521501857_item	2520471	et	4	main
läksid	doc_491521501857_item	2520472	et	4	main
möda	doc_491521501857_item	2520473	et	4	main
teed	doc_491521501857_item	2520474	et	4	main
kulla	doc_491521501857_item	2520475	et	4	main
pole	doc_491521501857_item	2520476	et	3	main
jäänes	doc_491521501857_item	2520477	et	4	main
küsip	doc_491521501857_item	2520478	et	4	main
rebaseld	doc_491521501857_item	2520479	et	4	main
mispärast	doc_491521501857_item	2520480	et	3	main
saa	doc_491521501857_item	2520481	et	4	main
aladi	doc_491521501857_item	2520482	et	4	main
takasi	doc_491521501857_item	2520483	et	4	main
vatad	doc_491521501857_item	2520484	et	4	main
kui	doc_491521501857_item	2520485	et	3	main
mõnnda	doc_491521501857_item	2520486	et	4	main
krabinad	doc_491521501857_item	2520487	et	3	main
kuled	doc_491521501857_item	2520488	et	4	main
rehane	doc_491521501857_item	2520489	et	4	main
vasstas	doc_491521501857_item	2520490	et	4	main
vaadan	doc_491521501857_item	2520491	et	4	main
tagasi	doc_491521501857_item	2520492	et	3	main
selepärast	doc_491521501857_item	2520493	et	4	main
olen	doc_491521501857_item	2520433	et	3	main
paljude	doc_491521501857_item	2520434	et	3	main
oma	doc_491521501857_item	2520435	et	4	main
tuttavate	doc_491521501857_item	2520436	et	3	main
meeldib	doc_491521501857_item	2520440	et	3	main
tublimatel	doc_491521501857_item	2520442	et	4	main
alati	doc_491521501857_item	2520444	et	4	main
head	doc_491521501857_item	2520445	et	4	main
vaatamata	doc_491521501857_item	2520455	et	4	main
näitlikusele	doc_491521501857_item	2520457	et	4	main
kohti	doc_491521501857_item	2520459	et	4	main
vigu	doc_491521501857_item	2520461	et	3	main
lisa	doc_491521501857_item	2520463	et	4	main
tekst	doc_491521501857_item	2520465	et	3	main
ole	doc_491521501857_item	2520498	et	4	main
aga	doc_491521501857_item	2520501	et	3	main
ütle	doc_491521501857_item	2520503	et	4	main
mule	doc_491521501857_item	2520504	et	4	main
ika	doc_491521501857_item	2520507	et	4	main
hüpad	doc_491521501857_item	2520510	et	4	main
kui	doc_491521501857_item	2520511	et	3	main
tee	doc_491521501857_item	2520516	et	4	main
muiduki	doc_491521501857_item	2520520	et	4	main
hausenberg	doc_491521501857_item	2520531	et	4	main
p	doc_491521501857_item	2520540	et	4	main
kirjutamisoskuse	doc_491521501857_item	2520542	et	3	main
7-10	doc_491521501857_item	2520555	et	2	main
2001	doc_491521501858_item	2520567	et	2	main
et	doc_491521501858_item	2520569	et	3	main
olen	doc_491521501858_item	2520572	et	3	main
sealsete	doc_491521501858_item	2520578	et	4	main
mitte-eestlastest	doc_491521501858_item	2520579	et	4	main
oskust	doc_491521501858_item	2520583	et	3	main
õppeaastal	doc_491521501858_item	2520594	et	3	main
3	doc_491521501858_item	2520628	et	2	main
tema	doc_491521501858_item	2520631	et	4	main
emakeeleks	doc_491521501858_item	2520632	et	4	main
ta	doc_491521501858_item	2520638	et	4	main
suuri	doc_491521501858_item	2520645	et	3	main
raskusi	doc_491521501858_item	2520646	et	4	main
lasnamäel	doc_491521501858_item	2520660	et	3	main
ning	doc_491521501858_item	2520661	et	3	main
eestlastest	doc_491521501858_item	2520664	et	4	main
sõpru	doc_491521501858_item	2520665	et	3	main
on	doc_491521501858_item	2520666	et	4	main
kus	doc_491521501858_item	2520670	et	3	main
rääkida	doc_491521501858_item	2520675	et	3	main
esineb	doc_491521501858_item	2520717	et	3	main
paronüümivigu	doc_491521501858_item	2520720	et	4	main
pisut	doc_491521501858_item	2520727	et	3	main
esineb	doc_491521501858_item	2520729	et	3	main
and	doc_491521501858_item	2520735	et	3	main
teha	doc_491521501858_item	2520737	et	3	main
levinud	doc_491521501858_item	2520744	et	4	main
ning	doc_491521501858_item	2520751	et	3	main
teavad	doc_491521501858_item	2520753	et	3	main
vähem	doc_491521501858_item	2520763	et	4	main
tegevuseta	doc_491521501858_item	2520773	et	4	main
kaotavad	doc_491521501858_item	2520774	et	4	main
igasugust	doc_491521501858_item	2520775	et	3	main
keelata	doc_491521501858_item	2520780	et	4	main
bisnesmenina	doc_491521501858_item	2520784	et	3	main
selge	doc_491521501858_item	2520789	et	4	main
et	doc_491521501858_item	2520790	et	3	main
inimesed	doc_491521501858_item	2520800	et	3	main
leppida	doc_491521501858_item	2520824	et	3	main
ootab	doc_491521501858_item	2520830	et	3	main
ees	doc_491521501858_item	2520832	et	4	main
vara	doc_491521501858_item	2520842	et	4	main
ametikohaga	doc_491521501858_item	2520843	et	4	main
tunnevad	doc_491521501858_item	2520846	et	3	main
ametikooli	doc_491521501858_item	2520849	et	4	main
on	doc_491521501858_item	2520867	et	4	main
keskharidust	doc_491521501858_item	2520869	et	4	main
käimine	doc_491521501858_item	2520873	et	4	main
ei	doc_491521501858_item	2520879	et	4	main
vaja	doc_491521501858_item	2520883	et	4	main
lihtsalt	doc_491521501858_item	2520886	et	4	main
amet	doc_491521501858_item	2520894	et	3	main
elanikest	doc_491521501858_item	2520905	et	3	main
materialseteta	doc_491521501858_item	2520907	et	4	main
sappa	doc_491521501857_item	2520499	et	3	main
ah	doc_491521501857_item	2520514	et	3	main
jänes	doc_491521501857_item	2520519	et	3	main
sellepärast	doc_491521501857_item	2520521	et	3	main
te	doc_491521501857_item	2520523	et	4	main
r	doc_491521501857_item	2520533	et	4	main
loengud	doc_491521501857_item	2520536	et	3	main
tplt	doc_491521501857_item	2520538	et	4	main
kartner	doc_491521501857_item	2520539	et	4	main
parandamine	doc_491521501857_item	2520552	et	4	main
keele	doc_491521501858_item	2520561	et	4	main
eesnimi	doc_491521501858_item	2520564	et	3	main
endine	doc_491521501858_item	2520585	et	3	main
keele	doc_491521501858_item	2520587	et	4	main
kui	doc_491521501858_item	2520588	et	3	main
käesoleval	doc_491521501858_item	2520593	et	3	main
kirjutatud	doc_491521501858_item	2520596	et	4	main
kirjandid	doc_491521501858_item	2520597	et	3	main
kuna	doc_491521501858_item	2520598	et	3	main
veaanalüüsitöö	doc_491521501858_item	2520599	et	4	main
et	doc_491521501857_item	2520522	et	3	main
2001	doc_491521501857_item	2520534	et	2	main
kontrastiivlingvistika	doc_491521501857_item	2520535	et	4	main
tallinn	doc_491521501857_item	2520537	et	4	main
tallinn	doc_491521501857_item	2520544	et	4	main
lk	doc_491521501857_item	2520545	et	4	main
7-11	doc_491521501857_item	2520546	et	2	main
30-32	doc_491521501857_item	2520547	et	2	main
25-30	doc_491521501857_item	2520556	et	2	main
analüüs	doc_491521501858_item	2520557	et	3	main
pedagoogikaiilikool	doc_491521501858_item	2520559	et	4	main
õppetool	doc_491521501858_item	2520562	et	3	main
veaanalüüsi	doc_491521501858_item	2520571	et	4	main
otsustanud	doc_491521501858_item	2520573	et	4	main
kooli	doc_491521501858_item	2520575	et	4	main
ning	doc_491521501858_item	2520576	et	3	main
uurida	doc_491521501858_item	2520577	et	3	main
õpilaste	doc_491521501858_item	2520580	et	4	main
minu	doc_491521501858_item	2520584	et	3	main
eesti	doc_491521501858_item	2520586	et	4	main
võõrkeele	doc_491521501858_item	2520589	et	4	main
õpetaja	doc_491521501858_item	2520590	et	4	main
andis	doc_491521501858_item	2520591	et	3	main
pikkus	doc_491521501858_item	2520600	et	4	main
õppijate	doc_491521501858_item	2520595	et	4	main
on	doc_491521501858_item	2520601	et	4	main
34	doc_491521501858_item	2520602	et	2	main
arvutilehekülge	doc_491521501858_item	2520603	et	4	main
otsustasin	doc_491521501858_item	2520604	et	3	main
võtta	doc_491521501858_item	2520605	et	3	main
ühe	doc_491521501858_item	2520606	et	4	main
õpilase	doc_491521501858_item	2520607	et	3	main
töö	doc_491521501858_item	2520608	et	4	main
eesnimi	doc_491521501858_item	2520609	et	3	main
õpilane	doc_491521501858_item	2520610	et	3	main
kelle	doc_491521501858_item	2520611	et	4	main
kirjandit	doc_491521501858_item	2520612	et	3	main
ma	doc_491521501858_item	2520613	et	3	main
analüüsisin	doc_491521501858_item	2520614	et	3	main
õpib	doc_491521501858_item	2520615	et	3	main
praegu	doc_491521501858_item	2520616	et	3	main
12	doc_491521501858_item	2520617	et	2	main
klassis	doc_491521501858_item	2520618	et	3	main
ning	doc_491521501858_item	2520619	et	3	main
lõpetab	doc_491521501858_item	2520620	et	3	main
tänavu	doc_491521501858_item	2520621	et	3	main
on	doc_491521501858_item	2520633	et	4	main
vene	doc_491521501858_item	2520634	et	4	main
inglise	doc_491521501858_item	2520639	et	4	main
keelt	doc_491521501858_item	2520640	et	4	main
käänamine	doc_491521501858_item	2520653	et	4	main
kool	doc_491521501858_item	2520667	et	4	main
ta	doc_491521501858_item	2520671	et	4	main
tema	doc_491521501858_item	2520683	et	4	main
riigikeele	doc_491521501858_item	2520684	et	4	main
seega	doc_491521501858_item	2520716	et	4	main
vead	doc_491521501858_item	2520726	et	4	main
vähem	doc_491521501858_item	2520728	et	4	main
tal	doc_491521501858_item	2520730	et	3	main
süntaksivigu	doc_491521501858_item	2520733	et	3	main
kooli	doc_491521501858_item	2520622	et	4	main
eesti	doc_491521501858_item	2520623	et	4	main
keel	doc_491521501858_item	2520635	et	4	main
tema	doc_491521501858_item	2520641	et	4	main
sõnul	doc_491521501858_item	2520642	et	3	main
tekitab	doc_491521501858_item	2520643	et	3	main
grammatika	doc_491521501858_item	2520649	et	4	main
eriti	doc_491521501858_item	2520650	et	3	main
astmevahelduslike	doc_491521501858_item	2520651	et	4	main
pööramine	doc_491521501858_item	2520655	et	4	main
saab	doc_491521501858_item	2520672	et	3	main
arvesse	doc_491521501858_item	2520677	et	4	main
asjaolu	doc_491521501858_item	2520679	et	4	main
võin	doc_491521501858_item	2520680	et	3	main
öelda	doc_491521501858_item	2520681	et	4	main
et	doc_491521501858_item	2520682	et	3	main
oskust	doc_491521501858_item	2520685	et	3	main
võib	doc_491521501858_item	2520686	et	3	main
pidada	doc_491521501858_item	2520687	et	4	main
küllaltki	doc_491521501858_item	2520688	et	4	main
heaks	doc_491521501858_item	2520689	et	4	main
irina	doc_491521501858_item	2520690	et	3	main
eesti	doc_491521501858_item	2520691	et	4	main
keel	doc_491521501858_item	2520692	et	4	main
nii	doc_491521501858_item	2520693	et	3	main
suuline	doc_491521501858_item	2520694	et	4	main
kui	doc_491521501858_item	2520695	et	3	main
ka	doc_491521501858_item	2520696	et	3	main
kirjalik	doc_491521501858_item	2520697	et	3	main
on	doc_491521501858_item	2520698	et	4	main
rikkalik	doc_491521501858_item	2520699	et	3	main
poolest	doc_491521501858_item	2520701	et	4	main
ja	doc_491521501858_item	2520702	et	3	main
sõnavara	doc_491521501858_item	2520700	et	4	main
ta	doc_491521501858_item	2520703	et	4	main
ei	doc_491521501858_item	2520704	et	4	main
karda	doc_491521501858_item	2520705	et	4	main
kasutada	doc_491521501858_item	2520706	et	3	main
sõnu	doc_491521501858_item	2520707	et	4	main
mis	doc_491521501858_item	2520708	et	4	main
võivad	doc_491521501858_item	2520709	et	4	main
keeletarvitajal	doc_491521501858_item	2520710	et	3	main
eriti	doc_491521501858_item	2520711	et	3	main
ebapiisava	doc_491521501858_item	2520712	et	3	main
keeleoskusega	doc_491521501858_item	2520713	et	3	main
võttes	doc_491521501858_item	2520676	et	4	main
minna	doc_491521501858_item	2520715	et	3	main
palju	doc_491521501858_item	2520719	et	4	main
sagedased	doc_491521501858_item	2520721	et	3	main
tema	doc_491521501858_item	2520723	et	4	main
juba	doc_491521501858_item	2520752	et	3	main
kus	doc_491521501858_item	2520754	et	3	main
sellist	doc_491521501858_item	2520761	et	4	main
noori	doc_491521501858_item	2520762	et	3	main
selliseid	doc_491521501858_item	2520765	et	4	main
kuid	doc_491521501858_item	2520770	et	4	main
vastavata	doc_491521501858_item	2520772	et	4	main
tahab	doc_491521501858_item	2520783	et	3	main
saada	doc_491521501858_item	2520785	et	4	main
on	doc_491521501858_item	2520788	et	4	main
mis	doc_491521501858_item	2520795	et	4	main
taha	doc_491521501858_item	2520823	et	4	main
teda	doc_491521501858_item	2520831	et	4	main
väga	doc_491521501858_item	2520833	et	3	main
noored	doc_491521501858_item	2520838	et	3	main
ei	doc_491521501858_item	2520839	et	4	main
nad	doc_491521501858_item	2520845	et	3	main
neil	doc_491521501858_item	2520852	et	4	main
saada	doc_491521501858_item	2520856	et	4	main
mõnes	doc_491521501858_item	2520857	et	3	main
mõttes	doc_491521501858_item	2520858	et	3	main
see	doc_491521501858_item	2520859	et	3	main
enamus	doc_491521501858_item	2520863	et	4	main
on	doc_491521501858_item	2520875	et	4	main
ebameeldiv	doc_491521501858_item	2520876	et	3	main
ja	doc_491521501858_item	2520877	et	3	main
ole	doc_491521501858_item	2520882	et	4	main
parem	doc_491521501858_item	2520891	et	4	main
kõik	doc_491521501858_item	2520896	et	4	main
saada	doc_491521501858_item	2520902	et	4	main
elavad	doc_491521501858_item	2520906	et	4	main
problemideta	doc_491521501858_item	2520908	et	4	main
saa	doc_491521501858_item	2520923	et	4	main
võlgades	doc_491521501858_item	2520927	et	3	main
aeg	doc_491521501858_item	2520930	et	3	main
eestis	doc_491521501858_item	2520932	et	3	main
paliu	doc_491521501858_item	2520942	et	4	main
osta	doc_491521501858_item	2520946	et	4	main
võib	doc_491521501858_item	2520949	et	3	main
inimene	doc_491521501858_item	2520952	et	3	main
täna	doc_491521501858_item	2520955	et	4	main
on	doc_491521501858_item	2520956	et	4	main
väga	doc_491521501858_item	2520957	et	3	main
oleksid	doc_491521501858_item	2520961	et	4	main
ning	doc_491521501858_item	2520964	et	3	main
oleksid	doc_491521501858_item	2520968	et	4	main
elukutse	doc_491521501858_item	2520973	et	4	main
kui	doc_491521501858_item	2520976	et	3	main
sobib	doc_491521501858_item	2520984	et	3	main
tea	doc_491521501858_item	2520999	et	4	main
enda	doc_491521501858_item	2521022	et	4	main
ja	doc_491521501858_item	2521024	et	3	main
jõuda	doc_491521501858_item	2521027	et	3	main
liikub	doc_491521501858_item	2521037	et	4	main
võib	doc_491521501858_item	2521040	et	3	main
olema	doc_491521501858_item	2521042	et	4	main
tema	doc_491521501858_item	2521044	et	4	main
inteks-	doc_491521501859_item	2521052	et	4	main
ekst	doc_491521501859_item	2521054	et	4	main
rateks	doc_491521501859_item	2521055	et	4	main
tuaalne	doc_491521501859_item	2521057	et	4	main
sotsiaalne	doc_491521501859_item	2521078	et	3	main
ruum	doc_491521501859_item	2521079	et	3	main
teos	doc_491521501859_item	2521085	et	4	main
kui	doc_491521501859_item	2521086	et	3	main
valjendus	doc_491521501859_item	2521089	et	4	main
kui	doc_491521501859_item	2521090	et	3	main
tal	doc_491521501858_item	2520718	et	3	main
mida	doc_491521501858_item	2520736	et	4	main
et	doc_491521501858_item	2520738	et	3	main
lootused	doc_491521501858_item	2520739	et	4	main
ei	doc_491521501858_item	2520740	et	4	main
puruneks	doc_491521501858_item	2520741	et	3	main
tänapaeval	doc_491521501858_item	2520742	et	4	main
muutunud	doc_491521501858_item	2520749	et	4	main
nad	doc_491521501858_item	2520755	et	3	main
kui	doc_491521501858_item	2520764	et	3	main
kelle	doc_491521501858_item	2520766	et	4	main
enamus	doc_491521501858_item	2520791	et	4	main
inimesi	doc_491521501858_item	2520792	et	4	main
tahab	doc_491521501858_item	2520793	et	3	main
seda	doc_491521501858_item	2520794	et	3	main
kõrgega	doc_491521501858_item	2520798	et	3	main
taha	doc_491521501858_item	2520802	et	4	main
tegema	doc_491521501858_item	2520803	et	3	main
tööd	doc_491521501858_item	2520804	et	4	main
mis	doc_491521501858_item	2520805	et	4	main
ei	doc_491521501858_item	2520806	et	4	main
vasta	doc_491521501858_item	2520807	et	4	main
nende	doc_491521501858_item	2520808	et	4	main
võimetele	doc_491521501858_item	2520809	et	4	main
tihti	doc_491521501858_item	2520810	et	3	main
ei	doc_491521501858_item	2520811	et	4	main
tunnusta	doc_491521501858_item	2520812	et	4	main
noored	doc_491521501858_item	2520813	et	3	main
tegelikke	doc_491521501858_item	2520814	et	3	main
võimeid	doc_491521501858_item	2520815	et	3	main
isegi	doc_491521501858_item	2520816	et	4	main
endale	doc_491521501858_item	2520817	et	4	main
ja	doc_491521501858_item	2520818	et	3	main
isegi	doc_491521501858_item	2520819	et	4	main
tavaline	doc_491521501858_item	2520820	et	4	main
ning	doc_491521501858_item	2520826	et	3	main
et	doc_491521501858_item	2520828	et	3	main
taha	doc_491521501858_item	2520840	et	4	main
ennast	doc_491521501858_item	2520841	et	4	main
et	doc_491521501858_item	2520848	et	3	main
haridusega	doc_491521501858_item	2520850	et	3	main
on	doc_491521501858_item	2520860	et	4	main
arvavad	doc_491521501858_item	2520865	et	4	main
aga	doc_491521501858_item	2520872	et	3	main
koolis	doc_491521501858_item	2520874	et	4	main
ei	doc_491521501858_item	2520881	et	4	main
oma	doc_491521501858_item	2520884	et	4	main
mõni	doc_491521501858_item	2520893	et	3	main
ei	doc_491521501858_item	2520898	et	4	main
või	doc_491521501858_item	2520899	et	4	main
suurt	doc_491521501858_item	2520900	et	3	main
ainult	doc_491521501858_item	2520903	et	4	main
saab	doc_491521501858_item	2520911	et	3	main
ei	doc_491521501858_item	2520922	et	4	main
elavad	doc_491521501858_item	2520926	et	4	main
mis	doc_491521501858_item	2520928	et	4	main
kasvavad	doc_491521501858_item	2520931	et	4	main
kõrege	doc_491521501858_item	2520935	et	4	main
haridusega	doc_491521501858_item	2520936	et	3	main
inimesi	doc_491521501858_item	2520937	et	4	main
kuid	doc_491521501858_item	2520947	et	4	main
kui	doc_491521501858_item	2520951	et	3	main
tööle	doc_491521501858_item	2520954	et	3	main
ka	doc_491521501858_item	2520965	et	3	main
kirj	doc_491521501858_item	2520734	et	4	main
arvamus	doc_491521501858_item	2520745	et	3	main
et	doc_491521501858_item	2520746	et	3	main
noored	doc_491521501858_item	2520747	et	3	main
on	doc_491521501858_item	2520748	et	4	main
hakkavad	doc_491521501858_item	2520756	et	4	main
lotused	doc_491521501858_item	2520767	et	4	main
ei	doc_491521501858_item	2520777	et	4	main
tohi	doc_491521501858_item	2520778	et	4	main
noorele	doc_491521501858_item	2520779	et	3	main
ta	doc_491521501858_item	2520782	et	4	main
on	doc_491521501858_item	2520796	et	4	main
haridusega	doc_491521501858_item	2520799	et	3	main
ei	doc_491521501858_item	2520822	et	4	main
realsusega	doc_491521501858_item	2520825	et	4	main
hirmu	doc_491521501858_item	2520847	et	4	main
pole	doc_491521501858_item	2520851	et	3	main
võimalust	doc_491521501858_item	2520853	et	3	main
sest	doc_491521501858_item	2520862	et	4	main
et	doc_491521501858_item	2520866	et	3	main
saama	doc_491521501858_item	2520870	et	4	main
kui	doc_491521501858_item	2520871	et	3	main
huvita	doc_491521501858_item	2520880	et	4	main
pead	doc_491521501858_item	2520885	et	4	main
vaevata	doc_491521501858_item	2520887	et	4	main
siis	doc_491521501858_item	2520888	et	3	main
kõige	doc_491521501858_item	2520890	et	4	main
palka	doc_491521501858_item	2520901	et	4	main
nad	doc_491521501858_item	2520925	et	3	main
kogu	doc_491521501858_item	2520929	et	4	main
on	doc_491521501858_item	2520933	et	4	main
palju	doc_491521501858_item	2520934	et	4	main
noored	doc_491521501858_item	2520943	et	3	main
tähtis	doc_491521501858_item	2520958	et	4	main
hea	doc_491521501858_item	2520962	et	4	main
huvitatud	doc_491521501858_item	2520970	et	4	main
valik	doc_491521501858_item	2520974	et	3	main
inimesele	doc_491521501858_item	2520983	et	3	main
mitu	doc_491521501858_item	2520985	et	4	main
kuid	doc_491521501858_item	2520987	et	4	main
inimene	doc_491521501858_item	2520990	et	3	main
ei	doc_491521501858_item	2520991	et	4	main
noor	doc_491521501858_item	2520821	et	3	main
loodab	doc_491521501858_item	2520827	et	3	main
kunagi	doc_491521501858_item	2520829	et	3	main
huvitav	doc_491521501858_item	2520834	et	4	main
kõrgega	doc_491521501858_item	2520835	et	3	main
maksuga	doc_491521501858_item	2520836	et	3	main
ametikoht	doc_491521501858_item	2520837	et	3	main
seoda	doc_491521501858_item	2520844	et	4	main
head	doc_491521501858_item	2520854	et	4	main
töökohta	doc_491521501858_item	2520855	et	4	main
õige	doc_491521501858_item	2520861	et	4	main
tööandjaid	doc_491521501858_item	2520864	et	3	main
vaja	doc_491521501858_item	2520868	et	4	main
aine	doc_491521501858_item	2520878	et	4	main
on	doc_491521501858_item	2520889	et	4	main
õppida	doc_491521501858_item	2520892	et	3	main
kuid	doc_491521501858_item	2520895	et	4	main
inimesed	doc_491521501858_item	2520897	et	3	main
10	doc_491521501858_item	2520904	et	2	main
kuidagi	doc_491521501858_item	2520912	et	3	main
hakkama	doc_491521501858_item	2520913	et	3	main
elades	doc_491521501858_item	2520914	et	4	main
al	doc_491521501858_item	2520915	et	4	main
ale	doc_491521501858_item	2520916	et	4	main
kuid	doc_491521501858_item	2520917	et	4	main
mina	doc_491521501858_item	2520918	et	4	main
tean	doc_491521501858_item	2520919	et	3	main
inimesi	doc_491521501858_item	2520920	et	4	main
kes	doc_491521501858_item	2520921	et	4	main
kuid	doc_491521501858_item	2520938	et	4	main
ka	doc_491521501858_item	2520939	et	3	main
madalaga	doc_491521501858_item	2520940	et	3	main
haridusega	doc_491521501858_item	2520941	et	3	main
et	doc_491521501858_item	2520959	et	3	main
suhtleja	doc_491521501858_item	2520963	et	4	main
tööga	doc_491521501858_item	2520969	et	3	main
vedab	doc_491521501858_item	2520979	et	4	main
mitte	doc_491521501858_item	2520981	et	3	main
edukas	doc_491521501858_item	2520994	et	4	main
kõikil	doc_491521501858_item	2520995	et	4	main
suundas	doc_491521501858_item	2521039	et	4	main
teksti-	doc_491521501859_item	2521050	et	4	main
40	doc_491521501859_item	2521074	et	2	main
a	doc_491521501859_item	2521097	et	4	main
autor	doc_491521501859_item	2521099	et	3	main
70	doc_491521501858_item	2520909	et	2	main
inimesi	doc_491521501858_item	2520910	et	4	main
hakkama	doc_491521501858_item	2520924	et	3	main
saavad	doc_491521501858_item	2520944	et	4	main
hariduse	doc_491521501858_item	2520945	et	3	main
see	doc_491521501858_item	2520948	et	3	main
selguda	doc_491521501858_item	2520950	et	3	main
läheb	doc_491521501858_item	2520953	et	3	main
sa	doc_491521501858_item	2520960	et	3	main
see	doc_491521501858_item	2520966	et	3	main
et	doc_491521501858_item	2520967	et	3	main
et	doc_491521501858_item	2520972	et	3	main
teisel	doc_491521501858_item	2520980	et	4	main
tegevusvaldkonda	doc_491521501858_item	2520986	et	4	main
üks	doc_491521501858_item	2520989	et	3	main
kohtadel	doc_491521501858_item	2520996	et	3	main
ei	doc_491521501858_item	2520998	et	4	main
paljud	doc_491521501858_item	2521000	et	3	main
inimesed	doc_491521501858_item	2521001	et	3	main
mida	doc_491521501858_item	2521002	et	4	main
nad	doc_491521501858_item	2521003	et	3	main
oskavad	doc_491521501858_item	2521004	et	4	main
tehapassivne	doc_491521501858_item	2521005	et	4	main
unistamine	doc_491521501858_item	2521006	et	4	main
põhjustab	doc_491521501858_item	2521007	et	3	main
aga	doc_491521501858_item	2521008	et	3	main
lootuste	doc_491521501858_item	2521009	et	4	main
purunemist	doc_491521501858_item	2521010	et	4	main
tahan	doc_491521501858_item	2521011	et	3	main
öelda	doc_491521501858_item	2521012	et	4	main
et	doc_491521501858_item	2521013	et	3	main
noor	doc_491521501858_item	2521014	et	3	main
inimene	doc_491521501858_item	2521015	et	3	main
ei	doc_491521501858_item	2521016	et	4	main
tohi	doc_491521501858_item	2521017	et	4	main
ennast	doc_491521501858_item	2521018	et	4	main
alahinnata	doc_491521501858_item	2521019	et	4	main
ta	doc_491521501858_item	2521020	et	4	main
peab	doc_491521501858_item	2521021	et	4	main
soovides	doc_491521501858_item	2521023	et	4	main
oskustes	doc_491521501858_item	2521025	et	3	main
selgusele	doc_491521501858_item	2521026	et	4	main
ning	doc_491521501858_item	2521028	et	3	main
aktiivselt	doc_491521501858_item	2521029	et	4	main
tegelema	doc_491521501858_item	2521030	et	3	main
kui	doc_491521501858_item	2521031	et	3	main
reaalseid	doc_491521501858_item	2521034	et	3	main
kindel	doc_491521501858_item	2521041	et	3	main
nlketuubid	doc_491521501859_item	2521049	et	4	main
tuaalne	doc_491521501859_item	2521060	et	4	main
qon	doc_491521501859_item	2521077	et	4	main
e	doc_491521501859_item	2521084	et	4	main
autori	doc_491521501859_item	2521087	et	3	main
iisametatekst	doc_491521501859_item	2521091	et	4	main
o	doc_491521501859_item	2521092	et	4	main
arnetlik	doc_491521501859_item	2521093	et	4	main
kultuuri-ja	doc_491521501859_item	2521094	et	3	main
tolkijaisiksus	doc_491521501859_item	2521096	et	4	main
j	doc_491521501859_item	2521103	et	4	main
öeldakse	doc_491521501858_item	2520971	et	3	main
on	doc_491521501858_item	2520975	et	4	main
lato	doc_491521501858_item	2520977	et	4	main
ühel	doc_491521501858_item	2520978	et	3	main
iaa	doc_491521501858_item	2520982	et	4	main
mitte	doc_491521501858_item	2520988	et	3	main
saa	doc_491521501858_item	2520992	et	4	main
olla	doc_491521501858_item	2520993	et	3	main
kahjuks	doc_491521501858_item	2520997	et	4	main
ta	doc_491521501858_item	2521032	et	4	main
püstitab	doc_491521501858_item	2521033	et	3	main
nende	doc_491521501858_item	2521038	et	4	main
et	doc_491521501858_item	2521043	et	3	main
interteks-	doc_491521501859_item	2521053	et	4	main
tuaalne	doc_491521501859_item	2521059	et	4	main
80	doc_491521501859_item	2521075	et	2	main
geograafiline	doc_491521501859_item	2521080	et	4	main
kui	doc_491521501859_item	2521082	et	3	main
eesmärke	doc_491521501858_item	2521035	et	4	main
ja	doc_491521501858_item	2521036	et	3	main
lootused	doc_491521501858_item	2521045	et	4	main
ei	doc_491521501858_item	2521046	et	4	main
purune	doc_491521501858_item	2521047	et	4	main
nlketuubid	doc_491521501859_item	2521048	et	4	main
metateks-	doc_491521501859_item	2521051	et	4	main
tolge	doc_491521501859_item	2521056	et	4	main
tuaalne	doc_491521501859_item	2521058	et	4	main
tnlge	doc_491521501859_item	2521061	et	4	main
tol	doc_491521501859_item	2521062	et	3	main
e	doc_491521501859_item	2521063	et	4	main
tol	doc_491521501859_item	2521064	et	3	main
e	doc_491521501859_item	2521065	et	4	main
tol	doc_491521501859_item	2521066	et	3	main
e	doc_491521501859_item	2521067	et	4	main
eesti	doc_491521501859_item	2521068	et	4	main
keel	doc_491521501859_item	2521069	et	4	main
ukraina	doc_491521501859_item	2521070	et	4	main
xx	doc_491521501859_item	2521071	et	4	main
sajandi	doc_491521501859_item	2521072	et	3	main
aeg	doc_491521501859_item	2521073	et	3	main
aastad	doc_491521501859_item	2521076	et	3	main
psiihholoogiline	doc_491521501859_item	2521081	et	4	main
autoritekst	doc_491521501859_item	2521083	et	3	main
taotluse	doc_491521501859_item	2521088	et	4	main
kirjanduspoliitika	doc_491521501859_item	2521095	et	4	main
retseptsioon	doc_491521501859_item	2521098	et	3	main
tolkija	doc_491521501859_item	2521100	et	4	main
v	doc_491521501859_item	2521101	et	4	main
lugea	doc_491521501859_item	2521102	et	4	main
analüüs	doc_491521501861_item	2522610	et	3	main
millele	doc_491521501861_item	2522615	et	3	main
pedagoogikaülikooli	doc_491521501861_item	2522622	et	4	main
korraldatava	doc_491521501861_item	2522625	et	4	main
keelekursuse	doc_491521501861_item	2522626	et	3	main
materjalidest	doc_491521501861_item	2522627	et	3	main
perekonnanime	doc_491521501861_item	2522634	et	4	main
ja	doc_491521501861_item	2522635	et	3	main
tehtud	doc_491521501861_item	2522636	et	4	main
vigade	doc_491521501861_item	2522637	et	3	main
omapoolsete	doc_491521501861_item	2522653	et	4	main
tallinnan	doc_491521501861_item	2522656	et	4	main
on	doc_491521501861_item	2522661	et	4	main
amadeus	doc_491521501861_item	2522662	et	4	main
on	doc_491521501861_item	2522677	et	4	main
koku	doc_491521501861_item	2522680	et	4	main
on	doc_491521501861_item	2522682	et	4	main
tüüpilised	doc_491521501861_item	2522687	et	3	main
on	doc_491521501861_item	2522697	et	4	main
hea	doc_491521501861_item	2522703	et	4	main
teenindamine	doc_491521501861_item	2522704	et	4	main
sealt	doc_491521501861_item	2522721	et	4	main
peate	doc_491521501861_item	2522723	et	4	main
hääldus-	doc_491521501861_item	2522732	et	4	main
siin	doc_491521501861_item	2522739	et	4	main
keele	doc_491521501861_item	2522748	et	4	main
sõna	doc_491521501861_item	2522766	et	4	main
u	doc_491521501861_item	2522775	et	4	main
hääldust	doc_491521501861_item	2522776	et	4	main
õpilase	doc_491521501861_item	2522613	et	3	main
toetusin	doc_491521501861_item	2522616	et	3	main
tallinna	doc_491521501861_item	2522621	et	4	main
õppejõu	doc_491521501861_item	2522623	et	3	main
poolt	doc_491521501861_item	2522624	et	4	main
täiskasvanud	doc_491521501861_item	2522631	et	4	main
inimene	doc_491521501861_item	2522632	et	3	main
kelle	doc_491521501861_item	2522633	et	4	main
kirjeldust	doc_491521501861_item	2522651	et	4	main
koos	doc_491521501861_item	2522652	et	4	main
kõige	doc_491521501861_item	2522657	et	4	main
asjatuntlikult	doc_491521501861_item	2522684	et	4	main
itaaliapäraseid	doc_491521501861_item	2522688	et	4	main
peaasjalikult	doc_491521501861_item	2522698	et	4	main
italialaasia	doc_491521501861_item	2522699	et	4	main
seal	doc_491521501861_item	2522705	et	4	main
just	doc_491521501861_item	2522710	et	3	main
amadeus	doc_491521501861_item	2522713	et	4	main
vigade	doc_491521501861_item	2522611	et	3	main
töö	doc_491521501861_item	2522614	et	4	main
oma	doc_491521501861_item	2522617	et	4	main
pildi	doc_491521501861_item	2522650	et	4	main
originaaltekst	doc_491521501861_item	2522655	et	3	main
itaalia	doc_491521501861_item	2522678	et	4	main
kiire	doc_491521501861_item	2522679	et	4	main
menüü	doc_491521501861_item	2522681	et	4	main
menüült	doc_491521501861_item	2522685	et	3	main
restoranil	doc_491521501861_item	2522690	et	3	main
on	doc_491521501861_item	2522691	et	4	main
korgklassist	doc_491521501861_item	2522709	et	4	main
on	doc_491521501861_item	2522714	et	4	main
wis	doc_491521501861_item	2522716	et	4	main
ette	doc_491521501861_item	2522728	et	4	main
registreeritud	doc_491521501861_item	2522729	et	4	main
vead	doc_491521501861_item	2522730	et	4	main
1	doc_491521501861_item	2522731	et	2	main
oletan	doc_491521501861_item	2522741	et	3	main
ja	doc_491521501861_item	2522750	et	3	main
sellest	doc_491521501861_item	2522752	et	4	main
õpilane	doc_491521501861_item	2522754	et	3	main
pd	doc_491521501861_item	2522756	et	4	main
ni	doc_491521501861_item	2522757	et	4	main
analüüs	doc_491521501861_item	2522612	et	3	main
analüüsis	doc_491521501861_item	2522618	et	4	main
pärineb	doc_491521501861_item	2522619	et	3	main
ühe	doc_491521501861_item	2522620	et	4	main
analüüsitava	doc_491521501861_item	2522628	et	4	main
on	doc_491521501861_item	2522644	et	4	main
soomlasega	doc_491521501861_item	2522645	et	3	main
see	doc_491521501861_item	2522646	et	3	main
tekst	doc_491521501861_item	2522647	et	3	main
kujutab	doc_491521501861_item	2522648	et	3	main
endast	doc_491521501861_item	2522649	et	4	main
kommentaaridega	doc_491521501861_item	2522654	et	3	main
restoranin	doc_491521501861_item	2522659	et	4	main
leitub	doc_491521501861_item	2522686	et	4	main
oma	doc_491521501861_item	2522692	et	4	main
spetsiaalne	doc_491521501861_item	2522693	et	3	main
veinkelder	doc_491521501861_item	2522694	et	4	main
ja	doc_491521501861_item	2522695	et	3	main
veineja	doc_491521501861_item	2522700	et	4	main
restoranis	doc_491521501861_item	2522701	et	3	main
on	doc_491521501861_item	2522706	et	4	main
nendel	doc_491521501861_item	2522711	et	4	main
lauta	doc_491521501861_item	2522720	et	4	main
astmevaheldusvead	doc_491521501861_item	2522735	et	4	main
ja	doc_491521501861_item	2522736	et	3	main
bildil	doc_491521501861_item	2522740	et	4	main
selline	doc_491521501861_item	2522743	et	4	main
on	doc_491521501861_item	2522745	et	4	main
tingitud	doc_491521501861_item	2522746	et	4	main
soome	doc_491521501861_item	2522747	et	3	main
i	doc_491521501861_item	2522759	et	4	main
peale	doc_491521501861_item	2522769	et	4	main
ja	doc_491521501861_item	2522771	et	3	main
peaks	doc_491521501861_item	2522778	et	4	main
muutub	doc_491521501861_item	2522788	et	3	main
et	doc_491521501861_item	2522792	et	3	main
on	doc_491521501861_item	2522794	et	4	main
teksti	doc_491521501861_item	2522629	et	4	main
kirjutas	doc_491521501861_item	2522630	et	3	main
järgi	doc_491521501861_item	2522638	et	4	main
saab	doc_491521501861_item	2522639	et	3	main
teha	doc_491521501861_item	2522640	et	3	main
järelduse	doc_491521501861_item	2522641	et	4	main
et	doc_491521501861_item	2522642	et	3	main
tegemist	doc_491521501861_item	2522643	et	4	main
parim	doc_491521501861_item	2522658	et	4	main
ja	doc_491521501861_item	2522663	et	3	main
nimi	doc_491521501861_item	2522660	et	3	main
see	doc_491521501861_item	2522664	et	3	main
on	doc_491521501861_item	2522665	et	4	main
siin	doc_491521501861_item	2522666	et	4	main
bildil	doc_491521501861_item	2522667	et	4	main
amadeus	doc_491521501861_item	2522668	et	4	main
restoran	doc_491521501861_item	2522669	et	3	main
on	doc_491521501861_item	2522670	et	4	main
hea	doc_491521501861_item	2522671	et	4	main
ja	doc_491521501861_item	2522672	et	3	main
uhke	doc_491521501861_item	2522673	et	4	main
restoran	doc_491521501861_item	2522674	et	3	main
see	doc_491521501861_item	2522675	et	3	main
restoranin	doc_491521501861_item	2522676	et	4	main
plaanitud	doc_491521501861_item	2522683	et	4	main
toitu	doc_491521501861_item	2522689	et	4	main
seal	doc_491521501861_item	2522696	et	4	main
on	doc_491521501861_item	2522702	et	4	main
koku	doc_491521501861_item	2522707	et	4	main
personal	doc_491521501861_item	2522708	et	3	main
pohjustel	doc_491521501861_item	2522712	et	4	main
alati	doc_491521501861_item	2522715	et	4	main
kui	doc_491521501861_item	2522717	et	3	main
te	doc_491521501861_item	2522718	et	4	main
tahate	doc_491521501861_item	2522719	et	3	main
teie	doc_491521501861_item	2522722	et	4	main
tellima	doc_491521501861_item	2522724	et	3	main
see	doc_491521501861_item	2522725	et	3	main
mittu	doc_491521501861_item	2522726	et	4	main
nädalad	doc_491521501861_item	2522727	et	3	main
õigekirja-	doc_491521501861_item	2522733	et	4	main
ja	doc_491521501861_item	2522734	et	3	main
et	doc_491521501861_item	2522742	et	3	main
hääldusviga	doc_491521501861_item	2522744	et	4	main
mõjust	doc_491521501861_item	2522749	et	3	main
et	doc_491521501861_item	2522753	et	3	main
kuulis	doc_491521501861_item	2522755	et	4	main
helilisena	doc_491521501861_item	2522761	et	4	main
hea	doc_491521501861_item	2522762	et	4	main
ja	doc_491521501861_item	2522763	et	3	main
uhke	doc_491521501861_item	2522764	et	4	main
restoran	doc_491521501861_item	2522765	et	3	main
mis	doc_491521501861_item	2522772	et	4	main
ilmselt	doc_491521501861_item	2522773	et	4	main
mõjutas	doc_491521501861_item	2522774	et	3	main
eesti	doc_491521501861_item	2522779	et	4	main
naabruses	doc_491521501861_item	2522785	et	3	main
eesvokaaliks	doc_491521501861_item	2522790	et	4	main
hoolimatusega	doc_491521501861_item	2522824	et	4	main
menüü	doc_491521501861_item	2522826	et	4	main
asjatuntlikult	doc_491521501861_item	2522836	et	4	main
peaks	doc_491521501861_item	2522837	et	4	main
olema	doc_491521501861_item	2522838	et	4	main
asjatundlikud	doc_491521501861_item	2522839	et	3	main
konsonandi	doc_491521501861_item	2522846	et	3	main
sellest	doc_491521501861_item	2522849	et	4	main
tingitud	doc_491521501861_item	2522858	et	4	main
ka	doc_491521501861_item	2522859	et	3	main
lihtsalt	doc_491521501861_item	2522884	et	4	main
viga	doc_491521501861_item	2522886	et	4	main
d	doc_491521501861_item	2522893	et	4	main
helitu	doc_491521501861_item	2522896	et	4	main
olema	doc_491521501861_item	2522906	et	4	main
see	doc_491521501861_item	2522908	et	3	main
mis	doc_491521501861_item	2522909	et	4	main
eestlase	doc_491521501861_item	2522910	et	3	main
valte	doc_491521501861_item	2522918	et	4	main
hääldatakse	doc_491521501861_item	2522922	et	3	main
kirjapildis	doc_491521501861_item	2522926	et	3	main
peegeldu	doc_491521501861_item	2522930	et	4	main
on	doc_491521501861_item	2522931	et	4	main
selle	doc_491521501861_item	2522937	et	4	main
vea	doc_491521501861_item	2522938	et	4	main
et	doc_491521501861_item	2522944	et	3	main
on	doc_491521501861_item	2522946	et	4	main
ehk	doc_491521501861_item	2522950	et	3	main
interferentsiga	doc_491521501861_item	2522952	et	3	main
mire	doc_491521501861_item	2522961	et	4	main
lihtlausega	doc_491521501861_item	2522970	et	3	main
vahel	doc_491521501861_item	2522972	et	4	main
peaks	doc_491521501861_item	2522973	et	4	main
seisma	doc_491521501861_item	2522974	et	3	main
koma	doc_491521501861_item	2522975	et	4	main
restoranis	doc_491521501861_item	2522976	et	3	main
teenindamine	doc_491521501861_item	2522979	et	4	main
seal	doc_491521501861_item	2522980	et	4	main
on	doc_491521501861_item	2522981	et	4	main
teadnud	doc_491521501861_item	2523023	et	4	main
õige	doc_491521501861_item	2523029	et	4	main
arvus	doc_491521501861_item	2523046	et	3	main
ja	doc_491521501861_item	2523047	et	3	main
ilmselt	doc_491521501861_item	2523053	et	4	main
peamiselt	doc_491521501861_item	2523061	et	4	main
vale	doc_491521501861_item	2523068	et	4	main
tahate	doc_491521501861_item	2523072	et	3	main
nagu	doc_491521501861_item	2523111	et	3	main
õige	doc_491521501861_item	2523120	et	4	main
leidub	doc_491521501861_item	2523124	et	3	main
seletus	doc_491521501861_item	2523126	et	4	main
on	doc_491521501861_item	2523127	et	4	main
punktis	doc_491521501861_item	2523129	et	4	main
lauta	doc_491521501861_item	2523133	et	4	main
eestlane	doc_491521501861_item	2523135	et	3	main
see	doc_491521501861_item	2522737	et	3	main
on	doc_491521501861_item	2522738	et	4	main
ka	doc_491521501861_item	2522751	et	3	main
vahel	doc_491521501861_item	2522760	et	4	main
sidesõna	doc_491521501861_item	2522770	et	4	main
mis	doc_491521501861_item	2522777	et	4	main
kõrge	doc_491521501861_item	2522782	et	4	main
tagavokaal	doc_491521501861_item	2522783	et	3	main
kuid	doc_491521501861_item	2522784	et	4	main
kõrgeks	doc_491521501861_item	2522789	et	4	main
tegemist	doc_491521501861_item	2522793	et	4	main
jällegi	doc_491521501861_item	2522795	et	4	main
soome	doc_491521501861_item	2522796	et	3	main
keele	doc_491521501861_item	2522797	et	4	main
mõjuga	doc_491521501861_item	2522798	et	3	main
kus	doc_491521501861_item	2522799	et	3	main
on	doc_491521501861_item	2522800	et	4	main
väga	doc_491521501861_item	2522801	et	3	main
levinud	doc_491521501861_item	2522802	et	4	main
vokaalharmoonia	doc_491521501861_item	2522803	et	4	main
nähtus	doc_491521501861_item	2522804	et	4	main
korduvalt	doc_491521501861_item	2522805	et	4	main
esinev	doc_491521501861_item	2522806	et	4	main
viga	doc_491521501861_item	2522807	et	4	main
kõige	doc_491521501861_item	2522808	et	4	main
parim	doc_491521501861_item	2522809	et	4	main
restoranin	doc_491521501861_item	2522810	et	4	main
nimi	doc_491521501861_item	2522811	et	3	main
see	doc_491521501861_item	2522812	et	3	main
restoranin	doc_491521501861_item	2522813	et	4	main
on	doc_491521501861_item	2522814	et	4	main
on	doc_491521501861_item	2522815	et	4	main
ilmselt	doc_491521501861_item	2522816	et	4	main
ka	doc_491521501861_item	2522817	et	3	main
põhjendatav	doc_491521501861_item	2522818	et	4	main
soome	doc_491521501861_item	2522819	et	3	main
keele	doc_491521501861_item	2522820	et	4	main
õpilase	doc_491521501861_item	2522823	et	3	main
peaks	doc_491521501861_item	2522827	et	4	main
mis	doc_491521501861_item	2522843	et	4	main
seisab	doc_491521501861_item	2522844	et	3	main
helituna	doc_491521501861_item	2522848	et	4	main
ka	doc_491521501861_item	2522850	et	3	main
vale	doc_491521501861_item	2522851	et	4	main
kirjutusviis	doc_491521501861_item	2522852	et	3	main
vale	doc_491521501861_item	2522860	et	4	main
välte	doc_491521501861_item	2522861	et	3	main
on	doc_491521501861_item	2522883	et	4	main
ortograafiline	doc_491521501861_item	2522885	et	4	main
kui	doc_491521501861_item	2522887	et	3	main
heliline	doc_491521501861_item	2522892	et	4	main
on	doc_491521501861_item	2522894	et	4	main
asendatud	doc_491521501861_item	2522895	et	4	main
tellima	doc_491521501861_item	2522900	et	3	main
see	doc_491521501861_item	2522901	et	3	main
mittu	doc_491521501861_item	2522902	et	4	main
nädalad	doc_491521501861_item	2522903	et	3	main
ja	doc_491521501861_item	2522758	et	3	main
uhke	doc_491521501861_item	2522767	et	4	main
seisab	doc_491521501861_item	2522768	et	3	main
keeles	doc_491521501861_item	2522780	et	4	main
sidesõnaga	doc_491521501861_item	2522786	et	3	main
mõjuga	doc_491521501861_item	2522821	et	3	main
olema	doc_491521501861_item	2522828	et	4	main
dd	doc_491521501861_item	2522842	et	4	main
vahel	doc_491521501861_item	2522847	et	4	main
on	doc_491521501861_item	2522857	et	4	main
leitub	doc_491521501861_item	2522864	et	4	main
sealt	doc_491521501861_item	2522891	et	4	main
peaks	doc_491521501861_item	2522905	et	4	main
on	doc_491521501861_item	2522916	et	4	main
olema	doc_491521501861_item	2522781	et	4	main
ja	doc_491521501861_item	2522787	et	3	main
oletan	doc_491521501861_item	2522791	et	3	main
koku	doc_491521501861_item	2522825	et	4	main
menüü	doc_491521501861_item	2522830	et	4	main
õpilane	doc_491521501861_item	2522832	et	3	main
gd	doc_491521501861_item	2522834	et	4	main
helituna	doc_491521501861_item	2522835	et	4	main
õpilane	doc_491521501861_item	2522840	et	3	main
kuulis	doc_491521501861_item	2522841	et	4	main
viga	doc_491521501861_item	2522856	et	4	main
menüült	doc_491521501861_item	2522863	et	3	main
tga	doc_491521501861_item	2522897	et	4	main
mitu	doc_491521501861_item	2522915	et	4	main
sõna	doc_491521501861_item	2522919	et	4	main
kerge	doc_491521501861_item	2522923	et	4	main
võõras	doc_491521501861_item	2522934	et	4	main
olen	doc_491521501861_item	2522940	et	3	main
mõjuga	doc_491521501861_item	2522949	et	3	main
esineb	doc_491521501861_item	2522953	et	3	main
punktuatsioonivigu	doc_491521501861_item	2522955	et	4	main
on	doc_491521501861_item	2522968	et	4	main
mille	doc_491521501861_item	2522971	et	3	main
hea	doc_491521501861_item	2522978	et	4	main
lause	doc_491521501861_item	2522987	et	4	main
seda	doc_491521501861_item	2523021	et	3	main
ja	doc_491521501861_item	2523024	et	3	main
kääne	doc_491521501861_item	2523030	et	3	main
näha	doc_491521501861_item	2523034	et	3	main
et	doc_491521501861_item	2523035	et	3	main
on	doc_491521501861_item	2523037	et	4	main
üh	doc_491521501861_item	2523041	et	4	main
nimisõnaga	doc_491521501861_item	2523042	et	3	main
on	doc_491521501861_item	2523049	et	4	main
peaasjalikult	doc_491521501861_item	2523050	et	4	main
italialaasia	doc_491521501861_item	2523051	et	4	main
itaalia	doc_491521501861_item	2523062	et	4	main
sõnamoodustusviis	doc_491521501861_item	2523069	et	4	main
lauta	doc_491521501861_item	2523073	et	4	main
teie	doc_491521501861_item	2523075	et	4	main
mida	doc_491521501861_item	2523107	et	4	main
seda	doc_491521501861_item	2523108	et	3	main
mitte	doc_491521501861_item	2523109	et	3	main
oleks	doc_491521501861_item	2523121	et	3	main
menüüst	doc_491521501861_item	2523123	et	3	main
vea	doc_491521501861_item	2523125	et	4	main
2	doc_491521501861_item	2523128	et	2	main
tahate	doc_491521501861_item	2523132	et	3	main
ütleks	doc_491521501861_item	2523136	et	3	main
seal	doc_491521501861_item	2523138	et	4	main
asja	doc_491521501861_item	2523147	et	4	main
väljendab	doc_491521501861_item	2523154	et	3	main
pronoomenivead	doc_491521501861_item	2523158	et	4	main
asesõnast	doc_491521501861_item	2523175	et	4	main
kasutamist	doc_491521501861_item	2523184	et	4	main
lauses	doc_491521501861_item	2523188	et	3	main
voi	doc_491521501861_item	2522822	et	4	main
kogu	doc_491521501861_item	2522829	et	4	main
ilmselt	doc_491521501861_item	2522831	et	4	main
kuulis	doc_491521501861_item	2522833	et	4	main
kahe	doc_491521501861_item	2522845	et	3	main
kuid	doc_491521501861_item	2522853	et	4	main
võimalik	doc_491521501861_item	2522854	et	3	main
et	doc_491521501861_item	2522855	et	3	main
kasutusest	doc_491521501861_item	2522862	et	4	main
õige	doc_491521501861_item	2522865	et	4	main
oleks	doc_491521501861_item	2522866	et	3	main
menüüst	doc_491521501861_item	2522867	et	3	main
jällegi	doc_491521501861_item	2522869	et	4	main
leiab	doc_491521501861_item	2522868	et	3	main
on	doc_491521501861_item	2522870	et	4	main
tegemist	doc_491521501861_item	2522871	et	4	main
helilise	doc_491521501861_item	2522872	et	4	main
konsonandiga	doc_491521501861_item	2522873	et	3	main
mida	doc_491521501861_item	2522874	et	4	main
ilmselt	doc_491521501861_item	2522875	et	4	main
kuuldi	doc_491521501861_item	2522876	et	4	main
helituna	doc_491521501861_item	2522877	et	4	main
kuid	doc_491521501861_item	2522878	et	4	main
on	doc_491521501861_item	2522879	et	4	main
võimalik	doc_491521501861_item	2522880	et	3	main
et	doc_491521501861_item	2522881	et	3	main
see	doc_491521501861_item	2522882	et	3	main
te	doc_491521501861_item	2522888	et	4	main
tahate	doc_491521501861_item	2522889	et	3	main
lauta	doc_491521501861_item	2522890	et	4	main
teie	doc_491521501861_item	2522898	et	4	main
peate	doc_491521501861_item	2522899	et	4	main
teise	doc_491521501861_item	2522917	et	4	main
kuid	doc_491521501861_item	2522925	et	4	main
kuidagi	doc_491521501861_item	2522928	et	3	main
italialaasia	doc_491521501861_item	2522935	et	4	main
veineja	doc_491521501861_item	2522936	et	4	main
täiesti	doc_491521501861_item	2522941	et	3	main
tegu	doc_491521501861_item	2522945	et	4	main
soome	doc_491521501861_item	2522947	et	3	main
emakeele	doc_491521501861_item	2522951	et	4	main
ka	doc_491521501861_item	2522954	et	3	main
näiteks	doc_491521501861_item	2522956	et	4	main
see	doc_491521501861_item	2522957	et	3	main
restoranin	doc_491521501861_item	2522958	et	4	main
koku	doc_491521501861_item	2522962	et	4	main
on	doc_491521501861_item	2522964	et	4	main
kahe	doc_491521501861_item	2522969	et	3	main
koku	doc_491521501861_item	2522982	et	4	main
personal	doc_491521501861_item	2522983	et	3	main
korgklassist	doc_491521501861_item	2522984	et	4	main
ka	doc_491521501861_item	2522985	et	3	main
see	doc_491521501861_item	2522986	et	3	main
ette	doc_491521501861_item	2522904	et	4	main
mitu	doc_491521501861_item	2522907	et	4	main
jaoks	doc_491521501861_item	2522911	et	4	main
on	doc_491521501861_item	2522912	et	4	main
loomulk	doc_491521501861_item	2522913	et	3	main
et	doc_491521501861_item	2522914	et	3	main
seega	doc_491521501861_item	2522920	et	4	main
td	doc_491521501861_item	2522921	et	4	main
rõhuga	doc_491521501861_item	2522924	et	3	main
puhul	doc_491521501861_item	2522939	et	4	main
nõutu	doc_491521501861_item	2522942	et	4	main
on	doc_491521501861_item	2522959	et	4	main
tegemist	doc_491521501861_item	2522967	et	4	main
on	doc_491521501861_item	2522977	et	4	main
vajab	doc_491521501861_item	2522988	et	3	main
ei	doc_491521501861_item	2523022	et	4	main
omadussõna	doc_491521501861_item	2523025	et	4	main
itaaliapäraseid	doc_491521501861_item	2523026	et	4	main
samas	doc_491521501861_item	2523032	et	4	main
ei	doc_491521501861_item	2523043	et	4	main
veineja	doc_491521501861_item	2523052	et	4	main
lausega	doc_491521501861_item	2523055	et	3	main
mõeldud	doc_491521501861_item	2523057	et	4	main
veinid	doc_491521501861_item	2523063	et	3	main
veinkelder	doc_491521501861_item	2523064	et	4	main
õige	doc_491521501861_item	2523065	et	4	main
vead	doc_491521501861_item	2523117	et	4	main
kui	doc_491521501861_item	2523130	et	3	main
siin	doc_491521501861_item	2523149	et	4	main
mida	doc_491521501861_item	2523153	et	4	main
4	doc_491521501861_item	2523157	et	2	main
sealt	doc_491521501861_item	2523163	et	4	main
püüdis	doc_491521501861_item	2523180	et	3	main
esimeses	doc_491521501861_item	2523187	et	3	main
tüüpilised	doc_491521501861_item	2523222	et	3	main
itaaliapäraseid	doc_491521501861_item	2523225	et	4	main
osastavas	doc_491521501861_item	2523226	et	4	main
6	doc_491521501861_item	2523227	et	2	main
restoranin	doc_491521501861_item	2523233	et	4	main
nimi	doc_491521501861_item	2523234	et	3	main
kõige	doc_491521501861_item	2523239	et	4	main
sellele	doc_491521501861_item	2523248	et	4	main
sõna	doc_491521501861_item	2523250	et	4	main
ütleb	doc_491521501861_item	2523252	et	3	main
ära	doc_491521501861_item	2523255	et	4	main
verbivormide	doc_491521501861_item	2523257	et	4	main
menüü	doc_491521501861_item	2523261	et	4	main
on	doc_491521501861_item	2523269	et	4	main
õpilane	doc_491521501861_item	2523273	et	3	main
verbi	doc_491521501861_item	2523276	et	4	main
sõnaga	doc_491521501861_item	2523289	et	3	main
kasutamine	doc_491521501861_item	2523293	et	4	main
rohkem	doc_491521501861_item	2523295	et	4	main
levinud	doc_491521501861_item	2523296	et	4	main
plaanima	doc_491521501861_item	2523297	et	3	main
planeerima	doc_491521501861_item	2523298	et	3	main
nagu	doc_491521501861_item	2523299	et	3	main
ka	doc_491521501861_item	2523300	et	3	main
restoranin	doc_491521501861_item	2523308	et	4	main
see	doc_491521501861_item	2522927	et	3	main
ei	doc_491521501861_item	2522929	et	4	main
välismaalase	doc_491521501861_item	2522932	et	3	main
jaoks	doc_491521501861_item	2522933	et	4	main
oletan	doc_491521501861_item	2522943	et	3	main
keele	doc_491521501861_item	2522948	et	4	main
itaalia	doc_491521501861_item	2522960	et	4	main
menüü	doc_491521501861_item	2522963	et	4	main
plaanitud	doc_491521501861_item	2522965	et	4	main
asjatuntlikult	doc_491521501861_item	2522966	et	4	main
koma	doc_491521501861_item	2522989	et	4	main
2	doc_491521501861_item	2522990	et	2	main
objektivead	doc_491521501861_item	2522991	et	4	main
vorm	doc_491521501861_item	2522992	et	3	main
ja	doc_491521501861_item	2522993	et	3	main
käändevalik	doc_491521501861_item	2522994	et	4	main
menüült	doc_491521501861_item	2522995	et	3	main
leitub	doc_491521501861_item	2522996	et	4	main
tüüpilised	doc_491521501861_item	2522997	et	3	main
itaaliapäraseid	doc_491521501861_item	2522998	et	4	main
toitu	doc_491521501861_item	2522999	et	4	main
ilmselt	doc_491521501861_item	2523000	et	4	main
selle	doc_491521501861_item	2523001	et	4	main
lausega	doc_491521501861_item	2523002	et	3	main
on	doc_491521501861_item	2523003	et	4	main
mõeldud	doc_491521501861_item	2523004	et	4	main
leidub	doc_491521501861_item	2523006	et	3	main
tüüpilisi	doc_491521501861_item	2523007	et	3	main
etmenüüst	doc_491521501861_item	2523005	et	4	main
itaaliapäraseid	doc_491521501861_item	2523008	et	4	main
toite	doc_491521501861_item	2523009	et	4	main
tegemist	doc_491521501861_item	2523010	et	4	main
on	doc_491521501861_item	2523011	et	4	main
partitiivverbiga	doc_491521501861_item	2523012	et	4	main
mis	doc_491521501861_item	2523013	et	4	main
nõuab	doc_491521501861_item	2523014	et	3	main
sihitist	doc_491521501861_item	2523015	et	3	main
osastavas	doc_491521501861_item	2523016	et	4	main
käändes	doc_491521501861_item	2523017	et	3	main
kuid	doc_491521501861_item	2523018	et	4	main
ilmselt	doc_491521501861_item	2523019	et	4	main
õpilane	doc_491521501861_item	2523020	et	3	main
sai	doc_491521501861_item	2523027	et	4	main
endale	doc_491521501861_item	2523028	et	4	main
omadussõnad	doc_491521501861_item	2523036	et	3	main
erinevates	doc_491521501861_item	2523038	et	4	main
käänetes	doc_491521501861_item	2523039	et	3	main
ja	doc_491521501861_item	2523040	et	3	main
ega	doc_491521501861_item	2523045	et	3	main
kogemata	doc_491521501861_item	2523031	et	4	main
on	doc_491521501861_item	2523033	et	4	main
käändes	doc_491521501861_item	2523044	et	3	main
seal	doc_491521501861_item	2523048	et	4	main
selle	doc_491521501861_item	2523054	et	4	main
on	doc_491521501861_item	2523056	et	4	main
et	doc_491521501861_item	2523058	et	3	main
seal	doc_491521501861_item	2523059	et	4	main
kui	doc_491521501861_item	2523070	et	3	main
sealt	doc_491521501861_item	2523074	et	4	main
peate	doc_491521501861_item	2523076	et	4	main
tellima	doc_491521501861_item	2523077	et	3	main
see	doc_491521501861_item	2523078	et	3	main
mittu	doc_491521501861_item	2523079	et	4	main
nädalad	doc_491521501861_item	2523080	et	3	main
ette	doc_491521501861_item	2523081	et	4	main
eestlane	doc_491521501861_item	2523082	et	3	main
oleks	doc_491521501861_item	2523083	et	3	main
öelnud	doc_491521501861_item	2523084	et	4	main
kui	doc_491521501861_item	2523085	et	3	main
te	doc_491521501861_item	2523086	et	4	main
tahate	doc_491521501861_item	2523087	et	3	main
tellida	doc_491521501861_item	2523088	et	3	main
lauda	doc_491521501861_item	2523089	et	4	main
siis	doc_491521501861_item	2523090	et	3	main
teatage	doc_491521501861_item	2523091	et	3	main
sellest	doc_491521501861_item	2523092	et	4	main
ette	doc_491521501861_item	2523093	et	4	main
või	doc_491521501861_item	2523094	et	4	main
siis	doc_491521501861_item	2523095	et	3	main
reserveerige	doc_491521501861_item	2523096	et	3	main
see	doc_491521501861_item	2523097	et	3	main
eelnevalt	doc_491521501861_item	2523098	et	4	main
ette	doc_491521501861_item	2523099	et	4	main
esiteks	doc_491521501861_item	2523100	et	3	main
sealt	doc_491521501861_item	2523101	et	4	main
eestlane	doc_491521501861_item	2523102	et	3	main
on	doc_491521501861_item	2523060	et	4	main
on	doc_491521501861_item	2523066	et	4	main
veinikelder	doc_491521501861_item	2523067	et	3	main
te	doc_491521501861_item	2523071	et	4	main
ütleks	doc_491521501861_item	2523103	et	3	main
pigem	doc_491521501861_item	2523104	et	3	main
seal	doc_491521501861_item	2523105	et	4	main
tellima	doc_491521501861_item	2523106	et	3	main
see	doc_491521501861_item	2523110	et	3	main
on	doc_491521501861_item	2523112	et	4	main
õpilane	doc_491521501861_item	2523113	et	3	main
kirjutanud	doc_491521501861_item	2523114	et	4	main
3	doc_491521501861_item	2523115	et	2	main
kohakäänete	doc_491521501861_item	2523116	et	3	main
menüült	doc_491521501861_item	2523118	et	3	main
leitub	doc_491521501861_item	2523119	et	4	main
kirjutada	doc_491521501861_item	2523122	et	3	main
alaltütlev	doc_491521501861_item	2523140	et	4	main
kääne	doc_491521501861_item	2523141	et	3	main
väljendab	doc_491521501861_item	2523142	et	3	main
kas	doc_491521501861_item	2523143	et	3	main
lahtekohta	doc_491521501861_item	2523144	et	4	main
aga	doc_491521501861_item	2523150	et	3	main
alalütlev	doc_491521501861_item	2523155	et	3	main
kääne	doc_491521501861_item	2523156	et	3	main
kui	doc_491521501861_item	2523159	et	3	main
tellima	doc_491521501861_item	2523166	et	3	main
see	doc_491521501861_item	2523167	et	3	main
kompenseerida	doc_491521501861_item	2523181	et	3	main
sellega	doc_491521501861_item	2523185	et	3	main
valed	doc_491521501861_item	2523221	et	3	main
võrdlusastmed	doc_491521501861_item	2523229	et	3	main
tallinnan	doc_491521501861_item	2523230	et	4	main
kõige	doc_491521501861_item	2523231	et	4	main
olema	doc_491521501861_item	2523238	et	4	main
korda	doc_491521501861_item	2523245	et	4	main
ülivorret	doc_491521501861_item	2523246	et	4	main
parim	doc_491521501861_item	2523251	et	4	main
õigem	doc_491521501861_item	2523264	et	4	main
oleks	doc_491521501861_item	2523265	et	3	main
ilmselt	doc_491521501861_item	2523271	et	4	main
tegemist	doc_491521501861_item	2523283	et	4	main
kus	doc_491521501861_item	2523290	et	3	main
on	doc_491521501861_item	2523294	et	4	main
8	doc_491521501861_item	2523304	et	2	main
on	doc_491521501861_item	2523309	et	4	main
koku	doc_491521501861_item	2523312	et	4	main
on	doc_491521501861_item	2523314	et	4	main
analüüsida	doc_491521501861_item	2523320	et	3	main
lauset	doc_491521501861_item	2523322	et	3	main
öelda	doc_491521501861_item	2523336	et	4	main
et	doc_491521501861_item	2523337	et	3	main
tegemist	doc_491521501861_item	2523338	et	4	main
osatud	doc_491521501861_item	2523343	et	4	main
vahendite	doc_491521501861_item	2523347	et	3	main
liitmise	doc_491521501861_item	2523352	et	4	main
toitu	doc_491521501861_item	2523364	et	4	main
kahtlemata	doc_491521501861_item	2523365	et	4	main
asemel	doc_491521501861_item	2523372	et	4	main
roogasid	doc_491521501861_item	2523373	et	3	main
on	doc_491521501861_item	2523380	et	4	main
restoranis	doc_491521501861_item	2523390	et	3	main
välja	doc_491521501861_item	2523400	et	4	main
lause	doc_491521501861_item	2523404	et	4	main
rohkem	doc_491521501861_item	2523405	et	4	main
kui	doc_491521501861_item	2523406	et	3	main
on	doc_491521501861_item	2523413	et	4	main
aadlisoost	doc_491521501861_item	2523414	et	4	main
kelneritega	doc_491521501861_item	2523415	et	3	main
lauta	doc_491521501861_item	2523435	et	4	main
itaalialaasia	doc_491521501861_item	2523456	et	4	main
peaasjalikult	doc_491521501861_item	2523458	et	4	main
asemel	doc_491521501861_item	2523463	et	4	main
peaks	doc_491521501861_item	2523464	et	4	main
subjektiivne	doc_491521501861_item	2523492	et	3	main
ta	doc_491521501861_item	2523505	et	4	main
rikas	doc_491521501861_item	2523511	et	4	main
keeles	doc_491521501861_item	2523512	et	4	main
korraldatava	doc_491521501862_item	2523548	et	4	main
jargi	doc_491521501862_item	2523561	et	4	main
saab	doc_491521501862_item	2523562	et	3	main
teha	doc_491521501862_item	2523563	et	3	main
jarelduse	doc_491521501862_item	2523564	et	4	main
et	doc_491521501862_item	2523565	et	3	main
kujutab	doc_491521501862_item	2523571	et	3	main
pildi	doc_491521501862_item	2523573	et	4	main
koos	doc_491521501862_item	2523575	et	4	main
omapoolsete	doc_491521501862_item	2523576	et	4	main
kommentaaridega	doc_491521501862_item	2523577	et	3	main
originaaltekst	doc_491521501862_item	2523578	et	3	main
nimi	doc_491521501862_item	2523583	et	3	main
ja	doc_491521501862_item	2523586	et	3	main
amadeus	doc_491521501862_item	2523591	et	4	main
hea	doc_491521501862_item	2523594	et	4	main
see	doc_491521501862_item	2523598	et	3	main
te	doc_491521501861_item	2523131	et	4	main
sealt	doc_491521501861_item	2523134	et	4	main
pigem	doc_491521501861_item	2523137	et	3	main
sest	doc_491521501861_item	2523139	et	4	main
teate	doc_491521501861_item	2523145	et	4	main
allikat	doc_491521501861_item	2523148	et	3	main
asukohta	doc_491521501861_item	2523152	et	4	main
teie	doc_491521501861_item	2523164	et	4	main
peate	doc_491521501861_item	2523165	et	4	main
mittu	doc_491521501861_item	2523168	et	4	main
nädalad	doc_491521501861_item	2523169	et	3	main
ette	doc_491521501861_item	2523170	et	4	main
oleks	doc_491521501861_item	2523171	et	3	main
parem	doc_491521501861_item	2523172	et	4	main
loobuda	doc_491521501861_item	2523173	et	3	main
kahekordsest	doc_491521501861_item	2523174	et	3	main
et	doc_491521501861_item	2523186	et	3	main
kasutas	doc_491521501861_item	2523189	et	3	main
selle	doc_491521501861_item	2523190	et	4	main
asesõna	doc_491521501861_item	2523191	et	4	main
lühikest	doc_491521501861_item	2523192	et	4	main
vormi	doc_491521501861_item	2523193	et	4	main
5	doc_491521501861_item	2523194	et	2	main
ühildumisvead	doc_491521501861_item	2523195	et	4	main
menüült	doc_491521501861_item	2523196	et	3	main
leitub	doc_491521501861_item	2523197	et	4	main
tüüpilised	doc_491521501861_item	2523198	et	3	main
itaaliapäraseid	doc_491521501861_item	2523199	et	4	main
toitu	doc_491521501861_item	2523200	et	4	main
nimisõna	doc_491521501861_item	2523201	et	4	main
ei	doc_491521501861_item	2523202	et	4	main
ühtu	doc_491521501861_item	2523203	et	4	main
omadussõnadega	doc_491521501861_item	2523204	et	3	main
peaks	doc_491521501861_item	2523205	et	4	main
olema	doc_491521501861_item	2523206	et	4	main
leidub	doc_491521501861_item	2523207	et	3	main
tüüpilisi	doc_491521501861_item	2523208	et	3	main
itaaliapäraseid	doc_491521501861_item	2523209	et	4	main
toite	doc_491521501861_item	2523210	et	4	main
toit	doc_491521501861_item	2523211	et	3	main
on	doc_491521501861_item	2523212	et	4	main
ainsuses	doc_491521501861_item	2523213	et	4	main
kuid	doc_491521501861_item	2523214	et	4	main
omadussõnad	doc_491521501861_item	2523215	et	3	main
on	doc_491521501861_item	2523216	et	4	main
mitmuses	doc_491521501861_item	2523217	et	3	main
käänded	doc_491521501861_item	2523218	et	3	main
on	doc_491521501861_item	2523219	et	4	main
ka	doc_491521501861_item	2523220	et	3	main
või	doc_491521501861_item	2523146	et	4	main
mõeldakse	doc_491521501861_item	2523151	et	3	main
te	doc_491521501861_item	2523160	et	4	main
tahate	doc_491521501861_item	2523161	et	3	main
lauta	doc_491521501861_item	2523162	et	4	main
teie	doc_491521501861_item	2523176	et	4	main
paistab	doc_491521501861_item	2523177	et	3	main
et	doc_491521501861_item	2523178	et	3	main
õpilane	doc_491521501861_item	2523179	et	3	main
asesõna	doc_491521501861_item	2523182	et	4	main
topelt	doc_491521501861_item	2523183	et	4	main
nimetavas	doc_491521501861_item	2523224	et	4	main
parim	doc_491521501861_item	2523232	et	4	main
peaks	doc_491521501861_item	2523237	et	4	main
kasutas	doc_491521501861_item	2523243	et	3	main
niigi	doc_491521501861_item	2523253	et	4	main
7	doc_491521501861_item	2523256	et	2	main
valiku	doc_491521501861_item	2523258	et	3	main
öelda	doc_491521501861_item	2523266	et	4	main
tuletada	doc_491521501861_item	2523275	et	3	main
on	doc_491521501861_item	2523284	et	4	main
eesti	doc_491521501861_item	2523285	et	4	main
keele	doc_491521501861_item	2523286	et	4	main
pikema	doc_491521501861_item	2523291	et	4	main
puhul	doc_491521501861_item	2523303	et	4	main
sõnatasandi	doc_491521501861_item	2523305	et	3	main
menü	doc_491521501861_item	2523313	et	4	main
seda	doc_491521501861_item	2523321	et	3	main
selle	doc_491521501861_item	2523333	et	4	main
lausega	doc_491521501861_item	2523334	et	3	main
taheti	doc_491521501861_item	2523335	et	3	main
kuid	doc_491521501861_item	2523341	et	4	main
väljendada	doc_491521501861_item	2523345	et	3	main
ja	doc_491521501861_item	2523354	et	3	main
kergema	doc_491521501861_item	2523357	et	4	main
oleks	doc_491521501861_item	2523367	et	3	main
kasutada	doc_491521501861_item	2523369	et	3	main
toit	doc_491521501861_item	2523371	et	3	main
mis	doc_491521501861_item	2523374	et	4	main
rohkem	doc_491521501861_item	2523375	et	4	main
vastab	doc_491521501861_item	2523376	et	3	main
kontekstile	doc_491521501861_item	2523377	et	3	main
teenindamine	doc_491521501861_item	2523393	et	4	main
korgklassist	doc_491521501861_item	2523398	et	4	main
kõlab	doc_491521501861_item	2523402	et	3	main
öelda	doc_491521501861_item	2523418	et	4	main
personal	doc_491521501861_item	2523421	et	3	main
on	doc_491521501861_item	2523424	et	4	main
vale	doc_491521501861_item	2523427	et	4	main
kääne	doc_491521501861_item	2523428	et	3	main
põhjustab	doc_491521501861_item	2523429	et	3	main
valesti	doc_491521501861_item	2523430	et	3	main
te	doc_491521501861_item	2523433	et	4	main
see	doc_491521501861_item	2523440	et	3	main
ette	doc_491521501861_item	2523443	et	4	main
parem	doc_491521501861_item	2523444	et	4	main
peaasjalikult	doc_491521501861_item	2523455	et	4	main
on	doc_491521501861_item	2523459	et	4	main
vale	doc_491521501861_item	2523460	et	4	main
olema	doc_491521501861_item	2523465	et	4	main
selle	doc_491521501861_item	2523489	et	4	main
lõpetuseks	doc_491521501861_item	2523494	et	4	main
vaatamata	doc_491521501861_item	2523498	et	4	main
vigadele	doc_491521501861_item	2523499	et	3	main
tekst	doc_491521501861_item	2523500	et	3	main
jätab	doc_491521501861_item	2523501	et	3	main
väga	doc_491521501861_item	2523502	et	3	main
hea	doc_491521501861_item	2523503	et	4	main
mulje	doc_491521501861_item	2523504	et	4	main
et	doc_491521501861_item	2523514	et	3	main
suuliselt	doc_491521501861_item	2523515	et	4	main
piisavalt	doc_491521501861_item	2523521	et	4	main
tasemel	doc_491521501861_item	2523523	et	3	main
peab	doc_491521501861_item	2523525	et	4	main
veel	doc_491521501861_item	2523526	et	4	main
grammatikat	doc_491521501861_item	2523527	et	3	main
lihvima	doc_491521501861_item	2523528	et	3	main
vigade	doc_491521501862_item	2523529	et	3	main
gibalo	doc_491521501862_item	2523532	et	4	main
tallinna	doc_491521501862_item	2523544	et	4	main
keelekursuse	doc_491521501862_item	2523549	et	3	main
omadussona	doc_491521501861_item	2523228	et	4	main
on	doc_491521501861_item	2523235	et	4	main
amadeus	doc_491521501861_item	2523236	et	4	main
kuid	doc_491521501861_item	2523241	et	4	main
õpilane	doc_491521501861_item	2523242	et	3	main
2	doc_491521501861_item	2523244	et	2	main
et	doc_491521501861_item	2523249	et	3	main
on	doc_491521501861_item	2523223	et	4	main
parem	doc_491521501861_item	2523240	et	4	main
vaatamata	doc_491521501861_item	2523247	et	4	main
kõik	doc_491521501861_item	2523254	et	4	main
koku	doc_491521501861_item	2523260	et	4	main
on	doc_491521501861_item	2523262	et	4	main
plaanitud	doc_491521501861_item	2523263	et	4	main
planeeritud	doc_491521501861_item	2523270	et	4	main
püüdis	doc_491521501861_item	2523274	et	3	main
võõrtüvelise	doc_491521501861_item	2523288	et	4	main
tüvevariandi	doc_491521501861_item	2523292	et	4	main
vead	doc_491521501861_item	2523306	et	4	main
see	doc_491521501861_item	2523307	et	3	main
plaanitud	doc_491521501861_item	2523315	et	4	main
asjatuntlikult	doc_491521501861_item	2523316	et	4	main
üsna	doc_491521501861_item	2523317	et	3	main
raske	doc_491521501861_item	2523318	et	4	main
on	doc_491521501861_item	2523319	et	4	main
mõte	doc_491521501861_item	2523325	et	3	main
minu	doc_491521501861_item	2523327	et	3	main
on	doc_491521501861_item	2523339	et	4	main
ei	doc_491521501861_item	2523342	et	4	main
sõnamoodustuse	doc_491521501861_item	2523346	et	3	main
abil	doc_491521501861_item	2523348	et	4	main
ja	doc_491521501861_item	2523350	et	3	main
nimisõna	doc_491521501861_item	2523351	et	4	main
vastupanu	doc_491521501861_item	2523358	et	4	main
parem	doc_491521501861_item	2523368	et	4	main
sõna	doc_491521501861_item	2523370	et	4	main
itaaliapäraseid	doc_491521501861_item	2523388	et	4	main
on	doc_491521501861_item	2523391	et	4	main
seal	doc_491521501861_item	2523394	et	4	main
koku	doc_491521501861_item	2523396	et	4	main
imelikult	doc_491521501861_item	2523407	et	4	main
klassi	doc_491521501861_item	2523420	et	4	main
vead	doc_491521501861_item	2523259	et	4	main
kogu	doc_491521501861_item	2523267	et	4	main
menü	doc_491521501861_item	2523268	et	4	main
siin	doc_491521501861_item	2523272	et	4	main
nimisõnast	doc_491521501861_item	2523277	et	4	main
ja	doc_491521501861_item	2523278	et	3	main
ei	doc_491521501861_item	2523279	et	4	main
pannud	doc_491521501861_item	2523280	et	4	main
tähele	doc_491521501861_item	2523281	et	3	main
et	doc_491521501861_item	2523282	et	3	main
jaoks	doc_491521501861_item	2523287	et	4	main
tsementima	doc_491521501861_item	2523301	et	4	main
tsementeerima	doc_491521501861_item	2523302	et	3	main
itaalia	doc_491521501861_item	2523310	et	4	main
mire	doc_491521501861_item	2523311	et	4	main
kuna	doc_491521501861_item	2523323	et	3	main
seda	doc_491521501861_item	2523344	et	3	main
teel	doc_491521501861_item	2523353	et	4	main
siis	doc_491521501861_item	2523355	et	3	main
teed	doc_491521501861_item	2523359	et	4	main
leitub	doc_491521501861_item	2523361	et	4	main
tüüpilised	doc_491521501861_item	2523362	et	3	main
siin	doc_491521501861_item	2523366	et	4	main
sõna	doc_491521501861_item	2523378	et	4	main
liiga	doc_491521501861_item	2523381	et	4	main
sest	doc_491521501861_item	2523383	et	4	main
siin	doc_491521501861_item	2523384	et	4	main
mõeldakse	doc_491521501861_item	2523385	et	3	main
ikka	doc_491521501861_item	2523386	et	4	main
konkreetseid	doc_491521501861_item	2523387	et	3	main
hea	doc_491521501861_item	2523392	et	4	main
on	doc_491521501861_item	2523395	et	4	main
personal	doc_491521501861_item	2523397	et	3	main
lõigatuna	doc_491521501861_item	2523401	et	4	main
sest	doc_491521501861_item	2523408	et	4	main
võib	doc_491521501861_item	2523409	et	3	main
õigem	doc_491521501861_item	2523416	et	4	main
oleks	doc_491521501861_item	2523417	et	3	main
personal	doc_491521501861_item	2523423	et	3	main
kui	doc_491521501861_item	2523432	et	3	main
tahate	doc_491521501861_item	2523434	et	3	main
teie	doc_491521501861_item	2523437	et	4	main
nädalad	doc_491521501861_item	2523442	et	3	main
oleks	doc_491521501861_item	2523445	et	3	main
öelda	doc_491521501861_item	2523446	et	4	main
reserveerida	doc_491521501861_item	2523447	et	3	main
või	doc_491521501861_item	2523448	et	4	main
kinni	doc_491521501861_item	2523449	et	3	main
sõna	doc_491521501861_item	2523461	et	4	main
peamiselt	doc_491521501861_item	2523466	et	4	main
autori	doc_491521501861_item	2523491	et	3	main
öelda	doc_491521501861_item	2523496	et	4	main
loogiliselt	doc_491521501861_item	2523507	et	4	main
ülesehitatud	doc_491521501861_item	2523508	et	4	main
ja	doc_491521501861_item	2523509	et	3	main
kirjutatud	doc_491521501861_item	2523510	et	4	main
suhelda	doc_491521501861_item	2523516	et	4	main
valdab	doc_491521501861_item	2523517	et	3	main
see	doc_491521501861_item	2523518	et	3	main
õpilane	doc_491521501861_item	2523519	et	3	main
analuus	doc_491521501862_item	2523530	et	4	main
vigade	doc_491521501862_item	2523534	et	3	main
opilase	doc_491521501862_item	2523536	et	4	main
too	doc_491521501862_item	2523537	et	4	main
millele	doc_491521501862_item	2523538	et	3	main
toetusin	doc_491521501862_item	2523539	et	3	main
parineb	doc_491521501862_item	2523542	et	4	main
pedagoogikaulikooli	doc_491521501862_item	2523545	et	4	main
oppejou	doc_491521501862_item	2523546	et	4	main
poolt	doc_491521501862_item	2523547	et	4	main
kelle	doc_491521501862_item	2523556	et	4	main
on	doc_491521501862_item	2523567	et	4	main
soomlasega	doc_491521501862_item	2523568	et	3	main
parim	doc_491521501862_item	2523581	et	4	main
restoranin	doc_491521501862_item	2523582	et	4	main
amadeus	doc_491521501862_item	2523585	et	4	main
see	doc_491521501862_item	2523587	et	3	main
on	doc_491521501862_item	2523593	et	4	main
on	doc_491521501862_item	2523625	et	4	main
seal	doc_491521501862_item	2523628	et	4	main
tais	doc_491521501862_item	2523639	et	3	main
sealt	doc_491521501862_item	2523644	et	4	main
selle	doc_491521501861_item	2523324	et	4	main
jai	doc_491521501861_item	2523326	et	4	main
jaoks	doc_491521501861_item	2523328	et	4	main
natuke	doc_491521501861_item	2523329	et	4	main
ähmaseks	doc_491521501861_item	2523330	et	4	main
oletan	doc_491521501861_item	2523331	et	3	main
et	doc_491521501861_item	2523332	et	3	main
kiirrestoraniga	doc_491521501861_item	2523340	et	4	main
omadussõna	doc_491521501861_item	2523349	et	4	main
mindi	doc_491521501861_item	2523356	et	3	main
menuüüt	doc_491521501861_item	2523360	et	4	main
itaaliapäraseid	doc_491521501861_item	2523363	et	4	main
toit	doc_491521501861_item	2523379	et	3	main
üldine	doc_491521501861_item	2523382	et	4	main
roogasid	doc_491521501861_item	2523389	et	3	main
kontekstist	doc_491521501861_item	2523399	et	3	main
see	doc_491521501861_item	2523403	et	3	main
arvata	doc_491521501861_item	2523410	et	4	main
et	doc_491521501861_item	2523411	et	3	main
tegemist	doc_491521501861_item	2523412	et	4	main
kõrgema	doc_491521501861_item	2523419	et	4	main
või	doc_491521501861_item	2523422	et	4	main
kõrgel	doc_491521501861_item	2523425	et	4	main
tasemel	doc_491521501861_item	2523426	et	3	main
sealt	doc_491521501861_item	2523436	et	4	main
peate	doc_491521501861_item	2523438	et	4	main
mittu	doc_491521501861_item	2523441	et	4	main
tellitakse	doc_491521501861_item	2523451	et	3	main
roogasid	doc_491521501861_item	2523452	et	3	main
mitte	doc_491521501861_item	2523453	et	3	main
veineja	doc_491521501861_item	2523457	et	4	main
töö	doc_491521501861_item	2523490	et	4	main
tahan	doc_491521501861_item	2523495	et	3	main
et	doc_491521501861_item	2523497	et	3	main
selleks	doc_491521501861_item	2523513	et	4	main
ev-51	doc_491521501862_item	2523533	et	4	main
analuus	doc_491521501862_item	2523535	et	4	main
analuusis	doc_491521501862_item	2523541	et	4	main
uhe	doc_491521501862_item	2523543	et	4	main
analuiasitava	doc_491521501862_item	2523551	et	4	main
kirjutas	doc_491521501862_item	2523553	et	3	main
inimene	doc_491521501862_item	2523555	et	3	main
tegemist	doc_491521501862_item	2523566	et	4	main
see	doc_491521501862_item	2523569	et	3	main
tallinnan	doc_491521501862_item	2523579	et	4	main
koige	doc_491521501862_item	2523580	et	4	main
siin	doc_491521501862_item	2523589	et	4	main
italialaasia	doc_491521501862_item	2523622	et	4	main
amadeus	doc_491521501862_item	2523636	et	4	main
lauta	doc_491521501862_item	2523643	et	4	main
mittu	doc_491521501862_item	2523649	et	4	main
ette	doc_491521501862_item	2523651	et	4	main
registreeritud	doc_491521501862_item	2523652	et	4	main
astmevaheldusvead	doc_491521501862_item	2523658	et	4	main
on	doc_491521501862_item	2523661	et	4	main
bildil	doc_491521501862_item	2523663	et	4	main
oletan	doc_491521501862_item	2523664	et	3	main
et	doc_491521501862_item	2523665	et	3	main
selline	doc_491521501862_item	2523666	et	4	main
voi	doc_491521501862_item	2523671	et	4	main
algab	doc_491521501862_item	2523678	et	3	main
uhke	doc_491521501862_item	2523682	et	4	main
restoran	doc_491521501862_item	2523683	et	3	main
sona	doc_491521501862_item	2523684	et	4	main
mis	doc_491521501862_item	2523690	et	4	main
haaldust	doc_491521501862_item	2523694	et	4	main
eesti	doc_491521501862_item	2523697	et	4	main
nimi	doc_491521501862_item	2523722	et	3	main
restoranin	doc_491521501862_item	2523724	et	4	main
hoolimatusega	doc_491521501862_item	2523734	et	4	main
kogu	doc_491521501862_item	2523739	et	4	main
menuu	doc_491521501862_item	2523740	et	4	main
viga	doc_491521501862_item	2523741	et	4	main
emakeele	doc_491521501862_item	2523744	et	4	main
ortograafiaga	doc_491521501862_item	2523745	et	3	main
d-d	doc_491521501862_item	2523752	et	4	main
mis	doc_491521501862_item	2523753	et	4	main
seisab	doc_491521501862_item	2523754	et	3	main
kahe	doc_491521501862_item	2523755	et	3	main
konsonandi	doc_491521501862_item	2523756	et	3	main
vahel	doc_491521501862_item	2523757	et	4	main
helituna	doc_491521501862_item	2523758	et	4	main
kirjutusviis	doc_491521501862_item	2523762	et	3	main
opilase	doc_491521501862_item	2523775	et	4	main
personal	doc_491521501862_item	2523783	et	3	main
mõistmist	doc_491521501861_item	2523431	et	4	main
tellima	doc_491521501861_item	2523439	et	3	main
panna	doc_491521501861_item	2523450	et	4	main
laudasid	doc_491521501861_item	2523454	et	3	main
selle	doc_491521501861_item	2523462	et	4	main
oletan	doc_491521501861_item	2523467	et	3	main
et	doc_491521501861_item	2523468	et	3	main
ka	doc_491521501861_item	2523469	et	3	main
siin	doc_491521501861_item	2523470	et	4	main
õpilane	doc_491521501861_item	2523471	et	3	main
võis	doc_491521501861_item	2523472	et	4	main
lahtuda	doc_491521501861_item	2523473	et	3	main
mingist	doc_491521501861_item	2523474	et	4	main
ainult	doc_491521501861_item	2523475	et	4	main
talle	doc_491521501861_item	2523476	et	4	main
omasest	doc_491521501861_item	2523477	et	3	main
loogikast	doc_491521501861_item	2523478	et	4	main
ala	doc_491521501861_item	2523479	et	4	main
peamiselt	doc_491521501861_item	2523480	et	4	main
pakutakse	doc_491521501861_item	2523481	et	3	main
selles	doc_491521501861_item	2523482	et	4	main
restoranis	doc_491521501861_item	2523483	et	3	main
järgmisi	doc_491521501861_item	2523484	et	3	main
asju	doc_491521501861_item	2523485	et	3	main
kuid	doc_491521501861_item	2523486	et	4	main
see	doc_491521501861_item	2523487	et	3	main
on	doc_491521501861_item	2523488	et	4	main
arvamus	doc_491521501861_item	2523493	et	3	main
on	doc_491521501861_item	2523506	et	4	main
keelt	doc_491521501861_item	2523520	et	4	main
heal	doc_491521501861_item	2523522	et	3	main
kuid	doc_491521501861_item	2523524	et	4	main
julia	doc_491521501862_item	2523531	et	4	main
oma	doc_491521501862_item	2523540	et	4	main
materjalidest	doc_491521501862_item	2523550	et	3	main
teksti	doc_491521501862_item	2523552	et	4	main
ja	doc_491521501862_item	2523558	et	3	main
tehtud	doc_491521501862_item	2523559	et	4	main
vigade	doc_491521501862_item	2523560	et	3	main
tekst	doc_491521501862_item	2523570	et	3	main
on	doc_491521501862_item	2523584	et	4	main
restoran	doc_491521501862_item	2523592	et	3	main
ja	doc_491521501862_item	2523595	et	3	main
uhke	doc_491521501862_item	2523596	et	4	main
restoran	doc_491521501862_item	2523597	et	3	main
restoranin	doc_491521501862_item	2523599	et	4	main
on	doc_491521501862_item	2523600	et	4	main
itaalia	doc_491521501862_item	2523601	et	4	main
kiire	doc_491521501862_item	2523602	et	4	main
koku	doc_491521501862_item	2523603	et	4	main
menuu	doc_491521501862_item	2523604	et	4	main
on	doc_491521501862_item	2523605	et	4	main
plaanitud	doc_491521501862_item	2523606	et	4	main
asjatuntlikult	doc_491521501862_item	2523607	et	4	main
menuult	doc_491521501862_item	2523608	et	4	main
leitub	doc_491521501862_item	2523609	et	4	main
tuupilised	doc_491521501862_item	2523610	et	4	main
itaaliaparaseid	doc_491521501862_item	2523611	et	3	main
toitu	doc_491521501862_item	2523612	et	4	main
restoranil	doc_491521501862_item	2523613	et	3	main
on	doc_491521501862_item	2523614	et	4	main
oma	doc_491521501862_item	2523615	et	4	main
spetsiaalne	doc_491521501862_item	2523616	et	3	main
veinkelder	doc_491521501862_item	2523617	et	4	main
ja	doc_491521501862_item	2523618	et	3	main
seal	doc_491521501862_item	2523619	et	4	main
on	doc_491521501862_item	2523620	et	4	main
peaasjalikult	doc_491521501862_item	2523621	et	4	main
hea	doc_491521501862_item	2523626	et	4	main
alati	doc_491521501862_item	2523638	et	4	main
kui	doc_491521501862_item	2523640	et	3	main
peate	doc_491521501862_item	2523646	et	4	main
tellima	doc_491521501862_item	2523647	et	3	main
nadalad	doc_491521501862_item	2523650	et	4	main
ja	doc_491521501862_item	2523659	et	3	main
haaldusviga	doc_491521501862_item	2523667	et	4	main
on	doc_491521501862_item	2523668	et	4	main
sona	doc_491521501862_item	2523676	et	4	main
hea	doc_491521501862_item	2523680	et	4	main
uhke	doc_491521501862_item	2523685	et	4	main
seisab	doc_491521501862_item	2523686	et	3	main
keeles	doc_491521501862_item	2523698	et	4	main
korge	doc_491521501862_item	2523700	et	4	main
kuid	doc_491521501862_item	2523702	et	4	main
pohjendatav	doc_491521501862_item	2523729	et	4	main
emakeele	doc_491521501862_item	2523730	et	4	main
voi	doc_491521501862_item	2523732	et	4	main
opilase	doc_491521501862_item	2523733	et	4	main
asjatuntlikult	doc_491521501862_item	2523746	et	4	main
taiskasvanud	doc_491521501862_item	2523554	et	4	main
perekonnanime	doc_491521501862_item	2523557	et	4	main
endast	doc_491521501862_item	2523572	et	4	main
kirjeldust	doc_491521501862_item	2523574	et	4	main
on	doc_491521501862_item	2523588	et	4	main
bildil	doc_491521501862_item	2523590	et	4	main
restoranis	doc_491521501862_item	2523624	et	3	main
teenindamine	doc_491521501862_item	2523627	et	4	main
on	doc_491521501862_item	2523629	et	4	main
koku	doc_491521501862_item	2523630	et	4	main
personal	doc_491521501862_item	2523631	et	3	main
on	doc_491521501862_item	2523637	et	4	main
teie	doc_491521501862_item	2523645	et	4	main
see	doc_491521501862_item	2523648	et	3	main
ja	doc_491521501862_item	2523657	et	3	main
rootsi	doc_491521501862_item	2523672	et	4	main
keele	doc_491521501862_item	2523673	et	4	main
pilt	doc_491521501862_item	2523677	et	3	main
b-ga	doc_491521501862_item	2523679	et	3	main
ja	doc_491521501862_item	2523681	et	3	main
ilmselt	doc_491521501862_item	2523691	et	4	main
peaks	doc_491521501862_item	2523696	et	4	main
see	doc_491521501862_item	2523723	et	3	main
ka	doc_491521501862_item	2523728	et	3	main
pohjendada	doc_491521501862_item	2523743	et	4	main
kuulis	doc_491521501862_item	2523751	et	4	main
sellest	doc_491521501862_item	2523759	et	4	main
menuult	doc_491521501862_item	2523763	et	4	main
oletan	doc_491521501862_item	2523765	et	3	main
oigem	doc_491521501862_item	2523767	et	4	main
oelda	doc_491521501862_item	2523769	et	4	main
leiab	doc_491521501862_item	2523771	et	3	main
koku	doc_491521501862_item	2523782	et	4	main
on	doc_491521501862_item	2523787	et	4	main
o	doc_491521501862_item	2523797	et	4	main
eriline	doc_491521501862_item	2523806	et	4	main
koht	doc_491521501862_item	2523807	et	3	main
sealt	doc_491521501862_item	2523816	et	4	main
nadalad	doc_491521501862_item	2523828	et	4	main
mis	doc_491521501862_item	2523834	et	4	main
eestlase	doc_491521501862_item	2523835	et	3	main
jaoks	doc_491521501862_item	2523836	et	4	main
seega	doc_491521501862_item	2523845	et	4	main
ei	doc_491521501862_item	2523854	et	4	main
valismaalase	doc_491521501862_item	2523857	et	4	main
vooras	doc_491521501862_item	2523859	et	4	main
tegu	doc_491521501862_item	2523870	et	4	main
mojuga	doc_491521501862_item	2523873	et	4	main
ehk	doc_491521501862_item	2523874	et	3	main
emakeele	doc_491521501862_item	2523875	et	4	main
interferents	doc_491521501862_item	2523876	et	3	main
kaandes	doc_491521501862_item	2523912	et	4	main
kuid	doc_491521501862_item	2523913	et	4	main
ja	doc_491521501862_item	2523919	et	3	main
omadussona	doc_491521501862_item	2523920	et	4	main
veineja	doc_491521501862_item	2523623	et	4	main
korgklassist	doc_491521501862_item	2523632	et	4	main
just	doc_491521501862_item	2523633	et	3	main
nendel	doc_491521501862_item	2523634	et	4	main
pohjustel	doc_491521501862_item	2523635	et	4	main
te	doc_491521501862_item	2523641	et	4	main
tahate	doc_491521501862_item	2523642	et	3	main
vead	doc_491521501862_item	2523653	et	4	main
1	doc_491521501862_item	2523654	et	2	main
haaldus-	doc_491521501862_item	2523655	et	4	main
siin	doc_491521501862_item	2523662	et	4	main
saksa	doc_491521501862_item	2523670	et	4	main
kus	doc_491521501862_item	2523675	et	3	main
peale	doc_491521501862_item	2523687	et	4	main
mojutas	doc_491521501862_item	2523692	et	4	main
olema	doc_491521501862_item	2523699	et	4	main
tagavokaal	doc_491521501862_item	2523701	et	3	main
naabruses	doc_491521501862_item	2523703	et	3	main
sidesonaga	doc_491521501862_item	2523704	et	4	main
ja	doc_491521501862_item	2523705	et	3	main
muutub	doc_491521501862_item	2523706	et	3	main
korgeks	doc_491521501862_item	2523707	et	3	main
eesvokaaliks	doc_491521501862_item	2523708	et	4	main
oletan	doc_491521501862_item	2523709	et	3	main
et	doc_491521501862_item	2523710	et	3	main
tegemist	doc_491521501862_item	2523711	et	4	main
jallegi	doc_491521501862_item	2523713	et	4	main
on	doc_491521501862_item	2523712	et	4	main
emakeele	doc_491521501862_item	2523714	et	4	main
mojuga	doc_491521501862_item	2523715	et	4	main
korduvalt	doc_491521501862_item	2523716	et	4	main
esinev	doc_491521501862_item	2523717	et	4	main
viga	doc_491521501862_item	2523718	et	4	main
koige	doc_491521501862_item	2523719	et	4	main
parim	doc_491521501862_item	2523720	et	4	main
oigekirja-	doc_491521501862_item	2523656	et	4	main
see	doc_491521501862_item	2523660	et	3	main
tingitud	doc_491521501862_item	2523669	et	4	main
mojust	doc_491521501862_item	2523674	et	4	main
sidesona	doc_491521501862_item	2523688	et	4	main
ja	doc_491521501862_item	2523689	et	3	main
u	doc_491521501862_item	2523693	et	4	main
mis	doc_491521501862_item	2523695	et	4	main
restoranin	doc_491521501862_item	2523721	et	4	main
ilmselt	doc_491521501862_item	2523727	et	4	main
mojuga	doc_491521501862_item	2523731	et	4	main
opilane	doc_491521501862_item	2523750	et	4	main
vale	doc_491521501862_item	2523761	et	4	main
leitub	doc_491521501862_item	2523764	et	4	main
oleksa	doc_491521501862_item	2523768	et	4	main
leitub	doc_491521501862_item	2523779	et	4	main
emakeele	doc_491521501862_item	2523780	et	4	main
interferents	doc_491521501862_item	2523781	et	3	main
et	doc_491521501862_item	2523785	et	3	main
vaga	doc_491521501862_item	2523792	et	4	main
keeles	doc_491521501862_item	2523805	et	4	main
tagavokaalide	doc_491521501862_item	2523810	et	3	main
lauta	doc_491521501862_item	2523815	et	4	main
heliline	doc_491521501862_item	2523817	et	4	main
asendatud	doc_491521501862_item	2523820	et	4	main
on	doc_491521501862_item	2523725	et	4	main
on	doc_491521501862_item	2523726	et	4	main
koku	doc_491521501862_item	2523735	et	4	main
menuu	doc_491521501862_item	2523736	et	4	main
peaks	doc_491521501862_item	2523737	et	4	main
olema	doc_491521501862_item	2523738	et	4	main
voib	doc_491521501862_item	2523742	et	4	main
peaks	doc_491521501862_item	2523747	et	4	main
olema	doc_491521501862_item	2523748	et	4	main
asjatundlikud	doc_491521501862_item	2523749	et	3	main
ka	doc_491521501862_item	2523760	et	3	main
et	doc_491521501862_item	2523766	et	3	main
menuust	doc_491521501862_item	2523770	et	3	main
poolt	doc_491521501862_item	2523776	et	4	main
varianti	doc_491521501862_item	2523778	et	4	main
opilane	doc_491521501862_item	2523786	et	4	main
varem	doc_491521501862_item	2523788	et	4	main
kogu	doc_491521501862_item	2523790	et	4	main
tempokalt	doc_491521501862_item	2523793	et	4	main
haaldatuna	doc_491521501862_item	2523794	et	4	main
mille	doc_491521501862_item	2523795	et	3	main
tulemusena	doc_491521501862_item	2523796	et	3	main
keskkorge	doc_491521501862_item	2523798	et	4	main
tagavokaal	doc_491521501862_item	2523799	et	3	main
vahel	doc_491521501862_item	2523811	et	4	main
te	doc_491521501862_item	2523813	et	4	main
d	doc_491521501862_item	2523818	et	4	main
on	doc_491521501862_item	2523819	et	4	main
peate	doc_491521501862_item	2523824	et	4	main
olema	doc_491521501862_item	2523831	et	4	main
et	doc_491521501862_item	2523839	et	3	main
t-d	doc_491521501862_item	2523846	et	4	main
haaldatakse	doc_491521501862_item	2523847	et	4	main
kerge	doc_491521501862_item	2523848	et	4	main
on	doc_491521501862_item	2523856	et	4	main
puhul	doc_491521501862_item	2523864	et	4	main
olen	doc_491521501862_item	2523865	et	3	main
taiesti	doc_491521501862_item	2523866	et	4	main
noutu	doc_491521501862_item	2523867	et	4	main
iga	doc_491521501862_item	2523877	et	4	main
nouab	doc_491521501862_item	2523909	et	4	main
sihitist	doc_491521501862_item	2523910	et	3	main
opilane	doc_491521501862_item	2523915	et	4	main
itaaliaparaseid	doc_491521501862_item	2523921	et	3	main
endale	doc_491521501862_item	2523923	et	4	main
kaande	doc_491521501862_item	2523925	et	3	main
et	doc_491521501862_item	2523930	et	3	main
kaanetes	doc_491521501862_item	2523934	et	4	main
nimisonaga	doc_491521501862_item	2523938	et	4	main
kirjapilt	doc_491521501862_item	2523959	et	3	main
vale	doc_491521501862_item	2523962	et	4	main
omadussona	doc_491521501862_item	2523963	et	4	main
ilmselt	doc_491521501862_item	2523970	et	4	main
selle	doc_491521501862_item	2523971	et	4	main
lausega	doc_491521501862_item	2523972	et	3	main
peamiselt	doc_491521501862_item	2523978	et	4	main
kohakaanete	doc_491521501862_item	2523982	et	4	main
leitub	doc_491521501862_item	2523985	et	4	main
oige	doc_491521501862_item	2523986	et	3	main
oleks	doc_491521501862_item	2523987	et	3	main
kirjutada	doc_491521501862_item	2523988	et	3	main
menuust	doc_491521501862_item	2523989	et	3	main
leidub	doc_491521501862_item	2523990	et	3	main
te	doc_491521501862_item	2523997	et	4	main
tahate	doc_491521501862_item	2523998	et	3	main
sest	doc_491521501862_item	2524005	et	4	main
alaltutlev	doc_491521501862_item	2524006	et	4	main
siin	doc_491521501862_item	2524015	et	4	main
sealt	doc_491521501862_item	2524029	et	4	main
ette	doc_491521501862_item	2524036	et	4	main
oleks	doc_491521501862_item	2524037	et	3	main
pronoomen	doc_491521501862_item	2524060	et	3	main
on	doc_491521501862_item	2524091	et	4	main
itaaliaparaseid	doc_491521501862_item	2524100	et	3	main
parim	doc_491521501862_item	2524107	et	4	main
olema	doc_491521501862_item	2524113	et	4	main
opilane	doc_491521501862_item	2524117	et	4	main
sellele	doc_491521501862_item	2524123	et	4	main
et	doc_491521501862_item	2524124	et	3	main
sona	doc_491521501862_item	2524125	et	4	main
parim	doc_491521501862_item	2524126	et	4	main
7	doc_491521501862_item	2524131	et	2	main
plaanitud	doc_491521501862_item	2524138	et	4	main
oigem	doc_491521501862_item	2524139	et	4	main
oelda	doc_491521501862_item	2524141	et	4	main
kogu	doc_491521501862_item	2524142	et	4	main
ilmselt	doc_491521501862_item	2524146	et	4	main
puiadis	doc_491521501862_item	2524149	et	4	main
tuletada	doc_491521501862_item	2524150	et	3	main
ei	doc_491521501862_item	2524154	et	4	main
eesti	doc_491521501862_item	2524160	et	4	main
kuid	doc_491521501862_item	2523772	et	4	main
kasutatakse	doc_491521501862_item	2523773	et	3	main
ka	doc_491521501862_item	2523774	et	3	main
pakutud	doc_491521501862_item	2523777	et	4	main
voimalik	doc_491521501862_item	2523784	et	4	main
eesti	doc_491521501862_item	2523804	et	4	main
ja	doc_491521501862_item	2523809	et	3	main
tahate	doc_491521501862_item	2523814	et	3	main
t-ga	doc_491521501862_item	2523822	et	3	main
teie	doc_491521501862_item	2523823	et	4	main
tellima	doc_491521501862_item	2523825	et	3	main
see	doc_491521501862_item	2523826	et	3	main
mittu	doc_491521501862_item	2523827	et	4	main
mitu	doc_491521501862_item	2523832	et	4	main
see	doc_491521501862_item	2523833	et	3	main
vea	doc_491521501862_item	2523863	et	4	main
et	doc_491521501862_item	2523869	et	3	main
soome	doc_491521501862_item	2523871	et	3	main
keele	doc_491521501862_item	2523872	et	4	main
veinkelder	doc_491521501862_item	2523878	et	4	main
mis	doc_491521501862_item	2523908	et	4	main
ilmselt	doc_491521501862_item	2523914	et	4	main
on	doc_491521501862_item	2523928	et	4	main
ja	doc_491521501862_item	2523943	et	3	main
on	doc_491521501862_item	2523960	et	4	main
keele	doc_491521501862_item	2523968	et	4	main
eeskujul	doc_491521501862_item	2523969	et	3	main
on	doc_491521501862_item	2523977	et	4	main
3	doc_491521501862_item	2523981	et	2	main
punktis	doc_491521501862_item	2523995	et	4	main
kui	doc_491521501862_item	2523996	et	3	main
seal	doc_491521501862_item	2524004	et	4	main
lahtekohta	doc_491521501862_item	2524010	et	4	main
voi	doc_491521501862_item	2524012	et	4	main
asja	doc_491521501862_item	2524013	et	4	main
allikat	doc_491521501862_item	2524014	et	3	main
sona	doc_491521501862_item	2523789	et	4	main
kuulnud	doc_491521501862_item	2523791	et	4	main
muutus	doc_491521501862_item	2523800	et	4	main
o-ks	doc_491521501862_item	2523801	et	3	main
millel	doc_491521501862_item	2523802	et	3	main
on	doc_491521501862_item	2523803	et	4	main
ees-	doc_491521501862_item	2523808	et	4	main
kui	doc_491521501862_item	2523812	et	3	main
helitu	doc_491521501862_item	2523821	et	4	main
peaks	doc_491521501862_item	2523830	et	4	main
on	doc_491521501862_item	2523837	et	4	main
loomulk	doc_491521501862_item	2523838	et	3	main
on	doc_491521501862_item	2523841	et	4	main
peegeldu	doc_491521501862_item	2523855	et	4	main
jaoks	doc_491521501862_item	2523858	et	4	main
italialaasia	doc_491521501862_item	2523860	et	4	main
veineja	doc_491521501862_item	2523861	et	4	main
selle	doc_491521501862_item	2523862	et	4	main
oletan	doc_491521501862_item	2523868	et	3	main
osastavas	doc_491521501862_item	2523911	et	4	main
seda	doc_491521501862_item	2523916	et	3	main
ei	doc_491521501862_item	2523917	et	4	main
naha	doc_491521501862_item	2523929	et	3	main
seal	doc_491521501862_item	2523944	et	4	main
peaasjalikult	doc_491521501862_item	2523946	et	4	main
moju	doc_491521501862_item	2523958	et	4	main
siiski	doc_491521501862_item	2523961	et	4	main
seal	doc_491521501862_item	2523976	et	4	main
veinid	doc_491521501862_item	2523980	et	3	main
seletus	doc_491521501862_item	2523992	et	4	main
kas	doc_491521501862_item	2524009	et	3	main
teate	doc_491521501862_item	2524011	et	4	main
aga	doc_491521501862_item	2524016	et	3	main
te	doc_491521501862_item	2524026	et	4	main
tahate	doc_491521501862_item	2524027	et	3	main
mittu	doc_491521501862_item	2524034	et	4	main
topelt	doc_491521501862_item	2524049	et	4	main
kasutamist	doc_491521501862_item	2524050	et	4	main
et	doc_491521501862_item	2524052	et	3	main
lauses	doc_491521501862_item	2524054	et	3	main
see	doc_491521501862_item	2524061	et	3	main
oige	doc_491521501862_item	2524066	et	3	main
omadussonad	doc_491521501862_item	2524090	et	4	main
valed	doc_491521501862_item	2524096	et	3	main
6	doc_491521501862_item	2524102	et	2	main
vordlusastmed	doc_491521501862_item	2524104	et	4	main
restoranin	doc_491521501862_item	2524108	et	4	main
koige	doc_491521501862_item	2524114	et	4	main
kasutas	doc_491521501862_item	2524118	et	3	main
ulivorret	doc_491521501862_item	2524121	et	4	main
koik	doc_491521501862_item	2524129	et	4	main
vead	doc_491521501862_item	2524134	et	4	main
oleks	doc_491521501862_item	2524140	et	3	main
pannud	doc_491521501862_item	2524155	et	4	main
tahele	doc_491521501862_item	2524156	et	4	main
on	doc_491521501862_item	2524159	et	4	main
jaoks	doc_491521501862_item	2524162	et	4	main
voortuvelise	doc_491521501862_item	2524163	et	4	main
sonaga	doc_491521501862_item	2524164	et	4	main
kus	doc_491521501862_item	2524165	et	3	main
rohkem	doc_491521501862_item	2524170	et	4	main
tsementeerima	doc_491521501862_item	2524177	et	3	main
koku	doc_491521501862_item	2524192	et	4	main
ja	doc_491521501862_item	2524234	et	3	main
tuupilised	doc_491521501862_item	2524242	et	4	main
itaaliaparaseid	doc_491521501862_item	2524243	et	3	main
oleks	doc_491521501862_item	2524247	et	3	main
korgklassist	doc_491521501862_item	2524278	et	4	main
kontekstist	doc_491521501862_item	2524279	et	3	main
kolab	doc_491521501862_item	2524282	et	3	main
on	doc_491521501862_item	2524293	et	4	main
oelda	doc_491521501862_item	2524298	et	4	main
korgema	doc_491521501862_item	2524299	et	4	main
klassi	doc_491521501862_item	2524300	et	4	main
personal	doc_491521501862_item	2524301	et	3	main
valesti	doc_491521501862_item	2524310	et	3	main
moistmist	doc_491521501862_item	2524311	et	4	main
ei	doc_491521501862_item	2524339	et	4	main
ole	doc_491521501862_item	2524340	et	4	main
asemel	doc_491521501862_item	2524345	et	4	main
peamiselt	doc_491521501862_item	2524348	et	4	main
autori	doc_491521501862_item	2524354	et	3	main
ette	doc_491521501862_item	2523829	et	4	main
mitu	doc_491521501862_item	2523840	et	4	main
teise	doc_491521501862_item	2523842	et	4	main
valte	doc_491521501862_item	2523843	et	4	main
sona	doc_491521501862_item	2523844	et	4	main
rohuga	doc_491521501862_item	2523849	et	4	main
kuid	doc_491521501862_item	2523850	et	4	main
kirjapildis	doc_491521501862_item	2523851	et	3	main
see	doc_491521501862_item	2523852	et	3	main
kuidagi	doc_491521501862_item	2523853	et	3	main
oige	doc_491521501862_item	2523879	et	3	main
on	doc_491521501862_item	2523880	et	4	main
veinikelder	doc_491521501862_item	2523881	et	3	main
vale	doc_491521501862_item	2523882	et	4	main
sonamoodustusviis	doc_491521501862_item	2523883	et	4	main
sonaviga	doc_491521501862_item	2523884	et	4	main
2	doc_491521501862_item	2523885	et	2	main
objektivead	doc_491521501862_item	2523886	et	4	main
vorm	doc_491521501862_item	2523887	et	3	main
ja	doc_491521501862_item	2523888	et	3	main
kaandevalik	doc_491521501862_item	2523889	et	4	main
menuult	doc_491521501862_item	2523890	et	4	main
leitub	doc_491521501862_item	2523891	et	4	main
tuupilised	doc_491521501862_item	2523892	et	4	main
itaaliaparaseid	doc_491521501862_item	2523893	et	3	main
toitu	doc_491521501862_item	2523894	et	4	main
ilmselt	doc_491521501862_item	2523895	et	4	main
selle	doc_491521501862_item	2523896	et	4	main
lausega	doc_491521501862_item	2523897	et	3	main
on	doc_491521501862_item	2523898	et	4	main
moeldud	doc_491521501862_item	2523899	et	4	main
etmenuust	doc_491521501862_item	2523900	et	4	main
leidub	doc_491521501862_item	2523901	et	3	main
tuupilisi	doc_491521501862_item	2523902	et	4	main
itaaliaparaseid	doc_491521501862_item	2523903	et	3	main
toite	doc_491521501862_item	2523904	et	4	main
tegemist	doc_491521501862_item	2523905	et	4	main
on	doc_491521501862_item	2523906	et	4	main
partitiivverbiga	doc_491521501862_item	2523907	et	4	main
teadnud	doc_491521501862_item	2523918	et	4	main
sai	doc_491521501862_item	2523922	et	4	main
oige	doc_491521501862_item	2523924	et	3	main
kogemata	doc_491521501862_item	2523926	et	4	main
samas	doc_491521501862_item	2523927	et	4	main
omadussonad	doc_491521501862_item	2523931	et	4	main
erinevates	doc_491521501862_item	2523933	et	4	main
ja	doc_491521501862_item	2523935	et	3	main
ei	doc_491521501862_item	2523936	et	4	main
uhildu	doc_491521501862_item	2523937	et	4	main
ei	doc_491521501862_item	2523939	et	4	main
kaandes	doc_491521501862_item	2523940	et	4	main
ega	doc_491521501862_item	2523941	et	3	main
arvus	doc_491521501862_item	2523942	et	3	main
on	doc_491521501862_item	2523964	et	4	main
on	doc_491521501862_item	2523973	et	4	main
vea	doc_491521501862_item	2523991	et	4	main
lauta	doc_491521501862_item	2523999	et	4	main
sealt	doc_491521501862_item	2524000	et	4	main
eestlane	doc_491521501862_item	2524001	et	3	main
utleks	doc_491521501862_item	2524002	et	4	main
pigem	doc_491521501862_item	2524003	et	3	main
valjendab	doc_491521501862_item	2524008	et	3	main
moeldakse	doc_491521501862_item	2524017	et	4	main
asukohta	doc_491521501862_item	2524018	et	4	main
mida	doc_491521501862_item	2524019	et	4	main
valjendab	doc_491521501862_item	2524020	et	3	main
4	doc_491521501862_item	2524023	et	2	main
pronoomenivead	doc_491521501862_item	2524024	et	4	main
kui	doc_491521501862_item	2524025	et	3	main
lauta	doc_491521501862_item	2524028	et	4	main
nadalad	doc_491521501862_item	2524035	et	4	main
opilane	doc_491521501862_item	2524045	et	4	main
puudis	doc_491521501862_item	2524046	et	3	main
kasutas	doc_491521501862_item	2524055	et	3	main
asesona	doc_491521501862_item	2524057	et	4	main
vormi	doc_491521501862_item	2524059	et	4	main
kasutatud	doc_491521501862_item	2524063	et	4	main
kaandes	doc_491521501862_item	2524065	et	4	main
toit	doc_491521501862_item	2524086	et	3	main
mitmuses	doc_491521501862_item	2524092	et	3	main
kaanded	doc_491521501862_item	2524093	et	4	main
on	doc_491521501862_item	2524094	et	4	main
osastavas	doc_491521501862_item	2524101	et	4	main
on	doc_491521501862_item	2524110	et	4	main
parem	doc_491521501862_item	2524115	et	4	main
2	doc_491521501862_item	2524119	et	2	main
utleb	doc_491521501862_item	2524127	et	4	main
verbivormide	doc_491521501862_item	2524132	et	4	main
koku	doc_491521501862_item	2524135	et	4	main
menuu	doc_491521501862_item	2524136	et	4	main
planeeritud	doc_491521501862_item	2524145	et	4	main
opilane	doc_491521501862_item	2524148	et	4	main
et	doc_491521501862_item	2524157	et	3	main
tuvevariandi	doc_491521501862_item	2524167	et	4	main
sonatasandi	doc_491521501862_item	2524185	et	4	main
mire	doc_491521501862_item	2524191	et	4	main
kuid	doc_491521501862_item	2524221	et	4	main
osatud	doc_491521501862_item	2524223	et	4	main
seda	doc_491521501862_item	2524224	et	3	main
valjendada	doc_491521501862_item	2524225	et	3	main
sonamoodustuse	doc_491521501862_item	2524226	et	4	main
liitmise	doc_491521501862_item	2524232	et	4	main
siis	doc_491521501862_item	2524235	et	3	main
teed	doc_491521501862_item	2524239	et	4	main
menuult	doc_491521501862_item	2524240	et	4	main
kahtlemata	doc_491521501862_item	2524245	et	4	main
parem	doc_491521501862_item	2524248	et	4	main
sona	doc_491521501862_item	2524250	et	4	main
toit	doc_491521501862_item	2524251	et	3	main
asemel	doc_491521501862_item	2524252	et	4	main
roogasid	doc_491521501862_item	2524253	et	3	main
mis	doc_491521501862_item	2524254	et	4	main
valja	doc_491521501862_item	2524280	et	3	main
voib	doc_491521501862_item	2524289	et	4	main
kelneritega	doc_491521501862_item	2524295	et	3	main
korgel	doc_491521501862_item	2524305	et	3	main
tasemel	doc_491521501862_item	2524306	et	3	main
te	doc_491521501862_item	2524313	et	4	main
lauta	doc_491521501862_item	2524315	et	4	main
teie	doc_491521501862_item	2524317	et	4	main
peate	doc_491521501862_item	2524318	et	4	main
on	doc_491521501862_item	2523932	et	4	main
on	doc_491521501862_item	2523945	et	4	main
italialaasia	doc_491521501862_item	2523947	et	4	main
veineja	doc_491521501862_item	2523948	et	4	main
vaatamata	doc_491521501862_item	2523949	et	4	main
sellele	doc_491521501862_item	2523950	et	4	main
et	doc_491521501862_item	2523951	et	3	main
objektikaane	doc_491521501862_item	2523952	et	4	main
on	doc_491521501862_item	2523953	et	4	main
oige	doc_491521501862_item	2523954	et	3	main
arvestades	doc_491521501862_item	2523955	et	3	main
soome	doc_491521501862_item	2523956	et	3	main
keele	doc_491521501862_item	2523957	et	4	main
samuti	doc_491521501862_item	2523965	et	3	main
moodustatud	doc_491521501862_item	2523966	et	4	main
soome	doc_491521501862_item	2523967	et	3	main
moeldud	doc_491521501862_item	2523974	et	4	main
et	doc_491521501862_item	2523975	et	3	main
itaalia	doc_491521501862_item	2523979	et	4	main
vead	doc_491521501862_item	2523983	et	4	main
menuult	doc_491521501862_item	2523984	et	4	main
on	doc_491521501862_item	2523993	et	4	main
2	doc_491521501862_item	2523994	et	2	main
kaane	doc_491521501862_item	2524007	et	4	main
alalutlev	doc_491521501862_item	2524021	et	4	main
teie	doc_491521501862_item	2524030	et	4	main
parem	doc_491521501862_item	2524038	et	4	main
loobuda	doc_491521501862_item	2524039	et	3	main
kahekordsest	doc_491521501862_item	2524040	et	3	main
asesona	doc_491521501862_item	2524048	et	4	main
sellega	doc_491521501862_item	2524051	et	3	main
esimeses	doc_491521501862_item	2524053	et	3	main
selle	doc_491521501862_item	2524056	et	4	main
luhikest	doc_491521501862_item	2524058	et	4	main
on	doc_491521501862_item	2524062	et	4	main
vales	doc_491521501862_item	2524064	et	3	main
kuid	doc_491521501862_item	2524089	et	4	main
ka	doc_491521501862_item	2524095	et	3	main
on	doc_491521501862_item	2524098	et	4	main
nimi	doc_491521501862_item	2524109	et	3	main
kuid	doc_491521501862_item	2524116	et	4	main
korda	doc_491521501862_item	2524120	et	4	main
vaatamata	doc_491521501862_item	2524122	et	4	main
niigi	doc_491521501862_item	2524128	et	4	main
on	doc_491521501862_item	2524137	et	4	main
pikema	doc_491521501862_item	2524166	et	4	main
levinud	doc_491521501862_item	2524171	et	4	main
nagu	doc_491521501862_item	2524174	et	3	main
tsementima	doc_491521501862_item	2524176	et	4	main
8	doc_491521501862_item	2524184	et	2	main
restoranin	doc_491521501862_item	2524188	et	4	main
kaane	doc_491521501862_item	2524022	et	4	main
peate	doc_491521501862_item	2524031	et	4	main
tellima	doc_491521501862_item	2524032	et	3	main
see	doc_491521501862_item	2524033	et	3	main
asesonast	doc_491521501862_item	2524041	et	4	main
teie	doc_491521501862_item	2524042	et	4	main
paistab	doc_491521501862_item	2524043	et	3	main
et	doc_491521501862_item	2524044	et	3	main
kompenseerida	doc_491521501862_item	2524047	et	3	main
oleks	doc_491521501862_item	2524067	et	3	main
selle	doc_491521501862_item	2524068	et	4	main
5	doc_491521501862_item	2524069	et	2	main
uhildumisvead	doc_491521501862_item	2524070	et	4	main
menuult	doc_491521501862_item	2524071	et	4	main
leitub	doc_491521501862_item	2524072	et	4	main
tuupilised	doc_491521501862_item	2524073	et	4	main
itaaliaparaseid	doc_491521501862_item	2524074	et	3	main
toitu	doc_491521501862_item	2524075	et	4	main
nimisona	doc_491521501862_item	2524076	et	4	main
ei	doc_491521501862_item	2524077	et	4	main
uhildu	doc_491521501862_item	2524078	et	4	main
omadussonadega	doc_491521501862_item	2524079	et	4	main
peaks	doc_491521501862_item	2524080	et	4	main
olema	doc_491521501862_item	2524081	et	4	main
leidub	doc_491521501862_item	2524082	et	3	main
tiaupilisi	doc_491521501862_item	2524083	et	4	main
itaaliaparaseid	doc_491521501862_item	2524084	et	3	main
toite	doc_491521501862_item	2524085	et	4	main
on	doc_491521501862_item	2524087	et	4	main
ainsuses	doc_491521501862_item	2524088	et	4	main
tuupilised	doc_491521501862_item	2524097	et	4	main
nimetavas	doc_491521501862_item	2524099	et	4	main
omadussona	doc_491521501862_item	2524103	et	4	main
tallinnan	doc_491521501862_item	2524105	et	4	main
koige	doc_491521501862_item	2524106	et	4	main
amadeus	doc_491521501862_item	2524111	et	4	main
peaks	doc_491521501862_item	2524112	et	4	main
ara	doc_491521501862_item	2524130	et	3	main
valiku	doc_491521501862_item	2524133	et	3	main
menuu	doc_491521501862_item	2524143	et	4	main
on	doc_491521501862_item	2524144	et	4	main
siin	doc_491521501862_item	2524147	et	4	main
verbi	doc_491521501862_item	2524151	et	4	main
nimisonast	doc_491521501862_item	2524152	et	4	main
ja	doc_491521501862_item	2524153	et	3	main
tegemist	doc_491521501862_item	2524158	et	4	main
kasutamine	doc_491521501862_item	2524168	et	4	main
plaanima	doc_491521501862_item	2524172	et	3	main
planeerima	doc_491521501862_item	2524173	et	3	main
see	doc_491521501862_item	2524187	et	3	main
on	doc_491521501862_item	2524189	et	4	main
itaalia	doc_491521501862_item	2524190	et	4	main
on	doc_491521501862_item	2524194	et	4	main
plaanitud	doc_491521501862_item	2524195	et	4	main
asjatuntlikult	doc_491521501862_item	2524196	et	4	main
usna	doc_491521501862_item	2524197	et	4	main
raske	doc_491521501862_item	2524198	et	4	main
on	doc_491521501862_item	2524199	et	4	main
analuusida	doc_491521501862_item	2524200	et	4	main
seda	doc_491521501862_item	2524201	et	3	main
lauset	doc_491521501862_item	2524202	et	3	main
kuna	doc_491521501862_item	2524203	et	3	main
selle	doc_491521501862_item	2524204	et	4	main
mote	doc_491521501862_item	2524205	et	4	main
jai	doc_491521501862_item	2524206	et	4	main
minu	doc_491521501862_item	2524207	et	3	main
jaoks	doc_491521501862_item	2524208	et	4	main
natuke	doc_491521501862_item	2524209	et	4	main
ahmaseks	doc_491521501862_item	2524210	et	4	main
oletan	doc_491521501862_item	2524211	et	3	main
et	doc_491521501862_item	2524212	et	3	main
selle	doc_491521501862_item	2524213	et	4	main
lausega	doc_491521501862_item	2524214	et	3	main
taheti	doc_491521501862_item	2524215	et	3	main
oelda	doc_491521501862_item	2524216	et	4	main
et	doc_491521501862_item	2524217	et	3	main
tegemist	doc_491521501862_item	2524218	et	4	main
on	doc_491521501862_item	2524219	et	4	main
kiirrestoraniga	doc_491521501862_item	2524220	et	4	main
kergema	doc_491521501862_item	2524237	et	4	main
vastupanu	doc_491521501862_item	2524238	et	4	main
siin	doc_491521501862_item	2524246	et	4	main
kasutada	doc_491521501862_item	2524249	et	3	main
kontekstile	doc_491521501862_item	2524257	et	3	main
loigatuna	doc_491521501862_item	2524281	et	4	main
see	doc_491521501862_item	2524283	et	3	main
rohkem	doc_491521501862_item	2524285	et	4	main
kui	doc_491521501862_item	2524286	et	3	main
imelikult	doc_491521501862_item	2524287	et	4	main
arvata	doc_491521501862_item	2524290	et	4	main
aadlisoost	doc_491521501862_item	2524294	et	4	main
oigem	doc_491521501862_item	2524296	et	4	main
keele	doc_491521501862_item	2524161	et	4	main
on	doc_491521501862_item	2524169	et	4	main
ka	doc_491521501862_item	2524175	et	3	main
puhul	doc_491521501862_item	2524178	et	4	main
autori	doc_491521501862_item	2524179	et	3	main
subjektiivne	doc_491521501862_item	2524180	et	3	main
arvamus	doc_491521501862_item	2524181	et	3	main
nous	doc_491521501862_item	2524182	et	4	main
pohjendama	doc_491521501862_item	2524183	et	4	main
vead	doc_491521501862_item	2524186	et	4	main
menuu	doc_491521501862_item	2524193	et	4	main
ei	doc_491521501862_item	2524222	et	4	main
vahendite	doc_491521501862_item	2524227	et	3	main
abil	doc_491521501862_item	2524228	et	4	main
omadussona	doc_491521501862_item	2524229	et	4	main
ja	doc_491521501862_item	2524230	et	3	main
teel	doc_491521501862_item	2524233	et	4	main
mindi	doc_491521501862_item	2524236	et	3	main
toitu	doc_491521501862_item	2524244	et	4	main
rohkem	doc_491521501862_item	2524255	et	4	main
vastab	doc_491521501862_item	2524256	et	3	main
sest	doc_491521501862_item	2524288	et	4	main
et	doc_491521501862_item	2524291	et	3	main
oleks	doc_491521501862_item	2524297	et	3	main
tahate	doc_491521501862_item	2524314	et	3	main
mittu	doc_491521501862_item	2524321	et	4	main
ette	doc_491521501862_item	2524323	et	4	main
parem	doc_491521501862_item	2524324	et	4	main
oleks	doc_491521501862_item	2524325	et	3	main
peaasjalikult	doc_491521501862_item	2524335	et	4	main
peaasjalikult	doc_491521501862_item	2524338	et	4	main
kuid	doc_491521501862_item	2524349	et	4	main
see	doc_491521501862_item	2524350	et	3	main
on	doc_491521501862_item	2524351	et	4	main
subjektiivne	doc_491521501862_item	2524355	et	3	main
punktuatsioonivigu	doc_491521501862_item	2524359	et	4	main
peaks	doc_491521501862_item	2524377	et	4	main
on	doc_491521501862_item	2524385	et	4	main
koku	doc_491521501862_item	2524386	et	4	main
oelda	doc_491521501862_item	2524396	et	4	main
piisavalt	doc_491521501862_item	2524421	et	4	main
on	doc_491521501862_item	2524432	et	4	main
selle	doc_491521501862_item	2524437	et	4	main
autoriks	doc_491521501862_item	2524438	et	3	main
oli	doc_491521501862_item	2524446	et	3	main
istusid	doc_491521501862_item	2524462	et	4	main
pilvine	doc_491521501862_item	2524476	et	4	main
laulma	doc_491521501862_item	2524520	et	3	main
sunipaev	doc_491521501862_item	2524522	et	4	main
laksin	doc_491521501862_item	2524527	et	3	main
parast	doc_491521501862_item	2524543	et	3	main
kes	doc_491521501862_item	2524552	et	4	main
kulas	doc_491521501862_item	2524553	et	3	main
on	doc_491521501862_item	2524554	et	4	main
registreeritud	doc_491521501862_item	2524556	et	4	main
on	doc_491521501862_item	2524585	et	4	main
oigekirjaveaga	doc_491521501862_item	2524586	et	4	main
raakisid	doc_491521501862_item	2524590	et	4	main
pedagigika	doc_491521501862_item	2524597	et	4	main
on	doc_491521501862_item	2524631	et	4	main
mis	doc_491521501862_item	2524635	et	4	main
on	doc_491521501862_item	2524636	et	4	main
ilmselt	doc_491521501862_item	2524643	et	4	main
lohakas	doc_491521501862_item	2524652	et	4	main
ka	doc_491521501862_item	2524653	et	3	main
opilane	doc_491521501862_item	2524672	et	4	main
vottis	doc_491521501862_item	2524673	et	4	main
mis	doc_491521501862_item	2524679	et	4	main
olema	doc_491521501862_item	2524681	et	4	main
oige	doc_491521501862_item	2524682	et	3	main
nad	doc_491521501862_item	2524700	et	3	main
madoanna	doc_491521501862_item	2524713	et	4	main
nad	doc_491521501862_item	2524716	et	3	main
madonna	doc_491521501862_item	2524718	et	4	main
kontserti	doc_491521501862_item	2524719	et	4	main
oletan	doc_491521501862_item	2524720	et	3	main
nimisona	doc_491521501862_item	2524231	et	4	main
leitub	doc_491521501862_item	2524241	et	4	main
sona	doc_491521501862_item	2524258	et	4	main
toit	doc_491521501862_item	2524259	et	3	main
on	doc_491521501862_item	2524260	et	4	main
liiga	doc_491521501862_item	2524261	et	4	main
uldine	doc_491521501862_item	2524262	et	4	main
sest	doc_491521501862_item	2524263	et	4	main
siin	doc_491521501862_item	2524264	et	4	main
moeldakse	doc_491521501862_item	2524265	et	4	main
ikka	doc_491521501862_item	2524266	et	4	main
konkreetseid	doc_491521501862_item	2524267	et	3	main
itaaliaparaseid	doc_491521501862_item	2524268	et	3	main
roogasid	doc_491521501862_item	2524269	et	3	main
restoranis	doc_491521501862_item	2524270	et	3	main
on	doc_491521501862_item	2524271	et	4	main
hea	doc_491521501862_item	2524272	et	4	main
teenindamine	doc_491521501862_item	2524273	et	4	main
seal	doc_491521501862_item	2524274	et	4	main
on	doc_491521501862_item	2524275	et	4	main
koku	doc_491521501862_item	2524276	et	4	main
personal	doc_491521501862_item	2524277	et	3	main
lause	doc_491521501862_item	2524284	et	4	main
tegemist	doc_491521501862_item	2524292	et	4	main
kui	doc_491521501862_item	2524312	et	3	main
oelda	doc_491521501862_item	2524326	et	4	main
reserveerida	doc_491521501862_item	2524327	et	3	main
voi	doc_491521501862_item	2524328	et	4	main
itaalialaasia	doc_491521501862_item	2524336	et	4	main
parem	doc_491521501862_item	2524342	et	4	main
rohkem	doc_491521501862_item	2524347	et	4	main
arvamus	doc_491521501862_item	2524356	et	3	main
naiteks	doc_491521501862_item	2524360	et	4	main
on	doc_491521501862_item	2524368	et	4	main
plaanitud	doc_491521501862_item	2524369	et	4	main
mille	doc_491521501862_item	2524375	et	3	main
on	doc_491521501862_item	2524381	et	4	main
et	doc_491521501862_item	2524397	et	3	main
tekst	doc_491521501862_item	2524400	et	3	main
kuid	doc_491521501862_item	2524424	et	4	main
analuiasitav	doc_491521501862_item	2524430	et	4	main
opilane	doc_491521501862_item	2524443	et	4	main
originaaltekst	doc_491521501862_item	2524451	et	3	main
ilus	doc_491521501862_item	2524453	et	4	main
koik	doc_491521501862_item	2524455	et	4	main
inimesed	doc_491521501862_item	2524456	et	3	main
ja	doc_491521501862_item	2524463	et	3	main
moned	doc_491521501862_item	2524467	et	4	main
aga	doc_491521501862_item	2524477	et	3	main
hakkab	doc_491521501862_item	2524505	et	3	main
marja	doc_491521501862_item	2524507	et	4	main
ehitas	doc_491521501862_item	2524513	et	3	main
raekoja	doc_491521501862_item	2524521	et	3	main
kontserti	doc_491521501862_item	2524525	et	4	main
perest	doc_491521501862_item	2524534	et	4	main
hommikul	doc_491521501862_item	2524535	et	3	main
nemad	doc_491521501862_item	2524536	et	3	main
sele	doc_491521501862_item	2524542	et	4	main
vasinud	doc_491521501862_item	2524545	et	4	main
on	doc_491521501862_item	2524547	et	4	main
tubli	doc_491521501862_item	2524555	et	4	main
haaldus-	doc_491521501862_item	2524559	et	4	main
siin	doc_491521501862_item	2524569	et	4	main
olema	doc_491521501862_item	2524589	et	4	main
vene	doc_491521501862_item	2524621	et	4	main
voi	doc_491521501862_item	2524302	et	4	main
personal	doc_491521501862_item	2524303	et	3	main
on	doc_491521501862_item	2524304	et	4	main
vale	doc_491521501862_item	2524307	et	4	main
kaane	doc_491521501862_item	2524308	et	4	main
pohjustab	doc_491521501862_item	2524309	et	4	main
sealt	doc_491521501862_item	2524316	et	4	main
nadalad	doc_491521501862_item	2524322	et	4	main
koige	doc_491521501862_item	2524341	et	4	main
sobiks	doc_491521501862_item	2524346	et	4	main
selle	doc_491521501862_item	2524352	et	4	main
esineb	doc_491521501862_item	2524357	et	3	main
menuu	doc_491521501862_item	2524367	et	4	main
on	doc_491521501862_item	2524372	et	4	main
kahe	doc_491521501862_item	2524373	et	3	main
lihtlausega	doc_491521501862_item	2524374	et	3	main
koma	doc_491521501862_item	2524379	et	4	main
restoranis	doc_491521501862_item	2524380	et	3	main
teenindamine	doc_491521501862_item	2524383	et	4	main
seal	doc_491521501862_item	2524384	et	4	main
koma	doc_491521501862_item	2524393	et	4	main
lopetuseks	doc_491521501862_item	2524394	et	4	main
tahan	doc_491521501862_item	2524395	et	3	main
vigadele	doc_491521501862_item	2524399	et	3	main
tellima	doc_491521501862_item	2524319	et	3	main
see	doc_491521501862_item	2524320	et	3	main
kinni	doc_491521501862_item	2524329	et	3	main
panna	doc_491521501862_item	2524330	et	4	main
tellitakse	doc_491521501862_item	2524331	et	3	main
roogasid	doc_491521501862_item	2524332	et	3	main
mitte	doc_491521501862_item	2524333	et	3	main
laudasid	doc_491521501862_item	2524334	et	3	main
veineja	doc_491521501862_item	2524337	et	4	main
sona	doc_491521501862_item	2524343	et	4	main
selle	doc_491521501862_item	2524344	et	4	main
too	doc_491521501862_item	2524353	et	4	main
see	doc_491521501862_item	2524361	et	3	main
on	doc_491521501862_item	2524363	et	4	main
koku	doc_491521501862_item	2524366	et	4	main
tegemist	doc_491521501862_item	2524371	et	4	main
seisma	doc_491521501862_item	2524378	et	3	main
hea	doc_491521501862_item	2524382	et	4	main
personal	doc_491521501862_item	2524387	et	3	main
korgklassist	doc_491521501862_item	2524388	et	4	main
ka	doc_491521501862_item	2524389	et	3	main
see	doc_491521501862_item	2524390	et	3	main
lause	doc_491521501862_item	2524391	et	4	main
vajab	doc_491521501862_item	2524392	et	3	main
jatab	doc_491521501862_item	2524401	et	4	main
vaga	doc_491521501862_item	2524402	et	4	main
hea	doc_491521501862_item	2524403	et	4	main
mulje	doc_491521501862_item	2524404	et	4	main
ta	doc_491521501862_item	2524405	et	4	main
on	doc_491521501862_item	2524406	et	4	main
loogiliselt	doc_491521501862_item	2524407	et	4	main
ulesehitatud	doc_491521501862_item	2524408	et	4	main
ja	doc_491521501862_item	2524409	et	3	main
kirjutatud	doc_491521501862_item	2524410	et	4	main
rikkas	doc_491521501862_item	2524411	et	4	main
keeles	doc_491521501862_item	2524412	et	4	main
selleks	doc_491521501862_item	2524413	et	4	main
et	doc_491521501862_item	2524414	et	3	main
suuliselt	doc_491521501862_item	2524415	et	4	main
suhelda	doc_491521501862_item	2524416	et	4	main
valdab	doc_491521501862_item	2524417	et	3	main
see	doc_491521501862_item	2524418	et	3	main
opilane	doc_491521501862_item	2524419	et	4	main
keelt	doc_491521501862_item	2524420	et	4	main
teine	doc_491521501862_item	2524429	et	3	main
kuid	doc_491521501862_item	2524436	et	4	main
keskkooli	doc_491521501862_item	2524442	et	4	main
ulesandeks	doc_491521501862_item	2524445	et	4	main
kirjeldumine	doc_491521501862_item	2524450	et	4	main
moned	doc_491521501862_item	2524460	et	4	main
inimesed	doc_491521501862_item	2524461	et	3	main
aga	doc_491521501862_item	2524466	et	3	main
auks	doc_491521501862_item	2524523	et	3	main
nemad	doc_491521501862_item	2524526	et	3	main
restorani	doc_491521501862_item	2524528	et	4	main
ja	doc_491521501862_item	2524530	et	3	main
hakkavad	doc_491521501862_item	2524531	et	4	main
istuma	doc_491521501862_item	2524532	et	3	main
hommikuni	doc_491521501862_item	2524533	et	4	main
et	doc_491521501862_item	2524544	et	3	main
1	doc_491521501862_item	2524558	et	2	main
olema	doc_491521501862_item	2524566	et	4	main
raekoja	doc_491521501862_item	2524567	et	3	main
platsile	doc_491521501862_item	2524568	et	4	main
ka	doc_491521501862_item	2524358	et	3	main
restoranin	doc_491521501862_item	2524362	et	4	main
itaalia	doc_491521501862_item	2524364	et	4	main
hire	doc_491521501862_item	2524365	et	4	main
asjatuntlikult	doc_491521501862_item	2524370	et	4	main
vahel	doc_491521501862_item	2524376	et	4	main
vaatamata	doc_491521501862_item	2524398	et	4	main
lihvima	doc_491521501862_item	2524428	et	3	main
tekst	doc_491521501862_item	2524431	et	3	main
parit	doc_491521501862_item	2524433	et	4	main
samast	doc_491521501862_item	2524434	et	4	main
allikast	doc_491521501862_item	2524435	et	4	main
rahvusest	doc_491521501862_item	2524441	et	4	main
uhe	doc_491521501862_item	2524447	et	4	main
paeva	doc_491521501862_item	2524449	et	4	main
paev	doc_491521501862_item	2524454	et	4	main
kogunesid	doc_491521501862_item	2524457	et	4	main
raekoja	doc_491521501862_item	2524458	et	3	main
platsele	doc_491521501862_item	2524459	et	3	main
olut	doc_491521501862_item	2524465	et	4	main
inimesed	doc_491521501862_item	2524468	et	3	main
ja	doc_491521501862_item	2524470	et	3	main
oli	doc_491521501862_item	2524472	et	3	main
vaga	doc_491521501862_item	2524473	et	4	main
ilus	doc_491521501862_item	2524474	et	4	main
ilm	doc_491521501862_item	2524475	et	3	main
laulma	doc_491521501862_item	2524506	et	3	main
nendele	doc_491521501862_item	2524508	et	4	main
meldib	doc_491521501862_item	2524509	et	4	main
see	doc_491521501862_item	2524510	et	3	main
lauljanna	doc_491521501862_item	2524511	et	4	main
viisteist	doc_491521501862_item	2524514	et	4	main
sajandil	doc_491521501862_item	2524516	et	3	main
ja	doc_491521501862_item	2524517	et	3	main
hakkab	doc_491521501862_item	2524519	et	3	main
margarita	doc_491521501862_item	2524529	et	4	main
magama	doc_491521501862_item	2524541	et	3	main
ja	doc_491521501862_item	2524546	et	3	main
gi	doc_491521501862_item	2524548	et	4	main
juutul	doc_491521501862_item	2524549	et	4	main
lopp	doc_491521501862_item	2524550	et	4	main
aga	doc_491521501862_item	2524551	et	3	main
vead	doc_491521501862_item	2524557	et	4	main
oigekirja-	doc_491521501862_item	2524560	et	4	main
ja	doc_491521501862_item	2524561	et	3	main
astmevaheldusvead	doc_491521501862_item	2524562	et	4	main
raekoja	doc_491521501862_item	2524563	et	3	main
platsele	doc_491521501862_item	2524564	et	3	main
peaks	doc_491521501862_item	2524565	et	4	main
viga	doc_491521501862_item	2524572	et	4	main
esiteks	doc_491521501862_item	2524573	et	3	main
peaks	doc_491521501862_item	2524576	et	4	main
raakidsid	doc_491521501862_item	2524587	et	4	main
peaks	doc_491521501862_item	2524588	et	4	main
et	doc_491521501862_item	2524592	et	3	main
on	doc_491521501862_item	2524594	et	4	main
opilase	doc_491521501862_item	2524595	et	4	main
ka	doc_491521501862_item	2524599	et	3	main
yhwbepcmter	doc_491521501862_item	2524624	et	4	main
koosneb	doc_491521501862_item	2524625	et	3	main
ortograafiline	doc_491521501862_item	2524637	et	4	main
tingitud	doc_491521501862_item	2524644	et	4	main
ka	doc_491521501862_item	2524645	et	3	main
aluseks	doc_491521501862_item	2524674	et	4	main
ilmselt	doc_491521501862_item	2524685	et	4	main
opilane	doc_491521501862_item	2524691	et	4	main
leiutas	doc_491521501862_item	2524692	et	3	main
uue	doc_491521501862_item	2524693	et	3	main
alusel	doc_491521501862_item	2524696	et	4	main
nagu	doc_491521501862_item	2524697	et	3	main
olema	doc_491521501862_item	2524707	et	4	main
nad	doc_491521501862_item	2524708	et	3	main
ootavad	doc_491521501862_item	2524709	et	4	main
kontsert	doc_491521501862_item	2524714	et	3	main
et	doc_491521501862_item	2524721	et	3	main
voimaliku	doc_491521501862_item	2524725	et	4	main
st	doc_491521501862_item	2524730	et	3	main
voimalikku	doc_491521501862_item	2524733	et	4	main
voib	doc_491521501862_item	2524744	et	4	main
see	doc_491521501862_item	2524763	et	3	main
vokaale	doc_491521501862_item	2524770	et	3	main
nagu	doc_491521501862_item	2524771	et	3	main
heal	doc_491521501862_item	2524422	et	3	main
tasemel	doc_491521501862_item	2524423	et	3	main
peab	doc_491521501862_item	2524425	et	4	main
veel	doc_491521501862_item	2524426	et	4	main
grammatikat	doc_491521501862_item	2524427	et	3	main
on	doc_491521501862_item	2524439	et	4	main
vene	doc_491521501862_item	2524440	et	4	main
opilase	doc_491521501862_item	2524444	et	4	main
ilusa	doc_491521501862_item	2524448	et	3	main
oli	doc_491521501862_item	2524452	et	3	main
joid	doc_491521501862_item	2524464	et	4	main
seisid	doc_491521501862_item	2524469	et	4	main
raakidsid	doc_491521501862_item	2524471	et	4	main
palav	doc_491521501862_item	2524478	et	4	main
need	doc_491521501862_item	2524479	et	3	main
on	doc_491521501862_item	2524480	et	4	main
opilased	doc_491521501862_item	2524481	et	4	main
nad	doc_491521501862_item	2524482	et	3	main
puhkavad	doc_491521501862_item	2524483	et	4	main
oppimisest	doc_491521501862_item	2524484	et	4	main
nad	doc_491521501862_item	2524485	et	3	main
opivad	doc_491521501862_item	2524486	et	4	main
pedagigika	doc_491521501862_item	2524487	et	4	main
ulikoolis	doc_491521501862_item	2524488	et	4	main
nad	doc_491521501862_item	2524489	et	3	main
opivad	doc_491521501862_item	2524490	et	4	main
kolmendal	doc_491521501862_item	2524491	et	4	main
kursusel	doc_491521501862_item	2524492	et	3	main
autoindust	doc_491521501862_item	2524493	et	4	main
nad	doc_491521501862_item	2524494	et	3	main
ootavad	doc_491521501862_item	2524495	et	4	main
kuni	doc_491521501862_item	2524496	et	3	main
hakkab	doc_491521501862_item	2524497	et	3	main
madonna	doc_491521501862_item	2524498	et	4	main
kontserti	doc_491521501862_item	2524499	et	4	main
aga	doc_491521501862_item	2524500	et	3	main
tema	doc_491521501862_item	2524501	et	4	main
on	doc_491521501862_item	2524502	et	4	main
ja	doc_491521501862_item	2524504	et	3	main
haigestus	doc_491521501862_item	2524503	et	4	main
raekoda	doc_491521501862_item	2524512	et	4	main
kumnendal	doc_491521501862_item	2524515	et	4	main
marja	doc_491521501862_item	2524518	et	4	main
perest	doc_491521501862_item	2524524	et	4	main
lahevad	doc_491521501862_item	2524537	et	4	main
koju	doc_491521501862_item	2524538	et	3	main
ja	doc_491521501862_item	2524539	et	3	main
hakkavad	doc_491521501862_item	2524540	et	4	main
on	doc_491521501862_item	2524570	et	4	main
kaks	doc_491521501862_item	2524571	et	3	main
plats	doc_491521501862_item	2524575	et	4	main
vaikese	doc_491521501862_item	2524578	et	3	main
oletan	doc_491521501862_item	2524591	et	3	main
lohakusega	doc_491521501862_item	2524596	et	4	main
ulkoolis	doc_491521501862_item	2524598	et	4	main
siin	doc_491521501862_item	2524600	et	4	main
on	doc_491521501862_item	2524601	et	4	main
mitu	doc_491521501862_item	2524603	et	4	main
korraga	doc_491521501862_item	2524602	et	4	main
viga	doc_491521501862_item	2524604	et	4	main
peaks	doc_491521501862_item	2524605	et	4	main
olema	doc_491521501862_item	2524606	et	4	main
pedagoogikaulikool	doc_491521501862_item	2524607	et	4	main
1	doc_491521501862_item	2524608	et	2	main
selles	doc_491521501862_item	2524609	et	4	main
et	doc_491521501862_item	2524610	et	3	main
opilane	doc_491521501862_item	2524611	et	4	main
kirjutas	doc_491521501862_item	2524612	et	3	main
lahku	doc_491521501862_item	2524613	et	4	main
pedagoogikaulikooli	doc_491521501862_item	2524614	et	4	main
voib	doc_491521501862_item	2524615	et	4	main
suudi	doc_491521501862_item	2524616	et	4	main
olla	doc_491521501862_item	2524617	et	3	main
emakeele	doc_491521501862_item	2524618	et	4	main
interferents	doc_491521501862_item	2524619	et	3	main
sest	doc_491521501862_item	2524620	et	4	main
pedagoogikaulikool	doc_491521501862_item	2524630	et	4	main
vaikese	doc_491521501862_item	2524633	et	3	main
vale	doc_491521501862_item	2524640	et	4	main
kirjapilt	doc_491521501862_item	2524641	et	3	main
opilane	doc_491521501862_item	2524648	et	4	main
oli	doc_491521501862_item	2524649	et	3	main
hajevil	doc_491521501862_item	2524650	et	4	main
ja	doc_491521501862_item	2524651	et	3	main
tekstis	doc_491521501862_item	2524655	et	3	main
palju	doc_491521501862_item	2524657	et	4	main
ilmselt	doc_491521501862_item	2524671	et	4	main
kolmas	doc_491521501862_item	2524678	et	3	main
peaks	doc_491521501862_item	2524686	et	4	main
olema	doc_491521501862_item	2524687	et	4	main
autondust	doc_491521501862_item	2524688	et	3	main
vale	doc_491521501862_item	2524689	et	4	main
sonamoodustusviis	doc_491521501862_item	2524690	et	4	main
algab	doc_491521501862_item	2524711	et	3	main
valis	doc_491521501862_item	2524723	et	3	main
lause	doc_491521501862_item	2524726	et	4	main
laulja	doc_491521501862_item	2524737	et	4	main
siin	doc_491521501862_item	2524743	et	4	main
jallegi	doc_491521501862_item	2524745	et	4	main
suudi	doc_491521501862_item	2524746	et	4	main
olla	doc_491521501862_item	2524747	et	3	main
keeles	doc_491521501862_item	2524752	et	4	main
esineb	doc_491521501862_item	2524753	et	3	main
sona	doc_491521501862_item	2524574	et	4	main
algama	doc_491521501862_item	2524577	et	3	main
tahega	doc_491521501862_item	2524579	et	4	main
teiseks	doc_491521501862_item	2524580	et	4	main
platsile	doc_491521501862_item	2524581	et	4	main
mitte	doc_491521501862_item	2524582	et	3	main
platsele	doc_491521501862_item	2524583	et	3	main
tegemist	doc_491521501862_item	2524584	et	4	main
tegemist	doc_491521501862_item	2524593	et	4	main
fleqarorwyeckwo	doc_491521501862_item	2524623	et	4	main
kahest	doc_491521501862_item	2524626	et	4	main
erinevast	doc_491521501862_item	2524627	et	4	main
sonast	doc_491521501862_item	2524628	et	4	main
viga	doc_491521501862_item	2524638	et	4	main
3	doc_491521501862_item	2524639	et	2	main
sellest	doc_491521501862_item	2524646	et	4	main
et	doc_491521501862_item	2524647	et	3	main
opivad	doc_491521501862_item	2524683	et	4	main
autoindust	doc_491521501862_item	2524684	et	4	main
analoogia	doc_491521501862_item	2524695	et	4	main
kuni	doc_491521501862_item	2524702	et	3	main
madonna	doc_491521501862_item	2524704	et	4	main
millal	doc_491521501862_item	2524710	et	3	main
i	doc_491521501862_item	2524712	et	4	main
opilane	doc_491521501862_item	2524722	et	4	main
kahe	doc_491521501862_item	2524724	et	3	main
tee	doc_491521501862_item	2524729	et	4	main
marja	doc_491521501862_item	2524736	et	4	main
oige	doc_491521501862_item	2524738	et	3	main
kahe	doc_491521501862_item	2524741	et	3	main
kuid	doc_491521501862_item	2524758	et	4	main
vene	doc_491521501862_item	2524765	et	4	main
ei	doc_491521501862_item	2524767	et	4	main
ole	doc_491521501862_item	2524768	et	4	main
ja	doc_491521501862_item	2524774	et	3	main
a	doc_491521501862_item	2524779	et	4	main
peaks	doc_491521501862_item	2524782	et	4	main
olema	doc_491521501862_item	2524783	et	4	main
eelmises	doc_491521501862_item	2524789	et	3	main
ei	doc_491521501862_item	2524799	et	4	main
oska	doc_491521501862_item	2524800	et	4	main
raekoja	doc_491521501862_item	2524805	et	3	main
peaks	doc_491521501862_item	2524808	et	4	main
on	doc_491521501862_item	2524830	et	4	main
perest	doc_491521501862_item	2524832	et	4	main
kontserti	doc_491521501862_item	2524833	et	4	main
kuid	doc_491521501862_item	2524838	et	4	main
parast	doc_491521501862_item	2524840	et	3	main
on	doc_491521501862_item	2524841	et	4	main
ka	doc_491521501862_item	2524842	et	3	main
peaks	doc_491521501862_item	2524848	et	4	main
e-ks	doc_491521501862_item	2524856	et	3	main
lahevad	doc_491521501862_item	2524857	et	4	main
koju	doc_491521501862_item	2524858	et	3	main
kirjtab	doc_491521501862_item	2524873	et	4	main
viga	doc_491521501862_item	2524878	et	4	main
peaks	doc_491521501862_item	2524884	et	4	main
on	doc_491521501862_item	2524894	et	4	main
mustiline	doc_491521501862_item	2524902	et	4	main
vl	doc_491521501862_item	2524916	et	4	main
kohela	doc_491521501862_item	2524918	et	4	main
opilane	doc_491521501862_item	2524922	et	4	main
segamini	doc_491521501862_item	2524924	et	4	main
teise	doc_491521501862_item	2524925	et	4	main
ja	doc_491521501862_item	2524926	et	3	main
kolmanda	doc_491521501862_item	2524927	et	3	main
peaks	doc_491521501862_item	2524934	et	4	main
pikki	doc_491521501862_item	2524941	et	4	main
vokaale	doc_491521501862_item	2524942	et	3	main
ka	doc_491521501862_item	2524944	et	3	main
2	doc_491521501862_item	2524947	et	2	main
kuid	doc_491521501862_item	2524951	et	4	main
objektiviga	doc_491521501862_item	2524959	et	4	main
3	doc_491521501862_item	2524968	et	2	main
ootavad	doc_491521501862_item	2524978	et	4	main
kuni	doc_491521501862_item	2524979	et	3	main
hakkab	doc_491521501862_item	2524980	et	3	main
madonna	doc_491521501862_item	2524981	et	4	main
kontserti	doc_491521501862_item	2524982	et	4	main
moodustamiseks	doc_491521501862_item	2524989	et	4	main
siis	doc_491521501862_item	2524990	et	3	main
keeles	doc_491521501862_item	2524622	et	4	main
2	doc_491521501862_item	2524629	et	2	main
kirjutatud	doc_491521501862_item	2524632	et	4	main
algustahega	doc_491521501862_item	2524634	et	4	main
on	doc_491521501862_item	2524642	et	4	main
mujal	doc_491521501862_item	2524654	et	3	main
esineb	doc_491521501862_item	2524656	et	3	main
seletamatuid	doc_491521501862_item	2524658	et	4	main
vigu	doc_491521501862_item	2524659	et	3	main
kolmendal	doc_491521501862_item	2524660	et	4	main
kursusel	doc_491521501862_item	2524661	et	3	main
peaks	doc_491521501862_item	2524662	et	4	main
olema	doc_491521501862_item	2524663	et	4	main
kolmandal	doc_491521501862_item	2524664	et	3	main
oletan	doc_491521501862_item	2524665	et	3	main
te	doc_491521501862_item	2524666	et	4	main
tegemist	doc_491521501862_item	2524667	et	4	main
on	doc_491521501862_item	2524668	et	4	main
vale	doc_491521501862_item	2524669	et	4	main
kaanamisviisiga	doc_491521501862_item	2524670	et	4	main
sona	doc_491521501862_item	2524675	et	4	main
kolm	doc_491521501862_item	2524676	et	3	main
mitte	doc_491521501862_item	2524677	et	3	main
peaks	doc_491521501862_item	2524680	et	4	main
sona	doc_491521501862_item	2524694	et	4	main
kodundus	doc_491521501862_item	2524698	et	3	main
aiandus	doc_491521501862_item	2524699	et	3	main
ootavad	doc_491521501862_item	2524701	et	4	main
hakkab	doc_491521501862_item	2524703	et	3	main
kontserti	doc_491521501862_item	2524705	et	4	main
peaks	doc_491521501862_item	2524706	et	4	main
voi	doc_491521501862_item	2524715	et	4	main
ootavad	doc_491521501862_item	2524717	et	4	main
vahel	doc_491521501862_item	2524727	et	4	main
pani	doc_491521501862_item	2524731	et	4	main
lauset	doc_491521501862_item	2524734	et	3	main
nimi	doc_491521501862_item	2524739	et	3	main
a-ga	doc_491521501862_item	2524742	et	3	main
veel	doc_491521501862_item	2524759	et	4	main
uks	doc_491521501862_item	2524760	et	3	main
pohjendus	doc_491521501862_item	2524761	et	4	main
pikki	doc_491521501862_item	2524769	et	4	main
ei	doc_491521501862_item	2524777	et	4	main
pikana	doc_491521501862_item	2524780	et	4	main
on	doc_491521501862_item	2524786	et	4	main
punktis	doc_491521501862_item	2524790	et	4	main
kumnendal	doc_491521501862_item	2524792	et	4	main
sajandil	doc_491521501862_item	2524793	et	3	main
peaks	doc_491521501862_item	2524794	et	4	main
laulma	doc_491521501862_item	2524804	et	3	main
sona	doc_491521501862_item	2524823	et	4	main
kaandes	doc_491521501862_item	2524826	et	4	main
tegemist	doc_491521501862_item	2524829	et	4	main
peaks	doc_491521501862_item	2524834	et	4	main
kontserti	doc_491521501862_item	2524837	et	4	main
sona	doc_491521501862_item	2524839	et	4	main
haalduse	doc_491521501862_item	2524854	et	4	main
grammatiline	doc_491521501862_item	2524877	et	3	main
ongi	doc_491521501862_item	2524887	et	4	main
lopp	doc_491521501862_item	2524889	et	4	main
ongi	doc_491521501862_item	2524890	et	4	main
jaoks	doc_491521501862_item	2524893	et	4	main
need	doc_491521501862_item	2524895	et	3	main
kaks	doc_491521501862_item	2524896	et	3	main
eraldi	doc_491521501862_item	2524897	et	4	main
voimalik	doc_491521501862_item	2524904	et	4	main
jargmiselt	doc_491521501862_item	2524914	et	4	main
bot	doc_491521501862_item	2524915	et	4	main
et	doc_491521501862_item	2524921	et	3	main
u	doc_491521501862_item	2524932	et	4	main
vene	doc_491521501862_item	2524937	et	4	main
ei	doc_491521501862_item	2524939	et	4	main
vale	doc_491521501862_item	2524945	et	4	main
kirjapilt	doc_491521501862_item	2524946	et	3	main
objektivead	doc_491521501862_item	2524948	et	4	main
taiesti	doc_491521501862_item	2524949	et	4	main
selle	doc_491521501862_item	2524961	et	4	main
parast	doc_491521501862_item	2524962	et	3	main
et	doc_491521501862_item	2524963	et	3	main
tekst	doc_491521501862_item	2524964	et	3	main
on	doc_491521501862_item	2524965	et	4	main
kaandevead	doc_491521501862_item	2524976	et	4	main
nad	doc_491521501862_item	2524977	et	3	main
voimalik	doc_491521501862_item	2524985	et	4	main
kaks	doc_491521501862_item	2524986	et	3	main
5	doc_491521501862_item	2525021	et	2	main
otseseid	doc_491521501862_item	2525023	et	3	main
leidnud	doc_491521501862_item	2525026	et	4	main
et	doc_491521501862_item	2525030	et	3	main
vaga	doc_491521501862_item	2525034	et	4	main
referentsete	doc_491521501862_item	2525041	et	4	main
opilane	doc_491521501862_item	2525046	et	4	main
ainult	doc_491521501862_item	2525048	et	4	main
puhkavad	doc_491521501862_item	2525059	et	4	main
nad	doc_491521501862_item	2525061	et	3	main
nad	doc_491521501862_item	2525065	et	3	main
hakkab	doc_491521501862_item	2525073	et	3	main
on	doc_491521501862_item	2525078	et	4	main
hakkab	doc_491521501862_item	2525081	et	3	main
marja	doc_491521501862_item	2525083	et	4	main
meldib	doc_491521501862_item	2525085	et	4	main
see	doc_491521501862_item	2525086	et	3	main
keskmise	doc_491521501862_item	2524728	et	3	main
kaks	doc_491521501862_item	2524732	et	3	main
kokku	doc_491521501862_item	2524735	et	3	main
kirjutatakse	doc_491521501862_item	2524740	et	3	main
emakeele	doc_491521501862_item	2524748	et	4	main
interferents	doc_491521501862_item	2524749	et	3	main
sest	doc_491521501862_item	2524750	et	4	main
vene	doc_491521501862_item	2524751	et	4	main
see	doc_491521501862_item	2524754	et	3	main
nimi	doc_491521501862_item	2524755	et	3	main
uhe	doc_491521501862_item	2524756	et	4	main
a-ga	doc_491521501862_item	2524757	et	3	main
on	doc_491521501862_item	2524762	et	4	main
keeles	doc_491521501862_item	2524766	et	4	main
keeles	doc_491521501862_item	2524773	et	4	main
pohjendus	doc_491521501862_item	2524785	et	4	main
viisteist	doc_491521501862_item	2524791	et	4	main
hakkab	doc_491521501862_item	2524803	et	3	main
olema	doc_491521501862_item	2524809	et	4	main
hakkab	doc_491521501862_item	2524810	et	3	main
laulma	doc_491521501862_item	2524811	et	3	main
raekoja	doc_491521501862_item	2524812	et	3	main
sunnipaeva	doc_491521501862_item	2524813	et	4	main
auks	doc_491521501862_item	2524814	et	3	main
valesti	doc_491521501862_item	2524815	et	3	main
kirjutatud	doc_491521501862_item	2524816	et	4	main
sona	doc_491521501862_item	2524817	et	4	main
sunnipaev	doc_491521501862_item	2524818	et	4	main
n	doc_491521501862_item	2524819	et	4	main
on	doc_491521501862_item	2524820	et	4	main
et	doc_491521501862_item	2524764	et	3	main
kuulnud	doc_491521501862_item	2524778	et	4	main
meldib	doc_491521501862_item	2524781	et	4	main
meeldib	doc_491521501862_item	2524784	et	3	main
mis	doc_491521501862_item	2524788	et	4	main
sajandil	doc_491521501862_item	2524797	et	3	main
opilane	doc_491521501862_item	2524798	et	4	main
arvsonu	doc_491521501862_item	2524802	et	4	main
sunipaev	doc_491521501862_item	2524806	et	4	main
oletan	doc_491521501862_item	2524827	et	3	main
olema	doc_491521501862_item	2524835	et	4	main
a	doc_491521501862_item	2524846	et	4	main
mis	doc_491521501862_item	2524847	et	4	main
puhul	doc_491521501862_item	2524855	et	4	main
opilane	doc_491521501862_item	2524872	et	4	main
nii	doc_491521501862_item	2524874	et	3	main
kuuleb	doc_491521501862_item	2524876	et	3	main
ja	doc_491521501862_item	2524879	et	3	main
on	doc_491521501862_item	2524880	et	4	main
gi	doc_491521501862_item	2524881	et	4	main
olema	doc_491521501862_item	2524885	et	4	main
jutul	doc_491521501862_item	2524888	et	3	main
opilase	doc_491521501862_item	2524892	et	4	main
tegusona	doc_491521501862_item	2524899	et	4	main
on	doc_491521501862_item	2524900	et	4	main
ja	doc_491521501862_item	2524901	et	3	main
et	doc_491521501862_item	2524905	et	3	main
lause	doc_491521501862_item	2524912	et	4	main
ajas	doc_491521501862_item	2524923	et	4	main
liigne	doc_491521501862_item	2524931	et	3	main
keeles	doc_491521501862_item	2524938	et	4	main
ole	doc_491521501862_item	2524940	et	4	main
leidnud	doc_491521501862_item	2524956	et	4	main
ma	doc_491521501862_item	2524957	et	3	main
uhtegi	doc_491521501862_item	2524958	et	3	main
usna	doc_491521501862_item	2524966	et	4	main
primitiivne	doc_491521501862_item	2524967	et	3	main
ei	doc_491521501862_item	2524971	et	4	main
muud	doc_491521501862_item	2524975	et	4	main
kuna	doc_491521501862_item	2524983	et	3	main
on	doc_491521501862_item	2524984	et	4	main
lause	doc_491521501862_item	2524988	et	4	main
on	doc_491521501862_item	2524992	et	4	main
vale	doc_491521501862_item	2524993	et	4	main
vorm	doc_491521501862_item	2524994	et	3	main
nad	doc_491521501862_item	2524995	et	3	main
vigu	doc_491521501862_item	2525024	et	3	main
pole	doc_491521501862_item	2525025	et	3	main
naha	doc_491521501862_item	2525029	et	3	main
tanu	doc_491521501862_item	2525037	et	4	main
sellele	doc_491521501862_item	2525038	et	4	main
ei	doc_491521501862_item	2525039	et	4	main
ole	doc_491521501862_item	2525040	et	4	main
mida	doc_491521501862_item	2525050	et	4	main
liiga	doc_491521501862_item	2525052	et	4	main
tihti	doc_491521501862_item	2525053	et	3	main
nad	doc_491521501862_item	2525058	et	3	main
oppimisest	doc_491521501862_item	2525060	et	4	main
madonna	doc_491521501862_item	2525074	et	4	main
kontserti	doc_491521501862_item	2525075	et	4	main
kasuta	doc_491521501862_item	2525091	et	4	main
arvsona	doc_491521501862_item	2525097	et	4	main
peaks	doc_491521501862_item	2525121	et	4	main
viieteistkumnendal	doc_491521501862_item	2525131	et	4	main
esiteks	doc_491521501862_item	2525133	et	3	main
ka	doc_491521501862_item	2525141	et	3	main
uhildumisvead	doc_491521501862_item	2525144	et	4	main
alus	doc_491521501862_item	2525147	et	4	main
ja	doc_491521501862_item	2525148	et	3	main
olema	doc_491521501862_item	2525157	et	4	main
emakeele	doc_491521501862_item	2525180	et	4	main
lause	doc_491521501862_item	2525184	et	4	main
noctpoeha	doc_491521501862_item	2525189	et	4	main
opilane	doc_491521501862_item	2525191	et	4	main
variandist	doc_491521501862_item	2525194	et	3	main
on	doc_491521501862_item	2525207	et	4	main
vales	doc_491521501862_item	2525208	et	3	main
poore	doc_491521501862_item	2525213	et	3	main
haigestus	doc_491521501862_item	2525225	et	4	main
milesse	doc_491521501862_item	2525226	et	4	main
aidsi	doc_491521501862_item	2525229	et	4	main
haigestus	doc_491521501862_item	2525237	et	4	main
eesti	doc_491521501862_item	2524772	et	4	main
opilane	doc_491521501862_item	2524775	et	4	main
lihtsalt	doc_491521501862_item	2524776	et	4	main
sama	doc_491521501862_item	2524787	et	4	main
olema	doc_491521501862_item	2524795	et	4	main
viieteistkumnendal	doc_491521501862_item	2524796	et	4	main
kaanata	doc_491521501862_item	2524801	et	4	main
auks	doc_491521501862_item	2524807	et	3	main
puudu	doc_491521501862_item	2524821	et	4	main
et	doc_491521501862_item	2524828	et	3	main
lohakusega	doc_491521501862_item	2524831	et	4	main
eesti	doc_491521501862_item	2524845	et	4	main
vene	doc_491521501862_item	2524853	et	4	main
olema	doc_491521501862_item	2524860	et	4	main
juutul	doc_491521501862_item	2524882	et	4	main
ja	doc_491521501862_item	2524886	et	3	main
sona	doc_491521501862_item	2524898	et	4	main
gi	doc_491521501862_item	2524903	et	4	main
tegemist	doc_491521501862_item	2524906	et	4	main
emakeele	doc_491521501862_item	2524908	et	4	main
mojuga	doc_491521501862_item	2524909	et	4	main
kus	doc_491521501862_item	2524910	et	3	main
see	doc_491521501862_item	2524911	et	3	main
oletan	doc_491521501862_item	2524920	et	3	main
valte	doc_491521501862_item	2524928	et	4	main
was	doc_491521501862_item	2524933	et	4	main
opilase	doc_491521501862_item	2524953	et	4	main
toos	doc_491521501862_item	2524954	et	3	main
ei	doc_491521501862_item	2524955	et	4	main
kohakaanete	doc_491521501862_item	2524969	et	4	main
ole	doc_491521501862_item	2524972	et	4	main
leidnud	doc_491521501862_item	2524973	et	4	main
4	doc_491521501862_item	2524974	et	2	main
varianti	doc_491521501862_item	2524987	et	4	main
tulemuseks	doc_491521501862_item	2524991	et	3	main
kuid	doc_491521501862_item	2525027	et	4	main
keel	doc_491521501862_item	2525032	et	4	main
on	doc_491521501862_item	2525033	et	4	main
moodustajate	doc_491521501862_item	2525042	et	4	main
nt	doc_491521501862_item	2525054	et	4	main
need	doc_491521501862_item	2525055	et	3	main
on	doc_491521501862_item	2525056	et	4	main
autoindust	doc_491521501862_item	2525069	et	4	main
nad	doc_491521501862_item	2525070	et	3	main
tema	doc_491521501862_item	2525077	et	4	main
ja	doc_491521501862_item	2525080	et	3	main
opilane	doc_491521501862_item	2525088	et	4	main
kordagi	doc_491521501862_item	2525089	et	4	main
ei	doc_491521501862_item	2525090	et	4	main
6	doc_491521501862_item	2525096	et	2	main
olema	doc_491521501862_item	2525122	et	4	main
kumnendal	doc_491521501862_item	2525127	et	4	main
sajandil	doc_491521501862_item	2525132	et	3	main
seda	doc_491521501862_item	2525134	et	3	main
peaks	doc_491521501862_item	2525136	et	4	main
teiseks	doc_491521501862_item	2525139	et	4	main
7	doc_491521501862_item	2525143	et	2	main
nemad	doc_491521501862_item	2525145	et	3	main
verb	doc_491521501862_item	2525152	et	3	main
raekoda	doc_491521501862_item	2525174	et	4	main
ehitati	doc_491521501862_item	2525175	et	3	main
kus	doc_491521501862_item	2525182	et	3	main
parywy	doc_491521501862_item	2525186	et	4	main
parywa	doc_491521501862_item	2525188	et	4	main
peaks	doc_491521501862_item	2525210	et	4	main
mitmust	doc_491521501862_item	2525214	et	3	main
on	doc_491521501862_item	2525216	et	4	main
peaks	doc_491521501862_item	2525218	et	4	main
haigeks	doc_491521501862_item	2525222	et	4	main
jne	doc_491521501862_item	2525230	et	4	main
sonatasandi	doc_491521501862_item	2525239	et	4	main
vead	doc_491521501862_item	2525240	et	4	main
vale	doc_491521501862_item	2525246	et	4	main
10tolkelaenud	doc_491521501862_item	2525252	et	4	main
et	doc_491521501862_item	2525259	et	3	main
cnatb	doc_491521501862_item	2525265	et	4	main
noronny	doc_491521501862_item	2525266	et	4	main
yro	doc_491521501862_item	2525267	et	4	main
kes	doc_491521501862_item	2525277	et	4	main
nnonoqeu	doc_491521501862_item	2525291	et	4	main
onnestunud	doc_491521501862_item	2525328	et	4	main
mingil	doc_491521501862_item	2525331	et	4	main
ja	doc_491521501862_item	2524822	et	3	main
esineb	doc_491521501862_item	2524824	et	3	main
vales	doc_491521501862_item	2524825	et	3	main
peale	doc_491521501862_item	2524836	et	4	main
valesti	doc_491521501862_item	2524843	et	3	main
kirjutatud	doc_491521501862_item	2524844	et	4	main
olema	doc_491521501862_item	2524849	et	4	main
madal	doc_491521501862_item	2524850	et	3	main
eesvokaal	doc_491521501862_item	2524851	et	3	main
muutub	doc_491521501862_item	2524852	et	3	main
peaks	doc_491521501862_item	2524859	et	4	main
lahevad	doc_491521501862_item	2524861	et	4	main
lohakusviga	doc_491521501862_item	2524862	et	4	main
tapid	doc_491521501862_item	2524863	et	4	main
jaid	doc_491521501862_item	2524864	et	4	main
panemata	doc_491521501862_item	2524865	et	4	main
sele	doc_491521501862_item	2524866	et	4	main
parast	doc_491521501862_item	2524867	et	3	main
peaks	doc_491521501862_item	2524868	et	4	main
olema	doc_491521501862_item	2524869	et	4	main
selle	doc_491521501862_item	2524870	et	4	main
parast	doc_491521501862_item	2524871	et	3	main
nagu	doc_491521501862_item	2524875	et	3	main
lopp	doc_491521501862_item	2524883	et	4	main
imselt	doc_491521501862_item	2524891	et	4	main
on	doc_491521501862_item	2524907	et	4	main
kolab	doc_491521501862_item	2524913	et	3	main
cka304ke	doc_491521501862_item	2524917	et	4	main
jutul	doc_491521501862_item	2524919	et	3	main
sellest	doc_491521501862_item	2524929	et	4	main
ka	doc_491521501862_item	2524930	et	3	main
olema	doc_491521501862_item	2524935	et	4	main
kuulas	doc_491521501862_item	2524936	et	3	main
sellest	doc_491521501862_item	2524943	et	4	main
ootamatu	doc_491521501862_item	2524950	et	4	main
selle	doc_491521501862_item	2524952	et	4	main
ilmselt	doc_491521501862_item	2524960	et	4	main
vead	doc_491521501862_item	2524970	et	4	main
ootavad	doc_491521501862_item	2524996	et	4	main
madonna	doc_491521501862_item	2524997	et	4	main
kontserti	doc_491521501862_item	2524998	et	4	main
siin	doc_491521501862_item	2524999	et	4	main
voiks	doc_491521501862_item	2525000	et	4	main
raakida	doc_491521501862_item	2525001	et	4	main
objektiveast	doc_491521501862_item	2525002	et	4	main
ja	doc_491521501862_item	2525003	et	3	main
nad	doc_491521501862_item	2525004	et	3	main
millal	doc_491521501862_item	2525006	et	3	main
ootavad	doc_491521501862_item	2525005	et	4	main
hakkab	doc_491521501862_item	2525007	et	3	main
madonna	doc_491521501862_item	2525008	et	4	main
kontsert	doc_491521501862_item	2525009	et	3	main
hakkab	doc_491521501862_item	2525010	et	3	main
laulma	doc_491521501862_item	2525011	et	3	main
raekoja	doc_491521501862_item	2525012	et	3	main
sunipaev	doc_491521501862_item	2525013	et	4	main
auks	doc_491521501862_item	2525014	et	3	main
omastava	doc_491521501862_item	2525015	et	4	main
asemel	doc_491521501862_item	2525016	et	4	main
on	doc_491521501862_item	2525017	et	4	main
millegi	doc_491521501862_item	2525018	et	4	main
parast	doc_491521501862_item	2525019	et	3	main
nimetav	doc_491521501862_item	2525020	et	4	main
pronoomenivead	doc_491521501862_item	2525022	et	4	main
opilase	doc_491521501862_item	2525031	et	4	main
ja	doc_491521501862_item	2525036	et	3	main
kuigi	doc_491521501862_item	2525044	et	3	main
piirdub	doc_491521501862_item	2525047	et	3	main
asesonadega	doc_491521501862_item	2525049	et	4	main
kasutab	doc_491521501862_item	2525051	et	3	main
opilased	doc_491521501862_item	2525057	et	4	main
pedagigika	doc_491521501862_item	2525063	et	4	main
ulikoolis	doc_491521501862_item	2525064	et	4	main
opivad	doc_491521501862_item	2525066	et	4	main
kolmendal	doc_491521501862_item	2525067	et	4	main
kursusel	doc_491521501862_item	2525068	et	3	main
aga	doc_491521501862_item	2525076	et	3	main
haigestus	doc_491521501862_item	2525079	et	4	main
laulma	doc_491521501862_item	2525082	et	3	main
nendele	doc_491521501862_item	2525084	et	4	main
kaanamine	doc_491521501862_item	2525098	et	4	main
ehitas	doc_491521501862_item	2525125	et	3	main
viisteist	doc_491521501862_item	2525126	et	4	main
sajandil	doc_491521501862_item	2525128	et	3	main
peaks	doc_491521501862_item	2525129	et	4	main
on	doc_491521501862_item	2525028	et	4	main
vaene	doc_491521501862_item	2525035	et	4	main
valik	doc_491521501862_item	2525043	et	3	main
suur	doc_491521501862_item	2525045	et	3	main
opivad	doc_491521501862_item	2525062	et	4	main
ootavad	doc_491521501862_item	2525071	et	4	main
kuni	doc_491521501862_item	2525072	et	3	main
vormi	doc_491521501862_item	2525095	et	4	main
kasutamine	doc_491521501862_item	2525100	et	4	main
kolmendal	doc_491521501862_item	2525101	et	4	main
peaks	doc_491521501862_item	2525103	et	4	main
olema	doc_491521501862_item	2525104	et	4	main
kolmandal	doc_491521501862_item	2525105	et	3	main
oletan	doc_491521501862_item	2525106	et	3	main
te	doc_491521501862_item	2525107	et	4	main
tegemist	doc_491521501862_item	2525108	et	4	main
on	doc_491521501862_item	2525109	et	4	main
vale	doc_491521501862_item	2525110	et	4	main
kaanamisviisiga	doc_491521501862_item	2525111	et	4	main
ilmselt	doc_491521501862_item	2525112	et	4	main
opilane	doc_491521501862_item	2525113	et	4	main
vottis	doc_491521501862_item	2525114	et	4	main
aluseks	doc_491521501862_item	2525115	et	4	main
sona	doc_491521501862_item	2525116	et	4	main
kolm	doc_491521501862_item	2525117	et	3	main
mitte	doc_491521501862_item	2525118	et	3	main
kolmas	doc_491521501862_item	2525119	et	3	main
mis	doc_491521501862_item	2525120	et	4	main
lauljanna	doc_491521501862_item	2525087	et	4	main
pronoomeni	doc_491521501862_item	2525092	et	3	main
nad	doc_491521501862_item	2525093	et	3	main
pikemat	doc_491521501862_item	2525094	et	4	main
ja	doc_491521501862_item	2525099	et	3	main
kursusel	doc_491521501862_item	2525102	et	3	main
oige	doc_491521501862_item	2525123	et	3	main
olema	doc_491521501862_item	2525130	et	4	main
kirjutama	doc_491521501862_item	2525138	et	3	main
oeldis	doc_491521501862_item	2525149	et	4	main
ei	doc_491521501862_item	2525150	et	4	main
vales	doc_491521501862_item	2525154	et	3	main
peaks	doc_491521501862_item	2525156	et	4	main
ehitatud	doc_491521501862_item	2525172	et	4	main
voi	doc_491521501862_item	2525173	et	4	main
selline	doc_491521501862_item	2525183	et	4	main
kolab	doc_491521501862_item	2525185	et	3	main
noctponnm	doc_491521501862_item	2525187	et	4	main
on	doc_491521501862_item	2525196	et	4	main
t	doc_491521501862_item	2525198	et	4	main
ta	doc_491521501862_item	2525199	et	4	main
ekslikult	doc_491521501862_item	2525200	et	4	main
kasutas	doc_491521501862_item	2525201	et	3	main
3	doc_491521501862_item	2525202	et	2	main
pooret	doc_491521501862_item	2525203	et	4	main
nemad	doc_491521501862_item	2525204	et	3	main
laksin	doc_491521501862_item	2525205	et	3	main
verb	doc_491521501862_item	2525206	et	3	main
tema	doc_491521501862_item	2525215	et	4	main
haigestus	doc_491521501862_item	2525217	et	4	main
voi	doc_491521501862_item	2525223	et	4	main
ei	doc_491521501862_item	2525234	et	4	main
pedagigika	doc_491521501862_item	2525241	et	4	main
sonamoodustusviis	doc_491521501862_item	2525247	et	4	main
ja	doc_491521501862_item	2525253	et	3	main
magama	doc_491521501862_item	2525256	et	3	main
parast	doc_491521501862_item	2525258	et	3	main
keelest	doc_491521501862_item	2525263	et	4	main
l1qryt	doc_491521501862_item	2525264	et	4	main
interferents	doc_491521501862_item	2525270	et	3	main
kulas	doc_491521501862_item	2525278	et	3	main
bot	doc_491521501862_item	2525284	et	4	main
a	doc_491521501862_item	2525288	et	4	main
cnywan	doc_491521501862_item	2525290	et	4	main
ei	doc_491521501862_item	2525327	et	4	main
lauset	doc_491521501862_item	2525334	et	3	main
lopp	doc_491521501862_item	2525342	et	4	main
ulearune	doc_491521501862_item	2525359	et	4	main
inimesed	doc_491521501862_item	2525372	et	3	main
seisid	doc_491521501862_item	2525373	et	4	main
vasinud	doc_491521501862_item	2525407	et	4	main
seisma	doc_491521501862_item	2525412	et	3	main
selle	doc_491521501862_item	2525422	et	4	main
eesti	doc_491521501862_item	2525424	et	4	main
on	doc_491521501862_item	2525436	et	4	main
et	doc_491521501862_item	2525441	et	3	main
poes	doc_491521501862_item	2525443	et	3	main
muujaga	doc_491521501862_item	2525445	et	4	main
raagib	doc_491521501862_item	2525446	et	4	main
raekoda	doc_491521501862_item	2525124	et	4	main
sona	doc_491521501862_item	2525135	et	4	main
kokku	doc_491521501862_item	2525137	et	3	main
viisteist	doc_491521501862_item	2525142	et	4	main
laksin	doc_491521501862_item	2525146	et	3	main
on	doc_491521501862_item	2525153	et	4	main
poordes	doc_491521501862_item	2525155	et	4	main
nemad	doc_491521501862_item	2525158	et	3	main
laksid	doc_491521501862_item	2525159	et	4	main
8	doc_491521501862_item	2525160	et	2	main
verbivormide	doc_491521501862_item	2525161	et	4	main
moodustus-	doc_491521501862_item	2525162	et	4	main
ja	doc_491521501862_item	2525163	et	3	main
valiku	doc_491521501862_item	2525164	et	3	main
vead	doc_491521501862_item	2525165	et	4	main
raekoda	doc_491521501862_item	2525166	et	4	main
ehitas	doc_491521501862_item	2525167	et	3	main
peaks	doc_491521501862_item	2525168	et	4	main
olema	doc_491521501862_item	2525169	et	4	main
kaandub	doc_491521501862_item	2525140	et	4	main
uhildu	doc_491521501862_item	2525151	et	4	main
on	doc_491521501862_item	2525171	et	4	main
on	doc_491521501862_item	2525179	et	4	main
siis	doc_491521501862_item	2525195	et	3	main
voimalik	doc_491521501862_item	2525197	et	4	main
poordes	doc_491521501862_item	2525209	et	4	main
kasutama	doc_491521501862_item	2525211	et	3	main
olema	doc_491521501862_item	2525219	et	4	main
tema	doc_491521501862_item	2525220	et	4	main
jai	doc_491521501862_item	2525221	et	4	main
nt	doc_491521501862_item	2525227	et	4	main
rektsiooniviga	doc_491521501862_item	2525231	et	4	main
verbiga	doc_491521501862_item	2525232	et	3	main
on	doc_491521501862_item	2525233	et	4	main
alusel	doc_491521501862_item	2525249	et	4	main
hakkavad	doc_491521501862_item	2525255	et	4	main
sele	doc_491521501862_item	2525257	et	4	main
vasinud	doc_491521501862_item	2525260	et	4	main
otsetolge	doc_491521501862_item	2525261	et	4	main
gi	doc_491521501862_item	2525273	et	4	main
on	doc_491521501862_item	2525279	et	4	main
keelest	doc_491521501862_item	2525283	et	4	main
sarnase	doc_491521501862_item	2525292	et	4	main
raekoda	doc_491521501862_item	2525170	et	4	main
oletan	doc_491521501862_item	2525176	et	3	main
et	doc_491521501862_item	2525177	et	3	main
tegemist	doc_491521501862_item	2525178	et	4	main
mojuga	doc_491521501862_item	2525181	et	4	main
kui	doc_491521501862_item	2525190	et	3	main
lahtus	doc_491521501862_item	2525192	et	3	main
esimesest	doc_491521501862_item	2525193	et	3	main
3	doc_491521501862_item	2525212	et	2	main
tema	doc_491521501862_item	2525224	et	4	main
grippi	doc_491521501862_item	2525228	et	4	main
tohi	doc_491521501862_item	2525235	et	4	main
kasutada	doc_491521501862_item	2525236	et	3	main
ulikoolis	doc_491521501862_item	2525242	et	4	main
analoogia	doc_491521501862_item	2525248	et	4	main
uusmoodustised	doc_491521501862_item	2525254	et	3	main
yctanw	doc_491521501862_item	2525268	et	4	main
ja	doc_491521501862_item	2525271	et	3	main
tubli	doc_491521501862_item	2525280	et	4	main
otsetolge	doc_491521501862_item	2525281	et	4	main
vene	doc_491521501862_item	2525282	et	4	main
m	doc_491521501862_item	2525285	et	4	main
kto	doc_491521501862_item	2525289	et	4	main
lausega	doc_491521501862_item	2525293	et	3	main
loppevad	doc_491521501862_item	2525294	et	4	main
enamasti	doc_491521501862_item	2525295	et	4	main
koik	doc_491521501862_item	2525296	et	4	main
vene	doc_491521501862_item	2525297	et	4	main
muinasjutud	doc_491521501862_item	2525298	et	3	main
ilmselt	doc_491521501862_item	2525299	et	4	main
opilane	doc_491521501862_item	2525300	et	4	main
tahtis	doc_491521501862_item	2525301	et	3	main
lisada	doc_491521501862_item	2525302	et	3	main
varvikust	doc_491521501862_item	2525303	et	4	main
oma	doc_491521501862_item	2525304	et	4	main
jutule	doc_491521501862_item	2525305	et	3	main
autoindust	doc_491521501862_item	2525306	et	4	main
tiglikult	doc_491521501862_item	2525307	et	4	main
voiks	doc_491521501862_item	2525308	et	4	main
seda	doc_491521501862_item	2525309	et	3	main
sona	doc_491521501862_item	2525310	et	4	main
pidada	doc_491521501862_item	2525311	et	4	main
uusmoodustiseks	doc_491521501862_item	2525312	et	3	main
opilane	doc_491521501862_item	2525313	et	4	main
naitas	doc_491521501862_item	2525314	et	4	main
et	doc_491521501862_item	2525315	et	3	main
oskab	doc_491521501862_item	2525316	et	3	main
luua	doc_491521501862_item	2525317	et	4	main
uusi	doc_491521501862_item	2525318	et	3	main
sonu	doc_491521501862_item	2525319	et	4	main
analoogia	doc_491521501862_item	2525320	et	4	main
sona	doc_491521501862_item	2525326	et	4	main
on	doc_491521501862_item	2525339	et	4	main
opilase	doc_491521501862_item	2525348	et	4	main
jutt	doc_491521501862_item	2525349	et	3	main
lopp	doc_491521501862_item	2525357	et	4	main
esineb	doc_491521501862_item	2525361	et	3	main
aga	doc_491521501862_item	2525370	et	3	main
raakidsid	doc_491521501862_item	2525375	et	4	main
peale	doc_491521501862_item	2525408	et	4	main
lopetuseks	doc_491521501862_item	2525418	et	4	main
tahan	doc_491521501862_item	2525419	et	3	main
9	doc_491521501862_item	2525238	et	2	main
emakeele	doc_491521501862_item	2525243	et	4	main
interferents	doc_491521501862_item	2525244	et	3	main
autoindust	doc_491521501862_item	2525245	et	4	main
nt	doc_491521501862_item	2525250	et	4	main
aiandus	doc_491521501862_item	2525251	et	3	main
vene	doc_491521501862_item	2525262	et	4	main
emakeele	doc_491521501862_item	2525269	et	4	main
on	doc_491521501862_item	2525272	et	4	main
juutul	doc_491521501862_item	2525274	et	4	main
lopp	doc_491521501862_item	2525275	et	4	main
aga	doc_491521501862_item	2525276	et	3	main
cka304ke	doc_491521501862_item	2525286	et	4	main
koheu	doc_491521501862_item	2525287	et	4	main
alusel	doc_491521501862_item	2525321	et	4	main
see	doc_491521501862_item	2525323	et	3	main
uus	doc_491521501862_item	2525325	et	3	main
maaral	doc_491521501862_item	2525332	et	3	main
viimast	doc_491521501862_item	2525333	et	4	main
voib	doc_491521501862_item	2525335	et	4	main
stiiliveaks	doc_491521501862_item	2525336	et	3	main
pidada	doc_491521501862_item	2525337	et	4	main
ja	doc_491521501862_item	2525338	et	3	main
aga	doc_491521501862_item	2525343	et	3	main
on	doc_491521501862_item	2525346	et	4	main
on	doc_491521501862_item	2525350	et	4	main
muinasjutu	doc_491521501862_item	2525351	et	3	main
zanrist	doc_491521501862_item	2525352	et	4	main
on	doc_491521501862_item	2525358	et	4	main
olut	doc_491521501862_item	2525369	et	4	main
moned	doc_491521501862_item	2525371	et	4	main
aga	doc_491521501862_item	2525376	et	3	main
peaks	doc_491521501862_item	2525378	et	4	main
peaks	doc_491521501862_item	2525411	et	4	main
hommikul	doc_491521501862_item	2525414	et	3	main
tapsustav	doc_491521501862_item	2525416	et	4	main
ajamaarus	doc_491521501862_item	2525417	et	4	main
oelda	doc_491521501862_item	2525420	et	4	main
opilase	doc_491521501862_item	2525423	et	4	main
see	doc_491521501862_item	2525447	et	3	main
keeles	doc_491521501862_item	2525450	et	4	main
kuid	doc_491521501862_item	2525322	et	4	main
kord	doc_491521501862_item	2525324	et	4	main
leian	doc_491521501862_item	2525329	et	3	main
et	doc_491521501862_item	2525330	et	3	main
gi	doc_491521501862_item	2525340	et	4	main
kes	doc_491521501862_item	2525344	et	4	main
vaga	doc_491521501862_item	2525353	et	4	main
kaugel	doc_491521501862_item	2525354	et	4	main
toos	doc_491521501862_item	2525360	et	3	main
moned	doc_491521501862_item	2525364	et	4	main
istusid	doc_491521501862_item	2525366	et	4	main
joid	doc_491521501862_item	2525368	et	4	main
ees	doc_491521501862_item	2525377	et	4	main
seisma	doc_491521501862_item	2525379	et	3	main
koma	doc_491521501862_item	2525380	et	4	main
oli	doc_491521501862_item	2525381	et	3	main
vaga	doc_491521501862_item	2525382	et	4	main
ilus	doc_491521501862_item	2525383	et	4	main
ilm	doc_491521501862_item	2525384	et	3	main
pilvine	doc_491521501862_item	2525385	et	4	main
aga	doc_491521501862_item	2525386	et	3	main
palav	doc_491521501862_item	2525387	et	4	main
ka	doc_491521501862_item	2525388	et	3	main
siin	doc_491521501862_item	2525389	et	4	main
peaks	doc_491521501862_item	2525390	et	4	main
enne	doc_491521501862_item	2525391	et	4	main
sidesona	doc_491521501862_item	2525392	et	4	main
aga	doc_491521501862_item	2525393	et	3	main
koma	doc_491521501862_item	2525394	et	4	main
seisma	doc_491521501862_item	2525395	et	3	main
perest	doc_491521501862_item	2525396	et	4	main
hommikul	doc_491521501862_item	2525397	et	3	main
nemad	doc_491521501862_item	2525398	et	3	main
lahevad	doc_491521501862_item	2525399	et	4	main
koju	doc_491521501862_item	2525400	et	3	main
ja	doc_491521501862_item	2525401	et	3	main
magama	doc_491521501862_item	2525403	et	3	main
hakkavad	doc_491521501862_item	2525402	et	4	main
sele	doc_491521501862_item	2525404	et	4	main
parast	doc_491521501862_item	2525405	et	3	main
et	doc_491521501862_item	2525406	et	3	main
juutul	doc_491521501862_item	2525341	et	4	main
kulas	doc_491521501862_item	2525345	et	3	main
tubli	doc_491521501862_item	2525347	et	4	main
seega	doc_491521501862_item	2525355	et	4	main
muinasjutuline	doc_491521501862_item	2525356	et	4	main
palju	doc_491521501862_item	2525362	et	4	main
punktuatsioonivigu	doc_491521501862_item	2525363	et	4	main
inimesed	doc_491521501862_item	2525365	et	3	main
ja	doc_491521501862_item	2525367	et	3	main
ja	doc_491521501862_item	2525374	et	3	main
sona	doc_491521501862_item	2525409	et	4	main
parast	doc_491521501862_item	2525410	et	3	main
et	doc_491521501862_item	2525421	et	3	main
oskus	doc_491521501862_item	2525426	et	3	main
soovida	doc_491521501862_item	2525428	et	4	main
tal	doc_491521501862_item	2525429	et	3	main
vaga	doc_491521501862_item	2525437	et	4	main
vaene	doc_491521501862_item	2525438	et	4	main
isegi	doc_491521501862_item	2525442	et	4	main
eestlasest	doc_491521501862_item	2525444	et	3	main
koma	doc_491521501862_item	2525413	et	4	main
on	doc_491521501862_item	2525415	et	4	main
grammatikast	doc_491521501862_item	2525433	et	4	main
kuid	doc_491521501862_item	2525434	et	4	main
sonavara	doc_491521501862_item	2525435	et	4	main
oletada	doc_491521501862_item	2525440	et	3	main
opilane	doc_491521501862_item	2525448	et	4	main
keele	doc_491521501862_item	2525425	et	4	main
jatab	doc_491521501862_item	2525427	et	4	main
on	doc_491521501862_item	2525430	et	4	main
kull	doc_491521501862_item	2525431	et	3	main
algteadmisi	doc_491521501862_item	2525432	et	3	main
julgen	doc_491521501862_item	2525439	et	3	main
vene	doc_491521501862_item	2525449	et	4	main
ev-51	doc_491521501864_item	2526671	et	4	main
nad	doc_491521501864_item	2526685	et	3	main
voimalus	doc_491521501864_item	2526687	et	4	main
toeline	doc_491521501864_item	2526701	et	4	main
veaanaliiiis	doc_491521501864_item	2526668	et	4	main
maris	doc_491521501864_item	2526669	et	3	main
koosnevad	doc_491521501864_item	2526680	et	4	main
kinos	doc_491521501864_item	2526684	et	3	main
arvsona	doc_491521501864_item	2526693	et	4	main
kolm	doc_491521501864_item	2526694	et	3	main
ainsus	doc_491521501864_item	2526695	et	4	main
filmis	doc_491521501864_item	2526696	et	4	main
inimese	doc_491521501864_item	2526700	et	4	main
armastus	doc_491521501864_item	2526702	et	4	main
kui	doc_491521501864_item	2526704	et	3	main
millest	doc_491521501864_item	2526677	et	3	main
need	doc_491521501864_item	2526678	et	3	main
filmis	doc_491521501864_item	2526689	et	4	main
raagitakse	doc_491521501864_item	2526690	et	4	main
on	doc_491521501864_item	2526697	et	4	main
juttu	doc_491521501864_item	2526725	et	4	main
kanal	doc_491521501864_item	2526730	et	4	main
kui	doc_491521501864_item	2526732	et	3	main
lisaks	doc_491521501864_item	2526744	et	4	main
vale	doc_491521501864_item	2526747	et	4	main
substantiivi	doc_491521501864_item	2526754	et	4	main
da-infinitiivi	doc_491521501864_item	2526762	et	4	main
kohakaanete	doc_491521501864_item	2526771	et	4	main
huvitavat	doc_491521501864_item	2526777	et	4	main
ja	doc_491521501864_item	2526783	et	3	main
pildis	doc_491521501864_item	2526785	et	3	main
ortograafiavead	doc_491521501864_item	2526809	et	4	main
mottetes	doc_491521501864_item	2526825	et	4	main
uhildumisviga	doc_491521501864_item	2526844	et	4	main
s	doc_491521501864_item	2526854	et	4	main
oudsalt	doc_491521501864_item	2526857	et	4	main
konekeele	doc_491521501864_item	2526859	et	4	main
ta	doc_491521501864_item	2526865	et	4	main
teise	doc_491521501864_item	2526869	et	4	main
maailma	doc_491521501864_item	2526870	et	4	main
soia	doc_491521501864_item	2526871	et	4	main
puhul	doc_491521501864_item	2526881	et	4	main
kasutatakse	doc_491521501864_item	2526882	et	3	main
lopetatud	doc_491521501864_item	2526893	et	4	main
genitiivi	doc_491521501864_item	2526896	et	4	main
oma	doc_491521501864_item	2526921	et	4	main
armastust	doc_491521501864_item	2526923	et	4	main
ma	doc_491521501864_item	2526924	et	3	main
vaimustan	doc_491521501864_item	2526925	et	3	main
katiava	doc_491521501864_item	2526926	et	4	main
on	doc_491521501864_item	2526939	et	4	main
ka	doc_491521501864_item	2526940	et	3	main
targem	doc_491521501864_item	2526947	et	4	main
laenu	doc_491521501864_item	2526950	et	4	main
ruumid	doc_491521501864_item	2526954	et	4	main
soprust	doc_491521501864_item	2526961	et	4	main
parem	doc_491521501864_item	2526962	et	4	main
kartsin	doc_491521501864_item	2526976	et	3	main
tahtnud	doc_491521501864_item	2526980	et	4	main
toolt	doc_491521501864_item	2526998	et	4	main
keeles	doc_491521501864_item	2527001	et	4	main
segadust	doc_491521501864_item	2527003	et	4	main
ja	doc_491521501864_item	2527005	et	3	main
vead	doc_491521501864_item	2527017	et	4	main
sona-sonaline	doc_491521501864_item	2527020	et	4	main
teatris	doc_491521501864_item	2527024	et	3	main
vale	doc_491521501864_item	2527045	et	4	main
hulluks	doc_491521501864_item	2527051	et	4	main
siin	doc_491521501864_item	2527069	et	4	main
tira	doc_491521501864_item	2527074	et	4	main
kuidas	doc_491521501864_item	2527075	et	3	main
kumbkil	doc_491521501864_item	2527089	et	4	main
kasutatud	doc_491521501864_item	2527106	et	4	main
saates	doc_491521501864_item	2526674	et	4	main
votavad	doc_491521501864_item	2526675	et	4	main
osa	doc_491521501864_item	2526676	et	4	main
naljakat	doc_491521501864_item	2526681	et	3	main
teksti	doc_491521501864_item	2526682	et	4	main
kolmest	doc_491521501864_item	2526691	et	4	main
ulikooliopilastest	doc_491521501864_item	2526692	et	4	main
kujutatud	doc_491521501864_item	2526698	et	4	main
eitus	doc_491521501864_item	2526726	et	4	main
peab	doc_491521501864_item	2526735	et	4	main
viga	doc_491521501864_item	2526746	et	4	main
sonavalik	doc_491521501864_item	2526748	et	4	main
adjektiivi	doc_491521501864_item	2526749	et	4	main
voimalus	doc_491521501864_item	2526756	et	4	main
viga	doc_491521501864_item	2526763	et	4	main
peab	doc_491521501864_item	2526765	et	4	main
koik	doc_491521501864_item	2526766	et	4	main
vastu	doc_491521501864_item	2526767	et	3	main
millele	doc_491521501864_item	2526768	et	3	main
saa	doc_491521501864_item	2526774	et	4	main
samas	doc_491521501864_item	2526780	et	4	main
segamini	doc_491521501864_item	2526795	et	4	main
ja	doc_491521501864_item	2526799	et	3	main
kus	doc_491521501864_item	2526800	et	3	main
i	doc_491521501864_item	2526804	et	4	main
teatris	doc_491521501864_item	2526810	et	3	main
mangivad	doc_491521501864_item	2526811	et	4	main
inimeset	doc_491521501864_item	2526812	et	3	main
austata	doc_491521501864_item	2526822	et	3	main
tekisid	doc_491521501864_item	2526834	et	4	main
koiketega	doc_491521501864_item	2526840	et	4	main
moju	doc_491521501864_item	2526860	et	4	main
teada	doc_491521501864_item	2526867	et	3	main
sunnitab	doc_491521501864_item	2526888	et	4	main
aga	doc_491521501864_item	2526905	et	3	main
ikka	doc_491521501864_item	2526927	et	4	main
tahenduselt	doc_491521501864_item	2526934	et	4	main
rektsiooniviga	doc_491521501864_item	2526941	et	4	main
ise	doc_491521501864_item	2526952	et	4	main
koetma	doc_491521501864_item	2526953	et	4	main
ka	doc_491521501864_item	2526955	et	3	main
uhildumisviga	doc_491521501864_item	2526957	et	4	main
kutta	doc_491521501864_item	2526958	et	4	main
vorm	doc_491521501864_item	2526963	et	3	main
kumme	doc_491521501864_item	2526966	et	3	main
parast	doc_491521501864_item	2526968	et	3	main
aega	doc_491521501864_item	2526984	et	4	main
ja	doc_491521501864_item	2526985	et	3	main
lubas	doc_491521501864_item	2526987	et	3	main
tagasi	doc_491521501864_item	2526994	et	3	main
tagasi	doc_491521501864_item	2526999	et	3	main
tulevikuaspekt	doc_491521501864_item	2527015	et	3	main
sonatasandi	doc_491521501864_item	2527016	et	4	main
saade	doc_491521501864_item	2527019	et	4	main
tolkelaen	doc_491521501864_item	2527021	et	4	main
on	doc_491521501864_item	2527025	et	4	main
aega	doc_491521501864_item	2527035	et	4	main
on	doc_491521501864_item	2527038	et	4	main
sonavalik	doc_491521501864_item	2527046	et	4	main
oskus	doc_491521501864_item	2527047	et	3	main
sonauhendi	doc_491521501864_item	2527053	et	4	main
keeles	doc_491521501864_item	2527062	et	4	main
kasutatakse	doc_491521501864_item	2527063	et	3	main
sonauhendit	doc_491521501864_item	2527064	et	4	main
teises	doc_491521501864_item	2527067	et	4	main
uhildumisvead	doc_491521501864_item	2526666	et	4	main
kontrastiivlingvistika	doc_491521501864_item	2526667	et	4	main
lind	doc_491521501864_item	2526670	et	3	main
uhildumisvead	doc_491521501864_item	2526672	et	4	main
selles	doc_491521501864_item	2526673	et	4	main
sonad	doc_491521501864_item	2526679	et	4	main
millest	doc_491521501864_item	2526683	et	3	main
on	doc_491521501864_item	2526686	et	4	main
kellel	doc_491521501864_item	2526688	et	4	main
kahe	doc_491521501864_item	2526699	et	3	main
mida	doc_491521501864_item	2526703	et	4	main
labi	doc_491521501864_item	2526705	et	4	main
aegade	doc_491521501864_item	2526706	et	3	main
kui	doc_491521501864_item	2526707	et	3	main
labi	doc_491521501864_item	2526708	et	4	main
igasuguseid	doc_491521501864_item	2526709	et	3	main
muudatusi	doc_491521501864_item	2526710	et	3	main
esimeses	doc_491521501864_item	2526711	et	3	main
lausepooles	doc_491521501864_item	2526712	et	3	main
on	doc_491521501864_item	2526713	et	4	main
kasutatud	doc_491521501864_item	2526714	et	4	main
oiget	doc_491521501864_item	2526715	et	4	main
kaandevormi	doc_491521501864_item	2526716	et	4	main
teises	doc_491521501864_item	2526717	et	4	main
pooles	doc_491521501864_item	2526718	et	4	main
on	doc_491521501864_item	2526719	et	4	main
eksitud	doc_491521501864_item	2526720	et	4	main
ma	doc_491521501864_item	2526728	et	3	main
olla	doc_491521501864_item	2526736	et	3	main
ma-	doc_491521501864_item	2526738	et	3	main
ja	doc_491521501864_item	2526739	et	3	main
da-infinitiivi	doc_491521501864_item	2526740	et	4	main
sonatasandi	doc_491521501864_item	2526745	et	4	main
asemel	doc_491521501864_item	2526751	et	4	main
on	doc_491521501864_item	2526752	et	4	main
oma	doc_491521501864_item	2526757	et	4	main
vigu	doc_491521501864_item	2526758	et	3	main
parandama	doc_491521501864_item	2526759	et	3	main
ma-	doc_491521501864_item	2526760	et	3	main
ja	doc_491521501864_item	2526761	et	3	main
ei	doc_491521501864_item	2526773	et	4	main
uhildumis-	doc_491521501864_item	2526782	et	4	main
hooletusviga	doc_491521501864_item	2526784	et	4	main
kaks	doc_491521501864_item	2526787	et	3	main
tuba	doc_491521501864_item	2526788	et	4	main
elutoas	doc_491521501864_item	2526789	et	3	main
kusimused	doc_491521501864_item	2526797	et	4	main
uhtus	doc_491521501864_item	2526805	et	4	main
sa	doc_491521501864_item	2526814	et	3	main
ole	doc_491521501864_item	2526722	et	4	main
naljaka	doc_491521501864_item	2526724	et	3	main
film	doc_491521501864_item	2526734	et	3	main
ebaoige	doc_491521501864_item	2526741	et	3	main
kasutus	doc_491521501864_item	2526742	et	4	main
milline	doc_491521501864_item	2526750	et	3	main
on	doc_491521501864_item	2526755	et	4	main
ta	doc_491521501864_item	2526764	et	4	main
vead	doc_491521501864_item	2526772	et	4	main
selles	doc_491521501864_item	2526778	et	4	main
teemal	doc_491521501864_item	2526779	et	3	main
kohakaanete	doc_491521501864_item	2526796	et	4	main
kaandevead	doc_491521501864_item	2526802	et	4	main
mida	doc_491521501864_item	2526803	et	4	main
haaldus-	doc_491521501864_item	2526807	et	4	main
ia	doc_491521501864_item	2526808	et	4	main
hakkad	doc_491521501864_item	2526815	et	3	main
kiiresti	doc_491521501864_item	2526816	et	3	main
kanaale	doc_491521501864_item	2526817	et	4	main
vahetama	doc_491521501864_item	2526818	et	3	main
otsene	doc_491521501864_item	2526819	et	3	main
vene	doc_491521501864_item	2526820	et	4	main
midagi	doc_491521501864_item	2526826	et	4	main
viis	doc_491521501864_item	2526828	et	4	main
keele	doc_491521501864_item	2526831	et	4	main
haaldusparane	doc_491521501864_item	2526832	et	4	main
kirjapilt	doc_491521501864_item	2526833	et	3	main
peaksin	doc_491521501864_item	2526838	et	4	main
arvestama	doc_491521501864_item	2526839	et	3	main
kaande	doc_491521501864_item	2526843	et	3	main
on	doc_491521501864_item	2526846	et	4	main
proffessorid	doc_491521501864_item	2526848	et	4	main
tootab	doc_491521501864_item	2526849	et	4	main
rezisoorina	doc_491521501864_item	2526850	et	4	main
oma	doc_491521501864_item	2526853	et	4	main
kirjutamisvead	doc_491521501864_item	2526862	et	3	main
kord	doc_491521501864_item	2526864	et	4	main
saab	doc_491521501864_item	2526866	et	3	main
koguaeg	doc_491521501864_item	2526868	et	3	main
lulitanud	doc_491521501864_item	2526877	et	4	main
teleri	doc_491521501864_item	2526878	et	3	main
valja	doc_491521501864_item	2526879	et	3	main
eituse	doc_491521501864_item	2526880	et	4	main
telerit	doc_491521501864_item	2526887	et	3	main
puhul	doc_491521501864_item	2526895	et	4	main
ei	doc_491521501864_item	2526902	et	4	main
vaita	doc_491521501864_item	2526903	et	4	main
et	doc_491521501864_item	2526904	et	3	main
ei	doc_491521501864_item	2526721	et	4	main
mingisugust	doc_491521501864_item	2526723	et	3	main
partitiiv	doc_491521501864_item	2526727	et	3	main
vaatan	doc_491521501864_item	2526729	et	3	main
vaatamamida	doc_491521501864_item	2526731	et	4	main
vaatate	doc_491521501864_item	2526733	et	3	main
leidlikkus	doc_491521501864_item	2526737	et	4	main
ja	doc_491521501864_item	2526743	et	3	main
kasutatud	doc_491521501864_item	2526753	et	4	main
vastu	doc_491521501864_item	2526769	et	3	main
pidama	doc_491521501864_item	2526770	et	4	main
kirjutada	doc_491521501864_item	2526775	et	3	main
muud	doc_491521501864_item	2526776	et	4	main
ka	doc_491521501864_item	2526781	et	3	main
on	doc_491521501864_item	2526786	et	4	main
paneksin	doc_491521501864_item	2526790	et	3	main
suure	doc_491521501864_item	2526791	et	3	main
vaiba	doc_491521501864_item	2526792	et	3	main
mitte-eestlased	doc_491521501864_item	2526793	et	3	main
ajavad	doc_491521501864_item	2526794	et	4	main
kuhu	doc_491521501864_item	2526798	et	3	main
muud	doc_491521501864_item	2526801	et	4	main
edasi	doc_491521501864_item	2526806	et	3	main
kui	doc_491521501864_item	2526813	et	3	main
moju	doc_491521501864_item	2526821	et	4	main
inimesi	doc_491521501864_item	2526823	et	4	main
kujutad	doc_491521501864_item	2526824	et	3	main
omaparast	doc_491521501864_item	2526827	et	3	main
minuutit	doc_491521501864_item	2526829	et	4	main
vene	doc_491521501864_item	2526830	et	4	main
astmevaheldusviga	doc_491521501864_item	2526837	et	4	main
asjatega	doc_491521501864_item	2526841	et	4	main
vanemad	doc_491521501864_item	2526845	et	4	main
kuulsad	doc_491521501864_item	2526847	et	3	main
kutsuta	doc_491521501864_item	2526852	et	4	main
minule	doc_491521501864_item	2526856	et	3	main
kokku-lahku	doc_491521501864_item	2526861	et	4	main
partitiivivormi	doc_491521501864_item	2526883	et	4	main
isa	doc_491521501864_item	2526884	et	4	main
keeles	doc_491521501864_item	2526891	et	4	main
vormi	doc_491521501864_item	2526897	et	4	main
verbivormide	doc_491521501864_item	2526898	et	4	main
valiku	doc_491521501864_item	2526899	et	3	main
vead	doc_491521501864_item	2526900	et	4	main
aga	doc_491521501864_item	2526901	et	3	main
rohkem	doc_491521501864_item	2526928	et	4	main
eksivad	doc_491521501864_item	2526930	et	4	main
sarnaste	doc_491521501864_item	2526932	et	4	main
tahaksin	doc_491521501864_item	2526951	et	3	main
kumne	doc_491521501864_item	2526969	et	4	main
tunned	doc_491521501864_item	2526970	et	3	main
olid	doc_491521501864_item	2526971	et	4	main
vaadata	doc_491521501864_item	2526977	et	4	main
ei	doc_491521501864_item	2526982	et	4	main
ta	doc_491521501864_item	2526986	et	4	main
teha	doc_491521501864_item	2526989	et	3	main
kui	doc_491521501864_item	2526990	et	3	main
kui	doc_491521501864_item	2526995	et	3	main
eesti	doc_491521501864_item	2527000	et	4	main
oleviku	doc_491521501864_item	2527006	et	3	main
viga	doc_491521501864_item	2527034	et	4	main
loovus	doc_491521501864_item	2527037	et	4	main
ig	doc_491521501864_item	2527041	et	4	main
mused	doc_491521501864_item	2527042	et	4	main
midagi	doc_491521501864_item	2527043	et	4	main
mitte	doc_491521501864_item	2527050	et	3	main
lkbi	doc_491521501864_item	2527065	et	4	main
tahenduses	doc_491521501864_item	2527068	et	4	main
sobiks	doc_491521501864_item	2527070	et	4	main
film	doc_491521501864_item	2527072	et	3	main
tugev	doc_491521501864_item	2527079	et	4	main
sober	doc_491521501864_item	2527088	et	4	main
laheks	doc_491521501864_item	2527091	et	4	main
eluline	doc_491521501864_item	2527100	et	4	main
tema	doc_491521501864_item	2527116	et	4	main
petmist-	doc_491521501864_item	2527117	et	4	main
pole	doc_491521501864_item	2527118	et	3	main
vead	doc_491521501864_item	2527134	et	4	main
vaatan	doc_491521501864_item	2527135	et	3	main
televiisorit	doc_491521501864_item	2527136	et	3	main
ja	doc_491521501864_item	2527137	et	3	main
oj	doc_491521501864_item	2527138	et	4	main
nende	doc_491521501864_item	2526835	et	4	main
vahel	doc_491521501864_item	2526836	et	4	main
ka	doc_491521501864_item	2526842	et	3	main
otsustavad	doc_491521501864_item	2526851	et	4	main
obraid	doc_491521501864_item	2526855	et	4	main
meeldis	doc_491521501864_item	2526858	et	3	main
uks	doc_491521501864_item	2526863	et	3	main
ajal	doc_491521501864_item	2526872	et	4	main
nii	doc_491521501864_item	2526873	et	3	main
siis	doc_491521501864_item	2526874	et	3	main
objektivead	doc_491521501864_item	2526875	et	4	main
ei	doc_491521501864_item	2526876	et	4	main
ostis	doc_491521501864_item	2526885	et	4	main
uut	doc_491521501864_item	2526886	et	3	main
last-	doc_491521501864_item	2526889	et	4	main
eesti	doc_491521501864_item	2526890	et	4	main
kasutatakse	doc_491521501864_item	2526892	et	3	main
tegevuse	doc_491521501864_item	2526894	et	4	main
ma	doc_491521501864_item	2526906	et	3	main
ei	doc_491521501864_item	2526907	et	4	main
eita	doc_491521501864_item	2526908	et	4	main
et	doc_491521501864_item	2526909	et	3	main
kui	doc_491521501864_item	2526910	et	3	main
saada	doc_491521501864_item	2526911	et	4	main
autori	doc_491521501864_item	2526912	et	3	main
motteid	doc_491521501864_item	2526913	et	4	main
selleks	doc_491521501864_item	2526914	et	4	main
et	doc_491521501864_item	2526915	et	3	main
aru	doc_491521501864_item	2526916	et	4	main
saada	doc_491521501864_item	2526917	et	4	main
autori	doc_491521501864_item	2526918	et	3	main
motteist	doc_491521501864_item	2526919	et	4	main
kohtub	doc_491521501864_item	2526920	et	3	main
mitte-eestlased	doc_491521501864_item	2526929	et	3	main
kolaliselt	doc_491521501864_item	2526931	et	4	main
aga	doc_491521501864_item	2526933	et	3	main
sonade	doc_491521501864_item	2526936	et	4	main
siin	doc_491521501864_item	2526938	et	4	main
tugevam	doc_491521501864_item	2526945	et	4	main
ja	doc_491521501864_item	2526946	et	3	main
verbi	doc_491521501864_item	2526956	et	4	main
mida	doc_491521501864_item	2526959	et	4	main
oleks	doc_491521501864_item	2526964	et	3	main
moodustusvead	doc_491521501864_item	2526975	et	4	main
vaga	doc_491521501864_item	2526979	et	4	main
isal	doc_491521501864_item	2526981	et	3	main
seda	doc_491521501864_item	2526988	et	3	main
ta	doc_491521501864_item	2526991	et	4	main
tuli	doc_491521501864_item	2526992	et	4	main
ta	doc_491521501864_item	2526996	et	4	main
ebaonnetu	doc_491521501864_item	2527018	et	4	main
esimest	doc_491521501864_item	2526922	et	4	main
erinevate	doc_491521501864_item	2526935	et	4	main
valikul	doc_491521501864_item	2526937	et	3	main
ta	doc_491521501864_item	2526942	et	4	main
hakkas	doc_491521501864_item	2526943	et	3	main
olema	doc_491521501864_item	2526944	et	4	main
vormimoodustusvead	doc_491521501864_item	2526948	et	4	main
andaksin	doc_491521501864_item	2526949	et	4	main
pidavad	doc_491521501864_item	2526960	et	4	main
sobrustavad	doc_491521501864_item	2526965	et	4	main
aasta	doc_491521501864_item	2526967	et	4	main
piihendatud	doc_491521501864_item	2526972	et	4	main
tunded	doc_491521501864_item	2526973	et	3	main
verbivormide	doc_491521501864_item	2526974	et	4	main
aga	doc_491521501864_item	2526978	et	3	main
olnud	doc_491521501864_item	2526983	et	4	main
toolt	doc_491521501864_item	2526993	et	4	main
tuleb	doc_491521501864_item	2526997	et	3	main
tekitab	doc_491521501864_item	2527002	et	3	main
mineviku	doc_491521501864_item	2527004	et	3	main
vormi	doc_491521501864_item	2527007	et	4	main
paralleelne	doc_491521501864_item	2527008	et	3	main
kasutus	doc_491521501864_item	2527009	et	4	main
uhes	doc_491521501864_item	2527010	et	4	main
lauses	doc_491521501864_item	2527011	et	3	main
kui	doc_491521501864_item	2527012	et	3	main
on	doc_491521501864_item	2527013	et	4	main
mangus	doc_491521501864_item	2527014	et	3	main
vene	doc_491521501864_item	2527022	et	4	main
votab	doc_491521501864_item	2527030	et	4	main
votma	doc_491521501864_item	2527036	et	4	main
inimese	doc_491521501864_item	2527039	et	4	main
tin	doc_491521501864_item	2527040	et	4	main
voime	doc_491521501864_item	2527048	et	4	main
et	doc_491521501864_item	2527049	et	3	main
saada	doc_491521501864_item	2527052	et	4	main
viga	doc_491521501864_item	2527054	et	4	main
hulluks	doc_491521501864_item	2527055	et	4	main
minema	doc_491521501864_item	2527056	et	3	main
kui	doc_491521501864_item	2527057	et	3	main
vaatasin	doc_491521501864_item	2527058	et	3	main
vois	doc_491521501864_item	2527076	et	4	main
nel	doc_491521501864_item	2527086	et	4	main
pronoomenivead	doc_491521501864_item	2527096	et	4	main
see	doc_491521501864_item	2527097	et	3	main
film	doc_491521501864_item	2527098	et	3	main
on	doc_491521501864_item	2527099	et	4	main
vaga	doc_491521501864_item	2527105	et	4	main
keelest	doc_491521501864_item	2527023	et	4	main
antrakt	doc_491521501864_item	2527026	et	3	main
vaheaeg	doc_491521501864_item	2527027	et	3	main
tolkelaen	doc_491521501864_item	2527028	et	4	main
see	doc_491521501864_item	2527029	et	3	main
15	doc_491521501864_item	2527031	et	2	main
tundi	doc_491521501864_item	2527032	et	4	main
sonauhendi	doc_491521501864_item	2527033	et	4	main
luua	doc_491521501864_item	2527044	et	4	main
filmi	doc_491521501864_item	2527059	et	4	main
labi	doc_491521501864_item	2527060	et	4	main
eesti	doc_491521501864_item	2527061	et	4	main
vaatama	doc_491521501864_item	2527066	et	3	main
olla	doc_491521501864_item	2527077	et	3	main
sonavaliku	doc_491521501864_item	2527081	et	4	main
isiksus	doc_491521501864_item	2527083	et	3	main
neist	doc_491521501864_item	2527090	et	4	main
hasti	doc_491521501864_item	2527092	et	4	main
kummagil	doc_491521501864_item	2527093	et	4	main
voi	doc_491521501864_item	2527094	et	4	main
molemal	doc_491521501864_item	2527095	et	4	main
ta	doc_491521501864_item	2527102	et	4	main
mind	doc_491521501864_item	2527104	et	4	main
asesona	doc_491521501864_item	2527107	et	4	main
ta	doc_491521501864_item	2527108	et	4	main
elutu	doc_491521501864_item	2527109	et	4	main
nahtuse	doc_491521501864_item	2527110	et	4	main
kohta	doc_491521501864_item	2527111	et	4	main
enesekohast	doc_491521501864_item	2527120	et	4	main
pronoomenit	doc_491521501864_item	2527121	et	3	main
on	doc_491521501864_item	2527129	et	4	main
tee	doc_491521501864_item	2527140	et	4	main
isiku	doc_491521501864_item	2527152	et	3	main
arvestatud	doc_491521501864_item	2527161	et	4	main
kreativsele	doc_491521501864_item	2527162	et	4	main
on	doc_491521501864_item	2527177	et	4	main
palju	doc_491521501864_item	2527178	et	4	main
anglitsisme	doc_491521501864_item	2527179	et	3	main
lisaks	doc_491521501864_item	2527180	et	4	main
vene	doc_491521501864_item	2527181	et	4	main
keeleklassidega	doc_491521501864_item	2527197	et	3	main
aktiivselt	doc_491521501864_item	2527204	et	4	main
kirjalikes	doc_491521501864_item	2527205	et	3	main
veaanalitijs	doc_491521501865_item	2527211	et	4	main
eraopilase	doc_491521501865_item	2527232	et	4	main
konet	doc_491521501865_item	2527236	et	3	main
eesti	doc_491521501865_item	2527247	et	4	main
ning	doc_491521501865_item	2527252	et	3	main
korraldada	doc_491521501865_item	2527266	et	3	main
iseloomustus	doc_491521501865_item	2527268	et	4	main
aleksandr	doc_491521501865_item	2527271	et	4	main
emakeel	doc_491521501865_item	2527307	et	4	main
on	doc_491521501865_item	2527308	et	4	main
keelt	doc_491521501865_item	2527317	et	4	main
oppis	doc_491521501865_item	2527319	et	4	main
selgeks	doc_491521501865_item	2527321	et	3	main
iilikooli	doc_491521501865_item	2527326	et	4	main
oppis	doc_491521501865_item	2527328	et	4	main
aleksandr	doc_491521501865_item	2527335	et	4	main
aleksandr	doc_491521501865_item	2527340	et	4	main
iseseisvalt	doc_491521501865_item	2527343	et	4	main
jargi	doc_491521501865_item	2527349	et	4	main
ja	doc_491521501865_item	2527350	et	3	main
puudis	doc_491521501865_item	2527351	et	3	main
30-aastasena	doc_491521501865_item	2527356	et	4	main
ei	doc_491521501865_item	2527380	et	4	main
vaatasin	doc_491521501864_item	2527071	et	3	main
i	doc_491521501864_item	2527073	et	4	main
nii	doc_491521501864_item	2527078	et	3	main
isik	doc_491521501864_item	2527080	et	3	main
viga	doc_491521501864_item	2527082	et	4	main
sh	doc_491521501864_item	2527084	et	4	main
sonamoodustusvead	doc_491521501864_item	2527085	et	4	main
aialguline	doc_491521501864_item	2527087	et	4	main
lugu	doc_491521501864_item	2527101	et	4	main
tabas	doc_491521501864_item	2527103	et	4	main
ta	doc_491521501864_item	2527112	et	4	main
kasutatud	doc_491521501864_item	2527119	et	4	main
muud	doc_491521501864_item	2527133	et	4	main
ajad	doc_491521501864_item	2527141	et	4	main
ei	doc_491521501864_item	2527142	et	4	main
osas	doc_491521501864_item	2527148	et	4	main
verbi	doc_491521501864_item	2527155	et	4	main
arvestatud-moeldud	doc_491521501864_item	2527183	et	4	main
on	doc_491521501864_item	2527185	et	4	main
lklassist	doc_491521501864_item	2527192	et	4	main
tugevate	doc_491521501864_item	2527196	et	4	main
opilased	doc_491521501864_item	2527198	et	4	main
toodes	doc_491521501864_item	2527206	et	3	main
grammatika-	doc_491521501864_item	2527208	et	4	main
ja	doc_491521501864_item	2527209	et	3	main
kontrastiivlingvistikas	doc_491521501865_item	2527216	et	4	main
ei	doc_491521501864_item	2527113	et	4	main
saa	doc_491521501864_item	2527114	et	4	main
andestada	doc_491521501864_item	2527115	et	3	main
sonajarievead	doc_491521501864_item	2527123	et	4	main
see	doc_491521501864_item	2527130	et	3	main
fantastiline	doc_491521501864_item	2527131	et	4	main
film	doc_491521501864_item	2527132	et	3	main
teises	doc_491521501864_item	2527147	et	4	main
poordeloppu	doc_491521501864_item	2527153	et	4	main
jooma	doc_491521501864_item	2527157	et	4	main
mitte-eestlaste	doc_491521501864_item	2527175	et	4	main
konepruugis	doc_491521501864_item	2527176	et	4	main
materjal	doc_491521501864_item	2527184	et	3	main
gumnaasiumi	doc_491521501864_item	2527189	et	4	main
l0ja	doc_491521501864_item	2527190	et	4	main
tegemist	doc_491521501864_item	2527193	et	4	main
suhtlevad	doc_491521501864_item	2527202	et	4	main
pedagoogikaiilikool	doc_491521501865_item	2527213	et	4	main
veaanalitijs	doc_491521501865_item	2527214	et	4	main
suhhorukova	doc_491521501865_item	2527219	et	4	main
ev-51	doc_491521501865_item	2527220	et	4	main
tallinn	doc_491521501865_item	2527221	et	4	main
talle	doc_491521501865_item	2527246	et	4	main
algusest	doc_491521501865_item	2527251	et	4	main
oli	doc_491521501865_item	2527254	et	3	main
paremini	doc_491521501865_item	2527265	et	4	main
keeleoskus	doc_491521501865_item	2527270	et	3	main
47-aastane	doc_491521501865_item	2527273	et	4	main
aleksandri	doc_491521501865_item	2527306	et	4	main
raagib	doc_491521501865_item	2527313	et	4	main
ta	doc_491521501865_item	2527314	et	4	main
kuna	doc_491521501865_item	2527318	et	3	main
lapsepolves	doc_491521501865_item	2527323	et	4	main
ja	doc_491521501865_item	2527325	et	3	main
saksa	doc_491521501865_item	2527330	et	4	main
iseseisvalt	doc_491521501865_item	2527336	et	4	main
oma	doc_491521501865_item	2527353	et	4	main
kones	doc_491521501865_item	2527354	et	3	main
toopaeviti	doc_491521501865_item	2527366	et	4	main
kaupa	doc_491521501865_item	2527369	et	4	main
kursus	doc_491521501865_item	2527373	et	3	main
kasulik	doc_491521501865_item	2527374	et	3	main
ta	doc_491521501865_item	2527382	et	4	main
1997	doc_491521501865_item	2527391	et	2	main
jalle	doc_491521501865_item	2527433	et	4	main
minna	doc_491521501865_item	2527435	et	3	main
tasemeeksamiteks	doc_491521501865_item	2527444	et	3	main
soovitasid	doc_491521501865_item	2527458	et	4	main
keelt	doc_491521501865_item	2527465	et	4	main
mis	doc_491521501865_item	2527479	et	4	main
moodunud	doc_491521501865_item	2527481	et	4	main
seejarel	doc_491521501865_item	2527489	et	4	main
seejarel	doc_491521501865_item	2527499	et	4	main
tegeleme	doc_491521501865_item	2527500	et	3	main
loeme	doc_491521501865_item	2527502	et	3	main
kuigi	doc_491521501865_item	2527510	et	3	main
on	doc_491521501865_item	2527512	et	4	main
tugev	doc_491521501865_item	2527514	et	4	main
et	doc_491521501865_item	2527528	et	3	main
on	doc_491521501865_item	2527530	et	4	main
taiesti	doc_491521501865_item	2527532	et	4	main
eesti	doc_491521501865_item	2527553	et	4	main
aleksandri	doc_491521501865_item	2527566	et	4	main
tase	doc_491521501865_item	2527568	et	3	main
grammatikareegleid	doc_491521501865_item	2527570	et	3	main
hasti	doc_491521501865_item	2527574	et	4	main
grammatikavigu	doc_491521501865_item	2527584	et	3	main
uhildumis-	doc_491521501865_item	2527586	et	4	main
rektsioonivigu	doc_491521501865_item	2527588	et	4	main
enda	doc_491521501864_item	2527122	et	4	main
alati	doc_491521501864_item	2527124	et	4	main
koos	doc_491521501864_item	2527125	et	4	main
veedavad	doc_491521501864_item	2527126	et	3	main
aega	doc_491521501864_item	2527127	et	4	main
toepoolest	doc_491521501864_item	2527128	et	4	main
uhildu	doc_491521501864_item	2527143	et	4	main
ei	doc_491521501864_item	2527149	et	4	main
kasutata	doc_491521501864_item	2527150	et	3	main
esimese	doc_491521501864_item	2527151	et	3	main
inimestele	doc_491521501864_item	2527163	et	3	main
kaandeviga	doc_491521501864_item	2527164	et	4	main
kasutatud	doc_491521501864_item	2527165	et	4	main
ainsust	doc_491521501864_item	2527166	et	4	main
ja	doc_491521501864_item	2527167	et	3	main
mitmust	doc_491521501864_item	2527168	et	3	main
koos	doc_491521501864_item	2527169	et	4	main
uhes	doc_491521501864_item	2527170	et	4	main
sonauhendis	doc_491521501864_item	2527171	et	4	main
tolkelaen	doc_491521501864_item	2527172	et	4	main
inglise	doc_491521501864_item	2527173	et	4	main
keelest	doc_491521501864_item	2527174	et	4	main
i	doc_491521501864_item	2527139	et	4	main
uhes	doc_491521501864_item	2527144	et	4	main
lauses	doc_491521501864_item	2527145	et	3	main
lause	doc_491521501864_item	2527146	et	4	main
lisaks	doc_491521501864_item	2527154	et	4	main
uhildumisviga	doc_491521501864_item	2527156	et	4	main
mida	doc_491521501864_item	2527158	et	4	main
kunstid	doc_491521501864_item	2527159	et	3	main
on	doc_491521501864_item	2527160	et	4	main
moju	doc_491521501864_item	2527182	et	4	main
l	doc_491521501864_item	2527191	et	4	main
tunnis	doc_491521501864_item	2527203	et	3	main
esineb	doc_491521501864_item	2527207	et	3	main
tallinna	doc_491521501865_item	2527212	et	4	main
kodutoo	doc_491521501865_item	2527215	et	4	main
et	doc_491521501865_item	2527224	et	3	main
veaanaluusi	doc_491521501865_item	2527226	et	4	main
olen	doc_491521501865_item	2527227	et	3	main
otsustanud	doc_491521501865_item	2527228	et	4	main
aleksandri	doc_491521501865_item	2527234	et	4	main
sellise	doc_491521501865_item	2527237	et	4	main
langetamisele	doc_491521501865_item	2527239	et	4	main
aitas	doc_491521501865_item	2527240	et	3	main
kaasa	doc_491521501865_item	2527241	et	4	main
asjaolu	doc_491521501865_item	2527242	et	4	main
et	doc_491521501865_item	2527243	et	3	main
hakkasin	doc_491521501865_item	2527244	et	3	main
opetama	doc_491521501865_item	2527245	et	4	main
mul	doc_491521501865_item	2527253	et	3	main
endal	doc_491521501865_item	2527255	et	4	main
tema	doc_491521501865_item	2527257	et	4	main
vigu	doc_491521501865_item	2527258	et	3	main
ruhmitada	doc_491521501865_item	2527259	et	4	main
ja	doc_491521501865_item	2527260	et	3	main
analuusida	doc_491521501865_item	2527261	et	4	main
et	doc_491521501865_item	2527262	et	3	main
edaspidist	doc_491521501865_item	2527263	et	3	main
oppetood	doc_491521501865_item	2527264	et	4	main
direktor	doc_491521501865_item	2527305	et	3	main
kuid	doc_491521501865_item	2527311	et	4	main
samuti	doc_491521501865_item	2527312	et	3	main
kooli	doc_491521501865_item	2527324	et	4	main
keelt	doc_491521501865_item	2527333	et	4	main
oppis	doc_491521501865_item	2527334	et	4	main
keelt	doc_491521501865_item	2527338	et	4	main
hakkas	doc_491521501865_item	2527339	et	3	main
kasutada	doc_491521501865_item	2527355	et	3	main
tunni	doc_491521501865_item	2527368	et	3	main
oli	doc_491521501865_item	2527372	et	3	main
eriti	doc_491521501865_item	2527375	et	3	main
aastatel	doc_491521501865_item	2527379	et	4	main
keelega	doc_491521501865_item	2527384	et	3	main
uldse	doc_491521501865_item	2527385	et	4	main
kuna	doc_491521501865_item	2527386	et	3	main
elas	doc_491521501865_item	2527387	et	3	main
ja	doc_491521501865_item	2527388	et	3	main
tootas	doc_491521501865_item	2527389	et	4	main
eestisse	doc_491521501865_item	2527395	et	4	main
tagasi	doc_491521501865_item	2527396	et	3	main
ning	doc_491521501865_item	2527397	et	3	main
tanavu	doc_491521501865_item	2527429	et	4	main
siigisel	doc_491521501865_item	2527430	et	4	main
ei	doc_491521501865_item	2527438	et	4	main
eesmark	doc_491521501865_item	2527446	et	3	main
et	doc_491521501865_item	2527450	et	3	main
tellijatega	doc_491521501865_item	2527452	et	4	main
talle	doc_491521501865_item	2527459	et	4	main
mind	doc_491521501865_item	2527460	et	4	main
nii	doc_491521501865_item	2527461	et	3	main
meie	doc_491521501865_item	2527467	et	4	main
tund	doc_491521501865_item	2527468	et	3	main
on	doc_491521501865_item	2527469	et	4	main
tundi	doc_491521501865_item	2527475	et	4	main
paevade	doc_491521501865_item	2527482	et	4	main
on	doc_491521501865_item	2527495	et	4	main
minuga	doc_491521501865_item	2527496	et	3	main
vestleme	doc_491521501865_item	2527505	et	3	main
opimotivatsioon	doc_491521501865_item	2527507	et	4	main
enesehinnang	doc_491521501865_item	2527509	et	3	main
aleksandril	doc_491521501865_item	2527511	et	4	main
keele	doc_491521501865_item	2527516	et	4	main
ta	doc_491521501865_item	2527529	et	4	main
kogutud	doc_491521501864_item	2527186	et	4	main
praktikatundidest	doc_491521501864_item	2527187	et	3	main
vene	doc_491521501864_item	2527188	et	4	main
on	doc_491521501864_item	2527194	et	4	main
kooli	doc_491521501864_item	2527195	et	4	main
on	doc_491521501864_item	2527199	et	4	main
laialdaste	doc_491521501864_item	2527200	et	3	main
huvidega	doc_491521501864_item	2527201	et	3	main
sonavalikuvigu	doc_491521501864_item	2527210	et	4	main
natalj	doc_491521501865_item	2527217	et	4	main
a	doc_491521501865_item	2527218	et	4	main
kommentaar	doc_491521501865_item	2527223	et	3	main
teha	doc_491521501865_item	2527225	et	3	main
oma	doc_491521501865_item	2527231	et	4	main
edaspidi	doc_491521501865_item	2527233	et	3	main
otsuse	doc_491521501865_item	2527238	et	3	main
alles	doc_491521501865_item	2527249	et	3	main
huvitav	doc_491521501865_item	2527256	et	4	main
on	doc_491521501865_item	2527272	et	4	main
ukraina	doc_491521501865_item	2527274	et	4	main
venelane	doc_491521501865_item	2527275	et	3	main
vene	doc_491521501865_item	2527309	et	4	main
vabalt	doc_491521501865_item	2527315	et	4	main
selle	doc_491521501865_item	2527320	et	4	main
ajal	doc_491521501865_item	2527327	et	4	main
samuti	doc_491521501865_item	2527342	et	3	main
neid	doc_491521501865_item	2527352	et	4	main
pool	doc_491521501865_item	2527359	et	4	main
nelja	doc_491521501865_item	2527367	et	4	main
tegelenud	doc_491521501865_item	2527381	et	4	main
venemaal	doc_491521501865_item	2527390	et	4	main
tuli	doc_491521501865_item	2527393	et	4	main
telerist	doc_491521501865_item	2527422	et	4	main
eratunde	doc_491521501865_item	2527428	et	4	main
tahtis	doc_491521501865_item	2527431	et	3	main
ta	doc_491521501865_item	2527432	et	4	main
sobinud	doc_491521501865_item	2527439	et	4	main
et	doc_491521501865_item	2527440	et	3	main
seal	doc_491521501865_item	2527441	et	4	main
opetatakse	doc_491521501865_item	2527442	et	4	main
ainult	doc_491521501865_item	2527443	et	4	main
on	doc_491521501865_item	2527447	et	4	main
vabalt	doc_491521501865_item	2527453	et	4	main
suhelda	doc_491521501865_item	2527454	et	4	main
meie	doc_491521501865_item	2527455	et	4	main
uhised	doc_491521501865_item	2527456	et	3	main
hakkasingi	doc_491521501865_item	2527462	et	3	main
talle	doc_491521501865_item	2527463	et	4	main
pool	doc_491521501865_item	2527474	et	4	main
raagib	doc_491521501865_item	2527477	et	4	main
juhtus	doc_491521501865_item	2527480	et	3	main
jooksul	doc_491521501865_item	2527483	et	4	main
ning	doc_491521501865_item	2527484	et	3	main
laks	doc_491521501865_item	2527486	et	4	main
tanane	doc_491521501865_item	2527487	et	4	main
huvitavat	doc_491521501865_item	2527494	et	4	main
grammatikaga	doc_491521501865_item	2527501	et	3	main
eesti	doc_491521501865_item	2527515	et	4	main
keeleoskuse	doc_491521501865_item	2527522	et	3	main
vaga	doc_491521501865_item	2527524	et	4	main
kriitiline	doc_491521501865_item	2527525	et	3	main
ta	doc_491521501865_item	2527526	et	4	main
enamik	doc_491521501865_item	2527544	et	3	main
keeles	doc_491521501865_item	2527554	et	4	main
osata	doc_491521501865_item	2527563	et	4	main
usna	doc_491521501865_item	2527573	et	4	main
grammatikaulesandeid	doc_491521501865_item	2527575	et	4	main
teeb	doc_491521501865_item	2527576	et	3	main
peaaegu	doc_491521501865_item	2527578	et	3	main
tema	doc_491521501865_item	2527581	et	4	main
infinitiivi	doc_491521501865_item	2527592	et	4	main
nu	doc_491521501865_item	2527621	et	4	main
tema	doc_491521501865_item	2527632	et	4	main
konele	doc_491521501865_item	2527633	et	3	main
domineerivad	doc_491521501865_item	2527640	et	4	main
sagedased	doc_491521501865_item	2527642	et	3	main
kolaliselt	doc_491521501865_item	2527658	et	4	main
sarnaseid	doc_491521501865_item	2527659	et	4	main
jaoks	doc_491521501865_item	2527669	et	4	main
haalikuuhendid	doc_491521501865_item	2527670	et	4	main
ou-	doc_491521501865_item	2527673	et	4	main
2001	doc_491521501865_item	2527222	et	2	main
lindistada	doc_491521501865_item	2527229	et	3	main
uhe	doc_491521501865_item	2527230	et	4	main
spontaanset	doc_491521501865_item	2527235	et	3	main
keelt	doc_491521501865_item	2527248	et	4	main
novembri	doc_491521501865_item	2527250	et	3	main
aleksandri	doc_491521501865_item	2527267	et	4	main
ja	doc_491521501865_item	2527269	et	3	main
ta	doc_491521501865_item	2527276	et	4	main
on	doc_491521501865_item	2527277	et	4	main
sundinud	doc_491521501865_item	2527278	et	4	main
1955	doc_491521501865_item	2527279	et	2	main
aastal	doc_491521501865_item	2527280	et	3	main
harkovis	doc_491521501865_item	2527281	et	4	main
lopetades	doc_491521501865_item	2527282	et	4	main
ulikooli	doc_491521501865_item	2527283	et	4	main
1978	doc_491521501865_item	2527284	et	2	main
aastal	doc_491521501865_item	2527285	et	3	main
tuli	doc_491521501865_item	2527286	et	4	main
ta	doc_491521501865_item	2527287	et	4	main
23-aastasena	doc_491521501865_item	2527288	et	4	main
eestisse	doc_491521501865_item	2527289	et	4	main
kolm	doc_491521501865_item	2527290	et	3	main
aastat	doc_491521501865_item	2527291	et	3	main
elas	doc_491521501865_item	2527292	et	3	main
ja	doc_491521501865_item	2527293	et	3	main
tootas	doc_491521501865_item	2527294	et	4	main
ta	doc_491521501865_item	2527295	et	4	main
kundas	doc_491521501865_item	2527296	et	4	main
seejarel	doc_491521501865_item	2527297	et	4	main
kolis	doc_491521501865_item	2527298	et	4	main
tallinna	doc_491521501865_item	2527299	et	4	main
praegu	doc_491521501865_item	2527300	et	3	main
ta	doc_491521501865_item	2527301	et	4	main
on	doc_491521501865_item	2527302	et	4	main
vaikese	doc_491521501865_item	2527303	et	3	main
ehitusfirma	doc_491521501865_item	2527304	et	4	main
keel	doc_491521501865_item	2527310	et	4	main
ukraina	doc_491521501865_item	2527316	et	4	main
juba	doc_491521501865_item	2527322	et	3	main
ta	doc_491521501865_item	2527329	et	4	main
keelt	doc_491521501865_item	2527331	et	4	main
inglise	doc_491521501865_item	2527332	et	4	main
eesti	doc_491521501865_item	2527337	et	4	main
oppima	doc_491521501865_item	2527341	et	4	main
oppis	doc_491521501865_item	2527344	et	4	main
sonu	doc_491521501865_item	2527345	et	4	main
ja	doc_491521501865_item	2527346	et	3	main
fraase	doc_491521501865_item	2527347	et	3	main
opiku	doc_491521501865_item	2527348	et	4	main
kais	doc_491521501865_item	2527357	et	3	main
aleksandr	doc_491521501865_item	2527358	et	4	main
aastat	doc_491521501865_item	2527360	et	3	main
eesti	doc_491521501865_item	2527361	et	4	main
keele	doc_491521501865_item	2527362	et	4	main
intensiivkursustel	doc_491521501865_item	2527363	et	3	main
kus	doc_491521501865_item	2527364	et	3	main
opiti	doc_491521501865_item	2527365	et	4	main
aleksandri	doc_491521501865_item	2527370	et	4	main
sonul	doc_491521501865_item	2527371	et	4	main
grammatika	doc_491521501865_item	2527376	et	4	main
moistmisel	doc_491521501865_item	2527377	et	4	main
jargnevatel	doc_491521501865_item	2527378	et	4	main
eesti	doc_491521501865_item	2527383	et	4	main
aastal	doc_491521501865_item	2527392	et	3	main
ta	doc_491521501865_item	2527394	et	4	main
1998	doc_491521501865_item	2527398	et	2	main
aastal	doc_491521501865_item	2527399	et	3	main
hakkas	doc_491521501865_item	2527400	et	3	main
votma	doc_491521501865_item	2527401	et	4	main
eesti	doc_491521501865_item	2527402	et	4	main
keele	doc_491521501865_item	2527403	et	4	main
eratunde	doc_491521501865_item	2527404	et	4	main
2000	doc_491521501865_item	2527405	et	2	main
aastal	doc_491521501865_item	2527406	et	3	main
labis	doc_491521501865_item	2527407	et	4	main
kaks	doc_491521501865_item	2527408	et	3	main
prossumi	doc_491521501865_item	2527409	et	4	main
kursust	doc_491521501865_item	2527410	et	3	main
2001	doc_491521501865_item	2527411	et	2	main
aastast	doc_491521501865_item	2527412	et	4	main
oppis	doc_491521501865_item	2527413	et	4	main
iseseisvalt	doc_491521501865_item	2527414	et	4	main
tolkis	doc_491521501865_item	2527415	et	4	main
luhikesi	doc_491521501865_item	2527416	et	4	main
jutustusi	doc_491521501865_item	2527417	et	4	main
sonaraamutu	doc_491521501865_item	2527418	et	4	main
abil	doc_491521501865_item	2527419	et	4	main
ja	doc_491521501865_item	2527420	et	3	main
saateid	doc_491521501865_item	2527424	et	3	main
aeg-ajalt	doc_491521501865_item	2527426	et	4	main
vottis	doc_491521501865_item	2527427	et	4	main
kuid	doc_491521501865_item	2527436	et	4	main
talle	doc_491521501865_item	2527437	et	4	main
oppida	doc_491521501865_item	2527449	et	4	main
tuttavad	doc_491521501865_item	2527457	et	4	main
eesti	doc_491521501865_item	2527464	et	4	main
korraldatud	doc_491521501865_item	2527470	et	4	main
jargnevalt	doc_491521501865_item	2527471	et	4	main
alguses	doc_491521501865_item	2527472	et	4	main
ta	doc_491521501865_item	2527476	et	4	main
vaatas	doc_491521501865_item	2527421	et	3	main
eestikeelseid	doc_491521501865_item	2527423	et	3	main
ning	doc_491521501865_item	2527425	et	3	main
kursustele	doc_491521501865_item	2527434	et	3	main
tema	doc_491521501865_item	2527445	et	4	main
raakima	doc_491521501865_item	2527448	et	4	main
saaks	doc_491521501865_item	2527451	et	3	main
opetama	doc_491521501865_item	2527466	et	4	main
umbes	doc_491521501865_item	2527473	et	4	main
sellest	doc_491521501865_item	2527478	et	4	main
toopaev	doc_491521501865_item	2527488	et	4	main
minult	doc_491521501865_item	2527492	et	3	main
mida	doc_491521501865_item	2527493	et	4	main
tekste	doc_491521501865_item	2527503	et	3	main
usna	doc_491521501865_item	2527513	et	4	main
oppimise	doc_491521501865_item	2527517	et	4	main
motivatsioon	doc_491521501865_item	2527518	et	3	main
on	doc_491521501865_item	2527519	et	4	main
ta	doc_491521501865_item	2527520	et	4	main
enda	doc_491521501865_item	2527521	et	4	main
suhtes	doc_491521501865_item	2527523	et	4	main
tarvis	doc_491521501865_item	2527540	et	3	main
et	doc_491521501865_item	2527543	et	3	main
tema	doc_491521501865_item	2527545	et	4	main
vene	doc_491521501865_item	2527548	et	4	main
tahab	doc_491521501865_item	2527550	et	3	main
sest	doc_491521501865_item	2527556	et	4	main
eesti	doc_491521501865_item	2527564	et	4	main
keeleoskuse	doc_491521501865_item	2527567	et	3	main
tunneb	doc_491521501865_item	2527571	et	3	main
esineb	doc_491521501865_item	2527580	et	3	main
ja	doc_491521501865_item	2527587	et	3	main
verbivormide	doc_491521501865_item	2527589	et	4	main
kasutamise	doc_491521501865_item	2527590	et	4	main
ja	doc_491521501865_item	2527591	et	3	main
muutub	doc_491521501865_item	2527624	et	3	main
emotsionaalseks	doc_491521501865_item	2527626	et	3	main
vene	doc_491521501865_item	2527636	et	4	main
keele	doc_491521501865_item	2527637	et	4	main
aleksandri	doc_491521501865_item	2527644	et	4	main
puhul	doc_491521501865_item	2527645	et	4	main
ka	doc_491521501865_item	2527646	et	3	main
leksikaalsed	doc_491521501865_item	2527647	et	3	main
usna	doc_491521501865_item	2527653	et	4	main
rikkalik	doc_491521501865_item	2527654	et	3	main
esineb	doc_491521501865_item	2527662	et	3	main
ka	doc_491521501865_item	2527663	et	3	main
moningaid	doc_491521501865_item	2527664	et	4	main
jou-	doc_491521501865_item	2527671	et	4	main
tekst	doc_491521501865_item	2527686	et	3	main
lindilt	doc_491521501865_item	2527687	et	3	main
eesmaspdeval	doc_491521501865_item	2527692	et	4	main
va	doc_491521501865_item	2527694	et	3	main
vaga	doc_491521501865_item	2527696	et	4	main
vara	doc_491521501865_item	2527697	et	4	main
vorru	doc_491521501865_item	2527713	et	4	main
ma	doc_491521501865_item	2527722	et	3	main
kell	doc_491521501865_item	2527724	et	3	main
ma	doc_491521501865_item	2527739	et	3	main
tahaksin	doc_491521501865_item	2527740	et	3	main
ei	doc_491521501865_item	2527741	et	4	main
teha	doc_491521501865_item	2527742	et	3	main
nadalas	doc_491521501865_item	2527754	et	4	main
annab	doc_491521501865_item	2527757	et	3	main
seda	doc_491521501865_item	2527762	et	3	main
me	doc_491521501865_item	2527782	et	4	main
abikaasaga	doc_491521501865_item	2527784	et	3	main
kell	doc_491521501865_item	2527786	et	3	main
veenaiteid	doc_491521501865_item	2527798	et	4	main
votma	doc_491521501865_item	2527821	et	4	main
ma	doc_491521501865_item	2527823	et	3	main
see	doc_491521501865_item	2527826	et	3	main
ma	doc_491521501865_item	2527836	et	3	main
haamri	doc_491521501865_item	2527839	et	3	main
selles	doc_491521501865_item	2527846	et	4	main
et	doc_491521501865_item	2527847	et	3	main
ma	doc_491521501865_item	2527848	et	3	main
meie	doc_491521501865_item	2527854	et	4	main
kuidas	doc_491521501865_item	2527485	et	3	main
kusib	doc_491521501865_item	2527490	et	4	main
ta	doc_491521501865_item	2527491	et	4	main
viimati	doc_491521501865_item	2527497	et	3	main
juhtunud	doc_491521501865_item	2527498	et	4	main
ja	doc_491521501865_item	2527504	et	3	main
aleksandri	doc_491521501865_item	2527506	et	4	main
ja	doc_491521501865_item	2527508	et	3	main
raagib	doc_491521501865_item	2527527	et	4	main
keelt	doc_491521501865_item	2527536	et	4	main
on	doc_491521501865_item	2527537	et	4	main
tal	doc_491521501865_item	2527538	et	3	main
hadasti	doc_491521501865_item	2527539	et	4	main
sellele	doc_491521501865_item	2527542	et	4	main
oskab	doc_491521501865_item	2527547	et	3	main
ta	doc_491521501865_item	2527551	et	4	main
nendega	doc_491521501865_item	2527552	et	4	main
ta	doc_491521501865_item	2527557	et	4	main
arvab	doc_491521501865_item	2527558	et	3	main
et	doc_491521501865_item	2527559	et	3	main
eestis	doc_491521501865_item	2527560	et	3	main
elades	doc_491521501865_item	2527561	et	4	main
tuleb	doc_491521501865_item	2527562	et	3	main
keelt	doc_491521501865_item	2527565	et	4	main
kuigi	doc_491521501865_item	2527569	et	3	main
aleksandr	doc_491521501865_item	2527572	et	4	main
ta	doc_491521501865_item	2527577	et	4	main
vigadeta	doc_491521501865_item	2527579	et	3	main
palju	doc_491521501865_item	2527583	et	4	main
ning	doc_491521501865_item	2527593	et	3	main
sisekohakaanete	doc_491521501865_item	2527594	et	4	main
valiku	doc_491521501865_item	2527595	et	3	main
vigu	doc_491521501865_item	2527596	et	3	main
tihti	doc_491521501865_item	2527597	et	3	main
esineb	doc_491521501865_item	2527598	et	3	main
ka	doc_491521501865_item	2527599	et	3	main
interferentsivigu	doc_491521501865_item	2527600	et	4	main
sageli	doc_491521501865_item	2527601	et	3	main
alustab	doc_491521501865_item	2527602	et	3	main
aleksandr	doc_491521501865_item	2527603	et	4	main
lauset	doc_491521501865_item	2527604	et	3	main
sidesonadest	doc_491521501865_item	2527605	et	4	main
ja	doc_491521501865_item	2527606	et	3	main
ning	doc_491521501865_item	2527607	et	3	main
selleparast	doc_491521501865_item	2527608	et	3	main
et	doc_491521501865_item	2527609	et	3	main
mis	doc_491521501865_item	2527610	et	4	main
on	doc_491521501865_item	2527611	et	4	main
vene	doc_491521501865_item	2527612	et	4	main
keelele	doc_491521501865_item	2527613	et	4	main
tuupiline	doc_491521501865_item	2527614	et	4	main
kasutab	doc_491521501865_item	2527615	et	3	main
parasiitsonu	doc_491521501865_item	2527616	et	4	main
vot	doc_491521501865_item	2527617	et	3	main
no	doc_491521501865_item	2527618	et	3	main
vrd	doc_491521501865_item	2527619	et	4	main
vene	doc_491521501865_item	2527620	et	4	main
vaga	doc_491521501865_item	2527625	et	4	main
aleksandr	doc_491521501865_item	2527628	et	4	main
omane	doc_491521501865_item	2527635	et	3	main
on	doc_491521501865_item	2527643	et	4	main
aleksandri	doc_491521501865_item	2527668	et	4	main
tal	doc_491521501865_item	2527676	et	3	main
keeltes	doc_491521501865_item	2527531	et	3	main
andetu	doc_491521501865_item	2527533	et	4	main
kuid	doc_491521501865_item	2527534	et	4	main
eesti	doc_491521501865_item	2527535	et	4	main
vaatamata	doc_491521501865_item	2527541	et	4	main
tellijatest	doc_491521501865_item	2527546	et	4	main
keelt	doc_491521501865_item	2527549	et	4	main
suhelda	doc_491521501865_item	2527555	et	4	main
kones	doc_491521501865_item	2527582	et	3	main
eriti	doc_491521501865_item	2527585	et	3	main
kui	doc_491521501865_item	2527622	et	3	main
laheb	doc_491521501865_item	2527627	et	4	main
vene	doc_491521501865_item	2527629	et	4	main
keelele	doc_491521501865_item	2527630	et	4	main
ule	doc_491521501865_item	2527631	et	4	main
sonajarg	doc_491521501865_item	2527638	et	4	main
kones	doc_491521501865_item	2527639	et	3	main
vead	doc_491521501865_item	2527648	et	4	main
kuigi	doc_491521501865_item	2527649	et	3	main
ajab	doc_491521501865_item	2527655	et	3	main
ta	doc_491521501865_item	2527656	et	4	main
segi	doc_491521501865_item	2527657	et	3	main
haaldusvigu	doc_491521501865_item	2527665	et	4	main
probleemsed	doc_491521501865_item	2527666	et	3	main
on	doc_491521501865_item	2527667	et	4	main
ja	doc_491521501865_item	2527672	et	3	main
on	doc_491521501865_item	2527675	et	4	main
vale	doc_491521501865_item	2527677	et	4	main
silbil	doc_491521501865_item	2527685	et	3	main
valmistan	doc_491521501865_item	2527690	et	3	main
juba	doc_491521501865_item	2527698	et	3	main
selleparast	doc_491521501865_item	2527701	et	3	main
olema	doc_491521501865_item	2527703	et	4	main
voru	doc_491521501865_item	2527714	et	4	main
kuueks	doc_491521501865_item	2527725	et	4	main
joua	doc_491521501865_item	2527738	et	4	main
kui	doc_491521501865_item	2527746	et	3	main
me	doc_491521501865_item	2527747	et	4	main
eesti	doc_491521501865_item	2527749	et	4	main
keeles	doc_491521501865_item	2527750	et	4	main
kuigi	doc_491521501865_item	2527751	et	3	main
kaks	doc_491521501865_item	2527752	et	3	main
ma	doc_491521501865_item	2527760	et	3	main
vot	doc_491521501865_item	2527773	et	3	main
kui	doc_491521501865_item	2527780	et	3	main
mina	doc_491521501865_item	2527791	et	4	main
midagi	doc_491521501865_item	2527793	et	4	main
vahetasin	doc_491521501865_item	2527795	et	3	main
jutt	doc_491521501865_item	2527623	et	3	main
on	doc_491521501865_item	2527634	et	4	main
lihtlaused	doc_491521501865_item	2527641	et	3	main
tema	doc_491521501865_item	2527650	et	4	main
sonavara	doc_491521501865_item	2527651	et	4	main
on	doc_491521501865_item	2527652	et	4	main
sonu	doc_491521501865_item	2527660	et	4	main
paronuumivead	doc_491521501865_item	2527661	et	4	main
monikord	doc_491521501865_item	2527674	et	4	main
alati	doc_491521501865_item	2527683	et	4	main
praegu	doc_491521501865_item	2527688	et	3	main
soiduks	doc_491521501865_item	2527691	et	4	main
me	doc_491521501865_item	2527693	et	4	main
kell	doc_491521501865_item	2527699	et	3	main
me	doc_491521501865_item	2527711	et	4	main
soidame	doc_491521501865_item	2527712	et	4	main
pdrast	doc_491521501865_item	2527715	et	4	main
me	doc_491521501865_item	2527716	et	4	main
tagastame	doc_491521501865_item	2527717	et	3	main
tallinna	doc_491521501865_item	2527718	et	4	main
ma	doc_491521501865_item	2527719	et	3	main
loodan	doc_491521501865_item	2527720	et	3	main
et	doc_491521501865_item	2527721	et	3	main
jouan	doc_491521501865_item	2527723	et	4	main
midagi	doc_491521501865_item	2527729	et	4	main
juhtub	doc_491521501865_item	2527730	et	3	main
no	doc_491521501865_item	2527731	et	3	main
teile	doc_491521501865_item	2527734	et	4	main
kui	doc_491521501865_item	2527735	et	3	main
ma	doc_491521501865_item	2527736	et	3	main
selleparast	doc_491521501865_item	2527744	et	3	main
ukskoik	doc_491521501865_item	2527755	et	4	main
see	doc_491521501865_item	2527756	et	3	main
kodus	doc_491521501865_item	2527768	et	4	main
vot	doc_491521501865_item	2527779	et	3	main
tulime	doc_491521501865_item	2527783	et	3	main
no	doc_491521501865_item	2527788	et	3	main
soime	doc_491521501865_item	2527790	et	4	main
elektripirnid	doc_491521501865_item	2527796	et	3	main
ja	doc_491521501865_item	2527799	et	3	main
on	doc_491521501865_item	2527827	et	4	main
joudne	doc_491521501865_item	2527830	et	4	main
on	doc_491521501865_item	2527845	et	4	main
joudu	doc_491521501865_item	2527864	et	4	main
votsin	doc_491521501865_item	2527868	et	4	main
ja	doc_491521501865_item	2527870	et	3	main
ja	doc_491521501865_item	2527877	et	3	main
see	doc_491521501865_item	2527881	et	3	main
see	doc_491521501865_item	2527887	et	3	main
elu	doc_491521501865_item	2527889	et	4	main
praegu	doc_491521501865_item	2527890	et	3	main
ei	doc_491521501865_item	2527891	et	4	main
ja	doc_491521501865_item	2527904	et	3	main
detsembris	doc_491521501865_item	2527919	et	3	main
rahad	doc_491521501865_item	2527920	et	4	main
on	doc_491521501865_item	2527922	et	4	main
nagu	doc_491521501865_item	2527933	et	3	main
on	doc_491521501865_item	2527937	et	4	main
koige	doc_491521501865_item	2527938	et	4	main
ja	doc_491521501865_item	2527948	et	3	main
ema	doc_491521501865_item	2527949	et	4	main
kulla	doc_491521501865_item	2527956	et	4	main
kalendrit	doc_491521501865_item	2527959	et	3	main
ei	doc_491521501865_item	2527978	et	4	main
saa	doc_491521501865_item	2527983	et	4	main
teha	doc_491521501865_item	2527984	et	3	main
pimaa	doc_491521501865_item	2528013	et	4	main
ajal	doc_491521501865_item	2528016	et	4	main
tahtsin	doc_491521501865_item	2528018	et	3	main
varem	doc_491521501865_item	2528020	et	4	main
lapimaa	doc_491521501865_item	2528021	et	4	main
aga	doc_491521501865_item	2528023	et	3	main
kord	doc_491521501865_item	2528025	et	4	main
lehte	doc_491521501865_item	2528033	et	4	main
seda	doc_491521501865_item	2528039	et	3	main
nagu	doc_491521501865_item	2528041	et	3	main
rohkem	doc_491521501865_item	2528047	et	4	main
intonatsioon	doc_491521501865_item	2527678	et	3	main
rohk	doc_491521501865_item	2527680	et	4	main
ei	doc_491521501865_item	2527681	et	4	main
ole	doc_491521501865_item	2527682	et	4	main
ma	doc_491521501865_item	2527689	et	3	main
neli	doc_491521501865_item	2527700	et	3	main
peame	doc_491521501865_item	2527702	et	4	main
kohal	doc_491521501865_item	2527704	et	4	main
juba	doc_491521501865_item	2527705	et	3	main
kell	doc_491521501865_item	2527706	et	3	main
kaheksa	doc_491521501865_item	2527707	et	4	main
ja	doc_491521501865_item	2527708	et	3	main
parast	doc_491521501865_item	2527709	et	3	main
seda	doc_491521501865_item	2527710	et	3	main
tagasi	doc_491521501865_item	2527726	et	3	main
aga	doc_491521501865_item	2527727	et	3	main
ma	doc_491521501865_item	2527732	et	3	main
vahet	doc_491521501865_item	2527743	et	3	main
korda	doc_491521501865_item	2527753	et	4	main
tunnen	doc_491521501865_item	2527761	et	3	main
mul	doc_491521501865_item	2527764	et	3	main
ole	doc_491521501865_item	2527766	et	4	main
voimalust	doc_491521501865_item	2527767	et	4	main
no	doc_491521501865_item	2527772	et	3	main
uldse	doc_491521501865_item	2527778	et	4	main
voimlast	doc_491521501865_item	2527785	et	4	main
kuus	doc_491521501865_item	2527787	et	4	main
votsin	doc_491521501865_item	2527797	et	4	main
ara	doc_491521501865_item	2527822	et	3	main
proovisin	doc_491521501865_item	2527824	et	3	main
oudne	doc_491521501865_item	2527828	et	4	main
ei	doc_491521501865_item	2527834	et	4	main
votavad	doc_491521501865_item	2527838	et	4	main
ma	doc_491521501865_item	2527867	et	3	main
on	doc_491521501865_item	2527882	et	4	main
mis	doc_491521501865_item	2527885	et	4	main
ole	doc_491521501865_item	2527892	et	4	main
uldse	doc_491521501865_item	2527893	et	4	main
minul	doc_491521501865_item	2527894	et	3	main
homme	doc_491521501865_item	2527901	et	3	main
ole	doc_491521501865_item	2527917	et	4	main
ning	doc_491521501865_item	2527679	et	3	main
esimesel	doc_491521501865_item	2527684	et	3	main
jume	doc_491521501865_item	2527695	et	4	main
akki	doc_491521501865_item	2527728	et	4	main
helistan	doc_491521501865_item	2527733	et	3	main
ei	doc_491521501865_item	2527737	et	4	main
et	doc_491521501865_item	2527745	et	3	main
tegeleme	doc_491521501865_item	2527748	et	3	main
mulle	doc_491521501865_item	2527758	et	4	main
palju	doc_491521501865_item	2527759	et	4	main
kahjuks	doc_491521501865_item	2527763	et	4	main
ei	doc_491521501865_item	2527765	et	4	main
midagi	doc_491521501865_item	2527769	et	4	main
teha	doc_491521501865_item	2527770	et	3	main
selleparast	doc_491521501865_item	2527771	et	3	main
ei	doc_491521501865_item	2527774	et	4	main
ole	doc_491521501865_item	2527775	et	4	main
aega	doc_491521501865_item	2527776	et	4	main
selleks	doc_491521501865_item	2527777	et	4	main
eile	doc_491521501865_item	2527781	et	3	main
natuke	doc_491521501865_item	2527789	et	4	main
puudsin	doc_491521501865_item	2527792	et	4	main
teha	doc_491521501865_item	2527794	et	3	main
vormistasin	doc_491521501865_item	2527800	et	3	main
kahekumne	doc_491521501865_item	2527801	et	4	main
kaheksandal	doc_491521501865_item	2527802	et	3	main
novembris	doc_491521501865_item	2527803	et	3	main
tulevad	doc_491521501865_item	2527804	et	4	main
torude	doc_491521501865_item	2527806	et	3	main
vahetada	doc_491521501865_item	2527807	et	3	main
meie	doc_491521501865_item	2527808	et	4	main
torud	doc_491521501865_item	2527809	et	3	main
santehnikud	doc_491521501865_item	2527805	et	4	main
on	doc_491521501865_item	2527810	et	4	main
ap	doc_491521501865_item	2527811	et	4	main
ndud	doc_491521501865_item	2527812	et	4	main
kinni	doc_491521501865_item	2527813	et	3	main
keeraami	doc_491521501865_item	2527814	et	4	main
lp	doc_491521501865_item	2527815	et	4	main
itkaga	doc_491521501865_item	2527816	et	4	main
ja	doc_491521501865_item	2527817	et	3	main
ma	doc_491521501865_item	2527818	et	3	main
pean	doc_491521501865_item	2527819	et	4	main
plitka	doc_491521501865_item	2527820	et	4	main
eile	doc_491521501865_item	2527825	et	3	main
hkaldus	doc_491521501865_item	2527829	et	4	main
aga	doc_491521501865_item	2527831	et	3	main
ma	doc_491521501865_item	2527833	et	3	main
tulevad	doc_491521501865_item	2527837	et	4	main
lammutavad	doc_491521501865_item	2527841	et	4	main
tegi	doc_491521501865_item	2527849	et	4	main
korteris	doc_491521501865_item	2527855	et	3	main
kil	doc_491521501865_item	2527872	et	4	main
plitka	doc_491521501865_item	2527873	et	4	main
vannas	doc_491521501865_item	2527874	et	3	main
ja	doc_491521501865_item	2527875	et	3	main
koogis	doc_491521501865_item	2527876	et	3	main
lammutama	doc_491521501865_item	2527880	et	4	main
valgas	doc_491521501865_item	2527900	et	4	main
hakkame	doc_491521501865_item	2527906	et	3	main
detsembris	doc_491521501865_item	2527924	et	3	main
detsember	doc_491521501865_item	2527927	et	3	main
kuu	doc_491521501865_item	2527940	et	4	main
minu	doc_491521501865_item	2527941	et	3	main
kusib	doc_491521501865_item	2527950	et	4	main
kui	doc_491521501865_item	2527832	et	3	main
tee	doc_491521501865_item	2527835	et	4	main
ja	doc_491521501865_item	2527840	et	3	main
koik	doc_491521501865_item	2527842	et	4	main
ara	doc_491521501865_item	2527843	et	3	main
asi	doc_491521501865_item	2527844	et	4	main
remonti	doc_491521501865_item	2527850	et	4	main
viis	doc_491521501865_item	2527851	et	4	main
aastat	doc_491521501865_item	2527852	et	3	main
tagasi	doc_491521501865_item	2527853	et	3	main
remont	doc_491521501865_item	2527856	et	3	main
ei	doc_491521501865_item	2527857	et	4	main
ole	doc_491521501865_item	2527858	et	4	main
loppenud	doc_491521501865_item	2527859	et	4	main
selleparast	doc_491521501865_item	2527860	et	3	main
mul	doc_491521501865_item	2527861	et	3	main
ei	doc_491521501865_item	2527862	et	4	main
ole	doc_491521501865_item	2527863	et	4	main
hadldus	doc_491521501865_item	2527865	et	4	main
oudu	doc_491521501865_item	2527866	et	4	main
tooline	doc_491521501865_item	2527869	et	4	main
ta	doc_491521501865_item	2527871	et	4	main
pean	doc_491521501865_item	2527879	et	4	main
kohutav	doc_491521501865_item	2527883	et	4	main
teha	doc_491521501865_item	2527886	et	3	main
meil	doc_491521501865_item	2527896	et	4	main
on	doc_491521501865_item	2527897	et	4	main
suur	doc_491521501865_item	2527898	et	3	main
objekt	doc_491521501865_item	2527899	et	3	main
sinna	doc_491521501865_item	2527903	et	3	main
kahjuks	doc_491521501865_item	2527908	et	4	main
on	doc_491521501865_item	2527910	et	4	main
raha	doc_491521501865_item	2527914	et	4	main
praegu	doc_491521501865_item	2527915	et	3	main
ei	doc_491521501865_item	2527916	et	4	main
vaja	doc_491521501865_item	2527923	et	4	main
nii	doc_491521501865_item	2527930	et	3	main
uldse	doc_491521501865_item	2527932	et	4	main
nadalat	doc_491521501865_item	2527935	et	4	main
see	doc_491521501865_item	2527936	et	3	main
ijot	doc_491521501865_item	2527943	et	4	main
sa	doc_491521501865_item	2527952	et	3	main
tuled	doc_491521501865_item	2527955	et	4	main
ma	doc_491521501865_item	2527957	et	3	main
ja	doc_491521501865_item	2527960	et	3	main
et	doc_491521501865_item	2527962	et	3	main
et	doc_491521501865_item	2527976	et	3	main
kahjuks	doc_491521501865_item	2527977	et	4	main
loodavad	doc_491521501865_item	2527986	et	4	main
tulen	doc_491521501865_item	2527989	et	3	main
mind	doc_491521501865_item	2527991	et	4	main
kui	doc_491521501865_item	2527993	et	3	main
ma	doc_491521501865_item	2527994	et	3	main
helistaks	doc_491521501865_item	2527995	et	3	main
hy	doc_491521501865_item	2527996	et	4	main
kanxo	doc_491521501865_item	2527998	et	4	main
ei	doc_491521501865_item	2528001	et	4	main
la	doc_491521501865_item	2528012	et	4	main
kui	doc_491521501865_item	2528026	et	3	main
tahaksin	doc_491521501865_item	2528028	et	3	main
vaba	doc_491521501865_item	2528032	et	4	main
up	doc_491521501865_item	2528045	et	4	main
udsi	doc_491521501865_item	2528046	et	4	main
ja	doc_491521501865_item	2528054	et	3	main
lootsin	doc_491521501865_item	2528058	et	4	main
me	doc_491521501865_item	2528060	et	4	main
soidame	doc_491521501865_item	2528061	et	4	main
leidsin	doc_491521501865_item	2528067	et	3	main
siin	doc_491521501865_item	2528070	et	4	main
paev	doc_491521501865_item	2528104	et	4	main
tulek	doc_491521501865_item	2528110	et	3	main
pdev	doc_491521501865_item	2528116	et	4	main
paev	doc_491521501865_item	2528119	et	4	main
kell	doc_491521501865_item	2528127	et	3	main
puhkus	doc_491521501865_item	2528146	et	3	main
kompveki	doc_491521501865_item	2528154	et	4	main
kell	doc_491521501865_item	2528157	et	3	main
kell	doc_491521501865_item	2528159	et	3	main
kell	doc_491521501865_item	2528163	et	3	main
helsinki	doc_491521501865_item	2528167	et	4	main
tulek	doc_491521501865_item	2528170	et	3	main
kell	doc_491521501865_item	2528173	et	3	main
ei	doc_491521501865_item	2528187	et	4	main
on	doc_491521501865_item	2528221	et	4	main
on	doc_491521501865_item	2528227	et	4	main
rongiga	doc_491521501865_item	2528229	et	4	main
ainult	doc_491521501865_item	2528239	et	4	main
helsingi	doc_491521501865_item	2528247	et	4	main
uldse	doc_491521501865_item	2528255	et	4	main
ma	doc_491521501865_item	2528261	et	3	main
miks	doc_491521501865_item	2528264	et	4	main
mulle	doc_491521501865_item	2528265	et	4	main
soome	doc_491521501865_item	2528271	et	3	main
venemaal	doc_491521501865_item	2528273	et	4	main
veel	doc_491521501865_item	2528299	et	4	main
koik	doc_491521501865_item	2528300	et	4	main
mida	doc_491521501865_item	2528302	et	4	main
tahtsin	doc_491521501865_item	2528303	et	3	main
siis	doc_491521501865_item	2528308	et	3	main
grammatikaga	doc_491521501865_item	2528311	et	3	main
ruhmitamine	doc_491521501865_item	2528313	et	4	main
nuud	doc_491521501865_item	2527878	et	4	main
no	doc_491521501865_item	2527884	et	3	main
on	doc_491521501865_item	2527888	et	4	main
aega	doc_491521501865_item	2527895	et	4	main
soidan	doc_491521501865_item	2527902	et	4	main
detsembris	doc_491521501865_item	2527905	et	3	main
tootada	doc_491521501865_item	2527907	et	4	main
tood	doc_491521501865_item	2527909	et	3	main
pa	doc_491521501865_item	2527911	et	4	main
ju	doc_491521501865_item	2527912	et	3	main
aga	doc_491521501865_item	2527913	et	3	main
vot	doc_491521501865_item	2527918	et	3	main
tulevad	doc_491521501865_item	2527921	et	4	main
kiirem	doc_491521501865_item	2527939	et	4	main
lubas	doc_491521501865_item	2527953	et	3	main
voimalust	doc_491521501865_item	2527980	et	4	main
ma	doc_491521501865_item	2527988	et	3	main
saa	doc_491521501865_item	2528002	et	4	main
nzidagi	doc_491521501865_item	2528004	et	4	main
teha	doc_491521501865_item	2528005	et	3	main
ei	doc_491521501865_item	2528006	et	4	main
ole	doc_491521501865_item	2528007	et	4	main
otsustasime	doc_491521501865_item	2528008	et	3	main
abikaasaga	doc_491521501865_item	2528009	et	3	main
et	doc_491521501865_item	2528010	et	3	main
oulu	doc_491521501865_item	2528015	et	4	main
juba	doc_491521501865_item	2528019	et	3	main
palju	doc_491521501865_item	2527925	et	4	main
tootada	doc_491521501865_item	2527926	et	4	main
ldheb	doc_491521501865_item	2527928	et	4	main
minule	doc_491521501865_item	2527929	et	3	main
kiiresti	doc_491521501865_item	2527931	et	3	main
uks	doc_491521501865_item	2527934	et	3	main
jaoks	doc_491521501865_item	2527942	et	4	main
ma	doc_491521501865_item	2527944	et	3	main
helistan	doc_491521501865_item	2527945	et	3	main
eile	doc_491521501865_item	2527946	et	3	main
vanematele	doc_491521501865_item	2527947	et	4	main
et	doc_491521501865_item	2527951	et	3	main
et	doc_491521501865_item	2527954	et	3	main
vaatan	doc_491521501865_item	2527958	et	3	main
naen	doc_491521501865_item	2527961	et	4	main
ei	doc_491521501865_item	2527963	et	4	main
saa	doc_491521501865_item	2527964	et	4	main
esiteks	doc_491521501865_item	2527965	et	3	main
raha	doc_491521501865_item	2527966	et	4	main
ei	doc_491521501865_item	2527967	et	4	main
ole	doc_491521501865_item	2527968	et	4	main
ja	doc_491521501865_item	2527969	et	3	main
teiseks	doc_491521501865_item	2527970	et	4	main
aega	doc_491521501865_item	2527971	et	4	main
ei	doc_491521501865_item	2527972	et	4	main
ole	doc_491521501865_item	2527973	et	4	main
ma	doc_491521501865_item	2527974	et	3	main
utlesin	doc_491521501865_item	2527975	et	4	main
midagi	doc_491521501865_item	2527981	et	4	main
ei	doc_491521501865_item	2527982	et	4	main
et	doc_491521501865_item	2527987	et	3	main
ootavad	doc_491521501865_item	2527990	et	4	main
ootavad	doc_491521501865_item	2527992	et	4	main
tax	doc_491521501865_item	2527997	et	4	main
hkxax	doc_491521501865_item	2527999	et	4	main
npam	doc_491521501865_item	2528000	et	4	main
laheme	doc_491521501865_item	2528011	et	4	main
l	doc_491521501865_item	2528014	et	4	main
ma	doc_491521501865_item	2528017	et	3	main
minema	doc_491521501865_item	2528022	et	3	main
passis	doc_491521501865_item	2528031	et	4	main
viisa	doc_491521501865_item	2528036	et	4	main
parast	doc_491521501865_item	2528038	et	3	main
solvusin	doc_491521501865_item	2528042	et	3	main
ei	doc_491521501865_item	2528050	et	4	main
uhugi	doc_491521501865_item	2528053	et	4	main
vot	doc_491521501865_item	2528056	et	3	main
paeva	doc_491521501865_item	2528073	et	4	main
oli	doc_491521501865_item	2528074	et	3	main
kolm	doc_491521501865_item	2528075	et	3	main
pakkusid	doc_491521501865_item	2528076	et	4	main
teine	doc_491521501865_item	2528118	et	3	main
kell	doc_491521501865_item	2528120	et	3	main
santa	doc_491521501865_item	2528130	et	4	main
klausi	doc_491521501865_item	2528131	et	4	main
poijari	doc_491521501865_item	2528137	et	4	main
ringist	doc_491521501865_item	2528138	et	3	main
paev	doc_491521501865_item	2528148	et	4	main
kulastamine	doc_491521501865_item	2528156	et	4	main
kulastamine	doc_491521501865_item	2528162	et	4	main
vallumine	doc_491521501865_item	2528166	et	4	main
oo	doc_491521501865_item	2528168	et	3	main
bussis	doc_491521501865_item	2528169	et	3	main
kaksteist	doc_491521501865_item	2528179	et	4	main
tallinnas	doc_491521501865_item	2528181	et	4	main
asi	doc_491521501865_item	2528182	et	4	main
ole	doc_491521501865_item	2528188	et	4	main
sauna	doc_491521501865_item	2528224	et	4	main
ma	doc_491521501865_item	2528230	et	3	main
rongiga	doc_491521501865_item	2528234	et	4	main
us	doc_491521501865_item	2528240	et	4	main
pdev	doc_491521501865_item	2528241	et	4	main
lapimaal	doc_491521501865_item	2528242	et	4	main
kolmandas	doc_491521501865_item	2528243	et	3	main
meeldib	doc_491521501865_item	2528257	et	3	main
see	doc_491521501865_item	2528259	et	3	main
kas	doc_491521501865_item	2528306	et	3	main
natuke	doc_491521501865_item	2528310	et	4	main
r	doc_491521501865_item	2528345	et	4	main
joudu	doc_491521501865_item	2528349	et	4	main
sarnasuse	doc_491521501865_item	2528353	et	4	main
haalikuiihendid	doc_491521501865_item	2528356	et	4	main
ei	doc_491521501865_item	2528357	et	4	main
esine	doc_491521501865_item	2528358	et	4	main
nt	doc_491521501865_item	2528373	et	4	main
eesmaspaeval	doc_491521501865_item	2528374	et	4	main
r	doc_491521501865_item	2528377	et	4	main
vene	doc_491521501865_item	2528380	et	4	main
keelega	doc_491521501865_item	2528381	et	3	main
kus	doc_491521501865_item	2528382	et	3	main
lahtine	doc_491521501865_item	2528383	et	3	main
esisilp	doc_491521501865_item	2528384	et	3	main
kahe	doc_491521501865_item	2528395	et	3	main
ole	doc_491521501865_item	2527979	et	4	main
nad	doc_491521501865_item	2527985	et	3	main
no	doc_491521501865_item	2528003	et	3	main
et	doc_491521501865_item	2528034	et	3	main
me	doc_491521501865_item	2528049	et	4	main
kainud	doc_491521501865_item	2528051	et	4	main
et	doc_491521501865_item	2528059	et	3	main
ukraina	doc_491521501865_item	2528062	et	4	main
seda	doc_491521501865_item	2528068	et	3	main
uheksandani	doc_491521501865_item	2528101	et	4	main
kell	doc_491521501865_item	2528105	et	3	main
paroomiga	doc_491521501865_item	2528109	et	4	main
hels	doc_491521501865_item	2528111	et	4	main
valiumine	doc_491521501865_item	2528113	et	4	main
soidus	doc_491521501865_item	2528117	et	4	main
kaheksa	doc_491521501865_item	2528121	et	4	main
hotellis	doc_491521501865_item	2528123	et	3	main
posti	doc_491521501865_item	2528134	et	4	main
kulastamine	doc_491521501865_item	2528135	et	4	main
ka	doc_491521501865_item	2528136	et	3	main
kell	doc_491521501865_item	2528142	et	3	main
hotelli	doc_491521501865_item	2528144	et	4	main
lossi	doc_491521501865_item	2528152	et	4	main
ja	doc_491521501865_item	2528153	et	3	main
kuueteistkumneni	doc_491521501865_item	2528160	et	4	main
kaks	doc_491521501865_item	2528165	et	3	main
kell	doc_491521501865_item	2528171	et	3	main
seitse	doc_491521501865_item	2528172	et	3	main
juba	doc_491521501865_item	2528180	et	3	main
esimene	doc_491521501865_item	2528024	et	3	main
ma	doc_491521501865_item	2528027	et	3	main
ei	doc_491521501865_item	2528029	et	4	main
ole	doc_491521501865_item	2528030	et	4	main
soome	doc_491521501865_item	2528035	et	3	main
panna	doc_491521501865_item	2528037	et	4	main
ma	doc_491521501865_item	2528040	et	3	main
sellesse	doc_491521501865_item	2528043	et	4	main
ei	doc_491521501865_item	2528044	et	4	main
sugisel	doc_491521501865_item	2528048	et	4	main
ma	doc_491521501865_item	2528057	et	3	main
valja	doc_491521501865_item	2528065	et	3	main
reisi	doc_491521501865_item	2528069	et	4	main
an	doc_491521501865_item	2528071	et	4	main
kolm	doc_491521501865_item	2528072	et	3	main
ja	doc_491521501865_item	2528077	et	3	main
ma	doc_491521501865_item	2528078	et	3	main
valisin	doc_491521501865_item	2528079	et	3	main
endale	doc_491521501865_item	2528080	et	4	main
soit	doc_491521501865_item	2528081	et	4	main
bussiqa	doc_491521501865_item	2528082	et	4	main
lapimaa	doc_491521501865_item	2528083	et	4	main
iiot	doc_491521501865_item	2528084	et	4	main
siin	doc_491521501865_item	2528085	et	4	main
aleksandr	doc_491521501865_item	2528086	et	4	main
naitab	doc_491521501865_item	2528087	et	4	main
reklaamteksti	doc_491521501865_item	2528088	et	4	main
ja	doc_491521501865_item	2528089	et	3	main
tolgib	doc_491521501865_item	2528090	et	4	main
seda	doc_491521501865_item	2528091	et	3	main
vene	doc_491521501865_item	2528092	et	4	main
keelest	doc_491521501865_item	2528093	et	4	main
eesti	doc_491521501865_item	2528094	et	4	main
keelde	doc_491521501865_item	2528095	et	4	main
see	doc_491521501865_item	2528096	et	3	main
on	doc_491521501865_item	2528097	et	4	main
kahekumne	doc_491521501865_item	2528098	et	4	main
kuuendal	doc_491521501865_item	2528099	et	3	main
k	doc_491521501865_item	2528052	et	4	main
praegu	doc_491521501865_item	2528055	et	3	main
ei	doc_491521501865_item	2528063	et	4	main
tule	doc_491521501865_item	2528064	et	4	main
ma	doc_491521501865_item	2528066	et	3	main
kahekumne	doc_491521501865_item	2528100	et	4	main
detsembrini	doc_491521501865_item	2528102	et	3	main
seitse	doc_491521501865_item	2528106	et	3	main
tallinnast	doc_491521501865_item	2528108	et	3	main
ja	doc_491521501865_item	2528112	et	3	main
terve	doc_491521501865_item	2528115	et	4	main
esimene	doc_491521501865_item	2528103	et	3	main
valjumine	doc_491521501865_item	2528107	et	4	main
lapimaa	doc_491521501865_item	2528114	et	4	main
on	doc_491521501865_item	2528122	et	4	main
uheteist	doc_491521501865_item	2528126	et	3	main
on	doc_491521501865_item	2528129	et	4	main
maja	doc_491521501865_item	2528132	et	4	main
kulastamine	doc_491521501865_item	2528133	et	4	main
kdimine	doc_491521501865_item	2528139	et	4	main
kulastamine	doc_491521501865_item	2528151	et	4	main
akvaparki	doc_491521501865_item	2528161	et	4	main
kakskummend	doc_491521501865_item	2528164	et	4	main
kaheksa	doc_491521501865_item	2528174	et	4	main
tallinna	doc_491521501865_item	2528176	et	4	main
pool	doc_491521501865_item	2528178	et	4	main
selles	doc_491521501865_item	2528184	et	4	main
et	doc_491521501865_item	2528185	et	3	main
see	doc_491521501865_item	2528186	et	3	main
hea	doc_491521501865_item	2528189	et	4	main
variant	doc_491521501865_item	2528226	et	3	main
meelega	doc_491521501865_item	2528232	et	4	main
soidaksin	doc_491521501865_item	2528233	et	4	main
on	doc_491521501865_item	2528238	et	4	main
variandis	doc_491521501865_item	2528244	et	3	main
on	doc_491521501865_item	2528245	et	4	main
ka	doc_491521501865_item	2528246	et	3	main
on	doc_491521501865_item	2528254	et	4	main
linn	doc_491521501865_item	2528260	et	3	main
tea	doc_491521501865_item	2528263	et	4	main
ja	doc_491521501865_item	2528270	et	3	main
xaaepxoe	doc_491521501865_item	2528301	et	4	main
me	doc_491521501865_item	2528307	et	4	main
nende	doc_491521501865_item	2528315	et	4	main
ja	doc_491521501865_item	2528322	et	3	main
vale	doc_491521501865_item	2528324	et	4	main
haaldus	doc_491521501865_item	2528325	et	4	main
nt	doc_491521501865_item	2528331	et	4	main
ei	doc_491521501865_item	2528332	et	4	main
ou-	doc_491521501865_item	2528336	et	4	main
asemel	doc_491521501865_item	2528337	et	4	main
haalikuuhendite	doc_491521501865_item	2528346	et	4	main
segiajamine	doc_491521501865_item	2528347	et	4	main
vene	doc_491521501865_item	2528359	et	4	main
venelastest	doc_491521501865_item	2528364	et	4	main
pikkus	doc_491521501865_item	2528372	et	4	main
pohjused	doc_491521501865_item	2528376	et	4	main
interferentsiviga	doc_491521501865_item	2528378	et	4	main
analoogia	doc_491521501865_item	2528379	et	4	main
aleksandr	doc_491521501865_item	2528388	et	4	main
millegiparast	doc_491521501865_item	2528389	et	3	main
arvas	doc_491521501865_item	2528390	et	3	main
et	doc_491521501865_item	2528391	et	3	main
vead	doc_491521501865_item	2528421	et	4	main
on	doc_491521501865_item	2528428	et	4	main
nt	doc_491521501865_item	2528445	et	4	main
tadi	doc_491521501865_item	2528446	et	4	main
karu	doc_491521501865_item	2528448	et	4	main
2	doc_491521501865_item	2528450	et	2	main
loomaaeda	doc_491521501865_item	2528461	et	4	main
kulastamine	doc_491521501865_item	2528462	et	4	main
asemel	doc_491521501865_item	2528467	et	4	main
tugev	doc_491521501865_item	2528469	et	4	main
aste	doc_491521501865_item	2528470	et	4	main
ajas	doc_491521501865_item	2528474	et	4	main
park	doc_491521501865_item	2528477	et	3	main
kuna	doc_491521501865_item	2528483	et	3	main
nt	doc_491521501865_item	2528491	et	4	main
verbirektsioon	doc_491521501865_item	2528499	et	4	main
ma	doc_491521501865_item	2528500	et	3	main
i	doc_491521501865_item	2528506	et	4	main
sona	doc_491521501865_item	2528512	et	4	main
ja	doc_491521501865_item	2528513	et	3	main
lopetatud	doc_491521501865_item	2528521	et	4	main
objekt	doc_491521501865_item	2528523	et	3	main
voimalikud	doc_491521501865_item	2528533	et	4	main
kaane	doc_491521501865_item	2528544	et	4	main
kasutatav	doc_491521501865_item	2528553	et	4	main
reisi	doc_491521501865_item	2528560	et	4	main
vene	doc_491521501865_item	2528567	et	4	main
sxxxteabxbw	doc_491521501865_item	2528568	et	4	main
kaandega	doc_491521501865_item	2528569	et	4	main
vahetamine	doc_491521501865_item	2528596	et	4	main
hommikusook	doc_491521501865_item	2528124	et	4	main
kell	doc_491521501865_item	2528125	et	3	main
kaheteistkumneni	doc_491521501865_item	2528128	et	4	main
labi	doc_491521501865_item	2528140	et	4	main
ja	doc_491521501865_item	2528141	et	3	main
uheksateist	doc_491521501865_item	2528143	et	4	main
tulek	doc_491521501865_item	2528145	et	3	main
kolmas	doc_491521501865_item	2528147	et	3	main
hommikusook	doc_491521501865_item	2528149	et	4	main
loomaaeda	doc_491521501865_item	2528150	et	4	main
vabariigi	doc_491521501865_item	2528155	et	3	main
neliteist	doc_491521501865_item	2528158	et	4	main
paroomiga	doc_491521501865_item	2528175	et	4	main
kell	doc_491521501865_item	2528177	et	3	main
on	doc_491521501865_item	2528183	et	4	main
sest	doc_491521501865_item	2528190	et	4	main
et	doc_491521501865_item	2528191	et	3	main
kaks	doc_491521501865_item	2528192	et	3	main
oo	doc_491521501865_item	2528193	et	3	main
bussis	doc_491521501865_item	2528194	et	3	main
aga	doc_491521501865_item	2528195	et	3	main
on	doc_491521501865_item	2528196	et	4	main
variant	doc_491521501865_item	2528198	et	3	main
see	doc_491521501865_item	2528199	et	3	main
on	doc_491521501865_item	2528200	et	4	main
veel	doc_491521501865_item	2528197	et	4	main
kahekumne	doc_491521501865_item	2528201	et	4	main
kolmandal	doc_491521501865_item	2528202	et	3	main
kahekumne	doc_491521501865_item	2528203	et	4	main
kaheksandani	doc_491521501865_item	2528204	et	3	main
detsembrini	doc_491521501865_item	2528205	et	3	main
seal	doc_491521501865_item	2528206	et	4	main
on	doc_491521501865_item	2528207	et	4	main
suur	doc_491521501865_item	2528208	et	3	main
pidu	doc_491521501865_item	2528209	et	4	main
aga	doc_491521501865_item	2528210	et	3	main
ukskoik	doc_491521501865_item	2528211	et	4	main
kaks	doc_491521501865_item	2528212	et	3	main
oo	doc_491521501865_item	2528213	et	3	main
bussis	doc_491521501865_item	2528214	et	3	main
ja	doc_491521501865_item	2528215	et	3	main
hotell	doc_491521501865_item	2528216	et	3	main
on	doc_491521501865_item	2528217	et	4	main
ka	doc_491521501865_item	2528218	et	3	main
parem	doc_491521501865_item	2528219	et	4	main
seal	doc_491521501865_item	2528220	et	4	main
bassein	doc_491521501865_item	2528222	et	3	main
kolmas	doc_491521501865_item	2528225	et	3	main
hea	doc_491521501865_item	2528231	et	4	main
aga	doc_491521501865_item	2528235	et	3	main
kahjuks	doc_491521501865_item	2528236	et	4	main
seal	doc_491521501865_item	2528237	et	4	main
on	doc_491521501865_item	2528250	et	4	main
ja	doc_491521501865_item	2528223	et	3	main
juba	doc_491521501865_item	2528228	et	3	main
ekskursioon	doc_491521501865_item	2528248	et	3	main
see	doc_491521501865_item	2528249	et	3	main
ka	doc_491521501865_item	2528251	et	3	main
huvitav	doc_491521501865_item	2528252	et	4	main
helsingi	doc_491521501865_item	2528253	et	4	main
ei	doc_491521501865_item	2528262	et	4	main
meeldivad	doc_491521501865_item	2528266	et	4	main
soomlased	doc_491521501865_item	2528267	et	3	main
elavad	doc_491521501865_item	2528274	et	4	main
ka	doc_491521501865_item	2528275	et	3	main
karjalased	doc_491521501865_item	2528276	et	3	main
ja	doc_491521501865_item	2528277	et	3	main
v	doc_491521501865_item	2528278	et	4	main
nad	doc_491521501865_item	2528280	et	3	main
on	doc_491521501865_item	2528281	et	4	main
psa	doc_491521501865_item	2528279	et	4	main
soomlastega	doc_491521501865_item	2528282	et	3	main
sugulased	doc_491521501865_item	2528283	et	3	main
mulle	doc_491521501865_item	2528284	et	4	main
uldse	doc_491521501865_item	2528285	et	4	main
meeldivad	doc_491521501865_item	2528286	et	4	main
talvised	doc_491521501865_item	2528287	et	4	main
ip	doc_491521501865_item	2528288	et	4	main
dud	doc_491521501865_item	2528289	et	4	main
joulud	doc_491521501865_item	2528290	et	4	main
ja	doc_491521501865_item	2528291	et	3	main
uus	doc_491521501865_item	2528292	et	3	main
aasta	doc_491521501865_item	2528293	et	4	main
see	doc_491521501865_item	2528294	et	3	main
on	doc_491521501865_item	2528295	et	4	main
lapsepolvest	doc_491521501865_item	2528296	et	4	main
no	doc_491521501865_item	2528297	et	3	main
mis	doc_491521501865_item	2528298	et	4	main
mulle	doc_491521501865_item	2528256	et	4	main
vaga	doc_491521501865_item	2528258	et	4	main
vale	doc_491521501865_item	2528268	et	4	main
r5hk	doc_491521501865_item	2528269	et	4	main
uldse	doc_491521501865_item	2528272	et	4	main
tegeleme	doc_491521501865_item	2528309	et	3	main
vigade	doc_491521501865_item	2528312	et	3	main
haaldusvead	doc_491521501865_item	2528318	et	4	main
haalikuuhendite	doc_491521501865_item	2528320	et	4	main
jou-	doc_491521501865_item	2528321	et	4	main
ou-	doc_491521501865_item	2528323	et	4	main
ole	doc_491521501865_item	2528333	et	4	main
sonade	doc_491521501865_item	2528348	et	4	main
kirjapildi	doc_491521501865_item	2528352	et	4	main
tottu	doc_491521501865_item	2528354	et	4	main
need	doc_491521501865_item	2528355	et	3	main
on	doc_491521501865_item	2528363	et	4	main
vaga	doc_491521501865_item	2528366	et	4	main
moodustada	doc_491521501865_item	2528368	et	3	main
voimalikud	doc_491521501865_item	2528375	et	4	main
sona	doc_491521501865_item	2528393	et	4	main
e-ga	doc_491521501865_item	2528396	et	3	main
rohk	doc_491521501865_item	2528399	et	4	main
peod	doc_491521501865_item	2528424	et	4	main
aste	doc_491521501865_item	2528430	et	4	main
kahesilbiliste	doc_491521501865_item	2528434	et	4	main
sonadega	doc_491521501865_item	2528435	et	4	main
kulastamine	doc_491521501865_item	2528454	et	4	main
norga	doc_491521501865_item	2528455	et	4	main
astme	doc_491521501865_item	2528456	et	3	main
kulastamine	doc_491521501865_item	2528464	et	4	main
kordadel	doc_491521501865_item	2528485	et	3	main
lossi	doc_491521501865_item	2528492	et	4	main
ja	doc_491521501865_item	2528493	et	3	main
kulastan	doc_491521501865_item	2528501	et	4	main
mida	doc_491521501865_item	2528502	et	4	main
votsin	doc_491521501865_item	2528507	et	4	main
vale	doc_491521501865_item	2528514	et	4	main
vorm	doc_491521501865_item	2528515	et	3	main
peab	doc_491521501865_item	2528528	et	4	main
aga	doc_491521501865_item	2528542	et	3	main
2	doc_491521501865_item	2528557	et	2	main
leidsin	doc_491521501865_item	2528558	et	3	main
analoogia	doc_491521501865_item	2528566	et	4	main
muu	doc_491521501865_item	2528595	et	4	main
tooline	doc_491521501865_item	2528599	et	4	main
endale	doc_491521501865_item	2528603	et	4	main
bussisoidu	doc_491521501865_item	2528608	et	4	main
nominatiivi	doc_491521501865_item	2528620	et	4	main
pidzinkeeltele	doc_491521501865_item	2528624	et	4	main
moodustamine	doc_491521501865_item	2528632	et	4	main
seda	doc_491521501865_item	2528635	et	3	main
ei	doc_491521501865_item	2528637	et	4	main
laheme	doc_491521501865_item	2528643	et	4	main
minna	doc_491521501865_item	2528650	et	3	main
lapimaalt	doc_491521501865_item	2528663	et	3	main
kell	doc_491521501865_item	2528681	et	3	main
kell	doc_491521501865_item	2528687	et	3	main
on	doc_491521501865_item	2528732	et	4	main
vrd	doc_491521501865_item	2528734	et	4	main
vene	doc_491521501865_item	2528735	et	4	main
saxxmatbca	doc_491521501865_item	2528736	et	4	main
asbixe	doc_491521501865_item	2528739	et	4	main
keeles	doc_491521501865_item	2528743	et	4	main
ei	doc_491521501865_item	2528744	et	4	main
interferentsiviga	doc_491521501865_item	2528753	et	4	main
see	doc_491521501865_item	2528758	et	3	main
on	doc_491521501865_item	2528765	et	4	main
jutustada	doc_491521501865_item	2528770	et	3	main
kaks	doc_491521501865_item	2528802	et	3	main
kaanamine	doc_491521501865_item	2528812	et	4	main
kell	doc_491521501865_item	2528813	et	3	main
iiheteist	doc_491521501865_item	2528814	et	4	main
kell	doc_491521501865_item	2528815	et	3	main
kell	doc_491521501865_item	2528820	et	3	main
kuueteistkumneni	doc_491521501865_item	2528822	et	4	main
korduv	doc_491521501865_item	2528823	et	4	main
1	doc_491521501865_item	2528832	et	2	main
taiendi	doc_491521501865_item	2528833	et	4	main
ja	doc_491521501865_item	2528834	et	3	main
novembris	doc_491521501865_item	2528840	et	3	main
novembril	doc_491521501865_item	2528843	et	3	main
tana	doc_491521501865_item	2528304	et	4	main
raakida	doc_491521501865_item	2528305	et	4	main
ja	doc_491521501865_item	2528314	et	3	main
seletamine	doc_491521501865_item	2528317	et	4	main
asemel	doc_491521501865_item	2528327	et	4	main
haaldab	doc_491521501865_item	2528328	et	4	main
aleksandr	doc_491521501865_item	2528329	et	4	main
au-	doc_491521501865_item	2528330	et	4	main
jou-	doc_491521501865_item	2528338	et	4	main
nt	doc_491521501865_item	2528339	et	4	main
see	doc_491521501865_item	2528340	et	3	main
ja	doc_491521501865_item	2528350	et	3	main
keeles	doc_491521501865_item	2528360	et	4	main
ning	doc_491521501865_item	2528361	et	3	main
raske	doc_491521501865_item	2528367	et	4	main
2	doc_491521501865_item	2528369	et	2	main
vale	doc_491521501865_item	2528370	et	4	main
haalikute	doc_491521501865_item	2528371	et	4	main
alati	doc_491521501865_item	2528386	et	4	main
pikalt	doc_491521501865_item	2528387	et	4	main
kirjutatakse	doc_491521501865_item	2528394	et	3	main
3	doc_491521501865_item	2528397	et	2	main
voimalik	doc_491521501865_item	2528431	et	4	main
analoogia	doc_491521501865_item	2528433	et	4	main
mis	doc_491521501865_item	2528436	et	4	main
kaandes	doc_491521501865_item	2528444	et	4	main
kulastamine	doc_491521501865_item	2528452	et	4	main
veepargi	doc_491521501865_item	2528453	et	3	main
on	doc_491521501865_item	2528458	et	4	main
tugev	doc_491521501865_item	2528459	et	4	main
loomaaia	doc_491521501865_item	2528463	et	4	main
voimalikud	doc_491521501865_item	2528471	et	4	main
segi	doc_491521501865_item	2528475	et	3	main
ja	doc_491521501865_item	2528478	et	3	main
ja	doc_491521501865_item	2528480	et	3	main
teinud	doc_491521501865_item	2528490	et	4	main
viga	doc_491521501865_item	2528497	et	4	main
pohjustas	doc_491521501865_item	2528498	et	4	main
objektivead	doc_491521501865_item	2528505	et	4	main
vale	doc_491521501865_item	2528511	et	4	main
tegevus	doc_491521501865_item	2528516	et	4	main
mitmuses	doc_491521501865_item	2528525	et	3	main
objekt	doc_491521501865_item	2528527	et	3	main
olema	doc_491521501865_item	2528529	et	4	main
nimetavas	doc_491521501865_item	2528531	et	4	main
kaandes	doc_491521501865_item	2528532	et	4	main
esineb	doc_491521501865_item	2528537	et	3	main
objekt	doc_491521501865_item	2528538	et	3	main
alati	doc_491521501865_item	2528539	et	4	main
paljudel	doc_491521501865_item	2528546	et	3	main
osastava	doc_491521501865_item	2528548	et	4	main
kaandega	doc_491521501865_item	2528549	et	4	main
vorm	doc_491521501865_item	2528554	et	3	main
seda	doc_491521501865_item	2528559	et	3	main
selle	doc_491521501865_item	2528562	et	4	main
voimalik	doc_491521501865_item	2528564	et	4	main
3	doc_491521501865_item	2528570	et	2	main
soit	doc_491521501865_item	2528604	et	4	main
ei	doc_491521501865_item	2528612	et	4	main
moelnud	doc_491521501865_item	2528613	et	4	main
tegevuse	doc_491521501865_item	2528614	et	4	main
lopetatusele	doc_491521501865_item	2528615	et	4	main
kaande	doc_491521501865_item	2528631	et	3	main
viga	doc_491521501865_item	2528640	et	4	main
lapimaale	doc_491521501865_item	2528644	et	4	main
helsingi	doc_491521501865_item	2528661	et	4	main
voimalik	doc_491521501865_item	2528665	et	4	main
kuueks	doc_491521501865_item	2528676	et	4	main
neliteist	doc_491521501865_item	2528688	et	4	main
kell	doc_491521501865_item	2528689	et	3	main
kella	doc_491521501865_item	2528691	et	4	main
verbirektsioon	doc_491521501865_item	2528722	et	4	main
eesti	doc_491521501865_item	2528724	et	4	main
see	doc_491521501865_item	2528731	et	3	main
3ctoxcxom	doc_491521501865_item	2528738	et	4	main
tahenduses	doc_491521501865_item	2528740	et	4	main
kainud	doc_491521501865_item	2528748	et	4	main
kuskil	doc_491521501865_item	2528749	et	3	main
toenaoliselt	doc_491521501865_item	2528750	et	4	main
on	doc_491521501865_item	2528751	et	4	main
koik	doc_491521501865_item	2528760	et	4	main
raakida	doc_491521501865_item	2528763	et	4	main
pohjuste	doc_491521501865_item	2528316	et	4	main
1	doc_491521501865_item	2528319	et	2	main
jou-	doc_491521501865_item	2528326	et	4	main
oudu	doc_491521501865_item	2528334	et	4	main
ning	doc_491521501865_item	2528335	et	3	main
on	doc_491521501865_item	2528341	et	4	main
joudne	doc_491521501865_item	2528342	et	4	main
voimalikud	doc_491521501865_item	2528343	et	4	main
pohjused	doc_491521501865_item	2528344	et	4	main
oudne	doc_491521501865_item	2528351	et	4	main
neid	doc_491521501865_item	2528362	et	4	main
konelejal	doc_491521501865_item	2528365	et	4	main
haaldatakse	doc_491521501865_item	2528385	et	4	main
see	doc_491521501865_item	2528392	et	3	main
vale	doc_491521501865_item	2528398	et	4	main
soomlased	doc_491521501865_item	2528400	et	3	main
pearohk	doc_491521501865_item	2528401	et	4	main
on	doc_491521501865_item	2528402	et	4	main
teisel	doc_491521501865_item	2528403	et	4	main
silbil	doc_491521501865_item	2528404	et	3	main
see	doc_491521501865_item	2528405	et	3	main
on	doc_491521501865_item	2528406	et	4	main
korduv	doc_491521501865_item	2528407	et	4	main
viga	doc_491521501865_item	2528408	et	4	main
samuti	doc_491521501865_item	2528409	et	3	main
haaldab	doc_491521501865_item	2528410	et	4	main
ta	doc_491521501865_item	2528411	et	4	main
venela	doc_491521501865_item	2528412	et	4	main
ne	doc_491521501865_item	2528413	et	4	main
eestla	doc_491521501865_item	2528414	et	4	main
ne	doc_491521501865_item	2528415	et	4	main
nagu	doc_491521501865_item	2528416	et	3	main
vene	doc_491521501865_item	2528417	et	4	main
nimi	doc_491521501865_item	2528418	et	3	main
cbetnaxa	doc_491521501865_item	2528419	et	4	main
astmevahelduse	doc_491521501865_item	2528420	et	4	main
1	doc_491521501865_item	2528422	et	2	main
norga	doc_491521501865_item	2528425	et	4	main
asemel	doc_491521501865_item	2528427	et	4	main
tugev	doc_491521501865_item	2528429	et	4	main
nimetavas	doc_491521501865_item	2528440	et	4	main
kabi	doc_491521501865_item	2528447	et	3	main
jne	doc_491521501865_item	2528449	et	4	main
akvaparki	doc_491521501865_item	2528451	et	4	main
asemel	doc_491521501865_item	2528457	et	4	main
on	doc_491521501865_item	2528468	et	4	main
sonade	doc_491521501865_item	2528476	et	4	main
osastava	doc_491521501865_item	2528481	et	4	main
kaande	doc_491521501865_item	2528482	et	3	main
ta	doc_491521501865_item	2528486	et	4	main
viga	doc_491521501865_item	2528488	et	4	main
ei	doc_491521501865_item	2528489	et	4	main
parki	doc_491521501865_item	2528503	et	4	main
veenaiteid	doc_491521501865_item	2528508	et	4	main
on	doc_491521501865_item	2528524	et	4	main
mitmuse	doc_491521501865_item	2528530	et	3	main
vene	doc_491521501865_item	2528535	et	4	main
keeles	doc_491521501865_item	2528536	et	4	main
kaandes	doc_491521501865_item	2528541	et	4	main
on	doc_491521501865_item	2528551	et	4	main
tihti	doc_491521501865_item	2528552	et	3	main
sonast	doc_491521501865_item	2528555	et	4	main
pohjus	doc_491521501865_item	2528565	et	4	main
millegi	doc_491521501865_item	2528594	et	4	main
pidud	doc_491521501865_item	2528423	et	3	main
astme	doc_491521501865_item	2528426	et	3	main
pohjus	doc_491521501865_item	2528432	et	4	main
on	doc_491521501865_item	2528437	et	4	main
uhesuguse	doc_491521501865_item	2528438	et	4	main
kujuga	doc_491521501865_item	2528439	et	3	main
omastavas	doc_491521501865_item	2528441	et	4	main
ja	doc_491521501865_item	2528442	et	3	main
osastavas	doc_491521501865_item	2528443	et	4	main
aste	doc_491521501865_item	2528460	et	4	main
norga	doc_491521501865_item	2528465	et	4	main
astme	doc_491521501865_item	2528466	et	3	main
pohjused	doc_491521501865_item	2528472	et	4	main
aleksandr	doc_491521501865_item	2528473	et	4	main
loomaaedomastava	doc_491521501865_item	2528479	et	3	main
teistel	doc_491521501865_item	2528484	et	4	main
sellist	doc_491521501865_item	2528487	et	4	main
kompveki	doc_491521501865_item	2528494	et	4	main
vabariigi	doc_491521501865_item	2528495	et	3	main
kulastamine	doc_491521501865_item	2528496	et	4	main
loomaaeda	doc_491521501865_item	2528504	et	4	main
votsin	doc_491521501865_item	2528509	et	4	main
veenaidud	doc_491521501865_item	2528510	et	3	main
on	doc_491521501865_item	2528517	et	4	main
luhiajaline	doc_491521501865_item	2528518	et	4	main
ja	doc_491521501865_item	2528519	et	3	main
ajas	doc_491521501865_item	2528520	et	4	main
ning	doc_491521501865_item	2528522	et	3	main
jarelikult	doc_491521501865_item	2528526	et	4	main
pohjused	doc_491521501865_item	2528534	et	4	main
bxxxtenbxbw	doc_491521501865_item	2528540	et	4	main
bxxhtenbxbw	doc_491521501865_item	2528543	et	4	main
assotsieerub	doc_491521501865_item	2528545	et	3	main
venelastel	doc_491521501865_item	2528547	et	4	main
naiteid	doc_491521501865_item	2528550	et	4	main
naide	doc_491521501865_item	2528556	et	4	main
leidsin	doc_491521501865_item	2528561	et	3	main
reisi	doc_491521501865_item	2528563	et	4	main
tulevad	doc_491521501865_item	2528571	et	4	main
torude	doc_491521501865_item	2528572	et	3	main
vahetama	doc_491521501865_item	2528573	et	3	main
tulevad	doc_491521501865_item	2528574	et	4	main
torusid	doc_491521501865_item	2528575	et	3	main
vahetama	doc_491521501865_item	2528576	et	3	main
voimalik	doc_491521501865_item	2528577	et	4	main
pohjus	doc_491521501865_item	2528578	et	4	main
kuna	doc_491521501865_item	2528579	et	3	main
aleksandr	doc_491521501865_item	2528580	et	4	main
tootab	doc_491521501865_item	2528581	et	4	main
ehitusfirmas	doc_491521501865_item	2528582	et	3	main
on	doc_491521501865_item	2528583	et	4	main
ta	doc_491521501865_item	2528584	et	4	main
ilmselt	doc_491521501865_item	2528585	et	4	main
mitu	doc_491521501865_item	2528586	et	4	main
korda	doc_491521501865_item	2528587	et	4	main
nainud	doc_491521501865_item	2528588	et	4	main
voi	doc_491521501865_item	2528589	et	4	main
kuulnud	doc_491521501865_item	2528590	et	4	main
sonauhendit	doc_491521501865_item	2528591	et	4	main
torude	doc_491521501865_item	2528592	et	3	main
voi	doc_491521501865_item	2528593	et	4	main
votsin	doc_491521501865_item	2528598	et	4	main
toolise	doc_491521501865_item	2528601	et	4	main
bussiga	doc_491521501865_item	2528605	et	3	main
vaid	doc_491521501865_item	2528616	et	3	main
see	doc_491521501865_item	2528621	et	3	main
4	doc_491521501865_item	2528597	et	2	main
endale	doc_491521501865_item	2528607	et	4	main
voimalik	doc_491521501865_item	2528609	et	4	main
pohjus	doc_491521501865_item	2528610	et	4	main
aleksandr	doc_491521501865_item	2528611	et	4	main
kasutas	doc_491521501865_item	2528618	et	3	main
on	doc_491521501865_item	2528622	et	4	main
kohakaanete	doc_491521501865_item	2528626	et	4	main
1	doc_491521501865_item	2528628	et	2	main
luhikese	doc_491521501865_item	2528629	et	4	main
lapimaa	doc_491521501865_item	2528642	et	4	main
minema	doc_491521501865_item	2528647	et	3	main
tahtsin	doc_491521501865_item	2528648	et	3	main
saabumine	doc_491521501865_item	2528658	et	4	main
valjumine	doc_491521501865_item	2528660	et	4	main
helsingisse	doc_491521501865_item	2528664	et	4	main
pohjus	doc_491521501865_item	2528666	et	4	main
luhikese	doc_491521501865_item	2528667	et	4	main
kaandevead	doc_491521501865_item	2528673	et	4	main
1	doc_491521501865_item	2528674	et	2	main
kell	doc_491521501865_item	2528675	et	3	main
kuueks	doc_491521501865_item	2528678	et	4	main
kaheteistkumneni	doc_491521501865_item	2528682	et	4	main
kella	doc_491521501865_item	2528683	et	4	main
uheteistkumnest	doc_491521501865_item	2528684	et	4	main
1	doc_491521501865_item	2528721	et	2	main
et	doc_491521501865_item	2528730	et	3	main
ei	doc_491521501865_item	2528747	et	4	main
kaima	doc_491521501865_item	2528754	et	4	main
xoaktb	doc_491521501865_item	2528756	et	4	main
on	doc_491521501865_item	2528759	et	4	main
mida	doc_491521501865_item	2528761	et	4	main
tahtsin	doc_491521501865_item	2528762	et	3	main
tahtsin	doc_491521501865_item	2528768	et	3	main
pakkusid	doc_491521501865_item	2528797	et	4	main
kolm	doc_491521501865_item	2528798	et	3	main
pohjus	doc_491521501865_item	2528804	et	4	main
kella	doc_491521501865_item	2528825	et	4	main
nimisona	doc_491521501865_item	2528835	et	4	main
kaheksandal	doc_491521501865_item	2528839	et	3	main
kaheksandal	doc_491521501865_item	2528842	et	3	main
pohjus	doc_491521501865_item	2528844	et	4	main
isikus	doc_491521501865_item	2528856	et	3	main
nad	doc_491521501865_item	2528861	et	3	main
tegi	doc_491521501865_item	2528864	et	4	main
sa	doc_491521501865_item	2528869	et	3	main
kasutamine	doc_491521501865_item	2528883	et	4	main
helistan	doc_491521501865_item	2528884	et	3	main
ema	doc_491521501865_item	2528887	et	4	main
kusib	doc_491521501865_item	2528888	et	4	main
helistasin	doc_491521501865_item	2528889	et	3	main
kusis	doc_491521501865_item	2528893	et	4	main
et	doc_491521501865_item	2528895	et	3	main
votsin	doc_491521501865_item	2528600	et	4	main
valisin	doc_491521501865_item	2528602	et	3	main
valisin	doc_491521501865_item	2528606	et	3	main
lihtsalt	doc_491521501865_item	2528617	et	4	main
sona	doc_491521501865_item	2528619	et	4	main
ka	doc_491521501865_item	2528623	et	3	main
kus	doc_491521501865_item	2528634	et	3	main
vormi	doc_491521501865_item	2528636	et	4	main
ole	doc_491521501865_item	2528638	et	4	main
korduv	doc_491521501865_item	2528639	et	4	main
lapimaa	doc_491521501865_item	2528646	et	4	main
lapimaale	doc_491521501865_item	2528649	et	4	main
valjumine	doc_491521501865_item	2528651	et	4	main
lapimaa	doc_491521501865_item	2528652	et	4	main
valjasoit	doc_491521501865_item	2528653	et	4	main
helsingist	doc_491521501865_item	2528654	et	4	main
helsingisse	doc_491521501865_item	2528659	et	4	main
valjasoit	doc_491521501865_item	2528662	et	4	main
funktsiooni	doc_491521501865_item	2528670	et	4	main
absolutiseerimine	doc_491521501865_item	2528671	et	4	main
muud	doc_491521501865_item	2528672	et	4	main
kella	doc_491521501865_item	2528677	et	4	main
kell	doc_491521501865_item	2528679	et	3	main
uheksateist	doc_491521501865_item	2528680	et	4	main
kaheteistkumneni	doc_491521501865_item	2528686	et	4	main
kuueteistkumneni	doc_491521501865_item	2528690	et	4	main
neljateistkumnest	doc_491521501865_item	2528692	et	4	main
kella	doc_491521501865_item	2528693	et	4	main
omane	doc_491521501865_item	2528625	et	3	main
vead	doc_491521501865_item	2528627	et	4	main
sisseutleva	doc_491521501865_item	2528630	et	4	main
sonadel	doc_491521501865_item	2528633	et	4	main
laheme	doc_491521501865_item	2528641	et	4	main
tahtsin	doc_491521501865_item	2528645	et	3	main
lapimaale	doc_491521501865_item	2528655	et	4	main
tulek	doc_491521501865_item	2528656	et	3	main
helsingi	doc_491521501865_item	2528657	et	4	main
sisseutleva	doc_491521501865_item	2528668	et	4	main
kaande	doc_491521501865_item	2528669	et	3	main
kella	doc_491521501865_item	2528685	et	4	main
kuueteistkiimneni	doc_491521501865_item	2528694	et	4	main
korduv	doc_491521501865_item	2528695	et	4	main
viga	doc_491521501865_item	2528696	et	4	main
2	doc_491521501865_item	2528697	et	2	main
kahekumne	doc_491521501865_item	2528698	et	4	main
kuuendal	doc_491521501865_item	2528699	et	3	main
kahekumne	doc_491521501865_item	2528700	et	4	main
uheksandani	doc_491521501865_item	2528701	et	4	main
detsembrini	doc_491521501865_item	2528702	et	3	main
kahekumne	doc_491521501865_item	2528703	et	4	main
kuuendast	doc_491521501865_item	2528704	et	3	main
kahekumne	doc_491521501865_item	2528705	et	4	main
uheksanda	doc_491521501865_item	2528706	et	4	main
detsembrini	doc_491521501865_item	2528707	et	3	main
kahekumne	doc_491521501865_item	2528708	et	4	main
kolmandal	doc_491521501865_item	2528709	et	3	main
kahekumne	doc_491521501865_item	2528710	et	4	main
kaheksandakeni	doc_491521501865_item	2528711	et	4	main
detsembrini	doc_491521501865_item	2528712	et	3	main
kahekumne	doc_491521501865_item	2528713	et	4	main
kolmandast	doc_491521501865_item	2528714	et	4	main
kahekumne	doc_491521501865_item	2528715	et	4	main
kaheksanda	doc_491521501865_item	2528716	et	3	main
detsembrini	doc_491521501865_item	2528717	et	3	main
korduv	doc_491521501865_item	2528718	et	4	main
viga	doc_491521501865_item	2528719	et	4	main
rektsioonivead	doc_491521501865_item	2528720	et	4	main
voimalik	doc_491521501865_item	2528729	et	4	main
interferentsiviga	doc_491521501865_item	2528733	et	4	main
oppima	doc_491521501865_item	2528741	et	4	main
koik	doc_491521501865_item	2528766	et	4	main
millest	doc_491521501865_item	2528767	et	3	main
ilmselt	doc_491521501865_item	2528771	et	4	main
pakkumist	doc_491521501865_item	2528799	et	4	main
kaks	doc_491521501865_item	2528800	et	3	main
oo	doc_491521501865_item	2528801	et	3	main
arvsona	doc_491521501865_item	2528807	et	4	main
kaanamine	doc_491521501865_item	2528808	et	4	main
1	doc_491521501865_item	2528809	et	2	main
jargarvsona	doc_491521501865_item	2528810	et	4	main
tegeleme	doc_491521501865_item	2528723	et	3	main
keeles	doc_491521501865_item	2528725	et	4	main
tegeleme	doc_491521501865_item	2528726	et	3	main
eesti	doc_491521501865_item	2528727	et	4	main
keelega	doc_491521501865_item	2528728	et	3	main
ha	doc_491521501865_item	2528737	et	4	main
eesti	doc_491521501865_item	2528742	et	4	main
kainud	doc_491521501865_item	2528745	et	4	main
kuhugi	doc_491521501865_item	2528746	et	4	main
see	doc_491521501865_item	2528752	et	3	main
kus	doc_491521501865_item	2528755	et	3	main
xyaa	doc_491521501865_item	2528757	et	4	main
samuti	doc_491521501865_item	2528774	et	3	main
interferentsiviga	doc_491521501865_item	2528775	et	4	main
vrd	doc_491521501865_item	2528776	et	4	main
vene	doc_491521501865_item	2528777	et	4	main
bce	doc_491521501865_item	2528779	et	4	main
nto	doc_491521501865_item	2528780	et	4	main
wo	doc_491521501865_item	2528778	et	4	main
x	doc_491521501865_item	2528781	et	4	main
xoten	doc_491521501865_item	2528782	et	4	main
cxasatb	doc_491521501865_item	2528783	et	4	main
solvusin	doc_491521501865_item	2528784	et	3	main
sellesse	doc_491521501865_item	2528785	et	4	main
solvusin	doc_491521501865_item	2528786	et	3	main
selle	doc_491521501865_item	2528787	et	4	main
2	doc_491521501865_item	2528789	et	2	main
arvsona	doc_491521501865_item	2528790	et	4	main
rektsioon	doc_491521501865_item	2528791	et	3	main
peale	doc_491521501865_item	2528788	et	4	main
us	doc_491521501865_item	2528792	et	4	main
nadalat	doc_491521501865_item	2528793	et	4	main
iiks	doc_491521501865_item	2528794	et	4	main
nadal	doc_491521501865_item	2528795	et	4	main
kolm	doc_491521501865_item	2528796	et	3	main
see	doc_491521501865_item	2528764	et	3	main
raakida	doc_491521501865_item	2528769	et	4	main
on	doc_491521501865_item	2528772	et	4	main
see	doc_491521501865_item	2528773	et	3	main
ood	doc_491521501865_item	2528803	et	3	main
reegli	doc_491521501865_item	2528805	et	3	main
kaheteistkumneni	doc_491521501865_item	2528817	et	4	main
neliteist	doc_491521501865_item	2528819	et	4	main
viga	doc_491521501865_item	2528824	et	4	main
kella	doc_491521501865_item	2528827	et	4	main
uhildumine	doc_491521501865_item	2528836	et	4	main
kaandes	doc_491521501865_item	2528837	et	4	main
oeldise	doc_491521501865_item	2528854	et	4	main
ja	doc_491521501865_item	2528857	et	3	main
valiku	doc_491521501865_item	2528872	et	3	main
asemel	doc_491521501865_item	2528876	et	4	main
koneviisi	doc_491521501865_item	2528881	et	4	main
eile	doc_491521501865_item	2528890	et	3	main
ei	doc_491521501865_item	2528929	et	4	main
segiajamine	doc_491521501865_item	2528941	et	4	main
ei	doc_491521501865_item	2528947	et	4	main
minema	doc_491521501865_item	2528966	et	3	main
minna	doc_491521501865_item	2528969	et	3	main
vene	doc_491521501865_item	2528971	et	4	main
puudsi	doc_491521501865_item	2528980	et	4	main
enam	doc_491521501865_item	2528984	et	4	main
pohjused	doc_491521501865_item	2528986	et	4	main
analoogia	doc_491521501865_item	2528987	et	4	main
piiiidsi	doc_491521501865_item	2528998	et	4	main
suhtleb	doc_491521501865_item	2529003	et	3	main
vorus	doc_491521501865_item	2529005	et	4	main
elavate	doc_491521501865_item	2529006	et	4	main
keelest	doc_491521501865_item	2529014	et	4	main
vene	doc_491521501865_item	2529021	et	4	main
vrd	doc_491521501865_item	2529030	et	4	main
vene	doc_491521501865_item	2529031	et	4	main
rlapom	doc_491521501865_item	2529032	et	4	main
ja	doc_491521501865_item	2529045	et	3	main
tottu	doc_491521501865_item	2529051	et	4	main
vrd	doc_491521501865_item	2529061	et	4	main
vene	doc_491521501865_item	2529062	et	4	main
rlonapxbw	doc_491521501865_item	2529063	et	4	main
homonuumia	doc_491521501865_item	2529066	et	4	main
kolm	doc_491521501865_item	2529095	et	3	main
valiku	doc_491521501865_item	2529099	et	3	main
kohal	doc_491521501865_item	2529114	et	4	main
kell	doc_491521501865_item	2529115	et	3	main
kaheksa	doc_491521501865_item	2529116	et	4	main
sest	doc_491521501865_item	2529120	et	4	main
korda	doc_491521501865_item	2529123	et	4	main
kasvoi	doc_491521501865_item	2529125	et	4	main
teha	doc_491521501865_item	2529131	et	3	main
teha	doc_491521501865_item	2529134	et	3	main
plitka	doc_491521501865_item	2529138	et	4	main
nii	doc_491521501865_item	2529145	et	3	main
jaoks	doc_491521501865_item	2529149	et	4	main
kiiresti	doc_491521501865_item	2529150	et	3	main
viisa	doc_491521501865_item	2529153	et	4	main
kinni	doc_491521501865_item	2529165	et	3	main
kaetud	doc_491521501865_item	2529166	et	4	main
valjumine	doc_491521501865_item	2529169	et	4	main
voi	doc_491521501865_item	2529190	et	4	main
kui	doc_491521501865_item	2529194	et	3	main
kulastamine	doc_491521501865_item	2529205	et	4	main
kolmas	doc_491521501865_item	2529206	et	3	main
variant	doc_491521501865_item	2529207	et	3	main
ma	doc_491521501865_item	2529216	et	3	main
tahaksin	doc_491521501865_item	2529217	et	3	main
ma	doc_491521501865_item	2529221	et	3	main
taha	doc_491521501865_item	2529223	et	4	main
ei	doc_491521501865_item	2529228	et	4	main
teha	doc_491521501865_item	2529233	et	3	main
hfert	doc_491521501865_item	2529239	et	4	main
ole	doc_491521501865_item	2529256	et	4	main
iildse	doc_491521501865_item	2529261	et	4	main
korteris	doc_491521501865_item	2529271	et	3	main
pole	doc_491521501865_item	2529272	et	3	main
remont	doc_491521501865_item	2529273	et	3	main
loppenud	doc_491521501865_item	2529274	et	4	main
on	doc_491521501865_item	2529280	et	4	main
uldse	doc_491521501865_item	2529286	et	4	main
aega	doc_491521501865_item	2529294	et	4	main
unustamine	doc_491521501865_item	2528806	et	4	main
kaheteistkiimneni	doc_491521501865_item	2528816	et	4	main
vale	doc_491521501865_item	2528811	et	4	main
kell	doc_491521501865_item	2528818	et	3	main
kuueteistkumneni	doc_491521501865_item	2528821	et	4	main
uheteistkumnest	doc_491521501865_item	2528826	et	4	main
kella	doc_491521501865_item	2528828	et	4	main
neljateistkumnest	doc_491521501865_item	2528829	et	4	main
kahekumne	doc_491521501865_item	2528841	et	4	main
grammatikareeglite	doc_491521501865_item	2528845	et	3	main
vrd	doc_491521501865_item	2528847	et	4	main
novembris	doc_491521501865_item	2528848	et	3	main
esimesel	doc_491521501865_item	2528849	et	3	main
novembril	doc_491521501865_item	2528850	et	3	main
uhildumine	doc_491521501865_item	2528855	et	4	main
tulevad	doc_491521501865_item	2528860	et	4	main
tulevad	doc_491521501865_item	2528862	et	4	main
l	doc_491521501865_item	2528874	et	4	main
ja	doc_491521501865_item	2528891	et	3	main
voimalik	doc_491521501865_item	2528894	et	4	main
on	doc_491521501865_item	2528897	et	4	main
vaba	doc_491521501865_item	2528921	et	4	main
esimene	doc_491521501865_item	2528923	et	3	main
kord	doc_491521501865_item	2528924	et	4	main
kui	doc_491521501865_item	2528925	et	3	main
ma	doc_491521501865_item	2528926	et	3	main
tahtsin	doc_491521501865_item	2528927	et	3	main
minna	doc_491521501865_item	2528928	et	3	main
nende	doc_491521501865_item	2528942	et	4	main
tule	doc_491521501865_item	2528948	et	4	main
valja	doc_491521501865_item	2528949	et	3	main
hakkame	doc_491521501865_item	2528957	et	3	main
tootada	doc_491521501865_item	2528958	et	4	main
hakkame	doc_491521501865_item	2528959	et	3	main
voi	doc_491521501865_item	2528961	et	4	main
asume	doc_491521501865_item	2528962	et	3	main
toole	doc_491521501865_item	2528963	et	3	main
tahtsin	doc_491521501865_item	2528964	et	3	main
lapimaa	doc_491521501865_item	2528965	et	4	main
us	doc_491521501865_item	2528975	et	4	main
enam	doc_491521501865_item	2528981	et	4	main
piiiia	doc_491521501865_item	2528995	et	4	main
taust	doc_491521501865_item	2529001	et	4	main
aeg-ajalt	doc_491521501865_item	2529004	et	4	main
tolkelaenud	doc_491521501865_item	2529012	et	4	main
keraamiplitka	doc_491521501865_item	2529017	et	4	main
keraamiline	doc_491521501865_item	2529018	et	3	main
praamiga	doc_491521501865_item	2529029	et	4	main
saun	doc_491521501865_item	2529034	et	3	main
cayxa	doc_491521501865_item	2529037	et	4	main
vepslased	doc_491521501865_item	2529039	et	3	main
vene	doc_491521501865_item	2529041	et	4	main
serlcbi	doc_491521501865_item	2529042	et	4	main
vene	doc_491521501865_item	2529046	et	4	main
labi	doc_491521501865_item	2529057	et	4	main
xpyr	doc_491521501865_item	2529064	et	4	main
vorut	doc_491521501865_item	2529070	et	4	main
kolm	doc_491521501865_item	2529093	et	3	main
pakkusid	doc_491521501865_item	2529094	et	4	main
sona	doc_491521501865_item	2529098	et	4	main
valja	doc_491521501865_item	2529110	et	3	main
selleparast	doc_491521501865_item	2529117	et	3	main
nadalas	doc_491521501865_item	2529124	et	4	main
korda	doc_491521501865_item	2529127	et	4	main
nadalas	doc_491521501865_item	2529128	et	4	main
piiudsin	doc_491521501865_item	2529129	et	4	main
uht-teist	doc_491521501865_item	2529133	et	4	main
ta	doc_491521501865_item	2529136	et	4	main
tegi	doc_491521501865_item	2529137	et	4	main
plaate	doc_491521501865_item	2529141	et	3	main
saadik	doc_491521501865_item	2529191	et	4	main
helistaksin	doc_491521501865_item	2529196	et	3	main
on	doc_491521501865_item	2529208	et	4	main
juba	doc_491521501865_item	2529209	et	3	main
ei	doc_491521501865_item	2529218	et	4	main
saa	doc_491521501865_item	2529229	et	4	main
teha	doc_491521501865_item	2529230	et	3	main
he	doc_491521501865_item	2529237	et	4	main
t	doc_491521501865_item	2529240	et	4	main
on	doc_491521501865_item	2529242	et	4	main
elu	doc_491521501865_item	2529243	et	4	main
vrd	doc_491521501865_item	2529248	et	4	main
vene	doc_491521501865_item	2529249	et	4	main
3to	doc_491521501865_item	2529250	et	4	main
kella	doc_491521501865_item	2528830	et	4	main
lthildumisvead	doc_491521501865_item	2528831	et	4	main
kahekumne	doc_491521501865_item	2528838	et	4	main
arvus	doc_491521501865_item	2528858	et	3	main
ma	doc_491521501865_item	2528865	et	3	main
sa	doc_491521501865_item	2528867	et	3	main
lubasid	doc_491521501865_item	2528870	et	4	main
verbivormide	doc_491521501865_item	2528871	et	4	main
oleviku	doc_491521501865_item	2528877	et	3	main
vormi	doc_491521501865_item	2528882	et	4	main
ja	doc_491521501865_item	2528886	et	3	main
ema	doc_491521501865_item	2528892	et	4	main
interferentsiviga	doc_491521501865_item	2528898	et	4	main
vene	doc_491521501865_item	2528899	et	4	main
keelele	doc_491521501865_item	2528900	et	4	main
on	doc_491521501865_item	2528901	et	4	main
omane	doc_491521501865_item	2528902	et	3	main
kaudse	doc_491521501865_item	2528903	et	3	main
oleviku	doc_491521501865_item	2528904	et	3	main
kasutamine	doc_491521501865_item	2528905	et	4	main
vrd	doc_491521501865_item	2528906	et	4	main
bxepa	doc_491521501865_item	2528907	et	4	main
3boxio	doc_491521501865_item	2528908	et	4	main
poahtenxm	doc_491521501865_item	2528909	et	4	main
x	doc_491521501865_item	2528910	et	4	main
cxpaiuhsaet	doc_491521501865_item	2528912	et	4	main
esimene	doc_491521501865_item	2528913	et	3	main
mama	doc_491521501865_item	2528911	et	4	main
kord	doc_491521501865_item	2528914	et	4	main
kui	doc_491521501865_item	2528915	et	3	main
ma	doc_491521501865_item	2528916	et	3	main
tahaksin	doc_491521501865_item	2528917	et	3	main
ei	doc_491521501865_item	2528918	et	4	main
ole	doc_491521501865_item	2528919	et	4	main
passis	doc_491521501865_item	2528920	et	4	main
olnud	doc_491521501865_item	2528930	et	4	main
pohjus	doc_491521501865_item	2528935	et	4	main
mineviku	doc_491521501865_item	2528936	et	3	main
tingiva	doc_491521501865_item	2528938	et	4	main
sarnasuse	doc_491521501865_item	2528945	et	4	main
lapimaale	doc_491521501865_item	2528968	et	4	main
pohjus	doc_491521501865_item	2528970	et	4	main
keeles	doc_491521501865_item	2528972	et	4	main
infinitiivivorm	doc_491521501865_item	2528976	et	4	main
verbivormi	doc_491521501865_item	2528977	et	4	main
puudnud	doc_491521501865_item	2528983	et	4	main
voimalikud	doc_491521501865_item	2528985	et	4	main
olevikuvormi	doc_491521501865_item	2528991	et	4	main
moodustamisega	doc_491521501865_item	2528992	et	4	main
aleksandr	doc_491521501865_item	2529002	et	4	main
a	doc_491521501865_item	2529011	et	4	main
plitka	doc_491521501865_item	2529015	et	4	main
plaat	doc_491521501865_item	2529019	et	3	main
vene	doc_491521501865_item	2529036	et	4	main
eesti	doc_491521501865_item	2529044	et	4	main
segiajamine	doc_491521501865_item	2529048	et	4	main
polaarjoone	doc_491521501865_item	2529060	et	3	main
votsin	doc_491521501865_item	2529089	et	4	main
ja	doc_491521501865_item	2529101	et	3	main
vormistasin	doc_491521501865_item	2529103	et	3	main
segiajamine	doc_491521501865_item	2528846	et	4	main
2	doc_491521501865_item	2528851	et	2	main
aluse	doc_491521501865_item	2528852	et	4	main
ja	doc_491521501865_item	2528853	et	3	main
ta	doc_491521501865_item	2528859	et	4	main
ma	doc_491521501865_item	2528863	et	3	main
tegin	doc_491521501865_item	2528866	et	3	main
lubas	doc_491521501865_item	2528868	et	3	main
vead	doc_491521501865_item	2528873	et	4	main
mineviku	doc_491521501865_item	2528875	et	3	main
j	doc_491521501865_item	2528878	et	4	main
a	doc_491521501865_item	2528879	et	4	main
tingiva	doc_491521501865_item	2528880	et	4	main
eile	doc_491521501865_item	2528885	et	3	main
see	doc_491521501865_item	2528896	et	3	main
lehte	doc_491521501865_item	2528922	et	4	main
mul	doc_491521501865_item	2528931	et	3	main
passis	doc_491521501865_item	2528932	et	4	main
vaba	doc_491521501865_item	2528933	et	4	main
ja	doc_491521501865_item	2528937	et	3	main
koneviisi	doc_491521501865_item	2528939	et	4	main
vormi	doc_491521501865_item	2528940	et	4	main
tottu	doc_491521501865_item	2528946	et	4	main
tahtsin	doc_491521501865_item	2528967	et	3	main
ainult	doc_491521501865_item	2528974	et	4	main
ei	doc_491521501865_item	2528979	et	4	main
piiiian	doc_491521501865_item	2528993	et	4	main
ei	doc_491521501865_item	2528994	et	4	main
ei	doc_491521501865_item	2528997	et	4	main
voru	doc_491521501865_item	2528999	et	4	main
vead	doc_491521501865_item	2529009	et	4	main
1	doc_491521501865_item	2529010	et	2	main
lehte	doc_491521501865_item	2528934	et	4	main
verbivormide	doc_491521501865_item	2528943	et	4	main
kolalise	doc_491521501865_item	2528944	et	4	main
ei	doc_491521501865_item	2528950	et	4	main
tulnud	doc_491521501865_item	2528951	et	4	main
valja	doc_491521501865_item	2528952	et	3	main
2	doc_491521501865_item	2528953	et	2	main
infinitiivi	doc_491521501865_item	2528954	et	4	main
valiku	doc_491521501865_item	2528955	et	3	main
vead	doc_491521501865_item	2528956	et	4	main
tootama	doc_491521501865_item	2528960	et	4	main
on	doc_491521501865_item	2528973	et	4	main
moodustamisvead	doc_491521501865_item	2528978	et	4	main
ei	doc_491521501865_item	2528982	et	4	main
jaatava	doc_491521501865_item	2528988	et	4	main
ja	doc_491521501865_item	2528989	et	3	main
eitava	doc_491521501865_item	2528990	et	4	main
piiiidsin	doc_491521501865_item	2528996	et	4	main
murde	doc_491521501865_item	2529000	et	4	main
tellijatega	doc_491521501865_item	2529007	et	4	main
leksikaalsed	doc_491521501865_item	2529008	et	3	main
vene	doc_491521501865_item	2529013	et	4	main
plaat	doc_491521501865_item	2529016	et	3	main
vrd	doc_491521501865_item	2529020	et	4	main
nnhtxa	doc_491521501865_item	2529022	et	4	main
vannas	doc_491521501865_item	2529023	et	3	main
vannitoas	doc_491521501865_item	2529024	et	3	main
vrd	doc_491521501865_item	2529025	et	4	main
vrd	doc_491521501865_item	2529035	et	4	main
sonade	doc_491521501865_item	2529047	et	4	main
kolalise	doc_491521501865_item	2529049	et	4	main
b	doc_491521501865_item	2529052	et	4	main
me	doc_491521501865_item	2529058	et	4	main
labime	doc_491521501865_item	2529059	et	4	main
2	doc_491521501865_item	2529065	et	2	main
voru	doc_491521501865_item	2529067	et	4	main
parast	doc_491521501865_item	2529069	et	3	main
veenaiteid	doc_491521501865_item	2529090	et	4	main
pakkumist	doc_491521501865_item	2529096	et	4	main
vead	doc_491521501865_item	2529100	et	4	main
kirja	doc_491521501865_item	2529106	et	4	main
voi	doc_491521501865_item	2529119	et	4	main
vene	doc_491521501865_item	2529026	et	4	main
baxxaa	doc_491521501865_item	2529027	et	4	main
paroomiga	doc_491521501865_item	2529028	et	4	main
sauna	doc_491521501865_item	2529033	et	4	main
vepsad	doc_491521501865_item	2529038	et	4	main
vrd	doc_491521501865_item	2529040	et	4	main
pohjus	doc_491521501865_item	2529043	et	4	main
sarnasuse	doc_491521501865_item	2529050	et	4	main
otsetolge	doc_491521501865_item	2529053	et	4	main
poljari	doc_491521501865_item	2529054	et	4	main
ringist	doc_491521501865_item	2529055	et	3	main
kaimine	doc_491521501865_item	2529056	et	4	main
parast	doc_491521501865_item	2529068	et	3	main
pohjus	doc_491521501865_item	2529071	et	4	main
taga-	doc_491521501865_item	2529072	et	4	main
ja	doc_491521501865_item	2529073	et	3	main
eessona	doc_491521501865_item	2529074	et	4	main
homonuumia	doc_491521501865_item	2529075	et	4	main
3	doc_491521501865_item	2529076	et	2	main
paronuumia	doc_491521501865_item	2529077	et	4	main
ja	doc_491521501865_item	2529078	et	3	main
parafaasia	doc_491521501865_item	2529079	et	4	main
valmistan	doc_491521501865_item	2529080	et	3	main
soiduks	doc_491521501865_item	2529081	et	4	main
valmistun	doc_491521501865_item	2529082	et	3	main
soiduks	doc_491521501865_item	2529083	et	4	main
tagastame	doc_491521501865_item	2529084	et	3	main
tallinna	doc_491521501865_item	2529085	et	4	main
tuleme	doc_491521501865_item	2529086	et	3	main
tallinna	doc_491521501865_item	2529087	et	4	main
tagasi	doc_491521501865_item	2529088	et	3	main
votsin	doc_491521501865_item	2529091	et	4	main
veenaidud	doc_491521501865_item	2529092	et	3	main
4	doc_491521501865_item	2529097	et	2	main
stiilivead	doc_491521501865_item	2529102	et	3	main
veenaidud	doc_491521501865_item	2529104	et	3	main
selleparast	doc_491521501865_item	2529111	et	3	main
olema	doc_491521501865_item	2529113	et	4	main
et	doc_491521501865_item	2529118	et	3	main
kuigi	doc_491521501865_item	2529121	et	3	main
midagi	doc_491521501865_item	2529130	et	4	main
kiiresti	doc_491521501865_item	2529146	et	3	main
jaoks	doc_491521501865_item	2529157	et	4	main
torud	doc_491521501865_item	2529158	et	3	main
on	doc_491521501865_item	2529159	et	4	main
on	doc_491521501865_item	2529164	et	4	main
keraamilise	doc_491521501865_item	2529167	et	3	main
nad	doc_491521501865_item	2529192	et	3	main
ootavad	doc_491521501865_item	2529198	et	4	main
helistaksin	doc_491521501865_item	2529201	et	3	main
kulastamine	doc_491521501865_item	2529203	et	4	main
postkontori	doc_491521501865_item	2529204	et	4	main
rongireis	doc_491521501865_item	2529214	et	4	main
vahet	doc_491521501865_item	2529220	et	3	main
ei	doc_491521501865_item	2529222	et	4	main
tundi	doc_491521501865_item	2529224	et	4	main
ara	doc_491521501865_item	2529225	et	3	main
jatta	doc_491521501865_item	2529226	et	4	main
selline	doc_491521501865_item	2529246	et	4	main
interferentsiviga	doc_491521501865_item	2529247	et	4	main
ei	doc_491521501865_item	2529255	et	4	main
ole	doc_491521501865_item	2529268	et	4	main
loppenud	doc_491521501865_item	2529269	et	4	main
palju	doc_491521501865_item	2529278	et	4	main
praegu	doc_491521501865_item	2529289	et	3	main
on	doc_491521501865_item	2529296	et	4	main
interferentsivead	doc_491521501865_item	2529297	et	4	main
veaanaluus	doc_491521501866_item	2529298	et	4	main
tallinna	doc_491521501866_item	2529299	et	4	main
kuuluvad	doc_491521501866_item	2529327	et	4	main
emakeelega	doc_491521501866_item	2529329	et	3	main
kaivad	doc_491521501866_item	2529333	et	4	main
minekut	doc_491521501866_item	2529341	et	3	main
nad	doc_491521501866_item	2529343	et	3	main
7	doc_491521501866_item	2529347	et	2	main
nii	doc_491521501866_item	2529362	et	3	main
on	doc_491521501866_item	2529369	et	4	main
iisna	doc_491521501866_item	2529374	et	4	main
nork	doc_491521501866_item	2529381	et	4	main
tase	doc_491521501866_item	2529387	et	3	main
paranema	doc_491521501866_item	2529389	et	3	main
keelekursustel	doc_491521501866_item	2529391	et	3	main
piiiia	doc_491521501866_item	2529440	et	4	main
pohjustel	doc_491521501866_item	2529446	et	4	main
sobib	doc_491521501866_item	2529447	et	3	main
veaanaluusiks	doc_491521501866_item	2529448	et	4	main
kogutud	doc_491521501866_item	2529452	et	4	main
kaesolevas	doc_491521501866_item	2529454	et	4	main
analuusitakse	doc_491521501866_item	2529456	et	4	main
korduvate	doc_491521501866_item	2529458	et	4	main
naiteid	doc_491521501866_item	2529461	et	4	main
ortograafilised	doc_491521501866_item	2529462	et	4	main
viga	doc_491521501866_item	2529467	et	4	main
vene	doc_491521501866_item	2529472	et	4	main
uu	doc_491521501866_item	2529512	et	3	main
kuna	doc_491521501866_item	2529525	et	3	main
vene	doc_491521501866_item	2529526	et	4	main
3	doc_491521501866_item	2529533	et	2	main
ortograafiline	doc_491521501866_item	2529534	et	4	main
tingitud	doc_491521501866_item	2529540	et	4	main
jaaniool	doc_491521501866_item	2529552	et	4	main
tehakse	doc_491521501866_item	2529553	et	3	main
vale	doc_491521501866_item	2529557	et	4	main
kirjutatud	doc_491521501866_item	2529563	et	4	main
taht	doc_491521501866_item	2529564	et	3	main
a	doc_491521501866_item	2529565	et	4	main
ei	doc_491521501866_item	2529569	et	4	main
nende	doc_491521501866_item	2529573	et	4	main
vahel	doc_491521501866_item	2529575	et	4	main
ole	doc_491521501866_item	2529582	et	4	main
need	doc_491521501866_item	2529583	et	3	main
inimesed	doc_491521501866_item	2529584	et	3	main
panin	doc_491521501865_item	2529105	et	3	main
valjume	doc_491521501865_item	2529107	et	4	main
soidame	doc_491521501865_item	2529108	et	4	main
tallinnast	doc_491521501865_item	2529109	et	3	main
peame	doc_491521501865_item	2529112	et	4	main
piiiidsin	doc_491521501865_item	2529132	et	4	main
ta	doc_491521501865_item	2529139	et	4	main
pani	doc_491521501865_item	2529140	et	4	main
detsember	doc_491521501865_item	2529142	et	3	main
minule	doc_491521501865_item	2529144	et	3	main
minu	doc_491521501865_item	2529148	et	3	main
et	doc_491521501865_item	2529151	et	3	main
pandud	doc_491521501865_item	2529160	et	4	main
kinni	doc_491521501865_item	2529161	et	3	main
keraamiplitkaga	doc_491521501865_item	2529162	et	4	main
ma	doc_491521501865_item	2529195	et	3	main
et	doc_491521501865_item	2529199	et	3	main
posti	doc_491521501865_item	2529202	et	4	main
rongiga	doc_491521501865_item	2529210	et	4	main
kolmas	doc_491521501865_item	2529211	et	3	main
variant	doc_491521501865_item	2529212	et	3	main
on	doc_491521501865_item	2529213	et	4	main
teha	doc_491521501865_item	2529219	et	3	main
midagi	doc_491521501865_item	2529232	et	4	main
parata	doc_491521501865_item	2529234	et	3	main
interferentsiviga	doc_491521501865_item	2529235	et	4	main
xkxero	doc_491521501865_item	2529236	et	4	main
vot	doc_491521501865_item	2529254	et	3	main
selleks	doc_491521501865_item	2529258	et	4	main
iildse	doc_491521501865_item	2529259	et	4	main
pole	doc_491521501865_item	2529260	et	3	main
aega	doc_491521501865_item	2529263	et	4	main
ei	doc_491521501865_item	2529267	et	4	main
kahjuks	doc_491521501865_item	2529275	et	4	main
tood	doc_491521501865_item	2529276	et	3	main
palju	doc_491521501865_item	2529281	et	4	main
tood	doc_491521501865_item	2529282	et	3	main
minul	doc_491521501865_item	2529287	et	3	main
ole	doc_491521501865_item	2529291	et	4	main
etteiitlustest	doc_491521501866_item	2529325	et	4	main
15	doc_491521501866_item	2529330	et	2	main
enne	doc_491521501866_item	2529339	et	4	main
keelekursustele	doc_491521501866_item	2529340	et	3	main
eesti	doc_491521501866_item	2529344	et	4	main
aastat	doc_491521501866_item	2529348	et	3	main
rohutada	doc_491521501866_item	2529350	et	4	main
eesti	doc_491521501866_item	2529353	et	4	main
keelekursustel	doc_491521501866_item	2529361	et	3	main
vaatamata	doc_491521501866_item	2529364	et	4	main
keelt	doc_491521501866_item	2529372	et	4	main
ikkagi	doc_491521501866_item	2529380	et	4	main
voib	doc_491521501866_item	2529395	et	4	main
arendada	doc_491521501866_item	2529421	et	3	main
keeleoskust	doc_491521501866_item	2529423	et	3	main
motivatsioon	doc_491521501866_item	2529425	et	3	main
on	doc_491521501866_item	2529426	et	4	main
korgem	doc_491521501866_item	2529427	et	4	main
kursustel	doc_491521501866_item	2529428	et	3	main
ei	doc_491521501866_item	2529429	et	4	main
teha	doc_491521501866_item	2529438	et	3	main
ulalmainitud	doc_491521501866_item	2529445	et	4	main
paremini	doc_491521501866_item	2529449	et	4	main
keelekursustel	doc_491521501866_item	2529451	et	3	main
viljandis	doc_491521501866_item	2529464	et	4	main
tingitud	doc_491521501866_item	2529469	et	4	main
kaks	doc_491521501865_item	2529122	et	3	main
kaks	doc_491521501865_item	2529126	et	3	main
interferentsiviga	doc_491521501865_item	2529135	et	4	main
laheb	doc_491521501865_item	2529143	et	4	main
laheb	doc_491521501865_item	2529147	et	4	main
soome	doc_491521501865_item	2529152	et	3	main
panna	doc_491521501865_item	2529154	et	4	main
soome	doc_491521501865_item	2529155	et	3	main
viisa	doc_491521501865_item	2529156	et	4	main
torud	doc_491521501865_item	2529163	et	3	main
plaadiga	doc_491521501865_item	2529168	et	3	main
valjasoit	doc_491521501865_item	2529170	et	4	main
kust	doc_491521501865_item	2529171	et	4	main
kuhu	doc_491521501865_item	2529172	et	3	main
tulek	doc_491521501865_item	2529173	et	3	main
saabumine	doc_491521501865_item	2529174	et	4	main
karjalased	doc_491521501865_item	2529175	et	3	main
ja	doc_491521501865_item	2529176	et	3	main
vepslased	doc_491521501865_item	2529177	et	3	main
on	doc_491521501865_item	2529178	et	4	main
soomlastega	doc_491521501865_item	2529179	et	3	main
sugulased	doc_491521501865_item	2529180	et	3	main
sugulasrahvad	doc_491521501865_item	2529181	et	3	main
see	doc_491521501865_item	2529182	et	3	main
on	doc_491521501865_item	2529183	et	4	main
lapsepolvest	doc_491521501865_item	2529184	et	4	main
j	doc_491521501865_item	2529185	et	4	main
nii	doc_491521501865_item	2529186	et	3	main
on	doc_491521501865_item	2529187	et	4	main
lapsepolvest	doc_491521501865_item	2529188	et	4	main
peale	doc_491521501865_item	2529189	et	4	main
ootavad	doc_491521501865_item	2529193	et	4	main
nad	doc_491521501865_item	2529197	et	3	main
ma	doc_491521501865_item	2529200	et	3	main
pragmaatikavead	doc_491521501865_item	2529215	et	4	main
midagi	doc_491521501865_item	2529227	et	4	main
pole	doc_491521501865_item	2529231	et	3	main
noaenaeriib	doc_491521501865_item	2529238	et	4	main
see	doc_491521501865_item	2529241	et	3	main
elu	doc_491521501865_item	2529244	et	4	main
on	doc_491521501865_item	2529245	et	4	main
wxsxb	doc_491521501865_item	2529251	et	4	main
sonajarg	doc_491521501865_item	2529252	et	4	main
no	doc_491521501865_item	2529253	et	3	main
aega	doc_491521501865_item	2529257	et	4	main
on	doc_491521501865_item	2529277	et	4	main
praegu	doc_491521501865_item	2529283	et	3	main
ei	doc_491521501865_item	2529284	et	4	main
ole	doc_491521501865_item	2529285	et	4	main
pedagoogikaulikool	doc_491521501866_item	2529300	et	4	main
jekaterina	doc_491521501866_item	2529301	et	4	main
janusevskaja	doc_491521501866_item	2529302	et	4	main
ev-51	doc_491521501866_item	2529303	et	4	main
veaanaluus	doc_491521501866_item	2529304	et	4	main
tallinn	doc_491521501866_item	2529305	et	4	main
2001	doc_491521501866_item	2529306	et	2	main
sissejuhatus	doc_491521501866_item	2529307	et	4	main
kaesolevas	doc_491521501866_item	2529308	et	4	main
ws	doc_491521501866_item	2529309	et	4	main
esitatakse	doc_491521501866_item	2529310	et	3	main
eesti	doc_491521501866_item	2529311	et	4	main
keele	doc_491521501866_item	2529312	et	4	main
halbiva	doc_491521501866_item	2529313	et	4	main
kasutuse	doc_491521501866_item	2529314	et	4	main
naiteid	doc_491521501866_item	2529315	et	4	main
veaanaliiiisi	doc_491521501866_item	2529316	et	4	main
materjal	doc_491521501866_item	2529317	et	3	main
on	doc_491521501866_item	2529318	et	4	main
voetud	doc_491521501866_item	2529319	et	4	main
keelekursustel	doc_491521501866_item	2529320	et	3	main
kogutud	doc_491521501866_item	2529321	et	4	main
tekstidest	doc_491521501866_item	2529323	et	3	main
16-aastased	doc_491521501866_item	2529331	et	4	main
aastat	doc_491521501866_item	2529338	et	3	main
oppisid	doc_491521501866_item	2529342	et	4	main
koolis	doc_491521501866_item	2529346	et	4	main
seda	doc_491521501866_item	2529351	et	3	main
keele	doc_491521501866_item	2529354	et	4	main
oppimine	doc_491521501866_item	2529355	et	4	main
oppimisest	doc_491521501866_item	2529360	et	4	main
et	doc_491521501866_item	2529363	et	3	main
sellele	doc_491521501866_item	2529365	et	4	main
et	doc_491521501866_item	2529366	et	3	main
pikka	doc_491521501866_item	2529375	et	4	main
on	doc_491521501866_item	2529377	et	4	main
nagu	doc_491521501866_item	2529382	et	3	main
naitab	doc_491521501866_item	2529384	et	4	main
keeleoskuse	doc_491521501866_item	2529386	et	3	main
markimisvaarselt	doc_491521501866_item	2529388	et	4	main
sedaet	doc_491521501866_item	2529397	et	4	main
opilasele	doc_491521501866_item	2529399	et	4	main
puhendatakse	doc_491521501866_item	2529400	et	4	main
oma	doc_491521501866_item	2529422	et	4	main
opilaste	doc_491521501866_item	2529424	et	4	main
opilased	doc_491521501866_item	2529436	et	4	main
selleks	doc_491521501865_item	2529262	et	4	main
meie	doc_491521501865_item	2529264	et	4	main
korteris	doc_491521501865_item	2529265	et	3	main
remont	doc_491521501865_item	2529266	et	3	main
meie	doc_491521501865_item	2529270	et	4	main
kahjuks	doc_491521501865_item	2529279	et	4	main
aega	doc_491521501865_item	2529288	et	4	main
ei	doc_491521501865_item	2529290	et	4	main
minul	doc_491521501865_item	2529292	et	3	main
uldse	doc_491521501865_item	2529293	et	4	main
kirjalikest	doc_491521501866_item	2529322	et	3	main
vene	doc_491521501866_item	2529328	et	4	main
esimest	doc_491521501866_item	2529337	et	4	main
keelt	doc_491521501866_item	2529345	et	4	main
tuleb	doc_491521501866_item	2529349	et	3	main
et	doc_491521501866_item	2529352	et	3	main
tugevasti	doc_491521501866_item	2529359	et	3	main
oppinud	doc_491521501866_item	2529370	et	4	main
juba	doc_491521501866_item	2529373	et	3	main
hakkab	doc_491521501866_item	2529385	et	3	main
keelekursuste	doc_491521501866_item	2529392	et	3	main
eelisteks	doc_491521501866_item	2529394	et	4	main
igale	doc_491521501866_item	2529398	et	3	main
need	doc_491521501865_item	2529295	et	3	main
kirjanditest	doc_491521501866_item	2529324	et	4	main
uurimisruhma	doc_491521501866_item	2529326	et	4	main
opilased	doc_491521501866_item	2529332	et	4	main
eesti	doc_491521501866_item	2529334	et	4	main
keele	doc_491521501866_item	2529335	et	4	main
kursustel	doc_491521501866_item	2529336	et	3	main
koolis	doc_491521501866_item	2529356	et	4	main
erineb	doc_491521501866_item	2529357	et	3	main
vaga	doc_491521501866_item	2529358	et	4	main
uurimisruhma	doc_491521501866_item	2529367	et	4	main
oppijad	doc_491521501866_item	2529368	et	4	main
eesti	doc_491521501866_item	2529371	et	4	main
aega	doc_491521501866_item	2529376	et	4	main
nende	doc_491521501866_item	2529378	et	4	main
keeleoskus	doc_491521501866_item	2529379	et	3	main
praktika	doc_491521501866_item	2529383	et	4	main
alles	doc_491521501866_item	2529390	et	3	main
pohilisteks	doc_491521501866_item	2529393	et	4	main
nimetada	doc_491521501866_item	2529396	et	3	main
tahelepanu	doc_491521501866_item	2529402	et	4	main
on	doc_491521501866_item	2529403	et	4	main
rohkem	doc_491521501866_item	2529401	et	4	main
rohkem	doc_491521501866_item	2529404	et	4	main
voimalusi	doc_491521501866_item	2529405	et	4	main
sihtkeelt	doc_491521501866_item	2529406	et	4	main
aktiivselt	doc_491521501866_item	2529407	et	4	main
kasutada	doc_491521501866_item	2529408	et	3	main
toimub	doc_491521501866_item	2529409	et	3	main
suhtlemine	doc_491521501866_item	2529410	et	4	main
sihtkeeles	doc_491521501866_item	2529411	et	4	main
antakse	doc_491521501866_item	2529412	et	3	main
rohkem	doc_491521501866_item	2529413	et	4	main
loovaid	doc_491521501866_item	2529414	et	4	main
kirjalikke	doc_491521501866_item	2529415	et	3	main
ulesandeid	doc_491521501866_item	2529416	et	4	main
opilasel	doc_491521501866_item	2529417	et	4	main
on	doc_491521501866_item	2529418	et	4	main
rohkem	doc_491521501866_item	2529419	et	4	main
voimalusi	doc_491521501866_item	2529420	et	4	main
hindeid	doc_491521501866_item	2529431	et	3	main
selleparast	doc_491521501866_item	2529432	et	3	main
ei	doc_491521501866_item	2529439	et	4	main
vormidest	doc_491521501866_item	2529442	et	3	main
hiilida	doc_491521501866_item	2529444	et	3	main
materjal	doc_491521501866_item	2529453	et	3	main
tuupiliste	doc_491521501866_item	2529459	et	4	main
vigade	doc_491521501866_item	2529460	et	3	main
on	doc_491521501866_item	2529465	et	4	main
emakeele	doc_491521501866_item	2529470	et	4	main
kolab	doc_491521501866_item	2529476	et	3	main
eesti	doc_491521501866_item	2529477	et	4	main
sonaga	doc_491521501866_item	2529478	et	4	main
2	doc_491521501866_item	2529510	et	2	main
asemel	doc_491521501866_item	2529513	et	4	main
kasutatud	doc_491521501866_item	2529515	et	4	main
luhike	doc_491521501866_item	2529516	et	4	main
u	doc_491521501866_item	2529517	et	4	main
raske	doc_491521501866_item	2529522	et	4	main
uhesugused	doc_491521501866_item	2529532	et	4	main
kuna	doc_491521501866_item	2529542	et	3	main
panda	doc_491521501866_item	2529430	et	4	main
ei	doc_491521501866_item	2529433	et	4	main
karda	doc_491521501866_item	2529434	et	4	main
ka	doc_491521501866_item	2529435	et	3	main
just	doc_491521501866_item	2529450	et	3	main
toos	doc_491521501866_item	2529455	et	3	main
tekstides	doc_491521501866_item	2529457	et	3	main
teatr	doc_491521501866_item	2529466	et	4	main
mojust	doc_491521501866_item	2529471	et	4	main
teater	doc_491521501866_item	2529479	et	3	main
sarnaselt	doc_491521501866_item	2529480	et	4	main
kuid	doc_491521501866_item	2529481	et	4	main
kirjapilt	doc_491521501866_item	2529482	et	3	main
on	doc_491521501866_item	2529483	et	4	main
erinev	doc_491521501866_item	2529484	et	4	main
mul	doc_491521501866_item	2529485	et	3	main
on	doc_491521501866_item	2529486	et	4	main
tume	doc_491521501866_item	2529487	et	3	main
sirge	doc_491521501866_item	2529488	et	4	main
luhikejuksed	doc_491521501866_item	2529489	et	4	main
ja	doc_491521501866_item	2529490	et	3	main
nops	doc_491521501866_item	2529491	et	4	main
nina-	doc_491521501866_item	2529492	et	4	main
antud	doc_491521501866_item	2529493	et	4	main
lauses	doc_491521501866_item	2529494	et	3	main
esineb	doc_491521501866_item	2529495	et	3	main
mitu	doc_491521501866_item	2529496	et	4	main
eri	doc_491521501866_item	2529497	et	4	main
liiki	doc_491521501866_item	2529498	et	4	main
viga	doc_491521501866_item	2529499	et	4	main
1	doc_491521501866_item	2529500	et	2	main
uhildumisviga	doc_491521501866_item	2529501	et	4	main
mis	doc_491521501866_item	2529502	et	4	main
ei	doc_491521501866_item	2529503	et	4	main
ole	doc_491521501866_item	2529504	et	4	main
tingitud	doc_491521501866_item	2529505	et	4	main
emakeelest	doc_491521501866_item	2529506	et	4	main
vaid	doc_491521501866_item	2529507	et	3	main
pigem	doc_491521501866_item	2529508	et	3	main
tahelepanematusest	doc_491521501866_item	2529509	et	4	main
vigu	doc_491521501866_item	2529437	et	3	main
kahtlastest	doc_491521501866_item	2529441	et	4	main
korvale	doc_491521501866_item	2529443	et	4	main
vead	doc_491521501866_item	2529463	et	4	main
on	doc_491521501866_item	2529468	et	4	main
keeles	doc_491521501866_item	2529473	et	4	main
sona	doc_491521501866_item	2529474	et	4	main
teatp	doc_491521501866_item	2529475	et	4	main
vene	doc_491521501866_item	2529518	et	4	main
emakeelega	doc_491521501866_item	2529519	et	3	main
oppijal	doc_491521501866_item	2529520	et	4	main
neid	doc_491521501866_item	2529523	et	4	main
koik	doc_491521501866_item	2529529	et	4	main
haalikud	doc_491521501866_item	2529530	et	4	main
emakeelest	doc_491521501866_item	2529541	et	4	main
vaste	doc_491521501866_item	2529544	et	4	main
hoc	doc_491521501866_item	2529546	et	4	main
sonauhend	doc_491521501866_item	2529551	et	4	main
tahe	doc_491521501866_item	2529558	et	4	main
kirjutamises	doc_491521501866_item	2529559	et	4	main
a	doc_491521501866_item	2529560	et	4	main
vene	doc_491521501866_item	2529566	et	4	main
emakeelega	doc_491521501866_item	2529567	et	3	main
tahtede	doc_491521501866_item	2529574	et	4	main
kuna	doc_491521501866_item	2529576	et	3	main
keeles	doc_491521501866_item	2529578	et	4	main
tappidega	doc_491521501866_item	2529579	et	3	main
kes	doc_491521501866_item	2529585	et	4	main
tegemist	doc_491521501866_item	2529597	et	4	main
liiki	doc_491521501866_item	2529600	et	4	main
venekeelne	doc_491521501866_item	2529617	et	3	main
a	doc_491521501866_item	2529624	et	4	main
sona	doc_491521501866_item	2529626	et	4	main
sona	doc_491521501866_item	2529634	et	4	main
kaandeviga	doc_491521501866_item	2529637	et	4	main
on	doc_491521501866_item	2529645	et	4	main
peaks	doc_491521501866_item	2529648	et	4	main
olema	doc_491521501866_item	2529649	et	4	main
jargmises	doc_491521501866_item	2529651	et	4	main
kohakaanete	doc_491521501866_item	2529656	et	4	main
me	doc_491521501866_item	2529658	et	4	main
siin	doc_491521501866_item	2529661	et	4	main
voib	doc_491521501866_item	2529674	et	4	main
u	doc_491521501866_item	2529681	et	4	main
on	doc_491521501866_item	2529685	et	4	main
on	doc_491521501866_item	2529721	et	4	main
oli	doc_491521501866_item	2529734	et	3	main
kleebi	doc_491521501866_item	2529744	et	4	main
osastava	doc_491521501866_item	2529750	et	4	main
oppija	doc_491521501866_item	2529762	et	4	main
sona	doc_491521501866_item	2529766	et	4	main
verbivorm	doc_491521501866_item	2529789	et	4	main
oleb	doc_491521501866_item	2529790	et	4	main
isiku	doc_491521501866_item	2529799	et	3	main
2	doc_491521501866_item	2529802	et	2	main
opetajaks	doc_491521501866_item	2529804	et	4	main
mojust	doc_491521501866_item	2529808	et	4	main
otsetolge	doc_491521501866_item	2529809	et	4	main
vene	doc_491521501866_item	2529810	et	4	main
pohjustatud	doc_491521501866_item	2529820	et	4	main
pika	doc_491521501866_item	2529511	et	4	main
on	doc_491521501866_item	2529514	et	4	main
on	doc_491521501866_item	2529521	et	4	main
pikkuselt	doc_491521501866_item	2529531	et	4	main
viga	doc_491521501866_item	2529535	et	4	main
sona	doc_491521501866_item	2529536	et	4	main
kokkukirjutamises	doc_491521501866_item	2529537	et	3	main
venekeelne	doc_491521501866_item	2529543	et	3	main
on	doc_491521501866_item	2529547	et	4	main
tee	doc_491521501866_item	2529570	et	4	main
vene	doc_491521501866_item	2529577	et	4	main
uhis	doc_491521501866_item	2529591	et	3	main
mitme	doc_491521501866_item	2529598	et	4	main
1	doc_491521501866_item	2529602	et	2	main
kokku-ja	doc_491521501866_item	2529604	et	3	main
lahkukirjutamises	doc_491521501866_item	2529605	et	3	main
kaks	doc_491521501866_item	2529606	et	3	main
mojust	doc_491521501866_item	2529613	et	4	main
trahvi	doc_491521501866_item	2529615	et	4	main
maksmast	doc_491521501866_item	2529616	et	3	main
uks	doc_491521501866_item	2529625	et	3	main
seestutlev	doc_491521501866_item	2529642	et	4	main
seesutlev	doc_491521501866_item	2529644	et	4	main
segi	doc_491521501866_item	2529646	et	3	main
vastupidi	doc_491521501866_item	2529650	et	3	main
peatzrses	doc_491521501866_item	2529652	et	4	main
on	doc_491521501866_item	2529662	et	4	main
mojust	doc_491521501866_item	2529679	et	4	main
i	doc_491521501866_item	2529684	et	4	main
lopp	doc_491521501866_item	2529724	et	4	main
moodustamisel	doc_491521501866_item	2529733	et	4	main
lahtealuseks	doc_491521501866_item	2529735	et	4	main
ku	doc_491521501866_item	2529737	et	4	main
muud	doc_491521501866_item	2529739	et	4	main
kaandevead	doc_491521501866_item	2529740	et	4	main
kaks	doc_491521501866_item	2529741	et	3	main
margi	doc_491521501866_item	2529742	et	3	main
kaks	doc_491521501866_item	2529743	et	3	main
valikus	doc_491521501866_item	2529749	et	3	main
asemel	doc_491521501866_item	2529751	et	4	main
sona	doc_491521501866_item	2529753	et	4	main
kleebi	doc_491521501866_item	2529754	et	4	main
osanud	doc_491521501866_item	2529764	et	4	main
kaanata	doc_491521501866_item	2529765	et	4	main
verbivormi	doc_491521501866_item	2529787	et	4	main
3	doc_491521501866_item	2529798	et	2	main
tunnus	doc_491521501866_item	2529800	et	3	main
on	doc_491521501866_item	2529825	et	4	main
ilma	doc_491521501866_item	2529840	et	4	main
rahata	doc_491521501866_item	2529841	et	4	main
moodustamisel	doc_491521501866_item	2529867	et	4	main
vormiga	doc_491521501866_item	2529873	et	4	main
koike	doc_491521501866_item	2529874	et	4	main
ei	doc_491521501866_item	2529875	et	4	main
tehtud	doc_491521501866_item	2529883	et	4	main
moodustamisel	doc_491521501866_item	2529885	et	4	main
emakeele	doc_491521501866_item	2529889	et	4	main
juhul	doc_491521501866_item	2529892	et	3	main
prefiks	doc_491521501866_item	2529900	et	3	main
pohisonaga	doc_491521501866_item	2529904	et	4	main
verbivormide	doc_491521501866_item	2529907	et	4	main
valiku	doc_491521501866_item	2529908	et	3	main
vead	doc_491521501866_item	2529909	et	4	main
ma	doc_491521501866_item	2529910	et	3	main
viga	doc_491521501866_item	2529913	et	4	main
verbi	doc_491521501866_item	2529915	et	4	main
vale	doc_491521501866_item	2529917	et	4	main
ei	doc_491521501866_item	2529928	et	4	main
tundi	doc_491521501866_item	2529934	et	4	main
mojust	doc_491521501866_item	2529944	et	4	main
vene	doc_491521501866_item	2529945	et	4	main
verbile	doc_491521501866_item	2529950	et	3	main
yuexn	doc_491521501866_item	2529959	et	4	main
laheme	doc_491521501866_item	2529964	et	4	main
seal	doc_491521501866_item	2529967	et	4	main
peaks	doc_491521501866_item	2529977	et	4	main
moistet	doc_491521501866_item	2530001	et	4	main
da-infinitiivi	doc_491521501866_item	2530004	et	4	main
lugenia	doc_491521501866_item	2530009	et	4	main
ja	doc_491521501866_item	2530011	et	3	main
on	doc_491521501866_item	2530013	et	4	main
aetud	doc_491521501866_item	2530015	et	4	main
mis	doc_491521501866_item	2529538	et	4	main
eristada	doc_491521501866_item	2529524	et	3	main
keeles	doc_491521501866_item	2529527	et	4	main
on	doc_491521501866_item	2529528	et	4	main
on	doc_491521501866_item	2529539	et	4	main
koosnev	doc_491521501866_item	2529550	et	4	main
viga	doc_491521501866_item	2529555	et	4	main
seisneb	doc_491521501866_item	2529556	et	3	main
on	doc_491521501866_item	2529562	et	4	main
tihtipeale	doc_491521501866_item	2529571	et	3	main
tahti	doc_491521501866_item	2529580	et	4	main
emakeele	doc_491521501866_item	2529612	et	4	main
vaste	doc_491521501866_item	2529618	et	4	main
on	doc_491521501866_item	2529619	et	4	main
otxasbibafotca	doc_491521501866_item	2529620	et	4	main
ucm	doc_491521501866_item	2529622	et	4	main
uhissoiduk	doc_491521501866_item	2529627	et	4	main
vaste	doc_491521501866_item	2529629	et	4	main
o6ufecmeexxbau	doc_491521501866_item	2529631	et	4	main
mpaxcnopm	doc_491521501866_item	2529632	et	4	main
kaks	doc_491521501866_item	2529633	et	3	main
2	doc_491521501866_item	2529635	et	2	main
kolm	doc_491521501866_item	2529636	et	3	main
valjuma	doc_491521501866_item	2529641	et	4	main
pargus	doc_491521501866_item	2529660	et	4	main
moodustatud	doc_491521501866_item	2529664	et	4	main
kaane	doc_491521501866_item	2529666	et	4	main
ka	doc_491521501866_item	2529669	et	3	main
vale	doc_491521501866_item	2529670	et	4	main
ka	doc_491521501866_item	2529677	et	3	main
ja	doc_491521501866_item	2529682	et	3	main
aetud	doc_491521501866_item	2529687	et	4	main
xypxocbau	doc_491521501866_item	2529545	et	4	main
kahest	doc_491521501866_item	2529548	et	4	main
sonast	doc_491521501866_item	2529549	et	4	main
jdanituld	doc_491521501866_item	2529554	et	4	main
asemel	doc_491521501866_item	2529561	et	4	main
oppija	doc_491521501866_item	2529568	et	4	main
vahet	doc_491521501866_item	2529572	et	3	main
ei	doc_491521501866_item	2529581	et	4	main
keelduvad	doc_491521501866_item	2529586	et	4	main
peavad	doc_491521501866_item	2529588	et	4	main
jargmisest	doc_491521501866_item	2529589	et	4	main
peatusest	doc_491521501866_item	2529590	et	4	main
viga	doc_491521501866_item	2529607	et	4	main
mis	doc_491521501866_item	2529608	et	4	main
on	doc_491521501866_item	2529609	et	4	main
molemad	doc_491521501866_item	2529610	et	4	main
trahvimaksmast	doc_491521501866_item	2529587	et	4	main
soidukis	doc_491521501866_item	2529592	et	4	main
valjuma	doc_491521501866_item	2529593	et	4	main
antud	doc_491521501866_item	2529594	et	4	main
lauses	doc_491521501866_item	2529595	et	3	main
on	doc_491521501866_item	2529596	et	4	main
eri	doc_491521501866_item	2529599	et	4	main
veaga	doc_491521501866_item	2529601	et	3	main
sona	doc_491521501866_item	2529603	et	4	main
pohjustatud	doc_491521501866_item	2529611	et	4	main
keelduvad	doc_491521501866_item	2529614	et	4	main
ot	doc_491521501866_item	2529621	et	4	main
a	doc_491521501866_item	2529623	et	4	main
venekeelne	doc_491521501866_item	2529628	et	3	main
jargmise	doc_491521501866_item	2529638	et	4	main
peatuse	doc_491521501866_item	2529639	et	4	main
soidukiv	doc_491521501866_item	2529640	et	4	main
soidzcki	doc_491521501866_item	2529653	et	4	main
kaandevead	doc_491521501866_item	2529655	et	4	main
vead	doc_491521501866_item	2529657	et	4	main
valesti	doc_491521501866_item	2529663	et	3	main
omastav	doc_491521501866_item	2529665	et	4	main
siit	doc_491521501866_item	2529667	et	3	main
tuleneb	doc_491521501866_item	2529668	et	3	main
olla	doc_491521501866_item	2529675	et	3	main
pohjustatud	doc_491521501866_item	2529676	et	4	main
emakeele	doc_491521501866_item	2529678	et	4	main
eestikeelne	doc_491521501866_item	2529683	et	3	main
segi	doc_491521501866_item	2529686	et	3	main
kusimusel	doc_491521501866_item	2529722	et	4	main
samasugune	doc_491521501866_item	2529723	et	3	main
peab	doc_491521501866_item	2529725	et	4	main
olema	doc_491521501866_item	2529726	et	4	main
ka	doc_491521501866_item	2529727	et	3	main
trepis	doc_491521501866_item	2529732	et	3	main
s	doc_491521501866_item	2529738	et	4	main
vale	doc_491521501866_item	2529747	et	4	main
puhul	doc_491521501866_item	2529755	et	4	main
on	doc_491521501866_item	2529756	et	4	main
ei	doc_491521501866_item	2529763	et	4	main
moodustatud	doc_491521501866_item	2529792	et	4	main
ma	doc_491521501866_item	2529797	et	3	main
tingitud	doc_491521501866_item	2529806	et	4	main
keelest	doc_491521501866_item	2529811	et	4	main
mnsiemca	doc_491521501866_item	2529812	et	4	main
ymumenena	doc_491521501866_item	2529814	et	4	main
suureks	doc_491521501866_item	2529817	et	4	main
on	doc_491521501866_item	2529819	et	4	main
tahelepanematusest	doc_491521501866_item	2529824	et	4	main
see	doc_491521501866_item	2529826	et	3	main
arvatatakse	doc_491521501866_item	2529834	et	4	main
et	doc_491521501866_item	2529835	et	3	main
kodust	doc_491521501866_item	2529839	et	4	main
tehtud	doc_491521501866_item	2529844	et	4	main
tegumoe	doc_491521501866_item	2529846	et	3	main
umbisikulise	doc_491521501866_item	2529848	et	4	main
tegumoe	doc_491521501866_item	2529849	et	3	main
tunnus	doc_491521501866_item	2529850	et	3	main
takse	doc_491521501866_item	2529851	et	3	main
on	doc_491521501866_item	2529852	et	4	main
lopule	doc_491521501866_item	2529857	et	4	main
kuunlaid	doc_491521501866_item	2529860	et	4	main
on	doc_491521501866_item	2529863	et	4	main
tehtud	doc_491521501866_item	2529864	et	4	main
umbisikulise	doc_491521501866_item	2529865	et	4	main
tegumoe	doc_491521501866_item	2529866	et	3	main
oma	doc_491521501866_item	2529871	et	4	main
valjamoeldud	doc_491521501866_item	2529872	et	4	main
voimalik	doc_491521501866_item	2529877	et	4	main
ulelugeda	doc_491521501866_item	2529878	et	4	main
files	doc_491521501866_item	2529879	et	4	main
antud	doc_491521501866_item	2529891	et	4	main
eestikeelse	doc_491521501866_item	2529894	et	3	main
venekeelseks	doc_491521501866_item	2529898	et	4	main
vormi	doc_491521501866_item	2529918	et	4	main
valikus	doc_491521501866_item	2529919	et	3	main
tegemist	doc_491521501866_item	2529922	et	4	main
alus	doc_491521501866_item	2529925	et	4	main
ja	doc_491521501866_item	2529926	et	3	main
kuus	doc_491521501866_item	2529933	et	4	main
on	doc_491521501866_item	2529937	et	4	main
on	doc_491521501866_item	2529630	et	4	main
ja	doc_491521501866_item	2529643	et	3	main
aetud	doc_491521501866_item	2529647	et	4	main
valjuma	doc_491521501866_item	2529654	et	4	main
jalutasime	doc_491521501866_item	2529659	et	3	main
seesutleva	doc_491521501866_item	2529671	et	4	main
vorm	doc_491521501866_item	2529672	et	3	main
viga	doc_491521501866_item	2529673	et	4	main
venekeelne	doc_491521501866_item	2529680	et	3	main
pane	doc_491521501866_item	2529688	et	4	main
purgis	doc_491521501866_item	2529690	et	3	main
hamstrid	doc_491521501866_item	2529689	et	3	main
viga	doc_491521501866_item	2529691	et	4	main
seisneb	doc_491521501866_item	2529692	et	3	main
vale	doc_491521501866_item	2529693	et	4	main
kaande	doc_491521501866_item	2529694	et	3	main
valikus	doc_491521501866_item	2529695	et	3	main
sisseutleva	doc_491521501866_item	2529696	et	4	main
asemel	doc_491521501866_item	2529697	et	4	main
seesutlev	doc_491521501866_item	2529698	et	4	main
kass	doc_491521501866_item	2529699	et	3	main
istub	doc_491521501866_item	2529700	et	3	main
trepis	doc_491521501866_item	2529701	et	3	main
on	doc_491521501866_item	2529703	et	4	main
tingitud	doc_491521501866_item	2529704	et	4	main
valis-	doc_491521501866_item	2529705	et	3	main
ja	doc_491521501866_item	2529706	et	3	main
sisekohakaanete	doc_491521501866_item	2529707	et	4	main
viga	doc_491521501866_item	2529702	et	4	main
segiajamisest	doc_491521501866_item	2529708	et	4	main
tegemist	doc_491521501866_item	2529709	et	4	main
on	doc_491521501866_item	2529710	et	4	main
tuupilise	doc_491521501866_item	2529711	et	4	main
veaga	doc_491521501866_item	2529712	et	3	main
mida	doc_491521501866_item	2529713	et	4	main
teevad	doc_491521501866_item	2529714	et	3	main
oppijad	doc_491521501866_item	2529715	et	4	main
orienteerudes	doc_491521501866_item	2529716	et	3	main
kusimuse	doc_491521501866_item	2529717	et	4	main
lopule	doc_491521501866_item	2529718	et	4	main
milline	doc_491521501866_item	2529719	et	3	main
lopp	doc_491521501866_item	2529720	et	4	main
vastusel	doc_491521501866_item	2529728	et	4	main
antud	doc_491521501866_item	2529729	et	4	main
juhul	doc_491521501866_item	2529730	et	3	main
moodustusega	doc_491521501866_item	2529761	et	4	main
on	doc_491521501866_item	2529791	et	4	main
ole	doc_491521501866_item	2529796	et	4	main
vormi	doc_491521501866_item	2529731	et	4	main
kusimus	doc_491521501866_item	2529736	et	3	main
viga	doc_491521501866_item	2529745	et	4	main
seisneb	doc_491521501866_item	2529746	et	3	main
kaande	doc_491521501866_item	2529748	et	3	main
omastav	doc_491521501866_item	2529752	et	4	main
tegemist	doc_491521501866_item	2529757	et	4	main
ka	doc_491521501866_item	2529758	et	3	main
vale	doc_491521501866_item	2529759	et	4	main
vormi	doc_491521501866_item	2529760	et	4	main
kleebis	doc_491521501866_item	2529767	et	4	main
ja	doc_491521501866_item	2529768	et	3	main
motles	doc_491521501866_item	2529769	et	4	main
oma	doc_491521501866_item	2529770	et	4	main
vormi	doc_491521501866_item	2529771	et	4	main
valja	doc_491521501866_item	2529772	et	3	main
minu	doc_491521501866_item	2529773	et	3	main
ema	doc_491521501866_item	2529774	et	4	main
oleb	doc_491521501866_item	2529775	et	4	main
opetajaks	doc_491521501866_item	2529776	et	4	main
suureks	doc_491521501866_item	2529777	et	4	main
linnakoolis	doc_491521501866_item	2529778	et	4	main
antud	doc_491521501866_item	2529779	et	4	main
lauses	doc_491521501866_item	2529780	et	3	main
esineb	doc_491521501866_item	2529781	et	3	main
mitu	doc_491521501866_item	2529782	et	4	main
eri	doc_491521501866_item	2529783	et	4	main
liiki	doc_491521501866_item	2529784	et	4	main
viga	doc_491521501866_item	2529785	et	4	main
1	doc_491521501866_item	2529786	et	2	main
moodustusviga	doc_491521501866_item	2529788	et	4	main
grammatika	doc_491521501866_item	2529793	et	4	main
reeglite	doc_491521501866_item	2529794	et	3	main
alusel	doc_491521501866_item	2529795	et	4	main
emakeele	doc_491521501866_item	2529807	et	4	main
3	doc_491521501866_item	2529815	et	2	main
eelmise	doc_491521501866_item	2529821	et	3	main
eelmise	doc_491521501866_item	2529828	et	3	main
opetajaks	doc_491521501866_item	2529830	et	4	main
moodustusvead	doc_491521501866_item	2529832	et	4	main
samuti	doc_491521501866_item	2529833	et	3	main
valjuda	doc_491521501866_item	2529838	et	4	main
lisatud	doc_491521501866_item	2529853	et	4	main
jouluajal	doc_491521501866_item	2529858	et	4	main
viga	doc_491521501866_item	2529862	et	4	main
tegemist	doc_491521501866_item	2529870	et	4	main
ole	doc_491521501866_item	2529876	et	4	main
viga	doc_491521501866_item	2529881	et	4	main
vasteks	doc_491521501866_item	2529899	et	3	main
nepe-	doc_491521501866_item	2529901	et	4	main
kokku	doc_491521501866_item	2529905	et	3	main
olema	doc_491521501866_item	2529916	et	4	main
on	doc_491521501866_item	2529921	et	4	main
ka	doc_491521501866_item	2529923	et	3	main
uhildumisveaga	doc_491521501866_item	2529924	et	4	main
tana	doc_491521501866_item	2529931	et	4	main
mul	doc_491521501866_item	2529932	et	3	main
tingitud	doc_491521501866_item	2529942	et	4	main
ei	doc_491521501866_item	2529947	et	4	main
ning	doc_491521501866_item	2529952	et	3	main
antud	doc_491521501866_item	2529955	et	4	main
me	doc_491521501866_item	2529963	et	4	main
selle	doc_491521501866_item	2529975	et	4	main
kasutuses	doc_491521501866_item	2530005	et	4	main
segi	doc_491521501866_item	2530014	et	3	main
keeles	doc_491521501866_item	2530018	et	4	main
infinitiiv	doc_491521501866_item	2530023	et	3	main
siis	doc_491521501866_item	2530029	et	3	main
eksitakse	doc_491521501866_item	2530030	et	4	main
eristamisel	doc_491521501866_item	2530032	et	4	main
vaga	doc_491521501866_item	2530033	et	4	main
sageli	doc_491521501866_item	2530034	et	3	main
lahetyia	doc_491521501866_item	2530038	et	4	main
verbivormi	doc_491521501866_item	2530050	et	4	main
lisiku	doc_491521501866_item	2530056	et	4	main
ma-infinitiivi	doc_491521501866_item	2530060	et	4	main
antud	doc_491521501866_item	2530067	et	4	main
tcirtcteiit	doc_491521501866_item	2530117	et	4	main
rtittscrcxme	doc_491521501866_item	2530118	et	4	main
cale	doc_491521501866_item	2530119	et	4	main
prohlecitaidcsl	doc_491521501866_item	2530121	et	4	main
mojust	doc_491521501866_item	2530127	et	4	main
keeles	doc_491521501866_item	2530129	et	4	main
teaaeu	doc_491521501866_item	2530138	et	4	main
xon-ry	doc_491521501866_item	2530144	et	4	main
vastab	doc_491521501866_item	2530145	et	3	main
eesti	doc_491521501866_item	2530146	et	4	main
osastav	doc_491521501866_item	2530152	et	4	main
vcasttr	doc_491521501866_item	2530163	et	4	main
antud	doc_491521501866_item	2530166	et	4	main
sonauhend	doc_491521501866_item	2530169	et	4	main
tundma	doc_491521501866_item	2530171	et	3	main
uxmepecoeamc-q	doc_491521501866_item	2530172	et	4	main
tundma	doc_491521501866_item	2530179	et	3	main
eesti	doc_491521501866_item	2530185	et	4	main
rahva	doc_491521501866_item	2530186	et	3	main
ja	doc_491521501866_item	2530189	et	3	main
tavadest	doc_491521501866_item	2530190	et	3	main
vea	doc_491521501866_item	2530191	et	4	main
lause	doc_491521501866_item	2530196	et	4	main
esineb	doc_491521501866_item	2530197	et	3	main
otsetolkena	doc_491521501866_item	2530198	et	4	main
selles	doc_491521501866_item	2530222	et	4	main
emakeelega	doc_491521501866_item	2530225	et	3	main
haalikute	doc_491521501866_item	2530234	et	4	main
vahel	doc_491521501866_item	2530235	et	4	main
sest	doc_491521501866_item	2530236	et	4	main
uks	doc_491521501866_item	2530249	et	3	main
eelm	doc_491521501866_item	2530256	et	4	main
nad	doc_491521501866_item	2530259	et	3	main
norga	doc_491521501866_item	2530290	et	4	main
b	doc_491521501866_item	2529801	et	4	main
kaandeviga	doc_491521501866_item	2529803	et	4	main
on	doc_491521501866_item	2529805	et	4	main
xem	doc_491521501866_item	2529813	et	4	main
uhildumisviga	doc_491521501866_item	2529816	et	4	main
linnakoolis	doc_491521501866_item	2529818	et	4	main
mojust	doc_491521501866_item	2529823	et	4	main
ei	doc_491521501866_item	2529836	et	4	main
viga	doc_491521501866_item	2529842	et	4	main
umbisikulise	doc_491521501866_item	2529845	et	4	main
moodustamisel	doc_491521501866_item	2529847	et	4	main
vormi	doc_491521501866_item	2529856	et	4	main
on	doc_491521501866_item	2529882	et	4	main
uhendverbi	doc_491521501866_item	2529884	et	4	main
viga	doc_491521501866_item	2529886	et	4	main
mojust	doc_491521501866_item	2529890	et	4	main
oleks	doc_491521501866_item	2529893	et	3	main
iihendverbi	doc_491521501866_item	2529895	et	4	main
koostisosa	doc_491521501866_item	2529896	et	4	main
mida	doc_491521501866_item	2529902	et	4	main
kirjutatakse	doc_491521501866_item	2529903	et	3	main
nepeeuumamb	doc_491521501866_item	2529906	et	4	main
nous	doc_491521501866_item	2529912	et	4	main
samas	doc_491521501866_item	2529920	et	4	main
sona	doc_491521501866_item	2529822	et	4	main
uhildatud	doc_491521501866_item	2529827	et	4	main
sonaga	doc_491521501866_item	2529829	et	4	main
verbivormide	doc_491521501866_item	2529831	et	4	main
tohi	doc_491521501866_item	2529837	et	4	main
on	doc_491521501866_item	2529843	et	4	main
da	doc_491521501866_item	2529854	et	4	main
infinitiivi	doc_491521501866_item	2529855	et	4	main
suutakse	doc_491521501866_item	2529859	et	3	main
4iiscatakse	doc_491521501866_item	2529861	et	4	main
ilmselt	doc_491521501866_item	2529868	et	4	main
on	doc_491521501866_item	2529869	et	4	main
hrccla	doc_491521501866_item	2529880	et	4	main
on	doc_491521501866_item	2529887	et	4	main
pohjustatud	doc_491521501866_item	2529888	et	4	main
ules	doc_491521501866_item	2529897	et	3	main
on	doc_491521501866_item	2529911	et	4	main
seisneb	doc_491521501866_item	2529914	et	3	main
uhildu	doc_491521501866_item	2529929	et	4	main
isikus	doc_491521501866_item	2529930	et	3	main
verb	doc_491521501866_item	2529935	et	3	main
emakeele	doc_491521501866_item	2529943	et	4	main
ole	doc_491521501866_item	2529948	et	4	main
laheme	doc_491521501866_item	2529974	et	4	main
ei	doc_491521501866_item	2530007	et	4	main
oeldis	doc_491521501866_item	2529927	et	4	main
olema	doc_491521501866_item	2529936	et	4	main
vahele	doc_491521501866_item	2529938	et	4	main
sellele	doc_491521501866_item	2529949	et	4	main
otsetolkes	doc_491521501866_item	2529953	et	4	main
lause	doc_491521501866_item	2529956	et	4	main
jargmiselt	doc_491521501866_item	2529957	et	4	main
ce2odxr	doc_491521501866_item	2529958	et	4	main
ucecmb	doc_491521501866_item	2529960	et	4	main
ypokoe	doc_491521501866_item	2529961	et	4	main
koolis	doc_491521501866_item	2529962	et	4	main
mangime	doc_491521501866_item	2529968	et	4	main
antud	doc_491521501866_item	2529969	et	4	main
lauses	doc_491521501866_item	2529970	et	3	main
esineb	doc_491521501866_item	2529971	et	3	main
vale	doc_491521501866_item	2529972	et	4	main
verb	doc_491521501866_item	2529973	et	3	main
olema	doc_491521501866_item	2529978	et	4	main
verb	doc_491521501866_item	2529979	et	3	main
kaime	doc_491521501866_item	2529980	et	3	main
oppija	doc_491521501866_item	2529981	et	4	main
ei	doc_491521501866_item	2529982	et	4	main
teinud	doc_491521501866_item	2529983	et	4	main
vahet	doc_491521501866_item	2529984	et	3	main
nende	doc_491521501866_item	2529985	et	4	main
verbide	doc_491521501866_item	2529986	et	3	main
tahenduste	doc_491521501866_item	2529987	et	4	main
vahel	doc_491521501866_item	2529988	et	4	main
kusjuures	doc_491521501866_item	2529989	et	3	main
ka	doc_491521501866_item	2529990	et	3	main
vene	doc_491521501866_item	2529991	et	4	main
keeles	doc_491521501866_item	2529992	et	4	main
on	doc_491521501866_item	2529993	et	4	main
xodumb	doc_491521501866_item	2529995	et	4	main
kaima	doc_491521501866_item	2529994	et	4	main
ja	doc_491521501866_item	2529996	et	3	main
minema	doc_491521501866_item	2529997	et	3	main
uomu	doc_491521501866_item	2529998	et	4	main
kaks	doc_491521501866_item	2529999	et	3	main
erinevat	doc_491521501866_item	2530000	et	4	main
jaetud	doc_491521501866_item	2529939	et	4	main
viga	doc_491521501866_item	2529940	et	4	main
on	doc_491521501866_item	2529941	et	4	main
keeles	doc_491521501866_item	2529946	et	4	main
vastet	doc_491521501866_item	2529951	et	3	main
kolab	doc_491521501866_item	2529954	et	3	main
oues	doc_491521501866_item	2529965	et	4	main
ja	doc_491521501866_item	2529966	et	3	main
asemel	doc_491521501866_item	2529976	et	4	main
vead	doc_491521501866_item	2530002	et	4	main
nad	doc_491521501866_item	2530006	et	3	main
ma-	doc_491521501866_item	2530010	et	3	main
uks	doc_491521501866_item	2530021	et	3	main
kaks	doc_491521501866_item	2530028	et	3	main
nende	doc_491521501866_item	2530031	et	4	main
juhul	doc_491521501866_item	2530040	et	3	main
ainult	doc_491521501866_item	2530044	et	4	main
infinitiivi	doc_491521501866_item	2530046	et	4	main
valikuga	doc_491521501866_item	2530047	et	3	main
kuid	doc_491521501866_item	2530048	et	4	main
ka	doc_491521501866_item	2530049	et	3	main
moodustatud	doc_491521501866_item	2530055	et	4	main
alusel	doc_491521501866_item	2530075	et	4	main
raskusi	doc_491521501866_item	2530113	et	4	main
ytrcxsulcjvatcst	doc_491521501866_item	2530120	et	4	main
on	doc_491521501866_item	2530130	et	4	main
mar	doc_491521501866_item	2530131	et	4	main
nowoeaem	doc_491521501866_item	2530132	et	4	main
dpy2	doc_491521501866_item	2530134	et	4	main
eo3xuxaloutue	doc_491521501866_item	2530140	et	4	main
vene	doc_491521501866_item	2530142	et	4	main
kusimusele	doc_491521501866_item	2530149	et	4	main
eesti	doc_491521501866_item	2530168	et	4	main
huvi	doc_491521501866_item	2530170	et	4	main
on	doc_491521501866_item	2530173	et	4	main
segi	doc_491521501866_item	2530174	et	3	main
pohjuseks	doc_491521501866_item	2530192	et	4	main
vene	doc_491521501866_item	2530199	et	4	main
raske	doc_491521501866_item	2530228	et	4	main
teha	doc_491521501866_item	2530229	et	3	main
vahet	doc_491521501866_item	2530230	et	3	main
liihikeste	doc_491521501866_item	2530231	et	4	main
vene	doc_491521501866_item	2530237	et	4	main
pikkuse	doc_491521501866_item	2530242	et	4	main
tavaliselt	doc_491521501866_item	2530248	et	4	main
kaupluss	doc_491521501866_item	2530250	et	4	main
veel	doc_491521501866_item	2530251	et	4	main
uks	doc_491521501866_item	2530252	et	3	main
n	doc_491521501866_item	2530257	et	4	main
ta	doc_491521501866_item	2530278	et	4	main
ei	doc_491521501866_item	2530279	et	4	main
saa	doc_491521501866_item	2530280	et	4	main
eriti	doc_491521501866_item	2530281	et	3	main
b-ga	doc_491521501866_item	2530291	et	3	main
haalikud	doc_491521501866_item	2530300	et	4	main
tema	doc_491521501866_item	2530301	et	4	main
pass	doc_491521501866_item	2530310	et	3	main
sama	doc_491521501866_item	2530314	et	4	main
vea	doc_491521501866_item	2530315	et	4	main
vead	doc_491521501866_item	2530322	et	4	main
teiseks	doc_491521501866_item	2530329	et	4	main
kojrz	doc_491521501866_item	2530332	et	4	main
kella	doc_491521501866_item	2530334	et	4	main
kcrheks	doc_491521501866_item	2530335	et	4	main
on	doc_491521501866_item	2530337	et	4	main
tolgitud	doc_491521501866_item	2530338	et	4	main
teine	doc_491521501866_item	2530351	et	3	main
kuigi	doc_491521501866_item	2530355	et	3	main
see	doc_491521501866_item	2530380	et	3	main
lauses	doc_491521501866_item	2530397	et	3	main
emakeele	doc_491521501866_item	2530410	et	4	main
keeles	doc_491521501866_item	2530413	et	4	main
ouexb	doc_491521501866_item	2530415	et	4	main
wo	doc_491521501866_item	2530418	et	4	main
vaga	doc_491521501866_item	2530423	et	4	main
anda	doc_491521501866_item	2530432	et	3	main
koike	doc_491521501866_item	2530434	et	4	main
meile	doc_491521501866_item	2530437	et	4	main
arzdcz	doc_491521501866_item	2530443	et	4	main
orncxh	doc_491521501866_item	2530444	et	4	main
koik	doc_491521501866_item	2530446	et	4	main
pcxrinrcztcksjcx	doc_491521501866_item	2530450	et	4	main
ma-	doc_491521501866_item	2530003	et	3	main
armasta	doc_491521501866_item	2530008	et	4	main
da-infinitiiv	doc_491521501866_item	2530012	et	3	main
on	doc_491521501866_item	2530019	et	4	main
ainult	doc_491521501866_item	2530020	et	4	main
verbi	doc_491521501866_item	2530022	et	4	main
eesti	doc_491521501866_item	2530024	et	4	main
keeles	doc_491521501866_item	2530025	et	4	main
motlesin	doc_491521501866_item	2530035	et	4	main
ole	doc_491521501866_item	2530043	et	4	main
verbivormist	doc_491521501866_item	2530057	et	4	main
tunnus	doc_491521501866_item	2530061	et	3	main
voimeline	doc_491521501866_item	2530065	et	4	main
sonauhendiga	doc_491521501866_item	2530072	et	4	main
olete	doc_491521501866_item	2530073	et	3	main
nil	doc_491521501866_item	2530076	et	4	main
verbiga	doc_491521501866_item	2530078	et	3	main
viga	doc_491521501866_item	2530123	et	4	main
emakeele	doc_491521501866_item	2530126	et	4	main
vene	doc_491521501866_item	2530128	et	4	main
dpyzy	doc_491521501866_item	2530135	et	4	main
c7oaicxocmu	doc_491521501866_item	2530141	et	4	main
kusimusele	doc_491521501866_item	2530143	et	4	main
keeles	doc_491521501866_item	2530147	et	4	main
kaane	doc_491521501866_item	2530153	et	4	main
ma	doc_491521501866_item	2530154	et	3	main
tunnen	doc_491521501866_item	2530155	et	3	main
neid	doc_491521501866_item	2530156	et	4	main
ara	doc_491521501866_item	2530157	et	3	main
suurt	doc_491521501866_item	2530158	et	3	main
huvi	doc_491521501866_item	2530159	et	4	main
mct	doc_491521501866_item	2530160	et	4	main
ltttttcrt	doc_491521501866_item	2530161	et	4	main
stnrt	doc_491521501866_item	2530164	et	4	main
aetud	doc_491521501866_item	2530175	et	4	main
teise	doc_491521501866_item	2530176	et	4	main
ysxaeams	doc_491521501866_item	2530180	et	4	main
siin	doc_491521501866_item	2530182	et	4	main
meelde	doc_491521501866_item	2530184	et	3	main
ajaloost	doc_491521501866_item	2530187	et	4	main
kultuurist	doc_491521501866_item	2530188	et	3	main
moju	doc_491521501866_item	2530195	et	4	main
sdecb	doc_491521501866_item	2530202	et	4	main
kuna	doc_491521501866_item	2530016	et	3	main
vene	doc_491521501866_item	2530017	et	4	main
aga	doc_491521501866_item	2530027	et	3	main
kaua	doc_491521501866_item	2530036	et	3	main
antud	doc_491521501866_item	2530039	et	4	main
tegemist	doc_491521501866_item	2530041	et	4	main
ei	doc_491521501866_item	2530042	et	4	main
vale	doc_491521501866_item	2530045	et	4	main
lahema	doc_491521501866_item	2530053	et	4	main
lahe	doc_491521501866_item	2530058	et	4	main
kas	doc_491521501866_item	2530062	et	3	main
olete	doc_491521501866_item	2530064	et	3	main
raakida	doc_491521501866_item	2530066	et	4	main
verbivorm	doc_491521501866_item	2530068	et	4	main
rakkida	doc_491521501866_item	2530069	et	4	main
on	doc_491521501866_item	2530070	et	4	main
nagu	doc_491521501866_item	2530077	et	3	main
voima	doc_491521501866_item	2530079	et	4	main
tile	doc_491521501866_item	2530114	et	4	main
llc	doc_491521501866_item	2530115	et	4	main
critaote	doc_491521501866_item	2530116	et	4	main
tile	doc_491521501866_item	2530122	et	4	main
tingitud	doc_491521501866_item	2530125	et	4	main
xonry	doc_491521501866_item	2530133	et	4	main
ilpeodo	doc_491521501866_item	2530137	et	4	main
ymo	doc_491521501866_item	2530139	et	4	main
alaleutlev	doc_491521501866_item	2530148	et	4	main
aga	doc_491521501866_item	2530151	et	3	main
hrrv	doc_491521501866_item	2530165	et	4	main
emakeele	doc_491521501866_item	2530194	et	4	main
bce	doc_491521501866_item	2530201	et	4	main
seisneb	doc_491521501866_item	2530221	et	3	main
ja	doc_491521501866_item	2530232	et	3	main
pikkade	doc_491521501866_item	2530233	et	4	main
keeles	doc_491521501866_item	2530238	et	4	main
poolest	doc_491521501866_item	2530243	et	4	main
iihesugused	doc_491521501866_item	2530244	et	4	main
pohjus	doc_491521501866_item	2530254	et	4	main
kuulmise	doc_491521501866_item	2530284	et	4	main
need	doc_491521501866_item	2530299	et	3	main
puss	doc_491521501866_item	2530313	et	3	main
on	doc_491521501866_item	2530026	et	4	main
kuidas	doc_491521501866_item	2530037	et	3	main
moodustusveaga	doc_491521501866_item	2530051	et	4	main
sona	doc_491521501866_item	2530052	et	4	main
on	doc_491521501866_item	2530054	et	4	main
n	doc_491521501866_item	2530059	et	4	main
te	doc_491521501866_item	2530063	et	4	main
kasutatud	doc_491521501866_item	2530071	et	4	main
voimelirieanaloogia	doc_491521501866_item	2530074	et	4	main
rektsioonivead	doc_491521501866_item	2530080	et	4	main
ta	doc_491521501866_item	2530081	et	4	main
kaib	doc_491521501866_item	2530082	et	4	main
kooli	doc_491521501866_item	2530083	et	4	main
viga	doc_491521501866_item	2530084	et	4	main
on	doc_491521501866_item	2530085	et	4	main
pohjustatud	doc_491521501866_item	2530086	et	4	main
emakeele	doc_491521501866_item	2530087	et	4	main
mojust	doc_491521501866_item	2530088	et	4	main
antud	doc_491521501866_item	2530089	et	4	main
lause	doc_491521501866_item	2530090	et	4	main
venekeelne	doc_491521501866_item	2530091	et	3	main
vaste	doc_491521501866_item	2530092	et	4	main
on	doc_491521501866_item	2530093	et	4	main
ox	doc_491521501866_item	2530094	et	4	main
xodum	doc_491521501866_item	2530095	et	4	main
xyda	doc_491521501866_item	2530096	et	4	main
b	doc_491521501866_item	2530097	et	4	main
uuxorty	doc_491521501866_item	2530098	et	4	main
vene	doc_491521501866_item	2530099	et	4	main
kusimusele	doc_491521501866_item	2530100	et	4	main
xyda	doc_491521501866_item	2530101	et	4	main
vastab	doc_491521501866_item	2530102	et	3	main
eesti	doc_491521501866_item	2530103	et	4	main
keeles	doc_491521501866_item	2530104	et	4	main
sisseiitlev	doc_491521501866_item	2530105	et	4	main
kaane	doc_491521501866_item	2530106	et	4	main
aitame	doc_491521501866_item	2530108	et	3	main
teineteisele	doc_491521501866_item	2530109	et	3	main
ja	doc_491521501866_item	2530110	et	3	main
me	doc_491521501866_item	2530107	et	4	main
saame	doc_491521501866_item	2530111	et	4	main
tuleoevaid	doc_491521501866_item	2530112	et	4	main
on	doc_491521501866_item	2530124	et	4	main
ja	doc_491521501866_item	2530136	et	3	main
umo	doc_491521501866_item	2530150	et	4	main
nottde	doc_491521501866_item	2530162	et	4	main
juhul	doc_491521501866_item	2530167	et	3	main
sonauhendiga	doc_491521501866_item	2530177	et	4	main
ara	doc_491521501866_item	2530178	et	3	main
koik	doc_491521501866_item	2530181	et	4	main
tuletab	doc_491521501866_item	2530183	et	3	main
on	doc_491521501866_item	2530193	et	4	main
keelest	doc_491521501866_item	2530200	et	4	main
xanonauxaen2	doc_491521501866_item	2530203	et	4	main
06	doc_491521501866_item	2530204	et	2	main
tcynbmype	doc_491521501866_item	2530206	et	4	main
ucmopuu	doc_491521501866_item	2530205	et	4	main
u	doc_491521501866_item	2530207	et	4	main
o6blvastx	doc_491521501866_item	2530208	et	4	main
scmoxcxo2o	doc_491521501866_item	2530209	et	4	main
xapoda	doc_491521501866_item	2530210	et	4	main
vale	doc_491521501866_item	2530211	et	4	main
valde	doc_491521501866_item	2530212	et	3	main
nad	doc_491521501866_item	2530213	et	3	main
on	doc_491521501866_item	2530214	et	4	main
nagu	doc_491521501866_item	2530215	et	3	main
sukk	doc_491521501866_item	2530216	et	3	main
ja	doc_491521501866_item	2530217	et	3	main
sabas	doc_491521501866_item	2530218	et	3	main
vea	doc_491521501866_item	2530219	et	4	main
pohjus	doc_491521501866_item	2530220	et	4	main
et	doc_491521501866_item	2530223	et	3	main
oppijal	doc_491521501866_item	2530226	et	4	main
on	doc_491521501866_item	2530227	et	4	main
on	doc_491521501866_item	2530239	et	4	main
koik	doc_491521501866_item	2530240	et	4	main
haalikud	doc_491521501866_item	2530241	et	4	main
rajonis	doc_491521501866_item	2530246	et	4	main
on	doc_491521501866_item	2530247	et	4	main
vt	doc_491521501866_item	2530255	et	4	main
oppimise	doc_491521501866_item	2530282	et	4	main
algetapil	doc_491521501866_item	2530283	et	3	main
on	doc_491521501866_item	2530289	et	4	main
tugeva	doc_491521501866_item	2530293	et	4	main
p-ga	doc_491521501866_item	2530294	et	3	main
sest	doc_491521501866_item	2530295	et	4	main
eesti	doc_491521501866_item	2530296	et	4	main
jaoks	doc_491521501866_item	2530302	et	4	main
sarnaselt	doc_491521501866_item	2530303	et	4	main
neist	doc_491521501866_item	2530306	et	4	main
uks	doc_491521501866_item	2530317	et	3	main
naide	doc_491521501866_item	2530318	et	4	main
n	doc_491521501866_item	2530321	et	4	main
ikkagi	doc_491521501866_item	2530328	et	4	main
lause	doc_491521501866_item	2530336	et	4	main
keelest	doc_491521501866_item	2530341	et	4	main
ti	doc_491521501866_item	2530342	et	4	main
ja	doc_491521501866_item	2530350	et	3	main
sageli	doc_491521501866_item	2530352	et	3	main
et	doc_491521501866_item	2530381	et	3	main
liiknviga	doc_491521501866_item	2530392	et	4	main
vale	doc_491521501866_item	2530395	et	4	main
on	doc_491521501866_item	2530398	et	4	main
pohjustatud	doc_491521501866_item	2530399	et	4	main
kasutamine	doc_491521501866_item	2530404	et	4	main
tingitud	doc_491521501866_item	2530409	et	4	main
vene	doc_491521501866_item	2530224	et	4	main
konkretses	doc_491521501866_item	2530245	et	4	main
naide	doc_491521501866_item	2530253	et	4	main
sellega	doc_491521501866_item	2530258	et	3	main
enam	doc_491521501866_item	2530260	et	4	main
ei	doc_491521501866_item	2530261	et	4	main
lebi	doc_491521501866_item	2530262	et	4	main
ci	doc_491521501866_item	2530263	et	4	main
lepi	doc_491521501866_item	2530264	et	4	main
vea	doc_491521501866_item	2530265	et	4	main
pohjus	doc_491521501866_item	2530266	et	4	main
on	doc_491521501866_item	2530267	et	4	main
samuti	doc_491521501866_item	2530268	et	3	main
selles	doc_491521501866_item	2530269	et	4	main
et	doc_491521501866_item	2530270	et	3	main
vene	doc_491521501866_item	2530271	et	4	main
emakeelega	doc_491521501866_item	2530272	et	3	main
oppija	doc_491521501866_item	2530273	et	4	main
ei	doc_491521501866_item	2530274	et	4	main
erista	doc_491521501866_item	2530275	et	4	main
eesti	doc_491521501866_item	2530276	et	4	main
valteid	doc_491521501866_item	2530277	et	4	main
jargi	doc_491521501866_item	2530285	et	4	main
maaratleda	doc_491521501866_item	2530286	et	4	main
kas	doc_491521501866_item	2530287	et	3	main
tegemist	doc_491521501866_item	2530288	et	4	main
keeles	doc_491521501866_item	2530297	et	4	main
kolavad	doc_491521501866_item	2530298	et	4	main
paljudel	doc_491521501866_item	2530304	et	3	main
on	doc_491521501866_item	2530307	et	4	main
priti	doc_491521501866_item	2530308	et	4	main
kodaniku	doc_491521501866_item	2530309	et	3	main
i3rit	doc_491521501866_item	2530311	et	4	main
kcdcrnikrr	doc_491521501866_item	2530312	et	4	main
vt	doc_491521501866_item	2530319	et	4	main
eelm	doc_491521501866_item	2530320	et	4	main
ma	doc_491521501866_item	2530324	et	3	main
pearr	doc_491521501866_item	2530331	et	4	main
jrrrdrna	doc_491521501866_item	2530333	et	4	main
vene	doc_491521501866_item	2530340	et	4	main
kcrks	doc_491521501866_item	2530349	et	4	main
segi	doc_491521501866_item	2530354	et	3	main
oppimicega	doc_491521501866_item	2530382	et	4	main
iga	doc_491521501866_item	2530384	et	4	main
tcrrgernaka	doc_491521501866_item	2530386	et	4	main
antud	doc_491521501866_item	2530387	et	4	main
lauses	doc_491521501866_item	2530388	et	3	main
2	doc_491521501866_item	2530390	et	2	main
asemel	doc_491521501866_item	2530406	et	4	main
samuti	doc_491521501866_item	2530408	et	3	main
mojust	doc_491521501866_item	2530411	et	4	main
mo	doc_491521501866_item	2530417	et	4	main
eesti	doc_491521501866_item	2530419	et	4	main
keeles	doc_491521501866_item	2530420	et	4	main
aga	doc_491521501866_item	2530422	et	3	main
saada	doc_491521501866_item	2530438	et	4	main
targemateks	doc_491521501866_item	2530441	et	4	main
iaryjernateks	doc_491521501866_item	2530451	et	4	main
on	doc_491521501866_item	2530454	et	4	main
hautu	doc_491521501866_item	2530463	et	4	main
6br	doc_491521501866_item	2530472	et	4	main
cmama	doc_491521501866_item	2530474	et	4	main
mis	doc_491521501866_item	2530527	et	4	main
on	doc_491521501866_item	2530528	et	4	main
tingitud	doc_491521501866_item	2530529	et	4	main
emakeelest	doc_491521501866_item	2530530	et	4	main
paku	doc_491521501866_item	2530547	et	4	main
on	doc_491521501866_item	2530553	et	4	main
nii	doc_491521501866_item	2530554	et	3	main
kui	doc_491521501866_item	2530555	et	3	main
ulesandeid	doc_491521501866_item	2530559	et	4	main
et	doc_491521501866_item	2530578	et	3	main
frtteligi	doc_491521501866_item	2530584	et	4	main
cxrttcrkse	doc_491521501866_item	2530590	et	4	main
emakeele	doc_491521501866_item	2530602	et	4	main
otse	doc_491521501866_item	2530607	et	4	main
voi	doc_491521501866_item	2530292	et	4	main
on	doc_491521501866_item	2530305	et	4	main
veel	doc_491521501866_item	2530316	et	4	main
pean	doc_491521501866_item	2530325	et	4	main
tulema	doc_491521501866_item	2530327	et	4	main
otse	doc_491521501866_item	2530339	et	4	main
aetakse	doc_491521501866_item	2530353	et	3	main
keeles	doc_491521501866_item	2530357	et	4	main
dea	doc_491521501866_item	2530359	et	4	main
samuti	doc_491521501866_item	2530362	et	3	main
targemaks	doc_491521501866_item	2530376	et	4	main
oflrridrrgi	doc_491521501866_item	2530377	et	4	main
orr	doc_491521501866_item	2530378	et	4	main
on	doc_491521501866_item	2530389	et	4	main
1	doc_491521501866_item	2530393	et	2	main
sonade	doc_491521501866_item	2530394	et	4	main
jarjekord	doc_491521501866_item	2530396	et	4	main
adverbi	doc_491521501866_item	2530403	et	4	main
vene	doc_491521501866_item	2530412	et	4	main
uxmepecxo	doc_491521501866_item	2530416	et	4	main
on	doc_491521501866_item	2530421	et	4	main
huvitav	doc_491521501866_item	2530424	et	4	main
on	doc_491521501866_item	2530425	et	4	main
see	doc_491521501866_item	2530426	et	3	main
et	doc_491521501866_item	2530427	et	3	main
aitaks	doc_491521501866_item	2530436	et	3	main
lause	doc_491521501866_item	2530457	et	4	main
keelest	doc_491521501866_item	2530462	et	4	main
cmaparomcr	doc_491521501866_item	2530466	et	4	main
xam	doc_491521501866_item	2530468	et	4	main
ymxee	doc_491521501866_item	2530477	et	4	main
ka	doc_491521501866_item	2530480	et	3	main
meile	doc_491521501866_item	2530485	et	4	main
kaane	doc_491521501866_item	2530491	et	4	main
rcxsh	doc_491521501866_item	2530521	et	4	main
sonade	doc_491521501866_item	2530523	et	4	main
minu	doc_491521501866_item	2530534	et	3	main
meeldib	doc_491521501866_item	2530536	et	3	main
ja	doc_491521501866_item	2530538	et	3	main
oelda	doc_491521501866_item	2530542	et	4	main
alati	doc_491521501866_item	2530544	et	4	main
see	doc_491521501866_item	2530545	et	3	main
ei	doc_491521501866_item	2530546	et	4	main
monikord	doc_491521501866_item	2530551	et	4	main
see	doc_491521501866_item	2530552	et	3	main
vasinud	doc_491521501866_item	2530567	et	4	main
oaatatnatcr	doc_491521501866_item	2530569	et	4	main
tneeldib	doc_491521501866_item	2530571	et	4	main
ei	doc_491521501866_item	2530575	et	4	main
cxlati	doc_491521501866_item	2530579	et	4	main
lcrkrrks	doc_491521501866_item	2530581	et	4	main
rtmrlle	doc_491521501866_item	2530582	et	4	main
kccrulisi	doc_491521501866_item	2530592	et	4	main
voltwcl	doc_491521501866_item	2530594	et	4	main
ttecd	doc_491521501866_item	2530595	et	4	main
lause	doc_491521501866_item	2530604	et	4	main
on	doc_491521501866_item	2530605	et	4	main
isegi	doc_491521501866_item	2530624	et	4	main
keeles	doc_491521501866_item	2530626	et	4	main
see	doc_491521501866_item	2530628	et	3	main
mida	doc_491521501866_item	2530639	et	4	main
tunda	doc_491521501866_item	2530645	et	3	main
teistele	doc_491521501866_item	2530648	et	4	main
irleks	doc_491521501866_item	2530650	et	4	main
sellect	doc_491521501866_item	2530655	et	4	main
eadr	doc_491521501866_item	2530661	et	4	main
tegemist	doc_491521501866_item	2530668	et	4	main
tavaliselt	doc_491521501866_item	2530674	et	4	main
moodustab	doc_491521501866_item	2530675	et	3	main
emakeele	doc_491521501866_item	2530682	et	4	main
mallist	doc_491521501866_item	2530683	et	4	main
ei	doc_491521501866_item	2530694	et	4	main
oska	doc_491521501866_item	2530695	et	4	main
stiili-	doc_491521501866_item	2530699	et	4	main
vene	doc_491521501866_item	2530712	et	4	main
ajalugu	doc_491521501866_item	2530721	et	4	main
selleparast	doc_491521501866_item	2530723	et	3	main
rahvastel	doc_491521501866_item	2530725	et	4	main
rting	doc_491521501866_item	2530748	et	4	main
rtertdegr	doc_491521501866_item	2530749	et	4	main
secotrrd	doc_491521501866_item	2530750	et	4	main
emakeele	doc_491521501866_item	2530755	et	4	main
lausemoodustuses	doc_491521501866_item	2530323	et	3	main
koju	doc_491521501866_item	2530326	et	3	main
lia	doc_491521501866_item	2530330	et	4	main
donmex	doc_491521501866_item	2530343	et	4	main
npuumu	doc_491521501866_item	2530344	et	4	main
domou	doc_491521501866_item	2530345	et	4	main
x	doc_491521501866_item	2530346	et	4	main
deyu	doc_491521501866_item	2530347	et	4	main
sonad	doc_491521501866_item	2530348	et	4	main
vene	doc_491521501866_item	2530356	et	4	main
on	doc_491521501866_item	2530358	et	4	main
ja	doc_491521501866_item	2530360	et	3	main
emopou	doc_491521501866_item	2530361	et	4	main
kaks	doc_491521501866_item	2530363	et	3	main
erinevat	doc_491521501866_item	2530364	et	4	main
sona	doc_491521501866_item	2530365	et	4	main
muidugi	doc_491521501866_item	2530366	et	4	main
vaga	doc_491521501866_item	2530367	et	4	main
huvitavalt	doc_491521501866_item	2530368	et	4	main
on	doc_491521501866_item	2530369	et	4	main
see	doc_491521501866_item	2530370	et	3	main
et	doc_491521501866_item	2530371	et	3	main
oppimisega	doc_491521501866_item	2530372	et	4	main
iga	doc_491521501866_item	2530373	et	4	main
inimene	doc_491521501866_item	2530374	et	3	main
saab	doc_491521501866_item	2530375	et	3	main
lmrrvitcn	doc_491521501866_item	2530379	et	4	main
saab	doc_491521501866_item	2530383	et	3	main
irrirnerae	doc_491521501866_item	2530385	et	4	main
eri	doc_491521501866_item	2530391	et	4	main
emakeele	doc_491521501866_item	2530400	et	4	main
mojust	doc_491521501866_item	2530401	et	4	main
2	doc_491521501866_item	2530402	et	2	main
adjektiivi	doc_491521501866_item	2530405	et	4	main
on	doc_491521501866_item	2530407	et	4	main
on	doc_491521501866_item	2530414	et	4	main
meie	doc_491521501866_item	2530428	et	4	main
andekad	doc_491521501866_item	2530429	et	3	main
opetajad	doc_491521501866_item	2530430	et	4	main
puuavad	doc_491521501866_item	2530431	et	3	main
meile	doc_491521501866_item	2530433	et	4	main
mida	doc_491521501866_item	2530435	et	4	main
ja	doc_491521501866_item	2530440	et	3	main
emakeelest	doc_491521501866_item	2530456	et	4	main
damb	doc_491521501866_item	2530467	et	4	main
ace	doc_491521501866_item	2530469	et	4	main
nouo2jro	doc_491521501866_item	2530471	et	4	main
u	doc_491521501866_item	2530476	et	4	main
mida	doc_491521501866_item	2530488	et	4	main
vale	doc_491521501866_item	2530490	et	4	main
traed	doc_491521501866_item	2530522	et	4	main
vale	doc_491521501866_item	2530524	et	4	main
jarjekord	doc_491521501866_item	2530525	et	4	main
lauses	doc_491521501866_item	2530526	et	3	main
aga	doc_491521501866_item	2530531	et	3	main
oppimine	doc_491521501866_item	2530535	et	4	main
mulle	doc_491521501866_item	2530537	et	4	main
saa	doc_491521501866_item	2530541	et	4	main
et	doc_491521501866_item	2530543	et	3	main
kuid	doc_491521501866_item	2530550	et	4	main
on	doc_491521501866_item	2530557	et	4	main
need	doc_491521501866_item	2530561	et	3	main
rasked	doc_491521501866_item	2530563	et	3	main
olen	doc_491521501866_item	2530566	et	3	main
iitclda	doc_491521501866_item	2530577	et	4	main
otz	doc_491521501866_item	2530585	et	4	main
rtii	doc_491521501866_item	2530586	et	4	main
krri	doc_491521501866_item	2530588	et	4	main
zcrljrr	doc_491521501866_item	2530591	et	4	main
iileccrrtdeid	doc_491521501866_item	2530593	et	4	main
i	doc_491521501866_item	2530597	et	4	main
pohjustatud	doc_491521501866_item	2530601	et	4	main
tolgitud	doc_491521501866_item	2530606	et	4	main
puhul	doc_491521501866_item	2530623	et	4	main
on	doc_491521501866_item	2530630	et	4	main
on	doc_491521501866_item	2530640	et	4	main
end	doc_491521501866_item	2530646	et	4	main
koike	doc_491521501866_item	2530657	et	4	main
tr7icla	doc_491521501866_item	2530658	et	4	main
on	doc_491521501866_item	2530659	et	4	main
ettttart	doc_491521501866_item	2530664	et	4	main
pohjustatud	doc_491521501866_item	2530672	et	4	main
oma	doc_491521501866_item	2530681	et	4	main
millele	doc_491521501866_item	2530692	et	3	main
sunonuumi	doc_491521501866_item	2530696	et	4	main
ka	doc_491521501866_item	2530705	et	3	main
guxumenbubau	doc_491521501866_item	2530713	et	4	main
eesti	doc_491521501866_item	2530715	et	4	main
iga	doc_491521501866_item	2530717	et	4	main
rahvas	doc_491521501866_item	2530718	et	4	main
omab	doc_491521501866_item	2530719	et	3	main
ja	doc_491521501866_item	2530722	et	3	main
koigil	doc_491521501866_item	2530724	et	4	main
omad	doc_491521501866_item	2530727	et	4	main
ja	doc_491521501866_item	2530729	et	3	main
cxst	doc_491521501866_item	2530742	et	4	main
veel	doc_491521501866_item	2530752	et	4	main
uks	doc_491521501866_item	2530753	et	3	main
antud	doc_491521501866_item	2530759	et	4	main
lauses	doc_491521501866_item	2530760	et	3	main
esineb	doc_491521501866_item	2530761	et	3	main
sonade	doc_491521501866_item	2530762	et	4	main
sonade	doc_491521501866_item	2530767	et	4	main
nt	doc_491521501866_item	2530770	et	4	main
traditsioortid	doc_491521501866_item	2530781	et	4	main
teie	doc_491521501866_item	2530793	et	4	main
im	doc_491521501866_item	2530798	et	4	main
r-cicygizw1	doc_491521501866_item	2530799	et	4	main
teicl	doc_491521501866_item	2530803	et	4	main
ci	doc_491521501866_item	2530804	et	4	main
viga	doc_491521501866_item	2530813	et	4	main
puuab	doc_491521501866_item	2530815	et	4	main
xe	doc_491521501866_item	2530828	et	4	main
eaur	doc_491521501866_item	2530830	et	4	main
3mo	doc_491521501866_item	2530832	et	4	main
olnud	doc_491521501866_item	2530840	et	4	main
ilus	doc_491521501866_item	2530843	et	4	main
margatav	doc_491521501866_item	2530845	et	4	main
parimateks	doc_491521501866_item	2530439	et	4	main
piiiicmard	doc_491521501866_item	2530442	et	4	main
pcxalt	doc_491521501866_item	2530445	et	4	main
clt	doc_491521501866_item	2530447	et	4	main
rrra	doc_491521501866_item	2530448	et	4	main
sacrfcirrre	doc_491521501866_item	2530449	et	4	main
irrimesleks	doc_491521501866_item	2530452	et	4	main
viga	doc_491521501866_item	2530453	et	4	main
pohjustatud	doc_491521501866_item	2530455	et	4	main
otse	doc_491521501866_item	2530460	et	4	main
vene	doc_491521501866_item	2530461	et	4	main
yuumenr	doc_491521501866_item	2530465	et	4	main
nyuuse	doc_491521501866_item	2530475	et	4	main
siit	doc_491521501866_item	2530478	et	3	main
vead	doc_491521501866_item	2530481	et	4	main
nt	doc_491521501866_item	2530482	et	4	main
puuavad	doc_491521501866_item	2530483	et	3	main
anda	doc_491521501866_item	2530484	et	3	main
stiiliviga	doc_491521501866_item	2530487	et	4	main
aitaks	doc_491521501866_item	2530489	et	3	main
sest	doc_491521501866_item	2530492	et	4	main
nii	doc_491521501866_item	2530493	et	3	main
eesti	doc_491521501866_item	2530494	et	4	main
mis	doc_491521501866_item	2530495	et	4	main
kui	doc_491521501866_item	2530496	et	3	main
ka	doc_491521501866_item	2530497	et	3	main
mida	doc_491521501866_item	2530498	et	4	main
tahendavad	doc_491521501866_item	2530499	et	4	main
vene	doc_491521501866_item	2530500	et	4	main
keeles	doc_491521501866_item	2530501	et	4	main
qmo	doc_491521501866_item	2530502	et	4	main
aitaks	doc_491521501866_item	2530503	et	3	main
meile	doc_491521501866_item	2530504	et	4	main
rektsiooniviga	doc_491521501866_item	2530505	et	4	main
nagu	doc_491521501866_item	2530506	et	3	main
igas	doc_491521501866_item	2530507	et	3	main
toos	doc_491521501866_item	2530508	et	3	main
meil	doc_491521501866_item	2530509	et	4	main
on	doc_491521501866_item	2530510	et	4	main
ka	doc_491521501866_item	2530511	et	3	main
oma	doc_491521501866_item	2530512	et	4	main
raskused	doc_491521501866_item	2530513	et	4	main
ncrgu	doc_491521501866_item	2530514	et	4	main
igas	doc_491521501866_item	2530515	et	3	main
toos	doc_491521501866_item	2530516	et	3	main
on	doc_491521501866_item	2530517	et	4	main
hi	doc_491521501866_item	2530518	et	4	main
meil	doc_491521501866_item	2530519	et	4	main
ottrcxd	doc_491521501866_item	2530520	et	4	main
on	doc_491521501866_item	2530458	et	4	main
tolgitud	doc_491521501866_item	2530459	et	4	main
mcuraxrrznuabre	doc_491521501866_item	2530464	et	4	main
umo	doc_491521501866_item	2530470	et	4	main
xam	doc_491521501866_item	2530473	et	4	main
tulevad	doc_491521501866_item	2530479	et	4	main
koike	doc_491521501866_item	2530486	et	4	main
sellele	doc_491521501866_item	2530533	et	4	main
ma	doc_491521501866_item	2530539	et	3	main
mul	doc_491521501866_item	2530556	et	3	main
on	doc_491521501866_item	2530562	et	4	main
ma	doc_491521501866_item	2530565	et	3	main
ntrrlle	doc_491521501866_item	2530572	et	4	main
et	doc_491521501866_item	2530587	et	3	main
dsiladi	doc_491521501866_item	2530598	et	4	main
viga	doc_491521501866_item	2530599	et	4	main
on	doc_491521501866_item	2530600	et	4	main
antud	doc_491521501866_item	2530621	et	4	main
selles	doc_491521501866_item	2530636	et	4	main
oleks	doc_491521501866_item	2530637	et	3	main
koik	doc_491521501866_item	2530638	et	4	main
ja	doc_491521501866_item	2530644	et	3	main
7	doc_491521501866_item	2530649	et	2	main
airlida	doc_491521501866_item	2530651	et	4	main
vaja	doc_491521501866_item	2530660	et	4	main
ja	doc_491521501866_item	2530662	et	3	main
i	doc_491521501866_item	2530665	et	4	main
ittirarcscrta	doc_491521501866_item	2530667	et	4	main
veaga	doc_491521501866_item	2530673	et	3	main
eesti	doc_491521501866_item	2530676	et	4	main
keele	doc_491521501866_item	2530677	et	4	main
oppija	doc_491521501866_item	2530693	et	4	main
ja	doc_491521501866_item	2530700	et	3	main
lausemoodustusvigade	doc_491521501866_item	2530701	et	4	main
esineb	doc_491521501866_item	2530702	et	3	main
kaandeviga	doc_491521501866_item	2530706	et	4	main
valida	doc_491521501866_item	2530707	et	3	main
toocp	doc_491521501866_item	2530709	et	4	main
otsetolkes	doc_491521501866_item	2530710	et	4	main
osastav	doc_491521501866_item	2530716	et	4	main
oma	doc_491521501866_item	2530720	et	4	main
erilisused	doc_491521501866_item	2530728	et	4	main
otncx	doc_491521501866_item	2530738	et	4	main
ajcrlry7rr	doc_491521501866_item	2530739	et	4	main
seilepit	doc_491521501866_item	2530741	et	4	main
moodustamisel	doc_491521501866_item	2530758	et	4	main
sama	doc_491521501866_item	2530765	et	4	main
kordamine	doc_491521501866_item	2530769	et	4	main
omab	doc_491521501866_item	2530771	et	3	main
ja	doc_491521501866_item	2530780	et	3	main
sunonuumid	doc_491521501866_item	2530783	et	4	main
teid	doc_491521501866_item	2530789	et	4	main
see	doc_491521501866_item	2530795	et	3	main
km	doc_491521501866_item	2530802	et	4	main
printsiibil	doc_491521501866_item	2530811	et	3	main
eesti	doc_491521501866_item	2530818	et	4	main
panna	doc_491521501866_item	2530821	et	4	main
3cmoxusa	doc_491521501866_item	2530823	et	4	main
zogopsam	doc_491521501866_item	2530824	et	4	main
eac	doc_491521501866_item	2530827	et	4	main
y3xm	doc_491521501866_item	2530829	et	4	main
sttatcombau	doc_491521501866_item	2530831	et	4	main
npuxecem	doc_491521501866_item	2530833	et	4	main
vaga	doc_491521501866_item	2530835	et	4	main
tallinn	doc_491521501866_item	2530838	et	4	main
ei	doc_491521501866_item	2530839	et	4	main
koik	doc_491521501866_item	2530849	et	4	main
rrri5oda	doc_491521501866_item	2530878	et	4	main
on	doc_491521501866_item	2530923	et	4	main
probleemiga	doc_491521501866_item	2530947	et	4	main
emakeelega	doc_491521501866_item	2530968	et	3	main
oppijatel	doc_491521501866_item	2530969	et	4	main
tehas	doc_491521501866_item	2530994	et	3	main
sonadest	doc_491521501866_item	2531028	et	4	main
kcxhllrrst	doc_491521501866_item	2531040	et	4	main
voetud	doc_491521501866_item	2531051	et	4	main
samuti	doc_491521501866_item	2531052	et	3	main
vea	doc_491521501866_item	2531054	et	4	main
jai	doc_491521501866_item	2531067	et	4	main
lause	doc_491521501866_item	2531073	et	4	main
voimaldab	doc_491521501866_item	2531081	et	4	main
vigu	doc_491521501866_item	2531090	et	3	main
vaatamata	doc_491521501866_item	2530532	et	4	main
ei	doc_491521501866_item	2530540	et	4	main
mulle	doc_491521501866_item	2530548	et	4	main
rahulolu	doc_491521501866_item	2530549	et	4	main
palju	doc_491521501866_item	2530558	et	4	main
ja	doc_491521501866_item	2530560	et	3	main
ja	doc_491521501866_item	2530564	et	3	main
trtt	doc_491521501866_item	2530568	et	4	main
sellele	doc_491521501866_item	2530570	et	4	main
oppiratitte	doc_491521501866_item	2530573	et	4	main
krrigi	doc_491521501866_item	2530574	et	4	main
saaks	doc_491521501866_item	2530576	et	3	main
see	doc_491521501866_item	2530580	et	3	main
rahrrlclrr	doc_491521501866_item	2530583	et	4	main
rtnrllc	doc_491521501866_item	2530589	et	4	main
mind	doc_491521501866_item	2530596	et	4	main
mojust	doc_491521501866_item	2530603	et	4	main
vene	doc_491521501866_item	2530608	et	4	main
keelesttavaliselt	doc_491521501866_item	2530609	et	4	main
on	doc_491521501866_item	2530610	et	4	main
vene	doc_491521501866_item	2530611	et	4	main
laused	doc_491521501866_item	2530612	et	3	main
konstruktsioonilt	doc_491521501866_item	2530613	et	3	main
pikemad	doc_491521501866_item	2530614	et	4	main
ja	doc_491521501866_item	2530615	et	3	main
keerulisemad	doc_491521501866_item	2530616	et	4	main
kui	doc_491521501866_item	2530617	et	3	main
eesti	doc_491521501866_item	2530618	et	4	main
omad	doc_491521501866_item	2530619	et	4	main
aga	doc_491521501866_item	2530620	et	3	main
vene	doc_491521501866_item	2530625	et	4	main
elada	doc_491521501866_item	2530643	et	3	main
vajalikuna	doc_491521501866_item	2530647	et	3	main
sellirte	doc_491521501866_item	2530652	et	4	main
et	doc_491521501866_item	2530654	et	3	main
trrttdcr	doc_491521501866_item	2530663	et	4	main
emakeelest	doc_491521501866_item	2530671	et	4	main
oppija	doc_491521501866_item	2530678	et	4	main
lauseid	doc_491521501866_item	2530679	et	3	main
just	doc_491521501866_item	2530680	et	3	main
lahtuvalt	doc_491521501866_item	2530684	et	4	main
stiililiselt	doc_491521501866_item	2530687	et	4	main
on	doc_491521501866_item	2530690	et	4	main
vajd	doc_491521501866_item	2530691	et	4	main
antud	doc_491521501866_item	2530703	et	4	main
vastab	doc_491521501866_item	2530711	et	3	main
kaandele	doc_491521501866_item	2530714	et	4	main
lause	doc_491521501866_item	2530622	et	4	main
kolaks	doc_491521501866_item	2530627	et	4	main
ebakorrektselt	doc_491521501866_item	2530629	et	4	main
vaja	doc_491521501866_item	2530631	et	4	main
valida	doc_491521501866_item	2530632	et	3	main
niisugust	doc_491521501866_item	2530633	et	3	main
tood	doc_491521501866_item	2530634	et	3	main
et	doc_491521501866_item	2530635	et	3	main
vaja	doc_491521501866_item	2530641	et	4	main
et	doc_491521501866_item	2530642	et	3	main
tip	doc_491521501866_item	2530653	et	4	main
acrks	doc_491521501866_item	2530656	et	4	main
crjcrliktr	doc_491521501866_item	2530666	et	4	main
on	doc_491521501866_item	2530669	et	4	main
jallegi	doc_491521501866_item	2530670	et	4	main
lause	doc_491521501866_item	2530685	et	4	main
on	doc_491521501866_item	2530686	et	4	main
ebakorrektne	doc_491521501866_item	2530688	et	3	main
kordub	doc_491521501866_item	2530689	et	3	main
leida	doc_491521501866_item	2530697	et	3	main
peale	doc_491521501866_item	2530698	et	4	main
lauses	doc_491521501866_item	2530704	et	3	main
niisugust	doc_491521501866_item	2530708	et	3	main
on	doc_491521501866_item	2530726	et	4	main
nendega	doc_491521501866_item	2530730	et	4	main
seotud	doc_491521501866_item	2530731	et	4	main
kombed	doc_491521501866_item	2530732	et	3	main
ja	doc_491521501866_item	2530733	et	3	main
traditsioonid	doc_491521501866_item	2530734	et	3	main
igal	doc_491521501866_item	2530735	et	3	main
rahocxi	doc_491521501866_item	2530736	et	4	main
ott	doc_491521501866_item	2530737	et	3	main
cmrad	doc_491521501866_item	2530746	et	4	main
eripurad	doc_491521501866_item	2530747	et	3	main
naide	doc_491521501866_item	2530754	et	4	main
vale	doc_491521501866_item	2530763	et	4	main
jarjekord	doc_491521501866_item	2530764	et	4	main
keeles	doc_491521501866_item	2530774	et	4	main
umeem	doc_491521501866_item	2530775	et	4	main
ceoto	doc_491521501866_item	2530776	et	4	main
liigsed	doc_491521501866_item	2530777	et	3	main
sonad	doc_491521501866_item	2530778	et	4	main
kombed	doc_491521501866_item	2530779	et	3	main
eestlased	doc_491521501866_item	2530785	et	3	main
kui	doc_491521501866_item	2530788	et	3	main
ei	doc_491521501866_item	2530790	et	4	main
tundnud	doc_491521501866_item	2530791	et	4	main
ara	doc_491521501866_item	2530792	et	3	main
rikkus	doc_491521501866_item	2530797	et	4	main
rikkaks	doc_491521501866_item	2530809	et	4	main
eute	doc_491521501866_item	2530822	et	4	main
limo	doc_491521501866_item	2530825	et	4	main
ecnu	doc_491521501866_item	2530826	et	4	main
ammu	doc_491521501866_item	2530836	et	4	main
selleparast	doc_491521501866_item	2530854	et	3	main
selle	doc_491521501866_item	2530855	et	4	main
arenenud	doc_491521501866_item	2530859	et	4	main
annrna	doc_491521501866_item	2530861	et	4	main
7cxllirtrt	doc_491521501866_item	2530863	et	4	main
kiik	doc_491521501866_item	2530875	et	3	main
ei	doc_491521501866_item	2530881	et	4	main
on	doc_491521501866_item	2530886	et	4	main
oppijal	doc_491521501866_item	2530922	et	4	main
jatta	doc_491521501866_item	2530926	et	4	main
eesti	doc_491521501866_item	2530928	et	4	main
keele	doc_491521501866_item	2530929	et	4	main
eripara	doc_491521501866_item	2530930	et	4	main
et	doc_491521501866_item	2530931	et	3	main
on	doc_491521501866_item	2530942	et	4	main
vrd	doc_491521501866_item	2530948	et	4	main
jalatsid	doc_491521501866_item	2530950	et	3	main
sukad	doc_491521501866_item	2530952	et	3	main
jalas	doc_491521501866_item	2530955	et	4	main
jope	doc_491521501866_item	2530956	et	4	main
jaglal	doc_491521501866_item	2530978	et	4	main
ja	doc_491521501866_item	2530987	et	3	main
jalgpalli	doc_491521501866_item	2530988	et	4	main
pall	doc_491521501866_item	2530989	et	3	main
asunud	doc_491521501866_item	2530993	et	4	main
7	doc_491521501866_item	2531026	et	2	main
aru	doc_491521501866_item	2531029	et	4	main
kahtlust	doc_491521501866_item	2531031	et	4	main
et	doc_491521501866_item	2531032	et	3	main
tooriietusel	doc_491521501866_item	2531033	et	3	main
ei	doc_491521501866_item	2531034	et	4	main
ole	doc_491521501866_item	2531035	et	4	main
tekkiiehrsel	doc_491521501866_item	2531042	et	4	main
ole	doc_491521501866_item	2531044	et	4	main
osr	doc_491521501866_item	2531048	et	4	main
etteutlusest	doc_491521501866_item	2531053	et	4	main
on	doc_491521501866_item	2531056	et	4	main
jcz	doc_491521501866_item	2530740	et	4	main
on	doc_491521501866_item	2530743	et	4	main
koigil	doc_491521501866_item	2530744	et	4	main
kcr	doc_491521501866_item	2530745	et	4	main
kottthed	doc_491521501866_item	2530751	et	4	main
tuvega	doc_491521501866_item	2530766	et	4	main
tuttav	doc_491521501866_item	2530794	et	3	main
eestlcrsecl	doc_491521501866_item	2530800	et	4	main
et	doc_491521501866_item	2530801	et	3	main
trrnta	doc_491521501866_item	2530805	et	4	main
amcr	doc_491521501866_item	2530806	et	4	main
siic	doc_491521501866_item	2530807	et	4	main
sonadega	doc_491521501866_item	2530819	et	4	main
kirja	doc_491521501866_item	2530820	et	4	main
nii	doc_491521501866_item	2530842	et	3	main
ja	doc_491521501866_item	2530844	et	3	main
linn	doc_491521501866_item	2530846	et	3	main
kui	doc_491521501866_item	2530847	et	3	main
kaubalaevad	doc_491521501866_item	2530850	et	3	main
linna	doc_491521501866_item	2530856	et	4	main
majandus	doc_491521501866_item	2530857	et	4	main
agcr	doc_491521501866_item	2530860	et	4	main
kui	doc_491521501866_item	2530862	et	3	main
rtii	doc_491521501866_item	2530867	et	4	main
ilrts	doc_491521501866_item	2530868	et	4	main
ktrrrhrs	doc_491521501866_item	2530870	et	4	main
ttcrgrr	doc_491521501866_item	2530872	et	4	main
sitcid	doc_491521501866_item	2530874	et	4	main
hrllirtrrast	doc_491521501866_item	2530877	et	4	main
meelde	doc_491521501866_item	2530925	et	3	main
ka	doc_491521501866_item	2530936	et	3	main
tegemist	doc_491521501866_item	2530943	et	4	main
ilmselt	doc_491521501866_item	2530944	et	4	main
nt	doc_491521501866_item	2530949	et	4	main
selgelt	doc_491521501866_item	2530954	et	4	main
asjad	doc_491521501866_item	2530960	et	3	main
nagu	doc_491521501866_item	2530961	et	3	main
iilikond	doc_491521501866_item	2530965	et	4	main
eriti	doc_491521501866_item	2530971	et	3	main
algetapil	doc_491521501866_item	2530972	et	3	main
lumepall	doc_491521501866_item	2530973	et	3	main
segiajamisega	doc_491521501866_item	2530990	et	4	main
lubja	doc_491521501866_item	2530991	et	3	main
kuulmise	doc_491521501866_item	2531021	et	4	main
kuigi	doc_491521501866_item	2531023	et	3	main
kirjutatud	doc_491521501866_item	2531027	et	4	main
pole	doc_491521501866_item	2531039	et	3	main
et	doc_491521501866_item	2531041	et	3	main
viga	doc_491521501866_item	2531049	et	4	main
on	doc_491521501866_item	2531050	et	4	main
sama	doc_491521501866_item	2531057	et	4	main
ka	doc_491521501866_item	2531059	et	3	main
eelmise	doc_491521501866_item	2531060	et	3	main
naite	doc_491521501866_item	2531061	et	3	main
puhul	doc_491521501866_item	2531062	et	4	main
oppija	doc_491521501866_item	2531063	et	4	main
kirjutas	doc_491521501866_item	2531064	et	3	main
seda	doc_491521501866_item	2531065	et	3	main
sisu	doc_491521501866_item	2531074	et	4	main
kokkuvote	doc_491521501866_item	2531078	et	4	main
veaanaluiis	doc_491521501866_item	2531080	et	4	main
jareldada	doc_491521501866_item	2531082	et	4	main
koige	doc_491521501866_item	2531088	et	4	main
rohkem	doc_491521501866_item	2531089	et	4	main
juhul	doc_491521501866_item	2531103	et	3	main
puuab	doc_491521501866_item	2531107	et	4	main
abiks	doc_491521501866_item	2531111	et	3	main
sellised	doc_491521501866_item	2531128	et	4	main
tiiiipilised	doc_491521501866_item	2531129	et	4	main
vead	doc_491521501866_item	2531130	et	4	main
nagu	doc_491521501866_item	2531131	et	3	main
vale	doc_491521501866_item	2531132	et	4	main
lausemoodustuses	doc_491521501866_item	2531137	et	3	main
sonade	doc_491521501866_item	2531138	et	4	main
riga	doc_491521501866_item	2531141	et	4	main
pikad	doc_491521501866_item	2531142	et	4	main
keerulised	doc_491521501866_item	2531144	et	4	main
jne	doc_491521501866_item	2531149	et	4	main
koige	doc_491521501866_item	2531150	et	4	main
valmistavad	doc_491521501866_item	2531154	et	4	main
uhendverbid	doc_491521501866_item	2531179	et	4	main
opetaja	doc_491521501866_item	2531196	et	4	main
tahelepanu	doc_491521501866_item	2531200	et	4	main
sarnasustele	doc_491521501866_item	2531204	et	4	main
erinevustele	doc_491521501866_item	2531207	et	4	main
areneks	doc_491521501866_item	2531211	et	3	main
mojust	doc_491521501866_item	2530756	et	4	main
lause	doc_491521501866_item	2530757	et	4	main
tarbetu	doc_491521501866_item	2530768	et	4	main
oma	doc_491521501866_item	2530772	et	4	main
vene	doc_491521501866_item	2530773	et	4	main
on	doc_491521501866_item	2530782	et	4	main
veel	doc_491521501866_item	2530784	et	4	main
raagivad	doc_491521501866_item	2530786	et	3	main
et	doc_491521501866_item	2530787	et	3	main
toob	doc_491521501866_item	2530796	et	3	main
scrcrte	doc_491521501866_item	2530808	et	4	main
samal	doc_491521501866_item	2530810	et	3	main
pohinev	doc_491521501866_item	2530812	et	4	main
oppija	doc_491521501866_item	2530814	et	4	main
vene	doc_491521501866_item	2530816	et	4	main
lauset	doc_491521501866_item	2530817	et	3	main
6o2amcmeo	doc_491521501866_item	2530834	et	4	main
kui	doc_491521501866_item	2530837	et	3	main
veel	doc_491521501866_item	2530841	et	4	main
praegu	doc_491521501866_item	2530848	et	3	main
soitsid	doc_491521501866_item	2530851	et	4	main
mooda	doc_491521501866_item	2530852	et	4	main
ei	doc_491521501866_item	2530858	et	4	main
ci	doc_491521501866_item	2530864	et	4	main
him	doc_491521501866_item	2530871	et	4	main
pracyjtr	doc_491521501866_item	2530873	et	4	main
karrhctlcreaad	doc_491521501866_item	2530876	et	4	main
kcr	doc_491521501866_item	2530883	et	4	main
tnallrtnlrrs	doc_491521501866_item	2530884	et	4	main
tegemist	doc_491521501866_item	2530885	et	4	main
jalle	doc_491521501866_item	2530887	et	4	main
emakeelest	doc_491521501866_item	2530888	et	4	main
tingitud	doc_491521501866_item	2530889	et	4	main
vigadega	doc_491521501866_item	2530890	et	3	main
sona	doc_491521501866_item	2530891	et	4	main
margatav	doc_491521501866_item	2530892	et	4	main
on	doc_491521501866_item	2530893	et	4	main
otsetolge	doc_491521501866_item	2530894	et	4	main
vene	doc_491521501866_item	2530895	et	4	main
sonast	doc_491521501866_item	2530896	et	4	main
san	doc_491521501866_item	2530897	et	4	main
aemxbau	doc_491521501866_item	2530898	et	4	main
soitsid	doc_491521501866_item	2530899	et	4	main
mooda	doc_491521501866_item	2530900	et	4	main
tallinnatnpoe3manu	doc_491521501866_item	2530901	et	4	main
mumo	doc_491521501866_item	2530902	et	4	main
tarututaxd	doc_491521501866_item	2530903	et	4	main
antud	doc_491521501866_item	2530904	et	4	main
viga	doc_491521501866_item	2530905	et	4	main
muudab	doc_491521501866_item	2530906	et	3	main
ka	doc_491521501866_item	2530907	et	3	main
lause	doc_491521501866_item	2530908	et	4	main
sonade	doc_491521501866_item	2530910	et	4	main
sisu	doc_491521501866_item	2530909	et	4	main
vale	doc_491521501866_item	2530911	et	4	main
jarjekord	doc_491521501866_item	2530912	et	4	main
lauses	doc_491521501866_item	2530913	et	3	main
muud	doc_491521501866_item	2530914	et	4	main
vead	doc_491521501866_item	2530915	et	4	main
mul	doc_491521501866_item	2530916	et	3	main
on	doc_491521501866_item	2530917	et	4	main
puksid	doc_491521501866_item	2530918	et	4	main
seljas	doc_491521501866_item	2530919	et	4	main
vene	doc_491521501866_item	2530920	et	4	main
tallinnat	doc_491521501866_item	2530853	et	4	main
oltnri	doc_491521501866_item	2530865	et	4	main
reel	doc_491521501866_item	2530866	et	3	main
ja	doc_491521501866_item	2530869	et	3	main
ttirtg	doc_491521501866_item	2530879	et	4	main
sellepcrrcrst	doc_491521501866_item	2530880	et	4	main
crt-ettenrrd	doc_491521501866_item	2530882	et	4	main
raske	doc_491521501866_item	2530924	et	4	main
teatud	doc_491521501866_item	2530927	et	4	main
tuleb	doc_491521501866_item	2530934	et	3	main
sellega	doc_491521501866_item	2530937	et	3	main
kehaosa	doc_491521501866_item	2530939	et	4	main
antud	doc_491521501866_item	2530940	et	4	main
juhul	doc_491521501866_item	2530941	et	3	main
maaratlemise	doc_491521501866_item	2530946	et	4	main
ja	doc_491521501866_item	2530951	et	3	main
on	doc_491521501866_item	2530953	et	4	main
voi	doc_491521501866_item	2530964	et	4	main
siin	doc_491521501866_item	2530979	et	4	main
tegemist	doc_491521501866_item	2530981	et	4	main
moiste	doc_491521501866_item	2530983	et	4	main
jal	doc_491521501866_item	2530984	et	4	main
l	doc_491521501866_item	2530985	et	4	main
gpalp	doc_491521501866_item	2530986	et	4	main
oli	doc_491521501866_item	2530995	et	3	main
amortiseerunud	doc_491521501866_item	2530996	et	4	main
ja	doc_491521501866_item	2530997	et	3	main
eimes	doc_491521501866_item	2530998	et	4	main
01	doc_491521501866_item	2530999	et	2	main
ellis	doc_491521501866_item	2531000	et	4	main
toodetud	doc_491521501866_item	2531001	et	4	main
seepi	doc_491521501866_item	2531002	et	4	main
piisas	doc_491521501866_item	2531003	et	4	main
ka	doc_491521501866_item	2531004	et	3	main
meie	doc_491521501866_item	2531005	et	4	main
jaoks	doc_491521501866_item	2531006	et	4	main
jcr	doc_491521501866_item	2531007	et	4	main
nasi-z-s	doc_491521501866_item	2531008	et	3	main
toocletrrd	doc_491521501866_item	2531009	et	4	main
secpi	doc_491521501866_item	2531010	et	4	main
piisas	doc_491521501866_item	2531011	et	4	main
kcr	doc_491521501866_item	2531012	et	4	main
rtaeiejcroks	doc_491521501866_item	2531013	et	4	main
antud	doc_491521501866_item	2531014	et	4	main
viga	doc_491521501866_item	2531015	et	4	main
on	doc_491521501866_item	2531016	et	4	main
voetud	doc_491521501866_item	2531017	et	4	main
etteiitlusest	doc_491521501866_item	2531018	et	4	main
oppija	doc_491521501866_item	2531019	et	4	main
kirjutas	doc_491521501866_item	2531020	et	3	main
emakeelega	doc_491521501866_item	2530921	et	3	main
riietusest	doc_491521501866_item	2530932	et	4	main
raakides	doc_491521501866_item	2530933	et	4	main
markida	doc_491521501866_item	2530935	et	4	main
seotud	doc_491521501866_item	2530938	et	4	main
kehaosa	doc_491521501866_item	2530945	et	4	main
on	doc_491521501866_item	2530957	et	4	main
seljas	doc_491521501866_item	2530958	et	4	main
sellised	doc_491521501866_item	2530959	et	4	main
nt	doc_491521501866_item	2530962	et	4	main
piiksid	doc_491521501866_item	2530963	et	3	main
tekitavad	doc_491521501866_item	2530966	et	4	main
vene	doc_491521501866_item	2530967	et	4	main
kahtlusi	doc_491521501866_item	2530970	et	4	main
oli	doc_491521501866_item	2530974	et	3	main
nii	doc_491521501866_item	2530975	et	3	main
suur	doc_491521501866_item	2530976	et	3	main
nagu	doc_491521501866_item	2530977	et	3	main
on	doc_491521501866_item	2530980	et	4	main
kahe	doc_491521501866_item	2530982	et	3	main
tanavas	doc_491521501866_item	2530992	et	4	main
jargi	doc_491521501866_item	2531022	et	4	main
ei	doc_491521501866_item	2531024	et	4	main
saanud	doc_491521501866_item	2531025	et	4	main
firma	doc_491521501866_item	2531036	et	4	main
tegevuses	doc_491521501866_item	2531037	et	4	main
ei	doc_491521501866_item	2531043	et	4	main
firmtra	doc_491521501866_item	2531045	et	4	main
tcihtsrrselrr	doc_491521501866_item	2531047	et	4	main
pohjus	doc_491521501866_item	2531055	et	4	main
muutunud	doc_491521501866_item	2531077	et	4	main
et	doc_491521501866_item	2531083	et	3	main
interferents	doc_491521501866_item	2531092	et	3	main
moju	doc_491521501866_item	2531095	et	4	main
inimene	doc_491521501866_item	2531098	et	3	main
voorkeelt	doc_491521501866_item	2531101	et	4	main
keelt	doc_491521501866_item	2531105	et	4	main
reeglid	doc_491521501866_item	2531116	et	3	main
pole	doc_491521501866_item	2531030	et	3	main
tahtsust	doc_491521501866_item	2531038	et	4	main
tegevrrsessr4yrrgi	doc_491521501866_item	2531046	et	4	main
mis	doc_491521501866_item	2531066	et	4	main
taiesti	doc_491521501866_item	2531076	et	4	main
oppimise	doc_491521501866_item	2531085	et	4	main
ehk	doc_491521501866_item	2531093	et	3	main
emakeele	doc_491521501866_item	2531094	et	4	main
hakkab	doc_491521501866_item	2531100	et	3	main
ta	doc_491521501866_item	2531108	et	4	main
kannab	doc_491521501866_item	2531113	et	3	main
kehtivad	doc_491521501866_item	2531115	et	4	main
sihtlkeelde	doc_491521501866_item	2531117	et	4	main
we	doc_491521501866_item	2531118	et	4	main
kasutab	doc_491521501866_item	2531119	et	3	main
palju	doc_491521501866_item	2531120	et	4	main
otsetolget	doc_491521501866_item	2531121	et	4	main
arvesta	doc_491521501866_item	2531123	et	4	main
tulenevad	doc_491521501866_item	2531127	et	4	main
kasutamine	doc_491521501866_item	2531134	et	4	main
ja	doc_491521501866_item	2531143	et	3	main
ja	doc_491521501866_item	2531145	et	3	main
voorkeele	doc_491521501866_item	2531157	et	4	main
millele	doc_491521501866_item	2531161	et	3	main
on	doc_491521501866_item	2531184	et	4	main
voorkeele	doc_491521501866_item	2531185	et	4	main
roll	doc_491521501866_item	2531189	et	3	main
peab	doc_491521501866_item	2531197	et	4	main
opilaste	doc_491521501866_item	2531199	et	4	main
esinevate	doc_491521501866_item	2531203	et	4	main
kui	doc_491521501866_item	2531205	et	3	main
et	doc_491521501866_item	2531209	et	3	main
opilastel	doc_491521501866_item	2531210	et	4	main
mis	doc_491521501866_item	2531058	et	4	main
talle	doc_491521501866_item	2531068	et	4	main
meelde	doc_491521501866_item	2531069	et	3	main
hoolimata	doc_491521501866_item	2531070	et	4	main
sellest	doc_491521501866_item	2531071	et	4	main
et	doc_491521501866_item	2531072	et	3	main
on	doc_491521501866_item	2531075	et	4	main
kaesolev	doc_491521501866_item	2531079	et	4	main
voorkeele	doc_491521501866_item	2531084	et	4	main
algetapil	doc_491521501866_item	2531086	et	3	main
pohjustab	doc_491521501866_item	2531087	et	4	main
emakeele	doc_491521501866_item	2531091	et	4	main
antud	doc_491521501866_item	2531102	et	4	main
emakeelt	doc_491521501866_item	2531110	et	4	main
votta	doc_491521501866_item	2531112	et	4	main
emakeeles	doc_491521501866_item	2531114	et	4	main
voi	doc_491521501866_item	2531135	et	4	main
jdrjekord	doc_491521501866_item	2531140	et	4	main
raskusi	doc_491521501866_item	2531152	et	4	main
aga	doc_491521501866_item	2531153	et	3	main
sellised	doc_491521501866_item	2531156	et	4	main
kategooriad	doc_491521501866_item	2531158	et	3	main
ja	doc_491521501866_item	2531159	et	3	main
moisted	doc_491521501866_item	2531160	et	4	main
valted	doc_491521501866_item	2531180	et	4	main
tappidega	doc_491521501866_item	2531181	et	3	main
tahed	doc_491521501866_item	2531182	et	4	main
vaga	doc_491521501866_item	2531187	et	4	main
just	doc_491521501866_item	2531190	et	3	main
ja	doc_491521501866_item	2531192	et	3	main
opitava	doc_491521501866_item	2531193	et	4	main
nii	doc_491521501866_item	2531201	et	3	main
selleks	doc_491521501866_item	2531208	et	4	main
siis	doc_491521501866_item	2531096	et	3	main
kui	doc_491521501866_item	2531097	et	3	main
alles	doc_491521501866_item	2531099	et	3	main
eesti	doc_491521501866_item	2531104	et	4	main
oppima	doc_491521501866_item	2531106	et	4	main
oma	doc_491521501866_item	2531109	et	4	main
naiteks	doc_491521501866_item	2531136	et	4	main
stiililt	doc_491521501866_item	2531146	et	3	main
ebakorrektsed	doc_491521501866_item	2531147	et	3	main
laused	doc_491521501866_item	2531148	et	3	main
seetottu	doc_491521501866_item	2531183	et	4	main
oppimisel	doc_491521501866_item	2531186	et	4	main
juhtima	doc_491521501866_item	2531198	et	4	main
keeltes	doc_491521501866_item	2531202	et	3	main
ka	doc_491521501866_item	2531206	et	3	main
ei	doc_491521501866_item	2531122	et	4	main
sihtkeele	doc_491521501866_item	2531124	et	4	main
eriparasustega	doc_491521501866_item	2531125	et	3	main
siit	doc_491521501866_item	2531126	et	3	main
verbirektsiooni	doc_491521501866_item	2531133	et	4	main
vale	doc_491521501866_item	2531139	et	4	main
rohkem	doc_491521501866_item	2531151	et	4	main
oppijale	doc_491521501866_item	2531155	et	4	main
ei	doc_491521501866_item	2531162	et	4	main
ole	doc_491521501866_item	2531163	et	4	main
vastet	doc_491521501866_item	2531164	et	3	main
tema	doc_491521501866_item	2531165	et	4	main
emakeeles	doc_491521501866_item	2531166	et	4	main
eesti	doc_491521501866_item	2531167	et	4	main
keele	doc_491521501866_item	2531168	et	4	main
puhul	doc_491521501866_item	2531169	et	4	main
on	doc_491521501866_item	2531170	et	4	main
need	doc_491521501866_item	2531171	et	3	main
naiteks	doc_491521501866_item	2531172	et	4	main
ma-	doc_491521501866_item	2531173	et	3	main
ja	doc_491521501866_item	2531174	et	3	main
da-infmitiiv	doc_491521501866_item	2531175	et	4	main
sise-	doc_491521501866_item	2531176	et	4	main
ja	doc_491521501866_item	2531177	et	3	main
valiskohakaanded	doc_491521501866_item	2531178	et	4	main
tahtis	doc_491521501866_item	2531188	et	3	main
emakeele	doc_491521501866_item	2531191	et	4	main
keele	doc_491521501866_item	2531194	et	4	main
vordlemisel	doc_491521501866_item	2531195	et	4	main
oppimisstrateegia	doc_491521501866_item	2531213	et	4	main
oige	doc_491521501866_item	2531212	et	3	main
eesti	doc_491521501870_item	2535508	et	4	main
antud	doc_491521501870_item	2535500	et	4	main
vigade	doc_491521501870_item	2535502	et	3	main
õpilaste	doc_491521501870_item	2535514	et	4	main
harjutuste	doc_491521501870_item	2535520	et	4	main
kontrolltööde	doc_491521501870_item	2535521	et	3	main
töö	doc_491521501870_item	2535501	et	4	main
analüüsist	doc_491521501870_item	2535503	et	3	main
on	doc_491521501870_item	2535504	et	4	main
antud	doc_491521501870_item	2535515	et	4	main
talvesemestri	doc_491521501870_item	2535516	et	3	main
eperekonnanimi	doc_491521501870_item	2535499	et	4	main
pühendatud	doc_491521501870_item	2535505	et	4	main
on	doc_491521501870_item	2535512	et	4	main
tööde	doc_491521501870_item	2535518	et	3	main
jt	doc_491521501870_item	2535522	et	4	main
klassi	doc_491521501870_item	2535530	et	4	main
keele	doc_491521501870_item	2535532	et	4	main
väga	doc_491521501870_item	2535537	et	3	main
kaks	doc_491521501870_item	2535543	et	3	main
ülejaanud	doc_491521501870_item	2535547	et	4	main
isegi	doc_491521501870_item	2535551	et	4	main
verbide	doc_491521501870_item	2535562	et	3	main
objekti	doc_491521501870_item	2535565	et	4	main
kasutamisega	doc_491521501870_item	2535566	et	4	main
vahel	doc_491521501870_item	2535582	et	4	main
märkus	doc_491521501870_item	2535583	et	3	main
mõnede	doc_491521501870_item	2535584	et	3	main
näidete	doc_491521501870_item	2535585	et	3	main
puhul	doc_491521501870_item	2535586	et	4	main
juhul	doc_491521501870_item	2535587	et	3	main
kui	doc_491521501870_item	2535588	et	3	main
või	doc_491521501870_item	2535595	et	4	main
pelgulinna	doc_491521501870_item	2535617	et	4	main
võib	doc_491521501870_item	2535627	et	3	main
tunda	doc_491521501870_item	2535628	et	3	main
et	doc_491521501870_item	2535629	et	3	main
me	doc_491521501870_item	2535630	et	4	main
kasutame	doc_491521501870_item	2535631	et	3	main
i	doc_491521501870_item	2535632	et	4	main
j	doc_491521501870_item	2535633	et	4	main
on	doc_491521501870_item	2535639	et	4	main
asemel	doc_491521501870_item	2535652	et	4	main
on	doc_491521501870_item	2535657	et	4	main
hoopis	doc_491521501870_item	2535658	et	3	main
olla	doc_491521501870_item	2535662	et	3	main
sellest	doc_491521501870_item	2535665	et	4	main
et	doc_491521501870_item	2535666	et	3	main
tunda	doc_491521501870_item	2535670	et	3	main
me	doc_491521501870_item	2535672	et	4	main
ad	doc_491521501870_item	2535674	et	4	main
eesti	doc_491521501870_item	2535721	et	4	main
lauses	doc_491521501870_item	2535726	et	3	main
omastavas	doc_491521501870_item	2535729	et	4	main
täissihitiseks	doc_491521501870_item	2535737	et	3	main
vene	doc_491521501870_item	2535741	et	4	main
vormid	doc_491521501870_item	2535752	et	4	main
uus	doc_491521501870_item	2535756	et	3	main
ma	doc_491521501870_item	2535758	et	3	main
uus	doc_491521501870_item	2535760	et	3	main
suhteid	doc_491521501870_item	2535790	et	3	main
käänded	doc_491521501870_item	2535792	et	3	main
kuuluvad	doc_491521501870_item	2535796	et	4	main
illatiiv	doc_491521501870_item	2535797	et	3	main
seesutlev	doc_491521501870_item	2535802	et	4	main
elatiiv	doc_491521501870_item	2535803	et	3	main
e	doc_491521501870_item	2535811	et	4	main
vene	doc_491521501870_item	2535820	et	4	main
analüüs	doc_491521501870_item	2535495	et	3	main
kontrastiivlingvistika	doc_491521501870_item	2535496	et	4	main
veaanalüüsi	doc_491521501870_item	2535497	et	4	main
kadutöö	doc_491521501870_item	2535498	et	4	main
õpilaste	doc_491521501870_item	2535506	et	4	main
hälbiva	doc_491521501870_item	2535507	et	4	main
tehtud	doc_491521501870_item	2535513	et	4	main
kirjandite	doc_491521501870_item	2535519	et	3	main
tegemist	doc_491521501870_item	2535524	et	4	main
õpetaja	doc_491521501870_item	2535533	et	4	main
ainult	doc_491521501870_item	2535542	et	4	main
ainult	doc_491521501870_item	2535548	et	4	main
ja	doc_491521501870_item	2535550	et	3	main
kõige	doc_491521501870_item	2535573	et	4	main
vigade	doc_491521501870_item	2535575	et	3	main
keele	doc_491521501870_item	2535581	et	4	main
oli	doc_491521501870_item	2535590	et	3	main
klassile	doc_491521501870_item	2535592	et	3	main
kontrolltööga	doc_491521501870_item	2535594	et	3	main
esitatud	doc_491521501870_item	2535599	et	4	main
ka	doc_491521501870_item	2535600	et	3	main
arvu	doc_491521501870_item	2535606	et	4	main
õigekiri	doc_491521501870_item	2535608	et	3	main
vormid	doc_491521501870_item	2535612	et	4	main
pelgulinna	doc_491521501870_item	2535615	et	4	main
raioonis	doc_491521501870_item	2535616	et	4	main
võib	doc_491521501870_item	2535637	et	3	main
põhjustatud	doc_491521501870_item	2535640	et	4	main
et	doc_491521501870_item	2535642	et	3	main
põhjuseks	doc_491521501870_item	2535656	et	3	main
av	doc_491521501870_item	2535659	et	4	main
lasnamäil	doc_491521501870_item	2535660	et	4	main
puhul	doc_491521501870_item	2535668	et	4	main
kasutame	doc_491521501870_item	2535673	et	3	main
diivaneid	doc_491521501870_item	2535679	et	3	main
olla	doc_491521501870_item	2535681	et	3	main
võib	doc_491521501870_item	2535723	et	3	main
nimetavas	doc_491521501870_item	2535728	et	4	main
sihitis	doc_491521501870_item	2535736	et	3	main
osasihitiseks	doc_491521501870_item	2535739	et	3	main
on	doc_491521501870_item	2535754	et	4	main
ostsin	doc_491521501870_item	2535759	et	3	main
sisseütlev	doc_491521501870_item	2535799	et	4	main
seestutlev	doc_491521501870_item	2535805	et	4	main
ja	doc_491521501870_item	2535806	et	3	main
e	doc_491521501870_item	2535814	et	4	main
alalütlev	doc_491521501870_item	2535815	et	3	main
e	doc_491521501870_item	2535818	et	4	main
alaltütlev	doc_491521501870_item	2535819	et	4	main
raskemateks	doc_491521501870_item	2535845	et	4	main
rohkearvuliste	doc_491521501870_item	2535858	et	4	main
keele	doc_491521501870_item	2535867	et	4	main
keeles	doc_491521501870_item	2535874	et	4	main
ei	doc_491521501870_item	2535875	et	4	main
sse	doc_491521501870_item	2535881	et	4	main
lõpu	doc_491521501870_item	2535882	et	3	main
tuleb	doc_491521501870_item	2535891	et	3	main
lihtsalt	doc_491521501870_item	2535892	et	4	main
tegelikult	doc_491521501870_item	2535903	et	4	main
nad	doc_491521501870_item	2535904	et	3	main
võiksid	doc_491521501870_item	2535905	et	4	main
kuuluda	doc_491521501870_item	2535906	et	4	main
av	doc_491521501870_item	2535907	et	4	main
ja	doc_491521501870_item	2535908	et	3	main
eesti	doc_491521501870_item	2535913	et	4	main
ja	doc_491521501870_item	2535914	et	3	main
kunagi	doc_491521501870_item	2535922	et	3	main
tenninatiivi	doc_491521501870_item	2535925	et	4	main
puhul	doc_491521501870_item	2535928	et	4	main
ei	doc_491521501870_item	2535932	et	4	main
üldse	doc_491521501870_item	2535934	et	3	main
oli	doc_491521501870_item	2535947	et	3	main
on	doc_491521501870_item	2535955	et	4	main
olemas	doc_491521501870_item	2535956	et	4	main
so	doc_491521501870_item	2535961	et	4	main
oma	doc_491521501870_item	2535962	et	4	main
mitu	doc_491521501870_item	2535967	et	4	main
isikukood	doc_491521501870_item	2535970	et	4	main
ütle	doc_491521501870_item	2535973	et	4	main
moodustusvead	doc_491521501870_item	2535996	et	4	main
kasutamisel	doc_491521501870_item	2536001	et	4	main
keeles	doc_491521501870_item	2536007	et	4	main
on	doc_491521501870_item	2536008	et	4	main
2	doc_491521501870_item	2536009	et	2	main
keelt	doc_491521501870_item	2536023	et	4	main
keele	doc_491521501870_item	2535509	et	4	main
kasutamisele	doc_491521501870_item	2535510	et	4	main
analüüs	doc_491521501870_item	2535511	et	3	main
kirjalikke	doc_491521501870_item	2535517	et	3	main
9	doc_491521501870_item	2535526	et	2	main
selle	doc_491521501870_item	2535529	et	4	main
eesti	doc_491521501870_item	2535531	et	4	main
on	doc_491521501870_item	2535536	et	4	main
klass	doc_491521501870_item	2535539	et	3	main
kahed	doc_491521501870_item	2535552	et	3	main
rektsiooniga	doc_491521501870_item	2535563	et	3	main
öelda	doc_491521501870_item	2535571	et	4	main
harjutustega	doc_491521501870_item	2535596	et	4	main
on	doc_491521501870_item	2535597	et	4	main
näitavad	doc_491521501870_item	2535603	et	4	main
hälbivate	doc_491521501870_item	2535604	et	4	main
õpilaste	doc_491521501870_item	2535609	et	4	main
rajoonis	doc_491521501870_item	2535618	et	4	main
põhjal	doc_491521501870_item	2535523	et	4	main
klassi	doc_491521501870_item	2535527	et	4	main
sõnul	doc_491521501870_item	2535534	et	3	main
klassis	doc_491521501870_item	2535540	et	3	main
kolm-neli	doc_491521501870_item	2535545	et	3	main
kolmed	doc_491521501870_item	2535549	et	3	main
opilaste	doc_491521501870_item	2535554	et	4	main
selgus	doc_491521501870_item	2535556	et	4	main
kõige	doc_491521501870_item	2535557	et	4	main
rohkem	doc_491521501870_item	2535558	et	4	main
töödest	doc_491521501870_item	2535555	et	3	main
raskusi	doc_491521501870_item	2535559	et	4	main
on	doc_491521501870_item	2535560	et	4	main
nendel	doc_491521501870_item	2535561	et	4	main
on	doc_491521501870_item	2535525	et	4	main
õpilastega	doc_491521501870_item	2535528	et	4	main
see	doc_491521501870_item	2535535	et	3	main
nõrk	doc_491521501870_item	2535538	et	3	main
on	doc_491521501870_item	2535541	et	4	main
viit	doc_491521501870_item	2535544	et	4	main
nelja	doc_491521501870_item	2535546	et	4	main
nagu	doc_491521501870_item	2535553	et	3	main
sisekohakäänetega	doc_491521501870_item	2535564	et	3	main
et	doc_491521501870_item	2535572	et	3	main
on	doc_491521501870_item	2535577	et	4	main
silmapaistvad	doc_491521501870_item	2535578	et	3	main
erinevused	doc_491521501870_item	2535579	et	4	main
kahe	doc_491521501870_item	2535580	et	3	main
tegemist	doc_491521501870_item	2535589	et	4	main
sulgudes	doc_491521501870_item	2535598	et	4	main
vastuste	doc_491521501870_item	2535605	et	4	main
töödes	doc_491521501870_item	2535610	et	3	main
võib	doc_491521501870_item	2535619	et	3	main
olla	doc_491521501870_item	2535620	et	3	main
puhul	doc_491521501870_item	2535626	et	4	main
karbis	doc_491521501870_item	2535636	et	3	main
hääldamise	doc_491521501870_item	2535643	et	4	main
puhul	doc_491521501870_item	2535644	et	4	main
võib	doc_491521501870_item	2535645	et	3	main
tunda	doc_491521501870_item	2535646	et	3	main
et	doc_491521501870_item	2535647	et	3	main
kuid	doc_491521501870_item	2535653	et	4	main
võib	doc_491521501870_item	2535654	et	3	main
lasnamäelvõib	doc_491521501870_item	2535661	et	4	main
et	doc_491521501870_item	2535671	et	3	main
nurgadiivan	doc_491521501870_item	2535678	et	3	main
võib	doc_491521501870_item	2535680	et	3	main
siin	doc_491521501870_item	2535682	et	4	main
ning	doc_491521501870_item	2535567	et	3	main
verbivormide	doc_491521501870_item	2535568	et	4	main
movdustamisega	doc_491521501870_item	2535569	et	4	main
võib	doc_491521501870_item	2535570	et	3	main
sagedasemate	doc_491521501870_item	2535574	et	4	main
põhjuseks	doc_491521501870_item	2535576	et	3	main
kogu	doc_491521501870_item	2535591	et	4	main
esitatud	doc_491521501870_item	2535593	et	4	main
protsendid	doc_491521501870_item	2535601	et	3	main
mis	doc_491521501870_item	2535602	et	4	main
klassis	doc_491521501870_item	2535607	et	3	main
esinenud	doc_491521501870_item	2535611	et	4	main
õiged	doc_491521501870_item	2535613	et	3	main
vormid	doc_491521501870_item	2535614	et	4	main
on	doc_491521501870_item	2535621	et	4	main
sellest	doc_491521501870_item	2535623	et	4	main
et	doc_491521501870_item	2535624	et	3	main
olla	doc_491521501870_item	2535638	et	3	main
sellest	doc_491521501870_item	2535641	et	4	main
p	doc_491521501870_item	2535650	et	4	main
b	doc_491521501870_item	2535651	et	4	main
on	doc_491521501870_item	2535663	et	4	main
põhjustatud	doc_491521501870_item	2535664	et	4	main
võib	doc_491521501870_item	2535669	et	3	main
de	doc_491521501870_item	2535675	et	4	main
asemel	doc_491521501870_item	2535676	et	4	main
hoopis	doc_491521501870_item	2535684	et	3	main
sihitis	doc_491521501870_item	2535720	et	3	main
esitatud	doc_491521501870_item	2535725	et	4	main
eesti	doc_491521501870_item	2535733	et	4	main
nende	doc_491521501870_item	2535744	et	4	main
kasutuspiirid	doc_491521501870_item	2535745	et	3	main
esinenud	doc_491521501870_item	2535751	et	4	main
tahab	doc_491521501870_item	2535762	et	3	main
osta	doc_491521501870_item	2535763	et	4	main
uus	doc_491521501870_item	2535764	et	3	main
maja	doc_491521501870_item	2535765	et	4	main
ma	doc_491521501870_item	2535766	et	3	main
ostsin	doc_491521501870_item	2535767	et	3	main
uus	doc_491521501870_item	2535768	et	3	main
ruumilisi	doc_491521501870_item	2535789	et	4	main
innessiiv	doc_491521501870_item	2535800	et	4	main
valiskohakaaneteks	doc_491521501870_item	2535807	et	4	main
kuhu	doc_491521501870_item	2535808	et	3	main
kuuluvad	doc_491521501870_item	2535809	et	4	main
ja	doc_491521501870_item	2535816	et	3	main
nagu	doc_491521501870_item	2535830	et	3	main
näha	doc_491521501870_item	2535836	et	3	main
osutasid	doc_491521501870_item	2535846	et	4	main
sellised	doc_491521501870_item	2535847	et	4	main
merre	doc_491521501870_item	2535856	et	3	main
võivad	doc_491521501870_item	2535861	et	4	main
erinevused	doc_491521501870_item	2535863	et	4	main
ruumiliste	doc_491521501870_item	2535869	et	4	main
suhete	doc_491521501870_item	2535870	et	3	main
väljendamises	doc_491521501870_item	2535871	et	4	main
nii	doc_491521501870_item	2535872	et	3	main
illatiivi	doc_491521501870_item	2535878	et	4	main
meelde	doc_491521501870_item	2535893	et	3	main
elatiivi	doc_491521501870_item	2535897	et	4	main
palju	doc_491521501870_item	2535901	et	4	main
muud	doc_491521501870_item	2535911	et	4	main
peaaegu	doc_491521501870_item	2535921	et	3	main
kokku	doc_491521501870_item	2535923	et	3	main
pronoomenivead	doc_491521501870_item	2535929	et	4	main
oli	doc_491521501870_item	2535938	et	3	main
enesekohase	doc_491521501870_item	2535939	et	4	main
keeles	doc_491521501870_item	2535954	et	4	main
asesõna-	doc_491521501870_item	2535960	et	4	main
ütle	doc_491521501870_item	2535968	et	4	main
vead	doc_491521501870_item	2536004	et	4	main
kuna	doc_491521501870_item	2536005	et	3	main
ja	doc_491521501870_item	2536011	et	3	main
probleeme	doc_491521501870_item	2536021	et	3	main
eesti	doc_491521501870_item	2536034	et	4	main
keelde	doc_491521501870_item	2536035	et	4	main
on	doc_491521501870_item	2536043	et	4	main
vastava	doc_491521501870_item	2536054	et	4	main
alati	doc_491521501870_item	2536059	et	4	main
suhteliselt	doc_491521501870_item	2536061	et	4	main
viga	doc_491521501870_item	2536070	et	4	main
põhjustatud	doc_491521501870_item	2535622	et	4	main
hääldamise	doc_491521501870_item	2535625	et	4	main
asemel	doc_491521501870_item	2535634	et	4	main
karpis	doc_491521501870_item	2535635	et	4	main
me	doc_491521501870_item	2535648	et	4	main
kasutame	doc_491521501870_item	2535649	et	3	main
olla	doc_491521501870_item	2535655	et	3	main
hääldamise	doc_491521501870_item	2535667	et	4	main
vanituba	doc_491521501870_item	2535677	et	4	main
toimus	doc_491521501870_item	2535683	et	3	main
vene	doc_491521501870_item	2535685	et	4	main
keele	doc_491521501870_item	2535686	et	4	main
maju	doc_491521501870_item	2535687	et	3	main
astmevaheldus	doc_491521501870_item	2535688	et	4	main
av	doc_491521501870_item	2535689	et	4	main
on	doc_491521501870_item	2535690	et	4	main
üleüldse	doc_491521501870_item	2535691	et	3	main
eesti	doc_491521501870_item	2535692	et	4	main
keele	doc_491521501870_item	2535693	et	4	main
üla	doc_491521501870_item	2535694	et	4	main
raskemaid	doc_491521501870_item	2535695	et	4	main
teemasid	doc_491521501870_item	2535696	et	3	main
õpilaste	doc_491521501870_item	2535697	et	4	main
töödes	doc_491521501870_item	2535698	et	3	main
esinenud	doc_491521501870_item	2535699	et	4	main
vormid	doc_491521501870_item	2535700	et	4	main
õiged	doc_491521501870_item	2535701	et	3	main
vormid	doc_491521501870_item	2535702	et	4	main
hakkada	doc_491521501870_item	2535703	et	4	main
karpis	doc_491521501870_item	2535704	et	4	main
suhtleda	doc_491521501870_item	2535705	et	4	main
kolmekorruselines	doc_491521501870_item	2535706	et	4	main
majas	doc_491521501870_item	2535707	et	3	main
tütrast	doc_491521501870_item	2535708	et	4	main
kuldast	doc_491521501870_item	2535709	et	3	main
hakata	doc_491521501870_item	2535710	et	4	main
karbis	doc_491521501870_item	2535711	et	3	main
suhelda	doc_491521501870_item	2535712	et	4	main
kolmekorruselises	doc_491521501870_item	2535713	et	4	main
majas	doc_491521501870_item	2535714	et	3	main
tütrest	doc_491521501870_item	2535715	et	4	main
kullast	doc_491521501870_item	2535716	et	4	main
objektivead	doc_491521501870_item	2535717	et	4	main
objekt	doc_491521501870_item	2535718	et	3	main
e	doc_491521501870_item	2535719	et	4	main
keeles	doc_491521501870_item	2535722	et	4	main
keeles	doc_491521501870_item	2535734	et	4	main
jaguneb	doc_491521501870_item	2535735	et	3	main
ja	doc_491521501870_item	2535738	et	3	main
samuti	doc_491521501870_item	2535740	et	3	main
keeleski	doc_491521501870_item	2535742	et	4	main
kuid	doc_491521501870_item	2535743	et	4	main
õpilaste	doc_491521501870_item	2535749	et	4	main
töödes	doc_491521501870_item	2535750	et	3	main
korter	doc_491521501870_item	2535769	et	3	main
meil	doc_491521501870_item	2535770	et	4	main
on	doc_491521501870_item	2535771	et	4	main
kaks	doc_491521501870_item	2535772	et	3	main
vannitoa	doc_491521501870_item	2535773	et	3	main
seal	doc_491521501870_item	2535774	et	4	main
palju	doc_491521501870_item	2535776	et	4	main
on	doc_491521501870_item	2535775	et	4	main
mugavused	doc_491521501870_item	2535777	et	4	main
panime	doc_491521501870_item	2535778	et	3	main
uued	doc_491521501870_item	2535779	et	3	main
tapeet	doc_491521501870_item	2535780	et	3	main
kohakäänete	doc_491521501870_item	2535781	et	3	main
vead	doc_491521501870_item	2535782	et	4	main
eesti	doc_491521501870_item	2535783	et	4	main
sisekohakäänete	doc_491521501870_item	2535784	et	3	main
peamine	doc_491521501870_item	2535785	et	3	main
funktsioon	doc_491521501870_item	2535786	et	3	main
on	doc_491521501870_item	2535787	et	4	main
väljendada	doc_491521501870_item	2535788	et	3	main
olla	doc_491521501870_item	2535724	et	3	main
kas	doc_491521501870_item	2535727	et	3	main
või	doc_491521501870_item	2535730	et	4	main
osastavas	doc_491521501870_item	2535731	et	4	main
käändes	doc_491521501870_item	2535732	et	3	main
ei	doc_491521501870_item	2535746	et	4	main
lange	doc_491521501870_item	2535747	et	4	main
kokku	doc_491521501870_item	2535748	et	3	main
mul	doc_491521501870_item	2535753	et	3	main
vaja	doc_491521501870_item	2535755	et	4	main
mööbel	doc_491521501870_item	2535757	et	3	main
kirjutuslaud	doc_491521501870_item	2535761	et	4	main
jagunevad	doc_491521501870_item	2535793	et	4	main
sisekohakääneteks	doc_491521501870_item	2535794	et	3	main
kuhu	doc_491521501870_item	2535795	et	3	main
e	doc_491521501870_item	2535798	et	4	main
e	doc_491521501870_item	2535804	et	4	main
alaleütlev	doc_491521501870_item	2535812	et	4	main
adessiiv	doc_491521501870_item	2535813	et	3	main
keeles	doc_491521501870_item	2535821	et	4	main
õpilaste	doc_491521501870_item	2535831	et	4	main
toodud	doc_491521501870_item	2535833	et	4	main
on	doc_491521501870_item	2535835	et	4	main
eksitakse	doc_491521501870_item	2535837	et	4	main
kõige	doc_491521501870_item	2535838	et	4	main
lühikese	doc_491521501870_item	2535840	et	4	main
vette	doc_491521501870_item	2535855	et	3	main
vahel	doc_491521501870_item	2535868	et	4	main
ainult	doc_491521501870_item	2535880	et	4	main
väga	doc_491521501870_item	2535888	et	3	main
palju	doc_491521501870_item	2535889	et	4	main
vorme	doc_491521501870_item	2535890	et	3	main
innessiivi	doc_491521501870_item	2535895	et	4	main
hulka	doc_491521501870_item	2535910	et	4	main
abessiivi	doc_491521501870_item	2535927	et	4	main
esinevatest	doc_491521501870_item	2535937	et	4	main
see	doc_491521501870_item	2535946	et	3	main
neid	doc_491521501870_item	2535965	et	4	main
esinesid	doc_491521501870_item	2535997	et	4	main
tegumoe	doc_491521501870_item	2535999	et	3	main
vene	doc_491521501870_item	2536012	et	4	main
ainult	doc_491521501870_item	2536014	et	4	main
palju	doc_491521501870_item	2536020	et	4	main
mitte	doc_491521501870_item	2536024	et	3	main
inimestel	doc_491521501870_item	2536027	et	3	main
tõlkimise	doc_491521501870_item	2536029	et	4	main
kui	doc_491521501870_item	2536036	et	3	main
ka	doc_491521501870_item	2536037	et	3	main
suhtlemisel	doc_491521501870_item	2536038	et	4	main
õpilaste	doc_491521501870_item	2536039	et	4	main
töödes	doc_491521501870_item	2536040	et	3	main
kasutamisreegleid	doc_491521501870_item	2536056	et	3	main
ise	doc_491521501870_item	2536075	et	4	main
ei	doc_491521501870_item	2536080	et	4	main
suuda	doc_491521501870_item	2536081	et	4	main
tuleb	doc_491521501870_item	2536082	et	3	main
lilled	doc_491521501870_item	2536083	et	3	main
vead	doc_491521501870_item	2536091	et	4	main
teemasid	doc_491521501870_item	2536102	et	3	main
on	doc_491521501870_item	2536106	et	4	main
määrab	doc_491521501870_item	2536111	et	3	main
temaga	doc_491521501870_item	2536112	et	3	main
seotud	doc_491521501870_item	2536113	et	4	main
sõnade	doc_491521501870_item	2536114	et	3	main
vormi	doc_491521501870_item	2536115	et	4	main
paljude	doc_491521501870_item	2536116	et	3	main
eesti	doc_491521501870_item	2535791	et	4	main
e	doc_491521501870_item	2535801	et	4	main
alatiiv	doc_491521501870_item	2535810	et	4	main
ablatiiv	doc_491521501870_item	2535817	et	3	main
ruumiliste	doc_491521501870_item	2535822	et	4	main
suhete	doc_491521501870_item	2535823	et	3	main
väljendamiseks	doc_491521501870_item	2535824	et	4	main
töödest	doc_491521501870_item	2535832	et	3	main
kõige	doc_491521501870_item	2535844	et	4	main
nagu	doc_491521501870_item	2535849	et	3	main
uttu	doc_491521501870_item	2535850	et	3	main
parki	doc_491521501870_item	2535851	et	4	main
pessa	doc_491521501870_item	2535852	et	3	main
keelde	doc_491521501870_item	2535853	et	4	main
kinno	doc_491521501870_item	2535854	et	3	main
vigade	doc_491521501870_item	2535859	et	3	main
põhjuseks	doc_491521501870_item	2535860	et	3	main
olla	doc_491521501870_item	2535862	et	3	main
eesti	doc_491521501870_item	2535864	et	4	main
ja	doc_491521501870_item	2535865	et	3	main
vene	doc_491521501870_item	2535866	et	4	main
eesti	doc_491521501870_item	2535873	et	4	main
moodustamisel	doc_491521501870_item	2535879	et	4	main
juurde	doc_491521501870_item	2535885	et	4	main
nii	doc_491521501870_item	2535886	et	3	main
et	doc_491521501870_item	2535887	et	3	main
ja	doc_491521501870_item	2535896	et	3	main
oli	doc_491521501870_item	2535899	et	3	main
vigu	doc_491521501870_item	2535900	et	3	main
kasutatakse	doc_491521501870_item	2535825	et	3	main
kas	doc_491521501870_item	2535826	et	3	main
käänded	doc_491521501870_item	2535827	et	3	main
vastavate	doc_491521501870_item	2535828	et	4	main
eessõnadega	doc_491521501870_item	2535829	et	3	main
näidetest	doc_491521501870_item	2535834	et	3	main
rohkem	doc_491521501870_item	2535839	et	4	main
illatiivi	doc_491521501870_item	2535841	et	4	main
puhul	doc_491521501870_item	2535842	et	4	main
nii	doc_491521501870_item	2535843	et	3	main
sõnad	doc_491521501870_item	2535848	et	4	main
nii	doc_491521501870_item	2535857	et	3	main
saa	doc_491521501870_item	2535876	et	4	main
piirduda	doc_491521501870_item	2535877	et	3	main
lisamisega	doc_491521501870_item	2535883	et	4	main
sõna	doc_491521501870_item	2535884	et	4	main
jätta	doc_491521501870_item	2535894	et	3	main
puhul	doc_491521501870_item	2535898	et	4	main
vähem	doc_491521501870_item	2535902	et	4	main
ühildumisvigade	doc_491521501870_item	2535909	et	4	main
käändevead	doc_491521501870_item	2535912	et	4	main
vene	doc_491521501870_item	2535915	et	4	main
käänetetähendused	doc_491521501870_item	2535916	et	4	main
ja	doc_491521501870_item	2535917	et	3	main
kasutamisreeglid	doc_491521501870_item	2535918	et	3	main
ei	doc_491521501870_item	2535919	et	4	main
lange	doc_491521501870_item	2535920	et	4	main
va	doc_491521501870_item	2535924	et	3	main
pronoomenivigu	doc_491521501870_item	2535930	et	4	main
kõige	doc_491521501870_item	2535935	et	4	main
sagedasemad	doc_491521501870_item	2535936	et	4	main
asemel	doc_491521501870_item	2535943	et	4	main
võib	doc_491521501870_item	2535944	et	3	main
olla	doc_491521501870_item	2535945	et	3	main
vene	doc_491521501870_item	2535949	et	4	main
mõ	doc_491521501870_item	2535951	et	4	main
just	doc_491521501870_item	2535952	et	3	main
vene	doc_491521501870_item	2535963	et	4	main
on	doc_491521501870_item	2535966	et	4	main
oma	doc_491521501870_item	2535969	et	4	main
asemel	doc_491521501870_item	2535971	et	4	main
kirjutati	doc_491521501870_item	2535972	et	3	main
verbivormide	doc_491521501870_item	2535995	et	4	main
umbisikulise	doc_491521501870_item	2535998	et	4	main
ja-da-infinitiivi	doc_491521501870_item	2536000	et	4	main
verbivormide	doc_491521501870_item	2536002	et	4	main
valiku	doc_491521501870_item	2536003	et	3	main
infinitiivivormi	doc_491521501870_item	2536010	et	4	main
keeles	doc_491521501870_item	2536013	et	4	main
üks	doc_491521501870_item	2536015	et	3	main
väga	doc_491521501870_item	2536019	et	3	main
ja	doc_491521501870_item	2535926	et	3	main
peaaegu	doc_491521501870_item	2535931	et	3	main
esinenud	doc_491521501870_item	2535933	et	4	main
asesõna	doc_491521501870_item	2535940	et	4	main
sinu	doc_491521501870_item	2535941	et	3	main
oma	doc_491521501870_item	2535942	et	4	main
tingitud	doc_491521501870_item	2535948	et	4	main
keele	doc_491521501870_item	2535950	et	4	main
eesti	doc_491521501870_item	2535953	et	4	main
ainult	doc_491521501870_item	2535957	et	4	main
üks	doc_491521501870_item	2535958	et	3	main
enesekohane	doc_491521501870_item	2535959	et	4	main
keeles	doc_491521501870_item	2535964	et	4	main
sinu	doc_491521501870_item	2535974	et	3	main
isikukood	doc_491521501870_item	2535975	et	4	main
kuigi	doc_491521501870_item	2535976	et	3	main
ülesandeks	doc_491521501870_item	2535977	et	4	main
oli	doc_491521501870_item	2535978	et	3	main
tõlkida	doc_491521501870_item	2535979	et	3	main
vene	doc_491521501870_item	2535980	et	4	main
keelest	doc_491521501870_item	2535981	et	4	main
eesti	doc_491521501870_item	2535982	et	4	main
keelde	doc_491521501870_item	2535983	et	4	main
arvsõna	doc_491521501870_item	2535984	et	4	main
käänamine	doc_491521501870_item	2535985	et	4	main
ühildumisvead	doc_491521501870_item	2535986	et	4	main
arvan	doc_491521501870_item	2535987	et	3	main
et	doc_491521501870_item	2535988	et	3	main
nende	doc_491521501870_item	2535989	et	4	main
veade	doc_491521501870_item	2535990	et	4	main
põhjus	doc_491521501870_item	2535991	et	4	main
oli	doc_491521501870_item	2535992	et	3	main
õpilaste	doc_491521501870_item	2535993	et	4	main
hajameelsus	doc_491521501870_item	2535994	et	4	main
eesti	doc_491521501870_item	2536006	et	4	main
kutsub	doc_491521501870_item	2536016	et	3	main
see	doc_491521501870_item	2536017	et	3	main
esile	doc_491521501870_item	2536018	et	3	main
eesti	doc_491521501870_item	2536022	et	4	main
esinevad	doc_491521501870_item	2536041	et	4	main
vead	doc_491521501870_item	2536042	et	4	main
sellest	doc_491521501870_item	2536047	et	4	main
et	doc_491521501870_item	2536048	et	3	main
nad	doc_491521501870_item	2536049	et	3	main
pole	doc_491521501870_item	2536050	et	3	main
kuid	doc_491521501870_item	2536057	et	4	main
mitte	doc_491521501870_item	2536058	et	3	main
infinitiivi	doc_491521501870_item	2536065	et	4	main
valik	doc_491521501870_item	2536066	et	3	main
on	doc_491521501870_item	2536067	et	4	main
tehtud	doc_491521501870_item	2536068	et	4	main
õieti	doc_491521501870_item	2536069	et	3	main
vormimoodustuses	doc_491521501870_item	2536073	et	3	main
neid	doc_491521501870_item	2536077	et	4	main
mõteldu	doc_491521501870_item	2536079	et	4	main
täna	doc_491521501870_item	2536087	et	4	main
õnnidelda	doc_491521501870_item	2536088	et	4	main
olulisemaid	doc_491521501870_item	2536101	et	4	main
rektsioon	doc_491521501870_item	2536105	et	3	main
olukord	doc_491521501870_item	2536108	et	3	main
mil	doc_491521501870_item	2536109	et	4	main
verb	doc_491521501870_item	2536110	et	3	main
juures	doc_491521501870_item	2536118	et	4	main
meelde	doc_491521501870_item	2536122	et	3	main
unustati	doc_491521501870_item	2536130	et	3	main
veaanaliiusi	doc_491521501872_item	2536386	et	4	main
veaanaliiusi	doc_491521501872_item	2536400	et	4	main
juhendaja	doc_491521501872_item	2536402	et	4	main
ar	doc_491521501872_item	2536404	et	4	main
too	doc_491521501872_item	2536409	et	4	main
vahetusuliopilasena	doc_491521501872_item	2536427	et	4	main
loomulikus	doc_491521501872_item	2536440	et	4	main
keeleoskusest	doc_491521501872_item	2536458	et	4	main
emakeelena	doc_491521501870_item	2536025	et	3	main
rääkivatel	doc_491521501870_item	2536026	et	4	main
keelest	doc_491521501870_item	2536033	et	4	main
minu	doc_491521501870_item	2536045	et	3	main
arvates	doc_491521501870_item	2536046	et	4	main
nii	doc_491521501870_item	2536028	et	3	main
puhul	doc_491521501870_item	2536030	et	4	main
eriti	doc_491521501870_item	2536031	et	3	main
vene	doc_491521501870_item	2536032	et	4	main
tingitud	doc_491521501870_item	2536044	et	4	main
omandanud	doc_491521501870_item	2536053	et	4	main
esineb	doc_491521501870_item	2536060	et	3	main
palju	doc_491521501870_item	2536062	et	4	main
juhtumeid	doc_491521501870_item	2536063	et	3	main
mil	doc_491521501870_item	2536064	et	4	main
ma	doc_491521501870_item	2536076	et	3	main
kaasa	doc_491521501870_item	2536084	et	4	main
jt	doc_491521501870_item	2536089	et	4	main
siia	doc_491521501870_item	2536092	et	4	main
rektsioon	doc_491521501870_item	2536096	et	3	main
üks	doc_491521501870_item	2536098	et	3	main
raskemaid	doc_491521501870_item	2536099	et	4	main
ja	doc_491521501870_item	2536100	et	3	main
keeles	doc_491521501870_item	2536104	et	4	main
selline	doc_491521501870_item	2536107	et	4	main
sõnade	doc_491521501870_item	2536117	et	3	main
70	doc_491521501870_item	2536129	et	2	main
suuroja	doc_491521501872_item	2536397	et	4	main
prof	doc_491521501872_item	2536403	et	4	main
2001	doc_491521501872_item	2536407	et	2	main
kolmel	doc_491521501872_item	2536411	et	4	main
soomlane	doc_491521501872_item	2536421	et	3	main
kes	doc_491521501872_item	2536423	et	4	main
199697	doc_491521501872_item	2536425	et	2	main
eesti	doc_491521501872_item	2536428	et	4	main
eesti	doc_491521501872_item	2536431	et	4	main
omandas	doc_491521501872_item	2536433	et	3	main
ta	doc_491521501872_item	2536434	et	4	main
suheldes	doc_491521501872_item	2536435	et	3	main
seega	doc_491521501872_item	2536437	et	4	main
suhteliselt	doc_491521501872_item	2536448	et	4	main
kuid	doc_491521501872_item	2536450	et	4	main
see	doc_491521501872_item	2536451	et	3	main
esiteks	doc_491521501872_item	2536459	et	3	main
vajalikus	doc_491521501870_item	2536051	et	4	main
ulatuses	doc_491521501870_item	2536052	et	4	main
infinitiivi	doc_491521501870_item	2536055	et	4	main
nt	doc_491521501870_item	2536074	et	4	main
valja	doc_491521501870_item	2536078	et	3	main
sõnatasandi	doc_491521501870_item	2536090	et	3	main
kuuluvad	doc_491521501870_item	2536093	et	4	main
tõlkelaenud	doc_491521501870_item	2536094	et	3	main
rektsioon	doc_491521501870_item	2536095	et	3	main
on	doc_491521501870_item	2536097	et	4	main
rektsioon	doc_491521501870_item	2536120	et	3	main
jätma	doc_491521501870_item	2536123	et	3	main
süntaks	doc_491521501870_item	2536124	et	3	main
rohkem	doc_491521501870_item	2536126	et	4	main
vigu	doc_491521501870_item	2536127	et	3	main
ca	doc_491521501870_item	2536128	et	4	main
seisneb	doc_491521501870_item	2536071	et	3	main
vaid	doc_491521501870_item	2536072	et	3	main
võtada	doc_491521501870_item	2536085	et	4	main
tahan	doc_491521501870_item	2536086	et	3	main
eesti	doc_491521501870_item	2536103	et	4	main
peab	doc_491521501870_item	2536119	et	4	main
lihtsalt	doc_491521501870_item	2536121	et	4	main
kõige	doc_491521501870_item	2536125	et	4	main
koma	doc_491521501870_item	2536131	et	4	main
tallinna	doc_491521501872_item	2536388	et	4	main
eesti	doc_491521501872_item	2536391	et	4	main
keele	doc_491521501872_item	2536392	et	4	main
kui	doc_491521501872_item	2536393	et	3	main
voorkeele	doc_491521501872_item	2536394	et	4	main
oppetool	doc_491521501872_item	2536395	et	4	main
kontrastiivlingvistika	doc_491521501872_item	2536399	et	4	main
hausenberg	doc_491521501872_item	2536405	et	4	main
saadetud	doc_491521501872_item	2536414	et	4	main
kirjal	doc_491521501872_item	2536415	et	3	main
need	doc_491521501872_item	2536416	et	3	main
oli	doc_491521501872_item	2536426	et	3	main
kunstiakadeemia	doc_491521501872_item	2536429	et	4	main
on	doc_491521501872_item	2536438	et	4	main
see	doc_491521501872_item	2536439	et	3	main
konekeelsed	doc_491521501872_item	2536449	et	4	main
ei	doc_491521501872_item	2536452	et	4	main
pruugi	doc_491521501872_item	2536453	et	4	main
ainult	doc_491521501872_item	2536456	et	4	main
oma	doc_491521501872_item	2536464	et	4	main
tuttavale	doc_491521501872_item	2536466	et	4	main
ja	doc_491521501872_item	2536467	et	3	main
teiseks	doc_491521501872_item	2536468	et	4	main
e-kirjadega	doc_491521501872_item	2536472	et	3	main
t	doc_491521501872_item	2536506	et	4	main
probleemiks	doc_491521501872_item	2536513	et	4	main
need	doc_491521501872_item	2536519	et	3	main
kirjutas	doc_491521501872_item	2536521	et	3	main
o	doc_491521501872_item	2536524	et	4	main
kasutamist	doc_491521501872_item	2536525	et	4	main
kodutoo	doc_491521501872_item	2536387	et	4	main
pedagoogikaiilikool	doc_491521501872_item	2536389	et	4	main
filoloogiateaduskond	doc_491521501872_item	2536390	et	3	main
ev-51	doc_491521501872_item	2536398	et	4	main
kodutoo	doc_491521501872_item	2536401	et	4	main
tallinn	doc_491521501872_item	2536406	et	4	main
pohineb	doc_491521501872_item	2536410	et	4	main
e-posti	doc_491521501872_item	2536412	et	4	main
teel	doc_491521501872_item	2536413	et	4	main
27-aastane	doc_491521501872_item	2536420	et	4	main
maret	doc_491521501872_item	2536396	et	4	main
kaesolev	doc_491521501872_item	2536408	et	4	main
kirjad	doc_491521501872_item	2536417	et	4	main
on	doc_491521501872_item	2536418	et	4	main
kirjutanud	doc_491521501872_item	2536419	et	4	main
tuukka	doc_491521501872_item	2536422	et	4	main
oppeaastal	doc_491521501872_item	2536424	et	4	main
opitud	doc_491521501872_item	2536442	et	4	main
keel	doc_491521501872_item	2536444	et	4	main
on	doc_491521501872_item	2536447	et	4	main
olla	doc_491521501872_item	2536454	et	3	main
tuukka	doc_491521501872_item	2536457	et	4	main
on	doc_491521501872_item	2536460	et	4	main
ta	doc_491521501872_item	2536461	et	4	main
tegemist	doc_491521501872_item	2536469	et	4	main
neid	doc_491521501872_item	2536507	et	4	main
kasutada	doc_491521501872_item	2536508	et	3	main
et	doc_491521501872_item	2536515	et	3	main
millega	doc_491521501872_item	2536517	et	3	main
voimaldanud	doc_491521501872_item	2536523	et	4	main
seda	doc_491521501872_item	2536535	et	3	main
t-1	doc_491521501872_item	2536539	et	4	main
on	doc_491521501872_item	2536540	et	4	main
kull	doc_491521501872_item	2536541	et	3	main
kirjades	doc_491521501872_item	2536542	et	3	main
hulganisti	doc_491521501872_item	2536543	et	3	main
hakkaks	doc_491521501872_item	2536549	et	3	main
siin	doc_491521501872_item	2536552	et	4	main
arvan	doc_491521501872_item	2536565	et	3	main
ka	doc_491521501872_item	2536574	et	3	main
vigade	doc_491521501872_item	2536580	et	3	main
on	doc_491521501872_item	2536582	et	4	main
raske	doc_491521501872_item	2536584	et	4	main
otsustada	doc_491521501872_item	2536585	et	3	main
kas	doc_491521501872_item	2536586	et	3	main
tegemist	doc_491521501872_item	2536587	et	4	main
voi	doc_491521501872_item	2536592	et	4	main
teab	doc_491521501872_item	2536622	et	3	main
loeksin	doc_491521501872_item	2536628	et	3	main
ka	doc_491521501872_item	2536636	et	3	main
klusiilidega	doc_491521501872_item	2536640	et	3	main
ilmuttamisele	doc_491521501872_item	2536644	et	4	main
emakeele	doc_491521501872_item	2536657	et	4	main
vigade	doc_491521501872_item	2536663	et	3	main
ka	doc_491521501872_item	2536667	et	3	main
pohjusi	doc_491521501872_item	2536669	et	4	main
olla	doc_491521501872_item	2536674	et	3	main
asti	doc_491521501872_item	2536679	et	4	main
vormimoodustus	doc_491521501872_item	2536683	et	3	main
kuhu	doc_491521501872_item	2536686	et	3	main
paris	doc_491521501872_item	2536690	et	3	main
moju	doc_491521501872_item	2536695	et	4	main
kirjapilti	doc_491521501872_item	2536707	et	4	main
panna	doc_491521501872_item	2536711	et	4	main
teeks	doc_491521501872_item	2536716	et	4	main
monigi	doc_491521501872_item	2536720	et	4	main
segaseks	doc_491521501872_item	2536722	et	4	main
juures	doc_491521501872_item	2536729	et	4	main
kas	doc_491521501872_item	2536730	et	3	main
t	doc_491521501872_item	2536731	et	4	main
markinud	doc_491521501872_item	2536748	et	4	main
vaib	doc_491521501872_item	2536763	et	4	main
on	doc_491521501872_item	2536783	et	4	main
oigesti	doc_491521501872_item	2536785	et	4	main
kasutatud	doc_491521501872_item	2536786	et	4	main
vaibad	doc_491521501872_item	2536787	et	3	main
vaipczde	doc_491521501872_item	2536788	et	4	main
kord	doc_491521501872_item	2536792	et	4	main
kin	doc_491521501872_item	2536793	et	4	main
arvan	doc_491521501872_item	2536796	et	3	main
ka	doc_491521501872_item	2536803	et	3	main
oppinud	doc_491521501872_item	2536807	et	4	main
ja	doc_491521501872_item	2536809	et	3	main
sellised	doc_491521501872_item	2536810	et	4	main
tudengiks	doc_491521501872_item	2536430	et	3	main
keele	doc_491521501872_item	2536432	et	4	main
kaasuliopilastega	doc_491521501872_item	2536436	et	4	main
keelekeskkonnas	doc_491521501872_item	2536441	et	3	main
eesti	doc_491521501872_item	2536443	et	4	main
need	doc_491521501872_item	2536445	et	3	main
kirjad	doc_491521501872_item	2536446	et	4	main
tingitud	doc_491521501872_item	2536455	et	4	main
kirjutanud	doc_491521501872_item	2536462	et	4	main
need	doc_491521501872_item	2536463	et	3	main
on	doc_491521501872_item	2536470	et	4	main
siiski	doc_491521501872_item	2536471	et	4	main
suhtlemise	doc_491521501872_item	2536475	et	4	main
puhul	doc_491521501872_item	2536476	et	4	main
kasutatav	doc_491521501872_item	2536477	et	4	main
keel	doc_491521501872_item	2536478	et	4	main
lahenebki	doc_491521501872_item	2536479	et	3	main
konekeelele	doc_491521501872_item	2536480	et	4	main
koik	doc_491521501872_item	2536481	et	4	main
kolm	doc_491521501872_item	2536482	et	3	main
kirja	doc_491521501872_item	2536483	et	4	main
on	doc_491521501872_item	2536484	et	4	main
ara	doc_491521501872_item	2536485	et	3	main
toodud	doc_491521501872_item	2536486	et	4	main
too	doc_491521501872_item	2536487	et	4	main
lopus	doc_491521501872_item	2536488	et	4	main
l	doc_491521501872_item	2536489	et	4	main
haaldus	doc_491521501872_item	2536490	et	4	main
ja	doc_491521501872_item	2536491	et	3	main
oigekiri	doc_491521501872_item	2536492	et	4	main
o-kasutamine	doc_491521501872_item	2536493	et	4	main
kuigi	doc_491521501872_item	2536494	et	3	main
kirjades	doc_491521501872_item	2536495	et	3	main
1	doc_491521501872_item	2536496	et	2	main
ja	doc_491521501872_item	2536497	et	3	main
3	doc_491521501872_item	2536498	et	2	main
puuduvad	doc_491521501872_item	2536499	et	4	main
heale	doc_491521501872_item	2536465	et	3	main
kus	doc_491521501872_item	2536473	et	3	main
o	doc_491521501872_item	2536501	et	4	main
ei	doc_491521501872_item	2536509	et	4	main
oska	doc_491521501872_item	2536510	et	4	main
arvatavasti	doc_491521501872_item	2536511	et	3	main
oli	doc_491521501872_item	2536512	et	3	main
kirjad	doc_491521501872_item	2536520	et	4	main
ei	doc_491521501872_item	2536522	et	4	main
o-d	doc_491521501872_item	2536532	et	4	main
kuid	doc_491521501872_item	2536546	et	4	main
ma	doc_491521501872_item	2536547	et	3	main
kuna	doc_491521501872_item	2536555	et	3	main
klusiilide	doc_491521501872_item	2536561	et	3	main
oi	doc_491521501872_item	2536562	et	3	main
kiri	doc_491521501872_item	2536564	et	3	main
et	doc_491521501872_item	2536566	et	3	main
nende	doc_491521501872_item	2536579	et	4	main
puhul	doc_491521501872_item	2536581	et	4	main
naiteks	doc_491521501872_item	2536595	et	4	main
kirjas	doc_491521501872_item	2536599	et	4	main
verbi	doc_491521501872_item	2536625	et	4	main
vead	doc_491521501872_item	2536630	et	4	main
on	doc_491521501872_item	2536634	et	4	main
nt	doc_491521501872_item	2536641	et	4	main
tutavatele	doc_491521501872_item	2536643	et	4	main
jattuksjdttan	doc_491521501872_item	2536648	et	4	main
tingitud	doc_491521501872_item	2536659	et	4	main
julgen	doc_491521501872_item	2536665	et	3	main
muid	doc_491521501872_item	2536668	et	4	main
naiteks	doc_491521501872_item	2536670	et	4	main
pohjuseks	doc_491521501872_item	2536675	et	4	main
sm	doc_491521501872_item	2536677	et	4	main
loppuun	doc_491521501872_item	2536678	et	4	main
loppuni	doc_491521501872_item	2536687	et	4	main
soome	doc_491521501872_item	2536693	et	3	main
sona	doc_491521501872_item	2536696	et	4	main
teades	doc_491521501872_item	2536699	et	4	main
eesti	doc_491521501872_item	2536702	et	4	main
sellist	doc_491521501872_item	2536706	et	4	main
pahaks	doc_491521501872_item	2536710	et	4	main
et	doc_491521501872_item	2536714	et	3	main
ka	doc_491521501872_item	2536718	et	3	main
eestlane	doc_491521501872_item	2536721	et	3	main
kusgilt	doc_491521501872_item	2536728	et	4	main
kusagilt	doc_491521501872_item	2536735	et	3	main
ja	doc_491521501872_item	2536736	et	3	main
tegemist	doc_491521501872_item	2536737	et	4	main
ta	doc_491521501872_item	2536742	et	4	main
siiski	doc_491521501872_item	2536743	et	4	main
ka	doc_491521501872_item	2536751	et	3	main
on	doc_491521501872_item	2536754	et	4	main
1	doc_491521501872_item	2536762	et	2	main
kiri	doc_491521501872_item	2536765	et	3	main
kiri	doc_491521501872_item	2536789	et	3	main
enamuses	doc_491521501872_item	2536802	et	4	main
voivad	doc_491521501872_item	2536812	et	4	main
oigeid	doc_491521501872_item	2536816	et	3	main
teades	doc_491521501872_item	2536818	et	4	main
leidsin	doc_491521501872_item	2536824	et	3	main
piisavalt	doc_491521501872_item	2536831	et	4	main
kiri	doc_491521501872_item	2536832	et	3	main
nditus	doc_491521501872_item	2536836	et	4	main
kiri	doc_491521501872_item	2536837	et	3	main
on	doc_491521501872_item	2536841	et	4	main
eesti	doc_491521501872_item	2536843	et	4	main
keele	doc_491521501872_item	2536844	et	4	main
ara	doc_491521501872_item	2536845	et	3	main
et	doc_491521501872_item	2536851	et	3	main
et	doc_491521501872_item	2536864	et	3	main
nt	doc_491521501872_item	2536868	et	4	main
loppuni	doc_491521501872_item	2536870	et	4	main
kiri	doc_491521501872_item	2536877	et	3	main
suntaks	doc_491521501872_item	2536880	et	4	main
t-1	doc_491521501872_item	2536885	et	4	main
ei	doc_491521501872_item	2536888	et	4	main
vead	doc_491521501872_item	2536892	et	4	main
markima	doc_491521501872_item	2536896	et	4	main
uczipade	doc_491521501872_item	2536899	et	4	main
informaalse	doc_491521501872_item	2536474	et	4	main
grafeemid	doc_491521501872_item	2536500	et	3	main
oelda	doc_491521501872_item	2536504	et	4	main
et	doc_491521501872_item	2536505	et	3	main
arvuti	doc_491521501872_item	2536516	et	4	main
ta	doc_491521501872_item	2536518	et	4	main
on	doc_491521501872_item	2536531	et	4	main
komasid	doc_491521501872_item	2536544	et	3	main
pikemalt	doc_491521501872_item	2536553	et	4	main
analuusima	doc_491521501872_item	2536554	et	4	main
adega	doc_491521501872_item	2536560	et	4	main
eg	doc_491521501872_item	2536563	et	4	main
soomlastest	doc_491521501872_item	2536568	et	3	main
see	doc_491521501872_item	2536570	et	3	main
teema	doc_491521501872_item	2536571	et	4	main
on	doc_491521501872_item	2536588	et	4	main
vigase	doc_491521501872_item	2536593	et	4	main
vormimoodustusega	doc_491521501872_item	2536594	et	3	main
on	doc_491521501872_item	2536598	et	4	main
seda	doc_491521501872_item	2536624	et	3	main
nii	doc_491521501872_item	2536627	et	3	main
pohjustatuteks	doc_491521501872_item	2536632	et	4	main
t-1	doc_491521501872_item	2536635	et	4	main
asuvate	doc_491521501872_item	2536639	et	4	main
printtimisele	doc_491521501872_item	2536645	et	4	main
oma	doc_491521501872_item	2536655	et	4	main
ebakindlusel	doc_491521501872_item	2536660	et	4	main
puhul	doc_491521501872_item	2536664	et	4	main
siin	doc_491521501872_item	2536672	et	4	main
vigane	doc_491521501872_item	2536682	et	4	main
loppu	doc_491521501872_item	2536685	et	4	main
kahtlane	doc_491521501872_item	2536691	et	3	main
printtimisele	doc_491521501872_item	2536697	et	4	main
kuidas	doc_491521501872_item	2536700	et	3	main
keeles	doc_491521501872_item	2536703	et	4	main
voib	doc_491521501872_item	2536712	et	4	main
nii	doc_491521501872_item	2536719	et	3	main
ei	doc_491521501872_item	2536502	et	4	main
saa	doc_491521501872_item	2536503	et	4	main
see	doc_491521501872_item	2536514	et	3	main
2	doc_491521501872_item	2536529	et	2	main
seal	doc_491521501872_item	2536530	et	4	main
kasutatud	doc_491521501872_item	2536533	et	4	main
puudu	doc_491521501872_item	2536545	et	4	main
ei	doc_491521501872_item	2536548	et	4	main
tegemist	doc_491521501872_item	2536556	et	4	main
enamusele	doc_491521501872_item	2536567	et	4	main
on	doc_491521501872_item	2536569	et	4	main
erand	doc_491521501872_item	2536578	et	3	main
siiski	doc_491521501872_item	2536583	et	4	main
moju	doc_491521501872_item	2536591	et	4	main
pildistama	doc_491521501872_item	2536597	et	3	main
1	doc_491521501872_item	2536600	et	2	main
mitu	doc_491521501872_item	2536601	et	4	main
piltistan	doc_491521501872_item	2536603	et	4	main
varianti	doc_491521501872_item	2536602	et	4	main
pildistamisele	doc_491521501872_item	2536604	et	4	main
pildisdama	doc_491521501872_item	2536605	et	4	main
ja	doc_491521501872_item	2536606	et	3	main
pildisdamiseks	doc_491521501872_item	2536607	et	4	main
kuigi	doc_491521501872_item	2536608	et	3	main
on	doc_491521501872_item	2536609	et	4	main
tehtud	doc_491521501872_item	2536610	et	4	main
mitu	doc_491521501872_item	2536611	et	4	main
viga	doc_491521501872_item	2536612	et	4	main
jaab	doc_491521501872_item	2536613	et	4	main
kirju	doc_491521501872_item	2536614	et	4	main
2	doc_491521501872_item	2536615	et	2	main
ja	doc_491521501872_item	2536616	et	3	main
3	doc_491521501872_item	2536617	et	2	main
lugedes	doc_491521501872_item	2536618	et	3	main
mlilje	doc_491521501872_item	2536619	et	4	main
et	doc_491521501872_item	2536620	et	3	main
seda	doc_491521501872_item	2536526	et	3	main
kinnitab	doc_491521501872_item	2536527	et	3	main
kiri	doc_491521501872_item	2536528	et	3	main
ja	doc_491521501872_item	2536534	et	3	main
taiesti	doc_491521501872_item	2536536	et	4	main
veatult	doc_491521501872_item	2536537	et	4	main
kiriavahemargid	doc_491521501872_item	2536538	et	4	main
nende	doc_491521501872_item	2536550	et	4	main
puudumist	doc_491521501872_item	2536551	et	4	main
on	doc_491521501872_item	2536557	et	4	main
mitteametlike	doc_491521501872_item	2536558	et	3	main
e-kirj	doc_491521501872_item	2536559	et	4	main
raske	doc_491521501872_item	2536572	et	4	main
ja	doc_491521501872_item	2536573	et	3	main
t	doc_491521501872_item	2536575	et	4	main
pole	doc_491521501872_item	2536576	et	3	main
mingi	doc_491521501872_item	2536577	et	4	main
lohakuse	doc_491521501872_item	2536589	et	4	main
emakeele	doc_491521501872_item	2536590	et	4	main
verbist	doc_491521501872_item	2536596	et	3	main
t	doc_491521501872_item	2536621	et	4	main
kasutatakse	doc_491521501872_item	2536626	et	3	main
hooletusest	doc_491521501872_item	2536631	et	4	main
raskusi	doc_491521501872_item	2536633	et	4	main
sona	doc_491521501872_item	2536637	et	4	main
loppuni	doc_491521501872_item	2536642	et	4	main
kiri	doc_491521501872_item	2536646	et	3	main
mojust	doc_491521501872_item	2536658	et	4	main
monede	doc_491521501872_item	2536662	et	4	main
loppuni	doc_491521501872_item	2536671	et	4	main
hoopis	doc_491521501872_item	2536681	et	3	main
kuhu	doc_491521501872_item	2536688	et	3	main
on	doc_491521501872_item	2536692	et	4	main
see	doc_491521501872_item	2536701	et	3	main
on	doc_491521501872_item	2536705	et	4	main
raske	doc_491521501872_item	2536709	et	4	main
siin	doc_491521501872_item	2536715	et	4	main
vea	doc_491521501872_item	2536717	et	4	main
jaab	doc_491521501872_item	2536723	et	4	main
vea	doc_491521501872_item	2536724	et	4	main
pohjus	doc_491521501872_item	2536725	et	4	main
on	doc_491521501872_item	2536738	et	4	main
hooletusveaga	doc_491521501872_item	2536739	et	4	main
moelnud	doc_491521501872_item	2536744	et	4	main
klusiili	doc_491521501872_item	2536749	et	4	main
sonalopuliste	doc_491521501872_item	2536752	et	4	main
nt	doc_491521501872_item	2536757	et	4	main
inti	doc_491521501872_item	2536759	et	4	main
kiri	doc_491521501872_item	2536761	et	3	main
ainuld	doc_491521501872_item	2536764	et	4	main
ka	doc_491521501872_item	2536784	et	3	main
ja	doc_491521501872_item	2536791	et	3	main
kokkuvotvalt	doc_491521501872_item	2536795	et	4	main
klusiilide	doc_491521501872_item	2536798	et	3	main
tekitab	doc_491521501872_item	2536800	et	3	main
ebakindlust	doc_491521501872_item	2536801	et	4	main
keele	doc_491521501872_item	2536805	et	4	main
ka	doc_491521501872_item	2536815	et	3	main
vigu	doc_491521501872_item	2536823	et	3	main
klaasi	doc_491521501872_item	2536835	et	4	main
kuna	doc_491521501872_item	2536839	et	3	main
selliseid	doc_491521501872_item	2536852	et	4	main
on	doc_491521501872_item	2536866	et	4	main
hooletusvigadega	doc_491521501872_item	2536867	et	4	main
kiri	doc_491521501872_item	2536872	et	3	main
votmu	doc_491521501872_item	2536876	et	4	main
2	doc_491521501872_item	2536879	et	2	main
sonajarjega	doc_491521501872_item	2536884	et	4	main
suuremaid	doc_491521501872_item	2536886	et	4	main
moned	doc_491521501872_item	2536891	et	4	main
0aatun	doc_491521501872_item	2536921	et	4	main
2	doc_491521501872_item	2536928	et	2	main
kahjuks	doc_491521501872_item	2536932	et	4	main
pohjust	doc_491521501872_item	2536934	et	4	main
ei	doc_491521501872_item	2536950	et	4	main
ole	doc_491521501872_item	2536951	et	4	main
vormis	doc_491521501872_item	2536955	et	4	main
mida	doc_491521501872_item	2536957	et	4	main
lseenesest	doc_491521501872_item	2536962	et	4	main
ka	doc_491521501872_item	2536965	et	3	main
koik	doc_491521501872_item	2536974	et	4	main
on	doc_491521501872_item	2536980	et	4	main
kuidas	doc_491521501872_item	2536623	et	3	main
need	doc_491521501872_item	2536629	et	3	main
keskel	doc_491521501872_item	2536638	et	3	main
1	doc_491521501872_item	2536647	et	2	main
kusgilt	doc_491521501872_item	2536649	et	4	main
kiri	doc_491521501872_item	2536650	et	3	main
2	doc_491521501872_item	2536651	et	2	main
kindlasti	doc_491521501872_item	2536652	et	3	main
on	doc_491521501872_item	2536653	et	4	main
siin	doc_491521501872_item	2536654	et	4	main
roll	doc_491521501872_item	2536656	et	3	main
kuid	doc_491521501872_item	2536661	et	4	main
kahtlustada	doc_491521501872_item	2536666	et	3	main
voib	doc_491521501872_item	2536673	et	4	main
emakeel	doc_491521501872_item	2536676	et	4	main
voi	doc_491521501872_item	2536680	et	4	main
lopp	doc_491521501872_item	2536684	et	4	main
maani	doc_491521501872_item	2536689	et	3	main
keele	doc_491521501872_item	2536694	et	4	main
puhul	doc_491521501872_item	2536698	et	4	main
haaldub	doc_491521501872_item	2536704	et	4	main
valismaalasele	doc_491521501872_item	2536708	et	4	main
arvata	doc_491521501872_item	2536713	et	4	main
veel	doc_491521501872_item	2536726	et	4	main
on	doc_491521501872_item	2536732	et	4	main
voi	doc_491521501872_item	2536740	et	4	main
sona	doc_491521501872_item	2536745	et	4	main
valesti	doc_491521501872_item	2536750	et	3	main
t	doc_491521501872_item	2536755	et	4	main
2	doc_491521501872_item	2536790	et	2	main
2	doc_491521501872_item	2536794	et	2	main
oigekiri	doc_491521501872_item	2536799	et	4	main
vead	doc_491521501872_item	2536811	et	4	main
lipsata	doc_491521501872_item	2536814	et	4	main
ja	doc_491521501872_item	2536820	et	3	main
lahkukirjutamine	doc_491521501872_item	2536821	et	3	main
ja	doc_491521501872_item	2536834	et	3	main
t	doc_491521501872_item	2536840	et	4	main
oppinud	doc_491521501872_item	2536842	et	4	main
moistetav	doc_491521501872_item	2536850	et	4	main
muud	doc_491521501872_item	2536856	et	4	main
tegemist	doc_491521501872_item	2536865	et	4	main
1	doc_491521501872_item	2536873	et	2	main
kaas	doc_491521501872_item	2536875	et	3	main
2	doc_491521501872_item	2536878	et	2	main
sonaj-arg	doc_491521501872_item	2536883	et	3	main
probleeme	doc_491521501872_item	2536887	et	3	main
ole	doc_491521501872_item	2536889	et	4	main
siiski	doc_491521501872_item	2536894	et	4	main
1	doc_491521501872_item	2536898	et	2	main
meile	doc_491521501872_item	2536922	et	4	main
oska	doc_491521501872_item	2536931	et	4	main
muud	doc_491521501872_item	2536933	et	4	main
leida	doc_491521501872_item	2536935	et	3	main
kui	doc_491521501872_item	2536936	et	3	main
kuncz	doc_491521501872_item	2536941	et	4	main
1	doc_491521501872_item	2536947	et	2	main
oigekirjaviga	doc_491521501872_item	2536954	et	4	main
oige	doc_491521501872_item	2536967	et	3	main
tegema	doc_491521501872_item	2536971	et	3	main
kuid	doc_491521501872_item	2536972	et	4	main
sobi	doc_491521501872_item	2536978	et	4	main
kasutamisega	doc_491521501872_item	2536984	et	4	main
ja	doc_491521501872_item	2536993	et	3	main
pildistan	doc_491521501872_item	2536994	et	3	main
sinu	doc_491521501872_item	2536997	et	3	main
vaibad	doc_491521501872_item	2536998	et	3	main
siin	doc_491521501872_item	2537001	et	4	main
tunda	doc_491521501872_item	2537003	et	3	main
moju	doc_491521501872_item	2537006	et	4	main
2	doc_491521501872_item	2537021	et	2	main
voi	doc_491521501872_item	2537035	et	4	main
kaandevead	doc_491521501872_item	2537037	et	4	main
toost	doc_491521501872_item	2537039	et	3	main
mojuga	doc_491521501872_item	2537047	et	4	main
soome	doc_491521501872_item	2537051	et	3	main
on	doc_491521501872_item	2537053	et	4	main
puhkudel	doc_491521501872_item	2537055	et	3	main
seestutlev	doc_491521501872_item	2537056	et	4	main
2	doc_491521501872_item	2537071	et	2	main
anda	doc_491521501872_item	2537081	et	3	main
on	doc_491521501872_item	2537087	et	4	main
vuibast	doc_491521501872_item	2537090	et	4	main
kiri	doc_491521501872_item	2537095	et	3	main
maarsona	doc_491521501872_item	2536727	et	4	main
tahtnud	doc_491521501872_item	2536733	et	4	main
kirjutada	doc_491521501872_item	2536734	et	3	main
on	doc_491521501872_item	2536741	et	4	main
kuskilt	doc_491521501872_item	2536746	et	4	main
ja	doc_491521501872_item	2536747	et	3	main
klusiilidega	doc_491521501872_item	2536753	et	3	main
eksinud	doc_491521501872_item	2536756	et	4	main
pr	doc_491521501872_item	2536758	et	4	main
mille	doc_491521501872_item	2536760	et	3	main
2	doc_491521501872_item	2536766	et	2	main
ja	doc_491521501872_item	2536767	et	3	main
kiri	doc_491521501872_item	2536769	et	3	main
3	doc_491521501872_item	2536770	et	2	main
kort	doc_491521501872_item	2536768	et	4	main
nendest	doc_491521501872_item	2536771	et	4	main
vigadest	doc_491521501872_item	2536772	et	3	main
vaib	doc_491521501872_item	2536773	et	4	main
ja	doc_491521501872_item	2536774	et	3	main
kort	doc_491521501872_item	2536775	et	4	main
tunduvad	doc_491521501872_item	2536776	et	4	main
olevat	doc_491521501872_item	2536777	et	4	main
juhuslikku	doc_491521501872_item	2536778	et	4	main
laadi	doc_491521501872_item	2536779	et	4	main
sest	doc_491521501872_item	2536780	et	4	main
molemat	doc_491521501872_item	2536781	et	4	main
sona	doc_491521501872_item	2536782	et	4	main
et	doc_491521501872_item	2536797	et	3	main
eesti	doc_491521501872_item	2536804	et	4	main
grammatikat	doc_491521501872_item	2536806	et	3	main
soomlastes	doc_491521501872_item	2536808	et	3	main
sisse	doc_491521501872_item	2536813	et	4	main
pole	doc_491521501872_item	2536830	et	3	main
1	doc_491521501872_item	2536833	et	2	main
eestlastega	doc_491521501872_item	2536846	et	4	main
suheldes	doc_491521501872_item	2536847	et	3	main
vigu	doc_491521501872_item	2536853	et	3	main
tuleb	doc_491521501872_item	2536854	et	3	main
vigade	doc_491521501872_item	2536859	et	3	main
algust	doc_491521501872_item	2536869	et	4	main
ja	doc_491521501872_item	2536874	et	3	main
morfoloogia	doc_491521501872_item	2536882	et	4	main
kuid	doc_491521501872_item	2536890	et	4	main
pildisdamiseks	doc_491521501872_item	2536900	et	4	main
ohtul	doc_491521501872_item	2536925	et	4	main
ei	doc_491521501872_item	2536930	et	4	main
obiektivead	doc_491521501872_item	2536940	et	4	main
teinud	doc_491521501872_item	2536953	et	4	main
kaandevalikuga	doc_491521501872_item	2536961	et	4	main
omastav	doc_491521501872_item	2536966	et	4	main
pean	doc_491521501872_item	2536968	et	4	main
mille	doc_491521501872_item	2536969	et	3	main
kasitsi	doc_491521501872_item	2536970	et	4	main
t-1	doc_491521501872_item	2536981	et	4	main
probleeme	doc_491521501872_item	2536982	et	3	main
abimaarsonade	doc_491521501872_item	2536983	et	4	main
nuiid	doc_491521501872_item	2536986	et	4	main
panin	doc_491521501872_item	2536990	et	3	main
mojutanud	doc_491521501872_item	2537027	et	4	main
konekeel	doc_491521501872_item	2537028	et	4	main
uhendverb	doc_491521501872_item	2537029	et	4	main
kaasa	doc_491521501872_item	2537030	et	4	main
votma	doc_491521501872_item	2537031	et	4	main
eeldab	doc_491521501872_item	2537032	et	3	main
kusimusi	doc_491521501872_item	2537033	et	4	main
mida	doc_491521501872_item	2537036	et	4	main
too	doc_491521501872_item	2537038	et	4	main
diil	doc_491521501872_item	2537040	et	4	main
1	doc_491521501872_item	2537042	et	2	main
tegemist	doc_491521501872_item	2537043	et	4	main
tyo	doc_491521501872_item	2537049	et	4	main
keeles	doc_491521501872_item	2537058	et	4	main
mille	doc_491521501872_item	2537063	et	3	main
vea	doc_491521501872_item	2537065	et	4	main
valistab	doc_491521501872_item	2537067	et	4	main
et	doc_491521501872_item	2537075	et	3	main
kaks	doc_491521501872_item	2537084	et	3	main
eksitud	doc_491521501872_item	2537088	et	4	main
oleks	doc_491521501872_item	2537093	et	3	main
suure	doc_491521501872_item	2537097	et	3	main
tegemist	doc_491521501872_item	2537100	et	4	main
naite	doc_491521501872_item	2537123	et	3	main
eestlane	doc_491521501872_item	2537130	et	3	main
kiri	doc_491521501872_item	2537139	et	3	main
nagu	doc_491521501872_item	2537157	et	3	main
pole	doc_491521501872_item	2537159	et	3	main
olen	doc_491521501872_item	2537162	et	3	main
molemad	doc_491521501872_item	2537168	et	4	main
kiri	doc_491521501872_item	2537169	et	3	main
naited	doc_491521501872_item	2537180	et	4	main
leidsin	doc_491521501872_item	2537181	et	3	main
voimalikust	doc_491521501872_item	2537185	et	4	main
mojust	doc_491521501872_item	2537188	et	4	main
ka	doc_491521501872_item	2537197	et	3	main
nii	doc_491521501872_item	2537206	et	3	main
sonavead	doc_491521501872_item	2537221	et	4	main
kaks	doc_491521501872_item	2537223	et	3	main
mis	doc_491521501872_item	2537225	et	4	main
et	doc_491521501872_item	2537235	et	3	main
vea	doc_491521501872_item	2537238	et	4	main
pohjustanud	doc_491521501872_item	2537240	et	4	main
soomekeelne	doc_491521501872_item	2537241	et	3	main
sobiks	doc_491521501872_item	2537246	et	4	main
muide	doc_491521501872_item	2537248	et	3	main
et	doc_491521501872_item	2537256	et	3	main
ikkagi	doc_491521501872_item	2537259	et	4	main
kasutada	doc_491521501872_item	2537261	et	3	main
t-1	doc_491521501872_item	2537288	et	4	main
kiri	doc_491521501872_item	2537291	et	3	main
vorme	doc_491521501872_item	2536817	et	3	main
kokku-	doc_491521501872_item	2536819	et	3	main
selliseid	doc_491521501872_item	2536822	et	4	main
t-1	doc_491521501872_item	2536825	et	4	main
ainult	doc_491521501872_item	2536826	et	4	main
kaks	doc_491521501872_item	2536827	et	3	main
uagu	doc_491521501872_item	2536828	et	4	main
nii	doc_491521501872_item	2536829	et	3	main
3	doc_491521501872_item	2536838	et	2	main
on	doc_491521501872_item	2536848	et	4	main
taiesti	doc_491521501872_item	2536849	et	4	main
ette	doc_491521501872_item	2536855	et	4	main
oigekirjavead	doc_491521501872_item	2536857	et	4	main
monede	doc_491521501872_item	2536858	et	4	main
puhul	doc_491521501872_item	2536860	et	4	main
olen	doc_491521501872_item	2536861	et	3	main
upris	doc_491521501872_item	2536862	et	4	main
kindel	doc_491521501872_item	2536863	et	3	main
kasitse	doc_491521501872_item	2536871	et	3	main
ja	doc_491521501872_item	2536881	et	3	main
peaksin	doc_491521501872_item	2536893	et	4	main
ara	doc_491521501872_item	2536895	et	3	main
kiri	doc_491521501872_item	2536897	et	3	main
paevavalgus	doc_491521501872_item	2536901	et	4	main
oleks	doc_491521501872_item	2536902	et	3	main
hea	doc_491521501872_item	2536903	et	4	main
siin	doc_491521501872_item	2536904	et	4	main
kirjutajat	doc_491521501872_item	2536906	et	4	main
on	doc_491521501872_item	2536905	et	4	main
arvatavasti	doc_491521501872_item	2536907	et	3	main
mojutanud	doc_491521501872_item	2536908	et	4	main
emakeel	doc_491521501872_item	2536909	et	4	main
selliste	doc_491521501872_item	2536910	et	4	main
vigade	doc_491521501872_item	2536911	et	3	main
nagu	doc_491521501872_item	2536912	et	3	main
nii	doc_491521501872_item	2536913	et	3	main
et	doc_491521501872_item	2536914	et	3	main
umbes	doc_491521501872_item	2536915	et	4	main
20ndczl	doc_491521501872_item	2536916	et	4	main
tulen	doc_491521501872_item	2536917	et	3	main
kiri	doc_491521501872_item	2536918	et	3	main
3	doc_491521501872_item	2536919	et	2	main
ja	doc_491521501872_item	2536920	et	3	main
veel	doc_491521501872_item	2536923	et	4	main
tdncz	doc_491521501872_item	2536924	et	4	main
kiri	doc_491521501872_item	2536927	et	3	main
juures	doc_491521501872_item	2536929	et	4	main
ainult	doc_491521501872_item	2536937	et	4	main
konekeele	doc_491521501872_item	2536938	et	4	main
koige	doc_491521501872_item	2536943	et	4	main
kdsitse	doc_491521501872_item	2536944	et	4	main
kiri	doc_491521501872_item	2536946	et	3	main
koike	doc_491521501872_item	2536956	et	4	main
on	doc_491521501872_item	2536958	et	4	main
ta	doc_491521501872_item	2536959	et	4	main
on	doc_491521501872_item	2536963	et	4	main
sona	doc_491521501872_item	2536973	et	4	main
veel	doc_491521501872_item	2536979	et	4	main
ostsin	doc_491521501872_item	2536985	et	3	main
igaljuhul	doc_491521501872_item	2536987	et	3	main
kiri	doc_491521501872_item	2536991	et	3	main
ainuld	doc_491521501872_item	2536995	et	4	main
need	doc_491521501872_item	2536996	et	3	main
kiri	doc_491521501872_item	2536999	et	3	main
kindlasti	doc_491521501872_item	2536926	et	3	main
moju	doc_491521501872_item	2536939	et	4	main
pean	doc_491521501872_item	2536942	et	4	main
tegemcz	doc_491521501872_item	2536945	et	4	main
kui	doc_491521501872_item	2536948	et	3	main
t	doc_491521501872_item	2536949	et	4	main
siin	doc_491521501872_item	2536952	et	4	main
eksinud	doc_491521501872_item	2536960	et	4	main
ju	doc_491521501872_item	2536964	et	3	main
puhul	doc_491521501872_item	2536975	et	4	main
see	doc_491521501872_item	2536976	et	3	main
ei	doc_491521501872_item	2536977	et	4	main
jcz	doc_491521501872_item	2536989	et	4	main
on	doc_491521501872_item	2537002	et	4	main
eesti	doc_491521501872_item	2537007	et	4	main
keeles	doc_491521501872_item	2537008	et	4	main
selline	doc_491521501872_item	2537009	et	4	main
vorm	doc_491521501872_item	2537010	et	3	main
nouab	doc_491521501872_item	2537011	et	4	main
abimaarsona	doc_491521501872_item	2537012	et	4	main
ara	doc_491521501872_item	2537013	et	3	main
rektsioonivead	doc_491521501872_item	2537014	et	4	main
teaksin	doc_491521501872_item	2537015	et	3	main
mis	doc_491521501872_item	2537016	et	4	main
pean	doc_491521501872_item	2537017	et	4	main
kaas	doc_491521501872_item	2537018	et	3	main
votma	doc_491521501872_item	2537019	et	4	main
kiri	doc_491521501872_item	2537020	et	3	main
siin	doc_491521501872_item	2537022	et	4	main
t-d	doc_491521501872_item	2537024	et	4	main
arvatavasti	doc_491521501872_item	2537025	et	3	main
jallegi	doc_491521501872_item	2537026	et	4	main
on	doc_491521501872_item	2537044	et	4	main
arvatavasti	doc_491521501872_item	2537045	et	3	main
emakeele	doc_491521501872_item	2537046	et	4	main
tyosta	doc_491521501872_item	2537050	et	4	main
keeles	doc_491521501872_item	2537052	et	4	main
sellistel	doc_491521501872_item	2537054	et	4	main
aga	doc_491521501872_item	2537059	et	3	main
omastav	doc_491521501872_item	2537060	et	4	main
kaassona	doc_491521501872_item	2537061	et	4	main
eest	doc_491521501872_item	2537064	et	4	main
juhuslikkuse	doc_491521501872_item	2537066	et	4	main
selle	doc_491521501872_item	2537068	et	4	main
kordumine	doc_491521501872_item	2537069	et	4	main
kni	doc_491521501872_item	2537072	et	4	main
vaib	doc_491521501872_item	2537076	et	4	main
sellest	doc_491521501872_item	2537078	et	4	main
palju	doc_491521501872_item	2537079	et	4	main
vastu	doc_491521501872_item	2537080	et	3	main
igas	doc_491521501872_item	2537089	et	3	main
1	doc_491521501872_item	2537096	et	2	main
moni	doc_491521501872_item	2537129	et	4	main
endale	doc_491521501872_item	2537138	et	4	main
1	doc_491521501872_item	2537140	et	2	main
ule	doc_491521501872_item	2537146	et	4	main
konstruktsiooniga	doc_491521501872_item	2537149	et	3	main
moned	doc_491521501872_item	2537152	et	4	main
konekeelest	doc_491521501872_item	2537154	et	4	main
kindlasti	doc_491521501872_item	2537156	et	3	main
kord	doc_491521501872_item	2537164	et	4	main
see	doc_491521501872_item	2537165	et	3	main
on	doc_491521501872_item	2537172	et	4	main
eestlaste	doc_491521501872_item	2537176	et	4	main
kasutatavad	doc_491521501872_item	2537178	et	4	main
konekeele	doc_491521501872_item	2537179	et	4	main
uhe	doc_491521501872_item	2537183	et	4	main
soome	doc_491521501872_item	2537186	et	3	main
filmi	doc_491521501872_item	2536988	et	4	main
2	doc_491521501872_item	2536992	et	2	main
soome	doc_491521501872_item	2537004	et	3	main
on	doc_491521501872_item	2537023	et	4	main
kiri	doc_491521501872_item	2537041	et	3	main
sm	doc_491521501872_item	2537048	et	4	main
eesti	doc_491521501872_item	2537057	et	4	main
eesl	doc_491521501872_item	2537062	et	4	main
kirjas	doc_491521501872_item	2537070	et	4	main
sidle	doc_491521501872_item	2537073	et	4	main
tundub	doc_491521501872_item	2537074	et	3	main
on	doc_491521501872_item	2537077	et	4	main
leidsin	doc_491521501872_item	2537083	et	3	main
kus	doc_491521501872_item	2537086	et	3	main
ja	doc_491521501872_item	2537091	et	3	main
kulzld	doc_491521501872_item	2537092	et	4	main
toenaosusega	doc_491521501872_item	2537098	et	4	main
siiski	doc_491521501872_item	2537121	et	4	main
mille	doc_491521501872_item	2537124	et	3	main
kas	doc_491521501872_item	2537128	et	3	main
niimoodi	doc_491521501872_item	2537132	et	3	main
siin	doc_491521501872_item	2537141	et	4	main
t	doc_491521501872_item	2537143	et	4	main
arvatavasti	doc_491521501872_item	2537144	et	3	main
jou	doc_491521501872_item	2537147	et	4	main
kaiva	doc_491521501872_item	2537148	et	4	main
veel	doc_491521501872_item	2537151	et	4	main
nii	doc_491521501872_item	2537158	et	3	main
eestis	doc_491521501872_item	2537167	et	3	main
1	doc_491521501872_item	2537170	et	2	main
juba	doc_491521501872_item	2537173	et	3	main
arvan	doc_491521501872_item	2537201	et	3	main
ei	doc_491521501872_item	2537209	et	4	main
on	doc_491521501872_item	2537227	et	4	main
mojutatud	doc_491521501872_item	2537228	et	4	main
soome	doc_491521501872_item	2537229	et	3	main
kiri	doc_491521501872_item	2537236	et	3	main
muuten	doc_491521501872_item	2537242	et	4	main
muidugi	doc_491521501872_item	2537250	et	4	main
taielikult	doc_491521501872_item	2537254	et	4	main
on	doc_491521501872_item	2537258	et	4	main
motlen	doc_491521501872_item	2537300	et	4	main
ma	doc_491521501872_item	2537303	et	3	main
ytleme	doc_491521501872_item	2537308	et	4	main
algust	doc_491521501872_item	2537310	et	4	main
loppuni	doc_491521501872_item	2537311	et	4	main
ja	doc_491521501872_item	2537312	et	3	main
igas	doc_491521501872_item	2537317	et	3	main
interjoorist	doc_491521501872_item	2537324	et	4	main
selle	doc_491521501872_item	2537326	et	4	main
ma	doc_491521501872_item	2537332	et	3	main
sellise	doc_491521501872_item	2537335	et	4	main
too	doc_491521501872_item	2537336	et	4	main
umbes	doc_491521501872_item	2537342	et	4	main
pean	doc_491521501872_item	2537359	et	4	main
mis	doc_491521501872_item	2537364	et	4	main
koht	doc_491521501872_item	2537369	et	3	main
peaks	doc_491521501872_item	2537372	et	4	main
pildisdama	doc_491521501872_item	2537373	et	4	main
ma	doc_491521501872_item	2537374	et	3	main
arvan	doc_491521501872_item	2537375	et	3	main
et	doc_491521501872_item	2537376	et	3	main
olen	doc_491521501872_item	2537377	et	3	main
nadalavahetus	doc_491521501872_item	2537381	et	4	main
ja	doc_491521501872_item	2537383	et	3	main
akki	doc_491521501872_item	2537386	et	4	main
kohe	doc_491521501872_item	2537387	et	4	main
ara	doc_491521501872_item	2537388	et	3	main
teha	doc_491521501872_item	2537389	et	3	main
vaipade	doc_491521501872_item	2537390	et	3	main
pildisdamiseks	doc_491521501872_item	2537391	et	4	main
nuud	doc_491521501872_item	2537422	et	4	main
koolist	doc_491521501872_item	2537428	et	4	main
kinni	doc_491521501872_item	2537430	et	3	main
homme	doc_491521501872_item	2537432	et	3	main
enam	doc_491521501872_item	2537434	et	4	main
ei	doc_491521501872_item	2537435	et	4	main
on	doc_491521501872_item	2537448	et	4	main
pean	doc_491521501872_item	2537451	et	4	main
votma	doc_491521501872_item	2537453	et	4	main
vaatan	doc_491521501872_item	2537454	et	3	main
meile	doc_491521501872_item	2537455	et	4	main
veel	doc_491521501872_item	2537456	et	4	main
2	doc_491521501872_item	2537000	et	2	main
keele	doc_491521501872_item	2537005	et	4	main
mille	doc_491521501872_item	2537034	et	3	main
uhildumisvead	doc_491521501872_item	2537082	et	4	main
naidet	doc_491521501872_item	2537085	et	4	main
molemad	doc_491521501872_item	2537094	et	4	main
on	doc_491521501872_item	2537099	et	4	main
hooletusvigadega	doc_491521501872_item	2537101	et	4	main
naite	doc_491521501872_item	2537103	et	3	main
puhul	doc_491521501872_item	2537104	et	4	main
voib	doc_491521501872_item	2537105	et	4	main
teise	doc_491521501872_item	2537102	et	4	main
muidugi	doc_491521501872_item	2537106	et	4	main
olla	doc_491521501872_item	2537107	et	3	main
tegemist	doc_491521501872_item	2537108	et	4	main
ka	doc_491521501872_item	2537109	et	3	main
konekeele	doc_491521501872_item	2537110	et	4	main
mojuga	doc_491521501872_item	2537111	et	4	main
3	doc_491521501872_item	2537112	et	2	main
sonatasand	doc_491521501872_item	2537113	et	4	main
stiilivead	doc_491521501872_item	2537114	et	3	main
kliigi	doc_491521501872_item	2537115	et	4	main
e-kirjades	doc_491521501872_item	2537116	et	3	main
kasutatakse	doc_491521501872_item	2537117	et	3	main
palju	doc_491521501872_item	2537118	et	4	main
leidsin	doc_491521501872_item	2537120	et	3	main
konekeelt	doc_491521501872_item	2537119	et	4	main
iihe	doc_491521501872_item	2537122	et	4	main
puhul	doc_491521501872_item	2537125	et	4	main
kahtlen	doc_491521501872_item	2537126	et	3	main
et	doc_491521501872_item	2537127	et	3	main
materiaali	doc_491521501872_item	2537134	et	4	main
mulle	doc_491521501872_item	2537137	et	4	main
moodustanud	doc_491521501872_item	2537145	et	4	main
interjooris	doc_491521501872_item	2537155	et	4	main
ja	doc_491521501872_item	2537161	et	3	main
jargmine	doc_491521501872_item	2537163	et	4	main
nadalavahetus	doc_491521501872_item	2537166	et	4	main
need	doc_491521501872_item	2537171	et	3	main
ka	doc_491521501872_item	2537175	et	3	main
ka	doc_491521501872_item	2537182	et	3	main
konekeele	doc_491521501872_item	2537187	et	4	main
pkevavalgus	doc_491521501872_item	2537189	et	4	main
hea	doc_491521501872_item	2537191	et	4	main
voimatu	doc_491521501872_item	2537193	et	4	main
et	doc_491521501872_item	2537202	et	3	main
eesti	doc_491521501872_item	2537204	et	4	main
luhikest	doc_491521501872_item	2537207	et	4	main
varianti	doc_491521501872_item	2537208	et	4	main
tundub	doc_491521501872_item	2537234	et	3	main
keeles	doc_491521501872_item	2537245	et	4	main
ei	doc_491521501872_item	2537252	et	4	main
saa	doc_491521501872_item	2537253	et	4	main
valistada	doc_491521501872_item	2537255	et	4	main
t	doc_491521501872_item	2537257	et	4	main
aga	doc_491521501872_item	2537264	et	3	main
ma	doc_491521501872_item	2537299	et	3	main
et	doc_491521501872_item	2537301	et	3	main
teie	doc_491521501872_item	2537305	et	4	main
ara	doc_491521501872_item	2537307	et	3	main
et	doc_491521501872_item	2537309	et	3	main
yhe	doc_491521501872_item	2537315	et	4	main
vaibast	doc_491521501872_item	2537318	et	4	main
oleks	doc_491521501872_item	2537131	et	3	main
kirjutanud	doc_491521501872_item	2537133	et	4	main
kulud	doc_491521501872_item	2537135	et	4	main
oleks	doc_491521501872_item	2537136	et	3	main
on	doc_491521501872_item	2537142	et	4	main
lause	doc_491521501872_item	2537150	et	4	main
naited	doc_491521501872_item	2537153	et	4	main
piisavalt	doc_491521501872_item	2537160	et	4	main
tavalised	doc_491521501872_item	2537174	et	4	main
poolt	doc_491521501872_item	2537177	et	4	main
naite	doc_491521501872_item	2537184	et	3	main
kui	doc_491521501872_item	2537192	et	3	main
siis	doc_491521501872_item	2537194	et	3	main
hakkama	doc_491521501872_item	2537198	et	3	main
1	doc_491521501872_item	2537200	et	2	main
kasutata	doc_491521501872_item	2537210	et	3	main
pigem	doc_491521501872_item	2537211	et	3	main
ikkagi	doc_491521501872_item	2537212	et	4	main
kui	doc_491521501872_item	2537213	et	3	main
see	doc_491521501872_item	2537214	et	3	main
on	doc_491521501872_item	2537215	et	4	main
voimatu	doc_491521501872_item	2537216	et	4	main
voi	doc_491521501872_item	2537217	et	4	main
kui	doc_491521501872_item	2537218	et	3	main
pole	doc_491521501872_item	2537219	et	3	main
voimalik	doc_491521501872_item	2537220	et	4	main
oleks	doc_491521501872_item	2537190	et	3	main
saub	doc_491521501872_item	2537195	et	4	main
ilma	doc_491521501872_item	2537196	et	4	main
kiri	doc_491521501872_item	2537199	et	3	main
isegi	doc_491521501872_item	2537203	et	4	main
konekeeles	doc_491521501872_item	2537205	et	4	main
viga	doc_491521501872_item	2537224	et	4	main
arvatavasti	doc_491521501872_item	2537226	et	3	main
keelest	doc_491521501872_item	2537230	et	4	main
muidu	doc_491521501872_item	2537231	et	3	main
kid	doc_491521501872_item	2537232	et	4	main
sulle	doc_491521501872_item	2537233	et	3	main
on	doc_491521501872_item	2537239	et	4	main
jos	doc_491521501872_item	2537243	et	4	main
voi	doc_491521501872_item	2537249	et	4	main
neist	doc_491521501872_item	2537263	et	4	main
teinud	doc_491521501872_item	2537266	et	4	main
konektselt	doc_491521501872_item	2537289	et	4	main
1	doc_491521501872_item	2537292	et	2	main
kuidas	doc_491521501872_item	2537294	et	3	main
piltistan	doc_491521501872_item	2537304	et	4	main
asjad	doc_491521501872_item	2537306	et	3	main
printi	doc_491521501872_item	2537316	et	4	main
naiteks	doc_491521501872_item	2537321	et	4	main
pilti	doc_491521501872_item	2537323	et	4	main
siis	doc_491521501872_item	2537325	et	3	main
vaiba	doc_491521501872_item	2537331	et	3	main
endale	doc_491521501872_item	2537341	et	4	main
fimi	doc_491521501872_item	2537344	et	4	main
laheks	doc_491521501872_item	2537347	et	4	main
ytleme	doc_491521501872_item	2537349	et	4	main
yks	doc_491521501872_item	2537350	et	4	main
tegema	doc_491521501872_item	2537362	et	3	main
jargmine	doc_491521501872_item	2537378	et	4	main
eestis	doc_491521501872_item	2537382	et	3	main
siis	doc_491521501872_item	2537385	et	3	main
joua	doc_491521501872_item	2537436	et	4	main
seda	doc_491521501872_item	2537437	et	3	main
kui	doc_491521501872_item	2537440	et	3	main
hea	doc_491521501872_item	2537444	et	4	main
teaksin	doc_491521501872_item	2537449	et	3	main
kaas	doc_491521501872_item	2537452	et	3	main
ja	doc_491521501872_item	2537460	et	3	main
loodan	doc_491521501872_item	2537461	et	3	main
et	doc_491521501872_item	2537462	et	3	main
veel	doc_491521501872_item	2537465	et	4	main
vaib	doc_491521501872_item	2537473	et	4	main
pildistan	doc_491521501872_item	2537485	et	3	main
sinu	doc_491521501872_item	2537488	et	3	main
on	doc_491521501872_item	2537522	et	4	main
seda	doc_491521501872_item	2537525	et	3	main
teha	doc_491521501872_item	2537529	et	3	main
kahe	doc_491521501872_item	2537543	et	3	main
katlini	doc_491521501872_item	2537549	et	4	main
naitus	doc_491521501872_item	2537551	et	4	main
see	doc_491521501872_item	2537554	et	3	main
siis	doc_491521501872_item	2537564	et	3	main
saaks	doc_491521501872_item	2537573	et	3	main
onju	doc_491521501872_item	2537578	et	4	main
tuukka	doc_491521501872_item	2537591	et	4	main
eestis	doc_491521501873_item	2537595	et	3	main
kirikutes	doc_491521501873_item	2537597	et	4	main
kui	doc_491521501873_item	2537622	et	3	main
siis	doc_491521501873_item	2537626	et	3	main
isegi	doc_491521501873_item	2537633	et	4	main
sõrmused	doc_491521501873_item	2537637	et	3	main
ateismi	doc_491521501873_item	2537641	et	4	main
ja	doc_491521501873_item	2537643	et	3	main
toimuma	doc_491521501873_item	2537645	et	3	main
varem	doc_491521501873_item	2537651	et	4	main
abielu	doc_491521501873_item	2537652	et	4	main
praegu	doc_491521501873_item	2537655	et	3	main
aga	doc_491521501873_item	2537656	et	3	main
abielu	doc_491521501873_item	2537657	et	4	main
lakkasid	doc_491521501873_item	2537663	et	4	main
leidsin	doc_491521501872_item	2537222	et	3	main
2	doc_491521501872_item	2537237	et	2	main
eesti	doc_491521501872_item	2537244	et	4	main
siia	doc_491521501872_item	2537247	et	4	main
loomulikult	doc_491521501872_item	2537251	et	4	main
moelnud	doc_491521501872_item	2537260	et	4	main
uhte	doc_491521501872_item	2537262	et	3	main
on	doc_491521501872_item	2537265	et	4	main
lihtsalt	doc_491521501872_item	2537267	et	4	main
hooletlisvea	doc_491521501872_item	2537268	et	4	main
viga	doc_491521501872_item	2537269	et	4	main
sonas	doc_491521501872_item	2537270	et	4	main
kiri	doc_491521501872_item	2537272	et	3	main
materiaali	doc_491521501872_item	2537271	et	4	main
1	doc_491521501872_item	2537273	et	2	main
oli	doc_491521501872_item	2537274	et	3	main
natuke	doc_491521501872_item	2537275	et	4	main
ullatav	doc_491521501872_item	2537276	et	4	main
sest	doc_491521501872_item	2537277	et	4	main
sona	doc_491521501872_item	2537278	et	4	main
interjoor	doc_491521501872_item	2537279	et	4	main
mis	doc_491521501872_item	2537280	et	4	main
on	doc_491521501872_item	2537281	et	4	main
samuti	doc_491521501872_item	2537282	et	3	main
sarnane	doc_491521501872_item	2537283	et	4	main
oma	doc_491521501872_item	2537284	et	4	main
soomekeelsele	doc_491521501872_item	2537285	et	3	main
vastele	doc_491521501872_item	2537286	et	3	main
on	doc_491521501872_item	2537287	et	4	main
kirjutatud	doc_491521501872_item	2537290	et	4	main
kuule	doc_491521501872_item	2537293	et	4	main
oleks	doc_491521501872_item	2537295	et	3	main
toost	doc_491521501872_item	2537297	et	3	main
annan	doc_491521501872_item	2537313	et	3	main
ja	doc_491521501872_item	2537319	et	3	main
saan	doc_491521501872_item	2537328	et	4	main
et	doc_491521501872_item	2537334	et	3	main
mulle	doc_491521501872_item	2537340	et	4	main
300	doc_491521501872_item	2537343	et	2	main
kasitse	doc_491521501872_item	2537361	et	3	main
ytle	doc_491521501872_item	2537363	et	4	main
arvad	doc_491521501872_item	2537365	et	3	main
ja	doc_491521501872_item	2537366	et	3	main
asub	doc_491521501872_item	2537370	et	3	main
kord	doc_491521501872_item	2537379	et	4	main
paevavalgus	doc_491521501872_item	2537392	et	4	main
oleks	doc_491521501872_item	2537393	et	3	main
igal	doc_491521501872_item	2537423	et	3	main
ja	doc_491521501872_item	2537426	et	3	main
aga	doc_491521501872_item	2537439	et	3	main
jouad	doc_491521501872_item	2537441	et	4	main
kui	doc_491521501872_item	2537445	et	3	main
kuidas	doc_491521501872_item	2537447	et	3	main
mis	doc_491521501872_item	2537450	et	4	main
ohtul	doc_491521501872_item	2537458	et	4	main
kindlasti	doc_491521501872_item	2537459	et	3	main
homme	doc_491521501872_item	2537463	et	3	main
kahtteist	doc_491521501872_item	2537467	et	4	main
et	doc_491521501872_item	2537472	et	3	main
on	doc_491521501872_item	2537474	et	4	main
sellest	doc_491521501872_item	2537475	et	4	main
palju	doc_491521501872_item	2537476	et	4	main
vastu	doc_491521501872_item	2537477	et	3	main
anda	doc_491521501872_item	2537478	et	3	main
siis	doc_491521501872_item	2537479	et	3	main
ainuld	doc_491521501872_item	2537486	et	4	main
tuukka	doc_491521501872_item	2537535	et	4	main
kiri	doc_491521501872_item	2537536	et	3	main
ilmselt	doc_491521501872_item	2537542	et	4	main
parast	doc_491521501872_item	2537545	et	3	main
klaasi	doc_491521501872_item	2537550	et	4	main
avatakse	doc_491521501872_item	2537552	et	4	main
voib	doc_491521501872_item	2537562	et	4	main
ei	doc_491521501872_item	2537566	et	4	main
kui	doc_491521501872_item	2537570	et	3	main
kokku	doc_491521501872_item	2537572	et	3	main
asja	doc_491521501872_item	2537576	et	4	main
et	doc_491521501872_item	2537580	et	3	main
enne	doc_491521501872_item	2537587	et	4	main
naiteks	doc_491521501872_item	2537588	et	4	main
kui	doc_491521501872_item	2537589	et	3	main
vaja	doc_491521501872_item	2537590	et	4	main
nõuk	doc_491521501873_item	2537594	et	4	main
võimul	doc_491521501873_item	2537623	et	3	main
olid	doc_491521501873_item	2537628	et	4	main
keelatud	doc_491521501873_item	2537629	et	4	main
igasugused	doc_491521501873_item	2537630	et	3	main
peod	doc_491521501873_item	2537631	et	4	main
siis	doc_491521501873_item	2537638	et	3	main
suur	doc_491521501873_item	2537640	et	3	main
kodanikke	doc_491521501873_item	2537646	et	3	main
kui	doc_491521501873_item	2537650	et	3	main
kirikutes	doc_491521501873_item	2537654	et	4	main
büroos	doc_491521501873_item	2537659	et	3	main
too	doc_491521501872_item	2537296	et	4	main
dill	doc_491521501872_item	2537298	et	4	main
kui	doc_491521501872_item	2537302	et	3	main
sulle	doc_491521501872_item	2537314	et	3	main
tutavatele	doc_491521501872_item	2537320	et	4	main
eest	doc_491521501872_item	2537327	et	4	main
arvan	doc_491521501872_item	2537333	et	3	main
oleks	doc_491521501872_item	2537339	et	3	main
aega	doc_491521501872_item	2537346	et	4	main
pildistamisele	doc_491521501872_item	2537348	et	4	main
ja	doc_491521501872_item	2537354	et	3	main
printtimisele	doc_491521501872_item	2537355	et	4	main
koige	doc_491521501872_item	2537360	et	4	main
kus	doc_491521501872_item	2537367	et	3	main
see	doc_491521501872_item	2537368	et	3	main
kus	doc_491521501872_item	2537371	et	3	main
saab	doc_491521501872_item	2537398	et	3	main
ilma	doc_491521501872_item	2537399	et	4	main
viis	doc_491521501872_item	2537322	et	4	main
sinu	doc_491521501872_item	2537329	et	3	main
kaest	doc_491521501872_item	2537330	et	4	main
materiaali	doc_491521501872_item	2537337	et	4	main
kulud	doc_491521501872_item	2537338	et	4	main
ja	doc_491521501872_item	2537345	et	3	main
paev	doc_491521501872_item	2537351	et	4	main
ja	doc_491521501872_item	2537352	et	3	main
ilmuttamisele	doc_491521501872_item	2537353	et	4	main
3-4	doc_491521501872_item	2537356	et	2	main
paeva	doc_491521501872_item	2537357	et	4	main
kuna	doc_491521501872_item	2537358	et	3	main
see	doc_491521501872_item	2537380	et	3	main
voiks	doc_491521501872_item	2537384	et	4	main
hea	doc_491521501872_item	2537394	et	4	main
kui	doc_491521501872_item	2537395	et	3	main
voimatu	doc_491521501872_item	2537396	et	4	main
siis	doc_491521501872_item	2537397	et	3	main
ka	doc_491521501872_item	2537400	et	3	main
hakkama	doc_491521501872_item	2537401	et	3	main
interjooris	doc_491521501872_item	2537402	et	4	main
kindlasti	doc_491521501872_item	2537403	et	3	main
nagu	doc_491521501872_item	2537404	et	3	main
nii	doc_491521501872_item	2537405	et	3	main
pole	doc_491521501872_item	2537406	et	3	main
piisavalt	doc_491521501872_item	2537407	et	4	main
paevavalgust	doc_491521501872_item	2537408	et	4	main
ja	doc_491521501872_item	2537409	et	3	main
peab	doc_491521501872_item	2537410	et	4	main
miksima	doc_491521501872_item	2537411	et	4	main
valguga	doc_491521501872_item	2537412	et	3	main
aga	doc_491521501872_item	2537413	et	3	main
teata	doc_491521501872_item	2537414	et	4	main
mis	doc_491521501872_item	2537415	et	4	main
arvad	doc_491521501872_item	2537416	et	3	main
tuukka	doc_491521501872_item	2537417	et	4	main
kiri	doc_491521501872_item	2537418	et	3	main
2	doc_491521501872_item	2537419	et	2	main
kuule	doc_491521501872_item	2537420	et	4	main
ostsin	doc_491521501872_item	2537421	et	3	main
panin	doc_491521501872_item	2537427	et	3	main
teha	doc_491521501872_item	2537438	et	3	main
ikkagi	doc_491521501872_item	2537443	et	4	main
ka	doc_491521501872_item	2537464	et	3	main
muidu	doc_491521501872_item	2537468	et	3	main
sulle	doc_491521501872_item	2537470	et	3	main
tundub	doc_491521501872_item	2537471	et	3	main
voib	doc_491521501872_item	2537480	et	4	main
nii	doc_491521501872_item	2537481	et	3	main
ka	doc_491521501872_item	2537482	et	3	main
teha	doc_491521501872_item	2537483	et	3	main
vaibad	doc_491521501872_item	2537489	et	3	main
pildistamine	doc_491521501872_item	2537521	et	4	main
lihtne	doc_491521501872_item	2537523	et	3	main
saab	doc_491521501872_item	2537526	et	3	main
igal	doc_491521501872_item	2537527	et	3	main
juhul	doc_491521501872_item	2537528	et	3	main
noh	doc_491521501872_item	2537530	et	3	main
teata	doc_491521501872_item	2537532	et	4	main
siis	doc_491521501872_item	2537533	et	3	main
kort	doc_491521501872_item	2537541	et	4	main
juhul	doc_491521501872_item	2537424	et	3	main
filmi	doc_491521501872_item	2537425	et	4	main
kaamera	doc_491521501872_item	2537429	et	4	main
kuna	doc_491521501872_item	2537431	et	3	main
vist	doc_491521501872_item	2537433	et	4	main
oleks	doc_491521501872_item	2537442	et	3	main
utled	doc_491521501872_item	2537446	et	4	main
tana	doc_491521501872_item	2537457	et	4	main
et	doc_491521501872_item	2537484	et	3	main
seal	doc_491521501872_item	2537490	et	4	main
nad	doc_491521501872_item	2537492	et	3	main
kus	doc_491521501872_item	2537491	et	3	main
nuud	doc_491521501872_item	2537493	et	4	main
olid	doc_491521501872_item	2537494	et	4	main
aga	doc_491521501872_item	2537495	et	3	main
jattaks	doc_491521501872_item	2537496	et	4	main
siis	doc_491521501872_item	2537497	et	3	main
selle	doc_491521501872_item	2537498	et	4	main
interjoori	doc_491521501872_item	2537499	et	4	main
ara	doc_491521501872_item	2537500	et	3	main
jattan	doc_491521501872_item	2537501	et	4	main
siis	doc_491521501872_item	2537502	et	3	main
filmi	doc_491521501872_item	2537503	et	4	main
sinu	doc_491521501872_item	2537504	et	3	main
katte	doc_491521501872_item	2537505	et	4	main
ja	doc_491521501872_item	2537506	et	3	main
sa	doc_491521501872_item	2537507	et	3	main
saad	doc_491521501872_item	2537508	et	4	main
ise	doc_491521501872_item	2537509	et	4	main
need	doc_491521501872_item	2537510	et	3	main
pildid	doc_491521501872_item	2537511	et	3	main
kusgilt	doc_491521501872_item	2537512	et	4	main
naiteks	doc_491521501872_item	2537513	et	4	main
morganist	doc_491521501872_item	2537514	et	3	main
tellida	doc_491521501872_item	2537515	et	3	main
onju	doc_491521501872_item	2537516	et	4	main
arvan	doc_491521501872_item	2537517	et	3	main
et	doc_491521501872_item	2537518	et	3	main
see	doc_491521501872_item	2537519	et	3	main
vaipade	doc_491521501872_item	2537520	et	3	main
3	doc_491521501872_item	2537537	et	2	main
ma	doc_491521501872_item	2537538	et	3	main
tulen	doc_491521501872_item	2537539	et	3	main
jargmine	doc_491521501872_item	2537540	et	4	main
nadala	doc_491521501872_item	2537544	et	4	main
kui	doc_491521501872_item	2537547	et	3	main
on	doc_491521501872_item	2537555	et	4	main
olla	doc_491521501872_item	2537563	et	3	main
siis	doc_491521501872_item	2537574	et	3	main
voi	doc_491521501872_item	2537584	et	4	main
siis	doc_491521501872_item	2537585	et	3	main
oli	doc_491521501873_item	2537598	et	3	main
enne	doc_491521501872_item	2537466	et	4	main
kui	doc_491521501872_item	2537469	et	3	main
need	doc_491521501872_item	2537487	et	3	main
ja	doc_491521501872_item	2537524	et	3	main
aga	doc_491521501872_item	2537531	et	3	main
onju	doc_491521501872_item	2537534	et	4	main
siis	doc_491521501872_item	2537546	et	3	main
see	doc_491521501872_item	2537548	et	3	main
aga	doc_491521501872_item	2537553	et	3	main
vist	doc_491521501872_item	2537556	et	4	main
umbes	doc_491521501872_item	2537557	et	4	main
just	doc_491521501872_item	2537558	et	3	main
20	doc_491521501872_item	2537559	et	2	main
nii	doc_491521501872_item	2537560	et	3	main
ka	doc_491521501872_item	2537565	et	3	main
joua	doc_491521501872_item	2537567	et	4	main
aga	doc_491521501872_item	2537569	et	3	main
saaks	doc_491521501872_item	2537575	et	3	main
paeva	doc_491521501872_item	2537586	et	4	main
suur	doc_491521501873_item	2537599	et	3	main
tartu	doc_491521501873_item	2537601	et	4	main
ülikoolis	doc_491521501873_item	2537602	et	4	main
oli	doc_491521501873_item	2537603	et	3	main
suletud	doc_491521501873_item	2537604	et	4	main
usuteaduse	doc_491521501873_item	2537605	et	3	main
teaduskond	doc_491521501873_item	2537606	et	3	main
aga	doc_491521501873_item	2537607	et	3	main
tallinnas	doc_491521501873_item	2537608	et	4	main
oli	doc_491521501873_item	2537609	et	3	main
avatud	doc_491521501873_item	2537610	et	4	main
instituut	doc_491521501873_item	2537612	et	3	main
mis	doc_491521501873_item	2537613	et	4	main
kuulus	doc_491521501873_item	2537614	et	4	main
usuteaduse	doc_491521501873_item	2537611	et	3	main
pühavaimu	doc_491521501873_item	2537615	et	4	main
kiriku	doc_491521501873_item	2537616	et	3	main
alla	doc_491521501873_item	2537617	et	3	main
oli	doc_491521501873_item	2537619	et	3	main
ainult	doc_491521501873_item	2537620	et	4	main
seal	doc_491521501873_item	2537618	et	4	main
kaugõppe	doc_491521501873_item	2537621	et	4	main
stalin	doc_491521501873_item	2537625	et	4	main
olid	doc_491521501873_item	2537634	et	4	main
kombed	doc_491521501873_item	2537647	et	3	main
abielu	doc_491521501873_item	2537649	et	4	main
sõlmiti	doc_491521501873_item	2537653	et	3	main
aastatel	doc_491521501873_item	2537661	et	4	main
et	doc_491521501872_item	2537561	et	3	main
pildistada	doc_491521501872_item	2537568	et	3	main
vahemalt	doc_491521501872_item	2537571	et	4	main
arutada	doc_491521501872_item	2537577	et	3	main
nii	doc_491521501872_item	2537579	et	3	main
umbes	doc_491521501872_item	2537581	et	4	main
20ndal	doc_491521501872_item	2537582	et	4	main
tulen	doc_491521501872_item	2537583	et	3	main
essee	doc_491521501873_item	2537592	et	4	main
kirik	doc_491521501873_item	2537593	et	3	main
19501960	doc_491521501873_item	2537596	et	2	main
renditasu	doc_491521501873_item	2537600	et	4	main
kirikutes	doc_491521501873_item	2537627	et	4	main
kommed	doc_491521501873_item	2537632	et	4	main
keelatud	doc_491521501873_item	2537635	et	4	main
poliitika	doc_491521501873_item	2537642	et	4	main
näiteks	doc_491521501873_item	2537648	et	4	main
sõlmimise	doc_491521501873_item	2537658	et	4	main
kuuekümnendatel	doc_491521501873_item	2537660	et	3	main
kirikusse	doc_491521501873_item	2537665	et	4	main
jumalasse	doc_491521501873_item	2537667	et	4	main
smuul	doc_491521501876_item	2538109	et	4	main
kuulub	doc_491521501876_item	2538118	et	3	main
teosed	doc_491521501876_item	2538122	et	3	main
mingil	doc_491521501876_item	2538123	et	4	main
määral	doc_491521501876_item	2538124	et	3	main
religioosseid	doc_491521501876_item	2538126	et	3	main
teoseid	doc_491521501876_item	2538127	et	3	main
oskar	doc_491521501876_item	2538128	et	4	main
ernesaks	doc_491521501876_item	2538139	et	4	main
oli	doc_491521501873_item	2537624	et	3	main
abielu	doc_491521501873_item	2537636	et	4	main
tuli	doc_491521501873_item	2537639	et	4	main
hakkasid	doc_491521501873_item	2537644	et	4	main
noored	doc_491521501873_item	2537662	et	3	main
uskuma	doc_491521501873_item	2537664	et	3	main
ja	doc_491521501873_item	2537666	et	3	main
sel	doc_491521501876_item	2538103	et	3	main
koduloomi	doc_491521501876_item	2538105	et	4	main
kajastub	doc_491521501876_item	2538112	et	3	main
sotsialistide	doc_491521501876_item	2538119	et	3	main
loorits	doc_491521501876_item	2538129	et	4	main
eesti	doc_491521501876_item	2538133	et	4	main
helilooja	doc_491521501876_item	2538140	et	4	main
väga	doc_491521501876_item	2538097	et	3	main
paljud	doc_491521501876_item	2538098	et	3	main
kirjanikud	doc_491521501876_item	2538099	et	3	main
ajal	doc_491521501876_item	2538104	et	4	main
ja	doc_491521501876_item	2538106	et	3	main
raamatus	doc_491521501876_item	2538110	et	4	main
raske	doc_491521501876_item	2538114	et	4	main
hulka	doc_491521501876_item	2538120	et	4	main
tema	doc_491521501876_item	2538121	et	4	main
meenutavad	doc_491521501876_item	2538125	et	4	main
folklorist	doc_491521501876_item	2538132	et	4	main
rahvaluule	doc_491521501876_item	2538134	et	4	main
arhiivi	doc_491521501876_item	2538135	et	4	main
esimene	doc_491521501876_item	2538136	et	3	main
direktor	doc_491521501876_item	2538137	et	3	main
e	doc_491521501876_item	2538144	et	4	main
hiir	doc_491521501876_item	2538149	et	4	main
riigipööre	doc_491521501876_item	2538152	et	4	main
tõi	doc_491521501876_item	2538153	et	3	main
kaasa	doc_491521501876_item	2538154	et	4	main
eestlaste	doc_491521501876_item	2538157	et	4	main
looming	doc_491521501876_item	2538214	et	3	main
kirjanikutele	doc_491521501876_item	2538215	et	4	main
mudeli	doc_491521501876_item	2538219	et	3	main
kasvatasid	doc_491521501876_item	2538102	et	4	main
linde	doc_491521501876_item	2538107	et	4	main
juhan	doc_491521501876_item	2538108	et	3	main
seda	doc_491521501876_item	2538113	et	3	main
j	doc_491521501876_item	2538116	et	4	main
smuul	doc_491521501876_item	2538117	et	4	main
eesti	doc_491521501876_item	2538085	et	4	main
kultuur	doc_491521501876_item	2538086	et	3	main
eksamitöö	doc_491521501876_item	2538084	et	4	main
nõukogude	doc_491521501876_item	2538087	et	3	main
tagalas	doc_491521501876_item	2538088	et	3	main
ms	doc_491521501876_item	2538090	et	4	main
ajal	doc_491521501876_item	2538091	et	4	main
sõja	doc_491521501876_item	2538092	et	3	main
ii	doc_491521501876_item	2538089	et	4	main
ajal	doc_491521501876_item	2538093	et	4	main
tegutseb	doc_491521501876_item	2538094	et	3	main
tartu	doc_491521501876_item	2538095	et	4	main
ülikool	doc_491521501876_item	2538096	et	4	main
vaikivad	doc_491521501876_item	2538100	et	4	main
eestlased	doc_491521501876_item	2538101	et	3	main
lea	doc_491521501876_item	2538111	et	4	main
aega	doc_491521501876_item	2538115	et	4	main
eesti	doc_491521501876_item	2538131	et	4	main
kapp	doc_491521501876_item	2538145	et	3	main
d	doc_491521501876_item	2538146	et	4	main
1940	doc_491521501876_item	2538150	et	2	main
selle	doc_491521501876_item	2538160	et	4	main
arenema	doc_491521501876_item	2538161	et	3	main
nõukogulike	doc_491521501876_item	2538162	et	3	main
kultuurimudelite	doc_491521501876_item	2538163	et	3	main
vabariigi	doc_491521501876_item	2538173	et	3	main
muutunud	doc_491521501876_item	2538177	et	4	main
ilmuma	doc_491521501876_item	2538212	et	3	main
seoti	doc_491521501876_item	2538216	et	3	main
nõukogude	doc_491521501876_item	2538218	et	3	main
oli	doc_491521501876_item	2538222	et	3	main
olema	doc_491521501876_item	2538227	et	4	main
parteine	doc_491521501876_item	2538228	et	4	main
ideeline	doc_491521501876_item	2538229	et	4	main
rahvalik	doc_491521501876_item	2538230	et	3	main
peamised	doc_491521501876_item	2538231	et	3	main
kirjandusžanrid	doc_491521501876_item	2538232	et	2	main
kirjanikut	doc_491521501876_item	2538240	et	4	main
koidula	doc_491521501876_item	2538246	et	4	main
ja	doc_491521501876_item	2538247	et	3	main
fr	doc_491521501876_item	2538248	et	4	main
r	doc_491521501876_item	2538249	et	4	main
vastu	doc_491521501876_item	2538278	et	3	main
ei	doc_491521501876_item	2538282	et	4	main
lääne	doc_491521501876_item	2538285	et	4	main
oswald	doc_491521501876_item	2538287	et	4	main
tooming	doc_491521501876_item	2538288	et	4	main
oli	doc_491521501876_item	2538289	et	3	main
ka	doc_491521501876_item	2538290	et	3	main
näitekirjanikutest	doc_491521501876_item	2538291	et	3	main
üks	doc_491521501876_item	2538292	et	3	main
populaarseim	doc_491521501876_item	2538293	et	4	main
lääne	doc_491521501876_item	2538302	et	4	main
olid	doc_491521501876_item	2538307	et	4	main
eestis	doc_491521501876_item	2538322	et	3	main
parema	doc_491521501876_item	2538332	et	4	main
sellele	doc_491521501876_item	2538340	et	4	main
erka	doc_491521501876_item	2538350	et	4	main
sega-	doc_491521501876_item	2538360	et	4	main
ja	doc_491521501876_item	2538361	et	3	main
sümfoonia-	doc_491521501876_item	2538366	et	4	main
džässiorkester	doc_491521501876_item	2538368	et	2	main
jegorjevski	doc_491521501876_item	2538401	et	4	main
eesti	doc_491521501876_item	2538402	et	4	main
õppekombinaadi	doc_491521501876_item	2538403	et	3	main
kirjandus	doc_491521501877_item	2538407	et	3	main
aastatel	doc_491521501877_item	2538409	et	4	main
aasta	doc_491521501877_item	2538411	et	4	main
seostati	doc_491521501877_item	2538419	et	3	main
uudiskirjandus	doc_491521501877_item	2538440	et	3	main
periood	doc_491521501877_item	2538446	et	3	main
ani	doc_491521501877_item	2538450	et	4	main
1953-1960	doc_491521501877_item	2538452	et	2	main
kirjandus	doc_491521501877_item	2538454	et	3	main
jagunes	doc_491521501877_item	2538455	et	3	main
1	doc_491521501877_item	2538456	et	2	main
nõukogude	doc_491521501877_item	2538457	et	3	main
kirjandus	doc_491521501877_item	2538458	et	3	main
täitsid	doc_491521501877_item	2538473	et	4	main
nagu	doc_491521501877_item	2538475	et	3	main
oli	doc_491521501877_item	2538478	et	3	main
ilmunud	doc_491521501877_item	2538495	et	4	main
sotsialistlik	doc_491521501877_item	2538523	et	3	main
pidi	doc_491521501877_item	2538526	et	4	main
ideeline	doc_491521501877_item	2538528	et	4	main
parteine	doc_491521501877_item	2538529	et	4	main
rahvalik	doc_491521501877_item	2538530	et	3	main
kirjandus	doc_491521501877_item	2538531	et	3	main
oli	doc_491521501877_item	2538532	et	3	main
rituaalseks	doc_491521501877_item	2538533	et	3	main
olid	doc_491521501877_item	2538539	et	4	main
smuul	doc_491521501877_item	2538547	et	4	main
ajal	doc_491521501877_item	2538558	et	4	main
r	doc_491521501877_item	2538566	et	4	main
oli	doc_491521501876_item	2538130	et	3	main
gustav	doc_491521501876_item	2538138	et	4	main
vaanandi	doc_491521501876_item	2538147	et	4	main
e	doc_491521501876_item	2538148	et	4	main
aasta	doc_491521501876_item	2538151	et	4	main
alusel	doc_491521501876_item	2538164	et	4	main
aastatel	doc_491521501876_item	2538166	et	4	main
püüti	doc_491521501876_item	2538167	et	3	main
oli	doc_491521501876_item	2538175	et	3	main
enda	doc_491521501876_item	2538178	et	4	main
tunnetamine	doc_491521501876_item	2538179	et	4	main
põhjamaade	doc_491521501876_item	2538180	et	3	main
ühiskultuuri	doc_491521501876_item	2538181	et	4	main
osana	doc_491521501876_item	2538182	et	3	main
samuti	doc_491521501876_item	2538183	et	3	main
soome-ugri	doc_491521501876_item	2538184	et	3	main
kultuuri	doc_491521501876_item	2538185	et	4	main
kandjana	doc_491521501876_item	2538186	et	4	main
ennekõike	doc_491521501876_item	2538187	et	3	main
mahuvad	doc_491521501876_item	2538188	et	3	main
nendesse	doc_491521501876_item	2538189	et	4	main
aastatesse	doc_491521501876_item	2538190	et	4	main
sõjameeleolud	doc_491521501876_item	2538191	et	3	main
ja	doc_491521501876_item	2538192	et	3	main
purustused	doc_491521501876_item	2538193	et	4	main
natsistid	doc_491521501876_item	2538194	et	4	main
keelasid	doc_491521501876_item	2538195	et	4	main
teisi	doc_491521501876_item	2538196	et	4	main
kultuuri	doc_491521501876_item	2538197	et	4	main
juudi	doc_491521501876_item	2538198	et	3	main
vene	doc_491521501876_item	2538199	et	4	main
prantsuse	doc_491521501876_item	2538200	et	3	main
toimusid	doc_491521501876_item	2538201	et	4	main
repressioonid	doc_491521501876_item	2538202	et	3	main
teiste	doc_491521501876_item	2538203	et	4	main
vastu	doc_491521501876_item	2538205	et	3	main
rahvaste	doc_491521501876_item	2538204	et	4	main
derigent	doc_491521501876_item	2538141	et	4	main
olulised	doc_491521501876_item	2538155	et	4	main
kultuurielus	doc_491521501876_item	2538158	et	4	main
pannes	doc_491521501876_item	2538159	et	4	main
kontakteeruda	doc_491521501876_item	2538168	et	4	main
lääne-euroopaga	doc_491521501876_item	2538169	et	3	main
ja	doc_491521501876_item	2538170	et	3	main
venemaaga	doc_491521501876_item	2538171	et	3	main
eesti	doc_491521501876_item	2538172	et	4	main
populaarseks	doc_491521501876_item	2538176	et	4	main
hakkab	doc_491521501876_item	2538211	et	3	main
sotsialistlik	doc_491521501876_item	2538223	et	3	main
kirjandus	doc_491521501876_item	2538225	et	3	main
lubatud	doc_491521501876_item	2538242	et	4	main
nõukogude	doc_491521501876_item	2538243	et	3	main
ajal	doc_491521501876_item	2538244	et	4	main
kreutzwald	doc_491521501876_item	2538250	et	4	main
ülemaailmne	doc_491521501876_item	2538256	et	3	main
otsus	doc_491521501876_item	2538279	et	3	main
tiraazid	doc_491521501876_item	2538306	et	4	main
kirjandusele	doc_491521501876_item	2538321	et	3	main
oli	doc_491521501876_item	2538323	et	3	main
konfliktuseteooria	doc_491521501876_item	2538325	et	4	main
võis	doc_491521501876_item	2538327	et	4	main
olla	doc_491521501876_item	2538328	et	3	main
hea	doc_491521501876_item	2538329	et	4	main
ja	doc_491521501876_item	2538330	et	3	main
veel	doc_491521501876_item	2538331	et	4	main
oli	doc_491521501876_item	2538344	et	3	main
250-liikmelisse	doc_491521501876_item	2538351	et	4	main
tantsuansambel	doc_491521501876_item	2538356	et	3	main
p	doc_491521501876_item	2538357	et	4	main
põldroosi	doc_491521501876_item	2538358	et	4	main
juhtimisel	doc_491521501876_item	2538359	et	4	main
tagalas	doc_491521501876_item	2538370	et	3	main
eksamitöö	doc_491521501877_item	2538405	et	4	main
nn	doc_491521501877_item	2538420	et	4	main
nõiajahti	doc_491521501877_item	2538421	et	4	main
erialaspetsialistid	doc_491521501877_item	2538423	et	3	main
uuele	doc_491521501877_item	2538424	et	3	main
ustavate	doc_491521501877_item	2538426	et	4	main
puhastus	doc_491521501877_item	2538428	et	4	main
liidus	doc_491521501877_item	2538430	et	4	main
oli	doc_491521501877_item	2538431	et	3	main
ei	doc_491521501877_item	2538436	et	4	main
ulatuslik	doc_491521501877_item	2538442	et	3	main
stalinismi	doc_491521501877_item	2538445	et	4	main
oli	doc_491521501877_item	2538447	et	3	main
eksiilkirjandus	doc_491521501877_item	2538460	et	3	main
kuni	doc_491521501877_item	2538464	et	3	main
aastani	doc_491521501877_item	2538466	et	3	main
kirjanikud	doc_491521501877_item	2538472	et	3	main
töölised	doc_491521501877_item	2538476	et	3	main
kontrollile	doc_491521501877_item	2538481	et	3	main
oli	doc_491521501877_item	2538482	et	3	main
ajal	doc_491521501877_item	2538486	et	4	main
tõlked	doc_491521501877_item	2538489	et	3	main
keelest	doc_491521501877_item	2538491	et	4	main
võõrkeelset	doc_491521501877_item	2538492	et	3	main
kirjandust	doc_491521501877_item	2538493	et	3	main
ei	doc_491521501877_item	2538494	et	4	main
kirjandus	doc_491521501877_item	2538525	et	3	main
valdavalt	doc_491521501877_item	2538540	et	4	main
august	doc_491521501877_item	2538549	et	4	main
jakobson	doc_491521501877_item	2538550	et	4	main
romaane	doc_491521501877_item	2538551	et	3	main
lubatud	doc_491521501877_item	2538556	et	4	main
ainult	doc_491521501877_item	2538559	et	4	main
kreutzwald	doc_491521501877_item	2538567	et	4	main
need	doc_491521501877_item	2538568	et	3	main
tuntud	doc_491521501876_item	2538142	et	4	main
näitlejad	doc_491521501876_item	2538143	et	4	main
muutused	doc_491521501876_item	2538156	et	4	main
192030	doc_491521501876_item	2538165	et	2	main
päevil	doc_491521501876_item	2538174	et	4	main
pärast	doc_491521501876_item	2538206	et	4	main
ajakiri	doc_491521501876_item	2538213	et	3	main
nn	doc_491521501876_item	2538217	et	4	main
ainuke	doc_491521501876_item	2538220	et	4	main
olid	doc_491521501876_item	2538233	et	4	main
valdavalt	doc_491521501876_item	2538234	et	4	main
poeem	doc_491521501876_item	2538235	et	3	main
ja	doc_491521501876_item	2538236	et	3	main
sees	doc_491521501876_item	2538254	et	4	main
eesti	doc_491521501876_item	2538255	et	4	main
teatrit	doc_491521501876_item	2538275	et	3	main
et	doc_491521501876_item	2538280	et	3	main
iseloomustab	doc_491521501876_item	2538297	et	4	main
satiir	doc_491521501876_item	2538298	et	3	main
mis	doc_491521501876_item	2538299	et	4	main
oli	doc_491521501876_item	2538300	et	3	main
suunatud	doc_491521501876_item	2538301	et	4	main
1940ndatel	doc_491521501876_item	2538304	et	4	main
tähtsaks	doc_491521501876_item	2538309	et	4	main
nõukogude	doc_491521501876_item	2538207	et	3	main
okupatsiooni	doc_491521501876_item	2538208	et	4	main
1945	doc_491521501876_item	2538209	et	2	main
aastast	doc_491521501876_item	2538210	et	4	main
kirjandusstiil	doc_491521501876_item	2538221	et	3	main
realism	doc_491521501876_item	2538224	et	3	main
pidi	doc_491521501876_item	2538226	et	4	main
draama	doc_491521501876_item	2538237	et	4	main
ainult	doc_491521501876_item	2538238	et	4	main
2	doc_491521501876_item	2538239	et	2	main
l	doc_491521501876_item	2538245	et	4	main
nad	doc_491521501876_item	2538251	et	3	main
olid	doc_491521501876_item	2538252	et	4	main
kirjanduse	doc_491521501876_item	2538257	et	3	main
võetakse	doc_491521501876_item	2538277	et	3	main
lavamängudes	doc_491521501876_item	2538281	et	3	main
1950ndatel	doc_491521501876_item	2538294	et	4	main
nõukogude	doc_491521501876_item	2538295	et	3	main
kirjanduse	doc_491521501876_item	2538305	et	3	main
väikesed	doc_491521501876_item	2538308	et	4	main
teemaks	doc_491521501876_item	2538310	et	4	main
tollases	doc_491521501876_item	2538311	et	3	main
kirjanduses	doc_491521501876_item	2538312	et	3	main
oli	doc_491521501876_item	2538313	et	3	main
võitlus	doc_491521501876_item	2538314	et	3	main
kodaniku	doc_491521501876_item	2538315	et	3	main
imperialismiga	doc_491521501876_item	2538316	et	3	main
ja	doc_491521501876_item	2538317	et	3	main
kodaniku	doc_491521501876_item	2538318	et	3	main
natsionalismiga	doc_491521501876_item	2538319	et	3	main
nõukogude	doc_491521501876_item	2538320	et	3	main
konflikt	doc_491521501876_item	2538326	et	3	main
g	doc_491521501876_item	2538363	et	4	main
töötas	doc_491521501876_item	2538371	et	3	main
kirjanikke	doc_491521501876_item	2538373	et	3	main
barbarus	doc_491521501876_item	2538375	et	4	main
eesti	doc_491521501877_item	2538406	et	4	main
viii	doc_491521501877_item	2538416	et	4	main
pleenum	doc_491521501877_item	2538417	et	3	main
sellega	doc_491521501877_item	2538418	et	3	main
kaadriametnikega	doc_491521501877_item	2538427	et	3	main
kirjanike	doc_491521501877_item	2538429	et	3	main
ilmunud	doc_491521501877_item	2538437	et	4	main
toimub	doc_491521501877_item	2538441	et	3	main
2	doc_491521501877_item	2538459	et	2	main
eesti	doc_491521501877_item	2538462	et	4	main
1953	doc_491521501877_item	2538465	et	2	main
nõukogude	doc_491521501877_item	2538467	et	3	main
valitses	doc_491521501877_item	2538469	et	3	main
käsumajandus	doc_491521501877_item	2538471	et	3	main
kirjandus	doc_491521501877_item	2538477	et	3	main
allutatud	doc_491521501877_item	2538479	et	4	main
tugev	doc_491521501877_item	2538483	et	4	main
tsentsuur	doc_491521501877_item	2538484	et	4	main
ilmusid	doc_491521501877_item	2538487	et	4	main
vene	doc_491521501877_item	2538490	et	4	main
kirjandusstiil	doc_491521501877_item	2538521	et	3	main
oli	doc_491521501877_item	2538522	et	3	main
e	doc_491521501877_item	2538534	et	4	main
stalini	doc_491521501877_item	2538535	et	4	main
keskseks	doc_491521501877_item	2538536	et	4	main
žanrid	doc_491521501877_item	2538538	et	2	main
praktiliselt	doc_491521501877_item	2538552	et	4	main
ilmunud	doc_491521501877_item	2538554	et	4	main
oli	doc_491521501877_item	2538555	et	3	main
nõukogude	doc_491521501877_item	2538557	et	3	main
2	doc_491521501877_item	2538560	et	2	main
kirjanikku	doc_491521501877_item	2538561	et	4	main
l	doc_491521501877_item	2538562	et	4	main
koidula	doc_491521501877_item	2538563	et	4	main
ja	doc_491521501877_item	2538564	et	3	main
olid	doc_491521501876_item	2538241	et	4	main
kooliprogrammi	doc_491521501876_item	2538253	et	4	main
selts	doc_491521501876_item	2538258	et	3	main
siia	doc_491521501876_item	2538259	et	4	main
koondunud	doc_491521501876_item	2538261	et	4	main
eksiilkirjanikud	doc_491521501876_item	2538262	et	3	main
esto	doc_491521501876_item	2538263	et	4	main
korraldas	doc_491521501876_item	2538264	et	3	main
olid	doc_491521501876_item	2538260	et	4	main
laulu-	doc_491521501876_item	2538265	et	4	main
ja	doc_491521501876_item	2538266	et	3	main
kultuuripeod	doc_491521501876_item	2538267	et	4	main
1972a	doc_491521501876_item	2538268	et	4	main
torontos	doc_491521501876_item	2538269	et	4	main
ja	doc_491521501876_item	2538270	et	3	main
kanadas	doc_491521501876_item	2538271	et	4	main
tegutseb	doc_491521501876_item	2538272	et	3	main
ainult	doc_491521501876_item	2538273	et	4	main
5	doc_491521501876_item	2538274	et	2	main
1946a	doc_491521501876_item	2538276	et	4	main
tohi	doc_491521501876_item	2538283	et	4	main
mängida	doc_491521501876_item	2538284	et	3	main
näidendeid	doc_491521501876_item	2538286	et	3	main
kirjandust	doc_491521501876_item	2538296	et	3	main
poole	doc_491521501876_item	2538303	et	4	main
vahel	doc_491521501876_item	2538333	et	4	main
vastandus	doc_491521501876_item	2538341	et	4	main
paha	doc_491521501876_item	2538342	et	4	main
kapitalism	doc_491521501876_item	2538343	et	3	main
oluline	doc_491521501876_item	2538346	et	4	main
kunstiansamblite	doc_491521501876_item	2538347	et	3	main
moodustamise	doc_491521501876_item	2538348	et	4	main
fakt	doc_491521501876_item	2538349	et	3	main
kollektiivi	doc_491521501876_item	2538352	et	4	main
laulu-	doc_491521501876_item	2538354	et	4	main
ernesaksa	doc_491521501876_item	2538364	et	4	main
juhtimisel	doc_491521501876_item	2538365	et	4	main
arvukalt	doc_491521501876_item	2538372	et	4	main
tegevus	doc_491521501876_item	2538404	et	4	main
ekbp	doc_491521501877_item	2538414	et	4	main
keskkomitee	doc_491521501877_item	2538415	et	4	main
niivõrd	doc_491521501877_item	2538432	et	3	main
põhjalik	doc_491521501877_item	2538433	et	3	main
et	doc_491521501877_item	2538434	et	3	main
peaaegu	doc_491521501877_item	2538435	et	3	main
eesti	doc_491521501877_item	2538439	et	4	main
kuni	doc_491521501877_item	2538448	et	3	main
e	doc_491521501877_item	2538461	et	4	main
kirjanduses	doc_491521501877_item	2538468	et	3	main
kontroll	doc_491521501877_item	2538470	et	3	main
plaani	doc_491521501877_item	2538474	et	4	main
stalinismi	doc_491521501877_item	2538485	et	4	main
iseloomulik	doc_491521501876_item	2538324	et	3	main
kujutamisobjektiks	doc_491521501876_item	2538334	et	3	main
oli	doc_491521501876_item	2538335	et	3	main
nn	doc_491521501876_item	2538336	et	4	main
helge	doc_491521501876_item	2538337	et	4	main
tulevik	doc_491521501876_item	2538338	et	3	main
kõige	doc_491521501876_item	2538339	et	4	main
väga	doc_491521501876_item	2538345	et	3	main
kuulus	doc_491521501876_item	2538353	et	4	main
ja	doc_491521501876_item	2538355	et	3	main
meeskoor	doc_491521501876_item	2538362	et	4	main
ja	doc_491521501876_item	2538367	et	3	main
draamakollektiiv	doc_491521501876_item	2538369	et	3	main
j	doc_491521501876_item	2538374	et	4	main
j	doc_491521501876_item	2538376	et	4	main
semper	doc_491521501876_item	2538377	et	4	main
m	doc_491521501876_item	2538378	et	4	main
raud	doc_491521501876_item	2538379	et	3	main
a	doc_491521501876_item	2538380	et	4	main
hint	doc_491521501876_item	2538381	et	4	main
jt	doc_491521501876_item	2538382	et	4	main
kunstnikke	doc_491521501876_item	2538383	et	3	main
adamson	doc_491521501876_item	2538384	et	4	main
eric	doc_491521501876_item	2538385	et	4	main
r	doc_491521501876_item	2538386	et	4	main
sagrits	doc_491521501876_item	2538387	et	4	main
e	doc_491521501876_item	2538388	et	4	main
okas	doc_491521501876_item	2538389	et	3	main
jt	doc_491521501876_item	2538390	et	4	main
heliloojaid	doc_491521501876_item	2538391	et	3	main
e	doc_491521501876_item	2538392	et	4	main
kapp	doc_491521501876_item	2538393	et	3	main
h	doc_491521501876_item	2538394	et	4	main
lepnurm	doc_491521501876_item	2538395	et	4	main
tagalaperioodi	doc_491521501876_item	2538396	et	4	main
kuulub	doc_491521501876_item	2538397	et	3	main
ka	doc_491521501876_item	2538398	et	3	main
loomeliitude	doc_491521501876_item	2538399	et	4	main
organiseerimine	doc_491521501876_item	2538400	et	4	main
1950ndatel	doc_491521501877_item	2538408	et	4	main
1950	doc_491521501877_item	2538410	et	2	main
märtsis	doc_491521501877_item	2538412	et	3	main
toimus	doc_491521501877_item	2538413	et	3	main
asendati	doc_491521501877_item	2538422	et	3	main
korrale	doc_491521501877_item	2538425	et	3	main
enam	doc_491521501877_item	2538438	et	4	main
raamatuhävitamine	doc_491521501877_item	2538443	et	3	main
raamatukogudes	doc_491521501877_item	2538444	et	3	main
1953	doc_491521501877_item	2538449	et	2	main
sulaperiood	doc_491521501877_item	2538451	et	3	main
eesti	doc_491521501877_item	2538453	et	4	main
kirjandus	doc_491521501877_item	2538463	et	3	main
partei	doc_491521501877_item	2538480	et	4	main
põhiliselt	doc_491521501877_item	2538488	et	4	main
hakkasid	doc_491521501877_item	2538496	et	4	main
ilmuma	doc_491521501877_item	2538497	et	3	main
sellised	doc_491521501877_item	2538498	et	4	main
ajalehed	doc_491521501877_item	2538499	et	3	main
nagu	doc_491521501877_item	2538500	et	3	main
sirp	doc_491521501877_item	2538501	et	3	main
vasar	doc_491521501877_item	2538502	et	3	main
ajakirjad	doc_491521501877_item	2538503	et	3	main
viisnurk	doc_491521501877_item	2538504	et	3	main
johannes	doc_491521501877_item	2538505	et	4	main
semper	doc_491521501877_item	2538506	et	4	main
aja	doc_491521501877_item	2538508	et	4	main
nõukogude	doc_491521501877_item	2538507	et	3	main
kirjanik	doc_491521501877_item	2538509	et	3	main
alguses	doc_491521501877_item	2538510	et	4	main
oli	doc_491521501877_item	2538511	et	3	main
semper	doc_491521501877_item	2538512	et	4	main
keelatud	doc_491521501877_item	2538513	et	4	main
autoriks	doc_491521501877_item	2538514	et	3	main
seoti	doc_491521501877_item	2538516	et	3	main
kirjanikutele	doc_491521501877_item	2538515	et	4	main
nn	doc_491521501877_item	2538517	et	4	main
nõukogude	doc_491521501877_item	2538518	et	3	main
mudeli	doc_491521501877_item	2538519	et	3	main
ainuke	doc_491521501877_item	2538520	et	4	main
realism	doc_491521501877_item	2538524	et	3	main
olema	doc_491521501877_item	2538527	et	4	main
peamised	doc_491521501877_item	2538537	et	3	main
poeem	doc_491521501877_item	2538541	et	3	main
poeetidest	doc_491521501877_item	2538544	et	3	main
juhan	doc_491521501877_item	2538546	et	3	main
draamakirjanikest	doc_491521501877_item	2538548	et	3	main
ja	doc_491521501877_item	2538542	et	3	main
draama	doc_491521501877_item	2538543	et	4	main
domineeris	doc_491521501877_item	2538545	et	3	main
ei	doc_491521501877_item	2538553	et	4	main
fr	doc_491521501877_item	2538565	et	4	main
olid	doc_491521501877_item	2538569	et	4	main
kooliprogrammis	doc_491521501877_item	2538570	et	3	main
1975	doc_491521501877_item	2538571	et	2	main
a	doc_491521501877_item	2538572	et	4	main
ilmub	doc_491521501877_item	2538573	et	3	main
deboora	doc_491521501877_item	2538574	et	4	main
varrandi	doc_491521501877_item	2538575	et	4	main
luulekogu	doc_491521501877_item	2538576	et	4	main
lihtsad	doc_491521501877_item	2538577	et	3	main
asjad	doc_491521501877_item	2538578	et	3	main
1960	doc_491521501879_item	2538954	et	2	main
nn	doc_491521501879_item	2538956	et	4	main
sulaperioodi	doc_491521501879_item	2538957	et	4	main
2	doc_491521501879_item	2538961	et	2	main
moskvale	doc_491521501879_item	2538979	et	4	main
millisest	doc_491521501879_item	2538984	et	3	main
millal	doc_491521501879_item	2538990	et	3	main
mida	doc_491521501879_item	2538994	et	4	main
balti	doc_491521501879_item	2538996	et	3	main
kruusemendi	doc_491521501879_item	2539003	et	4	main
pärast	doc_491521501879_item	2539007	et	4	main
tema	doc_491521501879_item	2539015	et	4	main
teisisõnu	doc_491521501879_item	2539018	et	3	main
e	doc_491521501879_item	2539020	et	4	main
võisid	doc_491521501879_item	2539028	et	4	main
kultuuriinimesed	doc_491521501879_item	2539031	et	3	main
olid	doc_491521501879_item	2539033	et	4	main
sisendab	doc_491521501879_item	2538980	et	3	main
hirmu	doc_491521501879_item	2538981	et	4	main
ahel	doc_491521501879_item	2538983	et	3	main
aimla	doc_491521501879_item	2538988	et	4	main
ja	doc_491521501879_item	2538993	et	3	main
see	doc_491521501879_item	2538995	et	3	main
riikide	doc_491521501879_item	2538997	et	3	main
hruštšovi	doc_491521501879_item	2539021	et	2	main
tegutseda	doc_491521501879_item	2539029	et	3	main
kes	doc_491521501879_item	2539032	et	4	main
stalini	doc_491521501879_item	2539034	et	4	main
ajal	doc_491521501879_item	2539035	et	4	main
alla	doc_491521501879_item	2539039	et	3	main
keda	doc_491521501879_item	2539054	et	4	main
enam	doc_491521501879_item	2539056	et	4	main
ega	doc_491521501879_item	2539059	et	3	main
mõjutanud	doc_491521501879_item	2539060	et	4	main
kord	doc_491521501879_item	2539064	et	4	main
raamatute	doc_491521501879_item	2539066	et	3	main
jaoks	doc_491521501879_item	2539081	et	4	main
oma	doc_491521501879_item	2539086	et	4	main
ilma	doc_491521501879_item	2539088	et	4	main
kirjastused	doc_491521501879_item	2539094	et	4	main
orto	doc_491521501879_item	2539097	et	4	main
vaba	doc_491521501879_item	2539098	et	4	main
saksamaal	doc_491521501879_item	2539100	et	4	main
filme	doc_491521501879_item	2539107	et	3	main
neist	doc_491521501879_item	2539109	et	4	main
kakskeelsuse	doc_491521501879_item	2539119	et	4	main
pealesurumine	doc_491521501879_item	2539120	et	3	main
aastate	doc_491521501879_item	2538955	et	3	main
kui	doc_491521501879_item	2538977	et	3	main
sündmusest	doc_491521501879_item	2538985	et	4	main
kõneldakse	doc_491521501879_item	2538986	et	3	main
p	doc_491521501879_item	2538987	et	4	main
see	doc_491521501879_item	2538991	et	3	main
jaoks	doc_491521501879_item	2538998	et	4	main
a	doc_491521501879_item	2539002	et	4	main
tuntumaid	doc_491521501879_item	2539004	et	4	main
filme	doc_491521501879_item	2539005	et	3	main
1	doc_491521501879_item	2539006	et	2	main
hruštšov	doc_491521501879_item	2539013	et	2	main
ning	doc_491521501879_item	2539014	et	3	main
eksamitöö	doc_491521501879_item	2538952	et	4	main
üldiseloomustus	doc_491521501879_item	2538960	et	4	main
nii	doc_491521501879_item	2538975	et	3	main
toompealt	doc_491521501879_item	2538976	et	3	main
luuletuses	doc_491521501879_item	2538989	et	4	main
toimus	doc_491521501879_item	2538992	et	3	main
3	doc_491521501879_item	2539000	et	2	main
nimetage	doc_491521501879_item	2539001	et	3	main
surma	doc_491521501879_item	2539009	et	4	main
1953a	doc_491521501879_item	2539010	et	4	main
sai	doc_491521501879_item	2539011	et	4	main
võimule	doc_491521501879_item	2539012	et	3	main
nimetatakse	doc_491521501879_item	2539017	et	3	main
sulaperioodiks	doc_491521501879_item	2539019	et	3	main
sulaks	doc_491521501879_item	2539022	et	4	main
ajal	doc_491521501879_item	2539024	et	4	main
tsensuur	doc_491521501879_item	2539026	et	3	main
julgemalt	doc_491521501879_item	2539027	et	4	main
kord	doc_491521501879_item	2539042	et	4	main
inimesed	doc_491521501879_item	2539045	et	3	main
põlvkond	doc_491521501879_item	2539052	et	3	main
siiski	doc_491521501879_item	2539061	et	4	main
elavate	doc_491521501879_item	2539079	et	4	main
inimeste	doc_491521501879_item	2539080	et	3	main
igasuguse	doc_491521501879_item	2539089	et	3	main
tsensuurita	doc_491521501879_item	2539090	et	3	main
sellised	doc_491521501879_item	2539093	et	4	main
nagu	doc_491521501879_item	2539095	et	3	main
kultuur	doc_491521501879_item	2539101	et	3	main
või	doc_491521501879_item	2539128	et	4	main
brežnevi	doc_491521501879_item	2539129	et	2	main
valitsemisajal	doc_491521501879_item	2539130	et	3	main
väga	doc_491521501879_item	2539131	et	3	main
populaarsed	doc_491521501879_item	2539132	et	3	main
olid	doc_491521501879_item	2539133	et	4	main
väärtuslikud	doc_491521501879_item	2539140	et	3	main
toimuvast	doc_491521501879_item	2539152	et	4	main
korterijärjekorrad	doc_491521501879_item	2539153	et	3	main
palju	doc_491521501879_item	2539156	et	4	main
halva	doc_491521501879_item	2539157	et	4	main
2	doc_491521501879_item	2539160	et	2	main
mis	doc_491521501879_item	2539164	et	4	main
a	doc_491521501879_item	2539169	et	4	main
kolme	doc_491521501879_item	2539171	et	4	main
balti	doc_491521501879_item	2539172	et	3	main
riigi	doc_491521501879_item	2539173	et	3	main
sõnastus	doc_491521501879_item	2539180	et	4	main
ühines	doc_491521501879_item	2539182	et	3	main
nl	doc_491521501879_item	2539183	et	4	main
toimus	doc_491521501879_item	2539187	et	3	main
kui	doc_491521501879_item	2539190	et	3	main
saadi	doc_491521501879_item	2539191	et	4	main
ja	doc_491521501879_item	2539200	et	3	main
eesti	doc_491521501879_item	2539203	et	4	main
rolli	doc_491521501879_item	2539233	et	4	main
ta	doc_491521501879_item	2539240	et	4	main
ometi	doc_491521501879_item	2539248	et	3	main
eksiilis	doc_491521501879_item	2539254	et	4	main
ning	doc_491521501879_item	2539261	et	3	main
3	doc_491521501879_item	2539263	et	2	main
uus	doc_491521501879_item	2539268	et	3	main
nukitsamees	doc_491521501879_item	2539270	et	4	main
1	doc_491521501879_item	2538953	et	2	main
eesti	doc_491521501879_item	2538958	et	4	main
kultuuri	doc_491521501879_item	2538959	et	4	main
ei	doc_491521501879_item	2538962	et	4	main
aima	doc_491521501879_item	2538963	et	4	main
kauge	doc_491521501879_item	2538964	et	4	main
korea	doc_491521501879_item	2538965	et	4	main
ega	doc_491521501879_item	2538966	et	3	main
hiina	doc_491521501879_item	2538967	et	3	main
sest	doc_491521501879_item	2538968	et	4	main
paelast	doc_491521501879_item	2538969	et	4	main
me	doc_491521501879_item	2538970	et	4	main
balti	doc_491521501879_item	2538971	et	3	main
pealinnade	doc_491521501879_item	2538972	et	3	main
vahel	doc_491521501879_item	2538973	et	4	main
aga	doc_491521501879_item	2538974	et	3	main
gediminasest	doc_491521501879_item	2538978	et	4	main
see	doc_491521501879_item	2538982	et	3	main
tähendas	doc_491521501879_item	2538999	et	3	main
stalini	doc_491521501879_item	2539008	et	4	main
valitsemisaega	doc_491521501879_item	2539016	et	4	main
tema	doc_491521501879_item	2539023	et	4	main
vähenes	doc_491521501879_item	2539025	et	3	main
põlu	doc_491521501879_item	2539036	et	3	main
range	doc_491521501879_item	2539041	et	4	main
hakkas	doc_491521501879_item	2539049	et	3	main
uus	doc_491521501879_item	2539051	et	3	main
valitses	doc_491521501879_item	2539062	et	3	main
üle	doc_491521501879_item	2539067	et	3	main
võib	doc_491521501879_item	2539070	et	3	main
oli	doc_491521501879_item	2539083	et	3	main
kevade	doc_491521501879_item	2539115	et	4	main
1969	doc_491521501879_item	2539116	et	2	main
hariduse	doc_491521501879_item	2539117	et	3	main
olnud	doc_491521501879_item	2539122	et	4	main
koduraamatukogud	doc_491521501879_item	2539134	et	3	main
paljude	doc_491521501879_item	2539146	et	3	main
suurenes	doc_491521501879_item	2539148	et	4	main
teadlikkus	doc_491521501879_item	2539150	et	4	main
ehitati	doc_491521501879_item	2539155	et	3	main
toimus	doc_491521501879_item	2539165	et	3	main
1989	doc_491521501879_item	2539168	et	2	main
pikkune	doc_491521501879_item	2539178	et	4	main
vabadusejanu	doc_491521501879_item	2539201	et	4	main
nii	doc_491521501879_item	2539205	et	3	main
eestlaste	doc_491521501879_item	2539229	et	4	main
vabaduspüüet	doc_491521501879_item	2539230	et	3	main
mängisid	doc_491521501879_item	2539231	et	4	main
keelatud	doc_491521501879_item	2539235	et	4	main
oli	doc_491521501879_item	2539241	et	3	main
olemas	doc_491521501879_item	2539243	et	4	main
olgugi	doc_491521501879_item	2539245	et	4	main
et	doc_491521501879_item	2539246	et	3	main
põrandaalused	doc_491521501879_item	2539247	et	4	main
ning	doc_491521501879_item	2539251	et	3	main
pm	doc_491521501879_item	2539262	et	4	main
reliikvia	doc_491521501879_item	2539265	et	4	main
need	doc_491521501879_item	2539030	et	3	main
repressioonide	doc_491521501879_item	2539038	et	3	main
hakkas	doc_491521501879_item	2539043	et	3	main
muutusid	doc_491521501879_item	2539046	et	4	main
60-ndatel	doc_491521501879_item	2539048	et	4	main
julgemaks	doc_491521501879_item	2539047	et	4	main
ja	doc_491521501879_item	2539037	et	3	main
sattunud	doc_491521501879_item	2539040	et	4	main
leevenema	doc_491521501879_item	2539044	et	4	main
tegutsema	doc_491521501879_item	2539050	et	3	main
sõjaõudused	doc_491521501879_item	2539055	et	3	main
puudutanud	doc_491521501879_item	2539058	et	4	main
kontrolliti	doc_491521501879_item	2539068	et	3	main
mida	doc_491521501879_item	2539072	et	4	main
neil	doc_491521501879_item	2539082	et	4	main
avaldada	doc_491521501879_item	2539085	et	3	main
raamatuid	doc_491521501879_item	2539087	et	3	main
välismaal	doc_491521501879_item	2539091	et	4	main
palju	doc_491521501879_item	2539106	et	4	main
andmine	doc_491521501879_item	2539118	et	4	main
stalini	doc_491521501879_item	2539127	et	4	main
koguti	doc_491521501879_item	2539135	et	3	main
mis	doc_491521501879_item	2539138	et	4	main
jõudes	doc_491521501879_item	2539145	et	3	main
inimeste	doc_491521501879_item	2539149	et	3	main
ümberringi	doc_491521501879_item	2539151	et	3	main
kvaliteediga	doc_491521501879_item	2539158	et	3	main
aug	doc_491521501879_item	2539167	et	4	main
läbi	doc_491521501879_item	2539170	et	4	main
viis	doc_491521501879_item	2539174	et	4	main
inimkett	doc_491521501879_item	2539179	et	4	main
rahvas	doc_491521501879_item	2539181	et	4	main
aru	doc_491521501879_item	2539192	et	4	main
et	doc_491521501879_item	2539193	et	3	main
tegid	doc_491521501879_item	2539202	et	4	main
rahva	doc_491521501879_item	2539204	et	3	main
kirjanikke	doc_491521501879_item	2539053	et	3	main
ei	doc_491521501879_item	2539057	et	4	main
range	doc_491521501879_item	2539063	et	4	main
eestikeelsete	doc_491521501879_item	2539065	et	4	main
mida	doc_491521501879_item	2539069	et	4	main
ja	doc_491521501879_item	2539071	et	3	main
mitte	doc_491521501879_item	2539073	et	3	main
avaldada	doc_491521501879_item	2539074	et	3	main
parem	doc_491521501879_item	2539075	et	4	main
oli	doc_491521501879_item	2539076	et	3	main
olukord	doc_491521501879_item	2539077	et	3	main
eksiilis	doc_491521501879_item	2539078	et	4	main
võimalus	doc_491521501879_item	2539084	et	3	main
tegutsesid	doc_491521501879_item	2539092	et	4	main
rootsis	doc_491521501879_item	2539096	et	3	main
eesti	doc_491521501879_item	2539099	et	4	main
jne	doc_491521501879_item	2539102	et	4	main
1960-ndatel	doc_491521501879_item	2539103	et	4	main
avaldati	doc_491521501879_item	2539104	et	3	main
eestis	doc_491521501879_item	2539105	et	3	main
kuulsamad	doc_491521501879_item	2539108	et	4	main
on	doc_491521501879_item	2539110	et	4	main
viimne	doc_491521501879_item	2539111	et	3	main
reliikvia	doc_491521501879_item	2539112	et	4	main
1965	doc_491521501879_item	2539113	et	2	main
ning	doc_491521501879_item	2539114	et	3	main
ei	doc_491521501879_item	2539121	et	4	main
nii	doc_491521501879_item	2539123	et	3	main
intensiivne	doc_491521501879_item	2539124	et	3	main
kui	doc_491521501879_item	2539125	et	3	main
nt	doc_491521501879_item	2539126	et	4	main
teoseid	doc_491521501879_item	2539137	et	3	main
vähegi	doc_491521501879_item	2539139	et	4	main
60-ndatel	doc_491521501879_item	2539141	et	4	main
arenes	doc_491521501879_item	2539142	et	3	main
ka	doc_491521501879_item	2539143	et	3	main
kodudesse	doc_491521501879_item	2539147	et	3	main
lühenesid	doc_491521501879_item	2539154	et	4	main
23	doc_491521501879_item	2539166	et	2	main
600	doc_491521501879_item	2539176	et	2	main
km	doc_491521501879_item	2539177	et	4	main
nl	doc_491521501879_item	2539194	et	4	main
polegi	doc_491521501879_item	2539195	et	3	main
enam	doc_491521501879_item	2539196	et	4	main
nii	doc_491521501879_item	2539197	et	3	main
kõikvõimas	doc_491521501879_item	2539198	et	3	main
ühtekuuluvustunne	doc_491521501879_item	2539199	et	3	main
tugevaks	doc_491521501879_item	2539206	et	4	main
a	doc_491521501879_item	2539221	et	4	main
iseseisvuse	doc_491521501879_item	2539223	et	4	main
selle	doc_491521501879_item	2539225	et	4	main
olulist	doc_491521501879_item	2539232	et	4	main
peideti	doc_491521501879_item	2539238	et	3	main
siiski	doc_491521501879_item	2539242	et	4	main
seltsid	doc_491521501879_item	2539244	et	4	main
üksteist	doc_491521501879_item	2539253	et	4	main
kultuuritegelased	doc_491521501879_item	2539256	et	3	main
ning	doc_491521501879_item	2539257	et	3	main
seal	doc_491521501879_item	2539258	et	4	main
põrgupõhja	doc_491521501879_item	2539267	et	4	main
vanapagan	doc_491521501879_item	2539269	et	3	main
kõiki	doc_491521501879_item	2539136	et	4	main
tv	doc_491521501879_item	2539144	et	4	main
paneelmaju	doc_491521501879_item	2539159	et	3	main
jutt	doc_491521501879_item	2539161	et	3	main
on	doc_491521501879_item	2539162	et	4	main
baltiketist	doc_491521501879_item	2539163	et	3	main
u	doc_491521501879_item	2539175	et	4	main
ja	doc_491521501879_item	2539184	et	3	main
sotsialismi	doc_491521501879_item	2539185	et	4	main
vastu	doc_491521501879_item	2539186	et	3	main
uus	doc_491521501879_item	2539188	et	3	main
ärkamisaeg	doc_491521501879_item	2539189	et	3	main
et	doc_491521501879_item	2539207	et	3	main
tänu	doc_491521501879_item	2539208	et	4	main
sellele	doc_491521501879_item	2539209	et	4	main
sai	doc_491521501879_item	2539210	et	4	main
16	doc_491521501879_item	2539211	et	2	main
nov	doc_491521501879_item	2539212	et	4	main
19888	doc_491521501879_item	2539213	et	2	main
a	doc_491521501879_item	2539214	et	4	main
eesti	doc_491521501879_item	2539215	et	4	main
suveräänsusdeklaratsiooni	doc_491521501879_item	2539216	et	4	main
ning	doc_491521501879_item	2539217	et	3	main
20	doc_491521501879_item	2539218	et	2	main
aug	doc_491521501879_item	2539219	et	4	main
1991	doc_491521501879_item	2539220	et	2	main
saavutas	doc_491521501879_item	2539222	et	3	main
kõige	doc_491521501879_item	2539224	et	4	main
raamatud	doc_491521501879_item	2539234	et	4	main
kuid	doc_491521501879_item	2539239	et	4	main
saadi	doc_491521501879_item	2539249	et	4	main
ilmuvad	doc_491521501879_item	2539259	et	4	main
väljaanded	doc_491521501879_item	2539260	et	3	main
viimne	doc_491521501879_item	2539264	et	3	main
1965	doc_491521501879_item	2539266	et	2	main
juures	doc_491521501879_item	2539226	et	4	main
mis	doc_491521501879_item	2539227	et	4	main
tingis	doc_491521501879_item	2539228	et	3	main
rahvuslikku	doc_491521501879_item	2539236	et	4	main
kirjandust	doc_491521501879_item	2539237	et	3	main
kokku	doc_491521501879_item	2539250	et	3	main
innustati	doc_491521501879_item	2539252	et	3	main
elavad	doc_491521501879_item	2539255	et	4	main
üldiseloomustus	doc_491521501881_item	2539696	et	4	main
2	doc_491521501881_item	2539697	et	2	main
osa	doc_491521501881_item	2539703	et	4	main
3	doc_491521501881_item	2539706	et	2	main
meri	doc_491521501881_item	2539708	et	3	main
kirjaniku	doc_491521501881_item	2539709	et	3	main
ja	doc_491521501881_item	2539710	et	3	main
1	doc_491521501881_item	2539712	et	2	main
kirjanduses	doc_491521501881_item	2539722	et	3	main
kujunes	doc_491521501881_item	2539723	et	3	main
lemmiktegelaseks	doc_491521501881_item	2539725	et	3	main
arendatud	doc_491521501881_item	2539730	et	4	main
ja	doc_491521501881_item	2539752	et	3	main
kolme	doc_491521501881_item	2539757	et	4	main
samuti	doc_491521501881_item	2539760	et	3	main
traadi	doc_491521501881_item	2539762	et	4	main
rahvuse	doc_491521501881_item	2539763	et	3	main
romaane	doc_491521501881_item	2539766	et	3	main
mõtteid	doc_491521501881_item	2539789	et	3	main
öölaulupeod	doc_491521501881_item	2539791	et	4	main
olla	doc_491521501881_item	2539803	et	3	main
balti	doc_491521501881_item	2539814	et	3	main
toimus	doc_491521501881_item	2539816	et	3	main
nn	doc_491521501881_item	2539698	et	4	main
revolutsiooni	doc_491521501881_item	2539702	et	4	main
eesti	doc_491521501881_item	2539704	et	4	main
ajal	doc_491521501881_item	2539714	et	4	main
kunstikultuur	doc_491521501881_item	2539716	et	3	main
läänepoolse	doc_491521501881_item	2539720	et	3	main
kellele	doc_491521501881_item	2539732	et	4	main
vastand	doc_491521501881_item	2539733	et	4	main
oli	doc_491521501881_item	2539734	et	3	main
hiired	doc_491521501881_item	2539738	et	3	main
publitsistikas	doc_491521501881_item	2539740	et	3	main
nagu	doc_491521501881_item	2539744	et	3	main
tema	doc_491521501881_item	2539753	et	4	main
olemust	doc_491521501881_item	2539764	et	3	main
olid	doc_491521501881_item	2539792	et	4	main
ajal	doc_491521501881_item	2539796	et	4	main
et	doc_491521501881_item	2539797	et	3	main
võiksid	doc_491521501881_item	2539799	et	4	main
et	doc_491521501881_item	2539802	et	3	main
1989	doc_491521501881_item	2539813	et	2	main
aktsioon	doc_491521501881_item	2539817	et	3	main
kelt	doc_491521501881_item	2539822	et	3	main
see	doc_491521501881_item	2539823	et	3	main
kes	doc_491521501881_item	2539835	et	4	main
armee	doc_491521501881_item	2539841	et	4	main
oli	doc_491521501881_item	2539842	et	3	main
välja	doc_491521501881_item	2539843	et	4	main
3	doc_491521501881_item	2539853	et	2	main
tema	doc_491521501881_item	2539865	et	4	main
samuti	doc_491521501881_item	2539870	et	3	main
ta	doc_491521501881_item	2539872	et	4	main
19701980	doc_491521501881_item	2539691	et	2	main
kirjanduselu	doc_491521501881_item	2539695	et	4	main
laulva	doc_491521501881_item	2539701	et	4	main
taasiseseisvumisel	doc_491521501881_item	2539705	et	3	main
l	doc_491521501881_item	2539707	et	4	main
filmiloojana	doc_491521501881_item	2539711	et	3	main
tol	doc_491521501881_item	2539713	et	3	main
püüdis	doc_491521501881_item	2539717	et	3	main
1	doc_491521501881_item	2539690	et	2	main
ii	doc_491521501881_item	2539693	et	4	main
poole	doc_491521501881_item	2539694	et	4	main
eesti	doc_491521501881_item	2539715	et	4	main
sidet	doc_491521501881_item	2539719	et	4	main
kultuuriareaaliga	doc_491521501881_item	2539721	et	3	main
emantsipeeritud	doc_491521501881_item	2539726	et	4	main
kohati	doc_491521501881_item	2539729	et	4	main
mutt	doc_491521501881_item	2539737	et	3	main
tuules	doc_491521501881_item	2539739	et	3	main
ajaloolisi	doc_491521501881_item	2539754	et	4	main
vahel	doc_491521501881_item	2539759	et	4	main
m	doc_491521501881_item	2539761	et	4	main
avavaid	doc_491521501881_item	2539765	et	4	main
kiiresti	doc_491521501881_item	2539767	et	3	main
inimesed	doc_491521501881_item	2539798	et	3	main
tulla	doc_491521501881_item	2539800	et	3	main
moraalselt	doc_491521501881_item	2539804	et	4	main
riikides	doc_491521501881_item	2539815	et	3	main
umbes	doc_491521501881_item	2539831	et	4	main
sooviksid	doc_491521501881_item	2539838	et	4	main
et	doc_491521501881_item	2539839	et	3	main
nl	doc_491521501881_item	2539840	et	4	main
territooriumitest	doc_491521501881_item	2539846	et	3	main
ja	doc_491521501881_item	2539847	et	3	main
balti	doc_491521501881_item	2539848	et	3	main
riigid	doc_491521501881_item	2539849	et	3	main
sooviksid	doc_491521501881_item	2539850	et	4	main
kirjutas	doc_491521501881_item	2539856	et	3	main
romaane	doc_491521501881_item	2539859	et	3	main
väga	doc_491521501881_item	2539868	et	3	main
filmide	doc_491521501881_item	2539874	et	3	main
eksamitöö	doc_491521501881_item	2539689	et	4	main
a-te	doc_491521501881_item	2539692	et	3	main
öölaulupidude	doc_491521501881_item	2539699	et	4	main
ja	doc_491521501881_item	2539700	et	3	main
hoida	doc_491521501881_item	2539718	et	3	main
oma	doc_491521501881_item	2539728	et	4	main
siseeluga	doc_491521501881_item	2539731	et	3	main
meeserudiit	doc_491521501881_item	2539735	et	3	main
kirjanikud	doc_491521501881_item	2539743	et	3	main
l	doc_491521501881_item	2539745	et	4	main
meri	doc_491521501881_item	2539746	et	3	main
ja	doc_491521501881_item	2539747	et	3	main
tema	doc_491521501881_item	2539748	et	4	main
hõbevalge	doc_491521501881_item	2539749	et	4	main
romaane	doc_491521501881_item	2539755	et	3	main
eriti	doc_491521501881_item	2539756	et	3	main
tol	doc_491521501881_item	2539795	et	3	main
08	doc_491521501881_item	2539812	et	2	main
oli	doc_491521501881_item	2539819	et	3	main
balti	doc_491521501881_item	2539821	et	3	main
oli	doc_491521501881_item	2539825	et	3	main
katkematu	doc_491521501881_item	2539827	et	4	main
laulsid	doc_491521501881_item	2539836	et	4	main
inimesed	doc_491521501881_item	2539837	et	3	main
viidud	doc_491521501881_item	2539844	et	4	main
l	doc_491521501881_item	2539854	et	4	main
1980-ndate	doc_491521501881_item	2539862	et	4	main
aastate	doc_491521501881_item	2539863	et	3	main
lõpul	doc_491521501881_item	2539864	et	3	main
stsenaariumid	doc_491521501881_item	2539873	et	3	main
jaoks	doc_491521501881_item	2539875	et	4	main
üheks	doc_491521501881_item	2539724	et	3	main
naine	doc_491521501881_item	2539727	et	3	main
m	doc_491521501881_item	2539736	et	4	main
olid	doc_491521501881_item	2539741	et	4	main
niisugused	doc_491521501881_item	2539742	et	3	main
j	doc_491521501881_item	2539750	et	4	main
kross	doc_491521501881_item	2539751	et	3	main
katku	doc_491521501881_item	2539758	et	4	main
kasvasid	doc_491521501881_item	2539768	et	4	main
koduraamatukogud	doc_491521501881_item	2539769	et	3	main
sest	doc_491521501881_item	2539770	et	4	main
ramaatu	doc_491521501881_item	2539771	et	4	main
hind	doc_491521501881_item	2539772	et	3	main
oli	doc_491521501881_item	2539773	et	3	main
madal	doc_491521501881_item	2539774	et	3	main
inimestel	doc_491521501881_item	2539775	et	3	main
oli	doc_491521501881_item	2539776	et	3	main
stabiilne	doc_491521501881_item	2539777	et	3	main
huvi	doc_491521501881_item	2539778	et	4	main
professionaalloomingu	doc_491521501881_item	2539779	et	3	main
vastu	doc_491521501881_item	2539780	et	3	main
2	doc_491521501881_item	2539781	et	2	main
1980-ndate	doc_491521501881_item	2539782	et	4	main
a-te	doc_491521501881_item	2539783	et	3	main
lõpul	doc_491521501881_item	2539784	et	3	main
balti	doc_491521501881_item	2539785	et	3	main
riikides	doc_491521501881_item	2539786	et	3	main
hakkasid	doc_491521501881_item	2539787	et	4	main
tekkima	doc_491521501881_item	2539788	et	3	main
iseseisvumisest	doc_491521501881_item	2539790	et	3	main
organiseeritud	doc_491521501881_item	2539793	et	4	main
just	doc_491521501881_item	2539794	et	3	main
lauluväljakule	doc_491521501881_item	2539801	et	3	main
oma	doc_491521501881_item	2539805	et	4	main
valitsusega	doc_491521501881_item	2539806	et	4	main
laulmine	doc_491521501881_item	2539807	et	4	main
oli	doc_491521501881_item	2539808	et	3	main
nagu	doc_491521501881_item	2539809	et	3	main
sümbol	doc_491521501881_item	2539810	et	3	main
23	doc_491521501881_item	2539811	et	2	main
mis	doc_491521501881_item	2539818	et	4	main
nimetatud	doc_491521501881_item	2539820	et	4	main
nendest	doc_491521501881_item	2539845	et	4	main
meri	doc_491521501881_item	2539855	et	3	main
looming	doc_491521501881_item	2539866	et	3	main
oli	doc_491521501881_item	2539867	et	3	main
populaarne	doc_491521501881_item	2539869	et	3	main
kirjutas	doc_491521501881_item	2539871	et	3	main
kelt	doc_491521501881_item	2539824	et	3	main
pea	doc_491521501881_item	2539826	et	4	main
ja	doc_491521501881_item	2539828	et	3	main
selles	doc_491521501881_item	2539829	et	4	main
osales	doc_491521501881_item	2539830	et	3	main
2	doc_491521501881_item	2539832	et	2	main
mln	doc_491521501881_item	2539833	et	4	main
inimest	doc_491521501881_item	2539834	et	3	main
saada	doc_491521501881_item	2539851	et	4	main
taasiseseisvumist	doc_491521501881_item	2539852	et	3	main
palju	doc_491521501881_item	2539857	et	4	main
ajaloolisi	doc_491521501881_item	2539858	et	4	main
eesti	doc_491521501881_item	2539860	et	4	main
ajaloost	doc_491521501881_item	2539861	et	4	main
aastaste	doc_491521501888_item	2541321	et	4	main
õpilaste	doc_491521501888_item	2541325	et	4	main
töödest	doc_491521501888_item	2541327	et	3	main
grupi	doc_491521501888_item	2541334	et	3	main
õpilaste	doc_491521501888_item	2541335	et	4	main
töödest	doc_491521501888_item	2541336	et	3	main
ajavahemikul	doc_491521501888_item	2541337	et	4	main
ema	doc_491521501888_item	2541341	et	4	main
õpilased	doc_491521501888_item	2541343	et	3	main
ortograafiavead	doc_491521501888_item	2541368	et	4	main
eriti	doc_491521501888_item	2541369	et	3	main
välismaiste	doc_491521501888_item	2541370	et	4	main
lõpetanud	doc_491521501888_item	2541324	et	4	main
algajate	doc_491521501888_item	2541333	et	4	main
2001	doc_491521501888_item	2541340	et	2	main
merekooli	doc_491521501888_item	2541342	et	4	main
põhikooli	doc_491521501888_item	2541348	et	4	main
9	doc_491521501888_item	2541349	et	2	main
klassini	doc_491521501888_item	2541350	et	3	main
grupi	doc_491521501888_item	2541351	et	3	main
tase	doc_491521501888_item	2541352	et	3	main
on	doc_491521501888_item	2541353	et	4	main
väga	doc_491521501888_item	2541354	et	3	main
on	doc_491521501888_item	2541358	et	4	main
erinevatest	doc_491521501888_item	2541360	et	4	main
parema	doc_491521501888_item	2541362	et	4	main
keeletasemega	doc_491521501888_item	2541363	et	3	main
õpilastel	doc_491521501888_item	2541364	et	4	main
nimede	doc_491521501888_item	2541371	et	3	main
kirjutamisel	doc_491521501888_item	2541372	et	4	main
bruce	doc_491521501888_item	2541380	et	4	main
cage	doc_491521501888_item	2541385	et	4	main
holliwuud	doc_491521501888_item	2541386	et	4	main
tingitud	doc_491521501888_item	2541390	et	4	main
vene	doc_491521501888_item	2541394	et	4	main
kirjutatakse	doc_491521501888_item	2541396	et	3	main
sama	doc_491521501888_item	2541403	et	4	main
tehtud	doc_491521501888_item	2541404	et	4	main
ka	doc_491521501888_item	2541405	et	3	main
otse	doc_491521501888_item	2541410	et	4	main
tõlgitud	doc_491521501888_item	2541413	et	4	main
nt	doc_491521501888_item	2541415	et	4	main
kolm	doc_491521501888_item	2541416	et	3	main
muskitirs	doc_491521501888_item	2541417	et	4	main
kolm	doc_491521501888_item	2541418	et	3	main
musketäri	doc_491521501888_item	2541419	et	4	main
paljud	doc_491521501888_item	2541420	et	3	main
põhikooli	doc_491521501888_item	2541323	et	4	main
multilingua	doc_491521501888_item	2541330	et	4	main
detsember	doc_491521501888_item	2541339	et	3	main
on	doc_491521501888_item	2541344	et	4	main
keelt	doc_491521501888_item	2541346	et	4	main
kuna	doc_491521501888_item	2541356	et	3	main
tulnud	doc_491521501888_item	2541359	et	4	main
koolidest	doc_491521501888_item	2541361	et	3	main
väikesed	doc_491521501888_item	2541367	et	4	main
miki	doc_491521501888_item	2541374	et	3	main
automaatselt	doc_491521501888_item	2541401	et	4	main
keeles	doc_491521501888_item	2541407	et	4	main
hästi	doc_491521501888_item	2541422	et	3	main
siukest	doc_491521501888_item	2541438	et	4	main
ma	doc_491521501888_item	2541440	et	3	main
tõenäoliselt	doc_491521501888_item	2541447	et	4	main
segiajamist	doc_491521501888_item	2541469	et	4	main
mul	doc_491521501888_item	2541471	et	3	main
toodavad	doc_491521501888_item	2541476	et	4	main
aastaga	doc_491521501888_item	2541478	et	3	main
paremat	doc_491521501888_item	2541480	et	4	main
autot	doc_491521501888_item	2541481	et	3	main
oma	doc_491521501888_item	2541482	et	4	main
teab	doc_491521501888_item	2541491	et	3	main
osastavat	doc_491521501888_item	2541496	et	4	main
kuid	doc_491521501888_item	2541497	et	4	main
saanud	doc_491521501888_item	2541503	et	4	main
analüüs	doc_491521501888_item	2541305	et	3	main
veaanalüüs	doc_491521501888_item	2541306	et	4	main
kontrastiivlingvistika	doc_491521501888_item	2541307	et	4	main
selles	doc_491521501888_item	2541308	et	4	main
töös	doc_491521501888_item	2541309	et	3	main
analüüsitud	doc_491521501888_item	2541310	et	4	main
vead	doc_491521501888_item	2541311	et	4	main
on	doc_491521501888_item	2541312	et	4	main
kogutud	doc_491521501888_item	2541313	et	4	main
eesti	doc_491521501888_item	2541314	et	4	main
mereakadeemia	doc_491521501888_item	2541315	et	4	main
ema	doc_491521501888_item	2541316	et	4	main
merekooli	doc_491521501888_item	2541317	et	4	main
16-	doc_491521501888_item	2541318	et	4	main
kuni	doc_491521501888_item	2541319	et	3	main
18-	doc_491521501888_item	2541320	et	4	main
venekeelse	doc_491521501888_item	2541322	et	3	main
sõnastusõpetuse	doc_491521501888_item	2541326	et	4	main
ning	doc_491521501888_item	2541328	et	3	main
eesti	doc_491521501888_item	2541331	et	4	main
keele	doc_491521501888_item	2541332	et	4	main
november	doc_491521501888_item	2541338	et	3	main
õppinud	doc_491521501888_item	2541347	et	4	main
õpilased	doc_491521501888_item	2541357	et	3	main
rurk	doc_491521501888_item	2541375	et	4	main
rourke	doc_491521501888_item	2541377	et	4	main
keidz	doc_491521501888_item	2541383	et	4	main
emakeele	doc_491521501888_item	2541391	et	4	main
ka	doc_491521501888_item	2541409	et	3	main
keelest	doc_491521501888_item	2541412	et	4	main
nimesid	doc_491521501888_item	2541414	et	3	main
keelt	doc_491521501888_item	2541424	et	4	main
õpilaste	doc_491521501888_item	2541426	et	4	main
on	doc_491521501888_item	2541428	et	4	main
eesti	doc_491521501888_item	2541429	et	4	main
trennis	doc_491521501888_item	2541439	et	3	main
käind	doc_491521501888_item	2541442	et	4	main
kolm	doc_491521501888_item	2541443	et	3	main
aastat	doc_491521501888_item	2541444	et	3	main
tingitud	doc_491521501888_item	2541448	et	4	main
et	doc_491521501888_item	2541454	et	3	main
mida	doc_491521501888_item	2541456	et	4	main
räägitakse	doc_491521501888_item	2541457	et	3	main
sobib	doc_491521501888_item	2541458	et	3	main
ka	doc_491521501888_item	2541459	et	3	main
mitu	doc_491521501888_item	2541473	et	4	main
lemmiknäitlejaid	doc_491521501888_item	2541474	et	3	main
aina	doc_491521501888_item	2541479	et	4	main
ei	doc_491521501888_item	2541498	et	4	main
millal	doc_491521501888_item	2541504	et	3	main
kasutada	doc_491521501888_item	2541505	et	3	main
ainsuse	doc_491521501888_item	2541506	et	4	main
ja	doc_491521501888_item	2541507	et	3	main
ka	doc_491521501888_item	2541521	et	3	main
ära	doc_491521501888_item	2541528	et	4	main
näites	doc_491521501888_item	2541529	et	3	main
mul	doc_491521501888_item	2541530	et	3	main
on	doc_491521501888_item	2541531	et	4	main
mõelda	doc_491521501888_item	2541537	et	4	main
kasutada	doc_491521501888_item	2541541	et	3	main
mitu	doc_491521501888_item	2541543	et	4	main
nt	doc_491521501888_item	2541563	et	4	main
igaühele	doc_491521501888_item	2541564	et	3	main
kas	doc_491521501888_item	2541570	et	3	main
õpilane	doc_491521501888_item	2541571	et	3	main
ei	doc_491521501888_item	2541572	et	4	main
asemel	doc_491521501888_item	2541584	et	4	main
ja	doc_491521501888_item	2541591	et	3	main
mootorataga	doc_491521501888_item	2541601	et	4	main
saab	doc_491521501888_item	2541603	et	3	main
käte	doc_491521501888_item	2541604	et	3	main
eesti	doc_491521501888_item	2541611	et	4	main
keele	doc_491521501888_item	2541612	et	4	main
silme	doc_491521501888_item	2541619	et	4	main
olnud	doc_491521501888_item	2541622	et	4	main
t	doc_491521501888_item	2541643	et	4	main
asemel	doc_491521501888_item	2541645	et	4	main
lõpu	doc_491521501888_item	2541647	et	3	main
kirjutamine	doc_491521501888_item	2541649	et	4	main
selles	doc_491521501888_item	2541658	et	4	main
õpilase	doc_491521501888_item	2541660	et	3	main
ei	doc_491521501888_item	2541662	et	4	main
hästi	doc_491521501888_item	2541664	et	3	main
sõnalõpulist	doc_491521501888_item	2541665	et	4	main
muusikad	doc_491521501888_item	2541674	et	3	main
oma	doc_491521501888_item	2541682	et	4	main
d	doc_491521501888_item	2541690	et	4	main
vaieldav	doc_491521501888_item	2541699	et	4	main
on	doc_491521501888_item	2541706	et	4	main
see	doc_491521501888_item	2541707	et	3	main
võimalik	doc_491521501888_item	2541708	et	3	main
põhistruktuuri	doc_491521501888_item	2541717	et	4	main
erakooli	doc_491521501888_item	2541329	et	4	main
eesti	doc_491521501888_item	2541345	et	4	main
erinev	doc_491521501888_item	2541355	et	4	main
esinevad	doc_491521501888_item	2541365	et	4	main
ainult	doc_491521501888_item	2541366	et	4	main
nt	doc_491521501888_item	2541373	et	4	main
mickey	doc_491521501888_item	2541376	et	4	main
bruss	doc_491521501888_item	2541378	et	4	main
lii	doc_491521501888_item	2541379	et	4	main
nicolas	doc_491521501888_item	2541384	et	4	main
on	doc_491521501888_item	2541389	et	4	main
kuna	doc_491521501888_item	2541393	et	3	main
keeles	doc_491521501888_item	2541395	et	4	main
võõrnimesid	doc_491521501888_item	2541397	et	3	main
häälduse	doc_491521501888_item	2541398	et	4	main
järgi	doc_491521501888_item	2541399	et	4	main
siis	doc_491521501888_item	2541400	et	3	main
eesti	doc_491521501888_item	2541406	et	4	main
vene	doc_491521501888_item	2541411	et	4	main
eesti	doc_491521501888_item	2541423	et	4	main
seas	doc_491521501888_item	2541427	et	4	main
nt	doc_491521501888_item	2541433	et	4	main
ma	doc_491521501888_item	2541434	et	3	main
viga	doc_491521501888_item	2541445	et	4	main
on	doc_491521501888_item	2541446	et	4	main
tekkinud	doc_491521501888_item	2541451	et	4	main
ekslikust	doc_491521501888_item	2541452	et	4	main
tihti	doc_491521501888_item	2541462	et	3	main
ainsuse	doc_491521501888_item	2541465	et	4	main
ja	doc_491521501888_item	2541466	et	3	main
mitmuse	doc_491521501888_item	2541467	et	3	main
osastava	doc_491521501888_item	2541468	et	4	main
on	doc_491521501888_item	2541472	et	4	main
iga	doc_491521501888_item	2541477	et	4	main
jooksul	doc_491521501888_item	2541484	et	4	main
küll	doc_491521501888_item	2541490	et	4	main
vaja	doc_491521501888_item	2541494	et	4	main
veel	doc_491521501888_item	2541500	et	4	main
mitmuse	doc_491521501888_item	2541509	et	3	main
varem	doc_491521501888_item	2541527	et	4	main
ka	doc_491521501888_item	2541536	et	3	main
unustades	doc_491521501888_item	2541546	et	3	main
mitu	doc_491521501888_item	2541548	et	4	main
ainsuse	doc_491521501888_item	2541550	et	4	main
tüüpiline	doc_491521501888_item	2541553	et	3	main
öelda	doc_491521501888_item	2541569	et	4	main
õiget	doc_491521501888_item	2541575	et	3	main
nimetava	doc_491521501888_item	2541580	et	4	main
osastava	doc_491521501888_item	2541592	et	4	main
üsna	doc_491521501888_item	2541594	et	3	main
sagedane	doc_491521501888_item	2541595	et	3	main
nt	doc_491521501888_item	2541600	et	4	main
võivad	doc_491521501888_item	2541609	et	4	main
olla	doc_491521501888_item	2541610	et	3	main
ees	doc_491521501888_item	2541620	et	4	main
mitte	doc_491521501888_item	2541627	et	3	main
sama	doc_491521501888_item	2541629	et	4	main
sõna	doc_491521501888_item	2541630	et	4	main
teine	doc_491521501888_item	2541631	et	3	main
käändevorm	doc_491521501888_item	2541632	et	4	main
õpilastel	doc_491521501888_item	2541639	et	4	main
et	doc_491521501888_item	2541659	et	3	main
d-d	doc_491521501888_item	2541666	et	4	main
ja	doc_491521501888_item	2541667	et	3	main
t-d	doc_491521501888_item	2541668	et	4	main
ning	doc_491521501888_item	2541669	et	3	main
kuna	doc_491521501888_item	2541670	et	3	main
sõnavormid	doc_491521501888_item	2541671	et	3	main
eesti	doc_491521501888_item	2541675	et	4	main
eksisteerivad	doc_491521501888_item	2541677	et	4	main
ja	doc_491521501888_item	2541678	et	3	main
ei	doc_491521501888_item	2541679	et	4	main
lõpud	doc_491521501888_item	2541691	et	3	main
vormi	doc_491521501888_item	2541695	et	4	main
kuid	doc_491521501888_item	2541700	et	4	main
arvata	doc_491521501888_item	2541702	et	4	main
et	doc_491521501888_item	2541703	et	3	main
teatud	doc_491521501888_item	2541704	et	4	main
kontekstis	doc_491521501888_item	2541705	et	3	main
merekooli	doc_491521501888_item	2541712	et	4	main
õpilaste	doc_491521501888_item	2541713	et	4	main
sellist	doc_491521501888_item	2541715	et	4	main
lee	doc_491521501888_item	2541381	et	4	main
nicolaz	doc_491521501888_item	2541382	et	4	main
hollywood	doc_491521501888_item	2541387	et	4	main
viga	doc_491521501888_item	2541388	et	4	main
mõjust	doc_491521501888_item	2541392	et	3	main
on	doc_491521501888_item	2541402	et	4	main
on	doc_491521501888_item	2541408	et	4	main
oskavate	doc_491521501888_item	2541425	et	4	main
mõjul	doc_491521501888_item	2541431	et	4	main
tekkinud	doc_491521501888_item	2541432	et	4	main
tahan	doc_491521501888_item	2541435	et	3	main
endale	doc_491521501888_item	2541436	et	4	main
ka	doc_491521501888_item	2541437	et	3	main
suhtlemisel	doc_491521501888_item	2541450	et	4	main
kirja	doc_491521501888_item	2541460	et	4	main
panna	doc_491521501888_item	2541461	et	4	main
ka	doc_491521501888_item	2541464	et	3	main
nt	doc_491521501888_item	2541470	et	4	main
karjääri	doc_491521501888_item	2541483	et	4	main
filmi	doc_491521501888_item	2541488	et	4	main
õpilane	doc_491521501888_item	2541489	et	3	main
on	doc_491521501888_item	2541493	et	4	main
kasutada	doc_491521501888_item	2541495	et	3	main
päris	doc_491521501888_item	2541501	et	4	main
selgeks	doc_491521501888_item	2541502	et	3	main
sest	doc_491521501888_item	2541523	et	4	main
palju	doc_491521501888_item	2541545	et	4	main
osastavat	doc_491521501888_item	2541551	et	4	main
järgmine	doc_491521501888_item	2541552	et	3	main
eksimuste	doc_491521501888_item	2541554	et	4	main
on	doc_491521501888_item	2541565	et	4	main
teadnud	doc_491521501888_item	2541573	et	4	main
lihtsalt	doc_491521501888_item	2541579	et	4	main
käände	doc_491521501888_item	2541581	et	4	main
eeskujul	doc_491521501888_item	2541582	et	3	main
p	doc_491521501888_item	2541583	et	4	main
segi	doc_491521501888_item	2541589	et	3	main
omastava	doc_491521501888_item	2541590	et	4	main
käände	doc_491521501888_item	2541593	et	4	main
on	doc_491521501888_item	2541596	et	4	main
konsonantühendite	doc_491521501888_item	2541597	et	4	main
vale	doc_491521501888_item	2541598	et	4	main
et	doc_491521501888_item	2541618	et	3	main
nt	doc_491521501888_item	2541626	et	4	main
nt	doc_491521501888_item	2541633	et	4	main
käte	doc_491521501888_item	2541634	et	3	main
peal	doc_491521501888_item	2541635	et	4	main
sagedane	doc_491521501888_item	2541636	et	3	main
viga	doc_491521501888_item	2541637	et	4	main
merekooli	doc_491521501888_item	2541638	et	4	main
osastava	doc_491521501888_item	2541641	et	4	main
lõpu	doc_491521501888_item	2541644	et	3	main
mitmuse	doc_491521501888_item	2541646	et	3	main
d	doc_491521501888_item	2541648	et	4	main
seisneda	doc_491521501888_item	2541657	et	3	main
kõrv	doc_491521501888_item	2541661	et	3	main
erista	doc_491521501888_item	2541663	et	4	main
riiva	doc_491521501888_item	2541680	et	4	main
valinud	doc_491521501888_item	2541688	et	4	main
just	doc_491521501888_item	2541689	et	3	main
muusika	doc_491521501888_item	2541693	et	4	main
julgen	doc_491521501888_item	2541701	et	3	main
esineb	doc_491521501888_item	2541711	et	3	main
seljas	doc_491521501888_item	2541731	et	4	main
on	doc_491521501888_item	2541732	et	4	main
mängib	doc_491521501888_item	2541742	et	3	main
on	doc_491521501888_item	2541752	et	4	main
sõnajärg	doc_491521501888_item	2541753	et	3	main
merekooli	doc_491521501888_item	2541763	et	4	main
eesti	doc_491521501888_item	2541767	et	4	main
vahel	doc_491521501888_item	2541775	et	4	main
lausa	doc_491521501888_item	2541776	et	4	main
kirjutaja	doc_491521501888_item	2541782	et	4	main
bantided	doc_491521501888_item	2541787	et	4	main
ei	doc_491521501888_item	2541791	et	4	main
midagi	doc_491521501888_item	2541792	et	4	main
ei	doc_491521501888_item	2541793	et	4	main
võib	doc_491521501888_item	2541794	et	3	main
et	doc_491521501888_item	2541799	et	3	main
tähendab	doc_491521501888_item	2541801	et	3	main
tasemega	doc_491521501888_item	2541822	et	3	main
tundmine	doc_491521501888_item	2541830	et	4	main
vead	doc_491521501888_item	2541421	et	4	main
kõnekeele	doc_491521501888_item	2541430	et	4	main
olen	doc_491521501888_item	2541441	et	3	main
eestlastega	doc_491521501888_item	2541449	et	4	main
arvamusest	doc_491521501888_item	2541453	et	4	main
kõike	doc_491521501888_item	2541455	et	4	main
esineb	doc_491521501888_item	2541463	et	3	main
nad	doc_491521501888_item	2541475	et	3	main
tegi	doc_491521501888_item	2541485	et	4	main
ta	doc_491521501888_item	2541486	et	4	main
palju	doc_491521501888_item	2541487	et	4	main
kus	doc_491521501888_item	2541492	et	3	main
ole	doc_491521501888_item	2541499	et	4	main
millal	doc_491521501888_item	2541508	et	3	main
vormi	doc_491521501888_item	2541510	et	4	main
sagedamini	doc_491521501888_item	2541511	et	4	main
esineb	doc_491521501888_item	2541512	et	3	main
siiski	doc_491521501888_item	2541513	et	4	main
mitmuse	doc_491521501888_item	2541514	et	3	main
vormi	doc_491521501888_item	2541515	et	4	main
asendamist	doc_491521501888_item	2541516	et	4	main
ainsuse	doc_491521501888_item	2541517	et	4	main
vormiga	doc_491521501888_item	2541518	et	4	main
mis	doc_491521501888_item	2541519	et	4	main
on	doc_491521501888_item	2541520	et	4	main
alati	doc_491521501888_item	2541526	et	4	main
võis	doc_491521501888_item	2541534	et	4	main
õpilane	doc_491521501888_item	2541535	et	3	main
ühtviisi	doc_491521501888_item	2541539	et	3	main
kui	doc_491521501888_item	2541544	et	3	main
koht	doc_491521501888_item	2541555	et	3	main
siin	doc_491521501888_item	2541574	et	4	main
ja	doc_491521501888_item	2541577	et	3	main
b	doc_491521501888_item	2541585	et	4	main
või	doc_491521501888_item	2541586	et	4	main
ajas	doc_491521501888_item	2541587	et	4	main
hoopis	doc_491521501888_item	2541588	et	3	main
ortograafia	doc_491521501888_item	2541599	et	4	main
mittu	doc_491521501888_item	2541602	et	4	main
tekkile	doc_491521501888_item	2541606	et	4	main
vea	doc_491521501888_item	2541607	et	4	main
põhjuseks	doc_491521501888_item	2541608	et	3	main
loogiline	doc_491521501888_item	2541522	et	4	main
ainsus	doc_491521501888_item	2541524	et	4	main
õpitakse	doc_491521501888_item	2541525	et	4	main
mitu	doc_491521501888_item	2541532	et	4	main
lemmiknäitlejaid	doc_491521501888_item	2541533	et	3	main
et	doc_491521501888_item	2541538	et	3	main
saab	doc_491521501888_item	2541540	et	3	main
nii	doc_491521501888_item	2541542	et	3	main
et	doc_491521501888_item	2541547	et	3	main
nõuab	doc_491521501888_item	2541549	et	3	main
tugevamate	doc_491521501888_item	2541556	et	4	main
merekooli	doc_491521501888_item	2541557	et	4	main
õpilaste	doc_491521501888_item	2541558	et	4	main
seas	doc_491521501888_item	2541559	et	4	main
on	doc_491521501888_item	2541560	et	4	main
konsonantide	doc_491521501888_item	2541561	et	3	main
õigekiri	doc_491521501888_item	2541562	et	3	main
vaja	doc_491521501888_item	2541566	et	4	main
sõbra	doc_491521501888_item	2541567	et	3	main
raske	doc_491521501888_item	2541568	et	4	main
väldet	doc_491521501888_item	2541576	et	3	main
kirjutas	doc_491521501888_item	2541578	et	3	main
jooksid	doc_491521501888_item	2541605	et	4	main
välted	doc_491521501888_item	2541613	et	3	main
või	doc_491521501888_item	2541614	et	4	main
ka	doc_491521501888_item	2541615	et	3	main
lihtsalt	doc_491521501888_item	2541616	et	4	main
see	doc_491521501888_item	2541617	et	3	main
voi	doc_491521501888_item	2541628	et	4	main
on	doc_491521501888_item	2541640	et	4	main
võib	doc_491521501888_item	2541656	et	3	main
ilusad	doc_491521501888_item	2541672	et	3	main
silma	doc_491521501888_item	2541681	et	4	main
sõna	doc_491521501888_item	2541692	et	4	main
mitmuse	doc_491521501888_item	2541694	et	3	main
olemasolu	doc_491521501888_item	2541696	et	4	main
on	doc_491521501888_item	2541697	et	4	main
väga	doc_491521501888_item	2541709	et	3	main
seas	doc_491521501888_item	2541714	et	4	main
lause	doc_491521501888_item	2541716	et	4	main
vale	doc_491521501888_item	2541720	et	4	main
tal	doc_491521501888_item	2541730	et	3	main
ta	doc_491521501888_item	2541740	et	4	main
hästi	doc_491521501888_item	2541741	et	3	main
otseselt	doc_491521501888_item	2541745	et	4	main
emakeele	doc_491521501888_item	2541747	et	4	main
eesti	doc_491521501888_item	2541755	et	4	main
keele	doc_491521501888_item	2541756	et	4	main
on	doc_491521501888_item	2541761	et	4	main
töödest	doc_491521501888_item	2541773	et	3	main
aru	doc_491521501888_item	2541778	et	4	main
teda	doc_491521501888_item	2541789	et	4	main
võib	doc_491521501888_item	2541796	et	3	main
bandiidid	doc_491521501888_item	2541802	et	3	main
teda	doc_491521501888_item	2541804	et	4	main
tappa	doc_491521501888_item	2541805	et	4	main
õpilaste	doc_491521501888_item	2541823	et	4	main
seas	doc_491521501888_item	2541824	et	4	main
torkab	doc_491521501888_item	2541825	et	3	main
silma	doc_491521501888_item	2541826	et	4	main
kõige	doc_491521501888_item	2541836	et	4	main
nt	doc_491521501888_item	2541843	et	4	main
lähevad	doc_491521501888_item	2541850	et	3	main
eelviimases	doc_491521501888_item	2541862	et	3	main
ortografiaviga	doc_491521501888_item	2541866	et	4	main
kontsert	doc_491521501888_item	2541868	et	3	main
võib-olla	doc_491521501888_item	2541875	et	3	main
tulevad	doc_491521501888_item	2541879	et	4	main
arvata	doc_491521501888_item	2541914	et	4	main
võib	doc_491521501888_item	2541917	et	3	main
olla	doc_491521501888_item	2541918	et	3	main
on	doc_491521501888_item	2541621	et	4	main
sarnase	doc_491521501888_item	2541623	et	4	main
sõna	doc_491521501888_item	2541624	et	4	main
kirjapilt	doc_491521501888_item	2541625	et	3	main
käände	doc_491521501888_item	2541642	et	4	main
nt	doc_491521501888_item	2541650	et	4	main
nad	doc_491521501888_item	2541651	et	3	main
teevad	doc_491521501888_item	2541652	et	3	main
ilusad	doc_491521501888_item	2541653	et	3	main
muusikad	doc_491521501888_item	2541654	et	3	main
viga	doc_491521501888_item	2541655	et	4	main
ja	doc_491521501888_item	2541673	et	3	main
keeles	doc_491521501888_item	2541676	et	4	main
vale	doc_491521501888_item	2541683	et	4	main
kirjapildiga	doc_491521501888_item	2541684	et	3	main
siis	doc_491521501888_item	2541685	et	3	main
ongi	doc_491521501888_item	2541686	et	4	main
õpilane	doc_491521501888_item	2541687	et	3	main
muidugi	doc_491521501888_item	2541698	et	4	main
tihti	doc_491521501888_item	2541710	et	3	main
nagu	doc_491521501888_item	2541719	et	3	main
nt	doc_491521501888_item	2541723	et	4	main
tal	doc_491521501888_item	2541724	et	3	main
viga	doc_491521501888_item	2541743	et	4	main
tingitud	doc_491521501888_item	2541746	et	4	main
erinev	doc_491521501888_item	2541754	et	4	main
mainitud	doc_491521501888_item	2541760	et	4	main
väga	doc_491521501888_item	2541765	et	3	main
selle	doc_491521501888_item	2541781	et	4	main
tahtnud	doc_491521501888_item	2541784	et	4	main
nt	doc_491521501888_item	2541786	et	4	main
vaid	doc_491521501888_item	2541797	et	3	main
tahtsid	doc_491521501888_item	2541803	et	4	main
viga	doc_491521501888_item	2541718	et	4	main
sõnajärje	doc_491521501888_item	2541721	et	3	main
käes	doc_491521501888_item	2541725	et	4	main
on	doc_491521501888_item	2541726	et	4	main
sõrmus	doc_491521501888_item	2541727	et	3	main
ja	doc_491521501888_item	2541728	et	3	main
kell	doc_491521501888_item	2541729	et	3	main
on	doc_491521501888_item	2541744	et	4	main
keeles	doc_491521501888_item	2541751	et	4	main
omast	doc_491521501888_item	2541757	et	4	main
nagu	doc_491521501888_item	2541758	et	3	main
eespool	doc_491521501888_item	2541759	et	3	main
grupis	doc_491521501888_item	2541764	et	3	main
erinev	doc_491521501888_item	2541766	et	4	main
keele	doc_491521501888_item	2541768	et	4	main
tase	doc_491521501888_item	2541769	et	3	main
kehvema	doc_491521501888_item	2541770	et	4	main
tasemega	doc_491521501888_item	2541771	et	3	main
raske	doc_491521501888_item	2541777	et	4	main
mida	doc_491521501888_item	2541780	et	4	main
tahavad	doc_491521501888_item	2541788	et	3	main
aga	doc_491521501888_item	2541790	et	3	main
oletada	doc_491521501888_item	2541798	et	3	main
ei	doc_491521501888_item	2541808	et	4	main
osastava	doc_491521501888_item	2541827	et	4	main
käände	doc_491521501888_item	2541828	et	4	main
halb	doc_491521501888_item	2541829	et	3	main
osastav	doc_491521501888_item	2541839	et	4	main
kuidas	doc_491521501888_item	2541847	et	3	main
meremehed	doc_491521501888_item	2541849	et	3	main
tema	doc_491521501888_item	2541851	et	4	main
tuleb	doc_491521501888_item	2541853	et	3	main
palju	doc_491521501888_item	2541854	et	4	main
inimesed	doc_491521501888_item	2541855	et	3	main
on	doc_491521501888_item	2541864	et	4	main
on	doc_491521501888_item	2541874	et	4	main
nimi	doc_491521501888_item	2541912	et	3	main
keele	doc_491521501888_item	2541923	et	4	main
õpetusest	doc_491521501888_item	2541924	et	4	main
õpilane	doc_491521501888_item	2541925	et	3	main
keeles	doc_491521501888_item	2541931	et	4	main
kiiresti	doc_491521501888_item	2541939	et	3	main
väljendada	doc_491521501888_item	2541940	et	3	main
esimene	doc_491521501888_item	2541941	et	3	main
vorm	doc_491521501888_item	2541942	et	3	main
mis	doc_491521501888_item	2541943	et	4	main
see	doc_491521501888_item	2541955	et	3	main
on	doc_491521501888_item	2541956	et	4	main
kohakäänete	doc_491521501888_item	2541965	et	3	main
nende	doc_491521501888_item	2541967	et	4	main
nt	doc_491521501888_item	2541973	et	4	main
pildis	doc_491521501888_item	2541975	et	3	main
sellel	doc_491521501888_item	2541978	et	4	main
üsna	doc_491521501888_item	2541987	et	3	main
ja	doc_491521501888_item	2541991	et	3	main
teisel	doc_491521501888_item	2542003	et	4	main
sest	doc_491521501888_item	2542011	et	4	main
vasteteks	doc_491521501888_item	2542016	et	4	main
vene	doc_491521501888_item	2542017	et	4	main
ja	doc_491521501888_item	2542021	et	3	main
nt	doc_491521501888_item	2542034	et	4	main
kui	doc_491521501888_item	2542035	et	3	main
käes	doc_491521501888_item	2542046	et	4	main
isegi	doc_491521501888_item	2542052	et	4	main
hea	doc_491521501888_item	2542053	et	4	main
keeleoskusega	doc_491521501888_item	2542054	et	3	main
inimeste	doc_491521501888_item	2542055	et	3	main
tähenduselt	doc_491521501888_item	2542062	et	4	main
ja	doc_491521501888_item	2542063	et	3	main
ära	doc_491521501888_item	2542078	et	4	main
merele	doc_491521501888_item	2542079	et	3	main
sest	doc_491521501888_item	2542080	et	4	main
on	doc_491521501888_item	2542131	et	4	main
väga	doc_491521501888_item	2542132	et	3	main
erakooli	doc_491521501888_item	2542142	et	4	main
tase	doc_491521501888_item	2542146	et	3	main
neist	doc_491521501888_item	2542149	et	4	main
eestikeelsest	doc_491521501888_item	2542151	et	3	main
kuid	doc_491521501888_item	2542155	et	4	main
ei	doc_491521501888_item	2542157	et	4	main
ilma	doc_491521501888_item	2542159	et	4	main
venekeelsete	doc_491521501888_item	2542160	et	4	main
kasutus	doc_491521501888_item	2541722	et	4	main
must	doc_491521501888_item	2541733	et	4	main
pintsak	doc_491521501888_item	2541734	et	3	main
peened	doc_491521501888_item	2541735	et	3	main
tal	doc_491521501888_item	2541736	et	3	main
on	doc_491521501888_item	2541737	et	4	main
huuled	doc_491521501888_item	2541738	et	3	main
ja	doc_491521501888_item	2541739	et	3	main
mõjust	doc_491521501888_item	2541748	et	3	main
sest	doc_491521501888_item	2541749	et	4	main
vene	doc_491521501888_item	2541750	et	4	main
selles	doc_491521501888_item	2541762	et	4	main
õpilaste	doc_491521501888_item	2541772	et	4	main
on	doc_491521501888_item	2541774	et	4	main
saada	doc_491521501888_item	2541779	et	4	main
on	doc_491521501888_item	2541783	et	4	main
öelda	doc_491521501888_item	2541785	et	4	main
ära	doc_491521501888_item	2541795	et	4	main
see	doc_491521501888_item	2541800	et	3	main
kuid	doc_491521501888_item	2541806	et	4	main
see	doc_491521501888_item	2541807	et	3	main
õnnestunud	doc_491521501888_item	2541809	et	4	main
vmt	doc_491521501888_item	2541810	et	4	main
sellise	doc_491521501888_item	2541811	et	4	main
vea	doc_491521501888_item	2541812	et	4	main
peamiseks	doc_491521501888_item	2541813	et	3	main
põhjuseks	doc_491521501888_item	2541814	et	3	main
on	doc_491521501888_item	2541815	et	4	main
kindlasti	doc_491521501888_item	2541816	et	3	main
halb	doc_491521501888_item	2541817	et	3	main
keeleõpetuse	doc_491521501888_item	2541818	et	3	main
tase	doc_491521501888_item	2541819	et	3	main
põhikoolis	doc_491521501888_item	2541820	et	4	main
kehvema	doc_491521501888_item	2541821	et	4	main
ning	doc_491521501888_item	2541831	et	3	main
oskamatus	doc_491521501888_item	2541832	et	4	main
seda	doc_491521501888_item	2541833	et	3	main
vajadusel	doc_491521501888_item	2541834	et	3	main
kasutada	doc_491521501888_item	2541835	et	3	main
nimetavaga	doc_491521501888_item	2541842	et	4	main
räägib	doc_491521501888_item	2541846	et	3	main
näites	doc_491521501888_item	2541863	et	3	main
sõnast	doc_491521501888_item	2541867	et	4	main
ärajäänud	doc_491521501888_item	2541869	et	4	main
t	doc_491521501888_item	2541870	et	4	main
näol	doc_491521501888_item	2541871	et	4	main
paljud	doc_491521501888_item	2541880	et	3	main
viga	doc_491521501888_item	2541916	et	4	main
tingitud	doc_491521501888_item	2541919	et	4	main
nii	doc_491521501888_item	2541920	et	3	main
eesti	doc_491521501888_item	2541922	et	4	main
soovist	doc_491521501888_item	2541937	et	4	main
nimetavas	doc_491521501888_item	2541948	et	4	main
segiajamisi	doc_491521501888_item	2541966	et	4	main
ja	doc_491521501888_item	2541970	et	3	main
väliskohakäänete	doc_491521501888_item	2541971	et	3	main
on	doc_491521501888_item	2541976	et	4	main
filmil	doc_491521501888_item	2541979	et	3	main
räägitakse	doc_491521501888_item	2541980	et	3	main
et	doc_491521501888_item	2541981	et	3	main
kas	doc_491521501888_item	2541982	et	3	main
sa	doc_491521501888_item	2541983	et	3	main
tihti	doc_491521501888_item	2541988	et	3	main
nii	doc_491521501888_item	2542000	et	3	main
võib	doc_491521501888_item	2542005	et	3	main
tingitud	doc_491521501888_item	2542008	et	4	main
emakeele	doc_491521501888_item	2542009	et	4	main
mõjust	doc_491521501888_item	2542010	et	3	main
sise-	doc_491521501888_item	2542013	et	4	main
keeles	doc_491521501888_item	2542018	et	4	main
sagedamini	doc_491521501888_item	2541837	et	4	main
asendatakse	doc_491521501888_item	2541838	et	3	main
see	doc_491521501888_item	2541844	et	3	main
kaks	doc_491521501888_item	2541848	et	3	main
konserdile	doc_491521501888_item	2541852	et	4	main
mitu	doc_491521501888_item	2541856	et	4	main
aastad	doc_491521501888_item	2541857	et	3	main
sa	doc_491521501888_item	2541858	et	3	main
juba	doc_491521501888_item	2541859	et	3	main
ka	doc_491521501888_item	2541865	et	3	main
ka	doc_491521501888_item	2541876	et	3	main
öelda	doc_491521501888_item	2541878	et	4	main
inimesed	doc_491521501888_item	2541881	et	3	main
ja	doc_491521501888_item	2541882	et	3	main
sellest	doc_491521501888_item	2541883	et	4	main
on	doc_491521501888_item	2541884	et	4	main
tulnud	doc_491521501888_item	2541885	et	4	main
mitmuse	doc_491521501888_item	2541886	et	3	main
nimetava	doc_491521501888_item	2541887	et	4	main
kasutamine	doc_491521501888_item	2541888	et	4	main
ainsuse	doc_491521501888_item	2541889	et	4	main
osastava	doc_491521501888_item	2541890	et	4	main
inimesi	doc_491521501888_item	2541891	et	4	main
asemel	doc_491521501888_item	2541892	et	4	main
näited	doc_491521501888_item	2541893	et	3	main
mul	doc_491521501888_item	2541894	et	3	main
on	doc_491521501888_item	2541895	et	4	main
palju	doc_491521501888_item	2541896	et	4	main
lemmikud	doc_491521501888_item	2541897	et	3	main
filmid	doc_491521501888_item	2541898	et	4	main
mulle	doc_491521501888_item	2541899	et	4	main
meeldib	doc_491521501888_item	2541900	et	3	main
lugeda	doc_491521501888_item	2541901	et	3	main
raamatud	doc_491521501888_item	2541902	et	4	main
tulevikus	doc_491521501888_item	2541903	et	4	main
ma	doc_491521501888_item	2541904	et	3	main
ostan	doc_491521501888_item	2541905	et	3	main
see	doc_491521501888_item	2541906	et	3	main
väga	doc_491521501888_item	2541907	et	3	main
hea	doc_491521501888_item	2541908	et	4	main
auto	doc_491521501888_item	2541909	et	4	main
ainult	doc_491521501888_item	2541910	et	4	main
lihtsalt	doc_491521501888_item	2541840	et	4	main
mitmuse	doc_491521501888_item	2541841	et	3	main
lugu	doc_491521501888_item	2541845	et	4	main
siin	doc_491521501888_item	2541860	et	4	main
töötad	doc_491521501888_item	2541861	et	3	main
samas	doc_491521501888_item	2541872	et	4	main
lauses	doc_491521501888_item	2541873	et	3	main
tahetud	doc_491521501888_item	2541877	et	4	main
et	doc_491521501888_item	2541915	et	3	main
halvast	doc_491521501888_item	2541921	et	3	main
ei	doc_491521501888_item	2541926	et	4	main
osastavat	doc_491521501888_item	2541932	et	4	main
käänet	doc_491521501888_item	2541933	et	3	main
kui	doc_491521501888_item	2541934	et	3	main
ka	doc_491521501888_item	2541935	et	3	main
tavaliselt	doc_491521501888_item	2541944	et	4	main
tuleb	doc_491521501888_item	2541946	et	3	main
kas	doc_491521501888_item	2541954	et	3	main
sise-	doc_491521501888_item	2541969	et	4	main
selles	doc_491521501888_item	2541974	et	4	main
ja	doc_491521501888_item	2541986	et	3	main
sisse-	doc_491521501888_item	2541990	et	4	main
seesütleva	doc_491521501888_item	2541992	et	3	main
laevas	doc_491521501888_item	2541999	et	3	main
kui	doc_491521501888_item	2542002	et	3	main
viga	doc_491521501888_item	2542006	et	4	main
nii	doc_491521501888_item	2542012	et	3	main
kui	doc_491521501888_item	2542014	et	3	main
ja	doc_491521501888_item	2542026	et	3	main
me	doc_491521501888_item	2542036	et	4	main
tormi	doc_491521501888_item	2542045	et	4	main
sõnatasandi	doc_491521501888_item	2542049	et	3	main
esineb	doc_491521501888_item	2542051	et	3	main
on	doc_491521501888_item	2542059	et	4	main
sõnadega	doc_491521501888_item	2542060	et	3	main
mis	doc_491521501888_item	2542061	et	4	main
merele	doc_491521501888_item	2542068	et	3	main
olla	doc_491521501888_item	2542070	et	3	main
tingitud	doc_491521501888_item	2542072	et	4	main
järeldanud	doc_491521501888_item	2542083	et	4	main
väike	doc_491521501888_item	2542121	et	4	main
verbiga	doc_491521501888_item	2542125	et	3	main
hukkuma	doc_491521501888_item	2542126	et	3	main
sarnasus	doc_491521501888_item	2542130	et	4	main
tegusõnaks	doc_491521501888_item	2542140	et	3	main
multilingua	doc_491521501888_item	2542141	et	4	main
algajate	doc_491521501888_item	2542145	et	4	main
selgitusteta	doc_491521501888_item	2542161	et	4	main
üldse	doc_491521501888_item	2542162	et	3	main
kirjatöödes	doc_491521501888_item	2542164	et	3	main
siiski	doc_491521501888_item	2542167	et	4	main
tulema	doc_491521501888_item	2542180	et	4	main
minema	doc_491521501888_item	2542181	et	3	main
ja	doc_491521501888_item	2542191	et	3	main
peame	doc_491521501888_item	2542200	et	4	main
viga	doc_491521501888_item	2542203	et	4	main
üks	doc_491521501888_item	2542221	et	3	main
on	doc_491521501888_item	2542223	et	4	main
sagedased	doc_491521501888_item	2542226	et	3	main
olla	doc_491521501888_item	2542229	et	3	main
ka	doc_491521501888_item	2542230	et	3	main
asjaolu	doc_491521501888_item	2542231	et	4	main
et	doc_491521501888_item	2542232	et	3	main
ei	doc_491521501888_item	2542236	et	4	main
seetõttu	doc_491521501888_item	2542243	et	3	main
inimesed	doc_491521501888_item	2542245	et	3	main
ta	doc_491521501888_item	2542260	et	4	main
vormi	doc_491521501888_item	2542263	et	4	main
võib	doc_491521501888_item	2542268	et	3	main
kõige	doc_491521501888_item	2542271	et	4	main
tüüpilisem	doc_491521501888_item	2542272	et	4	main
ja	doc_491521501888_item	2542273	et	3	main
õpilastel	doc_491521501888_item	2542277	et	4	main
vajaduseta	doc_491521501888_item	2542284	et	3	main
on	doc_491521501888_item	2542288	et	4	main
insenerina	doc_491521501888_item	2542290	et	3	main
nagu	doc_491521501888_item	2542294	et	3	main
sõna	doc_491521501888_item	2542300	et	4	main
side-	doc_491521501888_item	2542308	et	4	main
mida	doc_491521501888_item	2542311	et	4	main
midagi	doc_491521501888_item	2542317	et	4	main
olevat	doc_491521501888_item	2542319	et	4	main
kolm	doc_491521501888_item	2541911	et	3	main
lasevad	doc_491521501888_item	2541913	et	3	main
tea	doc_491521501888_item	2541927	et	4	main
lihtsalt	doc_491521501888_item	2541936	et	4	main
meelde	doc_491521501888_item	2541945	et	3	main
õige	doc_491521501888_item	2541957	et	4	main
või	doc_491521501888_item	2541958	et	4	main
mitte	doc_491521501888_item	2541959	et	3	main
väga	doc_491521501888_item	2541960	et	3	main
sagedasti	doc_491521501888_item	2541961	et	3	main
hulgas	doc_491521501888_item	2541968	et	4	main
äravahetamist	doc_491521501888_item	2541972	et	3	main
meres	doc_491521501888_item	2541985	et	3	main
juures	doc_491521501888_item	2541998	et	4	main
esimesel	doc_491521501888_item	2542001	et	3	main
on	doc_491521501888_item	2542019	et	4	main
ühed	doc_491521501888_item	2542020	et	3	main
mis	doc_491521501888_item	2541928	et	4	main
nõuab	doc_491521501888_item	2541929	et	3	main
eesti	doc_491521501888_item	2541930	et	4	main
ennast	doc_491521501888_item	2541938	et	4	main
on	doc_491521501888_item	2541947	et	4	main
käändes	doc_491521501888_item	2541949	et	3	main
ning	doc_491521501888_item	2541950	et	3	main
ei	doc_491521501888_item	2541951	et	4	main
vaevuta	doc_491521501888_item	2541952	et	3	main
mõtlema	doc_491521501888_item	2541953	et	3	main
esineb	doc_491521501888_item	2541962	et	3	main
õpilaste	doc_491521501888_item	2541963	et	4	main
töödes	doc_491521501888_item	2541964	et	3	main
kujutatud	doc_491521501888_item	2541977	et	4	main
olid	doc_491521501888_item	2541984	et	4	main
ka	doc_491521501888_item	2541989	et	3	main
segiajamist	doc_491521501888_item	2541993	et	4	main
nt	doc_491521501888_item	2541994	et	4	main
lähme	doc_491521501888_item	2541995	et	3	main
minu	doc_491521501888_item	2541996	et	3	main
isa	doc_491521501888_item	2541997	et	4	main
juhul	doc_491521501888_item	2542004	et	3	main
olla	doc_491521501888_item	2542007	et	3	main
väliskohakäänete	doc_491521501888_item	2542015	et	3	main
eessõnad	doc_491521501888_item	2542023	et	3	main
в	doc_491521501888_item	2542025	et	2	main
нa	doc_491521501888_item	2542027	et	2	main
lahkume	doc_491521501888_item	2542037	et	3	main
merele	doc_491521501888_item	2542038	et	3	main
homme	doc_491521501888_item	2542039	et	3	main
ma	doc_491521501888_item	2542040	et	3	main
käin	doc_491521501888_item	2542041	et	3	main
kukkus	doc_491521501888_item	2542047	et	3	main
seas	doc_491521501888_item	2542056	et	4	main
kuna	doc_491521501888_item	2542057	et	3	main
keele	doc_491521501888_item	2542075	et	4	main
fraasist	doc_491521501888_item	2542076	et	3	main
läheme	doc_491521501888_item	2542077	et	3	main
on	doc_491521501888_item	2542082	et	4	main
et	doc_491521501888_item	2542084	et	3	main
suur	doc_491521501888_item	2542133	et	3	main
on	doc_491521501888_item	2542134	et	4	main
õpilane	doc_491521501888_item	2542135	et	3	main
pidanud	doc_491521501888_item	2542136	et	4	main
seda	doc_491521501888_item	2542137	et	3	main
on	doc_491521501888_item	2542144	et	4	main
mõni	doc_491521501888_item	2542156	et	3	main
sarnaseid	doc_491521501888_item	2542168	et	4	main
levinumad	doc_491521501888_item	2542171	et	4	main
vead	doc_491521501888_item	2542172	et	4	main
kõigile	doc_491521501888_item	2542175	et	4	main
käima	doc_491521501888_item	2542182	et	4	main
infinitiivivigu	doc_491521501888_item	2542189	et	4	main
minna	doc_491521501888_item	2542202	et	3	main
sellised	doc_491521501888_item	2542224	et	4	main
eksimised	doc_491521501888_item	2542225	et	4	main
põhjuseks	doc_491521501888_item	2542227	et	3	main
võib	doc_491521501888_item	2542228	et	3	main
takista	doc_491521501888_item	2542237	et	4	main
ning	doc_491521501888_item	2542241	et	3	main
mulje	doc_491521501888_item	2542258	et	4	main
levinum	doc_491521501888_item	2542274	et	4	main
viga	doc_491521501888_item	2542275	et	4	main
multilingua	doc_491521501888_item	2542276	et	4	main
olema	doc_491521501888_item	2542280	et	4	main
pöördevormi	doc_491521501888_item	2542283	et	4	main
ma	doc_491521501888_item	2542287	et	3	main
falle	doc_491521501888_item	2542291	et	4	main
meeldib	doc_491521501888_item	2542293	et	3	main
levinud	doc_491521501888_item	2542299	et	4	main
kasutatakse	doc_491521501888_item	2542312	et	3	main
vea	doc_491521501888_item	2542324	et	4	main
tekkepõhjust	doc_491521501888_item	2542325	et	4	main
olen	doc_491521501888_item	2542326	et	3	main
taolist	doc_491521501888_item	2542327	et	3	main
tendentsi	doc_491521501888_item	2542328	et	4	main
ka	doc_491521501888_item	2542335	et	3	main
selliselt	doc_491521501888_item	2542352	et	4	main
ei	doc_491521501888_item	2542353	et	4	main
tingitud	doc_491521501888_item	2542360	et	4	main
õppinud	doc_491521501888_item	2542373	et	4	main
sündinud	doc_491521501888_item	2542377	et	4	main
kõige	doc_491521501888_item	2542386	et	4	main
on	doc_491521501888_item	2542388	et	4	main
viga	doc_491521501888_item	2542421	et	4	main
olla	doc_491521501888_item	2542423	et	3	main
emakeelest	doc_491521501888_item	2542426	et	4	main
kui	doc_491521501888_item	2542427	et	3	main
ka	doc_491521501888_item	2542428	et	3	main
teise	doc_491521501888_item	2542429	et	4	main
venemaal	doc_491521501888_item	2542435	et	4	main
veel	doc_491521501888_item	2542446	et	4	main
samad	doc_491521501888_item	2542022	et	3	main
esineb	doc_491521501888_item	2542028	et	3	main
ka	doc_491521501888_item	2542029	et	3	main
verbivalikul	doc_491521501888_item	2542033	et	4	main
laev	doc_491521501888_item	2542044	et	3	main
sellist	doc_491521501888_item	2542048	et	4	main
viga	doc_491521501888_item	2542050	et	4	main
tegemist	doc_491521501888_item	2542058	et	4	main
võib	doc_491521501888_item	2542069	et	3	main
ära	doc_491521501888_item	2542085	et	4	main
minema	doc_491521501888_item	2542086	et	3	main
tähendab	doc_491521501888_item	2542087	et	3	main
ju	doc_491521501888_item	2542088	et	3	main
ka	doc_491521501888_item	2542089	et	3	main
lahkuma	doc_491521501888_item	2542090	et	3	main
teine	doc_491521501888_item	2542091	et	3	main
näide	doc_491521501888_item	2542092	et	3	main
on	doc_491521501888_item	2542093	et	4	main
tavaline	doc_491521501888_item	2542094	et	4	main
illustreerimaks	doc_491521501888_item	2542095	et	3	main
eksimisi	doc_491521501888_item	2542096	et	4	main
minema	doc_491521501888_item	2542098	et	3	main
ja	doc_491521501888_item	2542099	et	3	main
verbidega	doc_491521501888_item	2542097	et	3	main
käima	doc_491521501888_item	2542100	et	4	main
õpilane	doc_491521501888_item	2542101	et	3	main
ei	doc_491521501888_item	2542102	et	4	main
ole	doc_491521501888_item	2542103	et	4	main
ära	doc_491521501888_item	2542104	et	4	main
õppinud	doc_491521501888_item	2542105	et	4	main
et	doc_491521501888_item	2542106	et	3	main
käiakse	doc_491521501888_item	2542107	et	3	main
edasi-tagasi	doc_491521501888_item	2542108	et	3	main
ja	doc_491521501888_item	2542109	et	3	main
korduvalt	doc_491521501888_item	2542110	et	4	main
minnakse	doc_491521501888_item	2542111	et	3	main
aga	doc_491521501888_item	2542112	et	3	main
ühe	doc_491521501888_item	2542113	et	4	main
korra	doc_491521501888_item	2542114	et	4	main
javõi	doc_491521501888_item	2542115	et	4	main
tulevikus	doc_491521501888_item	2542116	et	4	main
verbil	doc_491521501888_item	2542117	et	3	main
kukkuma	doc_491521501888_item	2542118	et	3	main
on	doc_491521501888_item	2542119	et	4	main
võib-olla	doc_491521501888_item	2542120	et	3	main
nt	doc_491521501888_item	2542024	et	4	main
v	doc_491521501888_item	2542030	et	4	main
ää	doc_491521501888_item	2542031	et	4	main
ratusi	doc_491521501888_item	2542032	et	4	main
aafrikas	doc_491521501888_item	2542042	et	4	main
meie	doc_491521501888_item	2542043	et	4	main
vormiliselt	doc_491521501888_item	2542064	et	4	main
sarnanevad	doc_491521501888_item	2542065	et	4	main
fraas	doc_491521501888_item	2542066	et	3	main
lahkume	doc_491521501888_item	2542067	et	3	main
ka	doc_491521501888_item	2542071	et	3	main
teisest	doc_491521501888_item	2542073	et	4	main
eesti	doc_491521501888_item	2542074	et	4	main
õpilane	doc_491521501888_item	2542081	et	3	main
sarnasus	doc_491521501888_item	2542124	et	4	main
kuid	doc_491521501888_item	2542127	et	4	main
kuna	doc_491521501888_item	2542128	et	3	main
kõlaline	doc_491521501888_item	2542129	et	4	main
siinkohal	doc_491521501888_item	2542138	et	3	main
sobivaks	doc_491521501888_item	2542139	et	4	main
suurem	doc_491521501888_item	2542147	et	4	main
saab	doc_491521501888_item	2542150	et	3	main
kõnest	doc_491521501888_item	2542152	et	4	main
enam-vähem	doc_491521501888_item	2542153	et	3	main
saa	doc_491521501888_item	2542158	et	4	main
on	doc_491521501888_item	2542173	et	4	main
algtaseme	doc_491521501888_item	2542176	et	3	main
kohakäänetevead	doc_491521501888_item	2542183	et	4	main
õpilastel	doc_491521501888_item	2542186	et	4	main
ma-	doc_491521501888_item	2542190	et	3	main
segiajamine	doc_491521501888_item	2542193	et	4	main
koju	doc_491521501888_item	2542201	et	3	main
infinitiivi	doc_491521501888_item	2542234	et	4	main
arusaamist	doc_491521501888_item	2542238	et	4	main
kõnes	doc_491521501888_item	2542240	et	3	main
eestikeelsed	doc_491521501888_item	2542244	et	3	main
ei	doc_491521501888_item	2542246	et	4	main
selle	doc_491521501888_item	2542248	et	4	main
parandamisele	doc_491521501888_item	2542249	et	4	main
et	doc_491521501888_item	2542259	et	3	main
vale	doc_491521501888_item	2542266	et	4	main
üks	doc_491521501888_item	2542270	et	3	main
töötan	doc_491521501888_item	2542289	et	3	main
viga	doc_491521501888_item	2542297	et	4	main
on	doc_491521501888_item	2542301	et	4	main
õpilaste	doc_491521501888_item	2542303	et	4	main
jaoks	doc_491521501888_item	2542304	et	4	main
alati	doc_491521501888_item	2542313	et	4	main
märganud	doc_491521501888_item	2542329	et	4	main
venelaste	doc_491521501888_item	2542333	et	4	main
arvates	doc_491521501888_item	2542338	et	4	main
saa	doc_491521501888_item	2542340	et	4	main
see	doc_491521501888_item	2542341	et	3	main
kuidagi	doc_491521501888_item	2542342	et	3	main
olla	doc_491521501888_item	2542343	et	3	main
seotud	doc_491521501888_item	2542344	et	4	main
verbi	doc_491521501888_item	2542350	et	4	main
käesoleval	doc_491521501888_item	2542355	et	3	main
võib-olla	doc_491521501888_item	2542359	et	3	main
täismineviku	doc_491521501888_item	2542365	et	3	main
mida	doc_491521501888_item	2542367	et	4	main
selle	doc_491521501888_item	2542369	et	4	main
grupi	doc_491521501888_item	2542370	et	3	main
õpilased	doc_491521501888_item	2542371	et	3	main
on	doc_491521501888_item	2542372	et	4	main
olen	doc_491521501888_item	2542376	et	3	main
jne	doc_491521501888_item	2542384	et	4	main
kuna	doc_491521501888_item	2542385	et	3	main
kaudne	doc_491521501888_item	2542122	et	3	main
tähenduslik	doc_491521501888_item	2542123	et	3	main
õpilastel	doc_491521501888_item	2542143	et	4	main
osa	doc_491521501888_item	2542148	et	4	main
aru	doc_491521501888_item	2542154	et	4	main
teevad	doc_491521501888_item	2542165	et	3	main
vigu	doc_491521501888_item	2542169	et	3	main
omased	doc_491521501888_item	2542174	et	3	main
õpilastele	doc_491521501888_item	2542177	et	4	main
multilingua	doc_491521501888_item	2542185	et	4	main
järgmisi	doc_491521501888_item	2542188	et	3	main
da-tegevusnime	doc_491521501888_item	2542192	et	4	main
nt	doc_491521501888_item	2542194	et	4	main
mulle	doc_491521501888_item	2542195	et	4	main
meeldib	doc_491521501888_item	2542196	et	3	main
telerit	doc_491521501888_item	2542197	et	3	main
vaatama	doc_491521501888_item	2542198	et	3	main
me	doc_491521501888_item	2542199	et	4	main
on	doc_491521501888_item	2542204	et	4	main
tingitud	doc_491521501888_item	2542205	et	4	main
sellest	doc_491521501888_item	2542206	et	4	main
et	doc_491521501888_item	2542207	et	3	main
kahe	doc_491521501888_item	2542208	et	3	main
erineva	doc_491521501888_item	2542209	et	4	main
infinitiivivormi	doc_491521501888_item	2542210	et	4	main
kasutamisväljad	doc_491521501888_item	2542211	et	3	main
ei	doc_491521501888_item	2542212	et	4	main
ole	doc_491521501888_item	2542213	et	4	main
veel	doc_491521501888_item	2542214	et	4	main
kinnistunud	doc_491521501888_item	2542215	et	4	main
kuna	doc_491521501888_item	2542216	et	3	main
õpilaste	doc_491521501888_item	2542217	et	4	main
emakeeles	doc_491521501888_item	2542218	et	4	main
on	doc_491521501888_item	2542219	et	4	main
vaid	doc_491521501888_item	2542220	et	3	main
hakkama	doc_491521501888_item	2542163	et	3	main
nad	doc_491521501888_item	2542166	et	3	main
kõige	doc_491521501888_item	2542170	et	4	main
infinitiivivead	doc_491521501888_item	2542178	et	4	main
verbivalikuvead	doc_491521501888_item	2542179	et	4	main
jm	doc_491521501888_item	2542184	et	4	main
esines	doc_491521501888_item	2542187	et	3	main
infinitiiv	doc_491521501888_item	2542222	et	3	main
kuna	doc_491521501888_item	2542242	et	3	main
pööra	doc_491521501888_item	2542247	et	4	main
õiget	doc_491521501888_item	2542262	et	3	main
hoopis	doc_491521501888_item	2542265	et	3	main
vorm	doc_491521501888_item	2542267	et	3	main
kinnistuda	doc_491521501888_item	2542269	et	3	main
on	doc_491521501888_item	2542278	et	4	main
isiku	doc_491521501888_item	2542282	et	3	main
kasutamine	doc_491521501888_item	2542285	et	4	main
on	doc_491521501888_item	2542292	et	4	main
öeldud	doc_491521501888_item	2542295	et	4	main
on	doc_491521501888_item	2542296	et	4	main
on	doc_491521501888_item	2542305	et	4	main
kui	doc_491521501888_item	2542306	et	3	main
omalaadne	doc_491521501888_item	2542307	et	3	main
parasiitsõna	doc_491521501888_item	2542310	et	4	main
kohas	doc_491521501888_item	2542314	et	4	main
on	doc_491521501888_item	2542321	et	4	main
eesti	doc_491521501888_item	2542330	et	4	main
varem	doc_491521501888_item	2542336	et	4	main
mõjuga	doc_491521501888_item	2542346	et	3	main
sest	doc_491521501888_item	2542347	et	4	main
vene	doc_491521501888_item	2542348	et	4	main
juhul	doc_491521501888_item	2542356	et	3	main
see	doc_491521501888_item	2542358	et	3	main
vormist	doc_491521501888_item	2542366	et	4	main
oled	doc_491521501888_item	2542379	et	3	main
õppetundides	doc_491521501888_item	2542389	et	3	main
võib	doc_491521501888_item	2542422	et	3	main
tingitud	doc_491521501888_item	2542424	et	4	main
nii	doc_491521501888_item	2542425	et	3	main
olen	doc_491521501888_item	2542433	et	3	main
mõjust	doc_491521501888_item	2542436	et	3	main
meeles	doc_491521501888_item	2542439	et	3	main
need	doc_491521501888_item	2542441	et	3	main
tähenduselt	doc_491521501888_item	2542443	et	4	main
küsimusele	doc_491521501888_item	2542453	et	4	main
ma	doc_491521501888_item	2542461	et	3	main
firmal	doc_491521501888_item	2542463	et	3	main
mõju	doc_491521501888_item	2542467	et	4	main
ka	doc_491521501888_item	2542469	et	3	main
õpilasel	doc_491521501888_item	2542472	et	3	main
intuitiivselt	doc_491521501888_item	2542481	et	4	main
kas	doc_491521501888_item	2542483	et	3	main
lõppu	doc_491521501888_item	2542485	et	4	main
tuleb	doc_491521501888_item	2542486	et	3	main
s	doc_491521501888_item	2542487	et	4	main
tunnetus	doc_491521501888_item	2542491	et	4	main
kui	doc_491521501888_item	2542495	et	3	main
on	doc_491521501888_item	2542505	et	4	main
2	doc_491521501888_item	2542507	et	2	main
ja	doc_491521501888_item	2542508	et	3	main
pöördelõpu	doc_491521501888_item	2542511	et	3	main
erinevus	doc_491521501888_item	2542530	et	4	main
sõnalõpul	doc_491521501888_item	2542531	et	3	main
eriti	doc_491521501888_item	2542532	et	3	main
teab	doc_491521501888_item	2542538	et	3	main
harjutustes	doc_491521501888_item	2542545	et	4	main
kõnekasutuses	doc_491521501888_item	2542547	et	4	main
segi	doc_491521501888_item	2542551	et	3	main
kasutab	doc_491521501888_item	2542553	et	3	main
harvemini	doc_491521501888_item	2542555	et	4	main
mina	doc_491521501888_item	2542561	et	4	main
töötad	doc_491521501888_item	2542565	et	3	main
я	doc_491521501888_item	2542601	et	2	main
aga	doc_491521501888_item	2542604	et	3	main
samuti	doc_491521501888_item	2542607	et	3	main
hjäl	doc_491521501888_item	2542615	et	4	main
vene	doc_491521501888_item	2542619	et	4	main
kahe	doc_491521501888_item	2542233	et	3	main
segiajamine	doc_491521501888_item	2542235	et	4	main
nt	doc_491521501888_item	2542239	et	4	main
tähelepanu	doc_491521501888_item	2542250	et	4	main
nt	doc_491521501888_item	2542251	et	4	main
igapäevases	doc_491521501888_item	2542252	et	4	main
suhtluses	doc_491521501888_item	2542253	et	3	main
siis	doc_491521501888_item	2542254	et	3	main
võib	doc_491521501888_item	2542255	et	3	main
õppijal	doc_491521501888_item	2542256	et	4	main
jääda	doc_491521501888_item	2542257	et	4	main
kasutab	doc_491521501888_item	2542261	et	3	main
ning	doc_491521501888_item	2542264	et	3	main
verbi	doc_491521501888_item	2542279	et	4	main
3	doc_491521501888_item	2542281	et	2	main
nt	doc_491521501888_item	2542286	et	4	main
väga	doc_491521501888_item	2542298	et	3	main
nende	doc_491521501888_item	2542302	et	4	main
voi	doc_491521501888_item	2542309	et	4	main
kus	doc_491521501888_item	2542315	et	3	main
tundub	doc_491521501888_item	2542316	et	3	main
puudu	doc_491521501888_item	2542318	et	4	main
raske	doc_491521501888_item	2542320	et	4	main
sellise	doc_491521501888_item	2542323	et	4	main
kõnelevate	doc_491521501888_item	2542332	et	4	main
minu	doc_491521501888_item	2542337	et	3	main
ei	doc_491521501888_item	2542339	et	4	main
keeles	doc_491521501888_item	2542349	et	4	main
kasutata	doc_491521501888_item	2542354	et	3	main
ainukesest	doc_491521501888_item	2542364	et	4	main
multilingua	doc_491521501888_item	2542368	et	4	main
ma	doc_491521501888_item	2542375	et	3	main
sa	doc_491521501888_item	2542378	et	3	main
sündinud	doc_491521501888_item	2542380	et	4	main
on	doc_491521501888_item	2542382	et	4	main
sündinud	doc_491521501888_item	2542383	et	4	main
sagedamini	doc_491521501888_item	2542387	et	4	main
kasutusel	doc_491521501888_item	2542391	et	4	main
tema-pööre	doc_491521501888_item	2542392	et	4	main
siis	doc_491521501888_item	2542393	et	3	main
võib-olla	doc_491521501888_item	2542394	et	3	main
siit	doc_491521501888_item	2542395	et	3	main
on	doc_491521501888_item	2542396	et	4	main
jäänud	doc_491521501888_item	2542397	et	4	main
õpilastele	doc_491521501888_item	2542398	et	4	main
kõrva	doc_491521501888_item	2542399	et	4	main
see	doc_491521501888_item	2542400	et	3	main
salapärane	doc_491521501888_item	2542401	et	4	main
on	doc_491521501888_item	2542402	et	4	main
mis	doc_491521501888_item	2542403	et	4	main
nagu	doc_491521501888_item	2542404	et	3	main
igale	doc_491521501888_item	2542405	et	3	main
poole	doc_491521501888_item	2542406	et	4	main
peaks	doc_491521501888_item	2542407	et	4	main
sobima	doc_491521501888_item	2542408	et	3	main
kohakäänetega	doc_491521501888_item	2542409	et	3	main
eksitavad	doc_491521501888_item	2542410	et	4	main
multilingua	doc_491521501888_item	2542411	et	4	main
õpilased	doc_491521501888_item	2542412	et	3	main
samuti	doc_491521501888_item	2542413	et	3	main
sageli	doc_491521501888_item	2542414	et	3	main
nt	doc_491521501888_item	2542415	et	4	main
ma	doc_491521501888_item	2542416	et	3	main
olen	doc_491521501888_item	2542417	et	3	main
pärit	doc_491521501888_item	2542418	et	3	main
venemaal	doc_491521501888_item	2542419	et	4	main
see	doc_491521501888_item	2542420	et	3	main
sündinud	doc_491521501888_item	2542434	et	4	main
et	doc_491521501888_item	2542440	et	3	main
et	doc_491521501888_item	2542449	et	3	main
pärit	doc_491521501888_item	2542451	et	3	main
kus	doc_491521501888_item	2542459	et	3	main
nii	doc_491521501888_item	2542465	et	3	main
kui	doc_491521501888_item	2542468	et	3	main
seletada	doc_491521501888_item	2542322	et	3	main
keelt	doc_491521501888_item	2542331	et	4	main
juures	doc_491521501888_item	2542334	et	4	main
emakeele	doc_491521501888_item	2542345	et	4	main
olema	doc_491521501888_item	2542351	et	4	main
on	doc_491521501888_item	2542357	et	4	main
ühest	doc_491521501888_item	2542361	et	4	main
ja	doc_491521501888_item	2542362	et	3	main
siiani	doc_491521501888_item	2542363	et	4	main
so	doc_491521501888_item	2542374	et	4	main
ta	doc_491521501888_item	2542381	et	4	main
olnud	doc_491521501888_item	2542390	et	4	main
sarnase	doc_491521501888_item	2542430	et	4	main
fraasi	doc_491521501888_item	2542431	et	4	main
on	doc_491521501888_item	2542438	et	4	main
ära	doc_491521501888_item	2542447	et	4	main
olema	doc_491521501888_item	2542450	et	4	main
vastab	doc_491521501888_item	2542452	et	3	main
samuti	doc_491521501888_item	2542460	et	3	main
töötan	doc_491521501888_item	2542462	et	3	main
emakeele	doc_491521501888_item	2542466	et	4	main
seda	doc_491521501888_item	2542470	et	3	main
ei	doc_491521501888_item	2542473	et	4	main
tekkinud	doc_491521501888_item	2542476	et	4	main
ütleks	doc_491521501888_item	2542482	et	3	main
l	doc_491521501888_item	2542489	et	4	main
selline	doc_491521501888_item	2542490	et	4	main
piisav	doc_491521501888_item	2542498	et	4	main
keele	doc_491521501888_item	2542499	et	4	main
kuulmis-	doc_491521501888_item	2542500	et	3	main
ja	doc_491521501888_item	2542501	et	3	main
kuulamiskogemus	doc_491521501888_item	2542502	et	3	main
sagedane	doc_491521501888_item	2542503	et	3	main
viga	doc_491521501888_item	2542504	et	4	main
äravahetamine	doc_491521501888_item	2542512	et	3	main
nt	doc_491521501888_item	2542513	et	4	main
ma	doc_491521501888_item	2542432	et	3	main
õpilasel	doc_491521501888_item	2542437	et	3	main
kattuvad	doc_491521501888_item	2542442	et	4	main
kuid	doc_491521501888_item	2542444	et	4	main
pole	doc_491521501888_item	2542445	et	3	main
õppinnud	doc_491521501888_item	2542448	et	4	main
kust	doc_491521501888_item	2542454	et	4	main
olema	doc_491521501888_item	2542456	et	4	main
küsimusele	doc_491521501888_item	2542458	et	4	main
näitab	doc_491521501888_item	2542464	et	3	main
ole	doc_491521501888_item	2542474	et	4	main
sellist	doc_491521501888_item	2542477	et	4	main
keelelist	doc_491521501888_item	2542478	et	4	main
sõna	doc_491521501888_item	2542484	et	4	main
tavaliselt	doc_491521501888_item	2542493	et	4	main
siis	doc_491521501888_item	2542494	et	3	main
õpilasel	doc_491521501888_item	2542496	et	3	main
ka	doc_491521501888_item	2542506	et	3	main
3	doc_491521501888_item	2542509	et	2	main
joob	doc_491521501888_item	2542517	et	3	main
kui	doc_491521501888_item	2542518	et	3	main
ta	doc_491521501888_item	2542519	et	4	main
ärkad	doc_491521501888_item	2542520	et	3	main
vea	doc_491521501888_item	2542521	et	4	main
võib	doc_491521501888_item	2542523	et	3	main
d	doc_491521501888_item	2542525	et	4	main
kiire	doc_491521501888_item	2542533	et	4	main
kõne	doc_491521501888_item	2542534	et	4	main
ja	doc_491521501888_item	2542539	et	3	main
õiget	doc_491521501888_item	2542542	et	3	main
viga	doc_491521501888_item	2542559	et	4	main
keeles	doc_491521501888_item	2542589	et	4	main
tahetakse	doc_491521501888_item	2542593	et	4	main
seda	doc_491521501888_item	2542594	et	3	main
hääldada	doc_491521501888_item	2542595	et	3	main
j-ühendina	doc_491521501888_item	2542596	et	3	main
nagu	doc_491521501888_item	2542597	et	3	main
ё	doc_491521501888_item	2542602	et	2	main
õige	doc_491521501888_item	2542606	et	4	main
d	doc_491521501888_item	2542612	et	4	main
ä	doc_491521501888_item	2542616	et	4	main
ka	doc_491521501888_item	2542623	et	3	main
hääldamine	doc_491521501888_item	2542633	et	4	main
sagedaseks	doc_491521501888_item	2542646	et	3	main
täpitähtede	doc_491521501888_item	2542648	et	4	main
ärajätmine	doc_491521501888_item	2542650	et	3	main
kaisin	doc_491521501888_item	2542654	et	4	main
jt	doc_491521501888_item	2542658	et	4	main
õppivale	doc_491521501888_item	2542671	et	4	main
ei	doc_491521501888_item	2542673	et	4	main
ole	doc_491521501888_item	2542674	et	4	main
need	doc_491521501888_item	2542675	et	3	main
täpid	doc_491521501888_item	2542676	et	4	main
nii	doc_491521501888_item	2542677	et	3	main
olulised	doc_491521501888_item	2542678	et	4	main
kui	doc_491521501888_item	2542679	et	3	main
eestlastele	doc_491521501888_item	2542680	et	4	main
palju	doc_491521501888_item	2542697	et	4	main
ilma	doc_491521501888_item	2542704	et	4	main
kõik	doc_491521501888_item	2542707	et	4	main
emakeele	doc_491521501888_item	2542722	et	4	main
ja	doc_491521501888_item	2542455	et	3	main
sündinud	doc_491521501888_item	2542457	et	4	main
veel	doc_491521501888_item	2542475	et	4	main
mis	doc_491521501888_item	2542480	et	4	main
voi	doc_491521501888_item	2542488	et	4	main
tuleb	doc_491521501888_item	2542492	et	3	main
on	doc_491521501888_item	2542497	et	4	main
isiku	doc_491521501888_item	2542510	et	3	main
sa	doc_491521501888_item	2542514	et	3	main
ja	doc_491521501888_item	2542516	et	3	main
hästi	doc_491521501888_item	2542541	et	3	main
pöördelõppu	doc_491521501888_item	2542543	et	4	main
lõpud	doc_491521501888_item	2542549	et	3	main
ning	doc_491521501888_item	2542552	et	3	main
valesti	doc_491521501888_item	2542554	et	3	main
on	doc_491521501888_item	2542556	et	4	main
ka	doc_491521501888_item	2542560	et	3	main
ma	doc_491521501888_item	2542564	et	3	main
vastav	doc_491521501888_item	2542590	et	4	main
häälik	doc_491521501888_item	2542591	et	3	main
puudub	doc_491521501888_item	2542592	et	3	main
keele	doc_491521501888_item	2542599	et	4	main
nt	doc_491521501888_item	2542613	et	4	main
d	doc_491521501888_item	2542617	et	4	main
nt	doc_491521501888_item	2542625	et	4	main
hesti	doc_491521501888_item	2542627	et	4	main
raskusi	doc_491521501888_item	2542628	et	4	main
kolmandavälteliste	doc_491521501888_item	2542631	et	4	main
sõnade	doc_491521501888_item	2542632	et	3	main
õpilaste	doc_491521501888_item	2542643	et	4	main
aitah	doc_491521501888_item	2542653	et	4	main
keelt	doc_491521501888_item	2542670	et	4	main
inimesele	doc_491521501888_item	2542672	et	3	main
prantsuse	doc_491521501888_item	2542689	et	3	main
erinevaid	doc_491521501888_item	2542698	et	4	main
kriipsukesi	doc_491521501888_item	2542699	et	4	main
nendeta	doc_491521501888_item	2542705	et	4	main
ka	doc_491521501888_item	2542728	et	3	main
et	doc_491521501888_item	2542471	et	3	main
tunnetust	doc_491521501888_item	2542479	et	4	main
sööb	doc_491521501888_item	2542515	et	3	main
põhjuseks	doc_491521501888_item	2542522	et	3	main
ja	doc_491521501888_item	2542526	et	3	main
b	doc_491521501888_item	2542527	et	4	main
vähene	doc_491521501888_item	2542528	et	4	main
korral	doc_491521501888_item	2542535	et	4	main
tavaliselt	doc_491521501888_item	2542536	et	4	main
õpilane	doc_491521501888_item	2542537	et	3	main
kuid	doc_491521501888_item	2542544	et	4	main
ja	doc_491521501888_item	2542546	et	3	main
ajab	doc_491521501888_item	2542548	et	3	main
omavahel	doc_491521501888_item	2542550	et	3	main
pöördega	doc_491521501888_item	2542562	et	3	main
nt	doc_491521501888_item	2542563	et	4	main
vene	doc_491521501888_item	2542598	et	4	main
mis	doc_491521501888_item	2542603	et	4	main
pole	doc_491521501888_item	2542605	et	3	main
kiputakse	doc_491521501888_item	2542608	et	3	main
j-ühendina	doc_491521501888_item	2542609	et	3	main
hääldama	doc_491521501888_item	2542610	et	3	main
ä	doc_491521501888_item	2542611	et	4	main
tahetakse	doc_491521501888_item	2542618	et	4	main
keele	doc_491521501888_item	2542620	et	4	main
e-sarnasena	doc_491521501888_item	2542624	et	4	main
hästi	doc_491521501888_item	2542626	et	3	main
ka	doc_491521501888_item	2542630	et	3	main
nt	doc_491521501888_item	2542634	et	4	main
kinno	doc_491521501888_item	2542636	et	3	main
jt	doc_491521501888_item	2542638	et	4	main
nii	doc_491521501888_item	2542639	et	3	main
on	doc_491521501888_item	2542645	et	4	main
nt	doc_491521501888_item	2542651	et	4	main
hooletusvigadega	doc_491521501888_item	2542665	et	4	main
pigem	doc_491521501888_item	2542666	et	3	main
tundub	doc_491521501888_item	2542667	et	3	main
et	doc_491521501888_item	2542668	et	3	main
midagi	doc_491521501888_item	2542685	et	4	main
keelt	doc_491521501888_item	2542690	et	4	main
on	doc_491521501888_item	2542693	et	4	main
neil	doc_491521501888_item	2542694	et	4	main
vaja	doc_491521501888_item	2542695	et	4	main
nii	doc_491521501888_item	2542696	et	3	main
ka	doc_491521501888_item	2542703	et	3	main
on	doc_491521501888_item	2542706	et	4	main
olla	doc_491521501888_item	2542524	et	3	main
kõlaline	doc_491521501888_item	2542529	et	4	main
mäletab	doc_491521501888_item	2542540	et	3	main
esinenud	doc_491521501888_item	2542557	et	4	main
sellist	doc_491521501888_item	2542558	et	4	main
kõige	doc_491521501888_item	2542566	et	4	main
sagedasem	doc_491521501888_item	2542567	et	4	main
hääldusviga	doc_491521501888_item	2542568	et	4	main
multilingua	doc_491521501888_item	2542569	et	4	main
õpilastel	doc_491521501888_item	2542570	et	4	main
tekib	doc_491521501888_item	2542571	et	3	main
ö	doc_491521501888_item	2542572	et	4	main
hääldamisel	doc_491521501888_item	2542573	et	4	main
sööma	doc_491521501888_item	2542575	et	4	main
sõnades	doc_491521501888_item	2542574	et	4	main
ma	doc_491521501888_item	2542576	et	3	main
söön	doc_491521501888_item	2542577	et	3	main
jt	doc_491521501888_item	2542578	et	4	main
hääldub	doc_491521501888_item	2542579	et	3	main
s-i	doc_491521501888_item	2542580	et	4	main
ja	doc_491521501888_item	2542581	et	3	main
ö	doc_491521501888_item	2542582	et	4	main
vahel	doc_491521501888_item	2542583	et	4	main
alati	doc_491521501888_item	2542584	et	4	main
ij	doc_491521501888_item	2542585	et	4	main
sjöma	doc_491521501888_item	2542586	et	4	main
kuna	doc_491521501888_item	2542587	et	3	main
vene	doc_491521501888_item	2542588	et	4	main
ю	doc_491521501888_item	2542600	et	2	main
hääl	doc_491521501888_item	2542614	et	3	main
mõjul	doc_491521501888_item	2542621	et	4	main
tekitab	doc_491521501888_item	2542629	et	3	main
kätte	doc_491521501888_item	2542635	et	4	main
sõpra	doc_491521501888_item	2542637	et	4	main
merekooli	doc_491521501888_item	2542640	et	4	main
kui	doc_491521501888_item	2542641	et	3	main
seas	doc_491521501888_item	2542644	et	4	main
ortograafiaveaks	doc_491521501888_item	2542647	et	4	main
täppide	doc_491521501888_item	2542649	et	3	main
janes	doc_491521501888_item	2542652	et	4	main
nad	doc_491521501888_item	2542656	et	3	main
lahevad	doc_491521501888_item	2542657	et	4	main
raske	doc_491521501888_item	2542659	et	4	main
öelda	doc_491521501888_item	2542660	et	4	main
kas	doc_491521501888_item	2542661	et	3	main
eesti	doc_491521501888_item	2542669	et	4	main
sarnast	doc_491521501888_item	2542686	et	4	main
kui	doc_491521501888_item	2542687	et	3	main
meie	doc_491521501888_item	2542688	et	4	main
milleks	doc_491521501888_item	2542692	et	4	main
ja	doc_491521501888_item	2542700	et	3	main
konksukesi	doc_491521501888_item	2542701	et	4	main
kui	doc_491521501888_item	2542702	et	3	main
eestlaste	doc_491521501888_item	2542729	et	4	main
kõnekeel	doc_491521501888_item	2542730	et	4	main
ning	doc_491521501888_item	2542731	et	3	main
loomulikult	doc_491521501888_item	2542732	et	4	main
halb	doc_491521501888_item	2542733	et	3	main
keeleõpetus	doc_491521501888_item	2542734	et	3	main
javõi	doc_491521501888_item	2542735	et	4	main
õpe	doc_491521501888_item	2542736	et	3	main
hääldada	doc_491521501888_item	2542622	et	3	main
multilingua	doc_491521501888_item	2542642	et	4	main
merel	doc_491521501888_item	2542655	et	3	main
tegu	doc_491521501888_item	2542662	et	4	main
on	doc_491521501888_item	2542663	et	4	main
ainult	doc_491521501888_item	2542664	et	4	main
endile	doc_491521501888_item	2542681	et	4	main
võib-olla	doc_491521501888_item	2542682	et	3	main
mõtlevad	doc_491521501888_item	2542683	et	4	main
nad	doc_491521501888_item	2542684	et	3	main
õppides	doc_491521501888_item	2542691	et	4	main
arusaadav	doc_491521501888_item	2542708	et	4	main
sellest	doc_491521501888_item	2542709	et	4	main
väikesest	doc_491521501888_item	2542710	et	4	main
analüüsist	doc_491521501888_item	2542711	et	3	main
selgus	doc_491521501888_item	2542712	et	4	main
et	doc_491521501888_item	2542713	et	3	main
üsna	doc_491521501888_item	2542714	et	3	main
paljud	doc_491521501888_item	2542715	et	3	main
eesti	doc_491521501888_item	2542716	et	4	main
keele	doc_491521501888_item	2542717	et	4	main
õppijate	doc_491521501888_item	2542718	et	4	main
vead	doc_491521501888_item	2542719	et	4	main
on	doc_491521501888_item	2542720	et	4	main
nende	doc_491521501888_item	2542721	et	4	main
tingitud	doc_491521501888_item	2542724	et	4	main
kuid	doc_491521501888_item	2542725	et	4	main
vigasid	doc_491521501888_item	2542726	et	3	main
põhjustavad	doc_491521501888_item	2542727	et	4	main
mõjust	doc_491521501888_item	2542723	et	3	main
eesti	doc_491521501890_item	2544304	et	4	main
keele	doc_491521501890_item	2544305	et	4	main
veaanalüüs	doc_491521501890_item	2544307	et	4	main
veaanalüüs	doc_491521501890_item	2544300	et	4	main
llinna	doc_491521501890_item	2544302	et	4	main
õppekool	doc_491521501890_item	2544306	et	4	main
alignright	doc_491521501890_item	2544309	et	4	main
stylemargin	doc_491521501890_item	2544311	et	4	main
text-indent	doc_491521501890_item	2544318	et	4	main
langet	doc_491521501890_item	2544322	et	3	main
150	doc_491521501890_item	2544326	et	2	main
span	doc_491521501890_item	2544329	et	4	main
2001	doc_491521501890_item	2544331	et	2	main
kommentaar	doc_491521501890_item	2544332	et	3	main
et	doc_491521501890_item	2544333	et	3	main
mitte-eestlastest	doc_491521501890_item	2544343	et	4	main
keele	doc_491521501890_item	2544346	et	4	main
õpetaja	doc_491521501890_item	2544354	et	4	main
õppeaastal	doc_491521501890_item	2544358	et	3	main
kuna	doc_491521501890_item	2544362	et	3	main
arvutilehekülge	doc_491521501890_item	2544367	et	4	main
kooli	doc_491521501890_item	2544386	et	4	main
keelt	doc_491521501890_item	2544388	et	4	main
ta	doc_491521501890_item	2544390	et	4	main
elab	doc_491521501890_item	2544422	et	3	main
ning	doc_491521501890_item	2544424	et	3	main
arvesse	doc_491521501890_item	2544440	et	4	main
seda	doc_491521501890_item	2544441	et	3	main
võib	doc_491521501890_item	2544449	et	3	main
küllaltki	doc_491521501890_item	2544451	et	4	main
heaks	doc_491521501890_item	2544452	et	4	main
irina	doc_491521501890_item	2544453	et	3	main
kirjalik	doc_491521501890_item	2544460	et	3	main
mis	doc_491521501890_item	2544471	et	4	main
on	doc_491521501890_item	2544510	et	4	main
ta	doc_491521501890_item	2544301	et	4	main
pedagoogikaülikool	doc_491521501890_item	2544303	et	4	main
text-align	doc_491521501890_item	2544316	et	4	main
72pt	doc_491521501890_item	2544319	et	4	main
õpilaste	doc_491521501890_item	2544344	et	4	main
keele	doc_491521501890_item	2544351	et	4	main
käesoleval	doc_491521501890_item	2544357	et	3	main
34	doc_491521501890_item	2544366	et	2	main
õpilase	doc_491521501890_item	2544371	et	3	main
irina	doc_491521501890_item	2544373	et	3	main
õpib	doc_491521501890_item	2544379	et	3	main
ning	doc_491521501890_item	2544383	et	3	main
lõpetab	doc_491521501890_item	2544384	et	3	main
pole	doc_491521501890_item	2544426	et	3	main
asjaolu	doc_491521501890_item	2544442	et	4	main
riigikeele	doc_491521501890_item	2544447	et	4	main
keel	doc_491521501890_item	2544455	et	4	main
nii	doc_491521501890_item	2544456	et	3	main
on	doc_491521501890_item	2544461	et	4	main
rikkalik	doc_491521501890_item	2544462	et	3	main
sõnavara	doc_491521501890_item	2544463	et	4	main
ei	doc_491521501890_item	2544467	et	4	main
ebapiisava	doc_491521501890_item	2544475	et	3	main
muutunud	doc_491521501890_item	2544511	et	4	main
teadlikumaks	doc_491521501890_item	2544512	et	4	main
ning	doc_491521501890_item	2544513	et	3	main
tegelikkuses	doc_491521501890_item	2544521	et	4	main
sellist	doc_491521501890_item	2544523	et	4	main
noori	doc_491521501890_item	2544524	et	3	main
vähem	doc_491521501890_item	2544525	et	4	main
kui	doc_491521501890_item	2544526	et	3	main
kuid	doc_491521501890_item	2544532	et	4	main
väärtust	doc_491521501890_item	2544538	et	4	main
bisnesmenina	doc_491521501890_item	2544546	et	3	main
ei	doc_491521501890_item	2544563	et	4	main
ei	doc_491521501890_item	2544573	et	4	main
tavaline	doc_491521501890_item	2544582	et	4	main
noor	doc_491521501890_item	2544583	et	3	main
ennast	doc_491521501890_item	2544603	et	4	main
seoda	doc_491521501890_item	2544606	et	4	main
tunnevad	doc_491521501890_item	2544608	et	3	main
et	doc_491521501890_item	2544610	et	3	main
mõnes	doc_491521501890_item	2544619	et	3	main
arvavad	doc_491521501890_item	2544627	et	4	main
et	doc_491521501890_item	2544628	et	3	main
vaja	doc_491521501890_item	2544630	et	4	main
keskharidust	doc_491521501890_item	2544631	et	4	main
ei	doc_491521501890_item	2544643	et	4	main
ole	doc_491521501890_item	2544644	et	4	main
vaevata	doc_491521501890_item	2544649	et	4	main
siis	doc_491521501890_item	2544650	et	3	main
õppida	doc_491521501890_item	2544654	et	3	main
kuid	doc_491521501890_item	2544657	et	4	main
inimesed	doc_491521501890_item	2544659	et	3	main
10	doc_491521501890_item	2544666	et	2	main
elanikest	doc_491521501890_item	2544667	et	3	main
elavad	doc_491521501890_item	2544668	et	4	main
materialseteta	doc_491521501890_item	2544669	et	4	main
kuidagi	doc_491521501890_item	2544674	et	3	main
palgale	doc_491521501890_item	2544677	et	3	main
see	doc_491521501890_item	2544710	et	3	main
selguda	doc_491521501890_item	2544712	et	3	main
inimene	doc_491521501890_item	2544714	et	3	main
tööle	doc_491521501890_item	2544716	et	3	main
väga	doc_491521501890_item	2544719	et	3	main
p	doc_491521501890_item	2544308	et	4	main
classmsonormal	doc_491521501890_item	2544310	et	4	main
1872pt	doc_491521501890_item	2544313	et	4	main
432pt	doc_491521501890_item	2544315	et	4	main
right	doc_491521501890_item	2544317	et	4	main
150span	doc_491521501890_item	2544321	et	4	main
stylefont-size	doc_491521501890_item	2544323	et	4	main
12pt	doc_491521501890_item	2544324	et	4	main
letter-spacing	doc_491521501890_item	2544327	et	4	main
01ptev-51	doc_491521501890_item	2544328	et	4	main
eesti	doc_491521501890_item	2544345	et	4	main
eesti	doc_491521501890_item	2544350	et	4	main
kirjutatud	doc_491521501890_item	2544360	et	4	main
veaanalüüsitöö	doc_491521501890_item	2544363	et	4	main
pikkus	doc_491521501890_item	2544364	et	4	main
otsustasin	doc_491521501890_item	2544368	et	3	main
ühe	doc_491521501890_item	2544370	et	4	main
töö	doc_491521501890_item	2544372	et	4	main
õpilane	doc_491521501890_item	2544374	et	3	main
kelle	doc_491521501890_item	2544375	et	4	main
kirjandit	doc_491521501890_item	2544376	et	3	main
ma	doc_491521501890_item	2544377	et	3	main
analüüsisin	doc_491521501890_item	2544378	et	3	main
praegu	doc_491521501890_item	2544380	et	3	main
12	doc_491521501890_item	2544381	et	2	main
klassis	doc_491521501890_item	2544382	et	3	main
eesti	doc_491521501890_item	2544387	et	4	main
ainus	doc_491521501890_item	2544431	et	4	main
koht	doc_491521501890_item	2544432	et	3	main
kus	doc_491521501890_item	2544433	et	3	main
ta	doc_491521501890_item	2544434	et	4	main
eesti	doc_491521501890_item	2544436	et	4	main
keelt	doc_491521501890_item	2544437	et	4	main
oskust	doc_491521501890_item	2544448	et	3	main
pidada	doc_491521501890_item	2544450	et	4	main
eesti	doc_491521501890_item	2544454	et	4	main
ta	doc_491521501890_item	2544466	et	4	main
võivad	doc_491521501890_item	2544472	et	4	main
keeleoskusega	doc_491521501890_item	2544476	et	3	main
segi	doc_491521501890_item	2544477	et	3	main
seega	doc_491521501890_item	2544479	et	4	main
esineb	doc_491521501890_item	2544480	et	3	main
juba	doc_491521501890_item	2544514	et	3	main
teavad	doc_491521501890_item	2544515	et	3	main
kus	doc_491521501890_item	2544516	et	3	main
nad	doc_491521501890_item	2544517	et	3	main
hakkavad	doc_491521501890_item	2544518	et	4	main
selliseid	doc_491521501890_item	2544527	et	4	main
mis	doc_491521501890_item	2544533	et	4	main
vastavata	doc_491521501890_item	2544534	et	4	main
tegevuseta	doc_491521501890_item	2544535	et	4	main
tahab	doc_491521501890_item	2544545	et	3	main
saada	doc_491521501890_item	2544547	et	4	main
pangadirektorina	doc_491521501890_item	2544549	et	3	main
ei	doc_491521501890_item	2544568	et	4	main
nende	doc_491521501890_item	2544570	et	4	main
võimetele	doc_491521501890_item	2544571	et	4	main
tihti	doc_491521501890_item	2544572	et	3	main
ja	doc_491521501890_item	2544580	et	3	main
isegi	doc_491521501890_item	2544581	et	4	main
leppida	doc_491521501890_item	2544586	et	3	main
et	doc_491521501890_item	2544590	et	3	main
ootab	doc_491521501890_item	2544592	et	3	main
neil	doc_491521501890_item	2544614	et	4	main
võimalust	doc_491521501890_item	2544615	et	3	main
head	doc_491521501890_item	2544616	et	4	main
see	doc_491521501890_item	2544621	et	3	main
on	doc_491521501890_item	2544629	et	4	main
koolis	doc_491521501890_item	2544636	et	4	main
lihtsalt	doc_491521501890_item	2544648	et	4	main
parem	doc_491521501890_item	2544653	et	4	main
kõik	doc_491521501890_item	2544658	et	4	main
inimesi	doc_491521501890_item	2544672	et	4	main
kuid	doc_491521501890_item	2544709	et	4	main
võib	doc_491521501890_item	2544711	et	3	main
läheb	doc_491521501890_item	2544715	et	3	main
teisel	doc_491521501890_item	2544742	et	4	main
inimesele	doc_491521501890_item	2544745	et	3	main
saa	doc_491521501890_item	2544754	et	4	main
kahjuks	doc_491521501890_item	2544759	et	4	main
passivne	doc_491521501890_item	2544768	et	4	main
0cm	doc_491521501890_item	2544312	et	4	main
00001pt	doc_491521501890_item	2544314	et	4	main
line-height	doc_491521501890_item	2544320	et	4	main
line-height	doc_491521501890_item	2544325	et	4	main
tallinn	doc_491521501890_item	2544330	et	4	main
teha	doc_491521501890_item	2544334	et	3	main
veaanalüüsi	doc_491521501890_item	2544335	et	4	main
olen	doc_491521501890_item	2544336	et	3	main
otsustanud	doc_491521501890_item	2544337	et	4	main
minna	doc_491521501890_item	2544338	et	3	main
kooli	doc_491521501890_item	2544339	et	4	main
ning	doc_491521501890_item	2544340	et	3	main
uurida	doc_491521501890_item	2544341	et	3	main
sealsete	doc_491521501890_item	2544342	et	4	main
minu	doc_491521501890_item	2544348	et	3	main
endine	doc_491521501890_item	2544349	et	3	main
kui	doc_491521501890_item	2544352	et	3	main
võõrkeele	doc_491521501890_item	2544353	et	4	main
mulle	doc_491521501890_item	2544356	et	4	main
on	doc_491521501890_item	2544365	et	4	main
tänavu	doc_491521501890_item	2544385	et	3	main
õpib	doc_491521501890_item	2544389	et	3	main
oskust	doc_491521501890_item	2544347	et	3	main
andis	doc_491521501890_item	2544355	et	3	main
õppijate	doc_491521501890_item	2544359	et	4	main
kirjandid	doc_491521501890_item	2544361	et	3	main
võtta	doc_491521501890_item	2544369	et	3	main
alates	doc_491521501890_item	2544391	et	3	main
3	doc_491521501890_item	2544392	et	2	main
klassist	doc_491521501890_item	2544393	et	3	main
ning	doc_491521501890_item	2544394	et	3	main
tema	doc_491521501890_item	2544395	et	4	main
emakeeleks	doc_491521501890_item	2544396	et	4	main
on	doc_491521501890_item	2544397	et	4	main
vene	doc_491521501890_item	2544398	et	4	main
keel	doc_491521501890_item	2544399	et	4	main
veel	doc_491521501890_item	2544400	et	4	main
õpib	doc_491521501890_item	2544401	et	3	main
ta	doc_491521501890_item	2544402	et	4	main
inglise	doc_491521501890_item	2544403	et	4	main
keelt	doc_491521501890_item	2544404	et	4	main
tema	doc_491521501890_item	2544405	et	4	main
sõnul	doc_491521501890_item	2544406	et	3	main
tekitab	doc_491521501890_item	2544407	et	3	main
talle	doc_491521501890_item	2544408	et	4	main
suuri	doc_491521501890_item	2544409	et	3	main
raskusi	doc_491521501890_item	2544410	et	4	main
eesti	doc_491521501890_item	2544411	et	4	main
keele	doc_491521501890_item	2544412	et	4	main
grammatika	doc_491521501890_item	2544413	et	4	main
eriti	doc_491521501890_item	2544414	et	3	main
astmevahelduslike	doc_491521501890_item	2544415	et	4	main
sõnade	doc_491521501890_item	2544416	et	3	main
käänamine	doc_491521501890_item	2544417	et	4	main
ja	doc_491521501890_item	2544418	et	3	main
pööramine	doc_491521501890_item	2544419	et	4	main
irinale	doc_491521501890_item	2544420	et	3	main
kes	doc_491521501890_item	2544421	et	4	main
lasnamäel	doc_491521501890_item	2544423	et	3	main
sõpru	doc_491521501890_item	2544428	et	3	main
on	doc_491521501890_item	2544429	et	4	main
kool	doc_491521501890_item	2544430	et	4	main
rääkida	doc_491521501890_item	2544438	et	3	main
võttes	doc_491521501890_item	2544439	et	4	main
tema	doc_491521501890_item	2544446	et	4	main
poolest	doc_491521501890_item	2544464	et	4	main
karda	doc_491521501890_item	2544468	et	4	main
kasutada	doc_491521501890_item	2544469	et	3	main
sõnu	doc_491521501890_item	2544470	et	4	main
tulevikus	doc_491521501890_item	2544519	et	4	main
töötama	doc_491521501890_item	2544520	et	3	main
on	doc_491521501890_item	2544522	et	4	main
on	doc_491521501890_item	2544530	et	4	main
kel	doc_491521501890_item	2544425	et	3	main
eestlastest	doc_491521501890_item	2544427	et	4	main
saab	doc_491521501890_item	2544435	et	3	main
võin	doc_491521501890_item	2544443	et	3	main
öelda	doc_491521501890_item	2544444	et	4	main
et	doc_491521501890_item	2544445	et	3	main
suuline	doc_491521501890_item	2544457	et	4	main
kui	doc_491521501890_item	2544458	et	3	main
ka	doc_491521501890_item	2544459	et	3	main
ja	doc_491521501890_item	2544465	et	3	main
keeletarvitajal	doc_491521501890_item	2544473	et	3	main
eriti	doc_491521501890_item	2544474	et	3	main
minna	doc_491521501890_item	2544478	et	3	main
tal	doc_491521501890_item	2544481	et	3	main
palju	doc_491521501890_item	2544482	et	4	main
paronüümivigu	doc_491521501890_item	2544483	et	4	main
sagedased	doc_491521501890_item	2544484	et	3	main
on	doc_491521501890_item	2544485	et	4	main
tema	doc_491521501890_item	2544486	et	4	main
puhul	doc_491521501890_item	2544487	et	4	main
ortograafilised	doc_491521501890_item	2544488	et	4	main
vead	doc_491521501890_item	2544489	et	4	main
pisut	doc_491521501890_item	2544490	et	3	main
vähem	doc_491521501890_item	2544491	et	4	main
esineb	doc_491521501890_item	2544492	et	3	main
tal	doc_491521501890_item	2544493	et	3	main
morfoloogilisi	doc_491521501890_item	2544494	et	4	main
ning	doc_491521501890_item	2544495	et	3	main
süntaksivigu	doc_491521501890_item	2544496	et	3	main
kirjand	doc_491521501890_item	2544497	et	3	main
mida	doc_491521501890_item	2544498	et	4	main
teha	doc_491521501890_item	2544499	et	3	main
et	doc_491521501890_item	2544500	et	3	main
lootused	doc_491521501890_item	2544501	et	4	main
puruneks	doc_491521501890_item	2544503	et	3	main
ei	doc_491521501890_item	2544502	et	4	main
tänapäeval	doc_491521501890_item	2544504	et	3	main
on	doc_491521501890_item	2544505	et	4	main
levinud	doc_491521501890_item	2544506	et	4	main
arvamus	doc_491521501890_item	2544507	et	3	main
et	doc_491521501890_item	2544508	et	3	main
noored	doc_491521501890_item	2544509	et	3	main
lotused	doc_491521501890_item	2544529	et	4	main
tohi	doc_491521501890_item	2544540	et	4	main
noorele	doc_491521501890_item	2544541	et	3	main
keelata	doc_491521501890_item	2544542	et	4	main
selge	doc_491521501890_item	2544551	et	4	main
enamus	doc_491521501890_item	2544553	et	4	main
inimesi	doc_491521501890_item	2544554	et	4	main
tahab	doc_491521501890_item	2544555	et	3	main
seda	doc_491521501890_item	2544556	et	3	main
mis	doc_491521501890_item	2544557	et	4	main
on	doc_491521501890_item	2544558	et	4	main
populaarne	doc_491521501890_item	2544559	et	3	main
kõrgega	doc_491521501890_item	2544560	et	3	main
haridusega	doc_491521501890_item	2544561	et	3	main
kelle	doc_491521501890_item	2544528	et	4	main
ei	doc_491521501890_item	2544539	et	4	main
ta	doc_491521501890_item	2544544	et	4	main
voi	doc_491521501890_item	2544548	et	4	main
et	doc_491521501890_item	2544552	et	3	main
inimesed	doc_491521501890_item	2544562	et	3	main
taha	doc_491521501890_item	2544564	et	4	main
tööd	doc_491521501890_item	2544566	et	4	main
vasta	doc_491521501890_item	2544569	et	4	main
isegi	doc_491521501890_item	2544578	et	4	main
endale	doc_491521501890_item	2544579	et	4	main
taha	doc_491521501890_item	2544585	et	4	main
ning	doc_491521501890_item	2544588	et	3	main
teda	doc_491521501890_item	2544593	et	4	main
väga	doc_491521501890_item	2544595	et	3	main
kõrgega	doc_491521501890_item	2544597	et	3	main
maksuga	doc_491521501890_item	2544598	et	3	main
ametikoht	doc_491521501890_item	2544599	et	3	main
noored	doc_491521501890_item	2544600	et	3	main
ei	doc_491521501890_item	2544601	et	4	main
ametikooli	doc_491521501890_item	2544611	et	4	main
haridusega	doc_491521501890_item	2544612	et	3	main
pole	doc_491521501890_item	2544613	et	3	main
suured	doc_491521501890_item	2544531	et	3	main
kaotavad	doc_491521501890_item	2544536	et	4	main
igasugust	doc_491521501890_item	2544537	et	3	main
kui	doc_491521501890_item	2544543	et	3	main
on	doc_491521501890_item	2544550	et	4	main
mis	doc_491521501890_item	2544567	et	4	main
noored	doc_491521501890_item	2544575	et	3	main
tegelikke	doc_491521501890_item	2544576	et	3	main
võimeid	doc_491521501890_item	2544577	et	3	main
realsusega	doc_491521501890_item	2544587	et	4	main
loodab	doc_491521501890_item	2544589	et	3	main
kunagi	doc_491521501890_item	2544591	et	3	main
ees	doc_491521501890_item	2544594	et	4	main
huvitav	doc_491521501890_item	2544596	et	4	main
vara	doc_491521501890_item	2544604	et	4	main
hirmu	doc_491521501890_item	2544609	et	4	main
töökohta	doc_491521501890_item	2544617	et	4	main
saada	doc_491521501890_item	2544618	et	4	main
mõttes	doc_491521501890_item	2544620	et	3	main
õige	doc_491521501890_item	2544623	et	4	main
enamus	doc_491521501890_item	2544625	et	4	main
tööandjaid	doc_491521501890_item	2544626	et	3	main
saama	doc_491521501890_item	2544632	et	4	main
kui	doc_491521501890_item	2544633	et	3	main
aga	doc_491521501890_item	2544634	et	3	main
ei	doc_491521501890_item	2544641	et	4	main
oma	doc_491521501890_item	2544646	et	4	main
on	doc_491521501890_item	2544651	et	4	main
mõni	doc_491521501890_item	2544655	et	3	main
ei	doc_491521501890_item	2544660	et	4	main
või	doc_491521501890_item	2544661	et	4	main
suurt	doc_491521501890_item	2544662	et	3	main
hakkama	doc_491521501890_item	2544675	et	3	main
elades	doc_491521501890_item	2544676	et	4	main
kuid	doc_491521501890_item	2544678	et	4	main
mina	doc_491521501890_item	2544679	et	4	main
on	doc_491521501890_item	2544718	et	4	main
et	doc_491521501890_item	2544721	et	3	main
hea	doc_491521501890_item	2544724	et	4	main
valik	doc_491521501890_item	2544736	et	3	main
on	doc_491521501890_item	2544737	et	4	main
kui	doc_491521501890_item	2544738	et	3	main
mitte	doc_491521501890_item	2544743	et	3	main
iga	doc_491521501890_item	2544744	et	4	main
kuid	doc_491521501890_item	2544749	et	4	main
mitte	doc_491521501890_item	2544750	et	3	main
üks	doc_491521501890_item	2544751	et	3	main
inimene	doc_491521501890_item	2544752	et	3	main
kohtadel	doc_491521501890_item	2544758	et	3	main
tea	doc_491521501890_item	2544761	et	4	main
tohi	doc_491521501890_item	2544780	et	4	main
ning	doc_491521501890_item	2544791	et	3	main
lotused	doc_491521501890_item	2544821	et	4	main
võimalik	doc_491521501890_item	2544823	et	3	main
põhjus	doc_491521501890_item	2544824	et	4	main
võimalik	doc_491521501890_item	2544830	et	3	main
ühekordne	doc_491521501890_item	2544841	et	3	main
võimalik	doc_491521501890_item	2544846	et	3	main
sõna	doc_491521501890_item	2544866	et	4	main
loto-	doc_491521501890_item	2544867	et	4	main
лато	doc_491521501890_item	2544868	et	2	main
vene	doc_491521501890_item	2544877	et	4	main
problemideta	doc_491521501890_item	2544887	et	4	main
vead	doc_491521501890_item	2544901	et	4	main
ainsuse	doc_491521501890_item	2544916	et	4	main
sõna	doc_491521501890_item	2544923	et	4	main
kirjapildi	doc_491521501890_item	2544925	et	4	main
kõikil	doc_491521501890_item	2544926	et	4	main
kõ	doc_491521501890_item	2544927	et	4	main
suunas	doc_491521501890_item	2544933	et	4	main
teadnud	doc_491521501890_item	2544937	et	4	main
parem	doc_491521501890_item	2544944	et	4	main
vene	doc_491521501890_item	2544955	et	4	main
keeles	doc_491521501890_item	2544956	et	4	main
специальность	doc_491521501890_item	2544960	et	2	main
saavad	doc_491521501890_item	2544964	et	4	main
osta	doc_491521501890_item	2544966	et	4	main
analoogia	doc_491521501890_item	2544973	et	4	main
kääne	doc_491521501890_item	2544999	et	3	main
muud	doc_491521501890_item	2545005	et	4	main
materialseteta	doc_491521501890_item	2545015	et	4	main
inimesele	doc_491521501890_item	2545039	et	3	main
tegema	doc_491521501890_item	2544565	et	3	main
tunnusta	doc_491521501890_item	2544574	et	4	main
ei	doc_491521501890_item	2544584	et	4	main
taha	doc_491521501890_item	2544602	et	4	main
ametikohaga	doc_491521501890_item	2544605	et	4	main
nad	doc_491521501890_item	2544607	et	3	main
käimine	doc_491521501890_item	2544635	et	4	main
huvita	doc_491521501890_item	2544642	et	4	main
pead	doc_491521501890_item	2544647	et	4	main
amet	doc_491521501890_item	2544656	et	3	main
problemideta	doc_491521501890_item	2544670	et	4	main
saab	doc_491521501890_item	2544673	et	3	main
ühel	doc_491521501890_item	2544740	et	3	main
mitu	doc_491521501890_item	2544747	et	4	main
tegevusvaldkonda	doc_491521501890_item	2544748	et	4	main
olla	doc_491521501890_item	2544755	et	3	main
edukas	doc_491521501890_item	2544756	et	4	main
kõikil	doc_491521501890_item	2544757	et	4	main
ei	doc_491521501890_item	2544760	et	4	main
mida	doc_491521501890_item	2544764	et	4	main
oskavad	doc_491521501890_item	2544766	et	4	main
põhjustab	doc_491521501890_item	2544770	et	3	main
lootuste	doc_491521501890_item	2544772	et	4	main
ennast	doc_491521501890_item	2544781	et	4	main
ta	doc_491521501890_item	2544783	et	4	main
peab	doc_491521501890_item	2544784	et	4	main
selgusele	doc_491521501890_item	2544789	et	4	main
kogemata	doc_491521501890_item	2544825	et	4	main
vene	doc_491521501890_item	2544833	et	4	main
keelega	doc_491521501890_item	2544834	et	3	main
kus	doc_491521501890_item	2544835	et	3	main
jällegi	doc_491521501890_item	2544848	et	4	main
vene	doc_491521501890_item	2544857	et	4	main
põhjus	doc_491521501890_item	2544862	et	4	main
vene	doc_491521501890_item	2544863	et	4	main
keeles	doc_491521501890_item	2544878	et	4	main
esineb	doc_491521501890_item	2544881	et	3	main
silbis	doc_491521501890_item	2544883	et	3	main
keelega	doc_491521501890_item	2544894	et	3	main
realsusega	doc_491521501890_item	2544895	et	4	main
eesti	doc_491521501890_item	2544909	et	4	main
omastavast	doc_491521501890_item	2544917	et	4	main
käändest	doc_491521501890_item	2544918	et	4	main
võimalik	doc_491521501890_item	2544934	et	3	main
sõnatüvi	doc_491521501890_item	2544939	et	3	main
ei	doc_491521501890_item	2544957	et	4	main
käändes	doc_491521501890_item	2544963	et	3	main
hariduse	doc_491521501890_item	2544965	et	3	main
kaotavad	doc_491521501890_item	2544968	et	4	main
sellist	doc_491521501890_item	2544969	et	4	main
käänet	doc_491521501890_item	2544996	et	3	main
paljudel	doc_491521501890_item	2545001	et	3	main
vinitelnõi	doc_491521501890_item	2545003	et	4	main
unustas	doc_491521501890_item	2545020	et	3	main
eesti	doc_491521501890_item	2545021	et	4	main
nelja	doc_491521501890_item	2545023	et	4	main
viimase	doc_491521501890_item	2545024	et	3	main
noored	doc_491521501890_item	2545037	et	3	main
juhuslikult	doc_491521501890_item	2545042	et	4	main
kirjutati	doc_491521501890_item	2545043	et	3	main
rektsioonivead	doc_491521501890_item	2545044	et	4	main
verbirektsioonivead	doc_491521501890_item	2545045	et	4	main
kui	doc_491521501890_item	2545046	et	3	main
ärimeheks	doc_491521501890_item	2545055	et	3	main
pangadirektoriks	doc_491521501890_item	2545057	et	3	main
on	doc_491521501890_item	2545069	et	4	main
elades	doc_491521501890_item	2545072	et	4	main
elades	doc_491521501890_item	2545074	et	4	main
interferentsiveaga	doc_491521501890_item	2545078	et	4	main
kus	doc_491521501890_item	2545079	et	3	main
elades	doc_491521501890_item	2545084	et	4	main
на	doc_491521501890_item	2545087	et	2	main
elan	doc_491521501890_item	2545092	et	3	main
see	doc_491521501890_item	2545101	et	3	main
võimalik	doc_491521501890_item	2545110	et	3	main
moodustusvead	doc_491521501890_item	2545125	et	4	main
taha	doc_491521501890_item	2545127	et	4	main
da-infinitiivi	doc_491521501890_item	2545145	et	4	main
ei	doc_491521501890_item	2545156	et	4	main
ning	doc_491521501890_item	2545163	et	3	main
leksikaalsed	doc_491521501890_item	2545189	et	3	main
on	doc_491521501890_item	2544622	et	4	main
sest	doc_491521501890_item	2544624	et	4	main
on	doc_491521501890_item	2544637	et	4	main
ebameeldiv	doc_491521501890_item	2544638	et	3	main
ja	doc_491521501890_item	2544639	et	3	main
aine	doc_491521501890_item	2544640	et	4	main
vaja	doc_491521501890_item	2544645	et	4	main
kõige	doc_491521501890_item	2544652	et	4	main
palka	doc_491521501890_item	2544663	et	4	main
saada	doc_491521501890_item	2544664	et	4	main
ainult	doc_491521501890_item	2544665	et	4	main
70	doc_491521501890_item	2544671	et	2	main
tean	doc_491521501890_item	2544680	et	3	main
inimesi	doc_491521501890_item	2544681	et	4	main
kes	doc_491521501890_item	2544682	et	4	main
ei	doc_491521501890_item	2544683	et	4	main
saa	doc_491521501890_item	2544684	et	4	main
hakkama	doc_491521501890_item	2544685	et	3	main
nad	doc_491521501890_item	2544686	et	3	main
elavad	doc_491521501890_item	2544687	et	4	main
võlgades	doc_491521501890_item	2544688	et	3	main
mis	doc_491521501890_item	2544689	et	4	main
kogu	doc_491521501890_item	2544690	et	4	main
aeg	doc_491521501890_item	2544691	et	3	main
kasvavad	doc_491521501890_item	2544692	et	4	main
eestis	doc_491521501890_item	2544693	et	3	main
palju	doc_491521501890_item	2544695	et	4	main
kõrgega	doc_491521501890_item	2544696	et	3	main
haridusega	doc_491521501890_item	2544697	et	3	main
inimesi	doc_491521501890_item	2544698	et	4	main
on	doc_491521501890_item	2544694	et	4	main
kuid	doc_491521501890_item	2544699	et	4	main
ka	doc_491521501890_item	2544700	et	3	main
madalaga	doc_491521501890_item	2544701	et	3	main
haridusega	doc_491521501890_item	2544702	et	3	main
span	doc_491521501890_item	2544703	et	4	main
paliu	doc_491521501890_item	2544704	et	4	main
noored	doc_491521501890_item	2544705	et	3	main
saavad	doc_491521501890_item	2544706	et	4	main
hariduse	doc_491521501890_item	2544707	et	3	main
osta	doc_491521501890_item	2544708	et	4	main
kui	doc_491521501890_item	2544713	et	3	main
täna	doc_491521501890_item	2544717	et	4	main
sa	doc_491521501890_item	2544722	et	3	main
suhtleja	doc_491521501890_item	2544725	et	4	main
ning	doc_491521501890_item	2544726	et	3	main
lato	doc_491521501890_item	2544739	et	4	main
ei	doc_491521501890_item	2544753	et	4	main
paljud	doc_491521501890_item	2544762	et	3	main
nad	doc_491521501890_item	2544765	et	3	main
teha	doc_491521501890_item	2544767	et	3	main
öelda	doc_491521501890_item	2544775	et	4	main
inimene	doc_491521501890_item	2544778	et	3	main
soovides	doc_491521501890_item	2544786	et	4	main
aktiivselt	doc_491521501890_item	2544792	et	4	main
ta	doc_491521501890_item	2544795	et	4	main
tehtud	doc_491521501890_item	2544826	et	4	main
sõna	doc_491521501890_item	2544836	et	4	main
материальный	doc_491521501890_item	2544837	et	2	main
4	doc_491521501890_item	2544838	et	2	main
silbis	doc_491521501890_item	2544839	et	3	main
esineb	doc_491521501890_item	2544840	et	3	main
a	doc_491521501890_item	2544842	et	4	main
elukutse	doc_491521501890_item	2544843	et	4	main
valik	doc_491521501890_item	2544844	et	3	main
problemideta	doc_491521501890_item	2544854	et	4	main
võimalik	doc_491521501890_item	2544861	et	3	main
põhjus	doc_491521501890_item	2544876	et	4	main
пассивный	doc_491521501890_item	2544880	et	2	main
materialseteta	doc_491521501890_item	2544886	et	4	main
võimalik	doc_491521501890_item	2544890	et	3	main
analoogia	doc_491521501890_item	2544892	et	4	main
vrd	doc_491521501890_item	2544897	et	4	main
vene	doc_491521501890_item	2544898	et	4	main
реальность	doc_491521501890_item	2544899	et	2	main
astmevaheldusvead	doc_491521501890_item	2544902	et	4	main
rikkad	doc_491521501890_item	2544904	et	4	main
keele	doc_491521501890_item	2544910	et	4	main
nimisõna	doc_491521501890_item	2544911	et	4	main
mitmuse	doc_491521501890_item	2544912	et	3	main
käändevorm	doc_491521501890_item	2544914	et	4	main
moodustatakse	doc_491521501890_item	2544915	et	3	main
võis	doc_491521501890_item	2544919	et	4	main
ig	doc_491521501890_item	2544928	et	4	main
il	doc_491521501890_item	2544929	et	4	main
ei	doc_491521501890_item	2544936	et	4	main
et	doc_491521501890_item	2544938	et	3	main
on	doc_491521501890_item	2544943	et	4	main
on	doc_491521501890_item	2544948	et	4	main
parem	doc_491521501890_item	2544949	et	4	main
õppida	doc_491521501890_item	2544950	et	3	main
kaovad	doc_491521501890_item	2544967	et	3	main
vene	doc_491521501890_item	2544974	et	4	main
osastav	doc_491521501890_item	2544998	et	4	main
tegevuseta	doc_491521501890_item	2545012	et	4	main
põhjus	doc_491521501890_item	2545019	et	4	main
tähtis	doc_491521501890_item	2544720	et	4	main
oleksid	doc_491521501890_item	2544723	et	4	main
ka	doc_491521501890_item	2544727	et	3	main
see	doc_491521501890_item	2544728	et	3	main
et	doc_491521501890_item	2544729	et	3	main
oleksid	doc_491521501890_item	2544730	et	4	main
tööga	doc_491521501890_item	2544731	et	3	main
huvitatud	doc_491521501890_item	2544732	et	4	main
öeldakse	doc_491521501890_item	2544733	et	3	main
et	doc_491521501890_item	2544734	et	3	main
elukutse	doc_491521501890_item	2544735	et	4	main
vedab	doc_491521501890_item	2544741	et	4	main
sobib	doc_491521501890_item	2544746	et	3	main
inimesed	doc_491521501890_item	2544763	et	3	main
unistamine	doc_491521501890_item	2544769	et	4	main
aga	doc_491521501890_item	2544771	et	3	main
tahan	doc_491521501890_item	2544774	et	3	main
et	doc_491521501890_item	2544776	et	3	main
enda	doc_491521501890_item	2544785	et	4	main
tegelema	doc_491521501890_item	2544793	et	3	main
kui	doc_491521501890_item	2544794	et	3	main
püstitab	doc_491521501890_item	2544796	et	3	main
eesmärke	doc_491521501890_item	2544798	et	4	main
ja	doc_491521501890_item	2544799	et	3	main
liikub	doc_491521501890_item	2544800	et	4	main
suundas	doc_491521501890_item	2544802	et	4	main
võib	doc_491521501890_item	2544803	et	3	main
kindel	doc_491521501890_item	2544804	et	3	main
olema	doc_491521501890_item	2544805	et	4	main
et	doc_491521501890_item	2544806	et	3	main
tema	doc_491521501890_item	2544807	et	4	main
lootused	doc_491521501890_item	2544808	et	4	main
ei	doc_491521501890_item	2544809	et	4	main
purune	doc_491521501890_item	2544810	et	4	main
vigade	doc_491521501890_item	2544811	et	3	main
rühmitamine	doc_491521501890_item	2544812	et	4	main
ning	doc_491521501890_item	2544813	et	3	main
nende	doc_491521501890_item	2544814	et	4	main
võimalike	doc_491521501890_item	2544815	et	4	main
põhjuste	doc_491521501890_item	2544816	et	3	main
seletamine	doc_491521501890_item	2544817	et	4	main
ortograafilised	doc_491521501890_item	2544818	et	4	main
vead	doc_491521501890_item	2544819	et	4	main
õigekirjavead	doc_491521501890_item	2544820	et	3	main
purunemist	doc_491521501890_item	2544773	et	4	main
noor	doc_491521501890_item	2544777	et	3	main
ei	doc_491521501890_item	2544779	et	4	main
alahinnata	doc_491521501890_item	2544782	et	4	main
ja	doc_491521501890_item	2544787	et	3	main
oskustes	doc_491521501890_item	2544788	et	3	main
jõuda	doc_491521501890_item	2544790	et	3	main
reaalseid	doc_491521501890_item	2544797	et	3	main
nende	doc_491521501890_item	2544801	et	4	main
viga	doc_491521501890_item	2544827	et	4	main
materialsete	doc_491521501890_item	2544828	et	4	main
materiaalsete	doc_491521501890_item	2544829	et	4	main
probleemideta	doc_491521501890_item	2544855	et	3	main
vrd	doc_491521501890_item	2544856	et	4	main
проблема	doc_491521501890_item	2544858	et	2	main
lato	doc_491521501890_item	2544859	et	4	main
passivne	doc_491521501890_item	2544873	et	4	main
passiivne	doc_491521501890_item	2544874	et	3	main
võimalik	doc_491521501890_item	2544875	et	3	main
u	doc_491521501890_item	2544885	et	4	main
materiaalsete	doc_491521501890_item	2544888	et	4	main
põhjus	doc_491521501890_item	2544891	et	4	main
vene	doc_491521501890_item	2544893	et	4	main
morfoloogilised	doc_491521501890_item	2544900	et	4	main
rikad	doc_491521501890_item	2544903	et	4	main
vanemad	doc_491521501890_item	2544905	et	4	main
võimalik	doc_491521501890_item	2544906	et	3	main
lootused	doc_491521501890_item	2544822	et	4	main
põhjus	doc_491521501890_item	2544831	et	4	main
analoogia	doc_491521501890_item	2544832	et	4	main
elukutsevalik	doc_491521501890_item	2544845	et	3	main
põhjus	doc_491521501890_item	2544847	et	4	main
analoogia	doc_491521501890_item	2544849	et	4	main
vene	doc_491521501890_item	2544850	et	4	main
keelega	doc_491521501890_item	2544851	et	3	main
выбор	doc_491521501890_item	2544852	et	2	main
профессии	doc_491521501890_item	2544853	et	2	main
loto	doc_491521501890_item	2544860	et	4	main
keeles	doc_491521501890_item	2544864	et	4	main
hääldatakse	doc_491521501890_item	2544865	et	3	main
nt	doc_491521501890_item	2544869	et	4	main
выиграл	doc_491521501890_item	2544870	et	2	main
в	doc_491521501890_item	2544871	et	2	main
лато	doc_491521501890_item	2544872	et	2	main
sõnas	doc_491521501890_item	2544879	et	4	main
teises	doc_491521501890_item	2544882	et	4	main
ühekordne	doc_491521501890_item	2544884	et	3	main
probleemideta	doc_491521501890_item	2544889	et	3	main
reaalsusega	doc_491521501890_item	2544896	et	4	main
põhjus	doc_491521501890_item	2544907	et	4	main
kuna	doc_491521501890_item	2544908	et	3	main
nimetava	doc_491521501890_item	2544913	et	4	main
õpilane	doc_491521501890_item	2544920	et	3	main
unustada	doc_491521501890_item	2544921	et	3	main
põhjus	doc_491521501890_item	2544935	et	4	main
objektivead	doc_491521501890_item	2544941	et	4	main
mõni	doc_491521501890_item	2544946	et	3	main
mõnda	doc_491521501890_item	2544951	et	4	main
ametit	doc_491521501890_item	2544952	et	3	main
võimalik	doc_491521501890_item	2544953	et	3	main
põhjus	doc_491521501890_item	2544954	et	4	main
sõna	doc_491521501890_item	2544959	et	4	main
kirjapilt	doc_491521501890_item	2544961	et	3	main
väärtust	doc_491521501890_item	2544970	et	4	main
venelastel	doc_491521501890_item	2545002	et	4	main
käändega	doc_491521501890_item	2545004	et	3	main
käändevead	doc_491521501890_item	2545006	et	4	main
madalaga	doc_491521501890_item	2545007	et	3	main
palgaga	doc_491521501890_item	2545008	et	3	main
madala	doc_491521501890_item	2545009	et	3	main
palgaga	doc_491521501890_item	2545010	et	3	main
vastavata	doc_491521501890_item	2545011	et	4	main
materiaalsete	doc_491521501890_item	2545016	et	4	main
probleemideta	doc_491521501890_item	2545017	et	3	main
võimalik	doc_491521501890_item	2545018	et	3	main
keele	doc_491521501890_item	2545022	et	4	main
käände	doc_491521501890_item	2545025	et	4	main
reeglid	doc_491521501890_item	2545026	et	3	main
põhjus	doc_491521501890_item	2545033	et	4	main
iga	doc_491521501890_item	2545038	et	4	main
põhjus	doc_491521501890_item	2545041	et	4	main
bisnesmenina	doc_491521501890_item	2545049	et	3	main
saada	doc_491521501890_item	2545054	et	4	main
või	doc_491521501890_item	2545056	et	4	main
ilmselt	doc_491521501890_item	2545058	et	4	main
olevas	doc_491521501890_item	2545070	et	4	main
palgale	doc_491521501890_item	2545073	et	3	main
keeles	doc_491521501890_item	2545081	et	4	main
huvitatud	doc_491521501890_item	2545099	et	4	main
kooliskäimine	doc_491521501890_item	2545109	et	4	main
on	doc_491521501890_item	2545113	et	4	main
kuhu	doc_491521501890_item	2545123	et	3	main
seoda	doc_491521501890_item	2545129	et	4	main
põhjus	doc_491521501890_item	2545132	et	4	main
võis	doc_491521501890_item	2545134	et	4	main
verbi	doc_491521501890_item	2545137	et	4	main
esimese	doc_491521501890_item	2545138	et	3	main
isiku	doc_491521501890_item	2545139	et	3	main
ennast	doc_491521501890_item	2545149	et	4	main
ühel	doc_491521501890_item	2545150	et	3	main
vedab	doc_491521501890_item	2545151	et	4	main
ühel	doc_491521501890_item	2545152	et	3	main
veab	doc_491521501890_item	2545153	et	3	main
võimalik	doc_491521501890_item	2545154	et	3	main
sõna	doc_491521501890_item	2545160	et	4	main
tüvi	doc_491521501890_item	2545161	et	3	main
selle	doc_491521501890_item	2544922	et	4	main
genitiivikäände	doc_491521501890_item	2544924	et	4	main
liikub	doc_491521501890_item	2544930	et	4	main
liigub	doc_491521501890_item	2544931	et	3	main
suundas	doc_491521501890_item	2544932	et	4	main
muutub	doc_491521501890_item	2544940	et	3	main
siis	doc_491521501890_item	2544942	et	3	main
õppida	doc_491521501890_item	2544945	et	3	main
amet	doc_491521501890_item	2544947	et	3	main
muutu	doc_491521501890_item	2544958	et	4	main
винительный	doc_491521501890_item	2544962	et	2	main
võimalik	doc_491521501890_item	2544971	et	3	main
põhjus	doc_491521501890_item	2544972	et	4	main
keelega	doc_491521501890_item	2544975	et	3	main
objekt	doc_491521501890_item	2544976	et	3	main
vene	doc_491521501890_item	2544977	et	4	main
keeles	doc_491521501890_item	2544978	et	4	main
esineb	doc_491521501890_item	2544979	et	3	main
alati	doc_491521501890_item	2544980	et	4	main
винительный	doc_491521501890_item	2544981	et	2	main
käändes	doc_491521501890_item	2544982	et	3	main
mis	doc_491521501890_item	2544983	et	4	main
vastab	doc_491521501890_item	2544984	et	3	main
küsimusele	doc_491521501890_item	2544985	et	4	main
кого	doc_491521501890_item	2544986	et	2	main
что	doc_491521501890_item	2544987	et	2	main
keda	doc_491521501890_item	2544988	et	4	main
mida	doc_491521501890_item	2544989	et	4	main
venelased	doc_491521501890_item	2544990	et	3	main
arvavadki	doc_491521501890_item	2544991	et	4	main
et	doc_491521501890_item	2544992	et	3	main
tuleb	doc_491521501890_item	2544993	et	3	main
kasutada	doc_491521501890_item	2544994	et	3	main
osastavat	doc_491521501890_item	2544995	et	4	main
just	doc_491521501890_item	2544997	et	3	main
assotsieerub	doc_491521501890_item	2545000	et	3	main
vastava	doc_491521501890_item	2545013	et	4	main
tegevuseta	doc_491521501890_item	2545014	et	4	main
ühildumisvead	doc_491521501890_item	2545027	et	4	main
on	doc_491521501890_item	2545028	et	4	main
kogemata	doc_491521501890_item	2545034	et	4	main
kirjutati	doc_491521501890_item	2545035	et	3	main
palju	doc_491521501890_item	2545036	et	4	main
on	doc_491521501890_item	2545059	et	4	main
irina	doc_491521501890_item	2545060	et	3	main
kuulnud	doc_491521501890_item	2545061	et	4	main
sageli	doc_491521501890_item	2545062	et	3	main
väljendit	doc_491521501890_item	2545063	et	3	main
ma	doc_491521501890_item	2545064	et	3	main
töötan	doc_491521501890_item	2545065	et	3	main
nt	doc_491521501890_item	2545066	et	4	main
direktorina	doc_491521501890_item	2545067	et	3	main
käändes	doc_491521501890_item	2545071	et	3	main
palgast	doc_491521501890_item	2545075	et	4	main
tegemist	doc_491521501890_item	2545076	et	4	main
vene	doc_491521501890_item	2545080	et	4	main
vastab	doc_491521501890_item	2545082	et	3	main
palgast	doc_491521501890_item	2545085	et	4	main
зарплату	doc_491521501890_item	2545088	et	2	main
palgale	doc_491521501890_item	2545093	et	3	main
või	doc_491521501890_item	2545094	et	4	main
palga	doc_491521501890_item	2545095	et	3	main
peale	doc_491521501890_item	2545096	et	4	main
on	doc_491521501890_item	2545102	et	4	main
vrd	doc_491521501890_item	2545116	et	4	main
хождение	doc_491521501890_item	2545117	et	2	main
в	doc_491521501890_item	2545118	et	2	main
школу	doc_491521501890_item	2545119	et	2	main
sellist	doc_491521501890_item	2545029	et	4	main
selliseid	doc_491521501890_item	2545030	et	4	main
noori	doc_491521501890_item	2545031	et	3	main
võimalik	doc_491521501890_item	2545032	et	3	main
võimalik	doc_491521501890_item	2545040	et	3	main
ta	doc_491521501890_item	2545047	et	4	main
tahab	doc_491521501890_item	2545048	et	3	main
saada	doc_491521501890_item	2545050	et	4	main
kui	doc_491521501890_item	2545051	et	3	main
tahab	doc_491521501890_item	2545053	et	3	main
mis	doc_491521501890_item	2545068	et	4	main
on	doc_491521501890_item	2545077	et	4	main
tööst	doc_491521501890_item	2545100	et	3	main
interferentsiviga	doc_491521501890_item	2545104	et	4	main
rektsioon	doc_491521501890_item	2545106	et	3	main
põhjus	doc_491521501890_item	2545111	et	4	main
interferentsiviga	doc_491521501890_item	2545115	et	4	main
vastab	doc_491521501890_item	2545120	et	3	main
verbivormide	doc_491521501890_item	2545124	et	4	main
siduda	doc_491521501890_item	2545130	et	3	main
võimalik	doc_491521501890_item	2545131	et	3	main
õpilane	doc_491521501890_item	2545133	et	3	main
teada	doc_491521501890_item	2545135	et	3	main
alusel	doc_491521501890_item	2545143	et	4	main
ennast-	doc_491521501890_item	2545147	et	4	main
seoda	doc_491521501890_item	2545148	et	4	main
põhjus	doc_491521501890_item	2545155	et	4	main
muutub	doc_491521501890_item	2545162	et	3	main
mainfinitiivist	doc_491521501890_item	2545166	et	4	main
väärtust	doc_491521501890_item	2545194	et	4	main
kaotavad	doc_491521501890_item	2545195	et	4	main
igasuguse	doc_491521501890_item	2545196	et	3	main
väärtuse	doc_491521501890_item	2545197	et	3	main
enamus	doc_491521501890_item	2545202	et	4	main
tegutsema	doc_491521501890_item	2545207	et	3	main
kõlaline	doc_491521501890_item	2545215	et	4	main
sarnasus	doc_491521501890_item	2545216	et	4	main
keeles	doc_491521501890_item	2545242	et	4	main
süntaksivead	doc_491521501890_item	2545261	et	3	main
inimesed	doc_491521501890_item	2545266	et	3	main
kõrgharidusega	doc_491521501890_item	2545271	et	3	main
inimesed	doc_491521501890_item	2545272	et	3	main
ei	doc_491521501890_item	2545273	et	4	main
on	doc_491521501890_item	2545280	et	4	main
kui	doc_491521501890_item	2545287	et	3	main
käimine	doc_491521501890_item	2545289	et	4	main
aga	doc_491521501890_item	2545294	et	3	main
on	doc_491521501890_item	2545296	et	4	main
interferentsivead	doc_491521501890_item	2545322	et	4	main
ta	doc_491521501890_item	2545052	et	4	main
väljendile	doc_491521501890_item	2545083	et	3	main
живя	doc_491521501890_item	2545086	et	2	main
mida	doc_491521501890_item	2545089	et	4	main
venelased	doc_491521501890_item	2545090	et	3	main
õlgivad	doc_491521501890_item	2545091	et	3	main
oleksid	doc_491521501890_item	2545097	et	4	main
tööga	doc_491521501890_item	2545098	et	3	main
samuti	doc_491521501890_item	2545103	et	3	main
nimisõna	doc_491521501890_item	2545105	et	4	main
käimine	doc_491521501890_item	2545107	et	4	main
kooli	doc_491521501890_item	2545108	et	4	main
ilmselt	doc_491521501890_item	2545112	et	4	main
see	doc_491521501890_item	2545114	et	3	main
куда	doc_491521501890_item	2545122	et	2	main
ennast	doc_491521501890_item	2545128	et	4	main
pöördevormi	doc_491521501890_item	2545140	et	4	main
ning	doc_491521501890_item	2545141	et	3	main
selle	doc_491521501890_item	2545142	et	4	main
seon	doc_491521501890_item	2545146	et	3	main
moodustas	doc_491521501890_item	2545164	et	3	main
enamus	doc_491521501890_item	2545198	et	4	main
inimesi	doc_491521501890_item	2545199	et	4	main
enamik	doc_491521501890_item	2545200	et	3	main
enamik	doc_491521501890_item	2545204	et	3	main
põhjus	doc_491521501890_item	2545213	et	4	main
bisnesmenina	doc_491521501890_item	2545220	et	3	main
irina	doc_491521501890_item	2545224	et	3	main
inglise	doc_491521501890_item	2545229	et	4	main
tulnud	doc_491521501890_item	2545233	et	4	main
sõnu	doc_491521501890_item	2545234	et	4	main
ning	doc_491521501890_item	2545235	et	3	main
olemas	doc_491521501890_item	2545243	et	4	main
maksuga	doc_491521501890_item	2545247	et	3	main
kõrge	doc_491521501890_item	2545249	et	4	main
inimene	doc_491521501890_item	2545255	et	3	main
inimene	doc_491521501890_item	2545257	et	3	main
on	doc_491521501890_item	2545259	et	4	main
interferentsiviga	doc_491521501890_item	2545260	et	4	main
ei	doc_491521501890_item	2545267	et	4	main
tegema	doc_491521501890_item	2545269	et	3	main
teha	doc_491521501890_item	2545276	et	3	main
mõnes	doc_491521501890_item	2545277	et	3	main
mõttes	doc_491521501890_item	2545278	et	3	main
õige	doc_491521501890_item	2545286	et	4	main
on	doc_491521501890_item	2545291	et	4	main
küsimusele	doc_491521501890_item	2545121	et	4	main
ei	doc_491521501890_item	2545126	et	4	main
selle	doc_491521501890_item	2545136	et	4	main
moodustada	doc_491521501890_item	2545144	et	3	main
teadnud	doc_491521501890_item	2545157	et	4	main
et	doc_491521501890_item	2545158	et	3	main
selle	doc_491521501890_item	2545159	et	4	main
valiku	doc_491521501890_item	2545168	et	3	main
vead	doc_491521501890_item	2545169	et	4	main
inimesed	doc_491521501890_item	2545170	et	3	main
ei	doc_491521501890_item	2545171	et	4	main
taha	doc_491521501890_item	2545172	et	4	main
tegema	doc_491521501890_item	2545173	et	3	main
inimesed	doc_491521501890_item	2545174	et	3	main
ei	doc_491521501890_item	2545175	et	4	main
taha	doc_491521501890_item	2545176	et	4	main
teha	doc_491521501890_item	2545177	et	3	main
võib	doc_491521501890_item	2545178	et	3	main
kindel	doc_491521501890_item	2545179	et	3	main
olema	doc_491521501890_item	2545180	et	4	main
võimalik	doc_491521501890_item	2545181	et	3	main
põhjus	doc_491521501890_item	2545182	et	4	main
vene	doc_491521501890_item	2545183	et	4	main
keeles	doc_491521501890_item	2545184	et	4	main
on	doc_491521501890_item	2545185	et	4	main
ainult	doc_491521501890_item	2545186	et	4	main
üks	doc_491521501890_item	2545187	et	3	main
infinitiivivorm	doc_491521501890_item	2545188	et	4	main
vedab	doc_491521501890_item	2545165	et	4	main
verbivormide	doc_491521501890_item	2545167	et	4	main
tööandjaid	doc_491521501890_item	2545203	et	3	main
tunnusta	doc_491521501890_item	2545209	et	4	main
ei	doc_491521501890_item	2545210	et	4	main
tunnista	doc_491521501890_item	2545211	et	4	main
võimalik	doc_491521501890_item	2545212	et	3	main
keelest	doc_491521501890_item	2545219	et	4	main
vist	doc_491521501890_item	2545226	et	4	main
arvas	doc_491521501890_item	2545236	et	3	main
vead	doc_491521501890_item	2545245	et	4	main
kõrgega	doc_491521501890_item	2545246	et	3	main
ametikoht	doc_491521501890_item	2545251	et	3	main
otsetõlge	doc_491521501890_item	2545252	et	3	main
mitte	doc_491521501890_item	2545253	et	3	main
üks	doc_491521501890_item	2545254	et	3	main
ükski	doc_491521501890_item	2545256	et	4	main
lauses	doc_491521501890_item	2545263	et	3	main
haridusega	doc_491521501890_item	2545265	et	3	main
tööd	doc_491521501890_item	2545275	et	4	main
see	doc_491521501890_item	2545279	et	3	main
mõnes	doc_491521501890_item	2545282	et	3	main
on	doc_491521501890_item	2545284	et	4	main
ebameeldiv	doc_491521501890_item	2545292	et	3	main
ei	doc_491521501890_item	2545298	et	4	main
tohi	doc_491521501890_item	2545299	et	4	main
vead	doc_491521501890_item	2545190	et	4	main
paronüümivead	doc_491521501890_item	2545191	et	4	main
kaovad	doc_491521501890_item	2545192	et	3	main
igasugust	doc_491521501890_item	2545193	et	3	main
inimesi	doc_491521501890_item	2545201	et	4	main
ei	doc_491521501890_item	2545208	et	4	main
tõlkelaenud	doc_491521501890_item	2545217	et	3	main
inglise	doc_491521501890_item	2545218	et	4	main
ärimehena	doc_491521501890_item	2545221	et	3	main
põhjus	doc_491521501890_item	2545223	et	4	main
on	doc_491521501890_item	2545225	et	4	main
keelde	doc_491521501890_item	2545232	et	4	main
eesti	doc_491521501890_item	2545241	et	4	main
see	doc_491521501890_item	2545258	et	3	main
kõrgega	doc_491521501890_item	2545264	et	3	main
taha	doc_491521501890_item	2545268	et	4	main
tööd	doc_491521501890_item	2545270	et	4	main
õige	doc_491521501890_item	2545281	et	4	main
mõttes	doc_491521501890_item	2545283	et	3	main
aga	doc_491521501890_item	2545288	et	3	main
kui	doc_491521501890_item	2545293	et	3	main
kooliskäimine	doc_491521501890_item	2545295	et	4	main
ebameeldiv	doc_491521501890_item	2545297	et	3	main
tööandjaid	doc_491521501890_item	2545205	et	3	main
tegelema	doc_491521501890_item	2545206	et	3	main
sõnade	doc_491521501890_item	2545214	et	3	main
võimalik	doc_491521501890_item	2545222	et	3	main
palju	doc_491521501890_item	2545227	et	4	main
kuulnud	doc_491521501890_item	2545228	et	4	main
keelest	doc_491521501890_item	2545230	et	4	main
eesti	doc_491521501890_item	2545231	et	4	main
et	doc_491521501890_item	2545237	et	3	main
sõna	doc_491521501890_item	2545238	et	4	main
bisnesmen	doc_491521501890_item	2545239	et	3	main
on	doc_491521501890_item	2545240	et	4	main
sõnavaliku	doc_491521501890_item	2545244	et	3	main
ametikoht	doc_491521501890_item	2545248	et	3	main
palgaga	doc_491521501890_item	2545250	et	3	main
sõnajärg	doc_491521501890_item	2545262	et	3	main
taha	doc_491521501890_item	2545274	et	4	main
see	doc_491521501890_item	2545285	et	3	main
kooli	doc_491521501890_item	2545290	et	4	main
noorele	doc_491521501890_item	2545300	et	3	main
keelata	doc_491521501890_item	2545301	et	4	main
kui	doc_491521501890_item	2545302	et	3	main
ta	doc_491521501890_item	2545303	et	4	main
tahab	doc_491521501890_item	2545304	et	3	main
bisnesmenina	doc_491521501890_item	2545305	et	3	main
saada	doc_491521501890_item	2545306	et	4	main
või	doc_491521501890_item	2545307	et	4	main
pangadirektorina	doc_491521501890_item	2545308	et	3	main
ei	doc_491521501890_item	2545309	et	4	main
tohi	doc_491521501890_item	2545310	et	4	main
noorele	doc_491521501890_item	2545311	et	3	main
keelata	doc_491521501890_item	2545312	et	4	main
kui	doc_491521501890_item	2545313	et	3	main
ta	doc_491521501890_item	2545314	et	4	main
tahab	doc_491521501890_item	2545315	et	3	main
saada	doc_491521501890_item	2545316	et	4	main
ärimeheks	doc_491521501890_item	2545317	et	3	main
või	doc_491521501890_item	2545318	et	4	main
pangadirektoriks	doc_491521501890_item	2545319	et	3	main
need	doc_491521501890_item	2545320	et	3	main
on	doc_491521501890_item	2545321	et	4	main
keele	doc_491521501892_item	2545921	et	4	main
võõrkeele	doc_491521501892_item	2545923	et	4	main
veaanalüüsi	doc_491521501892_item	2545926	et	4	main
käesolev	doc_491521501892_item	2545928	et	3	main
teel	doc_491521501892_item	2545933	et	4	main
199697	doc_491521501892_item	2545945	et	2	main
eesti	doc_491521501892_item	2545948	et	4	main
kunstiakadeemia	doc_491521501892_item	2545949	et	4	main
tudengiks	doc_491521501892_item	2545950	et	3	main
seega	doc_491521501892_item	2545957	et	4	main
keelekeskkonnas	doc_491521501892_item	2545961	et	3	main
keel	doc_491521501892_item	2545964	et	4	main
kõnekeelsed	doc_491521501892_item	2545969	et	3	main
ei	doc_491521501892_item	2545972	et	4	main
olla	doc_491521501892_item	2545974	et	3	main
oma	doc_491521501892_item	2545984	et	4	main
heale	doc_491521501892_item	2545985	et	3	main
informaalse	doc_491521501892_item	2545994	et	4	main
suhtlemise	doc_491521501892_item	2545995	et	4	main
kõik	doc_491521501892_item	2546001	et	4	main
e-posti	doc_491521501892_item	2545932	et	4	main
kirjutanud	doc_491521501892_item	2545939	et	4	main
eesti	doc_491521501892_item	2545951	et	4	main
on	doc_491521501892_item	2545958	et	4	main
see	doc_491521501892_item	2545959	et	3	main
eesti	doc_491521501892_item	2545963	et	4	main
on	doc_491521501892_item	2545967	et	4	main
keeleoskusest	doc_491521501892_item	2545978	et	4	main
esiteks	doc_491521501892_item	2545979	et	3	main
tegemist	doc_491521501892_item	2545989	et	4	main
siiski	doc_491521501892_item	2545991	et	4	main
e-kirjadega	doc_491521501892_item	2545992	et	3	main
kus	doc_491521501892_item	2545993	et	3	main
keel	doc_491521501892_item	2545998	et	4	main
lähenebki	doc_491521501892_item	2545999	et	3	main
kõnekeelele	doc_491521501892_item	2546000	et	4	main
toodud	doc_491521501892_item	2546006	et	4	main
saa	doc_491521501892_item	2546023	et	4	main
probleemiks	doc_491521501892_item	2546033	et	4	main
ta	doc_491521501892_item	2546038	et	4	main
need	doc_491521501892_item	2546039	et	3	main
kirjad	doc_491521501892_item	2546040	et	4	main
kirjutas	doc_491521501892_item	2546041	et	3	main
2	doc_491521501892_item	2546049	et	2	main
kasutatud	doc_491521501892_item	2546053	et	4	main
ei	doc_491521501892_item	2546068	et	4	main
hakkaks	doc_491521501892_item	2546069	et	3	main
pikemalt	doc_491521501892_item	2546073	et	4	main
soomlastest	doc_491521501892_item	2546086	et	3	main
raske	doc_491521501892_item	2546090	et	4	main
otsustada	doc_491521501892_item	2546103	et	3	main
kas	doc_491521501892_item	2546104	et	3	main
on	doc_491521501892_item	2546116	et	4	main
d	doc_491521501892_item	2546126	et	4	main
tehtud	doc_491521501892_item	2546134	et	4	main
kontrastiivlingvistika	doc_491521501892_item	2545925	et	4	main
saadetud	doc_491521501892_item	2545934	et	4	main
kirjal	doc_491521501892_item	2545935	et	3	main
need	doc_491521501892_item	2545936	et	3	main
kirjad	doc_491521501892_item	2545937	et	4	main
on	doc_491521501892_item	2545938	et	4	main
vahetusüliõpilasena	doc_491521501892_item	2545947	et	3	main
ta	doc_491521501892_item	2545954	et	4	main
suheldes	doc_491521501892_item	2545955	et	3	main
kaasüliõpilastega	doc_491521501892_item	2545956	et	4	main
see	doc_491521501892_item	2545971	et	3	main
ta	doc_491521501892_item	2545981	et	4	main
ja	doc_491521501892_item	2545987	et	3	main
on	doc_491521501892_item	2545990	et	4	main
ära	doc_491521501892_item	2546005	et	4	main
hääldus	doc_491521501892_item	2546010	et	4	main
ja	doc_491521501892_item	2546011	et	3	main
õigekiri	doc_491521501892_item	2546012	et	3	main
õ-kasutamine	doc_491521501892_item	2546013	et	4	main
kuigi	doc_491521501892_item	2546014	et	3	main
kirjades	doc_491521501892_item	2546015	et	3	main
3	doc_491521501892_item	2546018	et	2	main
puuduvad	doc_491521501892_item	2546019	et	4	main
grafeemid	doc_491521501892_item	2546020	et	3	main
analüüs	doc_491521501892_item	2545916	et	3	main
tallinna	doc_491521501892_item	2545917	et	4	main
pedagoogikaülikool	doc_491521501892_item	2545918	et	4	main
filoloogiateaduskond	doc_491521501892_item	2545919	et	3	main
eesti	doc_491521501892_item	2545920	et	4	main
õppetool	doc_491521501892_item	2545924	et	3	main
27-aastane	doc_491521501892_item	2545940	et	4	main
soomlane	doc_491521501892_item	2545941	et	3	main
eesnimi	doc_491521501892_item	2545942	et	3	main
keele	doc_491521501892_item	2545952	et	4	main
omandas	doc_491521501892_item	2545953	et	3	main
õpitud	doc_491521501892_item	2545962	et	4	main
kirjad	doc_491521501892_item	2545966	et	4	main
kuid	doc_491521501892_item	2545970	et	4	main
tingitud	doc_491521501892_item	2545975	et	4	main
ainult	doc_491521501892_item	2545976	et	4	main
eesnimi	doc_491521501892_item	2545977	et	3	main
kirjutanud	doc_491521501892_item	2545982	et	4	main
need	doc_491521501892_item	2545983	et	3	main
teiseks	doc_491521501892_item	2545988	et	4	main
kirja	doc_491521501892_item	2546003	et	4	main
on	doc_491521501892_item	2546004	et	4	main
l	doc_491521501892_item	2546009	et	4	main
õ	doc_491521501892_item	2546021	et	4	main
e	doc_491521501892_item	2546026	et	4	main
kasutada	doc_491521501892_item	2546028	et	3	main
ei	doc_491521501892_item	2546029	et	4	main
millega	doc_491521501892_item	2546037	et	3	main
kasutamist	doc_491521501892_item	2546045	et	4	main
seda	doc_491521501892_item	2546046	et	3	main
kinnitab	doc_491521501892_item	2546047	et	3	main
kui	doc_491521501892_item	2545922	et	3	main
kodutöö	doc_491521501892_item	2545927	et	4	main
töö	doc_491521501892_item	2545929	et	4	main
põhineb	doc_491521501892_item	2545930	et	3	main
kolmel	doc_491521501892_item	2545931	et	4	main
kes	doc_491521501892_item	2545943	et	4	main
õppeaastal	doc_491521501892_item	2545944	et	3	main
oli	doc_491521501892_item	2545946	et	3	main
loomulikus	doc_491521501892_item	2545960	et	4	main
need	doc_491521501892_item	2545965	et	3	main
suhteliselt	doc_491521501892_item	2545968	et	4	main
pruugi	doc_491521501892_item	2545973	et	4	main
on	doc_491521501892_item	2545980	et	4	main
tuttavale	doc_491521501892_item	2545986	et	4	main
puhul	doc_491521501892_item	2545996	et	4	main
kasutatav	doc_491521501892_item	2545997	et	4	main
lõpus	doc_491521501892_item	2546008	et	4	main
et	doc_491521501892_item	2546025	et	3	main
see	doc_491521501892_item	2546034	et	3	main
võimaldanud	doc_491521501892_item	2546043	et	4	main
õ	doc_491521501892_item	2546044	et	4	main
seal	doc_491521501892_item	2546050	et	4	main
puudu	doc_491521501892_item	2546065	et	4	main
kuid	doc_491521501892_item	2546066	et	4	main
ma	doc_491521501892_item	2546067	et	3	main
puudumist	doc_491521501892_item	2546071	et	4	main
kuna	doc_491521501892_item	2546075	et	3	main
õi	doc_491521501892_item	2546081	et	4	main
arvan	doc_491521501892_item	2546083	et	3	main
enamusele	doc_491521501892_item	2546085	et	4	main
raske	doc_491521501892_item	2546102	et	4	main
lohakuse	doc_491521501892_item	2546107	et	4	main
kirjas	doc_491521501892_item	2546117	et	4	main
1	doc_491521501892_item	2546118	et	2	main
mitu	doc_491521501892_item	2546119	et	4	main
t	doc_491521501892_item	2546122	et	4	main
mitu	doc_491521501892_item	2546135	et	4	main
vead	doc_491521501892_item	2546154	et	4	main
nt	doc_491521501892_item	2546165	et	4	main
pp	doc_491521501892_item	2546167	et	4	main
uni	doc_491521501892_item	2546168	et	3	main
avatele	doc_491521501892_item	2546171	et	4	main
tt	doc_491521501892_item	2546173	et	4	main
loppuun	doc_491521501892_item	2546214	et	4	main
vigane	doc_491521501892_item	2546218	et	4	main
kolm	doc_491521501892_item	2546002	et	3	main
töö	doc_491521501892_item	2546007	et	4	main
1	doc_491521501892_item	2546016	et	2	main
ja	doc_491521501892_item	2546017	et	3	main
öelda	doc_491521501892_item	2546024	et	4	main
neid	doc_491521501892_item	2546027	et	4	main
et	doc_491521501892_item	2546035	et	3	main
arvuti	doc_491521501892_item	2546036	et	4	main
on	doc_491521501892_item	2546051	et	4	main
seda	doc_491521501892_item	2546055	et	3	main
siin	doc_491521501892_item	2546072	et	4	main
analüüsima	doc_491521501892_item	2546074	et	3	main
et	doc_491521501892_item	2546084	et	3	main
ja	doc_491521501892_item	2546091	et	3	main
mingi	doc_491521501892_item	2546095	et	4	main
on	doc_491521501892_item	2546100	et	4	main
on	doc_491521501892_item	2546106	et	4	main
või	doc_491521501892_item	2546110	et	4	main
vormimoodustusega	doc_491521501892_item	2546112	et	3	main
naiteks	doc_491521501892_item	2546113	et	4	main
verbist	doc_491521501892_item	2546114	et	3	main
pildistama	doc_491521501892_item	2546115	et	3	main
ei	doc_491521501892_item	2546022	et	4	main
oska	doc_491521501892_item	2546030	et	4	main
arvatavasti	doc_491521501892_item	2546031	et	3	main
oli	doc_491521501892_item	2546032	et	3	main
ei	doc_491521501892_item	2546042	et	4	main
kiri	doc_491521501892_item	2546048	et	3	main
õ-d	doc_491521501892_item	2546052	et	4	main
ja	doc_491521501892_item	2546054	et	3	main
täiesti	doc_491521501892_item	2546056	et	3	main
veatult	doc_491521501892_item	2546057	et	4	main
kirjavahemärgid	doc_491521501892_item	2546058	et	3	main
e-1	doc_491521501892_item	2546059	et	4	main
on	doc_491521501892_item	2546060	et	4	main
küll	doc_491521501892_item	2546061	et	4	main
kirjades	doc_491521501892_item	2546062	et	3	main
hulganisti	doc_491521501892_item	2546063	et	3	main
komasid	doc_491521501892_item	2546064	et	3	main
nende	doc_491521501892_item	2546070	et	4	main
tegemist	doc_491521501892_item	2546076	et	4	main
on	doc_491521501892_item	2546077	et	4	main
mitteametlike	doc_491521501892_item	2546078	et	3	main
e-kirjadega	doc_491521501892_item	2546079	et	3	main
gekiri	doc_491521501892_item	2546082	et	4	main
ka	doc_491521501892_item	2546092	et	3	main
siiski	doc_491521501892_item	2546101	et	4	main
emakeele	doc_491521501892_item	2546108	et	4	main
pil	doc_491521501892_item	2546121	et	4	main
istan	doc_491521501892_item	2546123	et	4	main
pildistamisele	doc_491521501892_item	2546124	et	4	main
pildis	doc_491521501892_item	2546125	et	3	main
amiseks	doc_491521501892_item	2546131	et	4	main
kuigi	doc_491521501892_item	2546132	et	3	main
on	doc_491521501892_item	2546133	et	4	main
jääb	doc_491521501892_item	2546137	et	3	main
et	doc_491521501892_item	2546144	et	3	main
hooletusest	doc_491521501892_item	2546155	et	4	main
raskusi	doc_491521501892_item	2546157	et	4	main
asuvate	doc_491521501892_item	2546163	et	4	main
tt	doc_491521501892_item	2546176	et	4	main
imisele	doc_491521501892_item	2546177	et	4	main
1	doc_491521501892_item	2546179	et	2	main
tt	doc_491521501892_item	2546181	et	4	main
kahtlane	doc_491521501892_item	2546227	et	3	main
keele	doc_491521501892_item	2546230	et	4	main
teades	doc_491521501892_item	2546235	et	4	main
kuidas	doc_491521501892_item	2546236	et	3	main
sellist	doc_491521501892_item	2546242	et	4	main
välismaalasele	doc_491521501892_item	2546244	et	3	main
mõnigi	doc_491521501892_item	2546256	et	3	main
on	doc_491521501892_item	2546274	et	4	main
on	doc_491521501892_item	2546277	et	4	main
e	doc_491521501892_item	2546291	et	4	main
d	doc_491521501892_item	2546304	et	4	main
2	doc_491521501892_item	2546306	et	2	main
ja	doc_491521501892_item	2546307	et	3	main
kor	doc_491521501892_item	2546308	et	4	main
vigadest	doc_491521501892_item	2546313	et	3	main
laadi	doc_491521501892_item	2546320	et	4	main
2	doc_491521501892_item	2546335	et	2	main
arvan	doc_491521501892_item	2546337	et	3	main
ebakindlust	doc_491521501892_item	2546342	et	4	main
ja	doc_491521501892_item	2546350	et	3	main
kaks	doc_491521501892_item	2546368	et	3	main
kiri	doc_491521501892_item	2546373	et	3	main
et	doc_491521501892_item	2546392	et	3	main
ette	doc_491521501892_item	2546396	et	4	main
algu	doc_491521501892_item	2546410	et	4	main
süntaks	doc_491521501892_item	2546423	et	3	main
ole	doc_491521501892_item	2546432	et	4	main
hea	doc_491521501892_item	2546446	et	4	main
arvatavasti	doc_491521501892_item	2546450	et	3	main
vigade	doc_491521501892_item	2546454	et	3	main
nii	doc_491521501892_item	2546456	et	3	main
juures	doc_491521501892_item	2546472	et	4	main
kui	doc_491521501892_item	2546479	et	3	main
kõnekeele	doc_491521501892_item	2546481	et	4	main
mõju	doc_491521501892_item	2546482	et	4	main
kiri	doc_491521501892_item	2546489	et	3	main
kui	doc_491521501892_item	2546491	et	3	main
mida	doc_491521501892_item	2546500	et	4	main
pean	doc_491521501892_item	2546511	et	4	main
ei	doc_491521501892_item	2546520	et	4	main
klusiilide	doc_491521501892_item	2546080	et	3	main
on	doc_491521501892_item	2546087	et	4	main
see	doc_491521501892_item	2546088	et	3	main
teema	doc_491521501892_item	2546089	et	4	main
e	doc_491521501892_item	2546093	et	4	main
pole	doc_491521501892_item	2546094	et	3	main
erand	doc_491521501892_item	2546096	et	3	main
nende	doc_491521501892_item	2546097	et	4	main
vigade	doc_491521501892_item	2546098	et	3	main
puhul	doc_491521501892_item	2546099	et	4	main
tegemist	doc_491521501892_item	2546105	et	4	main
mõju	doc_491521501892_item	2546109	et	4	main
vigase	doc_491521501892_item	2546111	et	4	main
varianti	doc_491521501892_item	2546120	et	4	main
ama	doc_491521501892_item	2546127	et	4	main
ja	doc_491521501892_item	2546128	et	3	main
pildis	doc_491521501892_item	2546129	et	3	main
d	doc_491521501892_item	2546130	et	4	main
kirju	doc_491521501892_item	2546138	et	4	main
lugedes	doc_491521501892_item	2546142	et	3	main
sõna	doc_491521501892_item	2546161	et	4	main
keskel	doc_491521501892_item	2546162	et	3	main
tu	doc_491521501892_item	2546169	et	4	main
prin	doc_491521501892_item	2546175	et	4	main
kiri	doc_491521501892_item	2546178	et	3	main
asti	doc_491521501892_item	2546215	et	4	main
hoopis	doc_491521501892_item	2546217	et	3	main
vormimoodustus	doc_491521501892_item	2546219	et	3	main
mõju	doc_491521501892_item	2546231	et	4	main
see	doc_491521501892_item	2546237	et	3	main
hääldub	doc_491521501892_item	2546240	et	3	main
arvata	doc_491521501892_item	2546249	et	4	main
et	doc_491521501892_item	2546250	et	3	main
siin	doc_491521501892_item	2546251	et	4	main
on	doc_491521501892_item	2546268	et	4	main
tahtnud	doc_491521501892_item	2546269	et	4	main
kirjutada	doc_491521501892_item	2546270	et	3	main
kusagilt	doc_491521501892_item	2546271	et	3	main
ja	doc_491521501892_item	2546272	et	3	main
hooletusveaga	doc_491521501892_item	2546275	et	4	main
kuskilt	doc_491521501892_item	2546282	et	4	main
ja	doc_491521501892_item	2546283	et	3	main
eksinud	doc_491521501892_item	2546292	et	4	main
i	doc_491521501892_item	2546297	et	4	main
mille	doc_491521501892_item	2546298	et	3	main
kiri	doc_491521501892_item	2546299	et	3	main
1	doc_491521501892_item	2546300	et	2	main
vai	doc_491521501892_item	2546301	et	3	main
b	doc_491521501892_item	2546302	et	4	main
3	doc_491521501892_item	2546311	et	2	main
viga	doc_491521501892_item	2546136	et	4	main
ja	doc_491521501892_item	2546140	et	3	main
mulje	doc_491521501892_item	2546143	et	4	main
põhjustatuteks	doc_491521501892_item	2546156	et	4	main
on	doc_491521501892_item	2546158	et	4	main
e-1	doc_491521501892_item	2546159	et	4	main
ka	doc_491521501892_item	2546160	et	3	main
lo	doc_491521501892_item	2546166	et	4	main
ilmu	doc_491521501892_item	2546172	et	4	main
amisele	doc_491521501892_item	2546174	et	4	main
jättaksjä	doc_491521501892_item	2546180	et	4	main
an	doc_491521501892_item	2546182	et	4	main
kus	doc_491521501892_item	2546183	et	3	main
g	doc_491521501892_item	2546184	et	4	main
ilt	doc_491521501892_item	2546185	et	4	main
kiri	doc_491521501892_item	2546186	et	3	main
2	doc_491521501892_item	2546187	et	2	main
kindlasti	doc_491521501892_item	2546188	et	3	main
on	doc_491521501892_item	2546189	et	4	main
siin	doc_491521501892_item	2546190	et	4	main
oma	doc_491521501892_item	2546191	et	4	main
roll	doc_491521501892_item	2546192	et	3	main
emakeele	doc_491521501892_item	2546193	et	4	main
mõjust	doc_491521501892_item	2546194	et	3	main
tingitud	doc_491521501892_item	2546195	et	4	main
ebakindlusel	doc_491521501892_item	2546196	et	4	main
kuid	doc_491521501892_item	2546197	et	4	main
mõnede	doc_491521501892_item	2546198	et	3	main
vigade	doc_491521501892_item	2546199	et	3	main
puhul	doc_491521501892_item	2546200	et	4	main
julgen	doc_491521501892_item	2546201	et	3	main
kahtlustada	doc_491521501892_item	2546202	et	3	main
ka	doc_491521501892_item	2546203	et	3	main
muid	doc_491521501892_item	2546204	et	4	main
põhjusi	doc_491521501892_item	2546205	et	3	main
näiteks	doc_491521501892_item	2546206	et	4	main
loppuni	doc_491521501892_item	2546207	et	4	main
siin	doc_491521501892_item	2546208	et	4	main
võib	doc_491521501892_item	2546209	et	3	main
olla	doc_491521501892_item	2546210	et	3	main
põhjuseks	doc_491521501892_item	2546211	et	3	main
emakeel	doc_491521501892_item	2546212	et	4	main
sm	doc_491521501892_item	2546213	et	4	main
2	doc_491521501892_item	2546139	et	2	main
3	doc_491521501892_item	2546141	et	2	main
e	doc_491521501892_item	2546145	et	4	main
teab	doc_491521501892_item	2546146	et	3	main
kuidas	doc_491521501892_item	2546147	et	3	main
seda	doc_491521501892_item	2546148	et	3	main
verbi	doc_491521501892_item	2546149	et	4	main
kasutatakse	doc_491521501892_item	2546150	et	3	main
nii	doc_491521501892_item	2546151	et	3	main
loeksin	doc_491521501892_item	2546152	et	3	main
need	doc_491521501892_item	2546153	et	3	main
klusiilidega	doc_491521501892_item	2546164	et	3	main
t	doc_491521501892_item	2546170	et	4	main
lõppu	doc_491521501892_item	2546221	et	4	main
lõppuni	doc_491521501892_item	2546223	et	3	main
kuhu	doc_491521501892_item	2546224	et	3	main
on	doc_491521501892_item	2546228	et	4	main
soome	doc_491521501892_item	2546229	et	3	main
puhul	doc_491521501892_item	2546234	et	4	main
panna	doc_491521501892_item	2546247	et	4	main
võib	doc_491521501892_item	2546248	et	3	main
eestlane	doc_491521501892_item	2546257	et	3	main
mõelnud	doc_491521501892_item	2546280	et	4	main
sõnalõpuliste	doc_491521501892_item	2546288	et	4	main
klusiilidega	doc_491521501892_item	2546289	et	3	main
pr	doc_491521501892_item	2546294	et	4	main
ainul	doc_491521501892_item	2546303	et	4	main
juhuslikku	doc_491521501892_item	2546319	et	4	main
mõlemat	doc_491521501892_item	2546322	et	3	main
sõna	doc_491521501892_item	2546323	et	4	main
ka	doc_491521501892_item	2546325	et	3	main
õigesti	doc_491521501892_item	2546326	et	3	main
kasutatud	doc_491521501892_item	2546327	et	4	main
vaibad	doc_491521501892_item	2546328	et	3	main
vaipade	doc_491521501892_item	2546329	et	3	main
kiri	doc_491521501892_item	2546330	et	3	main
kin	doc_491521501892_item	2546334	et	4	main
et	doc_491521501892_item	2546338	et	3	main
õigekiri	doc_491521501892_item	2546340	et	3	main
õppinud	doc_491521501892_item	2546348	et	4	main
nii	doc_491521501892_item	2546370	et	3	main
on	doc_491521501892_item	2546382	et	4	main
ära	doc_491521501892_item	2546386	et	4	main
on	doc_491521501892_item	2546389	et	4	main
mõistetav	doc_491521501892_item	2546391	et	4	main
või	doc_491521501892_item	2546216	et	4	main
lõpp	doc_491521501892_item	2546220	et	3	main
sõna	doc_491521501892_item	2546232	et	4	main
keeles	doc_491521501892_item	2546239	et	4	main
pahaks	doc_491521501892_item	2546246	et	4	main
vea	doc_491521501892_item	2546253	et	4	main
ka	doc_491521501892_item	2546254	et	3	main
nii	doc_491521501892_item	2546255	et	3	main
tegemist	doc_491521501892_item	2546273	et	4	main
sõna	doc_491521501892_item	2546281	et	4	main
on	doc_491521501892_item	2546290	et	4	main
in	doc_491521501892_item	2546295	et	4	main
t	doc_491521501892_item	2546296	et	4	main
kiri	doc_491521501892_item	2546305	et	3	main
nendest	doc_491521501892_item	2546312	et	4	main
ja	doc_491521501892_item	2546315	et	3	main
tunduvad	doc_491521501892_item	2546317	et	4	main
olevat	doc_491521501892_item	2546318	et	4	main
2	doc_491521501892_item	2546331	et	2	main
keele	doc_491521501892_item	2546346	et	4	main
grammatikat	doc_491521501892_item	2546347	et	3	main
sellised	doc_491521501892_item	2546351	et	4	main
selliseid	doc_491521501892_item	2546363	et	4	main
vigu	doc_491521501892_item	2546364	et	3	main
leidsin	doc_491521501892_item	2546365	et	3	main
e-1	doc_491521501892_item	2546366	et	4	main
pole	doc_491521501892_item	2546371	et	3	main
1	doc_491521501892_item	2546374	et	2	main
ja	doc_491521501892_item	2546375	et	3	main
3	doc_491521501892_item	2546379	et	2	main
kuna	doc_491521501892_item	2546380	et	3	main
t	doc_491521501892_item	2546381	et	4	main
suheldes	doc_491521501892_item	2546388	et	3	main
täiesti	doc_491521501892_item	2546390	et	3	main
selliseid	doc_491521501892_item	2546393	et	4	main
muud	doc_491521501892_item	2546397	et	4	main
mõnede	doc_491521501892_item	2546399	et	3	main
puhul	doc_491521501892_item	2546401	et	4	main
olen	doc_491521501892_item	2546402	et	3	main
üpris	doc_491521501892_item	2546403	et	3	main
kindel	doc_491521501892_item	2546404	et	3	main
et	doc_491521501892_item	2546405	et	3	main
tegemist	doc_491521501892_item	2546406	et	4	main
nt	doc_491521501892_item	2546409	et	4	main
2	doc_491521501892_item	2546422	et	2	main
ei	doc_491521501892_item	2546431	et	4	main
mõned	doc_491521501892_item	2546434	et	3	main
vead	doc_491521501892_item	2546435	et	4	main
ära	doc_491521501892_item	2546438	et	4	main
1	doc_491521501892_item	2546441	et	2	main
vaipade	doc_491521501892_item	2546442	et	3	main
pildisdamiseks	doc_491521501892_item	2546443	et	4	main
mõjutanud	doc_491521501892_item	2546451	et	4	main
selliste	doc_491521501892_item	2546453	et	4	main
kiri	doc_491521501892_item	2546470	et	3	main
pean	doc_491521501892_item	2546485	et	4	main
koige	doc_491521501892_item	2546486	et	4	main
ei	doc_491521501892_item	2546493	et	4	main
on	doc_491521501892_item	2546501	et	4	main
on	doc_491521501892_item	2546506	et	4	main
ju	doc_491521501892_item	2546507	et	3	main
ka	doc_491521501892_item	2546508	et	3	main
sõna	doc_491521501892_item	2546516	et	4	main
sobi	doc_491521501892_item	2546521	et	4	main
sinu	doc_491521501892_item	2546541	et	3	main
on	doc_491521501892_item	2546546	et	4	main
nõuab	doc_491521501892_item	2546555	et	3	main
ära	doc_491521501892_item	2546557	et	4	main
mis	doc_491521501892_item	2546560	et	4	main
kaas	doc_491521501892_item	2546562	et	3	main
mõjutanud	doc_491521501892_item	2546571	et	4	main
tegemist	doc_491521501892_item	2546587	et	4	main
työstä	doc_491521501892_item	2546594	et	4	main
soome	doc_491521501892_item	2546595	et	3	main
sellistel	doc_491521501892_item	2546598	et	4	main
eesti	doc_491521501892_item	2546601	et	4	main
aga	doc_491521501892_item	2546603	et	3	main
omastav	doc_491521501892_item	2546604	et	4	main
kaassõna	doc_491521501892_item	2546605	et	4	main
kui	doc_491521501892_item	2546616	et	3	main
on	doc_491521501892_item	2546621	et	4	main
kiri	doc_491521501892_item	2546639	et	3	main
hooletusvigadega	doc_491521501892_item	2546645	et	4	main
kuhu	doc_491521501892_item	2546222	et	3	main
maani	doc_491521501892_item	2546225	et	3	main
päris	doc_491521501892_item	2546226	et	4	main
printtimisele	doc_491521501892_item	2546233	et	4	main
eesti	doc_491521501892_item	2546238	et	4	main
on	doc_491521501892_item	2546241	et	4	main
kirjapilti	doc_491521501892_item	2546243	et	4	main
raske	doc_491521501892_item	2546245	et	4	main
teeks	doc_491521501892_item	2546252	et	4	main
segaseks	doc_491521501892_item	2546258	et	4	main
jääb	doc_491521501892_item	2546259	et	3	main
vea	doc_491521501892_item	2546260	et	4	main
põhjus	doc_491521501892_item	2546261	et	4	main
veel	doc_491521501892_item	2546262	et	4	main
määrsõna	doc_491521501892_item	2546263	et	4	main
kusgilt	doc_491521501892_item	2546264	et	4	main
juures	doc_491521501892_item	2546265	et	4	main
kas	doc_491521501892_item	2546266	et	3	main
e	doc_491521501892_item	2546267	et	4	main
või	doc_491521501892_item	2546276	et	4	main
ta	doc_491521501892_item	2546278	et	4	main
siiski	doc_491521501892_item	2546279	et	4	main
märkinud	doc_491521501892_item	2546284	et	4	main
klusiili	doc_491521501892_item	2546285	et	4	main
valesti	doc_491521501892_item	2546286	et	3	main
ka	doc_491521501892_item	2546287	et	3	main
nt	doc_491521501892_item	2546293	et	4	main
t	doc_491521501892_item	2546309	et	4	main
kiri	doc_491521501892_item	2546310	et	3	main
vaib	doc_491521501892_item	2546314	et	4	main
kort	doc_491521501892_item	2546316	et	4	main
sest	doc_491521501892_item	2546321	et	4	main
on	doc_491521501892_item	2546324	et	4	main
kord	doc_491521501892_item	2546333	et	4	main
klusiilide	doc_491521501892_item	2546339	et	3	main
soomlastes	doc_491521501892_item	2546349	et	3	main
ainult	doc_491521501892_item	2546367	et	4	main
õppinud	doc_491521501892_item	2546383	et	4	main
eesti	doc_491521501892_item	2546384	et	4	main
eestlastega	doc_491521501892_item	2546387	et	4	main
vigu	doc_491521501892_item	2546394	et	3	main
on	doc_491521501892_item	2546407	et	4	main
st	doc_491521501892_item	2546411	et	3	main
käsits	doc_491521501892_item	2546413	et	4	main
kiri	doc_491521501892_item	2546415	et	3	main
ja	doc_491521501892_item	2546417	et	3	main
kaas	doc_491521501892_item	2546418	et	3	main
võtma	doc_491521501892_item	2546419	et	3	main
kiri	doc_491521501892_item	2546420	et	3	main
morfoloogia	doc_491521501892_item	2546425	et	4	main
sõnajärjega	doc_491521501892_item	2546427	et	3	main
suuremaid	doc_491521501892_item	2546429	et	4	main
kuid	doc_491521501892_item	2546433	et	4	main
siiski	doc_491521501892_item	2546437	et	4	main
märkima	doc_491521501892_item	2546439	et	4	main
kiri	doc_491521501892_item	2546440	et	3	main
on	doc_491521501892_item	2546448	et	4	main
kirjutajat	doc_491521501892_item	2546449	et	4	main
2	doc_491521501892_item	2546471	et	2	main
põhjust	doc_491521501892_item	2546477	et	4	main
leida	doc_491521501892_item	2546478	et	3	main
ainult	doc_491521501892_item	2546480	et	4	main
käsitse	doc_491521501892_item	2546487	et	4	main
e	doc_491521501892_item	2546492	et	4	main
ole	doc_491521501892_item	2546494	et	4	main
teinud	doc_491521501892_item	2546496	et	4	main
ta	doc_491521501892_item	2546502	et	4	main
eksinud	doc_491521501892_item	2546503	et	4	main
kõik	doc_491521501892_item	2546517	et	4	main
puhul	doc_491521501892_item	2546518	et	4	main
see	doc_491521501892_item	2546519	et	3	main
on	doc_491521501892_item	2546523	et	4	main
kasutamisega	doc_491521501892_item	2546527	et	4	main
ostsin	doc_491521501892_item	2546528	et	3	main
nüiid	doc_491521501892_item	2546529	et	4	main
vaibad	doc_491521501892_item	2546542	et	3	main
soome	doc_491521501892_item	2546548	et	3	main
mõju	doc_491521501892_item	2546550	et	4	main
t-d	doc_491521501892_item	2546568	et	4	main
arvatavasti	doc_491521501892_item	2546569	et	3	main
ühendverb	doc_491521501892_item	2546573	et	3	main
mille	doc_491521501892_item	2546578	et	3	main
töö	doc_491521501892_item	2546582	et	4	main
tööst	doc_491521501892_item	2546583	et	3	main
diil	doc_491521501892_item	2546584	et	4	main
kiri	doc_491521501892_item	2546585	et	3	main
1	doc_491521501892_item	2546586	et	2	main
on	doc_491521501892_item	2546597	et	4	main
eest	doc_491521501892_item	2546608	et	4	main
vea	doc_491521501892_item	2546609	et	4	main
2	doc_491521501892_item	2546615	et	2	main
ja	doc_491521501892_item	2546332	et	3	main
kokkuvõtvalt	doc_491521501892_item	2546336	et	4	main
tekitab	doc_491521501892_item	2546341	et	3	main
enamuses	doc_491521501892_item	2546343	et	4	main
ka	doc_491521501892_item	2546344	et	3	main
eesti	doc_491521501892_item	2546345	et	4	main
vead	doc_491521501892_item	2546352	et	4	main
võivad	doc_491521501892_item	2546353	et	4	main
sisse	doc_491521501892_item	2546354	et	4	main
lipsata	doc_491521501892_item	2546355	et	4	main
ka	doc_491521501892_item	2546356	et	3	main
õigeid	doc_491521501892_item	2546357	et	3	main
vorme	doc_491521501892_item	2546358	et	3	main
teades	doc_491521501892_item	2546359	et	4	main
kokku-	doc_491521501892_item	2546360	et	3	main
ja	doc_491521501892_item	2546361	et	3	main
lahkukirjutamine	doc_491521501892_item	2546362	et	3	main
nagu	doc_491521501892_item	2546369	et	3	main
piisavalt	doc_491521501892_item	2546372	et	4	main
klaasi	doc_491521501892_item	2546376	et	4	main
näitus	doc_491521501892_item	2546377	et	3	main
kiri	doc_491521501892_item	2546378	et	3	main
keele	doc_491521501892_item	2546385	et	4	main
tuleb	doc_491521501892_item	2546395	et	3	main
õigekirjavead	doc_491521501892_item	2546398	et	3	main
vigade	doc_491521501892_item	2546400	et	3	main
hooletusvigadega	doc_491521501892_item	2546408	et	4	main
loppuni	doc_491521501892_item	2546412	et	4	main
e	doc_491521501892_item	2546414	et	4	main
1	doc_491521501892_item	2546416	et	2	main
2	doc_491521501892_item	2546421	et	2	main
ja	doc_491521501892_item	2546424	et	3	main
peaksin	doc_491521501892_item	2546436	et	4	main
siin	doc_491521501892_item	2546447	et	4	main
kindlasti	doc_491521501892_item	2546469	et	3	main
ei	doc_491521501892_item	2546473	et	4	main
kahjuks	doc_491521501892_item	2546475	et	4	main
1	doc_491521501892_item	2546490	et	2	main
kõike	doc_491521501892_item	2546499	et	4	main
käändevalikuga	doc_491521501892_item	2546504	et	4	main
lseenesest	doc_491521501892_item	2546505	et	4	main
mille	doc_491521501892_item	2546512	et	3	main
käsitsi	doc_491521501892_item	2546513	et	3	main
tegema	doc_491521501892_item	2546514	et	3	main
kuid	doc_491521501892_item	2546515	et	4	main
probleeme	doc_491521501892_item	2546525	et	3	main
abimäärsõnade	doc_491521501892_item	2546526	et	4	main
igal	doc_491521501892_item	2546530	et	3	main
juhul	doc_491521501892_item	2546531	et	3	main
filmi	doc_491521501892_item	2546532	et	4	main
ja	doc_491521501892_item	2546533	et	3	main
panin	doc_491521501892_item	2546534	et	3	main
kiri	doc_491521501892_item	2546535	et	3	main
2	doc_491521501892_item	2546536	et	2	main
ja	doc_491521501892_item	2546537	et	3	main
pildistan	doc_491521501892_item	2546538	et	3	main
kiri	doc_491521501892_item	2546543	et	3	main
siin	doc_491521501892_item	2546545	et	4	main
selline	doc_491521501892_item	2546553	et	4	main
vorm	doc_491521501892_item	2546554	et	3	main
pean	doc_491521501892_item	2546561	et	4	main
võtma	doc_491521501892_item	2546563	et	3	main
2	doc_491521501892_item	2546565	et	2	main
kaasa	doc_491521501892_item	2546574	et	4	main
eeldab	doc_491521501892_item	2546576	et	3	main
mida	doc_491521501892_item	2546580	et	4	main
käändevead	doc_491521501892_item	2546581	et	4	main
sm	doc_491521501892_item	2546592	et	4	main
työ	doc_491521501892_item	2546593	et	4	main
seestütlev	doc_491521501892_item	2546600	et	3	main
kordumine	doc_491521501892_item	2546613	et	4	main
tundub	doc_491521501892_item	2546618	et	3	main
et	doc_491521501892_item	2546619	et	3	main
sellest	doc_491521501892_item	2546622	et	4	main
on	doc_491521501892_item	2546631	et	4	main
igas	doc_491521501892_item	2546633	et	3	main
vaibast	doc_491521501892_item	2546634	et	4	main
ja	doc_491521501892_item	2546635	et	3	main
1	doc_491521501892_item	2546640	et	2	main
kuigi	doc_491521501892_item	2546659	et	3	main
kasutatakse	doc_491521501892_item	2546661	et	3	main
kõnekeelt	doc_491521501892_item	2546663	et	4	main
mille	doc_491521501892_item	2546668	et	3	main
mõni	doc_491521501892_item	2546673	et	3	main
niimoodi	doc_491521501892_item	2546676	et	3	main
kulud	doc_491521501892_item	2546679	et	4	main
mulle	doc_491521501892_item	2546681	et	4	main
endale	doc_491521501892_item	2546682	et	4	main
kiri	doc_491521501892_item	2546683	et	3	main
1	doc_491521501892_item	2546684	et	2	main
käiva	doc_491521501892_item	2546692	et	4	main
konstruktsiooniga	doc_491521501892_item	2546693	et	3	main
kasutatavad	doc_491521501892_item	2546722	et	4	main
näite	doc_491521501892_item	2546728	et	4	main
siis	doc_491521501892_item	2546738	et	3	main
saab	doc_491521501892_item	2546739	et	3	main
sõnajärg	doc_491521501892_item	2546426	et	3	main
e-1	doc_491521501892_item	2546428	et	4	main
probleeme	doc_491521501892_item	2546430	et	3	main
päevavalgus	doc_491521501892_item	2546444	et	4	main
oleks	doc_491521501892_item	2546445	et	3	main
emakeel	doc_491521501892_item	2546452	et	4	main
nagu	doc_491521501892_item	2546455	et	3	main
et	doc_491521501892_item	2546457	et	3	main
umbes	doc_491521501892_item	2546458	et	4	main
20ndal	doc_491521501892_item	2546459	et	4	main
tulen	doc_491521501892_item	2546460	et	3	main
kiri	doc_491521501892_item	2546461	et	3	main
3	doc_491521501892_item	2546462	et	2	main
ja	doc_491521501892_item	2546463	et	3	main
vaatan	doc_491521501892_item	2546464	et	3	main
meile	doc_491521501892_item	2546465	et	4	main
veel	doc_491521501892_item	2546466	et	4	main
täna	doc_491521501892_item	2546467	et	4	main
õhtul	doc_491521501892_item	2546468	et	3	main
oska	doc_491521501892_item	2546474	et	4	main
muud	doc_491521501892_item	2546476	et	4	main
objektivead	doc_491521501892_item	2546483	et	4	main
kuna	doc_491521501892_item	2546484	et	3	main
tegema	doc_491521501892_item	2546488	et	3	main
siin	doc_491521501892_item	2546495	et	4	main
õigekirjaviga	doc_491521501892_item	2546497	et	4	main
vormis	doc_491521501892_item	2546498	et	4	main
omastav	doc_491521501892_item	2546509	et	4	main
õige	doc_491521501892_item	2546510	et	4	main
veel	doc_491521501892_item	2546522	et	4	main
need	doc_491521501892_item	2546540	et	3	main
tunda	doc_491521501892_item	2546547	et	3	main
keele	doc_491521501892_item	2546549	et	4	main
eesti	doc_491521501892_item	2546551	et	4	main
keeles	doc_491521501892_item	2546552	et	4	main
teaksin	doc_491521501892_item	2546559	et	3	main
jällegi	doc_491521501892_item	2546570	et	4	main
kusimusi	doc_491521501892_item	2546577	et	4	main
on	doc_491521501892_item	2546588	et	4	main
arvatavasti	doc_491521501892_item	2546589	et	3	main
emakeele	doc_491521501892_item	2546590	et	4	main
mõjuga	doc_491521501892_item	2546591	et	3	main
puhkudel	doc_491521501892_item	2546599	et	3	main
keeles	doc_491521501892_item	2546602	et	4	main
juhuslikkuse	doc_491521501892_item	2546610	et	4	main
välistab	doc_491521501892_item	2546611	et	3	main
selle	doc_491521501892_item	2546612	et	4	main
sulle	doc_491521501892_item	2546617	et	3	main
palju	doc_491521501892_item	2546623	et	4	main
ühildumisvead	doc_491521501892_item	2546626	et	4	main
kaks	doc_491521501892_item	2546628	et	3	main
kus	doc_491521501892_item	2546630	et	3	main
oleks	doc_491521501892_item	2546637	et	3	main
tõenäosusega	doc_491521501892_item	2546642	et	3	main
tegemist	doc_491521501892_item	2546644	et	4	main
näite	doc_491521501892_item	2546647	et	4	main
stiilivead	doc_491521501892_item	2546658	et	3	main
näite	doc_491521501892_item	2546667	et	4	main
siin	doc_491521501892_item	2546685	et	4	main
mõned	doc_491521501892_item	2546696	et	3	main
nii	doc_491521501892_item	2546702	et	3	main
leidsin	doc_491521501892_item	2546725	et	3	main
ühe	doc_491521501892_item	2546727	et	4	main
hea	doc_491521501892_item	2546735	et	4	main
kui	doc_491521501892_item	2546736	et	3	main
voimatu	doc_491521501892_item	2546737	et	4	main
arvan	doc_491521501892_item	2546745	et	3	main
varianti	doc_491521501892_item	2546752	et	4	main
või	doc_491521501892_item	2546761	et	4	main
sulle	doc_491521501892_item	2546777	et	3	main
et	doc_491521501892_item	2546779	et	3	main
mis	doc_491521501892_item	2546824	et	4	main
on	doc_491521501892_item	2546831	et	4	main
kiri	doc_491521501892_item	2546835	et	3	main
oleks	doc_491521501892_item	2546839	et	3	main
tööst	doc_491521501892_item	2546841	et	3	main
asjad	doc_491521501892_item	2546850	et	3	main
et	doc_491521501892_item	2546853	et	3	main
loppuni	doc_491521501892_item	2546855	et	4	main
ja	doc_491521501892_item	2546856	et	3	main
annan	doc_491521501892_item	2546857	et	3	main
sulle	doc_491521501892_item	2546858	et	3	main
yhe	doc_491521501892_item	2546859	et	4	main
ma	doc_491521501892_item	2546876	et	3	main
töö	doc_491521501892_item	2546880	et	4	main
fimi	doc_491521501892_item	2546888	et	4	main
ja	doc_491521501892_item	2546889	et	3	main
kord	doc_491521501892_item	2546923	et	4	main
nädalavahetus	doc_491521501892_item	2546925	et	4	main
voiks	doc_491521501892_item	2546928	et	4	main
äkki	doc_491521501892_item	2546930	et	3	main
ära	doc_491521501892_item	2546932	et	4	main
teha	doc_491521501892_item	2546933	et	3	main
vaipade	doc_491521501892_item	2546934	et	3	main
pildisdamiseks	doc_491521501892_item	2546935	et	4	main
ilma	doc_491521501892_item	2546943	et	4	main
teata	doc_491521501892_item	2546958	et	4	main
mis	doc_491521501892_item	2546959	et	4	main
arvad	doc_491521501892_item	2546960	et	3	main
eesnimi	doc_491521501892_item	2546961	et	3	main
panin	doc_491521501892_item	2546971	et	3	main
e-1	doc_491521501892_item	2546524	et	4	main
ainuld	doc_491521501892_item	2546539	et	4	main
2	doc_491521501892_item	2546544	et	2	main
abimäärsona	doc_491521501892_item	2546556	et	4	main
rektsioonivead	doc_491521501892_item	2546558	et	4	main
kiri	doc_491521501892_item	2546564	et	3	main
siin	doc_491521501892_item	2546566	et	4	main
on	doc_491521501892_item	2546567	et	4	main
kõnekeel	doc_491521501892_item	2546572	et	4	main
võtma	doc_491521501892_item	2546575	et	3	main
voi	doc_491521501892_item	2546579	et	4	main
keeles	doc_491521501892_item	2546596	et	4	main
eest	doc_491521501892_item	2546606	et	4	main
mille	doc_491521501892_item	2546607	et	3	main
kirjas	doc_491521501892_item	2546614	et	4	main
vaib	doc_491521501892_item	2546620	et	4	main
vastu	doc_491521501892_item	2546624	et	3	main
leidsin	doc_491521501892_item	2546627	et	3	main
kulud	doc_491521501892_item	2546636	et	4	main
suure	doc_491521501892_item	2546641	et	3	main
teise	doc_491521501892_item	2546646	et	4	main
kõnekeele	doc_491521501892_item	2546654	et	4	main
3	doc_491521501892_item	2546656	et	2	main
leidsin	doc_491521501892_item	2546664	et	3	main
oleks	doc_491521501892_item	2546675	et	3	main
e	doc_491521501892_item	2546687	et	4	main
arvatavasti	doc_491521501892_item	2546688	et	3	main
moodustanud	doc_491521501892_item	2546689	et	4	main
üle	doc_491521501892_item	2546690	et	3	main
jõu	doc_491521501892_item	2546691	et	3	main
veel	doc_491521501892_item	2546695	et	4	main
nagu	doc_491521501892_item	2546701	et	3	main
piisavalt	doc_491521501892_item	2546704	et	4	main
olen	doc_491521501892_item	2546706	et	3	main
järgmine	doc_491521501892_item	2546707	et	3	main
see	doc_491521501892_item	2546709	et	3	main
kõnekeele	doc_491521501892_item	2546723	et	4	main
kiri	doc_491521501892_item	2546743	et	3	main
ei	doc_491521501892_item	2546753	et	4	main
kasutata	doc_491521501892_item	2546754	et	3	main
pigem	doc_491521501892_item	2546755	et	3	main
see	doc_491521501892_item	2546758	et	3	main
kui	doc_491521501892_item	2546762	et	3	main
sõnavead	doc_491521501892_item	2546765	et	3	main
keelest	doc_491521501892_item	2546774	et	4	main
muidu	doc_491521501892_item	2546775	et	3	main
kiri	doc_491521501892_item	2546780	et	3	main
sõna	doc_491521501892_item	2546822	et	4	main
oma	doc_491521501892_item	2546828	et	4	main
vastele	doc_491521501892_item	2546830	et	3	main
kuidas	doc_491521501892_item	2546838	et	3	main
töö	doc_491521501892_item	2546840	et	4	main
teie	doc_491521501892_item	2546849	et	4	main
interjöörist	doc_491521501892_item	2546868	et	3	main
saan	doc_491521501892_item	2546872	et	4	main
käest	doc_491521501892_item	2546874	et	4	main
arvan	doc_491521501892_item	2546877	et	3	main
materiaali	doc_491521501892_item	2546881	et	4	main
oleks	doc_491521501892_item	2546883	et	3	main
järgmine	doc_491521501892_item	2546922	et	3	main
päevavalgus	doc_491521501892_item	2546936	et	4	main
oleks	doc_491521501892_item	2546937	et	3	main
ka	doc_491521501892_item	2546944	et	3	main
nagu	doc_491521501892_item	2546948	et	3	main
pole	doc_491521501892_item	2546950	et	3	main
kuule	doc_491521501892_item	2546964	et	4	main
nüüd	doc_491521501892_item	2546966	et	4	main
juhul	doc_491521501892_item	2546968	et	3	main
koolist	doc_491521501892_item	2546972	et	4	main
kinni	doc_491521501892_item	2546974	et	3	main
homme	doc_491521501892_item	2546976	et	3	main
enam	doc_491521501892_item	2546978	et	4	main
aga	doc_491521501892_item	2546983	et	3	main
kui	doc_491521501892_item	2546989	et	3	main
mis	doc_491521501892_item	2546994	et	4	main
siis	doc_491521501892_item	2547023	et	3	main
seal	doc_491521501892_item	2547034	et	4	main
kus	doc_491521501892_item	2547035	et	3	main
kätte	doc_491521501892_item	2547049	et	4	main
pildid	doc_491521501892_item	2547055	et	3	main
igal	doc_491521501892_item	2547071	et	3	main
anda	doc_491521501892_item	2546625	et	3	main
näidet	doc_491521501892_item	2546629	et	3	main
eksitud	doc_491521501892_item	2546632	et	4	main
mõlemad	doc_491521501892_item	2546638	et	3	main
on	doc_491521501892_item	2546643	et	4	main
muidugi	doc_491521501892_item	2546650	et	4	main
olla	doc_491521501892_item	2546651	et	3	main
tegemist	doc_491521501892_item	2546652	et	4	main
ka	doc_491521501892_item	2546653	et	3	main
e-kirjades	doc_491521501892_item	2546660	et	3	main
puhul	doc_491521501892_item	2546669	et	4	main
kahtlen	doc_491521501892_item	2546670	et	3	main
et	doc_491521501892_item	2546671	et	3	main
kas	doc_491521501892_item	2546672	et	3	main
eestlane	doc_491521501892_item	2546674	et	3	main
materiaali	doc_491521501892_item	2546678	et	4	main
on	doc_491521501892_item	2546686	et	4	main
näited	doc_491521501892_item	2546697	et	3	main
interjööris	doc_491521501892_item	2546699	et	3	main
kord	doc_491521501892_item	2546708	et	4	main
nädalavahetus	doc_491521501892_item	2546710	et	4	main
eestis	doc_491521501892_item	2546711	et	3	main
mõlemad	doc_491521501892_item	2546712	et	3	main
kiri	doc_491521501892_item	2546713	et	3	main
1	doc_491521501892_item	2546714	et	2	main
need	doc_491521501892_item	2546715	et	3	main
on	doc_491521501892_item	2546716	et	4	main
juba	doc_491521501892_item	2546717	et	3	main
tavalised	doc_491521501892_item	2546718	et	4	main
ka	doc_491521501892_item	2546719	et	3	main
eestlaste	doc_491521501892_item	2546720	et	4	main
poolt	doc_491521501892_item	2546721	et	4	main
ka	doc_491521501892_item	2546726	et	3	main
võimalikust	doc_491521501892_item	2546729	et	4	main
soome	doc_491521501892_item	2546730	et	3	main
kõnekeele	doc_491521501892_item	2546731	et	4	main
mõjust	doc_491521501892_item	2546732	et	3	main
hakkama	doc_491521501892_item	2546742	et	3	main
et	doc_491521501892_item	2546746	et	3	main
kõnekeeles	doc_491521501892_item	2546749	et	4	main
nii	doc_491521501892_item	2546750	et	3	main
lühikest	doc_491521501892_item	2546751	et	4	main
kui	doc_491521501892_item	2546757	et	3	main
pole	doc_491521501892_item	2546763	et	3	main
leidsin	doc_491521501892_item	2546766	et	3	main
viga	doc_491521501892_item	2546768	et	4	main
arvatavasti	doc_491521501892_item	2546770	et	3	main
on	doc_491521501892_item	2546771	et	4	main
2	doc_491521501892_item	2546781	et	2	main
muuten	doc_491521501892_item	2546786	et	4	main
jos	doc_491521501892_item	2546787	et	4	main
sest	doc_491521501892_item	2546821	et	4	main
samuti	doc_491521501892_item	2546826	et	3	main
korrektselt	doc_491521501892_item	2546833	et	4	main
kuule	doc_491521501892_item	2546837	et	4	main
ära	doc_491521501892_item	2546851	et	4	main
igas	doc_491521501892_item	2546861	et	3	main
vaibast	doc_491521501892_item	2546862	et	4	main
ja	doc_491521501892_item	2546863	et	3	main
tutavatele	doc_491521501892_item	2546864	et	4	main
siis	doc_491521501892_item	2546869	et	3	main
sinu	doc_491521501892_item	2546873	et	3	main
et	doc_491521501892_item	2546878	et	3	main
kulud	doc_491521501892_item	2546882	et	4	main
mulle	doc_491521501892_item	2546884	et	4	main
endale	doc_491521501892_item	2546885	et	4	main
olen	doc_491521501892_item	2546921	et	3	main
eestis	doc_491521501892_item	2546926	et	3	main
hea	doc_491521501892_item	2546938	et	4	main
kui	doc_491521501892_item	2546939	et	3	main
voimatu	doc_491521501892_item	2546940	et	4	main
interjööris	doc_491521501892_item	2546946	et	3	main
nii	doc_491521501892_item	2546949	et	3	main
puhul	doc_491521501892_item	2546648	et	4	main
voib	doc_491521501892_item	2546649	et	4	main
mõjuga	doc_491521501892_item	2546655	et	3	main
sõnatasand	doc_491521501892_item	2546657	et	3	main
palju	doc_491521501892_item	2546662	et	4	main
siiski	doc_491521501892_item	2546665	et	4	main
ühe	doc_491521501892_item	2546666	et	4	main
kirjutanud	doc_491521501892_item	2546677	et	4	main
oleks	doc_491521501892_item	2546680	et	3	main
lause	doc_491521501892_item	2546694	et	4	main
kõnekeelest	doc_491521501892_item	2546698	et	4	main
kindlasti	doc_491521501892_item	2546700	et	3	main
pole	doc_491521501892_item	2546703	et	3	main
ja	doc_491521501892_item	2546705	et	3	main
näited	doc_491521501892_item	2546724	et	3	main
päevavalgus	doc_491521501892_item	2546733	et	4	main
oleks	doc_491521501892_item	2546734	et	3	main
1	doc_491521501892_item	2546744	et	2	main
isegi	doc_491521501892_item	2546747	et	4	main
võimalik	doc_491521501892_item	2546764	et	3	main
kui	doc_491521501892_item	2546776	et	3	main
tundub	doc_491521501892_item	2546778	et	3	main
on	doc_491521501892_item	2546783	et	4	main
põhjustanud	doc_491521501892_item	2546784	et	4	main
keeles	doc_491521501892_item	2546789	et	4	main
sobiks	doc_491521501892_item	2546790	et	4	main
siia	doc_491521501892_item	2546791	et	4	main
muide	doc_491521501892_item	2546792	et	3	main
voi	doc_491521501892_item	2546793	et	4	main
muidugi	doc_491521501892_item	2546794	et	4	main
loomulikult	doc_491521501892_item	2546795	et	4	main
ei	doc_491521501892_item	2546796	et	4	main
saa	doc_491521501892_item	2546797	et	4	main
täielikult	doc_491521501892_item	2546798	et	4	main
välistada	doc_491521501892_item	2546799	et	3	main
et	doc_491521501892_item	2546800	et	3	main
e	doc_491521501892_item	2546801	et	4	main
on	doc_491521501892_item	2546802	et	4	main
ikkagi	doc_491521501892_item	2546803	et	4	main
mõelnud	doc_491521501892_item	2546804	et	4	main
kasutada	doc_491521501892_item	2546805	et	3	main
ühte	doc_491521501892_item	2546806	et	4	main
neist	doc_491521501892_item	2546807	et	4	main
aga	doc_491521501892_item	2546808	et	3	main
on	doc_491521501892_item	2546809	et	4	main
teinud	doc_491521501892_item	2546810	et	4	main
lihtsalt	doc_491521501892_item	2546811	et	4	main
hooletusvea	doc_491521501892_item	2546812	et	4	main
viga	doc_491521501892_item	2546813	et	4	main
sõnas	doc_491521501892_item	2546814	et	4	main
materiaali	doc_491521501892_item	2546815	et	4	main
kiri	doc_491521501892_item	2546816	et	3	main
1	doc_491521501892_item	2546817	et	2	main
oli	doc_491521501892_item	2546818	et	3	main
natuke	doc_491521501892_item	2546819	et	4	main
üllatav	doc_491521501892_item	2546820	et	4	main
on	doc_491521501892_item	2546825	et	4	main
sarnane	doc_491521501892_item	2546827	et	4	main
soomekeelsele	doc_491521501892_item	2546829	et	3	main
kirjutatud	doc_491521501892_item	2546834	et	4	main
1	doc_491521501892_item	2546836	et	2	main
diil	doc_491521501892_item	2546842	et	4	main
ma	doc_491521501892_item	2546843	et	3	main
motlen	doc_491521501892_item	2546844	et	4	main
ilma	doc_491521501892_item	2546740	et	4	main
ka	doc_491521501892_item	2546741	et	3	main
eesti	doc_491521501892_item	2546748	et	4	main
ikkagi	doc_491521501892_item	2546756	et	4	main
on	doc_491521501892_item	2546759	et	4	main
võimatu	doc_491521501892_item	2546760	et	4	main
kaks	doc_491521501892_item	2546767	et	3	main
mis	doc_491521501892_item	2546769	et	4	main
mõjutatud	doc_491521501892_item	2546772	et	4	main
soome	doc_491521501892_item	2546773	et	3	main
vea	doc_491521501892_item	2546782	et	4	main
soomekeelne	doc_491521501892_item	2546785	et	3	main
eesti	doc_491521501892_item	2546788	et	4	main
interjöör	doc_491521501892_item	2546823	et	3	main
e-1	doc_491521501892_item	2546832	et	4	main
piltistan	doc_491521501892_item	2546848	et	4	main
ytleme	doc_491521501892_item	2546852	et	4	main
algust	doc_491521501892_item	2546854	et	4	main
näiteks	doc_491521501892_item	2546865	et	4	main
viis	doc_491521501892_item	2546866	et	4	main
selle	doc_491521501892_item	2546870	et	4	main
vaiba	doc_491521501892_item	2546875	et	3	main
sellise	doc_491521501892_item	2546879	et	4	main
aega	doc_491521501892_item	2546890	et	4	main
läheks	doc_491521501892_item	2546891	et	3	main
pildistamisele	doc_491521501892_item	2546892	et	4	main
ytleme	doc_491521501892_item	2546893	et	4	main
yks	doc_491521501892_item	2546894	et	4	main
päev	doc_491521501892_item	2546895	et	3	main
ja	doc_491521501892_item	2546896	et	3	main
ilmuttamisele	doc_491521501892_item	2546897	et	4	main
ja	doc_491521501892_item	2546898	et	3	main
printtimisele	doc_491521501892_item	2546899	et	4	main
3-4	doc_491521501892_item	2546900	et	2	main
kuna	doc_491521501892_item	2546902	et	3	main
pean	doc_491521501892_item	2546903	et	4	main
päeva	doc_491521501892_item	2546901	et	4	main
kõige	doc_491521501892_item	2546904	et	4	main
käsitse	doc_491521501892_item	2546905	et	4	main
tegema	doc_491521501892_item	2546906	et	3	main
ytle	doc_491521501892_item	2546907	et	4	main
mis	doc_491521501892_item	2546908	et	4	main
arvad	doc_491521501892_item	2546909	et	3	main
ja	doc_491521501892_item	2546910	et	3	main
kus	doc_491521501892_item	2546911	et	3	main
see	doc_491521501892_item	2546912	et	3	main
koht	doc_491521501892_item	2546913	et	3	main
asub	doc_491521501892_item	2546914	et	3	main
kus	doc_491521501892_item	2546915	et	3	main
peaks	doc_491521501892_item	2546916	et	4	main
pildisdama	doc_491521501892_item	2546917	et	4	main
ma	doc_491521501892_item	2546918	et	3	main
arvan	doc_491521501892_item	2546919	et	3	main
et	doc_491521501892_item	2546920	et	3	main
ja	doc_491521501892_item	2546927	et	3	main
siis	doc_491521501892_item	2546929	et	3	main
siis	doc_491521501892_item	2546941	et	3	main
saab	doc_491521501892_item	2546942	et	3	main
piisavalt	doc_491521501892_item	2546951	et	4	main
kiri	doc_491521501892_item	2546962	et	3	main
ja	doc_491521501892_item	2546970	et	3	main
kaamera	doc_491521501892_item	2546973	et	4	main
kuna	doc_491521501892_item	2546975	et	3	main
kui	doc_491521501892_item	2546984	et	3	main
et	doc_491521501892_item	2546845	et	3	main
kui	doc_491521501892_item	2546846	et	3	main
ma	doc_491521501892_item	2546847	et	3	main
printi	doc_491521501892_item	2546860	et	4	main
pilti	doc_491521501892_item	2546867	et	4	main
eest	doc_491521501892_item	2546871	et	4	main
umbes	doc_491521501892_item	2546886	et	4	main
300	doc_491521501892_item	2546887	et	2	main
see	doc_491521501892_item	2546924	et	3	main
kohe	doc_491521501892_item	2546931	et	4	main
hakkama	doc_491521501892_item	2546945	et	3	main
kindlasti	doc_491521501892_item	2546947	et	3	main
päevavalgust	doc_491521501892_item	2546952	et	4	main
ja	doc_491521501892_item	2546953	et	3	main
peab	doc_491521501892_item	2546954	et	4	main
2	doc_491521501892_item	2546963	et	2	main
igal	doc_491521501892_item	2546967	et	3	main
ei	doc_491521501892_item	2546979	et	4	main
jõuad	doc_491521501892_item	2546985	et	3	main
ütled	doc_491521501892_item	2546990	et	3	main
pean	doc_491521501892_item	2546995	et	4	main
kaas	doc_491521501892_item	2546996	et	3	main
võtma	doc_491521501892_item	2546997	et	3	main
vaatan	doc_491521501892_item	2546998	et	3	main
meile	doc_491521501892_item	2546999	et	4	main
veel	doc_491521501892_item	2547000	et	4	main
täna	doc_491521501892_item	2547001	et	4	main
õhtul	doc_491521501892_item	2547002	et	3	main
kindlasti	doc_491521501892_item	2547003	et	3	main
ja	doc_491521501892_item	2547004	et	3	main
loodan	doc_491521501892_item	2547005	et	3	main
et	doc_491521501892_item	2547006	et	3	main
homme	doc_491521501892_item	2547007	et	3	main
ka	doc_491521501892_item	2547008	et	3	main
veel	doc_491521501892_item	2547009	et	4	main
enne	doc_491521501892_item	2547010	et	4	main
kahtteist	doc_491521501892_item	2547011	et	4	main
muidu	doc_491521501892_item	2547012	et	3	main
kui	doc_491521501892_item	2547013	et	3	main
sulle	doc_491521501892_item	2547014	et	3	main
tundub	doc_491521501892_item	2547015	et	3	main
et	doc_491521501892_item	2547016	et	3	main
vaib	doc_491521501892_item	2547017	et	4	main
on	doc_491521501892_item	2547018	et	4	main
sellest	doc_491521501892_item	2547019	et	4	main
palju	doc_491521501892_item	2547020	et	4	main
anda	doc_491521501892_item	2547022	et	3	main
ka	doc_491521501892_item	2547026	et	3	main
ainuld	doc_491521501892_item	2547030	et	4	main
nüüd	doc_491521501892_item	2547037	et	4	main
aga	doc_491521501892_item	2547039	et	3	main
jättan	doc_491521501892_item	2547045	et	4	main
siis	doc_491521501892_item	2547046	et	3	main
filmi	doc_491521501892_item	2547047	et	4	main
sinu	doc_491521501892_item	2547048	et	3	main
pildistamine	doc_491521501892_item	2547065	et	4	main
ja	doc_491521501892_item	2547068	et	3	main
teata	doc_491521501892_item	2547076	et	4	main
onju	doc_491521501892_item	2547078	et	4	main
tulen	doc_491521501892_item	2547083	et	3	main
nii	doc_491521501892_item	2547123	et	3	main
enne	doc_491521501892_item	2547131	et	4	main
keele	doc_491521501893_item	2547139	et	4	main
õppejõud	doc_491521501893_item	2547147	et	4	main
2001	doc_491521501893_item	2547148	et	2	main
miksima	doc_491521501892_item	2546955	et	4	main
välguga	doc_491521501892_item	2546956	et	3	main
aga	doc_491521501892_item	2546957	et	3	main
ostsin	doc_491521501892_item	2546965	et	3	main
filmi	doc_491521501892_item	2546969	et	4	main
jõua	doc_491521501892_item	2546980	et	4	main
seda	doc_491521501892_item	2546981	et	3	main
hea	doc_491521501892_item	2546988	et	4	main
on	doc_491521501892_item	2546992	et	4	main
vist	doc_491521501892_item	2546977	et	4	main
teha	doc_491521501892_item	2546982	et	3	main
ikkagi	doc_491521501892_item	2546987	et	4	main
teaksin	doc_491521501892_item	2546993	et	3	main
võib	doc_491521501892_item	2547024	et	3	main
teha	doc_491521501892_item	2547027	et	3	main
pildistan	doc_491521501892_item	2547029	et	3	main
need	doc_491521501892_item	2547031	et	3	main
interjööri	doc_491521501892_item	2547043	et	4	main
ära	doc_491521501892_item	2547044	et	4	main
ja	doc_491521501892_item	2547050	et	3	main
need	doc_491521501892_item	2547054	et	3	main
on	doc_491521501892_item	2547066	et	4	main
lihtne	doc_491521501892_item	2547067	et	3	main
aga	doc_491521501892_item	2547075	et	3	main
kahe	doc_491521501892_item	2547087	et	3	main
siis	doc_491521501892_item	2547090	et	3	main
see	doc_491521501892_item	2547092	et	3	main
arutada	doc_491521501892_item	2547121	et	3	main
näiteks	doc_491521501892_item	2547132	et	4	main
kui	doc_491521501892_item	2547133	et	3	main
eesti	doc_491521501893_item	2547138	et	4	main
õppetool	doc_491521501893_item	2547142	et	3	main
veaanalüüs	doc_491521501893_item	2547144	et	4	main
koostaja	doc_491521501893_item	2547145	et	4	main
ev-51	doc_491521501893_item	2547146	et	4	main
õpilastele	doc_491521501893_item	2547155	et	4	main
pole	doc_491521501893_item	2547156	et	3	main
laste	doc_491521501893_item	2547174	et	4	main
käi	doc_491521501893_item	2547180	et	4	main
olla	doc_491521501893_item	2547182	et	3	main
looduse	doc_491521501893_item	2547183	et	4	main
alla	doc_491521501893_item	2547192	et	3	main
vaba	doc_491521501893_item	2547193	et	4	main
käima	doc_491521501893_item	2547221	et	4	main
käände	doc_491521501893_item	2547228	et	4	main
vead	doc_491521501893_item	2547230	et	4	main
ei	doc_491521501893_item	2547235	et	4	main
tunnides	doc_491521501893_item	2547238	et	4	main
viimane	doc_491521501893_item	2547245	et	3	main
aasta	doc_491521501893_item	2547246	et	4	main
mäletame	doc_491521501893_item	2547248	et	3	main
vahetame	doc_491521501893_item	2547259	et	3	main
sain	doc_491521501893_item	2547261	et	3	main
keelt	doc_491521501893_item	2547276	et	4	main
natuke	doc_491521501893_item	2547282	et	4	main
eesti	doc_491521501893_item	2547283	et	4	main
rohi	doc_491521501893_item	2547288	et	4	main
on	doc_491521501893_item	2547292	et	4	main
verbi	doc_491521501893_item	2547294	et	4	main
ühildumisel	doc_491521501893_item	2547295	et	4	main
inimestega	doc_491521501893_item	2547342	et	3	main
keelelaagris	doc_491521501893_item	2547346	et	3	main
tahsin	doc_491521501893_item	2547353	et	4	main
siin	doc_491521501893_item	2547357	et	4	main
sõita	doc_491521501893_item	2547361	et	3	main
jalutama	doc_491521501893_item	2547366	et	3	main
matkal	doc_491521501893_item	2547368	et	3	main
jalutada	doc_491521501893_item	2547370	et	3	main
tahan	doc_491521501893_item	2547371	et	3	main
seda	doc_491521501893_item	2547372	et	3	main
seda	doc_491521501893_item	2547376	et	3	main
siia	doc_491521501893_item	2547385	et	4	main
õppima	doc_491521501893_item	2547386	et	3	main
tahaksin	doc_491521501893_item	2547395	et	3	main
ei	doc_491521501893_item	2547422	et	4	main
on	doc_491521501893_item	2547425	et	4	main
noorematel	doc_491521501893_item	2547435	et	4	main
lastel	doc_491521501893_item	2547436	et	4	main
kl	doc_491521501893_item	2547440	et	4	main
kl	doc_491521501893_item	2547453	et	4	main
samu	doc_491521501893_item	2547457	et	3	main
tööb	doc_491521501893_item	2547458	et	4	main
naabritest	doc_491521501893_item	2547463	et	4	main
sellist	doc_491521501893_item	2547471	et	4	main
osalejate	doc_491521501893_item	2547477	et	4	main
mänge	doc_491521501893_item	2547482	et	3	main
oleks	doc_491521501892_item	2546986	et	3	main
kuidas	doc_491521501892_item	2546991	et	3	main
vastu	doc_491521501892_item	2547021	et	3	main
sinu	doc_491521501892_item	2547032	et	3	main
olid	doc_491521501892_item	2547038	et	4	main
saad	doc_491521501892_item	2547052	et	4	main
kusgilt	doc_491521501892_item	2547056	et	4	main
morganist	doc_491521501892_item	2547058	et	3	main
tellida	doc_491521501892_item	2547059	et	3	main
onju	doc_491521501892_item	2547060	et	4	main
arvan	doc_491521501892_item	2547061	et	3	main
et	doc_491521501892_item	2547062	et	3	main
see	doc_491521501892_item	2547063	et	3	main
vaipade	doc_491521501892_item	2547064	et	3	main
saab	doc_491521501892_item	2547070	et	3	main
juhul	doc_491521501892_item	2547072	et	3	main
noh	doc_491521501892_item	2547074	et	3	main
3	doc_491521501892_item	2547081	et	2	main
ma	doc_491521501892_item	2547082	et	3	main
kort	doc_491521501892_item	2547085	et	4	main
pärast	doc_491521501892_item	2547089	et	4	main
kui	doc_491521501892_item	2547091	et	3	main
umbes	doc_491521501892_item	2547125	et	4	main
tulen	doc_491521501892_item	2547127	et	3	main
voi	doc_491521501892_item	2547128	et	4	main
siis	doc_491521501892_item	2547129	et	3	main
kontrastiivlingvistika	doc_491521501893_item	2547136	et	4	main
vead	doc_491521501893_item	2547154	et	4	main
olla	doc_491521501893_item	2547159	et	3	main
pole	doc_491521501893_item	2547161	et	3	main
lauas	doc_491521501893_item	2547163	et	3	main
kooli	doc_491521501893_item	2547178	et	4	main
ajal	doc_491521501893_item	2547194	et	4	main
objekti	doc_491521501893_item	2547227	et	4	main
kl	doc_491521501893_item	2547232	et	4	main
meie	doc_491521501893_item	2547244	et	4	main
koolis	doc_491521501893_item	2547247	et	4	main
viimast	doc_491521501893_item	2547250	et	4	main
aastat	doc_491521501893_item	2547251	et	3	main
riideid	doc_491521501893_item	2547260	et	3	main
vead	doc_491521501893_item	2547268	et	4	main
tahaksin	doc_491521501893_item	2547269	et	3	main
õppida	doc_491521501893_item	2547270	et	3	main
eesti	doc_491521501893_item	2547271	et	4	main
eesti	doc_491521501893_item	2547275	et	4	main
eesti	doc_491521501893_item	2547279	et	4	main
õppisin	doc_491521501893_item	2547281	et	3	main
roheline	doc_491521501893_item	2547290	et	4	main
sihilise	doc_491521501893_item	2547293	et	4	main
kolme	doc_491521501893_item	2547300	et	4	main
käände	doc_491521501893_item	2547301	et	4	main
vahel	doc_491521501893_item	2547302	et	4	main
sageli	doc_491521501893_item	2547303	et	3	main
kasutatakse	doc_491521501893_item	2547304	et	3	main
nimetavat	doc_491521501893_item	2547305	et	4	main
nii	doc_491521501892_item	2547025	et	3	main
et	doc_491521501892_item	2547028	et	3	main
vaibad	doc_491521501892_item	2547033	et	3	main
nad	doc_491521501892_item	2547036	et	3	main
jättaks	doc_491521501892_item	2547040	et	4	main
siis	doc_491521501892_item	2547041	et	3	main
selle	doc_491521501892_item	2547042	et	4	main
sa	doc_491521501892_item	2547051	et	3	main
ise	doc_491521501892_item	2547053	et	4	main
näiteks	doc_491521501892_item	2547057	et	4	main
seda	doc_491521501892_item	2547069	et	3	main
teha	doc_491521501892_item	2547073	et	3	main
ilmselt	doc_491521501892_item	2547086	et	4	main
klaasi	doc_491521501892_item	2547094	et	4	main
näitus	doc_491521501892_item	2547095	et	3	main
avatakse	doc_491521501892_item	2547096	et	4	main
aga	doc_491521501892_item	2547097	et	3	main
see	doc_491521501892_item	2547098	et	3	main
on	doc_491521501892_item	2547099	et	4	main
vist	doc_491521501892_item	2547100	et	4	main
umbes	doc_491521501892_item	2547101	et	4	main
just	doc_491521501892_item	2547102	et	3	main
20	doc_491521501892_item	2547103	et	2	main
nii	doc_491521501892_item	2547104	et	3	main
et	doc_491521501892_item	2547105	et	3	main
voib	doc_491521501892_item	2547106	et	4	main
olla	doc_491521501892_item	2547107	et	3	main
siis	doc_491521501892_item	2547108	et	3	main
ka	doc_491521501892_item	2547109	et	3	main
ei	doc_491521501892_item	2547110	et	4	main
joua	doc_491521501892_item	2547111	et	4	main
pildistada	doc_491521501892_item	2547112	et	3	main
aga	doc_491521501892_item	2547113	et	3	main
kui	doc_491521501892_item	2547114	et	3	main
vähemalt	doc_491521501892_item	2547115	et	4	main
kokku	doc_491521501892_item	2547116	et	3	main
saaks	doc_491521501892_item	2547117	et	3	main
siis	doc_491521501892_item	2547118	et	3	main
saaks	doc_491521501892_item	2547119	et	3	main
asja	doc_491521501892_item	2547120	et	4	main
päeva	doc_491521501892_item	2547130	et	4	main
veaanalüüs	doc_491521501893_item	2547137	et	4	main
võõrkeele	doc_491521501893_item	2547141	et	4	main
kontrastiivlingvistika	doc_491521501893_item	2547143	et	4	main
kohakäänete	doc_491521501893_item	2547149	et	3	main
12	doc_491521501893_item	2547151	et	2	main
kl	doc_491521501893_item	2547152	et	4	main
õpilase	doc_491521501893_item	2547153	et	3	main
koolis	doc_491521501893_item	2547158	et	4	main
vaja	doc_491521501893_item	2547162	et	4	main
ungari	doc_491521501893_item	2547165	et	4	main
ei	doc_491521501893_item	2547176	et	4	main
olla	doc_491521501893_item	2547185	et	3	main
vabal	doc_491521501893_item	2547195	et	3	main
siis	doc_491521501892_item	2547077	et	3	main
eesnimi	doc_491521501892_item	2547079	et	3	main
kiri	doc_491521501892_item	2547080	et	3	main
järgmine	doc_491521501892_item	2547084	et	3	main
nädala	doc_491521501892_item	2547088	et	3	main
kätlini	doc_491521501892_item	2547093	et	4	main
onju	doc_491521501892_item	2547122	et	4	main
et	doc_491521501892_item	2547124	et	3	main
20ndal	doc_491521501892_item	2547126	et	4	main
vaja	doc_491521501892_item	2547134	et	4	main
eesnimi	doc_491521501892_item	2547135	et	3	main
kui	doc_491521501893_item	2547140	et	3	main
vead	doc_491521501893_item	2547150	et	4	main
õpilastel	doc_491521501893_item	2547160	et	4	main
osalenud	doc_491521501893_item	2547173	et	4	main
käi	doc_491521501893_item	2547177	et	4	main
ei	doc_491521501893_item	2547179	et	4	main
koolis	doc_491521501893_item	2547181	et	4	main
all	doc_491521501893_item	2547189	et	3	main
viidi	doc_491521501893_item	2547190	et	4	main
duši	doc_491521501893_item	2547191	et	2	main
ajal	doc_491521501893_item	2547196	et	4	main
kohakäänete	doc_491521501893_item	2547197	et	3	main
valikul	doc_491521501893_item	2547198	et	3	main
on	doc_491521501893_item	2547199	et	4	main
sageli	doc_491521501893_item	2547200	et	3	main
vea	doc_491521501893_item	2547201	et	4	main
põhjuseks	doc_491521501893_item	2547202	et	3	main
sise-	doc_491521501893_item	2547203	et	4	main
ja	doc_491521501893_item	2547204	et	3	main
väliskohakäänete	doc_491521501893_item	2547205	et	3	main
kasutamise	doc_491521501893_item	2547206	et	4	main
ebaõigsus	doc_491521501893_item	2547207	et	3	main
eriti	doc_491521501893_item	2547208	et	3	main
gümnaasiumiõpilasel	doc_491521501893_item	2547209	et	3	main
samuti	doc_491521501893_item	2547210	et	3	main
põhjustab	doc_491521501893_item	2547211	et	3	main
vigu	doc_491521501893_item	2547212	et	3	main
verbi	doc_491521501893_item	2547213	et	4	main
rektsiooni	doc_491521501893_item	2547214	et	4	main
erinevus	doc_491521501893_item	2547215	et	4	main
vene	doc_491521501893_item	2547216	et	4	main
keelega	doc_491521501893_item	2547217	et	3	main
nt	doc_491521501893_item	2547218	et	4	main
vene	doc_491521501893_item	2547219	et	4	main
keeles	doc_491521501893_item	2547220	et	4	main
kuhu	doc_491521501893_item	2547222	et	3	main
käima	doc_491521501893_item	2547225	et	4	main
kus	doc_491521501893_item	2547226	et	3	main
pinge	doc_491521501893_item	2547237	et	4	main
tunne	doc_491521501893_item	2547240	et	4	main
pinget	doc_491521501893_item	2547241	et	3	main
tundides	doc_491521501893_item	2547242	et	3	main
määletame	doc_491521501893_item	2547243	et	4	main
koolis	doc_491521501893_item	2547252	et	4	main
vahetame	doc_491521501893_item	2547253	et	3	main
riided	doc_491521501893_item	2547254	et	3	main
riided	doc_491521501893_item	2547258	et	3	main
kingituse	doc_491521501893_item	2547264	et	4	main
osalenud	doc_491521501893_item	2547266	et	4	main
laste	doc_491521501893_item	2547267	et	4	main
tahaksin	doc_491521501893_item	2547273	et	3	main
keelt	doc_491521501893_item	2547284	et	4	main
vaja	doc_491521501893_item	2547157	et	4	main
laual	doc_491521501893_item	2547164	et	3	main
ungarisse	doc_491521501893_item	2547166	et	4	main
tulin	doc_491521501893_item	2547167	et	3	main
tööst	doc_491521501893_item	2547168	et	3	main
tulin	doc_491521501893_item	2547169	et	3	main
töölt	doc_491521501893_item	2547170	et	3	main
suvises	doc_491521501893_item	2547171	et	4	main
keelelaagris	doc_491521501893_item	2547172	et	3	main
vead	doc_491521501893_item	2547175	et	4	main
ääres	doc_491521501893_item	2547184	et	4	main
looduses	doc_491521501893_item	2547186	et	4	main
viidi	doc_491521501893_item	2547187	et	4	main
dušši	doc_491521501893_item	2547188	et	2	main
eesti	doc_491521501893_item	2547223	et	4	main
keeles	doc_491521501893_item	2547224	et	4	main
õpilase	doc_491521501893_item	2547233	et	3	main
oma	doc_491521501893_item	2547249	et	4	main
vahetame	doc_491521501893_item	2547255	et	3	main
ostma	doc_491521501893_item	2547257	et	3	main
kingitust	doc_491521501893_item	2547262	et	4	main
keel	doc_491521501893_item	2547272	et	4	main
õppida	doc_491521501893_item	2547274	et	3	main
natukene	doc_491521501893_item	2547278	et	4	main
keeles	doc_491521501893_item	2547280	et	4	main
roheline	doc_491521501893_item	2547287	et	4	main
probleemne	doc_491521501893_item	2547291	et	3	main
12	doc_491521501893_item	2547322	et	2	main
vead	doc_491521501893_item	2547331	et	4	main
tahan	doc_491521501893_item	2547332	et	3	main
seda	doc_491521501893_item	2547333	et	3	main
õued	doc_491521501893_item	2547340	et	3	main
kubisevad	doc_491521501893_item	2547341	et	4	main
kubisevad	doc_491521501893_item	2547344	et	4	main
siin	doc_491521501893_item	2547354	et	4	main
sõita	doc_491521501893_item	2547359	et	3	main
matkal	doc_491521501893_item	2547364	et	3	main
käia	doc_491521501893_item	2547369	et	4	main
keelt	doc_491521501893_item	2547383	et	4	main
tulin	doc_491521501893_item	2547384	et	3	main
keelt	doc_491521501893_item	2547392	et	4	main
tahaksin	doc_491521501893_item	2547393	et	3	main
puhkama	doc_491521501893_item	2547394	et	3	main
meeldib	doc_491521501893_item	2547399	et	3	main
üks	doc_491521501893_item	2547402	et	3	main
lastel	doc_491521501893_item	2547410	et	4	main
on	doc_491521501893_item	2547411	et	4	main
da-	doc_491521501893_item	2547415	et	4	main
mida	doc_491521501893_item	2547419	et	4	main
gümnaasiumiõpilasel	doc_491521501893_item	2547420	et	3	main
kindlasti	doc_491521501893_item	2547427	et	3	main
12	doc_491521501893_item	2547439	et	2	main
õpilase	doc_491521501893_item	2547441	et	3	main
näevad	doc_491521501893_item	2547443	et	3	main
teisi	doc_491521501893_item	2547444	et	4	main
viimane	doc_491521501893_item	2547445	et	3	main
aasta	doc_491521501893_item	2547446	et	4	main
näevad	doc_491521501893_item	2547447	et	3	main
õpilase	doc_491521501893_item	2547454	et	3	main
töötab	doc_491521501893_item	2547459	et	3	main
riiku	doc_491521501893_item	2547464	et	4	main
ärge	doc_491521501893_item	2547468	et	3	main
ükski	doc_491521501893_item	2547472	et	4	main
üheski	doc_491521501893_item	2547474	et	4	main
keelelaagris	doc_491521501893_item	2547476	et	3	main
vead	doc_491521501893_item	2547478	et	4	main
mängida	doc_491521501893_item	2547479	et	3	main
meeldis	doc_491521501893_item	2547525	et	3	main
eestlastega	doc_491521501893_item	2547537	et	4	main
lapse	doc_491521501893_item	2547538	et	4	main
tekitab	doc_491521501893_item	2547554	et	3	main
mitmuse	doc_491521501893_item	2547555	et	3	main
osastava	doc_491521501893_item	2547556	et	4	main
sest	doc_491521501893_item	2547562	et	4	main
saamaoskamavõima	doc_491521501893_item	2547575	et	4	main
sõnade	doc_491521501893_item	2547576	et	3	main
ebaõige	doc_491521501893_item	2547577	et	4	main
puhul	doc_491521501893_item	2547582	et	4	main
vormimoodustusvigu	doc_491521501893_item	2547592	et	4	main
keelelaagrilaste	doc_491521501893_item	2547598	et	4	main
räägida	doc_491521501893_item	2547601	et	4	main
valiku	doc_491521501893_item	2547229	et	3	main
12	doc_491521501893_item	2547231	et	2	main
vead	doc_491521501893_item	2547234	et	4	main
tunne	doc_491521501893_item	2547236	et	4	main
ei	doc_491521501893_item	2547239	et	4	main
riideid	doc_491521501893_item	2547256	et	3	main
sain	doc_491521501893_item	2547263	et	3	main
keelelaagris	doc_491521501893_item	2547265	et	3	main
õppisin	doc_491521501893_item	2547277	et	3	main
on	doc_491521501893_item	2547286	et	4	main
õige	doc_491521501893_item	2547296	et	4	main
kui	doc_491521501893_item	2547306	et	3	main
tegelikult	doc_491521501893_item	2547307	et	4	main
on	doc_491521501893_item	2547308	et	4	main
õige	doc_491521501893_item	2547309	et	4	main
omastav	doc_491521501893_item	2547310	et	4	main
või	doc_491521501893_item	2547311	et	4	main
osastav	doc_491521501893_item	2547312	et	4	main
seega	doc_491521501893_item	2547313	et	4	main
sihitist	doc_491521501893_item	2547314	et	3	main
puudutavas	doc_491521501893_item	2547315	et	4	main
osas	doc_491521501893_item	2547316	et	4	main
on	doc_491521501893_item	2547317	et	4	main
teadmised	doc_491521501893_item	2547318	et	4	main
kesised	doc_491521501893_item	2547319	et	3	main
seda	doc_491521501893_item	2547320	et	3	main
ka	doc_491521501893_item	2547321	et	3	main
õpilasel	doc_491521501893_item	2547324	et	3	main
verbi	doc_491521501893_item	2547325	et	4	main
rektsiooni	doc_491521501893_item	2547326	et	4	main
keele	doc_491521501893_item	2547334	et	4	main
osata	doc_491521501893_item	2547335	et	4	main
tahan	doc_491521501893_item	2547336	et	3	main
seda	doc_491521501893_item	2547337	et	3	main
inimestest	doc_491521501893_item	2547345	et	3	main
osalejate	doc_491521501893_item	2547347	et	4	main
jalgrattaga	doc_491521501893_item	2547362	et	3	main
käima	doc_491521501893_item	2547365	et	4	main
töö	doc_491521501893_item	2547373	et	4	main
teha	doc_491521501893_item	2547374	et	3	main
tahan	doc_491521501893_item	2547375	et	3	main
tööd	doc_491521501893_item	2547377	et	4	main
teha	doc_491521501893_item	2547378	et	3	main
tulin	doc_491521501893_item	2547379	et	3	main
eesti	doc_491521501893_item	2547387	et	4	main
puhata	doc_491521501893_item	2547396	et	4	main
joonistada	doc_491521501893_item	2547400	et	3	main
meeldis	doc_491521501893_item	2547404	et	3	main
põhilised	doc_491521501893_item	2547407	et	3	main
keelelaagri	doc_491521501893_item	2547409	et	3	main
ja	doc_491521501893_item	2547414	et	3	main
ebaõige	doc_491521501893_item	2547417	et	4	main
tingitud	doc_491521501893_item	2547426	et	4	main
keeleoskuse	doc_491521501893_item	2547428	et	3	main
keelekeskkonnas	doc_491521501893_item	2547431	et	3	main
viibimise	doc_491521501893_item	2547432	et	4	main
vähestest	doc_491521501893_item	2547433	et	3	main
kogemustest	doc_491521501893_item	2547434	et	4	main
ühildumisvead	doc_491521501893_item	2547438	et	4	main
vead	doc_491521501893_item	2547442	et	4	main
aastat	doc_491521501893_item	2547450	et	3	main
vormimoodustusvead	doc_491521501893_item	2547451	et	4	main
12	doc_491521501893_item	2547452	et	2	main
samaid	doc_491521501893_item	2547456	et	4	main
meie	doc_491521501893_item	2547462	et	4	main
riike	doc_491521501893_item	2547465	et	3	main
rohtu	doc_491521501893_item	2547285	et	4	main
on	doc_491521501893_item	2547289	et	4	main
vormi	doc_491521501893_item	2547297	et	4	main
valik	doc_491521501893_item	2547298	et	3	main
esimese	doc_491521501893_item	2547299	et	3	main
kl	doc_491521501893_item	2547329	et	4	main
õpilase	doc_491521501893_item	2547330	et	3	main
osata	doc_491521501893_item	2547339	et	4	main
mängida	doc_491521501893_item	2547352	et	3	main
tahtsin	doc_491521501893_item	2547356	et	3	main
tahaksin	doc_491521501893_item	2547363	et	3	main
tahaksin	doc_491521501893_item	2547367	et	3	main
eesti	doc_491521501893_item	2547382	et	4	main
et	doc_491521501893_item	2547389	et	3	main
õppida	doc_491521501893_item	2547390	et	3	main
eesti	doc_491521501893_item	2547391	et	4	main
meeldib	doc_491521501893_item	2547397	et	3	main
meeldis	doc_491521501893_item	2547401	et	3	main
päeva	doc_491521501893_item	2547403	et	4	main
päev	doc_491521501893_item	2547406	et	3	main
seotud	doc_491521501893_item	2547412	et	4	main
enam	doc_491521501893_item	2547421	et	4	main
esine	doc_491521501893_item	2547423	et	4	main
see	doc_491521501893_item	2547424	et	3	main
teisi	doc_491521501893_item	2547448	et	4	main
vead	doc_491521501893_item	2547455	et	4	main
naabritest	doc_491521501893_item	2547461	et	4	main
seest	doc_491521501893_item	2547470	et	3	main
olukordas	doc_491521501893_item	2547473	et	4	main
olukorras	doc_491521501893_item	2547475	et	3	main
mängida	doc_491521501893_item	2547481	et	3	main
tahaksin	doc_491521501893_item	2547487	et	3	main
tahaksin	doc_491521501893_item	2547489	et	3	main
õigus	doc_491521501893_item	2547521	et	4	main
keeles	doc_491521501893_item	2547531	et	4	main
oskan	doc_491521501893_item	2547532	et	3	main
rääkida	doc_491521501893_item	2547533	et	3	main
kasulik	doc_491521501893_item	2547546	et	3	main
on	doc_491521501893_item	2547549	et	4	main
on	doc_491521501893_item	2547559	et	4	main
mõneti	doc_491521501893_item	2547560	et	3	main
vorm	doc_491521501893_item	2547564	et	3	main
erinevate	doc_491521501893_item	2547568	et	4	main
tekitab	doc_491521501893_item	2547571	et	3	main
kasutamine	doc_491521501893_item	2547578	et	4	main
sagedane	doc_491521501893_item	2547583	et	3	main
olla	doc_491521501893_item	2547586	et	3	main
keele	doc_491521501893_item	2547589	et	4	main
mõjust	doc_491521501893_item	2547590	et	3	main
osa	doc_491521501893_item	2547591	et	4	main
ortograafiavead	doc_491521501893_item	2547597	et	4	main
ning	doc_491521501893_item	2547627	et	3	main
kirjutamise	doc_491521501893_item	2547629	et	4	main
vead	doc_491521501893_item	2547636	et	4	main
mis	doc_491521501893_item	2547637	et	4	main
mis	doc_491521501893_item	2547642	et	4	main
kuulsate	doc_491521501893_item	2547644	et	3	main
rõivatootjate	doc_491521501893_item	2547645	et	3	main
rõivastega	doc_491521501893_item	2547646	et	4	main
keeles	doc_491521501893_item	2547659	et	4	main
pea	doc_491521501893_item	2547665	et	4	main
eesti	doc_491521501893_item	2547670	et	4	main
on	doc_491521501893_item	2547688	et	4	main
linnas	doc_491521501893_item	2547691	et	4	main
inimesi	doc_491521501893_item	2547697	et	4	main
linnas	doc_491521501893_item	2547698	et	4	main
ei	doc_491521501893_item	2547699	et	4	main
on	doc_491521501893_item	2547732	et	4	main
eesti	doc_491521501893_item	2547743	et	4	main
arvsõna	doc_491521501893_item	2547751	et	4	main
käänamise	doc_491521501893_item	2547752	et	4	main
vead	doc_491521501893_item	2547753	et	4	main
tuhat	doc_491521501893_item	2547756	et	4	main
üheksasaja	doc_491521501893_item	2547757	et	4	main
arvsõnad	doc_491521501893_item	2547761	et	3	main
nii	doc_491521501893_item	2547767	et	3	main
vead	doc_491521501893_item	2547793	et	4	main
ainult	doc_491521501893_item	2547796	et	4	main
et	doc_491521501893_item	2547803	et	3	main
mõlemat	doc_491521501893_item	2547807	et	3	main
только	doc_491521501893_item	2547810	et	2	main
sest	doc_491521501893_item	2547814	et	4	main
kl	doc_491521501893_item	2547323	et	4	main
vead	doc_491521501893_item	2547327	et	4	main
12	doc_491521501893_item	2547328	et	2	main
keelt	doc_491521501893_item	2547338	et	4	main
tänavad	doc_491521501893_item	2547343	et	4	main
vead	doc_491521501893_item	2547348	et	4	main
tahaksin	doc_491521501893_item	2547349	et	3	main
mängima	doc_491521501893_item	2547350	et	3	main
tahaksin	doc_491521501893_item	2547351	et	3	main
mängima	doc_491521501893_item	2547355	et	3	main
mängida	doc_491521501893_item	2547358	et	3	main
jalgrattas	doc_491521501893_item	2547360	et	3	main
siia	doc_491521501893_item	2547380	et	4	main
õppida	doc_491521501893_item	2547381	et	3	main
keelt	doc_491521501893_item	2547388	et	4	main
joonistama	doc_491521501893_item	2547398	et	3	main
üks	doc_491521501893_item	2547405	et	3	main
vead	doc_491521501893_item	2547408	et	4	main
ma-	doc_491521501893_item	2547413	et	3	main
infinitiivi	doc_491521501893_item	2547416	et	4	main
valikuga	doc_491521501893_item	2547418	et	3	main
erinevusest	doc_491521501893_item	2547429	et	4	main
ning	doc_491521501893_item	2547430	et	3	main
muud	doc_491521501893_item	2547437	et	4	main
viimast	doc_491521501893_item	2547449	et	4	main
meietest	doc_491521501893_item	2547460	et	3	main
ei	doc_491521501893_item	2547466	et	4	main
mänguid	doc_491521501893_item	2547480	et	4	main
siija	doc_491521501893_item	2547483	et	4	main
uurja	doc_491521501893_item	2547485	et	4	main
joosta	doc_491521501893_item	2547490	et	4	main
jooksta	doc_491521501893_item	2547488	et	4	main
lemmikud	doc_491521501893_item	2547492	et	3	main
mina	doc_491521501893_item	2547491	et	4	main
aastaajad	doc_491521501893_item	2547493	et	3	main
minu	doc_491521501893_item	2547494	et	3	main
lemmikaastaajad	doc_491521501893_item	2547495	et	3	main
meeldib	doc_491521501893_item	2547496	et	3	main
loema	doc_491521501893_item	2547497	et	4	main
meeldib	doc_491521501893_item	2547498	et	3	main
lugeda	doc_491521501893_item	2547499	et	3	main
mulle	doc_491521501893_item	2547500	et	4	main
ei	doc_491521501893_item	2547501	et	4	main
meeldib	doc_491521501893_item	2547502	et	3	main
mulle	doc_491521501893_item	2547503	et	4	main
ei	doc_491521501893_item	2547504	et	4	main
meeldi	doc_491521501893_item	2547505	et	4	main
neid	doc_491521501893_item	2547506	et	4	main
tööd	doc_491521501893_item	2547507	et	4	main
ei	doc_491521501893_item	2547508	et	4	main
ole	doc_491521501893_item	2547509	et	4	main
need	doc_491521501893_item	2547510	et	3	main
tööd	doc_491521501893_item	2547511	et	4	main
ei	doc_491521501893_item	2547512	et	4	main
ole	doc_491521501893_item	2547513	et	4	main
mul	doc_491521501893_item	2547514	et	3	main
ei	doc_491521501893_item	2547515	et	4	main
ole	doc_491521501893_item	2547516	et	4	main
tõedus	doc_491521501893_item	2547517	et	4	main
mul	doc_491521501893_item	2547518	et	3	main
ei	doc_491521501893_item	2547519	et	4	main
ole	doc_491521501893_item	2547520	et	4	main
meeldisin	doc_491521501893_item	2547522	et	3	main
rahvastepall	doc_491521501893_item	2547524	et	3	main
saan	doc_491521501893_item	2547528	et	4	main
räägin	doc_491521501893_item	2547529	et	3	main
eesti	doc_491521501893_item	2547534	et	4	main
keeles	doc_491521501893_item	2547535	et	4	main
suhtlema	doc_491521501893_item	2547536	et	3	main
tegema	doc_491521501893_item	2547543	et	3	main
on	doc_491521501893_item	2547544	et	4	main
moodustamine	doc_491521501893_item	2547557	et	4	main
kirjutage	doc_491521501893_item	2547467	et	3	main
kirjutage	doc_491521501893_item	2547469	et	3	main
siia	doc_491521501893_item	2547484	et	4	main
uurija	doc_491521501893_item	2547486	et	4	main
rahvastepalli	doc_491521501893_item	2547527	et	4	main
väga	doc_491521501893_item	2547545	et	3	main
tegemine	doc_491521501893_item	2547548	et	4	main
väga	doc_491521501893_item	2547550	et	3	main
kasulik	doc_491521501893_item	2547551	et	3	main
palju	doc_491521501893_item	2547552	et	4	main
probleeme	doc_491521501893_item	2547553	et	3	main
arusaadav	doc_491521501893_item	2547561	et	4	main
mis	doc_491521501893_item	2547584	et	4	main
tingitud	doc_491521501893_item	2547587	et	4	main
on	doc_491521501893_item	2547593	et	4	main
tingitud	doc_491521501893_item	2547594	et	4	main
vead	doc_491521501893_item	2547599	et	4	main
tahaksin	doc_491521501893_item	2547602	et	3	main
kl	doc_491521501893_item	2547634	et	4	main
õpilase	doc_491521501893_item	2547635	et	3	main
vead	doc_491521501893_item	2547648	et	4	main
õppisin	doc_491521501893_item	2547651	et	3	main
juurde	doc_491521501893_item	2547660	et	4	main
alati	doc_491521501893_item	2547666	et	4	main
suurest	doc_491521501893_item	2547673	et	4	main
konstruktsioonivead	doc_491521501893_item	2547675	et	3	main
vead	doc_491521501893_item	2547677	et	4	main
me	doc_491521501893_item	2547678	et	4	main
meie	doc_491521501893_item	2547679	et	4	main
klassiga	doc_491521501893_item	2547680	et	3	main
silmnähtav	doc_491521501893_item	2547687	et	3	main
et	doc_491521501893_item	2547690	et	3	main
mängima	doc_491521501893_item	2547523	et	3	main
mängida	doc_491521501893_item	2547526	et	3	main
eesti	doc_491521501893_item	2547530	et	4	main
suhtlema	doc_491521501893_item	2547539	et	3	main
eesti	doc_491521501893_item	2547540	et	4	main
lastega	doc_491521501893_item	2547541	et	3	main
spordi	doc_491521501893_item	2547542	et	4	main
spordi	doc_491521501893_item	2547547	et	4	main
mis	doc_491521501893_item	2547558	et	4	main
nimetatud	doc_491521501893_item	2547563	et	4	main
raske	doc_491521501893_item	2547566	et	4	main
ka	doc_491521501893_item	2547570	et	3	main
eituse	doc_491521501893_item	2547573	et	4	main
moodustamine	doc_491521501893_item	2547574	et	4	main
venelaste	doc_491521501893_item	2547581	et	4	main
vene	doc_491521501893_item	2547588	et	4	main
astmevaheldusreeglite	doc_491521501893_item	2547595	et	4	main
mittetundmisest	doc_491521501893_item	2547596	et	3	main
tahaksin	doc_491521501893_item	2547600	et	3	main
mõni	doc_491521501893_item	2547604	et	3	main
mõnikord	doc_491521501893_item	2547606	et	3	main
õpetaja	doc_491521501893_item	2547607	et	4	main
pakus	doc_491521501893_item	2547608	et	3	main
seda	doc_491521501893_item	2547609	et	3	main
õpetaja	doc_491521501893_item	2547610	et	4	main
pakkus	doc_491521501893_item	2547611	et	3	main
seda	doc_491521501893_item	2547612	et	3	main
kõik	doc_491521501893_item	2547613	et	4	main
sõprad	doc_491521501893_item	2547614	et	4	main
kõik	doc_491521501893_item	2547615	et	4	main
sõbrad	doc_491521501893_item	2547616	et	3	main
koos	doc_491521501893_item	2547617	et	4	main
sõpratega	doc_491521501893_item	2547618	et	4	main
koos	doc_491521501893_item	2547619	et	4	main
sõpradega	doc_491521501893_item	2547620	et	3	main
need	doc_491521501893_item	2547621	et	3	main
on	doc_491521501893_item	2547623	et	4	main
teadmiste	doc_491521501893_item	2547630	et	4	main
rõivastega	doc_491521501893_item	2547639	et	4	main
sarnane	doc_491521501893_item	2547647	et	4	main
juurde	doc_491521501893_item	2547652	et	4	main
palju	doc_491521501893_item	2547661	et	4	main
tingitud	doc_491521501893_item	2547667	et	4	main
keele	doc_491521501893_item	2547671	et	4	main
oma	doc_491521501893_item	2547682	et	4	main
klassiga	doc_491521501893_item	2547683	et	3	main
pronoomeni	doc_491521501893_item	2547684	et	3	main
silmnähtav	doc_491521501893_item	2547689	et	3	main
palju	doc_491521501893_item	2547696	et	4	main
ajavormi	doc_491521501893_item	2547721	et	4	main
suvi	doc_491521501893_item	2547726	et	3	main
palju	doc_491521501893_item	2547728	et	4	main
lilli	doc_491521501893_item	2547734	et	4	main
arvan	doc_491521501893_item	2547735	et	3	main
et	doc_491521501893_item	2547736	et	3	main
on	doc_491521501893_item	2547739	et	4	main
tingitud	doc_491521501893_item	2547740	et	4	main
vähestest	doc_491521501893_item	2547741	et	3	main
teadmistest	doc_491521501893_item	2547742	et	4	main
selles	doc_491521501893_item	2547749	et	4	main
aastal	doc_491521501893_item	2547760	et	3	main
enamasti	doc_491521501893_item	2547763	et	4	main
vead	doc_491521501893_item	2547795	et	4	main
nüüd	doc_491521501893_item	2547797	et	4	main
alles	doc_491521501893_item	2547798	et	3	main
siis	doc_491521501893_item	2547799	et	3	main
viga	doc_491521501893_item	2547800	et	4	main
on	doc_491521501893_item	2547565	et	4	main
ja	doc_491521501893_item	2547567	et	3	main
variatsioonidega	doc_491521501893_item	2547569	et	3	main
probleeme	doc_491521501893_item	2547572	et	3	main
on	doc_491521501893_item	2547579	et	4	main
ka	doc_491521501893_item	2547580	et	3	main
võib	doc_491521501893_item	2547585	et	3	main
mitte-tundmisest	doc_491521501893_item	2547626	et	4	main
kokku-lahku	doc_491521501893_item	2547628	et	4	main
kuulsate	doc_491521501893_item	2547640	et	3	main
rõivatootjate	doc_491521501893_item	2547641	et	3	main
keelelaagri	doc_491521501893_item	2547649	et	3	main
eesti	doc_491521501893_item	2547653	et	4	main
sõnad	doc_491521501893_item	2547655	et	4	main
sõnu	doc_491521501893_item	2547662	et	4	main
vene	doc_491521501893_item	2547668	et	4	main
sõnajärje	doc_491521501893_item	2547672	et	3	main
erinevusest	doc_491521501893_item	2547674	et	4	main
abituriendi	doc_491521501893_item	2547676	et	3	main
vale	doc_491521501893_item	2547685	et	4	main
kasutus	doc_491521501893_item	2547686	et	4	main
ei	doc_491521501893_item	2547693	et	4	main
kasutus	doc_491521501893_item	2547723	et	4	main
on	doc_491521501893_item	2547725	et	4	main
et	doc_491521501893_item	2547727	et	3	main
lilli	doc_491521501893_item	2547729	et	4	main
sest	doc_491521501893_item	2547730	et	4	main
siis	doc_491521501893_item	2547731	et	3	main
ka	doc_491521501893_item	2547737	et	3	main
keele	doc_491521501893_item	2547746	et	4	main
erinevuse	doc_491521501893_item	2547747	et	4	main
1997	doc_491521501893_item	2547754	et	2	main
aastal	doc_491521501893_item	2547755	et	3	main
katsumuseks	doc_491521501893_item	2547766	et	3	main
eesti	doc_491521501893_item	2547769	et	4	main
vene	doc_491521501893_item	2547804	et	4	main
sama	doc_491521501893_item	2547808	et	4	main
moe	doc_491521501893_item	2547812	et	3	main
vead	doc_491521501893_item	2547833	et	4	main
tahan	doc_491521501893_item	2547837	et	3	main
kahest	doc_491521501893_item	2547842	et	4	main
kombineeritud	doc_491521501893_item	2547848	et	4	main
vale	doc_491521501893_item	2547851	et	4	main
uue	doc_491521501893_item	2547854	et	3	main
uute	doc_491521501893_item	2547857	et	3	main
vale	doc_491521501893_item	2547865	et	4	main
rektsioon	doc_491521501893_item	2547867	et	3	main
vahel	doc_491521501893_item	2547869	et	4	main
õpilaste	doc_491521501893_item	2547870	et	4	main
õppiva	doc_491521501893_item	2547880	et	4	main
töödest	doc_491521501893_item	2547885	et	3	main
samuti	doc_491521501893_item	2547887	et	3	main
keeletaset	doc_491521501893_item	2547894	et	3	main
iseloomustades	doc_491521501893_item	2547895	et	3	main
ütleksin	doc_491521501893_item	2547896	et	3	main
et	doc_491521501893_item	2547897	et	3	main
vigu	doc_491521501893_item	2547921	et	3	main
vigase	doc_491521501893_item	2547929	et	4	main
keelekasutuse	doc_491521501893_item	2547930	et	4	main
kohta	doc_491521501893_item	2547943	et	4	main
üldistust	doc_491521501893_item	2547946	et	4	main
kokku	doc_491521501893_item	2547959	et	3	main
erinev	doc_491521501893_item	2547970	et	4	main
saavutasid	doc_491521501893_item	2547978	et	4	main
lapsed	doc_491521501893_item	2547979	et	3	main
nagu	doc_491521501893_item	2547983	et	3	main
rääkida	doc_491521501893_item	2547603	et	3	main
kord	doc_491521501893_item	2547605	et	4	main
vead	doc_491521501893_item	2547622	et	4	main
tingitud	doc_491521501893_item	2547624	et	4	main
astmevahelduse	doc_491521501893_item	2547625	et	4	main
vähesusest	doc_491521501893_item	2547631	et	4	main
sõnajärjevead	doc_491521501893_item	2547632	et	3	main
12	doc_491521501893_item	2547633	et	2	main
sarnane	doc_491521501893_item	2547638	et	4	main
on	doc_491521501893_item	2547643	et	4	main
lastel	doc_491521501893_item	2547650	et	4	main
keelest	doc_491521501893_item	2547654	et	4	main
palju	doc_491521501893_item	2547656	et	4	main
õppisin	doc_491521501893_item	2547657	et	3	main
eesti	doc_491521501893_item	2547658	et	4	main
sõnajärjevead	doc_491521501893_item	2547663	et	3	main
on	doc_491521501893_item	2547664	et	4	main
ja	doc_491521501893_item	2547669	et	3	main
me	doc_491521501893_item	2547681	et	4	main
mitte	doc_491521501893_item	2547692	et	3	main
ole	doc_491521501893_item	2547694	et	4	main
liiga	doc_491521501893_item	2547695	et	4	main
ole	doc_491521501893_item	2547700	et	4	main
liiga	doc_491521501893_item	2547701	et	4	main
palju	doc_491521501893_item	2547702	et	4	main
inimesi	doc_491521501893_item	2547703	et	4	main
mööda	doc_491521501893_item	2547704	et	4	main
keeruliste	doc_491521501893_item	2547705	et	4	main
radade	doc_491521501893_item	2547706	et	3	main
mööda	doc_491521501893_item	2547707	et	4	main
keerulisi	doc_491521501893_item	2547708	et	4	main
radu	doc_491521501893_item	2547709	et	3	main
laagrilaste	doc_491521501893_item	2547710	et	4	main
vead	doc_491521501893_item	2547711	et	4	main
ma	doc_491521501893_item	2547712	et	3	main
ei	doc_491521501893_item	2547713	et	4	main
seal	doc_491521501893_item	2547715	et	4	main
ma	doc_491521501893_item	2547716	et	3	main
olnud	doc_491521501893_item	2547714	et	4	main
ei	doc_491521501893_item	2547717	et	4	main
ole	doc_491521501893_item	2547718	et	4	main
seal	doc_491521501893_item	2547719	et	4	main
olnud	doc_491521501893_item	2547720	et	4	main
lemmikaastaaeg	doc_491521501893_item	2547724	et	3	main
palju	doc_491521501893_item	2547733	et	4	main
konstruktsioonivead	doc_491521501893_item	2547738	et	3	main
ja	doc_491521501893_item	2547744	et	3	main
seitsenda	doc_491521501893_item	2547759	et	4	main
ka	doc_491521501893_item	2547768	et	3	main
abituriendi	doc_491521501893_item	2547794	et	3	main
tingitud	doc_491521501893_item	2547801	et	4	main
keeles	doc_491521501893_item	2547805	et	4	main
väljendav	doc_491521501893_item	2547818	et	4	main
verb	doc_491521501893_item	2547819	et	3	main
valesti	doc_491521501893_item	2547820	et	3	main
rahvast	doc_491521501893_item	2547826	et	4	main
elab	doc_491521501893_item	2547827	et	3	main
sõna	doc_491521501893_item	2547828	et	4	main
vale	doc_491521501893_item	2547831	et	4	main
tahan	doc_491521501893_item	2547834	et	3	main
organiseerijatahan	doc_491521501893_item	2547839	et	4	main
organiseerijana	doc_491521501893_item	2547841	et	4	main
vale	doc_491521501893_item	2547722	et	4	main
vene	doc_491521501893_item	2547745	et	4	main
kohta	doc_491521501893_item	2547748	et	4	main
osas	doc_491521501893_item	2547750	et	4	main
üheksa	doc_491521501893_item	2547758	et	4	main
on	doc_491521501893_item	2547762	et	4	main
kõigile	doc_491521501893_item	2547764	et	4	main
võõrkeeleõppijaile	doc_491521501893_item	2547765	et	3	main
puhul	doc_491521501893_item	2547771	et	4	main
keele	doc_491521501893_item	2547770	et	4	main
omadussõna	doc_491521501893_item	2547772	et	4	main
võrdlusastmete	doc_491521501893_item	2547773	et	3	main
muutmise	doc_491521501893_item	2547774	et	4	main
vead	doc_491521501893_item	2547775	et	4	main
muutusid	doc_491521501893_item	2547776	et	4	main
koledamiks	doc_491521501893_item	2547777	et	4	main
muutusid	doc_491521501893_item	2547778	et	4	main
koledamaks	doc_491521501893_item	2547779	et	4	main
12	doc_491521501893_item	2547780	et	2	main
kl	doc_491521501893_item	2547781	et	4	main
õpilase	doc_491521501893_item	2547782	et	3	main
viga	doc_491521501893_item	2547783	et	4	main
talle	doc_491521501893_item	2547785	et	4	main
raske	doc_491521501893_item	2547786	et	4	main
tundub	doc_491521501893_item	2547784	et	3	main
kuigi	doc_491521501893_item	2547787	et	3	main
on	doc_491521501893_item	2547788	et	4	main
äsja	doc_491521501893_item	2547789	et	3	main
üle	doc_491521501893_item	2547790	et	3	main
korratud	doc_491521501893_item	2547791	et	4	main
muud	doc_491521501893_item	2547792	et	4	main
sellest	doc_491521501893_item	2547802	et	4	main
sõnaga	doc_491521501893_item	2547809	et	3	main
sest	doc_491521501893_item	2547811	et	4	main
jookseb	doc_491521501893_item	2547813	et	3	main
mood	doc_491521501893_item	2547815	et	3	main
muutub	doc_491521501893_item	2547816	et	3	main
valitud	doc_491521501893_item	2547821	et	4	main
osa	doc_491521501893_item	2547825	et	4	main
ühildumine	doc_491521501893_item	2547830	et	4	main
organiseerijana	doc_491521501893_item	2547836	et	4	main
töötada	doc_491521501893_item	2547840	et	3	main
kokku	doc_491521501893_item	2547847	et	3	main
üks	doc_491521501893_item	2547850	et	3	main
tutvustama	doc_491521501893_item	2547853	et	3	main
lastele	doc_491521501893_item	2547855	et	4	main
enesekohasus	doc_491521501893_item	2547859	et	4	main
ja	doc_491521501893_item	2547860	et	3	main
mitte-enesekohasus	doc_491521501893_item	2547861	et	4	main
valesti	doc_491521501893_item	2547862	et	3	main
õpilastele	doc_491521501893_item	2547868	et	4	main
klassis	doc_491521501893_item	2547879	et	3	main
vestluse	doc_491521501893_item	2547923	et	3	main
talle	doc_491521501893_item	2547927	et	4	main
märku	doc_491521501893_item	2547928	et	4	main
ta	doc_491521501893_item	2547933	et	4	main
sageli	doc_491521501893_item	2547934	et	3	main
juba	doc_491521501893_item	2547935	et	3	main
viibinud	doc_491521501893_item	2547941	et	4	main
raske	doc_491521501893_item	2547945	et	4	main
erinevad	doc_491521501893_item	2547956	et	4	main
lapsed	doc_491521501893_item	2547957	et	3	main
eelnev	doc_491521501893_item	2547965	et	4	main
loomulik	doc_491521501893_item	2547966	et	3	main
autoga	doc_491521501895_item	2548114	et	3	main
kõrgharidust	doc_491521501895_item	2548119	et	4	main
väljendatakse	doc_491521501893_item	2547806	et	3	main
liikumist	doc_491521501893_item	2547817	et	4	main
osa	doc_491521501893_item	2547822	et	4	main
rahvas	doc_491521501893_item	2547823	et	4	main
elab	doc_491521501893_item	2547824	et	3	main
osa	doc_491521501893_item	2547829	et	4	main
keelelaagrilaste	doc_491521501893_item	2547832	et	4	main
olla	doc_491521501893_item	2547835	et	3	main
variant	doc_491521501893_item	2547852	et	3	main
samuti	doc_491521501893_item	2547864	et	3	main
verbi	doc_491521501893_item	2547866	et	4	main
vale	doc_491521501893_item	2547872	et	4	main
käände	doc_491521501893_item	2547873	et	4	main
kasutamine	doc_491521501893_item	2547874	et	4	main
vead	doc_491521501893_item	2547875	et	4	main
võtva	doc_491521501893_item	2547882	et	4	main
ta	doc_491521501893_item	2547898	et	4	main
ise	doc_491521501893_item	2547936	et	4	main
võimeline	doc_491521501893_item	2547937	et	4	main
seda	doc_491521501893_item	2547938	et	3	main
parandama	doc_491521501893_item	2547939	et	3	main
on	doc_491521501893_item	2547944	et	4	main
nende	doc_491521501893_item	2547949	et	4	main
olnud	doc_491521501893_item	2547969	et	4	main
12	doc_491521501893_item	2547973	et	2	main
suurema	doc_491521501893_item	2547980	et	4	main
suhtlemisjulguse	doc_491521501893_item	2547981	et	4	main
ja	doc_491521501893_item	2547982	et	3	main
ise	doc_491521501893_item	2547985	et	4	main
sõnavara	doc_491521501893_item	2547988	et	4	main
kõik	doc_491521501895_item	2548116	et	4	main
rahvusi	doc_491521501895_item	2548147	et	3	main
teisest	doc_491521501895_item	2548159	et	4	main
eest	doc_491521501895_item	2548166	et	4	main
noortel	doc_491521501895_item	2548167	et	3	main
on	doc_491521501895_item	2548168	et	4	main
palju	doc_491521501895_item	2548169	et	4	main
tegevusvabadus	doc_491521501895_item	2548173	et	4	main
oma	doc_491521501895_item	2548189	et	4	main
emotsionaalsuseid	doc_491521501895_item	2548199	et	4	main
pingulolekult	doc_491521501895_item	2548202	et	4	main
teen	doc_491521501895_item	2548204	et	3	main
tänapäeva	doc_491521501895_item	2548207	et	4	main
hoolitvad	doc_491521501895_item	2548209	et	4	main
oma	doc_491521501895_item	2548210	et	4	main
tervisest	doc_491521501895_item	2548211	et	4	main
keskealised	doc_491521501895_item	2548214	et	4	main
tänapäeva	doc_491521501896_item	2548216	et	4	main
nad	doc_491521501896_item	2548242	et	3	main
siis	doc_491521501896_item	2548247	et	3	main
inimesed	doc_491521501896_item	2548253	et	3	main
arvates	doc_491521501896_item	2548261	et	4	main
ei	doc_491521501896_item	2548262	et	4	main
ole	doc_491521501896_item	2548263	et	4	main
see	doc_491521501896_item	2548264	et	3	main
nii	doc_491521501896_item	2548265	et	3	main
tänapäeva	doc_491521501896_item	2548266	et	4	main
tervisest	doc_491521501896_item	2548270	et	4	main
ja	doc_491521501896_item	2548271	et	3	main
70-ndatel	doc_491521501896_item	2548278	et	4	main
peaaegu	doc_491521501896_item	2548280	et	3	main
olla	doc_491521501893_item	2547838	et	3	main
on	doc_491521501893_item	2547846	et	4	main
kasutatud	doc_491521501893_item	2547863	et	4	main
on	doc_491521501893_item	2547876	et	4	main
kogutud	doc_491521501893_item	2547877	et	4	main
12	doc_491521501893_item	2547878	et	2	main
õpilase	doc_491521501893_item	2547883	et	3	main
suvises	doc_491521501893_item	2547889	et	4	main
keelelaagris	doc_491521501893_item	2547890	et	3	main
kirjutatud	doc_491521501893_item	2547891	et	4	main
töödest	doc_491521501893_item	2547892	et	3	main
abituriendi	doc_491521501893_item	2547893	et	3	main
suhtlemisega	doc_491521501893_item	2547900	et	4	main
hästi	doc_491521501893_item	2547901	et	3	main
hakkama	doc_491521501893_item	2547902	et	3	main
st	doc_491521501893_item	2547903	et	3	main
sõnavara	doc_491521501893_item	2547904	et	4	main
on	doc_491521501893_item	2547905	et	4	main
piisavalt	doc_491521501893_item	2547906	et	4	main
lai	doc_491521501893_item	2547907	et	3	main
ning	doc_491521501893_item	2547908	et	3	main
ka	doc_491521501893_item	2547909	et	3	main
suhtlemisjulgus	doc_491521501893_item	2547910	et	4	main
on	doc_491521501893_item	2547911	et	4	main
saavutatud	doc_491521501893_item	2547912	et	4	main
kuid	doc_491521501893_item	2547913	et	4	main
grammatika	doc_491521501893_item	2547914	et	4	main
osas	doc_491521501893_item	2547915	et	4	main
teeb	doc_491521501893_item	2547916	et	3	main
ta	doc_491521501893_item	2547917	et	4	main
siiski	doc_491521501893_item	2547918	et	4	main
veel	doc_491521501893_item	2547919	et	4	main
palju	doc_491521501893_item	2547920	et	4	main
võimalikust	doc_491521501893_item	2547843	et	4	main
õigest	doc_491521501893_item	2547844	et	3	main
variandist	doc_491521501893_item	2547845	et	3	main
kahjuks	doc_491521501893_item	2547849	et	4	main
tutvuda	doc_491521501893_item	2547856	et	3	main
lastega	doc_491521501893_item	2547858	et	3	main
vahel	doc_491521501893_item	2547871	et	4	main
eratunde	doc_491521501893_item	2547881	et	4	main
kirjalikest	doc_491521501893_item	2547884	et	3	main
ning	doc_491521501893_item	2547886	et	3	main
laste	doc_491521501893_item	2547888	et	4	main
saab	doc_491521501893_item	2547899	et	3	main
käigus	doc_491521501893_item	2547924	et	4	main
kui	doc_491521501893_item	2547925	et	3	main
kohta	doc_491521501893_item	2547931	et	4	main
on	doc_491521501893_item	2547932	et	4	main
laste	doc_491521501893_item	2547942	et	4	main
teha	doc_491521501893_item	2547947	et	3	main
olid	doc_491521501893_item	2547958	et	4	main
oli	doc_491521501893_item	2547968	et	3	main
kestis	doc_491521501893_item	2547972	et	4	main
päeva	doc_491521501893_item	2547974	et	4	main
ning	doc_491521501893_item	2547975	et	3	main
selle	doc_491521501893_item	2547976	et	4	main
nad	doc_491521501893_item	2547984	et	3	main
tahavad	doc_491521501895_item	2548118	et	3	main
saada	doc_491521501895_item	2548120	et	4	main
rohkem	doc_491521501895_item	2548130	et	4	main
kui	doc_491521501895_item	2548131	et	3	main
eest	doc_491521501895_item	2548137	et	4	main
tahavad	doc_491521501895_item	2548145	et	3	main
teada	doc_491521501895_item	2548148	et	3	main
oma	doc_491521501895_item	2548164	et	4	main
taskuraha	doc_491521501895_item	2548170	et	4	main
narkootikumi	doc_491521501895_item	2548180	et	4	main
see	doc_491521501895_item	2548181	et	3	main
on	doc_491521501895_item	2548182	et	4	main
suur	doc_491521501895_item	2548183	et	3	main
hooli	doc_491521501895_item	2548188	et	4	main
rohkem	doc_491521501895_item	2548191	et	4	main
kui	doc_491521501895_item	2548192	et	3	main
pingeid	doc_491521501895_item	2548200	et	3	main
rohkem	doc_491521501895_item	2548212	et	4	main
tervisest	doc_491521501896_item	2548220	et	4	main
kuid	doc_491521501893_item	2547922	et	4	main
annan	doc_491521501893_item	2547926	et	3	main
keelelaagris	doc_491521501893_item	2547940	et	3	main
sest	doc_491521501893_item	2547948	et	4	main
vanus	doc_491521501893_item	2547950	et	4	main
ning	doc_491521501893_item	2547951	et	3	main
keeleline	doc_491521501893_item	2547952	et	4	main
tase	doc_491521501893_item	2547953	et	3	main
olid	doc_491521501893_item	2547954	et	4	main
väga	doc_491521501893_item	2547955	et	3	main
tulnud	doc_491521501893_item	2547960	et	4	main
erinevatest	doc_491521501893_item	2547961	et	4	main
koolidest	doc_491521501893_item	2547962	et	3	main
ja	doc_491521501893_item	2547963	et	3	main
ka	doc_491521501893_item	2547964	et	3	main
keelekeskkond	doc_491521501893_item	2547967	et	3	main
laager	doc_491521501893_item	2547971	et	3	main
lõpuks	doc_491521501893_item	2547977	et	4	main
kirjutasid	doc_491521501893_item	2547986	et	4	main
ka	doc_491521501893_item	2547987	et	3	main
laienes	doc_491521501893_item	2547989	et	3	main
essee	doc_491521501895_item	2548083	et	4	main
väide	doc_491521501895_item	2548084	et	4	main
tänapäeva	doc_491521501895_item	2548085	et	4	main
noored	doc_491521501895_item	2548086	et	3	main
hoolivad	doc_491521501895_item	2548087	et	4	main
oma	doc_491521501895_item	2548088	et	4	main
tervisest	doc_491521501895_item	2548089	et	4	main
rohkem	doc_491521501895_item	2548090	et	4	main
kui	doc_491521501895_item	2548091	et	3	main
keskealised	doc_491521501895_item	2548092	et	4	main
ma	doc_491521501895_item	2548093	et	3	main
olen	doc_491521501895_item	2548094	et	3	main
nõus	doc_491521501895_item	2548095	et	4	main
väitega	doc_491521501895_item	2548096	et	3	main
sellepärast	doc_491521501895_item	2548097	et	3	main
et	doc_491521501895_item	2548098	et	3	main
praegu	doc_491521501895_item	2548099	et	3	main
noored	doc_491521501895_item	2548100	et	3	main
käivad	doc_491521501895_item	2548101	et	4	main
koolis	doc_491521501895_item	2548102	et	4	main
õppivad	doc_491521501895_item	2548103	et	4	main
ülikoolis	doc_491521501895_item	2548104	et	4	main
nad	doc_491521501895_item	2548105	et	3	main
tahavad	doc_491521501895_item	2548106	et	3	main
head	doc_491521501895_item	2548107	et	4	main
tööd	doc_491521501895_item	2548108	et	4	main
leida	doc_491521501895_item	2548109	et	3	main
maodsates	doc_491521501895_item	2548110	et	4	main
büroruumides	doc_491521501895_item	2548111	et	4	main
istuda	doc_491521501895_item	2548112	et	3	main
ja	doc_491521501895_item	2548113	et	3	main
uut	doc_491521501895_item	2548121	et	3	main
sellepärast	doc_491521501895_item	2548124	et	3	main
hoolivad	doc_491521501895_item	2548127	et	4	main
oma	doc_491521501895_item	2548128	et	4	main
tervisest	doc_491521501895_item	2548129	et	4	main
tervisest	doc_491521501895_item	2548136	et	4	main
inimesed	doc_491521501895_item	2548144	et	3	main
saada	doc_491521501895_item	2548149	et	4	main
käia	doc_491521501895_item	2548157	et	4	main
tervisest	doc_491521501895_item	2548165	et	4	main
nendel	doc_491521501895_item	2548171	et	4	main
istuvad	doc_491521501895_item	2548175	et	4	main
problem	doc_491521501895_item	2548184	et	4	main
hoolivad	doc_491521501896_item	2548218	et	4	main
oma	doc_491521501896_item	2548219	et	4	main
kui	doc_491521501896_item	2548222	et	3	main
tänapäeval	doc_491521501896_item	2548224	et	3	main
oma	doc_491521501896_item	2548239	et	4	main
hoolimatult	doc_491521501896_item	2548241	et	4	main
kui	doc_491521501896_item	2548248	et	3	main
et	doc_491521501896_item	2548251	et	3	main
oma	doc_491521501896_item	2548255	et	4	main
rohkem	doc_491521501896_item	2548259	et	4	main
minu	doc_491521501896_item	2548260	et	3	main
noored	doc_491521501896_item	2548267	et	3	main
hoolitsevad	doc_491521501896_item	2548268	et	4	main
hoolitsevad	doc_491521501896_item	2548272	et	4	main
väga	doc_491521501896_item	2548273	et	3	main
hoolikalt	doc_491521501896_item	2548274	et	4	main
suitsetamine	doc_491521501896_item	2548277	et	4	main
kõik	doc_491521501896_item	2548281	et	4	main
aga	doc_491521501896_item	2548283	et	3	main
moes	doc_491521501896_item	2548287	et	3	main
ja	doc_491521501896_item	2548292	et	3	main
on	doc_491521501896_item	2548297	et	4	main
muutunud	doc_491521501896_item	2548298	et	4	main
igaüks	doc_491521501896_item	2548303	et	3	main
teab	doc_491521501896_item	2548306	et	3	main
ja	doc_491521501896_item	2548318	et	3	main
sõita	doc_491521501895_item	2548115	et	3	main
noored	doc_491521501895_item	2548117	et	3	main
põlvkonda	doc_491521501895_item	2548122	et	4	main
et	doc_491521501895_item	2548125	et	3	main
nad	doc_491521501895_item	2548126	et	3	main
keskealised	doc_491521501895_item	2548132	et	4	main
noored	doc_491521501895_item	2548133	et	3	main
selleks	doc_491521501895_item	2548138	et	4	main
et	doc_491521501895_item	2548139	et	3	main
tahavad	doc_491521501895_item	2548140	et	3	main
teisi	doc_491521501895_item	2548141	et	4	main
maid	doc_491521501895_item	2548142	et	4	main
külastada	doc_491521501895_item	2548143	et	3	main
esinduskaupluses	doc_491521501895_item	2548158	et	3	main
küljest	doc_491521501895_item	2548160	et	4	main
joovad	doc_491521501895_item	2548177	et	4	main
suitsetavad	doc_491521501895_item	2548178	et	4	main
tarvitavad	doc_491521501895_item	2548179	et	4	main
järelduse	doc_491521501895_item	2548205	et	4	main
et	doc_491521501895_item	2548206	et	3	main
noored	doc_491521501895_item	2548208	et	3	main
kui	doc_491521501895_item	2548213	et	3	main
essee	doc_491521501896_item	2548215	et	4	main
noored	doc_491521501896_item	2548217	et	3	main
keksealised	doc_491521501896_item	2548223	et	4	main
räägitakse	doc_491521501896_item	2548225	et	3	main
on	doc_491521501896_item	2548229	et	4	main
hakkavad	doc_491521501896_item	2548243	et	4	main
mõtlema	doc_491521501896_item	2548245	et	3	main
haigestuvad	doc_491521501896_item	2548249	et	4	main
keskealised	doc_491521501896_item	2548252	et	4	main
oma	doc_491521501896_item	2548269	et	4	main
näiteks	doc_491521501896_item	2548276	et	4	main
noored	doc_491521501896_item	2548288	et	3	main
hingamist	doc_491521501896_item	2548294	et	4	main
arvan	doc_491521501896_item	2548301	et	3	main
värskeid	doc_491521501896_item	2548311	et	4	main
puuvilju	doc_491521501896_item	2548312	et	3	main
ja	doc_491521501896_item	2548313	et	3	main
aedvilju	doc_491521501896_item	2548314	et	3	main
ning	doc_491521501896_item	2548315	et	3	main
inimesed	doc_491521501896_item	2548322	et	3	main
parem	doc_491521501896_item	2548333	et	4	main
erinevad	doc_491521501896_item	2548342	et	4	main
juba	doc_491521501896_item	2548345	et	3	main
kõik	doc_491521501896_item	2548375	et	4	main
hoolitsevad	doc_491521501896_item	2548381	et	4	main
huvitavam	doc_491521501897_item	2548391	et	4	main
arvan	doc_491521501897_item	2548399	et	3	main
on	doc_491521501897_item	2548408	et	4	main
ilm	doc_491521501897_item	2548416	et	3	main
ilus	doc_491521501897_item	2548418	et	4	main
jalutasin	doc_491521501897_item	2548420	et	3	main
koos	doc_491521501897_item	2548424	et	4	main
oli	doc_491521501897_item	2548429	et	3	main
aega	doc_491521501897_item	2548433	et	4	main
palju	doc_491521501897_item	2548438	et	4	main
väikesed	doc_491521501897_item	2548440	et	4	main
vee	doc_491521501897_item	2548443	et	3	main
avaneb	doc_491521501897_item	2548456	et	3	main
vaade	doc_491521501897_item	2548458	et	3	main
on	doc_491521501897_item	2548464	et	4	main
pool	doc_491521501897_item	2548468	et	4	main
värvilised	doc_491521501897_item	2548470	et	4	main
laternad	doc_491521501897_item	2548471	et	3	main
õhul	doc_491521501897_item	2548474	et	3	main
on	doc_491521501897_item	2548476	et	4	main
kõik	doc_491521501897_item	2548479	et	4	main
väga	doc_491521501897_item	2548483	et	3	main
väga	doc_491521501897_item	2548489	et	3	main
pariisi	doc_491521501897_item	2548497	et	4	main
mängida	doc_491521501898_item	2548522	et	3	main
lapsega	doc_491521501898_item	2548524	et	3	main
süüa	doc_491521501898_item	2548526	et	3	main
kui	doc_491521501898_item	2548537	et	3	main
ma	doc_491521501898_item	2548550	et	3	main
pesen	doc_491521501898_item	2548551	et	3	main
peseme	doc_491521501898_item	2548564	et	3	main
jääb	doc_491521501898_item	2548568	et	3	main
ma	doc_491521501898_item	2548570	et	3	main
pesen	doc_491521501898_item	2548578	et	3	main
kasvatada	doc_491521501895_item	2548123	et	3	main
hoolivad	doc_491521501895_item	2548134	et	4	main
oma	doc_491521501895_item	2548135	et	4	main
teisi	doc_491521501895_item	2548146	et	4	main
nad	doc_491521501895_item	2548150	et	3	main
tahavad	doc_491521501895_item	2548151	et	3	main
ka	doc_491521501895_item	2548152	et	3	main
kallihinnalisi	doc_491521501895_item	2548153	et	4	main
lingitusi	doc_491521501895_item	2548154	et	4	main
teha	doc_491521501895_item	2548155	et	3	main
ning	doc_491521501895_item	2548156	et	3	main
noored	doc_491521501895_item	2548161	et	3	main
ei	doc_491521501895_item	2548162	et	4	main
hooli	doc_491521501895_item	2548163	et	4	main
on	doc_491521501895_item	2548172	et	4	main
noored	doc_491521501895_item	2548174	et	3	main
baaris	doc_491521501895_item	2548176	et	3	main
tänapäeva	doc_491521501895_item	2548185	et	4	main
noored	doc_491521501895_item	2548186	et	3	main
ei	doc_491521501895_item	2548187	et	4	main
tervisest	doc_491521501895_item	2548190	et	4	main
keskealised	doc_491521501895_item	2548193	et	4	main
sellepärast	doc_491521501895_item	2548194	et	3	main
et	doc_491521501895_item	2548195	et	3	main
tunnevad	doc_491521501895_item	2548196	et	3	main
tihti	doc_491521501895_item	2548197	et	3	main
väsimust	doc_491521501895_item	2548198	et	4	main
või	doc_491521501895_item	2548201	et	4	main
ma	doc_491521501895_item	2548203	et	3	main
rohkem	doc_491521501896_item	2548221	et	4	main
palju	doc_491521501896_item	2548226	et	4	main
see	doc_491521501896_item	2548228	et	3	main
viimaste	doc_491521501896_item	2548230	et	3	main
aastate	doc_491521501896_item	2548231	et	3	main
keskne	doc_491521501896_item	2548232	et	3	main
teema	doc_491521501896_item	2548233	et	4	main
tihti	doc_491521501896_item	2548234	et	3	main
arvatakse	doc_491521501896_item	2548235	et	3	main
et	doc_491521501896_item	2548236	et	3	main
noored	doc_491521501896_item	2548237	et	3	main
suhtuvad	doc_491521501896_item	2548238	et	4	main
väidetakse	doc_491521501896_item	2548250	et	3	main
võtame	doc_491521501896_item	2548275	et	3	main
ei	doc_491521501896_item	2548284	et	4	main
eelistavad	doc_491521501896_item	2548289	et	4	main
hambaid	doc_491521501896_item	2548291	et	3	main
toitumine	doc_491521501896_item	2548296	et	4	main
tähtsaks	doc_491521501896_item	2548299	et	4	main
ma	doc_491521501896_item	2548300	et	3	main
piirama	doc_491521501896_item	2548316	et	3	main
liha	doc_491521501896_item	2548317	et	4	main
söömist	doc_491521501896_item	2548320	et	4	main
keskealised	doc_491521501896_item	2548321	et	4	main
enamasti	doc_491521501896_item	2548324	et	4	main
on	doc_491521501896_item	2548334	et	4	main
sport	doc_491521501896_item	2548335	et	3	main
on	doc_491521501896_item	2548344	et	4	main
kohaks	doc_491521501896_item	2548348	et	4	main
kus	doc_491521501896_item	2548349	et	3	main
nad	doc_491521501896_item	2548350	et	3	main
veedavad	doc_491521501896_item	2548351	et	3	main
suure	doc_491521501896_item	2548352	et	3	main
ajast	doc_491521501896_item	2548356	et	4	main
tänapäeva	doc_491521501896_item	2548379	et	4	main
oma	doc_491521501896_item	2548383	et	4	main
terviseest	doc_491521501896_item	2548384	et	4	main
kui	doc_491521501896_item	2548385	et	3	main
keskealised	doc_491521501896_item	2548386	et	4	main
inimesed	doc_491521501896_item	2548387	et	3	main
essee	doc_491521501897_item	2548388	et	4	main
minu	doc_491521501897_item	2548389	et	3	main
kõige	doc_491521501897_item	2548390	et	4	main
pariisis	doc_491521501897_item	2548397	et	4	main
ma	doc_491521501897_item	2548398	et	3	main
et	doc_491521501897_item	2548400	et	3	main
see	doc_491521501897_item	2548401	et	3	main
on	doc_491521501897_item	2548402	et	4	main
palju	doc_491521501897_item	2548409	et	4	main
muuseume	doc_491521501897_item	2548410	et	3	main
kauneid	doc_491521501897_item	2548411	et	3	main
parke	doc_491521501897_item	2548412	et	3	main
ja	doc_491521501897_item	2548413	et	3	main
ma	doc_491521501897_item	2548419	et	3	main
terviseprobleemidest	doc_491521501896_item	2548227	et	3	main
tervisesse	doc_491521501896_item	2548240	et	4	main
sulele	doc_491521501896_item	2548244	et	4	main
alles	doc_491521501896_item	2548246	et	3	main
hoolivad	doc_491521501896_item	2548254	et	4	main
tervise	doc_491521501896_item	2548256	et	3	main
eest	doc_491521501896_item	2548257	et	4	main
märksa	doc_491521501896_item	2548258	et	3	main
suitsetasid	doc_491521501896_item	2548279	et	4	main
nüüd	doc_491521501896_item	2548282	et	4	main
suitsetamine	doc_491521501896_item	2548286	et	4	main
valgeid	doc_491521501896_item	2548290	et	3	main
tervislik	doc_491521501896_item	2548295	et	3	main
et	doc_491521501896_item	2548302	et	3	main
peab	doc_491521501896_item	2548308	et	4	main
rohkem	doc_491521501896_item	2548309	et	4	main
tarvitama	doc_491521501896_item	2548310	et	3	main
magusa	doc_491521501896_item	2548319	et	3	main
odavam	doc_491521501896_item	2548331	et	4	main
seda	doc_491521501896_item	2548332	et	3	main
spordiklubid	doc_491521501896_item	2548343	et	3	main
ei	doc_491521501896_item	2548370	et	4	main
mõju	doc_491521501896_item	2548371	et	4	main
tervisele	doc_491521501896_item	2548372	et	3	main
ülaltoodu	doc_491521501896_item	2548376	et	4	main
et	doc_491521501896_item	2548378	et	3	main
rohkem	doc_491521501896_item	2548382	et	4	main
oma	doc_491521501897_item	2548394	et	4	main
käisin	doc_491521501897_item	2548395	et	3	main
ilusam	doc_491521501897_item	2548404	et	4	main
pariisi	doc_491521501897_item	2548422	et	4	main
tänavaid	doc_491521501897_item	2548423	et	4	main
luuvrit	doc_491521501897_item	2548427	et	4	main
oli	doc_491521501897_item	2548434	et	3	main
kõrge	doc_491521501897_item	2548453	et	4	main
pariis	doc_491521501897_item	2548465	et	4	main
vabal	doc_491521501897_item	2548473	et	3	main
tänavatel	doc_491521501897_item	2548475	et	4	main
on	doc_491521501897_item	2548482	et	4	main
lendas	doc_491521501897_item	2548488	et	3	main
kiiresti	doc_491521501897_item	2548490	et	3	main
kunagi	doc_491521501897_item	2548494	et	3	main
külastan	doc_491521501897_item	2548496	et	3	main
jälle	doc_491521501897_item	2548498	et	3	main
essee	doc_491521501898_item	2548499	et	4	main
tavaline	doc_491521501898_item	2548503	et	4	main
ärkan	doc_491521501898_item	2548507	et	3	main
hommikul	doc_491521501898_item	2548510	et	3	main
oma	doc_491521501898_item	2548523	et	4	main
iga	doc_491521501898_item	2548527	et	4	main
lapsega	doc_491521501898_item	2548534	et	3	main
mu	doc_491521501898_item	2548538	et	3	main
kell	doc_491521501898_item	2548542	et	3	main
me	doc_491521501898_item	2548544	et	4	main
perega	doc_491521501898_item	2548547	et	3	main
süüa	doc_491521501898_item	2548548	et	3	main
pärast	doc_491521501898_item	2548549	et	4	main
nõud	doc_491521501898_item	2548552	et	3	main
kõik	doc_491521501898_item	2548572	et	4	main
kohale	doc_491521501898_item	2548574	et	4	main
uni	doc_491521501898_item	2548575	et	3	main
natuke	doc_491521501898_item	2548579	et	4	main
lugege	doc_491521501899_item	2548586	et	3	main
marguse	doc_491521501899_item	2548588	et	4	main
kirjutage	doc_491521501899_item	2548591	et	3	main
kuhu	doc_491521501899_item	2548609	et	3	main
sa	doc_491521501899_item	2548610	et	3	main
tallinnas	doc_491521501899_item	2548611	et	4	main
minna	doc_491521501899_item	2548612	et	3	main
tahad	doc_491521501899_item	2548613	et	3	main
jään	doc_491521501899_item	2548614	et	3	main
margus	doc_491521501899_item	2548619	et	3	main
sain	doc_491521501899_item	2548620	et	3	main
kirju	doc_491521501899_item	2548622	et	4	main
mina	doc_491521501899_item	2548624	et	4	main
planeerin	doc_491521501899_item	2548625	et	3	main
reede	doc_491521501899_item	2548631	et	4	main
oled	doc_491521501899_item	2548634	et	3	main
siis	doc_491521501899_item	2548636	et	3	main
juures	doc_491521501899_item	2548639	et	4	main
terve	doc_491521501899_item	2548640	et	4	main
nädal	doc_491521501899_item	2548641	et	3	main
sellepärast	doc_491521501899_item	2548642	et	3	main
et	doc_491521501899_item	2548643	et	3	main
vaher	doc_491521501900_item	2548682	et	3	main
tammelt	doc_491521501900_item	2548688	et	4	main
ole	doc_491521501896_item	2548285	et	4	main
värsket	doc_491521501896_item	2548293	et	4	main
noorest	doc_491521501896_item	2548304	et	3	main
põlvkonnast	doc_491521501896_item	2548305	et	4	main
et	doc_491521501896_item	2548307	et	3	main
aga	doc_491521501896_item	2548323	et	3	main
pööravad	doc_491521501896_item	2548325	et	4	main
hinnale	doc_491521501896_item	2548329	et	3	main
on	doc_491521501896_item	2548336	et	4	main
samuti	doc_491521501896_item	2548337	et	3	main
paljude	doc_491521501896_item	2548338	et	3	main
noorte	doc_491521501896_item	2548339	et	3	main
inimeste	doc_491521501896_item	2548340	et	3	main
lemmiktegevasala	doc_491521501896_item	2548341	et	4	main
osa	doc_491521501896_item	2548353	et	4	main
oma	doc_491521501896_item	2548354	et	4	main
vabast	doc_491521501896_item	2548355	et	3	main
siis	doc_491521501896_item	2548374	et	3	main
näitab	doc_491521501896_item	2548377	et	3	main
prantsusmaal	doc_491521501897_item	2548396	et	4	main
linn	doc_491521501897_item	2548405	et	3	main
maailmas	doc_491521501897_item	2548406	et	3	main
seal	doc_491521501897_item	2548407	et	4	main
poode	doc_491521501897_item	2548415	et	3	main
oli	doc_491521501897_item	2548417	et	3	main
mööda	doc_491521501897_item	2548421	et	4	main
teistega	doc_491521501897_item	2548425	et	4	main
väga	doc_491521501897_item	2548430	et	3	main
vähe	doc_491521501897_item	2548435	et	3	main
purskkaeve	doc_491521501897_item	2548439	et	4	main
mängivad	doc_491521501897_item	2548442	et	4	main
sees	doc_491521501897_item	2548444	et	4	main
torni	doc_491521501897_item	2548454	et	4	main
ilus	doc_491521501897_item	2548457	et	4	main
linnale	doc_491521501897_item	2548459	et	4	main
eriti	doc_491521501897_item	2548460	et	3	main
pidulik	doc_491521501897_item	2548461	et	3	main
ka	doc_491521501897_item	2548462	et	3	main
uhke	doc_491521501897_item	2548463	et	4	main
kohvikud	doc_491521501897_item	2548472	et	3	main
ja	doc_491521501897_item	2548481	et	3	main
et	doc_491521501897_item	2548486	et	3	main
loodan	doc_491521501897_item	2548491	et	3	main
et	doc_491521501897_item	2548493	et	3	main
ma	doc_491521501897_item	2548495	et	3	main
üks	doc_491521501898_item	2548502	et	3	main
tavaliselt	doc_491521501898_item	2548505	et	4	main
kell	doc_491521501898_item	2548508	et	3	main
6	doc_491521501898_item	2548509	et	2	main
tähelepanu	doc_491521501896_item	2548326	et	4	main
eelkõige	doc_491521501896_item	2548327	et	3	main
toidu	doc_491521501896_item	2548328	et	3	main
mida	doc_491521501896_item	2548330	et	4	main
ammu	doc_491521501896_item	2548346	et	4	main
saanud	doc_491521501896_item	2548347	et	4	main
vanem	doc_491521501896_item	2548357	et	4	main
põlvkond	doc_491521501896_item	2548358	et	3	main
aga	doc_491521501896_item	2548359	et	3	main
selle	doc_491521501896_item	2548360	et	4	main
eelistab	doc_491521501896_item	2548362	et	3	main
sporti	doc_491521501896_item	2548363	et	4	main
asemel	doc_491521501896_item	2548361	et	4	main
tugitoolis	doc_491521501896_item	2548364	et	3	main
mis	doc_491521501896_item	2548365	et	4	main
muidugi	doc_491521501896_item	2548366	et	4	main
mitte	doc_491521501896_item	2548367	et	3	main
eriti	doc_491521501896_item	2548368	et	3	main
hästi	doc_491521501896_item	2548369	et	3	main
nii	doc_491521501896_item	2548373	et	3	main
noored	doc_491521501896_item	2548380	et	3	main
reis	doc_491521501897_item	2548392	et	4	main
suvel	doc_491521501897_item	2548393	et	3	main
kõige	doc_491521501897_item	2548403	et	4	main
igasuguseid	doc_491521501897_item	2548414	et	3	main
külastasin	doc_491521501897_item	2548426	et	3	main
seal	doc_491521501897_item	2548428	et	4	main
kuid	doc_491521501897_item	2548432	et	4	main
on	doc_491521501897_item	2548437	et	4	main
on	doc_491521501897_item	2548451	et	4	main
väga	doc_491521501897_item	2548452	et	3	main
tipust	doc_491521501897_item	2548455	et	3	main
igal	doc_491521501897_item	2548467	et	3	main
palju	doc_491521501897_item	2548477	et	4	main
heatahtlikud	doc_491521501897_item	2548484	et	3	main
kahju	doc_491521501897_item	2548485	et	4	main
aeg	doc_491521501897_item	2548487	et	3	main
aga	doc_491521501897_item	2548492	et	3	main
eile	doc_491521501898_item	2548500	et	3	main
annan	doc_491521501898_item	2548525	et	3	main
tunni	doc_491521501898_item	2548529	et	3	main
poes	doc_491521501898_item	2548536	et	3	main
mees	doc_491521501898_item	2548539	et	4	main
1700	doc_491521501898_item	2548543	et	2	main
kogu	doc_491521501898_item	2548546	et	4	main
lapsi	doc_491521501898_item	2548565	et	4	main
manguasjad	doc_491521501898_item	2548573	et	4	main
eest	doc_491521501898_item	2548576	et	4	main
siis	doc_491521501898_item	2548582	et	3	main
läbi	doc_491521501899_item	2548587	et	4	main
kiri	doc_491521501899_item	2548589	et	3	main
kirjuta	doc_491521501899_item	2548595	et	4	main
palun	doc_491521501899_item	2548596	et	3	main
mulle	doc_491521501899_item	2548597	et	4	main
tuled	doc_491521501899_item	2548601	et	4	main
päeva	doc_491521501899_item	2548603	et	4	main
sa	doc_491521501899_item	2548604	et	3	main
minu	doc_491521501899_item	2548605	et	3	main
juures	doc_491521501899_item	2548606	et	4	main
oled	doc_491521501899_item	2548607	et	3	main
ja	doc_491521501899_item	2548608	et	3	main
tere	doc_491521501899_item	2548618	et	3	main
huvitav	doc_491521501897_item	2548431	et	4	main
pariisis	doc_491521501897_item	2548436	et	4	main
lapsed	doc_491521501897_item	2548441	et	3	main
muidugi	doc_491521501897_item	2548445	et	4	main
käisime	doc_491521501897_item	2548446	et	3	main
ka	doc_491521501897_item	2548447	et	3	main
eiffeli	doc_491521501897_item	2548448	et	4	main
tornil	doc_491521501897_item	2548449	et	3	main
see	doc_491521501897_item	2548450	et	3	main
õhtul	doc_491521501897_item	2548466	et	3	main
on	doc_491521501897_item	2548469	et	4	main
inimesi	doc_491521501897_item	2548478	et	4	main
naeratavad	doc_491521501897_item	2548480	et	4	main
oli	doc_491521501898_item	2548501	et	3	main
päev	doc_491521501898_item	2548504	et	3	main
ma	doc_491521501898_item	2548506	et	3	main
anna	doc_491521501898_item	2548511	et	4	main
oma	doc_491521501898_item	2548512	et	4	main
lapsekele	doc_491521501898_item	2548513	et	4	main
süüa	doc_491521501898_item	2548514	et	3	main
pärast	doc_491521501898_item	2548515	et	4	main
teen	doc_491521501898_item	2548516	et	3	main
süüa	doc_491521501898_item	2548517	et	3	main
koristan	doc_491521501898_item	2548518	et	3	main
korterit	doc_491521501898_item	2548519	et	3	main
ma	doc_491521501898_item	2548520	et	3	main
armastan	doc_491521501898_item	2548521	et	3	main
lapsele	doc_491521501898_item	2548530	et	4	main
käin	doc_491521501898_item	2548532	et	3	main
käin	doc_491521501898_item	2548535	et	3	main
töölt	doc_491521501898_item	2548541	et	3	main
istume	doc_491521501898_item	2548545	et	3	main
kui	doc_491521501898_item	2548566	et	3	main
uljana	doc_491521501898_item	2548567	et	3	main
magama	doc_491521501898_item	2548569	et	3	main
lähen	doc_491521501898_item	2548583	et	3	main
magama	doc_491521501898_item	2548584	et	3	main
millal	doc_491521501899_item	2548598	et	3	main
mitu	doc_491521501899_item	2548602	et	4	main
margus	doc_491521501899_item	2548617	et	3	main
tallinnasse	doc_491521501899_item	2548623	et	3	main
tulla	doc_491521501899_item	2548626	et	3	main
järgmisel	doc_491521501899_item	2548627	et	3	main
nädalal	doc_491521501899_item	2548628	et	3	main
mõtlen	doc_491521501899_item	2548629	et	3	main
tahan	doc_491521501899_item	2548644	et	3	main
muud	doc_491521501899_item	2548655	et	4	main
eesnimi	doc_491521501899_item	2548656	et	3	main
etteütlus	doc_491521501900_item	2548657	et	3	main
etteütlus	doc_491521501900_item	2548658	et	3	main
sügis	doc_491521501900_item	2548659	et	3	main
aedades	doc_491521501900_item	2548693	et	3	main
pirnid	doc_491521501900_item	2548697	et	3	main
koristavad	doc_491521501900_item	2548699	et	4	main
järjest	doc_491521501900_item	2548703	et	4	main
jahedamaks	doc_491521501900_item	2548704	et	4	main
langevad	doc_491521501900_item	2548709	et	4	main
korjavad	doc_491521501900_item	2548717	et	4	main
loodus	doc_491521501900_item	2548719	et	4	main
vihmasajud	doc_491521501900_item	2548727	et	3	main
sageli	doc_491521501900_item	2548735	et	3	main
ette	doc_491521501901_item	2548738	et	4	main
sügis	doc_491521501901_item	2548740	et	3	main
tasahilju	doc_491521501901_item	2548743	et	3	main
septembri	doc_491521501901_item	2548744	et	3	main
on	doc_491521501901_item	2548746	et	4	main
aga	doc_491521501901_item	2548747	et	3	main
ilmad	doc_491521501901_item	2548748	et	3	main
rohelised	doc_491521501901_item	2548753	et	4	main
aidades	doc_491521501901_item	2548775	et	4	main
pirnid	doc_491521501901_item	2548779	et	3	main
ilmad	doc_491521501901_item	2548783	et	3	main
neli	doc_491521501898_item	2548528	et	3	main
süüa	doc_491521501898_item	2548531	et	3	main
jalutamas	doc_491521501898_item	2548533	et	3	main
tuleb	doc_491521501898_item	2548540	et	3	main
ja	doc_491521501898_item	2548553	et	3	main
me	doc_491521501898_item	2548554	et	4	main
käime	doc_491521501898_item	2548555	et	4	main
veel	doc_491521501898_item	2548556	et	4	main
jalutamas	doc_491521501898_item	2548557	et	3	main
õhtul	doc_491521501898_item	2548558	et	3	main
vaatame	doc_491521501898_item	2548559	et	3	main
telerit	doc_491521501898_item	2548560	et	3	main
pool	doc_491521501898_item	2548561	et	4	main
üheksa	doc_491521501898_item	2548562	et	4	main
me	doc_491521501898_item	2548563	et	4	main
panen	doc_491521501898_item	2548571	et	3	main
ma	doc_491521501898_item	2548577	et	3	main
loen	doc_491521501898_item	2548580	et	3	main
sa	doc_491521501899_item	2548599	et	3	main
vastust	doc_491521501899_item	2548615	et	4	main
et	doc_491521501899_item	2548630	et	3	main
kui	doc_491521501899_item	2548632	et	3	main
sa	doc_491521501899_item	2548633	et	3	main
elan	doc_491521501899_item	2548637	et	3	main
vaadata	doc_491521501899_item	2548647	et	4	main
näiteks	doc_491521501899_item	2548648	et	4	main
vanalinn	doc_491521501899_item	2548650	et	3	main
pirita	doc_491521501899_item	2548652	et	4	main
ja	doc_491521501899_item	2548653	et	3	main
palju	doc_491521501899_item	2548654	et	4	main
ehitti	doc_491521501900_item	2548679	et	4	main
tuulega	doc_491521501900_item	2548683	et	3	main
kastanipuu	doc_491521501900_item	2548685	et	4	main
ja	doc_491521501900_item	2548687	et	3	main
tammetõrusi	doc_491521501900_item	2548689	et	4	main
pähkleid	doc_491521501900_item	2548692	et	3	main
inimesed	doc_491521501900_item	2548698	et	3	main
ilmad	doc_491521501900_item	2548701	et	3	main
lähevad	doc_491521501900_item	2548702	et	3	main
tihti	doc_491521501900_item	2548705	et	3	main
on	doc_491521501900_item	2548706	et	4	main
öökülm	doc_491521501900_item	2548707	et	3	main
oravad	doc_491521501900_item	2548716	et	3	main
talvevarusid	doc_491521501900_item	2548718	et	3	main
talvaks	doc_491521501900_item	2548721	et	3	main
lompudel	doc_491521501900_item	2548724	et	4	main
vahel	doc_491521501900_item	2548729	et	4	main
merel	doc_491521501900_item	2548733	et	3	main
ja	doc_491521501901_item	2548751	et	3	main
värvuvad	doc_491521501901_item	2548755	et	4	main
kastanipuuld	doc_491521501901_item	2548766	et	4	main
lahkuvad	doc_491521501901_item	2548793	et	4	main
kured	doc_491521501901_item	2548794	et	3	main
saabub	doc_491521501902_item	2548824	et	3	main
koläseks	doc_491521501902_item	2548840	et	4	main
pähkleid	doc_491521501902_item	2548856	et	3	main
ja	doc_491521501902_item	2548860	et	3	main
inimesed	doc_491521501902_item	2548862	et	3	main
saaki	doc_491521501902_item	2548864	et	4	main
järjest	doc_491521501902_item	2548867	et	4	main
jahedamaks	doc_491521501902_item	2548868	et	4	main
tihti	doc_491521501902_item	2548869	et	3	main
lehed	doc_491521501902_item	2548874	et	3	main
lahkuvad	doc_491521501902_item	2548875	et	4	main
haned	doc_491521501902_item	2548877	et	3	main
juba	doc_491521501902_item	2548889	et	3	main
mõnikord	doc_491521501902_item	2548895	et	3	main
ka	doc_491521501902_item	2548897	et	3	main
ja	doc_491521501898_item	2548581	et	3	main
kiri	doc_491521501899_item	2548585	et	3	main
ja	doc_491521501899_item	2548590	et	3	main
talle	doc_491521501899_item	2548592	et	4	main
vastus	doc_491521501899_item	2548593	et	3	main
tere	doc_491521501899_item	2548594	et	3	main
tallinnasse	doc_491521501899_item	2548600	et	3	main
ootama	doc_491521501899_item	2548616	et	3	main
sinust	doc_491521501899_item	2548621	et	3	main
väga	doc_491521501899_item	2548645	et	3	main
loomaaed	doc_491521501899_item	2548649	et	3	main
mälestuskivid	doc_491521501899_item	2548651	et	3	main
on	doc_491521501900_item	2548681	et	4	main
korjatakse	doc_491521501900_item	2548691	et	3	main
õunad	doc_491521501900_item	2548695	et	3	main
ja	doc_491521501900_item	2548696	et	3	main
lehed	doc_491521501900_item	2548710	et	3	main
kured	doc_491521501900_item	2548712	et	3	main
hommikuti	doc_491521501900_item	2548722	et	4	main
on	doc_491521501900_item	2548734	et	4	main
sügis	doc_491521501901_item	2548741	et	3	main
algul	doc_491521501901_item	2548745	et	4	main
veel	doc_491521501901_item	2548749	et	4	main
sojad	doc_491521501901_item	2548750	et	3	main
puudelehed	doc_491521501901_item	2548756	et	3	main
punaseks	doc_491521501901_item	2548759	et	4	main
eriti	doc_491521501901_item	2548760	et	3	main
ilus	doc_491521501901_item	2548761	et	4	main
ja	doc_491521501901_item	2548768	et	3	main
tamme	doc_491521501901_item	2548770	et	4	main
sarapuuld	doc_491521501901_item	2548772	et	4	main
korjatakse	doc_491521501901_item	2548773	et	3	main
õunad	doc_491521501901_item	2548777	et	3	main
inimesed	doc_491521501901_item	2548780	et	3	main
lahevad	doc_491521501901_item	2548784	et	4	main
jahedamaks	doc_491521501901_item	2548786	et	4	main
haned	doc_491521501901_item	2548795	et	3	main
tasahilju	doc_491521501902_item	2548825	et	3	main
järkjargult	doc_491521501902_item	2548836	et	4	main
lehed	doc_491521501902_item	2548839	et	3	main
eriti	doc_491521501902_item	2548843	et	3	main
tammelt	doc_491521501902_item	2548852	et	4	main
tammetõrussid	doc_491521501902_item	2548853	et	4	main
valmivaid	doc_491521501902_item	2548858	et	4	main
pirnid	doc_491521501902_item	2548861	et	3	main
koristavad	doc_491521501902_item	2548863	et	4	main
ilmad	doc_491521501902_item	2548865	et	3	main
on	doc_491521501902_item	2548887	et	4	main
nõus	doc_491521501899_item	2548635	et	4	main
sinu	doc_491521501899_item	2548638	et	3	main
palju	doc_491521501899_item	2548646	et	4	main
sügis	doc_491521501900_item	2548660	et	3	main
saabub	doc_491521501900_item	2548661	et	3	main
tasahiljut	doc_491521501900_item	2548662	et	4	main
septembrialgul	doc_491521501900_item	2548663	et	3	main
on	doc_491521501900_item	2548664	et	4	main
aga	doc_491521501900_item	2548665	et	3	main
ilmat	doc_491521501900_item	2548666	et	4	main
veel	doc_491521501900_item	2548667	et	4	main
sojad	doc_491521501900_item	2548668	et	3	main
ja	doc_491521501900_item	2548669	et	3	main
puud-põõsad	doc_491521501900_item	2548670	et	3	main
rohelised	doc_491521501900_item	2548671	et	4	main
järkjärgult	doc_491521501900_item	2548672	et	3	main
värvuvad	doc_491521501900_item	2548673	et	4	main
lehed	doc_491521501900_item	2548675	et	3	main
puude	doc_491521501900_item	2548674	et	4	main
kollaseks	doc_491521501900_item	2548676	et	4	main
ja	doc_491521501900_item	2548677	et	3	main
punaseks	doc_491521501900_item	2548678	et	4	main
ilus	doc_491521501900_item	2548680	et	4	main
kukub	doc_491521501900_item	2548684	et	3	main
kastanimunasid	doc_491521501900_item	2548686	et	3	main
valmivad	doc_491521501900_item	2548694	et	4	main
saaki	doc_491521501900_item	2548700	et	4	main
ja	doc_491521501900_item	2548714	et	3	main
luiged	doc_491521501900_item	2548715	et	3	main
on	doc_491521501900_item	2548723	et	4	main
juba	doc_491521501900_item	2548725	et	3	main
torm	doc_491521501900_item	2548736	et	3	main
puud-põõsad	doc_491521501901_item	2548752	et	3	main
järgjärgult	doc_491521501901_item	2548754	et	4	main
kolaseks	doc_491521501901_item	2548757	et	4	main
ja	doc_491521501901_item	2548758	et	3	main
on	doc_491521501901_item	2548762	et	4	main
vaher	doc_491521501901_item	2548763	et	3	main
tuulega	doc_491521501901_item	2548764	et	3	main
kukub	doc_491521501901_item	2548765	et	3	main
tammelt	doc_491521501901_item	2548769	et	4	main
tõrusid	doc_491521501901_item	2548771	et	3	main
valmivad	doc_491521501901_item	2548776	et	4	main
ja	doc_491521501901_item	2548778	et	3	main
koristavad	doc_491521501901_item	2548781	et	4	main
ja	doc_491521501901_item	2548796	et	3	main
sügis	doc_491521501902_item	2548822	et	3	main
aga	doc_491521501902_item	2548829	et	3	main
puude	doc_491521501902_item	2548838	et	4	main
punaseks	doc_491521501902_item	2548842	et	4	main
sarapuult	doc_491521501902_item	2548854	et	3	main
langevad	doc_491521501902_item	2548873	et	4	main
kured	doc_491521501902_item	2548876	et	3	main
luiged	doc_491521501902_item	2548879	et	3	main
korjavad	doc_491521501902_item	2548881	et	4	main
lompidel	doc_491521501902_item	2548888	et	3	main
vahel	doc_491521501902_item	2548893	et	4	main
sajab	doc_491521501902_item	2548896	et	3	main
torm	doc_491521501902_item	2548902	et	3	main
sarapult	doc_491521501900_item	2548690	et	3	main
puudel-põõsasteld	doc_491521501900_item	2548708	et	4	main
lahkuvad	doc_491521501900_item	2548711	et	4	main
haned	doc_491521501900_item	2548713	et	3	main
valmistub	doc_491521501900_item	2548720	et	3	main
jää	doc_491521501900_item	2548726	et	4	main
kestavad	doc_491521501900_item	2548728	et	4	main
nädalaid	doc_491521501900_item	2548730	et	3	main
mõnikord	doc_491521501900_item	2548731	et	3	main
sajab	doc_491521501900_item	2548732	et	3	main
etteütlus	doc_491521501901_item	2548737	et	3	main
ütles	doc_491521501901_item	2548739	et	3	main
saabub	doc_491521501901_item	2548742	et	3	main
kastanimunasid	doc_491521501901_item	2548767	et	3	main
pähkleid	doc_491521501901_item	2548774	et	3	main
saaki	doc_491521501901_item	2548782	et	4	main
tihti	doc_491521501901_item	2548787	et	3	main
on	doc_491521501901_item	2548788	et	4	main
öökülm	doc_491521501901_item	2548789	et	3	main
puudelt-poosastelt	doc_491521501901_item	2548790	et	4	main
luiged	doc_491521501901_item	2548797	et	3	main
oravad	doc_491521501901_item	2548798	et	3	main
korjavad	doc_491521501901_item	2548799	et	4	main
talvevarusid	doc_491521501901_item	2548800	et	3	main
loodus	doc_491521501901_item	2548801	et	4	main
valmistub	doc_491521501901_item	2548802	et	3	main
talveks	doc_491521501901_item	2548803	et	4	main
hommikuti	doc_491521501901_item	2548804	et	4	main
on	doc_491521501901_item	2548805	et	4	main
lompidel	doc_491521501901_item	2548806	et	3	main
juba	doc_491521501901_item	2548807	et	3	main
jää	doc_491521501901_item	2548808	et	4	main
vihmasajud	doc_491521501901_item	2548809	et	3	main
kestavad	doc_491521501901_item	2548810	et	4	main
vähel	doc_491521501901_item	2548811	et	3	main
nädalait	doc_491521501901_item	2548812	et	4	main
mõnikord	doc_491521501901_item	2548813	et	3	main
sajab	doc_491521501901_item	2548814	et	3	main
ka	doc_491521501901_item	2548815	et	3	main
lörtsi	doc_491521501901_item	2548816	et	4	main
merel	doc_491521501901_item	2548817	et	3	main
on	doc_491521501901_item	2548818	et	4	main
sageli	doc_491521501901_item	2548819	et	3	main
torm	doc_491521501901_item	2548820	et	3	main
ärjest	doc_491521501901_item	2548785	et	4	main
langevad	doc_491521501901_item	2548791	et	4	main
lehed	doc_491521501901_item	2548792	et	3	main
etteütlus	doc_491521501902_item	2548821	et	3	main
sügis	doc_491521501902_item	2548823	et	3	main
septembrit	doc_491521501902_item	2548826	et	3	main
on	doc_491521501902_item	2548828	et	4	main
sojad	doc_491521501902_item	2548832	et	3	main
ja	doc_491521501902_item	2548833	et	3	main
puud-põsad	doc_491521501902_item	2548834	et	4	main
värvuvad	doc_491521501902_item	2548837	et	4	main
ilus	doc_491521501902_item	2548844	et	4	main
vaher	doc_491521501902_item	2548846	et	3	main
tuulega	doc_491521501902_item	2548847	et	3	main
kukub	doc_491521501902_item	2548848	et	3	main
kasstanipuult	doc_491521501902_item	2548849	et	4	main
ja	doc_491521501902_item	2548851	et	3	main
aidadest	doc_491521501902_item	2548857	et	4	main
õunad	doc_491521501902_item	2548859	et	3	main
lähevad	doc_491521501902_item	2548866	et	3	main
puudeld-põsasteld	doc_491521501902_item	2548872	et	4	main
ja	doc_491521501902_item	2548878	et	3	main
oravad	doc_491521501902_item	2548880	et	3	main
talvevalusid	doc_491521501902_item	2548882	et	4	main
loodus	doc_491521501902_item	2548883	et	4	main
valmistub	doc_491521501902_item	2548884	et	3	main
talveks	doc_491521501902_item	2548885	et	4	main
vihmasajud	doc_491521501902_item	2548891	et	3	main
kestavad	doc_491521501902_item	2548892	et	4	main
nädalaid	doc_491521501902_item	2548894	et	3	main
lördsi	doc_491521501902_item	2548898	et	4	main
merel	doc_491521501902_item	2548899	et	3	main
on	doc_491521501902_item	2548900	et	4	main
sageli	doc_491521501902_item	2548901	et	3	main
kirjud	doc_491521501905_item	2549141	et	4	main
uudised	doc_491521501905_item	2549142	et	3	main
tumedate	doc_491521501905_item	2549143	et	3	main
näha	doc_491521501905_item	2549149	et	3	main
afgaanlased	doc_491521501905_item	2549151	et	4	main
naiste	doc_491521501905_item	2549160	et	3	main
riietuse	doc_491521501905_item	2549165	et	4	main
algul	doc_491521501902_item	2548827	et	4	main
ilmad	doc_491521501902_item	2548830	et	3	main
veel	doc_491521501902_item	2548831	et	4	main
rohelised	doc_491521501902_item	2548835	et	4	main
ja	doc_491521501902_item	2548841	et	3	main
on	doc_491521501902_item	2548845	et	4	main
kastanimunasid	doc_491521501902_item	2548850	et	3	main
korjatakse	doc_491521501902_item	2548855	et	3	main
on	doc_491521501902_item	2548870	et	4	main
öökülm	doc_491521501902_item	2548871	et	3	main
hommikuti	doc_491521501902_item	2548886	et	4	main
jää	doc_491521501902_item	2548890	et	4	main
ümberjutustus	doc_491521501905_item	2549140	et	3	main
maailmast	doc_491521501905_item	2549156	et	4	main
mässitud	doc_491521501905_item	2549166	et	4	main
hakkasid	doc_491521501905_item	2549168	et	4	main
nato	doc_491521501905_item	2549173	et	4	main
sõdureid	doc_491521501905_item	2549174	et	3	main
leiti	doc_491521501905_item	2549175	et	3	main
selle	doc_491521501905_item	2549196	et	4	main
sai	doc_491521501905_item	2549203	et	4	main
naistele	doc_491521501905_item	2549206	et	3	main
kannavad	doc_491521501905_item	2549211	et	3	main
aga	doc_491521501905_item	2549215	et	3	main
riietuse	doc_491521501905_item	2549221	et	4	main
näia	doc_491521501905_item	2549224	et	4	main
kanda	doc_491521501905_item	2549235	et	4	main
värskeid	doc_491521501905_item	2549241	et	4	main
keetud	doc_491521501905_item	2549242	et	4	main
korneeli	doc_491521501905_item	2549251	et	4	main
kuigi	doc_491521501905_item	2549254	et	3	main
väheneb	doc_491521501905_item	2549256	et	3	main
ta	doc_491521501905_item	2549260	et	4	main
punase	doc_491521501905_item	2549268	et	4	main
ja	doc_491521501905_item	2549275	et	3	main
olin	doc_491521501907_item	2549404	et	3	main
esimesel	doc_491521501907_item	2549405	et	3	main
see	doc_491521501907_item	2549420	et	3	main
oli	doc_491521501907_item	2549426	et	3	main
pintsak	doc_491521501907_item	2549430	et	3	main
kooli	doc_491521501907_item	2549442	et	4	main
olnud	doc_491521501907_item	2549446	et	4	main
mida	doc_491521501907_item	2549448	et	4	main
selga	doc_491521501907_item	2549449	et	4	main
mõtlen	doc_491521501907_item	2549469	et	3	main
kuidas	doc_491521501907_item	2549475	et	3	main
riietuma	doc_491521501907_item	2549485	et	3	main
ei	doc_491521501907_item	2549495	et	4	main
anna	doc_491521501907_item	2549496	et	4	main
võimalik	doc_491521501905_item	2549146	et	3	main
ei	doc_491521501905_item	2549152	et	4	main
tsivilisatsiooni	doc_491521501905_item	2549155	et	4	main
riigis	doc_491521501905_item	2549159	et	3	main
hulgas	doc_491521501905_item	2549161	et	4	main
paanika	doc_491521501905_item	2549163	et	4	main
oma	doc_491521501905_item	2549164	et	4	main
laiali	doc_491521501905_item	2549169	et	3	main
jooksma	doc_491521501905_item	2549170	et	3	main
kuid	doc_491521501905_item	2549183	et	4	main
seda	doc_491521501905_item	2549187	et	3	main
prillid	doc_491521501905_item	2549200	et	3	main
lõi	doc_491521501905_item	2549207	et	4	main
pähe	doc_491521501905_item	2549208	et	4	main
mitte	doc_491521501905_item	2549212	et	3	main
lihtsaid	doc_491521501905_item	2549213	et	3	main
rengeeniga	doc_491521501905_item	2549216	et	4	main
selle	doc_491521501905_item	2549217	et	4	main
läbi	doc_491521501905_item	2549220	et	4	main
ja	doc_491521501905_item	2549223	et	3	main
naisi	doc_491521501905_item	2549226	et	3	main
kehi	doc_491521501905_item	2549227	et	4	main
aga	doc_491521501905_item	2549228	et	3	main
afgaanlanad	doc_491521501905_item	2549229	et	4	main
ei	doc_491521501905_item	2549230	et	4	main
saa	doc_491521501905_item	2549231	et	4	main
seda	doc_491521501905_item	2549232	et	3	main
tomatid	doc_491521501905_item	2549237	et	3	main
haotatud	doc_491521501905_item	2549244	et	4	main
on	doc_491521501905_item	2549246	et	4	main
kui	doc_491521501905_item	2549248	et	3	main
prillidega	doc_491521501905_item	2549144	et	3	main
on	doc_491521501905_item	2549145	et	4	main
läbi	doc_491521501905_item	2549148	et	4	main
vanad	doc_491521501905_item	2549150	et	3	main
tulnukatega	doc_491521501905_item	2549157	et	4	main
relvastatuid	doc_491521501905_item	2549181	et	4	main
nende	doc_491521501905_item	2549184	et	4	main
eeristavad	doc_491521501905_item	2549193	et	4	main
kandma	doc_491521501905_item	2549194	et	3	main
kuid	doc_491521501905_item	2549195	et	4	main
maha	doc_491521501905_item	2549201	et	4	main
saavad	doc_491521501905_item	2549219	et	4	main
on	doc_491521501905_item	2549238	et	4	main
kui	doc_491521501905_item	2549240	et	3	main
ja	doc_491521501905_item	2549243	et	3	main
kasulikem	doc_491521501905_item	2549247	et	4	main
sisaldus	doc_491521501905_item	2549258	et	4	main
lükopeenid	doc_491521501905_item	2549270	et	4	main
sellepärast	doc_491521501905_item	2549276	et	3	main
skleroosi	doc_491521501905_item	2549279	et	4	main
pahaloomuliste	doc_491521501905_item	2549281	et	4	main
teket	doc_491521501905_item	2549283	et	3	main
naisi	doc_491521501905_item	2549147	et	3	main
saa	doc_491521501905_item	2549153	et	4	main
harjuda	doc_491521501905_item	2549154	et	3	main
hiljuti	doc_491521501905_item	2549158	et	4	main
levis	doc_491521501905_item	2549162	et	4	main
daamid	doc_491521501905_item	2549167	et	3	main
nägid	doc_491521501905_item	2549172	et	4	main
inimesi	doc_491521501905_item	2549182	et	4	main
päikeseprille	doc_491521501905_item	2549185	et	3	main
pärast	doc_491521501905_item	2549186	et	4	main
hispaania	doc_491521501905_item	2549188	et	4	main
ja	doc_491521501905_item	2549189	et	3	main
itaalia	doc_491521501905_item	2549190	et	4	main
sõdurite	doc_491521501905_item	2549191	et	3	main
prille	doc_491521501905_item	2549197	et	3	main
need	doc_491521501905_item	2549199	et	3	main
selgeks	doc_491521501905_item	2549204	et	3	main
et	doc_491521501905_item	2549209	et	3	main
võõramaalased	doc_491521501905_item	2549210	et	3	main
prille	doc_491521501905_item	2549214	et	3	main
vaadata	doc_491521501905_item	2549222	et	4	main
alasti	doc_491521501905_item	2549225	et	3	main
haotatud	doc_491521501905_item	2549236	et	4	main
kasulikumad	doc_491521501905_item	2549239	et	4	main
ülikooli	doc_491521501905_item	2549252	et	4	main
tomatides	doc_491521501905_item	2549259	et	4	main
mis	doc_491521501905_item	2549264	et	4	main
tomatidele	doc_491521501905_item	2549266	et	4	main
talistavad	doc_491521501905_item	2549277	et	4	main
sinine	doc_491521501907_item	2549411	et	4	main
kleit	doc_491521501907_item	2549412	et	3	main
hele-sinine	doc_491521501907_item	2549413	et	4	main
sinine	doc_491521501907_item	2549415	et	4	main
oli	doc_491521501907_item	2549421	et	3	main
koolivorm	doc_491521501907_item	2549423	et	3	main
sinised	doc_491521501907_item	2549427	et	4	main
ja	doc_491521501907_item	2549429	et	3	main
hele-sinine	doc_491521501907_item	2549431	et	4	main
oli	doc_491521501907_item	2549436	et	3	main
hea	doc_491521501907_item	2549437	et	4	main
ja	doc_491521501907_item	2549444	et	3	main
mida	doc_491521501907_item	2549467	et	4	main
jõukal	doc_491521501907_item	2549478	et	3	main
temal	doc_491521501907_item	2549488	et	3	main
oma	doc_491521501907_item	2549490	et	4	main
aga	doc_491521501907_item	2549492	et	3	main
mitte	doc_491521501907_item	2549493	et	3	main
keegi	doc_491521501907_item	2549494	et	4	main
kutsuvad	doc_491521501908_item	2549536	et	4	main
ostavad	doc_491521501908_item	2549547	et	3	main
kui	doc_491521501908_item	2549554	et	3	main
mõtleme1	doc_491521501908_item	2549558	et	3	main
on	doc_491521501908_item	2549564	et	4	main
ajal	doc_491521501908_item	2549568	et	4	main
inimesed	doc_491521501908_item	2549571	et	3	main
potililli	doc_491521501908_item	2549573	et	4	main
sest	doc_491521501908_item	2549574	et	4	main
või	doc_491521501908_item	2549585	et	4	main
pere	doc_491521501908_item	2549589	et	4	main
lapsi	doc_491521501908_item	2549591	et	4	main
võib	doc_491521501908_item	2549592	et	3	main
4	doc_491521501908_item	2549595	et	2	main
puuvilju	doc_491521501908_item	2549596	et	3	main
või	doc_491521501908_item	2549597	et	4	main
kommi	doc_491521501908_item	2549598	et	4	main
ka	doc_491521501908_item	2549599	et	3	main
ilusa	doc_491521501908_item	2549600	et	3	main
5	doc_491521501908_item	2549601	et	2	main
ei	doc_491521501908_item	2549613	et	4	main
näiteks	doc_491521501908_item	2549630	et	4	main
värske	doc_491521501908_item	2549633	et	4	main
võite	doc_491521501908_item	2549635	et	4	main
kindel	doc_491521501908_item	2549636	et	3	main
olla	doc_491521501908_item	2549637	et	3	main
et	doc_491521501908_item	2549638	et	3	main
kui	doc_491521501905_item	2549171	et	3	main
välja	doc_491521501905_item	2549176	et	4	main
et	doc_491521501905_item	2549177	et	3	main
nad	doc_491521501905_item	2549178	et	3	main
kartsid	doc_491521501905_item	2549179	et	4	main
mitte	doc_491521501905_item	2549180	et	3	main
kes	doc_491521501905_item	2549192	et	4	main
käskisid	doc_491521501905_item	2549198	et	4	main
võtma	doc_491521501905_item	2549202	et	3	main
et	doc_491521501905_item	2549205	et	3	main
pärast	doc_491521501905_item	2549218	et	4	main
häbi	doc_491521501905_item	2549233	et	4	main
välja	doc_491521501905_item	2549234	et	4	main
tomatid	doc_491521501905_item	2549245	et	3	main
kuumtöötlus	doc_491521501905_item	2549255	et	3	main
vitamiini	doc_491521501905_item	2549257	et	4	main
omastamise	doc_491521501905_item	2549263	et	4	main
tugevad	doc_491521501905_item	2549273	et	4	main
antioksüdandid	doc_491521501905_item	2549274	et	4	main
aga	doc_491521501907_item	2549424	et	3	main
aeg	doc_491521501907_item	2549438	et	3	main
kõik	doc_491521501907_item	2549439	et	4	main
värsked	doc_491521501905_item	2549249	et	4	main
kinnitavad	doc_491521501905_item	2549250	et	4	main
keemikud	doc_491521501905_item	2549253	et	3	main
pareneb	doc_491521501905_item	2549261	et	3	main
lükopeenide-pigmentide	doc_491521501905_item	2549262	et	3	main
annavad	doc_491521501905_item	2549265	et	3	main
eri	doc_491521501905_item	2549267	et	4	main
värvi	doc_491521501905_item	2549269	et	4	main
on	doc_491521501905_item	2549271	et	4	main
väga	doc_491521501905_item	2549272	et	3	main
veresoonte	doc_491521501905_item	2549278	et	3	main
ja	doc_491521501905_item	2549280	et	3	main
kasvajate	doc_491521501905_item	2549282	et	4	main
klassil	doc_491521501907_item	2549406	et	3	main
meie	doc_491521501907_item	2549407	et	4	main
pluus	doc_491521501907_item	2549414	et	3	main
müts	doc_491521501907_item	2549416	et	4	main
punane	doc_491521501907_item	2549418	et	4	main
tüdruku	doc_491521501907_item	2549422	et	3	main
püksid	doc_491521501907_item	2549428	et	3	main
särk	doc_491521501907_item	2549432	et	3	main
ja	doc_491521501907_item	2549433	et	3	main
müts	doc_491521501907_item	2549434	et	4	main
see	doc_491521501907_item	2549435	et	3	main
koolivormis	doc_491521501907_item	2549443	et	3	main
probleemi	doc_491521501907_item	2549447	et	4	main
on	doc_491521501907_item	2549452	et	4	main
ilusam	doc_491521501907_item	2549453	et	4	main
ja	doc_491521501907_item	2549454	et	3	main
parem	doc_491521501907_item	2549455	et	4	main
käisid	doc_491521501907_item	2549462	et	4	main
riietuvad	doc_491521501907_item	2549464	et	4	main
mida	doc_491521501907_item	2549465	et	4	main
tahtsid	doc_491521501907_item	2549466	et	4	main
et	doc_491521501907_item	2549470	et	3	main
ei	doc_491521501907_item	2549472	et	4	main
laps	doc_491521501907_item	2549476	et	4	main
perekonnal	doc_491521501907_item	2549479	et	4	main
on	doc_491521501907_item	2549481	et	4	main
kõik	doc_491521501907_item	2549482	et	4	main
ja	doc_491521501907_item	2549487	et	3	main
essee	doc_491521501907_item	2549377	et	4	main
igal	doc_491521501907_item	2549378	et	3	main
koolil	doc_491521501907_item	2549379	et	4	main
peaks	doc_491521501907_item	2549380	et	4	main
olema	doc_491521501907_item	2549381	et	4	main
oma	doc_491521501907_item	2549382	et	4	main
koolivorm	doc_491521501907_item	2549383	et	3	main
sest	doc_491521501907_item	2549384	et	4	main
see	doc_491521501907_item	2549385	et	3	main
aitab	doc_491521501907_item	2549386	et	3	main
kaasa	doc_491521501907_item	2549387	et	4	main
omakoolitunde	doc_491521501907_item	2549388	et	4	main
tekkimisele	doc_491521501907_item	2549389	et	4	main
koolil	doc_491521501907_item	2549390	et	4	main
peab	doc_491521501907_item	2549391	et	4	main
olema	doc_491521501907_item	2549392	et	4	main
koolivorm	doc_491521501907_item	2549393	et	3	main
sellepärast	doc_491521501907_item	2549394	et	3	main
see	doc_491521501907_item	2549395	et	3	main
aitab	doc_491521501907_item	2549396	et	3	main
kaasa	doc_491521501907_item	2549397	et	4	main
omakoolitunde	doc_491521501907_item	2549398	et	4	main
tekkimisele	doc_491521501907_item	2549399	et	4	main
mina	doc_491521501907_item	2549400	et	4	main
käisin	doc_491521501907_item	2549401	et	3	main
kooli	doc_491521501907_item	2549402	et	4	main
kui	doc_491521501907_item	2549403	et	3	main
koolil	doc_491521501907_item	2549408	et	4	main
oli	doc_491521501907_item	2549409	et	3	main
koolivorm	doc_491521501907_item	2549410	et	3	main
ja	doc_491521501907_item	2549417	et	3	main
rätik	doc_491521501907_item	2549419	et	3	main
poisil	doc_491521501907_item	2549425	et	3	main
käisid	doc_491521501907_item	2549441	et	4	main
ei	doc_491521501907_item	2549445	et	4	main
mida	doc_491521501907_item	2549451	et	4	main
olid	doc_491521501907_item	2549457	et	4	main
ühesugused	doc_491521501907_item	2549458	et	3	main
aga	doc_491521501907_item	2549459	et	3	main
praegu	doc_491521501907_item	2549460	et	3	main
lapsed	doc_491521501907_item	2549461	et	3	main
kooli	doc_491521501907_item	2549463	et	4	main
õesti	doc_491521501907_item	2549474	et	4	main
elab	doc_491521501907_item	2549477	et	3	main
siistal	doc_491521501907_item	2549480	et	4	main
rikas	doc_491521501907_item	2549486	et	4	main
on	doc_491521501907_item	2549489	et	4	main
rahad	doc_491521501907_item	2549491	et	4	main
õigus	doc_491521501907_item	2549498	et	4	main
heida	doc_491521501907_item	2549499	et	4	main
vaese	doc_491521501907_item	2549500	et	4	main
lapse	doc_491521501907_item	2549501	et	4	main
üle	doc_491521501907_item	2549502	et	3	main
sellepärast	doc_491521501907_item	2549503	et	3	main
vaene	doc_491521501907_item	2549504	et	4	main
lapspaha	doc_491521501907_item	2549505	et	4	main
riietub	doc_491521501907_item	2549506	et	3	main
selleks	doc_491521501907_item	2549507	et	4	main
et	doc_491521501907_item	2549508	et	3	main
seda	doc_491521501907_item	2549509	et	3	main
probleeme	doc_491521501907_item	2549510	et	3	main
ei	doc_491521501907_item	2549511	et	4	main
ole	doc_491521501907_item	2549512	et	4	main
on	doc_491521501907_item	2549513	et	4	main
vaja	doc_491521501907_item	2549514	et	4	main
juhtida	doc_491521501907_item	2549515	et	4	main
koolivormi	doc_491521501907_item	2549516	et	4	main
see	doc_491521501907_item	2549517	et	3	main
on	doc_491521501907_item	2549518	et	4	main
väga	doc_491521501907_item	2549519	et	3	main
hea	doc_491521501907_item	2549520	et	4	main
probleem	doc_491521501907_item	2549523	et	3	main
rikkade	doc_491521501907_item	2549525	et	4	main
ja	doc_491521501907_item	2549526	et	3	main
lapsede	doc_491521501907_item	2549528	et	4	main
eksamitöö	doc_491521501908_item	2549530	et	4	main
vali	doc_491521501908_item	2549531	et	4	main
igasse	doc_491521501908_item	2549532	et	3	main
unustada	doc_491521501908_item	2549537	et	3	main
külalised	doc_491521501908_item	2549538	et	4	main
ruudulise	doc_491521501908_item	2549540	et	4	main
meeles	doc_491521501908_item	2549541	et	3	main
puuvilju	doc_491521501908_item	2549548	et	3	main
minema	doc_491521501908_item	2549557	et	3	main
viimasel	doc_491521501908_item	2549567	et	3	main
kauem	doc_491521501908_item	2549578	et	4	main
ja	doc_491521501908_item	2549580	et	3	main
silmarõõmu	doc_491521501908_item	2549582	et	4	main
mitu	doc_491521501908_item	2549583	et	4	main
kuud	doc_491521501908_item	2549584	et	4	main
kui	doc_491521501908_item	2549588	et	3	main
lapsed	doc_491521501907_item	2549440	et	3	main
panna	doc_491521501907_item	2549450	et	4	main
kõik	doc_491521501907_item	2549456	et	4	main
meeldibmina	doc_491521501907_item	2549468	et	4	main
see	doc_491521501907_item	2549471	et	3	main
ole	doc_491521501907_item	2549473	et	4	main
ta	doc_491521501907_item	2549483	et	4	main
võib	doc_491521501907_item	2549484	et	3	main
vahel	doc_491521501907_item	2549529	et	4	main
sõna	doc_491521501908_item	2549535	et	4	main
tavaliselt	doc_491521501908_item	2549542	et	4	main
värvilise	doc_491521501908_item	2549543	et	4	main
kui	doc_491521501908_item	2549551	et	3	main
külla	doc_491521501908_item	2549553	et	4	main
hakkame	doc_491521501908_item	2549555	et	3	main
mida	doc_491521501908_item	2549560	et	4	main
kaasa	doc_491521501908_item	2549561	et	4	main
võtta	doc_491521501908_item	2549562	et	3	main
lilled	doc_491521501908_item	2549563	et	3	main
sobivad	doc_491521501908_item	2549566	et	4	main
2	doc_491521501908_item	2549569	et	2	main
rohkem	doc_491521501908_item	2549572	et	4	main
3	doc_491521501908_item	2549577	et	2	main
kaasa	doc_491521501908_item	2549593	et	4	main
tuua	doc_491521501908_item	2549594	et	3	main
raamatu	doc_491521501908_item	2549603	et	4	main
väikese	doc_491521501908_item	2549605	et	4	main
mänguasja	doc_491521501908_item	2549606	et	4	main
eest	doc_491521501908_item	2549607	et	4	main
ka	doc_491521501908_item	2549617	et	3	main
lemmikloomi	doc_491521501908_item	2549618	et	4	main
tore	doc_491521501908_item	2549621	et	3	main
pererahva	doc_491521501908_item	2549623	et	3	main
9	doc_491521501908_item	2549625	et	2	main
või	doc_491521501908_item	2549632	et	4	main
10	doc_491521501908_item	2549645	et	2	main
meeles	doc_491521501908_item	2549646	et	3	main
kirjuta	doc_491521501908_item	2549647	et	4	main
tavaline	doc_491521501908_item	2549658	et	4	main
hommikul	doc_491521501908_item	2549660	et	3	main
kutsekoolis	doc_491521501908_item	2549663	et	4	main
koos	doc_491521501908_item	2549671	et	4	main
naitus	doc_491521501908_item	2549673	et	4	main
meeldib	doc_491521501908_item	2549682	et	3	main
huvitavad	doc_491521501908_item	2549688	et	4	main
väga	doc_491521501908_item	2549690	et	3	main
pärast	doc_491521501908_item	2549697	et	4	main
me	doc_491521501908_item	2549699	et	4	main
käisime	doc_491521501908_item	2549700	et	3	main
koju	doc_491521501908_item	2549701	et	3	main
olin	doc_491521501908_item	2549725	et	3	main
läksin	doc_491521501908_item	2549730	et	3	main
jalgsi	doc_491521501908_item	2549731	et	3	main
siis	doc_491521501908_item	2549733	et	3	main
läksin	doc_491521501908_item	2549735	et	3	main
ei	doc_491521501908_item	2549741	et	4	main
eksamitöö	doc_491521501909_item	2549743	et	4	main
ruudulise	doc_491521501909_item	2549753	et	4	main
värvilise	doc_491521501909_item	2549756	et	4	main
külla	doc_491521501909_item	2549766	et	4	main
kui	doc_491521501909_item	2549767	et	3	main
3	doc_491521501909_item	2549790	et	2	main
värsked	doc_491521501909_item	2549792	et	4	main
ja	doc_491521501909_item	2549793	et	3	main
pakuvad	doc_491521501909_item	2549794	et	3	main
silmarõõmu	doc_491521501909_item	2549795	et	4	main
mitu	doc_491521501909_item	2549796	et	4	main
aastat	doc_491521501909_item	2549800	et	3	main
4	doc_491521501909_item	2549808	et	2	main
või	doc_491521501909_item	2549817	et	4	main
lemmikloomi	doc_491521501909_item	2549831	et	4	main
pererahva	doc_491521501909_item	2549836	et	3	main
kala	doc_491521501909_item	2549847	et	4	main
päev	doc_491521501909_item	2549867	et	3	main
päev	doc_491521501909_item	2549872	et	3	main
ja	doc_491521501909_item	2549878	et	3	main
pesin	doc_491521501909_item	2549884	et	3	main
pärast	doc_491521501909_item	2549894	et	4	main
seda	doc_491521501909_item	2549895	et	3	main
umbes	doc_491521501909_item	2549896	et	4	main
nukrad	doc_491521501909_item	2549921	et	3	main
kõige	doc_491521501909_item	2549923	et	4	main
temale	doc_491521501907_item	2549497	et	3	main
kadub	doc_491521501907_item	2549522	et	4	main
riietus	doc_491521501907_item	2549524	et	4	main
vaenede	doc_491521501907_item	2549527	et	4	main
üks	doc_491521501908_item	2549534	et	3	main
tore	doc_491521501908_item	2549539	et	3	main
jääda	doc_491521501908_item	2549549	et	4	main
külla	doc_491521501908_item	2549556	et	4	main
alati	doc_491521501908_item	2549565	et	4	main
ostavad	doc_491521501908_item	2549570	et	3	main
seisavad	doc_491521501908_item	2549576	et	3	main
pakuvad	doc_491521501908_item	2549581	et	3	main
isegi	doc_491521501908_item	2549586	et	4	main
värvilise	doc_491521501908_item	2549602	et	4	main
tohi	doc_491521501908_item	2549614	et	4	main
7	doc_491521501908_item	2549615	et	2	main
unustada	doc_491521501908_item	2549616	et	3	main
on	doc_491521501908_item	2549619	et	4	main
neljajalgsele	doc_491521501908_item	2549624	et	3	main
porgandi	doc_491521501908_item	2549631	et	3	main
kala	doc_491521501908_item	2549634	et	4	main
tänavad	doc_491521501908_item	2549640	et	4	main
lauset	doc_491521501908_item	2549649	et	3	main
üks	doc_491521501908_item	2549652	et	3	main
päev	doc_491521501908_item	2549654	et	3	main
mul	doc_491521501908_item	2549656	et	3	main
minna	doc_491521501908_item	2549666	et	3	main
nukud	doc_491521501908_item	2549676	et	3	main
nad	doc_491521501908_item	2549677	et	3	main
mulle	doc_491521501908_item	2549681	et	4	main
seda	doc_491521501908_item	2549683	et	3	main
asjad	doc_491521501908_item	2549686	et	3	main
mulle	doc_491521501908_item	2549689	et	4	main
meeldib	doc_491521501908_item	2549691	et	3	main
ja	doc_491521501908_item	2549694	et	3	main
ja	doc_491521501907_item	2549521	et	3	main
lünka	doc_491521501908_item	2549533	et	4	main
sõbrale	doc_491521501908_item	2549544	et	3	main
ütlevad	doc_491521501908_item	2549545	et	4	main
kauem	doc_491521501908_item	2549546	et	4	main
otsivad	doc_491521501908_item	2549550	et	4	main
lähme	doc_491521501908_item	2549552	et	3	main
tavaliselt	doc_491521501908_item	2549559	et	4	main
need	doc_491521501908_item	2549575	et	3	main
värsked	doc_491521501908_item	2549579	et	4	main
aastat	doc_491521501908_item	2549587	et	3	main
on	doc_491521501908_item	2549590	et	4	main
või	doc_491521501908_item	2549604	et	4	main
6	doc_491521501908_item	2549608	et	2	main
ütlevad	doc_491521501908_item	2549609	et	4	main
lapsed	doc_491521501908_item	2549610	et	3	main
aitäh	doc_491521501908_item	2549611	et	3	main
8	doc_491521501908_item	2549620	et	2	main
kui	doc_491521501908_item	2549622	et	3	main
sõbrale	doc_491521501908_item	2549626	et	3	main
oma	doc_491521501908_item	2549628	et	4	main
taskust	doc_491521501908_item	2549629	et	3	main
ja	doc_491521501908_item	2549642	et	3	main
peavad	doc_491521501908_item	2549643	et	4	main
kaua	doc_491521501908_item	2549644	et	3	main
oli	doc_491521501908_item	2549651	et	3	main
eile	doc_491521501908_item	2549655	et	3	main
me	doc_491521501908_item	2549661	et	4	main
olime	doc_491521501908_item	2549662	et	3	main
näitusele	doc_491521501908_item	2549667	et	4	main
grupiga	doc_491521501908_item	2549670	et	3	main
nimetus	doc_491521501908_item	2549674	et	4	main
on	doc_491521501908_item	2549675	et	4	main
nukrad	doc_491521501908_item	2549680	et	3	main
olid	doc_491521501908_item	2549687	et	4	main
punapea	doc_491521501908_item	2549692	et	4	main
õpilane	doc_491521501908_item	2549693	et	3	main
seal	doc_491521501908_item	2549723	et	4	main
spordimasast	doc_491521501908_item	2549728	et	4	main
ma	doc_491521501908_item	2549734	et	3	main
midagi	doc_491521501908_item	2549737	et	4	main
asju	doc_491521501908_item	2549739	et	3	main
sõna	doc_491521501909_item	2549748	et	4	main
tavaliselt	doc_491521501909_item	2549755	et	4	main
sõbrale	doc_491521501909_item	2549757	et	3	main
kauem	doc_491521501909_item	2549791	et	4	main
isegi	doc_491521501909_item	2549799	et	4	main
pere	doc_491521501909_item	2549802	et	4	main
on	doc_491521501909_item	2549803	et	4	main
tuua	doc_491521501909_item	2549807	et	3	main
puuvilju	doc_491521501909_item	2549809	et	3	main
ilusa	doc_491521501909_item	2549813	et	3	main
eest	doc_491521501909_item	2549820	et	4	main
ütlevad	doc_491521501909_item	2549822	et	4	main
aitäh	doc_491521501909_item	2549824	et	3	main
ei	doc_491521501909_item	2549826	et	4	main
tohi	doc_491521501909_item	2549827	et	4	main
7	doc_491521501909_item	2549828	et	2	main
unustada	doc_491521501909_item	2549829	et	3	main
ka	doc_491521501909_item	2549830	et	3	main
tore	doc_491521501909_item	2549834	et	3	main
9	doc_491521501909_item	2549838	et	2	main
oma	doc_491521501909_item	2549841	et	4	main
porgandi	doc_491521501909_item	2549844	et	3	main
teid	doc_491521501909_item	2549854	et	4	main
ja	doc_491521501909_item	2549855	et	3	main
peavad	doc_491521501909_item	2549856	et	4	main
kaua	doc_491521501909_item	2549857	et	3	main
10	doc_491521501909_item	2549858	et	2	main
meeles	doc_491521501909_item	2549859	et	3	main
kirjuta	doc_491521501909_item	2549860	et	4	main
15-18	doc_491521501909_item	2549861	et	2	main
lauset	doc_491521501909_item	2549862	et	3	main
eile	doc_491521501909_item	2549863	et	3	main
oli	doc_491521501909_item	2549864	et	3	main
tavaline	doc_491521501909_item	2549871	et	4	main
kell	doc_491521501909_item	2549876	et	3	main
sõin	doc_491521501909_item	2549883	et	3	main
me	doc_491521501909_item	2549892	et	4	main
töötasime	doc_491521501909_item	2549893	et	3	main
valges	doc_491521501909_item	2549904	et	4	main
saalis	doc_491521501909_item	2549905	et	4	main
ja	doc_491521501909_item	2549906	et	3	main
mille	doc_491521501909_item	2549907	et	3	main
olnud	doc_491521501909_item	2549917	et	4	main
aga	doc_491521501909_item	2549919	et	3	main
mulle	doc_491521501909_item	2549922	et	4	main
maksis	doc_491521501909_item	2549930	et	4	main
ära	doc_491521501908_item	2549612	et	4	main
leiate	doc_491521501908_item	2549627	et	3	main
teid	doc_491521501908_item	2549641	et	4	main
eile	doc_491521501908_item	2549650	et	3	main
me	doc_491521501908_item	2549664	et	4	main
otsustasime	doc_491521501908_item	2549665	et	3	main
läksime	doc_491521501908_item	2549669	et	3	main
grupijuhataja	doc_491521501908_item	2549672	et	4	main
olid	doc_491521501908_item	2549678	et	4	main
näitus	doc_491521501908_item	2549684	et	3	main
kodukäija	doc_491521501908_item	2549695	et	4	main
eile	doc_491521501908_item	2549702	et	3	main
oli	doc_491521501908_item	2549703	et	3	main
väga	doc_491521501908_item	2549704	et	3	main
ilus	doc_491521501908_item	2549705	et	4	main
ilm	doc_491521501908_item	2549706	et	3	main
ja	doc_491521501908_item	2549707	et	3	main
ma	doc_491521501908_item	2549708	et	3	main
käin	doc_491521501908_item	2549709	et	3	main
koju	doc_491521501908_item	2549710	et	3	main
väga	doc_491521501908_item	2549711	et	3	main
aeglaselt	doc_491521501908_item	2549712	et	4	main
kodus	doc_491521501908_item	2549713	et	4	main
ma	doc_491521501908_item	2549714	et	3	main
sõi	doc_491521501908_item	2549715	et	3	main
vaatasin	doc_491521501908_item	2549716	et	3	main
telerit	doc_491521501908_item	2549717	et	3	main
õhtul	doc_491521501908_item	2549718	et	3	main
ma	doc_491521501908_item	2549719	et	3	main
pean	doc_491521501908_item	2549720	et	4	main
minema	doc_491521501908_item	2549721	et	3	main
magama	doc_491521501908_item	2549736	et	3	main
huvitavamaid	doc_491521501908_item	2549738	et	4	main
ole	doc_491521501908_item	2549742	et	4	main
vali	doc_491521501909_item	2549744	et	4	main
igasse	doc_491521501909_item	2549745	et	3	main
lünka	doc_491521501909_item	2549746	et	4	main
üks	doc_491521501909_item	2549747	et	3	main
meeles	doc_491521501909_item	2549754	et	3	main
ütlevad	doc_491521501909_item	2549758	et	4	main
seisavad	doc_491521501909_item	2549789	et	3	main
või	doc_491521501909_item	2549798	et	4	main
võib	doc_491521501909_item	2549805	et	3	main
või	doc_491521501909_item	2549810	et	4	main
ka	doc_491521501909_item	2549812	et	3	main
5	doc_491521501909_item	2549814	et	2	main
värvilise	doc_491521501909_item	2549815	et	4	main
raamatu	doc_491521501909_item	2549816	et	4	main
6	doc_491521501909_item	2549821	et	2	main
nad	doc_491521501908_item	2549639	et	3	main
15-18	doc_491521501908_item	2549648	et	2	main
tavaline	doc_491521501908_item	2549653	et	4	main
oli	doc_491521501908_item	2549657	et	3	main
päev	doc_491521501908_item	2549659	et	3	main
me	doc_491521501908_item	2549668	et	4	main
väga	doc_491521501908_item	2549679	et	3	main
mõned	doc_491521501908_item	2549685	et	3	main
kuzja	doc_491521501908_item	2549696	et	4	main
näituse	doc_491521501908_item	2549698	et	3	main
aeroobikale	doc_491521501908_item	2549722	et	3	main
ma	doc_491521501908_item	2549724	et	3	main
üks	doc_491521501908_item	2549726	et	3	main
tund	doc_491521501908_item	2549727	et	3	main
ma	doc_491521501908_item	2549729	et	3	main
koju	doc_491521501908_item	2549732	et	3	main
kauem	doc_491521501909_item	2549759	et	4	main
ostavad	doc_491521501909_item	2549760	et	3	main
puuvilju	doc_491521501909_item	2549761	et	3	main
jääda	doc_491521501909_item	2549762	et	4	main
kuud	doc_491521501909_item	2549797	et	4	main
lapsi	doc_491521501909_item	2549804	et	4	main
kommi	doc_491521501909_item	2549811	et	4	main
mänguasja	doc_491521501909_item	2549819	et	4	main
kui	doc_491521501909_item	2549835	et	3	main
neljajalgsele	doc_491521501909_item	2549837	et	3	main
võite	doc_491521501909_item	2549848	et	4	main
olla	doc_491521501909_item	2549850	et	3	main
et	doc_491521501909_item	2549851	et	3	main
nad	doc_491521501909_item	2549852	et	3	main
tänavad	doc_491521501909_item	2549853	et	4	main
tavaline	doc_491521501909_item	2549866	et	4	main
üks	doc_491521501909_item	2549870	et	3	main
siis	doc_491521501909_item	2549881	et	3	main
läksin	doc_491521501909_item	2549886	et	3	main
meil	doc_491521501909_item	2549888	et	4	main
kell	doc_491521501909_item	2549897	et	3	main
12oo	doc_491521501909_item	2549898	et	3	main
me	doc_491521501909_item	2549899	et	4	main
ei	doc_491521501909_item	2549916	et	4	main
mul	doc_491521501908_item	2549740	et	3	main
kutsuvad	doc_491521501909_item	2549749	et	4	main
unustada	doc_491521501909_item	2549750	et	3	main
külalised	doc_491521501909_item	2549751	et	4	main
tore	doc_491521501909_item	2549752	et	3	main
otsivad	doc_491521501909_item	2549763	et	4	main
kui	doc_491521501909_item	2549764	et	3	main
lähme	doc_491521501909_item	2549765	et	3	main
hakkame	doc_491521501909_item	2549768	et	3	main
külla	doc_491521501909_item	2549769	et	4	main
minema	doc_491521501909_item	2549770	et	3	main
mõtleme1	doc_491521501909_item	2549771	et	3	main
tavaliselt	doc_491521501909_item	2549772	et	4	main
mida	doc_491521501909_item	2549773	et	4	main
kaasa	doc_491521501909_item	2549774	et	4	main
võtta	doc_491521501909_item	2549775	et	3	main
lilled	doc_491521501909_item	2549776	et	3	main
on	doc_491521501909_item	2549777	et	4	main
alati	doc_491521501909_item	2549778	et	4	main
sobivad	doc_491521501909_item	2549779	et	4	main
viimasel	doc_491521501909_item	2549780	et	3	main
ajal	doc_491521501909_item	2549781	et	4	main
2	doc_491521501909_item	2549782	et	2	main
ostavad	doc_491521501909_item	2549783	et	3	main
inimesed	doc_491521501909_item	2549784	et	3	main
rohkem	doc_491521501909_item	2549785	et	4	main
potililli	doc_491521501909_item	2549786	et	4	main
sest	doc_491521501909_item	2549787	et	4	main
need	doc_491521501909_item	2549788	et	3	main
kui	doc_491521501909_item	2549801	et	3	main
kaasa	doc_491521501909_item	2549806	et	4	main
väikese	doc_491521501909_item	2549818	et	4	main
lapsed	doc_491521501909_item	2549823	et	3	main
ära	doc_491521501909_item	2549825	et	4	main
8	doc_491521501909_item	2549833	et	2	main
sõbrale	doc_491521501909_item	2549839	et	3	main
näiteks	doc_491521501909_item	2549843	et	4	main
või	doc_491521501909_item	2549845	et	4	main
värske	doc_491521501909_item	2549846	et	4	main
üks	doc_491521501909_item	2549865	et	3	main
ma	doc_491521501909_item	2549873	et	3	main
700	doc_491521501909_item	2549877	et	2	main
tegin	doc_491521501909_item	2549879	et	3	main
ja	doc_491521501909_item	2549885	et	3	main
kutsekooli	doc_491521501909_item	2549887	et	4	main
oli	doc_491521501909_item	2549889	et	3	main
praktika	doc_491521501909_item	2549890	et	4	main
ja	doc_491521501909_item	2549891	et	3	main
läksime	doc_491521501909_item	2549900	et	3	main
näitusele	doc_491521501909_item	2549901	et	4	main
näitus	doc_491521501909_item	2549902	et	3	main
oli	doc_491521501909_item	2549903	et	3	main
olid	doc_491521501909_item	2549912	et	4	main
erinevad	doc_491521501909_item	2549913	et	4	main
nukud	doc_491521501909_item	2549914	et	3	main
nad	doc_491521501909_item	2549915	et	3	main
lõbusad	doc_491521501909_item	2549918	et	3	main
väike	doc_491521501909_item	2549926	et	4	main
pilet	doc_491521501909_item	2549929	et	3	main
oli	doc_491521501909_item	2549934	et	3	main
õhtul	doc_491521501909_item	2549938	et	3	main
õe	doc_491521501909_item	2549942	et	4	main
võtsin	doc_491521501909_item	2549945	et	3	main
šokolaadi	doc_491521501909_item	2549948	et	2	main
ja	doc_491521501909_item	2549949	et	3	main
me	doc_491521501909_item	2549950	et	4	main
jõime	doc_491521501909_item	2549951	et	3	main
läksin	doc_491521501909_item	2549957	et	3	main
kirjuta	doc_491521501910_item	2549960	et	4	main
sõnad	doc_491521501910_item	2549962	et	4	main
viima	doc_491521501910_item	2549987	et	3	main
te	doc_491521501910_item	2549992	et	4	main
pearaamatupidajad	doc_491521501910_item	2549997	et	3	main
külalised	doc_491521501910_item	2550005	et	4	main
on	doc_491521501909_item	2549832	et	4	main
leiate	doc_491521501909_item	2549840	et	3	main
taskust	doc_491521501909_item	2549842	et	3	main
kindel	doc_491521501909_item	2549849	et	3	main
eile	doc_491521501909_item	2549868	et	3	main
oli	doc_491521501909_item	2549869	et	3	main
tõusin	doc_491521501909_item	2549874	et	3	main
üles	doc_491521501909_item	2549875	et	3	main
aeroobikat	doc_491521501909_item	2549880	et	3	main
ma	doc_491521501909_item	2549882	et	3	main
nimetus	doc_491521501909_item	2549908	et	4	main
on	doc_491521501909_item	2549909	et	4	main
nukud	doc_491521501909_item	2549910	et	3	main
seal	doc_491521501909_item	2549911	et	4	main
vastupidi	doc_491521501909_item	2549920	et	3	main
rohkem	doc_491521501909_item	2549924	et	4	main
kollektsioon	doc_491521501909_item	2549937	et	3	main
eksamitöö	doc_491521501910_item	2549959	et	4	main
laused	doc_491521501910_item	2549961	et	3	main
te	doc_491521501910_item	2549985	et	4	main
arve	doc_491521501910_item	2549989	et	4	main
võite	doc_491521501910_item	2549993	et	4	main
need	doc_491521501910_item	2549995	et	3	main
eile	doc_491521501910_item	2550006	et	3	main
öösel	doc_491521501910_item	2550007	et	4	main
palju	doc_491521501910_item	2550011	et	4	main
šveits	doc_491521501910_item	2550020	et	2	main
meie	doc_491521501910_item	2550022	et	4	main
šveitsi	doc_491521501910_item	2550028	et	2	main
kui	doc_491521501910_item	2550031	et	3	main
vihma	doc_491521501910_item	2550042	et	4	main
6	doc_491521501910_item	2550051	et	2	main
lukk	doc_491521501910_item	2550077	et	3	main
ma	doc_491521501910_item	2550079	et	3	main
olin	doc_491521501910_item	2550082	et	3	main
uks	doc_491521501910_item	2550085	et	3	main
8	doc_491521501910_item	2550087	et	2	main
palun	doc_491521501910_item	2550088	et	3	main
näitama	doc_491521501910_item	2550089	et	3	main
koos	doc_491521501910_item	2550103	et	4	main
sõbrad	doc_491521501910_item	2550104	et	3	main
norra	doc_491521501910_item	2550105	et	4	main
koos	doc_491521501910_item	2550111	et	4	main
üritus	doc_491521501910_item	2550122	et	4	main
seel	doc_491521501910_item	2550125	et	4	main
festivali	doc_491521501910_item	2550133	et	4	main
rohkem	doc_491521501910_item	2550146	et	4	main
võimalusi	doc_491521501910_item	2550149	et	3	main
suvel	doc_491521501910_item	2550158	et	3	main
sõitsin	doc_491521501910_item	2550164	et	3	main
sõbraga	doc_491521501910_item	2550166	et	3	main
kahekesi	doc_491521501910_item	2550169	et	3	main
käisime	doc_491521501910_item	2550182	et	3	main
sõime	doc_491521501910_item	2550184	et	4	main
muuseumis	doc_491521501910_item	2550188	et	3	main
väga	doc_491521501910_item	2550190	et	3	main
see	doc_491521501910_item	2550192	et	3	main
kodukäia	doc_491521501909_item	2549927	et	4	main
krooni	doc_491521501909_item	2549932	et	4	main
see	doc_491521501909_item	2549933	et	3	main
teet	doc_491521501909_item	2549952	et	4	main
seda	doc_491521501909_item	2549955	et	3	main
on	doc_491521501910_item	2549963	et	4	main
õiges	doc_491521501910_item	2549964	et	3	main
järjekorras	doc_491521501910_item	2549965	et	3	main
1	doc_491521501910_item	2549966	et	2	main
homme	doc_491521501910_item	2549967	et	3	main
õhtu	doc_491521501910_item	2549968	et	4	main
toimuma	doc_491521501910_item	2549969	et	3	main
raekoda	doc_491521501910_item	2549970	et	4	main
pidulik	doc_491521501910_item	2549971	et	3	main
vastuvõtt	doc_491521501910_item	2549972	et	3	main
parimad	doc_491521501910_item	2549973	et	4	main
sportlased	doc_491521501910_item	2549974	et	3	main
homme	doc_491521501910_item	2549975	et	3	main
õhtul	doc_491521501910_item	2549976	et	3	main
toimub	doc_491521501910_item	2549977	et	3	main
raekojas	doc_491521501910_item	2549978	et	3	main
pidulik	doc_491521501910_item	2549979	et	3	main
vastuvõtt	doc_491521501910_item	2549980	et	3	main
meeldis	doc_491521501909_item	2549925	et	3	main
nafanja	doc_491521501909_item	2549928	et	4	main
kolm	doc_491521501909_item	2549931	et	3	main
väga	doc_491521501909_item	2549935	et	3	main
käisin	doc_491521501909_item	2549940	et	3	main
külas	doc_491521501909_item	2549943	et	3	main
ja	doc_491521501909_item	2549953	et	3	main
koju	doc_491521501909_item	2549958	et	3	main
sportlastele	doc_491521501910_item	2549982	et	4	main
2	doc_491521501910_item	2549983	et	2	main
pearaamatupidaja	doc_491521501910_item	2549990	et	4	main
viima	doc_491521501910_item	2549994	et	3	main
arved	doc_491521501910_item	2549996	et	3	main
naabrid	doc_491521501910_item	2550002	et	3	main
külalisi	doc_491521501910_item	2550012	et	4	main
osakond	doc_491521501910_item	2550015	et	3	main
juhataja	doc_491521501910_item	2550016	et	4	main
sõitma	doc_491521501910_item	2550017	et	3	main
eelmine	doc_491521501910_item	2550018	et	3	main
nädal	doc_491521501910_item	2550019	et	3	main
osakonna	doc_491521501910_item	2550023	et	4	main
nädalal	doc_491521501910_item	2550027	et	3	main
jooksma	doc_491521501910_item	2550035	et	3	main
sadama	doc_491521501910_item	2550043	et	4	main
hakkas	doc_491521501910_item	2550044	et	3	main
jooksis	doc_491521501910_item	2550045	et	4	main
vanasti	doc_491521501910_item	2550052	et	3	main
ka	doc_491521501910_item	2550066	et	3	main
võid	doc_491521501910_item	2550067	et	4	main
7	doc_491521501910_item	2550068	et	2	main
kui	doc_491521501910_item	2550069	et	3	main
ma	doc_491521501910_item	2550070	et	3	main
trepikoda	doc_491521501910_item	2550075	et	4	main
palun	doc_491521501910_item	2550093	et	3	main
jalgrattamatk	doc_491521501910_item	2550106	et	3	main
norra	doc_491521501910_item	2550113	et	4	main
10	doc_491521501910_item	2550115	et	2	main
palju	doc_491521501910_item	2550119	et	4	main
palju	doc_491521501910_item	2550128	et	4	main
rootsimaal	doc_491521501910_item	2550153	et	4	main
see	doc_491521501910_item	2550155	et	3	main
sellel	doc_491521501910_item	2550157	et	4	main
oli	doc_491521501910_item	2550160	et	3	main
me	doc_491521501910_item	2550179	et	4	main
käisime	doc_491521501910_item	2550187	et	3	main
seal	doc_491521501910_item	2550221	et	4	main
kallis	doc_491521501910_item	2550223	et	4	main
kui	doc_491521501910_item	2550224	et	3	main
raha	doc_491521501910_item	2550225	et	4	main
ei	doc_491521501910_item	2550226	et	4	main
ole	doc_491521501910_item	2550230	et	4	main
huvitav	doc_491521501909_item	2549936	et	4	main
ma	doc_491521501909_item	2549939	et	3	main
oma	doc_491521501909_item	2549941	et	4	main
ma	doc_491521501909_item	2549944	et	3	main
kaasa	doc_491521501909_item	2549946	et	4	main
suurt	doc_491521501909_item	2549947	et	3	main
peale	doc_491521501909_item	2549954	et	4	main
ma	doc_491521501909_item	2549956	et	3	main
need	doc_491521501910_item	2549988	et	3	main
kas	doc_491521501910_item	2549991	et	3	main
3	doc_491521501910_item	2549998	et	2	main
käima	doc_491521501910_item	2550001	et	4	main
juures	doc_491521501910_item	2550003	et	4	main
palju	doc_491521501910_item	2550004	et	4	main
naabrid	doc_491521501910_item	2550009	et	3	main
4	doc_491521501910_item	2550013	et	2	main
meie	doc_491521501910_item	2550014	et	4	main
komandeering	doc_491521501910_item	2550021	et	3	main
laps	doc_491521501910_item	2550037	et	4	main
suur	doc_491521501910_item	2550038	et	3	main
vihmavari	doc_491521501910_item	2550039	et	4	main
all	doc_491521501910_item	2550040	et	3	main
kui	doc_491521501910_item	2550041	et	3	main
küpsetama	doc_491521501910_item	2550053	et	4	main
ja	doc_491521501910_item	2550056	et	3	main
olema	doc_491521501910_item	2550073	et	4	main
trepikojas	doc_491521501910_item	2550084	et	3	main
lukkus	doc_491521501910_item	2550086	et	4	main
mina	doc_491521501910_item	2550090	et	4	main
see	doc_491521501910_item	2550091	et	3	main
kiri	doc_491521501910_item	2550092	et	3	main
mulle	doc_491521501910_item	2550095	et	4	main
kirja	doc_491521501910_item	2550097	et	4	main
juuli	doc_491521501910_item	2550099	et	4	main
lõpp	doc_491521501910_item	2550100	et	3	main
minema	doc_491521501910_item	2550101	et	3	main
ma	doc_491521501910_item	2550102	et	3	main
lõppuks	doc_491521501910_item	2550108	et	3	main
käin	doc_491521501910_item	2550109	et	3	main
see	doc_491521501910_item	2550116	et	3	main
huvitav	doc_491521501910_item	2550121	et	4	main
suvil	doc_491521501910_item	2550126	et	4	main
olime	doc_491521501910_item	2550127	et	3	main
kirjuta	doc_491521501910_item	2550134	et	4	main
15-18	doc_491521501910_item	2550135	et	2	main
lauset	doc_491521501910_item	2550136	et	3	main
minu	doc_491521501910_item	2550137	et	3	main
kõige	doc_491521501910_item	2550138	et	4	main
huvitavam	doc_491521501910_item	2550139	et	4	main
kui	doc_491521501910_item	2550147	et	3	main
oleks	doc_491521501910_item	2550148	et	3	main
huvitav	doc_491521501910_item	2550162	et	4	main
me	doc_491521501910_item	2550167	et	4	main
pilte	doc_491521501910_item	2550181	et	3	main
veel	doc_491521501910_item	2550186	et	4	main
meeldis	doc_491521501910_item	2550191	et	3	main
seal	doc_491521501910_item	2550194	et	4	main
ei	doc_491521501910_item	2550229	et	4	main
minna	doc_491521501910_item	2550233	et	3	main
parimatele	doc_491521501910_item	2549981	et	4	main
kas	doc_491521501910_item	2549984	et	3	main
võima	doc_491521501910_item	2549986	et	3	main
eile	doc_491521501910_item	2549999	et	3	main
öö	doc_491521501910_item	2550000	et	4	main
käisid	doc_491521501910_item	2550008	et	4	main
juures	doc_491521501910_item	2550010	et	4	main
juhataja	doc_491521501910_item	2550024	et	4	main
eelmisel	doc_491521501910_item	2550026	et	3	main
5	doc_491521501910_item	2550030	et	2	main
sadama	doc_491521501910_item	2550033	et	4	main
leib	doc_491521501910_item	2550055	et	3	main
tegema	doc_491521501910_item	2550057	et	3	main
kodu	doc_491521501910_item	2550071	et	4	main
jõudma	doc_491521501910_item	2550072	et	3	main
uks	doc_491521501910_item	2550076	et	3	main
kui	doc_491521501910_item	2550078	et	3	main
jõudsin	doc_491521501910_item	2550081	et	3	main
ma	doc_491521501910_item	2550110	et	3	main
sõbranaga	doc_491521501910_item	2550112	et	4	main
jalgrattamatkale	doc_491521501910_item	2550114	et	3	main
suvi	doc_491521501910_item	2550117	et	3	main
igasugune	doc_491521501910_item	2550120	et	3	main
igasugused	doc_491521501910_item	2550129	et	3	main
huvitavad	doc_491521501910_item	2550130	et	4	main
reisiksin	doc_491521501910_item	2550145	et	3	main
ma	doc_491521501910_item	2550151	et	3	main
stokholmis	doc_491521501910_item	2550154	et	4	main
oli	doc_491521501910_item	2550156	et	3	main
see	doc_491521501910_item	2550159	et	3	main
väga	doc_491521501910_item	2550161	et	3	main
koos	doc_491521501910_item	2550165	et	4	main
sõitsime	doc_491521501910_item	2550168	et	3	main
seal	doc_491521501910_item	2550170	et	4	main
me	doc_491521501910_item	2550171	et	4	main
olime	doc_491521501910_item	2550172	et	3	main
üks	doc_491521501910_item	2550173	et	3	main
nädal	doc_491521501910_item	2550174	et	3	main
me	doc_491521501910_item	2550175	et	4	main
jalutasime	doc_491521501910_item	2550176	et	3	main
tegime	doc_491521501910_item	2550180	et	3	main
restoranis	doc_491521501910_item	2550185	et	3	main
meile	doc_491521501910_item	2550189	et	4	main
väga	doc_491521501910_item	2550222	et	3	main
sõitis	doc_491521501910_item	2550025	et	3	main
komandeeringusse	doc_491521501910_item	2550029	et	3	main
vihm	doc_491521501910_item	2550032	et	3	main
hakkama	doc_491521501910_item	2550034	et	3	main
kõik	doc_491521501910_item	2550036	et	4	main
kõik	doc_491521501910_item	2550046	et	4	main
lapsed	doc_491521501910_item	2550047	et	3	main
suure	doc_491521501910_item	2550048	et	3	main
vihmavarju	doc_491521501910_item	2550049	et	4	main
alla	doc_491521501910_item	2550050	et	3	main
kodu	doc_491521501910_item	2550054	et	4	main
ka	doc_491521501910_item	2550058	et	3	main
või	doc_491521501910_item	2550059	et	4	main
vanasti	doc_491521501910_item	2550060	et	3	main
küpsetati	doc_491521501910_item	2550061	et	3	main
leiba	doc_491521501910_item	2550063	et	4	main
ja	doc_491521501910_item	2550064	et	3	main
tehti	doc_491521501910_item	2550065	et	3	main
kodus	doc_491521501910_item	2550062	et	4	main
meie	doc_491521501910_item	2550074	et	4	main
kodu	doc_491521501910_item	2550080	et	4	main
meie	doc_491521501910_item	2550083	et	4	main
näita	doc_491521501910_item	2550094	et	4	main
seda	doc_491521501910_item	2550096	et	3	main
9	doc_491521501910_item	2550098	et	2	main
juuli	doc_491521501910_item	2550107	et	4	main
olema	doc_491521501910_item	2550118	et	4	main
ja	doc_491521501910_item	2550123	et	3	main
festival	doc_491521501910_item	2550124	et	3	main
üritusi	doc_491521501910_item	2550131	et	4	main
ja	doc_491521501910_item	2550132	et	3	main
reis	doc_491521501910_item	2550140	et	4	main
mulle	doc_491521501910_item	2550141	et	4	main
meeldib	doc_491521501910_item	2550142	et	3	main
reisida	doc_491521501910_item	2550143	et	3	main
ma	doc_491521501910_item	2550144	et	3	main
viimati	doc_491521501910_item	2550150	et	3	main
käisin	doc_491521501910_item	2550152	et	3	main
ma	doc_491521501910_item	2550163	et	3	main
stokholmis	doc_491521501910_item	2550177	et	4	main
seal	doc_491521501910_item	2550178	et	4	main
kaubamajas	doc_491521501910_item	2550183	et	3	main
linn	doc_491521501910_item	2550193	et	3	main
on	doc_491521501910_item	2550195	et	4	main
palju	doc_491521501910_item	2550196	et	4	main
ilusaid	doc_491521501910_item	2550197	et	3	main
kohti	doc_491521501910_item	2550198	et	4	main
pärast	doc_491521501910_item	2550199	et	4	main
reisimist	doc_491521501910_item	2550200	et	4	main
mul	doc_491521501910_item	2550201	et	3	main
on	doc_491521501910_item	2550202	et	4	main
palju	doc_491521501910_item	2550203	et	4	main
häid	doc_491521501910_item	2550204	et	3	main
muljeid	doc_491521501910_item	2550205	et	3	main
mulle	doc_491521501910_item	2550206	et	4	main
meeldib	doc_491521501910_item	2550207	et	3	main
reisida	doc_491521501910_item	2550208	et	3	main
kui	doc_491521501910_item	2550209	et	3	main
on	doc_491521501910_item	2550210	et	4	main
palju	doc_491521501910_item	2550211	et	4	main
raha	doc_491521501910_item	2550212	et	4	main
stokholmis	doc_491521501910_item	2550213	et	4	main
on	doc_491521501910_item	2550214	et	4	main
vaja	doc_491521501910_item	2550215	et	4	main
palju	doc_491521501910_item	2550216	et	4	main
raha	doc_491521501910_item	2550217	et	4	main
sest	doc_491521501910_item	2550218	et	4	main
elu	doc_491521501910_item	2550219	et	4	main
on	doc_491521501910_item	2550220	et	4	main
ole	doc_491521501910_item	2550227	et	4	main
siis	doc_491521501910_item	2550228	et	3	main
kuhugi	doc_491521501910_item	2550232	et	4	main
võimalust	doc_491521501910_item	2550231	et	3	main
homme	doc_491521501912_item	2550485	et	3	main
õhtul	doc_491521501912_item	2550494	et	3	main
parimatele	doc_491521501912_item	2550499	et	4	main
võima	doc_491521501912_item	2550504	et	3	main
need	doc_491521501912_item	2550506	et	3	main
pearaamatupidaja	doc_491521501912_item	2550508	et	4	main
kas	doc_491521501912_item	2550509	et	3	main
te	doc_491521501912_item	2550510	et	4	main
3	doc_491521501912_item	2550516	et	2	main
öö	doc_491521501912_item	2550518	et	4	main
eile	doc_491521501912_item	2550524	et	3	main
naabritejuures	doc_491521501912_item	2550527	et	4	main
juhataja	doc_491521501912_item	2550533	et	4	main
nädal	doc_491521501912_item	2550536	et	3	main
meie	doc_491521501912_item	2550539	et	4	main
komandeeringusse	doc_491521501912_item	2550546	et	3	main
hakkama	doc_491521501912_item	2550551	et	3	main
kui	doc_491521501912_item	2550558	et	3	main
sadama	doc_491521501912_item	2550560	et	4	main
jooksevad	doc_491521501912_item	2550562	et	4	main
kõik	doc_491521501912_item	2550563	et	4	main
lapsed	doc_491521501912_item	2550564	et	3	main
suure	doc_491521501912_item	2550565	et	3	main
tegema	doc_491521501912_item	2550574	et	3	main
küpsetati	doc_491521501912_item	2550578	et	3	main
kirja	doc_491521501912_item	2550614	et	4	main
üritus	doc_491521501912_item	2550639	et	4	main
ja	doc_491521501912_item	2550640	et	3	main
festival	doc_491521501912_item	2550641	et	3	main
sel	doc_491521501912_item	2550642	et	3	main
suvel	doc_491521501912_item	2550643	et	3	main
huvitavaid	doc_491521501912_item	2550647	et	4	main
festivale	doc_491521501912_item	2550650	et	3	main
15-18	doc_491521501912_item	2550652	et	2	main
lauset	doc_491521501912_item	2550653	et	3	main
reisida	doc_491521501912_item	2550660	et	3	main
kui	doc_491521501912_item	2550664	et	3	main
pargis	doc_491521501912_item	2550681	et	3	main
äärde	doc_491521501912_item	2550688	et	4	main
on	doc_491521501912_item	2550690	et	4	main
on	doc_491521501912_item	2550699	et	4	main
järjekorras	doc_491521501912_item	2550483	et	3	main
toimuma	doc_491521501912_item	2550487	et	3	main
pidulik	doc_491521501912_item	2550489	et	3	main
sportlased	doc_491521501912_item	2550492	et	3	main
sportlastele	doc_491521501912_item	2550500	et	4	main
te	doc_491521501912_item	2550503	et	4	main
külalised	doc_491521501912_item	2550523	et	4	main
sõitma	doc_491521501912_item	2550534	et	3	main
šveits	doc_491521501912_item	2550537	et	2	main
nädalal	doc_491521501912_item	2550544	et	3	main
vihm	doc_491521501912_item	2550549	et	3	main
jooksma	doc_491521501912_item	2550552	et	3	main
all	doc_491521501912_item	2550557	et	3	main
vihmavarju	doc_491521501912_item	2550566	et	4	main
alla	doc_491521501912_item	2550567	et	3	main
vanasti	doc_491521501912_item	2550569	et	3	main
kodu	doc_491521501912_item	2550571	et	4	main
leib	doc_491521501912_item	2550572	et	3	main
või	doc_491521501912_item	2550576	et	4	main
juuli	doc_491521501912_item	2550616	et	4	main
koos	doc_491521501912_item	2550620	et	4	main
norra	doc_491521501912_item	2550622	et	4	main
jalgrattamatk	doc_491521501912_item	2550623	et	3	main
norra	doc_491521501912_item	2550630	et	4	main
jalgrattamatkale	doc_491521501912_item	2550631	et	3	main
olema	doc_491521501912_item	2550635	et	4	main
igasugune	doc_491521501912_item	2550637	et	3	main
huvitav	doc_491521501912_item	2550638	et	4	main
üritusi	doc_491521501912_item	2550648	et	4	main
minu	doc_491521501912_item	2550654	et	3	main
meeldib	doc_491521501912_item	2550659	et	3	main
ma	doc_491521501912_item	2550669	et	3	main
käinud	doc_491521501912_item	2550671	et	4	main
temaga	doc_491521501912_item	2550678	et	3	main
asub	doc_491521501912_item	2550686	et	3	main
mere	doc_491521501912_item	2550687	et	3	main
eksamitöö	doc_491521501913_item	2550723	et	4	main
raekojas	doc_491521501913_item	2550742	et	3	main
pidulik	doc_491521501913_item	2550743	et	3	main
kas	doc_491521501913_item	2550748	et	3	main
need	doc_491521501913_item	2550752	et	3	main
öö	doc_491521501913_item	2550764	et	4	main
käisid	doc_491521501913_item	2550772	et	4	main
naabrite	doc_491521501913_item	2550773	et	3	main
juhataja	doc_491521501913_item	2550780	et	4	main
sõitma	doc_491521501913_item	2550781	et	3	main
eelmine	doc_491521501913_item	2550782	et	3	main
vihmavari	doc_491521501913_item	2550803	et	4	main
kui	doc_491521501913_item	2550805	et	3	main
sadama	doc_491521501913_item	2550807	et	4	main
hakkas	doc_491521501913_item	2550808	et	3	main
jooksid	doc_491521501913_item	2550809	et	4	main
kõik	doc_491521501913_item	2550810	et	4	main
lapsed	doc_491521501913_item	2550811	et	3	main
suure	doc_491521501913_item	2550812	et	3	main
vihmavarja	doc_491521501913_item	2550813	et	4	main
alla	doc_491521501913_item	2550814	et	3	main
6	doc_491521501913_item	2550815	et	2	main
vanasti	doc_491521501913_item	2550816	et	3	main
leib	doc_491521501913_item	2550819	et	3	main
või	doc_491521501913_item	2550823	et	4	main
on	doc_491521501912_item	2550481	et	4	main
õiges	doc_491521501912_item	2550482	et	3	main
õhtu	doc_491521501912_item	2550486	et	4	main
raekoda	doc_491521501912_item	2550488	et	4	main
toimub	doc_491521501912_item	2550495	et	3	main
pidulik	doc_491521501912_item	2550497	et	3	main
kas	doc_491521501912_item	2550502	et	3	main
viima	doc_491521501912_item	2550505	et	3	main
viia	doc_491521501912_item	2550512	et	3	main
arved	doc_491521501912_item	2550514	et	3	main
palju	doc_491521501912_item	2550522	et	4	main
käisid	doc_491521501912_item	2550526	et	4	main
palju	doc_491521501912_item	2550528	et	4	main
külalisi	doc_491521501912_item	2550529	et	4	main
4	doc_491521501912_item	2550530	et	2	main
meie	doc_491521501912_item	2550531	et	4	main
osakonna	doc_491521501912_item	2550540	et	4	main
5	doc_491521501912_item	2550547	et	2	main
kõik	doc_491521501912_item	2550553	et	4	main
suur	doc_491521501912_item	2550555	et	3	main
hakab	doc_491521501912_item	2550561	et	4	main
küpsetama	doc_491521501912_item	2550570	et	4	main
ja	doc_491521501912_item	2550573	et	3	main
vanasti	doc_491521501912_item	2550577	et	3	main
9	doc_491521501912_item	2550615	et	2	main
ma	doc_491521501912_item	2550619	et	3	main
juuli	doc_491521501912_item	2550624	et	4	main
lähen	doc_491521501912_item	2550626	et	3	main
mina	doc_491521501912_item	2550627	et	4	main
see	doc_491521501912_item	2550633	et	3	main
huvitavam	doc_491521501912_item	2550656	et	4	main
reis	doc_491521501912_item	2550657	et	4	main
mina	doc_491521501912_item	2550661	et	4	main
viimati	doc_491521501912_item	2550668	et	3	main
olen	doc_491521501912_item	2550670	et	3	main
toilas	doc_491521501912_item	2550672	et	4	main
seal	doc_491521501912_item	2550673	et	4	main
elab	doc_491521501912_item	2550674	et	3	main
minu	doc_491521501912_item	2550675	et	3	main
me	doc_491521501912_item	2550679	et	4	main
käinud	doc_491521501912_item	2550683	et	4	main
mis	doc_491521501912_item	2550685	et	4	main
sealt	doc_491521501912_item	2550689	et	4	main
väga	doc_491521501912_item	2550691	et	3	main
kaunis	doc_491521501912_item	2550692	et	4	main
kirjuta	doc_491521501912_item	2550478	et	4	main
laused	doc_491521501912_item	2550479	et	3	main
sõnad	doc_491521501912_item	2550480	et	4	main
homme	doc_491521501912_item	2550493	et	3	main
vastuvõt	doc_491521501912_item	2550498	et	4	main
2	doc_491521501912_item	2550501	et	2	main
arve	doc_491521501912_item	2550507	et	4	main
pearaamatupidajale	doc_491521501912_item	2550515	et	3	main
käima	doc_491521501912_item	2550519	et	4	main
naabrid	doc_491521501912_item	2550520	et	3	main
eksamitöö	doc_491521501912_item	2550477	et	4	main
1	doc_491521501912_item	2550484	et	2	main
vastuvõtt	doc_491521501912_item	2550490	et	3	main
parimad	doc_491521501912_item	2550491	et	4	main
raekojas	doc_491521501912_item	2550496	et	3	main
võite	doc_491521501912_item	2550511	et	4	main
need	doc_491521501912_item	2550513	et	3	main
eile	doc_491521501912_item	2550517	et	3	main
juures	doc_491521501912_item	2550521	et	4	main
osakond	doc_491521501912_item	2550532	et	3	main
juhataja	doc_491521501912_item	2550541	et	4	main
eelmisel	doc_491521501912_item	2550543	et	3	main
sadama	doc_491521501912_item	2550550	et	4	main
laps	doc_491521501912_item	2550554	et	4	main
6	doc_491521501912_item	2550568	et	2	main
ka	doc_491521501912_item	2550575	et	3	main
kodu	doc_491521501912_item	2550579	et	4	main
sõbrad	doc_491521501912_item	2550621	et	3	main
koos	doc_491521501912_item	2550628	et	4	main
suvi	doc_491521501912_item	2550634	et	3	main
palju	doc_491521501912_item	2550636	et	4	main
igasuguseid	doc_491521501912_item	2550646	et	3	main
ja	doc_491521501912_item	2550649	et	3	main
kirjuta	doc_491521501912_item	2550651	et	4	main
kõige	doc_491521501912_item	2550655	et	4	main
reisiksin	doc_491521501912_item	2550662	et	3	main
rohkem	doc_491521501912_item	2550663	et	4	main
oleks	doc_491521501912_item	2550665	et	3	main
piisavalt	doc_491521501912_item	2550666	et	4	main
sõbranna	doc_491521501912_item	2550676	et	4	main
jalutasime	doc_491521501912_item	2550680	et	3	main
oleme	doc_491521501912_item	2550682	et	3	main
selle	doc_491521501912_item	2550721	et	4	main
sõnad	doc_491521501913_item	2550726	et	4	main
on	doc_491521501913_item	2550727	et	4	main
2	doc_491521501913_item	2550747	et	2	main
naabrid	doc_491521501913_item	2550766	et	3	main
palju	doc_491521501913_item	2550768	et	4	main
eile	doc_491521501913_item	2550770	et	3	main
öösel	doc_491521501913_item	2550771	et	4	main
4	doc_491521501913_item	2550777	et	2	main
meie	doc_491521501913_item	2550778	et	4	main
osakond	doc_491521501913_item	2550779	et	3	main
meie	doc_491521501913_item	2550786	et	4	main
šveitsi	doc_491521501913_item	2550792	et	2	main
5	doc_491521501913_item	2550794	et	2	main
kui	doc_491521501913_item	2550795	et	3	main
suur	doc_491521501913_item	2550802	et	3	main
ja	doc_491521501913_item	2550820	et	3	main
ka	doc_491521501913_item	2550822	et	3	main
leiba	doc_491521501913_item	2550827	et	4	main
tehti	doc_491521501913_item	2550829	et	3	main
ka	doc_491521501913_item	2550830	et	3	main
7	doc_491521501913_item	2550832	et	2	main
kui	doc_491521501913_item	2550842	et	3	main
uks	doc_491521501913_item	2550849	et	3	main
palun	doc_491521501913_item	2550852	et	3	main
see	doc_491521501913_item	2550855	et	3	main
näita	doc_491521501913_item	2550858	et	4	main
mulle	doc_491521501913_item	2550859	et	4	main
seda	doc_491521501913_item	2550860	et	3	main
norra	doc_491521501913_item	2550869	et	4	main
ma	doc_491521501913_item	2550874	et	3	main
festival	doc_491521501913_item	2550888	et	3	main
suvel	doc_491521501913_item	2550890	et	3	main
festivale	doc_491521501913_item	2550897	et	3	main
15-18	doc_491521501913_item	2550899	et	2	main
huvitavam	doc_491521501913_item	2550903	et	4	main
on	doc_491521501913_item	2550906	et	4	main
jooksul	doc_491521501913_item	2550930	et	4	main
venna	doc_491521501913_item	2550940	et	3	main
mul	doc_491521501913_item	2550949	et	3	main
ma	doc_491521501913_item	2550956	et	3	main
ilus	doc_491521501913_item	2550969	et	4	main
kuigi	doc_491521501913_item	2550973	et	3	main
meeldib	doc_491521501913_item	2550982	et	3	main
seal	doc_491521501913_item	2550987	et	4	main
loodus	doc_491521501913_item	2550992	et	4	main
harjutus	doc_491521501914_item	2550995	et	4	main
tööle	doc_491521501914_item	2551003	et	3	main
kevadel	doc_491521501914_item	2551015	et	4	main
ekskursioonile	doc_491521501914_item	2551017	et	3	main
öösel	doc_491521501912_item	2550525	et	4	main
eelmine	doc_491521501912_item	2550535	et	3	main
komandeering	doc_491521501912_item	2550538	et	3	main
sõitis	doc_491521501912_item	2550542	et	3	main
šveitsi	doc_491521501912_item	2550545	et	2	main
kui	doc_491521501912_item	2550548	et	3	main
vihmavari	doc_491521501912_item	2550556	et	4	main
vihm	doc_491521501912_item	2550559	et	3	main
leiba	doc_491521501912_item	2550580	et	4	main
ja	doc_491521501912_item	2550581	et	3	main
tehti	doc_491521501912_item	2550582	et	3	main
ka	doc_491521501912_item	2550583	et	3	main
võid	doc_491521501912_item	2550584	et	4	main
7	doc_491521501912_item	2550585	et	2	main
kui	doc_491521501912_item	2550586	et	3	main
ma	doc_491521501912_item	2550587	et	3	main
kodu	doc_491521501912_item	2550588	et	4	main
jõudma	doc_491521501912_item	2550589	et	3	main
olema	doc_491521501912_item	2550590	et	4	main
meie	doc_491521501912_item	2550591	et	4	main
trepikoda	doc_491521501912_item	2550592	et	4	main
uks	doc_491521501912_item	2550593	et	3	main
lukk	doc_491521501912_item	2550594	et	3	main
kui	doc_491521501912_item	2550595	et	3	main
ma	doc_491521501912_item	2550596	et	3	main
koju	doc_491521501912_item	2550597	et	3	main
jõudsin	doc_491521501912_item	2550598	et	3	main
on	doc_491521501912_item	2550599	et	4	main
meie	doc_491521501912_item	2550600	et	4	main
trepikoja	doc_491521501912_item	2550601	et	3	main
uks	doc_491521501912_item	2550602	et	3	main
lukus	doc_491521501912_item	2550603	et	3	main
8	doc_491521501912_item	2550604	et	2	main
palun	doc_491521501912_item	2550605	et	3	main
näitama	doc_491521501912_item	2550606	et	3	main
mina	doc_491521501912_item	2550607	et	4	main
see	doc_491521501912_item	2550608	et	3	main
kiri	doc_491521501912_item	2550609	et	3	main
palun	doc_491521501912_item	2550610	et	3	main
näidake	doc_491521501912_item	2550611	et	3	main
mulle	doc_491521501912_item	2550612	et	4	main
seda	doc_491521501912_item	2550613	et	3	main
lõpp	doc_491521501912_item	2550617	et	3	main
minema	doc_491521501912_item	2550618	et	3	main
lõpus	doc_491521501912_item	2550625	et	4	main
sõbratega	doc_491521501912_item	2550629	et	4	main
10	doc_491521501912_item	2550632	et	2	main
on	doc_491521501912_item	2550644	et	4	main
palju	doc_491521501912_item	2550645	et	4	main
mulle	doc_491521501912_item	2550658	et	4	main
raha	doc_491521501912_item	2550667	et	4	main
koos	doc_491521501912_item	2550677	et	4	main
päsupesa	doc_491521501912_item	2550684	et	4	main
peisaaž	doc_491521501912_item	2550693	et	2	main
sealt	doc_491521501912_item	2550694	et	4	main
võib	doc_491521501912_item	2550695	et	3	main
näha	doc_491521501912_item	2550696	et	3	main
merd	doc_491521501912_item	2550697	et	3	main
toila	doc_491521501912_item	2550698	et	4	main
koht	doc_491521501912_item	2550701	et	3	main
kuhu	doc_491521501912_item	2550702	et	3	main
tulevad	doc_491521501912_item	2550703	et	4	main
noorpaarid	doc_491521501912_item	2550704	et	4	main
kellel	doc_491521501912_item	2550705	et	4	main
on	doc_491521501912_item	2550706	et	4	main
pulmapäev	doc_491521501912_item	2550707	et	3	main
mulle	doc_491521501912_item	2550708	et	4	main
meeldis	doc_491521501912_item	2550709	et	3	main
see	doc_491521501912_item	2550710	et	3	main
koht	doc_491521501912_item	2550711	et	3	main
ja	doc_491521501912_item	2550712	et	3	main
sõidaksin	doc_491521501912_item	2550713	et	3	main
veel	doc_491521501912_item	2550714	et	4	main
sinna	doc_491521501912_item	2550715	et	3	main
aga	doc_491521501912_item	2550716	et	3	main
kahjuks	doc_491521501912_item	2550717	et	4	main
mul	doc_491521501912_item	2550718	et	3	main
pole	doc_491521501912_item	2550719	et	3	main
aega	doc_491521501912_item	2550720	et	4	main
laused	doc_491521501913_item	2550725	et	3	main
järjekorras	doc_491521501913_item	2550729	et	3	main
homme	doc_491521501913_item	2550731	et	3	main
parimatele	doc_491521501913_item	2550745	et	4	main
võima	doc_491521501913_item	2550750	et	3	main
pearaamatupidaja	doc_491521501913_item	2550754	et	4	main
ka	doc_491521501913_item	2550755	et	3	main
käima	doc_491521501913_item	2550765	et	4	main
külalised	doc_491521501913_item	2550769	et	4	main
külalisi	doc_491521501913_item	2550776	et	4	main
komandeering	doc_491521501913_item	2550785	et	3	main
osakonna	doc_491521501913_item	2550787	et	4	main
sõitis	doc_491521501913_item	2550789	et	3	main
eelmisel	doc_491521501913_item	2550790	et	3	main
nädalal	doc_491521501913_item	2550791	et	3	main
komandeeringusse	doc_491521501913_item	2550793	et	3	main
vihm	doc_491521501913_item	2550796	et	3	main
sadama	doc_491521501913_item	2550797	et	4	main
hakkama	doc_491521501913_item	2550798	et	3	main
jooksma	doc_491521501913_item	2550799	et	3	main
kodu	doc_491521501913_item	2550818	et	4	main
kaunis	doc_491521501912_item	2550700	et	4	main
jaoks	doc_491521501912_item	2550722	et	4	main
1	doc_491521501913_item	2550730	et	2	main
sportlastele	doc_491521501913_item	2550746	et	4	main
juures	doc_491521501913_item	2550767	et	4	main
nädal	doc_491521501913_item	2550783	et	3	main
laps	doc_491521501913_item	2550801	et	4	main
all	doc_491521501913_item	2550804	et	3	main
küpsetama	doc_491521501913_item	2550817	et	4	main
tegema	doc_491521501913_item	2550821	et	3	main
olema	doc_491521501913_item	2550837	et	4	main
ma	doc_491521501913_item	2550843	et	3	main
meie	doc_491521501913_item	2550847	et	4	main
8	doc_491521501913_item	2550851	et	2	main
minema	doc_491521501913_item	2550865	et	3	main
lõpus	doc_491521501913_item	2550872	et	4	main
lahen	doc_491521501913_item	2550873	et	4	main
ja	doc_491521501913_item	2550896	et	3	main
minu	doc_491521501913_item	2550901	et	3	main
mulle	doc_491521501913_item	2550923	et	4	main
mina	doc_491521501913_item	2550926	et	4	main
arvan	doc_491521501913_item	2550927	et	3	main
et	doc_491521501913_item	2550928	et	3	main
reisi	doc_491521501913_item	2550929	et	4	main
käisin	doc_491521501913_item	2550938	et	3	main
perekonna	doc_491521501913_item	2550941	et	4	main
iga	doc_491521501913_item	2550943	et	4	main
kord	doc_491521501913_item	2550944	et	4	main
kui	doc_491521501913_item	2550945	et	3	main
ma	doc_491521501913_item	2550946	et	3	main
sest	doc_491521501913_item	2550955	et	4	main
poiss	doc_491521501913_item	2550972	et	3	main
ta	doc_491521501913_item	2550974	et	4	main
veel	doc_491521501913_item	2550976	et	4	main
eriti	doc_491521501913_item	2550981	et	3	main
värske	doc_491521501913_item	2550989	et	4	main
kaksteist	doc_491521501914_item	2550999	et	4	main
siis	doc_491521501914_item	2551001	et	3	main
astutakse	doc_491521501914_item	2551005	et	3	main
juubilari	doc_491521501914_item	2551008	et	4	main
ja	doc_491521501914_item	2551010	et	3	main
kõike	doc_491521501914_item	2551012	et	4	main
riidehoidu	doc_491521501914_item	2551021	et	4	main
keskkoolis	doc_491521501915_item	2551038	et	4	main
käiakse	doc_491521501915_item	2551039	et	3	main
2	doc_491521501915_item	2551048	et	2	main
ja	doc_491521501915_item	2551051	et	3	main
kõike	doc_491521501915_item	2551053	et	4	main
3	doc_491521501915_item	2551055	et	2	main
kevadel	doc_491521501915_item	2551056	et	4	main
sõidetakse	doc_491521501915_item	2551057	et	3	main
ekskursioonile	doc_491521501915_item	2551058	et	3	main
4	doc_491521501915_item	2551059	et	2	main
mantlid	doc_491521501915_item	2551060	et	3	main
emadele	doc_491521501915_item	2551066	et	3	main
pealinnas	doc_491521501915_item	2551069	et	4	main
moodsaid	doc_491521501915_item	2551071	et	3	main
7	doc_491521501915_item	2551073	et	2	main
lüpstakse	doc_491521501915_item	2551075	et	3	main
huvitavamast	doc_491521501916_item	2551087	et	4	main
sõitsin	doc_491521501916_item	2551090	et	3	main
viis	doc_491521501916_item	2551106	et	4	main
saabusime	doc_491521501916_item	2551118	et	3	main
registreerisime	doc_491521501916_item	2551121	et	3	main
oli	doc_491521501916_item	2551126	et	3	main
ja	doc_491521501916_item	2551141	et	3	main
meie	doc_491521501916_item	2551142	et	4	main
giid	doc_491521501916_item	2551143	et	3	main
jutustas	doc_491521501916_item	2551144	et	3	main
meile	doc_491521501916_item	2551147	et	4	main
väga	doc_491521501916_item	2551151	et	3	main
linn	doc_491521501916_item	2551153	et	3	main
seal	doc_491521501916_item	2551154	et	4	main
linnarahvuspark	doc_491521501916_item	2551163	et	3	main
rikkalik	doc_491521501916_item	2551166	et	3	main
taimestik	doc_491521501916_item	2551168	et	3	main
puhtad	doc_491521501916_item	2551178	et	3	main
muuseume	doc_491521501916_item	2551182	et	3	main
liljevalchsi	doc_491521501916_item	2551185	et	4	main
eelajaloolist	doc_491521501916_item	2551191	et	4	main
kirjuta	doc_491521501913_item	2550724	et	4	main
õiges	doc_491521501913_item	2550728	et	3	main
õhtu	doc_491521501913_item	2550732	et	4	main
toimuma	doc_491521501913_item	2550733	et	3	main
raekoda	doc_491521501913_item	2550734	et	4	main
pidulik	doc_491521501913_item	2550735	et	3	main
vastuvõtt	doc_491521501913_item	2550736	et	3	main
parimad	doc_491521501913_item	2550737	et	4	main
sportlased	doc_491521501913_item	2550738	et	3	main
homme	doc_491521501913_item	2550739	et	3	main
õhtul	doc_491521501913_item	2550740	et	3	main
toimub	doc_491521501913_item	2550741	et	3	main
vastuvõtt	doc_491521501913_item	2550744	et	3	main
te	doc_491521501913_item	2550749	et	4	main
viima	doc_491521501913_item	2550751	et	3	main
arve	doc_491521501913_item	2550753	et	4	main
te	doc_491521501913_item	2550756	et	4	main
võiksite	doc_491521501913_item	2550757	et	3	main
viia	doc_491521501913_item	2550758	et	3	main
need	doc_491521501913_item	2550759	et	3	main
arved	doc_491521501913_item	2550760	et	3	main
pearaamatupidajale	doc_491521501913_item	2550761	et	3	main
3	doc_491521501913_item	2550762	et	2	main
eile	doc_491521501913_item	2550763	et	3	main
juures	doc_491521501913_item	2550774	et	4	main
palju	doc_491521501913_item	2550775	et	4	main
šveits	doc_491521501913_item	2550784	et	2	main
juhataja	doc_491521501913_item	2550788	et	4	main
kõik	doc_491521501913_item	2550800	et	4	main
vihma	doc_491521501913_item	2550806	et	4	main
vanasti	doc_491521501913_item	2550824	et	3	main
trepikoda	doc_491521501913_item	2550839	et	4	main
uks	doc_491521501913_item	2550840	et	3	main
jõudsin	doc_491521501913_item	2550845	et	3	main
lukus	doc_491521501913_item	2550850	et	3	main
mina	doc_491521501913_item	2550854	et	4	main
kiri	doc_491521501913_item	2550856	et	3	main
juuli	doc_491521501913_item	2550863	et	4	main
ma	doc_491521501913_item	2550866	et	3	main
juuli	doc_491521501913_item	2550871	et	4	main
koos	doc_491521501913_item	2550875	et	4	main
sõbratega	doc_491521501913_item	2550876	et	4	main
norra	doc_491521501913_item	2550877	et	4	main
jalgrattamatkale	doc_491521501913_item	2550878	et	3	main
10	doc_491521501913_item	2550879	et	2	main
see	doc_491521501913_item	2550880	et	3	main
suvi	doc_491521501913_item	2550881	et	3	main
üritus	doc_491521501913_item	2550886	et	4	main
lauset	doc_491521501913_item	2550900	et	3	main
kõige	doc_491521501913_item	2550902	et	4	main
reis	doc_491521501913_item	2550904	et	4	main
endale	doc_491521501913_item	2550921	et	4	main
meeldib	doc_491521501913_item	2550924	et	3	main
reisida	doc_491521501913_item	2550925	et	3	main
ma	doc_491521501913_item	2550937	et	3	main
et	doc_491521501913_item	2550958	et	3	main
tark	doc_491521501913_item	2550971	et	3	main
aastane	doc_491521501913_item	2550979	et	4	main
mulle	doc_491521501913_item	2550980	et	4	main
kundas	doc_491521501913_item	2550983	et	4	main
käia	doc_491521501913_item	2550984	et	4	main
suvel	doc_491521501913_item	2550985	et	3	main
õhk	doc_491521501913_item	2550990	et	3	main
aastat	doc_491521501914_item	2551000	et	3	main
kõrgkooli	doc_491521501914_item	2551006	et	4	main
head	doc_491521501914_item	2551013	et	4	main
3	doc_491521501914_item	2551014	et	2	main
5	doc_491521501914_item	2551022	et	2	main
küpsetati	doc_491521501913_item	2550825	et	3	main
kodus	doc_491521501913_item	2550826	et	4	main
ja	doc_491521501913_item	2550828	et	3	main
meie	doc_491521501913_item	2550838	et	4	main
koju	doc_491521501913_item	2550844	et	3	main
oli	doc_491521501913_item	2550846	et	3	main
kirja	doc_491521501913_item	2550861	et	4	main
9	doc_491521501913_item	2550862	et	2	main
jalgrattamatk	doc_491521501913_item	2550870	et	3	main
olema	doc_491521501913_item	2550882	et	4	main
palju	doc_491521501913_item	2550883	et	4	main
igasugune	doc_491521501913_item	2550884	et	3	main
huvitav	doc_491521501913_item	2550885	et	4	main
sellel	doc_491521501913_item	2550889	et	4	main
olime	doc_491521501913_item	2550891	et	3	main
huvitavait	doc_491521501913_item	2550894	et	4	main
üritusi	doc_491521501913_item	2550895	et	4	main
kirjuta	doc_491521501913_item	2550898	et	4	main
reisimine	doc_491521501913_item	2550905	et	4	main
tähtis	doc_491521501913_item	2550908	et	4	main
osa	doc_491521501913_item	2550909	et	4	main
inimese	doc_491521501913_item	2550910	et	4	main
elust	doc_491521501913_item	2550911	et	3	main
aga	doc_491521501913_item	2550912	et	3	main
kahjuks	doc_491521501913_item	2550913	et	4	main
viimasel	doc_491521501913_item	2550914	et	3	main
ajal	doc_491521501913_item	2550915	et	4	main
enamus	doc_491521501913_item	2550916	et	4	main
inimestest	doc_491521501913_item	2550917	et	3	main
ei	doc_491521501913_item	2550918	et	4	main
saa	doc_491521501913_item	2550919	et	4	main
seda	doc_491521501913_item	2550920	et	3	main
võid	doc_491521501913_item	2550831	et	4	main
kui	doc_491521501913_item	2550833	et	3	main
ma	doc_491521501913_item	2550834	et	3	main
kodu	doc_491521501913_item	2550835	et	4	main
jõudma	doc_491521501913_item	2550836	et	3	main
lukk	doc_491521501913_item	2550841	et	3	main
trepikoja	doc_491521501913_item	2550848	et	3	main
näitama	doc_491521501913_item	2550853	et	3	main
palun	doc_491521501913_item	2550857	et	3	main
lõpp	doc_491521501913_item	2550864	et	3	main
koos	doc_491521501913_item	2550867	et	4	main
sõbrad	doc_491521501913_item	2550868	et	3	main
ja	doc_491521501913_item	2550887	et	3	main
palju	doc_491521501913_item	2550892	et	4	main
igasuguseid	doc_491521501913_item	2550893	et	3	main
väga	doc_491521501913_item	2550907	et	3	main
lubada	doc_491521501913_item	2550922	et	3	main
viimane	doc_491521501913_item	2550935	et	3	main
kord	doc_491521501913_item	2550936	et	4	main
kunda	doc_491521501913_item	2550947	et	4	main
läheb	doc_491521501913_item	2550950	et	3	main
tean	doc_491521501913_item	2550957	et	3	main
väga	doc_491521501913_item	2550968	et	3	main
on	doc_491521501913_item	2550975	et	4	main
ainult	doc_491521501913_item	2550977	et	4	main
25	doc_491521501913_item	2550978	et	2	main
väga	doc_491521501913_item	2550988	et	3	main
ja	doc_491521501913_item	2550993	et	3	main
1	doc_491521501914_item	2550996	et	2	main
või	doc_491521501914_item	2551004	et	4	main
sõitakse	doc_491521501914_item	2551016	et	4	main
4	doc_491521501914_item	2551018	et	2	main
andtakse	doc_491521501914_item	2551020	et	4	main
emadepäeval	doc_491521501914_item	2551023	et	3	main
kingitakse	doc_491521501914_item	2551024	et	4	main
7	doc_491521501914_item	2551032	et	2	main
lehmi	doc_491521501914_item	2551033	et	4	main
või	doc_491521501915_item	2551045	et	4	main
juubilari	doc_491521501915_item	2551049	et	4	main
soovitakse	doc_491521501915_item	2551050	et	4	main
5	doc_491521501915_item	2551063	et	2	main
emadepäeval	doc_491521501915_item	2551064	et	3	main
huvitavam	doc_491521501916_item	2551081	et	4	main
rootsisse	doc_491521501916_item	2551091	et	3	main
20	doc_491521501916_item	2551095	et	2	main
inimest	doc_491521501916_item	2551096	et	3	main
ja	doc_491521501916_item	2551097	et	3	main
kestis	doc_491521501916_item	2551098	et	4	main
3	doc_491521501916_item	2551099	et	2	main
praamis	doc_491521501916_item	2551108	et	3	main
meil	doc_491521501916_item	2551109	et	4	main
kajutid	doc_491521501916_item	2551111	et	3	main
kolmandal	doc_491521501916_item	2551112	et	3	main
ööbisime	doc_491521501916_item	2551116	et	3	main
kahekesi	doc_491521501916_item	2551117	et	3	main
hommikul	doc_491521501916_item	2551120	et	3	main
seda	doc_491521501916_item	2551124	et	3	main
vaba	doc_491521501916_item	2551127	et	4	main
aeg	doc_491521501916_item	2551128	et	3	main
puhkamaks	doc_491521501916_item	2551129	et	3	main
lõuna	doc_491521501916_item	2551130	et	4	main
oli	doc_491521501916_item	2551131	et	3	main
hotellibaaris	doc_491521501916_item	2551132	et	3	main
peale	doc_491521501916_item	2551133	et	4	main
lõunat	doc_491521501916_item	2551134	et	3	main
meil	doc_491521501916_item	2551135	et	4	main
oli	doc_491521501916_item	2551136	et	3	main
linnaekskursioon	doc_491521501916_item	2551137	et	3	main
on	doc_491521501916_item	2551150	et	4	main
maailma	doc_491521501916_item	2551161	et	4	main
esimene	doc_491521501916_item	2551162	et	3	main
on	doc_491521501916_item	2551165	et	4	main
pargid	doc_491521501916_item	2551175	et	4	main
on	doc_491521501916_item	2551176	et	4	main
palju	doc_491521501916_item	2551181	et	4	main
kullatoas	doc_491521501916_item	2551188	et	3	main
kus	doc_491521501916_item	2551231	et	3	main
tõllad	doc_491521501916_item	2551233	et	3	main
teisi	doc_491521501916_item	2551242	et	4	main
riigisaalis	doc_491521501916_item	2551246	et	3	main
kuninganna	doc_491521501916_item	2551250	et	4	main
lossis	doc_491521501916_item	2551254	et	4	main
inimene	doc_491521501913_item	2550931	et	3	main
arendab	doc_491521501913_item	2550932	et	3	main
oma	doc_491521501913_item	2550933	et	4	main
teadusi	doc_491521501913_item	2550934	et	3	main
kundas	doc_491521501913_item	2550939	et	4	main
juures	doc_491521501913_item	2550942	et	4	main
sõidan	doc_491521501913_item	2550948	et	3	main
tuju	doc_491521501913_item	2550951	et	4	main
paremaks	doc_491521501913_item	2550952	et	4	main
juba	doc_491521501913_item	2550953	et	3	main
bussis	doc_491521501913_item	2550954	et	3	main
sinna	doc_491521501913_item	2550959	et	3	main
tulles	doc_491521501913_item	2550960	et	4	main
ma	doc_491521501913_item	2550961	et	3	main
näen	doc_491521501913_item	2550962	et	3	main
oma	doc_491521501913_item	2550963	et	4	main
ristipoega	doc_491521501913_item	2550964	et	4	main
vennapoega	doc_491521501913_item	2550965	et	4	main
ta	doc_491521501913_item	2550966	et	4	main
on	doc_491521501913_item	2550967	et	4	main
ja	doc_491521501913_item	2550970	et	3	main
sest	doc_491521501913_item	2550986	et	4	main
ilus	doc_491521501913_item	2550991	et	4	main
meri	doc_491521501913_item	2550994	et	3	main
keskkoolis	doc_491521501914_item	2550997	et	4	main
käikse	doc_491521501914_item	2550998	et	4	main
minnakse	doc_491521501914_item	2551002	et	3	main
2	doc_491521501914_item	2551007	et	2	main
õnnitletakse	doc_491521501914_item	2551009	et	3	main
soovitakse	doc_491521501914_item	2551011	et	4	main
mantlid	doc_491521501914_item	2551019	et	3	main
emadele	doc_491521501914_item	2551025	et	3	main
lilli	doc_491521501914_item	2551026	et	4	main
pealinnas	doc_491521501914_item	2551028	et	4	main
kantakse	doc_491521501914_item	2551029	et	3	main
moodsaid	doc_491521501914_item	2551030	et	3	main
riideid	doc_491521501914_item	2551031	et	3	main
lüpstakse	doc_491521501914_item	2551034	et	3	main
masinatega	doc_491521501914_item	2551035	et	3	main
harjutus	doc_491521501915_item	2551036	et	4	main
1	doc_491521501915_item	2551037	et	2	main
käietakse	doc_491521501915_item	2551046	et	4	main
6	doc_491521501915_item	2551068	et	2	main
lehmi	doc_491521501915_item	2551076	et	4	main
masinatega	doc_491521501915_item	2551077	et	3	main
essee	doc_491521501916_item	2551078	et	4	main
minu	doc_491521501916_item	2551079	et	3	main
ma	doc_491521501916_item	2551083	et	3	main
tahaksin	doc_491521501916_item	2551084	et	3	main
reisist	doc_491521501916_item	2551088	et	3	main
välja	doc_491521501916_item	2551101	et	4	main
sõitsime	doc_491521501916_item	2551102	et	3	main
tallinnast	doc_491521501916_item	2551103	et	3	main
õhtul	doc_491521501916_item	2551104	et	3	main
olid	doc_491521501916_item	2551110	et	4	main
laevalael	doc_491521501916_item	2551113	et	4	main
seal	doc_491521501916_item	2551114	et	4	main
rootsisse	doc_491521501916_item	2551119	et	3	main
pärast	doc_491521501916_item	2551123	et	4	main
meil	doc_491521501916_item	2551125	et	4	main
me	doc_491521501916_item	2551138	et	4	main
sõitsime	doc_491521501916_item	2551139	et	3	main
bussiga	doc_491521501916_item	2551140	et	3	main
linnavaatamisväärsuseid	doc_491521501916_item	2551148	et	4	main
ebatavaline	doc_491521501916_item	2551167	et	4	main
ja	doc_491521501916_item	2551169	et	3	main
linna	doc_491521501916_item	2551172	et	4	main
stockholmis	doc_491521501916_item	2551179	et	4	main
ajaloomuuseumi	doc_491521501916_item	2551187	et	4	main
hall	doc_491521501916_item	2551221	et	4	main
toimuvad	doc_491521501916_item	2551223	et	4	main
me	doc_491521501916_item	2551238	et	4	main
nägime	doc_491521501916_item	2551239	et	3	main
giid	doc_491521501916_item	2551247	et	3	main
drottningholmi	doc_491521501916_item	2551253	et	4	main
17	doc_491521501916_item	2551258	et	2	main
elab	doc_491521501916_item	2551260	et	3	main
perekond	doc_491521501916_item	2551262	et	3	main
ka	doc_491521501916_item	2551272	et	3	main
6	doc_491521501914_item	2551027	et	2	main
üksteist	doc_491521501915_item	2551040	et	4	main
aastat	doc_491521501915_item	2551041	et	3	main
siis	doc_491521501915_item	2551042	et	3	main
minetakse	doc_491521501915_item	2551043	et	4	main
tööle	doc_491521501915_item	2551044	et	3	main
andakse	doc_491521501915_item	2551061	et	4	main
riidehoidu	doc_491521501915_item	2551062	et	4	main
kingitakse	doc_491521501915_item	2551065	et	4	main
kantakse	doc_491521501915_item	2551070	et	3	main
riideid	doc_491521501915_item	2551072	et	3	main
majandites	doc_491521501915_item	2551074	et	3	main
reis	doc_491521501916_item	2551082	et	4	main
jutustada	doc_491521501916_item	2551085	et	3	main
ma	doc_491521501916_item	2551089	et	3	main
rühmas	doc_491521501916_item	2551093	et	4	main
päeva	doc_491521501916_item	2551100	et	4	main
praamiga	doc_491521501916_item	2551107	et	4	main
ja	doc_491521501916_item	2551145	et	3	main
näitas	doc_491521501916_item	2551146	et	3	main
on	doc_491521501916_item	2551160	et	4	main
üllatavalt	doc_491521501916_item	2551177	et	4	main
rahvamuuseum	doc_491521501916_item	2551184	et	3	main
3000	doc_491521501916_item	2551190	et	2	main
kuld-	doc_491521501916_item	2551192	et	3	main
nobeli	doc_491521501916_item	2551225	et	4	main
pidustused	doc_491521501916_item	2551226	et	3	main
kuningalossis	doc_491521501916_item	2551228	et	3	main
asub	doc_491521501916_item	2551229	et	3	main
relvakamber	doc_491521501916_item	2551230	et	3	main
on	doc_491521501916_item	2551232	et	4	main
keskaegne	doc_491521501916_item	2551235	et	3	main
varakambris	doc_491521501916_item	2551237	et	3	main
ja	doc_491521501916_item	2551241	et	3	main
väärtuslikuid	doc_491521501916_item	2551243	et	4	main
esemeid	doc_491521501916_item	2551244	et	3	main
meile	doc_491521501916_item	2551249	et	4	main
kristiina	doc_491521501916_item	2551251	et	4	main
hõbetrooni	doc_491521501916_item	2551252	et	4	main
mis	doc_491521501916_item	2551255	et	4	main
pärit	doc_491521501916_item	2551257	et	3	main
sajandist	doc_491521501916_item	2551259	et	3	main
kuninglik	doc_491521501916_item	2551261	et	3	main
see	doc_491521501916_item	2551263	et	3	main
ainulaadne	doc_491521501916_item	2551273	et	3	main
teater	doc_491521501916_item	2551275	et	3	main
vaata	doc_491521501916_item	2551277	et	4	main
mis	doc_491521501916_item	2551278	et	4	main
väärsuseid	doc_491521501916_item	2551279	et	4	main
meile	doc_491521501916_item	2551286	et	4	main
kõrgkooli	doc_491521501915_item	2551047	et	4	main
õnnitletakse	doc_491521501915_item	2551052	et	3	main
head	doc_491521501915_item	2551054	et	4	main
lilli	doc_491521501915_item	2551067	et	4	main
kõige	doc_491521501916_item	2551080	et	4	main
kõigest	doc_491521501916_item	2551086	et	4	main
meie	doc_491521501916_item	2551092	et	4	main
oli	doc_491521501916_item	2551094	et	3	main
kell	doc_491521501916_item	2551105	et	3	main
me	doc_491521501916_item	2551115	et	4	main
hotellis	doc_491521501916_item	2551122	et	3	main
stockholm	doc_491521501916_item	2551149	et	4	main
ilus	doc_491521501916_item	2551152	et	4	main
me	doc_491521501916_item	2551155	et	4	main
olime	doc_491521501916_item	2551156	et	3	main
kuninglik	doc_491521501916_item	2551157	et	3	main
ökopargis	doc_491521501916_item	2551158	et	3	main
see	doc_491521501916_item	2551159	et	3	main
kus	doc_491521501916_item	2551164	et	3	main
loomastik	doc_491521501916_item	2551170	et	4	main
rotsis	doc_491521501916_item	2551171	et	4	main
tänavad	doc_491521501916_item	2551173	et	4	main
ja	doc_491521501916_item	2551174	et	3	main
on	doc_491521501916_item	2551180	et	4	main
naiteks	doc_491521501916_item	2551183	et	4	main
kunstihoone	doc_491521501916_item	2551186	et	4	main
on	doc_491521501916_item	2551189	et	4	main
ja	doc_491521501916_item	2551193	et	3	main
hõbeeset	doc_491521501916_item	2551194	et	3	main
loodusmuuseumis	doc_491521501916_item	2551195	et	3	main
huvitavaid	doc_491521501916_item	2551197	et	4	main
väljapanekuid	doc_491521501916_item	2551198	et	3	main
on	doc_491521501916_item	2551196	et	4	main
loomadest	doc_491521501916_item	2551199	et	3	main
fossiilidest	doc_491521501916_item	2551200	et	3	main
kivististest	doc_491521501916_item	2551201	et	3	main
mineraalides	doc_491521501916_item	2551202	et	3	main
bergiani	doc_491521501916_item	2551203	et	4	main
botaanikaaias	doc_491521501916_item	2551204	et	4	main
me	doc_491521501916_item	2551205	et	4	main
nägime	doc_491521501916_item	2551206	et	3	main
hiigelvesiroosi	doc_491521501916_item	2551207	et	4	main
victoria	doc_491521501916_item	2551208	et	4	main
vaatamisväärsus	doc_491521501916_item	2551210	et	4	main
huvitav	doc_491521501916_item	2551209	et	4	main
on	doc_491521501916_item	2551211	et	4	main
raekoda	doc_491521501916_item	2551212	et	4	main
koos	doc_491521501916_item	2551213	et	4	main
torniga	doc_491521501916_item	2551214	et	4	main
raekojas	doc_491521501916_item	2551215	et	3	main
on	doc_491521501916_item	2551216	et	4	main
kuldne	doc_491521501916_item	2551217	et	3	main
saal	doc_491521501916_item	2551218	et	3	main
ja	doc_491521501916_item	2551219	et	3	main
sinine	doc_491521501916_item	2551220	et	4	main
kus	doc_491521501916_item	2551222	et	3	main
igaaastased	doc_491521501916_item	2551224	et	4	main
barokkstiilis	doc_491521501916_item	2551227	et	3	main
relvastus	doc_491521501916_item	2551236	et	4	main
kroone	doc_491521501916_item	2551240	et	3	main
populaarsemkoht	doc_491521501916_item	2551266	et	4	main
praegu	doc_491521501916_item	2551269	et	3	main
ja	doc_491521501916_item	2551234	et	3	main
lossi	doc_491521501916_item	2551245	et	4	main
näitas	doc_491521501916_item	2551248	et	3	main
on	doc_491521501916_item	2551256	et	4	main
on	doc_491521501916_item	2551264	et	4	main
kõige	doc_491521501916_item	2551265	et	4	main
jaoks	doc_491521501916_item	2551268	et	4	main
seal	doc_491521501916_item	2551270	et	4	main
jäid	doc_491521501916_item	2551285	et	4	main
mällu	doc_491521501916_item	2551287	et	3	main
turistide	doc_491521501916_item	2551267	et	3	main
asub	doc_491521501916_item	2551271	et	3	main
drottningholmi	doc_491521501916_item	2551274	et	4	main
neid	doc_491521501916_item	2551276	et	4	main
päeva	doc_491521501916_item	2551283	et	4	main
need	doc_491521501916_item	2551284	et	3	main
mulle	doc_491521501916_item	2551288	et	4	main
sõit	doc_491521501916_item	2551291	et	3	main
laps	doc_491521501919_item	2551497	et	4	main
päevi	doc_491521501919_item	2551508	et	4	main
tramme	doc_491521501919_item	2551522	et	3	main
rong	doc_491521501919_item	2551525	et	3	main
taksosid	doc_491521501919_item	2551530	et	3	main
jalgrataid	doc_491521501919_item	2551534	et	4	main
parte	doc_491521501919_item	2551548	et	4	main
menüü	doc_491521501919_item	2551551	et	4	main
58	doc_491521501919_item	2551564	et	2	main
mugavaid	doc_491521501919_item	2551590	et	3	main
vanamehi	doc_491521501919_item	2551597	et	3	main
suuri	doc_491521501919_item	2551601	et	3	main
kajakaid	doc_491521501919_item	2551604	et	4	main
tahaksin	doc_491521501921_item	2551731	et	3	main
tuttav	doc_491521501921_item	2551743	et	3	main
koolitusreisil	doc_491521501921_item	2551758	et	3	main
tema	doc_491521501921_item	2551768	et	4	main
praegune	doc_491521501921_item	2551769	et	3	main
tugevaks	doc_491521501921_item	2551780	et	4	main
küljeks	doc_491521501921_item	2551781	et	3	main
me	doc_491521501916_item	2551280	et	4	main
vaatasime	doc_491521501916_item	2551281	et	3	main
kolm	doc_491521501916_item	2551282	et	3	main
meeldis	doc_491521501916_item	2551289	et	3	main
see	doc_491521501916_item	2551290	et	3	main
väga	doc_491521501916_item	2551292	et	3	main
lapsi	doc_491521501919_item	2551498	et	4	main
kuu	doc_491521501919_item	2551509	et	4	main
lennuk	doc_491521501919_item	2551527	et	3	main
jalgratas	doc_491521501919_item	2551533	et	3	main
hiiri	doc_491521501919_item	2551536	et	4	main
karu	doc_491521501919_item	2551541	et	4	main
tiiger	doc_491521501919_item	2551543	et	3	main
liblikas	doc_491521501919_item	2551545	et	4	main
taldrik	doc_491521501919_item	2551549	et	3	main
taldrikuid	doc_491521501919_item	2551550	et	3	main
konserve	doc_491521501919_item	2551560	et	3	main
ametnikke	doc_491521501919_item	2551593	et	3	main
laevasid	doc_491521501919_item	2551598	et	3	main
kisavaid	doc_491521501919_item	2551603	et	4	main
õnnelikuid	doc_491521501919_item	2551605	et	4	main
mustikaid	doc_491521501919_item	2551614	et	3	main
onu	doc_491521501919_item	2551491	et	4	main
mehi	doc_491521501919_item	2551502	et	3	main
vanur	doc_491521501919_item	2551503	et	3	main
vanur	doc_491521501919_item	2551504	et	3	main
aasta	doc_491521501919_item	2551505	et	4	main
lennukeid	doc_491521501919_item	2551528	et	3	main
kass	doc_491521501919_item	2551537	et	3	main
kassi	doc_491521501919_item	2551538	et	4	main
liblikaid	doc_491521501919_item	2551546	et	3	main
pipar	doc_491521501919_item	2551557	et	3	main
konserv	doc_491521501919_item	2551559	et	3	main
klaase	doc_491521501919_item	2551562	et	3	main
päkapikuid	doc_491521501919_item	2551566	et	4	main
jõuluvanu	doc_491521501919_item	2551567	et	3	main
igasuguseid	doc_491521501919_item	2551592	et	3	main
praamind	doc_491521501919_item	2551600	et	3	main
laenesid	doc_491521501919_item	2551602	et	4	main
keerulisi	doc_491521501919_item	2551607	et	4	main
aknaid	doc_491521501919_item	2551610	et	3	main
linlasi	doc_491521501919_item	2551612	et	3	main
pohlaid	doc_491521501919_item	2551615	et	4	main
naine	doc_491521501919_item	2551499	et	3	main
naisi	doc_491521501919_item	2551500	et	3	main
mees	doc_491521501919_item	2551501	et	4	main
kuuid	doc_491521501919_item	2551510	et	4	main
tund	doc_491521501919_item	2551511	et	3	main
tunde	doc_491521501919_item	2551512	et	4	main
minut	doc_491521501919_item	2551513	et	3	main
minuteid	doc_491521501919_item	2551514	et	4	main
öö	doc_491521501919_item	2551515	et	4	main
ööid	doc_491521501919_item	2551516	et	4	main
sekund	doc_491521501919_item	2551517	et	3	main
sekundeid	doc_491521501919_item	2551518	et	3	main
auto	doc_491521501919_item	2551519	et	4	main
autosid	doc_491521501919_item	2551520	et	3	main
buss	doc_491521501919_item	2551523	et	3	main
harjutus	doc_491521501919_item	2551490	et	4	main
onusid	doc_491521501919_item	2551492	et	3	main
tädi	doc_491521501919_item	2551493	et	4	main
tädisid	doc_491521501919_item	2551494	et	3	main
sõber	doc_491521501919_item	2551495	et	3	main
sõbru	doc_491521501919_item	2551496	et	4	main
aastaid	doc_491521501919_item	2551506	et	4	main
päev	doc_491521501919_item	2551507	et	3	main
takso	doc_491521501919_item	2551529	et	4	main
takso	doc_491521501919_item	2551531	et	4	main
taksosid	doc_491521501919_item	2551532	et	3	main
koer	doc_491521501919_item	2551539	et	3	main
koerasid	doc_491521501919_item	2551540	et	3	main
menüusid	doc_491521501919_item	2551552	et	4	main
makaron	doc_491521501919_item	2551553	et	3	main
klaas	doc_491521501919_item	2551561	et	3	main
kaunistusi	doc_491521501919_item	2551565	et	4	main
kuninglikuid	doc_491521501919_item	2551584	et	4	main
liiliaid	doc_491521501919_item	2551585	et	3	main
lihtsaid	doc_491521501919_item	2551586	et	3	main
karikakraid	doc_491521501919_item	2551587	et	4	main
kvaliteetseid	doc_491521501919_item	2551588	et	3	main
ja	doc_491521501919_item	2551589	et	3	main
jalatsid	doc_491521501919_item	2551591	et	3	main
inimesi	doc_491521501919_item	2551595	et	4	main
paadisid	doc_491521501919_item	2551599	et	4	main
eluetapide	doc_491521501919_item	2551608	et	4	main
dekoreerituid	doc_491521501919_item	2551609	et	4	main
ostuhimuliseid	doc_491521501919_item	2551611	et	4	main
maasikaid	doc_491521501919_item	2551613	et	3	main
murakaid	doc_491521501919_item	2551617	et	3	main
tramm	doc_491521501919_item	2551521	et	3	main
busse	doc_491521501919_item	2551524	et	3	main
ronge	doc_491521501919_item	2551526	et	3	main
hiir	doc_491521501919_item	2551535	et	4	main
karusid	doc_491521501919_item	2551542	et	3	main
tiigreid	doc_491521501919_item	2551544	et	3	main
part	doc_491521501919_item	2551547	et	4	main
makarone	doc_491521501919_item	2551554	et	3	main
võileib	doc_491521501919_item	2551555	et	3	main
võileibasid	doc_491521501919_item	2551556	et	3	main
pipraid	doc_491521501919_item	2551558	et	3	main
h	doc_491521501919_item	2551563	et	4	main
kingipakke	doc_491521501919_item	2551568	et	4	main
vaikesi	doc_491521501919_item	2551569	et	4	main
ja	doc_491521501919_item	2551570	et	3	main
suureid	doc_491521501919_item	2551571	et	3	main
kuuski	doc_491521501919_item	2551572	et	4	main
sõnu	doc_491521501919_item	2551573	et	4	main
lausi	doc_491521501919_item	2551574	et	4	main
lõiguid	doc_491521501919_item	2551575	et	4	main
ja	doc_491521501919_item	2551576	et	3	main
tervesid	doc_491521501919_item	2551577	et	4	main
tekste	doc_491521501919_item	2551578	et	3	main
kirjalikuid	doc_491521501919_item	2551579	et	4	main
tööid	doc_491521501919_item	2551580	et	4	main
lille	doc_491521501919_item	2551581	et	4	main
punaseid	doc_491521501919_item	2551582	et	4	main
roose	doc_491521501919_item	2551583	et	3	main
naeratavaid	doc_491521501919_item	2551594	et	4	main
tigedaid	doc_491521501919_item	2551596	et	3	main
päevi	doc_491521501919_item	2551606	et	4	main
ja	doc_491521501919_item	2551616	et	3	main
võimalust	doc_491521501921_item	2551733	et	3	main
minu	doc_491521501921_item	2551741	et	3	main
hea	doc_491521501921_item	2551742	et	4	main
eesnimi	doc_491521501921_item	2551747	et	3	main
on	doc_491521501921_item	2551749	et	4	main
praegu	doc_491521501921_item	2551759	et	3	main
põhitegevus	doc_491521501921_item	2551770	et	4	main
kooli	doc_491521501921_item	2551771	et	4	main
lõpetamine	doc_491521501921_item	2551772	et	4	main
iseloomult	doc_491521501921_item	2551773	et	3	main
tema	doc_491521501921_item	2551786	et	4	main
sport	doc_491521501921_item	2551791	et	3	main
õhtul	doc_491521501921_item	2551795	et	3	main
temal	doc_491521501921_item	2551797	et	3	main
ammu	doc_491521501921_item	2551812	et	4	main
õppime	doc_491521501921_item	2551814	et	4	main
tahaksin	doc_491521501922_item	2551820	et	3	main
tutvustada	doc_491521501922_item	2551824	et	3	main
oma	doc_491521501922_item	2551825	et	4	main
kes	doc_491521501922_item	2551837	et	4	main
tema	doc_491521501922_item	2551851	et	4	main
ja	doc_491521501922_item	2551855	et	3	main
pürgimine	doc_491521501922_item	2551857	et	4	main
iseloomult	doc_491521501922_item	2551858	et	3	main
tugevaks	doc_491521501922_item	2551864	et	4	main
on	doc_491521501922_item	2551866	et	4	main
paindlikkus	doc_491521501922_item	2551868	et	4	main
tahaksin	doc_491521501924_item	2551987	et	3	main
eesnimi	doc_491521501924_item	2551996	et	3	main
meeldiva	doc_491521501924_item	2552000	et	4	main
õppimisega	doc_491521501924_item	2552013	et	4	main
tema	doc_491521501924_item	2552017	et	4	main
rahulik	doc_491521501924_item	2552025	et	3	main
tema	doc_491521501924_item	2552027	et	4	main
hulka	doc_491521501924_item	2552034	et	4	main
hea	doc_491521501924_item	2552047	et	4	main
tutvustada	doc_491521501921_item	2551735	et	3	main
koolikaaslast	doc_491521501921_item	2551737	et	4	main
ta	doc_491521501921_item	2551738	et	4	main
tema	doc_491521501921_item	2551744	et	4	main
on	doc_491521501921_item	2551746	et	4	main
tema	doc_491521501921_item	2551748	et	4	main
see	doc_491521501921_item	2551750	et	3	main
linnas	doc_491521501921_item	2551757	et	4	main
ta	doc_491521501921_item	2551761	et	4	main
õppimisega	doc_491521501921_item	2551764	et	4	main
aga	doc_491521501921_item	2551765	et	3	main
muidu	doc_491521501921_item	2551766	et	3	main
rahulik	doc_491521501921_item	2551776	et	3	main
täpsus	doc_491521501921_item	2551784	et	4	main
kuuluvad	doc_491521501921_item	2551789	et	4	main
muusika	doc_491521501921_item	2551790	et	4	main
jalutada	doc_491521501921_item	2551796	et	3	main
ka	doc_491521501921_item	2551799	et	3	main
neid	doc_491521501921_item	2551806	et	4	main
lugeda	doc_491521501921_item	2551807	et	3	main
juba	doc_491521501921_item	2551811	et	3	main
ja	doc_491521501921_item	2551813	et	3	main
präegu	doc_491521501921_item	2551815	et	4	main
tere	doc_491521501922_item	2551818	et	3	main
kiri	doc_491521501921_item	2551730	et	3	main
oma	doc_491521501921_item	2551736	et	4	main
siin	doc_491521501921_item	2551756	et	4	main
tegeleb	doc_491521501921_item	2551760	et	3	main
eesti	doc_491521501921_item	2551762	et	4	main
keele	doc_491521501921_item	2551763	et	4	main
ta	doc_491521501921_item	2551775	et	4	main
sõjakas	doc_491521501921_item	2551778	et	4	main
tema	doc_491521501921_item	2551779	et	4	main
on	doc_491521501921_item	2551782	et	4	main
töökus	doc_491521501921_item	2551783	et	4	main
hulka	doc_491521501921_item	2551788	et	4	main
tema	doc_491521501921_item	2551792	et	4	main
väga	doc_491521501921_item	2551794	et	3	main
on	doc_491521501921_item	2551798	et	4	main
hobbi	doc_491521501921_item	2551800	et	4	main
talle	doc_491521501921_item	2551801	et	4	main
meeldib	doc_491521501921_item	2551802	et	3	main
raamatuid	doc_491521501921_item	2551803	et	3	main
koguda	doc_491521501921_item	2551804	et	3	main
ja	doc_491521501921_item	2551805	et	3	main
temaga	doc_491521501921_item	2551810	et	3	main
kasutada	doc_491521501922_item	2551821	et	3	main
ja	doc_491521501922_item	2551823	et	3	main
nimi	doc_491521501922_item	2551828	et	3	main
tema	doc_491521501922_item	2551831	et	4	main
see	doc_491521501922_item	2551833	et	3	main
tüdruk	doc_491521501922_item	2551836	et	3	main
siin	doc_491521501922_item	2551839	et	4	main
praegune	doc_491521501922_item	2551852	et	3	main
hoidlik	doc_491521501922_item	2551862	et	3	main
kasutada	doc_491521501921_item	2551732	et	3	main
ja	doc_491521501921_item	2551734	et	3	main
on	doc_491521501921_item	2551739	et	4	main
ka	doc_491521501921_item	2551740	et	3	main
nimi	doc_491521501921_item	2551745	et	3	main
meeldiva	doc_491521501921_item	2551751	et	4	main
välimusega	doc_491521501921_item	2551752	et	3	main
kes	doc_491521501921_item	2551754	et	4	main
neiu	doc_491521501921_item	2551753	et	4	main
on	doc_491521501921_item	2551755	et	4	main
on	doc_491521501921_item	2551767	et	4	main
on	doc_491521501921_item	2551774	et	4	main
kannatlik	doc_491521501921_item	2551777	et	3	main
korrektsus	doc_491521501921_item	2551785	et	4	main
armastab	doc_491521501921_item	2551793	et	3	main
tutvastasime	doc_491521501921_item	2551809	et	4	main
kiri	doc_491521501922_item	2551817	et	3	main
võimalust	doc_491521501922_item	2551822	et	3	main
koolikaslast	doc_491521501922_item	2551826	et	4	main
on	doc_491521501922_item	2551829	et	4	main
on	doc_491521501922_item	2551838	et	4	main
linnas	doc_491521501922_item	2551840	et	4	main
koolitusreisil	doc_491521501922_item	2551841	et	3	main
praegu	doc_491521501922_item	2551842	et	3	main
tegeleb	doc_491521501922_item	2551843	et	3	main
ta	doc_491521501922_item	2551844	et	4	main
on	doc_491521501922_item	2551850	et	4	main
koolilõpetamine	doc_491521501922_item	2551854	et	3	main
kõrgkooli	doc_491521501922_item	2551856	et	4	main
on	doc_491521501922_item	2551859	et	4	main
tema	doc_491521501922_item	2551863	et	4	main
küljeks	doc_491521501922_item	2551865	et	3	main
kasutada	doc_491521501924_item	2551988	et	3	main
ja	doc_491521501924_item	2551990	et	3	main
sõbratari	doc_491521501924_item	2551992	et	4	main
nimi	doc_491521501924_item	2551994	et	3	main
see	doc_491521501924_item	2551999	et	3	main
välimusega	doc_491521501924_item	2552001	et	3	main
praegu	doc_491521501924_item	2552008	et	3	main
ta	doc_491521501924_item	2552010	et	4	main
eesti	doc_491521501924_item	2552011	et	4	main
iseloomult	doc_491521501924_item	2552022	et	3	main
harrastuste	doc_491521501924_item	2552033	et	4	main
on	doc_491521501924_item	2552045	et	4	main
väga	doc_491521501924_item	2552046	et	3	main
sõbratar	doc_491521501924_item	2552048	et	3	main
jalutame	doc_491521501924_item	2552052	et	3	main
harrastuste	doc_491521501921_item	2551787	et	4	main
meie	doc_491521501921_item	2551808	et	4	main
koos	doc_491521501921_item	2551816	et	4	main
päevast	doc_491521501922_item	2551819	et	4	main
eesnimi	doc_491521501922_item	2551830	et	3	main
eesti	doc_491521501922_item	2551845	et	4	main
ta	doc_491521501922_item	2551860	et	4	main
tagasi	doc_491521501922_item	2551861	et	3	main
tähelepanelikkus	doc_491521501922_item	2551867	et	4	main
on	doc_491521501924_item	2551995	et	4	main
on	doc_491521501924_item	2551998	et	4	main
neiu	doc_491521501924_item	2552002	et	4	main
kes	doc_491521501924_item	2552003	et	4	main
tegeleb	doc_491521501924_item	2552009	et	3	main
aga	doc_491521501924_item	2552014	et	3	main
praegune	doc_491521501924_item	2552018	et	3	main
tema	doc_491521501922_item	2551827	et	4	main
on	doc_491521501922_item	2551832	et	4	main
meeldiva	doc_491521501922_item	2551834	et	4	main
välimusega	doc_491521501922_item	2551835	et	3	main
keele	doc_491521501922_item	2551846	et	4	main
õppimisega	doc_491521501922_item	2551847	et	4	main
aga	doc_491521501922_item	2551848	et	3	main
muidu	doc_491521501922_item	2551849	et	3	main
põhitegevus	doc_491521501922_item	2551853	et	4	main
tema	doc_491521501922_item	2551869	et	4	main
harrastuse	doc_491521501922_item	2551870	et	4	main
hulka	doc_491521501922_item	2551871	et	4	main
kuuluvad	doc_491521501922_item	2551872	et	4	main
sport	doc_491521501922_item	2551873	et	3	main
ja	doc_491521501922_item	2551874	et	3	main
tantsimine	doc_491521501922_item	2551875	et	4	main
kiri	doc_491521501924_item	2551986	et	3	main
võimalust	doc_491521501924_item	2551989	et	3	main
on	doc_491521501924_item	2552004	et	4	main
keele	doc_491521501924_item	2552012	et	4	main
on	doc_491521501924_item	2552016	et	4	main
lõpetamine	doc_491521501924_item	2552021	et	4	main
tema	doc_491521501924_item	2552032	et	4	main
muusika	doc_491521501924_item	2552036	et	4	main
kaua	doc_491521501924_item	2552039	et	3	main
ja	doc_491521501924_item	2552040	et	3	main
ma	doc_491521501924_item	2552041	et	3	main
arvan	doc_491521501924_item	2552042	et	3	main
et	doc_491521501924_item	2552043	et	3	main
tema	doc_491521501924_item	2552044	et	4	main
tutvustada	doc_491521501924_item	2551991	et	3	main
tema	doc_491521501924_item	2551993	et	4	main
tema	doc_491521501924_item	2551997	et	4	main
siin	doc_491521501924_item	2552005	et	4	main
linnas	doc_491521501924_item	2552006	et	4	main
vahetusüliõpilasena	doc_491521501924_item	2552007	et	3	main
muidu	doc_491521501924_item	2552015	et	3	main
põhitegevus	doc_491521501924_item	2552019	et	4	main
kõrgkooli	doc_491521501924_item	2552020	et	4	main
ta	doc_491521501924_item	2552024	et	4	main
me	doc_491521501924_item	2552050	et	4	main
koos	doc_491521501924_item	2552051	et	4	main
või	doc_491521501924_item	2552053	et	4	main
koos	doc_491521501924_item	2552054	et	4	main
reisime	doc_491521501924_item	2552055	et	3	main
tal	doc_491521501924_item	2552056	et	3	main
on	doc_491521501924_item	2552023	et	4	main
tagasihoidlik	doc_491521501924_item	2552026	et	3	main
tugevaks	doc_491521501924_item	2552028	et	4	main
küljeks	doc_491521501924_item	2552029	et	3	main
on	doc_491521501924_item	2552030	et	4	main
sõbralikkus	doc_491521501924_item	2552031	et	4	main
kuuluvad	doc_491521501924_item	2552035	et	4	main
me	doc_491521501924_item	2552037	et	4	main
sõbrustame	doc_491521501924_item	2552038	et	3	main
tihti	doc_491521501924_item	2552049	et	3	main
on	doc_491521501924_item	2552057	et	4	main
suur	doc_491521501924_item	2552058	et	3	main
märgikogu	doc_491521501924_item	2552059	et	4	main
eesnimi	doc_491521501928_item	2552664	et	3	main
on	doc_491521501928_item	2552669	et	4	main
juulis	doc_491521501928_item	2552671	et	3	main
lacoste	doc_491521501928_item	2552701	et	4	main
versace	doc_491521501928_item	2552702	et	4	main
salvador	doc_491521501928_item	2552704	et	4	main
loreal	doc_491521501928_item	2552708	et	4	main
dekotraktiivkosmeetika	doc_491521501928_item	2552710	et	4	main
mulle	doc_491521501928_item	2552711	et	4	main
väga	doc_491521501928_item	2552712	et	3	main
osakond	doc_491521501928_item	2552735	et	3	main
tahaksin	doc_491521501928_item	2552738	et	3	main
sul	doc_491521501928_item	2552666	et	3	main
poodis	doc_491521501928_item	2552674	et	4	main
mul	doc_491521501928_item	2552675	et	3	main
oli	doc_491521501928_item	2552676	et	3	main
praktika	doc_491521501928_item	2552677	et	4	main
minu	doc_491521501928_item	2552678	et	3	main
praktika	doc_491521501928_item	2552679	et	4	main
oli	doc_491521501928_item	2552680	et	3	main
poodis	doc_491521501928_item	2552681	et	4	main
tsentral	doc_491521501928_item	2552682	et	4	main
jõhvis	doc_491521501928_item	2552683	et	3	main
agdek	doc_491521501928_item	2552685	et	4	main
parfümeerija	doc_491521501928_item	2552686	et	4	main
as	doc_491521501928_item	2552684	et	4	main
töö	doc_491521501928_item	2552687	et	4	main
algab	doc_491521501928_item	2552688	et	3	main
kell	doc_491521501928_item	2552689	et	3	main
üheksa	doc_491521501928_item	2552690	et	4	main
sellel	doc_491521501928_item	2552691	et	4	main
osakonnas	doc_491521501928_item	2552692	et	4	main
väga	doc_491521501928_item	2552693	et	3	main
hea	doc_491521501928_item	2552694	et	4	main
kosmetika	doc_491521501928_item	2552695	et	4	main
parfümeerija	doc_491521501928_item	2552696	et	4	main
parfüm	doc_491521501928_item	2552697	et	4	main
kaubamärk	doc_491521501928_item	2552698	et	3	main
hugo	doc_491521501928_item	2552699	et	4	main
boss	doc_491521501928_item	2552700	et	3	main
läheb	doc_491521501928_item	2552667	et	3	main
töötasin	doc_491521501928_item	2552673	et	3	main
kreemid	doc_491521501928_item	2552706	et	3	main
osakonnas	doc_491521501928_item	2552716	et	4	main
kiri	doc_491521501928_item	2552662	et	3	main
tere	doc_491521501928_item	2552663	et	3	main
hästi	doc_491521501928_item	2552670	et	3	main
matis	doc_491521501928_item	2552707	et	4	main
meeldib	doc_491521501928_item	2552713	et	3	main
palju	doc_491521501928_item	2552717	et	4	main
ostjaga	doc_491521501928_item	2552719	et	4	main
töötasin	doc_491521501928_item	2552721	et	3	main
terminaaliga	doc_491521501928_item	2552725	et	3	main
kaubad	doc_491521501928_item	2552727	et	3	main
arvutasin	doc_491521501928_item	2552729	et	3	main
kaubad	doc_491521501928_item	2552731	et	3	main
signatsioni	doc_491521501928_item	2552736	et	4	main
töötan	doc_491521501928_item	2552739	et	3	main
aega	doc_491521501928_item	2552743	et	4	main
minu	doc_491521501931_item	2553130	et	3	main
nimi	doc_491521501931_item	2553131	et	3	main
eesnimi	doc_491521501931_item	2553133	et	3	main
abielus	doc_491521501931_item	2553136	et	4	main
me	doc_491521501931_item	2553137	et	4	main
on	doc_491521501931_item	2553149	et	4	main
plaanija	doc_491521501931_item	2553160	et	4	main
meil	doc_491521501931_item	2553161	et	4	main
kuidas	doc_491521501928_item	2552665	et	3	main
mul	doc_491521501928_item	2552668	et	3	main
ma	doc_491521501928_item	2552672	et	3	main
dali	doc_491521501928_item	2552705	et	4	main
juusevärvid	doc_491521501928_item	2552709	et	4	main
sellel	doc_491521501928_item	2552715	et	4	main
kassale	doc_491521501928_item	2552722	et	4	main
kasutasin	doc_491521501928_item	2552724	et	3	main
ja	doc_491521501928_item	2552733	et	3	main
olen	doc_491521501931_item	2553135	et	3	main
perekond	doc_491521501931_item	2553143	et	3	main
minu	doc_491521501931_item	2553144	et	3	main
mees	doc_491521501931_item	2553145	et	4	main
nimi	doc_491521501931_item	2553146	et	3	main
lalique	doc_491521501928_item	2552703	et	4	main
tööta	doc_491521501928_item	2552714	et	4	main
suhtlesin	doc_491521501928_item	2552718	et	3	main
ma	doc_491521501928_item	2552720	et	3	main
ja	doc_491521501928_item	2552723	et	3	main
ja	doc_491521501928_item	2552728	et	3	main
andsin	doc_491521501928_item	2552732	et	3	main
võitsin	doc_491521501928_item	2552734	et	3	main
ma	doc_491521501928_item	2552737	et	3	main
poes	doc_491521501928_item	2552741	et	3	main
vastusin	doc_491521501928_item	2552726	et	3	main
hinna	doc_491521501928_item	2552730	et	3	main
selle	doc_491521501928_item	2552740	et	4	main
head	doc_491521501928_item	2552742	et	4	main
kiri	doc_491521501931_item	2553129	et	3	main
ma	doc_491521501931_item	2553134	et	3	main
kohtla-järvel	doc_491521501931_item	2553139	et	4	main
väike	doc_491521501931_item	2553142	et	4	main
abikaasa	doc_491521501931_item	2553154	et	4	main
töötab	doc_491521501931_item	2553155	et	3	main
as	doc_491521501931_item	2553156	et	4	main
velsicol	doc_491521501931_item	2553157	et	4	main
üks	doc_491521501931_item	2553163	et	3	main
on	doc_491521501931_item	2553172	et	4	main
eesnimi	doc_491521501931_item	2553173	et	3	main
on	doc_491521501931_item	2553190	et	4	main
kolm	doc_491521501931_item	2553191	et	3	main
magamistuba	doc_491521501931_item	2553194	et	4	main
esik	doc_491521501931_item	2553198	et	3	main
on	doc_491521501931_item	2553202	et	4	main
töötab	doc_491521501931_item	2553205	et	3	main
abielus	doc_491521501931_item	2553209	et	4	main
töötab	doc_491521501931_item	2553222	et	3	main
postkontoris	doc_491521501931_item	2553223	et	3	main
pensionär	doc_491521501931_item	2553230	et	3	main
ma	doc_491521501932_item	2553249	et	3	main
abielus	doc_491521501932_item	2553254	et	4	main
on	doc_491521501931_item	2553132	et	4	main
elame	doc_491521501931_item	2553138	et	3	main
on	doc_491521501931_item	2553141	et	4	main
ta	doc_491521501931_item	2553148	et	4	main
üheksa	doc_491521501931_item	2553151	et	4	main
minu	doc_491521501931_item	2553153	et	3	main
teie	doc_491521501931_item	2553170	et	4	main
nimi	doc_491521501931_item	2553171	et	3	main
kolmakorruselises	doc_491521501931_item	2553181	et	4	main
meie	doc_491521501931_item	2553185	et	4	main
tuba	doc_491521501931_item	2553192	et	4	main
lastetuba	doc_491521501931_item	2553196	et	4	main
vend	doc_491521501931_item	2553203	et	3	main
ta	doc_491521501931_item	2553204	et	4	main
trükikodas	doc_491521501931_item	2553206	et	4	main
vend	doc_491521501931_item	2553207	et	3	main
on	doc_491521501931_item	2553228	et	4	main
veel	doc_491521501931_item	2553232	et	4	main
on	doc_491521501932_item	2553237	et	4	main
ei	doc_491521501932_item	2553247	et	4	main
meil	doc_491521501931_item	2553140	et	4	main
ta	doc_491521501931_item	2553158	et	4	main
last	doc_491521501931_item	2553164	et	4	main
on	doc_491521501931_item	2553167	et	4	main
ta	doc_491521501931_item	2553174	et	4	main
läheb	doc_491521501931_item	2553175	et	3	main
teisel	doc_491521501931_item	2553183	et	4	main
ja	doc_491521501931_item	2553195	et	3	main
ja	doc_491521501931_item	2553199	et	3	main
teil	doc_491521501931_item	2553210	et	4	main
on	doc_491521501931_item	2553211	et	4	main
kaks	doc_491521501931_item	2553212	et	3	main
last	doc_491521501931_item	2553213	et	4	main
nad	doc_491521501931_item	2553214	et	3	main
elavad	doc_491521501931_item	2553215	et	4	main
jõhvis	doc_491521501931_item	2553216	et	3	main
minu	doc_491521501931_item	2553217	et	3	main
vanemad	doc_491521501931_item	2553218	et	4	main
elavad	doc_491521501931_item	2553219	et	4	main
jõhvis	doc_491521501931_item	2553220	et	3	main
eesnimi	doc_491521501931_item	2553147	et	3	main
kakskümmend	doc_491521501931_item	2553150	et	4	main
aastane	doc_491521501931_item	2553152	et	4	main
on	doc_491521501931_item	2553159	et	4	main
poeg	doc_491521501931_item	2553165	et	3	main
kuus	doc_491521501931_item	2553168	et	4	main
aastane	doc_491521501931_item	2553169	et	4	main
kooli	doc_491521501931_item	2553176	et	4	main
esimene	doc_491521501931_item	2553177	et	3	main
klass	doc_491521501931_item	2553178	et	3	main
me	doc_491521501931_item	2553179	et	4	main
elame	doc_491521501931_item	2553180	et	3	main
on	doc_491521501931_item	2553187	et	4	main
suur	doc_491521501931_item	2553188	et	3	main
meil	doc_491521501931_item	2553189	et	4	main
vannituba	doc_491521501931_item	2553197	et	4	main
mul	doc_491521501931_item	2553201	et	3	main
ta	doc_491521501931_item	2553224	et	4	main
kohtla-järvel	doc_491521501932_item	2553245	et	4	main
ma	doc_491521501932_item	2553246	et	3	main
õppima	doc_491521501932_item	2553250	et	3	main
mees	doc_491521501932_item	2553256	et	4	main
on	doc_491521501932_item	2553258	et	4	main
eesnimi	doc_491521501932_item	2553259	et	3	main
meil	doc_491521501932_item	2553265	et	4	main
artur	doc_491521501932_item	2553269	et	4	main
minu	doc_491521501933_item	2553294	et	3	main
ma	doc_491521501933_item	2553297	et	3	main
nelja	doc_491521501933_item	2553299	et	4	main
mees	doc_491521501933_item	2553303	et	4	main
eesnimi	doc_491521501933_item	2553306	et	3	main
meil	doc_491521501933_item	2553312	et	4	main
on	doc_491521501933_item	2553313	et	4	main
kaks	doc_491521501933_item	2553314	et	3	main
laste	doc_491521501933_item	2553318	et	4	main
ja	doc_491521501933_item	2553322	et	3	main
ees	doc_491521501933_item	2553344	et	4	main
on	doc_491521501933_item	2553348	et	4	main
mul	doc_491521501935_item	2553459	et	3	main
mulle	doc_491521501935_item	2553485	et	4	main
ei	doc_491521501935_item	2553486	et	4	main
mulle	doc_491521501935_item	2553489	et	4	main
ma	doc_491521501935_item	2553492	et	3	main
muusikat	doc_491521501935_item	2553494	et	3	main
mul	doc_491521501935_item	2553496	et	3	main
teen	doc_491521501935_item	2553500	et	3	main
mina	doc_491521501935_item	2553504	et	4	main
võin	doc_491521501935_item	2553505	et	3	main
terve	doc_491521501935_item	2553506	et	4	main
päev	doc_491521501935_item	2553507	et	3	main
mul	doc_491521501935_item	2553521	et	3	main
palju	doc_491521501935_item	2553533	et	4	main
sõpru	doc_491521501935_item	2553534	et	3	main
ma	doc_491521501935_item	2553535	et	3	main
suhtlen	doc_491521501935_item	2553536	et	3	main
sõpradega	doc_491521501935_item	2553537	et	3	main
vene	doc_491521501935_item	2553538	et	4	main
keeles	doc_491521501935_item	2553539	et	4	main
sõpru	doc_491521501935_item	2553545	et	3	main
minu	doc_491521501935_item	2553550	et	3	main
kui	doc_491521501935_item	2553559	et	3	main
mul	doc_491521501935_item	2553560	et	3	main
on	doc_491521501935_item	2553561	et	4	main
mind	doc_491521501935_item	2553567	et	4	main
kui	doc_491521501935_item	2553568	et	3	main
mul	doc_491521501935_item	2553569	et	3	main
on	doc_491521501931_item	2553162	et	4	main
ta	doc_491521501931_item	2553166	et	4	main
majas	doc_491521501931_item	2553182	et	3	main
korrusel	doc_491521501931_item	2553184	et	3	main
korter	doc_491521501931_item	2553186	et	3	main
elutuba	doc_491521501931_item	2553193	et	4	main
köök	doc_491521501931_item	2553200	et	3	main
on	doc_491521501931_item	2553208	et	4	main
isa	doc_491521501931_item	2553221	et	4	main
juba	doc_491521501931_item	2553229	et	3	main
töötab	doc_491521501931_item	2553233	et	3	main
minu	doc_491521501932_item	2553235	et	3	main
elan	doc_491521501932_item	2553244	et	3	main
ma	doc_491521501932_item	2553252	et	3	main
olen	doc_491521501932_item	2553253	et	3	main
on	doc_491521501932_item	2553261	et	4	main
kolmekümne	doc_491521501932_item	2553262	et	4	main
seitsme	doc_491521501932_item	2553263	et	3	main
poega	doc_491521501932_item	2553268	et	4	main
nimi	doc_491521501933_item	2553295	et	3	main
olen	doc_491521501933_item	2553298	et	3	main
minu	doc_491521501933_item	2553302	et	3	main
aastane	doc_491521501933_item	2553311	et	4	main
minu	doc_491521501933_item	2553317	et	3	main
see	doc_491521501933_item	2553319	et	3	main
õpe	doc_491521501933_item	2553325	et	3	main
juba	doc_491521501933_item	2553330	et	3	main
koolis	doc_491521501933_item	2553331	et	4	main
mull	doc_491521501933_item	2553332	et	3	main
suures	doc_491521501933_item	2553339	et	3	main
majas	doc_491521501933_item	2553340	et	3	main
mere	doc_491521501933_item	2553341	et	3	main
ääres	doc_491521501933_item	2553342	et	4	main
lilleg	doc_491521501933_item	2553346	et	4	main
on	doc_491521501931_item	2553225	et	4	main
autojuht	doc_491521501931_item	2553226	et	3	main
ema	doc_491521501931_item	2553227	et	4	main
kuid	doc_491521501931_item	2553231	et	4	main
kiri	doc_491521501932_item	2553234	et	3	main
nimi	doc_491521501932_item	2553236	et	3	main
eesnimi	doc_491521501932_item	2553238	et	3	main
ma	doc_491521501932_item	2553239	et	3	main
olen	doc_491521501932_item	2553240	et	3	main
neljakümne	doc_491521501932_item	2553241	et	4	main
aastane	doc_491521501932_item	2553242	et	4	main
ma	doc_491521501932_item	2553243	et	3	main
kursis	doc_491521501932_item	2553251	et	3	main
ja	doc_491521501932_item	2553270	et	3	main
artur	doc_491521501932_item	2553272	et	4	main
on	doc_491521501932_item	2553273	et	4	main
üheksateistaastane	doc_491521501932_item	2553274	et	4	main
edik	doc_491521501932_item	2553275	et	4	main
on	doc_491521501932_item	2553276	et	4	main
kuusteistaastane	doc_491521501932_item	2553277	et	4	main
artur	doc_491521501932_item	2553278	et	4	main
opib	doc_491521501932_item	2553279	et	4	main
tehnikumis	doc_491521501932_item	2553280	et	3	main
edik	doc_491521501932_item	2553281	et	4	main
õpib	doc_491521501932_item	2553282	et	3	main
koolis	doc_491521501932_item	2553283	et	4	main
mulle	doc_491521501932_item	2553284	et	4	main
on	doc_491521501932_item	2553285	et	4	main
kolm	doc_491521501932_item	2553286	et	3	main
tuba	doc_491521501932_item	2553287	et	4	main
mulle	doc_491521501932_item	2553288	et	4	main
meeldib	doc_491521501932_item	2553289	et	3	main
õmblema	doc_491521501932_item	2553290	et	3	main
kuduma	doc_491521501932_item	2553291	et	4	main
kiri	doc_491521501933_item	2553292	et	3	main
töötan	doc_491521501932_item	2553248	et	3	main
minu	doc_491521501932_item	2553255	et	3	main
nimi	doc_491521501932_item	2553257	et	3	main
ta	doc_491521501932_item	2553260	et	4	main
on	doc_491521501932_item	2553266	et	4	main
kaks	doc_491521501932_item	2553267	et	3	main
edik	doc_491521501932_item	2553271	et	4	main
eesnimi	doc_491521501933_item	2553296	et	3	main
aastane	doc_491521501933_item	2553301	et	4	main
pavel	doc_491521501933_item	2553323	et	4	main
venema	doc_491521501933_item	2553327	et	4	main
on	doc_491521501933_item	2553333	et	4	main
kaks	doc_491521501933_item	2553334	et	3	main
maja	doc_491521501933_item	2553343	et	4	main
mull	doc_491521501933_item	2553347	et	3	main
hoov	doc_491521501933_item	2553349	et	3	main
essee	doc_491521501935_item	2553456	et	4	main
huvialad	doc_491521501935_item	2553458	et	3	main
meeldib	doc_491521501935_item	2553461	et	3	main
igav	doc_491521501935_item	2553498	et	3	main
tööd	doc_491521501935_item	2553502	et	4	main
rahustab	doc_491521501935_item	2553512	et	3	main
muusikuid	doc_491521501935_item	2553518	et	3	main
ja	doc_491521501935_item	2553519	et	3	main
ole	doc_491521501935_item	2553523	et	4	main
meeldivad	doc_491521501935_item	2553527	et	4	main
žanrid	doc_491521501935_item	2553529	et	2	main
mul	doc_491521501935_item	2553530	et	3	main
on	doc_491521501935_item	2553531	et	4	main
väga	doc_491521501935_item	2553532	et	3	main
sest	doc_491521501935_item	2553540	et	4	main
mul	doc_491521501935_item	2553542	et	3	main
räägivad	doc_491521501935_item	2553547	et	3	main
hea	doc_491521501935_item	2553564	et	4	main
nad	doc_491521501935_item	2553565	et	3	main
aega	doc_491521501935_item	2553578	et	4	main
koos	doc_491521501935_item	2553580	et	4	main
nendega	doc_491521501935_item	2553586	et	4	main
rääkida	doc_491521501935_item	2553588	et	3	main
ka	doc_491521501935_item	2553591	et	3	main
hobit	doc_491521501935_item	2553594	et	4	main
aastane	doc_491521501932_item	2553264	et	4	main
tere	doc_491521501933_item	2553293	et	3	main
kolme	doc_491521501933_item	2553300	et	4	main
nimi	doc_491521501933_item	2553304	et	3	main
on	doc_491521501933_item	2553305	et	4	main
ta	doc_491521501933_item	2553307	et	4	main
on	doc_491521501933_item	2553308	et	4	main
last	doc_491521501933_item	2553315	et	4	main
nelja	doc_491521501933_item	2553309	et	4	main
viiese	doc_491521501933_item	2553310	et	4	main
poeg	doc_491521501933_item	2553316	et	3	main
on	doc_491521501933_item	2553320	et	4	main
sergei	doc_491521501933_item	2553321	et	4	main
tuba	doc_491521501933_item	2553335	et	4	main
meie	doc_491521501933_item	2553336	et	4	main
on	doc_491521501933_item	2553345	et	4	main
minu	doc_491521501935_item	2553457	et	3	main
väga	doc_491521501935_item	2553460	et	3	main
hoolitseda	doc_491521501935_item	2553462	et	3	main
meeldi	doc_491521501935_item	2553487	et	4	main
koorilaul	doc_491521501935_item	2553488	et	4	main
kui	doc_491521501935_item	2553495	et	3	main
ma	doc_491521501935_item	2553513	et	3	main
poppkruppe	doc_491521501935_item	2553516	et	4	main
ansambleid	doc_491521501935_item	2553520	et	3	main
ei	doc_491521501935_item	2553522	et	4	main
ole	doc_491521501935_item	2553544	et	4	main
kes	doc_491521501935_item	2553546	et	4	main
eesti	doc_491521501935_item	2553548	et	4	main
keeles	doc_491521501935_item	2553549	et	4	main
jaoks	doc_491521501935_item	2553551	et	4	main
sõbrad	doc_491521501935_item	2553552	et	3	main
või	doc_491521501935_item	2553563	et	4	main
abistavad	doc_491521501935_item	2553566	et	4	main
koos	doc_491521501935_item	2553573	et	4	main
ma	doc_491521501935_item	2553575	et	3	main
sest	doc_491521501935_item	2553581	et	4	main
ja	doc_491521501935_item	2553585	et	3	main
see	doc_491521501935_item	2553590	et	3	main
võib	doc_491521501935_item	2553592	et	3	main
ja	doc_491521501936_item	2553628	et	3	main
oma	doc_491521501936_item	2553629	et	4	main
on	doc_491521501936_item	2553645	et	4	main
rock	doc_491521501936_item	2553650	et	4	main
kui	doc_491521501936_item	2553657	et	3	main
kõige	doc_491521501936_item	2553668	et	4	main
suuremed	doc_491521501936_item	2553669	et	4	main
huvialad	doc_491521501936_item	2553670	et	3	main
minu	doc_491521501936_item	2553671	et	3	main
elus	doc_491521501936_item	2553672	et	4	main
on	doc_491521501936_item	2553681	et	4	main
vana	doc_491521501936_item	2553684	et	4	main
müüja	doc_491521501937_item	2553696	et	4	main
lugeda	doc_491521501937_item	2553700	et	3	main
spordi	doc_491521501937_item	2553703	et	4	main
iga	doc_491521501937_item	2553705	et	4	main
päev	doc_491521501937_item	2553706	et	3	main
tihti	doc_491521501937_item	2553714	et	3	main
valmistan	doc_491521501937_item	2553715	et	3	main
olen	doc_491521501937_item	2553725	et	3	main
ma	doc_491521501937_item	2553732	et	3	main
kell	doc_491521501937_item	2553735	et	3	main
sõbrale	doc_491521501938_item	2553752	et	3	main
külla	doc_491521501938_item	2553771	et	4	main
pikkus	doc_491521501938_item	2553774	et	4	main
korter	doc_491521501938_item	2553784	et	3	main
uues	doc_491521501938_item	2553786	et	3	main
maja	doc_491521501938_item	2553789	et	4	main
on	doc_491521501938_item	2553790	et	4	main
suur	doc_491521501938_item	2553791	et	3	main
ja	doc_491521501938_item	2553792	et	3	main
mugav	doc_491521501938_item	2553793	et	3	main
seal	doc_491521501938_item	2553794	et	4	main
et	doc_491521501938_item	2553824	et	3	main
sergei	doc_491521501933_item	2553324	et	4	main
on	doc_491521501933_item	2553326	et	4	main
pavel	doc_491521501933_item	2553328	et	4	main
kõib	doc_491521501933_item	2553329	et	4	main
pere	doc_491521501933_item	2553337	et	4	main
elab	doc_491521501933_item	2553338	et	3	main
muusika	doc_491521501935_item	2553484	et	4	main
meeldib	doc_491521501935_item	2553490	et	3	main
kuulan	doc_491521501935_item	2553493	et	3	main
kui	doc_491521501935_item	2553499	et	3	main
muusikat	doc_491521501935_item	2553508	et	3	main
kuulata	doc_491521501935_item	2553509	et	4	main
tean	doc_491521501935_item	2553514	et	3	main
loomad	doc_491521501935_item	2553463	et	3	main
see	doc_491521501935_item	2553464	et	3	main
on	doc_491521501935_item	2553465	et	4	main
minu	doc_491521501935_item	2553466	et	3	main
lemmik	doc_491521501935_item	2553467	et	3	main
minu	doc_491521501935_item	2553469	et	3	main
töö	doc_491521501935_item	2553468	et	4	main
hobi	doc_491521501935_item	2553470	et	4	main
on	doc_491521501935_item	2553471	et	4	main
ratsutamine	doc_491521501935_item	2553472	et	4	main
ma	doc_491521501935_item	2553473	et	3	main
armastan	doc_491521501935_item	2553474	et	3	main
hobused	doc_491521501935_item	2553475	et	4	main
ja	doc_491521501935_item	2553476	et	3	main
nad	doc_491521501935_item	2553477	et	3	main
armastavad	doc_491521501935_item	2553478	et	4	main
mind	doc_491521501935_item	2553479	et	4	main
veel	doc_491521501935_item	2553480	et	4	main
ma	doc_491521501935_item	2553481	et	3	main
armastan	doc_491521501935_item	2553482	et	3	main
kuulata	doc_491521501935_item	2553483	et	4	main
estraadimuusika	doc_491521501935_item	2553491	et	4	main
on	doc_491521501935_item	2553497	et	4	main
koduseid	doc_491521501935_item	2553501	et	4	main
mõnikord	doc_491521501935_item	2553503	et	3	main
mind	doc_491521501935_item	2553510	et	4	main
muusika	doc_491521501935_item	2553511	et	4	main
palju	doc_491521501935_item	2553515	et	4	main
popularseid	doc_491521501935_item	2553517	et	4	main
žanrit	doc_491521501935_item	2553525	et	2	main
et	doc_491521501935_item	2553541	et	3	main
on	doc_491521501935_item	2553553	et	4	main
halb	doc_491521501935_item	2553562	et	3	main
halb	doc_491521501935_item	2553571	et	3	main
proobleme	doc_491521501935_item	2553574	et	4	main
veedan	doc_491521501935_item	2553576	et	3	main
et	doc_491521501935_item	2553582	et	3	main
nimitada	doc_491521501935_item	2553593	et	4	main
essee	doc_491521501936_item	2553595	et	4	main
mul	doc_491521501936_item	2553596	et	3	main
on	doc_491521501936_item	2553597	et	4	main
mõned	doc_491521501936_item	2553598	et	3	main
huvialad	doc_491521501936_item	2553599	et	3	main
aga	doc_491521501936_item	2553600	et	3	main
kõige	doc_491521501936_item	2553601	et	4	main
rohkem	doc_491521501936_item	2553602	et	4	main
mulle	doc_491521501936_item	2553603	et	4	main
meeldib	doc_491521501936_item	2553604	et	3	main
suvel	doc_491521501936_item	2553605	et	3	main
jalgrattaga	doc_491521501936_item	2553606	et	3	main
sõita	doc_491521501936_item	2553607	et	3	main
see	doc_491521501936_item	2553608	et	3	main
on	doc_491521501936_item	2553609	et	4	main
väga	doc_491521501936_item	2553610	et	3	main
rahustab	doc_491521501936_item	2553611	et	3	main
mind	doc_491521501936_item	2553612	et	4	main
ja	doc_491521501936_item	2553613	et	3	main
annab	doc_491521501936_item	2553614	et	3	main
mulle	doc_491521501936_item	2553615	et	4	main
eluenergia	doc_491521501936_item	2553616	et	4	main
teine	doc_491521501936_item	2553617	et	3	main
huviala	doc_491521501936_item	2553618	et	4	main
see	doc_491521501936_item	2553619	et	3	main
on	doc_491521501936_item	2553620	et	4	main
perele	doc_491521501936_item	2553630	et	3	main
väga	doc_491521501936_item	2553631	et	3	main
meeldib	doc_491521501936_item	2553632	et	3	main
mulle	doc_491521501936_item	2553633	et	4	main
kuulan	doc_491521501936_item	2553639	et	3	main
hea	doc_491521501936_item	2553641	et	4	main
armastan	doc_491521501936_item	2553652	et	3	main
rahulikult	doc_491521501936_item	2553666	et	4	main
muidugi	doc_491521501936_item	2553667	et	4	main
mul	doc_491521501936_item	2553680	et	3	main
p	doc_491521501936_item	2553687	et	4	main
alju	doc_491521501936_item	2553688	et	4	main
meeldib	doc_491521501937_item	2553702	et	3	main
tegelenda	doc_491521501937_item	2553704	et	4	main
vaatan	doc_491521501937_item	2553708	et	3	main
telerit	doc_491521501937_item	2553709	et	3	main
kuulan	doc_491521501937_item	2553710	et	3	main
muusikat	doc_491521501937_item	2553711	et	3	main
üldiselt	doc_491521501937_item	2553717	et	4	main
mina	doc_491521501937_item	2553718	et	4	main
oskan	doc_491521501937_item	2553719	et	3	main
lemmik	doc_491521501935_item	2553524	et	3	main
mulle	doc_491521501935_item	2553526	et	4	main
kõik	doc_491521501935_item	2553528	et	4	main
ei	doc_491521501935_item	2553543	et	4	main
väga	doc_491521501935_item	2553554	et	3	main
olulised	doc_491521501935_item	2553555	et	4	main
nad	doc_491521501935_item	2553556	et	3	main
näevad	doc_491521501935_item	2553557	et	3	main
ise	doc_491521501935_item	2553558	et	4	main
lahendada	doc_491521501935_item	2553572	et	3	main
vaba	doc_491521501935_item	2553577	et	4	main
sõpradega	doc_491521501935_item	2553579	et	3	main
sõbrad	doc_491521501935_item	2553583	et	3	main
ja	doc_491521501935_item	2553589	et	3	main
ise	doc_491521501936_item	2553623	et	4	main
kuulata	doc_491521501936_item	2553636	et	4	main
ma	doc_491521501936_item	2553638	et	3	main
hea	doc_491521501936_item	2553640	et	4	main
klassika	doc_491521501936_item	2553642	et	4	main
kui	doc_491521501936_item	2553643	et	3	main
mul	doc_491521501936_item	2553644	et	3	main
minu	doc_491521501936_item	2553678	et	3	main
pere	doc_491521501936_item	2553679	et	4	main
kursustee	doc_491521501937_item	2553697	et	4	main
mulle	doc_491521501937_item	2553698	et	4	main
kodu	doc_491521501937_item	2553712	et	4	main
et	doc_491521501937_item	2553721	et	3	main
palju	doc_491521501937_item	2553729	et	4	main
1100	doc_491521501937_item	2553736	et	2	main
kolinud	doc_491521501938_item	2553743	et	4	main
uude	doc_491521501938_item	2553744	et	3	main
korterisse	doc_491521501938_item	2553745	et	3	main
ja	doc_491521501938_item	2553746	et	3	main
tahate	doc_491521501938_item	2553747	et	3	main
teatada	doc_491521501938_item	2553748	et	3	main
sellest	doc_491521501938_item	2553749	et	4	main
läks	doc_491521501938_item	2553756	et	3	main
kuidas	doc_491521501938_item	2553758	et	3	main
kutsuge	doc_491521501938_item	2553769	et	3	main
ta	doc_491521501938_item	2553770	et	4	main
sõna	doc_491521501938_item	2553778	et	4	main
ma	doc_491521501938_item	2553779	et	3	main
kolisin	doc_491521501938_item	2553780	et	3	main
uude	doc_491521501938_item	2553781	et	3	main
minu	doc_491521501938_item	2553788	et	3	main
maja	doc_491521501938_item	2553801	et	4	main
ma	doc_491521501938_item	2553821	et	3	main
on	doc_491521501938_item	2553835	et	4	main
väga	doc_491521501938_item	2553836	et	3	main
on	doc_491521501935_item	2553570	et	4	main
lõbused	doc_491521501935_item	2553584	et	3	main
võib	doc_491521501935_item	2553587	et	3	main
õmblemine	doc_491521501936_item	2553621	et	4	main
õmblen	doc_491521501936_item	2553624	et	3	main
asjad	doc_491521501936_item	2553626	et	3	main
endale	doc_491521501936_item	2553627	et	4	main
muusikat	doc_491521501936_item	2553635	et	3	main
mõnikord	doc_491521501936_item	2553637	et	3	main
kuulata	doc_491521501936_item	2553653	et	4	main
üksinda	doc_491521501936_item	2553655	et	4	main
magavad	doc_491521501936_item	2553659	et	4	main
ma	doc_491521501936_item	2553660	et	3	main
panin	doc_491521501936_item	2553661	et	3	main
disk	doc_491521501936_item	2553662	et	4	main
ainult	doc_491521501936_item	2553682	et	4	main
aga	doc_491521501936_item	2553686	et	3	main
tuttavaid	doc_491521501936_item	2553689	et	3	main
essee	doc_491521501937_item	2553690	et	4	main
1	doc_491521501937_item	2553691	et	2	main
minu	doc_491521501937_item	2553692	et	3	main
päev	doc_491521501937_item	2553693	et	3	main
ma	doc_491521501937_item	2553694	et	3	main
õpin	doc_491521501937_item	2553695	et	3	main
mulle	doc_491521501937_item	2553701	et	4	main
ma	doc_491521501937_item	2553713	et	3	main
päev	doc_491521501937_item	2553723	et	3	main
kursud	doc_491521501937_item	2553727	et	4	main
aega	doc_491521501937_item	2553730	et	4	main
lähen	doc_491521501937_item	2553738	et	3	main
oma	doc_491521501938_item	2553750	et	4	main
eestlasest	doc_491521501938_item	2553751	et	3	main
kirjutage	doc_491521501938_item	2553753	et	3	main
käia	doc_491521501938_item	2553767	et	4	main
ja	doc_491521501938_item	2553768	et	3	main
nõutav	doc_491521501938_item	2553773	et	4	main
umbes	doc_491521501938_item	2553776	et	4	main
80	doc_491521501938_item	2553777	et	2	main
asub	doc_491521501938_item	2553785	et	3	main
valge	doc_491521501938_item	2553800	et	4	main
ma	doc_491521501936_item	2553622	et	3	main
kõige	doc_491521501936_item	2553625	et	4	main
hea	doc_491521501936_item	2553634	et	4	main
teine	doc_491521501936_item	2553646	et	3	main
meil	doc_491521501936_item	2553647	et	4	main
siis	doc_491521501936_item	2553648	et	3	main
kuulan	doc_491521501936_item	2553649	et	3	main
ma	doc_491521501936_item	2553651	et	3	main
muusikat	doc_491521501936_item	2553654	et	3	main
õhtul	doc_491521501936_item	2553656	et	3	main
lapsed	doc_491521501936_item	2553658	et	3	main
ja	doc_491521501936_item	2553663	et	3	main
lihtsalt	doc_491521501936_item	2553664	et	4	main
kuulan	doc_491521501936_item	2553665	et	3	main
see	doc_491521501936_item	2553673	et	3	main
on	doc_491521501936_item	2553674	et	4	main
minu	doc_491521501936_item	2553675	et	3	main
lapsed	doc_491521501936_item	2553676	et	3	main
ja	doc_491521501936_item	2553677	et	3	main
kaks	doc_491521501936_item	2553683	et	3	main
sõpru	doc_491521501936_item	2553685	et	3	main
meeldib	doc_491521501937_item	2553699	et	3	main
ma	doc_491521501937_item	2553707	et	3	main
sööki	doc_491521501937_item	2553716	et	4	main
terve	doc_491521501937_item	2553722	et	4	main
kursusee	doc_491521501937_item	2553726	et	4	main
võttavad	doc_491521501937_item	2553728	et	4	main
õhtul	doc_491521501937_item	2553731	et	3	main
käin	doc_491521501937_item	2553733	et	3	main
magama	doc_491521501937_item	2553739	et	3	main
te	doc_491521501938_item	2553741	et	4	main
olete	doc_491521501938_item	2553742	et	3	main
talle	doc_491521501938_item	2553754	et	4	main
kolimine	doc_491521501938_item	2553757	et	4	main
on	doc_491521501938_item	2553764	et	4	main
kauge	doc_491521501938_item	2553765	et	4	main
tööl	doc_491521501938_item	2553766	et	3	main
see	doc_491521501938_item	2553783	et	3	main
raioonis	doc_491521501938_item	2553787	et	4	main
toas	doc_491521501938_item	2553798	et	3	main
talle	doc_491521501938_item	2553823	et	4	main
palju	doc_491521501938_item	2553837	et	4	main
ma	doc_491521501938_item	2553839	et	3	main
elasin	doc_491521501938_item	2553840	et	3	main
ütelda	doc_491521501937_item	2553720	et	4	main
ma	doc_491521501937_item	2553724	et	3	main
külas	doc_491521501937_item	2553734	et	3	main
ma	doc_491521501937_item	2553737	et	3	main
eksamitöö	doc_491521501938_item	2553740	et	4	main
kuidas	doc_491521501938_item	2553755	et	3	main
teile	doc_491521501938_item	2553759	et	4	main
meeldib	doc_491521501938_item	2553760	et	3	main
uues	doc_491521501938_item	2553761	et	3	main
elukohas	doc_491521501938_item	2553762	et	4	main
kas	doc_491521501938_item	2553763	et	3	main
kirja	doc_491521501938_item	2553772	et	4	main
on	doc_491521501938_item	2553775	et	4	main
korterisse	doc_491521501938_item	2553782	et	3	main
on	doc_491521501938_item	2553795	et	4	main
neli	doc_491521501938_item	2553796	et	3	main
toas	doc_491521501938_item	2553797	et	3	main
on	doc_491521501938_item	2553799	et	4	main
ees	doc_491521501938_item	2553802	et	4	main
kaks	doc_491521501938_item	2553804	et	3	main
kaubad	doc_491521501938_item	2553805	et	3	main
veel	doc_491521501938_item	2553806	et	4	main
on	doc_491521501938_item	2553803	et	4	main
on	doc_491521501938_item	2553807	et	4	main
juksla	doc_491521501938_item	2553808	et	4	main
ja	doc_491521501938_item	2553809	et	3	main
post	doc_491521501938_item	2553810	et	3	main
ma	doc_491521501938_item	2553811	et	3	main
teatan	doc_491521501938_item	2553812	et	3	main
oma	doc_491521501938_item	2553813	et	4	main
eestlasest	doc_491521501938_item	2553814	et	3	main
sõbrale	doc_491521501938_item	2553815	et	3	main
et	doc_491521501938_item	2553816	et	3	main
ma	doc_491521501938_item	2553817	et	3	main
kolisin	doc_491521501938_item	2553818	et	3	main
uude	doc_491521501938_item	2553819	et	3	main
korterisse	doc_491521501938_item	2553820	et	3	main
mehed	doc_491521501938_item	2553827	et	3	main
vana	doc_491521501938_item	2553841	et	4	main
raioonis	doc_491521501938_item	2553842	et	4	main
ma	doc_491521501938_item	2553843	et	3	main
käisin	doc_491521501938_item	2553844	et	3	main
tööle	doc_491521501938_item	2553845	et	3	main
ja	doc_491521501938_item	2553846	et	3	main
minu	doc_491521501938_item	2553847	et	3	main
töö	doc_491521501938_item	2553848	et	4	main
asub	doc_491521501938_item	2553849	et	3	main
lähedal	doc_491521501938_item	2553850	et	4	main
aga	doc_491521501938_item	2553851	et	3	main
praegu	doc_491521501938_item	2553852	et	3	main
ma	doc_491521501938_item	2553853	et	3	main
sõidan	doc_491521501938_item	2553854	et	3	main
rägisin	doc_491521501938_item	2553822	et	4	main
mulle	doc_491521501938_item	2553825	et	4	main
tassima	doc_491521501938_item	2553828	et	3	main
mööbel	doc_491521501938_item	2553829	et	3	main
millal	doc_491521501938_item	2553838	et	3	main
bussile	doc_491521501938_item	2553855	et	3	main
aitasid	doc_491521501938_item	2553826	et	4	main
selle	doc_491521501938_item	2553830	et	4	main
pärast	doc_491521501938_item	2553831	et	4	main
et	doc_491521501938_item	2553832	et	3	main
mööbli	doc_491521501938_item	2553833	et	3	main
mul	doc_491521501938_item	2553834	et	3	main
marguse	doc_491521501941_item	2554114	et	4	main
kirjutage	doc_491521501941_item	2554117	et	3	main
kiri	doc_491521501941_item	2554115	et	3	main
sõna	doc_491521501941_item	2554123	et	4	main
kirjuta	doc_491521501941_item	2554125	et	4	main
palun	doc_491521501941_item	2554126	et	3	main
minu	doc_491521501941_item	2554135	et	3	main
kuhu	doc_491521501941_item	2554139	et	3	main
2	doc_491521501941_item	2554165	et	2	main
olla	doc_491521501941_item	2554167	et	3	main
ma	doc_491521501941_item	2554168	et	3	main
tulen	doc_491521501941_item	2554169	et	3	main
sinu	doc_491521501941_item	2554170	et	3	main
tulen	doc_491521501941_item	2554178	et	3	main
kohtumiseni	doc_491521501941_item	2554185	et	4	main
lugege	doc_491521501942_item	2554188	et	3	main
ja	doc_491521501942_item	2554192	et	3	main
kirjutage	doc_491521501942_item	2554193	et	3	main
talle	doc_491521501942_item	2554194	et	4	main
vastus	doc_491521501942_item	2554195	et	3	main
kus	doc_491521501942_item	2554196	et	3	main
tallinnasse	doc_491521501942_item	2554206	et	3	main
sa	doc_491521501942_item	2554210	et	3	main
kiri	doc_491521501941_item	2554111	et	3	main
lugege	doc_491521501941_item	2554112	et	3	main
läbi	doc_491521501941_item	2554113	et	4	main
20-25	doc_491521501941_item	2554122	et	2	main
mitu	doc_491521501941_item	2554132	et	4	main
juures	doc_491521501941_item	2554136	et	4	main
ja	doc_491521501941_item	2554138	et	3	main
sa	doc_491521501941_item	2554140	et	3	main
tahad	doc_491521501941_item	2554143	et	3	main
võiksin	doc_491521501941_item	2554162	et	3	main
juures	doc_491521501941_item	2554164	et	4	main
lõuna	doc_491521501941_item	2554177	et	4	main
ma	doc_491521501941_item	2554181	et	3	main
kiri	doc_491521501942_item	2554187	et	3	main
läbi	doc_491521501942_item	2554189	et	4	main
marguse	doc_491521501942_item	2554190	et	4	main
kiri	doc_491521501942_item	2554191	et	3	main
tere	doc_491521501942_item	2554200	et	3	main
palun	doc_491521501942_item	2554202	et	3	main
millal	doc_491521501942_item	2554204	et	3	main
päeva	doc_491521501942_item	2554209	et	4	main
juures	doc_491521501942_item	2554212	et	4	main
ja	doc_491521501942_item	2554214	et	3	main
sa	doc_491521501942_item	2554216	et	3	main
minna	doc_491521501942_item	2554218	et	3	main
tahad	doc_491521501942_item	2554219	et	3	main
jään	doc_491521501942_item	2554220	et	3	main
olen	doc_491521501942_item	2554232	et	3	main
juures	doc_491521501942_item	2554234	et	4	main
päeva	doc_491521501942_item	2554236	et	4	main
saabub	doc_491521501943_item	2554250	et	3	main
värvuvad	doc_491521501943_item	2554263	et	4	main
puude	doc_491521501943_item	2554264	et	4	main
ja	doc_491521501943_item	2554294	et	3	main
on	doc_491521501943_item	2554297	et	4	main
öökülm	doc_491521501943_item	2554298	et	3	main
puudelt-põsastelt	doc_491521501943_item	2554299	et	4	main
kestavad	doc_491521501943_item	2554319	et	4	main
sajab	doc_491521501943_item	2554323	et	3	main
etteütlus	doc_491521501944_item	2554330	et	3	main
ütles	doc_491521501944_item	2554332	et	3	main
on	doc_491521501944_item	2554339	et	4	main
puude	doc_491521501944_item	2554349	et	4	main
punaseks	doc_491521501944_item	2554353	et	4	main
eriti	doc_491521501944_item	2554354	et	3	main
ilus	doc_491521501944_item	2554355	et	4	main
on	doc_491521501944_item	2554356	et	4	main
vaher	doc_491521501944_item	2554357	et	3	main
tuulega	doc_491521501944_item	2554358	et	3	main
kukub	doc_491521501944_item	2554359	et	3	main
kastani	doc_491521501944_item	2554360	et	3	main
puult	doc_491521501944_item	2554361	et	3	main
munasid	doc_491521501944_item	2554363	et	3	main
koristavad	doc_491521501944_item	2554377	et	4	main
lahkuvad	doc_491521501944_item	2554389	et	4	main
kured	doc_491521501944_item	2554390	et	3	main
haned	doc_491521501944_item	2554391	et	3	main
korjavad	doc_491521501944_item	2554395	et	4	main
tallinnasse	doc_491521501941_item	2554130	et	3	main
tuled	doc_491521501941_item	2554131	et	4	main
võib	doc_491521501941_item	2554159	et	3	main
ma	doc_491521501941_item	2554161	et	3	main
sinu	doc_491521501941_item	2554163	et	3	main
päeva	doc_491521501941_item	2554166	et	4	main
juurde	doc_491521501941_item	2554171	et	4	main
reedel	doc_491521501941_item	2554172	et	3	main
õhtul	doc_491521501941_item	2554173	et	3	main
aga	doc_491521501941_item	2554174	et	3	main
päeast	doc_491521501941_item	2554176	et	4	main
museumi	doc_491521501941_item	2554183	et	4	main
sõna	doc_491521501942_item	2554199	et	4	main
mulle	doc_491521501942_item	2554203	et	4	main
sa	doc_491521501942_item	2554205	et	3	main
mitu	doc_491521501942_item	2554208	et	4	main
oled	doc_491521501942_item	2554213	et	3	main
kuhu	doc_491521501942_item	2554215	et	3	main
tallinnas	doc_491521501942_item	2554217	et	4	main
ootama	doc_491521501942_item	2554222	et	3	main
tere	doc_491521501942_item	2554224	et	3	main
ma	doc_491521501942_item	2554226	et	3	main
lähen	doc_491521501942_item	2554227	et	3	main
järgmisel	doc_491521501942_item	2554229	et	3	main
linna	doc_491521501942_item	2554242	et	4	main
ja	doc_491521501942_item	2554243	et	3	main
etteütlus	doc_491521501943_item	2554247	et	3	main
ilad	doc_491521501943_item	2554256	et	3	main
sojad	doc_491521501943_item	2554258	et	3	main
lehet	doc_491521501943_item	2554265	et	4	main
ja	doc_491521501943_item	2554286	et	3	main
langevad	doc_491521501943_item	2554300	et	4	main
lehed	doc_491521501943_item	2554301	et	3	main
on	doc_491521501943_item	2554314	et	4	main
lompidel	doc_491521501943_item	2554315	et	3	main
juba	doc_491521501943_item	2554316	et	3	main
jää	doc_491521501943_item	2554317	et	4	main
vihmasajud	doc_491521501943_item	2554318	et	3	main
mõnikord	doc_491521501943_item	2554322	et	3	main
merel	doc_491521501943_item	2554326	et	3	main
sügis	doc_491521501944_item	2554333	et	3	main
septembri	doc_491521501944_item	2554337	et	3	main
lehed	doc_491521501944_item	2554350	et	3	main
ja	doc_491521501944_item	2554352	et	3	main
ja	doc_491521501944_item	2554364	et	3	main
tamme	doc_491521501944_item	2554366	et	4	main
korjatakse	doc_491521501944_item	2554369	et	3	main
lähevad	doc_491521501944_item	2554380	et	3	main
jarjest	doc_491521501944_item	2554381	et	4	main
jahedamaks	doc_491521501944_item	2554382	et	4	main
tihti	doc_491521501944_item	2554383	et	3	main
on	doc_491521501944_item	2554384	et	4	main
öökülm	doc_491521501944_item	2554385	et	3	main
puudelt-põõsastelt	doc_491521501944_item	2554386	et	4	main
ilmad	doc_491521501945_item	2554427	et	3	main
sojäd	doc_491521501945_item	2554429	et	4	main
tuulega	doc_491521501945_item	2554444	et	3	main
talmenelt	doc_491521501945_item	2554449	et	4	main
sarapult	doc_491521501945_item	2554451	et	3	main
lähevad	doc_491521501945_item	2554463	et	3	main
tihti	doc_491521501945_item	2554466	et	3	main
ja	doc_491521501945_item	2554475	et	3	main
jää	doc_491521501945_item	2554487	et	4	main
vihmasajud	doc_491521501945_item	2554488	et	3	main
kestavad	doc_491521501945_item	2554489	et	4	main
ja	doc_491521501941_item	2554116	et	3	main
talle	doc_491521501941_item	2554118	et	4	main
vastus	doc_491521501941_item	2554119	et	3	main
kus	doc_491521501941_item	2554120	et	3	main
on	doc_491521501941_item	2554121	et	4	main
tere	doc_491521501941_item	2554124	et	3	main
mulle	doc_491521501941_item	2554127	et	4	main
millal	doc_491521501941_item	2554128	et	3	main
sa	doc_491521501941_item	2554129	et	3	main
päeva	doc_491521501941_item	2554133	et	4	main
oled	doc_491521501941_item	2554137	et	3	main
tallinnas	doc_491521501941_item	2554141	et	4	main
jään	doc_491521501941_item	2554144	et	3	main
vastust	doc_491521501941_item	2554145	et	4	main
ootama	doc_491521501941_item	2554146	et	3	main
margus	doc_491521501941_item	2554147	et	3	main
tere	doc_491521501941_item	2554148	et	3	main
margus	doc_491521501941_item	2554149	et	3	main
olla	doc_491521501941_item	2554160	et	3	main
püahapäeval	doc_491521501941_item	2554175	et	4	main
ära	doc_491521501941_item	2554179	et	4	main
sovitaksin	doc_491521501941_item	2554182	et	4	main
on	doc_491521501942_item	2554197	et	4	main
20-25	doc_491521501942_item	2554198	et	2	main
tuled	doc_491521501942_item	2554207	et	4	main
margus	doc_491521501942_item	2554225	et	3	main
tallinnasse	doc_491521501942_item	2554228	et	3	main
kolm	doc_491521501942_item	2554235	et	3	main
tallinnas	doc_491521501942_item	2554237	et	4	main
ma	doc_491521501942_item	2554238	et	3	main
tahaksin	doc_491521501942_item	2554239	et	3	main
minna	doc_491521501942_item	2554240	et	3	main
vana	doc_491521501942_item	2554241	et	4	main
sügis	doc_491521501943_item	2554249	et	3	main
septembri	doc_491521501943_item	2554252	et	3	main
on	doc_491521501943_item	2554254	et	4	main
aga	doc_491521501943_item	2554255	et	3	main
ilmad	doc_491521501943_item	2554291	et	3	main
lähevad	doc_491521501943_item	2554292	et	3	main
jäärjest	doc_491521501943_item	2554293	et	4	main
hedamaks	doc_491521501943_item	2554295	et	4	main
tihti	doc_491521501943_item	2554296	et	3	main
hommikuti	doc_491521501943_item	2554313	et	4	main
nädalaid	doc_491521501943_item	2554321	et	3	main
ka	doc_491521501943_item	2554324	et	3	main
saabub	doc_491521501944_item	2554335	et	3	main
värvuvat	doc_491521501944_item	2554348	et	4	main
kollaseks	doc_491521501944_item	2554351	et	4	main
sarapuult	doc_491521501944_item	2554368	et	3	main
aidades	doc_491521501944_item	2554371	et	4	main
valmivad	doc_491521501944_item	2554372	et	4	main
õunad	doc_491521501944_item	2554373	et	3	main
ja	doc_491521501944_item	2554374	et	3	main
pirnid	doc_491521501944_item	2554375	et	3	main
inimesed	doc_491521501944_item	2554376	et	3	main
langevad	doc_491521501944_item	2554387	et	4	main
lehed	doc_491521501944_item	2554388	et	3	main
täsahilju	doc_491521501945_item	2554422	et	4	main
värvivad	doc_491521501945_item	2554434	et	4	main
kolaseks	doc_491521501945_item	2554437	et	4	main
kukub	doc_491521501945_item	2554445	et	3	main
kastanimunisid	doc_491521501945_item	2554447	et	4	main
ja	doc_491521501945_item	2554448	et	3	main
tammetõrusid	doc_491521501945_item	2554450	et	3	main
pähkleit	doc_491521501945_item	2554453	et	4	main
valmivad	doc_491521501945_item	2554455	et	4	main
ja	doc_491521501945_item	2554457	et	3	main
koristavad	doc_491521501945_item	2554460	et	4	main
ilmad	doc_491521501945_item	2554462	et	3	main
on	doc_491521501945_item	2554484	et	4	main
lompidel	doc_491521501945_item	2554485	et	3	main
juba	doc_491521501945_item	2554486	et	3	main
3	doc_491521501946_item	2554498	et	2	main
kukkusin	doc_491521501946_item	2554524	et	3	main
ei	doc_491521501946_item	2554538	et	4	main
võistlenud	doc_491521501946_item	2554539	et	4	main
ei	doc_491521501946_item	2554548	et	4	main
suve	doc_491521501947_item	2554558	et	4	main
sa	doc_491521501941_item	2554134	et	3	main
minna	doc_491521501941_item	2554142	et	3	main
ma	doc_491521501941_item	2554150	et	3	main
tulen	doc_491521501941_item	2554151	et	3	main
tallinnasse	doc_491521501941_item	2554152	et	3	main
järgmisel	doc_491521501941_item	2554153	et	3	main
nädalal	doc_491521501941_item	2554154	et	3	main
kindlasti	doc_491521501941_item	2554155	et	3	main
me	doc_491521501941_item	2554156	et	4	main
sulle	doc_491521501941_item	2554158	et	3	main
helistan	doc_491521501941_item	2554157	et	3	main
tallinnas	doc_491521501941_item	2554180	et	4	main
minna	doc_491521501941_item	2554184	et	3	main
eesnimi	doc_491521501941_item	2554186	et	3	main
kirjuta	doc_491521501942_item	2554201	et	4	main
minu	doc_491521501942_item	2554211	et	3	main
vastust	doc_491521501942_item	2554221	et	4	main
margus	doc_491521501942_item	2554223	et	3	main
ja	doc_491521501942_item	2554231	et	3	main
sinu	doc_491521501942_item	2554233	et	3	main
mereranda	doc_491521501942_item	2554244	et	4	main
tervitades	doc_491521501942_item	2554245	et	3	main
sügis	doc_491521501943_item	2554248	et	3	main
tasahilju	doc_491521501943_item	2554251	et	3	main
valmivad	doc_491521501943_item	2554284	et	4	main
õunad	doc_491521501943_item	2554285	et	3	main
pirnid	doc_491521501943_item	2554287	et	3	main
inimesed	doc_491521501943_item	2554288	et	3	main
koristavad	doc_491521501943_item	2554289	et	4	main
lahkuvad	doc_491521501943_item	2554302	et	4	main
kured	doc_491521501943_item	2554303	et	3	main
haned	doc_491521501943_item	2554304	et	3	main
ja	doc_491521501943_item	2554305	et	3	main
luiged	doc_491521501943_item	2554306	et	3	main
oravad	doc_491521501943_item	2554307	et	3	main
korjavad	doc_491521501943_item	2554308	et	4	main
talvevarusid	doc_491521501943_item	2554309	et	3	main
lõõrtsi	doc_491521501943_item	2554325	et	4	main
torm	doc_491521501943_item	2554329	et	3	main
ette	doc_491521501944_item	2554331	et	4	main
sügis	doc_491521501944_item	2554334	et	3	main
algul	doc_491521501944_item	2554338	et	4	main
aga	doc_491521501944_item	2554340	et	3	main
ilmad	doc_491521501944_item	2554341	et	3	main
veel	doc_491521501944_item	2554342	et	4	main
sojad	doc_491521501944_item	2554343	et	3	main
ja	doc_491521501944_item	2554344	et	3	main
puud-põõsad	doc_491521501944_item	2554345	et	3	main
rohelised	doc_491521501944_item	2554346	et	4	main
jarkjargult	doc_491521501944_item	2554347	et	4	main
kastani	doc_491521501944_item	2554362	et	3	main
saaki	doc_491521501944_item	2554378	et	4	main
ilmad	doc_491521501944_item	2554379	et	3	main
oravad	doc_491521501944_item	2554394	et	3	main
talvevarusid	doc_491521501944_item	2554396	et	3	main
algul	doc_491521501945_item	2554424	et	4	main
aga	doc_491521501945_item	2554426	et	3	main
veel	doc_491521501945_item	2554428	et	4	main
ja	doc_491521501945_item	2554430	et	3	main
puud-põlsad	doc_491521501945_item	2554431	et	4	main
järkjargult	doc_491521501945_item	2554433	et	4	main
puunaseks	doc_491521501945_item	2554439	et	4	main
eritti	doc_491521501945_item	2554440	et	4	main
ilus	doc_491521501945_item	2554441	et	4	main
väher	doc_491521501945_item	2554443	et	4	main
kastanipuult	doc_491521501945_item	2554446	et	3	main
pirnid	doc_491521501945_item	2554458	et	3	main
langevad	doc_491521501945_item	2554470	et	4	main
lehed	doc_491521501945_item	2554471	et	3	main
lahkuvad	doc_491521501945_item	2554472	et	4	main
oravad	doc_491521501945_item	2554477	et	3	main
p	doc_491521501946_item	2554499	et	4	main
ains	doc_491521501946_item	2554500	et	4	main
eitav	doc_491521501946_item	2554501	et	4	main
andma	doc_491521501946_item	2554502	et	3	main
kandasin	doc_491521501946_item	2554523	et	4	main
tekkisin	doc_491521501946_item	2554525	et	3	main
ei	doc_491521501946_item	2554532	et	4	main
ei	doc_491521501946_item	2554542	et	4	main
tööd	doc_491521501947_item	2554573	et	4	main
ja	doc_491521501947_item	2554583	et	3	main
käin	doc_491521501947_item	2554585	et	3	main
mina	doc_491521501947_item	2554587	et	4	main
meelest	doc_491521501947_item	2554588	et	4	main
kus	doc_491521501947_item	2554600	et	3	main
saab	doc_491521501947_item	2554605	et	3	main
mulle	doc_491521501947_item	2554630	et	4	main
arvates	doc_491521501947_item	2554642	et	4	main
nii	doc_491521501947_item	2554649	et	3	main
päike	doc_491521501947_item	2554651	et	3	main
mis	doc_491521501947_item	2554653	et	4	main
teenida	doc_491521501948_item	2554671	et	3	main
ise	doc_491521501948_item	2554719	et	4	main
nädalal	doc_491521501942_item	2554230	et	3	main
etteütlus	doc_491521501943_item	2554246	et	3	main
algul	doc_491521501943_item	2554253	et	4	main
veel	doc_491521501943_item	2554257	et	4	main
ja	doc_491521501943_item	2554259	et	3	main
puud-põsad	doc_491521501943_item	2554260	et	4	main
rohilised	doc_491521501943_item	2554261	et	4	main
järkjärguld	doc_491521501943_item	2554262	et	4	main
kolaseks	doc_491521501943_item	2554266	et	4	main
ja	doc_491521501943_item	2554267	et	3	main
eriti	doc_491521501943_item	2554269	et	3	main
ilus	doc_491521501943_item	2554270	et	4	main
on	doc_491521501943_item	2554271	et	4	main
vaher	doc_491521501943_item	2554272	et	3	main
punaseks	doc_491521501943_item	2554268	et	4	main
tuulega	doc_491521501943_item	2554273	et	3	main
kukup	doc_491521501943_item	2554274	et	4	main
kastanipuud	doc_491521501943_item	2554275	et	4	main
kastamimunasid	doc_491521501943_item	2554276	et	4	main
ja	doc_491521501943_item	2554277	et	3	main
tammelt	doc_491521501943_item	2554278	et	4	main
tammetõrusid	doc_491521501943_item	2554279	et	3	main
korjatakse	doc_491521501943_item	2554281	et	3	main
pähkleid	doc_491521501943_item	2554282	et	3	main
sarapuuld	doc_491521501943_item	2554280	et	4	main
aedades	doc_491521501943_item	2554283	et	3	main
saaki	doc_491521501943_item	2554290	et	4	main
loodus	doc_491521501943_item	2554310	et	4	main
valmistub	doc_491521501943_item	2554311	et	3	main
talveks	doc_491521501943_item	2554312	et	4	main
vahel	doc_491521501943_item	2554320	et	4	main
on	doc_491521501943_item	2554327	et	4	main
sageli	doc_491521501943_item	2554328	et	3	main
tasahilju	doc_491521501944_item	2554336	et	3	main
tammelt	doc_491521501944_item	2554365	et	4	main
tõrusid	doc_491521501944_item	2554367	et	3	main
pähkleid	doc_491521501944_item	2554370	et	3	main
ja	doc_491521501944_item	2554392	et	3	main
luiged	doc_491521501944_item	2554393	et	3	main
loodus	doc_491521501944_item	2554397	et	4	main
valmistu	doc_491521501944_item	2554398	et	4	main
talveks	doc_491521501944_item	2554399	et	4	main
hommikuti	doc_491521501944_item	2554400	et	4	main
on	doc_491521501944_item	2554401	et	4	main
lompidel	doc_491521501944_item	2554402	et	3	main
juba	doc_491521501944_item	2554403	et	3	main
jää	doc_491521501944_item	2554404	et	4	main
vihma	doc_491521501944_item	2554405	et	4	main
sajud	doc_491521501944_item	2554406	et	3	main
kestavad	doc_491521501944_item	2554407	et	4	main
vahel	doc_491521501944_item	2554408	et	4	main
nädalaid	doc_491521501944_item	2554409	et	3	main
mõnikord	doc_491521501944_item	2554410	et	3	main
sajab	doc_491521501944_item	2554411	et	3	main
ka	doc_491521501944_item	2554412	et	3	main
lörtsi	doc_491521501944_item	2554413	et	4	main
merel	doc_491521501944_item	2554414	et	3	main
on	doc_491521501944_item	2554415	et	4	main
sageli	doc_491521501944_item	2554416	et	3	main
torn	doc_491521501944_item	2554417	et	3	main
etteütlus	doc_491521501945_item	2554418	et	3	main
sügis	doc_491521501945_item	2554419	et	3	main
sügis	doc_491521501945_item	2554420	et	3	main
saabub	doc_491521501945_item	2554421	et	3	main
septembri	doc_491521501945_item	2554423	et	3	main
rohilised	doc_491521501945_item	2554432	et	4	main
on	doc_491521501945_item	2554442	et	4	main
korjatakse	doc_491521501945_item	2554452	et	3	main
adades	doc_491521501945_item	2554454	et	4	main
õunad	doc_491521501945_item	2554456	et	3	main
kured	doc_491521501945_item	2554473	et	3	main
haned	doc_491521501945_item	2554474	et	3	main
luiged	doc_491521501945_item	2554476	et	3	main
korjavad	doc_491521501945_item	2554478	et	4	main
talvevarusid	doc_491521501945_item	2554479	et	3	main
loodus	doc_491521501945_item	2554480	et	4	main
valmistub	doc_491521501945_item	2554481	et	3	main
vahel	doc_491521501945_item	2554490	et	4	main
nädalaid	doc_491521501945_item	2554491	et	3	main
mõnikord	doc_491521501945_item	2554492	et	3	main
on	doc_491521501945_item	2554425	et	4	main
puude	doc_491521501945_item	2554435	et	4	main
lehed	doc_491521501945_item	2554436	et	3	main
ja	doc_491521501945_item	2554438	et	3	main
inimesed	doc_491521501945_item	2554459	et	3	main
saaki	doc_491521501945_item	2554461	et	4	main
järjest	doc_491521501945_item	2554464	et	4	main
jahedumaks	doc_491521501945_item	2554465	et	4	main
on	doc_491521501945_item	2554467	et	4	main
öökülm	doc_491521501945_item	2554468	et	3	main
pudelt-põsastelt	doc_491521501945_item	2554469	et	4	main
talveks	doc_491521501945_item	2554482	et	4	main
hommikutti	doc_491521501945_item	2554483	et	4	main
on	doc_491521501945_item	2554493	et	4	main
sageli	doc_491521501945_item	2554494	et	3	main
torm	doc_491521501945_item	2554495	et	3	main
minevik	doc_491521501946_item	2554496	et	3	main
minevik	doc_491521501946_item	2554497	et	3	main
ootama	doc_491521501946_item	2554503	et	3	main
näitama	doc_491521501946_item	2554504	et	3	main
lendama	doc_491521501946_item	2554505	et	3	main
oskama	doc_491521501946_item	2554506	et	3	main
võistlema	doc_491521501946_item	2554507	et	3	main
märkama	doc_491521501946_item	2554508	et	3	main
täitma	doc_491521501946_item	2554509	et	3	main
kandma	doc_491521501946_item	2554510	et	3	main
kukkuma	doc_491521501946_item	2554511	et	3	main
tekkima	doc_491521501946_item	2554512	et	3	main
kinkima	doc_491521501946_item	2554513	et	3	main
tõlkima	doc_491521501946_item	2554514	et	3	main
ootasin	doc_491521501946_item	2554516	et	3	main
andsin	doc_491521501946_item	2554515	et	3	main
näitasin	doc_491521501946_item	2554517	et	3	main
lendasin	doc_491521501946_item	2554518	et	3	main
oskasin	doc_491521501946_item	2554519	et	3	main
võistlesin	doc_491521501946_item	2554520	et	3	main
täitsin	doc_491521501946_item	2554522	et	3	main
tõlkisin	doc_491521501946_item	2554527	et	3	main
andnud	doc_491521501946_item	2554529	et	4	main
ootanud	doc_491521501946_item	2554531	et	4	main
oskanud	doc_491521501946_item	2554537	et	4	main
ei	doc_491521501946_item	2554544	et	4	main
ei	doc_491521501946_item	2554552	et	4	main
kuidas	doc_491521501947_item	2554555	et	3	main
veetsin	doc_491521501947_item	2554557	et	3	main
olin	doc_491521501947_item	2554560	et	3	main
suvel	doc_491521501947_item	2554561	et	3	main
vahest	doc_491521501947_item	2554569	et	4	main
stop	doc_491521501947_item	2554582	et	4	main
ma	doc_491521501947_item	2554584	et	3	main
sõpru	doc_491521501947_item	2554603	et	3	main
vanaisa	doc_491521501947_item	2554628	et	4	main
meeldis	doc_491521501947_item	2554632	et	3	main
ma	doc_491521501947_item	2554634	et	3	main
on	doc_491521501947_item	2554643	et	4	main
soojemad	doc_491521501947_item	2554646	et	3	main
ja	doc_491521501947_item	2554648	et	3	main
ja	doc_491521501947_item	2554652	et	3	main
kõige	doc_491521501947_item	2554654	et	4	main
tähtsam	doc_491521501947_item	2554655	et	4	main
suvel	doc_491521501947_item	2554656	et	3	main
saab	doc_491521501947_item	2554657	et	3	main
kaua	doc_491521501947_item	2554658	et	3	main
näinud	doc_491521501946_item	2554533	et	4	main
ei	doc_491521501946_item	2554534	et	4	main
lendnud	doc_491521501946_item	2554535	et	4	main
märknud	doc_491521501946_item	2554541	et	4	main
täitnud	doc_491521501946_item	2554543	et	4	main
ei	doc_491521501946_item	2554546	et	4	main
tekkinud	doc_491521501946_item	2554549	et	4	main
kinknud	doc_491521501946_item	2554551	et	4	main
essee	doc_491521501947_item	2554554	et	4	main
ma	doc_491521501947_item	2554556	et	3	main
mina	doc_491521501947_item	2554559	et	4	main
pidin	doc_491521501947_item	2554570	et	3	main
on	doc_491521501947_item	2554589	et	4	main
iga	doc_491521501947_item	2554597	et	4	main
sugustel	doc_491521501947_item	2554598	et	3	main
sporti	doc_491521501947_item	2554613	et	4	main
sõitsin	doc_491521501947_item	2554614	et	3	main
jalgrattaga	doc_491521501947_item	2554615	et	3	main
ja	doc_491521501947_item	2554616	et	3	main
ma	doc_491521501947_item	2554617	et	3	main
armastan	doc_491521501947_item	2554618	et	3	main
mängima	doc_491521501947_item	2554619	et	3	main
võrkpallis	doc_491521501947_item	2554620	et	3	main
lõpus	doc_491521501947_item	2554622	et	4	main
käisin	doc_491521501947_item	2554623	et	3	main
väga	doc_491521501947_item	2554631	et	3	main
sain	doc_491521501947_item	2554635	et	3	main
kõige	doc_491521501947_item	2554645	et	4	main
pea	doc_491521501947_item	2554661	et	4	main
vara	doc_491521501947_item	2554662	et	4	main
ärkama	doc_491521501947_item	2554663	et	3	main
et	doc_491521501947_item	2554664	et	3	main
kooli	doc_491521501947_item	2554665	et	4	main
tulla	doc_491521501947_item	2554666	et	3	main
ma	doc_491521501948_item	2554674	et	3	main
minu	doc_491521501948_item	2554727	et	3	main
taskuraha	doc_491521501948_item	2554738	et	4	main
vanemate	doc_491521501948_item	2554739	et	4	main
käest	doc_491521501948_item	2554740	et	4	main
need	doc_491521501948_item	2554741	et	3	main
tarbimisele	doc_491521501948_item	2554748	et	4	main
hullem	doc_491521501948_item	2554752	et	4	main
et	doc_491521501948_item	2554753	et	3	main
mõned	doc_491521501948_item	2554754	et	3	main
narkotikud	doc_491521501948_item	2554758	et	3	main
suvel	doc_491521501948_item	2554770	et	3	main
nad	doc_491521501948_item	2554774	et	3	main
märkasin	doc_491521501946_item	2554521	et	3	main
kinkisin	doc_491521501946_item	2554526	et	3	main
ei	doc_491521501946_item	2554528	et	4	main
ei	doc_491521501946_item	2554530	et	4	main
ei	doc_491521501946_item	2554536	et	4	main
ei	doc_491521501946_item	2554540	et	4	main
kandnud	doc_491521501946_item	2554545	et	4	main
kukkunud	doc_491521501946_item	2554547	et	4	main
ei	doc_491521501946_item	2554550	et	4	main
tõlknud	doc_491521501946_item	2554553	et	4	main
ja	doc_491521501947_item	2554568	et	3	main
aia	doc_491521501947_item	2554572	et	4	main
tegema	doc_491521501947_item	2554574	et	3	main
ma	doc_491521501947_item	2554576	et	3	main
diskos	doc_491521501947_item	2554586	et	4	main
ulutustel	doc_491521501947_item	2554599	et	4	main
head	doc_491521501947_item	2554606	et	4	main
muusikat	doc_491521501947_item	2554607	et	3	main
kuulata	doc_491521501947_item	2554608	et	4	main
suvel	doc_491521501947_item	2554609	et	3	main
tegin	doc_491521501947_item	2554610	et	3	main
ma	doc_491521501947_item	2554611	et	3	main
ka	doc_491521501947_item	2554612	et	3	main
maal	doc_491521501947_item	2554562	et	4	main
seal	doc_491521501947_item	2554563	et	4	main
ma	doc_491521501947_item	2554564	et	3	main
sain	doc_491521501947_item	2554565	et	3	main
ujuda	doc_491521501947_item	2554566	et	3	main
päevitada	doc_491521501947_item	2554567	et	3	main
ka	doc_491521501947_item	2554571	et	3	main
kui	doc_491521501947_item	2554575	et	3	main
linnas	doc_491521501947_item	2554577	et	4	main
olin	doc_491521501947_item	2554578	et	3	main
käisin	doc_491521501947_item	2554579	et	3	main
suvekontsertitel	doc_491521501947_item	2554580	et	4	main
summer	doc_491521501947_item	2554581	et	3	main
suve	doc_491521501947_item	2554590	et	4	main
juures	doc_491521501947_item	2554591	et	4	main
see	doc_491521501947_item	2554592	et	3	main
hea	doc_491521501947_item	2554593	et	4	main
et	doc_491521501947_item	2554594	et	3	main
saab	doc_491521501947_item	2554595	et	3	main
käia	doc_491521501947_item	2554596	et	4	main
näeb	doc_491521501947_item	2554601	et	3	main
palju	doc_491521501947_item	2554602	et	4	main
ja	doc_491521501947_item	2554604	et	3	main
suve	doc_491521501947_item	2554621	et	4	main
perega	doc_491521501947_item	2554624	et	3	main
narvas	doc_491521501947_item	2554625	et	4	main
vanaema	doc_491521501947_item	2554626	et	4	main
ja	doc_491521501947_item	2554627	et	3	main
nii	doc_491521501947_item	2554636	et	3	main
uusi	doc_491521501947_item	2554638	et	3	main
narvast	doc_491521501947_item	2554640	et	4	main
rannad	doc_491521501947_item	2554647	et	3	main
ei	doc_491521501947_item	2554660	et	4	main
oma	doc_491521501948_item	2554668	et	4	main
jah	doc_491521501948_item	2554673	et	3	main
sellega	doc_491521501948_item	2554676	et	3	main
nõus	doc_491521501948_item	2554678	et	4	main
ma	doc_491521501948_item	2554679	et	3	main
ei	doc_491521501948_item	2554680	et	4	main
ja	doc_491521501948_item	2554714	et	3	main
töötama	doc_491521501948_item	2554715	et	3	main
aga	doc_491521501948_item	2554716	et	3	main
et	doc_491521501948_item	2554721	et	3	main
ma	doc_491521501948_item	2554724	et	3	main
soovin	doc_491521501948_item	2554725	et	3	main
minust	doc_491521501948_item	2554730	et	3	main
nad	doc_491521501948_item	2554743	et	3	main
kõige	doc_491521501948_item	2554751	et	4	main
noored	doc_491521501948_item	2554755	et	3	main
varastama	doc_491521501948_item	2554762	et	3	main
inimesed	doc_491521501948_item	2554766	et	3	main
või	doc_491521501948_item	2554771	et	4	main
külas	doc_491521501947_item	2554629	et	3	main
seal	doc_491521501947_item	2554633	et	4	main
palju	doc_491521501947_item	2554637	et	4	main
sõpru	doc_491521501947_item	2554639	et	3	main
minu	doc_491521501947_item	2554641	et	3	main
seal	doc_491521501947_item	2554644	et	4	main
mõnus	doc_491521501947_item	2554650	et	4	main
taskuraha	doc_491521501948_item	2554669	et	4	main
tuleb	doc_491521501948_item	2554670	et	3	main
mõistan	doc_491521501948_item	2554681	et	3	main
neid	doc_491521501948_item	2554682	et	4	main
noored	doc_491521501948_item	2554683	et	3	main
kes	doc_491521501948_item	2554684	et	4	main
küsivad	doc_491521501948_item	2554685	et	4	main
taskuraha	doc_491521501948_item	2554686	et	4	main
vanemate	doc_491521501948_item	2554687	et	4	main
käest	doc_491521501948_item	2554688	et	4	main
see	doc_491521501948_item	2554689	et	3	main
on	doc_491521501948_item	2554690	et	4	main
ebanormaalne	doc_491521501948_item	2554691	et	3	main
näiteks	doc_491521501948_item	2554692	et	4	main
mulle	doc_491521501948_item	2554693	et	4	main
on	doc_491521501948_item	2554694	et	4	main
häbi	doc_491521501948_item	2554695	et	4	main
küsida	doc_491521501948_item	2554696	et	3	main
ma	doc_491521501948_item	2554697	et	3	main
õpin	doc_491521501948_item	2554698	et	3	main
ja	doc_491521501948_item	2554699	et	3	main
töötan	doc_491521501948_item	2554700	et	3	main
teenindan	doc_491521501948_item	2554701	et	3	main
ise	doc_491521501948_item	2554702	et	4	main
raha	doc_491521501948_item	2554703	et	4	main
võin	doc_491521501948_item	2554704	et	3	main
teha	doc_491521501948_item	2554705	et	3	main
mida	doc_491521501948_item	2554706	et	4	main
tahan	doc_491521501948_item	2554707	et	3	main
aidatan	doc_491521501948_item	2554708	et	4	main
emale	doc_491521501948_item	2554709	et	3	main
muidugi	doc_491521501948_item	2554710	et	4	main
on	doc_491521501948_item	2554711	et	4	main
raske	doc_491521501948_item	2554712	et	4	main
õpima	doc_491521501948_item	2554713	et	4	main
magada	doc_491521501947_item	2554659	et	3	main
essee	doc_491521501948_item	2554667	et	4	main
ise	doc_491521501948_item	2554672	et	4	main
olen	doc_491521501948_item	2554675	et	3	main
täisti	doc_491521501948_item	2554677	et	4	main
ma	doc_491521501948_item	2554717	et	3	main
püüdma	doc_491521501948_item	2554720	et	3	main
mis	doc_491521501948_item	2554723	et	4	main
täidaksid	doc_491521501948_item	2554726	et	4	main
on	doc_491521501948_item	2554732	et	4	main
niisuguseid	doc_491521501948_item	2554734	et	3	main
suitsule	doc_491521501948_item	2554746	et	3	main
aga	doc_491521501948_item	2554749	et	3	main
inimesed	doc_491521501948_item	2554756	et	3	main
pärast	doc_491521501948_item	2554759	et	4	main
mida	doc_491521501948_item	2554763	et	4	main
need	doc_491521501948_item	2554765	et	3	main
püüdavad	doc_491521501948_item	2554768	et	4	main
suhelda	doc_491521501948_item	2554776	et	4	main
pean	doc_491521501948_item	2554718	et	4	main
tulevikus	doc_491521501948_item	2554728	et	4	main
näiteks	doc_491521501948_item	2554733	et	4	main
kes	doc_491521501948_item	2554736	et	4	main
küsivad	doc_491521501948_item	2554737	et	4	main
raha	doc_491521501948_item	2554742	et	4	main
pidule	doc_491521501948_item	2554745	et	3	main
alkohooli	doc_491521501948_item	2554747	et	3	main
hakkavad	doc_491521501948_item	2554761	et	4	main
sudavad	doc_491521501948_item	2554764	et	4	main
kes	doc_491521501948_item	2554767	et	4	main
töötada	doc_491521501948_item	2554769	et	3	main
kooli	doc_491521501948_item	2554772	et	4	main
ajal	doc_491521501948_item	2554773	et	4	main
õppivad	doc_491521501948_item	2554775	et	4	main
kõik	doc_491521501948_item	2554722	et	4	main
seotub	doc_491521501948_item	2554729	et	4	main
aga	doc_491521501948_item	2554731	et	3	main
noored	doc_491521501948_item	2554735	et	3	main
raiskavad	doc_491521501948_item	2554744	et	4	main
on	doc_491521501948_item	2554750	et	4	main
tarbivad	doc_491521501948_item	2554757	et	4	main
nad	doc_491521501948_item	2554760	et	3	main
lapsepõlves	doc_491521501953_item	2555392	et	4	main
luurajaks	doc_491521501953_item	2555396	et	4	main
tolleaegne	doc_491521501953_item	2555401	et	3	main
ärritab	doc_491521501953_item	2555434	et	3	main
välja	doc_491521501953_item	2555444	et	4	main
on	doc_491521501953_item	2555447	et	4	main
kokku	doc_491521501953_item	2555455	et	3	main
teie	doc_491521501953_item	2555460	et	4	main
ongi	doc_491521501953_item	2555465	et	4	main
see	doc_491521501953_item	2555466	et	3	main
minu	doc_491521501953_item	2555467	et	3	main
võitlus	doc_491521501953_item	2555469	et	3	main
nimel	doc_491521501953_item	2555471	et	3	main
rikkad	doc_491521501953_item	2555491	et	4	main
ja	doc_491521501953_item	2555492	et	3	main
küsimust	doc_491521501953_item	2555387	et	4	main
13	doc_491521501953_item	2555388	et	2	main
ka	doc_491521501953_item	2555399	et	3	main
suurimaks	doc_491521501953_item	2555421	et	4	main
ma	doc_491521501953_item	2555423	et	3	main
loodan	doc_491521501953_item	2555424	et	3	main
selline	doc_491521501953_item	2555426	et	4	main
saavutus	doc_491521501953_item	2555427	et	4	main
ootab	doc_491521501953_item	2555428	et	3	main
teid	doc_491521501953_item	2555433	et	4	main
valetamine	doc_491521501953_item	2555437	et	4	main
et	doc_491521501953_item	2555445	et	3	main
inimestega	doc_491521501953_item	2555454	et	3	main
puutumast	doc_491521501953_item	2555456	et	4	main
mis	doc_491521501953_item	2555457	et	4	main
praegune	doc_491521501953_item	2555468	et	3	main
selle	doc_491521501953_item	2555470	et	4	main
on	doc_491521501953_item	2555478	et	4	main
eestis	doc_491521501953_item	2555480	et	3	main
hea	doc_491521501953_item	2555481	et	4	main
elada	doc_491521501953_item	2555482	et	3	main
tahan	doc_491521501953_item	2555523	et	3	main
targemaks	doc_491521501953_item	2555529	et	4	main
tõsta	doc_491521501953_item	2555532	et	4	main
parim	doc_491521501953_item	2555542	et	4	main
puhkus	doc_491521501953_item	2555543	et	3	main
teie	doc_491521501953_item	2555551	et	4	main
peipsi-äärne	doc_491521501953_item	2555554	et	3	main
alajõe	doc_491521501953_item	2555556	et	3	main
vasknarva	doc_491521501953_item	2555558	et	4	main
mille	doc_491521501953_item	2555559	et	3	main
jaoks	doc_491521501953_item	2555560	et	4	main
kohtuasjades	doc_491521501953_item	2555566	et	3	main
siis	doc_491521501953_item	2555571	et	3	main
rohkem	doc_491521501953_item	2555577	et	4	main
ma	doc_491521501953_item	2555585	et	3	main
olen	doc_491521501953_item	2555586	et	3	main
loomult	doc_491521501953_item	2555587	et	3	main
seetõttu	doc_491521501953_item	2555592	et	3	main
oma	doc_491521501953_item	2555603	et	4	main
tugevaimaks	doc_491521501953_item	2555604	et	4	main
see	doc_491521501953_item	2555609	et	3	main
13	doc_491521501953_item	2555386	et	2	main
saada	doc_491521501953_item	2555393	et	4	main
unistasin	doc_491521501953_item	2555394	et	3	main
köitis	doc_491521501953_item	2555398	et	3	main
saavutuseks	doc_491521501953_item	2555422	et	4	main
et	doc_491521501953_item	2555425	et	3	main
mis	doc_491521501953_item	2555432	et	4	main
ja	doc_491521501953_item	2555436	et	3	main
küll	doc_491521501953_item	2555439	et	4	main
selliste	doc_491521501953_item	2555453	et	4	main
elu	doc_491521501953_item	2555461	et	4	main
pööraseim	doc_491521501953_item	2555462	et	4	main
et	doc_491521501953_item	2555472	et	3	main
kuid	doc_491521501953_item	2555485	et	4	main
ei	doc_491521501953_item	2555487	et	4	main
ole	doc_491521501953_item	2555488	et	4	main
need	doc_491521501953_item	2555489	et	3	main
ainult	doc_491521501953_item	2555490	et	4	main
osta	doc_491521501953_item	2555521	et	4	main
eelkõige	doc_491521501953_item	2555530	et	3	main
valitud	doc_491521501953_item	2555535	et	4	main
erialal	doc_491521501953_item	2555536	et	3	main
olla	doc_491521501953_item	2555544	et	3	main
looduses	doc_491521501953_item	2555548	et	4	main
milline	doc_491521501953_item	2555549	et	3	main
ida-virumaal	doc_491521501953_item	2555553	et	4	main
kant	doc_491521501953_item	2555555	et	3	main
karjamaa	doc_491521501953_item	2555557	et	4	main
kuna	doc_491521501953_item	2555564	et	3	main
inimesi	doc_491521501953_item	2555567	et	4	main
võimalikult	doc_491521501953_item	2555568	et	4	main
veelgi	doc_491521501953_item	2555581	et	4	main
paremini	doc_491521501953_item	2555582	et	4	main
valmistuda	doc_491521501953_item	2555583	et	3	main
kuid	doc_491521501953_item	2555584	et	4	main
inimene	doc_491521501953_item	2555590	et	3	main
harjunud	doc_491521501953_item	2555594	et	4	main
hilistel	doc_491521501953_item	2555598	et	3	main
omadust	doc_491521501953_item	2555601	et	4	main
peate	doc_491521501953_item	2555602	et	4	main
arvan	doc_491521501953_item	2555607	et	3	main
on	doc_491521501953_item	2555610	et	4	main
see	doc_491521501953_item	2555625	et	3	main
ma	doc_491521501953_item	2555627	et	3	main
olin	doc_491521501953_item	2555629	et	3	main
lootnud	doc_491521501953_item	2555630	et	4	main
ei	doc_491521501953_item	2555631	et	4	main
saada	doc_491521501953_item	2555395	et	4	main
tehtud	doc_491521501953_item	2555403	et	4	main
dessantväelasest	doc_491521501953_item	2555402	et	3	main
film	doc_491521501953_item	2555404	et	3	main
sööst	doc_491521501953_item	2555405	et	3	main
eritsooni	doc_491521501953_item	2555406	et	4	main
ja	doc_491521501953_item	2555407	et	3	main
tahtsin	doc_491521501953_item	2555408	et	3	main
saada	doc_491521501953_item	2555409	et	4	main
samasuguseks	doc_491521501953_item	2555410	et	4	main
nagu	doc_491521501953_item	2555411	et	3	main
nemad	doc_491521501953_item	2555412	et	3	main
aga	doc_491521501953_item	2555413	et	3	main
hiljem	doc_491521501953_item	2555414	et	3	main
huvid	doc_491521501953_item	2555415	et	3	main
muutusid	doc_491521501953_item	2555416	et	4	main
mida	doc_491521501953_item	2555417	et	4	main
peate	doc_491521501953_item	2555418	et	4	main
oma	doc_491521501953_item	2555419	et	4	main
elu	doc_491521501953_item	2555420	et	4	main
mind	doc_491521501953_item	2555429	et	4	main
veel	doc_491521501953_item	2555430	et	4	main
ütle	doc_491521501953_item	2555442	et	4	main
inimestele	doc_491521501953_item	2555443	et	3	main
kuid	doc_491521501953_item	2555450	et	4	main
hoidun	doc_491521501953_item	2555451	et	3	main
edaspidi	doc_491521501953_item	2555452	et	3	main
olnud	doc_491521501953_item	2555459	et	4	main
ilmselt	doc_491521501953_item	2555464	et	4	main
õhk	doc_491521501953_item	2555474	et	3	main
puhtaks	doc_491521501953_item	2555475	et	3	main
kellel	doc_491521501953_item	2555477	et	4	main
tänapäeva	doc_491521501953_item	2555479	et	4	main
öelda	doc_491521501953_item	2555484	et	4	main
palju	doc_491521501953_item	2555525	et	4	main
lugeda	doc_491521501953_item	2555526	et	3	main
oma	doc_491521501953_item	2555533	et	4	main
õigusteaduses	doc_491521501953_item	2555537	et	3	main
koos	doc_491521501953_item	2555545	et	4	main
perega	doc_491521501953_item	2555546	et	3	main
lemmikkoht	doc_491521501953_item	2555552	et	3	main
jätku	doc_491521501953_item	2555562	et	4	main
tundub	doc_491521501953_item	2555572	et	3	main
alati	doc_491521501953_item	2555573	et	4	main
oleks	doc_491521501953_item	2555575	et	3	main
natukene	doc_491521501953_item	2555576	et	4	main
tüüpi	doc_491521501953_item	2555589	et	4	main
et	doc_491521501953_item	2555608	et	3	main
päris	doc_491521501953_item	2555624	et	4	main
alguses	doc_491521501953_item	2555628	et	4	main
olen	doc_491521501953_item	2555646	et	3	main
tööd	doc_491521501953_item	2555650	et	4	main
saksamaal	doc_491521501953_item	2555654	et	4	main
parem	doc_491521501953_item	2555661	et	4	main
küsimust	doc_491521501953_item	2555389	et	4	main
kelleks	doc_491521501953_item	2555390	et	4	main
tahtsite	doc_491521501953_item	2555391	et	3	main
mind	doc_491521501953_item	2555397	et	4	main
väga	doc_491521501953_item	2555400	et	3	main
ees	doc_491521501953_item	2555431	et	4	main
reeturlus	doc_491521501953_item	2555435	et	4	main
ma	doc_491521501953_item	2555438	et	3	main
üldiselt	doc_491521501953_item	2555440	et	4	main
ei	doc_491521501953_item	2555441	et	4	main
nad	doc_491521501953_item	2555446	et	3	main
mind	doc_491521501953_item	2555448	et	4	main
petnud	doc_491521501953_item	2555449	et	4	main
on	doc_491521501953_item	2555458	et	4	main
tegu	doc_491521501953_item	2555463	et	4	main
kohlta-järve	doc_491521501953_item	2555473	et	4	main
saaks	doc_491521501953_item	2555476	et	3	main
raske	doc_491521501953_item	2555483	et	4	main
kindlasti	doc_491521501953_item	2555486	et	3	main
võimu	doc_491521501953_item	2555493	et	4	main
juures	doc_491521501953_item	2555494	et	4	main
olevad	doc_491521501953_item	2555495	et	4	main
inimesed	doc_491521501953_item	2555496	et	3	main
sest	doc_491521501953_item	2555497	et	4	main
mida	doc_491521501953_item	2555498	et	4	main
rohkem	doc_491521501953_item	2555499	et	4	main
raha	doc_491521501953_item	2555500	et	4	main
ja	doc_491521501953_item	2555501	et	3	main
võimu	doc_491521501953_item	2555502	et	4	main
on	doc_491521501953_item	2555503	et	4	main
käes	doc_491521501953_item	2555504	et	4	main
seda	doc_491521501953_item	2555505	et	3	main
rohkem	doc_491521501953_item	2555506	et	4	main
on	doc_491521501953_item	2555507	et	4	main
ka	doc_491521501953_item	2555508	et	3	main
probleeme	doc_491521501953_item	2555509	et	3	main
mille	doc_491521501953_item	2555510	et	3	main
peale	doc_491521501953_item	2555511	et	4	main
kulub	doc_491521501953_item	2555512	et	3	main
teil	doc_491521501953_item	2555513	et	4	main
kõige	doc_491521501953_item	2555514	et	4	main
rohkem	doc_491521501953_item	2555515	et	4	main
raha	doc_491521501953_item	2555516	et	4	main
kommunaalkulude	doc_491521501953_item	2555517	et	3	main
peale	doc_491521501953_item	2555518	et	4	main
mida	doc_491521501953_item	2555519	et	4	main
tahaksite	doc_491521501953_item	2555520	et	3	main
väga	doc_491521501953_item	2555524	et	3	main
et	doc_491521501953_item	2555527	et	3	main
taset	doc_491521501953_item	2555534	et	3	main
jaoks	doc_491521501953_item	2555541	et	4	main
ei	doc_491521501953_item	2555561	et	4	main
hästi	doc_491521501953_item	2555569	et	3	main
millist	doc_491521501953_item	2555600	et	3	main
ma	doc_491521501953_item	2555606	et	3	main
ole	doc_491521501953_item	2555621	et	4	main
mida	doc_491521501953_item	2555626	et	4	main
riigis	doc_491521501953_item	2555640	et	3	main
elanud	doc_491521501953_item	2555647	et	4	main
ma	doc_491521501953_item	2555522	et	3	main
saada	doc_491521501953_item	2555528	et	4	main
tahaks	doc_491521501953_item	2555531	et	3	main
mis	doc_491521501953_item	2555538	et	4	main
on	doc_491521501953_item	2555539	et	4	main
teie	doc_491521501953_item	2555540	et	4	main
kusagil	doc_491521501953_item	2555547	et	3	main
on	doc_491521501953_item	2555550	et	4	main
aega	doc_491521501953_item	2555563	et	4	main
tahan	doc_491521501953_item	2555565	et	3	main
aidata	doc_491521501953_item	2555570	et	4	main
et	doc_491521501953_item	2555574	et	3	main
aega	doc_491521501953_item	2555578	et	4	main
siis	doc_491521501953_item	2555579	et	3	main
jõuaks	doc_491521501953_item	2555580	et	3	main
öökulli	doc_491521501953_item	2555588	et	4	main
ja	doc_491521501953_item	2555591	et	3	main
olen	doc_491521501953_item	2555593	et	3	main
tööd	doc_491521501953_item	2555595	et	4	main
tegema	doc_491521501953_item	2555596	et	3	main
ka	doc_491521501953_item	2555597	et	3	main
öötundidel	doc_491521501953_item	2555599	et	3	main
küljeks	doc_491521501953_item	2555605	et	3	main
kord	doc_491521501953_item	2555623	et	4	main
ma	doc_491521501953_item	2555645	et	3	main
nii	doc_491521501953_item	2555651	et	3	main
ka	doc_491521501953_item	2555670	et	3	main
kas	doc_491521501953_item	2555672	et	3	main
horoskoope	doc_491521501953_item	2555674	et	3	main
ei	doc_491521501953_item	2555675	et	4	main
kellest	doc_491521501953_item	2555690	et	4	main
järjekindlus	doc_491521501953_item	2555611	et	4	main
viia	doc_491521501953_item	2555612	et	3	main
asjad	doc_491521501953_item	2555613	et	3	main
lõpuni	doc_491521501953_item	2555614	et	3	main
isegi	doc_491521501953_item	2555615	et	4	main
siis	doc_491521501953_item	2555616	et	3	main
kui	doc_491521501953_item	2555617	et	3	main
see	doc_491521501953_item	2555618	et	3	main
tulemus	doc_491521501953_item	2555619	et	3	main
ei	doc_491521501953_item	2555620	et	4	main
iga	doc_491521501953_item	2555622	et	4	main
ole	doc_491521501953_item	2555632	et	4	main
mul	doc_491521501953_item	2555633	et	3	main
kombeks	doc_491521501953_item	2555634	et	4	main
oma	doc_491521501953_item	2555635	et	4	main
ettevõtmisi	doc_491521501953_item	2555636	et	3	main
pooleli	doc_491521501953_item	2555637	et	3	main
ja	doc_491521501953_item	2555648	et	3	main
on	doc_491521501953_item	2555657	et	4	main
eestis	doc_491521501953_item	2555658	et	3	main
mul	doc_491521501953_item	2555659	et	3	main
öeldut	doc_491521501953_item	2555665	et	4	main
kus	doc_491521501953_item	2555666	et	3	main
peab	doc_491521501953_item	2555669	et	4	main
usu	doc_491521501953_item	2555678	et	4	main
nendest	doc_491521501953_item	2555682	et	4	main
see	doc_491521501953_item	2555683	et	3	main
ei	doc_491521501953_item	2555684	et	4	main
iseloomusta	doc_491521501953_item	2555688	et	4	main
inimest	doc_491521501953_item	2555689	et	3	main
intervjueeritav	doc_491521501953_item	2555694	et	4	main
on	doc_491521501953_item	2555695	et	4	main
mees	doc_491521501953_item	2555696	et	4	main
või	doc_491521501953_item	2555697	et	4	main
naine	doc_491521501953_item	2555698	et	3	main
ma	doc_491521501953_item	2555699	et	3	main
arvan	doc_491521501953_item	2555700	et	3	main
et	doc_491521501953_item	2555701	et	3	main
see	doc_491521501953_item	2555702	et	3	main
on	doc_491521501953_item	2555703	et	4	main
mees	doc_491521501953_item	2555704	et	4	main
2	doc_491521501953_item	2555705	et	2	main
kes	doc_491521501953_item	2555706	et	4	main
ta	doc_491521501953_item	2555707	et	4	main
on	doc_491521501953_item	2555708	et	4	main
elukutselt	doc_491521501953_item	2555709	et	4	main
ta	doc_491521501953_item	2555710	et	4	main
on	doc_491521501953_item	2555711	et	4	main
juurist	doc_491521501953_item	2555712	et	3	main
3	doc_491521501953_item	2555713	et	2	main
missugune	doc_491521501953_item	2555714	et	3	main
ta	doc_491521501953_item	2555715	et	4	main
on	doc_491521501953_item	2555716	et	4	main
oma	doc_491521501953_item	2555717	et	4	main
iseloomult	doc_491521501953_item	2555718	et	3	main
ma	doc_491521501953_item	2555719	et	3	main
arvan	doc_491521501953_item	2555720	et	3	main
reeturlus	doc_491521501953_item	2555725	et	4	main
kus	doc_491521501953_item	2555729	et	3	main
võiks	doc_491521501953_item	2555731	et	4	main
sinu	doc_491521501953_item	2555732	et	3	main
arvates	doc_491521501953_item	2555733	et	4	main
töötada	doc_491521501953_item	2555734	et	3	main
see	doc_491521501953_item	2555735	et	3	main
loodus	doc_491521501953_item	2555744	et	4	main
tugevad	doc_491521501953_item	2555763	et	4	main
jätta	doc_491521501953_item	2555638	et	3	main
millises	doc_491521501953_item	2555639	et	3	main
peale	doc_491521501953_item	2555641	et	4	main
eesti	doc_491521501953_item	2555642	et	4	main
tahaksite	doc_491521501953_item	2555643	et	3	main
elada	doc_491521501953_item	2555644	et	3	main
venemaal	doc_491521501953_item	2555652	et	4	main
kui	doc_491521501953_item	2555653	et	3	main
kuid	doc_491521501953_item	2555655	et	4	main
siiski	doc_491521501953_item	2555656	et	4	main
oma	doc_491521501953_item	2555663	et	4	main
isa	doc_491521501953_item	2555664	et	4	main
elama	doc_491521501953_item	2555671	et	3	main
loete	doc_491521501953_item	2555673	et	4	main
neid	doc_491521501953_item	2555679	et	4	main
ole	doc_491521501953_item	2555685	et	4	main
tõsine	doc_491521501953_item	2555686	et	4	main
1	doc_491521501953_item	2555692	et	2	main
et	doc_491521501953_item	2555721	et	3	main
on	doc_491521501953_item	2555723	et	4	main
valetamine	doc_491521501953_item	2555727	et	4	main
ja	doc_491521501953_item	2555742	et	3	main
harjutud	doc_491521501953_item	2555753	et	4	main
tegema	doc_491521501953_item	2555755	et	3	main
öötundidel	doc_491521501953_item	2555758	et	3	main
missugused	doc_491521501953_item	2555760	et	3	main
arvan	doc_491521501953_item	2555766	et	3	main
asjad	doc_491521501953_item	2555772	et	3	main
12c	doc_491521501953_item	2555774	et	4	main
samasuguseks	doc_491521501954_item	2555799	et	4	main
muutusid	doc_491521501954_item	2555805	et	4	main
ma	doc_491521501954_item	2555812	et	3	main
mind	doc_491521501954_item	2555818	et	4	main
ees	doc_491521501954_item	2555820	et	4	main
teinud	doc_491521501953_item	2555649	et	4	main
kõige	doc_491521501953_item	2555660	et	4	main
sündisid	doc_491521501953_item	2555667	et	4	main
ma	doc_491521501953_item	2555676	et	3	main
ega	doc_491521501953_item	2555680	et	3	main
kas	doc_491521501953_item	2555693	et	3	main
mees	doc_491521501953_item	2555736	et	4	main
arvatab	doc_491521501953_item	2555737	et	4	main
töötada	doc_491521501953_item	2555738	et	3	main
värske	doc_491521501953_item	2555743	et	4	main
missugused	doc_491521501953_item	2555746	et	3	main
tema	doc_491521501953_item	2555748	et	4	main
tööharjumused	doc_491521501953_item	2555749	et	3	main
tema	doc_491521501953_item	2555750	et	4	main
tööd	doc_491521501953_item	2555754	et	4	main
hilistel	doc_491521501953_item	2555757	et	3	main
6	doc_491521501953_item	2555759	et	2	main
ma	doc_491521501953_item	2555765	et	3	main
suurimaks	doc_491521501954_item	2555810	et	4	main
selline	doc_491521501954_item	2555815	et	4	main
ärritab	doc_491521501954_item	2555823	et	3	main
üldiselt	doc_491521501954_item	2555829	et	4	main
ei	doc_491521501954_item	2555830	et	4	main
on	doc_491521501954_item	2555836	et	4	main
hoidun	doc_491521501954_item	2555840	et	3	main
inimestega	doc_491521501954_item	2555843	et	3	main
puutumast	doc_491521501954_item	2555845	et	4	main
mis	doc_491521501954_item	2555846	et	4	main
pööraseim	doc_491521501954_item	2555851	et	4	main
ilmselt	doc_491521501954_item	2555853	et	4	main
selle	doc_491521501954_item	2555859	et	4	main
kellel	doc_491521501954_item	2555866	et	4	main
on	doc_491521501954_item	2555867	et	4	main
käes	doc_491521501954_item	2555893	et	4	main
seda	doc_491521501954_item	2555894	et	3	main
väga	doc_491521501954_item	2555913	et	3	main
lugeda	doc_491521501954_item	2555915	et	3	main
saada	doc_491521501954_item	2555917	et	4	main
järgin	doc_491521501953_item	2555662	et	3	main
seal	doc_491521501953_item	2555668	et	4	main
ei	doc_491521501953_item	2555677	et	4	main
huvitu	doc_491521501953_item	2555681	et	4	main
asi	doc_491521501953_item	2555687	et	4	main
kirjutatakse	doc_491521501953_item	2555691	et	3	main
ta	doc_491521501953_item	2555722	et	4	main
ärritab	doc_491521501953_item	2555724	et	3	main
ta	doc_491521501953_item	2555730	et	4	main
värske	doc_491521501953_item	2555740	et	4	main
õhk	doc_491521501953_item	2555741	et	3	main
5	doc_491521501953_item	2555745	et	2	main
on	doc_491521501953_item	2555747	et	4	main
küljed	doc_491521501953_item	2555764	et	3	main
see	doc_491521501953_item	2555768	et	3	main
järjekindlustus	doc_491521501953_item	2555770	et	3	main
lõpuni	doc_491521501953_item	2555773	et	3	main
nemad	doc_491521501954_item	2555801	et	3	main
huvid	doc_491521501954_item	2555804	et	3	main
peate	doc_491521501954_item	2555807	et	4	main
loodan	doc_491521501954_item	2555813	et	3	main
veel	doc_491521501954_item	2555819	et	4	main
mis	doc_491521501954_item	2555821	et	4	main
ütle	doc_491521501954_item	2555831	et	4	main
inimestele	doc_491521501954_item	2555832	et	3	main
kuid	doc_491521501954_item	2555839	et	4	main
selliste	doc_491521501954_item	2555842	et	4	main
kokku	doc_491521501954_item	2555844	et	3	main
ongi	doc_491521501954_item	2555854	et	4	main
praegune	doc_491521501954_item	2555857	et	3	main
võimu	doc_491521501954_item	2555891	et	4	main
on	doc_491521501954_item	2555896	et	4	main
raha	doc_491521501954_item	2555905	et	4	main
kommunaalkulude	doc_491521501954_item	2555906	et	3	main
peale	doc_491521501954_item	2555907	et	4	main
on	doc_491521501954_item	2555928	et	4	main
teie	doc_491521501954_item	2555940	et	4	main
lemmikkoht	doc_491521501954_item	2555941	et	3	main
vasknarva	doc_491521501954_item	2555947	et	4	main
ei	doc_491521501954_item	2555950	et	4	main
jätku	doc_491521501954_item	2555951	et	4	main
aega	doc_491521501954_item	2555952	et	4	main
kuna	doc_491521501954_item	2555953	et	3	main
tahan	doc_491521501954_item	2555954	et	3	main
kohtuasjades	doc_491521501954_item	2555955	et	3	main
ja	doc_491521501954_item	2555980	et	3	main
seetõttu	doc_491521501954_item	2555981	et	3	main
olen	doc_491521501954_item	2555982	et	3	main
oma	doc_491521501954_item	2555992	et	4	main
on	doc_491521501954_item	2555999	et	4	main
lõpuni	doc_491521501954_item	2556003	et	3	main
iga	doc_491521501954_item	2556011	et	4	main
eesti	doc_491521501954_item	2556032	et	4	main
olen	doc_491521501954_item	2556036	et	3	main
ja	doc_491521501954_item	2556038	et	3	main
tööd	doc_491521501954_item	2556040	et	4	main
nii	doc_491521501954_item	2556041	et	3	main
venemaal	doc_491521501954_item	2556042	et	4	main
kui	doc_491521501954_item	2556043	et	3	main
mul	doc_491521501954_item	2556049	et	3	main
ma	doc_491521501954_item	2556078	et	3	main
on	doc_491521501954_item	2556082	et	4	main
võib	doc_491521501954_item	2556084	et	3	main
ta	doc_491521501954_item	2556090	et	4	main
inimesi	doc_491521501954_item	2556093	et	4	main
oma	doc_491521501954_item	2556100	et	4	main
igas	doc_491521501954_item	2556102	et	3	main
tugevat	doc_491521501954_item	2556105	et	4	main
küljed	doc_491521501954_item	2556106	et	3	main
tal	doc_491521501954_item	2556107	et	3	main
on	doc_491521501954_item	2556108	et	4	main
ka	doc_491521501954_item	2556109	et	3	main
iga	doc_491521501954_item	2556117	et	4	main
see	doc_491521501954_item	2556120	et	3	main
lootnud	doc_491521501954_item	2556125	et	4	main
tegema	doc_491521501954_item	2556133	et	3	main
13	doc_491521501955_item	2556139	et	2	main
tehtud	doc_491521501955_item	2556154	et	4	main
eritsooni	doc_491521501955_item	2556157	et	4	main
saada	doc_491521501955_item	2556160	et	4	main
samasuguseks	doc_491521501955_item	2556161	et	4	main
nagu	doc_491521501955_item	2556162	et	3	main
ja	doc_491521501953_item	2555726	et	3	main
4	doc_491521501953_item	2555728	et	2	main
on	doc_491521501953_item	2555739	et	4	main
tööharjumused	doc_491521501953_item	2555751	et	3	main
on	doc_491521501953_item	2555752	et	4	main
ka	doc_491521501953_item	2555756	et	3	main
on	doc_491521501953_item	2555761	et	4	main
tema	doc_491521501953_item	2555762	et	4	main
et	doc_491521501953_item	2555767	et	3	main
on	doc_491521501953_item	2555769	et	4	main
viia	doc_491521501953_item	2555771	et	3	main
13	doc_491521501954_item	2555775	et	2	main
küsimust	doc_491521501954_item	2555776	et	4	main
13	doc_491521501954_item	2555777	et	2	main
küsimust	doc_491521501954_item	2555778	et	4	main
kelleks	doc_491521501954_item	2555779	et	4	main
tahtsite	doc_491521501954_item	2555780	et	3	main
lapsepõlves	doc_491521501954_item	2555781	et	4	main
saada	doc_491521501954_item	2555782	et	4	main
unistasin	doc_491521501954_item	2555783	et	3	main
saada	doc_491521501954_item	2555784	et	4	main
luurajaks	doc_491521501954_item	2555785	et	4	main
mind	doc_491521501954_item	2555786	et	4	main
köitis	doc_491521501954_item	2555787	et	3	main
ka	doc_491521501954_item	2555788	et	3	main
väga	doc_491521501954_item	2555789	et	3	main
tolleaegne	doc_491521501954_item	2555790	et	3	main
dessantväelasest	doc_491521501954_item	2555791	et	3	main
tehtud	doc_491521501954_item	2555792	et	4	main
film	doc_491521501954_item	2555793	et	3	main
sööst	doc_491521501954_item	2555794	et	3	main
eritsooni	doc_491521501954_item	2555795	et	4	main
ja	doc_491521501954_item	2555796	et	3	main
tahtsin	doc_491521501954_item	2555797	et	3	main
saada	doc_491521501954_item	2555798	et	4	main
nagu	doc_491521501954_item	2555800	et	3	main
aga	doc_491521501954_item	2555802	et	3	main
mida	doc_491521501954_item	2555806	et	4	main
oma	doc_491521501954_item	2555808	et	4	main
elu	doc_491521501954_item	2555809	et	4	main
et	doc_491521501954_item	2555814	et	3	main
ja	doc_491521501954_item	2555825	et	3	main
petnud	doc_491521501954_item	2555838	et	4	main
teie	doc_491521501954_item	2555849	et	4	main
tegu	doc_491521501954_item	2555852	et	4	main
see	doc_491521501954_item	2555855	et	3	main
minu	doc_491521501954_item	2555856	et	3	main
võitlus	doc_491521501954_item	2555858	et	3	main
kohlta-järve	doc_491521501954_item	2555862	et	4	main
puhtaks	doc_491521501954_item	2555864	et	3	main
on	doc_491521501954_item	2555892	et	4	main
ka	doc_491521501954_item	2555897	et	3	main
peale	doc_491521501954_item	2555900	et	4	main
kulub	doc_491521501954_item	2555901	et	3	main
kõige	doc_491521501954_item	2555903	et	4	main
rohkem	doc_491521501954_item	2555904	et	4	main
ma	doc_491521501954_item	2555911	et	3	main
targemaks	doc_491521501954_item	2555918	et	4	main
eelkõige	doc_491521501954_item	2555919	et	3	main
tahaks	doc_491521501954_item	2555920	et	3	main
oma	doc_491521501954_item	2555922	et	4	main
taset	doc_491521501954_item	2555923	et	3	main
õigusteaduses	doc_491521501954_item	2555926	et	3	main
mis	doc_491521501954_item	2555927	et	4	main
jaoks	doc_491521501954_item	2555930	et	4	main
puhkus	doc_491521501954_item	2555932	et	3	main
olla	doc_491521501954_item	2555933	et	3	main
mille	doc_491521501954_item	2555948	et	3	main
aidata	doc_491521501954_item	2555959	et	4	main
tundub	doc_491521501954_item	2555961	et	3	main
et	doc_491521501954_item	2555963	et	3	main
ma	doc_491521501954_item	2555995	et	3	main
et	doc_491521501954_item	2555997	et	3	main
järjekindlus	doc_491521501954_item	2556000	et	4	main
viia	doc_491521501954_item	2556001	et	3	main
isegi	doc_491521501954_item	2556004	et	4	main
siis	doc_491521501954_item	2556005	et	3	main
kui	doc_491521501954_item	2556006	et	3	main
see	doc_491521501954_item	2556007	et	3	main
tulemus	doc_491521501954_item	2556008	et	3	main
ei	doc_491521501954_item	2556009	et	4	main
ei	doc_491521501954_item	2556020	et	4	main
hiljem	doc_491521501954_item	2555803	et	3	main
saavutuseks	doc_491521501954_item	2555811	et	4	main
saavutus	doc_491521501954_item	2555816	et	4	main
ootab	doc_491521501954_item	2555817	et	3	main
reeturlus	doc_491521501954_item	2555824	et	4	main
valetamine	doc_491521501954_item	2555826	et	4	main
küll	doc_491521501954_item	2555828	et	4	main
et	doc_491521501954_item	2555834	et	3	main
nad	doc_491521501954_item	2555835	et	3	main
mind	doc_491521501954_item	2555837	et	4	main
olnud	doc_491521501954_item	2555848	et	4	main
et	doc_491521501954_item	2555861	et	3	main
tänapäeva	doc_491521501954_item	2555868	et	4	main
probleeme	doc_491521501954_item	2555898	et	3	main
teil	doc_491521501954_item	2555902	et	4	main
mida	doc_491521501954_item	2555908	et	4	main
tahaksite	doc_491521501954_item	2555909	et	3	main
osta	doc_491521501954_item	2555910	et	4	main
palju	doc_491521501954_item	2555914	et	4	main
on	doc_491521501954_item	2555939	et	4	main
hästi	doc_491521501954_item	2555958	et	3	main
oleks	doc_491521501954_item	2555964	et	3	main
tüüpi	doc_491521501954_item	2555978	et	4	main
harjunud	doc_491521501954_item	2555983	et	4	main
tööd	doc_491521501954_item	2555984	et	4	main
tegema	doc_491521501954_item	2555985	et	3	main
ka	doc_491521501954_item	2555986	et	3	main
hilistel	doc_491521501954_item	2555987	et	3	main
öötundidel	doc_491521501954_item	2555988	et	3	main
millist	doc_491521501954_item	2555989	et	3	main
omadust	doc_491521501954_item	2555990	et	4	main
tugevaimaks	doc_491521501954_item	2555993	et	4	main
arvan	doc_491521501954_item	2555996	et	3	main
see	doc_491521501954_item	2555998	et	3	main
asjad	doc_491521501954_item	2556002	et	3	main
kord	doc_491521501954_item	2556012	et	4	main
see	doc_491521501954_item	2556014	et	3	main
mida	doc_491521501954_item	2556015	et	4	main
ma	doc_491521501954_item	2556016	et	3	main
alguses	doc_491521501954_item	2556017	et	4	main
kombeks	doc_491521501954_item	2556023	et	4	main
ettevõtmisi	doc_491521501954_item	2556025	et	3	main
span	doc_491521501954_item	2556028	et	4	main
elada	doc_491521501954_item	2556034	et	3	main
teinud	doc_491521501954_item	2556039	et	4	main
on	doc_491521501954_item	2556047	et	4	main
eestis	doc_491521501954_item	2556048	et	3	main
kõige	doc_491521501954_item	2556050	et	4	main
oma	doc_491521501954_item	2556053	et	4	main
huvitu	doc_491521501954_item	2556071	et	4	main
see	doc_491521501954_item	2556073	et	3	main
ole	doc_491521501954_item	2556075	et	4	main
tõsine	doc_491521501954_item	2556076	et	4	main
et	doc_491521501954_item	2556080	et	3	main
hästi	doc_491521501954_item	2556094	et	3	main
on	doc_491521501954_item	2556097	et	4	main
armastab	doc_491521501954_item	2556099	et	3	main
inimes	doc_491521501954_item	2556103	et	4	main
on	doc_491521501954_item	2556104	et	4	main
kord	doc_491521501954_item	2556118	et	4	main
teid	doc_491521501954_item	2555822	et	4	main
ma	doc_491521501954_item	2555827	et	3	main
välja	doc_491521501954_item	2555833	et	4	main
edaspidi	doc_491521501954_item	2555841	et	3	main
on	doc_491521501954_item	2555847	et	4	main
elu	doc_491521501954_item	2555850	et	4	main
nimel	doc_491521501954_item	2555860	et	3	main
õhk	doc_491521501954_item	2555863	et	3	main
saaks	doc_491521501954_item	2555865	et	3	main
eestis	doc_491521501954_item	2555869	et	3	main
hea	doc_491521501954_item	2555870	et	4	main
elada	doc_491521501954_item	2555871	et	3	main
raske	doc_491521501954_item	2555872	et	4	main
öelda	doc_491521501954_item	2555873	et	4	main
kuid	doc_491521501954_item	2555874	et	4	main
kindlasti	doc_491521501954_item	2555875	et	3	main
ei	doc_491521501954_item	2555876	et	4	main
ole	doc_491521501954_item	2555877	et	4	main
need	doc_491521501954_item	2555878	et	3	main
ainult	doc_491521501954_item	2555879	et	4	main
rikkad	doc_491521501954_item	2555880	et	4	main
ja	doc_491521501954_item	2555881	et	3	main
võimu	doc_491521501954_item	2555882	et	4	main
juures	doc_491521501954_item	2555883	et	4	main
olevad	doc_491521501954_item	2555884	et	4	main
inimesed	doc_491521501954_item	2555885	et	3	main
sest	doc_491521501954_item	2555886	et	4	main
mida	doc_491521501954_item	2555887	et	4	main
rohkem	doc_491521501954_item	2555888	et	4	main
raha	doc_491521501954_item	2555889	et	4	main
ja	doc_491521501954_item	2555890	et	3	main
rohkem	doc_491521501954_item	2555895	et	4	main
mille	doc_491521501954_item	2555899	et	3	main
tahan	doc_491521501954_item	2555912	et	3	main
et	doc_491521501954_item	2555916	et	3	main
tõsta	doc_491521501954_item	2555921	et	4	main
ida-virumaal	doc_491521501954_item	2555942	et	4	main
peipsi-äärne	doc_491521501954_item	2555943	et	3	main
kant	doc_491521501954_item	2555944	et	3	main
alajõe	doc_491521501954_item	2555945	et	3	main
inimesi	doc_491521501954_item	2555956	et	4	main
loomult	doc_491521501954_item	2555976	et	3	main
inimene	doc_491521501954_item	2555979	et	3	main
küljeks	doc_491521501954_item	2555994	et	3	main
ole	doc_491521501954_item	2556010	et	4	main
päris	doc_491521501954_item	2556013	et	4	main
ole	doc_491521501954_item	2556021	et	4	main
jätta	doc_491521501954_item	2556027	et	3	main
riigis	doc_491521501954_item	2556030	et	3	main
ma	doc_491521501954_item	2556035	et	3	main
saksamaal	doc_491521501954_item	2556044	et	4	main
neid	doc_491521501954_item	2556069	et	4	main
asi	doc_491521501954_item	2556077	et	4	main
arvan	doc_491521501954_item	2556079	et	3	main
mees	doc_491521501954_item	2556083	et	4	main
et	doc_491521501954_item	2556086	et	3	main
ta	doc_491521501954_item	2556087	et	4	main
töötab	doc_491521501954_item	2556088	et	3	main
juriiks	doc_491521501954_item	2556089	et	4	main
aidata	doc_491521501954_item	2556095	et	4	main
isegi	doc_491521501954_item	2556110	et	4	main
siis	doc_491521501954_item	2556111	et	3	main
kui	doc_491521501954_item	2556112	et	3	main
see	doc_491521501954_item	2556113	et	3	main
ta	doc_491521501954_item	2556128	et	4	main
hilistel	doc_491521501954_item	2556135	et	3	main
kelleks	doc_491521501955_item	2556141	et	4	main
lapsepõlves	doc_491521501955_item	2556143	et	4	main
unistasin	doc_491521501955_item	2556145	et	3	main
väga	doc_491521501955_item	2556151	et	3	main
dessantväelasest	doc_491521501955_item	2556153	et	3	main
tahtsin	doc_491521501955_item	2556159	et	3	main
oma	doc_491521501955_item	2556170	et	4	main
selline	doc_491521501955_item	2556177	et	4	main
ees	doc_491521501955_item	2556182	et	4	main
teid	doc_491521501955_item	2556184	et	4	main
ärritab	doc_491521501955_item	2556185	et	3	main
reeturlus	doc_491521501955_item	2556186	et	4	main
ja	doc_491521501955_item	2556187	et	3	main
on	doc_491521501955_item	2556198	et	4	main
edaspidi	doc_491521501955_item	2556203	et	3	main
kokku	doc_491521501955_item	2556206	et	3	main
mis	doc_491521501955_item	2556208	et	4	main
see	doc_491521501955_item	2556217	et	3	main
minu	doc_491521501955_item	2556218	et	3	main
tänapäeva	doc_491521501955_item	2556230	et	4	main
eestis	doc_491521501955_item	2556231	et	3	main
ainult	doc_491521501955_item	2556241	et	4	main
rikkad	doc_491521501955_item	2556242	et	4	main
ja	doc_491521501955_item	2556243	et	3	main
võimu	doc_491521501955_item	2556244	et	4	main
rohkem	doc_491521501955_item	2556250	et	4	main
raha	doc_491521501955_item	2556251	et	4	main
ja	doc_491521501955_item	2556252	et	3	main
raha	doc_491521501955_item	2556267	et	4	main
tahaksite	doc_491521501955_item	2556271	et	3	main
vasknarva	doc_491521501955_item	2556309	et	4	main
jaoks	doc_491521501955_item	2556311	et	4	main
ei	doc_491521501955_item	2556312	et	4	main
kohtuasjades	doc_491521501955_item	2556317	et	3	main
võimalikult	doc_491521501955_item	2556319	et	4	main
alati	doc_491521501955_item	2556324	et	4	main
et	doc_491521501955_item	2556325	et	3	main
oleks	doc_491521501955_item	2556326	et	3	main
rohkem	doc_491521501955_item	2556328	et	4	main
ma	doc_491521501955_item	2556336	et	3	main
tüüpi	doc_491521501955_item	2556340	et	4	main
tööd	doc_491521501955_item	2556346	et	4	main
tegema	doc_491521501955_item	2556347	et	3	main
ka	doc_491521501955_item	2556348	et	3	main
hilistel	doc_491521501955_item	2556349	et	3	main
öötundidel	doc_491521501955_item	2556350	et	3	main
valitud	doc_491521501954_item	2555924	et	4	main
erialal	doc_491521501954_item	2555925	et	3	main
teie	doc_491521501954_item	2555929	et	4	main
parim	doc_491521501954_item	2555931	et	4	main
koos	doc_491521501954_item	2555934	et	4	main
perega	doc_491521501954_item	2555935	et	3	main
kusagil	doc_491521501954_item	2555936	et	3	main
looduses	doc_491521501954_item	2555937	et	4	main
milline	doc_491521501954_item	2555938	et	3	main
karjamaa	doc_491521501954_item	2555946	et	4	main
jaoks	doc_491521501954_item	2555949	et	4	main
võimalikult	doc_491521501954_item	2555957	et	4	main
siis	doc_491521501954_item	2555960	et	3	main
alati	doc_491521501954_item	2555962	et	4	main
natukene	doc_491521501954_item	2555965	et	4	main
rohkem	doc_491521501954_item	2555966	et	4	main
aega	doc_491521501954_item	2555967	et	4	main
siis	doc_491521501954_item	2555968	et	3	main
jõuaks	doc_491521501954_item	2555969	et	3	main
veelgi	doc_491521501954_item	2555970	et	4	main
paremini	doc_491521501954_item	2555971	et	4	main
valmistuda	doc_491521501954_item	2555972	et	3	main
kuid	doc_491521501954_item	2555973	et	4	main
ma	doc_491521501954_item	2555974	et	3	main
olen	doc_491521501954_item	2555975	et	3	main
öökulli	doc_491521501954_item	2555977	et	4	main
peate	doc_491521501954_item	2555991	et	4	main
olin	doc_491521501954_item	2556018	et	3	main
lootnud	doc_491521501954_item	2556019	et	4	main
mul	doc_491521501954_item	2556022	et	3	main
pooleli	doc_491521501954_item	2556026	et	3	main
tahaksite	doc_491521501954_item	2556033	et	3	main
elanud	doc_491521501954_item	2556037	et	4	main
siiski	doc_491521501954_item	2556046	et	4	main
järgin	doc_491521501954_item	2556052	et	3	main
usu	doc_491521501954_item	2556068	et	4	main
nendest	doc_491521501954_item	2556072	et	4	main
intervjueeritav	doc_491521501954_item	2556081	et	4	main
olla	doc_491521501954_item	2556085	et	3	main
ta	doc_491521501954_item	2556096	et	4	main
targemaks	doc_491521501954_item	2556098	et	4	main
pere	doc_491521501954_item	2556101	et	4	main
ole	doc_491521501954_item	2556116	et	4	main
päris	doc_491521501954_item	2556119	et	4	main
alguses	doc_491521501954_item	2556123	et	4	main
on	doc_491521501954_item	2556129	et	4	main
öötundidel	doc_491521501954_item	2556136	et	3	main
küsimust	doc_491521501955_item	2556140	et	4	main
tahtsite	doc_491521501955_item	2556142	et	3	main
saada	doc_491521501955_item	2556146	et	4	main
luurajaks	doc_491521501955_item	2556147	et	4	main
film	doc_491521501955_item	2556155	et	3	main
ja	doc_491521501955_item	2556158	et	3	main
peate	doc_491521501955_item	2556169	et	4	main
ma	doc_491521501955_item	2556174	et	3	main
loodan	doc_491521501955_item	2556175	et	3	main
et	doc_491521501955_item	2556176	et	3	main
mind	doc_491521501955_item	2556180	et	4	main
mis	doc_491521501955_item	2556183	et	4	main
küll	doc_491521501955_item	2556190	et	4	main
ütle	doc_491521501955_item	2556193	et	4	main
inimestele	doc_491521501955_item	2556194	et	3	main
välja	doc_491521501955_item	2556195	et	4	main
et	doc_491521501955_item	2556196	et	3	main
nad	doc_491521501955_item	2556197	et	3	main
hoidun	doc_491521501955_item	2556202	et	3	main
elu	doc_491521501955_item	2556212	et	4	main
pööraseim	doc_491521501955_item	2556213	et	4	main
võitlus	doc_491521501955_item	2556220	et	3	main
nimel	doc_491521501955_item	2556222	et	3	main
raske	doc_491521501955_item	2556234	et	4	main
juures	doc_491521501955_item	2556245	et	4	main
olevad	doc_491521501955_item	2556246	et	4	main
inimesed	doc_491521501955_item	2556247	et	3	main
võimu	doc_491521501955_item	2556253	et	4	main
on	doc_491521501955_item	2556258	et	4	main
ka	doc_491521501955_item	2556259	et	3	main
probleeme	doc_491521501955_item	2556260	et	3	main
mille	doc_491521501955_item	2556261	et	3	main
peale	doc_491521501955_item	2556262	et	4	main
kulub	doc_491521501955_item	2556263	et	3	main
kommunaalkulude	doc_491521501955_item	2556268	et	3	main
osta	doc_491521501955_item	2556272	et	4	main
väga	doc_491521501955_item	2556275	et	3	main
kant	doc_491521501955_item	2556306	et	3	main
jätku	doc_491521501955_item	2556313	et	4	main
oma	doc_491521501954_item	2556024	et	4	main
millises	doc_491521501954_item	2556029	et	3	main
peale	doc_491521501954_item	2556031	et	4	main
kuid	doc_491521501954_item	2556045	et	4	main
parem	doc_491521501954_item	2556051	et	4	main
isa	doc_491521501954_item	2556054	et	4	main
öeldut	doc_491521501954_item	2556055	et	4	main
kus	doc_491521501954_item	2556056	et	3	main
sündisid	doc_491521501954_item	2556057	et	4	main
seal	doc_491521501954_item	2556058	et	4	main
peab	doc_491521501954_item	2556059	et	4	main
ka	doc_491521501954_item	2556060	et	3	main
elama	doc_491521501954_item	2556061	et	3	main
kas	doc_491521501954_item	2556062	et	3	main
loete	doc_491521501954_item	2556063	et	4	main
horoskoope	doc_491521501954_item	2556064	et	3	main
ei	doc_491521501954_item	2556065	et	4	main
ma	doc_491521501954_item	2556066	et	3	main
ei	doc_491521501954_item	2556067	et	4	main
ega	doc_491521501954_item	2556070	et	3	main
ei	doc_491521501954_item	2556074	et	4	main
tahab	doc_491521501954_item	2556091	et	3	main
kohtuasjades	doc_491521501954_item	2556092	et	3	main
tulemus	doc_491521501954_item	2556114	et	3	main
et	doc_491521501954_item	2556115	et	3	main
mida	doc_491521501954_item	2556121	et	4	main
ma	doc_491521501954_item	2556122	et	3	main
olin	doc_491521501954_item	2556124	et	3	main
räägis	doc_491521501954_item	2556126	et	3	main
ta	doc_491521501954_item	2556127	et	4	main
ka	doc_491521501954_item	2556134	et	3	main
küsimust	doc_491521501955_item	2556138	et	4	main
mind	doc_491521501955_item	2556148	et	4	main
köitis	doc_491521501955_item	2556149	et	3	main
ka	doc_491521501955_item	2556150	et	3	main
tolleaegne	doc_491521501955_item	2556152	et	3	main
mida	doc_491521501955_item	2556168	et	4	main
saavutuseks	doc_491521501955_item	2556173	et	4	main
ootab	doc_491521501955_item	2556179	et	3	main
valetamine	doc_491521501955_item	2556188	et	4	main
mind	doc_491521501955_item	2556199	et	4	main
olnud	doc_491521501955_item	2556210	et	4	main
ilmselt	doc_491521501955_item	2556215	et	4	main
ongi	doc_491521501955_item	2556216	et	4	main
praegune	doc_491521501955_item	2556219	et	3	main
öökull	doc_491521501954_item	2556130	et	3	main
ja	doc_491521501954_item	2556131	et	3	main
tööd	doc_491521501954_item	2556132	et	4	main
13	doc_491521501955_item	2556137	et	2	main
saada	doc_491521501955_item	2556144	et	4	main
sööst	doc_491521501955_item	2556156	et	3	main
elu	doc_491521501955_item	2556171	et	4	main
suurimaks	doc_491521501955_item	2556172	et	4	main
saavutus	doc_491521501955_item	2556178	et	4	main
ma	doc_491521501955_item	2556189	et	3	main
ei	doc_491521501955_item	2556192	et	4	main
kuid	doc_491521501955_item	2556201	et	4	main
puutumast	doc_491521501955_item	2556207	et	4	main
on	doc_491521501955_item	2556209	et	4	main
tegu	doc_491521501955_item	2556214	et	4	main
selle	doc_491521501955_item	2556221	et	4	main
puhtaks	doc_491521501955_item	2556226	et	3	main
hea	doc_491521501955_item	2556232	et	4	main
kuid	doc_491521501955_item	2556236	et	4	main
kindlasti	doc_491521501955_item	2556237	et	3	main
mida	doc_491521501955_item	2556249	et	4	main
käes	doc_491521501955_item	2556255	et	4	main
seda	doc_491521501955_item	2556256	et	3	main
rohkem	doc_491521501955_item	2556257	et	4	main
rohkem	doc_491521501955_item	2556266	et	4	main
mida	doc_491521501955_item	2556270	et	4	main
palju	doc_491521501955_item	2556276	et	4	main
aidata	doc_491521501955_item	2556321	et	4	main
tundub	doc_491521501955_item	2556323	et	3	main
paremini	doc_491521501955_item	2556333	et	4	main
valmistuda	doc_491521501955_item	2556334	et	3	main
öökulli	doc_491521501955_item	2556339	et	4	main
inimene	doc_491521501955_item	2556341	et	3	main
seetõttu	doc_491521501955_item	2556343	et	3	main
oma	doc_491521501955_item	2556354	et	4	main
järjekindlus	doc_491521501955_item	2556362	et	4	main
siis	doc_491521501955_item	2556367	et	3	main
kui	doc_491521501955_item	2556368	et	3	main
see	doc_491521501955_item	2556369	et	3	main
tulemus	doc_491521501955_item	2556370	et	3	main
ei	doc_491521501955_item	2556371	et	4	main
kord	doc_491521501955_item	2556374	et	4	main
see	doc_491521501955_item	2556376	et	3	main
ma	doc_491521501955_item	2556378	et	3	main
peale	doc_491521501955_item	2556393	et	4	main
olen	doc_491521501955_item	2556398	et	3	main
parem	doc_491521501955_item	2556413	et	4	main
loete	doc_491521501955_item	2556425	et	4	main
ei	doc_491521501955_item	2556427	et	4	main
tõsine	doc_491521501955_item	2556438	et	4	main
kellest	doc_491521501955_item	2556442	et	4	main
mees	doc_491521501955_item	2556448	et	4	main
arvan	doc_491521501955_item	2556452	et	3	main
ta	doc_491521501955_item	2556454	et	4	main
kohtus	doc_491521501955_item	2556465	et	4	main
juristina	doc_491521501955_item	2556470	et	3	main
et	doc_491521501955_item	2556504	et	3	main
lugeda	doc_491521501955_item	2556507	et	3	main
arvab	doc_491521501955_item	2556509	et	3	main
et	doc_491521501955_item	2556510	et	3	main
tema	doc_491521501955_item	2556511	et	4	main
tuevad	doc_491521501955_item	2556512	et	4	main
küljed	doc_491521501955_item	2556513	et	3	main
et	doc_491521501955_item	2556514	et	3	main
see	doc_491521501955_item	2556515	et	3	main
12c	doc_491521501955_item	2556521	et	4	main
13	doc_491521501956_item	2556524	et	2	main
kelleks	doc_491521501956_item	2556526	et	4	main
tahtsite	doc_491521501956_item	2556527	et	3	main
mind	doc_491521501956_item	2556533	et	4	main
köitis	doc_491521501956_item	2556534	et	3	main
ka	doc_491521501956_item	2556535	et	3	main
väga	doc_491521501956_item	2556536	et	3	main
tolleaegne	doc_491521501956_item	2556537	et	3	main
dessantväelasest	doc_491521501956_item	2556538	et	3	main
eritsooni	doc_491521501956_item	2556542	et	4	main
tahtsin	doc_491521501956_item	2556544	et	3	main
samasuguseks	doc_491521501956_item	2556546	et	4	main
mida	doc_491521501956_item	2556553	et	4	main
oma	doc_491521501956_item	2556555	et	4	main
loodan	doc_491521501956_item	2556560	et	3	main
saavutus	doc_491521501956_item	2556563	et	4	main
pööraseim	doc_491521501956_item	2556598	et	4	main
ongi	doc_491521501956_item	2556601	et	4	main
praegune	doc_491521501956_item	2556604	et	3	main
tänapäeva	doc_491521501956_item	2556615	et	4	main
nemad	doc_491521501955_item	2556163	et	3	main
aga	doc_491521501955_item	2556164	et	3	main
hiljem	doc_491521501955_item	2556165	et	3	main
huvid	doc_491521501955_item	2556166	et	3	main
muutusid	doc_491521501955_item	2556167	et	4	main
veel	doc_491521501955_item	2556181	et	4	main
üldiselt	doc_491521501955_item	2556191	et	4	main
petnud	doc_491521501955_item	2556200	et	4	main
selliste	doc_491521501955_item	2556204	et	4	main
inimestega	doc_491521501955_item	2556205	et	3	main
teie	doc_491521501955_item	2556211	et	4	main
et	doc_491521501955_item	2556223	et	3	main
kellel	doc_491521501955_item	2556228	et	4	main
on	doc_491521501955_item	2556229	et	4	main
elada	doc_491521501955_item	2556233	et	3	main
öelda	doc_491521501955_item	2556235	et	4	main
ei	doc_491521501955_item	2556238	et	4	main
ole	doc_491521501955_item	2556239	et	4	main
need	doc_491521501955_item	2556240	et	3	main
kõige	doc_491521501955_item	2556265	et	4	main
ma	doc_491521501955_item	2556273	et	3	main
alajõe	doc_491521501955_item	2556307	et	3	main
aega	doc_491521501955_item	2556314	et	4	main
tahan	doc_491521501955_item	2556316	et	3	main
inimesi	doc_491521501955_item	2556318	et	4	main
hästi	doc_491521501955_item	2556320	et	3	main
natukene	doc_491521501955_item	2556327	et	4	main
kuid	doc_491521501955_item	2556335	et	4	main
peate	doc_491521501955_item	2556353	et	4	main
ma	doc_491521501955_item	2556357	et	3	main
ole	doc_491521501955_item	2556372	et	4	main
alguses	doc_491521501955_item	2556379	et	4	main
olin	doc_491521501955_item	2556380	et	3	main
lootnud	doc_491521501955_item	2556381	et	4	main
ei	doc_491521501955_item	2556382	et	4	main
pooleli	doc_491521501955_item	2556388	et	3	main
nii	doc_491521501955_item	2556403	et	3	main
venemaal	doc_491521501955_item	2556404	et	4	main
kui	doc_491521501955_item	2556405	et	3	main
siiski	doc_491521501955_item	2556408	et	4	main
mul	doc_491521501955_item	2556411	et	3	main
oma	doc_491521501955_item	2556415	et	4	main
kus	doc_491521501955_item	2556418	et	3	main
sündisid	doc_491521501955_item	2556419	et	4	main
elama	doc_491521501955_item	2556423	et	3	main
ei	doc_491521501955_item	2556429	et	4	main
usu	doc_491521501955_item	2556430	et	4	main
asi	doc_491521501955_item	2556439	et	4	main
kirjutatakse	doc_491521501955_item	2556443	et	3	main
intervjueeritav	doc_491521501955_item	2556446	et	4	main
luurajaks	doc_491521501955_item	2556461	et	4	main
2	doc_491521501955_item	2556462	et	2	main
ta	doc_491521501955_item	2556469	et	4	main
viia	doc_491521501955_item	2556518	et	3	main
13	doc_491521501956_item	2556522	et	2	main
küsimust	doc_491521501956_item	2556523	et	4	main
küsimust	doc_491521501956_item	2556525	et	4	main
film	doc_491521501956_item	2556540	et	3	main
aga	doc_491521501956_item	2556549	et	3	main
muutusid	doc_491521501956_item	2556552	et	4	main
peate	doc_491521501956_item	2556554	et	4	main
ma	doc_491521501956_item	2556559	et	3	main
mind	doc_491521501956_item	2556565	et	4	main
elu	doc_491521501956_item	2556597	et	4	main
nimel	doc_491521501956_item	2556607	et	3	main
eestis	doc_491521501956_item	2556616	et	3	main
hea	doc_491521501956_item	2556617	et	4	main
elada	doc_491521501956_item	2556618	et	3	main
kuid	doc_491521501956_item	2556621	et	4	main
olevad	doc_491521501956_item	2556631	et	4	main
inimesed	doc_491521501956_item	2556632	et	3	main
seda	doc_491521501956_item	2556641	et	3	main
kommunaalkulude	doc_491521501956_item	2556653	et	3	main
tõsta	doc_491521501956_item	2556668	et	4	main
puhkus	doc_491521501956_item	2556679	et	3	main
koos	doc_491521501956_item	2556681	et	4	main
milline	doc_491521501956_item	2556685	et	3	main
teie	doc_491521501956_item	2556687	et	4	main
lemmikkoht	doc_491521501956_item	2556688	et	3	main
mille	doc_491521501956_item	2556695	et	3	main
ei	doc_491521501956_item	2556697	et	4	main
ma	doc_491521501956_item	2556721	et	3	main
kohlta-järve	doc_491521501955_item	2556224	et	4	main
õhk	doc_491521501955_item	2556225	et	3	main
saaks	doc_491521501955_item	2556227	et	3	main
sest	doc_491521501955_item	2556248	et	4	main
on	doc_491521501955_item	2556254	et	4	main
teil	doc_491521501955_item	2556264	et	4	main
peale	doc_491521501955_item	2556269	et	4	main
tahan	doc_491521501955_item	2556274	et	3	main
lugeda	doc_491521501955_item	2556277	et	3	main
et	doc_491521501955_item	2556278	et	3	main
saada	doc_491521501955_item	2556279	et	4	main
targemaks	doc_491521501955_item	2556280	et	4	main
eelkõige	doc_491521501955_item	2556281	et	3	main
tahaks	doc_491521501955_item	2556282	et	3	main
tõsta	doc_491521501955_item	2556283	et	4	main
oma	doc_491521501955_item	2556284	et	4	main
taset	doc_491521501955_item	2556285	et	3	main
valitud	doc_491521501955_item	2556286	et	4	main
erialal	doc_491521501955_item	2556287	et	3	main
õigusteaduses	doc_491521501955_item	2556288	et	3	main
mis	doc_491521501955_item	2556289	et	4	main
on	doc_491521501955_item	2556290	et	4	main
teie	doc_491521501955_item	2556291	et	4	main
jaoks	doc_491521501955_item	2556292	et	4	main
parim	doc_491521501955_item	2556293	et	4	main
puhkus	doc_491521501955_item	2556294	et	3	main
olla	doc_491521501955_item	2556295	et	3	main
koos	doc_491521501955_item	2556296	et	4	main
perega	doc_491521501955_item	2556297	et	3	main
kusagil	doc_491521501955_item	2556298	et	3	main
looduses	doc_491521501955_item	2556299	et	4	main
milline	doc_491521501955_item	2556300	et	3	main
on	doc_491521501955_item	2556301	et	4	main
teie	doc_491521501955_item	2556302	et	4	main
lemmikkoht	doc_491521501955_item	2556303	et	3	main
ida-virumaal	doc_491521501955_item	2556304	et	4	main
peipsi-äärne	doc_491521501955_item	2556305	et	3	main
karjamaa	doc_491521501955_item	2556308	et	4	main
mille	doc_491521501955_item	2556310	et	3	main
kuna	doc_491521501955_item	2556315	et	3	main
aega	doc_491521501955_item	2556329	et	4	main
siis	doc_491521501955_item	2556330	et	3	main
olen	doc_491521501955_item	2556337	et	3	main
ja	doc_491521501955_item	2556342	et	3	main
olen	doc_491521501955_item	2556344	et	3	main
harjunud	doc_491521501955_item	2556345	et	4	main
tugevaimaks	doc_491521501955_item	2556355	et	4	main
on	doc_491521501955_item	2556361	et	4	main
viia	doc_491521501955_item	2556363	et	3	main
asjad	doc_491521501955_item	2556364	et	3	main
lõpuni	doc_491521501955_item	2556365	et	3	main
isegi	doc_491521501955_item	2556366	et	4	main
päris	doc_491521501955_item	2556375	et	4	main
ole	doc_491521501955_item	2556383	et	4	main
mul	doc_491521501955_item	2556384	et	3	main
kombeks	doc_491521501955_item	2556385	et	4	main
oma	doc_491521501955_item	2556386	et	4	main
ettevõtmisi	doc_491521501955_item	2556387	et	3	main
span	doc_491521501955_item	2556390	et	4	main
millises	doc_491521501955_item	2556391	et	3	main
tahaksite	doc_491521501955_item	2556395	et	3	main
ma	doc_491521501955_item	2556397	et	3	main
elanud	doc_491521501955_item	2556399	et	4	main
kuid	doc_491521501955_item	2556407	et	4	main
eestis	doc_491521501955_item	2556410	et	3	main
seal	doc_491521501955_item	2556420	et	4	main
siis	doc_491521501955_item	2556322	et	3	main
jõuaks	doc_491521501955_item	2556331	et	3	main
veelgi	doc_491521501955_item	2556332	et	4	main
loomult	doc_491521501955_item	2556338	et	3	main
millist	doc_491521501955_item	2556351	et	3	main
omadust	doc_491521501955_item	2556352	et	4	main
küljeks	doc_491521501955_item	2556356	et	3	main
et	doc_491521501955_item	2556359	et	3	main
jätta	doc_491521501955_item	2556389	et	3	main
riigis	doc_491521501955_item	2556392	et	3	main
eesti	doc_491521501955_item	2556394	et	4	main
elada	doc_491521501955_item	2556396	et	3	main
saksamaal	doc_491521501955_item	2556406	et	4	main
kõige	doc_491521501955_item	2556412	et	4	main
peab	doc_491521501955_item	2556421	et	4	main
huvitu	doc_491521501955_item	2556433	et	4	main
ole	doc_491521501955_item	2556437	et	4	main
1	doc_491521501955_item	2556444	et	2	main
kas	doc_491521501955_item	2556445	et	3	main
on	doc_491521501955_item	2556447	et	4	main
ma	doc_491521501955_item	2556451	et	3	main
et	doc_491521501955_item	2556453	et	3	main
oli	doc_491521501955_item	2556455	et	3	main
ta	doc_491521501955_item	2556463	et	4	main
arvan	doc_491521501955_item	2556467	et	3	main
ta	doc_491521501955_item	2556472	et	4	main
on	doc_491521501955_item	2556516	et	4	main
lõpuni	doc_491521501955_item	2556520	et	3	main
saada	doc_491521501956_item	2556529	et	4	main
unistasin	doc_491521501956_item	2556530	et	3	main
tehtud	doc_491521501956_item	2556539	et	4	main
ja	doc_491521501956_item	2556543	et	3	main
saada	doc_491521501956_item	2556545	et	4	main
nagu	doc_491521501956_item	2556547	et	3	main
veel	doc_491521501956_item	2556566	et	4	main
ees	doc_491521501956_item	2556567	et	4	main
tegu	doc_491521501956_item	2556599	et	4	main
võitlus	doc_491521501956_item	2556605	et	3	main
õhk	doc_491521501956_item	2556610	et	3	main
kellel	doc_491521501956_item	2556613	et	4	main
on	doc_491521501956_item	2556614	et	4	main
raske	doc_491521501956_item	2556619	et	4	main
ole	doc_491521501956_item	2556624	et	4	main
ainult	doc_491521501956_item	2556626	et	4	main
ja	doc_491521501956_item	2556628	et	3	main
võimu	doc_491521501956_item	2556629	et	4	main
mida	doc_491521501956_item	2556634	et	4	main
rohkem	doc_491521501956_item	2556635	et	4	main
on	doc_491521501956_item	2556639	et	4	main
mille	doc_491521501956_item	2556646	et	3	main
kulub	doc_491521501956_item	2556648	et	3	main
teil	doc_491521501956_item	2556649	et	4	main
raha	doc_491521501956_item	2556652	et	4	main
ma	doc_491521501956_item	2556658	et	3	main
lugeda	doc_491521501956_item	2556662	et	3	main
et	doc_491521501956_item	2556663	et	3	main
parim	doc_491521501956_item	2556678	et	4	main
kusagil	doc_491521501956_item	2556683	et	3	main
on	doc_491521501956_item	2556686	et	4	main
vasknarva	doc_491521501956_item	2556694	et	4	main
olen	doc_491521501956_item	2556722	et	3	main
inimene	doc_491521501956_item	2556726	et	3	main
seetõttu	doc_491521501956_item	2556728	et	3	main
harjunud	doc_491521501956_item	2556730	et	4	main
tugevaimaks	doc_491521501956_item	2556740	et	4	main
see	doc_491521501956_item	2556745	et	3	main
siis	doc_491521501956_item	2556752	et	3	main
kui	doc_491521501956_item	2556753	et	3	main
see	doc_491521501956_item	2556754	et	3	main
kord	doc_491521501956_item	2556759	et	4	main
kombeks	doc_491521501956_item	2556770	et	4	main
peale	doc_491521501956_item	2556778	et	4	main
ja	doc_491521501956_item	2556785	et	3	main
nii	doc_491521501956_item	2556788	et	3	main
venemaal	doc_491521501956_item	2556789	et	4	main
ei	doc_491521501956_item	2556821	et	4	main
kes	doc_491521501956_item	2556837	et	4	main
ta	doc_491521501956_item	2556849	et	4	main
arvates	doc_491521501956_item	2556852	et	4	main
tema	doc_491521501956_item	2556857	et	4	main
teda	doc_491521501956_item	2556873	et	4	main
elukutselt	doc_491521501956_item	2556874	et	4	main
kõik	doc_491521501956_item	2556881	et	4	main
ta	doc_491521501956_item	2556888	et	4	main
ta	doc_491521501956_item	2556892	et	4	main
asjad	doc_491521501956_item	2556906	et	3	main
12c	doc_491521501956_item	2556908	et	4	main
arvan	doc_491521501955_item	2556358	et	3	main
see	doc_491521501955_item	2556360	et	3	main
iga	doc_491521501955_item	2556373	et	4	main
mida	doc_491521501955_item	2556377	et	4	main
ja	doc_491521501955_item	2556400	et	3	main
teinud	doc_491521501955_item	2556401	et	4	main
tööd	doc_491521501955_item	2556402	et	4	main
on	doc_491521501955_item	2556409	et	4	main
järgin	doc_491521501955_item	2556414	et	3	main
isa	doc_491521501955_item	2556416	et	4	main
öeldut	doc_491521501955_item	2556417	et	4	main
ka	doc_491521501955_item	2556422	et	3	main
horoskoope	doc_491521501955_item	2556426	et	3	main
ma	doc_491521501955_item	2556428	et	3	main
ega	doc_491521501955_item	2556432	et	3	main
iseloomusta	doc_491521501955_item	2556440	et	4	main
või	doc_491521501955_item	2556449	et	4	main
naine	doc_491521501955_item	2556450	et	3	main
mees	doc_491521501955_item	2556456	et	4	main
sellepärast	doc_491521501955_item	2556457	et	3	main
ta	doc_491521501955_item	2556458	et	4	main
unistas	doc_491521501955_item	2556459	et	3	main
töötab	doc_491521501955_item	2556464	et	3	main
et	doc_491521501955_item	2556468	et	3	main
3	doc_491521501955_item	2556471	et	2	main
peab	doc_491521501955_item	2556473	et	4	main
kõik	doc_491521501955_item	2556474	et	4	main
meeldib	doc_491521501955_item	2556503	et	3	main
armastab	doc_491521501955_item	2556506	et	3	main
ta	doc_491521501955_item	2556508	et	4	main
järjekindlus	doc_491521501955_item	2556517	et	4	main
kas	doc_491521501955_item	2556424	et	3	main
neid	doc_491521501955_item	2556431	et	4	main
nendest	doc_491521501955_item	2556434	et	4	main
see	doc_491521501955_item	2556435	et	3	main
ei	doc_491521501955_item	2556436	et	4	main
inimet	doc_491521501955_item	2556441	et	4	main
saada	doc_491521501955_item	2556460	et	4	main
ma	doc_491521501955_item	2556466	et	3	main
asjad	doc_491521501955_item	2556475	et	3	main
lõpuni	doc_491521501955_item	2556476	et	3	main
4	doc_491521501955_item	2556477	et	2	main
kohtus	doc_491521501955_item	2556478	et	4	main
aidata	doc_491521501955_item	2556479	et	4	main
inimesi	doc_491521501955_item	2556480	et	4	main
5	doc_491521501955_item	2556481	et	2	main
ta	doc_491521501955_item	2556482	et	4	main
saab	doc_491521501955_item	2556483	et	3	main
päeval	doc_491521501955_item	2556484	et	3	main
töötada	doc_491521501955_item	2556485	et	3	main
aga	doc_491521501955_item	2556486	et	3	main
ööl	doc_491521501955_item	2556487	et	3	main
õppida	doc_491521501955_item	2556488	et	3	main
talle	doc_491521501955_item	2556489	et	4	main
meeldib	doc_491521501955_item	2556490	et	3	main
öö	doc_491521501955_item	2556491	et	4	main
ta	doc_491521501955_item	2556492	et	4	main
arvab	doc_491521501955_item	2556493	et	3	main
et	doc_491521501955_item	2556494	et	3	main
ta	doc_491521501955_item	2556495	et	4	main
ole	doc_491521501955_item	2556496	et	4	main
loomult	doc_491521501955_item	2556497	et	3	main
öökulli	doc_491521501955_item	2556498	et	4	main
tüüpi	doc_491521501955_item	2556499	et	4	main
inimene	doc_491521501955_item	2556500	et	3	main
6	doc_491521501955_item	2556501	et	2	main
mulle	doc_491521501955_item	2556502	et	4	main
ta	doc_491521501955_item	2556505	et	4	main
asjad	doc_491521501955_item	2556519	et	3	main
lapsepõlves	doc_491521501956_item	2556528	et	4	main
nemad	doc_491521501956_item	2556548	et	3	main
elu	doc_491521501956_item	2556556	et	4	main
et	doc_491521501956_item	2556561	et	3	main
mis	doc_491521501956_item	2556568	et	4	main
teid	doc_491521501956_item	2556569	et	4	main
ärritab	doc_491521501956_item	2556570	et	3	main
reeturlus	doc_491521501956_item	2556571	et	4	main
see	doc_491521501956_item	2556602	et	3	main
selle	doc_491521501956_item	2556606	et	4	main
et	doc_491521501956_item	2556608	et	3	main
saaks	doc_491521501956_item	2556612	et	3	main
need	doc_491521501956_item	2556625	et	3	main
võimu	doc_491521501956_item	2556638	et	4	main
rohkem	doc_491521501956_item	2556642	et	4	main
ka	doc_491521501956_item	2556644	et	3	main
probleeme	doc_491521501956_item	2556645	et	3	main
peale	doc_491521501956_item	2556647	et	4	main
peale	doc_491521501956_item	2556654	et	4	main
tahan	doc_491521501956_item	2556659	et	3	main
palju	doc_491521501956_item	2556661	et	4	main
saada	doc_491521501956_item	2556664	et	4	main
targemaks	doc_491521501956_item	2556665	et	4	main
eelkõige	doc_491521501956_item	2556666	et	3	main
tahaks	doc_491521501956_item	2556667	et	3	main
mis	doc_491521501956_item	2556674	et	4	main
on	doc_491521501956_item	2556675	et	4	main
perega	doc_491521501956_item	2556682	et	3	main
looduses	doc_491521501956_item	2556684	et	4	main
karjamaa	doc_491521501956_item	2556693	et	4	main
peate	doc_491521501956_item	2556738	et	4	main
ma	doc_491521501956_item	2556742	et	3	main
ole	doc_491521501956_item	2556757	et	4	main
päris	doc_491521501956_item	2556760	et	4	main
alguses	doc_491521501956_item	2556764	et	4	main
olin	doc_491521501956_item	2556765	et	3	main
lootnud	doc_491521501956_item	2556766	et	4	main
jätta	doc_491521501956_item	2556774	et	3	main
span	doc_491521501956_item	2556775	et	4	main
millises	doc_491521501956_item	2556776	et	3	main
tööd	doc_491521501956_item	2556787	et	4	main
saada	doc_491521501956_item	2556531	et	4	main
luurajaks	doc_491521501956_item	2556532	et	4	main
sööst	doc_491521501956_item	2556541	et	3	main
hiljem	doc_491521501956_item	2556550	et	3	main
huvid	doc_491521501956_item	2556551	et	3	main
suurimaks	doc_491521501956_item	2556557	et	4	main
saavutuseks	doc_491521501956_item	2556558	et	4	main
selline	doc_491521501956_item	2556562	et	4	main
ootab	doc_491521501956_item	2556564	et	3	main
ja	doc_491521501956_item	2556572	et	3	main
valetamine	doc_491521501956_item	2556573	et	4	main
ma	doc_491521501956_item	2556574	et	3	main
küll	doc_491521501956_item	2556575	et	4	main
üldiselt	doc_491521501956_item	2556576	et	4	main
ei	doc_491521501956_item	2556577	et	4	main
ütle	doc_491521501956_item	2556578	et	4	main
inimestele	doc_491521501956_item	2556579	et	3	main
välja	doc_491521501956_item	2556580	et	4	main
et	doc_491521501956_item	2556581	et	3	main
nad	doc_491521501956_item	2556582	et	3	main
on	doc_491521501956_item	2556583	et	4	main
mind	doc_491521501956_item	2556584	et	4	main
petnud	doc_491521501956_item	2556585	et	4	main
kuid	doc_491521501956_item	2556586	et	4	main
hoidun	doc_491521501956_item	2556587	et	3	main
selliste	doc_491521501956_item	2556589	et	4	main
inimestega	doc_491521501956_item	2556590	et	3	main
kokku	doc_491521501956_item	2556591	et	3	main
edaspidi	doc_491521501956_item	2556588	et	3	main
puutumast	doc_491521501956_item	2556592	et	4	main
mis	doc_491521501956_item	2556593	et	4	main
on	doc_491521501956_item	2556594	et	4	main
olnud	doc_491521501956_item	2556595	et	4	main
teie	doc_491521501956_item	2556596	et	4	main
ilmselt	doc_491521501956_item	2556600	et	4	main
minu	doc_491521501956_item	2556603	et	3	main
kohlta-järve	doc_491521501956_item	2556609	et	4	main
puhtaks	doc_491521501956_item	2556611	et	3	main
öelda	doc_491521501956_item	2556620	et	4	main
ei	doc_491521501956_item	2556623	et	4	main
rikkad	doc_491521501956_item	2556627	et	4	main
sest	doc_491521501956_item	2556633	et	4	main
kõige	doc_491521501956_item	2556650	et	4	main
mida	doc_491521501956_item	2556655	et	4	main
tahaksite	doc_491521501956_item	2556656	et	3	main
väga	doc_491521501956_item	2556660	et	3	main
valitud	doc_491521501956_item	2556671	et	4	main
erialal	doc_491521501956_item	2556672	et	3	main
õigusteaduses	doc_491521501956_item	2556673	et	3	main
jaoks	doc_491521501956_item	2556677	et	4	main
olla	doc_491521501956_item	2556680	et	3	main
kindlasti	doc_491521501956_item	2556622	et	3	main
juures	doc_491521501956_item	2556630	et	4	main
raha	doc_491521501956_item	2556636	et	4	main
ja	doc_491521501956_item	2556637	et	3	main
käes	doc_491521501956_item	2556640	et	4	main
on	doc_491521501956_item	2556643	et	4	main
rohkem	doc_491521501956_item	2556651	et	4	main
osta	doc_491521501956_item	2556657	et	4	main
oma	doc_491521501956_item	2556669	et	4	main
taset	doc_491521501956_item	2556670	et	3	main
teie	doc_491521501956_item	2556676	et	4	main
ida-virumaal	doc_491521501956_item	2556689	et	4	main
peipsi-äärne	doc_491521501956_item	2556690	et	3	main
kant	doc_491521501956_item	2556691	et	3	main
alajõe	doc_491521501956_item	2556692	et	3	main
jaoks	doc_491521501956_item	2556696	et	4	main
jätku	doc_491521501956_item	2556698	et	4	main
aega	doc_491521501956_item	2556699	et	4	main
kuna	doc_491521501956_item	2556700	et	3	main
tahan	doc_491521501956_item	2556701	et	3	main
kohtuasjades	doc_491521501956_item	2556702	et	3	main
inimesi	doc_491521501956_item	2556703	et	4	main
võimalikult	doc_491521501956_item	2556704	et	4	main
hästi	doc_491521501956_item	2556705	et	3	main
aidata	doc_491521501956_item	2556706	et	4	main
siis	doc_491521501956_item	2556707	et	3	main
tundub	doc_491521501956_item	2556708	et	3	main
alati	doc_491521501956_item	2556709	et	4	main
et	doc_491521501956_item	2556710	et	3	main
oleks	doc_491521501956_item	2556711	et	3	main
natukene	doc_491521501956_item	2556712	et	4	main
rohkem	doc_491521501956_item	2556713	et	4	main
aega	doc_491521501956_item	2556714	et	4	main
siis	doc_491521501956_item	2556715	et	3	main
jõuaks	doc_491521501956_item	2556716	et	3	main
veelgi	doc_491521501956_item	2556717	et	4	main
valmistuda	doc_491521501956_item	2556719	et	3	main
paremini	doc_491521501956_item	2556718	et	4	main
kuid	doc_491521501956_item	2556720	et	4	main
loomult	doc_491521501956_item	2556723	et	3	main
ja	doc_491521501956_item	2556727	et	3	main
olen	doc_491521501956_item	2556729	et	3	main
tööd	doc_491521501956_item	2556731	et	4	main
tegema	doc_491521501956_item	2556732	et	3	main
ka	doc_491521501956_item	2556733	et	3	main
hilistel	doc_491521501956_item	2556734	et	3	main
öötundidel	doc_491521501956_item	2556735	et	3	main
millist	doc_491521501956_item	2556736	et	3	main
omadust	doc_491521501956_item	2556737	et	4	main
küljeks	doc_491521501956_item	2556741	et	3	main
et	doc_491521501956_item	2556744	et	3	main
iga	doc_491521501956_item	2556758	et	4	main
mida	doc_491521501956_item	2556762	et	4	main
oma	doc_491521501956_item	2556771	et	4	main
ettevõtmisi	doc_491521501956_item	2556772	et	3	main
pooleli	doc_491521501956_item	2556773	et	3	main
tahaksite	doc_491521501956_item	2556780	et	3	main
ma	doc_491521501956_item	2556782	et	3	main
elanud	doc_491521501956_item	2556784	et	4	main
öökulli	doc_491521501956_item	2556724	et	4	main
arvan	doc_491521501956_item	2556743	et	3	main
järjekindlus	doc_491521501956_item	2556747	et	4	main
viia	doc_491521501956_item	2556748	et	3	main
asjad	doc_491521501956_item	2556749	et	3	main
lõpuni	doc_491521501956_item	2556750	et	3	main
see	doc_491521501956_item	2556761	et	3	main
ma	doc_491521501956_item	2556763	et	3	main
ei	doc_491521501956_item	2556767	et	4	main
riigis	doc_491521501956_item	2556777	et	3	main
olen	doc_491521501956_item	2556783	et	3	main
kui	doc_491521501956_item	2556790	et	3	main
saksamaal	doc_491521501956_item	2556791	et	4	main
kuid	doc_491521501956_item	2556792	et	4	main
siiski	doc_491521501956_item	2556793	et	4	main
on	doc_491521501956_item	2556794	et	4	main
eestis	doc_491521501956_item	2556795	et	3	main
mul	doc_491521501956_item	2556796	et	3	main
kõige	doc_491521501956_item	2556797	et	4	main
parem	doc_491521501956_item	2556798	et	4	main
järgin	doc_491521501956_item	2556799	et	3	main
oma	doc_491521501956_item	2556800	et	4	main
öeldut	doc_491521501956_item	2556802	et	4	main
kus	doc_491521501956_item	2556803	et	3	main
isa	doc_491521501956_item	2556801	et	4	main
sündisid	doc_491521501956_item	2556804	et	4	main
seal	doc_491521501956_item	2556805	et	4	main
peab	doc_491521501956_item	2556806	et	4	main
ka	doc_491521501956_item	2556807	et	3	main
elama	doc_491521501956_item	2556808	et	3	main
kas	doc_491521501956_item	2556809	et	3	main
loete	doc_491521501956_item	2556810	et	4	main
horoskoope	doc_491521501956_item	2556811	et	3	main
ei	doc_491521501956_item	2556812	et	4	main
ma	doc_491521501956_item	2556813	et	3	main
ei	doc_491521501956_item	2556814	et	4	main
usu	doc_491521501956_item	2556815	et	4	main
neid	doc_491521501956_item	2556816	et	4	main
ega	doc_491521501956_item	2556817	et	3	main
huvitu	doc_491521501956_item	2556818	et	4	main
nendest	doc_491521501956_item	2556819	et	4	main
see	doc_491521501956_item	2556820	et	3	main
iseloomusta	doc_491521501956_item	2556825	et	4	main
kellest	doc_491521501956_item	2556827	et	4	main
ta	doc_491521501956_item	2556843	et	4	main
on	doc_491521501956_item	2556844	et	4	main
4	doc_491521501956_item	2556847	et	2	main
on	doc_491521501956_item	2556856	et	4	main
6	doc_491521501956_item	2556859	et	2	main
2	doc_491521501956_item	2556872	et	2	main
lõpuni	doc_491521501956_item	2556883	et	3	main
et	doc_491521501956_item	2556887	et	3	main
tüüpi	doc_491521501956_item	2556725	et	4	main
oma	doc_491521501956_item	2556739	et	4	main
on	doc_491521501956_item	2556746	et	4	main
isegi	doc_491521501956_item	2556751	et	4	main
tulemus	doc_491521501956_item	2556755	et	3	main
ei	doc_491521501956_item	2556756	et	4	main
ole	doc_491521501956_item	2556768	et	4	main
mul	doc_491521501956_item	2556769	et	3	main
eesti	doc_491521501956_item	2556779	et	4	main
elada	doc_491521501956_item	2556781	et	3	main
tõsine	doc_491521501956_item	2556823	et	4	main
või	doc_491521501956_item	2556834	et	4	main
naine	doc_491521501956_item	2556835	et	3	main
2	doc_491521501956_item	2556836	et	2	main
sinu	doc_491521501956_item	2556851	et	3	main
töötada	doc_491521501956_item	2556853	et	3	main
tööharjumused	doc_491521501956_item	2556858	et	3	main
asjad	doc_491521501956_item	2556882	et	3	main
ma	doc_491521501956_item	2556885	et	3	main
saab	doc_491521501956_item	2556893	et	3	main
päeval	doc_491521501956_item	2556895	et	3	main
6	doc_491521501956_item	2556898	et	2	main
järjekindlus	doc_491521501956_item	2556904	et	4	main
lõpuni	doc_491521501956_item	2556907	et	3	main
küsimust	doc_491521501957_item	2556910	et	4	main
küsimust	doc_491521501957_item	2556912	et	4	main
kelleks	doc_491521501957_item	2556913	et	4	main
tahtsite	doc_491521501957_item	2556914	et	3	main
mind	doc_491521501957_item	2556920	et	4	main
teinud	doc_491521501956_item	2556786	et	4	main
asi	doc_491521501956_item	2556824	et	4	main
inimest	doc_491521501956_item	2556826	et	3	main
kirjutatakse	doc_491521501956_item	2556828	et	3	main
kas	doc_491521501956_item	2556830	et	3	main
on	doc_491521501956_item	2556832	et	4	main
ta	doc_491521501956_item	2556838	et	4	main
on	doc_491521501956_item	2556839	et	4	main
oma	doc_491521501956_item	2556845	et	4	main
iseloomult	doc_491521501956_item	2556846	et	3	main
kus	doc_491521501956_item	2556848	et	3	main
5	doc_491521501956_item	2556854	et	2	main
on	doc_491521501956_item	2556875	et	4	main
jurist	doc_491521501956_item	2556876	et	3	main
inimesed	doc_491521501956_item	2556879	et	3	main
4	doc_491521501956_item	2556884	et	2	main
töötast	doc_491521501956_item	2556889	et	4	main
5	doc_491521501956_item	2556891	et	2	main
on	doc_491521501956_item	2556903	et	4	main
13	doc_491521501957_item	2556909	et	2	main
saada	doc_491521501957_item	2556916	et	4	main
unistasin	doc_491521501957_item	2556917	et	3	main
väga	doc_491521501957_item	2556923	et	3	main
tehtud	doc_491521501957_item	2556926	et	4	main
eritsooni	doc_491521501957_item	2556929	et	4	main
aga	doc_491521501957_item	2556936	et	3	main
huvid	doc_491521501957_item	2556938	et	3	main
mida	doc_491521501957_item	2556940	et	4	main
ees	doc_491521501957_item	2556954	et	4	main
teid	doc_491521501957_item	2556956	et	4	main
ärritab	doc_491521501957_item	2556957	et	3	main
ei	doc_491521501957_item	2556964	et	4	main
petnud	doc_491521501957_item	2556972	et	4	main
kuid	doc_491521501957_item	2556973	et	4	main
tänapäeva	doc_491521501957_item	2557002	et	4	main
kuid	doc_491521501957_item	2557008	et	4	main
kindlasti	doc_491521501957_item	2557009	et	3	main
ei	doc_491521501957_item	2557010	et	4	main
ja	doc_491521501957_item	2557015	et	3	main
mida	doc_491521501957_item	2557021	et	4	main
raha	doc_491521501957_item	2557023	et	4	main
ja	doc_491521501957_item	2557024	et	3	main
on	doc_491521501957_item	2557030	et	4	main
ka	doc_491521501957_item	2557031	et	3	main
probleeme	doc_491521501957_item	2557032	et	3	main
mille	doc_491521501957_item	2557033	et	3	main
raha	doc_491521501957_item	2557039	et	4	main
saada	doc_491521501957_item	2557051	et	4	main
tõsta	doc_491521501957_item	2557055	et	4	main
on	doc_491521501957_item	2557062	et	4	main
olla	doc_491521501957_item	2557067	et	3	main
perega	doc_491521501957_item	2557069	et	3	main
kant	doc_491521501957_item	2557078	et	3	main
jätku	doc_491521501957_item	2557085	et	4	main
ole	doc_491521501956_item	2556822	et	4	main
1	doc_491521501956_item	2556829	et	2	main
intervjueeritav	doc_491521501956_item	2556831	et	4	main
mees	doc_491521501956_item	2556833	et	4	main
elukutselt	doc_491521501956_item	2556840	et	4	main
3	doc_491521501956_item	2556841	et	2	main
missugune	doc_491521501956_item	2556842	et	3	main
võiks	doc_491521501956_item	2556850	et	4	main
missugused	doc_491521501956_item	2556855	et	3	main
missugused	doc_491521501956_item	2556860	et	3	main
on	doc_491521501956_item	2556861	et	4	main
tema	doc_491521501956_item	2556862	et	4	main
tugevad	doc_491521501956_item	2556863	et	4	main
küljed	doc_491521501956_item	2556864	et	3	main
1	doc_491521501956_item	2556865	et	2	main
ma	doc_491521501956_item	2556866	et	3	main
mõtlen	doc_491521501956_item	2556867	et	3	main
et	doc_491521501956_item	2556868	et	3	main
see	doc_491521501956_item	2556869	et	3	main
on	doc_491521501956_item	2556870	et	4	main
mees	doc_491521501956_item	2556871	et	4	main
3	doc_491521501956_item	2556877	et	2	main
see	doc_491521501956_item	2556878	et	3	main
peab	doc_491521501956_item	2556880	et	4	main
arvan	doc_491521501956_item	2556886	et	3	main
töötab	doc_491521501956_item	2556894	et	3	main
öösel	doc_491521501956_item	2556897	et	4	main
viia	doc_491521501956_item	2556905	et	3	main
saada	doc_491521501957_item	2556918	et	4	main
film	doc_491521501957_item	2556927	et	3	main
nagu	doc_491521501957_item	2556934	et	3	main
hiljem	doc_491521501957_item	2556937	et	3	main
mind	doc_491521501957_item	2556952	et	4	main
küll	doc_491521501957_item	2556962	et	4	main
öelda	doc_491521501957_item	2557007	et	4	main
rikkad	doc_491521501957_item	2557014	et	4	main
võimu	doc_491521501957_item	2557016	et	4	main
käes	doc_491521501957_item	2557027	et	4	main
seda	doc_491521501957_item	2557028	et	3	main
erialal	doc_491521501957_item	2557059	et	3	main
mis	doc_491521501957_item	2557061	et	4	main
lemmikkoht	doc_491521501957_item	2557075	et	3	main
alajõe	doc_491521501957_item	2557079	et	3	main
kohtuasjades	doc_491521501957_item	2557089	et	3	main
hilistel	doc_491521501957_item	2557121	et	3	main
see	doc_491521501957_item	2557132	et	3	main
ole	doc_491521501957_item	2557144	et	4	main
elada	doc_491521501957_item	2557168	et	3	main
saksamaal	doc_491521501957_item	2557178	et	4	main
oma	doc_491521501957_item	2557187	et	4	main
kus	doc_491521501957_item	2557190	et	3	main
on	doc_491521501957_item	2557220	et	4	main
tööd	doc_491521501957_item	2557244	et	4	main
tegema	doc_491521501957_item	2557245	et	3	main
öötundidel	doc_491521501957_item	2557248	et	3	main
küsimust	doc_491521501958_item	2557250	et	4	main
nagu	doc_491521501958_item	2557274	et	3	main
elu	doc_491521501958_item	2557283	et	4	main
suurimaks	doc_491521501958_item	2557284	et	4	main
saavutuseks	doc_491521501958_item	2557285	et	4	main
ma	doc_491521501958_item	2557286	et	3	main
selline	doc_491521501958_item	2557289	et	4	main
saavutus	doc_491521501958_item	2557290	et	4	main
veel	doc_491521501958_item	2557293	et	4	main
ma	doc_491521501958_item	2557301	et	3	main
ütle	doc_491521501958_item	2557305	et	4	main
välja	doc_491521501958_item	2557307	et	4	main
hoidun	doc_491521501958_item	2557314	et	3	main
kokku	doc_491521501958_item	2557318	et	3	main
teie	doc_491521501958_item	2557323	et	4	main
ilmselt	doc_491521501958_item	2557327	et	4	main
võitlus	doc_491521501958_item	2557332	et	3	main
eestis	doc_491521501958_item	2557343	et	3	main
juures	doc_491521501958_item	2557357	et	4	main
rohkem	doc_491521501958_item	2557362	et	4	main
võimu	doc_491521501958_item	2557365	et	4	main
on	doc_491521501958_item	2557366	et	4	main
mille	doc_491521501958_item	2557373	et	3	main
raha	doc_491521501958_item	2557379	et	4	main
tahaksite	doc_491521501958_item	2557383	et	3	main
saada	doc_491521501958_item	2557391	et	4	main
targemaks	doc_491521501958_item	2557392	et	4	main
vasknarva	doc_491521501958_item	2557421	et	4	main
jaoks	doc_491521501958_item	2557423	et	4	main
ei	doc_491521501958_item	2557424	et	4	main
jätku	doc_491521501958_item	2557425	et	4	main
natukene	doc_491521501958_item	2557439	et	4	main
jõuaks	doc_491521501958_item	2557443	et	3	main
tüüpi	doc_491521501958_item	2557452	et	4	main
seetõttu	doc_491521501958_item	2557455	et	3	main
tegema	doc_491521501958_item	2557459	et	3	main
öötundidel	doc_491521501958_item	2557462	et	3	main
see	doc_491521501958_item	2557481	et	3	main
ole	doc_491521501958_item	2557495	et	4	main
mul	doc_491521501958_item	2557496	et	3	main
millises	doc_491521501958_item	2557503	et	3	main
venemaal	doc_491521501958_item	2557516	et	4	main
saksamaal	doc_491521501958_item	2557518	et	4	main
kuid	doc_491521501958_item	2557519	et	4	main
siiski	doc_491521501958_item	2557520	et	4	main
kohtus	doc_491521501956_item	2556890	et	4	main
ja	doc_491521501956_item	2556896	et	3	main
teda	doc_491521501956_item	2556899	et	4	main
tugevad	doc_491521501956_item	2556900	et	4	main
küljed	doc_491521501956_item	2556901	et	3	main
see	doc_491521501956_item	2556902	et	3	main
lapsepõlves	doc_491521501957_item	2556915	et	4	main
köitis	doc_491521501957_item	2556921	et	3	main
sööst	doc_491521501957_item	2556928	et	3	main
ja	doc_491521501957_item	2556930	et	3	main
saada	doc_491521501957_item	2556932	et	4	main
muutusid	doc_491521501957_item	2556939	et	4	main
peate	doc_491521501957_item	2556941	et	4	main
oma	doc_491521501957_item	2556942	et	4	main
saavutus	doc_491521501957_item	2556950	et	4	main
ootab	doc_491521501957_item	2556951	et	3	main
üldiselt	doc_491521501957_item	2556963	et	4	main
on	doc_491521501957_item	2556970	et	4	main
on	doc_491521501957_item	2557001	et	4	main
eestis	doc_491521501957_item	2557003	et	3	main
ole	doc_491521501957_item	2557011	et	4	main
on	doc_491521501957_item	2557026	et	4	main
teil	doc_491521501957_item	2557036	et	4	main
kommunaalkulude	doc_491521501957_item	2557040	et	3	main
eelkõige	doc_491521501957_item	2557053	et	3	main
oma	doc_491521501957_item	2557056	et	4	main
õigusteaduses	doc_491521501957_item	2557060	et	3	main
teie	doc_491521501957_item	2557063	et	4	main
jaoks	doc_491521501957_item	2557064	et	4	main
teie	doc_491521501957_item	2557074	et	4	main
vasknarva	doc_491521501957_item	2557081	et	4	main
mille	doc_491521501957_item	2557082	et	3	main
kuna	doc_491521501957_item	2557087	et	3	main
võimalikult	doc_491521501957_item	2557091	et	4	main
aidata	doc_491521501957_item	2557093	et	4	main
siis	doc_491521501957_item	2557094	et	3	main
peate	doc_491521501957_item	2557125	et	4	main
oma	doc_491521501957_item	2557126	et	4	main
küljeks	doc_491521501957_item	2557128	et	3	main
ma	doc_491521501957_item	2557129	et	3	main
ei	doc_491521501957_item	2557143	et	4	main
iga	doc_491521501957_item	2557145	et	4	main
kord	doc_491521501957_item	2557146	et	4	main
olin	doc_491521501957_item	2557152	et	3	main
eesti	doc_491521501957_item	2557166	et	4	main
venemaal	doc_491521501957_item	2557176	et	4	main
kui	doc_491521501957_item	2557177	et	3	main
peab	doc_491521501957_item	2557193	et	4	main
neid	doc_491521501957_item	2557203	et	4	main
ega	doc_491521501957_item	2557204	et	3	main
huvitu	doc_491521501957_item	2557205	et	4	main
nendest	doc_491521501957_item	2557206	et	4	main
iseloomusta	doc_491521501957_item	2557212	et	4	main
mees	doc_491521501957_item	2557221	et	4	main
arvan	doc_491521501957_item	2557223	et	3	main
et	doc_491521501957_item	2557224	et	3	main
ta	doc_491521501957_item	2557225	et	4	main
võib-olla	doc_491521501957_item	2557226	et	3	main
juurist	doc_491521501957_item	2557227	et	3	main
eriala	doc_491521501957_item	2557228	et	4	main
ma	doc_491521501957_item	2557229	et	3	main
arvan	doc_491521501957_item	2557230	et	3	main
et	doc_491521501957_item	2557231	et	3	main
ta	doc_491521501957_item	2557232	et	4	main
ka	doc_491521501957_item	2557246	et	3	main
hilistel	doc_491521501957_item	2557247	et	3	main
13	doc_491521501958_item	2557249	et	2	main
13	doc_491521501958_item	2557251	et	2	main
küsimust	doc_491521501958_item	2557252	et	4	main
saada	doc_491521501958_item	2557256	et	4	main
luurajaks	doc_491521501958_item	2557259	et	4	main
mind	doc_491521501958_item	2557260	et	4	main
väga	doc_491521501958_item	2557263	et	3	main
tolleaegne	doc_491521501958_item	2557264	et	3	main
dessantväelasest	doc_491521501958_item	2557265	et	3	main
tehtud	doc_491521501958_item	2557266	et	4	main
film	doc_491521501958_item	2557267	et	3	main
sööst	doc_491521501958_item	2557268	et	3	main
eritsooni	doc_491521501958_item	2557269	et	4	main
ja	doc_491521501958_item	2557270	et	3	main
tahtsin	doc_491521501958_item	2557271	et	3	main
nemad	doc_491521501958_item	2557275	et	3	main
13	doc_491521501957_item	2556911	et	2	main
luurajaks	doc_491521501957_item	2556919	et	4	main
ka	doc_491521501957_item	2556922	et	3	main
tolleaegne	doc_491521501957_item	2556924	et	3	main
samasuguseks	doc_491521501957_item	2556933	et	4	main
suurimaks	doc_491521501957_item	2556944	et	4	main
saavutuseks	doc_491521501957_item	2556945	et	4	main
ma	doc_491521501957_item	2556946	et	3	main
loodan	doc_491521501957_item	2556947	et	3	main
et	doc_491521501957_item	2556948	et	3	main
selline	doc_491521501957_item	2556949	et	4	main
veel	doc_491521501957_item	2556953	et	4	main
mis	doc_491521501957_item	2556955	et	4	main
reeturlus	doc_491521501957_item	2556958	et	4	main
ja	doc_491521501957_item	2556959	et	3	main
ütle	doc_491521501957_item	2556965	et	4	main
inimestele	doc_491521501957_item	2556966	et	3	main
mind	doc_491521501957_item	2556971	et	4	main
kellel	doc_491521501957_item	2557000	et	4	main
ainult	doc_491521501957_item	2557013	et	4	main
rohkem	doc_491521501957_item	2557022	et	4	main
võimu	doc_491521501957_item	2557025	et	4	main
peale	doc_491521501957_item	2557034	et	4	main
kulub	doc_491521501957_item	2557035	et	3	main
rohkem	doc_491521501957_item	2557038	et	4	main
peale	doc_491521501957_item	2557041	et	4	main
tahaksite	doc_491521501957_item	2557043	et	3	main
osta	doc_491521501957_item	2557044	et	4	main
ma	doc_491521501957_item	2557045	et	3	main
tahan	doc_491521501957_item	2557046	et	3	main
väga	doc_491521501957_item	2557047	et	3	main
palju	doc_491521501957_item	2557048	et	4	main
lugeda	doc_491521501957_item	2557049	et	3	main
et	doc_491521501957_item	2557050	et	3	main
tahaks	doc_491521501957_item	2557054	et	3	main
valitud	doc_491521501957_item	2557058	et	4	main
parim	doc_491521501957_item	2557065	et	4	main
puhkus	doc_491521501957_item	2557066	et	3	main
koos	doc_491521501957_item	2557068	et	4	main
kusagil	doc_491521501957_item	2557070	et	3	main
peipsi-äärne	doc_491521501957_item	2557077	et	3	main
karjamaa	doc_491521501957_item	2557080	et	4	main
jaoks	doc_491521501957_item	2557083	et	4	main
ei	doc_491521501957_item	2557084	et	4	main
tahan	doc_491521501957_item	2557088	et	3	main
hästi	doc_491521501957_item	2557092	et	3	main
öötundidel	doc_491521501957_item	2557122	et	3	main
arvan	doc_491521501957_item	2557130	et	3	main
järjekindlus	doc_491521501957_item	2557134	et	4	main
mida	doc_491521501957_item	2557149	et	4	main
jätta	doc_491521501957_item	2557161	et	3	main
tahaksite	doc_491521501957_item	2557167	et	3	main
ma	doc_491521501957_item	2557169	et	3	main
elanud	doc_491521501957_item	2557171	et	4	main
teinud	doc_491521501957_item	2557173	et	4	main
tööd	doc_491521501957_item	2557174	et	4	main
nii	doc_491521501957_item	2557175	et	3	main
on	doc_491521501957_item	2557181	et	4	main
eestis	doc_491521501957_item	2557182	et	3	main
mul	doc_491521501957_item	2557183	et	3	main
kõige	doc_491521501957_item	2557184	et	4	main
isa	doc_491521501957_item	2557188	et	4	main
tõsine	doc_491521501957_item	2557210	et	4	main
asi	doc_491521501957_item	2557211	et	4	main
dessantväelasest	doc_491521501957_item	2556925	et	3	main
tahtsin	doc_491521501957_item	2556931	et	3	main
nemad	doc_491521501957_item	2556935	et	3	main
elu	doc_491521501957_item	2556943	et	4	main
valetamine	doc_491521501957_item	2556960	et	4	main
ma	doc_491521501957_item	2556961	et	3	main
välja	doc_491521501957_item	2556967	et	4	main
et	doc_491521501957_item	2556968	et	3	main
nad	doc_491521501957_item	2556969	et	3	main
hoidun	doc_491521501957_item	2556974	et	3	main
edaspidi	doc_491521501957_item	2556975	et	3	main
selliste	doc_491521501957_item	2556976	et	4	main
inimestega	doc_491521501957_item	2556977	et	3	main
kokku	doc_491521501957_item	2556978	et	3	main
puutumast	doc_491521501957_item	2556979	et	4	main
mis	doc_491521501957_item	2556980	et	4	main
on	doc_491521501957_item	2556981	et	4	main
olnud	doc_491521501957_item	2556982	et	4	main
teie	doc_491521501957_item	2556983	et	4	main
elu	doc_491521501957_item	2556984	et	4	main
pööraseim	doc_491521501957_item	2556985	et	4	main
tegu	doc_491521501957_item	2556986	et	4	main
ongi	doc_491521501957_item	2556988	et	4	main
see	doc_491521501957_item	2556989	et	3	main
minu	doc_491521501957_item	2556990	et	3	main
ilmselt	doc_491521501957_item	2556987	et	4	main
praegune	doc_491521501957_item	2556991	et	3	main
võitlus	doc_491521501957_item	2556992	et	3	main
selle	doc_491521501957_item	2556993	et	4	main
nimel	doc_491521501957_item	2556994	et	3	main
et	doc_491521501957_item	2556995	et	3	main
kohlta-järve	doc_491521501957_item	2556996	et	4	main
õhk	doc_491521501957_item	2556997	et	3	main
puhtaks	doc_491521501957_item	2556998	et	3	main
saaks	doc_491521501957_item	2556999	et	3	main
hea	doc_491521501957_item	2557004	et	4	main
elada	doc_491521501957_item	2557005	et	3	main
raske	doc_491521501957_item	2557006	et	4	main
need	doc_491521501957_item	2557012	et	3	main
juures	doc_491521501957_item	2557017	et	4	main
olevad	doc_491521501957_item	2557018	et	4	main
inimesed	doc_491521501957_item	2557019	et	3	main
sest	doc_491521501957_item	2557020	et	4	main
rohkem	doc_491521501957_item	2557029	et	4	main
kõige	doc_491521501957_item	2557037	et	4	main
mida	doc_491521501957_item	2557042	et	4	main
targemaks	doc_491521501957_item	2557052	et	4	main
taset	doc_491521501957_item	2557057	et	3	main
looduses	doc_491521501957_item	2557071	et	4	main
milline	doc_491521501957_item	2557072	et	3	main
on	doc_491521501957_item	2557073	et	4	main
ida-virumaal	doc_491521501957_item	2557076	et	4	main
aega	doc_491521501957_item	2557086	et	4	main
inimesi	doc_491521501957_item	2557090	et	4	main
tundub	doc_491521501957_item	2557095	et	3	main
alati	doc_491521501957_item	2557096	et	4	main
et	doc_491521501957_item	2557097	et	3	main
oleks	doc_491521501957_item	2557098	et	3	main
natukene	doc_491521501957_item	2557099	et	4	main
rohkem	doc_491521501957_item	2557100	et	4	main
aega	doc_491521501957_item	2557101	et	4	main
siis	doc_491521501957_item	2557102	et	3	main
jõuaks	doc_491521501957_item	2557103	et	3	main
veelgi	doc_491521501957_item	2557104	et	4	main
paremini	doc_491521501957_item	2557105	et	4	main
valmistuda	doc_491521501957_item	2557106	et	3	main
kuid	doc_491521501957_item	2557107	et	4	main
ma	doc_491521501957_item	2557108	et	3	main
olen	doc_491521501957_item	2557109	et	3	main
loomult	doc_491521501957_item	2557110	et	3	main
öökulli	doc_491521501957_item	2557111	et	4	main
tüüpi	doc_491521501957_item	2557112	et	4	main
inimene	doc_491521501957_item	2557113	et	3	main
ja	doc_491521501957_item	2557114	et	3	main
seetõttu	doc_491521501957_item	2557115	et	3	main
olen	doc_491521501957_item	2557116	et	3	main
harjunud	doc_491521501957_item	2557117	et	4	main
tööd	doc_491521501957_item	2557118	et	4	main
tegema	doc_491521501957_item	2557119	et	3	main
ka	doc_491521501957_item	2557120	et	3	main
millist	doc_491521501957_item	2557123	et	3	main
tugevaimaks	doc_491521501957_item	2557127	et	4	main
on	doc_491521501957_item	2557133	et	4	main
viia	doc_491521501957_item	2557135	et	3	main
asjad	doc_491521501957_item	2557136	et	3	main
lõpuni	doc_491521501957_item	2557137	et	3	main
isegi	doc_491521501957_item	2557138	et	4	main
siis	doc_491521501957_item	2557139	et	3	main
kui	doc_491521501957_item	2557140	et	3	main
see	doc_491521501957_item	2557141	et	3	main
tulemus	doc_491521501957_item	2557142	et	3	main
päris	doc_491521501957_item	2557147	et	4	main
see	doc_491521501957_item	2557148	et	3	main
peale	doc_491521501957_item	2557165	et	4	main
olen	doc_491521501957_item	2557170	et	3	main
ja	doc_491521501957_item	2557172	et	3	main
siiski	doc_491521501957_item	2557180	et	4	main
järgin	doc_491521501957_item	2557186	et	3	main
öeldut	doc_491521501957_item	2557189	et	4	main
omadust	doc_491521501957_item	2557124	et	4	main
et	doc_491521501957_item	2557131	et	3	main
ma	doc_491521501957_item	2557150	et	3	main
alguses	doc_491521501957_item	2557151	et	4	main
lootnud	doc_491521501957_item	2557153	et	4	main
ei	doc_491521501957_item	2557154	et	4	main
ole	doc_491521501957_item	2557155	et	4	main
mul	doc_491521501957_item	2557156	et	3	main
kombeks	doc_491521501957_item	2557157	et	4	main
oma	doc_491521501957_item	2557158	et	4	main
ettevõtmisi	doc_491521501957_item	2557159	et	3	main
pooleli	doc_491521501957_item	2557160	et	3	main
span	doc_491521501957_item	2557162	et	4	main
millises	doc_491521501957_item	2557163	et	3	main
riigis	doc_491521501957_item	2557164	et	3	main
kuid	doc_491521501957_item	2557179	et	4	main
parem	doc_491521501957_item	2557185	et	4	main
ka	doc_491521501957_item	2557194	et	3	main
elama	doc_491521501957_item	2557195	et	3	main
kas	doc_491521501957_item	2557196	et	3	main
loete	doc_491521501957_item	2557197	et	4	main
horoskoope	doc_491521501957_item	2557198	et	3	main
ei	doc_491521501957_item	2557199	et	4	main
ma	doc_491521501957_item	2557200	et	3	main
ei	doc_491521501957_item	2557201	et	4	main
usu	doc_491521501957_item	2557202	et	4	main
ole	doc_491521501957_item	2557209	et	4	main
töötab	doc_491521501957_item	2557233	et	3	main
kohus	doc_491521501957_item	2557234	et	4	main
ta	doc_491521501957_item	2557235	et	4	main
tüüpi	doc_491521501957_item	2557238	et	4	main
ja	doc_491521501957_item	2557240	et	3	main
oli	doc_491521501957_item	2557242	et	3	main
kelleks	doc_491521501958_item	2557253	et	4	main
tahtsite	doc_491521501958_item	2557254	et	3	main
saada	doc_491521501958_item	2557258	et	4	main
köitis	doc_491521501958_item	2557261	et	3	main
ka	doc_491521501958_item	2557262	et	3	main
samasuguseks	doc_491521501958_item	2557273	et	4	main
hiljem	doc_491521501958_item	2557277	et	3	main
teid	doc_491521501958_item	2557296	et	4	main
ärritab	doc_491521501958_item	2557297	et	3	main
inimestele	doc_491521501958_item	2557306	et	3	main
et	doc_491521501958_item	2557308	et	3	main
petnud	doc_491521501958_item	2557312	et	4	main
selliste	doc_491521501958_item	2557316	et	4	main
pööraseim	doc_491521501958_item	2557325	et	4	main
tegu	doc_491521501958_item	2557326	et	4	main
ongi	doc_491521501958_item	2557328	et	4	main
see	doc_491521501958_item	2557329	et	3	main
minu	doc_491521501958_item	2557330	et	3	main
praegune	doc_491521501958_item	2557331	et	3	main
selle	doc_491521501958_item	2557333	et	4	main
nimel	doc_491521501958_item	2557334	et	3	main
et	doc_491521501958_item	2557335	et	3	main
on	doc_491521501958_item	2557341	et	4	main
hea	doc_491521501958_item	2557344	et	4	main
raske	doc_491521501958_item	2557346	et	4	main
öelda	doc_491521501958_item	2557347	et	4	main
olevad	doc_491521501958_item	2557358	et	4	main
seda	doc_491521501958_item	2557368	et	3	main
rohkem	doc_491521501958_item	2557369	et	4	main
rohkem	doc_491521501958_item	2557378	et	4	main
väga	doc_491521501958_item	2557387	et	3	main
et	doc_491521501958_item	2557390	et	3	main
kuna	doc_491521501958_item	2557427	et	3	main
inimesi	doc_491521501958_item	2557430	et	4	main
kuid	doc_491521501958_item	2557447	et	4	main
ma	doc_491521501958_item	2557448	et	3	main
olen	doc_491521501958_item	2557449	et	3	main
loomult	doc_491521501958_item	2557450	et	3	main
öökulli	doc_491521501958_item	2557451	et	4	main
harjunud	doc_491521501958_item	2557457	et	4	main
tööd	doc_491521501958_item	2557458	et	4	main
hilistel	doc_491521501958_item	2557461	et	3	main
päris	doc_491521501958_item	2557487	et	4	main
see	doc_491521501958_item	2557488	et	3	main
mida	doc_491521501958_item	2557489	et	4	main
ma	doc_491521501958_item	2557490	et	3	main
alguses	doc_491521501958_item	2557491	et	4	main
olin	doc_491521501958_item	2557492	et	3	main
span	doc_491521501958_item	2557502	et	4	main
tööd	doc_491521501958_item	2557514	et	4	main
kui	doc_491521501958_item	2557517	et	3	main
eestis	doc_491521501958_item	2557522	et	3	main
peab	doc_491521501958_item	2557533	et	4	main
ka	doc_491521501958_item	2557534	et	3	main
elama	doc_491521501958_item	2557535	et	3	main
kas	doc_491521501958_item	2557536	et	3	main
loete	doc_491521501958_item	2557537	et	4	main
ei	doc_491521501958_item	2557541	et	4	main
huvitu	doc_491521501958_item	2557545	et	4	main
nendest	doc_491521501958_item	2557546	et	4	main
see	doc_491521501958_item	2557547	et	3	main
see	doc_491521501958_item	2557558	et	3	main
sündisid	doc_491521501957_item	2557191	et	4	main
seal	doc_491521501957_item	2557192	et	4	main
see	doc_491521501957_item	2557207	et	3	main
ei	doc_491521501957_item	2557208	et	4	main
inimest	doc_491521501957_item	2557213	et	3	main
kellest	doc_491521501957_item	2557214	et	4	main
kirjutatakse	doc_491521501957_item	2557215	et	3	main
ma	doc_491521501957_item	2557216	et	3	main
arvan	doc_491521501957_item	2557217	et	3	main
et	doc_491521501957_item	2557218	et	3	main
intervjueeritav	doc_491521501957_item	2557219	et	4	main
ma	doc_491521501957_item	2557222	et	3	main
öökulli	doc_491521501957_item	2557237	et	4	main
inimene	doc_491521501957_item	2557239	et	3	main
unistasin	doc_491521501958_item	2557257	et	3	main
saada	doc_491521501958_item	2557272	et	4	main
muutusid	doc_491521501958_item	2557279	et	4	main
peate	doc_491521501958_item	2557281	et	4	main
oma	doc_491521501958_item	2557282	et	4	main
loodan	doc_491521501958_item	2557287	et	3	main
mind	doc_491521501958_item	2557292	et	4	main
ees	doc_491521501958_item	2557294	et	4	main
mis	doc_491521501958_item	2557295	et	4	main
mind	doc_491521501958_item	2557311	et	4	main
edaspidi	doc_491521501958_item	2557315	et	3	main
olnud	doc_491521501958_item	2557322	et	4	main
kohlta-järve	doc_491521501958_item	2557336	et	4	main
õhk	doc_491521501958_item	2557337	et	3	main
puhtaks	doc_491521501958_item	2557338	et	3	main
kellel	doc_491521501958_item	2557340	et	4	main
ainult	doc_491521501958_item	2557353	et	4	main
rikkad	doc_491521501958_item	2557354	et	4	main
ja	doc_491521501958_item	2557355	et	3	main
mida	doc_491521501958_item	2557361	et	4	main
ja	doc_491521501958_item	2557364	et	3	main
käes	doc_491521501958_item	2557367	et	4	main
kõige	doc_491521501958_item	2557377	et	4	main
mida	doc_491521501958_item	2557382	et	4	main
osta	doc_491521501958_item	2557384	et	4	main
oli	doc_491521501957_item	2557236	et	3	main
seetõttu	doc_491521501957_item	2557241	et	3	main
harjunud	doc_491521501957_item	2557243	et	4	main
lapsepõlves	doc_491521501958_item	2557255	et	4	main
aga	doc_491521501958_item	2557276	et	3	main
huvid	doc_491521501958_item	2557278	et	3	main
ootab	doc_491521501958_item	2557291	et	3	main
valetamine	doc_491521501958_item	2557300	et	4	main
küll	doc_491521501958_item	2557302	et	4	main
üldiselt	doc_491521501958_item	2557303	et	4	main
kuid	doc_491521501958_item	2557313	et	4	main
mis	doc_491521501958_item	2557320	et	4	main
on	doc_491521501958_item	2557321	et	4	main
tänapäeva	doc_491521501958_item	2557342	et	4	main
elada	doc_491521501958_item	2557345	et	3	main
kuid	doc_491521501958_item	2557348	et	4	main
kindlasti	doc_491521501958_item	2557349	et	3	main
võimu	doc_491521501958_item	2557356	et	4	main
sest	doc_491521501958_item	2557360	et	4	main
raha	doc_491521501958_item	2557363	et	4	main
probleeme	doc_491521501958_item	2557372	et	3	main
kommunaalkulude	doc_491521501958_item	2557380	et	3	main
ma	doc_491521501958_item	2557385	et	3	main
tahan	doc_491521501958_item	2557386	et	3	main
palju	doc_491521501958_item	2557388	et	4	main
lugeda	doc_491521501958_item	2557389	et	3	main
aega	doc_491521501958_item	2557426	et	4	main
tahan	doc_491521501958_item	2557428	et	3	main
et	doc_491521501958_item	2557437	et	3	main
tulemus	doc_491521501958_item	2557482	et	3	main
ole	doc_491521501958_item	2557484	et	4	main
iga	doc_491521501958_item	2557485	et	4	main
kord	doc_491521501958_item	2557486	et	4	main
lootnud	doc_491521501958_item	2557493	et	4	main
oma	doc_491521501958_item	2557498	et	4	main
ettevõtmisi	doc_491521501958_item	2557499	et	3	main
eesti	doc_491521501958_item	2557506	et	4	main
öeldut	doc_491521501958_item	2557529	et	4	main
kus	doc_491521501958_item	2557530	et	3	main
seal	doc_491521501958_item	2557532	et	4	main
ei	doc_491521501958_item	2557539	et	4	main
usu	doc_491521501958_item	2557542	et	4	main
ega	doc_491521501958_item	2557544	et	3	main
tõsine	doc_491521501958_item	2557550	et	4	main
intervju	doc_491521501958_item	2557557	et	4	main
on	doc_491521501958_item	2557559	et	4	main
tema	doc_491521501958_item	2557561	et	4	main
eriala	doc_491521501958_item	2557562	et	4	main
ta	doc_491521501958_item	2557566	et	4	main
tüüpi	doc_491521501958_item	2557578	et	4	main
inimene	doc_491521501958_item	2557579	et	3	main
seetõttu	doc_491521501958_item	2557581	et	3	main
teda	doc_491521501958_item	2557589	et	4	main
ja	doc_491521501958_item	2557592	et	3	main
valetamine	doc_491521501958_item	2557593	et	4	main
on	doc_491521501958_item	2557598	et	4	main
sees	doc_491521501958_item	2557605	et	4	main
mida	doc_491521501958_item	2557280	et	4	main
et	doc_491521501958_item	2557288	et	3	main
reeturlus	doc_491521501958_item	2557298	et	4	main
ja	doc_491521501958_item	2557299	et	3	main
ei	doc_491521501958_item	2557304	et	4	main
nad	doc_491521501958_item	2557309	et	3	main
on	doc_491521501958_item	2557310	et	4	main
inimestega	doc_491521501958_item	2557317	et	3	main
puutumast	doc_491521501958_item	2557319	et	4	main
elu	doc_491521501958_item	2557324	et	4	main
saaks	doc_491521501958_item	2557339	et	3	main
ei	doc_491521501958_item	2557350	et	4	main
ole	doc_491521501958_item	2557351	et	4	main
need	doc_491521501958_item	2557352	et	3	main
inimesed	doc_491521501958_item	2557359	et	3	main
on	doc_491521501958_item	2557370	et	4	main
ka	doc_491521501958_item	2557371	et	3	main
peale	doc_491521501958_item	2557374	et	4	main
kulub	doc_491521501958_item	2557375	et	3	main
teil	doc_491521501958_item	2557376	et	4	main
peale	doc_491521501958_item	2557381	et	4	main
eelkõige	doc_491521501958_item	2557393	et	3	main
tahaks	doc_491521501958_item	2557394	et	3	main
tõsta	doc_491521501958_item	2557395	et	4	main
oma	doc_491521501958_item	2557396	et	4	main
valitud	doc_491521501958_item	2557398	et	4	main
taset	doc_491521501958_item	2557397	et	3	main
erialal	doc_491521501958_item	2557399	et	3	main
õigusteaduses	doc_491521501958_item	2557400	et	3	main
mis	doc_491521501958_item	2557401	et	4	main
on	doc_491521501958_item	2557402	et	4	main
teie	doc_491521501958_item	2557403	et	4	main
jaoks	doc_491521501958_item	2557404	et	4	main
parim	doc_491521501958_item	2557405	et	4	main
puhkus	doc_491521501958_item	2557406	et	3	main
olla	doc_491521501958_item	2557407	et	3	main
koos	doc_491521501958_item	2557408	et	4	main
perega	doc_491521501958_item	2557409	et	3	main
kusagil	doc_491521501958_item	2557410	et	3	main
looduses	doc_491521501958_item	2557411	et	4	main
milline	doc_491521501958_item	2557412	et	3	main
on	doc_491521501958_item	2557413	et	4	main
teie	doc_491521501958_item	2557414	et	4	main
lemmikkoht	doc_491521501958_item	2557415	et	3	main
ida-virumaal	doc_491521501958_item	2557416	et	4	main
peipsi-äärne	doc_491521501958_item	2557417	et	3	main
kant	doc_491521501958_item	2557418	et	3	main
alajõe	doc_491521501958_item	2557419	et	3	main
karjamaa	doc_491521501958_item	2557420	et	4	main
kohtuasjades	doc_491521501958_item	2557429	et	3	main
võimalikult	doc_491521501958_item	2557431	et	4	main
hästi	doc_491521501958_item	2557432	et	3	main
aidata	doc_491521501958_item	2557433	et	4	main
siis	doc_491521501958_item	2557434	et	3	main
tundub	doc_491521501958_item	2557435	et	3	main
alati	doc_491521501958_item	2557436	et	4	main
rohkem	doc_491521501958_item	2557440	et	4	main
siis	doc_491521501958_item	2557442	et	3	main
inimene	doc_491521501958_item	2557453	et	3	main
ja	doc_491521501958_item	2557454	et	3	main
kui	doc_491521501958_item	2557480	et	3	main
ei	doc_491521501958_item	2557494	et	4	main
jätta	doc_491521501958_item	2557501	et	3	main
riigis	doc_491521501958_item	2557504	et	3	main
mille	doc_491521501958_item	2557422	et	3	main
oleks	doc_491521501958_item	2557438	et	3	main
aega	doc_491521501958_item	2557441	et	4	main
veelgi	doc_491521501958_item	2557444	et	4	main
paremini	doc_491521501958_item	2557445	et	4	main
valmistuda	doc_491521501958_item	2557446	et	3	main
olen	doc_491521501958_item	2557456	et	3	main
ka	doc_491521501958_item	2557460	et	3	main
millist	doc_491521501958_item	2557463	et	3	main
omadust	doc_491521501958_item	2557464	et	4	main
peate	doc_491521501958_item	2557465	et	4	main
oma	doc_491521501958_item	2557466	et	4	main
tugevaimaks	doc_491521501958_item	2557467	et	4	main
küljeks	doc_491521501958_item	2557468	et	3	main
ma	doc_491521501958_item	2557469	et	3	main
arvan	doc_491521501958_item	2557470	et	3	main
et	doc_491521501958_item	2557471	et	3	main
see	doc_491521501958_item	2557472	et	3	main
on	doc_491521501958_item	2557473	et	4	main
järjekindlus	doc_491521501958_item	2557474	et	4	main
viia	doc_491521501958_item	2557475	et	3	main
asjad	doc_491521501958_item	2557476	et	3	main
lõpuni	doc_491521501958_item	2557477	et	3	main
isegi	doc_491521501958_item	2557478	et	4	main
siis	doc_491521501958_item	2557479	et	3	main
ei	doc_491521501958_item	2557483	et	4	main
kombeks	doc_491521501958_item	2557497	et	4	main
pooleli	doc_491521501958_item	2557500	et	3	main
peale	doc_491521501958_item	2557505	et	4	main
ja	doc_491521501958_item	2557512	et	3	main
teinud	doc_491521501958_item	2557513	et	4	main
on	doc_491521501958_item	2557521	et	4	main
ma	doc_491521501958_item	2557540	et	3	main
neid	doc_491521501958_item	2557543	et	4	main
annab	doc_491521501958_item	2557556	et	3	main
jurist	doc_491521501958_item	2557564	et	3	main
tõsta	doc_491521501958_item	2557568	et	4	main
taset	doc_491521501958_item	2557570	et	3	main
valitud	doc_491521501958_item	2557571	et	4	main
erialal	doc_491521501958_item	2557572	et	3	main
öökulli	doc_491521501958_item	2557577	et	4	main
tegema	doc_491521501958_item	2557585	et	3	main
reeturlus	doc_491521501958_item	2557591	et	4	main
võimu	doc_491521501958_item	2557602	et	4	main
järtku	doc_491521501958_item	2557623	et	4	main
inimesi	doc_491521501958_item	2557627	et	4	main
hästi	doc_491521501958_item	2557629	et	3	main
aidata	doc_491521501958_item	2557630	et	4	main
ma	doc_491521501958_item	2557631	et	3	main
arvan	doc_491521501958_item	2557632	et	3	main
et	doc_491521501958_item	2557633	et	3	main
kohtus	doc_491521501958_item	2557637	et	4	main
tal	doc_491521501958_item	2557639	et	3	main
tugev	doc_491521501958_item	2557641	et	4	main
ja	doc_491521501958_item	2557642	et	3	main
aus	doc_491521501958_item	2557643	et	4	main
iseloom	doc_491521501958_item	2557644	et	3	main
ja	doc_491521501958_item	2557645	et	3	main
kelleks	doc_491521501959_item	2557656	et	4	main
tahtsite	doc_491521501959_item	2557657	et	3	main
lapsepõlves	doc_491521501959_item	2557658	et	4	main
ka	doc_491521501959_item	2557665	et	3	main
väga	doc_491521501959_item	2557666	et	3	main
tehtud	doc_491521501959_item	2557669	et	4	main
sööst	doc_491521501959_item	2557671	et	3	main
nagu	doc_491521501959_item	2557677	et	3	main
aga	doc_491521501959_item	2557679	et	3	main
elu	doc_491521501959_item	2557686	et	4	main
suurimaks	doc_491521501959_item	2557687	et	4	main
ootab	doc_491521501959_item	2557694	et	3	main
ütle	doc_491521501959_item	2557708	et	4	main
inimestele	doc_491521501959_item	2557709	et	3	main
on	doc_491521501959_item	2557713	et	4	main
teie	doc_491521501959_item	2557726	et	4	main
elu	doc_491521501959_item	2557727	et	4	main
nimel	doc_491521501959_item	2557737	et	3	main
hea	doc_491521501959_item	2557747	et	4	main
elada	doc_491521501959_item	2557748	et	3	main
võimu	doc_491521501959_item	2557759	et	4	main
raha	doc_491521501959_item	2557766	et	4	main
ja	doc_491521501959_item	2557767	et	3	main
võimu	doc_491521501959_item	2557768	et	4	main
tõsta	doc_491521501959_item	2557798	et	4	main
on	doc_491521501959_item	2557805	et	4	main
teie	doc_491521501959_item	2557817	et	4	main
jaoks	doc_491521501959_item	2557826	et	4	main
inimesi	doc_491521501959_item	2557833	et	4	main
siis	doc_491521501959_item	2557837	et	3	main
oleks	doc_491521501959_item	2557841	et	3	main
paremini	doc_491521501959_item	2557848	et	4	main
valmistuda	doc_491521501959_item	2557849	et	3	main
kuid	doc_491521501959_item	2557850	et	4	main
peate	doc_491521501959_item	2557868	et	4	main
ma	doc_491521501959_item	2557872	et	3	main
et	doc_491521501959_item	2557874	et	3	main
järjekindlus	doc_491521501959_item	2557877	et	4	main
isegi	doc_491521501959_item	2557881	et	4	main
mida	doc_491521501959_item	2557892	et	4	main
alguses	doc_491521501959_item	2557894	et	4	main
saksamaal	doc_491521501959_item	2557921	et	4	main
siiski	doc_491521501959_item	2557923	et	4	main
kõige	doc_491521501959_item	2557927	et	4	main
järgin	doc_491521501959_item	2557929	et	3	main
oma	doc_491521501959_item	2557930	et	4	main
ei	doc_491521501959_item	2557942	et	4	main
ei	doc_491521501959_item	2557944	et	4	main
usu	doc_491521501959_item	2557945	et	4	main
tahaksite	doc_491521501958_item	2557507	et	3	main
elada	doc_491521501958_item	2557508	et	3	main
ma	doc_491521501958_item	2557509	et	3	main
olen	doc_491521501958_item	2557510	et	3	main
elanud	doc_491521501958_item	2557511	et	4	main
nii	doc_491521501958_item	2557515	et	3	main
mul	doc_491521501958_item	2557523	et	3	main
parem	doc_491521501958_item	2557525	et	4	main
sündisid	doc_491521501958_item	2557531	et	4	main
horoskoope	doc_491521501958_item	2557538	et	3	main
ei	doc_491521501958_item	2557548	et	4	main
tahab	doc_491521501958_item	2557567	et	3	main
oma	doc_491521501958_item	2557569	et	4	main
loomult	doc_491521501958_item	2557576	et	3	main
ja	doc_491521501958_item	2557580	et	3	main
ärritab	doc_491521501958_item	2557590	et	3	main
kellel	doc_491521501958_item	2557597	et	4	main
rohkem	doc_491521501958_item	2557599	et	4	main
raha	doc_491521501958_item	2557600	et	4	main
ja	doc_491521501958_item	2557601	et	3	main
et	doc_491521501958_item	2557625	et	3	main
luurajaks	doc_491521501959_item	2557662	et	4	main
ja	doc_491521501959_item	2557673	et	3	main
tahtsin	doc_491521501959_item	2557674	et	3	main
nemad	doc_491521501959_item	2557678	et	3	main
teid	doc_491521501959_item	2557699	et	4	main
ärritab	doc_491521501959_item	2557700	et	3	main
ei	doc_491521501959_item	2557707	et	4	main
nad	doc_491521501959_item	2557712	et	3	main
mind	doc_491521501959_item	2557714	et	4	main
selliste	doc_491521501959_item	2557719	et	4	main
inimestega	doc_491521501959_item	2557720	et	3	main
oma	doc_491521501958_item	2557527	et	4	main
kõige	doc_491521501958_item	2557524	et	4	main
järgin	doc_491521501958_item	2557526	et	3	main
isa	doc_491521501958_item	2557528	et	4	main
ole	doc_491521501958_item	2557549	et	4	main
asi	doc_491521501958_item	2557551	et	4	main
ma	doc_491521501958_item	2557552	et	3	main
arvan	doc_491521501958_item	2557553	et	3	main
et	doc_491521501958_item	2557554	et	3	main
kes	doc_491521501958_item	2557555	et	4	main
on	doc_491521501958_item	2557563	et	4	main
õigusteaduses	doc_491521501958_item	2557573	et	3	main
arvab	doc_491521501958_item	2557595	et	3	main
on	doc_491521501958_item	2557603	et	4	main
käes	doc_491521501958_item	2557604	et	4	main
nendel	doc_491521501958_item	2557606	et	4	main
on	doc_491521501958_item	2557607	et	4	main
ka	doc_491521501958_item	2557608	et	3	main
probleemid	doc_491521501958_item	2557609	et	3	main
samuti	doc_491521501958_item	2557610	et	3	main
ta	doc_491521501958_item	2557611	et	4	main
arvab	doc_491521501958_item	2557612	et	3	main
et	doc_491521501958_item	2557613	et	3	main
eestis	doc_491521501958_item	2557614	et	3	main
on	doc_491521501958_item	2557615	et	4	main
kõige	doc_491521501958_item	2557616	et	4	main
parem	doc_491521501958_item	2557617	et	4	main
elada	doc_491521501958_item	2557618	et	3	main
ja	doc_491521501958_item	2557619	et	3	main
töötada	doc_491521501958_item	2557620	et	3	main
talle	doc_491521501958_item	2557621	et	4	main
võimalikult	doc_491521501958_item	2557628	et	4	main
töötada	doc_491521501958_item	2557636	et	3	main
grupp	doc_491521501958_item	2557651	et	3	main
saada	doc_491521501959_item	2557659	et	4	main
mind	doc_491521501959_item	2557663	et	4	main
muutusid	doc_491521501959_item	2557682	et	4	main
saavutuseks	doc_491521501959_item	2557688	et	4	main
ma	doc_491521501959_item	2557689	et	3	main
loodan	doc_491521501959_item	2557690	et	3	main
et	doc_491521501959_item	2557691	et	3	main
mind	doc_491521501959_item	2557695	et	4	main
ees	doc_491521501959_item	2557697	et	4	main
mis	doc_491521501959_item	2557698	et	4	main
üldiselt	doc_491521501959_item	2557706	et	4	main
et	doc_491521501959_item	2557711	et	3	main
puutumast	doc_491521501959_item	2557722	et	4	main
pööraseim	doc_491521501959_item	2557728	et	4	main
praegune	doc_491521501959_item	2557734	et	3	main
et	doc_491521501959_item	2557738	et	3	main
on	doc_491521501959_item	2557744	et	4	main
tänapäeva	doc_491521501959_item	2557745	et	4	main
eestis	doc_491521501959_item	2557746	et	3	main
kindlasti	doc_491521501959_item	2557752	et	3	main
need	doc_491521501959_item	2557755	et	3	main
ainult	doc_491521501959_item	2557756	et	4	main
rikkad	doc_491521501959_item	2557757	et	4	main
ja	doc_491521501959_item	2557758	et	3	main
inimesed	doc_491521501959_item	2557762	et	3	main
mida	doc_491521501959_item	2557764	et	4	main
rohkem	doc_491521501959_item	2557765	et	4	main
eelkõige	doc_491521501959_item	2557796	et	3	main
tahaks	doc_491521501959_item	2557797	et	3	main
on	doc_491521501959_item	2557816	et	4	main
peipsi-äärne	doc_491521501959_item	2557820	et	3	main
kant	doc_491521501959_item	2557821	et	3	main
aega	doc_491521501959_item	2557829	et	4	main
kuna	doc_491521501959_item	2557830	et	3	main
mees	doc_491521501958_item	2557560	et	4	main
eelkõige	doc_491521501958_item	2557565	et	3	main
ta	doc_491521501958_item	2557574	et	4	main
on	doc_491521501958_item	2557575	et	4	main
on	doc_491521501958_item	2557582	et	4	main
harjunud	doc_491521501958_item	2557583	et	4	main
tööd	doc_491521501958_item	2557584	et	4	main
ka	doc_491521501958_item	2557586	et	3	main
hilistel	doc_491521501958_item	2557587	et	3	main
öötundidel	doc_491521501958_item	2557588	et	3	main
ta	doc_491521501958_item	2557594	et	4	main
et	doc_491521501958_item	2557596	et	3	main
aega	doc_491521501958_item	2557624	et	4	main
kohtuasjades	doc_491521501958_item	2557626	et	3	main
võiks	doc_491521501958_item	2557635	et	4	main
sellepärast	doc_491521501958_item	2557638	et	3	main
on	doc_491521501958_item	2557640	et	4	main
13	doc_491521501959_item	2557654	et	2	main
küsimust	doc_491521501959_item	2557655	et	4	main
saada	doc_491521501959_item	2557661	et	4	main
dessantväelasest	doc_491521501959_item	2557668	et	3	main
samasuguseks	doc_491521501959_item	2557676	et	4	main
huvid	doc_491521501959_item	2557681	et	3	main
peate	doc_491521501959_item	2557684	et	4	main
selline	doc_491521501959_item	2557692	et	4	main
saavutus	doc_491521501959_item	2557693	et	4	main
veel	doc_491521501959_item	2557696	et	4	main
petnud	doc_491521501959_item	2557715	et	4	main
hoidun	doc_491521501959_item	2557717	et	3	main
kokku	doc_491521501959_item	2557721	et	3	main
mis	doc_491521501959_item	2557723	et	4	main
on	doc_491521501959_item	2557724	et	4	main
tegu	doc_491521501959_item	2557729	et	4	main
võitlus	doc_491521501959_item	2557735	et	3	main
puhtaks	doc_491521501959_item	2557741	et	3	main
kellel	doc_491521501959_item	2557743	et	4	main
kuid	doc_491521501959_item	2557751	et	4	main
ole	doc_491521501959_item	2557754	et	4	main
olevad	doc_491521501959_item	2557761	et	4	main
on	doc_491521501959_item	2557769	et	4	main
oma	doc_491521501959_item	2557799	et	4	main
perega	doc_491521501959_item	2557812	et	3	main
kusagil	doc_491521501959_item	2557813	et	3	main
looduses	doc_491521501959_item	2557814	et	4	main
milline	doc_491521501959_item	2557815	et	3	main
ida-virumaal	doc_491521501959_item	2557819	et	4	main
alajõe	doc_491521501959_item	2557822	et	3	main
karjamaa	doc_491521501959_item	2557823	et	4	main
vasknarva	doc_491521501959_item	2557824	et	4	main
mille	doc_491521501959_item	2557825	et	3	main
kohtuasjades	doc_491521501959_item	2557832	et	3	main
aidata	doc_491521501959_item	2557836	et	4	main
alati	doc_491521501959_item	2557839	et	4	main
et	doc_491521501959_item	2557840	et	3	main
öökulli	doc_491521501959_item	2557854	et	4	main
inimene	doc_491521501959_item	2557856	et	3	main
oma	doc_491521501959_item	2557869	et	4	main
on	doc_491521501959_item	2557876	et	4	main
viia	doc_491521501959_item	2557878	et	3	main
lõpuni	doc_491521501959_item	2557880	et	3	main
ole	doc_491521501959_item	2557887	et	4	main
iga	doc_491521501959_item	2557888	et	4	main
olin	doc_491521501959_item	2557895	et	3	main
ei	doc_491521501958_item	2557622	et	4	main
ta	doc_491521501958_item	2557634	et	4	main
talle	doc_491521501958_item	2557646	et	4	main
meeldib	doc_491521501958_item	2557647	et	3	main
aidata	doc_491521501958_item	2557648	et	4	main
inimestele	doc_491521501958_item	2557649	et	3	main
12	doc_491521501958_item	2557650	et	2	main
13	doc_491521501959_item	2557652	et	2	main
küsimust	doc_491521501959_item	2557653	et	4	main
unistasin	doc_491521501959_item	2557660	et	3	main
köitis	doc_491521501959_item	2557664	et	3	main
tolleaegne	doc_491521501959_item	2557667	et	3	main
film	doc_491521501959_item	2557670	et	3	main
eritsooni	doc_491521501959_item	2557672	et	4	main
saada	doc_491521501959_item	2557675	et	4	main
hiljem	doc_491521501959_item	2557680	et	3	main
mida	doc_491521501959_item	2557683	et	4	main
oma	doc_491521501959_item	2557685	et	4	main
reeturlus	doc_491521501959_item	2557701	et	4	main
ja	doc_491521501959_item	2557702	et	3	main
valetamine	doc_491521501959_item	2557703	et	4	main
ma	doc_491521501959_item	2557704	et	3	main
küll	doc_491521501959_item	2557705	et	4	main
välja	doc_491521501959_item	2557710	et	4	main
kuid	doc_491521501959_item	2557716	et	4	main
edaspidi	doc_491521501959_item	2557718	et	3	main
ongi	doc_491521501959_item	2557731	et	4	main
see	doc_491521501959_item	2557732	et	3	main
minu	doc_491521501959_item	2557733	et	3	main
õhk	doc_491521501959_item	2557740	et	3	main
raske	doc_491521501959_item	2557749	et	4	main
öelda	doc_491521501959_item	2557750	et	4	main
juures	doc_491521501959_item	2557760	et	4	main
sest	doc_491521501959_item	2557763	et	4	main
erialal	doc_491521501959_item	2557802	et	3	main
õigusteaduses	doc_491521501959_item	2557803	et	3	main
mis	doc_491521501959_item	2557804	et	4	main
jaoks	doc_491521501959_item	2557807	et	4	main
lemmikkoht	doc_491521501959_item	2557818	et	3	main
ei	doc_491521501959_item	2557827	et	4	main
rohkem	doc_491521501959_item	2557843	et	4	main
ma	doc_491521501959_item	2557851	et	3	main
olen	doc_491521501959_item	2557852	et	3	main
ja	doc_491521501959_item	2557857	et	3	main
seetõttu	doc_491521501959_item	2557858	et	3	main
arvan	doc_491521501959_item	2557873	et	3	main
kui	doc_491521501959_item	2557883	et	3	main
ei	doc_491521501959_item	2557886	et	4	main
päris	doc_491521501959_item	2557890	et	4	main
ma	doc_491521501959_item	2557893	et	3	main
kuid	doc_491521501959_item	2557922	et	4	main
öeldut	doc_491521501959_item	2557932	et	4	main
kus	doc_491521501959_item	2557933	et	3	main
seal	doc_491521501959_item	2557935	et	4	main
ole	doc_491521501959_item	2557952	et	4	main
tõsine	doc_491521501959_item	2557953	et	4	main
2	doc_491521501959_item	2557959	et	2	main
tema	doc_491521501959_item	2557960	et	4	main
ma	doc_491521501959_item	2557965	et	3	main
on	doc_491521501959_item	2557969	et	4	main
ole	doc_491521501959_item	2557975	et	4	main
valetaja	doc_491521501959_item	2557976	et	4	main
korralik	doc_491521501959_item	2557978	et	3	main
seltsiv	doc_491521501959_item	2557979	et	4	main
ta	doc_491521501959_item	2557991	et	4	main
ta	doc_491521501959_item	2557998	et	4	main
siis	doc_491521501959_item	2558008	et	3	main
oma	doc_491521501959_item	2558027	et	4	main
ettevõtmisi	doc_491521501959_item	2558028	et	3	main
ta	doc_491521501959_item	2558039	et	4	main
tundidel	doc_491521501959_item	2558047	et	3	main
ei	doc_491521501959_item	2558059	et	4	main
13	doc_491521501960_item	2558066	et	2	main
tolleaegne	doc_491521501960_item	2558079	et	3	main
eritsooni	doc_491521501960_item	2558084	et	4	main
saada	doc_491521501960_item	2558087	et	4	main
samasuguseks	doc_491521501960_item	2558088	et	4	main
nagu	doc_491521501960_item	2558089	et	3	main
inimestele	doc_491521501960_item	2558121	et	3	main
puutumast	doc_491521501960_item	2558134	et	4	main
elu	doc_491521501960_item	2558139	et	4	main
minu	doc_491521501960_item	2558145	et	3	main
tänapäeva	doc_491521501960_item	2558157	et	4	main
eestis	doc_491521501960_item	2558158	et	3	main
kuid	doc_491521501960_item	2558163	et	4	main
võimu	doc_491521501960_item	2558171	et	4	main
juures	doc_491521501960_item	2558172	et	4	main
raha	doc_491521501960_item	2558178	et	4	main
ja	doc_491521501960_item	2558179	et	3	main
olnud	doc_491521501959_item	2557725	et	4	main
ilmselt	doc_491521501959_item	2557730	et	4	main
selle	doc_491521501959_item	2557736	et	4	main
kohlta-järve	doc_491521501959_item	2557739	et	4	main
saaks	doc_491521501959_item	2557742	et	3	main
ei	doc_491521501959_item	2557753	et	4	main
käes	doc_491521501959_item	2557770	et	4	main
seda	doc_491521501959_item	2557771	et	3	main
rohkem	doc_491521501959_item	2557772	et	4	main
on	doc_491521501959_item	2557773	et	4	main
ka	doc_491521501959_item	2557774	et	3	main
probleeme	doc_491521501959_item	2557775	et	3	main
mille	doc_491521501959_item	2557776	et	3	main
peale	doc_491521501959_item	2557777	et	4	main
kulub	doc_491521501959_item	2557778	et	3	main
teil	doc_491521501959_item	2557779	et	4	main
kõige	doc_491521501959_item	2557780	et	4	main
rohkem	doc_491521501959_item	2557781	et	4	main
raha	doc_491521501959_item	2557782	et	4	main
kommunaalkulude	doc_491521501959_item	2557783	et	3	main
peale	doc_491521501959_item	2557784	et	4	main
mida	doc_491521501959_item	2557785	et	4	main
tahaksite	doc_491521501959_item	2557786	et	3	main
osta	doc_491521501959_item	2557787	et	4	main
ma	doc_491521501959_item	2557788	et	3	main
tahan	doc_491521501959_item	2557789	et	3	main
väga	doc_491521501959_item	2557790	et	3	main
palju	doc_491521501959_item	2557791	et	4	main
lugeda	doc_491521501959_item	2557792	et	3	main
et	doc_491521501959_item	2557793	et	3	main
saada	doc_491521501959_item	2557794	et	4	main
targemaks	doc_491521501959_item	2557795	et	4	main
taset	doc_491521501959_item	2557800	et	3	main
valitud	doc_491521501959_item	2557801	et	4	main
teie	doc_491521501959_item	2557806	et	4	main
parim	doc_491521501959_item	2557808	et	4	main
puhkus	doc_491521501959_item	2557809	et	3	main
olla	doc_491521501959_item	2557810	et	3	main
koos	doc_491521501959_item	2557811	et	4	main
jätku	doc_491521501959_item	2557828	et	4	main
võimalikult	doc_491521501959_item	2557834	et	4	main
tundub	doc_491521501959_item	2557838	et	3	main
natukene	doc_491521501959_item	2557842	et	4	main
aega	doc_491521501959_item	2557844	et	4	main
siis	doc_491521501959_item	2557845	et	3	main
jõuaks	doc_491521501959_item	2557846	et	3	main
loomult	doc_491521501959_item	2557853	et	3	main
tüüpi	doc_491521501959_item	2557855	et	4	main
olen	doc_491521501959_item	2557859	et	3	main
harjunud	doc_491521501959_item	2557860	et	4	main
tugevaimaks	doc_491521501959_item	2557870	et	4	main
see	doc_491521501959_item	2557875	et	3	main
asjad	doc_491521501959_item	2557879	et	3	main
see	doc_491521501959_item	2557884	et	3	main
tulemus	doc_491521501959_item	2557885	et	3	main
kord	doc_491521501959_item	2557889	et	4	main
lootnud	doc_491521501959_item	2557896	et	4	main
ei	doc_491521501959_item	2557897	et	4	main
ole	doc_491521501959_item	2557898	et	4	main
mul	doc_491521501959_item	2557899	et	3	main
kombeks	doc_491521501959_item	2557900	et	4	main
oma	doc_491521501959_item	2557901	et	4	main
ettevõtmisi	doc_491521501959_item	2557902	et	3	main
pooleli	doc_491521501959_item	2557903	et	3	main
jätta	doc_491521501959_item	2557904	et	3	main
span	doc_491521501959_item	2557905	et	4	main
millises	doc_491521501959_item	2557906	et	3	main
riigis	doc_491521501959_item	2557907	et	3	main
peale	doc_491521501959_item	2557908	et	4	main
eesti	doc_491521501959_item	2557909	et	4	main
tahaksite	doc_491521501959_item	2557910	et	3	main
elada	doc_491521501959_item	2557911	et	3	main
ma	doc_491521501959_item	2557912	et	3	main
olen	doc_491521501959_item	2557913	et	3	main
elanud	doc_491521501959_item	2557914	et	4	main
teinud	doc_491521501959_item	2557916	et	4	main
tööd	doc_491521501959_item	2557917	et	4	main
nii	doc_491521501959_item	2557918	et	3	main
ja	doc_491521501959_item	2557915	et	3	main
venemaal	doc_491521501959_item	2557919	et	4	main
kui	doc_491521501959_item	2557920	et	3	main
eestis	doc_491521501959_item	2557925	et	3	main
huvitu	doc_491521501959_item	2557948	et	4	main
ei	doc_491521501959_item	2557951	et	4	main
arvan	doc_491521501959_item	2557966	et	3	main
ei	doc_491521501959_item	2557974	et	4	main
ja	doc_491521501959_item	2557980	et	3	main
nad	doc_491521501959_item	2557987	et	3	main
on	doc_491521501959_item	2557988	et	4	main
tede	doc_491521501959_item	2557989	et	4	main
4	doc_491521501959_item	2557994	et	2	main
kohtus	doc_491521501959_item	2558000	et	4	main
ta	doc_491521501959_item	2558002	et	4	main
viib	doc_491521501959_item	2558003	et	3	main
oma	doc_491521501959_item	2558004	et	4	main
see	doc_491521501959_item	2558017	et	3	main
mida	doc_491521501959_item	2558018	et	4	main
tahan	doc_491521501959_item	2557831	et	3	main
hästi	doc_491521501959_item	2557835	et	3	main
veelgi	doc_491521501959_item	2557847	et	4	main
tööd	doc_491521501959_item	2557861	et	4	main
tegema	doc_491521501959_item	2557862	et	3	main
ka	doc_491521501959_item	2557863	et	3	main
hilistel	doc_491521501959_item	2557864	et	3	main
öötundidel	doc_491521501959_item	2557865	et	3	main
millist	doc_491521501959_item	2557866	et	3	main
omadust	doc_491521501959_item	2557867	et	4	main
küljeks	doc_491521501959_item	2557871	et	3	main
siis	doc_491521501959_item	2557882	et	3	main
see	doc_491521501959_item	2557891	et	3	main
on	doc_491521501959_item	2557924	et	4	main
parem	doc_491521501959_item	2557928	et	4	main
sündisid	doc_491521501959_item	2557934	et	4	main
peab	doc_491521501959_item	2557936	et	4	main
ka	doc_491521501959_item	2557937	et	3	main
elama	doc_491521501959_item	2557938	et	3	main
kas	doc_491521501959_item	2557939	et	3	main
loete	doc_491521501959_item	2557940	et	4	main
horoskoope	doc_491521501959_item	2557941	et	3	main
neid	doc_491521501959_item	2557946	et	4	main
nendest	doc_491521501959_item	2557949	et	4	main
asi	doc_491521501959_item	2557954	et	4	main
elukutse	doc_491521501959_item	2557961	et	4	main
on	doc_491521501959_item	2557962	et	4	main
et	doc_491521501959_item	2557967	et	3	main
ta	doc_491521501959_item	2557973	et	4	main
aus	doc_491521501959_item	2557977	et	4	main
kunagi	doc_491521501959_item	2557982	et	3	main
ei	doc_491521501959_item	2557983	et	4	main
inimestele	doc_491521501959_item	2557985	et	3	main
petnud	doc_491521501959_item	2557990	et	4	main
ma	doc_491521501959_item	2557995	et	3	main
et	doc_491521501959_item	2557997	et	3	main
töötab	doc_491521501959_item	2557999	et	3	main
5	doc_491521501959_item	2558001	et	2	main
isegi	doc_491521501959_item	2558007	et	4	main
see	doc_491521501959_item	2558010	et	3	main
ei	doc_491521501959_item	2558012	et	4	main
oli	doc_491521501959_item	2558021	et	3	main
jätta	doc_491521501959_item	2558030	et	3	main
on	doc_491521501959_item	2558040	et	4	main
7	doc_491521501959_item	2558048	et	2	main
huvitud	doc_491521501959_item	2558054	et	4	main
nendest	doc_491521501959_item	2558055	et	4	main
köitis	doc_491521501960_item	2558076	et	3	main
väga	doc_491521501960_item	2558078	et	3	main
film	doc_491521501960_item	2558082	et	3	main
sööst	doc_491521501960_item	2558083	et	3	main
ja	doc_491521501960_item	2558085	et	3	main
tahtsin	doc_491521501960_item	2558086	et	3	main
mul	doc_491521501959_item	2557926	et	3	main
isa	doc_491521501959_item	2557931	et	4	main
ma	doc_491521501959_item	2557943	et	3	main
ega	doc_491521501959_item	2557947	et	3	main
see	doc_491521501959_item	2557950	et	3	main
mees	doc_491521501959_item	2557958	et	4	main
3	doc_491521501959_item	2557964	et	2	main
siiukene	doc_491521501959_item	2557970	et	4	main
et	doc_491521501959_item	2557972	et	3	main
mitte	doc_491521501959_item	2557981	et	3	main
ütle	doc_491521501959_item	2557984	et	4	main
et	doc_491521501959_item	2557986	et	3	main
on	doc_491521501959_item	2557992	et	4	main
öökulli-tüüpi	doc_491521501959_item	2557993	et	4	main
lõpuni	doc_491521501959_item	2558006	et	3	main
kui	doc_491521501959_item	2558009	et	3	main
päris	doc_491521501959_item	2558016	et	4	main
ei	doc_491521501959_item	2558023	et	4	main
ole	doc_491521501959_item	2558024	et	4	main
temal	doc_491521501959_item	2558025	et	3	main
6	doc_491521501959_item	2558031	et	2	main
ta	doc_491521501959_item	2558056	et	4	main
arvab	doc_491521501959_item	2558057	et	3	main
see	doc_491521501959_item	2558058	et	3	main
küsimust	doc_491521501960_item	2558067	et	4	main
tahtsite	doc_491521501960_item	2558069	et	3	main
lapsepõlves	doc_491521501960_item	2558070	et	4	main
mind	doc_491521501960_item	2558075	et	4	main
välja	doc_491521501960_item	2558122	et	4	main
mind	doc_491521501960_item	2558126	et	4	main
kuid	doc_491521501960_item	2558128	et	4	main
olnud	doc_491521501960_item	2558137	et	4	main
ilmselt	doc_491521501960_item	2558142	et	4	main
on	doc_491521501960_item	2558156	et	4	main
raske	doc_491521501960_item	2558161	et	4	main
kindlasti	doc_491521501960_item	2558164	et	3	main
olevad	doc_491521501960_item	2558173	et	4	main
teil	doc_491521501960_item	2558191	et	4	main
jaoks	doc_491521501960_item	2558219	et	4	main
parim	doc_491521501960_item	2558220	et	4	main
perega	doc_491521501960_item	2558224	et	3	main
looduses	doc_491521501960_item	2558226	et	4	main
milline	doc_491521501960_item	2558227	et	3	main
aega	doc_491521501960_item	2558241	et	4	main
kuna	doc_491521501960_item	2558242	et	3	main
tahan	doc_491521501960_item	2558243	et	3	main
kohtuasjades	doc_491521501960_item	2558244	et	3	main
tundub	doc_491521501960_item	2558250	et	3	main
natukene	doc_491521501960_item	2558254	et	4	main
ma	doc_491521501960_item	2558263	et	3	main
olen	doc_491521501960_item	2558264	et	3	main
tugevaimaks	doc_491521501960_item	2558282	et	4	main
see	doc_491521501960_item	2558287	et	3	main
elanud	doc_491521501960_item	2558326	et	4	main
ja	doc_491521501960_item	2558327	et	3	main
teinud	doc_491521501960_item	2558328	et	4	main
tööd	doc_491521501960_item	2558329	et	4	main
nii	doc_491521501960_item	2558330	et	3	main
on	doc_491521501960_item	2558336	et	4	main
mul	doc_491521501960_item	2558338	et	3	main
parem	doc_491521501960_item	2558340	et	4	main
järgin	doc_491521501960_item	2558341	et	3	main
usu	doc_491521501960_item	2558357	et	4	main
arvan	doc_491521501960_item	2558380	et	3	main
et	doc_491521501960_item	2558381	et	3	main
see	doc_491521501960_item	2558382	et	3	main
4	doc_491521501960_item	2558398	et	2	main
võiks	doc_491521501960_item	2558411	et	4	main
et	doc_491521501960_item	2558417	et	3	main
tugevad	doc_491521501960_item	2558419	et	4	main
kuljed	doc_491521501960_item	2558420	et	4	main
1	doc_491521501959_item	2557955	et	2	main
intervjueeritav	doc_491521501959_item	2557956	et	4	main
on	doc_491521501959_item	2557957	et	4	main
jurist	doc_491521501959_item	2557963	et	3	main
ta	doc_491521501959_item	2557968	et	4	main
inimene	doc_491521501959_item	2557971	et	3	main
arvan	doc_491521501959_item	2557996	et	3	main
asjad	doc_491521501959_item	2558005	et	3	main
tulemus	doc_491521501959_item	2558011	et	3	main
ole	doc_491521501959_item	2558013	et	4	main
iga	doc_491521501959_item	2558014	et	4	main
kord	doc_491521501959_item	2558015	et	4	main
alguses	doc_491521501959_item	2558020	et	4	main
ta	doc_491521501959_item	2558019	et	4	main
pooleli	doc_491521501959_item	2558029	et	3	main
on	doc_491521501959_item	2558034	et	4	main
inimen	doc_491521501959_item	2558036	et	4	main
ja	doc_491521501959_item	2558037	et	3	main
seetõttu	doc_491521501959_item	2558038	et	3	main
öö	doc_491521501959_item	2558046	et	4	main
ei	doc_491521501959_item	2558050	et	4	main
horoskoope	doc_491521501959_item	2558052	et	3	main
ole	doc_491521501959_item	2558060	et	4	main
tõsine	doc_491521501959_item	2558061	et	4	main
asi	doc_491521501959_item	2558062	et	4	main
32c	doc_491521501959_item	2558063	et	4	main
13	doc_491521501960_item	2558064	et	2	main
kelleks	doc_491521501960_item	2558068	et	4	main
saada	doc_491521501960_item	2558071	et	4	main
unistasin	doc_491521501960_item	2558072	et	3	main
saada	doc_491521501960_item	2558073	et	4	main
tehtud	doc_491521501960_item	2558081	et	4	main
et	doc_491521501960_item	2558123	et	3	main
pööraseim	doc_491521501960_item	2558140	et	4	main
tegu	doc_491521501960_item	2558141	et	4	main
et	doc_491521501960_item	2558150	et	3	main
õhk	doc_491521501960_item	2558152	et	3	main
puhtaks	doc_491521501960_item	2558153	et	3	main
saaks	doc_491521501960_item	2558154	et	3	main
kellel	doc_491521501960_item	2558155	et	4	main
öelda	doc_491521501960_item	2558162	et	4	main
rohkem	doc_491521501960_item	2558177	et	4	main
on	doc_491521501960_item	2558181	et	4	main
rohkem	doc_491521501960_item	2558184	et	4	main
raha	doc_491521501960_item	2558194	et	4	main
peale	doc_491521501960_item	2558196	et	4	main
tahaksite	doc_491521501960_item	2558198	et	3	main
oma	doc_491521501960_item	2558211	et	4	main
taset	doc_491521501960_item	2558212	et	3	main
mis	doc_491521501960_item	2558216	et	4	main
ida-virumaal	doc_491521501960_item	2558231	et	4	main
peipsi-äärne	doc_491521501960_item	2558232	et	3	main
vasknarva	doc_491521501960_item	2558236	et	4	main
jaoks	doc_491521501960_item	2558238	et	4	main
võimalikult	doc_491521501960_item	2558246	et	4	main
hästi	doc_491521501960_item	2558247	et	3	main
siis	doc_491521501960_item	2558249	et	3	main
rohkem	doc_491521501960_item	2558255	et	4	main
aega	doc_491521501960_item	2558256	et	4	main
siis	doc_491521501960_item	2558257	et	3	main
jõuaks	doc_491521501960_item	2558258	et	3	main
veelgi	doc_491521501960_item	2558259	et	4	main
öökulli	doc_491521501960_item	2558266	et	4	main
ja	doc_491521501960_item	2558269	et	3	main
tööd	doc_491521501960_item	2558273	et	4	main
ka	doc_491521501960_item	2558275	et	3	main
oma	doc_491521501960_item	2558281	et	4	main
et	doc_491521501960_item	2558286	et	3	main
venemaal	doc_491521501960_item	2558331	et	4	main
kui	doc_491521501960_item	2558332	et	3	main
siiski	doc_491521501960_item	2558335	et	4	main
eestis	doc_491521501960_item	2558337	et	3	main
kõige	doc_491521501960_item	2558339	et	4	main
oma	doc_491521501960_item	2558342	et	4	main
isa	doc_491521501960_item	2558343	et	4	main
neid	doc_491521501960_item	2558358	et	4	main
ega	doc_491521501960_item	2558359	et	3	main
arvan	doc_491521501960_item	2558373	et	3	main
intervjueeritar	doc_491521501960_item	2558375	et	4	main
mees	doc_491521501960_item	2558377	et	4	main
ma	doc_491521501960_item	2558379	et	3	main
mees	doc_491521501960_item	2558383	et	4	main
elavik	doc_491521501960_item	2558387	et	4	main
jurist	doc_491521501960_item	2558392	et	3	main
ma	doc_491521501960_item	2558399	et	3	main
öösiti	doc_491521501960_item	2558413	et	4	main
arvan	doc_491521501960_item	2558416	et	3	main
tema	doc_491521501960_item	2558418	et	4	main
ei	doc_491521501960_item	2558423	et	4	main
lapsepõlves	doc_491521501961_item	2558436	et	4	main
tehtud	doc_491521501961_item	2558447	et	4	main
film	doc_491521501961_item	2558448	et	3	main
sööst	doc_491521501961_item	2558449	et	3	main
eritsooni	doc_491521501961_item	2558450	et	4	main
ja	doc_491521501961_item	2558451	et	3	main
lootnud	doc_491521501959_item	2558022	et	4	main
kombeks	doc_491521501959_item	2558026	et	4	main
kuna	doc_491521501959_item	2558032	et	3	main
ta	doc_491521501959_item	2558033	et	4	main
öökulli-tüüpi	doc_491521501959_item	2558035	et	4	main
harjunud	doc_491521501959_item	2558041	et	4	main
tööd	doc_491521501959_item	2558042	et	4	main
tegema	doc_491521501959_item	2558043	et	3	main
ka	doc_491521501959_item	2558044	et	3	main
hilistel	doc_491521501959_item	2558045	et	3	main
ta	doc_491521501959_item	2558049	et	4	main
usu	doc_491521501959_item	2558051	et	4	main
ega	doc_491521501959_item	2558053	et	3	main
küsimust	doc_491521501960_item	2558065	et	4	main
luurajaks	doc_491521501960_item	2558074	et	4	main
ka	doc_491521501960_item	2558077	et	3	main
dessantväelasest	doc_491521501960_item	2558080	et	3	main
nemad	doc_491521501960_item	2558090	et	3	main
aga	doc_491521501960_item	2558091	et	3	main
hiljem	doc_491521501960_item	2558092	et	3	main
huvid	doc_491521501960_item	2558093	et	3	main
muutusid	doc_491521501960_item	2558094	et	4	main
mida	doc_491521501960_item	2558095	et	4	main
peate	doc_491521501960_item	2558096	et	4	main
oma	doc_491521501960_item	2558097	et	4	main
elu	doc_491521501960_item	2558098	et	4	main
suurimaks	doc_491521501960_item	2558099	et	4	main
saavutuseks	doc_491521501960_item	2558100	et	4	main
ma	doc_491521501960_item	2558101	et	3	main
loodan	doc_491521501960_item	2558102	et	3	main
et	doc_491521501960_item	2558103	et	3	main
selline	doc_491521501960_item	2558104	et	4	main
saavutus	doc_491521501960_item	2558105	et	4	main
ootab	doc_491521501960_item	2558106	et	3	main
mind	doc_491521501960_item	2558107	et	4	main
veel	doc_491521501960_item	2558108	et	4	main
ees	doc_491521501960_item	2558109	et	4	main
mis	doc_491521501960_item	2558110	et	4	main
teid	doc_491521501960_item	2558111	et	4	main
ärritab	doc_491521501960_item	2558112	et	3	main
reeturlus	doc_491521501960_item	2558113	et	4	main
ja	doc_491521501960_item	2558114	et	3	main
valetamine	doc_491521501960_item	2558115	et	4	main
ma	doc_491521501960_item	2558116	et	3	main
küll	doc_491521501960_item	2558117	et	4	main
üldiselt	doc_491521501960_item	2558118	et	4	main
ei	doc_491521501960_item	2558119	et	4	main
ütle	doc_491521501960_item	2558120	et	4	main
on	doc_491521501960_item	2558125	et	4	main
mis	doc_491521501960_item	2558135	et	4	main
on	doc_491521501960_item	2558136	et	4	main
nad	doc_491521501960_item	2558124	et	3	main
petnud	doc_491521501960_item	2558127	et	4	main
hoidun	doc_491521501960_item	2558129	et	3	main
edaspidi	doc_491521501960_item	2558130	et	3	main
selliste	doc_491521501960_item	2558131	et	4	main
inimestega	doc_491521501960_item	2558132	et	3	main
kokku	doc_491521501960_item	2558133	et	3	main
teie	doc_491521501960_item	2558138	et	4	main
ongi	doc_491521501960_item	2558143	et	4	main
see	doc_491521501960_item	2558144	et	3	main
praegune	doc_491521501960_item	2558146	et	3	main
võitlus	doc_491521501960_item	2558147	et	3	main
selle	doc_491521501960_item	2558148	et	4	main
hea	doc_491521501960_item	2558159	et	4	main
ole	doc_491521501960_item	2558166	et	4	main
rikkad	doc_491521501960_item	2558169	et	4	main
ja	doc_491521501960_item	2558170	et	3	main
mida	doc_491521501960_item	2558176	et	4	main
on	doc_491521501960_item	2558185	et	4	main
ka	doc_491521501960_item	2558186	et	3	main
probleeme	doc_491521501960_item	2558187	et	3	main
mille	doc_491521501960_item	2558188	et	3	main
peale	doc_491521501960_item	2558189	et	4	main
kulub	doc_491521501960_item	2558190	et	3	main
rohkem	doc_491521501960_item	2558193	et	4	main
kommunaalkulude	doc_491521501960_item	2558195	et	3	main
mida	doc_491521501960_item	2558197	et	4	main
osta	doc_491521501960_item	2558199	et	4	main
ma	doc_491521501960_item	2558200	et	3	main
tahan	doc_491521501960_item	2558201	et	3	main
väga	doc_491521501960_item	2558202	et	3	main
palju	doc_491521501960_item	2558203	et	4	main
lugeda	doc_491521501960_item	2558204	et	3	main
et	doc_491521501960_item	2558205	et	3	main
tõsta	doc_491521501960_item	2558210	et	4	main
valitud	doc_491521501960_item	2558213	et	4	main
erialal	doc_491521501960_item	2558214	et	3	main
olla	doc_491521501960_item	2558222	et	3	main
koos	doc_491521501960_item	2558223	et	4	main
kusagil	doc_491521501960_item	2558225	et	3	main
alajõe	doc_491521501960_item	2558234	et	3	main
mille	doc_491521501960_item	2558237	et	3	main
ei	doc_491521501960_item	2558239	et	4	main
jätku	doc_491521501960_item	2558240	et	4	main
alati	doc_491521501960_item	2558251	et	4	main
oleks	doc_491521501960_item	2558253	et	3	main
paremini	doc_491521501960_item	2558260	et	4	main
harjunud	doc_491521501960_item	2558272	et	4	main
tegema	doc_491521501960_item	2558274	et	3	main
hilistel	doc_491521501960_item	2558276	et	3	main
millist	doc_491521501960_item	2558278	et	3	main
peate	doc_491521501960_item	2558280	et	4	main
küljeks	doc_491521501960_item	2558283	et	3	main
on	doc_491521501960_item	2558288	et	4	main
nimel	doc_491521501960_item	2558149	et	3	main
kohlta-järve	doc_491521501960_item	2558151	et	4	main
elada	doc_491521501960_item	2558160	et	3	main
ei	doc_491521501960_item	2558165	et	4	main
need	doc_491521501960_item	2558167	et	3	main
ainult	doc_491521501960_item	2558168	et	4	main
inimesed	doc_491521501960_item	2558174	et	3	main
sest	doc_491521501960_item	2558175	et	4	main
võimu	doc_491521501960_item	2558180	et	4	main
seda	doc_491521501960_item	2558183	et	3	main
kõige	doc_491521501960_item	2558192	et	4	main
saada	doc_491521501960_item	2558206	et	4	main
targemaks	doc_491521501960_item	2558207	et	4	main
tahaks	doc_491521501960_item	2558209	et	3	main
käes	doc_491521501960_item	2558182	et	4	main
eelkõige	doc_491521501960_item	2558208	et	3	main
õigusteaduses	doc_491521501960_item	2558215	et	3	main
on	doc_491521501960_item	2558217	et	4	main
teie	doc_491521501960_item	2558218	et	4	main
puhkus	doc_491521501960_item	2558221	et	3	main
kant	doc_491521501960_item	2558233	et	3	main
aidata	doc_491521501960_item	2558248	et	4	main
valmistuda	doc_491521501960_item	2558261	et	3	main
olen	doc_491521501960_item	2558271	et	3	main
öötundidel	doc_491521501960_item	2558277	et	3	main
ma	doc_491521501960_item	2558284	et	3	main
eesti	doc_491521501960_item	2558321	et	4	main
saksamaal	doc_491521501960_item	2558333	et	4	main
kus	doc_491521501960_item	2558345	et	3	main
sündisid	doc_491521501960_item	2558346	et	4	main
on	doc_491521501960_item	2558376	et	4	main
2	doc_491521501960_item	2558378	et	2	main
eesti	doc_491521501960_item	2558385	et	4	main
kohtla-järve	doc_491521501960_item	2558388	et	4	main
mees	doc_491521501960_item	2558390	et	4	main
tema	doc_491521501960_item	2558394	et	4	main
on	doc_491521501960_item	2558396	et	4	main
võiks	doc_491521501960_item	2558403	et	4	main
töötada	doc_491521501960_item	2558412	et	3	main
ma	doc_491521501960_item	2558415	et	3	main
oma	doc_491521501960_item	2558426	et	4	main
jatta	doc_491521501960_item	2558429	et	4	main
saada	doc_491521501961_item	2558437	et	4	main
unistasin	doc_491521501961_item	2558438	et	3	main
saada	doc_491521501961_item	2558453	et	4	main
muutusid	doc_491521501961_item	2558460	et	4	main
peate	doc_491521501961_item	2558462	et	4	main
oma	doc_491521501961_item	2558463	et	4	main
loodan	doc_491521501961_item	2558468	et	3	main
veel	doc_491521501961_item	2558474	et	4	main
teid	doc_491521501961_item	2558477	et	4	main
ei	doc_491521501961_item	2558485	et	4	main
hoidun	doc_491521501961_item	2558495	et	3	main
on	doc_491521501961_item	2558502	et	4	main
tegu	doc_491521501961_item	2558507	et	4	main
võitlus	doc_491521501961_item	2558513	et	3	main
kellel	doc_491521501961_item	2558521	et	4	main
tänapäeva	doc_491521501961_item	2558523	et	4	main
eestis	doc_491521501961_item	2558524	et	3	main
ei	doc_491521501961_item	2558531	et	4	main
juures	doc_491521501961_item	2558538	et	4	main
teil	doc_491521501961_item	2558557	et	4	main
kommunaalkulude	doc_491521501961_item	2558561	et	3	main
tahaksite	doc_491521501961_item	2558564	et	3	main
et	doc_491521501961_item	2558571	et	3	main
saada	doc_491521501961_item	2558572	et	4	main
tahaks	doc_491521501961_item	2558575	et	3	main
tõsta	doc_491521501961_item	2558576	et	4	main
mis	doc_491521501961_item	2558582	et	4	main
oleks	doc_491521501961_item	2558619	et	3	main
jõuaks	doc_491521501961_item	2558624	et	3	main
paremini	doc_491521501961_item	2558626	et	4	main
valmistuda	doc_491521501961_item	2558627	et	3	main
öökulli	doc_491521501961_item	2558632	et	4	main
inimene	doc_491521501961_item	2558634	et	3	main
seetõttu	doc_491521501961_item	2558636	et	3	main
olen	doc_491521501961_item	2558637	et	3	main
tööd	doc_491521501961_item	2558639	et	4	main
tegema	doc_491521501961_item	2558640	et	3	main
ka	doc_491521501961_item	2558641	et	3	main
hilistel	doc_491521501961_item	2558642	et	3	main
öötundidel	doc_491521501961_item	2558643	et	3	main
millist	doc_491521501961_item	2558644	et	3	main
tugevaimaks	doc_491521501961_item	2558648	et	4	main
et	doc_491521501961_item	2558652	et	3	main
on	doc_491521501961_item	2558654	et	4	main
ole	doc_491521501961_item	2558676	et	4	main
teinud	doc_491521501961_item	2558694	et	4	main
kui	doc_491521501961_item	2558698	et	3	main
parem	doc_491521501961_item	2558706	et	4	main
horoskoope	doc_491521501961_item	2558719	et	3	main
ma	doc_491521501961_item	2558721	et	3	main
asi	doc_491521501961_item	2558732	et	4	main
mees	doc_491521501961_item	2558736	et	4	main
eesti	doc_491521501961_item	2558745	et	4	main
kodanik	doc_491521501961_item	2558746	et	3	main
on	doc_491521501960_item	2558228	et	4	main
teie	doc_491521501960_item	2558229	et	4	main
lemmikkoht	doc_491521501960_item	2558230	et	3	main
karjamaa	doc_491521501960_item	2558235	et	4	main
inimesi	doc_491521501960_item	2558245	et	4	main
et	doc_491521501960_item	2558252	et	3	main
kuid	doc_491521501960_item	2558262	et	4	main
loomult	doc_491521501960_item	2558265	et	3	main
tüüpi	doc_491521501960_item	2558267	et	4	main
inimene	doc_491521501960_item	2558268	et	3	main
seetõttu	doc_491521501960_item	2558270	et	3	main
omadust	doc_491521501960_item	2558279	et	4	main
arvan	doc_491521501960_item	2558285	et	3	main
järjekindlus	doc_491521501960_item	2558289	et	4	main
viia	doc_491521501960_item	2558290	et	3	main
asjad	doc_491521501960_item	2558291	et	3	main
lõpuni	doc_491521501960_item	2558292	et	3	main
isegi	doc_491521501960_item	2558293	et	4	main
siis	doc_491521501960_item	2558294	et	3	main
kui	doc_491521501960_item	2558295	et	3	main
see	doc_491521501960_item	2558296	et	3	main
tulemus	doc_491521501960_item	2558297	et	3	main
ei	doc_491521501960_item	2558298	et	4	main
ole	doc_491521501960_item	2558299	et	4	main
iga	doc_491521501960_item	2558300	et	4	main
kord	doc_491521501960_item	2558301	et	4	main
päris	doc_491521501960_item	2558302	et	4	main
see	doc_491521501960_item	2558303	et	3	main
mida	doc_491521501960_item	2558304	et	4	main
ma	doc_491521501960_item	2558305	et	3	main
alguses	doc_491521501960_item	2558306	et	4	main
olin	doc_491521501960_item	2558307	et	3	main
lootnud	doc_491521501960_item	2558308	et	4	main
ei	doc_491521501960_item	2558309	et	4	main
ole	doc_491521501960_item	2558310	et	4	main
mul	doc_491521501960_item	2558311	et	3	main
kombeks	doc_491521501960_item	2558312	et	4	main
oma	doc_491521501960_item	2558313	et	4	main
ettevõtmisi	doc_491521501960_item	2558314	et	3	main
pooleli	doc_491521501960_item	2558315	et	3	main
jätta	doc_491521501960_item	2558316	et	3	main
span	doc_491521501960_item	2558317	et	4	main
millises	doc_491521501960_item	2558318	et	3	main
riigis	doc_491521501960_item	2558319	et	3	main
peale	doc_491521501960_item	2558320	et	4	main
elada	doc_491521501960_item	2558323	et	3	main
kuid	doc_491521501960_item	2558334	et	4	main
öeldut	doc_491521501960_item	2558344	et	4	main
ei	doc_491521501960_item	2558354	et	4	main
ma	doc_491521501960_item	2558355	et	3	main
ei	doc_491521501960_item	2558356	et	4	main
tahaksite	doc_491521501960_item	2558322	et	3	main
ma	doc_491521501960_item	2558324	et	3	main
olen	doc_491521501960_item	2558325	et	3	main
seal	doc_491521501960_item	2558347	et	4	main
peab	doc_491521501960_item	2558348	et	4	main
ka	doc_491521501960_item	2558349	et	3	main
elama	doc_491521501960_item	2558350	et	3	main
kas	doc_491521501960_item	2558351	et	3	main
loete	doc_491521501960_item	2558352	et	4	main
horoskoope	doc_491521501960_item	2558353	et	3	main
huvitu	doc_491521501960_item	2558360	et	4	main
nendest	doc_491521501960_item	2558361	et	4	main
see	doc_491521501960_item	2558362	et	3	main
ei	doc_491521501960_item	2558363	et	4	main
ole	doc_491521501960_item	2558364	et	4	main
tõsine	doc_491521501960_item	2558365	et	4	main
asi	doc_491521501960_item	2558366	et	4	main
iseloomusta	doc_491521501960_item	2558367	et	4	main
inimest	doc_491521501960_item	2558368	et	3	main
kellest	doc_491521501960_item	2558369	et	4	main
kirjutatakse	doc_491521501960_item	2558370	et	3	main
1	doc_491521501960_item	2558371	et	2	main
ma	doc_491521501960_item	2558372	et	3	main
3	doc_491521501960_item	2558393	et	2	main
iseloom	doc_491521501960_item	2558395	et	3	main
rahulik	doc_491521501960_item	2558397	et	3	main
ta	doc_491521501960_item	2558402	et	4	main
töötada	doc_491521501960_item	2558404	et	3	main
5	doc_491521501960_item	2558406	et	2	main
ma	doc_491521501960_item	2558407	et	3	main
arvan	doc_491521501960_item	2558408	et	3	main
et	doc_491521501960_item	2558409	et	3	main
ta	doc_491521501960_item	2558410	et	4	main
6	doc_491521501960_item	2558414	et	2	main
on	doc_491521501960_item	2558421	et	4	main
kombeks	doc_491521501960_item	2558425	et	4	main
pooleli	doc_491521501960_item	2558428	et	3	main
küsimust	doc_491521501961_item	2558431	et	4	main
küsimust	doc_491521501961_item	2558433	et	4	main
kelleks	doc_491521501961_item	2558434	et	4	main
tahtsite	doc_491521501961_item	2558435	et	3	main
mind	doc_491521501961_item	2558441	et	4	main
köitis	doc_491521501961_item	2558442	et	3	main
ka	doc_491521501961_item	2558443	et	3	main
väga	doc_491521501961_item	2558444	et	3	main
tolleaegne	doc_491521501961_item	2558445	et	3	main
dessantväelasest	doc_491521501961_item	2558446	et	3	main
samasuguseks	doc_491521501961_item	2558454	et	4	main
elu	doc_491521501961_item	2558464	et	4	main
mind	doc_491521501961_item	2558473	et	4	main
üldiselt	doc_491521501961_item	2558484	et	4	main
mind	doc_491521501961_item	2558492	et	4	main
olnud	doc_491521501961_item	2558503	et	4	main
ilmselt	doc_491521501961_item	2558508	et	4	main
raske	doc_491521501961_item	2558527	et	4	main
öelda	doc_491521501961_item	2558528	et	4	main
rikkad	doc_491521501961_item	2558535	et	4	main
ja	doc_491521501961_item	2558536	et	3	main
inimesed	doc_491521501961_item	2558540	et	3	main
on	doc_491521501961_item	2558547	et	4	main
seda	doc_491521501961_item	2558549	et	3	main
rohkem	doc_491521501961_item	2558550	et	4	main
kõige	doc_491521501961_item	2558558	et	4	main
osta	doc_491521501961_item	2558565	et	4	main
väga	doc_491521501961_item	2558568	et	3	main
lugeda	doc_491521501961_item	2558570	et	3	main
natukene	doc_491521501961_item	2558620	et	4	main
aega	doc_491521501961_item	2558622	et	4	main
veelgi	doc_491521501961_item	2558625	et	4	main
loomult	doc_491521501961_item	2558631	et	3	main
harjunud	doc_491521501961_item	2558638	et	4	main
arvan	doc_491521501961_item	2558651	et	3	main
see	doc_491521501961_item	2558653	et	3	main
olin	doc_491521501961_item	2558673	et	3	main
oma	doc_491521501961_item	2558679	et	4	main
ettevõtmisi	doc_491521501961_item	2558680	et	3	main
nii	doc_491521501961_item	2558696	et	3	main
saksamaal	doc_491521501961_item	2558699	et	4	main
siiski	doc_491521501961_item	2558701	et	4	main
on	doc_491521501961_item	2558702	et	4	main
eestis	doc_491521501961_item	2558703	et	3	main
mul	doc_491521501961_item	2558704	et	3	main
öeldut	doc_491521501961_item	2558710	et	4	main
kus	doc_491521501961_item	2558711	et	3	main
ka	doc_491521501961_item	2558715	et	3	main
ei	doc_491521501961_item	2558722	et	4	main
neid	doc_491521501961_item	2558724	et	4	main
ega	doc_491521501961_item	2558725	et	3	main
huvitu	doc_491521501961_item	2558726	et	4	main
büroo	doc_491521501961_item	2558741	et	4	main
öökulli	doc_491521501961_item	2558753	et	4	main
järjekindlustus	doc_491521501961_item	2558769	et	3	main
tal	doc_491521501961_item	2558773	et	3	main
6	doc_491521501961_item	2558781	et	2	main
tolleaegne	doc_491521501962_item	2558815	et	3	main
ja	doc_491521501962_item	2558821	et	3	main
muutusid	doc_491521501962_item	2558830	et	4	main
loodan	doc_491521501962_item	2558838	et	3	main
ees	doc_491521501962_item	2558845	et	4	main
reeturlus	doc_491521501962_item	2558849	et	4	main
edaspidi	doc_491521501962_item	2558866	et	3	main
puutumast	doc_491521501962_item	2558870	et	4	main
on	doc_491521501962_item	2558872	et	4	main
olnud	doc_491521501962_item	2558873	et	4	main
et	doc_491521501960_item	2558374	et	3	main
oli	doc_491521501960_item	2558384	et	3	main
kodanik	doc_491521501960_item	2558386	et	3	main
see	doc_491521501960_item	2558389	et	3	main
on	doc_491521501960_item	2558391	et	4	main
mõtlen	doc_491521501960_item	2558400	et	3	main
et	doc_491521501960_item	2558401	et	3	main
kohtus	doc_491521501960_item	2558405	et	4	main
temal	doc_491521501960_item	2558422	et	3	main
ettevõtmini	doc_491521501960_item	2558427	et	4	main
13	doc_491521501961_item	2558430	et	2	main
nagu	doc_491521501961_item	2558455	et	3	main
huvid	doc_491521501961_item	2558459	et	3	main
suurimaks	doc_491521501961_item	2558465	et	4	main
küll	doc_491521501961_item	2558483	et	4	main
edaspidi	doc_491521501961_item	2558496	et	3	main
kokku	doc_491521501961_item	2558499	et	3	main
ongi	doc_491521501961_item	2558509	et	4	main
praegune	doc_491521501961_item	2558512	et	3	main
ainult	doc_491521501961_item	2558534	et	4	main
sest	doc_491521501961_item	2558541	et	4	main
rohkem	doc_491521501961_item	2558543	et	4	main
ja	doc_491521501961_item	2558545	et	3	main
võimu	doc_491521501961_item	2558546	et	4	main
ka	doc_491521501961_item	2558552	et	3	main
probleeme	doc_491521501961_item	2558553	et	3	main
mille	doc_491521501961_item	2558554	et	3	main
peale	doc_491521501961_item	2558555	et	4	main
kulub	doc_491521501961_item	2558556	et	3	main
rohkem	doc_491521501961_item	2558559	et	4	main
peale	doc_491521501961_item	2558562	et	4	main
palju	doc_491521501961_item	2558569	et	4	main
taset	doc_491521501961_item	2558578	et	3	main
kuid	doc_491521501961_item	2558628	et	4	main
ma	doc_491521501961_item	2558650	et	3	main
järjekindlus	doc_491521501961_item	2558655	et	4	main
alguses	doc_491521501961_item	2558672	et	4	main
lootnud	doc_491521501961_item	2558674	et	4	main
ei	doc_491521501961_item	2558675	et	4	main
pooleli	doc_491521501961_item	2558681	et	3	main
span	doc_491521501961_item	2558683	et	4	main
millises	doc_491521501961_item	2558684	et	3	main
eesti	doc_491521501961_item	2558687	et	4	main
elanud	doc_491521501961_item	2558692	et	4	main
venemaal	doc_491521501961_item	2558697	et	4	main
kuid	doc_491521501961_item	2558700	et	4	main
järgin	doc_491521501961_item	2558707	et	3	main
sündisid	doc_491521501961_item	2558712	et	4	main
loete	doc_491521501961_item	2558718	et	4	main
usu	doc_491521501961_item	2558723	et	4	main
see	doc_491521501961_item	2558734	et	3	main
tõeline	doc_491521501961_item	2558744	et	4	main
ta	doc_491521501961_item	2558764	et	4	main
see	doc_491521501961_item	2558767	et	3	main
dessantväelasest	doc_491521501962_item	2558816	et	3	main
film	doc_491521501962_item	2558818	et	3	main
aga	doc_491521501962_item	2558827	et	3	main
mida	doc_491521501962_item	2558831	et	4	main
oma	doc_491521501962_item	2558833	et	4	main
ma	doc_491521501962_item	2558837	et	3	main
selline	doc_491521501962_item	2558840	et	4	main
saavutus	doc_491521501962_item	2558841	et	4	main
mis	doc_491521501962_item	2558846	et	4	main
valetamine	doc_491521501962_item	2558851	et	4	main
välja	doc_491521501962_item	2558858	et	4	main
hoidun	doc_491521501962_item	2558865	et	3	main
teie	doc_491521501962_item	2558874	et	4	main
see	doc_491521501962_item	2558880	et	3	main
nimel	doc_491521501962_item	2558885	et	3	main
peale	doc_491521501962_item	2558925	et	4	main
tahan	doc_491521501962_item	2558937	et	3	main
saada	doc_491521501962_item	2558942	et	4	main
targemaks	doc_491521501962_item	2558943	et	4	main
eelkõige	doc_491521501962_item	2558944	et	3	main
tahaks	doc_491521501962_item	2558945	et	3	main
ida-virumaal	doc_491521501962_item	2558967	et	4	main
peipsi-äärne	doc_491521501962_item	2558968	et	3	main
alajõe	doc_491521501962_item	2558970	et	3	main
vasknarva	doc_491521501962_item	2558972	et	4	main
kohtuasjades	doc_491521501962_item	2558980	et	3	main
võimalikult	doc_491521501962_item	2558982	et	4	main
et	doc_491521501962_item	2558988	et	3	main
ole	doc_491521501960_item	2558424	et	4	main
13	doc_491521501961_item	2558432	et	2	main
saada	doc_491521501961_item	2558439	et	4	main
luurajaks	doc_491521501961_item	2558440	et	4	main
tahtsin	doc_491521501961_item	2558452	et	3	main
aga	doc_491521501961_item	2558457	et	3	main
hiljem	doc_491521501961_item	2558458	et	3	main
mida	doc_491521501961_item	2558461	et	4	main
saavutuseks	doc_491521501961_item	2558466	et	4	main
et	doc_491521501961_item	2558469	et	3	main
mis	doc_491521501961_item	2558476	et	4	main
ärritab	doc_491521501961_item	2558478	et	3	main
ütle	doc_491521501961_item	2558486	et	4	main
inimestele	doc_491521501961_item	2558487	et	3	main
petnud	doc_491521501961_item	2558493	et	4	main
inimestega	doc_491521501961_item	2558498	et	3	main
puutumast	doc_491521501961_item	2558500	et	4	main
mis	doc_491521501961_item	2558501	et	4	main
pööraseim	doc_491521501961_item	2558506	et	4	main
minu	doc_491521501961_item	2558511	et	3	main
nimel	doc_491521501961_item	2558515	et	3	main
et	doc_491521501961_item	2558516	et	3	main
kohlta-järve	doc_491521501961_item	2558517	et	4	main
õhk	doc_491521501961_item	2558518	et	3	main
puhtaks	doc_491521501961_item	2558519	et	3	main
saaks	doc_491521501961_item	2558520	et	3	main
on	doc_491521501961_item	2558522	et	4	main
hea	doc_491521501961_item	2558525	et	4	main
elada	doc_491521501961_item	2558526	et	3	main
ole	doc_491521501961_item	2558532	et	4	main
need	doc_491521501961_item	2558533	et	3	main
olevad	doc_491521501961_item	2558539	et	4	main
mida	doc_491521501961_item	2558542	et	4	main
raha	doc_491521501961_item	2558544	et	4	main
on	doc_491521501961_item	2558551	et	4	main
raha	doc_491521501961_item	2558560	et	4	main
mida	doc_491521501961_item	2558563	et	4	main
tahan	doc_491521501961_item	2558567	et	3	main
targemaks	doc_491521501961_item	2558573	et	4	main
eelkõige	doc_491521501961_item	2558574	et	3	main
õigusteaduses	doc_491521501961_item	2558581	et	3	main
nemad	doc_491521501961_item	2558456	et	3	main
ma	doc_491521501961_item	2558467	et	3	main
selline	doc_491521501961_item	2558470	et	4	main
saavutus	doc_491521501961_item	2558471	et	4	main
ootab	doc_491521501961_item	2558472	et	3	main
ees	doc_491521501961_item	2558475	et	4	main
reeturlus	doc_491521501961_item	2558479	et	4	main
ja	doc_491521501961_item	2558480	et	3	main
valetamine	doc_491521501961_item	2558481	et	4	main
ma	doc_491521501961_item	2558482	et	3	main
välja	doc_491521501961_item	2558488	et	4	main
et	doc_491521501961_item	2558489	et	3	main
nad	doc_491521501961_item	2558490	et	3	main
on	doc_491521501961_item	2558491	et	4	main
kuid	doc_491521501961_item	2558494	et	4	main
selliste	doc_491521501961_item	2558497	et	4	main
teie	doc_491521501961_item	2558504	et	4	main
elu	doc_491521501961_item	2558505	et	4	main
see	doc_491521501961_item	2558510	et	3	main
selle	doc_491521501961_item	2558514	et	4	main
kuid	doc_491521501961_item	2558529	et	4	main
kindlasti	doc_491521501961_item	2558530	et	3	main
võimu	doc_491521501961_item	2558537	et	4	main
käes	doc_491521501961_item	2558548	et	4	main
ma	doc_491521501961_item	2558566	et	3	main
oma	doc_491521501961_item	2558577	et	4	main
valitud	doc_491521501961_item	2558579	et	4	main
erialal	doc_491521501961_item	2558580	et	3	main
on	doc_491521501961_item	2558583	et	4	main
teie	doc_491521501961_item	2558584	et	4	main
jaoks	doc_491521501961_item	2558585	et	4	main
parim	doc_491521501961_item	2558586	et	4	main
puhkus	doc_491521501961_item	2558587	et	3	main
olla	doc_491521501961_item	2558588	et	3	main
koos	doc_491521501961_item	2558589	et	4	main
perega	doc_491521501961_item	2558590	et	3	main
kusagil	doc_491521501961_item	2558591	et	3	main
looduses	doc_491521501961_item	2558592	et	4	main
milline	doc_491521501961_item	2558593	et	3	main
on	doc_491521501961_item	2558594	et	4	main
teie	doc_491521501961_item	2558595	et	4	main
lemmikkoht	doc_491521501961_item	2558596	et	3	main
ida-virumaal	doc_491521501961_item	2558597	et	4	main
peipsi-äärne	doc_491521501961_item	2558598	et	3	main
kant	doc_491521501961_item	2558599	et	3	main
alajõe	doc_491521501961_item	2558600	et	3	main
karjamaa	doc_491521501961_item	2558601	et	4	main
vasknarva	doc_491521501961_item	2558602	et	4	main
mille	doc_491521501961_item	2558603	et	3	main
jaoks	doc_491521501961_item	2558604	et	4	main
ei	doc_491521501961_item	2558605	et	4	main
jätku	doc_491521501961_item	2558606	et	4	main
aega	doc_491521501961_item	2558607	et	4	main
kuna	doc_491521501961_item	2558608	et	3	main
tahan	doc_491521501961_item	2558609	et	3	main
kohtuasjades	doc_491521501961_item	2558610	et	3	main
inimesi	doc_491521501961_item	2558611	et	4	main
võimalikult	doc_491521501961_item	2558612	et	4	main
hästi	doc_491521501961_item	2558613	et	3	main
aidata	doc_491521501961_item	2558614	et	4	main
siis	doc_491521501961_item	2558615	et	3	main
tundub	doc_491521501961_item	2558616	et	3	main
alati	doc_491521501961_item	2558617	et	4	main
et	doc_491521501961_item	2558618	et	3	main
rohkem	doc_491521501961_item	2558621	et	4	main
siis	doc_491521501961_item	2558623	et	3	main
olen	doc_491521501961_item	2558630	et	3	main
omadust	doc_491521501961_item	2558645	et	4	main
peate	doc_491521501961_item	2558646	et	4	main
küljeks	doc_491521501961_item	2558649	et	3	main
asjad	doc_491521501961_item	2558657	et	3	main
lõpuni	doc_491521501961_item	2558658	et	3	main
isegi	doc_491521501961_item	2558659	et	4	main
siis	doc_491521501961_item	2558660	et	3	main
kui	doc_491521501961_item	2558661	et	3	main
see	doc_491521501961_item	2558662	et	3	main
tulemus	doc_491521501961_item	2558663	et	3	main
ei	doc_491521501961_item	2558664	et	4	main
ole	doc_491521501961_item	2558665	et	4	main
iga	doc_491521501961_item	2558666	et	4	main
kord	doc_491521501961_item	2558667	et	4	main
päris	doc_491521501961_item	2558668	et	4	main
see	doc_491521501961_item	2558669	et	3	main
ma	doc_491521501961_item	2558629	et	3	main
tüüpi	doc_491521501961_item	2558633	et	4	main
ja	doc_491521501961_item	2558635	et	3	main
oma	doc_491521501961_item	2558647	et	4	main
viia	doc_491521501961_item	2558656	et	3	main
mida	doc_491521501961_item	2558670	et	4	main
mul	doc_491521501961_item	2558677	et	3	main
kombeks	doc_491521501961_item	2558678	et	4	main
jätta	doc_491521501961_item	2558682	et	3	main
riigis	doc_491521501961_item	2558685	et	3	main
elada	doc_491521501961_item	2558689	et	3	main
olen	doc_491521501961_item	2558691	et	3	main
ja	doc_491521501961_item	2558693	et	3	main
tööd	doc_491521501961_item	2558695	et	4	main
kõige	doc_491521501961_item	2558705	et	4	main
oma	doc_491521501961_item	2558708	et	4	main
isa	doc_491521501961_item	2558709	et	4	main
seal	doc_491521501961_item	2558713	et	4	main
peab	doc_491521501961_item	2558714	et	4	main
kas	doc_491521501961_item	2558717	et	3	main
ma	doc_491521501961_item	2558671	et	3	main
peale	doc_491521501961_item	2558686	et	4	main
tahaksite	doc_491521501961_item	2558688	et	3	main
ma	doc_491521501961_item	2558690	et	3	main
elama	doc_491521501961_item	2558716	et	3	main
ei	doc_491521501961_item	2558720	et	4	main
nendest	doc_491521501961_item	2558727	et	4	main
see	doc_491521501961_item	2558728	et	3	main
ei	doc_491521501961_item	2558729	et	4	main
ole	doc_491521501961_item	2558730	et	4	main
tõsine	doc_491521501961_item	2558731	et	4	main
võimalda	doc_491521501961_item	2558735	et	4	main
jurist	doc_491521501961_item	2558738	et	3	main
kohtutäituri	doc_491521501961_item	2558740	et	4	main
elanik	doc_491521501961_item	2558748	et	3	main
loomult	doc_491521501961_item	2558752	et	3	main
ta	doc_491521501961_item	2558755	et	4	main
viia	doc_491521501961_item	2558770	et	3	main
jääta	doc_491521501961_item	2558780	et	4	main
järgib	doc_491521501961_item	2558782	et	3	main
saada	doc_491521501962_item	2558823	et	4	main
nagu	doc_491521501962_item	2558825	et	3	main
nemad	doc_491521501962_item	2558826	et	3	main
huvid	doc_491521501962_item	2558829	et	3	main
peate	doc_491521501962_item	2558832	et	4	main
elu	doc_491521501962_item	2558834	et	4	main
ootab	doc_491521501962_item	2558842	et	3	main
mind	doc_491521501962_item	2558843	et	4	main
ei	doc_491521501962_item	2558855	et	4	main
ütle	doc_491521501962_item	2558856	et	4	main
inimestele	doc_491521501962_item	2558857	et	3	main
kuid	doc_491521501962_item	2558864	et	4	main
mis	doc_491521501962_item	2558871	et	4	main
pööraseim	doc_491521501962_item	2558876	et	4	main
selle	doc_491521501962_item	2558884	et	4	main
on	doc_491521501962_item	2558917	et	4	main
rohkem	doc_491521501962_item	2558929	et	4	main
osta	doc_491521501962_item	2558935	et	4	main
palju	doc_491521501962_item	2558939	et	4	main
et	doc_491521501962_item	2558941	et	3	main
erialal	doc_491521501962_item	2558950	et	3	main
õigusteaduses	doc_491521501962_item	2558951	et	3	main
teie	doc_491521501962_item	2558954	et	4	main
puhkus	doc_491521501962_item	2558957	et	3	main
looduses	doc_491521501962_item	2558962	et	4	main
milline	doc_491521501962_item	2558963	et	3	main
on	doc_491521501962_item	2558964	et	4	main
aega	doc_491521501962_item	2558977	et	4	main
tahan	doc_491521501962_item	2558979	et	3	main
siis	doc_491521501962_item	2558985	et	3	main
oleks	doc_491521501962_item	2558989	et	3	main
arvan	doc_491521501962_item	2559021	et	3	main
isegi	doc_491521501962_item	2559029	et	4	main
päris	doc_491521501962_item	2559038	et	4	main
see	doc_491521501962_item	2559039	et	3	main
alguses	doc_491521501962_item	2559042	et	4	main
oma	doc_491521501962_item	2559049	et	4	main
span	doc_491521501962_item	2559053	et	4	main
kuid	doc_491521501962_item	2559070	et	4	main
mul	doc_491521501962_item	2559074	et	3	main
parem	doc_491521501962_item	2559076	et	4	main
järgin	doc_491521501962_item	2559077	et	3	main
isa	doc_491521501962_item	2559079	et	4	main
elama	doc_491521501962_item	2559086	et	3	main
ei	doc_491521501962_item	2559090	et	4	main
ole	doc_491521501962_item	2559100	et	4	main
1	doc_491521501961_item	2558733	et	2	main
4	doc_491521501961_item	2558737	et	2	main
või	doc_491521501961_item	2558739	et	4	main
tööline	doc_491521501961_item	2558742	et	4	main
2	doc_491521501961_item	2558743	et	2	main
5	doc_491521501961_item	2558749	et	2	main
on	doc_491521501961_item	2558751	et	4	main
teegema	doc_491521501961_item	2558759	et	4	main
ka	doc_491521501961_item	2558760	et	3	main
hilistel	doc_491521501961_item	2558761	et	3	main
öötundidel	doc_491521501961_item	2558762	et	3	main
on	doc_491521501961_item	2558768	et	4	main
lõpuni	doc_491521501961_item	2558772	et	3	main
ei	doc_491521501961_item	2558774	et	4	main
oma	doc_491521501961_item	2558783	et	4	main
õeldut	doc_491521501961_item	2558785	et	4	main
isa	doc_491521501961_item	2558784	et	4	main
et	doc_491521501961_item	2558786	et	3	main
seal	doc_491521501961_item	2558787	et	4	main
kus	doc_491521501961_item	2558788	et	3	main
sündisid	doc_491521501961_item	2558789	et	4	main
seal	doc_491521501961_item	2558790	et	4	main
tuleb	doc_491521501961_item	2558791	et	3	main
ka	doc_491521501961_item	2558792	et	3	main
elada	doc_491521501961_item	2558793	et	3	main
väga	doc_491521501961_item	2558794	et	3	main
tarke	doc_491521501961_item	2558795	et	3	main
ja	doc_491521501961_item	2558796	et	3	main
töökas	doc_491521501961_item	2558797	et	4	main
meesterahvas	doc_491521501961_item	2558798	et	4	main
12c	doc_491521501961_item	2558799	et	4	main
13	doc_491521501962_item	2558800	et	2	main
küsimust	doc_491521501962_item	2558801	et	4	main
13	doc_491521501962_item	2558802	et	2	main
küsimust	doc_491521501962_item	2558803	et	4	main
kelleks	doc_491521501962_item	2558804	et	4	main
tahtsite	doc_491521501962_item	2558805	et	3	main
lapsepõlves	doc_491521501962_item	2558806	et	4	main
saada	doc_491521501962_item	2558807	et	4	main
unistasin	doc_491521501962_item	2558808	et	3	main
saada	doc_491521501962_item	2558809	et	4	main
luurajaks	doc_491521501962_item	2558810	et	4	main
mind	doc_491521501962_item	2558811	et	4	main
köitis	doc_491521501962_item	2558812	et	3	main
ka	doc_491521501962_item	2558813	et	3	main
k-järve	doc_491521501961_item	2558747	et	4	main
ta	doc_491521501961_item	2558750	et	4	main
tõõpi	doc_491521501961_item	2558754	et	4	main
on	doc_491521501961_item	2558756	et	4	main
harjunud	doc_491521501961_item	2558757	et	4	main
tööd	doc_491521501961_item	2558758	et	4	main
3	doc_491521501961_item	2558763	et	2	main
arvab	doc_491521501961_item	2558765	et	3	main
et	doc_491521501961_item	2558766	et	3	main
asjad	doc_491521501961_item	2558771	et	3	main
ole	doc_491521501961_item	2558775	et	4	main
kombeks	doc_491521501961_item	2558776	et	4	main
oma	doc_491521501961_item	2558777	et	4	main
ettevõtmisi	doc_491521501961_item	2558778	et	3	main
pooleli	doc_491521501961_item	2558779	et	3	main
tehtud	doc_491521501962_item	2558817	et	4	main
sööst	doc_491521501962_item	2558819	et	3	main
väga	doc_491521501962_item	2558814	et	3	main
eritsooni	doc_491521501962_item	2558820	et	4	main
suurimaks	doc_491521501962_item	2558835	et	4	main
veel	doc_491521501962_item	2558844	et	4	main
teid	doc_491521501962_item	2558847	et	4	main
petnud	doc_491521501962_item	2558863	et	4	main
selliste	doc_491521501962_item	2558867	et	4	main
ongi	doc_491521501962_item	2558879	et	4	main
praegune	doc_491521501962_item	2558882	et	3	main
käes	doc_491521501962_item	2558918	et	4	main
seda	doc_491521501962_item	2558919	et	3	main
on	doc_491521501962_item	2558921	et	4	main
probleeme	doc_491521501962_item	2558923	et	3	main
raha	doc_491521501962_item	2558930	et	4	main
kommunaalkulude	doc_491521501962_item	2558931	et	3	main
ma	doc_491521501962_item	2558936	et	3	main
lugeda	doc_491521501962_item	2558940	et	3	main
tõsta	doc_491521501962_item	2558946	et	4	main
on	doc_491521501962_item	2558953	et	4	main
koos	doc_491521501962_item	2558959	et	4	main
kusagil	doc_491521501962_item	2558961	et	3	main
kuna	doc_491521501962_item	2558978	et	3	main
aidata	doc_491521501962_item	2558984	et	4	main
alati	doc_491521501962_item	2558987	et	4	main
et	doc_491521501962_item	2559022	et	3	main
on	doc_491521501962_item	2559024	et	4	main
viia	doc_491521501962_item	2559026	et	3	main
siis	doc_491521501962_item	2559030	et	3	main
see	doc_491521501962_item	2559032	et	3	main
ma	doc_491521501962_item	2559041	et	3	main
olin	doc_491521501962_item	2559043	et	3	main
kombeks	doc_491521501962_item	2559048	et	4	main
millises	doc_491521501962_item	2559054	et	3	main
peale	doc_491521501962_item	2559056	et	4	main
eesti	doc_491521501962_item	2559057	et	4	main
tahaksite	doc_491521501962_item	2559058	et	3	main
elada	doc_491521501962_item	2559059	et	3	main
ma	doc_491521501962_item	2559060	et	3	main
olen	doc_491521501962_item	2559061	et	3	main
elanud	doc_491521501962_item	2559062	et	4	main
ja	doc_491521501962_item	2559063	et	3	main
oma	doc_491521501962_item	2559078	et	4	main
loete	doc_491521501962_item	2559088	et	4	main
usu	doc_491521501962_item	2559093	et	4	main
ega	doc_491521501962_item	2559095	et	3	main
4	doc_491521501962_item	2559121	et	2	main
sinu	doc_491521501962_item	2559125	et	3	main
tugevad	doc_491521501962_item	2559137	et	4	main
et	doc_491521501962_item	2559145	et	3	main
tõeline	doc_491521501962_item	2559148	et	4	main
kodanik	doc_491521501962_item	2559150	et	3	main
töötab	doc_491521501962_item	2559160	et	3	main
öökulli	doc_491521501962_item	2559166	et	4	main
on	doc_491521501962_item	2559174	et	4	main
hea	doc_491521501962_item	2559175	et	4	main
saada	doc_491521501963_item	2559186	et	4	main
tahtsin	doc_491521501963_item	2559199	et	3	main
oma	doc_491521501963_item	2559210	et	4	main
et	doc_491521501963_item	2559216	et	3	main
ees	doc_491521501963_item	2559222	et	4	main
ma	doc_491521501963_item	2559229	et	3	main
küll	doc_491521501963_item	2559230	et	4	main
et	doc_491521501963_item	2559236	et	3	main
petnud	doc_491521501963_item	2559240	et	4	main
kuid	doc_491521501963_item	2559241	et	4	main
hoidun	doc_491521501963_item	2559242	et	3	main
edaspidi	doc_491521501963_item	2559243	et	3	main
olnud	doc_491521501963_item	2559250	et	4	main
see	doc_491521501963_item	2559257	et	3	main
praegune	doc_491521501963_item	2559259	et	3	main
selle	doc_491521501963_item	2559261	et	4	main
saaks	doc_491521501963_item	2559267	et	3	main
öelda	doc_491521501963_item	2559275	et	4	main
rikkad	doc_491521501963_item	2559282	et	4	main
ja	doc_491521501963_item	2559283	et	3	main
võimu	doc_491521501963_item	2559293	et	4	main
seda	doc_491521501963_item	2559296	et	3	main
tahaks	doc_491521501963_item	2559322	et	3	main
õigusteaduses	doc_491521501963_item	2559328	et	3	main
puhkus	doc_491521501963_item	2559334	et	3	main
ida-virumaal	doc_491521501963_item	2559344	et	4	main
aega	doc_491521501963_item	2559354	et	4	main
tahtsin	doc_491521501962_item	2558822	et	3	main
samasuguseks	doc_491521501962_item	2558824	et	4	main
hiljem	doc_491521501962_item	2558828	et	3	main
saavutuseks	doc_491521501962_item	2558836	et	4	main
et	doc_491521501962_item	2558839	et	3	main
ärritab	doc_491521501962_item	2558848	et	3	main
ja	doc_491521501962_item	2558850	et	3	main
ma	doc_491521501962_item	2558852	et	3	main
küll	doc_491521501962_item	2558853	et	4	main
üldiselt	doc_491521501962_item	2558854	et	4	main
et	doc_491521501962_item	2558859	et	3	main
nad	doc_491521501962_item	2558860	et	3	main
on	doc_491521501962_item	2558861	et	4	main
mind	doc_491521501962_item	2558862	et	4	main
inimestega	doc_491521501962_item	2558868	et	3	main
kokku	doc_491521501962_item	2558869	et	3	main
elu	doc_491521501962_item	2558875	et	4	main
minu	doc_491521501962_item	2558881	et	3	main
võitlus	doc_491521501962_item	2558883	et	3	main
et	doc_491521501962_item	2558886	et	3	main
kohlta-järve	doc_491521501962_item	2558887	et	4	main
õhk	doc_491521501962_item	2558888	et	3	main
puhtaks	doc_491521501962_item	2558889	et	3	main
saaks	doc_491521501962_item	2558890	et	3	main
kellel	doc_491521501962_item	2558891	et	4	main
on	doc_491521501962_item	2558892	et	4	main
tänapäeva	doc_491521501962_item	2558893	et	4	main
eestis	doc_491521501962_item	2558894	et	3	main
hea	doc_491521501962_item	2558895	et	4	main
elada	doc_491521501962_item	2558896	et	3	main
raske	doc_491521501962_item	2558897	et	4	main
öelda	doc_491521501962_item	2558898	et	4	main
kuid	doc_491521501962_item	2558899	et	4	main
kindlasti	doc_491521501962_item	2558900	et	3	main
ei	doc_491521501962_item	2558901	et	4	main
ole	doc_491521501962_item	2558902	et	4	main
need	doc_491521501962_item	2558903	et	3	main
rikkad	doc_491521501962_item	2558905	et	4	main
ja	doc_491521501962_item	2558906	et	3	main
võimu	doc_491521501962_item	2558907	et	4	main
ainult	doc_491521501962_item	2558904	et	4	main
juures	doc_491521501962_item	2558908	et	4	main
olevad	doc_491521501962_item	2558909	et	4	main
inimesed	doc_491521501962_item	2558910	et	3	main
sest	doc_491521501962_item	2558911	et	4	main
mida	doc_491521501962_item	2558912	et	4	main
rohkem	doc_491521501962_item	2558913	et	4	main
tegu	doc_491521501962_item	2558877	et	4	main
ilmselt	doc_491521501962_item	2558878	et	4	main
raha	doc_491521501962_item	2558914	et	4	main
ja	doc_491521501962_item	2558915	et	3	main
rohkem	doc_491521501962_item	2558920	et	4	main
ka	doc_491521501962_item	2558922	et	3	main
mille	doc_491521501962_item	2558924	et	3	main
teil	doc_491521501962_item	2558927	et	4	main
peale	doc_491521501962_item	2558932	et	4	main
mida	doc_491521501962_item	2558933	et	4	main
tahaksite	doc_491521501962_item	2558934	et	3	main
oma	doc_491521501962_item	2558947	et	4	main
taset	doc_491521501962_item	2558948	et	3	main
valitud	doc_491521501962_item	2558949	et	4	main
mis	doc_491521501962_item	2558952	et	4	main
parim	doc_491521501962_item	2558956	et	4	main
olla	doc_491521501962_item	2558958	et	3	main
perega	doc_491521501962_item	2558960	et	3	main
lemmikkoht	doc_491521501962_item	2558966	et	3	main
jätku	doc_491521501962_item	2558976	et	4	main
hästi	doc_491521501962_item	2558983	et	3	main
natukene	doc_491521501962_item	2558990	et	4	main
rohkem	doc_491521501962_item	2558991	et	4	main
jõuaks	doc_491521501962_item	2558994	et	3	main
veelgi	doc_491521501962_item	2558995	et	4	main
paremini	doc_491521501962_item	2558996	et	4	main
valmistuda	doc_491521501962_item	2558997	et	3	main
järjekindlus	doc_491521501962_item	2559025	et	4	main
ei	doc_491521501962_item	2559034	et	4	main
mida	doc_491521501962_item	2559040	et	4	main
mul	doc_491521501962_item	2559047	et	3	main
teinud	doc_491521501962_item	2559064	et	4	main
tööd	doc_491521501962_item	2559065	et	4	main
nii	doc_491521501962_item	2559066	et	3	main
venemaal	doc_491521501962_item	2559067	et	4	main
kui	doc_491521501962_item	2559068	et	3	main
siiski	doc_491521501962_item	2559071	et	4	main
eestis	doc_491521501962_item	2559073	et	3	main
sündisid	doc_491521501962_item	2559082	et	4	main
seal	doc_491521501962_item	2559083	et	4	main
peab	doc_491521501962_item	2559084	et	4	main
ka	doc_491521501962_item	2559085	et	3	main
ei	doc_491521501962_item	2559092	et	4	main
huvitu	doc_491521501962_item	2559096	et	4	main
see	doc_491521501962_item	2559098	et	3	main
võiks	doc_491521501962_item	2559124	et	4	main
töötada	doc_491521501962_item	2559127	et	3	main
on	doc_491521501962_item	2559130	et	4	main
6	doc_491521501962_item	2559133	et	2	main
missugused	doc_491521501962_item	2559134	et	3	main
iseloomusta	doc_491521501962_item	2559138	et	4	main
mees	doc_491521501962_item	2559146	et	4	main
või	doc_491521501962_item	2559158	et	4	main
ta	doc_491521501962_item	2559163	et	4	main
ma	doc_491521501962_item	2559169	et	3	main
et	doc_491521501962_item	2559171	et	3	main
küljed	doc_491521501962_item	2559173	et	3	main
13	doc_491521501963_item	2559179	et	2	main
luurajaks	doc_491521501963_item	2559187	et	4	main
ja	doc_491521501963_item	2559198	et	3	main
samasuguseks	doc_491521501963_item	2559201	et	4	main
aga	doc_491521501963_item	2559204	et	3	main
muutusid	doc_491521501963_item	2559207	et	4	main
mida	doc_491521501963_item	2559208	et	4	main
saavutuseks	doc_491521501963_item	2559213	et	4	main
ma	doc_491521501963_item	2559214	et	3	main
mis	doc_491521501963_item	2559223	et	4	main
teid	doc_491521501963_item	2559224	et	4	main
ärritab	doc_491521501963_item	2559225	et	3	main
ei	doc_491521501963_item	2559232	et	4	main
kokku	doc_491521501963_item	2559246	et	3	main
puutumast	doc_491521501963_item	2559247	et	4	main
elu	doc_491521501963_item	2559252	et	4	main
kohlta-järve	doc_491521501963_item	2559264	et	4	main
puhtaks	doc_491521501963_item	2559266	et	3	main
elada	doc_491521501963_item	2559273	et	3	main
kindlasti	doc_491521501963_item	2559277	et	3	main
mida	doc_491521501963_item	2559289	et	4	main
rohkem	doc_491521501963_item	2559290	et	4	main
teil	doc_491521501963_item	2559304	et	4	main
tõsta	doc_491521501963_item	2559323	et	4	main
valitud	doc_491521501963_item	2559326	et	4	main
võimu	doc_491521501962_item	2558916	et	4	main
kulub	doc_491521501962_item	2558926	et	3	main
kõige	doc_491521501962_item	2558928	et	4	main
väga	doc_491521501962_item	2558938	et	3	main
jaoks	doc_491521501962_item	2558955	et	4	main
teie	doc_491521501962_item	2558965	et	4	main
kant	doc_491521501962_item	2558969	et	3	main
karjamaa	doc_491521501962_item	2558971	et	4	main
mille	doc_491521501962_item	2558973	et	3	main
jaoks	doc_491521501962_item	2558974	et	4	main
ei	doc_491521501962_item	2558975	et	4	main
inimesi	doc_491521501962_item	2558981	et	4	main
tundub	doc_491521501962_item	2558986	et	3	main
kuid	doc_491521501962_item	2558998	et	4	main
ma	doc_491521501962_item	2558999	et	3	main
olen	doc_491521501962_item	2559000	et	3	main
öökulli	doc_491521501962_item	2559002	et	4	main
tüüpi	doc_491521501962_item	2559003	et	4	main
inimene	doc_491521501962_item	2559004	et	3	main
ja	doc_491521501962_item	2559005	et	3	main
seetõttu	doc_491521501962_item	2559006	et	3	main
olen	doc_491521501962_item	2559007	et	3	main
harjunud	doc_491521501962_item	2559008	et	4	main
tööd	doc_491521501962_item	2559009	et	4	main
tegema	doc_491521501962_item	2559010	et	3	main
ka	doc_491521501962_item	2559011	et	3	main
hilistel	doc_491521501962_item	2559012	et	3	main
öötundidel	doc_491521501962_item	2559013	et	3	main
millist	doc_491521501962_item	2559014	et	3	main
omadust	doc_491521501962_item	2559015	et	4	main
peate	doc_491521501962_item	2559016	et	4	main
oma	doc_491521501962_item	2559017	et	4	main
tugevaimaks	doc_491521501962_item	2559018	et	4	main
küljeks	doc_491521501962_item	2559019	et	3	main
ma	doc_491521501962_item	2559020	et	3	main
see	doc_491521501962_item	2559023	et	3	main
lõpuni	doc_491521501962_item	2559028	et	3	main
ole	doc_491521501962_item	2559046	et	4	main
pooleli	doc_491521501962_item	2559051	et	3	main
jätta	doc_491521501962_item	2559052	et	3	main
saksamaal	doc_491521501962_item	2559069	et	4	main
öeldut	doc_491521501962_item	2559080	et	4	main
kus	doc_491521501962_item	2559081	et	3	main
arvates	doc_491521501962_item	2559126	et	4	main
tööharjumused	doc_491521501962_item	2559132	et	3	main
kellest	doc_491521501962_item	2559140	et	4	main
kirjutatakse	doc_491521501962_item	2559141	et	3	main
arvan	doc_491521501962_item	2559144	et	3	main
pola	doc_491521501962_item	2559159	et	4	main
mees	doc_491521501962_item	2559176	et	4	main
13	doc_491521501963_item	2559177	et	2	main
küsimust	doc_491521501963_item	2559180	et	4	main
lapsepõlves	doc_491521501963_item	2559183	et	4	main
saada	doc_491521501963_item	2559184	et	4	main
unistasin	doc_491521501963_item	2559185	et	3	main
tolleaegne	doc_491521501963_item	2559192	et	3	main
tehtud	doc_491521501963_item	2559194	et	4	main
film	doc_491521501963_item	2559195	et	3	main
peate	doc_491521501963_item	2559209	et	4	main
loodan	doc_491521501963_item	2559215	et	3	main
saavutus	doc_491521501963_item	2559218	et	4	main
aega	doc_491521501962_item	2558992	et	4	main
siis	doc_491521501962_item	2558993	et	3	main
loomult	doc_491521501962_item	2559001	et	3	main
asjad	doc_491521501962_item	2559027	et	3	main
kui	doc_491521501962_item	2559031	et	3	main
tulemus	doc_491521501962_item	2559033	et	3	main
ole	doc_491521501962_item	2559035	et	4	main
iga	doc_491521501962_item	2559036	et	4	main
kord	doc_491521501962_item	2559037	et	4	main
lootnud	doc_491521501962_item	2559044	et	4	main
ei	doc_491521501962_item	2559045	et	4	main
ettevõtmisi	doc_491521501962_item	2559050	et	3	main
riigis	doc_491521501962_item	2559055	et	3	main
on	doc_491521501962_item	2559072	et	4	main
kõige	doc_491521501962_item	2559075	et	4	main
kas	doc_491521501962_item	2559087	et	3	main
horoskoope	doc_491521501962_item	2559089	et	3	main
ma	doc_491521501962_item	2559091	et	3	main
neid	doc_491521501962_item	2559094	et	4	main
nendest	doc_491521501962_item	2559097	et	4	main
ei	doc_491521501962_item	2559099	et	4	main
tõsine	doc_491521501962_item	2559101	et	4	main
asi	doc_491521501962_item	2559102	et	4	main
1	doc_491521501962_item	2559103	et	2	main
kas	doc_491521501962_item	2559104	et	3	main
intervjueeritav	doc_491521501962_item	2559105	et	4	main
on	doc_491521501962_item	2559106	et	4	main
mees	doc_491521501962_item	2559107	et	4	main
või	doc_491521501962_item	2559108	et	4	main
naine	doc_491521501962_item	2559109	et	3	main
2	doc_491521501962_item	2559110	et	2	main
kas	doc_491521501962_item	2559111	et	3	main
ta	doc_491521501962_item	2559112	et	4	main
on	doc_491521501962_item	2559113	et	4	main
3	doc_491521501962_item	2559115	et	2	main
elukutsell	doc_491521501962_item	2559114	et	4	main
missugune	doc_491521501962_item	2559116	et	3	main
ta	doc_491521501962_item	2559117	et	4	main
on	doc_491521501962_item	2559118	et	4	main
oma	doc_491521501962_item	2559119	et	4	main
iseloomult	doc_491521501962_item	2559120	et	3	main
ksu	doc_491521501962_item	2559122	et	4	main
5	doc_491521501962_item	2559128	et	2	main
tema	doc_491521501962_item	2559131	et	4	main
on	doc_491521501962_item	2559135	et	4	main
tema	doc_491521501962_item	2559136	et	4	main
ma	doc_491521501962_item	2559143	et	3	main
eesti	doc_491521501962_item	2559149	et	4	main
on	doc_491521501962_item	2559153	et	4	main
loomult	doc_491521501962_item	2559154	et	3	main
4	doc_491521501962_item	2559155	et	2	main
ma	doc_491521501962_item	2559156	et	3	main
arvan	doc_491521501962_item	2559157	et	3	main
5	doc_491521501962_item	2559162	et	2	main
on	doc_491521501962_item	2559164	et	4	main
tüüpi	doc_491521501962_item	2559167	et	4	main
tugevad	doc_491521501962_item	2559172	et	4	main
küsimust	doc_491521501963_item	2559178	et	4	main
kelleks	doc_491521501963_item	2559181	et	4	main
mind	doc_491521501963_item	2559188	et	4	main
köitis	doc_491521501963_item	2559189	et	3	main
ka	doc_491521501963_item	2559190	et	3	main
eritsooni	doc_491521501963_item	2559197	et	4	main
nemad	doc_491521501963_item	2559203	et	3	main
huvid	doc_491521501963_item	2559206	et	3	main
veel	doc_491521501963_item	2559221	et	4	main
ta	doc_491521501962_item	2559123	et	4	main
missugused	doc_491521501962_item	2559129	et	3	main
inimest	doc_491521501962_item	2559139	et	3	main
1	doc_491521501962_item	2559142	et	2	main
2	doc_491521501962_item	2559147	et	2	main
3	doc_491521501962_item	2559151	et	2	main
ta	doc_491521501962_item	2559152	et	4	main
kohtus	doc_491521501962_item	2559161	et	4	main
loomult	doc_491521501962_item	2559165	et	3	main
6	doc_491521501962_item	2559168	et	2	main
arvan	doc_491521501962_item	2559170	et	3	main
tahtsite	doc_491521501963_item	2559182	et	3	main
väga	doc_491521501963_item	2559191	et	3	main
dessantväelasest	doc_491521501963_item	2559193	et	3	main
sööst	doc_491521501963_item	2559196	et	3	main
saada	doc_491521501963_item	2559200	et	4	main
nagu	doc_491521501963_item	2559202	et	3	main
hiljem	doc_491521501963_item	2559205	et	3	main
elu	doc_491521501963_item	2559211	et	4	main
suurimaks	doc_491521501963_item	2559212	et	4	main
selline	doc_491521501963_item	2559217	et	4	main
mind	doc_491521501963_item	2559220	et	4	main
ootab	doc_491521501963_item	2559219	et	3	main
reeturlus	doc_491521501963_item	2559226	et	4	main
ütle	doc_491521501963_item	2559233	et	4	main
inimestele	doc_491521501963_item	2559234	et	3	main
välja	doc_491521501963_item	2559235	et	4	main
mind	doc_491521501963_item	2559239	et	4	main
on	doc_491521501963_item	2559249	et	4	main
tegu	doc_491521501963_item	2559254	et	4	main
et	doc_491521501963_item	2559263	et	3	main
õhk	doc_491521501963_item	2559265	et	3	main
kellel	doc_491521501963_item	2559268	et	4	main
on	doc_491521501963_item	2559269	et	4	main
raske	doc_491521501963_item	2559274	et	4	main
võimu	doc_491521501963_item	2559284	et	4	main
juures	doc_491521501963_item	2559285	et	4	main
raha	doc_491521501963_item	2559291	et	4	main
käes	doc_491521501963_item	2559295	et	4	main
rohkem	doc_491521501963_item	2559297	et	4	main
ja	doc_491521501963_item	2559227	et	3	main
on	doc_491521501963_item	2559238	et	4	main
mis	doc_491521501963_item	2559248	et	4	main
pööraseim	doc_491521501963_item	2559253	et	4	main
ongi	doc_491521501963_item	2559256	et	4	main
minu	doc_491521501963_item	2559258	et	3	main
võitlus	doc_491521501963_item	2559260	et	3	main
nimel	doc_491521501963_item	2559262	et	3	main
tänapäeva	doc_491521501963_item	2559270	et	4	main
eestis	doc_491521501963_item	2559271	et	3	main
hea	doc_491521501963_item	2559272	et	4	main
kuid	doc_491521501963_item	2559276	et	4	main
ei	doc_491521501963_item	2559278	et	4	main
olevad	doc_491521501963_item	2559286	et	4	main
inimesed	doc_491521501963_item	2559287	et	3	main
sest	doc_491521501963_item	2559288	et	4	main
on	doc_491521501963_item	2559294	et	4	main
on	doc_491521501963_item	2559298	et	4	main
ka	doc_491521501963_item	2559299	et	3	main
probleeme	doc_491521501963_item	2559300	et	3	main
mille	doc_491521501963_item	2559301	et	3	main
peale	doc_491521501963_item	2559302	et	4	main
kulub	doc_491521501963_item	2559303	et	3	main
rohkem	doc_491521501963_item	2559306	et	4	main
raha	doc_491521501963_item	2559307	et	4	main
kommunaalkulude	doc_491521501963_item	2559308	et	3	main
peale	doc_491521501963_item	2559309	et	4	main
mida	doc_491521501963_item	2559310	et	4	main
tahaksite	doc_491521501963_item	2559311	et	3	main
osta	doc_491521501963_item	2559312	et	4	main
ma	doc_491521501963_item	2559313	et	3	main
tahan	doc_491521501963_item	2559314	et	3	main
väga	doc_491521501963_item	2559315	et	3	main
palju	doc_491521501963_item	2559316	et	4	main
lugeda	doc_491521501963_item	2559317	et	3	main
et	doc_491521501963_item	2559318	et	3	main
saada	doc_491521501963_item	2559319	et	4	main
targemaks	doc_491521501963_item	2559320	et	4	main
eelkõige	doc_491521501963_item	2559321	et	3	main
jaoks	doc_491521501963_item	2559332	et	4	main
parim	doc_491521501963_item	2559333	et	4	main
olla	doc_491521501963_item	2559335	et	3	main
teie	doc_491521501963_item	2559342	et	4	main
peipsi-äärne	doc_491521501963_item	2559345	et	3	main
karjamaa	doc_491521501963_item	2559348	et	4	main
mille	doc_491521501963_item	2559350	et	3	main
kohtuasjades	doc_491521501963_item	2559357	et	3	main
ma	doc_491521501963_item	2559376	et	3	main
olen	doc_491521501963_item	2559377	et	3	main
et	doc_491521501963_item	2559399	et	3	main
iga	doc_491521501963_item	2559413	et	4	main
lootnud	doc_491521501963_item	2559421	et	4	main
tahaksite	doc_491521501963_item	2559435	et	3	main
ja	doc_491521501963_item	2559440	et	3	main
tööd	doc_491521501963_item	2559442	et	4	main
nii	doc_491521501963_item	2559443	et	3	main
venemaal	doc_491521501963_item	2559444	et	4	main
kui	doc_491521501963_item	2559445	et	3	main
mul	doc_491521501963_item	2559451	et	3	main
kõige	doc_491521501963_item	2559452	et	4	main
sündisid	doc_491521501963_item	2559459	et	4	main
ka	doc_491521501963_item	2559462	et	3	main
loete	doc_491521501963_item	2559465	et	4	main
ei	doc_491521501963_item	2559467	et	4	main
ei	doc_491521501963_item	2559476	et	4	main
öötundidel	doc_491521501963_item	2559519	et	3	main
tema	doc_491521501963_item	2559521	et	4	main
valetamine	doc_491521501963_item	2559228	et	4	main
üldiselt	doc_491521501963_item	2559231	et	4	main
nad	doc_491521501963_item	2559237	et	3	main
selliste	doc_491521501963_item	2559244	et	4	main
inimestega	doc_491521501963_item	2559245	et	3	main
teie	doc_491521501963_item	2559251	et	4	main
ilmselt	doc_491521501963_item	2559255	et	4	main
ole	doc_491521501963_item	2559279	et	4	main
need	doc_491521501963_item	2559280	et	3	main
ainult	doc_491521501963_item	2559281	et	4	main
ja	doc_491521501963_item	2559292	et	3	main
kõige	doc_491521501963_item	2559305	et	4	main
taset	doc_491521501963_item	2559325	et	3	main
erialal	doc_491521501963_item	2559327	et	3	main
mis	doc_491521501963_item	2559329	et	4	main
on	doc_491521501963_item	2559330	et	4	main
koos	doc_491521501963_item	2559336	et	4	main
perega	doc_491521501963_item	2559337	et	3	main
kusagil	doc_491521501963_item	2559338	et	3	main
looduses	doc_491521501963_item	2559339	et	4	main
milline	doc_491521501963_item	2559340	et	3	main
alajõe	doc_491521501963_item	2559347	et	3	main
jaoks	doc_491521501963_item	2559351	et	4	main
ei	doc_491521501963_item	2559352	et	4	main
hästi	doc_491521501963_item	2559360	et	3	main
öökulli	doc_491521501963_item	2559379	et	4	main
ja	doc_491521501963_item	2559382	et	3	main
olen	doc_491521501963_item	2559384	et	3	main
tööd	doc_491521501963_item	2559386	et	4	main
tegema	doc_491521501963_item	2559387	et	3	main
ka	doc_491521501963_item	2559388	et	3	main
millist	doc_491521501963_item	2559391	et	3	main
ma	doc_491521501963_item	2559397	et	3	main
ole	doc_491521501963_item	2559412	et	4	main
see	doc_491521501963_item	2559416	et	3	main
ma	doc_491521501963_item	2559418	et	3	main
olin	doc_491521501963_item	2559420	et	3	main
elada	doc_491521501963_item	2559436	et	3	main
siiski	doc_491521501963_item	2559448	et	4	main
isa	doc_491521501963_item	2559456	et	4	main
öeldut	doc_491521501963_item	2559457	et	4	main
peab	doc_491521501963_item	2559461	et	4	main
horoskoope	doc_491521501963_item	2559466	et	3	main
ma	doc_491521501963_item	2559468	et	3	main
ei	doc_491521501963_item	2559469	et	4	main
nendest	doc_491521501963_item	2559474	et	4	main
tõsine	doc_491521501963_item	2559478	et	4	main
12-c	doc_491521501963_item	2559529	et	4	main
küsimust	doc_491521501964_item	2559531	et	4	main
saada	doc_491521501964_item	2559539	et	4	main
film	doc_491521501964_item	2559548	et	3	main
sööst	doc_491521501964_item	2559549	et	3	main
saada	doc_491521501964_item	2559553	et	4	main
nagu	doc_491521501964_item	2559555	et	3	main
hiljem	doc_491521501964_item	2559558	et	3	main
elu	doc_491521501964_item	2559564	et	4	main
mis	doc_491521501964_item	2559576	et	4	main
praegune	doc_491521501964_item	2559612	et	3	main
et	doc_491521501964_item	2559616	et	3	main
saaks	doc_491521501964_item	2559620	et	3	main
kellel	doc_491521501964_item	2559621	et	4	main
hea	doc_491521501964_item	2559625	et	4	main
inimesed	doc_491521501964_item	2559640	et	3	main
rohkem	doc_491521501964_item	2559659	et	4	main
mida	doc_491521501964_item	2559663	et	4	main
osta	doc_491521501964_item	2559665	et	4	main
ma	doc_491521501964_item	2559666	et	3	main
tahan	doc_491521501964_item	2559667	et	3	main
väga	doc_491521501964_item	2559668	et	3	main
saada	doc_491521501964_item	2559672	et	4	main
eelkõige	doc_491521501964_item	2559674	et	3	main
mis	doc_491521501964_item	2559682	et	4	main
oma	doc_491521501963_item	2559324	et	4	main
on	doc_491521501963_item	2559341	et	4	main
kant	doc_491521501963_item	2559346	et	3	main
vasknarva	doc_491521501963_item	2559349	et	4	main
kuna	doc_491521501963_item	2559355	et	3	main
inimesi	doc_491521501963_item	2559358	et	4	main
võimalikult	doc_491521501963_item	2559359	et	4	main
aidata	doc_491521501963_item	2559361	et	4	main
siis	doc_491521501963_item	2559362	et	3	main
tundub	doc_491521501963_item	2559363	et	3	main
alati	doc_491521501963_item	2559364	et	4	main
et	doc_491521501963_item	2559365	et	3	main
oleks	doc_491521501963_item	2559366	et	3	main
natukene	doc_491521501963_item	2559367	et	4	main
rohkem	doc_491521501963_item	2559368	et	4	main
aega	doc_491521501963_item	2559369	et	4	main
siis	doc_491521501963_item	2559370	et	3	main
jõuaks	doc_491521501963_item	2559371	et	3	main
veelgi	doc_491521501963_item	2559372	et	4	main
paremini	doc_491521501963_item	2559373	et	4	main
valmistuda	doc_491521501963_item	2559374	et	3	main
kuid	doc_491521501963_item	2559375	et	4	main
teie	doc_491521501963_item	2559331	et	4	main
lemmikkoht	doc_491521501963_item	2559343	et	3	main
jätku	doc_491521501963_item	2559353	et	4	main
hilistel	doc_491521501963_item	2559389	et	3	main
küljeks	doc_491521501963_item	2559396	et	3	main
see	doc_491521501963_item	2559400	et	3	main
kord	doc_491521501963_item	2559414	et	4	main
oma	doc_491521501963_item	2559426	et	4	main
ettevõtmisi	doc_491521501963_item	2559427	et	3	main
pooleli	doc_491521501963_item	2559428	et	3	main
jätta	doc_491521501963_item	2559429	et	3	main
span	doc_491521501963_item	2559430	et	4	main
millises	doc_491521501963_item	2559431	et	3	main
riigis	doc_491521501963_item	2559432	et	3	main
peale	doc_491521501963_item	2559433	et	4	main
olen	doc_491521501963_item	2559438	et	3	main
kuid	doc_491521501963_item	2559447	et	4	main
järgin	doc_491521501963_item	2559454	et	3	main
kus	doc_491521501963_item	2559458	et	3	main
neid	doc_491521501963_item	2559471	et	4	main
iseloomusta	doc_491521501963_item	2559480	et	4	main
tahan	doc_491521501963_item	2559356	et	3	main
loomult	doc_491521501963_item	2559378	et	3	main
inimene	doc_491521501963_item	2559381	et	3	main
seetõttu	doc_491521501963_item	2559383	et	3	main
harjunud	doc_491521501963_item	2559385	et	4	main
öötundidel	doc_491521501963_item	2559390	et	3	main
omadust	doc_491521501963_item	2559392	et	4	main
peate	doc_491521501963_item	2559393	et	4	main
arvan	doc_491521501963_item	2559398	et	3	main
on	doc_491521501963_item	2559401	et	4	main
viia	doc_491521501963_item	2559403	et	3	main
asjad	doc_491521501963_item	2559404	et	3	main
lõpuni	doc_491521501963_item	2559405	et	3	main
isegi	doc_491521501963_item	2559406	et	4	main
siis	doc_491521501963_item	2559407	et	3	main
kui	doc_491521501963_item	2559408	et	3	main
see	doc_491521501963_item	2559409	et	3	main
tulemus	doc_491521501963_item	2559410	et	3	main
ei	doc_491521501963_item	2559411	et	4	main
päris	doc_491521501963_item	2559415	et	4	main
alguses	doc_491521501963_item	2559419	et	4	main
tüüpi	doc_491521501963_item	2559380	et	4	main
oma	doc_491521501963_item	2559394	et	4	main
tugevaimaks	doc_491521501963_item	2559395	et	4	main
järjekindlus	doc_491521501963_item	2559402	et	4	main
mida	doc_491521501963_item	2559417	et	4	main
ei	doc_491521501963_item	2559422	et	4	main
ole	doc_491521501963_item	2559423	et	4	main
mul	doc_491521501963_item	2559424	et	3	main
ma	doc_491521501963_item	2559437	et	3	main
elanud	doc_491521501963_item	2559439	et	4	main
teinud	doc_491521501963_item	2559441	et	4	main
on	doc_491521501963_item	2559449	et	4	main
eestis	doc_491521501963_item	2559450	et	3	main
oma	doc_491521501963_item	2559455	et	4	main
seal	doc_491521501963_item	2559460	et	4	main
elama	doc_491521501963_item	2559463	et	3	main
kas	doc_491521501963_item	2559464	et	3	main
ega	doc_491521501963_item	2559472	et	3	main
huvitu	doc_491521501963_item	2559473	et	4	main
ole	doc_491521501963_item	2559477	et	4	main
asi	doc_491521501963_item	2559479	et	4	main
tugevad	doc_491521501963_item	2559522	et	4	main
13	doc_491521501964_item	2559532	et	2	main
mind	doc_491521501964_item	2559541	et	4	main
köitis	doc_491521501964_item	2559542	et	3	main
ka	doc_491521501964_item	2559543	et	3	main
väga	doc_491521501964_item	2559544	et	3	main
tolleaegne	doc_491521501964_item	2559545	et	3	main
tehtud	doc_491521501964_item	2559547	et	4	main
peate	doc_491521501964_item	2559562	et	4	main
loodan	doc_491521501964_item	2559568	et	3	main
ootab	doc_491521501964_item	2559572	et	3	main
veel	doc_491521501964_item	2559574	et	4	main
ees	doc_491521501964_item	2559575	et	4	main
selle	doc_491521501964_item	2559614	et	4	main
kohlta-järve	doc_491521501964_item	2559617	et	4	main
õhk	doc_491521501964_item	2559618	et	3	main
eestis	doc_491521501964_item	2559624	et	3	main
elada	doc_491521501964_item	2559626	et	3	main
öelda	doc_491521501964_item	2559628	et	4	main
kuid	doc_491521501964_item	2559629	et	4	main
kindlasti	doc_491521501964_item	2559630	et	3	main
sest	doc_491521501964_item	2559641	et	4	main
võimu	doc_491521501964_item	2559646	et	4	main
kommunaalkulude	doc_491521501964_item	2559661	et	3	main
tahaksite	doc_491521501964_item	2559664	et	3	main
valitud	doc_491521501964_item	2559679	et	4	main
erialal	doc_491521501964_item	2559680	et	3	main
tundub	doc_491521501964_item	2559716	et	3	main
alati	doc_491521501964_item	2559717	et	4	main
et	doc_491521501964_item	2559718	et	3	main
oleks	doc_491521501964_item	2559719	et	3	main
rohkem	doc_491521501964_item	2559721	et	4	main
öötundidel	doc_491521501964_item	2559743	et	3	main
peate	doc_491521501964_item	2559746	et	4	main
tugevaimaks	doc_491521501964_item	2559748	et	4	main
küljeks	doc_491521501964_item	2559749	et	3	main
ma	doc_491521501964_item	2559750	et	3	main
arvan	doc_491521501964_item	2559751	et	3	main
et	doc_491521501964_item	2559752	et	3	main
see	doc_491521501964_item	2559753	et	3	main
on	doc_491521501964_item	2559754	et	4	main
tulemus	doc_491521501964_item	2559763	et	3	main
alguses	doc_491521501964_item	2559772	et	4	main
olin	doc_491521501964_item	2559773	et	3	main
lootnud	doc_491521501964_item	2559774	et	4	main
oma	doc_491521501964_item	2559779	et	4	main
eesti	doc_491521501964_item	2559786	et	4	main
elanud	doc_491521501964_item	2559791	et	4	main
venemaal	doc_491521501964_item	2559796	et	4	main
kui	doc_491521501964_item	2559797	et	3	main
mul	doc_491521501964_item	2559803	et	3	main
kõige	doc_491521501964_item	2559804	et	4	main
öeldut	doc_491521501964_item	2559809	et	4	main
kus	doc_491521501964_item	2559810	et	3	main
sündisid	doc_491521501964_item	2559811	et	4	main
kombeks	doc_491521501963_item	2559425	et	4	main
eesti	doc_491521501963_item	2559434	et	4	main
saksamaal	doc_491521501963_item	2559446	et	4	main
parem	doc_491521501963_item	2559453	et	4	main
usu	doc_491521501963_item	2559470	et	4	main
see	doc_491521501963_item	2559475	et	3	main
inimest	doc_491521501963_item	2559481	et	3	main
kellest	doc_491521501963_item	2559482	et	4	main
kirjutatakse	doc_491521501963_item	2559483	et	3	main
1	doc_491521501963_item	2559484	et	2	main
ma	doc_491521501963_item	2559485	et	3	main
arvan	doc_491521501963_item	2559486	et	3	main
et	doc_491521501963_item	2559487	et	3	main
see	doc_491521501963_item	2559488	et	3	main
on	doc_491521501963_item	2559489	et	4	main
mees	doc_491521501963_item	2559490	et	4	main
2	doc_491521501963_item	2559491	et	2	main
ma	doc_491521501963_item	2559492	et	3	main
arvan	doc_491521501963_item	2559493	et	3	main
et	doc_491521501963_item	2559494	et	3	main
ta	doc_491521501963_item	2559495	et	4	main
on	doc_491521501963_item	2559496	et	4	main
jurist	doc_491521501963_item	2559497	et	3	main
3	doc_491521501963_item	2559498	et	2	main
oma	doc_491521501963_item	2559499	et	4	main
iseloomult	doc_491521501963_item	2559500	et	3	main
ta	doc_491521501963_item	2559501	et	4	main
rahulik	doc_491521501963_item	2559503	et	3	main
on	doc_491521501963_item	2559502	et	4	main
lõbus	doc_491521501963_item	2559504	et	4	main
sõbralik	doc_491521501963_item	2559505	et	3	main
tark	doc_491521501963_item	2559506	et	3	main
4	doc_491521501963_item	2559507	et	2	main
ta	doc_491521501963_item	2559508	et	4	main
võiks	doc_491521501963_item	2559509	et	4	main
töötada	doc_491521501963_item	2559510	et	3	main
pankis	doc_491521501963_item	2559511	et	4	main
5	doc_491521501963_item	2559512	et	2	main
ta	doc_491521501963_item	2559513	et	4	main
on	doc_491521501963_item	2559514	et	4	main
harjunud	doc_491521501963_item	2559515	et	4	main
tööd	doc_491521501963_item	2559516	et	4	main
tegema	doc_491521501963_item	2559517	et	3	main
hilistel	doc_491521501963_item	2559518	et	3	main
6	doc_491521501963_item	2559520	et	2	main
lõpuni	doc_491521501963_item	2559528	et	3	main
13	doc_491521501964_item	2559530	et	2	main
kelleks	doc_491521501964_item	2559534	et	4	main
saada	doc_491521501964_item	2559537	et	4	main
unistasin	doc_491521501964_item	2559538	et	3	main
dessantväelasest	doc_491521501964_item	2559546	et	3	main
eritsooni	doc_491521501964_item	2559550	et	4	main
nemad	doc_491521501964_item	2559556	et	3	main
huvid	doc_491521501964_item	2559559	et	3	main
suurimaks	doc_491521501964_item	2559565	et	4	main
selline	doc_491521501964_item	2559570	et	4	main
teid	doc_491521501964_item	2559577	et	4	main
ärritab	doc_491521501964_item	2559578	et	3	main
minu	doc_491521501964_item	2559611	et	3	main
võitlus	doc_491521501964_item	2559613	et	3	main
puhtaks	doc_491521501964_item	2559619	et	3	main
küljed	doc_491521501963_item	2559523	et	3	main
järjekindlus	doc_491521501963_item	2559525	et	4	main
viia	doc_491521501963_item	2559526	et	3	main
asjad	doc_491521501963_item	2559527	et	3	main
küsimust	doc_491521501964_item	2559533	et	4	main
tahtsite	doc_491521501964_item	2559535	et	3	main
lapsepõlves	doc_491521501964_item	2559536	et	4	main
tahtsin	doc_491521501964_item	2559552	et	3	main
oma	doc_491521501964_item	2559563	et	4	main
et	doc_491521501964_item	2559569	et	3	main
mind	doc_491521501964_item	2559573	et	4	main
reeturlus	doc_491521501964_item	2559579	et	4	main
ja	doc_491521501964_item	2559580	et	3	main
valetamine	doc_491521501964_item	2559581	et	4	main
ma	doc_491521501964_item	2559582	et	3	main
küll	doc_491521501964_item	2559583	et	4	main
üldiselt	doc_491521501964_item	2559584	et	4	main
ei	doc_491521501964_item	2559585	et	4	main
ütle	doc_491521501964_item	2559586	et	4	main
inimestele	doc_491521501964_item	2559587	et	3	main
välja	doc_491521501964_item	2559588	et	4	main
et	doc_491521501964_item	2559589	et	3	main
on	doc_491521501964_item	2559591	et	4	main
nad	doc_491521501964_item	2559590	et	3	main
mind	doc_491521501964_item	2559592	et	4	main
petnud	doc_491521501964_item	2559593	et	4	main
kuid	doc_491521501964_item	2559594	et	4	main
hoidun	doc_491521501964_item	2559595	et	3	main
edaspidi	doc_491521501964_item	2559596	et	3	main
selliste	doc_491521501964_item	2559597	et	4	main
inimestega	doc_491521501964_item	2559598	et	3	main
kokku	doc_491521501964_item	2559599	et	3	main
puutumast	doc_491521501964_item	2559600	et	4	main
mis	doc_491521501964_item	2559601	et	4	main
on	doc_491521501964_item	2559602	et	4	main
olnud	doc_491521501964_item	2559603	et	4	main
teie	doc_491521501964_item	2559604	et	4	main
elu	doc_491521501964_item	2559605	et	4	main
pööraseim	doc_491521501964_item	2559606	et	4	main
tegu	doc_491521501964_item	2559607	et	4	main
ilmselt	doc_491521501964_item	2559608	et	4	main
ongi	doc_491521501964_item	2559609	et	4	main
see	doc_491521501964_item	2559610	et	3	main
on	doc_491521501963_item	2559524	et	4	main
luurajaks	doc_491521501964_item	2559540	et	4	main
ja	doc_491521501964_item	2559551	et	3	main
samasuguseks	doc_491521501964_item	2559554	et	4	main
aga	doc_491521501964_item	2559557	et	3	main
muutusid	doc_491521501964_item	2559560	et	4	main
mida	doc_491521501964_item	2559561	et	4	main
saavutuseks	doc_491521501964_item	2559566	et	4	main
ma	doc_491521501964_item	2559567	et	3	main
saavutus	doc_491521501964_item	2559571	et	4	main
on	doc_491521501964_item	2559622	et	4	main
ole	doc_491521501964_item	2559632	et	4	main
need	doc_491521501964_item	2559633	et	3	main
ainult	doc_491521501964_item	2559634	et	4	main
rikkad	doc_491521501964_item	2559635	et	4	main
ja	doc_491521501964_item	2559636	et	3	main
võimu	doc_491521501964_item	2559637	et	4	main
rohkem	doc_491521501964_item	2559643	et	4	main
ja	doc_491521501964_item	2559645	et	3	main
on	doc_491521501964_item	2559647	et	4	main
teil	doc_491521501964_item	2559657	et	4	main
kõige	doc_491521501964_item	2559658	et	4	main
palju	doc_491521501964_item	2559669	et	4	main
jaoks	doc_491521501964_item	2559685	et	4	main
hästi	doc_491521501964_item	2559713	et	3	main
veelgi	doc_491521501964_item	2559725	et	4	main
kuid	doc_491521501964_item	2559728	et	4	main
loomult	doc_491521501964_item	2559731	et	3	main
hilistel	doc_491521501964_item	2559742	et	3	main
asjad	doc_491521501964_item	2559757	et	3	main
ei	doc_491521501964_item	2559764	et	4	main
mida	doc_491521501964_item	2559770	et	4	main
kombeks	doc_491521501964_item	2559778	et	4	main
millises	doc_491521501964_item	2559783	et	3	main
peale	doc_491521501964_item	2559785	et	4	main
elada	doc_491521501964_item	2559788	et	3	main
on	doc_491521501964_item	2559801	et	4	main
eestis	doc_491521501964_item	2559802	et	3	main
ei	doc_491521501964_item	2559821	et	4	main
neid	doc_491521501964_item	2559823	et	4	main
ole	doc_491521501964_item	2559829	et	4	main
asi	doc_491521501964_item	2559831	et	4	main
ole	doc_491521501964_item	2559851	et	4	main
väga	doc_491521501964_item	2559852	et	3	main
raske	doc_491521501964_item	2559853	et	4	main
ja	doc_491521501964_item	2559854	et	3	main
ma	doc_491521501964_item	2559855	et	3	main
arvan	doc_491521501964_item	2559856	et	3	main
et	doc_491521501964_item	2559857	et	3	main
ta	doc_491521501964_item	2559858	et	4	main
talle	doc_491521501964_item	2559863	et	4	main
reeturlus	doc_491521501964_item	2559866	et	4	main
igav	doc_491521501964_item	2559877	et	3	main
inimene	doc_491521501964_item	2559878	et	3	main
ta	doc_491521501964_item	2559879	et	4	main
loomult	doc_491521501964_item	2559887	et	3	main
ma	doc_491521501964_item	2559889	et	3	main
võiks	doc_491521501964_item	2559893	et	4	main
tal	doc_491521501964_item	2559902	et	3	main
asjad	doc_491521501964_item	2559906	et	3	main
ka	doc_491521501965_item	2559922	et	3	main
dessantväelasest	doc_491521501965_item	2559925	et	3	main
film	doc_491521501965_item	2559927	et	3	main
samasuguseks	doc_491521501965_item	2559933	et	4	main
hiljem	doc_491521501965_item	2559937	et	3	main
saavutus	doc_491521501965_item	2559950	et	4	main
ootab	doc_491521501965_item	2559951	et	3	main
ärritab	doc_491521501965_item	2559957	et	3	main
on	doc_491521501965_item	2559981	et	4	main
ilmselt	doc_491521501965_item	2559987	et	4	main
minu	doc_491521501965_item	2559990	et	3	main
praegune	doc_491521501965_item	2559991	et	3	main
võitlus	doc_491521501965_item	2559992	et	3	main
kohlta-järve	doc_491521501965_item	2559996	et	4	main
õhk	doc_491521501965_item	2559997	et	3	main
tänapäeva	doc_491521501965_item	2560002	et	4	main
need	doc_491521501965_item	2560012	et	3	main
ja	doc_491521501965_item	2560015	et	3	main
juures	doc_491521501965_item	2560017	et	4	main
nimel	doc_491521501964_item	2559615	et	3	main
raske	doc_491521501964_item	2559627	et	4	main
olevad	doc_491521501964_item	2559639	et	4	main
käes	doc_491521501964_item	2559648	et	4	main
seda	doc_491521501964_item	2559649	et	3	main
raha	doc_491521501964_item	2559660	et	4	main
et	doc_491521501964_item	2559671	et	3	main
tahaks	doc_491521501964_item	2559675	et	3	main
õigusteaduses	doc_491521501964_item	2559681	et	3	main
aidata	doc_491521501964_item	2559714	et	4	main
siis	doc_491521501964_item	2559715	et	3	main
siis	doc_491521501964_item	2559723	et	3	main
millist	doc_491521501964_item	2559744	et	3	main
lõpuni	doc_491521501964_item	2559758	et	3	main
kui	doc_491521501964_item	2559761	et	3	main
ole	doc_491521501964_item	2559765	et	4	main
kord	doc_491521501964_item	2559767	et	4	main
päris	doc_491521501964_item	2559768	et	4	main
see	doc_491521501964_item	2559769	et	3	main
ole	doc_491521501964_item	2559776	et	4	main
mul	doc_491521501964_item	2559777	et	3	main
pooleli	doc_491521501964_item	2559781	et	3	main
riigis	doc_491521501964_item	2559784	et	3	main
tahaksite	doc_491521501964_item	2559787	et	3	main
saksamaal	doc_491521501964_item	2559798	et	4	main
kuid	doc_491521501964_item	2559799	et	4	main
isa	doc_491521501964_item	2559808	et	4	main
see	doc_491521501964_item	2559827	et	3	main
mees	doc_491521501964_item	2559842	et	4	main
see	doc_491521501964_item	2559843	et	3	main
mees	doc_491521501964_item	2559844	et	4	main
on	doc_491521501964_item	2559845	et	4	main
jurist	doc_491521501964_item	2559846	et	3	main
inimen	doc_491521501964_item	2559862	et	4	main
ta	doc_491521501964_item	2559874	et	4	main
töö	doc_491521501964_item	2559881	et	4	main
öötundidel	doc_491521501964_item	2559883	et	3	main
ta	doc_491521501964_item	2559885	et	4	main
arvan	doc_491521501964_item	2559890	et	3	main
ta	doc_491521501964_item	2559892	et	4	main
kohtus	doc_491521501964_item	2559895	et	4	main
ise	doc_491521501964_item	2559896	et	4	main
tolleaegne	doc_491521501965_item	2559924	et	3	main
eritsooni	doc_491521501965_item	2559929	et	4	main
nagu	doc_491521501965_item	2559934	et	3	main
aga	doc_491521501965_item	2559936	et	3	main
muutusid	doc_491521501965_item	2559939	et	4	main
peate	doc_491521501965_item	2559941	et	4	main
oma	doc_491521501965_item	2559942	et	4	main
loodan	doc_491521501965_item	2559947	et	3	main
mind	doc_491521501965_item	2559952	et	4	main
ees	doc_491521501965_item	2559954	et	4	main
mis	doc_491521501965_item	2559955	et	4	main
ja	doc_491521501965_item	2559959	et	3	main
kokku	doc_491521501965_item	2559978	et	3	main
saaks	doc_491521501965_item	2559999	et	3	main
on	doc_491521501965_item	2560001	et	4	main
eestis	doc_491521501965_item	2560003	et	3	main
raske	doc_491521501965_item	2560006	et	4	main
sest	doc_491521501965_item	2560020	et	4	main
mida	doc_491521501965_item	2560021	et	4	main
raha	doc_491521501965_item	2560023	et	4	main
ja	doc_491521501965_item	2560024	et	3	main
käes	doc_491521501965_item	2560027	et	4	main
rohkem	doc_491521501965_item	2560029	et	4	main
ka	doc_491521501965_item	2560031	et	3	main
probleeme	doc_491521501965_item	2560032	et	3	main
mille	doc_491521501965_item	2560033	et	3	main
peale	doc_491521501965_item	2560034	et	4	main
kulub	doc_491521501965_item	2560035	et	3	main
ma	doc_491521501965_item	2560045	et	3	main
oma	doc_491521501965_item	2560056	et	4	main
taset	doc_491521501965_item	2560057	et	3	main
on	doc_491521501965_item	2560062	et	4	main
kusagil	doc_491521501965_item	2560070	et	3	main
natukene	doc_491521501965_item	2560099	et	4	main
jõuaks	doc_491521501965_item	2560103	et	3	main
paremini	doc_491521501965_item	2560105	et	4	main
millist	doc_491521501965_item	2560123	et	3	main
kord	doc_491521501965_item	2560146	et	4	main
ei	doc_491521501965_item	2560154	et	4	main
eesti	doc_491521501965_item	2560165	et	4	main
tänapäeva	doc_491521501964_item	2559623	et	4	main
ei	doc_491521501964_item	2559631	et	4	main
juures	doc_491521501964_item	2559638	et	4	main
mida	doc_491521501964_item	2559642	et	4	main
raha	doc_491521501964_item	2559644	et	4	main
rohkem	doc_491521501964_item	2559650	et	4	main
on	doc_491521501964_item	2559651	et	4	main
ka	doc_491521501964_item	2559652	et	3	main
probleeme	doc_491521501964_item	2559653	et	3	main
mille	doc_491521501964_item	2559654	et	3	main
peale	doc_491521501964_item	2559655	et	4	main
kulub	doc_491521501964_item	2559656	et	3	main
peale	doc_491521501964_item	2559662	et	4	main
lugeda	doc_491521501964_item	2559670	et	3	main
targemaks	doc_491521501964_item	2559673	et	4	main
tõsta	doc_491521501964_item	2559676	et	4	main
oma	doc_491521501964_item	2559677	et	4	main
taset	doc_491521501964_item	2559678	et	3	main
on	doc_491521501964_item	2559683	et	4	main
teie	doc_491521501964_item	2559684	et	4	main
parim	doc_491521501964_item	2559686	et	4	main
puhkus	doc_491521501964_item	2559687	et	3	main
olla	doc_491521501964_item	2559688	et	3	main
koos	doc_491521501964_item	2559689	et	4	main
perega	doc_491521501964_item	2559690	et	3	main
kusagil	doc_491521501964_item	2559691	et	3	main
looduses	doc_491521501964_item	2559692	et	4	main
milline	doc_491521501964_item	2559693	et	3	main
on	doc_491521501964_item	2559694	et	4	main
teie	doc_491521501964_item	2559695	et	4	main
lemmikkoht	doc_491521501964_item	2559696	et	3	main
ida-virumaal	doc_491521501964_item	2559697	et	4	main
peipsi-äärne	doc_491521501964_item	2559698	et	3	main
kant	doc_491521501964_item	2559699	et	3	main
alajõe	doc_491521501964_item	2559700	et	3	main
karjamaa	doc_491521501964_item	2559701	et	4	main
vasknarva	doc_491521501964_item	2559702	et	4	main
mille	doc_491521501964_item	2559703	et	3	main
jaoks	doc_491521501964_item	2559704	et	4	main
ei	doc_491521501964_item	2559705	et	4	main
jätku	doc_491521501964_item	2559706	et	4	main
aega	doc_491521501964_item	2559707	et	4	main
kuna	doc_491521501964_item	2559708	et	3	main
tahan	doc_491521501964_item	2559709	et	3	main
kohtuasjades	doc_491521501964_item	2559710	et	3	main
inimesi	doc_491521501964_item	2559711	et	4	main
võimalikult	doc_491521501964_item	2559712	et	4	main
natukene	doc_491521501964_item	2559720	et	4	main
jõuaks	doc_491521501964_item	2559724	et	3	main
paremini	doc_491521501964_item	2559726	et	4	main
olen	doc_491521501964_item	2559730	et	3	main
öökulli	doc_491521501964_item	2559732	et	4	main
tüüpi	doc_491521501964_item	2559733	et	4	main
inimene	doc_491521501964_item	2559734	et	3	main
ja	doc_491521501964_item	2559735	et	3	main
seetõttu	doc_491521501964_item	2559736	et	3	main
olen	doc_491521501964_item	2559737	et	3	main
harjunud	doc_491521501964_item	2559738	et	4	main
tööd	doc_491521501964_item	2559739	et	4	main
tegema	doc_491521501964_item	2559740	et	3	main
omadust	doc_491521501964_item	2559745	et	4	main
oma	doc_491521501964_item	2559747	et	4	main
see	doc_491521501964_item	2559762	et	3	main
iga	doc_491521501964_item	2559766	et	4	main
ei	doc_491521501964_item	2559775	et	4	main
ettevõtmisi	doc_491521501964_item	2559780	et	3	main
ma	doc_491521501964_item	2559789	et	3	main
ja	doc_491521501964_item	2559792	et	3	main
parem	doc_491521501964_item	2559805	et	4	main
järgin	doc_491521501964_item	2559806	et	3	main
seal	doc_491521501964_item	2559812	et	4	main
usu	doc_491521501964_item	2559822	et	4	main
ega	doc_491521501964_item	2559824	et	3	main
huvitu	doc_491521501964_item	2559825	et	4	main
ei	doc_491521501964_item	2559828	et	4	main
ei	doc_491521501964_item	2559850	et	4	main
ole	doc_491521501964_item	2559860	et	4	main
usune	doc_491521501964_item	2559861	et	4	main
ei	doc_491521501964_item	2559864	et	4	main
ei	doc_491521501964_item	2559875	et	4	main
ole	doc_491521501964_item	2559876	et	4	main
hilistel	doc_491521501964_item	2559882	et	3	main
on	doc_491521501964_item	2559886	et	4	main
ta	doc_491521501964_item	2559897	et	4	main
arvab	doc_491521501964_item	2559898	et	3	main
et	doc_491521501964_item	2559899	et	3	main
tugevad	doc_491521501964_item	2559900	et	4	main
on	doc_491521501964_item	2559903	et	4	main
lõpuni	doc_491521501964_item	2559907	et	3	main
tehtud	doc_491521501965_item	2559926	et	4	main
tahtsin	doc_491521501965_item	2559931	et	3	main
selline	doc_491521501965_item	2559949	et	4	main
valetamine	doc_491521501965_item	2559960	et	4	main
mis	doc_491521501965_item	2559980	et	4	main
teie	doc_491521501965_item	2559983	et	4	main
pööraseim	doc_491521501965_item	2559985	et	4	main
selle	doc_491521501965_item	2559993	et	4	main
nimel	doc_491521501965_item	2559994	et	3	main
kellel	doc_491521501965_item	2560000	et	4	main
kuid	doc_491521501965_item	2560008	et	4	main
kindlasti	doc_491521501965_item	2560009	et	3	main
rikkad	doc_491521501965_item	2560014	et	4	main
võimu	doc_491521501965_item	2560016	et	4	main
teil	doc_491521501965_item	2560036	et	4	main
kõige	doc_491521501965_item	2560037	et	4	main
tahaksite	doc_491521501965_item	2560043	et	3	main
tahan	doc_491521501965_item	2560046	et	3	main
lugeda	doc_491521501965_item	2560049	et	3	main
saada	doc_491521501965_item	2560051	et	4	main
perega	doc_491521501965_item	2560069	et	3	main
vasknarva	doc_491521501965_item	2560081	et	4	main
mille	doc_491521501965_item	2560082	et	3	main
jaoks	doc_491521501965_item	2560083	et	4	main
ei	doc_491521501965_item	2560084	et	4	main
peate	doc_491521501965_item	2560125	et	4	main
oma	doc_491521501965_item	2560126	et	4	main
küljeks	doc_491521501965_item	2560128	et	3	main
arvan	doc_491521501965_item	2560130	et	3	main
see	doc_491521501965_item	2560132	et	3	main
on	doc_491521501965_item	2560133	et	4	main
järjekindlus	doc_491521501965_item	2560134	et	4	main
viia	doc_491521501965_item	2560135	et	3	main
isegi	doc_491521501965_item	2560138	et	4	main
siis	doc_491521501965_item	2560139	et	3	main
kui	doc_491521501965_item	2560140	et	3	main
see	doc_491521501965_item	2560141	et	3	main
päris	doc_491521501965_item	2560147	et	4	main
mida	doc_491521501965_item	2560149	et	4	main
ma	doc_491521501965_item	2560168	et	3	main
aega	doc_491521501964_item	2559722	et	4	main
valmistuda	doc_491521501964_item	2559727	et	3	main
ma	doc_491521501964_item	2559729	et	3	main
ka	doc_491521501964_item	2559741	et	3	main
järjekindlus	doc_491521501964_item	2559755	et	4	main
viia	doc_491521501964_item	2559756	et	3	main
isegi	doc_491521501964_item	2559759	et	4	main
siis	doc_491521501964_item	2559760	et	3	main
ma	doc_491521501964_item	2559771	et	3	main
jätta	doc_491521501964_item	2559782	et	3	main
olen	doc_491521501964_item	2559790	et	3	main
teinud	doc_491521501964_item	2559793	et	4	main
tööd	doc_491521501964_item	2559794	et	4	main
nii	doc_491521501964_item	2559795	et	3	main
siiski	doc_491521501964_item	2559800	et	4	main
oma	doc_491521501964_item	2559807	et	4	main
peab	doc_491521501964_item	2559813	et	4	main
ka	doc_491521501964_item	2559814	et	3	main
elama	doc_491521501964_item	2559815	et	3	main
kas	doc_491521501964_item	2559816	et	3	main
loete	doc_491521501964_item	2559817	et	4	main
horoskoope	doc_491521501964_item	2559818	et	3	main
ei	doc_491521501964_item	2559819	et	4	main
ma	doc_491521501964_item	2559820	et	3	main
nendest	doc_491521501964_item	2559826	et	4	main
tõsine	doc_491521501964_item	2559830	et	4	main
iseloomusta	doc_491521501964_item	2559832	et	4	main
inimest	doc_491521501964_item	2559833	et	3	main
kellest	doc_491521501964_item	2559834	et	4	main
kirjutatakse	doc_491521501964_item	2559835	et	3	main
ma	doc_491521501964_item	2559836	et	3	main
arvan	doc_491521501964_item	2559837	et	3	main
et	doc_491521501964_item	2559838	et	3	main
elukutselt	doc_491521501964_item	2559847	et	4	main
töötada	doc_491521501964_item	2559894	et	3	main
küljed	doc_491521501964_item	2559901	et	3	main
viia	doc_491521501964_item	2559905	et	3	main
13	doc_491521501965_item	2559909	et	2	main
köitis	doc_491521501965_item	2559921	et	3	main
väga	doc_491521501965_item	2559923	et	3	main
sööst	doc_491521501965_item	2559928	et	3	main
saada	doc_491521501965_item	2559932	et	4	main
elu	doc_491521501965_item	2559943	et	4	main
suurimaks	doc_491521501965_item	2559944	et	4	main
saavutuseks	doc_491521501965_item	2559945	et	4	main
et	doc_491521501965_item	2559948	et	3	main
teid	doc_491521501965_item	2559956	et	4	main
puutumast	doc_491521501965_item	2559979	et	4	main
olnud	doc_491521501965_item	2559982	et	4	main
elu	doc_491521501965_item	2559984	et	4	main
ongi	doc_491521501965_item	2559988	et	4	main
see	doc_491521501965_item	2559989	et	3	main
öelda	doc_491521501965_item	2560007	et	4	main
ole	doc_491521501965_item	2560011	et	4	main
olevad	doc_491521501965_item	2560018	et	4	main
rohkem	doc_491521501965_item	2560022	et	4	main
osta	doc_491521501965_item	2560044	et	4	main
väga	doc_491521501965_item	2560047	et	3	main
valitud	doc_491521501965_item	2560058	et	4	main
erialal	doc_491521501965_item	2560059	et	3	main
mis	doc_491521501965_item	2560061	et	4	main
jaoks	doc_491521501965_item	2560064	et	4	main
puhkus	doc_491521501965_item	2560066	et	3	main
olla	doc_491521501965_item	2560067	et	3	main
looduses	doc_491521501965_item	2560071	et	4	main
milline	doc_491521501965_item	2560072	et	3	main
teie	doc_491521501965_item	2560074	et	4	main
lemmikkoht	doc_491521501965_item	2560075	et	3	main
ida-virumaal	doc_491521501965_item	2560076	et	4	main
peipsi-äärne	doc_491521501965_item	2560077	et	3	main
kant	doc_491521501965_item	2560078	et	3	main
jätku	doc_491521501965_item	2560085	et	4	main
alati	doc_491521501965_item	2560096	et	4	main
et	doc_491521501965_item	2560097	et	3	main
see	doc_491521501964_item	2559839	et	3	main
inimene	doc_491521501964_item	2559840	et	3	main
on	doc_491521501964_item	2559841	et	4	main
tema	doc_491521501964_item	2559848	et	4	main
iseloom	doc_491521501964_item	2559849	et	3	main
ei	doc_491521501964_item	2559859	et	4	main
meeldi	doc_491521501964_item	2559865	et	4	main
ja	doc_491521501964_item	2559867	et	3	main
valetamine	doc_491521501964_item	2559868	et	4	main
armastab	doc_491521501964_item	2559869	et	3	main
värske	doc_491521501964_item	2559870	et	4	main
õhk	doc_491521501964_item	2559871	et	3	main
arvan	doc_491521501964_item	2559872	et	3	main
et	doc_491521501964_item	2559873	et	3	main
teeb	doc_491521501964_item	2559880	et	3	main
sest	doc_491521501964_item	2559884	et	4	main
öökulli	doc_491521501964_item	2559888	et	4	main
et	doc_491521501964_item	2559891	et	3	main
järjekindlus	doc_491521501964_item	2559904	et	4	main
12s	doc_491521501964_item	2559908	et	4	main
küsimust	doc_491521501965_item	2559910	et	4	main
13	doc_491521501965_item	2559911	et	2	main
küsimust	doc_491521501965_item	2559912	et	4	main
kelleks	doc_491521501965_item	2559913	et	4	main
tahtsite	doc_491521501965_item	2559914	et	3	main
lapsepõlves	doc_491521501965_item	2559915	et	4	main
saada	doc_491521501965_item	2559916	et	4	main
unistasin	doc_491521501965_item	2559917	et	3	main
saada	doc_491521501965_item	2559918	et	4	main
luurajaks	doc_491521501965_item	2559919	et	4	main
mind	doc_491521501965_item	2559920	et	4	main
ja	doc_491521501965_item	2559930	et	3	main
nemad	doc_491521501965_item	2559935	et	3	main
huvid	doc_491521501965_item	2559938	et	3	main
mida	doc_491521501965_item	2559940	et	4	main
ma	doc_491521501965_item	2559946	et	3	main
veel	doc_491521501965_item	2559953	et	4	main
reeturlus	doc_491521501965_item	2559958	et	4	main
ma	doc_491521501965_item	2559961	et	3	main
küll	doc_491521501965_item	2559962	et	4	main
üldiselt	doc_491521501965_item	2559963	et	4	main
ei	doc_491521501965_item	2559964	et	4	main
ütle	doc_491521501965_item	2559965	et	4	main
inimestele	doc_491521501965_item	2559966	et	3	main
välja	doc_491521501965_item	2559967	et	4	main
et	doc_491521501965_item	2559968	et	3	main
nad	doc_491521501965_item	2559969	et	3	main
on	doc_491521501965_item	2559970	et	4	main
mind	doc_491521501965_item	2559971	et	4	main
petnud	doc_491521501965_item	2559972	et	4	main
kuid	doc_491521501965_item	2559973	et	4	main
hoidun	doc_491521501965_item	2559974	et	3	main
edaspidi	doc_491521501965_item	2559975	et	3	main
selliste	doc_491521501965_item	2559976	et	4	main
inimestega	doc_491521501965_item	2559977	et	3	main
tegu	doc_491521501965_item	2559986	et	4	main
et	doc_491521501965_item	2559995	et	3	main
puhtaks	doc_491521501965_item	2559998	et	3	main
hea	doc_491521501965_item	2560004	et	4	main
elada	doc_491521501965_item	2560005	et	3	main
ei	doc_491521501965_item	2560010	et	4	main
ainult	doc_491521501965_item	2560013	et	4	main
inimesed	doc_491521501965_item	2560019	et	3	main
on	doc_491521501965_item	2560026	et	4	main
mida	doc_491521501965_item	2560042	et	4	main
õigusteaduses	doc_491521501965_item	2560060	et	3	main
parim	doc_491521501965_item	2560065	et	4	main
koos	doc_491521501965_item	2560068	et	4	main
on	doc_491521501965_item	2560073	et	4	main
rohkem	doc_491521501965_item	2560100	et	4	main
veelgi	doc_491521501965_item	2560104	et	4	main
omadust	doc_491521501965_item	2560124	et	4	main
tugevaimaks	doc_491521501965_item	2560127	et	4	main
ma	doc_491521501965_item	2560129	et	3	main
et	doc_491521501965_item	2560131	et	3	main
ole	doc_491521501965_item	2560155	et	4	main
mul	doc_491521501965_item	2560156	et	3	main
kombeks	doc_491521501965_item	2560157	et	4	main
oma	doc_491521501965_item	2560158	et	4	main
ettevõtmisi	doc_491521501965_item	2560159	et	3	main
pooleli	doc_491521501965_item	2560160	et	3	main
jätta	doc_491521501965_item	2560161	et	3	main
millises	doc_491521501965_item	2560162	et	3	main
riigis	doc_491521501965_item	2560163	et	3	main
peale	doc_491521501965_item	2560164	et	4	main
nii	doc_491521501965_item	2560174	et	3	main
kuid	doc_491521501965_item	2560178	et	4	main
öeldut	doc_491521501965_item	2560188	et	4	main
kus	doc_491521501965_item	2560189	et	3	main
ei	doc_491521501965_item	2560198	et	4	main
usu	doc_491521501965_item	2560201	et	4	main
on	doc_491521501965_item	2560223	et	4	main
tugev	doc_491521501965_item	2560225	et	4	main
viib	doc_491521501965_item	2560228	et	3	main
siis	doc_491521501965_item	2560232	et	3	main
ta	doc_491521501965_item	2560242	et	4	main
kombeks	doc_491521501965_item	2560249	et	4	main
jääta	doc_491521501965_item	2560253	et	4	main
tüüpi	doc_491521501965_item	2560264	et	4	main
seetõttu	doc_491521501965_item	2560267	et	3	main
tegeb	doc_491521501965_item	2560271	et	4	main
kõige	doc_491521501965_item	2560275	et	4	main
külg	doc_491521501965_item	2560277	et	3	main
viia	doc_491521501965_item	2560278	et	3	main
asjad	doc_491521501965_item	2560279	et	3	main
lõpuni	doc_491521501965_item	2560280	et	3	main
12c	doc_491521501965_item	2560281	et	4	main
13	doc_491521501966_item	2560282	et	2	main
tahtsite	doc_491521501966_item	2560287	et	3	main
saada	doc_491521501966_item	2560289	et	4	main
ees	doc_491521501966_item	2560327	et	4	main
ma	doc_491521501966_item	2560334	et	3	main
välja	doc_491521501966_item	2560340	et	4	main
et	doc_491521501966_item	2560341	et	3	main
nad	doc_491521501966_item	2560342	et	3	main
on	doc_491521501966_item	2560343	et	4	main
mis	doc_491521501966_item	2560353	et	4	main
tegu	doc_491521501966_item	2560359	et	4	main
ilmselt	doc_491521501966_item	2560360	et	4	main
ongi	doc_491521501966_item	2560361	et	4	main
raske	doc_491521501966_item	2560379	et	4	main
need	doc_491521501966_item	2560385	et	3	main
ainult	doc_491521501966_item	2560386	et	4	main
juures	doc_491521501966_item	2560390	et	4	main
inimesed	doc_491521501966_item	2560392	et	3	main
on	doc_491521501966_item	2560403	et	4	main
et	doc_491521501966_item	2560423	et	3	main
tõsta	doc_491521501966_item	2560428	et	4	main
õigusteaduses	doc_491521501966_item	2560433	et	3	main
jaoks	doc_491521501966_item	2560437	et	4	main
koos	doc_491521501966_item	2560441	et	4	main
looduses	doc_491521501966_item	2560444	et	4	main
kant	doc_491521501966_item	2560451	et	3	main
tahan	doc_491521501966_item	2560461	et	3	main
võimalikult	doc_491521501966_item	2560464	et	4	main
võimu	doc_491521501965_item	2560025	et	4	main
seda	doc_491521501965_item	2560028	et	3	main
on	doc_491521501965_item	2560030	et	4	main
rohkem	doc_491521501965_item	2560038	et	4	main
raha	doc_491521501965_item	2560039	et	4	main
kommunaalkulude	doc_491521501965_item	2560040	et	3	main
peale	doc_491521501965_item	2560041	et	4	main
palju	doc_491521501965_item	2560048	et	4	main
et	doc_491521501965_item	2560050	et	3	main
targemaks	doc_491521501965_item	2560052	et	4	main
eelkõige	doc_491521501965_item	2560053	et	3	main
tahaks	doc_491521501965_item	2560054	et	3	main
tõsta	doc_491521501965_item	2560055	et	4	main
teie	doc_491521501965_item	2560063	et	4	main
alajõe	doc_491521501965_item	2560079	et	3	main
karjamaa	doc_491521501965_item	2560080	et	4	main
aega	doc_491521501965_item	2560086	et	4	main
kuna	doc_491521501965_item	2560087	et	3	main
tahan	doc_491521501965_item	2560088	et	3	main
kohtuasjades	doc_491521501965_item	2560089	et	3	main
inimesi	doc_491521501965_item	2560090	et	4	main
võimalikult	doc_491521501965_item	2560091	et	4	main
hästi	doc_491521501965_item	2560092	et	3	main
aidata	doc_491521501965_item	2560093	et	4	main
siis	doc_491521501965_item	2560094	et	3	main
tundub	doc_491521501965_item	2560095	et	3	main
aega	doc_491521501965_item	2560101	et	4	main
valmistuda	doc_491521501965_item	2560106	et	3	main
kuid	doc_491521501965_item	2560107	et	4	main
ma	doc_491521501965_item	2560108	et	3	main
olen	doc_491521501965_item	2560109	et	3	main
loomult	doc_491521501965_item	2560110	et	3	main
öökulli	doc_491521501965_item	2560111	et	4	main
tüüpi	doc_491521501965_item	2560112	et	4	main
inimene	doc_491521501965_item	2560113	et	3	main
ja	doc_491521501965_item	2560114	et	3	main
seetõttu	doc_491521501965_item	2560115	et	3	main
olen	doc_491521501965_item	2560116	et	3	main
harjunud	doc_491521501965_item	2560117	et	4	main
tööd	doc_491521501965_item	2560118	et	4	main
tegema	doc_491521501965_item	2560119	et	3	main
ka	doc_491521501965_item	2560120	et	3	main
hilistel	doc_491521501965_item	2560121	et	3	main
asjad	doc_491521501965_item	2560136	et	3	main
lõpuni	doc_491521501965_item	2560137	et	3	main
ei	doc_491521501965_item	2560143	et	4	main
ole	doc_491521501965_item	2560144	et	4	main
iga	doc_491521501965_item	2560145	et	4	main
ma	doc_491521501965_item	2560150	et	3	main
saksamaal	doc_491521501965_item	2560177	et	4	main
eestis	doc_491521501965_item	2560181	et	3	main
kõige	doc_491521501965_item	2560183	et	4	main
isa	doc_491521501965_item	2560187	et	4	main
ma	doc_491521501965_item	2560199	et	3	main
ei	doc_491521501965_item	2560235	et	4	main
ei	doc_491521501965_item	2560246	et	4	main
pooleli	doc_491521501965_item	2560252	et	3	main
töötada	doc_491521501965_item	2560258	et	3	main
oleb	doc_491521501965_item	2560268	et	4	main
küsimust	doc_491521501966_item	2560283	et	4	main
oleks	doc_491521501965_item	2560098	et	3	main
siis	doc_491521501965_item	2560102	et	3	main
öötundidel	doc_491521501965_item	2560122	et	3	main
tulemus	doc_491521501965_item	2560142	et	3	main
see	doc_491521501965_item	2560148	et	3	main
alguses	doc_491521501965_item	2560151	et	4	main
olin	doc_491521501965_item	2560152	et	3	main
lootnud	doc_491521501965_item	2560153	et	4	main
tööd	doc_491521501965_item	2560173	et	4	main
mul	doc_491521501965_item	2560182	et	3	main
sündisid	doc_491521501965_item	2560190	et	4	main
horoskoope	doc_491521501965_item	2560197	et	3	main
ei	doc_491521501965_item	2560200	et	4	main
neid	doc_491521501965_item	2560202	et	4	main
ega	doc_491521501965_item	2560203	et	3	main
huvitu	doc_491521501965_item	2560204	et	4	main
nendest	doc_491521501965_item	2560205	et	4	main
see	doc_491521501965_item	2560206	et	3	main
ei	doc_491521501965_item	2560207	et	4	main
ole	doc_491521501965_item	2560208	et	4	main
tõsine	doc_491521501965_item	2560209	et	4	main
asi	doc_491521501965_item	2560210	et	4	main
intervjueeritav	doc_491521501965_item	2560211	et	4	main
on	doc_491521501965_item	2560212	et	4	main
mees	doc_491521501965_item	2560213	et	4	main
ma	doc_491521501965_item	2560214	et	3	main
arvan	doc_491521501965_item	2560215	et	3	main
nii	doc_491521501965_item	2560216	et	3	main
elukutselt	doc_491521501965_item	2560217	et	4	main
ta	doc_491521501965_item	2560218	et	4	main
jurist	doc_491521501965_item	2560219	et	3	main
oma	doc_491521501965_item	2560220	et	4	main
tal	doc_491521501965_item	2560222	et	3	main
väga	doc_491521501965_item	2560224	et	3	main
külje	doc_491521501965_item	2560226	et	3	main
ta	doc_491521501965_item	2560227	et	4	main
isegi	doc_491521501965_item	2560231	et	4	main
mida	doc_491521501965_item	2560241	et	4	main
ole	doc_491521501965_item	2560247	et	4	main
tal	doc_491521501965_item	2560248	et	3	main
minu	doc_491521501965_item	2560254	et	3	main
arvate	doc_491521501965_item	2560255	et	3	main
inimene	doc_491521501965_item	2560265	et	3	main
ja	doc_491521501965_item	2560266	et	3	main
töd	doc_491521501965_item	2560270	et	4	main
tugev	doc_491521501965_item	2560276	et	4	main
küsimust	doc_491521501966_item	2560285	et	4	main
lapsepõlves	doc_491521501966_item	2560288	et	4	main
unistasin	doc_491521501966_item	2560290	et	3	main
mind	doc_491521501966_item	2560325	et	4	main
veel	doc_491521501966_item	2560326	et	4	main
reeturlus	doc_491521501966_item	2560331	et	4	main
ja	doc_491521501966_item	2560332	et	3	main
mind	doc_491521501966_item	2560344	et	4	main
puutumast	doc_491521501966_item	2560352	et	4	main
olnud	doc_491521501966_item	2560355	et	4	main
teie	doc_491521501966_item	2560356	et	4	main
puhtaks	doc_491521501966_item	2560371	et	3	main
tänapäeva	doc_491521501966_item	2560375	et	4	main
eestis	doc_491521501966_item	2560376	et	3	main
mida	doc_491521501966_item	2560394	et	4	main
ja	doc_491521501966_item	2560397	et	3	main
võimu	doc_491521501966_item	2560398	et	4	main
ka	doc_491521501966_item	2560404	et	3	main
probleeme	doc_491521501966_item	2560405	et	3	main
tahaksite	doc_491521501965_item	2560166	et	3	main
elada	doc_491521501965_item	2560167	et	3	main
elanud	doc_491521501965_item	2560170	et	4	main
ja	doc_491521501965_item	2560171	et	3	main
teinud	doc_491521501965_item	2560172	et	4	main
kui	doc_491521501965_item	2560176	et	3	main
siiski	doc_491521501965_item	2560179	et	4	main
asjad	doc_491521501965_item	2560229	et	3	main
tulemus	doc_491521501965_item	2560234	et	3	main
ole	doc_491521501965_item	2560236	et	4	main
kord	doc_491521501965_item	2560238	et	4	main
päris	doc_491521501965_item	2560239	et	4	main
see	doc_491521501965_item	2560240	et	3	main
oma	doc_491521501965_item	2560250	et	4	main
võib	doc_491521501965_item	2560257	et	3	main
ta	doc_491521501965_item	2560260	et	4	main
on	doc_491521501965_item	2560261	et	4	main
loomult	doc_491521501965_item	2560262	et	3	main
öökuli	doc_491521501965_item	2560263	et	4	main
hiliste	doc_491521501965_item	2560273	et	3	main
13	doc_491521501966_item	2560284	et	2	main
selline	doc_491521501966_item	2560322	et	4	main
mis	doc_491521501966_item	2560328	et	4	main
üldiselt	doc_491521501966_item	2560336	et	4	main
ütle	doc_491521501966_item	2560338	et	4	main
petnud	doc_491521501966_item	2560345	et	4	main
kuid	doc_491521501966_item	2560346	et	4	main
hoidun	doc_491521501966_item	2560347	et	3	main
selliste	doc_491521501966_item	2560349	et	4	main
inimestega	doc_491521501966_item	2560350	et	3	main
kokku	doc_491521501966_item	2560351	et	3	main
on	doc_491521501966_item	2560354	et	4	main
saaks	doc_491521501966_item	2560372	et	3	main
on	doc_491521501966_item	2560374	et	4	main
hea	doc_491521501966_item	2560377	et	4	main
elada	doc_491521501966_item	2560378	et	3	main
ole	doc_491521501966_item	2560384	et	4	main
rohkem	doc_491521501966_item	2560395	et	4	main
raha	doc_491521501966_item	2560396	et	4	main
rohkem	doc_491521501966_item	2560402	et	4	main
saada	doc_491521501966_item	2560424	et	4	main
oma	doc_491521501966_item	2560429	et	4	main
mis	doc_491521501966_item	2560434	et	4	main
puhkus	doc_491521501966_item	2560439	et	3	main
peipsi-äärne	doc_491521501966_item	2560450	et	3	main
jaoks	doc_491521501966_item	2560456	et	4	main
jätku	doc_491521501966_item	2560458	et	4	main
kohtuasjades	doc_491521501966_item	2560462	et	3	main
aidata	doc_491521501966_item	2560466	et	4	main
tundub	doc_491521501966_item	2560468	et	3	main
natukene	doc_491521501966_item	2560472	et	4	main
veelgi	doc_491521501966_item	2560477	et	4	main
olen	doc_491521501966_item	2560482	et	3	main
seetõttu	doc_491521501966_item	2560488	et	3	main
lootnud	doc_491521501966_item	2560526	et	4	main
oma	doc_491521501966_item	2560531	et	4	main
millises	doc_491521501966_item	2560535	et	3	main
eesti	doc_491521501966_item	2560538	et	4	main
elanud	doc_491521501966_item	2560543	et	4	main
kuid	doc_491521501966_item	2560551	et	4	main
järgin	doc_491521501966_item	2560558	et	3	main
öeldut	doc_491521501966_item	2560561	et	4	main
kus	doc_491521501966_item	2560562	et	3	main
ei	doc_491521501966_item	2560571	et	4	main
ma	doc_491521501966_item	2560572	et	3	main
neid	doc_491521501966_item	2560575	et	4	main
huvitu	doc_491521501966_item	2560577	et	4	main
nendest	doc_491521501966_item	2560578	et	4	main
see	doc_491521501966_item	2560579	et	3	main
iseloomusta	doc_491521501966_item	2560584	et	4	main
inimest	doc_491521501966_item	2560585	et	3	main
luurajaks	doc_491521501966_item	2560603	et	4	main
2	doc_491521501966_item	2560604	et	2	main
on	doc_491521501966_item	2560618	et	4	main
olen	doc_491521501965_item	2560169	et	3	main
venemaal	doc_491521501965_item	2560175	et	4	main
on	doc_491521501965_item	2560180	et	4	main
parem	doc_491521501965_item	2560184	et	4	main
järgin	doc_491521501965_item	2560185	et	3	main
oma	doc_491521501965_item	2560186	et	4	main
seal	doc_491521501965_item	2560191	et	4	main
peab	doc_491521501965_item	2560192	et	4	main
ka	doc_491521501965_item	2560193	et	3	main
elama	doc_491521501965_item	2560194	et	3	main
kas	doc_491521501965_item	2560195	et	3	main
loete	doc_491521501965_item	2560196	et	4	main
iseloomult	doc_491521501965_item	2560221	et	3	main
lõpuni	doc_491521501965_item	2560230	et	3	main
kui	doc_491521501965_item	2560233	et	3	main
iga	doc_491521501965_item	2560237	et	4	main
alguses	doc_491521501965_item	2560243	et	4	main
oli	doc_491521501965_item	2560244	et	3	main
lootnud	doc_491521501965_item	2560245	et	4	main
ettevõtmisi	doc_491521501965_item	2560251	et	3	main
ta	doc_491521501965_item	2560256	et	4	main
kohtus	doc_491521501965_item	2560259	et	4	main
harjunud	doc_491521501965_item	2560269	et	4	main
ka	doc_491521501965_item	2560272	et	3	main
öötundidel	doc_491521501965_item	2560274	et	3	main
kelleks	doc_491521501966_item	2560286	et	4	main
saada	doc_491521501966_item	2560291	et	4	main
luurajaks	doc_491521501966_item	2560292	et	4	main
mind	doc_491521501966_item	2560293	et	4	main
köitis	doc_491521501966_item	2560294	et	3	main
ka	doc_491521501966_item	2560295	et	3	main
väga	doc_491521501966_item	2560296	et	3	main
tolleaegne	doc_491521501966_item	2560297	et	3	main
dessantväelasest	doc_491521501966_item	2560298	et	3	main
film	doc_491521501966_item	2560300	et	3	main
sööst	doc_491521501966_item	2560301	et	3	main
eritsooni	doc_491521501966_item	2560302	et	4	main
ja	doc_491521501966_item	2560303	et	3	main
tehtud	doc_491521501966_item	2560299	et	4	main
tahtsin	doc_491521501966_item	2560304	et	3	main
saada	doc_491521501966_item	2560305	et	4	main
samasuguseks	doc_491521501966_item	2560306	et	4	main
nagu	doc_491521501966_item	2560307	et	3	main
nemad	doc_491521501966_item	2560308	et	3	main
aga	doc_491521501966_item	2560309	et	3	main
hiljem	doc_491521501966_item	2560310	et	3	main
huvid	doc_491521501966_item	2560311	et	3	main
muutusid	doc_491521501966_item	2560312	et	4	main
mida	doc_491521501966_item	2560313	et	4	main
peate	doc_491521501966_item	2560314	et	4	main
oma	doc_491521501966_item	2560315	et	4	main
elu	doc_491521501966_item	2560316	et	4	main
suurimaks	doc_491521501966_item	2560317	et	4	main
saavutuseks	doc_491521501966_item	2560318	et	4	main
ma	doc_491521501966_item	2560319	et	3	main
loodan	doc_491521501966_item	2560320	et	3	main
et	doc_491521501966_item	2560321	et	3	main
saavutus	doc_491521501966_item	2560323	et	4	main
ootab	doc_491521501966_item	2560324	et	3	main
ärritab	doc_491521501966_item	2560330	et	3	main
küll	doc_491521501966_item	2560335	et	4	main
elu	doc_491521501966_item	2560357	et	4	main
see	doc_491521501966_item	2560362	et	3	main
minu	doc_491521501966_item	2560363	et	3	main
teid	doc_491521501966_item	2560329	et	4	main
valetamine	doc_491521501966_item	2560333	et	4	main
ei	doc_491521501966_item	2560337	et	4	main
inimestele	doc_491521501966_item	2560339	et	3	main
edaspidi	doc_491521501966_item	2560348	et	3	main
pööraseim	doc_491521501966_item	2560358	et	4	main
kohlta-järve	doc_491521501966_item	2560369	et	4	main
õhk	doc_491521501966_item	2560370	et	3	main
öelda	doc_491521501966_item	2560380	et	4	main
kuid	doc_491521501966_item	2560381	et	4	main
kindlasti	doc_491521501966_item	2560382	et	3	main
ei	doc_491521501966_item	2560383	et	4	main
võimu	doc_491521501966_item	2560389	et	4	main
sest	doc_491521501966_item	2560393	et	4	main
on	doc_491521501966_item	2560399	et	4	main
kõige	doc_491521501966_item	2560410	et	4	main
rohkem	doc_491521501966_item	2560411	et	4	main
raha	doc_491521501966_item	2560412	et	4	main
kommunaalkulude	doc_491521501966_item	2560413	et	3	main
peale	doc_491521501966_item	2560414	et	4	main
mida	doc_491521501966_item	2560415	et	4	main
tahaksite	doc_491521501966_item	2560416	et	3	main
ma	doc_491521501966_item	2560418	et	3	main
tahan	doc_491521501966_item	2560419	et	3	main
osta	doc_491521501966_item	2560417	et	4	main
väga	doc_491521501966_item	2560420	et	3	main
lugeda	doc_491521501966_item	2560422	et	3	main
tahaks	doc_491521501966_item	2560427	et	3	main
erialal	doc_491521501966_item	2560432	et	3	main
on	doc_491521501966_item	2560435	et	4	main
olla	doc_491521501966_item	2560440	et	3	main
on	doc_491521501966_item	2560446	et	4	main
teie	doc_491521501966_item	2560447	et	4	main
lemmikkoht	doc_491521501966_item	2560448	et	3	main
aega	doc_491521501966_item	2560459	et	4	main
et	doc_491521501966_item	2560470	et	3	main
valmistuda	doc_491521501966_item	2560479	et	3	main
ma	doc_491521501966_item	2560481	et	3	main
inimene	doc_491521501966_item	2560486	et	3	main
praegune	doc_491521501966_item	2560364	et	3	main
võitlus	doc_491521501966_item	2560365	et	3	main
selle	doc_491521501966_item	2560366	et	4	main
nimel	doc_491521501966_item	2560367	et	3	main
et	doc_491521501966_item	2560368	et	3	main
kellel	doc_491521501966_item	2560373	et	4	main
rikkad	doc_491521501966_item	2560387	et	4	main
ja	doc_491521501966_item	2560388	et	3	main
olevad	doc_491521501966_item	2560391	et	4	main
käes	doc_491521501966_item	2560400	et	4	main
seda	doc_491521501966_item	2560401	et	3	main
mille	doc_491521501966_item	2560406	et	3	main
peale	doc_491521501966_item	2560407	et	4	main
kulub	doc_491521501966_item	2560408	et	3	main
teil	doc_491521501966_item	2560409	et	4	main
targemaks	doc_491521501966_item	2560425	et	4	main
valitud	doc_491521501966_item	2560431	et	4	main
teie	doc_491521501966_item	2560436	et	4	main
perega	doc_491521501966_item	2560442	et	3	main
ida-virumaal	doc_491521501966_item	2560449	et	4	main
karjamaa	doc_491521501966_item	2560453	et	4	main
mille	doc_491521501966_item	2560455	et	3	main
kuna	doc_491521501966_item	2560460	et	3	main
hästi	doc_491521501966_item	2560465	et	3	main
alati	doc_491521501966_item	2560469	et	4	main
aega	doc_491521501966_item	2560474	et	4	main
jõuaks	doc_491521501966_item	2560476	et	3	main
loomult	doc_491521501966_item	2560483	et	3	main
ja	doc_491521501966_item	2560487	et	3	main
tööd	doc_491521501966_item	2560491	et	4	main
ole	doc_491521501966_item	2560528	et	4	main
riigis	doc_491521501966_item	2560536	et	3	main
elada	doc_491521501966_item	2560540	et	3	main
olen	doc_491521501966_item	2560542	et	3	main
ja	doc_491521501966_item	2560544	et	3	main
seal	doc_491521501966_item	2560564	et	4	main
peab	doc_491521501966_item	2560565	et	4	main
ka	doc_491521501966_item	2560566	et	3	main
elama	doc_491521501966_item	2560567	et	3	main
kas	doc_491521501966_item	2560568	et	3	main
loete	doc_491521501966_item	2560569	et	4	main
horoskoope	doc_491521501966_item	2560570	et	3	main
usu	doc_491521501966_item	2560574	et	4	main
ega	doc_491521501966_item	2560576	et	3	main
tõsine	doc_491521501966_item	2560582	et	4	main
on	doc_491521501966_item	2560590	et	4	main
oli	doc_491521501966_item	2560597	et	3	main
sellepärast	doc_491521501966_item	2560599	et	3	main
tahaksid	doc_491521501966_item	2560601	et	4	main
on	doc_491521501966_item	2560607	et	4	main
elukutselt	doc_491521501966_item	2560608	et	4	main
et	doc_491521501966_item	2560611	et	3	main
ta	doc_491521501966_item	2560621	et	4	main
järjekindlus	doc_491521501966_item	2560623	et	4	main
kus	doc_491521501966_item	2560628	et	3	main
arvates	doc_491521501966_item	2560632	et	4	main
töötada	doc_491521501966_item	2560633	et	3	main
ma	doc_491521501966_item	2560634	et	3	main
arvan	doc_491521501966_item	2560635	et	3	main
5	doc_491521501966_item	2560641	et	2	main
missugused	doc_491521501966_item	2560642	et	3	main
tööd	doc_491521501966_item	2560649	et	4	main
tegema	doc_491521501966_item	2560650	et	3	main
ka	doc_491521501966_item	2560651	et	3	main
hilistel	doc_491521501966_item	2560652	et	3	main
6	doc_491521501966_item	2560654	et	2	main
tugevad	doc_491521501966_item	2560658	et	4	main
ma	doc_491521501966_item	2560660	et	3	main
et	doc_491521501966_item	2560662	et	3	main
13	doc_491521501967_item	2560671	et	2	main
küsimust	doc_491521501967_item	2560674	et	4	main
tahtsite	doc_491521501967_item	2560676	et	3	main
saada	doc_491521501967_item	2560680	et	4	main
mind	doc_491521501967_item	2560682	et	4	main
samasuguseks	doc_491521501967_item	2560695	et	4	main
oma	doc_491521501967_item	2560704	et	4	main
palju	doc_491521501966_item	2560421	et	4	main
eelkõige	doc_491521501966_item	2560426	et	3	main
taset	doc_491521501966_item	2560430	et	3	main
parim	doc_491521501966_item	2560438	et	4	main
kusagil	doc_491521501966_item	2560443	et	3	main
milline	doc_491521501966_item	2560445	et	3	main
alajõe	doc_491521501966_item	2560452	et	3	main
vasknarva	doc_491521501966_item	2560454	et	4	main
ei	doc_491521501966_item	2560457	et	4	main
inimesi	doc_491521501966_item	2560463	et	4	main
siis	doc_491521501966_item	2560467	et	3	main
rohkem	doc_491521501966_item	2560473	et	4	main
paremini	doc_491521501966_item	2560478	et	4	main
öökulli	doc_491521501966_item	2560484	et	4	main
olen	doc_491521501966_item	2560489	et	3	main
tegema	doc_491521501966_item	2560492	et	3	main
ka	doc_491521501966_item	2560493	et	3	main
hilistel	doc_491521501966_item	2560494	et	3	main
öötundidel	doc_491521501966_item	2560495	et	3	main
millist	doc_491521501966_item	2560496	et	3	main
omadust	doc_491521501966_item	2560497	et	4	main
peate	doc_491521501966_item	2560498	et	4	main
oma	doc_491521501966_item	2560499	et	4	main
tugevaimaks	doc_491521501966_item	2560500	et	4	main
küljeks	doc_491521501966_item	2560501	et	3	main
ma	doc_491521501966_item	2560502	et	3	main
arvan	doc_491521501966_item	2560503	et	3	main
et	doc_491521501966_item	2560504	et	3	main
see	doc_491521501966_item	2560505	et	3	main
on	doc_491521501966_item	2560506	et	4	main
järjekindlus	doc_491521501966_item	2560507	et	4	main
asjad	doc_491521501966_item	2560509	et	3	main
viia	doc_491521501966_item	2560508	et	3	main
lõpuni	doc_491521501966_item	2560510	et	3	main
isegi	doc_491521501966_item	2560511	et	4	main
siis	doc_491521501966_item	2560512	et	3	main
kui	doc_491521501966_item	2560513	et	3	main
see	doc_491521501966_item	2560514	et	3	main
tulemus	doc_491521501966_item	2560515	et	3	main
ei	doc_491521501966_item	2560516	et	4	main
ole	doc_491521501966_item	2560517	et	4	main
kord	doc_491521501966_item	2560519	et	4	main
iga	doc_491521501966_item	2560518	et	4	main
päris	doc_491521501966_item	2560520	et	4	main
see	doc_491521501966_item	2560521	et	3	main
mida	doc_491521501966_item	2560522	et	4	main
alguses	doc_491521501966_item	2560524	et	4	main
olin	doc_491521501966_item	2560525	et	3	main
teinud	doc_491521501966_item	2560545	et	4	main
tööd	doc_491521501966_item	2560546	et	4	main
nii	doc_491521501966_item	2560547	et	3	main
ei	doc_491521501966_item	2560573	et	4	main
asi	doc_491521501966_item	2560583	et	4	main
oleks	doc_491521501966_item	2560471	et	3	main
siis	doc_491521501966_item	2560475	et	3	main
kuid	doc_491521501966_item	2560480	et	4	main
tüüpi	doc_491521501966_item	2560485	et	4	main
harjunud	doc_491521501966_item	2560490	et	4	main
ei	doc_491521501966_item	2560527	et	4	main
pooleli	doc_491521501966_item	2560533	et	3	main
peale	doc_491521501966_item	2560537	et	4	main
tahaksite	doc_491521501966_item	2560539	et	3	main
ma	doc_491521501966_item	2560541	et	3	main
saksamaal	doc_491521501966_item	2560550	et	4	main
ei	doc_491521501966_item	2560580	et	4	main
kellest	doc_491521501966_item	2560586	et	4	main
kirjutatakse	doc_491521501966_item	2560587	et	3	main
mees	doc_491521501966_item	2560591	et	4	main
naine	doc_491521501966_item	2560593	et	3	main
et	doc_491521501966_item	2560596	et	3	main
kes	doc_491521501966_item	2560605	et	4	main
ma	doc_491521501966_item	2560609	et	3	main
ta	doc_491521501966_item	2560612	et	4	main
on	doc_491521501966_item	2560613	et	4	main
juurist	doc_491521501966_item	2560614	et	3	main
3	doc_491521501966_item	2560615	et	2	main
oma	doc_491521501966_item	2560619	et	4	main
asjad	doc_491521501966_item	2560625	et	3	main
ta	doc_491521501966_item	2560637	et	4	main
töötada	doc_491521501966_item	2560639	et	3	main
on	doc_491521501966_item	2560643	et	4	main
tema	doc_491521501966_item	2560644	et	4	main
tööharjumused	doc_491521501966_item	2560645	et	3	main
missugused	doc_491521501966_item	2560655	et	3	main
on	doc_491521501966_item	2560666	et	4	main
viia	doc_491521501966_item	2560668	et	3	main
lõpuni	doc_491521501966_item	2560670	et	3	main
13	doc_491521501967_item	2560673	et	2	main
unistasin	doc_491521501967_item	2560679	et	3	main
luurajaks	doc_491521501967_item	2560681	et	4	main
köitis	doc_491521501967_item	2560683	et	3	main
ka	doc_491521501967_item	2560684	et	3	main
väga	doc_491521501967_item	2560685	et	3	main
tolleaegne	doc_491521501967_item	2560686	et	3	main
dessantväelasest	doc_491521501967_item	2560687	et	3	main
tehtud	doc_491521501967_item	2560688	et	4	main
film	doc_491521501967_item	2560689	et	3	main
sööst	doc_491521501967_item	2560690	et	3	main
eritsooni	doc_491521501967_item	2560691	et	4	main
ja	doc_491521501967_item	2560692	et	3	main
tahtsin	doc_491521501967_item	2560693	et	3	main
nemad	doc_491521501967_item	2560697	et	3	main
huvid	doc_491521501967_item	2560700	et	3	main
suurimaks	doc_491521501967_item	2560706	et	4	main
ma	doc_491521501967_item	2560708	et	3	main
loodan	doc_491521501967_item	2560709	et	3	main
ma	doc_491521501967_item	2560723	et	3	main
ei	doc_491521501967_item	2560726	et	4	main
petnud	doc_491521501967_item	2560734	et	4	main
on	doc_491521501967_item	2560743	et	4	main
pööraseim	doc_491521501967_item	2560747	et	4	main
tänapäeva	doc_491521501967_item	2560764	et	4	main
eestis	doc_491521501967_item	2560765	et	3	main
ainult	doc_491521501967_item	2560775	et	4	main
rikkad	doc_491521501967_item	2560776	et	4	main
mida	doc_491521501967_item	2560783	et	4	main
võimu	doc_491521501967_item	2560787	et	4	main
käes	doc_491521501967_item	2560789	et	4	main
seda	doc_491521501967_item	2560790	et	3	main
rohkem	doc_491521501967_item	2560791	et	4	main
tõsta	doc_491521501967_item	2560817	et	4	main
erialal	doc_491521501967_item	2560821	et	3	main
olla	doc_491521501967_item	2560829	et	3	main
perega	doc_491521501967_item	2560831	et	3	main
looduses	doc_491521501967_item	2560833	et	4	main
milline	doc_491521501967_item	2560834	et	3	main
on	doc_491521501967_item	2560835	et	4	main
vasknarva	doc_491521501967_item	2560843	et	4	main
jätku	doc_491521501967_item	2560847	et	4	main
aega	doc_491521501967_item	2560848	et	4	main
kuna	doc_491521501967_item	2560849	et	3	main
tahan	doc_491521501967_item	2560850	et	3	main
kohtuasjades	doc_491521501967_item	2560851	et	3	main
tegema	doc_491521501967_item	2560881	et	3	main
et	doc_491521501967_item	2560893	et	3	main
ma	doc_491521501966_item	2560523	et	3	main
mul	doc_491521501966_item	2560529	et	3	main
kombeks	doc_491521501966_item	2560530	et	4	main
ettevõtmisi	doc_491521501966_item	2560532	et	3	main
jätta	doc_491521501966_item	2560534	et	3	main
venemaal	doc_491521501966_item	2560548	et	4	main
kui	doc_491521501966_item	2560549	et	3	main
siiski	doc_491521501966_item	2560552	et	4	main
on	doc_491521501966_item	2560553	et	4	main
eestis	doc_491521501966_item	2560554	et	3	main
mul	doc_491521501966_item	2560555	et	3	main
kõige	doc_491521501966_item	2560556	et	4	main
parem	doc_491521501966_item	2560557	et	4	main
oma	doc_491521501966_item	2560559	et	4	main
isa	doc_491521501966_item	2560560	et	4	main
sündisid	doc_491521501966_item	2560563	et	4	main
ole	doc_491521501966_item	2560581	et	4	main
1kas	doc_491521501966_item	2560588	et	3	main
või	doc_491521501966_item	2560592	et	4	main
ma	doc_491521501966_item	2560594	et	3	main
mees	doc_491521501966_item	2560598	et	4	main
missugune	doc_491521501966_item	2560616	et	3	main
viia	doc_491521501966_item	2560624	et	3	main
ta	doc_491521501966_item	2560629	et	4	main
ta	doc_491521501966_item	2560646	et	4	main
olen	doc_491521501966_item	2560647	et	3	main
küljed	doc_491521501966_item	2560665	et	3	main
asjad	doc_491521501966_item	2560669	et	3	main
saada	doc_491521501967_item	2560678	et	4	main
saada	doc_491521501967_item	2560694	et	4	main
muutusid	doc_491521501967_item	2560701	et	4	main
ja	doc_491521501967_item	2560721	et	3	main
kuid	doc_491521501967_item	2560735	et	4	main
hoidun	doc_491521501967_item	2560736	et	3	main
olnud	doc_491521501967_item	2560744	et	4	main
ilmselt	doc_491521501967_item	2560749	et	4	main
ongi	doc_491521501967_item	2560750	et	4	main
praegune	doc_491521501967_item	2560753	et	3	main
nimel	doc_491521501967_item	2560756	et	3	main
raske	doc_491521501967_item	2560768	et	4	main
kuid	doc_491521501967_item	2560770	et	4	main
kindlasti	doc_491521501967_item	2560771	et	3	main
ei	doc_491521501967_item	2560772	et	4	main
juures	doc_491521501967_item	2560779	et	4	main
rohkem	doc_491521501967_item	2560784	et	4	main
mille	doc_491521501967_item	2560795	et	3	main
teil	doc_491521501967_item	2560798	et	4	main
kõige	doc_491521501967_item	2560799	et	4	main
rohkem	doc_491521501967_item	2560800	et	4	main
mida	doc_491521501967_item	2560804	et	4	main
tahan	doc_491521501967_item	2560808	et	3	main
saada	doc_491521501967_item	2560813	et	4	main
targemaks	doc_491521501967_item	2560814	et	4	main
eelkõige	doc_491521501967_item	2560815	et	3	main
tahaks	doc_491521501967_item	2560816	et	3	main
on	doc_491521501967_item	2560824	et	4	main
puhkus	doc_491521501967_item	2560828	et	3	main
kusagil	doc_491521501967_item	2560832	et	3	main
jaoks	doc_491521501967_item	2560845	et	4	main
võimalikult	doc_491521501967_item	2560853	et	4	main
aidata	doc_491521501967_item	2560855	et	4	main
siis	doc_491521501967_item	2560856	et	3	main
tundub	doc_491521501967_item	2560857	et	3	main
alati	doc_491521501967_item	2560858	et	4	main
et	doc_491521501967_item	2560859	et	3	main
oleks	doc_491521501967_item	2560860	et	3	main
olen	doc_491521501967_item	2560878	et	3	main
ka	doc_491521501967_item	2560882	et	3	main
millist	doc_491521501967_item	2560885	et	3	main
peate	doc_491521501967_item	2560887	et	4	main
oma	doc_491521501967_item	2560888	et	4	main
on	doc_491521501967_item	2560895	et	4	main
viia	doc_491521501967_item	2560897	et	3	main
asjad	doc_491521501967_item	2560898	et	3	main
kui	doc_491521501967_item	2560902	et	3	main
iga	doc_491521501967_item	2560907	et	4	main
kord	doc_491521501967_item	2560908	et	4	main
ei	doc_491521501967_item	2560916	et	4	main
intervjueeritar	doc_491521501966_item	2560589	et	4	main
arvan	doc_491521501966_item	2560595	et	3	main
ta	doc_491521501966_item	2560600	et	4	main
saada	doc_491521501966_item	2560602	et	4	main
ta	doc_491521501966_item	2560606	et	4	main
arvan	doc_491521501966_item	2560610	et	3	main
ta	doc_491521501966_item	2560617	et	4	main
iseloomult	doc_491521501966_item	2560620	et	3	main
lõpuni	doc_491521501966_item	2560626	et	3	main
võiks	doc_491521501966_item	2560638	et	4	main
kohtus	doc_491521501966_item	2560640	et	4	main
öötundidel	doc_491521501966_item	2560653	et	3	main
tema	doc_491521501966_item	2560657	et	4	main
küljed	doc_491521501966_item	2560659	et	3	main
arvan	doc_491521501966_item	2560661	et	3	main
tulgev	doc_491521501966_item	2560664	et	4	main
küsimust	doc_491521501967_item	2560672	et	4	main
nagu	doc_491521501967_item	2560696	et	3	main
hiljem	doc_491521501967_item	2560699	et	3	main
mida	doc_491521501967_item	2560702	et	4	main
peate	doc_491521501967_item	2560703	et	4	main
valetamine	doc_491521501967_item	2560722	et	4	main
küll	doc_491521501967_item	2560724	et	4	main
üldiselt	doc_491521501967_item	2560725	et	4	main
on	doc_491521501967_item	2560732	et	4	main
inimestega	doc_491521501967_item	2560739	et	3	main
kokku	doc_491521501967_item	2560740	et	3	main
puutumast	doc_491521501967_item	2560741	et	4	main
mis	doc_491521501967_item	2560742	et	4	main
minu	doc_491521501967_item	2560752	et	3	main
võitlus	doc_491521501967_item	2560754	et	3	main
et	doc_491521501967_item	2560757	et	3	main
elada	doc_491521501967_item	2560767	et	3	main
sest	doc_491521501967_item	2560782	et	4	main
raha	doc_491521501967_item	2560785	et	4	main
on	doc_491521501967_item	2560788	et	4	main
peale	doc_491521501967_item	2560796	et	4	main
peale	doc_491521501967_item	2560803	et	4	main
ma	doc_491521501967_item	2560807	et	3	main
väga	doc_491521501967_item	2560809	et	3	main
lugeda	doc_491521501967_item	2560811	et	3	main
taset	doc_491521501967_item	2560819	et	3	main
on	doc_491521501966_item	2560622	et	4	main
4	doc_491521501966_item	2560627	et	2	main
võiks	doc_491521501966_item	2560630	et	4	main
sinu	doc_491521501966_item	2560631	et	3	main
et	doc_491521501966_item	2560636	et	3	main
harjunud	doc_491521501966_item	2560648	et	4	main
on	doc_491521501966_item	2560656	et	4	main
tal	doc_491521501966_item	2560663	et	3	main
järjekindlus	doc_491521501966_item	2560667	et	4	main
kelleks	doc_491521501967_item	2560675	et	4	main
lapsepõlves	doc_491521501967_item	2560677	et	4	main
aga	doc_491521501967_item	2560698	et	3	main
elu	doc_491521501967_item	2560705	et	4	main
saavutuseks	doc_491521501967_item	2560707	et	4	main
et	doc_491521501967_item	2560710	et	3	main
selline	doc_491521501967_item	2560711	et	4	main
saavutus	doc_491521501967_item	2560712	et	4	main
ootab	doc_491521501967_item	2560713	et	3	main
mind	doc_491521501967_item	2560714	et	4	main
veel	doc_491521501967_item	2560715	et	4	main
ees	doc_491521501967_item	2560716	et	4	main
mis	doc_491521501967_item	2560717	et	4	main
teid	doc_491521501967_item	2560718	et	4	main
ärritab	doc_491521501967_item	2560719	et	3	main
reeturlus	doc_491521501967_item	2560720	et	4	main
ütle	doc_491521501967_item	2560727	et	4	main
inimestele	doc_491521501967_item	2560728	et	3	main
välja	doc_491521501967_item	2560729	et	4	main
mind	doc_491521501967_item	2560733	et	4	main
elu	doc_491521501967_item	2560746	et	4	main
on	doc_491521501967_item	2560763	et	4	main
ole	doc_491521501967_item	2560773	et	4	main
need	doc_491521501967_item	2560774	et	3	main
olevad	doc_491521501967_item	2560780	et	4	main
inimesed	doc_491521501967_item	2560781	et	3	main
on	doc_491521501967_item	2560792	et	4	main
ka	doc_491521501967_item	2560793	et	3	main
kulub	doc_491521501967_item	2560797	et	3	main
tahaksite	doc_491521501967_item	2560805	et	3	main
oma	doc_491521501967_item	2560818	et	4	main
õigusteaduses	doc_491521501967_item	2560822	et	3	main
jaoks	doc_491521501967_item	2560826	et	4	main
parim	doc_491521501967_item	2560827	et	4	main
ida-virumaal	doc_491521501967_item	2560838	et	4	main
peipsi-äärne	doc_491521501967_item	2560839	et	3	main
inimesi	doc_491521501967_item	2560852	et	4	main
harjunud	doc_491521501967_item	2560879	et	4	main
see	doc_491521501967_item	2560894	et	3	main
siis	doc_491521501967_item	2560901	et	3	main
tulemus	doc_491521501967_item	2560904	et	3	main
ole	doc_491521501967_item	2560906	et	4	main
kombeks	doc_491521501967_item	2560919	et	4	main
jätta	doc_491521501967_item	2560923	et	3	main
tahaksite	doc_491521501967_item	2560928	et	3	main
elada	doc_491521501967_item	2560929	et	3	main
elanud	doc_491521501967_item	2560932	et	4	main
teinud	doc_491521501967_item	2560934	et	4	main
tööd	doc_491521501967_item	2560935	et	4	main
nii	doc_491521501967_item	2560936	et	3	main
venemaal	doc_491521501967_item	2560937	et	4	main
kui	doc_491521501967_item	2560938	et	3	main
saksamaal	doc_491521501967_item	2560939	et	4	main
parem	doc_491521501967_item	2560946	et	4	main
järgin	doc_491521501967_item	2560947	et	3	main
peab	doc_491521501967_item	2560954	et	4	main
ka	doc_491521501967_item	2560955	et	3	main
elama	doc_491521501967_item	2560956	et	3	main
kas	doc_491521501967_item	2560957	et	3	main
loete	doc_491521501967_item	2560958	et	4	main
horoskoope	doc_491521501967_item	2560959	et	3	main
usu	doc_491521501967_item	2560963	et	4	main
huvitu	doc_491521501967_item	2560966	et	4	main
et	doc_491521501967_item	2560730	et	3	main
nad	doc_491521501967_item	2560731	et	3	main
edaspidi	doc_491521501967_item	2560737	et	3	main
selliste	doc_491521501967_item	2560738	et	4	main
teie	doc_491521501967_item	2560745	et	4	main
tegu	doc_491521501967_item	2560748	et	4	main
see	doc_491521501967_item	2560751	et	3	main
selle	doc_491521501967_item	2560755	et	4	main
kohlta-järve	doc_491521501967_item	2560758	et	4	main
õhk	doc_491521501967_item	2560759	et	3	main
puhtaks	doc_491521501967_item	2560760	et	3	main
saaks	doc_491521501967_item	2560761	et	3	main
kellel	doc_491521501967_item	2560762	et	4	main
hea	doc_491521501967_item	2560766	et	4	main
öelda	doc_491521501967_item	2560769	et	4	main
ja	doc_491521501967_item	2560777	et	3	main
võimu	doc_491521501967_item	2560778	et	4	main
ja	doc_491521501967_item	2560786	et	3	main
probleeme	doc_491521501967_item	2560794	et	3	main
raha	doc_491521501967_item	2560801	et	4	main
kommunaalkulude	doc_491521501967_item	2560802	et	3	main
osta	doc_491521501967_item	2560806	et	4	main
palju	doc_491521501967_item	2560810	et	4	main
et	doc_491521501967_item	2560812	et	3	main
valitud	doc_491521501967_item	2560820	et	4	main
mis	doc_491521501967_item	2560823	et	4	main
teie	doc_491521501967_item	2560836	et	4	main
lemmikkoht	doc_491521501967_item	2560837	et	3	main
mille	doc_491521501967_item	2560844	et	3	main
ei	doc_491521501967_item	2560846	et	4	main
hästi	doc_491521501967_item	2560854	et	3	main
tööd	doc_491521501967_item	2560880	et	4	main
tugevaimaks	doc_491521501967_item	2560889	et	4	main
küljeks	doc_491521501967_item	2560890	et	3	main
ma	doc_491521501967_item	2560891	et	3	main
arvan	doc_491521501967_item	2560892	et	3	main
isegi	doc_491521501967_item	2560900	et	4	main
ei	doc_491521501967_item	2560905	et	4	main
alguses	doc_491521501967_item	2560913	et	4	main
olin	doc_491521501967_item	2560914	et	3	main
lootnud	doc_491521501967_item	2560915	et	4	main
oma	doc_491521501967_item	2560920	et	4	main
eesti	doc_491521501967_item	2560927	et	4	main
kõige	doc_491521501967_item	2560945	et	4	main
sündisid	doc_491521501967_item	2560952	et	4	main
ei	doc_491521501967_item	2560969	et	4	main
on	doc_491521501967_item	2561005	et	4	main
väga	doc_491521501967_item	2561007	et	3	main
kuna	doc_491521501967_item	2561009	et	3	main
on	doc_491521501967_item	2561017	et	4	main
teie	doc_491521501967_item	2560825	et	4	main
koos	doc_491521501967_item	2560830	et	4	main
kant	doc_491521501967_item	2560840	et	3	main
alajõe	doc_491521501967_item	2560841	et	3	main
karjamaa	doc_491521501967_item	2560842	et	4	main
natukene	doc_491521501967_item	2560861	et	4	main
rohkem	doc_491521501967_item	2560862	et	4	main
siis	doc_491521501967_item	2560864	et	3	main
aega	doc_491521501967_item	2560863	et	4	main
jõuaks	doc_491521501967_item	2560865	et	3	main
veelgi	doc_491521501967_item	2560866	et	4	main
paremini	doc_491521501967_item	2560867	et	4	main
valmistuda	doc_491521501967_item	2560868	et	3	main
kuid	doc_491521501967_item	2560869	et	4	main
ma	doc_491521501967_item	2560870	et	3	main
olen	doc_491521501967_item	2560871	et	3	main
loomult	doc_491521501967_item	2560872	et	3	main
öökulli	doc_491521501967_item	2560873	et	4	main
tüüpi	doc_491521501967_item	2560874	et	4	main
inimene	doc_491521501967_item	2560875	et	3	main
ja	doc_491521501967_item	2560876	et	3	main
seetõttu	doc_491521501967_item	2560877	et	3	main
hilistel	doc_491521501967_item	2560883	et	3	main
öötundidel	doc_491521501967_item	2560884	et	3	main
omadust	doc_491521501967_item	2560886	et	4	main
lõpuni	doc_491521501967_item	2560899	et	3	main
see	doc_491521501967_item	2560903	et	3	main
see	doc_491521501967_item	2560910	et	3	main
ma	doc_491521501967_item	2560912	et	3	main
mul	doc_491521501967_item	2560918	et	3	main
pooleli	doc_491521501967_item	2560922	et	3	main
riigis	doc_491521501967_item	2560925	et	3	main
kuid	doc_491521501967_item	2560940	et	4	main
oma	doc_491521501967_item	2560948	et	4	main
isa	doc_491521501967_item	2560949	et	4	main
neid	doc_491521501967_item	2560964	et	4	main
ega	doc_491521501967_item	2560965	et	3	main
nendest	doc_491521501967_item	2560967	et	4	main
see	doc_491521501967_item	2560968	et	3	main
iseloomusta	doc_491521501967_item	2560973	et	4	main
inimest	doc_491521501967_item	2560974	et	3	main
kellest	doc_491521501967_item	2560975	et	4	main
kirjutatakse	doc_491521501967_item	2560976	et	3	main
ma	doc_491521501967_item	2560977	et	3	main
mees	doc_491521501967_item	2560982	et	4	main
tema	doc_491521501967_item	2560992	et	4	main
elab	doc_491521501967_item	2561002	et	3	main
ja	doc_491521501967_item	2561019	et	3	main
temaga	doc_491521501967_item	2561022	et	3	main
on	doc_491521501967_item	2561031	et	4	main
ka	doc_491521501967_item	2561036	et	3	main
ma	doc_491521501967_item	2561038	et	3	main
tal	doc_491521501967_item	2561046	et	3	main
väga	doc_491521501967_item	2561048	et	3	main
pooleli	doc_491521501967_item	2561065	et	3	main
jätta	doc_491521501967_item	2561066	et	3	main
küsimust	doc_491521501968_item	2561070	et	4	main
luurajaks	doc_491521501968_item	2561077	et	4	main
köitis	doc_491521501968_item	2561079	et	3	main
väga	doc_491521501968_item	2561081	et	3	main
tolleaegne	doc_491521501968_item	2561082	et	3	main
dessantväelasest	doc_491521501968_item	2561083	et	3	main
tehtud	doc_491521501968_item	2561084	et	4	main
film	doc_491521501968_item	2561085	et	3	main
sööst	doc_491521501968_item	2561086	et	3	main
nagu	doc_491521501968_item	2561092	et	3	main
elu	doc_491521501968_item	2561101	et	4	main
suurimaks	doc_491521501968_item	2561102	et	4	main
selline	doc_491521501968_item	2561107	et	4	main
veel	doc_491521501968_item	2561111	et	4	main
ees	doc_491521501968_item	2561112	et	4	main
mis	doc_491521501968_item	2561113	et	4	main
valetamine	doc_491521501968_item	2561118	et	4	main
inimestele	doc_491521501968_item	2561124	et	3	main
nad	doc_491521501968_item	2561127	et	3	main
ongi	doc_491521501968_item	2561146	et	4	main
see	doc_491521501968_item	2561147	et	3	main
minu	doc_491521501968_item	2561148	et	3	main
praegune	doc_491521501968_item	2561149	et	3	main
võitlus	doc_491521501968_item	2561150	et	3	main
rikkad	doc_491521501968_item	2561172	et	4	main
ja	doc_491521501968_item	2561173	et	3	main
mida	doc_491521501968_item	2561179	et	4	main
kõige	doc_491521501968_item	2561195	et	4	main
raha	doc_491521501968_item	2561197	et	4	main
mida	doc_491521501968_item	2561200	et	4	main
eelkõige	doc_491521501968_item	2561211	et	3	main
oma	doc_491521501968_item	2561214	et	4	main
parim	doc_491521501968_item	2561223	et	4	main
aega	doc_491521501968_item	2561244	et	4	main
kuna	doc_491521501968_item	2561245	et	3	main
inimesi	doc_491521501968_item	2561248	et	4	main
võimalikult	doc_491521501968_item	2561249	et	4	main
aega	doc_491521501968_item	2561259	et	4	main
on	doc_491521501968_item	2561291	et	4	main
asjad	doc_491521501968_item	2561294	et	3	main
ole	doc_491521501968_item	2561313	et	4	main
kombeks	doc_491521501968_item	2561315	et	4	main
millises	doc_491521501968_item	2561320	et	3	main
tööd	doc_491521501968_item	2561331	et	4	main
on	doc_491521501968_item	2561338	et	4	main
eestis	doc_491521501968_item	2561339	et	3	main
mul	doc_491521501968_item	2561340	et	3	main
öeldut	doc_491521501968_item	2561346	et	4	main
järjekindlus	doc_491521501967_item	2560896	et	4	main
päris	doc_491521501967_item	2560909	et	4	main
mida	doc_491521501967_item	2560911	et	4	main
ole	doc_491521501967_item	2560917	et	4	main
ettevõtmisi	doc_491521501967_item	2560921	et	3	main
peale	doc_491521501967_item	2560926	et	4	main
ma	doc_491521501967_item	2560930	et	3	main
siiski	doc_491521501967_item	2560941	et	4	main
seal	doc_491521501967_item	2560953	et	4	main
ei	doc_491521501967_item	2560962	et	4	main
tõsine	doc_491521501967_item	2560971	et	4	main
asi	doc_491521501967_item	2560972	et	4	main
on	doc_491521501967_item	2560981	et	4	main
sellepärast	doc_491521501967_item	2560983	et	3	main
elukutselt	doc_491521501967_item	2560993	et	4	main
on	doc_491521501967_item	2560994	et	4	main
jurist	doc_491521501967_item	2560995	et	3	main
tavaline	doc_491521501967_item	2560998	et	4	main
ja	doc_491521501967_item	2561001	et	3	main
iseloomulik	doc_491521501967_item	2561006	et	3	main
ta	doc_491521501967_item	2561010	et	4	main
ei	doc_491521501967_item	2561011	et	4	main
armastas	doc_491521501967_item	2561012	et	3	main
targ	doc_491521501967_item	2561018	et	4	main
mees	doc_491521501967_item	2561021	et	4	main
olen	doc_491521501967_item	2561024	et	3	main
rohkem	doc_491521501967_item	2561027	et	4	main
raha	doc_491521501967_item	2561028	et	4	main
ja	doc_491521501967_item	2561029	et	3	main
on	doc_491521501967_item	2561035	et	4	main
ta	doc_491521501967_item	2561040	et	4	main
kohkus	doc_491521501967_item	2561043	et	3	main
silmaring	doc_491521501967_item	2561050	et	3	main
ettevõtmisi	doc_491521501967_item	2561064	et	3	main
küsimust	doc_491521501968_item	2561068	et	4	main
ja	doc_491521501968_item	2561088	et	3	main
tahtsin	doc_491521501968_item	2561089	et	3	main
aga	doc_491521501968_item	2561094	et	3	main
saavutus	doc_491521501968_item	2561108	et	4	main
ja	doc_491521501968_item	2561117	et	3	main
üldiselt	doc_491521501968_item	2561121	et	4	main
ütle	doc_491521501968_item	2561123	et	4	main
selliste	doc_491521501968_item	2561134	et	4	main
inimestega	doc_491521501968_item	2561135	et	3	main
kokku	doc_491521501968_item	2561136	et	3	main
puutumast	doc_491521501968_item	2561137	et	4	main
mis	doc_491521501968_item	2561138	et	4	main
pööraseim	doc_491521501968_item	2561143	et	4	main
selle	doc_491521501968_item	2561151	et	4	main
nimel	doc_491521501968_item	2561152	et	3	main
et	doc_491521501968_item	2561153	et	3	main
kohlta-järve	doc_491521501968_item	2561154	et	4	main
võimu	doc_491521501968_item	2561174	et	4	main
juures	doc_491521501968_item	2561175	et	4	main
võimu	doc_491521501968_item	2561183	et	4	main
käes	doc_491521501968_item	2561185	et	4	main
teil	doc_491521501968_item	2561194	et	4	main
kommunaalkulude	doc_491521501968_item	2561198	et	3	main
peale	doc_491521501968_item	2561199	et	4	main
tahaksite	doc_491521501968_item	2561201	et	3	main
osta	doc_491521501968_item	2561202	et	4	main
palju	doc_491521501968_item	2561206	et	4	main
et	doc_491521501968_item	2561208	et	3	main
targemaks	doc_491521501968_item	2561210	et	4	main
olla	doc_491521501968_item	2561225	et	3	main
kusagil	doc_491521501968_item	2561228	et	3	main
on	doc_491521501968_item	2561231	et	4	main
ida-virumaal	doc_491521501968_item	2561234	et	4	main
peipsi-äärne	doc_491521501968_item	2561235	et	3	main
kant	doc_491521501968_item	2561236	et	3	main
alajõe	doc_491521501968_item	2561237	et	3	main
jätku	doc_491521501968_item	2561243	et	4	main
alati	doc_491521501968_item	2561254	et	4	main
et	doc_491521501968_item	2561255	et	3	main
oleks	doc_491521501968_item	2561256	et	3	main
isegi	doc_491521501968_item	2561296	et	4	main
kui	doc_491521501968_item	2561298	et	3	main
ole	doc_491521501968_item	2561302	et	4	main
kord	doc_491521501968_item	2561304	et	4	main
lootnud	doc_491521501968_item	2561311	et	4	main
oma	doc_491521501968_item	2561316	et	4	main
ettevõtmisi	doc_491521501968_item	2561317	et	3	main
millises	doc_491521501967_item	2560924	et	3	main
olen	doc_491521501967_item	2560931	et	3	main
ja	doc_491521501967_item	2560933	et	3	main
on	doc_491521501967_item	2560942	et	4	main
eestis	doc_491521501967_item	2560943	et	3	main
mul	doc_491521501967_item	2560944	et	3	main
öeldut	doc_491521501967_item	2560950	et	4	main
kus	doc_491521501967_item	2560951	et	3	main
ei	doc_491521501967_item	2560960	et	4	main
ma	doc_491521501967_item	2560961	et	3	main
luurajaks	doc_491521501967_item	2560987	et	4	main
aga	doc_491521501967_item	2560988	et	3	main
hiljem	doc_491521501967_item	2560989	et	3	main
huvid	doc_491521501967_item	2560990	et	3	main
muutusid	doc_491521501967_item	2560991	et	4	main
mees	doc_491521501967_item	2560996	et	4	main
eesti	doc_491521501967_item	2560999	et	4	main
kodanik	doc_491521501967_item	2561000	et	3	main
sul	doc_491521501967_item	2561004	et	3	main
hea	doc_491521501967_item	2561008	et	4	main
ta	doc_491521501967_item	2561016	et	4	main
tähelepanelik	doc_491521501967_item	2561020	et	4	main
ma	doc_491521501967_item	2561023	et	3	main
nõus	doc_491521501967_item	2561025	et	4	main
et	doc_491521501967_item	2561026	et	3	main
käes	doc_491521501967_item	2561032	et	4	main
arvan	doc_491521501967_item	2561039	et	3	main
või	doc_491521501967_item	2561044	et	4	main
lai	doc_491521501967_item	2561049	et	3	main
kombeks	doc_491521501967_item	2561062	et	4	main
13	doc_491521501968_item	2561067	et	2	main
13	doc_491521501968_item	2561069	et	2	main
kelleks	doc_491521501968_item	2561071	et	4	main
tahtsite	doc_491521501968_item	2561072	et	3	main
saada	doc_491521501968_item	2561076	et	4	main
mind	doc_491521501968_item	2561078	et	4	main
ka	doc_491521501968_item	2561080	et	3	main
samasuguseks	doc_491521501968_item	2561091	et	4	main
hiljem	doc_491521501968_item	2561095	et	3	main
mida	doc_491521501968_item	2561098	et	4	main
oma	doc_491521501968_item	2561100	et	4	main
et	doc_491521501968_item	2561106	et	3	main
teid	doc_491521501968_item	2561114	et	4	main
ma	doc_491521501968_item	2561119	et	3	main
ei	doc_491521501968_item	2561122	et	4	main
ole	doc_491521501967_item	2560970	et	4	main
arvan	doc_491521501967_item	2560978	et	3	main
et	doc_491521501967_item	2560979	et	3	main
intervjueeritar	doc_491521501967_item	2560980	et	4	main
ta	doc_491521501967_item	2560984	et	4	main
unistasin	doc_491521501967_item	2560985	et	3	main
saada	doc_491521501967_item	2560986	et	4	main
on	doc_491521501967_item	2560997	et	4	main
kohlta-järvel	doc_491521501967_item	2561003	et	4	main
reeturlus	doc_491521501967_item	2561013	et	4	main
ja	doc_491521501967_item	2561014	et	3	main
valetamine	doc_491521501967_item	2561015	et	4	main
võimu	doc_491521501967_item	2561030	et	4	main
rohkem	doc_491521501967_item	2561034	et	4	main
probleeme	doc_491521501967_item	2561037	et	3	main
võiks	doc_491521501967_item	2561041	et	4	main
linnavalitsuses	doc_491521501967_item	2561045	et	4	main
oma	doc_491521501967_item	2561063	et	4	main
saada	doc_491521501968_item	2561074	et	4	main
eritsooni	doc_491521501968_item	2561087	et	4	main
nemad	doc_491521501968_item	2561093	et	3	main
huvid	doc_491521501968_item	2561096	et	3	main
kuid	doc_491521501968_item	2561131	et	4	main
hoidun	doc_491521501968_item	2561132	et	3	main
edaspidi	doc_491521501968_item	2561133	et	3	main
olnud	doc_491521501968_item	2561140	et	4	main
ilmselt	doc_491521501968_item	2561145	et	4	main
olevad	doc_491521501968_item	2561176	et	4	main
inimesed	doc_491521501968_item	2561177	et	3	main
raha	doc_491521501968_item	2561181	et	4	main
tahan	doc_491521501968_item	2561204	et	3	main
tahaks	doc_491521501968_item	2561212	et	3	main
valitud	doc_491521501968_item	2561216	et	4	main
erialal	doc_491521501968_item	2561217	et	3	main
õigusteaduses	doc_491521501968_item	2561218	et	3	main
on	doc_491521501968_item	2561220	et	4	main
seda	doc_491521501967_item	2561033	et	3	main
töötada	doc_491521501967_item	2561042	et	3	main
on	doc_491521501967_item	2561047	et	4	main
ja	doc_491521501967_item	2561051	et	3	main
armastab	doc_491521501967_item	2561052	et	3	main
puhkuda	doc_491521501967_item	2561053	et	4	main
ta	doc_491521501967_item	2561054	et	4	main
elistab	doc_491521501967_item	2561055	et	4	main
töötada	doc_491521501967_item	2561056	et	3	main
hilistel	doc_491521501967_item	2561057	et	3	main
öötundidel	doc_491521501967_item	2561058	et	3	main
temal	doc_491521501967_item	2561059	et	3	main
ei	doc_491521501967_item	2561060	et	4	main
ole	doc_491521501967_item	2561061	et	4	main
lapsepõlves	doc_491521501968_item	2561073	et	4	main
unistasin	doc_491521501968_item	2561075	et	3	main
saada	doc_491521501968_item	2561090	et	4	main
muutusid	doc_491521501968_item	2561097	et	4	main
peate	doc_491521501968_item	2561099	et	4	main
saavutuseks	doc_491521501968_item	2561103	et	4	main
ma	doc_491521501968_item	2561104	et	3	main
loodan	doc_491521501968_item	2561105	et	3	main
ootab	doc_491521501968_item	2561109	et	3	main
mind	doc_491521501968_item	2561110	et	4	main
ärritab	doc_491521501968_item	2561115	et	3	main
reeturlus	doc_491521501968_item	2561116	et	4	main
küll	doc_491521501968_item	2561120	et	4	main
et	doc_491521501968_item	2561126	et	3	main
on	doc_491521501968_item	2561128	et	4	main
mind	doc_491521501968_item	2561129	et	4	main
teie	doc_491521501968_item	2561141	et	4	main
elu	doc_491521501968_item	2561142	et	4	main
rohkem	doc_491521501968_item	2561180	et	4	main
on	doc_491521501968_item	2561184	et	4	main
seda	doc_491521501968_item	2561186	et	3	main
rohkem	doc_491521501968_item	2561196	et	4	main
ma	doc_491521501968_item	2561203	et	3	main
lugeda	doc_491521501968_item	2561207	et	3	main
mis	doc_491521501968_item	2561219	et	4	main
teie	doc_491521501968_item	2561221	et	4	main
koos	doc_491521501968_item	2561226	et	4	main
karjamaa	doc_491521501968_item	2561238	et	4	main
vasknarva	doc_491521501968_item	2561239	et	4	main
mille	doc_491521501968_item	2561240	et	3	main
tahan	doc_491521501968_item	2561246	et	3	main
siis	doc_491521501968_item	2561260	et	3	main
veelgi	doc_491521501968_item	2561262	et	4	main
kuid	doc_491521501968_item	2561265	et	4	main
viia	doc_491521501968_item	2561293	et	3	main
tulemus	doc_491521501968_item	2561300	et	3	main
ma	doc_491521501968_item	2561308	et	3	main
mul	doc_491521501968_item	2561314	et	3	main
pooleli	doc_491521501968_item	2561318	et	3	main
eesti	doc_491521501968_item	2561323	et	4	main
elada	doc_491521501968_item	2561325	et	3	main
olen	doc_491521501968_item	2561327	et	3	main
elanud	doc_491521501968_item	2561328	et	4	main
ja	doc_491521501968_item	2561329	et	3	main
teinud	doc_491521501968_item	2561330	et	4	main
siiski	doc_491521501968_item	2561337	et	4	main
isa	doc_491521501968_item	2561345	et	4	main
elama	doc_491521501968_item	2561352	et	3	main
ei	doc_491521501968_item	2561358	et	4	main
ega	doc_491521501968_item	2561361	et	3	main
huvitu	doc_491521501968_item	2561362	et	4	main
tõsine	doc_491521501968_item	2561367	et	4	main
asi	doc_491521501968_item	2561368	et	4	main
inetrjueeritav	doc_491521501968_item	2561372	et	4	main
2	doc_491521501968_item	2561375	et	2	main
eesti	doc_491521501968_item	2561382	et	4	main
on	doc_491521501968_item	2561391	et	4	main
4	doc_491521501968_item	2561396	et	2	main
ta	doc_491521501968_item	2561399	et	4	main
välja	doc_491521501968_item	2561125	et	4	main
petnud	doc_491521501968_item	2561130	et	4	main
on	doc_491521501968_item	2561139	et	4	main
tegu	doc_491521501968_item	2561144	et	4	main
õhk	doc_491521501968_item	2561155	et	3	main
puhtaks	doc_491521501968_item	2561156	et	3	main
saaks	doc_491521501968_item	2561157	et	3	main
kellel	doc_491521501968_item	2561158	et	4	main
on	doc_491521501968_item	2561159	et	4	main
tänapäeva	doc_491521501968_item	2561160	et	4	main
eestis	doc_491521501968_item	2561161	et	3	main
hea	doc_491521501968_item	2561162	et	4	main
elada	doc_491521501968_item	2561163	et	3	main
raske	doc_491521501968_item	2561164	et	4	main
öelda	doc_491521501968_item	2561165	et	4	main
kuid	doc_491521501968_item	2561166	et	4	main
kindlasti	doc_491521501968_item	2561167	et	3	main
ei	doc_491521501968_item	2561168	et	4	main
ole	doc_491521501968_item	2561169	et	4	main
need	doc_491521501968_item	2561170	et	3	main
ainult	doc_491521501968_item	2561171	et	4	main
sest	doc_491521501968_item	2561178	et	4	main
ja	doc_491521501968_item	2561182	et	3	main
rohkem	doc_491521501968_item	2561187	et	4	main
on	doc_491521501968_item	2561188	et	4	main
ka	doc_491521501968_item	2561189	et	3	main
probleeme	doc_491521501968_item	2561190	et	3	main
mille	doc_491521501968_item	2561191	et	3	main
peale	doc_491521501968_item	2561192	et	4	main
kulub	doc_491521501968_item	2561193	et	3	main
väga	doc_491521501968_item	2561205	et	3	main
saada	doc_491521501968_item	2561209	et	4	main
tõsta	doc_491521501968_item	2561213	et	4	main
taset	doc_491521501968_item	2561215	et	3	main
jaoks	doc_491521501968_item	2561222	et	4	main
perega	doc_491521501968_item	2561227	et	3	main
looduses	doc_491521501968_item	2561229	et	4	main
teie	doc_491521501968_item	2561232	et	4	main
lemmikkoht	doc_491521501968_item	2561233	et	3	main
ei	doc_491521501968_item	2561242	et	4	main
hästi	doc_491521501968_item	2561250	et	3	main
aidata	doc_491521501968_item	2561251	et	4	main
siis	doc_491521501968_item	2561252	et	3	main
tundub	doc_491521501968_item	2561253	et	3	main
rohkem	doc_491521501968_item	2561258	et	4	main
jõuaks	doc_491521501968_item	2561261	et	3	main
paremini	doc_491521501968_item	2561263	et	4	main
valmistuda	doc_491521501968_item	2561264	et	3	main
järjekindlus	doc_491521501968_item	2561292	et	4	main
lõpuni	doc_491521501968_item	2561295	et	3	main
siis	doc_491521501968_item	2561297	et	3	main
päris	doc_491521501968_item	2561305	et	4	main
see	doc_491521501968_item	2561306	et	3	main
mida	doc_491521501968_item	2561307	et	4	main
alguses	doc_491521501968_item	2561309	et	4	main
olin	doc_491521501968_item	2561310	et	3	main
nii	doc_491521501968_item	2561332	et	3	main
venemaal	doc_491521501968_item	2561333	et	4	main
kui	doc_491521501968_item	2561334	et	3	main
kõige	doc_491521501968_item	2561341	et	4	main
parem	doc_491521501968_item	2561342	et	4	main
järgin	doc_491521501968_item	2561343	et	3	main
oma	doc_491521501968_item	2561344	et	4	main
peab	doc_491521501968_item	2561350	et	4	main
ka	doc_491521501968_item	2561351	et	3	main
ei	doc_491521501968_item	2561356	et	4	main
1	doc_491521501968_item	2561369	et	2	main
mees	doc_491521501968_item	2561374	et	4	main
tema	doc_491521501968_item	2561384	et	4	main
eriala	doc_491521501968_item	2561385	et	4	main
on	doc_491521501968_item	2561386	et	4	main
juurist	doc_491521501968_item	2561387	et	3	main
soovlik	doc_491521501968_item	2561394	et	3	main
järjekindlus	doc_491521501968_item	2561421	et	4	main
lapsepõlves	doc_491521501969_item	2561431	et	4	main
köitis	doc_491521501969_item	2561437	et	3	main
hiljem	doc_491521501969_item	2561453	et	3	main
mida	doc_491521501969_item	2561456	et	4	main
veel	doc_491521501969_item	2561469	et	4	main
teid	doc_491521501969_item	2561472	et	4	main
ei	doc_491521501969_item	2561480	et	4	main
on	doc_491521501969_item	2561486	et	4	main
mind	doc_491521501969_item	2561487	et	4	main
selliste	doc_491521501969_item	2561492	et	4	main
olnud	doc_491521501969_item	2561498	et	4	main
pööraseim	doc_491521501969_item	2561501	et	4	main
võitlus	doc_491521501969_item	2561508	et	3	main
õhk	doc_491521501969_item	2561513	et	3	main
tänapäeva	doc_491521501969_item	2561518	et	4	main
kuid	doc_491521501969_item	2561524	et	4	main
olevad	doc_491521501969_item	2561534	et	4	main
võimu	doc_491521501969_item	2561541	et	4	main
on	doc_491521501969_item	2561542	et	4	main
mille	doc_491521501969_item	2561549	et	3	main
rohkem	doc_491521501969_item	2561554	et	4	main
kommunaalkulude	doc_491521501969_item	2561556	et	3	main
peale	doc_491521501969_item	2561557	et	4	main
jaoks	doc_491521501969_item	2561580	et	4	main
looduses	doc_491521501969_item	2561587	et	4	main
on	doc_491521501969_item	2561589	et	4	main
lemmikkoht	doc_491521501969_item	2561591	et	3	main
jätku	doc_491521501969_item	2561601	et	4	main
võimalikult	doc_491521501969_item	2561607	et	4	main
puhkus	doc_491521501968_item	2561224	et	3	main
milline	doc_491521501968_item	2561230	et	3	main
jaoks	doc_491521501968_item	2561241	et	4	main
kohtuasjades	doc_491521501968_item	2561247	et	3	main
natukene	doc_491521501968_item	2561257	et	4	main
ma	doc_491521501968_item	2561266	et	3	main
olen	doc_491521501968_item	2561267	et	3	main
loomult	doc_491521501968_item	2561268	et	3	main
öökulli	doc_491521501968_item	2561269	et	4	main
tüüpi	doc_491521501968_item	2561270	et	4	main
inimene	doc_491521501968_item	2561271	et	3	main
ja	doc_491521501968_item	2561272	et	3	main
seetõttu	doc_491521501968_item	2561273	et	3	main
olen	doc_491521501968_item	2561274	et	3	main
harjunud	doc_491521501968_item	2561275	et	4	main
tööd	doc_491521501968_item	2561276	et	4	main
tegema	doc_491521501968_item	2561277	et	3	main
ka	doc_491521501968_item	2561278	et	3	main
hilistel	doc_491521501968_item	2561279	et	3	main
öötundidel	doc_491521501968_item	2561280	et	3	main
millist	doc_491521501968_item	2561281	et	3	main
omadust	doc_491521501968_item	2561282	et	4	main
oma	doc_491521501968_item	2561284	et	4	main
peate	doc_491521501968_item	2561283	et	4	main
tugevaimaks	doc_491521501968_item	2561285	et	4	main
küljeks	doc_491521501968_item	2561286	et	3	main
ma	doc_491521501968_item	2561287	et	3	main
arvan	doc_491521501968_item	2561288	et	3	main
et	doc_491521501968_item	2561289	et	3	main
see	doc_491521501968_item	2561290	et	3	main
see	doc_491521501968_item	2561299	et	3	main
ei	doc_491521501968_item	2561301	et	4	main
iga	doc_491521501968_item	2561303	et	4	main
ei	doc_491521501968_item	2561312	et	4	main
riigis	doc_491521501968_item	2561321	et	3	main
tahaksite	doc_491521501968_item	2561324	et	3	main
ma	doc_491521501968_item	2561326	et	3	main
saksamaal	doc_491521501968_item	2561335	et	4	main
kas	doc_491521501968_item	2561353	et	3	main
ma	doc_491521501968_item	2561357	et	3	main
usu	doc_491521501968_item	2561359	et	4	main
ei	doc_491521501968_item	2561365	et	4	main
ole	doc_491521501968_item	2561366	et	4	main
on	doc_491521501968_item	2561373	et	4	main
küsimustele	doc_491521501968_item	2561379	et	4	main
hea	doc_491521501968_item	2561393	et	4	main
asjad	doc_491521501968_item	2561423	et	3	main
küsimust	doc_491521501969_item	2561426	et	4	main
13	doc_491521501969_item	2561427	et	2	main
küsimust	doc_491521501969_item	2561428	et	4	main
kelleks	doc_491521501969_item	2561429	et	4	main
tahtsite	doc_491521501969_item	2561430	et	3	main
ka	doc_491521501969_item	2561438	et	3	main
sööst	doc_491521501969_item	2561444	et	3	main
elu	doc_491521501969_item	2561459	et	4	main
selline	doc_491521501969_item	2561465	et	4	main
mis	doc_491521501969_item	2561471	et	4	main
ma	doc_491521501969_item	2561477	et	3	main
inimestele	doc_491521501969_item	2561482	et	3	main
et	doc_491521501969_item	2561484	et	3	main
kuid	doc_491521501969_item	2561489	et	4	main
kokku	doc_491521501969_item	2561494	et	3	main
elu	doc_491521501969_item	2561500	et	4	main
tegu	doc_491521501969_item	2561502	et	4	main
ilmselt	doc_491521501969_item	2561503	et	4	main
et	doc_491521501969_item	2561511	et	3	main
puhtaks	doc_491521501969_item	2561514	et	3	main
eestis	doc_491521501969_item	2561519	et	3	main
öelda	doc_491521501969_item	2561523	et	4	main
juures	doc_491521501969_item	2561533	et	4	main
rohkem	doc_491521501969_item	2561545	et	4	main
kulub	doc_491521501969_item	2561551	et	3	main
kõige	doc_491521501969_item	2561553	et	4	main
raha	doc_491521501969_item	2561555	et	4	main
tahaks	doc_491521501969_item	2561570	et	3	main
oma	doc_491521501969_item	2561572	et	4	main
valitud	doc_491521501969_item	2561574	et	4	main
erialal	doc_491521501969_item	2561575	et	3	main
koos	doc_491521501969_item	2561584	et	4	main
perega	doc_491521501969_item	2561585	et	3	main
alajõe	doc_491521501969_item	2561595	et	3	main
vasknarva	doc_491521501969_item	2561597	et	4	main
kuna	doc_491521501969_item	2561603	et	3	main
inimesi	doc_491521501969_item	2561606	et	4	main
ja	doc_491521501969_item	2561630	et	3	main
harjunud	doc_491521501969_item	2561633	et	4	main
tööd	doc_491521501969_item	2561634	et	4	main
tegema	doc_491521501969_item	2561635	et	3	main
ka	doc_491521501969_item	2561636	et	3	main
öötundidel	doc_491521501969_item	2561638	et	3	main
oma	doc_491521501969_item	2561642	et	4	main
tugevaimaks	doc_491521501969_item	2561643	et	4	main
küljeks	doc_491521501969_item	2561644	et	3	main
ma	doc_491521501969_item	2561645	et	3	main
arvan	doc_491521501969_item	2561646	et	3	main
et	doc_491521501969_item	2561647	et	3	main
see	doc_491521501969_item	2561648	et	3	main
tulemus	doc_491521501969_item	2561658	et	3	main
mida	doc_491521501969_item	2561665	et	4	main
oma	doc_491521501969_item	2561702	et	4	main
peab	doc_491521501969_item	2561708	et	4	main
ka	doc_491521501969_item	2561709	et	3	main
elama	doc_491521501969_item	2561710	et	3	main
kas	doc_491521501969_item	2561711	et	3	main
nendest	doc_491521501969_item	2561721	et	4	main
ei	doc_491521501969_item	2561723	et	4	main
mees	doc_491521501969_item	2561733	et	4	main
2	doc_491521501969_item	2561742	et	2	main
ei	doc_491521501969_item	2561762	et	4	main
ja	doc_491521501969_item	2561765	et	3	main
jätta	doc_491521501968_item	2561319	et	3	main
peale	doc_491521501968_item	2561322	et	4	main
kuid	doc_491521501968_item	2561336	et	4	main
seal	doc_491521501968_item	2561349	et	4	main
loete	doc_491521501968_item	2561354	et	4	main
nendest	doc_491521501968_item	2561363	et	4	main
see	doc_491521501968_item	2561364	et	3	main
minu	doc_491521501968_item	2561370	et	3	main
kes	doc_491521501968_item	2561377	et	4	main
kodanik	doc_491521501968_item	2561383	et	3	main
töökas	doc_491521501968_item	2561392	et	4	main
jutukas	doc_491521501968_item	2561395	et	4	main
arvates	doc_491521501968_item	2561398	et	4	main
võiks	doc_491521501968_item	2561400	et	4	main
töötada	doc_491521501968_item	2561401	et	3	main
kohtus	doc_491521501968_item	2561402	et	4	main
5	doc_491521501968_item	2561403	et	2	main
tema	doc_491521501968_item	2561404	et	4	main
tööharjumused	doc_491521501968_item	2561405	et	3	main
on	doc_491521501968_item	2561406	et	4	main
selline	doc_491521501968_item	2561407	et	4	main
et	doc_491521501968_item	2561408	et	3	main
ta	doc_491521501968_item	2561409	et	4	main
on	doc_491521501968_item	2561410	et	4	main
harjunud	doc_491521501968_item	2561411	et	4	main
tööd	doc_491521501968_item	2561412	et	4	main
tegema	doc_491521501968_item	2561413	et	3	main
hilistel	doc_491521501968_item	2561414	et	3	main
öötundidel	doc_491521501968_item	2561415	et	3	main
6	doc_491521501968_item	2561416	et	2	main
tema	doc_491521501968_item	2561417	et	4	main
rugevad	doc_491521501968_item	2561418	et	4	main
küljed	doc_491521501968_item	2561419	et	3	main
on	doc_491521501968_item	2561420	et	4	main
viia	doc_491521501968_item	2561422	et	3	main
13	doc_491521501969_item	2561425	et	2	main
saada	doc_491521501969_item	2561432	et	4	main
mind	doc_491521501969_item	2561436	et	4	main
tolleaegne	doc_491521501969_item	2561440	et	3	main
samasuguseks	doc_491521501969_item	2561449	et	4	main
nagu	doc_491521501969_item	2561450	et	3	main
nemad	doc_491521501969_item	2561451	et	3	main
aga	doc_491521501969_item	2561452	et	3	main
suurimaks	doc_491521501969_item	2561460	et	4	main
loodan	doc_491521501969_item	2561463	et	3	main
ees	doc_491521501969_item	2561470	et	4	main
reeturlus	doc_491521501969_item	2561474	et	4	main
ütle	doc_491521501969_item	2561481	et	4	main
välja	doc_491521501969_item	2561483	et	4	main
nad	doc_491521501969_item	2561485	et	3	main
ongi	doc_491521501969_item	2561504	et	4	main
see	doc_491521501969_item	2561505	et	3	main
minu	doc_491521501969_item	2561506	et	3	main
nimel	doc_491521501969_item	2561510	et	3	main
saaks	doc_491521501969_item	2561515	et	3	main
on	doc_491521501969_item	2561517	et	4	main
kus	doc_491521501968_item	2561347	et	3	main
sündisid	doc_491521501968_item	2561348	et	4	main
horoskoope	doc_491521501968_item	2561355	et	3	main
neid	doc_491521501968_item	2561360	et	4	main
arvates	doc_491521501968_item	2561371	et	4	main
mees	doc_491521501968_item	2561376	et	4	main
vastas	doc_491521501968_item	2561378	et	4	main
on	doc_491521501968_item	2561380	et	4	main
lihtsalt	doc_491521501968_item	2561381	et	4	main
3	doc_491521501968_item	2561388	et	2	main
tema	doc_491521501968_item	2561389	et	4	main
iseloom	doc_491521501968_item	2561390	et	3	main
minu	doc_491521501968_item	2561397	et	3	main
lõpuni	doc_491521501968_item	2561424	et	3	main
saada	doc_491521501969_item	2561434	et	4	main
väga	doc_491521501969_item	2561439	et	3	main
dessantväelasest	doc_491521501969_item	2561441	et	3	main
huvid	doc_491521501969_item	2561454	et	3	main
peate	doc_491521501969_item	2561457	et	4	main
oma	doc_491521501969_item	2561458	et	4	main
ma	doc_491521501969_item	2561462	et	3	main
saavutus	doc_491521501969_item	2561466	et	4	main
ootab	doc_491521501969_item	2561467	et	3	main
mind	doc_491521501969_item	2561468	et	4	main
ja	doc_491521501969_item	2561475	et	3	main
valetamine	doc_491521501969_item	2561476	et	4	main
küll	doc_491521501969_item	2561478	et	4	main
üldiselt	doc_491521501969_item	2561479	et	4	main
hoidun	doc_491521501969_item	2561490	et	3	main
edaspidi	doc_491521501969_item	2561491	et	3	main
inimestega	doc_491521501969_item	2561493	et	3	main
puutumast	doc_491521501969_item	2561495	et	4	main
mis	doc_491521501969_item	2561496	et	4	main
on	doc_491521501969_item	2561497	et	4	main
selle	doc_491521501969_item	2561509	et	4	main
kellel	doc_491521501969_item	2561516	et	4	main
hea	doc_491521501969_item	2561520	et	4	main
elada	doc_491521501969_item	2561521	et	3	main
võimu	doc_491521501969_item	2561532	et	4	main
rohkem	doc_491521501969_item	2561538	et	4	main
raha	doc_491521501969_item	2561539	et	4	main
ja	doc_491521501969_item	2561540	et	3	main
teil	doc_491521501969_item	2561552	et	4	main
väga	doc_491521501969_item	2561563	et	3	main
palju	doc_491521501969_item	2561564	et	4	main
lugeda	doc_491521501969_item	2561565	et	3	main
et	doc_491521501969_item	2561566	et	3	main
saada	doc_491521501969_item	2561567	et	4	main
tõsta	doc_491521501969_item	2561571	et	4	main
taset	doc_491521501969_item	2561573	et	3	main
mis	doc_491521501969_item	2561577	et	4	main
on	doc_491521501969_item	2561578	et	4	main
olla	doc_491521501969_item	2561583	et	3	main
kusagil	doc_491521501969_item	2561586	et	3	main
teie	doc_491521501969_item	2561590	et	4	main
jaoks	doc_491521501969_item	2561599	et	4	main
kohtuasjades	doc_491521501969_item	2561605	et	3	main
aidata	doc_491521501969_item	2561609	et	4	main
tundub	doc_491521501969_item	2561611	et	3	main
olen	doc_491521501969_item	2561632	et	3	main
omadust	doc_491521501969_item	2561640	et	4	main
isegi	doc_491521501969_item	2561654	et	4	main
siis	doc_491521501969_item	2561655	et	3	main
ei	doc_491521501969_item	2561659	et	4	main
päris	doc_491521501969_item	2561663	et	4	main
see	doc_491521501969_item	2561664	et	3	main
tööd	doc_491521501969_item	2561689	et	4	main
nii	doc_491521501969_item	2561690	et	3	main
venemaal	doc_491521501969_item	2561691	et	4	main
kui	doc_491521501969_item	2561692	et	3	main
isa	doc_491521501969_item	2561703	et	4	main
ei	doc_491521501969_item	2561714	et	4	main
neid	doc_491521501969_item	2561718	et	4	main
huvitu	doc_491521501969_item	2561720	et	4	main
1	doc_491521501969_item	2561727	et	2	main
arvan	doc_491521501969_item	2561729	et	3	main
ta	doc_491521501969_item	2561737	et	4	main
on	doc_491521501969_item	2561738	et	4	main
ma	doc_491521501969_item	2561743	et	3	main
armasta	doc_491521501969_item	2561763	et	4	main
hoidja	doc_491521501969_item	2561774	et	4	main
küljed	doc_491521501969_item	2561779	et	3	main
unistasin	doc_491521501969_item	2561433	et	3	main
luurajaks	doc_491521501969_item	2561435	et	4	main
tehtud	doc_491521501969_item	2561442	et	4	main
film	doc_491521501969_item	2561443	et	3	main
eritsooni	doc_491521501969_item	2561445	et	4	main
ja	doc_491521501969_item	2561446	et	3	main
tahtsin	doc_491521501969_item	2561447	et	3	main
saada	doc_491521501969_item	2561448	et	4	main
muutusid	doc_491521501969_item	2561455	et	4	main
saavutuseks	doc_491521501969_item	2561461	et	4	main
et	doc_491521501969_item	2561464	et	3	main
ärritab	doc_491521501969_item	2561473	et	3	main
petnud	doc_491521501969_item	2561488	et	4	main
teie	doc_491521501969_item	2561499	et	4	main
praegune	doc_491521501969_item	2561507	et	3	main
kohlta-järve	doc_491521501969_item	2561512	et	4	main
raske	doc_491521501969_item	2561522	et	4	main
ei	doc_491521501969_item	2561526	et	4	main
need	doc_491521501969_item	2561528	et	3	main
inimesed	doc_491521501969_item	2561535	et	3	main
sest	doc_491521501969_item	2561536	et	4	main
on	doc_491521501969_item	2561546	et	4	main
ka	doc_491521501969_item	2561547	et	3	main
probleeme	doc_491521501969_item	2561548	et	3	main
mida	doc_491521501969_item	2561558	et	4	main
tahaksite	doc_491521501969_item	2561559	et	3	main
osta	doc_491521501969_item	2561560	et	4	main
ma	doc_491521501969_item	2561561	et	3	main
tahan	doc_491521501969_item	2561562	et	3	main
eelkõige	doc_491521501969_item	2561569	et	3	main
teie	doc_491521501969_item	2561579	et	4	main
ida-virumaal	doc_491521501969_item	2561592	et	4	main
peipsi-äärne	doc_491521501969_item	2561593	et	3	main
karjamaa	doc_491521501969_item	2561596	et	4	main
mille	doc_491521501969_item	2561598	et	3	main
ei	doc_491521501969_item	2561600	et	4	main
paremini	doc_491521501969_item	2561621	et	4	main
kuid	doc_491521501969_item	2561623	et	4	main
ma	doc_491521501969_item	2561624	et	3	main
olen	doc_491521501969_item	2561625	et	3	main
loomult	doc_491521501969_item	2561626	et	3	main
öökulli	doc_491521501969_item	2561627	et	4	main
tüüpi	doc_491521501969_item	2561628	et	4	main
inimene	doc_491521501969_item	2561629	et	3	main
seetõttu	doc_491521501969_item	2561631	et	3	main
see	doc_491521501969_item	2561657	et	3	main
ma	doc_491521501969_item	2561666	et	3	main
teinud	doc_491521501969_item	2561688	et	4	main
siiski	doc_491521501969_item	2561695	et	4	main
on	doc_491521501969_item	2561696	et	4	main
mul	doc_491521501969_item	2561698	et	3	main
kõige	doc_491521501969_item	2561699	et	4	main
kus	doc_491521501969_item	2561705	et	3	main
sündisid	doc_491521501969_item	2561706	et	4	main
horoskoope	doc_491521501969_item	2561713	et	3	main
usu	doc_491521501969_item	2561717	et	4	main
intervjueritav	doc_491521501969_item	2561731	et	4	main
et	doc_491521501969_item	2561736	et	3	main
saadad	doc_491521501969_item	2561740	et	3	main
arvan	doc_491521501969_item	2561744	et	3	main
selle	doc_491521501969_item	2561757	et	4	main
pärast	doc_491521501969_item	2561758	et	4	main
et	doc_491521501969_item	2561759	et	3	main
ta	doc_491521501969_item	2561760	et	4	main
reeturlus	doc_491521501969_item	2561764	et	4	main
arvan	doc_491521501969_item	2561769	et	3	main
temal	doc_491521501969_item	2561776	et	3	main
tugevad	doc_491521501969_item	2561778	et	4	main
see	doc_491521501969_item	2561780	et	3	main
järjekindlus	doc_491521501969_item	2561784	et	4	main
eritsooni	doc_491521501970_item	2561826	et	4	main
aga	doc_491521501970_item	2561833	et	3	main
elu	doc_491521501970_item	2561840	et	4	main
selline	doc_491521501970_item	2561846	et	4	main
saavutus	doc_491521501970_item	2561847	et	4	main
ootab	doc_491521501970_item	2561848	et	3	main
ees	doc_491521501970_item	2561851	et	4	main
teid	doc_491521501970_item	2561853	et	4	main
hoidun	doc_491521501970_item	2561871	et	3	main
edaspidi	doc_491521501970_item	2561872	et	3	main
inimestega	doc_491521501970_item	2561874	et	3	main
puutumast	doc_491521501970_item	2561876	et	4	main
tegu	doc_491521501970_item	2561883	et	4	main
minu	doc_491521501970_item	2561887	et	3	main
võitlus	doc_491521501970_item	2561889	et	3	main
nimel	doc_491521501970_item	2561891	et	3	main
kindlasti	doc_491521501969_item	2561525	et	3	main
ole	doc_491521501969_item	2561527	et	4	main
ainult	doc_491521501969_item	2561529	et	4	main
rikkad	doc_491521501969_item	2561530	et	4	main
ja	doc_491521501969_item	2561531	et	3	main
mida	doc_491521501969_item	2561537	et	4	main
käes	doc_491521501969_item	2561543	et	4	main
seda	doc_491521501969_item	2561544	et	3	main
peale	doc_491521501969_item	2561550	et	4	main
targemaks	doc_491521501969_item	2561568	et	4	main
õigusteaduses	doc_491521501969_item	2561576	et	3	main
parim	doc_491521501969_item	2561581	et	4	main
puhkus	doc_491521501969_item	2561582	et	3	main
milline	doc_491521501969_item	2561588	et	3	main
kant	doc_491521501969_item	2561594	et	3	main
aega	doc_491521501969_item	2561602	et	4	main
tahan	doc_491521501969_item	2561604	et	3	main
hästi	doc_491521501969_item	2561608	et	3	main
alati	doc_491521501969_item	2561612	et	4	main
et	doc_491521501969_item	2561613	et	3	main
oleks	doc_491521501969_item	2561614	et	3	main
natukene	doc_491521501969_item	2561615	et	4	main
rohkem	doc_491521501969_item	2561616	et	4	main
aega	doc_491521501969_item	2561617	et	4	main
siis	doc_491521501969_item	2561618	et	3	main
jõuaks	doc_491521501969_item	2561619	et	3	main
veelgi	doc_491521501969_item	2561620	et	4	main
siis	doc_491521501969_item	2561610	et	3	main
millist	doc_491521501969_item	2561639	et	3	main
asjad	doc_491521501969_item	2561652	et	3	main
lõpuni	doc_491521501969_item	2561653	et	3	main
kui	doc_491521501969_item	2561656	et	3	main
ole	doc_491521501969_item	2561660	et	4	main
iga	doc_491521501969_item	2561661	et	4	main
saksamaal	doc_491521501969_item	2561693	et	4	main
eestis	doc_491521501969_item	2561697	et	3	main
öeldut	doc_491521501969_item	2561704	et	4	main
loete	doc_491521501969_item	2561712	et	4	main
ei	doc_491521501969_item	2561716	et	4	main
valmistuda	doc_491521501969_item	2561622	et	3	main
hilistel	doc_491521501969_item	2561637	et	3	main
peate	doc_491521501969_item	2561641	et	4	main
on	doc_491521501969_item	2561649	et	4	main
järjekindlus	doc_491521501969_item	2561650	et	4	main
viia	doc_491521501969_item	2561651	et	3	main
kord	doc_491521501969_item	2561662	et	4	main
alguses	doc_491521501969_item	2561667	et	4	main
olin	doc_491521501969_item	2561668	et	3	main
lootnud	doc_491521501969_item	2561669	et	4	main
ei	doc_491521501969_item	2561670	et	4	main
ole	doc_491521501969_item	2561671	et	4	main
mul	doc_491521501969_item	2561672	et	3	main
kombeks	doc_491521501969_item	2561673	et	4	main
oma	doc_491521501969_item	2561674	et	4	main
ettevõtmisi	doc_491521501969_item	2561675	et	3	main
pooleli	doc_491521501969_item	2561676	et	3	main
jätta	doc_491521501969_item	2561677	et	3	main
millises	doc_491521501969_item	2561678	et	3	main
riigis	doc_491521501969_item	2561679	et	3	main
peale	doc_491521501969_item	2561680	et	4	main
eesti	doc_491521501969_item	2561681	et	4	main
tahaksite	doc_491521501969_item	2561682	et	3	main
elada	doc_491521501969_item	2561683	et	3	main
ma	doc_491521501969_item	2561684	et	3	main
olen	doc_491521501969_item	2561685	et	3	main
elanud	doc_491521501969_item	2561686	et	4	main
ja	doc_491521501969_item	2561687	et	3	main
kuid	doc_491521501969_item	2561694	et	4	main
parem	doc_491521501969_item	2561700	et	4	main
järgin	doc_491521501969_item	2561701	et	3	main
seal	doc_491521501969_item	2561707	et	4	main
ma	doc_491521501969_item	2561715	et	3	main
ega	doc_491521501969_item	2561719	et	3	main
asi	doc_491521501969_item	2561726	et	4	main
ma	doc_491521501969_item	2561728	et	3	main
et	doc_491521501969_item	2561730	et	3	main
on	doc_491521501969_item	2561732	et	4	main
selle	doc_491521501969_item	2561734	et	4	main
tahaksin	doc_491521501969_item	2561739	et	3	main
luurajaks	doc_491521501969_item	2561741	et	4	main
et	doc_491521501969_item	2561745	et	3	main
on	doc_491521501969_item	2561747	et	4	main
juurist	doc_491521501969_item	2561748	et	3	main
3	doc_491521501969_item	2561750	et	2	main
looduse	doc_491521501969_item	2561773	et	4	main
lõpuni	doc_491521501969_item	2561787	et	3	main
ta	doc_491521501969_item	2561790	et	4	main
tolleaegne	doc_491521501970_item	2561821	et	3	main
film	doc_491521501970_item	2561824	et	3	main
nagu	doc_491521501970_item	2561831	et	3	main
nemad	doc_491521501970_item	2561832	et	3	main
küll	doc_491521501970_item	2561859	et	4	main
välja	doc_491521501970_item	2561864	et	4	main
et	doc_491521501970_item	2561865	et	3	main
nad	doc_491521501970_item	2561866	et	3	main
on	doc_491521501970_item	2561867	et	4	main
kokku	doc_491521501970_item	2561875	et	3	main
on	doc_491521501970_item	2561898	et	4	main
võimu	doc_491521501970_item	2561922	et	4	main
peale	doc_491521501970_item	2561931	et	4	main
kulub	doc_491521501970_item	2561932	et	3	main
teil	doc_491521501970_item	2561933	et	4	main
kõige	doc_491521501970_item	2561934	et	4	main
peale	doc_491521501970_item	2561938	et	4	main
targemaks	doc_491521501970_item	2561949	et	4	main
eelkõige	doc_491521501970_item	2561950	et	3	main
tahaks	doc_491521501970_item	2561951	et	3	main
õigusteaduses	doc_491521501970_item	2561957	et	3	main
on	doc_491521501970_item	2561959	et	4	main
milline	doc_491521501970_item	2561969	et	3	main
alajõe	doc_491521501970_item	2561976	et	3	main
vasknarva	doc_491521501970_item	2561978	et	4	main
tegema	doc_491521501970_item	2562016	et	3	main
see	doc_491521501969_item	2561722	et	3	main
ole	doc_491521501969_item	2561724	et	4	main
tõsine	doc_491521501969_item	2561725	et	4	main
pärast	doc_491521501969_item	2561735	et	4	main
ta	doc_491521501969_item	2561746	et	4	main
kohtus	doc_491521501969_item	2561749	et	4	main
ma	doc_491521501969_item	2561751	et	3	main
arvan	doc_491521501969_item	2561752	et	3	main
temal	doc_491521501969_item	2561753	et	3	main
on	doc_491521501969_item	2561754	et	4	main
sõbralik	doc_491521501969_item	2561755	et	3	main
iseloom	doc_491521501969_item	2561756	et	3	main
on	doc_491521501969_item	2561761	et	4	main
valetamine	doc_491521501969_item	2561766	et	4	main
ma	doc_491521501969_item	2561768	et	3	main
1	doc_491521501969_item	2561775	et	2	main
viia	doc_491521501969_item	2561785	et	3	main
kuid	doc_491521501969_item	2561789	et	4	main
oleb	doc_491521501969_item	2561791	et	4	main
loomult	doc_491521501969_item	2561792	et	3	main
öökulli	doc_491521501969_item	2561793	et	4	main
tüüpi	doc_491521501969_item	2561794	et	4	main
inimene	doc_491521501969_item	2561795	et	3	main
ja	doc_491521501969_item	2561796	et	3	main
seetõttu	doc_491521501969_item	2561797	et	3	main
oleb	doc_491521501969_item	2561798	et	4	main
harjunud	doc_491521501969_item	2561799	et	4	main
tööd	doc_491521501969_item	2561800	et	4	main
tegema	doc_491521501969_item	2561801	et	3	main
ka	doc_491521501969_item	2561802	et	3	main
hilistel	doc_491521501969_item	2561803	et	3	main
öötundidel	doc_491521501969_item	2561804	et	3	main
12c	doc_491521501969_item	2561805	et	4	main
13	doc_491521501970_item	2561806	et	2	main
küsimust	doc_491521501970_item	2561807	et	4	main
13	doc_491521501970_item	2561808	et	2	main
küsimust	doc_491521501970_item	2561809	et	4	main
kelleks	doc_491521501970_item	2561810	et	4	main
tahtsite	doc_491521501970_item	2561811	et	3	main
lapsepõlves	doc_491521501970_item	2561812	et	4	main
saada	doc_491521501970_item	2561813	et	4	main
unistasin	doc_491521501970_item	2561814	et	3	main
saada	doc_491521501970_item	2561815	et	4	main
luurajaks	doc_491521501970_item	2561816	et	4	main
mind	doc_491521501970_item	2561817	et	4	main
köitis	doc_491521501970_item	2561818	et	3	main
ka	doc_491521501970_item	2561819	et	3	main
väga	doc_491521501970_item	2561820	et	3	main
dessantväelasest	doc_491521501970_item	2561822	et	3	main
tehtud	doc_491521501970_item	2561823	et	4	main
sööst	doc_491521501970_item	2561825	et	3	main
saada	doc_491521501970_item	2561829	et	4	main
mida	doc_491521501970_item	2561837	et	4	main
4	doc_491521501969_item	2561767	et	2	main
ta	doc_491521501969_item	2561770	et	4	main
võiks	doc_491521501969_item	2561771	et	4	main
töötada	doc_491521501969_item	2561772	et	3	main
on	doc_491521501969_item	2561777	et	4	main
asjad	doc_491521501969_item	2561786	et	3	main
tahtsin	doc_491521501970_item	2561828	et	3	main
huvid	doc_491521501970_item	2561835	et	3	main
muutusid	doc_491521501970_item	2561836	et	4	main
peate	doc_491521501970_item	2561838	et	4	main
oma	doc_491521501970_item	2561839	et	4	main
saavutuseks	doc_491521501970_item	2561842	et	4	main
ärritab	doc_491521501970_item	2561854	et	3	main
ei	doc_491521501970_item	2561861	et	4	main
inimestele	doc_491521501970_item	2561863	et	3	main
petnud	doc_491521501970_item	2561869	et	4	main
on	doc_491521501970_item	2561878	et	4	main
olnud	doc_491521501970_item	2561879	et	4	main
elu	doc_491521501970_item	2561881	et	4	main
ilmselt	doc_491521501970_item	2561884	et	4	main
see	doc_491521501970_item	2561886	et	3	main
praegune	doc_491521501970_item	2561888	et	3	main
selle	doc_491521501970_item	2561890	et	4	main
saaks	doc_491521501970_item	2561896	et	3	main
on	doc_491521501969_item	2561781	et	4	main
ta	doc_491521501969_item	2561782	et	4	main
on	doc_491521501969_item	2561783	et	4	main
1	doc_491521501969_item	2561788	et	2	main
ja	doc_491521501970_item	2561827	et	3	main
samasuguseks	doc_491521501970_item	2561830	et	4	main
hiljem	doc_491521501970_item	2561834	et	3	main
suurimaks	doc_491521501970_item	2561841	et	4	main
ma	doc_491521501970_item	2561843	et	3	main
loodan	doc_491521501970_item	2561844	et	3	main
veel	doc_491521501970_item	2561850	et	4	main
üldiselt	doc_491521501970_item	2561860	et	4	main
ütle	doc_491521501970_item	2561862	et	4	main
kuid	doc_491521501970_item	2561870	et	4	main
mis	doc_491521501970_item	2561877	et	4	main
teie	doc_491521501970_item	2561880	et	4	main
kohlta-järve	doc_491521501970_item	2561893	et	4	main
tänapäeva	doc_491521501970_item	2561899	et	4	main
eestis	doc_491521501970_item	2561900	et	3	main
hea	doc_491521501970_item	2561901	et	4	main
elada	doc_491521501970_item	2561902	et	3	main
raske	doc_491521501970_item	2561903	et	4	main
öelda	doc_491521501970_item	2561904	et	4	main
kuid	doc_491521501970_item	2561905	et	4	main
kindlasti	doc_491521501970_item	2561906	et	3	main
ei	doc_491521501970_item	2561907	et	4	main
ole	doc_491521501970_item	2561908	et	4	main
need	doc_491521501970_item	2561909	et	3	main
ainult	doc_491521501970_item	2561910	et	4	main
rikkad	doc_491521501970_item	2561911	et	4	main
ja	doc_491521501970_item	2561912	et	3	main
võimu	doc_491521501970_item	2561913	et	4	main
juures	doc_491521501970_item	2561914	et	4	main
olevad	doc_491521501970_item	2561915	et	4	main
inimesed	doc_491521501970_item	2561916	et	3	main
sest	doc_491521501970_item	2561917	et	4	main
mida	doc_491521501970_item	2561918	et	4	main
rohkem	doc_491521501970_item	2561919	et	4	main
raha	doc_491521501970_item	2561920	et	4	main
on	doc_491521501970_item	2561923	et	4	main
käes	doc_491521501970_item	2561924	et	4	main
seda	doc_491521501970_item	2561925	et	3	main
mida	doc_491521501970_item	2561939	et	4	main
ma	doc_491521501970_item	2561942	et	3	main
palju	doc_491521501970_item	2561945	et	4	main
taset	doc_491521501970_item	2561954	et	3	main
valitud	doc_491521501970_item	2561955	et	4	main
koos	doc_491521501970_item	2561965	et	4	main
kusagil	doc_491521501970_item	2561967	et	3	main
on	doc_491521501970_item	2561970	et	4	main
teie	doc_491521501970_item	2561971	et	4	main
lemmikkoht	doc_491521501970_item	2561972	et	3	main
ida-virumaal	doc_491521501970_item	2561973	et	4	main
karjamaa	doc_491521501970_item	2561977	et	4	main
harjunud	doc_491521501970_item	2562014	et	4	main
tööd	doc_491521501970_item	2562015	et	4	main
küljeks	doc_491521501970_item	2562025	et	3	main
see	doc_491521501970_item	2562029	et	3	main
iga	doc_491521501970_item	2562042	et	4	main
lootnud	doc_491521501970_item	2562050	et	4	main
ei	doc_491521501970_item	2562051	et	4	main
oma	doc_491521501970_item	2562055	et	4	main
elanud	doc_491521501970_item	2562067	et	4	main
kuid	doc_491521501970_item	2562075	et	4	main
et	doc_491521501970_item	2561845	et	3	main
mind	doc_491521501970_item	2561849	et	4	main
mis	doc_491521501970_item	2561852	et	4	main
reeturlus	doc_491521501970_item	2561855	et	4	main
ja	doc_491521501970_item	2561856	et	3	main
valetamine	doc_491521501970_item	2561857	et	4	main
ma	doc_491521501970_item	2561858	et	3	main
mind	doc_491521501970_item	2561868	et	4	main
selliste	doc_491521501970_item	2561873	et	4	main
pööraseim	doc_491521501970_item	2561882	et	4	main
ongi	doc_491521501970_item	2561885	et	4	main
et	doc_491521501970_item	2561892	et	3	main
õhk	doc_491521501970_item	2561894	et	3	main
on	doc_491521501970_item	2561927	et	4	main
mille	doc_491521501970_item	2561930	et	3	main
kommunaalkulude	doc_491521501970_item	2561937	et	3	main
oma	doc_491521501970_item	2561953	et	4	main
mis	doc_491521501970_item	2561958	et	4	main
teie	doc_491521501970_item	2561960	et	4	main
jaoks	doc_491521501970_item	2561961	et	4	main
looduses	doc_491521501970_item	2561968	et	4	main
kant	doc_491521501970_item	2561975	et	3	main
olen	doc_491521501970_item	2562013	et	3	main
öötundidel	doc_491521501970_item	2562019	et	3	main
omadust	doc_491521501970_item	2562021	et	4	main
oma	doc_491521501970_item	2562023	et	4	main
järjekindlus	doc_491521501970_item	2562031	et	4	main
see	doc_491521501970_item	2562038	et	3	main
tulemus	doc_491521501970_item	2562039	et	3	main
ei	doc_491521501970_item	2562040	et	4	main
mida	doc_491521501970_item	2562046	et	4	main
ma	doc_491521501970_item	2562047	et	3	main
ettevõtmisi	doc_491521501970_item	2562056	et	3	main
tööd	doc_491521501970_item	2562070	et	4	main
kõige	doc_491521501970_item	2562080	et	4	main
horoskoope	doc_491521501970_item	2562094	et	3	main
ei	doc_491521501970_item	2562095	et	4	main
ei	doc_491521501970_item	2562097	et	4	main
ei	doc_491521501970_item	2562104	et	4	main
ole	doc_491521501970_item	2562105	et	4	main
õigusteadaja	doc_491521501970_item	2562118	et	4	main
inimene	doc_491521501970_item	2562124	et	3	main
teil	doc_491521501970_item	2562132	et	4	main
on	doc_491521501970_item	2562133	et	4	main
hilistel	doc_491521501970_item	2562139	et	3	main
öötundidel	doc_491521501970_item	2562140	et	3	main
viia	doc_491521501970_item	2562146	et	3	main
13	doc_491521501971_item	2562150	et	2	main
saada	doc_491521501971_item	2562159	et	4	main
mind	doc_491521501971_item	2562161	et	4	main
köitis	doc_491521501971_item	2562162	et	3	main
ka	doc_491521501971_item	2562163	et	3	main
selline	doc_491521501971_item	2562190	et	4	main
saavutus	doc_491521501971_item	2562191	et	4	main
ootab	doc_491521501971_item	2562192	et	3	main
teid	doc_491521501971_item	2562197	et	4	main
ärritab	doc_491521501971_item	2562198	et	3	main
reeturlus	doc_491521501971_item	2562199	et	4	main
valetamine	doc_491521501971_item	2562201	et	4	main
välja	doc_491521501971_item	2562208	et	4	main
et	doc_491521501971_item	2562209	et	3	main
on	doc_491521501971_item	2562222	et	4	main
olnud	doc_491521501971_item	2562223	et	4	main
ilmselt	doc_491521501971_item	2562228	et	4	main
õhk	doc_491521501971_item	2562238	et	3	main
kellel	doc_491521501971_item	2562241	et	4	main
tänapäeva	doc_491521501971_item	2562243	et	4	main
eestis	doc_491521501971_item	2562244	et	3	main
kindlasti	doc_491521501971_item	2562250	et	3	main
ainult	doc_491521501971_item	2562254	et	4	main
inimesed	doc_491521501971_item	2562260	et	3	main
võimu	doc_491521501971_item	2562266	et	4	main
käes	doc_491521501971_item	2562268	et	4	main
teil	doc_491521501971_item	2562277	et	4	main
mida	doc_491521501971_item	2562283	et	4	main
ma	doc_491521501971_item	2562286	et	3	main
väga	doc_491521501971_item	2562288	et	3	main
et	doc_491521501971_item	2562291	et	3	main
karjamaa	doc_491521501971_item	2562321	et	4	main
võimalikult	doc_491521501971_item	2562332	et	4	main
siis	doc_491521501971_item	2562343	et	3	main
kuid	doc_491521501971_item	2562348	et	4	main
puhtaks	doc_491521501970_item	2561895	et	3	main
kellel	doc_491521501970_item	2561897	et	4	main
ja	doc_491521501970_item	2561921	et	3	main
rohkem	doc_491521501970_item	2561926	et	4	main
rohkem	doc_491521501970_item	2561935	et	4	main
tahaksite	doc_491521501970_item	2561940	et	3	main
osta	doc_491521501970_item	2561941	et	4	main
tahan	doc_491521501970_item	2561943	et	3	main
väga	doc_491521501970_item	2561944	et	3	main
lugeda	doc_491521501970_item	2561946	et	3	main
et	doc_491521501970_item	2561947	et	3	main
saada	doc_491521501970_item	2561948	et	4	main
erialal	doc_491521501970_item	2561956	et	3	main
perega	doc_491521501970_item	2561966	et	3	main
peipsi-äärne	doc_491521501970_item	2561974	et	3	main
ka	doc_491521501970_item	2562017	et	3	main
millist	doc_491521501970_item	2562020	et	3	main
peate	doc_491521501970_item	2562022	et	4	main
arvan	doc_491521501970_item	2562027	et	3	main
ole	doc_491521501970_item	2562041	et	4	main
alguses	doc_491521501970_item	2562048	et	4	main
olin	doc_491521501970_item	2562049	et	3	main
kombeks	doc_491521501970_item	2562054	et	4	main
ma	doc_491521501970_item	2562065	et	3	main
kui	doc_491521501970_item	2562073	et	3	main
oma	doc_491521501970_item	2562083	et	4	main
isa	doc_491521501970_item	2562084	et	4	main
ka	doc_491521501970_item	2562090	et	3	main
huvitu	doc_491521501970_item	2562101	et	4	main
asi	doc_491521501970_item	2562107	et	4	main
1	doc_491521501970_item	2562108	et	2	main
ma	doc_491521501970_item	2562109	et	3	main
on	doc_491521501970_item	2562113	et	4	main
ka	doc_491521501970_item	2561928	et	3	main
probleeme	doc_491521501970_item	2561929	et	3	main
raha	doc_491521501970_item	2561936	et	4	main
tõsta	doc_491521501970_item	2561952	et	4	main
parim	doc_491521501970_item	2561962	et	4	main
puhkus	doc_491521501970_item	2561963	et	3	main
olla	doc_491521501970_item	2561964	et	3	main
mille	doc_491521501970_item	2561979	et	3	main
jaoks	doc_491521501970_item	2561980	et	4	main
ei	doc_491521501970_item	2561981	et	4	main
jätku	doc_491521501970_item	2561982	et	4	main
aega	doc_491521501970_item	2561983	et	4	main
kuna	doc_491521501970_item	2561984	et	3	main
tahan	doc_491521501970_item	2561985	et	3	main
kohtuasjades	doc_491521501970_item	2561986	et	3	main
inimesi	doc_491521501970_item	2561987	et	4	main
võimalikult	doc_491521501970_item	2561988	et	4	main
hästi	doc_491521501970_item	2561989	et	3	main
aidata	doc_491521501970_item	2561990	et	4	main
siis	doc_491521501970_item	2561991	et	3	main
tundub	doc_491521501970_item	2561992	et	3	main
alati	doc_491521501970_item	2561993	et	4	main
et	doc_491521501970_item	2561994	et	3	main
oleks	doc_491521501970_item	2561995	et	3	main
natukene	doc_491521501970_item	2561996	et	4	main
rohkem	doc_491521501970_item	2561997	et	4	main
aega	doc_491521501970_item	2561998	et	4	main
siis	doc_491521501970_item	2561999	et	3	main
jõuaks	doc_491521501970_item	2562000	et	3	main
veelgi	doc_491521501970_item	2562001	et	4	main
paremini	doc_491521501970_item	2562002	et	4	main
kuid	doc_491521501970_item	2562004	et	4	main
valmistuda	doc_491521501970_item	2562003	et	3	main
ma	doc_491521501970_item	2562005	et	3	main
olen	doc_491521501970_item	2562006	et	3	main
loomult	doc_491521501970_item	2562007	et	3	main
öökulli	doc_491521501970_item	2562008	et	4	main
tüüpi	doc_491521501970_item	2562009	et	4	main
inimene	doc_491521501970_item	2562010	et	3	main
ja	doc_491521501970_item	2562011	et	3	main
seetõttu	doc_491521501970_item	2562012	et	3	main
hilistel	doc_491521501970_item	2562018	et	3	main
ma	doc_491521501970_item	2562026	et	3	main
et	doc_491521501970_item	2562028	et	3	main
kord	doc_491521501970_item	2562043	et	4	main
nii	doc_491521501970_item	2562071	et	3	main
venemaal	doc_491521501970_item	2562072	et	4	main
peab	doc_491521501970_item	2562089	et	4	main
elama	doc_491521501970_item	2562091	et	3	main
arvan	doc_491521501970_item	2562110	et	3	main
mees	doc_491521501970_item	2562114	et	4	main
ta	doc_491521501970_item	2562116	et	4	main
on	doc_491521501970_item	2562117	et	4	main
oleb	doc_491521501970_item	2562121	et	4	main
5	doc_491521501970_item	2562131	et	2	main
tööharjumus	doc_491521501970_item	2562134	et	3	main
ta	doc_491521501970_item	2562135	et	4	main
meeldib	doc_491521501970_item	2562136	et	3	main
tema	doc_491521501970_item	2562142	et	4	main
küljed	doc_491521501970_item	2562144	et	3	main
13	doc_491521501971_item	2562152	et	2	main
kelleks	doc_491521501971_item	2562154	et	4	main
sööst	doc_491521501971_item	2562169	et	3	main
mis	doc_491521501971_item	2562196	et	4	main
üldiselt	doc_491521501971_item	2562204	et	4	main
on	doc_491521501971_item	2562211	et	4	main
selliste	doc_491521501971_item	2562217	et	4	main
inimestega	doc_491521501971_item	2562218	et	3	main
mis	doc_491521501971_item	2562221	et	4	main
teie	doc_491521501971_item	2562224	et	4	main
ongi	doc_491521501971_item	2562229	et	4	main
see	doc_491521501971_item	2562230	et	3	main
minu	doc_491521501971_item	2562231	et	3	main
praegune	doc_491521501971_item	2562232	et	3	main
võitlus	doc_491521501971_item	2562233	et	3	main
kohlta-järve	doc_491521501971_item	2562237	et	4	main
on	doc_491521501971_item	2562242	et	4	main
hea	doc_491521501971_item	2562245	et	4	main
elada	doc_491521501971_item	2562246	et	3	main
ole	doc_491521501971_item	2562252	et	4	main
need	doc_491521501971_item	2562253	et	3	main
rikkad	doc_491521501971_item	2562255	et	4	main
ja	doc_491521501971_item	2562256	et	3	main
mida	doc_491521501971_item	2562262	et	4	main
tahaksite	doc_491521501971_item	2562284	et	3	main
lugeda	doc_491521501971_item	2562290	et	3	main
tugevaimaks	doc_491521501970_item	2562024	et	4	main
on	doc_491521501970_item	2562030	et	4	main
viia	doc_491521501970_item	2562032	et	3	main
asjad	doc_491521501970_item	2562033	et	3	main
lõpuni	doc_491521501970_item	2562034	et	3	main
isegi	doc_491521501970_item	2562035	et	4	main
siis	doc_491521501970_item	2562036	et	3	main
kui	doc_491521501970_item	2562037	et	3	main
päris	doc_491521501970_item	2562044	et	4	main
see	doc_491521501970_item	2562045	et	3	main
ole	doc_491521501970_item	2562052	et	4	main
mul	doc_491521501970_item	2562053	et	3	main
pooleli	doc_491521501970_item	2562057	et	3	main
millises	doc_491521501970_item	2562059	et	3	main
jätta	doc_491521501970_item	2562058	et	3	main
riigis	doc_491521501970_item	2562060	et	3	main
peale	doc_491521501970_item	2562061	et	4	main
eesti	doc_491521501970_item	2562062	et	4	main
tahaksite	doc_491521501970_item	2562063	et	3	main
elada	doc_491521501970_item	2562064	et	3	main
olen	doc_491521501970_item	2562066	et	3	main
ja	doc_491521501970_item	2562068	et	3	main
teinud	doc_491521501970_item	2562069	et	4	main
saksamaal	doc_491521501970_item	2562074	et	4	main
on	doc_491521501970_item	2562077	et	4	main
parem	doc_491521501970_item	2562081	et	4	main
järgin	doc_491521501970_item	2562082	et	3	main
seal	doc_491521501970_item	2562088	et	4	main
loete	doc_491521501970_item	2562093	et	4	main
nendest	doc_491521501970_item	2562102	et	4	main
see	doc_491521501970_item	2562103	et	3	main
et	doc_491521501970_item	2562111	et	3	main
2	doc_491521501970_item	2562115	et	2	main
ta	doc_491521501970_item	2562120	et	4	main
öökulli	doc_491521501970_item	2562122	et	4	main
võiks	doc_491521501970_item	2562127	et	4	main
asjad	doc_491521501970_item	2562147	et	3	main
lõpuni	doc_491521501970_item	2562148	et	3	main
küsimust	doc_491521501971_item	2562151	et	4	main
lapsepõlves	doc_491521501971_item	2562156	et	4	main
saada	doc_491521501971_item	2562157	et	4	main
unistasin	doc_491521501971_item	2562158	et	3	main
ees	doc_491521501971_item	2562195	et	4	main
ma	doc_491521501971_item	2562202	et	3	main
küll	doc_491521501971_item	2562203	et	4	main
nad	doc_491521501971_item	2562210	et	3	main
mind	doc_491521501971_item	2562212	et	4	main
kokku	doc_491521501971_item	2562219	et	3	main
elu	doc_491521501971_item	2562225	et	4	main
pööraseim	doc_491521501971_item	2562226	et	4	main
selle	doc_491521501971_item	2562234	et	4	main
nimel	doc_491521501971_item	2562235	et	3	main
et	doc_491521501971_item	2562236	et	3	main
ei	doc_491521501971_item	2562251	et	4	main
olevad	doc_491521501971_item	2562259	et	4	main
rohkem	doc_491521501971_item	2562263	et	4	main
peale	doc_491521501971_item	2562275	et	4	main
kulub	doc_491521501971_item	2562276	et	3	main
peale	doc_491521501971_item	2562282	et	4	main
jätku	doc_491521501971_item	2562326	et	4	main
kohtuasjades	doc_491521501971_item	2562330	et	3	main
aega	doc_491521501971_item	2562342	et	4	main
on	doc_491521501971_item	2562374	et	4	main
ole	doc_491521501971_item	2562385	et	4	main
lootnud	doc_491521501971_item	2562394	et	4	main
ole	doc_491521501971_item	2562396	et	4	main
mul	doc_491521501971_item	2562397	et	3	main
peale	doc_491521501971_item	2562405	et	4	main
eesti	doc_491521501971_item	2562406	et	4	main
ma	doc_491521501971_item	2562409	et	3	main
saksamaal	doc_491521501971_item	2562418	et	4	main
isa	doc_491521501971_item	2562428	et	4	main
kus	doc_491521501971_item	2562430	et	3	main
horoskoope	doc_491521501971_item	2562438	et	3	main
huvitu	doc_491521501971_item	2562445	et	4	main
on	doc_491521501971_item	2562459	et	4	main
juurist	doc_491521501971_item	2562460	et	3	main
kelleks	doc_491521501972_item	2562493	et	4	main
tahtsite	doc_491521501972_item	2562494	et	3	main
et	doc_491521501972_item	2562528	et	3	main
veel	doc_491521501972_item	2562533	et	4	main
ütle	doc_491521501972_item	2562545	et	4	main
on	doc_491521501972_item	2562550	et	4	main
mind	doc_491521501972_item	2562551	et	4	main
kuid	doc_491521501972_item	2562553	et	4	main
hoidun	doc_491521501972_item	2562554	et	3	main
edaspidi	doc_491521501972_item	2562555	et	3	main
olnud	doc_491521501972_item	2562562	et	4	main
võimu	doc_491521501972_item	2562605	et	4	main
seda	doc_491521501972_item	2562608	et	3	main
ka	doc_491521501972_item	2562611	et	3	main
teil	doc_491521501972_item	2562616	et	4	main
et	doc_491521501972_item	2562630	et	3	main
oma	doc_491521501972_item	2562636	et	4	main
teie	doc_491521501972_item	2562643	et	4	main
kusagil	doc_491521501972_item	2562650	et	3	main
teie	doc_491521501972_item	2562654	et	4	main
ida-virumaal	doc_491521501972_item	2562656	et	4	main
peipsi-äärne	doc_491521501972_item	2562657	et	3	main
kant	doc_491521501972_item	2562658	et	3	main
alajõe	doc_491521501972_item	2562659	et	3	main
siiski	doc_491521501970_item	2562076	et	4	main
eestis	doc_491521501970_item	2562078	et	3	main
mul	doc_491521501970_item	2562079	et	3	main
öeldut	doc_491521501970_item	2562085	et	4	main
kus	doc_491521501970_item	2562086	et	3	main
sündisid	doc_491521501970_item	2562087	et	4	main
kas	doc_491521501970_item	2562092	et	3	main
ma	doc_491521501970_item	2562096	et	3	main
usu	doc_491521501970_item	2562098	et	4	main
neid	doc_491521501970_item	2562099	et	4	main
ega	doc_491521501970_item	2562100	et	3	main
tõsine	doc_491521501970_item	2562106	et	4	main
intervjueeritav	doc_491521501970_item	2562112	et	4	main
3	doc_491521501970_item	2562119	et	2	main
tüüpi	doc_491521501970_item	2562123	et	4	main
ta	doc_491521501970_item	2562126	et	4	main
ka	doc_491521501970_item	2562138	et	3	main
6	doc_491521501970_item	2562141	et	2	main
tugevad	doc_491521501970_item	2562143	et	4	main
tolleaegne	doc_491521501971_item	2562165	et	3	main
dessantväelasest	doc_491521501971_item	2562166	et	3	main
tehtud	doc_491521501971_item	2562167	et	4	main
film	doc_491521501971_item	2562168	et	3	main
ei	doc_491521501971_item	2562205	et	4	main
petnud	doc_491521501971_item	2562213	et	4	main
puutumast	doc_491521501971_item	2562220	et	4	main
tegu	doc_491521501971_item	2562227	et	4	main
saaks	doc_491521501971_item	2562240	et	3	main
kuid	doc_491521501971_item	2562249	et	4	main
sest	doc_491521501971_item	2562261	et	4	main
ja	doc_491521501971_item	2562265	et	3	main
on	doc_491521501971_item	2562267	et	4	main
seda	doc_491521501971_item	2562269	et	3	main
rohkem	doc_491521501971_item	2562270	et	4	main
kõige	doc_491521501971_item	2562278	et	4	main
rohkem	doc_491521501971_item	2562279	et	4	main
eelkõige	doc_491521501971_item	2562294	et	3	main
aega	doc_491521501971_item	2562327	et	4	main
tahan	doc_491521501971_item	2562329	et	3	main
natukene	doc_491521501971_item	2562340	et	4	main
rohkem	doc_491521501971_item	2562341	et	4	main
veelgi	doc_491521501971_item	2562345	et	4	main
valmistuda	doc_491521501971_item	2562347	et	3	main
arvan	doc_491521501971_item	2562371	et	3	main
see	doc_491521501971_item	2562389	et	3	main
mida	doc_491521501971_item	2562390	et	4	main
ma	doc_491521501971_item	2562391	et	3	main
riigis	doc_491521501971_item	2562404	et	3	main
olen	doc_491521501971_item	2562410	et	3	main
teinud	doc_491521501971_item	2562413	et	4	main
nii	doc_491521501971_item	2562415	et	3	main
venemaal	doc_491521501971_item	2562416	et	4	main
kui	doc_491521501971_item	2562417	et	3	main
oma	doc_491521501971_item	2562427	et	4	main
öeldut	doc_491521501971_item	2562429	et	4	main
peab	doc_491521501971_item	2562433	et	4	main
ka	doc_491521501971_item	2562434	et	3	main
elama	doc_491521501971_item	2562435	et	3	main
kas	doc_491521501971_item	2562436	et	3	main
neid	doc_491521501971_item	2562443	et	4	main
ega	doc_491521501971_item	2562444	et	3	main
ei	doc_491521501971_item	2562448	et	4	main
asi	doc_491521501971_item	2562451	et	4	main
1	doc_491521501971_item	2562452	et	2	main
ma	doc_491521501971_item	2562453	et	3	main
arvan	doc_491521501971_item	2562454	et	3	main
et	doc_491521501971_item	2562455	et	3	main
mees	doc_491521501971_item	2562456	et	4	main
2	doc_491521501971_item	2562457	et	2	main
öökulli	doc_491521501971_item	2562465	et	4	main
on	doc_491521501971_item	2562475	et	4	main
6	doc_491521501971_item	2562476	et	2	main
tema	doc_491521501971_item	2562477	et	4	main
see	doc_491521501971_item	2562482	et	3	main
järjekindlus	doc_491521501971_item	2562484	et	4	main
lõpuni	doc_491521501971_item	2562487	et	3	main
13	doc_491521501972_item	2562489	et	2	main
küsimust	doc_491521501972_item	2562490	et	4	main
saavutuseks	doc_491521501972_item	2562525	et	4	main
ma	doc_491521501972_item	2562526	et	3	main
selline	doc_491521501972_item	2562529	et	4	main
saavutus	doc_491521501972_item	2562530	et	4	main
4	doc_491521501970_item	2562125	et	2	main
töötada	doc_491521501970_item	2562128	et	3	main
linnavaalitsuses	doc_491521501970_item	2562129	et	4	main
kohtuses	doc_491521501970_item	2562130	et	4	main
tegema	doc_491521501970_item	2562137	et	3	main
on	doc_491521501970_item	2562145	et	4	main
12-s	doc_491521501970_item	2562149	et	3	main
küsimust	doc_491521501971_item	2562153	et	4	main
tahtsite	doc_491521501971_item	2562155	et	3	main
luurajaks	doc_491521501971_item	2562160	et	4	main
väga	doc_491521501971_item	2562164	et	3	main
eritsooni	doc_491521501971_item	2562170	et	4	main
ja	doc_491521501971_item	2562171	et	3	main
tahtsin	doc_491521501971_item	2562172	et	3	main
saada	doc_491521501971_item	2562173	et	4	main
samasuguseks	doc_491521501971_item	2562174	et	4	main
nagu	doc_491521501971_item	2562175	et	3	main
nemad	doc_491521501971_item	2562176	et	3	main
aga	doc_491521501971_item	2562177	et	3	main
hiljem	doc_491521501971_item	2562178	et	3	main
huvid	doc_491521501971_item	2562179	et	3	main
muutusid	doc_491521501971_item	2562180	et	4	main
mida	doc_491521501971_item	2562181	et	4	main
peate	doc_491521501971_item	2562182	et	4	main
oma	doc_491521501971_item	2562183	et	4	main
elu	doc_491521501971_item	2562184	et	4	main
suurimaks	doc_491521501971_item	2562185	et	4	main
saavutuseks	doc_491521501971_item	2562186	et	4	main
ma	doc_491521501971_item	2562187	et	3	main
loodan	doc_491521501971_item	2562188	et	3	main
et	doc_491521501971_item	2562189	et	3	main
mind	doc_491521501971_item	2562193	et	4	main
veel	doc_491521501971_item	2562194	et	4	main
ja	doc_491521501971_item	2562200	et	3	main
ütle	doc_491521501971_item	2562206	et	4	main
inimestele	doc_491521501971_item	2562207	et	3	main
kuid	doc_491521501971_item	2562214	et	4	main
hoidun	doc_491521501971_item	2562215	et	3	main
edaspidi	doc_491521501971_item	2562216	et	3	main
puhtaks	doc_491521501971_item	2562239	et	3	main
raske	doc_491521501971_item	2562247	et	4	main
öelda	doc_491521501971_item	2562248	et	4	main
võimu	doc_491521501971_item	2562257	et	4	main
juures	doc_491521501971_item	2562258	et	4	main
raha	doc_491521501971_item	2562264	et	4	main
on	doc_491521501971_item	2562271	et	4	main
ka	doc_491521501971_item	2562272	et	3	main
probleeme	doc_491521501971_item	2562273	et	3	main
mille	doc_491521501971_item	2562274	et	3	main
raha	doc_491521501971_item	2562280	et	4	main
kommunaalkulude	doc_491521501971_item	2562281	et	3	main
osta	doc_491521501971_item	2562285	et	4	main
tahan	doc_491521501971_item	2562287	et	3	main
palju	doc_491521501971_item	2562289	et	4	main
saada	doc_491521501971_item	2562292	et	4	main
targemaks	doc_491521501971_item	2562293	et	4	main
tahaks	doc_491521501971_item	2562295	et	3	main
tõsta	doc_491521501971_item	2562296	et	4	main
oma	doc_491521501971_item	2562297	et	4	main
taset	doc_491521501971_item	2562298	et	3	main
valitud	doc_491521501971_item	2562299	et	4	main
erialal	doc_491521501971_item	2562300	et	3	main
õigusteaduses	doc_491521501971_item	2562301	et	3	main
mis	doc_491521501971_item	2562302	et	4	main
on	doc_491521501971_item	2562303	et	4	main
teie	doc_491521501971_item	2562304	et	4	main
jaoks	doc_491521501971_item	2562305	et	4	main
parim	doc_491521501971_item	2562306	et	4	main
puhkus	doc_491521501971_item	2562307	et	3	main
olla	doc_491521501971_item	2562308	et	3	main
koos	doc_491521501971_item	2562309	et	4	main
perega	doc_491521501971_item	2562310	et	3	main
kusagil	doc_491521501971_item	2562311	et	3	main
looduses	doc_491521501971_item	2562312	et	4	main
milline	doc_491521501971_item	2562313	et	3	main
on	doc_491521501971_item	2562314	et	4	main
teie	doc_491521501971_item	2562315	et	4	main
lemmikkoht	doc_491521501971_item	2562316	et	3	main
ida-virumaal	doc_491521501971_item	2562317	et	4	main
peipsi-äärne	doc_491521501971_item	2562318	et	3	main
kant	doc_491521501971_item	2562319	et	3	main
alajõe	doc_491521501971_item	2562320	et	3	main
vasknarva	doc_491521501971_item	2562322	et	4	main
mille	doc_491521501971_item	2562323	et	3	main
jaoks	doc_491521501971_item	2562324	et	4	main
inimesi	doc_491521501971_item	2562331	et	4	main
hästi	doc_491521501971_item	2562333	et	3	main
aidata	doc_491521501971_item	2562334	et	4	main
siis	doc_491521501971_item	2562335	et	3	main
tundub	doc_491521501971_item	2562336	et	3	main
alati	doc_491521501971_item	2562337	et	4	main
et	doc_491521501971_item	2562338	et	3	main
oleks	doc_491521501971_item	2562339	et	3	main
jõuaks	doc_491521501971_item	2562344	et	3	main
paremini	doc_491521501971_item	2562346	et	4	main
ei	doc_491521501971_item	2562325	et	4	main
kuna	doc_491521501971_item	2562328	et	3	main
tüüpi	doc_491521501971_item	2562353	et	4	main
inimene	doc_491521501971_item	2562354	et	3	main
ja	doc_491521501971_item	2562355	et	3	main
seetõttu	doc_491521501971_item	2562356	et	3	main
olen	doc_491521501971_item	2562357	et	3	main
harjunud	doc_491521501971_item	2562358	et	4	main
tööd	doc_491521501971_item	2562359	et	4	main
tegema	doc_491521501971_item	2562360	et	3	main
ka	doc_491521501971_item	2562361	et	3	main
hilistel	doc_491521501971_item	2562362	et	3	main
öötundidel	doc_491521501971_item	2562363	et	3	main
millist	doc_491521501971_item	2562364	et	3	main
omadust	doc_491521501971_item	2562365	et	4	main
peate	doc_491521501971_item	2562366	et	4	main
oma	doc_491521501971_item	2562367	et	4	main
tugevaimaks	doc_491521501971_item	2562368	et	4	main
ma	doc_491521501971_item	2562349	et	3	main
olen	doc_491521501971_item	2562350	et	3	main
loomult	doc_491521501971_item	2562351	et	3	main
öökulli	doc_491521501971_item	2562352	et	4	main
alguses	doc_491521501971_item	2562392	et	4	main
ei	doc_491521501971_item	2562395	et	4	main
kombeks	doc_491521501971_item	2562398	et	4	main
oma	doc_491521501971_item	2562399	et	4	main
ettevõtmisi	doc_491521501971_item	2562400	et	3	main
pooleli	doc_491521501971_item	2562401	et	3	main
jätta	doc_491521501971_item	2562402	et	3	main
elanud	doc_491521501971_item	2562411	et	4	main
tööd	doc_491521501971_item	2562414	et	4	main
kuid	doc_491521501971_item	2562419	et	4	main
eestis	doc_491521501971_item	2562422	et	3	main
parem	doc_491521501971_item	2562425	et	4	main
sündisid	doc_491521501971_item	2562431	et	4	main
seal	doc_491521501971_item	2562432	et	4	main
ei	doc_491521501971_item	2562441	et	4	main
usu	doc_491521501971_item	2562442	et	4	main
nendest	doc_491521501971_item	2562446	et	4	main
ole	doc_491521501971_item	2562449	et	4	main
tõsine	doc_491521501971_item	2562450	et	4	main
3	doc_491521501971_item	2562461	et	2	main
tema	doc_491521501971_item	2562462	et	4	main
4	doc_491521501971_item	2562466	et	2	main
tugev	doc_491521501971_item	2562478	et	4	main
küljed	doc_491521501971_item	2562479	et	3	main
on	doc_491521501971_item	2562483	et	4	main
viia	doc_491521501971_item	2562485	et	3	main
12-s	doc_491521501971_item	2562488	et	3	main
13	doc_491521501972_item	2562491	et	2	main
küsimust	doc_491521501972_item	2562492	et	4	main
saada	doc_491521501972_item	2562496	et	4	main
küljeks	doc_491521501971_item	2562369	et	3	main
see	doc_491521501971_item	2562373	et	3	main
järjekindlus	doc_491521501971_item	2562375	et	4	main
viia	doc_491521501971_item	2562376	et	3	main
asjad	doc_491521501971_item	2562377	et	3	main
lõpuni	doc_491521501971_item	2562378	et	3	main
isegi	doc_491521501971_item	2562379	et	4	main
siis	doc_491521501971_item	2562380	et	3	main
kui	doc_491521501971_item	2562381	et	3	main
see	doc_491521501971_item	2562382	et	3	main
tulemus	doc_491521501971_item	2562383	et	3	main
iga	doc_491521501971_item	2562386	et	4	main
olin	doc_491521501971_item	2562393	et	3	main
millises	doc_491521501971_item	2562403	et	3	main
tahaksite	doc_491521501971_item	2562407	et	3	main
ja	doc_491521501971_item	2562412	et	3	main
siiski	doc_491521501971_item	2562420	et	4	main
on	doc_491521501971_item	2562421	et	4	main
mul	doc_491521501971_item	2562423	et	3	main
loete	doc_491521501971_item	2562437	et	4	main
see	doc_491521501971_item	2562447	et	3	main
ta	doc_491521501971_item	2562458	et	4	main
on	doc_491521501971_item	2562464	et	4	main
ta	doc_491521501971_item	2562467	et	4	main
on	doc_491521501971_item	2562468	et	4	main
võiks	doc_491521501971_item	2562469	et	4	main
töötada	doc_491521501971_item	2562470	et	3	main
linnavalitsuselt	doc_491521501971_item	2562471	et	4	main
5	doc_491521501971_item	2562472	et	2	main
tema	doc_491521501971_item	2562473	et	4	main
haridus	doc_491521501971_item	2562474	et	3	main
on	doc_491521501971_item	2562480	et	4	main
unistasin	doc_491521501972_item	2562497	et	3	main
oma	doc_491521501972_item	2562522	et	4	main
suurimaks	doc_491521501972_item	2562524	et	4	main
mind	doc_491521501972_item	2562532	et	4	main
mis	doc_491521501972_item	2562535	et	4	main
teid	doc_491521501972_item	2562536	et	4	main
ärritab	doc_491521501972_item	2562537	et	3	main
nad	doc_491521501972_item	2562549	et	3	main
elu	doc_491521501972_item	2562564	et	4	main
pööraseim	doc_491521501972_item	2562565	et	4	main
tegu	doc_491521501972_item	2562566	et	4	main
võimu	doc_491521501972_item	2562596	et	4	main
mida	doc_491521501972_item	2562601	et	4	main
ja	doc_491521501972_item	2562604	et	3	main
kõige	doc_491521501972_item	2562617	et	4	main
peale	doc_491521501972_item	2562621	et	4	main
tahaksite	doc_491521501972_item	2562623	et	3	main
ma	doc_491521501972_item	2562625	et	3	main
tahan	doc_491521501972_item	2562626	et	3	main
väga	doc_491521501972_item	2562627	et	3	main
palju	doc_491521501972_item	2562628	et	4	main
eelkõige	doc_491521501972_item	2562633	et	3	main
on	doc_491521501972_item	2562642	et	4	main
perega	doc_491521501972_item	2562649	et	3	main
on	doc_491521501972_item	2562653	et	4	main
lemmikkoht	doc_491521501972_item	2562655	et	3	main
jätku	doc_491521501972_item	2562665	et	4	main
kohtuasjades	doc_491521501972_item	2562669	et	3	main
hästi	doc_491521501972_item	2562672	et	3	main
see	doc_491521501972_item	2562721	et	3	main
ei	doc_491521501972_item	2562723	et	4	main
iga	doc_491521501972_item	2562725	et	4	main
kord	doc_491521501972_item	2562726	et	4	main
olin	doc_491521501972_item	2562732	et	3	main
ei	doc_491521501972_item	2562734	et	4	main
eesti	doc_491521501972_item	2562745	et	4	main
tahaksite	doc_491521501972_item	2562746	et	3	main
olen	doc_491521501972_item	2562749	et	3	main
isa	doc_491521501972_item	2562767	et	4	main
ei	doc_491521501972_item	2562780	et	4	main
ei	doc_491521501972_item	2562787	et	4	main
1	doc_491521501972_item	2562791	et	2	main
tema	doc_491521501972_item	2562826	et	4	main
inimesi	doc_491521501972_item	2562828	et	4	main
6	doc_491521501972_item	2562848	et	2	main
oma	doc_491521501972_item	2562858	et	4	main
ettevõtmisi	doc_491521501972_item	2562859	et	3	main
pooleli	doc_491521501972_item	2562860	et	3	main
luurajaks	doc_491521501973_item	2562872	et	4	main
mind	doc_491521501973_item	2562873	et	4	main
ma	doc_491521501971_item	2562370	et	3	main
et	doc_491521501971_item	2562372	et	3	main
ei	doc_491521501971_item	2562384	et	4	main
kord	doc_491521501971_item	2562387	et	4	main
päris	doc_491521501971_item	2562388	et	4	main
elada	doc_491521501971_item	2562408	et	3	main
kõige	doc_491521501971_item	2562424	et	4	main
järgin	doc_491521501971_item	2562426	et	3	main
ei	doc_491521501971_item	2562439	et	4	main
ma	doc_491521501971_item	2562440	et	3	main
iseloom	doc_491521501971_item	2562463	et	3	main
et	doc_491521501971_item	2562481	et	3	main
asjad	doc_491521501971_item	2562486	et	3	main
lapsepõlves	doc_491521501972_item	2562495	et	4	main
saada	doc_491521501972_item	2562498	et	4	main
luurajaks	doc_491521501972_item	2562499	et	4	main
mind	doc_491521501972_item	2562500	et	4	main
köitis	doc_491521501972_item	2562501	et	3	main
ka	doc_491521501972_item	2562502	et	3	main
väga	doc_491521501972_item	2562503	et	3	main
tolleaegne	doc_491521501972_item	2562504	et	3	main
dessantväelasest	doc_491521501972_item	2562505	et	3	main
tehtud	doc_491521501972_item	2562506	et	4	main
film	doc_491521501972_item	2562507	et	3	main
sööst	doc_491521501972_item	2562508	et	3	main
ja	doc_491521501972_item	2562510	et	3	main
tahtsin	doc_491521501972_item	2562511	et	3	main
saada	doc_491521501972_item	2562512	et	4	main
eritsooni	doc_491521501972_item	2562509	et	4	main
samasuguseks	doc_491521501972_item	2562513	et	4	main
nagu	doc_491521501972_item	2562514	et	3	main
nemad	doc_491521501972_item	2562515	et	3	main
aga	doc_491521501972_item	2562516	et	3	main
hiljem	doc_491521501972_item	2562517	et	3	main
huvid	doc_491521501972_item	2562518	et	3	main
muutusid	doc_491521501972_item	2562519	et	4	main
mida	doc_491521501972_item	2562520	et	4	main
peate	doc_491521501972_item	2562521	et	4	main
elu	doc_491521501972_item	2562523	et	4	main
reeturlus	doc_491521501972_item	2562538	et	4	main
ma	doc_491521501972_item	2562541	et	3	main
üldiselt	doc_491521501972_item	2562543	et	4	main
ei	doc_491521501972_item	2562544	et	4	main
välja	doc_491521501972_item	2562547	et	4	main
petnud	doc_491521501972_item	2562552	et	4	main
selliste	doc_491521501972_item	2562556	et	4	main
inimestega	doc_491521501972_item	2562557	et	3	main
kokku	doc_491521501972_item	2562558	et	3	main
teie	doc_491521501972_item	2562563	et	4	main
ilmselt	doc_491521501972_item	2562567	et	4	main
ainult	doc_491521501972_item	2562593	et	4	main
olevad	doc_491521501972_item	2562598	et	4	main
inimesed	doc_491521501972_item	2562599	et	3	main
sest	doc_491521501972_item	2562600	et	4	main
raha	doc_491521501972_item	2562603	et	4	main
on	doc_491521501972_item	2562610	et	4	main
probleeme	doc_491521501972_item	2562612	et	3	main
raha	doc_491521501972_item	2562619	et	4	main
kommunaalkulude	doc_491521501972_item	2562620	et	3	main
lugeda	doc_491521501972_item	2562629	et	3	main
tahaks	doc_491521501972_item	2562634	et	3	main
valitud	doc_491521501972_item	2562638	et	4	main
erialal	doc_491521501972_item	2562639	et	3	main
õigusteaduses	doc_491521501972_item	2562640	et	3	main
loodan	doc_491521501972_item	2562527	et	3	main
valetamine	doc_491521501972_item	2562540	et	4	main
küll	doc_491521501972_item	2562542	et	4	main
et	doc_491521501972_item	2562548	et	3	main
puutumast	doc_491521501972_item	2562559	et	4	main
mis	doc_491521501972_item	2562560	et	4	main
see	doc_491521501972_item	2562569	et	3	main
minu	doc_491521501972_item	2562570	et	3	main
praegune	doc_491521501972_item	2562571	et	3	main
võitlus	doc_491521501972_item	2562572	et	3	main
selle	doc_491521501972_item	2562573	et	4	main
nimel	doc_491521501972_item	2562574	et	3	main
et	doc_491521501972_item	2562575	et	3	main
kohlta-järve	doc_491521501972_item	2562576	et	4	main
õhk	doc_491521501972_item	2562577	et	3	main
puhtaks	doc_491521501972_item	2562578	et	3	main
saaks	doc_491521501972_item	2562579	et	3	main
kellel	doc_491521501972_item	2562580	et	4	main
on	doc_491521501972_item	2562581	et	4	main
tänapäeva	doc_491521501972_item	2562582	et	4	main
eestis	doc_491521501972_item	2562583	et	3	main
hea	doc_491521501972_item	2562584	et	4	main
elada	doc_491521501972_item	2562585	et	3	main
raske	doc_491521501972_item	2562586	et	4	main
öelda	doc_491521501972_item	2562587	et	4	main
kuid	doc_491521501972_item	2562588	et	4	main
kindlasti	doc_491521501972_item	2562589	et	3	main
ei	doc_491521501972_item	2562590	et	4	main
ole	doc_491521501972_item	2562591	et	4	main
need	doc_491521501972_item	2562592	et	3	main
ootab	doc_491521501972_item	2562531	et	3	main
ees	doc_491521501972_item	2562534	et	4	main
ja	doc_491521501972_item	2562539	et	3	main
inimestele	doc_491521501972_item	2562546	et	3	main
on	doc_491521501972_item	2562561	et	4	main
ongi	doc_491521501972_item	2562568	et	4	main
rikkad	doc_491521501972_item	2562594	et	4	main
ja	doc_491521501972_item	2562595	et	3	main
käes	doc_491521501972_item	2562607	et	4	main
rohkem	doc_491521501972_item	2562609	et	4	main
mille	doc_491521501972_item	2562613	et	3	main
peale	doc_491521501972_item	2562614	et	4	main
kulub	doc_491521501972_item	2562615	et	3	main
juures	doc_491521501972_item	2562597	et	4	main
rohkem	doc_491521501972_item	2562602	et	4	main
on	doc_491521501972_item	2562606	et	4	main
rohkem	doc_491521501972_item	2562618	et	4	main
targemaks	doc_491521501972_item	2562632	et	4	main
olla	doc_491521501972_item	2562647	et	3	main
koos	doc_491521501972_item	2562648	et	4	main
vasknarva	doc_491521501972_item	2562661	et	4	main
kuna	doc_491521501972_item	2562667	et	3	main
võimalikult	doc_491521501972_item	2562671	et	4	main
et	doc_491521501972_item	2562677	et	3	main
paremini	doc_491521501972_item	2562685	et	4	main
kuid	doc_491521501972_item	2562687	et	4	main
ma	doc_491521501972_item	2562688	et	3	main
see	doc_491521501972_item	2562728	et	3	main
mida	doc_491521501972_item	2562729	et	4	main
ma	doc_491521501972_item	2562730	et	3	main
peale	doc_491521501972_item	2562744	et	4	main
sündisid	doc_491521501972_item	2562770	et	4	main
ei	doc_491521501972_item	2562778	et	4	main
usu	doc_491521501972_item	2562781	et	4	main
nendest	doc_491521501972_item	2562785	et	4	main
see	doc_491521501972_item	2562786	et	3	main
asi	doc_491521501972_item	2562790	et	4	main
intervjueeritav	doc_491521501972_item	2562795	et	4	main
mees	doc_491521501972_item	2562797	et	4	main
ja	doc_491521501972_item	2562825	et	3	main
saab	doc_491521501972_item	2562827	et	3	main
aidata	doc_491521501972_item	2562829	et	4	main
4	doc_491521501972_item	2562830	et	2	main
minu	doc_491521501972_item	2562831	et	3	main
arvates	doc_491521501972_item	2562832	et	4	main
kohtus	doc_491521501972_item	2562836	et	4	main
tema	doc_491521501972_item	2562838	et	4	main
tööharjumused	doc_491521501972_item	2562839	et	3	main
tugevad	doc_491521501972_item	2562850	et	4	main
küljed	doc_491521501972_item	2562851	et	3	main
on	doc_491521501972_item	2562852	et	4	main
jätta	doc_491521501972_item	2562861	et	3	main
küsimust	doc_491521501973_item	2562865	et	4	main
tahtsite	doc_491521501973_item	2562867	et	3	main
saada	doc_491521501973_item	2562869	et	4	main
unistasin	doc_491521501973_item	2562870	et	3	main
sööst	doc_491521501973_item	2562881	et	3	main
tahtsin	doc_491521501973_item	2562884	et	3	main
samasuguseks	doc_491521501973_item	2562886	et	4	main
muutusid	doc_491521501973_item	2562892	et	4	main
mida	doc_491521501973_item	2562893	et	4	main
saavutuseks	doc_491521501973_item	2562898	et	4	main
ma	doc_491521501973_item	2562899	et	3	main
saavutus	doc_491521501973_item	2562903	et	4	main
mind	doc_491521501973_item	2562905	et	4	main
välja	doc_491521501973_item	2562920	et	4	main
mind	doc_491521501973_item	2562924	et	4	main
inimestega	doc_491521501973_item	2562930	et	3	main
ilmselt	doc_491521501973_item	2562940	et	4	main
ongi	doc_491521501973_item	2562941	et	4	main
see	doc_491521501973_item	2562942	et	3	main
minu	doc_491521501973_item	2562943	et	3	main
praegune	doc_491521501973_item	2562944	et	3	main
võitlus	doc_491521501973_item	2562945	et	3	main
õhk	doc_491521501973_item	2562950	et	3	main
saaks	doc_491521501973_item	2562952	et	3	main
ainult	doc_491521501973_item	2562966	et	4	main
ja	doc_491521501973_item	2562968	et	3	main
mida	doc_491521501973_item	2562974	et	4	main
rohkem	doc_491521501973_item	2562975	et	4	main
raha	doc_491521501973_item	2562976	et	4	main
ja	doc_491521501973_item	2562977	et	3	main
võimu	doc_491521501973_item	2562978	et	4	main
probleeme	doc_491521501973_item	2562985	et	3	main
mida	doc_491521501972_item	2562622	et	4	main
osta	doc_491521501972_item	2562624	et	4	main
saada	doc_491521501972_item	2562631	et	4	main
tõsta	doc_491521501972_item	2562635	et	4	main
taset	doc_491521501972_item	2562637	et	3	main
jaoks	doc_491521501972_item	2562644	et	4	main
milline	doc_491521501972_item	2562652	et	3	main
mille	doc_491521501972_item	2562662	et	3	main
siis	doc_491521501972_item	2562674	et	3	main
alati	doc_491521501972_item	2562676	et	4	main
oleks	doc_491521501972_item	2562678	et	3	main
natukene	doc_491521501972_item	2562679	et	4	main
valmistuda	doc_491521501972_item	2562686	et	3	main
olen	doc_491521501972_item	2562689	et	3	main
loomult	doc_491521501972_item	2562690	et	3	main
öökulli	doc_491521501972_item	2562691	et	4	main
tüüpi	doc_491521501972_item	2562692	et	4	main
inimene	doc_491521501972_item	2562693	et	3	main
ja	doc_491521501972_item	2562694	et	3	main
seetõttu	doc_491521501972_item	2562695	et	3	main
olen	doc_491521501972_item	2562696	et	3	main
harjunud	doc_491521501972_item	2562697	et	4	main
tööd	doc_491521501972_item	2562698	et	4	main
tegema	doc_491521501972_item	2562699	et	3	main
ka	doc_491521501972_item	2562700	et	3	main
hilistel	doc_491521501972_item	2562701	et	3	main
öötundidel	doc_491521501972_item	2562702	et	3	main
millist	doc_491521501972_item	2562703	et	3	main
omadust	doc_491521501972_item	2562704	et	4	main
peate	doc_491521501972_item	2562705	et	4	main
oma	doc_491521501972_item	2562706	et	4	main
tugevaimaks	doc_491521501972_item	2562707	et	4	main
küljeks	doc_491521501972_item	2562708	et	3	main
ma	doc_491521501972_item	2562709	et	3	main
arvan	doc_491521501972_item	2562710	et	3	main
et	doc_491521501972_item	2562711	et	3	main
see	doc_491521501972_item	2562712	et	3	main
on	doc_491521501972_item	2562713	et	4	main
järjekindlus	doc_491521501972_item	2562714	et	4	main
viia	doc_491521501972_item	2562715	et	3	main
asjad	doc_491521501972_item	2562716	et	3	main
lõpuni	doc_491521501972_item	2562717	et	3	main
isegi	doc_491521501972_item	2562718	et	4	main
siis	doc_491521501972_item	2562719	et	3	main
kui	doc_491521501972_item	2562720	et	3	main
päris	doc_491521501972_item	2562727	et	4	main
oma	doc_491521501972_item	2562738	et	4	main
ettevõtmisi	doc_491521501972_item	2562739	et	3	main
pooleli	doc_491521501972_item	2562740	et	3	main
jätta	doc_491521501972_item	2562741	et	3	main
millises	doc_491521501972_item	2562742	et	3	main
mis	doc_491521501972_item	2562641	et	4	main
parim	doc_491521501972_item	2562645	et	4	main
puhkus	doc_491521501972_item	2562646	et	3	main
looduses	doc_491521501972_item	2562651	et	4	main
jaoks	doc_491521501972_item	2562663	et	4	main
ei	doc_491521501972_item	2562664	et	4	main
tahan	doc_491521501972_item	2562668	et	3	main
aidata	doc_491521501972_item	2562673	et	4	main
tundub	doc_491521501972_item	2562675	et	3	main
rohkem	doc_491521501972_item	2562680	et	4	main
aega	doc_491521501972_item	2562681	et	4	main
siis	doc_491521501972_item	2562682	et	3	main
jõuaks	doc_491521501972_item	2562683	et	3	main
ole	doc_491521501972_item	2562724	et	4	main
alguses	doc_491521501972_item	2562731	et	4	main
ma	doc_491521501972_item	2562748	et	3	main
teinud	doc_491521501972_item	2562752	et	4	main
tööd	doc_491521501972_item	2562753	et	4	main
siiski	doc_491521501972_item	2562759	et	4	main
on	doc_491521501972_item	2562760	et	4	main
eestis	doc_491521501972_item	2562761	et	3	main
mul	doc_491521501972_item	2562762	et	3	main
kõige	doc_491521501972_item	2562763	et	4	main
öeldut	doc_491521501972_item	2562768	et	4	main
seal	doc_491521501972_item	2562771	et	4	main
elama	doc_491521501972_item	2562774	et	3	main
ma	doc_491521501972_item	2562779	et	3	main
neid	doc_491521501972_item	2562782	et	4	main
ega	doc_491521501972_item	2562783	et	3	main
huvitu	doc_491521501972_item	2562784	et	4	main
et	doc_491521501972_item	2562794	et	3	main
mees	doc_491521501972_item	2562821	et	4	main
hea	doc_491521501972_item	2562823	et	4	main
5	doc_491521501972_item	2562837	et	2	main
on	doc_491521501972_item	2562840	et	4	main
et	doc_491521501972_item	2562841	et	3	main
ta	doc_491521501972_item	2562842	et	4	main
kombeks	doc_491521501972_item	2562857	et	4	main
küsimust	doc_491521501973_item	2562863	et	4	main
tehtud	doc_491521501973_item	2562879	et	4	main
ja	doc_491521501973_item	2562883	et	3	main
oma	doc_491521501973_item	2562895	et	4	main
elu	doc_491521501973_item	2562896	et	4	main
suurimaks	doc_491521501973_item	2562897	et	4	main
selline	doc_491521501973_item	2562902	et	4	main
ootab	doc_491521501973_item	2562904	et	3	main
ärritab	doc_491521501973_item	2562910	et	3	main
reeturlus	doc_491521501973_item	2562911	et	4	main
ja	doc_491521501973_item	2562912	et	3	main
inimestele	doc_491521501973_item	2562919	et	3	main
on	doc_491521501973_item	2562923	et	4	main
petnud	doc_491521501973_item	2562925	et	4	main
kuid	doc_491521501973_item	2562926	et	4	main
hoidun	doc_491521501973_item	2562927	et	3	main
edaspidi	doc_491521501973_item	2562928	et	3	main
elu	doc_491521501973_item	2562937	et	4	main
pööraseim	doc_491521501973_item	2562938	et	4	main
tegu	doc_491521501973_item	2562939	et	4	main
et	doc_491521501973_item	2562948	et	3	main
raske	doc_491521501973_item	2562959	et	4	main
rohkem	doc_491521501973_item	2562982	et	4	main
peale	doc_491521501973_item	2562987	et	4	main
kõige	doc_491521501973_item	2562990	et	4	main
raha	doc_491521501973_item	2562992	et	4	main
kommunaalkulude	doc_491521501973_item	2562993	et	3	main
koos	doc_491521501973_item	2563021	et	4	main
kusagil	doc_491521501973_item	2563023	et	3	main
aega	doc_491521501973_item	2563039	et	4	main
kuna	doc_491521501973_item	2563040	et	3	main
kohtuasjades	doc_491521501973_item	2563042	et	3	main
aidata	doc_491521501973_item	2563046	et	4	main
alati	doc_491521501973_item	2563049	et	4	main
ja	doc_491521501973_item	2563067	et	3	main
harjunud	doc_491521501973_item	2563070	et	4	main
tegema	doc_491521501973_item	2563072	et	3	main
ka	doc_491521501973_item	2563073	et	3	main
omadust	doc_491521501973_item	2563077	et	4	main
peate	doc_491521501973_item	2563078	et	4	main
et	doc_491521501973_item	2563084	et	3	main
asjad	doc_491521501973_item	2563089	et	3	main
isegi	doc_491521501973_item	2563091	et	4	main
kui	doc_491521501973_item	2563093	et	3	main
karjamaa	doc_491521501972_item	2562660	et	4	main
aega	doc_491521501972_item	2562666	et	4	main
inimesi	doc_491521501972_item	2562670	et	4	main
veelgi	doc_491521501972_item	2562684	et	4	main
tulemus	doc_491521501972_item	2562722	et	3	main
lootnud	doc_491521501972_item	2562733	et	4	main
ole	doc_491521501972_item	2562735	et	4	main
mul	doc_491521501972_item	2562736	et	3	main
kombeks	doc_491521501972_item	2562737	et	4	main
elada	doc_491521501972_item	2562747	et	3	main
elanud	doc_491521501972_item	2562750	et	4	main
nii	doc_491521501972_item	2562754	et	3	main
kuid	doc_491521501972_item	2562758	et	4	main
kus	doc_491521501972_item	2562769	et	3	main
peab	doc_491521501972_item	2562772	et	4	main
horoskoope	doc_491521501972_item	2562777	et	3	main
ole	doc_491521501972_item	2562788	et	4	main
tõsine	doc_491521501972_item	2562789	et	4	main
arvan	doc_491521501972_item	2562793	et	3	main
on	doc_491521501972_item	2562796	et	4	main
2	doc_491521501972_item	2562798	et	2	main
see	doc_491521501972_item	2562799	et	3	main
mees	doc_491521501972_item	2562800	et	4	main
on	doc_491521501972_item	2562801	et	4	main
lihtsalt	doc_491521501972_item	2562802	et	4	main
kohtla-järve	doc_491521501972_item	2562803	et	4	main
elanik	doc_491521501972_item	2562804	et	3	main
ja	doc_491521501972_item	2562805	et	3	main
või	doc_491521501972_item	2562806	et	4	main
ekoloog	doc_491521501972_item	2562807	et	4	main
ta	doc_491521501972_item	2562808	et	4	main
on	doc_491521501972_item	2562809	et	4	main
eesti	doc_491521501972_item	2562810	et	4	main
kodanik	doc_491521501972_item	2562811	et	3	main
elukutselt	doc_491521501972_item	2562812	et	4	main
ta	doc_491521501972_item	2562813	et	4	main
on	doc_491521501972_item	2562814	et	4	main
kohtunik	doc_491521501972_item	2562815	et	3	main
3	doc_491521501972_item	2562816	et	2	main
mina	doc_491521501972_item	2562817	et	4	main
arvan	doc_491521501972_item	2562818	et	3	main
et	doc_491521501972_item	2562819	et	3	main
see	doc_491521501972_item	2562820	et	3	main
riigis	doc_491521501972_item	2562743	et	3	main
ja	doc_491521501972_item	2562751	et	3	main
venemaal	doc_491521501972_item	2562755	et	4	main
kui	doc_491521501972_item	2562756	et	3	main
saksamaal	doc_491521501972_item	2562757	et	4	main
parem	doc_491521501972_item	2562764	et	4	main
järgin	doc_491521501972_item	2562765	et	3	main
oma	doc_491521501972_item	2562766	et	4	main
ka	doc_491521501972_item	2562773	et	3	main
kas	doc_491521501972_item	2562775	et	3	main
loete	doc_491521501972_item	2562776	et	4	main
mina	doc_491521501972_item	2562792	et	4	main
on	doc_491521501972_item	2562822	et	4	main
inimene	doc_491521501972_item	2562824	et	3	main
võiks	doc_491521501972_item	2562834	et	4	main
töötada	doc_491521501972_item	2562835	et	3	main
teeb	doc_491521501972_item	2562843	et	3	main
tema	doc_491521501972_item	2562849	et	4	main
selles	doc_491521501972_item	2562853	et	4	main
et	doc_491521501972_item	2562854	et	3	main
tal	doc_491521501972_item	2562855	et	3	main
13	doc_491521501973_item	2562862	et	2	main
kelleks	doc_491521501973_item	2562866	et	4	main
lapsepõlves	doc_491521501973_item	2562868	et	4	main
dessantväelasest	doc_491521501973_item	2562878	et	3	main
peate	doc_491521501973_item	2562894	et	4	main
loodan	doc_491521501973_item	2562900	et	3	main
veel	doc_491521501973_item	2562906	et	4	main
ees	doc_491521501973_item	2562907	et	4	main
valetamine	doc_491521501973_item	2562913	et	4	main
ma	doc_491521501973_item	2562914	et	3	main
küll	doc_491521501973_item	2562915	et	4	main
ütle	doc_491521501973_item	2562918	et	4	main
puutumast	doc_491521501973_item	2562932	et	4	main
selle	doc_491521501973_item	2562946	et	4	main
nimel	doc_491521501973_item	2562947	et	3	main
on	doc_491521501973_item	2562954	et	4	main
eestis	doc_491521501973_item	2562956	et	3	main
hea	doc_491521501973_item	2562957	et	4	main
elada	doc_491521501973_item	2562958	et	3	main
ole	doc_491521501973_item	2562964	et	4	main
need	doc_491521501973_item	2562965	et	3	main
võimu	doc_491521501973_item	2562969	et	4	main
juures	doc_491521501973_item	2562970	et	4	main
olevad	doc_491521501973_item	2562971	et	4	main
inimesed	doc_491521501973_item	2562972	et	3	main
on	doc_491521501973_item	2562983	et	4	main
ka	doc_491521501973_item	2562984	et	3	main
alajõe	doc_491521501973_item	2563032	et	3	main
vasknarva	doc_491521501973_item	2563034	et	4	main
mille	doc_491521501973_item	2563035	et	3	main
jaoks	doc_491521501973_item	2563036	et	4	main
öökulli	doc_491521501973_item	2563064	et	4	main
olen	doc_491521501973_item	2563069	et	3	main
ma	doc_491521501973_item	2563082	et	3	main
on	doc_491521501973_item	2563086	et	4	main
kord	doc_491521501973_item	2563099	et	4	main
olin	doc_491521501973_item	2563105	et	3	main
lootnud	doc_491521501973_item	2563106	et	4	main
ma	doc_491521501973_item	2563121	et	3	main
isa	doc_491521501973_item	2563140	et	4	main
sündisid	doc_491521501973_item	2563143	et	4	main
ei	doc_491521501973_item	2563153	et	4	main
ole	doc_491521501973_item	2563161	et	4	main
tõsine	doc_491521501973_item	2563162	et	4	main
asi	doc_491521501973_item	2563163	et	4	main
on	doc_491521501973_item	2563169	et	4	main
ja	doc_491521501973_item	2563178	et	3	main
kõik	doc_491521501973_item	2563180	et	4	main
lõpuni	doc_491521501973_item	2563184	et	3	main
ja	doc_491521501973_item	2563191	et	3	main
ta	doc_491521501972_item	2562833	et	4	main
tööd	doc_491521501972_item	2562844	et	4	main
ka	doc_491521501972_item	2562845	et	3	main
hilistel	doc_491521501972_item	2562846	et	3	main
öötundidel	doc_491521501972_item	2562847	et	3	main
ole	doc_491521501972_item	2562856	et	4	main
13	doc_491521501973_item	2562864	et	2	main
saada	doc_491521501973_item	2562871	et	4	main
film	doc_491521501973_item	2562880	et	3	main
saada	doc_491521501973_item	2562885	et	4	main
nagu	doc_491521501973_item	2562887	et	3	main
nemad	doc_491521501973_item	2562888	et	3	main
aga	doc_491521501973_item	2562889	et	3	main
hiljem	doc_491521501973_item	2562890	et	3	main
huvid	doc_491521501973_item	2562891	et	3	main
mis	doc_491521501973_item	2562908	et	4	main
üldiselt	doc_491521501973_item	2562916	et	4	main
et	doc_491521501973_item	2562921	et	3	main
selliste	doc_491521501973_item	2562929	et	4	main
on	doc_491521501973_item	2562934	et	4	main
teie	doc_491521501973_item	2562936	et	4	main
kohlta-järve	doc_491521501973_item	2562949	et	4	main
kellel	doc_491521501973_item	2562953	et	4	main
tänapäeva	doc_491521501973_item	2562955	et	4	main
rikkad	doc_491521501973_item	2562967	et	4	main
käes	doc_491521501973_item	2562980	et	4	main
seda	doc_491521501973_item	2562981	et	3	main
kulub	doc_491521501973_item	2562988	et	3	main
peale	doc_491521501973_item	2562994	et	4	main
ida-virumaal	doc_491521501973_item	2563029	et	4	main
peipsi-äärne	doc_491521501973_item	2563030	et	3	main
kant	doc_491521501973_item	2563031	et	3	main
ei	doc_491521501973_item	2563037	et	4	main
tahan	doc_491521501973_item	2563041	et	3	main
võimalikult	doc_491521501973_item	2563044	et	4	main
siis	doc_491521501973_item	2563047	et	3	main
et	doc_491521501973_item	2563050	et	3	main
natukene	doc_491521501973_item	2563052	et	4	main
rohkem	doc_491521501973_item	2563053	et	4	main
kuid	doc_491521501973_item	2563060	et	4	main
inimene	doc_491521501973_item	2563066	et	3	main
seetõttu	doc_491521501973_item	2563068	et	3	main
tööd	doc_491521501973_item	2563071	et	4	main
hilistel	doc_491521501973_item	2563074	et	3	main
öötundidel	doc_491521501973_item	2563075	et	3	main
millist	doc_491521501973_item	2563076	et	3	main
arvan	doc_491521501973_item	2563083	et	3	main
järjekindlus	doc_491521501973_item	2563087	et	4	main
siis	doc_491521501973_item	2563092	et	3	main
tulemus	doc_491521501973_item	2563095	et	3	main
iga	doc_491521501973_item	2563098	et	4	main
ma	doc_491521501973_item	2563103	et	3	main
ja	doc_491521501973_item	2563124	et	3	main
nii	doc_491521501973_item	2563127	et	3	main
eestis	doc_491521501973_item	2563134	et	3	main
mul	doc_491521501973_item	2563135	et	3	main
kõige	doc_491521501973_item	2563136	et	4	main
öeldut	doc_491521501973_item	2563141	et	4	main
kus	doc_491521501973_item	2563142	et	3	main
horoskoope	doc_491521501973_item	2563150	et	3	main
usu	doc_491521501973_item	2563154	et	4	main
kirjutatakse	doc_491521501973_item	2563167	et	3	main
reeturlus	doc_491521501973_item	2563177	et	4	main
järjekindlus	doc_491521501973_item	2563181	et	4	main
köitis	doc_491521501974_item	2563221	et	3	main
tehtud	doc_491521501974_item	2563226	et	4	main
sööst	doc_491521501974_item	2563228	et	3	main
samasuguseks	doc_491521501974_item	2563233	et	4	main
aga	doc_491521501974_item	2563236	et	3	main
elu	doc_491521501974_item	2563243	et	4	main
saavutuseks	doc_491521501974_item	2563245	et	4	main
selline	doc_491521501974_item	2563249	et	4	main
ootab	doc_491521501974_item	2563251	et	3	main
mind	doc_491521501974_item	2563252	et	4	main
ärritab	doc_491521501974_item	2563257	et	3	main
reeturlus	doc_491521501974_item	2563258	et	4	main
ja	doc_491521501974_item	2563259	et	3	main
välja	doc_491521501974_item	2563267	et	4	main
nad	doc_491521501974_item	2563269	et	3	main
on	doc_491521501974_item	2563270	et	4	main
mind	doc_491521501974_item	2563271	et	4	main
inimestega	doc_491521501974_item	2563277	et	3	main
mis	doc_491521501974_item	2563280	et	4	main
on	doc_491521501974_item	2563281	et	4	main
olnud	doc_491521501974_item	2563282	et	4	main
pööraseim	doc_491521501974_item	2563285	et	4	main
ongi	doc_491521501974_item	2563288	et	4	main
köitis	doc_491521501973_item	2562874	et	3	main
ka	doc_491521501973_item	2562875	et	3	main
väga	doc_491521501973_item	2562876	et	3	main
tolleaegne	doc_491521501973_item	2562877	et	3	main
eritsooni	doc_491521501973_item	2562882	et	4	main
et	doc_491521501973_item	2562901	et	3	main
teid	doc_491521501973_item	2562909	et	4	main
ei	doc_491521501973_item	2562917	et	4	main
nad	doc_491521501973_item	2562922	et	3	main
kokku	doc_491521501973_item	2562931	et	3	main
mis	doc_491521501973_item	2562933	et	4	main
olnud	doc_491521501973_item	2562935	et	4	main
puhtaks	doc_491521501973_item	2562951	et	3	main
öelda	doc_491521501973_item	2562960	et	4	main
kuid	doc_491521501973_item	2562961	et	4	main
kindlasti	doc_491521501973_item	2562962	et	3	main
ei	doc_491521501973_item	2562963	et	4	main
sest	doc_491521501973_item	2562973	et	4	main
on	doc_491521501973_item	2562979	et	4	main
mille	doc_491521501973_item	2562986	et	3	main
teil	doc_491521501973_item	2562989	et	4	main
rohkem	doc_491521501973_item	2562991	et	4	main
mida	doc_491521501973_item	2562995	et	4	main
tahaksite	doc_491521501973_item	2562996	et	3	main
osta	doc_491521501973_item	2562997	et	4	main
ma	doc_491521501973_item	2562998	et	3	main
tahan	doc_491521501973_item	2562999	et	3	main
väga	doc_491521501973_item	2563000	et	3	main
palju	doc_491521501973_item	2563001	et	4	main
lugeda	doc_491521501973_item	2563002	et	3	main
et	doc_491521501973_item	2563003	et	3	main
saada	doc_491521501973_item	2563004	et	4	main
targemaks	doc_491521501973_item	2563005	et	4	main
eelkõige	doc_491521501973_item	2563006	et	3	main
tahaks	doc_491521501973_item	2563007	et	3	main
tõsta	doc_491521501973_item	2563008	et	4	main
oma	doc_491521501973_item	2563009	et	4	main
taset	doc_491521501973_item	2563010	et	3	main
valitud	doc_491521501973_item	2563011	et	4	main
erialal	doc_491521501973_item	2563012	et	3	main
õigusteaduses	doc_491521501973_item	2563013	et	3	main
mis	doc_491521501973_item	2563014	et	4	main
on	doc_491521501973_item	2563015	et	4	main
teie	doc_491521501973_item	2563016	et	4	main
jaoks	doc_491521501973_item	2563017	et	4	main
parim	doc_491521501973_item	2563018	et	4	main
puhkus	doc_491521501973_item	2563019	et	3	main
olla	doc_491521501973_item	2563020	et	3	main
perega	doc_491521501973_item	2563022	et	3	main
looduses	doc_491521501973_item	2563024	et	4	main
milline	doc_491521501973_item	2563025	et	3	main
on	doc_491521501973_item	2563026	et	4	main
teie	doc_491521501973_item	2563027	et	4	main
lemmikkoht	doc_491521501973_item	2563028	et	3	main
hästi	doc_491521501973_item	2563045	et	3	main
paremini	doc_491521501973_item	2563058	et	4	main
valmistuda	doc_491521501973_item	2563059	et	3	main
ma	doc_491521501973_item	2563061	et	3	main
olen	doc_491521501973_item	2563062	et	3	main
loomult	doc_491521501973_item	2563063	et	3	main
see	doc_491521501973_item	2563085	et	3	main
viia	doc_491521501973_item	2563088	et	3	main
see	doc_491521501973_item	2563094	et	3	main
päris	doc_491521501973_item	2563100	et	4	main
karjamaa	doc_491521501973_item	2563033	et	4	main
jätku	doc_491521501973_item	2563038	et	4	main
inimesi	doc_491521501973_item	2563043	et	4	main
tundub	doc_491521501973_item	2563048	et	3	main
oleks	doc_491521501973_item	2563051	et	3	main
aega	doc_491521501973_item	2563054	et	4	main
siis	doc_491521501973_item	2563055	et	3	main
jõuaks	doc_491521501973_item	2563056	et	3	main
veelgi	doc_491521501973_item	2563057	et	4	main
tüüpi	doc_491521501973_item	2563065	et	4	main
oma	doc_491521501973_item	2563079	et	4	main
tugevaimaks	doc_491521501973_item	2563080	et	4	main
küljeks	doc_491521501973_item	2563081	et	3	main
lõpuni	doc_491521501973_item	2563090	et	3	main
mida	doc_491521501973_item	2563102	et	4	main
ei	doc_491521501973_item	2563107	et	4	main
ole	doc_491521501973_item	2563108	et	4	main
mul	doc_491521501973_item	2563109	et	3	main
kombeks	doc_491521501973_item	2563110	et	4	main
jätta	doc_491521501973_item	2563114	et	3	main
millises	doc_491521501973_item	2563115	et	3	main
riigis	doc_491521501973_item	2563116	et	3	main
peale	doc_491521501973_item	2563117	et	4	main
eesti	doc_491521501973_item	2563118	et	4	main
tahaksite	doc_491521501973_item	2563119	et	3	main
elada	doc_491521501973_item	2563120	et	3	main
olen	doc_491521501973_item	2563122	et	3	main
tööd	doc_491521501973_item	2563126	et	4	main
venemaal	doc_491521501973_item	2563128	et	4	main
kui	doc_491521501973_item	2563129	et	3	main
saksamaal	doc_491521501973_item	2563130	et	4	main
parem	doc_491521501973_item	2563137	et	4	main
seal	doc_491521501973_item	2563144	et	4	main
ei	doc_491521501973_item	2563151	et	4	main
huvitu	doc_491521501973_item	2563157	et	4	main
nendest	doc_491521501973_item	2563158	et	4	main
see	doc_491521501973_item	2563159	et	3	main
iseloomusta	doc_491521501973_item	2563164	et	4	main
inimest	doc_491521501973_item	2563165	et	3	main
teda	doc_491521501973_item	2563171	et	4	main
teda	doc_491521501973_item	2563185	et	4	main
väga	doc_491521501974_item	2563223	et	3	main
dessantväelasest	doc_491521501974_item	2563225	et	3	main
film	doc_491521501974_item	2563227	et	3	main
saada	doc_491521501974_item	2563232	et	4	main
oma	doc_491521501974_item	2563242	et	4	main
ees	doc_491521501974_item	2563254	et	4	main
küll	doc_491521501974_item	2563262	et	4	main
inimestele	doc_491521501974_item	2563266	et	3	main
petnud	doc_491521501974_item	2563272	et	4	main
kokku	doc_491521501974_item	2563278	et	3	main
elu	doc_491521501974_item	2563284	et	4	main
ilmselt	doc_491521501974_item	2563287	et	4	main
see	doc_491521501974_item	2563289	et	3	main
hea	doc_491521501974_item	2563304	et	4	main
elada	doc_491521501974_item	2563305	et	3	main
raske	doc_491521501974_item	2563306	et	4	main
ei	doc_491521501974_item	2563310	et	4	main
need	doc_491521501974_item	2563312	et	3	main
on	doc_491521501974_item	2563330	et	4	main
ka	doc_491521501974_item	2563331	et	3	main
probleeme	doc_491521501974_item	2563332	et	3	main
mille	doc_491521501974_item	2563333	et	3	main
peale	doc_491521501974_item	2563341	et	4	main
ma	doc_491521501974_item	2563345	et	3	main
väga	doc_491521501974_item	2563347	et	3	main
saada	doc_491521501974_item	2563351	et	4	main
targemaks	doc_491521501974_item	2563352	et	4	main
eelkõige	doc_491521501974_item	2563353	et	3	main
tahaks	doc_491521501974_item	2563354	et	3	main
tõsta	doc_491521501974_item	2563355	et	4	main
mis	doc_491521501974_item	2563361	et	4	main
teie	doc_491521501974_item	2563363	et	4	main
aega	doc_491521501974_item	2563401	et	4	main
paremini	doc_491521501974_item	2563405	et	4	main
ei	doc_491521501973_item	2563096	et	4	main
ole	doc_491521501973_item	2563097	et	4	main
alguses	doc_491521501973_item	2563104	et	4	main
oma	doc_491521501973_item	2563111	et	4	main
ettevõtmisi	doc_491521501973_item	2563112	et	3	main
pooleli	doc_491521501973_item	2563113	et	3	main
see	doc_491521501973_item	2563101	et	3	main
elanud	doc_491521501973_item	2563123	et	4	main
kuid	doc_491521501973_item	2563131	et	4	main
järgin	doc_491521501973_item	2563138	et	3	main
oma	doc_491521501973_item	2563139	et	4	main
peab	doc_491521501973_item	2563145	et	4	main
ka	doc_491521501973_item	2563146	et	3	main
elama	doc_491521501973_item	2563147	et	3	main
kas	doc_491521501973_item	2563148	et	3	main
ma	doc_491521501973_item	2563152	et	3	main
neid	doc_491521501973_item	2563155	et	4	main
ega	doc_491521501973_item	2563156	et	3	main
mees	doc_491521501973_item	2563170	et	4	main
elukutselt	doc_491521501973_item	2563172	et	4	main
jurist	doc_491521501973_item	2563174	et	3	main
teid	doc_491521501973_item	2563175	et	4	main
äriitab	doc_491521501973_item	2563176	et	4	main
valetamine	doc_491521501973_item	2563179	et	4	main
asjad	doc_491521501973_item	2563183	et	3	main
ta	doc_491521501973_item	2563187	et	4	main
tegema	doc_491521501973_item	2563189	et	3	main
hilistel	doc_491521501973_item	2563192	et	3	main
ta	doc_491521501973_item	2563195	et	4	main
viia	doc_491521501973_item	2563196	et	3	main
tahtsin	doc_491521501974_item	2563231	et	3	main
nemad	doc_491521501974_item	2563235	et	3	main
muutusid	doc_491521501974_item	2563239	et	4	main
peate	doc_491521501974_item	2563241	et	4	main
et	doc_491521501974_item	2563248	et	3	main
mis	doc_491521501974_item	2563255	et	4	main
üldiselt	doc_491521501974_item	2563263	et	4	main
kuid	doc_491521501974_item	2563273	et	4	main
hoidun	doc_491521501974_item	2563274	et	3	main
edaspidi	doc_491521501974_item	2563275	et	3	main
puutumast	doc_491521501974_item	2563279	et	4	main
selle	doc_491521501974_item	2563293	et	4	main
kohlta-järve	doc_491521501974_item	2563296	et	4	main
saaks	doc_491521501974_item	2563299	et	3	main
on	doc_491521501974_item	2563301	et	4	main
tänapäeva	doc_491521501974_item	2563302	et	4	main
eestis	doc_491521501974_item	2563303	et	3	main
rohkem	doc_491521501974_item	2563322	et	4	main
raha	doc_491521501974_item	2563339	et	4	main
kommunaalkulude	doc_491521501974_item	2563340	et	3	main
osta	doc_491521501974_item	2563344	et	4	main
lugeda	doc_491521501974_item	2563349	et	3	main
õigusteaduses	doc_491521501974_item	2563360	et	3	main
et	doc_491521501974_item	2563397	et	3	main
oleks	doc_491521501974_item	2563398	et	3	main
siis	doc_491521501974_item	2563402	et	3	main
olen	doc_491521501974_item	2563416	et	3	main
öötundidel	doc_491521501974_item	2563422	et	3	main
viia	doc_491521501974_item	2563435	et	3	main
isegi	doc_491521501974_item	2563438	et	4	main
kui	doc_491521501974_item	2563440	et	3	main
see	doc_491521501974_item	2563441	et	3	main
mida	doc_491521501974_item	2563449	et	4	main
ma	doc_491521501974_item	2563450	et	3	main
ei	doc_491521501974_item	2563454	et	4	main
oma	doc_491521501974_item	2563458	et	4	main
on	doc_491521501974_item	2563480	et	4	main
mees	doc_491521501974_item	2563527	et	4	main
mehel	doc_491521501974_item	2563538	et	3	main
vastutav	doc_491521501974_item	2563541	et	4	main
arvates	doc_491521501974_item	2563544	et	4	main
ta	doc_491521501974_item	2563545	et	4	main
töötab	doc_491521501974_item	2563546	et	3	main
tema	doc_491521501974_item	2563550	et	4	main
et	doc_491521501974_item	2563555	et	3	main
inimesi	doc_491521501974_item	2563558	et	4	main
aidata	doc_491521501974_item	2563559	et	4	main
viib	doc_491521501974_item	2563565	et	3	main
päris	doc_491521501974_item	2563574	et	4	main
see	doc_491521501974_item	2563575	et	3	main
ta	doc_491521501974_item	2563581	et	4	main
ettevõtmisi	doc_491521501974_item	2563585	et	3	main
ei	doc_491521501974_item	2563588	et	4	main
teinud	doc_491521501973_item	2563125	et	4	main
siiski	doc_491521501973_item	2563132	et	4	main
on	doc_491521501973_item	2563133	et	4	main
loete	doc_491521501973_item	2563149	et	4	main
ei	doc_491521501973_item	2563160	et	4	main
kellest	doc_491521501973_item	2563166	et	4	main
see	doc_491521501973_item	2563168	et	3	main
on	doc_491521501973_item	2563173	et	4	main
vii	doc_491521501973_item	2563182	et	4	main
tööharjumused	doc_491521501973_item	2563186	et	3	main
tööd	doc_491521501973_item	2563188	et	4	main
päevad	doc_491521501973_item	2563190	et	3	main
ööd	doc_491521501973_item	2563193	et	4	main
tundidel	doc_491521501973_item	2563194	et	3	main
asjad	doc_491521501973_item	2563197	et	3	main
lõpuni	doc_491521501973_item	2563198	et	3	main
ja	doc_491521501973_item	2563199	et	3	main
temal	doc_491521501973_item	2563200	et	3	main
ei	doc_491521501973_item	2563201	et	4	main
ole	doc_491521501973_item	2563202	et	4	main
kombeks	doc_491521501973_item	2563203	et	4	main
oma	doc_491521501973_item	2563204	et	4	main
ettevõtmini	doc_491521501973_item	2563205	et	4	main
pooleli	doc_491521501973_item	2563206	et	3	main
jätta	doc_491521501973_item	2563207	et	3	main
12c	doc_491521501973_item	2563208	et	4	main
13	doc_491521501974_item	2563209	et	2	main
küsimust	doc_491521501974_item	2563210	et	4	main
13	doc_491521501974_item	2563211	et	2	main
küsimust	doc_491521501974_item	2563212	et	4	main
kelleks	doc_491521501974_item	2563213	et	4	main
tahtsite	doc_491521501974_item	2563214	et	3	main
lapsepõlves	doc_491521501974_item	2563215	et	4	main
saada	doc_491521501974_item	2563216	et	4	main
unistasin	doc_491521501974_item	2563217	et	3	main
saada	doc_491521501974_item	2563218	et	4	main
luurajaks	doc_491521501974_item	2563219	et	4	main
mind	doc_491521501974_item	2563220	et	4	main
tolleaegne	doc_491521501974_item	2563224	et	3	main
eritsooni	doc_491521501974_item	2563229	et	4	main
ja	doc_491521501974_item	2563230	et	3	main
hiljem	doc_491521501974_item	2563237	et	3	main
mida	doc_491521501974_item	2563240	et	4	main
suurimaks	doc_491521501974_item	2563244	et	4	main
ma	doc_491521501974_item	2563246	et	3	main
veel	doc_491521501974_item	2563253	et	4	main
valetamine	doc_491521501974_item	2563260	et	4	main
ma	doc_491521501974_item	2563261	et	3	main
ütle	doc_491521501974_item	2563265	et	4	main
et	doc_491521501974_item	2563268	et	3	main
selliste	doc_491521501974_item	2563276	et	4	main
võitlus	doc_491521501974_item	2563292	et	3	main
et	doc_491521501974_item	2563295	et	3	main
kuid	doc_491521501974_item	2563308	et	4	main
ja	doc_491521501974_item	2563324	et	3	main
on	doc_491521501974_item	2563326	et	4	main
seda	doc_491521501974_item	2563328	et	3	main
peale	doc_491521501974_item	2563334	et	4	main
ka	doc_491521501974_item	2563222	et	3	main
nagu	doc_491521501974_item	2563234	et	3	main
huvid	doc_491521501974_item	2563238	et	3	main
loodan	doc_491521501974_item	2563247	et	3	main
saavutus	doc_491521501974_item	2563250	et	4	main
teid	doc_491521501974_item	2563256	et	4	main
ei	doc_491521501974_item	2563264	et	4	main
teie	doc_491521501974_item	2563283	et	4	main
tegu	doc_491521501974_item	2563286	et	4	main
minu	doc_491521501974_item	2563290	et	3	main
nimel	doc_491521501974_item	2563294	et	3	main
kellel	doc_491521501974_item	2563300	et	4	main
öelda	doc_491521501974_item	2563307	et	4	main
ole	doc_491521501974_item	2563311	et	4	main
ainult	doc_491521501974_item	2563313	et	4	main
rikkad	doc_491521501974_item	2563314	et	4	main
ja	doc_491521501974_item	2563315	et	3	main
võimu	doc_491521501974_item	2563316	et	4	main
juures	doc_491521501974_item	2563317	et	4	main
olevad	doc_491521501974_item	2563318	et	4	main
inimesed	doc_491521501974_item	2563319	et	3	main
sest	doc_491521501974_item	2563320	et	4	main
praegune	doc_491521501974_item	2563291	et	3	main
õhk	doc_491521501974_item	2563297	et	3	main
puhtaks	doc_491521501974_item	2563298	et	3	main
kindlasti	doc_491521501974_item	2563309	et	3	main
mida	doc_491521501974_item	2563321	et	4	main
raha	doc_491521501974_item	2563323	et	4	main
teil	doc_491521501974_item	2563336	et	4	main
kõige	doc_491521501974_item	2563337	et	4	main
on	doc_491521501974_item	2563362	et	4	main
jaoks	doc_491521501974_item	2563364	et	4	main
koos	doc_491521501974_item	2563368	et	4	main
perega	doc_491521501974_item	2563369	et	3	main
kusagil	doc_491521501974_item	2563370	et	3	main
tüüpi	doc_491521501974_item	2563412	et	4	main
inimene	doc_491521501974_item	2563413	et	3	main
ja	doc_491521501974_item	2563414	et	3	main
seetõttu	doc_491521501974_item	2563415	et	3	main
võimu	doc_491521501974_item	2563325	et	4	main
käes	doc_491521501974_item	2563327	et	4	main
rohkem	doc_491521501974_item	2563329	et	4	main
rohkem	doc_491521501974_item	2563338	et	4	main
mida	doc_491521501974_item	2563342	et	4	main
oma	doc_491521501974_item	2563356	et	4	main
taset	doc_491521501974_item	2563357	et	3	main
valitud	doc_491521501974_item	2563358	et	4	main
erialal	doc_491521501974_item	2563359	et	3	main
looduses	doc_491521501974_item	2563371	et	4	main
milline	doc_491521501974_item	2563372	et	3	main
on	doc_491521501974_item	2563373	et	4	main
teie	doc_491521501974_item	2563374	et	4	main
lemmikkoht	doc_491521501974_item	2563375	et	3	main
ida-virumaal	doc_491521501974_item	2563376	et	4	main
peipsi-äärne	doc_491521501974_item	2563377	et	3	main
kant	doc_491521501974_item	2563378	et	3	main
alajõe	doc_491521501974_item	2563379	et	3	main
karjamaa	doc_491521501974_item	2563380	et	4	main
vasknarva	doc_491521501974_item	2563381	et	4	main
mille	doc_491521501974_item	2563382	et	3	main
ei	doc_491521501974_item	2563384	et	4	main
jaoks	doc_491521501974_item	2563383	et	4	main
jätku	doc_491521501974_item	2563385	et	4	main
aega	doc_491521501974_item	2563386	et	4	main
kuna	doc_491521501974_item	2563387	et	3	main
tahan	doc_491521501974_item	2563388	et	3	main
kohtuasjades	doc_491521501974_item	2563389	et	3	main
inimesi	doc_491521501974_item	2563390	et	4	main
võimalikult	doc_491521501974_item	2563391	et	4	main
hästi	doc_491521501974_item	2563392	et	3	main
aidata	doc_491521501974_item	2563393	et	4	main
siis	doc_491521501974_item	2563394	et	3	main
tundub	doc_491521501974_item	2563395	et	3	main
alati	doc_491521501974_item	2563396	et	4	main
kulub	doc_491521501974_item	2563335	et	3	main
tahaksite	doc_491521501974_item	2563343	et	3	main
tahan	doc_491521501974_item	2563346	et	3	main
palju	doc_491521501974_item	2563348	et	4	main
et	doc_491521501974_item	2563350	et	3	main
parim	doc_491521501974_item	2563365	et	4	main
puhkus	doc_491521501974_item	2563366	et	3	main
olla	doc_491521501974_item	2563367	et	3	main
natukene	doc_491521501974_item	2563399	et	4	main
rohkem	doc_491521501974_item	2563400	et	4	main
veelgi	doc_491521501974_item	2563404	et	4	main
valmistuda	doc_491521501974_item	2563406	et	3	main
kuid	doc_491521501974_item	2563407	et	4	main
ma	doc_491521501974_item	2563408	et	3	main
olen	doc_491521501974_item	2563409	et	3	main
tegema	doc_491521501974_item	2563419	et	3	main
omadust	doc_491521501974_item	2563424	et	4	main
oma	doc_491521501974_item	2563426	et	4	main
tugevaimaks	doc_491521501974_item	2563427	et	4	main
küljeks	doc_491521501974_item	2563428	et	3	main
ma	doc_491521501974_item	2563429	et	3	main
arvan	doc_491521501974_item	2563430	et	3	main
et	doc_491521501974_item	2563431	et	3	main
on	doc_491521501974_item	2563433	et	4	main
lõpuni	doc_491521501974_item	2563437	et	3	main
ei	doc_491521501974_item	2563443	et	4	main
iga	doc_491521501974_item	2563445	et	4	main
alguses	doc_491521501974_item	2563451	et	4	main
ole	doc_491521501974_item	2563455	et	4	main
mul	doc_491521501974_item	2563456	et	3	main
kombeks	doc_491521501974_item	2563457	et	4	main
ma	doc_491521501974_item	2563468	et	3	main
teinud	doc_491521501974_item	2563472	et	4	main
nii	doc_491521501974_item	2563474	et	3	main
venemaal	doc_491521501974_item	2563475	et	4	main
kui	doc_491521501974_item	2563476	et	3	main
saksamaal	doc_491521501974_item	2563477	et	4	main
eestis	doc_491521501974_item	2563481	et	3	main
sellel	doc_491521501974_item	2563537	et	4	main
mingi	doc_491521501974_item	2563540	et	4	main
amet	doc_491521501974_item	2563542	et	3	main
minu	doc_491521501974_item	2563543	et	3	main
see	doc_491521501974_item	2563554	et	3	main
ta	doc_491521501974_item	2563564	et	4	main
isegi	doc_491521501974_item	2563568	et	4	main
kui	doc_491521501974_item	2563570	et	3	main
mida	doc_491521501974_item	2563576	et	4	main
ta	doc_491521501974_item	2563577	et	4	main
jätta	doc_491521501974_item	2563583	et	3	main
mees	doc_491521501974_item	2563587	et	4	main
usu	doc_491521501974_item	2563589	et	4	main
horoskoopidesse	doc_491521501974_item	2563590	et	3	main
ta	doc_491521501974_item	2563591	et	4	main
hiljem	doc_491521501975_item	2563623	et	3	main
mida	doc_491521501975_item	2563626	et	4	main
oma	doc_491521501975_item	2563628	et	4	main
ma	doc_491521501975_item	2563632	et	3	main
üldiselt	doc_491521501975_item	2563649	et	4	main
välja	doc_491521501975_item	2563653	et	4	main
kokku	doc_491521501975_item	2563664	et	3	main
elu	doc_491521501975_item	2563670	et	4	main
tegu	doc_491521501975_item	2563672	et	4	main
nimel	doc_491521501975_item	2563680	et	3	main
puhtaks	doc_491521501975_item	2563684	et	3	main
kellel	doc_491521501975_item	2563686	et	4	main
rikkad	doc_491521501975_item	2563700	et	4	main
teil	doc_491521501975_item	2563722	et	4	main
on	doc_491521501975_item	2563748	et	4	main
parim	doc_491521501975_item	2563751	et	4	main
ida-virumaal	doc_491521501975_item	2563762	et	4	main
peipsi-äärne	doc_491521501975_item	2563763	et	3	main
kant	doc_491521501975_item	2563764	et	3	main
alajõe	doc_491521501975_item	2563765	et	3	main
karjamaa	doc_491521501975_item	2563766	et	4	main
vasknarva	doc_491521501975_item	2563767	et	4	main
ei	doc_491521501975_item	2563770	et	4	main
aega	doc_491521501975_item	2563787	et	4	main
paremini	doc_491521501975_item	2563791	et	4	main
harjunud	doc_491521501975_item	2563803	et	4	main
tööd	doc_491521501975_item	2563804	et	4	main
tugevaimaks	doc_491521501975_item	2563813	et	4	main
küljeks	doc_491521501975_item	2563814	et	3	main
jõuaks	doc_491521501974_item	2563403	et	3	main
harjunud	doc_491521501974_item	2563417	et	4	main
tööd	doc_491521501974_item	2563418	et	4	main
hilistel	doc_491521501974_item	2563421	et	3	main
see	doc_491521501974_item	2563432	et	3	main
siis	doc_491521501974_item	2563439	et	3	main
tulemus	doc_491521501974_item	2563442	et	3	main
ole	doc_491521501974_item	2563444	et	4	main
ettevõtmisi	doc_491521501974_item	2563459	et	3	main
pooleli	doc_491521501974_item	2563460	et	3	main
jätta	doc_491521501974_item	2563461	et	3	main
millises	doc_491521501974_item	2563462	et	3	main
riigis	doc_491521501974_item	2563463	et	3	main
peale	doc_491521501974_item	2563464	et	4	main
ja	doc_491521501974_item	2563471	et	3	main
kuid	doc_491521501974_item	2563478	et	4	main
mul	doc_491521501974_item	2563482	et	3	main
järgin	doc_491521501974_item	2563485	et	3	main
on	doc_491521501974_item	2563528	et	4	main
korralik	doc_491521501974_item	2563529	et	3	main
õiglane	doc_491521501974_item	2563530	et	3	main
ja	doc_491521501974_item	2563531	et	3	main
tõsine	doc_491521501974_item	2563532	et	4	main
et	doc_491521501974_item	2563536	et	3	main
linnavalitsuses	doc_491521501974_item	2563547	et	4	main
või	doc_491521501974_item	2563548	et	4	main
tugevamad	doc_491521501974_item	2563551	et	4	main
ta	doc_491521501974_item	2563556	et	4	main
asja	doc_491521501974_item	2563566	et	4	main
ei	doc_491521501974_item	2563572	et	4	main
ole	doc_491521501974_item	2563573	et	4	main
alguses	doc_491521501974_item	2563578	et	4	main
pooleli	doc_491521501974_item	2563586	et	3	main
huvid	doc_491521501975_item	2563624	et	3	main
suurimaks	doc_491521501975_item	2563630	et	4	main
selline	doc_491521501975_item	2563635	et	4	main
ootab	doc_491521501975_item	2563637	et	3	main
veel	doc_491521501975_item	2563639	et	4	main
ees	doc_491521501975_item	2563640	et	4	main
küll	doc_491521501975_item	2563648	et	4	main
nad	doc_491521501975_item	2563655	et	3	main
mind	doc_491521501975_item	2563657	et	4	main
selliste	doc_491521501975_item	2563662	et	4	main
teie	doc_491521501975_item	2563669	et	4	main
ongi	doc_491521501975_item	2563674	et	4	main
selle	doc_491521501975_item	2563679	et	4	main
õhk	doc_491521501975_item	2563683	et	3	main
raske	doc_491521501975_item	2563692	et	4	main
need	doc_491521501975_item	2563698	et	3	main
inimesed	doc_491521501975_item	2563705	et	3	main
peale	doc_491521501975_item	2563727	et	4	main
targemaks	doc_491521501975_item	2563738	et	4	main
eelkõige	doc_491521501975_item	2563739	et	3	main
tahaks	doc_491521501975_item	2563740	et	3	main
tõsta	doc_491521501975_item	2563741	et	4	main
teie	doc_491521501975_item	2563749	et	4	main
perega	doc_491521501975_item	2563755	et	3	main
võimalikult	doc_491521501975_item	2563777	et	4	main
hästi	doc_491521501975_item	2563778	et	3	main
tüüpi	doc_491521501975_item	2563798	et	4	main
inimene	doc_491521501975_item	2563799	et	3	main
ja	doc_491521501975_item	2563800	et	3	main
seetõttu	doc_491521501975_item	2563801	et	3	main
öötundidel	doc_491521501975_item	2563808	et	3	main
ei	doc_491521501975_item	2563829	et	4	main
ole	doc_491521501975_item	2563830	et	4	main
ma	doc_491521501975_item	2563836	et	3	main
lootnud	doc_491521501975_item	2563839	et	4	main
mul	doc_491521501975_item	2563842	et	3	main
elada	doc_491521501975_item	2563853	et	3	main
kuid	doc_491521501975_item	2563864	et	4	main
parem	doc_491521501975_item	2563870	et	4	main
järgin	doc_491521501975_item	2563871	et	3	main
oma	doc_491521501975_item	2563872	et	4	main
ei	doc_491521501975_item	2563886	et	4	main
usu	doc_491521501975_item	2563887	et	4	main
iseloomusta	doc_491521501975_item	2563897	et	4	main
inimest	doc_491521501975_item	2563898	et	3	main
intervjueeritav	doc_491521501975_item	2563903	et	4	main
on	doc_491521501975_item	2563916	et	4	main
iseloomult	doc_491521501975_item	2563917	et	3	main
4	doc_491521501975_item	2563918	et	2	main
loomult	doc_491521501974_item	2563410	et	3	main
öökulli	doc_491521501974_item	2563411	et	4	main
ka	doc_491521501974_item	2563420	et	3	main
millist	doc_491521501974_item	2563423	et	3	main
asjad	doc_491521501974_item	2563436	et	3	main
kord	doc_491521501974_item	2563446	et	4	main
olin	doc_491521501974_item	2563452	et	3	main
elada	doc_491521501974_item	2563467	et	3	main
olen	doc_491521501974_item	2563469	et	3	main
siiski	doc_491521501974_item	2563479	et	4	main
parem	doc_491521501974_item	2563484	et	4	main
peate	doc_491521501974_item	2563425	et	4	main
järjekindlus	doc_491521501974_item	2563434	et	4	main
päris	doc_491521501974_item	2563447	et	4	main
see	doc_491521501974_item	2563448	et	3	main
lootnud	doc_491521501974_item	2563453	et	4	main
eesti	doc_491521501974_item	2563465	et	4	main
tahaksite	doc_491521501974_item	2563466	et	3	main
elanud	doc_491521501974_item	2563470	et	4	main
tööd	doc_491521501974_item	2563473	et	4	main
kõige	doc_491521501974_item	2563483	et	4	main
oma	doc_491521501974_item	2563486	et	4	main
öeldut	doc_491521501974_item	2563488	et	4	main
kus	doc_491521501974_item	2563489	et	3	main
isa	doc_491521501974_item	2563487	et	4	main
sündisid	doc_491521501974_item	2563490	et	4	main
seal	doc_491521501974_item	2563491	et	4	main
peab	doc_491521501974_item	2563492	et	4	main
ka	doc_491521501974_item	2563493	et	3	main
elama	doc_491521501974_item	2563494	et	3	main
kas	doc_491521501974_item	2563495	et	3	main
loete	doc_491521501974_item	2563496	et	4	main
horoskoope	doc_491521501974_item	2563497	et	3	main
ei	doc_491521501974_item	2563498	et	4	main
ma	doc_491521501974_item	2563499	et	3	main
ei	doc_491521501974_item	2563500	et	4	main
usu	doc_491521501974_item	2563501	et	4	main
ega	doc_491521501974_item	2563503	et	3	main
huvitu	doc_491521501974_item	2563504	et	4	main
neid	doc_491521501974_item	2563502	et	4	main
nendest	doc_491521501974_item	2563505	et	4	main
see	doc_491521501974_item	2563506	et	3	main
ei	doc_491521501974_item	2563507	et	4	main
ole	doc_491521501974_item	2563508	et	4	main
tõsine	doc_491521501974_item	2563509	et	4	main
asi	doc_491521501974_item	2563510	et	4	main
ma	doc_491521501974_item	2563511	et	3	main
arvan	doc_491521501974_item	2563512	et	3	main
et	doc_491521501974_item	2563513	et	3	main
intervjueeritav	doc_491521501974_item	2563514	et	4	main
on	doc_491521501974_item	2563515	et	4	main
mees	doc_491521501974_item	2563516	et	4	main
tema	doc_491521501974_item	2563517	et	4	main
eriala	doc_491521501974_item	2563518	et	4	main
on	doc_491521501974_item	2563519	et	4	main
jurist	doc_491521501974_item	2563520	et	3	main
või	doc_491521501974_item	2563521	et	4	main
ta	doc_491521501974_item	2563523	et	4	main
töökab	doc_491521501974_item	2563524	et	4	main
advokat	doc_491521501974_item	2563522	et	4	main
kohtus	doc_491521501974_item	2563525	et	4	main
see	doc_491521501974_item	2563526	et	3	main
on	doc_491521501974_item	2563539	et	4	main
kohtus	doc_491521501974_item	2563549	et	4	main
kõljed	doc_491521501974_item	2563552	et	4	main
tööd	doc_491521501974_item	2563563	et	4	main
ei	doc_491521501974_item	2563582	et	4	main
on	doc_491521501974_item	2563592	et	4	main
huvitu	doc_491521501974_item	2563593	et	4	main
nendest	doc_491521501974_item	2563594	et	4	main
13	doc_491521501975_item	2563595	et	2	main
küsimust	doc_491521501975_item	2563596	et	4	main
13	doc_491521501975_item	2563597	et	2	main
küsimust	doc_491521501975_item	2563598	et	4	main
kelleks	doc_491521501975_item	2563599	et	4	main
tahtsite	doc_491521501975_item	2563600	et	3	main
lapsepõlves	doc_491521501975_item	2563601	et	4	main
saada	doc_491521501975_item	2563602	et	4	main
unistasin	doc_491521501975_item	2563603	et	3	main
saada	doc_491521501975_item	2563604	et	4	main
luurajaks	doc_491521501975_item	2563605	et	4	main
mind	doc_491521501975_item	2563606	et	4	main
köitis	doc_491521501975_item	2563607	et	3	main
ka	doc_491521501975_item	2563608	et	3	main
väga	doc_491521501975_item	2563609	et	3	main
tolleaegne	doc_491521501975_item	2563610	et	3	main
dessantväelasest	doc_491521501975_item	2563611	et	3	main
tehtud	doc_491521501975_item	2563612	et	4	main
film	doc_491521501975_item	2563613	et	3	main
sööst	doc_491521501975_item	2563614	et	3	main
eritsooni	doc_491521501975_item	2563615	et	4	main
ja	doc_491521501975_item	2563616	et	3	main
tahtsin	doc_491521501975_item	2563617	et	3	main
saada	doc_491521501975_item	2563618	et	4	main
samasuguseks	doc_491521501975_item	2563619	et	4	main
nagu	doc_491521501975_item	2563620	et	3	main
elu	doc_491521501975_item	2563629	et	4	main
loodan	doc_491521501975_item	2563633	et	3	main
ärritab	doc_491521501975_item	2563643	et	3	main
reeturlus	doc_491521501975_item	2563644	et	4	main
ütle	doc_491521501975_item	2563651	et	4	main
edaspidi	doc_491521501975_item	2563661	et	3	main
mis	doc_491521501975_item	2563666	et	4	main
olnud	doc_491521501975_item	2563668	et	4	main
ilmselt	doc_491521501975_item	2563673	et	4	main
et	doc_491521501975_item	2563681	et	3	main
on	doc_491521501975_item	2563687	et	4	main
eestis	doc_491521501975_item	2563689	et	3	main
kindlasti	doc_491521501975_item	2563695	et	3	main
ei	doc_491521501975_item	2563696	et	4	main
ja	doc_491521501975_item	2563701	et	3	main
kõige	doc_491521501975_item	2563723	et	4	main
inimene	doc_491521501974_item	2563533	et	3	main
ma	doc_491521501974_item	2563534	et	3	main
arvan	doc_491521501974_item	2563535	et	3	main
on	doc_491521501974_item	2563553	et	4	main
tahab	doc_491521501974_item	2563557	et	3	main
ja	doc_491521501974_item	2563560	et	3	main
teeb	doc_491521501974_item	2563561	et	3	main
palju	doc_491521501974_item	2563562	et	4	main
lõpuni	doc_491521501974_item	2563567	et	3	main
siis	doc_491521501974_item	2563569	et	3	main
tulemus	doc_491521501974_item	2563571	et	3	main
oli	doc_491521501974_item	2563579	et	3	main
lootnud	doc_491521501974_item	2563580	et	4	main
oma	doc_491521501974_item	2563584	et	4	main
nemad	doc_491521501975_item	2563621	et	3	main
muutusid	doc_491521501975_item	2563625	et	4	main
peate	doc_491521501975_item	2563627	et	4	main
saavutuseks	doc_491521501975_item	2563631	et	4	main
saavutus	doc_491521501975_item	2563636	et	4	main
mind	doc_491521501975_item	2563638	et	4	main
ja	doc_491521501975_item	2563645	et	3	main
valetamine	doc_491521501975_item	2563646	et	4	main
ma	doc_491521501975_item	2563647	et	3	main
inimestele	doc_491521501975_item	2563652	et	3	main
on	doc_491521501975_item	2563656	et	4	main
petnud	doc_491521501975_item	2563658	et	4	main
kuid	doc_491521501975_item	2563659	et	4	main
hoidun	doc_491521501975_item	2563660	et	3	main
see	doc_491521501975_item	2563675	et	3	main
minu	doc_491521501975_item	2563676	et	3	main
praegune	doc_491521501975_item	2563677	et	3	main
kohlta-järve	doc_491521501975_item	2563682	et	4	main
öelda	doc_491521501975_item	2563693	et	4	main
kuid	doc_491521501975_item	2563694	et	4	main
ainult	doc_491521501975_item	2563699	et	4	main
juures	doc_491521501975_item	2563703	et	4	main
kulub	doc_491521501975_item	2563721	et	3	main
osta	doc_491521501975_item	2563730	et	4	main
tahan	doc_491521501975_item	2563732	et	3	main
oma	doc_491521501975_item	2563742	et	4	main
taset	doc_491521501975_item	2563743	et	3	main
puhkus	doc_491521501975_item	2563752	et	3	main
koos	doc_491521501975_item	2563754	et	4	main
jaoks	doc_491521501975_item	2563769	et	4	main
aidata	doc_491521501975_item	2563779	et	4	main
siis	doc_491521501975_item	2563780	et	3	main
tundub	doc_491521501975_item	2563781	et	3	main
alati	doc_491521501975_item	2563782	et	4	main
et	doc_491521501975_item	2563783	et	3	main
oleks	doc_491521501975_item	2563784	et	3	main
natukene	doc_491521501975_item	2563785	et	4	main
jõuaks	doc_491521501975_item	2563789	et	3	main
olen	doc_491521501975_item	2563802	et	3	main
hilistel	doc_491521501975_item	2563807	et	3	main
millist	doc_491521501975_item	2563809	et	3	main
peate	doc_491521501975_item	2563811	et	4	main
oma	doc_491521501975_item	2563812	et	4	main
aga	doc_491521501975_item	2563622	et	3	main
et	doc_491521501975_item	2563634	et	3	main
mis	doc_491521501975_item	2563641	et	4	main
teid	doc_491521501975_item	2563642	et	4	main
ei	doc_491521501975_item	2563650	et	4	main
et	doc_491521501975_item	2563654	et	3	main
inimestega	doc_491521501975_item	2563663	et	3	main
puutumast	doc_491521501975_item	2563665	et	4	main
on	doc_491521501975_item	2563667	et	4	main
pööraseim	doc_491521501975_item	2563671	et	4	main
võitlus	doc_491521501975_item	2563678	et	3	main
saaks	doc_491521501975_item	2563685	et	3	main
tänapäeva	doc_491521501975_item	2563688	et	4	main
hea	doc_491521501975_item	2563690	et	4	main
elada	doc_491521501975_item	2563691	et	3	main
ole	doc_491521501975_item	2563697	et	4	main
võimu	doc_491521501975_item	2563702	et	4	main
olevad	doc_491521501975_item	2563704	et	4	main
sest	doc_491521501975_item	2563706	et	4	main
mida	doc_491521501975_item	2563707	et	4	main
rohkem	doc_491521501975_item	2563708	et	4	main
raha	doc_491521501975_item	2563709	et	4	main
ja	doc_491521501975_item	2563710	et	3	main
võimu	doc_491521501975_item	2563711	et	4	main
on	doc_491521501975_item	2563712	et	4	main
käes	doc_491521501975_item	2563713	et	4	main
seda	doc_491521501975_item	2563714	et	3	main
rohkem	doc_491521501975_item	2563715	et	4	main
on	doc_491521501975_item	2563716	et	4	main
ka	doc_491521501975_item	2563717	et	3	main
probleeme	doc_491521501975_item	2563718	et	3	main
mille	doc_491521501975_item	2563719	et	3	main
peale	doc_491521501975_item	2563720	et	4	main
mida	doc_491521501975_item	2563728	et	4	main
tahaksite	doc_491521501975_item	2563729	et	3	main
ma	doc_491521501975_item	2563731	et	3	main
väga	doc_491521501975_item	2563733	et	3	main
palju	doc_491521501975_item	2563734	et	4	main
lugeda	doc_491521501975_item	2563735	et	3	main
et	doc_491521501975_item	2563736	et	3	main
valitud	doc_491521501975_item	2563744	et	4	main
erialal	doc_491521501975_item	2563745	et	3	main
õigusteaduses	doc_491521501975_item	2563746	et	3	main
jaoks	doc_491521501975_item	2563750	et	4	main
olla	doc_491521501975_item	2563753	et	3	main
kusagil	doc_491521501975_item	2563756	et	3	main
looduses	doc_491521501975_item	2563757	et	4	main
milline	doc_491521501975_item	2563758	et	3	main
on	doc_491521501975_item	2563759	et	4	main
teie	doc_491521501975_item	2563760	et	4	main
lemmikkoht	doc_491521501975_item	2563761	et	3	main
rohkem	doc_491521501975_item	2563724	et	4	main
raha	doc_491521501975_item	2563725	et	4	main
kommunaalkulude	doc_491521501975_item	2563726	et	3	main
saada	doc_491521501975_item	2563737	et	4	main
mis	doc_491521501975_item	2563747	et	4	main
mille	doc_491521501975_item	2563768	et	3	main
jätku	doc_491521501975_item	2563771	et	4	main
aega	doc_491521501975_item	2563772	et	4	main
siis	doc_491521501975_item	2563788	et	3	main
kuid	doc_491521501975_item	2563793	et	4	main
ma	doc_491521501975_item	2563794	et	3	main
olen	doc_491521501975_item	2563795	et	3	main
loomult	doc_491521501975_item	2563796	et	3	main
öökulli	doc_491521501975_item	2563797	et	4	main
ka	doc_491521501975_item	2563806	et	3	main
omadust	doc_491521501975_item	2563810	et	4	main
isegi	doc_491521501975_item	2563824	et	4	main
kui	doc_491521501975_item	2563826	et	3	main
päris	doc_491521501975_item	2563833	et	4	main
ei	doc_491521501975_item	2563840	et	4	main
ja	doc_491521501975_item	2563857	et	3	main
tööd	doc_491521501975_item	2563859	et	4	main
on	doc_491521501975_item	2563866	et	4	main
sündisid	doc_491521501975_item	2563876	et	4	main
elama	doc_491521501975_item	2563880	et	3	main
neid	doc_491521501975_item	2563888	et	4	main
ei	doc_491521501975_item	2563893	et	4	main
tõsine	doc_491521501975_item	2563895	et	4	main
asi	doc_491521501975_item	2563896	et	4	main
mis	doc_491521501975_item	2563909	et	4	main
võiks	doc_491521501975_item	2563921	et	4	main
arvates	doc_491521501975_item	2563923	et	4	main
ta	doc_491521501975_item	2563938	et	4	main
suhtub	doc_491521501975_item	2563939	et	3	main
horoskoopidesse	doc_491521501975_item	2563940	et	3	main
intervjueeritav	doc_491521501975_item	2563942	et	4	main
tema	doc_491521501975_item	2563946	et	4	main
on	doc_491521501975_item	2563948	et	4	main
jurist	doc_491521501975_item	2563949	et	3	main
inimene	doc_491521501975_item	2563952	et	3	main
korralik	doc_491521501975_item	2563956	et	3	main
on	doc_491521501975_item	2563958	et	4	main
kohtus	doc_491521501975_item	2563966	et	4	main
ta	doc_491521501975_item	2563968	et	4	main
ei	doc_491521501975_item	2564014	et	4	main
et	doc_491521501975_item	2564018	et	3	main
olesja	doc_491521501976_item	2564031	et	4	main
kuidas	doc_491521501976_item	2564032	et	3	main
sa	doc_491521501976_item	2564033	et	3	main
elan	doc_491521501976_item	2564036	et	3	main
ma	doc_491521501976_item	2564043	et	3	main
poes	doc_491521501976_item	2564046	et	3	main
mul	doc_491521501976_item	2564053	et	3	main
olnud	doc_491521501976_item	2564055	et	4	main
jahu	doc_491521501976_item	2564063	et	4	main
ja	doc_491521501976_item	2564071	et	3	main
kus	doc_491521501976_item	2564074	et	3	main
müüjavad	doc_491521501976_item	2564076	et	4	main
jäätist	doc_491521501976_item	2564117	et	3	main
kord	doc_491521501976_item	2564120	et	4	main
kaubatarnija	doc_491521501976_item	2564122	et	4	main
rakverest	doc_491521501976_item	2564125	et	4	main
tooded	doc_491521501976_item	2564129	et	4	main
ma	doc_491521501976_item	2564138	et	3	main
meel	doc_491521501976_item	2564147	et	4	main
töölada	doc_491521501976_item	2564149	et	4	main
müüjad	doc_491521501976_item	2564150	et	4	main
neilega	doc_491521501976_item	2564160	et	4	main
on	doc_491521501976_item	2564170	et	4	main
ja	doc_491521501976_item	2564172	et	3	main
kuna	doc_491521501975_item	2563773	et	3	main
tahan	doc_491521501975_item	2563774	et	3	main
kohtuasjades	doc_491521501975_item	2563775	et	3	main
inimesi	doc_491521501975_item	2563776	et	4	main
rohkem	doc_491521501975_item	2563786	et	4	main
veelgi	doc_491521501975_item	2563790	et	4	main
valmistuda	doc_491521501975_item	2563792	et	3	main
tegema	doc_491521501975_item	2563805	et	3	main
on	doc_491521501975_item	2563819	et	4	main
järjekindlus	doc_491521501975_item	2563820	et	4	main
asjad	doc_491521501975_item	2563822	et	3	main
kord	doc_491521501975_item	2563832	et	4	main
olin	doc_491521501975_item	2563838	et	3	main
ole	doc_491521501975_item	2563841	et	4	main
kombeks	doc_491521501975_item	2563843	et	4	main
oma	doc_491521501975_item	2563844	et	4	main
ettevõtmisi	doc_491521501975_item	2563845	et	3	main
pooleli	doc_491521501975_item	2563846	et	3	main
elanud	doc_491521501975_item	2563856	et	4	main
venemaal	doc_491521501975_item	2563861	et	4	main
kui	doc_491521501975_item	2563862	et	3	main
saksamaal	doc_491521501975_item	2563863	et	4	main
eestis	doc_491521501975_item	2563867	et	3	main
kõige	doc_491521501975_item	2563869	et	4	main
kus	doc_491521501975_item	2563875	et	3	main
peab	doc_491521501975_item	2563878	et	4	main
kas	doc_491521501975_item	2563881	et	3	main
ega	doc_491521501975_item	2563889	et	3	main
huvitu	doc_491521501975_item	2563890	et	4	main
kellest	doc_491521501975_item	2563899	et	4	main
kirjutatakse	doc_491521501975_item	2563900	et	3	main
on	doc_491521501975_item	2563904	et	4	main
või	doc_491521501975_item	2563906	et	4	main
2	doc_491521501975_item	2563908	et	2	main
tema	doc_491521501975_item	2563911	et	4	main
3	doc_491521501975_item	2563913	et	2	main
missugune	doc_491521501975_item	2563914	et	3	main
ta	doc_491521501975_item	2563915	et	4	main
sinu	doc_491521501975_item	2563922	et	3	main
tema	doc_491521501975_item	2563934	et	4	main
tööharjumused	doc_491521501975_item	2563935	et	3	main
kuidas	doc_491521501975_item	2563937	et	3	main
1	doc_491521501975_item	2563941	et	2	main
2	doc_491521501975_item	2563945	et	2	main
elukutse	doc_491521501975_item	2563947	et	4	main
öökullitüüpi	doc_491521501975_item	2563959	et	4	main
et	doc_491521501975_item	2563963	et	3	main
tulemus	doc_491521501975_item	2563976	et	3	main
usu	doc_491521501975_item	2564015	et	4	main
aleksandra	doc_491521501976_item	2564028	et	4	main
kirjutab	doc_491521501976_item	2564029	et	3	main
sulle	doc_491521501976_item	2564030	et	3	main
ma	doc_491521501976_item	2564035	et	3	main
tead	doc_491521501976_item	2564038	et	4	main
ma	doc_491521501976_item	2564039	et	3	main
leidsin	doc_491521501976_item	2564040	et	3	main
ma	doc_491521501976_item	2564047	et	3	main
iga	doc_491521501976_item	2564050	et	4	main
aga	doc_491521501976_item	2564052	et	3	main
ei	doc_491521501976_item	2564054	et	4	main
tuju	doc_491521501976_item	2564056	et	4	main
sinna	doc_491521501976_item	2564057	et	3	main
kaalusin	doc_491521501976_item	2564061	et	3	main
küpsised	doc_491521501976_item	2564064	et	3	main
pärast	doc_491521501976_item	2564067	et	4	main
viisin	doc_491521501976_item	2564072	et	3	main
ma	doc_491521501976_item	2564078	et	3	main
ise	doc_491521501976_item	2564079	et	4	main
allahinlus	doc_491521501976_item	2564136	et	4	main
hea	doc_491521501976_item	2564146	et	4	main
minuga	doc_491521501976_item	2564152	et	3	main
ma	doc_491521501976_item	2564154	et	3	main
tahtnud	doc_491521501976_item	2564156	et	4	main
sealt	doc_491521501976_item	2564157	et	4	main
eesti	doc_491521501976_item	2564163	et	4	main
keeles	doc_491521501976_item	2564164	et	4	main
ma	doc_491521501976_item	2564166	et	3	main
töötada	doc_491521501976_item	2564169	et	3	main
ma	doc_491521501975_item	2563815	et	3	main
arvan	doc_491521501975_item	2563816	et	3	main
et	doc_491521501975_item	2563817	et	3	main
see	doc_491521501975_item	2563818	et	3	main
viia	doc_491521501975_item	2563821	et	3	main
lõpuni	doc_491521501975_item	2563823	et	3	main
iga	doc_491521501975_item	2563831	et	4	main
alguses	doc_491521501975_item	2563837	et	4	main
tahaksite	doc_491521501975_item	2563852	et	3	main
olen	doc_491521501975_item	2563855	et	3	main
siiski	doc_491521501975_item	2563865	et	4	main
isa	doc_491521501975_item	2563873	et	4	main
seal	doc_491521501975_item	2563877	et	4	main
ka	doc_491521501975_item	2563879	et	3	main
loete	doc_491521501975_item	2563882	et	4	main
horoskoope	doc_491521501975_item	2563883	et	3	main
ei	doc_491521501975_item	2563884	et	4	main
ma	doc_491521501975_item	2563885	et	3	main
nendest	doc_491521501975_item	2563891	et	4	main
ole	doc_491521501975_item	2563894	et	4	main
kas	doc_491521501975_item	2563902	et	3	main
mees	doc_491521501975_item	2563905	et	4	main
naine	doc_491521501975_item	2563907	et	3	main
kus	doc_491521501975_item	2563919	et	3	main
ta	doc_491521501975_item	2563920	et	4	main
siis	doc_491521501975_item	2563825	et	3	main
see	doc_491521501975_item	2563827	et	3	main
tulemus	doc_491521501975_item	2563828	et	3	main
see	doc_491521501975_item	2563834	et	3	main
mida	doc_491521501975_item	2563835	et	4	main
jätta	doc_491521501975_item	2563847	et	3	main
millises	doc_491521501975_item	2563848	et	3	main
riigis	doc_491521501975_item	2563849	et	3	main
peale	doc_491521501975_item	2563850	et	4	main
eesti	doc_491521501975_item	2563851	et	4	main
ma	doc_491521501975_item	2563854	et	3	main
teinud	doc_491521501975_item	2563858	et	4	main
nii	doc_491521501975_item	2563860	et	3	main
mul	doc_491521501975_item	2563868	et	3	main
öeldut	doc_491521501975_item	2563874	et	4	main
see	doc_491521501975_item	2563892	et	3	main
1	doc_491521501975_item	2563901	et	2	main
on	doc_491521501975_item	2563910	et	4	main
elukutse	doc_491521501975_item	2563912	et	4	main
missugused	doc_491521501975_item	2563926	et	3	main
on	doc_491521501975_item	2563927	et	4	main
tugevad	doc_491521501975_item	2563929	et	4	main
küljed	doc_491521501975_item	2563930	et	3	main
6	doc_491521501975_item	2563931	et	2	main
3	doc_491521501975_item	2563950	et	2	main
see	doc_491521501975_item	2563951	et	3	main
ja	doc_491521501975_item	2563955	et	3	main
ta	doc_491521501975_item	2563957	et	4	main
arvan	doc_491521501975_item	2563962	et	3	main
ooe	doc_491521501975_item	2563978	et	4	main
7	doc_491521501975_item	2564012	et	2	main
see	doc_491521501975_item	2564019	et	3	main
töötada	doc_491521501975_item	2563924	et	3	main
7	doc_491521501975_item	2563936	et	2	main
on	doc_491521501975_item	2563943	et	4	main
aus	doc_491521501975_item	2563954	et	4	main
4	doc_491521501975_item	2563960	et	2	main
ta	doc_491521501975_item	2563964	et	4	main
ei	doc_491521501975_item	2563977	et	4	main
iga	doc_491521501975_item	2563979	et	4	main
kord	doc_491521501975_item	2563980	et	4	main
päris	doc_491521501975_item	2563981	et	4	main
see	doc_491521501975_item	2563982	et	3	main
mida	doc_491521501975_item	2563983	et	4	main
ta	doc_491521501975_item	2563984	et	4	main
alguses	doc_491521501975_item	2563985	et	4	main
oli	doc_491521501975_item	2563986	et	3	main
lootnud	doc_491521501975_item	2563987	et	4	main
ei	doc_491521501975_item	2563988	et	4	main
ole	doc_491521501975_item	2563989	et	4	main
temal	doc_491521501975_item	2563990	et	3	main
kombeks	doc_491521501975_item	2563991	et	4	main
oma	doc_491521501975_item	2563992	et	4	main
ettevõtmisi	doc_491521501975_item	2563993	et	3	main
pooleli	doc_491521501975_item	2563994	et	3	main
jätta	doc_491521501975_item	2563995	et	3	main
6	doc_491521501975_item	2563996	et	2	main
kuna	doc_491521501975_item	2563997	et	3	main
ta	doc_491521501975_item	2563998	et	4	main
on	doc_491521501975_item	2563999	et	4	main
öökulli-tüüpi	doc_491521501975_item	2564000	et	4	main
inimene	doc_491521501975_item	2564001	et	3	main
ja	doc_491521501975_item	2564002	et	3	main
seetõttu	doc_491521501975_item	2564003	et	3	main
ta	doc_491521501975_item	2564004	et	4	main
on	doc_491521501975_item	2564005	et	4	main
harjunud	doc_491521501975_item	2564006	et	4	main
tööd	doc_491521501975_item	2564007	et	4	main
tegema	doc_491521501975_item	2564008	et	3	main
ka	doc_491521501975_item	2564009	et	3	main
hilistel	doc_491521501975_item	2564010	et	3	main
öö-tundidel	doc_491521501975_item	2564011	et	3	main
5	doc_491521501975_item	2563925	et	2	main
tema	doc_491521501975_item	2563928	et	4	main
missugused	doc_491521501975_item	2563932	et	3	main
on	doc_491521501975_item	2563933	et	4	main
mees	doc_491521501975_item	2563944	et	4	main
on	doc_491521501975_item	2563953	et	4	main
ma	doc_491521501975_item	2563961	et	3	main
töötab	doc_491521501975_item	2563965	et	3	main
5	doc_491521501975_item	2563967	et	2	main
viib	doc_491521501975_item	2563969	et	3	main
asjad	doc_491521501975_item	2563970	et	3	main
lõpuni	doc_491521501975_item	2563971	et	3	main
isegi	doc_491521501975_item	2563972	et	4	main
siis	doc_491521501975_item	2563973	et	3	main
kui	doc_491521501975_item	2563974	et	3	main
see	doc_491521501975_item	2563975	et	3	main
asjadeste	doc_491521501975_item	2564017	et	4	main
ei	doc_491521501975_item	2564020	et	4	main
tõsine	doc_491521501975_item	2564022	et	4	main
32	doc_491521501975_item	2564024	et	2	main
elad	doc_491521501976_item	2564034	et	3	main
hästi	doc_491521501976_item	2564037	et	3	main
töötasin	doc_491521501976_item	2564044	et	3	main
praktikal	doc_491521501976_item	2564049	et	3	main
seal	doc_491521501976_item	2564059	et	4	main
tatar	doc_491521501976_item	2564065	et	3	main
panin	doc_491521501976_item	2564069	et	3	main
saali	doc_491521501976_item	2564073	et	4	main
see	doc_491521501976_item	2564075	et	3	main
korda	doc_491521501976_item	2564116	et	4	main
ta	doc_491521501975_item	2564013	et	4	main
sellistesse	doc_491521501975_item	2564016	et	4	main
ole	doc_491521501975_item	2564021	et	4	main
asi	doc_491521501975_item	2564023	et	4	main
s	doc_491521501975_item	2564025	et	4	main
tere	doc_491521501976_item	2564026	et	3	main
tere	doc_491521501976_item	2564027	et	3	main
endale	doc_491521501976_item	2564041	et	4	main
toidu	doc_491521501976_item	2564045	et	3	main
päev	doc_491521501976_item	2564051	et	3	main
ma	doc_491521501976_item	2564060	et	3	main
hinna	doc_491521501976_item	2564070	et	3	main
vastu	doc_491521501976_item	2564080	et	3	main
üks	doc_491521501976_item	2564119	et	3	main
kassaga	doc_491521501976_item	2564140	et	3	main
maksuordenit	doc_491521501976_item	2564143	et	3	main
hästi	doc_491521501976_item	2564153	et	3	main
ma	doc_491521501976_item	2564161	et	3	main
nüüd	doc_491521501976_item	2564165	et	4	main
tean	doc_491521501976_item	2564167	et	3	main
praktikat	doc_491521501976_item	2564042	et	3	main
käisin	doc_491521501976_item	2564048	et	3	main
käia	doc_491521501976_item	2564058	et	4	main
suhkur	doc_491521501976_item	2564062	et	3	main
jne	doc_491521501976_item	2564066	et	4	main
ise	doc_491521501976_item	2564068	et	4	main
tooded	doc_491521501976_item	2564077	et	4	main
võtsin	doc_491521501976_item	2564081	et	3	main
aga	doc_491521501976_item	2564082	et	3	main
müüja	doc_491521501976_item	2564083	et	4	main
ise	doc_491521501976_item	2564084	et	4	main
pani	doc_491521501976_item	2564085	et	4	main
oma	doc_491521501976_item	2564086	et	4	main
allkiri	doc_491521501976_item	2564087	et	3	main
saatelehti	doc_491521501976_item	2564088	et	4	main
pärast	doc_491521501976_item	2564089	et	4	main
nad	doc_491521501976_item	2564090	et	3	main
näitasid	doc_491521501976_item	2564091	et	4	main
mulle	doc_491521501976_item	2564092	et	4	main
ja	doc_491521501976_item	2564093	et	3	main
siis	doc_491521501976_item	2564094	et	3	main
juba	doc_491521501976_item	2564095	et	3	main
mina	doc_491521501976_item	2564096	et	4	main
võtsin	doc_491521501976_item	2564097	et	3	main
vastu	doc_491521501976_item	2564098	et	3	main
ja	doc_491521501976_item	2564099	et	3	main
panin	doc_491521501976_item	2564100	et	3	main
oma	doc_491521501976_item	2564101	et	4	main
allkiri	doc_491521501976_item	2564102	et	3	main
saatelehti	doc_491521501976_item	2564103	et	4	main
tooded	doc_491521501976_item	2564104	et	4	main
toimitavad	doc_491521501976_item	2564105	et	4	main
kaks	doc_491521501976_item	2564106	et	3	main
korda	doc_491521501976_item	2564107	et	4	main
nädalas	doc_491521501976_item	2564108	et	3	main
sai	doc_491521501976_item	2564110	et	4	main
aga	doc_491521501976_item	2564109	et	3	main
ja	doc_491521501976_item	2564111	et	3	main
leib	doc_491521501976_item	2564112	et	3	main
iga	doc_491521501976_item	2564113	et	4	main
päev	doc_491521501976_item	2564114	et	3	main
kaks	doc_491521501976_item	2564115	et	3	main
toimitab	doc_491521501976_item	2564118	et	4	main
tooded	doc_491521501976_item	2564124	et	4	main
jõhvi	doc_491521501976_item	2564126	et	4	main
kui	doc_491521501976_item	2564128	et	3	main
juba	doc_491521501976_item	2564131	et	3	main
möödunud	doc_491521501976_item	2564133	et	4	main
panevad	doc_491521501976_item	2564135	et	4	main
oskan	doc_491521501976_item	2564139	et	3	main
täitasin	doc_491521501976_item	2564142	et	3	main
oli	doc_491521501976_item	2564145	et	3	main
seal	doc_491521501976_item	2564148	et	4	main
suhtlesid	doc_491521501976_item	2564151	et	4	main
ei	doc_491521501976_item	2564155	et	4	main
rääkisin	doc_491521501976_item	2564162	et	3	main
et	doc_491521501976_item	2564168	et	3	main
hea	doc_491521501976_item	2564171	et	4	main
kuus	doc_491521501976_item	2564121	et	4	main
toimitab	doc_491521501976_item	2564123	et	4	main
piimakombitist	doc_491521501976_item	2564127	et	3	main
on	doc_491521501976_item	2564130	et	4	main
parim	doc_491521501976_item	2564132	et	4	main
siis	doc_491521501976_item	2564134	et	3	main
tead	doc_491521501976_item	2564137	et	4	main
töötada	doc_491521501976_item	2564141	et	3	main
mul	doc_491521501976_item	2564144	et	3	main
ära	doc_491521501976_item	2564158	et	4	main
minna	doc_491521501976_item	2564159	et	3	main
ma	doc_491521501976_item	2564173	et	3	main
looda	doc_491521501976_item	2564174	et	4	main
kui	doc_491521501976_item	2564175	et	3	main
lõpetan	doc_491521501976_item	2564176	et	3	main
kursused	doc_491521501976_item	2564177	et	3	main
ma	doc_491521501976_item	2564178	et	3	main
lähen	doc_491521501976_item	2564179	et	3	main
töötada	doc_491521501976_item	2564180	et	3	main
kirjuta	doc_491521501976_item	2564181	et	4	main
mulle	doc_491521501976_item	2564182	et	4	main
ja	doc_491521501976_item	2564183	et	3	main
ma	doc_491521501976_item	2564184	et	3	main
loen	doc_491521501976_item	2564185	et	3	main
hea	doc_491521501976_item	2564186	et	4	main
meelega	doc_491521501976_item	2564187	et	4	main
sinu	doc_491521501976_item	2564188	et	3	main
kiri	doc_491521501976_item	2564189	et	3	main
head	doc_491521501976_item	2564190	et	4	main
aega	doc_491521501976_item	2564191	et	4	main
olesja	doc_491521501976_item	2564192	et	4	main
29082003	doc_491521501976_item	2564193	et	2	main
mina	doc_491521501978_item	2564318	et	4	main
iga	doc_491521501978_item	2564330	et	4	main
päev	doc_491521501978_item	2564331	et	3	main
kell	doc_491521501978_item	2564332	et	3	main
eesti	doc_491521501978_item	2564350	et	4	main
nägemiseni	doc_491521501978_item	2564352	et	4	main
kiri	doc_491521501980_item	2564454	et	3	main
tere	doc_491521501980_item	2564455	et	3	main
õppisin	doc_491521501980_item	2564460	et	3	main
kompleksoskustega	doc_491521501980_item	2564462	et	3	main
praktika	doc_491521501980_item	2564466	et	4	main
tallinn	doc_491521501980_item	2564468	et	4	main
oü	doc_491521501980_item	2564470	et	4	main
tallinn	doc_491521501980_item	2564474	et	4	main
väike	doc_491521501980_item	2564476	et	4	main
turuplats	doc_491521501980_item	2564477	et	3	main
lähedal	doc_491521501980_item	2564483	et	4	main
sul	doc_491521501981_item	2564534	et	3	main
on	doc_491521501981_item	2564550	et	4	main
töötab	doc_491521501981_item	2564553	et	3	main
mul	doc_491521501981_item	2564560	et	3	main
kaks	doc_491521501981_item	2564562	et	3	main
lapselapsed	doc_491521501981_item	2564563	et	3	main
ja	doc_491521501981_item	2564565	et	3	main
valerija	doc_491521501981_item	2564567	et	4	main
kolis	doc_491521501981_item	2564569	et	4	main
klassi	doc_491521501981_item	2564571	et	4	main
ta	doc_491521501981_item	2564572	et	4	main
ijuli	doc_491521501982_item	2564604	et	4	main
teises	doc_491521501982_item	2564610	et	4	main
müüsin	doc_491521501982_item	2564613	et	3	main
toode	doc_491521501978_item	2564320	et	3	main
pood	doc_491521501978_item	2564321	et	4	main
vaike	doc_491521501978_item	2564323	et	3	main
kaheksas	doc_491521501978_item	2564333	et	4	main
on	doc_491521501978_item	2564337	et	4	main
hästi	doc_491521501978_item	2564338	et	3	main
seal	doc_491521501978_item	2564341	et	4	main
poel	doc_491521501978_item	2564344	et	3	main
töötan	doc_491521501978_item	2564345	et	3	main
praegu	doc_491521501978_item	2564346	et	3	main
ma	doc_491521501978_item	2564347	et	3	main
käima	doc_491521501978_item	2564348	et	4	main
keele	doc_491521501978_item	2564351	et	4	main
290803	doc_491521501978_item	2564353	et	2	main
eesnimi	doc_491521501978_item	2564354	et	3	main
kallis	doc_491521501980_item	2564456	et	4	main
sõber	doc_491521501980_item	2564457	et	3	main
rest	doc_491521501980_item	2564471	et	4	main
on	doc_491521501980_item	2564475	et	4	main
pood	doc_491521501980_item	2564480	et	4	main
et	doc_491521501981_item	2564528	et	3	main
sa	doc_491521501981_item	2564529	et	3	main
on	doc_491521501981_item	2564535	et	4	main
hästi	doc_491521501981_item	2564537	et	3	main
praegu	doc_491521501981_item	2564542	et	3	main
sompa	doc_491521501981_item	2564546	et	4	main
kaevanduses	doc_491521501981_item	2564547	et	4	main
kaevandus	doc_491521501981_item	2564549	et	4	main
a	doc_491521501981_item	2564555	et	4	main
nikita	doc_491521501981_item	2564566	et	4	main
2	doc_491521501982_item	2564603	et	2	main
ma	doc_491521501982_item	2564608	et	3	main
inimest	doc_491521501982_item	2564622	et	3	main
keel	doc_491521501982_item	2564633	et	4	main
seal	doc_491521501982_item	2564641	et	4	main
töötada	doc_491521501982_item	2564642	et	3	main
kirjuta	doc_491521501982_item	2564643	et	4	main
kuidas	doc_491521501982_item	2564644	et	3	main
läheb	doc_491521501982_item	2564645	et	3	main
olin	doc_491521501983_item	2564652	et	3	main
võga	doc_491521501983_item	2564659	et	4	main
eesnimi	doc_491521501983_item	2564677	et	3	main
töötasin	doc_491521501984_item	2564681	et	3	main
poes	doc_491521501984_item	2564684	et	3	main
gorispolkoomi	doc_491521501984_item	2564688	et	4	main
ka	doc_491521501984_item	2564702	et	3	main
töötavad	doc_491521501984_item	2564707	et	4	main
kiri	doc_491521501978_item	2564289	et	3	main
tere	doc_491521501978_item	2564290	et	3	main
kallis	doc_491521501978_item	2564291	et	4	main
sõber	doc_491521501978_item	2564292	et	3	main
mina	doc_491521501978_item	2564293	et	4	main
kirjutan	doc_491521501978_item	2564294	et	3	main
sinu	doc_491521501978_item	2564295	et	3	main
kiri	doc_491521501978_item	2564296	et	3	main
mina	doc_491521501978_item	2564297	et	4	main
käima	doc_491521501978_item	2564298	et	4	main
suvel	doc_491521501978_item	2564299	et	3	main
kursusel	doc_491521501978_item	2564300	et	3	main
kompleksoskutega	doc_491521501978_item	2564301	et	4	main
müüja	doc_491521501978_item	2564302	et	4	main
ma	doc_491521501978_item	2564303	et	3	main
õpin	doc_491521501978_item	2564304	et	3	main
oktoobrile	doc_491521501978_item	2564305	et	3	main
ma	doc_491521501978_item	2564306	et	3	main
õpin	doc_491521501978_item	2564307	et	3	main
hommikul	doc_491521501978_item	2564308	et	3	main
iga	doc_491521501978_item	2564309	et	4	main
päev	doc_491521501978_item	2564310	et	3	main
juuli	doc_491521501978_item	2564311	et	4	main
ma	doc_491521501978_item	2564312	et	3	main
käima	doc_491521501978_item	2564313	et	4	main
praktikal	doc_491521501978_item	2564314	et	3	main
ma	doc_491521501978_item	2564315	et	3	main
töötan	doc_491521501978_item	2564316	et	3	main
poodi	doc_491521501978_item	2564317	et	4	main
üheksateist	doc_491521501978_item	2564335	et	4	main
kolliktiiv	doc_491521501978_item	2564336	et	4	main
mulle	doc_491521501978_item	2564339	et	4	main
müüsin	doc_491521501978_item	2564319	et	3	main
poel	doc_491521501978_item	2564324	et	3	main
töötavad	doc_491521501978_item	2564325	et	4	main
kolm	doc_491521501978_item	2564326	et	3	main
inimesed	doc_491521501978_item	2564327	et	3	main
pood	doc_491521501978_item	2564328	et	4	main
töötan	doc_491521501978_item	2564329	et	3	main
meldib	doc_491521501978_item	2564340	et	4	main
ma	doc_491521501978_item	2564342	et	3	main
tahan	doc_491521501978_item	2564343	et	3	main
anna	doc_491521501980_item	2564458	et	4	main
müüja	doc_491521501980_item	2564463	et	4	main
poodi	doc_491521501980_item	2564467	et	4	main
ettevõte	doc_491521501980_item	2564469	et	3	main
pood	doc_491521501980_item	2564473	et	4	main
saal	doc_491521501980_item	2564478	et	3	main
kohtla-järve	doc_491521501980_item	2564482	et	4	main
on	doc_491521501978_item	2564322	et	4	main
kuni	doc_491521501978_item	2564334	et	3	main
kursusel	doc_491521501978_item	2564349	et	3	main
ma	doc_491521501980_item	2564459	et	3	main
käisin	doc_491521501980_item	2564465	et	3	main
agent	doc_491521501980_item	2564472	et	3	main
190m²	doc_491521501980_item	2564479	et	4	main
kirja	doc_491521501981_item	2564521	et	4	main
mul	doc_491521501981_item	2564523	et	3	main
on	doc_491521501981_item	2564524	et	4	main
väga	doc_491521501981_item	2564525	et	3	main
hea	doc_491521501981_item	2564526	et	4	main
et	doc_491521501981_item	2564533	et	3	main
on	doc_491521501981_item	2564539	et	4	main
sulle	doc_491521501981_item	2564540	et	3	main
ma	doc_491521501981_item	2564543	et	3	main
see	doc_491521501981_item	2564548	et	3	main
ta	doc_491521501981_item	2564552	et	4	main
inimest	doc_491521501981_item	2564559	et	3	main
on	doc_491521501981_item	2564561	et	4	main
käib	doc_491521501981_item	2564568	et	3	main
on	doc_491521501981_item	2564574	et	4	main
oli	doc_491521501982_item	2564602	et	3	main
29	doc_491521501982_item	2564606	et	2	main
kopfekti	doc_491521501982_item	2564616	et	4	main
poes	doc_491521501982_item	2564619	et	3	main
12	doc_491521501982_item	2564621	et	2	main
mulle	doc_491521501982_item	2564635	et	4	main
head	doc_491521501982_item	2564646	et	4	main
praktikal	doc_491521501983_item	2564653	et	3	main
pooes	doc_491521501983_item	2564655	et	4	main
töö	doc_491521501983_item	2564657	et	4	main
kus	doc_491521501983_item	2564664	et	3	main
elad	doc_491521501983_item	2564666	et	3	main
praegu	doc_491521501983_item	2564670	et	3	main
ei	doc_491521501983_item	2564672	et	4	main
on	doc_491521501983_item	2564674	et	4	main
koduperenaine	doc_491521501983_item	2564675	et	3	main
nagemmiseni	doc_491521501983_item	2564676	et	4	main
ma	doc_491521501984_item	2564680	et	3	main
asub	doc_491521501984_item	2564686	et	3	main
ja	doc_491521501984_item	2564700	et	3	main
käindsin	doc_491521501984_item	2564703	et	4	main
kaupluses	doc_491521501984_item	2564706	et	3	main
töötan	doc_491521501984_item	2564712	et	3	main
kursusele	doc_491521501980_item	2564461	et	3	main
ma	doc_491521501980_item	2564464	et	3	main
asub	doc_491521501980_item	2564481	et	3	main
plats	doc_491521501980_item	2564484	et	4	main
ma	doc_491521501980_item	2564485	et	3	main
töötab	doc_491521501980_item	2564486	et	3	main
osakond	doc_491521501980_item	2564487	et	3	main
vorst-liha	doc_491521501980_item	2564488	et	4	main
kauplus	doc_491521501980_item	2564489	et	3	main
töötab	doc_491521501980_item	2564490	et	3	main
8ºº-	doc_491521501980_item	2564491	et	4	main
20ºº	doc_491521501980_item	2564492	et	4	main
ma	doc_491521501980_item	2564493	et	3	main
töötab	doc_491521501980_item	2564494	et	3	main
iga	doc_491521501980_item	2564495	et	4	main
kaheksa	doc_491521501980_item	2564497	et	4	main
päiv	doc_491521501980_item	2564496	et	4	main
tundi	doc_491521501980_item	2564498	et	4	main
mulle	doc_491521501980_item	2564499	et	4	main
meeldib	doc_491521501980_item	2564500	et	3	main
poodi	doc_491521501980_item	2564502	et	4	main
töötada	doc_491521501980_item	2564501	et	3	main
ma	doc_491521501980_item	2564503	et	3	main
tahaksin	doc_491521501980_item	2564504	et	3	main
seal	doc_491521501980_item	2564505	et	4	main
töötada	doc_491521501980_item	2564506	et	3	main
aga	doc_491521501980_item	2564507	et	3	main
kuidas	doc_491521501980_item	2564508	et	3	main
laheb	doc_491521501980_item	2564509	et	4	main
anna	doc_491521501980_item	2564510	et	4	main
head	doc_491521501980_item	2564511	et	4	main
aega	doc_491521501980_item	2564512	et	4	main
eesnimi	doc_491521501980_item	2564513	et	3	main
29082003	doc_491521501980_item	2564514	et	2	main
kiri	doc_491521501981_item	2564515	et	3	main
tere	doc_491521501981_item	2564516	et	3	main
kallis	doc_491521501981_item	2564517	et	4	main
tatjana	doc_491521501981_item	2564518	et	4	main
sain	doc_491521501981_item	2564519	et	3	main
sinu	doc_491521501981_item	2564520	et	3	main
meel	doc_491521501981_item	2564527	et	4	main
mulle	doc_491521501981_item	2564530	et	4	main
kätte	doc_491521501981_item	2564522	et	4	main
tore	doc_491521501981_item	2564532	et	3	main
kõik	doc_491521501981_item	2564536	et	4	main
mul	doc_491521501981_item	2564538	et	3	main
uudis	doc_491521501981_item	2564541	et	3	main
olen	doc_491521501981_item	2564544	et	3	main
vana	doc_491521501981_item	2564551	et	4	main
1947	doc_491521501981_item	2564554	et	2	main
kaevurist	doc_491521501981_item	2564556	et	4	main
töötavad	doc_491521501981_item	2564557	et	4	main
kolm	doc_491521501981_item	2564570	et	3	main
hästi	doc_491521501981_item	2564575	et	3	main
nikita	doc_491521501981_item	2564576	et	4	main
on	doc_491521501981_item	2564577	et	4	main
kolm	doc_491521501981_item	2564578	et	3	main
aastad	doc_491521501981_item	2564579	et	3	main
ta	doc_491521501981_item	2564580	et	4	main
käib	doc_491521501981_item	2564581	et	3	main
lastemajast	doc_491521501981_item	2564582	et	4	main
ma	doc_491521501981_item	2564583	et	3	main
ootama	doc_491521501981_item	2564584	et	3	main
sinu	doc_491521501981_item	2564585	et	3	main
kirja	doc_491521501981_item	2564586	et	4	main
nagemiseni	doc_491521501981_item	2564587	et	4	main
kiri	doc_491521501982_item	2564588	et	3	main
tere	doc_491521501982_item	2564589	et	3	main
leno	doc_491521501982_item	2564590	et	4	main
kirjutan	doc_491521501982_item	2564591	et	3	main
eesnimi	doc_491521501982_item	2564592	et	3	main
praktikal	doc_491521501982_item	2564593	et	3	main
ma	doc_491521501982_item	2564594	et	3	main
töotasin	doc_491521501982_item	2564595	et	4	main
kaupluses	doc_491521501982_item	2564596	et	3	main
tallinnas	doc_491521501982_item	2564597	et	4	main
ma	doc_491521501982_item	2564598	et	3	main
töötasin	doc_491521501982_item	2564599	et	3	main
müüjana	doc_491521501982_item	2564600	et	4	main
kirjutasid	doc_491521501981_item	2564531	et	4	main
töötan	doc_491521501981_item	2564545	et	3	main
320	doc_491521501981_item	2564558	et	2	main
valerija	doc_491521501981_item	2564564	et	4	main
õppib	doc_491521501981_item	2564573	et	4	main
praktika	doc_491521501982_item	2564601	et	4	main
kuni	doc_491521501982_item	2564605	et	3	main
töötasin	doc_491521501982_item	2564609	et	3	main
osakonnas	doc_491521501982_item	2564611	et	4	main
küpsisse	doc_491521501982_item	2564617	et	3	main
sigaeti	doc_491521501982_item	2564618	et	4	main
töötavad	doc_491521501982_item	2564620	et	4	main
hea	doc_491521501982_item	2564625	et	4	main
töopäev	doc_491521501982_item	2564627	et	4	main
meeldis	doc_491521501982_item	2564636	et	3	main
seal	doc_491521501982_item	2564637	et	4	main
ma	doc_491521501982_item	2564639	et	3	main
kiri	doc_491521501983_item	2564648	et	3	main
tere	doc_491521501983_item	2564649	et	3	main
lena	doc_491521501983_item	2564650	et	4	main
mina	doc_491521501983_item	2564651	et	4	main
mulle	doc_491521501983_item	2564658	et	4	main
meeldis	doc_491521501983_item	2564660	et	3	main
suu	doc_491521501983_item	2564662	et	4	main
elan	doc_491521501983_item	2564668	et	3	main
ma	doc_491521501983_item	2564671	et	3	main
29082003	doc_491521501983_item	2564678	et	2	main
praktikal	doc_491521501984_item	2564682	et	3	main
pood	doc_491521501984_item	2564685	et	4	main
mulle	doc_491521501984_item	2564691	et	4	main
küpsised	doc_491521501984_item	2564699	et	3	main
samuti	doc_491521501984_item	2564701	et	3	main
kaubad	doc_491521501984_item	2564705	et	3	main
inemesed	doc_491521501984_item	2564709	et	4	main
meiega	doc_491521501986_item	2564817	et	4	main
väga	doc_491521501986_item	2564842	et	3	main
küme	doc_491521501986_item	2564845	et	4	main
sõpralik	doc_491521501986_item	2564850	et	4	main
ma	doc_491521501986_item	2564856	et	3	main
poeg	doc_491521501986_item	2564861	et	3	main
õpima	doc_491521501986_item	2564863	et	4	main
klassis	doc_491521501986_item	2564865	et	3	main
hommikust	doc_491521501987_item	2564894	et	4	main
iga	doc_491521501987_item	2564901	et	4	main
tundasin	doc_491521501987_item	2564904	et	4	main
tahaksin	doc_491521501987_item	2564908	et	3	main
seal	doc_491521501987_item	2564909	et	4	main
aga	doc_491521501987_item	2564911	et	3	main
kurjuta	doc_491521501987_item	2564914	et	3	main
mulle	doc_491521501987_item	2564915	et	4	main
sõber	doc_491521501988_item	2564923	et	3	main
kuidas	doc_491521501988_item	2564924	et	3	main
käisin	doc_491521501988_item	2564931	et	3	main
praktikal	doc_491521501988_item	2564932	et	3	main
ma	doc_491521501988_item	2564934	et	3	main
kaupluses	doc_491521501988_item	2564936	et	3	main
ma	doc_491521501988_item	2564940	et	3	main
mulle	doc_491521501988_item	2564947	et	4	main
suvel	doc_491521501988_item	2564960	et	3	main
kallis	doc_491521501989_item	2564971	et	4	main
lühike	doc_491521501989_item	2564976	et	4	main
kiri	doc_491521501989_item	2564977	et	3	main
ma	doc_491521501989_item	2564978	et	3	main
tahan	doc_491521501989_item	2564979	et	3	main
sulle	doc_491521501989_item	2564980	et	3	main
uudist	doc_491521501989_item	2564981	et	3	main
teatama	doc_491521501989_item	2564982	et	4	main
ja	doc_491521501989_item	2564986	et	3	main
ei	doc_491521501989_item	2565021	et	4	main
aega	doc_491521501989_item	2565023	et	4	main
kirjuta	doc_491521501989_item	2565024	et	4	main
ijuli	doc_491521501982_item	2564607	et	4	main
ma	doc_491521501982_item	2564612	et	3	main
vaina	doc_491521501982_item	2564614	et	4	main
kooki	doc_491521501982_item	2564615	et	4	main
on	doc_491521501982_item	2564624	et	4	main
minu	doc_491521501982_item	2564626	et	3	main
kell	doc_491521501982_item	2564629	et	3	main
kaheksa	doc_491521501982_item	2564630	et	4	main
ja	doc_491521501982_item	2564631	et	3	main
lõppus	doc_491521501982_item	2564632	et	4	main
aega	doc_491521501982_item	2564647	et	4	main
läheb	doc_491521501983_item	2564663	et	3	main
sa	doc_491521501983_item	2564665	et	3	main
tööta	doc_491521501983_item	2564673	et	4	main
juures	doc_491521501984_item	2564689	et	4	main
uued	doc_491521501984_item	2564704	et	3	main
ma	doc_491521501984_item	2564710	et	3	main
tahan	doc_491521501984_item	2564711	et	3	main
essee	doc_491521501986_item	2564810	et	4	main
kollektiv	doc_491521501982_item	2564623	et	4	main
algas	doc_491521501982_item	2564628	et	3	main
neli	doc_491521501982_item	2564634	et	3	main
töötada	doc_491521501982_item	2564638	et	3	main
tahan	doc_491521501982_item	2564640	et	3	main
töötasin	doc_491521501983_item	2564654	et	3	main
ehitusabc	doc_491521501983_item	2564656	et	4	main
kuidas	doc_491521501983_item	2564661	et	3	main
ma	doc_491521501983_item	2564667	et	3	main
jõhvis	doc_491521501983_item	2564669	et	3	main
kiri	doc_491521501984_item	2564679	et	3	main
toidu	doc_491521501984_item	2564683	et	3	main
jõhvis	doc_491521501984_item	2564687	et	3	main
praktikal	doc_491521501984_item	2564690	et	3	main
väga	doc_491521501984_item	2564692	et	3	main
meeldib	doc_491521501984_item	2564693	et	3	main
iga	doc_491521501984_item	2564694	et	4	main
päev	doc_491521501984_item	2564695	et	3	main
ma	doc_491521501984_item	2564696	et	3	main
teen	doc_491521501984_item	2564697	et	3	main
kaubad	doc_491521501984_item	2564698	et	3	main
seitse	doc_491521501984_item	2564708	et	3	main
sellel	doc_491521501984_item	2564713	et	4	main
kaupluses	doc_491521501984_item	2564714	et	3	main
eesnimi	doc_491521501984_item	2564715	et	3	main
töö	doc_491521501986_item	2564812	et	4	main
ma	doc_491521501986_item	2564813	et	3	main
töötasin	doc_491521501986_item	2564814	et	3	main
firmas	doc_491521501986_item	2564815	et	3	main
müüna	doc_491521501986_item	2564816	et	3	main
palju	doc_491521501986_item	2564819	et	4	main
sealiha	doc_491521501986_item	2564825	et	4	main
ja	doc_491521501986_item	2564827	et	3	main
veel	doc_491521501986_item	2564833	et	4	main
hombarasta	doc_491521501986_item	2564838	et	4	main
kõigest	doc_491521501986_item	2564844	et	4	main
tötasid	doc_491521501986_item	2564848	et	4	main
tööta	doc_491521501986_item	2564858	et	4	main
minu	doc_491521501986_item	2564860	et	3	main
töötasin	doc_491521501987_item	2564881	et	3	main
osakondi	doc_491521501987_item	2564882	et	4	main
olid	doc_491521501987_item	2564885	et	4	main
kuueda	doc_491521501987_item	2564895	et	4	main
väga	doc_491521501987_item	2564898	et	3	main
ma	doc_491521501987_item	2564907	et	3	main
kuidas	doc_491521501987_item	2564912	et	3	main
eesnimi	doc_491521501987_item	2564918	et	3	main
väga	doc_491521501988_item	2564927	et	3	main
ijuulis	doc_491521501988_item	2564929	et	4	main
töötasin	doc_491521501988_item	2564935	et	3	main
teen	doc_491521501988_item	2564945	et	3	main
seal	doc_491521501988_item	2564949	et	4	main
see	doc_491521501988_item	2564954	et	3	main
töö	doc_491521501988_item	2564956	et	4	main
musi	doc_491521501988_item	2564966	et	4	main
kiri	doc_491521501989_item	2564969	et	3	main
ma	doc_491521501989_item	2564973	et	3	main
sulle	doc_491521501989_item	2564975	et	3	main
pood	doc_491521501989_item	2564995	et	4	main
oli	doc_491521501986_item	2564818	et	3	main
mitmendased	doc_491521501986_item	2564820	et	4	main
toiduainedkohvi	doc_491521501986_item	2564821	et	4	main
tee	doc_491521501986_item	2564823	et	4	main
mineral	doc_491521501986_item	2564830	et	4	main
deodororanti	doc_491521501986_item	2564837	et	4	main
oli	doc_491521501986_item	2564841	et	3	main
oli	doc_491521501986_item	2564849	et	3	main
praegu	doc_491521501986_item	2564855	et	3	main
ei	doc_491521501986_item	2564857	et	4	main
kaubad	doc_491521501987_item	2564887	et	3	main
lampid	doc_491521501987_item	2564889	et	4	main
tapeedid	doc_491521501987_item	2564890	et	4	main
mulle	doc_491521501987_item	2564897	et	4	main
meeldib	doc_491521501987_item	2564899	et	3	main
päev	doc_491521501987_item	2564902	et	3	main
29082003	doc_491521501987_item	2564919	et	2	main
kiri	doc_491521501988_item	2564920	et	3	main
tere	doc_491521501988_item	2564921	et	3	main
hästi	doc_491521501988_item	2564928	et	3	main
ma	doc_491521501988_item	2564930	et	3	main
praktikal	doc_491521501988_item	2564933	et	3	main
kalev	doc_491521501988_item	2564937	et	3	main
lilled	doc_491521501988_item	2564942	et	3	main
ja	doc_491521501988_item	2564943	et	3	main
meeldis	doc_491521501988_item	2564948	et	3	main
seal	doc_491521501988_item	2564952	et	4	main
millena	doc_491521501988_item	2564957	et	3	main
tegelesib	doc_491521501988_item	2564959	et	4	main
kirjuta	doc_491521501988_item	2564961	et	4	main
kõik	doc_491521501988_item	2564965	et	4	main
ma	doc_491521501989_item	2564983	et	3	main
pärast	doc_491521501989_item	2564987	et	4	main
poodis	doc_491521501989_item	2564989	et	4	main
minu	doc_491521501986_item	2564811	et	3	main
makaronid	doc_491521501986_item	2564822	et	3	main
maionez	doc_491521501986_item	2564826	et	4	main
limonad	doc_491521501986_item	2564829	et	4	main
vesi	doc_491521501986_item	2564831	et	4	main
kollektiv	doc_491521501986_item	2564840	et	4	main
kõik	doc_491521501986_item	2564847	et	4	main
kõigele	doc_491521501986_item	2564852	et	4	main
hea	doc_491521501986_item	2564854	et	4	main
sest	doc_491521501986_item	2564859	et	4	main
hakkas	doc_491521501986_item	2564862	et	3	main
esimes	doc_491521501986_item	2564864	et	4	main
elektrikaubad	doc_491521501987_item	2564883	et	3	main
palju	doc_491521501987_item	2564886	et	4	main
ilused	doc_491521501987_item	2564888	et	3	main
kauplus	doc_491521501987_item	2564891	et	3	main
töötab	doc_491521501987_item	2564892	et	3	main
kümmnendas	doc_491521501987_item	2564893	et	4	main
õhtuni	doc_491521501987_item	2564896	et	3	main
seal	doc_491521501987_item	2564900	et	4	main
ma	doc_491521501987_item	2564903	et	3	main
palju	doc_491521501987_item	2564905	et	4	main
head	doc_491521501987_item	2564916	et	4	main
lillepoos	doc_491521501988_item	2564938	et	3	main
müüsin	doc_491521501988_item	2564941	et	3	main
lillekimp	doc_491521501988_item	2564946	et	3	main
tahaksin	doc_491521501988_item	2564951	et	3	main
töötada	doc_491521501988_item	2564953	et	3	main
sa	doc_491521501988_item	2564958	et	3	main
vastukiri	doc_491521501988_item	2564962	et	3	main
on	doc_491521501988_item	2564964	et	4	main
29082003	doc_491521501988_item	2564967	et	2	main
tere	doc_491521501989_item	2564970	et	3	main
tatjana	doc_491521501989_item	2564972	et	4	main
kirjutan	doc_491521501989_item	2564974	et	3	main
kursusel	doc_491521501989_item	2564985	et	3	main
ole	doc_491521501989_item	2565022	et	4	main
aega	doc_491521501989_item	2565030	et	4	main
kohvikat	doc_491521501986_item	2564824	et	4	main
puuviljad	doc_491521501986_item	2564828	et	3	main
ja	doc_491521501986_item	2564832	et	3	main
palju	doc_491521501986_item	2564834	et	4	main
muud	doc_491521501986_item	2564835	et	4	main
pesupulber	doc_491521501986_item	2564836	et	3	main
meie	doc_491521501986_item	2564839	et	4	main
väike	doc_491521501986_item	2564843	et	4	main
inumest	doc_491521501986_item	2564846	et	4	main
iseloom	doc_491521501986_item	2564851	et	3	main
oli	doc_491521501986_item	2564853	et	3	main
kiri	doc_491521501987_item	2564866	et	3	main
tere	doc_491521501987_item	2564867	et	3	main
irina	doc_491521501987_item	2564868	et	3	main
suvel	doc_491521501987_item	2564869	et	3	main
ma	doc_491521501987_item	2564870	et	3	main
käisisn	doc_491521501987_item	2564871	et	4	main
kursussele	doc_491521501987_item	2564872	et	4	main
kompleksoskustega	doc_491521501987_item	2564873	et	3	main
müüja	doc_491521501987_item	2564874	et	4	main
praktikast	doc_491521501987_item	2564875	et	4	main
ma	doc_491521501987_item	2564876	et	3	main
käisin	doc_491521501987_item	2564877	et	3	main
kaupluses	doc_491521501987_item	2564878	et	3	main
volta	doc_491521501987_item	2564879	et	4	main
ma	doc_491521501987_item	2564880	et	3	main
seal	doc_491521501987_item	2564884	et	4	main
uue	doc_491521501987_item	2564906	et	3	main
töötada	doc_491521501987_item	2564910	et	3	main
läheb	doc_491521501987_item	2564913	et	3	main
aega	doc_491521501987_item	2564917	et	4	main
kallis	doc_491521501988_item	2564922	et	4	main
käib	doc_491521501988_item	2564925	et	3	main
mul	doc_491521501988_item	2564926	et	3	main
osakonnas	doc_491521501988_item	2564939	et	4	main
õppisin	doc_491521501988_item	2564944	et	3	main
ma	doc_491521501988_item	2564950	et	3	main
ülihuvitav	doc_491521501988_item	2564955	et	3	main
seniks	doc_491521501988_item	2564963	et	3	main
eesnimi	doc_491521501988_item	2564968	et	3	main
õppisin	doc_491521501989_item	2564984	et	3	main
töötasin	doc_491521501989_item	2564988	et	3	main
see	doc_491521501989_item	2564990	et	3	main
on	doc_491521501989_item	2564991	et	4	main
suur	doc_491521501989_item	2564992	et	3	main
ja	doc_491521501989_item	2564993	et	3	main
hea	doc_491521501989_item	2564994	et	4	main
juures	doc_491521501989_item	2564999	et	4	main
ta	doc_491521501989_item	2565000	et	4	main
avatud	doc_491521501989_item	2565001	et	4	main
kell	doc_491521501989_item	2565002	et	3	main
9ºº	doc_491521501989_item	2565003	et	4	main
ja	doc_491521501989_item	2565004	et	3	main
suletud	doc_491521501989_item	2565005	et	4	main
21ºº	doc_491521501989_item	2565006	et	4	main
ma	doc_491521501989_item	2565007	et	3	main
sõidsin	doc_491521501989_item	2565008	et	4	main
autobussile	doc_491521501989_item	2565009	et	3	main
hommikul	doc_491521501989_item	2565010	et	3	main
kell	doc_491521501989_item	2565011	et	3	main
7³º	doc_491521501989_item	2565012	et	4	main
mulle	doc_491521501989_item	2565013	et	4	main
väga	doc_491521501989_item	2565014	et	3	main
meeldib	doc_491521501989_item	2565015	et	3	main
töötada	doc_491521501989_item	2565016	et	3	main
poodis	doc_491521501989_item	2565017	et	4	main
no	doc_491521501989_item	2565018	et	3	main
mul	doc_491521501989_item	2565020	et	3	main
kõik	doc_491521501989_item	2565019	et	4	main
head	doc_491521501989_item	2565029	et	4	main
nägemiseni	doc_491521501989_item	2565031	et	4	main
29082003	doc_491521501989_item	2565032	et	2	main
eesnimi	doc_491521501989_item	2565033	et	3	main
ta	doc_491521501989_item	2564996	et	4	main
asub	doc_491521501989_item	2564997	et	3	main
vanakiirikas	doc_491521501989_item	2564998	et	4	main
mulle	doc_491521501989_item	2565026	et	4	main
läheb	doc_491521501989_item	2565028	et	3	main
kuidas	doc_491521501989_item	2565027	et	3	main
palun	doc_491521501989_item	2565025	et	3	main
ja	doc_491521501992_item	2565361	et	3	main
pere	doc_491521501992_item	2565363	et	4	main
eesnimi	doc_491521501992_item	2565367	et	3	main
kolm	doc_491521501992_item	2565369	et	3	main
poeg	doc_491521501992_item	2565381	et	3	main
tal	doc_491521501992_item	2565384	et	3	main
käeb	doc_491521501992_item	2565390	et	4	main
mina	doc_491521501992_item	2565360	et	4	main
ta	doc_491521501992_item	2565375	et	4	main
norem	doc_491521501992_item	2565388	et	4	main
kursusule	doc_491521501994_item	2565635	et	4	main
praktika	doc_491521501994_item	2565638	et	4	main
kosmeetika	doc_491521501994_item	2565642	et	4	main
parfümeerija	doc_491521501994_item	2565644	et	4	main
meil	doc_491521501994_item	2565651	et	4	main
nimi	doc_491521501992_item	2565365	et	3	main
õppip	doc_491521501992_item	2565376	et	4	main
kesk	doc_491521501992_item	2565380	et	3	main
käib	doc_491521501992_item	2565382	et	3	main
essee	doc_491521501994_item	2565593	et	4	main
kutsekoolis	doc_491521501994_item	2565623	et	4	main
koolis	doc_491521501994_item	2565627	et	4	main
ma	doc_491521501994_item	2565629	et	3	main
olen	doc_491521501994_item	2565630	et	3	main
töötu	doc_491521501994_item	2565631	et	4	main
õpib	doc_491521501994_item	2565632	et	3	main
juulis	doc_491521501994_item	2565636	et	3	main
töötasin	doc_491521501994_item	2565640	et	3	main
on	doc_491521501994_item	2565652	et	4	main
kolm	doc_491521501994_item	2565654	et	3	main
mul	doc_491521501994_item	2565656	et	3	main
must	doc_491521501994_item	2565659	et	4	main
üksteist	doc_491521501994_item	2565663	et	4	main
on	doc_491521501994_item	2565667	et	4	main
ja	doc_491521501994_item	2565669	et	3	main
suvel	doc_491521501994_item	2565671	et	3	main
me	doc_491521501994_item	2565672	et	4	main
puhkasime	doc_491521501994_item	2565673	et	3	main
perekonnanimi	doc_491521501995_item	2565683	et	3	main
vana	doc_491521501995_item	2565703	et	4	main
on	doc_491521501995_item	2565705	et	4	main
abielus	doc_491521501995_item	2565715	et	4	main
nad	doc_491521501995_item	2565716	et	3	main
õpivad	doc_491521501995_item	2565717	et	3	main
õpib	doc_491521501995_item	2565722	et	3	main
õhutl	doc_491521501995_item	2565727	et	4	main
pere	doc_491521501995_item	2565729	et	4	main
vaatan	doc_491521501995_item	2565734	et	3	main
tütar	doc_491521501995_item	2565736	et	3	main
on	doc_491521501995_item	2565752	et	4	main
väga	doc_491521501995_item	2565753	et	3	main
ilus	doc_491521501995_item	2565754	et	4	main
ja	doc_491521501995_item	2565755	et	3	main
minu	doc_491521501992_item	2565364	et	3	main
vanem	doc_491521501992_item	2565371	et	4	main
pois	doc_491521501992_item	2565372	et	3	main
seitseteist	doc_491521501992_item	2565373	et	4	main
aastana	doc_491521501992_item	2565374	et	3	main
teine	doc_491521501992_item	2565378	et	3	main
on	doc_491521501992_item	2565385	et	4	main
aastana	doc_491521501992_item	2565387	et	3	main
poeg	doc_491521501992_item	2565389	et	3	main
evgeni	doc_491521501994_item	2565621	et	4	main
praegu	doc_491521501994_item	2565628	et	3	main
me	doc_491521501994_item	2565648	et	4	main
elame	doc_491521501994_item	2565649	et	3	main
lemmikloom	doc_491521501994_item	2565658	et	3	main
on	doc_491521501994_item	2565662	et	4	main
ta	doc_491521501994_item	2565666	et	4	main
pehme	doc_491521501994_item	2565670	et	4	main
nimi	doc_491521501995_item	2565678	et	3	main
eesnimi	doc_491521501995_item	2565680	et	3	main
on	doc_491521501995_item	2565682	et	4	main
vana	doc_491521501995_item	2565687	et	4	main
on	doc_491521501995_item	2565689	et	4	main
abielus	doc_491521501995_item	2565690	et	4	main
essee	doc_491521501992_item	2565359	et	4	main
minu	doc_491521501992_item	2565362	et	3	main
on	doc_491521501992_item	2565366	et	4	main
minu	doc_491521501992_item	2565368	et	3	main
last	doc_491521501992_item	2565370	et	4	main
kutsekoolis	doc_491521501992_item	2565377	et	4	main
kursuse	doc_491521501992_item	2565379	et	3	main
koolis	doc_491521501992_item	2565383	et	4	main
kusteist	doc_491521501992_item	2565386	et	4	main
on	doc_491521501992_item	2565391	et	4	main
esimene	doc_491521501992_item	2565392	et	3	main
klassis	doc_491521501992_item	2565393	et	3	main
tal	doc_491521501992_item	2565394	et	3	main
on	doc_491521501992_item	2565395	et	4	main
aastana	doc_491521501992_item	2565397	et	3	main
setse	doc_491521501992_item	2565396	et	4	main
ma	doc_491521501992_item	2565398	et	3	main
elan	doc_491521501992_item	2565399	et	3	main
majas	doc_491521501992_item	2565400	et	3	main
kolme	doc_491521501992_item	2565401	et	4	main
korused	doc_491521501992_item	2565402	et	4	main
minu	doc_491521501992_item	2565403	et	3	main
on	doc_491521501992_item	2565404	et	4	main
kahe	doc_491521501992_item	2565405	et	3	main
toa	doc_491521501992_item	2565406	et	3	main
maja	doc_491521501992_item	2565407	et	4	main
juures	doc_491521501992_item	2565408	et	4	main
asub	doc_491521501992_item	2565409	et	3	main
limonaditehas	doc_491521501992_item	2565410	et	4	main
samuti	doc_491521501992_item	2565411	et	3	main
meel	doc_491521501992_item	2565412	et	4	main
on	doc_491521501992_item	2565413	et	4	main
väga	doc_491521501992_item	2565414	et	3	main
ilus	doc_491521501992_item	2565415	et	4	main
õu	doc_491521501992_item	2565416	et	4	main
seal	doc_491521501992_item	2565417	et	4	main
mängivad	doc_491521501992_item	2565418	et	4	main
lapsed	doc_491521501992_item	2565419	et	3	main
eesti	doc_491521501994_item	2565633	et	4	main
ma	doc_491521501994_item	2565639	et	3	main
idlas	doc_491521501994_item	2565650	et	4	main
tubaw	doc_491521501994_item	2565655	et	4	main
kass	doc_491521501994_item	2565660	et	3	main
vana	doc_491521501994_item	2565664	et	4	main
essee	doc_491521501995_item	2565676	et	4	main
on	doc_491521501995_item	2565679	et	4	main
on	doc_491521501995_item	2565685	et	4	main
mees	doc_491521501995_item	2565692	et	4	main
nimi	doc_491521501995_item	2565693	et	3	main
on	doc_491521501995_item	2565694	et	4	main
teil	doc_491521501995_item	2565699	et	4	main
mina	doc_491521501994_item	2565594	et	4	main
ja	doc_491521501994_item	2565595	et	3	main
minu	doc_491521501994_item	2565596	et	3	main
pere	doc_491521501994_item	2565597	et	4	main
mul	doc_491521501994_item	2565598	et	3	main
on	doc_491521501994_item	2565599	et	4	main
pere	doc_491521501994_item	2565600	et	4	main
kolm	doc_491521501994_item	2565601	et	3	main
inimesed	doc_491521501994_item	2565602	et	3	main
mina	doc_491521501994_item	2565603	et	4	main
ja	doc_491521501994_item	2565604	et	3	main
kaks	doc_491521501994_item	2565605	et	3	main
poega	doc_491521501994_item	2565606	et	4	main
vanem	doc_491521501994_item	2565607	et	4	main
poeg	doc_491521501994_item	2565608	et	3	main
evgeni	doc_491521501994_item	2565609	et	4	main
tal	doc_491521501994_item	2565610	et	3	main
on	doc_491521501994_item	2565611	et	4	main
seitsmeneteist	doc_491521501994_item	2565612	et	4	main
aastane	doc_491521501994_item	2565613	et	4	main
noorem	doc_491521501994_item	2565614	et	4	main
poeg	doc_491521501994_item	2565615	et	3	main
vledislav	doc_491521501994_item	2565616	et	4	main
tal	doc_491521501994_item	2565617	et	3	main
on	doc_491521501994_item	2565618	et	4	main
viieneteist	doc_491521501994_item	2565619	et	4	main
aastane	doc_491521501994_item	2565620	et	4	main
õpib	doc_491521501994_item	2565622	et	3	main
aga	doc_491521501994_item	2565624	et	3	main
vladislav	doc_491521501994_item	2565625	et	4	main
õpib	doc_491521501994_item	2565626	et	3	main
keelt	doc_491521501994_item	2565634	et	4	main
oli	doc_491521501994_item	2565637	et	3	main
poodis	doc_491521501994_item	2565641	et	4	main
ja	doc_491521501994_item	2565643	et	3	main
mul	doc_491521501994_item	2565645	et	3	main
väga	doc_491521501994_item	2565646	et	3	main
meeldiv	doc_491521501994_item	2565647	et	4	main
korter	doc_491521501994_item	2565653	et	3	main
on	doc_491521501994_item	2565657	et	4	main
tal	doc_491521501994_item	2565661	et	3	main
peipsijärve	doc_491521501994_item	2565674	et	4	main
minu	doc_491521501995_item	2565677	et	3	main
perekonnanimi	doc_491521501995_item	2565681	et	3	main
on	doc_491521501995_item	2565700	et	4	main
koolis	doc_491521501995_item	2565718	et	4	main
minu	doc_491521501995_item	2565719	et	3	main
tütar	doc_491521501995_item	2565720	et	3	main
koolis	doc_491521501995_item	2565723	et	4	main
mees	doc_491521501995_item	2565733	et	4	main
raamt	doc_491521501995_item	2565738	et	4	main
joonistab	doc_491521501995_item	2565741	et	3	main
on	doc_491521501995_item	2565743	et	4	main
kohtla-jarvel	doc_491521501996_item	2565779	et	4	main
perekonnas	doc_491521501996_item	2565789	et	4	main
ja	doc_491521501996_item	2565796	et	3	main
ajas	doc_491521501996_item	2565805	et	4	main
ta	doc_491521501996_item	2565811	et	4	main
töötab	doc_491521501996_item	2565812	et	3	main
autojunti	doc_491521501996_item	2565813	et	4	main
on	doc_491521501996_item	2565816	et	4	main
ma	doc_491521501996_item	2565821	et	3	main
mul	doc_491521501996_item	2565826	et	3	main
venemaal	doc_491521501996_item	2565834	et	4	main
minu	doc_491521501996_item	2565835	et	3	main
vanaisa	doc_491521501996_item	2565836	et	4	main
elab	doc_491521501996_item	2565837	et	3	main
jõhvis	doc_491521501996_item	2565838	et	3	main
mul	doc_491521501996_item	2565839	et	3	main
aastat	doc_491521501994_item	2565665	et	3	main
suur	doc_491521501994_item	2565668	et	3	main
ääres	doc_491521501994_item	2565675	et	4	main
mul	doc_491521501995_item	2565684	et	3	main
48aastat	doc_491521501995_item	2565686	et	3	main
mina	doc_491521501995_item	2565688	et	4	main
vladimir	doc_491521501995_item	2565695	et	4	main
ta	doc_491521501995_item	2565696	et	4	main
50	doc_491521501995_item	2565701	et	2	main
meil	doc_491521501995_item	2565704	et	4	main
kaks	doc_491521501995_item	2565706	et	3	main
lapsed	doc_491521501995_item	2565707	et	3	main
poeg	doc_491521501995_item	2565708	et	3	main
ja	doc_491521501995_item	2565709	et	3	main
tütar	doc_491521501995_item	2565710	et	3	main
minu	doc_491521501995_item	2565711	et	3	main
poeg	doc_491521501995_item	2565712	et	3	main
on	doc_491521501995_item	2565713	et	4	main
ka	doc_491521501995_item	2565714	et	3	main
ka	doc_491521501995_item	2565721	et	3	main
hästi	doc_491521501995_item	2565726	et	3	main
minu	doc_491521501995_item	2565728	et	3	main
kodus	doc_491521501995_item	2565732	et	4	main
telerit	doc_491521501995_item	2565735	et	3	main
telerit	doc_491521501995_item	2565740	et	3	main
kassi	doc_491521501995_item	2565750	et	4	main
ta	doc_491521501995_item	2565757	et	4	main
inimest	doc_491521501996_item	2565792	et	3	main
minu	doc_491521501996_item	2565798	et	3	main
õpetaja	doc_491521501996_item	2565806	et	4	main
minu	doc_491521501996_item	2565807	et	3	main
isa	doc_491521501996_item	2565808	et	4	main
minu	doc_491521501996_item	2565814	et	3	main
õppin	doc_491521501996_item	2565822	et	4	main
kompleksoskustega	doc_491521501996_item	2565824	et	3	main
on	doc_491521501996_item	2565827	et	4	main
vanaema	doc_491521501996_item	2565828	et	4	main
ja	doc_491521501996_item	2565829	et	3	main
on	doc_491521501996_item	2565840	et	4	main
sõber	doc_491521501996_item	2565841	et	3	main
elan	doc_491521501998_item	2565944	et	3	main
eesti	doc_491521501998_item	2565961	et	4	main
keelt	doc_491521501998_item	2565962	et	4	main
see	doc_491521501998_item	2565972	et	3	main
mina	doc_491521501998_item	2565988	et	4	main
õppida	doc_491521501998_item	2565995	et	3	main
mind	doc_491521501998_item	2566002	et	4	main
eestile	doc_491521501998_item	2566003	et	3	main
lasteaiale	doc_491521501998_item	2566004	et	4	main
kui	doc_491521501998_item	2566010	et	3	main
klass	doc_491521501998_item	2566013	et	3	main
gümnaasiumi	doc_491521501998_item	2566017	et	4	main
keeles	doc_491521501998_item	2566019	et	4	main
et	doc_491521501998_item	2566022	et	3	main
on	doc_491521501998_item	2566037	et	4	main
keelt	doc_491521501998_item	2566044	et	4	main
koolis	doc_491521501998_item	2566050	et	4	main
päev	doc_491521501998_item	2566052	et	3	main
tähtis	doc_491521501998_item	2566069	et	4	main
vaatan	doc_491521501998_item	2566075	et	3	main
sõnastikule	doc_491521501998_item	2566087	et	3	main
ja	doc_491521501998_item	2566088	et	3	main
pähe	doc_491521501998_item	2566091	et	4	main
kasutasin	doc_491521501998_item	2566109	et	3	main
ise	doc_491521501998_item	2566122	et	4	main
ja	doc_491521501998_item	2566123	et	3	main
sõnaraamat	doc_491521501998_item	2566124	et	3	main
kasutan	doc_491521501998_item	2566125	et	3	main
väga	doc_491521501998_item	2566126	et	3	main
eestlane	doc_491521501998_item	2566133	et	3	main
igal	doc_491521501998_item	2566140	et	3	main
õhtul	doc_491521501998_item	2566141	et	3	main
minu	doc_491521501995_item	2565691	et	3	main
on	doc_491521501995_item	2565697	et	4	main
autojuht	doc_491521501995_item	2565698	et	3	main
aastat	doc_491521501995_item	2565702	et	3	main
õpib	doc_491521501995_item	2565725	et	3	main
on	doc_491521501995_item	2565730	et	4	main
loeb	doc_491521501995_item	2565737	et	3	main
vaatab	doc_491521501995_item	2565739	et	3	main
meil	doc_491521501995_item	2565742	et	4	main
must	doc_491521501995_item	2565744	et	4	main
kass	doc_491521501995_item	2565745	et	3	main
minu	doc_491521501995_item	2565746	et	3	main
pere	doc_491521501995_item	2565747	et	4	main
armastab	doc_491521501995_item	2565748	et	3	main
see	doc_491521501995_item	2565749	et	3	main
rõõmus	doc_491521501995_item	2565756	et	4	main
eesnimi	doc_491521501996_item	2565776	et	3	main
xxxxxx	doc_491521501996_item	2565783	et	4	main
mina	doc_491521501996_item	2565793	et	4	main
laste	doc_491521501996_item	2565804	et	4	main
nikolai	doc_491521501996_item	2565810	et	4	main
õppib	doc_491521501996_item	2565819	et	4	main
koolis	doc_491521501996_item	2565820	et	4	main
ta	doc_491521501995_item	2565724	et	4	main
kõik	doc_491521501995_item	2565731	et	4	main
ta	doc_491521501995_item	2565751	et	4	main
on	doc_491521501995_item	2565758	et	4	main
palju	doc_491521501995_item	2565759	et	4	main
mängib	doc_491521501995_item	2565760	et	3	main
ja	doc_491521501995_item	2565761	et	3	main
palju	doc_491521501995_item	2565762	et	4	main
magab	doc_491521501995_item	2565763	et	3	main
mulle	doc_491521501995_item	2565764	et	4	main
meeldib	doc_491521501995_item	2565765	et	3	main
minu	doc_491521501995_item	2565766	et	3	main
pere	doc_491521501995_item	2565767	et	4	main
essee	doc_491521501996_item	2565768	et	4	main
mina	doc_491521501996_item	2565769	et	4	main
ja	doc_491521501996_item	2565770	et	3	main
mina	doc_491521501996_item	2565771	et	4	main
pere	doc_491521501996_item	2565772	et	4	main
minu	doc_491521501996_item	2565773	et	3	main
nimi	doc_491521501996_item	2565774	et	3	main
on	doc_491521501996_item	2565775	et	4	main
ma	doc_491521501996_item	2565777	et	3	main
minu	doc_491521501996_item	2565780	et	3	main
on	doc_491521501996_item	2565790	et	4	main
neli	doc_491521501996_item	2565791	et	3	main
vend	doc_491521501996_item	2565797	et	3	main
on	doc_491521501996_item	2565800	et	4	main
ta	doc_491521501996_item	2565802	et	4	main
töötab	doc_491521501996_item	2565803	et	3	main
on	doc_491521501996_item	2565809	et	4	main
vend	doc_491521501996_item	2565815	et	3	main
vanaema	doc_491521501996_item	2565832	et	4	main
elab	doc_491521501996_item	2565833	et	3	main
eestlane	doc_491521501996_item	2565844	et	3	main
kõik	doc_491521501996_item	2565845	et	4	main
essee	doc_491521501998_item	2565937	et	4	main
õpin	doc_491521501998_item	2565940	et	3	main
keelt	doc_491521501998_item	2565942	et	4	main
meie	doc_491521501998_item	2565963	et	4	main
ei	doc_491521501998_item	2565973	et	4	main
me	doc_491521501998_item	2565976	et	4	main
olin	doc_491521501998_item	2565989	et	3	main
väike	doc_491521501998_item	2565990	et	4	main
siis	doc_491521501998_item	2565992	et	3	main
kahjuks	doc_491521501998_item	2566005	et	4	main
ema	doc_491521501998_item	2566006	et	4	main
lõpetasin	doc_491521501998_item	2566011	et	3	main
siis	doc_491521501998_item	2566014	et	3	main
eesti	doc_491521501998_item	2566018	et	4	main
varem	doc_491521501998_item	2566020	et	4	main
elan	doc_491521501996_item	2565778	et	3	main
aadress	doc_491521501996_item	2565781	et	3	main
on	doc_491521501996_item	2565782	et	4	main
19	doc_491521501996_item	2565784	et	2	main
korter	doc_491521501996_item	2565785	et	3	main
number	doc_491521501996_item	2565786	et	3	main
x	doc_491521501996_item	2565787	et	4	main
meie	doc_491521501996_item	2565788	et	4	main
ema	doc_491521501996_item	2565794	et	4	main
isa	doc_491521501996_item	2565795	et	4	main
ema	doc_491521501996_item	2565799	et	4	main
tatjana	doc_491521501996_item	2565801	et	4	main
aleksei	doc_491521501996_item	2565817	et	4	main
ta	doc_491521501996_item	2565818	et	4	main
kursusse	doc_491521501996_item	2565823	et	3	main
müüja	doc_491521501996_item	2565825	et	4	main
on	doc_491521501996_item	2565843	et	4	main
eesti	doc_491521501998_item	2565941	et	4	main
ma	doc_491521501998_item	2565943	et	3	main
asub	doc_491521501998_item	2565947	et	3	main
kes	doc_491521501998_item	2565956	et	4	main
eestis	doc_491521501998_item	2565958	et	3	main
teadma	doc_491521501998_item	2565979	et	3	main
eesti	doc_491521501998_item	2565980	et	4	main
eestlastega	doc_491521501998_item	2565986	et	4	main
kui	doc_491521501998_item	2565987	et	3	main
tahaksin	doc_491521501998_item	2565994	et	3	main
eesti	doc_491521501998_item	2565996	et	4	main
tahtsin	doc_491521501998_item	2565998	et	3	main
et	doc_491521501998_item	2565999	et	3	main
ema	doc_491521501998_item	2566000	et	4	main
saatis	doc_491521501998_item	2566001	et	3	main
seda	doc_491521501998_item	2566009	et	3	main
mõtlesin	doc_491521501998_item	2566021	et	3	main
keel	doc_491521501998_item	2566024	et	4	main
mulle	doc_491521501998_item	2566025	et	4	main
sain	doc_491521501998_item	2566032	et	3	main
aru	doc_491521501998_item	2566033	et	4	main
et	doc_491521501998_item	2566034	et	3	main
asi	doc_491521501998_item	2566040	et	4	main
eesti	doc_491521501998_item	2566043	et	4	main
tagasi	doc_491521501998_item	2566049	et	3	main
kuulan	doc_491521501998_item	2566054	et	3	main
väga	doc_491521501998_item	2566068	et	3	main
keeles	doc_491521501998_item	2566071	et	4	main
võttan	doc_491521501998_item	2566072	et	4	main
tea	doc_491521501998_item	2566081	et	4	main
ma	doc_491521501998_item	2566082	et	3	main
kohe	doc_491521501998_item	2566083	et	4	main
kirjutan	doc_491521501998_item	2566084	et	3	main
välja	doc_491521501998_item	2566085	et	4	main
õppin	doc_491521501998_item	2566090	et	4	main
samuti	doc_491521501998_item	2566092	et	3	main
varem	doc_491521501998_item	2566104	et	4	main
ma	doc_491521501998_item	2566135	et	3	main
räägin	doc_491521501998_item	2566136	et	3	main
keeles	doc_491521501998_item	2566139	et	4	main
keeles	doc_491521501998_item	2566148	et	4	main
siis	doc_491521501998_item	2566174	et	3	main
häbi	doc_491521501998_item	2566177	et	4	main
kui	doc_491521501998_item	2566178	et	3	main
sa	doc_491521501998_item	2566179	et	3	main
ei	doc_491521501998_item	2566180	et	4	main
ei	doc_491521501998_item	2566191	et	4	main
ole	doc_491521501998_item	2566201	et	4	main
eest	doc_491521501998_item	2566207	et	4	main
jaoks	doc_491521501998_item	2566211	et	4	main
eesti	doc_491521501998_item	2566212	et	4	main
keel	doc_491521501998_item	2566213	et	4	main
on	doc_491521501998_item	2566214	et	4	main
minu	doc_491521501999_item	2566217	et	3	main
vanaisa	doc_491521501996_item	2565830	et	4	main
minu	doc_491521501996_item	2565831	et	3	main
ta	doc_491521501996_item	2565842	et	4	main
ma	doc_491521501998_item	2565939	et	3	main
kohtla-järvel	doc_491521501998_item	2565945	et	4	main
kohlta-järve	doc_491521501998_item	2565946	et	4	main
elab	doc_491521501998_item	2565957	et	3	main
peab	doc_491521501998_item	2565959	et	4	main
teadma	doc_491521501998_item	2565960	et	3	main
tähenda	doc_491521501998_item	2565974	et	4	main
keelt	doc_491521501998_item	2565981	et	4	main
me	doc_491521501998_item	2565982	et	4	main
peame	doc_491521501998_item	2565983	et	4	main
vestlema	doc_491521501998_item	2565984	et	3	main
tüdruk	doc_491521501998_item	2565991	et	3	main
9	doc_491521501998_item	2566012	et	2	main
õppima	doc_491521501998_item	2566016	et	3	main
keel	doc_491521501998_item	2566036	et	4	main
meie	doc_491521501998_item	2566041	et	4	main
elus	doc_491521501998_item	2566042	et	4	main
3	doc_491521501998_item	2566047	et	2	main
ja	doc_491521501998_item	2566074	et	3	main
sõnad	doc_491521501998_item	2566077	et	4	main
mis	doc_491521501998_item	2566078	et	4	main
ma	doc_491521501998_item	2566079	et	3	main
loen	doc_491521501998_item	2566094	et	3	main
sõnaraamatuga	doc_491521501998_item	2566103	et	4	main
rohkem	doc_491521501998_item	2566108	et	4	main
sõnaraamat	doc_491521501998_item	2566110	et	3	main
et	doc_491521501998_item	2566113	et	3	main
väga	doc_491521501998_item	2566117	et	3	main
on	doc_491521501998_item	2566132	et	4	main
harjutused	doc_491521501998_item	2566146	et	4	main
eesti	doc_491521501998_item	2566147	et	4	main
mina	doc_491521501998_item	2566150	et	4	main
et	doc_491521501998_item	2566153	et	3	main
meetod	doc_491521501998_item	2566155	et	3	main
tea	doc_491521501998_item	2566181	et	4	main
eesti	doc_491521501998_item	2566182	et	4	main
keelt	doc_491521501998_item	2566189	et	4	main
aga	doc_491521501998_item	2566194	et	3	main
ma	doc_491521501998_item	2566203	et	3	main
ei	doc_491521501998_item	2566204	et	4	main
minu	doc_491521501998_item	2566210	et	3	main
päev	doc_491521501999_item	2566218	et	3	main
kell	doc_491521501999_item	2566220	et	3	main
homikul	doc_491521501999_item	2566223	et	4	main
lõusen	doc_491521501999_item	2566225	et	4	main
tein	doc_491521501999_item	2566228	et	4	main
siis	doc_491521501999_item	2566231	et	3	main
söön	doc_491521501999_item	2566245	et	3	main
ma	doc_491521501999_item	2566253	et	3	main
töötan	doc_491521501999_item	2566254	et	3	main
toidipodis	doc_491521501999_item	2566256	et	4	main
töö	doc_491521501999_item	2566258	et	4	main
melidib	doc_491521501999_item	2566260	et	4	main
ma	doc_491521501999_item	2566265	et	3	main
lähen	doc_491521501999_item	2566266	et	3	main
mä	doc_491521501999_item	2566268	et	4	main
käit	doc_491521501999_item	2566271	et	4	main
olen	doc_491521502000_item	2566280	et	3	main
kahjuks	doc_491521502000_item	2566287	et	4	main
ta	doc_491521502000_item	2566288	et	4	main
palju	doc_491521502000_item	2566297	et	4	main
ei	doc_491521502000_item	2566298	et	4	main
kuidas	doc_491521502000_item	2566332	et	3	main
eesti	doc_491521502000_item	2566339	et	4	main
klassi	doc_491521502000_item	2566340	et	4	main
tšehhovi	doc_491521502000_item	2566354	et	2	main
koerakesega	doc_491521502000_item	2566356	et	4	main
tihti	doc_491521502000_item	2566367	et	3	main
internetit	doc_491521502000_item	2566369	et	4	main
poberezje	doc_491521502000_item	2566371	et	4	main
toetanud	doc_491521502001_item	2566407	et	4	main
kirjutage	doc_491521502001_item	2566408	et	3	main
taotlus	doc_491521502001_item	2566411	et	4	main
selle	doc_491521502001_item	2566413	et	4	main
toetusraha	doc_491521502001_item	2566415	et	4	main
saamiseks	doc_491521502001_item	2566416	et	4	main
kirjeldage	doc_491521502001_item	2566417	et	3	main
valisite	doc_491521502001_item	2566422	et	3	main
kuidas	doc_491521501998_item	2565938	et	3	main
ida-virumaal	doc_491521501998_item	2565948	et	4	main
ida-virumaal	doc_491521501998_item	2565949	et	4	main
on	doc_491521501998_item	2565950	et	4	main
vaja	doc_491521501998_item	2565951	et	4	main
eesti	doc_491521501998_item	2565952	et	4	main
keel	doc_491521501998_item	2565953	et	4	main
iga	doc_491521501998_item	2565954	et	4	main
inimene	doc_491521501998_item	2565955	et	3	main
linnas	doc_491521501998_item	2565964	et	4	main
väga	doc_491521501998_item	2565965	et	3	main
palju	doc_491521501998_item	2565966	et	4	main
eestlasi	doc_491521501998_item	2565967	et	3	main
meie	doc_491521501998_item	2565968	et	4	main
oleme	doc_491521501998_item	2565969	et	3	main
venelased	doc_491521501998_item	2565970	et	3	main
aga	doc_491521501998_item	2565971	et	3	main
et	doc_491521501998_item	2565975	et	3	main
ei	doc_491521501998_item	2565977	et	4	main
pea	doc_491521501998_item	2565978	et	4	main
koos	doc_491521501998_item	2565985	et	4	main
ma	doc_491521501998_item	2565993	et	3	main
keelt	doc_491521501998_item	2565997	et	4	main
ei	doc_491521501998_item	2566007	et	4	main
ee	doc_491521501998_item	2566008	et	3	main
lähen	doc_491521501998_item	2566015	et	3	main
eesti	doc_491521501998_item	2566023	et	4	main
ei	doc_491521501998_item	2566026	et	4	main
eesti	doc_491521501998_item	2566035	et	4	main
tähtis	doc_491521501998_item	2566039	et	4	main
hakkasin	doc_491521501998_item	2566045	et	3	main
aastat	doc_491521501998_item	2566048	et	3	main
iga	doc_491521501998_item	2566051	et	4	main
eesti	doc_491521501998_item	2566055	et	4	main
see	doc_491521501998_item	2566066	et	3	main
eesti	doc_491521501998_item	2566070	et	4	main
sõnaraamat	doc_491521501998_item	2566073	et	3	main
sõnad	doc_491521501998_item	2566076	et	4	main
ei	doc_491521501998_item	2566080	et	4	main
endale	doc_491521501998_item	2566086	et	4	main
raamatud	doc_491521501998_item	2566095	et	4	main
keeles	doc_491521501998_item	2566097	et	4	main
pärast	doc_491521501998_item	2566099	et	4	main
hakkan	doc_491521501998_item	2566100	et	3	main
tõlkima	doc_491521501998_item	2566101	et	3	main
koos	doc_491521501998_item	2566102	et	4	main
tõlkesin	doc_491521501998_item	2566106	et	4	main
selle	doc_491521501998_item	2566111	et	4	main
minu	doc_491521501998_item	2566114	et	3	main
oli	doc_491521501998_item	2566116	et	3	main
vaene	doc_491521501998_item	2566118	et	4	main
nüüd	doc_491521501998_item	2566119	et	4	main
aga	doc_491521501998_item	2566120	et	3	main
ole	doc_491521501998_item	2566027	et	4	main
vaja	doc_491521501998_item	2566028	et	4	main
aga	doc_491521501998_item	2566029	et	3	main
nüüd	doc_491521501998_item	2566030	et	4	main
ma	doc_491521501998_item	2566031	et	3	main
väga	doc_491521501998_item	2566038	et	3	main
õppima	doc_491521501998_item	2566046	et	3	main
mina	doc_491521501998_item	2566053	et	4	main
raadiot	doc_491521501998_item	2566056	et	3	main
vaatan	doc_491521501998_item	2566057	et	3	main
eesti	doc_491521501998_item	2566058	et	4	main
telesaade	doc_491521501998_item	2566059	et	4	main
selle	doc_491521501998_item	2566060	et	4	main
pärast	doc_491521501998_item	2566061	et	4	main
et	doc_491521501998_item	2566062	et	3	main
kuulamina	doc_491521501998_item	2566063	et	4	main
ja	doc_491521501998_item	2566064	et	3	main
nägemine	doc_491521501998_item	2566065	et	4	main
on	doc_491521501998_item	2566067	et	4	main
pärast	doc_491521501998_item	2566089	et	4	main
ka	doc_491521501998_item	2566093	et	3	main
eesti	doc_491521501998_item	2566096	et	4	main
ja	doc_491521501998_item	2566098	et	3	main
kui	doc_491521501998_item	2566105	et	3	main
tekstid	doc_491521501998_item	2566107	et	3	main
pärast	doc_491521501998_item	2566112	et	4	main
sõnavara	doc_491521501998_item	2566115	et	4	main
tõlkin	doc_491521501998_item	2566121	et	4	main
harvasti	doc_491521501998_item	2566127	et	3	main
mul	doc_491521501998_item	2566128	et	3	main
mõnikord	doc_491521501998_item	2566134	et	3	main
temga	doc_491521501998_item	2566137	et	4	main
oskan	doc_491521501998_item	2566151	et	3	main
mida	doc_491521501998_item	2566156	et	4	main
kasutan	doc_491521501998_item	2566158	et	3	main
eestimaal	doc_491521501998_item	2566173	et	4	main
et	doc_491521501998_item	2566187	et	3	main
ole	doc_491521501998_item	2566192	et	4	main
ei	doc_491521501998_item	2566196	et	4	main
taha	doc_491521501998_item	2566205	et	4	main
teiste	doc_491521501998_item	2566206	et	4	main
essee	doc_491521501999_item	2566216	et	4	main
8	doc_491521501999_item	2566222	et	2	main
ma	doc_491521501999_item	2566224	et	3	main
vannituba	doc_491521501999_item	2566233	et	4	main
aratama	doc_491521501999_item	2566237	et	4	main
mulle	doc_491521501999_item	2566261	et	4	main
23	doc_491521501999_item	2566264	et	2	main
vaja	doc_491521501999_item	2566275	et	4	main
minna	doc_491521501999_item	2566277	et	3	main
ma	doc_491521502000_item	2566279	et	3	main
isa	doc_491521502000_item	2566284	et	4	main
ma	doc_491521502000_item	2566302	et	3	main
ma	doc_491521502000_item	2566333	et	3	main
tegin	doc_491521502000_item	2566335	et	3	main
käin	doc_491521502000_item	2566336	et	3	main
õest	doc_491521502000_item	2566342	et	4	main
õpin	doc_491521502000_item	2566351	et	3	main
algus	doc_491521502000_item	2566357	et	4	main
lause	doc_491521502000_item	2566360	et	4	main
keelt	doc_491521502000_item	2566362	et	4	main
severnoje	doc_491521502000_item	2566370	et	4	main
põhja	doc_491521502000_item	2566373	et	4	main
reisi	doc_491521502001_item	2566414	et	4	main
selle	doc_491521502001_item	2566424	et	4	main
korraldab	doc_491521502001_item	2566428	et	3	main
maria	doc_491521502001_item	2566431	et	4	main
pane	doc_491521502001_item	2566439	et	4	main
inimest	doc_491521502001_item	2566444	et	3	main
20	doc_491521502001_item	2566446	et	2	main
edasi-tagasi	doc_491521502001_item	2566449	et	3	main
ja	doc_491521502001_item	2566453	et	3	main
kohaliku	doc_491521502001_item	2566456	et	3	main
ermitaaži	doc_491521502001_item	2566459	et	2	main
telefonil	doc_491521502001_item	2566469	et	3	main
kallis	doc_491521502001_item	2566481	et	4	main
sõber	doc_491521502001_item	2566482	et	3	main
nimi	doc_491521502001_item	2566483	et	3	main
vastan	doc_491521502001_item	2566484	et	3	main
sulle	doc_491521502001_item	2566486	et	3	main
on	doc_491521502001_item	2566522	et	4	main
eest	doc_491521502001_item	2566524	et	4	main
laevasõit	doc_491521502001_item	2566525	et	3	main
osa	doc_491521502002_item	2566529	et	4	main
kas	doc_491521502002_item	2566534	et	3	main
töö	doc_491521502002_item	2566543	et	4	main
meid	doc_491521502002_item	2566566	et	4	main
keele	doc_491521502002_item	2566570	et	4	main
annab	doc_491521502002_item	2566572	et	3	main
inimesele	doc_491521502002_item	2566573	et	3	main
suurt	doc_491521502002_item	2566574	et	3	main
pluusi	doc_491521502002_item	2566575	et	4	main
et	doc_491521502002_item	2566576	et	3	main
aitab	doc_491521502002_item	2566586	et	3	main
tööl	doc_491521502002_item	2566588	et	3	main
sa	doc_491521502002_item	2566590	et	3	main
keelt	doc_491521502002_item	2566598	et	4	main
sa	doc_491521502002_item	2566599	et	3	main
saad	doc_491521502002_item	2566600	et	4	main
vätab	doc_491521502002_item	2566604	et	4	main
on	doc_491521501998_item	2566129	et	4	main
sõber	doc_491521501998_item	2566130	et	3	main
ta	doc_491521501998_item	2566131	et	4	main
eesti	doc_491521501998_item	2566138	et	4	main
kaks	doc_491521501998_item	2566142	et	3	main
mina	doc_491521501998_item	2566144	et	4	main
ütleda	doc_491521501998_item	2566152	et	4	main
see	doc_491521501998_item	2566154	et	3	main
väga	doc_491521501998_item	2566159	et	3	main
mulle	doc_491521501998_item	2566161	et	4	main
aitab	doc_491521501998_item	2566160	et	3	main
kuna	doc_491521501998_item	2566162	et	3	main
õppin	doc_491521501998_item	2566163	et	4	main
ise	doc_491521501998_item	2566164	et	4	main
eesti	doc_491521501998_item	2566165	et	4	main
keelt	doc_491521501998_item	2566166	et	4	main
ma	doc_491521501998_item	2566167	et	3	main
mõtlen	doc_491521501998_item	2566168	et	3	main
et	doc_491521501998_item	2566169	et	3	main
kui	doc_491521501998_item	2566170	et	3	main
sa	doc_491521501998_item	2566171	et	3	main
tundi	doc_491521501998_item	2566143	et	4	main
teen	doc_491521501998_item	2566145	et	3	main
üldiselt	doc_491521501998_item	2566149	et	4	main
ma	doc_491521501998_item	2566157	et	3	main
on	doc_491521501998_item	2566175	et	4	main
keelt	doc_491521501998_item	2566183	et	4	main
mõned	doc_491521501998_item	2566184	et	3	main
inimesed	doc_491521501998_item	2566185	et	3	main
eesti	doc_491521501998_item	2566188	et	4	main
vaja	doc_491521501998_item	2566193	et	4	main
õige	doc_491521501998_item	2566202	et	4	main
vastutada	doc_491521501998_item	2566208	et	3	main
aga	doc_491521501998_item	2566209	et	3	main
emakeel	doc_491521501998_item	2566215	et	4	main
on	doc_491521501999_item	2566221	et	4	main
honniku	doc_491521501999_item	2566229	et	4	main
pesen	doc_491521501999_item	2566235	et	3	main
nägu	doc_491521501999_item	2566236	et	4	main
lapsed	doc_491521501999_item	2566238	et	3	main
koolis	doc_491521501999_item	2566239	et	4	main
siis	doc_491521501999_item	2566240	et	3	main
ma	doc_491521501999_item	2566241	et	3	main
lähen	doc_491521501999_item	2566242	et	3	main
kööki	doc_491521501999_item	2566243	et	4	main
ja	doc_491521501999_item	2566244	et	3	main
tööale	doc_491521501999_item	2566252	et	4	main
on	doc_491521501999_item	2566263	et	4	main
ja	doc_491521501999_item	2566270	et	3	main
on	doc_491521501999_item	2566274	et	4	main
eesti	doc_491521502000_item	2566278	et	4	main
eestis	doc_491521502000_item	2566282	et	3	main
on	doc_491521502000_item	2566285	et	4	main
eestlane	doc_491521502000_item	2566286	et	3	main
isa	doc_491521502000_item	2566293	et	4	main
oli	doc_491521502000_item	2566294	et	3	main
vaikne	doc_491521502000_item	2566295	et	3	main
mees	doc_491521502000_item	2566296	et	4	main
kui	doc_491521502000_item	2566301	et	3	main
räägida	doc_491521502000_item	2566321	et	4	main
keelt	doc_491521502000_item	2566323	et	4	main
kui	doc_491521502000_item	2566324	et	3	main
ma	doc_491521502000_item	2566325	et	3	main
ma	doc_491521502000_item	2566328	et	3	main
õpin	doc_491521502000_item	2566329	et	3	main
eesti	doc_491521502000_item	2566330	et	4	main
kord	doc_491521502000_item	2566344	et	4	main
sõnastlik	doc_491521502000_item	2566346	et	4	main
leian	doc_491521502000_item	2566347	et	3	main
tundmatu	doc_491521502000_item	2566348	et	4	main
loen	doc_491521502000_item	2566353	et	3	main
vene	doc_491521502000_item	2566361	et	4	main
loen	doc_491521502000_item	2566363	et	3	main
järgmise	doc_491521502000_item	2566364	et	3	main
eesti	doc_491521502000_item	2566365	et	4	main
ja	doc_491521502000_item	2566372	et	3	main
proovin	doc_491521502000_item	2566375	et	3	main
alati	doc_491521502001_item	2566406	et	4	main
miks	doc_491521502001_item	2566421	et	4	main
just	doc_491521502001_item	2566423	et	3	main
aeg	doc_491521502001_item	2566433	et	3	main
1500	doc_491521502001_item	2566437	et	2	main
teatripiletid	doc_491521502001_item	2566451	et	3	main
juhtimisel	doc_491521502001_item	2566458	et	4	main
ja	doc_491521502001_item	2566460	et	3	main
lisatasu	doc_491521502001_item	2566464	et	4	main
eest	doc_491521502001_item	2566465	et	4	main
laevasõit	doc_491521502001_item	2566466	et	3	main
osavõtusoovist	doc_491521502001_item	2566467	et	4	main
789	doc_491521502001_item	2566472	et	2	main
et	doc_491521502001_item	2566487	et	3	main
ma	doc_491521502001_item	2566490	et	3	main
teatrireisile	doc_491521502001_item	2566492	et	3	main
koraldatakse	doc_491521502001_item	2566496	et	4	main
22	doc_491521502001_item	2566498	et	2	main
neljas	doc_491521502002_item	2566526	et	4	main
osa	doc_491521502002_item	2566527	et	4	main
väidet	doc_491521502002_item	2566531	et	3	main
kirjutage	doc_491521502002_item	2566533	et	3	main
sellega	doc_491521502002_item	2566536	et	3	main
või	doc_491521502002_item	2566538	et	4	main
esitage	doc_491521502002_item	2566540	et	3	main
pikkus	doc_491521502002_item	2566544	et	4	main
elad	doc_491521501998_item	2566172	et	3	main
väga	doc_491521501998_item	2566176	et	3	main
õtlevad	doc_491521501998_item	2566186	et	4	main
meile	doc_491521501998_item	2566190	et	4	main
see	doc_491521501998_item	2566195	et	3	main
ole	doc_491521501998_item	2566197	et	4	main
nii	doc_491521501998_item	2566198	et	3	main
see	doc_491521501998_item	2566199	et	3	main
ei	doc_491521501998_item	2566200	et	4	main
algab	doc_491521501999_item	2566219	et	3	main
voodi	doc_491521501999_item	2566226	et	4	main
võilemine	doc_491521501999_item	2566230	et	4	main
ma	doc_491521501999_item	2566234	et	3	main
lähen	doc_491521501999_item	2566251	et	3	main
müüjana	doc_491521501999_item	2566255	et	4	main
kell	doc_491521501999_item	2566262	et	3	main
koju	doc_491521501999_item	2566267	et	3	main
söön	doc_491521501999_item	2566269	et	3	main
mägama	doc_491521501999_item	2566272	et	4	main
tööile	doc_491521501999_item	2566276	et	4	main
minu	doc_491521502000_item	2566283	et	3	main
surnud	doc_491521502000_item	2566289	et	4	main
aastat	doc_491521502000_item	2566291	et	3	main
tagasi	doc_491521502000_item	2566292	et	3	main
meiega	doc_491521502000_item	2566300	et	4	main
saan	doc_491521502000_item	2566303	et	4	main
ma	doc_491521501999_item	2566227	et	3	main
lähen	doc_491521501999_item	2566232	et	3	main
hommikust	doc_491521501999_item	2566246	et	4	main
kell	doc_491521501999_item	2566247	et	3	main
on	doc_491521501999_item	2566248	et	4	main
930	doc_491521501999_item	2566249	et	2	main
ma	doc_491521501999_item	2566250	et	3	main
see	doc_491521501999_item	2566257	et	3	main
väga	doc_491521501999_item	2566259	et	3	main
homme	doc_491521501999_item	2566273	et	3	main
pärit	doc_491521502000_item	2566281	et	3	main
13	doc_491521502000_item	2566290	et	2	main
kõnelta	doc_491521502000_item	2566299	et	4	main
7	doc_491521502000_item	2566304	et	2	main
a	doc_491521502000_item	2566305	et	4	main
vana	doc_491521502000_item	2566306	et	4	main
isa	doc_491521502000_item	2566307	et	4	main
saadis	doc_491521502000_item	2566308	et	4	main
отправил	doc_491521502000_item	2566309	et	2	main
mind	doc_491521502000_item	2566310	et	4	main
vene	doc_491521502000_item	2566311	et	4	main
kool	doc_491521502000_item	2566312	et	4	main
õpima	doc_491521502000_item	2566313	et	4	main
selle	doc_491521502000_item	2566314	et	4	main
pärast	doc_491521502000_item	2566315	et	4	main
ma	doc_491521502000_item	2566316	et	3	main
ei	doc_491521502000_item	2566317	et	4	main
saa	doc_491521502000_item	2566318	et	4	main
nii	doc_491521502000_item	2566319	et	3	main
hästi	doc_491521502000_item	2566320	et	3	main
keelt	doc_491521502000_item	2566331	et	4	main
seda	doc_491521502000_item	2566334	et	3	main
kurssusele	doc_491521502000_item	2566337	et	4	main
suhtlen	doc_491521502000_item	2566338	et	3	main
mõni	doc_491521502000_item	2566343	et	3	main
võttan	doc_491521502000_item	2566345	et	4	main
õhtul	doc_491521502000_item	2566352	et	3	main
daami	doc_491521502000_item	2566355	et	4	main
сначала	doc_491521502000_item	2566358	et	2	main
üks	doc_491521502000_item	2566359	et	3	main
keelt	doc_491521502000_item	2566366	et	4	main
loen	doc_491521502000_item	2566368	et	3	main
vabas	doc_491521502001_item	2566409	et	3	main
reisikava	doc_491521502001_item	2566418	et	4	main
ja	doc_491521502001_item	2566419	et	3	main
põhjendage	doc_491521502001_item	2566420	et	3	main
teatrireisi	doc_491521502001_item	2566429	et	4	main
2122	doc_491521502001_item	2566434	et	2	main
krooni	doc_491521502001_item	2566438	et	4	main
tähele	doc_491521502001_item	2566440	et	3	main
hommiku-	doc_491521502001_item	2566452	et	3	main
külastamine	doc_491521502001_item	2566463	et	4	main
teata	doc_491521502001_item	2566468	et	4	main
otsusta	doc_491521502001_item	2566473	et	4	main
sest	doc_491521502001_item	2566475	et	4	main
homme	doc_491521502001_item	2566476	et	3	main
on	doc_491521502001_item	2566477	et	4	main
juba	doc_491521502001_item	2566478	et	3	main
hilja	doc_491521502001_item	2566479	et	3	main
tere	doc_491521502001_item	2566480	et	3	main
21-22	doc_491521502001_item	2566488	et	2	main
peterburi	doc_491521502001_item	2566493	et	4	main
maria	doc_491521502001_item	2566494	et	4	main
teatrisse	doc_491521502001_item	2566495	et	3	main
lugege	doc_491521502002_item	2566530	et	3	main
poolt-ja	doc_491521502002_item	2566541	et	3	main
eesti	doc_491521502000_item	2566322	et	4	main
tahan	doc_491521502000_item	2566326	et	3	main
praegu	doc_491521502000_item	2566327	et	3	main
õdest	doc_491521502000_item	2566341	et	4	main
sõnad	doc_491521502000_item	2566349	et	4	main
ja	doc_491521502000_item	2566350	et	3	main
rannik	doc_491521502000_item	2566374	et	3	main
tõlkima	doc_491521502000_item	2566376	et	3	main
vaatan	doc_491521502000_item	2566377	et	3	main
telerit	doc_491521502000_item	2566378	et	3	main
eesti	doc_491521502000_item	2566379	et	4	main
keele	doc_491521502000_item	2566380	et	4	main
saadet	doc_491521502000_item	2566381	et	3	main
eksamitöö	doc_491521502001_item	2566382	et	4	main
esimene	doc_491521502001_item	2566383	et	3	main
osa	doc_491521502001_item	2566384	et	4	main
te	doc_491521502001_item	2566385	et	4	main
lugesite	doc_491521502001_item	2566386	et	3	main
ajalehest	doc_491521502001_item	2566387	et	4	main
kuulutust	doc_491521502001_item	2566388	et	4	main
ning	doc_491521502001_item	2566389	et	3	main
arvate	doc_491521502001_item	2566390	et	3	main
et	doc_491521502001_item	2566391	et	3	main
võiksite	doc_491521502001_item	2566392	et	3	main
oma	doc_491521502001_item	2566393	et	4	main
koolikaaslatega	doc_491521502001_item	2566394	et	4	main
sellele	doc_491521502001_item	2566395	et	4	main
reisile	doc_491521502001_item	2566396	et	3	main
minna	doc_491521502001_item	2566397	et	3	main
teie	doc_491521502001_item	2566398	et	4	main
on	doc_491521502001_item	2566400	et	4	main
sponsor	doc_491521502001_item	2566401	et	3	main
koolil	doc_491521502001_item	2566399	et	4	main
kes	doc_491521502001_item	2566402	et	4	main
on	doc_491521502001_item	2566403	et	4	main
õpilaste	doc_491521502001_item	2566404	et	4	main
reise	doc_491521502001_item	2566405	et	3	main
vormis	doc_491521502001_item	2566410	et	4	main
ka	doc_491521502001_item	2566412	et	3	main
reisi	doc_491521502001_item	2566425	et	4	main
reisibüroo	doc_491521502001_item	2566426	et	4	main
peterburi	doc_491521502001_item	2566430	et	4	main
juuni	doc_491521502001_item	2566435	et	4	main
vähemalt	doc_491521502001_item	2566442	et	4	main
hinna	doc_491521502001_item	2566447	et	3	main
rongipilet	doc_491521502001_item	2566450	et	3	main
lõunasöök	doc_491521502001_item	2566454	et	3	main
giidi	doc_491521502001_item	2566457	et	4	main
peeter-pauli	doc_491521502001_item	2566461	et	4	main
kindluse	doc_491521502001_item	2566462	et	4	main
456	doc_491521502001_item	2566471	et	2	main
kohe	doc_491521502001_item	2566485	et	4	main
juuni	doc_491521502001_item	2566489	et	4	main
sõidan	doc_491521502001_item	2566491	et	3	main
pilet	doc_491521502001_item	2566500	et	3	main
hinnab	doc_491521502001_item	2566501	et	4	main
1500	doc_491521502001_item	2566502	et	2	main
krooni	doc_491521502001_item	2566503	et	4	main
hinna	doc_491521502001_item	2566504	et	3	main
seis	doc_491521502001_item	2566505	et	4	main
onedasi-tagasi	doc_491521502001_item	2566506	et	3	main
rongipilet	doc_491521502001_item	2566507	et	3	main
teatripiletid	doc_491521502001_item	2566508	et	3	main
hommiku-	doc_491521502001_item	2566509	et	3	main
ja	doc_491521502001_item	2566510	et	3	main
lõunasöök	doc_491521502001_item	2566511	et	3	main
linnaekskursioon	doc_491521502001_item	2566512	et	3	main
kohaliku	doc_491521502001_item	2566513	et	3	main
giidi	doc_491521502001_item	2566514	et	4	main
ja	doc_491521502001_item	2566516	et	3	main
juhtmisel	doc_491521502001_item	2566515	et	4	main
ermitaaži	doc_491521502001_item	2566517	et	2	main
ja	doc_491521502001_item	2566518	et	3	main
peeter-paul	doc_491521502001_item	2566519	et	4	main
kindluse	doc_491521502001_item	2566520	et	4	main
ellenring	doc_491521502001_item	2566427	et	4	main
teatrisse	doc_491521502001_item	2566432	et	3	main
hind	doc_491521502001_item	2566436	et	3	main
grupile	doc_491521502001_item	2566441	et	3	main
22	doc_491521502001_item	2566443	et	2	main
hinnaalandus	doc_491521502001_item	2566445	et	3	main
sees	doc_491521502001_item	2566448	et	4	main
linnaekskursioon	doc_491521502001_item	2566455	et	3	main
3	doc_491521502001_item	2566470	et	2	main
kohe	doc_491521502001_item	2566474	et	4	main
grupile	doc_491521502001_item	2566497	et	3	main
inimest	doc_491521502001_item	2566499	et	3	main
külastamine	doc_491521502001_item	2566521	et	4	main
lisatasu	doc_491521502001_item	2566523	et	4	main
neljas	doc_491521502002_item	2566528	et	4	main
olete	doc_491521502002_item	2566535	et	3	main
nõus	doc_491521502002_item	2566537	et	4	main
mitte	doc_491521502002_item	2566539	et	3	main
selle	doc_491521502002_item	2566560	et	4	main
võõrkeelte	doc_491521502002_item	2566563	et	3	main
edasi	doc_491521502002_item	2566568	et	3	main
oskuse	doc_491521502002_item	2566585	et	3	main
spetsialist	doc_491521502002_item	2566593	et	3	main
ei	doc_491521502002_item	2566595	et	4	main
kaotada	doc_491521502002_item	2566601	et	3	main
neid	doc_491521502002_item	2566606	et	4	main
eesti	doc_491521502002_item	2566610	et	4	main
ma	doc_491521502002_item	2566612	et	3	main
eesti	doc_491521502002_item	2566615	et	4	main
eesti	doc_491521502002_item	2566621	et	4	main
tunnid	doc_491521502002_item	2566623	et	3	main
ei	doc_491521502002_item	2566624	et	4	main
olnud	doc_491521502002_item	2566625	et	4	main
kui	doc_491521502002_item	2566632	et	3	main
pead	doc_491521502002_item	2566638	et	4	main
poes	doc_491521502002_item	2566648	et	3	main
teises	doc_491521502002_item	2566650	et	4	main
kartan	doc_491521502002_item	2566653	et	4	main
et	doc_491521502002_item	2566656	et	3	main
vaadan	doc_491521502002_item	2566661	et	4	main
eesti	doc_491521502002_item	2566662	et	4	main
saateit	doc_491521502002_item	2566663	et	3	main
aga	doc_491521502002_item	2566664	et	3	main
see	doc_491521502002_item	2566665	et	3	main
ka	doc_491521502002_item	2566666	et	3	main
ei	doc_491521502002_item	2566667	et	4	main
rohkem	doc_491521502002_item	2566670	et	4	main
vaja	doc_491521502002_item	2566672	et	4	main
ei	doc_491521502002_item	2566684	et	4	main
keelt	doc_491521502002_item	2566700	et	4	main
sellega	doc_491521502003_item	2566732	et	3	main
võõrkeelte	doc_491521502003_item	2566735	et	3	main
aitab	doc_491521502003_item	2566737	et	3	main
meid	doc_491521502003_item	2566738	et	4	main
oskamine	doc_491521502003_item	2566741	et	4	main
aitab	doc_491521502003_item	2566743	et	3	main
oskamine	doc_491521502003_item	2566754	et	4	main
vaga	doc_491521502003_item	2566757	et	4	main
kasulikku	doc_491521502003_item	2566758	et	4	main
saad	doc_491521502003_item	2566769	et	4	main
soobib	doc_491521502003_item	2566798	et	4	main
elada	doc_491521502003_item	2566800	et	3	main
vat	doc_491521502003_item	2566802	et	4	main
nii	doc_491521502003_item	2566803	et	3	main
soovitan	doc_491521502003_item	2566805	et	3	main
elu	doc_491521502003_item	2566811	et	4	main
edukas	doc_491521502003_item	2566814	et	4	main
ja	doc_491521502003_item	2566815	et	3	main
ilus	doc_491521502003_item	2566816	et	4	main
neljas	doc_491521502004_item	2566817	et	4	main
sellega	doc_491521502004_item	2566827	et	3	main
esitage	doc_491521502004_item	2566831	et	3	main
poolt-ja	doc_491521502004_item	2566832	et	3	main
vastuargumente	doc_491521502004_item	2566833	et	3	main
töö	doc_491521502004_item	2566834	et	4	main
peab	doc_491521502004_item	2566836	et	4	main
aitab	doc_491521502004_item	2566844	et	3	main
ma	doc_491521502004_item	2566848	et	3	main
nõus	doc_491521502004_item	2566850	et	4	main
selle	doc_491521502004_item	2566851	et	4	main
väidega	doc_491521502004_item	2566852	et	3	main
et	doc_491521502004_item	2566853	et	3	main
ja	doc_491521502002_item	2566532	et	3	main
peab	doc_491521502002_item	2566545	et	4	main
olema	doc_491521502002_item	2566546	et	4	main
120	doc_491521502002_item	2566548	et	2	main
umbes	doc_491521502002_item	2566547	et	4	main
sõna	doc_491521502002_item	2566549	et	4	main
vastuargumente	doc_491521502002_item	2566542	et	3	main
võõrkeelte	doc_491521502002_item	2566551	et	3	main
oskamine	doc_491521502002_item	2566552	et	4	main
aitab	doc_491521502002_item	2566553	et	3	main
meid	doc_491521502002_item	2566554	et	4	main
oskamine	doc_491521502002_item	2566564	et	4	main
aitab	doc_491521502002_item	2566565	et	3	main
riigi	doc_491521502002_item	2566583	et	3	main
kui	doc_491521502002_item	2566589	et	3	main
hea	doc_491521502002_item	2566592	et	4	main
spetsialisti	doc_491521502002_item	2566607	et	4	main
ise	doc_491521502002_item	2566613	et	4	main
õpesin	doc_491521502002_item	2566614	et	4	main
selle	doc_491521502002_item	2566619	et	4	main
keele	doc_491521502002_item	2566622	et	4	main
ja	doc_491521502002_item	2566631	et	3	main
sa	doc_491521502002_item	2566633	et	3	main
midagi	doc_491521502002_item	2566635	et	4	main
eesti	doc_491521502002_item	2566641	et	4	main
keelt	doc_491521502002_item	2566642	et	4	main
ma	doc_491521502002_item	2566643	et	3	main
räägin	doc_491521502002_item	2566644	et	3	main
ainult	doc_491521502002_item	2566647	et	4	main
räägida	doc_491521502002_item	2566654	et	4	main
aita	doc_491521502002_item	2566668	et	4	main
sellest	doc_491521502002_item	2566674	et	4	main
ühes	doc_491521502002_item	2566677	et	4	main
on	doc_491521502002_item	2566680	et	4	main
palju	doc_491521502002_item	2566681	et	4	main
aega	doc_491521502002_item	2566693	et	4	main
väide	doc_491521502003_item	2566722	et	4	main
ma	doc_491521502003_item	2566729	et	3	main
elus	doc_491521502003_item	2566739	et	4	main
meie	doc_491521502003_item	2566745	et	4	main
huvitavam	doc_491521502003_item	2566747	et	4	main
matkama	doc_491521502003_item	2566752	et	3	main
sa	doc_491521502003_item	2566759	et	3	main
huvitavaid	doc_491521502003_item	2566762	et	4	main
mis	doc_491521502003_item	2566770	et	4	main
nemad	doc_491521502003_item	2566771	et	3	main
tahavad	doc_491521502003_item	2566772	et	3	main
teie	doc_491521502003_item	2566810	et	4	main
on	doc_491521502003_item	2566813	et	4	main
osa	doc_491521502004_item	2566820	et	4	main
väide	doc_491521502002_item	2566550	et	4	main
väitega	doc_491521502002_item	2566561	et	3	main
et	doc_491521502002_item	2566562	et	3	main
elus	doc_491521502002_item	2566567	et	4	main
riigi	doc_491521502002_item	2566569	et	3	main
teadmise	doc_491521502002_item	2566571	et	4	main
ilma	doc_491521502002_item	2566577	et	4	main
keeleta	doc_491521502002_item	2566578	et	3	main
on	doc_491521502002_item	2566579	et	4	main
väga	doc_491521502002_item	2566580	et	3	main
keele	doc_491521502002_item	2566584	et	4	main
oled	doc_491521502002_item	2566591	et	3	main
tööd	doc_491521502002_item	2566602	et	4	main
tööle	doc_491521502002_item	2566605	et	3	main
valdab	doc_491521502002_item	2566609	et	3	main
keelt	doc_491521502002_item	2566611	et	4	main
aga	doc_491521502002_item	2566618	et	3	main
sa	doc_491521502002_item	2566637	et	3	main
räägima	doc_491521502002_item	2566640	et	4	main
sellepärast	doc_491521502002_item	2566655	et	3	main
vigu	doc_491521502002_item	2566659	et	3	main
ma	doc_491521502002_item	2566660	et	3	main
kõige	doc_491521502002_item	2566669	et	4	main
suhtlemist	doc_491521502002_item	2566673	et	4	main
ole	doc_491521502002_item	2566685	et	4	main
suhtlemist	doc_491521502002_item	2566686	et	4	main
aga	doc_491521502002_item	2566687	et	3	main
mõtlen	doc_491521502002_item	2566688	et	3	main
et	doc_491521502002_item	2566689	et	3	main
mul	doc_491521502002_item	2566690	et	3	main
on	doc_491521502002_item	2566691	et	4	main
ja	doc_491521502002_item	2566694	et	3	main
saan	doc_491521502002_item	2566696	et	4	main
õppida	doc_491521502002_item	2566697	et	3	main
sõna	doc_491521502003_item	2566721	et	4	main
võõrkeelte	doc_491521502003_item	2566723	et	3	main
oskamine	doc_491521502003_item	2566724	et	4	main
aitab	doc_491521502003_item	2566725	et	3	main
meid	doc_491521502003_item	2566726	et	4	main
ilusam	doc_491521502003_item	2566748	et	4	main
palju	doc_491521502003_item	2566761	et	4	main
ajaloost	doc_491521502003_item	2566764	et	4	main
aru	doc_491521502003_item	2566768	et	4	main
maailmas	doc_491521502003_item	2566799	et	3	main
seal	doc_491521502003_item	2566801	et	4	main
ja	doc_491521502004_item	2566823	et	3	main
kas	doc_491521502004_item	2566825	et	3	main
pikkus	doc_491521502004_item	2566835	et	4	main
oskamine	doc_491521502004_item	2566843	et	4	main
elus	doc_491521502004_item	2566846	et	4	main
präegu	doc_491521502004_item	2566878	et	4	main
on	doc_491521502004_item	2566879	et	4	main
õpib	doc_491521502004_item	2566884	et	3	main
on	doc_491521502004_item	2566886	et	4	main
õpida	doc_491521502004_item	2566891	et	4	main
eesti	doc_491521502004_item	2566892	et	4	main
keel	doc_491521502004_item	2566893	et	4	main
kuidas	doc_491521502004_item	2566894	et	3	main
nad	doc_491521502004_item	2566895	et	3	main
oskab	doc_491521502004_item	2566907	et	3	main
keele	doc_491521502004_item	2566910	et	4	main
tubli	doc_491521502004_item	2566917	et	4	main
need	doc_491521502004_item	2566921	et	3	main
selle	doc_491521502004_item	2566923	et	4	main
ja	doc_491521502004_item	2566930	et	3	main
õpida	doc_491521502004_item	2566935	et	4	main
ja	doc_491521502004_item	2566936	et	3	main
rääkida	doc_491521502004_item	2566937	et	3	main
neljas	doc_491521502005_item	2566944	et	4	main
väidet	doc_491521502005_item	2566949	et	3	main
või	doc_491521502005_item	2566956	et	4	main
esitage	doc_491521502005_item	2566958	et	3	main
umbes	doc_491521502005_item	2566965	et	4	main
kohe	doc_491521502005_item	2566977	et	4	main
täiesti	doc_491521502005_item	2566983	et	3	main
elus	doc_491521502002_item	2566555	et	4	main
edasi	doc_491521502002_item	2566556	et	3	main
ma	doc_491521502002_item	2566557	et	3	main
olen	doc_491521502002_item	2566558	et	3	main
nõus	doc_491521502002_item	2566559	et	4	main
raske	doc_491521502002_item	2566581	et	4	main
suhelda	doc_491521502002_item	2566582	et	4	main
inimesele	doc_491521502002_item	2566587	et	3	main
aga	doc_491521502002_item	2566594	et	3	main
valda	doc_491521502002_item	2566596	et	4	main
eesti	doc_491521502002_item	2566597	et	4	main
töövõtja	doc_491521502002_item	2566603	et	4	main
keelt	doc_491521502002_item	2566616	et	4	main
ajal	doc_491521502002_item	2566620	et	4	main
ni	doc_491521502002_item	2566626	et	4	main
tähtsaid	doc_491521502002_item	2566627	et	3	main
praegu	doc_491521502002_item	2566628	et	3	main
kõik	doc_491521502002_item	2566629	et	4	main
muutub	doc_491521502002_item	2566630	et	3	main
eesti	doc_491521502002_item	2566645	et	4	main
ma	doc_491521502002_item	2566652	et	3	main
on	doc_491521502002_item	2566657	et	4	main
on	doc_491521502002_item	2566671	et	4	main
ma	doc_491521502002_item	2566675	et	3	main
kohas	doc_491521502002_item	2566678	et	4	main
mul	doc_491521502002_item	2566679	et	3	main
veel	doc_491521502002_item	2566698	et	4	main
eesti	doc_491521502002_item	2566699	et	4	main
kes	doc_491521502002_item	2566608	et	4	main
koolis	doc_491521502002_item	2566617	et	4	main
tahad	doc_491521502002_item	2566634	et	3	main
saada	doc_491521502002_item	2566636	et	4	main
hästi	doc_491521502002_item	2566639	et	3	main
keelt	doc_491521502002_item	2566646	et	4	main
aga	doc_491521502002_item	2566649	et	3	main
kohas	doc_491521502002_item	2566651	et	4	main
palju	doc_491521502002_item	2566658	et	4	main
seisan	doc_491521502002_item	2566676	et	3	main
sõnavara	doc_491521502002_item	2566682	et	4	main
aga	doc_491521502002_item	2566683	et	3	main
vell	doc_491521502002_item	2566692	et	4	main
ma	doc_491521502002_item	2566695	et	3	main
essee	doc_491521502003_item	2566701	et	4	main
lugege	doc_491521502003_item	2566702	et	3	main
väidet	doc_491521502003_item	2566703	et	3	main
ja	doc_491521502003_item	2566704	et	3	main
kirjutage	doc_491521502003_item	2566705	et	3	main
kas	doc_491521502003_item	2566706	et	3	main
olete	doc_491521502003_item	2566707	et	3	main
sellega	doc_491521502003_item	2566708	et	3	main
või	doc_491521502003_item	2566710	et	4	main
nõus	doc_491521502003_item	2566709	et	4	main
mitte	doc_491521502003_item	2566711	et	3	main
esitage	doc_491521502003_item	2566712	et	3	main
poolt-ja	doc_491521502003_item	2566713	et	3	main
vastuargumente	doc_491521502003_item	2566714	et	3	main
töö	doc_491521502003_item	2566715	et	4	main
pikkus	doc_491521502003_item	2566716	et	4	main
peab	doc_491521502003_item	2566717	et	4	main
olema	doc_491521502003_item	2566718	et	4	main
umbes	doc_491521502003_item	2566719	et	4	main
120	doc_491521502003_item	2566720	et	2	main
elus	doc_491521502003_item	2566727	et	4	main
edasi	doc_491521502003_item	2566728	et	3	main
nõus	doc_491521502003_item	2566731	et	4	main
et	doc_491521502003_item	2566734	et	3	main
kui	doc_491521502003_item	2566749	et	3	main
armastad	doc_491521502003_item	2566751	et	3	main
siis	doc_491521502003_item	2566753	et	3	main
võõrkeelte	doc_491521502003_item	2566755	et	3	main
sulle	doc_491521502003_item	2566756	et	3	main
sulle	doc_491521502003_item	2566773	et	3	main
kus	doc_491521502003_item	2566797	et	3	main
ma	doc_491521502003_item	2566804	et	3	main
kõikele	doc_491521502003_item	2566806	et	4	main
õppite	doc_491521502003_item	2566807	et	4	main
võõrkeel	doc_491521502003_item	2566808	et	4	main
ja	doc_491521502003_item	2566809	et	3	main
osa	doc_491521502004_item	2566818	et	4	main
neljas	doc_491521502004_item	2566819	et	4	main
väidet	doc_491521502004_item	2566822	et	3	main
kirjutage	doc_491521502004_item	2566824	et	3	main
olete	doc_491521502004_item	2566826	et	3	main
nõus	doc_491521502004_item	2566828	et	4	main
mitte	doc_491521502004_item	2566830	et	3	main
sõna	doc_491521502004_item	2566840	et	4	main
väide	doc_491521502004_item	2566841	et	4	main
võõrkeelte	doc_491521502004_item	2566842	et	3	main
aitab	doc_491521502004_item	2566856	et	3	main
meid	doc_491521502004_item	2566857	et	4	main
kes	doc_491521502004_item	2566882	et	4	main
hakkavad	doc_491521502004_item	2566896	et	4	main
rääkida	doc_491521502004_item	2566897	et	3	main
olen	doc_491521502003_item	2566730	et	3	main
väitega	doc_491521502003_item	2566733	et	3	main
askamine	doc_491521502003_item	2566736	et	4	main
edasi	doc_491521502003_item	2566740	et	3	main
võõrkeelte	doc_491521502003_item	2566742	et	3	main
teha	doc_491521502003_item	2566744	et	3	main
elu	doc_491521502003_item	2566746	et	4	main
sa	doc_491521502003_item	2566750	et	3	main
oskasid	doc_491521502003_item	2566760	et	4	main
faktid	doc_491521502003_item	2566763	et	3	main
ja	doc_491521502003_item	2566765	et	3	main
kultuurist	doc_491521502003_item	2566766	et	3	main
maailma	doc_491521502003_item	2566767	et	4	main
rääkida	doc_491521502003_item	2566774	et	3	main
kui	doc_491521502003_item	2566775	et	3	main
sa	doc_491521502003_item	2566776	et	3	main
osakd	doc_491521502003_item	2566777	et	4	main
võrrkeel	doc_491521502003_item	2566778	et	4	main
võib	doc_491521502003_item	2566779	et	3	main
lugeda	doc_491521502003_item	2566780	et	3	main
raamatuid	doc_491521502003_item	2566781	et	3	main
maailmaluletajad	doc_491521502003_item	2566782	et	4	main
sa	doc_491521502003_item	2566783	et	3	main
leidad	doc_491521502003_item	2566784	et	4	main
palju	doc_491521502003_item	2566785	et	4	main
uued	doc_491521502003_item	2566786	et	3	main
sõbrad	doc_491521502003_item	2566787	et	3	main
kui	doc_491521502003_item	2566788	et	3	main
sa	doc_491521502003_item	2566789	et	3	main
oskad	doc_491521502003_item	2566790	et	3	main
võõrkeetvõib	doc_491521502003_item	2566791	et	4	main
saada	doc_491521502003_item	2566792	et	4	main
hea	doc_491521502003_item	2566793	et	4	main
töötöötada	doc_491521502003_item	2566794	et	4	main
välismaal	doc_491521502003_item	2566795	et	4	main
või	doc_491521502003_item	2566796	et	4	main
edasi	doc_491521502003_item	2566812	et	3	main
lugege	doc_491521502004_item	2566821	et	3	main
või	doc_491521502004_item	2566829	et	4	main
olema	doc_491521502004_item	2566837	et	4	main
umbes	doc_491521502004_item	2566838	et	4	main
120	doc_491521502004_item	2566839	et	2	main
elus	doc_491521502004_item	2566858	et	4	main
keelt	doc_491521502004_item	2566877	et	4	main
tahab	doc_491521502004_item	2566883	et	3	main
aga	doc_491521502004_item	2566885	et	3	main
ei	doc_491521502004_item	2566889	et	4	main
reklaamid	doc_491521502004_item	2566903	et	4	main
lehed	doc_491521502004_item	2566904	et	3	main
inimesed	doc_491521502004_item	2566905	et	3	main
inglise	doc_491521502004_item	2566909	et	4	main
ja	doc_491521502004_item	2566911	et	3	main
saksa	doc_491521502004_item	2566914	et	4	main
meid	doc_491521502004_item	2566845	et	4	main
edasi	doc_491521502004_item	2566847	et	3	main
olen	doc_491521502004_item	2566849	et	3	main
võõrkeelte	doc_491521502004_item	2566854	et	3	main
oskamine	doc_491521502004_item	2566855	et	4	main
edasi	doc_491521502004_item	2566859	et	3	main
me	doc_491521502004_item	2566860	et	4	main
elame	doc_491521502004_item	2566861	et	3	main
eestis	doc_491521502004_item	2566862	et	3	main
ja	doc_491521502004_item	2566863	et	3	main
emakeel	doc_491521502004_item	2566864	et	4	main
on	doc_491521502004_item	2566865	et	4	main
eesti	doc_491521502004_item	2566866	et	4	main
keel	doc_491521502004_item	2566867	et	4	main
eestis	doc_491521502004_item	2566868	et	3	main
on	doc_491521502004_item	2566869	et	4	main
palju	doc_491521502004_item	2566870	et	4	main
venelaseid	doc_491521502004_item	2566871	et	4	main
kes	doc_491521502004_item	2566872	et	4	main
ei	doc_491521502004_item	2566873	et	4	main
oska	doc_491521502004_item	2566874	et	4	main
rääkida	doc_491521502004_item	2566875	et	3	main
eesti	doc_491521502004_item	2566876	et	4	main
ja	doc_491521502004_item	2566881	et	3	main
inimesed	doc_491521502004_item	2566887	et	3	main
taha	doc_491521502004_item	2566890	et	4	main
eestise	doc_491521502004_item	2566901	et	4	main
keele	doc_491521502004_item	2566902	et	4	main
rääkida	doc_491521502004_item	2566908	et	3	main
on	doc_491521502004_item	2566916	et	4	main
võivad	doc_491521502004_item	2566926	et	4	main
seda	doc_491521502004_item	2566928	et	3	main
keele	doc_491521502004_item	2566939	et	4	main
nad	doc_491521502004_item	2566941	et	3	main
kirjutage	doc_491521502005_item	2566951	et	3	main
sellega	doc_491521502005_item	2566954	et	3	main
vastuargumente	doc_491521502005_item	2566960	et	3	main
120	doc_491521502005_item	2566966	et	2	main
aitab	doc_491521502005_item	2566971	et	3	main
vastata	doc_491521502005_item	2566976	et	4	main
nõus	doc_491521502005_item	2566982	et	4	main
puutume	doc_491521502005_item	2566985	et	4	main
ennast	doc_491521502005_item	2567021	et	4	main
teiselt	doc_491521502005_item	2567024	et	4	main
poolt	doc_491521502005_item	2567025	et	4	main
hea	doc_491521502005_item	2567040	et	4	main
nad	doc_491521502005_item	2567042	et	3	main
teavad	doc_491521502005_item	2567043	et	3	main
aga	doc_491521502005_item	2567052	et	3	main
üldse	doc_491521502005_item	2567055	et	3	main
meid	doc_491521502005_item	2567057	et	4	main
edasi	doc_491521502005_item	2567059	et	3	main
neljas	doc_491521502006_item	2567060	et	4	main
osa	doc_491521502006_item	2567061	et	4	main
või	doc_491521502006_item	2567072	et	4	main
töö	doc_491521502006_item	2567077	et	4	main
olema	doc_491521502006_item	2567080	et	4	main
väidega	doc_491521502006_item	2567095	et	3	main
teadnud	doc_491521502006_item	2567105	et	4	main
keelte	doc_491521502006_item	2567106	et	3	main
selge	doc_491521502006_item	2567131	et	4	main
et	doc_491521502006_item	2567132	et	3	main
kõigepealt	doc_491521502006_item	2567133	et	3	main
ju	doc_491521502006_item	2567139	et	3	main
inglise	doc_491521502006_item	2567143	et	4	main
keelest	doc_491521502006_item	2567144	et	4	main
on	doc_491521502006_item	2567155	et	4	main
taha	doc_491521502006_item	2567184	et	4	main
et	doc_491521502006_item	2567185	et	3	main
õpin	doc_491521502006_item	2567194	et	3	main
abistan	doc_491521502006_item	2567196	et	3	main
samuti	doc_491521502006_item	2567198	et	3	main
seda	doc_491521502006_item	2567200	et	3	main
aitab	doc_491521502006_item	2567202	et	3	main
te	doc_491521502007_item	2567208	et	4	main
ukrainasse	doc_491521502007_item	2567211	et	4	main
peate	doc_491521502007_item	2567213	et	4	main
viisaankeedi	doc_491521502007_item	2567215	et	3	main
perekonnanimi	doc_491521502007_item	2567229	et	3	main
3	doc_491521502007_item	2567234	et	2	main
käinud	doc_491521502007_item	2567246	et	4	main
ei	doc_491521502007_item	2567248	et	4	main
6	doc_491521502007_item	2567250	et	2	main
amet	doc_491521502007_item	2567251	et	3	main
telefon	doc_491521502007_item	2567260	et	3	main
9	doc_491521502007_item	2567262	et	2	main
2	doc_491521502007_item	2567268	et	2	main
oma	doc_491521502007_item	2567284	et	4	main
ning	doc_491521502007_item	2567290	et	3	main
te	doc_491521502007_item	2567292	et	4	main
seal	doc_491521502007_item	2567293	et	4	main
teete	doc_491521502007_item	2567294	et	3	main
on	doc_491521502007_item	2567298	et	4	main
tere	doc_491521502007_item	2567302	et	3	main
lahke	doc_491521502007_item	2567314	et	4	main
iga	doc_491521502007_item	2567319	et	4	main
tallinna	doc_491521502007_item	2567345	et	4	main
seal	doc_491521502007_item	2567348	et	4	main
väga	doc_491521502007_item	2567349	et	3	main
meeldis	doc_491521502007_item	2567350	et	3	main
pärast	doc_491521502007_item	2567351	et	4	main
kiriku	doc_491521502007_item	2567352	et	3	main
kursused	doc_491521502004_item	2566880	et	3	main
kes	doc_491521502004_item	2566888	et	4	main
on	doc_491521502004_item	2566900	et	4	main
kes	doc_491521502004_item	2566906	et	4	main
soome	doc_491521502004_item	2566912	et	3	main
keele	doc_491521502004_item	2566913	et	4	main
kes	doc_491521502004_item	2566918	et	4	main
oskab	doc_491521502004_item	2566919	et	3	main
võõrkeelte	doc_491521502004_item	2566920	et	3	main
vaatavad	doc_491521502004_item	2566922	et	4	main
on	doc_491521502004_item	2566932	et	4	main
kus	doc_491521502004_item	2566940	et	3	main
neljas	doc_491521502005_item	2566946	et	4	main
osa	doc_491521502005_item	2566947	et	4	main
nõus	doc_491521502005_item	2566955	et	4	main
mitte	doc_491521502005_item	2566957	et	3	main
poolt-ja	doc_491521502005_item	2566959	et	3	main
töö	doc_491521502005_item	2566961	et	4	main
pikkus	doc_491521502005_item	2566962	et	4	main
väide	doc_491521502005_item	2566968	et	4	main
selle	doc_491521502005_item	2566978	et	4	main
väitega	doc_491521502005_item	2566979	et	3	main
ma	doc_491521502005_item	2566980	et	3	main
me	doc_491521502005_item	2566984	et	4	main
edukalt	doc_491521502005_item	2567022	et	4	main
aga	doc_491521502005_item	2567023	et	3	main
on	doc_491521502005_item	2567038	et	4	main
väga	doc_491521502005_item	2567039	et	3	main
intsiativ	doc_491521502005_item	2567041	et	4	main
mida	doc_491521502005_item	2567044	et	4	main
tahavad	doc_491521502005_item	2567045	et	3	main
ja	doc_491521502005_item	2567046	et	3	main
mis	doc_491521502005_item	2567047	et	4	main
taha	doc_491521502005_item	2567051	et	4	main
mitte	doc_491521502006_item	2567073	et	3	main
esitage	doc_491521502006_item	2567074	et	3	main
peab	doc_491521502006_item	2567079	et	4	main
nõus	doc_491521502006_item	2567093	et	4	main
sellega	doc_491521502006_item	2567094	et	3	main
ei	doc_491521502006_item	2567108	et	4	main
et	doc_491521502004_item	2566898	et	3	main
kõik	doc_491521502004_item	2566899	et	4	main
keele	doc_491521502004_item	2566915	et	4	main
keele	doc_491521502004_item	2566924	et	4	main
sõita	doc_491521502004_item	2566927	et	3	main
riigi	doc_491521502004_item	2566929	et	3	main
kui	doc_491521502004_item	2566931	et	3	main
raha	doc_491521502004_item	2566933	et	4	main
seal	doc_491521502004_item	2566934	et	4	main
präegu	doc_491521502004_item	2566942	et	4	main
elavad	doc_491521502004_item	2566943	et	4	main
lugege	doc_491521502005_item	2566948	et	3	main
kas	doc_491521502005_item	2566952	et	3	main
peab	doc_491521502005_item	2566963	et	4	main
olema	doc_491521502005_item	2566964	et	4	main
võõrkeelte	doc_491521502005_item	2566969	et	3	main
oskamine	doc_491521502005_item	2566970	et	4	main
meid	doc_491521502005_item	2566972	et	4	main
elus	doc_491521502005_item	2566973	et	4	main
edasi	doc_491521502005_item	2566974	et	3	main
võin	doc_491521502005_item	2566975	et	3	main
olen	doc_491521502005_item	2566981	et	3	main
nendel	doc_491521502005_item	2567036	et	4	main
inimestel	doc_491521502005_item	2567037	et	3	main
selleks	doc_491521502005_item	2567048	et	4	main
neljas	doc_491521502006_item	2567062	et	4	main
kas	doc_491521502006_item	2567068	et	3	main
sellega	doc_491521502006_item	2567070	et	3	main
poolt-ja	doc_491521502006_item	2567075	et	3	main
umbes	doc_491521502006_item	2567081	et	4	main
võõrkeelte	doc_491521502006_item	2567085	et	3	main
aitab	doc_491521502006_item	2567087	et	3	main
meid	doc_491521502006_item	2567088	et	4	main
sest	doc_491521502006_item	2567096	et	4	main
venelased	doc_491521502006_item	2567100	et	3	main
oska	doc_491521502006_item	2567109	et	4	main
saa	doc_491521502006_item	2567128	et	4	main
ja	doc_491521502006_item	2567129	et	3	main
ma	doc_491521502006_item	2567138	et	3	main
räägi	doc_491521502006_item	2567141	et	4	main
sõida	doc_491521502006_item	2567154	et	4	main
valdata	doc_491521502006_item	2567158	et	4	main
inglise	doc_491521502006_item	2567159	et	4	main
lapsega	doc_491521502006_item	2567187	et	3	main
et	doc_491521502006_item	2567192	et	3	main
ja	doc_491521502006_item	2567195	et	3	main
last	doc_491521502006_item	2567197	et	4	main
ja	doc_491521502006_item	2567199	et	3	main
1	doc_491521502007_item	2567207	et	2	main
täna	doc_491521502007_item	2567219	et	4	main
kõigile	doc_491521502007_item	2567220	et	4	main
telerit	doc_491521502004_item	2566925	et	3	main
selle	doc_491521502004_item	2566938	et	4	main
osa	doc_491521502005_item	2566945	et	4	main
ja	doc_491521502005_item	2566950	et	3	main
olete	doc_491521502005_item	2566953	et	3	main
sõna	doc_491521502005_item	2566967	et	4	main
kokku	doc_491521502005_item	2566986	et	3	main
paljude	doc_491521502005_item	2566987	et	3	main
uute	doc_491521502005_item	2566988	et	3	main
teaduse	doc_491521502005_item	2566989	et	3	main
ja	doc_491521502005_item	2566990	et	3	main
tehnika	doc_491521502005_item	2566991	et	4	main
probleemidega	doc_491521502005_item	2566992	et	3	main
kus	doc_491521502005_item	2566993	et	3	main
vaja	doc_491521502005_item	2566994	et	4	main
oskada	doc_491521502005_item	2566995	et	4	main
võõrkeelte	doc_491521502005_item	2566996	et	3	main
kui	doc_491521502005_item	2566997	et	3	main
sa	doc_491521502005_item	2566998	et	3	main
ei	doc_491521502005_item	2566999	et	4	main
saa	doc_491521502005_item	2567000	et	4	main
võõrkeelt	doc_491521502005_item	2567001	et	4	main
ma	doc_491521502005_item	2567002	et	3	main
mõtlen	doc_491521502005_item	2567003	et	3	main
siis	doc_491521502005_item	2567004	et	3	main
ei	doc_491521502005_item	2567005	et	4	main
saa	doc_491521502005_item	2567006	et	4	main
endale	doc_491521502005_item	2567007	et	4	main
leida	doc_491521502005_item	2567008	et	3	main
hea	doc_491521502005_item	2567009	et	4	main
töökohta	doc_491521502005_item	2567010	et	4	main
siis	doc_491521502005_item	2567011	et	3	main
on	doc_491521502005_item	2567012	et	4	main
sul	doc_491521502005_item	2567013	et	3	main
palk	doc_491521502005_item	2567015	et	3	main
madal	doc_491521502005_item	2567014	et	3	main
ja	doc_491521502005_item	2567016	et	3	main
siis	doc_491521502005_item	2567017	et	3	main
ei	doc_491521502005_item	2567018	et	4	main
saa	doc_491521502005_item	2567019	et	4	main
tunne	doc_491521502005_item	2567020	et	4	main
on	doc_491521502005_item	2567026	et	4	main
plaju	doc_491521502005_item	2567027	et	4	main
inimest	doc_491521502005_item	2567028	et	3	main
kes	doc_491521502005_item	2567029	et	4	main
väga	doc_491521502005_item	2567030	et	3	main
edukalt	doc_491521502005_item	2567031	et	4	main
astub	doc_491521502005_item	2567032	et	3	main
on	doc_491521502005_item	2567049	et	4	main
võõtkeelte	doc_491521502005_item	2567053	et	4	main
aitab	doc_491521502005_item	2567056	et	3	main
elus	doc_491521502005_item	2567058	et	4	main
osa	doc_491521502006_item	2567063	et	4	main
lugege	doc_491521502006_item	2567064	et	3	main
ja	doc_491521502006_item	2567066	et	3	main
nõus	doc_491521502006_item	2567071	et	4	main
pikkus	doc_491521502006_item	2567078	et	4	main
sõna	doc_491521502006_item	2567083	et	4	main
elus	doc_491521502006_item	2567089	et	4	main
edasi	doc_491521502006_item	2567090	et	3	main
ma	doc_491521502006_item	2567091	et	3	main
olen	doc_491521502006_item	2567092	et	3	main
mine	doc_491521502006_item	2567097	et	3	main
mitte	doc_491521502006_item	2567102	et	3	main
oleme	doc_491521502006_item	2567104	et	3	main
probleemid	doc_491521502006_item	2567107	et	3	main
räägida	doc_491521502006_item	2567110	et	4	main
riigikeeles	doc_491521502006_item	2567111	et	4	main
kus	doc_491521502006_item	2567112	et	3	main
sa	doc_491521502006_item	2567113	et	3	main
elad	doc_491521502006_item	2567114	et	3	main
koik	doc_491521502006_item	2567115	et	4	main
teed	doc_491521502006_item	2567116	et	4	main
on	doc_491521502006_item	2567117	et	4	main
simńule	doc_491521502006_item	2567118	et	2	main
kinni	doc_491521502006_item	2567119	et	3	main
alates	doc_491521502006_item	2567120	et	3	main
naabri	doc_491521502006_item	2567121	et	3	main
öelda	doc_491521502006_item	2567125	et	4	main
aga	doc_491521502006_item	2567126	et	3	main
ei	doc_491521502006_item	2567127	et	4	main
võõrkeelt	doc_491521502006_item	2567137	et	4	main
inglise	doc_491521502006_item	2567145	et	4	main
keelt	doc_491521502006_item	2567160	et	4	main
sellepärast	doc_491521502006_item	2567161	et	3	main
juba	doc_491521502006_item	2567162	et	3	main
minu	doc_491521502006_item	2567186	et	3	main
ja	doc_491521502006_item	2567190	et	3	main
küll	doc_491521502006_item	2567201	et	4	main
sõita	doc_491521502007_item	2567210	et	3	main
täitma	doc_491521502007_item	2567214	et	3	main
kohe	doc_491521502007_item	2567218	et	4	main
sugu	doc_491521502007_item	2567232	et	4	main
kodakondsusetaei	doc_491521502007_item	2567236	et	4	main
5	doc_491521502007_item	2567241	et	2	main
8	doc_491521502007_item	2567259	et	2	main
kuupäev	doc_491521502007_item	2567263	et	3	main
allikiri	doc_491521502007_item	2567266	et	4	main
saabunud	doc_491521502007_item	2567269	et	4	main
suvine	doc_491521502007_item	2567271	et	4	main
te	doc_491521502007_item	2567274	et	4	main
veedate	doc_491521502007_item	2567275	et	3	main
sellest	doc_491521502007_item	2567276	et	4	main
kaks	doc_491521502007_item	2567277	et	3	main
nädalat	doc_491521502007_item	2567278	et	3	main
kirja	doc_491521502007_item	2567295	et	4	main
spordilaagris	doc_491521502007_item	2567306	et	3	main
siin	doc_491521502007_item	2567309	et	4	main
meeldib	doc_491521502007_item	2567311	et	3	main
sõbrad	doc_491521502007_item	2567318	et	3	main
elul	doc_491521502005_item	2567033	et	3	main
ilma	doc_491521502005_item	2567034	et	4	main
võõrkeelt	doc_491521502005_item	2567035	et	4	main
vaja	doc_491521502005_item	2567050	et	4	main
oskamine	doc_491521502005_item	2567054	et	4	main
väidet	doc_491521502006_item	2567065	et	3	main
kirjutage	doc_491521502006_item	2567067	et	3	main
olete	doc_491521502006_item	2567069	et	3	main
vastuargumente	doc_491521502006_item	2567076	et	3	main
120	doc_491521502006_item	2567082	et	2	main
väide	doc_491521502006_item	2567084	et	4	main
oskamine	doc_491521502006_item	2567086	et	4	main
ja	doc_491521502006_item	2567098	et	3	main
kõik	doc_491521502006_item	2567099	et	4	main
kui	doc_491521502006_item	2567101	et	3	main
keegi	doc_491521502006_item	2567103	et	4	main
tahad	doc_491521502006_item	2567123	et	3	main
midagi	doc_491521502006_item	2567124	et	4	main
me	doc_491521502006_item	2567134	et	4	main
peame	doc_491521502006_item	2567135	et	4	main
ei	doc_491521502006_item	2567140	et	4	main
juba	doc_491521502006_item	2567142	et	3	main
maailma	doc_491521502006_item	2567149	et	4	main
ja	doc_491521502006_item	2567150	et	3	main
kuhu	doc_491521502006_item	2567151	et	3	main
sa	doc_491521502006_item	2567152	et	3	main
ei	doc_491521502006_item	2567153	et	4	main
inglise	doc_491521502006_item	2567179	et	4	main
keelt	doc_491521502006_item	2567180	et	4	main
üldse	doc_491521502006_item	2567181	et	3	main
aga	doc_491521502006_item	2567182	et	3	main
ei	doc_491521502006_item	2567183	et	4	main
nii	doc_491521502006_item	2567189	et	3	main
arvan	doc_491521502006_item	2567191	et	3	main
meiel	doc_491521502006_item	2567203	et	4	main
elus	doc_491521502006_item	2567204	et	4	main
edasi	doc_491521502006_item	2567205	et	3	main
soovite	doc_491521502007_item	2567209	et	3	main
selleks	doc_491521502007_item	2567212	et	4	main
palun	doc_491521502007_item	2567216	et	3	main
naine	doc_491521502007_item	2567233	et	3	main
oma	doc_491521502007_item	2567237	et	4	main
elukohariik	doc_491521502007_item	2567239	et	3	main
eesti	doc_491521502007_item	2567240	et	4	main
kas	doc_491521502007_item	2567242	et	3	main
varem	doc_491521502007_item	2567244	et	4	main
millal	doc_491521502007_item	2567247	et	3	main
kainud	doc_491521502007_item	2567249	et	4	main
aadress	doc_491521502007_item	2567255	et	3	main
jõhvi	doc_491521502007_item	2567256	et	4	main
03361881	doc_491521502007_item	2567261	et	2	main
10	doc_491521502007_item	2567265	et	2	main
ühes	doc_491521502007_item	2567279	et	4	main
spordilaagris	doc_491521502007_item	2567282	et	3	main
sõbrale	doc_491521502007_item	2567286	et	3	main
laager	doc_491521502007_item	2567288	et	3	main
nõutav	doc_491521502007_item	2567296	et	4	main
umbes	doc_491521502007_item	2567299	et	4	main
tatjana	doc_491521502007_item	2567303	et	4	main
ma	doc_491521502007_item	2567304	et	3	main
puhkana	doc_491521502007_item	2567305	et	4	main
väga	doc_491521502007_item	2567310	et	3	main
ilusad	doc_491521502007_item	2567316	et	3	main
tegilise	doc_491521502007_item	2567321	et	4	main
see	doc_491521502007_item	2567323	et	3	main
värsked	doc_491521502007_item	2567328	et	4	main
meil	doc_491521502007_item	2567334	et	4	main
hästi	doc_491521502007_item	2567335	et	3	main
vannitoaga	doc_491521502007_item	2567339	et	3	main
ekskursioonil	doc_491521502007_item	2567342	et	3	main
kaisime	doc_491521502007_item	2567344	et	4	main
kirikus	doc_491521502007_item	2567346	et	3	main
3	doc_491521502007_item	2567358	et	2	main
bussiga	doc_491521502007_item	2567362	et	3	main
kaheksa	doc_491521502007_item	2567369	et	4	main
ekspress	doc_491521502007_item	2567375	et	4	main
on	doc_491521502007_item	2567379	et	4	main
pärnusse	doc_491521502007_item	2567384	et	4	main
kandis	doc_491521502007_item	2567394	et	4	main
tüdruk	doc_491521502007_item	2567399	et	3	main
saanud	doc_491521502007_item	2567401	et	4	main
4	doc_491521502007_item	2567405	et	2	main
suhtlemist	doc_491521502006_item	2567122	et	4	main
ongi	doc_491521502006_item	2567130	et	4	main
õppime	doc_491521502006_item	2567136	et	4	main
keeles	doc_491521502006_item	2567146	et	4	main
räägib	doc_491521502006_item	2567147	et	3	main
pooleks	doc_491521502006_item	2567148	et	4	main
kõige	doc_491521502006_item	2567156	et	4	main
parem	doc_491521502006_item	2567157	et	4	main
lasteaiast	doc_491521502006_item	2567163	et	4	main
peavad	doc_491521502006_item	2567164	et	4	main
lapsed	doc_491521502006_item	2567165	et	3	main
ektiivselt	doc_491521502006_item	2567166	et	4	main
õppima	doc_491521502006_item	2567167	et	3	main
ma	doc_491521502006_item	2567168	et	3	main
olen	doc_491521502006_item	2567169	et	3	main
juba	doc_491521502006_item	2567170	et	3	main
kahekümneviieaastane	doc_491521502006_item	2567171	et	4	main
aga	doc_491521502006_item	2567172	et	3	main
ei	doc_491521502006_item	2567173	et	4	main
hästi	doc_491521502006_item	2567175	et	3	main
valda	doc_491521502006_item	2567174	et	4	main
eesti	doc_491521502006_item	2567176	et	4	main
keelt	doc_491521502006_item	2567177	et	4	main
ja	doc_491521502006_item	2567178	et	3	main
oli	doc_491521502006_item	2567188	et	3	main
ise	doc_491521502006_item	2567193	et	4	main
eksamitöö	doc_491521502007_item	2567206	et	4	main
vastake	doc_491521502007_item	2567217	et	3	main
küsimustele	doc_491521502007_item	2567221	et	4	main
perekonna-	doc_491521502007_item	2567226	et	4	main
nimi	doc_491521502007_item	2567230	et	3	main
olete	doc_491521502007_item	2567243	et	3	main
22-86	doc_491521502007_item	2567258	et	2	main
05032002	doc_491521502007_item	2567264	et	2	main
perekonnanimi	doc_491521502007_item	2567267	et	3	main
on	doc_491521502007_item	2567270	et	4	main
koolivaheaeg	doc_491521502007_item	2567272	et	3	main
ja	doc_491521502007_item	2567273	et	3	main
asuvas	doc_491521502007_item	2567281	et	4	main
eestlasest	doc_491521502007_item	2567285	et	3	main
kus	doc_491521502007_item	2567287	et	3	main
asub	doc_491521502007_item	2567289	et	3	main
pikkus	doc_491521502007_item	2567297	et	4	main
sõna	doc_491521502007_item	2567301	et	4	main
lõbussad	doc_491521502007_item	2567315	et	4	main
sportida	doc_491521502007_item	2567322	et	4	main
aega	doc_491521502007_item	2567326	et	4	main
see	doc_491521502007_item	2567337	et	3	main
käime	doc_491521502007_item	2567341	et	4	main
viimati	doc_491521502007_item	2567343	et	3	main
mull	doc_491521502007_item	2567347	et	3	main
gümnaasiumisse	doc_491521502007_item	2567356	et	3	main
puuduvad	doc_491521502007_item	2567360	et	4	main
kulub	doc_491521502007_item	2567367	et	3	main
bussifirma	doc_491521502007_item	2567374	et	4	main
sõitvad	doc_491521502007_item	2567377	et	4	main
küljeaken	doc_491521502007_item	2567387	et	3	main
kord	doc_491521502007_item	2567390	et	4	main
bussil	doc_491521502007_item	2567392	et	3	main
kilingi-nõmme	doc_491521502007_item	2567393	et	4	main
on	doc_491521502007_item	2567398	et	4	main
tehke	doc_491521502007_item	2567410	et	4	main
on	doc_491521502007_item	2567428	et	4	main
3	doc_491521502007_item	2567439	et	2	main
pooldab	doc_491521502007_item	2567442	et	3	main
4	doc_491521502007_item	2567444	et	2	main
kõige	doc_491521502007_item	2567445	et	4	main
arvates	doc_491521502007_item	2567455	et	4	main
vastake	doc_491521502008_item	2567475	et	3	main
kohta	doc_491521502008_item	2567483	et	4	main
vanus	doc_491521502008_item	2567485	et	4	main
19a	doc_491521502008_item	2567486	et	4	main
2	doc_491521502008_item	2567487	et	2	main
perekonnaseis	doc_491521502008_item	2567491	et	4	main
elukoht	doc_491521502008_item	2567494	et	3	main
5	doc_491521502008_item	2567499	et	2	main
väljas	doc_491521502008_item	2567510	et	4	main
kui	doc_491521502008_item	2567513	et	3	main
käite	doc_491521502008_item	2567515	et	3	main
krooni	doc_491521502008_item	2567524	et	4	main
kuus	doc_491521502008_item	2567525	et	4	main
10	doc_491521502008_item	2567529	et	2	main
teil	doc_491521502008_item	2567534	et	4	main
hiljuti	doc_491521502008_item	2567536	et	4	main
sõbrale	doc_491521502008_item	2567544	et	3	main
te	doc_491521502008_item	2567552	et	4	main
kingiks	doc_491521502008_item	2567553	et	4	main
umbes	doc_491521502008_item	2567559	et	4	main
80	doc_491521502008_item	2567560	et	2	main
kirjutada	doc_491521502008_item	2567567	et	3	main
oli	doc_491521502008_item	2567574	et	3	main
ma	doc_491521502008_item	2567578	et	3	main
neiu	doc_491521502008_item	2567581	et	4	main
muidugi	doc_491521502008_item	2567619	et	4	main
ma	doc_491521502008_item	2567627	et	3	main
tuled	doc_491521502008_item	2567632	et	4	main
mulle	doc_491521502008_item	2567633	et	4	main
meil	doc_491521502008_item	2567635	et	4	main
oli	doc_491521502008_item	2567636	et	3	main
väga	doc_491521502008_item	2567637	et	3	main
lõbus	doc_491521502008_item	2567638	et	4	main
kõigepealt	doc_491521502008_item	2567639	et	3	main
siis	doc_491521502008_item	2567644	et	3	main
diskol	doc_491521502008_item	2567651	et	4	main
mulle	doc_491521502008_item	2567659	et	4	main
mis	doc_491521502008_item	2567664	et	4	main
viisa	doc_491521502007_item	2567222	et	4	main
taotleja	doc_491521502007_item	2567223	et	4	main
ankeet	doc_491521502007_item	2567224	et	3	main
1	doc_491521502007_item	2567225	et	2	main
ja	doc_491521502007_item	2567227	et	3	main
eesnimi	doc_491521502007_item	2567228	et	3	main
2	doc_491521502007_item	2567231	et	2	main
kodakondsus	doc_491521502007_item	2567235	et	3	main
4	doc_491521502007_item	2567238	et	2	main
ukrainas	doc_491521502007_item	2567245	et	4	main
7	doc_491521502007_item	2567253	et	2	main
sekretär	doc_491521502007_item	2567252	et	3	main
kodune	doc_491521502007_item	2567254	et	4	main
kaarepere	doc_491521502007_item	2567257	et	4	main
eestis	doc_491521502007_item	2567280	et	3	main
kirjutage	doc_491521502007_item	2567283	et	3	main
mida	doc_491521502007_item	2567291	et	4	main
80	doc_491521502007_item	2567300	et	2	main
sport	doc_491521502007_item	2567307	et	3	main
mul	doc_491521502007_item	2567308	et	3	main
siin	doc_491521502007_item	2567312	et	4	main
palju	doc_491521502007_item	2567313	et	4	main
tugevad	doc_491521502007_item	2567317	et	4	main
päev	doc_491521502007_item	2567320	et	3	main
palju	doc_491521502007_item	2567325	et	4	main
jalutama	doc_491521502007_item	2567327	et	3	main
õhud	doc_491521502007_item	2567329	et	3	main
see	doc_491521502007_item	2567330	et	3	main
hästi	doc_491521502007_item	2567332	et	3	main
on	doc_491521502007_item	2567338	et	4	main
pühapäevati	doc_491521502007_item	2567340	et	3	main
järve	doc_491521502007_item	2567354	et	4	main
lisage	doc_491521502007_item	2567359	et	3	main
1	doc_491521502007_item	2567364	et	2	main
kestab	doc_491521502007_item	2567385	et	4	main
vähemalt	doc_491521502007_item	2567386	et	4	main
5	doc_491521502007_item	2567395	et	2	main
a	doc_491521502007_item	2567421	et	4	main
õige	doc_491521502007_item	2567423	et	4	main
töötanud	doc_491521502007_item	2567430	et	4	main
2	doc_491521502007_item	2567433	et	2	main
varem	doc_491521502007_item	2567434	et	4	main
õp	doc_491521502007_item	2567440	et	4	main
terase	doc_491521502007_item	2567454	et	4	main
täna	doc_491521502008_item	2567477	et	4	main
3	doc_491521502008_item	2567490	et	2	main
vallaline	doc_491521502008_item	2567492	et	4	main
maakond	doc_491521502008_item	2567496	et	3	main
ei	doc_491521502008_item	2567511	et	4	main
turul	doc_491521502008_item	2567516	et	3	main
nädalas	doc_491521502008_item	2567519	et	3	main
kuusissetulek	doc_491521502008_item	2567522	et	3	main
kuupäev	doc_491521502008_item	2567527	et	3	main
allkiri	doc_491521502008_item	2567531	et	3	main
osa	doc_491521502008_item	2567533	et	4	main
oli	doc_491521502008_item	2567535	et	3	main
sünnipäev	doc_491521502008_item	2567537	et	3	main
te	doc_491521502008_item	2567538	et	4	main
saadate	doc_491521502008_item	2567539	et	3	main
pikkus	doc_491521502008_item	2567557	et	4	main
sulle	doc_491521502008_item	2567569	et	3	main
oma	doc_491521502008_item	2567570	et	4	main
rääkida	doc_491521502008_item	2567572	et	3	main
eile	doc_491521502008_item	2567575	et	3	main
võtta	doc_491521502007_item	2567324	et	3	main
on	doc_491521502007_item	2567331	et	4	main
söögid	doc_491521502007_item	2567333	et	3	main
tuba	doc_491521502007_item	2567336	et	4	main
tallinna	doc_491521502007_item	2567355	et	4	main
pärnusse	doc_491521502007_item	2567363	et	4	main
nädalalõpul	doc_491521502007_item	2567366	et	3	main
tüdrukul	doc_491521502007_item	2567368	et	3	main
tundi	doc_491521502007_item	2567370	et	4	main
bussisõidu	doc_491521502007_item	2567371	et	3	main
peale	doc_491521502007_item	2567372	et	4	main
2	doc_491521502007_item	2567373	et	2	main
pärnusse	doc_491521502007_item	2567376	et	4	main
bussid	doc_491521502007_item	2567378	et	3	main
vana	doc_491521502007_item	2567381	et	4	main
sõit	doc_491521502007_item	2567383	et	3	main
4	doc_491521502007_item	2567389	et	2	main
purunes	doc_491521502007_item	2567391	et	3	main
vahel	doc_491521502007_item	2567396	et	4	main
pärnusse	doc_491521502007_item	2567400	et	4	main
sõita	doc_491521502007_item	2567402	et	3	main
uue	doc_491521502007_item	2567403	et	3	main
bussiga	doc_491521502007_item	2567404	et	3	main
märge	doc_491521502007_item	2567411	et	4	main
õige	doc_491521502007_item	2567413	et	4	main
kui	doc_491521502007_item	2567414	et	3	main
a-ruutu	doc_491521502007_item	2567412	et	4	main
ei	doc_491521502007_item	2567415	et	4	main
nõustu	doc_491521502007_item	2567416	et	4	main
siis	doc_491521502007_item	2567417	et	3	main
märge	doc_491521502007_item	2567418	et	4	main
b-ruutu	doc_491521502007_item	2567419	et	4	main
vale	doc_491521502007_item	2567420	et	4	main
käisime	doc_491521502007_item	2567353	et	3	main
võistlustele	doc_491521502007_item	2567357	et	3	main
sõnad	doc_491521502007_item	2567361	et	4	main
igal	doc_491521502007_item	2567365	et	3	main
väga	doc_491521502007_item	2567380	et	3	main
3	doc_491521502007_item	2567382	et	2	main
tundi	doc_491521502007_item	2567388	et	4	main
harva	doc_491521502007_item	2567397	et	4	main
siis	doc_491521502007_item	2567409	et	3	main
õp	doc_491521502007_item	2567426	et	4	main
teras	doc_491521502007_item	2567427	et	4	main
koolis	doc_491521502007_item	2567436	et	4	main
meeldib	doc_491521502007_item	2567447	et	3	main
palun	doc_491521502008_item	2567474	et	3	main
kohe	doc_491521502008_item	2567476	et	4	main
1	doc_491521502008_item	2567484	et	2	main
naine	doc_491521502008_item	2567489	et	3	main
einestate	doc_491521502008_item	2567509	et	3	main
korda	doc_491521502008_item	2567518	et	4	main
kui	doc_491521502007_item	2567406	et	3	main
nõustute	doc_491521502007_item	2567407	et	3	main
võitega	doc_491521502007_item	2567408	et	4	main
b	doc_491521502007_item	2567422	et	4	main
vale	doc_491521502007_item	2567424	et	4	main
1	doc_491521502007_item	2567425	et	2	main
tuli	doc_491521502007_item	2567435	et	4	main
käia	doc_491521502007_item	2567438	et	4	main
teras	doc_491521502007_item	2567441	et	4	main
koolivormi	doc_491521502007_item	2567443	et	4	main
õp	doc_491521502007_item	2567448	et	4	main
käsitöö	doc_491521502007_item	2567450	et	4	main
5	doc_491521502007_item	2567452	et	2	main
õp	doc_491521502007_item	2567453	et	4	main
käitusis	doc_491521502007_item	2567456	et	4	main
varem	doc_491521502007_item	2567458	et	4	main
paremini	doc_491521502007_item	2567459	et	4	main
test	doc_491521502008_item	2567460	et	3	main
kõigile	doc_491521502008_item	2567478	et	4	main
küsimustele	doc_491521502008_item	2567479	et	4	main
küsitlusleht	doc_491521502008_item	2567480	et	3	main
toidukaupade	doc_491521502008_item	2567481	et	3	main
linn	doc_491521502008_item	2567495	et	3	main
kukruse	doc_491521502008_item	2567498	et	4	main
mitu	doc_491521502008_item	2567500	et	4	main
krooni	doc_491521502008_item	2567506	et	4	main
6	doc_491521502008_item	2567507	et	2	main
kas	doc_491521502008_item	2567508	et	3	main
9	doc_491521502008_item	2567526	et	2	main
kirjutae	doc_491521502008_item	2567545	et	4	main
möödus	doc_491521502008_item	2567548	et	3	main
ja	doc_491521502008_item	2567550	et	3	main
on	doc_491521502008_item	2567558	et	4	main
kirja	doc_491521502008_item	2567566	et	4	main
tegime	doc_491521502008_item	2567583	et	3	main
olid	doc_491521502008_item	2567614	et	4	main
sugulased	doc_491521502008_item	2567615	et	3	main
siis	doc_491521502008_item	2567616	et	3	main
minu	doc_491521502008_item	2567620	et	3	main
tea	doc_491521502008_item	2567625	et	4	main
aga	doc_491521502008_item	2567626	et	3	main
teid	doc_491521502008_item	2567629	et	4	main
sõime	doc_491521502008_item	2567641	et	4	main
tantsisime	doc_491521502008_item	2567647	et	3	main
me	doc_491521502008_item	2567649	et	4	main
käisime	doc_491521502008_item	2567650	et	3	main
meeldis	doc_491521502008_item	2567660	et	3	main
pehme	doc_491521502008_item	2567662	et	4	main
kirja	doc_491521502008_item	2567675	et	4	main
mari	doc_491521502009_item	2567678	et	4	main
hea	doc_491521502009_item	2567681	et	4	main
meel	doc_491521502009_item	2567682	et	4	main
et	doc_491521502009_item	2567683	et	3	main
selle	doc_491521502009_item	2567694	et	4	main
oli	doc_491521502009_item	2567698	et	3	main
me	doc_491521502009_item	2567703	et	4	main
ja	doc_491521502009_item	2567707	et	3	main
joome	doc_491521502009_item	2567709	et	4	main
sööme	doc_491521502009_item	2567712	et	4	main
olid	doc_491521502009_item	2567714	et	4	main
mulle	doc_491521502009_item	2567718	et	4	main
raha	doc_491521502009_item	2567720	et	4	main
ja	doc_491521502009_item	2567721	et	3	main
asjud	doc_491521502009_item	2567724	et	4	main
väga	doc_491521502009_item	2567725	et	3	main
et	doc_491521502009_item	2567727	et	3	main
sina	doc_491521502009_item	2567728	et	4	main
ma	doc_491521502009_item	2567738	et	3	main
unusta	doc_491521502009_item	2567744	et	4	main
thau	doc_491521502009_item	2567745	et	4	main
xxxxxxx	doc_491521502009_item	2567748	et	4	main
kirjutamistest	doc_491521502010_item	2567750	et	4	main
teil	doc_491521502010_item	2567759	et	4	main
palutakse	doc_491521502010_item	2567760	et	4	main
ostmise	doc_491521502010_item	2567771	et	4	main
2	doc_491521502010_item	2567778	et	2	main
8	doc_491521502010_item	2567811	et	2	main
kuusissetulek	doc_491521502010_item	2567813	et	3	main
9	doc_491521502010_item	2567816	et	2	main
10	doc_491521502010_item	2567819	et	2	main
tõstamaal	doc_491521502007_item	2567429	et	4	main
44	doc_491521502007_item	2567431	et	2	main
aastat	doc_491521502007_item	2567432	et	3	main
kauem	doc_491521502007_item	2567437	et	4	main
rohkem	doc_491521502007_item	2567446	et	4	main
terasele	doc_491521502007_item	2567449	et	4	main
õpetamine	doc_491521502007_item	2567451	et	4	main
õpilaseda	doc_491521502007_item	2567457	et	4	main
kirjutamistest	doc_491521502008_item	2567461	et	4	main
esimene	doc_491521502008_item	2567462	et	3	main
osa	doc_491521502008_item	2567463	et	4	main
küsimused	doc_491521502008_item	2567464	et	4	main
kaupluses	doc_491521502008_item	2567466	et	3	main
küsitletakse	doc_491521502008_item	2567467	et	3	main
1-10	doc_491521502008_item	2567465	et	2	main
ostjaid	doc_491521502008_item	2567468	et	4	main
ka	doc_491521502008_item	2567469	et	3	main
teil	doc_491521502008_item	2567470	et	4	main
palutakse	doc_491521502008_item	2567471	et	4	main
täita	doc_491521502008_item	2567472	et	4	main
ankeet	doc_491521502008_item	2567473	et	3	main
ostmise	doc_491521502008_item	2567482	et	4	main
sugu	doc_491521502008_item	2567488	et	4	main
4	doc_491521502008_item	2567493	et	2	main
ida-virumaa	doc_491521502008_item	2567497	et	4	main
krooni	doc_491521502008_item	2567501	et	4	main
päevas	doc_491521502008_item	2567502	et	3	main
kulutate	doc_491521502008_item	2567503	et	3	main
söögile	doc_491521502008_item	2567504	et	3	main
100	doc_491521502008_item	2567505	et	2	main
7	doc_491521502008_item	2567512	et	2	main
tihti	doc_491521502008_item	2567514	et	3	main
3	doc_491521502008_item	2567517	et	2	main
8	doc_491521502008_item	2567520	et	2	main
teie	doc_491521502008_item	2567521	et	4	main
07032002	doc_491521502008_item	2567528	et	2	main
teine	doc_491521502008_item	2567532	et	3	main
talle	doc_491521502008_item	2567546	et	4	main
kuidas	doc_491521502008_item	2567547	et	3	main
mis	doc_491521502008_item	2567551	et	4	main
saite	doc_491521502008_item	2567554	et	4	main
sõna	doc_491521502008_item	2567561	et	4	main
tere	doc_491521502008_item	2567562	et	3	main
anne	doc_491521502008_item	2567563	et	4	main
otsustasin	doc_491521502008_item	2567564	et	3	main
sulle	doc_491521502008_item	2567565	et	3	main
sünnipäev	doc_491521502008_item	2567576	et	3	main
olen	doc_491521502008_item	2567579	et	3	main
ja	doc_491521502008_item	2567618	et	3	main
noormees	doc_491521502008_item	2567621	et	4	main
kui	doc_491521502008_item	2567630	et	3	main
ära	doc_491521502008_item	2567643	et	4	main
suur	doc_491521502008_item	2567661	et	3	main
mänguasi	doc_491521502008_item	2567663	et	3	main
aega	doc_491521502008_item	2567670	et	4	main
anne	doc_491521502008_item	2567672	et	4	main
ootan	doc_491521502008_item	2567673	et	3	main
sul	doc_491521502009_item	2567687	et	3	main
hea	doc_491521502009_item	2567693	et	4	main
mul	doc_491521502009_item	2567697	et	3	main
ja	doc_491521502009_item	2567711	et	3	main
kingitused	doc_491521502009_item	2567717	et	4	main
ei	doc_491521502009_item	2567729	et	4	main
kahju	doc_491521502009_item	2567736	et	4	main
ära	doc_491521502009_item	2567740	et	4	main
sinu	doc_491521502009_item	2567746	et	3	main
vastake	doc_491521502010_item	2567764	et	3	main
1	doc_491521502010_item	2567773	et	2	main
17	doc_491521502010_item	2567775	et	2	main
naine	doc_491521502010_item	2567780	et	3	main
210302	doc_491521502010_item	2567818	et	2	main
te	doc_491521502010_item	2567842	et	4	main
pikkus	doc_491521502010_item	2567847	et	4	main
aga	doc_491521502010_item	2567860	et	3	main
ma	doc_491521502010_item	2567861	et	3	main
sinu	doc_491521502010_item	2567876	et	3	main
koos	doc_491521502010_item	2567887	et	4	main
me	doc_491521502010_item	2567891	et	4	main
hotellis	doc_491521502010_item	2567897	et	3	main
päev	doc_491521502010_item	2567899	et	3	main
väga	doc_491521502010_item	2567921	et	3	main
eksamitöö	doc_491521502011_item	2567930	et	4	main
esimene	doc_491521502011_item	2567931	et	3	main
küsitletakse	doc_491521502011_item	2567936	et	3	main
küsimustele	doc_491521502011_item	2567948	et	4	main
küsitlusleht	doc_491521502011_item	2567949	et	3	main
perekonnaseis	doc_491521502011_item	2567961	et	4	main
vallaline	doc_491521502011_item	2567962	et	4	main
4	doc_491521502011_item	2567963	et	2	main
10	doc_491521502011_item	2567976	et	2	main
krooni	doc_491521502011_item	2567977	et	4	main
einestate	doc_491521502011_item	2567980	et	3	main
väljas	doc_491521502011_item	2567981	et	4	main
käite	doc_491521502011_item	2567986	et	3	main
üks	doc_491521502011_item	2567988	et	3	main
nädalas	doc_491521502011_item	2567990	et	3	main
kuusissetulek	doc_491521502011_item	2567993	et	3	main
210302	doc_491521502011_item	2567997	et	2	main
allkiri	doc_491521502011_item	2567999	et	3	main
teine	doc_491521502011_item	2568001	et	3	main
sünnipäev	doc_491521502011_item	2568006	et	3	main
nüüd	doc_491521502011_item	2568009	et	4	main
kirja	doc_491521502011_item	2568010	et	4	main
7000	doc_491521502008_item	2567523	et	2	main
allkiri	doc_491521502008_item	2567530	et	3	main
nüüd	doc_491521502008_item	2567540	et	4	main
kirja	doc_491521502008_item	2567541	et	4	main
oma	doc_491521502008_item	2567542	et	4	main
eestlasest	doc_491521502008_item	2567543	et	3	main
sünnipäevapidu	doc_491521502008_item	2567549	et	4	main
kirja	doc_491521502008_item	2567555	et	4	main
nõutav	doc_491521502008_item	2567556	et	4	main
tahan	doc_491521502008_item	2567568	et	3	main
sünnipäevast	doc_491521502008_item	2567571	et	4	main
mul	doc_491521502008_item	2567573	et	3	main
nüüd	doc_491521502008_item	2567577	et	4	main
20-aastane	doc_491521502008_item	2567580	et	4	main
eile	doc_491521502008_item	2567582	et	3	main
emaga	doc_491521502008_item	2567584	et	3	main
terve	doc_491521502008_item	2567585	et	4	main
päeva	doc_491521502008_item	2567586	et	4	main
süüa	doc_491521502008_item	2567587	et	3	main
meil	doc_491521502008_item	2567588	et	4	main
oli	doc_491521502008_item	2567589	et	3	main
suur	doc_491521502008_item	2567590	et	3	main
laud	doc_491521502008_item	2567591	et	4	main
ja	doc_491521502008_item	2567592	et	3	main
seal	doc_491521502008_item	2567593	et	4	main
oli	doc_491521502008_item	2567594	et	3	main
palju	doc_491521502008_item	2567595	et	4	main
palju	doc_491521502008_item	2567596	et	4	main
maitsvat	doc_491521502008_item	2567597	et	4	main
näiteks	doc_491521502008_item	2567598	et	4	main
kana	doc_491521502008_item	2567599	et	4	main
õunatega	doc_491521502008_item	2567600	et	4	main
erinevad	doc_491521502008_item	2567601	et	4	main
salatid	doc_491521502008_item	2567602	et	3	main
ja	doc_491521502008_item	2567603	et	3	main
suur	doc_491521502008_item	2567604	et	3	main
tort	doc_491521502008_item	2567605	et	3	main
tordi	doc_491521502008_item	2567606	et	3	main
tegin	doc_491521502008_item	2567607	et	3	main
ise	doc_491521502008_item	2567608	et	4	main
mul	doc_491521502008_item	2567609	et	3	main
oli	doc_491521502008_item	2567610	et	3	main
palju	doc_491521502008_item	2567611	et	4	main
külalisi	doc_491521502008_item	2567612	et	4	main
kõigepealt	doc_491521502008_item	2567613	et	3	main
sõprad	doc_491521502008_item	2567617	et	4	main
tutvustan	doc_491521502008_item	2567628	et	3	main
me	doc_491521502008_item	2567640	et	4	main
mängisime	doc_491521502008_item	2567645	et	3	main
pärast	doc_491521502008_item	2567648	et	4	main
head	doc_491521502008_item	2567669	et	4	main
kirjutasid	doc_491521502009_item	2567684	et	4	main
oli	doc_491521502009_item	2567700	et	3	main
olime	doc_491521502009_item	2567704	et	3	main
korterisse	doc_491521502009_item	2567706	et	3	main
palju	doc_491521502009_item	2567723	et	4	main
kahju	doc_491521502009_item	2567726	et	4	main
aga	doc_491521502009_item	2567737	et	3	main
pean	doc_491521502009_item	2567739	et	4	main
kirjuta	doc_491521502009_item	2567742	et	4	main
ära	doc_491521502009_item	2567743	et	4	main
sõbranna	doc_491521502009_item	2567747	et	4	main
esimene	doc_491521502010_item	2567751	et	3	main
täita	doc_491521502010_item	2567761	et	4	main
kohe	doc_491521502010_item	2567765	et	4	main
kõigile	doc_491521502010_item	2567767	et	4	main
küsimustele	doc_491521502010_item	2567768	et	4	main
küsitlusleht	doc_491521502010_item	2567769	et	3	main
toidukaupade	doc_491521502010_item	2567770	et	3	main
aastad	doc_491521502010_item	2567776	et	3	main
3	doc_491521502010_item	2567781	et	2	main
nädalas	doc_491521502010_item	2567810	et	3	main
kuidas	doc_491521502010_item	2567814	et	3	main
allkiri	doc_491521502010_item	2567821	et	3	main
kirja	doc_491521502010_item	2567831	et	4	main
oma	doc_491521502010_item	2567832	et	4	main
eestlasest	doc_491521502010_item	2567833	et	3	main
sõbrale	doc_491521502010_item	2567834	et	3	main
kirjutage	doc_491521502010_item	2567835	et	3	main
talle	doc_491521502010_item	2567836	et	4	main
kuidas	doc_491521502010_item	2567837	et	3	main
möödus	doc_491521502010_item	2567838	et	3	main
saite	doc_491521502010_item	2567844	et	4	main
umbes	doc_491521502010_item	2567849	et	4	main
80	doc_491521502010_item	2567850	et	2	main
katte	doc_491521502010_item	2567859	et	4	main
kirjutada	doc_491521502010_item	2567866	et	3	main
käsi	doc_491521502010_item	2567869	et	4	main
käib	doc_491521502010_item	2567870	et	3	main
kuidas	doc_491521502010_item	2567871	et	3	main
sinu	doc_491521502010_item	2567872	et	3	main
pänud	doc_491521502010_item	2567886	et	4	main
vikaga	doc_491521502010_item	2567890	et	4	main
sina	doc_491521502008_item	2567622	et	4	main
teda	doc_491521502008_item	2567623	et	4	main
ei	doc_491521502008_item	2567624	et	4	main
sa	doc_491521502008_item	2567631	et	3	main
külla	doc_491521502008_item	2567634	et	4	main
kõik	doc_491521502008_item	2567642	et	4	main
ja	doc_491521502008_item	2567646	et	3	main
mul	doc_491521502008_item	2567652	et	3	main
oli	doc_491521502008_item	2567653	et	3	main
kingitusi	doc_491521502008_item	2567655	et	4	main
palju	doc_491521502008_item	2567654	et	4	main
aga	doc_491521502008_item	2567656	et	3	main
kõige	doc_491521502008_item	2567657	et	4	main
trohkem	doc_491521502008_item	2567658	et	4	main
kinkis	doc_491521502008_item	2567665	et	3	main
mulle	doc_491521502008_item	2567666	et	4	main
minu	doc_491521502008_item	2567667	et	3	main
kallis	doc_491521502008_item	2567671	et	4	main
kiri	doc_491521502009_item	2567676	et	3	main
tere	doc_491521502009_item	2567677	et	3	main
mul	doc_491521502009_item	2567679	et	3	main
oli	doc_491521502009_item	2567680	et	3	main
käsi	doc_491521502009_item	2567688	et	4	main
käeb	doc_491521502009_item	2567689	et	4	main
mul	doc_491521502009_item	2567690	et	3	main
on	doc_491521502009_item	2567691	et	4	main
väga	doc_491521502009_item	2567692	et	3	main
eile	doc_491521502009_item	2567696	et	3	main
väga	doc_491521502009_item	2567701	et	3	main
minul	doc_491521502009_item	2567705	et	3	main
me	doc_491521502009_item	2567708	et	4	main
limonadi	doc_491521502009_item	2567710	et	4	main
salattid	doc_491521502009_item	2567713	et	4	main
toredad	doc_491521502009_item	2567716	et	3	main
kingid	doc_491521502009_item	2567719	et	4	main
noormees	doc_491521502008_item	2567668	et	4	main
sinult	doc_491521502008_item	2567674	et	3	main
mulle	doc_491521502009_item	2567685	et	4	main
kuidas	doc_491521502009_item	2567686	et	3	main
pärast	doc_491521502009_item	2567695	et	4	main
sünnipäev	doc_491521502009_item	2567699	et	3	main
tore	doc_491521502009_item	2567702	et	3	main
väga	doc_491521502009_item	2567715	et	3	main
saanud	doc_491521502009_item	2567730	et	4	main
tulla	doc_491521502009_item	2567731	et	3	main
mul	doc_491521502009_item	2567733	et	3	main
väga	doc_491521502009_item	2567735	et	3	main
minna	doc_491521502009_item	2567741	et	3	main
ankeet	doc_491521502010_item	2567762	et	3	main
täna	doc_491521502010_item	2567766	et	4	main
vanus	doc_491521502010_item	2567774	et	4	main
teine	doc_491521502010_item	2567822	et	3	main
teil	doc_491521502010_item	2567824	et	4	main
hiljuti	doc_491521502010_item	2567826	et	4	main
sünnipäev	doc_491521502010_item	2567827	et	3	main
kingiks	doc_491521502010_item	2567843	et	4	main
on	doc_491521502010_item	2567848	et	4	main
sinu	doc_491521502010_item	2567857	et	3	main
tervis	doc_491521502010_item	2567873	et	3	main
pere	doc_491521502010_item	2567877	et	4	main
isa	doc_491521502010_item	2567879	et	4	main
ja	doc_491521502010_item	2567880	et	3	main
sinu	doc_491521502010_item	2567881	et	3	main
veetsime	doc_491521502010_item	2567892	et	3	main
me	doc_491521502010_item	2567895	et	4	main
sind	doc_491521502010_item	2567924	et	4	main
ootan	doc_491521502010_item	2567926	et	3	main
head	doc_491521502010_item	2567928	et	4	main
kaupluses	doc_491521502011_item	2567935	et	3	main
teil	doc_491521502011_item	2567939	et	4	main
vastake	doc_491521502011_item	2567944	et	3	main
kohta	doc_491521502011_item	2567952	et	4	main
kohtla-järve	doc_491521502011_item	2567969	et	4	main
mitu	doc_491521502011_item	2567971	et	4	main
päevas	doc_491521502011_item	2567973	et	3	main
kui	doc_491521502011_item	2567984	et	3	main
oma	doc_491521502011_item	2568011	et	4	main
eestlasest	doc_491521502011_item	2568012	et	3	main
väga	doc_491521502009_item	2567722	et	3	main
ok	doc_491521502009_item	2567732	et	4	main
on	doc_491521502009_item	2567734	et	4	main
test	doc_491521502010_item	2567749	et	3	main
osa	doc_491521502010_item	2567752	et	4	main
küsimused	doc_491521502010_item	2567753	et	4	main
1-10	doc_491521502010_item	2567754	et	2	main
kaupluses	doc_491521502010_item	2567755	et	3	main
küsitletakse	doc_491521502010_item	2567756	et	3	main
ostjaid	doc_491521502010_item	2567757	et	4	main
ka	doc_491521502010_item	2567758	et	3	main
palun	doc_491521502010_item	2567763	et	3	main
kohta	doc_491521502010_item	2567772	et	4	main
vana	doc_491521502010_item	2567777	et	4	main
sugu	doc_491521502010_item	2567779	et	4	main
perekonnaseis	doc_491521502010_item	2567782	et	4	main
vallaline	doc_491521502010_item	2567783	et	4	main
4	doc_491521502010_item	2567784	et	2	main
elukoht	doc_491521502010_item	2567785	et	3	main
linn	doc_491521502010_item	2567786	et	3	main
maakond	doc_491521502010_item	2567787	et	3	main
kohtla-järve	doc_491521502010_item	2567788	et	4	main
5	doc_491521502010_item	2567789	et	2	main
mitu	doc_491521502010_item	2567790	et	4	main
krooni	doc_491521502010_item	2567791	et	4	main
päevas	doc_491521502010_item	2567792	et	3	main
kulutate	doc_491521502010_item	2567793	et	3	main
söögile	doc_491521502010_item	2567794	et	3	main
10-	doc_491521502010_item	2567795	et	4	main
15	doc_491521502010_item	2567796	et	2	main
eek	doc_491521502010_item	2567797	et	4	main
6	doc_491521502010_item	2567798	et	2	main
kas	doc_491521502010_item	2567799	et	3	main
einestate	doc_491521502010_item	2567800	et	3	main
väljas	doc_491521502010_item	2567801	et	4	main
ja	doc_491521502010_item	2567802	et	3	main
7	doc_491521502010_item	2567803	et	2	main
kui	doc_491521502010_item	2567804	et	3	main
tihti	doc_491521502010_item	2567805	et	3	main
käite	doc_491521502010_item	2567806	et	3	main
turul	doc_491521502010_item	2567807	et	3	main
üks	doc_491521502010_item	2567808	et	3	main
kord	doc_491521502010_item	2567809	et	4	main
teie	doc_491521502010_item	2567812	et	4	main
kunagi	doc_491521502010_item	2567815	et	3	main
kuupäev	doc_491521502010_item	2567817	et	3	main
allkiri	doc_491521502010_item	2567820	et	3	main
osa	doc_491521502010_item	2567823	et	4	main
oli	doc_491521502010_item	2567825	et	3	main
te	doc_491521502010_item	2567828	et	4	main
saadate	doc_491521502010_item	2567829	et	3	main
sünnipäevapidu	doc_491521502010_item	2567839	et	4	main
ja	doc_491521502010_item	2567840	et	3	main
kirja	doc_491521502010_item	2567845	et	4	main
nõutav	doc_491521502010_item	2567846	et	4	main
kallis	doc_491521502010_item	2567853	et	4	main
andrei	doc_491521502010_item	2567854	et	4	main
ma	doc_491521502010_item	2567855	et	3	main
sain	doc_491521502010_item	2567856	et	3	main
saadnud	doc_491521502010_item	2567863	et	4	main
on	doc_491521502010_item	2567874	et	4	main
ema	doc_491521502010_item	2567878	et	4	main
vend	doc_491521502010_item	2567882	et	3	main
elavad	doc_491521502010_item	2567883	et	4	main
ma	doc_491521502010_item	2567884	et	3	main
puhtaks	doc_491521502010_item	2567885	et	3	main
hea	doc_491521502010_item	2567894	et	4	main
peatusime	doc_491521502010_item	2567896	et	4	main
mööda	doc_491521502010_item	2567904	et	4	main
ma	doc_491521502010_item	2567922	et	3	main
osa	doc_491521502011_item	2567932	et	4	main
palutakse	doc_491521502011_item	2567940	et	4	main
ankeet	doc_491521502011_item	2567942	et	3	main
toidukaupade	doc_491521502011_item	2567950	et	3	main
5	doc_491521502011_item	2567970	et	2	main
7	doc_491521502011_item	2567983	et	2	main
9	doc_491521502011_item	2567995	et	2	main
10	doc_491521502011_item	2567998	et	2	main
oli	doc_491521502011_item	2568004	et	3	main
te	doc_491521502011_item	2568007	et	4	main
saadate	doc_491521502011_item	2568008	et	3	main
nõutav	doc_491521502011_item	2568025	et	4	main
80	doc_491521502011_item	2568029	et	2	main
kohtla-järve	doc_491521502011_item	2568032	et	4	main
meil	doc_491521502011_item	2568044	et	4	main
palju	doc_491521502011_item	2568045	et	4	main
kõik	doc_491521502011_item	2568053	et	4	main
aerobikas	doc_491521502011_item	2568057	et	4	main
sinu	doc_491521502011_item	2568079	et	3	main
kohe	doc_491521502012_item	2568098	et	4	main
küsimustele	doc_491521502012_item	2568101	et	4	main
toidukaupade	doc_491521502012_item	2568103	et	3	main
naine	doc_491521502012_item	2568112	et	3	main
maakond	doc_491521502012_item	2568119	et	3	main
nüüd	doc_491521502010_item	2567830	et	4	main
mis	doc_491521502010_item	2567841	et	4	main
sõna	doc_491521502010_item	2567851	et	4	main
tere	doc_491521502010_item	2567852	et	3	main
kirja	doc_491521502010_item	2567858	et	4	main
ei	doc_491521502010_item	2567862	et	4	main
sulle	doc_491521502010_item	2567864	et	3	main
varem	doc_491521502010_item	2567865	et	4	main
vabanda	doc_491521502010_item	2567867	et	4	main
kuidas	doc_491521502010_item	2567868	et	3	main
kuidas	doc_491521502010_item	2567875	et	3	main
mina	doc_491521502010_item	2567888	et	4	main
sõbranna	doc_491521502010_item	2567889	et	4	main
aiaga	doc_491521502010_item	2567893	et	4	main
iga	doc_491521502010_item	2567898	et	4	main
me	doc_491521502010_item	2567900	et	4	main
jalutasime	doc_491521502010_item	2567901	et	3	main
palju	doc_491521502010_item	2567902	et	4	main
käisime	doc_491521502010_item	2567903	et	3	main
poode	doc_491521502010_item	2567905	et	3	main
kelgutasime	doc_491521502010_item	2567906	et	3	main
mäel	doc_491521502010_item	2567907	et	3	main
öösel	doc_491521502010_item	2567908	et	4	main
me	doc_491521502010_item	2567909	et	4	main
käisime	doc_491521502010_item	2567910	et	3	main
diskol	doc_491521502010_item	2567911	et	4	main
kõik	doc_491521502010_item	2567912	et	4	main
oli	doc_491521502010_item	2567913	et	3	main
väga	doc_491521502010_item	2567914	et	3	main
hea	doc_491521502010_item	2567915	et	4	main
ma	doc_491521502010_item	2567916	et	3	main
ootan	doc_491521502010_item	2567917	et	3	main
sinu	doc_491521502010_item	2567918	et	3	main
kirja	doc_491521502010_item	2567919	et	4	main
väga	doc_491521502010_item	2567920	et	3	main
armastan	doc_491521502010_item	2567923	et	3	main
1-10	doc_491521502011_item	2567934	et	2	main
ka	doc_491521502011_item	2567938	et	3	main
täita	doc_491521502011_item	2567941	et	4	main
täna	doc_491521502011_item	2567946	et	4	main
ostmise	doc_491521502011_item	2567951	et	4	main
1	doc_491521502011_item	2567953	et	2	main
elukoht	doc_491521502011_item	2567964	et	3	main
linn	doc_491521502011_item	2567965	et	3	main
maakond	doc_491521502011_item	2567966	et	3	main
serva	doc_491521502011_item	2567967	et	4	main
ei	doc_491521502011_item	2567982	et	4	main
kord	doc_491521502011_item	2567989	et	4	main
teil	doc_491521502011_item	2568003	et	4	main
sõbrale	doc_491521502011_item	2568013	et	3	main
kirjutage	doc_491521502011_item	2568014	et	3	main
talle	doc_491521502011_item	2568015	et	4	main
sünnipäevapidu	doc_491521502011_item	2568018	et	4	main
ja	doc_491521502011_item	2568019	et	3	main
kingiks	doc_491521502011_item	2568022	et	4	main
210302	doc_491521502011_item	2568031	et	2	main
kallis	doc_491521502011_item	2568034	et	4	main
suur	doc_491521502011_item	2568036	et	3	main
uus	doc_491521502011_item	2568048	et	3	main
mul	doc_491521502011_item	2568051	et	3	main
käin	doc_491521502011_item	2568056	et	3	main
aega	doc_491521502011_item	2568076	et	4	main
perele	doc_491521502011_item	2568080	et	3	main
eksamitöö	doc_491521502012_item	2568083	et	4	main
1-10	doc_491521502012_item	2568087	et	2	main
ostjaid	doc_491521502012_item	2568090	et	4	main
ja	doc_491521502010_item	2567925	et	3	main
sind	doc_491521502010_item	2567927	et	4	main
aega	doc_491521502010_item	2567929	et	4	main
küsimused	doc_491521502011_item	2567933	et	4	main
ostjaid	doc_491521502011_item	2567937	et	4	main
palun	doc_491521502011_item	2567943	et	3	main
kohe	doc_491521502011_item	2567945	et	4	main
kõigile	doc_491521502011_item	2567947	et	4	main
vanus	doc_491521502011_item	2567954	et	4	main
16	doc_491521502011_item	2567955	et	2	main
a	doc_491521502011_item	2567956	et	4	main
2	doc_491521502011_item	2567957	et	2	main
sugu	doc_491521502011_item	2567958	et	4	main
naine	doc_491521502011_item	2567959	et	3	main
3	doc_491521502011_item	2567960	et	2	main
21-2	doc_491521502011_item	2567968	et	2	main
krooni	doc_491521502011_item	2567972	et	4	main
kulutate	doc_491521502011_item	2567974	et	3	main
söögile	doc_491521502011_item	2567975	et	3	main
6	doc_491521502011_item	2567978	et	2	main
kas	doc_491521502011_item	2567979	et	3	main
tihti	doc_491521502011_item	2567985	et	3	main
turul	doc_491521502011_item	2567987	et	3	main
8	doc_491521502011_item	2567991	et	2	main
teie	doc_491521502011_item	2567992	et	4	main
3000	doc_491521502011_item	2567994	et	2	main
kuupäev	doc_491521502011_item	2567996	et	3	main
allkiri	doc_491521502011_item	2568000	et	3	main
osa	doc_491521502011_item	2568002	et	4	main
hiljuti	doc_491521502011_item	2568005	et	4	main
kuidas	doc_491521502011_item	2568016	et	3	main
möödus	doc_491521502011_item	2568017	et	3	main
te	doc_491521502011_item	2568021	et	4	main
saite	doc_491521502011_item	2568023	et	4	main
kirja	doc_491521502011_item	2568024	et	4	main
sõna	doc_491521502011_item	2568030	et	4	main
natašha	doc_491521502011_item	2568035	et	2	main
aitah	doc_491521502011_item	2568037	et	4	main
sulle	doc_491521502011_item	2568038	et	3	main
kirja	doc_491521502011_item	2568039	et	4	main
ma	doc_491521502011_item	2568040	et	3	main
ootasin	doc_491521502011_item	2568041	et	3	main
seda	doc_491521502011_item	2568042	et	3	main
väga	doc_491521502011_item	2568043	et	3	main
kauplus	doc_491521502011_item	2568049	et	3	main
ma	doc_491521502011_item	2568055	et	3	main
ma	doc_491521502011_item	2568059	et	3	main
sulle	doc_491521502011_item	2568077	et	3	main
osa	doc_491521502012_item	2568085	et	4	main
küsitletakse	doc_491521502012_item	2568089	et	3	main
ka	doc_491521502012_item	2568091	et	3	main
palutakse	doc_491521502012_item	2568093	et	4	main
täna	doc_491521502012_item	2568099	et	4	main
16	doc_491521502012_item	2568108	et	2	main
a	doc_491521502012_item	2568109	et	4	main
2	doc_491521502012_item	2568110	et	2	main
linn	doc_491521502012_item	2568118	et	3	main
5	doc_491521502012_item	2568123	et	2	main
päevas	doc_491521502012_item	2568126	et	3	main
iga	doc_491521502012_item	2568141	et	4	main
kuusissetulek	doc_491521502012_item	2568145	et	3	main
210302	doc_491521502012_item	2568150	et	2	main
kirjutage	doc_491521502012_item	2568167	et	3	main
möödus	doc_491521502012_item	2568170	et	3	main
kingiks	doc_491521502012_item	2568175	et	4	main
umbes	doc_491521502012_item	2568181	et	4	main
mul	doc_491521502012_item	2568187	et	3	main
meel	doc_491521502012_item	2568190	et	4	main
kingitused	doc_491521502012_item	2568205	et	4	main
väga	doc_491521502012_item	2568210	et	3	main
palju	doc_491521502012_item	2568215	et	4	main
inimesi	doc_491521502012_item	2568216	et	4	main
nad	doc_491521502012_item	2568217	et	3	main
mis	doc_491521502011_item	2568020	et	4	main
on	doc_491521502011_item	2568027	et	4	main
hea	doc_491521502011_item	2568054	et	4	main
eile	doc_491521502011_item	2568058	et	3	main
head	doc_491521502011_item	2568075	et	4	main
lugupeetud	doc_491521502011_item	2568082	et	4	main
esimene	doc_491521502012_item	2568084	et	3	main
vanus	doc_491521502012_item	2568107	et	4	main
elukoht	doc_491521502012_item	2568117	et	3	main
kas	doc_491521502012_item	2568132	et	3	main
väljas	doc_491521502012_item	2568134	et	4	main
ei	doc_491521502012_item	2568135	et	4	main
7	doc_491521502012_item	2568136	et	2	main
kui	doc_491521502012_item	2568137	et	3	main
tihti	doc_491521502012_item	2568138	et	3	main
käite	doc_491521502012_item	2568139	et	3	main
teie	doc_491521502012_item	2568144	et	4	main
kuupäev	doc_491521502012_item	2568149	et	3	main
nüüd	doc_491521502012_item	2568162	et	4	main
kirja	doc_491521502012_item	2568163	et	4	main
talle	doc_491521502012_item	2568168	et	4	main
ja	doc_491521502012_item	2568172	et	3	main
kirja	doc_491521502012_item	2568177	et	4	main
lõbus	doc_491521502012_item	2568211	et	4	main
oli	doc_491521502012_item	2568213	et	3	main
mulle	doc_491521502012_item	2568219	et	4	main
väga	doc_491521502012_item	2568223	et	3	main
head	doc_491521502012_item	2568225	et	4	main
asjad	doc_491521502012_item	2568226	et	3	main
salat	doc_491521502012_item	2568230	et	3	main
sõbranna	doc_491521502012_item	2568243	et	4	main
neljas	doc_491521502013_item	2568247	et	4	main
väidet	doc_491521502013_item	2568250	et	3	main
kirjutage	doc_491521502013_item	2568252	et	3	main
olete	doc_491521502013_item	2568254	et	3	main
peab	doc_491521502013_item	2568264	et	4	main
sõna	doc_491521502013_item	2568268	et	4	main
elan	doc_491521502013_item	2568287	et	3	main
rääkima	doc_491521502013_item	2568291	et	3	main
eesti	doc_491521502013_item	2568303	et	4	main
keelt	doc_491521502013_item	2568304	et	4	main
õppima	doc_491521502013_item	2568320	et	3	main
koolis	doc_491521502013_item	2568328	et	4	main
poeg	doc_491521502013_item	2568330	et	3	main
peab	doc_491521502013_item	2568348	et	4	main
nendel	doc_491521502013_item	2568358	et	4	main
nad	doc_491521502013_item	2568365	et	3	main
nendele	doc_491521502013_item	2568375	et	4	main
kirjutage	doc_491521502014_item	2568414	et	3	main
või	doc_491521502014_item	2568419	et	4	main
esitage	doc_491521502014_item	2568421	et	3	main
töö	doc_491521502014_item	2568424	et	4	main
olema	doc_491521502014_item	2568427	et	4	main
meid	doc_491521502014_item	2568435	et	4	main
aitab	doc_491521502014_item	2568446	et	3	main
meid	doc_491521502014_item	2568447	et	4	main
võõrkeeled	doc_491521502014_item	2568457	et	3	main
eriti	doc_491521502014_item	2568462	et	3	main
paljudel	doc_491521502014_item	2568470	et	3	main
kes	doc_491521502014_item	2568472	et	4	main
ei	doc_491521502014_item	2568476	et	4	main
võimalus	doc_491521502014_item	2568478	et	3	main
kursused	doc_491521502014_item	2568482	et	3	main
meid	doc_491521502014_item	2568491	et	4	main
sõita	doc_491521502014_item	2568498	et	3	main
ma	doc_491521502014_item	2568523	et	3	main
me	doc_491521502014_item	2568533	et	4	main
peame	doc_491521502014_item	2568534	et	4	main
õpimma	doc_491521502014_item	2568535	et	4	main
kas	doc_491521502015_item	2568543	et	3	main
sellega	doc_491521502015_item	2568545	et	3	main
poolt-ja	doc_491521502015_item	2568550	et	3	main
sõna	doc_491521502015_item	2568558	et	4	main
väide	doc_491521502015_item	2568559	et	4	main
võõrkeelte	doc_491521502015_item	2568560	et	3	main
meid	doc_491521502015_item	2568563	et	4	main
sellega	doc_491521502015_item	2568576	et	3	main
keel	doc_491521502015_item	2568577	et	4	main
rahva	doc_491521502015_item	2568580	et	3	main
saada	doc_491521502015_item	2568583	et	4	main
võime	doc_491521502015_item	2568585	et	4	main
reisima	doc_491521502015_item	2568586	et	3	main
pikkus	doc_491521502011_item	2568026	et	4	main
umbes	doc_491521502011_item	2568028	et	4	main
tere	doc_491521502011_item	2568033	et	3	main
uues	doc_491521502011_item	2568046	et	3	main
suue	doc_491521502011_item	2568047	et	3	main
aasaegne	doc_491521502011_item	2568050	et	3	main
on	doc_491521502011_item	2568052	et	4	main
olin	doc_491521502011_item	2568060	et	3	main
sünnipäeval	doc_491521502011_item	2568061	et	3	main
kuidas	doc_491521502011_item	2568062	et	3	main
pere	doc_491521502011_item	2568064	et	4	main
sinu	doc_491521502011_item	2568063	et	3	main
aga	doc_491521502011_item	2568066	et	3	main
elab	doc_491521502011_item	2568065	et	3	main
nüüd	doc_491521502011_item	2568067	et	4	main
ma	doc_491521502011_item	2568068	et	3	main
lõpetan	doc_491521502011_item	2568069	et	3	main
oma	doc_491521502011_item	2568070	et	4	main
kirja	doc_491521502011_item	2568071	et	4	main
ja	doc_491521502011_item	2568072	et	3	main
suudlen	doc_491521502011_item	2568073	et	3	main
teil	doc_491521502011_item	2568074	et	4	main
ja	doc_491521502011_item	2568078	et	3	main
sinu	doc_491521502011_item	2568081	et	3	main
küsimused	doc_491521502012_item	2568086	et	4	main
kaupluses	doc_491521502012_item	2568088	et	3	main
küsitlusleht	doc_491521502012_item	2568102	et	3	main
sugu	doc_491521502012_item	2568111	et	4	main
3	doc_491521502012_item	2568113	et	2	main
perekonnaseis	doc_491521502012_item	2568114	et	4	main
7-40	doc_491521502012_item	2568122	et	2	main
turul	doc_491521502012_item	2568140	et	3	main
9	doc_491521502012_item	2568148	et	2	main
teil	doc_491521502012_item	2568156	et	4	main
hiljuti	doc_491521502012_item	2568158	et	4	main
sünnipäev	doc_491521502012_item	2568159	et	3	main
te	doc_491521502012_item	2568160	et	4	main
saadate	doc_491521502012_item	2568161	et	3	main
eestlasest	doc_491521502012_item	2568165	et	3	main
saite	doc_491521502012_item	2568176	et	4	main
nõutav	doc_491521502012_item	2568178	et	4	main
pikkus	doc_491521502012_item	2568179	et	4	main
on	doc_491521502012_item	2568180	et	4	main
marek	doc_491521502012_item	2568186	et	4	main
et	doc_491521502012_item	2568191	et	3	main
kirjutasid	doc_491521502012_item	2568192	et	4	main
mulle	doc_491521502012_item	2568193	et	4	main
ma	doc_491521502012_item	2568194	et	3	main
tahan	doc_491521502012_item	2568195	et	3	main
rääkida	doc_491521502012_item	2568196	et	3	main
sulle	doc_491521502012_item	2568197	et	3	main
kuidas	doc_491521502012_item	2568198	et	3	main
ma	doc_491521502012_item	2568199	et	3	main
sain	doc_491521502012_item	2568206	et	3	main
sünnipäev	doc_491521502012_item	2568208	et	3	main
kinkivad	doc_491521502012_item	2568218	et	4	main
kommid	doc_491521502012_item	2568221	et	3	main
kommid	doc_491521502012_item	2568231	et	3	main
õues	doc_491521502012_item	2568240	et	4	main
paremate	doc_491521502012_item	2568241	et	4	main
osa	doc_491521502013_item	2568246	et	4	main
lugege	doc_491521502013_item	2568249	et	3	main
ja	doc_491521502013_item	2568251	et	3	main
kas	doc_491521502013_item	2568253	et	3	main
sellega	doc_491521502013_item	2568255	et	3	main
või	doc_491521502013_item	2568257	et	4	main
mitte	doc_491521502013_item	2568258	et	3	main
vastuargumente	doc_491521502013_item	2568261	et	3	main
väide	doc_491521502013_item	2568269	et	4	main
ma	doc_491521502013_item	2568289	et	3	main
keelt	doc_491521502013_item	2568293	et	4	main
varem	doc_491521502013_item	2568294	et	4	main
kui	doc_491521502013_item	2568295	et	3	main
ma	doc_491521502013_item	2568296	et	3	main
olin	doc_491521502013_item	2568297	et	3	main
noorem	doc_491521502013_item	2568298	et	4	main
ma	doc_491521502013_item	2568306	et	3	main
eesti	doc_491521502013_item	2568309	et	4	main
ilma	doc_491521502013_item	2568311	et	4	main
eestis	doc_491521502013_item	2568312	et	3	main
ma	doc_491521502013_item	2568313	et	3	main
ei	doc_491521502013_item	2568314	et	4	main
leida	doc_491521502013_item	2568315	et	3	main
eesti	doc_491521502013_item	2568321	et	4	main
aga	doc_491521502013_item	2568323	et	3	main
ikkagi	doc_491521502013_item	2568324	et	4	main
kõrgkooli	doc_491521502013_item	2568343	et	4	main
või	doc_491521502013_item	2568344	et	4	main
võõrkeelte	doc_491521502013_item	2568350	et	3	main
töö	doc_491521502013_item	2568364	et	4	main
on	doc_491521502013_item	2568376	et	4	main
võimalusi	doc_491521502013_item	2568377	et	3	main
vestlema	doc_491521502013_item	2568378	et	3	main
võõrkeelte	doc_491521502013_item	2568379	et	3	main
kas	doc_491521502014_item	2568415	et	3	main
vastuargumente	doc_491521502014_item	2568423	et	3	main
nõus	doc_491521502014_item	2568440	et	4	main
väga	doc_491521502014_item	2568454	et	3	main
me	doc_491521502014_item	2568458	et	4	main
õppida	doc_491521502014_item	2568460	et	3	main
eestis	doc_491521502014_item	2568468	et	3	main
kuid	doc_491521502014_item	2568469	et	4	main
kallid	doc_491521502014_item	2568483	et	3	main
teil	doc_491521502012_item	2568092	et	4	main
täita	doc_491521502012_item	2568094	et	4	main
ankeet	doc_491521502012_item	2568095	et	3	main
palun	doc_491521502012_item	2568096	et	3	main
vastake	doc_491521502012_item	2568097	et	3	main
kõigile	doc_491521502012_item	2568100	et	4	main
ostmise	doc_491521502012_item	2568104	et	4	main
kohta	doc_491521502012_item	2568105	et	4	main
1	doc_491521502012_item	2568106	et	2	main
vallaline	doc_491521502012_item	2568115	et	4	main
4	doc_491521502012_item	2568116	et	2	main
kohtla-jarve	doc_491521502012_item	2568120	et	4	main
marila	doc_491521502012_item	2568121	et	4	main
10	doc_491521502012_item	2568129	et	2	main
6	doc_491521502012_item	2568131	et	2	main
einestate	doc_491521502012_item	2568133	et	3	main
nädal	doc_491521502012_item	2568142	et	3	main
2000	doc_491521502012_item	2568146	et	2	main
sõbrale	doc_491521502012_item	2568166	et	3	main
sõna	doc_491521502012_item	2568183	et	4	main
tere	doc_491521502012_item	2568184	et	3	main
kallis	doc_491521502012_item	2568185	et	4	main
veedan	doc_491521502012_item	2568200	et	3	main
oma	doc_491521502012_item	2568201	et	4	main
sünnipäev	doc_491521502012_item	2568202	et	3	main
ja	doc_491521502012_item	2568203	et	3	main
oli	doc_491521502012_item	2568209	et	3	main
ja	doc_491521502012_item	2568232	et	3	main
me	doc_491521502012_item	2568234	et	4	main
tervitustega	doc_491521502012_item	2568242	et	4	main
nõus	doc_491521502013_item	2568256	et	4	main
esitage	doc_491521502013_item	2568259	et	3	main
töö	doc_491521502013_item	2568262	et	4	main
pikkus	doc_491521502013_item	2568263	et	4	main
umbes	doc_491521502013_item	2568266	et	4	main
võõrkeelte	doc_491521502013_item	2568270	et	3	main
meid	doc_491521502013_item	2568273	et	4	main
edasi	doc_491521502013_item	2568275	et	3	main
pean	doc_491521502013_item	2568290	et	4	main
eesti	doc_491521502013_item	2568292	et	4	main
et	doc_491521502013_item	2568308	et	3	main
keelt	doc_491521502013_item	2568322	et	4	main
õpib	doc_491521502013_item	2568331	et	3	main
ta	doc_491521502013_item	2568340	et	4	main
tahab	doc_491521502013_item	2568341	et	3	main
astuda	doc_491521502013_item	2568342	et	3	main
teadma	doc_491521502013_item	2568349	et	3	main
lõpetamist	doc_491521502013_item	2568353	et	4	main
eelistavad	doc_491521502013_item	2568355	et	4	main
töötada	doc_491521502013_item	2568356	et	3	main
välismaal	doc_491521502013_item	2568357	et	4	main
töötasu	doc_491521502013_item	2568361	et	4	main
ja	doc_491521502013_item	2568362	et	3	main
prestiizi	doc_491521502013_item	2568363	et	4	main
elavad	doc_491521502013_item	2568366	et	4	main
majades	doc_491521502013_item	2568369	et	3	main
nad	doc_491521502013_item	2568371	et	3	main
viivad	doc_491521502013_item	2568372	et	4	main
välismaal	doc_491521502013_item	2568373	et	4	main
ja	doc_491521502013_item	2568380	et	3	main
nad	doc_491521502013_item	2568381	et	3	main
sellega	doc_491521502014_item	2568417	et	3	main
pikkus	doc_491521502014_item	2568425	et	4	main
peab	doc_491521502014_item	2568426	et	4	main
väide	doc_491521502014_item	2568431	et	4	main
võõrkeelte	doc_491521502014_item	2568432	et	3	main
oskamine	doc_491521502014_item	2568433	et	4	main
aitab	doc_491521502014_item	2568434	et	3	main
selle	doc_491521502014_item	2568441	et	4	main
vätega	doc_491521502014_item	2568442	et	4	main
et	doc_491521502014_item	2568443	et	3	main
võõrkeelte	doc_491521502014_item	2568444	et	3	main
oskamine	doc_491521502014_item	2568445	et	4	main
teadma	doc_491521502014_item	2568456	et	3	main
keelt	doc_491521502014_item	2568464	et	4	main
elame	doc_491521502014_item	2568467	et	3	main
inimestel	doc_491521502014_item	2568471	et	3	main
neid	doc_491521502014_item	2568475	et	4	main
ole	doc_491521502014_item	2568477	et	4	main
võõrkeeled	doc_491521502014_item	2568480	et	3	main
võõrkeelte	doc_491521502014_item	2568488	et	3	main
mitu	doc_491521502012_item	2568124	et	4	main
krooni	doc_491521502012_item	2568125	et	4	main
kulutate	doc_491521502012_item	2568127	et	3	main
söögile	doc_491521502012_item	2568128	et	3	main
krooni	doc_491521502012_item	2568130	et	4	main
8	doc_491521502012_item	2568143	et	2	main
krooni	doc_491521502012_item	2568147	et	4	main
10	doc_491521502012_item	2568151	et	2	main
allkiri	doc_491521502012_item	2568152	et	3	main
allkiri	doc_491521502012_item	2568153	et	3	main
teine	doc_491521502012_item	2568154	et	3	main
osa	doc_491521502012_item	2568155	et	4	main
oli	doc_491521502012_item	2568157	et	3	main
oma	doc_491521502012_item	2568164	et	4	main
kuidas	doc_491521502012_item	2568169	et	3	main
sünnipäevapidu	doc_491521502012_item	2568171	et	4	main
mis	doc_491521502012_item	2568173	et	4	main
te	doc_491521502012_item	2568174	et	4	main
80	doc_491521502012_item	2568182	et	2	main
oli	doc_491521502012_item	2568188	et	3	main
hea	doc_491521502012_item	2568189	et	4	main
missuguseid	doc_491521502012_item	2568204	et	3	main
minu	doc_491521502012_item	2568207	et	3	main
kodus	doc_491521502012_item	2568212	et	4	main
väga	doc_491521502012_item	2568214	et	3	main
lilled	doc_491521502012_item	2568220	et	3	main
ja	doc_491521502012_item	2568222	et	3	main
palju	doc_491521502012_item	2568224	et	4	main
me	doc_491521502012_item	2568227	et	4	main
süame	doc_491521502012_item	2568228	et	4	main
tort	doc_491521502012_item	2568229	et	3	main
nimi	doc_491521502012_item	2568244	et	3	main
neljas	doc_491521502013_item	2568245	et	4	main
osa	doc_491521502013_item	2568248	et	4	main
120	doc_491521502013_item	2568267	et	2	main
aitab	doc_491521502013_item	2568272	et	3	main
minu	doc_491521502013_item	2568276	et	3	main
on	doc_491521502013_item	2568278	et	4	main
me	doc_491521502013_item	2568299	et	4	main
väga	doc_491521502013_item	2568300	et	3	main
õppisime	doc_491521502013_item	2568302	et	3	main
praegu	doc_491521502013_item	2568305	et	3	main
keele	doc_491521502013_item	2568310	et	4	main
minu	doc_491521502013_item	2568329	et	3	main
inglise	doc_491521502013_item	2568332	et	4	main
keelt	doc_491521502013_item	2568333	et	4	main
ja	doc_491521502013_item	2568334	et	3	main
eesti	doc_491521502013_item	2568335	et	4	main
ülikooli	doc_491521502013_item	2568345	et	4	main
siis	doc_491521502013_item	2568346	et	3	main
inimesed	doc_491521502013_item	2568351	et	3	main
on	doc_491521502013_item	2568359	et	4	main
hea	doc_491521502013_item	2568360	et	4	main
mugavuses	doc_491521502013_item	2568367	et	4	main
ja	doc_491521502014_item	2568413	et	3	main
mitte	doc_491521502014_item	2568420	et	3	main
120	doc_491521502014_item	2568429	et	2	main
sõna	doc_491521502014_item	2568430	et	4	main
elus	doc_491521502014_item	2568448	et	4	main
edasi	doc_491521502014_item	2568449	et	3	main
ma	doc_491521502014_item	2568450	et	3	main
arvan	doc_491521502014_item	2568451	et	3	main
et	doc_491521502014_item	2568452	et	3	main
tähits	doc_491521502014_item	2568455	et	4	main
peame	doc_491521502014_item	2568459	et	4	main
võõrkeeled	doc_491521502014_item	2568461	et	3	main
eesti	doc_491521502014_item	2568463	et	4	main
sellepäeast	doc_491521502014_item	2568465	et	4	main
tööta	doc_491521502014_item	2568474	et	4	main
õppima	doc_491521502014_item	2568479	et	3	main
keele	doc_491521502014_item	2568481	et	4	main
nendes	doc_491521502014_item	2568484	et	4	main
on	doc_491521502014_item	2568485	et	4	main
suhtlema	doc_491521502014_item	2568492	et	3	main
meil	doc_491521502014_item	2568495	et	4	main
võimalus	doc_491521502014_item	2568497	et	3	main
rääkida	doc_491521502014_item	2568521	et	3	main
meie	doc_491521502014_item	2568530	et	4	main
tulevikut	doc_491521502014_item	2568531	et	4	main
ja	doc_491521502014_item	2568532	et	3	main
veel	doc_491521502014_item	2568536	et	4	main
ja	doc_491521502015_item	2568541	et	3	main
nõus	doc_491521502015_item	2568546	et	4	main
elus	doc_491521502015_item	2568570	et	4	main
edasi	doc_491521502015_item	2568571	et	3	main
jah	doc_491521502015_item	2568572	et	3	main
ma	doc_491521502015_item	2568573	et	3	main
olen	doc_491521502015_item	2568574	et	3	main
nõus	doc_491521502015_item	2568575	et	4	main
elu	doc_491521502015_item	2568581	et	4	main
aru	doc_491521502015_item	2568582	et	4	main
riigidel	doc_491521502015_item	2568588	et	4	main
keelte	doc_491521502015_item	2568591	et	3	main
me	doc_491521502015_item	2568593	et	4	main
kunstiga	doc_491521502015_item	2568596	et	4	main
puuvilju	doc_491521502012_item	2568233	et	3	main
laulame	doc_491521502012_item	2568235	et	4	main
vaatame	doc_491521502012_item	2568236	et	3	main
teler	doc_491521502012_item	2568237	et	3	main
ja	doc_491521502012_item	2568238	et	3	main
käiame	doc_491521502012_item	2568239	et	3	main
poolt-ja	doc_491521502013_item	2568260	et	3	main
olema	doc_491521502013_item	2568265	et	4	main
oskamine	doc_491521502013_item	2568271	et	4	main
elus	doc_491521502013_item	2568274	et	4	main
rahvus	doc_491521502013_item	2568277	et	3	main
venelane	doc_491521502013_item	2568279	et	3	main
aga	doc_491521502013_item	2568280	et	3	main
pärit	doc_491521502013_item	2568281	et	3	main
olen	doc_491521502013_item	2568282	et	3	main
ma	doc_491521502013_item	2568283	et	3	main
eestist	doc_491521502013_item	2568284	et	3	main
kui	doc_491521502013_item	2568285	et	3	main
ma	doc_491521502013_item	2568286	et	3	main
eestis	doc_491521502013_item	2568288	et	3	main
halvasti	doc_491521502013_item	2568301	et	3	main
tean	doc_491521502013_item	2568307	et	3	main
hea	doc_491521502013_item	2568316	et	4	main
tööd	doc_491521502013_item	2568317	et	4	main
ma	doc_491521502013_item	2568318	et	3	main
püüan	doc_491521502013_item	2568319	et	3	main
väga	doc_491521502013_item	2568325	et	3	main
raske	doc_491521502013_item	2568326	et	4	main
praegu	doc_491521502013_item	2568327	et	3	main
keelt	doc_491521502013_item	2568336	et	4	main
ma	doc_491521502013_item	2568337	et	3	main
tean	doc_491521502013_item	2568338	et	3	main
kui	doc_491521502013_item	2568339	et	3	main
ta	doc_491521502013_item	2568347	et	4	main
pärast	doc_491521502013_item	2568352	et	4	main
ülikooli	doc_491521502013_item	2568354	et	4	main
oma	doc_491521502013_item	2568368	et	4	main
puhkus	doc_491521502013_item	2568370	et	3	main
seal	doc_491521502013_item	2568374	et	4	main
tunnevad	doc_491521502013_item	2568382	et	3	main
endas	doc_491521502013_item	2568383	et	4	main
parem	doc_491521502013_item	2568384	et	4	main
ja	doc_491521502013_item	2568385	et	3	main
temal	doc_491521502013_item	2568386	et	3	main
ei	doc_491521502013_item	2568387	et	4	main
ole	doc_491521502013_item	2568388	et	4	main
kompleksi	doc_491521502013_item	2568389	et	4	main
muidugi	doc_491521502013_item	2568390	et	4	main
kui	doc_491521502013_item	2568391	et	3	main
sa	doc_491521502013_item	2568392	et	3	main
oskad	doc_491521502013_item	2568393	et	3	main
võõrkelle	doc_491521502013_item	2568394	et	3	main
rääkida	doc_491521502013_item	2568395	et	3	main
sa	doc_491521502013_item	2568396	et	3	main
saab	doc_491521502013_item	2568397	et	3	main
lugeda	doc_491521502013_item	2568398	et	3	main
ajalehte	doc_491521502013_item	2568399	et	4	main
ja	doc_491521502013_item	2568400	et	3	main
ajakirju	doc_491521502013_item	2568401	et	4	main
sa	doc_491521502013_item	2568402	et	3	main
saab	doc_491521502013_item	2568403	et	3	main
tutvustada	doc_491521502013_item	2568404	et	3	main
huvitava	doc_491521502013_item	2568405	et	4	main
neljas	doc_491521502014_item	2568407	et	4	main
osa	doc_491521502014_item	2568408	et	4	main
inimestega	doc_491521502013_item	2568406	et	3	main
neljas	doc_491521502014_item	2568409	et	4	main
osa	doc_491521502014_item	2568410	et	4	main
lugege	doc_491521502014_item	2568411	et	3	main
väidet	doc_491521502014_item	2568412	et	3	main
olete	doc_491521502014_item	2568416	et	3	main
nõus	doc_491521502014_item	2568418	et	4	main
poolt-ja	doc_491521502014_item	2568422	et	3	main
umbes	doc_491521502014_item	2568428	et	4	main
elus	doc_491521502014_item	2568436	et	4	main
edasi	doc_491521502014_item	2568437	et	3	main
ma	doc_491521502014_item	2568438	et	3	main
olen	doc_491521502014_item	2568439	et	3	main
praegu	doc_491521502014_item	2568453	et	3	main
me	doc_491521502014_item	2568466	et	4	main
ei	doc_491521502014_item	2568473	et	4	main
vaja	doc_491521502014_item	2568486	et	4	main
maksma	doc_491521502014_item	2568487	et	3	main
inimestega	doc_491521502014_item	2568494	et	3	main
või	doc_491521502014_item	2568501	et	4	main
prantsusemaale	doc_491521502014_item	2568502	et	4	main
või	doc_491521502014_item	2568503	et	4	main
edasi	doc_491521502014_item	2568504	et	3	main
ja	doc_491521502014_item	2568505	et	3	main
seal	doc_491521502014_item	2568506	et	4	main
me	doc_491521502014_item	2568507	et	4	main
võime	doc_491521502014_item	2568508	et	4	main
rääkida	doc_491521502014_item	2568509	et	3	main
inglise	doc_491521502014_item	2568510	et	4	main
keelt	doc_491521502014_item	2568511	et	4	main
või	doc_491521502014_item	2568512	et	4	main
prantsuse	doc_491521502014_item	2568513	et	3	main
keelt	doc_491521502014_item	2568514	et	4	main
see	doc_491521502014_item	2568515	et	3	main
väga	doc_491521502014_item	2568516	et	3	main
tore	doc_491521502014_item	2568517	et	3	main
kuidas	doc_491521502014_item	2568518	et	3	main
inimesed	doc_491521502014_item	2568519	et	3	main
võivad	doc_491521502014_item	2568520	et	4	main
oskamine	doc_491521502014_item	2568489	et	4	main
teised	doc_491521502014_item	2568493	et	4	main
on	doc_491521502014_item	2568496	et	4	main
välismaale	doc_491521502014_item	2568499	et	4	main
inglismaale	doc_491521502014_item	2568500	et	4	main
et	doc_491521502014_item	2568525	et	3	main
oskamine	doc_491521502014_item	2568527	et	4	main
see	doc_491521502014_item	2568528	et	3	main
lugege	doc_491521502015_item	2568539	et	3	main
olete	doc_491521502015_item	2568544	et	3	main
oskamine	doc_491521502015_item	2568561	et	4	main
me	doc_491521502015_item	2568584	et	4	main
ja	doc_491521502015_item	2568589	et	3	main
keelte	doc_491521502015_item	2568599	et	3	main
ma	doc_491521502015_item	2568601	et	3	main
elus	doc_491521502015_item	2568612	et	4	main
ma	doc_491521502015_item	2568613	et	3	main
neljas	doc_491521502016_item	2568620	et	4	main
pikkus	doc_491521502016_item	2568636	et	4	main
umbes	doc_491521502016_item	2568639	et	4	main
väidega	doc_491521502016_item	2568659	et	3	main
inimesed	doc_491521502016_item	2568687	et	3	main
ja	doc_491521502016_item	2568691	et	3	main
nad	doc_491521502016_item	2568721	et	3	main
tegeleda	doc_491521502016_item	2568723	et	3	main
reisiga	doc_491521502016_item	2568725	et	3	main
ei	doc_491521502016_item	2568728	et	4	main
võõrkeet	doc_491521502016_item	2568730	et	3	main
rääkida	doc_491521502016_item	2568731	et	3	main
ei	doc_491521502016_item	2568736	et	4	main
töötasu	doc_491521502016_item	2568745	et	4	main
osa	doc_491521502017_item	2568757	et	4	main
ja	doc_491521502017_item	2568762	et	3	main
olete	doc_491521502017_item	2568765	et	3	main
või	doc_491521502017_item	2568768	et	4	main
esitage	doc_491521502017_item	2568770	et	3	main
töö	doc_491521502017_item	2568773	et	4	main
pikkus	doc_491521502017_item	2568774	et	4	main
väide	doc_491521502017_item	2568780	et	4	main
meid	doc_491521502017_item	2568790	et	4	main
inimesed	doc_491521502017_item	2568799	et	3	main
võõrkeeltele	doc_491521502017_item	2568802	et	3	main
karda	doc_491521502017_item	2568811	et	4	main
jääda	doc_491521502017_item	2568812	et	4	main
ma	doc_491521502017_item	2568822	et	3	main
peavad	doc_491521502017_item	2568834	et	4	main
õppima	doc_491521502017_item	2568835	et	3	main
esimesest	doc_491521502017_item	2568836	et	3	main
ei	doc_491521502017_item	2568851	et	4	main
leiaksid	doc_491521502017_item	2568856	et	4	main
tööd	doc_491521502017_item	2568858	et	4	main
nad	doc_491521502017_item	2568859	et	3	main
võiksid	doc_491521502017_item	2568860	et	4	main
tegeleda	doc_491521502017_item	2568861	et	3	main
spordiga	doc_491521502017_item	2568862	et	3	main
reisiga	doc_491521502017_item	2568863	et	3	main
inimene	doc_491521502017_item	2568864	et	3	main
kes	doc_491521502017_item	2568865	et	4	main
osa	doc_491521502018_item	2568895	et	4	main
mitte	doc_491521502018_item	2568907	et	3	main
sõna	doc_491521502018_item	2568917	et	4	main
väide	doc_491521502018_item	2568918	et	4	main
elus	doc_491521502018_item	2568932	et	4	main
edasi	doc_491521502018_item	2568933	et	3	main
ma	doc_491521502018_item	2568934	et	3	main
olen	doc_491521502018_item	2568935	et	3	main
venelane	doc_491521502018_item	2568936	et	3	main
ja	doc_491521502018_item	2568937	et	3	main
et	doc_491521502018_item	2568958	et	3	main
keelt	doc_491521502018_item	2568962	et	4	main
ma	doc_491521502018_item	2568968	et	3	main
ei	doc_491521502018_item	2568969	et	4	main
ja	doc_491521502018_item	2568975	et	3	main
neid	doc_491521502018_item	2569001	et	4	main
üks	doc_491521502018_item	2569015	et	3	main
aitab	doc_491521502014_item	2568490	et	3	main
võõrkeelte	doc_491521502014_item	2568522	et	3	main
võõrkeelte	doc_491521502014_item	2568526	et	3	main
kirjutage	doc_491521502015_item	2568542	et	3	main
või	doc_491521502015_item	2568547	et	4	main
mitte	doc_491521502015_item	2568548	et	3	main
esitage	doc_491521502015_item	2568549	et	3	main
aitab	doc_491521502015_item	2568562	et	3	main
elus	doc_491521502015_item	2568564	et	4	main
edasi	doc_491521502015_item	2568565	et	3	main
võõrkeelte	doc_491521502015_item	2568566	et	3	main
oskamine	doc_491521502015_item	2568567	et	4	main
aitab	doc_491521502015_item	2568568	et	3	main
meid	doc_491521502015_item	2568569	et	4	main
teine	doc_491521502015_item	2568579	et	3	main
keel	doc_491521502015_item	2568608	et	4	main
annab	doc_491521502015_item	2568609	et	3	main
neljas	doc_491521502016_item	2568618	et	4	main
kas	doc_491521502016_item	2568626	et	3	main
või	doc_491521502016_item	2568630	et	4	main
mitte	doc_491521502016_item	2568631	et	3	main
töö	doc_491521502016_item	2568635	et	4	main
oskamine	doc_491521502016_item	2568644	et	4	main
elus	doc_491521502016_item	2568647	et	4	main
võõrkeelte	doc_491521502016_item	2568649	et	3	main
meid	doc_491521502016_item	2568652	et	4	main
elus	doc_491521502016_item	2568653	et	4	main
edasi	doc_491521502016_item	2568654	et	3	main
ma	doc_491521502016_item	2568655	et	3	main
karda	doc_491521502016_item	2568673	et	4	main
võõrkeelte	doc_491521502016_item	2568690	et	3	main
inimene	doc_491521502016_item	2568726	et	3	main
oska	doc_491521502016_item	2568729	et	4	main
siis	doc_491521502016_item	2568732	et	3	main
leida	doc_491521502016_item	2568738	et	3	main
tööd	doc_491521502016_item	2568740	et	4	main
tavaliselt	doc_491521502016_item	2568741	et	4	main
temal	doc_491521502016_item	2568742	et	3	main
keete	doc_491521502016_item	2568755	et	4	main
kirjutage	doc_491521502017_item	2568763	et	3	main
kas	doc_491521502017_item	2568764	et	3	main
peab	doc_491521502017_item	2568775	et	4	main
sõna	doc_491521502017_item	2568779	et	4	main
oskamine	doc_491521502017_item	2568782	et	4	main
elus	doc_491521502017_item	2568791	et	4	main
edasi	doc_491521502017_item	2568792	et	3	main
ma	doc_491521502017_item	2568793	et	3	main
olen	doc_491521502017_item	2568794	et	3	main
nõus	doc_491521502017_item	2568795	et	4	main
sellega	doc_491521502017_item	2568796	et	3	main
kes	doc_491521502017_item	2568800	et	4	main
kergem	doc_491521502017_item	2568806	et	4	main
et	doc_491521502017_item	2568824	et	3	main
klaasist	doc_491521502017_item	2568837	et	4	main
ole	doc_491521502017_item	2568852	et	4	main
ei	doc_491521502017_item	2568866	et	4	main
väidet	doc_491521502018_item	2568899	et	3	main
ja	doc_491521502018_item	2568900	et	3	main
nõus	doc_491521502018_item	2568905	et	4	main
või	doc_491521502018_item	2568906	et	4	main
töö	doc_491521502018_item	2568911	et	4	main
elasin	doc_491521502018_item	2568938	et	3	main
või	doc_491521502018_item	2568956	et	4	main
suhelda	doc_491521502018_item	2568971	et	4	main
eesti	doc_491521502018_item	2568972	et	4	main
kolegikuga	doc_491521502018_item	2568973	et	4	main
me	doc_491521502018_item	2568977	et	4	main
tõlkin	doc_491521502018_item	2569000	et	4	main
võõrkeelte	doc_491521502018_item	2569005	et	3	main
vabaduse	doc_491521502018_item	2569009	et	4	main
suhltema	doc_491521502018_item	2569010	et	4	main
ja	doc_491521502018_item	2569011	et	3	main
inimesed	doc_491521502018_item	2569012	et	3	main
saavad	doc_491521502018_item	2569013	et	4	main
aru	doc_491521502018_item	2569014	et	4	main
parem	doc_491521502018_item	2569017	et	4	main
umbes	doc_491521502019_item	2569039	et	4	main
120	doc_491521502019_item	2569040	et	2	main
elus	doc_491521502019_item	2569047	et	4	main
olen	doc_491521502019_item	2569049	et	3	main
et	doc_491521502019_item	2569055	et	3	main
kesk-evropas	doc_491521502019_item	2569058	et	4	main
arvan	doc_491521502014_item	2568524	et	3	main
on	doc_491521502014_item	2568529	et	4	main
rohkem	doc_491521502014_item	2568537	et	4	main
essee	doc_491521502015_item	2568538	et	4	main
väidet	doc_491521502015_item	2568540	et	3	main
vastuargumente	doc_491521502015_item	2568551	et	3	main
töö	doc_491521502015_item	2568552	et	4	main
pikkus	doc_491521502015_item	2568553	et	4	main
peab	doc_491521502015_item	2568554	et	4	main
olema	doc_491521502015_item	2568555	et	4	main
120	doc_491521502015_item	2568557	et	2	main
umbes	doc_491521502015_item	2568556	et	4	main
aitab	doc_491521502015_item	2568578	et	3	main
erinevadel	doc_491521502015_item	2568587	et	4	main
ainult	doc_491521502015_item	2568590	et	4	main
võime	doc_491521502015_item	2568594	et	4	main
oskamisega	doc_491521502015_item	2568600	et	4	main
tööd	doc_491521502015_item	2568603	et	4	main
eestis	doc_491521502015_item	2568604	et	3	main
ja	doc_491521502015_item	2568605	et	3	main
välismaal	doc_491521502015_item	2568606	et	4	main
leida	doc_491521502015_item	2568607	et	3	main
õpida	doc_491521502015_item	2568617	et	4	main
kirjutage	doc_491521502016_item	2568625	et	3	main
120	doc_491521502016_item	2568640	et	2	main
sõna	doc_491521502016_item	2568641	et	4	main
võõrkeelte	doc_491521502016_item	2568643	et	3	main
meid	doc_491521502016_item	2568646	et	4	main
olen	doc_491521502016_item	2568656	et	3	main
sellepärast	doc_491521502016_item	2568660	et	3	main
kes	doc_491521502016_item	2568662	et	4	main
võõrkeeltele	doc_491521502016_item	2568664	et	3	main
võivad	doc_491521502016_item	2568665	et	4	main
suhelda	doc_491521502016_item	2568666	et	4	main
jääda	doc_491521502016_item	2568674	et	4	main
kindlad	doc_491521502016_item	2568678	et	3	main
peavad	doc_491521502016_item	2568688	et	4	main
õppima	doc_491521502016_item	2568692	et	3	main
kes	doc_491521502016_item	2568727	et	4	main
inimestest	doc_491521502016_item	2568734	et	3	main
on	doc_491521502016_item	2568743	et	4	main
neljas	doc_491521502017_item	2568756	et	4	main
neljas	doc_491521502017_item	2568758	et	4	main
nõus	doc_491521502017_item	2568767	et	4	main
mitte	doc_491521502017_item	2568769	et	3	main
vastuargumente	doc_491521502017_item	2568772	et	3	main
väidega	doc_491521502017_item	2568797	et	3	main
suhelda	doc_491521502017_item	2568804	et	4	main
nendele	doc_491521502017_item	2568805	et	4	main
leida	doc_491521502017_item	2568807	et	3	main
tööd	doc_491521502017_item	2568808	et	4	main
nad	doc_491521502017_item	2568809	et	3	main
ei	doc_491521502017_item	2568810	et	4	main
ja	doc_491521502017_item	2568829	et	3	main
oleks	doc_491521502017_item	2568838	et	3	main
väga	doc_491521502017_item	2568839	et	3	main
hea	doc_491521502017_item	2568840	et	4	main
kui	doc_491521502017_item	2568841	et	3	main
kooliõpilane	doc_491521502017_item	2568842	et	3	main
teaks	doc_491521502017_item	2568843	et	3	main
kaks	doc_491521502017_item	2568844	et	3	main
problem	doc_491521502017_item	2568853	et	4	main
elus	doc_491521502017_item	2568854	et	4	main
nad	doc_491521502017_item	2568855	et	3	main
oska	doc_491521502017_item	2568867	et	4	main
võõrkeet	doc_491521502017_item	2568868	et	3	main
rääkida	doc_491521502017_item	2568869	et	3	main
õppida	doc_491521502017_item	2568892	et	3	main
esitage	doc_491521502018_item	2568908	et	3	main
peab	doc_491521502018_item	2568913	et	4	main
võõrkeelte	doc_491521502018_item	2568919	et	3	main
elus	doc_491521502018_item	2568923	et	4	main
edasi	doc_491521502018_item	2568924	et	3	main
oskamine	doc_491521502018_item	2568929	et	4	main
aitab	doc_491521502018_item	2568930	et	3	main
aastat	doc_491521502018_item	2568943	et	3	main
õpin	doc_491521502018_item	2568945	et	3	main
keelt	doc_491521502018_item	2568947	et	4	main
eesti	doc_491521502018_item	2568948	et	4	main
ma	doc_491521502018_item	2568959	et	3	main
eesti	doc_491521502018_item	2568961	et	4	main
tekitab	doc_491521502018_item	2568964	et	3	main
palju	doc_491521502018_item	2568965	et	4	main
probleeme	doc_491521502018_item	2568966	et	3	main
tööga	doc_491521502018_item	2568967	et	3	main
vaba	doc_491521502018_item	2568974	et	4	main
pean	doc_491521502018_item	2568986	et	4	main
õppima	doc_491521502018_item	2568987	et	3	main
inglise	doc_491521502018_item	2568988	et	4	main
keelt	doc_491521502018_item	2568989	et	4	main
keele	doc_491521502018_item	2568996	et	4	main
ja	doc_491521502018_item	2568997	et	3	main
ma	doc_491521502018_item	2568998	et	3	main
oskamisega	doc_491521502015_item	2568592	et	4	main
ajaluguga	doc_491521502015_item	2568595	et	4	main
rahvaga	doc_491521502015_item	2568597	et	3	main
võin	doc_491521502015_item	2568602	et	3	main
tahaksin	doc_491521502015_item	2568614	et	3	main
rohkem	doc_491521502015_item	2568615	et	4	main
keelte	doc_491521502015_item	2568616	et	3	main
tutvuda	doc_491521502015_item	2568598	et	3	main
rohkem	doc_491521502015_item	2568610	et	4	main
võimalusi	doc_491521502015_item	2568611	et	3	main
osa	doc_491521502016_item	2568619	et	4	main
osa	doc_491521502016_item	2568621	et	4	main
väidet	doc_491521502016_item	2568623	et	3	main
ja	doc_491521502016_item	2568624	et	3	main
sellega	doc_491521502016_item	2568628	et	3	main
peab	doc_491521502016_item	2568637	et	4	main
aitab	doc_491521502016_item	2568645	et	3	main
edasi	doc_491521502016_item	2568648	et	3	main
aitab	doc_491521502016_item	2568651	et	3	main
sellega	doc_491521502016_item	2568658	et	3	main
oskavad	doc_491521502016_item	2568663	et	4	main
nendele	doc_491521502016_item	2568667	et	4	main
tööd	doc_491521502016_item	2568670	et	4	main
nad	doc_491521502016_item	2568671	et	3	main
ei	doc_491521502016_item	2568672	et	4	main
nad	doc_491521502016_item	2568676	et	3	main
iseennasse	doc_491521502016_item	2568679	et	4	main
nad	doc_491521502016_item	2568680	et	3	main
võivad	doc_491521502016_item	2568681	et	4	main
õppima	doc_491521502016_item	2568689	et	3	main
laste	doc_491521502016_item	2568694	et	4	main
võiksid	doc_491521502016_item	2568722	et	4	main
sõltub	doc_491521502016_item	2568733	et	3	main
saa	doc_491521502016_item	2568737	et	4	main
huvi	doc_491521502016_item	2568739	et	4	main
ja	doc_491521502016_item	2568746	et	3	main
temal	doc_491521502016_item	2568747	et	3	main
on	doc_491521502016_item	2568748	et	4	main
raske	doc_491521502016_item	2568749	et	4	main
elada	doc_491521502016_item	2568750	et	3	main
sellepärast	doc_491521502016_item	2568751	et	3	main
osa	doc_491521502017_item	2568759	et	4	main
lugege	doc_491521502017_item	2568760	et	3	main
sellega	doc_491521502017_item	2568766	et	3	main
poolt-ja	doc_491521502017_item	2568771	et	3	main
umbes	doc_491521502017_item	2568777	et	4	main
võõrkeelte	doc_491521502017_item	2568781	et	3	main
aitab	doc_491521502017_item	2568783	et	3	main
oskavad	doc_491521502017_item	2568801	et	4	main
teada	doc_491521502017_item	2568821	et	3	main
arvan	doc_491521502017_item	2568823	et	3	main
inimesed	doc_491521502017_item	2568825	et	3	main
õppima	doc_491521502017_item	2568827	et	3	main
oma	doc_491521502017_item	2568831	et	4	main
kolm	doc_491521502017_item	2568845	et	3	main
võõrkeelte	doc_491521502017_item	2568846	et	3	main
hea	doc_491521502017_item	2568857	et	4	main
neljas	doc_491521502018_item	2568894	et	4	main
kas	doc_491521502018_item	2568902	et	3	main
sellega	doc_491521502018_item	2568904	et	3	main
vastuargumente	doc_491521502018_item	2568910	et	3	main
lugege	doc_491521502016_item	2568622	et	3	main
olete	doc_491521502016_item	2568627	et	3	main
nõus	doc_491521502016_item	2568629	et	4	main
esitage	doc_491521502016_item	2568632	et	3	main
poolt-ja	doc_491521502016_item	2568633	et	3	main
vastuargumente	doc_491521502016_item	2568634	et	3	main
olema	doc_491521502016_item	2568638	et	4	main
väide	doc_491521502016_item	2568642	et	4	main
osakamine	doc_491521502016_item	2568650	et	4	main
nõus	doc_491521502016_item	2568657	et	4	main
inimesed	doc_491521502016_item	2568661	et	3	main
kergem	doc_491521502016_item	2568668	et	4	main
leida	doc_491521502016_item	2568669	et	3	main
tööst	doc_491521502016_item	2568675	et	3	main
rohkem	doc_491521502016_item	2568677	et	4	main
rohkem	doc_491521502016_item	2568682	et	4	main
teada	doc_491521502016_item	2568683	et	3	main
ma	doc_491521502016_item	2568684	et	3	main
arvan	doc_491521502016_item	2568685	et	3	main
et	doc_491521502016_item	2568686	et	3	main
oma	doc_491521502016_item	2568693	et	4	main
koolis	doc_491521502016_item	2568695	et	4	main
peavad	doc_491521502016_item	2568696	et	4	main
õppima	doc_491521502016_item	2568697	et	3	main
esimesest	doc_491521502016_item	2568698	et	3	main
klaasist	doc_491521502016_item	2568699	et	4	main
oleks	doc_491521502016_item	2568700	et	3	main
väga	doc_491521502016_item	2568701	et	3	main
hea	doc_491521502016_item	2568702	et	4	main
kui	doc_491521502016_item	2568703	et	3	main
kooliõpilane	doc_491521502016_item	2568704	et	3	main
teaks	doc_491521502016_item	2568705	et	3	main
kaks	doc_491521502016_item	2568706	et	3	main
kolm	doc_491521502016_item	2568707	et	3	main
võõrkeelte	doc_491521502016_item	2568708	et	3	main
kooli	doc_491521502016_item	2568709	et	4	main
lõpuks	doc_491521502016_item	2568710	et	4	main
siis	doc_491521502016_item	2568711	et	3	main
temal	doc_491521502016_item	2568712	et	3	main
ei	doc_491521502016_item	2568713	et	4	main
ole	doc_491521502016_item	2568714	et	4	main
problem	doc_491521502016_item	2568715	et	4	main
elus	doc_491521502016_item	2568716	et	4	main
nad	doc_491521502016_item	2568717	et	3	main
leiaksid	doc_491521502016_item	2568718	et	4	main
tööd	doc_491521502016_item	2568720	et	4	main
hea	doc_491521502016_item	2568719	et	4	main
spordiga	doc_491521502016_item	2568724	et	3	main
ta	doc_491521502016_item	2568735	et	4	main
väiksem	doc_491521502016_item	2568744	et	4	main
on	doc_491521502016_item	2568752	et	4	main
vaja	doc_491521502016_item	2568753	et	4	main
õppida	doc_491521502016_item	2568754	et	3	main
väidet	doc_491521502017_item	2568761	et	3	main
olema	doc_491521502017_item	2568776	et	4	main
120	doc_491521502017_item	2568778	et	2	main
meid	doc_491521502017_item	2568784	et	4	main
elus	doc_491521502017_item	2568785	et	4	main
edasi	doc_491521502017_item	2568786	et	3	main
võõrkeelte	doc_491521502017_item	2568787	et	3	main
osakamine	doc_491521502017_item	2568788	et	4	main
aitab	doc_491521502017_item	2568789	et	3	main
sellepärast	doc_491521502017_item	2568798	et	3	main
võivad	doc_491521502017_item	2568803	et	4	main
tööst	doc_491521502017_item	2568813	et	3	main
nad	doc_491521502017_item	2568814	et	3	main
rohkem	doc_491521502017_item	2568815	et	4	main
kindlad	doc_491521502017_item	2568816	et	3	main
iseennasse	doc_491521502017_item	2568817	et	4	main
nad	doc_491521502017_item	2568818	et	3	main
võivad	doc_491521502017_item	2568819	et	4	main
rohkem	doc_491521502017_item	2568820	et	4	main
peavad	doc_491521502017_item	2568826	et	4	main
võõrkeelte	doc_491521502017_item	2568828	et	3	main
õppima	doc_491521502017_item	2568830	et	3	main
laste	doc_491521502017_item	2568832	et	4	main
koolis	doc_491521502017_item	2568833	et	4	main
kooli	doc_491521502017_item	2568847	et	4	main
lõpuks	doc_491521502017_item	2568848	et	4	main
siis	doc_491521502017_item	2568849	et	3	main
temal	doc_491521502017_item	2568850	et	3	main
siis	doc_491521502017_item	2568870	et	3	main
sõltub	doc_491521502017_item	2568871	et	3	main
inimestest	doc_491521502017_item	2568872	et	3	main
ta	doc_491521502017_item	2568873	et	4	main
ei	doc_491521502017_item	2568874	et	4	main
saa	doc_491521502017_item	2568875	et	4	main
leida	doc_491521502017_item	2568876	et	3	main
huvi	doc_491521502017_item	2568877	et	4	main
tööd	doc_491521502017_item	2568878	et	4	main
tavaliselt	doc_491521502017_item	2568879	et	4	main
temal	doc_491521502017_item	2568880	et	3	main
on	doc_491521502017_item	2568881	et	4	main
väiksem	doc_491521502017_item	2568882	et	4	main
töötasu	doc_491521502017_item	2568883	et	4	main
ja	doc_491521502017_item	2568884	et	3	main
temal	doc_491521502017_item	2568885	et	3	main
on	doc_491521502017_item	2568886	et	4	main
raske	doc_491521502017_item	2568887	et	4	main
elada	doc_491521502017_item	2568888	et	3	main
sellepärast	doc_491521502017_item	2568889	et	3	main
on	doc_491521502017_item	2568890	et	4	main
vaja	doc_491521502017_item	2568891	et	4	main
keete	doc_491521502017_item	2568893	et	4	main
neljas	doc_491521502018_item	2568896	et	4	main
osa	doc_491521502018_item	2568897	et	4	main
lugege	doc_491521502018_item	2568898	et	3	main
kirjutage	doc_491521502018_item	2568901	et	3	main
olete	doc_491521502018_item	2568903	et	3	main
poolt-ja	doc_491521502018_item	2568909	et	3	main
pikkus	doc_491521502018_item	2568912	et	4	main
olema	doc_491521502018_item	2568914	et	4	main
umbes	doc_491521502018_item	2568915	et	4	main
120	doc_491521502018_item	2568916	et	2	main
oskamine	doc_491521502018_item	2568920	et	4	main
aitab	doc_491521502018_item	2568921	et	3	main
arvan	doc_491521502018_item	2568926	et	3	main
et	doc_491521502018_item	2568927	et	3	main
võõrkeelte	doc_491521502018_item	2568928	et	3	main
meid	doc_491521502018_item	2568931	et	4	main
üksteist	doc_491521502018_item	2568940	et	4	main
aastat	doc_491521502018_item	2568941	et	3	main
ma	doc_491521502018_item	2568944	et	3	main
eesti	doc_491521502018_item	2568946	et	4	main
rääkida	doc_491521502018_item	2568957	et	3	main
tean	doc_491521502018_item	2568960	et	3	main
see	doc_491521502018_item	2568963	et	3	main
ei	doc_491521502018_item	2568978	et	4	main
saa	doc_491521502018_item	2568979	et	4	main
üks	doc_491521502018_item	2568981	et	3	main
teise	doc_491521502018_item	2568982	et	4	main
peale	doc_491521502018_item	2568983	et	4	main
seda	doc_491521502018_item	2568984	et	3	main
ma	doc_491521502018_item	2568985	et	3	main
palju	doc_491521502018_item	2568992	et	4	main
laboriraamatuid	doc_491521502018_item	2568993	et	3	main
on	doc_491521502018_item	2568994	et	4	main
inglise	doc_491521502018_item	2568995	et	4	main
ma	doc_491521502018_item	2569002	et	3	main
oskamine	doc_491521502018_item	2569006	et	4	main
neljas	doc_491521502019_item	2569020	et	4	main
lugege	doc_491521502019_item	2569022	et	3	main
ja	doc_491521502019_item	2569024	et	3	main
peab	doc_491521502019_item	2569037	et	4	main
olema	doc_491521502019_item	2569038	et	4	main
aitab	doc_491521502019_item	2569045	et	3	main
väidega	doc_491521502019_item	2569051	et	3	main
me	doc_491521502019_item	2569056	et	4	main
meie	doc_491521502019_item	2569060	et	4	main
nabrid	doc_491521502019_item	2569061	et	4	main
sakslased	doc_491521502019_item	2569065	et	3	main
nendega	doc_491521502019_item	2569075	et	4	main
suhtlema	doc_491521502019_item	2569076	et	3	main
nad	doc_491521502019_item	2569079	et	3	main
aru	doc_491521502019_item	2569082	et	4	main
kuidas	doc_491521502019_item	2569086	et	3	main
hirm	doc_491521502019_item	2569102	et	3	main
toimuvad	doc_491521502019_item	2569105	et	4	main
igapäev	doc_491521502019_item	2569107	et	3	main
meid	doc_491521502018_item	2568922	et	4	main
ma	doc_491521502018_item	2568925	et	3	main
eestis	doc_491521502018_item	2568939	et	3	main
üksteist	doc_491521502018_item	2568942	et	4	main
keel	doc_491521502018_item	2568949	et	4	main
on	doc_491521502018_item	2568950	et	4	main
võõrkeelt	doc_491521502018_item	2568951	et	4	main
minule	doc_491521502018_item	2568952	et	3	main
kahjuks	doc_491521502018_item	2568953	et	4	main
ma	doc_491521502018_item	2568954	et	3	main
ei	doc_491521502018_item	2568955	et	4	main
oska	doc_491521502018_item	2568970	et	4	main
mõnikord	doc_491521502018_item	2568976	et	3	main
aru	doc_491521502018_item	2568980	et	4	main
sest	doc_491521502018_item	2568990	et	4	main
praegu	doc_491521502018_item	2568991	et	3	main
ise	doc_491521502018_item	2568999	et	4	main
et	doc_491521502018_item	2569004	et	3	main
annab	doc_491521502018_item	2569007	et	3	main
osa	doc_491521502019_item	2569021	et	4	main
väidet	doc_491521502019_item	2569023	et	3	main
sellega	doc_491521502019_item	2569028	et	3	main
või	doc_491521502019_item	2569030	et	4	main
mitte	doc_491521502019_item	2569031	et	3	main
esitage	doc_491521502019_item	2569032	et	3	main
poolt-ja	doc_491521502019_item	2569033	et	3	main
vastuargumente	doc_491521502019_item	2569034	et	3	main
töö	doc_491521502019_item	2569035	et	4	main
sõna	doc_491521502019_item	2569041	et	4	main
meid	doc_491521502019_item	2569046	et	4	main
sellega	doc_491521502019_item	2569050	et	3	main
nõus	doc_491521502019_item	2569052	et	4	main
on	doc_491521502019_item	2569062	et	4	main
elavad	doc_491521502019_item	2569066	et	4	main
ja	doc_491521502019_item	2569068	et	3	main
hästi	doc_491521502019_item	2569077	et	3	main
meid	doc_491521502019_item	2569081	et	4	main
mida	doc_491521502019_item	2569083	et	4	main
me	doc_491521502019_item	2569087	et	4	main
elama	doc_491521502019_item	2569090	et	3	main
kasvab	doc_491521502019_item	2569100	et	3	main
kui	doc_491521502019_item	2569104	et	3	main
muutud	doc_491521502019_item	2569108	et	4	main
laps	doc_491521502019_item	2569123	et	4	main
õppis	doc_491521502019_item	2569126	et	3	main
osa	doc_491521502020_item	2569138	et	4	main
kas	doc_491521502020_item	2569143	et	3	main
väide	doc_491521502020_item	2569159	et	4	main
võõrkeelte	doc_491521502020_item	2569160	et	3	main
on	doc_491521502020_item	2569189	et	4	main
pääse	doc_491521502020_item	2569198	et	4	main
iga	doc_491521502020_item	2569201	et	4	main
see	doc_491521502020_item	2569211	et	3	main
arvan	doc_491521502018_item	2569003	et	3	main
inimesele	doc_491521502018_item	2569008	et	3	main
teise	doc_491521502018_item	2569016	et	4	main
neljas	doc_491521502019_item	2569018	et	4	main
osa	doc_491521502019_item	2569019	et	4	main
kas	doc_491521502019_item	2569026	et	3	main
olete	doc_491521502019_item	2569027	et	3	main
nõus	doc_491521502019_item	2569029	et	4	main
pikkus	doc_491521502019_item	2569036	et	4	main
võõrkeelte	doc_491521502019_item	2569043	et	3	main
oskamine	doc_491521502019_item	2569044	et	4	main
minu	doc_491521502019_item	2569053	et	3	main
ja	doc_491521502019_item	2569078	et	3	main
tahame	doc_491521502019_item	2569085	et	3	main
ei	doc_491521502019_item	2569099	et	4	main
tuulevikust	doc_491521502019_item	2569103	et	3	main
muudadused	doc_491521502019_item	2569106	et	4	main
ja	doc_491521502019_item	2569125	et	3	main
mittu	doc_491521502019_item	2569127	et	4	main
valdamine	doc_491521502019_item	2569129	et	4	main
võõrkeelt	doc_491521502019_item	2569130	et	4	main
aitab	doc_491521502019_item	2569131	et	3	main
neljas	doc_491521502020_item	2569137	et	4	main
lugege	doc_491521502020_item	2569139	et	3	main
sellega	doc_491521502020_item	2569145	et	3	main
oskamine	doc_491521502020_item	2569161	et	4	main
aitab	doc_491521502020_item	2569162	et	3	main
kursustel	doc_491521502020_item	2569180	et	3	main
eesti	doc_491521502020_item	2569183	et	4	main
või	doc_491521502020_item	2569184	et	4	main
mingi	doc_491521502020_item	2569185	et	4	main
teine	doc_491521502020_item	2569186	et	3	main
edasi	doc_491521502020_item	2569193	et	3	main
võõrkeelte	doc_491521502020_item	2569195	et	3	main
ei	doc_491521502020_item	2569197	et	4	main
igal	doc_491521502020_item	2569199	et	3	main
pool	doc_491521502020_item	2569200	et	4	main
tööline	doc_491521502020_item	2569206	et	4	main
valdab	doc_491521502020_item	2569207	et	3	main
kursustel	doc_491521502020_item	2569220	et	3	main
räägivad	doc_491521502020_item	2569231	et	3	main
inimesed	doc_491521502020_item	2569234	et	3	main
aru	doc_491521502020_item	2569239	et	4	main
ennast	doc_491521502020_item	2569247	et	4	main
hakkasime	doc_491521502020_item	2569249	et	3	main
et	doc_491521502020_item	2569276	et	3	main
kui	doc_491521502020_item	2569284	et	3	main
neljas	doc_491521502021_item	2569287	et	4	main
väidet	doc_491521502021_item	2569292	et	3	main
kirjutage	doc_491521502021_item	2569294	et	3	main
sellega	doc_491521502021_item	2569297	et	3	main
või	doc_491521502021_item	2569299	et	4	main
mitte	doc_491521502021_item	2569300	et	3	main
olema	doc_491521502021_item	2569307	et	4	main
sõna	doc_491521502021_item	2569310	et	4	main
elus	doc_491521502021_item	2569316	et	4	main
et	doc_491521502021_item	2569323	et	3	main
kui	doc_491521502021_item	2569333	et	3	main
oskab	doc_491521502021_item	2569335	et	3	main
siis	doc_491521502021_item	2569338	et	3	main
te	doc_491521502021_item	2569354	et	4	main
väga	doc_491521502021_item	2569357	et	3	main
tunnete	doc_491521502021_item	2569360	et	4	main
et	doc_491521502021_item	2569362	et	3	main
te	doc_491521502021_item	2569363	et	4	main
võite	doc_491521502021_item	2569364	et	4	main
rääkida	doc_491521502021_item	2569365	et	3	main
tööt	doc_491521502021_item	2569371	et	4	main
firmad	doc_491521502021_item	2569380	et	3	main
töökohtad	doc_491521502021_item	2569383	et	4	main
kui	doc_491521502021_item	2569395	et	3	main
teate	doc_491521502021_item	2569397	et	4	main
teie	doc_491521502021_item	2569404	et	4	main
tehases	doc_491521502021_item	2569421	et	3	main
palju	doc_491521502021_item	2569423	et	4	main
inimesi	doc_491521502021_item	2569424	et	4	main
kes	doc_491521502021_item	2569425	et	4	main
inimesi	doc_491521502021_item	2569430	et	4	main
võõrkeelt	doc_491521502021_item	2569435	et	4	main
kõik	doc_491521502021_item	2569445	et	4	main
sõltub	doc_491521502021_item	2569446	et	3	main
sellest	doc_491521502021_item	2569447	et	4	main
kirjutage	doc_491521502019_item	2569025	et	3	main
väide	doc_491521502019_item	2569042	et	4	main
edasi	doc_491521502019_item	2569048	et	3	main
mõttes	doc_491521502019_item	2569054	et	3	main
elame	doc_491521502019_item	2569057	et	3	main
venelased	doc_491521502019_item	2569064	et	3	main
tihti	doc_491521502019_item	2569069	et	3	main
tahame	doc_491521502019_item	2569088	et	3	main
siis	doc_491521502019_item	2569091	et	3	main
inimestel	doc_491521502019_item	2569101	et	3	main
ka	doc_491521502019_item	2569109	et	3	main
elu	doc_491521502019_item	2569110	et	4	main
ja	doc_491521502019_item	2569111	et	3	main
meie	doc_491521502019_item	2569112	et	4	main
lapsed	doc_491521502019_item	2569113	et	3	main
minu	doc_491521502019_item	2569114	et	3	main
mõttes	doc_491521502019_item	2569115	et	3	main
iga	doc_491521502019_item	2569116	et	4	main
ise	doc_491521502019_item	2569117	et	4	main
ja	doc_491521502019_item	2569118	et	3	main
ema	doc_491521502019_item	2569119	et	4	main
tahaks	doc_491521502019_item	2569120	et	3	main
kasvas	doc_491521502019_item	2569124	et	3	main
osa	doc_491521502020_item	2569136	et	4	main
väidet	doc_491521502020_item	2569140	et	3	main
kirjutage	doc_491521502020_item	2569142	et	3	main
olete	doc_491521502020_item	2569144	et	3	main
peab	doc_491521502020_item	2569154	et	4	main
120	doc_491521502020_item	2569157	et	2	main
sõna	doc_491521502020_item	2569158	et	4	main
elus	doc_491521502020_item	2569164	et	4	main
edasi	doc_491521502020_item	2569165	et	3	main
olen	doc_491521502020_item	2569166	et	3	main
nõus	doc_491521502020_item	2569167	et	4	main
selle	doc_491521502020_item	2569168	et	4	main
väitega	doc_491521502020_item	2569169	et	3	main
et	doc_491521502020_item	2569170	et	3	main
võõrkeelte	doc_491521502020_item	2569171	et	3	main
elus	doc_491521502020_item	2569174	et	4	main
paljud	doc_491521502020_item	2569176	et	3	main
võõrkeel	doc_491521502020_item	2569187	et	4	main
elu	doc_491521502020_item	2569191	et	4	main
tema	doc_491521502020_item	2569205	et	4	main
mõne	doc_491521502020_item	2569208	et	3	main
on	doc_491521502020_item	2569212	et	4	main
ma	doc_491521502020_item	2569214	et	3	main
noord	doc_491521502020_item	2569233	et	4	main
mäletan	doc_491521502020_item	2569245	et	3	main
koolis	doc_491521502020_item	2569250	et	4	main
keelt	doc_491521502020_item	2569252	et	4	main
õppima	doc_491521502020_item	2569253	et	3	main
kogu	doc_491521502020_item	2569254	et	4	main
aeg	doc_491521502020_item	2569255	et	3	main
mõtlesin	doc_491521502020_item	2569256	et	3	main
et	doc_491521502020_item	2569257	et	3	main
seda	doc_491521502020_item	2569258	et	3	main
õppige	doc_491521502020_item	2569283	et	3	main
neljas	doc_491521502021_item	2569289	et	4	main
lugege	doc_491521502021_item	2569291	et	3	main
kas	doc_491521502021_item	2569295	et	3	main
nõus	doc_491521502021_item	2569298	et	4	main
esitage	doc_491521502021_item	2569301	et	3	main
poolt-ja	doc_491521502021_item	2569302	et	3	main
vastuargumente	doc_491521502021_item	2569303	et	3	main
120	doc_491521502021_item	2569309	et	2	main
selle	doc_491521502021_item	2569321	et	4	main
rohkem	doc_491521502021_item	2569341	et	4	main
võimalusi	doc_491521502021_item	2569342	et	3	main
saada	doc_491521502021_item	2569343	et	4	main
teate	doc_491521502021_item	2569355	et	4	main
vabalt	doc_491521502021_item	2569366	et	4	main
ja	doc_491521502019_item	2569059	et	3	main
soomlased	doc_491521502019_item	2569063	et	3	main
kõrval	doc_491521502019_item	2569067	et	4	main
käivad	doc_491521502019_item	2569070	et	4	main
eestis	doc_491521502019_item	2569071	et	3	main
kui	doc_491521502019_item	2569072	et	3	main
me	doc_491521502019_item	2569073	et	4	main
oskame	doc_491521502019_item	2569074	et	3	main
saavad	doc_491521502019_item	2569080	et	4	main
me	doc_491521502019_item	2569084	et	4	main
edasi	doc_491521502019_item	2569089	et	3	main
ei	doc_491521502019_item	2569092	et	4	main
tekitavad	doc_491521502019_item	2569093	et	4	main
paljud	doc_491521502019_item	2569094	et	3	main
probleeme	doc_491521502019_item	2569095	et	3	main
elus	doc_491521502019_item	2569096	et	4	main
ja	doc_491521502019_item	2569097	et	3	main
siis	doc_491521502019_item	2569098	et	3	main
et	doc_491521502019_item	2569121	et	3	main
keelt	doc_491521502019_item	2569128	et	4	main
elus	doc_491521502019_item	2569134	et	4	main
ja	doc_491521502020_item	2569141	et	3	main
nõus	doc_491521502020_item	2569146	et	4	main
vastuargumente	doc_491521502020_item	2569151	et	3	main
töö	doc_491521502020_item	2569152	et	4	main
olema	doc_491521502020_item	2569155	et	4	main
umbes	doc_491521502020_item	2569156	et	4	main
oskamine	doc_491521502020_item	2569172	et	4	main
inimesed	doc_491521502020_item	2569177	et	3	main
et	doc_491521502020_item	2569181	et	3	main
et	doc_491521502020_item	2569192	et	3	main
oskamist	doc_491521502020_item	2569196	et	4	main
keeles	doc_491521502020_item	2569209	et	4	main
keele	doc_491521502020_item	2569219	et	4	main
selle	doc_491521502020_item	2569221	et	4	main
et	doc_491521502020_item	2569223	et	3	main
aru	doc_491521502020_item	2569228	et	4	main
millest	doc_491521502020_item	2569229	et	3	main
nemad	doc_491521502020_item	2569230	et	3	main
mõned	doc_491521502020_item	2569232	et	3	main
saa	doc_491521502020_item	2569236	et	4	main
peab	doc_491521502020_item	2569241	et	4	main
õppima	doc_491521502020_item	2569242	et	3	main
võõrkeelt	doc_491521502020_item	2569243	et	4	main
ma	doc_491521502020_item	2569244	et	3	main
keelt	doc_491521502020_item	2569259	et	4	main
raskem	doc_491521502020_item	2569274	et	4	main
saan	doc_491521502020_item	2569277	et	4	main
sellega	doc_491521502020_item	2569278	et	3	main
hakkama	doc_491521502020_item	2569279	et	3	main
ja	doc_491521502020_item	2569280	et	3	main
soovitan	doc_491521502020_item	2569281	et	3	main
kõikidele	doc_491521502020_item	2569282	et	4	main
on	doc_491521502020_item	2569285	et	4	main
osa	doc_491521502021_item	2569290	et	4	main
ja	doc_491521502021_item	2569293	et	3	main
olete	doc_491521502021_item	2569296	et	3	main
pikkus	doc_491521502021_item	2569305	et	4	main
oskamine	doc_491521502021_item	2569313	et	4	main
meid	doc_491521502021_item	2569315	et	4	main
edasi	doc_491521502021_item	2569317	et	3	main
ma	doc_491521502021_item	2569318	et	3	main
olen	doc_491521502021_item	2569319	et	3	main
nõus	doc_491521502021_item	2569320	et	4	main
tema	doc_491521502019_item	2569122	et	4	main
nendele	doc_491521502019_item	2569132	et	4	main
edasi	doc_491521502019_item	2569133	et	3	main
neljas	doc_491521502020_item	2569135	et	4	main
või	doc_491521502020_item	2569147	et	4	main
mitte	doc_491521502020_item	2569148	et	3	main
esitage	doc_491521502020_item	2569149	et	3	main
poolt-ja	doc_491521502020_item	2569150	et	3	main
pikkus	doc_491521502020_item	2569153	et	4	main
meid	doc_491521502020_item	2569163	et	4	main
aitab	doc_491521502020_item	2569173	et	3	main
edasi	doc_491521502020_item	2569175	et	3	main
käivad	doc_491521502020_item	2569178	et	4	main
praegu	doc_491521502020_item	2569179	et	3	main
õppida	doc_491521502020_item	2569182	et	3	main
präegu	doc_491521502020_item	2569188	et	4	main
selline	doc_491521502020_item	2569190	et	4	main
ilma	doc_491521502020_item	2569194	et	4	main
tööandja	doc_491521502020_item	2569202	et	4	main
tahab	doc_491521502020_item	2569203	et	3	main
et	doc_491521502020_item	2569204	et	3	main
ja	doc_491521502020_item	2569210	et	3	main
õigus	doc_491521502020_item	2569213	et	4	main
ise	doc_491521502020_item	2569215	et	4	main
käin	doc_491521502020_item	2569216	et	3	main
praegu	doc_491521502020_item	2569217	et	3	main
eesti	doc_491521502020_item	2569218	et	4	main
räägin	doc_491521502020_item	2569224	et	3	main
inimestega	doc_491521502020_item	2569225	et	3	main
ei	doc_491521502020_item	2569235	et	4	main
veel	doc_491521502020_item	2569238	et	4	main
et	doc_491521502020_item	2569240	et	3	main
inglise	doc_491521502020_item	2569251	et	4	main
osa	doc_491521502021_item	2569288	et	4	main
peab	doc_491521502021_item	2569306	et	4	main
väide	doc_491521502021_item	2569311	et	4	main
aitab	doc_491521502021_item	2569314	et	3	main
arvan	doc_491521502021_item	2569331	et	3	main
et	doc_491521502021_item	2569332	et	3	main
võõrkeelt	doc_491521502021_item	2569336	et	4	main
tal	doc_491521502021_item	2569339	et	3	main
on	doc_491521502021_item	2569340	et	4	main
me	doc_491521502021_item	2569348	et	4	main
hakkame	doc_491521502021_item	2569349	et	3	main
õppima	doc_491521502021_item	2569350	et	3	main
mingit	doc_491521502021_item	2569351	et	3	main
võõrkeelt	doc_491521502021_item	2569352	et	4	main
kui	doc_491521502021_item	2569353	et	3	main
ja	doc_491521502021_item	2569359	et	3	main
praegu	doc_491521502021_item	2569373	et	3	main
ajalehtes	doc_491521502021_item	2569375	et	4	main
kuulutusi	doc_491521502021_item	2569378	et	4	main
tingimus	doc_491521502021_item	2569388	et	4	main
on	doc_491521502021_item	2569390	et	4	main
teda	doc_491521502021_item	2569392	et	4	main
te	doc_491521502021_item	2569396	et	4	main
võõrkeelt	doc_491521502021_item	2569398	et	4	main
hästi	doc_491521502021_item	2569399	et	3	main
siis	doc_491521502021_item	2569400	et	3	main
see	doc_491521502021_item	2569401	et	3	main
töö	doc_491521502021_item	2569402	et	4	main
on	doc_491521502021_item	2569408	et	4	main
tööl	doc_491521502021_item	2569428	et	3	main
teada	doc_491521502021_item	2569434	et	3	main
nad	doc_491521502021_item	2569436	et	3	main
töötavad	doc_491521502021_item	2569438	et	4	main
ilma	doc_491521502021_item	2569439	et	4	main
osa	doc_491521502022_item	2569454	et	4	main
väidet	doc_491521502022_item	2569458	et	3	main
sellega	doc_491521502022_item	2569463	et	3	main
mitte	doc_491521502022_item	2569466	et	3	main
olema	doc_491521502022_item	2569473	et	4	main
võõrkeelte	doc_491521502022_item	2569511	et	3	main
sellepärast	doc_491521502022_item	2569525	et	3	main
praegu	doc_491521502022_item	2569531	et	3	main
õppin	doc_491521502022_item	2569533	et	4	main
saksa	doc_491521502022_item	2569542	et	4	main
ja	doc_491521502022_item	2569543	et	3	main
on	doc_491521502022_item	2569547	et	4	main
töötada	doc_491521502022_item	2569549	et	3	main
näiteks	doc_491521502022_item	2569551	et	4	main
keelt	doc_491521502022_item	2569569	et	4	main
ülikooli	doc_491521502022_item	2569573	et	4	main
töö	doc_491521502022_item	2569581	et	4	main
originalis	doc_491521502022_item	2569622	et	4	main
rahakott	doc_491521502022_item	2569624	et	3	main
on	doc_491521502022_item	2569625	et	4	main
siis	doc_491521502022_item	2569627	et	3	main
hästi	doc_491521502022_item	2569628	et	3	main
praegu	doc_491521502022_item	2569630	et	3	main
pärast	doc_491521502020_item	2569222	et	4	main
ja	doc_491521502020_item	2569226	et	3	main
saada	doc_491521502020_item	2569227	et	4	main
sellest	doc_491521502020_item	2569237	et	4	main
ise	doc_491521502020_item	2569246	et	4	main
kui	doc_491521502020_item	2569248	et	3	main
mulle	doc_491521502020_item	2569260	et	4	main
pole	doc_491521502020_item	2569261	et	3	main
vaja	doc_491521502020_item	2569262	et	4	main
nüüd	doc_491521502020_item	2569263	et	4	main
kahetsen	doc_491521502020_item	2569264	et	3	main
sellest	doc_491521502020_item	2569265	et	4	main
hakkasin	doc_491521502020_item	2569266	et	3	main
õppima	doc_491521502020_item	2569267	et	3	main
no	doc_491521502020_item	2569269	et	3	main
aga	doc_491521502020_item	2569270	et	3	main
see	doc_491521502020_item	2569271	et	3	main
on	doc_491521502020_item	2569272	et	4	main
ise	doc_491521502020_item	2569268	et	4	main
juba	doc_491521502020_item	2569273	et	3	main
loodan	doc_491521502020_item	2569275	et	3	main
võimalust	doc_491521502020_item	2569286	et	3	main
töö	doc_491521502021_item	2569304	et	4	main
umbes	doc_491521502021_item	2569308	et	4	main
võõrkeelte	doc_491521502021_item	2569312	et	3	main
aitab	doc_491521502021_item	2569326	et	3	main
meid	doc_491521502021_item	2569327	et	4	main
elus	doc_491521502021_item	2569328	et	4	main
edasi	doc_491521502021_item	2569329	et	3	main
ma	doc_491521502021_item	2569330	et	3	main
inimene	doc_491521502021_item	2569334	et	3	main
hea	doc_491521502021_item	2569344	et	4	main
hästi	doc_491521502021_item	2569358	et	3	main
välismaalis	doc_491521502021_item	2569372	et	3	main
kui	doc_491521502021_item	2569379	et	3	main
vabad	doc_491521502021_item	2569382	et	3	main
on	doc_491521502021_item	2569387	et	4	main
vaja	doc_491521502021_item	2569391	et	4	main
mingit	doc_491521502021_item	2569393	et	3	main
jaoks	doc_491521502021_item	2569405	et	4	main
mõnikord	doc_491521502021_item	2569407	et	3	main
niisugune	doc_491521502021_item	2569409	et	3	main
töö	doc_491521502021_item	2569410	et	4	main
kui	doc_491521502021_item	2569411	et	3	main
võõrkeele	doc_491521502021_item	2569412	et	4	main
töötavad	doc_491521502021_item	2569426	et	4	main
jaoks	doc_491521502021_item	2569431	et	4	main
võõrkeele	doc_491521502021_item	2569440	et	4	main
oskamiseta	doc_491521502021_item	2569441	et	4	main
ma	doc_491521502021_item	2569442	et	3	main
arvan	doc_491521502021_item	2569443	et	3	main
et	doc_491521502021_item	2569444	et	3	main
neljas	doc_491521502022_item	2569453	et	4	main
kas	doc_491521502022_item	2569461	et	3	main
peab	doc_491521502022_item	2569472	et	4	main
sõna	doc_491521502022_item	2569476	et	4	main
võõrkeelte	doc_491521502022_item	2569478	et	3	main
oskamine	doc_491521502022_item	2569512	et	4	main
võimalus	doc_491521502022_item	2569514	et	3	main
töö	doc_491521502022_item	2569516	et	4	main
keelt	doc_491521502022_item	2569535	et	4	main
aga	doc_491521502022_item	2569536	et	3	main
rootsi	doc_491521502022_item	2569544	et	4	main
saksa	doc_491521502022_item	2569560	et	4	main
või	doc_491521502022_item	2569561	et	4	main
inglise	doc_491521502022_item	2569562	et	4	main
keelt	doc_491521502022_item	2569563	et	4	main
aga	doc_491521502022_item	2569564	et	3	main
kui	doc_491521502022_item	2569565	et	3	main
ma	doc_491521502022_item	2569566	et	3	main
tean	doc_491521502022_item	2569567	et	3	main
saksa	doc_491521502022_item	2569568	et	4	main
vastu	doc_491521502022_item	2569579	et	3	main
võtta	doc_491521502022_item	2569580	et	3	main
raamatuid	doc_491521502022_item	2569621	et	3	main
õppida	doc_491521502022_item	2569633	et	3	main
aga	doc_491521502022_item	2569637	et	3	main
iseseisvalt	doc_491521502022_item	2569640	et	4	main
oskamine	doc_491521502022_item	2569642	et	4	main
osa	doc_491521502023_item	2569662	et	4	main
väidet	doc_491521502023_item	2569666	et	3	main
olete	doc_491521502023_item	2569670	et	3	main
välismaale	doc_491521502023_item	2569707	et	4	main
interneti	doc_491521502023_item	2569709	et	4	main
raamatuid	doc_491521502023_item	2569713	et	3	main
võõrkeeli	doc_491521502023_item	2569727	et	3	main
me	doc_491521502023_item	2569728	et	4	main
oskame	doc_491521502023_item	2569729	et	3	main
meid	doc_491521502023_item	2569740	et	4	main
edasi	doc_491521502023_item	2569742	et	3	main
kui	doc_491521502023_item	2569751	et	3	main
areneda	doc_491521502023_item	2569755	et	3	main
võõrkeelte	doc_491521502023_item	2569759	et	3	main
on	doc_491521502023_item	2569761	et	4	main
palju	doc_491521502023_item	2569762	et	4	main
pole	doc_491521502023_item	2569767	et	3	main
keelte	doc_491521502023_item	2569775	et	3	main
töötada	doc_491521502023_item	2569780	et	3	main
võime	doc_491521502023_item	2569814	et	4	main
rääkida	doc_491521502023_item	2569815	et	3	main
väidega	doc_491521502021_item	2569322	et	3	main
võõrkeelte	doc_491521502021_item	2569324	et	3	main
oskamine	doc_491521502021_item	2569325	et	4	main
rääkida	doc_491521502021_item	2569337	et	3	main
tööt	doc_491521502021_item	2569345	et	4	main
juba	doc_491521502021_item	2569346	et	3	main
koolis	doc_491521502021_item	2569347	et	4	main
võõrkelt	doc_491521502021_item	2569356	et	3	main
ise	doc_491521502021_item	2569361	et	4	main
võiksite	doc_491521502021_item	2569369	et	3	main
meie	doc_491521502021_item	2569374	et	4	main
on	doc_491521502021_item	2569376	et	4	main
palju	doc_491521502021_item	2569377	et	4	main
pakkuvad	doc_491521502021_item	2569381	et	4	main
aga	doc_491521502021_item	2569385	et	3	main
et	doc_491521502021_item	2569389	et	3	main
võõrkeelt	doc_491521502021_item	2569394	et	4	main
on	doc_491521502021_item	2569403	et	4	main
aga	doc_491521502021_item	2569406	et	3	main
näiteks	doc_491521502021_item	2569416	et	4	main
see	doc_491521502021_item	2569417	et	3	main
töö	doc_491521502021_item	2569418	et	4	main
on	doc_491521502021_item	2569419	et	4	main
tehases	doc_491521502021_item	2569420	et	3	main
siis	doc_491521502021_item	2569367	et	3	main
te	doc_491521502021_item	2569368	et	4	main
otsida	doc_491521502021_item	2569370	et	4	main
välismaalis	doc_491521502021_item	2569384	et	3	main
firmadel	doc_491521502021_item	2569386	et	3	main
oskamine	doc_491521502021_item	2569413	et	4	main
pole	doc_491521502021_item	2569414	et	3	main
kindlasti	doc_491521502021_item	2569415	et	3	main
mehaanilisel	doc_491521502021_item	2569427	et	3	main
vaja	doc_491521502021_item	2569433	et	4	main
lugege	doc_491521502022_item	2569457	et	3	main
olete	doc_491521502022_item	2569462	et	3	main
120	doc_491521502022_item	2569475	et	2	main
väide	doc_491521502022_item	2569477	et	4	main
arvan	doc_491521502022_item	2569509	et	3	main
unustavad	doc_491521502022_item	2569520	et	4	main
on	doc_491521502021_item	2569422	et	4	main
niisuguste	doc_491521502021_item	2569429	et	3	main
pole	doc_491521502021_item	2569432	et	3	main
lihtsalt	doc_491521502021_item	2569437	et	4	main
osa	doc_491521502022_item	2569456	et	4	main
kirjutage	doc_491521502022_item	2569460	et	3	main
või	doc_491521502022_item	2569465	et	4	main
esitage	doc_491521502022_item	2569467	et	3	main
poolt-ja	doc_491521502022_item	2569468	et	3	main
vastuargumente	doc_491521502022_item	2569469	et	3	main
töö	doc_491521502022_item	2569470	et	4	main
oskamine	doc_491521502022_item	2569479	et	4	main
aitab	doc_491521502022_item	2569480	et	3	main
meid	doc_491521502022_item	2569481	et	4	main
elus	doc_491521502022_item	2569482	et	4	main
edasi	doc_491521502022_item	2569483	et	3	main
loodan	doc_491521502022_item	2569484	et	3	main
teilt	doc_491521502022_item	2569485	et	4	main
saada	doc_491521502022_item	2569486	et	4	main
vastuse	doc_491521502022_item	2569487	et	3	main
lähemal	doc_491521502022_item	2569488	et	4	main
ajal	doc_491521502022_item	2569489	et	4	main
palun	doc_491521502022_item	2569490	et	3	main
informeetite	doc_491521502022_item	2569491	et	4	main
mind	doc_491521502022_item	2569492	et	4	main
telefoni	doc_491521502022_item	2569493	et	4	main
teel	doc_491521502022_item	2569494	et	4	main
620-344	doc_491521502022_item	2569495	et	2	main
lugupidemisega	doc_491521502022_item	2569496	et	4	main
24092000	doc_491521502022_item	2569497	et	2	main
ma	doc_491521502022_item	2569498	et	3	main
olen	doc_491521502022_item	2569499	et	3	main
nõus	doc_491521502022_item	2569500	et	4	main
et	doc_491521502022_item	2569501	et	3	main
võõrkeelte	doc_491521502022_item	2569502	et	3	main
oskamine	doc_491521502022_item	2569503	et	4	main
aitab	doc_491521502022_item	2569504	et	3	main
mind	doc_491521502022_item	2569505	et	4	main
elus	doc_491521502022_item	2569506	et	4	main
edasi	doc_491521502022_item	2569507	et	3	main
mida	doc_491521502021_item	2569448	et	4	main
tahavad	doc_491521502021_item	2569449	et	3	main
inimesed	doc_491521502021_item	2569450	et	3	main
saada	doc_491521502021_item	2569451	et	4	main
elust	doc_491521502021_item	2569452	et	3	main
neljas	doc_491521502022_item	2569455	et	4	main
ja	doc_491521502022_item	2569459	et	3	main
nõus	doc_491521502022_item	2569464	et	4	main
pikkus	doc_491521502022_item	2569471	et	4	main
umbes	doc_491521502022_item	2569474	et	4	main
et	doc_491521502022_item	2569510	et	3	main
annab	doc_491521502022_item	2569513	et	3	main
heast	doc_491521502022_item	2569521	et	3	main
veel	doc_491521502022_item	2569537	et	4	main
ma	doc_491521502022_item	2569538	et	3	main
sooviksin	doc_491521502022_item	2569539	et	3	main
õppida	doc_491521502022_item	2569540	et	3	main
inglise	doc_491521502022_item	2569541	et	4	main
keelt	doc_491521502022_item	2569545	et	4	main
koduabilisena	doc_491521502022_item	2569553	et	4	main
selle	doc_491521502022_item	2569555	et	4	main
jaoks	doc_491521502022_item	2569556	et	4	main
ma	doc_491521502022_item	2569570	et	3	main
astuda	doc_491521502022_item	2569572	et	3	main
saksamaal	doc_491521502022_item	2569574	et	4	main
ja	doc_491521502022_item	2569575	et	3	main
pärast	doc_491521502022_item	2569576	et	4	main
peale	doc_491521502022_item	2569582	et	4	main
ma	doc_491521502022_item	2569508	et	3	main
hea	doc_491521502022_item	2569515	et	4	main
leidma	doc_491521502022_item	2569517	et	3	main
aga	doc_491521502022_item	2569518	et	3	main
kõik	doc_491521502022_item	2569519	et	4	main
ka	doc_491521502022_item	2569523	et	3	main
ma	doc_491521502022_item	2569526	et	3	main
jäin	doc_491521502022_item	2569527	et	3	main
tööst	doc_491521502022_item	2569529	et	3	main
ma	doc_491521502022_item	2569532	et	3	main
on	doc_491521502022_item	2569557	et	4	main
vajalik	doc_491521502022_item	2569558	et	3	main
teada	doc_491521502022_item	2569559	et	3	main
võin	doc_491521502022_item	2569571	et	3	main
võivad	doc_491521502022_item	2569578	et	4	main
erinevaid	doc_491521502022_item	2569620	et	4	main
suur	doc_491521502022_item	2569626	et	3	main
kahjuks	doc_491521502022_item	2569629	et	4	main
näiteks	doc_491521502022_item	2569634	et	4	main
aru	doc_491521502022_item	2569646	et	4	main
mul	doc_491521502022_item	2569653	et	3	main
eest	doc_491521502022_item	2569657	et	4	main
sest	doc_491521502022_item	2569658	et	4	main
õppida	doc_491521502022_item	2569659	et	3	main
võõrkeelid	doc_491521502022_item	2569660	et	4	main
osa	doc_491521502023_item	2569664	et	4	main
on	doc_491521502023_item	2569700	et	4	main
ja	doc_491521502023_item	2569712	et	3	main
rohkem	doc_491521502023_item	2569726	et	4	main
võõrkeelte	doc_491521502023_item	2569737	et	3	main
elus	doc_491521502023_item	2569741	et	4	main
sobib	doc_491521502023_item	2569744	et	3	main
kes	doc_491521502023_item	2569746	et	4	main
ei	doc_491521502023_item	2569753	et	4	main
jaoks	doc_491521502023_item	2569757	et	4	main
oskavad	doc_491521502023_item	2569772	et	4	main
oskamiseta	doc_491521502023_item	2569776	et	4	main
keeles	doc_491521502023_item	2569817	et	4	main
inimkond	doc_491521502023_item	2569821	et	3	main
osa	doc_491521502024_item	2569827	et	4	main
lugege	doc_491521502024_item	2569828	et	3	main
olete	doc_491521502024_item	2569833	et	3	main
vastuargumente	doc_491521502024_item	2569840	et	3	main
umbes	doc_491521502024_item	2569845	et	4	main
sõna	doc_491521502024_item	2569847	et	4	main
väide	doc_491521502024_item	2569848	et	4	main
võõrkeelte	doc_491521502024_item	2569849	et	3	main
elus	doc_491521502024_item	2569853	et	4	main
oskamine	doc_491521502024_item	2569861	et	4	main
aitab	doc_491521502024_item	2569862	et	3	main
siis	doc_491521502024_item	2569870	et	3	main
väälismaal	doc_491521502024_item	2569884	et	4	main
kui	doc_491521502024_item	2569891	et	3	main
ma	doc_491521502024_item	2569921	et	3	main
oska	doc_491521502024_item	2569923	et	4	main
mul	doc_491521502024_item	2569926	et	3	main
on	doc_491521502024_item	2569927	et	4	main
hirm	doc_491521502024_item	2569928	et	3	main
võõrkeeelte	doc_491521502024_item	2569929	et	4	main
oskamine	doc_491521502024_item	2569930	et	4	main
huvitavam	doc_491521502024_item	2569941	et	4	main
ja	doc_491521502024_item	2569942	et	3	main
töötasu	doc_491521502024_item	2569944	et	4	main
võib	doc_491521502024_item	2569945	et	3	main
siis	doc_491521502024_item	2569959	et	3	main
eest	doc_491521502024_item	2569962	et	4	main
lugege	doc_491521502025_item	2569978	et	3	main
ja	doc_491521502025_item	2569980	et	3	main
kask	doc_491521502025_item	2569988	et	3	main
lõpetanu	doc_491521502025_item	2569990	et	4	main
tellerina	doc_491521502025_item	2570000	et	3	main
turvamehena	doc_491521502025_item	2570028	et	3	main
neil	doc_491521502025_item	2570029	et	4	main
tütar	doc_491521502025_item	2570033	et	3	main
71	doc_491521502025_item	2570037	et	2	main
perekonnanimi	doc_491521502025_item	2570038	et	3	main
72	doc_491521502025_item	2570040	et	2	main
2	doc_491521502025_item	2570053	et	2	main
läbi	doc_491521502025_item	2570055	et	4	main
kirjutage	doc_491521502025_item	2570059	et	3	main
talle	doc_491521502025_item	2570060	et	4	main
vastus	doc_491521502025_item	2570061	et	3	main
tööst	doc_491521502022_item	2569522	et	3	main
mina	doc_491521502022_item	2569524	et	4	main
ilma	doc_491521502022_item	2569528	et	4	main
ja	doc_491521502022_item	2569530	et	3	main
eesti	doc_491521502022_item	2569534	et	4	main
siis	doc_491521502022_item	2569546	et	3	main
võimalus	doc_491521502022_item	2569548	et	3	main
väilsmaal	doc_491521502022_item	2569550	et	4	main
esialgu	doc_491521502022_item	2569552	et	3	main
saksamaal	doc_491521502022_item	2569554	et	4	main
mind	doc_491521502022_item	2569577	et	4	main
seal	doc_491521502022_item	2569583	et	4	main
ma	doc_491521502022_item	2569584	et	3	main
mõtlen	doc_491521502022_item	2569585	et	3	main
et	doc_491521502022_item	2569586	et	3	main
võõrkeelte	doc_491521502022_item	2569587	et	3	main
oskamine	doc_491521502022_item	2569588	et	4	main
annab	doc_491521502022_item	2569589	et	3	main
võimalus	doc_491521502022_item	2569590	et	3	main
tutvustada	doc_491521502022_item	2569591	et	3	main
uue	doc_491521502022_item	2569592	et	3	main
inimestega	doc_491521502022_item	2569593	et	3	main
erinevatest	doc_491521502022_item	2569594	et	4	main
riigist	doc_491521502022_item	2569595	et	3	main
ka	doc_491521502022_item	2569596	et	3	main
ma	doc_491521502022_item	2569597	et	3	main
saan	doc_491521502022_item	2569598	et	4	main
rohkem	doc_491521502022_item	2569599	et	4	main
reisida	doc_491521502022_item	2569600	et	3	main
ja	doc_491521502022_item	2569601	et	3	main
suhtleda	doc_491521502022_item	2569603	et	4	main
rahulikult	doc_491521502022_item	2569602	et	4	main
inimestega	doc_491521502022_item	2569604	et	3	main
välismaal	doc_491521502022_item	2569605	et	4	main
veel	doc_491521502022_item	2569606	et	4	main
ma	doc_491521502022_item	2569607	et	3	main
saan	doc_491521502022_item	2569608	et	4	main
vaadata	doc_491521502022_item	2569609	et	4	main
telerit	doc_491521502022_item	2569610	et	3	main
ja	doc_491521502022_item	2569611	et	3	main
kuulata	doc_491521502022_item	2569612	et	4	main
raadiot	doc_491521502022_item	2569613	et	3	main
ilma	doc_491521502022_item	2569614	et	4	main
tõlgejata	doc_491521502022_item	2569615	et	4	main
veel	doc_491521502022_item	2569616	et	4	main
ma	doc_491521502022_item	2569617	et	3	main
võin	doc_491521502022_item	2569618	et	3	main
lugeda	doc_491521502022_item	2569619	et	3	main
kui	doc_491521502022_item	2569623	et	3	main
on	doc_491521502022_item	2569631	et	4	main
kallis	doc_491521502022_item	2569632	et	4	main
õppida	doc_491521502022_item	2569639	et	3	main
võrkeelte	doc_491521502022_item	2569641	et	4	main
mind	doc_491521502022_item	2569644	et	4	main
kultuurit	doc_491521502022_item	2569649	et	4	main
aluviisit	doc_491521502022_item	2569651	et	4	main
aga	doc_491521502022_item	2569652	et	3	main
neljas	doc_491521502023_item	2569663	et	4	main
kirjutage	doc_491521502023_item	2569668	et	3	main
esitage	doc_491521502023_item	2569675	et	3	main
vastuargumente	doc_491521502023_item	2569677	et	3	main
töö	doc_491521502023_item	2569678	et	4	main
poolt-ja	doc_491521502023_item	2569676	et	3	main
pikkus	doc_491521502023_item	2569679	et	4	main
peab	doc_491521502023_item	2569680	et	4	main
olema	doc_491521502023_item	2569681	et	4	main
umbes	doc_491521502023_item	2569682	et	4	main
120	doc_491521502023_item	2569683	et	2	main
sõna	doc_491521502023_item	2569684	et	4	main
väide	doc_491521502023_item	2569685	et	4	main
võõrkeelte	doc_491521502023_item	2569686	et	3	main
oskamine	doc_491521502023_item	2569687	et	4	main
aitab	doc_491521502023_item	2569688	et	3	main
meid	doc_491521502023_item	2569689	et	4	main
elus	doc_491521502023_item	2569690	et	4	main
edasi	doc_491521502023_item	2569691	et	3	main
sellega	doc_491521502023_item	2569692	et	3	main
ma	doc_491521502023_item	2569693	et	3	main
olen	doc_491521502023_item	2569694	et	3	main
nõus	doc_491521502023_item	2569695	et	4	main
praegu	doc_491521502023_item	2569696	et	3	main
meie	doc_491521502023_item	2569697	et	4	main
väike	doc_491521502023_item	2569698	et	4	main
mailm	doc_491521502023_item	2569699	et	4	main
inglise	doc_491521502022_item	2569635	et	4	main
võib	doc_491521502022_item	2569638	et	3	main
saama	doc_491521502022_item	2569647	et	4	main
nende	doc_491521502022_item	2569650	et	4	main
on	doc_491521502022_item	2569654	et	4	main
kogu	doc_491521502022_item	2569655	et	4	main
ja	doc_491521502023_item	2569667	et	3	main
nõus	doc_491521502023_item	2569672	et	4	main
või	doc_491521502023_item	2569673	et	4	main
mitte	doc_491521502023_item	2569674	et	3	main
uuendanud	doc_491521502023_item	2569701	et	4	main
ja	doc_491521502023_item	2569702	et	3	main
suurendanud	doc_491521502023_item	2569703	et	4	main
võime	doc_491521502023_item	2569705	et	4	main
kasutada	doc_491521502023_item	2569708	et	3	main
lugeda	doc_491521502023_item	2569710	et	3	main
vaadata	doc_491521502023_item	2569714	et	4	main
programme	doc_491521502023_item	2569716	et	3	main
telerist	doc_491521502023_item	2569717	et	4	main
kõik	doc_491521502023_item	2569719	et	4	main
see	doc_491521502023_item	2569720	et	3	main
keelt	doc_491521502022_item	2569636	et	4	main
aitab	doc_491521502022_item	2569643	et	3	main
meid	doc_491521502022_item	2569645	et	4	main
muud	doc_491521502022_item	2569648	et	4	main
elu	doc_491521502022_item	2569656	et	4	main
neljas	doc_491521502023_item	2569661	et	4	main
lugege	doc_491521502023_item	2569665	et	3	main
kas	doc_491521502023_item	2569669	et	3	main
sellega	doc_491521502023_item	2569671	et	3	main
reisida	doc_491521502023_item	2569706	et	3	main
on	doc_491521502023_item	2569721	et	4	main
seda	doc_491521502023_item	2569730	et	3	main
oskamine	doc_491521502023_item	2569738	et	4	main
teisest	doc_491521502023_item	2569749	et	4	main
mille	doc_491521502023_item	2569756	et	3	main
keelte	doc_491521502023_item	2569765	et	3	main
vaja	doc_491521502023_item	2569768	et	4	main
hasti	doc_491521502023_item	2569769	et	4	main
kui	doc_491521502023_item	2569770	et	3	main
nad	doc_491521502023_item	2569771	et	3	main
võivad	doc_491521502023_item	2569777	et	4	main
ühes	doc_491521502023_item	2569816	et	4	main
niimodi	doc_491521502023_item	2569819	et	4	main
tulevikus	doc_491521502023_item	2569823	et	4	main
väidet	doc_491521502024_item	2569829	et	3	main
kirjutage	doc_491521502024_item	2569831	et	3	main
olema	doc_491521502024_item	2569844	et	4	main
oskamine	doc_491521502024_item	2569850	et	4	main
nõus	doc_491521502024_item	2569857	et	4	main
sellega	doc_491521502024_item	2569858	et	3	main
et	doc_491521502024_item	2569859	et	3	main
võrkeelte	doc_491521502024_item	2569860	et	4	main
või	doc_491521502024_item	2569877	et	4	main
saan	doc_491521502024_item	2569881	et	4	main
suhelda	doc_491521502024_item	2569882	et	4	main
inimestega	doc_491521502024_item	2569883	et	3	main
piiratud	doc_491521502024_item	2569889	et	4	main
keeleoskusega	doc_491521502024_item	2569890	et	3	main
keel	doc_491521502024_item	2569898	et	4	main
minu	doc_491521502024_item	2569899	et	3	main
me	doc_491521502023_item	2569704	et	4	main
ajalehte	doc_491521502023_item	2569711	et	4	main
palju	doc_491521502023_item	2569715	et	4	main
aga	doc_491521502023_item	2569718	et	3	main
seotud	doc_491521502023_item	2569722	et	4	main
rohkem	doc_491521502023_item	2569731	et	4	main
võib	doc_491521502023_item	2569732	et	3	main
teada	doc_491521502023_item	2569733	et	3	main
selles	doc_491521502023_item	2569734	et	4	main
mõttes	doc_491521502023_item	2569735	et	3	main
aitab	doc_491521502023_item	2569739	et	3	main
seda	doc_491521502023_item	2569743	et	3	main
neile	doc_491521502023_item	2569745	et	4	main
tahab	doc_491521502023_item	2569747	et	3	main
areneda	doc_491521502023_item	2569748	et	3	main
inimene	doc_491521502023_item	2569752	et	3	main
inimesi	doc_491521502023_item	2569763	et	4	main
keelel	doc_491521502023_item	2569764	et	4	main
oskamine	doc_491521502023_item	2569766	et	4	main
emakeelt	doc_491521502023_item	2569773	et	4	main
ilma	doc_491521502023_item	2569774	et	4	main
nimelt	doc_491521502023_item	2569818	et	4	main
areneda	doc_491521502023_item	2569822	et	3	main
osa	doc_491521502024_item	2569825	et	4	main
neljas	doc_491521502024_item	2569826	et	4	main
nõus	doc_491521502024_item	2569835	et	4	main
või	doc_491521502024_item	2569836	et	4	main
esitage	doc_491521502024_item	2569838	et	3	main
poolt-ja	doc_491521502024_item	2569839	et	3	main
120	doc_491521502024_item	2569846	et	2	main
aitab	doc_491521502024_item	2569851	et	3	main
edasi	doc_491521502024_item	2569854	et	3	main
olen	doc_491521502024_item	2569856	et	3	main
võõrkeelt	doc_491521502024_item	2569869	et	4	main
lugeda	doc_491521502024_item	2569873	et	3	main
inglise	doc_491521502024_item	2569878	et	4	main
ma	doc_491521502024_item	2569880	et	3	main
ma	doc_491521502024_item	2569892	et	3	main
tea	doc_491521502024_item	2569894	et	4	main
võimalusid	doc_491521502024_item	2569900	et	4	main
on	doc_491521502024_item	2569901	et	4	main
piiratud	doc_491521502024_item	2569902	et	4	main
ma	doc_491521502024_item	2569903	et	3	main
ja	doc_491521502024_item	2569925	et	3	main
minu	doc_491521502024_item	2569943	et	3	main
olla	doc_491521502024_item	2569946	et	3	main
kallis	doc_491521502024_item	2569951	et	4	main
maksta	doc_491521502024_item	2569960	et	4	main
1	doc_491521502025_item	2569977	et	2	main
ja	doc_491521502025_item	2569993	et	3	main
on	doc_491521502025_item	2569995	et	4	main
oskab	doc_491521502025_item	2570002	et	3	main
eesti	doc_491521502025_item	2570003	et	4	main
ja	doc_491521502025_item	2570005	et	3	main
m	doc_491521502025_item	2570008	et	4	main
on	doc_491521502025_item	2570010	et	4	main
hea	doc_491521502025_item	2570011	et	4	main
kolmekümne	doc_491521502025_item	2570019	et	4	main
viie	doc_491521502025_item	2570020	et	3	main
võõrkeelte	doc_491521502023_item	2569723	et	3	main
oskamisega	doc_491521502023_item	2569724	et	4	main
mida	doc_491521502023_item	2569725	et	4	main
muidugi	doc_491521502023_item	2569736	et	4	main
poolest	doc_491521502023_item	2569750	et	4	main
taha	doc_491521502023_item	2569754	et	4	main
temale	doc_491521502023_item	2569758	et	3	main
oskamine	doc_491521502023_item	2569760	et	4	main
elada	doc_491521502023_item	2569778	et	3	main
ja	doc_491521502023_item	2569779	et	3	main
lihtne	doc_491521502023_item	2569781	et	3	main
töötajad	doc_491521502023_item	2569782	et	4	main
nii	doc_491521502023_item	2569783	et	3	main
koristajad	doc_491521502023_item	2569784	et	4	main
ja	doc_491521502023_item	2569785	et	3	main
majahoidjad	doc_491521502023_item	2569786	et	3	main
kui	doc_491521502023_item	2569787	et	3	main
ka	doc_491521502023_item	2569788	et	3	main
valvurid	doc_491521502023_item	2569789	et	3	main
ja	doc_491521502023_item	2569790	et	3	main
riidehoidjad	doc_491521502023_item	2569791	et	3	main
aga	doc_491521502023_item	2569792	et	3	main
kui	doc_491521502023_item	2569793	et	3	main
rääkida	doc_491521502023_item	2569794	et	3	main
tõsiselt	doc_491521502023_item	2569795	et	4	main
siis	doc_491521502023_item	2569796	et	3	main
ma	doc_491521502023_item	2569797	et	3	main
ja	doc_491521502023_item	2569799	et	3	main
arvan	doc_491521502023_item	2569798	et	3	main
absoluutselt	doc_491521502023_item	2569800	et	4	main
olen	doc_491521502023_item	2569801	et	3	main
kindel	doc_491521502023_item	2569802	et	3	main
et	doc_491521502023_item	2569803	et	3	main
võõrkeelte	doc_491521502023_item	2569804	et	3	main
oskamine	doc_491521502023_item	2569805	et	4	main
aitab	doc_491521502023_item	2569806	et	3	main
inimkonda	doc_491521502023_item	2569807	et	4	main
elus	doc_491521502023_item	2569808	et	4	main
edasi	doc_491521502023_item	2569809	et	3	main
ja	doc_491521502023_item	2569810	et	3	main
tulevikus	doc_491521502023_item	2569811	et	4	main
kõik	doc_491521502023_item	2569812	et	4	main
me	doc_491521502023_item	2569813	et	4	main
võib	doc_491521502023_item	2569820	et	3	main
neljas	doc_491521502024_item	2569824	et	4	main
ja	doc_491521502024_item	2569830	et	3	main
kas	doc_491521502024_item	2569832	et	3	main
mitte	doc_491521502024_item	2569837	et	3	main
töö	doc_491521502024_item	2569841	et	4	main
mind	doc_491521502024_item	2569863	et	4	main
ma	doc_491521502024_item	2569871	et	3	main
saksa	doc_491521502024_item	2569875	et	4	main
keelt	doc_491521502024_item	2569876	et	4	main
keelt	doc_491521502024_item	2569879	et	4	main
suhtles	doc_491521502024_item	2569886	et	3	main
ei	doc_491521502024_item	2569887	et	4	main
ole	doc_491521502024_item	2569888	et	4	main
ei	doc_491521502024_item	2569893	et	4	main
eesti	doc_491521502024_item	2569895	et	4	main
või	doc_491521502024_item	2569896	et	4	main
ei	doc_491521502024_item	2569904	et	4	main
aitab	doc_491521502024_item	2569931	et	3	main
mind	doc_491521502024_item	2569932	et	4	main
aga	doc_491521502024_item	2569948	et	3	main
ei	doc_491521502024_item	2569957	et	4	main
kuursusi	doc_491521502024_item	2569961	et	4	main
informatsiooni	doc_491521502025_item	2569979	et	4	main
ankeet	doc_491521502025_item	2569982	et	3	main
tähistatud	doc_491521502025_item	2569985	et	4	main
0-ga	doc_491521502025_item	2569986	et	3	main
maarika	doc_491521502025_item	2569987	et	4	main
tallinna	doc_491521502025_item	2569991	et	4	main
tehnikaülikooli	doc_491521502025_item	2569992	et	4	main
hansapangas	doc_491521502025_item	2569996	et	4	main
maarika	doc_491521502025_item	2570001	et	4	main
keelt	doc_491521502025_item	2570007	et	4	main
tarmo	doc_491521502025_item	2570024	et	4	main
kask	doc_491521502025_item	2570025	et	3	main
hansapangas	doc_491521502025_item	2570027	et	4	main
poeg	doc_491521502025_item	2570031	et	3	main
maarika	doc_491521502025_item	2570036	et	4	main
sugu	doc_491521502025_item	2570041	et	4	main
a	doc_491521502025_item	2570046	et	4	main
sõna	doc_491521502025_item	2570065	et	4	main
millal	doc_491521502025_item	2570070	et	3	main
tallinnasse	doc_491521502025_item	2570072	et	3	main
tallinnas	doc_491521502025_item	2570083	et	4	main
jään	doc_491521502025_item	2570086	et	3	main
tere	doc_491521502025_item	2570090	et	3	main
sain	doc_491521502025_item	2570093	et	3	main
homme	doc_491521502025_item	2570102	et	3	main
maarika	doc_491521502025_item	2570111	et	4	main
lugege	doc_491521502026_item	2570113	et	3	main
vastus	doc_491521502026_item	2570120	et	3	main
kirjuta	doc_491521502026_item	2570126	et	4	main
millal	doc_491521502026_item	2570128	et	3	main
tallinnasse	doc_491521502026_item	2570130	et	3	main
sa	doc_491521502026_item	2570134	et	3	main
vastust	doc_491521502026_item	2570145	et	4	main
margus	doc_491521502026_item	2570149	et	3	main
sinu	doc_491521502026_item	2570151	et	3	main
ma	doc_491521502026_item	2570156	et	3	main
et	doc_491521502026_item	2570158	et	3	main
ma	doc_491521502026_item	2570163	et	3	main
sinu	doc_491521502026_item	2570165	et	3	main
veski	doc_491521502026_item	2570175	et	4	main
minna	doc_491521502026_item	2570182	et	3	main
et	doc_491521502027_item	2570241	et	3	main
ma	doc_491521502027_item	2570246	et	3	main
et	doc_491521502027_item	2570248	et	3	main
tallinnas	doc_491521502027_item	2570249	et	4	main
võimalus	doc_491521502027_item	2570256	et	3	main
et	doc_491521502027_item	2570260	et	3	main
haige	doc_491521502027_item	2570263	et	4	main
varsti	doc_491521502027_item	2570265	et	3	main
on	doc_491521502027_item	2570267	et	4	main
kõik	doc_491521502027_item	2570268	et	4	main
täitke	doc_491521502028_item	2570303	et	3	main
tähistatud	doc_491521502028_item	2570307	et	4	main
0-ga	doc_491521502028_item	2570308	et	3	main
maarika	doc_491521502028_item	2570309	et	4	main
kask	doc_491521502028_item	2570310	et	3	main
on	doc_491521502028_item	2570311	et	4	main
on	doc_491521502028_item	2570317	et	4	main
aastat	doc_491521502028_item	2570321	et	3	main
sellega	doc_491521502024_item	2569834	et	3	main
pikkus	doc_491521502024_item	2569842	et	4	main
peab	doc_491521502024_item	2569843	et	4	main
meid	doc_491521502024_item	2569852	et	4	main
ma	doc_491521502024_item	2569855	et	3	main
elus	doc_491521502024_item	2569864	et	4	main
edasi	doc_491521502024_item	2569865	et	3	main
kui	doc_491521502024_item	2569866	et	3	main
ma	doc_491521502024_item	2569867	et	3	main
oskan	doc_491521502024_item	2569868	et	3	main
saan	doc_491521502024_item	2569872	et	4	main
raamatuid	doc_491521502024_item	2569874	et	3	main
meie	doc_491521502024_item	2569885	et	4	main
inglise	doc_491521502024_item	2569897	et	4	main
saa	doc_491521502024_item	2569905	et	4	main
küsita	doc_491521502024_item	2569906	et	4	main
hindast	doc_491521502024_item	2569907	et	3	main
eesti	doc_491521502024_item	2569908	et	4	main
kaupluses	doc_491521502024_item	2569909	et	3	main
ma	doc_491521502024_item	2569910	et	3	main
ei	doc_491521502024_item	2569911	et	4	main
saa	doc_491521502024_item	2569912	et	4	main
sõida	doc_491521502024_item	2569913	et	4	main
puhata	doc_491521502024_item	2569914	et	4	main
maale	doc_491521502024_item	2569915	et	4	main
kus	doc_491521502024_item	2569916	et	3	main
rägitakse	doc_491521502024_item	2569917	et	4	main
inglise	doc_491521502024_item	2569918	et	4	main
keelt	doc_491521502024_item	2569919	et	4	main
sest	doc_491521502024_item	2569920	et	4	main
saata	doc_491521502024_item	2569933	et	3	main
uue	doc_491521502024_item	2569934	et	3	main
töö	doc_491521502024_item	2569935	et	4	main
kätte	doc_491521502024_item	2569936	et	4	main
see	doc_491521502024_item	2569937	et	3	main
koolitus	doc_491521502024_item	2569949	et	4	main
ole	doc_491521502024_item	2569958	et	4	main
raskemalt	doc_491521502024_item	2569975	et	4	main
saksa	doc_491521502025_item	2570006	et	4	main
kask	doc_491521502025_item	2570009	et	3	main
suhtleja	doc_491521502025_item	2570012	et	4	main
ning	doc_491521502025_item	2570013	et	3	main
oskab	doc_491521502025_item	2570014	et	3	main
kasutada	doc_491521502025_item	2570015	et	3	main
arvutit	doc_491521502025_item	2570016	et	3	main
ta	doc_491521502025_item	2570017	et	4	main
aastane	doc_491521502025_item	2570021	et	4	main
on	doc_491521502025_item	2570030	et	4	main
73	doc_491521502025_item	2570043	et	2	main
abielus	doc_491521502025_item	2570049	et	4	main
teller	doc_491521502025_item	2570052	et	3	main
lugege	doc_491521502025_item	2570054	et	3	main
marguse	doc_491521502025_item	2570056	et	4	main
kiri	doc_491521502025_item	2570057	et	3	main
ja	doc_491521502025_item	2570058	et	3	main
kirjuta	doc_491521502025_item	2570067	et	4	main
tahad	doc_491521502025_item	2570085	et	3	main
tallinnasse	doc_491521502025_item	2570101	et	3	main
olen	doc_491521502025_item	2570104	et	3	main
üks	doc_491521502025_item	2570106	et	3	main
mind	doc_491521502025_item	2570109	et	4	main
nägemiseni	doc_491521502025_item	2570110	et	4	main
talle	doc_491521502026_item	2570119	et	4	main
on	doc_491521502026_item	2570122	et	4	main
palunmulle	doc_491521502026_item	2570127	et	4	main
sa	doc_491521502026_item	2570129	et	3	main
ei	doc_491521502024_item	2569922	et	4	main
seda	doc_491521502024_item	2569924	et	3	main
töö	doc_491521502024_item	2569938	et	4	main
võib	doc_491521502024_item	2569939	et	3	main
olla	doc_491521502024_item	2569940	et	3	main
rohkem	doc_491521502024_item	2569947	et	4	main
on	doc_491521502024_item	2569950	et	4	main
mõnu	doc_491521502024_item	2569952	et	4	main
ja	doc_491521502024_item	2569953	et	3	main
kui	doc_491521502024_item	2569954	et	3	main
inimesel	doc_491521502024_item	2569955	et	3	main
raha	doc_491521502024_item	2569956	et	4	main
ei	doc_491521502024_item	2569963	et	4	main
ole	doc_491521502024_item	2569964	et	4	main
võimalusi	doc_491521502024_item	2569965	et	3	main
siis	doc_491521502024_item	2569966	et	3	main
inimesi	doc_491521502024_item	2569967	et	4	main
peab	doc_491521502024_item	2569968	et	4	main
ise	doc_491521502024_item	2569969	et	4	main
õppida	doc_491521502024_item	2569970	et	3	main
keel	doc_491521502024_item	2569971	et	4	main
see	doc_491521502024_item	2569972	et	3	main
on	doc_491521502024_item	2569973	et	4	main
muidugi	doc_491521502024_item	2569974	et	4	main
eksamitöö	doc_491521502025_item	2569976	et	4	main
täitke	doc_491521502025_item	2569981	et	3	main
näidis	doc_491521502025_item	2569983	et	4	main
on	doc_491521502025_item	2569984	et	4	main
on	doc_491521502025_item	2569989	et	4	main
ta	doc_491521502025_item	2569994	et	4	main
töötanud	doc_491521502025_item	2569997	et	4	main
kaks	doc_491521502025_item	2569998	et	3	main
aastat	doc_491521502025_item	2569999	et	3	main
vene	doc_491521502025_item	2570004	et	4	main
on	doc_491521502025_item	2570018	et	4	main
abikaasa	doc_491521502025_item	2570023	et	4	main
töötab	doc_491521502025_item	2570026	et	3	main
ja	doc_491521502025_item	2570032	et	3	main
eesnimi	doc_491521502025_item	2570035	et	3	main
kask	doc_491521502025_item	2570039	et	3	main
74	doc_491521502025_item	2570047	et	2	main
amet	doc_491521502025_item	2570051	et	3	main
20-25	doc_491521502025_item	2570064	et	2	main
palun	doc_491521502025_item	2570068	et	3	main
sõidan	doc_491521502025_item	2570100	et	3	main
tallinnas	doc_491521502025_item	2570105	et	4	main
kuu	doc_491521502025_item	2570107	et	4	main
ootab	doc_491521502025_item	2570108	et	3	main
marguse	doc_491521502026_item	2570115	et	4	main
kiri	doc_491521502026_item	2570116	et	3	main
ja	doc_491521502026_item	2570117	et	3	main
kirjutage	doc_491521502026_item	2570118	et	3	main
kus	doc_491521502026_item	2570121	et	3	main
sõna	doc_491521502026_item	2570124	et	4	main
mitu	doc_491521502026_item	2570132	et	4	main
oled	doc_491521502026_item	2570137	et	3	main
sa	doc_491521502026_item	2570140	et	3	main
tallinnas	doc_491521502026_item	2570141	et	4	main
jään	doc_491521502026_item	2570144	et	3	main
tere	doc_491521502026_item	2570148	et	3	main
sain	doc_491521502026_item	2570150	et	3	main
tänu	doc_491521502026_item	2570155	et	4	main
arvan	doc_491521502026_item	2570157	et	3	main
tallinnasse	doc_491521502026_item	2570160	et	3	main
umbes	doc_491521502026_item	2570167	et	4	main
kinno	doc_491521502026_item	2570181	et	3	main
tahad	doc_491521502027_item	2570228	et	3	main
suur	doc_491521502027_item	2570239	et	3	main
ei	doc_491521502027_item	2570242	et	4	main
nägisime	doc_491521502027_item	2570251	et	4	main
praegu	doc_491521502027_item	2570252	et	3	main
sellepärast	doc_491521502027_item	2570259	et	3	main
ma	doc_491521502027_item	2570261	et	3	main
kuid	doc_491521502027_item	2570264	et	4	main
juurde	doc_491521502027_item	2570274	et	4	main
ankeet	doc_491521502028_item	2570304	et	3	main
tallinna	doc_491521502028_item	2570313	et	4	main
töötanud	doc_491521502028_item	2570319	et	4	main
kaks	doc_491521502028_item	2570320	et	3	main
tellerina	doc_491521502028_item	2570322	et	3	main
eesti	doc_491521502028_item	2570325	et	4	main
m	doc_491521502028_item	2570330	et	4	main
on	doc_491521502028_item	2570332	et	4	main
arvutit	doc_491521502028_item	2570338	et	3	main
on	doc_491521502028_item	2570340	et	4	main
kolmekümne	doc_491521502028_item	2570341	et	4	main
aastane	doc_491521502028_item	2570343	et	4	main
maarika	doc_491521502028_item	2570344	et	4	main
turvamehena	doc_491521502028_item	2570350	et	3	main
maarika	doc_491521502028_item	2570358	et	4	main
perekonnanimi	doc_491521502028_item	2570360	et	3	main
sugu	doc_491521502028_item	2570363	et	4	main
73	doc_491521502028_item	2570365	et	2	main
perkonnaseis	doc_491521502028_item	2570369	et	4	main
läbi	doc_491521502028_item	2570376	et	4	main
tallinna	doc_491521502028_item	2570415	et	4	main
kell	doc_491521502028_item	2570417	et	3	main
kaks	doc_491521502028_item	2570424	et	3	main
draamateatrisse	doc_491521502028_item	2570428	et	3	main
minna	doc_491521502028_item	2570429	et	3	main
maarika	doc_491521502028_item	2570431	et	4	main
ankeet	doc_491521502029_item	2570438	et	3	main
tähistatud	doc_491521502029_item	2570441	et	4	main
on	doc_491521502029_item	2570445	et	4	main
lõpetanu	doc_491521502029_item	2570446	et	4	main
hansapangas	doc_491521502029_item	2570452	et	4	main
maarika	doc_491521502025_item	2570022	et	4	main
0	doc_491521502025_item	2570034	et	2	main
naine	doc_491521502025_item	2570042	et	3	main
vanus	doc_491521502025_item	2570044	et	4	main
35	doc_491521502025_item	2570045	et	2	main
perkonnaseis	doc_491521502025_item	2570048	et	4	main
75	doc_491521502025_item	2570050	et	2	main
on	doc_491521502025_item	2570063	et	4	main
mulle	doc_491521502025_item	2570069	et	4	main
sa	doc_491521502025_item	2570071	et	3	main
mitu	doc_491521502025_item	2570074	et	4	main
päeva	doc_491521502025_item	2570075	et	4	main
sa	doc_491521502025_item	2570076	et	3	main
minu	doc_491521502025_item	2570077	et	3	main
margus	doc_491521502025_item	2570091	et	3	main
sinu	doc_491521502025_item	2570094	et	3	main
ma	doc_491521502025_item	2570103	et	3	main
läbi	doc_491521502026_item	2570114	et	4	main
tuled	doc_491521502026_item	2570131	et	4	main
kuhu	doc_491521502026_item	2570139	et	3	main
ootama	doc_491521502026_item	2570146	et	3	main
suur	doc_491521502026_item	2570154	et	3	main
juures	doc_491521502026_item	2570166	et	4	main
kümme	doc_491521502026_item	2570168	et	3	main
päeva	doc_491521502026_item	2570169	et	4	main
ma	doc_491521502026_item	2570170	et	3	main
tahan	doc_491521502026_item	2570171	et	3	main
minna	doc_491521502026_item	2570172	et	3	main
lauluväljakuse	doc_491521502026_item	2570173	et	3	main
kuulata	doc_491521502026_item	2570177	et	4	main
veel	doc_491521502026_item	2570178	et	4	main
ma	doc_491521502026_item	2570179	et	3	main
seal	doc_491521502026_item	2570183	et	4	main
kus	doc_491521502025_item	2570062	et	3	main
tere	doc_491521502025_item	2570066	et	3	main
tuled	doc_491521502025_item	2570073	et	4	main
juures	doc_491521502025_item	2570078	et	4	main
oled	doc_491521502025_item	2570079	et	3	main
ja	doc_491521502025_item	2570080	et	3	main
kuhu	doc_491521502025_item	2570081	et	3	main
sa	doc_491521502025_item	2570082	et	3	main
minna	doc_491521502025_item	2570084	et	3	main
vastust	doc_491521502025_item	2570087	et	4	main
ootama	doc_491521502025_item	2570088	et	3	main
margus	doc_491521502025_item	2570089	et	3	main
ma	doc_491521502025_item	2570092	et	3	main
kirja	doc_491521502025_item	2570095	et	4	main
ma	doc_491521502025_item	2570096	et	3	main
mõtlen	doc_491521502025_item	2570097	et	3	main
mis	doc_491521502025_item	2570098	et	4	main
ma	doc_491521502025_item	2570099	et	3	main
kiri	doc_491521502026_item	2570112	et	3	main
20-25	doc_491521502026_item	2570123	et	2	main
tere	doc_491521502026_item	2570125	et	3	main
margus	doc_491521502026_item	2570147	et	3	main
kätte	doc_491521502026_item	2570153	et	4	main
tulen	doc_491521502026_item	2570159	et	3	main
nädalal	doc_491521502026_item	2570162	et	3	main
tahan	doc_491521502026_item	2570180	et	3	main
uus	doc_491521502026_item	2570185	et	3	main
on	doc_491521502026_item	2570184	et	4	main
film	doc_491521502026_item	2570186	et	3	main
meil	doc_491521502026_item	2570187	et	4	main
kohtla-järvel	doc_491521502026_item	2570188	et	4	main
ei	doc_491521502026_item	2570189	et	4	main
ole	doc_491521502026_item	2570190	et	4	main
kinot	doc_491521502026_item	2570191	et	4	main
kõige	doc_491521502026_item	2570192	et	4	main
head	doc_491521502026_item	2570193	et	4	main
sinu	doc_491521502026_item	2570194	et	3	main
sõber	doc_491521502026_item	2570195	et	3	main
xxxxx	doc_491521502026_item	2570196	et	4	main
kiri	doc_491521502027_item	2570197	et	3	main
lugege	doc_491521502027_item	2570198	et	3	main
läbi	doc_491521502027_item	2570199	et	4	main
marguse	doc_491521502027_item	2570200	et	4	main
kiri	doc_491521502027_item	2570201	et	3	main
ja	doc_491521502027_item	2570202	et	3	main
kirjutage	doc_491521502027_item	2570203	et	3	main
talle	doc_491521502027_item	2570204	et	4	main
vastus	doc_491521502027_item	2570205	et	3	main
kus	doc_491521502027_item	2570206	et	3	main
on	doc_491521502027_item	2570207	et	4	main
20-25	doc_491521502027_item	2570208	et	2	main
sõna	doc_491521502027_item	2570209	et	4	main
tere	doc_491521502027_item	2570210	et	3	main
kirjuta	doc_491521502027_item	2570211	et	4	main
palunmulle	doc_491521502027_item	2570212	et	4	main
millal	doc_491521502027_item	2570213	et	3	main
sa	doc_491521502027_item	2570214	et	3	main
tallinnasse	doc_491521502027_item	2570215	et	3	main
tuled	doc_491521502027_item	2570216	et	4	main
mitu	doc_491521502027_item	2570217	et	4	main
päeva	doc_491521502027_item	2570218	et	4	main
sa	doc_491521502027_item	2570219	et	3	main
minu	doc_491521502027_item	2570220	et	3	main
juures	doc_491521502027_item	2570221	et	4	main
päeva	doc_491521502026_item	2570133	et	4	main
minu	doc_491521502026_item	2570135	et	3	main
juures	doc_491521502026_item	2570136	et	4	main
ja	doc_491521502026_item	2570138	et	3	main
minna	doc_491521502026_item	2570142	et	3	main
tahad	doc_491521502026_item	2570143	et	3	main
kirja	doc_491521502026_item	2570152	et	4	main
järgmisel	doc_491521502026_item	2570161	et	3	main
olen	doc_491521502026_item	2570164	et	3	main
anne	doc_491521502026_item	2570174	et	4	main
kontserdi	doc_491521502026_item	2570176	et	3	main
oled	doc_491521502027_item	2570222	et	3	main
kuhu	doc_491521502027_item	2570224	et	3	main
kätte	doc_491521502027_item	2570238	et	4	main
me	doc_491521502027_item	2570250	et	4	main
tallinnas	doc_491521502027_item	2570257	et	4	main
hea	doc_491521502027_item	2570269	et	4	main
sinule	doc_491521502027_item	2570273	et	3	main
lõpetanu	doc_491521502028_item	2570312	et	4	main
hansapangas	doc_491521502028_item	2570318	et	4	main
hea	doc_491521502028_item	2570333	et	4	main
viie	doc_491521502028_item	2570342	et	3	main
töötab	doc_491521502028_item	2570348	et	3	main
neil	doc_491521502028_item	2570351	et	4	main
on	doc_491521502028_item	2570352	et	4	main
poeg	doc_491521502028_item	2570353	et	3	main
ja	doc_491521502028_item	2570354	et	3	main
71	doc_491521502028_item	2570359	et	2	main
72	doc_491521502028_item	2570362	et	2	main
naine	doc_491521502028_item	2570364	et	3	main
35	doc_491521502028_item	2570367	et	2	main
75	doc_491521502028_item	2570371	et	2	main
vastus	doc_491521502028_item	2570382	et	3	main
ma	doc_491521502028_item	2570420	et	3	main
juures	doc_491521502028_item	2570423	et	4	main
ma	doc_491521502028_item	2570426	et	3	main
on	doc_491521502029_item	2570440	et	4	main
maarika	doc_491521502029_item	2570443	et	4	main
ja	doc_491521502029_item	2570449	et	3	main
ta	doc_491521502029_item	2570450	et	4	main
tellerina	doc_491521502029_item	2570456	et	3	main
ja	doc_491521502029_item	2570461	et	3	main
keelt	doc_491521502029_item	2570463	et	4	main
m	doc_491521502029_item	2570464	et	4	main
kask	doc_491521502029_item	2570465	et	3	main
ta	doc_491521502029_item	2570473	et	4	main
töötab	doc_491521502029_item	2570482	et	3	main
turvamehena	doc_491521502029_item	2570484	et	3	main
on	doc_491521502029_item	2570486	et	4	main
poeg	doc_491521502029_item	2570487	et	3	main
ja	doc_491521502029_item	2570488	et	3	main
tütar	doc_491521502029_item	2570489	et	3	main
sugu	doc_491521502029_item	2570497	et	4	main
vanus	doc_491521502029_item	2570500	et	4	main
sõna	doc_491521502029_item	2570523	et	4	main
ootama	doc_491521502029_item	2570546	et	3	main
margus	doc_491521502029_item	2570549	et	3	main
kiri	doc_491521502029_item	2570552	et	3	main
tallinnasse	doc_491521502029_item	2570558	et	3	main
margus	doc_491521502029_item	2570560	et	3	main
üle	doc_491521502029_item	2570570	et	3	main
teatrit	doc_491521502029_item	2570572	et	3	main
mis	doc_491521502029_item	2570574	et	4	main
lugege	doc_491521502030_item	2570583	et	3	main
täitke	doc_491521502030_item	2570586	et	3	main
on	doc_491521502030_item	2570623	et	4	main
hansapangas	doc_491521502030_item	2570632	et	4	main
turvamehena	doc_491521502030_item	2570633	et	3	main
kask	doc_491521502030_item	2570644	et	3	main
sugu	doc_491521502030_item	2570646	et	4	main
naine	doc_491521502030_item	2570647	et	3	main
vanus	doc_491521502030_item	2570649	et	4	main
abielus	doc_491521502030_item	2570654	et	4	main
marguse	doc_491521502030_item	2570661	et	4	main
kiri	doc_491521502030_item	2570662	et	3	main
ja	doc_491521502030_item	2570663	et	3	main
kirjutage	doc_491521502030_item	2570664	et	3	main
vastus	doc_491521502030_item	2570666	et	3	main
kus	doc_491521502030_item	2570667	et	3	main
mulle	doc_491521502030_item	2570674	et	4	main
ootama	doc_491521502030_item	2570693	et	3	main
margus	doc_491521502030_item	2570694	et	3	main
jään	doc_491521502027_item	2570229	et	3	main
ootama	doc_491521502027_item	2570231	et	3	main
margus	doc_491521502027_item	2570232	et	3	main
aitäh	doc_491521502027_item	2570240	et	3	main
mäleta	doc_491521502027_item	2570243	et	4	main
minust	doc_491521502027_item	2570244	et	3	main
sünnipäevast	doc_491521502027_item	2570245	et	4	main
loodan	doc_491521502027_item	2570247	et	3	main
ole	doc_491521502027_item	2570255	et	4	main
olen	doc_491521502027_item	2570262	et	3	main
mul	doc_491521502027_item	2570266	et	3	main
sõita	doc_491521502027_item	2570275	et	3	main
ma	doc_491521502027_item	2570276	et	3	main
tulen	doc_491521502027_item	2570277	et	3	main
tallinnasse	doc_491521502027_item	2570278	et	3	main
esimesel	doc_491521502027_item	2570279	et	3	main
juulil	doc_491521502027_item	2570280	et	3	main
ma	doc_491521502027_item	2570281	et	3	main
jaan	doc_491521502027_item	2570282	et	3	main
juures	doc_491521502027_item	2570283	et	4	main
kaheks	doc_491521502027_item	2570284	et	4	main
nädalaks	doc_491521502027_item	2570285	et	3	main
ma	doc_491521502027_item	2570286	et	3	main
tahaksin	doc_491521502027_item	2570287	et	3	main
jalutada	doc_491521502027_item	2570288	et	3	main
vanalinnas	doc_491521502027_item	2570289	et	4	main
ja	doc_491521502027_item	2570290	et	3	main
vaadata	doc_491521502027_item	2570291	et	4	main
filmi	doc_491521502027_item	2570292	et	4	main
kinoteatris	doc_491521502027_item	2570293	et	3	main
kõike	doc_491521502027_item	2570294	et	4	main
head	doc_491521502027_item	2570295	et	4	main
nägemiseni	doc_491521502027_item	2570296	et	4	main
xxxxxx	doc_491521502027_item	2570297	et	4	main
eksamitöö	doc_491521502028_item	2570298	et	4	main
ja	doc_491521502027_item	2570223	et	3	main
sa	doc_491521502027_item	2570225	et	3	main
tallinnas	doc_491521502027_item	2570226	et	4	main
minna	doc_491521502027_item	2570227	et	3	main
vastust	doc_491521502027_item	2570230	et	4	main
tere	doc_491521502027_item	2570233	et	3	main
margus	doc_491521502027_item	2570234	et	3	main
sain	doc_491521502027_item	2570235	et	3	main
sinu	doc_491521502027_item	2570236	et	3	main
kirja	doc_491521502027_item	2570237	et	4	main
mul	doc_491521502027_item	2570253	et	3	main
ei	doc_491521502027_item	2570254	et	4	main
sõita	doc_491521502027_item	2570258	et	3	main
ja	doc_491521502027_item	2570270	et	3	main
ma	doc_491521502027_item	2570271	et	3	main
võin	doc_491521502027_item	2570272	et	3	main
näidis	doc_491521502028_item	2570305	et	4	main
tehnikaülikooli	doc_491521502028_item	2570314	et	4	main
ja	doc_491521502028_item	2570315	et	3	main
1	doc_491521502028_item	2570299	et	2	main
lugege	doc_491521502028_item	2570300	et	3	main
informatsiooni	doc_491521502028_item	2570301	et	4	main
ja	doc_491521502028_item	2570302	et	3	main
on	doc_491521502028_item	2570306	et	4	main
ta	doc_491521502028_item	2570316	et	4	main
oskab	doc_491521502028_item	2570324	et	3	main
saksa	doc_491521502028_item	2570328	et	4	main
suhtleja	doc_491521502028_item	2570334	et	4	main
ning	doc_491521502028_item	2570335	et	3	main
ta	doc_491521502028_item	2570339	et	4	main
tarmo	doc_491521502028_item	2570346	et	4	main
kask	doc_491521502028_item	2570347	et	3	main
0	doc_491521502028_item	2570356	et	2	main
kask	doc_491521502028_item	2570361	et	3	main
ja	doc_491521502028_item	2570379	et	3	main
kirjutage	doc_491521502028_item	2570380	et	3	main
kus	doc_491521502028_item	2570383	et	3	main
õhtul	doc_491521502028_item	2570419	et	3	main
olen	doc_491521502028_item	2570421	et	3	main
päeva	doc_491521502028_item	2570425	et	4	main
tahaksin	doc_491521502028_item	2570427	et	3	main
täitke	doc_491521502029_item	2570437	et	3	main
0-ga	doc_491521502029_item	2570442	et	3	main
kask	doc_491521502029_item	2570444	et	3	main
on	doc_491521502029_item	2570451	et	4	main
maarika	doc_491521502029_item	2570457	et	4	main
tarmo	doc_491521502029_item	2570480	et	4	main
72	doc_491521502029_item	2570496	et	2	main
73	doc_491521502029_item	2570499	et	2	main
on	doc_491521502029_item	2570521	et	4	main
kirjuta	doc_491521502029_item	2570525	et	4	main
päeva	doc_491521502029_item	2570533	et	4	main
oled	doc_491521502029_item	2570537	et	3	main
kuhu	doc_491521502029_item	2570539	et	3	main
tallinnas	doc_491521502029_item	2570541	et	4	main
jään	doc_491521502029_item	2570544	et	3	main
margus	doc_491521502029_item	2570547	et	3	main
ma	doc_491521502029_item	2570550	et	3	main
ma	doc_491521502029_item	2570553	et	3	main
meeldib	doc_491521502029_item	2570569	et	3	main
maarika	doc_491521502029_item	2570580	et	4	main
eksamitöö	doc_491521502030_item	2570581	et	4	main
1	doc_491521502030_item	2570582	et	2	main
informatsiooni	doc_491521502030_item	2570584	et	4	main
ankeet	doc_491521502030_item	2570587	et	3	main
ta	doc_491521502030_item	2570622	et	4	main
tarmo	doc_491521502030_item	2570629	et	4	main
kask	doc_491521502030_item	2570630	et	3	main
töötab	doc_491521502030_item	2570631	et	3	main
poeg	doc_491521502030_item	2570636	et	3	main
75	doc_491521502030_item	2570655	et	2	main
läbi	doc_491521502030_item	2570660	et	4	main
tallinnasse	doc_491521502030_item	2570677	et	3	main
juures	doc_491521502030_item	2570683	et	4	main
oled	doc_491521502030_item	2570684	et	3	main
ma	doc_491521502030_item	2570697	et	3	main
teatrisse	doc_491521502030_item	2570715	et	3	main
kus	doc_491521502031_item	2570728	et	3	main
palun	doc_491521502031_item	2570734	et	3	main
millal	doc_491521502031_item	2570736	et	3	main
sa	doc_491521502031_item	2570737	et	3	main
oled	doc_491521502031_item	2570745	et	3	main
tallinnas	doc_491521502031_item	2570749	et	4	main
vähe	doc_491521502031_item	2570768	et	3	main
mina	doc_491521502031_item	2570771	et	4	main
haige	doc_491521502031_item	2570773	et	4	main
ma	doc_491521502031_item	2570786	et	3	main
helistan	doc_491521502031_item	2570787	et	3	main
vene	doc_491521502028_item	2570326	et	4	main
keelt	doc_491521502028_item	2570329	et	4	main
kask	doc_491521502028_item	2570331	et	3	main
kasutada	doc_491521502028_item	2570337	et	3	main
hansapangas	doc_491521502028_item	2570349	et	4	main
eesnimi	doc_491521502028_item	2570357	et	3	main
74	doc_491521502028_item	2570368	et	2	main
abielus	doc_491521502028_item	2570370	et	4	main
amet	doc_491521502028_item	2570372	et	3	main
teller	doc_491521502028_item	2570373	et	3	main
2	doc_491521502028_item	2570374	et	2	main
lugege	doc_491521502028_item	2570375	et	3	main
kiri	doc_491521502028_item	2570378	et	3	main
talle	doc_491521502028_item	2570381	et	4	main
on	doc_491521502028_item	2570384	et	4	main
20-25	doc_491521502028_item	2570385	et	2	main
sõna	doc_491521502028_item	2570386	et	4	main
tere	doc_491521502028_item	2570387	et	3	main
kirjuta	doc_491521502028_item	2570388	et	4	main
palun	doc_491521502028_item	2570389	et	3	main
mulle	doc_491521502028_item	2570390	et	4	main
millal	doc_491521502028_item	2570391	et	3	main
sa	doc_491521502028_item	2570392	et	3	main
tuled	doc_491521502028_item	2570394	et	4	main
tallinnasse	doc_491521502028_item	2570393	et	3	main
mitu	doc_491521502028_item	2570395	et	4	main
päeva	doc_491521502028_item	2570396	et	4	main
sa	doc_491521502028_item	2570397	et	3	main
minu	doc_491521502028_item	2570398	et	3	main
juures	doc_491521502028_item	2570399	et	4	main
oled	doc_491521502028_item	2570400	et	3	main
ja	doc_491521502028_item	2570401	et	3	main
kuhu	doc_491521502028_item	2570402	et	3	main
sa	doc_491521502028_item	2570403	et	3	main
tallinnas	doc_491521502028_item	2570404	et	4	main
minna	doc_491521502028_item	2570405	et	3	main
tahad	doc_491521502028_item	2570406	et	3	main
jään	doc_491521502028_item	2570407	et	3	main
vastust	doc_491521502028_item	2570408	et	4	main
ootama	doc_491521502028_item	2570409	et	3	main
margus	doc_491521502028_item	2570410	et	3	main
tere	doc_491521502028_item	2570411	et	3	main
margus	doc_491521502028_item	2570412	et	3	main
ma	doc_491521502028_item	2570413	et	3	main
tulen	doc_491521502028_item	2570414	et	3	main
maarika	doc_491521502028_item	2570323	et	4	main
ja	doc_491521502028_item	2570327	et	3	main
oskab	doc_491521502028_item	2570336	et	3	main
abikaasa	doc_491521502028_item	2570345	et	4	main
tütar	doc_491521502028_item	2570355	et	3	main
vanus	doc_491521502028_item	2570366	et	4	main
marguse	doc_491521502028_item	2570377	et	4	main
6	doc_491521502028_item	2570418	et	2	main
1	doc_491521502029_item	2570433	et	2	main
lugege	doc_491521502029_item	2570434	et	3	main
informatsiooni	doc_491521502029_item	2570435	et	4	main
ja	doc_491521502029_item	2570436	et	3	main
tallinna	doc_491521502029_item	2570447	et	4	main
töötanud	doc_491521502029_item	2570453	et	4	main
kaks	doc_491521502029_item	2570454	et	3	main
aastat	doc_491521502029_item	2570455	et	3	main
on	doc_491521502029_item	2570466	et	4	main
on	doc_491521502029_item	2570474	et	4	main
maarika	doc_491521502029_item	2570478	et	4	main
abikaasa	doc_491521502029_item	2570479	et	4	main
hansapangas	doc_491521502029_item	2570483	et	4	main
kask	doc_491521502029_item	2570495	et	3	main
20-25	doc_491521502029_item	2570522	et	2	main
tere	doc_491521502029_item	2570524	et	3	main
palun	doc_491521502029_item	2570526	et	3	main
mulle	doc_491521502029_item	2570527	et	4	main
millal	doc_491521502029_item	2570528	et	3	main
sa	doc_491521502029_item	2570529	et	3	main
tallinnasse	doc_491521502029_item	2570530	et	3	main
tuled	doc_491521502029_item	2570531	et	4	main
mitu	doc_491521502029_item	2570532	et	4	main
juures	doc_491521502029_item	2570536	et	4	main
ja	doc_491521502029_item	2570538	et	3	main
sa	doc_491521502029_item	2570540	et	3	main
minna	doc_491521502029_item	2570542	et	3	main
vastust	doc_491521502029_item	2570545	et	4	main
tere	doc_491521502029_item	2570548	et	3	main
sain	doc_491521502029_item	2570551	et	3	main
ma	doc_491521502029_item	2570561	et	3	main
olla	doc_491521502029_item	2570563	et	3	main
päeva	doc_491521502029_item	2570567	et	4	main
mulle	doc_491521502029_item	2570568	et	4	main
aga	doc_491521502029_item	2570573	et	3	main
seal	doc_491521502029_item	2570575	et	4	main
praegu	doc_491521502029_item	2570576	et	3	main
näidatakse	doc_491521502029_item	2570577	et	3	main
oota	doc_491521502029_item	2570578	et	4	main
mind	doc_491521502029_item	2570579	et	4	main
ja	doc_491521502030_item	2570585	et	3	main
on	doc_491521502030_item	2570589	et	4	main
arvutit	doc_491521502030_item	2570621	et	3	main
kolmekümne	doc_491521502030_item	2570624	et	4	main
viie	doc_491521502030_item	2570625	et	3	main
aastane	doc_491521502030_item	2570626	et	4	main
on	doc_491521502030_item	2570635	et	4	main
tütar	doc_491521502030_item	2570638	et	3	main
eesnimi	doc_491521502030_item	2570640	et	3	main
71	doc_491521502030_item	2570642	et	2	main
perkonnaseis	doc_491521502030_item	2570653	et	4	main
2	doc_491521502030_item	2570658	et	2	main
sa	doc_491521502030_item	2570676	et	3	main
päeva	doc_491521502030_item	2570680	et	4	main
ja	doc_491521502030_item	2570685	et	3	main
kuhu	doc_491521502030_item	2570686	et	3	main
sa	doc_491521502030_item	2570687	et	3	main
tallinnas	doc_491521502030_item	2570688	et	4	main
minna	doc_491521502030_item	2570689	et	3	main
tahad	doc_491521502030_item	2570690	et	3	main
jään	doc_491521502030_item	2570691	et	3	main
tulen	doc_491521502030_item	2570698	et	3	main
pärast	doc_491521502030_item	2570701	et	4	main
4	doc_491521502030_item	2570704	et	2	main
olen	doc_491521502030_item	2570707	et	3	main
estonia	doc_491521502030_item	2570716	et	4	main
marguse	doc_491521502031_item	2570722	et	4	main
kirjutage	doc_491521502031_item	2570725	et	3	main
talle	doc_491521502031_item	2570726	et	4	main
kuhu	doc_491521502031_item	2570747	et	3	main
jään	doc_491521502031_item	2570752	et	3	main
ootama	doc_491521502031_item	2570754	et	3	main
ja	doc_491521502031_item	2570766	et	3	main
veel	doc_491521502031_item	2570770	et	4	main
laupäeval	doc_491521502028_item	2570416	et	3	main
sinu	doc_491521502028_item	2570422	et	3	main
nägemiseni	doc_491521502028_item	2570430	et	4	main
eksamitöö	doc_491521502029_item	2570432	et	4	main
näidis	doc_491521502029_item	2570439	et	4	main
tehnikaülikooli	doc_491521502029_item	2570448	et	4	main
eesti	doc_491521502029_item	2570459	et	4	main
hea	doc_491521502029_item	2570467	et	4	main
suhtleja	doc_491521502029_item	2570468	et	4	main
ning	doc_491521502029_item	2570469	et	3	main
oskab	doc_491521502029_item	2570470	et	3	main
kasutada	doc_491521502029_item	2570471	et	3	main
arvutit	doc_491521502029_item	2570472	et	3	main
viie	doc_491521502029_item	2570476	et	3	main
naine	doc_491521502029_item	2570498	et	3	main
a	doc_491521502029_item	2570502	et	4	main
74	doc_491521502029_item	2570503	et	2	main
perkonnaseis	doc_491521502029_item	2570504	et	4	main
abielus	doc_491521502029_item	2570505	et	4	main
75	doc_491521502029_item	2570506	et	2	main
amet	doc_491521502029_item	2570507	et	3	main
ta	doc_491521502029_item	2570508	et	4	main
töötab	doc_491521502029_item	2570509	et	3	main
tellerina	doc_491521502029_item	2570510	et	3	main
2	doc_491521502029_item	2570511	et	2	main
lugege	doc_491521502029_item	2570512	et	3	main
läbi	doc_491521502029_item	2570513	et	4	main
marguse	doc_491521502029_item	2570514	et	4	main
kiri	doc_491521502029_item	2570515	et	3	main
ja	doc_491521502029_item	2570516	et	3	main
kirjutage	doc_491521502029_item	2570517	et	3	main
talle	doc_491521502029_item	2570518	et	4	main
vastus	doc_491521502029_item	2570519	et	3	main
kus	doc_491521502029_item	2570520	et	3	main
sa	doc_491521502029_item	2570534	et	3	main
tahad	doc_491521502029_item	2570543	et	3	main
et	doc_491521502029_item	2570555	et	3	main
ma	doc_491521502029_item	2570556	et	3	main
tahaksin	doc_491521502029_item	2570562	et	3	main
sinu	doc_491521502029_item	2570564	et	3	main
2kaks	doc_491521502029_item	2570566	et	3	main
kõige	doc_491521502029_item	2570571	et	4	main
näidis	doc_491521502030_item	2570588	et	4	main
maarika	doc_491521502030_item	2570627	et	4	main
neil	doc_491521502030_item	2570634	et	4	main
ja	doc_491521502030_item	2570637	et	3	main
0	doc_491521502030_item	2570639	et	2	main
maarika	doc_491521502030_item	2570641	et	4	main
perekonnanimi	doc_491521502030_item	2570643	et	3	main
72	doc_491521502030_item	2570645	et	2	main
73	doc_491521502030_item	2570648	et	2	main
35	doc_491521502030_item	2570650	et	2	main
a	doc_491521502030_item	2570651	et	4	main
74	doc_491521502030_item	2570652	et	2	main
amet	doc_491521502030_item	2570656	et	3	main
sõna	doc_491521502030_item	2570670	et	4	main
tere	doc_491521502030_item	2570671	et	3	main
kirjuta	doc_491521502030_item	2570672	et	4	main
palun	doc_491521502030_item	2570673	et	3	main
tuled	doc_491521502030_item	2570678	et	4	main
vastust	doc_491521502030_item	2570692	et	4	main
tallinnasse	doc_491521502030_item	2570699	et	3	main
kell	doc_491521502030_item	2570703	et	3	main
ma	doc_491521502030_item	2570706	et	3	main
oskab	doc_491521502029_item	2570458	et	3	main
vene	doc_491521502029_item	2570460	et	4	main
saksa	doc_491521502029_item	2570462	et	4	main
kolmekümne	doc_491521502029_item	2570475	et	4	main
aastane	doc_491521502029_item	2570477	et	4	main
kask	doc_491521502029_item	2570481	et	3	main
neil	doc_491521502029_item	2570485	et	4	main
0	doc_491521502029_item	2570490	et	2	main
eesnimi	doc_491521502029_item	2570491	et	3	main
maarika	doc_491521502029_item	2570492	et	4	main
71	doc_491521502029_item	2570493	et	2	main
perekonnanimi	doc_491521502029_item	2570494	et	3	main
35	doc_491521502029_item	2570501	et	2	main
minu	doc_491521502029_item	2570535	et	3	main
arvan	doc_491521502029_item	2570554	et	3	main
tulen	doc_491521502029_item	2570557	et	3	main
ülehomme	doc_491521502029_item	2570559	et	3	main
juures	doc_491521502029_item	2570565	et	4	main
tähistatud	doc_491521502030_item	2570590	et	4	main
0-ga	doc_491521502030_item	2570591	et	3	main
maarika	doc_491521502030_item	2570592	et	4	main
kask	doc_491521502030_item	2570593	et	3	main
on	doc_491521502030_item	2570594	et	4	main
lõpetanu	doc_491521502030_item	2570595	et	4	main
tallinna	doc_491521502030_item	2570596	et	4	main
tehnikaülikooli	doc_491521502030_item	2570597	et	4	main
ja	doc_491521502030_item	2570598	et	3	main
ta	doc_491521502030_item	2570599	et	4	main
on	doc_491521502030_item	2570600	et	4	main
hansapangas	doc_491521502030_item	2570601	et	4	main
töötanud	doc_491521502030_item	2570602	et	4	main
kaks	doc_491521502030_item	2570603	et	3	main
aastat	doc_491521502030_item	2570604	et	3	main
tellerina	doc_491521502030_item	2570605	et	3	main
maarika	doc_491521502030_item	2570606	et	4	main
oskab	doc_491521502030_item	2570607	et	3	main
eesti	doc_491521502030_item	2570608	et	4	main
vene	doc_491521502030_item	2570609	et	4	main
ja	doc_491521502030_item	2570610	et	3	main
saksa	doc_491521502030_item	2570611	et	4	main
keelt	doc_491521502030_item	2570612	et	4	main
m	doc_491521502030_item	2570613	et	4	main
kask	doc_491521502030_item	2570614	et	3	main
on	doc_491521502030_item	2570615	et	4	main
hea	doc_491521502030_item	2570616	et	4	main
suhtleja	doc_491521502030_item	2570617	et	4	main
ning	doc_491521502030_item	2570618	et	3	main
oskab	doc_491521502030_item	2570619	et	3	main
kasutada	doc_491521502030_item	2570620	et	3	main
abikaasa	doc_491521502030_item	2570628	et	4	main
teller	doc_491521502030_item	2570657	et	3	main
lugege	doc_491521502030_item	2570659	et	3	main
talle	doc_491521502030_item	2570665	et	4	main
on	doc_491521502030_item	2570668	et	4	main
20-25	doc_491521502030_item	2570669	et	2	main
millal	doc_491521502030_item	2570675	et	3	main
mitu	doc_491521502030_item	2570679	et	4	main
sa	doc_491521502030_item	2570681	et	3	main
minu	doc_491521502030_item	2570682	et	3	main
margus	doc_491521502030_item	2570696	et	3	main
nädala	doc_491521502030_item	2570700	et	3	main
bussiga	doc_491521502030_item	2570702	et	3	main
maarika	doc_491521502030_item	2570718	et	4	main
kiri	doc_491521502031_item	2570719	et	3	main
lugege	doc_491521502031_item	2570720	et	3	main
läbi	doc_491521502031_item	2570721	et	4	main
kiri	doc_491521502031_item	2570723	et	3	main
ja	doc_491521502031_item	2570724	et	3	main
on	doc_491521502031_item	2570729	et	4	main
tere	doc_491521502031_item	2570732	et	3	main
sa	doc_491521502031_item	2570742	et	3	main
minu	doc_491521502031_item	2570743	et	3	main
juures	doc_491521502031_item	2570744	et	4	main
palju	doc_491521502031_item	2570764	et	4	main
aega	doc_491521502031_item	2570769	et	4	main
on	doc_491521502031_item	2570775	et	4	main
palavik	doc_491521502031_item	2570776	et	3	main
ja	doc_491521502031_item	2570777	et	3	main
homme	doc_491521502031_item	2570778	et	3	main
lähen	doc_491521502031_item	2570780	et	3	main
ma	doc_491521502031_item	2570783	et	3	main
marguse	doc_491521502033_item	2570867	et	4	main
kiri	doc_491521502033_item	2570868	et	3	main
ja	doc_491521502033_item	2570869	et	3	main
kirjutage	doc_491521502033_item	2570870	et	3	main
talle	doc_491521502033_item	2570871	et	4	main
vastus	doc_491521502033_item	2570872	et	3	main
kus	doc_491521502033_item	2570873	et	3	main
tallinnasse	doc_491521502033_item	2570883	et	3	main
tuled	doc_491521502033_item	2570884	et	4	main
kuhu	doc_491521502033_item	2570892	et	3	main
jään	doc_491521502033_item	2570897	et	3	main
ootama	doc_491521502033_item	2570899	et	3	main
tere	doc_491521502033_item	2570901	et	3	main
tulen	doc_491521502033_item	2570904	et	3	main
ma	doc_491521502033_item	2570907	et	3	main
sinu	doc_491521502033_item	2570909	et	3	main
kolma	doc_491521502033_item	2570911	et	4	main
päeva	doc_491521502033_item	2570912	et	4	main
ma	doc_491521502033_item	2570913	et	3	main
kontserdi	doc_491521502033_item	2570923	et	3	main
kell	doc_491521502033_item	2570930	et	3	main
head	doc_491521502033_item	2570932	et	4	main
kirjuta	doc_491521502034_item	2570948	et	4	main
palun	doc_491521502034_item	2570949	et	3	main
millal	doc_491521502034_item	2570951	et	3	main
mitu	doc_491521502034_item	2570955	et	4	main
tere	doc_491521502034_item	2570971	et	3	main
ma	doc_491521502034_item	2570979	et	3	main
kontserdile	doc_491521502034_item	2570990	et	3	main
kallis	doc_491521502030_item	2570695	et	4	main
õhtu	doc_491521502030_item	2570705	et	4	main
sinu	doc_491521502030_item	2570708	et	3	main
20-25	doc_491521502031_item	2570730	et	2	main
mitu	doc_491521502031_item	2570740	et	4	main
päeva	doc_491521502031_item	2570741	et	4	main
sa	doc_491521502031_item	2570748	et	3	main
minna	doc_491521502031_item	2570750	et	3	main
margus	doc_491521502031_item	2570755	et	3	main
tere	doc_491521502031_item	2570756	et	3	main
margus	doc_491521502031_item	2570757	et	3	main
vabandage	doc_491521502031_item	2570758	et	3	main
palun	doc_491521502031_item	2570759	et	3	main
praegu	doc_491521502031_item	2570760	et	3	main
mul	doc_491521502031_item	2570761	et	3	main
on	doc_491521502031_item	2570762	et	4	main
nii	doc_491521502031_item	2570763	et	3	main
väga	doc_491521502031_item	2570767	et	3	main
praegu	doc_491521502031_item	2570772	et	3	main
mul	doc_491521502031_item	2570774	et	3	main
terve	doc_491521502031_item	2570785	et	4	main
eesnimi	doc_491521502031_item	2570791	et	3	main
mulle	doc_491521502033_item	2570880	et	4	main
millal	doc_491521502033_item	2570881	et	3	main
sa	doc_491521502033_item	2570882	et	3	main
ja	doc_491521502033_item	2570891	et	3	main
tahad	doc_491521502033_item	2570896	et	3	main
vastust	doc_491521502033_item	2570898	et	4	main
margus	doc_491521502033_item	2570902	et	3	main
juures	doc_491521502033_item	2570910	et	4	main
tahan	doc_491521502033_item	2570914	et	3	main
vanalinnasse	doc_491521502033_item	2570918	et	4	main
ma	doc_491521502033_item	2570920	et	3	main
tahan	doc_491521502033_item	2570921	et	3	main
aega	doc_491521502033_item	2570933	et	4	main
mulle	doc_491521502034_item	2570950	et	4	main
tuled	doc_491521502034_item	2570954	et	4	main
päeva	doc_491521502034_item	2570956	et	4	main
sa	doc_491521502034_item	2570957	et	3	main
minu	doc_491521502034_item	2570958	et	3	main
juures	doc_491521502034_item	2570959	et	4	main
oled	doc_491521502034_item	2570960	et	3	main
ja	doc_491521502034_item	2570961	et	3	main
kuhu	doc_491521502034_item	2570962	et	3	main
sa	doc_491521502034_item	2570963	et	3	main
tallinnas	doc_491521502034_item	2570964	et	4	main
minna	doc_491521502034_item	2570965	et	3	main
tahad	doc_491521502034_item	2570966	et	3	main
jään	doc_491521502034_item	2570967	et	3	main
ma	doc_491521502034_item	2570973	et	3	main
õhtul	doc_491521502034_item	2570978	et	3	main
jalutada	doc_491521502034_item	2570991	et	3	main
vastus	doc_491521502036_item	2571079	et	3	main
kus	doc_491521502036_item	2571080	et	3	main
on	doc_491521502036_item	2571081	et	4	main
sa	doc_491521502036_item	2571089	et	3	main
sa	doc_491521502036_item	2571094	et	3	main
juures	doc_491521502036_item	2571096	et	4	main
ja	doc_491521502036_item	2571098	et	3	main
sa	doc_491521502036_item	2571100	et	3	main
tahad	doc_491521502036_item	2571103	et	3	main
hea	doc_491521502036_item	2571112	et	4	main
sa	doc_491521502036_item	2571115	et	3	main
augusti	doc_491521502036_item	2571124	et	3	main
või	doc_491521502036_item	2571128	et	4	main
26-ndal	doc_491521502036_item	2571129	et	4	main
ja	doc_491521502036_item	2571130	et	3	main
jään	doc_491521502036_item	2571131	et	3	main
sinu	doc_491521502036_item	2571132	et	3	main
juures	doc_491521502036_item	2571133	et	4	main
ma	doc_491521502036_item	2571137	et	3	main
juures	doc_491521502030_item	2570709	et	4	main
kolm	doc_491521502030_item	2570710	et	3	main
päeva	doc_491521502030_item	2570711	et	4	main
ma	doc_491521502030_item	2570712	et	3	main
tahan	doc_491521502030_item	2570713	et	3	main
minna	doc_491521502030_item	2570714	et	3	main
kohtumiseni	doc_491521502030_item	2570717	et	4	main
vastus	doc_491521502031_item	2570727	et	3	main
sõna	doc_491521502031_item	2570731	et	4	main
kirjuta	doc_491521502031_item	2570733	et	4	main
mulle	doc_491521502031_item	2570735	et	4	main
tallinnasse	doc_491521502031_item	2570738	et	3	main
tuled	doc_491521502031_item	2570739	et	4	main
ja	doc_491521502031_item	2570746	et	3	main
tahad	doc_491521502031_item	2570751	et	3	main
vastust	doc_491521502031_item	2570753	et	4	main
töö	doc_491521502031_item	2570765	et	4	main
ma	doc_491521502031_item	2570779	et	3	main
haiglasse	doc_491521502031_item	2570781	et	4	main
kui	doc_491521502031_item	2570782	et	3	main
head	doc_491521502031_item	2570789	et	4	main
olen	doc_491521502031_item	2570784	et	3	main
sulle	doc_491521502031_item	2570788	et	3	main
aega	doc_491521502031_item	2570790	et	4	main
lugege	doc_491521502033_item	2570865	et	3	main
läbi	doc_491521502033_item	2570866	et	4	main
tere	doc_491521502033_item	2570877	et	3	main
kirjuta	doc_491521502033_item	2570878	et	4	main
palun	doc_491521502033_item	2570879	et	3	main
tallinnasse	doc_491521502033_item	2570905	et	3	main
tellida	doc_491521502033_item	2570925	et	3	main
piletit	doc_491521502033_item	2570926	et	3	main
sõida	doc_491521502033_item	2570928	et	4	main
läbi	doc_491521502034_item	2570936	et	4	main
marguse	doc_491521502034_item	2570937	et	4	main
ja	doc_491521502034_item	2570939	et	3	main
talle	doc_491521502034_item	2570941	et	4	main
vastus	doc_491521502034_item	2570942	et	3	main
kus	doc_491521502034_item	2570943	et	3	main
on	doc_491521502034_item	2570944	et	4	main
20-25	doc_491521502034_item	2570945	et	2	main
sa	doc_491521502034_item	2570952	et	3	main
vastust	doc_491521502034_item	2570968	et	4	main
margus	doc_491521502034_item	2570970	et	3	main
tulen	doc_491521502034_item	2570974	et	3	main
kümnendal	doc_491521502034_item	2570976	et	3	main
olen	doc_491521502034_item	2570980	et	3	main
päeva	doc_491521502034_item	2570984	et	4	main
ma	doc_491521502034_item	2570985	et	3	main
tahan	doc_491521502034_item	2570986	et	3	main
loomaaeda	doc_491521502034_item	2570988	et	4	main
on	doc_491521502033_item	2570874	et	4	main
20-25	doc_491521502033_item	2570875	et	2	main
mitu	doc_491521502033_item	2570885	et	4	main
sa	doc_491521502033_item	2570893	et	3	main
minna	doc_491521502033_item	2570895	et	3	main
margus	doc_491521502033_item	2570900	et	3	main
ma	doc_491521502033_item	2570903	et	3	main
minna	doc_491521502033_item	2570915	et	3	main
kaubamajasse	doc_491521502033_item	2570917	et	3	main
veel	doc_491521502033_item	2570919	et	4	main
külastada	doc_491521502033_item	2570922	et	3	main
ma	doc_491521502033_item	2570927	et	3	main
laupäeval	doc_491521502033_item	2570929	et	3	main
20	doc_491521502033_item	2570931	et	2	main
lugege	doc_491521502034_item	2570935	et	3	main
margus	doc_491521502034_item	2570972	et	3	main
tallinnasse	doc_491521502034_item	2570975	et	3	main
oktoobril	doc_491521502034_item	2570977	et	3	main
juures	doc_491521502034_item	2570982	et	4	main
kinno	doc_491521502034_item	2570989	et	3	main
marguse	doc_491521502036_item	2571074	et	4	main
mulle	doc_491521502036_item	2571087	et	4	main
tuled	doc_491521502036_item	2571091	et	4	main
oli	doc_491521502036_item	2571111	et	3	main
et	doc_491521502036_item	2571114	et	3	main
tallinnasse	doc_491521502036_item	2571123	et	3	main
tahan	doc_491521502036_item	2571138	et	3	main
teatrisse	doc_491521502036_item	2571146	et	3	main
head	doc_491521502036_item	2571148	et	4	main
sulle	doc_491521502036_item	2571149	et	3	main
eesnimi	doc_491521502036_item	2571150	et	3	main
kiri	doc_491521502037_item	2571151	et	3	main
kiri	doc_491521502037_item	2571155	et	3	main
ja	doc_491521502037_item	2571156	et	3	main
kus	doc_491521502037_item	2571160	et	3	main
20-25	doc_491521502037_item	2571162	et	2	main
sõna	doc_491521502037_item	2571163	et	4	main
tere	doc_491521502037_item	2571164	et	3	main
päeva	doc_491521502037_item	2571173	et	4	main
minu	doc_491521502037_item	2571175	et	3	main
oled	doc_491521502037_item	2571177	et	3	main
sa	doc_491521502037_item	2571180	et	3	main
ma	doc_491521502037_item	2571188	et	3	main
tallinnas	doc_491521502037_item	2571194	et	4	main
päeva	doc_491521502038_item	2571232	et	4	main
sa	doc_491521502038_item	2571233	et	3	main
minu	doc_491521502038_item	2571234	et	3	main
juures	doc_491521502038_item	2571235	et	4	main
vastust	doc_491521502038_item	2571244	et	4	main
sinu	doc_491521502038_item	2571256	et	3	main
loomaajja	doc_491521502038_item	2571267	et	4	main
tulan	doc_491521502038_item	2571270	et	4	main
mind	doc_491521502038_item	2571272	et	4	main
talle	doc_491521502039_item	2571280	et	4	main
sõna	doc_491521502039_item	2571285	et	4	main
palun	doc_491521502039_item	2571288	et	3	main
mulle	doc_491521502039_item	2571289	et	4	main
millal	doc_491521502039_item	2571290	et	3	main
sa	doc_491521502039_item	2571291	et	3	main
tallinnasse	doc_491521502039_item	2571292	et	3	main
tallinnas	doc_491521502039_item	2571303	et	4	main
minna	doc_491521502039_item	2571304	et	3	main
tahad	doc_491521502039_item	2571305	et	3	main
vastust	doc_491521502039_item	2571307	et	4	main
ootama	doc_491521502039_item	2571308	et	3	main
margus	doc_491521502039_item	2571309	et	3	main
tere	doc_491521502039_item	2571310	et	3	main
ma	doc_491521502039_item	2571311	et	3	main
pühapäeval	doc_491521502039_item	2571314	et	3	main
nädala	doc_491521502039_item	2571319	et	3	main
ma	doc_491521502039_item	2571320	et	3	main
botaanikaaed	doc_491521502039_item	2571325	et	3	main
kiri	doc_491521502033_item	2570864	et	3	main
sõna	doc_491521502033_item	2570876	et	4	main
päeva	doc_491521502033_item	2570886	et	4	main
sa	doc_491521502033_item	2570887	et	3	main
minu	doc_491521502033_item	2570888	et	3	main
juures	doc_491521502033_item	2570889	et	4	main
oled	doc_491521502033_item	2570890	et	3	main
tallinnas	doc_491521502033_item	2570894	et	4	main
laupäeval	doc_491521502033_item	2570906	et	3	main
olen	doc_491521502033_item	2570908	et	3	main
tallinnas	doc_491521502033_item	2570916	et	4	main
palun	doc_491521502033_item	2570924	et	3	main
kiri	doc_491521502034_item	2570934	et	3	main
kiri	doc_491521502034_item	2570938	et	3	main
kirjutage	doc_491521502034_item	2570940	et	3	main
sõna	doc_491521502034_item	2570946	et	4	main
tere	doc_491521502034_item	2570947	et	3	main
tallinnasse	doc_491521502034_item	2570953	et	3	main
ootama	doc_491521502034_item	2570969	et	3	main
sinu	doc_491521502034_item	2570981	et	3	main
kolm	doc_491521502034_item	2570983	et	3	main
minna	doc_491521502034_item	2570987	et	3	main
vana	doc_491521502034_item	2570992	et	4	main
eesnimi	doc_491521502034_item	2570994	et	3	main
linnas	doc_491521502034_item	2570993	et	4	main
ja	doc_491521502036_item	2571076	et	3	main
kirjutage	doc_491521502036_item	2571077	et	3	main
millal	doc_491521502036_item	2571088	et	3	main
minu	doc_491521502036_item	2571095	et	3	main
kiri	doc_491521502036_item	2571071	et	3	main
lugege	doc_491521502036_item	2571072	et	3	main
läbi	doc_491521502036_item	2571073	et	4	main
kiri	doc_491521502036_item	2571075	et	3	main
talle	doc_491521502036_item	2571078	et	4	main
20-25	doc_491521502036_item	2571082	et	2	main
sõna	doc_491521502036_item	2571083	et	4	main
tere	doc_491521502036_item	2571084	et	3	main
tallinnasse	doc_491521502036_item	2571090	et	3	main
mitu	doc_491521502036_item	2571092	et	4	main
kuhu	doc_491521502036_item	2571099	et	3	main
tallinnas	doc_491521502036_item	2571101	et	4	main
jään	doc_491521502036_item	2571104	et	3	main
tere	doc_491521502036_item	2571108	et	3	main
margus	doc_491521502036_item	2571109	et	3	main
saan	doc_491521502036_item	2571121	et	4	main
25	doc_491521502036_item	2571127	et	2	main
tallinnas	doc_491521502036_item	2571136	et	4	main
näha	doc_491521502036_item	2571139	et	3	main
marguse	doc_491521502037_item	2571154	et	4	main
kirjuta	doc_491521502037_item	2571165	et	4	main
palun	doc_491521502037_item	2571166	et	3	main
mitu	doc_491521502037_item	2571172	et	4	main
sa	doc_491521502037_item	2571174	et	3	main
juures	doc_491521502037_item	2571176	et	4	main
kuhu	doc_491521502037_item	2571179	et	3	main
margus	doc_491521502037_item	2571187	et	3	main
looamaega	doc_491521502037_item	2571190	et	4	main
ma	doc_491521502037_item	2571192	et	3	main
sõna	doc_491521502038_item	2571222	et	4	main
sa	doc_491521502038_item	2571228	et	3	main
tallinnasse	doc_491521502038_item	2571229	et	3	main
tuled	doc_491521502038_item	2571230	et	4	main
ja	doc_491521502038_item	2571237	et	3	main
minna	doc_491521502038_item	2571241	et	3	main
kirjutan	doc_491521502038_item	2571248	et	3	main
talle	doc_491521502038_item	2571249	et	4	main
tallinnasse	doc_491521502038_item	2571251	et	3	main
tulen	doc_491521502038_item	2571252	et	3	main
varsti	doc_491521502038_item	2571253	et	3	main
vana	doc_491521502038_item	2571265	et	4	main
linna	doc_491521502038_item	2571266	et	4	main
oota	doc_491521502038_item	2571271	et	4	main
läbi	doc_491521502039_item	2571275	et	4	main
kiri	doc_491521502039_item	2571277	et	3	main
ja	doc_491521502039_item	2571278	et	3	main
jään	doc_491521502039_item	2571306	et	3	main
tulen	doc_491521502039_item	2571312	et	3	main
ma	doc_491521502039_item	2571315	et	3	main
tahan	doc_491521502039_item	2571321	et	3	main
tallinnas	doc_491521502039_item	2571323	et	4	main
vana	doc_491521502039_item	2571326	et	4	main
kiri	doc_491521502040_item	2571336	et	3	main
mulle	doc_491521502040_item	2571348	et	4	main
millal	doc_491521502040_item	2571349	et	3	main
tallinnas	doc_491521502040_item	2571362	et	4	main
minna	doc_491521502040_item	2571363	et	3	main
tahad	doc_491521502040_item	2571364	et	3	main
tallinnas	doc_491521502040_item	2571401	et	4	main
tahan	doc_491521502040_item	2571403	et	3	main
kiri	doc_491521502041_item	2571415	et	3	main
talle	doc_491521502041_item	2571418	et	4	main
vastus	doc_491521502041_item	2571419	et	3	main
kus	doc_491521502041_item	2571420	et	3	main
kirjuta	doc_491521502041_item	2571425	et	4	main
sa	doc_491521502041_item	2571429	et	3	main
sa	doc_491521502041_item	2571440	et	3	main
aga	doc_491521502041_item	2571452	et	3	main
pean	doc_491521502041_item	2571465	et	4	main
sõidemist	doc_491521502041_item	2571467	et	4	main
teveks	doc_491521502041_item	2571468	et	4	main
olen	doc_491521502041_item	2571476	et	3	main
kirjuta	doc_491521502036_item	2571085	et	4	main
palun	doc_491521502036_item	2571086	et	3	main
päeva	doc_491521502036_item	2571093	et	4	main
oled	doc_491521502036_item	2571097	et	3	main
mulle	doc_491521502036_item	2571117	et	4	main
ma	doc_491521502036_item	2571118	et	3	main
loodan	doc_491521502036_item	2571119	et	3	main
et	doc_491521502036_item	2571120	et	3	main
lõpul	doc_491521502036_item	2571125	et	3	main
umbes	doc_491521502036_item	2571126	et	4	main
paariks	doc_491521502036_item	2571134	et	4	main
nevski	doc_491521502036_item	2571141	et	4	main
tahan	doc_491521502036_item	2571144	et	3	main
kõike	doc_491521502036_item	2571147	et	4	main
talle	doc_491521502037_item	2571158	et	4	main
on	doc_491521502037_item	2571161	et	4	main
tuled	doc_491521502037_item	2571171	et	4	main
ootama	doc_491521502037_item	2571186	et	3	main
tulen	doc_491521502037_item	2571189	et	3	main
tallinnasse	doc_491521502037_item	2571191	et	3	main
20-25	doc_491521502038_item	2571221	et	2	main
palun	doc_491521502038_item	2571225	et	3	main
mulle	doc_491521502038_item	2571226	et	4	main
millal	doc_491521502038_item	2571227	et	3	main
oled	doc_491521502038_item	2571236	et	3	main
jään	doc_491521502038_item	2571243	et	3	main
margus	doc_491521502038_item	2571246	et	3	main
juures	doc_491521502038_item	2571257	et	4	main
kaks	doc_491521502038_item	2571258	et	3	main
muuseumisse	doc_491521502038_item	2571264	et	3	main
pargi	doc_491521502038_item	2571268	et	4	main
lugege	doc_491521502039_item	2571274	et	3	main
kus	doc_491521502039_item	2571282	et	3	main
tuled	doc_491521502039_item	2571293	et	4	main
üks	doc_491521502039_item	2571318	et	3	main
minna	doc_491521502036_item	2571102	et	3	main
vastust	doc_491521502036_item	2571105	et	4	main
ootama	doc_491521502036_item	2571106	et	3	main
margus	doc_491521502036_item	2571107	et	3	main
mul	doc_491521502036_item	2571110	et	3	main
meel	doc_491521502036_item	2571113	et	4	main
kirjutasid	doc_491521502036_item	2571116	et	4	main
tulla	doc_491521502036_item	2571122	et	3	main
päevaks	doc_491521502036_item	2571135	et	3	main
minna	doc_491521502036_item	2571145	et	3	main
lugege	doc_491521502037_item	2571152	et	3	main
mulle	doc_491521502037_item	2571167	et	4	main
tallinnasse	doc_491521502037_item	2571170	et	3	main
ja	doc_491521502037_item	2571178	et	3	main
tallinnas	doc_491521502037_item	2571181	et	4	main
minna	doc_491521502037_item	2571182	et	3	main
tahad	doc_491521502037_item	2571183	et	3	main
jään	doc_491521502037_item	2571184	et	3	main
olen	doc_491521502037_item	2571193	et	3	main
korda	doc_491521502037_item	2571196	et	4	main
suvel	doc_491521502037_item	2571197	et	3	main
ja	doc_491521502037_item	2571198	et	3	main
sügus	doc_491521502037_item	2571199	et	4	main
ma	doc_491521502037_item	2571200	et	3	main
sõidan	doc_491521502037_item	2571201	et	3	main
kevadel	doc_491521502037_item	2571203	et	4	main
haiglas	doc_491521502037_item	2571202	et	3	main
ma	doc_491521502037_item	2571204	et	3	main
sõidsin	doc_491521502037_item	2571205	et	4	main
isale	doc_491521502037_item	2571206	et	3	main
ta	doc_491521502037_item	2571207	et	4	main
selle	doc_491521502037_item	2571208	et	4	main
elab	doc_491521502037_item	2571209	et	3	main
kiri	doc_491521502038_item	2571210	et	3	main
lugege	doc_491521502038_item	2571211	et	3	main
läbi	doc_491521502038_item	2571212	et	4	main
marguse	doc_491521502038_item	2571213	et	4	main
kiri	doc_491521502038_item	2571214	et	3	main
ja	doc_491521502038_item	2571215	et	3	main
kirjutage	doc_491521502038_item	2571216	et	3	main
talle	doc_491521502038_item	2571217	et	4	main
vastus	doc_491521502038_item	2571218	et	3	main
kus	doc_491521502038_item	2571219	et	3	main
on	doc_491521502038_item	2571220	et	4	main
aleksandri	doc_491521502036_item	2571140	et	4	main
katedrali	doc_491521502036_item	2571142	et	4	main
ja	doc_491521502036_item	2571143	et	3	main
läbi	doc_491521502037_item	2571153	et	4	main
kirjutage	doc_491521502037_item	2571157	et	3	main
vastus	doc_491521502037_item	2571159	et	3	main
millal	doc_491521502037_item	2571168	et	3	main
sa	doc_491521502037_item	2571169	et	3	main
vastust	doc_491521502037_item	2571185	et	4	main
kaks	doc_491521502037_item	2571195	et	3	main
mitu	doc_491521502038_item	2571231	et	4	main
kuhu	doc_491521502038_item	2571238	et	3	main
tahad	doc_491521502038_item	2571242	et	3	main
vastust	doc_491521502038_item	2571250	et	4	main
ma	doc_491521502038_item	2571254	et	3	main
päeva	doc_491521502038_item	2571259	et	4	main
tallinnas	doc_491521502038_item	2571260	et	4	main
ma	doc_491521502038_item	2571261	et	3	main
tahan	doc_491521502038_item	2571262	et	3	main
minna	doc_491521502038_item	2571263	et	3	main
varsti	doc_491521502038_item	2571269	et	3	main
kiri	doc_491521502039_item	2571273	et	3	main
marguse	doc_491521502039_item	2571276	et	4	main
kirjutage	doc_491521502039_item	2571279	et	3	main
20-25	doc_491521502039_item	2571284	et	2	main
tere	doc_491521502039_item	2571286	et	3	main
kirjuta	doc_491521502039_item	2571287	et	4	main
tallinnasse	doc_491521502039_item	2571313	et	3	main
olen	doc_491521502039_item	2571316	et	3	main
vaatama	doc_491521502039_item	2571322	et	3	main
jargmiseni	doc_491521502039_item	2571331	et	4	main
marguse	doc_491521502040_item	2571335	et	4	main
ja	doc_491521502040_item	2571337	et	3	main
talle	doc_491521502040_item	2571339	et	4	main
20-25	doc_491521502040_item	2571343	et	2	main
sõna	doc_491521502040_item	2571344	et	4	main
tere	doc_491521502040_item	2571345	et	3	main
kirjuta	doc_491521502040_item	2571346	et	4	main
palun	doc_491521502040_item	2571347	et	3	main
raekoja	doc_491521502040_item	2571406	et	3	main
kiri	doc_491521502041_item	2571411	et	3	main
on	doc_491521502041_item	2571421	et	4	main
palun	doc_491521502041_item	2571426	et	3	main
tuled	doc_491521502041_item	2571431	et	4	main
minna	doc_491521502041_item	2571442	et	3	main
tahad	doc_491521502041_item	2571443	et	3	main
jään	doc_491521502041_item	2571444	et	3	main
vastust	doc_491521502041_item	2571445	et	4	main
ootama	doc_491521502041_item	2571446	et	3	main
margus	doc_491521502041_item	2571447	et	3	main
tere	doc_491521502041_item	2571448	et	3	main
margus	doc_491521502041_item	2571449	et	3	main
vabanda	doc_491521502041_item	2571450	et	4	main
tallinnasse	doc_491521502041_item	2571460	et	3	main
enne	doc_491521502041_item	2571466	et	4	main
saada	doc_491521502041_item	2571469	et	4	main
ma	doc_491521502041_item	2571470	et	3	main
helistan	doc_491521502041_item	2571471	et	3	main
või	doc_491521502041_item	2571472	et	4	main
kiri	doc_491521502043_item	2571578	et	3	main
talle	doc_491521502043_item	2571581	et	4	main
sa	doc_491521502043_item	2571592	et	3	main
ootama	doc_491521502043_item	2571609	et	3	main
margus	doc_491521502043_item	2571610	et	3	main
tere	doc_491521502043_item	2571611	et	3	main
margus	doc_491521502043_item	2571612	et	3	main
kätte	doc_491521502043_item	2571616	et	4	main
ma	doc_491521502043_item	2571621	et	3	main
tallinnasse	doc_491521502043_item	2571623	et	3	main
tere	doc_491521502038_item	2571223	et	3	main
kirjuta	doc_491521502038_item	2571224	et	4	main
sa	doc_491521502038_item	2571239	et	3	main
tallinnas	doc_491521502038_item	2571240	et	4	main
ootama	doc_491521502038_item	2571245	et	3	main
tere	doc_491521502038_item	2571247	et	3	main
olen	doc_491521502038_item	2571255	et	3	main
vastus	doc_491521502039_item	2571281	et	3	main
on	doc_491521502039_item	2571283	et	4	main
mitu	doc_491521502039_item	2571294	et	4	main
päeva	doc_491521502039_item	2571295	et	4	main
sa	doc_491521502039_item	2571296	et	3	main
minu	doc_491521502039_item	2571297	et	3	main
juures	doc_491521502039_item	2571298	et	4	main
oled	doc_491521502039_item	2571299	et	3	main
ja	doc_491521502039_item	2571300	et	3	main
kuhu	doc_491521502039_item	2571301	et	3	main
sa	doc_491521502039_item	2571302	et	3	main
seal	doc_491521502039_item	2571317	et	4	main
loomaaed	doc_491521502039_item	2571324	et	3	main
muuseumid	doc_491521502039_item	2571329	et	3	main
näited	doc_491521502039_item	2571330	et	3	main
kiri	doc_491521502040_item	2571332	et	3	main
läbi	doc_491521502040_item	2571334	et	4	main
kirjutage	doc_491521502040_item	2571338	et	3	main
vastus	doc_491521502040_item	2571340	et	3	main
on	doc_491521502040_item	2571342	et	4	main
päeva	doc_491521502040_item	2571354	et	4	main
sa	doc_491521502040_item	2571355	et	3	main
minu	doc_491521502040_item	2571356	et	3	main
juures	doc_491521502040_item	2571357	et	4	main
oled	doc_491521502040_item	2571358	et	3	main
ja	doc_491521502040_item	2571359	et	3	main
kuhu	doc_491521502040_item	2571360	et	3	main
sa	doc_491521502040_item	2571361	et	3	main
selle	doc_491521502040_item	2571391	et	4	main
sinu	doc_491521502040_item	2571395	et	3	main
ma	doc_491521502040_item	2571402	et	3	main
minna	doc_491521502040_item	2571404	et	3	main
näitusele	doc_491521502040_item	2571405	et	4	main
kohtumiseni	doc_491521502040_item	2571410	et	4	main
läbi	doc_491521502041_item	2571413	et	4	main
marguse	doc_491521502041_item	2571414	et	4	main
ja	doc_491521502041_item	2571416	et	3	main
tere	doc_491521502041_item	2571424	et	3	main
millal	doc_491521502041_item	2571428	et	3	main
mitu	doc_491521502041_item	2571432	et	4	main
päeva	doc_491521502041_item	2571433	et	4	main
sa	doc_491521502041_item	2571434	et	3	main
minu	doc_491521502041_item	2571435	et	3	main
ma	doc_491521502041_item	2571454	et	3	main
sellel	doc_491521502041_item	2571458	et	4	main
nädalavahetusel	doc_491521502041_item	2571459	et	4	main
grippi	doc_491521502041_item	2571463	et	4	main
kirjutan	doc_491521502041_item	2571473	et	3	main
eesnimi	doc_491521502041_item	2571480	et	3	main
linna	doc_491521502039_item	2571327	et	4	main
kus	doc_491521502040_item	2571341	et	3	main
sa	doc_491521502040_item	2571350	et	3	main
tuled	doc_491521502040_item	2571352	et	4	main
mitu	doc_491521502040_item	2571353	et	4	main
jään	doc_491521502040_item	2571365	et	3	main
margus	doc_491521502040_item	2571368	et	3	main
tere	doc_491521502040_item	2571369	et	3	main
minu	doc_491521502040_item	2571370	et	3	main
puhkas	doc_491521502040_item	2571371	et	3	main
algab	doc_491521502040_item	2571372	et	3	main
suvel	doc_491521502040_item	2571373	et	3	main
kui	doc_491521502040_item	2571374	et	3	main
ilm	doc_491521502040_item	2571375	et	3	main
on	doc_491521502040_item	2571376	et	4	main
hästi	doc_491521502040_item	2571377	et	3	main
ma	doc_491521502040_item	2571378	et	3	main
sinu	doc_491521502040_item	2571379	et	3	main
juurde	doc_491521502040_item	2571380	et	4	main
tulen	doc_491521502040_item	2571381	et	3	main
lähen	doc_491521502040_item	2571382	et	3	main
ma	doc_491521502040_item	2571383	et	3	main
sõidan	doc_491521502040_item	2571384	et	3	main
bussiga	doc_491521502040_item	2571385	et	3	main
mul	doc_491521502040_item	2571386	et	3	main
on	doc_491521502040_item	2571387	et	4	main
praegu	doc_491521502040_item	2571388	et	3	main
palju	doc_491521502040_item	2571389	et	4	main
raha	doc_491521502040_item	2571390	et	4	main
erinevad	doc_491521502039_item	2571328	et	4	main
lugege	doc_491521502040_item	2571333	et	3	main
tallinnasse	doc_491521502040_item	2571351	et	3	main
vastust	doc_491521502040_item	2571366	et	4	main
ootama	doc_491521502040_item	2571367	et	3	main
palju	doc_491521502040_item	2571393	et	4	main
juures	doc_491521502040_item	2571396	et	4	main
ma	doc_491521502040_item	2571397	et	3	main
olen	doc_491521502040_item	2571398	et	3	main
lähen	doc_491521502040_item	2571399	et	3	main
juuniks	doc_491521502040_item	2571400	et	3	main
restoranisse	doc_491521502040_item	2571409	et	3	main
lugege	doc_491521502041_item	2571412	et	3	main
kirjutage	doc_491521502041_item	2571417	et	3	main
pärast	doc_491521502040_item	2571392	et	4	main
plaanid	doc_491521502040_item	2571394	et	4	main
platsile	doc_491521502040_item	2571407	et	4	main
poodi	doc_491521502040_item	2571408	et	4	main
20-25	doc_491521502041_item	2571422	et	2	main
juures	doc_491521502041_item	2571436	et	4	main
oled	doc_491521502041_item	2571437	et	3	main
ja	doc_491521502041_item	2571438	et	3	main
kuhu	doc_491521502041_item	2571439	et	3	main
tallinnas	doc_491521502041_item	2571441	et	4	main
kahjuks	doc_491521502041_item	2571453	et	4	main
ei	doc_491521502041_item	2571455	et	4	main
tulla	doc_491521502041_item	2571457	et	3	main
sain	doc_491521502041_item	2571462	et	3	main
sulle	doc_491521502041_item	2571474	et	3	main
valmis	doc_491521502041_item	2571477	et	4	main
tervitades	doc_491521502041_item	2571479	et	3	main
ja	doc_491521502043_item	2571579	et	3	main
kirjutage	doc_491521502043_item	2571580	et	3	main
on	doc_491521502043_item	2571584	et	4	main
sõna	doc_491521502043_item	2571586	et	4	main
tere	doc_491521502043_item	2571587	et	3	main
kirjuta	doc_491521502043_item	2571588	et	4	main
palun	doc_491521502043_item	2571589	et	3	main
mitu	doc_491521502043_item	2571595	et	4	main
ja	doc_491521502043_item	2571601	et	3	main
ja	doc_491521502043_item	2571617	et	3	main
minna	doc_491521502043_item	2571636	et	3	main
koju	doc_491521502043_item	2571643	et	3	main
kiri	doc_491521502044_item	2571653	et	3	main
kirjutage	doc_491521502044_item	2571655	et	3	main
vastus	doc_491521502044_item	2571657	et	3	main
sõna	doc_491521502044_item	2571661	et	4	main
palun	doc_491521502044_item	2571664	et	3	main
tallinnasse	doc_491521502044_item	2571668	et	3	main
ja	doc_491521502044_item	2571676	et	3	main
kuhu	doc_491521502044_item	2571677	et	3	main
teie	doc_491521502044_item	2571688	et	4	main
sõna	doc_491521502041_item	2571423	et	4	main
mulle	doc_491521502041_item	2571427	et	4	main
tallinnasse	doc_491521502041_item	2571430	et	3	main
mind	doc_491521502041_item	2571451	et	4	main
saa	doc_491521502041_item	2571456	et	4	main
ma	doc_491521502041_item	2571461	et	3	main
ja	doc_491521502041_item	2571464	et	3	main
kui	doc_491521502041_item	2571475	et	3	main
reisimiseks	doc_491521502041_item	2571478	et	4	main
kiri	doc_491521502043_item	2571574	et	3	main
läbi	doc_491521502043_item	2571576	et	4	main
tallinnasse	doc_491521502043_item	2571593	et	3	main
sinu	doc_491521502043_item	2571614	et	3	main
vastas	doc_491521502043_item	2571620	et	4	main
tulen	doc_491521502043_item	2571622	et	3	main
sellel	doc_491521502043_item	2571624	et	4	main
olen	doc_491521502043_item	2571628	et	3	main
külla	doc_491521502043_item	2571639	et	4	main
eesnimi	doc_491521502043_item	2571648	et	3	main
kiri	doc_491521502044_item	2571649	et	3	main
lugege	doc_491521502044_item	2571650	et	3	main
läbi	doc_491521502044_item	2571651	et	4	main
on	doc_491521502044_item	2571659	et	4	main
tere	doc_491521502044_item	2571662	et	3	main
mulle	doc_491521502044_item	2571665	et	4	main
millal	doc_491521502044_item	2571666	et	3	main
tuled	doc_491521502044_item	2571669	et	4	main
mitu	doc_491521502044_item	2571670	et	4	main
oled	doc_491521502044_item	2571675	et	3	main
tahad	doc_491521502044_item	2571681	et	3	main
ootama	doc_491521502044_item	2571684	et	3	main
läbi	doc_491521502044_item	2571687	et	4	main
kirja	doc_491521502044_item	2571689	et	4	main
vastus	doc_491521502046_item	2571806	et	3	main
mitu	doc_491521502046_item	2571819	et	4	main
minu	doc_491521502046_item	2571822	et	3	main
margus	doc_491521502046_item	2571834	et	3	main
sään	doc_491521502046_item	2571837	et	4	main
kaks	doc_491521502046_item	2571842	et	3	main
ma	doc_491521502046_item	2571844	et	3	main
olla	doc_491521502046_item	2571846	et	3	main
raeplatsele	doc_491521502046_item	2571852	et	3	main
soovin	doc_491521502046_item	2571855	et	3	main
vana	doc_491521502046_item	2571860	et	4	main
linnas	doc_491521502046_item	2571861	et	4	main
ja	doc_491521502046_item	2571862	et	3	main
täitke	doc_491521502047_item	2571871	et	3	main
on	doc_491521502047_item	2571874	et	4	main
tehnikaülikooli	doc_491521502047_item	2571882	et	4	main
ja	doc_491521502047_item	2571883	et	3	main
tellerina	doc_491521502047_item	2571890	et	3	main
eesti	doc_491521502047_item	2571893	et	4	main
tütar	doc_491521502047_item	2571923	et	3	main
72	doc_491521502047_item	2571930	et	2	main
aastat	doc_491521502047_item	2571936	et	3	main
vana	doc_491521502047_item	2571937	et	4	main
74	doc_491521502047_item	2571938	et	2	main
marguse	doc_491521502047_item	2571947	et	4	main
talle	doc_491521502047_item	2571951	et	4	main
on	doc_491521502047_item	2571954	et	4	main
kirjuta	doc_491521502047_item	2571958	et	4	main
palun	doc_491521502047_item	2571959	et	3	main
päeva	doc_491521502047_item	2571966	et	4	main
minna	doc_491521502047_item	2571975	et	3	main
tahad	doc_491521502047_item	2571976	et	3	main
jään	doc_491521502047_item	2571977	et	3	main
margus	doc_491521502047_item	2571980	et	3	main
homme	doc_491521502047_item	2571986	et	3	main
kolm	doc_491521502047_item	2571994	et	3	main
rae	doc_491521502047_item	2571998	et	3	main
lugege	doc_491521502043_item	2571575	et	3	main
kus	doc_491521502043_item	2571583	et	3	main
20-25	doc_491521502043_item	2571585	et	2	main
päeva	doc_491521502043_item	2571596	et	4	main
sa	doc_491521502043_item	2571597	et	3	main
juures	doc_491521502043_item	2571599	et	4	main
kuhu	doc_491521502043_item	2571602	et	3	main
tallinnas	doc_491521502043_item	2571604	et	4	main
minna	doc_491521502043_item	2571605	et	3	main
tahad	doc_491521502043_item	2571606	et	3	main
jään	doc_491521502043_item	2571607	et	3	main
vastust	doc_491521502043_item	2571608	et	4	main
sain	doc_491521502043_item	2571613	et	3	main
kirjutan	doc_491521502043_item	2571618	et	3	main
nädalas	doc_491521502043_item	2571625	et	3	main
ma	doc_491521502043_item	2571627	et	3	main
juures	doc_491521502043_item	2571630	et	4	main
päeva	doc_491521502043_item	2571632	et	4	main
oma	doc_491521502043_item	2571637	et	4	main
sõprale	doc_491521502043_item	2571638	et	4	main
lähen	doc_491521502043_item	2571642	et	3	main
kõige	doc_491521502043_item	2571645	et	4	main
ja	doc_491521502044_item	2571654	et	3	main
20-25	doc_491521502044_item	2571660	et	2	main
kirjuta	doc_491521502044_item	2571663	et	4	main
minu	doc_491521502044_item	2571673	et	3	main
sa	doc_491521502044_item	2571678	et	3	main
vastust	doc_491521502044_item	2571683	et	4	main
margus	doc_491521502044_item	2571685	et	3	main
kirja	doc_491521502044_item	2571691	et	4	main
tervitab	doc_491521502044_item	2571724	et	3	main
eesnimi	doc_491521502044_item	2571725	et	3	main
marguse	doc_491521502046_item	2571801	et	4	main
kiri	doc_491521502046_item	2571802	et	3	main
ja	doc_491521502046_item	2571803	et	3	main
kirjutage	doc_491521502046_item	2571804	et	3	main
talle	doc_491521502046_item	2571805	et	4	main
20-25	doc_491521502046_item	2571809	et	2	main
tere	doc_491521502046_item	2571811	et	3	main
kirjuta	doc_491521502046_item	2571812	et	4	main
palun	doc_491521502046_item	2571813	et	3	main
mulle	doc_491521502046_item	2571814	et	4	main
oled	doc_491521502046_item	2571824	et	3	main
kuhu	doc_491521502046_item	2571826	et	3	main
tallinnas	doc_491521502046_item	2571828	et	4	main
jään	doc_491521502046_item	2571831	et	3	main
tallinnasse	doc_491521502046_item	2571840	et	3	main
sinu	doc_491521502046_item	2571847	et	3	main
tahan	doc_491521502046_item	2571850	et	3	main
ma	doc_491521502046_item	2571854	et	3	main
ühe	doc_491521502046_item	2571857	et	4	main
jalutan	doc_491521502046_item	2571859	et	3	main
lugege	doc_491521502047_item	2571868	et	3	main
informatsiooni	doc_491521502047_item	2571869	et	4	main
ja	doc_491521502047_item	2571870	et	3	main
ankeet	doc_491521502047_item	2571872	et	3	main
tähistatud	doc_491521502047_item	2571875	et	4	main
0-ga	doc_491521502047_item	2571876	et	3	main
maarika	doc_491521502047_item	2571877	et	4	main
on	doc_491521502047_item	2571885	et	4	main
maarika	doc_491521502047_item	2571891	et	4	main
marguse	doc_491521502043_item	2571577	et	4	main
vastus	doc_491521502043_item	2571582	et	3	main
mulle	doc_491521502043_item	2571590	et	4	main
millal	doc_491521502043_item	2571591	et	3	main
tuled	doc_491521502043_item	2571594	et	4	main
minu	doc_491521502043_item	2571598	et	3	main
oled	doc_491521502043_item	2571600	et	3	main
sa	doc_491521502043_item	2571603	et	3	main
kirja	doc_491521502043_item	2571615	et	4	main
sulle	doc_491521502043_item	2571619	et	3	main
sinu	doc_491521502043_item	2571629	et	3	main
kolm	doc_491521502043_item	2571631	et	3	main
ja	doc_491521502043_item	2571633	et	3	main
ma	doc_491521502043_item	2571634	et	3	main
tahan	doc_491521502043_item	2571635	et	3	main
ma	doc_491521502043_item	2571641	et	3	main
marguse	doc_491521502044_item	2571652	et	4	main
talle	doc_491521502044_item	2571656	et	4	main
kus	doc_491521502044_item	2571658	et	3	main
päeva	doc_491521502044_item	2571671	et	4	main
sa	doc_491521502044_item	2571672	et	3	main
tallinnas	doc_491521502044_item	2571679	et	4	main
suutänu	doc_491521502044_item	2571690	et	4	main
eest	doc_491521502044_item	2571692	et	4	main
ma	doc_491521502044_item	2571693	et	3	main
tulen	doc_491521502044_item	2571694	et	3	main
tallinnasse	doc_491521502044_item	2571695	et	3	main
laupäeval	doc_491521502044_item	2571696	et	3	main
kaheks	doc_491521502044_item	2571697	et	4	main
päevaks	doc_491521502044_item	2571698	et	3	main
praegu	doc_491521502044_item	2571699	et	3	main
mul	doc_491521502044_item	2571700	et	3	main
on	doc_491521502044_item	2571701	et	4	main
palju	doc_491521502044_item	2571702	et	4	main
töid	doc_491521502044_item	2571703	et	3	main
ma	doc_491521502044_item	2571704	et	3	main
tahan	doc_491521502044_item	2571705	et	3	main
külastada	doc_491521502044_item	2571706	et	3	main
toompea	doc_491521502044_item	2571707	et	4	main
pikka	doc_491521502044_item	2571709	et	4	main
lossi	doc_491521502044_item	2571708	et	4	main
hermanni	doc_491521502044_item	2571710	et	4	main
kadrioru	doc_491521502044_item	2571711	et	3	main
lossi	doc_491521502044_item	2571712	et	4	main
vabaõhumuuseumi	doc_491521502044_item	2571713	et	4	main
loomaaeda	doc_491521502044_item	2571714	et	4	main
õhtul	doc_491521502044_item	2571715	et	3	main
soovin	doc_491521502044_item	2571716	et	3	main
minna	doc_491521502044_item	2571717	et	3	main
draamateatrisse	doc_491521502044_item	2571718	et	3	main
osta	doc_491521502044_item	2571719	et	4	main
mulle	doc_491521502044_item	2571720	et	4	main
teisipäeval	doc_491521502043_item	2571626	et	3	main
siis	doc_491521502043_item	2571640	et	3	main
tagasi	doc_491521502043_item	2571644	et	3	main
head	doc_491521502043_item	2571646	et	4	main
nägemist	doc_491521502043_item	2571647	et	4	main
sa	doc_491521502044_item	2571667	et	3	main
juures	doc_491521502044_item	2571674	et	4	main
minna	doc_491521502044_item	2571680	et	3	main
jään	doc_491521502044_item	2571682	et	3	main
lugesin	doc_491521502044_item	2571686	et	3	main
piletit	doc_491521502044_item	2571721	et	3	main
puhapäevaks	doc_491521502044_item	2571723	et	4	main
kiri	doc_491521502046_item	2571798	et	3	main
lugege	doc_491521502046_item	2571799	et	3	main
millal	doc_491521502046_item	2571815	et	3	main
sa	doc_491521502046_item	2571816	et	3	main
tallinnasse	doc_491521502046_item	2571817	et	3	main
tuled	doc_491521502046_item	2571818	et	4	main
sa	doc_491521502046_item	2571827	et	3	main
minna	doc_491521502046_item	2571829	et	3	main
vastust	doc_491521502046_item	2571832	et	4	main
ülehomme	doc_491521502046_item	2571841	et	3	main
turul	doc_491521502046_item	2571864	et	3	main
kohtumiseni	doc_491521502046_item	2571865	et	4	main
eksamitöö	doc_491521502047_item	2571866	et	4	main
1	doc_491521502047_item	2571867	et	2	main
on	doc_491521502047_item	2571879	et	4	main
lõpetanu	doc_491521502047_item	2571880	et	4	main
hansapangas	doc_491521502047_item	2571886	et	4	main
oskab	doc_491521502047_item	2571892	et	3	main
ja	doc_491521502047_item	2571922	et	3	main
perkonnaseis	doc_491521502047_item	2571939	et	4	main
kiri	doc_491521502047_item	2571948	et	3	main
tallinnasse	doc_491521502047_item	2571963	et	3	main
minu	doc_491521502047_item	2571968	et	3	main
sa	doc_491521502047_item	2571973	et	3	main
vastust	doc_491521502047_item	2571978	et	4	main
ma	doc_491521502047_item	2571983	et	3	main
juures	doc_491521502047_item	2571993	et	4	main
minna	doc_491521502047_item	2571997	et	3	main
platsile	doc_491521502047_item	2571999	et	4	main
kohtumiseni	doc_491521502047_item	2572010	et	4	main
teatrisse	doc_491521502044_item	2571722	et	3	main
kus	doc_491521502046_item	2571807	et	3	main
sõna	doc_491521502046_item	2571810	et	4	main
päeva	doc_491521502046_item	2571820	et	4	main
läbi	doc_491521502046_item	2571800	et	4	main
on	doc_491521502046_item	2571808	et	4	main
sa	doc_491521502046_item	2571821	et	3	main
juures	doc_491521502046_item	2571823	et	4	main
ja	doc_491521502046_item	2571825	et	3	main
tahad	doc_491521502046_item	2571830	et	3	main
tere	doc_491521502046_item	2571835	et	3	main
sõber	doc_491521502046_item	2571836	et	3	main
ma	doc_491521502046_item	2571838	et	3	main
minna	doc_491521502046_item	2571851	et	3	main
käija	doc_491521502046_item	2571863	et	4	main
kask	doc_491521502047_item	2571878	et	3	main
ta	doc_491521502047_item	2571884	et	4	main
poeg	doc_491521502047_item	2571921	et	3	main
71	doc_491521502047_item	2571927	et	2	main
kask	doc_491521502047_item	2571929	et	3	main
73	doc_491521502047_item	2571933	et	2	main
vanus	doc_491521502047_item	2571934	et	4	main
35	doc_491521502047_item	2571935	et	2	main
tellerina	doc_491521502047_item	2571943	et	3	main
lugege	doc_491521502047_item	2571945	et	3	main
kirjutage	doc_491521502047_item	2571950	et	3	main
vastus	doc_491521502047_item	2571952	et	3	main
tuled	doc_491521502047_item	2571964	et	4	main
mitu	doc_491521502047_item	2571965	et	4	main
juures	doc_491521502047_item	2571969	et	4	main
ja	doc_491521502047_item	2571971	et	3	main
tere	doc_491521502047_item	2571981	et	3	main
tulen	doc_491521502047_item	2571984	et	3	main
lõuna	doc_491521502047_item	2571988	et	4	main
linnas	doc_491521502047_item	2572005	et	4	main
ja	doc_491521502047_item	2572006	et	3	main
tere	doc_491521502049_item	2572131	et	3	main
eesnimi	doc_491521502049_item	2572132	et	3	main
ma	doc_491521502049_item	2572133	et	3	main
kirja	doc_491521502049_item	2572136	et	4	main
katte	doc_491521502049_item	2572137	et	4	main
sur	doc_491521502049_item	2572138	et	4	main
mul	doc_491521502049_item	2572148	et	3	main
väga	doc_491521502049_item	2572151	et	3	main
täna	doc_491521502049_item	2572155	et	4	main
jures	doc_491521502049_item	2572157	et	4	main
avati	doc_491521502049_item	2572158	et	3	main
uus	doc_491521502049_item	2572159	et	3	main
kauplus	doc_491521502049_item	2572160	et	3	main
ootama	doc_491521502046_item	2571833	et	3	main
tulen	doc_491521502046_item	2571839	et	3	main
päeva	doc_491521502046_item	2571843	et	4	main
tahtsin	doc_491521502046_item	2571845	et	3	main
juurest	doc_491521502046_item	2571848	et	4	main
ma	doc_491521502046_item	2571849	et	3	main
veel	doc_491521502046_item	2571853	et	4	main
kohtusin	doc_491521502046_item	2571856	et	4	main
naisega	doc_491521502046_item	2571858	et	3	main
näidis	doc_491521502047_item	2571873	et	4	main
tallinna	doc_491521502047_item	2571881	et	4	main
töötanud	doc_491521502047_item	2571887	et	4	main
kaks	doc_491521502047_item	2571888	et	3	main
aastat	doc_491521502047_item	2571889	et	3	main
vene	doc_491521502047_item	2571894	et	4	main
ja	doc_491521502047_item	2571895	et	3	main
saksa	doc_491521502047_item	2571896	et	4	main
keelt	doc_491521502047_item	2571897	et	4	main
m	doc_491521502047_item	2571898	et	4	main
kask	doc_491521502047_item	2571899	et	3	main
on	doc_491521502047_item	2571900	et	4	main
hea	doc_491521502047_item	2571901	et	4	main
suhtleja	doc_491521502047_item	2571902	et	4	main
ning	doc_491521502047_item	2571903	et	3	main
oskab	doc_491521502047_item	2571904	et	3	main
kasutada	doc_491521502047_item	2571905	et	3	main
arvutit	doc_491521502047_item	2571906	et	3	main
ta	doc_491521502047_item	2571907	et	4	main
on	doc_491521502047_item	2571908	et	4	main
kolmekümne	doc_491521502047_item	2571909	et	4	main
viie	doc_491521502047_item	2571910	et	3	main
aastane	doc_491521502047_item	2571911	et	4	main
maarika	doc_491521502047_item	2571912	et	4	main
abikaasa	doc_491521502047_item	2571913	et	4	main
tarmo	doc_491521502047_item	2571914	et	4	main
kask	doc_491521502047_item	2571915	et	3	main
töötab	doc_491521502047_item	2571916	et	3	main
hansapangas	doc_491521502047_item	2571917	et	4	main
turvamehena	doc_491521502047_item	2571918	et	3	main
neil	doc_491521502047_item	2571919	et	4	main
on	doc_491521502047_item	2571920	et	4	main
0	doc_491521502047_item	2571924	et	2	main
maarika	doc_491521502047_item	2571926	et	4	main
sugu	doc_491521502047_item	2571931	et	4	main
naiste	doc_491521502047_item	2571932	et	3	main
75	doc_491521502047_item	2571941	et	2	main
ja	doc_491521502047_item	2571949	et	3	main
kus	doc_491521502047_item	2571953	et	3	main
20-25	doc_491521502047_item	2571955	et	2	main
sõna	doc_491521502047_item	2571956	et	4	main
tere	doc_491521502047_item	2571957	et	3	main
ootama	doc_491521502047_item	2571979	et	3	main
peale	doc_491521502047_item	2571987	et	4	main
ma	doc_491521502047_item	2571989	et	3	main
olen	doc_491521502047_item	2571991	et	3	main
eesnimi	doc_491521502047_item	2571925	et	3	main
perekonnanimi	doc_491521502047_item	2571928	et	3	main
abielus	doc_491521502047_item	2571940	et	4	main
amet	doc_491521502047_item	2571942	et	3	main
2	doc_491521502047_item	2571944	et	2	main
läbi	doc_491521502047_item	2571946	et	4	main
mulle	doc_491521502047_item	2571960	et	4	main
millal	doc_491521502047_item	2571961	et	3	main
sa	doc_491521502047_item	2571962	et	3	main
sa	doc_491521502047_item	2571967	et	3	main
oled	doc_491521502047_item	2571970	et	3	main
kuhu	doc_491521502047_item	2571972	et	3	main
tallinnas	doc_491521502047_item	2571974	et	4	main
jään	doc_491521502047_item	2571982	et	3	main
tallinnasse	doc_491521502047_item	2571985	et	3	main
tahan	doc_491521502047_item	2571990	et	3	main
sinule	doc_491521502047_item	2571992	et	3	main
tahan	doc_491521502047_item	2571996	et	3	main
tahan	doc_491521502047_item	2572007	et	3	main
palju	doc_491521502047_item	2572008	et	4	main
ostus	doc_491521502047_item	2572009	et	3	main
päeva	doc_491521502047_item	2571995	et	4	main
veel	doc_491521502047_item	2572000	et	4	main
ma	doc_491521502047_item	2572001	et	3	main
tahan	doc_491521502047_item	2572002	et	3	main
jalutan	doc_491521502047_item	2572003	et	3	main
vana	doc_491521502047_item	2572004	et	4	main
kuidas	doc_491521502049_item	2572141	et	3	main
sull	doc_491521502049_item	2572142	et	4	main
läheb	doc_491521502049_item	2572143	et	3	main
millega	doc_491521502049_item	2572144	et	3	main
sa	doc_491521502049_item	2572145	et	3	main
hea	doc_491521502049_item	2572152	et	4	main
60	doc_491521502052_item	2572425	et	2	main
sõna	doc_491521502052_item	2572426	et	4	main
ennast	doc_491521502052_item	2572428	et	4	main
haridus	doc_491521502052_item	2572430	et	3	main
töökogemused	doc_491521502052_item	2572431	et	3	main
keelteoskus	doc_491521502052_item	2572432	et	3	main
arvutioskus	doc_491521502052_item	2572433	et	3	main
autojuhiload	doc_491521502052_item	2572434	et	4	main
hobid	doc_491521502052_item	2572435	et	3	main
ja	doc_491521502052_item	2572436	et	3	main
kirjutage	doc_491521502052_item	2572437	et	3	main
ja	doc_491521502052_item	2572466	et	3	main
vene	doc_491521502052_item	2572467	et	4	main
keele	doc_491521502052_item	2572468	et	4	main
soovitav	doc_491521502052_item	2572472	et	4	main
ka	doc_491521502052_item	2572474	et	3	main
nüit	doc_491521502049_item	2572146	et	4	main
tänu	doc_491521502049_item	2572139	et	4	main
sulle	doc_491521502049_item	2572140	et	3	main
on	doc_491521502049_item	2572149	et	4	main
meiel	doc_491521502049_item	2572154	et	4	main
maja	doc_491521502049_item	2572156	et	4	main
ma	doc_491521502049_item	2572161	et	3	main
ootasin	doc_491521502049_item	2572162	et	3	main
kiri	doc_491521502049_item	2572130	et	3	main
sain	doc_491521502049_item	2572134	et	3	main
sinu	doc_491521502049_item	2572135	et	3	main
tegeled	doc_491521502049_item	2572147	et	3	main
sulle	doc_491521502049_item	2572150	et	3	main
uudis	doc_491521502049_item	2572153	et	3	main
kiri	doc_491521502052_item	2572414	et	3	main
peab	doc_491521502052_item	2572422	et	4	main
oma	doc_491521502052_item	2572438	et	4	main
soovidest	doc_491521502052_item	2572439	et	3	main
tööd	doc_491521502052_item	2572441	et	4	main
soovite	doc_491521502052_item	2572442	et	3	main
kui	doc_491521502052_item	2572443	et	3	main
suurt	doc_491521502052_item	2572444	et	3	main
töötasu	doc_491521502052_item	2572445	et	4	main
soovite	doc_491521502052_item	2572446	et	3	main
milline	doc_491521502052_item	2572447	et	3	main
töögraafik	doc_491521502052_item	2572448	et	3	main
sobib	doc_491521502052_item	2572449	et	3	main
kahe	doc_491521502052_item	2572450	et	3	main
turvamehi	doc_491521502052_item	2572460	et	3	main
oskust	doc_491521502052_item	2572469	et	3	main
on	doc_491521502052_item	2572473	et	4	main
pakume	doc_491521502052_item	2572476	et	3	main
teile	doc_491521502052_item	2572479	et	4	main
sobivat	doc_491521502052_item	2572480	et	4	main
töögraafikut	doc_491521502052_item	2572481	et	3	main
kindlat	doc_491521502052_item	2572482	et	3	main
kakuke	doc_491521502052_item	2572486	et	4	main
kakuke	doc_491521502052_item	2572493	et	4	main
eesnimi	doc_491521502052_item	2572496	et	3	main
otsite	doc_491521502052_item	2572503	et	3	main
müüjana	doc_491521502052_item	2572507	et	4	main
olema	doc_491521502052_item	2572423	et	4	main
millist	doc_491521502052_item	2572440	et	3	main
koristajaid	doc_491521502052_item	2572461	et	4	main
pakkijaid	doc_491521502052_item	2572462	et	4	main
kanditaatidelt	doc_491521502052_item	2572463	et	3	main
ootame	doc_491521502052_item	2572464	et	3	main
palka	doc_491521502052_item	2572483	et	4	main
mnt3	doc_491521502052_item	2572488	et	4	main
te	doc_491521502052_item	2572502	et	4	main
ma	doc_491521502052_item	2572505	et	3	main
kaupluses	doc_491521502052_item	2572508	et	3	main
hea	doc_491521502052_item	2572516	et	4	main
ma	doc_491521502052_item	2572518	et	3	main
rägin	doc_491521502052_item	2572520	et	3	main
ja	doc_491521502052_item	2572522	et	3	main
vene	doc_491521502052_item	2572523	et	4	main
mull	doc_491521502052_item	2572525	et	3	main
on	doc_491521502052_item	2572526	et	4	main
te	doc_491521502052_item	2572532	et	4	main
arvutioskus	doc_491521502052_item	2572537	et	3	main
päras	doc_491521502052_item	2572542	et	3	main
võiks	doc_491521502052_item	2572545	et	4	main
teil	doc_491521502052_item	2572547	et	4	main
tööpäevast	doc_491521502052_item	2572557	et	4	main
olla	doc_491521502052_item	2572573	et	3	main
minu	doc_491521502052_item	2572576	et	3	main
olla	doc_491521502052_item	2572580	et	3	main
eek	doc_491521502052_item	2572583	et	4	main
00000000	doc_491521502052_item	2572587	et	2	main
abielus	doc_491521502052_item	2572591	et	4	main
on	doc_491521502052_item	2572593	et	4	main
kesktänav	doc_491521502052_item	2572603	et	4	main
lugege	doc_491521502052_item	2572415	et	3	main
läbi	doc_491521502052_item	2572416	et	4	main
kuulutus	doc_491521502052_item	2572417	et	4	main
ja	doc_491521502052_item	2572418	et	3	main
vastake	doc_491521502052_item	2572419	et	3	main
sellele	doc_491521502052_item	2572420	et	4	main
kirjas	doc_491521502052_item	2572421	et	4	main
perekonnaseis	doc_491521502052_item	2572429	et	4	main
eesti	doc_491521502052_item	2572465	et	4	main
head	doc_491521502052_item	2572470	et	4	main
lisainfo	doc_491521502052_item	2572484	et	4	main
tartu	doc_491521502052_item	2572487	et	4	main
direktor	doc_491521502052_item	2572491	et	3	main
kirjutab	doc_491521502052_item	2572494	et	3	main
perekonnanimi	doc_491521502052_item	2572497	et	3	main
on	doc_491521502052_item	2572515	et	4	main
eesti	doc_491521502052_item	2572521	et	4	main
keeles	doc_491521502052_item	2572524	et	4	main
majanduskool	doc_491521502052_item	2572531	et	4	main
ka	doc_491521502052_item	2572536	et	3	main
lõppetan	doc_491521502052_item	2572540	et	4	main
lõppes	doc_491521502052_item	2572562	et	4	main
on	doc_491521502052_item	2572566	et	4	main
last	doc_491521502052_item	2572568	et	4	main
ja	doc_491521502052_item	2572569	et	3	main
õhtul	doc_491521502052_item	2572570	et	3	main
ma	doc_491521502052_item	2572571	et	3	main
palk	doc_491521502052_item	2572578	et	3	main
olen	doc_491521502052_item	2572585	et	3	main
elan	doc_491521502052_item	2572588	et	3	main
eesnimi	doc_491521502052_item	2572601	et	3	main
perekonnanimi	doc_491521502052_item	2572602	et	3	main
aseri	doc_491521502052_item	2572605	et	4	main
võite	doc_491521502052_item	2572607	et	4	main
helistada	doc_491521502052_item	2572608	et	3	main
ja	doc_491521502052_item	2572614	et	3	main
000000000	doc_491521502052_item	2572616	et	2	main
umbes	doc_491521502052_item	2572424	et	4	main
tutvustage	doc_491521502052_item	2572427	et	3	main
kuu	doc_491521502052_item	2572451	et	4	main
pärast	doc_491521502052_item	2572452	et	4	main
avatakse	doc_491521502052_item	2572453	et	4	main
uus	doc_491521502052_item	2572454	et	3	main
toidukauplus	doc_491521502052_item	2572455	et	3	main
kauplusse	doc_491521502052_item	2572456	et	3	main
vajatakse	doc_491521502052_item	2572457	et	4	main
müüjat	doc_491521502052_item	2572458	et	4	main
kassapidajat	doc_491521502052_item	2572459	et	3	main
suhtlemisoskust	doc_491521502052_item	2572471	et	3	main
arvutikasutusoskus	doc_491521502052_item	2572475	et	3	main
töötingimusi	doc_491521502052_item	2572478	et	3	main
as	doc_491521502052_item	2572485	et	4	main
tallinn	doc_491521502052_item	2572489	et	4	main
teile	doc_491521502052_item	2572495	et	4	main
lugesin	doc_491521502052_item	2572498	et	3	main
kulutuse	doc_491521502052_item	2572500	et	4	main
kus	doc_491521502052_item	2572501	et	3	main
müüjat	doc_491521502052_item	2572504	et	4	main
töötasin	doc_491521502052_item	2572506	et	3	main
edu	doc_491521502052_item	2572509	et	4	main
ja	doc_491521502052_item	2572510	et	3	main
ma	doc_491521502052_item	2572511	et	3	main
tean	doc_491521502052_item	2572512	et	3	main
kui	doc_491521502052_item	2572513	et	3	main
tähtis	doc_491521502052_item	2572514	et	4	main
soovitaksite	doc_491521502052_item	2572533	et	3	main
oli	doc_491521502052_item	2572535	et	3	main
lõppetamist	doc_491521502052_item	2572543	et	4	main
müüjana	doc_491521502052_item	2572549	et	4	main
ma	doc_491521502052_item	2572550	et	3	main
tahaksin	doc_491521502052_item	2572551	et	3	main
et	doc_491521502052_item	2572552	et	3	main
minu	doc_491521502052_item	2572553	et	3	main
töögrafik	doc_491521502052_item	2572554	et	4	main
algas	doc_491521502052_item	2572559	et	3	main
1600	doc_491521502052_item	2572563	et	2	main
mull	doc_491521502052_item	2572565	et	3	main
oma	doc_491521502052_item	2572574	et	4	main
perga	doc_491521502052_item	2572575	et	4	main
ümbes	doc_491521502052_item	2572581	et	4	main
ma	doc_491521502052_item	2572584	et	3	main
olen	doc_491521502052_item	2572590	et	3	main
last	doc_491521502052_item	2572595	et	4	main
palun	doc_491521502052_item	2572596	et	3	main
adresile	doc_491521502052_item	2572600	et	4	main
00000000	doc_491521502052_item	2572613	et	2	main
mugavaid	doc_491521502052_item	2572477	et	3	main
lugupeetud	doc_491521502052_item	2572490	et	4	main
as	doc_491521502052_item	2572492	et	4	main
teie	doc_491521502052_item	2572499	et	4	main
suhtlemisoskus	doc_491521502052_item	2572517	et	3	main
vabalt	doc_491521502052_item	2572519	et	4	main
kesk-eri	doc_491521502052_item	2572527	et	4	main
haridus	doc_491521502052_item	2572528	et	3	main
lõppetasin	doc_491521502052_item	2572529	et	4	main
präegu	doc_491521502052_item	2572538	et	4	main
algama	doc_491521502052_item	2572546	et	3	main
töötama	doc_491521502052_item	2572548	et	3	main
koosnes	doc_491521502052_item	2572555	et	3	main
viiest	doc_491521502052_item	2572556	et	4	main
800	doc_491521502052_item	2572560	et	2	main
peab	doc_491521502052_item	2572579	et	4	main
2000	doc_491521502052_item	2572582	et	2	main
aseris	doc_491521502052_item	2572589	et	4	main
mull	doc_491521502052_item	2572592	et	3	main
kaks	doc_491521502052_item	2572594	et	3	main
saadke	doc_491521502052_item	2572597	et	4	main
oma	doc_491521502052_item	2572598	et	4	main
00-00	doc_491521502052_item	2572604	et	2	main
ida-irumaa	doc_491521502052_item	2572606	et	4	main
minu	doc_491521502052_item	2572609	et	3	main
telefon	doc_491521502052_item	2572611	et	3	main
on	doc_491521502052_item	2572612	et	4	main
tallinna	doc_491521502052_item	2572530	et	4	main
et	doc_491521502052_item	2572534	et	3	main
ma	doc_491521502052_item	2572539	et	3	main
arvutikursid	doc_491521502052_item	2572541	et	3	main
ma	doc_491521502052_item	2572544	et	3	main
tööpäev	doc_491521502052_item	2572558	et	3	main
ja	doc_491521502052_item	2572561	et	3	main
seest	doc_491521502052_item	2572564	et	3	main
kaks	doc_491521502052_item	2572567	et	3	main
tahaksin	doc_491521502052_item	2572572	et	3	main
mõõtes	doc_491521502052_item	2572577	et	4	main
sündinud	doc_491521502052_item	2572586	et	4	main
selle	doc_491521502052_item	2572599	et	4	main
kodu	doc_491521502052_item	2572610	et	4	main
moobiltelefon	doc_491521502052_item	2572615	et	4	main
ja	doc_491521502056_item	2573099	et	3	main
umbes	doc_491521502056_item	2573105	et	4	main
60	doc_491521502056_item	2573106	et	2	main
haridus	doc_491521502056_item	2573111	et	3	main
millist	doc_491521502056_item	2573121	et	3	main
suurt	doc_491521502056_item	2573125	et	3	main
milline	doc_491521502056_item	2573128	et	3	main
sobib	doc_491521502056_item	2573130	et	3	main
avatakse	doc_491521502056_item	2573134	et	4	main
müüjat	doc_491521502056_item	2573139	et	4	main
kassapidajat	doc_491521502056_item	2573140	et	3	main
turvamehi	doc_491521502056_item	2573141	et	3	main
olema	doc_491521502056_item	2573104	et	4	main
ennast	doc_491521502056_item	2573109	et	4	main
töökogemused	doc_491521502056_item	2573112	et	3	main
arvutioskus	doc_491521502056_item	2573114	et	3	main
kirjutage	doc_491521502056_item	2573118	et	3	main
sellele	doc_491521502056_item	2573101	et	4	main
kirjas	doc_491521502056_item	2573102	et	4	main
tutvustage	doc_491521502056_item	2573108	et	3	main
autojuhiload	doc_491521502056_item	2573115	et	4	main
soovidest	doc_491521502056_item	2573120	et	3	main
kuu	doc_491521502056_item	2573132	et	4	main
toidukauplus	doc_491521502056_item	2573136	et	3	main
vajatakse	doc_491521502056_item	2573138	et	4	main
eesti	doc_491521502056_item	2573146	et	4	main
lisainfo	doc_491521502056_item	2573165	et	4	main
mnt3	doc_491521502056_item	2573169	et	4	main
direktorile	doc_491521502056_item	2573173	et	3	main
teie	doc_491521502056_item	2573177	et	4	main
otsite	doc_491521502056_item	2573181	et	3	main
mulle	doc_491521502056_item	2573185	et	4	main
väga	doc_491521502056_item	2573186	et	3	main
meeldib	doc_491521502056_item	2573187	et	3	main
olen	doc_491521502056_item	2573189	et	3	main
müüjade	doc_491521502056_item	2573191	et	4	main
ma	doc_491521502056_item	2573206	et	3	main
ja	doc_491521502056_item	2573209	et	3	main
keelt	doc_491521502056_item	2573211	et	4	main
mul	doc_491521502056_item	2573212	et	3	main
on	doc_491521502056_item	2573213	et	4	main
autojuhiload	doc_491521502056_item	2573214	et	4	main
kiri	doc_491521502056_item	2573095	et	3	main
lugege	doc_491521502056_item	2573096	et	3	main
läbi	doc_491521502056_item	2573097	et	4	main
kuulutus	doc_491521502056_item	2573098	et	4	main
peab	doc_491521502056_item	2573103	et	4	main
perekonnaseis	doc_491521502056_item	2573110	et	4	main
keelteoskus	doc_491521502056_item	2573113	et	3	main
ja	doc_491521502056_item	2573117	et	3	main
tööd	doc_491521502056_item	2573122	et	4	main
soovite	doc_491521502056_item	2573123	et	3	main
töötasu	doc_491521502056_item	2573126	et	4	main
töögraafik	doc_491521502056_item	2573129	et	3	main
pärast	doc_491521502056_item	2573133	et	4	main
kauplusse	doc_491521502056_item	2573137	et	3	main
suhtlemisoskust	doc_491521502056_item	2573152	et	3	main
pakume	doc_491521502056_item	2573157	et	3	main
as	doc_491521502056_item	2573171	et	4	main
lugupeetud	doc_491521502056_item	2573174	et	4	main
lugesin	doc_491521502056_item	2573176	et	3	main
teie	doc_491521502056_item	2573180	et	4	main
kursuse	doc_491521502056_item	2573192	et	3	main
28-aastane	doc_491521502056_item	2573199	et	4	main
keskeri	doc_491521502056_item	2573201	et	4	main
vastake	doc_491521502056_item	2573100	et	3	main
sõna	doc_491521502056_item	2573107	et	4	main
hobid	doc_491521502056_item	2573116	et	3	main
oma	doc_491521502056_item	2573119	et	4	main
pakkijaid	doc_491521502056_item	2573143	et	4	main
kanditaatidelt	doc_491521502056_item	2573144	et	3	main
vene	doc_491521502056_item	2573148	et	4	main
head	doc_491521502056_item	2573151	et	4	main
on	doc_491521502056_item	2573154	et	4	main
töötingimusi	doc_491521502056_item	2573159	et	3	main
sobivat	doc_491521502056_item	2573161	et	4	main
töögraafikut	doc_491521502056_item	2573162	et	3	main
tartu	doc_491521502056_item	2573168	et	4	main
kakuke	doc_491521502056_item	2573172	et	4	main
direktor	doc_491521502056_item	2573175	et	3	main
ja	doc_491521502056_item	2573193	et	3	main
tööd	doc_491521502056_item	2573196	et	4	main
olen	doc_491521502056_item	2573198	et	3	main
valdan	doc_491521502056_item	2573207	et	3	main
vene	doc_491521502056_item	2573210	et	4	main
arvuti	doc_491521502056_item	2573218	et	4	main
lõpetasin	doc_491521502056_item	2573221	et	3	main
suitseta	doc_491521502056_item	2573225	et	4	main
et	doc_491521502056_item	2573243	et	3	main
õigel	doc_491521502056_item	2573246	et	3	main
ma	doc_491521502056_item	2573249	et	3	main
tööd	doc_491521502056_item	2573251	et	4	main
teie	doc_491521502056_item	2573252	et	4	main
firmas	doc_491521502056_item	2573253	et	3	main
12092000	doc_491521502056_item	2573254	et	2	main
kui	doc_491521502056_item	2573124	et	3	main
soovite	doc_491521502056_item	2573127	et	3	main
kahe	doc_491521502056_item	2573131	et	3	main
uus	doc_491521502056_item	2573135	et	3	main
ootame	doc_491521502056_item	2573145	et	3	main
keele	doc_491521502056_item	2573149	et	4	main
oskust	doc_491521502056_item	2573150	et	3	main
ka	doc_491521502056_item	2573155	et	3	main
as	doc_491521502056_item	2573166	et	4	main
kakuke	doc_491521502056_item	2573167	et	4	main
tallinn	doc_491521502056_item	2573170	et	4	main
et	doc_491521502056_item	2573179	et	3	main
muujat	doc_491521502056_item	2573182	et	4	main
tööd	doc_491521502056_item	2573184	et	4	main
ma	doc_491521502056_item	2573188	et	3	main
praegu	doc_491521502056_item	2573194	et	3	main
ma	doc_491521502056_item	2573197	et	3	main
abielus	doc_491521502056_item	2573200	et	4	main
mul	doc_491521502056_item	2573202	et	3	main
on	doc_491521502056_item	2573203	et	4	main
eesti	doc_491521502056_item	2573208	et	4	main
hobi	doc_491521502056_item	2573216	et	4	main
sest	doc_491521502056_item	2573219	et	4	main
ma	doc_491521502056_item	2573220	et	3	main
arvutikursuse	doc_491521502056_item	2573222	et	3	main
ei	doc_491521502056_item	2573227	et	4	main
minu	doc_491521502056_item	2573231	et	3	main
4000	doc_491521502056_item	2573234	et	2	main
8	doc_491521502056_item	2573238	et	2	main
tunnid	doc_491521502056_item	2573239	et	3	main
kaks	doc_491521502056_item	2573240	et	3	main
pühkepäeva	doc_491521502056_item	2573241	et	4	main
arvan	doc_491521502056_item	2573242	et	3	main
a	doc_491521502056_item	2573255	et	4	main
tallinn	doc_491521502056_item	2573260	et	4	main
koristajaid	doc_491521502056_item	2573142	et	4	main
ja	doc_491521502056_item	2573147	et	3	main
soovitav	doc_491521502056_item	2573153	et	4	main
arvutikasutusoskus	doc_491521502056_item	2573156	et	3	main
mugavaid	doc_491521502056_item	2573158	et	3	main
teile	doc_491521502056_item	2573160	et	4	main
kindlat	doc_491521502056_item	2573163	et	3	main
palka	doc_491521502056_item	2573164	et	4	main
kuulutusest	doc_491521502056_item	2573178	et	4	main
see	doc_491521502056_item	2573183	et	3	main
lõpetasid	doc_491521502056_item	2573190	et	4	main
otsin	doc_491521502056_item	2573195	et	3	main
head	doc_491521502056_item	2573204	et	4	main
suhtlemisoskus	doc_491521502056_item	2573205	et	3	main
on	doc_491521502056_item	2573217	et	4	main
mul	doc_491521502056_item	2573244	et	3	main
looda	doc_491521502056_item	2573247	et	4	main
tel	doc_491521502056_item	2573261	et	4	main
minu	doc_491521502056_item	2573215	et	3	main
ma	doc_491521502056_item	2573223	et	3	main
joo	doc_491521502056_item	2573228	et	4	main
sooviksin	doc_491521502056_item	2573229	et	3	main
ei	doc_491521502056_item	2573224	et	4	main
ja	doc_491521502056_item	2573226	et	3	main
et	doc_491521502056_item	2573230	et	3	main
palk	doc_491521502056_item	2573232	et	3	main
oli	doc_491521502056_item	2573233	et	3	main
krooni	doc_491521502056_item	2573235	et	4	main
ja	doc_491521502056_item	2573236	et	3	main
tööpäev	doc_491521502056_item	2573237	et	3	main
on	doc_491521502056_item	2573245	et	4	main
ja	doc_491521502056_item	2573248	et	3	main
saan	doc_491521502056_item	2573250	et	4	main
margit	doc_491521502056_item	2573256	et	4	main
tartu	doc_491521502056_item	2573257	et	4	main
mnt	doc_491521502056_item	2573258	et	4	main
x-y	doc_491521502056_item	2573259	et	4	main
xxx8581	doc_491521502056_item	2573262	et	4	main
lugege	doc_491521502062_item	2574143	et	3	main
teksti	doc_491521502062_item	2574145	et	4	main
kirjutage	doc_491521502062_item	2574147	et	3	main
tere	doc_491521502062_item	2574149	et	3	main
endale	doc_491521502062_item	2574156	et	4	main
kirjuta	doc_491521502062_item	2574158	et	4	main
mida	doc_491521502062_item	2574159	et	4	main
kirjutage	doc_491521502062_item	2574168	et	3	main
aitah	doc_491521502062_item	2574172	et	4	main
mul	doc_491521502062_item	2574176	et	3	main
praegu	doc_491521502062_item	2574180	et	3	main
eesti	doc_491521502062_item	2574183	et	4	main
keele	doc_491521502062_item	2574184	et	4	main
kursusel	doc_491521502062_item	2574185	et	3	main
minu	doc_491521502062_item	2574186	et	3	main
lapsed	doc_491521502062_item	2574187	et	3	main
lasteaias	doc_491521502062_item	2574193	et	4	main
keelt	doc_491521502062_item	2574197	et	4	main
ka	doc_491521502062_item	2574199	et	3	main
me	doc_491521502062_item	2574200	et	4	main
kiri	doc_491521502062_item	2574142	et	3	main
järgmist	doc_491521502062_item	2574144	et	3	main
teed	doc_491521502062_item	2574160	et	4	main
kuidas	doc_491521502062_item	2574161	et	3	main
lapsed	doc_491521502062_item	2574162	et	3	main
elavad	doc_491521502062_item	2574163	et	4	main
ja	doc_491521502062_item	2574164	et	3	main
millal	doc_491521502062_item	2574165	et	3	main
sõidad	doc_491521502062_item	2574166	et	3	main
on	doc_491521502062_item	2574177	et	4	main
hästi	doc_491521502062_item	2574179	et	3	main
terved	doc_491521502062_item	2574190	et	4	main
kevadel	doc_491521502062_item	2574206	et	4	main
kiri	doc_491521502063_item	2574207	et	3	main
lugege	doc_491521502063_item	2574208	et	3	main
soovin	doc_491521502063_item	2574215	et	3	main
mida	doc_491521502063_item	2574224	et	4	main
kuidas	doc_491521502063_item	2574226	et	3	main
vastus	doc_491521502063_item	2574234	et	3	main
sõnaga	doc_491521502063_item	2574236	et	3	main
hästi	doc_491521502063_item	2574240	et	3	main
õpivad	doc_491521502063_item	2574242	et	3	main
suvel	doc_491521502063_item	2574248	et	3	main
lugege	doc_491521502064_item	2574250	et	3	main
puudmase	doc_491521502064_item	2574288	et	4	main
väga	doc_491521502064_item	2574292	et	3	main
elan	doc_491521502064_item	2574300	et	3	main
järgmist	doc_491521502065_item	2574309	et	3	main
ja	doc_491521502065_item	2574311	et	3	main
kirjutage	doc_491521502065_item	2574312	et	3	main
sulle	doc_491521502065_item	2574316	et	3	main
puhkust	doc_491521502065_item	2574318	et	4	main
ootan	doc_491521502065_item	2574319	et	3	main
kirjuta	doc_491521502065_item	2574323	et	4	main
mida	doc_491521502065_item	2574324	et	4	main
sõidad	doc_491521502065_item	2574331	et	3	main
vastus	doc_491521502065_item	2574334	et	3	main
metsa	doc_491521502065_item	2574340	et	4	main
kala	doc_491521502065_item	2574342	et	4	main
lapsed	doc_491521502065_item	2574343	et	3	main
elavad	doc_491521502065_item	2574344	et	4	main
hästi	doc_491521502065_item	2574345	et	3	main
vanaema	doc_491521502065_item	2574348	et	4	main
ma	doc_491521502065_item	2574351	et	3	main
venemaale	doc_491521502065_item	2574353	et	4	main
sind	doc_491521502062_item	2574155	et	4	main
20-25	doc_491521502062_item	2574170	et	2	main
eest	doc_491521502062_item	2574175	et	4	main
kõik	doc_491521502062_item	2574178	et	4	main
ma	doc_491521502062_item	2574181	et	3	main
õpin	doc_491521502062_item	2574182	et	3	main
ja	doc_491521502062_item	2574191	et	3	main
käivad	doc_491521502062_item	2574192	et	4	main
eesti	doc_491521502062_item	2574196	et	4	main
tahame	doc_491521502062_item	2574201	et	3	main
sõita	doc_491521502062_item	2574202	et	3	main
venemaale	doc_491521502062_item	2574203	et	4	main
järgmisel	doc_491521502062_item	2574204	et	3	main
aastal	doc_491521502062_item	2574205	et	3	main
tere	doc_491521502063_item	2574214	et	3	main
ja	doc_491521502062_item	2574146	et	3	main
sulle	doc_491521502062_item	2574151	et	3	main
puhkust	doc_491521502062_item	2574153	et	4	main
ootan	doc_491521502062_item	2574154	et	3	main
külla	doc_491521502062_item	2574157	et	4	main
venemaale	doc_491521502062_item	2574167	et	4	main
kõik	doc_491521502062_item	2574188	et	4	main
nad	doc_491521502062_item	2574194	et	3	main
järgmist	doc_491521502063_item	2574209	et	3	main
ja	doc_491521502063_item	2574211	et	3	main
sulle	doc_491521502063_item	2574216	et	3	main
teed	doc_491521502063_item	2574225	et	4	main
lapsed	doc_491521502063_item	2574227	et	3	main
sõidad	doc_491521502063_item	2574231	et	3	main
kirjutage	doc_491521502063_item	2574233	et	3	main
tere	doc_491521502063_item	2574237	et	3	main
lapsed	doc_491521502063_item	2574241	et	3	main
teksti	doc_491521502064_item	2574252	et	4	main
kirjutage	doc_491521502064_item	2574254	et	3	main
puhkust	doc_491521502064_item	2574260	et	4	main
sind	doc_491521502064_item	2574262	et	4	main
hästi	doc_491521502064_item	2574293	et	3	main
sind	doc_491521502065_item	2574320	et	4	main
venemaale	doc_491521502065_item	2574332	et	4	main
20-25	doc_491521502065_item	2574335	et	2	main
tere	doc_491521502065_item	2574337	et	3	main
ta	doc_491521502065_item	2574346	et	4	main
kiri	doc_491521502067_item	2574468	et	3	main
järgmist	doc_491521502067_item	2574470	et	3	main
sulle	doc_491521502067_item	2574477	et	3	main
sind	doc_491521502067_item	2574481	et	4	main
kuidas	doc_491521502067_item	2574487	et	3	main
elavad	doc_491521502067_item	2574489	et	4	main
sõidad	doc_491521502067_item	2574492	et	3	main
kirjutage	doc_491521502067_item	2574494	et	3	main
vastus	doc_491521502067_item	2574495	et	3	main
sõnaga	doc_491521502067_item	2574497	et	3	main
olen	doc_491521502067_item	2574501	et	3	main
ja	doc_491521502067_item	2574508	et	3	main
valeri	doc_491521502067_item	2574510	et	4	main
head	doc_491521502067_item	2574512	et	4	main
kuidas	doc_491521502067_item	2574519	et	3	main
op	doc_491521502067_item	2574521	et	4	main
i	doc_491521502068_item	2574523	et	4	main
tõlkige	doc_491521502068_item	2574524	et	3	main
taipama	doc_491521502068_item	2574525	et	3	main
соображать	doc_491521502068_item	2574526	et	2	main
hallitama	doc_491521502068_item	2574527	et	3	main
недоверчивый	doc_491521502068_item	2574530	et	2	main
льдом	doc_491521502068_item	2574533	et	2	main
pihustama	doc_491521502068_item	2574534	et	3	main
пшикать	doc_491521502068_item	2574535	et	2	main
lakkama	doc_491521502068_item	2574538	et	3	main
делать	doc_491521502068_item	2574541	et	2	main
kuluma	doc_491521502068_item	2574546	et	3	main
mida	doc_491521502068_item	2574572	et	4	main
pakkuma	doc_491521502068_item	2574582	et	3	main
rääkima	doc_491521502068_item	2574594	et	3	main
vastus	doc_491521502062_item	2574148	et	3	main
soovin	doc_491521502062_item	2574150	et	3	main
head	doc_491521502062_item	2574152	et	4	main
vastus	doc_491521502062_item	2574169	et	3	main
sõnaga	doc_491521502062_item	2574171	et	3	main
teie	doc_491521502062_item	2574173	et	4	main
kirja	doc_491521502062_item	2574174	et	4	main
on	doc_491521502062_item	2574189	et	4	main
õpivad	doc_491521502062_item	2574195	et	3	main
lasteaias	doc_491521502062_item	2574198	et	4	main
teksti	doc_491521502063_item	2574210	et	4	main
kirjutage	doc_491521502063_item	2574212	et	3	main
head	doc_491521502063_item	2574217	et	4	main
puhkust	doc_491521502063_item	2574218	et	4	main
ootan	doc_491521502063_item	2574219	et	3	main
sind	doc_491521502063_item	2574220	et	4	main
endale	doc_491521502063_item	2574221	et	4	main
elavad	doc_491521502063_item	2574228	et	4	main
ja	doc_491521502063_item	2574229	et	3	main
sõidavad	doc_491521502063_item	2574247	et	3	main
kiri	doc_491521502064_item	2574249	et	3	main
järgmist	doc_491521502064_item	2574251	et	3	main
tere	doc_491521502064_item	2574256	et	3	main
sulle	doc_491521502064_item	2574258	et	3	main
endale	doc_491521502064_item	2574263	et	4	main
jarvel	doc_491521502064_item	2574286	et	4	main
lapsed	doc_491521502064_item	2574290	et	3	main
venemaale	doc_491521502064_item	2574295	et	4	main
ma	doc_491521502064_item	2574298	et	3	main
hästi	doc_491521502064_item	2574301	et	3	main
ka	doc_491521502064_item	2574303	et	3	main
sama	doc_491521502064_item	2574305	et	4	main
v	doc_491521502064_item	2574306	et	4	main
kiri	doc_491521502065_item	2574307	et	3	main
lugege	doc_491521502065_item	2574308	et	3	main
vastus	doc_491521502065_item	2574313	et	3	main
head	doc_491521502065_item	2574317	et	4	main
teed	doc_491521502065_item	2574325	et	4	main
kuidas	doc_491521502065_item	2574326	et	3	main
elavad	doc_491521502065_item	2574328	et	4	main
püügi	doc_491521502065_item	2574341	et	4	main
juures	doc_491521502065_item	2574349	et	4	main
teksti	doc_491521502067_item	2574471	et	4	main
ja	doc_491521502067_item	2574472	et	3	main
kirjutage	doc_491521502067_item	2574473	et	3	main
head	doc_491521502067_item	2574478	et	4	main
teed	doc_491521502067_item	2574486	et	4	main
headi	doc_491521502067_item	2574503	et	4	main
lapsed	doc_491521502067_item	2574505	et	3	main
tervis	doc_491521502067_item	2574511	et	3	main
ma	doc_491521502067_item	2574513	et	3	main
tuletud	doc_491521502067_item	2574515	et	4	main
elad	doc_491521502067_item	2574520	et	3	main
kontrolltöö	doc_491521502068_item	2574522	et	4	main
плесневеть	doc_491521502068_item	2574528	et	2	main
umbusklik	doc_491521502068_item	2574529	et	3	main
jäätmed	doc_491521502068_item	2574531	et	3	main
покрываться	doc_491521502068_item	2574532	et	2	main
jõukohane	doc_491521502068_item	2574536	et	4	main
ära	doc_491521502068_item	2574555	et	4	main
minema	doc_491521502068_item	2574556	et	3	main
suletama	doc_491521502068_item	2574570	et	3	main
nõudma	doc_491521502068_item	2574574	et	3	main
nõuti	doc_491521502068_item	2574576	et	3	main
vastus	doc_491521502063_item	2574213	et	3	main
kirjuta	doc_491521502063_item	2574223	et	4	main
millal	doc_491521502063_item	2574230	et	3	main
venemaale	doc_491521502063_item	2574232	et	4	main
20-25	doc_491521502063_item	2574235	et	2	main
ma	doc_491521502063_item	2574238	et	3	main
elan	doc_491521502063_item	2574239	et	3	main
koollis	doc_491521502063_item	2574243	et	4	main
ma	doc_491521502063_item	2574244	et	3	main
töötan	doc_491521502063_item	2574245	et	3	main
ja	doc_491521502064_item	2574253	et	3	main
soovin	doc_491521502064_item	2574257	et	3	main
head	doc_491521502064_item	2574259	et	4	main
ootan	doc_491521502064_item	2574261	et	3	main
meie	doc_491521502064_item	2574289	et	4	main
ei	doc_491521502064_item	2574296	et	4	main
soovin	doc_491521502065_item	2574315	et	3	main
endale	doc_491521502065_item	2574321	et	4	main
lapsed	doc_491521502065_item	2574327	et	3	main
millal	doc_491521502065_item	2574330	et	3	main
kirjutage	doc_491521502065_item	2574333	et	3	main
sõnaga	doc_491521502065_item	2574336	et	3	main
ma	doc_491521502065_item	2574338	et	3	main
maal	doc_491521502065_item	2574350	et	4	main
puhkust	doc_491521502067_item	2574479	et	4	main
endale	doc_491521502067_item	2574482	et	4	main
lapsed	doc_491521502067_item	2574488	et	3	main
ja	doc_491521502067_item	2574490	et	3	main
viktor	doc_491521502067_item	2574499	et	4	main
tüdrug	doc_491521502067_item	2574509	et	4	main
külla	doc_491521502063_item	2574222	et	4	main
venemaale	doc_491521502063_item	2574246	et	4	main
vastus	doc_491521502064_item	2574255	et	3	main
külla	doc_491521502064_item	2574264	et	4	main
mida	doc_491521502064_item	2574266	et	4	main
kirjuta	doc_491521502064_item	2574265	et	4	main
teed	doc_491521502064_item	2574267	et	4	main
kuidas	doc_491521502064_item	2574268	et	3	main
lapsed	doc_491521502064_item	2574269	et	3	main
elavad	doc_491521502064_item	2574270	et	4	main
ja	doc_491521502064_item	2574271	et	3	main
millal	doc_491521502064_item	2574272	et	3	main
sõidad	doc_491521502064_item	2574273	et	3	main
venemaale	doc_491521502064_item	2574274	et	4	main
kirjutage	doc_491521502064_item	2574275	et	3	main
vastus	doc_491521502064_item	2574276	et	3	main
sõnaga	doc_491521502064_item	2574278	et	3	main
20-25	doc_491521502064_item	2574277	et	2	main
mina	doc_491521502064_item	2574279	et	4	main
käin	doc_491521502064_item	2574280	et	3	main
metsas	doc_491521502064_item	2574281	et	3	main
seeni	doc_491521502064_item	2574282	et	3	main
korjamas	doc_491521502064_item	2574283	et	3	main
ja	doc_491521502064_item	2574284	et	3	main
käin	doc_491521502064_item	2574285	et	3	main
kala	doc_491521502064_item	2574287	et	4	main
elavad	doc_491521502064_item	2574291	et	4	main
mina	doc_491521502064_item	2574294	et	4	main
sõida	doc_491521502064_item	2574297	et	4	main
ka	doc_491521502064_item	2574299	et	3	main
sovin	doc_491521502064_item	2574302	et	4	main
teile	doc_491521502064_item	2574304	et	4	main
teksti	doc_491521502065_item	2574310	et	4	main
tere	doc_491521502065_item	2574314	et	3	main
külla	doc_491521502065_item	2574322	et	4	main
ja	doc_491521502065_item	2574329	et	3	main
kain	doc_491521502065_item	2574339	et	3	main
puhkad	doc_491521502065_item	2574347	et	3	main
sõidan	doc_491521502065_item	2574352	et	3	main
ja	doc_491521502065_item	2574354	et	3	main
ostan	doc_491521502065_item	2574355	et	3	main
seal	doc_491521502065_item	2574356	et	4	main
uue	doc_491521502065_item	2574357	et	3	main
auto	doc_491521502065_item	2574358	et	4	main
lugege	doc_491521502067_item	2574469	et	3	main
vastus	doc_491521502067_item	2574474	et	3	main
tere	doc_491521502067_item	2574475	et	3	main
soovin	doc_491521502067_item	2574476	et	3	main
mida	doc_491521502067_item	2574485	et	4	main
tere	doc_491521502067_item	2574498	et	3	main
elad	doc_491521502067_item	2574502	et	3	main
minu	doc_491521502067_item	2574504	et	3	main
vitali	doc_491521502067_item	2574507	et	4	main
kakkuminkake	doc_491521502067_item	2574517	et	4	main
oktombri	doc_491521502067_item	2574518	et	4	main
ära	doc_491521502068_item	2574545	et	4	main
toime	doc_491521502068_item	2574548	et	4	main
собираться	doc_491521502068_item	2574550	et	2	main
ii	doc_491521502068_item	2574551	et	4	main
kirjutage	doc_491521502068_item	2574552	et	3	main
iii	doc_491521502068_item	2574571	et	4	main
üteldi	doc_491521502068_item	2574578	et	3	main
lasati	doc_491521502068_item	2574589	et	4	main
saati	doc_491521502068_item	2574593	et	3	main
kodus	doc_491521502068_item	2574607	et	4	main
prügi	doc_491521502068_item	2574609	et	4	main
värskendav	doc_491521502068_item	2574616	et	4	main
ootan	doc_491521502067_item	2574480	et	3	main
külla	doc_491521502067_item	2574483	et	4	main
kirjuta	doc_491521502067_item	2574484	et	4	main
millal	doc_491521502067_item	2574491	et	3	main
venemaale	doc_491521502067_item	2574493	et	4	main
20-25	doc_491521502067_item	2574496	et	2	main
ma	doc_491521502067_item	2574500	et	3	main
pois	doc_491521502067_item	2574506	et	3	main
olen	doc_491521502067_item	2574514	et	3	main
ja	doc_491521502067_item	2574516	et	3	main
подходящий	doc_491521502068_item	2574537	et	2	main
переставать	doc_491521502068_item	2574539	et	2	main
tõhus	doc_491521502068_item	2574542	et	4	main
правильный	doc_491521502068_item	2574544	et	2	main
изнашиваться	doc_491521502068_item	2574547	et	2	main
tulema	doc_491521502068_item	2574549	et	4	main
tehti	doc_491521502068_item	2574573	et	3	main
anti	doc_491521502068_item	2574581	et	3	main
pakuti	doc_491521502068_item	2574583	et	3	main
tegema	doc_491521502068_item	2574586	et	3	main
laskma	doc_491521502068_item	2574588	et	3	main
saatma	doc_491521502068_item	2574591	et	3	main
räägiti	doc_491521502068_item	2574596	et	3	main
v-kesksõna	doc_491521502068_item	2574601	et	4	main
värskev	doc_491521502068_item	2574614	et	4	main
kes	doc_491521502068_item	2574619	et	4	main
müüv	doc_491521502068_item	2574622	et	4	main
kosmeetikavahendeid	doc_491521502068_item	2574623	et	3	main
pehmev	doc_491521502068_item	2574629	et	4	main
ravivad	doc_491521502068_item	2574634	et	4	main
välismaal	doc_491521502068_item	2574646	et	4	main
süüakse	doc_491521502068_item	2574659	et	3	main
süüatav	doc_491521502068_item	2574660	et	4	main
ostetakse	doc_491521502068_item	2574664	et	3	main
kaup	doc_491521502068_item	2574668	et	3	main
kergesti	doc_491521502068_item	2574674	et	3	main
valed	doc_491521502068_item	2574681	et	3	main
pintsaku	doc_491521502068_item	2574691	et	3	main
artiklid	doc_491521502068_item	2574696	et	3	main
firma	doc_491521502068_item	2574698	et	4	main
järeldusi	doc_491521502068_item	2574716	et	4	main
tagajärgi	doc_491521502068_item	2574717	et	4	main
tulemusi	doc_491521502068_item	2574718	et	4	main
не	doc_491521502068_item	2574724	et	2	main
prügi	doc_491521502068_item	2574726	et	4	main
ei	doc_491521502068_item	2574728	et	4	main
ole	doc_491521502068_item	2574729	et	4	main
время	doc_491521502068_item	2574737	et	2	main
клиентов	doc_491521502068_item	2574745	et	2	main
mainib	doc_491521502068_item	2574748	et	3	main
vabaturgi	doc_491521502068_item	2574758	et	4	main
tingimused	doc_491521502068_item	2574759	et	3	main
дома	doc_491521502068_item	2574764	et	2	main
välja	doc_491521502068_item	2574786	et	4	main
piinlik	doc_491521502068_item	2574791	et	3	main
kui	doc_491521502068_item	2574792	et	3	main
inimesed	doc_491521502068_item	2574793	et	3	main
ei	doc_491521502068_item	2574794	et	4	main
korista	doc_491521502068_item	2574795	et	4	main
vihma	doc_491521502068_item	2574798	et	4	main
lakkamatud	doc_491521502068_item	2574801	et	4	main
hirmus	doc_491521502068_item	2574805	et	4	main
ebameeldiv	doc_491521502068_item	2574810	et	3	main
что-либо	doc_491521502068_item	2574540	et	2	main
хороший	doc_491521502068_item	2574543	et	2	main
ühesõnalised	doc_491521502068_item	2574553	et	4	main
sünonüümid	doc_491521502068_item	2574554	et	3	main
tulema	doc_491521502068_item	2574557	et	4	main
lähema	doc_491521502068_item	2574558	et	4	main
haigeks	doc_491521502068_item	2574559	et	4	main
jääma	doc_491521502068_item	2574560	et	4	main
haigema	doc_491521502068_item	2574561	et	4	main
külmama	doc_491521502068_item	2574562	et	3	main
terveks	doc_491521502068_item	2574563	et	4	main
saama	doc_491521502068_item	2574564	et	4	main
jätma	doc_491521502068_item	2574566	et	3	main
kukkuma	doc_491521502068_item	2574567	et	3	main
maha	doc_491521502068_item	2574565	et	4	main
kinni	doc_491521502068_item	2574568	et	3	main
püüdma	doc_491521502068_item	2574569	et	3	main
nõudati	doc_491521502068_item	2574575	et	4	main
ütlema	doc_491521502068_item	2574577	et	3	main
andati	doc_491521502068_item	2574580	et	4	main
lubama	doc_491521502068_item	2574584	et	3	main
iv	doc_491521502068_item	2574599	et	4	main
kasutage	doc_491521502068_item	2574600	et	3	main
mis	doc_491521502068_item	2574603	et	4	main
kodus	doc_491521502068_item	2574605	et	4	main
tekkiv	doc_491521502068_item	2574608	et	4	main
vahenditeta	doc_491521502068_item	2574610	et	3	main
müüb	doc_491521502068_item	2574620	et	3	main
kosmeetikavahendeid	doc_491521502068_item	2574621	et	3	main
müüv	doc_491521502068_item	2574624	et	4	main
kreem	doc_491521502068_item	2574631	et	3	main
juukse	doc_491521502068_item	2574637	et	3	main
v	doc_491521502068_item	2574640	et	4	main
tav-kesksõna	doc_491521502068_item	2574642	et	4	main
kreemidele	doc_491521502068_item	2574643	et	3	main
toodetakse	doc_491521502068_item	2574645	et	3	main
toodetav	doc_491521502068_item	2574648	et	4	main
kaupu	doc_491521502068_item	2574662	et	3	main
harva	doc_491521502068_item	2574665	et	4	main
kergesti	doc_491521502068_item	2574672	et	3	main
avatav	doc_491521502068_item	2574675	et	4	main
kaane	doc_491521502068_item	2574676	et	4	main
tõmmake	doc_491521502068_item	2574678	et	3	main
alla	doc_491521502068_item	2574680	et	3	main
sõnad	doc_491521502068_item	2574682	et	4	main
suurt	doc_491521502068_item	2574683	et	3	main
koera	doc_491521502068_item	2574684	et	4	main
peaksid	doc_491521502068_item	2574710	et	4	main
rohkem	doc_491521502068_item	2574712	et	4	main
teadvustama	doc_491521502068_item	2574713	et	3	main
keskkonna	doc_491521502068_item	2574714	et	3	main
reostamise	doc_491521502068_item	2574715	et	4	main
andma	doc_491521502068_item	2574579	et	3	main
lubati	doc_491521502068_item	2574585	et	3	main
tehti	doc_491521502068_item	2574587	et	3	main
laskati	doc_491521502068_item	2574590	et	4	main
saadati	doc_491521502068_item	2574592	et	4	main
rääkiti	doc_491521502068_item	2574595	et	4	main
teatama	doc_491521502068_item	2574597	et	4	main
prügi	doc_491521502068_item	2574602	et	4	main
värskendavad	doc_491521502068_item	2574612	et	4	main
vahenditeta	doc_491521502068_item	2574617	et	3	main
inimest	doc_491521502068_item	2574618	et	3	main
mis	doc_491521502068_item	2574627	et	4	main
niisutab	doc_491521502068_item	2574628	et	3	main
mis	doc_491521502068_item	2574633	et	4	main
ravidav	doc_491521502068_item	2574638	et	4	main
mida	doc_491521502068_item	2574670	et	4	main
õmblused	doc_491521502068_item	2574692	et	3	main
kisuvad	doc_491521502068_item	2574694	et	3	main
on	doc_491521502068_item	2574704	et	4	main
система	doc_491521502068_item	2574721	et	2	main
ära	doc_491521502068_item	2574731	et	4	main
по	doc_491521502068_item	2574733	et	2	main
вы	doc_491521502068_item	2574735	et	2	main
aega	doc_491521502068_item	2574742	et	4	main
подарками	doc_491521502068_item	2574746	et	2	main
торговли	doc_491521502068_item	2574754	et	2	main
рынка	doc_491521502068_item	2574756	et	2	main
seeda	doc_491521502068_item	2574757	et	4	main
возможность	doc_491521502068_item	2574763	et	2	main
enda	doc_491521502068_item	2574796	et	4	main
seda	doc_491521502068_item	2574812	et	3	main
teatati	doc_491521502068_item	2574598	et	3	main
tekib	doc_491521502068_item	2574604	et	3	main
tekkiv	doc_491521502068_item	2574606	et	4	main
mis	doc_491521502068_item	2574611	et	4	main
õhku	doc_491521502068_item	2574613	et	4	main
õhku	doc_491521502068_item	2574615	et	4	main
šampoone	doc_491521502068_item	2574632	et	2	main
ravitav	doc_491521502068_item	2574636	et	4	main
šampoone	doc_491521502068_item	2574639	et	2	main
kasutage	doc_491521502068_item	2574641	et	3	main
pesu	doc_491521502068_item	2574650	et	4	main
mida	doc_491521502068_item	2574651	et	4	main
pestakse	doc_491521502068_item	2574652	et	3	main
mida	doc_491521502068_item	2574663	et	4	main
harva	doc_491521502068_item	2574666	et	4	main
ostetav	doc_491521502068_item	2574667	et	4	main
peab	doc_491521502068_item	2574685	et	4	main
kordamööda	doc_491521502068_item	2574686	et	3	main
ilmtingimata	doc_491521502068_item	2574687	et	3	main
omapead	doc_491521502068_item	2574688	et	3	main
õpetama	doc_491521502068_item	2574689	et	3	main
selle	doc_491521502068_item	2574690	et	4	main
plaani	doc_491521502068_item	2574703	et	4	main
liigitada	doc_491521502068_item	2574706	et	3	main
teostada	doc_491521502068_item	2574708	et	3	main
переработки	doc_491521502068_item	2574722	et	2	main
заказывая	doc_491521502068_item	2574732	et	2	main
каталогу	doc_491521502068_item	2574734	et	2	main
te	doc_491521502068_item	2574740	et	4	main
привлекает	doc_491521502068_item	2574744	et	2	main
klientid	doc_491521502068_item	2574749	et	4	main
это	doc_491521502068_item	2574751	et	2	main
у	doc_491521502068_item	2574760	et	2	main
näeb	doc_491521502068_item	2574783	et	3	main
juba	doc_491521502068_item	2574785	et	3	main
on	doc_491521502068_item	2574787	et	4	main
väga	doc_491521502068_item	2574788	et	3	main
piinlik	doc_491521502068_item	2574789	et	3	main
piinliku	doc_491521502068_item	2574790	et	3	main
sajab	doc_491521502068_item	2574799	et	3	main
ajavad	doc_491521502068_item	2574804	et	4	main
hirmuses	doc_491521502068_item	2574806	et	4	main
karva	doc_491521502068_item	2574807	et	4	main
mul	doc_491521502068_item	2574808	et	3	main
on	doc_491521502068_item	2574809	et	4	main
vaadata	doc_491521502068_item	2574813	et	4	main
inimene	doc_491521502068_item	2574625	et	3	main
kreemiga	doc_491521502068_item	2574626	et	4	main
niisutav	doc_491521502068_item	2574630	et	4	main
juukseid	doc_491521502068_item	2574635	et	3	main
mis	doc_491521502068_item	2574644	et	4	main
välismaal	doc_491521502068_item	2574647	et	4	main
kreemi	doc_491521502068_item	2574649	et	4	main
käsitsi	doc_491521502068_item	2574653	et	3	main
käsitsi	doc_491521502068_item	2574654	et	3	main
pestav	doc_491521502068_item	2574655	et	4	main
pesu	doc_491521502068_item	2574656	et	4	main
toidust	doc_491521502068_item	2574657	et	4	main
mida	doc_491521502068_item	2574658	et	4	main
toit	doc_491521502068_item	2574661	et	3	main
kaanega	doc_491521502068_item	2574669	et	3	main
saab	doc_491521502068_item	2574671	et	3	main
avada	doc_491521502068_item	2574673	et	3	main
vi	doc_491521502068_item	2574677	et	4	main
maha	doc_491521502068_item	2574679	et	4	main
käsitsevad	doc_491521502068_item	2574693	et	4	main
luituvad	doc_491521502068_item	2574695	et	4	main
kahjustasid	doc_491521502068_item	2574697	et	4	main
olemust	doc_491521502068_item	2574699	et	3	main
mainet	doc_491521502068_item	2574700	et	4	main
puänti	doc_491521502068_item	2574701	et	4	main
seda	doc_491521502068_item	2574702	et	3	main
raske	doc_491521502068_item	2574705	et	4	main
sisaldada	doc_491521502068_item	2574707	et	3	main
inimesed	doc_491521502068_item	2574709	et	3	main
endale	doc_491521502068_item	2574711	et	4	main
vii	doc_491521502068_item	2574719	et	4	main
tõlkige	doc_491521502068_item	2574720	et	3	main
мусора	doc_491521502068_item	2574723	et	2	main
tehtud	doc_491521502068_item	2574730	et	4	main
katalogi	doc_491521502068_item	2574738	et	4	main
фирма	doc_491521502068_item	2574743	et	2	main
firma	doc_491521502068_item	2574747	et	4	main
kingitusega	doc_491521502068_item	2574750	et	4	main
нарушает	doc_491521502068_item	2574752	et	2	main
принципы	doc_491521502068_item	2574753	et	2	main
свободного	doc_491521502068_item	2574755	et	2	main
есть	doc_491521502068_item	2574762	et	2	main
jube	doc_491521502068_item	2574784	et	4	main
järelt	doc_491521502068_item	2574797	et	4	main
lakkamatu	doc_491521502068_item	2574800	et	4	main
lakkamatult	doc_491521502068_item	2574802	et	4	main
ebameeldiv	doc_491521502068_item	2574811	et	3	main
разработана	doc_491521502068_item	2574725	et	2	main
süsteem	doc_491521502068_item	2574727	et	3	main
экономите	doc_491521502068_item	2574736	et	2	main
tellimiseks	doc_491521502068_item	2574739	et	4	main
lühendate	doc_491521502068_item	2574741	et	3	main
вас	doc_491521502068_item	2574761	et	2	main
спокойно	doc_491521502068_item	2574765	et	2	main
изучить	doc_491521502068_item	2574766	et	2	main
каталог	doc_491521502068_item	2574767	et	2	main
teil	doc_491521502068_item	2574768	et	4	main
on	doc_491521502068_item	2574769	et	4	main
võimalus	doc_491521502068_item	2574770	et	3	main
rahul	doc_491521502068_item	2574771	et	4	main
kodus	doc_491521502068_item	2574772	et	4	main
näidata	doc_491521502068_item	2574773	et	4	main
katalogi	doc_491521502068_item	2574774	et	4	main
viii	doc_491521502068_item	2574775	et	4	main
pange	doc_491521502068_item	2574776	et	4	main
sulgudes	doc_491521502068_item	2574777	et	4	main
olevad	doc_491521502068_item	2574778	et	4	main
sõnad	doc_491521502068_item	2574779	et	4	main
õigesse	doc_491521502068_item	2574780	et	3	main
vormi	doc_491521502068_item	2574781	et	4	main
see	doc_491521502068_item	2574782	et	3	main
kassis	doc_491521502068_item	2574803	et	3	main
kontrolltöö	doc_491521502082_item	2578409	et	4	main
по	doc_491521502082_item	2578419	et	2	main
käed	doc_491521502082_item	2578422	et	3	main
taga	doc_491521502082_item	2578424	et	4	main
3	doc_491521502082_item	2578428	et	2	main
ноги	doc_491521502082_item	2578432	et	2	main
плеч	doc_491521502082_item	2578435	et	2	main
работы	doc_491521502082_item	2578439	et	2	main
karvase	doc_491521502082_item	2578413	et	4	main
с	doc_491521502082_item	2578417	et	2	main
за	doc_491521502082_item	2578426	et	2	main
harki	doc_491521502082_item	2578431	et	4	main
на	doc_491521502082_item	2578433	et	2	main
tunnustama	doc_491521502082_item	2578444	et	3	main
8	doc_491521502082_item	2578449	et	2	main
в	doc_491521502082_item	2578458	et	2	main
eelistama	doc_491521502082_item	2578465	et	3	main
наклоняться	doc_491521502082_item	2578469	et	2	main
liibuvad	doc_491521502082_item	2578471	et	4	main
брюки	doc_491521502082_item	2578474	et	2	main
акушерка	doc_491521502082_item	2578477	et	2	main
takistama	doc_491521502082_item	2578485	et	3	main
asjatundlik	doc_491521502082_item	2578489	et	3	main
ii	doc_491521502082_item	2578491	et	4	main
või	doc_491521502082_item	2578521	et	4	main
по	doc_491521502082_item	2578524	et	2	main
5	doc_491521502082_item	2578527	et	2	main
собой	doc_491521502082_item	2578531	et	2	main
8	doc_491521502082_item	2578551	et	2	main
фирмой	doc_491521502082_item	2578555	et	2	main
tutvusta	doc_491521502082_item	2578557	et	4	main
9	doc_491521502082_item	2578559	et	2	main
sõnad	doc_491521502082_item	2578581	et	4	main
teadlik	doc_491521502082_item	2578583	et	3	main
oma	doc_491521502082_item	2578594	et	4	main
1	doc_491521502082_item	2578412	et	2	main
saapad	doc_491521502082_item	2578415	et	3	main
краям	doc_491521502082_item	2578420	et	2	main
руки	doc_491521502082_item	2578425	et	2	main
paneb	doc_491521502082_item	2578429	et	3	main
haljastustööd	doc_491521502082_item	2578437	et	4	main
puutuma	doc_491521502082_item	2578442	et	4	main
признавать	doc_491521502082_item	2578445	et	2	main
nägema	doc_491521502082_item	2578448	et	3	main
10	doc_491521502082_item	2578456	et	2	main
11	doc_491521502082_item	2578461	et	2	main
12	doc_491521502082_item	2578464	et	2	main
13	doc_491521502082_item	2578467	et	2	main
20	doc_491521502082_item	2578488	et	2	main
i	doc_491521502082_item	2578410	et	4	main
tõlkige	doc_491521502082_item	2578411	et	3	main
äärega	doc_491521502082_item	2578414	et	3	main
сапоги	doc_491521502082_item	2578416	et	2	main
мехом	doc_491521502082_item	2578418	et	2	main
2	doc_491521502082_item	2578421	et	2	main
4	doc_491521502082_item	2578436	et	2	main
5	doc_491521502082_item	2578440	et	2	main
колебаться	doc_491521502082_item	2578451	et	2	main
прямое	doc_491521502082_item	2578454	et	2	main
облегающие	doc_491521502082_item	2578473	et	2	main
ämmaemand	doc_491521502082_item	2578476	et	3	main
reostus	doc_491521502082_item	2578479	et	4	main
teesklema	doc_491521502082_item	2578482	et	3	main
vilets	doc_491521502082_item	2578487	et	3	main
специалист	doc_491521502082_item	2578490	et	2	main
умение	doc_491521502082_item	2578528	et	2	main
разумеется	doc_491521502082_item	2578532	et	2	main
suhelda	doc_491521502082_item	2578534	et	4	main
итоги	doc_491521502082_item	2578538	et	2	main
сезона	doc_491521502082_item	2578540	et	2	main
знакомящий	doc_491521502082_item	2578553	et	2	main
voldik	doc_491521502082_item	2578558	et	3	main
ли	doc_491521502082_item	2578562	et	2	main
tutvub	doc_491521502082_item	2578587	et	3	main
2	doc_491521502082_item	2578590	et	2	main
hooldame	doc_491521502082_item	2578592	et	3	main
töötajate	doc_491521502082_item	2578595	et	4	main
3	doc_491521502082_item	2578597	et	2	main
lobises	doc_491521502082_item	2578600	et	3	main
vaeva	doc_491521502082_item	2578611	et	4	main
korterit	doc_491521502082_item	2578614	et	3	main
haldab	doc_491521502082_item	2578621	et	3	main
firma	doc_491521502082_item	2578624	et	4	main
küsimustikukõmu	doc_491521502082_item	2578637	et	4	main
tema	doc_491521502082_item	2578641	et	4	main
varrukas	doc_491521502082_item	2578643	et	4	main
krae	doc_491521502082_item	2578645	et	4	main
pooleks	doc_491521502082_item	2578647	et	4	main
järeldavadjagunevadhulguvad	doc_491521502082_item	2578651	et	4	main
umbisikuliseks	doc_491521502082_item	2578664	et	4	main
luba	doc_491521502082_item	2578668	et	4	main
lastel	doc_491521502082_item	2578669	et	4	main
teise	doc_491521502082_item	2578700	et	4	main
hinda	doc_491521502082_item	2578706	et	4	main
piisavalt	doc_491521502082_item	2578713	et	4	main
tööandja	doc_491521502082_item	2578715	et	4	main
töölepingu	doc_491521502082_item	2578718	et	4	main
nõusolekul	doc_491521502082_item	2578721	et	3	main
töölepingu	doc_491521502082_item	2578724	et	4	main
9	doc_491521502082_item	2578744	et	2	main
raamatukogus	doc_491521502082_item	2578747	et	4	main
kirjandust	doc_491521502082_item	2578749	et	3	main
tavaliselt	doc_491521502082_item	2578752	et	4	main
asutused	doc_491521502082_item	2578754	et	4	main
järgmiste	doc_491521502082_item	2578761	et	3	main
kirjutage	doc_491521502082_item	2578787	et	3	main
lühendid	doc_491521502082_item	2578791	et	3	main
järgmine	doc_491521502082_item	2578794	et	3	main
nii	doc_491521502082_item	2578799	et	3	main
5	doc_491521502082_item	2578805	et	2	main
moodustage	doc_491521502082_item	2578809	et	3	main
laused	doc_491521502082_item	2578812	et	3	main
te	doc_491521502082_item	2578815	et	4	main
uuest	doc_491521502082_item	2578817	et	3	main
ärge	doc_491521502082_item	2578819	et	3	main
kesklinnaga	doc_491521502082_item	2578836	et	3	main
suhtlete	doc_491521502082_item	2578852	et	3	main
ametnikega	doc_491521502082_item	2578853	et	3	main
on	doc_491521502082_item	2578854	et	4	main
maaklerist	doc_491521502082_item	2578855	et	3	main
moodustage	doc_491521502082_item	2578859	et	3	main
3	doc_491521502082_item	2578885	et	2	main
suur	doc_491521502082_item	2578895	et	3	main
kokku	doc_491521502082_item	2578898	et	3	main
kokkutulemine	doc_491521502082_item	2578900	et	4	main
kirjanik	doc_491521502082_item	2578903	et	3	main
üüring	doc_491521502082_item	2578907	et	4	main
kujundama	doc_491521502082_item	2578909	et	3	main
aed	doc_491521502082_item	2578912	et	3	main
kõneviisi	doc_491521502082_item	2578931	et	4	main
1	doc_491521502082_item	2578932	et	2	main
ärge	doc_491521502082_item	2578934	et	3	main
valetage	doc_491521502082_item	2578935	et	3	main
kukla	doc_491521502082_item	2578423	et	3	main
головой	doc_491521502082_item	2578427	et	2	main
jalad	doc_491521502082_item	2578430	et	3	main
ширине	doc_491521502082_item	2578434	et	2	main
ремонтные	doc_491521502082_item	2578438	et	2	main
kokku	doc_491521502082_item	2578441	et	3	main
9	doc_491521502082_item	2578452	et	2	main
назначение	doc_491521502082_item	2578455	et	2	main
общих	doc_491521502082_item	2578459	et	2	main
rakendust	doc_491521502082_item	2578462	et	4	main
предпочитать	doc_491521502082_item	2578466	et	2	main
14	doc_491521502082_item	2578470	et	2	main
15	doc_491521502082_item	2578475	et	2	main
16	doc_491521502082_item	2578478	et	2	main
17	doc_491521502082_item	2578481	et	2	main
18	doc_491521502082_item	2578484	et	2	main
tõlkige	doc_491521502082_item	2578492	et	3	main
1	doc_491521502082_item	2578493	et	2	main
отпуск	doc_491521502082_item	2578494	et	2	main
проведенный	doc_491521502082_item	2578495	et	2	main
в	doc_491521502082_item	2578496	et	2	main
2	doc_491521502082_item	2578498	et	2	main
товар	doc_491521502082_item	2578499	et	2	main
деревне	doc_491521502082_item	2578497	et	2	main
привезенный	doc_491521502082_item	2578500	et	2	main
с	doc_491521502082_item	2578501	et	2	main
нового	doc_491521502082_item	2578502	et	2	main
оптового	doc_491521502082_item	2578503	et	2	main
склада	doc_491521502082_item	2578504	et	2	main
3	doc_491521502082_item	2578505	et	2	main
не	doc_491521502082_item	2578507	et	2	main
будет	doc_491521502082_item	2578509	et	2	main
договор	doc_491521502082_item	2578510	et	2	main
знаем	doc_491521502082_item	2578508	et	2	main
мы	doc_491521502082_item	2578506	et	2	main
подписан	doc_491521502082_item	2578511	et	2	main
или	doc_491521502082_item	2578512	et	2	main
нет	doc_491521502082_item	2578513	et	2	main
me	doc_491521502082_item	2578514	et	4	main
ei	doc_491521502082_item	2578515	et	4	main
kas	doc_491521502082_item	2578517	et	3	main
leping	doc_491521502082_item	2578518	et	3	main
kirjutaks	doc_491521502082_item	2578519	et	3	main
alla	doc_491521502082_item	2578520	et	3	main
tea	doc_491521502082_item	2578516	et	4	main
mitte	doc_491521502082_item	2578522	et	3	main
случайности	doc_491521502082_item	2578526	et	2	main
само	doc_491521502082_item	2578530	et	2	main
oskus	doc_491521502082_item	2578533	et	3	main
начальник	doc_491521502082_item	2578536	et	2	main
прошедшего	doc_491521502082_item	2578539	et	2	main
6	doc_491521502082_item	2578443	et	2	main
7	doc_491521502082_item	2578446	et	2	main
vaeva	doc_491521502082_item	2578447	et	4	main
kõikuma	doc_491521502082_item	2578450	et	3	main
otstarve	doc_491521502082_item	2578453	et	3	main
üldjoontes	doc_491521502082_item	2578457	et	3	main
чертах	doc_491521502082_item	2578460	et	2	main
leidma	doc_491521502082_item	2578463	et	3	main
kummarduma	doc_491521502082_item	2578468	et	3	main
püksid	doc_491521502082_item	2578472	et	3	main
загрязнять	doc_491521502082_item	2578480	et	2	main
притворяться	doc_491521502082_item	2578483	et	2	main
19	doc_491521502082_item	2578486	et	2	main
eelmisest	doc_491521502082_item	2578543	et	3	main
hojast	doc_491521502082_item	2578544	et	4	main
завоеванный	doc_491521502082_item	2578548	et	2	main
соревнованиях	doc_491521502082_item	2578550	et	2	main
firma	doc_491521502082_item	2578556	et	4	main
знаете	doc_491521502082_item	2578561	et	2	main
sobimatud	doc_491521502082_item	2578580	et	4	main
alati	doc_491521502082_item	2578588	et	4	main
me	doc_491521502082_item	2578591	et	4	main
tööotsija	doc_491521502082_item	2578598	et	4	main
müüa	doc_491521502082_item	2578616	et	3	main
maja	doc_491521502082_item	2578619	et	4	main
4	doc_491521502082_item	2578523	et	2	main
глупой	doc_491521502082_item	2578525	et	2	main
общаться	doc_491521502082_item	2578529	et	2	main
6	doc_491521502082_item	2578535	et	2	main
подвел	doc_491521502082_item	2578537	et	2	main
буклет	doc_491521502082_item	2578552	et	2	main
вы	doc_491521502082_item	2578563	et	2	main
где	doc_491521502082_item	2578564	et	2	main
директор	doc_491521502082_item	2578565	et	2	main
по	doc_491521502082_item	2578566	et	2	main
сбыту	doc_491521502082_item	2578567	et	2	main
ega	doc_491521502082_item	2578568	et	3	main
te	doc_491521502082_item	2578569	et	4	main
ei	doc_491521502082_item	2578570	et	4	main
teakus	doc_491521502082_item	2578571	et	4	main
on	doc_491521502082_item	2578572	et	4	main
10	doc_491521502082_item	2578574	et	2	main
зазубренные	doc_491521502082_item	2578575	et	2	main
слова	doc_491521502082_item	2578576	et	2	main
turundusdirektoor	doc_491521502082_item	2578573	et	4	main
iii	doc_491521502082_item	2578577	et	4	main
kriipsutage	doc_491521502082_item	2578578	et	3	main
maha	doc_491521502082_item	2578579	et	4	main
ülemus	doc_491521502082_item	2578541	et	4	main
tegi	doc_491521502082_item	2578542	et	4	main
kokkulepimine	doc_491521502082_item	2578545	et	4	main
7	doc_491521502082_item	2578546	et	2	main
кубок	doc_491521502082_item	2578547	et	2	main
на	doc_491521502082_item	2578549	et	2	main
с	doc_491521502082_item	2578554	et	2	main
не	doc_491521502082_item	2578560	et	2	main
1	doc_491521502082_item	2578582	et	2	main
üleolevüllatunud	doc_491521502082_item	2578584	et	4	main
t	doc_491521502082_item	2578585	et	4	main
arbija	doc_491521502082_item	2578586	et	4	main
hoolitsemehoolime	doc_491521502082_item	2578593	et	4	main
eest	doc_491521502082_item	2578596	et	4	main
hoidus	doc_491521502082_item	2578601	et	3	main
et	doc_491521502082_item	2578612	et	3	main
seda	doc_491521502082_item	2578613	et	3	main
seda	doc_491521502082_item	2578618	et	3	main
korteriühistu	doc_491521502082_item	2578622	et	4	main
töötajaid	doc_491521502082_item	2578626	et	4	main
seoses	doc_491521502082_item	2578627	et	4	main
uue	doc_491521502082_item	2578628	et	3	main
tootmisliini	doc_491521502082_item	2578629	et	4	main
kehtestamisegakäivitamisega	doc_491521502082_item	2578630	et	4	main
meelitamisega	doc_491521502082_item	2578631	et	4	main
7	doc_491521502082_item	2578632	et	2	main
me	doc_491521502082_item	2578633	et	4	main
ta	doc_491521502082_item	2578657	et	4	main
endist	doc_491521502082_item	2578659	et	4	main
muutke	doc_491521502082_item	2578662	et	3	main
laused	doc_491521502082_item	2578663	et	3	main
seadus	doc_491521502082_item	2578666	et	4	main
tema	doc_491521502082_item	2578707	et	4	main
piisavalt	doc_491521502082_item	2578709	et	4	main
ei	doc_491521502082_item	2578710	et	4	main
hindakse	doc_491521502082_item	2578711	et	4	main
vanema	doc_491521502082_item	2578719	et	4	main
sooduspakkumistega	doc_491521502082_item	2578589	et	3	main
liiga	doc_491521502082_item	2578603	et	4	main
4	doc_491521502082_item	2578605	et	2	main
maakler	doc_491521502082_item	2578606	et	3	main
maha	doc_491521502082_item	2578615	et	4	main
seas	doc_491521502082_item	2578639	et	4	main
konts	doc_491521502082_item	2578644	et	3	main
9	doc_491521502082_item	2578648	et	2	main
noorukid	doc_491521502082_item	2578650	et	3	main
10	doc_491521502082_item	2578653	et	2	main
sellele	doc_491521502082_item	2578655	et	4	main
oma	doc_491521502082_item	2578658	et	4	main
ülemust	doc_491521502082_item	2578660	et	4	main
lastel	doc_491521502082_item	2578674	et	4	main
töötada	doc_491521502082_item	2578675	et	3	main
nad	doc_491521502082_item	2578704	et	3	main
6	doc_491521502082_item	2578714	et	2	main
nõusolekul	doc_491521502082_item	2578727	et	3	main
alla	doc_491521502082_item	2578733	et	3	main
lepingule	doc_491521502082_item	2578735	et	3	main
esinetakse	doc_491521502082_item	2578743	et	3	main
pakutakse	doc_491521502082_item	2578757	et	3	main
moodustage	doc_491521502082_item	2578759	et	3	main
tähendavad	doc_491521502082_item	2578789	et	4	main
n-ö	doc_491521502082_item	2578798	et	4	main
muud	doc_491521502082_item	2578804	et	4	main
oma	doc_491521502082_item	2578821	et	4	main
võimalusi	doc_491521502082_item	2578823	et	3	main
on	doc_491521502082_item	2578837	et	4	main
see	doc_491521502082_item	2578838	et	3	main
korter	doc_491521502082_item	2578839	et	3	main
odav	doc_491521502082_item	2578840	et	3	main
suur	doc_491521502082_item	2578856	et	3	main
nik	doc_491521502082_item	2578861	et	4	main
pärane	doc_491521502082_item	2578863	et	4	main
meetrit	doc_491521502082_item	2578887	et	3	main
4	doc_491521502082_item	2578889	et	2	main
5	doc_491521502082_item	2578892	et	2	main
6	doc_491521502082_item	2578894	et	2	main
üür	doc_491521502082_item	2578906	et	3	main
meel	doc_491521502082_item	2578915	et	4	main
13	doc_491521502082_item	2578917	et	2	main
mainis	doc_491521502082_item	2578599	et	3	main
intervjuul	doc_491521502082_item	2578602	et	3	main
palju	doc_491521502082_item	2578604	et	4	main
lasi	doc_491521502082_item	2578607	et	4	main
läbiajas	doc_491521502082_item	2578608	et	3	main
korda	doc_491521502082_item	2578609	et	4	main
nägi	doc_491521502082_item	2578610	et	3	main
5	doc_491521502082_item	2578617	et	2	main
kerkibkaasneb	doc_491521502082_item	2578620	et	4	main
6	doc_491521502082_item	2578623	et	2	main
otsib	doc_491521502082_item	2578625	et	3	main
8	doc_491521502082_item	2578640	et	2	main
murdus	doc_491521502082_item	2578646	et	3	main
tänavail	doc_491521502082_item	2578652	et	4	main
lisaks	doc_491521502082_item	2578654	et	4	main
rõhutassüüdistasteeskles	doc_491521502082_item	2578656	et	4	main
lubatakse	doc_491521502082_item	2578673	et	4	main
ei	doc_491521502082_item	2578705	et	4	main
tööd	doc_491521502082_item	2578708	et	4	main
lapsega	doc_491521502082_item	2578717	et	3	main
lapsega	doc_491521502082_item	2578723	et	3	main
vanema	doc_491521502082_item	2578725	et	4	main
kirjutab	doc_491521502082_item	2578731	et	3	main
alla	doc_491521502082_item	2578736	et	3	main
ansambel	doc_491521502082_item	2578738	et	3	main
esineb	doc_491521502082_item	2578739	et	3	main
lauludega	doc_491521502082_item	2578742	et	3	main
erialast	doc_491521502082_item	2578748	et	4	main
loetakse	doc_491521502082_item	2578750	et	3	main
v	doc_491521502082_item	2578758	et	4	main
1	doc_491521502082_item	2578763	et	2	main
1	doc_491521502082_item	2578792	et	2	main
2	doc_491521502082_item	2578795	et	2	main
jm	doc_491521502082_item	2578802	et	4	main
nn	doc_491521502082_item	2578806	et	4	main
kui	doc_491521502082_item	2578814	et	3	main
unistate	doc_491521502082_item	2578816	et	3	main
korterist	doc_491521502082_item	2578818	et	3	main
viisime	doc_491521502082_item	2578634	et	4	main
läbi	doc_491521502082_item	2578635	et	4	main
küsitluse	doc_491521502082_item	2578636	et	4	main
tööandjate	doc_491521502082_item	2578638	et	3	main
kinga	doc_491521502082_item	2578642	et	4	main
tegevuseta	doc_491521502082_item	2578649	et	4	main
iv	doc_491521502082_item	2578661	et	4	main
1	doc_491521502082_item	2578665	et	2	main
ei	doc_491521502082_item	2578667	et	4	main
töötada	doc_491521502082_item	2578670	et	3	main
täisajaga	doc_491521502082_item	2578671	et	3	main
ei	doc_491521502082_item	2578672	et	4	main
täisajaga	doc_491521502082_item	2578676	et	3	main
2	doc_491521502082_item	2578677	et	2	main
ametnik	doc_491521502082_item	2578678	et	3	main
võtab	doc_491521502082_item	2578679	et	3	main
teiega	doc_491521502082_item	2578680	et	3	main
ühendust	doc_491521502082_item	2578681	et	4	main
võtakse	doc_491521502082_item	2578682	et	4	main
teiega	doc_491521502082_item	2578683	et	3	main
ühendust	doc_491521502082_item	2578684	et	4	main
3	doc_491521502082_item	2578685	et	2	main
firma	doc_491521502082_item	2578686	et	4	main
teeb	doc_491521502082_item	2578687	et	3	main
mitmesuguseid	doc_491521502082_item	2578688	et	3	main
ehitustöid	doc_491521502082_item	2578689	et	3	main
teakse	doc_491521502082_item	2578690	et	4	main
mitmesuguseid	doc_491521502082_item	2578691	et	3	main
ehitustöid	doc_491521502082_item	2578692	et	3	main
4	doc_491521502082_item	2578693	et	2	main
tihti	doc_491521502082_item	2578694	et	3	main
saadavad	doc_491521502082_item	2578695	et	4	main
ametnikud	doc_491521502082_item	2578696	et	3	main
tööotsijat	doc_491521502082_item	2578697	et	3	main
ühe	doc_491521502082_item	2578698	et	4	main
juurest	doc_491521502082_item	2578699	et	4	main
juurde	doc_491521502082_item	2578701	et	4	main
saadatakse	doc_491521502082_item	2578702	et	3	main
5	doc_491521502082_item	2578703	et	2	main
tööd	doc_491521502082_item	2578712	et	4	main
sõlmib	doc_491521502082_item	2578716	et	3	main
kirjalikul	doc_491521502082_item	2578720	et	3	main
sõlmitakse	doc_491521502082_item	2578722	et	3	main
7	doc_491521502082_item	2578728	et	2	main
firma	doc_491521502082_item	2578729	et	4	main
lepingule	doc_491521502082_item	2578732	et	3	main
kirjutakse	doc_491521502082_item	2578734	et	4	main
8	doc_491521502082_item	2578737	et	2	main
kontserdil	doc_491521502082_item	2578740	et	3	main
uute	doc_491521502082_item	2578741	et	3	main
loeb	doc_491521502082_item	2578746	et	3	main
10	doc_491521502082_item	2578751	et	2	main
pakuvad	doc_491521502082_item	2578753	et	3	main
laused	doc_491521502082_item	2578760	et	3	main
pigistama	doc_491521502082_item	2578785	et	3	main
järgmised	doc_491521502082_item	2578790	et	3	main
va	doc_491521502082_item	2578796	et	3	main
4	doc_491521502082_item	2578801	et	2	main
vii	doc_491521502082_item	2578808	et	4	main
lausetest	doc_491521502082_item	2578810	et	4	main
1	doc_491521502082_item	2578813	et	2	main
unustage	doc_491521502082_item	2578820	et	3	main
kui	doc_491521502082_item	2578825	et	3	main
tähelepanelik	doc_491521502082_item	2578832	et	4	main
kui	doc_491521502082_item	2578834	et	3	main
abi	doc_491521502082_item	2578857	et	4	main
poolmeetriline	doc_491521502082_item	2578888	et	4	main
tootma	doc_491521502082_item	2578893	et	3	main
tulema	doc_491521502082_item	2578899	et	4	main
kiri	doc_491521502082_item	2578902	et	3	main
kirjandus	doc_491521502082_item	2578904	et	3	main
11	doc_491521502082_item	2578911	et	2	main
ruttu	doc_491521502082_item	2578938	et	4	main
2	doc_491521502082_item	2578940	et	2	main
rahu	doc_491521502082_item	2578943	et	4	main
ärge	doc_491521502082_item	2578946	et	3	main
küsimusi	doc_491521502082_item	2578956	et	4	main
hakkage	doc_491521502082_item	2578960	et	4	main
ärge	doc_491521502082_item	2578973	et	3	main
vaatama	doc_491521502082_item	2578976	et	3	main
vaatage	doc_491521502082_item	2578977	et	4	main
silma	doc_491521502082_item	2578979	et	4	main
kõhklema	doc_491521502082_item	2578981	et	3	main
i	doc_491521502083_item	2578993	et	4	main
karvase	doc_491521502083_item	2578996	et	4	main
äärega	doc_491521502083_item	2578997	et	3	main
2	doc_491521502083_item	2579002	et	2	main
taga	doc_491521502083_item	2579005	et	4	main
3	doc_491521502083_item	2579010	et	2	main
haljastustööd	doc_491521502083_item	2579017	et	4	main
признавать	doc_491521502083_item	2579024	et	2	main
замечать	doc_491521502083_item	2579028	et	2	main
kõikuma	doc_491521502083_item	2579033	et	3	main
прямое	doc_491521502083_item	2579037	et	2	main
12	doc_491521502083_item	2579049	et	2	main
13	doc_491521502083_item	2579052	et	2	main
усложнять	doc_491521502083_item	2579055	et	2	main
liibuvad	doc_491521502083_item	2579057	et	4	main
15	doc_491521502083_item	2579061	et	2	main
16	doc_491521502083_item	2579064	et	2	main
17	doc_491521502083_item	2579067	et	2	main
18	doc_491521502083_item	2579069	et	2	main
20	doc_491521502083_item	2579074	et	2	main
ii	doc_491521502083_item	2579077	et	4	main
või	doc_491521502083_item	2579114	et	4	main
случайности	doc_491521502083_item	2579119	et	2	main
rumala	doc_491521502083_item	2579120	et	3	main
juhtliku	doc_491521502083_item	2579121	et	4	main
5	doc_491521502083_item	2579123	et	2	main
само	doc_491521502083_item	2579126	et	2	main
прошедшего	doc_491521502083_item	2579135	et	2	main
завоеванный	doc_491521502083_item	2579139	et	2	main
знакомящий	doc_491521502083_item	2579144	et	2	main
tutavatud	doc_491521502083_item	2579148	et	4	main
знаете	doc_491521502083_item	2579152	et	2	main
ei	doc_491521502083_item	2579161	et	4	main
on	doc_491521502083_item	2579164	et	4	main
kirjalikul	doc_491521502082_item	2578726	et	3	main
juht	doc_491521502082_item	2578730	et	3	main
üliõpilane	doc_491521502082_item	2578745	et	3	main
lapsele	doc_491521502082_item	2578755	et	4	main
abitööd	doc_491521502082_item	2578756	et	4	main
sõnaühenditega	doc_491521502082_item	2578762	et	3	main
paneb	doc_491521502082_item	2578764	et	3	main
piinlikkust	doc_491521502082_item	2578766	et	4	main
mind	doc_491521502082_item	2578765	et	4	main
tundma	doc_491521502082_item	2578767	et	3	main
2	doc_491521502082_item	2578768	et	2	main
ära	doc_491521502082_item	2578769	et	4	main
tüütama	doc_491521502082_item	2578770	et	3	main
ära	doc_491521502082_item	2578771	et	4	main
tüüta	doc_491521502082_item	2578772	et	4	main
mind	doc_491521502082_item	2578773	et	4	main
me	doc_491521502082_item	2578774	et	4	main
kohe	doc_491521502082_item	2578775	et	4	main
tulen	doc_491521502082_item	2578776	et	3	main
tagasi	doc_491521502082_item	2578777	et	3	main
3	doc_491521502082_item	2578778	et	2	main
meelepärane	doc_491521502082_item	2578779	et	4	main
4	doc_491521502082_item	2578780	et	2	main
vihale	doc_491521502082_item	2578781	et	4	main
ajama	doc_491521502082_item	2578782	et	4	main
5	doc_491521502082_item	2578783	et	2	main
rusikasse	doc_491521502082_item	2578784	et	4	main
vi	doc_491521502082_item	2578786	et	4	main
mida	doc_491521502082_item	2578788	et	4	main
jne	doc_491521502082_item	2578793	et	4	main
3	doc_491521502082_item	2578797	et	2	main
öelda	doc_491521502082_item	2578800	et	4	main
ja	doc_491521502082_item	2578803	et	3	main
nii-nii	doc_491521502082_item	2578807	et	3	main
des-lauselühendiga	doc_491521502082_item	2578811	et	3	main
te	doc_491521502082_item	2578826	et	4	main
väga	doc_491521502082_item	2578831	et	3	main
3	doc_491521502082_item	2578833	et	2	main
võrrelda	doc_491521502082_item	2578835	et	4	main
4	doc_491521502082_item	2578841	et	2	main
kui	doc_491521502082_item	2578842	et	3	main
lähete	doc_491521502082_item	2578843	et	4	main
korterit	doc_491521502082_item	2578844	et	3	main
üle	doc_491521502082_item	2578845	et	3	main
vaatama	doc_491521502082_item	2578846	et	3	main
võtke	doc_491521502082_item	2578847	et	3	main
kaasa	doc_491521502082_item	2578848	et	4	main
asjatundja	doc_491521502082_item	2578849	et	4	main
5	doc_491521502082_item	2578850	et	2	main
kui	doc_491521502082_item	2578851	et	3	main
ja	doc_491521502082_item	2578860	et	3	main
valima	doc_491521502082_item	2578883	et	3	main
suurepärane	doc_491521502082_item	2578896	et	4	main
kujundamine	doc_491521502082_item	2578910	et	4	main
aednik	doc_491521502082_item	2578913	et	3	main
meelepärane	doc_491521502082_item	2578916	et	4	main
lepping	doc_491521502082_item	2578919	et	4	main
lepimine	doc_491521502082_item	2578920	et	4	main
14	doc_491521502082_item	2578921	et	2	main
15	doc_491521502082_item	2578924	et	2	main
välja	doc_491521502082_item	2578939	et	4	main
ärge	doc_491521502082_item	2578959	et	3	main
9	doc_491521502082_item	2578980	et	2	main
kõhklge	doc_491521502082_item	2578982	et	4	main
10	doc_491521502082_item	2578985	et	2	main
töökohas	doc_491521502082_item	2578989	et	4	main
levinud	doc_491521502082_item	2578990	et	4	main
с	doc_491521502083_item	2579000	et	2	main
kukla	doc_491521502083_item	2579004	et	3	main
за	doc_491521502083_item	2579008	et	2	main
ноги	doc_491521502083_item	2579015	et	2	main
kokku	doc_491521502083_item	2579019	et	3	main
6	doc_491521502083_item	2579022	et	2	main
обр	doc_491521502083_item	2579030	et	2	main
otstarve	doc_491521502083_item	2579036	et	3	main
общих	doc_491521502083_item	2579042	et	2	main
rakendust	doc_491521502083_item	2579045	et	4	main
eelistama	doc_491521502083_item	2579050	et	3	main
запутывать	doc_491521502083_item	2579054	et	2	main
облегающ	doc_491521502083_item	2579059	et	2	main
акушерка	doc_491521502083_item	2579063	et	2	main
reostus	doc_491521502083_item	2579065	et	4	main
teesklema	doc_491521502083_item	2579068	et	3	main
19	doc_491521502083_item	2579072	et	2	main
tõlkige	doc_491521502083_item	2579078	et	3	main
начальник	doc_491521502083_item	2579132	et	2	main
сезона	doc_491521502083_item	2579136	et	2	main
на	doc_491521502083_item	2579140	et	2	main
с	doc_491521502083_item	2579145	et	2	main
директор	doc_491521502083_item	2579156	et	2	main
10	doc_491521502083_item	2579167	et	2	main
iii	doc_491521502083_item	2579172	et	4	main
maha	doc_491521502083_item	2579174	et	4	main
sõnad	doc_491521502083_item	2579176	et	4	main
1	doc_491521502083_item	2579177	et	2	main
teadliküleolevüllatunud	doc_491521502083_item	2579178	et	4	main
2	doc_491521502083_item	2579183	et	2	main
hoolitseme	doc_491521502083_item	2579186	et	3	main
kehtestamisega	doc_491521502083_item	2579223	et	4	main
me	doc_491521502083_item	2579227	et	4	main
viisime	doc_491521502083_item	2579228	et	4	main
tööandjate	doc_491521502083_item	2579232	et	3	main
8	doc_491521502083_item	2579234	et	2	main
9	doc_491521502083_item	2579242	et	2	main
jagunevad	doc_491521502083_item	2579246	et	4	main
ei	doc_491521502083_item	2579271	et	4	main
võtakse	doc_491521502083_item	2579281	et	4	main
rahalisi	doc_491521502082_item	2578822	et	4	main
2	doc_491521502082_item	2578824	et	2	main
sõlmite	doc_491521502082_item	2578827	et	3	main
uut	doc_491521502082_item	2578828	et	3	main
lepingut	doc_491521502082_item	2578829	et	3	main
olge	doc_491521502082_item	2578830	et	3	main
viii	doc_491521502082_item	2578858	et	4	main
ndus	doc_491521502082_item	2578862	et	4	main
ng	doc_491521502082_item	2578864	et	4	main
k	doc_491521502082_item	2578865	et	4	main
line	doc_491521502082_item	2578866	et	4	main
ne	doc_491521502082_item	2578867	et	4	main
mine	doc_491521502082_item	2578868	et	3	main
või	doc_491521502082_item	2578869	et	4	main
kond-	doc_491521502082_item	2578870	et	4	main
liitelised	doc_491521502082_item	2578871	et	4	main
sõnad	doc_491521502082_item	2578872	et	4	main
ühel	doc_491521502082_item	2578873	et	3	main
sõnal	doc_491521502082_item	2578874	et	3	main
võib	doc_491521502082_item	2578875	et	3	main
olla	doc_491521502082_item	2578876	et	3	main
mitu	doc_491521502082_item	2578877	et	4	main
varianti	doc_491521502082_item	2578878	et	4	main
1	doc_491521502082_item	2578879	et	2	main
õhk	doc_491521502082_item	2578880	et	3	main
õhkkond	doc_491521502082_item	2578881	et	3	main
2	doc_491521502082_item	2578882	et	2	main
valik	doc_491521502082_item	2578884	et	3	main
pool	doc_491521502082_item	2578886	et	4	main
kuus	doc_491521502082_item	2578890	et	4	main
liiget	doc_491521502082_item	2578891	et	3	main
7	doc_491521502082_item	2578897	et	2	main
8	doc_491521502082_item	2578901	et	2	main
9	doc_491521502082_item	2578905	et	2	main
10	doc_491521502082_item	2578908	et	2	main
12	doc_491521502082_item	2578914	et	2	main
leppima	doc_491521502082_item	2578918	et	3	main
valima	doc_491521502082_item	2578922	et	3	main
päeva	doc_491521502082_item	2578926	et	4	main
kasutage	doc_491521502082_item	2578929	et	3	main
säilitage	doc_491521502082_item	2578942	et	3	main
rääkima	doc_491521502082_item	2578945	et	3	main
rääkige	doc_491521502082_item	2578947	et	3	main
hoolikalt	doc_491521502082_item	2578955	et	4	main
8	doc_491521502082_item	2578975	et	2	main
püüdma	doc_491521502082_item	2578986	et	3	main
tõlkige	doc_491521502083_item	2578994	et	3	main
мехом	doc_491521502083_item	2579001	et	2	main
valkond	doc_491521502082_item	2578923	et	4	main
seitse	doc_491521502082_item	2578925	et	3	main
seitsepäevik	doc_491521502082_item	2578927	et	3	main
ix	doc_491521502082_item	2578928	et	4	main
käskivat	doc_491521502082_item	2578930	et	4	main
valetama	doc_491521502082_item	2578933	et	3	main
tuleb	doc_491521502082_item	2578937	et	3	main
3	doc_491521502082_item	2578944	et	2	main
5	doc_491521502082_item	2578957	et	2	main
intervjueerijat	doc_491521502082_item	2578961	et	4	main
pahandama	doc_491521502082_item	2578962	et	3	main
6	doc_491521502082_item	2578963	et	2	main
intervjuu	doc_491521502082_item	2578964	et	4	main
lõpus	doc_491521502082_item	2578965	et	4	main
küsima	doc_491521502082_item	2578966	et	3	main
küsige	doc_491521502082_item	2578967	et	3	main
millal	doc_491521502082_item	2578968	et	3	main
teatatakse	doc_491521502082_item	2578969	et	3	main
tulemused	doc_491521502082_item	2578970	et	3	main
7	doc_491521502082_item	2578971	et	2	main
hilinema	doc_491521502082_item	2578972	et	3	main
see	doc_491521502082_item	2578936	et	3	main
säilitama	doc_491521502082_item	2578941	et	4	main
enda	doc_491521502082_item	2578948	et	4	main
kohta	doc_491521502082_item	2578949	et	4	main
negatiivseid	doc_491521502082_item	2578950	et	3	main
asju	doc_491521502082_item	2578951	et	3	main
4	doc_491521502082_item	2578952	et	2	main
kuulama	doc_491521502082_item	2578953	et	3	main
kuulage	doc_491521502082_item	2578954	et	3	main
hakkama	doc_491521502082_item	2578958	et	3	main
oma	doc_491521502082_item	2578983	et	4	main
võimetes	doc_491521502082_item	2578984	et	4	main
sarnaneda	doc_491521502082_item	2578987	et	3	main
stiiliga	doc_491521502082_item	2578991	et	3	main
kontrolltöö	doc_491521502083_item	2578992	et	4	main
сапоги	doc_491521502083_item	2578999	et	2	main
скреп	doc_491521502083_item	2579007	et	2	main
jalad	doc_491521502083_item	2579012	et	3	main
скрещивать	doc_491521502083_item	2579014	et	2	main
5	doc_491521502083_item	2579018	et	2	main
соприкасаться	doc_491521502083_item	2579021	et	2	main
vaeva	doc_491521502083_item	2579026	et	4	main
nägema	doc_491521502083_item	2579027	et	3	main
8	doc_491521502083_item	2579032	et	2	main
назначение	doc_491521502083_item	2579038	et	2	main
üldjoontes	doc_491521502083_item	2579040	et	3	main
leidma	doc_491521502083_item	2579046	et	3	main
препочитать	doc_491521502083_item	2579051	et	2	main
14	doc_491521502083_item	2579056	et	2	main
püksid	doc_491521502083_item	2579058	et	3	main
возникать	doc_491521502083_item	2579071	et	2	main
asjatundlik	doc_491521502083_item	2579075	et	3	main
собой	doc_491521502083_item	2579127	et	2	main
suhtlelemeoskus	doc_491521502083_item	2579129	et	4	main
6	doc_491521502083_item	2579131	et	2	main
7	doc_491521502083_item	2579137	et	2	main
8	doc_491521502083_item	2579142	et	2	main
9	doc_491521502083_item	2579150	et	2	main
ли	doc_491521502083_item	2579153	et	2	main
по	doc_491521502083_item	2579157	et	2	main
te	doc_491521502083_item	2579160	et	4	main
tea	doc_491521502083_item	2579162	et	4	main
kus	doc_491521502083_item	2579163	et	3	main
слова	doc_491521502083_item	2579169	et	2	main
sõnad	doc_491521502083_item	2579171	et	4	main
alati	doc_491521502083_item	2579181	et	4	main
oma	doc_491521502083_item	2579188	et	4	main
eest	doc_491521502083_item	2579190	et	4	main
tööotsija	doc_491521502083_item	2579192	et	4	main
mainis	doc_491521502083_item	2579193	et	3	main
lobises	doc_491521502083_item	2579194	et	3	main
hilinegi	doc_491521502082_item	2578974	et	4	main
intervjueerijale	doc_491521502082_item	2578978	et	4	main
selles	doc_491521502082_item	2578988	et	4	main
1	doc_491521502083_item	2578995	et	2	main
saapad	doc_491521502083_item	2578998	et	3	main
käed	doc_491521502083_item	2579003	et	3	main
руки	doc_491521502083_item	2579006	et	2	main
спинов	doc_491521502083_item	2579009	et	2	main
paneb	doc_491521502083_item	2579011	et	3	main
harki	doc_491521502083_item	2579013	et	4	main
4	doc_491521502083_item	2579016	et	2	main
puutuma	doc_491521502083_item	2579020	et	4	main
7	doc_491521502083_item	2579025	et	2	main
отм	doc_491521502083_item	2579029	et	2	main
9	doc_491521502083_item	2579035	et	2	main
в	doc_491521502083_item	2579041	et	2	main
11	doc_491521502083_item	2579044	et	2	main
найти	doc_491521502083_item	2579047	et	2	main
kummarduma	doc_491521502083_item	2579053	et	3	main
штаны	doc_491521502083_item	2579060	et	2	main
ämmaemand	doc_491521502083_item	2579062	et	3	main
загрязнение	doc_491521502083_item	2579066	et	2	main
компетентный	doc_491521502083_item	2579076	et	2	main
отпуск	doc_491521502083_item	2579080	et	2	main
умение	doc_491521502083_item	2579124	et	2	main
разумеется	doc_491521502083_item	2579128	et	2	main
enesemõitlev	doc_491521502083_item	2579130	et	4	main
подвел	doc_491521502083_item	2579133	et	2	main
кубок	doc_491521502083_item	2579138	et	2	main
буклет	doc_491521502083_item	2579143	et	2	main
voldnik	doc_491521502083_item	2579147	et	4	main
не	doc_491521502083_item	2579151	et	2	main
где	doc_491521502083_item	2579155	et	2	main
ega	doc_491521502083_item	2579159	et	3	main
зазубренные	doc_491521502083_item	2579168	et	2	main
pahepanetud	doc_491521502083_item	2579170	et	4	main
sooduspakkumistega	doc_491521502083_item	2579182	et	3	main
hoolime	doc_491521502083_item	2579187	et	3	main
töötajate	doc_491521502083_item	2579189	et	4	main
3	doc_491521502083_item	2579191	et	2	main
tootmisliini	doc_491521502083_item	2579222	et	4	main
varrukas	doc_491521502083_item	2579237	et	4	main
konts	doc_491521502083_item	2579238	et	3	main
lisaks	doc_491521502083_item	2579250	et	4	main
ta	doc_491521502083_item	2579255	et	4	main
oma	doc_491521502083_item	2579256	et	4	main
laused	doc_491521502083_item	2579261	et	3	main
1	doc_491521502083_item	2579263	et	2	main
luba	doc_491521502083_item	2579266	et	4	main
uhendust	doc_491521502083_item	2579282	et	4	main
teeb	doc_491521502083_item	2579285	et	3	main
ehitustöid	doc_491521502083_item	2579287	et	3	main
tööotsijat	doc_491521502083_item	2579296	et	3	main
juurest	doc_491521502083_item	2579298	et	4	main
teise	doc_491521502083_item	2579299	et	4	main
teiste	doc_491521502083_item	2579307	et	4	main
hinda	doc_491521502083_item	2579312	et	4	main
töölepingu	doc_491521502083_item	2579325	et	4	main
vanema	doc_491521502083_item	2579332	et	4	main
firma	doc_491521502083_item	2579336	et	4	main
juht	doc_491521502083_item	2579337	et	3	main
kirjutab	doc_491521502083_item	2579338	et	3	main
lepingule	doc_491521502083_item	2579339	et	3	main
alla	doc_491521502083_item	2579340	et	3	main
firmas	doc_491521502083_item	2579341	et	3	main
uute	doc_491521502083_item	2579352	et	3	main
üliõpilane	doc_491521502083_item	2579355	et	3	main
kirjandu	doc_491521502083_item	2579363	et	4	main
pakuvad	doc_491521502083_item	2579366	et	3	main
järgmiste	doc_491521502083_item	2579377	et	3	main
sõnaühenditega	doc_491521502083_item	2579378	et	3	main
piinlikkust	doc_491521502083_item	2579382	et	4	main
panne	doc_491521502083_item	2579385	et	3	main
2	doc_491521502083_item	2579389	et	2	main
edasi	doc_491521502083_item	2579423	et	3	main
vastu	doc_491521502083_item	2579426	et	3	main
jm	doc_491521502083_item	2579432	et	4	main
muu	doc_491521502083_item	2579434	et	4	main
5	doc_491521502083_item	2579435	et	2	main
nn	doc_491521502083_item	2579436	et	4	main
tunnustama	doc_491521502083_item	2579023	et	3	main
вним	doc_491521502083_item	2579031	et	2	main
обобщать	doc_491521502083_item	2579034	et	2	main
10	doc_491521502083_item	2579039	et	2	main
чертах	doc_491521502083_item	2579043	et	2	main
деятельность	doc_491521502083_item	2579048	et	2	main
takistama	doc_491521502083_item	2579070	et	3	main
vilets	doc_491521502083_item	2579073	et	3	main
1	doc_491521502083_item	2579079	et	2	main
в	doc_491521502083_item	2579082	et	2	main
проведенный	doc_491521502083_item	2579081	et	2	main
деревне	doc_491521502083_item	2579083	et	2	main
külas	doc_491521502083_item	2579084	et	3	main
vedanud	doc_491521502083_item	2579085	et	4	main
2	doc_491521502083_item	2579087	et	2	main
товар	doc_491521502083_item	2579088	et	2	main
привезенный	doc_491521502083_item	2579089	et	2	main
с	doc_491521502083_item	2579090	et	2	main
нового	doc_491521502083_item	2579091	et	2	main
оптового	doc_491521502083_item	2579092	et	2	main
склада	doc_491521502083_item	2579093	et	2	main
puhkus	doc_491521502083_item	2579086	et	3	main
uuest	doc_491521502083_item	2579094	et	3	main
hulgilaost	doc_491521502083_item	2579095	et	4	main
tootud	doc_491521502083_item	2579096	et	4	main
kaup	doc_491521502083_item	2579097	et	3	main
3	doc_491521502083_item	2579098	et	2	main
мы	doc_491521502083_item	2579099	et	2	main
не	doc_491521502083_item	2579100	et	2	main
знаем	doc_491521502083_item	2579101	et	2	main
договор	doc_491521502083_item	2579103	et	2	main
подписан	doc_491521502083_item	2579104	et	2	main
или	doc_491521502083_item	2579105	et	2	main
будет	doc_491521502083_item	2579102	et	2	main
нет	doc_491521502083_item	2579106	et	2	main
me	doc_491521502083_item	2579107	et	4	main
ei	doc_491521502083_item	2579108	et	4	main
tea	doc_491521502083_item	2579109	et	4	main
kas	doc_491521502083_item	2579110	et	3	main
leping	doc_491521502083_item	2579111	et	3	main
alla	doc_491521502083_item	2579112	et	3	main
kirjatakse	doc_491521502083_item	2579113	et	4	main
mitte	doc_491521502083_item	2579115	et	3	main
4	doc_491521502083_item	2579116	et	2	main
по	doc_491521502083_item	2579117	et	2	main
глупой	doc_491521502083_item	2579118	et	2	main
järgi	doc_491521502083_item	2579122	et	4	main
общаться	doc_491521502083_item	2579125	et	2	main
итоги	doc_491521502083_item	2579134	et	2	main
соревнованиях	doc_491521502083_item	2579141	et	2	main
фирмой	doc_491521502083_item	2579146	et	2	main
firmaga	doc_491521502083_item	2579149	et	3	main
вы	doc_491521502083_item	2579154	et	2	main
сбыту	doc_491521502083_item	2579158	et	2	main
direktor	doc_491521502083_item	2579166	et	3	main
kriipsutage	doc_491521502083_item	2579173	et	3	main
hooldame	doc_491521502083_item	2579185	et	3	main
hoidus	doc_491521502083_item	2579195	et	3	main
intervjuul	doc_491521502083_item	2579196	et	3	main
liiga	doc_491521502083_item	2579197	et	4	main
palju	doc_491521502083_item	2579198	et	4	main
4	doc_491521502083_item	2579199	et	2	main
maakler	doc_491521502083_item	2579200	et	3	main
lasi	doc_491521502083_item	2579201	et	4	main
läbiajas	doc_491521502083_item	2579202	et	3	main
korda	doc_491521502083_item	2579203	et	4	main
nägi	doc_491521502083_item	2579204	et	3	main
vaeva	doc_491521502083_item	2579205	et	4	main
et	doc_491521502083_item	2579206	et	3	main
seda	doc_491521502083_item	2579207	et	3	main
korterit	doc_491521502083_item	2579208	et	3	main
maha	doc_491521502083_item	2579209	et	4	main
müüa	doc_491521502083_item	2579210	et	3	main
5	doc_491521502083_item	2579211	et	2	main
seda	doc_491521502083_item	2579212	et	3	main
maja	doc_491521502083_item	2579213	et	4	main
kerkibkaasnebhaldab	doc_491521502083_item	2579214	et	4	main
korteriühistu	doc_491521502083_item	2579215	et	4	main
6	doc_491521502083_item	2579216	et	2	main
firma	doc_491521502083_item	2579217	et	4	main
otsib	doc_491521502083_item	2579218	et	3	main
töötajaid	doc_491521502083_item	2579219	et	4	main
seoses	doc_491521502083_item	2579220	et	4	main
uue	doc_491521502083_item	2579221	et	3	main
käivitamisega	doc_491521502083_item	2579224	et	4	main
küsitluse	doc_491521502083_item	2579230	et	4	main
küsimustikukõmu	doc_491521502083_item	2579231	et	4	main
krae	doc_491521502083_item	2579239	et	4	main
murdus	doc_491521502083_item	2579240	et	3	main
pooleks	doc_491521502083_item	2579241	et	4	main
10	doc_491521502083_item	2579249	et	2	main
teeskles	doc_491521502083_item	2579254	et	3	main
umbisikuliseks	doc_491521502083_item	2579262	et	4	main
lubatud	doc_491521502083_item	2579272	et	4	main
töötada	doc_491521502083_item	2579273	et	3	main
taisajaga	doc_491521502083_item	2579274	et	4	main
2	doc_491521502083_item	2579275	et	2	main
mitmesuguseid	doc_491521502083_item	2579290	et	3	main
ametnikud	doc_491521502083_item	2579295	et	3	main
juurde	doc_491521502083_item	2579308	et	4	main
tööd	doc_491521502083_item	2579317	et	4	main
kaubandus	doc_491521502083_item	2579165	et	3	main
sobimatud	doc_491521502083_item	2579175	et	4	main
tarbija	doc_491521502083_item	2579179	et	4	main
tutvub	doc_491521502083_item	2579180	et	3	main
me	doc_491521502083_item	2579184	et	4	main
7	doc_491521502083_item	2579226	et	2	main
läbi	doc_491521502083_item	2579229	et	4	main
hulguvad	doc_491521502083_item	2579247	et	3	main
endist	doc_491521502083_item	2579257	et	4	main
seadus	doc_491521502083_item	2579264	et	4	main
ametnik	doc_491521502083_item	2579276	et	3	main
võtab	doc_491521502083_item	2579277	et	3	main
teiega	doc_491521502083_item	2579278	et	3	main
ühendust	doc_491521502083_item	2579279	et	4	main
3	doc_491521502083_item	2579283	et	2	main
firmas	doc_491521502083_item	2579288	et	3	main
tihti	doc_491521502083_item	2579293	et	3	main
ametniku	doc_491521502083_item	2579305	et	3	main
nad	doc_491521502083_item	2579310	et	3	main
tema	doc_491521502083_item	2579316	et	4	main
6	doc_491521502083_item	2579321	et	2	main
vanema	doc_491521502083_item	2579326	et	4	main
sõlmitakse	doc_491521502083_item	2579330	et	3	main
allkirjutakse	doc_491521502083_item	2579342	et	4	main
uute	doc_491521502083_item	2579348	et	3	main
erialast	doc_491521502083_item	2579362	et	4	main
lapsele	doc_491521502083_item	2579368	et	4	main
tavaliselt	doc_491521502083_item	2579370	et	4	main
pakutakse	doc_491521502083_item	2579371	et	3	main
v	doc_491521502083_item	2579374	et	4	main
laused	doc_491521502083_item	2579376	et	3	main
mind	doc_491521502083_item	2579386	et	4	main
va	doc_491521502083_item	2579425	et	3	main
n-ö	doc_491521502083_item	2579428	et	4	main
4	doc_491521502083_item	2579431	et	2	main
ja	doc_491521502083_item	2579433	et	3	main
nimetav	doc_491521502083_item	2579438	et	4	main
lausetest	doc_491521502083_item	2579441	et	4	main
laused	doc_491521502083_item	2579443	et	3	main
kui	doc_491521502083_item	2579445	et	3	main
rahalisi	doc_491521502083_item	2579453	et	4	main
unustage	doc_491521502083_item	2579459	et	3	main
sõlmite	doc_491521502083_item	2579466	et	3	main
see	doc_491521502083_item	2579489	et	3	main
kui	doc_491521502083_item	2579493	et	3	main
maaklerist	doc_491521502083_item	2579513	et	3	main
või	doc_491521502083_item	2579533	et	4	main
ühel	doc_491521502083_item	2579537	et	3	main
mitu	doc_491521502083_item	2579541	et	4	main
varianti	doc_491521502083_item	2579542	et	4	main
1	doc_491521502083_item	2579543	et	2	main
3	doc_491521502083_item	2579549	et	2	main
4	doc_491521502083_item	2579553	et	2	main
5	doc_491521502083_item	2579557	et	2	main
6	doc_491521502083_item	2579560	et	2	main
kokku	doc_491521502083_item	2579564	et	3	main
8	doc_491521502083_item	2579567	et	2	main
9	doc_491521502083_item	2579571	et	2	main
uurinik	doc_491521502083_item	2579573	et	4	main
15	doc_491521502083_item	2579589	et	2	main
5	doc_491521502083_item	2579622	et	2	main
intervjueerijat	doc_491521502083_item	2579625	et	4	main
pahandama	doc_491521502083_item	2579626	et	3	main
arge	doc_491521502083_item	2579637	et	3	main
vaatama	doc_491521502083_item	2579640	et	3	main
sarnaneda	doc_491521502083_item	2579653	et	3	main
сапоги	doc_491521502084_item	2579665	et	2	main
пушистым	doc_491521502084_item	2579667	et	2	main
за	doc_491521502084_item	2579675	et	2	main
3	doc_491521502084_item	2579678	et	2	main
jalad	doc_491521502084_item	2579680	et	3	main
чертах	doc_491521502084_item	2579711	et	2	main
leidma	doc_491521502084_item	2579714	et	3	main
12	doc_491521502084_item	2579717	et	2	main
предпочитать	doc_491521502084_item	2579719	et	2	main
kummarduma	doc_491521502084_item	2579721	et	3	main
püksid	doc_491521502084_item	2579725	et	3	main
15	doc_491521502084_item	2579728	et	2	main
17	doc_491521502084_item	2579733	et	2	main
18	doc_491521502084_item	2579736	et	2	main
препятствовать	doc_491521502084_item	2579738	et	2	main
20	doc_491521502084_item	2579742	et	2	main
meelitamisega	doc_491521502083_item	2579225	et	4	main
seas	doc_491521502083_item	2579233	et	4	main
tema	doc_491521502083_item	2579235	et	4	main
kinga	doc_491521502083_item	2579236	et	4	main
tegevuseta	doc_491521502083_item	2579243	et	4	main
noorukid	doc_491521502083_item	2579244	et	3	main
järeldavad	doc_491521502083_item	2579245	et	4	main
tänavail	doc_491521502083_item	2579248	et	4	main
sellele	doc_491521502083_item	2579251	et	4	main
rõhutas	doc_491521502083_item	2579252	et	3	main
süüdistas	doc_491521502083_item	2579253	et	3	main
ülemust	doc_491521502083_item	2579258	et	4	main
iv	doc_491521502083_item	2579259	et	4	main
muutke	doc_491521502083_item	2579260	et	3	main
ei	doc_491521502083_item	2579265	et	4	main
lastel	doc_491521502083_item	2579267	et	4	main
töötada	doc_491521502083_item	2579268	et	3	main
täisajaga	doc_491521502083_item	2579269	et	3	main
lastel	doc_491521502083_item	2579270	et	4	main
teiega	doc_491521502083_item	2579280	et	3	main
4	doc_491521502083_item	2579292	et	2	main
saadavad	doc_491521502083_item	2579294	et	4	main
ühe	doc_491521502083_item	2579297	et	4	main
uhe	doc_491521502083_item	2579304	et	4	main
uurest	doc_491521502083_item	2579306	et	3	main
5	doc_491521502083_item	2579309	et	2	main
ei	doc_491521502083_item	2579311	et	4	main
tema	doc_491521502083_item	2579313	et	4	main
tööd	doc_491521502083_item	2579314	et	4	main
ei	doc_491521502083_item	2579318	et	4	main
hinnatud	doc_491521502083_item	2579319	et	4	main
tööandja	doc_491521502083_item	2579322	et	4	main
nõusolekul	doc_491521502083_item	2579328	et	3	main
8	doc_491521502083_item	2579344	et	2	main
kontserdil	doc_491521502083_item	2579347	et	3	main
lauludega	doc_491521502083_item	2579349	et	3	main
kontserdil	doc_491521502083_item	2579350	et	3	main
9	doc_491521502083_item	2579354	et	2	main
kirjandust	doc_491521502083_item	2579359	et	3	main
tavaliselt	doc_491521502083_item	2579365	et	4	main
mind	doc_491521502083_item	2579381	et	4	main
tundma	doc_491521502083_item	2579383	et	3	main
tundma	doc_491521502083_item	2579388	et	3	main
firma	doc_491521502083_item	2579284	et	4	main
mitmesuguseid	doc_491521502083_item	2579286	et	3	main
tehekse	doc_491521502083_item	2579289	et	4	main
ehitustöid	doc_491521502083_item	2579291	et	3	main
juurde	doc_491521502083_item	2579300	et	4	main
tihti	doc_491521502083_item	2579301	et	3	main
seadatakse	doc_491521502083_item	2579302	et	4	main
tööotsijat	doc_491521502083_item	2579303	et	3	main
piisavalt	doc_491521502083_item	2579315	et	4	main
piisavalt	doc_491521502083_item	2579320	et	4	main
sõlmib	doc_491521502083_item	2579323	et	3	main
kirjalikul	doc_491521502083_item	2579327	et	3	main
lepingule	doc_491521502083_item	2579343	et	3	main
lauludega	doc_491521502083_item	2579353	et	3	main
loeb	doc_491521502083_item	2579356	et	3	main
erialast	doc_491521502083_item	2579358	et	4	main
loetakse	doc_491521502083_item	2579361	et	3	main
10	doc_491521502083_item	2579364	et	2	main
asutused	doc_491521502083_item	2579367	et	4	main
abitööd	doc_491521502083_item	2579369	et	4	main
abitööd	doc_491521502083_item	2579373	et	4	main
moodustage	doc_491521502083_item	2579375	et	3	main
1	doc_491521502083_item	2579379	et	2	main
ärge	doc_491521502083_item	2579384	et	3	main
piinlikus	doc_491521502083_item	2579387	et	4	main
tüütama	doc_491521502083_item	2579391	et	3	main
ära	doc_491521502083_item	2579392	et	4	main
tüüta	doc_491521502083_item	2579393	et	4	main
oma	doc_491521502083_item	2579394	et	4	main
jutu	doc_491521502083_item	2579395	et	3	main
3	doc_491521502083_item	2579396	et	2	main
meelepärane	doc_491521502083_item	2579397	et	4	main
see	doc_491521502083_item	2579398	et	3	main
sündmus	doc_491521502083_item	2579399	et	3	main
oli	doc_491521502083_item	2579400	et	3	main
päris	doc_491521502083_item	2579401	et	4	main
meeleparane	doc_491521502083_item	2579402	et	4	main
4	doc_491521502083_item	2579403	et	2	main
vihale	doc_491521502083_item	2579404	et	4	main
ajama	doc_491521502083_item	2579405	et	4	main
äbaõgustus	doc_491521502083_item	2579406	et	4	main
ajab	doc_491521502083_item	2579407	et	3	main
mind	doc_491521502083_item	2579408	et	4	main
vihale	doc_491521502083_item	2579409	et	4	main
5	doc_491521502083_item	2579410	et	2	main
rusikasse	doc_491521502083_item	2579411	et	4	main
pigistama	doc_491521502083_item	2579412	et	3	main
vi	doc_491521502083_item	2579413	et	4	main
kirjutage	doc_491521502083_item	2579414	et	3	main
mida	doc_491521502083_item	2579415	et	4	main
tähendavad	doc_491521502083_item	2579416	et	4	main
järgmised	doc_491521502083_item	2579417	et	3	main
lühendid	doc_491521502083_item	2579418	et	3	main
1	doc_491521502083_item	2579419	et	2	main
jne	doc_491521502083_item	2579420	et	4	main
oldakse	doc_491521502083_item	2579430	et	4	main
moodustage	doc_491521502083_item	2579440	et	3	main
korterist	doc_491521502083_item	2579449	et	3	main
oma	doc_491521502083_item	2579452	et	4	main
korterist	doc_491521502083_item	2579457	et	3	main
2	doc_491521502083_item	2579463	et	2	main
lapsega	doc_491521502083_item	2579324	et	3	main
lapsega	doc_491521502083_item	2579329	et	3	main
töölepingu	doc_491521502083_item	2579331	et	4	main
kirjalikku	doc_491521502083_item	2579333	et	4	main
nõusolekul	doc_491521502083_item	2579334	et	3	main
7	doc_491521502083_item	2579335	et	2	main
ansambel	doc_491521502083_item	2579345	et	3	main
esineb	doc_491521502083_item	2579346	et	3	main
esinetakse	doc_491521502083_item	2579351	et	3	main
raamatukogus	doc_491521502083_item	2579357	et	4	main
raamatuskogus	doc_491521502083_item	2579360	et	4	main
lapsele	doc_491521502083_item	2579372	et	4	main
paneb	doc_491521502083_item	2579380	et	3	main
ära	doc_491521502083_item	2579390	et	4	main
ja	doc_491521502083_item	2579421	et	3	main
vii	doc_491521502083_item	2579439	et	4	main
unistate	doc_491521502083_item	2579447	et	3	main
uuest	doc_491521502083_item	2579456	et	3	main
oma	doc_491521502083_item	2579460	et	4	main
rahalisi	doc_491521502083_item	2579461	et	4	main
üle	doc_491521502083_item	2579496	et	3	main
on	doc_491521502083_item	2579512	et	4	main
ametnikega	doc_491521502083_item	2579516	et	3	main
maaklerist	doc_491521502083_item	2579518	et	3	main
suur	doc_491521502083_item	2579520	et	3	main
ng	doc_491521502083_item	2579528	et	4	main
k	doc_491521502083_item	2579529	et	4	main
liitelised	doc_491521502083_item	2579535	et	4	main
sõnad	doc_491521502083_item	2579536	et	4	main
võib	doc_491521502083_item	2579539	et	3	main
kuueliigmeline	doc_491521502083_item	2579556	et	4	main
kirjanik	doc_491521502083_item	2579569	et	3	main
10	doc_491521502083_item	2579574	et	2	main
11	doc_491521502083_item	2579577	et	2	main
aianik	doc_491521502083_item	2579579	et	4	main
meel	doc_491521502083_item	2579581	et	4	main
13	doc_491521502083_item	2579583	et	2	main
leppima	doc_491521502083_item	2579584	et	3	main
leping	doc_491521502083_item	2579585	et	3	main
7	doc_491521502083_item	2579635	et	2	main
8	doc_491521502083_item	2579639	et	2	main
intervjueerijale	doc_491521502083_item	2579642	et	4	main
võimetes	doc_491521502083_item	2579649	et	4	main
10	doc_491521502083_item	2579650	et	2	main
püüdma	doc_491521502083_item	2579651	et	3	main
2	doc_491521502084_item	2579670	et	2	main
taga	doc_491521502084_item	2579673	et	4	main
положить	doc_491521502084_item	2579677	et	2	main
выход	doc_491521502084_item	2579716	et	2	main
eelistama	doc_491521502084_item	2579718	et	3	main
nii	doc_491521502083_item	2579422	et	3	main
2	doc_491521502083_item	2579424	et	2	main
3	doc_491521502083_item	2579427	et	2	main
nii	doc_491521502083_item	2579429	et	3	main
nõnda	doc_491521502083_item	2579437	et	3	main
des-lauselühendiga	doc_491521502083_item	2579442	et	3	main
1	doc_491521502083_item	2579444	et	2	main
te	doc_491521502083_item	2579446	et	4	main
unustage	doc_491521502083_item	2579451	et	3	main
võimalusi	doc_491521502083_item	2579454	et	3	main
võimalusi	doc_491521502083_item	2579462	et	3	main
te	doc_491521502083_item	2579465	et	4	main
uut	doc_491521502083_item	2579467	et	3	main
väga	doc_491521502083_item	2579470	et	3	main
tähelepanelik	doc_491521502083_item	2579471	et	4	main
solmides	doc_491521502083_item	2579472	et	4	main
uut	doc_491521502083_item	2579473	et	3	main
lepingut	doc_491521502083_item	2579474	et	3	main
olge	doc_491521502083_item	2579475	et	3	main
väga	doc_491521502083_item	2579476	et	3	main
tahelepanelik	doc_491521502083_item	2579477	et	3	main
3	doc_491521502083_item	2579478	et	2	main
kui	doc_491521502083_item	2579479	et	3	main
võrrelda	doc_491521502083_item	2579480	et	4	main
kesklinnaga	doc_491521502083_item	2579481	et	3	main
on	doc_491521502083_item	2579482	et	4	main
see	doc_491521502083_item	2579483	et	3	main
korter	doc_491521502083_item	2579484	et	3	main
odav	doc_491521502083_item	2579485	et	3	main
võrreldes	doc_491521502083_item	2579486	et	3	main
kesklinnaga	doc_491521502083_item	2579487	et	3	main
uuest	doc_491521502083_item	2579448	et	3	main
ärge	doc_491521502083_item	2579450	et	3	main
unistades	doc_491521502083_item	2579455	et	3	main
arge	doc_491521502083_item	2579458	et	3	main
kui	doc_491521502083_item	2579464	et	3	main
olge	doc_491521502083_item	2579469	et	3	main
odav	doc_491521502083_item	2579491	et	3	main
lähete	doc_491521502083_item	2579494	et	4	main
minnes	doc_491521502083_item	2579501	et	3	main
üle	doc_491521502083_item	2579503	et	3	main
kassa	doc_491521502083_item	2579506	et	4	main
asjatundja	doc_491521502083_item	2579507	et	4	main
abi	doc_491521502083_item	2579521	et	4	main
ndus	doc_491521502083_item	2579526	et	4	main
ne	doc_491521502083_item	2579531	et	4	main
mine	doc_491521502083_item	2579532	et	3	main
pool	doc_491521502083_item	2579550	et	4	main
kuus	doc_491521502083_item	2579554	et	4	main
toodang	doc_491521502083_item	2579559	et	3	main
kokkutulek	doc_491521502083_item	2579566	et	3	main
lepingut	doc_491521502083_item	2579468	et	3	main
korterit	doc_491521502083_item	2579495	et	3	main
võtke	doc_491521502083_item	2579498	et	3	main
asjatundja	doc_491521502083_item	2579500	et	4	main
vaatama	doc_491521502083_item	2579504	et	3	main
5	doc_491521502083_item	2579508	et	2	main
kui	doc_491521502083_item	2579509	et	3	main
suhtlete	doc_491521502083_item	2579510	et	3	main
ametnikega	doc_491521502083_item	2579511	et	3	main
abi	doc_491521502083_item	2579515	et	4	main
suheldes	doc_491521502083_item	2579517	et	3	main
on	doc_491521502083_item	2579519	et	4	main
on	doc_491521502083_item	2579488	et	4	main
korter	doc_491521502083_item	2579490	et	3	main
4	doc_491521502083_item	2579492	et	2	main
vaatama	doc_491521502083_item	2579497	et	3	main
kaasa	doc_491521502083_item	2579499	et	4	main
korterit	doc_491521502083_item	2579502	et	3	main
võtke	doc_491521502083_item	2579505	et	3	main
suur	doc_491521502083_item	2579514	et	3	main
pärane	doc_491521502083_item	2579527	et	4	main
õhk	doc_491521502083_item	2579544	et	3	main
õhkond	doc_491521502083_item	2579545	et	4	main
2	doc_491521502083_item	2579546	et	2	main
valima	doc_491521502083_item	2579547	et	3	main
valik	doc_491521502083_item	2579548	et	3	main
poolemetrid	doc_491521502083_item	2579552	et	4	main
liiget	doc_491521502083_item	2579555	et	3	main
suureparane	doc_491521502083_item	2579562	et	4	main
kujundama	doc_491521502083_item	2579575	et	3	main
aed	doc_491521502083_item	2579578	et	3	main
12	doc_491521502083_item	2579580	et	2	main
meeleparane	doc_491521502083_item	2579582	et	4	main
14	doc_491521502083_item	2579586	et	2	main
valima	doc_491521502083_item	2579587	et	3	main
valimine	doc_491521502083_item	2579588	et	4	main
lõpus	doc_491521502083_item	2579629	et	4	main
küsima	doc_491521502083_item	2579630	et	3	main
küsige	doc_491521502083_item	2579631	et	3	main
millal	doc_491521502083_item	2579632	et	3	main
teatatakse	doc_491521502083_item	2579633	et	3	main
vaadake	doc_491521502083_item	2579641	et	3	main
9	doc_491521502083_item	2579644	et	2	main
kõhklema	doc_491521502083_item	2579645	et	3	main
arge	doc_491521502083_item	2579646	et	3	main
kõhklege	doc_491521502083_item	2579647	et	4	main
oma	doc_491521502083_item	2579648	et	4	main
selles	doc_491521502083_item	2579654	et	4	main
levinud	doc_491521502083_item	2579656	et	4	main
stiiliga	doc_491521502083_item	2579657	et	3	main
меховым	doc_491521502084_item	2579669	et	2	main
kukla	doc_491521502084_item	2579672	et	3	main
голову	doc_491521502084_item	2579676	et	2	main
paneb	doc_491521502084_item	2579679	et	3	main
harki	doc_491521502084_item	2579681	et	4	main
общих	doc_491521502084_item	2579710	et	2	main
liibuvad	doc_491521502084_item	2579724	et	4	main
брюки	doc_491521502084_item	2579727	et	2	main
16	doc_491521502084_item	2579731	et	2	main
teesklema	doc_491521502084_item	2579734	et	3	main
19	doc_491521502084_item	2579739	et	2	main
знающий	doc_491521502084_item	2579745	et	2	main
tõlkige	doc_491521502084_item	2579747	et	3	main
проведенный	doc_491521502084_item	2579750	et	2	main
деревне	doc_491521502084_item	2579752	et	2	main
puhkus	doc_491521502084_item	2579755	et	3	main
hulgilaost	doc_491521502084_item	2579764	et	4	main
kaup	doc_491521502084_item	2579766	et	3	main
не	doc_491521502084_item	2579769	et	2	main
договор	doc_491521502084_item	2579772	et	2	main
rumale	doc_491521502084_item	2579790	et	4	main
само	doc_491521502084_item	2579796	et	2	main
начальник	doc_491521502084_item	2579801	et	2	main
7	doc_491521502084_item	2579807	et	2	main
võidetud	doc_491521502084_item	2579812	et	4	main
buklett	doc_491521502084_item	2579822	et	4	main
сбыту	doc_491521502084_item	2579831	et	2	main
üleolevüllatunud	doc_491521502084_item	2579851	et	4	main
me	doc_491521502084_item	2579857	et	4	main
töötajate	doc_491521502084_item	2579862	et	4	main
tööotsija	doc_491521502084_item	2579865	et	4	main
mainis	doc_491521502084_item	2579866	et	3	main
lobises	doc_491521502084_item	2579867	et	3	main
hoidus	doc_491521502084_item	2579868	et	3	main
intervjuul	doc_491521502084_item	2579869	et	3	main
maakler	doc_491521502084_item	2579873	et	3	main
korda	doc_491521502084_item	2579877	et	4	main
et	doc_491521502084_item	2579880	et	3	main
korterit	doc_491521502084_item	2579882	et	3	main
sellele	doc_491521502084_item	2579925	et	4	main
oma	doc_491521502084_item	2579934	et	4	main
seadus	doc_491521502084_item	2579942	et	4	main
lastel	doc_491521502084_item	2579950	et	4	main
viii	doc_491521502083_item	2579522	et	4	main
moodustage	doc_491521502083_item	2579523	et	3	main
ja	doc_491521502083_item	2579524	et	3	main
nik	doc_491521502083_item	2579525	et	4	main
line	doc_491521502083_item	2579530	et	4	main
kond-	doc_491521502083_item	2579534	et	4	main
sõnal	doc_491521502083_item	2579538	et	3	main
olla	doc_491521502083_item	2579540	et	3	main
meetrit	doc_491521502083_item	2579551	et	3	main
tootma	doc_491521502083_item	2579558	et	3	main
suur	doc_491521502083_item	2579561	et	3	main
7	doc_491521502083_item	2579563	et	2	main
tulema	doc_491521502083_item	2579565	et	4	main
kiri	doc_491521502083_item	2579568	et	3	main
kirjandus	doc_491521502083_item	2579570	et	3	main
üür	doc_491521502083_item	2579572	et	3	main
kujundaja	doc_491521502083_item	2579576	et	4	main
seitse	doc_491521502083_item	2579590	et	3	main
päeva	doc_491521502083_item	2579591	et	4	main
seitsepaivane	doc_491521502083_item	2579592	et	4	main
ix	doc_491521502083_item	2579593	et	4	main
kasutage	doc_491521502083_item	2579594	et	3	main
käskivat	doc_491521502083_item	2579595	et	4	main
kõneviisi	doc_491521502083_item	2579596	et	4	main
1	doc_491521502083_item	2579597	et	2	main
valetama	doc_491521502083_item	2579598	et	3	main
arge	doc_491521502083_item	2579599	et	3	main
valetage	doc_491521502083_item	2579600	et	3	main
see	doc_491521502083_item	2579601	et	3	main
tuleb	doc_491521502083_item	2579602	et	3	main
ruttu	doc_491521502083_item	2579603	et	4	main
välja	doc_491521502083_item	2579604	et	4	main
2	doc_491521502083_item	2579605	et	2	main
säilitama	doc_491521502083_item	2579606	et	4	main
säilitage	doc_491521502083_item	2579607	et	3	main
rahu	doc_491521502083_item	2579608	et	4	main
3	doc_491521502083_item	2579609	et	2	main
rääkima	doc_491521502083_item	2579610	et	3	main
arge	doc_491521502083_item	2579611	et	3	main
rääkige	doc_491521502083_item	2579612	et	3	main
enda	doc_491521502083_item	2579613	et	4	main
kohta	doc_491521502083_item	2579614	et	4	main
negatiivseid	doc_491521502083_item	2579615	et	3	main
asju	doc_491521502083_item	2579616	et	3	main
4	doc_491521502083_item	2579617	et	2	main
kuulama	doc_491521502083_item	2579618	et	3	main
kuulake	doc_491521502083_item	2579619	et	4	main
hoolikalt	doc_491521502083_item	2579620	et	4	main
küsimusi	doc_491521502083_item	2579621	et	4	main
tulemused	doc_491521502083_item	2579634	et	3	main
hilinema	doc_491521502083_item	2579636	et	3	main
hakkama	doc_491521502083_item	2579623	et	3	main
hakkage	doc_491521502083_item	2579624	et	4	main
6	doc_491521502083_item	2579627	et	2	main
intervjuu	doc_491521502083_item	2579628	et	4	main
hilinege	doc_491521502083_item	2579638	et	3	main
puudke	doc_491521502083_item	2579652	et	4	main
töökohas	doc_491521502083_item	2579655	et	4	main
kontrolltöö	doc_491521502084_item	2579658	et	4	main
i	doc_491521502084_item	2579659	et	4	main
tõlkige	doc_491521502084_item	2579660	et	3	main
1	doc_491521502084_item	2579661	et	2	main
käed	doc_491521502084_item	2579671	et	3	main
нога	doc_491521502084_item	2579682	et	2	main
на	doc_491521502084_item	2579683	et	2	main
ногу	doc_491521502084_item	2579684	et	2	main
4	doc_491521502084_item	2579685	et	2	main
haljastustööd	doc_491521502084_item	2579686	et	4	main
озеленение	doc_491521502084_item	2579687	et	2	main
5	doc_491521502084_item	2579688	et	2	main
kokku	doc_491521502084_item	2579689	et	3	main
соприкасаться	doc_491521502084_item	2579691	et	2	main
6	doc_491521502084_item	2579692	et	2	main
tunnustama	doc_491521502084_item	2579693	et	3	main
puutuma	doc_491521502084_item	2579690	et	4	main
предсказывать	doc_491521502084_item	2579694	et	2	main
7	doc_491521502084_item	2579695	et	2	main
vaeva	doc_491521502084_item	2579696	et	4	main
nägema	doc_491521502084_item	2579697	et	3	main
с	doc_491521502084_item	2579698	et	2	main
трудом	doc_491521502084_item	2579699	et	2	main
заметить	doc_491521502084_item	2579700	et	2	main
8	doc_491521502084_item	2579701	et	2	main
kõikuma	doc_491521502084_item	2579702	et	3	main
кончаться	doc_491521502084_item	2579703	et	2	main
9	doc_491521502084_item	2579704	et	2	main
otstarve	doc_491521502084_item	2579705	et	3	main
целесообразный	doc_491521502084_item	2579706	et	2	main
10	doc_491521502084_item	2579707	et	2	main
üldjoontes	doc_491521502084_item	2579708	et	3	main
в	doc_491521502084_item	2579709	et	2	main
11	doc_491521502084_item	2579712	et	2	main
silma	doc_491521502083_item	2579643	et	4	main
karvase	doc_491521502084_item	2579662	et	4	main
äärega	doc_491521502084_item	2579663	et	3	main
saapad	doc_491521502084_item	2579664	et	3	main
с	doc_491521502084_item	2579666	et	2	main
краем	doc_491521502084_item	2579668	et	2	main
руки	doc_491521502084_item	2579674	et	2	main
преклоняться	doc_491521502084_item	2579722	et	2	main
теща	doc_491521502084_item	2579730	et	2	main
скудный	doc_491521502084_item	2579741	et	2	main
деловой	doc_491521502084_item	2579744	et	2	main
товар	doc_491521502084_item	2579757	et	2	main
оптового	doc_491521502084_item	2579761	et	2	main
мы	doc_491521502084_item	2579768	et	2	main
будет	doc_491521502084_item	2579771	et	2	main
или	doc_491521502084_item	2579774	et	2	main
умение	doc_491521502084_item	2579794	et	2	main
прошедшего	doc_491521502084_item	2579804	et	2	main
завоеванный	doc_491521502084_item	2579809	et	2	main
с	doc_491521502084_item	2579818	et	2	main
tutvuv	doc_491521502084_item	2579820	et	4	main
не	doc_491521502084_item	2579824	et	2	main
вы	doc_491521502084_item	2579827	et	2	main
ei	doc_491521502084_item	2579834	et	4	main
on	doc_491521502084_item	2579837	et	4	main
слова	doc_491521502084_item	2579841	et	2	main
iii	doc_491521502084_item	2579844	et	4	main
alati	doc_491521502084_item	2579854	et	4	main
sooduspakkumistega	doc_491521502084_item	2579855	et	3	main
hoolime	doc_491521502084_item	2579860	et	3	main
läbi	doc_491521502084_item	2579875	et	4	main
vaeva	doc_491521502084_item	2579879	et	4	main
seda	doc_491521502084_item	2579881	et	3	main
maha	doc_491521502084_item	2579883	et	4	main
müüa	doc_491521502084_item	2579884	et	3	main
seda	doc_491521502084_item	2579886	et	3	main
hulguvad	doc_491521502084_item	2579921	et	3	main
rõhutas	doc_491521502084_item	2579926	et	3	main
teeskles	doc_491521502084_item	2579928	et	3	main
endist	doc_491521502084_item	2579931	et	4	main
ülemust	doc_491521502084_item	2579932	et	4	main
süüdistakse	doc_491521502084_item	2579933	et	4	main
lastel	doc_491521502084_item	2579945	et	4	main
töötada	doc_491521502084_item	2579946	et	3	main
täisajaga	doc_491521502084_item	2579947	et	3	main
ei	doc_491521502084_item	2579948	et	4	main
lubata	doc_491521502084_item	2579949	et	3	main
teiega	doc_491521502084_item	2579956	et	3	main
teiega	doc_491521502084_item	2579958	et	3	main
piisavalt	doc_491521502084_item	2579990	et	4	main
vanema	doc_491521502084_item	2580001	et	4	main
kirjalikul	doc_491521502084_item	2580002	et	3	main
töölepingu	doc_491521502084_item	2580006	et	4	main
kirjalikul	doc_491521502084_item	2580008	et	3	main
alla	doc_491521502084_item	2580018	et	3	main
rakendust	doc_491521502084_item	2579713	et	4	main
найти	doc_491521502084_item	2579715	et	2	main
13	doc_491521502084_item	2579720	et	2	main
блестящие	doc_491521502084_item	2579726	et	2	main
maal	doc_491521502084_item	2579753	et	4	main
привезенный	doc_491521502084_item	2579758	et	2	main
нет	doc_491521502084_item	2579775	et	2	main
ei	doc_491521502084_item	2579777	et	4	main
kirjutatakse	doc_491521502084_item	2579780	et	3	main
juhuse	doc_491521502084_item	2579791	et	3	main
общаться	doc_491521502084_item	2579795	et	2	main
suhtlemisoskus	doc_491521502084_item	2579799	et	3	main
итоги	doc_491521502084_item	2579803	et	2	main
соревнованиях	doc_491521502084_item	2579811	et	2	main
võistlustel	doc_491521502084_item	2579813	et	3	main
8	doc_491521502084_item	2579815	et	2	main
знакомящий	doc_491521502084_item	2579817	et	2	main
директор	doc_491521502084_item	2579829	et	2	main
ega	doc_491521502084_item	2579832	et	3	main
10	doc_491521502084_item	2579839	et	2	main
tuubitud	doc_491521502084_item	2579842	et	4	main
kriipsutage	doc_491521502084_item	2579845	et	3	main
maha	doc_491521502084_item	2579846	et	4	main
tutvub	doc_491521502084_item	2579853	et	3	main
2	doc_491521502084_item	2579856	et	2	main
liiga	doc_491521502084_item	2579870	et	4	main
lasi	doc_491521502084_item	2579874	et	4	main
nägi	doc_491521502084_item	2579878	et	3	main
maja	doc_491521502084_item	2579887	et	4	main
14	doc_491521502084_item	2579723	et	2	main
ämmaemand	doc_491521502084_item	2579729	et	3	main
reostus	doc_491521502084_item	2579732	et	4	main
притворяться	doc_491521502084_item	2579735	et	2	main
takistama	doc_491521502084_item	2579737	et	3	main
vilets	doc_491521502084_item	2579740	et	3	main
asjatundlik	doc_491521502084_item	2579743	et	3	main
ii	doc_491521502084_item	2579746	et	4	main
1	doc_491521502084_item	2579748	et	2	main
в	doc_491521502084_item	2579751	et	2	main
отпуск	doc_491521502084_item	2579749	et	2	main
veedetud	doc_491521502084_item	2579754	et	4	main
2	doc_491521502084_item	2579756	et	2	main
нового	doc_491521502084_item	2579760	et	2	main
uuest	doc_491521502084_item	2579763	et	3	main
toodud	doc_491521502084_item	2579765	et	4	main
3	doc_491521502084_item	2579767	et	2	main
знаем	doc_491521502084_item	2579770	et	2	main
подписан	doc_491521502084_item	2579773	et	2	main
me	doc_491521502084_item	2579776	et	4	main
tea	doc_491521502084_item	2579778	et	4	main
lepingule	doc_491521502084_item	2579781	et	3	main
alla	doc_491521502084_item	2579782	et	3	main
või	doc_491521502084_item	2579783	et	4	main
mitte	doc_491521502084_item	2579784	et	3	main
по	doc_491521502084_item	2579786	et	2	main
случайности	doc_491521502084_item	2579788	et	2	main
juhuslikult	doc_491521502084_item	2579789	et	4	main
pärast	doc_491521502084_item	2579792	et	4	main
собой	doc_491521502084_item	2579797	et	2	main
подвел	doc_491521502084_item	2579802	et	2	main
juhataja	doc_491521502084_item	2579806	et	4	main
firmaga	doc_491521502084_item	2579821	et	3	main
знаете	doc_491521502084_item	2579825	et	2	main
где	doc_491521502084_item	2579828	et	2	main
te	doc_491521502084_item	2579833	et	4	main
tea	doc_491521502084_item	2579835	et	4	main
kus	doc_491521502084_item	2579836	et	3	main
зазубренные	doc_491521502084_item	2579840	et	2	main
sõnad	doc_491521502084_item	2579843	et	4	main
tarbija	doc_491521502084_item	2579852	et	4	main
hooldame	doc_491521502084_item	2579858	et	3	main
oma	doc_491521502084_item	2579861	et	4	main
eest	doc_491521502084_item	2579863	et	4	main
3	doc_491521502084_item	2579864	et	2	main
4	doc_491521502084_item	2579872	et	2	main
lisaks	doc_491521502084_item	2579924	et	4	main
ta	doc_491521502084_item	2579929	et	4	main
ülemust	doc_491521502084_item	2579936	et	4	main
luba	doc_491521502084_item	2579944	et	4	main
täisajaga	doc_491521502084_item	2579952	et	3	main
ühendust	doc_491521502084_item	2579957	et	4	main
ühendust	doc_491521502084_item	2579960	et	4	main
mitmesuguseid	doc_491521502084_item	2579964	et	3	main
mitmesuguseid	doc_491521502084_item	2579967	et	3	main
tööandja	doc_491521502084_item	2579997	et	4	main
sõlmib	doc_491521502084_item	2579998	et	3	main
lapsega	doc_491521502084_item	2579999	et	3	main
töölepingu	doc_491521502084_item	2580000	et	4	main
7	doc_491521502084_item	2580010	et	2	main
juht	doc_491521502084_item	2580012	et	3	main
kirjutatakse	doc_491521502084_item	2580016	et	3	main
ansambel	doc_491521502084_item	2580020	et	3	main
kontserdil	doc_491521502084_item	2580022	et	3	main
uute	doc_491521502084_item	2580027	et	3	main
lauludega	doc_491521502084_item	2580028	et	3	main
loeb	doc_491521502084_item	2580031	et	3	main
kirjandust	doc_491521502084_item	2580034	et	3	main
erialast	doc_491521502084_item	2580037	et	4	main
kirjandust	doc_491521502084_item	2580038	et	3	main
v	doc_491521502084_item	2580049	et	4	main
järgmiste	doc_491521502084_item	2580052	et	3	main
2	doc_491521502084_item	2580067	et	2	main
tüütas	doc_491521502084_item	2580072	et	3	main
meelepärane	doc_491521502084_item	2580076	et	4	main
4	doc_491521502084_item	2580081	et	2	main
5	doc_491521502084_item	2580092	et	2	main
mees	doc_491521502084_item	2580096	et	4	main
järgmised	doc_491521502084_item	2580104	et	3	main
n-ö	doc_491521502084_item	2580121	et	4	main
ja	doc_491521502084_item	2580128	et	3	main
и	doc_491521502084_item	2580130	et	2	main
nn	doc_491521502084_item	2580134	et	4	main
nimetatud	doc_491521502084_item	2580136	et	4	main
называемый	doc_491521502084_item	2580138	et	2	main
vii	doc_491521502084_item	2580139	et	4	main
moodustage	doc_491521502084_item	2580140	et	3	main
ärge	doc_491521502084_item	2580150	et	3	main
oma	doc_491521502084_item	2580152	et	4	main
võimalusi	doc_491521502084_item	2580154	et	3	main
unistades	doc_491521502084_item	2580155	et	3	main
с	doc_491521502084_item	2579759	et	2	main
склада	doc_491521502084_item	2579762	et	2	main
kas	doc_491521502084_item	2579779	et	3	main
4	doc_491521502084_item	2579785	et	2	main
глупой	doc_491521502084_item	2579787	et	2	main
5	doc_491521502084_item	2579793	et	2	main
разумеется	doc_491521502084_item	2579798	et	2	main
6	doc_491521502084_item	2579800	et	2	main
сезона	doc_491521502084_item	2579805	et	2	main
кубок	doc_491521502084_item	2579808	et	2	main
на	doc_491521502084_item	2579810	et	2	main
kuubok	doc_491521502084_item	2579814	et	4	main
буклет	doc_491521502084_item	2579816	et	2	main
фирмой	doc_491521502084_item	2579819	et	2	main
9	doc_491521502084_item	2579823	et	2	main
ли	doc_491521502084_item	2579826	et	2	main
по	doc_491521502084_item	2579830	et	2	main
turundusdirektor	doc_491521502084_item	2579838	et	3	main
sobimatud	doc_491521502084_item	2579847	et	4	main
sõnad	doc_491521502084_item	2579848	et	4	main
1	doc_491521502084_item	2579849	et	2	main
teadlik	doc_491521502084_item	2579850	et	3	main
hoolitseme	doc_491521502084_item	2579859	et	3	main
palju	doc_491521502084_item	2579871	et	4	main
ajas	doc_491521502084_item	2579876	et	4	main
5	doc_491521502084_item	2579885	et	2	main
kerkibkaasneb	doc_491521502084_item	2579888	et	4	main
haldab	doc_491521502084_item	2579889	et	3	main
korteriühistu	doc_491521502084_item	2579890	et	4	main
6	doc_491521502084_item	2579891	et	2	main
firma	doc_491521502084_item	2579892	et	4	main
otsib	doc_491521502084_item	2579893	et	3	main
töötajaid	doc_491521502084_item	2579894	et	4	main
seoses	doc_491521502084_item	2579895	et	4	main
uue	doc_491521502084_item	2579896	et	3	main
tootmisliini	doc_491521502084_item	2579897	et	4	main
kehtestamisega	doc_491521502084_item	2579898	et	4	main
käivitamisega	doc_491521502084_item	2579899	et	4	main
meelitamisega	doc_491521502084_item	2579900	et	4	main
7	doc_491521502084_item	2579901	et	2	main
me	doc_491521502084_item	2579902	et	4	main
viisime	doc_491521502084_item	2579903	et	4	main
läbi	doc_491521502084_item	2579904	et	4	main
küsitluse	doc_491521502084_item	2579905	et	4	main
küsimustikukõmu	doc_491521502084_item	2579906	et	4	main
tööandjate	doc_491521502084_item	2579907	et	3	main
seas	doc_491521502084_item	2579908	et	4	main
8	doc_491521502084_item	2579909	et	2	main
tema	doc_491521502084_item	2579910	et	4	main
kinga	doc_491521502084_item	2579911	et	4	main
varrukas	doc_491521502084_item	2579912	et	4	main
konts	doc_491521502084_item	2579913	et	3	main
krae	doc_491521502084_item	2579914	et	4	main
murdus	doc_491521502084_item	2579915	et	3	main
pooleks	doc_491521502084_item	2579916	et	4	main
9	doc_491521502084_item	2579917	et	2	main
tegevuseta	doc_491521502084_item	2579918	et	4	main
noorukid	doc_491521502084_item	2579919	et	3	main
järeldavadjagunevad	doc_491521502084_item	2579920	et	4	main
10	doc_491521502084_item	2579923	et	2	main
endist	doc_491521502084_item	2579935	et	4	main
tänavail	doc_491521502084_item	2579922	et	4	main
süüdistas	doc_491521502084_item	2579927	et	3	main
oma	doc_491521502084_item	2579930	et	4	main
iv	doc_491521502084_item	2579937	et	4	main
muutke	doc_491521502084_item	2579938	et	3	main
laused	doc_491521502084_item	2579939	et	3	main
umbisikuliseks	doc_491521502084_item	2579940	et	4	main
1	doc_491521502084_item	2579941	et	2	main
võtab	doc_491521502084_item	2579955	et	3	main
võetakse	doc_491521502084_item	2579959	et	3	main
firma	doc_491521502084_item	2579962	et	4	main
ehitustöid	doc_491521502084_item	2579965	et	3	main
ehitustöid	doc_491521502084_item	2579968	et	3	main
tihti	doc_491521502084_item	2579970	et	3	main
ametnikud	doc_491521502084_item	2579972	et	3	main
tööotsijat	doc_491521502084_item	2579973	et	3	main
ühe	doc_491521502084_item	2579974	et	4	main
juurest	doc_491521502084_item	2579975	et	4	main
teise	doc_491521502084_item	2579976	et	4	main
tööotsijat	doc_491521502084_item	2579978	et	3	main
saadetakse	doc_491521502084_item	2579979	et	3	main
juurde	doc_491521502084_item	2579977	et	4	main
ühe	doc_491521502084_item	2579980	et	4	main
juurest	doc_491521502084_item	2579981	et	4	main
teise	doc_491521502084_item	2579982	et	4	main
juurde	doc_491521502084_item	2579983	et	4	main
5	doc_491521502084_item	2579984	et	2	main
nad	doc_491521502084_item	2579985	et	3	main
ei	doc_491521502084_item	2579986	et	4	main
hinda	doc_491521502084_item	2579987	et	4	main
tema	doc_491521502084_item	2579988	et	4	main
tööd	doc_491521502084_item	2579989	et	4	main
ei	doc_491521502084_item	2579943	et	4	main
ametnik	doc_491521502084_item	2579954	et	3	main
tema	doc_491521502084_item	2579993	et	4	main
tööd	doc_491521502084_item	2579994	et	4	main
6	doc_491521502084_item	2579996	et	2	main
nõusolekul	doc_491521502084_item	2580003	et	3	main
lapsega	doc_491521502084_item	2580005	et	3	main
vanema	doc_491521502084_item	2580007	et	4	main
nõusolekul	doc_491521502084_item	2580009	et	3	main
kirjutab	doc_491521502084_item	2580013	et	3	main
alla	doc_491521502084_item	2580015	et	3	main
lepingule	doc_491521502084_item	2580017	et	3	main
8	doc_491521502084_item	2580019	et	2	main
esineb	doc_491521502084_item	2580021	et	3	main
uute	doc_491521502084_item	2580023	et	3	main
esinetakse	doc_491521502084_item	2580025	et	3	main
raamatukogus	doc_491521502084_item	2580032	et	4	main
lapsele	doc_491521502084_item	2580043	et	4	main
abitööd	doc_491521502084_item	2580044	et	4	main
tavaliselt	doc_491521502084_item	2580045	et	4	main
laused	doc_491521502084_item	2580051	et	3	main
piinlikkust	doc_491521502084_item	2580065	et	4	main
tundma	doc_491521502084_item	2580066	et	3	main
ära	doc_491521502084_item	2580074	et	4	main
ei	doc_491521502084_item	2580090	et	4	main
pigistama	doc_491521502084_item	2580094	et	3	main
mida	doc_491521502084_item	2580102	et	4	main
1	doc_491521502084_item	2580106	et	2	main
ja	doc_491521502084_item	2580108	et	3	main
так	doc_491521502084_item	2580112	et	2	main
nii	doc_491521502084_item	2580122	et	3	main
так	doc_491521502084_item	2580124	et	2	main
jm	doc_491521502084_item	2580127	et	4	main
muud	doc_491521502084_item	2580129	et	4	main
te	doc_491521502084_item	2580146	et	4	main
unistate	doc_491521502084_item	2580147	et	3	main
sõlmite	doc_491521502084_item	2580166	et	3	main
väga	doc_491521502084_item	2580170	et	3	main
kaasa	doc_491521502084_item	2580206	et	4	main
kui	doc_491521502084_item	2580209	et	3	main
ametnikega	doc_491521502084_item	2580211	et	3	main
abi	doc_491521502084_item	2580215	et	4	main
suheldes	doc_491521502084_item	2580216	et	3	main
ametnikega	doc_491521502084_item	2580217	et	3	main
on	doc_491521502084_item	2580218	et	4	main
maaklerist	doc_491521502084_item	2580219	et	3	main
suur	doc_491521502084_item	2580220	et	3	main
töötada	doc_491521502084_item	2579951	et	3	main
2	doc_491521502084_item	2579953	et	2	main
3	doc_491521502084_item	2579961	et	2	main
teeb	doc_491521502084_item	2579963	et	3	main
tehakse	doc_491521502084_item	2579966	et	3	main
4	doc_491521502084_item	2579969	et	2	main
saadavad	doc_491521502084_item	2579971	et	4	main
ei	doc_491521502084_item	2579991	et	4	main
sõlmitakse	doc_491521502084_item	2580004	et	3	main
firma	doc_491521502084_item	2580011	et	4	main
lepingule	doc_491521502084_item	2580014	et	3	main
kontserdil	doc_491521502084_item	2580026	et	3	main
erialast	doc_491521502084_item	2580033	et	4	main
loetakse	doc_491521502084_item	2580035	et	3	main
paneb	doc_491521502084_item	2580062	et	3	main
ära	doc_491521502084_item	2580068	et	4	main
töö	doc_491521502084_item	2580071	et	4	main
mind	doc_491521502084_item	2580073	et	4	main
see	doc_491521502084_item	2580077	et	3	main
oli	doc_491521502084_item	2580079	et	3	main
jõua	doc_491521502084_item	2580091	et	4	main
vihane	doc_491521502084_item	2580095	et	4	main
pigistas	doc_491521502084_item	2580097	et	3	main
käed	doc_491521502084_item	2580098	et	3	main
kirjutage	doc_491521502084_item	2580101	et	3	main
jne	doc_491521502084_item	2580107	et	4	main
и	doc_491521502084_item	2580111	et	2	main
2	doc_491521502084_item	2580114	et	2	main
öelda	doc_491521502084_item	2580123	et	4	main
ое	doc_491521502084_item	2580132	et	2	main
lausetest	doc_491521502084_item	2580141	et	4	main
des-lauselühendiga	doc_491521502084_item	2580142	et	3	main
laused	doc_491521502084_item	2580143	et	3	main
1	doc_491521502084_item	2580144	et	2	main
kui	doc_491521502084_item	2580145	et	3	main
unustage	doc_491521502084_item	2580151	et	3	main
rahalisi	doc_491521502084_item	2580153	et	4	main
uut	doc_491521502084_item	2580167	et	3	main
tähelepanelik	doc_491521502084_item	2580171	et	4	main
uut	doc_491521502084_item	2580173	et	3	main
lepingut	doc_491521502084_item	2580174	et	3	main
olge	doc_491521502084_item	2580175	et	3	main
5	doc_491521502084_item	2580208	et	2	main
suhtlete	doc_491521502084_item	2580210	et	3	main
on	doc_491521502084_item	2580212	et	4	main
maaklerist	doc_491521502084_item	2580213	et	3	main
suur	doc_491521502084_item	2580214	et	3	main
nik	doc_491521502084_item	2580225	et	4	main
pärane	doc_491521502084_item	2580227	et	4	main
kond-	doc_491521502084_item	2580234	et	4	main
sõnal	doc_491521502084_item	2580238	et	3	main
mitu	doc_491521502084_item	2580241	et	4	main
2	doc_491521502084_item	2580246	et	2	main
valima	doc_491521502084_item	2580247	et	3	main
valik	doc_491521502084_item	2580248	et	3	main
valimine	doc_491521502084_item	2580249	et	4	main
pool	doc_491521502084_item	2580251	et	4	main
meetrit	doc_491521502084_item	2580252	et	3	main
poolmeetrine	doc_491521502084_item	2580253	et	4	main
9	doc_491521502084_item	2580274	et	2	main
üür	doc_491521502084_item	2580275	et	3	main
üürnik	doc_491521502084_item	2580276	et	3	main
10	doc_491521502084_item	2580277	et	2	main
kujundus	doc_491521502084_item	2580279	et	4	main
kasutage	doc_491521502084_item	2580299	et	3	main
kõneviisi	doc_491521502084_item	2580301	et	4	main
valetama	doc_491521502084_item	2580303	et	3	main
valeta	doc_491521502084_item	2580304	et	4	main
välja	doc_491521502084_item	2580309	et	4	main
säilitama	doc_491521502084_item	2580311	et	4	main
kohta	doc_491521502084_item	2580320	et	4	main
kuula	doc_491521502084_item	2580325	et	4	main
intervjuu	doc_491521502084_item	2580336	et	4	main
lõpus	doc_491521502084_item	2580337	et	4	main
küsima	doc_491521502084_item	2580338	et	3	main
teatatakse	doc_491521502084_item	2580342	et	3	main
silma	doc_491521502084_item	2580353	et	4	main
võimetes	doc_491521502084_item	2580359	et	4	main
püüa	doc_491521502084_item	2580362	et	4	main
selles	doc_491521502084_item	2580365	et	4	main
töökohas	doc_491521502084_item	2580366	et	4	main
karvase	doc_491521502085_item	2580373	et	4	main
hinnata	doc_491521502084_item	2579992	et	4	main
piisavalt	doc_491521502084_item	2579995	et	4	main
lauludega	doc_491521502084_item	2580024	et	3	main
9	doc_491521502084_item	2580029	et	2	main
moodustage	doc_491521502084_item	2580050	et	3	main
sõnaühenditega	doc_491521502084_item	2580053	et	3	main
paneb	doc_491521502084_item	2580055	et	3	main
piinlikkust	doc_491521502084_item	2580057	et	4	main
tundma	doc_491521502084_item	2580058	et	3	main
üks	doc_491521502084_item	2580059	et	3	main
sõber	doc_491521502084_item	2580061	et	3	main
see	doc_491521502084_item	2580070	et	3	main
vihale	doc_491521502084_item	2580086	et	4	main
kui	doc_491521502084_item	2580087	et	3	main
ma	doc_491521502084_item	2580088	et	3	main
midage	doc_491521502084_item	2580089	et	4	main
rusikasse	doc_491521502084_item	2580093	et	4	main
rusikasse	doc_491521502084_item	2580099	et	4	main
tähendavad	doc_491521502084_item	2580103	et	4	main
lühendid	doc_491521502084_item	2580105	et	3	main
nii	doc_491521502084_item	2580109	et	3	main
edasi	doc_491521502084_item	2580110	et	3	main
далее	doc_491521502084_item	2580113	et	2	main
va	doc_491521502084_item	2580115	et	3	main
arvatud	doc_491521502084_item	2580117	et	4	main
исключением	doc_491521502084_item	2580119	et	2	main
üliõpilane	doc_491521502084_item	2580030	et	3	main
raamatukogus	doc_491521502084_item	2580036	et	4	main
10	doc_491521502084_item	2580039	et	2	main
tavaliselt	doc_491521502084_item	2580040	et	4	main
pakuvad	doc_491521502084_item	2580041	et	3	main
asutused	doc_491521502084_item	2580042	et	4	main
pakutakse	doc_491521502084_item	2580046	et	3	main
lapsele	doc_491521502084_item	2580047	et	4	main
abitööd	doc_491521502084_item	2580048	et	4	main
1	doc_491521502084_item	2580054	et	2	main
mind	doc_491521502084_item	2580056	et	4	main
minu	doc_491521502084_item	2580060	et	3	main
mind	doc_491521502084_item	2580063	et	4	main
alati	doc_491521502084_item	2580064	et	4	main
tüütama	doc_491521502084_item	2580069	et	3	main
3	doc_491521502084_item	2580075	et	2	main
film	doc_491521502084_item	2580078	et	3	main
meelepärane	doc_491521502084_item	2580080	et	4	main
vihale	doc_491521502084_item	2580082	et	4	main
ajama	doc_491521502084_item	2580083	et	4	main
ma	doc_491521502084_item	2580084	et	3	main
ajan	doc_491521502084_item	2580085	et	3	main
vi	doc_491521502084_item	2580100	et	4	main
välja	doc_491521502084_item	2580116	et	4	main
за	doc_491521502084_item	2580118	et	2	main
3	doc_491521502084_item	2580120	et	2	main
сказать	doc_491521502084_item	2580125	et	2	main
5	doc_491521502084_item	2580133	et	2	main
nii	doc_491521502084_item	2580135	et	3	main
так	doc_491521502084_item	2580137	et	2	main
uuest	doc_491521502084_item	2580148	et	3	main
te	doc_491521502084_item	2580165	et	4	main
sõlmides	doc_491521502084_item	2580172	et	4	main
asjatundja	doc_491521502084_item	2580207	et	4	main
ja	doc_491521502084_item	2580224	et	3	main
ne	doc_491521502084_item	2580231	et	4	main
ühel	doc_491521502084_item	2580237	et	3	main
suurepärane	doc_491521502084_item	2580265	et	4	main
kokku	doc_491521502084_item	2580267	et	3	main
aednik	doc_491521502084_item	2580282	et	3	main
13	doc_491521502084_item	2580286	et	2	main
14	doc_491521502084_item	2580290	et	2	main
15	doc_491521502084_item	2580294	et	2	main
seitse	doc_491521502084_item	2580295	et	3	main
päeva	doc_491521502084_item	2580296	et	4	main
ge	doc_491521502084_item	2580313	et	4	main
enda	doc_491521502084_item	2580319	et	4	main
asju	doc_491521502084_item	2580322	et	3	main
ke	doc_491521502084_item	2580326	et	4	main
5	doc_491521502084_item	2580329	et	2	main
hakkama	doc_491521502084_item	2580330	et	3	main
küsi	doc_491521502084_item	2580339	et	4	main
7	doc_491521502084_item	2580344	et	2	main
ge	doc_491521502084_item	2580347	et	4	main
kõhelge	doc_491521502084_item	2580357	et	4	main
sarnaneda	doc_491521502084_item	2580364	et	3	main
1	doc_491521502085_item	2580372	et	2	main
мучаться	doc_491521502085_item	2580408	et	2	main
сомневаться	doc_491521502085_item	2580412	et	2	main
назначения	doc_491521502085_item	2580417	et	2	main
чертах	doc_491521502085_item	2580422	et	2	main
выход	doc_491521502085_item	2580427	et	2	main
13	doc_491521502085_item	2580431	et	2	main
штаны	doc_491521502085_item	2580438	et	2	main
свекровь	doc_491521502085_item	2580441	et	2	main
reostus	doc_491521502085_item	2580443	et	4	main
17	doc_491521502085_item	2580445	et	2	main
vilets	doc_491521502085_item	2580452	et	3	main
20	doc_491521502085_item	2580455	et	2	main
ii	doc_491521502085_item	2580458	et	4	main
отпуск	doc_491521502085_item	2580461	et	2	main
деревне	doc_491521502085_item	2580464	et	2	main
товар	doc_491521502085_item	2580469	et	2	main
on	doc_491521502085_item	2580477	et	4	main
договор	doc_491521502085_item	2580486	et	2	main
meie	doc_491521502085_item	2580490	et	4	main
ei	doc_491521502085_item	2580491	et	4	main
kvartalist	doc_491521502085_item	2580525	et	4	main
завоеванный	doc_491521502085_item	2580528	et	2	main
tuupitud	doc_491521502085_item	2580563	et	4	main
maha	doc_491521502085_item	2580567	et	4	main
oma	doc_491521502085_item	2580581	et	4	main
nägi	doc_491521502085_item	2580597	et	3	main
seda	doc_491521502085_item	2580605	et	3	main
maja	doc_491521502085_item	2580606	et	4	main
6	doc_491521502085_item	2580610	et	2	main
töötajaid	doc_491521502085_item	2580613	et	4	main
seoses	doc_491521502085_item	2580614	et	4	main
uue	doc_491521502085_item	2580615	et	3	main
4	doc_491521502084_item	2580126	et	2	main
другие	doc_491521502084_item	2580131	et	2	main
korterist	doc_491521502084_item	2580149	et	3	main
rahalisi	doc_491521502084_item	2580161	et	4	main
võimalusi	doc_491521502084_item	2580162	et	3	main
2	doc_491521502084_item	2580163	et	2	main
kui	doc_491521502084_item	2580164	et	3	main
olge	doc_491521502084_item	2580169	et	3	main
väga	doc_491521502084_item	2580176	et	3	main
tähelepanelik	doc_491521502084_item	2580177	et	4	main
3	doc_491521502084_item	2580178	et	2	main
kui	doc_491521502084_item	2580179	et	3	main
võrrelda	doc_491521502084_item	2580180	et	4	main
kesklinnaga	doc_491521502084_item	2580181	et	3	main
on	doc_491521502084_item	2580182	et	4	main
see	doc_491521502084_item	2580183	et	3	main
korter	doc_491521502084_item	2580184	et	3	main
odav	doc_491521502084_item	2580185	et	3	main
võrreldes	doc_491521502084_item	2580186	et	3	main
kesklinnaga	doc_491521502084_item	2580187	et	3	main
on	doc_491521502084_item	2580188	et	4	main
see	doc_491521502084_item	2580189	et	3	main
korter	doc_491521502084_item	2580190	et	3	main
odav	doc_491521502084_item	2580191	et	3	main
4	doc_491521502084_item	2580192	et	2	main
kui	doc_491521502084_item	2580193	et	3	main
lähete	doc_491521502084_item	2580194	et	4	main
korterit	doc_491521502084_item	2580195	et	3	main
üle	doc_491521502084_item	2580196	et	3	main
vaatama	doc_491521502084_item	2580197	et	3	main
võtke	doc_491521502084_item	2580198	et	3	main
kaasa	doc_491521502084_item	2580199	et	4	main
asjatundja	doc_491521502084_item	2580200	et	4	main
minnes	doc_491521502084_item	2580201	et	3	main
korterit	doc_491521502084_item	2580202	et	3	main
üle	doc_491521502084_item	2580203	et	3	main
vaatama	doc_491521502084_item	2580204	et	3	main
uuest	doc_491521502084_item	2580156	et	3	main
korterist	doc_491521502084_item	2580157	et	3	main
ärge	doc_491521502084_item	2580158	et	3	main
unustage	doc_491521502084_item	2580159	et	3	main
oma	doc_491521502084_item	2580160	et	4	main
lepingut	doc_491521502084_item	2580168	et	3	main
võtke	doc_491521502084_item	2580205	et	3	main
abi	doc_491521502084_item	2580221	et	4	main
moodustage	doc_491521502084_item	2580223	et	3	main
ndus	doc_491521502084_item	2580226	et	4	main
ng	doc_491521502084_item	2580228	et	4	main
k	doc_491521502084_item	2580229	et	4	main
liitelised	doc_491521502084_item	2580235	et	4	main
olla	doc_491521502084_item	2580240	et	3	main
1	doc_491521502084_item	2580243	et	2	main
3	doc_491521502084_item	2580250	et	2	main
12	doc_491521502084_item	2580283	et	2	main
meelepärane	doc_491521502084_item	2580285	et	4	main
leppima	doc_491521502084_item	2580287	et	3	main
leppimine	doc_491521502084_item	2580288	et	4	main
leping	doc_491521502084_item	2580289	et	3	main
valik	doc_491521502084_item	2580292	et	3	main
valimine	doc_491521502084_item	2580293	et	4	main
ix	doc_491521502084_item	2580298	et	4	main
2	doc_491521502084_item	2580310	et	2	main
3	doc_491521502084_item	2580315	et	2	main
räägi	doc_491521502084_item	2580317	et	4	main
viii	doc_491521502084_item	2580222	et	4	main
mine	doc_491521502084_item	2580232	et	3	main
või	doc_491521502084_item	2580233	et	4	main
võib	doc_491521502084_item	2580239	et	3	main
varianti	doc_491521502084_item	2580242	et	4	main
õhk	doc_491521502084_item	2580244	et	3	main
õhkkond	doc_491521502084_item	2580245	et	3	main
kuus	doc_491521502084_item	2580255	et	4	main
liiget	doc_491521502084_item	2580256	et	3	main
kuue	doc_491521502084_item	2580257	et	4	main
liikmene	doc_491521502084_item	2580258	et	4	main
5	doc_491521502084_item	2580259	et	2	main
tootma	doc_491521502084_item	2580260	et	3	main
tootja	doc_491521502084_item	2580261	et	4	main
6	doc_491521502084_item	2580263	et	2	main
tootmine	doc_491521502084_item	2580262	et	4	main
suur	doc_491521502084_item	2580264	et	3	main
line	doc_491521502084_item	2580230	et	4	main
sõnad	doc_491521502084_item	2580236	et	4	main
4	doc_491521502084_item	2580254	et	2	main
aed	doc_491521502084_item	2580281	et	3	main
seitsmepäevane	doc_491521502084_item	2580297	et	4	main
käskivat	doc_491521502084_item	2580300	et	4	main
1	doc_491521502084_item	2580302	et	2	main
ruttu	doc_491521502084_item	2580308	et	4	main
säilita	doc_491521502084_item	2580312	et	4	main
rahu	doc_491521502084_item	2580314	et	4	main
rääkima	doc_491521502084_item	2580316	et	3	main
rääkige	doc_491521502084_item	2580318	et	3	main
negatiivseid	doc_491521502084_item	2580321	et	3	main
hoolikalt	doc_491521502084_item	2580327	et	4	main
hakka	doc_491521502084_item	2580331	et	4	main
hakake	doc_491521502084_item	2580332	et	3	main
intervjueerijat	doc_491521502084_item	2580333	et	4	main
pahandama	doc_491521502084_item	2580334	et	3	main
6	doc_491521502084_item	2580335	et	2	main
ge	doc_491521502084_item	2580340	et	4	main
hiline	doc_491521502084_item	2580346	et	4	main
vaadake	doc_491521502084_item	2580351	et	3	main
intervjueerijale	doc_491521502084_item	2580352	et	4	main
oma	doc_491521502084_item	2580358	et	4	main
10	doc_491521502084_item	2580360	et	2	main
kontrolltöö	doc_491521502085_item	2580369	et	4	main
6	doc_491521502085_item	2580401	et	2	main
опознавать	doc_491521502085_item	2580404	et	2	main
8	doc_491521502085_item	2580409	et	2	main
kõikuma	doc_491521502085_item	2580410	et	3	main
otstarve	doc_491521502085_item	2580414	et	3	main
10	doc_491521502085_item	2580418	et	2	main
общих	doc_491521502085_item	2580421	et	2	main
leidma	doc_491521502085_item	2580425	et	3	main
12	doc_491521502085_item	2580428	et	2	main
наклоняться	doc_491521502085_item	2580433	et	2	main
püksid	doc_491521502085_item	2580436	et	3	main
ämmaemand	doc_491521502085_item	2580440	et	3	main
18	doc_491521502085_item	2580448	et	2	main
препятствовать	doc_491521502085_item	2580450	et	2	main
специалист	doc_491521502085_item	2580457	et	2	main
1	doc_491521502085_item	2580460	et	2	main
veedetud	doc_491521502085_item	2580466	et	4	main
нового	doc_491521502085_item	2580472	et	2	main
не	doc_491521502085_item	2580483	et	2	main
или	doc_491521502085_item	2580488	et	2	main
tea	doc_491521502085_item	2580492	et	4	main
kas	doc_491521502085_item	2580493	et	3	main
leping	doc_491521502085_item	2580494	et	3	main
sõlmitakse	doc_491521502085_item	2580495	et	3	main
või	doc_491521502085_item	2580496	et	4	main
7	doc_491521502084_item	2580266	et	2	main
tulema	doc_491521502084_item	2580268	et	4	main
kokkutulek	doc_491521502084_item	2580269	et	3	main
8	doc_491521502084_item	2580270	et	2	main
kiri	doc_491521502084_item	2580271	et	3	main
kirjanik	doc_491521502084_item	2580272	et	3	main
kirjandus	doc_491521502084_item	2580273	et	3	main
kujundama	doc_491521502084_item	2580278	et	3	main
11	doc_491521502084_item	2580280	et	2	main
meel	doc_491521502084_item	2580284	et	4	main
valima	doc_491521502084_item	2580291	et	3	main
ge	doc_491521502084_item	2580305	et	4	main
see	doc_491521502084_item	2580306	et	3	main
tuleb	doc_491521502084_item	2580307	et	3	main
kuulama	doc_491521502084_item	2580324	et	3	main
küsimusi	doc_491521502084_item	2580328	et	4	main
tulemused	doc_491521502084_item	2580343	et	3	main
9	doc_491521502084_item	2580354	et	2	main
kõhklema	doc_491521502084_item	2580355	et	3	main
kõhkle	doc_491521502084_item	2580356	et	4	main
püüdma	doc_491521502084_item	2580361	et	3	main
püüdke	doc_491521502084_item	2580363	et	3	main
i	doc_491521502085_item	2580370	et	4	main
tõlkige	doc_491521502085_item	2580371	et	3	main
5	doc_491521502085_item	2580397	et	2	main
признавать	doc_491521502085_item	2580403	et	2	main
9	doc_491521502085_item	2580413	et	2	main
прямого	doc_491521502085_item	2580416	et	2	main
в	doc_491521502085_item	2580420	et	2	main
предпочитать	doc_491521502085_item	2580430	et	2	main
liibuvad	doc_491521502085_item	2580435	et	4	main
облигающие	doc_491521502085_item	2580437	et	2	main
16	doc_491521502085_item	2580442	et	2	main
загрязнение	doc_491521502085_item	2580444	et	2	main
takistama	doc_491521502085_item	2580449	et	3	main
убогий	doc_491521502085_item	2580454	et	2	main
2	doc_491521502085_item	2580468	et	2	main
привезенный	doc_491521502085_item	2580470	et	2	main
склада	doc_491521502085_item	2580474	et	2	main
будет	doc_491521502085_item	2580485	et	2	main
нет	doc_491521502085_item	2580489	et	2	main
ülemus	doc_491521502085_item	2580521	et	4	main
kokkuvõtte	doc_491521502085_item	2580523	et	4	main
кубок	doc_491521502085_item	2580527	et	2	main
соревнованиях	doc_491521502085_item	2580530	et	2	main
фирмой	doc_491521502085_item	2580538	et	2	main
tuttavaks	doc_491521502085_item	2580542	et	4	main
firmaga	doc_491521502085_item	2580543	et	3	main
ли	doc_491521502085_item	2580547	et	2	main
ei	doc_491521502085_item	2580555	et	4	main
слова	doc_491521502085_item	2580562	et	2	main
iii	doc_491521502085_item	2580565	et	4	main
töötajate	doc_491521502085_item	2580582	et	4	main
palju	doc_491521502085_item	2580591	et	4	main
läbiajas	doc_491521502085_item	2580595	et	3	main
korda	doc_491521502085_item	2580596	et	4	main
5	doc_491521502085_item	2580604	et	2	main
haldab	doc_491521502085_item	2580608	et	3	main
kehtestamisega	doc_491521502085_item	2580617	et	4	main
me	doc_491521502085_item	2580621	et	4	main
kinga	doc_491521502085_item	2580630	et	4	main
konts	doc_491521502085_item	2580632	et	3	main
pooleks	doc_491521502085_item	2580635	et	4	main
9	doc_491521502085_item	2580636	et	2	main
10	doc_491521502085_item	2580642	et	2	main
teeskles	doc_491521502085_item	2580647	et	3	main
ehitustöid	doc_491521502085_item	2580682	et	3	main
ametnikud	doc_491521502085_item	2580690	et	3	main
juurest	doc_491521502085_item	2580701	et	4	main
piisavalt	doc_491521502085_item	2580710	et	4	main
nõusolekul	doc_491521502085_item	2580726	et	3	main
kirjutab	doc_491521502085_item	2580730	et	3	main
uute	doc_491521502085_item	2580740	et	3	main
abitööd	doc_491521502085_item	2580764	et	4	main
mind	doc_491521502085_item	2580772	et	4	main
tundma	doc_491521502085_item	2580774	et	3	main
2	doc_491521502085_item	2580782	et	2	main
ära	doc_491521502085_item	2580783	et	4	main
5	doc_491521502085_item	2580822	et	2	main
vi	doc_491521502085_item	2580833	et	4	main
4	doc_491521502084_item	2580323	et	2	main
millal	doc_491521502084_item	2580341	et	3	main
hilinema	doc_491521502084_item	2580345	et	3	main
8	doc_491521502084_item	2580348	et	2	main
vaatama	doc_491521502084_item	2580349	et	3	main
vaata	doc_491521502084_item	2580350	et	4	main
levinud	doc_491521502084_item	2580367	et	4	main
stiiliga	doc_491521502084_item	2580368	et	3	main
äärega	doc_491521502085_item	2580374	et	3	main
saapad	doc_491521502085_item	2580375	et	3	main
сапоги	doc_491521502085_item	2580376	et	2	main
с	doc_491521502085_item	2580377	et	2	main
ворсинками	doc_491521502085_item	2580378	et	2	main
2	doc_491521502085_item	2580379	et	2	main
käed	doc_491521502085_item	2580380	et	3	main
kukla	doc_491521502085_item	2580381	et	3	main
taga	doc_491521502085_item	2580382	et	4	main
за	doc_491521502085_item	2580384	et	2	main
голову	doc_491521502085_item	2580385	et	2	main
3	doc_491521502085_item	2580386	et	2	main
руки	doc_491521502085_item	2580383	et	2	main
paneb	doc_491521502085_item	2580387	et	3	main
jalad	doc_491521502085_item	2580388	et	3	main
harki	doc_491521502085_item	2580389	et	4	main
ставит	doc_491521502085_item	2580390	et	2	main
ноги	doc_491521502085_item	2580391	et	2	main
на	doc_491521502085_item	2580392	et	2	main
ширине	doc_491521502085_item	2580393	et	2	main
4	doc_491521502085_item	2580395	et	2	main
плеч	doc_491521502085_item	2580394	et	2	main
haljastustööd	doc_491521502085_item	2580396	et	4	main
kokku	doc_491521502085_item	2580398	et	3	main
puutuma	doc_491521502085_item	2580399	et	4	main
соприкосаться	doc_491521502085_item	2580400	et	2	main
tunnustama	doc_491521502085_item	2580402	et	3	main
7	doc_491521502085_item	2580405	et	2	main
vaeva	doc_491521502085_item	2580406	et	4	main
nägema	doc_491521502085_item	2580407	et	3	main
качаться	doc_491521502085_item	2580411	et	2	main
предмет	doc_491521502085_item	2580415	et	2	main
üldjoontes	doc_491521502085_item	2580419	et	3	main
11	doc_491521502085_item	2580423	et	2	main
eelistama	doc_491521502085_item	2580429	et	3	main
14	doc_491521502085_item	2580434	et	2	main
15	doc_491521502085_item	2580439	et	2	main
teesklema	doc_491521502085_item	2580446	et	3	main
19	doc_491521502085_item	2580451	et	2	main
asjatundlik	doc_491521502085_item	2580456	et	3	main
проведенный	doc_491521502085_item	2580462	et	2	main
puhkus	doc_491521502085_item	2580465	et	3	main
с	doc_491521502085_item	2580471	et	2	main
kaup	doc_491521502085_item	2580475	et	3	main
знаем	doc_491521502085_item	2580484	et	2	main
mitte	doc_491521502085_item	2580497	et	3	main
tegi	doc_491521502085_item	2580522	et	4	main
eelmisest	doc_491521502085_item	2580524	et	3	main
на	doc_491521502085_item	2580529	et	2	main
võidetud	doc_491521502085_item	2580532	et	4	main
mängudel	doc_491521502085_item	2580533	et	3	main
с	doc_491521502085_item	2580537	et	2	main
teeb	doc_491521502085_item	2580541	et	3	main
9	doc_491521502085_item	2580544	et	2	main
вы	doc_491521502085_item	2580548	et	2	main
on	doc_491521502085_item	2580558	et	4	main
зазубренные	doc_491521502085_item	2580561	et	2	main
sõnad	doc_491521502085_item	2580564	et	4	main
kriipsutage	doc_491521502085_item	2580566	et	3	main
sobimatud	doc_491521502085_item	2580568	et	4	main
alati	doc_491521502085_item	2580575	et	4	main
sooduspakkumistega	doc_491521502085_item	2580576	et	3	main
tööotsija	doc_491521502085_item	2580585	et	4	main
mainis	doc_491521502085_item	2580586	et	3	main
hoidus	doc_491521502085_item	2580588	et	3	main
intervjuul	doc_491521502085_item	2580589	et	3	main
liiga	doc_491521502085_item	2580590	et	4	main
maha	doc_491521502085_item	2580602	et	4	main
korteriühistu	doc_491521502085_item	2580609	et	4	main
firma	doc_491521502085_item	2580611	et	4	main
otsib	doc_491521502085_item	2580612	et	3	main
käivitamisega	doc_491521502085_item	2580618	et	4	main
meelitamisega	doc_491521502085_item	2580619	et	4	main
7	doc_491521502085_item	2580620	et	2	main
rakendust	doc_491521502085_item	2580424	et	4	main
находить	doc_491521502085_item	2580426	et	2	main
kummarduma	doc_491521502085_item	2580432	et	3	main
притворяться	doc_491521502085_item	2580447	et	2	main
плохой	doc_491521502085_item	2580453	et	2	main
tõlkige	doc_491521502085_item	2580459	et	3	main
в	doc_491521502085_item	2580463	et	2	main
maal	doc_491521502085_item	2580467	et	4	main
оптового	doc_491521502085_item	2580473	et	2	main
mis	doc_491521502085_item	2580476	et	4	main
toodud	doc_491521502085_item	2580478	et	4	main
hulgi	doc_491521502085_item	2580479	et	4	main
ladust	doc_491521502085_item	2580480	et	4	main
3	doc_491521502085_item	2580481	et	2	main
мы	doc_491521502085_item	2580482	et	2	main
подписан	doc_491521502085_item	2580487	et	2	main
4	doc_491521502085_item	2580498	et	2	main
по	doc_491521502085_item	2580499	et	2	main
глупой	doc_491521502085_item	2580500	et	2	main
случайности	doc_491521502085_item	2580501	et	2	main
rumalal	doc_491521502085_item	2580502	et	3	main
saatumusel	doc_491521502085_item	2580503	et	4	main
5	doc_491521502085_item	2580504	et	2	main
умение	doc_491521502085_item	2580505	et	2	main
общаться	doc_491521502085_item	2580506	et	2	main
само	doc_491521502085_item	2580507	et	2	main
собой	doc_491521502085_item	2580508	et	2	main
разумеется	doc_491521502085_item	2580509	et	2	main
oskus	doc_491521502085_item	2580510	et	3	main
suhelda	doc_491521502085_item	2580511	et	4	main
on	doc_491521502085_item	2580512	et	4	main
iseenesest	doc_491521502085_item	2580513	et	4	main
tarvis	doc_491521502085_item	2580514	et	3	main
6	doc_491521502085_item	2580515	et	2	main
начальник	doc_491521502085_item	2580516	et	2	main
подвел	doc_491521502085_item	2580517	et	2	main
итоги	doc_491521502085_item	2580518	et	2	main
прошедшего	doc_491521502085_item	2580519	et	2	main
сезона	doc_491521502085_item	2580520	et	2	main
7	doc_491521502085_item	2580526	et	2	main
буклет	doc_491521502085_item	2580535	et	2	main
mis	doc_491521502085_item	2580540	et	4	main
не	doc_491521502085_item	2580545	et	2	main
где	doc_491521502085_item	2580549	et	2	main
juhataja	doc_491521502085_item	2580559	et	4	main
10	doc_491521502085_item	2580560	et	2	main
sõnad	doc_491521502085_item	2580569	et	4	main
1	doc_491521502085_item	2580570	et	2	main
teadlik	doc_491521502085_item	2580571	et	3	main
üleolevüllatunud	doc_491521502085_item	2580572	et	4	main
tarbija	doc_491521502085_item	2580573	et	4	main
eest	doc_491521502085_item	2580583	et	4	main
3	doc_491521502085_item	2580584	et	2	main
4	doc_491521502085_item	2580592	et	2	main
lasi	doc_491521502085_item	2580594	et	4	main
vaeva	doc_491521502085_item	2580598	et	4	main
et	doc_491521502085_item	2580599	et	3	main
karikas	doc_491521502085_item	2580531	et	4	main
8	doc_491521502085_item	2580534	et	2	main
знакомящий	doc_491521502085_item	2580536	et	2	main
küsimustik	doc_491521502085_item	2580539	et	3	main
знаете	doc_491521502085_item	2580546	et	2	main
директор	doc_491521502085_item	2580550	et	2	main
по	doc_491521502085_item	2580551	et	2	main
сбыту	doc_491521502085_item	2580552	et	2	main
kas	doc_491521502085_item	2580553	et	3	main
te	doc_491521502085_item	2580554	et	4	main
tea	doc_491521502085_item	2580556	et	4	main
mis	doc_491521502085_item	2580557	et	4	main
tutvub	doc_491521502085_item	2580574	et	3	main
2	doc_491521502085_item	2580577	et	2	main
me	doc_491521502085_item	2580578	et	4	main
hooldamehoolitseme	doc_491521502085_item	2580579	et	4	main
hoolime	doc_491521502085_item	2580580	et	3	main
lobises	doc_491521502085_item	2580587	et	3	main
maakler	doc_491521502085_item	2580593	et	3	main
müüa	doc_491521502085_item	2580603	et	3	main
kerkibkaasneb	doc_491521502085_item	2580607	et	4	main
küsimustikukõmu	doc_491521502085_item	2580625	et	4	main
tööandjate	doc_491521502085_item	2580626	et	3	main
järeldavadjagunevad	doc_491521502085_item	2580639	et	4	main
süüdistas	doc_491521502085_item	2580646	et	3	main
iv	doc_491521502085_item	2580652	et	4	main
muutke	doc_491521502085_item	2580653	et	3	main
laused	doc_491521502085_item	2580654	et	3	main
luba	doc_491521502085_item	2580665	et	4	main
täisajaga	doc_491521502085_item	2580669	et	3	main
võtab	doc_491521502085_item	2580672	et	3	main
võetakse	doc_491521502085_item	2580676	et	3	main
3	doc_491521502085_item	2580678	et	2	main
firma	doc_491521502085_item	2580679	et	4	main
teeb	doc_491521502085_item	2580680	et	3	main
mitmesuguseid	doc_491521502085_item	2580681	et	3	main
mitmesugustega	doc_491521502085_item	2580685	et	3	main
tihti	doc_491521502085_item	2580688	et	3	main
5	doc_491521502085_item	2580704	et	2	main
hinda	doc_491521502085_item	2580707	et	4	main
vanema	doc_491521502085_item	2580718	et	4	main
kirjalikul	doc_491521502085_item	2580719	et	3	main
nõusolekul	doc_491521502085_item	2580720	et	3	main
vanema	doc_491521502085_item	2580724	et	4	main
lepingule	doc_491521502085_item	2580734	et	3	main
ansambel	doc_491521502085_item	2580737	et	3	main
9	doc_491521502085_item	2580746	et	2	main
erialast	doc_491521502085_item	2580750	et	4	main
raamatukogus	doc_491521502085_item	2580752	et	4	main
loetakse	doc_491521502085_item	2580753	et	3	main
erialast	doc_491521502085_item	2580754	et	4	main
kirjandust	doc_491521502085_item	2580755	et	3	main
10	doc_491521502085_item	2580756	et	2	main
lapsele	doc_491521502085_item	2580762	et	4	main
pakutakse	doc_491521502085_item	2580763	et	3	main
laused	doc_491521502085_item	2580767	et	3	main
1	doc_491521502085_item	2580770	et	2	main
ma	doc_491521502085_item	2580786	et	3	main
ta	doc_491521502085_item	2580829	et	4	main
lehe	doc_491521502085_item	2580831	et	3	main
3	doc_491521502085_item	2580848	et	2	main
n-ö	doc_491521502085_item	2580849	et	4	main
jm	doc_491521502085_item	2580853	et	4	main
muid	doc_491521502085_item	2580855	et	4	main
nii	doc_491521502085_item	2580859	et	3	main
näiteks	doc_491521502085_item	2580860	et	4	main
1	doc_491521502085_item	2580866	et	2	main
unistades	doc_491521502085_item	2580877	et	3	main
unustage	doc_491521502085_item	2580881	et	3	main
seda	doc_491521502085_item	2580600	et	3	main
korterit	doc_491521502085_item	2580601	et	3	main
tootmisliini	doc_491521502085_item	2580616	et	4	main
läbi	doc_491521502085_item	2580623	et	4	main
8	doc_491521502085_item	2580628	et	2	main
varrukas	doc_491521502085_item	2580631	et	4	main
krae	doc_491521502085_item	2580633	et	4	main
hulguvad	doc_491521502085_item	2580640	et	3	main
ta	doc_491521502085_item	2580648	et	4	main
oma	doc_491521502085_item	2580649	et	4	main
umbisikuliseks	doc_491521502085_item	2580655	et	4	main
ei	doc_491521502085_item	2580664	et	4	main
et	doc_491521502085_item	2580666	et	3	main
töötaks	doc_491521502085_item	2580668	et	4	main
2	doc_491521502085_item	2580670	et	2	main
teiega	doc_491521502085_item	2580673	et	3	main
teiega	doc_491521502085_item	2580675	et	3	main
ühendust	doc_491521502085_item	2580677	et	4	main
ehitustöötega	doc_491521502085_item	2580686	et	4	main
saadavad	doc_491521502085_item	2580689	et	4	main
juurest	doc_491521502085_item	2580693	et	4	main
teise	doc_491521502085_item	2580694	et	4	main
juurde	doc_491521502085_item	2580695	et	4	main
tihti	doc_491521502085_item	2580696	et	3	main
saadetakse	doc_491521502085_item	2580697	et	3	main
tööotsijaid	doc_491521502085_item	2580698	et	3	main
nad	doc_491521502085_item	2580705	et	3	main
tööd	doc_491521502085_item	2580709	et	4	main
ei	doc_491521502085_item	2580711	et	4	main
hinnata	doc_491521502085_item	2580712	et	4	main
6	doc_491521502085_item	2580713	et	2	main
sõlmib	doc_491521502085_item	2580715	et	3	main
lapsega	doc_491521502085_item	2580716	et	3	main
lapsega	doc_491521502085_item	2580722	et	3	main
töölepingut	doc_491521502085_item	2580723	et	3	main
kirjalikul	doc_491521502085_item	2580725	et	3	main
7	doc_491521502085_item	2580727	et	2	main
firma	doc_491521502085_item	2580728	et	4	main
lepingule	doc_491521502085_item	2580731	et	3	main
8	doc_491521502085_item	2580736	et	2	main
konserdil	doc_491521502085_item	2580742	et	4	main
loeb	doc_491521502085_item	2580748	et	3	main
tavaliselt	doc_491521502085_item	2580757	et	4	main
pakuvad	doc_491521502085_item	2580758	et	3	main
asutused	doc_491521502085_item	2580759	et	4	main
järgmiste	doc_491521502085_item	2580768	et	3	main
piinlikkust	doc_491521502085_item	2580773	et	4	main
mind	doc_491521502085_item	2580779	et	4	main
piinlikkust	doc_491521502085_item	2580780	et	4	main
tundma	doc_491521502085_item	2580781	et	3	main
kaua	doc_491521502085_item	2580787	et	3	main
vaatan	doc_491521502085_item	2580788	et	3	main
pigistama	doc_491521502085_item	2580824	et	3	main
et	doc_491521502085_item	2580825	et	3	main
keegi	doc_491521502085_item	2580826	et	4	main
rusikasse	doc_491521502085_item	2580832	et	4	main
kirjutage	doc_491521502085_item	2580834	et	3	main
nii	doc_491521502085_item	2580850	et	3	main
5	doc_491521502085_item	2580857	et	2	main
nn	doc_491521502085_item	2580858	et	4	main
laused	doc_491521502085_item	2580865	et	3	main
te	doc_491521502085_item	2580868	et	4	main
uuest	doc_491521502085_item	2580870	et	3	main
unustage	doc_491521502085_item	2580873	et	3	main
uuest	doc_491521502085_item	2580878	et	3	main
võtke	doc_491521502085_item	2580920	et	3	main
asjatundja	doc_491521502085_item	2580922	et	4	main
suur	doc_491521502085_item	2580931	et	3	main
nik	doc_491521502085_item	2580942	et	4	main
ng	doc_491521502085_item	2580945	et	4	main
liitelised	doc_491521502085_item	2580952	et	4	main
sõnad	doc_491521502085_item	2580953	et	4	main
ühel	doc_491521502085_item	2580954	et	3	main
sõnal	doc_491521502085_item	2580955	et	3	main
võib	doc_491521502085_item	2580956	et	3	main
olla	doc_491521502085_item	2580957	et	3	main
mitu	doc_491521502085_item	2580958	et	4	main
varianti	doc_491521502085_item	2580959	et	4	main
2	doc_491521502085_item	2580963	et	2	main
pool	doc_491521502085_item	2580969	et	4	main
kuus	doc_491521502085_item	2580972	et	4	main
küsitluse	doc_491521502085_item	2580624	et	4	main
seas	doc_491521502085_item	2580627	et	4	main
murdus	doc_491521502085_item	2580634	et	3	main
tegevuseta	doc_491521502085_item	2580637	et	4	main
noorukid	doc_491521502085_item	2580638	et	3	main
rõhutas	doc_491521502085_item	2580645	et	3	main
endist	doc_491521502085_item	2580650	et	4	main
ülemust	doc_491521502085_item	2580651	et	4	main
1	doc_491521502085_item	2580656	et	2	main
seadus	doc_491521502085_item	2580657	et	4	main
ei	doc_491521502085_item	2580658	et	4	main
luba	doc_491521502085_item	2580659	et	4	main
lastel	doc_491521502085_item	2580660	et	4	main
töötada	doc_491521502085_item	2580661	et	3	main
täisajaga	doc_491521502085_item	2580662	et	3	main
seiadus	doc_491521502085_item	2580663	et	4	main
viisime	doc_491521502085_item	2580622	et	4	main
tema	doc_491521502085_item	2580629	et	4	main
tänavail	doc_491521502085_item	2580641	et	4	main
lisaks	doc_491521502085_item	2580643	et	4	main
sellele	doc_491521502085_item	2580644	et	4	main
ühendust	doc_491521502085_item	2580674	et	4	main
tegeletakse	doc_491521502085_item	2580684	et	3	main
4	doc_491521502085_item	2580687	et	2	main
tööotsijat	doc_491521502085_item	2580691	et	3	main
ühe	doc_491521502085_item	2580699	et	4	main
ametniku	doc_491521502085_item	2580700	et	3	main
juurde	doc_491521502085_item	2580703	et	4	main
ei	doc_491521502085_item	2580706	et	4	main
tema	doc_491521502085_item	2580708	et	4	main
lapsed	doc_491521502085_item	2580667	et	3	main
ametnik	doc_491521502085_item	2580671	et	3	main
firmas	doc_491521502085_item	2580683	et	3	main
ühe	doc_491521502085_item	2580692	et	4	main
teise	doc_491521502085_item	2580702	et	4	main
tööandja	doc_491521502085_item	2580714	et	4	main
töölepingu	doc_491521502085_item	2580717	et	4	main
sõlmitakse	doc_491521502085_item	2580721	et	3	main
kirjutatakse	doc_491521502085_item	2580733	et	3	main
kontserdil	doc_491521502085_item	2580739	et	3	main
esinetakse	doc_491521502085_item	2580743	et	3	main
lauludega	doc_491521502085_item	2580745	et	3	main
raamatukogus	doc_491521502085_item	2580749	et	4	main
v	doc_491521502085_item	2580765	et	4	main
paneb	doc_491521502085_item	2580771	et	3	main
tema	doc_491521502085_item	2580775	et	4	main
käitumine	doc_491521502085_item	2580776	et	4	main
tüütama	doc_491521502085_item	2580784	et	3	main
vihale	doc_491521502085_item	2580821	et	4	main
juht	doc_491521502085_item	2580729	et	3	main
alla	doc_491521502085_item	2580732	et	3	main
alla	doc_491521502085_item	2580735	et	3	main
esineb	doc_491521502085_item	2580738	et	3	main
lauludega	doc_491521502085_item	2580741	et	3	main
uute	doc_491521502085_item	2580744	et	3	main
üliõpilane	doc_491521502085_item	2580747	et	3	main
kirjandust	doc_491521502085_item	2580751	et	3	main
lapsele	doc_491521502085_item	2580760	et	4	main
abitööd	doc_491521502085_item	2580761	et	4	main
moodustage	doc_491521502085_item	2580766	et	3	main
sõnaühenditega	doc_491521502085_item	2580769	et	3	main
tavaliselt	doc_491521502085_item	2580777	et	4	main
paneb	doc_491521502085_item	2580778	et	3	main
kui	doc_491521502085_item	2580785	et	3	main
telerit	doc_491521502085_item	2580789	et	3	main
see	doc_491521502085_item	2580790	et	3	main
hakkab	doc_491521502085_item	2580791	et	3	main
mind	doc_491521502085_item	2580792	et	4	main
ära	doc_491521502085_item	2580793	et	4	main
tüütama	doc_491521502085_item	2580794	et	3	main
3	doc_491521502085_item	2580795	et	2	main
meelepärane	doc_491521502085_item	2580796	et	4	main
see	doc_491521502085_item	2580797	et	3	main
inimene	doc_491521502085_item	2580798	et	3	main
on	doc_491521502085_item	2580799	et	4	main
meelepärane	doc_491521502085_item	2580800	et	4	main
ja	doc_491521502085_item	2580801	et	3	main
seetõttu	doc_491521502085_item	2580802	et	3	main
on	doc_491521502085_item	2580803	et	4	main
temaga	doc_491521502085_item	2580804	et	3	main
raske	doc_491521502085_item	2580805	et	4	main
suhelda	doc_491521502085_item	2580806	et	4	main
4	doc_491521502085_item	2580807	et	2	main
vihale	doc_491521502085_item	2580808	et	4	main
ajama	doc_491521502085_item	2580809	et	4	main
ta	doc_491521502085_item	2580810	et	4	main
oli	doc_491521502085_item	2580811	et	3	main
terve	doc_491521502085_item	2580812	et	4	main
päeva	doc_491521502085_item	2580813	et	4	main
minu	doc_491521502085_item	2580814	et	3	main
juures	doc_491521502085_item	2580815	et	4	main
ja	doc_491521502085_item	2580816	et	3	main
õhtuks	doc_491521502085_item	2580817	et	3	main
ta	doc_491521502085_item	2580818	et	4	main
ajas	doc_491521502085_item	2580819	et	4	main
mind	doc_491521502085_item	2580820	et	4	main
rusikasse	doc_491521502085_item	2580823	et	4	main
ei	doc_491521502085_item	2580827	et	4	main
näeks	doc_491521502085_item	2580828	et	3	main
pigistas	doc_491521502085_item	2580830	et	3	main
arvatud	doc_491521502085_item	2580847	et	4	main
4	doc_491521502085_item	2580852	et	2	main
vii	doc_491521502085_item	2580861	et	4	main
moodustage	doc_491521502085_item	2580862	et	3	main
des-lauselühendiga	doc_491521502085_item	2580864	et	3	main
korterist	doc_491521502085_item	2580871	et	3	main
oma	doc_491521502085_item	2580874	et	4	main
rahalisi	doc_491521502085_item	2580883	et	4	main
võimalusi	doc_491521502085_item	2580884	et	3	main
2	doc_491521502085_item	2580885	et	2	main
kui	doc_491521502085_item	2580886	et	3	main
te	doc_491521502085_item	2580887	et	4	main
sõlmite	doc_491521502085_item	2580888	et	3	main
uut	doc_491521502085_item	2580889	et	3	main
lepingut	doc_491521502085_item	2580890	et	3	main
olge	doc_491521502085_item	2580891	et	3	main
väga	doc_491521502085_item	2580892	et	3	main
tähelepanelik	doc_491521502085_item	2580893	et	4	main
sõlmides	doc_491521502085_item	2580894	et	4	main
uut	doc_491521502085_item	2580895	et	3	main
lepingut	doc_491521502085_item	2580896	et	3	main
olge	doc_491521502085_item	2580897	et	3	main
väga	doc_491521502085_item	2580898	et	3	main
tähelepanelik	doc_491521502085_item	2580899	et	4	main
3	doc_491521502085_item	2580900	et	2	main
kui	doc_491521502085_item	2580901	et	3	main
võrrelda	doc_491521502085_item	2580902	et	4	main
kesklinnaga	doc_491521502085_item	2580903	et	3	main
on	doc_491521502085_item	2580904	et	4	main
see	doc_491521502085_item	2580905	et	3	main
korter	doc_491521502085_item	2580906	et	3	main
odav	doc_491521502085_item	2580907	et	3	main
võrreldes	doc_491521502085_item	2580908	et	3	main
kesklinnaga	doc_491521502085_item	2580909	et	3	main
on	doc_491521502085_item	2580910	et	4	main
see	doc_491521502085_item	2580911	et	3	main
korter	doc_491521502085_item	2580912	et	3	main
odav	doc_491521502085_item	2580913	et	3	main
4	doc_491521502085_item	2580914	et	2	main
kui	doc_491521502085_item	2580915	et	3	main
lähete	doc_491521502085_item	2580916	et	4	main
korterit	doc_491521502085_item	2580917	et	3	main
üle	doc_491521502085_item	2580918	et	3	main
vaatama	doc_491521502085_item	2580919	et	3	main
mida	doc_491521502085_item	2580835	et	4	main
tähendavad	doc_491521502085_item	2580836	et	4	main
lühendid	doc_491521502085_item	2580838	et	3	main
jne	doc_491521502085_item	2580840	et	4	main
ja	doc_491521502085_item	2580841	et	3	main
nii	doc_491521502085_item	2580842	et	3	main
edasi	doc_491521502085_item	2580843	et	3	main
ja	doc_491521502085_item	2580854	et	3	main
muud	doc_491521502085_item	2580856	et	4	main
lausetest	doc_491521502085_item	2580863	et	4	main
rahalisi	doc_491521502085_item	2580875	et	4	main
korterist	doc_491521502085_item	2580879	et	3	main
kaasa	doc_491521502085_item	2580921	et	4	main
üle	doc_491521502085_item	2580923	et	3	main
vaatamiseks	doc_491521502085_item	2580924	et	4	main
suheldes	doc_491521502085_item	2580933	et	3	main
ndus	doc_491521502085_item	2580943	et	4	main
valima	doc_491521502085_item	2580964	et	3	main
valimine	doc_491521502085_item	2580967	et	4	main
kirjalik	doc_491521502085_item	2580990	et	3	main
9	doc_491521502085_item	2580992	et	2	main
meel	doc_491521502085_item	2581005	et	4	main
meelepärane	doc_491521502085_item	2581007	et	4	main
14	doc_491521502085_item	2581011	et	2	main
päeva	doc_491521502085_item	2581016	et	4	main
seitsme	doc_491521502085_item	2581017	et	3	main
päevane	doc_491521502085_item	2581018	et	4	main
valetamine	doc_491521502085_item	2581025	et	4	main
intervjuu	doc_491521502085_item	2581054	et	4	main
teatatakse	doc_491521502085_item	2581059	et	3	main
7	doc_491521502085_item	2581061	et	2	main
ärge	doc_491521502085_item	2581063	et	3	main
vaatama	doc_491521502085_item	2581066	et	3	main
saapad	doc_491521502086_item	2581090	et	3	main
käed	doc_491521502086_item	2581096	et	3	main
затылке	doc_491521502086_item	2581101	et	2	main
harki	doc_491521502086_item	2581105	et	4	main
расставлены	doc_491521502086_item	2581107	et	2	main
5	doc_491521502086_item	2581112	et	2	main
puutuma	doc_491521502086_item	2581114	et	4	main
tunnustama	doc_491521502086_item	2581117	et	3	main
vaeva	doc_491521502086_item	2581120	et	4	main
kõikuma	doc_491521502086_item	2581125	et	3	main
прямое	doc_491521502086_item	2581129	et	2	main
в	doc_491521502086_item	2581133	et	2	main
rakendust	doc_491521502086_item	2581137	et	4	main
решение	doc_491521502086_item	2581140	et	2	main
наклоняться	doc_491521502086_item	2581146	et	2	main
штаны	doc_491521502086_item	2581151	et	2	main
16	doc_491521502086_item	2581155	et	2	main
teesklema	doc_491521502086_item	2581158	et	3	main
19	doc_491521502086_item	2581163	et	2	main
20	doc_491521502086_item	2581166	et	2	main
me	doc_491521502086_item	2581201	et	4	main
tea	doc_491521502086_item	2581203	et	4	main
kas	doc_491521502086_item	2581204	et	3	main
kirjutatakse	doc_491521502086_item	2581205	et	3	main
lepingule	doc_491521502086_item	2581206	et	3	main
собой	doc_491521502086_item	2581218	et	2	main
suhtlemisoskus	doc_491521502086_item	2581220	et	3	main
tegi	doc_491521502086_item	2581233	et	4	main
eelmise	doc_491521502086_item	2581234	et	3	main
hoolitseme	doc_491521502086_item	2581289	et	3	main
töötajate	doc_491521502086_item	2581292	et	4	main
maakler	doc_491521502086_item	2581303	et	3	main
vaeva	doc_491521502086_item	2581309	et	4	main
seda	doc_491521502086_item	2581311	et	3	main
maha	doc_491521502086_item	2581313	et	4	main
kerkibkaasnebhaldab	doc_491521502086_item	2581318	et	4	main
korteriühistu	doc_491521502086_item	2581319	et	4	main
6	doc_491521502086_item	2581320	et	2	main
järgmised	doc_491521502085_item	2580837	et	3	main
1	doc_491521502085_item	2580839	et	2	main
2	doc_491521502085_item	2580844	et	2	main
va	doc_491521502085_item	2580845	et	3	main
välja	doc_491521502085_item	2580846	et	4	main
öelda	doc_491521502085_item	2580851	et	4	main
kui	doc_491521502085_item	2580867	et	3	main
unistate	doc_491521502085_item	2580869	et	3	main
ärge	doc_491521502085_item	2580872	et	3	main
võimalusi	doc_491521502085_item	2580876	et	3	main
ärge	doc_491521502085_item	2580880	et	3	main
oma	doc_491521502085_item	2580882	et	4	main
abi	doc_491521502085_item	2580932	et	4	main
on	doc_491521502085_item	2580935	et	4	main
abi	doc_491521502085_item	2580938	et	4	main
viii	doc_491521502085_item	2580939	et	4	main
moodustage	doc_491521502085_item	2580940	et	3	main
ja	doc_491521502085_item	2580941	et	3	main
k	doc_491521502085_item	2580946	et	4	main
ne	doc_491521502085_item	2580948	et	4	main
mine	doc_491521502085_item	2580949	et	3	main
valik	doc_491521502085_item	2580966	et	3	main
4	doc_491521502085_item	2580971	et	2	main
8	doc_491521502085_item	2580988	et	2	main
kirjandus	doc_491521502085_item	2580991	et	3	main
üürnik	doc_491521502085_item	2580994	et	3	main
kujundama	doc_491521502085_item	2580997	et	3	main
12	doc_491521502085_item	2581004	et	2	main
valima	doc_491521502085_item	2581012	et	3	main
seitse	doc_491521502085_item	2581015	et	3	main
ix	doc_491521502085_item	2581019	et	4	main
kasutage	doc_491521502085_item	2581020	et	3	main
5	doc_491521502085_item	2580925	et	2	main
kui	doc_491521502085_item	2580926	et	3	main
suhtlete	doc_491521502085_item	2580927	et	3	main
ametnikega	doc_491521502085_item	2580928	et	3	main
on	doc_491521502085_item	2580929	et	4	main
suur	doc_491521502085_item	2580937	et	3	main
pärane	doc_491521502085_item	2580944	et	4	main
line	doc_491521502085_item	2580947	et	4	main
valija	doc_491521502085_item	2580965	et	4	main
3	doc_491521502085_item	2580968	et	2	main
liiget	doc_491521502085_item	2580973	et	3	main
kuue	doc_491521502085_item	2580974	et	4	main
5	doc_491521502085_item	2580976	et	2	main
tootma	doc_491521502085_item	2580977	et	3	main
tootnik	doc_491521502085_item	2580978	et	4	main
suurendus	doc_491521502085_item	2580982	et	4	main
tulema	doc_491521502085_item	2580985	et	4	main
tulek	doc_491521502085_item	2580987	et	3	main
üür	doc_491521502085_item	2580993	et	3	main
10	doc_491521502085_item	2580996	et	2	main
kujundus	doc_491521502085_item	2580998	et	4	main
13	doc_491521502085_item	2581008	et	2	main
15	doc_491521502085_item	2581014	et	2	main
kõneviisi	doc_491521502085_item	2581022	et	4	main
tuleb	doc_491521502085_item	2581027	et	3	main
ruttu	doc_491521502085_item	2581028	et	4	main
kohta	doc_491521502085_item	2581039	et	4	main
negatiivseid	doc_491521502085_item	2581040	et	3	main
asju	doc_491521502085_item	2581041	et	3	main
hoolikalt	doc_491521502085_item	2581045	et	4	main
küsimusi	doc_491521502085_item	2581046	et	4	main
hakkama	doc_491521502085_item	2581048	et	3	main
kontrolltöö	doc_491521502086_item	2581084	et	4	main
с	doc_491521502086_item	2581092	et	2	main
руки	doc_491521502086_item	2581099	et	2	main
jalad	doc_491521502086_item	2581104	et	3	main
ноги	doc_491521502086_item	2581106	et	2	main
4	doc_491521502086_item	2581108	et	2	main
haljastustööd	doc_491521502086_item	2581109	et	4	main
сдвигать	doc_491521502086_item	2581115	et	2	main
7	doc_491521502086_item	2581119	et	2	main
10	doc_491521502086_item	2581131	et	2	main
eelistama	doc_491521502086_item	2581142	et	3	main
13	doc_491521502086_item	2581144	et	2	main
liibuvad	doc_491521502086_item	2581148	et	4	main
ämmaemand	doc_491521502086_item	2581153	et	3	main
спорить	doc_491521502086_item	2581159	et	2	main
плохой	doc_491521502086_item	2581165	et	2	main
специалист	doc_491521502086_item	2581169	et	2	main
нет	doc_491521502086_item	2581200	et	2	main
общаться	doc_491521502086_item	2581216	et	2	main
on	doc_491521502086_item	2581222	et	4	main
aasta	doc_491521502086_item	2581235	et	4	main
kokkuvõtte	doc_491521502086_item	2581236	et	4	main
7	doc_491521502086_item	2581237	et	2	main
кубок	doc_491521502086_item	2581238	et	2	main
завоеванный	doc_491521502086_item	2581239	et	2	main
на	doc_491521502086_item	2581240	et	2	main
соревнованиях	doc_491521502086_item	2581241	et	2	main
8	doc_491521502086_item	2581242	et	2	main
буклет	doc_491521502086_item	2581243	et	2	main
знакомящий	doc_491521502086_item	2581244	et	2	main
с	doc_491521502086_item	2581245	et	2	main
фирмой	doc_491521502086_item	2581246	et	2	main
firma	doc_491521502086_item	2581247	et	4	main
10	doc_491521502086_item	2581266	et	2	main
зазубренные	doc_491521502086_item	2581267	et	2	main
слова	doc_491521502086_item	2581268	et	2	main
tuupitud	doc_491521502086_item	2581272	et	4	main
iii	doc_491521502086_item	2581274	et	4	main
kriipsutage	doc_491521502086_item	2581275	et	3	main
tutvub	doc_491521502086_item	2581283	et	3	main
alati	doc_491521502086_item	2581284	et	4	main
sooduspakkumistega	doc_491521502086_item	2581285	et	3	main
2	doc_491521502086_item	2581286	et	2	main
oma	doc_491521502086_item	2581291	et	4	main
3	doc_491521502086_item	2581294	et	2	main
mainis	doc_491521502086_item	2581296	et	3	main
lobises	doc_491521502086_item	2581297	et	3	main
hoidus	doc_491521502086_item	2581298	et	3	main
intervjuul	doc_491521502086_item	2581299	et	3	main
liiga	doc_491521502086_item	2581300	et	4	main
korda	doc_491521502086_item	2581307	et	4	main
et	doc_491521502086_item	2581310	et	3	main
maaklerist	doc_491521502085_item	2580930	et	3	main
ametnikuga	doc_491521502085_item	2580934	et	3	main
maklerist	doc_491521502085_item	2580936	et	4	main
või	doc_491521502085_item	2580950	et	4	main
kond-	doc_491521502085_item	2580951	et	4	main
1	doc_491521502085_item	2580960	et	2	main
õhk	doc_491521502085_item	2580961	et	3	main
õhkkond	doc_491521502085_item	2580962	et	3	main
meetrit	doc_491521502085_item	2580970	et	3	main
liikne	doc_491521502085_item	2580975	et	4	main
tootmine	doc_491521502085_item	2580979	et	4	main
6	doc_491521502085_item	2580980	et	2	main
7	doc_491521502085_item	2580983	et	2	main
kokku	doc_491521502085_item	2580986	et	3	main
kujundlik	doc_491521502085_item	2580999	et	3	main
aednik	doc_491521502085_item	2581002	et	3	main
meeldimine	doc_491521502085_item	2581006	et	4	main
leppiline	doc_491521502085_item	2581010	et	4	main
valimine	doc_491521502085_item	2581013	et	4	main
käskivat	doc_491521502085_item	2581021	et	4	main
valetama	doc_491521502085_item	2581024	et	3	main
enda	doc_491521502085_item	2581038	et	4	main
4	doc_491521502085_item	2581042	et	2	main
hakkage	doc_491521502085_item	2581050	et	4	main
6	doc_491521502085_item	2581053	et	2	main
millal	doc_491521502085_item	2581058	et	3	main
tulemused	doc_491521502085_item	2581060	et	3	main
tõlkige	doc_491521502086_item	2581086	et	3	main
меховой	doc_491521502086_item	2581093	et	2	main
2	doc_491521502086_item	2581095	et	2	main
taga	doc_491521502086_item	2581098	et	4	main
kokku	doc_491521502086_item	2581113	et	3	main
8	doc_491521502086_item	2581124	et	2	main
otstarve	doc_491521502086_item	2581128	et	3	main
üldjoontes	doc_491521502086_item	2581132	et	3	main
11	doc_491521502086_item	2581136	et	2	main
находить	doc_491521502086_item	2581139	et	2	main
предпочитать	doc_491521502086_item	2581143	et	2	main
14	doc_491521502086_item	2581147	et	2	main
15	doc_491521502086_item	2581152	et	2	main
reostus	doc_491521502086_item	2581156	et	4	main
vilets	doc_491521502086_item	2581164	et	3	main
ii	doc_491521502086_item	2581170	et	4	main
отпуск	doc_491521502086_item	2581173	et	2	main
или	doc_491521502086_item	2581199	et	2	main
ei	doc_491521502086_item	2581202	et	4	main
alla	doc_491521502086_item	2581207	et	3	main
või	doc_491521502086_item	2581208	et	4	main
само	doc_491521502086_item	2581217	et	2	main
suur	doc_491521502085_item	2580981	et	3	main
kokku	doc_491521502085_item	2580984	et	3	main
kiri	doc_491521502085_item	2580989	et	3	main
üüriline	doc_491521502085_item	2580995	et	4	main
11	doc_491521502085_item	2581000	et	2	main
aed	doc_491521502085_item	2581001	et	3	main
aiandus	doc_491521502085_item	2581003	et	3	main
leppima	doc_491521502085_item	2581009	et	3	main
see	doc_491521502085_item	2581026	et	3	main
2	doc_491521502085_item	2581030	et	2	main
säilitama	doc_491521502085_item	2581031	et	4	main
säilitage	doc_491521502085_item	2581032	et	3	main
kuulama	doc_491521502085_item	2581043	et	3	main
5	doc_491521502085_item	2581047	et	2	main
intervjueerijat	doc_491521502085_item	2581051	et	4	main
lõpus	doc_491521502085_item	2581055	et	4	main
hilinema	doc_491521502085_item	2581062	et	3	main
8	doc_491521502085_item	2581065	et	2	main
i	doc_491521502086_item	2581085	et	4	main
1	doc_491521502086_item	2581087	et	2	main
karvase	doc_491521502086_item	2581088	et	4	main
äärega	doc_491521502086_item	2581089	et	3	main
каймой	doc_491521502086_item	2581094	et	2	main
безответственная	doc_491521502086_item	2581110	et	2	main
6	doc_491521502086_item	2581116	et	2	main
признаваться	doc_491521502086_item	2581118	et	2	main
nägema	doc_491521502086_item	2581121	et	3	main
1	doc_491521502085_item	2581023	et	2	main
välja	doc_491521502085_item	2581029	et	4	main
rahu	doc_491521502085_item	2581033	et	4	main
3	doc_491521502085_item	2581034	et	2	main
rääkima	doc_491521502085_item	2581035	et	3	main
ärge	doc_491521502085_item	2581036	et	3	main
rääkige	doc_491521502085_item	2581037	et	3	main
kuulake	doc_491521502085_item	2581044	et	4	main
ärge	doc_491521502085_item	2581049	et	3	main
pahandama	doc_491521502085_item	2581052	et	3	main
küsima	doc_491521502085_item	2581056	et	3	main
küsige	doc_491521502085_item	2581057	et	3	main
hilinege	doc_491521502085_item	2581064	et	3	main
vaatage	doc_491521502085_item	2581067	et	4	main
intervjueerijale	doc_491521502085_item	2581068	et	4	main
silma	doc_491521502085_item	2581069	et	4	main
9	doc_491521502085_item	2581070	et	2	main
kõhklema	doc_491521502085_item	2581071	et	3	main
ärge	doc_491521502085_item	2581072	et	3	main
kõhkelge	doc_491521502085_item	2581073	et	4	main
oma	doc_491521502085_item	2581074	et	4	main
võimetes	doc_491521502085_item	2581075	et	4	main
10	doc_491521502085_item	2581076	et	2	main
püüdma	doc_491521502085_item	2581077	et	3	main
püüdke	doc_491521502085_item	2581078	et	3	main
sarnaneda	doc_491521502085_item	2581079	et	3	main
töökohas	doc_491521502085_item	2581081	et	4	main
levinud	doc_491521502085_item	2581082	et	4	main
stiiliga	doc_491521502085_item	2581083	et	3	main
selles	doc_491521502085_item	2581080	et	4	main
сапоги	doc_491521502086_item	2581091	et	2	main
kukla	doc_491521502086_item	2581097	et	3	main
на	doc_491521502086_item	2581100	et	2	main
3	doc_491521502086_item	2581102	et	2	main
paneb	doc_491521502086_item	2581103	et	3	main
работа	doc_491521502086_item	2581111	et	2	main
хорошо	doc_491521502086_item	2581122	et	2	main
обобщать	doc_491521502086_item	2581126	et	2	main
назначение	doc_491521502086_item	2581130	et	2	main
общих	doc_491521502086_item	2581134	et	2	main
12	doc_491521502086_item	2581141	et	2	main
püksid	doc_491521502086_item	2581149	et	3	main
17	doc_491521502086_item	2581157	et	2	main
18	doc_491521502086_item	2581160	et	2	main
препядствовать	doc_491521502086_item	2581162	et	2	main
компетентный	doc_491521502086_item	2581168	et	2	main
1	doc_491521502086_item	2581172	et	2	main
подписан	doc_491521502086_item	2581198	et	2	main
ei	doc_491521502086_item	2581209	et	4	main
4	doc_491521502086_item	2581210	et	2	main
по	doc_491521502086_item	2581211	et	2	main
глупой	doc_491521502086_item	2581212	et	2	main
случайности	doc_491521502086_item	2581213	et	2	main
5	doc_491521502086_item	2581214	et	2	main
разумеется	doc_491521502086_item	2581219	et	2	main
välja	doc_491521502086_item	2581223	et	4	main
oskus	doc_491521502086_item	2581225	et	3	main
начальник	doc_491521502086_item	2581227	et	2	main
подвел	doc_491521502086_item	2581228	et	2	main
прошедшего	doc_491521502086_item	2581230	et	2	main
pähe	doc_491521502086_item	2581269	et	4	main
õppitud	doc_491521502086_item	2581270	et	4	main
sõnad	doc_491521502086_item	2581271	et	4	main
maha	doc_491521502086_item	2581276	et	4	main
sobimatud	doc_491521502086_item	2581277	et	4	main
me	doc_491521502086_item	2581287	et	4	main
palju	doc_491521502086_item	2581301	et	4	main
4	doc_491521502086_item	2581302	et	2	main
ajas	doc_491521502086_item	2581306	et	4	main
5	doc_491521502086_item	2581315	et	2	main
maja	doc_491521502086_item	2581317	et	4	main
töötajaid	doc_491521502086_item	2581323	et	4	main
tootmisliini	doc_491521502086_item	2581326	et	4	main
käivitamisega	doc_491521502086_item	2581328	et	4	main
viisime	doc_491521502086_item	2581332	et	4	main
küsitluse	doc_491521502086_item	2581334	et	4	main
küsimustikukõmu	doc_491521502086_item	2581335	et	4	main
tööandjate	doc_491521502086_item	2581336	et	3	main
krae	doc_491521502086_item	2581343	et	4	main
murdus	doc_491521502086_item	2581344	et	3	main
tänavail	doc_491521502086_item	2581352	et	4	main
10	doc_491521502086_item	2581353	et	2	main
endist	doc_491521502086_item	2581361	et	4	main
1	doc_491521502086_item	2581367	et	2	main
teiega	doc_491521502086_item	2581382	et	3	main
3	doc_491521502086_item	2581387	et	2	main
ehitustöid	doc_491521502086_item	2581391	et	3	main
4	doc_491521502086_item	2581395	et	2	main
saadavad	doc_491521502086_item	2581397	et	4	main
ühe	doc_491521502086_item	2581400	et	4	main
ühe	doc_491521502086_item	2581407	et	4	main
выглядеть	doc_491521502086_item	2581123	et	2	main
9	doc_491521502086_item	2581127	et	2	main
чертах	doc_491521502086_item	2581135	et	2	main
leidma	doc_491521502086_item	2581138	et	3	main
kummarduma	doc_491521502086_item	2581145	et	3	main
облегающие	doc_491521502086_item	2581150	et	2	main
няня	doc_491521502086_item	2581154	et	2	main
takistama	doc_491521502086_item	2581161	et	3	main
asjatundlik	doc_491521502086_item	2581167	et	3	main
tõlkige	doc_491521502086_item	2581171	et	3	main
проведенный	doc_491521502086_item	2581174	et	2	main
в	doc_491521502086_item	2581175	et	2	main
деревне	doc_491521502086_item	2581176	et	2	main
läbi	doc_491521502086_item	2581177	et	4	main
viidud	doc_491521502086_item	2581178	et	4	main
maal	doc_491521502086_item	2581179	et	4	main
puhkus	doc_491521502086_item	2581180	et	3	main
2	doc_491521502086_item	2581181	et	2	main
привезенный	doc_491521502086_item	2581183	et	2	main
товар	doc_491521502086_item	2581182	et	2	main
с	doc_491521502086_item	2581184	et	2	main
нового	doc_491521502086_item	2581185	et	2	main
оптового	doc_491521502086_item	2581186	et	2	main
склада	doc_491521502086_item	2581187	et	2	main
uuest	doc_491521502086_item	2581188	et	3	main
kaupalaost	doc_491521502086_item	2581189	et	3	main
toode	doc_491521502086_item	2581191	et	3	main
3	doc_491521502086_item	2581192	et	2	main
не	doc_491521502086_item	2581194	et	2	main
мы	doc_491521502086_item	2581193	et	2	main
viidud	doc_491521502086_item	2581190	et	4	main
знаем	doc_491521502086_item	2581195	et	2	main
будет	doc_491521502086_item	2581196	et	2	main
договор	doc_491521502086_item	2581197	et	2	main
умение	doc_491521502086_item	2581215	et	2	main
see	doc_491521502086_item	2581221	et	3	main
arvatud	doc_491521502086_item	2581224	et	4	main
6	doc_491521502086_item	2581226	et	2	main
итоги	doc_491521502086_item	2581229	et	2	main
сезона	doc_491521502086_item	2581231	et	2	main
ülemus	doc_491521502086_item	2581232	et	4	main
tutvustav	doc_491521502086_item	2581248	et	4	main
voldik	doc_491521502086_item	2581249	et	3	main
9	doc_491521502086_item	2581250	et	2	main
не	doc_491521502086_item	2581251	et	2	main
знаете	doc_491521502086_item	2581252	et	2	main
sõnad	doc_491521502086_item	2581278	et	4	main
1	doc_491521502086_item	2581279	et	2	main
teadlik	doc_491521502086_item	2581280	et	3	main
hooldame	doc_491521502086_item	2581288	et	3	main
eest	doc_491521502086_item	2581293	et	4	main
tööotsija	doc_491521502086_item	2581295	et	4	main
läbi	doc_491521502086_item	2581305	et	4	main
uue	doc_491521502086_item	2581325	et	3	main
meelitamisega	doc_491521502086_item	2581329	et	4	main
tema	doc_491521502086_item	2581339	et	4	main
kinga	doc_491521502086_item	2581340	et	4	main
sellele	doc_491521502086_item	2581355	et	4	main
rõhutas	doc_491521502086_item	2581356	et	3	main
iv	doc_491521502086_item	2581363	et	4	main
muutke	doc_491521502086_item	2581364	et	3	main
seadus	doc_491521502086_item	2581368	et	4	main
lastel	doc_491521502086_item	2581371	et	4	main
täisajaga	doc_491521502086_item	2581373	et	3	main
võetakse	doc_491521502086_item	2581385	et	3	main
juurest	doc_491521502086_item	2581401	et	4	main
nõusolekul	doc_491521502086_item	2581431	et	3	main
7	doc_491521502086_item	2581438	et	2	main
firma	doc_491521502086_item	2581439	et	4	main
8	doc_491521502086_item	2581447	et	2	main
ansambel	doc_491521502086_item	2581448	et	3	main
uusi	doc_491521502086_item	2581455	et	3	main
erialast	doc_491521502086_item	2581461	et	4	main
loetakse	doc_491521502086_item	2581464	et	3	main
kirjandust	doc_491521502086_item	2581466	et	3	main
tavaliselt	doc_491521502086_item	2581468	et	4	main
pakuvad	doc_491521502086_item	2581469	et	3	main
asutused	doc_491521502086_item	2581470	et	4	main
lapsele	doc_491521502086_item	2581475	et	4	main
abitööd	doc_491521502086_item	2581476	et	4	main
tundma	doc_491521502086_item	2581486	et	3	main
meelepärane	doc_491521502086_item	2581502	et	4	main
kontakti	doc_491521502086_item	2581511	et	4	main
leida	doc_491521502086_item	2581512	et	3	main
ajas	doc_491521502086_item	2581518	et	4	main
alustas	doc_491521502086_item	2581522	et	3	main
välja	doc_491521502086_item	2581524	et	4	main
rusikasse	doc_491521502086_item	2581533	et	4	main
mulle	doc_491521502086_item	2581536	et	4	main
et	doc_491521502086_item	2581537	et	3	main
mina	doc_491521502086_item	2581538	et	4	main
olen	doc_491521502086_item	2581539	et	3	main
paha	doc_491521502086_item	2581540	et	4	main
inimene	doc_491521502086_item	2581541	et	3	main
ja	doc_491521502086_item	2581550	et	3	main
nn	doc_491521502086_item	2581566	et	4	main
nii	doc_491521502086_item	2581567	et	3	main
unistades	doc_491521502086_item	2581587	et	3	main
rahalisi	doc_491521502086_item	2581591	et	4	main
uuest	doc_491521502086_item	2581594	et	3	main
ärge	doc_491521502086_item	2581596	et	3	main
oma	doc_491521502086_item	2581598	et	4	main
2	doc_491521502086_item	2581601	et	2	main
uut	doc_491521502086_item	2581605	et	3	main
tähelepanelik	doc_491521502086_item	2581615	et	4	main
olge	doc_491521502086_item	2581619	et	3	main
tähelepanelik	doc_491521502086_item	2581621	et	4	main
on	doc_491521502086_item	2581626	et	4	main
korter	doc_491521502086_item	2581628	et	3	main
kesklinnaga	doc_491521502086_item	2581630	et	3	main
kui	doc_491521502086_item	2581643	et	3	main
korterit	doc_491521502086_item	2581645	et	3	main
kaasa	doc_491521502086_item	2581649	et	4	main
asjatundja	doc_491521502086_item	2581650	et	4	main
ли	doc_491521502086_item	2581253	et	2	main
вы	doc_491521502086_item	2581254	et	2	main
где	doc_491521502086_item	2581255	et	2	main
директор	doc_491521502086_item	2581256	et	2	main
по	doc_491521502086_item	2581257	et	2	main
сбыту	doc_491521502086_item	2581258	et	2	main
ega	doc_491521502086_item	2581259	et	3	main
te	doc_491521502086_item	2581260	et	4	main
ei	doc_491521502086_item	2581261	et	4	main
tea	doc_491521502086_item	2581262	et	4	main
kus	doc_491521502086_item	2581263	et	3	main
on	doc_491521502086_item	2581264	et	4	main
turundusdirektor	doc_491521502086_item	2581265	et	3	main
sõnad	doc_491521502086_item	2581273	et	4	main
üleolevüllatunud	doc_491521502086_item	2581281	et	4	main
tarbija	doc_491521502086_item	2581282	et	4	main
hoolime	doc_491521502086_item	2581290	et	3	main
lasi	doc_491521502086_item	2581304	et	4	main
nägi	doc_491521502086_item	2581308	et	3	main
müüa	doc_491521502086_item	2581314	et	3	main
seda	doc_491521502086_item	2581316	et	3	main
otsib	doc_491521502086_item	2581322	et	3	main
kehtestamisega	doc_491521502086_item	2581327	et	4	main
me	doc_491521502086_item	2581331	et	4	main
läbi	doc_491521502086_item	2581333	et	4	main
varrukas	doc_491521502086_item	2581341	et	4	main
konts	doc_491521502086_item	2581342	et	3	main
jagunevad	doc_491521502086_item	2581350	et	4	main
hulguvad	doc_491521502086_item	2581351	et	3	main
oma	doc_491521502086_item	2581360	et	4	main
umbisikuliseks	doc_491521502086_item	2581366	et	4	main
lastel	doc_491521502086_item	2581374	et	4	main
ei	doc_491521502086_item	2581375	et	4	main
loata	doc_491521502086_item	2581376	et	4	main
töötada	doc_491521502086_item	2581377	et	3	main
täisajaga	doc_491521502086_item	2581378	et	3	main
2	doc_491521502086_item	2581379	et	2	main
ametnik	doc_491521502086_item	2581380	et	3	main
võtab	doc_491521502086_item	2581381	et	3	main
ühendust	doc_491521502086_item	2581386	et	4	main
teeb	doc_491521502086_item	2581389	et	3	main
tehakse	doc_491521502086_item	2581392	et	3	main
juurde	doc_491521502086_item	2581403	et	4	main
juurest	doc_491521502086_item	2581409	et	4	main
ei	doc_491521502086_item	2581421	et	4	main
piisavalt	doc_491521502086_item	2581423	et	4	main
6	doc_491521502086_item	2581424	et	2	main
kirjalikul	doc_491521502086_item	2581430	et	3	main
vanema	doc_491521502086_item	2581435	et	4	main
juht	doc_491521502086_item	2581440	et	3	main
kirjutab	doc_491521502086_item	2581441	et	3	main
lepingule	doc_491521502086_item	2581442	et	3	main
alla	doc_491521502086_item	2581443	et	3	main
lepingule	doc_491521502086_item	2581444	et	3	main
kirjutatakse	doc_491521502086_item	2581445	et	3	main
alla	doc_491521502086_item	2581446	et	3	main
esineb	doc_491521502086_item	2581449	et	3	main
laule	doc_491521502086_item	2581456	et	4	main
raamatukogus	doc_491521502086_item	2581460	et	4	main
abitööd	doc_491521502086_item	2581472	et	4	main
1	doc_491521502086_item	2581482	et	2	main
panid	doc_491521502086_item	2581489	et	4	main
2	doc_491521502086_item	2581493	et	2	main
korteri	doc_491521502086_item	2581496	et	3	main
tüütas	doc_491521502086_item	2581498	et	3	main
on	doc_491521502086_item	2581504	et	4	main
tõesti	doc_491521502086_item	2581505	et	3	main
meelepärane	doc_491521502086_item	2581506	et	4	main
inimene	doc_491521502086_item	2581507	et	3	main
vana	doc_491521502086_item	2581516	et	4	main
oma	doc_491521502086_item	2581531	et	4	main
järgmised	doc_491521502086_item	2581546	et	3	main
lühendid	doc_491521502086_item	2581547	et	3	main
2	doc_491521502086_item	2581553	et	2	main
muud	doc_491521502086_item	2581564	et	4	main
5	doc_491521502086_item	2581565	et	2	main
vii	doc_491521502086_item	2581569	et	4	main
des-lauselühendiga	doc_491521502086_item	2581572	et	3	main
1	doc_491521502086_item	2581574	et	2	main
te	doc_491521502086_item	2581576	et	4	main
uuest	doc_491521502086_item	2581578	et	3	main
korterist	doc_491521502086_item	2581579	et	3	main
ärge	doc_491521502086_item	2581580	et	3	main
oma	doc_491521502086_item	2581590	et	4	main
unistades	doc_491521502086_item	2581593	et	3	main
3	doc_491521502086_item	2581622	et	2	main
see	doc_491521502086_item	2581633	et	3	main
võrreldes	doc_491521502086_item	2581636	et	3	main
on	doc_491521502086_item	2581638	et	4	main
korter	doc_491521502086_item	2581640	et	3	main
odav	doc_491521502086_item	2581641	et	3	main
asjatundja	doc_491521502086_item	2581656	et	4	main
5	doc_491521502086_item	2581657	et	2	main
kui	doc_491521502086_item	2581658	et	3	main
korterit	doc_491521502086_item	2581312	et	3	main
firma	doc_491521502086_item	2581321	et	4	main
seas	doc_491521502086_item	2581337	et	4	main
8	doc_491521502086_item	2581338	et	2	main
pooleks	doc_491521502086_item	2581345	et	4	main
9	doc_491521502086_item	2581346	et	2	main
lisaks	doc_491521502086_item	2581354	et	4	main
ülemust	doc_491521502086_item	2581362	et	4	main
ei	doc_491521502086_item	2581369	et	4	main
luba	doc_491521502086_item	2581370	et	4	main
töötada	doc_491521502086_item	2581372	et	3	main
teiega	doc_491521502086_item	2581384	et	3	main
firma	doc_491521502086_item	2581388	et	4	main
mitmesuguseid	doc_491521502086_item	2581393	et	3	main
ametnikud	doc_491521502086_item	2581398	et	3	main
teise	doc_491521502086_item	2581402	et	4	main
saadetakse	doc_491521502086_item	2581405	et	3	main
ametniku	doc_491521502086_item	2581408	et	3	main
teise	doc_491521502086_item	2581410	et	4	main
hinnata	doc_491521502086_item	2581422	et	4	main
tööandja	doc_491521502086_item	2581425	et	4	main
sõlmib	doc_491521502086_item	2581426	et	3	main
lapsega	doc_491521502086_item	2581427	et	3	main
lapsega	doc_491521502086_item	2581432	et	3	main
töölepingu	doc_491521502086_item	2581434	et	4	main
kirjalikul	doc_491521502086_item	2581436	et	3	main
nõusolekul	doc_491521502086_item	2581437	et	3	main
lauludega	doc_491521502086_item	2581452	et	3	main
kontserdil	doc_491521502086_item	2581453	et	3	main
üliõpilane	doc_491521502086_item	2581458	et	3	main
lapsele	doc_491521502086_item	2581471	et	4	main
v	doc_491521502086_item	2581477	et	4	main
moodustage	doc_491521502086_item	2581478	et	3	main
laused	doc_491521502086_item	2581479	et	3	main
järgmiste	doc_491521502086_item	2581480	et	3	main
sõnaühenditega	doc_491521502086_item	2581481	et	3	main
piinlikkust	doc_491521502086_item	2581485	et	4	main
juhataja	doc_491521502086_item	2581487	et	4	main
sõnad	doc_491521502086_item	2581488	et	4	main
piinlikust	doc_491521502086_item	2581491	et	4	main
mind	doc_491521502086_item	2581499	et	4	main
ära	doc_491521502086_item	2581500	et	4	main
3	doc_491521502086_item	2581501	et	2	main
kellega	doc_491521502086_item	2581508	et	3	main
on	doc_491521502086_item	2581509	et	4	main
lihtne	doc_491521502086_item	2581510	et	3	main
tädike	doc_491521502086_item	2581517	et	4	main
5	doc_491521502086_item	2581526	et	2	main
ta	doc_491521502086_item	2581529	et	4	main
pigistas	doc_491521502086_item	2581530	et	3	main
vi	doc_491521502086_item	2581542	et	4	main
kirjutage	doc_491521502086_item	2581543	et	3	main
mida	doc_491521502086_item	2581544	et	4	main
edasi	doc_491521502086_item	2581552	et	3	main
moodustage	doc_491521502086_item	2581570	et	3	main
oma	doc_491521502086_item	2581582	et	4	main
rahalisi	doc_491521502086_item	2581583	et	4	main
võimalusi	doc_491521502086_item	2581584	et	3	main
uuest	doc_491521502086_item	2581585	et	3	main
korterist	doc_491521502086_item	2581586	et	3	main
kui	doc_491521502086_item	2581602	et	3	main
sõlmite	doc_491521502086_item	2581604	et	3	main
olge	doc_491521502086_item	2581607	et	3	main
sõlmides	doc_491521502086_item	2581612	et	4	main
olge	doc_491521502086_item	2581613	et	3	main
uut	doc_491521502086_item	2581617	et	3	main
lepingut	doc_491521502086_item	2581618	et	3	main
võrreldes	doc_491521502086_item	2581631	et	3	main
see	doc_491521502086_item	2581639	et	3	main
suur	doc_491521502086_item	2581669	et	3	main
ametnikega	doc_491521502086_item	2581671	et	3	main
on	doc_491521502086_item	2581673	et	4	main
suur	doc_491521502086_item	2581675	et	3	main
või	doc_491521502086_item	2581688	et	4	main
seoses	doc_491521502086_item	2581324	et	4	main
7	doc_491521502086_item	2581330	et	2	main
tegevuseta	doc_491521502086_item	2581347	et	4	main
noorukid	doc_491521502086_item	2581348	et	3	main
järeldavad	doc_491521502086_item	2581349	et	4	main
süüdistas	doc_491521502086_item	2581357	et	3	main
teeskles	doc_491521502086_item	2581358	et	3	main
ta	doc_491521502086_item	2581359	et	4	main
laused	doc_491521502086_item	2581365	et	3	main
ühendust	doc_491521502086_item	2581383	et	4	main
mitmesuguseid	doc_491521502086_item	2581390	et	3	main
ehitustöid	doc_491521502086_item	2581394	et	3	main
tihti	doc_491521502086_item	2581396	et	3	main
tööotsijat	doc_491521502086_item	2581399	et	3	main
tihti	doc_491521502086_item	2581404	et	3	main
tööotsijat	doc_491521502086_item	2581406	et	3	main
juurde	doc_491521502086_item	2581411	et	4	main
5	doc_491521502086_item	2581412	et	2	main
nad	doc_491521502086_item	2581413	et	3	main
ei	doc_491521502086_item	2581414	et	4	main
hinda	doc_491521502086_item	2581415	et	4	main
tema	doc_491521502086_item	2581416	et	4	main
tööd	doc_491521502086_item	2581417	et	4	main
piisavalt	doc_491521502086_item	2581418	et	4	main
tema	doc_491521502086_item	2581419	et	4	main
tööd	doc_491521502086_item	2581420	et	4	main
sõlmitakse	doc_491521502086_item	2581433	et	3	main
uute	doc_491521502086_item	2581451	et	3	main
9	doc_491521502086_item	2581457	et	2	main
loeb	doc_491521502086_item	2581459	et	3	main
raamatukogus	doc_491521502086_item	2581463	et	4	main
tavaliselt	doc_491521502086_item	2581473	et	4	main
pakutakse	doc_491521502086_item	2581474	et	3	main
mind	doc_491521502086_item	2581484	et	4	main
mind	doc_491521502086_item	2581490	et	4	main
tüütama	doc_491521502086_item	2581495	et	3	main
koristamine	doc_491521502086_item	2581497	et	4	main
ajama	doc_491521502086_item	2581515	et	4	main
vihale	doc_491521502086_item	2581520	et	4	main
töölepingu	doc_491521502086_item	2581428	et	4	main
vanema	doc_491521502086_item	2581429	et	4	main
kontserdil	doc_491521502086_item	2581450	et	3	main
esinetakse	doc_491521502086_item	2581454	et	3	main
kirjandust	doc_491521502086_item	2581462	et	3	main
erialast	doc_491521502086_item	2581465	et	4	main
10	doc_491521502086_item	2581467	et	2	main
paneb	doc_491521502086_item	2581483	et	3	main
tundma	doc_491521502086_item	2581492	et	3	main
ära	doc_491521502086_item	2581494	et	4	main
ta	doc_491521502086_item	2581503	et	4	main
4	doc_491521502086_item	2581513	et	2	main
vihale	doc_491521502086_item	2581514	et	4	main
mind	doc_491521502086_item	2581519	et	4	main
minna	doc_491521502086_item	2581525	et	3	main
rusikasse	doc_491521502086_item	2581527	et	4	main
pigistama	doc_491521502086_item	2581528	et	3	main
kätte	doc_491521502086_item	2581532	et	4	main
nii	doc_491521502086_item	2581551	et	3	main
nimetatud	doc_491521502086_item	2581568	et	4	main
lausetest	doc_491521502086_item	2581571	et	4	main
laused	doc_491521502086_item	2581573	et	3	main
kui	doc_491521502086_item	2581575	et	3	main
unistate	doc_491521502086_item	2581577	et	3	main
unustage	doc_491521502086_item	2581581	et	3	main
unustage	doc_491521502086_item	2581589	et	3	main
võimalusi	doc_491521502086_item	2581592	et	3	main
korterist	doc_491521502086_item	2581595	et	3	main
unustage	doc_491521502086_item	2581597	et	3	main
rahalisi	doc_491521502086_item	2581599	et	4	main
võimalusi	doc_491521502086_item	2581600	et	3	main
tähelepanelik	doc_491521502086_item	2581609	et	4	main
lepingut	doc_491521502086_item	2581611	et	3	main
väga	doc_491521502086_item	2581614	et	3	main
väga	doc_491521502086_item	2581620	et	3	main
kui	doc_491521502086_item	2581623	et	3	main
kesklinnaga	doc_491521502086_item	2581625	et	3	main
on	doc_491521502086_item	2581632	et	4	main
kaasa	doc_491521502086_item	2581655	et	4	main
on	doc_491521502086_item	2581667	et	4	main
nik	doc_491521502086_item	2581680	et	4	main
line	doc_491521502086_item	2581685	et	4	main
mine	doc_491521502086_item	2581687	et	3	main
suurendus	doc_491521502086_item	2581724	et	4	main
kokku	doc_491521502086_item	2581727	et	3	main
kokkutulek	doc_491521502086_item	2581729	et	3	main
kiri	doc_491521502086_item	2581731	et	3	main
kirjalik	doc_491521502086_item	2581734	et	3	main
aed	doc_491521502086_item	2581744	et	3	main
12	doc_491521502086_item	2581747	et	2	main
meelepärane	doc_491521502086_item	2581749	et	4	main
valima	doc_491521502086_item	2581754	et	3	main
valija	doc_491521502086_item	2581755	et	4	main
valdkond	doc_491521502086_item	2581756	et	3	main
2	doc_491521502086_item	2581774	et	2	main
säilitama	doc_491521502086_item	2581775	et	4	main
säilitage	doc_491521502086_item	2581776	et	3	main
rahu	doc_491521502086_item	2581777	et	4	main
3	doc_491521502086_item	2581778	et	2	main
enda	doc_491521502086_item	2581782	et	4	main
asju	doc_491521502086_item	2581785	et	3	main
kuulake	doc_491521502086_item	2581788	et	4	main
küsimusi	doc_491521502086_item	2581790	et	4	main
5	doc_491521502086_item	2581791	et	2	main
hakkama	doc_491521502086_item	2581792	et	3	main
ärge	doc_491521502086_item	2581793	et	3	main
hakake	doc_491521502086_item	2581794	et	3	main
püüdke	doc_491521502086_item	2581822	et	3	main
töökohas	doc_491521502086_item	2581825	et	4	main
levinud	doc_491521502086_item	2581826	et	4	main
1	doc_491521502087_item	2581831	et	2	main
опушкой	doc_491521502087_item	2581837	et	2	main
озеленению	doc_491521502087_item	2581857	et	2	main
vaeva	doc_491521502087_item	2581866	et	4	main
8	doc_491521502087_item	2581870	et	2	main
10	doc_491521502087_item	2581877	et	2	main
чертах	doc_491521502087_item	2581881	et	2	main
asjatundlik	doc_491521502087_item	2581917	et	3	main
отпуск	doc_491521502087_item	2581923	et	2	main
veedetud	doc_491521502087_item	2581928	et	4	main
привезенный	doc_491521502087_item	2581932	et	2	main
kui	doc_491521502086_item	2581521	et	3	main
bussist	doc_491521502086_item	2581523	et	3	main
millega	doc_491521502086_item	2581534	et	3	main
näidis	doc_491521502086_item	2581535	et	4	main
tähendavad	doc_491521502086_item	2581545	et	4	main
1	doc_491521502086_item	2581548	et	2	main
jne	doc_491521502086_item	2581549	et	4	main
va	doc_491521502086_item	2581554	et	3	main
välja	doc_491521502086_item	2581555	et	4	main
arvatud	doc_491521502086_item	2581556	et	4	main
3	doc_491521502086_item	2581557	et	2	main
nii	doc_491521502086_item	2581559	et	3	main
öeldakse	doc_491521502086_item	2581560	et	3	main
n-ö	doc_491521502086_item	2581558	et	4	main
4	doc_491521502086_item	2581561	et	2	main
jm	doc_491521502086_item	2581562	et	4	main
ja	doc_491521502086_item	2581563	et	3	main
ärge	doc_491521502086_item	2581588	et	3	main
te	doc_491521502086_item	2581603	et	4	main
lepingut	doc_491521502086_item	2581606	et	3	main
väga	doc_491521502086_item	2581608	et	3	main
uut	doc_491521502086_item	2581610	et	3	main
sõlmides	doc_491521502086_item	2581616	et	4	main
võrrelda	doc_491521502086_item	2581624	et	4	main
see	doc_491521502086_item	2581627	et	3	main
odav	doc_491521502086_item	2581629	et	3	main
korter	doc_491521502086_item	2581634	et	3	main
odav	doc_491521502086_item	2581635	et	3	main
kesklinnaga	doc_491521502086_item	2581637	et	3	main
4	doc_491521502086_item	2581642	et	2	main
lähete	doc_491521502086_item	2581644	et	4	main
üle	doc_491521502086_item	2581646	et	3	main
vaatama	doc_491521502086_item	2581647	et	3	main
võtke	doc_491521502086_item	2581648	et	3	main
ametnikega	doc_491521502086_item	2581660	et	3	main
on	doc_491521502086_item	2581661	et	4	main
maaklerist	doc_491521502086_item	2581662	et	3	main
suur	doc_491521502086_item	2581663	et	3	main
abi	doc_491521502086_item	2581664	et	4	main
suheldes	doc_491521502086_item	2581665	et	3	main
ametnikega	doc_491521502086_item	2581666	et	3	main
abi	doc_491521502086_item	2581676	et	4	main
viii	doc_491521502086_item	2581677	et	4	main
moodustage	doc_491521502086_item	2581678	et	3	main
ja	doc_491521502086_item	2581679	et	3	main
ng	doc_491521502086_item	2581683	et	4	main
ne	doc_491521502086_item	2581686	et	4	main
sõnad	doc_491521502086_item	2581691	et	4	main
sõnal	doc_491521502086_item	2581693	et	3	main
võib	doc_491521502086_item	2581694	et	3	main
olla	doc_491521502086_item	2581695	et	3	main
mitu	doc_491521502086_item	2581696	et	4	main
varianti	doc_491521502086_item	2581697	et	4	main
1	doc_491521502086_item	2581698	et	2	main
õhk	doc_491521502086_item	2581699	et	3	main
õhkkond	doc_491521502086_item	2581700	et	3	main
õhupärane	doc_491521502086_item	2581701	et	4	main
õhuline	doc_491521502086_item	2581702	et	4	main
2	doc_491521502086_item	2581703	et	2	main
valima	doc_491521502086_item	2581704	et	3	main
valdkond	doc_491521502086_item	2581705	et	3	main
valija	doc_491521502086_item	2581706	et	4	main
valimine	doc_491521502086_item	2581707	et	4	main
3	doc_491521502086_item	2581708	et	2	main
pool	doc_491521502086_item	2581709	et	4	main
meetrit	doc_491521502086_item	2581710	et	3	main
poolmeetrine	doc_491521502086_item	2581711	et	4	main
4	doc_491521502086_item	2581712	et	2	main
kuus	doc_491521502086_item	2581713	et	4	main
liiget	doc_491521502086_item	2581714	et	3	main
5	doc_491521502086_item	2581716	et	2	main
kuueliigne	doc_491521502086_item	2581715	et	3	main
tootma	doc_491521502086_item	2581717	et	3	main
tootmine	doc_491521502086_item	2581718	et	4	main
toodang	doc_491521502086_item	2581719	et	3	main
tootja	doc_491521502086_item	2581720	et	4	main
suur	doc_491521502086_item	2581722	et	3	main
kujundaja	doc_491521502086_item	2581741	et	4	main
aednik	doc_491521502086_item	2581745	et	3	main
korterit	doc_491521502086_item	2581651	et	3	main
üle	doc_491521502086_item	2581652	et	3	main
vaadates	doc_491521502086_item	2581653	et	3	main
võtke	doc_491521502086_item	2581654	et	3	main
abi	doc_491521502086_item	2581670	et	4	main
ndus	doc_491521502086_item	2581681	et	4	main
k	doc_491521502086_item	2581684	et	4	main
7	doc_491521502086_item	2581726	et	2	main
8	doc_491521502086_item	2581730	et	2	main
üürnik	doc_491521502086_item	2581737	et	3	main
11	doc_491521502086_item	2581743	et	2	main
valimine	doc_491521502086_item	2581757	et	4	main
15	doc_491521502086_item	2581758	et	2	main
päeva	doc_491521502086_item	2581760	et	4	main
käskivat	doc_491521502086_item	2581764	et	4	main
hoolikalt	doc_491521502086_item	2581789	et	4	main
7	doc_491521502086_item	2581805	et	2	main
hilinema	doc_491521502086_item	2581806	et	3	main
ärge	doc_491521502086_item	2581807	et	3	main
hilinege	doc_491521502086_item	2581808	et	3	main
i	doc_491521502087_item	2581829	et	4	main
karvase	doc_491521502087_item	2581832	et	4	main
saapad	doc_491521502087_item	2581834	et	3	main
по	doc_491521502087_item	2581838	et	2	main
käed	doc_491521502087_item	2581841	et	3	main
на	doc_491521502087_item	2581845	et	2	main
3	doc_491521502087_item	2581847	et	2	main
harki	doc_491521502087_item	2581850	et	4	main
4	doc_491521502087_item	2581853	et	2	main
работы	doc_491521502087_item	2581855	et	2	main
puutuma	doc_491521502087_item	2581860	et	4	main
признавать	doc_491521502087_item	2581864	et	2	main
nägema	doc_491521502087_item	2581867	et	3	main
kõikuma	doc_491521502087_item	2581871	et	3	main
otstarve	doc_491521502087_item	2581874	et	3	main
üldjoontes	doc_491521502087_item	2581878	et	3	main
rakendust	doc_491521502087_item	2581883	et	4	main
ii	doc_491521502087_item	2581920	et	4	main
tõlkige	doc_491521502087_item	2581921	et	3	main
деревне	doc_491521502087_item	2581926	et	2	main
с	doc_491521502087_item	2581933	et	2	main
uuest	doc_491521502087_item	2581937	et	3	main
будет	doc_491521502087_item	2581945	et	2	main
me	doc_491521502087_item	2581950	et	4	main
ei	doc_491521502087_item	2581951	et	4	main
kas	doc_491521502087_item	2581953	et	3	main
leping	doc_491521502087_item	2581954	et	3	main
kirjutatakse	doc_491521502087_item	2581955	et	3	main
alla	doc_491521502087_item	2581956	et	3	main
подвел	doc_491521502087_item	2581978	et	2	main
сезона	doc_491521502087_item	2581981	et	2	main
кубок	doc_491521502087_item	2581988	et	2	main
на	doc_491521502087_item	2581990	et	2	main
знакомящий	doc_491521502087_item	2581994	et	2	main
firmaga	doc_491521502087_item	2581997	et	3	main
знаете	doc_491521502087_item	2582002	et	2	main
по	doc_491521502087_item	2582007	et	2	main
aga	doc_491521502087_item	2582009	et	3	main
10	doc_491521502087_item	2582017	et	2	main
iii	doc_491521502087_item	2582023	et	4	main
maha	doc_491521502087_item	2582025	et	4	main
tutvub	doc_491521502087_item	2582032	et	3	main
hoolitseme	doc_491521502087_item	2582038	et	3	main
eest	doc_491521502087_item	2582042	et	4	main
4	doc_491521502087_item	2582051	et	2	main
nägi	doc_491521502087_item	2582056	et	3	main
et	doc_491521502087_item	2582058	et	3	main
müüa	doc_491521502087_item	2582062	et	3	main
seoses	doc_491521502087_item	2582073	et	4	main
7	doc_491521502087_item	2582079	et	2	main
kinga	doc_491521502087_item	2582090	et	4	main
varrukas	doc_491521502087_item	2582091	et	4	main
konts	doc_491521502087_item	2582092	et	3	main
krae	doc_491521502087_item	2582093	et	4	main
lisaks	doc_491521502087_item	2582103	et	4	main
töötada	doc_491521502087_item	2582121	et	3	main
teiega	doc_491521502087_item	2582131	et	3	main
ametnikud	doc_491521502087_item	2582147	et	3	main
juurest	doc_491521502087_item	2582157	et	4	main
teise	doc_491521502087_item	2582158	et	4	main
juurde	doc_491521502087_item	2582159	et	4	main
5	doc_491521502087_item	2582160	et	2	main
suhtlete	doc_491521502086_item	2581659	et	3	main
maaklerist	doc_491521502086_item	2581668	et	3	main
suheldes	doc_491521502086_item	2581672	et	3	main
maaklerist	doc_491521502086_item	2581674	et	3	main
pärane	doc_491521502086_item	2581682	et	4	main
kond-	doc_491521502086_item	2581689	et	4	main
liitelised	doc_491521502086_item	2581690	et	4	main
ühel	doc_491521502086_item	2581692	et	3	main
6	doc_491521502086_item	2581721	et	2	main
suurepärane	doc_491521502086_item	2581723	et	4	main
üür	doc_491521502086_item	2581736	et	3	main
üürija	doc_491521502086_item	2581738	et	4	main
kujundamine	doc_491521502086_item	2581742	et	4	main
seitse	doc_491521502086_item	2581759	et	3	main
kasutage	doc_491521502086_item	2581763	et	3	main
1	doc_491521502086_item	2581766	et	2	main
ära	doc_491521502086_item	2581768	et	4	main
rääkima	doc_491521502086_item	2581779	et	3	main
kohta	doc_491521502086_item	2581783	et	4	main
intervjuu	doc_491521502086_item	2581798	et	4	main
püüdma	doc_491521502086_item	2581821	et	3	main
sarnaneda	doc_491521502086_item	2581823	et	3	main
kontrolltöö	doc_491521502087_item	2581828	et	4	main
сапоги	doc_491521502087_item	2581835	et	2	main
краям	doc_491521502087_item	2581839	et	2	main
taga	doc_491521502087_item	2581843	et	4	main
paneb	doc_491521502087_item	2581848	et	3	main
ноги	doc_491521502087_item	2581852	et	2	main
haljastustööd	doc_491521502087_item	2581854	et	4	main
по	doc_491521502087_item	2581856	et	2	main
tunnustama	doc_491521502087_item	2581863	et	3	main
быть	doc_491521502087_item	2581868	et	2	main
прямое	doc_491521502087_item	2581875	et	2	main
общих	doc_491521502087_item	2581880	et	2	main
leidma	doc_491521502087_item	2581884	et	3	main
suuremine	doc_491521502086_item	2581725	et	4	main
tulema	doc_491521502086_item	2581728	et	4	main
kirjanik	doc_491521502086_item	2581732	et	3	main
kirjandus	doc_491521502086_item	2581733	et	3	main
9	doc_491521502086_item	2581735	et	2	main
10	doc_491521502086_item	2581739	et	2	main
kujundama	doc_491521502086_item	2581740	et	3	main
aiandus	doc_491521502086_item	2581746	et	3	main
13	doc_491521502086_item	2581750	et	2	main
ix	doc_491521502086_item	2581762	et	4	main
kõneviisi	doc_491521502086_item	2581765	et	4	main
valetama	doc_491521502086_item	2581767	et	3	main
valeta	doc_491521502086_item	2581769	et	4	main
see	doc_491521502086_item	2581770	et	3	main
tuleb	doc_491521502086_item	2581771	et	3	main
ruttu	doc_491521502086_item	2581772	et	4	main
ärge	doc_491521502086_item	2581780	et	3	main
intervjueerijat	doc_491521502086_item	2581795	et	4	main
pahandama	doc_491521502086_item	2581796	et	3	main
6	doc_491521502086_item	2581797	et	2	main
8	doc_491521502086_item	2581809	et	2	main
vaatama	doc_491521502086_item	2581810	et	3	main
vaadake	doc_491521502086_item	2581811	et	3	main
intervjueerijale	doc_491521502086_item	2581812	et	4	main
silma	doc_491521502086_item	2581813	et	4	main
9	doc_491521502086_item	2581814	et	2	main
kõhklema	doc_491521502086_item	2581815	et	3	main
ärge	doc_491521502086_item	2581816	et	3	main
oma	doc_491521502086_item	2581818	et	4	main
kõhelge	doc_491521502086_item	2581817	et	4	main
võimetes	doc_491521502086_item	2581819	et	4	main
10	doc_491521502086_item	2581820	et	2	main
selles	doc_491521502086_item	2581824	et	4	main
tõlkige	doc_491521502087_item	2581830	et	3	main
2	doc_491521502087_item	2581840	et	2	main
kukla	doc_491521502087_item	2581842	et	3	main
затылке	doc_491521502087_item	2581846	et	2	main
jalad	doc_491521502087_item	2581849	et	3	main
расставить	doc_491521502087_item	2581851	et	2	main
kokku	doc_491521502087_item	2581859	et	3	main
6	doc_491521502087_item	2581862	et	2	main
колебаться	doc_491521502087_item	2581872	et	2	main
назначение	doc_491521502087_item	2581876	et	2	main
в	doc_491521502087_item	2581879	et	2	main
компетентный	doc_491521502087_item	2581918	et	2	main
проведенный	doc_491521502087_item	2581924	et	2	main
товар	doc_491521502087_item	2581931	et	2	main
подписан	doc_491521502087_item	2581947	et	2	main
случайности	doc_491521502087_item	2581962	et	2	main
итоги	doc_491521502087_item	2581979	et	2	main
9	doc_491521502087_item	2582000	et	2	main
где	doc_491521502087_item	2582005	et	2	main
ei	doc_491521502087_item	2582011	et	4	main
direktor	doc_491521502087_item	2582016	et	3	main
meel	doc_491521502086_item	2581748	et	4	main
leppima	doc_491521502086_item	2581751	et	3	main
lepping	doc_491521502086_item	2581752	et	4	main
14	doc_491521502086_item	2581753	et	2	main
seitsmepäevane	doc_491521502086_item	2581761	et	4	main
välja	doc_491521502086_item	2581773	et	4	main
rääkige	doc_491521502086_item	2581781	et	3	main
negatiivseid	doc_491521502086_item	2581784	et	3	main
4	doc_491521502086_item	2581786	et	2	main
kuulama	doc_491521502086_item	2581787	et	3	main
lõpus	doc_491521502086_item	2581799	et	4	main
küsima	doc_491521502086_item	2581800	et	3	main
küsige	doc_491521502086_item	2581801	et	3	main
millal	doc_491521502086_item	2581802	et	3	main
teatatakse	doc_491521502086_item	2581803	et	3	main
tulemused	doc_491521502086_item	2581804	et	3	main
stiiliga	doc_491521502086_item	2581827	et	3	main
äärega	doc_491521502087_item	2581833	et	3	main
с	doc_491521502087_item	2581836	et	2	main
руки	doc_491521502087_item	2581844	et	2	main
5	doc_491521502087_item	2581858	et	2	main
касаться	doc_491521502087_item	2581861	et	2	main
7	doc_491521502087_item	2581865	et	2	main
тяжелым	doc_491521502087_item	2581869	et	2	main
9	doc_491521502087_item	2581873	et	2	main
11	doc_491521502087_item	2581882	et	2	main
находить	doc_491521502087_item	2581885	et	2	main
занятие	doc_491521502087_item	2581886	et	2	main
деятельность	doc_491521502087_item	2581887	et	2	main
12	doc_491521502087_item	2581888	et	2	main
eelistama	doc_491521502087_item	2581889	et	3	main
предпочитать	doc_491521502087_item	2581890	et	2	main
13	doc_491521502087_item	2581891	et	2	main
kummarduma	doc_491521502087_item	2581892	et	3	main
наклоняться	doc_491521502087_item	2581893	et	2	main
14	doc_491521502087_item	2581894	et	2	main
liibuvad	doc_491521502087_item	2581895	et	4	main
püksid	doc_491521502087_item	2581896	et	3	main
брюки	doc_491521502087_item	2581898	et	2	main
обтягивающие	doc_491521502087_item	2581897	et	2	main
15	doc_491521502087_item	2581899	et	2	main
акушерка	doc_491521502087_item	2581901	et	2	main
ämmaemand	doc_491521502087_item	2581900	et	3	main
16	doc_491521502087_item	2581902	et	2	main
reostus	doc_491521502087_item	2581903	et	4	main
загрязнение	doc_491521502087_item	2581904	et	2	main
17	doc_491521502087_item	2581905	et	2	main
teesklema	doc_491521502087_item	2581906	et	3	main
притворяться	doc_491521502087_item	2581907	et	2	main
18	doc_491521502087_item	2581908	et	2	main
takistama	doc_491521502087_item	2581909	et	3	main
препятствовать	doc_491521502087_item	2581910	et	2	main
19	doc_491521502087_item	2581911	et	2	main
vilets	doc_491521502087_item	2581912	et	3	main
убогий	doc_491521502087_item	2581913	et	2	main
бедный	doc_491521502087_item	2581914	et	2	main
плохой	doc_491521502087_item	2581915	et	2	main
20	doc_491521502087_item	2581916	et	2	main
человек	doc_491521502087_item	2581919	et	2	main
1	doc_491521502087_item	2581922	et	2	main
maal	doc_491521502087_item	2581927	et	4	main
puhkus	doc_491521502087_item	2581929	et	3	main
оптового	doc_491521502087_item	2581935	et	2	main
hulgilaost	doc_491521502087_item	2581938	et	4	main
знаем	doc_491521502087_item	2581944	et	2	main
прошедшего	doc_491521502087_item	2581980	et	2	main
tegi	doc_491521502087_item	2581983	et	4	main
hooajast	doc_491521502087_item	2581985	et	4	main
7	doc_491521502087_item	2581987	et	2	main
завоеванный	doc_491521502087_item	2581989	et	2	main
8	doc_491521502087_item	2581992	et	2	main
с	doc_491521502087_item	2581995	et	2	main
tutvustatud	doc_491521502087_item	2581998	et	4	main
директор	doc_491521502087_item	2582006	et	2	main
on	doc_491521502087_item	2582014	et	4	main
зазубренные	doc_491521502087_item	2582018	et	2	main
sobimatud	doc_491521502087_item	2582026	et	4	main
sõnad	doc_491521502087_item	2582027	et	4	main
1	doc_491521502087_item	2582028	et	2	main
teadlik	doc_491521502087_item	2582029	et	3	main
me	doc_491521502087_item	2582036	et	4	main
hooldame	doc_491521502087_item	2582037	et	3	main
lasi	doc_491521502087_item	2582053	et	4	main
vaeva	doc_491521502087_item	2582057	et	4	main
seda	doc_491521502087_item	2582059	et	3	main
seda	doc_491521502087_item	2582064	et	3	main
maja	doc_491521502087_item	2582065	et	4	main
korteriühistu	doc_491521502087_item	2582068	et	4	main
kehtestamisega	doc_491521502087_item	2582076	et	4	main
me	doc_491521502087_item	2582080	et	4	main
läbi	doc_491521502087_item	2582082	et	4	main
seas	doc_491521502087_item	2582087	et	4	main
murdus	doc_491521502087_item	2582094	et	3	main
pooleks	doc_491521502087_item	2582095	et	4	main
sellele	doc_491521502087_item	2582104	et	4	main
rõhutas	doc_491521502087_item	2582105	et	3	main
süüdistas	doc_491521502087_item	2582106	et	3	main
teeskles	doc_491521502087_item	2582107	et	3	main
ta	doc_491521502087_item	2582108	et	4	main
muutke	doc_491521502087_item	2582113	et	3	main
lubata	doc_491521502087_item	2582125	et	3	main
ametnik	doc_491521502087_item	2582129	et	3	main
ühendust	doc_491521502087_item	2582132	et	4	main
teiega	doc_491521502087_item	2582134	et	3	main
ühendust	doc_491521502087_item	2582135	et	4	main
firma	doc_491521502087_item	2582137	et	4	main
teeb	doc_491521502087_item	2582138	et	3	main
mitmesuguseid	doc_491521502087_item	2582139	et	3	main
ehitustöid	doc_491521502087_item	2582140	et	3	main
tehakse	doc_491521502087_item	2582141	et	3	main
mitmesuguseid	doc_491521502087_item	2582142	et	3	main
ehitustöid	doc_491521502087_item	2582143	et	3	main
ühe	doc_491521502087_item	2582156	et	4	main
hinda	doc_491521502087_item	2582163	et	4	main
piisavalt	doc_491521502087_item	2582166	et	4	main
hinnata	doc_491521502087_item	2582170	et	4	main
lauludega	doc_491521502087_item	2582204	et	3	main
raamatukogus	doc_491521502087_item	2582208	et	4	main
raamatukogus	doc_491521502087_item	2582211	et	4	main
erialast	doc_491521502087_item	2582213	et	4	main
tavaliselt	doc_491521502087_item	2582221	et	4	main
abitööd	doc_491521502087_item	2582224	et	4	main
v	doc_491521502087_item	2582225	et	4	main
moodustage	doc_491521502087_item	2582226	et	3	main
laused	doc_491521502087_item	2582227	et	3	main
järgmiste	doc_491521502087_item	2582228	et	3	main
sõnaühenditega	doc_491521502087_item	2582229	et	3	main
mind	doc_491521502087_item	2582232	et	4	main
piinlikkust	doc_491521502087_item	2582233	et	4	main
tundma	doc_491521502087_item	2582234	et	3	main
ma	doc_491521502087_item	2582235	et	3	main
ei	doc_491521502087_item	2582236	et	4	main
ta	doc_491521502087_item	2582250	et	4	main
väga	doc_491521502087_item	2582251	et	3	main
ära	doc_491521502087_item	2582259	et	4	main
midagi	doc_491521502087_item	2582287	et	4	main
1	doc_491521502087_item	2582295	et	2	main
välja	doc_491521502087_item	2582305	et	4	main
в	doc_491521502087_item	2581925	et	2	main
2	doc_491521502087_item	2581930	et	2	main
нового	doc_491521502087_item	2581934	et	2	main
договор	doc_491521502087_item	2581946	et	2	main
нет	doc_491521502087_item	2581949	et	2	main
tea	doc_491521502087_item	2581952	et	4	main
või	doc_491521502087_item	2581957	et	4	main
mitte	doc_491521502087_item	2581958	et	3	main
4	doc_491521502087_item	2581959	et	2	main
по	doc_491521502087_item	2581960	et	2	main
глупой	doc_491521502087_item	2581961	et	2	main
juhtuse	doc_491521502087_item	2581964	et	4	main
järgi	doc_491521502087_item	2581965	et	4	main
5	doc_491521502087_item	2581966	et	2	main
общаться	doc_491521502087_item	2581968	et	2	main
само	doc_491521502087_item	2581969	et	2	main
собой	doc_491521502087_item	2581970	et	2	main
разумеется	doc_491521502087_item	2581971	et	2	main
suhtlemisoskus	doc_491521502087_item	2581972	et	3	main
see	doc_491521502087_item	2581973	et	3	main
on	doc_491521502087_item	2581974	et	4	main
умение	doc_491521502087_item	2581967	et	2	main
6	doc_491521502087_item	2581976	et	2	main
ennustustmõistetav	doc_491521502087_item	2581975	et	4	main
начальник	doc_491521502087_item	2581977	et	2	main
склада	doc_491521502087_item	2581936	et	2	main
toodud	doc_491521502087_item	2581939	et	4	main
kaup	doc_491521502087_item	2581940	et	3	main
3	doc_491521502087_item	2581941	et	2	main
мы	doc_491521502087_item	2581942	et	2	main
не	doc_491521502087_item	2581943	et	2	main
или	doc_491521502087_item	2581948	et	2	main
rumaluse	doc_491521502087_item	2581963	et	4	main
voldik	doc_491521502087_item	2581999	et	3	main
вы	doc_491521502087_item	2582004	et	2	main
te	doc_491521502087_item	2582010	et	4	main
tea	doc_491521502087_item	2582012	et	4	main
kus	doc_491521502087_item	2582013	et	3	main
pähe	doc_491521502087_item	2582020	et	4	main
kriipsutage	doc_491521502087_item	2582024	et	3	main
üleolevüllatunud	doc_491521502087_item	2582030	et	4	main
hoolime	doc_491521502087_item	2582039	et	3	main
palju	doc_491521502087_item	2582050	et	4	main
maakler	doc_491521502087_item	2582052	et	3	main
läbiajas	doc_491521502087_item	2582054	et	3	main
korterit	doc_491521502087_item	2582060	et	3	main
6	doc_491521502087_item	2582069	et	2	main
firma	doc_491521502087_item	2582070	et	4	main
otsib	doc_491521502087_item	2582071	et	3	main
käivitamisega	doc_491521502087_item	2582077	et	4	main
küsimustiku	doc_491521502087_item	2582084	et	3	main
kõmu	doc_491521502087_item	2582085	et	4	main
tööandjate	doc_491521502087_item	2582086	et	3	main
8	doc_491521502087_item	2582088	et	2	main
tema	doc_491521502087_item	2582089	et	4	main
9	doc_491521502087_item	2582096	et	2	main
tegevuseta	doc_491521502087_item	2582097	et	4	main
noorukid	doc_491521502087_item	2582098	et	3	main
iv	doc_491521502087_item	2582112	et	4	main
võtab	doc_491521502087_item	2582130	et	3	main
3	doc_491521502087_item	2582136	et	2	main
4	doc_491521502087_item	2582144	et	2	main
tihti	doc_491521502087_item	2582145	et	3	main
ühe	doc_491521502087_item	2582149	et	4	main
juurde	doc_491521502087_item	2582152	et	4	main
tihti	doc_491521502087_item	2582153	et	3	main
saadatakse	doc_491521502087_item	2582154	et	3	main
tööotsijat	doc_491521502087_item	2582155	et	3	main
ei	doc_491521502087_item	2582162	et	4	main
esinetakse	doc_491521502087_item	2582202	et	3	main
kirjandust	doc_491521502087_item	2582210	et	3	main
loetakse	doc_491521502087_item	2582212	et	3	main
kirjandust	doc_491521502087_item	2582214	et	3	main
lapsele	doc_491521502087_item	2582223	et	4	main
armasta	doc_491521502087_item	2582237	et	4	main
eest	doc_491521502087_item	2582241	et	4	main
tüütab	doc_491521502087_item	2582258	et	3	main
ta	doc_491521502087_item	2582281	et	4	main
rusikasse	doc_491521502087_item	2582288	et	4	main
исключением	doc_491521502087_item	2582308	et	2	main
4	doc_491521502087_item	2582315	et	2	main
niinimetatud	doc_491521502087_item	2582323	et	3	main
moodustage	doc_491521502087_item	2582327	et	3	main
laused	doc_491521502087_item	2582330	et	3	main
unistate	doc_491521502087_item	2582334	et	3	main
uuest	doc_491521502087_item	2582335	et	3	main
korterist	doc_491521502087_item	2582336	et	3	main
unustage	doc_491521502087_item	2582338	et	3	main
unustage	doc_491521502087_item	2582346	et	3	main
võimalusi	doc_491521502087_item	2582349	et	3	main
te	doc_491521502087_item	2582352	et	4	main
uut	doc_491521502087_item	2582354	et	3	main
lepingut	doc_491521502087_item	2582360	et	3	main
kui	doc_491521502087_item	2582366	et	3	main
korterit	doc_491521502087_item	2582382	et	3	main
vaatama	doc_491521502087_item	2582384	et	3	main
kaasa	doc_491521502087_item	2582386	et	4	main
minnes	doc_491521502087_item	2582388	et	3	main
korterit	doc_491521502087_item	2582389	et	3	main
kaasa	doc_491521502087_item	2582393	et	4	main
liitelised	doc_491521502087_item	2582422	et	4	main
sõnal	doc_491521502087_item	2582425	et	3	main
õhk	doc_491521502087_item	2582431	et	3	main
valik	doc_491521502087_item	2582435	et	3	main
kuus	doc_491521502087_item	2582442	et	4	main
tootmine	doc_491521502087_item	2582448	et	4	main
ülemus	doc_491521502087_item	2581982	et	4	main
eelmisest	doc_491521502087_item	2581984	et	3	main
kokkuvõtte	doc_491521502087_item	2581986	et	4	main
соревнованиях	doc_491521502087_item	2581991	et	2	main
буклет	doc_491521502087_item	2581993	et	2	main
фирмой	doc_491521502087_item	2581996	et	2	main
не	doc_491521502087_item	2582001	et	2	main
ли	doc_491521502087_item	2582003	et	2	main
сбыту	doc_491521502087_item	2582008	et	2	main
turundus	doc_491521502087_item	2582015	et	3	main
слова	doc_491521502087_item	2582019	et	2	main
õpetud	doc_491521502087_item	2582021	et	4	main
tarbija	doc_491521502087_item	2582031	et	4	main
alati	doc_491521502087_item	2582033	et	4	main
sooduspakkumistega	doc_491521502087_item	2582034	et	3	main
2	doc_491521502087_item	2582035	et	2	main
oma	doc_491521502087_item	2582040	et	4	main
töötajate	doc_491521502087_item	2582041	et	4	main
3	doc_491521502087_item	2582043	et	2	main
liiga	doc_491521502087_item	2582049	et	4	main
korda	doc_491521502087_item	2582055	et	4	main
maha	doc_491521502087_item	2582061	et	4	main
töötajaid	doc_491521502087_item	2582072	et	4	main
meelitamisega	doc_491521502087_item	2582078	et	4	main
järeldavadjagunevad	doc_491521502087_item	2582099	et	4	main
hulguvad	doc_491521502087_item	2582100	et	3	main
oma	doc_491521502087_item	2582109	et	4	main
laused	doc_491521502087_item	2582114	et	3	main
ei	doc_491521502087_item	2582124	et	4	main
sõnad	doc_491521502087_item	2582022	et	4	main
tööotsija	doc_491521502087_item	2582044	et	4	main
mainis	doc_491521502087_item	2582045	et	3	main
lobises	doc_491521502087_item	2582046	et	3	main
hoidus	doc_491521502087_item	2582047	et	3	main
intervjuul	doc_491521502087_item	2582048	et	3	main
5	doc_491521502087_item	2582063	et	2	main
kerkibkaasneb	doc_491521502087_item	2582066	et	4	main
haldab	doc_491521502087_item	2582067	et	3	main
uue	doc_491521502087_item	2582074	et	3	main
tootmisliini	doc_491521502087_item	2582075	et	4	main
viisime	doc_491521502087_item	2582081	et	4	main
küsitluse	doc_491521502087_item	2582083	et	4	main
tänavail	doc_491521502087_item	2582101	et	4	main
10	doc_491521502087_item	2582102	et	2	main
endist	doc_491521502087_item	2582110	et	4	main
ülemust	doc_491521502087_item	2582111	et	4	main
umbisikuliseks	doc_491521502087_item	2582115	et	4	main
1	doc_491521502087_item	2582116	et	2	main
seadus	doc_491521502087_item	2582117	et	4	main
ei	doc_491521502087_item	2582118	et	4	main
luba	doc_491521502087_item	2582119	et	4	main
lastel	doc_491521502087_item	2582120	et	4	main
lastel	doc_491521502087_item	2582123	et	4	main
täisajaga	doc_491521502087_item	2582127	et	3	main
saadavad	doc_491521502087_item	2582146	et	4	main
juurest	doc_491521502087_item	2582150	et	4	main
teise	doc_491521502087_item	2582151	et	4	main
ei	doc_491521502087_item	2582169	et	4	main
kontserdil	doc_491521502087_item	2582198	et	3	main
lauludega	doc_491521502087_item	2582200	et	3	main
9	doc_491521502087_item	2582205	et	2	main
erialast	doc_491521502087_item	2582209	et	4	main
10	doc_491521502087_item	2582215	et	2	main
pakuvad	doc_491521502087_item	2582217	et	3	main
lapsele	doc_491521502087_item	2582219	et	4	main
abitööd	doc_491521502087_item	2582220	et	4	main
täisajaga	doc_491521502087_item	2582122	et	3	main
töötada	doc_491521502087_item	2582126	et	3	main
2	doc_491521502087_item	2582128	et	2	main
võetakse	doc_491521502087_item	2582133	et	3	main
tööotsijat	doc_491521502087_item	2582148	et	3	main
tema	doc_491521502087_item	2582164	et	4	main
tema	doc_491521502087_item	2582167	et	4	main
piisavalt	doc_491521502087_item	2582171	et	4	main
tööandja	doc_491521502087_item	2582173	et	4	main
sõlmib	doc_491521502087_item	2582174	et	3	main
lapsega	doc_491521502087_item	2582175	et	3	main
töölepingu	doc_491521502087_item	2582176	et	4	main
vanema	doc_491521502087_item	2582177	et	4	main
kirjalikul	doc_491521502087_item	2582178	et	3	main
nõusolekul	doc_491521502087_item	2582179	et	3	main
lapsega	doc_491521502087_item	2582180	et	3	main
töölepingu	doc_491521502087_item	2582181	et	4	main
sõlmitakse	doc_491521502087_item	2582182	et	3	main
vanema	doc_491521502087_item	2582183	et	4	main
kirjalikul	doc_491521502087_item	2582184	et	3	main
nõusolekul	doc_491521502087_item	2582185	et	3	main
7	doc_491521502087_item	2582186	et	2	main
firma	doc_491521502087_item	2582187	et	4	main
juht	doc_491521502087_item	2582188	et	3	main
kirjutab	doc_491521502087_item	2582189	et	3	main
lepingule	doc_491521502087_item	2582190	et	3	main
alla	doc_491521502087_item	2582191	et	3	main
kirjutatakse	doc_491521502087_item	2582192	et	3	main
lepingule	doc_491521502087_item	2582193	et	3	main
alla	doc_491521502087_item	2582194	et	3	main
8	doc_491521502087_item	2582195	et	2	main
ansambel	doc_491521502087_item	2582196	et	3	main
nad	doc_491521502087_item	2582161	et	3	main
tööd	doc_491521502087_item	2582165	et	4	main
tööd	doc_491521502087_item	2582168	et	4	main
6	doc_491521502087_item	2582172	et	2	main
uute	doc_491521502087_item	2582203	et	3	main
loeb	doc_491521502087_item	2582207	et	3	main
tavaliselt	doc_491521502087_item	2582216	et	4	main
asutused	doc_491521502087_item	2582218	et	4	main
pakutakse	doc_491521502087_item	2582222	et	3	main
luuletust	doc_491521502087_item	2582239	et	4	main
mind	doc_491521502087_item	2582244	et	4	main
tundma	doc_491521502087_item	2582246	et	3	main
mulle	doc_491521502087_item	2582255	et	4	main
rusikasse	doc_491521502087_item	2582278	et	4	main
kui	doc_491521502087_item	2582280	et	3	main
närvitseb	doc_491521502087_item	2582282	et	3	main
ta	doc_491521502087_item	2582283	et	4	main
vi	doc_491521502087_item	2582289	et	4	main
tähendavad	doc_491521502087_item	2582292	et	4	main
jne	doc_491521502087_item	2582296	et	4	main
ja	doc_491521502087_item	2582297	et	3	main
nii	doc_491521502087_item	2582298	et	3	main
edasi	doc_491521502087_item	2582299	et	3	main
так	doc_491521502087_item	2582301	et	2	main
2	doc_491521502087_item	2582303	et	2	main
n-ö	doc_491521502087_item	2582310	et	4	main
сказать	doc_491521502087_item	2582314	et	2	main
ja	doc_491521502087_item	2582317	et	3	main
lausetest	doc_491521502087_item	2582328	et	4	main
1	doc_491521502087_item	2582331	et	2	main
te	doc_491521502087_item	2582333	et	4	main
ärge	doc_491521502087_item	2582337	et	3	main
oma	doc_491521502087_item	2582347	et	4	main
2	doc_491521502087_item	2582350	et	2	main
sõlmides	doc_491521502087_item	2582361	et	4	main
3	doc_491521502087_item	2582365	et	2	main
korter	doc_491521502087_item	2582371	et	3	main
võrreldes	doc_491521502087_item	2582373	et	3	main
on	doc_491521502087_item	2582375	et	4	main
4	doc_491521502087_item	2582379	et	2	main
üle	doc_491521502087_item	2582383	et	3	main
5	doc_491521502087_item	2582395	et	2	main
kond-	doc_491521502087_item	2582421	et	4	main
sõnad	doc_491521502087_item	2582423	et	4	main
ühel	doc_491521502087_item	2582424	et	3	main
võib	doc_491521502087_item	2582426	et	3	main
1	doc_491521502087_item	2582430	et	2	main
2	doc_491521502087_item	2582433	et	2	main
3	doc_491521502087_item	2582437	et	2	main
pool	doc_491521502087_item	2582438	et	4	main
meetrit	doc_491521502087_item	2582439	et	3	main
poolemeetrine	doc_491521502087_item	2582440	et	4	main
4	doc_491521502087_item	2582441	et	2	main
5	doc_491521502087_item	2582445	et	2	main
üürnik	doc_491521502087_item	2582462	et	3	main
kujundama	doc_491521502087_item	2582464	et	3	main
esineb	doc_491521502087_item	2582197	et	3	main
uute	doc_491521502087_item	2582199	et	3	main
kontserdil	doc_491521502087_item	2582201	et	3	main
üliõpilane	doc_491521502087_item	2582206	et	3	main
1	doc_491521502087_item	2582230	et	2	main
klassi	doc_491521502087_item	2582240	et	4	main
see	doc_491521502087_item	2582242	et	3	main
paneb	doc_491521502087_item	2582243	et	3	main
piinlikkust	doc_491521502087_item	2582245	et	4	main
2	doc_491521502087_item	2582247	et	2	main
ära	doc_491521502087_item	2582248	et	4	main
tüütama	doc_491521502087_item	2582249	et	3	main
väga	doc_491521502087_item	2582257	et	3	main
5	doc_491521502087_item	2582277	et	2	main
pigistama	doc_491521502087_item	2582279	et	3	main
kogu	doc_491521502087_item	2582284	et	4	main
aeg	doc_491521502087_item	2582285	et	3	main
pigistab	doc_491521502087_item	2582286	et	3	main
kirjutage	doc_491521502087_item	2582290	et	3	main
lühendid	doc_491521502087_item	2582294	et	3	main
и	doc_491521502087_item	2582300	et	2	main
далее	doc_491521502087_item	2582302	et	2	main
va	doc_491521502087_item	2582304	et	3	main
nii	doc_491521502087_item	2582311	et	3	main
так	doc_491521502087_item	2582313	et	2	main
jm	doc_491521502087_item	2582316	et	4	main
muud	doc_491521502087_item	2582318	et	4	main
другое	doc_491521502087_item	2582320	et	2	main
5	doc_491521502087_item	2582321	et	2	main
называемый	doc_491521502087_item	2582325	et	2	main
rahalisi	doc_491521502087_item	2582348	et	4	main
olge	doc_491521502087_item	2582362	et	3	main
tähelepanelik	doc_491521502087_item	2582364	et	4	main
kesklinnaga	doc_491521502087_item	2582368	et	3	main
odav	doc_491521502087_item	2582372	et	3	main
kesklinnaga	doc_491521502087_item	2582374	et	3	main
see	doc_491521502087_item	2582376	et	3	main
korter	doc_491521502087_item	2582377	et	3	main
odav	doc_491521502087_item	2582378	et	3	main
võtke	doc_491521502087_item	2582385	et	3	main
vaatama	doc_491521502087_item	2582391	et	3	main
varianti	doc_491521502087_item	2582429	et	4	main
liiget	doc_491521502087_item	2582443	et	3	main
9	doc_491521502087_item	2582460	et	2	main
kujundaja	doc_491521502087_item	2582465	et	4	main
12	doc_491521502087_item	2582469	et	2	main
meelepärane	doc_491521502087_item	2582471	et	4	main
13	doc_491521502087_item	2582472	et	2	main
leppima	doc_491521502087_item	2582473	et	3	main
leping	doc_491521502087_item	2582474	et	3	main
14	doc_491521502087_item	2582475	et	2	main
valima	doc_491521502087_item	2582476	et	3	main
valik	doc_491521502087_item	2582477	et	3	main
valimine	doc_491521502087_item	2582478	et	4	main
15	doc_491521502087_item	2582479	et	2	main
seitse	doc_491521502087_item	2582480	et	3	main
küsige	doc_491521502087_item	2582520	et	3	main
hilinema	doc_491521502087_item	2582525	et	3	main
8	doc_491521502087_item	2582528	et	2	main
9	doc_491521502087_item	2582533	et	2	main
kõhelge	doc_491521502087_item	2582536	et	4	main
võimetes	doc_491521502087_item	2582538	et	4	main
оборкой	doc_491521502088_item	2582557	et	2	main
harki	doc_491521502088_item	2582569	et	4	main
работы	doc_491521502088_item	2582574	et	2	main
признавать	doc_491521502088_item	2582583	et	2	main
vaeva	doc_491521502088_item	2582585	et	4	main
nägema	doc_491521502088_item	2582586	et	3	main
мучаться	doc_491521502088_item	2582588	et	2	main
колебаться	doc_491521502088_item	2582591	et	2	main
прямое	doc_491521502088_item	2582594	et	2	main
10	doc_491521502088_item	2582596	et	2	main
üldjoontes	doc_491521502088_item	2582597	et	3	main
общих	doc_491521502088_item	2582599	et	2	main
11	doc_491521502088_item	2582601	et	2	main
leidma	doc_491521502088_item	2582603	et	3	main
13	doc_491521502088_item	2582609	et	2	main
14	doc_491521502088_item	2582612	et	2	main
15	doc_491521502088_item	2582617	et	2	main
16	doc_491521502088_item	2582620	et	2	main
tõlkige	doc_491521502088_item	2582635	et	3	main
paneb	doc_491521502087_item	2582231	et	3	main
lugeda	doc_491521502087_item	2582238	et	3	main
palju	doc_491521502087_item	2582252	et	4	main
lobiseb	doc_491521502087_item	2582253	et	3	main
ja	doc_491521502087_item	2582254	et	3	main
juba	doc_491521502087_item	2582256	et	3	main
3	doc_491521502087_item	2582260	et	2	main
selle	doc_491521502087_item	2582262	et	4	main
meelepärane	doc_491521502087_item	2582261	et	4	main
õpetajaga	doc_491521502087_item	2582263	et	4	main
me	doc_491521502087_item	2582264	et	4	main
räägime	doc_491521502087_item	2582265	et	3	main
meelepärast	doc_491521502087_item	2582266	et	4	main
4	doc_491521502087_item	2582267	et	2	main
vihale	doc_491521502087_item	2582268	et	4	main
ajama	doc_491521502087_item	2582269	et	4	main
ta	doc_491521502087_item	2582270	et	4	main
ajab	doc_491521502087_item	2582271	et	3	main
vihale	doc_491521502087_item	2582272	et	4	main
mind	doc_491521502087_item	2582273	et	4	main
kui	doc_491521502087_item	2582274	et	3	main
vaideb	doc_491521502087_item	2582275	et	4	main
minuga	doc_491521502087_item	2582276	et	3	main
mida	doc_491521502087_item	2582291	et	4	main
järgmised	doc_491521502087_item	2582293	et	3	main
3	doc_491521502087_item	2582309	et	2	main
öeldek	doc_491521502087_item	2582312	et	4	main
и	doc_491521502087_item	2582319	et	2	main
arvatud	doc_491521502087_item	2582306	et	4	main
за	doc_491521502087_item	2582307	et	2	main
des-lauselühendiga	doc_491521502087_item	2582329	et	3	main
kui	doc_491521502087_item	2582332	et	3	main
oma	doc_491521502087_item	2582339	et	4	main
rahalisi	doc_491521502087_item	2582340	et	4	main
võimalusi	doc_491521502087_item	2582341	et	3	main
unistades	doc_491521502087_item	2582342	et	3	main
uuest	doc_491521502087_item	2582343	et	3	main
korterist	doc_491521502087_item	2582344	et	3	main
ärge	doc_491521502087_item	2582345	et	3	main
kui	doc_491521502087_item	2582351	et	3	main
sõlmite	doc_491521502087_item	2582353	et	3	main
olge	doc_491521502087_item	2582356	et	3	main
tähelepanelik	doc_491521502087_item	2582358	et	4	main
võrrelda	doc_491521502087_item	2582367	et	4	main
on	doc_491521502087_item	2582369	et	4	main
kui	doc_491521502087_item	2582380	et	3	main
asjatundja	doc_491521502087_item	2582394	et	4	main
nn	doc_491521502087_item	2582322	et	4	main
так	doc_491521502087_item	2582324	et	2	main
vii	doc_491521502087_item	2582326	et	4	main
lepingut	doc_491521502087_item	2582355	et	3	main
väga	doc_491521502087_item	2582357	et	3	main
uut	doc_491521502087_item	2582359	et	3	main
väga	doc_491521502087_item	2582363	et	3	main
see	doc_491521502087_item	2582370	et	3	main
lähete	doc_491521502087_item	2582381	et	4	main
asjatundja	doc_491521502087_item	2582387	et	4	main
üle	doc_491521502087_item	2582390	et	3	main
võtke	doc_491521502087_item	2582392	et	3	main
kui	doc_491521502087_item	2582396	et	3	main
suhtlete	doc_491521502087_item	2582397	et	3	main
ametnikega	doc_491521502087_item	2582398	et	3	main
on	doc_491521502087_item	2582399	et	4	main
maaklerist	doc_491521502087_item	2582400	et	3	main
suur	doc_491521502087_item	2582401	et	3	main
abi	doc_491521502087_item	2582402	et	4	main
suheldes	doc_491521502087_item	2582403	et	3	main
ametnikega	doc_491521502087_item	2582404	et	3	main
on	doc_491521502087_item	2582405	et	4	main
maaklerist	doc_491521502087_item	2582406	et	3	main
suur	doc_491521502087_item	2582407	et	3	main
abi	doc_491521502087_item	2582408	et	4	main
viii	doc_491521502087_item	2582409	et	4	main
moodustage	doc_491521502087_item	2582410	et	3	main
ja	doc_491521502087_item	2582411	et	3	main
nik	doc_491521502087_item	2582412	et	4	main
ndus	doc_491521502087_item	2582413	et	4	main
pärane	doc_491521502087_item	2582414	et	4	main
ng	doc_491521502087_item	2582415	et	4	main
k	doc_491521502087_item	2582416	et	4	main
line	doc_491521502087_item	2582417	et	4	main
ne	doc_491521502087_item	2582418	et	4	main
mine	doc_491521502087_item	2582419	et	3	main
või	doc_491521502087_item	2582420	et	4	main
olla	doc_491521502087_item	2582427	et	3	main
tootma	doc_491521502087_item	2582446	et	3	main
6	doc_491521502087_item	2582449	et	2	main
suur	doc_491521502087_item	2582450	et	3	main
7	doc_491521502087_item	2582452	et	2	main
kokku	doc_491521502087_item	2582453	et	3	main
tulema	doc_491521502087_item	2582454	et	4	main
kokkutelek	doc_491521502087_item	2582455	et	4	main
8	doc_491521502087_item	2582456	et	2	main
kiri	doc_491521502087_item	2582457	et	3	main
kirjandus	doc_491521502087_item	2582458	et	3	main
10	doc_491521502087_item	2582463	et	2	main
11	doc_491521502087_item	2582466	et	2	main
aiandus	doc_491521502087_item	2582468	et	3	main
ix	doc_491521502087_item	2582483	et	4	main
millal	doc_491521502087_item	2582521	et	3	main
ärge	doc_491521502087_item	2582526	et	3	main
intervjueerijale	doc_491521502087_item	2582531	et	4	main
ärge	doc_491521502087_item	2582535	et	3	main
kontrolltöö	doc_491521502088_item	2582547	et	4	main
mitu	doc_491521502087_item	2582428	et	4	main
õhkond	doc_491521502087_item	2582432	et	4	main
valima	doc_491521502087_item	2582434	et	3	main
valimine	doc_491521502087_item	2582436	et	4	main
kuueliikmeline	doc_491521502087_item	2582444	et	4	main
toodang	doc_491521502087_item	2582447	et	3	main
suurepärane	doc_491521502087_item	2582451	et	4	main
kirjanik	doc_491521502087_item	2582459	et	3	main
aed	doc_491521502087_item	2582467	et	3	main
meel	doc_491521502087_item	2582470	et	4	main
kasutage	doc_491521502087_item	2582484	et	3	main
käskivat	doc_491521502087_item	2582485	et	4	main
kõneviisi	doc_491521502087_item	2582486	et	4	main
1	doc_491521502087_item	2582487	et	2	main
valetama	doc_491521502087_item	2582488	et	3	main
valetage	doc_491521502087_item	2582489	et	3	main
see	doc_491521502087_item	2582490	et	3	main
tuleb	doc_491521502087_item	2582491	et	3	main
ruttu	doc_491521502087_item	2582492	et	4	main
2	doc_491521502087_item	2582494	et	2	main
välja	doc_491521502087_item	2582493	et	4	main
säilitama	doc_491521502087_item	2582495	et	4	main
säilitage	doc_491521502087_item	2582496	et	3	main
rahu	doc_491521502087_item	2582497	et	4	main
3	doc_491521502087_item	2582498	et	2	main
rääkima	doc_491521502087_item	2582499	et	3	main
ärge	doc_491521502087_item	2582500	et	3	main
rääkige	doc_491521502087_item	2582501	et	3	main
enda	doc_491521502087_item	2582502	et	4	main
kohta	doc_491521502087_item	2582503	et	4	main
negatiivseid	doc_491521502087_item	2582504	et	3	main
asju	doc_491521502087_item	2582505	et	3	main
4	doc_491521502087_item	2582506	et	2	main
kuulama	doc_491521502087_item	2582507	et	3	main
kuulake	doc_491521502087_item	2582508	et	4	main
hoolikalt	doc_491521502087_item	2582509	et	4	main
küsimusi	doc_491521502087_item	2582510	et	4	main
5	doc_491521502087_item	2582511	et	2	main
hakkama	doc_491521502087_item	2582512	et	3	main
hakkake	doc_491521502087_item	2582513	et	4	main
intervjueerijat	doc_491521502087_item	2582514	et	4	main
pahandama	doc_491521502087_item	2582515	et	3	main
6	doc_491521502087_item	2582516	et	2	main
intervjuu	doc_491521502087_item	2582517	et	4	main
üür	doc_491521502087_item	2582461	et	3	main
päeva	doc_491521502087_item	2582481	et	4	main
seitsmepäevane	doc_491521502087_item	2582482	et	4	main
lõpus	doc_491521502087_item	2582518	et	4	main
tulemused	doc_491521502087_item	2582523	et	3	main
silma	doc_491521502087_item	2582532	et	4	main
oma	doc_491521502087_item	2582537	et	4	main
10	doc_491521502087_item	2582539	et	2	main
püüdma	doc_491521502087_item	2582540	et	3	main
püüdke	doc_491521502087_item	2582541	et	3	main
sarnaneda	doc_491521502087_item	2582542	et	3	main
selles	doc_491521502087_item	2582543	et	4	main
tõlkige	doc_491521502088_item	2582549	et	3	main
сапоги	doc_491521502088_item	2582554	et	2	main
2	doc_491521502088_item	2582558	et	2	main
kukla	doc_491521502088_item	2582560	et	3	main
за	doc_491521502088_item	2582564	et	2	main
jalad	doc_491521502088_item	2582568	et	3	main
4	doc_491521502088_item	2582572	et	2	main
озеленению	doc_491521502088_item	2582576	et	2	main
kokku	doc_491521502088_item	2582578	et	3	main
puutuma	doc_491521502088_item	2582579	et	4	main
прикасаться	doc_491521502088_item	2582580	et	2	main
7	doc_491521502088_item	2582584	et	2	main
трудиться	doc_491521502088_item	2582587	et	2	main
8	doc_491521502088_item	2582589	et	2	main
kõikuma	doc_491521502088_item	2582590	et	3	main
9	doc_491521502088_item	2582592	et	2	main
otstarve	doc_491521502088_item	2582593	et	3	main
назначение	doc_491521502088_item	2582595	et	2	main
в	doc_491521502088_item	2582598	et	2	main
чертах	doc_491521502088_item	2582600	et	2	main
rakendust	doc_491521502088_item	2582602	et	4	main
брюки	doc_491521502088_item	2582616	et	2	main
ämmaemand	doc_491521502088_item	2582618	et	3	main
17	doc_491521502088_item	2582622	et	2	main
притворяться	doc_491521502088_item	2582624	et	2	main
19	doc_491521502088_item	2582628	et	2	main
плохой	doc_491521502088_item	2582630	et	2	main
asjatundlik	doc_491521502088_item	2582632	et	3	main
отпуск	doc_491521502088_item	2582637	et	2	main
maal	doc_491521502088_item	2582641	et	4	main
3	doc_491521502088_item	2582655	et	2	main
нет	doc_491521502088_item	2582663	et	2	main
ei	doc_491521502088_item	2582665	et	4	main
tea	doc_491521502088_item	2582666	et	4	main
või	doc_491521502088_item	2582672	et	4	main
5	doc_491521502088_item	2582678	et	2	main
разумеется	doc_491521502088_item	2582683	et	2	main
enesemõistetav	doc_491521502088_item	2582686	et	3	main
по	doc_491521502088_item	2582721	et	2	main
sõnad	doc_491521502088_item	2582740	et	4	main
1	doc_491521502088_item	2582741	et	2	main
teadlik	doc_491521502088_item	2582742	et	3	main
üleolevüllatunud	doc_491521502088_item	2582743	et	4	main
hooldame	doc_491521502088_item	2582750	et	3	main
4	doc_491521502088_item	2582764	et	2	main
seda	doc_491521502088_item	2582772	et	3	main
maha	doc_491521502088_item	2582774	et	4	main
seda	doc_491521502088_item	2582777	et	3	main
maja	doc_491521502088_item	2582778	et	4	main
kerkibkaasneb	doc_491521502088_item	2582779	et	4	main
haldab	doc_491521502088_item	2582780	et	3	main
korteriühistu	doc_491521502088_item	2582781	et	4	main
6	doc_491521502088_item	2582782	et	2	main
tootmisliini	doc_491521502088_item	2582788	et	4	main
umbisikuliseks	doc_491521502088_item	2582827	et	4	main
seadus	doc_491521502088_item	2582829	et	4	main
2	doc_491521502088_item	2582840	et	2	main
ametnik	doc_491521502088_item	2582841	et	3	main
ühendust	doc_491521502088_item	2582844	et	4	main
teiega	doc_491521502088_item	2582845	et	3	main
võetakse	doc_491521502088_item	2582846	et	3	main
ühendust	doc_491521502088_item	2582847	et	4	main
3	doc_491521502088_item	2582848	et	2	main
ehitustöid	doc_491521502088_item	2582852	et	3	main
tihti	doc_491521502088_item	2582857	et	3	main
nad	doc_491521502088_item	2582873	et	3	main
tema	doc_491521502088_item	2582879	et	4	main
piisavalt	doc_491521502088_item	2582883	et	4	main
küsima	doc_491521502087_item	2582519	et	3	main
7	doc_491521502087_item	2582524	et	2	main
vaadake	doc_491521502087_item	2582530	et	3	main
1	doc_491521502088_item	2582550	et	2	main
с	doc_491521502088_item	2582555	et	2	main
taga	doc_491521502088_item	2582561	et	4	main
голову	doc_491521502088_item	2582565	et	2	main
paneb	doc_491521502088_item	2582567	et	3	main
ноги	doc_491521502088_item	2582571	et	2	main
по	doc_491521502088_item	2582575	et	2	main
найти	doc_491521502088_item	2582604	et	2	main
eelistama	doc_491521502088_item	2582607	et	3	main
наклоняться	doc_491521502088_item	2582611	et	2	main
püksid	doc_491521502088_item	2582614	et	3	main
teatatakse	doc_491521502087_item	2582522	et	3	main
hilinege	doc_491521502087_item	2582527	et	3	main
vaatama	doc_491521502087_item	2582529	et	3	main
kõhklema	doc_491521502087_item	2582534	et	3	main
töökohas	doc_491521502087_item	2582544	et	4	main
levinud	doc_491521502087_item	2582545	et	4	main
i	doc_491521502088_item	2582548	et	4	main
stiiliga	doc_491521502087_item	2582546	et	3	main
äärega	doc_491521502088_item	2582552	et	3	main
saapad	doc_491521502088_item	2582553	et	3	main
käed	doc_491521502088_item	2582559	et	3	main
руки	doc_491521502088_item	2582562	et	2	main
haljastustööd	doc_491521502088_item	2582573	et	4	main
5	doc_491521502088_item	2582577	et	2	main
6	doc_491521502088_item	2582581	et	2	main
tunnustama	doc_491521502088_item	2582582	et	3	main
занятие	doc_491521502088_item	2582605	et	2	main
облегающие	doc_491521502088_item	2582615	et	2	main
акушерка	doc_491521502088_item	2582619	et	2	main
reostus	doc_491521502088_item	2582621	et	4	main
takistama	doc_491521502088_item	2582626	et	3	main
vilets	doc_491521502088_item	2582629	et	3	main
ii	doc_491521502088_item	2582634	et	4	main
деревне	doc_491521502088_item	2582640	et	2	main
2	doc_491521502088_item	2582644	et	2	main
привезенный	doc_491521502088_item	2582646	et	2	main
нового	doc_491521502088_item	2582648	et	2	main
склада	doc_491521502088_item	2582650	et	2	main
uuest	doc_491521502088_item	2582651	et	3	main
не	doc_491521502088_item	2582657	et	2	main
или	doc_491521502088_item	2582662	et	2	main
mitte	doc_491521502088_item	2582673	et	3	main
по	doc_491521502088_item	2582675	et	2	main
общаться	doc_491521502088_item	2582680	et	2	main
suhtlemisoskus	doc_491521502088_item	2582684	et	3	main
сбыту	doc_491521502088_item	2582722	et	2	main
te	doc_491521502088_item	2582724	et	4	main
tea	doc_491521502088_item	2582726	et	4	main
kus	doc_491521502088_item	2582727	et	3	main
on	doc_491521502088_item	2582728	et	4	main
turundusdirektor	doc_491521502088_item	2582729	et	3	main
10	doc_491521502088_item	2582730	et	2	main
зазубренные	doc_491521502088_item	2582731	et	2	main
слова	doc_491521502088_item	2582732	et	2	main
sobimatud	doc_491521502088_item	2582739	et	4	main
hoolime	doc_491521502088_item	2582752	et	3	main
liiga	doc_491521502088_item	2582762	et	4	main
maakler	doc_491521502088_item	2582765	et	3	main
et	doc_491521502088_item	2582771	et	3	main
5	doc_491521502088_item	2582776	et	2	main
karvase	doc_491521502088_item	2582551	et	4	main
меховой	doc_491521502088_item	2582556	et	2	main
закинуты	doc_491521502088_item	2582563	et	2	main
3	doc_491521502088_item	2582566	et	2	main
расставляет	doc_491521502088_item	2582570	et	2	main
12	doc_491521502088_item	2582606	et	2	main
предпочитать	doc_491521502088_item	2582608	et	2	main
kummarduma	doc_491521502088_item	2582610	et	3	main
liibuvad	doc_491521502088_item	2582613	et	4	main
18	doc_491521502088_item	2582625	et	2	main
препятствовать	doc_491521502088_item	2582627	et	2	main
20	doc_491521502088_item	2582631	et	2	main
компетентный	doc_491521502088_item	2582633	et	2	main
в	doc_491521502088_item	2582639	et	2	main
veedetud	doc_491521502088_item	2582642	et	4	main
puhkus	doc_491521502088_item	2582643	et	3	main
товар	doc_491521502088_item	2582645	et	2	main
с	doc_491521502088_item	2582647	et	2	main
оптового	doc_491521502088_item	2582649	et	2	main
toodetud	doc_491521502088_item	2582653	et	4	main
мы	doc_491521502088_item	2582656	et	2	main
договор	doc_491521502088_item	2582660	et	2	main
on	doc_491521502088_item	2582668	et	4	main
leping	doc_491521502088_item	2582669	et	3	main
случайности	doc_491521502088_item	2582677	et	2	main
само	doc_491521502088_item	2582681	et	2	main
on	doc_491521502088_item	2582685	et	4	main
pähe	doc_491521502088_item	2582733	et	4	main
tuubidud	doc_491521502088_item	2582734	et	4	main
sõnad	doc_491521502088_item	2582735	et	4	main
me	doc_491521502088_item	2582749	et	4	main
lasi	doc_491521502088_item	2582766	et	4	main
nägi	doc_491521502088_item	2582769	et	3	main
firma	doc_491521502088_item	2582783	et	4	main
otsib	doc_491521502088_item	2582784	et	3	main
töötajaid	doc_491521502088_item	2582785	et	4	main
kehtestamisega	doc_491521502088_item	2582789	et	4	main
meelitamisega	doc_491521502088_item	2582791	et	4	main
1	doc_491521502088_item	2582828	et	2	main
võtab	doc_491521502088_item	2582842	et	3	main
teeb	doc_491521502088_item	2582850	et	3	main
ehitustöid	doc_491521502088_item	2582855	et	3	main
ei	doc_491521502088_item	2582874	et	4	main
tema	doc_491521502088_item	2582876	et	4	main
ei	doc_491521502088_item	2582881	et	4	main
kirjalikul	doc_491521502088_item	2582890	et	3	main
kontserdil	doc_491521502088_item	2582913	et	3	main
üliõpilane	doc_491521502088_item	2582918	et	3	main
teesklema	doc_491521502088_item	2582623	et	3	main
1	doc_491521502088_item	2582636	et	2	main
знаем	doc_491521502088_item	2582658	et	2	main
подписан	doc_491521502088_item	2582661	et	2	main
me	doc_491521502088_item	2582664	et	4	main
kirjatatud	doc_491521502088_item	2582671	et	4	main
глупой	doc_491521502088_item	2582676	et	2	main
собой	doc_491521502088_item	2582682	et	2	main
6	doc_491521502088_item	2582687	et	2	main
начальник	doc_491521502088_item	2582688	et	2	main
подвел	doc_491521502088_item	2582689	et	2	main
итоги	doc_491521502088_item	2582690	et	2	main
прошедшего	doc_491521502088_item	2582691	et	2	main
сезона	doc_491521502088_item	2582692	et	2	main
ülem	doc_491521502088_item	2582693	et	3	main
ajas	doc_491521502088_item	2582694	et	4	main
möödunud	doc_491521502088_item	2582695	et	4	main
hooaja	doc_491521502088_item	2582696	et	3	main
tulemusi	doc_491521502088_item	2582697	et	4	main
7	doc_491521502088_item	2582698	et	2	main
кубок	doc_491521502088_item	2582699	et	2	main
завоеванный	doc_491521502088_item	2582700	et	2	main
на	doc_491521502088_item	2582701	et	2	main
соревнованиях	doc_491521502088_item	2582702	et	2	main
võistlustel	doc_491521502088_item	2582703	et	3	main
võidetud	doc_491521502088_item	2582704	et	4	main
karikas	doc_491521502088_item	2582705	et	4	main
8	doc_491521502088_item	2582706	et	2	main
буклет	doc_491521502088_item	2582707	et	2	main
знакомящий	doc_491521502088_item	2582708	et	2	main
с	doc_491521502088_item	2582709	et	2	main
фирмой	doc_491521502088_item	2582710	et	2	main
firmaga	doc_491521502088_item	2582711	et	3	main
tutvustav	doc_491521502088_item	2582712	et	4	main
voldik	doc_491521502088_item	2582713	et	3	main
9	doc_491521502088_item	2582714	et	2	main
не	doc_491521502088_item	2582715	et	2	main
знаете	doc_491521502088_item	2582716	et	2	main
ли	doc_491521502088_item	2582717	et	2	main
вы	doc_491521502088_item	2582718	et	2	main
где	doc_491521502088_item	2582719	et	2	main
директор	doc_491521502088_item	2582720	et	2	main
ei	doc_491521502088_item	2582725	et	4	main
tarbija	doc_491521502088_item	2582744	et	4	main
tutvub	doc_491521502088_item	2582745	et	3	main
проведенный	doc_491521502088_item	2582638	et	2	main
hulgilaost	doc_491521502088_item	2582652	et	4	main
kaup	doc_491521502088_item	2582654	et	3	main
будет	doc_491521502088_item	2582659	et	2	main
kas	doc_491521502088_item	2582667	et	3	main
alla	doc_491521502088_item	2582670	et	3	main
4	doc_491521502088_item	2582674	et	2	main
умение	doc_491521502088_item	2582679	et	2	main
ega	doc_491521502088_item	2582723	et	3	main
iii	doc_491521502088_item	2582736	et	4	main
kriipsutage	doc_491521502088_item	2582737	et	3	main
maha	doc_491521502088_item	2582738	et	4	main
hoolitseme	doc_491521502088_item	2582751	et	3	main
oma	doc_491521502088_item	2582753	et	4	main
eest	doc_491521502088_item	2582755	et	4	main
palju	doc_491521502088_item	2582763	et	4	main
korterit	doc_491521502088_item	2582773	et	3	main
viisime	doc_491521502088_item	2582794	et	4	main
läbi	doc_491521502088_item	2582795	et	4	main
küsitluse	doc_491521502088_item	2582796	et	4	main
küsimustikukõmu	doc_491521502088_item	2582797	et	4	main
tööandjate	doc_491521502088_item	2582798	et	3	main
seas	doc_491521502088_item	2582799	et	4	main
8	doc_491521502088_item	2582800	et	2	main
tema	doc_491521502088_item	2582801	et	4	main
kinga	doc_491521502088_item	2582802	et	4	main
varrukas	doc_491521502088_item	2582803	et	4	main
konts	doc_491521502088_item	2582804	et	3	main
krae	doc_491521502088_item	2582805	et	4	main
murdus	doc_491521502088_item	2582806	et	3	main
pooleks	doc_491521502088_item	2582807	et	4	main
9	doc_491521502088_item	2582808	et	2	main
tegevuseta	doc_491521502088_item	2582809	et	4	main
noorukid	doc_491521502088_item	2582810	et	3	main
hulguvad	doc_491521502088_item	2582812	et	3	main
tänavail	doc_491521502088_item	2582813	et	4	main
10	doc_491521502088_item	2582814	et	2	main
järeldavadjagunevad	doc_491521502088_item	2582811	et	4	main
lisaks	doc_491521502088_item	2582815	et	4	main
sellele	doc_491521502088_item	2582816	et	4	main
rõhutas	doc_491521502088_item	2582817	et	3	main
süüdistas	doc_491521502088_item	2582818	et	3	main
teeskles	doc_491521502088_item	2582819	et	3	main
ta	doc_491521502088_item	2582820	et	4	main
oma	doc_491521502088_item	2582821	et	4	main
ülemust	doc_491521502088_item	2582823	et	4	main
iv	doc_491521502088_item	2582824	et	4	main
muutke	doc_491521502088_item	2582825	et	3	main
laused	doc_491521502088_item	2582826	et	3	main
lastel	doc_491521502088_item	2582832	et	4	main
lastel	doc_491521502088_item	2582835	et	4	main
ei	doc_491521502088_item	2582836	et	4	main
lubata	doc_491521502088_item	2582837	et	3	main
töötada	doc_491521502088_item	2582838	et	3	main
täisajaga	doc_491521502088_item	2582839	et	3	main
teiega	doc_491521502088_item	2582843	et	3	main
mitmesuguseid	doc_491521502088_item	2582851	et	3	main
hinda	doc_491521502088_item	2582875	et	4	main
tööd	doc_491521502088_item	2582877	et	4	main
tööd	doc_491521502088_item	2582880	et	4	main
hinnata	doc_491521502088_item	2582882	et	4	main
6	doc_491521502088_item	2582884	et	2	main
alati	doc_491521502088_item	2582746	et	4	main
sooduspakkumistega	doc_491521502088_item	2582747	et	3	main
2	doc_491521502088_item	2582748	et	2	main
töötajate	doc_491521502088_item	2582754	et	4	main
3	doc_491521502088_item	2582756	et	2	main
tööotsija	doc_491521502088_item	2582757	et	4	main
mainis	doc_491521502088_item	2582758	et	3	main
lobises	doc_491521502088_item	2582759	et	3	main
hoidus	doc_491521502088_item	2582760	et	3	main
intervjuul	doc_491521502088_item	2582761	et	3	main
läbiajas	doc_491521502088_item	2582767	et	3	main
korda	doc_491521502088_item	2582768	et	4	main
vaeva	doc_491521502088_item	2582770	et	4	main
müüa	doc_491521502088_item	2582775	et	3	main
seoses	doc_491521502088_item	2582786	et	4	main
uue	doc_491521502088_item	2582787	et	3	main
käivitamisega	doc_491521502088_item	2582790	et	4	main
7	doc_491521502088_item	2582792	et	2	main
me	doc_491521502088_item	2582793	et	4	main
luba	doc_491521502088_item	2582831	et	4	main
täisajaga	doc_491521502088_item	2582834	et	3	main
firma	doc_491521502088_item	2582849	et	4	main
tehakse	doc_491521502088_item	2582853	et	3	main
4	doc_491521502088_item	2582856	et	2	main
piisavalt	doc_491521502088_item	2582878	et	4	main
vanema	doc_491521502088_item	2582889	et	4	main
lapsega	doc_491521502088_item	2582892	et	3	main
firma	doc_491521502088_item	2582899	et	4	main
alla	doc_491521502088_item	2582903	et	3	main
kirjutatakse	doc_491521502088_item	2582905	et	3	main
esineb	doc_491521502088_item	2582909	et	3	main
lauludega	doc_491521502088_item	2582916	et	3	main
raamatukogus	doc_491521502088_item	2582923	et	4	main
asutused	doc_491521502088_item	2582930	et	4	main
lapsele	doc_491521502088_item	2582931	et	4	main
abitööd	doc_491521502088_item	2582936	et	4	main
järgmiste	doc_491521502088_item	2582940	et	3	main
paneb	doc_491521502088_item	2582943	et	3	main
tundma	doc_491521502088_item	2582946	et	3	main
võõraste	doc_491521502088_item	2582947	et	4	main
inimestega	doc_491521502088_item	2582948	et	3	main
piinlikkust	doc_491521502088_item	2582952	et	4	main
meelepärane	doc_491521502088_item	2582965	et	4	main
vihale	doc_491521502088_item	2582973	et	4	main
tunnis	doc_491521502088_item	2582977	et	3	main
õpetaja	doc_491521502088_item	2582981	et	4	main
et	doc_491521502088_item	2582993	et	3	main
vi	doc_491521502088_item	2582996	et	4	main
kirjutage	doc_491521502088_item	2582997	et	3	main
2	doc_491521502088_item	2583007	et	2	main
n-ö	doc_491521502088_item	2583010	et	4	main
4	doc_491521502088_item	2583013	et	2	main
jm	doc_491521502088_item	2583014	et	4	main
korterist	doc_491521502088_item	2583038	et	3	main
oma	doc_491521502088_item	2583042	et	4	main
uuest	doc_491521502088_item	2583046	et	3	main
korterist	doc_491521502088_item	2583047	et	3	main
ärge	doc_491521502088_item	2583048	et	3	main
unustage	doc_491521502088_item	2583049	et	3	main
te	doc_491521502088_item	2583055	et	4	main
sõlmite	doc_491521502088_item	2583056	et	3	main
lepingut	doc_491521502088_item	2583058	et	3	main
tähelepanelik	doc_491521502088_item	2583061	et	4	main
väga	doc_491521502088_item	2583066	et	3	main
3	doc_491521502088_item	2583074	et	2	main
kui	doc_491521502088_item	2583075	et	3	main
kesklinnaga	doc_491521502088_item	2583077	et	3	main
suur	doc_491521502088_item	2583123	et	3	main
viii	doc_491521502088_item	2583137	et	4	main
moodustage	doc_491521502088_item	2583138	et	3	main
k	doc_491521502088_item	2583144	et	4	main
õhk	doc_491521502088_item	2583159	et	3	main
2	doc_491521502088_item	2583161	et	2	main
3	doc_491521502088_item	2583166	et	2	main
pool	doc_491521502088_item	2583167	et	4	main
meetrit	doc_491521502088_item	2583168	et	3	main
liiget	doc_491521502088_item	2583172	et	3	main
5	doc_491521502088_item	2583174	et	2	main
toodeng	doc_491521502088_item	2583176	et	4	main
suurepärane	doc_491521502088_item	2583179	et	4	main
9	doc_491521502088_item	2583189	et	2	main
endist	doc_491521502088_item	2582822	et	4	main
ei	doc_491521502088_item	2582830	et	4	main
töötada	doc_491521502088_item	2582833	et	3	main
mitmesuguseid	doc_491521502088_item	2582854	et	3	main
saadavad	doc_491521502088_item	2582858	et	4	main
ametnikud	doc_491521502088_item	2582859	et	3	main
tööotsijat	doc_491521502088_item	2582860	et	3	main
ühe	doc_491521502088_item	2582861	et	4	main
juurest	doc_491521502088_item	2582862	et	4	main
teise	doc_491521502088_item	2582863	et	4	main
juurde	doc_491521502088_item	2582864	et	4	main
tööotsijat	doc_491521502088_item	2582865	et	3	main
tihti	doc_491521502088_item	2582866	et	3	main
saadetakse	doc_491521502088_item	2582867	et	3	main
ühe	doc_491521502088_item	2582868	et	4	main
juurest	doc_491521502088_item	2582869	et	4	main
teise	doc_491521502088_item	2582870	et	4	main
juurde	doc_491521502088_item	2582871	et	4	main
5	doc_491521502088_item	2582872	et	2	main
sõlmib	doc_491521502088_item	2582886	et	3	main
lapsega	doc_491521502088_item	2582887	et	3	main
töölepingu	doc_491521502088_item	2582888	et	4	main
töölepingu	doc_491521502088_item	2582894	et	4	main
kirjalikul	doc_491521502088_item	2582896	et	3	main
lauludega	doc_491521502088_item	2582912	et	3	main
loeb	doc_491521502088_item	2582919	et	3	main
kirjandust	doc_491521502088_item	2582926	et	3	main
pakuvad	doc_491521502088_item	2582929	et	3	main
abitööd	doc_491521502088_item	2582932	et	4	main
laused	doc_491521502088_item	2582939	et	3	main
1	doc_491521502088_item	2582942	et	2	main
mind	doc_491521502088_item	2582944	et	4	main
paneb	doc_491521502088_item	2582950	et	3	main
tüütasid	doc_491521502088_item	2582961	et	4	main
vihale	doc_491521502088_item	2582982	et	4	main
5	doc_491521502088_item	2582983	et	2	main
ta	doc_491521502088_item	2582994	et	4	main
närveerib	doc_491521502088_item	2582995	et	3	main
ja	doc_491521502088_item	2583004	et	3	main
nii	doc_491521502088_item	2583005	et	3	main
edasi	doc_491521502088_item	2583006	et	3	main
nii	doc_491521502088_item	2583011	et	3	main
ja	doc_491521502088_item	2583015	et	3	main
muud	doc_491521502088_item	2583016	et	4	main
5	doc_491521502088_item	2583017	et	2	main
vii	doc_491521502088_item	2583021	et	4	main
lausetest	doc_491521502088_item	2583023	et	4	main
des-lauselühendiga	doc_491521502088_item	2583024	et	3	main
kui	doc_491521502088_item	2583027	et	3	main
te	doc_491521502088_item	2583028	et	4	main
unistate	doc_491521502088_item	2583029	et	3	main
uuest	doc_491521502088_item	2583030	et	3	main
korterist	doc_491521502088_item	2583031	et	3	main
ärge	doc_491521502088_item	2583032	et	3	main
unustage	doc_491521502088_item	2583033	et	3	main
oma	doc_491521502088_item	2583034	et	4	main
rahalisi	doc_491521502088_item	2583035	et	4	main
võimalusi	doc_491521502088_item	2583036	et	3	main
uuest	doc_491521502088_item	2583037	et	3	main
2	doc_491521502088_item	2583053	et	2	main
väga	doc_491521502088_item	2583060	et	3	main
uut	doc_491521502088_item	2583062	et	3	main
sõlmides	doc_491521502088_item	2583064	et	4	main
tähelepanek	doc_491521502088_item	2583067	et	3	main
väga	doc_491521502088_item	2583072	et	3	main
võrrelda	doc_491521502088_item	2583076	et	4	main
korterit	doc_491521502088_item	2583111	et	3	main
kaasa	doc_491521502088_item	2583115	et	4	main
suhtlete	doc_491521502088_item	2583119	et	3	main
tööandja	doc_491521502088_item	2582885	et	4	main
sõlmitakse	doc_491521502088_item	2582893	et	3	main
7	doc_491521502088_item	2582898	et	2	main
juht	doc_491521502088_item	2582900	et	3	main
kirjutab	doc_491521502088_item	2582901	et	3	main
lepingule	doc_491521502088_item	2582904	et	3	main
8	doc_491521502088_item	2582907	et	2	main
kontserdil	doc_491521502088_item	2582910	et	3	main
uute	doc_491521502088_item	2582915	et	3	main
raamatukogus	doc_491521502088_item	2582920	et	4	main
erialast	doc_491521502088_item	2582921	et	4	main
tavaliselt	doc_491521502088_item	2582933	et	4	main
pakutakse	doc_491521502088_item	2582934	et	3	main
moodustage	doc_491521502088_item	2582938	et	3	main
suhtlemine	doc_491521502088_item	2582949	et	4	main
ära	doc_491521502088_item	2582963	et	4	main
3	doc_491521502088_item	2582964	et	2	main
kõigile	doc_491521502088_item	2582970	et	4	main
meeldima	doc_491521502088_item	2582971	et	3	main
4	doc_491521502088_item	2582972	et	2	main
rusikasse	doc_491521502088_item	2582984	et	4	main
pigistama	doc_491521502088_item	2582985	et	3	main
kui	doc_491521502088_item	2582986	et	3	main
tähendavad	doc_491521502088_item	2582999	et	4	main
järgmised	doc_491521502088_item	2583000	et	3	main
lühendid	doc_491521502088_item	2583001	et	3	main
1	doc_491521502088_item	2583002	et	2	main
3	doc_491521502088_item	2583009	et	2	main
nii	doc_491521502088_item	2583019	et	3	main
nimetatud	doc_491521502088_item	2583020	et	4	main
moodustage	doc_491521502088_item	2583022	et	3	main
laused	doc_491521502088_item	2583025	et	3	main
ärge	doc_491521502088_item	2583040	et	3	main
kui	doc_491521502088_item	2583054	et	3	main
uut	doc_491521502088_item	2583057	et	3	main
olge	doc_491521502088_item	2583059	et	3	main
vaatama	doc_491521502088_item	2583113	et	3	main
5	doc_491521502088_item	2583117	et	2	main
kui	doc_491521502088_item	2583118	et	3	main
abi	doc_491521502088_item	2583124	et	4	main
suheldes	doc_491521502088_item	2583126	et	3	main
abi	doc_491521502088_item	2583130	et	4	main
ndus	doc_491521502088_item	2583141	et	4	main
sõnad	doc_491521502088_item	2583151	et	4	main
1	doc_491521502088_item	2583158	et	2	main
õhkkond	doc_491521502088_item	2583160	et	3	main
valimine	doc_491521502088_item	2583163	et	4	main
poolemeetrine	doc_491521502088_item	2583169	et	4	main
kirjanik	doc_491521502088_item	2583187	et	3	main
13	doc_491521502088_item	2583205	et	2	main
leppija	doc_491521502088_item	2583207	et	4	main
käskivat	doc_491521502088_item	2583221	et	4	main
valetama	doc_491521502088_item	2583224	et	3	main
ärge	doc_491521502088_item	2583225	et	3	main
valetage	doc_491521502088_item	2583226	et	3	main
ruttu	doc_491521502088_item	2583229	et	4	main
rääkige	doc_491521502088_item	2583238	et	3	main
pahandama	doc_491521502088_item	2583253	et	3	main
vaadake	doc_491521502088_item	2583268	et	3	main
ärge	doc_491521502088_item	2583273	et	3	main
levinud	doc_491521502088_item	2583283	et	4	main
tõlkige	doc_491521502089_item	2583287	et	3	main
äärega	doc_491521502089_item	2583290	et	3	main
сапоги	doc_491521502089_item	2583292	et	2	main
vaeva	doc_491521502089_item	2583322	et	4	main
9	doc_491521502089_item	2583328	et	2	main
чертах	doc_491521502089_item	2583337	et	2	main
12	doc_491521502089_item	2583343	et	2	main
kummarduma	doc_491521502089_item	2583347	et	3	main
15	doc_491521502089_item	2583354	et	2	main
акушерка	doc_491521502089_item	2583356	et	2	main
reostus	doc_491521502089_item	2583358	et	4	main
18	doc_491521502089_item	2583363	et	2	main
tõlkige	doc_491521502089_item	2583373	et	3	main
в	doc_491521502089_item	2583377	et	2	main
мы	doc_491521502089_item	2583394	et	2	main
будет	doc_491521502089_item	2583397	et	2	main
подписан	doc_491521502089_item	2583399	et	2	main
või	doc_491521502089_item	2583410	et	4	main
ei	doc_491521502089_item	2583411	et	4	main
глупой	doc_491521502089_item	2583414	et	2	main
nõusolekul	doc_491521502088_item	2582891	et	3	main
vanema	doc_491521502088_item	2582895	et	4	main
nõusolekul	doc_491521502088_item	2582897	et	3	main
lepingule	doc_491521502088_item	2582902	et	3	main
alla	doc_491521502088_item	2582906	et	3	main
ansambel	doc_491521502088_item	2582908	et	3	main
uute	doc_491521502088_item	2582911	et	3	main
esinetakse	doc_491521502088_item	2582914	et	3	main
9	doc_491521502088_item	2582917	et	2	main
erialast	doc_491521502088_item	2582925	et	4	main
tavaliselt	doc_491521502088_item	2582928	et	4	main
v	doc_491521502088_item	2582937	et	4	main
sõnaühenditega	doc_491521502088_item	2582941	et	3	main
kõiki	doc_491521502088_item	2582962	et	4	main
meelepärane	doc_491521502088_item	2582966	et	4	main
välimus	doc_491521502088_item	2582967	et	3	main
ta	doc_491521502088_item	2582975	et	4	main
lobises	doc_491521502088_item	2582976	et	3	main
palju	doc_491521502088_item	2582978	et	4	main
ja	doc_491521502088_item	2582979	et	3	main
ajas	doc_491521502088_item	2582980	et	4	main
mida	doc_491521502088_item	2582998	et	4	main
va	doc_491521502088_item	2583008	et	3	main
öeldud	doc_491521502088_item	2583012	et	4	main
kirjandust	doc_491521502088_item	2582922	et	3	main
loetakse	doc_491521502088_item	2582924	et	3	main
10	doc_491521502088_item	2582927	et	2	main
lapsele	doc_491521502088_item	2582935	et	4	main
piinlikkust	doc_491521502088_item	2582945	et	4	main
teda	doc_491521502088_item	2582951	et	4	main
tundma	doc_491521502088_item	2582953	et	3	main
2	doc_491521502088_item	2582954	et	2	main
ära	doc_491521502088_item	2582955	et	4	main
tüütama	doc_491521502088_item	2582956	et	3	main
nad	doc_491521502088_item	2582957	et	3	main
lobisesid	doc_491521502088_item	2582958	et	4	main
palju	doc_491521502088_item	2582959	et	4	main
ja	doc_491521502088_item	2582960	et	3	main
ei	doc_491521502088_item	2582968	et	4	main
pea	doc_491521502088_item	2582969	et	4	main
ajama	doc_491521502088_item	2582974	et	4	main
keegi	doc_491521502088_item	2582987	et	4	main
pigistab	doc_491521502088_item	2582988	et	3	main
käed	doc_491521502088_item	2582989	et	3	main
rusikasse	doc_491521502088_item	2582990	et	4	main
see	doc_491521502088_item	2582991	et	3	main
tähendab	doc_491521502088_item	2582992	et	3	main
jne	doc_491521502088_item	2583003	et	4	main
nn	doc_491521502088_item	2583018	et	4	main
unustage	doc_491521502088_item	2583041	et	3	main
oma	doc_491521502088_item	2583050	et	4	main
rahalisi	doc_491521502088_item	2583051	et	4	main
võimalusi	doc_491521502088_item	2583052	et	3	main
lepingut	doc_491521502088_item	2583063	et	3	main
olge	doc_491521502088_item	2583065	et	3	main
sõlmides	doc_491521502088_item	2583068	et	4	main
uut	doc_491521502088_item	2583069	et	3	main
lepingut	doc_491521502088_item	2583070	et	3	main
olge	doc_491521502088_item	2583071	et	3	main
võtke	doc_491521502088_item	2583114	et	3	main
asjatundja	doc_491521502088_item	2583116	et	4	main
ametnikega	doc_491521502088_item	2583120	et	3	main
on	doc_491521502088_item	2583121	et	4	main
maaklerist	doc_491521502088_item	2583128	et	3	main
suur	doc_491521502088_item	2583129	et	3	main
suheldes	doc_491521502088_item	2583131	et	3	main
ametnikega	doc_491521502088_item	2583132	et	3	main
line	doc_491521502088_item	2583145	et	4	main
mine	doc_491521502088_item	2583147	et	3	main
4	doc_491521502088_item	2583170	et	2	main
kuueliikmeline	doc_491521502088_item	2583173	et	4	main
kirjandus	doc_491521502088_item	2583188	et	3	main
üürija	doc_491521502088_item	2583191	et	4	main
10	doc_491521502088_item	2583194	et	2	main
kujundaja	doc_491521502088_item	2583196	et	4	main
kujandamine	doc_491521502088_item	2583197	et	4	main
meelepärane	doc_491521502088_item	2583204	et	4	main
leppimine	doc_491521502088_item	2583209	et	4	main
14	doc_491521502088_item	2583210	et	2	main
ix	doc_491521502088_item	2583219	et	4	main
1	doc_491521502088_item	2583223	et	2	main
säilitage	doc_491521502088_item	2583233	et	3	main
ärge	doc_491521502088_item	2583237	et	3	main
kohta	doc_491521502088_item	2583240	et	4	main
kuulake	doc_491521502088_item	2583245	et	4	main
intervjuu	doc_491521502088_item	2583255	et	4	main
küsima	doc_491521502088_item	2583257	et	3	main
teatatakse	doc_491521502088_item	2583260	et	3	main
ärge	doc_491521502088_item	2583264	et	3	main
intervjueerijale	doc_491521502088_item	2583269	et	4	main
9	doc_491521502088_item	2583271	et	2	main
stiiliga	doc_491521502088_item	2583284	et	3	main
1	doc_491521502089_item	2583288	et	2	main
8	doc_491521502089_item	2583325	et	2	main
колебаться	doc_491521502089_item	2583327	et	2	main
товар	doc_491521502089_item	2583330	et	2	main
назначения	doc_491521502089_item	2583332	et	2	main
деятельность	doc_491521502089_item	2583342	et	2	main
13	doc_491521502089_item	2583346	et	2	main
liibuvad	doc_491521502089_item	2583350	et	4	main
püksid	doc_491521502089_item	2583351	et	3	main
16	doc_491521502089_item	2583357	et	2	main
мешать	doc_491521502089_item	2583365	et	2	main
20	doc_491521502089_item	2583369	et	2	main
деловой	doc_491521502089_item	2583371	et	2	main
1	doc_491521502089_item	2583374	et	2	main
деревне	doc_491521502089_item	2583378	et	2	main
veedetud	doc_491521502089_item	2583380	et	4	main
2	doc_491521502089_item	2583382	et	2	main
привезенный	doc_491521502089_item	2583384	et	2	main
с	doc_491521502089_item	2583385	et	2	main
оптового	doc_491521502089_item	2583387	et	2	main
ei	doc_491521502089_item	2583403	et	4	main
tea	doc_491521502089_item	2583404	et	4	main
veel	doc_491521502089_item	2583405	et	4	main
kas	doc_491521502089_item	2583406	et	3	main
lepingule	doc_491521502089_item	2583407	et	3	main
kirjutatakse	doc_491521502089_item	2583408	et	3	main
alla	doc_491521502089_item	2583409	et	3	main
1	doc_491521502088_item	2583026	et	2	main
unistades	doc_491521502088_item	2583039	et	3	main
rahalisi	doc_491521502088_item	2583043	et	4	main
võimalusi	doc_491521502088_item	2583044	et	3	main
unistades	doc_491521502088_item	2583045	et	3	main
tähelepanelik	doc_491521502088_item	2583073	et	4	main
on	doc_491521502088_item	2583078	et	4	main
see	doc_491521502088_item	2583079	et	3	main
korter	doc_491521502088_item	2583080	et	3	main
odav	doc_491521502088_item	2583081	et	3	main
kesklinnaga	doc_491521502088_item	2583082	et	3	main
võrreldes	doc_491521502088_item	2583083	et	3	main
on	doc_491521502088_item	2583084	et	4	main
see	doc_491521502088_item	2583085	et	3	main
korter	doc_491521502088_item	2583086	et	3	main
odav	doc_491521502088_item	2583087	et	3	main
võrreldes	doc_491521502088_item	2583088	et	3	main
kesklinnaga	doc_491521502088_item	2583089	et	3	main
on	doc_491521502088_item	2583090	et	4	main
see	doc_491521502088_item	2583091	et	3	main
korter	doc_491521502088_item	2583092	et	3	main
odav	doc_491521502088_item	2583093	et	3	main
4	doc_491521502088_item	2583094	et	2	main
kui	doc_491521502088_item	2583095	et	3	main
lähete	doc_491521502088_item	2583096	et	4	main
korterit	doc_491521502088_item	2583097	et	3	main
üle	doc_491521502088_item	2583098	et	3	main
vaatama	doc_491521502088_item	2583099	et	3	main
võtke	doc_491521502088_item	2583100	et	3	main
kaasa	doc_491521502088_item	2583101	et	4	main
asjatundja	doc_491521502088_item	2583102	et	4	main
korterit	doc_491521502088_item	2583103	et	3	main
üle	doc_491521502088_item	2583104	et	3	main
vaatama	doc_491521502088_item	2583105	et	3	main
minnes	doc_491521502088_item	2583106	et	3	main
võtke	doc_491521502088_item	2583107	et	3	main
kaasa	doc_491521502088_item	2583108	et	4	main
asjatundja	doc_491521502088_item	2583109	et	4	main
minnes	doc_491521502088_item	2583110	et	3	main
üle	doc_491521502088_item	2583112	et	3	main
maaklerist	doc_491521502088_item	2583122	et	3	main
on	doc_491521502088_item	2583127	et	4	main
ja	doc_491521502088_item	2583139	et	3	main
nik	doc_491521502088_item	2583140	et	4	main
ng	doc_491521502088_item	2583143	et	4	main
ne	doc_491521502088_item	2583146	et	4	main
või	doc_491521502088_item	2583148	et	4	main
kond-	doc_491521502088_item	2583149	et	4	main
valima	doc_491521502088_item	2583162	et	3	main
valik	doc_491521502088_item	2583164	et	3	main
valija	doc_491521502088_item	2583165	et	4	main
kuus	doc_491521502088_item	2583171	et	4	main
tootma	doc_491521502088_item	2583175	et	3	main
kokkutulemine	doc_491521502088_item	2583184	et	4	main
8	doc_491521502088_item	2583185	et	2	main
kiri	doc_491521502088_item	2583186	et	3	main
meel	doc_491521502088_item	2583203	et	4	main
leppima	doc_491521502088_item	2583206	et	3	main
lepping	doc_491521502088_item	2583208	et	4	main
kasutage	doc_491521502088_item	2583220	et	3	main
kõneviisi	doc_491521502088_item	2583222	et	4	main
see	doc_491521502088_item	2583227	et	3	main
tuleb	doc_491521502088_item	2583228	et	3	main
säilitama	doc_491521502088_item	2583232	et	4	main
3	doc_491521502088_item	2583235	et	2	main
4	doc_491521502088_item	2583243	et	2	main
5	doc_491521502088_item	2583248	et	2	main
ärge	doc_491521502088_item	2583250	et	3	main
kõhklema	doc_491521502088_item	2583272	et	3	main
oma	doc_491521502088_item	2583275	et	4	main
10	doc_491521502088_item	2583277	et	2	main
püüdma	doc_491521502088_item	2583278	et	3	main
püüdke	doc_491521502088_item	2583279	et	3	main
sarnaneda	doc_491521502088_item	2583280	et	3	main
selles	doc_491521502088_item	2583281	et	4	main
töökohas	doc_491521502088_item	2583282	et	4	main
karvase	doc_491521502089_item	2583289	et	4	main
saapad	doc_491521502089_item	2583291	et	3	main
меховым	doc_491521502089_item	2583294	et	2	main
7	doc_491521502089_item	2583321	et	2	main
otstarve	doc_491521502089_item	2583329	et	3	main
прямого	doc_491521502089_item	2583331	et	2	main
в	doc_491521502089_item	2583335	et	2	main
rakendust	doc_491521502089_item	2583339	et	4	main
eelistama	doc_491521502089_item	2583344	et	3	main
наклониться	doc_491521502089_item	2583348	et	2	main
брюки	doc_491521502089_item	2583353	et	2	main
притворяться	doc_491521502089_item	2583362	et	2	main
19	doc_491521502089_item	2583366	et	2	main
asjatundlik	doc_491521502089_item	2583370	et	3	main
отпуск	doc_491521502089_item	2583375	et	2	main
kaup	doc_491521502089_item	2583392	et	3	main
не	doc_491521502089_item	2583395	et	2	main
или	doc_491521502089_item	2583400	et	2	main
me	doc_491521502089_item	2583402	et	4	main
4	doc_491521502089_item	2583412	et	2	main
разумеется	doc_491521502089_item	2583424	et	2	main
6	doc_491521502089_item	2583427	et	2	main
ülemus	doc_491521502089_item	2583433	et	4	main
кубок	doc_491521502089_item	2583439	et	2	main
на	doc_491521502089_item	2583441	et	2	main
võidetud	doc_491521502089_item	2583444	et	4	main
буклет	doc_491521502089_item	2583447	et	2	main
с	doc_491521502089_item	2583449	et	2	main
tutvustav	doc_491521502089_item	2583452	et	4	main
знаете	doc_491521502089_item	2583456	et	2	main
директор	doc_491521502089_item	2583460	et	2	main
зазубренные	doc_491521502089_item	2583470	et	2	main
õppitud	doc_491521502089_item	2583473	et	4	main
liiga	doc_491521502089_item	2583501	et	4	main
lasi	doc_491521502089_item	2583505	et	4	main
korda	doc_491521502089_item	2583507	et	4	main
vaeva	doc_491521502089_item	2583509	et	4	main
et	doc_491521502089_item	2583510	et	3	main
seda	doc_491521502089_item	2583511	et	3	main
korterit	doc_491521502089_item	2583512	et	3	main
maha	doc_491521502089_item	2583513	et	4	main
5	doc_491521502089_item	2583515	et	2	main
seda	doc_491521502089_item	2583516	et	3	main
maja	doc_491521502089_item	2583517	et	4	main
ametnikega	doc_491521502088_item	2583125	et	3	main
on	doc_491521502088_item	2583133	et	4	main
maaklerist	doc_491521502088_item	2583134	et	3	main
suur	doc_491521502088_item	2583135	et	3	main
abi	doc_491521502088_item	2583136	et	4	main
pärane	doc_491521502088_item	2583142	et	4	main
liitelised	doc_491521502088_item	2583150	et	4	main
ühel	doc_491521502088_item	2583152	et	3	main
sõnal	doc_491521502088_item	2583153	et	3	main
võib	doc_491521502088_item	2583154	et	3	main
olla	doc_491521502088_item	2583155	et	3	main
mitu	doc_491521502088_item	2583156	et	4	main
varianti	doc_491521502088_item	2583157	et	4	main
6	doc_491521502088_item	2583177	et	2	main
suur	doc_491521502088_item	2583178	et	3	main
7	doc_491521502088_item	2583180	et	2	main
kokku	doc_491521502088_item	2583181	et	3	main
tulema	doc_491521502088_item	2583182	et	4	main
kokkutulek	doc_491521502088_item	2583183	et	3	main
üür	doc_491521502088_item	2583190	et	3	main
üüring	doc_491521502088_item	2583193	et	4	main
kujundama	doc_491521502088_item	2583195	et	3	main
11	doc_491521502088_item	2583198	et	2	main
aed	doc_491521502088_item	2583199	et	3	main
aianik	doc_491521502088_item	2583200	et	4	main
aiamine	doc_491521502088_item	2583201	et	4	main
12	doc_491521502088_item	2583202	et	2	main
päeva	doc_491521502088_item	2583217	et	4	main
seitsmepäevane	doc_491521502088_item	2583218	et	4	main
2	doc_491521502088_item	2583231	et	2	main
rääkima	doc_491521502088_item	2583236	et	3	main
enda	doc_491521502088_item	2583239	et	4	main
negatiivseid	doc_491521502088_item	2583241	et	3	main
asju	doc_491521502088_item	2583242	et	3	main
kuulama	doc_491521502088_item	2583244	et	3	main
küsimusi	doc_491521502088_item	2583247	et	4	main
intervjueerijat	doc_491521502088_item	2583252	et	4	main
lõpus	doc_491521502088_item	2583256	et	4	main
küsige	doc_491521502088_item	2583258	et	3	main
millal	doc_491521502088_item	2583259	et	3	main
7	doc_491521502088_item	2583262	et	2	main
8	doc_491521502088_item	2583266	et	2	main
kontrolltöö	doc_491521502089_item	2583285	et	4	main
с	doc_491521502089_item	2583293	et	2	main
стараться	doc_491521502089_item	2583324	et	2	main
kõikuma	doc_491521502089_item	2583326	et	3	main
10	doc_491521502089_item	2583333	et	2	main
общих	doc_491521502089_item	2583336	et	2	main
найти	doc_491521502089_item	2583341	et	2	main
14	doc_491521502089_item	2583349	et	2	main
облигающие	doc_491521502089_item	2583352	et	2	main
ämmaemand	doc_491521502089_item	2583355	et	3	main
17	doc_491521502089_item	2583360	et	2	main
vilets	doc_491521502089_item	2583367	et	3	main
ii	doc_491521502089_item	2583372	et	4	main
проведенный	doc_491521502089_item	2583376	et	2	main
maal	doc_491521502089_item	2583379	et	4	main
puhkus	doc_491521502089_item	2583381	et	3	main
товар	doc_491521502089_item	2583383	et	2	main
нового	doc_491521502089_item	2583386	et	2	main
склада	doc_491521502089_item	2583388	et	2	main
uuest	doc_491521502089_item	2583389	et	3	main
hulgilaost	doc_491521502089_item	2583390	et	4	main
по	doc_491521502089_item	2583413	et	2	main
само	doc_491521502089_item	2583422	et	2	main
suhtlemisoskus	doc_491521502089_item	2583425	et	3	main
начальник	doc_491521502089_item	2583428	et	2	main
прошедшего	doc_491521502089_item	2583431	et	2	main
hooaja	doc_491521502089_item	2583436	et	3	main
7	doc_491521502089_item	2583438	et	2	main
завоеванный	doc_491521502089_item	2583440	et	2	main
võistlustel	doc_491521502089_item	2583443	et	3	main
karikas	doc_491521502089_item	2583445	et	4	main
знакомящий	doc_491521502089_item	2583448	et	2	main
фирмой	doc_491521502089_item	2583450	et	2	main
не	doc_491521502089_item	2583455	et	2	main
вы	doc_491521502089_item	2583458	et	2	main
сбыту	doc_491521502089_item	2583462	et	2	main
on	doc_491521502089_item	2583468	et	4	main
4	doc_491521502089_item	2583503	et	2	main
müüa	doc_491521502089_item	2583514	et	3	main
6	doc_491521502089_item	2583521	et	2	main
kehtestamisega	doc_491521502089_item	2583528	et	4	main
küsitluse	doc_491521502089_item	2583535	et	4	main
küsimustikukõmu	doc_491521502089_item	2583536	et	4	main
tööandjate	doc_491521502089_item	2583537	et	3	main
krae	doc_491521502089_item	2583544	et	4	main
murdus	doc_491521502089_item	2583545	et	3	main
noorukid	doc_491521502089_item	2583549	et	3	main
hulguvad	doc_491521502089_item	2583551	et	3	main
sellele	doc_491521502089_item	2583555	et	4	main
teeskles	doc_491521502089_item	2583558	et	3	main
ta	doc_491521502089_item	2583559	et	4	main
üürnik	doc_491521502088_item	2583192	et	3	main
valima	doc_491521502088_item	2583211	et	3	main
valija	doc_491521502088_item	2583212	et	4	main
valik	doc_491521502088_item	2583213	et	3	main
valimine	doc_491521502088_item	2583214	et	4	main
15	doc_491521502088_item	2583215	et	2	main
seitse	doc_491521502088_item	2583216	et	3	main
välja	doc_491521502088_item	2583230	et	4	main
rahu	doc_491521502088_item	2583234	et	4	main
hoolikalt	doc_491521502088_item	2583246	et	4	main
hakkama	doc_491521502088_item	2583249	et	3	main
hakake	doc_491521502088_item	2583251	et	3	main
6	doc_491521502088_item	2583254	et	2	main
tulemused	doc_491521502088_item	2583261	et	3	main
hilinema	doc_491521502088_item	2583263	et	3	main
hilinege	doc_491521502088_item	2583265	et	3	main
vaatama	doc_491521502088_item	2583267	et	3	main
silma	doc_491521502088_item	2583270	et	4	main
kõhelge	doc_491521502088_item	2583274	et	4	main
võimetes	doc_491521502088_item	2583276	et	4	main
i	doc_491521502089_item	2583286	et	4	main
краем	doc_491521502089_item	2583295	et	2	main
2	doc_491521502089_item	2583296	et	2	main
käed	doc_491521502089_item	2583297	et	3	main
kukla	doc_491521502089_item	2583298	et	3	main
taga	doc_491521502089_item	2583299	et	4	main
руки	doc_491521502089_item	2583300	et	2	main
за	doc_491521502089_item	2583301	et	2	main
затылком	doc_491521502089_item	2583302	et	2	main
3	doc_491521502089_item	2583303	et	2	main
paneb	doc_491521502089_item	2583304	et	3	main
jalad	doc_491521502089_item	2583305	et	3	main
harki	doc_491521502089_item	2583306	et	4	main
ставит	doc_491521502089_item	2583307	et	2	main
ноги	doc_491521502089_item	2583308	et	2	main
врозь	doc_491521502089_item	2583309	et	2	main
4	doc_491521502089_item	2583310	et	2	main
haljastustööd	doc_491521502089_item	2583311	et	4	main
озеленительные	doc_491521502089_item	2583312	et	2	main
работы	doc_491521502089_item	2583313	et	2	main
5	doc_491521502089_item	2583314	et	2	main
kokku	doc_491521502089_item	2583315	et	3	main
puutuma	doc_491521502089_item	2583316	et	4	main
соприкасаться	doc_491521502089_item	2583317	et	2	main
6	doc_491521502089_item	2583318	et	2	main
tunnustama	doc_491521502089_item	2583319	et	3	main
опознавать	doc_491521502089_item	2583320	et	2	main
nägema	doc_491521502089_item	2583323	et	3	main
üldjoontes	doc_491521502089_item	2583334	et	3	main
11	doc_491521502089_item	2583338	et	2	main
leidma	doc_491521502089_item	2583340	et	3	main
предпочитать	doc_491521502089_item	2583345	et	2	main
загрязнение	doc_491521502089_item	2583359	et	2	main
teesklema	doc_491521502089_item	2583361	et	3	main
takistama	doc_491521502089_item	2583364	et	3	main
плохой	doc_491521502089_item	2583368	et	2	main
toodud	doc_491521502089_item	2583391	et	4	main
3	doc_491521502089_item	2583393	et	2	main
знаем	doc_491521502089_item	2583396	et	2	main
договор	doc_491521502089_item	2583398	et	2	main
нет	doc_491521502089_item	2583401	et	2	main
случайности	doc_491521502089_item	2583415	et	2	main
totra	doc_491521502089_item	2583416	et	3	main
juhuse	doc_491521502089_item	2583417	et	3	main
pärast	doc_491521502089_item	2583418	et	4	main
5	doc_491521502089_item	2583419	et	2	main
умение	doc_491521502089_item	2583420	et	2	main
сезона	doc_491521502089_item	2583432	et	2	main
eelmise	doc_491521502089_item	2583435	et	3	main
kokkuvõtteid	doc_491521502089_item	2583437	et	3	main
соревнованиях	doc_491521502089_item	2583442	et	2	main
firmat	doc_491521502089_item	2583451	et	3	main
voldik	doc_491521502089_item	2583453	et	3	main
ли	doc_491521502089_item	2583457	et	2	main
по	doc_491521502089_item	2583461	et	2	main
te	doc_491521502089_item	2583464	et	4	main
tea	doc_491521502089_item	2583466	et	4	main
kus	doc_491521502089_item	2583467	et	3	main
sõnad	doc_491521502089_item	2583474	et	4	main
iii	doc_491521502089_item	2583475	et	4	main
kriipsutage	doc_491521502089_item	2583476	et	3	main
maha	doc_491521502089_item	2583477	et	4	main
sobimatud	doc_491521502089_item	2583478	et	4	main
sõnad	doc_491521502089_item	2583479	et	4	main
1	doc_491521502089_item	2583480	et	2	main
teadlik	doc_491521502089_item	2583481	et	3	main
üleolevüllatunud	doc_491521502089_item	2583482	et	4	main
tarbija	doc_491521502089_item	2583483	et	4	main
tutvub	doc_491521502089_item	2583484	et	3	main
alati	doc_491521502089_item	2583485	et	4	main
sooduspakkumistega	doc_491521502089_item	2583486	et	3	main
2	doc_491521502089_item	2583487	et	2	main
me	doc_491521502089_item	2583488	et	4	main
hooldame	doc_491521502089_item	2583489	et	3	main
hoolitseme	doc_491521502089_item	2583490	et	3	main
hoolime	doc_491521502089_item	2583491	et	3	main
oma	doc_491521502089_item	2583492	et	4	main
töötajate	doc_491521502089_item	2583493	et	4	main
eest	doc_491521502089_item	2583494	et	4	main
3	doc_491521502089_item	2583495	et	2	main
tööotsija	doc_491521502089_item	2583496	et	4	main
общаться	doc_491521502089_item	2583421	et	2	main
enesestmõistetav	doc_491521502089_item	2583426	et	3	main
итоги	doc_491521502089_item	2583430	et	2	main
tegi	doc_491521502089_item	2583434	et	4	main
8	doc_491521502089_item	2583446	et	2	main
9	doc_491521502089_item	2583454	et	2	main
где	doc_491521502089_item	2583459	et	2	main
ega	doc_491521502089_item	2583463	et	3	main
ei	doc_491521502089_item	2583465	et	4	main
слова	doc_491521502089_item	2583471	et	2	main
pähele	doc_491521502089_item	2583472	et	4	main
maakler	doc_491521502089_item	2583504	et	3	main
собой	doc_491521502089_item	2583423	et	2	main
подвел	doc_491521502089_item	2583429	et	2	main
10	doc_491521502089_item	2583469	et	2	main
palju	doc_491521502089_item	2583502	et	4	main
kerkibkaasneb	doc_491521502089_item	2583518	et	4	main
haldab	doc_491521502089_item	2583519	et	3	main
firma	doc_491521502089_item	2583522	et	4	main
uue	doc_491521502089_item	2583526	et	3	main
viisime	doc_491521502089_item	2583533	et	4	main
läbi	doc_491521502089_item	2583534	et	4	main
pooleks	doc_491521502089_item	2583546	et	4	main
oma	doc_491521502089_item	2583560	et	4	main
umbisikuliseks	doc_491521502089_item	2583566	et	4	main
luba	doc_491521502089_item	2583570	et	4	main
lastel	doc_491521502089_item	2583571	et	4	main
töötada	doc_491521502089_item	2583572	et	3	main
täisajaga	doc_491521502089_item	2583573	et	3	main
lastel	doc_491521502089_item	2583574	et	4	main
teiega	doc_491521502089_item	2583586	et	3	main
tööandja	doc_491521502089_item	2583626	et	4	main
sõlmib	doc_491521502089_item	2583627	et	3	main
kirjalikul	doc_491521502089_item	2583631	et	3	main
7	doc_491521502089_item	2583640	et	2	main
firma	doc_491521502089_item	2583641	et	4	main
juht	doc_491521502089_item	2583642	et	3	main
kirjutab	doc_491521502089_item	2583643	et	3	main
lepingule	doc_491521502089_item	2583644	et	3	main
kontserdil	doc_491521502089_item	2583654	et	3	main
esineks	doc_491521502089_item	2583658	et	3	main
raamatukogus	doc_491521502089_item	2583665	et	4	main
üliõpilane	doc_491521502089_item	2583668	et	3	main
lapsele	doc_491521502089_item	2583681	et	4	main
paneb	doc_491521502089_item	2583689	et	3	main
tundma	doc_491521502089_item	2583692	et	3	main
panevad	doc_491521502089_item	2583694	et	4	main
sõprade	doc_491521502089_item	2583698	et	3	main
oma	doc_491521502089_item	2583706	et	4	main
käitumisega	doc_491521502089_item	2583708	et	4	main
mainis	doc_491521502089_item	2583497	et	3	main
lobises	doc_491521502089_item	2583498	et	3	main
hoidus	doc_491521502089_item	2583499	et	3	main
intervjuul	doc_491521502089_item	2583500	et	3	main
läbiajas	doc_491521502089_item	2583506	et	3	main
nägi	doc_491521502089_item	2583508	et	3	main
korteriühistu	doc_491521502089_item	2583520	et	4	main
otsib	doc_491521502089_item	2583523	et	3	main
me	doc_491521502089_item	2583532	et	4	main
järeldavadjagunevad	doc_491521502089_item	2583550	et	4	main
endist	doc_491521502089_item	2583561	et	4	main
ülemust	doc_491521502089_item	2583562	et	4	main
ei	doc_491521502089_item	2583575	et	4	main
lubata	doc_491521502089_item	2583576	et	3	main
töötada	doc_491521502089_item	2583577	et	3	main
täisajaga	doc_491521502089_item	2583578	et	3	main
teiega	doc_491521502089_item	2583582	et	3	main
võtaks	doc_491521502089_item	2583585	et	3	main
lapsega	doc_491521502089_item	2583628	et	3	main
sõlmiks	doc_491521502089_item	2583634	et	4	main
firma	doc_491521502089_item	2583646	et	4	main
lepingule	doc_491521502089_item	2583649	et	3	main
ansambel	doc_491521502089_item	2583652	et	3	main
uute	doc_491521502089_item	2583655	et	3	main
9	doc_491521502089_item	2583662	et	2	main
üliõpilane	doc_491521502089_item	2583663	et	3	main
raamatukos	doc_491521502089_item	2583670	et	4	main
erialast	doc_491521502089_item	2583671	et	4	main
lapsele	doc_491521502089_item	2583677	et	4	main
tavaliselt	doc_491521502089_item	2583679	et	4	main
pakutakse	doc_491521502089_item	2583680	et	3	main
v	doc_491521502089_item	2583683	et	4	main
laused	doc_491521502089_item	2583685	et	3	main
sõnaühenditega	doc_491521502089_item	2583687	et	3	main
mind	doc_491521502089_item	2583690	et	4	main
ära	doc_491521502089_item	2583701	et	4	main
ära	doc_491521502089_item	2583703	et	4	main
lobisemisega	doc_491521502089_item	2583724	et	4	main
pigistama	doc_491521502089_item	2583727	et	3	main
sa	doc_491521502089_item	2583729	et	3	main
vihane	doc_491521502089_item	2583731	et	4	main
järgmised	doc_491521502089_item	2583741	et	3	main
lühendid	doc_491521502089_item	2583742	et	3	main
2	doc_491521502089_item	2583748	et	2	main
n-ö	doc_491521502089_item	2583753	et	4	main
öeldes	doc_491521502089_item	2583755	et	3	main
nimetatud	doc_491521502089_item	2583763	et	4	main
ärge	doc_491521502089_item	2583783	et	3	main
oma	doc_491521502089_item	2583785	et	4	main
võimalusi	doc_491521502089_item	2583787	et	3	main
te	doc_491521502089_item	2583790	et	4	main
sõlmite	doc_491521502089_item	2583791	et	3	main
uut	doc_491521502089_item	2583792	et	3	main
lepingut	doc_491521502089_item	2583793	et	3	main
olge	doc_491521502089_item	2583794	et	3	main
väga	doc_491521502089_item	2583801	et	3	main
see	doc_491521502089_item	2583808	et	3	main
on	doc_491521502089_item	2583813	et	4	main
korter	doc_491521502089_item	2583815	et	3	main
4	doc_491521502089_item	2583817	et	2	main
kui	doc_491521502089_item	2583818	et	3	main
korterit	doc_491521502089_item	2583820	et	3	main
võtke	doc_491521502089_item	2583823	et	3	main
üle	doc_491521502089_item	2583828	et	3	main
kaasa	doc_491521502089_item	2583831	et	4	main
on	doc_491521502089_item	2583837	et	4	main
nik	doc_491521502089_item	2583850	et	4	main
või	doc_491521502089_item	2583858	et	4	main
kuueliikmeline	doc_491521502089_item	2583884	et	4	main
5	doc_491521502089_item	2583885	et	2	main
tootma	doc_491521502089_item	2583886	et	3	main
tootja	doc_491521502089_item	2583887	et	4	main
toodang	doc_491521502089_item	2583888	et	3	main
suurepärane	doc_491521502089_item	2583892	et	4	main
üür	doc_491521502089_item	2583905	et	3	main
üürnik	doc_491521502089_item	2583907	et	3	main
13	doc_491521502089_item	2583920	et	2	main
valik	doc_491521502089_item	2583928	et	3	main
seitse	doc_491521502089_item	2583931	et	3	main
ix	doc_491521502089_item	2583934	et	4	main
säilitama	doc_491521502089_item	2583947	et	4	main
seoses	doc_491521502089_item	2583525	et	4	main
seas	doc_491521502089_item	2583538	et	4	main
8	doc_491521502089_item	2583539	et	2	main
tema	doc_491521502089_item	2583540	et	4	main
9	doc_491521502089_item	2583547	et	2	main
10	doc_491521502089_item	2583553	et	2	main
1	doc_491521502089_item	2583567	et	2	main
võtab	doc_491521502089_item	2583581	et	3	main
teeb	doc_491521502089_item	2583590	et	3	main
mitmesuguseid	doc_491521502089_item	2583591	et	3	main
ehitustöid	doc_491521502089_item	2583592	et	3	main
firma	doc_491521502089_item	2583593	et	4	main
teeks	doc_491521502089_item	2583594	et	4	main
mitmesuguseid	doc_491521502089_item	2583595	et	3	main
ehitustöid	doc_491521502089_item	2583596	et	3	main
4	doc_491521502089_item	2583597	et	2	main
tihti	doc_491521502089_item	2583598	et	3	main
saadavad	doc_491521502089_item	2583599	et	4	main
ametnikud	doc_491521502089_item	2583600	et	3	main
tööotsijat	doc_491521502089_item	2583601	et	3	main
ühe	doc_491521502089_item	2583602	et	4	main
juurest	doc_491521502089_item	2583603	et	4	main
teise	doc_491521502089_item	2583604	et	4	main
juurde	doc_491521502089_item	2583605	et	4	main
tihti	doc_491521502089_item	2583606	et	3	main
saadetakse	doc_491521502089_item	2583607	et	3	main
tööotsijat	doc_491521502089_item	2583608	et	3	main
ühe	doc_491521502089_item	2583609	et	4	main
juurest	doc_491521502089_item	2583610	et	4	main
teise	doc_491521502089_item	2583611	et	4	main
juurde	doc_491521502089_item	2583612	et	4	main
5	doc_491521502089_item	2583613	et	2	main
nad	doc_491521502089_item	2583614	et	3	main
ei	doc_491521502089_item	2583615	et	4	main
hinda	doc_491521502089_item	2583616	et	4	main
tema	doc_491521502089_item	2583617	et	4	main
tööd	doc_491521502089_item	2583618	et	4	main
piisavalt	doc_491521502089_item	2583619	et	4	main
tema	doc_491521502089_item	2583620	et	4	main
töötajaid	doc_491521502089_item	2583524	et	4	main
tootmisliini	doc_491521502089_item	2583527	et	4	main
käivitamisega	doc_491521502089_item	2583529	et	4	main
meelitamisega	doc_491521502089_item	2583530	et	4	main
7	doc_491521502089_item	2583531	et	2	main
kinga	doc_491521502089_item	2583541	et	4	main
varrukas	doc_491521502089_item	2583542	et	4	main
konts	doc_491521502089_item	2583543	et	3	main
tegevuseta	doc_491521502089_item	2583548	et	4	main
tänavail	doc_491521502089_item	2583552	et	4	main
lisaks	doc_491521502089_item	2583554	et	4	main
rõhutas	doc_491521502089_item	2583556	et	3	main
süüdistas	doc_491521502089_item	2583557	et	3	main
iv	doc_491521502089_item	2583563	et	4	main
muutke	doc_491521502089_item	2583564	et	3	main
laused	doc_491521502089_item	2583565	et	3	main
ei	doc_491521502089_item	2583569	et	4	main
ametnik	doc_491521502089_item	2583584	et	3	main
3	doc_491521502089_item	2583588	et	2	main
töölepingu	doc_491521502089_item	2583629	et	4	main
kirjutaks	doc_491521502089_item	2583648	et	3	main
8	doc_491521502089_item	2583651	et	2	main
ansambel	doc_491521502089_item	2583657	et	3	main
uute	doc_491521502089_item	2583660	et	3	main
loeb	doc_491521502089_item	2583664	et	3	main
loeks	doc_491521502089_item	2583669	et	4	main
kirjandust	doc_491521502089_item	2583672	et	3	main
tavaliselt	doc_491521502089_item	2583674	et	4	main
piinlikkust	doc_491521502089_item	2583691	et	4	main
mõnikord	doc_491521502089_item	2583693	et	3	main
piinlikkust	doc_491521502089_item	2583696	et	4	main
naljad	doc_491521502089_item	2583699	et	3	main
mind	doc_491521502089_item	2583705	et	4	main
meelepärane	doc_491521502089_item	2583710	et	4	main
õpetajat	doc_491521502089_item	2583722	et	4	main
käsi	doc_491521502089_item	2583736	et	4	main
tähendavad	doc_491521502089_item	2583740	et	4	main
välja	doc_491521502089_item	2583750	et	4	main
vii	doc_491521502089_item	2583764	et	4	main
sõlmides	doc_491521502089_item	2583797	et	4	main
lepingut	doc_491521502089_item	2583799	et	3	main
kesklinnaga	doc_491521502089_item	2583806	et	3	main
odav	doc_491521502089_item	2583810	et	3	main
seadus	doc_491521502089_item	2583568	et	4	main
2	doc_491521502089_item	2583579	et	2	main
ametnik	doc_491521502089_item	2583580	et	3	main
ühendust	doc_491521502089_item	2583583	et	4	main
ühendust	doc_491521502089_item	2583587	et	4	main
firma	doc_491521502089_item	2583589	et	4	main
tööd	doc_491521502089_item	2583621	et	4	main
hinnata	doc_491521502089_item	2583623	et	4	main
nõusolekul	doc_491521502089_item	2583632	et	3	main
alla	doc_491521502089_item	2583645	et	3	main
esineb	doc_491521502089_item	2583653	et	3	main
lauludega	doc_491521502089_item	2583661	et	3	main
asutused	doc_491521502089_item	2583676	et	4	main
abitööd	doc_491521502089_item	2583678	et	4	main
moodustage	doc_491521502089_item	2583684	et	3	main
tüütama	doc_491521502089_item	2583702	et	3	main
rumala	doc_491521502089_item	2583707	et	3	main
vihale	doc_491521502089_item	2583721	et	4	main
5	doc_491521502089_item	2583725	et	2	main
mida	doc_491521502089_item	2583739	et	4	main
jne	doc_491521502089_item	2583744	et	4	main
va	doc_491521502089_item	2583749	et	3	main
nii	doc_491521502089_item	2583754	et	3	main
4	doc_491521502089_item	2583756	et	2	main
ja	doc_491521502089_item	2583758	et	3	main
muud	doc_491521502089_item	2583759	et	4	main
5	doc_491521502089_item	2583760	et	2	main
rahalisi	doc_491521502089_item	2583786	et	4	main
2	doc_491521502089_item	2583788	et	2	main
uut	doc_491521502089_item	2583798	et	3	main
tähelepanelik	doc_491521502089_item	2583802	et	4	main
on	doc_491521502089_item	2583807	et	4	main
kesklinnaga	doc_491521502089_item	2583812	et	3	main
see	doc_491521502089_item	2583814	et	3	main
lähete	doc_491521502089_item	2583819	et	4	main
kaasa	doc_491521502089_item	2583824	et	4	main
minnes	doc_491521502089_item	2583826	et	3	main
võtke	doc_491521502089_item	2583830	et	3	main
asjatundja	doc_491521502089_item	2583832	et	4	main
5	doc_491521502089_item	2583833	et	2	main
kui	doc_491521502089_item	2583834	et	3	main
suheldes	doc_491521502089_item	2583841	et	3	main
on	doc_491521502089_item	2583843	et	4	main
pärane	doc_491521502089_item	2583852	et	4	main
line	doc_491521502089_item	2583855	et	4	main
õhk	doc_491521502089_item	2583869	et	3	main
pool	doc_491521502089_item	2583878	et	4	main
tootmine	doc_491521502089_item	2583889	et	4	main
suureline	doc_491521502089_item	2583893	et	4	main
tulema	doc_491521502089_item	2583896	et	4	main
kokkutulemine	doc_491521502089_item	2583897	et	4	main
kirjanik	doc_491521502089_item	2583901	et	3	main
üürija	doc_491521502089_item	2583906	et	4	main
kujundama	doc_491521502089_item	2583909	et	3	main
ei	doc_491521502089_item	2583622	et	4	main
piisavalt	doc_491521502089_item	2583624	et	4	main
6	doc_491521502089_item	2583625	et	2	main
vanema	doc_491521502089_item	2583630	et	4	main
tööandja	doc_491521502089_item	2583633	et	4	main
lapsega	doc_491521502089_item	2583635	et	3	main
töölepingu	doc_491521502089_item	2583636	et	4	main
vanema	doc_491521502089_item	2583637	et	4	main
kirjaliku	doc_491521502089_item	2583638	et	3	main
nõusolekul	doc_491521502089_item	2583639	et	3	main
juht	doc_491521502089_item	2583647	et	3	main
alla	doc_491521502089_item	2583650	et	3	main
lauludega	doc_491521502089_item	2583656	et	3	main
kontserdil	doc_491521502089_item	2583659	et	3	main
erialast	doc_491521502089_item	2583666	et	4	main
kirjandust	doc_491521502089_item	2583667	et	3	main
10	doc_491521502089_item	2583673	et	2	main
pakuvad	doc_491521502089_item	2583675	et	3	main
abitööd	doc_491521502089_item	2583682	et	4	main
järgmiste	doc_491521502089_item	2583686	et	3	main
1	doc_491521502089_item	2583688	et	2	main
mind	doc_491521502089_item	2583695	et	4	main
tundma	doc_491521502089_item	2583697	et	3	main
2	doc_491521502089_item	2583700	et	2	main
tüüta	doc_491521502089_item	2583704	et	4	main
3	doc_491521502089_item	2583709	et	2	main
mulle	doc_491521502089_item	2583711	et	4	main
meeldib	doc_491521502089_item	2583712	et	3	main
kuulata	doc_491521502089_item	2583713	et	4	main
meelepärast	doc_491521502089_item	2583714	et	4	main
muusikat	doc_491521502089_item	2583715	et	3	main
4	doc_491521502089_item	2583716	et	2	main
vihale	doc_491521502089_item	2583717	et	4	main
ajama	doc_491521502089_item	2583718	et	4	main
õpilased	doc_491521502089_item	2583719	et	3	main
ajasid	doc_491521502089_item	2583720	et	4	main
rusikasse	doc_491521502089_item	2583726	et	4	main
kui	doc_491521502089_item	2583728	et	3	main
pigista	doc_491521502089_item	2583733	et	4	main
rusikasse	doc_491521502089_item	2583734	et	4	main
oma	doc_491521502089_item	2583735	et	4	main
kirjutage	doc_491521502089_item	2583738	et	3	main
ja	doc_491521502089_item	2583745	et	3	main
nii	doc_491521502089_item	2583746	et	3	main
arvatud	doc_491521502089_item	2583751	et	4	main
nii	doc_491521502089_item	2583762	et	3	main
korterist	doc_491521502089_item	2583782	et	3	main
tähelepanelik	doc_491521502089_item	2583796	et	4	main
3	doc_491521502089_item	2583803	et	2	main
võrrelda	doc_491521502089_item	2583805	et	4	main
korter	doc_491521502089_item	2583809	et	3	main
üle	doc_491521502089_item	2583821	et	3	main
suhtlete	doc_491521502089_item	2583835	et	3	main
abi	doc_491521502089_item	2583840	et	4	main
ndus	doc_491521502089_item	2583851	et	4	main
k	doc_491521502089_item	2583854	et	4	main
ne	doc_491521502089_item	2583856	et	4	main
valija	doc_491521502089_item	2583874	et	4	main
valik	doc_491521502089_item	2583875	et	3	main
valimine	doc_491521502089_item	2583876	et	4	main
3	doc_491521502089_item	2583877	et	2	main
kokku	doc_491521502089_item	2583895	et	3	main
8	doc_491521502089_item	2583899	et	2	main
kirjandus	doc_491521502089_item	2583902	et	3	main
9	doc_491521502089_item	2583904	et	2	main
kujundaja	doc_491521502089_item	2583910	et	4	main
kujundamine	doc_491521502089_item	2583912	et	4	main
11	doc_491521502089_item	2583913	et	2	main
aed	doc_491521502089_item	2583914	et	3	main
aednik	doc_491521502089_item	2583915	et	3	main
aendus	doc_491521502089_item	2583916	et	4	main
12	doc_491521502089_item	2583917	et	2	main
leppimine	doc_491521502089_item	2583924	et	4	main
oma	doc_491521502089_item	2583723	et	4	main
oled	doc_491521502089_item	2583730	et	3	main
siis	doc_491521502089_item	2583732	et	3	main
vi	doc_491521502089_item	2583737	et	4	main
1	doc_491521502089_item	2583743	et	2	main
edasi	doc_491521502089_item	2583747	et	3	main
3	doc_491521502089_item	2583752	et	2	main
jm	doc_491521502089_item	2583757	et	4	main
nn	doc_491521502089_item	2583761	et	4	main
moodustage	doc_491521502089_item	2583765	et	3	main
lausetest	doc_491521502089_item	2583766	et	4	main
des-lauselühendiga	doc_491521502089_item	2583767	et	3	main
laused	doc_491521502089_item	2583768	et	3	main
1	doc_491521502089_item	2583769	et	2	main
kui	doc_491521502089_item	2583770	et	3	main
te	doc_491521502089_item	2583771	et	4	main
unistate	doc_491521502089_item	2583772	et	3	main
uuest	doc_491521502089_item	2583773	et	3	main
korterist	doc_491521502089_item	2583774	et	3	main
ärge	doc_491521502089_item	2583775	et	3	main
unustage	doc_491521502089_item	2583776	et	3	main
oma	doc_491521502089_item	2583777	et	4	main
rahalisi	doc_491521502089_item	2583778	et	4	main
võimalusi	doc_491521502089_item	2583779	et	3	main
unistades	doc_491521502089_item	2583780	et	3	main
uuest	doc_491521502089_item	2583781	et	3	main
unustage	doc_491521502089_item	2583784	et	3	main
kui	doc_491521502089_item	2583789	et	3	main
väga	doc_491521502089_item	2583795	et	3	main
olge	doc_491521502089_item	2583800	et	3	main
kui	doc_491521502089_item	2583804	et	3	main
võrreldes	doc_491521502089_item	2583811	et	3	main
odav	doc_491521502089_item	2583816	et	3	main
asjatundja	doc_491521502089_item	2583825	et	4	main
korterit	doc_491521502089_item	2583827	et	3	main
vaatama	doc_491521502089_item	2583829	et	3	main
maaklerist	doc_491521502089_item	2583838	et	3	main
ametnikega	doc_491521502089_item	2583842	et	3	main
suur	doc_491521502089_item	2583845	et	3	main
kond	doc_491521502089_item	2583870	et	4	main
õhuline	doc_491521502089_item	2583871	et	4	main
2	doc_491521502089_item	2583872	et	2	main
valima	doc_491521502089_item	2583873	et	3	main
kuus	doc_491521502089_item	2583882	et	4	main
liiget	doc_491521502089_item	2583883	et	3	main
suur	doc_491521502089_item	2583891	et	3	main
7	doc_491521502089_item	2583894	et	2	main
kokkutulija	doc_491521502089_item	2583898	et	4	main
kiri	doc_491521502089_item	2583900	et	3	main
kirjaline	doc_491521502089_item	2583903	et	4	main
10	doc_491521502089_item	2583908	et	2	main
meelepärane	doc_491521502089_item	2583919	et	4	main
leppija	doc_491521502089_item	2583922	et	4	main
seitsepäevane	doc_491521502089_item	2583933	et	4	main
käskivat	doc_491521502089_item	2583936	et	4	main
valeta	doc_491521502089_item	2583941	et	4	main
tuleb	doc_491521502089_item	2583943	et	3	main
millal	doc_491521502089_item	2583974	et	3	main
i	doc_491521502090_item	2584001	et	4	main
tõlkige	doc_491521502090_item	2584002	et	3	main
kukla	doc_491521502090_item	2584013	et	3	main
на	doc_491521502090_item	2584016	et	2	main
3	doc_491521502090_item	2584018	et	2	main
4	doc_491521502090_item	2584024	et	2	main
работы	doc_491521502090_item	2584027	et	2	main
5	doc_491521502090_item	2584028	et	2	main
kokku	doc_491521502090_item	2584029	et	3	main
6	doc_491521502090_item	2584032	et	2	main
7	doc_491521502090_item	2584035	et	2	main
9	doc_491521502090_item	2584042	et	2	main
10	doc_491521502090_item	2584045	et	2	main
чертах	doc_491521502090_item	2584049	et	2	main
rakendust	doc_491521502090_item	2584051	et	4	main
kummarduma	doc_491521502090_item	2584059	et	3	main
брюки	doc_491521502090_item	2584065	et	2	main
ämmaemand	doc_491521502090_item	2584067	et	3	main
знение	doc_491521502090_item	2584073	et	2	main
teesklema	doc_491521502090_item	2584075	et	3	main
склада	doc_491521502090_item	2584103	et	2	main
hulgilaost	doc_491521502090_item	2584105	et	4	main
kaup	doc_491521502090_item	2584107	et	3	main
договор	doc_491521502090_item	2584113	et	2	main
me	doc_491521502090_item	2584117	et	4	main
4	doc_491521502090_item	2584126	et	2	main
глупой	doc_491521502090_item	2584128	et	2	main
juhuse	doc_491521502090_item	2584131	et	3	main
5	doc_491521502090_item	2584133	et	2	main
общаться	doc_491521502090_item	2584135	et	2	main
разумеется	doc_491521502090_item	2584138	et	2	main
подвел	doc_491521502090_item	2584144	et	2	main
7	doc_491521502090_item	2584148	et	2	main
буклет	doc_491521502090_item	2584157	et	2	main
on	doc_491521502090_item	2584178	et	4	main
turundusdirektor	doc_491521502090_item	2584179	et	3	main
10	doc_491521502090_item	2584180	et	2	main
слова	doc_491521502090_item	2584182	et	2	main
tuubitud	doc_491521502090_item	2584183	et	4	main
sobimatud	doc_491521502090_item	2584188	et	4	main
üleolevüllatunud	doc_491521502090_item	2584192	et	4	main
tarbija	doc_491521502090_item	2584193	et	4	main
korterit	doc_491521502090_item	2584222	et	3	main
müüa	doc_491521502090_item	2584224	et	3	main
firma	doc_491521502090_item	2584232	et	4	main
uue	doc_491521502090_item	2584236	et	3	main
7	doc_491521502090_item	2584241	et	2	main
me	doc_491521502090_item	2584242	et	4	main
viisime	doc_491521502090_item	2584243	et	4	main
vaatama	doc_491521502089_item	2583822	et	3	main
ametnikega	doc_491521502089_item	2583836	et	3	main
suur	doc_491521502089_item	2583839	et	3	main
maaklerist	doc_491521502089_item	2583844	et	3	main
abi	doc_491521502089_item	2583846	et	4	main
viii	doc_491521502089_item	2583847	et	4	main
moodustage	doc_491521502089_item	2583848	et	3	main
ja	doc_491521502089_item	2583849	et	3	main
ng	doc_491521502089_item	2583853	et	4	main
mine	doc_491521502089_item	2583857	et	3	main
kond-	doc_491521502089_item	2583859	et	4	main
liitelised	doc_491521502089_item	2583860	et	4	main
sõnad	doc_491521502089_item	2583861	et	4	main
ühel	doc_491521502089_item	2583862	et	3	main
sõnal	doc_491521502089_item	2583863	et	3	main
võib	doc_491521502089_item	2583864	et	3	main
olla	doc_491521502089_item	2583865	et	3	main
mitu	doc_491521502089_item	2583866	et	4	main
varianti	doc_491521502089_item	2583867	et	4	main
1	doc_491521502089_item	2583868	et	2	main
meetrit	doc_491521502089_item	2583879	et	3	main
poolemeetrine	doc_491521502089_item	2583880	et	4	main
4	doc_491521502089_item	2583881	et	2	main
6	doc_491521502089_item	2583890	et	2	main
kujundus	doc_491521502089_item	2583911	et	4	main
meel	doc_491521502089_item	2583918	et	4	main
leppima	doc_491521502089_item	2583921	et	3	main
leping	doc_491521502089_item	2583923	et	3	main
valimine	doc_491521502089_item	2583929	et	4	main
1	doc_491521502089_item	2583938	et	2	main
enda	doc_491521502089_item	2583954	et	4	main
negatiivseid	doc_491521502089_item	2583956	et	3	main
kuula	doc_491521502089_item	2583960	et	4	main
hoolikalt	doc_491521502089_item	2583961	et	4	main
hakka	doc_491521502089_item	2583966	et	4	main
teatatakse	doc_491521502089_item	2583975	et	3	main
silma	doc_491521502089_item	2583985	et	4	main
9	doc_491521502089_item	2583986	et	2	main
kõhklema	doc_491521502089_item	2583987	et	3	main
sarnaneda	doc_491521502089_item	2583995	et	3	main
сапоги	doc_491521502090_item	2584007	et	2	main
мохнатым	doc_491521502090_item	2584009	et	2	main
расставляет	doc_491521502090_item	2584022	et	2	main
haljastustööd	doc_491521502090_item	2584025	et	4	main
puutuma	doc_491521502090_item	2584030	et	4	main
соприкасаться	doc_491521502090_item	2584031	et	2	main
tunnustama	doc_491521502090_item	2584033	et	3	main
8	doc_491521502090_item	2584039	et	2	main
otstarve	doc_491521502090_item	2584043	et	3	main
в	doc_491521502090_item	2584047	et	2	main
12	doc_491521502090_item	2584055	et	2	main
13	doc_491521502090_item	2584058	et	2	main
14	doc_491521502090_item	2584061	et	2	main
облигающие	doc_491521502090_item	2584064	et	2	main
16	doc_491521502090_item	2584069	et	2	main
загр	doc_491521502090_item	2584071	et	2	main
нового	doc_491521502090_item	2584101	et	2	main
не	doc_491521502090_item	2584110	et	2	main
подписан	doc_491521502090_item	2584114	et	2	main
kirjutatakse	doc_491521502090_item	2584122	et	3	main
võidetud	doc_491521502090_item	2584154	et	4	main
с	doc_491521502090_item	2584159	et	2	main
firmat	doc_491521502090_item	2584161	et	3	main
9	doc_491521502090_item	2584164	et	2	main
знаете	doc_491521502090_item	2584166	et	2	main
где	doc_491521502090_item	2584169	et	2	main
kas	doc_491521502090_item	2584173	et	3	main
ei	doc_491521502090_item	2584175	et	4	main
iii	doc_491521502090_item	2584185	et	4	main
kriipsutage	doc_491521502090_item	2584186	et	3	main
maha	doc_491521502090_item	2584187	et	4	main
14	doc_491521502089_item	2583925	et	2	main
valima	doc_491521502089_item	2583926	et	3	main
15	doc_491521502089_item	2583930	et	2	main
päeva	doc_491521502089_item	2583932	et	4	main
kasutage	doc_491521502089_item	2583935	et	3	main
valetama	doc_491521502089_item	2583939	et	3	main
see	doc_491521502089_item	2583942	et	3	main
rahu	doc_491521502089_item	2583949	et	4	main
3	doc_491521502089_item	2583950	et	2	main
valija	doc_491521502089_item	2583927	et	4	main
kõneviisi	doc_491521502089_item	2583937	et	4	main
ära	doc_491521502089_item	2583940	et	4	main
ruttu	doc_491521502089_item	2583944	et	4	main
välja	doc_491521502089_item	2583945	et	4	main
2	doc_491521502089_item	2583946	et	2	main
räägi	doc_491521502089_item	2583953	et	4	main
asju	doc_491521502089_item	2583957	et	3	main
kuulama	doc_491521502089_item	2583959	et	3	main
6	doc_491521502089_item	2583969	et	2	main
lõpus	doc_491521502089_item	2583971	et	4	main
7	doc_491521502089_item	2583977	et	2	main
ära	doc_491521502089_item	2583979	et	4	main
vaatama	doc_491521502089_item	2583982	et	3	main
kõhkle	doc_491521502089_item	2583989	et	4	main
oma	doc_491521502089_item	2583990	et	4	main
püüa	doc_491521502089_item	2583994	et	4	main
1	doc_491521502090_item	2584003	et	2	main
karvase	doc_491521502090_item	2584004	et	4	main
äärega	doc_491521502090_item	2584005	et	3	main
saapad	doc_491521502090_item	2584006	et	3	main
с	doc_491521502090_item	2584008	et	2	main
краем	doc_491521502090_item	2584010	et	2	main
руки	doc_491521502090_item	2584015	et	2	main
säilita	doc_491521502089_item	2583948	et	4	main
rääkima	doc_491521502089_item	2583951	et	3	main
ära	doc_491521502089_item	2583952	et	4	main
kohta	doc_491521502089_item	2583955	et	4	main
4	doc_491521502089_item	2583958	et	2	main
ära	doc_491521502089_item	2583965	et	4	main
pahandama	doc_491521502089_item	2583968	et	3	main
tulemused	doc_491521502089_item	2583976	et	3	main
hilinema	doc_491521502089_item	2583978	et	3	main
8	doc_491521502089_item	2583981	et	2	main
ära	doc_491521502089_item	2583988	et	4	main
püüdma	doc_491521502089_item	2583993	et	3	main
töökohas	doc_491521502089_item	2583997	et	4	main
stiiliga	doc_491521502089_item	2583999	et	3	main
2	doc_491521502090_item	2584011	et	2	main
признавать	doc_491521502090_item	2584034	et	2	main
kõikuma	doc_491521502090_item	2584040	et	3	main
занятие	doc_491521502090_item	2584054	et	2	main
eelistama	doc_491521502090_item	2584056	et	3	main
наклоняться	doc_491521502090_item	2584060	et	2	main
püksid	doc_491521502090_item	2584063	et	3	main
17	doc_491521502090_item	2584074	et	2	main
привезенный	doc_491521502090_item	2584099	et	2	main
toodud	doc_491521502090_item	2584106	et	4	main
знаем	doc_491521502090_item	2584111	et	2	main
lepingu	doc_491521502090_item	2584121	et	3	main
alla	doc_491521502090_item	2584123	et	3	main
või	doc_491521502090_item	2584124	et	4	main
по	doc_491521502090_item	2584127	et	2	main
tõttu	doc_491521502090_item	2584132	et	4	main
собой	doc_491521502090_item	2584137	et	2	main
6	doc_491521502090_item	2584142	et	2	main
прошедшего	doc_491521502090_item	2584146	et	2	main
на	doc_491521502090_item	2584151	et	2	main
фирмой	doc_491521502090_item	2584160	et	2	main
не	doc_491521502090_item	2584165	et	2	main
директор	doc_491521502090_item	2584170	et	2	main
te	doc_491521502090_item	2584174	et	4	main
tea	doc_491521502090_item	2584176	et	4	main
kus	doc_491521502090_item	2584177	et	3	main
зазубренные	doc_491521502090_item	2584181	et	2	main
1	doc_491521502090_item	2584190	et	2	main
seda	doc_491521502090_item	2584221	et	3	main
maja	doc_491521502090_item	2584227	et	4	main
otsib	doc_491521502090_item	2584233	et	3	main
seoses	doc_491521502090_item	2584235	et	4	main
küsitluse	doc_491521502090_item	2584245	et	4	main
tänavail	doc_491521502090_item	2584262	et	4	main
10	doc_491521502090_item	2584263	et	2	main
oma	doc_491521502090_item	2584268	et	4	main
seadus	doc_491521502090_item	2584276	et	4	main
võtab	doc_491521502090_item	2584289	et	3	main
teiega	doc_491521502090_item	2584290	et	3	main
teiega	doc_491521502090_item	2584292	et	3	main
firma	doc_491521502090_item	2584296	et	4	main
ehitustöid	doc_491521502090_item	2584299	et	3	main
mitmesuguseid	doc_491521502090_item	2584301	et	3	main
tihti	doc_491521502090_item	2584304	et	3	main
tööotsijat	doc_491521502090_item	2584307	et	3	main
teise	doc_491521502090_item	2584310	et	4	main
juurde	doc_491521502090_item	2584318	et	4	main
piisavalt	doc_491521502090_item	2584330	et	4	main
tööandja	doc_491521502090_item	2584332	et	4	main
vanema	doc_491521502090_item	2584342	et	4	main
7	doc_491521502090_item	2584345	et	2	main
8	doc_491521502090_item	2584354	et	2	main
erialast	doc_491521502090_item	2584368	et	4	main
raamatukogus	doc_491521502090_item	2584370	et	4	main
loetakse	doc_491521502090_item	2584371	et	3	main
tavaliselt	doc_491521502090_item	2584375	et	4	main
asutused	doc_491521502090_item	2584377	et	4	main
ka	doc_491521502090_item	2584421	et	3	main
võib	doc_491521502090_item	2584426	et	3	main
seda	doc_491521502090_item	2584427	et	3	main
tööd	doc_491521502090_item	2584428	et	4	main
ideaalseks	doc_491521502090_item	2584429	et	4	main
4	doc_491521502090_item	2584431	et	2	main
vihale	doc_491521502090_item	2584432	et	4	main
nimi	doc_491521502090_item	2584439	et	3	main
rusikasse	doc_491521502090_item	2584449	et	4	main
tähendavad	doc_491521502090_item	2584459	et	4	main
küsimusi	doc_491521502089_item	2583962	et	4	main
5	doc_491521502089_item	2583963	et	2	main
hakkama	doc_491521502089_item	2583964	et	3	main
intervjueerijat	doc_491521502089_item	2583967	et	4	main
intervjuu	doc_491521502089_item	2583970	et	4	main
küsima	doc_491521502089_item	2583972	et	3	main
küsi	doc_491521502089_item	2583973	et	4	main
hiline	doc_491521502089_item	2583980	et	4	main
vaata	doc_491521502089_item	2583983	et	4	main
intervjueerijale	doc_491521502089_item	2583984	et	4	main
võimetes	doc_491521502089_item	2583991	et	4	main
10	doc_491521502089_item	2583992	et	2	main
selles	doc_491521502089_item	2583996	et	4	main
levinud	doc_491521502089_item	2583998	et	4	main
kontrolltöö	doc_491521502090_item	2584000	et	4	main
käed	doc_491521502090_item	2584012	et	3	main
taga	doc_491521502090_item	2584014	et	4	main
затылке	doc_491521502090_item	2584017	et	2	main
paneb	doc_491521502090_item	2584019	et	3	main
jalad	doc_491521502090_item	2584020	et	3	main
harki	doc_491521502090_item	2584021	et	4	main
озеленительные	doc_491521502090_item	2584026	et	2	main
vaeva	doc_491521502090_item	2584036	et	4	main
трудиться	doc_491521502090_item	2584038	et	2	main
üldjoontes	doc_491521502090_item	2584046	et	3	main
leidma	doc_491521502090_item	2584052	et	3	main
я	doc_491521502090_item	2584072	et	2	main
с	doc_491521502090_item	2584100	et	2	main
uuest	doc_491521502090_item	2584104	et	3	main
3	doc_491521502090_item	2584108	et	2	main
или	doc_491521502090_item	2584115	et	2	main
mitte	doc_491521502090_item	2584125	et	3	main
случайности	doc_491521502090_item	2584129	et	2	main
totra	doc_491521502090_item	2584130	et	3	main
умение	doc_491521502090_item	2584134	et	2	main
само	doc_491521502090_item	2584136	et	2	main
on	doc_491521502090_item	2584140	et	4	main
начальник	doc_491521502090_item	2584143	et	2	main
сезона	doc_491521502090_item	2584147	et	2	main
завоеванный	doc_491521502090_item	2584150	et	2	main
võistlustel	doc_491521502090_item	2584153	et	3	main
karikas	doc_491521502090_item	2584155	et	4	main
знакомящий	doc_491521502090_item	2584158	et	2	main
voldik	doc_491521502090_item	2584163	et	3	main
вы	doc_491521502090_item	2584168	et	2	main
сбыту	doc_491521502090_item	2584172	et	2	main
sõnad	doc_491521502090_item	2584189	et	4	main
teadlik	doc_491521502090_item	2584191	et	3	main
maha	doc_491521502090_item	2584223	et	4	main
seda	doc_491521502090_item	2584226	et	3	main
kerkibkaasneb	doc_491521502090_item	2584228	et	4	main
haldab	doc_491521502090_item	2584229	et	3	main
korteriühistu	doc_491521502090_item	2584230	et	4	main
töötajaid	doc_491521502090_item	2584234	et	4	main
läbi	doc_491521502090_item	2584244	et	4	main
järeldavadjagunevad	doc_491521502090_item	2584260	et	4	main
hulguvad	doc_491521502090_item	2584261	et	3	main
ta	doc_491521502090_item	2584267	et	4	main
umbisikuliseks	doc_491521502090_item	2584274	et	4	main
1	doc_491521502090_item	2584275	et	2	main
täisajaga	doc_491521502090_item	2584281	et	3	main
lastel	doc_491521502090_item	2584282	et	4	main
ei	doc_491521502090_item	2584283	et	4	main
lubata	doc_491521502090_item	2584284	et	3	main
2	doc_491521502090_item	2584287	et	2	main
ühendust	doc_491521502090_item	2584294	et	4	main
tehakse	doc_491521502090_item	2584300	et	3	main
4	doc_491521502090_item	2584303	et	2	main
ametnikud	doc_491521502090_item	2584306	et	3	main
ühe	doc_491521502090_item	2584308	et	4	main
juurest	doc_491521502090_item	2584309	et	4	main
nad	doc_491521502090_item	2584320	et	3	main
tema	doc_491521502090_item	2584326	et	4	main
tööd	doc_491521502090_item	2584327	et	4	main
vanema	doc_491521502090_item	2584336	et	4	main
ansambel	doc_491521502090_item	2584355	et	3	main
lauludega	doc_491521502090_item	2584359	et	3	main
9	doc_491521502090_item	2584364	et	2	main
loeb	doc_491521502090_item	2584366	et	3	main
kirjandust	doc_491521502090_item	2584373	et	3	main
ноги	doc_491521502090_item	2584023	et	2	main
nägema	doc_491521502090_item	2584037	et	3	main
колебаться	doc_491521502090_item	2584041	et	2	main
назначение	doc_491521502090_item	2584044	et	2	main
общих	doc_491521502090_item	2584048	et	2	main
11	doc_491521502090_item	2584050	et	2	main
найти	doc_491521502090_item	2584053	et	2	main
предпочитать	doc_491521502090_item	2584057	et	2	main
liibuvad	doc_491521502090_item	2584062	et	4	main
15	doc_491521502090_item	2584066	et	2	main
акушерка	doc_491521502090_item	2584068	et	2	main
reostus	doc_491521502090_item	2584070	et	4	main
притворяться	doc_491521502090_item	2584076	et	2	main
18	doc_491521502090_item	2584077	et	2	main
takistama	doc_491521502090_item	2584078	et	3	main
препятствовать	doc_491521502090_item	2584079	et	2	main
19	doc_491521502090_item	2584080	et	2	main
vilets	doc_491521502090_item	2584081	et	3	main
худой	doc_491521502090_item	2584082	et	2	main
20	doc_491521502090_item	2584084	et	2	main
asjatundlik	doc_491521502090_item	2584085	et	3	main
компетентный	doc_491521502090_item	2584086	et	2	main
ii	doc_491521502090_item	2584087	et	4	main
tõlkige	doc_491521502090_item	2584088	et	3	main
1	doc_491521502090_item	2584089	et	2	main
отпуск	doc_491521502090_item	2584090	et	2	main
проведенный	doc_491521502090_item	2584091	et	2	main
в	doc_491521502090_item	2584092	et	2	main
плохой	doc_491521502090_item	2584083	et	2	main
деревне	doc_491521502090_item	2584093	et	2	main
maal	doc_491521502090_item	2584094	et	4	main
veetud	doc_491521502090_item	2584095	et	4	main
puhkus	doc_491521502090_item	2584096	et	3	main
2	doc_491521502090_item	2584097	et	2	main
товар	doc_491521502090_item	2584098	et	2	main
оптового	doc_491521502090_item	2584102	et	2	main
мы	doc_491521502090_item	2584109	et	2	main
будет	doc_491521502090_item	2584112	et	2	main
нет	doc_491521502090_item	2584116	et	2	main
ei	doc_491521502090_item	2584118	et	4	main
tea	doc_491521502090_item	2584119	et	4	main
kas	doc_491521502090_item	2584120	et	3	main
suhtlemisoskus	doc_491521502090_item	2584139	et	3	main
enesestmõistetav	doc_491521502090_item	2584141	et	3	main
итоги	doc_491521502090_item	2584145	et	2	main
кубок	doc_491521502090_item	2584149	et	2	main
соревнованиях	doc_491521502090_item	2584152	et	2	main
8	doc_491521502090_item	2584156	et	2	main
tutvuv	doc_491521502090_item	2584162	et	4	main
ли	doc_491521502090_item	2584167	et	2	main
по	doc_491521502090_item	2584171	et	2	main
sõnad	doc_491521502090_item	2584184	et	4	main
tutvub	doc_491521502090_item	2584194	et	3	main
alati	doc_491521502090_item	2584195	et	4	main
sooduspakkumistega	doc_491521502090_item	2584196	et	3	main
2	doc_491521502090_item	2584197	et	2	main
me	doc_491521502090_item	2584198	et	4	main
hooldame	doc_491521502090_item	2584199	et	3	main
hoolitseme	doc_491521502090_item	2584200	et	3	main
hoolime	doc_491521502090_item	2584201	et	3	main
oma	doc_491521502090_item	2584202	et	4	main
eest	doc_491521502090_item	2584204	et	4	main
töötajate	doc_491521502090_item	2584203	et	4	main
3	doc_491521502090_item	2584205	et	2	main
tööotsija	doc_491521502090_item	2584206	et	4	main
mainis	doc_491521502090_item	2584207	et	3	main
lobises	doc_491521502090_item	2584208	et	3	main
hoidus	doc_491521502090_item	2584209	et	3	main
intervjuul	doc_491521502090_item	2584210	et	3	main
liiga	doc_491521502090_item	2584211	et	4	main
palju	doc_491521502090_item	2584212	et	4	main
4	doc_491521502090_item	2584213	et	2	main
maakler	doc_491521502090_item	2584214	et	3	main
lasi	doc_491521502090_item	2584215	et	4	main
läbiajas	doc_491521502090_item	2584216	et	3	main
korda	doc_491521502090_item	2584217	et	4	main
nägi	doc_491521502090_item	2584218	et	3	main
vaeva	doc_491521502090_item	2584219	et	4	main
et	doc_491521502090_item	2584220	et	3	main
5	doc_491521502090_item	2584225	et	2	main
kehtestamisega	doc_491521502090_item	2584238	et	4	main
meelitamisega	doc_491521502090_item	2584240	et	4	main
küsimustikukõmu	doc_491521502090_item	2584246	et	4	main
tööandjate	doc_491521502090_item	2584247	et	3	main
8	doc_491521502090_item	2584249	et	2	main
tema	doc_491521502090_item	2584250	et	4	main
noorukid	doc_491521502090_item	2584259	et	3	main
rõhutassüüdistasteeskles	doc_491521502090_item	2584266	et	4	main
iv	doc_491521502090_item	2584271	et	4	main
muutke	doc_491521502090_item	2584272	et	3	main
laused	doc_491521502090_item	2584273	et	3	main
lastel	doc_491521502090_item	2584279	et	4	main
töötada	doc_491521502090_item	2584280	et	3	main
ametnik	doc_491521502090_item	2584288	et	3	main
ühendust	doc_491521502090_item	2584291	et	4	main
6	doc_491521502090_item	2584231	et	2	main
tootmisliini	doc_491521502090_item	2584237	et	4	main
käivitamisega	doc_491521502090_item	2584239	et	4	main
kinga	doc_491521502090_item	2584251	et	4	main
varrukas	doc_491521502090_item	2584252	et	4	main
konts	doc_491521502090_item	2584253	et	3	main
krae	doc_491521502090_item	2584254	et	4	main
murdus	doc_491521502090_item	2584255	et	3	main
pooleks	doc_491521502090_item	2584256	et	4	main
9	doc_491521502090_item	2584257	et	2	main
tegevuseta	doc_491521502090_item	2584258	et	4	main
seas	doc_491521502090_item	2584248	et	4	main
sellele	doc_491521502090_item	2584265	et	4	main
ülemust	doc_491521502090_item	2584270	et	4	main
luba	doc_491521502090_item	2584278	et	4	main
täisajaga	doc_491521502090_item	2584286	et	3	main
3	doc_491521502090_item	2584295	et	2	main
mitmesuguseid	doc_491521502090_item	2584298	et	3	main
saadetakse	doc_491521502090_item	2584313	et	3	main
lisaks	doc_491521502090_item	2584264	et	4	main
endist	doc_491521502090_item	2584269	et	4	main
ei	doc_491521502090_item	2584277	et	4	main
töötada	doc_491521502090_item	2584285	et	3	main
juurde	doc_491521502090_item	2584311	et	4	main
tihti	doc_491521502090_item	2584312	et	3	main
tööotsijat	doc_491521502090_item	2584314	et	3	main
5	doc_491521502090_item	2584319	et	2	main
piisavalt	doc_491521502090_item	2584325	et	4	main
6	doc_491521502090_item	2584331	et	2	main
sõlmib	doc_491521502090_item	2584333	et	3	main
lapsega	doc_491521502090_item	2584334	et	3	main
kirjalikul	doc_491521502090_item	2584337	et	3	main
kontserdil	doc_491521502090_item	2584357	et	3	main
esinetakse	doc_491521502090_item	2584361	et	3	main
erialast	doc_491521502090_item	2584372	et	4	main
mind	doc_491521502090_item	2584391	et	4	main
tundma	doc_491521502090_item	2584393	et	3	main
raha	doc_491521502090_item	2584423	et	4	main
siis	doc_491521502090_item	2584425	et	3	main
nimetada	doc_491521502090_item	2584430	et	3	main
tema	doc_491521502090_item	2584438	et	4	main
ajad	doc_491521502090_item	2584441	et	4	main
pigistatud	doc_491521502090_item	2584450	et	4	main
jne	doc_491521502090_item	2584463	et	4	main
nii	doc_491521502090_item	2584465	et	3	main
edasi	doc_491521502090_item	2584466	et	3	main
va	doc_491521502090_item	2584468	et	3	main
rahalisi	doc_491521502090_item	2584504	et	4	main
lepingut	doc_491521502090_item	2584517	et	3	main
võetakse	doc_491521502090_item	2584293	et	3	main
teeb	doc_491521502090_item	2584297	et	3	main
ehitustöid	doc_491521502090_item	2584302	et	3	main
saadavad	doc_491521502090_item	2584305	et	4	main
ühe	doc_491521502090_item	2584315	et	4	main
juurest	doc_491521502090_item	2584316	et	4	main
teise	doc_491521502090_item	2584317	et	4	main
ei	doc_491521502090_item	2584321	et	4	main
tema	doc_491521502090_item	2584323	et	4	main
ei	doc_491521502090_item	2584328	et	4	main
töölepingu	doc_491521502090_item	2584335	et	4	main
sõlmitakse	doc_491521502090_item	2584340	et	3	main
nõusolekul	doc_491521502090_item	2584344	et	3	main
firma	doc_491521502090_item	2584346	et	4	main
juht	doc_491521502090_item	2584347	et	3	main
kirjutab	doc_491521502090_item	2584348	et	3	main
lepingule	doc_491521502090_item	2584349	et	3	main
alla	doc_491521502090_item	2584350	et	3	main
lepingule	doc_491521502090_item	2584351	et	3	main
kirjutatakse	doc_491521502090_item	2584352	et	3	main
alla	doc_491521502090_item	2584353	et	3	main
lauludega	doc_491521502090_item	2584363	et	3	main
10	doc_491521502090_item	2584374	et	2	main
pakuvad	doc_491521502090_item	2584376	et	3	main
lapsele	doc_491521502090_item	2584378	et	4	main
abitööd	doc_491521502090_item	2584379	et	4	main
1	doc_491521502090_item	2584389	et	2	main
hinda	doc_491521502090_item	2584322	et	4	main
tööd	doc_491521502090_item	2584324	et	4	main
hinnata	doc_491521502090_item	2584329	et	4	main
nõusolekul	doc_491521502090_item	2584338	et	3	main
lapsega	doc_491521502090_item	2584339	et	3	main
töölepingu	doc_491521502090_item	2584341	et	4	main
kirjalikul	doc_491521502090_item	2584343	et	3	main
esineb	doc_491521502090_item	2584356	et	3	main
uute	doc_491521502090_item	2584358	et	3	main
kontserdil	doc_491521502090_item	2584360	et	3	main
uute	doc_491521502090_item	2584362	et	3	main
üliõpilane	doc_491521502090_item	2584365	et	3	main
raamatukogus	doc_491521502090_item	2584367	et	4	main
kirjandust	doc_491521502090_item	2584369	et	3	main
tavaliselt	doc_491521502090_item	2584380	et	4	main
pakutakse	doc_491521502090_item	2584381	et	3	main
piinlikkust	doc_491521502090_item	2584392	et	4	main
nende	doc_491521502090_item	2584394	et	4	main
komplimendid	doc_491521502090_item	2584395	et	3	main
on	doc_491521502090_item	2584396	et	4	main
nii	doc_491521502090_item	2584397	et	3	main
ruumalad	doc_491521502090_item	2584398	et	3	main
et	doc_491521502090_item	2584399	et	3	main
panevad	doc_491521502090_item	2584400	et	4	main
mind	doc_491521502090_item	2584401	et	4	main
piinlikkust	doc_491521502090_item	2584402	et	4	main
tundma	doc_491521502090_item	2584403	et	3	main
2	doc_491521502090_item	2584404	et	2	main
ära	doc_491521502090_item	2584405	et	4	main
tüütama	doc_491521502090_item	2584406	et	3	main
ära	doc_491521502090_item	2584407	et	4	main
haka	doc_491521502090_item	2584408	et	4	main
minu	doc_491521502090_item	2584409	et	3	main
peale	doc_491521502090_item	2584410	et	4	main
3	doc_491521502090_item	2584412	et	2	main
meelepärane	doc_491521502090_item	2584413	et	4	main
kui	doc_491521502090_item	2584414	et	3	main
inimese	doc_491521502090_item	2584415	et	4	main
tüüdata	doc_491521502090_item	2584411	et	4	main
töö	doc_491521502090_item	2584416	et	4	main
nii	doc_491521502090_item	2584417	et	3	main
meelepärane	doc_491521502090_item	2584418	et	4	main
on	doc_491521502090_item	2584419	et	4	main
kui	doc_491521502090_item	2584420	et	3	main
ajama	doc_491521502090_item	2584433	et	4	main
iga	doc_491521502090_item	2584434	et	4	main
sa	doc_491521502090_item	2584442	et	3	main
käed	doc_491521502090_item	2584451	et	3	main
tujust	doc_491521502090_item	2584455	et	3	main
mida	doc_491521502090_item	2584458	et	4	main
välja	doc_491521502090_item	2584469	et	4	main
n-ö	doc_491521502090_item	2584472	et	4	main
öelda	doc_491521502090_item	2584474	et	4	main
kui	doc_491521502090_item	2584507	et	3	main
te	doc_491521502090_item	2584508	et	4	main
lapsele	doc_491521502090_item	2584382	et	4	main
abitööd	doc_491521502090_item	2584383	et	4	main
v	doc_491521502090_item	2584384	et	4	main
moodustage	doc_491521502090_item	2584385	et	3	main
laused	doc_491521502090_item	2584386	et	3	main
järgmiste	doc_491521502090_item	2584387	et	3	main
sõnaühenditega	doc_491521502090_item	2584388	et	3	main
paneb	doc_491521502090_item	2584390	et	3	main
palju	doc_491521502090_item	2584422	et	4	main
toob	doc_491521502090_item	2584424	et	3	main
kord	doc_491521502090_item	2584435	et	4	main
kui	doc_491521502090_item	2584436	et	3	main
sa	doc_491521502090_item	2584437	et	3	main
rusikasse	doc_491521502090_item	2584446	et	4	main
pigistama	doc_491521502090_item	2584447	et	3	main
poisi	doc_491521502090_item	2584448	et	3	main
tema	doc_491521502090_item	2584453	et	4	main
pahast	doc_491521502090_item	2584454	et	4	main
vi	doc_491521502090_item	2584456	et	4	main
kirjutage	doc_491521502090_item	2584457	et	3	main
2	doc_491521502090_item	2584467	et	2	main
võimalusi	doc_491521502090_item	2584505	et	3	main
uut	doc_491521502090_item	2584510	et	3	main
olge	doc_491521502090_item	2584518	et	3	main
tähelepanelik	doc_491521502090_item	2584520	et	4	main
kui	doc_491521502090_item	2584522	et	3	main
kesklinnaga	doc_491521502090_item	2584529	et	3	main
4	doc_491521502090_item	2584535	et	2	main
üle	doc_491521502090_item	2584539	et	3	main
võtke	doc_491521502090_item	2584541	et	3	main
kaasa	doc_491521502090_item	2584549	et	4	main
asjatundja	doc_491521502090_item	2584550	et	4	main
5	doc_491521502090_item	2584551	et	2	main
kui	doc_491521502090_item	2584552	et	3	main
nik	doc_491521502090_item	2584568	et	4	main
k	doc_491521502090_item	2584572	et	4	main
7	doc_491521502090_item	2584607	et	2	main
8	doc_491521502090_item	2584611	et	2	main
kujundamine	doc_491521502090_item	2584621	et	4	main
seitsmepäevane	doc_491521502090_item	2584639	et	4	main
tuleb	doc_491521502090_item	2584649	et	3	main
rääkima	doc_491521502090_item	2584657	et	3	main
hakkama	doc_491521502090_item	2584670	et	3	main
hakake	doc_491521502090_item	2584672	et	3	main
intervjueerijat	doc_491521502090_item	2584673	et	4	main
lõpus	doc_491521502090_item	2584677	et	4	main
tulemused	doc_491521502090_item	2584682	et	3	main
ärge	doc_491521502090_item	2584685	et	3	main
vaadake	doc_491521502090_item	2584689	et	3	main
ärge	doc_491521502090_item	2584694	et	3	main
kisuvad	doc_491521502091_item	2584724	et	3	main
luituvad	doc_491521502091_item	2584725	et	4	main
plaani	doc_491521502091_item	2584730	et	4	main
5	doc_491521502091_item	2584743	et	2	main
tulemusi	doc_491521502091_item	2584764	et	4	main
6	doc_491521502091_item	2584799	et	2	main
ese	doc_491521502091_item	2584806	et	3	main
haisema	doc_491521502091_item	2584827	et	4	main
pigistama	doc_491521502091_item	2584830	et	3	main
iv	doc_491521502091_item	2584834	et	4	main
kreemide	doc_491521502091_item	2584849	et	3	main
kes	doc_491521502091_item	2584854	et	4	main
3	doc_491521502091_item	2584857	et	2	main
mis	doc_491521502091_item	2584861	et	4	main
4	doc_491521502091_item	2584867	et	2	main
mida	doc_491521502091_item	2584869	et	4	main
ei	doc_491521502091_item	2584880	et	4	main
nii	doc_491521502091_item	2584882	et	3	main
võib	doc_491521502091_item	2584887	et	3	main
eesti	doc_491521502091_item	2584895	et	4	main
keelde	doc_491521502091_item	2584896	et	4	main
1	doc_491521502091_item	2584897	et	2	main
клиенты	doc_491521502091_item	2584899	et	2	main
фирма	doc_491521502091_item	2584929	et	2	main
1	doc_491521502091_item	2584940	et	2	main
2	doc_491521502091_item	2584943	et	2	main
3	doc_491521502091_item	2584946	et	2	main
andetu	doc_491521502091_item	2584951	et	4	main
vii	doc_491521502091_item	2584955	et	4	main
ma	doc_491521502091_item	2584961	et	3	main
kavatsen	doc_491521502091_item	2584962	et	3	main
keele	doc_491521502091_item	2584964	et	4	main
mainid	doc_491521502090_item	2584440	et	3	main
mind	doc_491521502090_item	2584443	et	4	main
vihale	doc_491521502090_item	2584444	et	4	main
5	doc_491521502090_item	2584445	et	2	main
räägivad	doc_491521502090_item	2584452	et	3	main
ja	doc_491521502090_item	2584464	et	3	main
arvatud	doc_491521502090_item	2584470	et	4	main
jm	doc_491521502090_item	2584476	et	4	main
ja	doc_491521502090_item	2584477	et	3	main
4	doc_491521502090_item	2584475	et	2	main
muud	doc_491521502090_item	2584478	et	4	main
5	doc_491521502090_item	2584479	et	2	main
nn	doc_491521502090_item	2584480	et	4	main
niinimetatud	doc_491521502090_item	2584481	et	3	main
vii	doc_491521502090_item	2584482	et	4	main
moodustage	doc_491521502090_item	2584483	et	3	main
lausetest	doc_491521502090_item	2584484	et	4	main
des-lauselühendiga	doc_491521502090_item	2584485	et	3	main
laused	doc_491521502090_item	2584486	et	3	main
1	doc_491521502090_item	2584487	et	2	main
kui	doc_491521502090_item	2584488	et	3	main
te	doc_491521502090_item	2584489	et	4	main
unistate	doc_491521502090_item	2584490	et	3	main
uuest	doc_491521502090_item	2584491	et	3	main
korterist	doc_491521502090_item	2584492	et	3	main
ärge	doc_491521502090_item	2584493	et	3	main
unustage	doc_491521502090_item	2584494	et	3	main
oma	doc_491521502090_item	2584495	et	4	main
rahalisi	doc_491521502090_item	2584496	et	4	main
võimalusi	doc_491521502090_item	2584497	et	3	main
uuest	doc_491521502090_item	2584498	et	3	main
korterist	doc_491521502090_item	2584499	et	3	main
unistades	doc_491521502090_item	2584500	et	3	main
ärge	doc_491521502090_item	2584501	et	3	main
unustage	doc_491521502090_item	2584502	et	3	main
oma	doc_491521502090_item	2584503	et	4	main
2	doc_491521502090_item	2584506	et	2	main
järgmised	doc_491521502090_item	2584460	et	3	main
lühendid	doc_491521502090_item	2584461	et	3	main
1	doc_491521502090_item	2584462	et	2	main
3	doc_491521502090_item	2584471	et	2	main
nii	doc_491521502090_item	2584473	et	3	main
uut	doc_491521502090_item	2584516	et	3	main
3	doc_491521502090_item	2584521	et	2	main
korter	doc_491521502090_item	2584527	et	3	main
on	doc_491521502090_item	2584531	et	4	main
see	doc_491521502090_item	2584532	et	3	main
korter	doc_491521502090_item	2584533	et	3	main
odav	doc_491521502090_item	2584534	et	3	main
suhtlete	doc_491521502090_item	2584553	et	3	main
suur	doc_491521502090_item	2584557	et	3	main
suheldes	doc_491521502090_item	2584559	et	3	main
ametnikega	doc_491521502090_item	2584560	et	3	main
on	doc_491521502090_item	2584561	et	4	main
suur	doc_491521502090_item	2584563	et	3	main
pärane	doc_491521502090_item	2584570	et	4	main
ng	doc_491521502090_item	2584571	et	4	main
suurepärane	doc_491521502090_item	2584606	et	4	main
kiri	doc_491521502090_item	2584612	et	3	main
kirjanik	doc_491521502090_item	2584614	et	3	main
üürnik	doc_491521502090_item	2584617	et	3	main
kujundama	doc_491521502090_item	2584619	et	3	main
aednik	doc_491521502090_item	2584625	et	3	main
meel	doc_491521502090_item	2584627	et	4	main
käskivat	doc_491521502090_item	2584642	et	4	main
välja	doc_491521502090_item	2584651	et	4	main
säilitage	doc_491521502090_item	2584654	et	3	main
asju	doc_491521502090_item	2584663	et	3	main
kuulama	doc_491521502090_item	2584665	et	3	main
6	doc_491521502090_item	2584675	et	2	main
küsitage	doc_491521502090_item	2584679	et	3	main
millal	doc_491521502090_item	2584680	et	3	main
teatatakse	doc_491521502090_item	2584681	et	3	main
hilinege	doc_491521502090_item	2584686	et	3	main
oma	doc_491521502090_item	2584696	et	4	main
käsitsevad	doc_491521502091_item	2584723	et	4	main
raske	doc_491521502091_item	2584732	et	4	main
liigitada	doc_491521502091_item	2584733	et	3	main
teostada	doc_491521502091_item	2584735	et	3	main
uued	doc_491521502091_item	2584741	et	3	main
kui	doc_491521502091_item	2584744	et	3	main
kogeb	doc_491521502091_item	2584746	et	3	main
ebaõnnestumisi	doc_491521502091_item	2584748	et	3	main
isiksus	doc_491521502091_item	2584751	et	3	main
peaksid	doc_491521502091_item	2584757	et	4	main
endale	doc_491521502091_item	2584758	et	4	main
teadvustama	doc_491521502091_item	2584759	et	3	main
keskkonna	doc_491521502091_item	2584760	et	3	main
reostamise	doc_491521502091_item	2584761	et	4	main
7	doc_491521502091_item	2584765	et	2	main
mõned	doc_491521502091_item	2584768	et	3	main
mesikäpp	doc_491521502091_item	2584800	et	3	main
purunema	doc_491521502091_item	2584807	et	3	main
2	doc_491521502091_item	2584811	et	2	main
5	doc_491521502091_item	2584822	et	2	main
kreemituub	doc_491521502091_item	2584823	et	4	main
8	doc_491521502091_item	2584831	et	2	main
moodustage	doc_491521502091_item	2584835	et	3	main
ja	doc_491521502091_item	2584837	et	3	main
laused	doc_491521502091_item	2584839	et	3	main
seda	doc_491521502091_item	2584852	et	3	main
vitamiine	doc_491521502091_item	2584856	et	3	main
pesumasinas	doc_491521502091_item	2584865	et	3	main
pestav	doc_491521502091_item	2584878	et	4	main
käsitsi	doc_491521502091_item	2584879	et	3	main
paljudel	doc_491521502091_item	2584885	et	3	main
постоянные	doc_491521502091_item	2584898	et	2	main
товар	doc_491521502091_item	2584903	et	2	main
3	doc_491521502091_item	2584922	et	2	main
разработана	doc_491521502091_item	2584927	et	2	main
привлекает	doc_491521502091_item	2584930	et	2	main
kingitusega	doc_491521502091_item	2584936	et	4	main
moodustage	doc_491521502091_item	2584938	et	3	main
antonüümid	doc_491521502091_item	2584939	et	3	main
onnetu	doc_491521502091_item	2584942	et	4	main
haritud	doc_491521502091_item	2584944	et	4	main
4	doc_491521502091_item	2584949	et	2	main
lünkadesse	doc_491521502091_item	2584957	et	3	main
sõlmite	doc_491521502090_item	2584509	et	3	main
lepingut	doc_491521502090_item	2584511	et	3	main
olge	doc_491521502090_item	2584512	et	3	main
väga	doc_491521502090_item	2584513	et	3	main
tähelepanelik	doc_491521502090_item	2584514	et	4	main
väga	doc_491521502090_item	2584519	et	3	main
kesklinnaga	doc_491521502090_item	2584524	et	3	main
on	doc_491521502090_item	2584525	et	4	main
see	doc_491521502090_item	2584526	et	3	main
odav	doc_491521502090_item	2584528	et	3	main
võrreldes	doc_491521502090_item	2584530	et	3	main
lähete	doc_491521502090_item	2584537	et	4	main
kaasa	doc_491521502090_item	2584542	et	4	main
korterit	doc_491521502090_item	2584544	et	3	main
üle	doc_491521502090_item	2584545	et	3	main
vaatama	doc_491521502090_item	2584546	et	3	main
minnes	doc_491521502090_item	2584547	et	3	main
abi	doc_491521502090_item	2584564	et	4	main
viii	doc_491521502090_item	2584565	et	4	main
moodustage	doc_491521502090_item	2584566	et	3	main
ja	doc_491521502090_item	2584567	et	3	main
kokku	doc_491521502090_item	2584608	et	3	main
kirjandus	doc_491521502090_item	2584613	et	3	main
9	doc_491521502090_item	2584615	et	2	main
10	doc_491521502090_item	2584618	et	2	main
kujundaja	doc_491521502090_item	2584620	et	4	main
11	doc_491521502090_item	2584622	et	2	main
12	doc_491521502090_item	2584626	et	2	main
13	doc_491521502090_item	2584629	et	2	main
leppima	doc_491521502090_item	2584630	et	3	main
14	doc_491521502090_item	2584632	et	2	main
valima	doc_491521502090_item	2584633	et	3	main
valimine	doc_491521502090_item	2584635	et	4	main
kõneviisi	doc_491521502090_item	2584643	et	4	main
see	doc_491521502090_item	2584648	et	3	main
2	doc_491521502090_item	2584652	et	2	main
rahu	doc_491521502090_item	2584655	et	4	main
rääkige	doc_491521502090_item	2584659	et	3	main
kuulake	doc_491521502090_item	2584666	et	4	main
hoolikalt	doc_491521502090_item	2584667	et	4	main
8	doc_491521502090_item	2584687	et	2	main
vaatama	doc_491521502090_item	2584688	et	3	main
intervjueerijale	doc_491521502090_item	2584690	et	4	main
9	doc_491521502090_item	2584692	et	2	main
kõhelge	doc_491521502090_item	2584695	et	4	main
pintsaku	doc_491521502091_item	2584721	et	3	main
3	doc_491521502091_item	2584726	et	2	main
kardan	doc_491521502091_item	2584727	et	4	main
et	doc_491521502091_item	2584728	et	3	main
seda	doc_491521502091_item	2584729	et	3	main
kahjustatakse	doc_491521502091_item	2584739	et	3	main
sisekorraeeskirjad	doc_491521502091_item	2584742	et	3	main
siis	doc_491521502091_item	2584749	et	3	main
koormus	doc_491521502091_item	2584753	et	4	main
6	doc_491521502091_item	2584755	et	2	main
tagajärgi	doc_491521502091_item	2584763	et	4	main
on	doc_491521502091_item	2584767	et	4	main
eksitavad	doc_491521502091_item	2584770	et	4	main
hallitama	doc_491521502091_item	2584810	et	3	main
õmblusmasin	doc_491521502091_item	2584812	et	3	main
venima	doc_491521502091_item	2584814	et	3	main
minema	doc_491521502091_item	2584818	et	3	main
toidujäätmed	doc_491521502091_item	2584820	et	3	main
6	doc_491521502091_item	2584825	et	2	main
1	doc_491521502091_item	2584832	et	2	main
tav-kesksõnaga	doc_491521502091_item	2584838	et	3	main
kreeme	doc_491521502091_item	2584841	et	3	main
toodetakse	doc_491521502091_item	2584843	et	3	main
kasutatakse	doc_491521502091_item	2584845	et	3	main
neiult	doc_491521502091_item	2584853	et	4	main
müüb	doc_491521502091_item	2584855	et	3	main
lisa	doc_491521502091_item	2584858	et	4	main
vette	doc_491521502091_item	2584860	et	3	main
pesumasinas	doc_491521502091_item	2584863	et	3	main
lisati	doc_491521502091_item	2584864	et	3	main
pesu	doc_491521502091_item	2584868	et	4	main
pestakse	doc_491521502091_item	2584870	et	3	main
kulu	doc_491521502091_item	2584873	et	4	main
pesu	doc_491521502091_item	2584876	et	4	main
mida	doc_491521502091_item	2584877	et	4	main
5	doc_491521502091_item	2584884	et	2	main
sõlmides	doc_491521502090_item	2584515	et	4	main
võrrelda	doc_491521502090_item	2584523	et	4	main
korterit	doc_491521502090_item	2584538	et	3	main
ametnikega	doc_491521502090_item	2584554	et	3	main
kuus	doc_491521502090_item	2584598	et	4	main
kuueliikmeline	doc_491521502090_item	2584600	et	4	main
6	doc_491521502090_item	2584604	et	2	main
suur	doc_491521502090_item	2584605	et	3	main
tulema	doc_491521502090_item	2584609	et	4	main
üür	doc_491521502090_item	2584616	et	3	main
aiandus	doc_491521502090_item	2584624	et	3	main
meelepärane	doc_491521502090_item	2584628	et	4	main
leping	doc_491521502090_item	2584631	et	3	main
valik	doc_491521502090_item	2584634	et	3	main
15	doc_491521502090_item	2584636	et	2	main
seitse	doc_491521502090_item	2584637	et	3	main
päeva	doc_491521502090_item	2584638	et	4	main
1	doc_491521502090_item	2584644	et	2	main
valetama	doc_491521502090_item	2584645	et	3	main
ärge	doc_491521502090_item	2584646	et	3	main
valetage	doc_491521502090_item	2584647	et	3	main
ruttu	doc_491521502090_item	2584650	et	4	main
ärge	doc_491521502090_item	2584658	et	3	main
küsimusi	doc_491521502090_item	2584668	et	4	main
5	doc_491521502090_item	2584669	et	2	main
ärge	doc_491521502090_item	2584671	et	3	main
intervjuu	doc_491521502090_item	2584676	et	4	main
hilinema	doc_491521502090_item	2584684	et	3	main
silma	doc_491521502090_item	2584691	et	4	main
kõhklema	doc_491521502090_item	2584693	et	3	main
kui	doc_491521502090_item	2584536	et	3	main
vaatama	doc_491521502090_item	2584540	et	3	main
asjatundja	doc_491521502090_item	2584543	et	4	main
võtke	doc_491521502090_item	2584548	et	3	main
on	doc_491521502090_item	2584555	et	4	main
maaklerist	doc_491521502090_item	2584556	et	3	main
abi	doc_491521502090_item	2584558	et	4	main
maaklerist	doc_491521502090_item	2584562	et	3	main
ndus	doc_491521502090_item	2584569	et	4	main
line	doc_491521502090_item	2584573	et	4	main
ne	doc_491521502090_item	2584574	et	4	main
mine	doc_491521502090_item	2584575	et	3	main
või	doc_491521502090_item	2584576	et	4	main
kond-	doc_491521502090_item	2584577	et	4	main
liitelised	doc_491521502090_item	2584578	et	4	main
sõnad	doc_491521502090_item	2584579	et	4	main
ühel	doc_491521502090_item	2584580	et	3	main
sõnal	doc_491521502090_item	2584581	et	3	main
võib	doc_491521502090_item	2584582	et	3	main
olla	doc_491521502090_item	2584583	et	3	main
mitu	doc_491521502090_item	2584584	et	4	main
1	doc_491521502090_item	2584586	et	2	main
õhk	doc_491521502090_item	2584587	et	3	main
varianti	doc_491521502090_item	2584585	et	4	main
õhkkond	doc_491521502090_item	2584588	et	3	main
2	doc_491521502090_item	2584589	et	2	main
valima	doc_491521502090_item	2584590	et	3	main
valik	doc_491521502090_item	2584591	et	3	main
valimine	doc_491521502090_item	2584592	et	4	main
3	doc_491521502090_item	2584593	et	2	main
pool	doc_491521502090_item	2584594	et	4	main
meetrit	doc_491521502090_item	2584595	et	3	main
poolemetriline	doc_491521502090_item	2584596	et	4	main
4	doc_491521502090_item	2584597	et	2	main
liiget	doc_491521502090_item	2584599	et	3	main
5	doc_491521502090_item	2584601	et	2	main
tootma	doc_491521502090_item	2584602	et	3	main
toodang	doc_491521502090_item	2584603	et	3	main
kokkutulek	doc_491521502090_item	2584610	et	3	main
aed	doc_491521502090_item	2584623	et	3	main
ix	doc_491521502090_item	2584640	et	4	main
kasutage	doc_491521502090_item	2584641	et	3	main
säilitama	doc_491521502090_item	2584653	et	4	main
3	doc_491521502090_item	2584656	et	2	main
enda	doc_491521502090_item	2584660	et	4	main
kohta	doc_491521502090_item	2584661	et	4	main
negatiivseid	doc_491521502090_item	2584662	et	3	main
4	doc_491521502090_item	2584664	et	2	main
pahandama	doc_491521502090_item	2584674	et	3	main
küsima	doc_491521502090_item	2584678	et	3	main
7	doc_491521502090_item	2584683	et	2	main
võimetes	doc_491521502090_item	2584697	et	4	main
10	doc_491521502090_item	2584698	et	2	main
püüdma	doc_491521502090_item	2584699	et	3	main
püüdke	doc_491521502090_item	2584700	et	3	main
sarnaneda	doc_491521502090_item	2584701	et	3	main
selles	doc_491521502090_item	2584702	et	4	main
töökohas	doc_491521502090_item	2584703	et	4	main
levinud	doc_491521502090_item	2584704	et	4	main
stiiliga	doc_491521502090_item	2584705	et	3	main
kontrolltöö	doc_491521502091_item	2584706	et	4	main
i	doc_491521502091_item	2584707	et	4	main
valige	doc_491521502091_item	2584708	et	3	main
õige	doc_491521502091_item	2584709	et	4	main
sõna	doc_491521502091_item	2584710	et	4	main
1	doc_491521502091_item	2584711	et	2	main
suurt	doc_491521502091_item	2584712	et	3	main
koera	doc_491521502091_item	2584713	et	4	main
peab	doc_491521502091_item	2584714	et	4	main
kordamööda	doc_491521502091_item	2584715	et	3	main
ilmtingimata	doc_491521502091_item	2584716	et	3	main
omapead	doc_491521502091_item	2584717	et	3	main
õpetama	doc_491521502091_item	2584718	et	3	main
2	doc_491521502091_item	2584719	et	2	main
selle	doc_491521502091_item	2584720	et	4	main
õmblused	doc_491521502091_item	2584722	et	3	main
sisaldada	doc_491521502091_item	2584734	et	3	main
4	doc_491521502091_item	2584736	et	2	main
varsti	doc_491521502091_item	2584737	et	3	main
kehtestatakse	doc_491521502091_item	2584738	et	3	main
omandatakse	doc_491521502091_item	2584740	et	3	main
pidevalt	doc_491521502091_item	2584747	et	4	main
järeldusi	doc_491521502091_item	2584762	et	4	main
kasutusjuhendis	doc_491521502091_item	2584766	et	3	main
üleolevad	doc_491521502091_item	2584769	et	3	main
kehtivad	doc_491521502091_item	2584771	et	4	main
iii	doc_491521502091_item	2584802	et	4	main
1	doc_491521502091_item	2584808	et	2	main
juust	doc_491521502091_item	2584809	et	4	main
välja	doc_491521502091_item	2584813	et	4	main
3	doc_491521502091_item	2584815	et	2	main
õmblused	doc_491521502091_item	2584816	et	3	main
rikki	doc_491521502091_item	2584817	et	3	main
4	doc_491521502091_item	2584819	et	2	main
on	doc_491521502091_item	2584731	et	4	main
inimene	doc_491521502091_item	2584745	et	3	main
tema	doc_491521502091_item	2584750	et	4	main
enesehinnang	doc_491521502091_item	2584752	et	3	main
langeb	doc_491521502091_item	2584754	et	3	main
inimesed	doc_491521502091_item	2584756	et	3	main
kohad	doc_491521502091_item	2584772	et	4	main
ii	doc_491521502091_item	2584773	et	4	main
kirjutage	doc_491521502091_item	2584774	et	3	main
sünonüümid	doc_491521502091_item	2584775	et	3	main
1	doc_491521502091_item	2584776	et	2	main
hülgama	doc_491521502091_item	2584777	et	3	main
ära	doc_491521502091_item	2584778	et	4	main
viskama	doc_491521502091_item	2584779	et	3	main
2	doc_491521502091_item	2584780	et	2	main
taipama	doc_491521502091_item	2584781	et	3	main
arusaama	doc_491521502091_item	2584782	et	4	main
3	doc_491521502091_item	2584783	et	2	main
topib	doc_491521502091_item	2584784	et	3	main
nina	doc_491521502091_item	2584785	et	4	main
igale	doc_491521502091_item	2584786	et	3	main
poole	doc_491521502091_item	2584787	et	4	main
4	doc_491521502091_item	2584788	et	2	main
tuleb	doc_491521502091_item	2584789	et	3	main
õige	doc_491521502091_item	2584790	et	4	main
pea	doc_491521502091_item	2584791	et	4	main
ta	doc_491521502091_item	2584792	et	4	main
tuleb	doc_491521502091_item	2584793	et	3	main
varsti	doc_491521502091_item	2584794	et	3	main
5	doc_491521502091_item	2584795	et	2	main
lõi	doc_491521502091_item	2584796	et	4	main
kõigele	doc_491521502091_item	2584797	et	4	main
käega	doc_491521502091_item	2584798	et	3	main
karu	doc_491521502091_item	2584801	et	4	main
ühendage	doc_491521502091_item	2584803	et	3	main
tegusõna	doc_491521502091_item	2584804	et	4	main
ja	doc_491521502091_item	2584805	et	3	main
määrima	doc_491521502091_item	2584821	et	3	main
rebenema	doc_491521502091_item	2584824	et	3	main
näokreem	doc_491521502091_item	2584826	et	3	main
7	doc_491521502091_item	2584828	et	2	main
teksad	doc_491521502091_item	2584833	et	4	main
v-	doc_491521502091_item	2584836	et	4	main
1	doc_491521502091_item	2584840	et	2	main
eestis	doc_491521502091_item	2584848	et	3	main
pesupulbrit	doc_491521502091_item	2584859	et	3	main
ei	doc_491521502091_item	2584872	et	4	main
nii	doc_491521502091_item	2584874	et	3	main
kulutav	doc_491521502091_item	2584881	et	4	main
покупать	doc_491521502091_item	2584902	et	2	main
vaas	doc_491521502091_item	2584829	et	3	main
mida	doc_491521502091_item	2584842	et	4	main
eestis	doc_491521502091_item	2584844	et	3	main
palju	doc_491521502091_item	2584846	et	4	main
todetavad	doc_491521502091_item	2584847	et	4	main
2	doc_491521502091_item	2584850	et	2	main
küsi	doc_491521502091_item	2584851	et	4	main
on	doc_491521502091_item	2584862	et	4	main
pesupulbriti	doc_491521502091_item	2584866	et	4	main
käsitsi	doc_491521502091_item	2584871	et	3	main
kiiresti	doc_491521502091_item	2584875	et	3	main
kiiresti	doc_491521502091_item	2584883	et	3	main
keemiavahenditel	doc_491521502091_item	2584886	et	3	main
olla	doc_491521502091_item	2584888	et	3	main
mis	doc_491521502091_item	2584890	et	4	main
kahjustab	doc_491521502091_item	2584891	et	3	main
имеют	doc_491521502091_item	2584900	et	2	main
в	doc_491521502091_item	2584904	et	2	main
рассрочку	doc_491521502091_item	2584905	et	2	main
püsikliendil	doc_491521502091_item	2584906	et	3	main
on	doc_491521502091_item	2584907	et	4	main
õigus	doc_491521502091_item	2584908	et	4	main
osta	doc_491521502091_item	2584909	et	4	main
järelmaksuga	doc_491521502091_item	2584910	et	3	main
2	doc_491521502091_item	2584911	et	2	main
это	doc_491521502091_item	2584912	et	2	main
нарушает	doc_491521502091_item	2584913	et	2	main
принципы	doc_491521502091_item	2584914	et	2	main
торговли	doc_491521502091_item	2584915	et	2	main
рынка	doc_491521502091_item	2584917	et	2	main
see	doc_491521502091_item	2584918	et	3	main
свободного	doc_491521502091_item	2584916	et	2	main
tekkub	doc_491521502091_item	2584919	et	4	main
vabakaubanduse	doc_491521502091_item	2584920	et	3	main
система	doc_491521502091_item	2584923	et	2	main
не	doc_491521502091_item	2584926	et	2	main
клиентов	doc_491521502091_item	2584931	et	2	main
firma	doc_491521502091_item	2584933	et	4	main
kliendil	doc_491521502091_item	2584935	et	3	main
loetamatu	doc_491521502091_item	2584948	et	4	main
5	doc_491521502091_item	2584952	et	2	main
sidesõnad	doc_491521502091_item	2584959	et	3	main
aega	doc_491521502091_item	2584971	et	4	main
pean	doc_491521502091_item	2584973	et	4	main
kiiresti	doc_491521502091_item	2584974	et	3	main
minema	doc_491521502091_item	2584975	et	3	main
3	doc_491521502091_item	2584980	et	2	main
kasutage	doc_491521502091_item	2585021	et	3	main
tegumoe	doc_491521502091_item	2585023	et	3	main
lihtminevikku	doc_491521502091_item	2585024	et	4	main
1	doc_491521502091_item	2585027	et	2	main
meie	doc_491521502091_item	2585028	et	4	main
nõudma	doc_491521502091_item	2585029	et	3	main
allkiri	doc_491521502091_item	2585030	et	3	main
meilt	doc_491521502091_item	2585031	et	3	main
nõuti	doc_491521502091_item	2585032	et	3	main
allkirja	doc_491521502091_item	2585033	et	4	main
2	doc_491521502091_item	2585034	et	2	main
laistud	doc_491521502091_item	2585042	et	4	main
vait	doc_491521502091_item	2585052	et	3	main
läbi	doc_491521502091_item	2585058	et	4	main
läbi	doc_491521502091_item	2585064	et	4	main
lugeti	doc_491521502091_item	2585065	et	4	main
toime	doc_491521502091_item	2584889	et	4	main
tervist	doc_491521502091_item	2584892	et	4	main
v	doc_491521502091_item	2584893	et	4	main
tõlkige	doc_491521502091_item	2584894	et	3	main
право	doc_491521502091_item	2584901	et	2	main
põhimõttesse	doc_491521502091_item	2584921	et	4	main
мусора	doc_491521502091_item	2584925	et	2	main
4	doc_491521502091_item	2584928	et	2	main
vi	doc_491521502091_item	2584937	et	4	main
harimatu	doc_491521502091_item	2584945	et	4	main
loetav	doc_491521502091_item	2584947	et	4	main
andekas	doc_491521502091_item	2584950	et	4	main
oodatud	doc_491521502091_item	2584953	et	4	main
oodamatu	doc_491521502091_item	2584954	et	4	main
1	doc_491521502091_item	2584960	et	2	main
2	doc_491521502091_item	2584972	et	2	main
jään	doc_491521502091_item	2584978	et	3	main
endale	doc_491521502091_item	2584982	et	4	main
mida	doc_491521502091_item	2585025	et	4	main
tehti	doc_491521502091_item	2585026	et	3	main
midagi	doc_491521502091_item	2585038	et	4	main
ütlema	doc_491521502091_item	2585039	et	3	main
mul	doc_491521502091_item	2585050	et	3	main
alla	doc_491521502091_item	2585053	et	3	main
avaldus	doc_491521502091_item	2585056	et	4	main
avaldus	doc_491521502091_item	2585062	et	4	main
ostja	doc_491521502091_item	2585068	et	4	main
pakkuti	doc_491521502091_item	2585073	et	4	main
i	doc_491521502092_item	2585077	et	4	main
õige	doc_491521502092_item	2585079	et	4	main
sõna	doc_491521502092_item	2585080	et	4	main
selle	doc_491521502092_item	2585090	et	4	main
õmblused	doc_491521502092_item	2585092	et	3	main
3	doc_491521502092_item	2585096	et	2	main
inimene	doc_491521502092_item	2585115	et	3	main
koormus	doc_491521502092_item	2585123	et	4	main
tulemusi	doc_491521502092_item	2585134	et	4	main
7	doc_491521502092_item	2585135	et	2	main
kasutusjuhendis	doc_491521502092_item	2585136	et	3	main
üleolevad	doc_491521502092_item	2585139	et	3	main
1	doc_491521502092_item	2585146	et	2	main
on	doc_491521502092_item	2585159	et	4	main
uudishimulik	doc_491521502092_item	2585160	et	3	main
mesikäpp	doc_491521502092_item	2585172	et	3	main
8	doc_491521502092_item	2585189	et	2	main
mida	doc_491521502092_item	2585221	et	4	main
eestis	doc_491521502092_item	2585223	et	3	main
eestis	doc_491521502092_item	2585226	et	3	main
kreeme	doc_491521502092_item	2585228	et	3	main
kes	doc_491521502092_item	2585235	et	4	main
lisa	doc_491521502092_item	2585250	et	4	main
olevat	doc_491521502092_item	2585252	et	4	main
4	doc_491521502092_item	2585255	et	2	main
mida	doc_491521502092_item	2585257	et	4	main
ei	doc_491521502092_item	2585267	et	4	main
nii	doc_491521502092_item	2585269	et	3	main
5	doc_491521502092_item	2585271	et	2	main
keemiavahenditel	doc_491521502092_item	2585273	et	3	main
olla	doc_491521502092_item	2585275	et	3	main
mis	doc_491521502092_item	2585277	et	4	main
võib	doc_491521502092_item	2585282	et	3	main
kahjustav	doc_491521502092_item	2585285	et	4	main
toime	doc_491521502092_item	2585286	et	4	main
õigus	doc_491521502092_item	2585302	et	4	main
kaupa	doc_491521502092_item	2585304	et	4	main
это	doc_491521502092_item	2585307	et	2	main
торговли	doc_491521502092_item	2585310	et	2	main
не	doc_491521502092_item	2585323	et	2	main
ole	doc_491521502092_item	2585329	et	4	main
4	doc_491521502092_item	2585332	et	2	main
peibutab	doc_491521502092_item	2585338	et	3	main
meelitab	doc_491521502092_item	2585339	et	3	main
kliente	doc_491521502092_item	2585340	et	3	main
loetamatu	doc_491521502092_item	2585353	et	4	main
andekas	doc_491521502092_item	2585355	et	4	main
5	doc_491521502092_item	2585357	et	2	main
minema	doc_491521502092_item	2585380	et	3	main
hakkama	doc_491521502092_item	2585381	et	3	main
muidu	doc_491521502092_item	2585382	et	3	main
jään	doc_491521502092_item	2585383	et	3	main
hiljaks	doc_491521502092_item	2585384	et	3	main
3	doc_491521502092_item	2585385	et	2	main
переработки	doc_491521502091_item	2584924	et	2	main
подарками	doc_491521502091_item	2584932	et	2	main
meelitab	doc_491521502091_item	2584934	et	3	main
õnnelik	doc_491521502091_item	2584941	et	3	main
pange	doc_491521502091_item	2584956	et	4	main
eesti	doc_491521502091_item	2584963	et	4	main
õpinguid	doc_491521502091_item	2584965	et	3	main
juhul	doc_491521502091_item	2584967	et	3	main
kui	doc_491521502091_item	2584968	et	3	main
mul	doc_491521502091_item	2584969	et	3	main
on	doc_491521502091_item	2584970	et	4	main
kuigi	doc_491521502091_item	2584977	et	3	main
kleidi	doc_491521502091_item	2584985	et	3	main
muidu	doc_491521502091_item	2584986	et	3	main
pean	doc_491521502091_item	2584987	et	4	main
raha	doc_491521502091_item	2584988	et	4	main
kokku	doc_491521502091_item	2584989	et	3	main
hoidma	doc_491521502091_item	2584990	et	3	main
4	doc_491521502091_item	2584991	et	2	main
ta	doc_491521502091_item	2584992	et	4	main
teeb	doc_491521502091_item	2584993	et	3	main
terve	doc_491521502091_item	2584994	et	4	main
päeva	doc_491521502091_item	2584995	et	4	main
tööd	doc_491521502091_item	2584996	et	4	main
lisaks	doc_491521502091_item	2584997	et	4	main
sellele	doc_491521502091_item	2584998	et	4	main
käib	doc_491521502091_item	2584999	et	3	main
veel	doc_491521502091_item	2585000	et	4	main
trennis	doc_491521502091_item	2585001	et	3	main
5	doc_491521502091_item	2585002	et	2	main
tahan	doc_491521502091_item	2585003	et	3	main
kõrgkooli	doc_491521502091_item	2585004	et	4	main
sisse	doc_491521502091_item	2585005	et	4	main
saada	doc_491521502091_item	2585006	et	4	main
seega	doc_491521502091_item	2585007	et	4	main
tuleb	doc_491521502091_item	2585008	et	3	main
mul	doc_491521502091_item	2585009	et	3	main
palju	doc_491521502091_item	2585010	et	4	main
õppida	doc_491521502091_item	2585011	et	3	main
sõnad	doc_491521502091_item	2585012	et	4	main
muidu	doc_491521502091_item	2585013	et	3	main
seega	doc_491521502091_item	2585014	et	4	main
juhul	doc_491521502091_item	2585015	et	3	main
kui	doc_491521502091_item	2585016	et	3	main
kuigi	doc_491521502091_item	2585017	et	3	main
lisaks	doc_491521502091_item	2585018	et	4	main
õiged	doc_491521502091_item	2584958	et	3	main
jätkata	doc_491521502091_item	2584966	et	4	main
hakkama	doc_491521502091_item	2584976	et	3	main
sellele	doc_491521502091_item	2585019	et	4	main
viii	doc_491521502091_item	2585020	et	4	main
hiljaks	doc_491521502091_item	2584979	et	3	main
tahan	doc_491521502091_item	2584981	et	3	main
osta	doc_491521502091_item	2584983	et	4	main
uue	doc_491521502091_item	2584984	et	3	main
müüjal	doc_491521502091_item	2585040	et	4	main
öelda	doc_491521502091_item	2585044	et	4	main
mina	doc_491521502091_item	2585046	et	4	main
käskima	doc_491521502091_item	2585047	et	4	main
vait	doc_491521502091_item	2585048	et	3	main
ei	doc_491521502091_item	2585057	et	4	main
lugema	doc_491521502091_item	2585059	et	4	main
korralikult	doc_491521502091_item	2585060	et	4	main
minu	doc_491521502091_item	2585061	et	3	main
korralikult	doc_491521502091_item	2585066	et	4	main
5	doc_491521502091_item	2585067	et	2	main
peab	doc_491521502092_item	2585084	et	4	main
kordamööda	doc_491521502092_item	2585085	et	3	main
ilmtingimata	doc_491521502092_item	2585086	et	3	main
omapead	doc_491521502092_item	2585087	et	3	main
2	doc_491521502092_item	2585089	et	2	main
käsitsevad	doc_491521502092_item	2585093	et	4	main
kardan	doc_491521502092_item	2585097	et	4	main
langeb	doc_491521502092_item	2585124	et	3	main
peaksid	doc_491521502092_item	2585127	et	4	main
ii	doc_491521502092_item	2585143	et	4	main
2	doc_491521502092_item	2585150	et	2	main
poole	doc_491521502092_item	2585158	et	4	main
4	doc_491521502092_item	2585161	et	2	main
välja	doc_491521502092_item	2585187	et	4	main
venima	doc_491521502092_item	2585188	et	3	main
3	doc_491521502092_item	2585190	et	2	main
neiult	doc_491521502092_item	2585234	et	4	main
küsi	doc_491521502092_item	2585238	et	4	main
vitamiine	doc_491521502092_item	2585240	et	3	main
neiult	doc_491521502092_item	2585242	et	4	main
paljudel	doc_491521502092_item	2585280	et	3	main
olla	doc_491521502092_item	2585283	et	3	main
v	doc_491521502092_item	2585287	et	4	main
tõlkige	doc_491521502092_item	2585288	et	3	main
1	doc_491521502092_item	2585291	et	2	main
клиенты	doc_491521502092_item	2585293	et	2	main
право	doc_491521502092_item	2585295	et	2	main
товар	doc_491521502092_item	2585297	et	2	main
on	doc_491521502092_item	2585301	et	4	main
2	doc_491521502092_item	2585306	et	2	main
prügi	doc_491521502092_item	2585325	et	4	main
süsteem	doc_491521502092_item	2585327	et	3	main
välja	doc_491521502092_item	2585330	et	4	main
привлекает	doc_491521502092_item	2585334	et	2	main
подарками	doc_491521502092_item	2585336	et	2	main
haritud	doc_491521502092_item	2585349	et	4	main
haritu	doc_491521502092_item	2585350	et	4	main
4	doc_491521502092_item	2585354	et	2	main
oodatud	doc_491521502092_item	2585358	et	4	main
ootamatu	doc_491521502092_item	2585359	et	4	main
tahan	doc_491521502092_item	2585386	et	3	main
kuigi	doc_491521502092_item	2585391	et	3	main
hoidma	doc_491521502092_item	2585395	et	3	main
lisaks	doc_491521502092_item	2585402	et	4	main
kõrgkooli	doc_491521502092_item	2585409	et	4	main
seega	doc_491521502092_item	2585412	et	4	main
lihtminevikku	doc_491521502092_item	2585429	et	4	main
meie	doc_491521502092_item	2585433	et	4	main
ei	doc_491521502092_item	2585446	et	4	main
mina	doc_491521502092_item	2585451	et	4	main
loetud	doc_491521502092_item	2585469	et	4	main
5	doc_491521502092_item	2585472	et	2	main
pakkuma	doc_491521502092_item	2585474	et	3	main
kaks	doc_491521502092_item	2585475	et	3	main
suurt	doc_491521502093_item	2585487	et	3	main
2	doc_491521502093_item	2585494	et	2	main
selle	doc_491521502093_item	2585495	et	4	main
õmblused	doc_491521502093_item	2585497	et	3	main
kisuvad	doc_491521502093_item	2585499	et	3	main
3	doc_491521502093_item	2585501	et	2	main
kardan	doc_491521502093_item	2585502	et	4	main
et	doc_491521502093_item	2585503	et	3	main
on	doc_491521502093_item	2585506	et	4	main
liigitada	doc_491521502093_item	2585508	et	3	main
kogeb	doc_491521502093_item	2585521	et	3	main
müüja	doc_491521502091_item	2585035	et	4	main
ei	doc_491521502091_item	2585036	et	4	main
laskma	doc_491521502091_item	2585037	et	3	main
3	doc_491521502091_item	2585045	et	2	main
varsti	doc_491521502091_item	2585051	et	3	main
minu	doc_491521502091_item	2585055	et	3	main
kaks	doc_491521502091_item	2585074	et	3	main
valige	doc_491521502092_item	2585078	et	3	main
1	doc_491521502092_item	2585081	et	2	main
suurt	doc_491521502092_item	2585082	et	3	main
koera	doc_491521502092_item	2585083	et	4	main
et	doc_491521502092_item	2585098	et	3	main
seda	doc_491521502092_item	2585099	et	3	main
plaani	doc_491521502092_item	2585100	et	4	main
raske	doc_491521502092_item	2585102	et	4	main
liigitada	doc_491521502092_item	2585103	et	3	main
on	doc_491521502092_item	2585101	et	4	main
sisaldada	doc_491521502092_item	2585104	et	3	main
teostada	doc_491521502092_item	2585105	et	3	main
4	doc_491521502092_item	2585106	et	2	main
varsti	doc_491521502092_item	2585107	et	3	main
kehtestatakse	doc_491521502092_item	2585108	et	3	main
kahjustatakse	doc_491521502092_item	2585109	et	3	main
omandatakse	doc_491521502092_item	2585110	et	3	main
uued	doc_491521502092_item	2585111	et	3	main
sisekorraeeskirjad	doc_491521502092_item	2585112	et	3	main
5	doc_491521502092_item	2585113	et	2	main
kui	doc_491521502092_item	2585114	et	3	main
kogeb	doc_491521502092_item	2585116	et	3	main
pidevalt	doc_491521502092_item	2585117	et	4	main
ebaõnnestumisi	doc_491521502092_item	2585118	et	3	main
siis	doc_491521502092_item	2585119	et	3	main
tema	doc_491521502092_item	2585120	et	4	main
teadvustama	doc_491521502092_item	2585129	et	3	main
keskkonna	doc_491521502092_item	2585130	et	3	main
reostamise	doc_491521502092_item	2585131	et	4	main
kehtivad	doc_491521502092_item	2585141	et	4	main
kirjutage	doc_491521502092_item	2585144	et	3	main
hülgama	doc_491521502092_item	2585147	et	3	main
jätma	doc_491521502092_item	2585149	et	3	main
taipama	doc_491521502092_item	2585151	et	3	main
kõigele	doc_491521502092_item	2585169	et	4	main
käega	doc_491521502092_item	2585170	et	3	main
6	doc_491521502092_item	2585171	et	2	main
karu	doc_491521502092_item	2585173	et	4	main
iii	doc_491521502092_item	2585174	et	4	main
ühendage	doc_491521502092_item	2585175	et	3	main
toodetakse	doc_491521502092_item	2585222	et	3	main
toodetavaid	doc_491521502092_item	2585227	et	4	main
palju	doc_491521502092_item	2585230	et	4	main
2	doc_491521502092_item	2585231	et	2	main
müüb	doc_491521502092_item	2585236	et	3	main
seda	doc_491521502092_item	2585239	et	3	main
ei	doc_491521502092_item	2585260	et	4	main
pesu	doc_491521502092_item	2585266	et	4	main
keemiavahenditel	doc_491521502092_item	2585281	et	3	main
osta	doc_491521502092_item	2585303	et	4	main
järelmaksuga	doc_491521502092_item	2585305	et	3	main
нарушает	doc_491521502092_item	2585308	et	2	main
umbisikulise	doc_491521502091_item	2585022	et	4	main
ei	doc_491521502091_item	2585041	et	4	main
midagi	doc_491521502091_item	2585043	et	4	main
olema	doc_491521502091_item	2585049	et	4	main
4	doc_491521502091_item	2585054	et	2	main
ei	doc_491521502091_item	2585063	et	4	main
pakkuma	doc_491521502091_item	2585069	et	3	main
kaks	doc_491521502091_item	2585070	et	3	main
võimalus	doc_491521502091_item	2585071	et	3	main
ostjal	doc_491521502091_item	2585072	et	4	main
kontrolltöö	doc_491521502092_item	2585076	et	4	main
kisuvad	doc_491521502092_item	2585094	et	3	main
võimalust	doc_491521502091_item	2585075	et	3	main
õpetama	doc_491521502092_item	2585088	et	3	main
pintsaku	doc_491521502092_item	2585091	et	3	main
luituvad	doc_491521502092_item	2585095	et	4	main
isiksus	doc_491521502092_item	2585121	et	3	main
inimesed	doc_491521502092_item	2585126	et	3	main
on	doc_491521502092_item	2585137	et	4	main
mõned	doc_491521502092_item	2585138	et	3	main
sünonüümid	doc_491521502092_item	2585145	et	3	main
maha	doc_491521502092_item	2585148	et	4	main
aru	doc_491521502092_item	2585152	et	4	main
3	doc_491521502092_item	2585154	et	2	main
topib	doc_491521502092_item	2585155	et	3	main
tuleb	doc_491521502092_item	2585162	et	3	main
õige	doc_491521502092_item	2585163	et	4	main
pea	doc_491521502092_item	2585164	et	4	main
varsti	doc_491521502092_item	2585165	et	3	main
tuleb	doc_491521502092_item	2585166	et	3	main
tegusõna	doc_491521502092_item	2585176	et	4	main
ja	doc_491521502092_item	2585177	et	3	main
ese	doc_491521502092_item	2585178	et	3	main
purunema	doc_491521502092_item	2585179	et	3	main
1	doc_491521502092_item	2585181	et	2	main
juust	doc_491521502092_item	2585182	et	4	main
hallitama	doc_491521502092_item	2585183	et	3	main
1	doc_491521502092_item	2585184	et	2	main
2	doc_491521502092_item	2585185	et	2	main
õmblusmasin	doc_491521502092_item	2585186	et	3	main
kasutatakse	doc_491521502092_item	2585224	et	3	main
on	doc_491521502092_item	2585248	et	4	main
pesumasinas	doc_491521502092_item	2585249	et	3	main
pestav	doc_491521502092_item	2585265	et	4	main
kiiresti	doc_491521502092_item	2585270	et	3	main
paljudel	doc_491521502092_item	2585272	et	3	main
toime	doc_491521502092_item	2585276	et	4	main
kahjustab	doc_491521502092_item	2585278	et	3	main
eesti	doc_491521502092_item	2585289	et	4	main
рассрочку	doc_491521502092_item	2585299	et	2	main
püsiklientidel	doc_491521502092_item	2585300	et	3	main
enesehinnang	doc_491521502092_item	2585122	et	3	main
6	doc_491521502092_item	2585125	et	2	main
endale	doc_491521502092_item	2585128	et	4	main
järeldusi	doc_491521502092_item	2585132	et	4	main
tagajärgi	doc_491521502092_item	2585133	et	4	main
eksitavad	doc_491521502092_item	2585140	et	4	main
kohad	doc_491521502092_item	2585142	et	4	main
saama	doc_491521502092_item	2585153	et	4	main
nina	doc_491521502092_item	2585156	et	4	main
igale	doc_491521502092_item	2585157	et	3	main
5	doc_491521502092_item	2585167	et	2	main
lõi	doc_491521502092_item	2585168	et	4	main
7	doc_491521502092_item	2585180	et	2	main
õmblused	doc_491521502092_item	2585191	et	3	main
rikki	doc_491521502092_item	2585192	et	3	main
2	doc_491521502092_item	2585194	et	2	main
minema	doc_491521502092_item	2585193	et	3	main
4	doc_491521502092_item	2585195	et	2	main
toidujäätmed	doc_491521502092_item	2585196	et	3	main
määrima	doc_491521502092_item	2585197	et	3	main
6	doc_491521502092_item	2585198	et	2	main
5	doc_491521502092_item	2585199	et	2	main
kreemituub	doc_491521502092_item	2585200	et	4	main
rebenema	doc_491521502092_item	2585201	et	3	main
3	doc_491521502092_item	2585202	et	2	main
6	doc_491521502092_item	2585203	et	2	main
näokreem	doc_491521502092_item	2585204	et	3	main
haisema	doc_491521502092_item	2585205	et	4	main
4	doc_491521502092_item	2585206	et	2	main
7	doc_491521502092_item	2585207	et	2	main
vaas	doc_491521502092_item	2585208	et	3	main
pigistama	doc_491521502092_item	2585209	et	3	main
5	doc_491521502092_item	2585210	et	2	main
8	doc_491521502092_item	2585211	et	2	main
teksad	doc_491521502092_item	2585212	et	4	main
iv	doc_491521502092_item	2585213	et	4	main
moodustage	doc_491521502092_item	2585214	et	3	main
v-	doc_491521502092_item	2585215	et	4	main
ja	doc_491521502092_item	2585216	et	3	main
tav-kesksõnaga	doc_491521502092_item	2585217	et	3	main
laused	doc_491521502092_item	2585218	et	3	main
1	doc_491521502092_item	2585219	et	2	main
kreeme	doc_491521502092_item	2585220	et	3	main
palju	doc_491521502092_item	2585225	et	4	main
kasutatakse	doc_491521502092_item	2585229	et	3	main
küsi	doc_491521502092_item	2585232	et	4	main
seda	doc_491521502092_item	2585233	et	3	main
vitamiine	doc_491521502092_item	2585237	et	3	main
müüvalt	doc_491521502092_item	2585241	et	4	main
3	doc_491521502092_item	2585243	et	2	main
lisa	doc_491521502092_item	2585244	et	4	main
pesupulbrit	doc_491521502092_item	2585245	et	3	main
vette	doc_491521502092_item	2585246	et	3	main
mis	doc_491521502092_item	2585247	et	4	main
pesumasinas	doc_491521502092_item	2585251	et	3	main
pesupulbrit	doc_491521502092_item	2585253	et	3	main
vette	doc_491521502092_item	2585254	et	3	main
pesu	doc_491521502092_item	2585256	et	4	main
pestakse	doc_491521502092_item	2585258	et	3	main
käsitsi	doc_491521502092_item	2585259	et	3	main
kulu	doc_491521502092_item	2585261	et	4	main
nii	doc_491521502092_item	2585262	et	3	main
kiiresti	doc_491521502092_item	2585263	et	3	main
käsitsi	doc_491521502092_item	2585264	et	3	main
kulu	doc_491521502092_item	2585268	et	4	main
võib	doc_491521502092_item	2585274	et	3	main
tervist	doc_491521502092_item	2585279	et	4	main
tervist	doc_491521502092_item	2585284	et	4	main
keelde	doc_491521502092_item	2585290	et	4	main
постоянные	doc_491521502092_item	2585292	et	2	main
имеют	doc_491521502092_item	2585294	et	2	main
покупать	doc_491521502092_item	2585296	et	2	main
в	doc_491521502092_item	2585298	et	2	main
свободного	doc_491521502092_item	2585311	et	2	main
рынка	doc_491521502092_item	2585312	et	2	main
rikub	doc_491521502092_item	2585314	et	3	main
see	doc_491521502092_item	2585313	et	3	main
vaba	doc_491521502092_item	2585315	et	4	main
turu	doc_491521502092_item	2585316	et	3	main
kaubanduse	doc_491521502092_item	2585317	et	3	main
printsiipe	doc_491521502092_item	2585318	et	3	main
3	doc_491521502092_item	2585319	et	2	main
система	doc_491521502092_item	2585320	et	2	main
мусора	doc_491521502092_item	2585322	et	2	main
ümbertöötmise	doc_491521502092_item	2585326	et	4	main
töödeldud	doc_491521502092_item	2585331	et	4	main
фирма	doc_491521502092_item	2585333	et	2	main
клиентов	doc_491521502092_item	2585335	et	2	main
kingitustega	doc_491521502092_item	2585341	et	4	main
vi	doc_491521502092_item	2585342	et	4	main
moodustage	doc_491521502092_item	2585343	et	3	main
1	doc_491521502092_item	2585345	et	2	main
õnnelik	doc_491521502092_item	2585346	et	3	main
õnnetu	doc_491521502092_item	2585347	et	4	main
2	doc_491521502092_item	2585348	et	2	main
andetu	doc_491521502092_item	2585356	et	4	main
endale	doc_491521502092_item	2585387	et	4	main
raha	doc_491521502092_item	2585393	et	4	main
kokku	doc_491521502092_item	2585394	et	3	main
4	doc_491521502092_item	2585396	et	2	main
ta	doc_491521502092_item	2585397	et	4	main
teeb	doc_491521502092_item	2585398	et	3	main
sellele	doc_491521502092_item	2585403	et	4	main
käib	doc_491521502092_item	2585404	et	3	main
принципы	doc_491521502092_item	2585309	et	2	main
переработки	doc_491521502092_item	2585321	et	2	main
antonüümid	doc_491521502092_item	2585344	et	3	main
loetav	doc_491521502092_item	2585352	et	4	main
uue	doc_491521502092_item	2585389	et	3	main
päeva	doc_491521502092_item	2585400	et	4	main
tööd	doc_491521502092_item	2585401	et	4	main
sisse	doc_491521502092_item	2585410	et	4	main
seega	doc_491521502092_item	2585419	et	4	main
juhul	doc_491521502092_item	2585420	et	3	main
kui	doc_491521502092_item	2585421	et	3	main
sellele	doc_491521502092_item	2585424	et	4	main
kasutage	doc_491521502092_item	2585426	et	3	main
umbisikulise	doc_491521502092_item	2585427	et	4	main
tegumoe	doc_491521502092_item	2585428	et	3	main
1	doc_491521502092_item	2585432	et	2	main
müüjal	doc_491521502092_item	2585445	et	4	main
avaldus	doc_491521502092_item	2585461	et	4	main
mu	doc_491521502092_item	2585466	et	3	main
võimalus	doc_491521502092_item	2585476	et	3	main
1	doc_491521502093_item	2585486	et	2	main
ilmtingimata	doc_491521502093_item	2585491	et	3	main
seda	doc_491521502093_item	2585504	et	3	main
raske	doc_491521502093_item	2585507	et	4	main
ebaõnnestumisi	doc_491521502093_item	2585523	et	3	main
koormus	doc_491521502093_item	2585528	et	4	main
endale	doc_491521502093_item	2585533	et	4	main
keskkonna	doc_491521502093_item	2585535	et	3	main
7	doc_491521502093_item	2585540	et	2	main
on	doc_491521502093_item	2585563	et	4	main
uudishimulik	doc_491521502093_item	2585565	et	3	main
õige	doc_491521502093_item	2585568	et	4	main
iii	doc_491521502093_item	2585579	et	4	main
ühendage	doc_491521502093_item	2585580	et	3	main
purunema	doc_491521502093_item	2585584	et	3	main
juust	doc_491521502093_item	2585587	et	4	main
8	doc_491521502093_item	2585594	et	2	main
2	doc_491521502093_item	2585599	et	2	main
6	doc_491521502093_item	2585603	et	2	main
laused	doc_491521502093_item	2585623	et	3	main
mida	doc_491521502093_item	2585626	et	4	main
eestis	doc_491521502093_item	2585628	et	3	main
kasutatakse	doc_491521502093_item	2585629	et	3	main
palju	doc_491521502093_item	2585630	et	4	main
kreeme	doc_491521502093_item	2585633	et	3	main
kasutatakse	doc_491521502093_item	2585634	et	3	main
seda	doc_491521502093_item	2585638	et	3	main
seda	doc_491521502093_item	2585644	et	3	main
müüvalt	doc_491521502093_item	2585646	et	4	main
neiult	doc_491521502093_item	2585647	et	4	main
lisa	doc_491521502093_item	2585655	et	4	main
vette	doc_491521502093_item	2585659	et	3	main
mida	doc_491521502093_item	2585662	et	4	main
nii	doc_491521502093_item	2585674	et	3	main
paljudel	doc_491521502093_item	2585677	et	3	main
v	doc_491521502093_item	2585692	et	4	main
keelde	doc_491521502093_item	2585695	et	4	main
клиенты	doc_491521502093_item	2585698	et	2	main
покупать	doc_491521502093_item	2585701	et	2	main
рассрочку	doc_491521502093_item	2585704	et	2	main
õigus	doc_491521502093_item	2585707	et	4	main
järelmaksuga	doc_491521502093_item	2585710	et	3	main
торговли	doc_491521502093_item	2585715	et	2	main
sekkub	doc_491521502093_item	2585719	et	3	main
не	doc_491521502093_item	2585728	et	2	main
фирма	doc_491521502093_item	2585731	et	2	main
peibutab	doc_491521502093_item	2585736	et	3	main
antonüümid	doc_491521502093_item	2585741	et	3	main
2	doc_491521502093_item	2585745	et	2	main
harimatu	doc_491521502093_item	2585747	et	4	main
loetav	doc_491521502093_item	2585749	et	4	main
ootamatu	doc_491521502093_item	2585756	et	4	main
ma	doc_491521502093_item	2585763	et	3	main
eesti	doc_491521502093_item	2585765	et	4	main
õpinguid	doc_491521502093_item	2585767	et	3	main
jätkata	doc_491521502093_item	2585768	et	4	main
juhul	doc_491521502093_item	2585769	et	3	main
kui	doc_491521502093_item	2585770	et	3	main
mul	doc_491521502093_item	2585771	et	3	main
hiljaks	doc_491521502093_item	2585781	et	3	main
osta	doc_491521502093_item	2585785	et	4	main
разработана	doc_491521502092_item	2585324	et	2	main
ei	doc_491521502092_item	2585328	et	4	main
firma	doc_491521502092_item	2585337	et	4	main
3	doc_491521502092_item	2585351	et	2	main
vii	doc_491521502092_item	2585360	et	4	main
pange	doc_491521502092_item	2585361	et	4	main
lünkadesse	doc_491521502092_item	2585362	et	3	main
õiged	doc_491521502092_item	2585363	et	3	main
sidesõnad	doc_491521502092_item	2585364	et	3	main
1	doc_491521502092_item	2585365	et	2	main
ma	doc_491521502092_item	2585366	et	3	main
kavatsen	doc_491521502092_item	2585367	et	3	main
eesti	doc_491521502092_item	2585368	et	4	main
keele	doc_491521502092_item	2585369	et	4	main
õpinguid	doc_491521502092_item	2585370	et	3	main
jätkata	doc_491521502092_item	2585371	et	4	main
juhul	doc_491521502092_item	2585372	et	3	main
kui	doc_491521502092_item	2585373	et	3	main
mul	doc_491521502092_item	2585374	et	3	main
on	doc_491521502092_item	2585375	et	4	main
aega	doc_491521502092_item	2585376	et	4	main
2	doc_491521502092_item	2585377	et	2	main
pean	doc_491521502092_item	2585378	et	4	main
kiiresti	doc_491521502092_item	2585379	et	3	main
osta	doc_491521502092_item	2585388	et	4	main
tahan	doc_491521502092_item	2585408	et	3	main
mul	doc_491521502092_item	2585414	et	3	main
palju	doc_491521502092_item	2585415	et	4	main
õppida	doc_491521502092_item	2585416	et	3	main
sõnad	doc_491521502092_item	2585417	et	4	main
muidu	doc_491521502092_item	2585418	et	3	main
kuigi	doc_491521502092_item	2585422	et	3	main
viii	doc_491521502092_item	2585425	et	4	main
tehti	doc_491521502092_item	2585431	et	3	main
nõuti	doc_491521502092_item	2585437	et	3	main
müüja	doc_491521502092_item	2585440	et	4	main
ei	doc_491521502092_item	2585441	et	4	main
laskma	doc_491521502092_item	2585442	et	3	main
midagi	doc_491521502092_item	2585443	et	4	main
ütlema	doc_491521502092_item	2585444	et	3	main
öelda	doc_491521502092_item	2585449	et	4	main
3	doc_491521502092_item	2585450	et	2	main
vait	doc_491521502092_item	2585457	et	3	main
4	doc_491521502092_item	2585459	et	2	main
minu	doc_491521502092_item	2585460	et	3	main
ei	doc_491521502092_item	2585462	et	4	main
läbi	doc_491521502092_item	2585463	et	4	main
avaldust	doc_491521502092_item	2585467	et	4	main
õpetama	doc_491521502093_item	2585493	et	3	main
pintsaku	doc_491521502093_item	2585496	et	3	main
käsitsevad	doc_491521502093_item	2585498	et	4	main
luituvad	doc_491521502093_item	2585500	et	4	main
sisaldada	doc_491521502093_item	2585509	et	3	main
4	doc_491521502093_item	2585511	et	2	main
isiksus	doc_491521502093_item	2585526	et	3	main
6	doc_491521502093_item	2585530	et	2	main
peaksid	doc_491521502093_item	2585532	et	4	main
teadvustama	doc_491521502093_item	2585534	et	3	main
tulemusi	doc_491521502093_item	2585539	et	4	main
on	doc_491521502093_item	2585542	et	4	main
eksitavad	doc_491521502093_item	2585545	et	4	main
ii	doc_491521502093_item	2585548	et	4	main
kirjutage	doc_491521502093_item	2585549	et	3	main
sünonüümid	doc_491521502093_item	2585550	et	3	main
1	doc_491521502093_item	2585551	et	2	main
hülgama	doc_491521502093_item	2585552	et	3	main
viskama	doc_491521502093_item	2585553	et	3	main
2	doc_491521502093_item	2585554	et	2	main
taipama	doc_491521502093_item	2585555	et	3	main
väga	doc_491521502093_item	2585564	et	3	main
4	doc_491521502093_item	2585566	et	2	main
ja	doc_491521502093_item	2585582	et	3	main
7	doc_491521502093_item	2585585	et	2	main
1	doc_491521502093_item	2585589	et	2	main
tav-kesksõnaga	doc_491521502093_item	2585622	et	3	main
eestis	doc_491521502093_item	2585631	et	3	main
toodetavat	doc_491521502093_item	2585632	et	4	main
küsi	doc_491521502093_item	2585637	et	4	main
kes	doc_491521502093_item	2585640	et	4	main
vitamiine	doc_491521502093_item	2585642	et	3	main
küsi	doc_491521502093_item	2585643	et	4	main
pesumasinas	doc_491521502093_item	2585654	et	3	main
oletavasse	doc_491521502093_item	2585658	et	4	main
pesu	doc_491521502093_item	2585661	et	4	main
käsitsi	doc_491521502093_item	2585664	et	3	main
ei	doc_491521502093_item	2585672	et	4	main
olla	doc_491521502093_item	2585680	et	3	main
mis	doc_491521502093_item	2585682	et	4	main
kahjustab	doc_491521502093_item	2585683	et	3	main
tervist	doc_491521502093_item	2585684	et	4	main
on	doc_491521502093_item	2585706	et	4	main
2	doc_491521502093_item	2585711	et	2	main
принципы	doc_491521502093_item	2585714	et	2	main
põhimõttetesse	doc_491521502093_item	2585723	et	4	main
система	doc_491521502093_item	2585725	et	2	main
разработана	doc_491521502093_item	2585729	et	2	main
подарками	doc_491521502093_item	2585734	et	2	main
kliente	doc_491521502093_item	2585737	et	3	main
4	doc_491521502093_item	2585751	et	2	main
andekas	doc_491521502093_item	2585752	et	4	main
pange	doc_491521502093_item	2585758	et	4	main
lünkadesse	doc_491521502093_item	2585759	et	3	main
1	doc_491521502093_item	2585762	et	2	main
aega	doc_491521502093_item	2585773	et	4	main
tahan	doc_491521502093_item	2585783	et	3	main
kleidi	doc_491521502092_item	2585390	et	3	main
pean	doc_491521502092_item	2585392	et	4	main
terve	doc_491521502092_item	2585399	et	4	main
veel	doc_491521502092_item	2585405	et	4	main
trennis	doc_491521502092_item	2585406	et	3	main
5	doc_491521502092_item	2585407	et	2	main
saada	doc_491521502092_item	2585411	et	4	main
tuleb	doc_491521502092_item	2585413	et	3	main
mida	doc_491521502092_item	2585430	et	4	main
allkiri	doc_491521502092_item	2585435	et	3	main
2	doc_491521502092_item	2585439	et	2	main
korralikult	doc_491521502092_item	2585465	et	4	main
ei	doc_491521502092_item	2585468	et	4	main
korralikult	doc_491521502092_item	2585471	et	4	main
ostja	doc_491521502092_item	2585473	et	4	main
ostjale	doc_491521502092_item	2585477	et	4	main
pakuti	doc_491521502092_item	2585478	et	3	main
kaks	doc_491521502092_item	2585479	et	3	main
võimalust	doc_491521502092_item	2585480	et	3	main
kontrolltöö	doc_491521502093_item	2585481	et	4	main
sõna	doc_491521502093_item	2585485	et	4	main
peab	doc_491521502093_item	2585489	et	4	main
omapead	doc_491521502093_item	2585492	et	3	main
plaani	doc_491521502093_item	2585505	et	4	main
enesehinnang	doc_491521502093_item	2585527	et	3	main
langeb	doc_491521502093_item	2585529	et	3	main
üleolevad	doc_491521502093_item	2585544	et	3	main
kehtivad	doc_491521502093_item	2585546	et	4	main
kohad	doc_491521502093_item	2585547	et	4	main
3	doc_491521502093_item	2585558	et	2	main
topib	doc_491521502093_item	2585559	et	3	main
nina	doc_491521502093_item	2585560	et	4	main
igale	doc_491521502093_item	2585561	et	3	main
poole	doc_491521502093_item	2585562	et	4	main
varsti	doc_491521502093_item	2585571	et	3	main
lõi	doc_491521502093_item	2585573	et	4	main
kõigele	doc_491521502093_item	2585574	et	4	main
käega	doc_491521502093_item	2585575	et	3	main
6	doc_491521502093_item	2585576	et	2	main
mesikäpp	doc_491521502093_item	2585577	et	3	main
tegusõna	doc_491521502093_item	2585581	et	4	main
ese	doc_491521502093_item	2585583	et	3	main
1	doc_491521502093_item	2585624	et	2	main
toodetakse	doc_491521502093_item	2585627	et	3	main
neiult	doc_491521502093_item	2585639	et	4	main
vitamiine	doc_491521502093_item	2585645	et	3	main
4	doc_491521502093_item	2585660	et	2	main
pestakse	doc_491521502093_item	2585663	et	3	main
ei	doc_491521502093_item	2585665	et	4	main
kulu	doc_491521502093_item	2585666	et	4	main
nii	doc_491521502093_item	2585667	et	3	main
kiiresti	doc_491521502093_item	2585668	et	3	main
käsitsi	doc_491521502093_item	2585669	et	3	main
kiiresti	doc_491521502093_item	2585675	et	3	main
keemiavahenditel	doc_491521502093_item	2585678	et	3	main
toime	doc_491521502093_item	2585681	et	4	main
toime	doc_491521502093_item	2585691	et	4	main
это	doc_491521502093_item	2585712	et	2	main
свободного	doc_491521502093_item	2585716	et	2	main
müümise	doc_491521502093_item	2585722	et	4	main
3	doc_491521502093_item	2585724	et	2	main
4	doc_491521502093_item	2585730	et	2	main
клиентов	doc_491521502093_item	2585733	et	2	main
firma	doc_491521502093_item	2585735	et	4	main
kingitustega	doc_491521502093_item	2585738	et	4	main
vi	doc_491521502093_item	2585739	et	4	main
õnnelik	doc_491521502093_item	2585743	et	3	main
loetamatu	doc_491521502093_item	2585750	et	4	main
vii	doc_491521502093_item	2585757	et	4	main
kavatsen	doc_491521502093_item	2585764	et	3	main
keele	doc_491521502093_item	2585766	et	4	main
pean	doc_491521502093_item	2585775	et	4	main
kiiresti	doc_491521502093_item	2585776	et	3	main
minema	doc_491521502093_item	2585777	et	3	main
hakkama	doc_491521502093_item	2585778	et	3	main
muidu	doc_491521502093_item	2585779	et	3	main
raha	doc_491521502093_item	2585790	et	4	main
tööd	doc_491521502093_item	2585798	et	4	main
veel	doc_491521502093_item	2585802	et	4	main
trennis	doc_491521502093_item	2585803	et	3	main
sõnad	doc_491521502093_item	2585814	et	4	main
lisaks	doc_491521502092_item	2585423	et	4	main
nõudma	doc_491521502092_item	2585434	et	3	main
meilt	doc_491521502092_item	2585436	et	3	main
allkirja	doc_491521502092_item	2585438	et	4	main
lastud	doc_491521502092_item	2585447	et	4	main
midagi	doc_491521502092_item	2585448	et	4	main
käskima	doc_491521502092_item	2585452	et	4	main
vait	doc_491521502092_item	2585453	et	3	main
olema	doc_491521502092_item	2585454	et	4	main
mul	doc_491521502092_item	2585455	et	3	main
kästi	doc_491521502092_item	2585456	et	3	main
olla	doc_491521502092_item	2585458	et	3	main
lugema	doc_491521502092_item	2585464	et	4	main
läbi	doc_491521502092_item	2585470	et	4	main
i	doc_491521502093_item	2585482	et	4	main
valige	doc_491521502093_item	2585483	et	3	main
õige	doc_491521502093_item	2585484	et	4	main
koera	doc_491521502093_item	2585488	et	4	main
kordamööda	doc_491521502093_item	2585490	et	3	main
teostada	doc_491521502093_item	2585510	et	3	main
varsti	doc_491521502093_item	2585512	et	3	main
kehtestatakse	doc_491521502093_item	2585513	et	3	main
kahjustatakse	doc_491521502093_item	2585514	et	3	main
omandatakse	doc_491521502093_item	2585515	et	3	main
uued	doc_491521502093_item	2585516	et	3	main
sisekorraeeskirjad	doc_491521502093_item	2585517	et	3	main
5	doc_491521502093_item	2585518	et	2	main
kui	doc_491521502093_item	2585519	et	3	main
inimene	doc_491521502093_item	2585520	et	3	main
pidevalt	doc_491521502093_item	2585522	et	4	main
siis	doc_491521502093_item	2585524	et	3	main
tagajärgi	doc_491521502093_item	2585538	et	4	main
mõned	doc_491521502093_item	2585543	et	3	main
aru	doc_491521502093_item	2585556	et	4	main
saama	doc_491521502093_item	2585557	et	4	main
tuleb	doc_491521502093_item	2585567	et	3	main
karu	doc_491521502093_item	2585578	et	4	main
ja	doc_491521502093_item	2585621	et	3	main
2	doc_491521502093_item	2585636	et	2	main
müüb	doc_491521502093_item	2585641	et	3	main
pesumasinas	doc_491521502093_item	2585657	et	3	main
kulu	doc_491521502093_item	2585673	et	4	main
kahjustatavat	doc_491521502093_item	2585690	et	4	main
eesti	doc_491521502093_item	2585694	et	4	main
постоянные	doc_491521502093_item	2585697	et	2	main
право	doc_491521502093_item	2585700	et	2	main
в	doc_491521502093_item	2585703	et	2	main
püsiklienditel	doc_491521502093_item	2585705	et	4	main
osta	doc_491521502093_item	2585708	et	4	main
нарушает	doc_491521502093_item	2585713	et	2	main
see	doc_491521502093_item	2585718	et	3	main
tema	doc_491521502093_item	2585525	et	4	main
inimesed	doc_491521502093_item	2585531	et	3	main
reostamise	doc_491521502093_item	2585536	et	4	main
järeldusi	doc_491521502093_item	2585537	et	4	main
kasutusjuhendis	doc_491521502093_item	2585541	et	3	main
pea	doc_491521502093_item	2585569	et	4	main
tuleb	doc_491521502093_item	2585570	et	3	main
5	doc_491521502093_item	2585572	et	2	main
1	doc_491521502093_item	2585586	et	2	main
hallitama	doc_491521502093_item	2585588	et	3	main
2	doc_491521502093_item	2585590	et	2	main
õmblusmasin	doc_491521502093_item	2585591	et	3	main
välja	doc_491521502093_item	2585592	et	4	main
venima	doc_491521502093_item	2585593	et	3	main
3	doc_491521502093_item	2585595	et	2	main
õmblused	doc_491521502093_item	2585596	et	3	main
rikki	doc_491521502093_item	2585597	et	3	main
minema	doc_491521502093_item	2585598	et	3	main
4	doc_491521502093_item	2585600	et	2	main
toidujäätmed	doc_491521502093_item	2585601	et	3	main
määrima	doc_491521502093_item	2585602	et	3	main
5	doc_491521502093_item	2585604	et	2	main
kreemituub	doc_491521502093_item	2585605	et	4	main
rebenema	doc_491521502093_item	2585606	et	3	main
3	doc_491521502093_item	2585607	et	2	main
6	doc_491521502093_item	2585608	et	2	main
näokreem	doc_491521502093_item	2585609	et	3	main
haisema	doc_491521502093_item	2585610	et	4	main
4	doc_491521502093_item	2585611	et	2	main
7	doc_491521502093_item	2585612	et	2	main
vaas	doc_491521502093_item	2585613	et	3	main
pigistama	doc_491521502093_item	2585614	et	3	main
5	doc_491521502093_item	2585615	et	2	main
8	doc_491521502093_item	2585616	et	2	main
teksad	doc_491521502093_item	2585617	et	4	main
iv	doc_491521502093_item	2585618	et	4	main
moodustage	doc_491521502093_item	2585619	et	3	main
v-	doc_491521502093_item	2585620	et	4	main
kreeme	doc_491521502093_item	2585625	et	3	main
palju	doc_491521502093_item	2585635	et	4	main
3	doc_491521502093_item	2585648	et	2	main
lisa	doc_491521502093_item	2585649	et	4	main
pesupulbrit	doc_491521502093_item	2585650	et	3	main
vette	doc_491521502093_item	2585651	et	3	main
mis	doc_491521502093_item	2585652	et	4	main
on	doc_491521502093_item	2585653	et	4	main
pesupulbrit	doc_491521502093_item	2585656	et	3	main
pestavat	doc_491521502093_item	2585670	et	4	main
pesu	doc_491521502093_item	2585671	et	4	main
5	doc_491521502093_item	2585676	et	2	main
võib	doc_491521502093_item	2585679	et	3	main
paljudel	doc_491521502093_item	2585685	et	3	main
keemiavahenditel	doc_491521502093_item	2585686	et	3	main
võib	doc_491521502093_item	2585687	et	3	main
olla	doc_491521502093_item	2585688	et	3	main
tervist	doc_491521502093_item	2585689	et	4	main
tõlkige	doc_491521502093_item	2585693	et	3	main
1	doc_491521502093_item	2585696	et	2	main
имеют	doc_491521502093_item	2585699	et	2	main
товар	doc_491521502093_item	2585702	et	2	main
kaupa	doc_491521502093_item	2585709	et	4	main
рынка	doc_491521502093_item	2585717	et	2	main
vaba	doc_491521502093_item	2585720	et	4	main
turu	doc_491521502093_item	2585721	et	3	main
мусора	doc_491521502093_item	2585727	et	2	main
moodustage	doc_491521502093_item	2585740	et	3	main
õnnetu	doc_491521502093_item	2585744	et	4	main
andetu	doc_491521502093_item	2585753	et	4	main
sidesõnad	doc_491521502093_item	2585761	et	3	main
on	doc_491521502093_item	2585772	et	4	main
3	doc_491521502093_item	2585782	et	2	main
endale	doc_491521502093_item	2585784	et	4	main
uue	doc_491521502093_item	2585786	et	3	main
4	doc_491521502093_item	2585793	et	2	main
teeb	doc_491521502093_item	2585795	et	3	main
päeva	doc_491521502093_item	2585797	et	4	main
sellele	doc_491521502093_item	2585800	et	4	main
palju	doc_491521502093_item	2585812	et	4	main
õppida	doc_491521502093_item	2585813	et	3	main
kuigi	doc_491521502093_item	2585819	et	3	main
tegumoe	doc_491521502093_item	2585825	et	3	main
1	doc_491521502093_item	2585829	et	2	main
meie	doc_491521502093_item	2585830	et	4	main
nõudma	doc_491521502093_item	2585831	et	3	main
allkiri	doc_491521502093_item	2585832	et	3	main
meilt	doc_491521502093_item	2585833	et	3	main
nõuti	doc_491521502093_item	2585834	et	3	main
lastud	doc_491521502093_item	2585844	et	4	main
ütelda	doc_491521502093_item	2585846	et	4	main
mina	doc_491521502093_item	2585848	et	4	main
käskima	doc_491521502093_item	2585849	et	4	main
vait	doc_491521502093_item	2585850	et	3	main
avaldus	doc_491521502093_item	2585858	et	4	main
ei	doc_491521502093_item	2585859	et	4	main
ei	doc_491521502093_item	2585865	et	4	main
läbi	doc_491521502093_item	2585867	et	4	main
ostjale	doc_491521502093_item	2585874	et	4	main
kaks	doc_491521502093_item	2585876	et	3	main
sõna	doc_491521502094_item	2585882	et	4	main
1	doc_491521502094_item	2585883	et	2	main
suurt	doc_491521502094_item	2585884	et	3	main
koera	doc_491521502094_item	2585885	et	4	main
3	doc_491521502094_item	2585898	et	2	main
переработки	doc_491521502093_item	2585726	et	2	main
привлекает	doc_491521502093_item	2585732	et	2	main
1	doc_491521502093_item	2585742	et	2	main
haritud	doc_491521502093_item	2585746	et	4	main
3	doc_491521502093_item	2585748	et	2	main
5	doc_491521502093_item	2585754	et	2	main
oodatud	doc_491521502093_item	2585755	et	4	main
õiged	doc_491521502093_item	2585760	et	3	main
2	doc_491521502093_item	2585774	et	2	main
jään	doc_491521502093_item	2585780	et	3	main
seega	doc_491521502093_item	2585788	et	4	main
pean	doc_491521502093_item	2585789	et	4	main
lisaks	doc_491521502093_item	2585799	et	4	main
käib	doc_491521502093_item	2585801	et	3	main
5	doc_491521502093_item	2585804	et	2	main
tahan	doc_491521502093_item	2585805	et	3	main
kõrgkooli	doc_491521502093_item	2585806	et	4	main
muidu	doc_491521502093_item	2585815	et	3	main
seega	doc_491521502093_item	2585816	et	4	main
lisaks	doc_491521502093_item	2585820	et	4	main
sellele	doc_491521502093_item	2585821	et	4	main
kasutage	doc_491521502093_item	2585823	et	3	main
ei	doc_491521502093_item	2585838	et	4	main
müüjal	doc_491521502093_item	2585842	et	4	main
läbi	doc_491521502093_item	2585860	et	4	main
avaldust	doc_491521502093_item	2585864	et	4	main
5	doc_491521502093_item	2585869	et	2	main
pakkuma	doc_491521502093_item	2585871	et	3	main
võimalus	doc_491521502093_item	2585873	et	3	main
pakkuti	doc_491521502093_item	2585875	et	4	main
kontrolltöö	doc_491521502094_item	2585878	et	4	main
i	doc_491521502094_item	2585879	et	4	main
valige	doc_491521502094_item	2585880	et	3	main
peab	doc_491521502094_item	2585886	et	4	main
kordamööda	doc_491521502094_item	2585887	et	3	main
ilmtingimata	doc_491521502094_item	2585888	et	3	main
omapead	doc_491521502094_item	2585889	et	3	main
õpetama	doc_491521502094_item	2585890	et	3	main
2	doc_491521502094_item	2585891	et	2	main
koormus	doc_491521502094_item	2585925	et	4	main
inimesed	doc_491521502094_item	2585928	et	3	main
reostamise	doc_491521502094_item	2585933	et	4	main
järeldusi	doc_491521502094_item	2585934	et	4	main
kehtivad	doc_491521502094_item	2585943	et	4	main
ta	doc_491521502094_item	2585968	et	4	main
tuleb	doc_491521502094_item	2585969	et	3	main
varsti	doc_491521502094_item	2585970	et	3	main
5	doc_491521502094_item	2585971	et	2	main
iii	doc_491521502094_item	2585978	et	4	main
määrima	doc_491521502094_item	2585997	et	3	main
näokreem	doc_491521502094_item	2586002	et	3	main
vaas	doc_491521502094_item	2586005	et	3	main
pigistama	doc_491521502094_item	2586006	et	3	main
kreemituub	doc_491521502094_item	2586007	et	4	main
toodetakse	doc_491521502094_item	2586018	et	3	main
kasutatakse	doc_491521502094_item	2586025	et	3	main
seda	doc_491521502094_item	2586036	et	3	main
pesupulbrit	doc_491521502094_item	2586040	et	3	main
pesumasinas	doc_491521502094_item	2586045	et	3	main
kulu	doc_491521502094_item	2586062	et	4	main
kiiresti	doc_491521502094_item	2586064	et	3	main
keemiavahenditel	doc_491521502094_item	2586067	et	3	main
olla	doc_491521502094_item	2586069	et	3	main
mis	doc_491521502094_item	2586071	et	4	main
tõlkige	doc_491521502094_item	2586082	et	3	main
фирма	doc_491521502094_item	2586122	et	2	main
oodatud	doc_491521502094_item	2586146	et	4	main
keele	doc_491521502094_item	2586157	et	4	main
õpinguid	doc_491521502094_item	2586158	et	3	main
kui	doc_491521502094_item	2586161	et	3	main
hiljaks	doc_491521502094_item	2586174	et	3	main
osta	doc_491521502094_item	2586178	et	4	main
kleidi	doc_491521502094_item	2586180	et	3	main
tööd	doc_491521502094_item	2586191	et	4	main
5	doc_491521502094_item	2586197	et	2	main
tehti	doc_491521502094_item	2586221	et	3	main
allkiri	doc_491521502094_item	2586225	et	3	main
nõuti	doc_491521502094_item	2586227	et	3	main
müüja	doc_491521502094_item	2586230	et	4	main
midagi	doc_491521502094_item	2586238	et	4	main
mul	doc_491521502094_item	2586245	et	3	main
kästi	doc_491521502094_item	2586246	et	3	main
vait	doc_491521502094_item	2586247	et	3	main
olla	doc_491521502094_item	2586248	et	3	main
kleidi	doc_491521502093_item	2585787	et	3	main
terve	doc_491521502093_item	2585796	et	4	main
saada	doc_491521502093_item	2585808	et	4	main
kuigi	doc_491521502093_item	2585809	et	3	main
tuleb	doc_491521502093_item	2585810	et	3	main
mul	doc_491521502093_item	2585811	et	3	main
kui	doc_491521502093_item	2585818	et	3	main
viii	doc_491521502093_item	2585822	et	4	main
lihtminevikku	doc_491521502093_item	2585826	et	4	main
mida	doc_491521502093_item	2585827	et	4	main
tehti	doc_491521502093_item	2585828	et	3	main
laskma	doc_491521502093_item	2585839	et	3	main
ei	doc_491521502093_item	2585843	et	4	main
käsiti	doc_491521502093_item	2585853	et	4	main
vait	doc_491521502093_item	2585854	et	3	main
4	doc_491521502093_item	2585856	et	2	main
korralikult	doc_491521502093_item	2585862	et	4	main
võimalust	doc_491521502093_item	2585877	et	3	main
tema	doc_491521502094_item	2585922	et	4	main
endale	doc_491521502094_item	2585930	et	4	main
üleolevad	doc_491521502094_item	2585941	et	3	main
ii	doc_491521502094_item	2585945	et	4	main
1	doc_491521502094_item	2585948	et	2	main
poole	doc_491521502094_item	2585960	et	4	main
tuleb	doc_491521502094_item	2585965	et	3	main
lõi	doc_491521502094_item	2585972	et	4	main
ühendage	doc_491521502094_item	2585979	et	3	main
ese	doc_491521502094_item	2585982	et	3	main
vaas	doc_491521502094_item	2585984	et	3	main
juust	doc_491521502094_item	2585987	et	4	main
õmblusmasin	doc_491521502094_item	2585988	et	3	main
välja	doc_491521502094_item	2585989	et	4	main
venima	doc_491521502094_item	2585990	et	3	main
teksad	doc_491521502094_item	2586008	et	4	main
kreeme	doc_491521502094_item	2586016	et	3	main
palju	doc_491521502094_item	2586021	et	4	main
palju	doc_491521502094_item	2586026	et	4	main
küsi	doc_491521502094_item	2586028	et	4	main
seda	doc_491521502094_item	2586029	et	3	main
on	doc_491521502094_item	2586043	et	4	main
olevasse	doc_491521502094_item	2586046	et	4	main
4	doc_491521502094_item	2586049	et	2	main
mida	doc_491521502094_item	2586051	et	4	main
ei	doc_491521502094_item	2586061	et	4	main
toime	doc_491521502094_item	2586080	et	4	main
1	doc_491521502094_item	2586085	et	2	main
система	doc_491521502094_item	2586111	et	2	main
мусора	doc_491521502094_item	2586113	et	2	main
prahti	doc_491521502094_item	2586116	et	4	main
привлекает	doc_491521502094_item	2586123	et	2	main
firma	doc_491521502094_item	2586126	et	4	main
kliente	doc_491521502094_item	2586128	et	3	main
vi	doc_491521502094_item	2586130	et	4	main
antonüümid	doc_491521502094_item	2586132	et	3	main
harimatu	doc_491521502094_item	2586138	et	4	main
loetamatu	doc_491521502094_item	2586141	et	4	main
andekas	doc_491521502094_item	2586143	et	4	main
andetu	doc_491521502094_item	2586144	et	4	main
5	doc_491521502094_item	2586145	et	2	main
1	doc_491521502094_item	2586153	et	2	main
ma	doc_491521502094_item	2586154	et	3	main
juhul	doc_491521502094_item	2586160	et	3	main
lisaks	doc_491521502094_item	2586162	et	4	main
sellele	doc_491521502094_item	2586163	et	4	main
mul	doc_491521502094_item	2586164	et	3	main
jään	doc_491521502094_item	2586173	et	3	main
endale	doc_491521502094_item	2586177	et	4	main
raha	doc_491521502094_item	2586183	et	4	main
lisaks	doc_491521502094_item	2586192	et	4	main
sellele	doc_491521502094_item	2586193	et	4	main
käib	doc_491521502094_item	2586194	et	3	main
meilt	doc_491521502094_item	2586226	et	3	main
allkirja	doc_491521502094_item	2586228	et	4	main
ei	doc_491521502094_item	2586236	et	4	main
lastud	doc_491521502094_item	2586237	et	4	main
korralikult	doc_491521502094_item	2586260	et	4	main
1	doc_491521502095_item	2586276	et	2	main
koera	doc_491521502095_item	2586278	et	4	main
omapead	doc_491521502095_item	2586282	et	3	main
õpetama	doc_491521502095_item	2586283	et	3	main
selle	doc_491521502095_item	2586285	et	4	main
pintsaku	doc_491521502095_item	2586286	et	3	main
kokku	doc_491521502093_item	2585791	et	3	main
hoidma	doc_491521502093_item	2585792	et	3	main
ta	doc_491521502093_item	2585794	et	4	main
sisse	doc_491521502093_item	2585807	et	4	main
juhul	doc_491521502093_item	2585817	et	3	main
umbisikulise	doc_491521502093_item	2585824	et	4	main
allkirja	doc_491521502093_item	2585835	et	4	main
2	doc_491521502093_item	2585836	et	2	main
müüja	doc_491521502093_item	2585837	et	4	main
ütlema	doc_491521502093_item	2585841	et	3	main
midagi	doc_491521502093_item	2585845	et	4	main
3	doc_491521502093_item	2585847	et	2	main
olla	doc_491521502093_item	2585855	et	3	main
minu	doc_491521502093_item	2585857	et	3	main
minu	doc_491521502093_item	2585863	et	3	main
loetud	doc_491521502093_item	2585866	et	4	main
korralikult	doc_491521502093_item	2585868	et	4	main
kaks	doc_491521502093_item	2585872	et	3	main
pintsaku	doc_491521502094_item	2585893	et	3	main
õmblused	doc_491521502094_item	2585894	et	3	main
käsitsevad	doc_491521502094_item	2585895	et	4	main
kisuvad	doc_491521502094_item	2585896	et	3	main
luituvad	doc_491521502094_item	2585897	et	4	main
kardan	doc_491521502094_item	2585899	et	4	main
et	doc_491521502094_item	2585900	et	3	main
seda	doc_491521502094_item	2585901	et	3	main
plaani	doc_491521502094_item	2585902	et	4	main
on	doc_491521502094_item	2585903	et	4	main
liigitada	doc_491521502094_item	2585905	et	3	main
sisaldada	doc_491521502094_item	2585906	et	3	main
teostada	doc_491521502094_item	2585907	et	3	main
4	doc_491521502094_item	2585908	et	2	main
raske	doc_491521502094_item	2585904	et	4	main
varsti	doc_491521502094_item	2585909	et	3	main
kehtestatakse	doc_491521502094_item	2585910	et	3	main
kahjustatakse	doc_491521502094_item	2585911	et	3	main
omandatakse	doc_491521502094_item	2585912	et	3	main
uued	doc_491521502094_item	2585913	et	3	main
5	doc_491521502094_item	2585915	et	2	main
sisekorraeeskirjad	doc_491521502094_item	2585914	et	3	main
kui	doc_491521502094_item	2585916	et	3	main
inimene	doc_491521502094_item	2585917	et	3	main
kogeb	doc_491521502094_item	2585918	et	3	main
ebaõnnestumisi	doc_491521502094_item	2585920	et	3	main
pidevalt	doc_491521502094_item	2585919	et	4	main
isiksus	doc_491521502094_item	2585923	et	3	main
6	doc_491521502094_item	2585927	et	2	main
peaksid	doc_491521502094_item	2585929	et	4	main
teadvustama	doc_491521502094_item	2585931	et	3	main
keskkonna	doc_491521502094_item	2585932	et	3	main
on	doc_491521502094_item	2585939	et	4	main
mõned	doc_491521502094_item	2585940	et	3	main
kohad	doc_491521502094_item	2585944	et	4	main
kirjutage	doc_491521502094_item	2585946	et	3	main
sünonüümid	doc_491521502094_item	2585947	et	3	main
hülgama	doc_491521502094_item	2585949	et	3	main
2	doc_491521502094_item	2585952	et	2	main
taipama	doc_491521502094_item	2585953	et	3	main
ära	doc_491521502094_item	2585954	et	4	main
arvama	doc_491521502094_item	2585955	et	3	main
3	doc_491521502094_item	2585956	et	2	main
topib	doc_491521502094_item	2585957	et	3	main
ta	doc_491521502094_item	2585961	et	4	main
4	doc_491521502094_item	2585964	et	2	main
midagi	doc_491521502093_item	2585840	et	4	main
olema	doc_491521502093_item	2585851	et	4	main
mul	doc_491521502093_item	2585852	et	3	main
lugema	doc_491521502093_item	2585861	et	4	main
ostja	doc_491521502093_item	2585870	et	4	main
õige	doc_491521502094_item	2585881	et	4	main
selle	doc_491521502094_item	2585892	et	4	main
siis	doc_491521502094_item	2585921	et	3	main
eksitavad	doc_491521502094_item	2585942	et	4	main
maha	doc_491521502094_item	2585950	et	4	main
jätma	doc_491521502094_item	2585951	et	3	main
on	doc_491521502094_item	2585962	et	4	main
pea	doc_491521502094_item	2585967	et	4	main
6	doc_491521502094_item	2585975	et	2	main
mesikäpp	doc_491521502094_item	2585976	et	3	main
tegusõna	doc_491521502094_item	2585980	et	4	main
ja	doc_491521502094_item	2585981	et	3	main
hallitama	doc_491521502094_item	2585986	et	3	main
näokreem	doc_491521502094_item	2585998	et	3	main
v-	doc_491521502094_item	2586011	et	4	main
ja	doc_491521502094_item	2586012	et	3	main
1	doc_491521502094_item	2586015	et	2	main
kasutatakse	doc_491521502094_item	2586020	et	3	main
eestis	doc_491521502094_item	2586022	et	3	main
2	doc_491521502094_item	2586027	et	2	main
neiult	doc_491521502094_item	2586030	et	4	main
neiult	doc_491521502094_item	2586037	et	4	main
mis	doc_491521502094_item	2586042	et	4	main
vette	doc_491521502094_item	2586047	et	3	main
kulu	doc_491521502094_item	2586055	et	4	main
nii	doc_491521502094_item	2586056	et	3	main
kiiresti	doc_491521502094_item	2586057	et	3	main
käsitsi	doc_491521502094_item	2586058	et	3	main
nii	doc_491521502094_item	2586063	et	3	main
paljudel	doc_491521502094_item	2586066	et	3	main
võib	doc_491521502094_item	2586068	et	3	main
keelde	doc_491521502094_item	2586084	et	4	main
разработана	doc_491521502094_item	2586115	et	2	main
järelekasutamissüstem	doc_491521502094_item	2586117	et	4	main
töödeldakse	doc_491521502094_item	2586119	et	3	main
veel	doc_491521502094_item	2586120	et	4	main
4	doc_491521502094_item	2586121	et	2	main
3	doc_491521502094_item	2586139	et	2	main
4	doc_491521502094_item	2586142	et	2	main
eesti	doc_491521502094_item	2586156	et	4	main
aega	doc_491521502094_item	2586166	et	4	main
2	doc_491521502094_item	2586167	et	2	main
päeva	doc_491521502094_item	2586190	et	4	main
trennis	doc_491521502094_item	2586196	et	3	main
1	doc_491521502094_item	2586222	et	2	main
käskima	doc_491521502094_item	2586242	et	4	main
vait	doc_491521502094_item	2586243	et	3	main
olema	doc_491521502094_item	2586244	et	4	main
korralikult	doc_491521502094_item	2586255	et	4	main
minu	doc_491521502094_item	2586256	et	3	main
avaldus	doc_491521502094_item	2586257	et	4	main
ei	doc_491521502094_item	2586258	et	4	main
pakkuma	doc_491521502094_item	2586264	et	3	main
kaks	doc_491521502094_item	2586265	et	3	main
võimalus	doc_491521502094_item	2586266	et	3	main
ostjale	doc_491521502094_item	2586267	et	4	main
pakuti	doc_491521502094_item	2586268	et	3	main
kaht	doc_491521502094_item	2586269	et	3	main
võimalust	doc_491521502094_item	2586270	et	3	main
sõna	doc_491521502095_item	2586275	et	4	main
ilmtingimata	doc_491521502095_item	2586281	et	3	main
2	doc_491521502095_item	2586284	et	2	main
käsitsevad	doc_491521502095_item	2586288	et	4	main
kisuvad	doc_491521502095_item	2586289	et	3	main
seda	doc_491521502095_item	2586294	et	3	main
pidevalt	doc_491521502095_item	2586312	et	4	main
koormus	doc_491521502095_item	2586318	et	4	main
enesehinnang	doc_491521502094_item	2585924	et	3	main
langeb	doc_491521502094_item	2585926	et	3	main
tagajärgi	doc_491521502094_item	2585935	et	4	main
tulemusi	doc_491521502094_item	2585936	et	4	main
7	doc_491521502094_item	2585937	et	2	main
kasutusjuhendis	doc_491521502094_item	2585938	et	3	main
nina	doc_491521502094_item	2585958	et	4	main
igale	doc_491521502094_item	2585959	et	3	main
uudishimulik	doc_491521502094_item	2585963	et	3	main
õige	doc_491521502094_item	2585966	et	4	main
käega	doc_491521502094_item	2585974	et	3	main
teksad	doc_491521502094_item	2585991	et	4	main
õmblused	doc_491521502094_item	2585992	et	3	main
rikki	doc_491521502094_item	2585993	et	3	main
minema	doc_491521502094_item	2585994	et	3	main
õmblusmasin	doc_491521502094_item	2585995	et	3	main
kreemituub	doc_491521502094_item	2585999	et	4	main
õmblused	doc_491521502094_item	2586001	et	3	main
toidujäätmed	doc_491521502094_item	2586004	et	3	main
iv	doc_491521502094_item	2586009	et	4	main
moodustage	doc_491521502094_item	2586010	et	3	main
mida	doc_491521502094_item	2586017	et	4	main
kõigele	doc_491521502094_item	2585973	et	4	main
karu	doc_491521502094_item	2585977	et	4	main
purunema	doc_491521502094_item	2585983	et	3	main
juust	doc_491521502094_item	2585985	et	4	main
toidujäätmed	doc_491521502094_item	2585996	et	3	main
rebenema	doc_491521502094_item	2586000	et	3	main
haisema	doc_491521502094_item	2586003	et	4	main
tav-kesksõnaga	doc_491521502094_item	2586013	et	3	main
laused	doc_491521502094_item	2586014	et	3	main
eestis	doc_491521502094_item	2586019	et	3	main
toodetavateid	doc_491521502094_item	2586023	et	4	main
kreeme	doc_491521502094_item	2586024	et	3	main
3	doc_491521502094_item	2586038	et	2	main
vette	doc_491521502094_item	2586041	et	3	main
pesupulbrit	doc_491521502094_item	2586048	et	3	main
pesu	doc_491521502094_item	2586050	et	4	main
pestakse	doc_491521502094_item	2586052	et	3	main
käsitsi	doc_491521502094_item	2586053	et	3	main
ei	doc_491521502094_item	2586054	et	4	main
pesu	doc_491521502094_item	2586060	et	4	main
5	doc_491521502094_item	2586065	et	2	main
v	doc_491521502094_item	2586081	et	4	main
не	doc_491521502094_item	2586114	et	2	main
ei	doc_491521502094_item	2586118	et	4	main
клиентов	doc_491521502094_item	2586124	et	2	main
kingitustega	doc_491521502094_item	2586129	et	4	main
moodustage	doc_491521502094_item	2586131	et	3	main
1	doc_491521502094_item	2586133	et	2	main
õnnelik	doc_491521502094_item	2586134	et	3	main
õnnetu	doc_491521502094_item	2586135	et	4	main
2	doc_491521502094_item	2586136	et	2	main
pange	doc_491521502094_item	2586149	et	4	main
lünkadesse	doc_491521502094_item	2586150	et	3	main
õiged	doc_491521502094_item	2586151	et	3	main
sidesõnad	doc_491521502094_item	2586152	et	3	main
kavatsen	doc_491521502094_item	2586155	et	3	main
jätkata	doc_491521502094_item	2586159	et	4	main
pean	doc_491521502094_item	2586168	et	4	main
kiiresti	doc_491521502094_item	2586169	et	3	main
minema	doc_491521502094_item	2586170	et	3	main
hakkama	doc_491521502094_item	2586171	et	3	main
muidu	doc_491521502094_item	2586172	et	3	main
tahan	doc_491521502094_item	2586176	et	3	main
uue	doc_491521502094_item	2586179	et	3	main
pean	doc_491521502094_item	2586182	et	4	main
kokku	doc_491521502094_item	2586184	et	3	main
4	doc_491521502094_item	2586186	et	2	main
terve	doc_491521502094_item	2586189	et	4	main
veel	doc_491521502094_item	2586195	et	4	main
kõrgkooli	doc_491521502094_item	2586199	et	4	main
nõudma	doc_491521502094_item	2586224	et	3	main
2	doc_491521502094_item	2586229	et	2	main
ei	doc_491521502094_item	2586231	et	4	main
laskma	doc_491521502094_item	2586232	et	3	main
midagi	doc_491521502094_item	2586233	et	4	main
ütlema	doc_491521502094_item	2586234	et	3	main
öelda	doc_491521502094_item	2586239	et	4	main
3	doc_491521502094_item	2586240	et	2	main
läbi	doc_491521502094_item	2586261	et	4	main
i	doc_491521502095_item	2586272	et	4	main
valige	doc_491521502095_item	2586273	et	3	main
luituvad	doc_491521502095_item	2586290	et	4	main
4	doc_491521502095_item	2586301	et	2	main
kahjustatakse	doc_491521502095_item	2586304	et	3	main
uued	doc_491521502095_item	2586306	et	3	main
kui	doc_491521502095_item	2586309	et	3	main
siis	doc_491521502095_item	2586314	et	3	main
isiksus	doc_491521502095_item	2586316	et	3	main
6	doc_491521502095_item	2586320	et	2	main
peaksid	doc_491521502095_item	2586322	et	4	main
järeldusi	doc_491521502095_item	2586327	et	4	main
tagajärgi	doc_491521502095_item	2586328	et	4	main
kehtivad	doc_491521502095_item	2586336	et	4	main
kohad	doc_491521502095_item	2586337	et	4	main
taipama	doc_491521502095_item	2586344	et	3	main
topib	doc_491521502095_item	2586347	et	3	main
mõte	doc_491521502095_item	2586357	et	3	main
iii	doc_491521502095_item	2586366	et	4	main
ühendage	doc_491521502095_item	2586367	et	3	main
ja	doc_491521502095_item	2586369	et	3	main
juust	doc_491521502095_item	2586373	et	4	main
2	doc_491521502095_item	2586376	et	2	main
kes	doc_491521502094_item	2586031	et	4	main
müüb	doc_491521502094_item	2586032	et	3	main
vitamiine	doc_491521502094_item	2586033	et	3	main
vitamiine	doc_491521502094_item	2586034	et	3	main
müüvalt	doc_491521502094_item	2586035	et	4	main
lisa	doc_491521502094_item	2586039	et	4	main
pesumasinas	doc_491521502094_item	2586044	et	3	main
pestav	doc_491521502094_item	2586059	et	4	main
toime	doc_491521502094_item	2586070	et	4	main
kahjustab	doc_491521502094_item	2586072	et	3	main
tervist	doc_491521502094_item	2586073	et	4	main
tervist	doc_491521502094_item	2586074	et	4	main
kahjustavatel	doc_491521502094_item	2586075	et	4	main
paljudel	doc_491521502094_item	2586076	et	3	main
keemiavahenditel	doc_491521502094_item	2586077	et	3	main
võib	doc_491521502094_item	2586078	et	3	main
olla	doc_491521502094_item	2586079	et	3	main
eesti	doc_491521502094_item	2586083	et	4	main
постоянные	doc_491521502094_item	2586086	et	2	main
клиенты	doc_491521502094_item	2586087	et	2	main
имеют	doc_491521502094_item	2586088	et	2	main
право	doc_491521502094_item	2586089	et	2	main
покупать	doc_491521502094_item	2586090	et	2	main
в	doc_491521502094_item	2586092	et	2	main
товар	doc_491521502094_item	2586091	et	2	main
рассрочку	doc_491521502094_item	2586093	et	2	main
püsikliendil	doc_491521502094_item	2586094	et	3	main
on	doc_491521502094_item	2586095	et	4	main
õigus	doc_491521502094_item	2586096	et	4	main
osta	doc_491521502094_item	2586097	et	4	main
2	doc_491521502094_item	2586099	et	2	main
järelmaksuga	doc_491521502094_item	2586098	et	3	main
это	doc_491521502094_item	2586100	et	2	main
нарушает	doc_491521502094_item	2586101	et	2	main
принципы	doc_491521502094_item	2586102	et	2	main
торговли	doc_491521502094_item	2586103	et	2	main
свободного	doc_491521502094_item	2586104	et	2	main
рынка	doc_491521502094_item	2586105	et	2	main
see	doc_491521502094_item	2586106	et	3	main
sekkub	doc_491521502094_item	2586107	et	3	main
vabaturukaubanduse	doc_491521502094_item	2586108	et	3	main
põhimõttese	doc_491521502094_item	2586109	et	4	main
3	doc_491521502094_item	2586110	et	2	main
переработки	doc_491521502094_item	2586112	et	2	main
подарками	doc_491521502094_item	2586125	et	2	main
peibutab	doc_491521502094_item	2586127	et	3	main
haritud	doc_491521502094_item	2586137	et	4	main
loetav	doc_491521502094_item	2586140	et	4	main
ootamatu	doc_491521502094_item	2586147	et	4	main
vii	doc_491521502094_item	2586148	et	4	main
on	doc_491521502094_item	2586165	et	4	main
3	doc_491521502094_item	2586175	et	2	main
seega	doc_491521502094_item	2586181	et	4	main
hoidma	doc_491521502094_item	2586185	et	3	main
ta	doc_491521502094_item	2586187	et	4	main
teeb	doc_491521502094_item	2586188	et	3	main
tahan	doc_491521502094_item	2586198	et	3	main
sisse	doc_491521502094_item	2586200	et	4	main
saada	doc_491521502094_item	2586201	et	4	main
seega	doc_491521502094_item	2586202	et	4	main
tuleb	doc_491521502094_item	2586203	et	3	main
mul	doc_491521502094_item	2586204	et	3	main
palju	doc_491521502094_item	2586205	et	4	main
õppida	doc_491521502094_item	2586206	et	3	main
sõnad	doc_491521502094_item	2586207	et	4	main
muidu	doc_491521502094_item	2586208	et	3	main
seega	doc_491521502094_item	2586209	et	4	main
juhul	doc_491521502094_item	2586210	et	3	main
kui	doc_491521502094_item	2586211	et	3	main
kuigi	doc_491521502094_item	2586212	et	3	main
lisaks	doc_491521502094_item	2586213	et	4	main
sellele	doc_491521502094_item	2586214	et	4	main
viii	doc_491521502094_item	2586215	et	4	main
kasutage	doc_491521502094_item	2586216	et	3	main
umbisikulise	doc_491521502094_item	2586217	et	4	main
tegumoe	doc_491521502094_item	2586218	et	3	main
lihtminevikku	doc_491521502094_item	2586219	et	4	main
mida	doc_491521502094_item	2586220	et	4	main
meie	doc_491521502094_item	2586223	et	4	main
müüjal	doc_491521502094_item	2586235	et	4	main
mina	doc_491521502094_item	2586241	et	4	main
4	doc_491521502094_item	2586249	et	2	main
minu	doc_491521502094_item	2586250	et	3	main
avaldus	doc_491521502094_item	2586251	et	4	main
ei	doc_491521502094_item	2586252	et	4	main
läbi	doc_491521502094_item	2586253	et	4	main
lugema	doc_491521502094_item	2586254	et	4	main
loetud	doc_491521502094_item	2586259	et	4	main
kontrolltöö	doc_491521502095_item	2586271	et	4	main
suurt	doc_491521502095_item	2586277	et	3	main
3	doc_491521502095_item	2586291	et	2	main
plaani	doc_491521502095_item	2586295	et	4	main
raske	doc_491521502095_item	2586297	et	4	main
liigitada	doc_491521502095_item	2586298	et	3	main
sisaldada	doc_491521502095_item	2586299	et	3	main
teostada	doc_491521502095_item	2586300	et	3	main
kehtestatakse	doc_491521502095_item	2586303	et	3	main
sisekorraeeskirjad	doc_491521502095_item	2586307	et	3	main
inimene	doc_491521502095_item	2586310	et	3	main
tema	doc_491521502095_item	2586315	et	4	main
enesehinnang	doc_491521502095_item	2586317	et	3	main
langeb	doc_491521502095_item	2586319	et	3	main
endale	doc_491521502095_item	2586323	et	4	main
on	doc_491521502095_item	2586332	et	4	main
mõned	doc_491521502095_item	2586333	et	3	main
üleolevad	doc_491521502095_item	2586334	et	3	main
eksitavad	doc_491521502095_item	2586335	et	4	main
2	doc_491521502095_item	2586343	et	2	main
nina	doc_491521502095_item	2586348	et	4	main
igale	doc_491521502095_item	2586349	et	3	main
poole	doc_491521502095_item	2586350	et	4	main
uudishiimulik	doc_491521502095_item	2586351	et	4	main
õige	doc_491521502095_item	2586354	et	4	main
värske	doc_491521502095_item	2586356	et	4	main
5	doc_491521502095_item	2586358	et	2	main
tegusõna	doc_491521502095_item	2586368	et	4	main
1	doc_491521502095_item	2586400	et	2	main
pigistama	doc_491521502095_item	2586401	et	3	main
v-	doc_491521502095_item	2586407	et	4	main
kasutatakse	doc_491521502095_item	2586421	et	3	main
kes	doc_491521502095_item	2586427	et	4	main
müüb	doc_491521502095_item	2586428	et	3	main
vitamiine	doc_491521502095_item	2586429	et	3	main
küsi	doc_491521502095_item	2586430	et	4	main
on	doc_491521502095_item	2586440	et	4	main
pesumasinas	doc_491521502095_item	2586441	et	3	main
pesumasinas	doc_491521502095_item	2586442	et	3	main
vette	doc_491521502095_item	2586443	et	3	main
listav	doc_491521502095_item	2586444	et	4	main
4	doc_491521502095_item	2586446	et	2	main
pesu	doc_491521502095_item	2586447	et	4	main
kulu	doc_491521502095_item	2586452	et	4	main
käsitsi	doc_491521502095_item	2586456	et	3	main
eesti	doc_491521502095_item	2586480	et	4	main
keelde	doc_491521502095_item	2586481	et	4	main
1	doc_491521502095_item	2586482	et	2	main
постоянные	doc_491521502095_item	2586483	et	2	main
клиенты	doc_491521502095_item	2586484	et	2	main
имеют	doc_491521502095_item	2586485	et	2	main
право	doc_491521502095_item	2586486	et	2	main
покупать	doc_491521502095_item	2586487	et	2	main
товар	doc_491521502095_item	2586488	et	2	main
omavad	doc_491521502095_item	2586492	et	4	main
kaupa	doc_491521502095_item	2586495	et	4	main
järelmaksuga	doc_491521502095_item	2586496	et	3	main
это	doc_491521502095_item	2586498	et	2	main
принципы	doc_491521502095_item	2586500	et	2	main
свободного	doc_491521502095_item	2586502	et	2	main
3	doc_491521502095_item	2586509	et	2	main
разработана	doc_491521502095_item	2586514	et	2	main
ümbertöötlemis	doc_491521502095_item	2586516	et	4	main
клиентов	doc_491521502095_item	2586526	et	2	main
loetu	doc_491521502095_item	2586543	et	4	main
4	doc_491521502095_item	2586544	et	2	main
ootamatu	doc_491521502095_item	2586550	et	4	main
sidesõnad	doc_491521502095_item	2586555	et	3	main
ma	doc_491521502095_item	2586557	et	3	main
jään	doc_491521502095_item	2586574	et	3	main
uue	doc_491521502095_item	2586580	et	3	main
terve	doc_491521502095_item	2586590	et	4	main
käib	doc_491521502095_item	2586595	et	3	main
tahan	doc_491521502095_item	2586599	et	3	main
sõnad	doc_491521502095_item	2586608	et	4	main
seega	doc_491521502095_item	2586610	et	4	main
viii	doc_491521502095_item	2586616	et	4	main
kasutage	doc_491521502095_item	2586617	et	3	main
mida	doc_491521502095_item	2586621	et	4	main
5	doc_491521502094_item	2586262	et	2	main
ostja	doc_491521502094_item	2586263	et	4	main
õige	doc_491521502095_item	2586274	et	4	main
peab	doc_491521502095_item	2586279	et	4	main
kordamööda	doc_491521502095_item	2586280	et	3	main
kardan	doc_491521502095_item	2586292	et	4	main
on	doc_491521502095_item	2586296	et	4	main
varsti	doc_491521502095_item	2586302	et	3	main
omandatakse	doc_491521502095_item	2586305	et	3	main
5	doc_491521502095_item	2586308	et	2	main
kogeb	doc_491521502095_item	2586311	et	3	main
inimesed	doc_491521502095_item	2586321	et	3	main
hülgama	doc_491521502095_item	2586342	et	3	main
arusaama	doc_491521502095_item	2586345	et	4	main
maha	doc_491521502095_item	2586362	et	4	main
jätma	doc_491521502095_item	2586363	et	3	main
mesikäpp	doc_491521502095_item	2586365	et	3	main
1	doc_491521502095_item	2586372	et	2	main
2	doc_491521502095_item	2586374	et	2	main
õmblusmasin	doc_491521502095_item	2586377	et	3	main
välja	doc_491521502095_item	2586379	et	4	main
venima	doc_491521502095_item	2586380	et	3	main
6	doc_491521502095_item	2586383	et	2	main
4	doc_491521502095_item	2586386	et	2	main
7	doc_491521502095_item	2586388	et	2	main
määrima	doc_491521502095_item	2586389	et	3	main
kreemituub	doc_491521502095_item	2586391	et	4	main
6	doc_491521502095_item	2586394	et	2	main
näokreem	doc_491521502095_item	2586395	et	3	main
2	doc_491521502095_item	2586423	et	2	main
neiult	doc_491521502095_item	2586426	et	4	main
nii	doc_491521502095_item	2586453	et	3	main
pesu	doc_491521502095_item	2586457	et	4	main
ei	doc_491521502095_item	2586458	et	4	main
в	doc_491521502095_item	2586489	et	2	main
osta	doc_491521502095_item	2586494	et	4	main
2	doc_491521502095_item	2586497	et	2	main
нарушает	doc_491521502095_item	2586499	et	2	main
торговли	doc_491521502095_item	2586501	et	2	main
рынка	doc_491521502095_item	2586503	et	2	main
see	doc_491521502095_item	2586504	et	3	main
rikkub	doc_491521502095_item	2586505	et	4	main
vabaturu	doc_491521502095_item	2586506	et	3	main
система	doc_491521502095_item	2586510	et	2	main
õmblused	doc_491521502095_item	2586287	et	3	main
et	doc_491521502095_item	2586293	et	3	main
ebaõnnestumisi	doc_491521502095_item	2586313	et	3	main
keskkonna	doc_491521502095_item	2586325	et	3	main
1	doc_491521502095_item	2586341	et	2	main
3	doc_491521502095_item	2586346	et	2	main
tuleb	doc_491521502095_item	2586353	et	3	main
pea	doc_491521502095_item	2586355	et	4	main
lõi	doc_491521502095_item	2586359	et	4	main
kõigele	doc_491521502095_item	2586360	et	4	main
käega	doc_491521502095_item	2586361	et	3	main
ese	doc_491521502095_item	2586370	et	3	main
hallitama	doc_491521502095_item	2586375	et	3	main
teksad	doc_491521502095_item	2586403	et	4	main
ja	doc_491521502095_item	2586408	et	3	main
laused	doc_491521502095_item	2586410	et	3	main
seda	doc_491521502095_item	2586425	et	3	main
seda	doc_491521502095_item	2586431	et	3	main
vitamiine	doc_491521502095_item	2586432	et	3	main
müüvalt	doc_491521502095_item	2586433	et	4	main
pesupulbrit	doc_491521502095_item	2586445	et	3	main
kiiresti	doc_491521502095_item	2586454	et	3	main
olla	doc_491521502095_item	2586476	et	3	main
toime	doc_491521502095_item	2586477	et	4	main
v	doc_491521502095_item	2586478	et	4	main
tõlkige	doc_491521502095_item	2586479	et	3	main
рассрочку	doc_491521502095_item	2586490	et	2	main
müümise	doc_491521502095_item	2586507	et	4	main
переработки	doc_491521502095_item	2586511	et	2	main
prügi	doc_491521502095_item	2586515	et	4	main
ei	doc_491521502095_item	2586518	et	4	main
подарками	doc_491521502095_item	2586527	et	2	main
õnnelik	doc_491521502095_item	2586536	et	3	main
2	doc_491521502095_item	2586538	et	2	main
haritu	doc_491521502095_item	2586540	et	4	main
3	doc_491521502095_item	2586541	et	2	main
oodatud	doc_491521502095_item	2586549	et	4	main
pange	doc_491521502095_item	2586552	et	4	main
õiged	doc_491521502095_item	2586554	et	3	main
1	doc_491521502095_item	2586556	et	2	main
muidu	doc_491521502095_item	2586573	et	3	main
hiljaks	doc_491521502095_item	2586575	et	3	main
kleidi	doc_491521502095_item	2586581	et	3	main
pean	doc_491521502095_item	2586583	et	4	main
4	doc_491521502095_item	2586587	et	2	main
ta	doc_491521502095_item	2586588	et	4	main
teeb	doc_491521502095_item	2586589	et	3	main
sellele	doc_491521502095_item	2586594	et	4	main
sisse	doc_491521502095_item	2586601	et	4	main
saada	doc_491521502095_item	2586602	et	4	main
kuigi	doc_491521502095_item	2586603	et	3	main
tuleb	doc_491521502095_item	2586604	et	3	main
mul	doc_491521502095_item	2586605	et	3	main
palju	doc_491521502095_item	2586606	et	4	main
umbisikulise	doc_491521502095_item	2586618	et	4	main
tegumoe	doc_491521502095_item	2586619	et	3	main
lihtminevikku	doc_491521502095_item	2586620	et	4	main
tehti	doc_491521502095_item	2586622	et	3	main
allkiri	doc_491521502095_item	2586626	et	3	main
allkirja	doc_491521502095_item	2586629	et	4	main
ei	doc_491521502095_item	2586637	et	4	main
lasti	doc_491521502095_item	2586638	et	4	main
midagi	doc_491521502095_item	2586639	et	4	main
vait	doc_491521502095_item	2586644	et	3	main
olema	doc_491521502095_item	2586645	et	4	main
käskiti	doc_491521502095_item	2586647	et	4	main
vait	doc_491521502095_item	2586648	et	3	main
olla	doc_491521502095_item	2586649	et	3	main
avaldus	doc_491521502095_item	2586652	et	4	main
ei	doc_491521502095_item	2586653	et	4	main
korralikult	doc_491521502095_item	2586656	et	4	main
avaldus	doc_491521502095_item	2586658	et	4	main
ei	doc_491521502095_item	2586659	et	4	main
kordamööda	doc_491521502096_item	2586681	et	3	main
2	doc_491521502096_item	2586685	et	2	main
selle	doc_491521502096_item	2586686	et	4	main
pintsaku	doc_491521502096_item	2586687	et	3	main
õmblused	doc_491521502096_item	2586688	et	3	main
käsitsevad	doc_491521502096_item	2586689	et	4	main
kardan	doc_491521502096_item	2586693	et	4	main
pidevalt	doc_491521502096_item	2586713	et	4	main
teadvustama	doc_491521502095_item	2586324	et	3	main
reostamise	doc_491521502095_item	2586326	et	4	main
tulemusi	doc_491521502095_item	2586329	et	4	main
7	doc_491521502095_item	2586330	et	2	main
kasutusjuhendis	doc_491521502095_item	2586331	et	3	main
ii	doc_491521502095_item	2586338	et	4	main
kirjutage	doc_491521502095_item	2586339	et	3	main
sünonüümid	doc_491521502095_item	2586340	et	3	main
4	doc_491521502095_item	2586352	et	2	main
6	doc_491521502095_item	2586364	et	2	main
purunema	doc_491521502095_item	2586371	et	3	main
minema	doc_491521502095_item	2586385	et	3	main
toidujäätmed	doc_491521502095_item	2586387	et	3	main
5	doc_491521502095_item	2586390	et	2	main
8	doc_491521502095_item	2586392	et	2	main
rebenema	doc_491521502095_item	2586393	et	3	main
5	doc_491521502095_item	2586396	et	2	main
haisema	doc_491521502095_item	2586397	et	4	main
7	doc_491521502095_item	2586398	et	2	main
vaas	doc_491521502095_item	2586399	et	3	main
8	doc_491521502095_item	2586402	et	2	main
3	doc_491521502095_item	2586404	et	2	main
iv	doc_491521502095_item	2586405	et	4	main
1	doc_491521502095_item	2586411	et	2	main
kreeme	doc_491521502095_item	2586412	et	3	main
mida	doc_491521502095_item	2586413	et	4	main
toodetakse	doc_491521502095_item	2586414	et	3	main
eestis	doc_491521502095_item	2586415	et	3	main
kasutatakse	doc_491521502095_item	2586416	et	3	main
palju	doc_491521502095_item	2586417	et	4	main
eestis	doc_491521502095_item	2586418	et	3	main
toodetavaid	doc_491521502095_item	2586419	et	4	main
kreeme	doc_491521502095_item	2586420	et	3	main
4	doc_491521502095_item	2586378	et	2	main
3	doc_491521502095_item	2586381	et	2	main
õmblused	doc_491521502095_item	2586382	et	3	main
rikki	doc_491521502095_item	2586384	et	3	main
moodustage	doc_491521502095_item	2586406	et	3	main
tav-kesksõnaga	doc_491521502095_item	2586409	et	3	main
küsi	doc_491521502095_item	2586424	et	4	main
lisa	doc_491521502095_item	2586436	et	4	main
pesupulbrit	doc_491521502095_item	2586437	et	3	main
vette	doc_491521502095_item	2586438	et	3	main
mis	doc_491521502095_item	2586439	et	4	main
ei	doc_491521502095_item	2586451	et	4	main
pestav	doc_491521502095_item	2586455	et	4	main
kulu	doc_491521502095_item	2586459	et	4	main
keemiavahenditel	doc_491521502095_item	2586474	et	3	main
võib	doc_491521502095_item	2586475	et	3	main
püsikliendid	doc_491521502095_item	2586491	et	3	main
õigust	doc_491521502095_item	2586493	et	4	main
printsiipid	doc_491521502095_item	2586508	et	4	main
не	doc_491521502095_item	2586513	et	2	main
süsteem	doc_491521502095_item	2586517	et	3	main
välja	doc_491521502095_item	2586521	et	4	main
фирма	doc_491521502095_item	2586524	et	2	main
meelitab	doc_491521502095_item	2586529	et	3	main
kingitustega	doc_491521502095_item	2586531	et	4	main
antonüümid	doc_491521502095_item	2586534	et	3	main
andekas	doc_491521502095_item	2586545	et	4	main
3	doc_491521502095_item	2586576	et	2	main
endale	doc_491521502095_item	2586578	et	4	main
seega	doc_491521502095_item	2586582	et	4	main
raha	doc_491521502095_item	2586584	et	4	main
kokku	doc_491521502095_item	2586585	et	3	main
hoidma	doc_491521502095_item	2586586	et	3	main
veel	doc_491521502095_item	2586596	et	4	main
õppida	doc_491521502095_item	2586607	et	3	main
kuigi	doc_491521502095_item	2586613	et	3	main
palju	doc_491521502095_item	2586422	et	4	main
neiult	doc_491521502095_item	2586434	et	4	main
3	doc_491521502095_item	2586435	et	2	main
mida	doc_491521502095_item	2586448	et	4	main
pestakse	doc_491521502095_item	2586449	et	3	main
käsitsi	doc_491521502095_item	2586450	et	3	main
nii	doc_491521502095_item	2586460	et	3	main
kiiresti	doc_491521502095_item	2586461	et	3	main
5	doc_491521502095_item	2586462	et	2	main
paljudel	doc_491521502095_item	2586463	et	3	main
keemiavahenditel	doc_491521502095_item	2586464	et	3	main
võib	doc_491521502095_item	2586465	et	3	main
olla	doc_491521502095_item	2586466	et	3	main
toime	doc_491521502095_item	2586467	et	4	main
mis	doc_491521502095_item	2586468	et	4	main
tervist	doc_491521502095_item	2586470	et	4	main
kahjustab	doc_491521502095_item	2586469	et	3	main
paljudel	doc_491521502095_item	2586471	et	3	main
tervist	doc_491521502095_item	2586472	et	4	main
kahjustavatel	doc_491521502095_item	2586473	et	4	main
мусора	doc_491521502095_item	2586512	et	2	main
ole	doc_491521502095_item	2586519	et	4	main
veel	doc_491521502095_item	2586520	et	4	main
töödeldud	doc_491521502095_item	2586522	et	4	main
привлекает	doc_491521502095_item	2586525	et	2	main
firma	doc_491521502095_item	2586528	et	4	main
kliendi	doc_491521502095_item	2586530	et	3	main
vi	doc_491521502095_item	2586532	et	4	main
moodustage	doc_491521502095_item	2586533	et	3	main
õnnetu	doc_491521502095_item	2586537	et	4	main
andetu	doc_491521502095_item	2586546	et	4	main
annetu	doc_491521502095_item	2586547	et	4	main
5	doc_491521502095_item	2586548	et	2	main
vii	doc_491521502095_item	2586551	et	4	main
lünkadesse	doc_491521502095_item	2586553	et	3	main
osta	doc_491521502095_item	2586579	et	4	main
tööd	doc_491521502095_item	2586592	et	4	main
lisaks	doc_491521502095_item	2586593	et	4	main
trennis	doc_491521502095_item	2586597	et	3	main
kõrgkooli	doc_491521502095_item	2586600	et	4	main
muidu	doc_491521502095_item	2586609	et	3	main
juhul	doc_491521502095_item	2586611	et	3	main
kui	doc_491521502095_item	2586612	et	3	main
nõudma	doc_491521502095_item	2586625	et	3	main
müüjal	doc_491521502095_item	2586636	et	4	main
3	doc_491521502095_item	2586641	et	2	main
lugema	doc_491521502095_item	2586655	et	4	main
kisuvad	doc_491521502096_item	2586690	et	3	main
et	doc_491521502096_item	2586694	et	3	main
plaani	doc_491521502096_item	2586696	et	4	main
raske	doc_491521502096_item	2586698	et	4	main
liigitada	doc_491521502096_item	2586699	et	3	main
sisaldada	doc_491521502096_item	2586700	et	3	main
teostada	doc_491521502096_item	2586701	et	3	main
5	doc_491521502096_item	2586709	et	2	main
kui	doc_491521502096_item	2586710	et	3	main
inimene	doc_491521502096_item	2586711	et	3	main
tagajärgi	doc_491521502096_item	2586729	et	4	main
kohad	doc_491521502096_item	2586738	et	4	main
2	doc_491521502096_item	2586746	et	2	main
aru	doc_491521502096_item	2586749	et	4	main
õige	doc_491521502096_item	2586758	et	4	main
purunema	doc_491521502096_item	2586777	et	3	main
juust	doc_491521502096_item	2586780	et	4	main
venima	doc_491521502096_item	2586786	et	3	main
4	doc_491521502096_item	2586793	et	2	main
eestis	doc_491521502096_item	2586821	et	3	main
palju	doc_491521502096_item	2586828	et	4	main
neiult	doc_491521502096_item	2586832	et	4	main
neiult	doc_491521502096_item	2586843	et	4	main
lisa	doc_491521502096_item	2586845	et	4	main
pesupulbrit	doc_491521502096_item	2586846	et	3	main
vette	doc_491521502096_item	2586847	et	3	main
mis	doc_491521502096_item	2586848	et	4	main
4	doc_491521502096_item	2586856	et	2	main
pesu	doc_491521502096_item	2586857	et	4	main
ei	doc_491521502096_item	2586861	et	4	main
nii	doc_491521502096_item	2586863	et	3	main
kiiresti	doc_491521502096_item	2586864	et	3	main
pesu	doc_491521502096_item	2586865	et	4	main
kiresti	doc_491521502096_item	2586871	et	4	main
olla	doc_491521502096_item	2586876	et	3	main
tervist	doc_491521502096_item	2586880	et	4	main
kahjustatav	doc_491521502096_item	2586882	et	4	main
toime	doc_491521502096_item	2586883	et	4	main
on	doc_491521502096_item	2586884	et	4	main
paljudel	doc_491521502096_item	2586885	et	3	main
keemiavahenditel	doc_491521502096_item	2586886	et	3	main
paljudel	doc_491521502096_item	2586887	et	3	main
keemiavahendinel	doc_491521502096_item	2586888	et	4	main
on	doc_491521502096_item	2586889	et	4	main
v	doc_491521502096_item	2586893	et	4	main
keelde	doc_491521502096_item	2586896	et	4	main
клиенты	doc_491521502096_item	2586899	et	2	main
покупать	doc_491521502096_item	2586902	et	2	main
рассрочку	doc_491521502096_item	2586905	et	2	main
2	doc_491521502096_item	2586910	et	2	main
торговли	doc_491521502096_item	2586914	et	2	main
мусора	doc_491521502096_item	2586924	et	2	main
soorteerimis	doc_491521502096_item	2586928	et	4	main
4	doc_491521502096_item	2586935	et	2	main
4	doc_491521502095_item	2586523	et	2	main
1	doc_491521502095_item	2586535	et	2	main
haritud	doc_491521502095_item	2586539	et	4	main
loetav	doc_491521502095_item	2586542	et	4	main
kavatsen	doc_491521502095_item	2586558	et	3	main
eesti	doc_491521502095_item	2586559	et	4	main
keele	doc_491521502095_item	2586560	et	4	main
õpinguid	doc_491521502095_item	2586561	et	3	main
jätkata	doc_491521502095_item	2586562	et	4	main
juhul	doc_491521502095_item	2586563	et	3	main
kui	doc_491521502095_item	2586564	et	3	main
mul	doc_491521502095_item	2586565	et	3	main
on	doc_491521502095_item	2586566	et	4	main
aega	doc_491521502095_item	2586567	et	4	main
2	doc_491521502095_item	2586568	et	2	main
pean	doc_491521502095_item	2586569	et	4	main
kiiresti	doc_491521502095_item	2586570	et	3	main
minema	doc_491521502095_item	2586571	et	3	main
hakkama	doc_491521502095_item	2586572	et	3	main
tahan	doc_491521502095_item	2586577	et	3	main
päeva	doc_491521502095_item	2586591	et	4	main
5	doc_491521502095_item	2586598	et	2	main
lisaks	doc_491521502095_item	2586614	et	4	main
sellele	doc_491521502095_item	2586615	et	4	main
meie	doc_491521502095_item	2586624	et	4	main
mina	doc_491521502095_item	2586642	et	4	main
mul	doc_491521502095_item	2586646	et	3	main
4	doc_491521502095_item	2586650	et	2	main
minu	doc_491521502095_item	2586651	et	3	main
loeti	doc_491521502095_item	2586660	et	3	main
korralikult	doc_491521502095_item	2586661	et	4	main
seda	doc_491521502096_item	2586695	et	3	main
on	doc_491521502096_item	2586697	et	4	main
4	doc_491521502096_item	2586702	et	2	main
varsti	doc_491521502096_item	2586703	et	3	main
kehtestatakse	doc_491521502096_item	2586704	et	3	main
kahjustatakse	doc_491521502096_item	2586705	et	3	main
omandatakse	doc_491521502096_item	2586706	et	3	main
uued	doc_491521502096_item	2586707	et	3	main
sisekorraeeskirjad	doc_491521502096_item	2586708	et	3	main
kogeb	doc_491521502096_item	2586712	et	3	main
tema	doc_491521502096_item	2586716	et	4	main
enesehinnang	doc_491521502096_item	2586718	et	3	main
langeb	doc_491521502096_item	2586720	et	3	main
peaksid	doc_491521502096_item	2586723	et	4	main
reostamise	doc_491521502096_item	2586727	et	4	main
järeldusi	doc_491521502096_item	2586728	et	4	main
ii	doc_491521502096_item	2586739	et	4	main
hülgama	doc_491521502096_item	2586743	et	3	main
ära	doc_491521502096_item	2586745	et	4	main
poole	doc_491521502096_item	2586754	et	4	main
uudisimulik	doc_491521502096_item	2586755	et	4	main
4	doc_491521502096_item	2586756	et	2	main
tuleb	doc_491521502096_item	2586757	et	3	main
on	doc_491521502096_item	2586767	et	4	main
ükskõik	doc_491521502096_item	2586768	et	3	main
6	doc_491521502096_item	2586769	et	2	main
mesikäpp	doc_491521502096_item	2586770	et	3	main
iii	doc_491521502096_item	2586772	et	4	main
ühendage	doc_491521502096_item	2586773	et	3	main
tegusõna	doc_491521502096_item	2586774	et	4	main
ja	doc_491521502096_item	2586775	et	3	main
7	doc_491521502096_item	2586778	et	2	main
1	doc_491521502096_item	2586782	et	2	main
välja	doc_491521502096_item	2586785	et	4	main
3	doc_491521502096_item	2586787	et	2	main
õmblused	doc_491521502096_item	2586789	et	3	main
rikki	doc_491521502096_item	2586790	et	3	main
2	doc_491521502096_item	2586792	et	2	main
toidujäätmed	doc_491521502096_item	2586794	et	3	main
1	doc_491521502095_item	2586623	et	2	main
meilt	doc_491521502095_item	2586627	et	3	main
2	doc_491521502095_item	2586630	et	2	main
ei	doc_491521502095_item	2586632	et	4	main
laskma	doc_491521502095_item	2586633	et	3	main
midagi	doc_491521502095_item	2586634	et	4	main
ütlema	doc_491521502095_item	2586635	et	3	main
öelda	doc_491521502095_item	2586640	et	4	main
läbi	doc_491521502095_item	2586654	et	4	main
minu	doc_491521502095_item	2586657	et	3	main
ostja	doc_491521502095_item	2586664	et	4	main
pakkuma	doc_491521502095_item	2586665	et	3	main
kaks	doc_491521502095_item	2586666	et	3	main
võimalus	doc_491521502095_item	2586667	et	3	main
ostjale	doc_491521502095_item	2586668	et	4	main
pakkuti	doc_491521502095_item	2586669	et	4	main
kaks	doc_491521502095_item	2586670	et	3	main
võimalust	doc_491521502095_item	2586671	et	3	main
kontrolltöö	doc_491521502096_item	2586672	et	4	main
i	doc_491521502096_item	2586673	et	4	main
valige	doc_491521502096_item	2586674	et	3	main
õige	doc_491521502096_item	2586675	et	4	main
sõna	doc_491521502096_item	2586676	et	4	main
1	doc_491521502096_item	2586677	et	2	main
suurt	doc_491521502096_item	2586678	et	3	main
koera	doc_491521502096_item	2586679	et	4	main
peab	doc_491521502096_item	2586680	et	4	main
nõuti	doc_491521502095_item	2586628	et	3	main
müüja	doc_491521502095_item	2586631	et	4	main
käskima	doc_491521502095_item	2586643	et	4	main
läbi	doc_491521502095_item	2586662	et	4	main
5	doc_491521502095_item	2586663	et	2	main
luituvad	doc_491521502096_item	2586691	et	4	main
ebaõnnestumisi	doc_491521502096_item	2586714	et	3	main
endale	doc_491521502096_item	2586724	et	4	main
mõned	doc_491521502096_item	2586734	et	3	main
kehtivad	doc_491521502096_item	2586737	et	4	main
sünonüümid	doc_491521502096_item	2586741	et	3	main
maijusmokk	doc_491521502096_item	2586771	et	4	main
palju	doc_491521502096_item	2586823	et	4	main
kasutatakse	doc_491521502096_item	2586827	et	3	main
2	doc_491521502096_item	2586829	et	2	main
küsi	doc_491521502096_item	2586830	et	4	main
neiu	doc_491521502096_item	2586838	et	4	main
küsi	doc_491521502096_item	2586839	et	4	main
seda	doc_491521502096_item	2586840	et	3	main
pestakse	doc_491521502096_item	2586859	et	3	main
pestav	doc_491521502096_item	2586866	et	4	main
käsitsi	doc_491521502096_item	2586867	et	3	main
võib	doc_491521502096_item	2586875	et	3	main
kahjustab	doc_491521502096_item	2586879	et	3	main
toime	doc_491521502096_item	2586892	et	4	main
kaupa	doc_491521502096_item	2586909	et	4	main
vabaturu	doc_491521502096_item	2586919	et	3	main
переработки	doc_491521502096_item	2586923	et	2	main
ole	doc_491521502096_item	2586931	et	4	main
veel	doc_491521502096_item	2586932	et	4	main
привлекает	doc_491521502096_item	2586937	et	2	main
firma	doc_491521502096_item	2586940	et	4	main
oodatud	doc_491521502096_item	2586961	et	4	main
õiged	doc_491521502096_item	2586966	et	3	main
kui	doc_491521502096_item	2586976	et	3	main
aega	doc_491521502096_item	2586979	et	4	main
3	doc_491521502096_item	2586988	et	2	main
uue	doc_491521502096_item	2586992	et	3	main
raha	doc_491521502096_item	2586996	et	4	main
ilmtingimata	doc_491521502096_item	2586682	et	3	main
omapead	doc_491521502096_item	2586683	et	3	main
õpetama	doc_491521502096_item	2586684	et	3	main
3	doc_491521502096_item	2586692	et	2	main
siis	doc_491521502096_item	2586715	et	3	main
koormus	doc_491521502096_item	2586719	et	4	main
isiksus	doc_491521502096_item	2586717	et	3	main
6	doc_491521502096_item	2586721	et	2	main
tulemusi	doc_491521502096_item	2586730	et	4	main
7	doc_491521502096_item	2586731	et	2	main
kasutusjuhendis	doc_491521502096_item	2586732	et	3	main
1	doc_491521502096_item	2586742	et	2	main
saama	doc_491521502096_item	2586748	et	4	main
3	doc_491521502096_item	2586750	et	2	main
topib	doc_491521502096_item	2586751	et	3	main
nina	doc_491521502096_item	2586752	et	4	main
igale	doc_491521502096_item	2586753	et	3	main
tuleb	doc_491521502096_item	2586761	et	3	main
lõi	doc_491521502096_item	2586763	et	4	main
kõigele	doc_491521502096_item	2586764	et	4	main
käega	doc_491521502096_item	2586765	et	3	main
tal	doc_491521502096_item	2586766	et	3	main
ese	doc_491521502096_item	2586776	et	3	main
hallitama	doc_491521502096_item	2586781	et	3	main
õmblusmasin	doc_491521502096_item	2586784	et	3	main
3	doc_491521502096_item	2586788	et	2	main
minema	doc_491521502096_item	2586791	et	3	main
määrima	doc_491521502096_item	2586795	et	3	main
kasutatakse	doc_491521502096_item	2586822	et	3	main
müüv	doc_491521502096_item	2586837	et	4	main
müüvalt	doc_491521502096_item	2586842	et	4	main
3	doc_491521502096_item	2586844	et	2	main
pesupulber	doc_491521502096_item	2586855	et	3	main
ei	doc_491521502096_item	2586868	et	4	main
нарушает	doc_491521502096_item	2586912	et	2	main
рынка	doc_491521502096_item	2586916	et	2	main
система	doc_491521502096_item	2586922	et	2	main
prügi	doc_491521502096_item	2586927	et	4	main
süsteem	doc_491521502096_item	2586929	et	3	main
ei	doc_491521502096_item	2586930	et	4	main
фирма	doc_491521502096_item	2586936	et	2	main
ebaharitud	doc_491521502096_item	2586952	et	4	main
loetav	doc_491521502096_item	2586955	et	4	main
ootamatu	doc_491521502096_item	2586962	et	4	main
sidesõnad	doc_491521502096_item	2586967	et	3	main
eesti	doc_491521502096_item	2586971	et	4	main
õpinguid	doc_491521502096_item	2586973	et	3	main
juhul	doc_491521502096_item	2586975	et	3	main
2	doc_491521502096_item	2586980	et	2	main
kiiresti	doc_491521502096_item	2586982	et	3	main
minema	doc_491521502096_item	2586983	et	3	main
hakkama	doc_491521502096_item	2586984	et	3	main
muidu	doc_491521502096_item	2586985	et	3	main
jään	doc_491521502096_item	2586986	et	3	main
tahan	doc_491521502096_item	2586989	et	3	main
kokku	doc_491521502096_item	2586997	et	3	main
tehti	doc_491521502096_item	2587034	et	3	main
2	doc_491521502096_item	2587042	et	2	main
ei	doc_491521502096_item	2587044	et	4	main
midagi	doc_491521502096_item	2587051	et	4	main
mul	doc_491521502096_item	2587058	et	3	main
kontrolltöö	doc_491521502097_item	2587084	et	4	main
i	doc_491521502097_item	2587085	et	4	main
valige	doc_491521502097_item	2587086	et	3	main
kordamööda	doc_491521502097_item	2587093	et	3	main
ilmtingimata	doc_491521502097_item	2587094	et	3	main
selle	doc_491521502097_item	2587098	et	4	main
õmblused	doc_491521502097_item	2587100	et	3	main
omandatakse	doc_491521502097_item	2587118	et	3	main
kui	doc_491521502097_item	2587122	et	3	main
ebaõnnestumisi	doc_491521502097_item	2587126	et	3	main
siis	doc_491521502097_item	2587127	et	3	main
isiksus	doc_491521502097_item	2587129	et	3	main
enesehinnang	doc_491521502097_item	2587130	et	3	main
langeb	doc_491521502097_item	2587132	et	3	main
endale	doc_491521502097_item	2587136	et	4	main
tagajärgi	doc_491521502097_item	2587141	et	4	main
tulema	doc_491521502097_item	2587174	et	4	main
kõigele	doc_491521502097_item	2587177	et	4	main
mesikäpp	doc_491521502097_item	2587181	et	3	main
juust	doc_491521502097_item	2587191	et	4	main
õmblusmasin	doc_491521502097_item	2587195	et	3	main
3	doc_491521502097_item	2587199	et	2	main
toidujäätmed	doc_491521502097_item	2587205	et	3	main
näokreem	doc_491521502097_item	2587213	et	3	main
7	doc_491521502097_item	2587216	et	2	main
5	doc_491521502097_item	2587219	et	2	main
inimesed	doc_491521502096_item	2586722	et	3	main
teadvustama	doc_491521502096_item	2586725	et	3	main
keskkonna	doc_491521502096_item	2586726	et	3	main
on	doc_491521502096_item	2586733	et	4	main
üleolevad	doc_491521502096_item	2586735	et	3	main
eksitavad	doc_491521502096_item	2586736	et	4	main
kirjutage	doc_491521502096_item	2586740	et	3	main
viskama	doc_491521502096_item	2586744	et	3	main
taipama	doc_491521502096_item	2586747	et	3	main
pea	doc_491521502096_item	2586759	et	4	main
varsti	doc_491521502096_item	2586760	et	3	main
5	doc_491521502096_item	2586762	et	2	main
1	doc_491521502096_item	2586779	et	2	main
2	doc_491521502096_item	2586783	et	2	main
6	doc_491521502096_item	2586796	et	2	main
5	doc_491521502096_item	2586797	et	2	main
kreemituub	doc_491521502096_item	2586798	et	4	main
rebenema	doc_491521502096_item	2586799	et	3	main
8	doc_491521502096_item	2586800	et	2	main
6	doc_491521502096_item	2586801	et	2	main
näokreem	doc_491521502096_item	2586802	et	3	main
haisema	doc_491521502096_item	2586803	et	4	main
4	doc_491521502096_item	2586804	et	2	main
7	doc_491521502096_item	2586805	et	2	main
vaas	doc_491521502096_item	2586806	et	3	main
5	doc_491521502096_item	2586808	et	2	main
8	doc_491521502096_item	2586809	et	2	main
pigistama	doc_491521502096_item	2586807	et	3	main
teksad	doc_491521502096_item	2586810	et	4	main
iv	doc_491521502096_item	2586811	et	4	main
moodustage	doc_491521502096_item	2586812	et	3	main
v-	doc_491521502096_item	2586813	et	4	main
ja	doc_491521502096_item	2586814	et	3	main
tav-kesksõnaga	doc_491521502096_item	2586815	et	3	main
laused	doc_491521502096_item	2586816	et	3	main
1	doc_491521502096_item	2586817	et	2	main
kreeme	doc_491521502096_item	2586818	et	3	main
mida	doc_491521502096_item	2586819	et	4	main
toodetakse	doc_491521502096_item	2586820	et	3	main
eestis	doc_491521502096_item	2586825	et	3	main
kreeme	doc_491521502096_item	2586826	et	3	main
on	doc_491521502096_item	2586849	et	4	main
pesumasinas	doc_491521502096_item	2586850	et	3	main
mida	doc_491521502096_item	2586858	et	4	main
kulu	doc_491521502096_item	2586869	et	4	main
nii	doc_491521502096_item	2586870	et	3	main
mis	doc_491521502096_item	2586878	et	4	main
tervist	doc_491521502096_item	2586881	et	4	main
tervist	doc_491521502096_item	2586890	et	4	main
kahjustatav	doc_491521502096_item	2586891	et	4	main
eesti	doc_491521502096_item	2586895	et	4	main
постоянные	doc_491521502096_item	2586898	et	2	main
право	doc_491521502096_item	2586901	et	2	main
в	doc_491521502096_item	2586904	et	2	main
püsiklientid	doc_491521502096_item	2586906	et	4	main
saavad	doc_491521502096_item	2586907	et	4	main
osta	doc_491521502096_item	2586908	et	4	main
toodetavaid	doc_491521502096_item	2586824	et	4	main
seda	doc_491521502096_item	2586831	et	3	main
kes	doc_491521502096_item	2586833	et	4	main
müüb	doc_491521502096_item	2586834	et	3	main
vitamiine	doc_491521502096_item	2586835	et	3	main
vitamiine	doc_491521502096_item	2586836	et	3	main
viitamiine	doc_491521502096_item	2586841	et	3	main
lisa	doc_491521502096_item	2586851	et	4	main
vette	doc_491521502096_item	2586852	et	3	main
pesumasinas	doc_491521502096_item	2586853	et	3	main
olev	doc_491521502096_item	2586854	et	4	main
käsitsi	doc_491521502096_item	2586860	et	3	main
kulu	doc_491521502096_item	2586862	et	4	main
5	doc_491521502096_item	2586872	et	2	main
paljudel	doc_491521502096_item	2586873	et	3	main
keemiavahenditel	doc_491521502096_item	2586874	et	3	main
toime	doc_491521502096_item	2586877	et	4	main
tõlkige	doc_491521502096_item	2586894	et	3	main
1	doc_491521502096_item	2586897	et	2	main
имеют	doc_491521502096_item	2586900	et	2	main
товар	doc_491521502096_item	2586903	et	2	main
это	doc_491521502096_item	2586911	et	2	main
свободного	doc_491521502096_item	2586915	et	2	main
tähistab	doc_491521502096_item	2586918	et	3	main
süsteemi	doc_491521502096_item	2586920	et	4	main
не	doc_491521502096_item	2586925	et	2	main
läbi	doc_491521502096_item	2586933	et	4	main
клиентов	doc_491521502096_item	2586938	et	2	main
kliente	doc_491521502096_item	2586942	et	3	main
vi	doc_491521502096_item	2586944	et	4	main
1	doc_491521502096_item	2586947	et	2	main
õnnelik	doc_491521502096_item	2586948	et	3	main
õnnetu	doc_491521502096_item	2586949	et	4	main
2	doc_491521502096_item	2586950	et	2	main
haritamatu	doc_491521502096_item	2586953	et	4	main
loetamatu	doc_491521502096_item	2586956	et	4	main
andetu	doc_491521502096_item	2586959	et	4	main
5	doc_491521502096_item	2586960	et	2	main
vii	doc_491521502096_item	2586963	et	4	main
keele	doc_491521502096_item	2586972	et	4	main
on	doc_491521502096_item	2586978	et	4	main
endale	doc_491521502096_item	2586990	et	4	main
kleidi	doc_491521502096_item	2586993	et	3	main
pean	doc_491521502096_item	2586995	et	4	main
juhul	doc_491521502096_item	2587023	et	3	main
kui	doc_491521502096_item	2587024	et	3	main
lisaks	doc_491521502096_item	2587026	et	4	main
viii	doc_491521502096_item	2587028	et	4	main
kasutage	doc_491521502096_item	2587029	et	3	main
nõuti	doc_491521502096_item	2587040	et	3	main
lastud	doc_491521502096_item	2587050	et	4	main
olema	doc_491521502096_item	2587057	et	4	main
4	doc_491521502096_item	2587062	et	2	main
kaks	doc_491521502096_item	2587082	et	3	main
suurt	doc_491521502097_item	2587090	et	3	main
koera	doc_491521502097_item	2587091	et	4	main
kisuvad	doc_491521502097_item	2587102	et	3	main
kardan	doc_491521502097_item	2587105	et	4	main
plaani	doc_491521502097_item	2587108	et	4	main
on	doc_491521502097_item	2587109	et	4	main
принципы	doc_491521502096_item	2586913	et	2	main
see	doc_491521502096_item	2586917	et	3	main
3	doc_491521502096_item	2586921	et	2	main
разработана	doc_491521502096_item	2586926	et	2	main
töödatud	doc_491521502096_item	2586934	et	4	main
haritud	doc_491521502096_item	2586951	et	4	main
3	doc_491521502096_item	2586954	et	2	main
4	doc_491521502096_item	2586957	et	2	main
andekas	doc_491521502096_item	2586958	et	4	main
lünkadesse	doc_491521502096_item	2586965	et	3	main
1	doc_491521502096_item	2586968	et	2	main
kavatsen	doc_491521502096_item	2586970	et	3	main
jätkata	doc_491521502096_item	2586974	et	4	main
seega	doc_491521502096_item	2586994	et	4	main
4	doc_491521502096_item	2586999	et	2	main
ta	doc_491521502096_item	2587000	et	4	main
teeb	doc_491521502096_item	2587001	et	3	main
terve	doc_491521502096_item	2587002	et	4	main
päeva	doc_491521502096_item	2587003	et	4	main
tööd	doc_491521502096_item	2587004	et	4	main
lisaks	doc_491521502096_item	2587005	et	4	main
sellele	doc_491521502096_item	2587006	et	4	main
käib	doc_491521502096_item	2587007	et	3	main
veel	doc_491521502096_item	2587008	et	4	main
trennis	doc_491521502096_item	2587009	et	3	main
5	doc_491521502096_item	2587010	et	2	main
tahan	doc_491521502096_item	2587011	et	3	main
kõrgkooli	doc_491521502096_item	2587012	et	4	main
sisse	doc_491521502096_item	2587013	et	4	main
saada	doc_491521502096_item	2587014	et	4	main
kuigi	doc_491521502096_item	2587015	et	3	main
tuleb	doc_491521502096_item	2587016	et	3	main
mul	doc_491521502096_item	2587017	et	3	main
palju	doc_491521502096_item	2587018	et	4	main
õppida	doc_491521502096_item	2587019	et	3	main
sõnad	doc_491521502096_item	2587020	et	4	main
muidu	doc_491521502096_item	2587021	et	3	main
kuigi	doc_491521502096_item	2587025	et	3	main
sellele	doc_491521502096_item	2587027	et	4	main
mida	doc_491521502096_item	2587033	et	4	main
1	doc_491521502096_item	2587035	et	2	main
meie	doc_491521502096_item	2587036	et	4	main
nõudma	doc_491521502096_item	2587037	et	3	main
allkiri	doc_491521502096_item	2587038	et	3	main
meilt	doc_491521502096_item	2587039	et	3	main
müüja	doc_491521502096_item	2587043	et	4	main
laskma	doc_491521502096_item	2587045	et	3	main
midagi	doc_491521502096_item	2587046	et	4	main
ütlema	doc_491521502096_item	2587047	et	3	main
müüjal	doc_491521502096_item	2587048	et	4	main
öelda	doc_491521502096_item	2587052	et	4	main
käsitsi	doc_491521502096_item	2587059	et	3	main
sõna	doc_491521502097_item	2587088	et	4	main
1	doc_491521502097_item	2587089	et	2	main
2	doc_491521502097_item	2587097	et	2	main
käsitsevad	doc_491521502097_item	2587101	et	4	main
3	doc_491521502097_item	2587104	et	2	main
seda	doc_491521502097_item	2587107	et	3	main
sisekorraeeskirjad	doc_491521502097_item	2587120	et	3	main
inimene	doc_491521502097_item	2587123	et	3	main
koormus	doc_491521502097_item	2587131	et	4	main
reostamise	doc_491521502097_item	2587139	et	4	main
kasutusjuhendis	doc_491521502097_item	2587144	et	3	main
подарками	doc_491521502096_item	2586939	et	2	main
meelitab	doc_491521502096_item	2586941	et	3	main
kingitustega	doc_491521502096_item	2586943	et	4	main
moodustage	doc_491521502096_item	2586945	et	3	main
antonüümid	doc_491521502096_item	2586946	et	3	main
pange	doc_491521502096_item	2586964	et	4	main
ma	doc_491521502096_item	2586969	et	3	main
mul	doc_491521502096_item	2586977	et	3	main
pean	doc_491521502096_item	2586981	et	4	main
hiljaks	doc_491521502096_item	2586987	et	3	main
osta	doc_491521502096_item	2586991	et	4	main
hoidma	doc_491521502096_item	2586998	et	3	main
seega	doc_491521502096_item	2587022	et	4	main
lihtminevikku	doc_491521502096_item	2587032	et	4	main
allkirja	doc_491521502096_item	2587041	et	4	main
3	doc_491521502096_item	2587053	et	2	main
mina	doc_491521502096_item	2587054	et	4	main
vait	doc_491521502096_item	2587060	et	3	main
pakkuti	doc_491521502096_item	2587081	et	4	main
võimalust	doc_491521502096_item	2587083	et	3	main
peab	doc_491521502097_item	2587092	et	4	main
omapead	doc_491521502097_item	2587095	et	3	main
pintsaku	doc_491521502097_item	2587099	et	3	main
luituvad	doc_491521502097_item	2587103	et	4	main
et	doc_491521502097_item	2587106	et	3	main
kahjustatakse	doc_491521502097_item	2587117	et	3	main
pidevalt	doc_491521502097_item	2587125	et	4	main
inimesed	doc_491521502097_item	2587134	et	3	main
keskkonna	doc_491521502097_item	2587138	et	3	main
kohad	doc_491521502097_item	2587150	et	4	main
5	doc_491521502097_item	2587175	et	2	main
1	doc_491521502097_item	2587193	et	2	main
välja	doc_491521502097_item	2587196	et	4	main
õmblused	doc_491521502097_item	2587200	et	3	main
minema	doc_491521502097_item	2587202	et	3	main
4	doc_491521502097_item	2587204	et	2	main
määrima	doc_491521502097_item	2587206	et	3	main
8	doc_491521502097_item	2587211	et	2	main
vaas	doc_491521502097_item	2587217	et	3	main
teksad	doc_491521502097_item	2587221	et	4	main
iv	doc_491521502097_item	2587222	et	4	main
moodustage	doc_491521502097_item	2587223	et	3	main
v-	doc_491521502097_item	2587224	et	4	main
ja	doc_491521502097_item	2587225	et	3	main
laused	doc_491521502097_item	2587227	et	3	main
toodav	doc_491521502097_item	2587235	et	4	main
müüb	doc_491521502097_item	2587248	et	3	main
müüdav	doc_491521502097_item	2587253	et	4	main
lisatav	doc_491521502097_item	2587264	et	4	main
pesupulber	doc_491521502097_item	2587266	et	3	main
4	doc_491521502097_item	2587270	et	2	main
ei	doc_491521502097_item	2587275	et	4	main
käsitsi	doc_491521502097_item	2587280	et	3	main
pesu	doc_491521502097_item	2587281	et	4	main
kulu	doc_491521502097_item	2587283	et	4	main
nii	doc_491521502097_item	2587284	et	3	main
olla	doc_491521502097_item	2587293	et	3	main
kahjustab	doc_491521502097_item	2587296	et	3	main
müümise	doc_491521502097_item	2587336	et	4	main
printsiipe	doc_491521502097_item	2587337	et	3	main
переработки	doc_491521502097_item	2587340	et	2	main
клиентов	doc_491521502097_item	2587352	et	2	main
kingitustega	doc_491521502097_item	2587357	et	4	main
1	doc_491521502097_item	2587361	et	2	main
õnnetu	doc_491521502097_item	2587363	et	4	main
pange	doc_491521502097_item	2587377	et	4	main
päeva	doc_491521502097_item	2587416	et	4	main
tööd	doc_491521502097_item	2587417	et	4	main
umbisikulise	doc_491521502096_item	2587030	et	4	main
tegumoe	doc_491521502096_item	2587031	et	3	main
ei	doc_491521502096_item	2587049	et	4	main
käskima	doc_491521502096_item	2587055	et	4	main
vait	doc_491521502096_item	2587056	et	3	main
olla	doc_491521502096_item	2587061	et	3	main
minu	doc_491521502096_item	2587063	et	3	main
avaldus	doc_491521502096_item	2587064	et	4	main
ei	doc_491521502096_item	2587065	et	4	main
läbi	doc_491521502096_item	2587066	et	4	main
lugema	doc_491521502096_item	2587067	et	4	main
korralikult	doc_491521502096_item	2587068	et	4	main
minu	doc_491521502096_item	2587069	et	3	main
avaldust	doc_491521502096_item	2587070	et	4	main
ei	doc_491521502096_item	2587071	et	4	main
loetud	doc_491521502096_item	2587072	et	4	main
korralikult	doc_491521502096_item	2587073	et	4	main
läbi	doc_491521502096_item	2587074	et	4	main
5	doc_491521502096_item	2587075	et	2	main
ostja	doc_491521502096_item	2587076	et	4	main
pakkuma	doc_491521502096_item	2587077	et	3	main
kaks	doc_491521502096_item	2587078	et	3	main
võimalus	doc_491521502096_item	2587079	et	3	main
ostjale	doc_491521502096_item	2587080	et	4	main
õige	doc_491521502097_item	2587087	et	4	main
õpetama	doc_491521502097_item	2587096	et	3	main
raske	doc_491521502097_item	2587110	et	4	main
liigitada	doc_491521502097_item	2587111	et	3	main
sisaldada	doc_491521502097_item	2587112	et	3	main
teostada	doc_491521502097_item	2587113	et	3	main
4	doc_491521502097_item	2587114	et	2	main
varsti	doc_491521502097_item	2587115	et	3	main
kehtestatakse	doc_491521502097_item	2587116	et	3	main
uued	doc_491521502097_item	2587119	et	3	main
5	doc_491521502097_item	2587121	et	2	main
kogeb	doc_491521502097_item	2587124	et	3	main
tema	doc_491521502097_item	2587128	et	4	main
peaksid	doc_491521502097_item	2587135	et	4	main
teadvustama	doc_491521502097_item	2587137	et	3	main
7	doc_491521502097_item	2587143	et	2	main
ii	doc_491521502097_item	2587151	et	4	main
kirjutage	doc_491521502097_item	2587152	et	3	main
õige	doc_491521502097_item	2587170	et	4	main
õigel	doc_491521502097_item	2587172	et	3	main
lõi	doc_491521502097_item	2587176	et	4	main
käega	doc_491521502097_item	2587178	et	3	main
tüütama	doc_491521502097_item	2587179	et	3	main
ühendage	doc_491521502097_item	2587184	et	3	main
tegusõna	doc_491521502097_item	2587185	et	4	main
ja	doc_491521502097_item	2587186	et	3	main
ese	doc_491521502097_item	2587187	et	3	main
purunema	doc_491521502097_item	2587188	et	3	main
7	doc_491521502097_item	2587189	et	2	main
2	doc_491521502097_item	2587194	et	2	main
3	doc_491521502097_item	2587198	et	2	main
6	doc_491521502097_item	2587207	et	2	main
haisema	doc_491521502097_item	2587214	et	4	main
8	doc_491521502097_item	2587220	et	2	main
kasutatakse	doc_491521502097_item	2587233	et	3	main
kreem	doc_491521502097_item	2587237	et	3	main
kreeme	doc_491521502097_item	2587240	et	3	main
2	doc_491521502097_item	2587243	et	2	main
kes	doc_491521502097_item	2587247	et	4	main
pesumasinas	doc_491521502097_item	2587263	et	3	main
pesumasinast	doc_491521502097_item	2587265	et	4	main
lisav	doc_491521502097_item	2587267	et	4	main
pestakse	doc_491521502097_item	2587273	et	3	main
kiiresti	doc_491521502097_item	2587278	et	3	main
ei	doc_491521502097_item	2587282	et	4	main
kiiresti	doc_491521502097_item	2587285	et	3	main
pesev	doc_491521502097_item	2587286	et	4	main
paljudel	doc_491521502097_item	2587290	et	3	main
mis	doc_491521502097_item	2587295	et	4	main
toime	doc_491521502097_item	2587302	et	4	main
3	doc_491521502097_item	2587338	et	2	main
не	doc_491521502097_item	2587342	et	2	main
prügi	doc_491521502097_item	2587344	et	4	main
подарками	doc_491521502097_item	2587353	et	2	main
kliente	doc_491521502097_item	2587356	et	3	main
antonüümid	doc_491521502097_item	2587360	et	3	main
haritud	doc_491521502097_item	2587365	et	4	main
loetav	doc_491521502097_item	2587368	et	4	main
ootamata	doc_491521502097_item	2587375	et	4	main
muidu	doc_491521502097_item	2587434	et	3	main
juhul	doc_491521502097_item	2587436	et	3	main
lisaks	doc_491521502097_item	2587439	et	4	main
mida	doc_491521502097_item	2587446	et	4	main
tehti	doc_491521502097_item	2587447	et	3	main
müüjal	doc_491521502097_item	2587461	et	4	main
olema	doc_491521502097_item	2587470	et	4	main
korralikult	doc_491521502097_item	2587481	et	4	main
minu	doc_491521502097_item	2587482	et	3	main
läbi	doc_491521502097_item	2587487	et	4	main
võimalus	doc_491521502097_item	2587492	et	3	main
2	doc_491521502097_item	2587495	et	2	main
kontrolltöö	doc_491521502098_item	2587497	et	4	main
kordamööda	doc_491521502098_item	2587506	et	3	main
ilmtingimata	doc_491521502098_item	2587507	et	3	main
omapead	doc_491521502098_item	2587508	et	3	main
õpetama	doc_491521502098_item	2587509	et	3	main
kahjustatakse	doc_491521502098_item	2587530	et	3	main
5	doc_491521502098_item	2587534	et	2	main
ebaõnnestumisi	doc_491521502098_item	2587539	et	3	main
tema	doc_491521502098_item	2587541	et	4	main
isiksus	doc_491521502098_item	2587542	et	3	main
6	doc_491521502097_item	2587133	et	2	main
järeldusi	doc_491521502097_item	2587140	et	4	main
tulemusi	doc_491521502097_item	2587142	et	4	main
sünonüümid	doc_491521502097_item	2587153	et	3	main
1	doc_491521502097_item	2587154	et	2	main
hülgama	doc_491521502097_item	2587155	et	3	main
maha	doc_491521502097_item	2587156	et	4	main
jätma	doc_491521502097_item	2587157	et	3	main
2	doc_491521502097_item	2587158	et	2	main
taipama	doc_491521502097_item	2587159	et	3	main
aru	doc_491521502097_item	2587160	et	4	main
saama	doc_491521502097_item	2587161	et	4	main
3	doc_491521502097_item	2587162	et	2	main
topib	doc_491521502097_item	2587163	et	3	main
on	doc_491521502097_item	2587145	et	4	main
mõned	doc_491521502097_item	2587146	et	3	main
üleolevad	doc_491521502097_item	2587147	et	3	main
eksitavad	doc_491521502097_item	2587148	et	4	main
kehtivad	doc_491521502097_item	2587149	et	4	main
nina	doc_491521502097_item	2587164	et	4	main
igale	doc_491521502097_item	2587165	et	3	main
poole	doc_491521502097_item	2587166	et	4	main
segama	doc_491521502097_item	2587167	et	3	main
4	doc_491521502097_item	2587168	et	2	main
tuleb	doc_491521502097_item	2587169	et	3	main
1	doc_491521502097_item	2587190	et	2	main
venima	doc_491521502097_item	2587197	et	3	main
rikki	doc_491521502097_item	2587201	et	3	main
2	doc_491521502097_item	2587203	et	2	main
5	doc_491521502097_item	2587208	et	2	main
rebenema	doc_491521502097_item	2587210	et	3	main
4	doc_491521502097_item	2587215	et	2	main
pigistama	doc_491521502097_item	2587218	et	3	main
mida	doc_491521502097_item	2587230	et	4	main
palju	doc_491521502097_item	2587234	et	4	main
eestis	doc_491521502097_item	2587236	et	3	main
kes	doc_491521502097_item	2587251	et	4	main
vitamiine	doc_491521502097_item	2587256	et	3	main
lisa	doc_491521502097_item	2587258	et	4	main
pesupulbrit	doc_491521502097_item	2587259	et	3	main
vette	doc_491521502097_item	2587260	et	3	main
mis	doc_491521502097_item	2587261	et	4	main
vette	doc_491521502097_item	2587268	et	3	main
pesu	doc_491521502097_item	2587271	et	4	main
nii	doc_491521502097_item	2587277	et	3	main
pesu	doc_491521502097_item	2587288	et	4	main
võib	doc_491521502097_item	2587292	et	3	main
tervist	doc_491521502097_item	2587299	et	4	main
on	doc_491521502097_item	2587321	et	4	main
osta	doc_491521502097_item	2587323	et	4	main
kaupa	doc_491521502097_item	2587324	et	4	main
järelmaksuga	doc_491521502097_item	2587325	et	3	main
2	doc_491521502097_item	2587326	et	2	main
это	doc_491521502097_item	2587327	et	2	main
нарушает	doc_491521502097_item	2587328	et	2	main
принципы	doc_491521502097_item	2587329	et	2	main
торговли	doc_491521502097_item	2587330	et	2	main
свободного	doc_491521502097_item	2587331	et	2	main
рынка	doc_491521502097_item	2587332	et	2	main
see	doc_491521502097_item	2587333	et	3	main
rikub	doc_491521502097_item	2587334	et	3	main
kehtestatud	doc_491521502097_item	2587348	et	4	main
4	doc_491521502097_item	2587349	et	2	main
фирма	doc_491521502097_item	2587350	et	2	main
привлекает	doc_491521502097_item	2587351	et	2	main
veetleb	doc_491521502097_item	2587355	et	3	main
andekas	doc_491521502097_item	2587371	et	4	main
andetu	doc_491521502097_item	2587372	et	4	main
vii	doc_491521502097_item	2587376	et	4	main
õiged	doc_491521502097_item	2587379	et	3	main
lisaks	doc_491521502097_item	2587418	et	4	main
veel	doc_491521502097_item	2587421	et	4	main
kõrgkooli	doc_491521502097_item	2587425	et	4	main
sõnad	doc_491521502097_item	2587433	et	4	main
nõuti	doc_491521502097_item	2587453	et	3	main
ei	doc_491521502097_item	2587462	et	4	main
lastud	doc_491521502097_item	2587463	et	4	main
vait	doc_491521502097_item	2587469	et	3	main
olla	doc_491521502097_item	2587474	et	3	main
avaldust	doc_491521502097_item	2587483	et	4	main
ei	doc_491521502097_item	2587484	et	4	main
kaks	doc_491521502097_item	2587491	et	3	main
pakuti	doc_491521502097_item	2587494	et	3	main
i	doc_491521502098_item	2587498	et	4	main
valige	doc_491521502098_item	2587499	et	3	main
õige	doc_491521502098_item	2587500	et	4	main
õmblused	doc_491521502098_item	2587513	et	3	main
käsitsevad	doc_491521502098_item	2587514	et	4	main
kehtestatakse	doc_491521502098_item	2587529	et	3	main
kogeb	doc_491521502098_item	2587537	et	3	main
tagajärgi	doc_491521502098_item	2587554	et	4	main
üleolevad	doc_491521502098_item	2587560	et	3	main
eksitavad	doc_491521502098_item	2587561	et	4	main
kehtivad	doc_491521502098_item	2587562	et	4	main
topib	doc_491521502098_item	2587575	et	3	main
pea	doc_491521502097_item	2587171	et	4	main
ajal	doc_491521502097_item	2587173	et	4	main
6	doc_491521502097_item	2587180	et	2	main
maiasmokk	doc_491521502097_item	2587182	et	3	main
iii	doc_491521502097_item	2587183	et	4	main
hallitama	doc_491521502097_item	2587192	et	3	main
kreemituub	doc_491521502097_item	2587209	et	4	main
6	doc_491521502097_item	2587212	et	2	main
toodetakse	doc_491521502097_item	2587231	et	3	main
palju	doc_491521502097_item	2587242	et	4	main
vitamiine	doc_491521502097_item	2587249	et	3	main
on	doc_491521502097_item	2587252	et	4	main
vitamiine	doc_491521502097_item	2587254	et	3	main
müüdetav	doc_491521502097_item	2587255	et	4	main
3	doc_491521502097_item	2587257	et	2	main
mida	doc_491521502097_item	2587272	et	4	main
kulu	doc_491521502097_item	2587276	et	4	main
käsitsi	doc_491521502097_item	2587287	et	3	main
keemiavahenditel	doc_491521502097_item	2587291	et	3	main
tervist	doc_491521502097_item	2587297	et	4	main
toime	doc_491521502097_item	2587300	et	4	main
tav-kesksõnaga	doc_491521502097_item	2587226	et	3	main
1	doc_491521502097_item	2587228	et	2	main
kreeme	doc_491521502097_item	2587229	et	3	main
eestis	doc_491521502097_item	2587232	et	3	main
toodetava	doc_491521502097_item	2587238	et	4	main
eestis	doc_491521502097_item	2587239	et	3	main
kasutatakse	doc_491521502097_item	2587241	et	3	main
küsi	doc_491521502097_item	2587244	et	4	main
seda	doc_491521502097_item	2587245	et	3	main
neiult	doc_491521502097_item	2587246	et	4	main
küsi	doc_491521502097_item	2587250	et	4	main
on	doc_491521502097_item	2587262	et	4	main
pesupulber	doc_491521502097_item	2587269	et	3	main
käsitsi	doc_491521502097_item	2587274	et	3	main
pestav	doc_491521502097_item	2587279	et	4	main
5	doc_491521502097_item	2587289	et	2	main
toime	doc_491521502097_item	2587294	et	4	main
kahjustav	doc_491521502097_item	2587298	et	4	main
kahjuv	doc_491521502097_item	2587301	et	4	main
võib	doc_491521502097_item	2587303	et	3	main
olla	doc_491521502097_item	2587304	et	3	main
paljudel	doc_491521502097_item	2587305	et	3	main
v	doc_491521502097_item	2587307	et	4	main
tõlkige	doc_491521502097_item	2587308	et	3	main
keemiavahenditel	doc_491521502097_item	2587306	et	3	main
eesti	doc_491521502097_item	2587309	et	4	main
keelde	doc_491521502097_item	2587310	et	4	main
1	doc_491521502097_item	2587311	et	2	main
постоянные	doc_491521502097_item	2587312	et	2	main
клиенты	doc_491521502097_item	2587313	et	2	main
имеют	doc_491521502097_item	2587314	et	2	main
право	doc_491521502097_item	2587315	et	2	main
покупать	doc_491521502097_item	2587316	et	2	main
товар	doc_491521502097_item	2587317	et	2	main
в	doc_491521502097_item	2587318	et	2	main
рассрочку	doc_491521502097_item	2587319	et	2	main
püsiklienditel	doc_491521502097_item	2587320	et	4	main
õigus	doc_491521502097_item	2587322	et	4	main
система	doc_491521502097_item	2587339	et	2	main
разработана	doc_491521502097_item	2587343	et	2	main
süsteem	doc_491521502097_item	2587345	et	3	main
firma	doc_491521502097_item	2587354	et	4	main
moodustage	doc_491521502097_item	2587359	et	3	main
õnnelik	doc_491521502097_item	2587362	et	3	main
2	doc_491521502097_item	2587364	et	2	main
harimatu	doc_491521502097_item	2587366	et	4	main
3	doc_491521502097_item	2587367	et	2	main
5	doc_491521502097_item	2587373	et	2	main
lünkadesse	doc_491521502097_item	2587378	et	3	main
käib	doc_491521502097_item	2587420	et	3	main
tahan	doc_491521502097_item	2587424	et	3	main
umbisikulise	doc_491521502097_item	2587443	et	4	main
tegumoe	doc_491521502097_item	2587444	et	3	main
meilt	doc_491521502097_item	2587452	et	3	main
2	doc_491521502097_item	2587455	et	2	main
ei	doc_491521502097_item	2587457	et	4	main
laskma	doc_491521502097_item	2587458	et	3	main
midagi	doc_491521502097_item	2587459	et	4	main
ütlema	doc_491521502097_item	2587460	et	3	main
ütelda	doc_491521502097_item	2587465	et	4	main
3	doc_491521502097_item	2587466	et	2	main
mina	doc_491521502097_item	2587467	et	4	main
vabaturu	doc_491521502097_item	2587335	et	3	main
мусора	doc_491521502097_item	2587341	et	2	main
ei	doc_491521502097_item	2587346	et	4	main
ole	doc_491521502097_item	2587347	et	4	main
vi	doc_491521502097_item	2587358	et	4	main
loetu	doc_491521502097_item	2587369	et	4	main
4	doc_491521502097_item	2587370	et	2	main
oodatud	doc_491521502097_item	2587374	et	4	main
sidesõnad	doc_491521502097_item	2587380	et	3	main
1	doc_491521502097_item	2587381	et	2	main
ma	doc_491521502097_item	2587382	et	3	main
kavatsen	doc_491521502097_item	2587383	et	3	main
eesti	doc_491521502097_item	2587384	et	4	main
keele	doc_491521502097_item	2587385	et	4	main
õpinguid	doc_491521502097_item	2587386	et	3	main
jätkata	doc_491521502097_item	2587387	et	4	main
juhul	doc_491521502097_item	2587388	et	3	main
kui	doc_491521502097_item	2587389	et	3	main
mul	doc_491521502097_item	2587390	et	3	main
on	doc_491521502097_item	2587391	et	4	main
aega	doc_491521502097_item	2587392	et	4	main
2	doc_491521502097_item	2587393	et	2	main
pean	doc_491521502097_item	2587394	et	4	main
kiiresti	doc_491521502097_item	2587395	et	3	main
minema	doc_491521502097_item	2587396	et	3	main
hakkama	doc_491521502097_item	2587397	et	3	main
muidu	doc_491521502097_item	2587398	et	3	main
jään	doc_491521502097_item	2587399	et	3	main
3	doc_491521502097_item	2587401	et	2	main
hiljaks	doc_491521502097_item	2587400	et	3	main
tahan	doc_491521502097_item	2587402	et	3	main
endale	doc_491521502097_item	2587403	et	4	main
osta	doc_491521502097_item	2587404	et	4	main
uue	doc_491521502097_item	2587405	et	3	main
kleidi	doc_491521502097_item	2587406	et	3	main
seega	doc_491521502097_item	2587407	et	4	main
pean	doc_491521502097_item	2587408	et	4	main
raha	doc_491521502097_item	2587409	et	4	main
kokku	doc_491521502097_item	2587410	et	3	main
hoidma	doc_491521502097_item	2587411	et	3	main
4	doc_491521502097_item	2587412	et	2	main
ta	doc_491521502097_item	2587413	et	4	main
teeb	doc_491521502097_item	2587414	et	3	main
terve	doc_491521502097_item	2587415	et	4	main
sellele	doc_491521502097_item	2587419	et	4	main
5	doc_491521502097_item	2587423	et	2	main
õppida	doc_491521502097_item	2587432	et	3	main
kuigi	doc_491521502097_item	2587438	et	3	main
sellele	doc_491521502097_item	2587440	et	4	main
viii	doc_491521502097_item	2587441	et	4	main
kasutage	doc_491521502097_item	2587442	et	3	main
allkiri	doc_491521502097_item	2587451	et	3	main
müüja	doc_491521502097_item	2587456	et	4	main
midagi	doc_491521502097_item	2587464	et	4	main
käsiti	doc_491521502097_item	2587472	et	4	main
4	doc_491521502097_item	2587475	et	2	main
avaldus	doc_491521502097_item	2587477	et	4	main
läbi	doc_491521502097_item	2587479	et	4	main
5	doc_491521502097_item	2587488	et	2	main
sõna	doc_491521502098_item	2587501	et	4	main
1	doc_491521502098_item	2587502	et	2	main
suurt	doc_491521502098_item	2587503	et	3	main
selle	doc_491521502098_item	2587511	et	4	main
kisuvad	doc_491521502098_item	2587515	et	3	main
trennis	doc_491521502097_item	2587422	et	3	main
sisse	doc_491521502097_item	2587426	et	4	main
saada	doc_491521502097_item	2587427	et	4	main
kuigi	doc_491521502097_item	2587428	et	3	main
tuleb	doc_491521502097_item	2587429	et	3	main
mul	doc_491521502097_item	2587430	et	3	main
palju	doc_491521502097_item	2587431	et	4	main
seega	doc_491521502097_item	2587435	et	4	main
kui	doc_491521502097_item	2587437	et	3	main
lihtminevikku	doc_491521502097_item	2587445	et	4	main
1	doc_491521502097_item	2587448	et	2	main
meie	doc_491521502097_item	2587449	et	4	main
nõudma	doc_491521502097_item	2587450	et	3	main
allkirja	doc_491521502097_item	2587454	et	4	main
käskima	doc_491521502097_item	2587468	et	4	main
loetud	doc_491521502097_item	2587485	et	4	main
ostja	doc_491521502097_item	2587489	et	4	main
ostjale	doc_491521502097_item	2587493	et	4	main
võimalust	doc_491521502097_item	2587496	et	3	main
koera	doc_491521502098_item	2587504	et	4	main
peab	doc_491521502098_item	2587505	et	4	main
2	doc_491521502098_item	2587510	et	2	main
luituvad	doc_491521502098_item	2587516	et	4	main
3	doc_491521502098_item	2587517	et	2	main
kardan	doc_491521502098_item	2587518	et	4	main
et	doc_491521502098_item	2587519	et	3	main
seda	doc_491521502098_item	2587520	et	3	main
omandatakse	doc_491521502098_item	2587531	et	3	main
inimene	doc_491521502098_item	2587536	et	3	main
pidevalt	doc_491521502098_item	2587538	et	4	main
siis	doc_491521502098_item	2587540	et	3	main
kohad	doc_491521502098_item	2587563	et	4	main
3	doc_491521502098_item	2587574	et	2	main
purunema	doc_491521502098_item	2587603	et	3	main
2	doc_491521502098_item	2587610	et	2	main
rikki	doc_491521502098_item	2587616	et	3	main
mul	doc_491521502097_item	2587471	et	3	main
vait	doc_491521502097_item	2587473	et	3	main
minu	doc_491521502097_item	2587476	et	3	main
ei	doc_491521502097_item	2587478	et	4	main
lugema	doc_491521502097_item	2587480	et	4	main
korralikult	doc_491521502097_item	2587486	et	4	main
pakkuma	doc_491521502097_item	2587490	et	3	main
pintsaku	doc_491521502098_item	2587512	et	3	main
plaani	doc_491521502098_item	2587521	et	4	main
on	doc_491521502098_item	2587522	et	4	main
uued	doc_491521502098_item	2587532	et	3	main
kui	doc_491521502098_item	2587535	et	3	main
endale	doc_491521502098_item	2587549	et	4	main
teadvustama	doc_491521502098_item	2587550	et	3	main
keskkonna	doc_491521502098_item	2587551	et	3	main
reostamise	doc_491521502098_item	2587552	et	4	main
7	doc_491521502098_item	2587556	et	2	main
on	doc_491521502098_item	2587558	et	4	main
käima	doc_491521502098_item	2587573	et	4	main
poole	doc_491521502098_item	2587578	et	4	main
1	doc_491521502098_item	2587606	et	2	main
8	doc_491521502098_item	2587608	et	2	main
3	doc_491521502098_item	2587613	et	2	main
4	doc_491521502098_item	2587620	et	2	main
kreemituub	doc_491521502098_item	2587623	et	4	main
rebenema	doc_491521502098_item	2587625	et	3	main
6	doc_491521502098_item	2587628	et	2	main
4	doc_491521502098_item	2587630	et	2	main
pigistama	doc_491521502098_item	2587633	et	3	main
tav-kesksõnaga	doc_491521502098_item	2587641	et	3	main
palju	doc_491521502098_item	2587649	et	4	main
eestis	doc_491521502098_item	2587650	et	3	main
toodetavat	doc_491521502098_item	2587651	et	4	main
kreeme	doc_491521502098_item	2587652	et	3	main
kasutatakse	doc_491521502098_item	2587653	et	3	main
palju	doc_491521502098_item	2587654	et	4	main
2	doc_491521502098_item	2587655	et	2	main
pesumasinas	doc_491521502098_item	2587672	et	3	main
pesu	doc_491521502098_item	2587679	et	4	main
pestakse	doc_491521502098_item	2587681	et	3	main
ei	doc_491521502098_item	2587690	et	4	main
võib	doc_491521502098_item	2587705	et	3	main
kahjustav	doc_491521502098_item	2587708	et	4	main
toime	doc_491521502098_item	2587709	et	4	main
клиенты	doc_491521502098_item	2587716	et	2	main
raske	doc_491521502098_item	2587523	et	4	main
liigitada	doc_491521502098_item	2587524	et	3	main
sisaldada	doc_491521502098_item	2587525	et	3	main
teostada	doc_491521502098_item	2587526	et	3	main
4	doc_491521502098_item	2587527	et	2	main
varsti	doc_491521502098_item	2587528	et	3	main
sisekorraeeskirjad	doc_491521502098_item	2587533	et	3	main
peaksid	doc_491521502098_item	2587548	et	4	main
tulemusi	doc_491521502098_item	2587555	et	4	main
ii	doc_491521502098_item	2587564	et	4	main
kirjutage	doc_491521502098_item	2587565	et	3	main
sünonüümid	doc_491521502098_item	2587566	et	3	main
1	doc_491521502098_item	2587567	et	2	main
hülgama	doc_491521502098_item	2587568	et	3	main
2	doc_491521502098_item	2587570	et	2	main
taipama	doc_491521502098_item	2587571	et	3	main
segab	doc_491521502098_item	2587579	et	3	main
tahab	doc_491521502098_item	2587580	et	3	main
kõik	doc_491521502098_item	2587581	et	4	main
kõigest	doc_491521502098_item	2587582	et	4	main
teada	doc_491521502098_item	2587583	et	3	main
4	doc_491521502098_item	2587584	et	2	main
tuleb	doc_491521502098_item	2587585	et	3	main
õige	doc_491521502098_item	2587586	et	4	main
pea	doc_491521502098_item	2587587	et	4	main
tuleb	doc_491521502098_item	2587588	et	3	main
õigele	doc_491521502098_item	2587589	et	3	main
ajal	doc_491521502098_item	2587590	et	4	main
5	doc_491521502098_item	2587591	et	2	main
lõi	doc_491521502098_item	2587592	et	4	main
kõigele	doc_491521502098_item	2587593	et	4	main
käega	doc_491521502098_item	2587594	et	3	main
6	doc_491521502098_item	2587595	et	2	main
mesikäpp	doc_491521502098_item	2587596	et	3	main
majasmokk	doc_491521502098_item	2587597	et	4	main
iii	doc_491521502098_item	2587598	et	4	main
ühendage	doc_491521502098_item	2587599	et	3	main
tegusõna	doc_491521502098_item	2587600	et	4	main
ja	doc_491521502098_item	2587601	et	3	main
ese	doc_491521502098_item	2587602	et	3	main
enesehinnang	doc_491521502098_item	2587543	et	3	main
koormus	doc_491521502098_item	2587544	et	4	main
langeb	doc_491521502098_item	2587545	et	3	main
6	doc_491521502098_item	2587546	et	2	main
inimesed	doc_491521502098_item	2587547	et	3	main
järeldusi	doc_491521502098_item	2587553	et	4	main
kasutusjuhendis	doc_491521502098_item	2587557	et	3	main
mõned	doc_491521502098_item	2587559	et	3	main
hüppatama	doc_491521502098_item	2587569	et	4	main
tõttu	doc_491521502098_item	2587572	et	4	main
nina	doc_491521502098_item	2587576	et	4	main
juust	doc_491521502098_item	2587605	et	4	main
venima	doc_491521502098_item	2587612	et	3	main
3	doc_491521502098_item	2587615	et	2	main
toidujäätmed	doc_491521502098_item	2587619	et	3	main
määrima	doc_491521502098_item	2587621	et	3	main
teksad	doc_491521502098_item	2587635	et	4	main
laused	doc_491521502098_item	2587642	et	3	main
toodetakse	doc_491521502098_item	2587646	et	3	main
mida	doc_491521502098_item	2587680	et	4	main
käsitsi	doc_491521502098_item	2587682	et	3	main
ei	doc_491521502098_item	2587683	et	4	main
nii	doc_491521502098_item	2587685	et	3	main
kiiresti	doc_491521502098_item	2587686	et	3	main
5	doc_491521502098_item	2587694	et	2	main
olla	doc_491521502098_item	2587698	et	3	main
mis	doc_491521502098_item	2587700	et	4	main
eesti	doc_491521502098_item	2587712	et	4	main
право	doc_491521502098_item	2587718	et	2	main
on	doc_491521502098_item	2587724	et	4	main
õigus	doc_491521502098_item	2587725	et	4	main
osta	doc_491521502098_item	2587726	et	4	main
kaupa	doc_491521502098_item	2587727	et	4	main
järelmaksuga	doc_491521502098_item	2587728	et	3	main
2	doc_491521502098_item	2587729	et	2	main
это	doc_491521502098_item	2587730	et	2	main
нарушает	doc_491521502098_item	2587731	et	2	main
принципы	doc_491521502098_item	2587732	et	2	main
торговли	doc_491521502098_item	2587733	et	2	main
свободного	doc_491521502098_item	2587734	et	2	main
рынка	doc_491521502098_item	2587735	et	2	main
система	doc_491521502098_item	2587742	et	2	main
разработана	doc_491521502098_item	2587746	et	2	main
süsteem	doc_491521502098_item	2587749	et	3	main
фирма	doc_491521502098_item	2587755	et	2	main
loetav	doc_491521502098_item	2587773	et	4	main
vii	doc_491521502098_item	2587781	et	4	main
õiged	doc_491521502098_item	2587784	et	3	main
kavatsen	doc_491521502098_item	2587788	et	3	main
kui	doc_491521502098_item	2587794	et	3	main
2	doc_491521502098_item	2587798	et	2	main
3	doc_491521502098_item	2587806	et	2	main
kuigi	doc_491521502098_item	2587812	et	3	main
4	doc_491521502098_item	2587817	et	2	main
teeb	doc_491521502098_item	2587819	et	3	main
kõrgkooli	doc_491521502098_item	2587830	et	4	main
saada	doc_491521502098_item	2587832	et	4	main
kui	doc_491521502098_item	2587842	et	3	main
mida	doc_491521502098_item	2587851	et	4	main
tehti	doc_491521502098_item	2587852	et	3	main
meie	doc_491521502098_item	2587854	et	4	main
nõudma	doc_491521502098_item	2587855	et	3	main
allkiri	doc_491521502098_item	2587856	et	3	main
ei	doc_491521502098_item	2587867	et	4	main
lakstud	doc_491521502098_item	2587868	et	4	main
3	doc_491521502098_item	2587871	et	2	main
käskima	doc_491521502098_item	2587873	et	4	main
sisekohakäänetesse	doc_491521502099_item	2587908	et	3	main
jõudes	doc_491521502099_item	2587923	et	3	main
tulen	doc_491521502099_item	2587925	et	3	main
maja	doc_491521502099_item	2587926	et	4	main
välja	doc_491521502099_item	2587927	et	4	main
sulle	doc_491521502099_item	2587928	et	3	main
vastu	doc_491521502099_item	2587929	et	3	main
2	doc_491521502099_item	2587930	et	2	main
kurbus	doc_491521502099_item	2587934	et	4	main
vabaneda	doc_491521502099_item	2587945	et	3	main
lükkub	doc_491521502099_item	2587949	et	3	main
kauplus	doc_491521502099_item	2587954	et	3	main
on	doc_491521502099_item	2587955	et	4	main
4	doc_491521502099_item	2587960	et	2	main
igale	doc_491521502098_item	2587577	et	3	main
välja	doc_491521502098_item	2587611	et	4	main
õmblused	doc_491521502098_item	2587614	et	3	main
minema	doc_491521502098_item	2587617	et	3	main
5	doc_491521502098_item	2587624	et	2	main
6	doc_491521502098_item	2587626	et	2	main
näokreem	doc_491521502098_item	2587627	et	3	main
ja	doc_491521502098_item	2587640	et	3	main
mida	doc_491521502098_item	2587645	et	4	main
eestis	doc_491521502098_item	2587647	et	3	main
vette	doc_491521502098_item	2587677	et	3	main
kulu	doc_491521502098_item	2587684	et	4	main
pesetav	doc_491521502098_item	2587688	et	4	main
pesu	doc_491521502098_item	2587689	et	4	main
võib	doc_491521502098_item	2587697	et	3	main
tervist	doc_491521502098_item	2587702	et	4	main
paljudel	doc_491521502098_item	2587703	et	3	main
keemiavahendite	doc_491521502098_item	2587704	et	3	main
tervist	doc_491521502098_item	2587707	et	4	main
keelde	doc_491521502098_item	2587713	et	4	main
постоянные	doc_491521502098_item	2587715	et	2	main
товар	doc_491521502098_item	2587720	et	2	main
see	doc_491521502098_item	2587736	et	3	main
4	doc_491521502098_item	2587754	et	2	main
haritu	doc_491521502098_item	2587771	et	4	main
3	doc_491521502098_item	2587772	et	2	main
andekas	doc_491521502098_item	2587776	et	4	main
5	doc_491521502098_item	2587778	et	2	main
oodatud	doc_491521502098_item	2587779	et	4	main
jätkata	doc_491521502098_item	2587792	et	4	main
aega	doc_491521502098_item	2587797	et	4	main
pean	doc_491521502098_item	2587799	et	4	main
kiiresti	doc_491521502098_item	2587800	et	3	main
minema	doc_491521502098_item	2587801	et	3	main
hakkama	doc_491521502098_item	2587802	et	3	main
muidu	doc_491521502098_item	2587803	et	3	main
jään	doc_491521502098_item	2587804	et	3	main
hiljaks	doc_491521502098_item	2587805	et	3	main
tahan	doc_491521502098_item	2587807	et	3	main
endale	doc_491521502098_item	2587808	et	4	main
pean	doc_491521502098_item	2587813	et	4	main
raha	doc_491521502098_item	2587814	et	4	main
sellele	doc_491521502098_item	2587824	et	4	main
käib	doc_491521502098_item	2587825	et	3	main
veel	doc_491521502098_item	2587826	et	4	main
trennis	doc_491521502098_item	2587827	et	3	main
5	doc_491521502098_item	2587828	et	2	main
tahan	doc_491521502098_item	2587829	et	3	main
sisse	doc_491521502098_item	2587831	et	4	main
muidu	doc_491521502098_item	2587839	et	3	main
kuigi	doc_491521502098_item	2587843	et	3	main
sellele	doc_491521502098_item	2587845	et	4	main
viii	doc_491521502098_item	2587846	et	4	main
allkiri	doc_491521502098_item	2587859	et	3	main
müüjal	doc_491521502098_item	2587866	et	4	main
ütleda	doc_491521502098_item	2587870	et	4	main
laused	doc_491521502099_item	2587910	et	3	main
uus	doc_491521502099_item	2587913	et	3	main
aastat	doc_491521502099_item	2587921	et	3	main
sinu	doc_491521502099_item	2587932	et	3	main
nädalat	doc_491521502099_item	2587937	et	3	main
sügav	doc_491521502099_item	2587939	et	4	main
loodan	doc_491521502099_item	2587941	et	3	main
peagi	doc_491521502099_item	2587942	et	4	main
oma	doc_491521502099_item	2587943	et	4	main
3	doc_491521502099_item	2587946	et	2	main
oktoober	doc_491521502099_item	2587950	et	3	main
avatakse	doc_491521502099_item	2587952	et	4	main
avatud	doc_491521502099_item	2587957	et	4	main
alates	doc_491521502099_item	2587958	et	3	main
oktoober	doc_491521502099_item	2587959	et	3	main
auk	doc_491521502099_item	2587968	et	3	main
kivid	doc_491521502099_item	2587974	et	3	main
osakond	doc_491521502099_item	2587981	et	3	main
1	doc_491521502099_item	2587986	et	2	main
majas	doc_491521502099_item	2587990	et	3	main
2	doc_491521502099_item	2587992	et	2	main
ajutiselt	doc_491521502099_item	2588021	et	4	main
kutsekooli	doc_491521502099_item	2588023	et	4	main
majandusjuhataja	doc_491521502099_item	2588024	et	4	main
2	doc_491521502099_item	2588025	et	2	main
tähtaeg	doc_491521502099_item	2588033	et	3	main
7	doc_491521502098_item	2587604	et	2	main
hallitama	doc_491521502098_item	2587607	et	3	main
õmblusmasin	doc_491521502098_item	2587609	et	3	main
2	doc_491521502098_item	2587618	et	2	main
moodustage	doc_491521502098_item	2587638	et	3	main
v-	doc_491521502098_item	2587639	et	4	main
kreeme	doc_491521502098_item	2587644	et	3	main
kasutatakse	doc_491521502098_item	2587648	et	3	main
vitamiine	doc_491521502098_item	2587661	et	3	main
lisa	doc_491521502098_item	2587673	et	4	main
pesupubrit	doc_491521502098_item	2587674	et	4	main
käsitsi	doc_491521502098_item	2587687	et	3	main
paljudel	doc_491521502098_item	2587695	et	3	main
toime	doc_491521502098_item	2587699	et	4	main
kahjustab	doc_491521502098_item	2587701	et	3	main
1	doc_491521502098_item	2587714	et	2	main
покупать	doc_491521502098_item	2587719	et	2	main
в	doc_491521502098_item	2587721	et	2	main
kaubasnduse	doc_491521502098_item	2587739	et	4	main
не	doc_491521502098_item	2587745	et	2	main
prügi	doc_491521502098_item	2587747	et	4	main
töötanud	doc_491521502098_item	2587753	et	4	main
lugematu	doc_491521502098_item	2587774	et	4	main
mul	doc_491521502098_item	2587795	et	3	main
osta	doc_491521502098_item	2587809	et	4	main
1	doc_491521502098_item	2587622	et	2	main
haisema	doc_491521502098_item	2587629	et	4	main
vaas	doc_491521502098_item	2587631	et	3	main
7	doc_491521502098_item	2587632	et	2	main
5	doc_491521502098_item	2587634	et	2	main
8	doc_491521502098_item	2587636	et	2	main
iv	doc_491521502098_item	2587637	et	4	main
1	doc_491521502098_item	2587643	et	2	main
küsi	doc_491521502098_item	2587656	et	4	main
seda	doc_491521502098_item	2587657	et	3	main
neiult	doc_491521502098_item	2587658	et	4	main
kes	doc_491521502098_item	2587659	et	4	main
müüb	doc_491521502098_item	2587660	et	3	main
küsi	doc_491521502098_item	2587662	et	4	main
vitamiine	doc_491521502098_item	2587663	et	3	main
müüvalt	doc_491521502098_item	2587664	et	4	main
neiult	doc_491521502098_item	2587665	et	4	main
3	doc_491521502098_item	2587666	et	2	main
lisa	doc_491521502098_item	2587667	et	4	main
pesupulbrit	doc_491521502098_item	2587668	et	3	main
vette	doc_491521502098_item	2587669	et	3	main
mis	doc_491521502098_item	2587670	et	4	main
on	doc_491521502098_item	2587671	et	4	main
pesumasinas	doc_491521502098_item	2587675	et	3	main
olevasse	doc_491521502098_item	2587676	et	4	main
4	doc_491521502098_item	2587678	et	2	main
kulu	doc_491521502098_item	2587691	et	4	main
nii	doc_491521502098_item	2587692	et	3	main
kiiresti	doc_491521502098_item	2587693	et	3	main
keemiavahenditel	doc_491521502098_item	2587696	et	3	main
olla	doc_491521502098_item	2587706	et	3	main
v	doc_491521502098_item	2587710	et	4	main
tõlkige	doc_491521502098_item	2587711	et	3	main
имеют	doc_491521502098_item	2587717	et	2	main
рассрочку	doc_491521502098_item	2587722	et	2	main
rikkutab	doc_491521502098_item	2587737	et	4	main
3	doc_491521502098_item	2587741	et	2	main
мусора	doc_491521502098_item	2587744	et	2	main
läbi	doc_491521502098_item	2587751	et	4	main
antonüümid	doc_491521502098_item	2587765	et	3	main
õnnelik	doc_491521502098_item	2587767	et	3	main
2	doc_491521502098_item	2587769	et	2	main
haritud	doc_491521502098_item	2587770	et	4	main
oodatu	doc_491521502098_item	2587780	et	4	main
lünkadesse	doc_491521502098_item	2587783	et	3	main
ma	doc_491521502098_item	2587787	et	3	main
eesti	doc_491521502098_item	2587789	et	4	main
keele	doc_491521502098_item	2587790	et	4	main
õpinguid	doc_491521502098_item	2587791	et	3	main
kleidi	doc_491521502098_item	2587811	et	3	main
kokku	doc_491521502098_item	2587815	et	3	main
terve	doc_491521502098_item	2587820	et	4	main
juhul	doc_491521502098_item	2587841	et	3	main
lisaks	doc_491521502098_item	2587844	et	4	main
kasutage	doc_491521502098_item	2587847	et	3	main
umbisikulise	doc_491521502098_item	2587848	et	4	main
tegumoe	doc_491521502098_item	2587849	et	3	main
2	doc_491521502098_item	2587860	et	2	main
mina	doc_491521502098_item	2587872	et	4	main
vait	doc_491521502098_item	2587874	et	3	main
olema	doc_491521502098_item	2587875	et	4	main
mul	doc_491521502098_item	2587876	et	3	main
käskiti	doc_491521502098_item	2587877	et	4	main
tõlkige	doc_491521502099_item	2587909	et	3	main
kolime	doc_491521502099_item	2587912	et	3	main
me	doc_491521502099_item	2587915	et	4	main
kohale	doc_491521502099_item	2587922	et	4	main
helista	doc_491521502099_item	2587924	et	4	main
juba	doc_491521502099_item	2587935	et	3	main
mitmendat	doc_491521502099_item	2587936	et	3	main
kurbus	doc_491521502099_item	2587944	et	4	main
sein	doc_491521502099_item	2587961	et	3	main
auk	doc_491521502099_item	2587964	et	3	main
on	doc_491521502099_item	2587966	et	4	main
sügav	doc_491521502099_item	2587967	et	4	main
sein	doc_491521502099_item	2587969	et	3	main
on	doc_491521502099_item	2587970	et	4	main
ainult	doc_491521502099_item	2587973	et	4	main
majapidamistarvete	doc_491521502099_item	2587978	et	4	main
sügav	doc_491521502099_item	2587994	et	4	main
direktor	doc_491521502099_item	2588026	et	3	main
õige	doc_491521502099_item	2588032	et	4	main
valminud	doc_491521502099_item	2588034	et	4	main
ja	doc_491521502099_item	2588043	et	3	main
4	doc_491521502099_item	2588045	et	2	main
muretsevad	doc_491521502099_item	2588048	et	4	main
haritud	doc_491521502099_item	2588063	et	4	main
muutusid	doc_491521502099_item	2588065	et	4	main
teised	doc_491521502099_item	2588067	et	4	main
end	doc_491521502099_item	2588069	et	4	main
tähtaega	doc_491521502099_item	2588079	et	4	main
maakonnas	doc_491521502099_item	2588086	et	4	main
esindajalt	doc_491521502099_item	2588089	et	4	main
olevad	doc_491521502099_item	2588092	et	4	main
4	doc_491521502099_item	2588122	et	2	main
all	doc_491521502099_item	2588124	et	3	main
istus	doc_491521502099_item	2588125	et	4	main
paks	doc_491521502099_item	2588126	et	3	main
7	doc_491521502099_item	2588147	et	2	main
saabus	doc_491521502099_item	2588149	et	3	main
passi	doc_491521502099_item	2588153	et	4	main
4	doc_491521502099_item	2588159	et	2	main
viimasest	doc_491521502099_item	2588168	et	3	main
saaks	doc_491521502099_item	2588170	et	3	main
püsiklientidel	doc_491521502098_item	2587723	et	3	main
vabaturu	doc_491521502098_item	2587738	et	3	main
pohimotteid	doc_491521502098_item	2587740	et	4	main
переработки	doc_491521502098_item	2587743	et	2	main
ületöötamise	doc_491521502098_item	2587748	et	3	main
ei	doc_491521502098_item	2587750	et	4	main
valja	doc_491521502098_item	2587752	et	3	main
привлекает	doc_491521502098_item	2587756	et	2	main
клиентов	doc_491521502098_item	2587757	et	2	main
подарками	doc_491521502098_item	2587758	et	2	main
firma	doc_491521502098_item	2587759	et	4	main
mainekab	doc_491521502098_item	2587760	et	4	main
klietideid	doc_491521502098_item	2587761	et	4	main
kingitusetega	doc_491521502098_item	2587762	et	4	main
vi	doc_491521502098_item	2587763	et	4	main
moodustage	doc_491521502098_item	2587764	et	3	main
1	doc_491521502098_item	2587766	et	2	main
õnnetu	doc_491521502098_item	2587768	et	4	main
4	doc_491521502098_item	2587775	et	2	main
andetu	doc_491521502098_item	2587777	et	4	main
pange	doc_491521502098_item	2587782	et	4	main
sidesõnad	doc_491521502098_item	2587785	et	3	main
1	doc_491521502098_item	2587786	et	2	main
juhul	doc_491521502098_item	2587793	et	3	main
on	doc_491521502098_item	2587796	et	4	main
uue	doc_491521502098_item	2587810	et	3	main
hoidma	doc_491521502098_item	2587816	et	3	main
ta	doc_491521502098_item	2587818	et	4	main
päeva	doc_491521502098_item	2587821	et	4	main
lissaks	doc_491521502098_item	2587823	et	4	main
seega	doc_491521502098_item	2587833	et	4	main
tuleb	doc_491521502098_item	2587834	et	3	main
mul	doc_491521502098_item	2587835	et	3	main
seega	doc_491521502098_item	2587840	et	4	main
nõudi	doc_491521502098_item	2587858	et	4	main
müüja	doc_491521502098_item	2587861	et	4	main
laskma	doc_491521502098_item	2587863	et	3	main
midagi	doc_491521502098_item	2587864	et	4	main
ütlema	doc_491521502098_item	2587865	et	3	main
1homme	doc_491521502099_item	2587911	et	3	main
langesin	doc_491521502099_item	2587931	et	3	main
viibin	doc_491521502099_item	2587938	et	3	main
avamine	doc_491521502099_item	2587948	et	4	main
kauplus	doc_491521502099_item	2587951	et	3	main
külastajatele	doc_491521502099_item	2587956	et	4	main
on	doc_491521502099_item	2587962	et	4	main
5	doc_491521502099_item	2587975	et	2	main
vajalikku	doc_491521502099_item	2587985	et	4	main
maja	doc_491521502099_item	2587991	et	4	main
kurban	doc_491521502099_item	2587993	et	4	main
kurbust	doc_491521502099_item	2587995	et	4	main
teatas	doc_491521502099_item	2588027	et	3	main
vastutan	doc_491521502099_item	2588030	et	3	main
remondi	doc_491521502099_item	2588035	et	4	main
inimene	doc_491521502099_item	2588039	et	3	main
oma	doc_491521502099_item	2588050	et	4	main
keele	doc_491521502099_item	2588051	et	4	main
saatuse	doc_491521502099_item	2588052	et	3	main
eesti	doc_491521502099_item	2588057	et	4	main
erinevad	doc_491521502099_item	2588059	et	4	main
eestlased	doc_491521502099_item	2588064	et	3	main
2	doc_491521502099_item	2588076	et	2	main
erinevad	doc_491521502099_item	2588085	et	4	main
pange	doc_491521502099_item	2588090	et	4	main
saba	doc_491521502099_item	2588127	et	4	main
uskuge	doc_491521502099_item	2588131	et	3	main
ilma	doc_491521502099_item	2588135	et	4	main
ilma	doc_491521502099_item	2588139	et	4	main
taotlus	doc_491521502099_item	2588141	et	4	main
2	doc_491521502099_item	2588154	et	2	main
suured	doc_491521502099_item	2588157	et	3	main
5	doc_491521502099_item	2588160	et	2	main
muutke	doc_491521502099_item	2588164	et	3	main
tõlkige	doc_491521502099_item	2588172	et	3	main
vene	doc_491521502099_item	2588174	et	4	main
keelde	doc_491521502099_item	2588175	et	4	main
saastatus	doc_491521502099_item	2588191	et	4	main
tööstuspiirkonnas	doc_491521502099_item	2588200	et	4	main
hommikul	doc_491521502099_item	2588212	et	3	main
venelased	doc_491521502099_item	2588221	et	3	main
elanikkonnast	doc_491521502099_item	2588224	et	4	main
esindavad	doc_491521502099_item	2588229	et	4	main
ei	doc_491521502099_item	2588239	et	4	main
me	doc_491521502099_item	2588241	et	4	main
vett	doc_491521502099_item	2588243	et	3	main
asustusega	doc_491521502099_item	2588256	et	4	main
sõjamees	doc_491521502099_item	2588259	et	4	main
ja	doc_491521502099_item	2588263	et	3	main
omab	doc_491521502099_item	2588270	et	3	main
в	doc_491521502099_item	2588322	et	2	main
условиях	doc_491521502099_item	2588329	et	2	main
6	doc_491521502099_item	2588331	et	2	main
ma	doc_491521502099_item	2588342	et	3	main
minu	doc_491521502099_item	2588348	et	3	main
2	doc_491521502099_item	2588365	et	2	main
tartu	doc_491521502099_item	2588371	et	4	main
parem	doc_491521502099_item	2588379	et	4	main
kui	doc_491521502099_item	2588381	et	3	main
tööd	doc_491521502098_item	2587822	et	4	main
palju	doc_491521502098_item	2587836	et	4	main
õppida	doc_491521502098_item	2587837	et	3	main
sõnad	doc_491521502098_item	2587838	et	4	main
lihtminevikku	doc_491521502098_item	2587850	et	4	main
1	doc_491521502098_item	2587853	et	2	main
meilt	doc_491521502098_item	2587857	et	3	main
ei	doc_491521502098_item	2587862	et	4	main
midagi	doc_491521502098_item	2587869	et	4	main
olla	doc_491521502098_item	2587878	et	3	main
vait	doc_491521502098_item	2587879	et	3	main
4	doc_491521502098_item	2587880	et	2	main
minu	doc_491521502098_item	2587881	et	3	main
avaldus	doc_491521502098_item	2587882	et	4	main
ei	doc_491521502098_item	2587883	et	4	main
läbi	doc_491521502098_item	2587884	et	4	main
korralikult	doc_491521502098_item	2587886	et	4	main
minu	doc_491521502098_item	2587887	et	3	main
lugema	doc_491521502098_item	2587885	et	4	main
avaldust	doc_491521502098_item	2587888	et	4	main
ei	doc_491521502098_item	2587889	et	4	main
läbi	doc_491521502098_item	2587890	et	4	main
loetud	doc_491521502098_item	2587891	et	4	main
korralikult	doc_491521502098_item	2587892	et	4	main
5	doc_491521502098_item	2587893	et	2	main
ostja	doc_491521502098_item	2587894	et	4	main
pakkuma	doc_491521502098_item	2587895	et	3	main
kaks	doc_491521502098_item	2587896	et	3	main
võimalus	doc_491521502098_item	2587897	et	3	main
ostjele	doc_491521502098_item	2587898	et	4	main
pakuti	doc_491521502098_item	2587899	et	3	main
kaks	doc_491521502098_item	2587900	et	3	main
voimalust	doc_491521502098_item	2587901	et	4	main
pange	doc_491521502099_item	2587903	et	4	main
kontrolltöö	doc_491521502099_item	2587902	et	4	main
sulgudes	doc_491521502099_item	2587904	et	4	main
olevad	doc_491521502099_item	2587905	et	4	main
vastavatesse	doc_491521502099_item	2587907	et	4	main
sõnad	doc_491521502099_item	2587906	et	4	main
maja	doc_491521502099_item	2587914	et	4	main
elame	doc_491521502099_item	2587916	et	3	main
uus	doc_491521502099_item	2587917	et	3	main
maja	doc_491521502099_item	2587918	et	4	main
juba	doc_491521502099_item	2587919	et	3	main
pool	doc_491521502099_item	2587920	et	4	main
pärast	doc_491521502099_item	2587933	et	4	main
kurbus	doc_491521502099_item	2587940	et	4	main
kaupluse	doc_491521502099_item	2587947	et	3	main
oktoober	doc_491521502099_item	2587953	et	3	main
järele	doc_491521502099_item	2587971	et	4	main
läheme	doc_491521502099_item	2587976	et	3	main
nüüd	doc_491521502099_item	2587977	et	4	main
osakond	doc_491521502099_item	2587979	et	3	main
leidub	doc_491521502099_item	2587982	et	3	main
uude	doc_491521502099_item	2587987	et	3	main
uues	doc_491521502099_item	2587989	et	3	main
kurbu	doc_491521502099_item	2587996	et	4	main
3	doc_491521502099_item	2587997	et	2	main
oktoobrisse	doc_491521502099_item	2587998	et	3	main
oktoobrist	doc_491521502099_item	2587999	et	3	main
oktoobril	doc_491521502099_item	2588000	et	3	main
4	doc_491521502099_item	2588001	et	2	main
seinas	doc_491521502099_item	2588002	et	3	main
sein	doc_491521502099_item	2588003	et	3	main
seinad	doc_491521502099_item	2588004	et	3	main
5	doc_491521502099_item	2588005	et	2	main
majapidamistarve	doc_491521502099_item	2588006	et	4	main
osakonna	doc_491521502099_item	2588007	et	4	main
majapidamistarvetele	doc_491521502099_item	2588008	et	4	main
osakond	doc_491521502099_item	2588009	et	3	main
valige	doc_491521502099_item	2588010	et	3	main
õige	doc_491521502099_item	2588011	et	4	main
kas	doc_491521502099_item	2588013	et	3	main
kääne	doc_491521502099_item	2588012	et	3	main
saav	doc_491521502099_item	2588014	et	4	main
või	doc_491521502099_item	2588015	et	4	main
olev	doc_491521502099_item	2588016	et	4	main
1möödunud	doc_491521502099_item	2588017	et	4	main
talvel	doc_491521502099_item	2588018	et	4	main
kutsuti	doc_491521502099_item	2588019	et	3	main
mind	doc_491521502099_item	2588020	et	4	main
sellesse	doc_491521502099_item	2588022	et	4	main
kasvamine	doc_491521502099_item	2588040	et	4	main
rahvas	doc_491521502099_item	2588047	et	4	main
eestlased	doc_491521502099_item	2588049	et	3	main
oli	doc_491521502099_item	2588056	et	3	main
baltisakslased	doc_491521502099_item	2588066	et	3	main
majandusjuhataja	doc_491521502099_item	2588075	et	4	main
majandusjuhatajast	doc_491521502099_item	2588077	et	4	main
õiges	doc_491521502099_item	2588078	et	3	main
3	doc_491521502099_item	2588080	et	2	main
tehtud	doc_491521502099_item	2587963	et	4	main
sein	doc_491521502099_item	2587965	et	3	main
jäänud	doc_491521502099_item	2587972	et	4	main
majapidamistarvete	doc_491521502099_item	2587980	et	4	main
alati	doc_491521502099_item	2587983	et	4	main
midagi	doc_491521502099_item	2587984	et	4	main
maja	doc_491521502099_item	2587988	et	4	main
et	doc_491521502099_item	2588028	et	3	main
majandusjuhataja	doc_491521502099_item	2588029	et	4	main
mina	doc_491521502099_item	2588031	et	4	main
haritud	doc_491521502099_item	2588038	et	4	main
töökust	doc_491521502099_item	2588042	et	4	main
kannatlikust	doc_491521502099_item	2588044	et	4	main
pärast	doc_491521502099_item	2588053	et	4	main
maakonnad	doc_491521502099_item	2588060	et	4	main
tundsid	doc_491521502099_item	2588068	et	4	main
endiselt	doc_491521502099_item	2588070	et	4	main
oma	doc_491521502099_item	2588071	et	4	main
rahva	doc_491521502099_item	2588072	et	3	main
4	doc_491521502099_item	2588082	et	2	main
5	doc_491521502099_item	2588084	et	2	main
6	doc_491521502099_item	2588087	et	2	main
või	doc_491521502099_item	2588095	et	4	main
omastavasse	doc_491521502099_item	2588096	et	4	main
käändesse	doc_491521502099_item	2588097	et	4	main
tõlkige	doc_491521502099_item	2588098	et	3	main
vene	doc_491521502099_item	2588100	et	4	main
laused	doc_491521502099_item	2588099	et	3	main
keelde	doc_491521502099_item	2588101	et	4	main
1ilma	doc_491521502099_item	2588102	et	4	main
pass	doc_491521502099_item	2588103	et	3	main
ei	doc_491521502099_item	2588104	et	4	main
ole	doc_491521502099_item	2588105	et	4	main
lubatud	doc_491521502099_item	2588106	et	4	main
piiri	doc_491521502099_item	2588107	et	4	main
ületada	doc_491521502099_item	2588108	et	3	main
2	doc_491521502099_item	2588109	et	2	main
poisi	doc_491521502099_item	2588110	et	3	main
nägu	doc_491521502099_item	2588111	et	4	main
oli	doc_491521502099_item	2588112	et	3	main
pesema	doc_491521502099_item	2588113	et	3	main
3	doc_491521502099_item	2588114	et	2	main
reisijad	doc_491521502099_item	2588115	et	4	main
suhtusid	doc_491521502099_item	2588116	et	4	main
giidi	doc_491521502099_item	2588117	et	4	main
ettepanekusse	doc_491521502099_item	2588118	et	3	main
ilma	doc_491521502099_item	2588119	et	4	main
suur	doc_491521502099_item	2588120	et	3	main
huvi	doc_491521502099_item	2588121	et	4	main
kass	doc_491521502099_item	2588128	et	3	main
et	doc_491521502099_item	2588132	et	3	main
möödub	doc_491521502099_item	2588134	et	3	main
vaatamisväärsused	doc_491521502099_item	2588137	et	4	main
ametlik	doc_491521502099_item	2588140	et	3	main
ei	doc_491521502099_item	2588142	et	4	main
hilinemine	doc_491521502099_item	2588151	et	4	main
3	doc_491521502099_item	2588156	et	2	main
huvid	doc_491521502099_item	2588158	et	3	main
hilinemiste	doc_491521502099_item	2588163	et	4	main
et	doc_491521502099_item	2588167	et	3	main
näidis	doc_491521502099_item	2588176	et	4	main
ole	doc_491521502099_item	2588181	et	4	main
end	doc_491521502099_item	2588197	et	4	main
eest	doc_491521502099_item	2588036	et	4	main
3	doc_491521502099_item	2588037	et	2	main
nõuab	doc_491521502099_item	2588041	et	3	main
väikese	doc_491521502099_item	2588046	et	4	main
5	doc_491521502099_item	2588054	et	2	main
ajalooliselt	doc_491521502099_item	2588055	et	4	main
jagunenud	doc_491521502099_item	2588058	et	4	main
6	doc_491521502099_item	2588061	et	2	main
mõned	doc_491521502099_item	2588062	et	3	main
esindajad	doc_491521502099_item	2588073	et	4	main
1	doc_491521502099_item	2588074	et	2	main
inimised	doc_491521502099_item	2588081	et	4	main
rahvase	doc_491521502099_item	2588083	et	4	main
baltisakslasest	doc_491521502099_item	2588088	et	3	main
sulgudes	doc_491521502099_item	2588091	et	4	main
sõnad	doc_491521502099_item	2588093	et	4	main
ilmaütlevasse	doc_491521502099_item	2588094	et	3	main
5	doc_491521502099_item	2588129	et	2	main
reis	doc_491521502099_item	2588133	et	4	main
ole	doc_491521502099_item	2588143	et	4	main
võimalik	doc_491521502099_item	2588144	et	3	main
viisat	doc_491521502099_item	2588145	et	3	main
vormistada	doc_491521502099_item	2588146	et	3	main
rong	doc_491521502099_item	2588148	et	3	main
1	doc_491521502099_item	2588152	et	2	main
6	doc_491521502099_item	2588161	et	2	main
nii	doc_491521502099_item	2588166	et	3	main
tegusõnast	doc_491521502099_item	2588169	et	4	main
des-vorm	doc_491521502099_item	2588171	et	3	main
eriti	doc_491521502099_item	2588182	et	3	main
tunda	doc_491521502099_item	2588187	et	3	main
läks	doc_491521502099_item	2588206	et	3	main
puu	doc_491521502099_item	2588209	et	4	main
alla	doc_491521502099_item	2588226	et	3	main
ja	doc_491521502099_item	2588228	et	3	main
kohalikku	doc_491521502099_item	2588231	et	4	main
me	doc_491521502099_item	2588236	et	4	main
eesti	doc_491521502099_item	2588254	et	4	main
4	doc_491521502099_item	2588258	et	2	main
selle	doc_491521502099_item	2588265	et	4	main
teatavat	doc_491521502099_item	2588271	et	4	main
ka	doc_491521502099_item	2588276	et	3	main
keelde	doc_491521502099_item	2588288	et	4	main
5	doc_491521502099_item	2588321	et	2	main
работодателем	doc_491521502099_item	2588326	et	2	main
вчера	doc_491521502099_item	2588332	et	2	main
растет	doc_491521502099_item	2588337	et	2	main
näidise	doc_491521502099_item	2588339	et	3	main
õde	doc_491521502099_item	2588347	et	4	main
õde	doc_491521502099_item	2588349	et	4	main
isa	doc_491521502099_item	2588359	et	4	main
isa	doc_491521502099_item	2588360	et	4	main
on	doc_491521502099_item	2588372	et	4	main
on	doc_491521502099_item	2588378	et	4	main
õpilane	doc_491521502099_item	2588380	et	3	main
on	doc_491521502099_item	2588393	et	4	main
grammatika	doc_491521502099_item	2588407	et	4	main
5	doc_491521502099_item	2588408	et	2	main
meie	doc_491521502099_item	2588409	et	4	main
puu	doc_491521502099_item	2588123	et	4	main
ärge	doc_491521502099_item	2588130	et	3	main
igasugused	doc_491521502099_item	2588136	et	3	main
6	doc_491521502099_item	2588138	et	2	main
kohale	doc_491521502099_item	2588150	et	4	main
pesen	doc_491521502099_item	2588155	et	3	main
7	doc_491521502099_item	2588162	et	2	main
lauseid	doc_491521502099_item	2588165	et	3	main
a	doc_491521502099_item	2588177	et	4	main
keskkonna	doc_491521502099_item	2588178	et	3	main
ja	doc_491521502099_item	2588184	et	3	main
end	doc_491521502099_item	2588186	et	4	main
tööstuspiirkonnas	doc_491521502099_item	2588189	et	4	main
keskkonna	doc_491521502099_item	2588190	et	3	main
eriti	doc_491521502099_item	2588194	et	3	main
tugev	doc_491521502099_item	2588195	et	4	main
b	doc_491521502099_item	2588201	et	4	main
kui	doc_491521502099_item	2588202	et	3	main
karin	doc_491521502099_item	2588203	et	4	main
hommikul	doc_491521502099_item	2588204	et	3	main
minnes	doc_491521502099_item	2588214	et	3	main
nägi	doc_491521502099_item	2588215	et	3	main
karin	doc_491521502099_item	2588216	et	4	main
puu	doc_491521502099_item	2588217	et	4	main
otsas	doc_491521502099_item	2588218	et	4	main
oravat	doc_491521502099_item	2588219	et	3	main
1	doc_491521502099_item	2588220	et	2	main
kolmandiku	doc_491521502099_item	2588227	et	3	main
2	doc_491521502099_item	2588234	et	2	main
kui	doc_491521502099_item	2588235	et	3	main
püüdsime	doc_491521502099_item	2588245	et	3	main
olla	doc_491521502099_item	2588246	et	3	main
ettevaatlikud	doc_491521502099_item	2588248	et	3	main
kui	doc_491521502099_item	2588250	et	3	main
võrrelda	doc_491521502099_item	2588251	et	4	main
hõreda	doc_491521502099_item	2588255	et	3	main
juurde	doc_491521502099_item	2588262	et	4	main
lootis	doc_491521502099_item	2588264	et	3	main
abile	doc_491521502099_item	2588266	et	3	main
iga	doc_491521502099_item	2588268	et	4	main
taim	doc_491521502099_item	2588269	et	3	main
inimorganismile	doc_491521502099_item	2588277	et	3	main
kask	doc_491521502099_item	2588279	et	3	main
väsimuse	doc_491521502099_item	2588282	et	4	main
eesti	doc_491521502099_item	2588287	et	4	main
laused	doc_491521502099_item	2588173	et	3	main
saastatus	doc_491521502099_item	2588179	et	4	main
ei	doc_491521502099_item	2588180	et	4	main
tugev	doc_491521502099_item	2588183	et	4	main
annab	doc_491521502099_item	2588185	et	3	main
vaid	doc_491521502099_item	2588188	et	3	main
ei	doc_491521502099_item	2588192	et	4	main
ole	doc_491521502099_item	2588193	et	4	main
andes	doc_491521502099_item	2588196	et	4	main
nägi	doc_491521502099_item	2588207	et	3	main
ta	doc_491521502099_item	2588208	et	4	main
otsas	doc_491521502099_item	2588210	et	4	main
kooli	doc_491521502099_item	2588213	et	4	main
eesti	doc_491521502099_item	2588223	et	4	main
tunda	doc_491521502099_item	2588198	et	3	main
vaid	doc_491521502099_item	2588199	et	3	main
kooli	doc_491521502099_item	2588205	et	4	main
oravat	doc_491521502099_item	2588211	et	3	main
veidi	doc_491521502099_item	2588225	et	3	main
suurimat	doc_491521502099_item	2588230	et	3	main
esindades	doc_491521502099_item	2588233	et	3	main
matkal	doc_491521502099_item	2588237	et	3	main
tarvitanud	doc_491521502099_item	2588240	et	4	main
keetmata	doc_491521502099_item	2588242	et	4	main
3	doc_491521502099_item	2588249	et	2	main
hollandiga	doc_491521502099_item	2588252	et	4	main
on	doc_491521502099_item	2588253	et	4	main
maa	doc_491521502099_item	2588257	et	4	main
tamme	doc_491521502099_item	2588261	et	4	main
5	doc_491521502099_item	2588267	et	2	main
mõjuvõimu	doc_491521502099_item	2588272	et	4	main
avaldab	doc_491521502099_item	2588274	et	3	main
võtab	doc_491521502099_item	2588280	et	3	main
ja	doc_491521502099_item	2588283	et	3	main
vähendab	doc_491521502099_item	2588284	et	3	main
stressi	doc_491521502099_item	2588285	et	4	main
tõlkige	doc_491521502099_item	2588286	et	3	main
ходе	doc_491521502099_item	2588323	et	2	main
говорят	doc_491521502099_item	2588327	et	2	main
сообщали	doc_491521502099_item	2588334	et	2	main
безработица	doc_491521502099_item	2588336	et	2	main
olen	doc_491521502099_item	2588343	et	3	main
minu	doc_491521502099_item	2588346	et	3	main
kui	doc_491521502099_item	2588358	et	3	main
poeg	doc_491521502099_item	2588364	et	3	main
tallinn	doc_491521502099_item	2588375	et	4	main
4	doc_491521502099_item	2588389	et	2	main
grammatika	doc_491521502099_item	2588392	et	4	main
kergem	doc_491521502099_item	2588394	et	4	main
kui	doc_491521502099_item	2588395	et	3	main
keele	doc_491521502099_item	2588400	et	4	main
keele	doc_491521502099_item	2588406	et	4	main
puhtam	doc_491521502099_item	2588412	et	4	main
kui	doc_491521502099_item	2588413	et	3	main
sõle	doc_491521502099_item	2588414	et	3	main
kui	doc_491521502099_item	2588420	et	3	main
tänav	doc_491521502099_item	2588422	et	4	main
õige	doc_491521502099_item	2588424	et	4	main
kääne	doc_491521502099_item	2588425	et	3	main
ning	doc_491521502099_item	2588426	et	3	main
vajadusel	doc_491521502099_item	2588427	et	3	main
ka	doc_491521502099_item	2588428	et	3	main
tahan	doc_491521502099_item	2588430	et	3	main
puhata	doc_491521502099_item	2588431	et	4	main
hommik	doc_491521502099_item	2588432	et	3	main
hommikul	doc_491521502099_item	2588433	et	3	main
viimaste	doc_491521502099_item	2588439	et	3	main
villane	doc_491521502099_item	2588451	et	4	main
riidest	doc_491521502099_item	2588452	et	4	main
ma	doc_491521502099_item	2588454	et	3	main
olen	doc_491521502099_item	2588455	et	3	main
suvi	doc_491521502099_item	2588456	et	3	main
suvel	doc_491521502099_item	2588457	et	3	main
puhanud	doc_491521502099_item	2588458	et	4	main
mäed	doc_491521502099_item	2588459	et	3	main
isa	doc_491521502099_item	2588467	et	4	main
kool	doc_491521502099_item	2588478	et	4	main
koju	doc_491521502099_item	2588479	et	3	main
sellesse	doc_491521502099_item	2588488	et	4	main
kes	doc_491521502099_item	2588493	et	4	main
keel	doc_491521502099_item	2588500	et	4	main
itaalia	doc_491521502099_item	2588501	et	4	main
ilma	doc_491521502099_item	2588505	et	4	main
vigad	doc_491521502099_item	2588507	et	4	main
klassis	doc_491521502099_item	2588511	et	3	main
uued	doc_491521502099_item	2588513	et	3	main
õpilase	doc_491521502099_item	2588516	et	3	main
moodustavad	doc_491521502099_item	2588222	et	4	main
rahvusvähemust	doc_491521502099_item	2588232	et	4	main
olime	doc_491521502099_item	2588238	et	3	main
ja	doc_491521502099_item	2588244	et	3	main
võimalikult	doc_491521502099_item	2588247	et	4	main
läks	doc_491521502099_item	2588260	et	3	main
ja	doc_491521502099_item	2588273	et	3	main
seda	doc_491521502099_item	2588275	et	3	main
6	doc_491521502099_item	2588278	et	2	main
ära	doc_491521502099_item	2588281	et	4	main
umbisikulise	doc_491521502099_item	2588289	et	4	main
tegumoe	doc_491521502099_item	2588290	et	3	main
abil	doc_491521502099_item	2588291	et	4	main
vajaduse	doc_491521502099_item	2588292	et	3	main
korral	doc_491521502099_item	2588293	et	4	main
kasutage	doc_491521502099_item	2588294	et	3	main
vene-eesti	doc_491521502099_item	2588295	et	4	main
õppesõnastikku	doc_491521502099_item	2588296	et	4	main
1цели	doc_491521502099_item	2588297	et	2	main
достигают	doc_491521502099_item	2588298	et	2	main
временем	doc_491521502099_item	2588300	et	2	main
со	doc_491521502099_item	2588299	et	2	main
данные	doc_491521502099_item	2588302	et	2	main
2	doc_491521502099_item	2588301	et	2	main
о	doc_491521502099_item	2588303	et	2	main
семейном	doc_491521502099_item	2588304	et	2	main
положении	doc_491521502099_item	2588305	et	2	main
вчера	doc_491521502099_item	2588307	et	2	main
представляли	doc_491521502099_item	2588306	et	2	main
3	doc_491521502099_item	2588308	et	2	main
обсуждение	doc_491521502099_item	2588309	et	2	main
суммы	doc_491521502099_item	2588310	et	2	main
зарплаты	doc_491521502099_item	2588311	et	2	main
начинают	doc_491521502099_item	2588312	et	2	main
позже	doc_491521502099_item	2588313	et	2	main
4	doc_491521502099_item	2588314	et	2	main
вас	doc_491521502099_item	2588315	et	2	main
не	doc_491521502099_item	2588316	et	2	main
выбрали	doc_491521502099_item	2588317	et	2	main
эту	doc_491521502099_item	2588319	et	2	main
на	doc_491521502099_item	2588318	et	2	main
работу	doc_491521502099_item	2588320	et	2	main
с	doc_491521502099_item	2588325	et	2	main
труда	doc_491521502099_item	2588330	et	2	main
что	doc_491521502099_item	2588335	et	2	main
jätkake	doc_491521502099_item	2588338	et	3	main
järgi	doc_491521502099_item	2588340	et	4	main
беседы	doc_491521502099_item	2588324	et	2	main
об	doc_491521502099_item	2588328	et	2	main
не	doc_491521502099_item	2588333	et	2	main
kui	doc_491521502099_item	2588345	et	3	main
on	doc_491521502099_item	2588350	et	4	main
noorem	doc_491521502099_item	2588351	et	4	main
kui	doc_491521502099_item	2588352	et	3	main
mina	doc_491521502099_item	2588353	et	4	main
1	doc_491521502099_item	2588354	et	2	main
poeg	doc_491521502099_item	2588355	et	3	main
on	doc_491521502099_item	2588356	et	4	main
pikem	doc_491521502099_item	2588357	et	4	main
näidis	doc_491521502099_item	2588341	et	4	main
vanem	doc_491521502099_item	2588344	et	4	main
on	doc_491521502099_item	2588361	et	4	main
tallinn	doc_491521502099_item	2588366	et	4	main
suurem	doc_491521502099_item	2588368	et	4	main
kui	doc_491521502099_item	2588369	et	3	main
tartu	doc_491521502099_item	2588370	et	4	main
kui	doc_491521502099_item	2588374	et	3	main
3	doc_491521502099_item	2588376	et	2	main
heino	doc_491521502099_item	2588377	et	4	main
kalle	doc_491521502099_item	2588382	et	3	main
on	doc_491521502099_item	2588384	et	4	main
halvem	doc_491521502099_item	2588385	et	4	main
inglise	doc_491521502099_item	2588390	et	4	main
grammatika	doc_491521502099_item	2588401	et	4	main
on	doc_491521502099_item	2588402	et	4	main
tänav	doc_491521502099_item	2588415	et	4	main
sõle	doc_491521502099_item	2588416	et	3	main
tänav	doc_491521502099_item	2588417	et	4	main
meie	doc_491521502099_item	2588421	et	4	main
valige	doc_491521502099_item	2588423	et	3	main
tagasõna	doc_491521502099_item	2588429	et	4	main
viimane	doc_491521502099_item	2588438	et	3	main
on	doc_491521502099_item	2588448	et	4	main
riie	doc_491521502099_item	2588450	et	3	main
mägedest	doc_491521502099_item	2588461	et	3	main
kunstnikul	doc_491521502099_item	2588463	et	3	main
palju	doc_491521502099_item	2588465	et	4	main
kodu	doc_491521502099_item	2588477	et	4	main
see	doc_491521502099_item	2588486	et	3	main
auto	doc_491521502099_item	2588487	et	4	main
kuus	doc_491521502099_item	2588491	et	4	main
teksti	doc_491521502099_item	2588496	et	4	main
keel	doc_491521502099_item	2588498	et	4	main
vene	doc_491521502099_item	2588499	et	4	main
õpetaja	doc_491521502099_item	2588508	et	4	main
klass	doc_491521502099_item	2588510	et	3	main
klassi	doc_491521502099_item	2588512	et	4	main
õpilased	doc_491521502099_item	2588514	et	3	main
olevad	doc_491521502099_item	2588520	et	4	main
laused	doc_491521502099_item	2588527	et	3	main
saabusid	doc_491521502099_item	2588531	et	4	main
kohanemine	doc_491521502099_item	2588545	et	4	main
nõuab	doc_491521502099_item	2588546	et	3	main
lõigata	doc_491521502099_item	2588551	et	4	main
terav	doc_491521502099_item	2588552	et	3	main
ärge	doc_491521502099_item	2588555	et	3	main
nii	doc_491521502099_item	2588557	et	3	main
6	doc_491521502099_item	2588560	et	2	main
jutustuse	doc_491521502099_item	2588563	et	4	main
mees	doc_491521502099_item	2588568	et	4	main
minna	doc_491521502099_item	2588573	et	3	main
kohvrid	doc_491521502099_item	2588580	et	3	main
või	doc_491521502099_item	2588583	et	4	main
bussi	doc_491521502099_item	2588584	et	4	main
3	doc_491521502099_item	2588585	et	2	main
pidama	doc_491521502099_item	2588603	et	4	main
suitsetama	doc_491521502099_item	2588621	et	4	main
suitsetada	doc_491521502099_item	2588623	et	3	main
palju	doc_491521502099_item	2588624	et	4	main
te	doc_491521502099_item	2588625	et	4	main
hakkama	doc_491521502099_item	2588626	et	3	main
kirjutama	doc_491521502099_item	2588627	et	3	main
hakkate	doc_491521502099_item	2588628	et	3	main
kirjutama	doc_491521502099_item	2588629	et	3	main
tallinnas	doc_491521502099_item	2588651	et	4	main
õpetama	doc_491521502099_item	2588654	et	3	main
võõrkeelt	doc_491521502099_item	2588658	et	4	main
tõlkige	doc_491521502099_item	2588660	et	3	main
laused	doc_491521502099_item	2588661	et	3	main
eesti	doc_491521502099_item	2588662	et	4	main
подробное	doc_491521502099_item	2588669	et	2	main
бытовых	doc_491521502099_item	2588671	et	2	main
общаться	doc_491521502099_item	2588695	et	2	main
разных	doc_491521502099_item	2588701	et	2	main
отдыхают	doc_491521502099_item	2588705	et	2	main
довольно	doc_491521502099_item	2588710	et	2	main
очень	doc_491521502099_item	2588716	et	2	main
изменение	doc_491521502099_item	2588719	et	2	main
тяжело	doc_491521502099_item	2588722	et	2	main
oli	doc_491521502099_item	2588733	et	3	main
lühem	doc_491521502099_item	2588362	et	4	main
kui	doc_491521502099_item	2588363	et	3	main
on	doc_491521502099_item	2588367	et	4	main
väiksem	doc_491521502099_item	2588373	et	4	main
heino	doc_491521502099_item	2588388	et	4	main
keele	doc_491521502099_item	2588391	et	4	main
keele	doc_491521502099_item	2588397	et	4	main
grammatika	doc_491521502099_item	2588398	et	4	main
raskem	doc_491521502099_item	2588403	et	4	main
kui	doc_491521502099_item	2588404	et	3	main
inglise	doc_491521502099_item	2588405	et	4	main
on	doc_491521502099_item	2588411	et	4	main
kes	doc_491521502099_item	2588434	et	4	main
teist	doc_491521502099_item	2588435	et	4	main
sooritas	doc_491521502099_item	2588436	et	3	main
eksami	doc_491521502099_item	2588437	et	3	main
kleit	doc_491521502099_item	2588447	et	3	main
villane	doc_491521502099_item	2588449	et	4	main
on	doc_491521502099_item	2588464	et	4	main
kool	doc_491521502099_item	2588476	et	4	main
auto	doc_491521502099_item	2588485	et	4	main
inimest	doc_491521502099_item	2588492	et	3	main
vene	doc_491521502099_item	2588503	et	4	main
pange	doc_491521502099_item	2588518	et	4	main
kaasaütlevasse	doc_491521502099_item	2588522	et	3	main
käändesse	doc_491521502099_item	2588525	et	4	main
tõlkige	doc_491521502099_item	2588526	et	3	main
1turistid	doc_491521502099_item	2588530	et	3	main
suured	doc_491521502099_item	2588533	et	3	main
paljud	doc_491521502099_item	2588536	et	3	main
buss	doc_491521502099_item	2588541	et	3	main
kliima	doc_491521502099_item	2588544	et	4	main
nuga	doc_491521502099_item	2588553	et	4	main
eduard	doc_491521502099_item	2588561	et	4	main
pealkiri	doc_491521502099_item	2588564	et	3	main
on	doc_491521502099_item	2588565	et	4	main
7	doc_491521502099_item	2588569	et	2	main
nii	doc_491521502099_item	2588574	et	3	main
kui	doc_491521502099_item	2588576	et	3	main
suurest	doc_491521502099_item	2588579	et	4	main
kliima	doc_491521502099_item	2588587	et	4	main
4	doc_491521502099_item	2588588	et	2	main
6	doc_491521502099_item	2588594	et	2	main
kui	doc_491521502099_item	2588599	et	3	main
ta	doc_491521502099_item	2588601	et	4	main
pidab	doc_491521502099_item	2588605	et	4	main
viis	doc_491521502099_item	2588608	et	4	main
tüdrukud	doc_491521502099_item	2588610	et	3	main
oma	doc_491521502099_item	2588644	et	4	main
tuttavatele	doc_491521502099_item	2588645	et	3	main
me	doc_491521502099_item	2588646	et	4	main
hakkama	doc_491521502099_item	2588647	et	3	main
elama	doc_491521502099_item	2588648	et	3	main
õpema	doc_491521502099_item	2588656	et	4	main
keelde	doc_491521502099_item	2588663	et	4	main
1здесь	doc_491521502099_item	2588664	et	2	main
нет	doc_491521502099_item	2588665	et	2	main
описание	doc_491521502099_item	2588670	et	2	main
вас	doc_491521502099_item	2588692	et	2	main
6	doc_491521502099_item	2588696	et	2	main
много	doc_491521502099_item	2588700	et	2	main
8	doc_491521502099_item	2588706	et	2	main
этого	doc_491521502099_item	2588714	et	2	main
kalle	doc_491521502099_item	2588383	et	3	main
õpilane	doc_491521502099_item	2588386	et	3	main
kui	doc_491521502099_item	2588387	et	3	main
eesti	doc_491521502099_item	2588396	et	4	main
eesti	doc_491521502099_item	2588399	et	4	main
tänav	doc_491521502099_item	2588410	et	4	main
on	doc_491521502099_item	2588418	et	4	main
mustam	doc_491521502099_item	2588419	et	4	main
täna	doc_491521502099_item	2588441	et	4	main
oma	doc_491521502099_item	2588443	et	4	main
mäega	doc_491521502099_item	2588460	et	3	main
tööd	doc_491521502099_item	2588466	et	4	main
ostis	doc_491521502099_item	2588468	et	4	main
õhtu	doc_491521502099_item	2588469	et	4	main
õhtul	doc_491521502099_item	2588470	et	3	main
piletid	doc_491521502099_item	2588471	et	3	main
teater	doc_491521502099_item	2588472	et	3	main
teatrisse	doc_491521502099_item	2588473	et	3	main
kella	doc_491521502099_item	2588480	et	4	main
kolm	doc_491521502099_item	2588481	et	3	main
kolmeni	doc_491521502099_item	2588482	et	3	main
kolmeks	doc_491521502099_item	2588483	et	4	main
see	doc_491521502099_item	2588484	et	3	main
mahub	doc_491521502099_item	2588490	et	3	main
tõlkida	doc_491521502099_item	2588495	et	3	main
keeld	doc_491521502099_item	2588504	et	3	main
sulgudes	doc_491521502099_item	2588519	et	4	main
sõnad	doc_491521502099_item	2588521	et	4	main
või	doc_491521502099_item	2588523	et	4	main
omastavasse	doc_491521502099_item	2588524	et	4	main
eelistavad	doc_491521502099_item	2588537	et	4	main
rong	doc_491521502099_item	2588539	et	3	main
4	doc_491521502099_item	2588548	et	2	main
oksi	doc_491521502099_item	2588549	et	4	main
istuge	doc_491521502099_item	2588556	et	3	main
näod	doc_491521502099_item	2588559	et	3	main
soome	doc_491521502099_item	2588570	et	3	main
võimalik	doc_491521502099_item	2588572	et	3	main
1	doc_491521502099_item	2588578	et	2	main
2	doc_491521502099_item	2588581	et	2	main
nuga	doc_491521502099_item	2588590	et	4	main
mantel	doc_491521502099_item	2588596	et	3	main
lahkuma	doc_491521502099_item	2588604	et	3	main
taha	doc_491521502099_item	2588622	et	4	main
meeldib	doc_491521502099_item	2588634	et	3	main
hakkame	doc_491521502099_item	2588649	et	3	main
бытовых	doc_491521502099_item	2588666	et	2	main
у	doc_491521502099_item	2588691	et	2	main
эта	doc_491521502099_item	2588697	et	2	main
7	doc_491521502099_item	2588703	et	2	main
были	doc_491521502099_item	2588709	et	2	main
глаза	doc_491521502099_item	2588713	et	2	main
робкие	doc_491521502099_item	2588717	et	2	main
siin	doc_491521502099_item	2588724	et	4	main
3	doc_491521502099_item	2588729	et	2	main
teil	doc_491521502099_item	2588742	et	4	main
ole	doc_491521502099_item	2588744	et	4	main
suhtlemine	doc_491521502099_item	2588745	et	4	main
oskus	doc_491521502099_item	2588746	et	3	main
6	doc_491521502099_item	2588747	et	2	main
see	doc_491521502099_item	2588748	et	3	main
erinevad	doc_491521502099_item	2588753	et	4	main
9	doc_491521502099_item	2588764	et	2	main
väga	doc_491521502099_item	2588769	et	3	main
raske	doc_491521502099_item	2588775	et	4	main
täismineviku	doc_491521502099_item	2588783	et	3	main
1в	doc_491521502099_item	2588785	et	2	main
рабочий	doc_491521502099_item	2588789	et	2	main
утром	doc_491521502099_item	2588793	et	2	main
всю	doc_491521502099_item	2588797	et	2	main
не	doc_491521502099_item	2588802	et	2	main
что	doc_491521502099_item	2588806	et	2	main
я	doc_491521502099_item	2588813	et	2	main
нуждались	doc_491521502099_item	2588820	et	2	main
7	doc_491521502099_item	2588823	et	2	main
8	doc_491521502099_item	2588830	et	2	main
tööpäev	doc_491521502099_item	2588842	et	3	main
õppimine	doc_491521502099_item	2588847	et	4	main
me	doc_491521502099_item	2588849	et	4	main
ei	doc_491521502099_item	2588850	et	4	main
4	doc_491521502099_item	2588851	et	2	main
taha	doc_491521502099_item	2588860	et	4	main
viimasena	doc_491521502099_item	2588440	et	3	main
kohtun	doc_491521502099_item	2588442	et	3	main
sugulased	doc_491521502099_item	2588444	et	3	main
sugulast	doc_491521502099_item	2588445	et	4	main
see	doc_491521502099_item	2588446	et	3	main
tavaliselt	doc_491521502099_item	2588453	et	4	main
kunstnik	doc_491521502099_item	2588462	et	3	main
lapsed	doc_491521502099_item	2588474	et	3	main
tulevad	doc_491521502099_item	2588475	et	4	main
autosse	doc_491521502099_item	2588489	et	4	main
suudab	doc_491521502099_item	2588494	et	3	main
itaalia	doc_491521502099_item	2588497	et	4	main
keele	doc_491521502099_item	2588502	et	4	main
viga	doc_491521502099_item	2588506	et	4	main
tuli	doc_491521502099_item	2588509	et	4	main
uue	doc_491521502099_item	2588515	et	3	main
õpilastega	doc_491521502099_item	2588517	et	4	main
vene	doc_491521502099_item	2588528	et	4	main
lennujaama	doc_491521502099_item	2588532	et	4	main
2	doc_491521502099_item	2588535	et	2	main
või	doc_491521502099_item	2588540	et	4	main
3	doc_491521502099_item	2588542	et	2	main
palav	doc_491521502099_item	2588543	et	4	main
saab	doc_491521502099_item	2588550	et	3	main
5	doc_491521502099_item	2588554	et	2	main
hapud	doc_491521502099_item	2588558	et	3	main
vilde	doc_491521502099_item	2588562	et	4	main
must	doc_491521502099_item	2588566	et	4	main
mantel	doc_491521502099_item	2588567	et	3	main
on	doc_491521502099_item	2588571	et	4	main
palav	doc_491521502099_item	2588586	et	4	main
näoge	doc_491521502099_item	2588593	et	4	main
7	doc_491521502099_item	2588597	et	2	main
kell	doc_491521502099_item	2588607	et	3	main
need	doc_491521502099_item	2588609	et	3	main
keelde	doc_491521502099_item	2588529	et	4	main
kohvrid	doc_491521502099_item	2588534	et	3	main
reisida	doc_491521502099_item	2588538	et	3	main
aega	doc_491521502099_item	2588547	et	4	main
laev	doc_491521502099_item	2588575	et	3	main
lennuk	doc_491521502099_item	2588577	et	3	main
rongi	doc_491521502099_item	2588582	et	4	main
terava	doc_491521502099_item	2588589	et	3	main
5	doc_491521502099_item	2588591	et	2	main
hapuge	doc_491521502099_item	2588592	et	4	main
must	doc_491521502099_item	2588595	et	4	main
laeva	doc_491521502099_item	2588598	et	4	main
lennuke	doc_491521502099_item	2588600	et	4	main
tavaliselt	doc_491521502099_item	2588602	et	4	main
lahkuma	doc_491521502099_item	2588606	et	3	main
võima	doc_491521502099_item	2588611	et	3	main
rääkima	doc_491521502099_item	2588612	et	3	main
võin	doc_491521502099_item	2588613	et	3	main
oskan	doc_491521502099_item	2588614	et	3	main
rääkida	doc_491521502099_item	2588615	et	3	main
kolme	doc_491521502099_item	2588616	et	4	main
võõrkeelt	doc_491521502099_item	2588617	et	4	main
ei	doc_491521502099_item	2588619	et	4	main
tahtma	doc_491521502099_item	2588620	et	3	main
ta	doc_491521502099_item	2588618	et	4	main
harjutust	doc_491521502099_item	2588630	et	4	main
talle	doc_491521502099_item	2588631	et	4	main
meeldima	doc_491521502099_item	2588632	et	3	main
töötama	doc_491521502099_item	2588633	et	3	main
töötada	doc_491521502099_item	2588635	et	3	main
elama	doc_491521502099_item	2588650	et	3	main
oskama	doc_491521502099_item	2588653	et	3	main
oskan	doc_491521502099_item	2588655	et	3	main
õpetama	doc_491521502099_item	2588657	et	3	main
удобств	doc_491521502099_item	2588667	et	2	main
умения	doc_491521502099_item	2588694	et	2	main
работа	doc_491521502099_item	2588698	et	2	main
умений	doc_491521502099_item	2588702	et	2	main
людей	doc_491521502099_item	2588708	et	2	main
9	doc_491521502099_item	2588712	et	2	main
10	doc_491521502099_item	2588718	et	2	main
проходит	doc_491521502099_item	2588721	et	2	main
ole	doc_491521502099_item	2588726	et	4	main
kodutarve	doc_491521502099_item	2588727	et	3	main
sellel	doc_491521502099_item	2588730	et	4	main
aastal	doc_491521502099_item	2588731	et	3	main
mul	doc_491521502099_item	2588732	et	3	main
võidat	doc_491521502099_item	2588736	et	4	main
suured	doc_491521502099_item	2588738	et	3	main
5	doc_491521502099_item	2588741	et	2	main
olema	doc_491521502099_item	2588751	et	4	main
inimesed	doc_491521502099_item	2588756	et	3	main
puhkavad	doc_491521502099_item	2588758	et	4	main
inimene	doc_491521502099_item	2588766	et	3	main
on	doc_491521502099_item	2588768	et	4	main
10	doc_491521502099_item	2588770	et	2	main
isehinned	doc_491521502099_item	2588771	et	4	main
või	doc_491521502099_item	2588782	et	4	main
то	doc_491521502099_item	2588786	et	2	main
день	doc_491521502099_item	2588790	et	2	main
2	doc_491521502099_item	2588794	et	2	main
жизнь	doc_491521502099_item	2588798	et	2	main
оказываем	doc_491521502099_item	2588803	et	2	main
вас	doc_491521502099_item	2588808	et	2	main
что	doc_491521502099_item	2588812	et	2	main
6	doc_491521502099_item	2588817	et	2	main
разумным	doc_491521502099_item	2588828	et	2	main
вносил	doc_491521502099_item	2588833	et	2	main
ясность	doc_491521502099_item	2588836	et	2	main
iga	doc_491521502099_item	2588840	et	4	main
algab	doc_491521502099_item	2588843	et	3	main
2	doc_491521502099_item	2588846	et	2	main
selles	doc_491521502099_item	2588636	et	4	main
ettevõttes	doc_491521502099_item	2588637	et	3	main
ma	doc_491521502099_item	2588638	et	3	main
tahtma	doc_491521502099_item	2588639	et	3	main
kirjutama	doc_491521502099_item	2588640	et	3	main
tahan	doc_491521502099_item	2588641	et	3	main
kirjutama	doc_491521502099_item	2588642	et	3	main
kirja	doc_491521502099_item	2588643	et	4	main
ma	doc_491521502099_item	2588652	et	3	main
välismaalastele	doc_491521502099_item	2588659	et	4	main
2	doc_491521502099_item	2588668	et	2	main
удобств	doc_491521502099_item	2588672	et	2	main
требует	doc_491521502099_item	2588673	et	2	main
времени	doc_491521502099_item	2588674	et	2	main
3	doc_491521502099_item	2588675	et	2	main
в	doc_491521502099_item	2588676	et	2	main
этом	doc_491521502099_item	2588677	et	2	main
году	doc_491521502099_item	2588678	et	2	main
у	doc_491521502099_item	2588679	et	2	main
меня	doc_491521502099_item	2588680	et	2	main
три	doc_491521502099_item	2588682	et	2	main
было	doc_491521502099_item	2588681	et	2	main
больших	doc_491521502099_item	2588683	et	2	main
достижения	doc_491521502099_item	2588684	et	2	main
4	doc_491521502099_item	2588685	et	2	main
большие	doc_491521502099_item	2588686	et	2	main
достижения	doc_491521502099_item	2588687	et	2	main
будут	doc_491521502099_item	2588688	et	2	main
завтра	doc_491521502099_item	2588689	et	2	main
5	doc_491521502099_item	2588690	et	2	main
нет	doc_491521502099_item	2588693	et	2	main
требует	doc_491521502099_item	2588699	et	2	main
люди	doc_491521502099_item	2588704	et	2	main
лица	doc_491521502099_item	2588707	et	2	main
простые	doc_491521502099_item	2588711	et	2	main
человека	doc_491521502099_item	2588715	et	2	main
самооценки	doc_491521502099_item	2588720	et	2	main
1	doc_491521502099_item	2588723	et	2	main
2	doc_491521502099_item	2588728	et	2	main
kolm	doc_491521502099_item	2588734	et	3	main
4	doc_491521502099_item	2588737	et	2	main
olla	doc_491521502099_item	2588740	et	3	main
ei	doc_491521502099_item	2588743	et	4	main
palju	doc_491521502099_item	2588752	et	4	main
on	doc_491521502099_item	2588757	et	4	main
inimese	doc_491521502099_item	2588760	et	4	main
muutus	doc_491521502099_item	2588772	et	4	main
väga	doc_491521502099_item	2588774	et	3	main
tulemus	doc_491521502099_item	2588776	et	3	main
kas	doc_491521502099_item	2588780	et	3	main
продолжалось	doc_491521502099_item	2588796	et	2	main
3	doc_491521502099_item	2588799	et	2	main
давления	doc_491521502099_item	2588804	et	2	main
случилось	doc_491521502099_item	2588809	et	2	main
не	doc_491521502099_item	2588814	et	2	main
мы	doc_491521502099_item	2588818	et	2	main
обсуждение	doc_491521502099_item	2588825	et	2	main
решением	doc_491521502099_item	2588829	et	2	main
в	doc_491521502099_item	2588834	et	2	main
selle	doc_491521502099_item	2588838	et	4	main
üks	doc_491521502099_item	2588841	et	3	main
vara	doc_491521502099_item	2588844	et	4	main
teil	doc_491521502099_item	2588853	et	4	main
5	doc_491521502099_item	2588855	et	2	main
6	doc_491521502099_item	2588862	et	2	main
olevad	doc_491521502100_item	2588868	et	4	main
sõnad	doc_491521502100_item	2588869	et	4	main
elame	doc_491521502100_item	2588879	et	3	main
oktoober	doc_491521502100_item	2588922	et	3	main
tehtud	doc_491521502100_item	2588926	et	4	main
on	doc_491521502100_item	2588929	et	4	main
on	doc_491521502100_item	2588933	et	4	main
ainult	doc_491521502100_item	2588936	et	4	main
vajalikku	doc_491521502100_item	2588948	et	4	main
1	doc_491521502100_item	2588949	et	2	main
majja	doc_491521502100_item	2588951	et	3	main
majast	doc_491521502100_item	2588954	et	4	main
majapidamistarvete	doc_491521502100_item	2588969	et	4	main
talvel	doc_491521502100_item	2588981	et	4	main
kutsuti	doc_491521502100_item	2588982	et	3	main
mind	doc_491521502100_item	2588983	et	4	main
2	doc_491521502100_item	2588988	et	2	main
direktor	doc_491521502100_item	2588989	et	3	main
teatas	doc_491521502100_item	2588990	et	3	main
et	doc_491521502100_item	2588991	et	3	main
majandusjuhataja	doc_491521502100_item	2588992	et	4	main
mina	doc_491521502100_item	2588994	et	4	main
ei	doc_491521502099_item	2588725	et	4	main
võidad	doc_491521502099_item	2588739	et	3	main
töö	doc_491521502099_item	2588749	et	4	main
oskused	doc_491521502099_item	2588754	et	3	main
see	doc_491521502099_item	2588765	et	3	main
silmad	doc_491521502099_item	2588767	et	4	main
on	doc_491521502099_item	2588773	et	4	main
eesti	doc_491521502099_item	2588778	et	4	main
keelde	doc_491521502099_item	2588779	et	4	main
abil	doc_491521502099_item	2588784	et	4	main
каждый	doc_491521502099_item	2588788	et	2	main
начинался	doc_491521502099_item	2588791	et	2	main
обучение	doc_491521502099_item	2588795	et	2	main
никогда	doc_491521502099_item	2588801	et	2	main
4	doc_491521502099_item	2588805	et	2	main
5	doc_491521502099_item	2588810	et	2	main
хотел	doc_491521502099_item	2588815	et	2	main
постоянно	doc_491521502099_item	2588819	et	2	main
совете	doc_491521502099_item	2588822	et	2	main
бывало	doc_491521502099_item	2588826	et	2	main
он	doc_491521502099_item	2588831	et	2	main
дело	doc_491521502099_item	2588835	et	2	main
aega	doc_491521502099_item	2588839	et	4	main
pange	doc_491521502100_item	2588866	et	4	main
laused	doc_491521502100_item	2588873	et	3	main
1homme	doc_491521502100_item	2588874	et	3	main
uus	doc_491521502100_item	2588880	et	3	main
juba	doc_491521502100_item	2588882	et	3	main
on	doc_491521502100_item	2588925	et	4	main
auk	doc_491521502100_item	2588927	et	3	main
auk	doc_491521502100_item	2588931	et	3	main
5	doc_491521502100_item	2588938	et	2	main
osakond	doc_491521502100_item	2588942	et	3	main
osakond	doc_491521502100_item	2588944	et	3	main
leidub	doc_491521502100_item	2588945	et	3	main
majas	doc_491521502100_item	2588953	et	3	main
2	doc_491521502100_item	2588955	et	2	main
saav	doc_491521502100_item	2588977	et	4	main
olev	doc_491521502100_item	2588979	et	4	main
1möödunud	doc_491521502100_item	2588980	et	4	main
tähtaeg	doc_491521502100_item	2588996	et	3	main
remondi	doc_491521502100_item	2588998	et	4	main
3	doc_491521502100_item	2589000	et	2	main
haritud	doc_491521502100_item	2589001	et	4	main
inimene	doc_491521502100_item	2589002	et	3	main
jagunenud	doc_491521502100_item	2589021	et	4	main
eestlased	doc_491521502100_item	2589027	et	3	main
esindajad	doc_491521502100_item	2589036	et	4	main
tähtajaks	doc_491521502100_item	2589042	et	3	main
inimesena	doc_491521502100_item	2589044	et	3	main
5	doc_491521502100_item	2589047	et	2	main
sulgudes	doc_491521502100_item	2589054	et	4	main
sõnad	doc_491521502100_item	2589056	et	4	main
ei	doc_491521502100_item	2589067	et	4	main
oli	doc_491521502100_item	2589075	et	3	main
suur	doc_491521502100_item	2589083	et	3	main
reis	doc_491521502100_item	2589096	et	4	main
möödub	doc_491521502100_item	2589097	et	3	main
6	doc_491521502100_item	2589101	et	2	main
ei	doc_491521502100_item	2589105	et	4	main
saabus	doc_491521502100_item	2589112	et	3	main
1	doc_491521502100_item	2589115	et	2	main
2	doc_491521502100_item	2589117	et	2	main
pesemata	doc_491521502100_item	2589118	et	4	main
huvi	doc_491521502100_item	2589121	et	4	main
suured	doc_491521502099_item	2588735	et	3	main
peab	doc_491521502099_item	2588750	et	4	main
7	doc_491521502099_item	2588755	et	2	main
8	doc_491521502099_item	2588759	et	2	main
on	doc_491521502099_item	2588761	et	4	main
väga	doc_491521502099_item	2588762	et	3	main
lihsad	doc_491521502099_item	2588763	et	4	main
tõlkige	doc_491521502099_item	2588777	et	3	main
liht-	doc_491521502099_item	2588781	et	3	main
время	doc_491521502099_item	2588787	et	2	main
рано	doc_491521502099_item	2588792	et	2	main
мы	doc_491521502099_item	2588800	et	2	main
у	doc_491521502099_item	2588807	et	2	main
случалось	doc_491521502099_item	2588811	et	2	main
учиться	doc_491521502099_item	2588816	et	2	main
в	doc_491521502099_item	2588821	et	2	main
спокойное	doc_491521502099_item	2588824	et	2	main
самым	doc_491521502099_item	2588827	et	2	main
всегда	doc_491521502099_item	2588832	et	2	main
1	doc_491521502099_item	2588837	et	2	main
hommikul	doc_491521502099_item	2588845	et	3	main
3	doc_491521502099_item	2588848	et	2	main
juhtus	doc_491521502099_item	2588854	et	3	main
juhtub	doc_491521502099_item	2588856	et	3	main
ei	doc_491521502099_item	2588859	et	4	main
sulgudes	doc_491521502100_item	2588867	et	4	main
me	doc_491521502100_item	2588878	et	4	main
aastat	doc_491521502100_item	2588884	et	3	main
helista	doc_491521502100_item	2588887	et	4	main
tulen	doc_491521502100_item	2588888	et	3	main
maja	doc_491521502100_item	2588889	et	4	main
välja	doc_491521502100_item	2588890	et	4	main
sulle	doc_491521502100_item	2588891	et	3	main
vastu	doc_491521502100_item	2588892	et	3	main
2	doc_491521502100_item	2588893	et	2	main
langesin	doc_491521502100_item	2588894	et	3	main
sinu	doc_491521502100_item	2588895	et	3	main
pärast	doc_491521502100_item	2588896	et	4	main
kurbus	doc_491521502100_item	2588897	et	4	main
juba	doc_491521502100_item	2588898	et	3	main
mitmendat	doc_491521502100_item	2588899	et	3	main
nädalat	doc_491521502100_item	2588900	et	3	main
viibin	doc_491521502100_item	2588901	et	3	main
sügav	doc_491521502100_item	2588902	et	4	main
kurbus	doc_491521502100_item	2588903	et	4	main
loodan	doc_491521502100_item	2588904	et	3	main
peagi	doc_491521502100_item	2588905	et	4	main
oma	doc_491521502100_item	2588906	et	4	main
kurbus	doc_491521502100_item	2588907	et	4	main
vabaneda	doc_491521502100_item	2588908	et	3	main
3	doc_491521502100_item	2588909	et	2	main
kaupluse	doc_491521502100_item	2588910	et	3	main
avamine	doc_491521502100_item	2588911	et	4	main
lükkub	doc_491521502100_item	2588912	et	3	main
oktoober	doc_491521502100_item	2588913	et	3	main
kauplus	doc_491521502100_item	2588914	et	3	main
avatakse	doc_491521502100_item	2588915	et	4	main
oktoober	doc_491521502100_item	2588916	et	3	main
kauplus	doc_491521502100_item	2588917	et	3	main
on	doc_491521502100_item	2588918	et	4	main
külastajatele	doc_491521502100_item	2588919	et	4	main
avatud	doc_491521502100_item	2588920	et	4	main
mida	doc_491521502099_item	2588852	et	4	main
et	doc_491521502099_item	2588857	et	3	main
ma	doc_491521502099_item	2588858	et	3	main
õpida	doc_491521502099_item	2588861	et	4	main
me	doc_491521502099_item	2588863	et	4	main
alates	doc_491521502100_item	2588921	et	3	main
sein	doc_491521502100_item	2588932	et	3	main
kivid	doc_491521502100_item	2588937	et	3	main
majapidamistarvete	doc_491521502100_item	2588943	et	4	main
midagi	doc_491521502100_item	2588947	et	4	main
kurbust	doc_491521502100_item	2588956	et	4	main
kurbust	doc_491521502100_item	2588959	et	4	main
4	doc_491521502100_item	2588964	et	2	main
seinal	doc_491521502100_item	2588965	et	3	main
seinas	doc_491521502100_item	2588966	et	3	main
seinast	doc_491521502100_item	2588967	et	4	main
osakonna	doc_491521502100_item	2588970	et	4	main
osakonnas	doc_491521502100_item	2588972	et	4	main
valige	doc_491521502100_item	2588973	et	3	main
õige	doc_491521502100_item	2588974	et	4	main
kääne	doc_491521502100_item	2588975	et	3	main
vastutan	doc_491521502100_item	2588993	et	3	main
valminud	doc_491521502100_item	2588997	et	4	main
eest	doc_491521502100_item	2588999	et	4	main
erinevad	doc_491521502100_item	2589022	et	4	main
6	doc_491521502100_item	2589024	et	2	main
mõned	doc_491521502100_item	2589025	et	3	main
teised	doc_491521502100_item	2589030	et	4	main
1	doc_491521502100_item	2589037	et	2	main
majandusjuhatajaks	doc_491521502100_item	2589038	et	3	main
rahvasena	doc_491521502100_item	2589046	et	4	main
pange	doc_491521502100_item	2589053	et	4	main
olevad	doc_491521502100_item	2589055	et	4	main
vene	doc_491521502100_item	2589063	et	4	main
keelde	doc_491521502100_item	2589064	et	4	main
piiri	doc_491521502100_item	2589070	et	4	main
2	doc_491521502100_item	2589072	et	2	main
poisi	doc_491521502100_item	2589073	et	3	main
nägu	doc_491521502100_item	2589074	et	4	main
reisijad	doc_491521502100_item	2589078	et	4	main
ilma	doc_491521502100_item	2589082	et	4	main
ole	doc_491521502100_item	2589106	et	4	main
viisat	doc_491521502100_item	2589108	et	3	main
rong	doc_491521502100_item	2589111	et	3	main
5	doc_491521502100_item	2589124	et	2	main
taotlust	doc_491521502100_item	2589129	et	4	main
lauseid	doc_491521502100_item	2589133	et	3	main
et	doc_491521502100_item	2589135	et	3	main
tegusõnast	doc_491521502100_item	2589137	et	4	main
des-vorm	doc_491521502100_item	2589139	et	3	main
end	doc_491521502100_item	2589154	et	4	main
tööstuspiirkonnas	doc_491521502100_item	2589157	et	4	main
keskkonna	doc_491521502100_item	2589158	et	3	main
end	doc_491521502100_item	2589165	et	4	main
vaid	doc_491521502100_item	2589167	et	3	main
karin	doc_491521502100_item	2589171	et	4	main
alla	doc_491521502100_item	2589194	et	3	main
kolmandiku	doc_491521502100_item	2589195	et	3	main
ja	doc_491521502100_item	2589196	et	3	main
esindavad	doc_491521502100_item	2589197	et	4	main
suurimat	doc_491521502100_item	2589198	et	3	main
olime	doc_491521502100_item	2589205	et	3	main
maa	doc_491521502100_item	2589224	et	4	main
4	doc_491521502100_item	2589225	et	2	main
teatavat	doc_491521502100_item	2589238	et	4	main
ära	doc_491521502100_item	2589248	et	4	main
ja	doc_491521502100_item	2589250	et	3	main
eesti	doc_491521502100_item	2589256	et	4	main
rahvusvähemust	doc_491521502100_item	2589264	et	4	main
me	doc_491521502100_item	2589270	et	4	main
püüdes	doc_491521502100_item	2589273	et	4	main
hõreda	doc_491521502100_item	2589282	et	3	main
juurde	doc_491521502100_item	2589289	et	4	main
lootes	doc_491521502100_item	2589290	et	4	main
1цели	doc_491521502100_item	2589321	et	2	main
данные	doc_491521502100_item	2589326	et	2	main
представляли	doc_491521502100_item	2589330	et	2	main
зарплаты	doc_491521502100_item	2589335	et	2	main
выбрали	doc_491521502100_item	2589341	et	2	main
5	doc_491521502100_item	2589345	et	2	main
говорят	doc_491521502100_item	2589351	et	2	main
alati	doc_491521502099_item	2588864	et	4	main
kontrolltöö	doc_491521502100_item	2588865	et	4	main
vastavatesse	doc_491521502100_item	2588870	et	4	main
sisekohakäänetesse	doc_491521502100_item	2588871	et	3	main
tõlkige	doc_491521502100_item	2588872	et	3	main
kolime	doc_491521502100_item	2588875	et	3	main
uus	doc_491521502100_item	2588876	et	3	main
maja	doc_491521502100_item	2588877	et	4	main
maja	doc_491521502100_item	2588881	et	4	main
pool	doc_491521502100_item	2588883	et	4	main
kohale	doc_491521502100_item	2588885	et	4	main
jõudes	doc_491521502100_item	2588886	et	3	main
sein	doc_491521502100_item	2588924	et	3	main
sein	doc_491521502100_item	2588928	et	3	main
nüüd	doc_491521502100_item	2588940	et	4	main
alati	doc_491521502100_item	2588946	et	4	main
sügavat	doc_491521502100_item	2588957	et	4	main
kurbust	doc_491521502100_item	2588958	et	4	main
3	doc_491521502100_item	2588960	et	2	main
oktoobris	doc_491521502100_item	2588961	et	3	main
oktoobris	doc_491521502100_item	2588962	et	3	main
oktoobrist	doc_491521502100_item	2588963	et	3	main
kas	doc_491521502100_item	2588976	et	3	main
või	doc_491521502100_item	2588978	et	4	main
ajutiselt	doc_491521502100_item	2588984	et	4	main
sellesse	doc_491521502100_item	2588985	et	4	main
kutsekooli	doc_491521502100_item	2588986	et	4	main
kasvamine	doc_491521502100_item	2589003	et	4	main
haritud	doc_491521502100_item	2589026	et	4	main
end	doc_491521502100_item	2589032	et	4	main
majandusjuhatajana	doc_491521502100_item	2589040	et	3	main
baltisakslasteks	doc_491521502100_item	2589051	et	4	main
või	doc_491521502100_item	2589058	et	4	main
käändesse	doc_491521502100_item	2589060	et	4	main
ole	doc_491521502100_item	2589068	et	4	main
lubatud	doc_491521502100_item	2589069	et	4	main
pesema	doc_491521502100_item	2589076	et	3	main
ettepanekusse	doc_491521502100_item	2589081	et	3	main
4	doc_491521502100_item	2589085	et	2	main
all	doc_491521502100_item	2589087	et	3	main
paks	doc_491521502100_item	2589089	et	3	main
saba	doc_491521502100_item	2589090	et	4	main
kass	doc_491521502100_item	2589091	et	3	main
5	doc_491521502100_item	2589092	et	2	main
ärge	doc_491521502100_item	2589093	et	3	main
uskuge	doc_491521502100_item	2589094	et	3	main
et	doc_491521502100_item	2589095	et	3	main
vaatamisväärsused	doc_491521502100_item	2589100	et	4	main
ametlik	doc_491521502100_item	2589103	et	3	main
kohale	doc_491521502100_item	2589113	et	4	main
4	doc_491521502100_item	2589122	et	2	main
igasuguseid	doc_491521502100_item	2589125	et	3	main
ametlikku	doc_491521502100_item	2589128	et	4	main
viimasest	doc_491521502100_item	2589136	et	3	main
saaks	doc_491521502100_item	2589138	et	3	main
laused	doc_491521502100_item	2589141	et	3	main
keelde	doc_491521502100_item	2589143	et	4	main
näidis	doc_491521502100_item	2589144	et	4	main
tugev	doc_491521502100_item	2589151	et	4	main
ja	doc_491521502100_item	2589152	et	3	main
annab	doc_491521502100_item	2589153	et	3	main
ole	doc_491521502100_item	2589161	et	4	main
eriti	doc_491521502100_item	2589162	et	3	main
b	doc_491521502100_item	2589169	et	4	main
kui	doc_491521502100_item	2589170	et	3	main
hommikul	doc_491521502100_item	2589172	et	3	main
karin	doc_491521502100_item	2589184	et	4	main
1	doc_491521502100_item	2589188	et	2	main
moodustavad	doc_491521502100_item	2589190	et	4	main
me	doc_491521502100_item	2589203	et	4	main
tarvitanud	doc_491521502100_item	2589207	et	4	main
läks	doc_491521502100_item	2589227	et	3	main
juurde	doc_491521502100_item	2589229	et	4	main
selle	doc_491521502100_item	2589232	et	4	main
abile	doc_491521502100_item	2589233	et	3	main
5	doc_491521502100_item	2589234	et	2	main
kask	doc_491521502100_item	2589246	et	3	main
stressi	doc_491521502100_item	2589252	et	4	main
kolmandiku	doc_491521502100_item	2589260	et	3	main
suurimat	doc_491521502100_item	2589262	et	3	main
olles	doc_491521502100_item	2589267	et	3	main
4	doc_491521502100_item	2588923	et	2	main
sügav	doc_491521502100_item	2588930	et	4	main
järele	doc_491521502100_item	2588934	et	4	main
jäänud	doc_491521502100_item	2588935	et	4	main
läheme	doc_491521502100_item	2588939	et	3	main
majapidamistarvete	doc_491521502100_item	2588941	et	4	main
uue	doc_491521502100_item	2588950	et	3	main
uues	doc_491521502100_item	2588952	et	3	main
5	doc_491521502100_item	2588968	et	2	main
majapidamistarvete	doc_491521502100_item	2588971	et	4	main
majandusjuhataja	doc_491521502100_item	2588987	et	4	main
õige	doc_491521502100_item	2588995	et	4	main
nõuab	doc_491521502100_item	2589004	et	3	main
töökust	doc_491521502100_item	2589005	et	4	main
ja	doc_491521502100_item	2589006	et	3	main
kannatlikust	doc_491521502100_item	2589007	et	4	main
4	doc_491521502100_item	2589008	et	2	main
väikese	doc_491521502100_item	2589009	et	4	main
rahvas	doc_491521502100_item	2589010	et	4	main
muretsevad	doc_491521502100_item	2589011	et	4	main
eestlased	doc_491521502100_item	2589012	et	3	main
oma	doc_491521502100_item	2589013	et	4	main
keele	doc_491521502100_item	2589014	et	4	main
saatuse	doc_491521502100_item	2589015	et	3	main
pärast	doc_491521502100_item	2589016	et	4	main
5	doc_491521502100_item	2589017	et	2	main
ajalooliselt	doc_491521502100_item	2589018	et	4	main
eesti	doc_491521502100_item	2589020	et	4	main
oli	doc_491521502100_item	2589019	et	3	main
baltisakslased	doc_491521502100_item	2589029	et	3	main
2	doc_491521502100_item	2589039	et	2	main
õigeks	doc_491521502100_item	2589041	et	3	main
3	doc_491521502100_item	2589043	et	2	main
maakondadeks	doc_491521502100_item	2589049	et	3	main
ilmaütlevasse	doc_491521502100_item	2589057	et	3	main
tõlkige	doc_491521502100_item	2589061	et	3	main
laused	doc_491521502100_item	2589062	et	3	main
1ilma	doc_491521502100_item	2589065	et	4	main
pass	doc_491521502100_item	2589066	et	3	main
ületada	doc_491521502100_item	2589071	et	3	main
giidi	doc_491521502100_item	2589080	et	4	main
huvi	doc_491521502100_item	2589084	et	4	main
istus	doc_491521502100_item	2589088	et	4	main
igasugused	doc_491521502100_item	2589099	et	3	main
taotlus	doc_491521502100_item	2589104	et	4	main
võimalik	doc_491521502100_item	2589107	et	3	main
vormistada	doc_491521502100_item	2589109	et	3	main
hilinemine	doc_491521502100_item	2589114	et	4	main
passi	doc_491521502100_item	2589116	et	4	main
3	doc_491521502100_item	2589119	et	2	main
suurt	doc_491521502100_item	2589120	et	3	main
hilinemiseta	doc_491521502100_item	2589131	et	4	main
muutke	doc_491521502100_item	2589132	et	3	main
nii	doc_491521502100_item	2589134	et	3	main
tõlkige	doc_491521502100_item	2589140	et	3	main
vene	doc_491521502100_item	2589142	et	4	main
saastatus	doc_491521502100_item	2589147	et	4	main
tugev	doc_491521502100_item	2589163	et	4	main
tööstuspiirkonnas	doc_491521502100_item	2589168	et	4	main
otsas	doc_491521502100_item	2589178	et	4	main
oravat	doc_491521502100_item	2589179	et	3	main
hommikul	doc_491521502100_item	2589180	et	3	main
kooli	doc_491521502100_item	2589181	et	4	main
nägi	doc_491521502100_item	2589183	et	3	main
maakonnad	doc_491521502100_item	2589023	et	4	main
muutusid	doc_491521502100_item	2589028	et	4	main
tundsid	doc_491521502100_item	2589031	et	4	main
endiselt	doc_491521502100_item	2589033	et	4	main
oma	doc_491521502100_item	2589034	et	4	main
rahva	doc_491521502100_item	2589035	et	3	main
4	doc_491521502100_item	2589045	et	2	main
erinevateks	doc_491521502100_item	2589048	et	4	main
6	doc_491521502100_item	2589050	et	2	main
esindajatena	doc_491521502100_item	2589052	et	4	main
omastavasse	doc_491521502100_item	2589059	et	4	main
3	doc_491521502100_item	2589077	et	2	main
suhtusid	doc_491521502100_item	2589079	et	4	main
puu	doc_491521502100_item	2589086	et	4	main
ilma	doc_491521502100_item	2589098	et	4	main
ilma	doc_491521502100_item	2589102	et	4	main
7	doc_491521502100_item	2589110	et	2	main
vaatamisväärsuseid	doc_491521502100_item	2589126	et	4	main
6	doc_491521502100_item	2589127	et	2	main
7	doc_491521502100_item	2589130	et	2	main
keskkonna	doc_491521502100_item	2589146	et	3	main
ei	doc_491521502100_item	2589148	et	4	main
ole	doc_491521502100_item	2589149	et	4	main
eriti	doc_491521502100_item	2589150	et	3	main
saastatus	doc_491521502100_item	2589159	et	4	main
ei	doc_491521502100_item	2589160	et	4	main
tunda	doc_491521502100_item	2589166	et	3	main
kooli	doc_491521502100_item	2589173	et	4	main
ta	doc_491521502100_item	2589176	et	4	main
puu	doc_491521502100_item	2589177	et	4	main
oravat	doc_491521502100_item	2589187	et	3	main
kohalikku	doc_491521502100_item	2589199	et	4	main
keetmata	doc_491521502100_item	2589209	et	4	main
vett	doc_491521502100_item	2589210	et	3	main
ja	doc_491521502100_item	2589211	et	3	main
püüdsime	doc_491521502100_item	2589212	et	3	main
olla	doc_491521502100_item	2589213	et	3	main
tamme	doc_491521502100_item	2589228	et	4	main
ja	doc_491521502100_item	2589230	et	3	main
lootis	doc_491521502100_item	2589231	et	3	main
6	doc_491521502100_item	2589245	et	2	main
esindades	doc_491521502100_item	2589261	et	3	main
kohalikku	doc_491521502100_item	2589263	et	4	main
tarvitanud	doc_491521502100_item	2589269	et	4	main
vett	doc_491521502100_item	2589272	et	3	main
võimalikult	doc_491521502100_item	2589275	et	4	main
3	doc_491521502100_item	2589277	et	2	main
tamme	doc_491521502100_item	2589288	et	4	main
abile	doc_491521502100_item	2589292	et	3	main
со	doc_491521502100_item	2589323	et	2	main
о	doc_491521502100_item	2589327	et	2	main
3	doc_491521502100_item	2589332	et	2	main
4	doc_491521502100_item	2589338	et	2	main
не	doc_491521502100_item	2589340	et	2	main
работу	doc_491521502100_item	2589344	et	2	main
об	doc_491521502100_item	2589352	et	2	main
вчера	doc_491521502100_item	2589356	et	2	main
ajaga	doc_491521502100_item	2589365	et	3	main
töö	doc_491521502100_item	2589377	et	4	main
et	doc_491521502100_item	2589383	et	3	main
olen	doc_491521502100_item	2589391	et	3	main
mina	doc_491521502100_item	2589401	et	4	main
isa	doc_491521502100_item	2589408	et	4	main
kui	doc_491521502100_item	2589411	et	3	main
heino	doc_491521502100_item	2589425	et	4	main
parem	doc_491521502100_item	2589427	et	4	main
kui	doc_491521502100_item	2589429	et	3	main
kalle	doc_491521502100_item	2589431	et	3	main
halvem	doc_491521502100_item	2589433	et	4	main
on	doc_491521502100_item	2589441	et	4	main
keele	doc_491521502100_item	2589445	et	4	main
raskem	doc_491521502100_item	2589451	et	4	main
on	doc_491521502100_item	2589459	et	4	main
puhtam	doc_491521502100_item	2589460	et	4	main
kui	doc_491521502100_item	2589461	et	3	main
sõle	doc_491521502100_item	2589462	et	3	main
kui	doc_491521502100_item	2589468	et	3	main
riie	doc_491521502100_item	2589497	et	3	main
tavaliselt	doc_491521502100_item	2589500	et	4	main
olen	doc_491521502100_item	2589502	et	3	main
on	doc_491521502100_item	2589510	et	4	main
tööd	doc_491521502100_item	2589512	et	4	main
isa	doc_491521502100_item	2589513	et	4	main
sabata	doc_491521502100_item	2589123	et	3	main
a	doc_491521502100_item	2589145	et	4	main
tunda	doc_491521502100_item	2589155	et	3	main
vaid	doc_491521502100_item	2589156	et	3	main
andes	doc_491521502100_item	2589164	et	4	main
läks	doc_491521502100_item	2589174	et	3	main
nägi	doc_491521502100_item	2589175	et	3	main
minnes	doc_491521502100_item	2589182	et	3	main
otsas	doc_491521502100_item	2589186	et	4	main
eesti	doc_491521502100_item	2589191	et	4	main
elanikkonnast	doc_491521502100_item	2589192	et	4	main
veidi	doc_491521502100_item	2589193	et	3	main
matkal	doc_491521502100_item	2589204	et	3	main
me	doc_491521502100_item	2589208	et	4	main
võimalikult	doc_491521502100_item	2589214	et	4	main
ettevaatlikud	doc_491521502100_item	2589215	et	3	main
kui	doc_491521502100_item	2589217	et	3	main
hollandiga	doc_491521502100_item	2589219	et	4	main
on	doc_491521502100_item	2589220	et	4	main
eesti	doc_491521502100_item	2589221	et	4	main
asustusega	doc_491521502100_item	2589223	et	4	main
iga	doc_491521502100_item	2589235	et	4	main
taim	doc_491521502100_item	2589236	et	3	main
omab	doc_491521502100_item	2589237	et	3	main
võtab	doc_491521502100_item	2589247	et	3	main
väsimuse	doc_491521502100_item	2589249	et	4	main
vähendab	doc_491521502100_item	2589251	et	3	main
1	doc_491521502100_item	2589253	et	2	main
venelased	doc_491521502100_item	2589254	et	3	main
moodustavad	doc_491521502100_item	2589255	et	4	main
matkal	doc_491521502100_item	2589266	et	3	main
keetmata	doc_491521502100_item	2589271	et	4	main
eesti	doc_491521502100_item	2589281	et	4	main
asustusega	doc_491521502100_item	2589283	et	4	main
4	doc_491521502100_item	2589285	et	2	main
sõjamees	doc_491521502100_item	2589286	et	4	main
läks	doc_491521502100_item	2589287	et	3	main
достигают	doc_491521502100_item	2589322	et	2	main
семейном	doc_491521502100_item	2589328	et	2	main
обсуждение	doc_491521502100_item	2589333	et	2	main
начинают	doc_491521502100_item	2589336	et	2	main
в	doc_491521502100_item	2589346	et	2	main
работодателем	doc_491521502100_item	2589350	et	2	main
6	doc_491521502100_item	2589355	et	2	main
безработица	doc_491521502100_item	2589360	et	2	main
seisu	doc_491521502100_item	2589368	et	4	main
andmeid	doc_491521502100_item	2589369	et	3	main
4	doc_491521502100_item	2589379	et	2	main
eeile	doc_491521502100_item	2589380	et	4	main
ma	doc_491521502100_item	2589390	et	3	main
kui	doc_491521502100_item	2589393	et	3	main
minu	doc_491521502100_item	2589396	et	3	main
on	doc_491521502100_item	2589404	et	4	main
pikem	doc_491521502100_item	2589405	et	4	main
kui	doc_491521502100_item	2589406	et	3	main
on	doc_491521502100_item	2589409	et	4	main
väiksem	doc_491521502100_item	2589410	et	4	main
kui	doc_491521502100_item	2589422	et	3	main
on	doc_491521502100_item	2589426	et	4	main
õpilane	doc_491521502100_item	2589428	et	3	main
on	doc_491521502100_item	2589432	et	4	main
õpilane	doc_491521502100_item	2589434	et	3	main
kui	doc_491521502100_item	2589435	et	3	main
heino	doc_491521502100_item	2589436	et	4	main
4	doc_491521502100_item	2589437	et	2	main
kergem	doc_491521502100_item	2589442	et	4	main
kui	doc_491521502100_item	2589443	et	3	main
grammatika	doc_491521502100_item	2589449	et	4	main
tänav	doc_491521502100_item	2589458	et	4	main
on	doc_491521502100_item	2589466	et	4	main
suvel	doc_491521502100_item	2589504	et	3	main
palju	doc_491521502100_item	2589511	et	4	main
kella	doc_491521502100_item	2589526	et	4	main
kolm	doc_491521502100_item	2589527	et	3	main
kolmeks	doc_491521502100_item	2589528	et	4	main
see	doc_491521502100_item	2589529	et	3	main
auto	doc_491521502100_item	2589530	et	4	main
see	doc_491521502100_item	2589531	et	3	main
itaalia	doc_491521502100_item	2589540	et	4	main
puu	doc_491521502100_item	2589185	et	4	main
venelased	doc_491521502100_item	2589189	et	3	main
rahvusvähemust	doc_491521502100_item	2589200	et	4	main
2	doc_491521502100_item	2589201	et	2	main
kui	doc_491521502100_item	2589202	et	3	main
ei	doc_491521502100_item	2589206	et	4	main
3	doc_491521502100_item	2589216	et	2	main
võrrelda	doc_491521502100_item	2589218	et	4	main
hõreda	doc_491521502100_item	2589222	et	3	main
sõjamees	doc_491521502100_item	2589226	et	4	main
mõjuvõimu	doc_491521502100_item	2589239	et	4	main
ja	doc_491521502100_item	2589240	et	3	main
avaldab	doc_491521502100_item	2589241	et	3	main
seda	doc_491521502100_item	2589242	et	3	main
ka	doc_491521502100_item	2589243	et	3	main
inimorganismile	doc_491521502100_item	2589244	et	3	main
elanikkonnast	doc_491521502100_item	2589257	et	4	main
veidi	doc_491521502100_item	2589258	et	3	main
alla	doc_491521502100_item	2589259	et	3	main
2	doc_491521502100_item	2589265	et	2	main
ei	doc_491521502100_item	2589268	et	4	main
on	doc_491521502100_item	2589280	et	4	main
maa	doc_491521502100_item	2589284	et	4	main
selle	doc_491521502100_item	2589291	et	4	main
iga	doc_491521502100_item	2589294	et	4	main
taim	doc_491521502100_item	2589295	et	3	main
omab	doc_491521502100_item	2589296	et	3	main
teatavat	doc_491521502100_item	2589297	et	4	main
mõjuvõimu	doc_491521502100_item	2589298	et	4	main
avaldades	doc_491521502100_item	2589299	et	3	main
seda	doc_491521502100_item	2589300	et	3	main
ka	doc_491521502100_item	2589301	et	3	main
inimorganismile	doc_491521502100_item	2589302	et	3	main
6	doc_491521502100_item	2589303	et	2	main
kask	doc_491521502100_item	2589304	et	3	main
võtab	doc_491521502100_item	2589305	et	3	main
ära	doc_491521502100_item	2589306	et	4	main
väsimuse	doc_491521502100_item	2589307	et	4	main
vähendades	doc_491521502100_item	2589308	et	3	main
stressi	doc_491521502100_item	2589309	et	4	main
tõlkige	doc_491521502100_item	2589310	et	3	main
eesti	doc_491521502100_item	2589311	et	4	main
keelde	doc_491521502100_item	2589312	et	4	main
umbisikulise	doc_491521502100_item	2589313	et	4	main
tegumoe	doc_491521502100_item	2589314	et	3	main
abil	doc_491521502100_item	2589315	et	4	main
vajaduse	doc_491521502100_item	2589316	et	3	main
korral	doc_491521502100_item	2589317	et	4	main
kasutage	doc_491521502100_item	2589318	et	3	main
vene-eesti	doc_491521502100_item	2589319	et	4	main
õppesõnastikku	doc_491521502100_item	2589320	et	4	main
olla	doc_491521502100_item	2589274	et	3	main
ettevaatlikud	doc_491521502100_item	2589276	et	3	main
hollandiga	doc_491521502100_item	2589278	et	4	main
võrreldades	doc_491521502100_item	2589279	et	4	main
5	doc_491521502100_item	2589293	et	2	main
временем	doc_491521502100_item	2589324	et	2	main
положении	doc_491521502100_item	2589329	et	2	main
суммы	doc_491521502100_item	2589334	et	2	main
позже	doc_491521502100_item	2589337	et	2	main
на	doc_491521502100_item	2589342	et	2	main
беседы	doc_491521502100_item	2589348	et	2	main
условиях	doc_491521502100_item	2589353	et	2	main
сообщали	doc_491521502100_item	2589358	et	2	main
1	doc_491521502100_item	2589362	et	2	main
eile	doc_491521502100_item	2589371	et	3	main
teil	doc_491521502100_item	2589373	et	4	main
valiti	doc_491521502100_item	2589375	et	3	main
ei	doc_491521502100_item	2589381	et	4	main
kasvab	doc_491521502100_item	2589385	et	3	main
näidise	doc_491521502100_item	2589387	et	3	main
näidis	doc_491521502100_item	2589389	et	4	main
õde	doc_491521502100_item	2589397	et	4	main
on	doc_491521502100_item	2589398	et	4	main
isa	doc_491521502100_item	2589407	et	4	main
tallinn	doc_491521502100_item	2589423	et	4	main
kalle	doc_491521502100_item	2589430	et	3	main
keele	doc_491521502100_item	2589439	et	4	main
grammatika	doc_491521502100_item	2589440	et	4	main
grammatika	doc_491521502100_item	2589446	et	4	main
keele	doc_491521502100_item	2589448	et	4	main
inglise	doc_491521502100_item	2589453	et	4	main
5	doc_491521502100_item	2589456	et	2	main
meie	doc_491521502100_item	2589457	et	4	main
sugulastega	doc_491521502100_item	2589492	et	4	main
see	doc_491521502100_item	2589493	et	3	main
kleit	doc_491521502100_item	2589494	et	3	main
on	doc_491521502100_item	2589495	et	4	main
riiest	doc_491521502100_item	2589499	et	3	main
õhtu	doc_491521502100_item	2589515	et	4	main
õhtul	doc_491521502100_item	2589516	et	3	main
lapsed	doc_491521502100_item	2589520	et	3	main
kool	doc_491521502100_item	2589522	et	4	main
tõlkida	doc_491521502100_item	2589538	et	3	main
teksti	doc_491521502100_item	2589539	et	4	main
tuli	doc_491521502100_item	2589552	et	4	main
klass	doc_491521502100_item	2589553	et	3	main
sulgudes	doc_491521502100_item	2589561	et	4	main
või	doc_491521502100_item	2589565	et	4	main
käändesse	doc_491521502100_item	2589567	et	4	main
tõlkige	doc_491521502100_item	2589568	et	3	main
laused	doc_491521502100_item	2589569	et	3	main
vene	doc_491521502100_item	2589570	et	4	main
või	doc_491521502100_item	2589582	et	4	main
nuga	doc_491521502100_item	2589595	et	4	main
ärge	doc_491521502100_item	2589597	et	3	main
nii	doc_491521502100_item	2589599	et	3	main
vilde	doc_491521502100_item	2589604	et	4	main
pealkiri	doc_491521502100_item	2589606	et	3	main
on	doc_491521502100_item	2589607	et	4	main
kohvritega	doc_491521502100_item	2589622	et	3	main
bussiga	doc_491521502100_item	2589626	et	3	main
noaga	doc_491521502100_item	2589632	et	3	main
lennukiga	doc_491521502100_item	2589642	et	3	main
pidama	doc_491521502100_item	2589645	et	4	main
rääkima	doc_491521502100_item	2589654	et	3	main
võõrkeelt	doc_491521502100_item	2589658	et	4	main
palju	doc_491521502100_item	2589665	et	4	main
te	doc_491521502100_item	2589666	et	4	main
hakkama	doc_491521502100_item	2589667	et	3	main
kirjutama	doc_491521502100_item	2589668	et	3	main
hakkate	doc_491521502100_item	2589669	et	3	main
kirjutama	doc_491521502100_item	2589670	et	3	main
harjutust	doc_491521502100_item	2589671	et	4	main
töötada	doc_491521502100_item	2589676	et	3	main
tahtma	doc_491521502100_item	2589680	et	3	main
tahan	doc_491521502100_item	2589682	et	3	main
hakkame	doc_491521502100_item	2589690	et	3	main
три	doc_491521502100_item	2589722	et	2	main
будут	doc_491521502100_item	2589728	et	2	main
умения	doc_491521502100_item	2589734	et	2	main
работа	doc_491521502100_item	2589738	et	2	main
2	doc_491521502100_item	2589325	et	2	main
вчера	doc_491521502100_item	2589331	et	2	main
вас	doc_491521502100_item	2589339	et	2	main
эту	doc_491521502100_item	2589343	et	2	main
ходе	doc_491521502100_item	2589347	et	2	main
с	doc_491521502100_item	2589349	et	2	main
труда	doc_491521502100_item	2589354	et	2	main
что	doc_491521502100_item	2589359	et	2	main
eesmärgid	doc_491521502100_item	2589363	et	3	main
2	doc_491521502100_item	2589366	et	2	main
3	doc_491521502100_item	2589372	et	2	main
ei	doc_491521502100_item	2589374	et	4	main
selle	doc_491521502100_item	2589376	et	4	main
räägiti	doc_491521502100_item	2589382	et	3	main
noorem	doc_491521502100_item	2589399	et	4	main
kui	doc_491521502100_item	2589400	et	3	main
poeg	doc_491521502100_item	2589412	et	3	main
2	doc_491521502100_item	2589413	et	2	main
tallinn	doc_491521502100_item	2589414	et	4	main
on	doc_491521502100_item	2589415	et	4	main
suurem	doc_491521502100_item	2589416	et	4	main
kui	doc_491521502100_item	2589417	et	3	main
tartu	doc_491521502100_item	2589418	et	4	main
tartu	doc_491521502100_item	2589419	et	4	main
on	doc_491521502100_item	2589420	et	4	main
не	doc_491521502100_item	2589357	et	2	main
растет	doc_491521502100_item	2589361	et	2	main
saavutatakse	doc_491521502100_item	2589364	et	3	main
perekonna	doc_491521502100_item	2589367	et	4	main
esitati	doc_491521502100_item	2589370	et	4	main
peale	doc_491521502100_item	2589378	et	4	main
töötu	doc_491521502100_item	2589384	et	4	main
jätkake	doc_491521502100_item	2589386	et	3	main
järgi	doc_491521502100_item	2589388	et	4	main
vanem	doc_491521502100_item	2589392	et	4	main
minu	doc_491521502100_item	2589394	et	3	main
õde	doc_491521502100_item	2589395	et	4	main
1	doc_491521502100_item	2589402	et	2	main
poeg	doc_491521502100_item	2589403	et	3	main
vähem	doc_491521502100_item	2589421	et	4	main
3	doc_491521502100_item	2589424	et	2	main
inglise	doc_491521502100_item	2589438	et	4	main
on	doc_491521502100_item	2589450	et	4	main
kui	doc_491521502100_item	2589452	et	3	main
ebapuhtam	doc_491521502100_item	2589467	et	4	main
villast	doc_491521502100_item	2589498	et	4	main
suvi	doc_491521502100_item	2589503	et	3	main
puhanud	doc_491521502100_item	2589505	et	4	main
mägidel	doc_491521502100_item	2589507	et	4	main
kunstnik	doc_491521502100_item	2589508	et	3	main
ostis	doc_491521502100_item	2589514	et	4	main
tulevad	doc_491521502100_item	2589521	et	4	main
kodu	doc_491521502100_item	2589523	et	4	main
koolist	doc_491521502100_item	2589524	et	4	main
koju	doc_491521502100_item	2589525	et	3	main
auto	doc_491521502100_item	2589532	et	4	main
keel	doc_491521502100_item	2589541	et	4	main
vene	doc_491521502100_item	2589546	et	4	main
klassi	doc_491521502100_item	2589554	et	4	main
uued	doc_491521502100_item	2589555	et	3	main
õpilased	doc_491521502100_item	2589556	et	3	main
uute	doc_491521502100_item	2589557	et	3	main
õpilaste	doc_491521502100_item	2589558	et	4	main
juurde	doc_491521502100_item	2589559	et	4	main
keelde	doc_491521502100_item	2589571	et	4	main
1turistid	doc_491521502100_item	2589572	et	3	main
rong	doc_491521502100_item	2589581	et	3	main
3	doc_491521502100_item	2589584	et	2	main
4	doc_491521502100_item	2589590	et	2	main
5	doc_491521502100_item	2589596	et	2	main
näod	doc_491521502100_item	2589601	et	3	main
või	doc_491521502100_item	2589625	et	4	main
palava	doc_491521502100_item	2589628	et	4	main
kliimaga	doc_491521502100_item	2589629	et	3	main
terava	doc_491521502100_item	2589631	et	3	main
5	doc_491521502100_item	2589633	et	2	main
näodega	doc_491521502100_item	2589635	et	4	main
musta	doc_491521502100_item	2589637	et	4	main
viis	doc_491521502100_item	2589650	et	4	main
need	doc_491521502100_item	2589651	et	3	main
võivad	doc_491521502100_item	2589655	et	4	main
kolme	doc_491521502100_item	2589657	et	4	main
ta	doc_491521502100_item	2589659	et	4	main
ei	doc_491521502100_item	2589660	et	4	main
tahtma	doc_491521502100_item	2589661	et	3	main
meeldib	doc_491521502100_item	2589675	et	3	main
selles	doc_491521502100_item	2589677	et	4	main
ma	doc_491521502100_item	2589679	et	3	main
elama	doc_491521502100_item	2589689	et	3	main
было	doc_491521502100_item	2589721	et	2	main
большие	doc_491521502100_item	2589726	et	2	main
5	doc_491521502100_item	2589730	et	2	main
нет	doc_491521502100_item	2589733	et	2	main
эта	doc_491521502100_item	2589737	et	2	main
7	doc_491521502100_item	2589743	et	2	main
8	doc_491521502100_item	2589746	et	2	main
глаза	doc_491521502100_item	2589753	et	2	main
изменение	doc_491521502100_item	2589759	et	2	main
3sellel	doc_491521502100_item	2589767	et	4	main
suurt	doc_491521502100_item	2589772	et	3	main
saavutused	doc_491521502100_item	2589775	et	4	main
erinevaid	doc_491521502100_item	2589786	et	4	main
keelde	doc_491521502100_item	2589797	et	4	main
või	doc_491521502100_item	2589800	et	4	main
täismineviku	doc_491521502100_item	2589801	et	3	main
abil	doc_491521502100_item	2589802	et	4	main
то	doc_491521502100_item	2589804	et	2	main
eesti	doc_491521502100_item	2589444	et	4	main
eesti	doc_491521502100_item	2589447	et	4	main
keele	doc_491521502100_item	2589454	et	4	main
grammatika	doc_491521502100_item	2589455	et	4	main
tänav	doc_491521502100_item	2589463	et	4	main
sõle	doc_491521502100_item	2589464	et	3	main
tänav	doc_491521502100_item	2589465	et	4	main
meie	doc_491521502100_item	2589469	et	4	main
tänav	doc_491521502100_item	2589470	et	4	main
valige	doc_491521502100_item	2589471	et	3	main
õige	doc_491521502100_item	2589472	et	4	main
kääne	doc_491521502100_item	2589473	et	3	main
ning	doc_491521502100_item	2589474	et	3	main
vajadusel	doc_491521502100_item	2589475	et	3	main
ka	doc_491521502100_item	2589476	et	3	main
tagasõna	doc_491521502100_item	2589477	et	4	main
tahan	doc_491521502100_item	2589478	et	3	main
puhata	doc_491521502100_item	2589479	et	4	main
hommik	doc_491521502100_item	2589480	et	3	main
hommikul	doc_491521502100_item	2589481	et	3	main
kes	doc_491521502100_item	2589482	et	4	main
teist	doc_491521502100_item	2589483	et	4	main
sooritas	doc_491521502100_item	2589484	et	3	main
eksami	doc_491521502100_item	2589485	et	3	main
viimane	doc_491521502100_item	2589486	et	3	main
viimasena	doc_491521502100_item	2589487	et	3	main
täna	doc_491521502100_item	2589488	et	4	main
kohtun	doc_491521502100_item	2589489	et	3	main
oma	doc_491521502100_item	2589490	et	4	main
sugulased	doc_491521502100_item	2589491	et	3	main
villane	doc_491521502100_item	2589496	et	4	main
ma	doc_491521502100_item	2589501	et	3	main
mäed	doc_491521502100_item	2589506	et	3	main
kunstnikul	doc_491521502100_item	2589509	et	3	main
piletid	doc_491521502100_item	2589517	et	3	main
teater	doc_491521502100_item	2589518	et	3	main
teatrisse	doc_491521502100_item	2589519	et	3	main
kes	doc_491521502100_item	2589536	et	4	main
suudab	doc_491521502100_item	2589537	et	3	main
keel	doc_491521502100_item	2589543	et	4	main
keelde	doc_491521502100_item	2589547	et	4	main
viga	doc_491521502100_item	2589549	et	4	main
õpetaja	doc_491521502100_item	2589551	et	4	main
pange	doc_491521502100_item	2589560	et	4	main
sõnad	doc_491521502100_item	2589563	et	4	main
saabusid	doc_491521502100_item	2589573	et	4	main
kohanemine	doc_491521502100_item	2589587	et	4	main
nõuab	doc_491521502100_item	2589588	et	3	main
saab	doc_491521502100_item	2589592	et	3	main
lõigata	doc_491521502100_item	2589593	et	4	main
rongiga	doc_491521502100_item	2589624	et	4	main
4	doc_491521502100_item	2589630	et	2	main
hapude	doc_491521502100_item	2589634	et	3	main
6	doc_491521502100_item	2589636	et	2	main
ta	doc_491521502100_item	2589643	et	4	main
võima	doc_491521502100_item	2589653	et	3	main
suitsetama	doc_491521502100_item	2589662	et	4	main
talle	doc_491521502100_item	2589672	et	4	main
hakkama	doc_491521502100_item	2589688	et	3	main
больших	doc_491521502100_item	2589723	et	2	main
завтра	doc_491521502100_item	2589729	et	2	main
вас	doc_491521502100_item	2589732	et	2	main
6	doc_491521502100_item	2589736	et	2	main
разных	doc_491521502100_item	2589741	et	2	main
отдыхают	doc_491521502100_item	2589745	et	2	main
довольно	doc_491521502100_item	2589750	et	2	main
человека	doc_491521502100_item	2589755	et	2	main
тяжело	doc_491521502100_item	2589762	et	2	main
aastal	doc_491521502100_item	2589768	et	3	main
kolm	doc_491521502100_item	2589771	et	3	main
suured	doc_491521502100_item	2589774	et	3	main
teil	doc_491521502100_item	2589778	et	4	main
suhelda	doc_491521502100_item	2589781	et	4	main
see	doc_491521502100_item	2589782	et	3	main
inimesed	doc_491521502100_item	2589788	et	3	main
inimestel	doc_491521502100_item	2589791	et	3	main
kas	doc_491521502100_item	2589798	et	3	main
рабочий	doc_491521502100_item	2589807	et	2	main
mahub	doc_491521502100_item	2589533	et	3	main
kuus	doc_491521502100_item	2589534	et	4	main
inimest	doc_491521502100_item	2589535	et	3	main
vene	doc_491521502100_item	2589542	et	4	main
keelest	doc_491521502100_item	2589545	et	4	main
ilma	doc_491521502100_item	2589548	et	4	main
veata	doc_491521502100_item	2589550	et	3	main
olevad	doc_491521502100_item	2589562	et	4	main
lennujaama	doc_491521502100_item	2589574	et	4	main
suured	doc_491521502100_item	2589575	et	3	main
kohvrid	doc_491521502100_item	2589576	et	3	main
2	doc_491521502100_item	2589577	et	2	main
eelistavad	doc_491521502100_item	2589579	et	4	main
palav	doc_491521502100_item	2589585	et	4	main
oksi	doc_491521502100_item	2589591	et	4	main
terav	doc_491521502100_item	2589594	et	3	main
istuge	doc_491521502100_item	2589598	et	3	main
hapud	doc_491521502100_item	2589600	et	3	main
6	doc_491521502100_item	2589602	et	2	main
mantel	doc_491521502100_item	2589609	et	3	main
mees	doc_491521502100_item	2589610	et	4	main
7	doc_491521502100_item	2589611	et	2	main
soome	doc_491521502100_item	2589612	et	3	main
on	doc_491521502100_item	2589613	et	4	main
võimalik	doc_491521502100_item	2589614	et	3	main
minna	doc_491521502100_item	2589615	et	3	main
nii	doc_491521502100_item	2589616	et	3	main
laev	doc_491521502100_item	2589617	et	3	main
kui	doc_491521502100_item	2589618	et	3	main
lennuk	doc_491521502100_item	2589619	et	3	main
1	doc_491521502100_item	2589620	et	2	main
suurte	doc_491521502100_item	2589621	et	3	main
kui	doc_491521502100_item	2589641	et	3	main
tavaliselt	doc_491521502100_item	2589644	et	4	main
lahkuma	doc_491521502100_item	2589646	et	3	main
pidi	doc_491521502100_item	2589647	et	4	main
lahkuma	doc_491521502100_item	2589648	et	3	main
kell	doc_491521502100_item	2589649	et	3	main
rääkida	doc_491521502100_item	2589656	et	3	main
taha	doc_491521502100_item	2589663	et	4	main
meeldima	doc_491521502100_item	2589673	et	3	main
kirjutama	doc_491521502100_item	2589681	et	3	main
kirjutada	doc_491521502100_item	2589683	et	3	main
oma	doc_491521502100_item	2589685	et	4	main
tuttavatele	doc_491521502100_item	2589686	et	3	main
me	doc_491521502100_item	2589687	et	4	main
достижения	doc_491521502100_item	2589724	et	2	main
достижения	doc_491521502100_item	2589727	et	2	main
у	doc_491521502100_item	2589731	et	2	main
требует	doc_491521502100_item	2589739	et	2	main
люди	doc_491521502100_item	2589744	et	2	main
были	doc_491521502100_item	2589749	et	2	main
простые	doc_491521502100_item	2589751	et	2	main
очень	doc_491521502100_item	2589756	et	2	main
самооценки	doc_491521502100_item	2589760	et	2	main
siin	doc_491521502100_item	2589764	et	4	main
mul	doc_491521502100_item	2589769	et	3	main
töö	doc_491521502100_item	2589783	et	4	main
vajab	doc_491521502100_item	2589784	et	3	main
palju	doc_491521502100_item	2589785	et	4	main
puhkavad	doc_491521502100_item	2589789	et	4	main
näod	doc_491521502100_item	2589790	et	3	main
olid	doc_491521502100_item	2589792	et	4	main
liht-	doc_491521502100_item	2589799	et	3	main
день	doc_491521502100_item	2589808	et	2	main
оказываем	doc_491521502100_item	2589821	et	2	main
вас	doc_491521502100_item	2589826	et	2	main
я	doc_491521502100_item	2589831	et	2	main
учиться	doc_491521502100_item	2589834	et	2	main
itaalia	doc_491521502100_item	2589544	et	4	main
kaasaütlevasse	doc_491521502100_item	2589564	et	3	main
omastavasse	doc_491521502100_item	2589566	et	4	main
paljud	doc_491521502100_item	2589578	et	3	main
reisida	doc_491521502100_item	2589580	et	3	main
buss	doc_491521502100_item	2589583	et	3	main
kliima	doc_491521502100_item	2589586	et	4	main
aega	doc_491521502100_item	2589589	et	4	main
eduard	doc_491521502100_item	2589603	et	4	main
jutustuse	doc_491521502100_item	2589605	et	4	main
must	doc_491521502100_item	2589608	et	4	main
2	doc_491521502100_item	2589623	et	2	main
3	doc_491521502100_item	2589627	et	2	main
mantliga	doc_491521502100_item	2589638	et	3	main
7	doc_491521502100_item	2589639	et	2	main
laevaga	doc_491521502100_item	2589640	et	4	main
tüdrukud	doc_491521502100_item	2589652	et	3	main
suitsetada	doc_491521502100_item	2589664	et	3	main
töötama	doc_491521502100_item	2589674	et	3	main
ettevõttes	doc_491521502100_item	2589678	et	3	main
kirja	doc_491521502100_item	2589684	et	4	main
elama	doc_491521502100_item	2589691	et	3	main
tallinnas	doc_491521502100_item	2589692	et	4	main
ma	doc_491521502100_item	2589693	et	3	main
oskama	doc_491521502100_item	2589694	et	3	main
õpetama	doc_491521502100_item	2589695	et	3	main
oskan	doc_491521502100_item	2589696	et	3	main
õpetada	doc_491521502100_item	2589697	et	3	main
võõrkeelt	doc_491521502100_item	2589698	et	4	main
välismaalastele	doc_491521502100_item	2589699	et	4	main
tõlkige	doc_491521502100_item	2589700	et	3	main
laused	doc_491521502100_item	2589701	et	3	main
eesti	doc_491521502100_item	2589702	et	4	main
keelde	doc_491521502100_item	2589703	et	4	main
1здесь	doc_491521502100_item	2589704	et	2	main
нет	doc_491521502100_item	2589705	et	2	main
бытовых	doc_491521502100_item	2589706	et	2	main
удобств	doc_491521502100_item	2589707	et	2	main
2	doc_491521502100_item	2589708	et	2	main
подробное	doc_491521502100_item	2589709	et	2	main
описание	doc_491521502100_item	2589710	et	2	main
бытовых	doc_491521502100_item	2589711	et	2	main
удобств	doc_491521502100_item	2589712	et	2	main
требует	doc_491521502100_item	2589713	et	2	main
времени	doc_491521502100_item	2589714	et	2	main
3	doc_491521502100_item	2589715	et	2	main
в	doc_491521502100_item	2589716	et	2	main
этом	doc_491521502100_item	2589717	et	2	main
году	doc_491521502100_item	2589718	et	2	main
у	doc_491521502100_item	2589719	et	2	main
меня	doc_491521502100_item	2589720	et	2	main
4	doc_491521502100_item	2589725	et	2	main
общаться	doc_491521502100_item	2589735	et	2	main
много	doc_491521502100_item	2589740	et	2	main
людей	doc_491521502100_item	2589748	et	2	main
этого	doc_491521502100_item	2589754	et	2	main
10	doc_491521502100_item	2589758	et	2	main
1	doc_491521502100_item	2589763	et	2	main
mugavuseid	doc_491521502100_item	2589766	et	4	main
oli	doc_491521502100_item	2589770	et	3	main
tulevad	doc_491521502100_item	2589776	et	4	main
homme	doc_491521502100_item	2589777	et	3	main
pole	doc_491521502100_item	2589779	et	3	main
oskusi	doc_491521502100_item	2589780	et	3	main
oskusi	doc_491521502100_item	2589787	et	3	main
päris	doc_491521502100_item	2589793	et	4	main
lihtsalt	doc_491521502100_item	2589794	et	4	main
tõlkige	doc_491521502100_item	2589795	et	3	main
eesti	doc_491521502100_item	2589796	et	4	main
каждый	doc_491521502100_item	2589806	et	2	main
рано	doc_491521502100_item	2589810	et	2	main
утром	doc_491521502100_item	2589811	et	2	main
2	doc_491521502100_item	2589812	et	2	main
обучение	doc_491521502100_item	2589813	et	2	main
продолжалось	doc_491521502100_item	2589814	et	2	main
всю	doc_491521502100_item	2589815	et	2	main
3	doc_491521502100_item	2589817	et	2	main
жизнь	doc_491521502100_item	2589816	et	2	main
мы	doc_491521502100_item	2589818	et	2	main
никогда	doc_491521502100_item	2589819	et	2	main
не	doc_491521502100_item	2589820	et	2	main
давления	doc_491521502100_item	2589822	et	2	main
случилось	doc_491521502100_item	2589827	et	2	main
не	doc_491521502100_item	2589832	et	2	main
постоянно	doc_491521502100_item	2589837	et	2	main
спокойное	doc_491521502100_item	2589842	et	2	main
разумным	doc_491521502100_item	2589846	et	2	main
вносил	doc_491521502100_item	2589851	et	2	main
в	doc_491521502100_item	2589852	et	2	main
tee	doc_491521502100_item	2589868	et	4	main
pingitust	doc_491521502100_item	2589869	et	4	main
ma	doc_491521502100_item	2589875	et	3	main
me	doc_491521502100_item	2589879	et	4	main
selgelt	doc_491521502100_item	2589887	et	4	main
sõnad	doc_491521502101_item	2589892	et	4	main
tõlkige	doc_491521502101_item	2589895	et	3	main
uus	doc_491521502101_item	2589899	et	3	main
me	doc_491521502101_item	2589901	et	4	main
maja	doc_491521502101_item	2589912	et	4	main
langesin	doc_491521502101_item	2589917	et	3	main
pärast	doc_491521502101_item	2589919	et	4	main
sügav	doc_491521502101_item	2589925	et	4	main
kauplus	doc_491521502101_item	2589937	et	3	main
on	doc_491521502101_item	2589941	et	4	main
sein	doc_491521502101_item	2589951	et	3	main
jäänud	doc_491521502101_item	2589958	et	4	main
uesesse	doc_491521502101_item	2589975	et	4	main
kohale	doc_491521502101_item	2589984	et	4	main
on	doc_491521502101_item	2590016	et	4	main
avatud	doc_491521502101_item	2590018	et	4	main
alates	doc_491521502101_item	2590019	et	3	main
oktoobris	doc_491521502101_item	2590020	et	3	main
4	doc_491521502101_item	2590021	et	2	main
on	doc_491521502101_item	2590027	et	4	main
auk	doc_491521502101_item	2590029	et	3	main
seinasse	doc_491521502101_item	2590030	et	3	main
jäänud	doc_491521502101_item	2590033	et	4	main
majapidamistarvatesse	doc_491521502101_item	2590039	et	3	main
leidub	doc_491521502101_item	2590043	et	3	main
kas	doc_491521502101_item	2590050	et	3	main
olev	doc_491521502101_item	2590053	et	4	main
умений	doc_491521502100_item	2589742	et	2	main
лица	doc_491521502100_item	2589747	et	2	main
9	doc_491521502100_item	2589752	et	2	main
робкие	doc_491521502100_item	2589757	et	2	main
проходит	doc_491521502100_item	2589761	et	2	main
pole	doc_491521502100_item	2589765	et	3	main
saavutust	doc_491521502100_item	2589773	et	4	main
1в	doc_491521502100_item	2589803	et	2	main
время	doc_491521502100_item	2589805	et	2	main
у	doc_491521502100_item	2589825	et	2	main
случалось	doc_491521502100_item	2589829	et	2	main
6	doc_491521502100_item	2589835	et	2	main
в	doc_491521502100_item	2589839	et	2	main
бывало	doc_491521502100_item	2589844	et	2	main
8	doc_491521502100_item	2589848	et	2	main
mis	doc_491521502100_item	2589870	et	4	main
juhtus	doc_491521502100_item	2589872	et	3	main
et	doc_491521502100_item	2589874	et	3	main
ei	doc_491521502100_item	2589876	et	4	main
vajasime	doc_491521502100_item	2589881	et	3	main
nõuannes	doc_491521502100_item	2589882	et	3	main
viis	doc_491521502100_item	2589885	et	4	main
pange	doc_491521502101_item	2589889	et	4	main
sisekohakäänetesse	doc_491521502101_item	2589894	et	3	main
välja	doc_491521502101_item	2589913	et	4	main
nädalat	doc_491521502101_item	2589923	et	3	main
loodan	doc_491521502101_item	2589927	et	3	main
oktoober	doc_491521502101_item	2589936	et	3	main
külastajatele	doc_491521502101_item	2589942	et	4	main
4	doc_491521502101_item	2589946	et	2	main
järele	doc_491521502101_item	2589957	et	4	main
majapidamistarvete	doc_491521502101_item	2589966	et	4	main
osakond	doc_491521502101_item	2589967	et	3	main
leidub	doc_491521502101_item	2589968	et	3	main
alati	doc_491521502101_item	2589969	et	4	main
majasse	doc_491521502101_item	2589976	et	3	main
ueses	doc_491521502101_item	2589979	et	4	main
pool	doc_491521502101_item	2589982	et	4	main
on	doc_491521502101_item	2590023	et	4	main
järele	doc_491521502101_item	2590032	et	4	main
õige	doc_491521502101_item	2590048	et	4	main
mind	doc_491521502101_item	2590057	et	4	main
ajutiselt	doc_491521502101_item	2590058	et	4	main
mina	doc_491521502101_item	2590068	et	4	main
mind	doc_491521502101_item	2590115	et	4	main
direktor	doc_491521502101_item	2590121	et	3	main
minu	doc_491521502101_item	2590126	et	3	main
õige	doc_491521502101_item	2590127	et	4	main
remondi	doc_491521502101_item	2590130	et	4	main
eest	doc_491521502101_item	2590131	et	4	main
3	doc_491521502101_item	2590132	et	2	main
inimeseni	doc_491521502101_item	2590133	et	3	main
4	doc_491521502101_item	2590134	et	2	main
rahvaseni	doc_491521502101_item	2590135	et	4	main
5	doc_491521502101_item	2590136	et	2	main
või	doc_491521502101_item	2590147	et	4	main
omastavasse	doc_491521502101_item	2590148	et	4	main
keelde	doc_491521502101_item	2590153	et	4	main
nägu	doc_491521502101_item	2590163	et	4	main
oli	doc_491521502101_item	2590164	et	3	main
3	doc_491521502101_item	2590166	et	2	main
suur	doc_491521502101_item	2590172	et	3	main
4	doc_491521502101_item	2590174	et	2	main
istus	doc_491521502101_item	2590177	et	4	main
möödub	doc_491521502101_item	2590186	et	3	main
4	doc_491521502101_item	2590225	et	2	main
ametliku	doc_491521502101_item	2590243	et	3	main
lauseid	doc_491521502101_item	2590256	et	3	main
laused	doc_491521502101_item	2590264	et	3	main
keelde	doc_491521502101_item	2590266	et	4	main
näidis	doc_491521502101_item	2590267	et	4	main
a	doc_491521502101_item	2590268	et	4	main
keskkonna	doc_491521502101_item	2590269	et	3	main
tugev	doc_491521502101_item	2590274	et	4	main
ja	doc_491521502101_item	2590275	et	3	main
annab	doc_491521502101_item	2590276	et	3	main
end	doc_491521502101_item	2590277	et	4	main
tunda	doc_491521502101_item	2590278	et	3	main
vaid	doc_491521502101_item	2590279	et	3	main
suurimat	doc_491521502101_item	2590321	et	3	main
начинался	doc_491521502100_item	2589809	et	2	main
что	doc_491521502100_item	2589824	et	2	main
что	doc_491521502100_item	2589830	et	2	main
мы	doc_491521502100_item	2589836	et	2	main
7	doc_491521502100_item	2589841	et	2	main
решением	doc_491521502100_item	2589847	et	2	main
kestas	doc_491521502100_item	2589861	et	4	main
oli	doc_491521502100_item	2589873	et	3	main
ajasse	doc_491521502100_item	2589886	et	3	main
kontrolltöö	doc_491521502101_item	2589888	et	4	main
vastavatesse	doc_491521502101_item	2589893	et	4	main
kohale	doc_491521502101_item	2589908	et	4	main
jõudes	doc_491521502101_item	2589909	et	3	main
helista	doc_491521502101_item	2589910	et	4	main
sulle	doc_491521502101_item	2589914	et	3	main
sinu	doc_491521502101_item	2589918	et	3	main
4	doc_491521502100_item	2589823	et	2	main
5	doc_491521502100_item	2589828	et	2	main
хотел	doc_491521502100_item	2589833	et	2	main
нуждались	doc_491521502100_item	2589838	et	2	main
обсуждение	doc_491521502100_item	2589843	et	2	main
он	doc_491521502100_item	2589849	et	2	main
дело	doc_491521502100_item	2589853	et	2	main
ясность	doc_491521502100_item	2589854	et	2	main
varem	doc_491521502100_item	2589855	et	4	main
tööpäev	doc_491521502100_item	2589856	et	3	main
alga	doc_491521502100_item	2589857	et	4	main
vara	doc_491521502100_item	2589858	et	4	main
hommikul	doc_491521502100_item	2589859	et	3	main
õppimine	doc_491521502100_item	2589860	et	4	main
совете	doc_491521502100_item	2589840	et	2	main
самым	doc_491521502100_item	2589845	et	2	main
всегда	doc_491521502100_item	2589850	et	2	main
terve	doc_491521502100_item	2589862	et	4	main
elu	doc_491521502100_item	2589863	et	4	main
teil	doc_491521502100_item	2589871	et	4	main
õppida	doc_491521502100_item	2589878	et	3	main
koguaeg	doc_491521502100_item	2589880	et	3	main
ta	doc_491521502100_item	2589883	et	4	main
koguaeg	doc_491521502100_item	2589884	et	3	main
1homme	doc_491521502101_item	2589897	et	3	main
uus	doc_491521502101_item	2589903	et	3	main
maja	doc_491521502101_item	2589904	et	4	main
juba	doc_491521502101_item	2589905	et	3	main
pool	doc_491521502101_item	2589906	et	4	main
aastat	doc_491521502101_item	2589907	et	3	main
vastu	doc_491521502101_item	2589915	et	3	main
kurbus	doc_491521502101_item	2589920	et	4	main
juba	doc_491521502101_item	2589921	et	3	main
avamine	doc_491521502101_item	2589934	et	4	main
lükkub	doc_491521502101_item	2589935	et	3	main
avatakse	doc_491521502101_item	2589938	et	4	main
alates	doc_491521502101_item	2589944	et	3	main
sein	doc_491521502101_item	2589947	et	3	main
tehtud	doc_491521502101_item	2589949	et	4	main
on	doc_491521502101_item	2589952	et	4	main
sügav	doc_491521502101_item	2589953	et	4	main
auk	doc_491521502101_item	2589954	et	3	main
sein	doc_491521502101_item	2589955	et	3	main
läheme	doc_491521502101_item	2589962	et	3	main
nüüd	doc_491521502101_item	2589963	et	4	main
vajalikku	doc_491521502101_item	2589971	et	4	main
1	doc_491521502101_item	2589972	et	2	main
homme	doc_491521502101_item	2589973	et	3	main
kolime	doc_491521502101_item	2589974	et	3	main
juba	doc_491521502101_item	2589981	et	3	main
seinast	doc_491521502101_item	2590022	et	4	main
tehtnud	doc_491521502101_item	2590024	et	4	main
5	doc_491521502101_item	2590036	et	2	main
nüüd	doc_491521502101_item	2590038	et	4	main
majapidamistarvetes	doc_491521502101_item	2590041	et	4	main
kääne	doc_491521502101_item	2590049	et	3	main
majandusjuhataja	doc_491521502101_item	2590066	et	4	main
remondi	doc_491521502101_item	2590072	et	4	main
haritud	doc_491521502101_item	2590100	et	4	main
eestlased	doc_491521502101_item	2590101	et	3	main
muutusid	doc_491521502101_item	2590102	et	4	main
oma	doc_491521502101_item	2590108	et	4	main
esindajad	doc_491521502101_item	2590110	et	4	main
möödunud	doc_491521502101_item	2590112	et	4	main
talvel	doc_491521502101_item	2590113	et	4	main
kutsuti	doc_491521502101_item	2590114	et	3	main
2	doc_491521502101_item	2590120	et	2	main
et	doc_491521502101_item	2590123	et	3	main
erinevate	doc_491521502101_item	2590137	et	4	main
esindajatene	doc_491521502101_item	2590141	et	4	main
käändesse	doc_491521502101_item	2590149	et	4	main
tõlkige	doc_491521502101_item	2590150	et	3	main
pass	doc_491521502101_item	2590155	et	3	main
ei	doc_491521502101_item	2590156	et	4	main
piiri	doc_491521502101_item	2590159	et	4	main
ületada	doc_491521502101_item	2590160	et	3	main
2	doc_491521502101_item	2590161	et	2	main
poisi	doc_491521502101_item	2590162	et	3	main
et	doc_491521502101_item	2590235	et	3	main
ilma	doc_491521502101_item	2590242	et	4	main
nii	doc_491521502101_item	2590257	et	3	main
des-vorm	doc_491521502101_item	2590262	et	3	main
vene	doc_491521502101_item	2590265	et	4	main
ei	doc_491521502101_item	2590271	et	4	main
ole	doc_491521502101_item	2590272	et	4	main
eriti	doc_491521502101_item	2590273	et	3	main
rahvusvähemust	doc_491521502101_item	2590323	et	4	main
keetmata	doc_491521502101_item	2590332	et	4	main
vett	doc_491521502101_item	2590333	et	3	main
olla	doc_491521502101_item	2590336	et	3	main
hõreda	doc_491521502101_item	2590345	et	3	main
läks	doc_491521502101_item	2590350	et	3	main
tamme	doc_491521502101_item	2590351	et	4	main
ja	doc_491521502101_item	2590353	et	3	main
1	doc_491521502101_item	2590376	et	2	main
kohalikku	doc_491521502101_item	2590386	et	4	main
me	doc_491521502100_item	2589864	et	4	main
mitte	doc_491521502100_item	2589865	et	3	main
kunagi	doc_491521502100_item	2589866	et	3	main
ei	doc_491521502100_item	2589867	et	4	main
tahtnud	doc_491521502100_item	2589877	et	4	main
sulgudes	doc_491521502101_item	2589890	et	4	main
olevad	doc_491521502101_item	2589891	et	4	main
laused	doc_491521502101_item	2589896	et	3	main
kolime	doc_491521502101_item	2589898	et	3	main
maja	doc_491521502101_item	2589900	et	4	main
elame	doc_491521502101_item	2589902	et	3	main
tulen	doc_491521502101_item	2589911	et	3	main
2	doc_491521502101_item	2589916	et	2	main
viibin	doc_491521502101_item	2589924	et	3	main
peagi	doc_491521502101_item	2589928	et	4	main
oma	doc_491521502101_item	2589929	et	4	main
oktoober	doc_491521502101_item	2589939	et	3	main
oktoober	doc_491521502101_item	2589945	et	3	main
on	doc_491521502101_item	2589956	et	4	main
majapidamistarvete	doc_491521502101_item	2589964	et	4	main
osakond	doc_491521502101_item	2589965	et	3	main
aastat	doc_491521502101_item	2589983	et	3	main
jõudes	doc_491521502101_item	2589985	et	3	main
kauplus	doc_491521502101_item	2590015	et	3	main
külastajatele	doc_491521502101_item	2590017	et	4	main
mitmendat	doc_491521502101_item	2589922	et	3	main
kurbus	doc_491521502101_item	2589926	et	4	main
kurbus	doc_491521502101_item	2589930	et	4	main
vabaneda	doc_491521502101_item	2589931	et	3	main
3	doc_491521502101_item	2589932	et	2	main
kaupluse	doc_491521502101_item	2589933	et	3	main
kauplus	doc_491521502101_item	2589940	et	3	main
avatud	doc_491521502101_item	2589943	et	4	main
on	doc_491521502101_item	2589948	et	4	main
auk	doc_491521502101_item	2589950	et	3	main
ainult	doc_491521502101_item	2589959	et	4	main
kivid	doc_491521502101_item	2589960	et	3	main
5	doc_491521502101_item	2589961	et	2	main
midagi	doc_491521502101_item	2589970	et	4	main
me	doc_491521502101_item	2589977	et	4	main
elame	doc_491521502101_item	2589978	et	3	main
majas	doc_491521502101_item	2589980	et	3	main
helista	doc_491521502101_item	2589986	et	4	main
tulen	doc_491521502101_item	2589987	et	3	main
majast	doc_491521502101_item	2589988	et	4	main
väljasulle	doc_491521502101_item	2589989	et	4	main
vastu	doc_491521502101_item	2589990	et	3	main
2	doc_491521502101_item	2589991	et	2	main
langesin	doc_491521502101_item	2589992	et	3	main
sinu	doc_491521502101_item	2589993	et	3	main
pärast	doc_491521502101_item	2589994	et	4	main
kurbusist	doc_491521502101_item	2589995	et	4	main
juba	doc_491521502101_item	2589996	et	3	main
mitmendat	doc_491521502101_item	2589997	et	3	main
nädalat	doc_491521502101_item	2589998	et	3	main
viibin	doc_491521502101_item	2589999	et	3	main
sügavasse	doc_491521502101_item	2590000	et	4	main
kurbusisse	doc_491521502101_item	2590001	et	4	main
loodan	doc_491521502101_item	2590002	et	3	main
peagi	doc_491521502101_item	2590003	et	4	main
oma	doc_491521502101_item	2590004	et	4	main
vabaneda	doc_491521502101_item	2590006	et	3	main
3	doc_491521502101_item	2590007	et	2	main
kaupluse	doc_491521502101_item	2590008	et	3	main
kurbusis	doc_491521502101_item	2590005	et	4	main
avamine	doc_491521502101_item	2590009	et	4	main
lükkub	doc_491521502101_item	2590010	et	3	main
oktoobrist	doc_491521502101_item	2590011	et	3	main
kauplus	doc_491521502101_item	2590012	et	3	main
avatakse	doc_491521502101_item	2590013	et	4	main
oktoobrisse	doc_491521502101_item	2590014	et	3	main
seinas	doc_491521502101_item	2590026	et	3	main
sügav	doc_491521502101_item	2590028	et	4	main
kivid	doc_491521502101_item	2590035	et	3	main
läheme	doc_491521502101_item	2590037	et	3	main
alati	doc_491521502101_item	2590044	et	4	main
midagi	doc_491521502101_item	2590045	et	4	main
talvel	doc_491521502101_item	2590055	et	4	main
kutsuti	doc_491521502101_item	2590056	et	3	main
majandusjuhataja	doc_491521502101_item	2590061	et	4	main
2	doc_491521502101_item	2590062	et	2	main
direktor	doc_491521502101_item	2590063	et	3	main
teatas	doc_491521502101_item	2590064	et	3	main
et	doc_491521502101_item	2590065	et	3	main
eest	doc_491521502101_item	2590073	et	4	main
haritud	doc_491521502101_item	2590075	et	4	main
kasvamine	doc_491521502101_item	2590077	et	4	main
nõuab	doc_491521502101_item	2590078	et	3	main
töökust	doc_491521502101_item	2590079	et	4	main
ja	doc_491521502101_item	2590080	et	3	main
kannatlikust	doc_491521502101_item	2590081	et	4	main
4	doc_491521502101_item	2590082	et	2	main
väikese	doc_491521502101_item	2590083	et	4	main
rahvas	doc_491521502101_item	2590084	et	4	main
muretsevad	doc_491521502101_item	2590085	et	4	main
eestlased	doc_491521502101_item	2590086	et	3	main
oma	doc_491521502101_item	2590087	et	4	main
keele	doc_491521502101_item	2590088	et	4	main
saatuse	doc_491521502101_item	2590089	et	3	main
pärast	doc_491521502101_item	2590090	et	4	main
5	doc_491521502101_item	2590091	et	2	main
ajalooliselt	doc_491521502101_item	2590092	et	4	main
oli	doc_491521502101_item	2590093	et	3	main
eesti	doc_491521502101_item	2590094	et	4	main
jagunenud	doc_491521502101_item	2590095	et	4	main
erinevad	doc_491521502101_item	2590096	et	4	main
maakonnad	doc_491521502101_item	2590097	et	4	main
6	doc_491521502101_item	2590098	et	2	main
aud	doc_491521502101_item	2590025	et	3	main
on	doc_491521502101_item	2590031	et	4	main
ainult	doc_491521502101_item	2590034	et	4	main
osakonnasse	doc_491521502101_item	2590040	et	4	main
osakonnas	doc_491521502101_item	2590042	et	4	main
vajalikku	doc_491521502101_item	2590046	et	4	main
valige	doc_491521502101_item	2590047	et	3	main
saav	doc_491521502101_item	2590051	et	4	main
või	doc_491521502101_item	2590052	et	4	main
sellesse	doc_491521502101_item	2590059	et	4	main
vastutan	doc_491521502101_item	2590067	et	3	main
valminud	doc_491521502101_item	2590071	et	4	main
mõned	doc_491521502101_item	2590099	et	3	main
end	doc_491521502101_item	2590106	et	4	main
kutsekooli	doc_491521502101_item	2590118	et	4	main
majandusjuhatajana	doc_491521502101_item	2590119	et	3	main
1möödunud	doc_491521502101_item	2590054	et	4	main
kutsekooli	doc_491521502101_item	2590060	et	4	main
õige	doc_491521502101_item	2590069	et	4	main
tähtaeg	doc_491521502101_item	2590070	et	3	main
3	doc_491521502101_item	2590074	et	2	main
inimene	doc_491521502101_item	2590076	et	3	main
baltisakslased	doc_491521502101_item	2590103	et	3	main
teised	doc_491521502101_item	2590104	et	4	main
endiselt	doc_491521502101_item	2590107	et	4	main
rahva	doc_491521502101_item	2590109	et	3	main
1	doc_491521502101_item	2590111	et	2	main
ajutiselt	doc_491521502101_item	2590116	et	4	main
sellesse	doc_491521502101_item	2590117	et	4	main
teata	doc_491521502101_item	2590122	et	4	main
maakonnana	doc_491521502101_item	2590138	et	4	main
6	doc_491521502101_item	2590139	et	2	main
sulgudes	doc_491521502101_item	2590143	et	4	main
laused	doc_491521502101_item	2590151	et	3	main
huvita	doc_491521502101_item	2590224	et	4	main
puu	doc_491521502101_item	2590226	et	4	main
ärge	doc_491521502101_item	2590233	et	3	main
reis	doc_491521502101_item	2590236	et	4	main
möödud	doc_491521502101_item	2590237	et	3	main
igasuguste	doc_491521502101_item	2590239	et	3	main
6	doc_491521502101_item	2590241	et	2	main
rong	doc_491521502101_item	2590251	et	3	main
kohale	doc_491521502101_item	2590253	et	4	main
viimasest	doc_491521502101_item	2590259	et	3	main
tõlkige	doc_491521502101_item	2590263	et	3	main
elanikkonnast	doc_491521502101_item	2590315	et	4	main
veidi	doc_491521502101_item	2590316	et	3	main
alla	doc_491521502101_item	2590317	et	3	main
kolmandiku	doc_491521502101_item	2590318	et	3	main
ja	doc_491521502101_item	2590319	et	3	main
esindavad	doc_491521502101_item	2590320	et	4	main
tarvitanud	doc_491521502101_item	2590330	et	4	main
ja	doc_491521502101_item	2590334	et	3	main
võimalikult	doc_491521502101_item	2590337	et	4	main
3	doc_491521502101_item	2590339	et	2	main
võrrelda	doc_491521502101_item	2590341	et	4	main
4	doc_491521502101_item	2590348	et	2	main
juurde	doc_491521502101_item	2590352	et	4	main
selle	doc_491521502101_item	2590355	et	4	main
abile	doc_491521502101_item	2590356	et	3	main
teatavat	doc_491521502101_item	2590361	et	4	main
mõjuvõimu	doc_491521502101_item	2590362	et	4	main
inimorganismile	doc_491521502101_item	2590367	et	3	main
võtab	doc_491521502101_item	2590370	et	3	main
vähendab	doc_491521502101_item	2590374	et	3	main
suurimat	doc_491521502101_item	2590385	et	3	main
püüdis	doc_491521502101_item	2590396	et	3	main
ka	doc_491521502101_item	2590424	et	3	main
välimuse	doc_491521502101_item	2590430	et	3	main
vähendades	doc_491521502101_item	2590431	et	3	main
tõlkige	doc_491521502101_item	2590433	et	3	main
tegumoe	doc_491521502101_item	2590437	et	3	main
vajaduse	doc_491521502101_item	2590439	et	3	main
вчера	doc_491521502101_item	2590454	et	2	main
позже	doc_491521502101_item	2590460	et	2	main
работу	doc_491521502101_item	2590467	et	2	main
работодателем	doc_491521502101_item	2590473	et	2	main
сообщали	doc_491521502101_item	2590481	et	2	main
kalle	doc_491521502101_item	2590530	et	3	main
heino	doc_491521502101_item	2590535	et	4	main
keele	doc_491521502101_item	2590544	et	4	main
grammatika	doc_491521502101_item	2590548	et	4	main
tänav	doc_491521502101_item	2590556	et	4	main
on	doc_491521502101_item	2590564	et	4	main
kes	doc_491521502101_item	2590580	et	4	main
teist	doc_491521502101_item	2590581	et	4	main
sooritas	doc_491521502101_item	2590582	et	3	main
viimane	doc_491521502101_item	2590584	et	3	main
oma	doc_491521502101_item	2590588	et	4	main
sugulastega	doc_491521502101_item	2590590	et	4	main
see	doc_491521502101_item	2590591	et	3	main
kleit	doc_491521502101_item	2590592	et	3	main
on	doc_491521502101_item	2590593	et	4	main
villane	doc_491521502101_item	2590594	et	4	main
riie	doc_491521502101_item	2590595	et	3	main
villasest	doc_491521502101_item	2590596	et	4	main
riiest	doc_491521502101_item	2590597	et	3	main
tundsid	doc_491521502101_item	2590105	et	4	main
majandusjuhataja	doc_491521502101_item	2590124	et	4	main
valminud	doc_491521502101_item	2590129	et	4	main
1ilma	doc_491521502101_item	2590154	et	4	main
pesema	doc_491521502101_item	2590165	et	3	main
reisijad	doc_491521502101_item	2590167	et	4	main
suhtusid	doc_491521502101_item	2590168	et	4	main
giidi	doc_491521502101_item	2590169	et	4	main
ettepanekusse	doc_491521502101_item	2590170	et	3	main
huvi	doc_491521502101_item	2590173	et	4	main
puu	doc_491521502101_item	2590175	et	4	main
all	doc_491521502101_item	2590176	et	3	main
paks	doc_491521502101_item	2590178	et	3	main
saba	doc_491521502101_item	2590179	et	4	main
kass	doc_491521502101_item	2590180	et	3	main
5	doc_491521502101_item	2590181	et	2	main
ärge	doc_491521502101_item	2590182	et	3	main
uskuge	doc_491521502101_item	2590183	et	3	main
et	doc_491521502101_item	2590184	et	3	main
vastan	doc_491521502101_item	2590125	et	3	main
tähtajana	doc_491521502101_item	2590128	et	3	main
baltisakslasteni	doc_491521502101_item	2590140	et	4	main
pange	doc_491521502101_item	2590142	et	4	main
olevad	doc_491521502101_item	2590144	et	4	main
sõnad	doc_491521502101_item	2590145	et	4	main
ilmaütlevasse	doc_491521502101_item	2590146	et	3	main
vene	doc_491521502101_item	2590152	et	4	main
ole	doc_491521502101_item	2590157	et	4	main
lubatud	doc_491521502101_item	2590158	et	4	main
ilma	doc_491521502101_item	2590171	et	4	main
reis	doc_491521502101_item	2590185	et	4	main
ilma	doc_491521502101_item	2590187	et	4	main
igasugused	doc_491521502101_item	2590188	et	3	main
vaatamisväärsused	doc_491521502101_item	2590189	et	4	main
6	doc_491521502101_item	2590190	et	2	main
ilma	doc_491521502101_item	2590191	et	4	main
ametlik	doc_491521502101_item	2590192	et	3	main
taotlus	doc_491521502101_item	2590193	et	4	main
ei	doc_491521502101_item	2590194	et	4	main
ole	doc_491521502101_item	2590195	et	4	main
võimalik	doc_491521502101_item	2590196	et	3	main
viisat	doc_491521502101_item	2590197	et	3	main
vormistada	doc_491521502101_item	2590198	et	3	main
7	doc_491521502101_item	2590199	et	2	main
rong	doc_491521502101_item	2590200	et	3	main
saabus	doc_491521502101_item	2590201	et	3	main
kohale	doc_491521502101_item	2590202	et	4	main
hilinemine	doc_491521502101_item	2590203	et	4	main
1	doc_491521502101_item	2590204	et	2	main
ilma	doc_491521502101_item	2590205	et	4	main
passita	doc_491521502101_item	2590206	et	4	main
ei	doc_491521502101_item	2590207	et	4	main
ole	doc_491521502101_item	2590208	et	4	main
lubatud	doc_491521502101_item	2590209	et	4	main
piiri	doc_491521502101_item	2590210	et	4	main
ületada	doc_491521502101_item	2590211	et	3	main
2	doc_491521502101_item	2590212	et	2	main
poisi	doc_491521502101_item	2590213	et	3	main
nägu	doc_491521502101_item	2590214	et	4	main
oli	doc_491521502101_item	2590215	et	3	main
pesemata	doc_491521502101_item	2590216	et	4	main
3	doc_491521502101_item	2590217	et	2	main
reisijad	doc_491521502101_item	2590218	et	4	main
suhtusid	doc_491521502101_item	2590219	et	4	main
giidi	doc_491521502101_item	2590220	et	4	main
ettepanekusse	doc_491521502101_item	2590221	et	3	main
all	doc_491521502101_item	2590227	et	3	main
ilma	doc_491521502101_item	2590222	et	4	main
suure	doc_491521502101_item	2590223	et	3	main
istus	doc_491521502101_item	2590228	et	4	main
saba	doc_491521502101_item	2590230	et	4	main
kass	doc_491521502101_item	2590231	et	3	main
taotluseta	doc_491521502101_item	2590244	et	4	main
ole	doc_491521502101_item	2590246	et	4	main
võimalik	doc_491521502101_item	2590247	et	3	main
viisat	doc_491521502101_item	2590248	et	3	main
vormistada	doc_491521502101_item	2590249	et	3	main
saabus	doc_491521502101_item	2590252	et	3	main
hilinemise	doc_491521502101_item	2590254	et	4	main
muutke	doc_491521502101_item	2590255	et	3	main
saaks	doc_491521502101_item	2590261	et	3	main
saastatus	doc_491521502101_item	2590270	et	4	main
ole	doc_491521502101_item	2590284	et	4	main
eriti	doc_491521502101_item	2590285	et	3	main
tugev	doc_491521502101_item	2590286	et	4	main
andes	doc_491521502101_item	2590287	et	4	main
tunda	doc_491521502101_item	2590289	et	3	main
vaid	doc_491521502101_item	2590290	et	3	main
end	doc_491521502101_item	2590288	et	4	main
tööstuspiirkonnas	doc_491521502101_item	2590291	et	4	main
kui	doc_491521502101_item	2590293	et	3	main
b	doc_491521502101_item	2590292	et	4	main
karin	doc_491521502101_item	2590294	et	4	main
hommikul	doc_491521502101_item	2590295	et	3	main
kooli	doc_491521502101_item	2590296	et	4	main
läks	doc_491521502101_item	2590297	et	3	main
nägi	doc_491521502101_item	2590298	et	3	main
ta	doc_491521502101_item	2590299	et	4	main
puu	doc_491521502101_item	2590300	et	4	main
otsas	doc_491521502101_item	2590301	et	4	main
oravat	doc_491521502101_item	2590302	et	3	main
hommikul	doc_491521502101_item	2590303	et	3	main
kooli	doc_491521502101_item	2590304	et	4	main
minnes	doc_491521502101_item	2590305	et	3	main
nägi	doc_491521502101_item	2590306	et	3	main
karin	doc_491521502101_item	2590307	et	4	main
puu	doc_491521502101_item	2590308	et	4	main
otsas	doc_491521502101_item	2590309	et	4	main
oravat	doc_491521502101_item	2590310	et	3	main
1	doc_491521502101_item	2590311	et	2	main
venelased	doc_491521502101_item	2590312	et	3	main
moodustavad	doc_491521502101_item	2590313	et	4	main
paks	doc_491521502101_item	2590229	et	3	main
5	doc_491521502101_item	2590232	et	2	main
uskuge	doc_491521502101_item	2590234	et	3	main
ilma	doc_491521502101_item	2590238	et	4	main
vaatamisväärsusteta	doc_491521502101_item	2590240	et	4	main
ei	doc_491521502101_item	2590245	et	4	main
7	doc_491521502101_item	2590250	et	2	main
et	doc_491521502101_item	2590258	et	3	main
tegusõnast	doc_491521502101_item	2590260	et	4	main
tööstuspiirkonnas	doc_491521502101_item	2590280	et	4	main
keskkonna	doc_491521502101_item	2590281	et	3	main
saastatus	doc_491521502101_item	2590282	et	4	main
ei	doc_491521502101_item	2590283	et	4	main
kohalikku	doc_491521502101_item	2590322	et	4	main
matkal	doc_491521502101_item	2590327	et	3	main
ei	doc_491521502101_item	2590329	et	4	main
ettevaatlikud	doc_491521502101_item	2590338	et	3	main
kui	doc_491521502101_item	2590340	et	3	main
asustusega	doc_491521502101_item	2590346	et	4	main
maa	doc_491521502101_item	2590347	et	4	main
omab	doc_491521502101_item	2590360	et	3	main
avaldab	doc_491521502101_item	2590364	et	3	main
ka	doc_491521502101_item	2590366	et	3	main
6	doc_491521502101_item	2590368	et	2	main
väsimuse	doc_491521502101_item	2590372	et	4	main
venelased	doc_491521502101_item	2590377	et	3	main
eesti	doc_491521502101_item	2590379	et	4	main
elanikkonnast	doc_491521502101_item	2590380	et	4	main
veidi	doc_491521502101_item	2590381	et	3	main
alla	doc_491521502101_item	2590382	et	3	main
kolmandiku	doc_491521502101_item	2590383	et	3	main
rahvusvähemust	doc_491521502101_item	2590387	et	4	main
oles	doc_491521502101_item	2590390	et	3	main
olla	doc_491521502101_item	2590397	et	3	main
3	doc_491521502101_item	2590400	et	2	main
ära	doc_491521502101_item	2590429	et	4	main
umbisikulise	doc_491521502101_item	2590436	et	4	main
korral	doc_491521502101_item	2590440	et	4	main
kasutage	doc_491521502101_item	2590441	et	3	main
3	doc_491521502101_item	2590455	et	2	main
суммы	doc_491521502101_item	2590457	et	2	main
вас	doc_491521502101_item	2590462	et	2	main
эту	doc_491521502101_item	2590466	et	2	main
беседы	doc_491521502101_item	2590471	et	2	main
об	doc_491521502101_item	2590475	et	2	main
вчера	doc_491521502101_item	2590479	et	2	main
on	doc_491521502101_item	2590519	et	4	main
heino	doc_491521502101_item	2590524	et	4	main
õpilane	doc_491521502101_item	2590533	et	3	main
kui	doc_491521502101_item	2590534	et	3	main
on	doc_491521502101_item	2590540	et	4	main
kergem	doc_491521502101_item	2590541	et	4	main
keele	doc_491521502101_item	2590547	et	4	main
raskem	doc_491521502101_item	2590550	et	4	main
on	doc_491521502101_item	2590557	et	4	main
mustem	doc_491521502101_item	2590565	et	4	main
tänav	doc_491521502101_item	2590568	et	4	main
õige	doc_491521502101_item	2590570	et	4	main
kääne	doc_491521502101_item	2590571	et	3	main
vajadusel	doc_491521502101_item	2590573	et	3	main
eksami	doc_491521502101_item	2590583	et	3	main
tavaliselt	doc_491521502101_item	2590598	et	4	main
kolm	doc_491521502101_item	2590625	et	3	main
kes	doc_491521502101_item	2590634	et	4	main
suudab	doc_491521502101_item	2590635	et	3	main
keel	doc_491521502101_item	2590641	et	4	main
õpilastele	doc_491521502101_item	2590656	et	4	main
olevad	doc_491521502101_item	2590659	et	4	main
aega	doc_491521502101_item	2590686	et	4	main
4	doc_491521502101_item	2590687	et	2	main
hapud	doc_491521502101_item	2590697	et	3	main
mees	doc_491521502101_item	2590707	et	4	main
soome	doc_491521502101_item	2590709	et	3	main
3	doc_491521502101_item	2590730	et	2	main
saab	doc_491521502101_item	2590738	et	3	main
nugaga	doc_491521502101_item	2590741	et	4	main
näole	doc_491521502101_item	2590747	et	3	main
tavaliselt	doc_491521502101_item	2590767	et	4	main
tüdrukud	doc_491521502101_item	2590775	et	3	main
rääkima	doc_491521502101_item	2590777	et	3	main
tahtma	doc_491521502101_item	2590784	et	3	main
eesti	doc_491521502101_item	2590314	et	4	main
2	doc_491521502101_item	2590324	et	2	main
kui	doc_491521502101_item	2590325	et	3	main
me	doc_491521502101_item	2590326	et	4	main
olime	doc_491521502101_item	2590328	et	3	main
me	doc_491521502101_item	2590331	et	4	main
püüdsime	doc_491521502101_item	2590335	et	3	main
eesti	doc_491521502101_item	2590344	et	4	main
sõjamees	doc_491521502101_item	2590349	et	4	main
lootis	doc_491521502101_item	2590354	et	3	main
5	doc_491521502101_item	2590357	et	2	main
iga	doc_491521502101_item	2590358	et	4	main
ära	doc_491521502101_item	2590371	et	4	main
ja	doc_491521502101_item	2590373	et	3	main
keetmata	doc_491521502101_item	2590394	et	4	main
vett	doc_491521502101_item	2590395	et	3	main
ettvaatlikud	doc_491521502101_item	2590399	et	4	main
hollandiga	doc_491521502101_item	2590342	et	4	main
on	doc_491521502101_item	2590343	et	4	main
taim	doc_491521502101_item	2590359	et	3	main
ja	doc_491521502101_item	2590363	et	3	main
seda	doc_491521502101_item	2590365	et	3	main
kask	doc_491521502101_item	2590369	et	3	main
stressi	doc_491521502101_item	2590375	et	4	main
moodustavad	doc_491521502101_item	2590378	et	4	main
esindades	doc_491521502101_item	2590384	et	3	main
2	doc_491521502101_item	2590388	et	2	main
tarvitanud	doc_491521502101_item	2590392	et	4	main
me	doc_491521502101_item	2590393	et	4	main
võimalikult	doc_491521502101_item	2590398	et	4	main
hollandiga	doc_491521502101_item	2590401	et	4	main
hõreda	doc_491521502101_item	2590405	et	3	main
eesti	doc_491521502101_item	2590404	et	4	main
asustusega	doc_491521502101_item	2590406	et	4	main
maa	doc_491521502101_item	2590407	et	4	main
4	doc_491521502101_item	2590408	et	2	main
sõjamees	doc_491521502101_item	2590409	et	4	main
läks	doc_491521502101_item	2590410	et	3	main
tamme	doc_491521502101_item	2590411	et	4	main
juurde	doc_491521502101_item	2590412	et	4	main
lootes	doc_491521502101_item	2590413	et	4	main
selle	doc_491521502101_item	2590414	et	4	main
abil	doc_491521502101_item	2590415	et	4	main
5	doc_491521502101_item	2590416	et	2	main
igal	doc_491521502101_item	2590417	et	3	main
taim	doc_491521502101_item	2590418	et	3	main
omab	doc_491521502101_item	2590419	et	3	main
teatavat	doc_491521502101_item	2590420	et	4	main
avaldades	doc_491521502101_item	2590422	et	3	main
seda	doc_491521502101_item	2590423	et	3	main
6	doc_491521502101_item	2590426	et	2	main
võtab	doc_491521502101_item	2590428	et	3	main
stressi	doc_491521502101_item	2590432	et	4	main
eesti	doc_491521502101_item	2590434	et	4	main
abil	doc_491521502101_item	2590438	et	4	main
представляли	doc_491521502101_item	2590453	et	2	main
зарплаты	doc_491521502101_item	2590458	et	2	main
не	doc_491521502101_item	2590463	et	2	main
5	doc_491521502101_item	2590468	et	2	main
с	doc_491521502101_item	2590472	et	2	main
труда	doc_491521502101_item	2590477	et	2	main
что	doc_491521502101_item	2590482	et	2	main
tallinn	doc_491521502101_item	2590522	et	4	main
on	doc_491521502101_item	2590531	et	4	main
eesti	doc_491521502101_item	2590546	et	4	main
on	doc_491521502101_item	2590549	et	4	main
inglise	doc_491521502101_item	2590551	et	4	main
keele	doc_491521502101_item	2590552	et	4	main
puhtam	doc_491521502101_item	2590558	et	4	main
kui	doc_491521502101_item	2590559	et	3	main
sõle	doc_491521502101_item	2590560	et	3	main
tänav	doc_491521502101_item	2590561	et	4	main
sõle	doc_491521502101_item	2590562	et	3	main
täna	doc_491521502101_item	2590586	et	4	main
olen	doc_491521502101_item	2590600	et	3	main
matkal	doc_491521502101_item	2590389	et	3	main
ei	doc_491521502101_item	2590391	et	4	main
võrreldes	doc_491521502101_item	2590402	et	3	main
on	doc_491521502101_item	2590403	et	4	main
mõjuvõimu	doc_491521502101_item	2590421	et	4	main
inimorganisile	doc_491521502101_item	2590425	et	4	main
kask	doc_491521502101_item	2590427	et	3	main
vene-eesti	doc_491521502101_item	2590442	et	4	main
1цели	doc_491521502101_item	2590444	et	2	main
со	doc_491521502101_item	2590446	et	2	main
2	doc_491521502101_item	2590448	et	2	main
о	doc_491521502101_item	2590450	et	2	main
положении	doc_491521502101_item	2590452	et	2	main
начинают	doc_491521502101_item	2590459	et	2	main
на	doc_491521502101_item	2590465	et	2	main
в	doc_491521502101_item	2590469	et	2	main
говорят	doc_491521502101_item	2590474	et	2	main
6	doc_491521502101_item	2590478	et	2	main
безработица	doc_491521502101_item	2590483	et	2	main
tartu	doc_491521502101_item	2590518	et	4	main
kui	doc_491521502101_item	2590521	et	3	main
halvem	doc_491521502101_item	2590532	et	4	main
4	doc_491521502101_item	2590536	et	2	main
inglise	doc_491521502101_item	2590537	et	4	main
keele	doc_491521502101_item	2590538	et	4	main
grammatika	doc_491521502101_item	2590539	et	4	main
grammatika	doc_491521502101_item	2590545	et	4	main
grammatika	doc_491521502101_item	2590553	et	4	main
5	doc_491521502101_item	2590554	et	2	main
kui	doc_491521502101_item	2590566	et	3	main
valige	doc_491521502101_item	2590569	et	3	main
ning	doc_491521502101_item	2590572	et	3	main
tagasõna	doc_491521502101_item	2590575	et	4	main
tahan	doc_491521502101_item	2590576	et	3	main
puhata	doc_491521502101_item	2590577	et	4	main
hommik	doc_491521502101_item	2590578	et	3	main
hommikul	doc_491521502101_item	2590579	et	3	main
kohtun	doc_491521502101_item	2590587	et	3	main
ma	doc_491521502101_item	2590599	et	3	main
kodu	doc_491521502101_item	2590621	et	4	main
sellesse	doc_491521502101_item	2590629	et	4	main
kuus	doc_491521502101_item	2590632	et	4	main
inimest	doc_491521502101_item	2590633	et	3	main
keel	doc_491521502101_item	2590639	et	4	main
vene	doc_491521502101_item	2590644	et	4	main
ilma	doc_491521502101_item	2590646	et	4	main
õpilased	doc_491521502101_item	2590654	et	3	main
pange	doc_491521502101_item	2590657	et	4	main
kaasaütlevasse	doc_491521502101_item	2590661	et	3	main
omastavasse	doc_491521502101_item	2590663	et	4	main
2	doc_491521502101_item	2590674	et	2	main
buss	doc_491521502101_item	2590680	et	3	main
oksi	doc_491521502101_item	2590688	et	4	main
saab	doc_491521502101_item	2590689	et	3	main
6	doc_491521502101_item	2590699	et	2	main
vilde	doc_491521502101_item	2590701	et	4	main
paljud	doc_491521502101_item	2590724	et	3	main
rongiga	doc_491521502101_item	2590727	et	4	main
palava	doc_491521502101_item	2590731	et	4	main
kohanemine	doc_491521502101_item	2590733	et	4	main
nõuab	doc_491521502101_item	2590734	et	3	main
aega	doc_491521502101_item	2590735	et	4	main
4	doc_491521502101_item	2590736	et	2	main
ärge	doc_491521502101_item	2590743	et	3	main
hapute	doc_491521502101_item	2590746	et	4	main
on	doc_491521502101_item	2590753	et	4	main
minna	doc_491521502101_item	2590761	et	3	main
nii	doc_491521502101_item	2590762	et	3	main
laevaga	doc_491521502101_item	2590763	et	4	main
lahkuma	doc_491521502101_item	2590769	et	3	main
peab	doc_491521502101_item	2590770	et	4	main
kell	doc_491521502101_item	2590772	et	3	main
ta	doc_491521502101_item	2590782	et	4	main
te	doc_491521502101_item	2590789	et	4	main
tõlkige	doc_491521502101_item	2590823	et	3	main
1здесь	doc_491521502101_item	2590827	et	2	main
2	doc_491521502101_item	2590831	et	2	main
удобств	doc_491521502101_item	2590835	et	2	main
3	doc_491521502101_item	2590838	et	2	main
три	doc_491521502101_item	2590845	et	2	main
достижения	doc_491521502101_item	2590850	et	2	main
keelde	doc_491521502101_item	2590435	et	4	main
õppesõnastikku	doc_491521502101_item	2590443	et	4	main
достигают	doc_491521502101_item	2590445	et	2	main
временем	doc_491521502101_item	2590447	et	2	main
данные	doc_491521502101_item	2590449	et	2	main
семейном	doc_491521502101_item	2590451	et	2	main
обсуждение	doc_491521502101_item	2590456	et	2	main
4	doc_491521502101_item	2590461	et	2	main
выбрали	doc_491521502101_item	2590464	et	2	main
ходе	doc_491521502101_item	2590470	et	2	main
условиях	doc_491521502101_item	2590476	et	2	main
не	doc_491521502101_item	2590480	et	2	main
растет	doc_491521502101_item	2590484	et	2	main
jätkake	doc_491521502101_item	2590485	et	3	main
näidise	doc_491521502101_item	2590486	et	3	main
järgi	doc_491521502101_item	2590487	et	4	main
ma	doc_491521502101_item	2590489	et	3	main
olen	doc_491521502101_item	2590490	et	3	main
näidis	doc_491521502101_item	2590488	et	4	main
vanem	doc_491521502101_item	2590491	et	4	main
kui	doc_491521502101_item	2590492	et	3	main
minu	doc_491521502101_item	2590493	et	3	main
õde	doc_491521502101_item	2590494	et	4	main
minu	doc_491521502101_item	2590495	et	3	main
õde	doc_491521502101_item	2590496	et	4	main
on	doc_491521502101_item	2590497	et	4	main
noorem	doc_491521502101_item	2590498	et	4	main
kui	doc_491521502101_item	2590499	et	3	main
mina	doc_491521502101_item	2590500	et	4	main
1	doc_491521502101_item	2590501	et	2	main
poeg	doc_491521502101_item	2590502	et	3	main
on	doc_491521502101_item	2590503	et	4	main
pikem	doc_491521502101_item	2590504	et	4	main
kui	doc_491521502101_item	2590505	et	3	main
isa	doc_491521502101_item	2590506	et	4	main
isa	doc_491521502101_item	2590507	et	4	main
on	doc_491521502101_item	2590508	et	4	main
lühikem	doc_491521502101_item	2590509	et	4	main
kui	doc_491521502101_item	2590510	et	3	main
poeg	doc_491521502101_item	2590511	et	3	main
2	doc_491521502101_item	2590512	et	2	main
tallinn	doc_491521502101_item	2590513	et	4	main
on	doc_491521502101_item	2590514	et	4	main
suurem	doc_491521502101_item	2590515	et	4	main
kui	doc_491521502101_item	2590516	et	3	main
tartu	doc_491521502101_item	2590517	et	4	main
väiksem	doc_491521502101_item	2590520	et	4	main
3	doc_491521502101_item	2590523	et	2	main
on	doc_491521502101_item	2590525	et	4	main
parem	doc_491521502101_item	2590526	et	4	main
õpilane	doc_491521502101_item	2590527	et	3	main
kui	doc_491521502101_item	2590528	et	3	main
kalle	doc_491521502101_item	2590529	et	3	main
kui	doc_491521502101_item	2590542	et	3	main
eesti	doc_491521502101_item	2590543	et	4	main
meie	doc_491521502101_item	2590555	et	4	main
tänav	doc_491521502101_item	2590563	et	4	main
meie	doc_491521502101_item	2590567	et	4	main
ka	doc_491521502101_item	2590574	et	3	main
viimaseks	doc_491521502101_item	2590585	et	3	main
sugulased	doc_491521502101_item	2590589	et	3	main
suvi	doc_491521502101_item	2590601	et	3	main
suvil	doc_491521502101_item	2590602	et	4	main
puhanud	doc_491521502101_item	2590603	et	4	main
mäed	doc_491521502101_item	2590604	et	3	main
mägedel	doc_491521502101_item	2590605	et	3	main
kunstnik	doc_491521502101_item	2590606	et	3	main
kunstnikul	doc_491521502101_item	2590607	et	3	main
on	doc_491521502101_item	2590608	et	4	main
palju	doc_491521502101_item	2590609	et	4	main
tööd	doc_491521502101_item	2590610	et	4	main
isa	doc_491521502101_item	2590611	et	4	main
ostis	doc_491521502101_item	2590612	et	4	main
õhtu	doc_491521502101_item	2590613	et	4	main
õhtust	doc_491521502101_item	2590614	et	4	main
piletid	doc_491521502101_item	2590615	et	3	main
teater	doc_491521502101_item	2590616	et	3	main
teatris	doc_491521502101_item	2590617	et	3	main
lapsed	doc_491521502101_item	2590618	et	3	main
tulevad	doc_491521502101_item	2590619	et	4	main
kool	doc_491521502101_item	2590620	et	4	main
kella	doc_491521502101_item	2590624	et	4	main
kolmeni	doc_491521502101_item	2590626	et	3	main
tõlkida	doc_491521502101_item	2590636	et	3	main
vene	doc_491521502101_item	2590640	et	4	main
õpetaja	doc_491521502101_item	2590649	et	4	main
tuli	doc_491521502101_item	2590650	et	4	main
klass	doc_491521502101_item	2590651	et	3	main
klassisse	doc_491521502101_item	2590652	et	3	main
uued	doc_491521502101_item	2590653	et	3	main
sulgudes	doc_491521502101_item	2590658	et	4	main
või	doc_491521502101_item	2590662	et	4	main
käändesse	doc_491521502101_item	2590664	et	4	main
tõlkige	doc_491521502101_item	2590665	et	3	main
laused	doc_491521502101_item	2590666	et	3	main
vene	doc_491521502101_item	2590667	et	4	main
paljud	doc_491521502101_item	2590675	et	3	main
rong	doc_491521502101_item	2590678	et	3	main
lõigata	doc_491521502101_item	2590690	et	4	main
terav	doc_491521502101_item	2590691	et	3	main
nuga	doc_491521502101_item	2590692	et	4	main
5	doc_491521502101_item	2590693	et	2	main
ärge	doc_491521502101_item	2590694	et	3	main
istuge	doc_491521502101_item	2590695	et	3	main
must	doc_491521502101_item	2590705	et	4	main
mantel	doc_491521502101_item	2590706	et	3	main
7	doc_491521502101_item	2590708	et	2	main
koju	doc_491521502101_item	2590623	et	3	main
see	doc_491521502101_item	2590627	et	3	main
auto	doc_491521502101_item	2590628	et	4	main
autosse	doc_491521502101_item	2590630	et	4	main
mahub	doc_491521502101_item	2590631	et	3	main
itaaliast	doc_491521502101_item	2590642	et	4	main
keelest	doc_491521502101_item	2590643	et	4	main
keelele	doc_491521502101_item	2590645	et	4	main
uuetele	doc_491521502101_item	2590655	et	4	main
sõnad	doc_491521502101_item	2590660	et	4	main
või	doc_491521502101_item	2590679	et	4	main
palav	doc_491521502101_item	2590682	et	4	main
näod	doc_491521502101_item	2590698	et	3	main
eduard	doc_491521502101_item	2590700	et	4	main
jutustuse	doc_491521502101_item	2590702	et	4	main
pealkiri	doc_491521502101_item	2590703	et	3	main
on	doc_491521502101_item	2590704	et	4	main
on	doc_491521502101_item	2590710	et	4	main
võimalik	doc_491521502101_item	2590711	et	3	main
minna	doc_491521502101_item	2590712	et	3	main
nii	doc_491521502101_item	2590713	et	3	main
laev	doc_491521502101_item	2590714	et	3	main
kui	doc_491521502101_item	2590715	et	3	main
lennuk	doc_491521502101_item	2590716	et	3	main
1	doc_491521502101_item	2590717	et	2	main
turistid	doc_491521502101_item	2590718	et	3	main
saabusid	doc_491521502101_item	2590719	et	4	main
lennujaama	doc_491521502101_item	2590720	et	4	main
kohvitega	doc_491521502101_item	2590722	et	4	main
bussiga	doc_491521502101_item	2590729	et	3	main
lõigata	doc_491521502101_item	2590739	et	4	main
vilde	doc_491521502101_item	2590750	et	4	main
musta	doc_491521502101_item	2590754	et	4	main
7	doc_491521502101_item	2590757	et	2	main
võimalik	doc_491521502101_item	2590760	et	3	main
kui	doc_491521502101_item	2590764	et	3	main
lennukuga	doc_491521502101_item	2590765	et	4	main
viis	doc_491521502101_item	2590773	et	4	main
ei	doc_491521502101_item	2590783	et	4	main
kirjutama	doc_491521502101_item	2590791	et	3	main
töötama	doc_491521502101_item	2590797	et	3	main
võõrkeelt	doc_491521502101_item	2590821	et	4	main
eesti	doc_491521502101_item	2590825	et	4	main
бытовых	doc_491521502101_item	2590829	et	2	main
подробное	doc_491521502101_item	2590832	et	2	main
требует	doc_491521502101_item	2590836	et	2	main
году	doc_491521502101_item	2590841	et	2	main
больших	doc_491521502101_item	2590846	et	2	main
будут	doc_491521502101_item	2590851	et	2	main
нет	doc_491521502101_item	2590856	et	2	main
были	doc_491521502101_item	2590872	et	2	main
9	doc_491521502101_item	2590875	et	2	main
очень	doc_491521502101_item	2590879	et	2	main
проходит	doc_491521502101_item	2590884	et	2	main
puhavad	doc_491521502101_item	2590887	et	4	main
muugavat	doc_491521502101_item	2590892	et	4	main
oli	doc_491521502101_item	2590896	et	3	main
suuri	doc_491521502101_item	2590898	et	3	main
olevad	doc_491521502101_item	2590902	et	4	main
kas	doc_491521502101_item	2590907	et	3	main
то	doc_491521502101_item	2590913	et	2	main
рабочий	doc_491521502101_item	2590916	et	2	main
утром	doc_491521502101_item	2590920	et	2	main
жизнь	doc_491521502101_item	2590925	et	2	main
оказываем	doc_491521502101_item	2590930	et	2	main
у	doc_491521502101_item	2590934	et	2	main
я	doc_491521502101_item	2590940	et	2	main
6	doc_491521502101_item	2590944	et	2	main
в	doc_491521502101_item	2590948	et	2	main
бывало	doc_491521502101_item	2590953	et	2	main
koolist	doc_491521502101_item	2590622	et	4	main
teksti	doc_491521502101_item	2590637	et	4	main
itaalia	doc_491521502101_item	2590638	et	4	main
viga	doc_491521502101_item	2590647	et	4	main
vigaga	doc_491521502101_item	2590648	et	4	main
keelde	doc_491521502101_item	2590668	et	4	main
1turistid	doc_491521502101_item	2590669	et	3	main
saabusid	doc_491521502101_item	2590670	et	4	main
lennujaama	doc_491521502101_item	2590671	et	4	main
suured	doc_491521502101_item	2590672	et	3	main
kohvrid	doc_491521502101_item	2590673	et	3	main
eelistavad	doc_491521502101_item	2590676	et	4	main
reisida	doc_491521502101_item	2590677	et	3	main
3	doc_491521502101_item	2590681	et	2	main
kliima	doc_491521502101_item	2590683	et	4	main
kohanemine	doc_491521502101_item	2590684	et	4	main
nõuab	doc_491521502101_item	2590685	et	3	main
nii	doc_491521502101_item	2590696	et	3	main
suurte	doc_491521502101_item	2590721	et	3	main
eelistavad	doc_491521502101_item	2590725	et	4	main
või	doc_491521502101_item	2590728	et	4	main
kliima	doc_491521502101_item	2590732	et	4	main
terava	doc_491521502101_item	2590740	et	3	main
5	doc_491521502101_item	2590742	et	2	main
nii	doc_491521502101_item	2590745	et	3	main
6	doc_491521502101_item	2590748	et	2	main
eduard	doc_491521502101_item	2590749	et	4	main
jutustuse	doc_491521502101_item	2590751	et	4	main
pealkiri	doc_491521502101_item	2590752	et	3	main
mees	doc_491521502101_item	2590756	et	4	main
ta	doc_491521502101_item	2590766	et	4	main
pidama	doc_491521502101_item	2590768	et	4	main
need	doc_491521502101_item	2590774	et	3	main
võivad	doc_491521502101_item	2590778	et	4	main
kolme	doc_491521502101_item	2590780	et	4	main
võõrkeelt	doc_491521502101_item	2590781	et	4	main
hakkate	doc_491521502101_item	2590792	et	3	main
välismaalastele	doc_491521502101_item	2590822	et	4	main
keelde	doc_491521502101_item	2590826	et	4	main
удобств	doc_491521502101_item	2590830	et	2	main
бытовых	doc_491521502101_item	2590834	et	2	main
в	doc_491521502101_item	2590839	et	2	main
было	doc_491521502101_item	2590844	et	2	main
большие	doc_491521502101_item	2590849	et	2	main
вас	doc_491521502101_item	2590855	et	2	main
лица	doc_491521502101_item	2590870	et	2	main
довольно	doc_491521502101_item	2590873	et	2	main
этого	doc_491521502101_item	2590877	et	2	main
изменение	doc_491521502101_item	2590882	et	2	main
тяжело	doc_491521502101_item	2590885	et	2	main
aastas	doc_491521502101_item	2590894	et	3	main
mul	doc_491521502101_item	2590895	et	3	main
või	doc_491521502101_item	2590909	et	4	main
abil	doc_491521502101_item	2590911	et	4	main
день	doc_491521502101_item	2590917	et	2	main
2	doc_491521502101_item	2590723	et	2	main
reisida	doc_491521502101_item	2590726	et	3	main
oksi	doc_491521502101_item	2590737	et	4	main
istuge	doc_491521502101_item	2590744	et	3	main
mantliga	doc_491521502101_item	2590755	et	3	main
soome	doc_491521502101_item	2590758	et	3	main
on	doc_491521502101_item	2590759	et	4	main
lahkuda	doc_491521502101_item	2590771	et	3	main
võima	doc_491521502101_item	2590776	et	3	main
rääkida	doc_491521502101_item	2590779	et	3	main
hakkama	doc_491521502101_item	2590790	et	3	main
talle	doc_491521502101_item	2590795	et	4	main
tahan	doc_491521502101_item	2590805	et	3	main
kirjutada	doc_491521502101_item	2590806	et	3	main
kirja	doc_491521502101_item	2590807	et	4	main
oma	doc_491521502101_item	2590808	et	4	main
tuttavatele	doc_491521502101_item	2590809	et	3	main
me	doc_491521502101_item	2590810	et	4	main
hakkama	doc_491521502101_item	2590811	et	3	main
elama	doc_491521502101_item	2590812	et	3	main
hakkan	doc_491521502101_item	2590813	et	3	main
elama	doc_491521502101_item	2590814	et	3	main
tallinnas	doc_491521502101_item	2590815	et	4	main
ma	doc_491521502101_item	2590816	et	3	main
oskama	doc_491521502101_item	2590817	et	3	main
õpetama	doc_491521502101_item	2590818	et	3	main
oskan	doc_491521502101_item	2590819	et	3	main
õpetada	doc_491521502101_item	2590820	et	3	main
suitsetama	doc_491521502101_item	2590785	et	4	main
taha	doc_491521502101_item	2590786	et	4	main
suitsetada	doc_491521502101_item	2590787	et	3	main
palju	doc_491521502101_item	2590788	et	4	main
kirjutama	doc_491521502101_item	2590793	et	3	main
harjutust	doc_491521502101_item	2590794	et	4	main
meeldima	doc_491521502101_item	2590796	et	3	main
meeldib	doc_491521502101_item	2590798	et	3	main
töötada	doc_491521502101_item	2590799	et	3	main
selles	doc_491521502101_item	2590800	et	4	main
ettevõttes	doc_491521502101_item	2590801	et	3	main
ma	doc_491521502101_item	2590802	et	3	main
tahtma	doc_491521502101_item	2590803	et	3	main
kirjutama	doc_491521502101_item	2590804	et	3	main
laused	doc_491521502101_item	2590824	et	3	main
этом	doc_491521502101_item	2590840	et	2	main
меня	doc_491521502101_item	2590843	et	2	main
4	doc_491521502101_item	2590848	et	2	main
у	doc_491521502101_item	2590854	et	2	main
людей	doc_491521502101_item	2590871	et	2	main
глаза	doc_491521502101_item	2590876	et	2	main
робкие	doc_491521502101_item	2590880	et	2	main
1siin	doc_491521502101_item	2590888	et	4	main
бытовых	doc_491521502101_item	2590891	et	2	main
3selles	doc_491521502101_item	2590893	et	4	main
достижений	doc_491521502101_item	2590899	et	2	main
tõlkige	doc_491521502101_item	2590904	et	3	main
liht-	doc_491521502101_item	2590908	et	3	main
продолжалось	doc_491521502101_item	2590923	et	2	main
мы	doc_491521502101_item	2590927	et	2	main
4	doc_491521502101_item	2590932	et	2	main
5	doc_491521502101_item	2590937	et	2	main
не	doc_491521502101_item	2590941	et	2	main
постоянно	doc_491521502101_item	2590946	et	2	main
7	doc_491521502101_item	2590950	et	2	main
разумным	doc_491521502101_item	2590955	et	2	main
всегда	doc_491521502101_item	2590959	et	2	main
mida	doc_491521502101_item	2590965	et	4	main
juhtis	doc_491521502101_item	2590967	et	3	main
5	doc_491521502101_item	2590968	et	2	main
olen	doc_491521502101_item	2590969	et	3	main
juhtisin	doc_491521502101_item	2590970	et	3	main
et	doc_491521502101_item	2590971	et	3	main
ma	doc_491521502101_item	2590972	et	3	main
maja	doc_491521502102_item	2590992	et	4	main
välja	doc_491521502102_item	2591001	et	4	main
sulle	doc_491521502102_item	2591002	et	3	main
peagi	doc_491521502102_item	2591016	et	4	main
oma	doc_491521502102_item	2591017	et	4	main
leidub	doc_491521502102_item	2591056	et	3	main
majas	doc_491521502102_item	2591064	et	3	main
elame	doc_491521502102_item	2591066	et	3	main
majas	doc_491521502102_item	2591068	et	3	main
uude	doc_491521502102_item	2591077	et	3	main
uues	doc_491521502102_item	2591079	et	3	main
majas	doc_491521502102_item	2591081	et	3	main
eest	doc_491521502102_item	2591118	et	4	main
rahvas	doc_491521502102_item	2591129	et	4	main
ajalooliselt	doc_491521502102_item	2591137	et	4	main
oli	doc_491521502102_item	2591138	et	3	main
eestlased	doc_491521502102_item	2591146	et	3	main
esindajad	doc_491521502102_item	2591155	et	4	main
pange	doc_491521502102_item	2591156	et	4	main
sulgudes	doc_491521502102_item	2591157	et	4	main
olevad	doc_491521502102_item	2591158	et	4	main
käändesse	doc_491521502102_item	2591163	et	4	main
keelde	doc_491521502102_item	2591167	et	4	main
pass	doc_491521502102_item	2591169	et	3	main
ületada	doc_491521502102_item	2591174	et	3	main
poisi	doc_491521502102_item	2591176	et	3	main
pesema	doc_491521502102_item	2591179	et	3	main
giidi	doc_491521502102_item	2591183	et	4	main
4	doc_491521502102_item	2591188	et	2	main
paks	doc_491521502102_item	2591192	et	3	main
ole	doc_491521502102_item	2591222	et	4	main
lubatud	doc_491521502102_item	2591223	et	4	main
piiri	doc_491521502102_item	2591224	et	4	main
ületada	doc_491521502102_item	2591225	et	3	main
2	doc_491521502102_item	2591226	et	2	main
poisi	doc_491521502102_item	2591227	et	3	main
kass	doc_491521502102_item	2591244	et	3	main
нет	doc_491521502101_item	2590828	et	2	main
описание	doc_491521502101_item	2590833	et	2	main
времени	doc_491521502101_item	2590837	et	2	main
у	doc_491521502101_item	2590842	et	2	main
достижения	doc_491521502101_item	2590847	et	2	main
5	doc_491521502101_item	2590853	et	2	main
общаться	doc_491521502101_item	2590858	et	2	main
6	doc_491521502101_item	2590859	et	2	main
эта	doc_491521502101_item	2590860	et	2	main
работа	doc_491521502101_item	2590861	et	2	main
требует	doc_491521502101_item	2590862	et	2	main
много	doc_491521502101_item	2590863	et	2	main
разных	doc_491521502101_item	2590864	et	2	main
умений	doc_491521502101_item	2590865	et	2	main
7	doc_491521502101_item	2590866	et	2	main
люди	doc_491521502101_item	2590867	et	2	main
завтра	doc_491521502101_item	2590852	et	2	main
умения	doc_491521502101_item	2590857	et	2	main
8	doc_491521502101_item	2590869	et	2	main
простые	doc_491521502101_item	2590874	et	2	main
10	doc_491521502101_item	2590881	et	2	main
7inimesed	doc_491521502101_item	2590886	et	3	main
ei	doc_491521502101_item	2590889	et	4	main
ole	doc_491521502101_item	2590890	et	4	main
достижения	doc_491521502101_item	2590901	et	2	main
keelde	doc_491521502101_item	2590906	et	4	main
1в	doc_491521502101_item	2590912	et	2	main
каждый	doc_491521502101_item	2590915	et	2	main
рано	doc_491521502101_item	2590919	et	2	main
всю	doc_491521502101_item	2590924	et	2	main
не	doc_491521502101_item	2590929	et	2	main
случилось	doc_491521502101_item	2590936	et	2	main
мы	doc_491521502101_item	2590945	et	2	main
обсуждение	doc_491521502101_item	2590952	et	2	main
8	doc_491521502101_item	2590957	et	2	main
дело	doc_491521502101_item	2590962	et	2	main
pange	doc_491521502102_item	2590977	et	4	main
kohale	doc_491521502102_item	2590996	et	4	main
jõudes	doc_491521502102_item	2590997	et	3	main
helista	doc_491521502102_item	2590998	et	4	main
tulen	doc_491521502102_item	2590999	et	3	main
langesin	doc_491521502102_item	2591005	et	3	main
kurbus	doc_491521502102_item	2591008	et	4	main
nädalat	doc_491521502102_item	2591011	et	3	main
kurbus	doc_491521502102_item	2591018	et	4	main
3	doc_491521502102_item	2591020	et	2	main
lükkub	doc_491521502102_item	2591023	et	3	main
avatakse	doc_491521502102_item	2591026	et	4	main
külastajatele	doc_491521502102_item	2591030	et	4	main
on	doc_491521502102_item	2591036	et	4	main
sein	doc_491521502102_item	2591043	et	3	main
midagi	doc_491521502102_item	2591058	et	4	main
kolime	doc_491521502102_item	2591062	et	3	main
me	doc_491521502102_item	2591065	et	4	main
juba	doc_491521502102_item	2591069	et	3	main
pool	doc_491521502102_item	2591070	et	4	main
aastat	doc_491521502102_item	2591071	et	3	main
kohale	doc_491521502102_item	2591072	et	4	main
jõudes	doc_491521502102_item	2591073	et	3	main
helista	doc_491521502102_item	2591074	et	4	main
maja	doc_491521502102_item	2591078	et	4	main
2	doc_491521502102_item	2591082	et	2	main
3	doc_491521502102_item	2591119	et	2	main
inimene	doc_491521502102_item	2591121	et	3	main
muretsevad	doc_491521502102_item	2591130	et	4	main
eestlased	doc_491521502102_item	2591131	et	3	main
oma	doc_491521502102_item	2591132	et	4	main
haritud	doc_491521502102_item	2591145	et	4	main
teised	doc_491521502102_item	2591149	et	4	main
end	doc_491521502102_item	2591151	et	4	main
tõlkige	doc_491521502102_item	2591164	et	3	main
ei	doc_491521502102_item	2591170	et	4	main
ole	doc_491521502102_item	2591171	et	4	main
oli	doc_491521502102_item	2591178	et	3	main
suhtusid	doc_491521502102_item	2591182	et	4	main
ilma	doc_491521502102_item	2591185	et	4	main
all	doc_491521502102_item	2591190	et	3	main
5	doc_491521502102_item	2591195	et	2	main
ärge	doc_491521502102_item	2591196	et	3	main
uskuge	doc_491521502102_item	2591197	et	3	main
et	doc_491521502102_item	2591198	et	3	main
ei	doc_491521502102_item	2591221	et	4	main
ettepanekuses	doc_491521502102_item	2591235	et	4	main
4	doc_491521502102_item	2591239	et	2	main
uskuge	doc_491521502102_item	2591247	et	3	main
reis	doc_491521502102_item	2591249	et	4	main
viisat	doc_491521502102_item	2591261	et	3	main
7	doc_491521502102_item	2591263	et	2	main
et	doc_491521502102_item	2591271	et	3	main
viimasest	doc_491521502102_item	2591272	et	3	main
tõlkige	doc_491521502102_item	2591276	et	3	main
keskkonna	doc_491521502102_item	2591282	et	3	main
saastatus	doc_491521502102_item	2591283	et	4	main
ei	doc_491521502102_item	2591284	et	4	main
ole	doc_491521502102_item	2591285	et	4	main
eriti	doc_491521502102_item	2591286	et	3	main
end	doc_491521502102_item	2591290	et	4	main
vaid	doc_491521502102_item	2591292	et	3	main
отдыхают	doc_491521502101_item	2590868	et	2	main
человека	doc_491521502101_item	2590878	et	2	main
самооценки	doc_491521502101_item	2590883	et	2	main
kolm	doc_491521502101_item	2590897	et	3	main
4suured	doc_491521502101_item	2590900	et	3	main
homme	doc_491521502101_item	2590903	et	3	main
eesti	doc_491521502101_item	2590905	et	4	main
täismineviku	doc_491521502101_item	2590910	et	3	main
время	doc_491521502101_item	2590914	et	2	main
начинался	doc_491521502101_item	2590918	et	2	main
2	doc_491521502101_item	2590921	et	2	main
никогда	doc_491521502101_item	2590928	et	2	main
что	doc_491521502101_item	2590933	et	2	main
случалось	doc_491521502101_item	2590938	et	2	main
учиться	doc_491521502101_item	2590943	et	2	main
совете	doc_491521502101_item	2590949	et	2	main
самым	doc_491521502101_item	2590954	et	2	main
вносил	doc_491521502101_item	2590960	et	2	main
4	doc_491521502101_item	2590964	et	2	main
õpida	doc_491521502101_item	2590975	et	4	main
juba	doc_491521502102_item	2590993	et	3	main
pool	doc_491521502102_item	2590994	et	4	main
aastat	doc_491521502102_item	2590995	et	3	main
vastu	doc_491521502102_item	2591003	et	3	main
pärast	doc_491521502102_item	2591007	et	4	main
juba	doc_491521502102_item	2591009	et	3	main
mitmendat	doc_491521502102_item	2591010	et	3	main
sügav	doc_491521502102_item	2591013	et	4	main
kurbus	doc_491521502102_item	2591014	et	4	main
loodan	doc_491521502102_item	2591015	et	3	main
avamine	doc_491521502102_item	2591022	et	4	main
oktoober	doc_491521502102_item	2591024	et	3	main
on	doc_491521502102_item	2591029	et	4	main
tehtud	doc_491521502102_item	2591037	et	4	main
sügav	doc_491521502102_item	2591041	et	4	main
on	doc_491521502102_item	2591044	et	4	main
järele	doc_491521502102_item	2591045	et	4	main
jäänud	doc_491521502102_item	2591046	et	4	main
majapidamistarvete	doc_491521502102_item	2591054	et	4	main
õige	doc_491521502102_item	2591114	et	4	main
nõuab	doc_491521502102_item	2591123	et	3	main
ja	doc_491521502102_item	2591125	et	3	main
kannatlikust	doc_491521502102_item	2591126	et	4	main
4	doc_491521502102_item	2591127	et	2	main
eesti	doc_491521502102_item	2591139	et	4	main
jagunenud	doc_491521502102_item	2591140	et	4	main
lubatud	doc_491521502102_item	2591172	et	4	main
3	doc_491521502102_item	2591180	et	2	main
ettepanekusse	doc_491521502102_item	2591184	et	3	main
suur	doc_491521502102_item	2591186	et	3	main
huvi	doc_491521502102_item	2591187	et	4	main
istus	doc_491521502102_item	2591191	et	4	main
saba	doc_491521502102_item	2591193	et	4	main
kass	doc_491521502102_item	2591194	et	3	main
reis	doc_491521502102_item	2591199	et	4	main
möödub	doc_491521502102_item	2591200	et	3	main
ilma	doc_491521502102_item	2591201	et	4	main
nägu	doc_491521502102_item	2591228	et	4	main
giidi	doc_491521502102_item	2591234	et	4	main
5	doc_491521502102_item	2591245	et	2	main
ilma	doc_491521502102_item	2591251	et	4	main
6	doc_491521502102_item	2591254	et	2	main
taotlusta	doc_491521502102_item	2591257	et	4	main
vormistada	doc_491521502102_item	2591262	et	3	main
hilinemiseta	doc_491521502102_item	2591267	et	4	main
muutke	doc_491521502102_item	2591268	et	3	main
saaks	doc_491521502102_item	2591274	et	3	main
ja	doc_491521502102_item	2591288	et	3	main
saastatus	doc_491521502102_item	2591295	et	4	main
ei	doc_491521502102_item	2591296	et	4	main
tunda	doc_491521502102_item	2591302	et	3	main
vaid	doc_491521502102_item	2591303	et	3	main
tööstuspiirkonnas	doc_491521502102_item	2591304	et	4	main
läks	doc_491521502102_item	2591310	et	3	main
обучение	doc_491521502101_item	2590922	et	2	main
3	doc_491521502101_item	2590926	et	2	main
давления	doc_491521502101_item	2590931	et	2	main
вас	doc_491521502101_item	2590935	et	2	main
что	doc_491521502101_item	2590939	et	2	main
хотел	doc_491521502101_item	2590942	et	2	main
нуждались	doc_491521502101_item	2590947	et	2	main
спокойное	doc_491521502101_item	2590951	et	2	main
он	doc_491521502101_item	2590958	et	2	main
в	doc_491521502101_item	2590961	et	2	main
ei	doc_491521502101_item	2590973	et	4	main
kontrolltöö	doc_491521502102_item	2590976	et	4	main
sulgudes	doc_491521502102_item	2590978	et	4	main
uus	doc_491521502102_item	2590987	et	3	main
2	doc_491521502102_item	2591004	et	2	main
kaupluse	doc_491521502102_item	2591021	et	3	main
kauplus	doc_491521502102_item	2591025	et	3	main
oktoober	doc_491521502102_item	2591027	et	3	main
avatud	doc_491521502102_item	2591031	et	4	main
alates	doc_491521502102_item	2591032	et	3	main
oktoober	doc_491521502102_item	2591033	et	3	main
sein	doc_491521502102_item	2591035	et	3	main
sein	doc_491521502102_item	2591039	et	3	main
ainult	doc_491521502102_item	2591047	et	4	main
5	doc_491521502102_item	2591049	et	2	main
nüüd	doc_491521502102_item	2591051	et	4	main
osakond	doc_491521502102_item	2591053	et	3	main
osakond	doc_491521502102_item	2591055	et	3	main
vajalikku	doc_491521502102_item	2591059	et	4	main
homme	doc_491521502102_item	2591061	et	3	main
uues	doc_491521502102_item	2591067	et	3	main
1	doc_491521502102_item	2591076	et	2	main
mina	doc_491521502102_item	2591113	et	4	main
tähtaeg	doc_491521502102_item	2591115	et	3	main
valminud	doc_491521502102_item	2591116	et	4	main
haritud	doc_491521502102_item	2591120	et	4	main
kasvamine	doc_491521502102_item	2591122	et	4	main
väikese	doc_491521502102_item	2591128	et	4	main
keele	doc_491521502102_item	2591133	et	4	main
erinevad	doc_491521502102_item	2591141	et	4	main
muutusid	doc_491521502102_item	2591147	et	4	main
või	doc_491521502102_item	2591161	et	4	main
omastavasse	doc_491521502102_item	2591162	et	4	main
vene	doc_491521502102_item	2591166	et	4	main
1ilma	doc_491521502102_item	2591168	et	4	main
nägu	doc_491521502102_item	2591177	et	4	main
reisijad	doc_491521502102_item	2591181	et	4	main
puu	doc_491521502102_item	2591189	et	4	main
oli	doc_491521502102_item	2591229	et	3	main
3	doc_491521502102_item	2591231	et	2	main
ilma	doc_491521502102_item	2591236	et	4	main
huvita	doc_491521502102_item	2591238	et	4	main
ärge	doc_491521502102_item	2591246	et	3	main
möödub	doc_491521502102_item	2591250	et	3	main
vaatamisväärsusta	doc_491521502102_item	2591253	et	4	main
ametliku	doc_491521502102_item	2591256	et	3	main
ole	doc_491521502102_item	2591259	et	4	main
rong	doc_491521502102_item	2591264	et	3	main
kohale	doc_491521502102_item	2591266	et	4	main
lauseid	doc_491521502102_item	2591269	et	3	main
a	doc_491521502102_item	2591281	et	4	main
tugev	doc_491521502102_item	2591287	et	4	main
tunda	doc_491521502102_item	2591291	et	3	main
tööstuspiirkonnas	doc_491521502102_item	2591293	et	4	main
kui	doc_491521502102_item	2591306	et	3	main
kooli	doc_491521502102_item	2591317	et	4	main
elanikkonnast	doc_491521502102_item	2591328	et	4	main
veidi	doc_491521502102_item	2591329	et	3	main
alla	doc_491521502102_item	2591330	et	3	main
kolmandiku	doc_491521502102_item	2591331	et	3	main
rahvusvähemust	doc_491521502102_item	2591336	et	4	main
keetmata	doc_491521502102_item	2591345	et	4	main
vett	doc_491521502102_item	2591346	et	3	main
püüdsime	doc_491521502102_item	2591348	et	3	main
võimalikult	doc_491521502102_item	2591350	et	4	main
3	doc_491521502102_item	2591352	et	2	main
võrrelda	doc_491521502102_item	2591354	et	4	main
tamme	doc_491521502102_item	2591364	et	4	main
omab	doc_491521502102_item	2591373	et	3	main
võtab	doc_491521502102_item	2591383	et	3	main
väsimuse	doc_491521502102_item	2591392	et	4	main
mõjuvõimu	doc_491521502102_item	2591400	et	4	main
ja	doc_491521502102_item	2591401	et	3	main
avades	doc_491521502102_item	2591402	et	4	main
seda	doc_491521502102_item	2591403	et	3	main
ka	doc_491521502102_item	2591404	et	3	main
inimorganismile	doc_491521502102_item	2591405	et	3	main
решением	doc_491521502101_item	2590956	et	2	main
ясность	doc_491521502101_item	2590963	et	2	main
teile	doc_491521502101_item	2590966	et	4	main
tahtnud	doc_491521502101_item	2590974	et	4	main
olevad	doc_491521502102_item	2590979	et	4	main
sõnad	doc_491521502102_item	2590980	et	4	main
vastavatesse	doc_491521502102_item	2590981	et	4	main
sisekohakäänetesse	doc_491521502102_item	2590982	et	3	main
tõlkige	doc_491521502102_item	2590983	et	3	main
laused	doc_491521502102_item	2590984	et	3	main
1homme	doc_491521502102_item	2590985	et	3	main
kolime	doc_491521502102_item	2590986	et	3	main
maja	doc_491521502102_item	2590988	et	4	main
me	doc_491521502102_item	2590989	et	4	main
elame	doc_491521502102_item	2590990	et	3	main
uus	doc_491521502102_item	2590991	et	3	main
maja	doc_491521502102_item	2591000	et	4	main
sinu	doc_491521502102_item	2591006	et	3	main
viibin	doc_491521502102_item	2591012	et	3	main
vabaneda	doc_491521502102_item	2591019	et	3	main
kauplus	doc_491521502102_item	2591028	et	3	main
4	doc_491521502102_item	2591034	et	2	main
auk	doc_491521502102_item	2591038	et	3	main
on	doc_491521502102_item	2591040	et	4	main
auk	doc_491521502102_item	2591042	et	3	main
kivid	doc_491521502102_item	2591048	et	3	main
läheme	doc_491521502102_item	2591050	et	3	main
majapidamistarvete	doc_491521502102_item	2591052	et	4	main
alati	doc_491521502102_item	2591057	et	4	main
1	doc_491521502102_item	2591060	et	2	main
uus	doc_491521502102_item	2591063	et	3	main
tulen	doc_491521502102_item	2591075	et	3	main
majas	doc_491521502102_item	2591080	et	3	main
kurbus	doc_491521502102_item	2591083	et	4	main
3	doc_491521502102_item	2591084	et	2	main
oktoobrisse	doc_491521502102_item	2591085	et	3	main
oktoobris	doc_491521502102_item	2591086	et	3	main
oktoobrilt	doc_491521502102_item	2591087	et	3	main
4	doc_491521502102_item	2591088	et	2	main
seina	doc_491521502102_item	2591089	et	4	main
seinas	doc_491521502102_item	2591090	et	3	main
seinalt	doc_491521502102_item	2591091	et	3	main
valige	doc_491521502102_item	2591092	et	3	main
õige	doc_491521502102_item	2591093	et	4	main
kääne	doc_491521502102_item	2591094	et	3	main
kas	doc_491521502102_item	2591095	et	3	main
saav	doc_491521502102_item	2591096	et	4	main
või	doc_491521502102_item	2591097	et	4	main
olev	doc_491521502102_item	2591098	et	4	main
1möödunud	doc_491521502102_item	2591099	et	4	main
talvel	doc_491521502102_item	2591100	et	4	main
kutsuti	doc_491521502102_item	2591101	et	3	main
mind	doc_491521502102_item	2591102	et	4	main
ajutiselt	doc_491521502102_item	2591103	et	4	main
sellesse	doc_491521502102_item	2591104	et	4	main
kutsekooli	doc_491521502102_item	2591105	et	4	main
majandusjuhataja	doc_491521502102_item	2591106	et	4	main
2	doc_491521502102_item	2591107	et	2	main
direktor	doc_491521502102_item	2591108	et	3	main
teatas	doc_491521502102_item	2591109	et	3	main
et	doc_491521502102_item	2591110	et	3	main
majandusjuhataja	doc_491521502102_item	2591111	et	4	main
vastutan	doc_491521502102_item	2591112	et	3	main
remondi	doc_491521502102_item	2591117	et	4	main
töökust	doc_491521502102_item	2591124	et	4	main
saatuse	doc_491521502102_item	2591134	et	3	main
pärast	doc_491521502102_item	2591135	et	4	main
5	doc_491521502102_item	2591136	et	2	main
maakonnad	doc_491521502102_item	2591142	et	4	main
6	doc_491521502102_item	2591143	et	2	main
mõned	doc_491521502102_item	2591144	et	3	main
baltisakslased	doc_491521502102_item	2591148	et	3	main
tundsid	doc_491521502102_item	2591150	et	4	main
endiselt	doc_491521502102_item	2591152	et	4	main
oma	doc_491521502102_item	2591153	et	4	main
rahva	doc_491521502102_item	2591154	et	3	main
sõnad	doc_491521502102_item	2591159	et	4	main
ilmaütlevasse	doc_491521502102_item	2591160	et	3	main
laused	doc_491521502102_item	2591165	et	3	main
piiri	doc_491521502102_item	2591173	et	4	main
2	doc_491521502102_item	2591175	et	2	main
igasugused	doc_491521502102_item	2591202	et	3	main
vaatamisväärsused	doc_491521502102_item	2591203	et	4	main
6	doc_491521502102_item	2591204	et	2	main
ilma	doc_491521502102_item	2591205	et	4	main
ametlik	doc_491521502102_item	2591206	et	3	main
taotlus	doc_491521502102_item	2591207	et	4	main
ei	doc_491521502102_item	2591208	et	4	main
ole	doc_491521502102_item	2591209	et	4	main
võimalik	doc_491521502102_item	2591210	et	3	main
viisat	doc_491521502102_item	2591211	et	3	main
vormistada	doc_491521502102_item	2591212	et	3	main
7	doc_491521502102_item	2591213	et	2	main
rong	doc_491521502102_item	2591214	et	3	main
saabus	doc_491521502102_item	2591215	et	3	main
kohale	doc_491521502102_item	2591216	et	4	main
hilinemine	doc_491521502102_item	2591217	et	4	main
1	doc_491521502102_item	2591218	et	2	main
ilma	doc_491521502102_item	2591219	et	4	main
passita	doc_491521502102_item	2591220	et	4	main
pesta	doc_491521502102_item	2591230	et	4	main
resijad	doc_491521502102_item	2591232	et	4	main
suhutusid	doc_491521502102_item	2591233	et	4	main
suure	doc_491521502102_item	2591237	et	3	main
puu	doc_491521502102_item	2591240	et	4	main
all	doc_491521502102_item	2591241	et	3	main
istus	doc_491521502102_item	2591242	et	4	main
sabata	doc_491521502102_item	2591243	et	3	main
et	doc_491521502102_item	2591248	et	3	main
igasugusta	doc_491521502102_item	2591252	et	4	main
ilma	doc_491521502102_item	2591255	et	4	main
nii	doc_491521502102_item	2591270	et	3	main
des-vorm	doc_491521502102_item	2591275	et	3	main
laused	doc_491521502102_item	2591277	et	3	main
keelde	doc_491521502102_item	2591279	et	4	main
näidis	doc_491521502102_item	2591280	et	4	main
ole	doc_491521502102_item	2591297	et	4	main
eriti	doc_491521502102_item	2591298	et	3	main
karin	doc_491521502102_item	2591307	et	4	main
hommikul	doc_491521502102_item	2591308	et	3	main
ta	doc_491521502102_item	2591312	et	4	main
nägi	doc_491521502102_item	2591319	et	3	main
esindavad	doc_491521502102_item	2591333	et	4	main
suurimat	doc_491521502102_item	2591334	et	3	main
ja	doc_491521502102_item	2591347	et	3	main
hollandiga	doc_491521502102_item	2591355	et	4	main
asustusega	doc_491521502102_item	2591359	et	4	main
maa	doc_491521502102_item	2591360	et	4	main
4	doc_491521502102_item	2591361	et	2	main
5	doc_491521502102_item	2591370	et	2	main
iga	doc_491521502102_item	2591371	et	4	main
väsimuse	doc_491521502102_item	2591385	et	4	main
6kask	doc_491521502102_item	2591389	et	3	main
ära	doc_491521502102_item	2591391	et	4	main
vähedes	doc_491521502102_item	2591394	et	4	main
omab	doc_491521502102_item	2591398	et	3	main
esindades	doc_491521502102_item	2591422	et	3	main
hõreda	doc_491521502102_item	2591429	et	3	main
eesti	doc_491521502102_item	2591433	et	4	main
vajaduse	doc_491521502102_item	2591438	et	3	main
обсуждение	doc_491521502102_item	2591455	et	2	main
зарплаты	doc_491521502102_item	2591457	et	2	main
не	doc_491521502102_item	2591462	et	2	main
эту	doc_491521502102_item	2591465	et	2	main
ходе	doc_491521502102_item	2591469	et	2	main
говорят	doc_491521502102_item	2591473	et	2	main
труда	doc_491521502102_item	2591476	et	2	main
что	doc_491521502102_item	2591481	et	2	main
sellel	doc_491521502102_item	2591490	et	4	main
töötama	doc_491521502102_item	2591491	et	3	main
suurem	doc_491521502102_item	2591522	et	4	main
kui	doc_491521502102_item	2591523	et	3	main
halsem	doc_491521502102_item	2591539	et	4	main
inglise	doc_491521502102_item	2591544	et	4	main
grammatika	doc_491521502102_item	2591552	et	4	main
eesti	doc_491521502102_item	2591553	et	4	main
kui	doc_491521502102_item	2591558	et	3	main
inglise	doc_491521502102_item	2591559	et	4	main
kes	doc_491521502102_item	2591588	et	4	main
sooritas	doc_491521502102_item	2591590	et	3	main
oma	doc_491521502102_item	2591596	et	4	main
on	doc_491521502102_item	2591601	et	4	main
riie	doc_491521502102_item	2591603	et	3	main
riielt	doc_491521502102_item	2591605	et	3	main
tavaliselt	doc_491521502102_item	2591606	et	4	main
õhtu	doc_491521502102_item	2591620	et	4	main
ei	doc_491521502102_item	2591258	et	4	main
võimalik	doc_491521502102_item	2591260	et	3	main
saabus	doc_491521502102_item	2591265	et	3	main
tegusõnast	doc_491521502102_item	2591273	et	4	main
vene	doc_491521502102_item	2591278	et	4	main
annab	doc_491521502102_item	2591289	et	3	main
tugev	doc_491521502102_item	2591299	et	4	main
b	doc_491521502102_item	2591305	et	4	main
puu	doc_491521502102_item	2591313	et	4	main
otsas	doc_491521502102_item	2591314	et	4	main
oravat	doc_491521502102_item	2591315	et	3	main
hommikul	doc_491521502102_item	2591316	et	3	main
karin	doc_491521502102_item	2591320	et	4	main
1	doc_491521502102_item	2591324	et	2	main
ja	doc_491521502102_item	2591332	et	3	main
2	doc_491521502102_item	2591337	et	2	main
me	doc_491521502102_item	2591339	et	4	main
olime	doc_491521502102_item	2591341	et	3	main
olla	doc_491521502102_item	2591349	et	3	main
ettevaatlikud	doc_491521502102_item	2591351	et	3	main
kui	doc_491521502102_item	2591353	et	3	main
eesti	doc_491521502102_item	2591357	et	4	main
juurde	doc_491521502102_item	2591365	et	4	main
ja	doc_491521502102_item	2591366	et	3	main
lootis	doc_491521502102_item	2591367	et	3	main
selle	doc_491521502102_item	2591368	et	4	main
abile	doc_491521502102_item	2591369	et	3	main
teatavat	doc_491521502102_item	2591374	et	4	main
ja	doc_491521502102_item	2591376	et	3	main
avaldab	doc_491521502102_item	2591377	et	3	main
seda	doc_491521502102_item	2591378	et	3	main
ka	doc_491521502102_item	2591379	et	3	main
6	doc_491521502102_item	2591381	et	2	main
vähendab	doc_491521502102_item	2591387	et	3	main
stressi	doc_491521502102_item	2591388	et	4	main
võtab	doc_491521502102_item	2591390	et	3	main
stressi	doc_491521502102_item	2591395	et	4	main
laks	doc_491521502102_item	2591407	et	4	main
ja	doc_491521502102_item	2591421	et	3	main
suurimat	doc_491521502102_item	2591423	et	3	main
kohalikku	doc_491521502102_item	2591424	et	4	main
keelde	doc_491521502102_item	2591434	et	4	main
3	doc_491521502102_item	2591454	et	2	main
начинают	doc_491521502102_item	2591458	et	2	main
5	doc_491521502102_item	2591467	et	2	main
об	doc_491521502102_item	2591474	et	2	main
вчера	doc_491521502102_item	2591478	et	2	main
безработица	doc_491521502102_item	2591482	et	2	main
saavutused	doc_491521502102_item	2591485	et	4	main
näidise	doc_491521502102_item	2591493	et	3	main
olen	doc_491521502102_item	2591497	et	3	main
väiksem	doc_491521502102_item	2591527	et	4	main
kui	doc_491521502102_item	2591528	et	3	main
tallinn	doc_491521502102_item	2591529	et	4	main
3	doc_491521502102_item	2591530	et	2	main
kalle	doc_491521502102_item	2591537	et	3	main
4	doc_491521502102_item	2591543	et	2	main
on	doc_491521502102_item	2591547	et	4	main
kui	doc_491521502102_item	2591549	et	3	main
eesti	doc_491521502102_item	2591550	et	4	main
grammatika	doc_491521502102_item	2591555	et	4	main
grammatika	doc_491521502102_item	2591561	et	4	main
5	doc_491521502102_item	2591562	et	2	main
hommik	doc_491521502102_item	2591586	et	3	main
viimane	doc_491521502102_item	2591592	et	3	main
see	doc_491521502102_item	2591599	et	3	main
ma	doc_491521502102_item	2591607	et	3	main
olen	doc_491521502102_item	2591608	et	3	main
suvi	doc_491521502102_item	2591609	et	3	main
suvil	doc_491521502102_item	2591610	et	4	main
on	doc_491521502102_item	2591615	et	4	main
õhtul	doc_491521502102_item	2591621	et	3	main
kella	doc_491521502102_item	2591631	et	4	main
see	doc_491521502102_item	2591634	et	3	main
mahub	doc_491521502102_item	2591638	et	3	main
inimest	doc_491521502102_item	2591640	et	3	main
suudab	doc_491521502102_item	2591642	et	3	main
viga	doc_491521502102_item	2591654	et	4	main
õpilased	doc_491521502102_item	2591661	et	3	main
saabusid	doc_491521502102_item	2591677	et	4	main
paljud	doc_491521502102_item	2591682	et	3	main
kliima	doc_491521502102_item	2591690	et	4	main
keskkonna	doc_491521502102_item	2591294	et	3	main
andes	doc_491521502102_item	2591300	et	4	main
end	doc_491521502102_item	2591301	et	4	main
kooli	doc_491521502102_item	2591309	et	4	main
nägi	doc_491521502102_item	2591311	et	3	main
minnes	doc_491521502102_item	2591318	et	3	main
puu	doc_491521502102_item	2591321	et	4	main
oravat	doc_491521502102_item	2591323	et	3	main
venelased	doc_491521502102_item	2591325	et	3	main
moodustavad	doc_491521502102_item	2591326	et	4	main
eesti	doc_491521502102_item	2591327	et	4	main
kui	doc_491521502102_item	2591338	et	3	main
matkal	doc_491521502102_item	2591340	et	3	main
ei	doc_491521502102_item	2591342	et	4	main
tarvitanud	doc_491521502102_item	2591343	et	4	main
sõjamees	doc_491521502102_item	2591362	et	4	main
läks	doc_491521502102_item	2591363	et	3	main
taim	doc_491521502102_item	2591372	et	3	main
mõjuvõimu	doc_491521502102_item	2591375	et	4	main
inimorganismile	doc_491521502102_item	2591380	et	3	main
kask	doc_491521502102_item	2591382	et	3	main
ära	doc_491521502102_item	2591384	et	4	main
5iga	doc_491521502102_item	2591396	et	4	main
taim	doc_491521502102_item	2591397	et	3	main
teatavat	doc_491521502102_item	2591399	et	4	main
3hollandiga	doc_491521502102_item	2591426	et	4	main
abil	doc_491521502102_item	2591437	et	4	main
вчера	doc_491521502102_item	2591453	et	2	main
4	doc_491521502102_item	2591460	et	2	main
выбрали	doc_491521502102_item	2591463	et	2	main
в	doc_491521502102_item	2591468	et	2	main
беседы	doc_491521502102_item	2591470	et	2	main
условиях	doc_491521502102_item	2591475	et	2	main
не	doc_491521502102_item	2591479	et	2	main
растет	doc_491521502102_item	2591483	et	2	main
teil	doc_491521502102_item	2591487	et	4	main
näidis	doc_491521502102_item	2591495	et	4	main
ma	doc_491521502102_item	2591496	et	3	main
vanem	doc_491521502102_item	2591498	et	4	main
otsas	doc_491521502102_item	2591322	et	4	main
kohalikku	doc_491521502102_item	2591335	et	4	main
me	doc_491521502102_item	2591344	et	4	main
on	doc_491521502102_item	2591356	et	4	main
hõreda	doc_491521502102_item	2591358	et	3	main
ja	doc_491521502102_item	2591386	et	3	main
ja	doc_491521502102_item	2591393	et	3	main
tamme	doc_491521502102_item	2591408	et	4	main
ja	doc_491521502102_item	2591410	et	3	main
lootes	doc_491521502102_item	2591411	et	4	main
selle	doc_491521502102_item	2591412	et	4	main
abile	doc_491521502102_item	2591413	et	3	main
1venelased	doc_491521502102_item	2591414	et	3	main
moodustavad	doc_491521502102_item	2591415	et	4	main
eesti	doc_491521502102_item	2591416	et	4	main
elanikkonnast	doc_491521502102_item	2591417	et	4	main
veidi	doc_491521502102_item	2591418	et	3	main
alla	doc_491521502102_item	2591419	et	3	main
kolmandiku	doc_491521502102_item	2591420	et	3	main
võrreldes	doc_491521502102_item	2591427	et	3	main
eesti	doc_491521502102_item	2591428	et	4	main
asustusega	doc_491521502102_item	2591430	et	4	main
maa	doc_491521502102_item	2591431	et	4	main
tõlkige	doc_491521502102_item	2591432	et	3	main
tegumoe	doc_491521502102_item	2591436	et	3	main
kasutage	doc_491521502102_item	2591440	et	3	main
õppesõnastikku	doc_491521502102_item	2591442	et	4	main
достигают	doc_491521502102_item	2591444	et	2	main
временем	doc_491521502102_item	2591446	et	2	main
данные	doc_491521502102_item	2591448	et	2	main
семейном	doc_491521502102_item	2591450	et	2	main
представляли	doc_491521502102_item	2591452	et	2	main
позже	doc_491521502102_item	2591459	et	2	main
на	doc_491521502102_item	2591464	et	2	main
с	doc_491521502102_item	2591471	et	2	main
6	doc_491521502102_item	2591477	et	2	main
jätkake	doc_491521502102_item	2591492	et	3	main
on	doc_491521502102_item	2591521	et	4	main
tartu	doc_491521502102_item	2591524	et	4	main
tartu	doc_491521502102_item	2591525	et	4	main
on	doc_491521502102_item	2591532	et	4	main
parem	doc_491521502102_item	2591533	et	4	main
õpilane	doc_491521502102_item	2591534	et	3	main
kui	doc_491521502102_item	2591535	et	3	main
kalle	doc_491521502102_item	2591536	et	3	main
kui	doc_491521502102_item	2591540	et	3	main
keele	doc_491521502102_item	2591545	et	4	main
grammatika	doc_491521502102_item	2591546	et	4	main
kergem	doc_491521502102_item	2591548	et	4	main
keele	doc_491521502102_item	2591554	et	4	main
keele	doc_491521502102_item	2591560	et	4	main
puhata	doc_491521502102_item	2591585	et	4	main
viimasel	doc_491521502102_item	2591593	et	3	main
kohtun	doc_491521502102_item	2591595	et	3	main
kleit	doc_491521502102_item	2591600	et	3	main
villane	doc_491521502102_item	2591602	et	4	main
villase	doc_491521502102_item	2591604	et	4	main
kunstniku	doc_491521502102_item	2591614	et	3	main
tööd	doc_491521502102_item	2591617	et	4	main
teater	doc_491521502102_item	2591623	et	3	main
kool	doc_491521502102_item	2591627	et	4	main
kodu	doc_491521502102_item	2591628	et	4	main
koolis	doc_491521502102_item	2591629	et	4	main
koju	doc_491521502102_item	2591630	et	3	main
auto	doc_491521502102_item	2591635	et	4	main
kes	doc_491521502102_item	2591641	et	4	main
tõlkida	doc_491521502102_item	2591643	et	3	main
teksti	doc_491521502102_item	2591644	et	4	main
uued	doc_491521502102_item	2591662	et	3	main
sulgudes	doc_491521502102_item	2591665	et	4	main
4sõjamees	doc_491521502102_item	2591406	et	4	main
juurde	doc_491521502102_item	2591409	et	4	main
rahvusvähemust	doc_491521502102_item	2591425	et	4	main
umbisikulise	doc_491521502102_item	2591435	et	4	main
korral	doc_491521502102_item	2591439	et	4	main
vene-eesti	doc_491521502102_item	2591441	et	4	main
1цели	doc_491521502102_item	2591443	et	2	main
со	doc_491521502102_item	2591445	et	2	main
2	doc_491521502102_item	2591447	et	2	main
о	doc_491521502102_item	2591449	et	2	main
положении	doc_491521502102_item	2591451	et	2	main
суммы	doc_491521502102_item	2591456	et	2	main
вас	doc_491521502102_item	2591461	et	2	main
работу	doc_491521502102_item	2591466	et	2	main
работодателем	doc_491521502102_item	2591472	et	2	main
сообщали	doc_491521502102_item	2591480	et	2	main
eesmärgi	doc_491521502102_item	2591484	et	4	main
ajaga	doc_491521502102_item	2591486	et	3	main
ei	doc_491521502102_item	2591488	et	4	main
võtta	doc_491521502102_item	2591489	et	3	main
järgi	doc_491521502102_item	2591494	et	4	main
kui	doc_491521502102_item	2591499	et	3	main
minu	doc_491521502102_item	2591500	et	3	main
minu	doc_491521502102_item	2591502	et	3	main
õde	doc_491521502102_item	2591501	et	4	main
õde	doc_491521502102_item	2591503	et	4	main
on	doc_491521502102_item	2591504	et	4	main
noorem	doc_491521502102_item	2591505	et	4	main
kui	doc_491521502102_item	2591506	et	3	main
mina	doc_491521502102_item	2591507	et	4	main
1	doc_491521502102_item	2591508	et	2	main
poeg	doc_491521502102_item	2591509	et	3	main
on	doc_491521502102_item	2591510	et	4	main
pikem	doc_491521502102_item	2591511	et	4	main
kui	doc_491521502102_item	2591512	et	3	main
isa	doc_491521502102_item	2591513	et	4	main
isa	doc_491521502102_item	2591514	et	4	main
on	doc_491521502102_item	2591515	et	4	main
lühem	doc_491521502102_item	2591516	et	4	main
kui	doc_491521502102_item	2591517	et	3	main
poeg	doc_491521502102_item	2591518	et	3	main
2	doc_491521502102_item	2591519	et	2	main
tallinn	doc_491521502102_item	2591520	et	4	main
on	doc_491521502102_item	2591526	et	4	main
õpilane	doc_491521502102_item	2591541	et	3	main
on	doc_491521502102_item	2591556	et	4	main
raskem	doc_491521502102_item	2591557	et	4	main
hommikul	doc_491521502102_item	2591587	et	3	main
eksami	doc_491521502102_item	2591591	et	3	main
sugulased	doc_491521502102_item	2591597	et	3	main
kunstnik	doc_491521502102_item	2591613	et	3	main
teatrisse	doc_491521502102_item	2591624	et	3	main
kolm	doc_491521502102_item	2591632	et	3	main
ilma	doc_491521502102_item	2591653	et	4	main
klassi	doc_491521502102_item	2591659	et	4	main
uued	doc_491521502102_item	2591660	et	3	main
või	doc_491521502102_item	2591669	et	4	main
omastavasse	doc_491521502102_item	2591670	et	4	main
lennujaama	doc_491521502102_item	2591678	et	4	main
kohanemine	doc_491521502102_item	2591691	et	4	main
saab	doc_491521502102_item	2591696	et	3	main
nuga	doc_491521502102_item	2591699	et	4	main
heino	doc_491521502102_item	2591531	et	4	main
on	doc_491521502102_item	2591538	et	4	main
heino	doc_491521502102_item	2591542	et	4	main
keele	doc_491521502102_item	2591551	et	4	main
meie	doc_491521502102_item	2591563	et	4	main
tänav	doc_491521502102_item	2591564	et	4	main
on	doc_491521502102_item	2591565	et	4	main
puhtam	doc_491521502102_item	2591566	et	4	main
kui	doc_491521502102_item	2591567	et	3	main
sõle	doc_491521502102_item	2591568	et	3	main
tänav	doc_491521502102_item	2591569	et	4	main
sõle	doc_491521502102_item	2591570	et	3	main
tänav	doc_491521502102_item	2591571	et	4	main
on	doc_491521502102_item	2591572	et	4	main
paksem	doc_491521502102_item	2591573	et	4	main
kui	doc_491521502102_item	2591574	et	3	main
meie	doc_491521502102_item	2591575	et	4	main
tänav	doc_491521502102_item	2591576	et	4	main
valige	doc_491521502102_item	2591577	et	3	main
õige	doc_491521502102_item	2591578	et	4	main
kääne	doc_491521502102_item	2591579	et	3	main
ning	doc_491521502102_item	2591580	et	3	main
vajadusel	doc_491521502102_item	2591581	et	3	main
ka	doc_491521502102_item	2591582	et	3	main
tagasõna	doc_491521502102_item	2591583	et	4	main
tahan	doc_491521502102_item	2591584	et	3	main
teist	doc_491521502102_item	2591589	et	4	main
täna	doc_491521502102_item	2591594	et	4	main
sugulaselt	doc_491521502102_item	2591598	et	3	main
puhanud	doc_491521502102_item	2591611	et	4	main
mäed	doc_491521502102_item	2591612	et	3	main
palju	doc_491521502102_item	2591616	et	4	main
isa	doc_491521502102_item	2591618	et	4	main
ostis	doc_491521502102_item	2591619	et	4	main
piletid	doc_491521502102_item	2591622	et	3	main
kolmas	doc_491521502102_item	2591633	et	3	main
autosse	doc_491521502102_item	2591637	et	4	main
kuus	doc_491521502102_item	2591639	et	4	main
keeles	doc_491521502102_item	2591650	et	4	main
viga	doc_491521502102_item	2591655	et	4	main
õpetaja	doc_491521502102_item	2591656	et	4	main
tuli	doc_491521502102_item	2591657	et	4	main
klass	doc_491521502102_item	2591658	et	3	main
õpilastega	doc_491521502102_item	2591663	et	4	main
pange	doc_491521502102_item	2591664	et	4	main
olevad	doc_491521502102_item	2591666	et	4	main
vene	doc_491521502102_item	2591674	et	4	main
kohvrid	doc_491521502102_item	2591680	et	3	main
eelistavad	doc_491521502102_item	2591683	et	4	main
rong	doc_491521502102_item	2591685	et	3	main
3	doc_491521502102_item	2591688	et	2	main
palav	doc_491521502102_item	2591689	et	4	main
aega	doc_491521502102_item	2591693	et	4	main
jutustuse	doc_491521502102_item	2591709	et	4	main
on	doc_491521502102_item	2591711	et	4	main
1	doc_491521502102_item	2591724	et	2	main
saabusid	doc_491521502102_item	2591726	et	4	main
2	doc_491521502102_item	2591730	et	2	main
palava	doc_491521502102_item	2591738	et	4	main
nõuab	doc_491521502102_item	2591741	et	3	main
nii	doc_491521502102_item	2591752	et	3	main
eduard	doc_491521502102_item	2591756	et	4	main
jutustuse	doc_491521502102_item	2591758	et	4	main
pealkiri	doc_491521502102_item	2591759	et	3	main
on	doc_491521502102_item	2591760	et	4	main
7	doc_491521502102_item	2591764	et	2	main
kui	doc_491521502102_item	2591771	et	3	main
võid	doc_491521502102_item	2591785	et	4	main
ta	doc_491521502102_item	2591789	et	4	main
eesti	doc_491521502102_item	2591832	et	4	main
keelde	doc_491521502102_item	2591833	et	4	main
1здесь	doc_491521502102_item	2591834	et	2	main
нет	doc_491521502102_item	2591835	et	2	main
бытовых	doc_491521502102_item	2591836	et	2	main
удобств	doc_491521502102_item	2591837	et	2	main
2	doc_491521502102_item	2591838	et	2	main
подробное	doc_491521502102_item	2591839	et	2	main
времени	doc_491521502102_item	2591844	et	2	main
у	doc_491521502102_item	2591849	et	2	main
достижения	doc_491521502102_item	2591854	et	2	main
будут	doc_491521502102_item	2591858	et	2	main
умения	doc_491521502102_item	2591864	et	2	main
требует	doc_491521502102_item	2591869	et	2	main
7inimesed	doc_491521502102_item	2591904	et	3	main
время	doc_491521502102_item	2591916	et	2	main
рано	doc_491521502102_item	2591921	et	2	main
всю	doc_491521502102_item	2591926	et	2	main
мы	doc_491521502102_item	2591929	et	2	main
у	doc_491521502102_item	2591936	et	2	main
я	doc_491521502102_item	2591942	et	2	main
мы	doc_491521502102_item	2591947	et	2	main
совете	doc_491521502102_item	2591951	et	2	main
самым	doc_491521502102_item	2591956	et	2	main
он	doc_491521502102_item	2591960	et	2	main
ясность	doc_491521502102_item	2591965	et	2	main
ei	doc_491521502102_item	2591976	et	4	main
taha	doc_491521502102_item	2591977	et	4	main
sõnad	doc_491521502103_item	2591983	et	4	main
vastavatesse	doc_491521502103_item	2591984	et	4	main
tõlkige	doc_491521502103_item	2591986	et	3	main
juba	doc_491521502103_item	2591996	et	3	main
kurbus	doc_491521502103_item	2592021	et	4	main
kauplus	doc_491521502103_item	2592028	et	3	main
külastajatele	doc_491521502103_item	2592033	et	4	main
avatud	doc_491521502103_item	2592034	et	4	main
alates	doc_491521502103_item	2592035	et	3	main
lapsed	doc_491521502102_item	2591625	et	3	main
tulevad	doc_491521502102_item	2591626	et	4	main
selle	doc_491521502102_item	2591636	et	4	main
itaalia	doc_491521502102_item	2591645	et	4	main
keel	doc_491521502102_item	2591646	et	4	main
vene	doc_491521502102_item	2591647	et	4	main
keel	doc_491521502102_item	2591648	et	4	main
itaalia	doc_491521502102_item	2591649	et	4	main
vene	doc_491521502102_item	2591651	et	4	main
keeles	doc_491521502102_item	2591652	et	4	main
sõnad	doc_491521502102_item	2591667	et	4	main
kaasaütlevasse	doc_491521502102_item	2591668	et	3	main
keelde	doc_491521502102_item	2591675	et	4	main
1turistid	doc_491521502102_item	2591676	et	3	main
2	doc_491521502102_item	2591681	et	2	main
reisida	doc_491521502102_item	2591684	et	3	main
nõuab	doc_491521502102_item	2591692	et	3	main
lõigata	doc_491521502102_item	2591697	et	4	main
istuge	doc_491521502102_item	2591702	et	3	main
hapud	doc_491521502102_item	2591704	et	3	main
6	doc_491521502102_item	2591706	et	2	main
turistid	doc_491521502102_item	2591725	et	3	main
lennujaama	doc_491521502102_item	2591727	et	4	main
suuri	doc_491521502102_item	2591728	et	3	main
paljud	doc_491521502102_item	2591731	et	3	main
rongi	doc_491521502102_item	2591734	et	4	main
nugaga	doc_491521502102_item	2591748	et	4	main
5	doc_491521502102_item	2591749	et	2	main
ärge	doc_491521502102_item	2591750	et	3	main
6	doc_491521502102_item	2591755	et	2	main
soome	doc_491521502102_item	2591765	et	3	main
laeva	doc_491521502102_item	2591770	et	4	main
ta	doc_491521502102_item	2591773	et	4	main
rääkima	doc_491521502102_item	2591784	et	3	main
käändesse	doc_491521502102_item	2591671	et	4	main
tõlkige	doc_491521502102_item	2591672	et	3	main
laused	doc_491521502102_item	2591673	et	3	main
suured	doc_491521502102_item	2591679	et	3	main
või	doc_491521502102_item	2591686	et	4	main
buss	doc_491521502102_item	2591687	et	3	main
oksi	doc_491521502102_item	2591695	et	4	main
pealkiri	doc_491521502102_item	2591710	et	3	main
laev	doc_491521502102_item	2591721	et	3	main
kohviga	doc_491521502102_item	2591729	et	3	main
eelistavad	doc_491521502102_item	2591732	et	4	main
reisida	doc_491521502102_item	2591733	et	3	main
kliimaga	doc_491521502102_item	2591739	et	3	main
ituge	doc_491521502102_item	2591751	et	4	main
vilde	doc_491521502102_item	2591757	et	4	main
mees	doc_491521502102_item	2591763	et	4	main
minna	doc_491521502102_item	2591768	et	3	main
lennukiga	doc_491521502102_item	2591772	et	3	main
tavaliselt	doc_491521502102_item	2591774	et	4	main
pidama	doc_491521502102_item	2591775	et	4	main
lahkuma	doc_491521502102_item	2591776	et	3	main
rääkida	doc_491521502102_item	2591786	et	3	main
võõrkeelt	doc_491521502102_item	2591788	et	4	main
ma	doc_491521502102_item	2591823	et	3	main
õpetada	doc_491521502102_item	2591827	et	3	main
välismaalastele	doc_491521502102_item	2591829	et	4	main
tõlkige	doc_491521502102_item	2591830	et	3	main
laused	doc_491521502102_item	2591831	et	3	main
удобств	doc_491521502102_item	2591842	et	2	main
году	doc_491521502102_item	2591848	et	2	main
три	doc_491521502102_item	2591852	et	2	main
достижения	doc_491521502102_item	2591857	et	2	main
у	doc_491521502102_item	2591861	et	2	main
эта	doc_491521502102_item	2591867	et	2	main
умений	doc_491521502102_item	2591872	et	2	main
või	doc_491521502102_item	2591911	et	4	main
день	doc_491521502102_item	2591919	et	2	main
продолжалось	doc_491521502102_item	2591925	et	2	main
3	doc_491521502102_item	2591928	et	2	main
4	doc_491521502102_item	2591934	et	2	main
5	doc_491521502102_item	2591939	et	2	main
не	doc_491521502102_item	2591943	et	2	main
постоянно	doc_491521502102_item	2591948	et	2	main
спокойное	doc_491521502102_item	2591953	et	2	main
решением	doc_491521502102_item	2591958	et	2	main
дело	doc_491521502102_item	2591964	et	2	main
elu	doc_491521502102_item	2591969	et	4	main
mis	doc_491521502102_item	2591970	et	4	main
õppida	doc_491521502102_item	2591978	et	3	main
kolime	doc_491521502103_item	2591989	et	3	main
maja	doc_491521502103_item	2591995	et	4	main
vabaneda	doc_491521502103_item	2592022	et	3	main
avatakse	doc_491521502103_item	2592029	et	4	main
tehtud	doc_491521502103_item	2592040	et	4	main
nüüd	doc_491521502103_item	2592054	et	4	main
vajalikku	doc_491521502103_item	2592062	et	4	main
majasse	doc_491521502103_item	2592068	et	3	main
sügava	doc_491521502103_item	2592071	et	4	main
seinas	doc_491521502103_item	2592079	et	3	main
majapidamistarvetesse	doc_491521502103_item	2592083	et	4	main
mind	doc_491521502103_item	2592097	et	4	main
majandusjuhataja	doc_491521502103_item	2592101	et	4	main
et	doc_491521502103_item	2592105	et	3	main
eest	doc_491521502103_item	2592113	et	4	main
3	doc_491521502103_item	2592114	et	2	main
4	doc_491521502102_item	2591694	et	2	main
terav	doc_491521502102_item	2591698	et	3	main
5	doc_491521502102_item	2591700	et	2	main
ärge	doc_491521502102_item	2591701	et	3	main
must	doc_491521502102_item	2591712	et	4	main
mantel	doc_491521502102_item	2591713	et	3	main
mees	doc_491521502102_item	2591714	et	4	main
7	doc_491521502102_item	2591715	et	2	main
soome	doc_491521502102_item	2591716	et	3	main
on	doc_491521502102_item	2591717	et	4	main
võimalik	doc_491521502102_item	2591718	et	3	main
minna	doc_491521502102_item	2591719	et	3	main
nii	doc_491521502102_item	2591720	et	3	main
nii	doc_491521502102_item	2591703	et	3	main
näod	doc_491521502102_item	2591705	et	3	main
eduard	doc_491521502102_item	2591707	et	4	main
vilde	doc_491521502102_item	2591708	et	4	main
kui	doc_491521502102_item	2591722	et	3	main
lennuk	doc_491521502102_item	2591723	et	3	main
bussiga	doc_491521502102_item	2591736	et	3	main
kohanemine	doc_491521502102_item	2591740	et	4	main
aega	doc_491521502102_item	2591742	et	4	main
oksi	doc_491521502102_item	2591744	et	4	main
hapude	doc_491521502102_item	2591753	et	3	main
musta	doc_491521502102_item	2591761	et	4	main
on	doc_491521502102_item	2591766	et	4	main
nii	doc_491521502102_item	2591769	et	3	main
pidab	doc_491521502102_item	2591777	et	4	main
lahkuma	doc_491521502102_item	2591778	et	3	main
viis	doc_491521502102_item	2591780	et	4	main
tüdrukud	doc_491521502102_item	2591782	et	3	main
kolme	doc_491521502102_item	2591787	et	4	main
tallinnas	doc_491521502102_item	2591822	et	4	main
õpetama	doc_491521502102_item	2591825	et	3	main
võõrkeelt	doc_491521502102_item	2591828	et	4	main
требует	doc_491521502102_item	2591843	et	2	main
3	doc_491521502102_item	2591845	et	2	main
меня	doc_491521502102_item	2591850	et	2	main
4	doc_491521502102_item	2591855	et	2	main
завтра	doc_491521502102_item	2591859	et	2	main
нет	doc_491521502102_item	2591863	et	2	main
общаться	doc_491521502102_item	2591865	et	2	main
много	doc_491521502102_item	2591870	et	2	main
oled	doc_491521502102_item	2591902	et	3	main
täismineviku	doc_491521502102_item	2591912	et	3	main
abil	doc_491521502102_item	2591913	et	4	main
1в	doc_491521502102_item	2591914	et	2	main
то	doc_491521502102_item	2591915	et	2	main
начинался	doc_491521502102_item	2591920	et	2	main
утром	doc_491521502102_item	2591922	et	2	main
жизнь	doc_491521502102_item	2591927	et	2	main
оказываем	doc_491521502102_item	2591932	et	2	main
что	doc_491521502102_item	2591935	et	2	main
что	doc_491521502102_item	2591941	et	2	main
хотел	doc_491521502102_item	2591944	et	2	main
нуждались	doc_491521502102_item	2591949	et	2	main
бывало	doc_491521502102_item	2591955	et	2	main
всегда	doc_491521502102_item	2591961	et	2	main
õpetamine	doc_491521502102_item	2591966	et	4	main
kogu	doc_491521502102_item	2591968	et	4	main
teie	doc_491521502102_item	2591971	et	4	main
juhtus	doc_491521502102_item	2591972	et	3	main
juhtus	doc_491521502102_item	2591973	et	3	main
et	doc_491521502102_item	2591974	et	3	main
ma	doc_491521502102_item	2591975	et	3	main
sulgudes	doc_491521502103_item	2591981	et	4	main
laused	doc_491521502103_item	2591987	et	3	main
maja	doc_491521502103_item	2591991	et	4	main
elame	doc_491521502103_item	2591993	et	3	main
või	doc_491521502102_item	2591735	et	4	main
3	doc_491521502102_item	2591737	et	2	main
4	doc_491521502102_item	2591743	et	2	main
saab	doc_491521502102_item	2591745	et	3	main
lõigata	doc_491521502102_item	2591746	et	4	main
terava	doc_491521502102_item	2591747	et	3	main
näoga	doc_491521502102_item	2591754	et	3	main
manteliga	doc_491521502102_item	2591762	et	4	main
võimalik	doc_491521502102_item	2591767	et	3	main
kell	doc_491521502102_item	2591779	et	3	main
need	doc_491521502102_item	2591781	et	3	main
võima	doc_491521502102_item	2591783	et	3	main
ei	doc_491521502102_item	2591790	et	4	main
tahtma	doc_491521502102_item	2591791	et	3	main
suitsetama	doc_491521502102_item	2591792	et	4	main
taha	doc_491521502102_item	2591793	et	4	main
suitsetada	doc_491521502102_item	2591794	et	3	main
palju	doc_491521502102_item	2591795	et	4	main
te	doc_491521502102_item	2591796	et	4	main
hakkama	doc_491521502102_item	2591797	et	3	main
kirjutama	doc_491521502102_item	2591798	et	3	main
hakkate	doc_491521502102_item	2591799	et	3	main
kirjutama	doc_491521502102_item	2591800	et	3	main
harjutust	doc_491521502102_item	2591801	et	4	main
talle	doc_491521502102_item	2591802	et	4	main
meeldima	doc_491521502102_item	2591803	et	3	main
töötama	doc_491521502102_item	2591804	et	3	main
meeldib	doc_491521502102_item	2591805	et	3	main
töötada	doc_491521502102_item	2591806	et	3	main
selles	doc_491521502102_item	2591807	et	4	main
ettevõttes	doc_491521502102_item	2591808	et	3	main
ma	doc_491521502102_item	2591809	et	3	main
tahtma	doc_491521502102_item	2591810	et	3	main
kirjutama	doc_491521502102_item	2591811	et	3	main
tahan	doc_491521502102_item	2591812	et	3	main
kirjutada	doc_491521502102_item	2591813	et	3	main
kirja	doc_491521502102_item	2591814	et	4	main
oma	doc_491521502102_item	2591815	et	4	main
tuttavatele	doc_491521502102_item	2591816	et	3	main
me	doc_491521502102_item	2591817	et	4	main
hakkama	doc_491521502102_item	2591818	et	3	main
hakkame	doc_491521502102_item	2591820	et	3	main
elama	doc_491521502102_item	2591819	et	3	main
elama	doc_491521502102_item	2591821	et	3	main
oskama	doc_491521502102_item	2591824	et	3	main
oskan	doc_491521502102_item	2591826	et	3	main
описание	doc_491521502102_item	2591840	et	2	main
в	doc_491521502102_item	2591846	et	2	main
было	doc_491521502102_item	2591851	et	2	main
большие	doc_491521502102_item	2591856	et	2	main
бытовых	doc_491521502102_item	2591841	et	2	main
этом	doc_491521502102_item	2591847	et	2	main
больших	doc_491521502102_item	2591853	et	2	main
вас	doc_491521502102_item	2591862	et	2	main
6	doc_491521502102_item	2591866	et	2	main
разных	doc_491521502102_item	2591871	et	2	main
люди	doc_491521502102_item	2591874	et	2	main
отдыхают	doc_491521502102_item	2591875	et	2	main
8	doc_491521502102_item	2591876	et	2	main
лица	doc_491521502102_item	2591877	et	2	main
людей	doc_491521502102_item	2591878	et	2	main
были	doc_491521502102_item	2591879	et	2	main
довольно	doc_491521502102_item	2591880	et	2	main
простые	doc_491521502102_item	2591881	et	2	main
9	doc_491521502102_item	2591882	et	2	main
глаза	doc_491521502102_item	2591883	et	2	main
этого	doc_491521502102_item	2591884	et	2	main
человека	doc_491521502102_item	2591885	et	2	main
очень	doc_491521502102_item	2591886	et	2	main
робкие	doc_491521502102_item	2591887	et	2	main
изменение	doc_491521502102_item	2591889	et	2	main
10	doc_491521502102_item	2591888	et	2	main
проходит	doc_491521502102_item	2591891	et	2	main
самооценки	doc_491521502102_item	2591890	et	2	main
3sellel	doc_491521502102_item	2591893	et	4	main
тяжело	doc_491521502102_item	2591892	et	2	main
ajal	doc_491521502102_item	2591894	et	4	main
mul	doc_491521502102_item	2591895	et	3	main
kolm	doc_491521502102_item	2591897	et	3	main
oli	doc_491521502102_item	2591896	et	3	main
suured	doc_491521502102_item	2591898	et	3	main
saavutus	doc_491521502102_item	2591899	et	4	main
4suured	doc_491521502102_item	2591900	et	3	main
5	doc_491521502102_item	2591860	et	2	main
работа	doc_491521502102_item	2591868	et	2	main
7	doc_491521502102_item	2591873	et	2	main
каждый	doc_491521502102_item	2591917	et	2	main
saavutus	doc_491521502102_item	2591901	et	4	main
homme	doc_491521502102_item	2591903	et	3	main
puhkavad	doc_491521502102_item	2591905	et	4	main
tõlkige	doc_491521502102_item	2591906	et	3	main
eesti	doc_491521502102_item	2591907	et	4	main
keelde	doc_491521502102_item	2591908	et	4	main
kas	doc_491521502102_item	2591909	et	3	main
liht-	doc_491521502102_item	2591910	et	3	main
рабочий	doc_491521502102_item	2591918	et	2	main
обучение	doc_491521502102_item	2591924	et	2	main
никогда	doc_491521502102_item	2591930	et	2	main
давления	doc_491521502102_item	2591933	et	2	main
вас	doc_491521502102_item	2591937	et	2	main
случалось	doc_491521502102_item	2591940	et	2	main
учиться	doc_491521502102_item	2591945	et	2	main
в	doc_491521502102_item	2591950	et	2	main
обсуждение	doc_491521502102_item	2591954	et	2	main
8	doc_491521502102_item	2591959	et	2	main
вносил	doc_491521502102_item	2591962	et	2	main
olevad	doc_491521502103_item	2591982	et	4	main
1homme	doc_491521502103_item	2591988	et	3	main
uus	doc_491521502103_item	2591990	et	3	main
uus	doc_491521502103_item	2591994	et	3	main
kaupluse	doc_491521502103_item	2592024	et	3	main
oktoober	doc_491521502103_item	2592027	et	3	main
kauplus	doc_491521502103_item	2592031	et	3	main
auk	doc_491521502103_item	2592041	et	3	main
majas	doc_491521502103_item	2592067	et	3	main
oktoobris	doc_491521502103_item	2592077	et	3	main
osakonnas	doc_491521502103_item	2592086	et	4	main
valige	doc_491521502103_item	2592087	et	3	main
talvel	doc_491521502103_item	2592095	et	4	main
teatas	doc_491521502103_item	2592104	et	3	main
remondi	doc_491521502103_item	2592112	et	4	main
keele	doc_491521502103_item	2592128	et	4	main
saatuse	doc_491521502103_item	2592129	et	3	main
pärast	doc_491521502103_item	2592130	et	4	main
eesti	doc_491521502103_item	2592134	et	4	main
jagunenud	doc_491521502103_item	2592135	et	4	main
oma	doc_491521502103_item	2592148	et	4	main
esindajad	doc_491521502103_item	2592150	et	4	main
sulgudes	doc_491521502103_item	2592154	et	4	main
sõnad	doc_491521502103_item	2592156	et	4	main
ilmaütlevasse	doc_491521502103_item	2592157	et	3	main
või	doc_491521502103_item	2592158	et	4	main
1ilma	doc_491521502103_item	2592165	et	4	main
pass	doc_491521502103_item	2592166	et	3	main
2	doc_491521502103_item	2592172	et	2	main
nägu	doc_491521502103_item	2592174	et	4	main
reisijad	doc_491521502103_item	2592178	et	4	main
vaatamisväärsused	doc_491521502103_item	2592200	et	4	main
ole	doc_491521502103_item	2592206	et	4	main
hilinemine	doc_491521502103_item	2592214	et	4	main
ei	doc_491521502103_item	2592243	et	4	main
vaid	doc_491521502103_item	2592262	et	3	main
minnes	doc_491521502103_item	2592277	et	3	main
puu	doc_491521502103_item	2592280	et	4	main
1	doc_491521502103_item	2592283	et	2	main
venelased	doc_491521502103_item	2592284	et	3	main
moodustavad	doc_491521502103_item	2592285	et	4	main
suurimat	doc_491521502103_item	2592293	et	3	main
2	doc_491521502103_item	2592296	et	2	main
keetmata	doc_491521502103_item	2592304	et	4	main
vett	doc_491521502103_item	2592305	et	3	main
ja	doc_491521502103_item	2592306	et	3	main
olla	doc_491521502103_item	2592308	et	3	main
võrrelda	doc_491521502103_item	2592313	et	4	main
asustusega	doc_491521502103_item	2592318	et	4	main
2	doc_491521502102_item	2591923	et	2	main
не	doc_491521502102_item	2591931	et	2	main
случилось	doc_491521502102_item	2591938	et	2	main
6	doc_491521502102_item	2591946	et	2	main
7	doc_491521502102_item	2591952	et	2	main
разумным	doc_491521502102_item	2591957	et	2	main
в	doc_491521502102_item	2591963	et	2	main
tuleb	doc_491521502102_item	2591967	et	3	main
kontrolltöö	doc_491521502103_item	2591979	et	4	main
pange	doc_491521502103_item	2591980	et	4	main
sisekohakäänetesse	doc_491521502103_item	2591985	et	3	main
me	doc_491521502103_item	2591992	et	4	main
pool	doc_491521502103_item	2591997	et	4	main
aastat	doc_491521502103_item	2591998	et	3	main
kohale	doc_491521502103_item	2591999	et	4	main
jõudes	doc_491521502103_item	2592000	et	3	main
helista	doc_491521502103_item	2592001	et	4	main
tulen	doc_491521502103_item	2592002	et	3	main
maja	doc_491521502103_item	2592003	et	4	main
välja	doc_491521502103_item	2592004	et	4	main
sulle	doc_491521502103_item	2592005	et	3	main
vastu	doc_491521502103_item	2592006	et	3	main
2	doc_491521502103_item	2592007	et	2	main
langesin	doc_491521502103_item	2592008	et	3	main
sinu	doc_491521502103_item	2592009	et	3	main
pärast	doc_491521502103_item	2592010	et	4	main
kurbus	doc_491521502103_item	2592011	et	4	main
juba	doc_491521502103_item	2592012	et	3	main
mitmendat	doc_491521502103_item	2592013	et	3	main
nädalat	doc_491521502103_item	2592014	et	3	main
viibin	doc_491521502103_item	2592015	et	3	main
sügav	doc_491521502103_item	2592016	et	4	main
kurbus	doc_491521502103_item	2592017	et	4	main
loodan	doc_491521502103_item	2592018	et	3	main
peagi	doc_491521502103_item	2592019	et	4	main
oma	doc_491521502103_item	2592020	et	4	main
avamine	doc_491521502103_item	2592025	et	4	main
oktoober	doc_491521502103_item	2592030	et	3	main
on	doc_491521502103_item	2592032	et	4	main
sein	doc_491521502103_item	2592042	et	3	main
auk	doc_491521502103_item	2592045	et	3	main
ainult	doc_491521502103_item	2592050	et	4	main
kivid	doc_491521502103_item	2592051	et	3	main
5	doc_491521502103_item	2592052	et	2	main
läheme	doc_491521502103_item	2592053	et	3	main
alati	doc_491521502103_item	2592060	et	4	main
uuesse	doc_491521502103_item	2592064	et	3	main
uues	doc_491521502103_item	2592066	et	3	main
4	doc_491521502103_item	2592078	et	2	main
seinasse	doc_491521502103_item	2592081	et	3	main
osakonnadesse	doc_491521502103_item	2592084	et	3	main
1möödunud	doc_491521502103_item	2592094	et	4	main
ajutiselt	doc_491521502103_item	2592098	et	4	main
kutsekooli	doc_491521502103_item	2592100	et	4	main
2	doc_491521502103_item	2592102	et	2	main
direktor	doc_491521502103_item	2592103	et	3	main
majandusjuhataja	doc_491521502103_item	2592106	et	4	main
3	doc_491521502103_item	2592023	et	2	main
lükkub	doc_491521502103_item	2592026	et	3	main
sügav	doc_491521502103_item	2592044	et	4	main
sein	doc_491521502103_item	2592046	et	3	main
on	doc_491521502103_item	2592047	et	4	main
järele	doc_491521502103_item	2592048	et	4	main
oktoober	doc_491521502103_item	2592036	et	3	main
4	doc_491521502103_item	2592037	et	2	main
sein	doc_491521502103_item	2592038	et	3	main
on	doc_491521502103_item	2592039	et	4	main
on	doc_491521502103_item	2592043	et	4	main
majapidamistarvete	doc_491521502103_item	2592055	et	4	main
osakond	doc_491521502103_item	2592056	et	3	main
midagi	doc_491521502103_item	2592061	et	4	main
kurbusse	doc_491521502103_item	2592070	et	4	main
3	doc_491521502103_item	2592074	et	2	main
oktoobrisse	doc_491521502103_item	2592075	et	3	main
seinas	doc_491521502103_item	2592080	et	3	main
majapidamistarvetes	doc_491521502103_item	2592085	et	4	main
õige	doc_491521502103_item	2592088	et	4	main
kääne	doc_491521502103_item	2592089	et	3	main
kas	doc_491521502103_item	2592090	et	3	main
saav	doc_491521502103_item	2592091	et	4	main
kutsuti	doc_491521502103_item	2592096	et	3	main
õige	doc_491521502103_item	2592109	et	4	main
tähtaeg	doc_491521502103_item	2592110	et	3	main
valminud	doc_491521502103_item	2592111	et	4	main
inimene	doc_491521502103_item	2592116	et	3	main
väikese	doc_491521502103_item	2592123	et	4	main
muretsevad	doc_491521502103_item	2592125	et	4	main
eestlased	doc_491521502103_item	2592126	et	3	main
ajalooliselt	doc_491521502103_item	2592132	et	4	main
erinevad	doc_491521502103_item	2592136	et	4	main
maakonnad	doc_491521502103_item	2592137	et	4	main
6	doc_491521502103_item	2592138	et	2	main
mõned	doc_491521502103_item	2592139	et	3	main
end	doc_491521502103_item	2592146	et	4	main
majandusjuhatajana	doc_491521502103_item	2592152	et	3	main
tõlkige	doc_491521502103_item	2592161	et	3	main
laused	doc_491521502103_item	2592162	et	3	main
ületada	doc_491521502103_item	2592171	et	3	main
poisi	doc_491521502103_item	2592173	et	3	main
oli	doc_491521502103_item	2592175	et	3	main
3	doc_491521502103_item	2592177	et	2	main
suhtusid	doc_491521502103_item	2592179	et	4	main
giidi	doc_491521502103_item	2592180	et	4	main
ettepanekusse	doc_491521502103_item	2592181	et	3	main
all	doc_491521502103_item	2592187	et	3	main
ärge	doc_491521502103_item	2592193	et	3	main
ilma	doc_491521502103_item	2592198	et	4	main
vormistada	doc_491521502103_item	2592209	et	3	main
saabus	doc_491521502103_item	2592212	et	3	main
2	doc_491521502103_item	2592217	et	2	main
4	doc_491521502103_item	2592222	et	2	main
5	doc_491521502103_item	2592225	et	2	main
hilinemisega	doc_491521502103_item	2592226	et	4	main
nii	doc_491521502103_item	2592229	et	3	main
tegusõnast	doc_491521502103_item	2592232	et	4	main
saaks	doc_491521502103_item	2592233	et	3	main
des-vorm	doc_491521502103_item	2592234	et	3	main
keelde	doc_491521502103_item	2592238	et	4	main
ja	doc_491521502103_item	2592247	et	3	main
ole	doc_491521502103_item	2592256	et	4	main
karin	doc_491521502103_item	2592279	et	4	main
otsas	doc_491521502103_item	2592281	et	4	main
oravat	doc_491521502103_item	2592282	et	3	main
kolmandiku	doc_491521502103_item	2592290	et	3	main
kohalikku	doc_491521502103_item	2592294	et	4	main
olime	doc_491521502103_item	2592300	et	3	main
tarvitanud	doc_491521502103_item	2592302	et	4	main
võimalikult	doc_491521502103_item	2592309	et	4	main
kui	doc_491521502103_item	2592312	et	3	main
eesti	doc_491521502103_item	2592316	et	4	main
maa	doc_491521502103_item	2592319	et	4	main
6	doc_491521502103_item	2592340	et	2	main
väsimuse	doc_491521502103_item	2592344	et	4	main
tegumoe	doc_491521502103_item	2592352	et	3	main
abil	doc_491521502103_item	2592353	et	4	main
vajaduse	doc_491521502103_item	2592354	et	3	main
1цели	doc_491521502103_item	2592359	et	2	main
семейном	doc_491521502103_item	2592366	et	2	main
обсуждение	doc_491521502103_item	2592371	et	2	main
вас	doc_491521502103_item	2592377	et	2	main
работу	doc_491521502103_item	2592382	et	2	main
беседы	doc_491521502103_item	2592386	et	2	main
условиях	doc_491521502103_item	2592391	et	2	main
не	doc_491521502103_item	2592395	et	2	main
jäänud	doc_491521502103_item	2592049	et	4	main
majapidamistarvete	doc_491521502103_item	2592057	et	4	main
osakond	doc_491521502103_item	2592058	et	3	main
leidub	doc_491521502103_item	2592059	et	3	main
1	doc_491521502103_item	2592063	et	2	main
majja	doc_491521502103_item	2592065	et	3	main
2	doc_491521502103_item	2592069	et	2	main
kurbuses	doc_491521502103_item	2592072	et	4	main
kurbus	doc_491521502103_item	2592073	et	4	main
oktoobris	doc_491521502103_item	2592076	et	3	main
5	doc_491521502103_item	2592082	et	2	main
või	doc_491521502103_item	2592092	et	4	main
olev	doc_491521502103_item	2592093	et	4	main
sellesse	doc_491521502103_item	2592099	et	4	main
haritud	doc_491521502103_item	2592115	et	4	main
töökust	doc_491521502103_item	2592119	et	4	main
kannatlikust	doc_491521502103_item	2592121	et	4	main
rahvas	doc_491521502103_item	2592124	et	4	main
5	doc_491521502103_item	2592131	et	2	main
muutusid	doc_491521502103_item	2592142	et	4	main
baltisakslased	doc_491521502103_item	2592143	et	3	main
rahva	doc_491521502103_item	2592149	et	3	main
1	doc_491521502103_item	2592151	et	2	main
käändesse	doc_491521502103_item	2592160	et	4	main
vene	doc_491521502103_item	2592163	et	4	main
keelde	doc_491521502103_item	2592164	et	4	main
lubatud	doc_491521502103_item	2592169	et	4	main
ilma	doc_491521502103_item	2592182	et	4	main
suur	doc_491521502103_item	2592183	et	3	main
paks	doc_491521502103_item	2592189	et	3	main
et	doc_491521502103_item	2592195	et	3	main
möödub	doc_491521502103_item	2592197	et	3	main
igasugused	doc_491521502103_item	2592199	et	3	main
6	doc_491521502103_item	2592201	et	2	main
ilma	doc_491521502103_item	2592202	et	4	main
ametlik	doc_491521502103_item	2592203	et	3	main
võimalik	doc_491521502103_item	2592207	et	3	main
kohale	doc_491521502103_item	2592213	et	4	main
passi	doc_491521502103_item	2592216	et	4	main
huvid	doc_491521502103_item	2592221	et	3	main
vastutan	doc_491521502103_item	2592107	et	3	main
mina	doc_491521502103_item	2592108	et	4	main
kasvamine	doc_491521502103_item	2592117	et	4	main
nõuab	doc_491521502103_item	2592118	et	3	main
ja	doc_491521502103_item	2592120	et	3	main
oma	doc_491521502103_item	2592127	et	4	main
oli	doc_491521502103_item	2592133	et	3	main
teised	doc_491521502103_item	2592144	et	4	main
tundsid	doc_491521502103_item	2592145	et	4	main
pange	doc_491521502103_item	2592153	et	4	main
olevad	doc_491521502103_item	2592155	et	4	main
ole	doc_491521502103_item	2592168	et	4	main
pesema	doc_491521502103_item	2592176	et	3	main
istus	doc_491521502103_item	2592188	et	4	main
kass	doc_491521502103_item	2592191	et	3	main
uskuge	doc_491521502103_item	2592194	et	3	main
reis	doc_491521502103_item	2592196	et	4	main
ei	doc_491521502103_item	2592205	et	4	main
7	doc_491521502103_item	2592210	et	2	main
1	doc_491521502103_item	2592215	et	2	main
pesta	doc_491521502103_item	2592218	et	4	main
laused	doc_491521502103_item	2592236	et	3	main
ole	doc_491521502103_item	2592244	et	4	main
eriti	doc_491521502103_item	2592245	et	3	main
tugev	doc_491521502103_item	2592246	et	4	main
end	doc_491521502103_item	2592249	et	4	main
tunda	doc_491521502103_item	2592250	et	3	main
vaid	doc_491521502103_item	2592251	et	3	main
tööstuspiirkonnas	doc_491521502103_item	2592252	et	4	main
keskkonna	doc_491521502103_item	2592253	et	3	main
tugev	doc_491521502103_item	2592258	et	4	main
kooli	doc_491521502103_item	2592276	et	4	main
veidi	doc_491521502103_item	2592288	et	3	main
alla	doc_491521502103_item	2592289	et	3	main
esindavad	doc_491521502103_item	2592292	et	4	main
rahvusvähemust	doc_491521502103_item	2592295	et	4	main
kui	doc_491521502103_item	2592297	et	3	main
me	doc_491521502103_item	2592298	et	4	main
matkal	doc_491521502103_item	2592299	et	3	main
püüdsime	doc_491521502103_item	2592307	et	3	main
ka	doc_491521502103_item	2592338	et	3	main
keelde	doc_491521502103_item	2592350	et	4	main
kasutage	doc_491521502103_item	2592356	et	3	main
временем	doc_491521502103_item	2592362	et	2	main
положении	doc_491521502103_item	2592367	et	2	main
зарплаты	doc_491521502103_item	2592373	et	2	main
не	doc_491521502103_item	2592378	et	2	main
в	doc_491521502103_item	2592384	et	2	main
говорят	doc_491521502103_item	2592389	et	2	main
вчера	doc_491521502103_item	2592394	et	2	main
растет	doc_491521502103_item	2592399	et	2	main
näidis	doc_491521502103_item	2592403	et	4	main
kui	doc_491521502103_item	2592407	et	3	main
tallinn	doc_491521502103_item	2592428	et	4	main
heino	doc_491521502103_item	2592439	et	4	main
õpilane	doc_491521502103_item	2592442	et	3	main
kalle	doc_491521502103_item	2592444	et	3	main
on	doc_491521502103_item	2592446	et	4	main
eesti	doc_491521502103_item	2592458	et	4	main
kes	doc_491521502103_item	2592489	et	4	main
sooritas	doc_491521502103_item	2592491	et	3	main
eksami	doc_491521502103_item	2592492	et	3	main
viimane	doc_491521502103_item	2592493	et	3	main
riie	doc_491521502103_item	2592504	et	3	main
teatrisse	doc_491521502103_item	2592524	et	3	main
auto	doc_491521502103_item	2592535	et	4	main
teksti	doc_491521502103_item	2592544	et	4	main
vene	doc_491521502103_item	2592547	et	4	main
ilma	doc_491521502103_item	2592554	et	4	main
veod	doc_491521502103_item	2592556	et	3	main
lennujaama	doc_491521502103_item	2592582	et	4	main
terav	doc_491521502103_item	2592602	et	3	main
ärge	doc_491521502103_item	2592605	et	3	main
istuge	doc_491521502103_item	2592606	et	3	main
vilde	doc_491521502103_item	2592612	et	4	main
jutustuse	doc_491521502103_item	2592613	et	4	main
pealkiri	doc_491521502103_item	2592614	et	3	main
mees	doc_491521502103_item	2592618	et	4	main
on	doc_491521502103_item	2592621	et	4	main
7soome	doc_491521502103_item	2592628	et	3	main
minna	doc_491521502103_item	2592631	et	3	main
4	doc_491521502103_item	2592122	et	2	main
haritud	doc_491521502103_item	2592140	et	4	main
eestlased	doc_491521502103_item	2592141	et	3	main
endiselt	doc_491521502103_item	2592147	et	4	main
omastavasse	doc_491521502103_item	2592159	et	4	main
ei	doc_491521502103_item	2592167	et	4	main
piiri	doc_491521502103_item	2592170	et	4	main
huvi	doc_491521502103_item	2592184	et	4	main
4	doc_491521502103_item	2592185	et	2	main
puu	doc_491521502103_item	2592186	et	4	main
saba	doc_491521502103_item	2592190	et	4	main
5	doc_491521502103_item	2592192	et	2	main
taotlus	doc_491521502103_item	2592204	et	4	main
viisat	doc_491521502103_item	2592208	et	3	main
rong	doc_491521502103_item	2592211	et	3	main
3	doc_491521502103_item	2592219	et	2	main
suuri	doc_491521502103_item	2592220	et	3	main
taotluseta	doc_491521502103_item	2592224	et	4	main
et	doc_491521502103_item	2592230	et	3	main
viimasest	doc_491521502103_item	2592231	et	3	main
tõlkige	doc_491521502103_item	2592235	et	3	main
saastatus	doc_491521502103_item	2592254	et	4	main
eriti	doc_491521502103_item	2592257	et	3	main
andes	doc_491521502103_item	2592259	et	4	main
end	doc_491521502103_item	2592260	et	4	main
tunda	doc_491521502103_item	2592261	et	3	main
eesti	doc_491521502103_item	2592286	et	4	main
ei	doc_491521502103_item	2592301	et	4	main
3	doc_491521502103_item	2592311	et	2	main
hollandiga	doc_491521502103_item	2592314	et	4	main
on	doc_491521502103_item	2592315	et	4	main
läks	doc_491521502103_item	2592322	et	3	main
juurde	doc_491521502103_item	2592324	et	4	main
selle	doc_491521502103_item	2592327	et	4	main
abile	doc_491521502103_item	2592328	et	3	main
5	doc_491521502103_item	2592329	et	2	main
iga	doc_491521502103_item	2592330	et	4	main
taim	doc_491521502103_item	2592331	et	3	main
omab	doc_491521502103_item	2592332	et	3	main
teatavat	doc_491521502103_item	2592333	et	4	main
mõjuvõimu	doc_491521502103_item	2592334	et	4	main
ja	doc_491521502103_item	2592335	et	3	main
avaldab	doc_491521502103_item	2592336	et	3	main
kask	doc_491521502103_item	2592341	et	3	main
umbisikulise	doc_491521502103_item	2592351	et	4	main
õppesõnastikku	doc_491521502103_item	2592358	et	4	main
2	doc_491521502103_item	2592363	et	2	main
представляли	doc_491521502103_item	2592368	et	2	main
начинают	doc_491521502103_item	2592374	et	2	main
выбрали	doc_491521502103_item	2592379	et	2	main
5	doc_491521502103_item	2592383	et	2	main
об	doc_491521502103_item	2592390	et	2	main
что	doc_491521502103_item	2592397	et	2	main
vanem	doc_491521502103_item	2592406	et	4	main
minu	doc_491521502103_item	2592408	et	3	main
õde	doc_491521502103_item	2592411	et	4	main
on	doc_491521502103_item	2592412	et	4	main
isa	doc_491521502103_item	2592421	et	4	main
on	doc_491521502103_item	2592423	et	4	main
halvam	doc_491521502103_item	2592447	et	4	main
õpilane	doc_491521502103_item	2592448	et	3	main
kui	doc_491521502103_item	2592449	et	3	main
kalle	doc_491521502103_item	2592450	et	3	main
kergem	doc_491521502103_item	2592456	et	4	main
raskem	doc_491521502103_item	2592465	et	4	main
kui	doc_491521502103_item	2592466	et	3	main
eesti	doc_491521502103_item	2592467	et	4	main
keele	doc_491521502103_item	2592468	et	4	main
hommikul	doc_491521502103_item	2592488	et	3	main
sugulased	doc_491521502103_item	2592498	et	3	main
kleit	doc_491521502103_item	2592501	et	3	main
villane	doc_491521502103_item	2592503	et	4	main
ma	doc_491521502103_item	2592506	et	3	main
tööd	doc_491521502103_item	2592517	et	4	main
piletid	doc_491521502103_item	2592522	et	3	main
kool	doc_491521502103_item	2592527	et	4	main
kodu	doc_491521502103_item	2592528	et	4	main
sellel	doc_491521502103_item	2592536	et	4	main
autol	doc_491521502103_item	2592537	et	3	main
mahub	doc_491521502103_item	2592538	et	3	main
ametliku	doc_491521502103_item	2592223	et	3	main
muutke	doc_491521502103_item	2592227	et	3	main
lauseid	doc_491521502103_item	2592228	et	3	main
vene	doc_491521502103_item	2592237	et	4	main
näidis	doc_491521502103_item	2592239	et	4	main
a	doc_491521502103_item	2592240	et	4	main
keskkonna	doc_491521502103_item	2592241	et	3	main
saastatus	doc_491521502103_item	2592242	et	4	main
annab	doc_491521502103_item	2592248	et	3	main
ei	doc_491521502103_item	2592255	et	4	main
tööstuspiirkonnas	doc_491521502103_item	2592263	et	4	main
b	doc_491521502103_item	2592264	et	4	main
kui	doc_491521502103_item	2592265	et	3	main
karin	doc_491521502103_item	2592266	et	4	main
hommikul	doc_491521502103_item	2592267	et	3	main
kooli	doc_491521502103_item	2592268	et	4	main
läks	doc_491521502103_item	2592269	et	3	main
nägi	doc_491521502103_item	2592270	et	3	main
ta	doc_491521502103_item	2592271	et	4	main
puu	doc_491521502103_item	2592272	et	4	main
otsas	doc_491521502103_item	2592273	et	4	main
oravat	doc_491521502103_item	2592274	et	3	main
hommikul	doc_491521502103_item	2592275	et	3	main
nägi	doc_491521502103_item	2592278	et	3	main
elanikkonnast	doc_491521502103_item	2592287	et	4	main
ja	doc_491521502103_item	2592291	et	3	main
me	doc_491521502103_item	2592303	et	4	main
ettevaatlikud	doc_491521502103_item	2592310	et	3	main
hõreda	doc_491521502103_item	2592317	et	3	main
4	doc_491521502103_item	2592320	et	2	main
sõjamees	doc_491521502103_item	2592321	et	4	main
tamme	doc_491521502103_item	2592323	et	4	main
ja	doc_491521502103_item	2592325	et	3	main
lootis	doc_491521502103_item	2592326	et	3	main
seda	doc_491521502103_item	2592337	et	3	main
võtab	doc_491521502103_item	2592342	et	3	main
vähendab	doc_491521502103_item	2592346	et	3	main
vene-eesti	doc_491521502103_item	2592357	et	4	main
со	doc_491521502103_item	2592361	et	2	main
о	doc_491521502103_item	2592365	et	2	main
3	doc_491521502103_item	2592370	et	2	main
суммы	doc_491521502103_item	2592372	et	2	main
позже	doc_491521502103_item	2592375	et	2	main
эту	doc_491521502103_item	2592381	et	2	main
работодателем	doc_491521502103_item	2592388	et	2	main
труда	doc_491521502103_item	2592392	et	2	main
сообщали	doc_491521502103_item	2592396	et	2	main
järgi	doc_491521502103_item	2592402	et	4	main
ma	doc_491521502103_item	2592404	et	3	main
poeg	doc_491521502103_item	2592422	et	3	main
lühem	doc_491521502103_item	2592424	et	4	main
kui	doc_491521502103_item	2592425	et	3	main
isa	doc_491521502103_item	2592426	et	4	main
2	doc_491521502103_item	2592427	et	2	main
tallinn	doc_491521502103_item	2592433	et	4	main
on	doc_491521502103_item	2592440	et	4	main
keele	doc_491521502103_item	2592459	et	4	main
inglise	doc_491521502103_item	2592461	et	4	main
grammatika	doc_491521502103_item	2592463	et	4	main
teist	doc_491521502103_item	2592490	et	4	main
täna	doc_491521502103_item	2592495	et	4	main
kohtun	doc_491521502103_item	2592496	et	3	main
tavaliselt	doc_491521502103_item	2592505	et	4	main
olen	doc_491521502103_item	2592507	et	3	main
suvel	doc_491521502103_item	2592509	et	3	main
kunstnik	doc_491521502103_item	2592513	et	3	main
on	doc_491521502103_item	2592515	et	4	main
palju	doc_491521502103_item	2592516	et	4	main
ostis	doc_491521502103_item	2592519	et	4	main
inimorganismile	doc_491521502103_item	2592339	et	3	main
ära	doc_491521502103_item	2592343	et	4	main
ja	doc_491521502103_item	2592345	et	3	main
stressi	doc_491521502103_item	2592347	et	4	main
tõlkige	doc_491521502103_item	2592348	et	3	main
eesti	doc_491521502103_item	2592349	et	4	main
korral	doc_491521502103_item	2592355	et	4	main
достигают	doc_491521502103_item	2592360	et	2	main
данные	doc_491521502103_item	2592364	et	2	main
вчера	doc_491521502103_item	2592369	et	2	main
4	doc_491521502103_item	2592376	et	2	main
на	doc_491521502103_item	2592380	et	2	main
ходе	doc_491521502103_item	2592385	et	2	main
с	doc_491521502103_item	2592387	et	2	main
6	doc_491521502103_item	2592393	et	2	main
безработица	doc_491521502103_item	2592398	et	2	main
näidise	doc_491521502103_item	2592401	et	3	main
olen	doc_491521502103_item	2592405	et	3	main
õde	doc_491521502103_item	2592409	et	4	main
minu	doc_491521502103_item	2592410	et	3	main
kui	doc_491521502103_item	2592414	et	3	main
mina	doc_491521502103_item	2592415	et	4	main
1	doc_491521502103_item	2592416	et	2	main
poeg	doc_491521502103_item	2592417	et	3	main
on	doc_491521502103_item	2592418	et	4	main
pikem	doc_491521502103_item	2592419	et	4	main
kui	doc_491521502103_item	2592420	et	3	main
jätkake	doc_491521502103_item	2592400	et	3	main
noorem	doc_491521502103_item	2592413	et	4	main
on	doc_491521502103_item	2592434	et	4	main
väiksem	doc_491521502103_item	2592435	et	4	main
kui	doc_491521502103_item	2592436	et	3	main
tartu	doc_491521502103_item	2592437	et	4	main
parem	doc_491521502103_item	2592441	et	4	main
kui	doc_491521502103_item	2592443	et	3	main
heino	doc_491521502103_item	2592445	et	4	main
4	doc_491521502103_item	2592451	et	2	main
inglise	doc_491521502103_item	2592452	et	4	main
kui	doc_491521502103_item	2592457	et	3	main
viimasel	doc_491521502103_item	2592494	et	3	main
oma	doc_491521502103_item	2592497	et	4	main
see	doc_491521502103_item	2592500	et	3	main
tulevad	doc_491521502103_item	2592526	et	4	main
koolisse	doc_491521502103_item	2592529	et	4	main
kodust	doc_491521502103_item	2592530	et	4	main
kella	doc_491521502103_item	2592531	et	4	main
kolm	doc_491521502103_item	2592532	et	3	main
kolmas	doc_491521502103_item	2592533	et	3	main
see	doc_491521502103_item	2592534	et	3	main
kes	doc_491521502103_item	2592541	et	4	main
suudab	doc_491521502103_item	2592542	et	3	main
keel	doc_491521502103_item	2592546	et	4	main
keel	doc_491521502103_item	2592548	et	4	main
italia	doc_491521502103_item	2592549	et	4	main
keelest	doc_491521502103_item	2592550	et	4	main
viga	doc_491521502103_item	2592555	et	4	main
laused	doc_491521502103_item	2592574	et	3	main
vene	doc_491521502103_item	2592575	et	4	main
suured	doc_491521502103_item	2592583	et	3	main
paljud	doc_491521502103_item	2592586	et	3	main
reisida	doc_491521502103_item	2592588	et	3	main
või	doc_491521502103_item	2592590	et	4	main
3	doc_491521502103_item	2592592	et	2	main
oksi	doc_491521502103_item	2592599	et	4	main
5	doc_491521502103_item	2592604	et	2	main
eduard	doc_491521502103_item	2592611	et	4	main
soome	doc_491521502103_item	2592620	et	3	main
minna	doc_491521502103_item	2592623	et	3	main
kui	doc_491521502103_item	2592626	et	3	main
laevaga	doc_491521502103_item	2592632	et	4	main
lennukiga	doc_491521502103_item	2592634	et	3	main
2paljud	doc_491521502103_item	2592635	et	3	main
vilde	doc_491521502103_item	2592642	et	4	main
on	doc_491521502103_item	2592645	et	4	main
saabusid	doc_491521502103_item	2592650	et	4	main
pidama	doc_491521502103_item	2592666	et	4	main
viis	doc_491521502103_item	2592671	et	4	main
oma	doc_491521502103_item	2592706	et	4	main
me	doc_491521502103_item	2592708	et	4	main
tõlkige	doc_491521502103_item	2592721	et	3	main
1здесь	doc_491521502103_item	2592725	et	2	main
2	doc_491521502103_item	2592729	et	2	main
времени	doc_491521502103_item	2592735	et	2	main
у	doc_491521502103_item	2592740	et	2	main
4	doc_491521502103_item	2592746	et	2	main
5	doc_491521502103_item	2592751	et	2	main
6	doc_491521502103_item	2592757	et	2	main
умений	doc_491521502103_item	2592763	et	2	main
лица	doc_491521502103_item	2592768	et	2	main
silmad	doc_491521502103_item	2592797	et	4	main
täismineviku	doc_491521502103_item	2592811	et	3	main
abil	doc_491521502103_item	2592812	et	4	main
1в	doc_491521502103_item	2592813	et	2	main
то	doc_491521502103_item	2592814	et	2	main
время	doc_491521502103_item	2592815	et	2	main
каждый	doc_491521502103_item	2592816	et	2	main
on	doc_491521502103_item	2592429	et	4	main
suurem	doc_491521502103_item	2592430	et	4	main
kui	doc_491521502103_item	2592431	et	3	main
tartu	doc_491521502103_item	2592432	et	4	main
3	doc_491521502103_item	2592438	et	2	main
keele	doc_491521502103_item	2592453	et	4	main
grammatika	doc_491521502103_item	2592454	et	4	main
on	doc_491521502103_item	2592455	et	4	main
grammatika	doc_491521502103_item	2592460	et	4	main
keele	doc_491521502103_item	2592462	et	4	main
on	doc_491521502103_item	2592464	et	4	main
grammatika	doc_491521502103_item	2592469	et	4	main
5	doc_491521502103_item	2592470	et	2	main
meie	doc_491521502103_item	2592471	et	4	main
tänav	doc_491521502103_item	2592472	et	4	main
on	doc_491521502103_item	2592473	et	4	main
puhtam	doc_491521502103_item	2592474	et	4	main
kui	doc_491521502103_item	2592475	et	3	main
sõle	doc_491521502103_item	2592476	et	3	main
tänav	doc_491521502103_item	2592477	et	4	main
valige	doc_491521502103_item	2592478	et	3	main
õige	doc_491521502103_item	2592479	et	4	main
kääne	doc_491521502103_item	2592480	et	3	main
ning	doc_491521502103_item	2592481	et	3	main
vajadusel	doc_491521502103_item	2592482	et	3	main
ka	doc_491521502103_item	2592483	et	3	main
tagasõna	doc_491521502103_item	2592484	et	4	main
tahan	doc_491521502103_item	2592485	et	3	main
puhata	doc_491521502103_item	2592486	et	4	main
hommik	doc_491521502103_item	2592487	et	3	main
sugulastega	doc_491521502103_item	2592499	et	4	main
on	doc_491521502103_item	2592502	et	4	main
suvi	doc_491521502103_item	2592508	et	3	main
puhanud	doc_491521502103_item	2592510	et	4	main
mäed	doc_491521502103_item	2592511	et	3	main
mäedel	doc_491521502103_item	2592512	et	4	main
kunstnikul	doc_491521502103_item	2592514	et	3	main
isa	doc_491521502103_item	2592518	et	4	main
õhtu	doc_491521502103_item	2592520	et	4	main
teater	doc_491521502103_item	2592523	et	3	main
tõlkida	doc_491521502103_item	2592543	et	3	main
vene	doc_491521502103_item	2592552	et	4	main
omastavasse	doc_491521502103_item	2592571	et	4	main
käändesse	doc_491521502103_item	2592572	et	4	main
tõlkige	doc_491521502103_item	2592573	et	3	main
saabusid	doc_491521502103_item	2592581	et	4	main
2	doc_491521502103_item	2592585	et	2	main
eelistavad	doc_491521502103_item	2592587	et	4	main
rong	doc_491521502103_item	2592589	et	3	main
buss	doc_491521502103_item	2592591	et	3	main
palav	doc_491521502103_item	2592593	et	4	main
kliima	doc_491521502103_item	2592594	et	4	main
saab	doc_491521502103_item	2592600	et	3	main
nuga	doc_491521502103_item	2592603	et	4	main
nii	doc_491521502103_item	2592607	et	3	main
näod	doc_491521502103_item	2592609	et	3	main
must	doc_491521502103_item	2592616	et	4	main
õhtul	doc_491521502103_item	2592521	et	3	main
lapsed	doc_491521502103_item	2592525	et	3	main
itaalia	doc_491521502103_item	2592545	et	4	main
on	doc_491521502103_item	2592551	et	4	main
õpetaja	doc_491521502103_item	2592557	et	4	main
tuli	doc_491521502103_item	2592558	et	4	main
klass	doc_491521502103_item	2592559	et	3	main
klassi	doc_491521502103_item	2592560	et	4	main
uued	doc_491521502103_item	2592561	et	3	main
õpilased	doc_491521502103_item	2592562	et	3	main
uuedega	doc_491521502103_item	2592563	et	4	main
õpilastega	doc_491521502103_item	2592564	et	4	main
pange	doc_491521502103_item	2592565	et	4	main
sulgudes	doc_491521502103_item	2592566	et	4	main
olevad	doc_491521502103_item	2592567	et	4	main
sõnad	doc_491521502103_item	2592568	et	4	main
kaasaütlevasse	doc_491521502103_item	2592569	et	3	main
või	doc_491521502103_item	2592570	et	4	main
kuus	doc_491521502103_item	2592539	et	4	main
inimest	doc_491521502103_item	2592540	et	3	main
keeles	doc_491521502103_item	2592553	et	4	main
keelde	doc_491521502103_item	2592576	et	4	main
перевода	doc_491521502103_item	2592577	et	2	main
не	doc_491521502103_item	2592578	et	2	main
надо	doc_491521502103_item	2592579	et	2	main
lõigata	doc_491521502103_item	2592601	et	4	main
hapud	doc_491521502103_item	2592608	et	3	main
6	doc_491521502103_item	2592610	et	2	main
mantel	doc_491521502103_item	2592617	et	3	main
laev	doc_491521502103_item	2592625	et	3	main
kui	doc_491521502103_item	2592633	et	3	main
reisida	doc_491521502103_item	2592637	et	3	main
rongiga	doc_491521502103_item	2592638	et	4	main
jutustuse	doc_491521502103_item	2592643	et	4	main
kohvritega	doc_491521502103_item	2592653	et	3	main
saab	doc_491521502103_item	2592655	et	3	main
tavaliselt	doc_491521502103_item	2592665	et	4	main
lahkuma	doc_491521502103_item	2592669	et	3	main
need	doc_491521502103_item	2592672	et	3	main
tuttavatele	doc_491521502103_item	2592707	et	3	main
hakkama	doc_491521502103_item	2592709	et	3	main
hakkame	doc_491521502103_item	2592711	et	3	main
tallinnas	doc_491521502103_item	2592713	et	4	main
õpetama	doc_491521502103_item	2592716	et	3	main
võõrkeelt	doc_491521502103_item	2592719	et	4	main
välismaalastele	doc_491521502103_item	2592720	et	4	main
1turistid	doc_491521502103_item	2592580	et	3	main
kohvrid	doc_491521502103_item	2592584	et	3	main
kohanemine	doc_491521502103_item	2592595	et	4	main
nõuab	doc_491521502103_item	2592596	et	3	main
aega	doc_491521502103_item	2592597	et	4	main
4	doc_491521502103_item	2592598	et	2	main
on	doc_491521502103_item	2592615	et	4	main
7	doc_491521502103_item	2592619	et	2	main
nii	doc_491521502103_item	2592624	et	3	main
lennuk	doc_491521502103_item	2592627	et	3	main
pealkiri	doc_491521502103_item	2592644	et	3	main
musta	doc_491521502103_item	2592646	et	4	main
mantliga	doc_491521502103_item	2592647	et	3	main
4oksi	doc_491521502103_item	2592654	et	4	main
lõigata	doc_491521502103_item	2592656	et	4	main
nugaga	doc_491521502103_item	2592658	et	4	main
5ärge	doc_491521502103_item	2592659	et	3	main
istuge	doc_491521502103_item	2592660	et	3	main
nii	doc_491521502103_item	2592661	et	3	main
hapude	doc_491521502103_item	2592662	et	3	main
ta	doc_491521502103_item	2592664	et	4	main
pidab	doc_491521502103_item	2592668	et	4	main
võima	doc_491521502103_item	2592674	et	3	main
kirja	doc_491521502103_item	2592705	et	4	main
elama	doc_491521502103_item	2592710	et	3	main
elada	doc_491521502103_item	2592712	et	3	main
ma	doc_491521502103_item	2592714	et	3	main
oskan	doc_491521502103_item	2592717	et	3	main
keelde	doc_491521502103_item	2592724	et	4	main
бытовых	doc_491521502103_item	2592732	et	2	main
году	doc_491521502103_item	2592739	et	2	main
больших	doc_491521502103_item	2592744	et	2	main
достижения	doc_491521502103_item	2592748	et	2	main
общаться	doc_491521502103_item	2592756	et	2	main
разных	doc_491521502103_item	2592762	et	2	main
отдыхают	doc_491521502103_item	2592766	et	2	main
довольно	doc_491521502103_item	2592771	et	2	main
3selles	doc_491521502103_item	2592799	et	4	main
aastas	doc_491521502103_item	2592800	et	3	main
mull	doc_491521502103_item	2592801	et	3	main
suurt	doc_491521502103_item	2592804	et	3	main
рабочий	doc_491521502103_item	2592817	et	2	main
продолжалось	doc_491521502103_item	2592824	et	2	main
мы	doc_491521502103_item	2592828	et	2	main
что	doc_491521502103_item	2592834	et	2	main
что	doc_491521502103_item	2592840	et	2	main
6	doc_491521502103_item	2592845	et	2	main
7	doc_491521502103_item	2592851	et	2	main
бывало	doc_491521502103_item	2592854	et	2	main
8	doc_491521502103_item	2592858	et	2	main
в	doc_491521502103_item	2592862	et	2	main
juhtus	doc_491521502103_item	2592867	et	3	main
et	doc_491521502103_item	2592869	et	3	main
elu	doc_491521502103_item	2592880	et	4	main
kontrolltöö	doc_491521502104_item	2592881	et	4	main
kohale	doc_491521502104_item	2592901	et	4	main
maja	doc_491521502104_item	2592905	et	4	main
vastu	doc_491521502104_item	2592908	et	3	main
sinu	doc_491521502104_item	2592911	et	3	main
kurbus	doc_491521502104_item	2592913	et	4	main
avatakse	doc_491521502104_item	2592931	et	4	main
külastajatele	doc_491521502104_item	2592935	et	4	main
oktoober	doc_491521502104_item	2592938	et	3	main
sein	doc_491521502104_item	2592940	et	3	main
jäänud	doc_491521502104_item	2592951	et	4	main
alati	doc_491521502104_item	2592962	et	4	main
ajutiselt	doc_491521502104_item	2593000	et	4	main
sellesse	doc_491521502104_item	2593001	et	4	main
vastutan	doc_491521502104_item	2593009	et	3	main
võimalik	doc_491521502103_item	2592622	et	3	main
on	doc_491521502103_item	2592629	et	4	main
võimalik	doc_491521502103_item	2592630	et	3	main
või	doc_491521502103_item	2592639	et	4	main
bussiga	doc_491521502103_item	2592640	et	3	main
6eduard	doc_491521502103_item	2592641	et	4	main
1turistid	doc_491521502103_item	2592649	et	3	main
lennujaama	doc_491521502103_item	2592651	et	4	main
terava	doc_491521502103_item	2592657	et	3	main
lahkuma	doc_491521502103_item	2592667	et	3	main
rääkima	doc_491521502103_item	2592675	et	3	main
võivad	doc_491521502103_item	2592676	et	4	main
rääkida	doc_491521502103_item	2592677	et	3	main
võõrkeelt	doc_491521502103_item	2592679	et	4	main
ta	doc_491521502103_item	2592680	et	4	main
kolme	doc_491521502103_item	2592678	et	4	main
ei	doc_491521502103_item	2592681	et	4	main
tahtma	doc_491521502103_item	2592682	et	3	main
suitsetama	doc_491521502103_item	2592683	et	4	main
tahtnud	doc_491521502103_item	2592684	et	4	main
suitsetama	doc_491521502103_item	2592685	et	4	main
palju	doc_491521502103_item	2592686	et	4	main
te	doc_491521502103_item	2592687	et	4	main
hakkama	doc_491521502103_item	2592688	et	3	main
kirjutama	doc_491521502103_item	2592689	et	3	main
hakkate	doc_491521502103_item	2592690	et	3	main
kirjutada	doc_491521502103_item	2592691	et	3	main
harjutust	doc_491521502103_item	2592692	et	4	main
talle	doc_491521502103_item	2592693	et	4	main
meeldima	doc_491521502103_item	2592694	et	3	main
töötama	doc_491521502103_item	2592695	et	3	main
meeldib	doc_491521502103_item	2592696	et	3	main
töötama	doc_491521502103_item	2592697	et	3	main
selles	doc_491521502103_item	2592698	et	4	main
ettevõttes	doc_491521502103_item	2592699	et	3	main
eelistavad	doc_491521502103_item	2592636	et	4	main
mees	doc_491521502103_item	2592648	et	4	main
suurte	doc_491521502103_item	2592652	et	3	main
näodega	doc_491521502103_item	2592663	et	4	main
kell	doc_491521502103_item	2592670	et	3	main
tüdrukud	doc_491521502103_item	2592673	et	3	main
ma	doc_491521502103_item	2592700	et	3	main
tahtma	doc_491521502103_item	2592701	et	3	main
kirjutama	doc_491521502103_item	2592702	et	3	main
tahan	doc_491521502103_item	2592703	et	3	main
нет	doc_491521502103_item	2592726	et	2	main
подробное	doc_491521502103_item	2592730	et	2	main
требует	doc_491521502103_item	2592734	et	2	main
этом	doc_491521502103_item	2592738	et	2	main
три	doc_491521502103_item	2592743	et	2	main
будут	doc_491521502103_item	2592749	et	2	main
вас	doc_491521502103_item	2592753	et	2	main
эта	doc_491521502103_item	2592758	et	2	main
требует	doc_491521502103_item	2592760	et	2	main
7	doc_491521502103_item	2592764	et	2	main
людей	doc_491521502103_item	2592769	et	2	main
oli	doc_491521502103_item	2592802	et	3	main
eesti	doc_491521502103_item	2592806	et	4	main
keelde	doc_491521502103_item	2592807	et	4	main
kas	doc_491521502103_item	2592808	et	3	main
liht-	doc_491521502103_item	2592809	et	3	main
начинался	doc_491521502103_item	2592819	et	2	main
2	doc_491521502103_item	2592822	et	2	main
оказываем	doc_491521502103_item	2592831	et	2	main
вас	doc_491521502103_item	2592836	et	2	main
я	doc_491521502103_item	2592841	et	2	main
мы	doc_491521502103_item	2592846	et	2	main
спокойное	doc_491521502103_item	2592852	et	2	main
решением	doc_491521502103_item	2592857	et	2	main
5juhtunud	doc_491521502103_item	2592868	et	4	main
sulgudes	doc_491521502104_item	2592883	et	4	main
vastavatesse	doc_491521502104_item	2592886	et	4	main
tõlkige	doc_491521502104_item	2592888	et	3	main
laused	doc_491521502104_item	2592889	et	3	main
1homme	doc_491521502104_item	2592890	et	3	main
kolime	doc_491521502104_item	2592891	et	3	main
aastat	doc_491521502104_item	2592900	et	3	main
helista	doc_491521502104_item	2592903	et	4	main
2	doc_491521502104_item	2592909	et	2	main
peagi	doc_491521502104_item	2592921	et	4	main
kaupluse	doc_491521502104_item	2592926	et	3	main
on	doc_491521502104_item	2592934	et	4	main
avatud	doc_491521502104_item	2592936	et	4	main
on	doc_491521502104_item	2592941	et	4	main
on	doc_491521502104_item	2592945	et	4	main
auk	doc_491521502104_item	2592947	et	3	main
järele	doc_491521502104_item	2592950	et	4	main
osakond	doc_491521502104_item	2592958	et	3	main
majapidamistarvete	doc_491521502104_item	2592959	et	4	main
osakond	doc_491521502104_item	2592960	et	3	main
leidub	doc_491521502104_item	2592961	et	3	main
majas	doc_491521502104_item	2592969	et	3	main
2	doc_491521502104_item	2592971	et	2	main
kurbuseni	doc_491521502104_item	2592972	et	4	main
2	doc_491521502104_item	2593004	et	2	main
et	doc_491521502104_item	2593007	et	3	main
oma	doc_491521502104_item	2593029	et	4	main
saatuse	doc_491521502104_item	2593031	et	3	main
maakonnad	doc_491521502104_item	2593039	et	4	main
haritud	doc_491521502104_item	2593042	et	4	main
baltisakslased	doc_491521502104_item	2593045	et	3	main
baltisakslaseks	doc_491521502104_item	2593067	et	3	main
sulgudes	doc_491521502104_item	2593070	et	4	main
olevad	doc_491521502104_item	2593071	et	4	main
ei	doc_491521502104_item	2593083	et	4	main
möödub	doc_491521502104_item	2593113	et	3	main
3	doc_491521502104_item	2593135	et	2	main
sabata	doc_491521502104_item	2593139	et	3	main
7	doc_491521502104_item	2593146	et	2	main
muutke	doc_491521502104_item	2593148	et	3	main
nii	doc_491521502104_item	2593150	et	3	main
tegusõnast	doc_491521502104_item	2593153	et	4	main
tõlkige	doc_491521502104_item	2593156	et	3	main
vene	doc_491521502104_item	2593158	et	4	main
keskkonna	doc_491521502104_item	2593162	et	3	main
tööstuspiirkonnas	doc_491521502104_item	2593173	et	4	main
kirjutama	doc_491521502103_item	2592704	et	3	main
oskama	doc_491521502103_item	2592715	et	3	main
õpetama	doc_491521502103_item	2592718	et	3	main
eesti	doc_491521502103_item	2592723	et	4	main
удобств	doc_491521502103_item	2592728	et	2	main
удобств	doc_491521502103_item	2592733	et	2	main
в	doc_491521502103_item	2592737	et	2	main
меня	doc_491521502103_item	2592741	et	2	main
достижения	doc_491521502103_item	2592745	et	2	main
завтра	doc_491521502103_item	2592750	et	2	main
нет	doc_491521502103_item	2592754	et	2	main
работа	doc_491521502103_item	2592759	et	2	main
люди	doc_491521502103_item	2592765	et	2	main
простые	doc_491521502103_item	2592772	et	2	main
9selle	doc_491521502103_item	2592795	et	4	main
või	doc_491521502103_item	2592810	et	4	main
рано	doc_491521502103_item	2592820	et	2	main
обучение	doc_491521502103_item	2592823	et	2	main
3	doc_491521502103_item	2592827	et	2	main
давления	doc_491521502103_item	2592832	et	2	main
случалось	doc_491521502103_item	2592839	et	2	main
учиться	doc_491521502103_item	2592844	et	2	main
постоянно	doc_491521502103_item	2592847	et	2	main
совете	doc_491521502103_item	2592850	et	2	main
разумным	doc_491521502103_item	2592856	et	2	main
вносил	doc_491521502103_item	2592861	et	2	main
4mis	doc_491521502103_item	2592865	et	4	main
ei	doc_491521502103_item	2592871	et	4	main
õppima	doc_491521502103_item	2592873	et	3	main
ei	doc_491521502103_item	2592876	et	4	main
2õppimine	doc_491521502103_item	2592877	et	4	main
sõltub	doc_491521502103_item	2592878	et	3	main
kõiki	doc_491521502103_item	2592879	et	4	main
olevad	doc_491521502104_item	2592884	et	4	main
sõnad	doc_491521502104_item	2592885	et	4	main
sisekohakäänetesse	doc_491521502104_item	2592887	et	3	main
maja	doc_491521502104_item	2592893	et	4	main
me	doc_491521502104_item	2592894	et	4	main
elame	doc_491521502104_item	2592895	et	3	main
uus	doc_491521502104_item	2592896	et	3	main
jõudes	doc_491521502104_item	2592902	et	3	main
välja	doc_491521502104_item	2592906	et	4	main
sulle	doc_491521502104_item	2592907	et	3	main
oma	doc_491521502104_item	2592922	et	4	main
kurbus	doc_491521502104_item	2592923	et	4	main
vabaneda	doc_491521502104_item	2592924	et	3	main
3	doc_491521502104_item	2592925	et	2	main
avamine	doc_491521502104_item	2592927	et	4	main
lükkub	doc_491521502104_item	2592928	et	3	main
oktoober	doc_491521502104_item	2592929	et	3	main
kauplus	doc_491521502104_item	2592930	et	3	main
oktoober	doc_491521502104_item	2592932	et	3	main
tehtud	doc_491521502104_item	2592942	et	4	main
ainult	doc_491521502104_item	2592952	et	4	main
kivid	doc_491521502104_item	2592953	et	3	main
midagi	doc_491521502104_item	2592963	et	4	main
majandusjuhataja	doc_491521502104_item	2593003	et	4	main
teatas	doc_491521502104_item	2593006	et	3	main
tähtaeg	doc_491521502104_item	2593012	et	3	main
eest	doc_491521502104_item	2593015	et	4	main
3	doc_491521502104_item	2593016	et	2	main
kasvamine	doc_491521502104_item	2593019	et	4	main
muretsevad	doc_491521502104_item	2593027	et	4	main
pärast	doc_491521502104_item	2593032	et	4	main
eesti	doc_491521502104_item	2593036	et	4	main
jagunenud	doc_491521502104_item	2593037	et	4	main
mõned	doc_491521502104_item	2593041	et	3	main
eestlased	doc_491521502104_item	2593043	et	3	main
4	doc_491521502104_item	2593061	et	2	main
5	doc_491521502104_item	2593063	et	2	main
omastavasse	doc_491521502104_item	2593075	et	4	main
nägu	doc_491521502104_item	2593090	et	4	main
3	doc_491521502104_item	2593093	et	2	main
giidi	doc_491521502104_item	2593096	et	4	main
all	doc_491521502104_item	2593103	et	3	main
paks	doc_491521502104_item	2593105	et	3	main
5	doc_491521502104_item	2593108	et	2	main
ärge	doc_491521502104_item	2593109	et	3	main
uskuge	doc_491521502104_item	2593110	et	3	main
et	doc_491521502104_item	2593111	et	3	main
reis	doc_491521502104_item	2593112	et	4	main
laused	doc_491521502103_item	2592722	et	3	main
бытовых	doc_491521502103_item	2592727	et	2	main
описание	doc_491521502103_item	2592731	et	2	main
3	doc_491521502103_item	2592736	et	2	main
было	doc_491521502103_item	2592742	et	2	main
большие	doc_491521502103_item	2592747	et	2	main
у	doc_491521502103_item	2592752	et	2	main
умения	doc_491521502103_item	2592755	et	2	main
много	doc_491521502103_item	2592761	et	2	main
8	doc_491521502103_item	2592767	et	2	main
были	doc_491521502103_item	2592770	et	2	main
глаза	doc_491521502103_item	2592774	et	2	main
9	doc_491521502103_item	2592773	et	2	main
этого	doc_491521502103_item	2592775	et	2	main
человека	doc_491521502103_item	2592776	et	2	main
очень	doc_491521502103_item	2592777	et	2	main
робкие	doc_491521502103_item	2592778	et	2	main
10	doc_491521502103_item	2592779	et	2	main
изменение	doc_491521502103_item	2592780	et	2	main
проходит	doc_491521502103_item	2592782	et	2	main
тяжело	doc_491521502103_item	2592783	et	2	main
самооценки	doc_491521502103_item	2592781	et	2	main
7inimesed	doc_491521502103_item	2592784	et	3	main
5kas	doc_491521502103_item	2592786	et	3	main
puhkavad	doc_491521502103_item	2592785	et	4	main
teil	doc_491521502103_item	2592787	et	4	main
ei	doc_491521502103_item	2592788	et	4	main
saanud	doc_491521502103_item	2592789	et	4	main
vestelda	doc_491521502103_item	2592790	et	4	main
8inimeste	doc_491521502103_item	2592791	et	3	main
näod	doc_491521502103_item	2592792	et	3	main
oli	doc_491521502103_item	2592793	et	3	main
lihtsad	doc_491521502103_item	2592794	et	3	main
inimeste	doc_491521502103_item	2592796	et	3	main
väga	doc_491521502103_item	2592798	et	3	main
kolm	doc_491521502103_item	2592803	et	3	main
tõlkige	doc_491521502103_item	2592805	et	3	main
день	doc_491521502103_item	2592818	et	2	main
утром	doc_491521502103_item	2592821	et	2	main
всю	doc_491521502103_item	2592825	et	2	main
никогда	doc_491521502103_item	2592829	et	2	main
4	doc_491521502103_item	2592833	et	2	main
случилось	doc_491521502103_item	2592837	et	2	main
не	doc_491521502103_item	2592842	et	2	main
в	doc_491521502103_item	2592849	et	2	main
обсуждение	doc_491521502103_item	2592853	et	2	main
он	doc_491521502103_item	2592859	et	2	main
дело	doc_491521502103_item	2592863	et	2	main
tahtnud	doc_491521502103_item	2592872	et	4	main
pange	doc_491521502104_item	2592882	et	4	main
maja	doc_491521502104_item	2592897	et	4	main
juba	doc_491521502104_item	2592898	et	3	main
pool	doc_491521502104_item	2592899	et	4	main
tulen	doc_491521502104_item	2592904	et	3	main
langesin	doc_491521502104_item	2592910	et	3	main
pärast	doc_491521502104_item	2592912	et	4	main
sein	doc_491521502104_item	2592944	et	3	main
sügav	doc_491521502104_item	2592946	et	4	main
5	doc_491521502104_item	2592954	et	2	main
läheme	doc_491521502104_item	2592955	et	3	main
nüüd	doc_491521502104_item	2592956	et	4	main
majapidamistarvete	doc_491521502104_item	2592957	et	4	main
1	doc_491521502104_item	2592965	et	2	main
uue	doc_491521502104_item	2592966	et	3	main
majja	doc_491521502104_item	2592967	et	3	main
uues	doc_491521502104_item	2592968	et	3	main
kutsekooli	doc_491521502104_item	2593002	et	4	main
majandusjuhataja	doc_491521502104_item	2593008	et	4	main
haritud	doc_491521502104_item	2593017	et	4	main
nõuab	doc_491521502104_item	2593020	et	3	main
ja	doc_491521502104_item	2593022	et	3	main
eestlased	doc_491521502104_item	2593028	et	3	main
5	doc_491521502104_item	2593033	et	2	main
oli	doc_491521502104_item	2593035	et	3	main
muutusid	doc_491521502104_item	2593044	et	4	main
end	doc_491521502104_item	2593048	et	4	main
oma	doc_491521502104_item	2593050	et	4	main
rahva	doc_491521502104_item	2593051	et	3	main
erinevateks	doc_491521502104_item	2593064	et	4	main
ilmaütlevasse	doc_491521502104_item	2593073	et	3	main
ole	doc_491521502104_item	2593084	et	4	main
poisi	doc_491521502104_item	2593089	et	3	main
oli	doc_491521502104_item	2593091	et	3	main
suhtusid	doc_491521502104_item	2593095	et	4	main
ettepanekusse	doc_491521502104_item	2593097	et	3	main
suur	doc_491521502104_item	2593099	et	3	main
huvi	doc_491521502104_item	2593100	et	4	main
4	doc_491521502104_item	2593101	et	2	main
istus	doc_491521502104_item	2593104	et	4	main
ole	doc_491521502104_item	2593122	et	4	main
vormistada	doc_491521502104_item	2593125	et	3	main
suure	doc_491521502104_item	2593136	et	3	main
vaatamisväärsusteta	doc_491521502104_item	2593142	et	4	main
ametliku	doc_491521502104_item	2593144	et	3	main
hilinemiseta	doc_491521502104_item	2593147	et	4	main
lauseid	doc_491521502104_item	2593149	et	3	main
ole	doc_491521502104_item	2593165	et	4	main
eriti	doc_491521502104_item	2593166	et	3	main
tugev	doc_491521502104_item	2593167	et	4	main
ja	doc_491521502104_item	2593168	et	3	main
annab	doc_491521502104_item	2593169	et	3	main
end	doc_491521502104_item	2593170	et	4	main
tunda	doc_491521502104_item	2593171	et	3	main
vaid	doc_491521502104_item	2593172	et	3	main
end	doc_491521502104_item	2593181	et	4	main
otsas	doc_491521502104_item	2593194	et	4	main
oravat	doc_491521502104_item	2593195	et	3	main
olime	doc_491521502104_item	2593222	et	3	main
ei	doc_491521502104_item	2593223	et	4	main
keetmata	doc_491521502104_item	2593226	et	4	main
vett	doc_491521502104_item	2593227	et	3	main
võimalikult	doc_491521502104_item	2593231	et	4	main
olles	doc_491521502104_item	2593233	et	3	main
жизнь	doc_491521502103_item	2592826	et	2	main
не	doc_491521502103_item	2592830	et	2	main
у	doc_491521502103_item	2592835	et	2	main
5	doc_491521502103_item	2592838	et	2	main
хотел	doc_491521502103_item	2592843	et	2	main
нуждались	doc_491521502103_item	2592848	et	2	main
самым	doc_491521502103_item	2592855	et	2	main
всегда	doc_491521502103_item	2592860	et	2	main
ясность	doc_491521502103_item	2592864	et	2	main
teil	doc_491521502103_item	2592866	et	4	main
ma	doc_491521502103_item	2592870	et	3	main
3me	doc_491521502103_item	2592874	et	4	main
kunagi	doc_491521502103_item	2592875	et	3	main
uus	doc_491521502104_item	2592892	et	3	main
juba	doc_491521502104_item	2592914	et	3	main
mitmendat	doc_491521502104_item	2592915	et	3	main
nädalat	doc_491521502104_item	2592916	et	3	main
viibin	doc_491521502104_item	2592917	et	3	main
sügav	doc_491521502104_item	2592918	et	4	main
kurbus	doc_491521502104_item	2592919	et	4	main
loodan	doc_491521502104_item	2592920	et	3	main
kauplus	doc_491521502104_item	2592933	et	3	main
alates	doc_491521502104_item	2592937	et	3	main
4	doc_491521502104_item	2592939	et	2	main
auk	doc_491521502104_item	2592943	et	3	main
sein	doc_491521502104_item	2592948	et	3	main
on	doc_491521502104_item	2592949	et	4	main
vajalikku	doc_491521502104_item	2592964	et	4	main
majast	doc_491521502104_item	2592970	et	4	main
sügavas	doc_491521502104_item	2592973	et	4	main
kurbuses	doc_491521502104_item	2592974	et	4	main
kurbusest	doc_491521502104_item	2592975	et	4	main
3	doc_491521502104_item	2592976	et	2	main
oktoobriks	doc_491521502104_item	2592977	et	3	main
oktoobris	doc_491521502104_item	2592978	et	3	main
oktoobrist	doc_491521502104_item	2592979	et	3	main
4	doc_491521502104_item	2592980	et	2	main
seinas	doc_491521502104_item	2592981	et	3	main
seinal	doc_491521502104_item	2592982	et	3	main
seinast	doc_491521502104_item	2592983	et	4	main
5	doc_491521502104_item	2592984	et	2	main
majapidamistarvete	doc_491521502104_item	2592985	et	4	main
osakonda	doc_491521502104_item	2592986	et	4	main
majapidamistarvete	doc_491521502104_item	2592987	et	4	main
osakonnast	doc_491521502104_item	2592988	et	4	main
valige	doc_491521502104_item	2592989	et	3	main
õige	doc_491521502104_item	2592990	et	4	main
kääne	doc_491521502104_item	2592991	et	3	main
kas	doc_491521502104_item	2592992	et	3	main
saav	doc_491521502104_item	2592993	et	4	main
või	doc_491521502104_item	2592994	et	4	main
olev	doc_491521502104_item	2592995	et	4	main
1möödunud	doc_491521502104_item	2592996	et	4	main
talvel	doc_491521502104_item	2592997	et	4	main
kutsuti	doc_491521502104_item	2592998	et	3	main
mind	doc_491521502104_item	2592999	et	4	main
direktor	doc_491521502104_item	2593005	et	3	main
mina	doc_491521502104_item	2593010	et	4	main
õige	doc_491521502104_item	2593011	et	4	main
valminud	doc_491521502104_item	2593013	et	4	main
remondi	doc_491521502104_item	2593014	et	4	main
inimene	doc_491521502104_item	2593018	et	3	main
töökust	doc_491521502104_item	2593021	et	4	main
4	doc_491521502104_item	2593024	et	2	main
keele	doc_491521502104_item	2593030	et	4	main
erinevad	doc_491521502104_item	2593038	et	4	main
tundsid	doc_491521502104_item	2593047	et	4	main
maakonnadeks	doc_491521502104_item	2593065	et	3	main
sõnad	doc_491521502104_item	2593072	et	4	main
käändesse	doc_491521502104_item	2593076	et	4	main
laused	doc_491521502104_item	2593078	et	3	main
keelde	doc_491521502104_item	2593080	et	4	main
1ilma	doc_491521502104_item	2593081	et	4	main
pass	doc_491521502104_item	2593082	et	3	main
lubatud	doc_491521502104_item	2593085	et	4	main
piiri	doc_491521502104_item	2593086	et	4	main
ületada	doc_491521502104_item	2593087	et	3	main
2	doc_491521502104_item	2593088	et	2	main
pesema	doc_491521502104_item	2593092	et	3	main
ilma	doc_491521502104_item	2593098	et	4	main
1	doc_491521502104_item	2593131	et	2	main
2	doc_491521502104_item	2593133	et	2	main
taotluseta	doc_491521502104_item	2593145	et	4	main
des-vorm	doc_491521502104_item	2593155	et	3	main
laused	doc_491521502104_item	2593157	et	3	main
a	doc_491521502104_item	2593161	et	4	main
ei	doc_491521502104_item	2593164	et	4	main
ei	doc_491521502104_item	2593176	et	4	main
andes	doc_491521502104_item	2593180	et	4	main
b	doc_491521502104_item	2593185	et	4	main
karin	doc_491521502104_item	2593187	et	4	main
hommikul	doc_491521502104_item	2593196	et	3	main
kooli	doc_491521502104_item	2593197	et	4	main
minnes	doc_491521502104_item	2593198	et	3	main
nägi	doc_491521502104_item	2593199	et	3	main
puu	doc_491521502104_item	2593201	et	4	main
otsas	doc_491521502104_item	2593202	et	4	main
ja	doc_491521502104_item	2593228	et	3	main
eesti	doc_491521502104_item	2593240	et	4	main
hõreda	doc_491521502104_item	2593241	et	3	main
iga	doc_491521502104_item	2593256	et	4	main
taim	doc_491521502104_item	2593257	et	3	main
ka	doc_491521502104_item	2593264	et	3	main
stressi	doc_491521502104_item	2593274	et	4	main
eesti	doc_491521502104_item	2593277	et	4	main
umbisikulise	doc_491521502104_item	2593279	et	4	main
tegumoe	doc_491521502104_item	2593280	et	3	main
korral	doc_491521502104_item	2593283	et	4	main
vene-eesti	doc_491521502104_item	2593285	et	4	main
1цели	doc_491521502104_item	2593287	et	2	main
со	doc_491521502104_item	2593289	et	2	main
2	doc_491521502104_item	2593291	et	2	main
о	doc_491521502104_item	2593293	et	2	main
положении	doc_491521502104_item	2593295	et	2	main
вчера	doc_491521502104_item	2593297	et	2	main
обсуждение	doc_491521502104_item	2593299	et	2	main
зарплаты	doc_491521502104_item	2593301	et	2	main
позже	doc_491521502104_item	2593303	et	2	main
на	doc_491521502104_item	2593308	et	2	main
ходе	doc_491521502104_item	2593313	et	2	main
об	doc_491521502104_item	2593318	et	2	main
сообщали	doc_491521502104_item	2593324	et	2	main
1	doc_491521502104_item	2593328	et	2	main
esitati	doc_491521502104_item	2593335	et	4	main
teid	doc_491521502104_item	2593343	et	4	main
tööandjaga	doc_491521502104_item	2593351	et	3	main
töötingimustest	doc_491521502104_item	2593353	et	3	main
kasvab	doc_491521502104_item	2593360	et	3	main
jätkake	doc_491521502104_item	2593361	et	3	main
järgi	doc_491521502104_item	2593363	et	4	main
ma	doc_491521502104_item	2593365	et	3	main
3	doc_491521502104_item	2593399	et	2	main
heino	doc_491521502104_item	2593400	et	4	main
kalle	doc_491521502104_item	2593405	et	3	main
grammatika	doc_491521502104_item	2593421	et	4	main
keele	doc_491521502104_item	2593423	et	4	main
grammatika	doc_491521502104_item	2593424	et	4	main
kannatlikust	doc_491521502104_item	2593023	et	4	main
väikese	doc_491521502104_item	2593025	et	4	main
rahvas	doc_491521502104_item	2593026	et	4	main
ajalooliselt	doc_491521502104_item	2593034	et	4	main
6	doc_491521502104_item	2593040	et	2	main
teised	doc_491521502104_item	2593046	et	4	main
endiselt	doc_491521502104_item	2593049	et	4	main
esindajad	doc_491521502104_item	2593052	et	4	main
1	doc_491521502104_item	2593053	et	2	main
majandusjuhatajana	doc_491521502104_item	2593054	et	3	main
2	doc_491521502104_item	2593055	et	2	main
majandusjuhatajana	doc_491521502104_item	2593056	et	3	main
õigeks	doc_491521502104_item	2593057	et	3	main
tähtajaks	doc_491521502104_item	2593058	et	3	main
3	doc_491521502104_item	2593059	et	2	main
inimeseks	doc_491521502104_item	2593060	et	3	main
rahvasena	doc_491521502104_item	2593062	et	4	main
6	doc_491521502104_item	2593066	et	2	main
esindajana	doc_491521502104_item	2593068	et	4	main
pange	doc_491521502104_item	2593069	et	4	main
või	doc_491521502104_item	2593074	et	4	main
tõlkige	doc_491521502104_item	2593077	et	3	main
vene	doc_491521502104_item	2593079	et	4	main
reisijad	doc_491521502104_item	2593094	et	4	main
puu	doc_491521502104_item	2593102	et	4	main
saba	doc_491521502104_item	2593106	et	4	main
kass	doc_491521502104_item	2593107	et	3	main
ilma	doc_491521502104_item	2593114	et	4	main
igasugused	doc_491521502104_item	2593115	et	3	main
vaatamisväärsused	doc_491521502104_item	2593116	et	4	main
6	doc_491521502104_item	2593117	et	2	main
ilma	doc_491521502104_item	2593118	et	4	main
ametlik	doc_491521502104_item	2593119	et	3	main
taotlus	doc_491521502104_item	2593120	et	4	main
ei	doc_491521502104_item	2593121	et	4	main
viisat	doc_491521502104_item	2593124	et	3	main
rong	doc_491521502104_item	2593127	et	3	main
saabus	doc_491521502104_item	2593128	et	3	main
pesemata	doc_491521502104_item	2593134	et	4	main
4	doc_491521502104_item	2593138	et	2	main
viimasest	doc_491521502104_item	2593152	et	3	main
ole	doc_491521502104_item	2593177	et	4	main
eriti	doc_491521502104_item	2593178	et	3	main
vaid	doc_491521502104_item	2593183	et	3	main
kui	doc_491521502104_item	2593186	et	3	main
kooli	doc_491521502104_item	2593189	et	4	main
ta	doc_491521502104_item	2593192	et	4	main
puu	doc_491521502104_item	2593193	et	4	main
karin	doc_491521502104_item	2593200	et	4	main
püüdsime	doc_491521502104_item	2593229	et	3	main
ettevaatlikud	doc_491521502104_item	2593232	et	3	main
püüdes	doc_491521502104_item	2593234	et	4	main
mõjuvõimu	doc_491521502104_item	2593260	et	4	main
ja	doc_491521502104_item	2593261	et	3	main
avaldades	doc_491521502104_item	2593266	et	3	main
kask	doc_491521502104_item	2593268	et	3	main
vähendades	doc_491521502104_item	2593275	et	3	main
вас	doc_491521502104_item	2593305	et	2	main
эту	doc_491521502104_item	2593309	et	2	main
беседы	doc_491521502104_item	2593314	et	2	main
труда	doc_491521502104_item	2593320	et	2	main
вчера	doc_491521502104_item	2593322	et	2	main
alustatakse	doc_491521502104_item	2593340	et	3	main
4	doc_491521502104_item	2593342	et	2	main
sellele	doc_491521502104_item	2593346	et	4	main
räägitakse	doc_491521502104_item	2593352	et	3	main
ei	doc_491521502104_item	2593356	et	4	main
tööhõive	doc_491521502104_item	2593359	et	4	main
kui	doc_491521502104_item	2593368	et	3	main
kui	doc_491521502104_item	2593397	et	3	main
on	doc_491521502104_item	2593401	et	4	main
parem	doc_491521502104_item	2593402	et	4	main
õpilane	doc_491521502104_item	2593403	et	3	main
kui	doc_491521502104_item	2593404	et	3	main
võimalik	doc_491521502104_item	2593123	et	3	main
7	doc_491521502104_item	2593126	et	2	main
kohale	doc_491521502104_item	2593129	et	4	main
hilinemine	doc_491521502104_item	2593130	et	4	main
passita	doc_491521502104_item	2593132	et	4	main
huvita	doc_491521502104_item	2593137	et	4	main
5	doc_491521502104_item	2593140	et	2	main
igasuguste	doc_491521502104_item	2593141	et	3	main
6	doc_491521502104_item	2593143	et	2	main
et	doc_491521502104_item	2593151	et	3	main
saaks	doc_491521502104_item	2593154	et	3	main
keelde	doc_491521502104_item	2593159	et	4	main
näidis	doc_491521502104_item	2593160	et	4	main
saastatus	doc_491521502104_item	2593163	et	4	main
tugev	doc_491521502104_item	2593179	et	4	main
tööstuspiirkonnas	doc_491521502104_item	2593184	et	4	main
hommikul	doc_491521502104_item	2593188	et	3	main
läks	doc_491521502104_item	2593190	et	3	main
oravat	doc_491521502104_item	2593203	et	3	main
1	doc_491521502104_item	2593204	et	2	main
venelased	doc_491521502104_item	2593205	et	3	main
moodustavad	doc_491521502104_item	2593206	et	4	main
eesti	doc_491521502104_item	2593207	et	4	main
elanikkonnast	doc_491521502104_item	2593208	et	4	main
veidi	doc_491521502104_item	2593209	et	3	main
alla	doc_491521502104_item	2593210	et	3	main
kolmandiku	doc_491521502104_item	2593211	et	3	main
ja	doc_491521502104_item	2593212	et	3	main
esindavad	doc_491521502104_item	2593213	et	4	main
suurimat	doc_491521502104_item	2593214	et	3	main
kohalikku	doc_491521502104_item	2593215	et	4	main
rahvusvähemust	doc_491521502104_item	2593216	et	4	main
esindades	doc_491521502104_item	2593217	et	3	main
2	doc_491521502104_item	2593218	et	2	main
kui	doc_491521502104_item	2593219	et	3	main
me	doc_491521502104_item	2593220	et	4	main
keskkonna	doc_491521502104_item	2593174	et	3	main
saastatus	doc_491521502104_item	2593175	et	4	main
tunda	doc_491521502104_item	2593182	et	3	main
nägi	doc_491521502104_item	2593191	et	3	main
matkal	doc_491521502104_item	2593221	et	3	main
tarvitanud	doc_491521502104_item	2593224	et	4	main
me	doc_491521502104_item	2593225	et	4	main
asustusega	doc_491521502104_item	2593242	et	4	main
maa	doc_491521502104_item	2593243	et	4	main
võrreldes	doc_491521502104_item	2593244	et	3	main
omab	doc_491521502104_item	2593258	et	3	main
teatavat	doc_491521502104_item	2593259	et	4	main
inimorganismile	doc_491521502104_item	2593265	et	3	main
väsimuse	doc_491521502104_item	2593271	et	4	main
vajaduse	doc_491521502104_item	2593282	et	3	main
õppesõnastikku	doc_491521502104_item	2593286	et	4	main
достигают	doc_491521502104_item	2593288	et	2	main
временем	doc_491521502104_item	2593290	et	2	main
данные	doc_491521502104_item	2593292	et	2	main
семейном	doc_491521502104_item	2593294	et	2	main
представляли	doc_491521502104_item	2593296	et	2	main
3	doc_491521502104_item	2593298	et	2	main
суммы	doc_491521502104_item	2593300	et	2	main
начинают	doc_491521502104_item	2593302	et	2	main
выбрали	doc_491521502104_item	2593307	et	2	main
в	doc_491521502104_item	2593312	et	2	main
работодателем	doc_491521502104_item	2593316	et	2	main
olla	doc_491521502104_item	2593230	et	3	main
on	doc_491521502104_item	2593239	et	4	main
läks	doc_491521502104_item	2593247	et	3	main
tamme	doc_491521502104_item	2593248	et	4	main
ja	doc_491521502104_item	2593250	et	3	main
lootis	doc_491521502104_item	2593251	et	3	main
juurde	doc_491521502104_item	2593249	et	4	main
3	doc_491521502104_item	2593235	et	2	main
kui	doc_491521502104_item	2593236	et	3	main
võrrelda	doc_491521502104_item	2593237	et	4	main
hollandiga	doc_491521502104_item	2593238	et	4	main
4	doc_491521502104_item	2593245	et	2	main
sõjamees	doc_491521502104_item	2593246	et	4	main
avaldab	doc_491521502104_item	2593262	et	3	main
võtab	doc_491521502104_item	2593269	et	3	main
tõlkige	doc_491521502104_item	2593276	et	3	main
keelde	doc_491521502104_item	2593278	et	4	main
4	doc_491521502104_item	2593304	et	2	main
работу	doc_491521502104_item	2593310	et	2	main
с	doc_491521502104_item	2593315	et	2	main
условиях	doc_491521502104_item	2593319	et	2	main
6	doc_491521502104_item	2593321	et	2	main
безработица	doc_491521502104_item	2593326	et	2	main
eesmärgid	doc_491521502104_item	2593329	et	3	main
ajaga	doc_491521502104_item	2593331	et	3	main
perekonnaseisukohalt	doc_491521502104_item	2593334	et	4	main
5	doc_491521502104_item	2593348	et	2	main
käigus	doc_491521502104_item	2593350	et	4	main
6	doc_491521502104_item	2593354	et	2	main
minu	doc_491521502104_item	2593369	et	3	main
minu	doc_491521502104_item	2593371	et	3	main
tallinn	doc_491521502104_item	2593398	et	4	main
on	doc_491521502104_item	2593407	et	4	main
õpilane	doc_491521502104_item	2593409	et	3	main
4	doc_491521502104_item	2593412	et	2	main
on	doc_491521502104_item	2593425	et	4	main
meie	doc_491521502104_item	2593432	et	4	main
tänav	doc_491521502104_item	2593445	et	4	main
valige	doc_491521502104_item	2593446	et	3	main
teist	doc_491521502104_item	2593458	et	4	main
eksami	doc_491521502104_item	2593460	et	3	main
villane	doc_491521502104_item	2593471	et	4	main
ma	doc_491521502104_item	2593476	et	3	main
mäed	doc_491521502104_item	2593481	et	3	main
kunstnik	doc_491521502104_item	2593483	et	3	main
ostis	doc_491521502104_item	2593489	et	4	main
õhtu	doc_491521502104_item	2593490	et	4	main
õhtul	doc_491521502104_item	2593491	et	3	main
selle	doc_491521502104_item	2593252	et	4	main
abile	doc_491521502104_item	2593253	et	3	main
lootes	doc_491521502104_item	2593254	et	4	main
5	doc_491521502104_item	2593255	et	2	main
seda	doc_491521502104_item	2593263	et	3	main
6	doc_491521502104_item	2593267	et	2	main
ära	doc_491521502104_item	2593270	et	4	main
ja	doc_491521502104_item	2593272	et	3	main
vähendab	doc_491521502104_item	2593273	et	3	main
abil	doc_491521502104_item	2593281	et	4	main
kasutage	doc_491521502104_item	2593284	et	3	main
не	doc_491521502104_item	2593306	et	2	main
5	doc_491521502104_item	2593311	et	2	main
говорят	doc_491521502104_item	2593317	et	2	main
что	doc_491521502104_item	2593325	et	2	main
2	doc_491521502104_item	2593332	et	2	main
3	doc_491521502104_item	2593337	et	2	main
töötasusumma	doc_491521502104_item	2593338	et	4	main
hiljem	doc_491521502104_item	2593341	et	3	main
valitatud	doc_491521502104_item	2593345	et	4	main
tööle	doc_491521502104_item	2593347	et	3	main
eile	doc_491521502104_item	2593355	et	3	main
et	doc_491521502104_item	2593358	et	3	main
näidis	doc_491521502104_item	2593364	et	4	main
vanem	doc_491521502104_item	2593367	et	4	main
on	doc_491521502104_item	2593373	et	4	main
grammatika	doc_491521502104_item	2593415	et	4	main
raskem	doc_491521502104_item	2593426	et	4	main
kui	doc_491521502104_item	2593427	et	3	main
tänav	doc_491521502104_item	2593433	et	4	main
tänav	doc_491521502104_item	2593438	et	4	main
õige	doc_491521502104_item	2593447	et	4	main
kääne	doc_491521502104_item	2593448	et	3	main
vajadusel	doc_491521502104_item	2593450	et	3	main
kes	doc_491521502104_item	2593457	et	4	main
kohtun	doc_491521502104_item	2593464	et	3	main
oma	doc_491521502104_item	2593465	et	4	main
sugulased	doc_491521502104_item	2593466	et	3	main
kleit	doc_491521502104_item	2593469	et	3	main
on	doc_491521502104_item	2593470	et	4	main
tavaliselt	doc_491521502104_item	2593475	et	4	main
suvel	doc_491521502104_item	2593479	et	3	main
on	doc_491521502104_item	2593485	et	4	main
piletid	doc_491521502104_item	2593492	et	3	main
ilma	doc_491521502104_item	2593523	et	4	main
õpilastega	doc_491521502104_item	2593533	et	4	main
pange	doc_491521502104_item	2593534	et	4	main
omastavasse	doc_491521502104_item	2593540	et	4	main
vene	doc_491521502104_item	2593544	et	4	main
kliima	doc_491521502104_item	2593560	et	4	main
istuge	doc_491521502104_item	2593572	et	3	main
näod	doc_491521502104_item	2593575	et	3	main
eduard	doc_491521502104_item	2593577	et	4	main
vilde	doc_491521502104_item	2593578	et	4	main
rongiga	doc_491521502104_item	2593598	et	4	main
bussiga	doc_491521502104_item	2593600	et	3	main
4	doc_491521502104_item	2593604	et	2	main
6	doc_491521502104_item	2593610	et	2	main
7	doc_491521502104_item	2593613	et	2	main
lennukiga	doc_491521502104_item	2593615	et	3	main
lahkuma	doc_491521502104_item	2593621	et	3	main
ei	doc_491521502104_item	2593633	et	4	main
tahtma	doc_491521502104_item	2593634	et	3	main
kirjutama	doc_491521502104_item	2593641	et	3	main
selles	doc_491521502104_item	2593650	et	4	main
ma	doc_491521502104_item	2593652	et	3	main
tahan	doc_491521502104_item	2593655	et	3	main
kirja	doc_491521502104_item	2593657	et	4	main
oma	doc_491521502104_item	2593658	et	4	main
tuttavatele	doc_491521502104_item	2593659	et	3	main
ma	doc_491521502104_item	2593666	et	3	main
õpetama	doc_491521502104_item	2593668	et	3	main
удобств	doc_491521502104_item	2593685	et	2	main
этом	doc_491521502104_item	2593690	et	2	main
больших	doc_491521502104_item	2593696	et	2	main
будут	doc_491521502104_item	2593701	et	2	main
6	doc_491521502104_item	2593709	et	2	main
умений	doc_491521502104_item	2593715	et	2	main
люди	doc_491521502104_item	2593717	et	2	main
людей	doc_491521502104_item	2593721	et	2	main
этого	doc_491521502104_item	2593727	et	2	main
не	doc_491521502104_item	2593323	et	2	main
растет	doc_491521502104_item	2593327	et	2	main
saavutatakse	doc_491521502104_item	2593330	et	3	main
andmed	doc_491521502104_item	2593333	et	3	main
eile	doc_491521502104_item	2593336	et	3	main
määramine	doc_491521502104_item	2593339	et	4	main
ei	doc_491521502104_item	2593344	et	4	main
vestluse	doc_491521502104_item	2593349	et	3	main
öeldatud	doc_491521502104_item	2593357	et	4	main
näidise	doc_491521502104_item	2593362	et	3	main
olen	doc_491521502104_item	2593366	et	3	main
õde	doc_491521502104_item	2593370	et	4	main
õde	doc_491521502104_item	2593372	et	4	main
noorem	doc_491521502104_item	2593374	et	4	main
kui	doc_491521502104_item	2593375	et	3	main
mina	doc_491521502104_item	2593376	et	4	main
1	doc_491521502104_item	2593377	et	2	main
poeg	doc_491521502104_item	2593378	et	3	main
on	doc_491521502104_item	2593379	et	4	main
pikem	doc_491521502104_item	2593380	et	4	main
kui	doc_491521502104_item	2593381	et	3	main
isa	doc_491521502104_item	2593382	et	4	main
isa	doc_491521502104_item	2593383	et	4	main
on	doc_491521502104_item	2593384	et	4	main
lühem	doc_491521502104_item	2593385	et	4	main
kui	doc_491521502104_item	2593386	et	3	main
poeg	doc_491521502104_item	2593387	et	3	main
2	doc_491521502104_item	2593388	et	2	main
tallinn	doc_491521502104_item	2593389	et	4	main
on	doc_491521502104_item	2593390	et	4	main
suurem	doc_491521502104_item	2593391	et	4	main
kui	doc_491521502104_item	2593392	et	3	main
tartu	doc_491521502104_item	2593393	et	4	main
tartu	doc_491521502104_item	2593394	et	4	main
on	doc_491521502104_item	2593395	et	4	main
väiksem	doc_491521502104_item	2593396	et	4	main
kalle	doc_491521502104_item	2593406	et	3	main
heino	doc_491521502104_item	2593411	et	4	main
inglise	doc_491521502104_item	2593413	et	4	main
keele	doc_491521502104_item	2593414	et	4	main
inglise	doc_491521502104_item	2593428	et	4	main
on	doc_491521502104_item	2593434	et	4	main
puhtam	doc_491521502104_item	2593435	et	4	main
kui	doc_491521502104_item	2593436	et	3	main
tänav	doc_491521502104_item	2593440	et	4	main
mustam	doc_491521502104_item	2593442	et	4	main
kui	doc_491521502104_item	2593443	et	3	main
meie	doc_491521502104_item	2593444	et	4	main
hommikul	doc_491521502104_item	2593456	et	3	main
riiest	doc_491521502104_item	2593474	et	3	main
isa	doc_491521502104_item	2593488	et	4	main
teatrisse	doc_491521502104_item	2593494	et	3	main
või	doc_491521502104_item	2593539	et	4	main
laused	doc_491521502104_item	2593543	et	3	main
saabusid	doc_491521502104_item	2593547	et	4	main
suured	doc_491521502104_item	2593549	et	3	main
2	doc_491521502104_item	2593551	et	2	main
paljud	doc_491521502104_item	2593552	et	3	main
või	doc_491521502104_item	2593556	et	4	main
buss	doc_491521502104_item	2593557	et	3	main
on	doc_491521502104_item	2593581	et	4	main
või	doc_491521502104_item	2593599	et	4	main
noaga	doc_491521502104_item	2593606	et	3	main
nägudega	doc_491521502104_item	2593609	et	3	main
ta	doc_491521502104_item	2593616	et	4	main
tavaliselt	doc_491521502104_item	2593617	et	4	main
pidama	doc_491521502104_item	2593618	et	4	main
lahkuma	doc_491521502104_item	2593619	et	3	main
peab	doc_491521502104_item	2593620	et	4	main
halvem	doc_491521502104_item	2593408	et	4	main
kui	doc_491521502104_item	2593410	et	3	main
on	doc_491521502104_item	2593416	et	4	main
kergem	doc_491521502104_item	2593417	et	4	main
kui	doc_491521502104_item	2593418	et	3	main
eesti	doc_491521502104_item	2593419	et	4	main
keele	doc_491521502104_item	2593420	et	4	main
eesti	doc_491521502104_item	2593422	et	4	main
keele	doc_491521502104_item	2593429	et	4	main
sõle	doc_491521502104_item	2593439	et	3	main
on	doc_491521502104_item	2593441	et	4	main
ka	doc_491521502104_item	2593451	et	3	main
sooritas	doc_491521502104_item	2593459	et	3	main
viimane	doc_491521502104_item	2593461	et	3	main
täna	doc_491521502104_item	2593463	et	4	main
sugulastega	doc_491521502104_item	2593467	et	4	main
see	doc_491521502104_item	2593468	et	3	main
olen	doc_491521502104_item	2593477	et	3	main
suvi	doc_491521502104_item	2593478	et	3	main
puhanud	doc_491521502104_item	2593480	et	4	main
mägedes	doc_491521502104_item	2593482	et	3	main
kunstnikul	doc_491521502104_item	2593484	et	3	main
palju	doc_491521502104_item	2593486	et	4	main
tööd	doc_491521502104_item	2593487	et	4	main
teater	doc_491521502104_item	2593493	et	3	main
tulevad	doc_491521502104_item	2593496	et	4	main
kool	doc_491521502104_item	2593497	et	4	main
kodu	doc_491521502104_item	2593498	et	4	main
koolist	doc_491521502104_item	2593499	et	4	main
koju	doc_491521502104_item	2593500	et	3	main
kella	doc_491521502104_item	2593501	et	4	main
kolm	doc_491521502104_item	2593502	et	3	main
kolmeks	doc_491521502104_item	2593503	et	4	main
see	doc_491521502104_item	2593504	et	3	main
auto	doc_491521502104_item	2593505	et	4	main
sellesse	doc_491521502104_item	2593506	et	4	main
autosse	doc_491521502104_item	2593507	et	4	main
mahub	doc_491521502104_item	2593508	et	3	main
kuus	doc_491521502104_item	2593509	et	4	main
inimest	doc_491521502104_item	2593510	et	3	main
kes	doc_491521502104_item	2593511	et	4	main
suudab	doc_491521502104_item	2593512	et	3	main
tõlkida	doc_491521502104_item	2593513	et	3	main
teksti	doc_491521502104_item	2593514	et	4	main
itaalia	doc_491521502104_item	2593515	et	4	main
keel	doc_491521502104_item	2593516	et	4	main
vene	doc_491521502104_item	2593517	et	4	main
keel	doc_491521502104_item	2593518	et	4	main
itaalia	doc_491521502104_item	2593519	et	4	main
keelest	doc_491521502104_item	2593520	et	4	main
keelde	doc_491521502104_item	2593522	et	4	main
tuli	doc_491521502104_item	2593527	et	4	main
sulgudes	doc_491521502104_item	2593535	et	4	main
nii	doc_491521502104_item	2593573	et	3	main
must	doc_491521502104_item	2593582	et	4	main
mantel	doc_491521502104_item	2593583	et	3	main
mees	doc_491521502104_item	2593584	et	4	main
7	doc_491521502104_item	2593585	et	2	main
soome	doc_491521502104_item	2593586	et	3	main
on	doc_491521502104_item	2593587	et	4	main
võimalik	doc_491521502104_item	2593588	et	3	main
minna	doc_491521502104_item	2593589	et	3	main
nii	doc_491521502104_item	2593590	et	3	main
laev	doc_491521502104_item	2593591	et	3	main
1	doc_491521502104_item	2593594	et	2	main
grammatika	doc_491521502104_item	2593430	et	4	main
5	doc_491521502104_item	2593431	et	2	main
sõle	doc_491521502104_item	2593437	et	3	main
ning	doc_491521502104_item	2593449	et	3	main
tagasõna	doc_491521502104_item	2593452	et	4	main
tahan	doc_491521502104_item	2593453	et	3	main
puhata	doc_491521502104_item	2593454	et	4	main
hommik	doc_491521502104_item	2593455	et	3	main
viimasena	doc_491521502104_item	2593462	et	3	main
riie	doc_491521502104_item	2593472	et	3	main
villasest	doc_491521502104_item	2593473	et	4	main
lapsed	doc_491521502104_item	2593495	et	3	main
vene	doc_491521502104_item	2593521	et	4	main
õpetaja	doc_491521502104_item	2593526	et	4	main
klassi	doc_491521502104_item	2593529	et	4	main
olevad	doc_491521502104_item	2593536	et	4	main
käändesse	doc_491521502104_item	2593541	et	4	main
keelde	doc_491521502104_item	2593545	et	4	main
kohvrid	doc_491521502104_item	2593550	et	3	main
jutustuse	doc_491521502104_item	2593579	et	4	main
pealkiri	doc_491521502104_item	2593580	et	3	main
kui	doc_491521502104_item	2593592	et	3	main
lennuk	doc_491521502104_item	2593593	et	3	main
suurtega	doc_491521502104_item	2593595	et	3	main
kohvritega	doc_491521502104_item	2593596	et	3	main
palava	doc_491521502104_item	2593602	et	4	main
5	doc_491521502104_item	2593607	et	2	main
need	doc_491521502104_item	2593624	et	3	main
rääkima	doc_491521502104_item	2593627	et	3	main
taha	doc_491521502104_item	2593636	et	4	main
suitsetada	doc_491521502104_item	2593637	et	3	main
palju	doc_491521502104_item	2593638	et	4	main
te	doc_491521502104_item	2593639	et	4	main
hakkama	doc_491521502104_item	2593640	et	3	main
harjutust	doc_491521502104_item	2593644	et	4	main
meeldima	doc_491521502104_item	2593646	et	3	main
kirjutama	doc_491521502104_item	2593654	et	3	main
elama	doc_491521502104_item	2593662	et	3	main
tallinnas	doc_491521502104_item	2593665	et	4	main
oskama	doc_491521502104_item	2593667	et	3	main
времени	doc_491521502104_item	2593687	et	2	main
у	doc_491521502104_item	2593692	et	2	main
достижения	doc_491521502104_item	2593697	et	2	main
5	doc_491521502104_item	2593703	et	2	main
умения	doc_491521502104_item	2593707	et	2	main
много	doc_491521502104_item	2593713	et	2	main
лица	doc_491521502104_item	2593720	et	2	main
9	doc_491521502104_item	2593725	et	2	main
изменение	doc_491521502104_item	2593732	et	2	main
2	doc_491521502104_item	2593742	et	2	main
detailne	doc_491521502104_item	2593743	et	3	main
nõuab	doc_491521502104_item	2593747	et	3	main
saavutust	doc_491521502104_item	2593756	et	4	main
oskust	doc_491521502104_item	2593766	et	3	main
vestlema	doc_491521502104_item	2593767	et	3	main
töö	doc_491521502104_item	2593770	et	4	main
nõuab	doc_491521502104_item	2593771	et	3	main
puhkavad	doc_491521502104_item	2593777	et	4	main
näod	doc_491521502104_item	2593780	et	3	main
давления	doc_491521502104_item	2593823	et	2	main
случилось	doc_491521502104_item	2593828	et	2	main
я	doc_491521502104_item	2593832	et	2	main
6	doc_491521502104_item	2593836	et	2	main
в	doc_491521502104_item	2593840	et	2	main
обсуждение	doc_491521502104_item	2593844	et	2	main
решением	doc_491521502104_item	2593848	et	2	main
вносил	doc_491521502104_item	2593852	et	2	main
1	doc_491521502104_item	2593856	et	2	main
elu	doc_491521502104_item	2593868	et	4	main
me	doc_491521502104_item	2593888	et	4	main
koguaeg	doc_491521502104_item	2593889	et	3	main
on	doc_491521502104_item	2593895	et	4	main
8	doc_491521502104_item	2593900	et	2	main
ta	doc_491521502104_item	2593901	et	4	main
koguaeg	doc_491521502104_item	2593903	et	3	main
a	doc_491521502105_item	2593922	et	4	main
p	doc_491521502105_item	2593925	et	4	main
vaadates	doc_491521502105_item	2593931	et	3	main
leks	doc_491521502105_item	2593938	et	4	main
lugenud	doc_491521502105_item	2593944	et	4	main
teisikute	doc_491521502105_item	2593945	et	3	main
viga	doc_491521502104_item	2593524	et	4	main
veata	doc_491521502104_item	2593525	et	3	main
klass	doc_491521502104_item	2593528	et	3	main
uued	doc_491521502104_item	2593530	et	3	main
õpilased	doc_491521502104_item	2593531	et	3	main
uuete	doc_491521502104_item	2593532	et	4	main
sõnad	doc_491521502104_item	2593537	et	4	main
kaasaütlevasse	doc_491521502104_item	2593538	et	3	main
tõlkige	doc_491521502104_item	2593542	et	3	main
1turistid	doc_491521502104_item	2593546	et	3	main
lennujaama	doc_491521502104_item	2593548	et	4	main
eelistavad	doc_491521502104_item	2593553	et	4	main
reisida	doc_491521502104_item	2593554	et	3	main
rong	doc_491521502104_item	2593555	et	3	main
3	doc_491521502104_item	2593558	et	2	main
palav	doc_491521502104_item	2593559	et	4	main
kohanemine	doc_491521502104_item	2593561	et	4	main
nõuab	doc_491521502104_item	2593562	et	3	main
aega	doc_491521502104_item	2593563	et	4	main
4	doc_491521502104_item	2593564	et	2	main
oksi	doc_491521502104_item	2593565	et	4	main
saab	doc_491521502104_item	2593566	et	3	main
lõigata	doc_491521502104_item	2593567	et	4	main
terav	doc_491521502104_item	2593568	et	3	main
nuga	doc_491521502104_item	2593569	et	4	main
5	doc_491521502104_item	2593570	et	2	main
ärge	doc_491521502104_item	2593571	et	3	main
hapud	doc_491521502104_item	2593574	et	3	main
6	doc_491521502104_item	2593576	et	2	main
terava	doc_491521502104_item	2593605	et	3	main
hapude	doc_491521502104_item	2593608	et	3	main
musta	doc_491521502104_item	2593611	et	4	main
kell	doc_491521502104_item	2593622	et	3	main
rääkida	doc_491521502104_item	2593629	et	3	main
võõrkeelt	doc_491521502104_item	2593631	et	4	main
ta	doc_491521502104_item	2593632	et	4	main
meeldib	doc_491521502104_item	2593648	et	3	main
me	doc_491521502104_item	2593660	et	4	main
3	doc_491521502104_item	2593688	et	2	main
меня	doc_491521502104_item	2593693	et	2	main
4	doc_491521502104_item	2593698	et	2	main
у	doc_491521502104_item	2593704	et	2	main
нет	doc_491521502104_item	2593706	et	2	main
работа	doc_491521502104_item	2593711	et	2	main
отдыхают	doc_491521502104_item	2593718	et	2	main
были	doc_491521502104_item	2593722	et	2	main
самооценки	doc_491521502104_item	2593733	et	2	main
1	doc_491521502104_item	2593736	et	2	main
mugavuste	doc_491521502104_item	2593745	et	4	main
aega	doc_491521502104_item	2593748	et	4	main
mul	doc_491521502104_item	2593752	et	3	main
kolm	doc_491521502104_item	2593754	et	3	main
ole	doc_491521502104_item	2593765	et	4	main
6	doc_491521502104_item	2593768	et	2	main
see	doc_491521502104_item	2593769	et	3	main
inimese	doc_491521502104_item	2593786	et	4	main
enesehinnangu	doc_491521502104_item	2593792	et	3	main
вас	doc_491521502104_item	2593827	et	2	main
хотел	doc_491521502104_item	2593834	et	2	main
постоянно	doc_491521502104_item	2593838	et	2	main
7	doc_491521502104_item	2593842	et	2	main
самым	doc_491521502104_item	2593846	et	2	main
он	doc_491521502104_item	2593850	et	2	main
ясность	doc_491521502104_item	2593855	et	2	main
2	doc_491521502104_item	2593864	et	2	main
õppimine	doc_491521502104_item	2593865	et	4	main
kestas	doc_491521502104_item	2593866	et	4	main
tervce	doc_491521502104_item	2593867	et	4	main
kunagi	doc_491521502104_item	2593871	et	3	main
tekinud	doc_491521502104_item	2593873	et	4	main
juhtus	doc_491521502104_item	2593878	et	3	main
juhtunud	doc_491521502104_item	2593881	et	4	main
ei	doc_491521502104_item	2593884	et	4	main
tahtnud	doc_491521502104_item	2593885	et	4	main
õppima	doc_491521502104_item	2593886	et	3	main
6	doc_491521502104_item	2593887	et	2	main
targem	doc_491521502104_item	2593898	et	4	main
põimunud	doc_491521502105_item	2593921	et	4	main
mõnikord	doc_491521502105_item	2593933	et	3	main
nagu	doc_491521502105_item	2593936	et	3	main
taolist	doc_491521502105_item	2593941	et	3	main
näinud	doc_491521502105_item	2593942	et	4	main
l	doc_491521502105_item	2593946	et	4	main
eskseks	doc_491521502105_item	2593952	et	4	main
j	doc_491521502105_item	2593955	et	4	main
konflikt	doc_491521502105_item	2593957	et	3	main
teisiku	doc_491521502105_item	2593961	et	3	main
n	doc_491521502105_item	2593964	et	4	main
ka	doc_491521502105_item	2593967	et	3	main
teisik	doc_491521502105_item	2594000	et	3	main
püüab	doc_491521502105_item	2594001	et	3	main
olla	doc_491521502105_item	2594009	et	3	main
ust	doc_491521502105_item	2594014	et	4	main
lemuse	doc_491521502105_item	2594058	et	4	main
inimesed	doc_491521502105_item	2594067	et	3	main
ta	doc_491521502105_item	2594074	et	4	main
ära	doc_491521502105_item	2594086	et	4	main
i	doc_491521502105_item	2594092	et	4	main
huvitav	doc_491521502105_item	2594096	et	4	main
2	doc_491521502104_item	2593597	et	2	main
3	doc_491521502104_item	2593601	et	2	main
kliimaga	doc_491521502104_item	2593603	et	3	main
mantliga	doc_491521502104_item	2593612	et	3	main
laevaga	doc_491521502104_item	2593614	et	4	main
viis	doc_491521502104_item	2593623	et	4	main
võima	doc_491521502104_item	2593626	et	3	main
võivad	doc_491521502104_item	2593628	et	4	main
kolme	doc_491521502104_item	2593630	et	4	main
kirjutama	doc_491521502104_item	2593643	et	3	main
hakkame	doc_491521502104_item	2593663	et	3	main
в	doc_491521502104_item	2593689	et	2	main
три	doc_491521502104_item	2593695	et	2	main
достижения	doc_491521502104_item	2593700	et	2	main
вас	doc_491521502104_item	2593705	et	2	main
эта	doc_491521502104_item	2593710	et	2	main
разных	doc_491521502104_item	2593714	et	2	main
8	doc_491521502104_item	2593719	et	2	main
простые	doc_491521502104_item	2593724	et	2	main
человека	doc_491521502104_item	2593728	et	2	main
10	doc_491521502104_item	2593731	et	2	main
тяжело	doc_491521502104_item	2593735	et	2	main
ei	doc_491521502104_item	2593738	et	4	main
ole	doc_491521502104_item	2593739	et	4	main
olme	doc_491521502104_item	2593740	et	4	main
3	doc_491521502104_item	2593749	et	2	main
aastal	doc_491521502104_item	2593751	et	3	main
oli	doc_491521502104_item	2593753	et	3	main
4	doc_491521502104_item	2593757	et	2	main
tulevad	doc_491521502104_item	2593760	et	4	main
homme	doc_491521502104_item	2593761	et	3	main
inimesed	doc_491521502104_item	2593776	et	3	main
inimeste	doc_491521502104_item	2593779	et	3	main
silmad	doc_491521502104_item	2593787	et	4	main
on	doc_491521502104_item	2593788	et	4	main
оказываем	doc_491521502104_item	2593822	et	2	main
у	doc_491521502104_item	2593826	et	2	main
что	doc_491521502104_item	2593831	et	2	main
учиться	doc_491521502104_item	2593835	et	2	main
нуждались	doc_491521502104_item	2593839	et	2	main
разумным	doc_491521502104_item	2593847	et	2	main
в	doc_491521502104_item	2593853	et	2	main
sel	doc_491521502104_item	2593857	et	3	main
tööpäev	doc_491521502104_item	2593860	et	3	main
me	doc_491521502104_item	2593870	et	4	main
4	doc_491521502104_item	2593875	et	2	main
teil	doc_491521502104_item	2593877	et	4	main
on	doc_491521502104_item	2593880	et	4	main
nõuannet	doc_491521502104_item	2593891	et	4	main
kõige	doc_491521502104_item	2593897	et	4	main
essee	doc_491521502105_item	2593907	et	4	main
teema	doc_491521502105_item	2593924	et	4	main
oliitika	doc_491521502105_item	2593926	et	4	main
a	doc_491521502105_item	2593928	et	4	main
t	doc_491521502105_item	2593934	et	4	main
aset	doc_491521502105_item	2593996	et	3	main
leidnud	doc_491521502105_item	2593997	et	4	main
olukord	doc_491521502105_item	2593998	et	3	main
k	doc_491521502105_item	2594005	et	4	main
ja	doc_491521502105_item	2594010	et	3	main
j	doc_491521502105_item	2594013	et	4	main
e	doc_491521502105_item	2594015	et	4	main
meeldiv	doc_491521502105_item	2594017	et	4	main
filmis	doc_491521502105_item	2594018	et	4	main
oli	doc_491521502105_item	2594019	et	3	main
hästi	doc_491521502105_item	2594020	et	3	main
niiöelda	doc_491521502105_item	2594025	et	4	main
peamise	doc_491521502105_item	2594026	et	3	main
pidi	doc_491521502105_item	2594036	et	4	main
es	doc_491521502105_item	2594043	et	4	main
ta	doc_491521502105_item	2594044	et	4	main
katsumus	doc_491521502105_item	2594051	et	3	main
ära	doc_491521502105_item	2594062	et	4	main
et	doc_491521502105_item	2594069	et	3	main
veidi	doc_491521502105_item	2594077	et	3	main
har	doc_491521502105_item	2594079	et	4	main
uuе	doc_491521502105_item	2594084	et	2	main
tegelane	doc_491521502105_item	2594089	et	3	main
e	doc_491521502105_item	2594091	et	4	main
tekitanud	doc_491521502105_item	2594093	et	4	main
pigem	doc_491521502105_item	2594094	et	3	main
oli	doc_491521502105_item	2594095	et	3	main
tüdrukud	doc_491521502104_item	2593625	et	3	main
suitsetama	doc_491521502104_item	2593635	et	4	main
hakkate	doc_491521502104_item	2593642	et	3	main
talle	doc_491521502104_item	2593645	et	4	main
töötama	doc_491521502104_item	2593647	et	3	main
töötada	doc_491521502104_item	2593649	et	3	main
ettevõttes	doc_491521502104_item	2593651	et	3	main
tahtma	doc_491521502104_item	2593653	et	3	main
kirjutada	doc_491521502104_item	2593656	et	3	main
hakkama	doc_491521502104_item	2593661	et	3	main
elama	doc_491521502104_item	2593664	et	3	main
oskan	doc_491521502104_item	2593669	et	3	main
õpetada	doc_491521502104_item	2593670	et	3	main
võõrkeelt	doc_491521502104_item	2593671	et	4	main
välismaalastele	doc_491521502104_item	2593672	et	4	main
tõlkige	doc_491521502104_item	2593673	et	3	main
laused	doc_491521502104_item	2593674	et	3	main
eesti	doc_491521502104_item	2593675	et	4	main
keelde	doc_491521502104_item	2593676	et	4	main
1здесь	doc_491521502104_item	2593677	et	2	main
нет	doc_491521502104_item	2593678	et	2	main
бытовых	doc_491521502104_item	2593679	et	2	main
удобств	doc_491521502104_item	2593680	et	2	main
2	doc_491521502104_item	2593681	et	2	main
подробное	doc_491521502104_item	2593682	et	2	main
описание	doc_491521502104_item	2593683	et	2	main
бытовых	doc_491521502104_item	2593684	et	2	main
требует	doc_491521502104_item	2593686	et	2	main
году	doc_491521502104_item	2593691	et	2	main
было	doc_491521502104_item	2593694	et	2	main
большие	doc_491521502104_item	2593699	et	2	main
завтра	doc_491521502104_item	2593702	et	2	main
общаться	doc_491521502104_item	2593708	et	2	main
требует	doc_491521502104_item	2593712	et	2	main
7	doc_491521502104_item	2593716	et	2	main
довольно	doc_491521502104_item	2593723	et	2	main
глаза	doc_491521502104_item	2593726	et	2	main
робкие	doc_491521502104_item	2593730	et	2	main
mugavust	doc_491521502104_item	2593741	et	4	main
kirjeldus	doc_491521502104_item	2593746	et	4	main
sellel	doc_491521502104_item	2593750	et	4	main
suurt	doc_491521502104_item	2593755	et	3	main
saavutused	doc_491521502104_item	2593759	et	4	main
5	doc_491521502104_item	2593762	et	2	main
palju	doc_491521502104_item	2593772	et	4	main
7	doc_491521502104_item	2593775	et	2	main
päris	doc_491521502104_item	2593782	et	4	main
lihtsad	doc_491521502104_item	2593783	et	3	main
väga	doc_491521502104_item	2593789	et	3	main
kardsad	doc_491521502104_item	2593790	et	4	main
toimub	doc_491521502104_item	2593794	et	3	main
raskelt	doc_491521502104_item	2593795	et	4	main
tõlkige	doc_491521502104_item	2593796	et	3	main
eesti	doc_491521502104_item	2593797	et	4	main
keelde	doc_491521502104_item	2593798	et	4	main
kas	doc_491521502104_item	2593799	et	3	main
liht-	doc_491521502104_item	2593800	et	3	main
või	doc_491521502104_item	2593801	et	4	main
täismineviku	doc_491521502104_item	2593802	et	3	main
abil	doc_491521502104_item	2593803	et	4	main
1в	doc_491521502104_item	2593804	et	2	main
то	doc_491521502104_item	2593805	et	2	main
время	doc_491521502104_item	2593806	et	2	main
каждый	doc_491521502104_item	2593807	et	2	main
рабочий	doc_491521502104_item	2593808	et	2	main
начинался	doc_491521502104_item	2593810	et	2	main
рано	doc_491521502104_item	2593811	et	2	main
день	doc_491521502104_item	2593809	et	2	main
утром	doc_491521502104_item	2593812	et	2	main
2	doc_491521502104_item	2593813	et	2	main
обучение	doc_491521502104_item	2593814	et	2	main
продолжалось	doc_491521502104_item	2593815	et	2	main
всю	doc_491521502104_item	2593816	et	2	main
жизнь	doc_491521502104_item	2593817	et	2	main
мы	doc_491521502104_item	2593819	et	2	main
3	doc_491521502104_item	2593818	et	2	main
никогда	doc_491521502104_item	2593820	et	2	main
очень	doc_491521502104_item	2593729	et	2	main
проходит	doc_491521502104_item	2593734	et	2	main
siin	doc_491521502104_item	2593737	et	4	main
olme	doc_491521502104_item	2593744	et	4	main
suured	doc_491521502104_item	2593758	et	3	main
teil	doc_491521502104_item	2593763	et	4	main
ei	doc_491521502104_item	2593764	et	4	main
erinevaid	doc_491521502104_item	2593773	et	4	main
oskusi	doc_491521502104_item	2593774	et	3	main
8	doc_491521502104_item	2593778	et	2	main
olid	doc_491521502104_item	2593781	et	4	main
9	doc_491521502104_item	2593784	et	2	main
selle	doc_491521502104_item	2593785	et	4	main
10	doc_491521502104_item	2593791	et	2	main
muutumine	doc_491521502104_item	2593793	et	4	main
не	doc_491521502104_item	2593821	et	2	main
что	doc_491521502104_item	2593825	et	2	main
5	doc_491521502104_item	2593829	et	2	main
не	doc_491521502104_item	2593833	et	2	main
совете	doc_491521502104_item	2593841	et	2	main
бывало	doc_491521502104_item	2593845	et	2	main
всегда	doc_491521502104_item	2593851	et	2	main
дело	doc_491521502104_item	2593854	et	2	main
3	doc_491521502104_item	2593869	et	2	main
mis	doc_491521502104_item	2593876	et	4	main
5	doc_491521502104_item	2593879	et	2	main
et	doc_491521502104_item	2593882	et	3	main
ma	doc_491521502104_item	2593883	et	3	main
läbirääkimine	doc_491521502104_item	2593894	et	3	main
otsus	doc_491521502104_item	2593899	et	3	main
on	doc_491521502104_item	2593902	et	4	main
toonud	doc_491521502104_item	2593904	et	4	main
asjasse	doc_491521502104_item	2593905	et	3	main
selgust	doc_491521502104_item	2593906	et	4	main
leninid	doc_491521502105_item	2593909	et	4	main
n	doc_491521502105_item	2593911	et	4	main
küllaltki	doc_491521502105_item	2593912	et	4	main
j	doc_491521502105_item	2593927	et	4	main
huumor	doc_491521502105_item	2593929	et	3	main
tekkis	doc_491521502105_item	2593932	et	3	main
unne	doc_491521502105_item	2593935	et	3	main
o	doc_491521502105_item	2593937	et	4	main
varem	doc_491521502105_item	2593939	et	4	main
midagi	doc_491521502105_item	2593940	et	4	main
oomise	doc_491521502105_item	2593947	et	4	main
idee	doc_491521502105_item	2593948	et	4	main
ning	doc_491521502105_item	2593950	et	3	main
teemaks	doc_491521502105_item	2593953	et	4	main
unev	doc_491521502105_item	2593956	et	4	main
päris	doc_491521502105_item	2593958	et	4	main
tegelase	doc_491521502105_item	2593959	et	3	main
ja	doc_491521502105_item	2593960	et	3	main
o	doc_491521502105_item	2593963	et	4	main
mil	doc_491521502105_item	2593999	et	4	main
inimesest	doc_491521502105_item	2594002	et	3	main
ehastab	doc_491521502105_item	2594006	et	4	main
rivaalitseda	doc_491521502105_item	2594011	et	3	main
väl	doc_491521502105_item	2594021	et	4	main
vassili	doc_491521502105_item	2594029	et	4	main
ebakindlus	doc_491521502105_item	2594030	et	4	main
ta	doc_491521502105_item	2594035	et	4	main
isikut	doc_491521502105_item	2594041	et	3	main
k	doc_491521502105_item	2594042	et	4	main
mamoodi	doc_491521502105_item	2594050	et	4	main
uudab	doc_491521502105_item	2594055	et	4	main
p	doc_491521502105_item	2594063	et	4	main
lähedased	doc_491521502105_item	2594066	et	3	main
käitumine	doc_491521502105_item	2594075	et	4	main
imelik	doc_491521502105_item	2594078	et	3	main
j	doc_491521502105_item	2594080	et	4	main
nad	doc_491521502105_item	2594082	et	3	main
vastikustunnet	doc_491521502105_item	2594087	et	4	main
teda	doc_491521502105_item	2594097	et	4	main
j	doc_491521502105_item	2594098	et	4	main
älgida	doc_491521502105_item	2594099	et	4	main
kuna	doc_491521502105_item	2594100	et	3	main
oskus	doc_491521502105_item	2594132	et	3	main
ärgatavalt	doc_491521502105_item	2594135	et	4	main
kui	doc_491521502105_item	2594137	et	3	main
ü	doc_491521502105_item	2594145	et	4	main
kesküla	doc_491521502105_item	2594148	et	4	main
alati	doc_491521502105_item	2594168	et	4	main
4	doc_491521502104_item	2593824	et	2	main
случалось	doc_491521502104_item	2593830	et	2	main
мы	doc_491521502104_item	2593837	et	2	main
спокойное	doc_491521502104_item	2593843	et	2	main
8	doc_491521502104_item	2593849	et	2	main
ajal	doc_491521502104_item	2593858	et	4	main
iga	doc_491521502104_item	2593859	et	4	main
algas	doc_491521502104_item	2593861	et	3	main
vara	doc_491521502104_item	2593862	et	4	main
hommikul	doc_491521502104_item	2593863	et	3	main
ei	doc_491521502104_item	2593872	et	4	main
survet	doc_491521502104_item	2593874	et	3	main
vajasime	doc_491521502104_item	2593890	et	3	main
7	doc_491521502104_item	2593892	et	2	main
rahulik	doc_491521502104_item	2593893	et	3	main
olnud	doc_491521502104_item	2593896	et	4	main
minu	doc_491521502105_item	2593908	et	3	main
o	doc_491521502105_item	2593910	et	4	main
o	doc_491521502105_item	2593913	et	4	main
mapärane	doc_491521502105_item	2593914	et	4	main
film	doc_491521502105_item	2593915	et	3	main
milles	doc_491521502105_item	2593916	et	3	main
o	doc_491521502105_item	2593917	et	4	main
n	doc_491521502105_item	2593918	et	4	main
o	doc_491521502105_item	2593919	et	4	main
mavahel	doc_491521502105_item	2593920	et	4	main
rmastuse	doc_491521502105_item	2593923	et	4	main
seda	doc_491521502105_item	2593930	et	3	main
või	doc_491521502105_item	2593943	et	4	main
ku	doc_491521502105_item	2593954	et	4	main
l	doc_491521502105_item	2593965	et	4	main
eidnud	doc_491521502105_item	2593966	et	4	main
nii	doc_491521502105_item	2593970	et	3	main
mõneski	doc_491521502105_item	2593971	et	3	main
filmis	doc_491521502105_item	2593972	et	4	main
j	doc_491521502105_item	2593973	et	4	main
a	doc_491521502105_item	2593974	et	4	main
võimalik	doc_491521502105_item	2593976	et	3	main
et	doc_491521502105_item	2593977	et	3	main
raamatus	doc_491521502105_item	2593975	et	4	main
a	doc_491521502105_item	2593978	et	4	main
j	doc_491521502105_item	2593979	et	4	main
s	doc_491521502105_item	2593981	et	4	main
aloolistel	doc_491521502105_item	2593980	et	4	main
ündmustel	doc_491521502105_item	2593982	et	4	main
põhinevad	doc_491521502105_item	2593983	et	4	main
filmid	doc_491521502105_item	2593984	et	4	main
vahendavad	doc_491521502105_item	2593985	et	4	main
vaata	doc_491521502105_item	2593986	et	4	main
j	doc_491521502105_item	2593987	et	4	main
askonnale	doc_491521502105_item	2593988	et	4	main
neid	doc_491521502105_item	2593989	et	4	main
fakte	doc_491521502105_item	2593990	et	3	main
mis	doc_491521502105_item	2593991	et	4	main
o	doc_491521502105_item	2593992	et	4	main
n	doc_491521502105_item	2593993	et	4	main
tõesti	doc_491521502105_item	2593994	et	3	main
kasutamine	doc_491521502105_item	2593949	et	4	main
k	doc_491521502105_item	2593951	et	4	main
vahel	doc_491521502105_item	2593962	et	4	main
j	doc_491521502105_item	2593968	et	4	main
astust	doc_491521502105_item	2593969	et	4	main
ta	doc_491521502105_item	2594004	et	4	main
igati	doc_491521502105_item	2594007	et	3	main
pole	doc_491521502105_item	2594012	et	3	main
riti	doc_491521502105_item	2594016	et	4	main
lenini	doc_491521502105_item	2594027	et	4	main
lenini	doc_491521502105_item	2594037	et	4	main
kodus	doc_491521502105_item	2594038	et	4	main
tegelikult	doc_491521502105_item	2594045	et	4	main
polnud	doc_491521502105_item	2594046	et	3	main
see	doc_491521502105_item	2594047	et	3	main
oli	doc_491521502105_item	2594048	et	3	main
kas	doc_491521502105_item	2594052	et	3	main
s	doc_491521502105_item	2594054	et	4	main
oma	doc_491521502105_item	2594056	et	4	main
etta	doc_491521502105_item	2594064	et	4	main
leninile	doc_491521502105_item	2594065	et	4	main
selgus	doc_491521502105_item	2594068	et	4	main
lguses	doc_491521502105_item	2594072	et	4	main
usid	doc_491521502105_item	2594081	et	4	main
peagi	doc_491521502105_item	2594083	et	4	main
leniniga	doc_491521502105_item	2594085	et	4	main
see	doc_491521502105_item	2594088	et	3	main
eninite	doc_491521502105_item	2594122	et	4	main
koolis	doc_491521502105_item	2594123	et	4	main
oli	doc_491521502105_item	2594133	et	3	main
kuid	doc_491521502105_item	2594139	et	4	main
sna	doc_491521502105_item	2594146	et	4	main
j	doc_491521502105_item	2594149	et	4	main
lenini	doc_491521502105_item	2594151	et	4	main
mitte	doc_491521502105_item	2594167	et	3	main
nei1e	doc_491521502105_item	2594169	et	4	main
oli	doc_491521502105_item	2594170	et	3	main
uhke	doc_491521502105_item	2594181	et	4	main
kavala	doc_491521502105_item	2594182	et	3	main
j	doc_491521502105_item	2594183	et	4	main
ükskõik	doc_491521502105_item	2594189	et	3	main
oli	doc_491521502105_item	2594196	et	3	main
esti	doc_491521502105_item	2594199	et	4	main
e	doc_491521502105_item	2594206	et	4	main
lluviimise	doc_491521502105_item	2594207	et	4	main
lenini	doc_491521502105_item	2594222	et	4	main
samas	doc_491521502105_item	2594229	et	4	main
teavitas	doc_491521502105_item	2594230	et	4	main
k	doc_491521502105_item	2594234	et	4	main
omakorda	doc_491521502105_item	2594236	et	3	main
тета	doc_491521502105_item	2594242	et	2	main
lenin	doc_491521502105_item	2594245	et	4	main
nimelt	doc_491521502105_item	2594254	et	4	main
j	doc_491521502105_item	2594257	et	4	main
tagaplaanile	doc_491521502105_item	2594261	et	4	main
vassili	doc_491521502105_item	2594263	et	4	main
soovitatud	doc_491521502105_item	2594282	et	4	main
nõuannete	doc_491521502105_item	2594283	et	3	main
kohaselt	doc_491521502105_item	2594284	et	4	main
nii	doc_491521502105_item	2594285	et	3	main
nagu	doc_491521502105_item	2594286	et	3	main
j	doc_491521502105_item	2594290	et	4	main
j	doc_491521502105_item	2594293	et	4	main
näitle	doc_491521502105_item	2594300	et	4	main
a	doc_491521502105_item	2594302	et	4	main
oli	doc_491521502105_item	2594304	et	3	main
j	doc_491521502105_item	2594306	et	4	main
kuna	doc_491521502105_item	2594308	et	3	main
t	doc_491521502105_item	2594326	et	4	main
ning	doc_491521502105_item	2594336	et	3	main
käitub	doc_491521502105_item	2594337	et	3	main
mõttes	doc_491521502105_item	2594344	et	3	main
a	doc_491521502105_item	2594351	et	4	main
omavahel	doc_491521502105_item	2594353	et	3	main
kõrvutades	doc_491521502105_item	2594354	et	3	main
leiame	doc_491521502105_item	2594355	et	3	main
äranägemise	doc_491521502105_item	2594365	et	3	main
paistab	doc_491521502105_item	2594379	et	3	main
nende	doc_491521502105_item	2594380	et	4	main
a	doc_491521502105_item	2594425	et	4	main
j	doc_491521502105_item	2594426	et	4	main
aloolist	doc_491521502105_item	2594427	et	4	main
kunagi	doc_491521502105_item	2593995	et	3	main
keda	doc_491521502105_item	2594003	et	4	main
ülе	doc_491521502105_item	2594008	et	2	main
j	doc_491521502105_item	2594022	et	4	main
a	doc_491521502105_item	2594023	et	4	main
toodud	doc_491521502105_item	2594024	et	4	main
teisiku	doc_491521502105_item	2594028	et	3	main
j	doc_491521502105_item	2594031	et	4	main
a	doc_491521502105_item	2594032	et	4	main
hirm	doc_491521502105_item	2594033	et	3	main
kui	doc_491521502105_item	2594034	et	3	main
k	doc_491521502105_item	2594039	et	4	main
ehastama	doc_491521502105_item	2594040	et	4	main
o	doc_491521502105_item	2594049	et	4	main
ta	doc_491521502105_item	2594053	et	4	main
o	doc_491521502105_item	2594057	et	4	main
j	doc_491521502105_item	2594059	et	4	main
a	doc_491521502105_item	2594060	et	4	main
käitumisega	doc_491521502105_item	2594061	et	4	main
kuigi	doc_491521502105_item	2594070	et	3	main
a	doc_491521502105_item	2594071	et	4	main
tundus	doc_491521502105_item	2594073	et	3	main
teistele	doc_491521502105_item	2594076	et	4	main
minus	doc_491521502105_item	2594090	et	3	main
iseloomult	doc_491521502105_item	2594101	et	3	main
tundus	doc_491521502105_item	2594102	et	3	main
ta	doc_491521502105_item	2594103	et	4	main
olevat	doc_491521502105_item	2594104	et	4	main
ü	doc_491521502105_item	2594105	et	4	main
sna	doc_491521502105_item	2594106	et	4	main
tagasihoidlik	doc_491521502105_item	2594107	et	3	main
ja	doc_491521502105_item	2594108	et	3	main
teiste	doc_491521502105_item	2594109	et	4	main
poolt	doc_491521502105_item	2594110	et	4	main
mõneti	doc_491521502105_item	2594111	et	3	main
manipuleeritav	doc_491521502105_item	2594112	et	4	main
mis	doc_491521502105_item	2594113	et	4	main
sundis	doc_491521502105_item	2594114	et	3	main
talle	doc_491521502105_item	2594115	et	4	main
natuke	doc_491521502105_item	2594116	et	4	main
kaasa	doc_491521502105_item	2594117	et	4	main
tundma	doc_491521502105_item	2594118	et	3	main
samas	doc_491521502105_item	2594119	et	4	main
oli	doc_491521502105_item	2594120	et	3	main
l	doc_491521502105_item	2594121	et	4	main
k	doc_491521502105_item	2594124	et	4	main
a	doc_491521502105_item	2594125	et	4	main
kehvem	doc_491521502105_item	2594136	et	4	main
vassilil	doc_491521502105_item	2594138	et	4	main
o	doc_491521502105_item	2594157	et	4	main
lid	doc_491521502105_item	2594158	et	4	main
nad	doc_491521502105_item	2594159	et	3	main
positiivsed	doc_491521502105_item	2594160	et	3	main
ning	doc_491521502105_item	2594161	et	3	main
toredad	doc_491521502105_item	2594162	et	3	main
tegelased	doc_491521502105_item	2594163	et	3	main
aga	doc_491521502105_item	2594164	et	3	main
keeruline	doc_491521502105_item	2594171	et	4	main
hea	doc_491521502105_item	2594174	et	4	main
mida	doc_491521502105_item	2594190	et	4	main
oma	doc_491521502105_item	2594192	et	4	main
tеmа	doc_491521502105_item	2594194	et	2	main
suur-	doc_491521502105_item	2594197	et	3	main
l	doc_491521502105_item	2594200	et	4	main
oomine	doc_491521502105_item	2594201	et	4	main
m	doc_491521502105_item	2594134	et	4	main
nad	doc_491521502105_item	2594140	et	3	main
k	doc_491521502105_item	2594142	et	4	main
o	doc_491521502105_item	2594143	et	4	main
lid	doc_491521502105_item	2594144	et	4	main
ambitsioonikad	doc_491521502105_item	2594147	et	4	main
vahel	doc_491521502105_item	2594156	et	4	main
augeltki	doc_491521502105_item	2594166	et	3	main
kindlat	doc_491521502105_item	2594173	et	3	main
tundus	doc_491521502105_item	2594180	et	3	main
tegi	doc_491521502105_item	2594188	et	4	main
tahtmist	doc_491521502105_item	2594193	et	4	main
kinnisideeks	doc_491521502105_item	2594195	et	3	main
nimel	doc_491521502105_item	2594208	et	3	main
oli	doc_491521502105_item	2594209	et	3	main
kesküla	doc_491521502105_item	2594210	et	4	main
valmis	doc_491521502105_item	2594211	et	4	main
sõdima	doc_491521502105_item	2594212	et	3	main
kahel	doc_491521502105_item	2594213	et	4	main
rindel	doc_491521502105_item	2594214	et	3	main
ü	doc_491521502105_item	2594215	et	4	main
he1t	doc_491521502105_item	2594216	et	4	main
poolt	doc_491521502105_item	2594217	et	4	main
toetas	doc_491521502105_item	2594218	et	3	main
enamlasi	doc_491521502105_item	2594219	et	3	main
ning	doc_491521502105_item	2594220	et	3	main
selliseid	doc_491521502105_item	2594126	et	4	main
õpilasi	doc_491521502105_item	2594127	et	3	main
kelle	doc_491521502105_item	2594128	et	4	main
päris	doc_491521502105_item	2594129	et	4	main
lenini	doc_491521502105_item	2594130	et	4	main
matkimise	doc_491521502105_item	2594131	et	4	main
kõi	doc_491521502105_item	2594141	et	4	main
a	doc_491521502105_item	2594150	et	4	main
kohta	doc_491521502105_item	2594152	et	4	main
võib	doc_491521502105_item	2594153	et	3	main
öеlда	doc_491521502105_item	2594154	et	2	main
et	doc_491521502105_item	2594155	et	3	main
k	doc_491521502105_item	2594165	et	4	main
või	doc_491521502105_item	2594175	et	4	main
halva	doc_491521502105_item	2594176	et	4	main
tegelase	doc_491521502105_item	2594177	et	3	main
mainet	doc_491521502105_item	2594178	et	4	main
a	doc_491521502105_item	2594184	et	4	main
o	doc_491521502105_item	2594185	et	4	main
makasupüüdlikuna	doc_491521502105_item	2594186	et	4	main
e	doc_491521502105_item	2594198	et	4	main
a	doc_491521502105_item	2594228	et	4	main
nende	doc_491521502105_item	2594232	et	4	main
vale	doc_491521502105_item	2594244	et	4	main
vassili	doc_491521502105_item	2594246	et	4	main
oli	doc_491521502105_item	2594247	et	3	main
niiöelda	doc_491521502105_item	2594248	et	4	main
ätta	doc_491521502105_item	2594258	et	4	main
ehastanud	doc_491521502105_item	2594299	et	4	main
s	doc_491521502105_item	2594315	et	4	main
tõetruult	doc_491521502105_item	2594319	et	4	main
kes	doc_491521502105_item	2594329	et	4	main
olukorrale	doc_491521502105_item	2594333	et	3	main
meelt	doc_491521502105_item	2594335	et	4	main
enda	doc_491521502105_item	2594339	et	4	main
huve	doc_491521502105_item	2594340	et	3	main
arvestades	doc_491521502105_item	2594341	et	3	main
egoist	doc_491521502105_item	2594345	et	3	main
kõigutamatu	doc_491521502105_item	2594347	et	4	main
j	doc_491521502105_item	2594358	et	4	main
koostöö	doc_491521502105_item	2594381	et	4	main
l	doc_491521502105_item	2594382	et	4	main
aabuvat	doc_491521502105_item	2594383	et	4	main
partnerlusele	doc_491521502105_item	2594387	et	3	main
paremini	doc_491521502105_item	2594417	et	4	main
mõista	doc_491521502105_item	2594418	et	4	main
tuleb	doc_491521502105_item	2594419	et	3	main
teada	doc_491521502105_item	2594420	et	3	main
ning	doc_491521502105_item	2594423	et	3	main
oli	doc_491521502105_item	2594431	et	3	main
ning	doc_491521502105_item	2594445	et	3	main
oli	doc_491521502105_item	2594449	et	3	main
iis	doc_491521502105_item	2594452	et	4	main
rahvastest	doc_491521502105_item	2594456	et	4	main
sõ	doc_491521502105_item	2594460	et	4	main
j	doc_491521502105_item	2594493	et	4	main
et	doc_491521502105_item	2594499	et	3	main
abiga	doc_491521502105_item	2594501	et	3	main
nii	doc_491521502105_item	2594503	et	3	main
filmis	doc_491521502105_item	2594508	et	4	main
kui	doc_491521502105_item	2594512	et	3	main
see	doc_491521502105_item	2594525	et	3	main
j	doc_491521502105_item	2594532	et	4	main
mõtlema	doc_491521502105_item	2594534	et	3	main
igapäevaelus	doc_491521502105_item	2594555	et	4	main
põhiidee	doc_491521502105_item	2594557	et	4	main
seisneski	doc_491521502105_item	2594558	et	3	main
ollakse	doc_491521502105_item	2594591	et	3	main
e	doc_491521502105_item	2594603	et	4	main
kohti	doc_491521502105_item	2594608	et	4	main
panid	doc_491521502105_item	2594610	et	4	main
muigama	doc_491521502105_item	2594611	et	3	main
tundus	doc_491521502105_item	2594612	et	3	main
et	doc_491521502105_item	2594613	et	3	main
filmi	doc_491521502105_item	2594614	et	4	main
natuke	doc_491521502105_item	2594619	et	4	main
omistada	doc_491521502105_item	2594172	et	3	main
kesküla	doc_491521502105_item	2594179	et	4	main
kes	doc_491521502105_item	2594187	et	4	main
saavutamaks	doc_491521502105_item	2594191	et	3	main
a	doc_491521502105_item	2594203	et	4	main
selle	doc_491521502105_item	2594204	et	4	main
plaani	doc_491521502105_item	2594205	et	4	main
oli	doc_491521502105_item	2594221	et	3	main
tegevusest	doc_491521502105_item	2594233	et	4	main
es	doc_491521502105_item	2594235	et	4	main
abiks	doc_491521502105_item	2594249	et	3	main
läbimõeldud	doc_491521502105_item	2594250	et	4	main
soovis	doc_491521502105_item	2594255	et	4	main
päris	doc_491521502105_item	2594259	et	4	main
asti	doc_491521502105_item	2594291	et	4	main
va	doc_491521502105_item	2594292	et	3	main
alikuks	doc_491521502105_item	2594294	et	4	main
p	doc_491521502105_item	2594295	et	4	main
eab	doc_491521502105_item	2594296	et	4	main
k	doc_491521502105_item	2594298	et	4	main
j	doc_491521502105_item	2594301	et	4	main
ta	doc_491521502105_item	2594309	et	4	main
isse	doc_491521502105_item	2594316	et	4	main
oma	doc_491521502105_item	2594323	et	4	main
tegelast	doc_491521502105_item	2594324	et	3	main
undus	doc_491521502105_item	2594327	et	4	main
isikuna	doc_491521502105_item	2594328	et	3	main
muudab	doc_491521502105_item	2594330	et	3	main
m	doc_491521502105_item	2594342	et	4	main
oma	doc_491521502105_item	2594364	et	4	main
j	doc_491521502105_item	2594372	et	4	main
eelkõige	doc_491521502105_item	2594374	et	3	main
arvestamata	doc_491521502105_item	2594376	et	4	main
ust	doc_491521502105_item	2594385	et	4	main
j	doc_491521502105_item	2594202	et	4	main
j	doc_491521502105_item	2594224	et	4	main
j	doc_491521502105_item	2594227	et	4	main
sakslasi	doc_491521502105_item	2594231	et	3	main
toetasid	doc_491521502105_item	2594237	et	4	main
õõnestustööd	doc_491521502105_item	2594240	et	4	main
venemaal	doc_491521502105_item	2594241	et	4	main
koolitatud	doc_491521502105_item	2594243	et	4	main
e	doc_491521502105_item	2594252	et	4	main
lluviimisel	doc_491521502105_item	2594253	et	4	main
kesküla	doc_491521502105_item	2594256	et	4	main
lenini	doc_491521502105_item	2594260	et	4	main
para	doc_491521502105_item	2594289	et	4	main
las	doc_491521502105_item	2594311	et	4	main
püüdes	doc_491521502105_item	2594317	et	4	main
sõber	doc_491521502105_item	2594223	et	3	main
a	doc_491521502105_item	2594225	et	4	main
nõusta	doc_491521502105_item	2594226	et	4	main
e	doc_491521502105_item	2594238	et	4	main
namlaste	doc_491521502105_item	2594239	et	4	main
plaani	doc_491521502105_item	2594251	et	4	main
kuulutada	doc_491521502105_item	2594262	et	3	main
leniniks	doc_491521502105_item	2594264	et	4	main
ning	doc_491521502105_item	2594265	et	3	main
saavutada	doc_491521502105_item	2594266	et	3	main
seda	doc_491521502105_item	2594267	et	3	main
et	doc_491521502105_item	2594268	et	3	main
tema	doc_491521502105_item	2594269	et	4	main
enda	doc_491521502105_item	2594270	et	4	main
poliitilised	doc_491521502105_item	2594271	et	3	main
plaanid	doc_491521502105_item	2594272	et	4	main
õ	doc_491521502105_item	2594273	et	4	main
nnestuks	doc_491521502105_item	2594274	et	4	main
kesküla	doc_491521502105_item	2594275	et	4	main
oli	doc_491521502105_item	2594276	et	3	main
kindel	doc_491521502105_item	2594277	et	3	main
et	doc_491521502105_item	2594278	et	3	main
vassili	doc_491521502105_item	2594279	et	4	main
toimiks	doc_491521502105_item	2594280	et	4	main
kindlasti	doc_491521502105_item	2594281	et	3	main
tema	doc_491521502105_item	2594287	et	4	main
kesküla	doc_491521502105_item	2594288	et	4	main
leninit	doc_491521502105_item	2594297	et	4	main
mäng	doc_491521502105_item	2594303	et	3	main
meelde	doc_491521502105_item	2594305	et	3	main
ääv	doc_491521502105_item	2594307	et	4	main
e	doc_491521502105_item	2594310	et	4	main
oma	doc_491521502105_item	2594312	et	4	main
rolli	doc_491521502105_item	2594313	et	4	main
hästi	doc_491521502105_item	2594314	et	3	main
arvatavasti	doc_491521502105_item	2594318	et	3	main
ku	doc_491521502105_item	2594320	et	4	main
utada	doc_491521502105_item	2594322	et	4	main
та	doc_491521502105_item	2594325	et	2	main
sageli	doc_491521502105_item	2594331	et	3	main
õnes	doc_491521502105_item	2594343	et	4	main
kesküla	doc_491521502105_item	2594349	et	4	main
sarnaseid	doc_491521502105_item	2594357	et	4	main
i	doc_491521502105_item	2594360	et	4	main
toimida	doc_491521502105_item	2594363	et	3	main
teistega	doc_491521502105_item	2594371	et	4	main
j	doc_491521502105_item	2594384	et	4	main
venemaa	doc_491521502105_item	2594422	et	4	main
kuna	doc_491521502105_item	2594429	et	3	main
venemaa	doc_491521502105_item	2594430	et	4	main
j	doc_491521502105_item	2594434	et	4	main
monarhistlik	doc_491521502105_item	2594436	et	3	main
riik	doc_491521502105_item	2594437	et	3	main
puudus	doc_491521502105_item	2594439	et	4	main
e	doc_491521502105_item	2594443	et	4	main
aks	doc_491521502105_item	2594448	et	4	main
a	doc_491521502105_item	2594459	et	4	main
sagedased	doc_491521502105_item	2594464	et	3	main
omakorda	doc_491521502105_item	2594466	et	3	main
vene	doc_491521502105_item	2594468	et	4	main
ammu	doc_491521502105_item	2594491	et	4	main
töötatud	doc_491521502105_item	2594495	et	4	main
ettekäänet	doc_491521502105_item	2594498	et	3	main
lähtutakse	doc_491521502105_item	2594509	et	3	main
j	doc_491521502105_item	2594515	et	4	main
j	doc_491521502105_item	2594321	et	4	main
vastavalt	doc_491521502105_item	2594332	et	4	main
oma	doc_491521502105_item	2594334	et	4	main
ainult	doc_491521502105_item	2594338	et	4	main
teisalt	doc_491521502105_item	2594346	et	4	main
revolutsionäär	doc_491521502105_item	2594348	et	3	main
j	doc_491521502105_item	2594350	et	4	main
leninit	doc_491521502105_item	2594352	et	4	main
mõlеmаl	doc_491521502105_item	2594356	et	2	main
ooni	doc_491521502105_item	2594359	et	4	main
gaüks	doc_491521502105_item	2594361	et	4	main
püüab	doc_491521502105_item	2594362	et	3	main
j	doc_491521502105_item	2594366	et	4	main
ärgi	doc_491521502105_item	2594367	et	4	main
see	doc_491521502105_item	2594368	et	3	main
j	doc_491521502105_item	2594369	et	4	main
uures	doc_491521502105_item	2594370	et	3	main
a	doc_491521502105_item	2594373	et	4	main
teineteisega	doc_491521502105_item	2594375	et	3	main
ehkki	doc_491521502105_item	2594377	et	3	main
esialgu	doc_491521502105_item	2594378	et	3	main
tänu	doc_491521502105_item	2594386	et	4	main
filmi	doc_491521502105_item	2594388	et	4	main
eesmärk	doc_491521502105_item	2594389	et	3	main
oli	doc_491521502105_item	2594390	et	3	main
k	doc_491521502105_item	2594391	et	4	main
a	doc_491521502105_item	2594392	et	4	main
j	doc_491521502105_item	2594393	et	4	main
astada	doc_491521502105_item	2594394	et	4	main
poliitilisi	doc_491521502105_item	2594395	et	3	main
s	doc_491521502105_item	2594396	et	4	main
ündmusi	doc_491521502105_item	2594397	et	4	main
saksamaal	doc_491521502105_item	2594398	et	4	main
sveitsis	doc_491521502105_item	2594399	et	4	main
ja	doc_491521502105_item	2594400	et	3	main
venemaal	doc_491521502105_item	2594401	et	4	main
e	doc_491521502105_item	2594402	et	4	main
nne	doc_491521502105_item	2594403	et	4	main
i	doc_491521502105_item	2594404	et	4	main
ms	doc_491521502105_item	2594405	et	4	main
ning	doc_491521502105_item	2594406	et	3	main
ka	doc_491521502105_item	2594407	et	3	main
sõ	doc_491521502105_item	2594408	et	4	main
j	doc_491521502105_item	2594409	et	4	main
a	doc_491521502105_item	2594410	et	4	main
a	doc_491521502105_item	2594411	et	4	main
j	doc_491521502105_item	2594412	et	4	main
a1	doc_491521502105_item	2594413	et	4	main
selleks	doc_491521502105_item	2594414	et	4	main
et	doc_491521502105_item	2594415	et	3	main
filmi	doc_491521502105_item	2594416	et	4	main
eelkõige	doc_491521502105_item	2594421	et	3	main
saksamaa	doc_491521502105_item	2594424	et	4	main
tol	doc_491521502105_item	2594432	et	3	main
rakonnad	doc_491521502105_item	2594444	et	4	main
j	doc_491521502105_item	2594447	et	4	main
üsna	doc_491521502105_item	2594463	et	3	main
saksamaal	doc_491521502105_item	2594487	et	4	main
j	doc_491521502105_item	2594489	et	4	main
aplaan	doc_491521502105_item	2594490	et	4	main
vaid	doc_491521502105_item	2594497	et	3	main
kesküla	doc_491521502105_item	2594511	et	4	main
tolle	doc_491521502105_item	2594513	et	4	main
a	doc_491521502105_item	2594514	et	4	main
o	doc_491521502105_item	2594521	et	4	main
mõnegi	doc_491521502105_item	2594528	et	3	main
lukorra	doc_491521502105_item	2594530	et	4	main
ärele	doc_491521502105_item	2594533	et	4	main
ehkki	doc_491521502105_item	2594535	et	3	main
ahe	doc_491521502105_item	2594541	et	3	main
seotud	doc_491521502105_item	2594553	et	4	main
probleemid	doc_491521502105_item	2594554	et	3	main
k	doc_491521502105_item	2594580	et	4	main
ära	doc_491521502105_item	2594589	et	4	main
kellegi	doc_491521502105_item	2594592	et	4	main
niikaua	doc_491521502105_item	2594595	et	3	main
see	doc_491521502105_item	2594597	et	3	main
asulik	doc_491521502105_item	2594599	et	4	main
olukordade	doc_491521502105_item	2594642	et	3	main
sna	doc_491521502105_item	2594650	et	4	main
õpetlik	doc_491521502105_item	2594651	et	3	main
m	doc_491521502105_item	2594653	et	4	main
sellest	doc_491521502105_item	2594657	et	4	main
aru	doc_491521502105_item	2594658	et	4	main
uleb	doc_491521502105_item	2594661	et	4	main
kursis	doc_491521502105_item	2594665	et	3	main
p	doc_491521502106_item	2594671	et	4	main
ärast	doc_491521502106_item	2594672	et	3	main
al	doc_491521502106_item	2594681	et	4	main
undeid	doc_491521502106_item	2594685	et	4	main
lid	doc_491521502106_item	2594693	et	4	main
filmi	doc_491521502106_item	2594705	et	4	main
oli	doc_491521502106_item	2594708	et	3	main
a	doc_491521502106_item	2594725	et	4	main
rvates	doc_491521502106_item	2594726	et	4	main
k	doc_491521502106_item	2594727	et	4	main
enini	doc_491521502106_item	2594736	et	4	main
teisik	doc_491521502106_item	2594737	et	3	main
oli	doc_491521502106_item	2594738	et	3	main
nii	doc_491521502106_item	2594739	et	3	main
u	doc_491521502106_item	2594740	et	4	main
eniniga	doc_491521502106_item	2594744	et	4	main
minu	doc_491521502106_item	2594747	et	3	main
esimene	doc_491521502106_item	2594748	et	3	main
kuidas	doc_491521502106_item	2594754	et	3	main
inimene	doc_491521502106_item	2594756	et	3	main
a	doc_491521502106_item	2594759	et	4	main
mis	doc_491521502106_item	2594784	et	4	main
kooliga	doc_491521502106_item	2594788	et	4	main
kus	doc_491521502106_item	2594789	et	3	main
v	doc_491521502106_item	2594790	et	4	main
l	doc_491521502106_item	2594793	et	4	main
o	doc_491521502106_item	2594804	et	4	main
osa	doc_491521502106_item	2594807	et	4	main
kesküla	doc_491521502106_item	2594812	et	4	main
a	doc_491521502106_item	2594819	et	4	main
eist	doc_491521502106_item	2594822	et	4	main
e	doc_491521502106_item	2594826	et	4	main
k	doc_491521502106_item	2594832	et	4	main
s	doc_491521502106_item	2594836	et	4	main
oli	doc_491521502106_item	2594845	et	3	main
s	doc_491521502106_item	2594856	et	4	main
olnud	doc_491521502106_item	2594868	et	4	main
oma	doc_491521502106_item	2594871	et	4	main
deede	doc_491521502106_item	2594873	et	4	main
k	doc_491521502106_item	2594883	et	4	main
r	doc_491521502106_item	2594886	et	4	main
ealiseerida	doc_491521502106_item	2594887	et	4	main
oma	doc_491521502106_item	2594888	et	4	main
t	doc_491521502106_item	2594892	et	4	main
sellest	doc_491521502106_item	2594894	et	4	main
et	doc_491521502106_item	2594895	et	3	main
tema	doc_491521502106_item	2594896	et	4	main
tausta	doc_491521502105_item	2594428	et	4	main
a	doc_491521502105_item	2594433	et	4	main
al	doc_491521502105_item	2594435	et	4	main
kus	doc_491521502105_item	2594438	et	3	main
parlament	doc_491521502105_item	2594440	et	3	main
kodanikuõigused	doc_491521502105_item	2594441	et	4	main
tsaar	doc_491521502105_item	2594450	et	3	main
lid	doc_491521502105_item	2594454	et	4	main
erinevatest	doc_491521502105_item	2594455	et	4	main
j	doc_491521502105_item	2594461	et	4	main
mis	doc_491521502105_item	2594465	et	4	main
lõhestasid	doc_491521502105_item	2594467	et	4	main
impeeriumit	doc_491521502105_item	2594469	et	3	main
sisekonfliktidele	doc_491521502105_item	2594470	et	3	main
lisaks	doc_491521502105_item	2594471	et	4	main
venemaa	doc_491521502105_item	2594473	et	4	main
alustada	doc_491521502105_item	2594474	et	3	main
sõ	doc_491521502105_item	2594475	et	4	main
otsustas	doc_491521502105_item	2594472	et	3	main
j	doc_491521502105_item	2594476	et	4	main
ategevust	doc_491521502105_item	2594477	et	4	main
austria-ungari	doc_491521502105_item	2594478	et	4	main
vastu	doc_491521502105_item	2594479	et	3	main
toetades	doc_491521502105_item	2594480	et	3	main
seega	doc_491521502105_item	2594481	et	4	main
i	doc_491521502105_item	2594482	et	4	main
ms-s	doc_491521502105_item	2594483	et	3	main
serbiat	doc_491521502105_item	2594484	et	4	main
samas	doc_491521502105_item	2594485	et	4	main
oli	doc_491521502105_item	2594486	et	3	main
ja	doc_491521502105_item	2594442	et	3	main
ainuvalitse	doc_491521502105_item	2594446	et	4	main
s	doc_491521502105_item	2594451	et	4	main
o	doc_491521502105_item	2594453	et	4	main
vabastuspüüded	doc_491521502105_item	2594457	et	3	main
j	doc_491521502105_item	2594458	et	4	main
aväemässud	doc_491521502105_item	2594462	et	4	main
väl	doc_491521502105_item	2594492	et	4	main
a	doc_491521502105_item	2594494	et	4	main
ootas	doc_491521502105_item	2594496	et	3	main
purustada	doc_491521502105_item	2594502	et	3	main
serbia	doc_491521502105_item	2594504	et	4	main
kui	doc_491521502105_item	2594505	et	3	main
venemaa	doc_491521502105_item	2594507	et	4	main
duka	doc_491521502105_item	2594518	et	4	main
makasupüüdliku	doc_491521502105_item	2594522	et	4	main
nii	doc_491521502105_item	2594527	et	3	main
taustaks	doc_491521502105_item	2594536	et	3	main
vahel	doc_491521502105_item	2594543	et	4	main
oli	doc_491521502105_item	2594544	et	3	main
hästi	doc_491521502105_item	2594545	et	3	main
esile	doc_491521502105_item	2594546	et	3	main
toodud	doc_491521502105_item	2594547	et	4	main
ka	doc_491521502105_item	2594548	et	3	main
inimestevahelised	doc_491521502105_item	2594549	et	4	main
suhted	doc_491521502105_item	2594550	et	3	main
ja	doc_491521502105_item	2594551	et	3	main
sellega	doc_491521502105_item	2594552	et	3	main
j	doc_491521502105_item	2594561	et	4	main
samas	doc_491521502105_item	2594602	et	4	main
ka	doc_491521502105_item	2594607	et	3	main
püütud	doc_491521502105_item	2594617	et	4	main
huumori	doc_491521502105_item	2594621	et	3	main
meeldejäävamad	doc_491521502105_item	2594623	et	4	main
seotud	doc_491521502105_item	2594629	et	4	main
käitumist	doc_491521502105_item	2594640	et	4	main
ü	doc_491521502105_item	2594649	et	4	main
et	doc_491521502105_item	2594656	et	3	main
saada	doc_491521502105_item	2594659	et	4	main
j	doc_491521502105_item	2594663	et	4	main
e	doc_491521502106_item	2594668	et	4	main
kultuurilugu	doc_491521502106_item	2594670	et	4	main
ilmus	doc_491521502106_item	2594679	et	4	main
u	doc_491521502106_item	2594683	et	4	main
o	doc_491521502106_item	2594692	et	4	main
v	doc_491521502106_item	2594695	et	4	main
õib-	doc_491521502106_item	2594696	et	4	main
olla	doc_491521502106_item	2594697	et	3	main
t	doc_491521502106_item	2594701	et	4	main
p	doc_491521502106_item	2594709	et	4	main
üllatavam	doc_491521502106_item	2594729	et	4	main
skumatu	doc_491521502106_item	2594741	et	4	main
j	doc_491521502106_item	2594760	et	4	main
a	doc_491521502106_item	2594761	et	4	main
n	doc_491521502106_item	2594786	et	4	main
uusi	doc_491521502106_item	2594792	et	3	main
nii	doc_491521502106_item	2594796	et	3	main
ka	doc_491521502106_item	2594799	et	3	main
k	doc_491521502106_item	2594810	et	4	main
sandri	doc_491521502106_item	2594811	et	4	main
теmа	doc_491521502106_item	2594814	et	2	main
sõ	doc_491521502105_item	2594488	et	4	main
austria-ungari	doc_491521502105_item	2594500	et	4	main
ka	doc_491521502105_item	2594506	et	3	main
eelkõige	doc_491521502105_item	2594510	et	3	main
a	doc_491521502105_item	2594516	et	4	main
e	doc_491521502105_item	2594517	et	4	main
j	doc_491521502105_item	2594519	et	4	main
a	doc_491521502105_item	2594520	et	4	main
pani	doc_491521502105_item	2594526	et	4	main
ülе	doc_491521502105_item	2594531	et	2	main
oli	doc_491521502105_item	2594537	et	3	main
k	doc_491521502105_item	2594540	et	4	main
suurriigi	doc_491521502105_item	2594542	et	3	main
selles	doc_491521502105_item	2594559	et	4	main
et	doc_491521502105_item	2594560	et	3	main
nimellihtsalt	doc_491521502105_item	2594588	et	4	main
sõber	doc_491521502105_item	2594593	et	3	main
i	doc_491521502105_item	2594604	et	4	main
puudunud	doc_491521502105_item	2594605	et	4	main
o	doc_491521502105_item	2594615	et	4	main
teha	doc_491521502105_item	2594618	et	3	main
ameerikaliku	doc_491521502105_item	2594620	et	3	main
j	doc_491521502105_item	2594625	et	4	main
leninlikku	doc_491521502105_item	2594639	et	4	main
film	doc_491521502105_item	2594644	et	3	main
leninid	doc_491521502105_item	2594646	et	4	main
mõnes	doc_491521502105_item	2594652	et	3	main
filmi	doc_491521502106_item	2594673	et	4	main
minu	doc_491521502106_item	2594674	et	3	main
leninid	doc_491521502106_item	2594675	et	4	main
j	doc_491521502106_item	2594682	et	4	main
j	doc_491521502106_item	2594686	et	4	main
k	doc_491521502106_item	2594688	et	4	main
n	doc_491521502106_item	2594690	et	4	main
eed	doc_491521502106_item	2594691	et	3	main
segaduses	doc_491521502106_item	2594694	et	3	main
segadused	doc_491521502106_item	2594698	et	3	main
et	doc_491521502106_item	2594704	et	3	main
älgida	doc_491521502106_item	2594721	et	4	main
poliitiku	doc_491521502105_item	2594523	et	3	main
tegevusest	doc_491521502105_item	2594524	et	4	main
o	doc_491521502105_item	2594529	et	4	main
poliitiline	doc_491521502105_item	2594538	et	3	main
konflikt	doc_491521502105_item	2594539	et	3	main
filmistsenaariumi	doc_491521502105_item	2594556	et	4	main
är	doc_491521502105_item	2594562	et	4	main
j	doc_491521502105_item	2594563	et	4	main
ekordselt	doc_491521502105_item	2594564	et	4	main
tõestada	doc_491521502105_item	2594565	et	3	main
vaata	doc_491521502105_item	2594566	et	4	main
j	doc_491521502105_item	2594567	et	4	main
atele	doc_491521502105_item	2594568	et	3	main
kuivõrd	doc_491521502105_item	2594569	et	3	main
habras	doc_491521502105_item	2594570	et	3	main
j	doc_491521502105_item	2594571	et	4	main
a	doc_491521502105_item	2594572	et	4	main
kahepalgeline	doc_491521502105_item	2594573	et	4	main
sõprus	doc_491521502105_item	2594575	et	3	main
võib	doc_491521502105_item	2594574	et	3	main
olla	doc_491521502105_item	2594576	et	3	main
kuidas	doc_491521502105_item	2594577	et	3	main
suhted	doc_491521502105_item	2594578	et	3	main
võivad	doc_491521502105_item	2594579	et	4	main
orrapealt	doc_491521502105_item	2594581	et	4	main
muutuda	doc_491521502105_item	2594582	et	3	main
vaenulikuks	doc_491521502105_item	2594583	et	3	main
inimesi	doc_491521502105_item	2594584	et	4	main
kasutatakse	doc_491521502105_item	2594585	et	3	main
oma	doc_491521502105_item	2594586	et	4	main
eesmärkide	doc_491521502105_item	2594587	et	3	main
ning	doc_491521502105_item	2594590	et	3	main
vaid	doc_491521502105_item	2594594	et	3	main
kui	doc_491521502105_item	2594596	et	3	main
k	doc_491521502105_item	2594598	et	4	main
o	doc_491521502105_item	2594600	et	4	main
n	doc_491521502105_item	2594601	et	4	main
filmis	doc_491521502105_item	2594606	et	4	main
mis	doc_491521502105_item	2594609	et	4	main
n	doc_491521502105_item	2594616	et	4	main
leninite	doc_491521502105_item	2594630	et	4	main
vale-	doc_491521502105_item	2594633	et	4	main
o	doc_491521502105_item	2594647	et	4	main
n	doc_491521502105_item	2594648	et	4	main
a	doc_491521502105_item	2594662	et	4	main
alooga	doc_491521502105_item	2594664	et	4	main
v	doc_491521502106_item	2594676	et	4	main
aatamist	doc_491521502106_item	2594677	et	4	main
mul	doc_491521502106_item	2594678	et	3	main
a	doc_491521502106_item	2594687	et	4	main
õik	doc_491521502106_item	2594689	et	4	main
o	doc_491521502106_item	2594699	et	4	main
ingitud	doc_491521502106_item	2594702	et	4	main
sellega	doc_491521502106_item	2594703	et	3	main
s	doc_491521502106_item	2594706	et	4	main
arendamist	doc_491521502106_item	2594723	et	4	main
filmis	doc_491521502106_item	2594731	et	4	main
oli	doc_491521502106_item	2594732	et	3	main
see	doc_491521502106_item	2594733	et	3	main
et	doc_491521502106_item	2594734	et	3	main
sarnane	doc_491521502106_item	2594742	et	4	main
a	doc_491521502106_item	2594746	et	4	main
oli	doc_491521502106_item	2594751	et	3	main
j	doc_491521502106_item	2594762	et	4	main
ooksul	doc_491521502106_item	2594763	et	4	main
o	doc_491521502106_item	2594785	et	4	main
traagilisi	doc_491521502106_item	2594800	et	3	main
le	doc_491521502106_item	2594809	et	4	main
elust	doc_491521502106_item	2594813	et	3	main
oli	doc_491521502106_item	2594815	et	3	main
evolutsionäär	doc_491521502106_item	2594817	et	4	main
j	doc_491521502106_item	2594818	et	4	main
n	doc_491521502106_item	2594821	et	4	main
eda	doc_491521502106_item	2594824	et	4	main
nimetati	doc_491521502106_item	2594825	et	4	main
v	doc_491521502106_item	2594834	et	4	main
õttis	doc_491521502106_item	2594835	et	4	main
uure	doc_491521502106_item	2594837	et	4	main
osa	doc_491521502106_item	2594838	et	4	main
j	doc_491521502106_item	2594851	et	4	main
seda	doc_491521502106_item	2594862	et	3	main
soomega	doc_491521502106_item	2594863	et	4	main
k	doc_491521502106_item	2594865	et	4	main
p	doc_491521502106_item	2594867	et	4	main
propageeri	doc_491521502106_item	2594874	et	4	main
teha	doc_491521502106_item	2594882	et	3	main
et	doc_491521502106_item	2594885	et	3	main
on	doc_491521502106_item	2594898	et	4	main
t	doc_491521502106_item	2594902	et	4	main
htlikus	doc_491521502106_item	2594905	et	4	main
t	doc_491521502106_item	2594908	et	4	main
a	doc_491521502106_item	2594910	et	4	main
lati	doc_491521502106_item	2594911	et	3	main
almis	doc_491521502106_item	2594914	et	4	main
inimeseks	doc_491521502106_item	2594924	et	3	main
k	doc_491521502106_item	2594925	et	4	main
eda	doc_491521502106_item	2594926	et	4	main
arta	doc_491521502106_item	2594929	et	4	main
et	doc_491521502106_item	2594936	et	3	main
e	doc_491521502106_item	2594940	et	4	main
r	doc_491521502106_item	2594942	et	4	main
evolutsionäär	doc_491521502106_item	2594943	et	4	main
avantüristlik	doc_491521502106_item	2594948	et	3	main
m	doc_491521502106_item	2594960	et	4	main
õlemad	doc_491521502106_item	2594961	et	4	main
rvamused	doc_491521502106_item	2594963	et	4	main
õ	doc_491521502106_item	2594968	et	4	main
stiilis	doc_491521502105_item	2594622	et	4	main
nal	doc_491521502105_item	2594624	et	4	main
ahetked	doc_491521502105_item	2594626	et	4	main
o	doc_491521502105_item	2594627	et	4	main
n	doc_491521502105_item	2594628	et	4	main
koolitamisega	doc_491521502105_item	2594631	et	4	main
mil	doc_491521502105_item	2594632	et	4	main
l	doc_491521502105_item	2594634	et	4	main
eninitele	doc_491521502105_item	2594635	et	4	main
püüti	doc_491521502105_item	2594636	et	3	main
õ	doc_491521502105_item	2594637	et	4	main
petada	doc_491521502105_item	2594638	et	4	main
erinevate	doc_491521502105_item	2594641	et	4	main
tarvis	doc_491521502105_item	2594643	et	3	main
minu	doc_491521502105_item	2594645	et	3	main
õttes	doc_491521502105_item	2594654	et	4	main
samas	doc_491521502105_item	2594655	et	4	main
t	doc_491521502105_item	2594660	et	4	main
olla	doc_491521502105_item	2594666	et	3	main
essee	doc_491521502106_item	2594667	et	4	main
esti	doc_491521502106_item	2594669	et	4	main
p	doc_491521502106_item	2594680	et	4	main
t	doc_491521502106_item	2594684	et	4	main
n	doc_491521502106_item	2594700	et	4	main
üzee	doc_491521502106_item	2594707	et	4	main
äris	doc_491521502106_item	2594710	et	3	main
k	doc_491521502106_item	2594711	et	4	main
eeruline	doc_491521502106_item	2594712	et	4	main
j	doc_491521502106_item	2594713	et	4	main
a	doc_491521502106_item	2594714	et	4	main
oli	doc_491521502106_item	2594715	et	3	main
ü	doc_491521502106_item	2594716	et	4	main
sna	doc_491521502106_item	2594717	et	4	main
r	doc_491521502106_item	2594718	et	4	main
aske	doc_491521502106_item	2594719	et	3	main
j	doc_491521502106_item	2594720	et	4	main
õige	doc_491521502106_item	2594728	et	4	main
selles	doc_491521502106_item	2594730	et	4	main
l	doc_491521502106_item	2594743	et	4	main
m	doc_491521502106_item	2594749	et	4	main
see	doc_491521502106_item	2594752	et	3	main
nii	doc_491521502106_item	2594757	et	3	main
saada	doc_491521502106_item	2594764	et	4	main
koomilisi	doc_491521502106_item	2594797	et	3	main
momente	doc_491521502106_item	2594801	et	3	main
samuti	doc_491521502106_item	2594802	et	3	main
filmis	doc_491521502106_item	2594803	et	4	main
n	doc_491521502106_item	2594805	et	4	main
a	doc_491521502106_item	2594808	et	4	main
r	doc_491521502106_item	2594816	et	4	main
üks	doc_491521502106_item	2594820	et	3	main
k	doc_491521502106_item	2594823	et	4	main
aleksander	doc_491521502106_item	2594831	et	4	main
j	doc_491521502106_item	2594841	et	4	main
tema	doc_491521502106_item	2594843	et	4	main
eesmärk	doc_491521502106_item	2594844	et	3	main
e	doc_491521502106_item	2594847	et	4	main
j	doc_491521502106_item	2594853	et	4	main
a	doc_491521502106_item	2594854	et	4	main
a	doc_491521502106_item	2594860	et	4	main
liita	doc_491521502106_item	2594861	et	4	main
a	doc_491521502106_item	2594876	et	4	main
oli	doc_491521502106_item	2594891	et	3	main
k	doc_491521502106_item	2594899	et	4	main
oli	doc_491521502106_item	2594901	et	3	main
õned	doc_491521502106_item	2594918	et	4	main
pidid	doc_491521502106_item	2594919	et	4	main
aleksandri	doc_491521502106_item	2594920	et	4	main
sündmuste	doc_491521502106_item	2594722	et	3	main
minu	doc_491521502106_item	2594724	et	3	main
l	doc_491521502106_item	2594735	et	4	main
j	doc_491521502106_item	2594745	et	4	main
õte	doc_491521502106_item	2594750	et	4	main
et	doc_491521502106_item	2594753	et	3	main
suudab	doc_491521502106_item	2594755	et	3	main
lühikese	doc_491521502106_item	2594758	et	4	main
sarnaseks	doc_491521502106_item	2594765	et	4	main
i	doc_491521502106_item	2594766	et	4	main
sikuga	doc_491521502106_item	2594767	et	3	main
l	doc_491521502106_item	2594769	et	4	main
kelle	doc_491521502106_item	2594768	et	4	main
oomus	doc_491521502106_item	2594770	et	4	main
o	doc_491521502106_item	2594771	et	4	main
n	doc_491521502106_item	2594772	et	4	main
nii	doc_491521502106_item	2594773	et	3	main
j	doc_491521502106_item	2594774	et	4	main
äl	doc_491521502106_item	2594775	et	4	main
j	doc_491521502106_item	2594776	et	4	main
etamatu	doc_491521502106_item	2594777	et	4	main
nagu	doc_491521502106_item	2594778	et	3	main
l	doc_491521502106_item	2594779	et	4	main
enini	doc_491521502106_item	2594780	et	4	main
filmi	doc_491521502106_item	2594781	et	4	main
k	doc_491521502106_item	2594782	et	4	main
atkenditest	doc_491521502106_item	2594783	et	4	main
seotud	doc_491521502106_item	2594787	et	4	main
almistati	doc_491521502106_item	2594791	et	4	main
enineid	doc_491521502106_item	2594794	et	4	main
oli	doc_491521502106_item	2594795	et	3	main
kui	doc_491521502106_item	2594798	et	3	main
esitatud	doc_491521502106_item	2594806	et	4	main
esti	doc_491521502106_item	2594827	et	4	main
r	doc_491521502106_item	2594839	et	4	main
estist	doc_491521502106_item	2594848	et	4	main
õh	doc_491521502106_item	2594850	et	4	main
a-lätist	doc_491521502106_item	2594852	et	4	main
ingerimaasi	doc_491521502106_item	2594855	et	4	main
eesti	doc_491521502106_item	2594858	et	4	main
j	doc_491521502106_item	2594859	et	4	main
a	doc_491521502106_item	2594869	et	4	main
j	doc_491521502106_item	2594875	et	4	main
v	doc_491521502106_item	2594877	et	4	main
aid	doc_491521502106_item	2594878	et	4	main
samuti	doc_491521502106_item	2594879	et	3	main
tema	doc_491521502106_item	2594880	et	4	main
püüdis	doc_491521502106_item	2594881	et	3	main
та	doc_491521502106_item	2594890	et	2	main
tegevus	doc_491521502106_item	2594897	et	4	main
p	doc_491521502106_item	2594915	et	4	main
m	doc_491521502106_item	2594917	et	4	main
kesküla	doc_491521502106_item	2594921	et	4	main
õimekaks	doc_491521502106_item	2594923	et	4	main
k	doc_491521502106_item	2594928	et	4	main
v	doc_491521502106_item	2594933	et	4	main
p	doc_491521502106_item	2594938	et	4	main
htis	doc_491521502106_item	2594941	et	4	main
a	doc_491521502106_item	2594955	et	4	main
v	doc_491521502106_item	2594956	et	4	main
iged	doc_491521502106_item	2594969	et	4	main
kindlasti	doc_491521502106_item	2594972	et	3	main
kui	doc_491521502106_item	2594976	et	3	main
nõudis	doc_491521502106_item	2594978	et	3	main
ku	doc_491521502106_item	2594980	et	4	main
oma	doc_491521502106_item	2594999	et	4	main
ideede	doc_491521502106_item	2595000	et	3	main
ta	doc_491521502106_item	2595024	et	4	main
saavutada	doc_491521502106_item	2595026	et	3	main
ärgi	doc_491521502106_item	2595035	et	4	main
unnustatud	doc_491521502106_item	2595041	et	4	main
enin	doc_491521502106_item	2595045	et	4	main
a	doc_491521502106_item	2595047	et	4	main
see	doc_491521502106_item	2595055	et	3	main
uudne	doc_491521502106_item	2595060	et	3	main
p	doc_491521502106_item	2595071	et	4	main
kõik	doc_491521502106_item	2595073	et	4	main
ilmselge	doc_491521502106_item	2595074	et	4	main
mis	doc_491521502106_item	2595087	et	4	main
r	doc_491521502106_item	2595093	et	4	main
leninid	doc_491521502107_item	2595127	et	4	main
saksamaa	doc_491521502107_item	2595135	et	4	main
venemaal	doc_491521502107_item	2595142	et	4	main
aga	doc_491521502107_item	2595143	et	3	main
üsna	doc_491521502107_item	2595144	et	3	main
ja	doc_491521502107_item	2595146	et	3	main
aleksandrile	doc_491521502107_item	2595157	et	4	main
mitte	doc_491521502107_item	2595174	et	3	main
lennini	doc_491521502107_item	2595187	et	4	main
sõber	doc_491521502107_item	2595188	et	3	main
lenenile	doc_491521502107_item	2595196	et	4	main
sotsiaaldemokraatid	doc_491521502107_item	2595200	et	4	main
tulevikus	doc_491521502107_item	2595202	et	4	main
venemaad	doc_491521502107_item	2595203	et	4	main
valitsema	doc_491521502107_item	2595204	et	3	main
eestimaale	doc_491521502107_item	2595210	et	4	main
välja	doc_491521502107_item	2595215	et	4	main
bolsevikide	doc_491521502107_item	2595219	et	4	main
aga	doc_491521502107_item	2595222	et	3	main
selgitas	doc_491521502107_item	2595223	et	3	main
see	doc_491521502107_item	2595225	et	3	main
ta	doc_491521502107_item	2595227	et	4	main
lenin	doc_491521502107_item	2595239	et	4	main
omaga	doc_491521502107_item	2595240	et	3	main
sarnane	doc_491521502107_item	2595241	et	4	main
sotsiaaldemokraatide	doc_491521502107_item	2595242	et	3	main
liider	doc_491521502107_item	2595243	et	3	main
keskküla	doc_491521502107_item	2595247	et	4	main
mõistis	doc_491521502107_item	2595248	et	4	main
p	doc_491521502106_item	2594828	et	4	main
eterburi	doc_491521502106_item	2594829	et	4	main
patriootideks	doc_491521502106_item	2594830	et	3	main
esküla	doc_491521502106_item	2594833	et	4	main
evolutsioonitegevuses	doc_491521502106_item	2594840	et	4	main
a	doc_491521502106_item	2594842	et	4	main
teha	doc_491521502106_item	2594846	et	3	main
p	doc_491521502106_item	2594849	et	4	main
uur	doc_491521502106_item	2594857	et	3	main
aleksander	doc_491521502106_item	2594864	et	4	main
esküla	doc_491521502106_item	2594866	et	4	main
inult	doc_491521502106_item	2594870	et	4	main
i	doc_491521502106_item	2594872	et	4	main
õik	doc_491521502106_item	2594884	et	4	main
ideed	doc_491521502106_item	2594889	et	4	main
eadlik	doc_491521502106_item	2594893	et	4	main
o	doc_491521502106_item	2594904	et	4	main
situatsioonis	doc_491521502106_item	2594906	et	3	main
v	doc_491521502106_item	2594913	et	4	main
tuleks	doc_491521502106_item	2594927	et	4	main
õned	doc_491521502106_item	2594931	et	4	main
tema	doc_491521502106_item	2594937	et	4	main
v	doc_491521502106_item	2594944	et	4	main
öеldа	doc_491521502106_item	2594958	et	2	main
aleksandri	doc_491521502106_item	2594964	et	4	main
oli	doc_491521502106_item	2594971	et	3	main
kuid	doc_491521502106_item	2594975	et	4	main
situatsioon	doc_491521502106_item	2594977	et	3	main
unes	doc_491521502106_item	2594982	et	3	main
a	doc_491521502106_item	2594986	et	4	main
p	doc_491521502106_item	2594989	et	4	main
ta	doc_491521502106_item	2594997	et	4	main
oli	doc_491521502106_item	2594998	et	3	main
k	doc_491521502106_item	2595002	et	4	main
mida	doc_491521502106_item	2595023	et	4	main
unistas	doc_491521502106_item	2595025	et	3	main
lenini	doc_491521502106_item	2595036	et	4	main
teisik	doc_491521502106_item	2595037	et	3	main
nagu	doc_491521502106_item	2595042	et	3	main
minu	doc_491521502106_item	2595057	et	3	main
õib-olla	doc_491521502106_item	2595076	et	3	main
et	doc_491521502106_item	2595078	et	3	main
p	doc_491521502106_item	2595082	et	4	main
filmi	doc_491521502107_item	2595128	et	4	main
valmistas	doc_491521502107_item	2595136	et	3	main
end	doc_491521502107_item	2595137	et	4	main
ette	doc_491521502107_item	2595138	et	4	main
kasvas	doc_491521502107_item	2595148	et	3	main
vahel	doc_491521502107_item	2595153	et	4	main
kino	doc_491521502107_item	2595154	et	4	main
keskküla	doc_491521502107_item	2595158	et	4	main
ning	doc_491521502107_item	2595159	et	3	main
teenida	doc_491521502107_item	2595178	et	3	main
ka	doc_491521502107_item	2595184	et	3	main
hea	doc_491521502107_item	2595193	et	4	main
tema	doc_491521502107_item	2595198	et	4	main
hakkaksid	doc_491521502107_item	2595201	et	4	main
vastu	doc_491521502107_item	2595207	et	3	main
aristatav	doc_491521502106_item	2594900	et	4	main
ihti	doc_491521502106_item	2594903	et	4	main
kui	doc_491521502106_item	2594907	et	3	main
uleb	doc_491521502106_item	2594909	et	4	main
olla	doc_491521502106_item	2594912	et	3	main
õgeneda	doc_491521502106_item	2594916	et	4	main
m	doc_491521502106_item	2594930	et	4	main
äidasid	doc_491521502106_item	2594934	et	4	main
et	doc_491521502106_item	2594935	et	3	main
oli	doc_491521502106_item	2594947	et	3	main
hinge	doc_491521502106_item	2594949	et	4	main
oli	doc_491521502106_item	2594951	et	3	main
õ	doc_491521502106_item	2594952	et	4	main
nneotsi	doc_491521502106_item	2594953	et	4	main
j	doc_491521502106_item	2594954	et	4	main
et	doc_491521502106_item	2594959	et	3	main
vantürist	doc_491521502106_item	2594974	et	4	main
temast	doc_491521502106_item	2594979	et	3	main
j	doc_491521502106_item	2594983	et	4	main
j	doc_491521502106_item	2594985	et	4	main
kui	doc_491521502106_item	2594994	et	3	main
s	doc_491521502106_item	2594995	et	4	main
ihiteadlik	doc_491521502106_item	2594996	et	4	main
ah	doc_491521502106_item	2595003	et	3	main
j	doc_491521502106_item	2595004	et	4	main
et	doc_491521502106_item	2595006	et	3	main
m	doc_491521502106_item	2595007	et	4	main
saavutada	doc_491521502106_item	2595021	et	3	main
1õрр	doc_491521502106_item	2595032	et	2	main
mille	doc_491521502106_item	2595033	et	3	main
j	doc_491521502106_item	2595034	et	4	main
päris	doc_491521502106_item	2595043	et	4	main
p	doc_491521502106_item	2595051	et	4	main
eniniks	doc_491521502106_item	2595054	et	4	main
okuvõttes	doc_491521502106_item	2595062	et	4	main
j	doc_491521502106_item	2595069	et	4	main
aoks	doc_491521502106_item	2595070	et	3	main
mа	doc_491521502106_item	2595079	et	2	main
tea	doc_491521502106_item	2595081	et	4	main
al	doc_491521502106_item	2595083	et	4	main
faktidest	doc_491521502106_item	2595086	et	3	main
n	doc_491521502106_item	2595089	et	4	main
s	doc_491521502106_item	2595091	et	4	main
uure	doc_491521502106_item	2595092	et	4	main
v	doc_491521502106_item	2594922	et	4	main
aga	doc_491521502106_item	2594932	et	3	main
olnud	doc_491521502106_item	2594939	et	4	main
aid	doc_491521502106_item	2594945	et	4	main
temal	doc_491521502106_item	2594946	et	3	main
ta	doc_491521502106_item	2594950	et	4	main
õib	doc_491521502106_item	2594957	et	4	main
a	doc_491521502106_item	2594962	et	4	main
keskülast	doc_491521502106_item	2594965	et	3	main
o	doc_491521502106_item	2594966	et	4	main
n	doc_491521502106_item	2594967	et	4	main
j	doc_491521502106_item	2594981	et	4	main
ulge	doc_491521502106_item	2594984	et	3	main
õned	doc_491521502106_item	2595008	et	4	main
ideed	doc_491521502106_item	2595009	et	4	main
j	doc_491521502106_item	2595010	et	4	main
äid	doc_491521502106_item	2595011	et	4	main
sooritamata	doc_491521502106_item	2595012	et	4	main
j	doc_491521502106_item	2595013	et	4	main
a	doc_491521502106_item	2595014	et	4	main
r	doc_491521502106_item	2595015	et	4	main
evolutsiooniga	doc_491521502106_item	2595016	et	3	main
e	doc_491521502106_item	2595017	et	4	main
i	doc_491521502106_item	2595018	et	4	main
õ	doc_491521502106_item	2595019	et	4	main
nnestunud	doc_491521502106_item	2595020	et	4	main
seda	doc_491521502106_item	2595022	et	3	main
fi1mi1	doc_491521502106_item	2595027	et	4	main
o	doc_491521502106_item	2595028	et	4	main
n	doc_491521502106_item	2595029	et	4	main
täiesti	doc_491521502106_item	2595030	et	3	main
o	doc_491521502106_item	2595038	et	4	main
eetakse	doc_491521502106_item	2595052	et	4	main
oli	doc_491521502106_item	2595056	et	3	main
k	doc_491521502106_item	2595061	et	4	main
v	doc_491521502106_item	2595063	et	4	main
õin	doc_491521502106_item	2595064	et	4	main
v	doc_491521502106_item	2595075	et	4	main
ei	doc_491521502106_item	2595080	et	4	main
u	doc_491521502106_item	2595085	et	4	main
j	doc_491521502106_item	2595121	et	4	main
teada	doc_491521502106_item	2595123	et	3	main
essee	doc_491521502107_item	2595124	et	4	main
tegevus	doc_491521502107_item	2595131	et	4	main
toimub	doc_491521502107_item	2595132	et	3	main
tulevase	doc_491521502107_item	2595139	et	4	main
sõja	doc_491521502107_item	2595140	et	3	main
võitlus	doc_491521502107_item	2595149	et	3	main
sotsiaaldemokraatia	doc_491521502107_item	2595152	et	4	main
pühendatud	doc_491521502107_item	2595156	et	4	main
mees	doc_491521502107_item	2595172	et	4	main
välja	doc_491521502107_item	2595177	et	4	main
tema	doc_491521502107_item	2595189	et	4	main
esmaplaan	doc_491521502107_item	2595190	et	3	main
oli	doc_491521502107_item	2595191	et	3	main
et	doc_491521502107_item	2595197	et	3	main
mehi	doc_491521502107_item	2595216	et	3	main
särnasid	doc_491521502107_item	2595218	et	4	main
liidriga	doc_491521502107_item	2595220	et	3	main
on	doc_491521502107_item	2595226	et	4	main
elu	doc_491521502107_item	2595228	et	4	main
ning	doc_491521502107_item	2595261	et	3	main
pärast	doc_491521502107_item	2595272	et	4	main
autor	doc_491521502107_item	2595282	et	3	main
sangar	doc_491521502107_item	2595290	et	3	main
jaoks	doc_491521502107_item	2595295	et	4	main
pühendas	doc_491521502107_item	2595297	et	3	main
kui	doc_491521502107_item	2595310	et	3	main
tema	doc_491521502107_item	2595311	et	4	main
tugev	doc_491521502107_item	2595312	et	4	main
ta	doc_491521502106_item	2594970	et	4	main
a	doc_491521502106_item	2594973	et	4	main
ettevõtlik	doc_491521502106_item	2594987	et	3	main
revolutsionäär	doc_491521502106_item	2594988	et	3	main
äris	doc_491521502106_item	2594990	et	3	main
üllatav	doc_491521502106_item	2594991	et	4	main
oli	doc_491521502106_item	2594992	et	3	main
see	doc_491521502106_item	2594993	et	3	main
elluviimises	doc_491521502106_item	2595001	et	3	main
u	doc_491521502106_item	2595005	et	4	main
üllatav	doc_491521502106_item	2595031	et	4	main
n	doc_491521502106_item	2595039	et	4	main
t	doc_491521502106_item	2595040	et	4	main
l	doc_491521502106_item	2595044	et	4	main
j	doc_491521502106_item	2595046	et	4	main
tema	doc_491521502106_item	2595048	et	4	main
surmani	doc_491521502106_item	2595049	et	3	main
teda	doc_491521502106_item	2595050	et	4	main
l	doc_491521502106_item	2595053	et	4	main
j	doc_491521502106_item	2595058	et	4	main
aoks	doc_491521502106_item	2595059	et	3	main
öеldа	doc_491521502106_item	2595065	et	2	main
et	doc_491521502106_item	2595066	et	3	main
filmis	doc_491521502106_item	2595067	et	4	main
minu	doc_491521502106_item	2595068	et	3	main
olnud	doc_491521502106_item	2595072	et	4	main
sellepärast	doc_491521502106_item	2595077	et	3	main
j	doc_491521502106_item	2595084	et	4	main
o	doc_491521502106_item	2595088	et	4	main
seotud	doc_491521502106_item	2595090	et	4	main
evolutsiooniga	doc_491521502106_item	2595094	et	3	main
j	doc_491521502106_item	2595095	et	4	main
a	doc_491521502106_item	2595096	et	4	main
aleksandri	doc_491521502106_item	2595097	et	4	main
kesküla	doc_491521502106_item	2595098	et	4	main
eluga	doc_491521502106_item	2595099	et	3	main
j	doc_491521502106_item	2595100	et	4	main
a	doc_491521502106_item	2595101	et	4	main
oli	doc_491521502106_item	2595102	et	3	main
r	doc_491521502106_item	2595103	et	4	main
aske	doc_491521502106_item	2595104	et	3	main
aru	doc_491521502106_item	2595105	et	4	main
saada	doc_491521502106_item	2595106	et	4	main
mis	doc_491521502106_item	2595107	et	4	main
j	doc_491521502106_item	2595108	et	4	main
a	doc_491521502106_item	2595109	et	4	main
milleks	doc_491521502106_item	2595110	et	4	main
selles	doc_491521502106_item	2595111	et	4	main
filmis	doc_491521502106_item	2595112	et	4	main
o	doc_491521502106_item	2595113	et	4	main
n	doc_491521502106_item	2595114	et	4	main
aga	doc_491521502106_item	2595115	et	3	main
üldiselt	doc_491521502106_item	2595116	et	4	main
sain	doc_491521502106_item	2595117	et	3	main
filmist	doc_491521502106_item	2595118	et	4	main
p	doc_491521502106_item	2595119	et	4	main
al	doc_491521502106_item	2595120	et	4	main
u	doc_491521502106_item	2595122	et	4	main
minu	doc_491521502107_item	2595129	et	3	main
leninid	doc_491521502107_item	2595130	et	4	main
rohkem	doc_491521502107_item	2595145	et	4	main
tsarismi	doc_491521502107_item	2595150	et	4	main
ainult	doc_491521502107_item	2595175	et	4	main
usaldust	doc_491521502107_item	2595180	et	4	main
temast	doc_491521502107_item	2595182	et	3	main
päris	doc_491521502107_item	2595192	et	4	main
arvustus	doc_491521502107_item	2595125	et	4	main
minu	doc_491521502107_item	2595126	et	3	main
ajal	doc_491521502107_item	2595133	et	4	main
millal	doc_491521502107_item	2595134	et	3	main
jaoks	doc_491521502107_item	2595141	et	4	main
rohkem	doc_491521502107_item	2595147	et	4	main
ja	doc_491521502107_item	2595151	et	3	main
on	doc_491521502107_item	2595155	et	4	main
tema	doc_491521502107_item	2595160	et	4	main
suure	doc_491521502107_item	2595161	et	3	main
elueesmärgile	doc_491521502107_item	2595162	et	3	main
ehk	doc_491521502107_item	2595163	et	3	main
eesti	doc_491521502107_item	2595164	et	4	main
suurvabariigi	doc_491521502107_item	2595165	et	3	main
ülesehitamisele	doc_491521502107_item	2595166	et	3	main
keskküla	doc_491521502107_item	2595167	et	4	main
oli	doc_491521502107_item	2595168	et	3	main
noor	doc_491521502107_item	2595169	et	3	main
ja	doc_491521502107_item	2595170	et	3	main
haritud	doc_491521502107_item	2595171	et	4	main
kes	doc_491521502107_item	2595173	et	4	main
suudas	doc_491521502107_item	2595176	et	4	main
saksavalitsuse	doc_491521502107_item	2595179	et	3	main
vaid	doc_491521502107_item	2595181	et	3	main
sai	doc_491521502107_item	2595183	et	4	main
hea	doc_491521502107_item	2595185	et	4	main
v	doc_491521502107_item	2595186	et	4	main
ta	doc_491521502107_item	2595194	et	4	main
aitab	doc_491521502107_item	2595195	et	3	main
ning	doc_491521502107_item	2595199	et	3	main
aitamise	doc_491521502107_item	2595206	et	4	main
lenin	doc_491521502107_item	2595208	et	4	main
peab	doc_491521502107_item	2595209	et	4	main
kes	doc_491521502107_item	2595217	et	4	main
lenenile	doc_491521502107_item	2595221	et	4	main
et	doc_491521502107_item	2595224	et	3	main
käitumine	doc_491521502107_item	2595237	et	4	main
oleks	doc_491521502107_item	2595238	et	3	main
kinkida	doc_491521502107_item	2595255	et	3	main
peas	doc_491521502107_item	2595257	et	4	main
asetas	doc_491521502107_item	2595263	et	3	main
koha	doc_491521502107_item	2595265	et	4	main
teisikuga	doc_491521502107_item	2595266	et	3	main
nimega	doc_491521502107_item	2595267	et	3	main
vanja	doc_491521502107_item	2595268	et	4	main
valitsema	doc_491521502107_item	2595275	et	3	main
need	doc_491521502107_item	2595276	et	3	main
teisikud	doc_491521502107_item	2595277	et	3	main
filmis	doc_491521502107_item	2595278	et	4	main
tõelist	doc_491521502107_item	2595287	et	4	main
sellele	doc_491521502107_item	2595298	et	4	main
ei	doc_491521502107_item	2595305	et	4	main
olnud	doc_491521502107_item	2595306	et	4	main
usk	doc_491521502107_item	2595316	et	3	main
kangelasi	doc_491521502107_item	2595321	et	3	main
väga	doc_491521502107_item	2595323	et	3	main
tänapäevases	doc_491521502107_item	2595325	et	4	main
praegu	doc_491521502107_item	2595327	et	3	main
noorte	doc_491521502107_item	2595328	et	3	main
lõbutüdrukud	doc_491521502107_item	2595353	et	3	main
kusagil	doc_491521502107_item	2595356	et	3	main
lõppus	doc_491521502107_item	2595358	et	4	main
ja	doc_491521502107_item	2595369	et	3	main
muud	doc_491521502107_item	2595370	et	4	main
ühiskonna	doc_491521502107_item	2595371	et	4	main
madalad	doc_491521502107_item	2595372	et	3	main
osad	doc_491521502107_item	2595373	et	3	main
võib	doc_491521502107_item	2595374	et	3	main
olla	doc_491521502107_item	2595375	et	3	main
valesti	doc_491521502107_item	2595380	et	3	main
lenin	doc_491521502107_item	2595386	et	4	main
selle	doc_491521502107_item	2595205	et	4	main
vabaduse	doc_491521502107_item	2595211	et	4	main
kinkima	doc_491521502107_item	2595212	et	3	main
aleksender	doc_491521502107_item	2595213	et	4	main
otsis	doc_491521502107_item	2595214	et	4	main
jaoks	doc_491521502107_item	2595230	et	4	main
ta	doc_491521502107_item	2595231	et	4	main
koolitas	doc_491521502107_item	2595232	et	3	main
neid	doc_491521502107_item	2595233	et	4	main
välja	doc_491521502107_item	2595234	et	4	main
et	doc_491521502107_item	2595235	et	3	main
aitas	doc_491521502107_item	2595244	et	3	main
protsessile	doc_491521502107_item	2595245	et	3	main
tema	doc_491521502107_item	2595256	et	4	main
sündis	doc_491521502107_item	2595258	et	3	main
teine	doc_491521502107_item	2595259	et	3	main
aleksander	doc_491521502107_item	2595262	et	4	main
lenini	doc_491521502107_item	2595264	et	4	main
venemaad	doc_491521502107_item	2595274	et	4	main
see	doc_491521502107_item	2595289	et	3	main
isegi	doc_491521502107_item	2595301	et	4	main
naine	doc_491521502107_item	2595302	et	3	main
ja	doc_491521502107_item	2595303	et	3	main
olulised	doc_491521502107_item	2595309	et	4	main
lenin	doc_491521502107_item	2595342	et	4	main
näidati	doc_491521502107_item	2595343	et	3	main
rumala	doc_491521502107_item	2595347	et	3	main
kelle	doc_491521502107_item	2595349	et	4	main
olid	doc_491521502107_item	2595352	et	4	main
ning	doc_491521502107_item	2595354	et	3	main
mõrtsukad	doc_491521502107_item	2595368	et	3	main
idee	doc_491521502107_item	2595379	et	4	main
autori	doc_491521502107_item	2595384	et	3	main
käitumises	doc_491521502107_item	2595421	et	4	main
episoodi	doc_491521502107_item	2595423	et	4	main
kus	doc_491521502107_item	2595425	et	3	main
lenin	doc_491521502107_item	2595426	et	4	main
tabab	doc_491521502107_item	2595427	et	3	main
peavad	doc_491521502107_item	2595433	et	4	main
lihtsalt	doc_491521502107_item	2595443	et	4	main
jai	doc_491521502107_item	2595452	et	4	main
aeg	doc_491521502107_item	2595467	et	3	main
teda	doc_491521502107_item	2595469	et	4	main
targaks	doc_491521502107_item	2595471	et	3	main
ning	doc_491521502107_item	2595472	et	3	main
hea	doc_491521502107_item	2595473	et	4	main
haridusega	doc_491521502107_item	2595474	et	3	main
meheks	doc_491521502107_item	2595475	et	3	main
kes	doc_491521502107_item	2595476	et	4	main
armastas	doc_491521502107_item	2595477	et	3	main
ta	doc_491521502107_item	2595486	et	4	main
mulle	doc_491521502107_item	2595506	et	4	main
toime	doc_491521502107_item	2595529	et	4	main
liikuma	doc_491521502107_item	2595539	et	3	main
nälg	doc_491521502107_item	2595559	et	3	main
ei	doc_491521502107_item	2595562	et	4	main
saama	doc_491521502107_item	2595567	et	4	main
valitsuse	doc_491521502107_item	2595570	et	4	main
ei	doc_491521502107_item	2595574	et	4	main
olnud	doc_491521502107_item	2595575	et	4	main
uppuvaid	doc_491521502107_item	2595622	et	4	main
luksuses	doc_491521502107_item	2595623	et	4	main
kui	doc_491521502107_item	2595633	et	3	main
pensionäärid	doc_491521502107_item	2595637	et	4	main
jõudu	doc_491521502107_item	2595643	et	4	main
ning	doc_491521502107_item	2595644	et	3	main
tervise	doc_491521502107_item	2595645	et	3	main
eestimaa	doc_491521502107_item	2595646	et	4	main
sorima	doc_491521502107_item	2595650	et	3	main
seast	doc_491521502107_item	2595674	et	4	main
saartele	doc_491521502107_item	2595686	et	3	main
päästaks	doc_491521502107_item	2595698	et	4	main
on	doc_491521502107_item	2595703	et	4	main
praeguses	doc_491521502107_item	2595711	et	3	main
mul	doc_491521502107_item	2595713	et	3	main
kaitsmise	doc_491521502107_item	2595229	et	4	main
nende	doc_491521502107_item	2595236	et	4	main
hiljem	doc_491521502107_item	2595246	et	3	main
et	doc_491521502107_item	2595249	et	3	main
bolsevik	doc_491521502107_item	2595250	et	4	main
ei	doc_491521502107_item	2595251	et	4	main
kavatsegi	doc_491521502107_item	2595252	et	4	main
eestimaale	doc_491521502107_item	2595253	et	4	main
sõltumatuse	doc_491521502107_item	2595254	et	4	main
plaan	doc_491521502107_item	2595260	et	3	main
hakkasid	doc_491521502107_item	2595273	et	4	main
a	doc_491521502107_item	2595283	et	4	main
keskküla	doc_491521502107_item	2595284	et	4	main
kaudu	doc_491521502107_item	2595285	et	3	main
näitas	doc_491521502107_item	2595286	et	3	main
eluga	doc_491521502107_item	2595292	et	3	main
ta	doc_491521502107_item	2595296	et	4	main
laps	doc_491521502107_item	2595304	et	4	main
isamaa-armastus	doc_491521502107_item	2595315	et	4	main
hea	doc_491521502107_item	2595318	et	4	main
tulevikusse	doc_491521502107_item	2595319	et	4	main
niisuguseid	doc_491521502107_item	2595320	et	3	main
lenin	doc_491521502107_item	2595269	et	4	main
uppus	doc_491521502107_item	2595270	et	3	main
meres	doc_491521502107_item	2595271	et	3	main
mulle	doc_491521502107_item	2595279	et	4	main
meeldis	doc_491521502107_item	2595280	et	3	main
kuidas	doc_491521502107_item	2595281	et	3	main
patriotismi	doc_491521502107_item	2595288	et	4	main
riskis	doc_491521502107_item	2595291	et	4	main
oma	doc_491521502107_item	2595293	et	4	main
eesmärgi	doc_491521502107_item	2595294	et	4	main
terve	doc_491521502107_item	2595299	et	4	main
elu	doc_491521502107_item	2595300	et	4	main
talle	doc_491521502107_item	2595307	et	4	main
nii	doc_491521502107_item	2595308	et	3	main
omakasupüüdlematu	doc_491521502107_item	2595314	et	4	main
sünnimaa	doc_491521502107_item	2595317	et	4	main
on	doc_491521502107_item	2595322	et	4	main
v	doc_491521502107_item	2595341	et	4	main
taktitundetu	doc_491521502107_item	2595345	et	4	main
tulid	doc_491521502107_item	2595361	et	4	main
teisikud	doc_491521502107_item	2595362	et	3	main
nad	doc_491521502107_item	2595363	et	3	main
mõistsin	doc_491521502107_item	2595377	et	3	main
arvan	doc_491521502107_item	2595382	et	3	main
ja	doc_491521502107_item	2595420	et	3	main
tõeliseks	doc_491521502107_item	2595434	et	4	main
on	doc_491521502107_item	2595444	et	4	main
hull	doc_491521502107_item	2595445	et	3	main
ei	doc_491521502107_item	2595446	et	4	main
selline	doc_491521502107_item	2595455	et	4	main
lavastaja	doc_491521502107_item	2595458	et	4	main
kogu	doc_491521502107_item	2595466	et	4	main
venemaad	doc_491521502107_item	2595478	et	4	main
oma	doc_491521502107_item	2595484	et	4	main
ekspluateerimise	doc_491521502107_item	2595493	et	4	main
vastu	doc_491521502107_item	2595497	et	3	main
aastate	doc_491521502107_item	2595499	et	3	main
kujunenud	doc_491521502107_item	2595501	et	4	main
ning	doc_491521502107_item	2595509	et	3	main
piltidega	doc_491521502107_item	2595512	et	3	main
temana	doc_491521502107_item	2595518	et	3	main
joonistatud	doc_491521502107_item	2595519	et	4	main
ei	doc_491521502107_item	2595522	et	4	main
venemaal	doc_491521502107_item	2595528	et	4	main
enda	doc_491521502107_item	2595537	et	4	main
läks	doc_491521502107_item	2595546	et	3	main
ilma	doc_491521502107_item	2595548	et	4	main
nikolai	doc_491521502107_item	2595560	et	4	main
ning	doc_491521502107_item	2595568	et	3	main
saaks	doc_491521502107_item	2595590	et	3	main
poliitikuid	doc_491521502107_item	2595624	et	3	main
pidevalt	doc_491521502107_item	2595626	et	4	main
tõstavad	doc_491521502107_item	2595627	et	3	main
endale	doc_491521502107_item	2595628	et	4	main
niigi	doc_491521502107_item	2595629	et	4	main
need	doc_491521502107_item	2595636	et	3	main
ära	doc_491521502107_item	2595639	et	4	main
on	doc_491521502107_item	2595648	et	4	main
pügikastides	doc_491521502107_item	2595651	et	4	main
kopikates	doc_491521502107_item	2595654	et	3	main
poliitikute	doc_491521502107_item	2595673	et	3	main
jne	doc_491521502107_item	2595689	et	4	main
järjekordses	doc_491521502107_item	2595691	et	3	main
lastehaiglas	doc_491521502107_item	2595692	et	3	main
hulgast	doc_491521502107_item	2595708	et	4	main
kinematograafia	doc_491521502107_item	2595719	et	4	main
ning	doc_491521502107_item	2595723	et	3	main
bolsevikide	doc_491521502107_item	2595724	et	4	main
on	doc_491521502107_item	2595726	et	4	main
mõeldut	doc_491521502107_item	2595727	et	4	main
elu	doc_491521502107_item	2595736	et	4	main
oli	doc_491521502107_item	2595738	et	3	main
keegi	doc_491521502107_item	2595740	et	4	main
asjad	doc_491521502107_item	2595745	et	3	main
on	doc_491521502107_item	2595746	et	4	main
näljakas	doc_491521502107_item	2595747	et	4	main
kui	doc_491521502107_item	2595753	et	3	main
head	doc_491521502107_item	2595763	et	4	main
jaab	doc_491521502107_item	2595773	et	4	main
tähtis	doc_491521502107_item	2595776	et	4	main
võim	doc_491521502107_item	2595779	et	3	main
ning	doc_491521502107_item	2595313	et	3	main
vähe	doc_491521502107_item	2595324	et	3	main
seas	doc_491521502107_item	2595330	et	4	main
häbenevad	doc_491521502107_item	2595340	et	4	main
jõhkra	doc_491521502107_item	2595344	et	3	main
ning	doc_491521502107_item	2595346	et	3	main
joodikuna	doc_491521502107_item	2595348	et	3	main
lemmikud	doc_491521502107_item	2595350	et	3	main
kaklused	doc_491521502107_item	2595355	et	3	main
baaris	doc_491521502107_item	2595357	et	3	main
tema	doc_491521502107_item	2595359	et	4	main
asemele	doc_491521502107_item	2595360	et	4	main
filmi	doc_491521502107_item	2595378	et	4	main
et	doc_491521502107_item	2595383	et	3	main
jaoks	doc_491521502107_item	2595385	et	4	main
oli	doc_491521502107_item	2595387	et	3	main
kõikide	doc_491521502107_item	2595388	et	4	main
too	doc_491521502107_item	2595422	et	4	main
kaudu	doc_491521502107_item	2595424	et	3	main
kõik	doc_491521502107_item	2595432	et	4	main
kuidagi	doc_491521502107_item	2595453	et	3	main
a	doc_491521502107_item	2595482	et	4	main
keskküla	doc_491521502107_item	2595483	et	4	main
töötajate	doc_491521502107_item	2595492	et	4	main
ebavõrdsuse	doc_491521502107_item	2595496	et	4	main
arvamus	doc_491521502107_item	2595502	et	3	main
ei	doc_491521502107_item	2595504	et	4	main
luba	doc_491521502107_item	2595505	et	4	main
nende	doc_491521502107_item	2595510	et	4	main
mis	doc_491521502107_item	2595513	et	4	main
filmiautor	doc_491521502107_item	2595514	et	3	main
teoses	doc_491521502107_item	2595516	et	3	main
klounid	doc_491521502107_item	2595520	et	3	main
kunagi	doc_491521502107_item	2595521	et	3	main
tulla	doc_491521502107_item	2595530	et	3	main
korralikult	doc_491521502107_item	2595531	et	4	main
ning	doc_491521502107_item	2595534	et	3	main
ei	doc_491521502107_item	2595545	et	4	main
inimsurma	doc_491521502107_item	2595549	et	4	main
ning	doc_491521502107_item	2595550	et	3	main
vereta	doc_491521502107_item	2595551	et	4	main
aga	doc_491521502107_item	2595552	et	3	main
sunnade	doc_491521502107_item	2595572	et	3	main
juhtimisel	doc_491521502107_item	2595579	et	4	main
teda	doc_491521502107_item	2595582	et	4	main
seda	doc_491521502107_item	2595586	et	3	main
kinematograafias	doc_491521502107_item	2595326	et	3	main
inimeste	doc_491521502107_item	2595329	et	3	main
patriotism	doc_491521502107_item	2595331	et	3	main
ei	doc_491521502107_item	2595332	et	4	main
ole	doc_491521502107_item	2595333	et	4	main
nii	doc_491521502107_item	2595334	et	3	main
populaarne	doc_491521502107_item	2595335	et	3	main
mõned	doc_491521502107_item	2595336	et	3	main
isegi	doc_491521502107_item	2595337	et	4	main
seda	doc_491521502107_item	2595338	et	3	main
tunnet	doc_491521502107_item	2595339	et	3	main
meelelahutused	doc_491521502107_item	2595351	et	4	main
olid	doc_491521502107_item	2595364	et	4	main
endised	doc_491521502107_item	2595365	et	3	main
vargad	doc_491521502107_item	2595366	et	3	main
kaltsakad	doc_491521502107_item	2595367	et	3	main
ma	doc_491521502107_item	2595376	et	3	main
aga	doc_491521502107_item	2595381	et	3	main
inimpattude	doc_491521502107_item	2595389	et	3	main
kehastus	doc_491521502107_item	2595390	et	4	main
ning	doc_491521502107_item	2595391	et	3	main
tema	doc_491521502107_item	2595392	et	4	main
teisikud	doc_491521502107_item	2595393	et	3	main
olidki	doc_491521502107_item	2595394	et	4	main
need	doc_491521502107_item	2595395	et	3	main
pahed	doc_491521502107_item	2595396	et	3	main
oli	doc_491521502107_item	2595398	et	3	main
ta	doc_491521502107_item	2595397	et	4	main
nii	doc_491521502107_item	2595399	et	3	main
nõrk	doc_491521502107_item	2595400	et	3	main
et	doc_491521502107_item	2595401	et	3	main
lõppuks	doc_491521502107_item	2595402	et	3	main
läks	doc_491521502107_item	2595403	et	3	main
segi	doc_491521502107_item	2595404	et	3	main
rezissööril	doc_491521502107_item	2595405	et	4	main
ning	doc_491521502107_item	2595406	et	3	main
lenini	doc_491521502107_item	2595407	et	4	main
näitlejal	doc_491521502107_item	2595409	et	4	main
mängival	doc_491521502107_item	2595408	et	4	main
õnnestus	doc_491521502107_item	2595410	et	4	main
näidata	doc_491521502107_item	2595411	et	4	main
tõelist	doc_491521502107_item	2595412	et	4	main
hirmu	doc_491521502107_item	2595413	et	4	main
pettumust	doc_491521502107_item	2595414	et	4	main
abitust	doc_491521502107_item	2595415	et	4	main
ja	doc_491521502107_item	2595416	et	3	main
tähtsusetust	doc_491521502107_item	2595417	et	4	main
inimese	doc_491521502107_item	2595418	et	4	main
silmides	doc_491521502107_item	2595419	et	3	main
oma	doc_491521502107_item	2595428	et	4	main
ning	doc_491521502107_item	2595435	et	3	main
temas	doc_491521502107_item	2595436	et	3	main
ehk	doc_491521502107_item	2595437	et	3	main
õiges	doc_491521502107_item	2595438	et	3	main
lenenis	doc_491521502107_item	2595439	et	4	main
näevad	doc_491521502107_item	2595440	et	3	main
teisikku	doc_491521502107_item	2595441	et	4	main
kes	doc_491521502107_item	2595442	et	4	main
miks	doc_491521502107_item	2595448	et	4	main
aga	doc_491521502107_item	2595449	et	3	main
see	doc_491521502107_item	2595450	et	3	main
lõik	doc_491521502107_item	2595451	et	3	main
kohal	doc_491521502107_item	2595429	et	4	main
teisiku	doc_491521502107_item	2595430	et	3	main
kelle	doc_491521502107_item	2595431	et	4	main
tea	doc_491521502107_item	2595447	et	4	main
hingesse	doc_491521502107_item	2595454	et	4	main
lenin	doc_491521502107_item	2595457	et	4	main
jaoks	doc_491521502107_item	2595459	et	4	main
minu	doc_491521502107_item	2595460	et	3	main
oma	doc_491521502107_item	2595461	et	4	main
erineb	doc_491521502107_item	2595462	et	3	main
rezissööri	doc_491521502107_item	2595463	et	4	main
kangelasest	doc_491521502107_item	2595464	et	3	main
ma	doc_491521502107_item	2595465	et	3	main
mitte	doc_491521502107_item	2595479	et	3	main
vähem	doc_491521502107_item	2595480	et	4	main
kui	doc_491521502107_item	2595481	et	3	main
oli	doc_491521502107_item	2595487	et	3	main
ülemvõimu	doc_491521502107_item	2595489	et	4	main
ning	doc_491521502107_item	2595494	et	3	main
see	doc_491521502107_item	2595498	et	3	main
välja	doc_491521502107_item	2595500	et	4	main
kunagi	doc_491521502107_item	2595503	et	3	main
liidri	doc_491521502107_item	2595511	et	3	main
oma	doc_491521502107_item	2595515	et	4	main
suudaks	doc_491521502107_item	2595523	et	3	main
ega	doc_491521502107_item	2595525	et	3	main
füüsiliselt	doc_491521502107_item	2595526	et	4	main
revolutsiooniga	doc_491521502107_item	2595527	et	3	main
suured	doc_491521502107_item	2595535	et	3	main
järel	doc_491521502107_item	2595538	et	4	main
jah	doc_491521502107_item	2595541	et	3	main
poliitika	doc_491521502107_item	2595543	et	4	main
tõepoolest	doc_491521502107_item	2595544	et	3	main
läbi	doc_491521502107_item	2595566	et	4	main
vähem	doc_491521502107_item	2595576	et	4	main
kui	doc_491521502107_item	2595577	et	3	main
bolsevikide	doc_491521502107_item	2595578	et	4	main
pidi	doc_491521502107_item	2595581	et	4	main
poleks	doc_491521502107_item	2595585	et	3	main
on	doc_491521502107_item	2595620	et	4	main
vaatlema	doc_491521502107_item	2595621	et	3	main
kes	doc_491521502107_item	2595625	et	4	main
ajal	doc_491521502107_item	2595635	et	4	main
et	doc_491521502107_item	2595652	et	3	main
elada	doc_491521502107_item	2595656	et	3	main
või	doc_491521502107_item	2595676	et	4	main
puhkusele	doc_491521502107_item	2595683	et	4	main
kusagile	doc_491521502107_item	2595684	et	3	main
kanaari	doc_491521502107_item	2595685	et	4	main
eest	doc_491521502107_item	2595688	et	4	main
tuhandeid	doc_491521502107_item	2595699	et	3	main
need	doc_491521502107_item	2595702	et	3	main
mõned	doc_491521502107_item	2595705	et	3	main
nõukogude	doc_491521502107_item	2595722	et	3	main
ajast	doc_491521502107_item	2595725	et	4	main
selleks	doc_491521502107_item	2595728	et	4	main
et	doc_491521502107_item	2595729	et	3	main
inimesed	doc_491521502107_item	2595730	et	3	main
istuksid	doc_491521502107_item	2595731	et	4	main
ja	doc_491521502107_item	2595732	et	3	main
kui	doc_491521502107_item	2595734	et	3	main
et	doc_491521502107_item	2595750	et	3	main
muutub	doc_491521502107_item	2595755	et	3	main
praegu	doc_491521502107_item	2595765	et	3	main
enam	doc_491521502107_item	2595766	et	4	main
vähem	doc_491521502107_item	2595767	et	4	main
aga	doc_491521502107_item	2595771	et	3	main
milline	doc_491521502107_item	2595777	et	3	main
poliitiline	doc_491521502107_item	2595778	et	3	main
ühed	doc_491521502107_item	2595781	et	3	main
need	doc_491521502107_item	2595789	et	3	main
on	doc_491521502107_item	2595791	et	4	main
lihtsad	doc_491521502107_item	2595794	et	3	main
millal	doc_491521502107_item	2595797	et	3	main
elaksid	doc_491521502107_item	2595799	et	4	main
õnelikkult	doc_491521502107_item	2595800	et	4	main
on	doc_491521502107_item	2595801	et	4	main
võimalik	doc_491521502107_item	2595802	et	3	main
maa	doc_491521502107_item	2595807	et	4	main
temast	doc_491521502107_item	2595827	et	3	main
veiderdajat	doc_491521502107_item	2595828	et	4	main
kuidagi	doc_491521502107_item	2595831	et	3	main
on	doc_491521502107_item	2595456	et	4	main
kujutlesin	doc_491521502107_item	2595468	et	3	main
ette	doc_491521502107_item	2595470	et	4	main
sünnimaad	doc_491521502107_item	2595485	et	4	main
monopolijate	doc_491521502107_item	2595488	et	4	main
kapitalismi	doc_491521502107_item	2595490	et	4	main
hundiseaduste	doc_491521502107_item	2595491	et	4	main
ühiskondliku	doc_491521502107_item	2595495	et	3	main
nõustada	doc_491521502107_item	2595507	et	3	main
bolsevikide	doc_491521502107_item	2595508	et	4	main
näitas	doc_491521502107_item	2595517	et	3	main
moraalselt	doc_491521502107_item	2595524	et	4	main
organizeerida	doc_491521502107_item	2595532	et	4	main
seda	doc_491521502107_item	2595533	et	3	main
rahvamassid	doc_491521502107_item	2595536	et	3	main
panna	doc_491521502107_item	2595540	et	4	main
nende	doc_491521502107_item	2595542	et	4	main
lähi	doc_491521502107_item	2595547	et	4	main
tool	doc_491521502107_item	2595553	et	3	main
ajal	doc_491521502107_item	2595554	et	4	main
riigis	doc_491521502107_item	2595555	et	3	main
oli	doc_491521502107_item	2595556	et	3	main
kriis	doc_491521502107_item	2595557	et	3	main
ja	doc_491521502107_item	2595558	et	3	main
ii	doc_491521502107_item	2595561	et	4	main
olnud	doc_491521502107_item	2595563	et	4	main
võimeline	doc_491521502107_item	2595564	et	4	main
sellega	doc_491521502107_item	2595565	et	3	main
tema	doc_491521502107_item	2595569	et	4	main
ajal	doc_491521502107_item	2595571	et	4	main
arv	doc_491521502107_item	2595573	et	3	main
keegi	doc_491521502107_item	2595580	et	4	main
asendada	doc_491521502107_item	2595583	et	3	main
kui	doc_491521502107_item	2595584	et	3	main
teinud	doc_491521502107_item	2595587	et	4	main
sotsiaaldemokraatid	doc_491521502107_item	2595588	et	4	main
siis	doc_491521502107_item	2595589	et	3	main
sellega	doc_491521502107_item	2595591	et	3	main
hakkama	doc_491521502107_item	2595592	et	3	main
mingi	doc_491521502107_item	2595593	et	4	main
teine	doc_491521502107_item	2595594	et	3	main
võim	doc_491521502107_item	2595595	et	3	main
mul	doc_491521502107_item	2595596	et	3	main
tekkis	doc_491521502107_item	2595597	et	3	main
üks	doc_491521502107_item	2595598	et	3	main
küsimus	doc_491521502107_item	2595599	et	4	main
kui	doc_491521502107_item	2595600	et	3	main
seda	doc_491521502107_item	2595601	et	3	main
lindi	doc_491521502107_item	2595602	et	4	main
vaatasin	doc_491521502107_item	2595603	et	3	main
miks	doc_491521502107_item	2595604	et	4	main
keegi	doc_491521502107_item	2595605	et	4	main
ei	doc_491521502107_item	2595606	et	4	main
filmi	doc_491521502107_item	2595607	et	4	main
midagi	doc_491521502107_item	2595608	et	4	main
reaalsest	doc_491521502107_item	2595609	et	4	main
tänapäevasest	doc_491521502107_item	2595610	et	4	main
elust	doc_491521502107_item	2595611	et	3	main
või	doc_491521502107_item	2595612	et	4	main
ta	doc_491521502107_item	2595613	et	4	main
lihtsalt	doc_491521502107_item	2595614	et	4	main
ei	doc_491521502107_item	2595615	et	4	main
pääse	doc_491521502107_item	2595616	et	4	main
eetrisse	doc_491521502107_item	2595617	et	3	main
kus	doc_491521502107_item	2595618	et	3	main
ebameeldiv	doc_491521502107_item	2595619	et	3	main
liiga	doc_491521502107_item	2595630	et	4	main
suured	doc_491521502107_item	2595631	et	3	main
palgad	doc_491521502107_item	2595632	et	3	main
samal	doc_491521502107_item	2595634	et	3	main
kes	doc_491521502107_item	2595638	et	4	main
andsid	doc_491521502107_item	2595640	et	4	main
oma	doc_491521502107_item	2595641	et	4	main
sunnitud	doc_491521502107_item	2595649	et	4	main
kuidagi	doc_491521502107_item	2595653	et	3	main
välja	doc_491521502107_item	2595655	et	4	main
maha	doc_491521502107_item	2595681	et	4	main
lendas	doc_491521502107_item	2595682	et	3	main
riigiraha	doc_491521502107_item	2595687	et	4	main
aga	doc_491521502107_item	2595690	et	3	main
mis	doc_491521502107_item	2595697	et	4	main
elu	doc_491521502107_item	2595701	et	4	main
mõnikord	doc_491521502107_item	2595712	et	3	main
selline	doc_491521502107_item	2595715	et	4	main
tänapäeva	doc_491521502107_item	2595718	et	4	main
räägib	doc_491521502107_item	2595721	et	3	main
ega	doc_491521502107_item	2595739	et	3	main
praegu	doc_491521502107_item	2595744	et	3	main
on	doc_491521502107_item	2595748	et	4	main
see	doc_491521502107_item	2595749	et	3	main
hakkavad	doc_491521502107_item	2595756	et	4	main
halba	doc_491521502107_item	2595760	et	4	main
rääkima	doc_491521502107_item	2595761	et	3	main
ning	doc_491521502107_item	2595762	et	3	main
on	doc_491521502107_item	2595768	et	4	main
fakt	doc_491521502107_item	2595772	et	3	main
pole	doc_491521502107_item	2595775	et	3	main
kogu	doc_491521502107_item	2595782	et	4	main
aeg	doc_491521502107_item	2595783	et	3	main
elavad	doc_491521502107_item	2595784	et	4	main
kõik	doc_491521502107_item	2595798	et	4	main
paradiis	doc_491521502107_item	2595806	et	3	main
ei	doc_491521502107_item	2595823	et	4	main
rääkida	doc_491521502108_item	2595839	et	3	main
minu	doc_491521502108_item	2595851	et	3	main
leninid	doc_491521502108_item	2595852	et	4	main
siis	doc_491521502108_item	2595853	et	3	main
on	doc_491521502108_item	2595861	et	4	main
ma	doc_491521502108_item	2595864	et	3	main
osanudki	doc_491521502108_item	2595866	et	4	main
isegi	doc_491521502108_item	2595867	et	4	main
ei	doc_491521502108_item	2595876	et	4	main
et	doc_491521502108_item	2595881	et	3	main
üldse	doc_491521502108_item	2595883	et	3	main
tea	doc_491521502108_item	2595885	et	4	main
oleks	doc_491521502108_item	2595892	et	3	main
kes	doc_491521502108_item	2595897	et	4	main
nooruse	doc_491521502107_item	2595642	et	4	main
peale	doc_491521502107_item	2595647	et	4	main
mis	doc_491521502107_item	2595657	et	4	main
riig	doc_491521502107_item	2595658	et	4	main
neile	doc_491521502107_item	2595659	et	4	main
lahkelt	doc_491521502107_item	2595660	et	4	main
eritab	doc_491521502107_item	2595661	et	3	main
vahepeal	doc_491521502107_item	2595662	et	3	main
on	doc_491521502107_item	2595663	et	4	main
isegi	doc_491521502107_item	2595664	et	4	main
vastik	doc_491521502107_item	2595665	et	3	main
kuulata	doc_491521502107_item	2595666	et	4	main
raadiost	doc_491521502107_item	2595667	et	3	main
sellest	doc_491521502107_item	2595668	et	4	main
kui	doc_491521502107_item	2595669	et	3	main
tetavad	doc_491521502107_item	2595670	et	4	main
et	doc_491521502107_item	2595671	et	3	main
keegi	doc_491521502107_item	2595672	et	4	main
varastas	doc_491521502107_item	2595675	et	3	main
mängis	doc_491521502107_item	2595677	et	3	main
kasinos	doc_491521502107_item	2595678	et	4	main
mingi	doc_491521502107_item	2595679	et	4	main
miljoni	doc_491521502107_item	2595680	et	3	main
ei	doc_491521502107_item	2595693	et	4	main
jatku	doc_491521502107_item	2595694	et	4	main
finantsvahendeid	doc_491521502107_item	2595695	et	3	main
aparaadile	doc_491521502107_item	2595696	et	3	main
laste	doc_491521502107_item	2595700	et	4	main
ainult	doc_491521502107_item	2595704	et	4	main
ühikud	doc_491521502107_item	2595706	et	3	main
ebaõigluse	doc_491521502107_item	2595707	et	4	main
mis	doc_491521502107_item	2595709	et	4	main
toimub	doc_491521502107_item	2595710	et	3	main
tuleb	doc_491521502107_item	2595714	et	3	main
mõtte	doc_491521502107_item	2595716	et	3	main
et	doc_491521502107_item	2595717	et	3	main
mis	doc_491521502107_item	2595720	et	4	main
arutleksid	doc_491521502107_item	2595733	et	4	main
siis	doc_491521502107_item	2595737	et	3	main
pärast	doc_491521502107_item	2595752	et	4	main
tänapäeva	doc_491521502107_item	2595757	et	4	main
elust	doc_491521502107_item	2595758	et	3	main
ainult	doc_491521502107_item	2595759	et	4	main
hoidma	doc_491521502107_item	2595770	et	3	main
teiste	doc_491521502107_item	2595785	et	4	main
arvul	doc_491521502107_item	2595786	et	3	main
teised	doc_491521502107_item	2595790	et	4	main
ausad	doc_491521502107_item	2595792	et	3	main
ning	doc_491521502107_item	2595793	et	3	main
olukord	doc_491521502107_item	2595796	et	3	main
on	doc_491521502107_item	2595809	et	4	main
see	doc_491521502107_item	2595821	et	3	main
et	doc_491521502107_item	2595826	et	3	main
siis	doc_491521502108_item	2595840	et	3	main
et	doc_491521502108_item	2595859	et	3	main
veider	doc_491521502108_item	2595863	et	3	main
kujutada	doc_491521502108_item	2595870	et	3	main
millest	doc_491521502108_item	2595871	et	3	main
see	doc_491521502108_item	2595872	et	3	main
film	doc_491521502108_item	2595873	et	3	main
ma	doc_491521502108_item	2595882	et	3	main
ei	doc_491521502108_item	2595884	et	4	main
oli	doc_491521502108_item	2595888	et	3	main
see	doc_491521502108_item	2595891	et	3	main
tingimata	doc_491521502108_item	2595894	et	4	main
lenin	doc_491521502108_item	2595899	et	4	main
et	doc_491521502108_item	2595921	et	3	main
selle	doc_491521502108_item	2595935	et	4	main
põhjendatud	doc_491521502108_item	2595940	et	4	main
sain	doc_491521502108_item	2595955	et	3	main
mitte	doc_491521502108_item	2595961	et	3	main
aleksander	doc_491521502108_item	2595965	et	4	main
millised	doc_491521502108_item	2595971	et	3	main
õeti	doc_491521502108_item	2595976	et	4	main
tahtis	doc_491521502108_item	2595980	et	3	main
purustamine	doc_491521502108_item	2595991	et	4	main
väljaviskamine	doc_491521502108_item	2595998	et	3	main
sünniks	doc_491521502108_item	2596021	et	4	main
kui	doc_491521502108_item	2596025	et	3	main
seda	doc_491521502108_item	2596030	et	3	main
on	doc_491521502108_item	2596046	et	4	main
välja	doc_491521502108_item	2596050	et	4	main
kui	doc_491521502108_item	2596052	et	3	main
õpiti	doc_491521502108_item	2596063	et	3	main
lõppus	doc_491521502108_item	2596074	et	4	main
halb	doc_491521502107_item	2595735	et	3	main
ei	doc_491521502107_item	2595741	et	4	main
vaadaks	doc_491521502107_item	2595742	et	4	main
kuidas	doc_491521502107_item	2595743	et	3	main
aastade	doc_491521502107_item	2595751	et	4	main
võim	doc_491521502107_item	2595754	et	3	main
mis	doc_491521502107_item	2595764	et	4	main
salajas	doc_491521502107_item	2595769	et	3	main
faktiks	doc_491521502107_item	2595774	et	3	main
kõige	doc_491521502107_item	2595787	et	4	main
ainult	doc_491521502107_item	2595803	et	4	main
paradiisis	doc_491521502107_item	2595804	et	3	main
peal	doc_491521502107_item	2595808	et	4	main
võimatu	doc_491521502107_item	2595810	et	4	main
võib	doc_491521502107_item	2595811	et	3	main
olla	doc_491521502107_item	2595812	et	3	main
lenin	doc_491521502107_item	2595813	et	4	main
ei	doc_491521502107_item	2595814	et	4	main
olnud	doc_491521502107_item	2595815	et	4	main
ideaalne	doc_491521502107_item	2595816	et	3	main
kusagil	doc_491521502107_item	2595817	et	3	main
isegi	doc_491521502107_item	2595818	et	4	main
julm	doc_491521502107_item	2595819	et	3	main
aga	doc_491521502107_item	2595820	et	3	main
veel	doc_491521502107_item	2595822	et	4	main
ole	doc_491521502107_item	2595824	et	4	main
teha	doc_491521502107_item	2595829	et	3	main
ebaviisakalt	doc_491521502107_item	2595832	et	4	main
kui	doc_491521502108_item	2595837	et	3	main
et	doc_491521502108_item	2595845	et	3	main
ma	doc_491521502108_item	2595847	et	3	main
nimetust	doc_491521502108_item	2595850	et	4	main
järsku	doc_491521502108_item	2595854	et	4	main
mul	doc_491521502108_item	2595855	et	3	main
kujunes	doc_491521502108_item	2595856	et	3	main
niisugune	doc_491521502108_item	2595857	et	3	main
arvamus	doc_491521502108_item	2595858	et	3	main
ette	doc_491521502108_item	2595869	et	4	main
jutustab	doc_491521502108_item	2595874	et	3	main
et	doc_491521502108_item	2595878	et	3	main
mõtleks	doc_491521502108_item	2595880	et	3	main
lenin	doc_491521502108_item	2595887	et	4	main
vastasel	doc_491521502108_item	2595889	et	3	main
kummaline	doc_491521502108_item	2595893	et	3	main
tean	doc_491521502108_item	2595896	et	3	main
ajaloo	doc_491521502108_item	2595922	et	4	main
pilgu	doc_491521502108_item	2595923	et	4	main
lenin	doc_491521502108_item	2595925	et	4	main
üks	doc_491521502108_item	2595927	et	3	main
ainuke	doc_491521502108_item	2595928	et	4	main
ja	doc_491521502108_item	2595929	et	3	main
ma	doc_491521502108_item	2595930	et	3	main
arvan	doc_491521502108_item	2595931	et	3	main
et	doc_491521502108_item	2595932	et	3	main
veidrus	doc_491521502108_item	2595934	et	4	main
täiesti	doc_491521502108_item	2595939	et	3	main
öelda	doc_491521502108_item	2595959	et	4	main
mida	doc_491521502108_item	2595967	et	4	main
õeti	doc_491521502108_item	2595968	et	4	main
ma	doc_491521502108_item	2595975	et	3	main
mis	doc_491521502108_item	2595982	et	4	main
oli	doc_491521502108_item	2595983	et	3	main
surve	doc_491521502108_item	2595994	et	4	main
leninita	doc_491521502108_item	2596003	et	4	main
vaadates	doc_491521502108_item	2596004	et	3	main
seda	doc_491521502108_item	2596005	et	3	main
mul	doc_491521502108_item	2596007	et	3	main
jäi	doc_491521502108_item	2596008	et	3	main
meelde	doc_491521502108_item	2596009	et	3	main
üks	doc_491521502108_item	2596010	et	3	main
lause	doc_491521502108_item	2596011	et	4	main
valitseb	doc_491521502107_item	2595780	et	3	main
sagedam	doc_491521502107_item	2595788	et	4	main
töölised	doc_491521502107_item	2595795	et	3	main
aga	doc_491521502107_item	2595805	et	3	main
põhjus	doc_491521502107_item	2595825	et	4	main
tuleb	doc_491521502107_item	2595830	et	3	main
tõsiselt	doc_491521502108_item	2595838	et	4	main
ausalt	doc_491521502108_item	2595842	et	4	main
seda	doc_491521502108_item	2595844	et	3	main
kui	doc_491521502108_item	2595846	et	3	main
seda	doc_491521502108_item	2595849	et	3	main
muidugi	doc_491521502108_item	2595875	et	4	main
keegi	doc_491521502108_item	2595879	et	4	main
ma	doc_491521502108_item	2595895	et	3	main
tema	doc_491521502108_item	2595903	et	4	main
minu	doc_491521502108_item	2595901	et	3	main
teadmised	doc_491521502108_item	2595902	et	4	main
kohta	doc_491521502108_item	2595904	et	4	main
on	doc_491521502108_item	2595905	et	4	main
pealiskaudselt	doc_491521502108_item	2595906	et	4	main
ja	doc_491521502108_item	2595907	et	3	main
ma	doc_491521502108_item	2595908	et	3	main
arvan	doc_491521502108_item	2595909	et	3	main
et	doc_491521502108_item	2595910	et	3	main
paljud	doc_491521502108_item	2595911	et	3	main
minu	doc_491521502108_item	2595912	et	3	main
eakaaslastest	doc_491521502108_item	2595913	et	4	main
oleksid	doc_491521502108_item	2595914	et	4	main
minuga	doc_491521502108_item	2595915	et	3	main
nõus	doc_491521502108_item	2595916	et	4	main
aga	doc_491521502108_item	2595917	et	3	main
ma	doc_491521502108_item	2595918	et	3	main
tean	doc_491521502108_item	2595919	et	3	main
täpselt	doc_491521502108_item	2595920	et	4	main
see	doc_491521502108_item	2595933	et	3	main
nüüd	doc_491521502108_item	2595941	et	4	main
filmi	doc_491521502108_item	2595944	et	4	main
seda	doc_491521502108_item	2595946	et	3	main
kõigest	doc_491521502108_item	2595956	et	4	main
täpselt	doc_491521502108_item	2595963	et	4	main
ta	doc_491521502108_item	2595969	et	4	main
tahtis	doc_491521502108_item	2595970	et	3	main
siis	doc_491521502108_item	2595978	et	3	main
seda	doc_491521502108_item	2595981	et	3	main
impeeriumi	doc_491521502108_item	2595990	et	4	main
venemaa	doc_491521502108_item	2595993	et	4	main
vähendamine	doc_491521502108_item	2595995	et	4	main
venelaste	doc_491521502108_item	2595997	et	4	main
või	doc_491521502108_item	2596001	et	4	main
välja	doc_491521502107_item	2595833	et	4	main
lenin	doc_491521502108_item	2595834	et	4	main
minu	doc_491521502108_item	2595835	et	3	main
leninid	doc_491521502108_item	2595836	et	4	main
pean	doc_491521502108_item	2595841	et	4	main
ütlema	doc_491521502108_item	2595843	et	3	main
kuulsin	doc_491521502108_item	2595848	et	3	main
see	doc_491521502108_item	2595860	et	3	main
liialt	doc_491521502108_item	2595862	et	4	main
ei	doc_491521502108_item	2595865	et	4	main
endale	doc_491521502108_item	2595868	et	4	main
tahaks	doc_491521502108_item	2595877	et	3	main
kes	doc_491521502108_item	2595886	et	4	main
juhul	doc_491521502108_item	2595890	et	3	main
oli	doc_491521502108_item	2595898	et	3	main
aga	doc_491521502108_item	2595900	et	3	main
vaadates	doc_491521502108_item	2595924	et	3	main
oli	doc_491521502108_item	2595926	et	3	main
on	doc_491521502108_item	2595938	et	4	main
koheselt	doc_491521502108_item	2595943	et	4	main
filmi	doc_491521502108_item	2595947	et	4	main
vaadates	doc_491521502108_item	2595948	et	3	main
aru	doc_491521502108_item	2595957	et	4	main
õigem	doc_491521502108_item	2595958	et	4	main
kes	doc_491521502108_item	2595962	et	4	main
oli	doc_491521502108_item	2595964	et	3	main
kesküla	doc_491521502108_item	2595966	et	4	main
tegevuseesmärgidkui	doc_491521502108_item	2595974	et	4	main
aimasin	doc_491521502108_item	2595977	et	3	main
ta	doc_491521502108_item	2595979	et	4	main
ebaõnnestunud	doc_491521502108_item	2595984	et	4	main
karl	doc_491521502108_item	2595985	et	4	main
12	doc_491521502108_item	2595986	et	2	main
ja	doc_491521502108_item	2595987	et	3	main
napoleonil	doc_491521502108_item	2595988	et	4	main
kolmandaks	doc_491521502108_item	2595996	et	4	main
euroopast	doc_491521502108_item	2595999	et	3	main
ilma	doc_491521502108_item	2596002	et	4	main
filmi	doc_491521502108_item	2596006	et	4	main
minu	doc_491521502108_item	2596022	et	3	main
ja	doc_491521502108_item	2596024	et	3	main
leniniga	doc_491521502108_item	2596026	et	4	main
midagi	doc_491521502108_item	2596027	et	4	main
teisi	doc_491521502108_item	2596038	et	4	main
see	doc_491521502108_item	2596048	et	3	main
on	doc_491521502108_item	2596054	et	4	main
rumal	doc_491521502108_item	2596055	et	3	main
ja	doc_491521502108_item	2596056	et	3	main
teda	doc_491521502108_item	2596057	et	4	main
võib	doc_491521502108_item	2596058	et	3	main
asendada	doc_491521502108_item	2596059	et	3	main
nagu	doc_491521502108_item	2596065	et	3	main
mõelda	doc_491521502108_item	2596067	et	4	main
nagu	doc_491521502108_item	2596071	et	3	main
teda	doc_491521502108_item	2596080	et	4	main
ta	doc_491521502108_item	2596083	et	4	main
ja	doc_491521502108_item	2596086	et	3	main
uppub	doc_491521502108_item	2596088	et	4	main
tahaks	doc_491521502108_item	2596090	et	3	main
kas	doc_491521502108_item	2596092	et	3	main
püüdles	doc_491521502108_item	2596098	et	3	main
arust	doc_491521502108_item	2596100	et	4	main
tegelased	doc_491521502108_item	2596104	et	3	main
nimetuse	doc_491521502108_item	2595936	et	4	main
kohta	doc_491521502108_item	2595937	et	4	main
asun	doc_491521502108_item	2595942	et	3	main
juurde	doc_491521502108_item	2595945	et	4	main
ma	doc_491521502108_item	2595949	et	3	main
ei	doc_491521502108_item	2595950	et	4	main
saa	doc_491521502108_item	2595951	et	4	main
öelda	doc_491521502108_item	2595952	et	4	main
et	doc_491521502108_item	2595953	et	3	main
ma	doc_491521502108_item	2595954	et	3	main
et	doc_491521502108_item	2595960	et	3	main
olid	doc_491521502108_item	2595972	et	4	main
tema	doc_491521502108_item	2595973	et	4	main
venemaa	doc_491521502108_item	2595989	et	4	main
teiseks	doc_491521502108_item	2595992	et	4	main
koos	doc_491521502108_item	2596000	et	4	main
selle	doc_491521502108_item	2596013	et	4	main
lause	doc_491521502108_item	2596014	et	4	main
mõte	doc_491521502108_item	2596015	et	3	main
oli	doc_491521502108_item	2596016	et	3	main
niisugune	doc_491521502108_item	2596017	et	3	main
ma	doc_491521502108_item	2596018	et	3	main
tahan	doc_491521502108_item	2596019	et	3	main
et	doc_491521502108_item	2596020	et	3	main
kuidagi	doc_491521502108_item	2596031	et	3	main
me	doc_491521502108_item	2596035	et	4	main
looma	doc_491521502108_item	2596037	et	4	main
aleksander	doc_491521502108_item	2596040	et	4	main
kesküla	doc_491521502108_item	2596041	et	4	main
ma	doc_491521502108_item	2596042	et	3	main
arvan	doc_491521502108_item	2596043	et	3	main
et	doc_491521502108_item	2596044	et	3	main
see	doc_491521502108_item	2596045	et	3	main
teiste	doc_491521502108_item	2596060	et	4	main
inimestega	doc_491521502108_item	2596061	et	3	main
tõelist	doc_491521502108_item	2596075	et	4	main
enam	doc_491521502108_item	2596081	et	4	main
hüppab	doc_491521502108_item	2596084	et	3	main
laevapardalt	doc_491521502108_item	2596085	et	3	main
vist	doc_491521502108_item	2596087	et	4	main
ja	doc_491521502108_item	2596089	et	3	main
küsida	doc_491521502108_item	2596091	et	3	main
tõesti	doc_491521502108_item	2596093	et	3	main
selles	doc_491521502108_item	2596101	et	4	main
kõik	doc_491521502108_item	2596103	et	4	main
ja	doc_491521502108_item	2596012	et	3	main
suur-eestimaa	doc_491521502108_item	2596023	et	4	main
peame	doc_491521502108_item	2596029	et	4	main
tähendab	doc_491521502108_item	2596034	et	3	main
peame	doc_491521502108_item	2596036	et	4	main
lenini	doc_491521502108_item	2596039	et	4	main
nägi	doc_491521502108_item	2596049	et	3	main
just	doc_491521502108_item	2596051	et	3	main
lenin	doc_491521502108_item	2596053	et	4	main
rääkida	doc_491521502108_item	2596064	et	3	main
lenin	doc_491521502108_item	2596069	et	4	main
liikuda	doc_491521502108_item	2596070	et	3	main
leninit	doc_491521502108_item	2596076	et	4	main
näidatakse	doc_491521502108_item	2596077	et	3	main
hullusena	doc_491521502108_item	2596078	et	4	main
ja	doc_491521502108_item	2596079	et	3	main
millele	doc_491521502108_item	2596097	et	3	main
minu	doc_491521502108_item	2596099	et	3	main
tehtud	doc_491521502108_item	2596107	et	4	main
juhtubme	doc_491521502108_item	2596028	et	4	main
vältima	doc_491521502108_item	2596032	et	3	main
see	doc_491521502108_item	2596033	et	3	main
absuurdne	doc_491521502108_item	2596047	et	4	main
keda	doc_491521502108_item	2596062	et	4	main
lenin	doc_491521502108_item	2596066	et	4	main
nagu	doc_491521502108_item	2596068	et	3	main
lenin	doc_491521502108_item	2596072	et	4	main
filmi	doc_491521502108_item	2596073	et	4	main
pole	doc_491521502108_item	2596082	et	3	main
kesküla	doc_491521502108_item	2596094	et	4	main
saavutas	doc_491521502108_item	2596095	et	3	main
seda	doc_491521502108_item	2596096	et	3	main
filmis	doc_491521502108_item	2596102	et	4	main
on	doc_491521502108_item	2596105	et	4	main
naerualuseks	doc_491521502108_item	2596106	et	4	main
eksamitöö	doc_491521502112_item	2596900	et	4	main
omariikluse	doc_491521502112_item	2596904	et	4	main
kujundajana	doc_491521502112_item	2596905	et	4	main
naisteseltsid	doc_491521502112_item	2596933	et	3	main
venemaa	doc_491521502112_item	2596934	et	4	main
hakati	doc_491521502112_item	2596954	et	3	main
liikmed	doc_491521502112_item	2596959	et	3	main
5	doc_491521502112_item	2596962	et	2	main
1905	doc_491521502112_item	2596971	et	2	main
kultuuri	doc_491521502112_item	2596995	et	4	main
seltsiliikumise	doc_491521502112_item	2596902	et	3	main
1871a	doc_491521502112_item	2596921	et	4	main
seltsid	doc_491521502112_item	2596924	et	4	main
seltsi	doc_491521502112_item	2596925	et	4	main
liider	doc_491521502112_item	2596926	et	3	main
ja	doc_491521502112_item	2596935	et	3	main
naistest	doc_491521502112_item	2596945	et	4	main
mille	doc_491521502112_item	2596958	et	3	main
tööliseeltsid	doc_491521502112_item	2596963	et	4	main
olid	doc_491521502112_item	2596965	et	4	main
haridusseltsid	doc_491521502112_item	2596966	et	3	main
tegid	doc_491521502112_item	2596968	et	4	main
aitas	doc_491521502112_item	2596993	et	3	main
tema	doc_491521502112_item	2597006	et	4	main
kogumise	doc_491521502112_item	2597009	et	4	main
avaldas	doc_491521502112_item	2597011	et	3	main
kaastööliste	doc_491521502112_item	2597013	et	4	main
õpetas	doc_491521502112_item	2597017	et	3	main
jakobson	doc_491521502112_item	2596927	et	4	main
1870	doc_491521502112_item	2596928	et	2	main
oli	doc_491521502112_item	2596929	et	3	main
president	doc_491521502112_item	2596930	et	3	main
jansen	doc_491521502112_item	2596931	et	4	main
3	doc_491521502112_item	2596932	et	2	main
esimene	doc_491521502112_item	2596940	et	3	main
naiskirjanik	doc_491521502112_item	2596941	et	3	main
kes	doc_491521502112_item	2596942	et	4	main
kirjutas	doc_491521502112_item	2596943	et	3	main
esimesena	doc_491521502112_item	2596944	et	3	main
moodustama	doc_491521502112_item	2596955	et	3	main
eestis	doc_491521502112_item	2596972	et	3	main
vanemuise	doc_491521502112_item	2596998	et	4	main
seltsile	doc_491521502112_item	2596999	et	3	main
elutöö	doc_491521502112_item	2597007	et	4	main
ja	doc_491521502112_item	2597016	et	3	main
ta	doc_491521502112_item	2597018	et	4	main
oma	doc_491521502112_item	2597020	et	4	main
ärkamisajal	doc_491521502112_item	2597024	et	3	main
000	doc_491521502112_item	2597045	et	2	main
lepingu	doc_491521502112_item	2597058	et	3	main
1	doc_491521502112_item	2596901	et	2	main
osatähtsusest	doc_491521502112_item	2596903	et	4	main
1	doc_491521502112_item	2596906	et	2	main
ekms	doc_491521502112_item	2596907	et	4	main
üks	doc_491521502112_item	2596908	et	3	main
põhilisi	doc_491521502112_item	2596909	et	3	main
organisatsioone	doc_491521502112_item	2596910	et	3	main
mis	doc_491521502112_item	2596911	et	4	main
tegeles	doc_491521502112_item	2596912	et	3	main
eesti	doc_491521502112_item	2596913	et	4	main
pärimuskultuuriga	doc_491521502112_item	2596914	et	4	main
selle	doc_491521502112_item	2596915	et	4	main
seltsi	doc_491521502112_item	2596916	et	4	main
president	doc_491521502112_item	2596917	et	3	main
oli	doc_491521502112_item	2596918	et	3	main
j	doc_491521502112_item	2596919	et	4	main
hurt	doc_491521502112_item	2596920	et	3	main
2	doc_491521502112_item	2596922	et	2	main
põllumeeste	doc_491521502112_item	2596923	et	4	main
saksamaa	doc_491521502112_item	2596936	et	4	main
esindajad	doc_491521502112_item	2596937	et	4	main
ja	doc_491521502112_item	2596946	et	3	main
oli	doc_491521502112_item	2596947	et	3	main
tüdrukute	doc_491521502112_item	2596948	et	4	main
kooli	doc_491521502112_item	2596949	et	4	main
korporatsioone	doc_491521502112_item	2596957	et	3	main
ta	doc_491521502112_item	2597000	et	4	main
esines	doc_491521502112_item	2597001	et	3	main
oma	doc_491521502112_item	2597002	et	4	main
kõnega	doc_491521502112_item	2597003	et	3	main
esimesel	doc_491521502112_item	2597004	et	3	main
nimesid	doc_491521502112_item	2597014	et	3	main
oli	doc_491521502112_item	2597019	et	3	main
panuse	doc_491521502112_item	2597021	et	3	main
andnud	doc_491521502112_item	2597023	et	4	main
3	doc_491521502112_item	2597025	et	2	main
rahu	doc_491521502112_item	2597027	et	4	main
vahel	doc_491521502112_item	2597035	et	4	main
sellega	doc_491521502112_item	2597036	et	3	main
tunnistab	doc_491521502112_item	2597037	et	3	main
venemaa	doc_491521502112_item	2597041	et	4	main
000	doc_491521502112_item	2597046	et	2	main
määrati	doc_491521502112_item	2597056	et	3	main
piirid	doc_491521502112_item	2597057	et	3	main
eesti	doc_491521502112_item	2597060	et	4	main
poolt	doc_491521502112_item	2597061	et	4	main
alla	doc_491521502112_item	2597062	et	3	main
kujundajana	doc_491521502113_item	2597070	et	4	main
lilli	doc_491521502112_item	2596938	et	4	main
suburg	doc_491521502112_item	2596939	et	3	main
juhataja	doc_491521502112_item	2596950	et	4	main
pärnus	doc_491521502112_item	2596951	et	3	main
4	doc_491521502112_item	2596952	et	2	main
üliõpilasselts	doc_491521502112_item	2596953	et	3	main
simesi	doc_491521502112_item	2596956	et	4	main
olid	doc_491521502112_item	2596960	et	4	main
korporandid	doc_491521502112_item	2596961	et	3	main
need	doc_491521502112_item	2596964	et	3	main
mis	doc_491521502112_item	2596967	et	4	main
poliitilist	doc_491521502112_item	2596969	et	3	main
propagandat	doc_491521502112_item	2596970	et	3	main
oli	doc_491521502112_item	2596973	et	3	main
üle	doc_491521502112_item	2596974	et	3	main
500	doc_491521502112_item	2596975	et	2	main
erinevat	doc_491521502112_item	2596976	et	4	main
2	doc_491521502112_item	2596978	et	2	main
seltsi	doc_491521502112_item	2596977	et	4	main
jakob	doc_491521502112_item	2596979	et	4	main
hurda	doc_491521502112_item	2596980	et	3	main
roll	doc_491521502112_item	2596981	et	3	main
kaasaegses	doc_491521502112_item	2596982	et	3	main
eestis	doc_491521502112_item	2596983	et	3	main
jakob	doc_491521502112_item	2596984	et	4	main
hurt	doc_491521502112_item	2596985	et	3	main
oli	doc_491521502112_item	2596986	et	3	main
liberaal	doc_491521502112_item	2596987	et	3	main
demokraatliku	doc_491521502112_item	2596988	et	3	main
suuna	doc_491521502112_item	2596989	et	4	main
esindaja	doc_491521502112_item	2596990	et	4	main
aktiivne	doc_491521502112_item	2596991	et	3	main
seltsiliige	doc_491521502112_item	2596992	et	4	main
pani	doc_491521502112_item	2596996	et	4	main
arendada	doc_491521502112_item	2596994	et	3	main
laulupeol	doc_491521502112_item	2597005	et	4	main
rahvaluule	doc_491521502112_item	2597008	et	4	main
aktsioon	doc_491521502112_item	2597010	et	3	main
ajalehtedes	doc_491521502112_item	2597012	et	4	main
julgustas	doc_491521502112_item	2597015	et	3	main
poliitikuna	doc_491521502112_item	2597022	et	3	main
tartu	doc_491521502112_item	2597026	et	4	main
1920	doc_491521502112_item	2597028	et	2	main
tartu	doc_491521502112_item	2597029	et	4	main
venemaa	doc_491521502112_item	2597038	et	4	main
maksab	doc_491521502112_item	2597042	et	3	main
eestisse	doc_491521502112_item	2597055	et	4	main
kirjutas	doc_491521502112_item	2597059	et	3	main
osatähtsusest	doc_491521502113_item	2597068	et	4	main
eesmärgiks	doc_491521502113_item	2597074	et	3	main
ärkada	doc_491521502113_item	2597076	et	4	main
eneseteadvust	doc_491521502113_item	2597079	et	4	main
tähtsuse	doc_491521502113_item	2597086	et	4	main
vanemuise	doc_491521502113_item	2597087	et	4	main
ühendas	doc_491521502113_item	2597099	et	3	main
andis	doc_491521502113_item	2597101	et	3	main
kalender	doc_491521502113_item	2597103	et	3	main
ka	doc_491521502113_item	2597106	et	3	main
seltsi	doc_491521502113_item	2597121	et	4	main
arengu	doc_491521502113_item	2597131	et	3	main
kehtib	doc_491521502113_item	2597150	et	3	main
korjamises	doc_491521502113_item	2597161	et	4	main
rahvuvliikumise	doc_491521502113_item	2597167	et	4	main
eesti	doc_491521502113_item	2597178	et	4	main
ja	doc_491521502113_item	2597179	et	3	main
tulemuseks	doc_491521502113_item	2597184	et	3	main
venemaa	doc_491521502113_item	2597186	et	4	main
eesti	doc_491521502113_item	2597188	et	4	main
iseseisvust	doc_491521502113_item	2597189	et	4	main
sellega	doc_491521502113_item	2597190	et	3	main
vabariigi	doc_491521502113_item	2597196	et	3	main
osatähtsusest	doc_491521502114_item	2597201	et	4	main
kujundajana	doc_491521502114_item	2597203	et	4	main
tegelased	doc_491521502114_item	2597213	et	3	main
seltsidest	doc_491521502114_item	2597217	et	3	main
igasugused	doc_491521502114_item	2597219	et	3	main
eesti	doc_491521502114_item	2597228	et	4	main
pollumeeste	doc_491521502114_item	2597229	et	4	main
põllum	doc_491521502114_item	2597234	et	4	main
muutub	doc_491521502114_item	2597236	et	3	main
seisund	doc_491521502114_item	2597239	et	3	main
rahvusliku	doc_491521502114_item	2597282	et	3	main
mis	doc_491521502114_item	2597292	et	4	main
algas	doc_491521502114_item	2597293	et	3	main
sai	doc_491521502114_item	2597303	et	4	main
algas	doc_491521502114_item	2597305	et	3	main
i	doc_491521502114_item	2597306	et	4	main
eestit	doc_491521502114_item	2597314	et	3	main
tööle	doc_491521502114_item	2597320	et	3	main
20	doc_491521502114_item	2597321	et	2	main
riigikogus	doc_491521502114_item	2597324	et	4	main
perioodil	doc_491521502115_item	2597340	et	3	main
rahvast	doc_491521502115_item	2597344	et	4	main
hakkasid	doc_491521502115_item	2597347	et	4	main
eestlasteks	doc_491521502115_item	2597349	et	4	main
nimetama	doc_491521502115_item	2597350	et	3	main
arenes	doc_491521502115_item	2597351	et	3	main
poliitiline	doc_491521502115_item	2597352	et	3	main
iseseisvus	doc_491521502115_item	2597353	et	4	main
tekkis	doc_491521502115_item	2597354	et	3	main
professionaalne	doc_491521502115_item	2597355	et	3	main
kõrgkultuur	doc_491521502115_item	2597356	et	3	main
rahvuslik	doc_491521502115_item	2597357	et	3	main
teater	doc_491521502115_item	2597358	et	3	main
kirjandus	doc_491521502115_item	2597359	et	3	main
aastatel	doc_491521502115_item	2597399	et	4	main
asutati	doc_491521502115_item	2597400	et	4	main
kaubalaeva	doc_491521502115_item	2597402	et	4	main
selts	doc_491521502115_item	2597403	et	3	main
linda	doc_491521502115_item	2597404	et	4	main
narvas	doc_491521502115_item	2597411	et	4	main
naisliikumise	doc_491521502115_item	2597417	et	3	main
viljandi	doc_491521502115_item	2597419	et	4	main
seltsis	doc_491521502115_item	2597420	et	4	main
alguse	doc_491521502112_item	2596997	et	3	main
eesti	doc_491521502112_item	2597039	et	4	main
suveräänsust	doc_491521502112_item	2597040	et	4	main
15	doc_491521502112_item	2597044	et	2	main
tänu	doc_491521502112_item	2597048	et	4	main
lepingule	doc_491521502112_item	2597050	et	3	main
j	doc_491521502112_item	2597063	et	4	main
omariikluse	doc_491521502113_item	2597069	et	4	main
seltside	doc_491521502113_item	2597073	et	3	main
emakeele	doc_491521502113_item	2597085	et	4	main
tartus	doc_491521502113_item	2597094	et	3	main
selts	doc_491521502113_item	2597098	et	3	main
maaomanikke	doc_491521502113_item	2597100	et	3	main
keele	doc_491521502113_item	2597130	et	4	main
eest	doc_491521502113_item	2597132	et	4	main
tahtis	doc_491521502113_item	2597133	et	3	main
et	doc_491521502113_item	2597134	et	3	main
kõik	doc_491521502113_item	2597135	et	4	main
ametnikud	doc_491521502113_item	2597136	et	3	main
valdaksid	doc_491521502113_item	2597137	et	4	main
eesti	doc_491521502113_item	2597138	et	4	main
üleminek	doc_491521502113_item	2597145	et	3	main
mis	doc_491521502113_item	2597149	et	4	main
jakob	doc_491521502113_item	2597152	et	4	main
tegi	doc_491521502113_item	2597154	et	4	main
folkloori	doc_491521502113_item	2597158	et	4	main
oli	doc_491521502113_item	2597163	et	3	main
üks	doc_491521502113_item	2597165	et	3	main
liidreid	doc_491521502113_item	2597168	et	3	main
venemaa	doc_491521502113_item	2597181	et	4	main
eestlased	doc_491521502114_item	2597210	et	3	main
said	doc_491521502114_item	2597214	et	4	main
just	doc_491521502114_item	2597216	et	3	main
toimusid	doc_491521502114_item	2597218	et	4	main
rahu	doc_491521502112_item	2597030	et	4	main
leping	doc_491521502112_item	2597031	et	3	main
eestimaa	doc_491521502112_item	2597032	et	4	main
ja	doc_491521502112_item	2597033	et	3	main
venemaa	doc_491521502112_item	2597034	et	4	main
eestile	doc_491521502112_item	2597043	et	3	main
rubla	doc_491521502112_item	2597047	et	4	main
selle	doc_491521502112_item	2597049	et	4	main
eestlased	doc_491521502112_item	2597051	et	3	main
võisid	doc_491521502112_item	2597052	et	4	main
pöörduda	doc_491521502112_item	2597053	et	3	main
tagasi	doc_491521502112_item	2597054	et	3	main
poska	doc_491521502112_item	2597064	et	4	main
eksamitöö	doc_491521502113_item	2597065	et	4	main
1	doc_491521502113_item	2597066	et	2	main
seltsiliikumise	doc_491521502113_item	2597067	et	3	main
eesti	doc_491521502113_item	2597072	et	4	main
eesti	doc_491521502113_item	2597077	et	4	main
eesti	doc_491521502113_item	2597080	et	4	main
kirjameeste	doc_491521502113_item	2597081	et	4	main
selts	doc_491521502113_item	2597082	et	3	main
püüdis	doc_491521502113_item	2597083	et	3	main
laulu-	doc_491521502113_item	2597088	et	4	main
ja	doc_491521502113_item	2597089	et	3	main
mänguselts	doc_491521502113_item	2597090	et	3	main
tegeles	doc_491521502113_item	2597091	et	3	main
kultuuriarenguga	doc_491521502113_item	2597092	et	3	main
põllumeeste	doc_491521502113_item	2597097	et	4	main
välja	doc_491521502113_item	2597102	et	4	main
oli	doc_491521502113_item	2597105	et	3	main
nõuanded	doc_491521502113_item	2597108	et	3	main
2	doc_491521502113_item	2597109	et	2	main
jakob	doc_491521502113_item	2597110	et	4	main
hurda	doc_491521502113_item	2597111	et	3	main
roll	doc_491521502113_item	2597112	et	3	main
kaasaegses	doc_491521502113_item	2597113	et	3	main
eestis	doc_491521502113_item	2597114	et	3	main
jakob	doc_491521502113_item	2597115	et	4	main
hurt	doc_491521502113_item	2597116	et	3	main
oli	doc_491521502113_item	2597117	et	3	main
esimene	doc_491521502113_item	2597118	et	3	main
eesti	doc_491521502113_item	2597119	et	4	main
kirjameeste	doc_491521502113_item	2597120	et	4	main
kõikide	doc_491521502113_item	2597071	et	4	main
oli	doc_491521502113_item	2597075	et	3	main
rahvuse	doc_491521502113_item	2597078	et	3	main
a	doc_491521502113_item	2597096	et	4	main
eesti	doc_491521502113_item	2597129	et	4	main
keelt	doc_491521502113_item	2597139	et	4	main
ka	doc_491521502113_item	2597140	et	3	main
tol	doc_491521502113_item	2597141	et	3	main
ajal	doc_491521502113_item	2597142	et	4	main
oli	doc_491521502113_item	2597143	et	3	main
tänapäevani	doc_491521502113_item	2597151	et	3	main
palju	doc_491521502113_item	2597155	et	4	main
tööd	doc_491521502113_item	2597156	et	4	main
ka	doc_491521502113_item	2597164	et	3	main
sõlmitud	doc_491521502113_item	2597175	et	4	main
vahel	doc_491521502113_item	2597182	et	4	main
areng	doc_491521502113_item	2597197	et	3	main
1	doc_491521502114_item	2597199	et	2	main
olid	doc_491521502114_item	2597209	et	4	main
tuntud	doc_491521502114_item	2597212	et	4	main
nt	doc_491521502114_item	2597221	et	4	main
jansen	doc_491521502114_item	2597231	et	4	main
õpetatud	doc_491521502114_item	2597240	et	4	main
jakob	doc_491521502114_item	2597244	et	4	main
üks	doc_491521502114_item	2597250	et	3	main
saksatee	doc_491521502114_item	2597262	et	4	main
jakobson	doc_491521502114_item	2597265	et	4	main
liikumisega	doc_491521502114_item	2597283	et	4	main
president	doc_491521502114_item	2597285	et	3	main
1918	doc_491521502114_item	2597294	et	2	main
lõppes	doc_491521502114_item	2597295	et	4	main
tartus	doc_491521502114_item	2597298	et	3	main
eesti	doc_491521502114_item	2597302	et	4	main
pidi	doc_491521502114_item	2597311	et	4	main
riigikeel	doc_491521502114_item	2597315	et	4	main
eesti	doc_491521502114_item	2597316	et	4	main
tõsta	doc_491521502113_item	2597084	et	4	main
asutatud	doc_491521502113_item	2597093	et	4	main
1865	doc_491521502113_item	2597095	et	2	main
kus	doc_491521502113_item	2597104	et	3	main
igasugused	doc_491521502113_item	2597107	et	3	main
mis	doc_491521502113_item	2597122	et	4	main
oli	doc_491521502113_item	2597123	et	3	main
asutatud	doc_491521502113_item	2597124	et	4	main
1872a	doc_491521502113_item	2597125	et	4	main
president	doc_491521502113_item	2597126	et	3	main
eesti	doc_491521502113_item	2597157	et	4	main
ta	doc_491521502113_item	2597162	et	4	main
3	doc_491521502113_item	2597169	et	2	main
rahu	doc_491521502113_item	2597171	et	4	main
tartu	doc_491521502113_item	2597172	et	4	main
rahu	doc_491521502113_item	2597173	et	4	main
oli	doc_491521502113_item	2597174	et	3	main
mille	doc_491521502113_item	2597183	et	3	main
nõukogu	doc_491521502113_item	2597185	et	4	main
tunnistas	doc_491521502113_item	2597187	et	3	main
vabadussõda	doc_491521502113_item	2597192	et	4	main
ja	doc_491521502113_item	2597193	et	3	main
algas	doc_491521502113_item	2597194	et	3	main
eesti	doc_491521502113_item	2597195	et	4	main
eksamitöö	doc_491521502114_item	2597198	et	4	main
omariikluse	doc_491521502114_item	2597202	et	4	main
tekkisid	doc_491521502114_item	2597204	et	4	main
uued	doc_491521502114_item	2597205	et	3	main
seltsid	doc_491521502114_item	2597206	et	4	main
kus	doc_491521502114_item	2597207	et	3	main
liikmed	doc_491521502114_item	2597208	et	3	main
alguse	doc_491521502114_item	2597215	et	3	main
selts	doc_491521502114_item	2597230	et	3	main
selts	doc_491521502114_item	2597242	et	3	main
hurda	doc_491521502114_item	2597245	et	3	main
kaasaegses	doc_491521502114_item	2597247	et	3	main
tegijatest	doc_491521502114_item	2597251	et	4	main
eestis	doc_491521502114_item	2597253	et	3	main
jannseniga	doc_491521502114_item	2597256	et	4	main
hiljem	doc_491521502114_item	2597258	et	3	main
tekkis	doc_491521502114_item	2597259	et	3	main
kolm	doc_491521502114_item	2597260	et	3	main
gruppi	doc_491521502114_item	2597261	et	4	main
eestitee	doc_491521502114_item	2597264	et	4	main
kreutzwald	doc_491521502114_item	2597266	et	4	main
venetee	doc_491521502114_item	2597267	et	4	main
tegeles	doc_491521502114_item	2597286	et	3	main
3	doc_491521502114_item	2597288	et	2	main
1920	doc_491521502114_item	2597296	et	2	main
kui	doc_491521502114_item	2597297	et	3	main
vebruaris	doc_491521502114_item	2597301	et	4	main
venemaa	doc_491521502114_item	2597310	et	4	main
põhiseadus	doc_491521502114_item	2597318	et	4	main
1	doc_491521502115_item	2597332	et	2	main
sajandi	doc_491521502115_item	2597338	et	3	main
teisel	doc_491521502115_item	2597339	et	4	main
kujunema	doc_491521502115_item	2597343	et	3	main
muusika	doc_491521502115_item	2597360	et	4	main
ja	doc_491521502115_item	2597392	et	3	main
kõrgperiood	doc_491521502115_item	2597395	et	3	main
kult	doc_491521502115_item	2597407	et	3	main
seltsid	doc_491521502115_item	2597408	et	4	main
ilmaline	doc_491521502115_item	2597412	et	4	main
eesti	doc_491521502115_item	2597414	et	4	main
selts	doc_491521502115_item	2597416	et	3	main
ajal	doc_491521502115_item	2597418	et	4	main
mängida	doc_491521502115_item	2597427	et	3	main
kaasaegses	doc_491521502115_item	2597432	et	3	main
1870	doc_491521502115_item	2597434	et	2	main
tuntumaid	doc_491521502115_item	2597445	et	4	main
korda	doc_491521502115_item	2597450	et	4	main
ees	doc_491521502115_item	2597456	et	4	main
1869	doc_491521502115_item	2597457	et	2	main
rääkis	doc_491521502115_item	2597462	et	3	main
ta	doc_491521502115_item	2597465	et	4	main
ühiskonnas	doc_491521502115_item	2597485	et	4	main
2	doc_491521502115_item	2597489	et	2	main
1920	doc_491521502115_item	2597491	et	2	main
eesti	doc_491521502115_item	2597494	et	4	main
elasid	doc_491521502115_item	2597501	et	4	main
venemaal	doc_491521502115_item	2597502	et	4	main
1	doc_491521502116_item	2597523	et	2	main
ta	doc_491521502113_item	2597127	et	4	main
võitles	doc_491521502113_item	2597128	et	3	main
teostatud	doc_491521502113_item	2597144	et	4	main
uuele	doc_491521502113_item	2597146	et	3	main
foneetilisele	doc_491521502113_item	2597147	et	3	main
kirjaviisile	doc_491521502113_item	2597148	et	3	main
hurt	doc_491521502113_item	2597153	et	3	main
uurimises	doc_491521502113_item	2597159	et	4	main
ja	doc_491521502113_item	2597160	et	3	main
tähtsamaid	doc_491521502113_item	2597166	et	4	main
tartu	doc_491521502113_item	2597170	et	4	main
2veebr	doc_491521502113_item	2597176	et	4	main
1920a	doc_491521502113_item	2597177	et	4	main
nõukogude	doc_491521502113_item	2597180	et	3	main
lõppes	doc_491521502113_item	2597191	et	4	main
seltsiliikumise	doc_491521502114_item	2597200	et	3	main
paljud	doc_491521502114_item	2597211	et	3	main
seminarid	doc_491521502114_item	2597220	et	3	main
president	doc_491521502114_item	2597232	et	3	main
sotsiaalne	doc_491521502114_item	2597238	et	3	main
2	doc_491521502114_item	2597243	et	2	main
ärkamisaegses	doc_491521502114_item	2597252	et	3	main
jakobsoniga	doc_491521502114_item	2597255	et	4	main
jannsen	doc_491521502114_item	2597263	et	4	main
rahu	doc_491521502114_item	2597290	et	4	main
vabadussõja	doc_491521502114_item	2597291	et	3	main
rahu	doc_491521502114_item	2597300	et	4	main
vabaduse	doc_491521502114_item	2597304	et	4	main
mitte	doc_491521502114_item	2597312	et	3	main
segada	doc_491521502114_item	2597313	et	3	main
hakkab	doc_491521502114_item	2597319	et	3	main
lõppus	doc_491521502114_item	2597323	et	4	main
valitsesid	doc_491521502114_item	2597325	et	4	main
üheksateistkümnenda	doc_491521502115_item	2597337	et	4	main
rahvus	doc_491521502115_item	2597345	et	3	main
rahvuslik	doc_491521502115_item	2597363	et	3	main
laulu	doc_491521502115_item	2597391	et	4	main
oli	doc_491521502115_item	2597396	et	3	main
tallinna	doc_491521502115_item	2597401	et	4	main
võrus	doc_491521502115_item	2597409	et	3	main
eüs	doc_491521502115_item	2597413	et	4	main
üliõp	doc_491521502115_item	2597415	et	4	main
teatris	doc_491521502115_item	2597426	et	3	main
jakob	doc_491521502115_item	2597429	et	4	main
roll	doc_491521502115_item	2597431	et	3	main
liikumise	doc_491521502115_item	2597447	et	4	main
esimest	doc_491521502115_item	2597449	et	4	main
ta	doc_491521502115_item	2597451	et	4	main
pidas	doc_491521502115_item	2597452	et	3	main
kõnet	doc_491521502115_item	2597453	et	3	main
suure	doc_491521502115_item	2597454	et	3	main
auditooriumi	doc_491521502115_item	2597455	et	4	main
ta	doc_491521502115_item	2597461	et	4	main
ta	doc_491521502115_item	2597471	et	4	main
eesti	doc_491521502115_item	2597473	et	4	main
postimehe	doc_491521502115_item	2597474	et	3	main
peatoimetaja	doc_491521502115_item	2597475	et	4	main
otepäil	doc_491521502115_item	2597476	et	4	main
tartu	doc_491521502115_item	2597487	et	4	main
haritud	doc_491521502116_item	2597531	et	4	main
inimesed	doc_491521502116_item	2597532	et	3	main
nad	doc_491521502116_item	2597533	et	3	main
ettevõtmisi	doc_491521502116_item	2597536	et	3	main
heategevusena	doc_491521502116_item	2597542	et	4	main
oli	doc_491521502116_item	2597549	et	3	main
kirjameeste	doc_491521502116_item	2597551	et	4	main
jakobson	doc_491521502116_item	2597568	et	4	main
välja	doc_491521502116_item	2597573	et	4	main
brožüüre	doc_491521502116_item	2597575	et	2	main
õpetusi	doc_491521502116_item	2597576	et	4	main
oli	doc_491521502116_item	2597612	et	3	main
osad	doc_491521502116_item	2597622	et	3	main
sellest	doc_491521502116_item	2597631	et	4	main
palju	doc_491521502116_item	2597646	et	4	main
poliitik	doc_491521502116_item	2597652	et	3	main
lahkus	doc_491521502116_item	2597655	et	4	main
peterburgi	doc_491521502116_item	2597658	et	4	main
oli	doc_491521502116_item	2597659	et	3	main
seal	doc_491521502116_item	2597660	et	4	main
surmani	doc_491521502116_item	2597661	et	3	main
koguduse	doc_491521502116_item	2597662	et	3	main
veebruar	doc_491521502116_item	2597671	et	3	main
see	doc_491521502116_item	2597673	et	3	main
pakt	doc_491521502116_item	2597675	et	3	main
maad	doc_491521502116_item	2597687	et	4	main
vallutada	doc_491521502116_item	2597691	et	3	main
puhuks	doc_491521502116_item	2597693	et	4	main
ekms	doc_491521502114_item	2597222	et	4	main
tegelesid	doc_491521502114_item	2597223	et	4	main
eesti	doc_491521502114_item	2597224	et	4	main
keelega	doc_491521502114_item	2597225	et	3	main
kirjandusega	doc_491521502114_item	2597226	et	3	main
keeleteadusega	doc_491521502114_item	2597227	et	3	main
korraldati	doc_491521502114_item	2597233	et	3	main
näitused	doc_491521502114_item	2597235	et	3	main
inimeste	doc_491521502114_item	2597237	et	3	main
eesti	doc_491521502114_item	2597241	et	4	main
roll	doc_491521502114_item	2597246	et	3	main
eestis	doc_491521502114_item	2597248	et	3	main
oli	doc_491521502114_item	2597249	et	3	main
koos	doc_491521502114_item	2597254	et	4	main
jt	doc_491521502114_item	2597257	et	4	main
hurt	doc_491521502114_item	2597268	et	3	main
passivne	doc_491521502114_item	2597269	et	4	main
ei	doc_491521502114_item	2597270	et	4	main
mänginud	doc_491521502114_item	2597271	et	4	main
suurt	doc_491521502114_item	2597272	et	3	main
rolli	doc_491521502114_item	2597273	et	4	main
oma	doc_491521502114_item	2597274	et	4	main
elu	doc_491521502114_item	2597275	et	4	main
viimastel	doc_491521502114_item	2597276	et	3	main
aastatel	doc_491521502114_item	2597277	et	4	main
elas	doc_491521502114_item	2597278	et	3	main
venemaal	doc_491521502114_item	2597279	et	4	main
oli	doc_491521502114_item	2597280	et	3	main
seotud	doc_491521502114_item	2597281	et	4	main
ekms	doc_491521502114_item	2597284	et	4	main
kultuuriga	doc_491521502114_item	2597287	et	4	main
tartu	doc_491521502114_item	2597289	et	4	main
sõlmiti	doc_491521502114_item	2597299	et	3	main
eesti	doc_491521502114_item	2597307	et	4	main
vabariigi	doc_491521502114_item	2597308	et	3	main
aeg	doc_491521502114_item	2597309	et	3	main
keel	doc_491521502114_item	2597317	et	4	main
a	doc_491521502114_item	2597322	et	4	main
3	doc_491521502114_item	2597326	et	2	main
aastat	doc_491521502114_item	2597327	et	3	main
riigivanemad	doc_491521502114_item	2597328	et	4	main
päts	doc_491521502114_item	2597329	et	3	main
tõnisson	doc_491521502114_item	2597330	et	4	main
eksamitöö	doc_491521502115_item	2597331	et	4	main
osatähtsusest	doc_491521502115_item	2597334	et	4	main
omariikluse	doc_491521502115_item	2597335	et	4	main
kujundajana	doc_491521502115_item	2597336	et	4	main
eestis	doc_491521502115_item	2597342	et	3	main
paljud	doc_491521502115_item	2597346	et	3	main
end	doc_491521502115_item	2597348	et	4	main
esimene	doc_491521502115_item	2597362	et	3	main
liikumine	doc_491521502115_item	2597364	et	4	main
olid	doc_491521502115_item	2597386	et	4	main
vanemuine	doc_491521502115_item	2597390	et	4	main
rahvusliikumise	doc_491521502115_item	2597394	et	3	main
1882	doc_491521502115_item	2597398	et	2	main
tekkisid	doc_491521502115_item	2597405	et	4	main
kannel	doc_491521502115_item	2597410	et	4	main
said	doc_491521502115_item	2597422	et	4	main
esimest	doc_491521502115_item	2597424	et	4	main
tõusis	doc_491521502115_item	2597438	et	4	main
uuele	doc_491521502115_item	2597439	et	3	main
juht	doc_491521502115_item	2597448	et	3	main
i	doc_491521502115_item	2597458	et	4	main
üldlaulupeol	doc_491521502115_item	2597459	et	4	main
liige	doc_491521502115_item	2597470	et	4	main
oli	doc_491521502115_item	2597478	et	3	main
3	doc_491521502115_item	2597486	et	2	main
rahu	doc_491521502115_item	2597488	et	4	main
feebruaril	doc_491521502115_item	2597490	et	4	main
sõlmiti	doc_491521502115_item	2597493	et	3	main
ja	doc_491521502115_item	2597495	et	3	main
seltsiliikumise	doc_491521502116_item	2597524	et	3	main
rahva	doc_491521502116_item	2597538	et	3	main
raha	doc_491521502116_item	2597543	et	4	main
asutati	doc_491521502116_item	2597544	et	4	main
koole	doc_491521502116_item	2597545	et	4	main
eesti	doc_491521502116_item	2597550	et	4	main
mis	doc_491521502116_item	2597553	et	4	main
kultuuriseltsile	doc_491521502116_item	2597559	et	3	main
seltsi	doc_491521502116_item	2597565	et	4	main
elus	doc_491521502116_item	2597566	et	4	main
hakkab	doc_491521502116_item	2597567	et	3	main
tema	doc_491521502116_item	2597577	et	4	main
hakkas	doc_491521502116_item	2597606	et	3	main
rahvapärimuste	doc_491521502116_item	2597609	et	4	main
üleskirjutamisele	doc_491521502116_item	2597610	et	3	main
sisse	doc_491521502116_item	2597617	et	4	main
seltsiliikumise	doc_491521502115_item	2597333	et	3	main
hakkas	doc_491521502115_item	2597341	et	3	main
kunst	doc_491521502115_item	2597361	et	3	main
oli	doc_491521502115_item	2597365	et	3	main
balti	doc_491521502115_item	2597366	et	3	main
erakorra	doc_491521502115_item	2597367	et	3	main
vastu	doc_491521502115_item	2597368	et	3	main
inimesed	doc_491521502115_item	2597369	et	3	main
hakkasid	doc_491521502115_item	2597370	et	4	main
kogunema	doc_491521502115_item	2597371	et	3	main
seltsidesse	doc_491521502115_item	2597372	et	3	main
et	doc_491521502115_item	2597373	et	3	main
oma	doc_491521502115_item	2597374	et	4	main
eesmärke	doc_491521502115_item	2597375	et	4	main
läbiviia	doc_491521502115_item	2597376	et	4	main
toetasid	doc_491521502115_item	2597377	et	4	main
üksteist	doc_491521502115_item	2597378	et	4	main
võitlesid	doc_491521502115_item	2597379	et	4	main
oma	doc_491521502115_item	2597380	et	4	main
õiguste	doc_491521502115_item	2597381	et	4	main
eest	doc_491521502115_item	2597382	et	4	main
enamasti	doc_491521502115_item	2597383	et	4	main
seltside	doc_491521502115_item	2597384	et	3	main
juhid	doc_491521502115_item	2597385	et	4	main
kultuuritegelased	doc_491521502115_item	2597387	et	3	main
1865	doc_491521502115_item	2597388	et	2	main
asutati	doc_491521502115_item	2597389	et	4	main
mänguselts	doc_491521502115_item	2597393	et	3	main
1878	doc_491521502115_item	2597397	et	2	main
tekkisid	doc_491521502115_item	2597406	et	4	main
koit	doc_491521502115_item	2597421	et	3	main
naised	doc_491521502115_item	2597423	et	3	main
korda	doc_491521502115_item	2597425	et	4	main
tasemele	doc_491521502115_item	2597440	et	3	main
j	doc_491521502115_item	2597441	et	4	main
hurt	doc_491521502115_item	2597442	et	3	main
oli	doc_491521502115_item	2597443	et	3	main
üks	doc_491521502115_item	2597444	et	3	main
kus	doc_491521502115_item	2597460	et	3	main
tähtsusest	doc_491521502115_item	2597464	et	4	main
oli	doc_491521502115_item	2597466	et	3	main
vanemuise	doc_491521502115_item	2597468	et	4	main
seltsi	doc_491521502115_item	2597469	et	4	main
ta	doc_491521502115_item	2597477	et	4	main
mis	doc_491521502115_item	2597480	et	4	main
aastal	doc_491521502115_item	2597492	et	3	main
venemaa	doc_491521502115_item	2597496	et	4	main
vahel	doc_491521502115_item	2597497	et	4	main
need	doc_491521502115_item	2597498	et	3	main
eestlased	doc_491521502115_item	2597499	et	3	main
2	doc_491521502115_item	2597428	et	2	main
hurda	doc_491521502115_item	2597430	et	3	main
eestis	doc_491521502115_item	2597433	et	3	main
a	doc_491521502115_item	2597435	et	4	main
rahvuslik	doc_491521502115_item	2597436	et	3	main
liikumine	doc_491521502115_item	2597437	et	4	main
rahvusliku	doc_491521502115_item	2597446	et	3	main
hariduse	doc_491521502115_item	2597463	et	3	main
ka	doc_491521502115_item	2597467	et	3	main
oli	doc_491521502115_item	2597472	et	3	main
paastrina	doc_491521502115_item	2597479	et	4	main
veelgi	doc_491521502115_item	2597481	et	4	main
tõstis	doc_491521502115_item	2597482	et	4	main
ta	doc_491521502115_item	2597483	et	4	main
heanime	doc_491521502115_item	2597484	et	4	main
kes	doc_491521502115_item	2597500	et	4	main
said	doc_491521502115_item	2597503	et	4	main
võimaluse	doc_491521502115_item	2597504	et	3	main
eestisse	doc_491521502115_item	2597505	et	4	main
tagasi	doc_491521502115_item	2597506	et	3	main
tulla	doc_491521502115_item	2597507	et	3	main
eestlased	doc_491521502115_item	2597508	et	3	main
said	doc_491521502115_item	2597509	et	4	main
oma	doc_491521502115_item	2597510	et	4	main
vabariigile	doc_491521502115_item	2597511	et	3	main
nõutud	doc_491521502115_item	2597512	et	4	main
piirid	doc_491521502115_item	2597513	et	3	main
oli	doc_491521502115_item	2597515	et	3	main
nõus	doc_491521502115_item	2597516	et	4	main
eestit	doc_491521502115_item	2597517	et	3	main
vabaks	doc_491521502115_item	2597518	et	3	main
ja	doc_491521502115_item	2597519	et	3	main
iseseisvaks	doc_491521502115_item	2597520	et	3	main
venema	doc_491521502115_item	2597514	et	4	main
kuulutama	doc_491521502115_item	2597521	et	4	main
omariikluse	doc_491521502116_item	2597526	et	4	main
kujundajana	doc_491521502116_item	2597527	et	4	main
seltsiliikumistesse	doc_491521502116_item	2597528	et	3	main
haarati	doc_491521502116_item	2597529	et	3	main
eelkõige	doc_491521502116_item	2597530	et	3	main
et	doc_491521502116_item	2597537	et	3	main
olukorda	doc_491521502116_item	2597539	et	4	main
korjati	doc_491521502116_item	2597541	et	3	main
tegeles	doc_491521502116_item	2597554	et	3	main
eesti	doc_491521502116_item	2597555	et	4	main
tegutsema	doc_491521502116_item	2597570	et	3	main
andis	doc_491521502116_item	2597572	et	3	main
pastor	doc_491521502116_item	2597613	et	3	main
õnnistas	doc_491521502116_item	2597616	et	3	main
eesti	doc_491521502116_item	2597618	et	4	main
üliõpilas	doc_491521502116_item	2597619	et	4	main
liidu	doc_491521502116_item	2597620	et	3	main
lipu	doc_491521502116_item	2597621	et	3	main
et	doc_491521502116_item	2597625	et	3	main
baltisakslaste	doc_491521502116_item	2597628	et	4	main
aga	doc_491521502116_item	2597630	et	3	main
lootvat	doc_491521502116_item	2597644	et	4	main
kehv	doc_491521502116_item	2597651	et	3	main
ta	doc_491521502116_item	2597654	et	4	main
areenilt	doc_491521502116_item	2597656	et	3	main
läks	doc_491521502116_item	2597657	et	3	main
rahu	doc_491521502116_item	2597666	et	4	main
2	doc_491521502116_item	2597670	et	2	main
eksamitöö	doc_491521502116_item	2597522	et	4	main
igasuguseid	doc_491521502116_item	2597535	et	3	main
parandada	doc_491521502116_item	2597540	et	3	main
avaldati	doc_491521502116_item	2597546	et	3	main
ajalehti	doc_491521502116_item	2597547	et	4	main
kultuuriga	doc_491521502116_item	2597558	et	4	main
loodi	doc_491521502116_item	2597561	et	4	main
põllumeeste	doc_491521502116_item	2597563	et	4	main
aktiivselt	doc_491521502116_item	2597569	et	4	main
ta	doc_491521502116_item	2597571	et	4	main
põhiline	doc_491521502116_item	2597578	et	3	main
idee	doc_491521502116_item	2597579	et	4	main
oli	doc_491521502116_item	2597580	et	3	main
et	doc_491521502116_item	2597581	et	3	main
piimakari	doc_491521502116_item	2597582	et	4	main
on	doc_491521502116_item	2597583	et	4	main
ikka	doc_491521502116_item	2597584	et	4	main
oluline	doc_491521502116_item	2597585	et	4	main
ning	doc_491521502116_item	2597586	et	3	main
viib	doc_491521502116_item	2597587	et	3	main
meie	doc_491521502116_item	2597588	et	4	main
majandust	doc_491521502116_item	2597589	et	4	main
2	doc_491521502116_item	2597591	et	2	main
edasi	doc_491521502116_item	2597590	et	3	main
jakob	doc_491521502116_item	2597592	et	4	main
hurda	doc_491521502116_item	2597593	et	3	main
roll	doc_491521502116_item	2597594	et	3	main
kaasaegses	doc_491521502116_item	2597595	et	3	main
eestis	doc_491521502116_item	2597596	et	3	main
jakob	doc_491521502116_item	2597597	et	4	main
hurt	doc_491521502116_item	2597598	et	3	main
oli	doc_491521502116_item	2597599	et	3	main
eesti	doc_491521502116_item	2597600	et	4	main
seltsi	doc_491521502116_item	2597602	et	4	main
kirjameeste	doc_491521502116_item	2597601	et	4	main
esimene	doc_491521502116_item	2597603	et	3	main
esimees	doc_491521502116_item	2597604	et	4	main
ta	doc_491521502116_item	2597605	et	4	main
hurt	doc_491521502116_item	2597611	et	3	main
osatähtsusest	doc_491521502116_item	2597525	et	4	main
korraldasid	doc_491521502116_item	2597534	et	4	main
põhiline	doc_491521502116_item	2597548	et	3	main
selts	doc_491521502116_item	2597552	et	3	main
keele	doc_491521502116_item	2597556	et	4	main
ja	doc_491521502116_item	2597557	et	3	main
lisaks	doc_491521502116_item	2597560	et	4	main
ka	doc_491521502116_item	2597562	et	3	main
seltse	doc_491521502116_item	2597564	et	3	main
mitmeid	doc_491521502116_item	2597574	et	4	main
ja	doc_491521502116_item	2597614	et	3	main
inimesed	doc_491521502116_item	2597623	et	3	main
pooldaja	doc_491521502116_item	2597629	et	4	main
oli	doc_491521502116_item	2597633	et	3	main
eesti	doc_491521502116_item	2597635	et	4	main
pooldaja	doc_491521502116_item	2597637	et	4	main
hurt	doc_491521502116_item	2597638	et	3	main
liiga	doc_491521502116_item	2597645	et	4	main
hurt	doc_491521502116_item	2597649	et	3	main
õpetaja	doc_491521502116_item	2597663	et	4	main
rahu	doc_491521502116_item	2597668	et	4	main
oli	doc_491521502116_item	2597674	et	3	main
eesti	doc_491521502116_item	2597676	et	4	main
iseseisvuse	doc_491521502116_item	2597682	et	4	main
aga	doc_491521502116_item	2597683	et	3	main
ikka	doc_491521502116_item	2597688	et	4	main
nüüd	doc_491521502116_item	2597695	et	4	main
venemaa	doc_491521502116_item	2597698	et	4	main
tungi	doc_491521502116_item	2597700	et	4	main
eesti	doc_491521502116_item	2597703	et	4	main
selle	doc_491521502116_item	2597706	et	4	main
tähelepanu	doc_491521502116_item	2597607	et	4	main
pöörama	doc_491521502116_item	2597608	et	3	main
tema	doc_491521502116_item	2597615	et	4	main
arvasid	doc_491521502116_item	2597624	et	4	main
ta	doc_491521502116_item	2597634	et	4	main
jakobsoni	doc_491521502116_item	2597640	et	4	main
vastu	doc_491521502116_item	2597641	et	3	main
kuna	doc_491521502116_item	2597642	et	3	main
too	doc_491521502116_item	2597643	et	4	main
ja	doc_491521502116_item	2597653	et	3	main
tartu	doc_491521502116_item	2597667	et	4	main
1890	doc_491521502116_item	2597672	et	2	main
sai	doc_491521502116_item	2597681	et	4	main
jälle	doc_491521502116_item	2597690	et	3	main
lõppes	doc_491521502116_item	2597710	et	4	main
hurt	doc_491521502116_item	2597626	et	3	main
oli	doc_491521502116_item	2597627	et	3	main
hoolimata	doc_491521502116_item	2597632	et	4	main
vaimukultuuri	doc_491521502116_item	2597636	et	4	main
oli	doc_491521502116_item	2597639	et	3	main
venemaa	doc_491521502116_item	2597647	et	4	main
poole	doc_491521502116_item	2597648	et	4	main
oli	doc_491521502116_item	2597650	et	3	main
3	doc_491521502116_item	2597664	et	2	main
tartu	doc_491521502116_item	2597665	et	4	main
algas	doc_491521502116_item	2597669	et	3	main
ja	doc_491521502116_item	2597677	et	3	main
vahel	doc_491521502116_item	2597679	et	4	main
eesti	doc_491521502116_item	2597680	et	4	main
ja	doc_491521502116_item	2597689	et	3	main
selleks	doc_491521502116_item	2597692	et	4	main
sõlmiti	doc_491521502116_item	2597694	et	3	main
et	doc_491521502116_item	2597697	et	3	main
eestisse	doc_491521502116_item	2597702	et	4	main
sai	doc_491521502116_item	2597704	et	4	main
tartu	doc_491521502116_item	2597707	et	4	main
rahu	doc_491521502116_item	2597708	et	4	main
lepinguga	doc_491521502116_item	2597709	et	3	main
venemaa	doc_491521502116_item	2597678	et	4	main
venemaa	doc_491521502116_item	2597684	et	4	main
tahtis	doc_491521502116_item	2597685	et	3	main
meie	doc_491521502116_item	2597686	et	4	main
leping	doc_491521502116_item	2597696	et	3	main
enam	doc_491521502116_item	2597701	et	4	main
vabadussõda	doc_491521502116_item	2597711	et	4	main
ei	doc_491521502116_item	2597699	et	4	main
autonoomia	doc_491521502116_item	2597705	et	4	main
täiendav	doc_491521502122_item	2599229	et	4	main
haridusreform	doc_491521502122_item	2599230	et	3	main
5	doc_491521502122_item	2599233	et	2	main
progümnaasium	doc_491521502122_item	2599235	et	4	main
algkool	doc_491521502122_item	2599241	et	4	main
3	doc_491521502122_item	2599242	et	2	main
võis	doc_491521502122_item	2599246	et	4	main
gümnaasiumi	doc_491521502122_item	2599249	et	4	main
kutseharidust	doc_491521502122_item	2599221	et	4	main
politseikoolis	doc_491521502122_item	2599223	et	4	main
toimus	doc_491521502122_item	2599227	et	3	main
4-kl	doc_491521502122_item	2599231	et	4	main
kl	doc_491521502122_item	2599234	et	4	main
oli	doc_491521502122_item	2599236	et	3	main
ka	doc_491521502122_item	2599237	et	3	main
teine	doc_491521502122_item	2599238	et	3	main
võimalus	doc_491521502122_item	2599239	et	3	main
6-kl	doc_491521502122_item	2599240	et	4	main
edasi	doc_491521502122_item	2599245	et	3	main
tartu	doc_491521502122_item	2599256	et	4	main
saareste	doc_491521502122_item	2599267	et	4	main
soome-ugri	doc_491521502122_item	2599285	et	3	main
keele	doc_491521502122_item	2599286	et	4	main
tartus	doc_491521502122_item	2599292	et	3	main
tampere	doc_491521502122_item	2599297	et	4	main
eesti	doc_491521502122_item	2599330	et	4	main
ärkamisaegses	doc_491521502122_item	2599338	et	3	main
ka	doc_491521502122_item	2599350	et	3	main
oli	doc_491521502122_item	2599352	et	3	main
mitmeid	doc_491521502122_item	2599354	et	4	main
1878	doc_491521502122_item	2599364	et	2	main
andma	doc_491521502122_item	2599368	et	3	main
venelased	doc_491521502122_item	2599402	et	3	main
väiksed	doc_491521502122_item	2599407	et	4	main
olla	doc_491521502122_item	2599418	et	3	main
1	doc_491521502122_item	2599178	et	2	main
omakeelne	doc_491521502122_item	2599179	et	3	main
kõrgharidus	doc_491521502122_item	2599180	et	3	main
ja	doc_491521502122_item	2599181	et	3	main
teadus	doc_491521502122_item	2599182	et	4	main
kõrgkoolid	doc_491521502122_item	2599225	et	3	main
1934-1937	doc_491521502122_item	2599226	et	2	main
algkool	doc_491521502122_item	2599232	et	4	main
aastat	doc_491521502122_item	2599254	et	3	main
töötasid	doc_491521502122_item	2599255	et	4	main
tehnika	doc_491521502122_item	2599260	et	4	main
palju	doc_491521502122_item	2599263	et	4	main
keele	doc_491521502122_item	2599269	et	4	main
aavik	doc_491521502122_item	2599272	et	4	main
m	doc_491521502122_item	2599280	et	4	main
mägiste	doc_491521502122_item	2599282	et	4	main
ja	doc_491521502122_item	2599283	et	3	main
ariste	doc_491521502122_item	2599284	et	4	main
asuti	doc_491521502122_item	2599293	et	3	main
i	doc_491521502122_item	2599300	et	4	main
muusika	doc_491521502122_item	2599302	et	4	main
füüsika	doc_491521502122_item	2599321	et	4	main
teaduslik	doc_491521502122_item	2599331	et	3	main
akadeemia	doc_491521502122_item	2599332	et	4	main
2	doc_491521502122_item	2599333	et	2	main
jakobsoni	doc_491521502122_item	2599336	et	4	main
c	doc_491521502122_item	2599340	et	4	main
jakobson	doc_491521502122_item	2599342	et	4	main
ja	doc_491521502122_item	2599356	et	3	main
välja	doc_491521502122_item	2599367	et	4	main
kõneid	doc_491521502122_item	2599371	et	4	main
esimene	doc_491521502122_item	2599373	et	3	main
rahva	doc_491521502122_item	2599375	et	3	main
kohta	doc_491521502122_item	2599401	et	4	main
rootslased	doc_491521502122_item	2599404	et	3	main
teised	doc_491521502122_item	2599406	et	4	main
rahvad	doc_491521502122_item	2599408	et	3	main
neile	doc_491521502122_item	2599409	et	4	main
oli	doc_491521502122_item	2599410	et	3	main
elu	doc_491521502122_item	2599414	et	4	main
trükisõna	doc_491521502122_item	2599415	et	4	main
kontkatis	doc_491521502122_item	2599419	et	4	main
emamaa	doc_491521502122_item	2599421	et	4	main
eestis	doc_491521502122_item	2599423	et	3	main
rootsi	doc_491521502122_item	2599426	et	4	main
saksa-	doc_491521502122_item	2599434	et	4	main
eksamitöö	doc_491521502122_item	2599177	et	4	main
veel	doc_491521502122_item	2599228	et	4	main
reaalgümnaasiumi	doc_491521502122_item	2599244	et	4	main
ülikool	doc_491521502122_item	2599257	et	4	main
ülikool	doc_491521502122_item	2599261	et	4	main
v	doc_491521502122_item	2599276	et	4	main
sets	doc_491521502122_item	2599291	et	4	main
rahvalaule	doc_491521502122_item	2599299	et	4	main
eesti	doc_491521502122_item	2599183	et	4	main
vabariigis	doc_491521502122_item	2599184	et	3	main
kaua	doc_491521502122_item	2599185	et	3	main
aega	doc_491521502122_item	2599186	et	4	main
polnud	doc_491521502122_item	2599187	et	3	main
eestlastel	doc_491521502122_item	2599188	et	4	main
võimalust	doc_491521502122_item	2599189	et	3	main
saada	doc_491521502122_item	2599190	et	4	main
emakeeles	doc_491521502122_item	2599191	et	4	main
i	doc_491521502122_item	2599192	et	4	main
eesti	doc_491521502122_item	2599193	et	4	main
vabariigi	doc_491521502122_item	2599194	et	3	main
ajal	doc_491521502122_item	2599195	et	4	main
oli	doc_491521502122_item	2599196	et	3	main
neljaklassiline	doc_491521502122_item	2599197	et	4	main
haridus	doc_491521502122_item	2599198	et	3	main
kuni	doc_491521502122_item	2599199	et	3	main
15	doc_491521502122_item	2599200	et	2	main
aastani	doc_491521502122_item	2599201	et	3	main
kohustuslik	doc_491521502122_item	2599202	et	3	main
hiljem	doc_491521502122_item	2599203	et	3	main
aja	doc_491521502122_item	2599204	et	4	main
oli	doc_491521502122_item	2599205	et	3	main
kaheastmeline	doc_491521502122_item	2599206	et	4	main
koolisüsteem	doc_491521502122_item	2599207	et	3	main
1	doc_491521502122_item	2599208	et	2	main
6-klassiline	doc_491521502122_item	2599209	et	4	main
algkoolmis	doc_491521502122_item	2599210	et	3	main
oli	doc_491521502122_item	2599211	et	3	main
tasuta	doc_491521502122_item	2599212	et	4	main
2	doc_491521502122_item	2599213	et	2	main
3-klassiline	doc_491521502122_item	2599214	et	4	main
keskkool	doc_491521502122_item	2599215	et	4	main
pärast	doc_491521502122_item	2599216	et	4	main
oli	doc_491521502122_item	2599217	et	3	main
võimalik	doc_491521502122_item	2599218	et	3	main
juba	doc_491521502122_item	2599219	et	3	main
omandada	doc_491521502122_item	2599220	et	3	main
merekoolid	doc_491521502122_item	2599222	et	3	main
jne	doc_491521502122_item	2599224	et	4	main
aastat	doc_491521502122_item	2599243	et	3	main
minna	doc_491521502122_item	2599247	et	3	main
mingisse	doc_491521502122_item	2599248	et	4	main
ja	doc_491521502122_item	2599258	et	3	main
tallinna	doc_491521502122_item	2599259	et	4	main
eesti	doc_491521502122_item	2599268	et	4	main
j	doc_491521502122_item	2599271	et	4	main
keeleuuendusega	doc_491521502122_item	2599274	et	3	main
veske	doc_491521502122_item	2599281	et	4	main
emakeele	doc_491521502122_item	2599290	et	4	main
rahvaluule	doc_491521502122_item	2599295	et	4	main
haridusega	doc_491521502122_item	2599303	et	3	main
tegeldi	doc_491521502122_item	2599304	et	3	main
etnograafiaga	doc_491521502122_item	2599305	et	3	main
arheoloogiaga	doc_491521502122_item	2599306	et	3	main
uuriti	doc_491521502122_item	2599307	et	3	main
kunstiajalugu	doc_491521502122_item	2599308	et	4	main
eesti	doc_491521502122_item	2599309	et	4	main
ajalugu	doc_491521502122_item	2599310	et	4	main
ka	doc_491521502122_item	2599311	et	3	main
reaalteadused	doc_491521502122_item	2599312	et	3	main
arenesid	doc_491521502122_item	2599313	et	4	main
astronoomia	doc_491521502122_item	2599314	et	4	main
tartu	doc_491521502122_item	2599315	et	4	main
tähetorn	doc_491521502122_item	2599316	et	3	main
struve	doc_491521502122_item	2599317	et	4	main
oli	doc_491521502122_item	2599318	et	3	main
tü	doc_491521502122_item	2599319	et	4	main
juures	doc_491521502122_item	2599320	et	4	main
arstid	doc_491521502122_item	2599325	et	4	main
häid	doc_491521502122_item	2599327	et	3	main
tulemus	doc_491521502122_item	2599328	et	3	main
loodi	doc_491521502122_item	2599329	et	4	main
robert	doc_491521502122_item	2599335	et	4	main
eestis	doc_491521502122_item	2599339	et	3	main
r	doc_491521502122_item	2599341	et	4	main
enamasti	doc_491521502122_item	2599343	et	4	main
orienteerus	doc_491521502122_item	2599344	et	3	main
poliitikale	doc_491521502122_item	2599345	et	3	main
oli	doc_491521502122_item	2599346	et	3	main
aktiivne	doc_491521502122_item	2599347	et	3	main
poliitik	doc_491521502122_item	2599348	et	3	main
kostnud	doc_491521502122_item	2599353	et	4	main
koolilugemikke	doc_491521502122_item	2599355	et	3	main
ajaloo	doc_491521502122_item	2599357	et	4	main
õpikuid	doc_491521502122_item	2599358	et	4	main
viljandis	doc_491521502122_item	2599366	et	4	main
lubatud	doc_491521502122_item	2599411	et	4	main
oma	doc_491521502122_item	2599420	et	4	main
olid	doc_491521502122_item	2599424	et	4	main
ilmusid	doc_491521502122_item	2599433	et	4	main
või	doc_491521502122_item	2599250	et	4	main
valida	doc_491521502122_item	2599251	et	3	main
kutseõpe	doc_491521502122_item	2599252	et	3	main
3	doc_491521502122_item	2599253	et	2	main
teaduses	doc_491521502122_item	2599262	et	3	main
uuriti	doc_491521502122_item	2599264	et	3	main
eesti	doc_491521502122_item	2599265	et	4	main
keelt	doc_491521502122_item	2599266	et	4	main
mõistesõnaraamat	doc_491521502122_item	2599270	et	4	main
tegeles	doc_491521502122_item	2599273	et	3	main
j	doc_491521502122_item	2599275	et	4	main
veski	doc_491521502122_item	2599277	et	4	main
e	doc_491521502122_item	2599278	et	4	main
muuk	doc_491521502122_item	2599279	et	3	main
uurijad	doc_491521502122_item	2599287	et	4	main
töötas	doc_491521502122_item	2599288	et	3	main
akadeemiline	doc_491521502122_item	2599289	et	3	main
eesti	doc_491521502122_item	2599294	et	4	main
arhiiv	doc_491521502122_item	2599296	et	3	main
uuris	doc_491521502122_item	2599298	et	4	main
kõrgema	doc_491521502122_item	2599301	et	4	main
põllumajandusteadus	doc_491521502122_item	2599323	et	4	main
saavutasid	doc_491521502122_item	2599326	et	4	main
roll	doc_491521502122_item	2599337	et	3	main
samas	doc_491521502122_item	2599349	et	4	main
põllumajanduslikk	doc_491521502122_item	2599359	et	4	main
brošüüre	doc_491521502122_item	2599360	et	2	main
ajalehe	doc_491521502122_item	2599369	et	3	main
pidas	doc_491521502122_item	2599370	et	3	main
ja	doc_491521502122_item	2599405	et	3	main
usuvabadus	doc_491521502122_item	2599412	et	4	main
seltsi	doc_491521502122_item	2599413	et	4	main
võisid	doc_491521502122_item	2599417	et	4	main
kultuurieluga	doc_491521502122_item	2599422	et	3	main
algkool	doc_491521502122_item	2599432	et	4	main
tekkisid	doc_491521502122_item	2599439	et	4	main
seltsid	doc_491521502122_item	2599440	et	4	main
instituut	doc_491521502122_item	2599322	et	3	main
eesti	doc_491521502122_item	2599324	et	4	main
carl	doc_491521502122_item	2599334	et	4	main
kooliõpetaja	doc_491521502122_item	2599351	et	4	main
tema	doc_491521502122_item	2599361	et	4	main
hakkas	doc_491521502122_item	2599362	et	3	main
alates	doc_491521502122_item	2599363	et	3	main
aastast	doc_491521502122_item	2599365	et	4	main
eestimaalt	doc_491521502122_item	2599372	et	3	main
eesti	doc_491521502122_item	2599374	et	4	main
valguse-	doc_491521502122_item	2599376	et	4	main
pimeduse-	doc_491521502122_item	2599377	et	4	main
ja	doc_491521502122_item	2599378	et	3	main
koiduajast	doc_491521502122_item	2599379	et	4	main
tegeles	doc_491521502122_item	2599380	et	3	main
esimesena	doc_491521502122_item	2599381	et	3	main
piimatööstusega	doc_491521502122_item	2599382	et	3	main
korraldas	doc_491521502122_item	2599383	et	3	main
põllumajandusnäituseid	doc_491521502122_item	2599384	et	3	main
oli	doc_491521502122_item	2599385	et	3	main
põllumeesteseltsi	doc_491521502122_item	2599386	et	4	main
liider	doc_491521502122_item	2599387	et	3	main
3	doc_491521502122_item	2599388	et	2	main
vähemusrahvuste	doc_491521502122_item	2599389	et	3	main
kultuuri-	doc_491521502122_item	2599390	et	4	main
ja	doc_491521502122_item	2599391	et	3	main
hariduselu	doc_491521502122_item	2599392	et	4	main
eesti	doc_491521502122_item	2599393	et	4	main
vabariigis	doc_491521502122_item	2599394	et	3	main
1925	doc_491521502122_item	2599395	et	2	main
võeti	doc_491521502122_item	2599396	et	3	main
vastu	doc_491521502122_item	2599397	et	3	main
seadus	doc_491521502122_item	2599398	et	4	main
vähemusrahvuste	doc_491521502122_item	2599399	et	3	main
kultuuriautonoomia	doc_491521502122_item	2599400	et	4	main
sakslased	doc_491521502122_item	2599403	et	3	main
nad	doc_491521502122_item	2599416	et	3	main
vene	doc_491521502122_item	2599435	et	4	main
ja	doc_491521502122_item	2599436	et	3	main
rootsikeelsed	doc_491521502122_item	2599437	et	3	main
ajakirjad	doc_491521502122_item	2599438	et	3	main
juudi	doc_491521502122_item	2599425	et	3	main
saksa	doc_491521502122_item	2599427	et	4	main
ja	doc_491521502122_item	2599428	et	3	main
vene	doc_491521502122_item	2599429	et	4	main
gümnaasiumid	doc_491521502122_item	2599430	et	3	main
soomekeelne	doc_491521502122_item	2599431	et	3	main
lahing	doc_491521502125_item	2599862	et	3	main
petseri	doc_491521502125_item	2599866	et	4	main
põhiseadus	doc_491521502125_item	2599872	et	4	main
rahuläbirääkimised	doc_491521502125_item	2599873	et	3	main
vahel	doc_491521502125_item	2599877	et	4	main
nende	doc_491521502125_item	2599898	et	4	main
töid	doc_491521502125_item	2599899	et	3	main
perno	doc_491521502125_item	2599906	et	4	main
rahva	doc_491521502125_item	2599936	et	3	main
seltsi	doc_491521502125_item	2599945	et	4	main
eesti	doc_491521502125_item	2599951	et	4	main
pärast	doc_491521502125_item	2599970	et	4	main
1900	doc_491521502125_item	2599972	et	2	main
tallinnasse	doc_491521502125_item	2599975	et	3	main
poshe	doc_491521502125_item	2599982	et	4	main
ta	doc_491521502125_item	2599986	et	4	main
1905	doc_491521502125_item	2599998	et	2	main
eesti	doc_491521502126_item	2600008	et	4	main
vabariigi	doc_491521502126_item	2600009	et	3	main
1905	doc_491521502126_item	2600018	et	2	main
püüe	doc_491521502126_item	2600021	et	3	main
se	doc_491521502126_item	2600023	et	4	main
ühiserahva	doc_491521502126_item	2600032	et	4	main
eestis	doc_491521502126_item	2600036	et	3	main
euroopas	doc_491521502126_item	2600039	et	3	main
a	doc_491521502126_item	2600044	et	4	main
revolutsioon	doc_491521502126_item	2600045	et	3	main
ja	doc_491521502126_item	2600061	et	3	main
eestimaa	doc_491521502126_item	2600063	et	4	main
koosseisus	doc_491521502126_item	2600067	et	4	main
lubati	doc_491521502126_item	2600069	et	3	main
mõu	doc_491521502126_item	2600075	et	4	main
oli	doc_491521502126_item	2600076	et	3	main
eksamitöö	doc_491521502125_item	2599843	et	4	main
nov	doc_491521502125_item	2599854	et	4	main
1918	doc_491521502125_item	2599855	et	2	main
algus	doc_491521502125_item	2599857	et	4	main
1919	doc_491521502125_item	2599860	et	2	main
eesti	doc_491521502125_item	2599874	et	4	main
30	doc_491521502125_item	2599878	et	2	main
tänu	doc_491521502125_item	2599850	et	4	main
järgmistele	doc_491521502125_item	2599851	et	3	main
sündmustele	doc_491521502125_item	2599852	et	3	main
28	doc_491521502125_item	2599853	et	2	main
paju	doc_491521502125_item	2599861	et	4	main
tegevus	doc_491521502125_item	2599869	et	4	main
venemaa	doc_491521502125_item	2599876	et	4	main
rahu	doc_491521502125_item	2599882	et	4	main
02	doc_491521502125_item	2599886	et	2	main
loetle	doc_491521502125_item	2599892	et	4	main
ärkamisaegseid	doc_491521502125_item	2599894	et	3	main
esimest	doc_491521502125_item	2599904	et	4	main
ajalehte	doc_491521502125_item	2599905	et	4	main
kõnet	doc_491521502125_item	2599921	et	3	main
pimeduse-	doc_491521502125_item	2599923	et	4	main
mihkel	doc_491521502125_item	2599929	et	3	main
veske	doc_491521502125_item	2599930	et	4	main
ta	doc_491521502125_item	2599934	et	4	main
3	doc_491521502125_item	2599947	et	2	main
vabariigis	doc_491521502125_item	2599952	et	3	main
1938	doc_491521502125_item	2599955	et	2	main
kus	doc_491521502125_item	2599976	et	3	main
g	doc_491521502125_item	2599981	et	4	main
advokaadina	doc_491521502125_item	2599983	et	3	main
ajalehe	doc_491521502125_item	2599985	et	3	main
valitsusse	doc_491521502125_item	2599997	et	4	main
eksamitöö	doc_491521502126_item	2600006	et	4	main
1	doc_491521502126_item	2600007	et	2	main
sündmustele	doc_491521502126_item	2600015	et	3	main
venemaal	doc_491521502126_item	2600016	et	4	main
toimus	doc_491521502126_item	2600017	et	3	main
aastal	doc_491521502126_item	2600019	et	3	main
eesti	doc_491521502125_item	2599845	et	4	main
vabadussõja	doc_491521502125_item	2599856	et	3	main
30	doc_491521502125_item	2599858	et	2	main
jaan	doc_491521502125_item	2599859	et	3	main
02	doc_491521502125_item	2599864	et	2	main
lõpeb	doc_491521502125_item	2599867	et	4	main
sõja	doc_491521502125_item	2599868	et	3	main
1920	doc_491521502125_item	2599870	et	2	main
eesti	doc_491521502125_item	2599871	et	4	main
01	doc_491521502125_item	2599879	et	2	main
tartu	doc_491521502125_item	2599881	et	4	main
rahu	doc_491521502125_item	2599883	et	4	main
leppisid	doc_491521502125_item	2599884	et	4	main
2	doc_491521502125_item	2599885	et	2	main
1920	doc_491521502125_item	2599887	et	2	main
eesti	doc_491521502125_item	2599888	et	4	main
vabariigi	doc_491521502125_item	2599889	et	3	main
hakkas	doc_491521502125_item	2599901	et	3	main
andma	doc_491521502125_item	2599902	et	3	main
välja	doc_491521502125_item	2599903	et	4	main
koiduajast	doc_491521502125_item	2599925	et	4	main
koolilugemisraamat	doc_491521502125_item	2599926	et	3	main
laule	doc_491521502125_item	2599937	et	4	main
karell	doc_491521502125_item	2599938	et	4	main
hurt	doc_491521502125_item	2599942	et	3	main
kirjanduse	doc_491521502125_item	2599944	et	3	main
president	doc_491521502125_item	2599946	et	3	main
roll	doc_491521502125_item	2599950	et	3	main
04	doc_491521502125_item	2599954	et	2	main
a	doc_491521502125_item	2599956	et	4	main
valiti	doc_491521502125_item	2599957	et	3	main
juht	doc_491521502125_item	2599969	et	3	main
sõjaväkke	doc_491521502125_item	2599971	et	3	main
a	doc_491521502125_item	2599973	et	4	main
tuleb	doc_491521502125_item	2599974	et	3	main
poliitikuna	doc_491521502125_item	2599979	et	3	main
avaldab	doc_491521502125_item	2599987	et	3	main
tallinnas	doc_491521502125_item	2599988	et	4	main
eesti-vene	doc_491521502125_item	2599989	et	4	main
blokk	doc_491521502125_item	2599990	et	3	main
võidab	doc_491521502125_item	2599991	et	3	main
loomine	doc_491521502126_item	2600010	et	4	main
revolutsiooni	doc_491521502126_item	2600020	et	4	main
ja	doc_491521502126_item	2600022	et	3	main
negatiivselt	doc_491521502126_item	2600025	et	4	main
venelaste	doc_491521502126_item	2600026	et	4	main
vaid	doc_491521502126_item	2600037	et	3	main
ajutine	doc_491521502126_item	2600049	et	4	main
valisus	doc_491521502126_item	2600050	et	4	main
eesti	doc_491521502126_item	2600057	et	4	main
liidrid	doc_491521502126_item	2600058	et	3	main
palusid	doc_491521502126_item	2600062	et	4	main
jaaoks	doc_491521502126_item	2600064	et	4	main
autonoomiat	doc_491521502126_item	2600065	et	3	main
neile	doc_491521502126_item	2600068	et	4	main
tugev	doc_491521502126_item	2600074	et	4	main
toimus	doc_491521502126_item	2600086	et	3	main
eestlaste	doc_491521502126_item	2600087	et	4	main
arenes	doc_491521502126_item	2600092	et	3	main
olid	doc_491521502126_item	2600096	et	4	main
ja	doc_491521502126_item	2600098	et	3	main
põlisrahvale	doc_491521502126_item	2600105	et	3	main
ja	doc_491521502126_item	2600115	et	3	main
ärkamisaegseid	doc_491521502126_item	2600125	et	3	main
1	doc_491521502125_item	2599844	et	2	main
vabariigi	doc_491521502125_item	2599846	et	3	main
loomine	doc_491521502125_item	2599847	et	4	main
sai	doc_491521502125_item	2599848	et	4	main
võimalikuks	doc_491521502125_item	2599849	et	3	main
4	doc_491521502125_item	2599863	et	2	main
1919	doc_491521502125_item	2599865	et	2	main
ja	doc_491521502125_item	2599875	et	3	main
1920	doc_491521502125_item	2599880	et	2	main
2	doc_491521502125_item	2599891	et	2	main
kultuuritegelase	doc_491521502125_item	2599895	et	3	main
ja	doc_491521502125_item	2599896	et	3	main
postimees	doc_491521502125_item	2599907	et	4	main
korraldas	doc_491521502125_item	2599908	et	3	main
esimest	doc_491521502125_item	2599909	et	4	main
eesti	doc_491521502125_item	2599910	et	4	main
üldlaulupidu	doc_491521502125_item	2599911	et	4	main
faehlmann	doc_491521502125_item	2599912	et	4	main
kreutzwald	doc_491521502125_item	2599913	et	4	main
kirjutasid	doc_491521502125_item	2599914	et	4	main
eepose	doc_491521502125_item	2599915	et	3	main
kalevipoeg	doc_491521502125_item	2599916	et	3	main
c	doc_491521502125_item	2599917	et	4	main
r	doc_491521502125_item	2599918	et	4	main
jakobson	doc_491521502125_item	2599919	et	4	main
3	doc_491521502125_item	2599920	et	2	main
iseseisvus	doc_491521502125_item	2599890	et	4	main
tähtsamaid	doc_491521502125_item	2599893	et	4	main
nimeta	doc_491521502125_item	2599897	et	4	main
jansen	doc_491521502125_item	2599900	et	4	main
valguse-	doc_491521502125_item	2599922	et	4	main
ja	doc_491521502125_item	2599924	et	3	main
ajaleht	doc_491521502125_item	2599927	et	3	main
kogus	doc_491521502125_item	2599935	et	4	main
helilooja	doc_491521502125_item	2599940	et	4	main
j	doc_491521502125_item	2599941	et	4	main
eesti	doc_491521502125_item	2599943	et	4	main
konstantin	doc_491521502125_item	2599948	et	4	main
tahab	doc_491521502125_item	2599977	et	3	main
töötas	doc_491521502125_item	2599980	et	3	main
teataja	doc_491521502125_item	2599984	et	4	main
linnapea	doc_491521502125_item	2600004	et	4	main
abiliseks	doc_491521502125_item	2600005	et	4	main
tänu	doc_491521502126_item	2600013	et	4	main
järgmistele	doc_491521502126_item	2600014	et	3	main
mõjutas	doc_491521502126_item	2600024	et	3	main
mitte	doc_491521502126_item	2600034	et	3	main
kogu	doc_491521502126_item	2600038	et	4	main
venemaal	doc_491521502126_item	2600046	et	4	main
ja	doc_491521502126_item	2600047	et	3	main
veel	doc_491521502126_item	2600054	et	4	main
venemaa	doc_491521502126_item	2600066	et	4	main
toimusid	doc_491521502126_item	2600071	et	4	main
monitestatsioonid	doc_491521502126_item	2600072	et	4	main
tahtsid	doc_491521502126_item	2600082	et	4	main
ka	doc_491521502126_item	2600083	et	3	main
rahvaks	doc_491521502126_item	2600090	et	3	main
põllumajandus	doc_491521502126_item	2600094	et	3	main
seltsi	doc_491521502126_item	2600103	et	4	main
aoma	doc_491521502126_item	2600119	et	4	main
organiseerimiseks	doc_491521502126_item	2600121	et	4	main
tähtsamaid	doc_491521502126_item	2600124	et	4	main
rahvana	doc_491521502126_item	2600139	et	3	main
siin	doc_491521502126_item	2600141	et	4	main
roll	doc_491521502126_item	2600144	et	3	main
kultuuritegelastel	doc_491521502126_item	2600146	et	3	main
tekkis	doc_491521502126_item	2600147	et	3	main
pooldaja	doc_491521502126_item	2600159	et	4	main
2	doc_491521502126_item	2600160	et	2	main
j	doc_491521502126_item	2600188	et	4	main
j	doc_491521502126_item	2600193	et	4	main
kirjameeste	doc_491521502126_item	2600205	et	4	main
ametlikult	doc_491521502126_item	2600212	et	4	main
eeskujul	doc_491521502126_item	2600222	et	3	main
vabariigis	doc_491521502126_item	2600240	et	3	main
eesti	doc_491521502126_item	2600244	et	4	main
president	doc_491521502126_item	2600246	et	3	main
valiti	doc_491521502126_item	2600253	et	3	main
ja	doc_491521502126_item	2600255	et	3	main
eesmärgiks	doc_491521502126_item	2600258	et	3	main
võitles	doc_491521502126_item	2600273	et	3	main
eesti	doc_491521502126_item	2600275	et	4	main
eest	doc_491521502126_item	2600277	et	4	main
1934	doc_491521502126_item	2600278	et	2	main
kuulutas	doc_491521502126_item	2600279	et	3	main
aga	doc_491521502126_item	2600280	et	3	main
vägivastu	doc_491521502126_item	2600281	et	4	main
eesti	doc_491521502126_item	2600285	et	4	main
sakala	doc_491521502125_item	2599928	et	4	main
eesti	doc_491521502125_item	2599931	et	4	main
keele	doc_491521502125_item	2599932	et	4	main
teadlane	doc_491521502125_item	2599933	et	3	main
esimene	doc_491521502125_item	2599939	et	3	main
pätsi	doc_491521502125_item	2599949	et	4	main
24	doc_491521502125_item	2599953	et	2	main
teda	doc_491521502125_item	2599958	et	4	main
eesti	doc_491521502125_item	2599959	et	4	main
vabariigi	doc_491521502125_item	2599960	et	3	main
presidendiks	doc_491521502125_item	2599961	et	4	main
1920	doc_491521502125_item	2599962	et	2	main
aastail	doc_491521502125_item	2599963	et	4	main
oli	doc_491521502125_item	2599964	et	3	main
koos	doc_491521502125_item	2599965	et	4	main
tõnisoniga	doc_491521502125_item	2599966	et	4	main
riigivanem	doc_491521502125_item	2599967	et	4	main
maavalitsuse	doc_491521502125_item	2599968	et	3	main
olla	doc_491521502125_item	2599978	et	3	main
baltisakslaste	doc_491521502125_item	2599992	et	4	main
üle	doc_491521502125_item	2599993	et	3	main
ja	doc_491521502125_item	2599994	et	3	main
ta	doc_491521502125_item	2599995	et	4	main
pääseb	doc_491521502125_item	2599996	et	3	main
a	doc_491521502125_item	2599999	et	4	main
valiti	doc_491521502125_item	2600000	et	3	main
k	doc_491521502125_item	2600001	et	4	main
pätsa	doc_491521502125_item	2600002	et	4	main
tallinna	doc_491521502125_item	2600003	et	4	main
sai	doc_491521502126_item	2600011	et	4	main
võimalikuks	doc_491521502126_item	2600012	et	3	main
peole	doc_491521502126_item	2600027	et	4	main
hakkas	doc_491521502126_item	2600028	et	3	main
arenema	doc_491521502126_item	2600029	et	3	main
rahvuskultuur	doc_491521502126_item	2600030	et	3	main
ainult	doc_491521502126_item	2600035	et	4	main
mis	doc_491521502126_item	2600040	et	4	main
oli	doc_491521502126_item	2600041	et	3	main
eeskujuks	doc_491521502126_item	2600042	et	3	main
mis	doc_491521502126_item	2600051	et	4	main
tundis	doc_491521502126_item	2600052	et	3	main
ennast	doc_491521502126_item	2600053	et	4	main
kasutasid	doc_491521502126_item	2600059	et	4	main
muutmine	doc_491521502126_item	2600088	et	4	main
saksastumise	doc_491521502126_item	2600097	et	4	main
venestamise	doc_491521502126_item	2600099	et	4	main
võrdseid	doc_491521502126_item	2600106	et	3	main
õigusi	doc_491521502126_item	2600108	et	4	main
sõlmis	doc_491521502126_item	2600110	et	4	main
venemaaga	doc_491521502126_item	2600111	et	3	main
rahulepingu	doc_491521502126_item	2600114	et	3	main
see	doc_491521502126_item	2600116	et	3	main
võimaluse	doc_491521502126_item	2600118	et	3	main
keel	doc_491521502126_item	2600031	et	4	main
tunne	doc_491521502126_item	2600033	et	4	main
1917	doc_491521502126_item	2600043	et	2	main
tuli	doc_491521502126_item	2600048	et	4	main
ebakindlalt	doc_491521502126_item	2600055	et	4	main
ja	doc_491521502126_item	2600056	et	3	main
hetke	doc_491521502126_item	2600060	et	4	main
peterburis	doc_491521502126_item	2600070	et	4	main
eestis	doc_491521502126_item	2600073	et	3	main
iseseisvust	doc_491521502126_item	2600084	et	4	main
saavutada	doc_491521502126_item	2600085	et	3	main
kiiresti	doc_491521502126_item	2600091	et	3	main
töstus	doc_491521502126_item	2600093	et	4	main
eestlased	doc_491521502126_item	2600095	et	3	main
korrldasid	doc_491521502126_item	2600101	et	4	main
üritusi	doc_491521502126_item	2600102	et	4	main
nõudsid	doc_491521502126_item	2600104	et	4	main
eesti	doc_491521502126_item	2600109	et	4	main
2021920	doc_491521502126_item	2600112	et	2	main
riigi	doc_491521502126_item	2600120	et	3	main
2	doc_491521502126_item	2600122	et	2	main
nimeta	doc_491521502126_item	2600128	et	4	main
töid	doc_491521502126_item	2600130	et	3	main
arkamisaeg	doc_491521502126_item	2600131	et	4	main
1930ndates	doc_491521502126_item	2600133	et	4	main
kui	doc_491521502126_item	2600134	et	3	main
hakkas	doc_491521502126_item	2600136	et	3	main
ihise	doc_491521502126_item	2600138	et	4	main
tundma	doc_491521502126_item	2600140	et	3	main
suur	doc_491521502126_item	2600143	et	3	main
kaks	doc_491521502126_item	2600148	et	3	main
r	doc_491521502126_item	2600152	et	4	main
jakobson	doc_491521502126_item	2600153	et	4	main
tema	doc_491521502126_item	2600155	et	4	main
i	doc_491521502126_item	2600164	et	4	main
uldlaulupidu	doc_491521502126_item	2600165	et	4	main
tartus	doc_491521502126_item	2600166	et	3	main
kalevipoeg	doc_491521502126_item	2600186	et	3	main
koostamine	doc_491521502126_item	2600187	et	4	main
ka	doc_491521502126_item	2600190	et	3	main
orienteerus	doc_491521502126_item	2600195	et	3	main
eesti	doc_491521502126_item	2600198	et	4	main
seltsi	doc_491521502126_item	2600206	et	4	main
l	doc_491521502126_item	2600209	et	4	main
panebbaluse	doc_491521502126_item	2600211	et	4	main
pooldas	doc_491521502126_item	2600215	et	3	main
eesti	doc_491521502126_item	2600216	et	4	main
saksa	doc_491521502126_item	2600221	et	4	main
kirjutas	doc_491521502126_item	2600223	et	3	main
1880ndat	doc_491521502126_item	2600226	et	4	main
kriis	doc_491521502126_item	2600227	et	3	main
konstantin	doc_491521502126_item	2600236	et	4	main
pätsi	doc_491521502126_item	2600237	et	4	main
roll	doc_491521502126_item	2600238	et	3	main
esimene	doc_491521502126_item	2600243	et	3	main
1938a	doc_491521502126_item	2600247	et	4	main
saavutas	doc_491521502126_item	2600250	et	3	main
iseseisvuse	doc_491521502126_item	2600259	et	4	main
oli	doc_491521502126_item	2600261	et	3	main
esimene	doc_491521502126_item	2600263	et	3	main
konstitutsioon	doc_491521502126_item	2600264	et	3	main
manitesti	doc_491521502126_item	2600268	et	4	main
mõne	doc_491521502126_item	2600323	et	3	main
eksamitöö	doc_491521502127_item	2600327	et	4	main
venemaa	doc_491521502127_item	2600337	et	4	main
olnud	doc_491521502127_item	2600345	et	4	main
tugevana	doc_491521502127_item	2600354	et	4	main
oma	doc_491521502127_item	2600362	et	4	main
streikidega	doc_491521502127_item	2600365	et	3	main
streigi	doc_491521502127_item	2600368	et	4	main
alustab	doc_491521502127_item	2600386	et	3	main
oma	doc_491521502127_item	2600387	et	4	main
uue	doc_491521502127_item	2600408	et	3	main
aluseks	doc_491521502127_item	2600414	et	4	main
karell	doc_491521502127_item	2600426	et	4	main
oli	doc_491521502127_item	2600427	et	3	main
esimene	doc_491521502127_item	2600428	et	3	main
arst	doc_491521502127_item	2600429	et	3	main
j	doc_491521502127_item	2600451	et	4	main
1857	doc_491521502127_item	2600461	et	2	main
folkloori	doc_491521502127_item	2600470	et	4	main
ta	doc_491521502127_item	2600481	et	4	main
enne	doc_491521502127_item	2600488	et	4	main
liikumise	doc_491521502127_item	2600500	et	4	main
liidritel	doc_491521502126_item	2600077	et	3	main
kes	doc_491521502126_item	2600078	et	4	main
olid	doc_491521502126_item	2600079	et	4	main
haritud	doc_491521502126_item	2600080	et	4	main
ja	doc_491521502126_item	2600081	et	3	main
tsiviliseerituks	doc_491521502126_item	2600089	et	4	main
vastu	doc_491521502126_item	2600100	et	3	main
poliitilisi	doc_491521502126_item	2600107	et	3	main
a	doc_491521502126_item	2600113	et	4	main
annas	doc_491521502126_item	2600117	et	3	main
end	doc_491521502126_item	2600137	et	4	main
k	doc_491521502126_item	2600151	et	4	main
köler	doc_491521502126_item	2600189	et	4	main
venetee	doc_491521502126_item	2600192	et	4	main
eestlstele	doc_491521502126_item	2600196	et	4	main
vaimu	doc_491521502126_item	2600217	et	4	main
ka	doc_491521502126_item	2600224	et	3	main
loetle	doc_491521502126_item	2600123	et	4	main
kultuuritegelasi	doc_491521502126_item	2600126	et	3	main
mitmndal	doc_491521502126_item	2600145	et	4	main
1	doc_491521502126_item	2600150	et	2	main
ja	doc_491521502126_item	2600154	et	3	main
3	doc_491521502126_item	2600156	et	2	main
kõnet	doc_491521502126_item	2600157	et	3	main
venelaste	doc_491521502126_item	2600158	et	4	main
1969	doc_491521502126_item	2600167	et	2	main
a	doc_491521502126_item	2600168	et	4	main
koidula	doc_491521502126_item	2600170	et	4	main
ludia	doc_491521502126_item	2600169	et	4	main
paneb	doc_491521502126_item	2600171	et	3	main
aluse	doc_491521502126_item	2600172	et	4	main
1863	doc_491521502126_item	2600173	et	2	main
a	doc_491521502126_item	2600174	et	4	main
vanemuise	doc_491521502126_item	2600175	et	4	main
laulu-	doc_491521502126_item	2600176	et	4	main
ja	doc_491521502126_item	2600177	et	3	main
mänguseltsile	doc_491521502126_item	2600178	et	3	main
fr	doc_491521502126_item	2600179	et	4	main
r	doc_491521502126_item	2600180	et	4	main
kreutzwald	doc_491521502126_item	2600181	et	4	main
ja	doc_491521502126_item	2600182	et	3	main
faehlmann	doc_491521502126_item	2600183	et	4	main
eesti	doc_491521502126_item	2600184	et	4	main
rahvuseepolse	doc_491521502126_item	2600185	et	4	main
ja	doc_491521502126_item	2600127	et	3	main
nende	doc_491521502126_item	2600129	et	4	main
algas	doc_491521502126_item	2600132	et	3	main
rahvas	doc_491521502126_item	2600135	et	4	main
oli	doc_491521502126_item	2600142	et	3	main
suunda	doc_491521502126_item	2600149	et	4	main
jannsen	doc_491521502126_item	2600161	et	4	main
ja	doc_491521502126_item	2600162	et	3	main
vanemuine	doc_491521502126_item	2600163	et	4	main
hurt	doc_491521502126_item	2600194	et	3	main
ja	doc_491521502126_item	2600200	et	3	main
religiooni	doc_491521502126_item	2600201	et	4	main
oli	doc_491521502126_item	2600202	et	3	main
ka	doc_491521502126_item	2600203	et	3	main
eesti	doc_491521502126_item	2600204	et	4	main
presidentiks	doc_491521502126_item	2600207	et	4	main
kultuuri	doc_491521502126_item	2600218	et	4	main
lavastas	doc_491521502126_item	2600219	et	3	main
näidendeid	doc_491521502126_item	2600220	et	3	main
jakobson	doc_491521502126_item	2600230	et	4	main
ja	doc_491521502126_item	2600231	et	3	main
eesti	doc_491521502126_item	2600239	et	4	main
kui	doc_491521502126_item	2600248	et	3	main
autonoomiat	doc_491521502126_item	2600251	et	3	main
riigipeaks	doc_491521502126_item	2600254	et	3	main
ta	doc_491521502126_item	2600256	et	4	main
saavutamist	doc_491521502126_item	2600260	et	4	main
loodud	doc_491521502126_item	2600262	et	4	main
1918a	doc_491521502126_item	2600265	et	4	main
ja	doc_491521502126_item	2600269	et	3	main
ka	doc_491521502126_item	2600271	et	3	main
et	doc_491521502126_item	2600282	et	3	main
jooksul	doc_491521502126_item	2600325	et	4	main
vanglas	doc_491521502126_item	2600326	et	3	main
eesti	doc_491521502127_item	2600329	et	4	main
sai	doc_491521502127_item	2600332	et	4	main
võimalikuks	doc_491521502127_item	2600333	et	3	main
ta	doc_491521502127_item	2600343	et	4	main
eesti	doc_491521502127_item	2600348	et	4	main
end	doc_491521502127_item	2600351	et	4	main
ühtlasena	doc_491521502127_item	2600352	et	3	main
ja	doc_491521502127_item	2600353	et	3	main
enne	doc_491521502127_item	2600361	et	4	main
nad	doc_491521502127_item	2600378	et	3	main
aastal	doc_491521502127_item	2600382	et	3	main
itsus	doc_491521502127_item	2600385	et	4	main
andmise	doc_491521502127_item	2600394	et	4	main
nende	doc_491521502127_item	2600403	et	4	main
eduard	doc_491521502127_item	2600405	et	4	main
kirjaviisi	doc_491521502127_item	2600409	et	4	main
rahvuskeel	doc_491521502127_item	2600413	et	4	main
pooldas	doc_491521502126_item	2600191	et	3	main
pooldas	doc_491521502126_item	2600197	et	3	main
keelt	doc_491521502126_item	2600199	et	4	main
1870ndates	doc_491521502126_item	2600208	et	4	main
koidula	doc_491521502126_item	2600210	et	4	main
eesti	doc_491521502126_item	2600213	et	4	main
rahvusteartrile	doc_491521502126_item	2600214	et	3	main
ise	doc_491521502126_item	2600225	et	4	main
sest	doc_491521502126_item	2600228	et	4	main
surid	doc_491521502126_item	2600229	et	4	main
päts	doc_491521502126_item	2600242	et	3	main
vabariigi	doc_491521502126_item	2600245	et	3	main
eesti	doc_491521502126_item	2600249	et	4	main
püstitas	doc_491521502126_item	2600257	et	3	main
ka	doc_491521502126_item	2600267	et	3	main
luges	doc_491521502126_item	2600270	et	3	main
aktiivselt	doc_491521502126_item	2600274	et	4	main
õiguste	doc_491521502126_item	2600276	et	4	main
võimu	doc_491521502126_item	2600283	et	4	main
hoida	doc_491521502126_item	2600284	et	3	main
aja	doc_491521502126_item	2600324	et	4	main
1	doc_491521502127_item	2600328	et	2	main
vabariigi	doc_491521502127_item	2600330	et	3	main
loomine	doc_491521502127_item	2600331	et	4	main
i	doc_491521502127_item	2600339	et	4	main
maailmasõjas	doc_491521502127_item	2600340	et	3	main
nii	doc_491521502127_item	2600341	et	3	main
et	doc_491521502127_item	2600342	et	3	main
sellele	doc_491521502127_item	2600356	et	4	main
ta	doc_491521502127_item	2600358	et	4	main
protestidega	doc_491521502127_item	2600363	et	3	main
ja	doc_491521502127_item	2600364	et	3	main
1905	doc_491521502127_item	2600366	et	2	main
aastal	doc_491521502127_item	2600367	et	3	main
eestlased	doc_491521502127_item	2600370	et	3	main
et	doc_491521502127_item	2600373	et	3	main
sai	doc_491521502127_item	2600375	et	4	main
tundsid	doc_491521502127_item	2600379	et	4	main
jõu	doc_491521502127_item	2600380	et	3	main
tööd	doc_491521502127_item	2600388	et	4	main
2	doc_491521502127_item	2600396	et	2	main
töid	doc_491521502127_item	2600404	et	3	main
lõi	doc_491521502127_item	2600407	et	4	main
sai	doc_491521502127_item	2600411	et	4	main
välja	doc_491521502127_item	2600419	et	4	main
brošüüre	doc_491521502127_item	2600420	et	2	main
aastast	doc_491521502127_item	2600436	et	4	main
ta	doc_491521502127_item	2600437	et	4	main
rahvaluule	doc_491521502127_item	2600468	et	4	main
ja	doc_491521502127_item	2600469	et	3	main
aprill	doc_491521502127_item	2600478	et	3	main
esialgu	doc_491521502127_item	2600487	et	3	main
vabariigi	doc_491521502127_item	2600491	et	3	main
juhte	doc_491521502127_item	2600501	et	4	main
ja	doc_491521502127_item	2600502	et	3	main
ajalehe	doc_491521502127_item	2600508	et	3	main
suburg	doc_491521502127_item	2600511	et	3	main
pärnus	doc_491521502127_item	2600515	et	3	main
muuk	doc_491521502127_item	2600518	et	3	main
mägiste	doc_491521502127_item	2600521	et	4	main
adamson	doc_491521502127_item	2600529	et	4	main
a	doc_491521502127_item	2600532	et	4	main
võimalikuks	doc_491521502128_item	2600541	et	3	main
1914	doc_491521502128_item	2600545	et	2	main
maailmasõda	doc_491521502128_item	2600549	et	4	main
venemaa	doc_491521502128_item	2600550	et	4	main
ja	doc_491521502128_item	2600551	et	3	main
saab	doc_491521502128_item	2600562	et	3	main
1917	doc_491521502128_item	2600591	et	2	main
otsus	doc_491521502128_item	2600596	et	3	main
vabariigiks	doc_491521502128_item	2600600	et	3	main
olid	doc_491521502128_item	2600619	et	4	main
venemaal	doc_491521502128_item	2600627	et	4	main
toimunud	doc_491521502128_item	2600628	et	4	main
peale	doc_491521502128_item	2600635	et	4	main
suruma	doc_491521502128_item	2600636	et	3	main
nende	doc_491521502128_item	2600648	et	4	main
pärnus	doc_491521502128_item	2600653	et	3	main
1864	doc_491521502128_item	2600670	et	2	main
kurgja	doc_491521502128_item	2600705	et	4	main
kreutzwald	doc_491521502126_item	2600232	et	4	main
suleti	doc_491521502126_item	2600233	et	3	main
ekms	doc_491521502126_item	2600234	et	4	main
3	doc_491521502126_item	2600235	et	2	main
k	doc_491521502126_item	2600241	et	4	main
teda	doc_491521502126_item	2600252	et	4	main
koostas	doc_491521502126_item	2600266	et	4	main
ette	doc_491521502126_item	2600272	et	4	main
kroon	doc_491521502126_item	2600286	et	3	main
sai	doc_491521502126_item	2600287	et	4	main
rahvusvaheliselt	doc_491521502126_item	2600288	et	4	main
tunnustatud	doc_491521502126_item	2600289	et	4	main
1930-ndatek	doc_491521502126_item	2600290	et	4	main
ei	doc_491521502126_item	2600291	et	4	main
hukka	doc_491521502126_item	2600292	et	4	main
poliitilisel	doc_491521502126_item	2600293	et	3	main
põhjuse	doc_491521502126_item	2600294	et	3	main
ühtegi	doc_491521502126_item	2600295	et	4	main
inimest	doc_491521502126_item	2600296	et	3	main
k	doc_491521502126_item	2600297	et	4	main
päts	doc_491521502126_item	2600298	et	3	main
oli	doc_491521502126_item	2600299	et	3	main
radikaal	doc_491521502126_item	2600300	et	4	main
ja	doc_491521502126_item	2600301	et	3	main
ajalehe	doc_491521502126_item	2600302	et	3	main
teataja	doc_491521502126_item	2600303	et	4	main
toimetaja	doc_491521502126_item	2600304	et	4	main
pooldas	doc_491521502126_item	2600305	et	3	main
reforme	doc_491521502126_item	2600306	et	3	main
1904	doc_491521502126_item	2600307	et	2	main
a	doc_491521502126_item	2600308	et	4	main
tallinnas	doc_491521502126_item	2600309	et	4	main
saavutati	doc_491521502126_item	2600310	et	3	main
võim	doc_491521502126_item	2600311	et	3	main
sakslaste	doc_491521502126_item	2600312	et	3	main
üle	doc_491521502126_item	2600313	et	3	main
k	doc_491521502126_item	2600314	et	4	main
päts	doc_491521502126_item	2600315	et	3	main
oli	doc_491521502126_item	2600316	et	3	main
eestist	doc_491521502126_item	2600317	et	3	main
välja	doc_491521502126_item	2600318	et	4	main
saadetud	doc_491521502126_item	2600319	et	4	main
ja	doc_491521502126_item	2600320	et	3	main
ka	doc_491521502126_item	2600322	et	3	main
ei	doc_491521502127_item	2600344	et	4	main
tugev	doc_491521502127_item	2600347	et	4	main
rahvas	doc_491521502127_item	2600349	et	4	main
istus	doc_491521502126_item	2600321	et	4	main
tänu	doc_491521502127_item	2600334	et	4	main
järgmistele	doc_491521502127_item	2600335	et	3	main
sündmustele	doc_491521502127_item	2600336	et	3	main
osales	doc_491521502127_item	2600338	et	3	main
eriti	doc_491521502127_item	2600346	et	3	main
saavutasid	doc_491521502127_item	2600371	et	4	main
10	doc_491521502127_item	2600376	et	2	main
tunniliseks	doc_491521502127_item	2600377	et	4	main
ajutine	doc_491521502127_item	2600383	et	4	main
val	doc_491521502127_item	2600384	et	4	main
ja	doc_491521502127_item	2600389	et	3	main
annab	doc_491521502127_item	2600391	et	3	main
omavalitsuse	doc_491521502127_item	2600393	et	3	main
seaduse	doc_491521502127_item	2600395	et	3	main
ärkamisaegseid	doc_491521502127_item	2600399	et	3	main
kultuuritegelasi	doc_491521502127_item	2600400	et	3	main
ja	doc_491521502127_item	2600401	et	3	main
nimeta	doc_491521502127_item	2600402	et	4	main
ühise	doc_491521502127_item	2600412	et	3	main
karl	doc_491521502127_item	2600415	et	4	main
robert	doc_491521502127_item	2600416	et	4	main
jakobson	doc_491521502127_item	2600417	et	4	main
andis	doc_491521502127_item	2600418	et	3	main
mis	doc_491521502127_item	2600421	et	4	main
talupoegadel	doc_491521502127_item	2600423	et	3	main
tegelda	doc_491521502127_item	2600424	et	4	main
põllumajandusega	doc_491521502127_item	2600425	et	3	main
ekms-is	doc_491521502127_item	2600433	et	3	main
st	doc_491521502127_item	2600435	et	3	main
kirjtuas	doc_491521502127_item	2600438	et	4	main
eestlaste	doc_491521502127_item	2600445	et	4	main
hulgas	doc_491521502127_item	2600446	et	4	main
ja	doc_491521502127_item	2600447	et	3	main
aitasid	doc_491521502127_item	2600448	et	4	main
tõsta	doc_491521502127_item	2600449	et	4	main
aastast	doc_491521502127_item	2600463	et	4	main
wiedemann	doc_491521502127_item	2600464	et	4	main
3	doc_491521502127_item	2600471	et	2	main
konstantin	doc_491521502127_item	2600472	et	4	main
pätsi	doc_491521502127_item	2600473	et	4	main
roll	doc_491521502127_item	2600474	et	3	main
presidendiks	doc_491521502127_item	2600486	et	4	main
linnapea	doc_491521502127_item	2600494	et	4	main
avaldas	doc_491521502127_item	2600506	et	3	main
esimese	doc_491521502127_item	2600513	et	3	main
tütarlastekooli	doc_491521502127_item	2600514	et	4	main
veski	doc_491521502127_item	2600517	et	4	main
keeleuuendamisega	doc_491521502127_item	2600520	et	3	main
valmis	doc_491521502127_item	2600530	et	4	main
russalka	doc_491521502127_item	2600533	et	4	main
mälestussamma	doc_491521502127_item	2600534	et	3	main
vabariigi	doc_491521502128_item	2600538	et	3	main
järgmistele	doc_491521502128_item	2600543	et	3	main
mätsis	doc_491521502128_item	2600561	et	3	main
kubermangu	doc_491521502128_item	2600564	et	4	main
kõrgema	doc_491521502128_item	2600586	et	4	main
võimu	doc_491521502128_item	2600587	et	4	main
ja	doc_491521502128_item	2600590	et	3	main
lõpus	doc_491521502128_item	2600593	et	4	main
eesti	doc_491521502128_item	2600598	et	4	main
a	doc_491521502128_item	2600602	et	4	main
tehtigi	doc_491521502128_item	2600604	et	3	main
mis	doc_491521502128_item	2600605	et	4	main
võiduga	doc_491521502128_item	2600617	et	4	main
eestlased	doc_491521502128_item	2600618	et	3	main
juba	doc_491521502128_item	2600622	et	3	main
soovinud	doc_491521502128_item	2600624	et	4	main
varjus	doc_491521502128_item	2600631	et	4	main
hakati	doc_491521502128_item	2600632	et	3	main
loetle	doc_491521502128_item	2600642	et	4	main
1857	doc_491521502128_item	2600650	et	2	main
j	doc_491521502128_item	2600654	et	4	main
jannseni	doc_491521502128_item	2600656	et	4	main
eestvedamisel	doc_491521502128_item	2600657	et	3	main
ilmuma	doc_491521502128_item	2600658	et	3	main
ajaleht	doc_491521502128_item	2600659	et	3	main
perno	doc_491521502128_item	2600660	et	4	main
kasutati	doc_491521502128_item	2600665	et	4	main
nimetust	doc_491521502128_item	2600666	et	4	main
eestlased	doc_491521502128_item	2600667	et	3	main
1872	doc_491521502128_item	2600703	et	2	main
tundis	doc_491521502127_item	2600350	et	3	main
tänu	doc_491521502127_item	2600355	et	4	main
mida	doc_491521502127_item	2600357	et	4	main
oli	doc_491521502127_item	2600359	et	3	main
saavutanud	doc_491521502127_item	2600360	et	4	main
tulemusena	doc_491521502127_item	2600369	et	3	main
seda	doc_491521502127_item	2600372	et	3	main
tööpäev	doc_491521502127_item	2600374	et	3	main
1918	doc_491521502127_item	2600381	et	2	main
see	doc_491521502127_item	2600390	et	3	main
seaduse	doc_491521502127_item	2600392	et	3	main
loetle	doc_491521502127_item	2600397	et	4	main
tähtsamaid	doc_491521502127_item	2600398	et	4	main
ahrens	doc_491521502127_item	2600406	et	4	main
mis	doc_491521502127_item	2600410	et	4	main
tegeles	doc_491521502127_item	2600432	et	3	main
1874	doc_491521502127_item	2600434	et	2	main
laule	doc_491521502127_item	2600439	et	4	main
ja	doc_491521502127_item	2600440	et	3	main
näidendeid	doc_491521502127_item	2600441	et	3	main
mis	doc_491521502127_item	2600442	et	4	main
olid	doc_491521502127_item	2600443	et	4	main
populaarsed	doc_491521502127_item	2600444	et	3	main
rahvavaimu	doc_491521502127_item	2600450	et	4	main
kogusid	doc_491521502127_item	2600467	et	4	main
eesti	doc_491521502127_item	2600475	et	4	main
vabariigis	doc_491521502127_item	2600476	et	3	main
24	doc_491521502127_item	2600477	et	2	main
1938	doc_491521502127_item	2600479	et	2	main
aastal	doc_491521502127_item	2600480	et	3	main
esimest	doc_491521502127_item	2600489	et	4	main
oli	doc_491521502127_item	2600492	et	3	main
valitsuse	doc_491521502127_item	2600503	et	4	main
juhte	doc_491521502127_item	2600504	et	4	main
2	doc_491521502127_item	2600509	et	2	main
aitasid	doc_491521502127_item	2600422	et	4	main
l	doc_491521502127_item	2600430	et	4	main
koidula	doc_491521502127_item	2600431	et	4	main
v	doc_491521502127_item	2600452	et	4	main
jannsen	doc_491521502127_item	2600453	et	4	main
andis	doc_491521502127_item	2600454	et	3	main
välja	doc_491521502127_item	2600455	et	4	main
esimese	doc_491521502127_item	2600456	et	3	main
eesti	doc_491521502127_item	2600457	et	4	main
ajalehe	doc_491521502127_item	2600458	et	3	main
perno	doc_491521502127_item	2600459	et	4	main
postimees	doc_491521502127_item	2600460	et	4	main
st	doc_491521502127_item	2600462	et	3	main
ja	doc_491521502127_item	2600465	et	3	main
kreutzwald	doc_491521502127_item	2600466	et	4	main
sai	doc_491521502127_item	2600482	et	4	main
esimeseks	doc_491521502127_item	2600483	et	3	main
eesti	doc_491521502127_item	2600484	et	4	main
vabariigi	doc_491521502127_item	2600485	et	3	main
eesti	doc_491521502127_item	2600490	et	4	main
ta	doc_491521502127_item	2600493	et	4	main
abiliseks	doc_491521502127_item	2600495	et	4	main
hiljem	doc_491521502127_item	2600496	et	3	main
temast	doc_491521502127_item	2600497	et	3	main
sai	doc_491521502127_item	2600498	et	4	main
üks	doc_491521502127_item	2600499	et	3	main
teataja	doc_491521502127_item	2600507	et	4	main
aavik	doc_491521502127_item	2600516	et	4	main
tegelesid	doc_491521502127_item	2600524	et	4	main
eksamitöö	doc_491521502128_item	2600535	et	4	main
loomine	doc_491521502128_item	2600539	et	4	main
tänu	doc_491521502128_item	2600542	et	4	main
segadust	doc_491521502128_item	2600558	et	4	main
eestis	doc_491521502128_item	2600589	et	3	main
vastu	doc_491521502128_item	2600595	et	3	main
kuulutada	doc_491521502128_item	2600597	et	3	main
a	doc_491521502128_item	2600611	et	4	main
rohkem	doc_491521502128_item	2600634	et	4	main
hakkas	doc_491521502128_item	2600652	et	3	main
v	doc_491521502128_item	2600655	et	4	main
rahvas	doc_491521502128_item	2600669	et	4	main
leht	doc_491521502128_item	2600673	et	3	main
jakob	doc_491521502128_item	2600707	et	4	main
seltsi	doc_491521502128_item	2600712	et	4	main
oli	doc_491521502128_item	2600715	et	3	main
1884	doc_491521502128_item	2600719	et	2	main
a	doc_491521502128_item	2600720	et	4	main
jannseni	doc_491521502128_item	2600731	et	4	main
eesvedamisel	doc_491521502128_item	2600732	et	3	main
jannseni	doc_491521502128_item	2600739	et	4	main
tütar	doc_491521502128_item	2600740	et	3	main
lauldi	doc_491521502128_item	2600746	et	3	main
laulupidudel	doc_491521502128_item	2600747	et	4	main
3	doc_491521502128_item	2600748	et	2	main
päts	doc_491521502128_item	2600755	et	3	main
ja	doc_491521502128_item	2600758	et	3	main
algselt	doc_491521502128_item	2600765	et	4	main
oli	doc_491521502128_item	2600766	et	3	main
tema	doc_491521502128_item	2600767	et	4	main
ametinimi	doc_491521502128_item	2600768	et	3	main
a	doc_491521502128_item	2600774	et	4	main
sa	doc_491521502128_item	2600775	et	3	main
ajal	doc_491521502128_item	2600781	et	4	main
ei	doc_491521502128_item	2600782	et	4	main
saanud	doc_491521502128_item	2600783	et	4	main
eestlased	doc_491521502128_item	2600784	et	3	main
eriti	doc_491521502128_item	2600785	et	3	main
samuti	doc_491521502128_item	2600796	et	3	main
on	doc_491521502128_item	2600797	et	4	main
heidetud	doc_491521502128_item	2600800	et	4	main
baaside	doc_491521502128_item	2600801	et	3	main
lepingule	doc_491521502128_item	2600802	et	3	main
liiga	doc_491521502128_item	2600803	et	4	main
riigi	doc_491521502128_item	2600821	et	3	main
1	doc_491521502129_item	2600825	et	2	main
vabariigi	doc_491521502129_item	2600827	et	3	main
järgmistele	doc_491521502129_item	2600832	et	3	main
eesti	doc_491521502129_item	2600835	et	4	main
hakkas	doc_491521502129_item	2600837	et	3	main
loodi	doc_491521502129_item	2600846	et	4	main
tekkis	doc_491521502129_item	2600847	et	3	main
tsaari	doc_491521502129_item	2600859	et	4	main
3	doc_491521502129_item	2600861	et	2	main
eesti	doc_491521502129_item	2600862	et	4	main
poliitikud	doc_491521502129_item	2600863	et	3	main
riigipöörde	doc_491521502129_item	2600867	et	4	main
4	doc_491521502129_item	2600872	et	2	main
olin	doc_491521502129_item	2600876	et	3	main
ja	doc_491521502129_item	2600908	et	3	main
lõi	doc_491521502129_item	2600928	et	4	main
ajaleht	doc_491521502129_item	2600929	et	3	main
sakala	doc_491521502129_item	2600930	et	4	main
see	doc_491521502129_item	2600931	et	3	main
poliitiline	doc_491521502129_item	2600934	et	3	main
ta	doc_491521502127_item	2600505	et	4	main
lilli	doc_491521502127_item	2600510	et	4	main
avas	doc_491521502127_item	2600512	et	4	main
tegelesid	doc_491521502127_item	2600519	et	4	main
ja	doc_491521502127_item	2600522	et	3	main
areste	doc_491521502127_item	2600523	et	3	main
1902	doc_491521502127_item	2600531	et	2	main
1	doc_491521502128_item	2600536	et	2	main
sai	doc_491521502128_item	2600540	et	4	main
sündmustele	doc_491521502128_item	2600544	et	3	main
a	doc_491521502128_item	2600546	et	4	main
i	doc_491521502128_item	2600548	et	4	main
saksamaa	doc_491521502128_item	2600552	et	4	main
vahel	doc_491521502128_item	2600553	et	4	main
see	doc_491521502128_item	2600554	et	3	main
tekitas	doc_491521502128_item	2600555	et	3	main
euroopas	doc_491521502128_item	2600556	et	3	main
omajagu	doc_491521502128_item	2600557	et	3	main
eestimaa	doc_491521502128_item	2600563	et	4	main
jaan	doc_491521502128_item	2600566	et	3	main
kandjaks	doc_491521502128_item	2600588	et	4	main
iseseisvaks	doc_491521502128_item	2600599	et	3	main
seda	doc_491521502128_item	2600603	et	3	main
mis	doc_491521502128_item	2600609	et	4	main
2021920	doc_491521502128_item	2600610	et	2	main
tartu	doc_491521502128_item	2600613	et	4	main
eestlaste	doc_491521502128_item	2600616	et	4	main
soome-ugri	doc_491521502127_item	2600525	et	3	main
keelte	doc_491521502127_item	2600526	et	3	main
uurimusega	doc_491521502127_item	2600527	et	3	main
a	doc_491521502127_item	2600528	et	4	main
eesti	doc_491521502128_item	2600537	et	4	main
algas	doc_491521502128_item	2600547	et	3	main
1917	doc_491521502128_item	2600559	et	2	main
a	doc_491521502128_item	2600560	et	4	main
peaks	doc_491521502128_item	2600565	et	4	main
poska	doc_491521502128_item	2600567	et	4	main
veebruaris	doc_491521502128_item	2600568	et	3	main
oli	doc_491521502128_item	2600569	et	3	main
venemaal	doc_491521502128_item	2600570	et	4	main
kukutatud	doc_491521502128_item	2600571	et	4	main
tsaar	doc_491521502128_item	2600572	et	3	main
ja	doc_491521502128_item	2600573	et	3	main
ajutine	doc_491521502128_item	2600574	et	4	main
valitsus	doc_491521502128_item	2600575	et	4	main
andis	doc_491521502128_item	2600576	et	3	main
eestile	doc_491521502128_item	2600577	et	3	main
õiguse	doc_491521502128_item	2600578	et	4	main
moodustada	doc_491521502128_item	2600579	et	3	main
oma	doc_491521502128_item	2600580	et	4	main
see	doc_491521502128_item	2600582	et	3	main
maapäeva	doc_491521502128_item	2600581	et	4	main
üksus	doc_491521502128_item	2600583	et	3	main
kuulutas	doc_491521502128_item	2600584	et	3	main
end	doc_491521502128_item	2600585	et	4	main
a	doc_491521502128_item	2600592	et	4	main
võeti	doc_491521502128_item	2600594	et	3	main
24021918	doc_491521502128_item	2600601	et	2	main
tõi	doc_491521502128_item	2600606	et	3	main
kaasa	doc_491521502128_item	2600607	et	4	main
vabadussõja	doc_491521502128_item	2600608	et	3	main
lõppes	doc_491521502128_item	2600612	et	4	main
rahu	doc_491521502128_item	2600614	et	4	main
allakirjutamisega	doc_491521502128_item	2600615	et	3	main
iseseisvust	doc_491521502128_item	2600620	et	4	main
tegelikult	doc_491521502128_item	2600621	et	4	main
ammu	doc_491521502128_item	2600623	et	4	main
hetkelise	doc_491521502128_item	2600629	et	4	main
segaduse	doc_491521502128_item	2600630	et	3	main
ja	doc_491521502128_item	2600637	et	3	main
see	doc_491521502128_item	2600638	et	3	main
läkski	doc_491521502128_item	2600639	et	3	main
läbi	doc_491521502128_item	2600640	et	4	main
2	doc_491521502128_item	2600641	et	2	main
töid	doc_491521502128_item	2600649	et	3	main
postimees	doc_491521502128_item	2600661	et	4	main
kus	doc_491521502128_item	2600662	et	3	main
eesti	doc_491521502128_item	2600668	et	4	main
muutus	doc_491521502128_item	2600672	et	4	main
eesti	doc_491521502128_item	2600674	et	4	main
a	doc_491521502128_item	2600704	et	4	main
kirjameeste	doc_491521502128_item	2600711	et	4	main
ametilt	doc_491521502128_item	2600714	et	3	main
1869	doc_491521502128_item	2600735	et	2	main
pätsi	doc_491521502128_item	2600750	et	4	main
juhtida	doc_491521502128_item	2600764	et	4	main
1938	doc_491521502128_item	2600773	et	2	main
ta	doc_491521502128_item	2600776	et	4	main
president	doc_491521502128_item	2600778	et	3	main
soomega	doc_491521502128_item	2600787	et	4	main
talle	doc_491521502128_item	2600798	et	4	main
kiiresti	doc_491521502128_item	2600804	et	3	main
suur	doc_491521502128_item	2600822	et	3	main
sai	doc_491521502129_item	2600829	et	4	main
sündmustele	doc_491521502129_item	2600833	et	3	main
rahvas	doc_491521502129_item	2600836	et	4	main
kui	doc_491521502129_item	2600841	et	3	main
sellisena	doc_491521502129_item	2600842	et	4	main
venemaal	doc_491521502129_item	2600850	et	4	main
viia	doc_491521502129_item	2600866	et	3	main
saavutasid	doc_491521502129_item	2600869	et	4	main
ajaleht	doc_491521502129_item	2600916	et	3	main
r	doc_491521502129_item	2600920	et	4	main
ja	doc_491521502128_item	2600625	et	3	main
nüüd	doc_491521502128_item	2600626	et	4	main
ühe	doc_491521502128_item	2600633	et	4	main
tähtsamaid	doc_491521502128_item	2600643	et	4	main
ärkamisaegseid	doc_491521502128_item	2600644	et	3	main
kultuuritegelasi	doc_491521502128_item	2600645	et	3	main
ja	doc_491521502128_item	2600646	et	3	main
nimeta	doc_491521502128_item	2600647	et	4	main
a	doc_491521502128_item	2600651	et	4	main
esimest	doc_491521502128_item	2600663	et	4	main
korda	doc_491521502128_item	2600664	et	4	main
a	doc_491521502128_item	2600671	et	4	main
postimeheks	doc_491521502128_item	2600675	et	3	main
samas	doc_491521502128_item	2600676	et	4	main
lehes	doc_491521502128_item	2600677	et	3	main
töötas	doc_491521502128_item	2600678	et	3	main
ka	doc_491521502128_item	2600679	et	3	main
jakobson	doc_491521502128_item	2600680	et	4	main
kes	doc_491521502128_item	2600681	et	4	main
1878	doc_491521502128_item	2600682	et	2	main
a	doc_491521502128_item	2600683	et	4	main
tegi	doc_491521502128_item	2600684	et	4	main
oma	doc_491521502128_item	2600685	et	4	main
lehe	doc_491521502128_item	2600686	et	3	main
sakala	doc_491521502128_item	2600687	et	4	main
jakobson	doc_491521502128_item	2600688	et	4	main
oli	doc_491521502128_item	2600689	et	3	main
ka	doc_491521502128_item	2600690	et	3	main
suur	doc_491521502128_item	2600691	et	3	main
põllumeeste	doc_491521502128_item	2600692	et	4	main
seltside	doc_491521502128_item	2600693	et	3	main
pooldaja	doc_491521502128_item	2600694	et	4	main
ta	doc_491521502128_item	2600695	et	4	main
pidas	doc_491521502128_item	2600696	et	3	main
1864	doc_491521502128_item	2600697	et	2	main
a	doc_491521502128_item	2600698	et	4	main
kolm	doc_491521502128_item	2600699	et	3	main
lõi	doc_491521502128_item	2600702	et	4	main
isama	doc_491521502128_item	2600700	et	4	main
kõnet	doc_491521502128_item	2600701	et	3	main
oli	doc_491521502128_item	2600709	et	3	main
eesti	doc_491521502128_item	2600721	et	4	main
lipu	doc_491521502128_item	2600723	et	3	main
eesti	doc_491521502128_item	2600725	et	4	main
keelse	doc_491521502128_item	2600726	et	3	main
hariduse	doc_491521502128_item	2600727	et	3	main
kirjanduse	doc_491521502128_item	2600728	et	3	main
teoks	doc_491521502128_item	2600734	et	4	main
luuletaja	doc_491521502128_item	2600743	et	4	main
kelle	doc_491521502128_item	2600744	et	4	main
laule	doc_491521502128_item	2600745	et	4	main
roll	doc_491521502128_item	2600751	et	3	main
haritud	doc_491521502128_item	2600757	et	4	main
mees	doc_491521502128_item	2600760	et	4	main
riigivanem	doc_491521502128_item	2600769	et	4	main
aga	doc_491521502128_item	2600770	et	3	main
aprillil	doc_491521502128_item	2600772	et	3	main
läbi	doc_491521502128_item	2600786	et	4	main
ei	doc_491521502128_item	2600790	et	4	main
pätsi	doc_491521502128_item	2600792	et	4	main
liiga	doc_491521502128_item	2600793	et	4	main
autoritaarne	doc_491521502128_item	2600794	et	4	main
valitsemisstiil	doc_491521502128_item	2600795	et	3	main
näidistalu	doc_491521502128_item	2600706	et	4	main
hurt	doc_491521502128_item	2600708	et	3	main
eesti	doc_491521502128_item	2600710	et	4	main
esimees	doc_491521502128_item	2600713	et	4	main
ta	doc_491521502128_item	2600716	et	4	main
pastor	doc_491521502128_item	2600717	et	3	main
õnnistas	doc_491521502128_item	2600718	et	3	main
tuline	doc_491521502128_item	2600729	et	4	main
pooldaja	doc_491521502128_item	2600730	et	4	main
a	doc_491521502128_item	2600736	et	4	main
esimene	doc_491521502128_item	2600737	et	3	main
laulupidu	doc_491521502128_item	2600738	et	4	main
eesti	doc_491521502128_item	2600752	et	4	main
vabariigis	doc_491521502128_item	2600753	et	3	main
konstantin	doc_491521502128_item	2600754	et	4	main
kes	doc_491521502128_item	2600761	et	4	main
oskas	doc_491521502128_item	2600762	et	3	main
riiki	doc_491521502128_item	2600763	et	4	main
24	doc_491521502128_item	2600771	et	2	main
ametinimeks	doc_491521502128_item	2600777	et	3	main
esimese	doc_491521502128_item	2600779	et	3	main
vabariigi	doc_491521502128_item	2600780	et	3	main
sest	doc_491521502128_item	2600788	et	4	main
soomlastele	doc_491521502128_item	2600789	et	3	main
ette	doc_491521502128_item	2600799	et	4	main
tänu	doc_491521502129_item	2600831	et	4	main
1	doc_491521502129_item	2600834	et	2	main
kultuurilekunstile	doc_491521502129_item	2600844	et	4	main
muutused	doc_491521502129_item	2600852	et	4	main
alustades	doc_491521502129_item	2600853	et	3	main
revolutsiooniga	doc_491521502129_item	2600854	et	3	main
1905	doc_491521502129_item	2600855	et	2	main
tahtsid	doc_491521502129_item	2600864	et	4	main
ja	doc_491521502129_item	2600868	et	3	main
olukord	doc_491521502129_item	2600874	et	3	main
loetle	doc_491521502129_item	2600904	et	4	main
jannsen	doc_491521502129_item	2600914	et	4	main
1847	doc_491521502129_item	2600918	et	2	main
rahvuseepose	doc_491521502129_item	2600923	et	3	main
seotud	doc_491521502129_item	2600939	et	4	main
kes	doc_491521502129_item	2600943	et	4	main
tegelesid	doc_491521502129_item	2600944	et	4	main
aavik	doc_491521502129_item	2600950	et	4	main
kirjanukud	doc_491521502129_item	2600951	et	3	main
nt	doc_491521502129_item	2600952	et	4	main
läbi	doc_491521502129_item	2600967	et	4	main
päts	doc_491521502129_item	2600974	et	3	main
olnud	doc_491521502129_item	2600983	et	4	main
päästekomitees	doc_491521502129_item	2600984	et	3	main
ta	doc_491521502129_item	2600985	et	4	main
teised	doc_491521502129_item	2600995	et	4	main
et	doc_491521502129_item	2601002	et	3	main
on	doc_491521502129_item	2601004	et	4	main
radikaalne	doc_491521502129_item	2601006	et	3	main
üliõpilaste	doc_491521502128_item	2600722	et	4	main
ta	doc_491521502128_item	2600724	et	4	main
sai	doc_491521502128_item	2600733	et	4	main
koidula	doc_491521502128_item	2600741	et	4	main
oli	doc_491521502128_item	2600742	et	3	main
konstantin	doc_491521502128_item	2600749	et	4	main
oli	doc_491521502128_item	2600756	et	3	main
tark	doc_491521502128_item	2600759	et	3	main
meeldinud	doc_491521502128_item	2600791	et	4	main
alla	doc_491521502128_item	2600805	et	3	main
kirjutamist	doc_491521502128_item	2600806	et	4	main
pätsi	doc_491521502128_item	2600807	et	4	main
juhitud	doc_491521502128_item	2600808	et	4	main
vabariigi	doc_491521502128_item	2600809	et	3	main
ajal	doc_491521502128_item	2600810	et	4	main
oli	doc_491521502128_item	2600811	et	3	main
eesti	doc_491521502128_item	2600812	et	4	main
välispoliitikaga	doc_491521502128_item	2600813	et	3	main
kõik	doc_491521502128_item	2600814	et	4	main
korras	doc_491521502128_item	2600815	et	4	main
majandus	doc_491521502128_item	2600816	et	4	main
arenes	doc_491521502128_item	2600817	et	3	main
päts	doc_491521502128_item	2600818	et	3	main
oli	doc_491521502128_item	2600819	et	3	main
oma	doc_491521502128_item	2600820	et	4	main
juht	doc_491521502128_item	2600823	et	3	main
eesti	doc_491521502129_item	2600826	et	4	main
võimalikuks	doc_491521502129_item	2600830	et	3	main
tänu	doc_491521502129_item	2600843	et	4	main
2	doc_491521502129_item	2600849	et	2	main
toimunud	doc_491521502129_item	2600851	et	4	main
al	doc_491521502129_item	2600856	et	4	main
aastal	doc_491521502129_item	2600857	et	3	main
kuni	doc_491521502129_item	2600858	et	3	main
ka	doc_491521502129_item	2600871	et	3	main
majanduslik	doc_491521502129_item	2600873	et	3	main
eestis	doc_491521502129_item	2600875	et	3	main
nimeta	doc_491521502129_item	2600909	et	4	main
töid	doc_491521502129_item	2600911	et	3	main
v	doc_491521502129_item	2600913	et	4	main
postimees	doc_491521502129_item	2600917	et	4	main
f	doc_491521502129_item	2600919	et	4	main
kreutzwald	doc_491521502129_item	2600921	et	4	main
k	doc_491521502129_item	2600925	et	4	main
oli	doc_491521502129_item	2600932	et	3	main
ka	doc_491521502129_item	2600933	et	3	main
mitte	doc_491521502129_item	2600936	et	3	main
mitmed	doc_491521502129_item	2600940	et	4	main
wiedemann	doc_491521502129_item	2600948	et	4	main
j	doc_491521502129_item	2600949	et	4	main
sai	doc_491521502129_item	2600970	et	4	main
iseseisvaks	doc_491521502129_item	2600971	et	3	main
eesti	doc_491521502129_item	2600976	et	4	main
seda	doc_491521502129_item	2600980	et	3	main
väideti	doc_491521502129_item	2601001	et	3	main
eksamitöö	doc_491521502131_item	2601122	et	4	main
eksamitöö	doc_491521502129_item	2600824	et	4	main
loomine	doc_491521502129_item	2600828	et	4	main
end	doc_491521502129_item	2600838	et	4	main
tundma	doc_491521502129_item	2600839	et	3	main
rahvusena	doc_491521502129_item	2600840	et	3	main
mida	doc_491521502129_item	2600845	et	4	main
rahvusmeelsus	doc_491521502129_item	2600848	et	4	main
kukkutamiseni	doc_491521502129_item	2600860	et	4	main
läbi	doc_491521502129_item	2600865	et	4	main
selle	doc_491521502129_item	2600870	et	4	main
hea	doc_491521502129_item	2600877	et	4	main
st	doc_491521502129_item	2600878	et	3	main
inimesed	doc_491521502129_item	2600879	et	3	main
pidanud	doc_491521502129_item	2600881	et	4	main
ei	doc_491521502129_item	2600880	et	4	main
ainult	doc_491521502129_item	2600882	et	4	main
toidu	doc_491521502129_item	2600883	et	3	main
pärast	doc_491521502129_item	2600884	et	4	main
muretsema	doc_491521502129_item	2600885	et	3	main
5	doc_491521502129_item	2600886	et	2	main
poliitil	doc_491521502129_item	2600887	et	4	main
sündmused	doc_491521502129_item	2600888	et	3	main
mujal	doc_491521502129_item	2600889	et	3	main
maailmas	doc_491521502129_item	2600890	et	3	main
i	doc_491521502129_item	2600891	et	4	main
maailmasõda	doc_491521502129_item	2600892	et	4	main
mitmeid	doc_491521502129_item	2600893	et	4	main
teised	doc_491521502129_item	2600894	et	4	main
riigid	doc_491521502129_item	2600895	et	3	main
mis	doc_491521502129_item	2600896	et	4	main
samuti	doc_491521502129_item	2600897	et	3	main
tahtsid	doc_491521502129_item	2600898	et	4	main
iseseisvuda	doc_491521502129_item	2600899	et	3	main
olid	doc_491521502129_item	2600900	et	4	main
eestile	doc_491521502129_item	2600901	et	3	main
eeskujuks	doc_491521502129_item	2600902	et	3	main
2	doc_491521502129_item	2600903	et	2	main
tähtsamaid	doc_491521502129_item	2600905	et	4	main
ärkamisaegseid	doc_491521502129_item	2600906	et	3	main
kultuuritegelasi	doc_491521502129_item	2600907	et	3	main
nende	doc_491521502129_item	2600910	et	4	main
j	doc_491521502129_item	2600912	et	4	main
lõi	doc_491521502129_item	2600915	et	4	main
kirjutas	doc_491521502129_item	2600922	et	3	main
kalevipoeg	doc_491521502129_item	2600924	et	3	main
r	doc_491521502129_item	2600926	et	4	main
jakobson	doc_491521502129_item	2600927	et	4	main
keeleuurijad	doc_491521502129_item	2600941	et	3	main
tegelased	doc_491521502129_item	2600942	et	3	main
veske	doc_491521502129_item	2600947	et	4	main
lydia	doc_491521502129_item	2600953	et	4	main
riigipöörde	doc_491521502129_item	2600968	et	4	main
oli	doc_491521502129_item	2600975	et	3	main
viis	doc_491521502129_item	2600986	et	4	main
tekkitas	doc_491521502129_item	2600992	et	4	main
ka	doc_491521502129_item	2600993	et	3	main
vastuolu	doc_491521502129_item	2600994	et	4	main
ei	doc_491521502129_item	2600997	et	4	main
nõus	doc_491521502129_item	2601000	et	4	main
ta	doc_491521502129_item	2601003	et	4	main
liiga	doc_491521502129_item	2601005	et	4	main
rahvusliku	doc_491521502131_item	2601124	et	3	main
olid	doc_491521502131_item	2601127	et	4	main
loetle	doc_491521502131_item	2601128	et	4	main
üks	doc_491521502131_item	2601149	et	3	main
mille	doc_491521502131_item	2601152	et	3	main
ärkamine	doc_491521502131_item	2601156	et	4	main
rahvamajandus	doc_491521502131_item	2601158	et	3	main
valida	doc_491521502131_item	2601164	et	3	main
ennast	doc_491521502131_item	2601175	et	4	main
rahvuslik	doc_491521502131_item	2601185	et	3	main
maalikunst	doc_491521502131_item	2601187	et	3	main
muusika	doc_491521502131_item	2601188	et	4	main
poliituline	doc_491521502131_item	2601191	et	4	main
1857	doc_491521502131_item	2601193	et	2	main
arengus	doc_491521502131_item	2601198	et	3	main
hakkab	doc_491521502131_item	2601199	et	3	main
ilmuma	doc_491521502131_item	2601200	et	3	main
esimene	doc_491521502131_item	2601201	et	3	main
eesti	doc_491521502131_item	2601202	et	4	main
postimees	doc_491521502131_item	2601205	et	4	main
a	doc_491521502131_item	2601207	et	4	main
eesti	doc_491521502131_item	2601208	et	4	main
majandust	doc_491521502131_item	2601221	et	4	main
eesti	doc_491521502131_item	2601225	et	4	main
tsemendi	doc_491521502131_item	2601233	et	4	main
see	doc_491521502131_item	2601240	et	3	main
venemaale	doc_491521502131_item	2601245	et	4	main
majandus	doc_491521502131_item	2601259	et	4	main
tõttu	doc_491521502131_item	2601267	et	4	main
üle	doc_491521502131_item	2601271	et	3	main
tuh	doc_491521502131_item	2601273	et	4	main
mujalt	doc_491521502131_item	2601275	et	3	main
see	doc_491521502131_item	2601276	et	3	main
oli	doc_491521502131_item	2601277	et	3	main
hea	doc_491521502131_item	2601278	et	4	main
oli	doc_491521502131_item	2601283	et	3	main
kuulusid	doc_491521502131_item	2601321	et	4	main
leht	doc_491521502129_item	2600935	et	3	main
keeleuuendamisega	doc_491521502129_item	2600945	et	3	main
m	doc_491521502129_item	2600946	et	4	main
koidula	doc_491521502129_item	2600954	et	4	main
luuled	doc_491521502129_item	2600955	et	3	main
j	doc_491521502129_item	2600956	et	4	main
hurt	doc_491521502129_item	2600957	et	3	main
3	doc_491521502129_item	2600958	et	2	main
konstantin	doc_491521502129_item	2600959	et	4	main
pätsi	doc_491521502129_item	2600960	et	4	main
roll	doc_491521502129_item	2600961	et	3	main
eesti	doc_491521502129_item	2600962	et	4	main
vabariigis	doc_491521502129_item	2600963	et	3	main
k	doc_491521502129_item	2600964	et	4	main
päts	doc_491521502129_item	2600965	et	3	main
ainult	doc_491521502129_item	2600937	et	4	main
kultuuriga	doc_491521502129_item	2600938	et	4	main
eesti	doc_491521502129_item	2600969	et	4	main
esimene	doc_491521502129_item	2600977	et	3	main
oli	doc_491521502129_item	2600981	et	3	main
läbi	doc_491521502129_item	2600987	et	4	main
mitmeid	doc_491521502129_item	2600988	et	4	main
poliitilised	doc_491521502129_item	2600989	et	3	main
reformid	doc_491521502129_item	2600990	et	4	main
kuid	doc_491521502129_item	2600991	et	4	main
poliitikud	doc_491521502129_item	2600996	et	3	main
temaga	doc_491521502129_item	2600999	et	3	main
viis	doc_491521502129_item	2600966	et	4	main
riigiks	doc_491521502129_item	2600972	et	3	main
k	doc_491521502129_item	2600973	et	4	main
president	doc_491521502129_item	2600978	et	3	main
enne	doc_491521502129_item	2600979	et	4	main
ta	doc_491521502129_item	2600982	et	4	main
olnud	doc_491521502129_item	2600998	et	4	main
ärkamise	doc_491521502131_item	2601125	et	4	main
kubermang	doc_491521502131_item	2601136	et	3	main
pärisorjusest	doc_491521502131_item	2601142	et	4	main
pärisorjusest	doc_491521502131_item	2601146	et	4	main
oli	doc_491521502131_item	2601148	et	3	main
algas	doc_491521502131_item	2601154	et	3	main
muutus	doc_491521502131_item	2601157	et	4	main
on	doc_491521502131_item	2601160	et	4	main
nüüd	doc_491521502131_item	2601161	et	4	main
teine	doc_491521502131_item	2601167	et	3	main
rahvuskultuuri	doc_491521502131_item	2601169	et	4	main
ajast	doc_491521502131_item	2601172	et	4	main
eestlased	doc_491521502131_item	2601173	et	3	main
täiuslikult	doc_491521502131_item	2601177	et	4	main
rahvuseks	doc_491521502131_item	2601179	et	4	main
tõusis	doc_491521502131_item	2601181	et	4	main
emakeel	doc_491521502131_item	2601182	et	4	main
areneb	doc_491521502131_item	2601190	et	3	main
iseteadvus	doc_491521502131_item	2601192	et	4	main
iseloomustavad	doc_491521502131_item	2601222	et	4	main
peamised	doc_491521502131_item	2601223	et	3	main
oli	doc_491521502131_item	2601241	et	3	main
toodang	doc_491521502131_item	2601244	et	3	main
aastatel	doc_491521502131_item	2601250	et	4	main
vabariigi	doc_491521502131_item	2601252	et	3	main
majandus	doc_491521502131_item	2601253	et	4	main
sattus	doc_491521502131_item	2601254	et	3	main
euroopa	doc_491521502131_item	2601255	et	4	main
turusse	doc_491521502131_item	2601256	et	3	main
põllumajandus	doc_491521502131_item	2601257	et	3	main
eestisse	doc_491521502131_item	2601269	et	4	main
nende	doc_491521502131_item	2601280	et	4	main
kirjutasid	doc_491521502131_item	2601325	et	4	main
a	doc_491521502131_item	2601329	et	4	main
enda	doc_491521502131_item	2601129	et	4	main
1	doc_491521502131_item	2601123	et	2	main
eeltingimusteks	doc_491521502131_item	2601126	et	3	main
1816	doc_491521502131_item	2601132	et	2	main
a	doc_491521502131_item	2601133	et	4	main
vabastati	doc_491521502131_item	2601134	et	3	main
eestimaa	doc_491521502131_item	2601135	et	4	main
1819	doc_491521502131_item	2601137	et	2	main
a	doc_491521502131_item	2601138	et	4	main
vabastati	doc_491521502131_item	2601139	et	3	main
võib	doc_491521502131_item	2601143	et	3	main
et	doc_491521502131_item	2601145	et	3	main
vabastamine	doc_491521502131_item	2601147	et	4	main
tähtsamateks	doc_491521502131_item	2601150	et	4	main
asjadest	doc_491521502131_item	2601151	et	3	main
vaba	doc_491521502131_item	2601162	et	4	main
saj	doc_491521502131_item	2601166	et	4	main
pool	doc_491521502131_item	2601168	et	4	main
ärkamisaeg	doc_491521502131_item	2601170	et	3	main
sellest	doc_491521502131_item	2601171	et	4	main
ühinenud	doc_491521502131_item	2601178	et	4	main
tähtsamaks	doc_491521502131_item	2601180	et	4	main
emakeele	doc_491521502131_item	2601183	et	4	main
teateer	doc_491521502131_item	2601186	et	4	main
eesti	doc_491521502131_item	2601196	et	4	main
ajaleht	doc_491521502131_item	2601203	et	3	main
1857	doc_491521502131_item	2601206	et	2	main
rahv	doc_491521502131_item	2601209	et	4	main
kui	doc_491521502131_item	2601210	et	3	main
nimetus	doc_491521502131_item	2601211	et	4	main
1860	doc_491521502131_item	2601212	et	2	main
a	doc_491521502131_item	2601213	et	4	main
rahvuse	doc_491521502131_item	2601214	et	3	main
nimetus	doc_491521502131_item	2601215	et	4	main
sai	doc_491521502131_item	2601216	et	4	main
elujõuliseks	doc_491521502131_item	2601217	et	4	main
1	doc_491521502131_item	2601218	et	2	main
eesti	doc_491521502131_item	2601219	et	4	main
vabariigi	doc_491521502131_item	2601220	et	3	main
majandus	doc_491521502131_item	2601236	et	4	main
orienteeritud	doc_491521502131_item	2601238	et	4	main
venemaale	doc_491521502131_item	2601239	et	4	main
et	doc_491521502131_item	2601246	et	3	main
englismaalt	doc_491521502131_item	2601261	et	4	main
maadest	doc_491521502131_item	2601264	et	4	main
rahu	doc_491521502131_item	2601266	et	4	main
inim	doc_491521502131_item	2601281	et	4	main
keda	doc_491521502131_item	2601286	et	4	main
kes	doc_491521502131_item	2601324	et	4	main
eesti	doc_491521502131_item	2601326	et	4	main
arvates	doc_491521502131_item	2601130	et	4	main
peamised	doc_491521502131_item	2601131	et	3	main
kubermang	doc_491521502131_item	2601141	et	3	main
saab	doc_491521502131_item	2601163	et	3	main
hakkasid	doc_491521502131_item	2601174	et	4	main
õppimine	doc_491521502131_item	2601184	et	4	main
aastaarv	doc_491521502131_item	2601195	et	3	main
kultuuri	doc_491521502131_item	2601197	et	4	main
liivimaa	doc_491521502131_item	2601140	et	4	main
öelda	doc_491521502131_item	2601144	et	4	main
järgi	doc_491521502131_item	2601153	et	4	main
rahvuslik	doc_491521502131_item	2601155	et	3	main
talupoeg	doc_491521502131_item	2601159	et	3	main
19	doc_491521502131_item	2601165	et	2	main
tundma	doc_491521502131_item	2601176	et	3	main
kirjandus	doc_491521502131_item	2601189	et	3	main
oluline	doc_491521502131_item	2601194	et	4	main
perno	doc_491521502131_item	2601204	et	4	main
tootlusest	doc_491521502131_item	2601230	et	4	main
oli	doc_491521502131_item	2601231	et	3	main
eesti	doc_491521502131_item	2601235	et	4	main
realiseerida	doc_491521502131_item	2601243	et	3	main
eesti	doc_491521502131_item	2601258	et	4	main
skandinaavia	doc_491521502131_item	2601263	et	4	main
sest	doc_491521502131_item	2601279	et	4	main
spetsialiste	doc_491521502131_item	2601285	et	3	main
vajas	doc_491521502131_item	2601288	et	4	main
eesti	doc_491521502131_item	2601290	et	4	main
vabariik	doc_491521502131_item	2601291	et	3	main
hakkas	doc_491521502131_item	2601292	et	3	main
majandust	doc_491521502131_item	2601293	et	4	main
tunnused	doc_491521502131_item	2601224	et	3	main
tööstus	doc_491521502131_item	2601226	et	3	main
sai	doc_491521502131_item	2601227	et	4	main
alguse	doc_491521502131_item	2601228	et	3	main
tekstiili	doc_491521502131_item	2601229	et	4	main
suur	doc_491521502131_item	2601232	et	3	main
tootlus	doc_491521502131_item	2601234	et	3	main
oli	doc_491521502131_item	2601237	et	3	main
eesmärk	doc_491521502131_item	2601242	et	3	main
majanduslikult	doc_491521502131_item	2601247	et	4	main
suhelda	doc_491521502131_item	2601248	et	4	main
20ndatel	doc_491521502131_item	2601249	et	4	main
eesti	doc_491521502131_item	2601251	et	4	main
sõltus	doc_491521502131_item	2601260	et	4	main
saksamaalt	doc_491521502131_item	2601262	et	3	main
tartu	doc_491521502131_item	2601265	et	4	main
asus	doc_491521502131_item	2601268	et	4	main
elama	doc_491521502131_item	2601270	et	3	main
35	doc_491521502131_item	2601272	et	2	main
inim	doc_491521502131_item	2601274	et	4	main
hulgas	doc_491521502131_item	2601282	et	4	main
palju	doc_491521502131_item	2601284	et	4	main
eestimaa	doc_491521502131_item	2601287	et	4	main
1919-1924	doc_491521502131_item	2601289	et	2	main
ümbertegema	doc_491521502131_item	2601294	et	4	main
tekkis	doc_491521502131_item	2601295	et	3	main
turuprobleem	doc_491521502131_item	2601296	et	3	main
kus	doc_491521502131_item	2601297	et	3	main
ja	doc_491521502131_item	2601298	et	3	main
kuhu	doc_491521502131_item	2601299	et	3	main
müüa	doc_491521502131_item	2601300	et	3	main
1919	doc_491521502131_item	2601301	et	2	main
asutati	doc_491521502131_item	2601302	et	4	main
eesti	doc_491521502131_item	2601303	et	4	main
pank	doc_491521502131_item	2601304	et	3	main
rahareform	doc_491521502131_item	2601305	et	3	main
eesti	doc_491521502131_item	2601306	et	4	main
argraarriik	doc_491521502131_item	2601307	et	4	main
1	doc_491521502131_item	2601308	et	2	main
rühmituse	doc_491521502131_item	2601309	et	4	main
noor-eesti	doc_491521502131_item	2601310	et	4	main
olemus	doc_491521502131_item	2601311	et	3	main
ja	doc_491521502131_item	2601312	et	3	main
tähtsus	doc_491521502131_item	2601313	et	4	main
eesti	doc_491521502131_item	2601314	et	4	main
kultuuriloos	doc_491521502131_item	2601315	et	4	main
noor-eesti	doc_491521502131_item	2601316	et	4	main
on	doc_491521502131_item	2601317	et	4	main
kirjanduslik	doc_491521502131_item	2601318	et	3	main
rüh-mitus	doc_491521502131_item	2601319	et	4	main
sinna	doc_491521502131_item	2601320	et	3	main
kirjanikud	doc_491521502131_item	2601323	et	3	main
vabriigist	doc_491521502131_item	2601327	et	4	main
visnapuu	doc_491521502131_item	2601328	et	4	main
noord	doc_491521502131_item	2601322	et	4	main
artson	doc_491521502131_item	2601330	et	4	main
tuglas	doc_491521502131_item	2601331	et	4	main
oli	doc_491521502131_item	2601332	et	3	main
üks	doc_491521502131_item	2601333	et	3	main
esindajatest	doc_491521502131_item	2601334	et	4	main
eksamitöö	doc_491521502133_item	2601667	et	4	main
varem	doc_491521502133_item	2601686	et	4	main
ja	doc_491521502133_item	2601690	et	3	main
õigust	doc_491521502133_item	2601694	et	4	main
pärast	doc_491521502133_item	2601695	et	4	main
jhurt	doc_491521502133_item	2601715	et	4	main
rahvusliku	doc_491521502133_item	2601669	et	3	main
arvates	doc_491521502133_item	2601675	et	4	main
algas	doc_491521502133_item	2601680	et	3	main
saj	doc_491521502133_item	2601682	et	4	main
olnud	doc_491521502133_item	2601693	et	4	main
pärisorjuse	doc_491521502133_item	2601696	et	3	main
kaotamist	doc_491521502133_item	2601697	et	4	main
maarahvaks	doc_491521502133_item	2601704	et	3	main
hakkasid	doc_491521502133_item	2601707	et	4	main
endale	doc_491521502133_item	2601709	et	4	main
jannsenn	doc_491521502133_item	2601718	et	4	main
faehlmann	doc_491521502133_item	2601719	et	4	main
toimus	doc_491521502133_item	2601733	et	3	main
üldlaulupidu	doc_491521502133_item	2601735	et	4	main
tudis	doc_491521502133_item	2601742	et	4	main
end	doc_491521502133_item	2601743	et	4	main
vabalt	doc_491521502133_item	2601744	et	4	main
iseseisvalt	doc_491521502133_item	2601745	et	4	main
pacius	doc_491521502133_item	2601761	et	4	main
hümn	doc_491521502133_item	2601762	et	3	main
ajaleht	doc_491521502133_item	2601767	et	3	main
õiguste	doc_491521502133_item	2601773	et	4	main
kalevipoeg	doc_491521502133_item	2601775	et	3	main
eestlaste	doc_491521502133_item	2601776	et	4	main
eneseteadvus	doc_491521502133_item	2601777	et	4	main
jooned	doc_491521502133_item	2601784	et	3	main
eesti	doc_491521502133_item	2601810	et	4	main
pank	doc_491521502133_item	2601811	et	3	main
eesti	doc_491521502133_item	2601813	et	4	main
viljakas	doc_491521502133_item	2601817	et	4	main
arenenud	doc_491521502133_item	2601820	et	4	main
suhted	doc_491521502133_item	2601826	et	3	main
linda	doc_491521502133_item	2601834	et	4	main
piimatööstus	doc_491521502133_item	2601837	et	3	main
põllumajandus	doc_491521502133_item	2601842	et	3	main
kasvatati	doc_491521502133_item	2601845	et	3	main
lina	doc_491521502133_item	2601849	et	4	main
nagu	doc_491521502133_item	2601852	et	3	main
juust	doc_491521502133_item	2601853	et	4	main
ekstensiivne	doc_491521502133_item	2601874	et	3	main
kiiresti	doc_491521502133_item	2601890	et	3	main
parenesid	doc_491521502133_item	2601892	et	4	main
nad	doc_491521502133_item	2601897	et	3	main
palju	doc_491521502133_item	2601899	et	4	main
telliskivitööstus	doc_491521502133_item	2601907	et	3	main
1	doc_491521502133_item	2601911	et	2	main
tähtsus	doc_491521502133_item	2601916	et	4	main
noor-eesti	doc_491521502133_item	2601921	et	4	main
tähtsat	doc_491521502133_item	2601923	et	3	main
eestis	doc_491521502133_item	2601934	et	3	main
ilmusid	doc_491521502133_item	2601935	et	4	main
ka	doc_491521502133_item	2601936	et	3	main
uued	doc_491521502133_item	2601937	et	3	main
suundumused	doc_491521502133_item	2601938	et	4	main
ja	doc_491521502133_item	2601940	et	3	main
skaudid	doc_491521502133_item	2601941	et	3	main
kodutütrerd	doc_491521502133_item	2601942	et	4	main
enda	doc_491521502133_item	2601674	et	4	main
rahvuslik	doc_491521502133_item	2601677	et	3	main
olid	doc_491521502133_item	2601687	et	4	main
neil	doc_491521502133_item	2601691	et	4	main
18161819	doc_491521502133_item	2601698	et	2	main
nad	doc_491521502133_item	2601699	et	3	main
hakkasid	doc_491521502133_item	2601700	et	4	main
vaid	doc_491521502133_item	2601705	et	3	main
vabadust	doc_491521502133_item	2601712	et	4	main
tähtsamad	doc_491521502133_item	2601713	et	4	main
liidrid	doc_491521502133_item	2601714	et	3	main
kreutzwald	doc_491521502133_item	2601720	et	4	main
a	doc_491521502133_item	2601722	et	4	main
ajaleht	doc_491521502133_item	2601724	et	3	main
tartus	doc_491521502133_item	2601732	et	3	main
esimene	doc_491521502133_item	2601734	et	3	main
a	doc_491521502133_item	2601737	et	4	main
pärast	doc_491521502133_item	2601738	et	4	main
pärisor	doc_491521502133_item	2601739	et	4	main
koidula	doc_491521502133_item	2601760	et	4	main
poliitiline	doc_491521502133_item	2601766	et	3	main
majandust	doc_491521502133_item	2601781	et	4	main
eesti	doc_491521502133_item	2601785	et	4	main
agraarmaa	doc_491521502133_item	2601788	et	4	main
a-	doc_491521502133_item	2601790	et	4	main
ilmus	doc_491521502133_item	2601791	et	4	main
tartus	doc_491521502133_item	2601792	et	3	main
põllumajanduse	doc_491521502133_item	2601794	et	3	main
1902	doc_491521502133_item	2601796	et	2	main
võib	doc_491521502133_item	2601798	et	3	main
majandus	doc_491521502133_item	2601814	et	4	main
loetle	doc_491521502133_item	2601673	et	4	main
peamised	doc_491521502133_item	2601676	et	3	main
ärkamise	doc_491521502133_item	2601678	et	4	main
aeg	doc_491521502133_item	2601679	et	3	main
19	doc_491521502133_item	2601681	et	2	main
algusel	doc_491521502133_item	2601683	et	4	main
sest	doc_491521502133_item	2601684	et	4	main
eestlased	doc_491521502133_item	2601685	et	3	main
vaesed	doc_491521502133_item	2601689	et	4	main
end	doc_491521502133_item	2601701	et	4	main
kutsuma	doc_491521502133_item	2601702	et	3	main
nõudma	doc_491521502133_item	2601708	et	3	main
hariduse	doc_491521502133_item	2601710	et	3	main
võimalust	doc_491521502133_item	2601711	et	3	main
1857	doc_491521502133_item	2601721	et	2	main
1869a	doc_491521502133_item	2601731	et	4	main
50	doc_491521502133_item	2601736	et	2	main
kaotamist	doc_491521502133_item	2601740	et	4	main
lauldi	doc_491521502133_item	2601748	et	3	main
5	doc_491521502133_item	2601751	et	2	main
puhkpilliorkestrit	doc_491521502133_item	2601752	et	3	main
ilmus	doc_491521502133_item	2601763	et	4	main
1878	doc_491521502133_item	2601764	et	2	main
sakala	doc_491521502133_item	2601768	et	4	main
seltsid	doc_491521502133_item	2601770	et	4	main
iseloomustavad	doc_491521502133_item	2601782	et	4	main
nimetada	doc_491521502133_item	2601799	et	3	main
oli	doc_491521502133_item	2601802	et	3	main
eesti	doc_491521502133_item	2601805	et	4	main
1919	doc_491521502133_item	2601807	et	2	main
a	doc_491521502133_item	2601808	et	4	main
loodi	doc_491521502133_item	2601809	et	4	main
ei	doc_491521502133_item	2601815	et	4	main
olnud	doc_491521502133_item	2601816	et	4	main
ja	doc_491521502133_item	2601818	et	3	main
pärast	doc_491521502133_item	2601822	et	4	main
siseturg	doc_491521502133_item	2601824	et	3	main
narvas	doc_491521502133_item	2601836	et	4	main
kartulit	doc_491521502133_item	2601847	et	3	main
eesti	doc_491521502133_item	2601850	et	4	main
tooded	doc_491521502133_item	2601851	et	4	main
tulu	doc_491521502133_item	2601859	et	4	main
ja	doc_491521502133_item	2601860	et	3	main
1	doc_491521502133_item	2601668	et	2	main
ärkamise	doc_491521502133_item	2601670	et	4	main
eeltingimusteks	doc_491521502133_item	2601671	et	3	main
olid	doc_491521502133_item	2601672	et	4	main
pärisorjad	doc_491521502133_item	2601688	et	3	main
ei	doc_491521502133_item	2601692	et	4	main
mitte	doc_491521502133_item	2601703	et	3	main
eestlaseks	doc_491521502133_item	2601706	et	3	main
jakobson	doc_491521502133_item	2601716	et	4	main
jv	doc_491521502133_item	2601717	et	4	main
kultuurileevendamine	doc_491521502133_item	2601730	et	3	main
rahvas	doc_491521502133_item	2601741	et	4	main
sest	doc_491521502133_item	2601746	et	4	main
rahvalaule	doc_491521502133_item	2601749	et	4	main
isamaa	doc_491521502133_item	2601754	et	4	main
mu	doc_491521502133_item	2601755	et	3	main
õnn	doc_491521502133_item	2601756	et	3	main
ja	doc_491521502133_item	2601757	et	3	main
rõõm	doc_491521502133_item	2601758	et	3	main
l	doc_491521502133_item	2601759	et	4	main
jakobsoni	doc_491521502133_item	2601765	et	4	main
moodustasid	doc_491521502133_item	2601769	et	4	main
ühingud	doc_491521502133_item	2601771	et	3	main
eest	doc_491521502133_item	2601774	et	4	main
peamised	doc_491521502133_item	2601783	et	3	main
on	doc_491521502133_item	2601787	et	4	main
selts	doc_491521502133_item	2601795	et	3	main
aastaks	doc_491521502133_item	2601800	et	4	main
moodustatud	doc_491521502133_item	2601803	et	4	main
alguses	doc_491521502133_item	2601812	et	4	main
venemaa	doc_491521502133_item	2601828	et	4	main
tallinnas	doc_491521502133_item	2601831	et	4	main
ilmarine	doc_491521502133_item	2601835	et	4	main
karjakasvatus	doc_491521502133_item	2601838	et	4	main
uusi	doc_491521502133_item	2601840	et	3	main
põhja-eestis	doc_491521502133_item	2601844	et	3	main
l-e	doc_491521502133_item	2601848	et	3	main
masinaehitusvarikud	doc_491521502133_item	2601869	et	3	main
dvigatel	doc_491521502133_item	2601871	et	4	main
masinatehas	doc_491521502133_item	2601872	et	3	main
paberi	doc_491521502133_item	2601875	et	3	main
tekstiiltööstus	doc_491521502133_item	2601877	et	4	main
astmel	doc_491521502133_item	2601880	et	3	main
trikotaaž	doc_491521502133_item	2601882	et	2	main
põlismurre	doc_491521502133_item	2601884	et	4	main
metsandus	doc_491521502133_item	2601887	et	3	main
majandus	doc_491521502133_item	2601889	et	4	main
arenes	doc_491521502133_item	2601891	et	3	main
partneri	doc_491521502133_item	2601893	et	3	main
eestist	doc_491521502133_item	2601900	et	3	main
sai	doc_491521502133_item	2601902	et	4	main
toormaterjale	doc_491521502133_item	2601903	et	3	main
venemaalt	doc_491521502133_item	2601904	et	3	main
fosforiidi	doc_491521502133_item	2601905	et	4	main
kultuuriloost	doc_491521502133_item	2601918	et	4	main
vabriigi	doc_491521502133_item	2601930	et	4	main
arenemist	doc_491521502133_item	2601931	et	4	main
uuendamist	doc_491521502133_item	2601933	et	4	main
kodumaa	doc_491521502133_item	2601949	et	4	main
noor-eesti	doc_491521502133_item	2601958	et	4	main
kuulusid	doc_491521502133_item	2601960	et	4	main
jänud	doc_491521502134_item	2601989	et	4	main
hästi	doc_491521502134_item	2602002	et	3	main
aastal	doc_491521502134_item	2602010	et	3	main
töökohta	doc_491521502134_item	2602013	et	4	main
müüakse	doc_491521502134_item	2602015	et	3	main
ei	doc_491521502134_item	2602019	et	4	main
käita	doc_491521502134_item	2602020	et	4	main
jannseni	doc_491521502133_item	2601723	et	4	main
perno	doc_491521502133_item	2601725	et	4	main
postimees	doc_491521502133_item	2601726	et	4	main
esimene	doc_491521502133_item	2601727	et	3	main
eestikeelne	doc_491521502133_item	2601728	et	3	main
ajaleht	doc_491521502133_item	2601729	et	3	main
seal	doc_491521502133_item	2601747	et	4	main
mängis	doc_491521502133_item	2601750	et	3	main
mu	doc_491521502133_item	2601753	et	3	main
võitlus	doc_491521502133_item	2601772	et	3	main
1	doc_491521502133_item	2601778	et	2	main
eesti	doc_491521502133_item	2601779	et	4	main
vabariigi	doc_491521502133_item	2601780	et	3	main
vabariik	doc_491521502133_item	2601786	et	3	main
1870	doc_491521502133_item	2601789	et	2	main
esim	doc_491521502133_item	2601793	et	4	main
a	doc_491521502133_item	2601797	et	4	main
millal	doc_491521502133_item	2601801	et	3	main
esimene	doc_491521502133_item	2601804	et	3	main
pank	doc_491521502133_item	2601806	et	3	main
hästi	doc_491521502133_item	2601819	et	3	main
aga	doc_491521502133_item	2601821	et	3	main
laienes	doc_491521502133_item	2601823	et	3	main
välised	doc_491521502133_item	2601825	et	4	main
euroopaga	doc_491521502133_item	2601827	et	3	main
kaudu	doc_491521502133_item	2601829	et	3	main
1879	doc_491521502133_item	2601830	et	2	main
süsteemi	doc_491521502133_item	2601843	et	4	main
ohtralt	doc_491521502133_item	2601846	et	4	main
või	doc_491521502133_item	2601856	et	4	main
läksid	doc_491521502133_item	2601857	et	4	main
ekspordile	doc_491521502133_item	2601858	et	3	main
relvastamine	doc_491521502133_item	2601864	et	4	main
ehitati	doc_491521502133_item	2601867	et	3	main
volta	doc_491521502133_item	2601873	et	4	main
kõrgemal	doc_491521502133_item	2601879	et	4	main
kunstside	doc_491521502133_item	2601881	et	4	main
kaevandus	doc_491521502133_item	2601883	et	4	main
karjandus	doc_491521502133_item	2601888	et	3	main
inglismaaga	doc_491521502133_item	2601895	et	3	main
eesti	doc_491521502133_item	2601919	et	4	main
asutati	doc_491521502133_item	2601832	et	4	main
majandusselts	doc_491521502133_item	2601833	et	3	main
leiutati	doc_491521502133_item	2601839	et	4	main
rukkusorti	doc_491521502133_item	2601841	et	4	main
sealiha	doc_491521502133_item	2601854	et	4	main
peekon	doc_491521502133_item	2601855	et	3	main
venemaal	doc_491521502133_item	2601862	et	4	main
toimus	doc_491521502133_item	2601863	et	3	main
eestis	doc_491521502133_item	2601866	et	3	main
vagunivabrik	doc_491521502133_item	2601870	et	3	main
kalandus	doc_491521502133_item	2601886	et	3	main
suhted	doc_491521502133_item	2601894	et	3	main
saksamaaga	doc_491521502133_item	2601896	et	3	main
ostsid	doc_491521502133_item	2601898	et	4	main
eesti	doc_491521502133_item	2601901	et	4	main
liiv	doc_491521502133_item	2601909	et	3	main
noor-eesti	doc_491521502133_item	2601913	et	4	main
eesti	doc_491521502133_item	2601917	et	4	main
kultuuriloos	doc_491521502133_item	2601920	et	4	main
eesti	doc_491521502133_item	2601929	et	4	main
ja	doc_491521502133_item	2601943	et	3	main
oma	doc_491521502133_item	2601948	et	4	main
kombeid	doc_491521502133_item	2601951	et	4	main
kultuuris	doc_491521502133_item	2601955	et	3	main
vahetatakse	doc_491521502134_item	2602011	et	3	main
vahetama	doc_491521502134_item	2602012	et	3	main
müüma	doc_491521502134_item	2602016	et	3	main
käima	doc_491521502134_item	2602021	et	4	main
tihti	doc_491521502134_item	2602023	et	3	main
toit	doc_491521502134_item	2602025	et	3	main
süüakse	doc_491521502134_item	2602026	et	3	main
sööma	doc_491521502134_item	2602027	et	4	main
või	doc_491521502134_item	2602035	et	4	main
nõrga	doc_491521502134_item	2602036	et	3	main
astme	doc_491521502134_item	2602037	et	3	main
vorm	doc_491521502134_item	2602038	et	3	main
võrrelda	doc_491521502134_item	2602045	et	4	main
õppida	doc_491521502134_item	2602052	et	3	main
ilusam	doc_491521502134_item	2602076	et	4	main
aeglane	doc_491521502134_item	2602078	et	3	main
aeglasemalt	doc_491521502134_item	2602080	et	4	main
hea	doc_491521502134_item	2602081	et	4	main
rõõmsamalt	doc_491521502134_item	2602086	et	4	main
halvemini	doc_491521502134_item	2602089	et	4	main
ausalt	doc_491521502134_item	2602091	et	4	main
ausamalt	doc_491521502134_item	2602092	et	4	main
vihane	doc_491521502134_item	2602093	et	4	main
siin	doc_491521502134_item	2602123	et	4	main
septembrist	doc_491521502134_item	2602125	et	3	main
seisis	doc_491521502134_item	2602137	et	4	main
sisse	doc_491521502134_item	2602143	et	4	main
tulla	doc_491521502134_item	2602144	et	3	main
said	doc_491521502134_item	2602147	et	4	main
moodusta	doc_491521502134_item	2602151	et	4	main
lugema	doc_491521502134_item	2602171	et	4	main
loeng	doc_491521502134_item	2602172	et	3	main
vanur	doc_491521502134_item	2602179	et	3	main
6	doc_491521502134_item	2602184	et	2	main
pane	doc_491521502134_item	2602185	et	4	main
vormi	doc_491521502134_item	2602190	et	4	main
kas	doc_491521502134_item	2602191	et	3	main
said	doc_491521502134_item	2602192	et	4	main
aru	doc_491521502134_item	2602196	et	4	main
ära	doc_491521502134_item	2602197	et	4	main
teiste	doc_491521502134_item	2602199	et	4	main
uute	doc_491521502134_item	2602206	et	3	main
tingimused	doc_491521502134_item	2602209	et	3	main
sööki	doc_491521502134_item	2602212	et	4	main
söök	doc_491521502134_item	2602213	et	3	main
ma	doc_491521502134_item	2602214	et	3	main
tema	doc_491521502134_item	2602216	et	4	main
vastuse	doc_491521502134_item	2602217	et	3	main
õigsust	doc_491521502134_item	2602218	et	3	main
õigsus	doc_491521502134_item	2602219	et	3	main
see	doc_491521502134_item	2602224	et	3	main
võistlus	doc_491521502134_item	2602228	et	3	main
ainult	doc_491521502134_item	2602233	et	4	main
välismaalane	doc_491521502134_item	2602240	et	3	main
spordist	doc_491521502134_item	2602245	et	3	main
lühenda	doc_491521502134_item	2602248	et	4	main
kasu	doc_491521502133_item	2601861	et	4	main
militaalvajadused	doc_491521502133_item	2601865	et	4	main
metallitööstus	doc_491521502133_item	2601868	et	3	main
puuvalmistamine	doc_491521502133_item	2601876	et	3	main
oli	doc_491521502133_item	2601878	et	3	main
ehitus	doc_491521502133_item	2601885	et	4	main
dolomiidi	doc_491521502133_item	2601906	et	3	main
kruus	doc_491521502133_item	2601908	et	3	main
tort	doc_491521502133_item	2601910	et	3	main
rühmituse	doc_491521502133_item	2601912	et	4	main
olemus	doc_491521502133_item	2601914	et	3	main
ja	doc_491521502133_item	2601915	et	3	main
parenemist	doc_491521502133_item	2601932	et	4	main
noored	doc_491521502133_item	2601944	et	3	main
noormehed	doc_491521502133_item	2601946	et	3	main
säilitada	doc_491521502133_item	2601953	et	3	main
individuaalsust	doc_491521502133_item	2601956	et	4	main
iseseisvust	doc_491521502133_item	2601957	et	4	main
kes	doc_491521502133_item	2601963	et	4	main
sõpru	doc_491521502134_item	2601983	et	3	main
tunnakse	doc_491521502134_item	2601984	et	4	main
eile	doc_491521502134_item	2601987	et	3	main
ära	doc_491521502134_item	2601992	et	4	main
kaasa	doc_491521502134_item	2601998	et	4	main
eelmisel	doc_491521502134_item	2602009	et	3	main
kirjuta	doc_491521502134_item	2602030	et	4	main
sõnale	doc_491521502134_item	2602031	et	3	main
vastavalt	doc_491521502134_item	2602032	et	4	main
lennata	doc_491521502134_item	2602041	et	4	main
lendama	doc_491521502134_item	2602042	et	3	main
ootan	doc_491521502134_item	2602043	et	3	main
oodata	doc_491521502134_item	2602044	et	4	main
õpin	doc_491521502134_item	2602051	et	3	main
lehed	doc_491521502134_item	2602055	et	3	main
poisid	doc_491521502134_item	2602057	et	4	main
poiste	doc_491521502134_item	2602058	et	3	main
3	doc_491521502134_item	2602059	et	2	main
kiire	doc_491521502134_item	2602066	et	4	main
ilus	doc_491521502134_item	2602075	et	4	main
ilusamini	doc_491521502134_item	2602077	et	4	main
aeglaselt	doc_491521502134_item	2602079	et	4	main
rõõmus	doc_491521502134_item	2602084	et	4	main
halvasti	doc_491521502134_item	2602088	et	3	main
vihasemini	doc_491521502134_item	2602095	et	4	main
soojalt	doc_491521502134_item	2602097	et	4	main
täida	doc_491521502134_item	2602100	et	4	main
õigete	doc_491521502134_item	2602102	et	3	main
läksime	doc_491521502134_item	2602104	et	3	main
mängis	doc_491521502133_item	2601922	et	3	main
rolli	doc_491521502133_item	2601924	et	4	main
sest	doc_491521502133_item	2601925	et	4	main
see	doc_491521502133_item	2601926	et	3	main
rühmitus	doc_491521502133_item	2601927	et	4	main
soodustas	doc_491521502133_item	2601928	et	3	main
gaidid	doc_491521502133_item	2601939	et	3	main
uurisid	doc_491521502133_item	2601947	et	4	main
traditsioone	doc_491521502133_item	2601950	et	3	main
eesti	doc_491521502133_item	2601954	et	4	main
noored	doc_491521502133_item	2601961	et	3	main
kirjanikud	doc_491521502133_item	2601962	et	3	main
kirjutasid	doc_491521502133_item	2601964	et	4	main
uuest	doc_491521502133_item	2601965	et	3	main
eesti	doc_491521502133_item	2601966	et	4	main
vabariigist	doc_491521502133_item	2601967	et	3	main
nendest	doc_491521502133_item	2601968	et	4	main
sai	doc_491521502133_item	2601969	et	4	main
pärast	doc_491521502133_item	2601970	et	4	main
siuru	doc_491521502133_item	2601971	et	4	main
ühing	doc_491521502133_item	2601972	et	3	main
eksamitöö	doc_491521502134_item	2601973	et	4	main
eksamitöö	doc_491521502134_item	2601974	et	4	main
1	doc_491521502134_item	2601975	et	2	main
kotkad	doc_491521502133_item	2601945	et	3	main
kuidas	doc_491521502133_item	2601952	et	3	main
rühmitusse	doc_491521502133_item	2601959	et	4	main
kauplused	doc_491521502134_item	2601978	et	3	main
avama	doc_491521502134_item	2601980	et	3	main
10	doc_491521502134_item	2601982	et	2	main
hädas	doc_491521502134_item	2601986	et	3	main
on	doc_491521502134_item	2601988	et	4	main
kooli	doc_491521502134_item	2601997	et	4	main
käskitakse	doc_491521502134_item	2602000	et	4	main
õppida	doc_491521502134_item	2602003	et	3	main
ollakse	doc_491521502134_item	2602005	et	3	main
õigel	doc_491521502134_item	2602007	et	3	main
ajal	doc_491521502134_item	2602008	et	4	main
kogu	doc_491521502134_item	2602024	et	4	main
ära	doc_491521502134_item	2602028	et	4	main
2	doc_491521502134_item	2602029	et	2	main
kappi	doc_491521502134_item	2602039	et	4	main
võrdlen	doc_491521502134_item	2602046	et	3	main
rääkima	doc_491521502134_item	2602047	et	3	main
räägitud	doc_491521502134_item	2602048	et	4	main
kukkuma	doc_491521502134_item	2602049	et	3	main
nende	doc_491521502134_item	2602063	et	4	main
keskvõrre	doc_491521502134_item	2602064	et	4	main
nt	doc_491521502134_item	2602065	et	4	main
kurb	doc_491521502134_item	2602069	et	3	main
kurvalt	doc_491521502134_item	2602070	et	4	main
parem	doc_491521502134_item	2602082	et	4	main
rõõmsalt	doc_491521502134_item	2602085	et	4	main
aus	doc_491521502134_item	2602090	et	4	main
soe	doc_491521502134_item	2602096	et	4	main
trepist	doc_491521502134_item	2602105	et	3	main
õpib	doc_491521502134_item	2602122	et	3	main
juba	doc_491521502134_item	2602124	et	3	main
minu	doc_491521502134_item	2602134	et	3	main
uudis	doc_491521502134_item	2602135	et	3	main
võõras	doc_491521502134_item	2602136	et	4	main
ei	doc_491521502134_item	2602141	et	4	main
kas	doc_491521502134_item	2602145	et	3	main
laulmine	doc_491521502134_item	2602165	et	4	main
süda	doc_491521502134_item	2602166	et	3	main
südamlik	doc_491521502134_item	2602167	et	3	main
tulema	doc_491521502134_item	2602168	et	4	main
tulek	doc_491521502134_item	2602169	et	3	main
tulemus	doc_491521502134_item	2602170	et	3	main
õppimine	doc_491521502134_item	2602176	et	4	main
olevad	doc_491521502134_item	2602187	et	4	main
jutust	doc_491521502134_item	2602194	et	3	main
naera	doc_491521502134_item	2602198	et	4	main
tingimustega	doc_491521502134_item	2602207	et	3	main
kasuta	doc_491521502134_item	2601976	et	4	main
passiivi	doc_491521502134_item	2601977	et	4	main
avatakse	doc_491521502134_item	2601979	et	4	main
kl	doc_491521502134_item	2601981	et	4	main
tundma	doc_491521502134_item	2601985	et	3	main
jätma	doc_491521502134_item	2601990	et	3	main
tunnid	doc_491521502134_item	2601991	et	3	main
kõik	doc_491521502134_item	2601993	et	4	main
raamatud	doc_491521502134_item	2601994	et	4	main
võetakse	doc_491521502134_item	2601995	et	3	main
võtma	doc_491521502134_item	2601996	et	3	main
lapsel	doc_491521502134_item	2601999	et	4	main
käskima	doc_491521502134_item	2602001	et	4	main
kohal	doc_491521502134_item	2602004	et	4	main
olema	doc_491521502134_item	2602006	et	4	main
maja	doc_491521502134_item	2602014	et	4	main
kallilt	doc_491521502134_item	2602017	et	4	main
kinos	doc_491521502134_item	2602018	et	3	main
kas	doc_491521502134_item	2602033	et	3	main
tugeva	doc_491521502134_item	2602034	et	4	main
kukun	doc_491521502134_item	2602050	et	3	main
tuba	doc_491521502134_item	2602053	et	4	main
kiiremini	doc_491521502134_item	2602068	et	4	main
4	doc_491521502134_item	2602099	et	2	main
lüngad	doc_491521502134_item	2602101	et	3	main
jalutasime	doc_491521502134_item	2602107	et	3	main
liiga	doc_491521502134_item	2602129	et	4	main
ja	doc_491521502134_item	2602140	et	3	main
sa	doc_491521502134_item	2602146	et	3	main
5	doc_491521502134_item	2602150	et	2	main
antud	doc_491521502134_item	2602152	et	4	main
sõnadest	doc_491521502134_item	2602153	et	3	main
suvi	doc_491521502134_item	2602177	et	3	main
mõtlik	doc_491521502134_item	2602182	et	3	main
mõtlemine	doc_491521502134_item	2602183	et	4	main
õigesse	doc_491521502134_item	2602189	et	3	main
jutt	doc_491521502134_item	2602195	et	3	main
õnnetustest	doc_491521502134_item	2602200	et	4	main
õnnetused	doc_491521502134_item	2602201	et	4	main
on	doc_491521502134_item	2602203	et	4	main
laps	doc_491521502134_item	2602210	et	4	main
sa	doc_491521502134_item	2602221	et	3	main
võtta	doc_491521502134_item	2602230	et	3	main
üks	doc_491521502134_item	2602236	et	3	main
sa	doc_491521502134_item	2602242	et	3	main
huvi	doc_491521502134_item	2602244	et	4	main
vaata	doc_491521502134_item	2602252	et	4	main
lhk	doc_491521502134_item	2602267	et	4	main
passiivi	doc_491521502135_item	2602274	et	4	main
avama	doc_491521502135_item	2602277	et	3	main
10	doc_491521502135_item	2602279	et	2	main
sõpru	doc_491521502135_item	2602280	et	3	main
tuntakse	doc_491521502135_item	2602281	et	3	main
tundma	doc_491521502135_item	2602282	et	3	main
hädas	doc_491521502135_item	2602283	et	3	main
eile	doc_491521502135_item	2602284	et	3	main
jäetud	doc_491521502135_item	2602285	et	4	main
jätma	doc_491521502135_item	2602286	et	3	main
tunnid	doc_491521502135_item	2602287	et	3	main
ära	doc_491521502135_item	2602288	et	4	main
kohal	doc_491521502135_item	2602300	et	4	main
ollakse	doc_491521502135_item	2602301	et	3	main
ei	doc_491521502135_item	2602316	et	4	main
tihti	doc_491521502135_item	2602320	et	3	main
kogu	doc_491521502135_item	2602321	et	4	main
sõnale	doc_491521502135_item	2602328	et	3	main
tugeva	doc_491521502135_item	2602331	et	4	main
või	doc_491521502135_item	2602332	et	4	main
nõrga	doc_491521502135_item	2602333	et	3	main
astme	doc_491521502135_item	2602334	et	3	main
vorm	doc_491521502135_item	2602335	et	3	main
kappi	doc_491521502135_item	2602336	et	4	main
kapp	doc_491521502135_item	2602337	et	3	main
võrrelda	doc_491521502135_item	2602342	et	4	main
3	doc_491521502135_item	2602356	et	2	main
ja	doc_491521502135_item	2602359	et	3	main
kurb	doc_491521502135_item	2602366	et	3	main
aeglaselt	doc_491521502135_item	2602376	et	4	main
rõõmsasti	doc_491521502135_item	2602382	et	3	main
halb	doc_491521502135_item	2602384	et	3	main
ausasti	doc_491521502135_item	2602388	et	3	main
vihane	doc_491521502135_item	2602390	et	4	main
väga	doc_491521502134_item	2602022	et	3	main
kapi	doc_491521502134_item	2602040	et	4	main
toa	doc_491521502134_item	2602054	et	3	main
lehte	doc_491521502134_item	2602056	et	4	main
moodusta	doc_491521502134_item	2602060	et	4	main
määrsõnad	doc_491521502134_item	2602061	et	4	main
ja	doc_491521502134_item	2602062	et	3	main
kiiresti	doc_491521502134_item	2602067	et	3	main
kurvamalt	doc_491521502134_item	2602071	et	4	main
julge	doc_491521502134_item	2602072	et	4	main
julgesti	doc_491521502134_item	2602073	et	3	main
julgemini	doc_491521502134_item	2602074	et	4	main
paremini	doc_491521502134_item	2602083	et	4	main
halb	doc_491521502134_item	2602087	et	3	main
vihaselt	doc_491521502134_item	2602094	et	4	main
soojamalt	doc_491521502134_item	2602098	et	3	main
määrsõnadega	doc_491521502134_item	2602103	et	4	main
alla	doc_491521502134_item	2602106	et	3	main
pargi	doc_491521502134_item	2602109	et	4	main
auto	doc_491521502134_item	2602110	et	4	main
läbi	doc_491521502134_item	2602108	et	4	main
sõitis	doc_491521502134_item	2602111	et	3	main
üle	doc_491521502134_item	2602112	et	3	main
silla	doc_491521502134_item	2602113	et	3	main
tule	doc_491521502134_item	2602114	et	4	main
peale	doc_491521502134_item	2602115	et	4	main
lõunat	doc_491521502134_item	2602116	et	3	main
tagasi	doc_491521502134_item	2602117	et	3	main
sõidame	doc_491521502134_item	2602118	et	3	main
mere	doc_491521502134_item	2602119	et	3	main
äärde	doc_491521502134_item	2602120	et	4	main
ta	doc_491521502134_item	2602121	et	4	main
saadik	doc_491521502134_item	2602126	et	4	main
kohvis	doc_491521502134_item	2602127	et	3	main
on	doc_491521502134_item	2602128	et	4	main
ukse	doc_491521502134_item	2602138	et	3	main
taga	doc_491521502134_item	2602139	et	4	main
kätte	doc_491521502134_item	2602149	et	4	main
sulgudes	doc_491521502134_item	2602186	et	4	main
tema	doc_491521502134_item	2602193	et	4	main
kohaneda	doc_491521502134_item	2602204	et	3	main
keeldus	doc_491521502134_item	2602211	et	3	main
osa	doc_491521502134_item	2602229	et	4	main
üht	doc_491521502134_item	2602234	et	3	main
tutvusin	doc_491521502134_item	2602238	et	3	main
kas	doc_491521502134_item	2602241	et	3	main
tunned	doc_491521502134_item	2602243	et	3	main
7	doc_491521502134_item	2602247	et	2	main
ja	doc_491521502134_item	2602249	et	3	main
nii	doc_491521502134_item	2602250	et	3	main
kasuta	doc_491521502135_item	2602273	et	4	main
avatakse	doc_491521502135_item	2602276	et	4	main
kõik	doc_491521502135_item	2602289	et	4	main
raamatud	doc_491521502135_item	2602290	et	4	main
kaasa	doc_491521502135_item	2602294	et	4	main
käskitakse	doc_491521502135_item	2602296	et	4	main
käskima	doc_491521502135_item	2602297	et	4	main
hästi	doc_491521502135_item	2602298	et	3	main
õppida	doc_491521502135_item	2602299	et	3	main
maja	doc_491521502135_item	2602310	et	4	main
müüakse	doc_491521502135_item	2602312	et	3	main
kallilt	doc_491521502135_item	2602314	et	4	main
kinos	doc_491521502135_item	2602315	et	3	main
ära	doc_491521502135_item	2602325	et	4	main
lennata	doc_491521502135_item	2602338	et	4	main
lendan	doc_491521502135_item	2602339	et	3	main
ootan	doc_491521502135_item	2602340	et	3	main
rääkima	doc_491521502135_item	2602344	et	3	main
kukkuma	doc_491521502135_item	2602346	et	3	main
palju	doc_491521502134_item	2602130	et	4	main
suhkrut	doc_491521502134_item	2602131	et	3	main
see	doc_491521502134_item	2602132	et	3	main
oli	doc_491521502134_item	2602133	et	3	main
julgenud	doc_491521502134_item	2602142	et	4	main
kirja	doc_491521502134_item	2602148	et	4	main
liidete	doc_491521502134_item	2602154	et	3	main
abil	doc_491521502134_item	2602155	et	4	main
uusi	doc_491521502134_item	2602156	et	3	main
sõnu	doc_491521502134_item	2602157	et	4	main
elama	doc_491521502134_item	2602158	et	3	main
elanik	doc_491521502134_item	2602159	et	3	main
elamine	doc_491521502134_item	2602160	et	4	main
kasvama	doc_491521502134_item	2602161	et	3	main
kasvamine	doc_491521502134_item	2602162	et	4	main
laul	doc_491521502134_item	2602163	et	4	main
laulik	doc_491521502134_item	2602164	et	3	main
lugemine	doc_491521502134_item	2602173	et	4	main
õppima	doc_491521502134_item	2602174	et	3	main
õpik	doc_491521502134_item	2602175	et	3	main
vana	doc_491521502134_item	2602178	et	4	main
vanus	doc_491521502134_item	2602180	et	4	main
mõte	doc_491521502134_item	2602181	et	3	main
sõnad	doc_491521502134_item	2602188	et	4	main
raske	doc_491521502134_item	2602202	et	4	main
kiiresti	doc_491521502134_item	2602205	et	3	main
uued	doc_491521502134_item	2602208	et	3	main
kahtlen	doc_491521502134_item	2602215	et	3	main
kas	doc_491521502134_item	2602220	et	3	main
oled	doc_491521502134_item	2602222	et	3	main
sellest	doc_491521502134_item	2602223	et	4	main
kindel	doc_491521502134_item	2602225	et	3	main
võistlusel	doc_491521502134_item	2602227	et	3	main
oskan	doc_491521502134_item	2602232	et	3	main
võõrkeel	doc_491521502134_item	2602237	et	4	main
a	doc_491521502134_item	2602263	et	4	main
preili	doc_491521502134_item	2602264	et	4	main
prl	doc_491521502134_item	2602265	et	4	main
lehekülg	doc_491521502134_item	2602266	et	3	main
h	doc_491521502134_item	2602269	et	4	main
eksamitöö	doc_491521502135_item	2602271	et	4	main
kauplused	doc_491521502135_item	2602275	et	3	main
kl	doc_491521502135_item	2602278	et	4	main
võetakse	doc_491521502135_item	2602291	et	3	main
olema	doc_491521502135_item	2602302	et	4	main
õigel	doc_491521502135_item	2602303	et	3	main
käima	doc_491521502135_item	2602318	et	4	main
toit	doc_491521502135_item	2602322	et	3	main
söödud	doc_491521502135_item	2602323	et	4	main
sööma	doc_491521502135_item	2602324	et	4	main
kirjuta	doc_491521502135_item	2602327	et	4	main
tuba	doc_491521502135_item	2602350	et	4	main
lehed	doc_491521502135_item	2602352	et	3	main
poiss	doc_491521502135_item	2602355	et	3	main
kurvasti	doc_491521502135_item	2602367	et	4	main
aeglasemalt	doc_491521502135_item	2602377	et	4	main
rõõmus	doc_491521502135_item	2602381	et	4	main
rõõmsamini	doc_491521502135_item	2602383	et	4	main
halvasti	doc_491521502135_item	2602385	et	3	main
ausamini	doc_491521502135_item	2602389	et	4	main
soe	doc_491521502135_item	2602393	et	4	main
lt	doc_491521502135_item	2602395	et	4	main
see	doc_491521502135_item	2602432	et	3	main
uudis	doc_491521502135_item	2602436	et	3	main
seisis	doc_491521502135_item	2602438	et	4	main
ukse	doc_491521502135_item	2602439	et	3	main
taga	doc_491521502135_item	2602440	et	4	main
ja	doc_491521502135_item	2602441	et	3	main
ei	doc_491521502135_item	2602442	et	4	main
5	doc_491521502135_item	2602452	et	2	main
antud	doc_491521502135_item	2602454	et	4	main
sõnu	doc_491521502135_item	2602459	et	4	main
elama	doc_491521502135_item	2602460	et	3	main
kasvus	doc_491521502135_item	2602467	et	3	main
tuletamine	doc_491521502135_item	2602478	et	4	main
lugeja	doc_491521502135_item	2602480	et	4	main
õppetool	doc_491521502135_item	2602485	et	3	main
suvila	doc_491521502135_item	2602490	et	4	main
vanur	doc_491521502135_item	2602494	et	3	main
on	doc_491521502135_item	2602521	et	4	main
kiiresti	doc_491521502135_item	2602523	et	3	main
tingimustega	doc_491521502135_item	2602525	et	3	main
söök	doc_491521502135_item	2602531	et	3	main
tema	doc_491521502135_item	2602534	et	4	main
vastuse	doc_491521502135_item	2602535	et	3	main
õigusest	doc_491521502135_item	2602536	et	4	main
sa	doc_491521502135_item	2602539	et	3	main
seda	doc_491521502135_item	2602541	et	3	main
võtta	doc_491521502135_item	2602548	et	3	main
ainult	doc_491521502135_item	2602551	et	4	main
tunned	doc_491521502135_item	2602561	et	3	main
7	doc_491521502135_item	2602565	et	2	main
ja	doc_491521502135_item	2602567	et	3	main
nii	doc_491521502135_item	2602568	et	3	main
e	doc_491521502135_item	2602576	et	4	main
preili	doc_491521502135_item	2602584	et	4	main
eksamitöö	doc_491521502136_item	2602590	et	4	main
tahan	doc_491521502134_item	2602226	et	3	main
ma	doc_491521502134_item	2602231	et	3	main
võõrkeelt	doc_491521502134_item	2602235	et	4	main
välismaalasega	doc_491521502134_item	2602239	et	3	main
sport	doc_491521502134_item	2602246	et	3	main
edasi	doc_491521502134_item	2602251	et	3	main
v	doc_491521502134_item	2602253	et	4	main
võrdle	doc_491521502134_item	2602254	et	4	main
vrd	doc_491521502134_item	2602255	et	4	main
ehk	doc_491521502134_item	2602256	et	3	main
proua	doc_491521502134_item	2602258	et	4	main
e	doc_491521502134_item	2602257	et	4	main
pr	doc_491521502134_item	2602259	et	4	main
see	doc_491521502134_item	2602260	et	3	main
tähendab	doc_491521502134_item	2602261	et	3	main
aasta	doc_491521502134_item	2602262	et	4	main
härra	doc_491521502134_item	2602268	et	4	main
eksamitöö	doc_491521502135_item	2602270	et	4	main
1	doc_491521502135_item	2602272	et	2	main
kooli	doc_491521502135_item	2602293	et	4	main
ajal	doc_491521502135_item	2602304	et	4	main
eelmisel	doc_491521502135_item	2602305	et	3	main
aastal	doc_491521502135_item	2602306	et	3	main
vahetati	doc_491521502135_item	2602307	et	4	main
vahetama	doc_491521502135_item	2602308	et	3	main
müüma	doc_491521502135_item	2602313	et	3	main
vastavalt	doc_491521502135_item	2602329	et	4	main
võrdlema	doc_491521502135_item	2602343	et	3	main
räägin	doc_491521502135_item	2602345	et	3	main
kukuda	doc_491521502135_item	2602347	et	4	main
õppida	doc_491521502135_item	2602349	et	3	main
moodusta	doc_491521502135_item	2602357	et	4	main
nende	doc_491521502135_item	2602360	et	4	main
nt	doc_491521502135_item	2602362	et	4	main
julgesti	doc_491521502135_item	2602370	et	3	main
ilus	doc_491521502135_item	2602372	et	4	main
ilusasti	doc_491521502135_item	2602373	et	3	main
ilusamini	doc_491521502135_item	2602374	et	4	main
aeglane	doc_491521502135_item	2602375	et	3	main
paremini	doc_491521502135_item	2602380	et	4	main
halvemini	doc_491521502135_item	2602386	et	4	main
vihasemalt	doc_491521502135_item	2602392	et	4	main
siin	doc_491521502135_item	2602423	et	4	main
kohvis	doc_491521502135_item	2602427	et	3	main
oli	doc_491521502135_item	2602433	et	3	main
sisse	doc_491521502135_item	2602444	et	4	main
tulla	doc_491521502135_item	2602445	et	3	main
kas	doc_491521502135_item	2602446	et	3	main
sa	doc_491521502135_item	2602447	et	3	main
kirja	doc_491521502135_item	2602449	et	4	main
juba	doc_491521502135_item	2602450	et	3	main
südaöö	doc_491521502135_item	2602475	et	4	main
tulema	doc_491521502135_item	2602476	et	4	main
tuletõrju	doc_491521502135_item	2602477	et	4	main
õppimine	doc_491521502135_item	2602484	et	4	main
suvelik	doc_491521502135_item	2602491	et	4	main
laps	doc_491521502135_item	2602528	et	4	main
keeldus	doc_491521502135_item	2602529	et	3	main
ma	doc_491521502135_item	2602532	et	3	main
tahan	doc_491521502135_item	2602544	et	3	main
kas	doc_491521502135_item	2602559	et	3	main
aasta	doc_491521502135_item	2602582	et	4	main
härra	doc_491521502135_item	2602588	et	4	main
passiivi	doc_491521502136_item	2602594	et	4	main
kauplused	doc_491521502136_item	2602595	et	3	main
olema	doc_491521502136_item	2602622	et	4	main
õigel	doc_491521502136_item	2602623	et	3	main
eelmisel	doc_491521502136_item	2602625	et	3	main
töökohta	doc_491521502136_item	2602629	et	4	main
müüakse	doc_491521502136_item	2602631	et	3	main
ära	doc_491521502136_item	2602645	et	4	main
tugev	doc_491521502136_item	2602656	et	4	main
võrrelda	doc_491521502136_item	2602667	et	4	main
võrdlema	doc_491521502136_item	2602668	et	3	main
tugev	doc_491521502136_item	2602669	et	4	main
rääkima	doc_491521502136_item	2602670	et	3	main
õpin	doc_491521502136_item	2602676	et	3	main
tugev	doc_491521502136_item	2602678	et	4	main
toa	doc_491521502136_item	2602680	et	3	main
määrsõnad	doc_491521502136_item	2602689	et	4	main
nende	doc_491521502136_item	2602691	et	4	main
julgesti	doc_491521502136_item	2602702	et	3	main
hästi	doc_491521502136_item	2602710	et	3	main
parem	doc_491521502136_item	2602711	et	4	main
vihane	doc_491521502136_item	2602721	et	4	main
pargi	doc_491521502136_item	2602737	et	4	main
on	doc_491521502136_item	2602756	et	4	main
võõras	doc_491521502136_item	2602765	et	4	main
seisis	doc_491521502136_item	2602766	et	4	main
ukse	doc_491521502136_item	2602767	et	3	main
kasvamine	doc_491521502136_item	2602793	et	4	main
laulja	doc_491521502136_item	2602795	et	4	main
laulmine	doc_491521502136_item	2602796	et	4	main
lugeja	doc_491521502136_item	2602806	et	4	main
õppima	doc_491521502136_item	2602807	et	3	main
võtma	doc_491521502135_item	2602292	et	3	main
lapsel	doc_491521502135_item	2602295	et	4	main
töökohta	doc_491521502135_item	2602309	et	4	main
müüdi	doc_491521502135_item	2602311	et	4	main
käidud	doc_491521502135_item	2602317	et	4	main
väga	doc_491521502135_item	2602319	et	3	main
2	doc_491521502135_item	2602326	et	2	main
kas	doc_491521502135_item	2602330	et	3	main
oodata	doc_491521502135_item	2602341	et	4	main
tupa	doc_491521502135_item	2602351	et	4	main
lehte	doc_491521502135_item	2602353	et	4	main
poisid	doc_491521502135_item	2602354	et	4	main
keskvõrre	doc_491521502135_item	2602361	et	4	main
kiire	doc_491521502135_item	2602363	et	4	main
kiiresti	doc_491521502135_item	2602364	et	3	main
kurvemini	doc_491521502135_item	2602368	et	4	main
hea	doc_491521502135_item	2602378	et	4	main
hästi	doc_491521502135_item	2602379	et	3	main
sti	doc_491521502135_item	2602396	et	4	main
soojamalt	doc_491521502135_item	2602397	et	3	main
mini	doc_491521502135_item	2602398	et	4	main
4	doc_491521502135_item	2602399	et	2	main
täida	doc_491521502135_item	2602400	et	4	main
lüngad	doc_491521502135_item	2602401	et	3	main
õigete	doc_491521502135_item	2602402	et	3	main
määrsõnadega	doc_491521502135_item	2602403	et	4	main
läksime	doc_491521502135_item	2602404	et	3	main
trepist	doc_491521502135_item	2602405	et	3	main
alla	doc_491521502135_item	2602406	et	3	main
jalutasime	doc_491521502135_item	2602407	et	3	main
ümber	doc_491521502135_item	2602408	et	3	main
pargi	doc_491521502135_item	2602409	et	4	main
auto	doc_491521502135_item	2602410	et	4	main
sõitis	doc_491521502135_item	2602411	et	3	main
mööda	doc_491521502135_item	2602412	et	4	main
silla	doc_491521502135_item	2602413	et	3	main
tule	doc_491521502135_item	2602414	et	4	main
pärast	doc_491521502135_item	2602415	et	4	main
lõunat	doc_491521502135_item	2602416	et	3	main
tagasi	doc_491521502135_item	2602417	et	3	main
sõidame	doc_491521502135_item	2602418	et	3	main
mere	doc_491521502135_item	2602419	et	3	main
äärde	doc_491521502135_item	2602420	et	4	main
palju	doc_491521502135_item	2602430	et	4	main
suhkrut	doc_491521502135_item	2602431	et	3	main
jaoks	doc_491521502135_item	2602435	et	4	main
võõras	doc_491521502135_item	2602437	et	4	main
elamine	doc_491521502135_item	2602461	et	4	main
elanik	doc_491521502135_item	2602462	et	3	main
elatis	doc_491521502135_item	2602463	et	3	main
kasvama	doc_491521502135_item	2602464	et	3	main
kasvatamine	doc_491521502135_item	2602465	et	4	main
laul	doc_491521502135_item	2602468	et	4	main
õpija	doc_491521502135_item	2602483	et	4	main
uute	doc_491521502135_item	2602524	et	3	main
tingimused	doc_491521502135_item	2602527	et	3	main
sööki	doc_491521502135_item	2602530	et	4	main
õigsus	doc_491521502135_item	2602537	et	3	main
kas	doc_491521502135_item	2602538	et	3	main
see	doc_491521502135_item	2602542	et	3	main
oskan	doc_491521502135_item	2602550	et	3	main
võõrkeelt	doc_491521502135_item	2602553	et	4	main
üks	doc_491521502135_item	2602554	et	3	main
õpin	doc_491521502135_item	2602348	et	3	main
määrsõnad	doc_491521502135_item	2602358	et	4	main
kiiremini	doc_491521502135_item	2602365	et	4	main
julge	doc_491521502135_item	2602369	et	4	main
julgemini	doc_491521502135_item	2602371	et	4	main
aus	doc_491521502135_item	2602387	et	4	main
vihaselt	doc_491521502135_item	2602391	et	4	main
sooja	doc_491521502135_item	2602394	et	4	main
ta	doc_491521502135_item	2602421	et	4	main
õpib	doc_491521502135_item	2602422	et	3	main
juba	doc_491521502135_item	2602424	et	3	main
septembrist	doc_491521502135_item	2602425	et	3	main
on	doc_491521502135_item	2602428	et	4	main
liiga	doc_491521502135_item	2602429	et	4	main
said	doc_491521502135_item	2602448	et	4	main
moodusta	doc_491521502135_item	2602453	et	4	main
sõnadest	doc_491521502135_item	2602455	et	3	main
liidete	doc_491521502135_item	2602456	et	3	main
abil	doc_491521502135_item	2602457	et	4	main
uusi	doc_491521502135_item	2602458	et	3	main
laulja	doc_491521502135_item	2602469	et	4	main
laulmine	doc_491521502135_item	2602470	et	4	main
lauljatar	doc_491521502135_item	2602471	et	3	main
süda	doc_491521502135_item	2602472	et	3	main
südamik	doc_491521502135_item	2602473	et	3	main
südalinn	doc_491521502135_item	2602474	et	3	main
lugema	doc_491521502135_item	2602479	et	4	main
lugemine	doc_491521502135_item	2602481	et	4	main
õppima	doc_491521502135_item	2602482	et	3	main
õppekava	doc_491521502135_item	2602486	et	4	main
õpilane	doc_491521502135_item	2602487	et	3	main
suvi	doc_491521502135_item	2602488	et	3	main
suvitaja	doc_491521502135_item	2602489	et	4	main
vanadus	doc_491521502135_item	2602493	et	4	main
mõte	doc_491521502135_item	2602495	et	3	main
mõtleja	doc_491521502135_item	2602496	et	4	main
mõtteviis	doc_491521502135_item	2602497	et	3	main
mõttelik	doc_491521502135_item	2602499	et	4	main
6	doc_491521502135_item	2602500	et	2	main
pane	doc_491521502135_item	2602501	et	4	main
mõtlemine	doc_491521502135_item	2602498	et	4	main
sulgudes	doc_491521502135_item	2602502	et	4	main
olevad	doc_491521502135_item	2602503	et	4	main
sõnad	doc_491521502135_item	2602504	et	4	main
õigesse	doc_491521502135_item	2602505	et	3	main
kas	doc_491521502135_item	2602507	et	3	main
said	doc_491521502135_item	2602508	et	4	main
vormi	doc_491521502135_item	2602506	et	4	main
tema	doc_491521502135_item	2602509	et	4	main
jutust	doc_491521502135_item	2602510	et	3	main
jutt	doc_491521502135_item	2602511	et	3	main
aru	doc_491521502135_item	2602512	et	4	main
ära	doc_491521502135_item	2602513	et	4	main
naera	doc_491521502135_item	2602514	et	4	main
teiste	doc_491521502135_item	2602515	et	4	main
õnnetustele	doc_491521502135_item	2602516	et	4	main
õnnetuste	doc_491521502135_item	2602517	et	4	main
peale	doc_491521502135_item	2602518	et	4	main
õnnetused	doc_491521502135_item	2602519	et	4	main
raske	doc_491521502135_item	2602520	et	4	main
kahtlen	doc_491521502135_item	2602533	et	3	main
oled	doc_491521502135_item	2602540	et	3	main
võistluse	doc_491521502135_item	2602545	et	3	main
osa	doc_491521502135_item	2602547	et	4	main
ma	doc_491521502135_item	2602549	et	3	main
alates	doc_491521502135_item	2602426	et	3	main
minu	doc_491521502135_item	2602434	et	3	main
julgenud	doc_491521502135_item	2602443	et	4	main
nüüd	doc_491521502135_item	2602451	et	4	main
kasvataja	doc_491521502135_item	2602466	et	4	main
vana	doc_491521502135_item	2602492	et	4	main
kohaneda	doc_491521502135_item	2602522	et	3	main
uued	doc_491521502135_item	2602526	et	3	main
kindel	doc_491521502135_item	2602543	et	3	main
võistlus	doc_491521502135_item	2602546	et	3	main
sa	doc_491521502135_item	2602560	et	3	main
edasi	doc_491521502135_item	2602569	et	3	main
vaata	doc_491521502135_item	2602571	et	4	main
proua	doc_491521502135_item	2602577	et	4	main
prl	doc_491521502135_item	2602585	et	4	main
lehekülg	doc_491521502135_item	2602586	et	3	main
eksamitöö	doc_491521502136_item	2602591	et	4	main
1	doc_491521502136_item	2602592	et	2	main
avama	doc_491521502136_item	2602597	et	3	main
kl	doc_491521502136_item	2602598	et	4	main
10	doc_491521502136_item	2602599	et	2	main
sõpru	doc_491521502136_item	2602600	et	3	main
tunnakse	doc_491521502136_item	2602601	et	4	main
tundma	doc_491521502136_item	2602602	et	3	main
hädas	doc_491521502136_item	2602603	et	3	main
eile	doc_491521502136_item	2602604	et	3	main
jäti	doc_491521502136_item	2602605	et	3	main
jätma	doc_491521502136_item	2602606	et	3	main
tunnid	doc_491521502136_item	2602607	et	3	main
ära	doc_491521502136_item	2602608	et	4	main
kõik	doc_491521502136_item	2602609	et	4	main
raamatud	doc_491521502136_item	2602610	et	4	main
võetakse	doc_491521502136_item	2602611	et	3	main
võtma	doc_491521502136_item	2602612	et	3	main
kooli	doc_491521502136_item	2602613	et	4	main
kaasa	doc_491521502136_item	2602614	et	4	main
lapsel	doc_491521502136_item	2602615	et	4	main
käskitakse	doc_491521502136_item	2602616	et	4	main
käskima	doc_491521502136_item	2602617	et	4	main
hästi	doc_491521502136_item	2602618	et	3	main
õppida	doc_491521502136_item	2602619	et	3	main
kohal	doc_491521502136_item	2602620	et	4	main
üht	doc_491521502135_item	2602552	et	3	main
huvi	doc_491521502135_item	2602562	et	4	main
sport	doc_491521502135_item	2602564	et	3	main
võrdle	doc_491521502135_item	2602573	et	4	main
vd	doc_491521502135_item	2602574	et	4	main
ehk	doc_491521502135_item	2602575	et	3	main
a	doc_491521502135_item	2602583	et	4	main
hr	doc_491521502135_item	2602589	et	4	main
avatakse	doc_491521502136_item	2602596	et	4	main
ollakse	doc_491521502136_item	2602621	et	3	main
vahetama	doc_491521502136_item	2602628	et	3	main
maja	doc_491521502136_item	2602630	et	4	main
kallilt	doc_491521502136_item	2602633	et	4	main
kinos	doc_491521502136_item	2602634	et	3	main
ei	doc_491521502136_item	2602635	et	4	main
süüakse	doc_491521502136_item	2602642	et	3	main
kappi	doc_491521502136_item	2602657	et	4	main
nõrga	doc_491521502136_item	2602660	et	3	main
nõrga	doc_491521502136_item	2602675	et	3	main
õppima	doc_491521502136_item	2602677	et	3	main
nõrga	doc_491521502136_item	2602681	et	3	main
lehed	doc_491521502136_item	2602682	et	3	main
leht	doc_491521502136_item	2602683	et	3	main
nõrga	doc_491521502136_item	2602684	et	3	main
poisid	doc_491521502136_item	2602685	et	4	main
poiss	doc_491521502136_item	2602686	et	3	main
3	doc_491521502136_item	2602687	et	2	main
nt	doc_491521502136_item	2602693	et	4	main
kiiremini	doc_491521502136_item	2602696	et	4	main
kurb	doc_491521502136_item	2602697	et	3	main
kurvalt	doc_491521502136_item	2602698	et	4	main
ilus	doc_491521502136_item	2602703	et	4	main
ilusasti	doc_491521502136_item	2602704	et	3	main
ilusamini	doc_491521502136_item	2602705	et	4	main
aeglane	doc_491521502136_item	2602706	et	3	main
rõõmus	doc_491521502136_item	2602712	et	4	main
halvasti	doc_491521502136_item	2602716	et	3	main
aus	doc_491521502136_item	2602718	et	4	main
ausalt	doc_491521502136_item	2602719	et	4	main
sõitis	doc_491521502136_item	2602739	et	3	main
enne	doc_491521502136_item	2602743	et	4	main
mere	doc_491521502136_item	2602747	et	3	main
palju	doc_491521502136_item	2602758	et	4	main
see	doc_491521502136_item	2602760	et	3	main
minu	doc_491521502136_item	2602762	et	3	main
uudis	doc_491521502136_item	2602764	et	3	main
sisse	doc_491521502136_item	2602772	et	4	main
ebasüdamlik	doc_491521502136_item	2602800	et	3	main
tulema	doc_491521502136_item	2602801	et	4	main
tulevik	doc_491521502136_item	2602802	et	3	main
tulemus	doc_491521502136_item	2602803	et	3	main
vormi	doc_491521502136_item	2602826	et	4	main
kas	doc_491521502136_item	2602827	et	3	main
juttust	doc_491521502136_item	2602830	et	3	main
õnnetused	doc_491521502136_item	2602837	et	4	main
ma	doc_491521502136_item	2602850	et	3	main
tema	doc_491521502136_item	2602852	et	4	main
sa	doc_491521502136_item	2602857	et	3	main
oled	doc_491521502136_item	2602858	et	3	main
tahan	doc_491521502136_item	2602862	et	3	main
oskan	doc_491521502136_item	2602868	et	3	main
ainult	doc_491521502136_item	2602869	et	4	main
aasta	doc_491521502136_item	2602901	et	4	main
prl	doc_491521502136_item	2602904	et	4	main
hr	doc_491521502136_item	2602908	et	4	main
hädas	doc_491521502137_item	2602922	et	3	main
jäeti	doc_491521502137_item	2602924	et	3	main
võetakse	doc_491521502137_item	2602930	et	3	main
olema	doc_491521502137_item	2602941	et	4	main
õigel	doc_491521502137_item	2602942	et	3	main
maja	doc_491521502137_item	2602949	et	4	main
müüma	doc_491521502137_item	2602951	et	3	main
kinos	doc_491521502137_item	2602953	et	3	main
ei	doc_491521502137_item	2602954	et	4	main
käima	doc_491521502137_item	2602956	et	4	main
väga	doc_491521502137_item	2602957	et	3	main
tihti	doc_491521502137_item	2602958	et	3	main
kogu	doc_491521502137_item	2602959	et	4	main
toit	doc_491521502137_item	2602960	et	3	main
söödi	doc_491521502137_item	2602961	et	4	main
sõnale	doc_491521502137_item	2602966	et	3	main
tugeva	doc_491521502137_item	2602969	et	4	main
võõrkeel	doc_491521502135_item	2602555	et	4	main
tutvusin	doc_491521502135_item	2602556	et	3	main
välismaalasega	doc_491521502135_item	2602557	et	3	main
välismaalane	doc_491521502135_item	2602558	et	3	main
sporti	doc_491521502135_item	2602563	et	4	main
lühenda	doc_491521502135_item	2602566	et	4	main
jne	doc_491521502135_item	2602570	et	4	main
vt	doc_491521502135_item	2602572	et	4	main
pr	doc_491521502135_item	2602578	et	4	main
see	doc_491521502135_item	2602579	et	3	main
tähendab	doc_491521502135_item	2602580	et	3	main
st	doc_491521502135_item	2602581	et	3	main
lk	doc_491521502135_item	2602587	et	4	main
kasuta	doc_491521502136_item	2602593	et	4	main
aastal	doc_491521502136_item	2602626	et	3	main
käima	doc_491521502136_item	2602637	et	4	main
väga	doc_491521502136_item	2602638	et	3	main
tihti	doc_491521502136_item	2602639	et	3	main
toit	doc_491521502136_item	2602641	et	3	main
sööma	doc_491521502136_item	2602644	et	4	main
nõrga	doc_491521502136_item	2602653	et	3	main
astme	doc_491521502136_item	2602654	et	3	main
vorm	doc_491521502136_item	2602655	et	3	main
tugev	doc_491521502136_item	2602666	et	4	main
kukun	doc_491521502136_item	2602674	et	3	main
kiire	doc_491521502136_item	2602694	et	4	main
kiiresti	doc_491521502136_item	2602695	et	3	main
kurvamalt	doc_491521502136_item	2602699	et	4	main
aeglaselt	doc_491521502136_item	2602707	et	4	main
ausamalt	doc_491521502136_item	2602720	et	4	main
ajal	doc_491521502136_item	2602624	et	4	main
käia	doc_491521502136_item	2602636	et	4	main
sööti	doc_491521502136_item	2602643	et	4	main
vahetati	doc_491521502136_item	2602627	et	4	main
müüma	doc_491521502136_item	2602632	et	3	main
kogu	doc_491521502136_item	2602640	et	4	main
tugeva	doc_491521502136_item	2602651	et	4	main
või	doc_491521502136_item	2602652	et	4	main
oodata	doc_491521502136_item	2602665	et	4	main
kukkuma	doc_491521502136_item	2602673	et	3	main
moodusta	doc_491521502136_item	2602688	et	4	main
keskvõrre	doc_491521502136_item	2602692	et	4	main
julgelt	doc_491521502136_item	2602701	et	4	main
hea	doc_491521502136_item	2602709	et	4	main
rõõmsalt	doc_491521502136_item	2602713	et	4	main
vihasemalt	doc_491521502136_item	2602723	et	4	main
soojalt	doc_491521502136_item	2602725	et	4	main
4	doc_491521502136_item	2602727	et	2	main
täida	doc_491521502136_item	2602728	et	4	main
lüngad	doc_491521502136_item	2602729	et	3	main
auto	doc_491521502136_item	2602738	et	4	main
tule	doc_491521502136_item	2602742	et	4	main
äärde	doc_491521502136_item	2602748	et	4	main
ta	doc_491521502136_item	2602749	et	4	main
õpib	doc_491521502136_item	2602750	et	3	main
liiga	doc_491521502136_item	2602757	et	4	main
suhkrut	doc_491521502136_item	2602759	et	3	main
oli	doc_491521502136_item	2602761	et	3	main
oma	doc_491521502136_item	2602763	et	4	main
julgenud	doc_491521502136_item	2602771	et	4	main
täiskasvanud	doc_491521502136_item	2602792	et	4	main
lugema	doc_491521502136_item	2602804	et	4	main
suvi	doc_491521502136_item	2602810	et	3	main
suvemaja	doc_491521502136_item	2602812	et	4	main
vanemad	doc_491521502136_item	2602814	et	4	main
vanaema	doc_491521502136_item	2602815	et	4	main
mõte	doc_491521502136_item	2602816	et	3	main
mõtlema	doc_491521502136_item	2602817	et	3	main
mõtleja	doc_491521502136_item	2602818	et	4	main
sulgudes	doc_491521502136_item	2602822	et	4	main
tema	doc_491521502136_item	2602829	et	4	main
aru	doc_491521502136_item	2602832	et	4	main
naera	doc_491521502136_item	2602834	et	4	main
teiste	doc_491521502136_item	2602835	et	4	main
söök	doc_491521502136_item	2602849	et	3	main
võtta	doc_491521502136_item	2602866	et	3	main
üht	doc_491521502136_item	2602870	et	3	main
pr	doc_491521502136_item	2602897	et	4	main
härra	doc_491521502136_item	2602907	et	4	main
eksamitöö	doc_491521502137_item	2602910	et	4	main
passiivi	doc_491521502137_item	2602913	et	4	main
kauplused	doc_491521502137_item	2602914	et	3	main
avatakse	doc_491521502137_item	2602915	et	4	main
avama	doc_491521502137_item	2602916	et	3	main
kl	doc_491521502137_item	2602917	et	4	main
10	doc_491521502137_item	2602918	et	2	main
sõpru	doc_491521502137_item	2602919	et	3	main
tuntakse	doc_491521502137_item	2602920	et	3	main
tundma	doc_491521502137_item	2602921	et	3	main
jätma	doc_491521502137_item	2602925	et	3	main
kõik	doc_491521502137_item	2602928	et	4	main
lapsel	doc_491521502137_item	2602934	et	4	main
müüdi	doc_491521502137_item	2602950	et	4	main
kallilt	doc_491521502137_item	2602952	et	4	main
kas	doc_491521502137_item	2602968	et	3	main
lennata	doc_491521502137_item	2602976	et	4	main
lendama	doc_491521502137_item	2602977	et	3	main
ootan	doc_491521502137_item	2602978	et	3	main
oodata	doc_491521502137_item	2602979	et	4	main
tuba	doc_491521502137_item	2602988	et	4	main
lehed	doc_491521502137_item	2602990	et	3	main
poisid	doc_491521502137_item	2602992	et	4	main
poissi	doc_491521502137_item	2602993	et	4	main
3	doc_491521502137_item	2602994	et	2	main
halb	doc_491521502137_item	2603022	et	3	main
vihaselt	doc_491521502137_item	2603029	et	4	main
vihasemalt	doc_491521502137_item	2603030	et	4	main
4	doc_491521502137_item	2603034	et	2	main
lüngad	doc_491521502137_item	2603036	et	3	main
määrsõnadega	doc_491521502137_item	2603038	et	4	main
üles	doc_491521502137_item	2603041	et	3	main
läbi	doc_491521502137_item	2603043	et	4	main
pargi	doc_491521502137_item	2603044	et	4	main
lõunat	doc_491521502137_item	2603051	et	3	main
septembrist	doc_491521502137_item	2603060	et	3	main
2	doc_491521502136_item	2602646	et	2	main
kirjuta	doc_491521502136_item	2602647	et	4	main
sõnale	doc_491521502136_item	2602648	et	3	main
vastavalt	doc_491521502136_item	2602649	et	4	main
kas	doc_491521502136_item	2602650	et	3	main
kapi	doc_491521502136_item	2602658	et	4	main
g	doc_491521502136_item	2602659	et	4	main
lennata	doc_491521502136_item	2602661	et	4	main
lendma	doc_491521502136_item	2602662	et	4	main
tugev	doc_491521502136_item	2602663	et	4	main
ootan	doc_491521502136_item	2602664	et	3	main
räägin	doc_491521502136_item	2602671	et	3	main
tugev	doc_491521502136_item	2602672	et	4	main
tuba	doc_491521502136_item	2602679	et	4	main
ja	doc_491521502136_item	2602690	et	3	main
julge	doc_491521502136_item	2602700	et	4	main
aeglasemalt	doc_491521502136_item	2602708	et	4	main
rõõmsamalt	doc_491521502136_item	2602714	et	4	main
halb	doc_491521502136_item	2602715	et	3	main
halvemini	doc_491521502136_item	2602717	et	4	main
vihaselt	doc_491521502136_item	2602722	et	4	main
soojemalt	doc_491521502136_item	2602726	et	3	main
silla	doc_491521502136_item	2602741	et	3	main
lõunat	doc_491521502136_item	2602744	et	3	main
tagasi	doc_491521502136_item	2602745	et	3	main
sõidame	doc_491521502136_item	2602746	et	3	main
kohvis	doc_491521502136_item	2602755	et	3	main
ei	doc_491521502136_item	2602770	et	4	main
laul	doc_491521502136_item	2602794	et	4	main
lugemine	doc_491521502136_item	2602805	et	4	main
suvelik	doc_491521502136_item	2602811	et	4	main
mõtlemine	doc_491521502136_item	2602819	et	4	main
soe	doc_491521502136_item	2602724	et	4	main
õigete	doc_491521502136_item	2602730	et	3	main
määrsõnadega	doc_491521502136_item	2602731	et	4	main
läksime	doc_491521502136_item	2602732	et	3	main
trepist	doc_491521502136_item	2602733	et	3	main
alla	doc_491521502136_item	2602734	et	3	main
jalutasime	doc_491521502136_item	2602735	et	3	main
läbi	doc_491521502136_item	2602736	et	4	main
üle	doc_491521502136_item	2602740	et	3	main
siin	doc_491521502136_item	2602751	et	4	main
juba	doc_491521502136_item	2602752	et	3	main
septembrist	doc_491521502136_item	2602753	et	3	main
edasi	doc_491521502136_item	2602754	et	3	main
taga	doc_491521502136_item	2602768	et	4	main
ja	doc_491521502136_item	2602769	et	3	main
tulla	doc_491521502136_item	2602773	et	3	main
kas	doc_491521502136_item	2602774	et	3	main
sa	doc_491521502136_item	2602775	et	3	main
said	doc_491521502136_item	2602776	et	4	main
kirja	doc_491521502136_item	2602777	et	4	main
kätte	doc_491521502136_item	2602778	et	4	main
moodusta	doc_491521502136_item	2602780	et	4	main
5	doc_491521502136_item	2602779	et	2	main
antud	doc_491521502136_item	2602781	et	4	main
sõnadest	doc_491521502136_item	2602782	et	3	main
liidete	doc_491521502136_item	2602783	et	3	main
abil	doc_491521502136_item	2602784	et	4	main
uusi	doc_491521502136_item	2602785	et	3	main
sõnu	doc_491521502136_item	2602786	et	4	main
elama	doc_491521502136_item	2602787	et	3	main
elu	doc_491521502136_item	2602788	et	4	main
elav	doc_491521502136_item	2602789	et	4	main
elamus	doc_491521502136_item	2602790	et	4	main
kasvama	doc_491521502136_item	2602791	et	3	main
laul	doc_491521502136_item	2602797	et	4	main
süda	doc_491521502136_item	2602798	et	3	main
südamlik	doc_491521502136_item	2602799	et	3	main
õpik	doc_491521502136_item	2602809	et	3	main
vana	doc_491521502136_item	2602813	et	4	main
6	doc_491521502136_item	2602820	et	2	main
pane	doc_491521502136_item	2602821	et	4	main
olevad	doc_491521502136_item	2602823	et	4	main
sõnad	doc_491521502136_item	2602824	et	4	main
õigesse	doc_491521502136_item	2602825	et	3	main
ära	doc_491521502136_item	2602833	et	4	main
raske	doc_491521502136_item	2602838	et	4	main
on	doc_491521502136_item	2602839	et	4	main
kohaneda	doc_491521502136_item	2602840	et	3	main
kiiresti	doc_491521502136_item	2602841	et	3	main
uute	doc_491521502136_item	2602842	et	3	main
tingimustega	doc_491521502136_item	2602843	et	3	main
uued	doc_491521502136_item	2602844	et	3	main
tingimused	doc_491521502136_item	2602845	et	3	main
laps	doc_491521502136_item	2602846	et	4	main
kas	doc_491521502136_item	2602856	et	3	main
see	doc_491521502136_item	2602860	et	3	main
võistluses	doc_491521502136_item	2602863	et	3	main
osa	doc_491521502136_item	2602865	et	4	main
preili	doc_491521502136_item	2602903	et	4	main
kasuta	doc_491521502137_item	2602912	et	4	main
eile	doc_491521502137_item	2602923	et	3	main
ära	doc_491521502137_item	2602927	et	4	main
võtma	doc_491521502137_item	2602931	et	3	main
käskima	doc_491521502137_item	2602936	et	4	main
hästi	doc_491521502137_item	2602937	et	3	main
õppida	doc_491521502137_item	2602938	et	3	main
kohal	doc_491521502137_item	2602939	et	4	main
ollakse	doc_491521502137_item	2602940	et	3	main
töökohta	doc_491521502137_item	2602948	et	4	main
sööma	doc_491521502137_item	2602962	et	4	main
ära	doc_491521502137_item	2602963	et	4	main
vastavalt	doc_491521502137_item	2602967	et	4	main
või	doc_491521502137_item	2602970	et	4	main
kappi	doc_491521502137_item	2602974	et	4	main
kapi	doc_491521502137_item	2602975	et	4	main
räägin	doc_491521502137_item	2602983	et	3	main
moodusta	doc_491521502137_item	2602995	et	4	main
keskvõrre	doc_491521502137_item	2602999	et	4	main
ausamalt	doc_491521502137_item	2603027	et	4	main
auto	doc_491521502137_item	2603045	et	4	main
sõitis	doc_491521502137_item	2603046	et	3	main
üle	doc_491521502137_item	2603047	et	3	main
silla	doc_491521502137_item	2603048	et	3	main
tagasi	doc_491521502137_item	2603052	et	3	main
mere	doc_491521502137_item	2603054	et	3	main
kohvis	doc_491521502137_item	2603062	et	3	main
liiga	doc_491521502137_item	2603064	et	4	main
palju	doc_491521502137_item	2603065	et	4	main
suhkrut	doc_491521502137_item	2603066	et	3	main
see	doc_491521502137_item	2603067	et	3	main
oli	doc_491521502137_item	2603068	et	3	main
minu	doc_491521502137_item	2603069	et	3	main
jaoks	doc_491521502137_item	2603070	et	4	main
uudis	doc_491521502137_item	2603071	et	3	main
ja	doc_491521502137_item	2603076	et	3	main
julgenud	doc_491521502137_item	2603078	et	4	main
lugema	doc_491521502137_item	2603116	et	4	main
lugemine	doc_491521502137_item	2603119	et	4	main
õpilas	doc_491521502137_item	2603123	et	4	main
pane	doc_491521502137_item	2603138	et	4	main
tema	doc_491521502137_item	2603146	et	4	main
aru	doc_491521502137_item	2603149	et	4	main
naera	doc_491521502137_item	2603151	et	4	main
teiste	doc_491521502137_item	2603152	et	4	main
kohaneda	doc_491521502137_item	2603158	et	3	main
kiiresti	doc_491521502137_item	2603159	et	3	main
uute	doc_491521502137_item	2603160	et	3	main
tingimustega	doc_491521502137_item	2603161	et	3	main
ma	doc_491521502137_item	2603168	et	3	main
kahtlen	doc_491521502137_item	2603169	et	3	main
osa	doc_491521502137_item	2603183	et	4	main
hr	doc_491521502137_item	2603226	et	4	main
eksamitöö	doc_491521502138_item	2603227	et	4	main
passiivi	doc_491521502138_item	2603231	et	4	main
avama	doc_491521502138_item	2603234	et	3	main
jäeti	doc_491521502138_item	2603242	et	3	main
õpilane	doc_491521502136_item	2602808	et	3	main
jutt	doc_491521502136_item	2602831	et	3	main
söögi	doc_491521502136_item	2602848	et	4	main
õigsuses	doc_491521502136_item	2602854	et	3	main
õigsus	doc_491521502136_item	2602855	et	3	main
sellest	doc_491521502136_item	2602859	et	4	main
kindel	doc_491521502136_item	2602861	et	3	main
võistlus	doc_491521502136_item	2602864	et	3	main
a	doc_491521502136_item	2602902	et	4	main
lehekülg	doc_491521502136_item	2602905	et	3	main
lk	doc_491521502136_item	2602906	et	4	main
eksamitöö	doc_491521502137_item	2602909	et	4	main
1	doc_491521502137_item	2602911	et	2	main
raamatud	doc_491521502137_item	2602929	et	4	main
ajal	doc_491521502137_item	2602943	et	4	main
eelmisel	doc_491521502137_item	2602944	et	3	main
aastal	doc_491521502137_item	2602945	et	3	main
vahetati	doc_491521502137_item	2602946	et	4	main
vahetama	doc_491521502137_item	2602947	et	3	main
kirjuta	doc_491521502137_item	2602965	et	4	main
kukun	doc_491521502137_item	2602985	et	3	main
õppima	doc_491521502137_item	2602987	et	3	main
said	doc_491521502136_item	2602828	et	4	main
õnnetuste	doc_491521502136_item	2602836	et	4	main
keeldus	doc_491521502136_item	2602847	et	3	main
kahtlen	doc_491521502136_item	2602851	et	3	main
vastuse	doc_491521502136_item	2602853	et	3	main
ma	doc_491521502136_item	2602867	et	3	main
võõrkeelt	doc_491521502136_item	2602871	et	4	main
üks	doc_491521502136_item	2602872	et	3	main
võõrkeel	doc_491521502136_item	2602873	et	4	main
tutvusin	doc_491521502136_item	2602874	et	3	main
välismaalasega	doc_491521502136_item	2602875	et	3	main
välismaalane	doc_491521502136_item	2602876	et	3	main
kas	doc_491521502136_item	2602877	et	3	main
sa	doc_491521502136_item	2602878	et	3	main
tunned	doc_491521502136_item	2602879	et	3	main
huvi	doc_491521502136_item	2602880	et	4	main
spordi	doc_491521502136_item	2602881	et	4	main
vastus	doc_491521502136_item	2602882	et	3	main
sport	doc_491521502136_item	2602883	et	3	main
7	doc_491521502136_item	2602884	et	2	main
lühenda	doc_491521502136_item	2602885	et	4	main
ja	doc_491521502136_item	2602886	et	3	main
nii	doc_491521502136_item	2602887	et	3	main
edasi	doc_491521502136_item	2602888	et	3	main
jne	doc_491521502136_item	2602889	et	4	main
vaata	doc_491521502136_item	2602890	et	4	main
v	doc_491521502136_item	2602891	et	4	main
võrdle	doc_491521502136_item	2602892	et	4	main
vr	doc_491521502136_item	2602893	et	4	main
ehk	doc_491521502136_item	2602894	et	3	main
e	doc_491521502136_item	2602895	et	4	main
proua	doc_491521502136_item	2602896	et	4	main
see	doc_491521502136_item	2602898	et	3	main
tähendab	doc_491521502136_item	2602899	et	3	main
st	doc_491521502136_item	2602900	et	3	main
tunnid	doc_491521502137_item	2602926	et	3	main
kooli	doc_491521502137_item	2602932	et	4	main
kaasa	doc_491521502137_item	2602933	et	4	main
kästi	doc_491521502137_item	2602935	et	3	main
käida	doc_491521502137_item	2602955	et	3	main
2	doc_491521502137_item	2602964	et	2	main
kukkuma	doc_491521502137_item	2602984	et	3	main
toa	doc_491521502137_item	2602989	et	3	main
lehte	doc_491521502137_item	2602991	et	4	main
nende	doc_491521502137_item	2602998	et	4	main
nt	doc_491521502137_item	2603000	et	4	main
kiire	doc_491521502137_item	2603001	et	4	main
kiiremini	doc_491521502137_item	2603003	et	4	main
kurb	doc_491521502137_item	2603004	et	3	main
kiiresti	doc_491521502137_item	2603002	et	3	main
kurvalt	doc_491521502137_item	2603005	et	4	main
kurvamalt	doc_491521502137_item	2603006	et	4	main
julge	doc_491521502137_item	2603007	et	4	main
julgesti	doc_491521502137_item	2603008	et	3	main
julgemini	doc_491521502137_item	2603009	et	4	main
ilus	doc_491521502137_item	2603010	et	4	main
ilusalt	doc_491521502137_item	2603011	et	4	main
ilusamalt	doc_491521502137_item	2603012	et	4	main
aeglane	doc_491521502137_item	2603013	et	3	main
aeglaselt	doc_491521502137_item	2603014	et	4	main
aeglasemalt	doc_491521502137_item	2603015	et	4	main
hea	doc_491521502137_item	2603016	et	4	main
hästi	doc_491521502137_item	2603017	et	3	main
paremini	doc_491521502137_item	2603018	et	4	main
rõõmus	doc_491521502137_item	2603019	et	4	main
rõõmsalt	doc_491521502137_item	2603020	et	4	main
halvasti	doc_491521502137_item	2603023	et	3	main
halvemini	doc_491521502137_item	2603024	et	4	main
soojemalt	doc_491521502137_item	2603033	et	3	main
õigete	doc_491521502137_item	2603037	et	3	main
läksime	doc_491521502137_item	2603039	et	3	main
jalutasime	doc_491521502137_item	2603042	et	3	main
sõidame	doc_491521502137_item	2603053	et	3	main
äärde	doc_491521502137_item	2603055	et	4	main
õpib	doc_491521502137_item	2603057	et	3	main
siin	doc_491521502137_item	2603058	et	4	main
juba	doc_491521502137_item	2603059	et	3	main
taga	doc_491521502137_item	2603075	et	4	main
ei	doc_491521502137_item	2603077	et	4	main
sisse	doc_491521502137_item	2603079	et	4	main
tulla	doc_491521502137_item	2603080	et	3	main
õppima	doc_491521502137_item	2603121	et	3	main
õpik	doc_491521502137_item	2603124	et	3	main
õppimatus	doc_491521502137_item	2603126	et	4	main
suvine	doc_491521502137_item	2603129	et	4	main
suvitaja	doc_491521502137_item	2603130	et	4	main
vana	doc_491521502137_item	2603131	et	4	main
mõtetu	doc_491521502137_item	2603134	et	4	main
mõtlik	doc_491521502137_item	2603136	et	3	main
sulgudes	doc_491521502137_item	2603139	et	4	main
said	doc_491521502137_item	2603145	et	4	main
õnnetuste	doc_491521502137_item	2603153	et	4	main
üle	doc_491521502137_item	2603154	et	3	main
tingimused	doc_491521502137_item	2603163	et	3	main
õigsuses	doc_491521502137_item	2603172	et	3	main
nõrga	doc_491521502137_item	2602971	et	3	main
astme	doc_491521502137_item	2602972	et	3	main
vorm	doc_491521502137_item	2602973	et	3	main
võrrelda	doc_491521502137_item	2602980	et	4	main
võrdlen	doc_491521502137_item	2602981	et	3	main
rääkima	doc_491521502137_item	2602982	et	3	main
õpin	doc_491521502137_item	2602986	et	3	main
määrsõnad	doc_491521502137_item	2602996	et	4	main
ja	doc_491521502137_item	2602997	et	3	main
rõõmsamalt	doc_491521502137_item	2603021	et	4	main
vihane	doc_491521502137_item	2603028	et	4	main
soojalt	doc_491521502137_item	2603032	et	4	main
trepist	doc_491521502137_item	2603040	et	3	main
pärast	doc_491521502137_item	2603050	et	4	main
ukse	doc_491521502137_item	2603074	et	3	main
tulemus	doc_491521502137_item	2603115	et	3	main
lugeja	doc_491521502137_item	2603118	et	4	main
aus	doc_491521502137_item	2603025	et	4	main
ausalt	doc_491521502137_item	2603026	et	4	main
soe	doc_491521502137_item	2603031	et	4	main
täida	doc_491521502137_item	2603035	et	4	main
tule	doc_491521502137_item	2603049	et	4	main
ta	doc_491521502137_item	2603056	et	4	main
peale	doc_491521502137_item	2603061	et	4	main
on	doc_491521502137_item	2603063	et	4	main
seisis	doc_491521502137_item	2603073	et	4	main
kas	doc_491521502137_item	2603081	et	3	main
sa	doc_491521502137_item	2603082	et	3	main
said	doc_491521502137_item	2603083	et	4	main
kirja	doc_491521502137_item	2603084	et	4	main
kätte	doc_491521502137_item	2603085	et	4	main
5	doc_491521502137_item	2603086	et	2	main
moodusta	doc_491521502137_item	2603087	et	4	main
antud	doc_491521502137_item	2603088	et	4	main
sõnadest	doc_491521502137_item	2603089	et	3	main
liidete	doc_491521502137_item	2603090	et	3	main
abil	doc_491521502137_item	2603091	et	4	main
uusi	doc_491521502137_item	2603092	et	3	main
sõnu	doc_491521502137_item	2603093	et	4	main
elama	doc_491521502137_item	2603094	et	3	main
elaja	doc_491521502137_item	2603095	et	4	main
elanik	doc_491521502137_item	2603096	et	3	main
elamine	doc_491521502137_item	2603097	et	4	main
elamu	doc_491521502137_item	2603098	et	4	main
kasvama	doc_491521502137_item	2603099	et	3	main
kasvaja	doc_491521502137_item	2603100	et	4	main
kasvatus	doc_491521502137_item	2603101	et	4	main
kasvamine	doc_491521502137_item	2603102	et	4	main
laul	doc_491521502137_item	2603103	et	4	main
laulik	doc_491521502137_item	2603104	et	3	main
laulja	doc_491521502137_item	2603105	et	4	main
süda	doc_491521502137_item	2603106	et	3	main
südamlik	doc_491521502137_item	2603107	et	3	main
südametu	doc_491521502137_item	2603108	et	4	main
südametus	doc_491521502137_item	2603109	et	4	main
tulema	doc_491521502137_item	2603110	et	4	main
tulija	doc_491521502137_item	2603111	et	4	main
tulemine	doc_491521502137_item	2603112	et	4	main
tulnukas	doc_491521502137_item	2603113	et	4	main
võõras	doc_491521502137_item	2603072	et	4	main
tulek	doc_491521502137_item	2603114	et	3	main
lugemik	doc_491521502137_item	2603117	et	3	main
õpija	doc_491521502137_item	2603122	et	4	main
vormi	doc_491521502137_item	2603143	et	4	main
ära	doc_491521502137_item	2603150	et	4	main
raske	doc_491521502137_item	2603156	et	4	main
on	doc_491521502137_item	2603157	et	4	main
uued	doc_491521502137_item	2603162	et	3	main
keeldus	doc_491521502137_item	2603165	et	3	main
söök	doc_491521502137_item	2603167	et	3	main
tema	doc_491521502137_item	2603170	et	4	main
tahan	doc_491521502137_item	2603180	et	3	main
võistlus	doc_491521502137_item	2603182	et	3	main
preili	doc_491521502137_item	2603221	et	4	main
eksamitöö	doc_491521502138_item	2603228	et	4	main
1	doc_491521502138_item	2603229	et	2	main
10	doc_491521502138_item	2603236	et	2	main
tundma	doc_491521502138_item	2603239	et	3	main
eile	doc_491521502138_item	2603241	et	3	main
lapsel	doc_491521502138_item	2603252	et	4	main
kästakse	doc_491521502138_item	2603253	et	3	main
vahetati	doc_491521502138_item	2603264	et	4	main
vahetama	doc_491521502138_item	2603265	et	3	main
käima	doc_491521502138_item	2603274	et	4	main
süüakse	doc_491521502138_item	2603279	et	3	main
2	doc_491521502138_item	2603282	et	2	main
kirjuta	doc_491521502138_item	2603283	et	4	main
sõnale	doc_491521502138_item	2603284	et	3	main
kukun	doc_491521502138_item	2603303	et	3	main
kurb	doc_491521502138_item	2603322	et	3	main
ilus	doc_491521502138_item	2603328	et	4	main
rõõmsalt	doc_491521502138_item	2603338	et	4	main
rõõmsamalt	doc_491521502138_item	2603339	et	4	main
halb	doc_491521502138_item	2603340	et	3	main
vihane	doc_491521502138_item	2603346	et	4	main
õigete	doc_491521502138_item	2603355	et	3	main
trepist	doc_491521502138_item	2603358	et	3	main
läbi	doc_491521502138_item	2603361	et	4	main
auto	doc_491521502138_item	2603363	et	4	main
sõitis	doc_491521502138_item	2603364	et	3	main
üle	doc_491521502138_item	2603365	et	3	main
see	doc_491521502138_item	2603385	et	3	main
parim	doc_491521502138_item	2603388	et	4	main
uudis	doc_491521502138_item	2603389	et	3	main
julgenud	doc_491521502138_item	2603396	et	4	main
said	doc_491521502138_item	2603401	et	4	main
kätte	doc_491521502138_item	2603403	et	4	main
antud	doc_491521502138_item	2603406	et	4	main
sõnadest	doc_491521502138_item	2603407	et	3	main
liidete	doc_491521502138_item	2603408	et	3	main
elaja	doc_491521502138_item	2603415	et	4	main
kasv	doc_491521502138_item	2603420	et	3	main
laul	doc_491521502138_item	2603424	et	4	main
laulja	doc_491521502138_item	2603426	et	4	main
laulev	doc_491521502138_item	2603428	et	4	main
laulmine	doc_491521502138_item	2603429	et	4	main
süda	doc_491521502138_item	2603430	et	3	main
südametu	doc_491521502138_item	2603431	et	4	main
südamlik	doc_491521502138_item	2603432	et	3	main
lugeja	doc_491521502138_item	2603438	et	4	main
õppetaja	doc_491521502138_item	2603445	et	4	main
mõte	doc_491521502138_item	2603453	et	3	main
mõtetu	doc_491521502138_item	2603454	et	4	main
vormi	doc_491521502138_item	2603463	et	4	main
jutt	doc_491521502138_item	2603468	et	3	main
õnnetustele	doc_491521502138_item	2603473	et	4	main
õnnetused	doc_491521502138_item	2603474	et	4	main
tingimused	doc_491521502138_item	2603482	et	3	main
söögist	doc_491521502138_item	2603485	et	4	main
ma	doc_491521502138_item	2603487	et	3	main
ma	doc_491521502138_item	2603505	et	3	main
lugematus	doc_491521502137_item	2603120	et	4	main
suvi	doc_491521502137_item	2603127	et	3	main
vanus	doc_491521502137_item	2603132	et	4	main
mõttekas	doc_491521502137_item	2603135	et	4	main
6	doc_491521502137_item	2603137	et	2	main
olevad	doc_491521502137_item	2603140	et	4	main
sõnad	doc_491521502137_item	2603141	et	4	main
õigesse	doc_491521502137_item	2603142	et	3	main
jutust	doc_491521502137_item	2603147	et	3	main
laps	doc_491521502137_item	2603164	et	4	main
söögist	doc_491521502137_item	2603166	et	4	main
õigsus	doc_491521502137_item	2603173	et	3	main
sa	doc_491521502137_item	2603175	et	3	main
kindel	doc_491521502137_item	2603179	et	3	main
võistlusest	doc_491521502137_item	2603181	et	4	main
ma	doc_491521502137_item	2603185	et	3	main
kl	doc_491521502138_item	2603235	et	4	main
käskima	doc_491521502138_item	2603254	et	4	main
hästi	doc_491521502138_item	2603255	et	3	main
õppida	doc_491521502138_item	2603256	et	3	main
müüakse	doc_491521502138_item	2603268	et	3	main
kallilt	doc_491521502138_item	2603270	et	4	main
toit	doc_491521502138_item	2603278	et	3	main
ära	doc_491521502138_item	2603281	et	4	main
või	doc_491521502138_item	2603288	et	4	main
nõrga	doc_491521502138_item	2603289	et	3	main
astme	doc_491521502138_item	2603290	et	3	main
vorm	doc_491521502138_item	2603291	et	3	main
kappi	doc_491521502138_item	2603292	et	4	main
ootan	doc_491521502138_item	2603296	et	3	main
oodata	doc_491521502138_item	2603297	et	4	main
võrrelda	doc_491521502138_item	2603298	et	4	main
võrdlen	doc_491521502138_item	2603299	et	3	main
rääkima	doc_491521502138_item	2603300	et	3	main
räägin	doc_491521502138_item	2603301	et	3	main
kukkuma	doc_491521502138_item	2603302	et	3	main
õppimine	doc_491521502137_item	2603125	et	4	main
suvila	doc_491521502137_item	2603128	et	4	main
mõte	doc_491521502137_item	2603133	et	3	main
kas	doc_491521502137_item	2603144	et	3	main
jutt	doc_491521502137_item	2603148	et	3	main
õnnetused	doc_491521502137_item	2603155	et	4	main
vastuse	doc_491521502137_item	2603171	et	3	main
kas	doc_491521502137_item	2603174	et	3	main
oled	doc_491521502137_item	2603176	et	3	main
see	doc_491521502137_item	2603178	et	3	main
oskan	doc_491521502137_item	2603186	et	3	main
ainult	doc_491521502137_item	2603187	et	4	main
üht	doc_491521502137_item	2603188	et	3	main
võõrkeelt	doc_491521502137_item	2603189	et	4	main
üks	doc_491521502137_item	2603190	et	3	main
võõrkeel	doc_491521502137_item	2603191	et	4	main
tutvusin	doc_491521502137_item	2603192	et	3	main
välismaalasega	doc_491521502137_item	2603193	et	3	main
välismaalane	doc_491521502137_item	2603194	et	3	main
kas	doc_491521502137_item	2603195	et	3	main
sa	doc_491521502137_item	2603196	et	3	main
tunned	doc_491521502137_item	2603197	et	3	main
huvi	doc_491521502137_item	2603198	et	4	main
spordi	doc_491521502137_item	2603199	et	4	main
vastu	doc_491521502137_item	2603200	et	3	main
sport	doc_491521502137_item	2603201	et	3	main
7	doc_491521502137_item	2603202	et	2	main
lühenda	doc_491521502137_item	2603203	et	4	main
ja	doc_491521502137_item	2603204	et	3	main
nii	doc_491521502137_item	2603205	et	3	main
edasi	doc_491521502137_item	2603206	et	3	main
jne	doc_491521502137_item	2603207	et	4	main
vaata	doc_491521502137_item	2603208	et	4	main
vt	doc_491521502137_item	2603209	et	4	main
võrdle	doc_491521502137_item	2603210	et	4	main
vrd	doc_491521502137_item	2603211	et	4	main
ehk	doc_491521502137_item	2603212	et	3	main
e	doc_491521502137_item	2603213	et	4	main
proua	doc_491521502137_item	2603214	et	4	main
pr	doc_491521502137_item	2603215	et	4	main
see	doc_491521502137_item	2603216	et	3	main
tähendab	doc_491521502137_item	2603217	et	3	main
st	doc_491521502137_item	2603218	et	3	main
aasta	doc_491521502137_item	2603219	et	4	main
a	doc_491521502137_item	2603220	et	4	main
selles	doc_491521502137_item	2603177	et	4	main
võtta	doc_491521502137_item	2603184	et	3	main
prl	doc_491521502137_item	2603222	et	4	main
lehekülg	doc_491521502137_item	2603223	et	3	main
kauplused	doc_491521502138_item	2603232	et	3	main
sõpru	doc_491521502138_item	2603237	et	3	main
tundakse	doc_491521502138_item	2603238	et	4	main
hädas	doc_491521502138_item	2603240	et	3	main
jätma	doc_491521502138_item	2603243	et	3	main
tunnid	doc_491521502138_item	2603244	et	3	main
olema	doc_491521502138_item	2603259	et	4	main
müüma	doc_491521502138_item	2603269	et	3	main
kinos	doc_491521502138_item	2603271	et	3	main
ei	doc_491521502138_item	2603272	et	4	main
tihti	doc_491521502138_item	2603276	et	3	main
sööma	doc_491521502138_item	2603280	et	4	main
vastavalt	doc_491521502138_item	2603285	et	4	main
kas	doc_491521502138_item	2603286	et	3	main
lennata	doc_491521502138_item	2603294	et	4	main
kiiremini	doc_491521502138_item	2603321	et	4	main
kurvemini	doc_491521502138_item	2603324	et	4	main
julge	doc_491521502138_item	2603325	et	4	main
hea	doc_491521502138_item	2603334	et	4	main
halvasti	doc_491521502138_item	2603341	et	3	main
halvemini	doc_491521502138_item	2603342	et	4	main
lüngad	doc_491521502138_item	2603354	et	3	main
läksime	doc_491521502138_item	2603357	et	3	main
pargi	doc_491521502138_item	2603362	et	4	main
minu	doc_491521502138_item	2603387	et	3	main
võõras	doc_491521502138_item	2603390	et	4	main
sa	doc_491521502138_item	2603400	et	3	main
5	doc_491521502138_item	2603404	et	2	main
moodusta	doc_491521502138_item	2603405	et	4	main
elu	doc_491521502138_item	2603413	et	4	main
elav	doc_491521502138_item	2603414	et	4	main
kasvataja	doc_491521502138_item	2603423	et	4	main
tulema	doc_491521502138_item	2603433	et	4	main
lugemine	doc_491521502138_item	2603439	et	4	main
õppima	doc_491521502138_item	2603441	et	3	main
suvine	doc_491521502138_item	2603448	et	4	main
mõtlemine	doc_491521502138_item	2603456	et	4	main
naera	doc_491521502138_item	2603471	et	4	main
on	doc_491521502138_item	2603476	et	4	main
kohaneda	doc_491521502138_item	2603477	et	3	main
kiiresti	doc_491521502138_item	2603478	et	3	main
uute	doc_491521502138_item	2603479	et	3	main
kahtlen	doc_491521502138_item	2603488	et	3	main
õigsus	doc_491521502138_item	2603492	et	3	main
oled	doc_491521502138_item	2603495	et	3	main
kindel	doc_491521502138_item	2603499	et	3	main
võistlus	doc_491521502138_item	2603502	et	3	main
võtta	doc_491521502138_item	2603504	et	3	main
ainult	doc_491521502138_item	2603507	et	4	main
tutvusin	doc_491521502138_item	2603512	et	3	main
kas	doc_491521502138_item	2603515	et	3	main
huvi	doc_491521502138_item	2603518	et	4	main
spordi	doc_491521502138_item	2603519	et	4	main
vastu	doc_491521502138_item	2603520	et	3	main
sport	doc_491521502138_item	2603521	et	3	main
jne	doc_491521502138_item	2603527	et	4	main
proua	doc_491521502138_item	2603534	et	4	main
lehekülg	doc_491521502138_item	2603543	et	3	main
lg	doc_491521502138_item	2603544	et	4	main
härra	doc_491521502138_item	2603545	et	4	main
hrr	doc_491521502138_item	2603546	et	4	main
kauplused	doc_491521502139_item	2603552	et	3	main
10	doc_491521502139_item	2603556	et	2	main
hädas	doc_491521502139_item	2603560	et	3	main
eile	doc_491521502139_item	2603561	et	3	main
jätma	doc_491521502139_item	2603563	et	3	main
kõik	doc_491521502139_item	2603566	et	4	main
raamatud	doc_491521502139_item	2603567	et	4	main
kaasa	doc_491521502139_item	2603571	et	4	main
käskima	doc_491521502139_item	2603574	et	4	main
olema	doc_491521502139_item	2603579	et	4	main
sööma	doc_491521502139_item	2603600	et	4	main
või	doc_491521502139_item	2603608	et	4	main
vorm	doc_491521502139_item	2603611	et	3	main
nõrk	doc_491521502139_item	2603636	et	3	main
poisid	doc_491521502139_item	2603640	et	4	main
poja	doc_491521502139_item	2603641	et	4	main
3	doc_491521502139_item	2603642	et	2	main
lk	doc_491521502137_item	2603224	et	4	main
härra	doc_491521502137_item	2603225	et	4	main
kasuta	doc_491521502138_item	2603230	et	4	main
avatakse	doc_491521502138_item	2603233	et	4	main
kooli	doc_491521502138_item	2603250	et	4	main
kaasa	doc_491521502138_item	2603251	et	4	main
õigel	doc_491521502138_item	2603260	et	3	main
ajal	doc_491521502138_item	2603261	et	4	main
eelmisel	doc_491521502138_item	2603262	et	3	main
aastal	doc_491521502138_item	2603263	et	3	main
maja	doc_491521502138_item	2603267	et	4	main
käida	doc_491521502138_item	2603273	et	3	main
kapi	doc_491521502138_item	2603293	et	4	main
lendma	doc_491521502138_item	2603295	et	4	main
õpin	doc_491521502138_item	2603304	et	3	main
õppida	doc_491521502138_item	2603305	et	3	main
tuba	doc_491521502138_item	2603306	et	4	main
toa	doc_491521502138_item	2603307	et	3	main
lehed	doc_491521502138_item	2603308	et	3	main
lehte	doc_491521502138_item	2603309	et	4	main
poisid	doc_491521502138_item	2603310	et	4	main
poiss	doc_491521502138_item	2603311	et	3	main
3	doc_491521502138_item	2603312	et	2	main
moodusta	doc_491521502138_item	2603313	et	4	main
ja	doc_491521502138_item	2603315	et	3	main
nende	doc_491521502138_item	2603316	et	4	main
keskvõrre	doc_491521502138_item	2603317	et	4	main
määrsõnad	doc_491521502138_item	2603314	et	4	main
nt	doc_491521502138_item	2603318	et	4	main
kiire	doc_491521502138_item	2603319	et	4	main
kiiresti	doc_491521502138_item	2603320	et	3	main
kurvasti	doc_491521502138_item	2603323	et	4	main
ilusti	doc_491521502138_item	2603329	et	3	main
rõõmus	doc_491521502138_item	2603337	et	4	main
ausamalt	doc_491521502138_item	2603345	et	4	main
vihasemalt	doc_491521502138_item	2603348	et	4	main
soojalt	doc_491521502138_item	2603350	et	4	main
jalutasime	doc_491521502138_item	2603360	et	3	main
oli	doc_491521502138_item	2603386	et	3	main
seisis	doc_491521502138_item	2603391	et	4	main
ukse	doc_491521502138_item	2603392	et	3	main
sisse	doc_491521502138_item	2603397	et	4	main
kirja	doc_491521502138_item	2603402	et	4	main
elutu	doc_491521502138_item	2603416	et	4	main
ära	doc_491521502138_item	2603245	et	4	main
kõik	doc_491521502138_item	2603246	et	4	main
raamatud	doc_491521502138_item	2603247	et	4	main
võetakse	doc_491521502138_item	2603248	et	3	main
võtma	doc_491521502138_item	2603249	et	3	main
kohal	doc_491521502138_item	2603257	et	4	main
ollakse	doc_491521502138_item	2603258	et	3	main
töökohta	doc_491521502138_item	2603266	et	4	main
väga	doc_491521502138_item	2603275	et	3	main
kogu	doc_491521502138_item	2603277	et	4	main
tugeva	doc_491521502138_item	2603287	et	4	main
julgelt	doc_491521502138_item	2603326	et	4	main
ilusamini	doc_491521502138_item	2603330	et	4	main
aeglaselt	doc_491521502138_item	2603332	et	4	main
ausalt	doc_491521502138_item	2603344	et	4	main
soe	doc_491521502138_item	2603349	et	4	main
soojemalt	doc_491521502138_item	2603351	et	3	main
täida	doc_491521502138_item	2603353	et	4	main
määrsõnadega	doc_491521502138_item	2603356	et	4	main
taga	doc_491521502138_item	2603393	et	4	main
ja	doc_491521502138_item	2603394	et	3	main
tulla	doc_491521502138_item	2603398	et	3	main
sõnu	doc_491521502138_item	2603411	et	4	main
elamine	doc_491521502138_item	2603417	et	4	main
kasvama	doc_491521502138_item	2603418	et	3	main
kasvik	doc_491521502138_item	2603421	et	3	main
laululine	doc_491521502138_item	2603427	et	4	main
lugemistu	doc_491521502138_item	2603440	et	4	main
õppik	doc_491521502138_item	2603443	et	4	main
õppe	doc_491521502138_item	2603444	et	4	main
mõtleja	doc_491521502138_item	2603455	et	4	main
sõnad	doc_491521502138_item	2603461	et	4	main
said	doc_491521502138_item	2603465	et	4	main
jutust	doc_491521502138_item	2603467	et	3	main
aru	doc_491521502138_item	2603469	et	4	main
ära	doc_491521502138_item	2603470	et	4	main
raske	doc_491521502138_item	2603475	et	4	main
laps	doc_491521502138_item	2603483	et	4	main
keeldus	doc_491521502138_item	2603484	et	3	main
söök	doc_491521502138_item	2603486	et	3	main
tema	doc_491521502138_item	2603489	et	4	main
õigsuses	doc_491521502138_item	2603491	et	3	main
kas	doc_491521502138_item	2603493	et	3	main
selle	doc_491521502138_item	2603496	et	4	main
üle	doc_491521502138_item	2603497	et	3	main
see	doc_491521502138_item	2603498	et	3	main
oskan	doc_491521502138_item	2603506	et	3	main
üks	doc_491521502138_item	2603510	et	3	main
välismaalasega	doc_491521502138_item	2603513	et	3	main
sa	doc_491521502138_item	2603516	et	3	main
tunned	doc_491521502138_item	2603517	et	3	main
võrdle	doc_491521502138_item	2603530	et	4	main
see	doc_491521502138_item	2603536	et	3	main
eksamitöö	doc_491521502139_item	2603548	et	4	main
avatakse	doc_491521502139_item	2603553	et	4	main
jätatakse	doc_491521502139_item	2603562	et	4	main
ära	doc_491521502139_item	2603565	et	4	main
hästi	doc_491521502139_item	2603575	et	3	main
olatakse	doc_491521502139_item	2603578	et	4	main
kaiakse	doc_491521502139_item	2603593	et	4	main
kirjuta	doc_491521502139_item	2603603	et	4	main
sõnale	doc_491521502139_item	2603604	et	3	main
nõrga	doc_491521502139_item	2603609	et	3	main
tugev	doc_491521502139_item	2603612	et	4	main
võrrelda	doc_491521502139_item	2603622	et	4	main
võrran	doc_491521502139_item	2603623	et	4	main
nõrk	doc_491521502139_item	2603624	et	3	main
nõrk	doc_491521502139_item	2603627	et	3	main
õpin	doc_491521502139_item	2603631	et	3	main
moodusta	doc_491521502139_item	2603643	et	4	main
määrsõnad	doc_491521502139_item	2603644	et	4	main
ja	doc_491521502139_item	2603645	et	3	main
julgesti	doc_491521502139_item	2603656	et	3	main
ilus	doc_491521502139_item	2603658	et	4	main
ilusamalt	doc_491521502139_item	2603660	et	4	main
aeglane	doc_491521502139_item	2603661	et	3	main
aeglaselt	doc_491521502139_item	2603662	et	4	main
rõõmus	doc_491521502139_item	2603667	et	4	main
halvasti	doc_491521502139_item	2603671	et	3	main
määrsõnadega	doc_491521502139_item	2603686	et	4	main
mööda	doc_491521502139_item	2603691	et	4	main
julgemalt	doc_491521502138_item	2603327	et	4	main
aeglane	doc_491521502138_item	2603331	et	3	main
aeglasemalt	doc_491521502138_item	2603333	et	4	main
hästi	doc_491521502138_item	2603335	et	3	main
paremini	doc_491521502138_item	2603336	et	4	main
aus	doc_491521502138_item	2603343	et	4	main
vihaselt	doc_491521502138_item	2603347	et	4	main
4	doc_491521502138_item	2603352	et	2	main
alla	doc_491521502138_item	2603359	et	3	main
silla	doc_491521502138_item	2603366	et	3	main
tule	doc_491521502138_item	2603367	et	4	main
pärast	doc_491521502138_item	2603368	et	4	main
lõunat	doc_491521502138_item	2603369	et	3	main
tagasi	doc_491521502138_item	2603370	et	3	main
sõidame	doc_491521502138_item	2603371	et	3	main
mere	doc_491521502138_item	2603372	et	3	main
äärde	doc_491521502138_item	2603373	et	4	main
ta	doc_491521502138_item	2603374	et	4	main
õpib	doc_491521502138_item	2603375	et	3	main
siin	doc_491521502138_item	2603376	et	4	main
juba	doc_491521502138_item	2603377	et	3	main
septembrist	doc_491521502138_item	2603378	et	3	main
kohvis	doc_491521502138_item	2603380	et	3	main
saadi	doc_491521502138_item	2603379	et	4	main
on	doc_491521502138_item	2603381	et	4	main
liiga	doc_491521502138_item	2603382	et	4	main
palju	doc_491521502138_item	2603383	et	4	main
suhkrut	doc_491521502138_item	2603384	et	3	main
ei	doc_491521502138_item	2603395	et	4	main
kas	doc_491521502138_item	2603399	et	3	main
abil	doc_491521502138_item	2603409	et	4	main
uusi	doc_491521502138_item	2603410	et	3	main
elama	doc_491521502138_item	2603412	et	3	main
kasvav	doc_491521502138_item	2603419	et	4	main
laulik	doc_491521502138_item	2603425	et	3	main
tulija	doc_491521502138_item	2603434	et	4	main
tulek	doc_491521502138_item	2603435	et	3	main
tulemine	doc_491521502138_item	2603436	et	4	main
suvi	doc_491521502138_item	2603446	et	3	main
vana	doc_491521502138_item	2603450	et	4	main
vanus	doc_491521502138_item	2603452	et	4	main
sulgudes	doc_491521502138_item	2603459	et	4	main
olevad	doc_491521502138_item	2603460	et	4	main
kas	doc_491521502138_item	2603464	et	3	main
tema	doc_491521502138_item	2603466	et	4	main
tingimustega	doc_491521502138_item	2603480	et	3	main
vastuse	doc_491521502138_item	2603490	et	3	main
sa	doc_491521502138_item	2603494	et	3	main
võistlusest	doc_491521502138_item	2603501	et	4	main
osa	doc_491521502138_item	2603503	et	4	main
ühte	doc_491521502138_item	2603508	et	4	main
võõrkeelt	doc_491521502138_item	2603509	et	4	main
võõrkeel	doc_491521502138_item	2603511	et	4	main
välismaalane	doc_491521502138_item	2603514	et	3	main
7	doc_491521502138_item	2603522	et	2	main
ja	doc_491521502138_item	2603524	et	3	main
edasi	doc_491521502138_item	2603526	et	3	main
st	doc_491521502138_item	2603538	et	3	main
1	doc_491521502139_item	2603549	et	2	main
kasuta	doc_491521502139_item	2603550	et	4	main
avama	doc_491521502139_item	2603554	et	3	main
kl	doc_491521502139_item	2603555	et	4	main
sõpru	doc_491521502139_item	2603557	et	3	main
tundatakse	doc_491521502139_item	2603558	et	4	main
tundma	doc_491521502139_item	2603559	et	3	main
tunnid	doc_491521502139_item	2603564	et	3	main
võtatakse	doc_491521502139_item	2603568	et	4	main
kooli	doc_491521502139_item	2603570	et	4	main
kohal	doc_491521502139_item	2603577	et	4	main
õigel	doc_491521502139_item	2603580	et	3	main
eelmisel	doc_491521502139_item	2603582	et	3	main
aastal	doc_491521502139_item	2603583	et	3	main
vahetatakse	doc_491521502139_item	2603584	et	3	main
vahetama	doc_491521502139_item	2603585	et	3	main
töökohta	doc_491521502139_item	2603586	et	4	main
käima	doc_491521502139_item	2603594	et	4	main
väga	doc_491521502139_item	2603595	et	3	main
tihti	doc_491521502139_item	2603596	et	3	main
vastavalt	doc_491521502139_item	2603605	et	4	main
tuba	doc_491521502139_item	2603634	et	4	main
kasvamine	doc_491521502138_item	2603422	et	4	main
lugema	doc_491521502138_item	2603437	et	4	main
õppija	doc_491521502138_item	2603442	et	4	main
suvila	doc_491521502138_item	2603447	et	4	main
suvitaja	doc_491521502138_item	2603449	et	4	main
vananemine	doc_491521502138_item	2603451	et	4	main
6	doc_491521502138_item	2603457	et	2	main
pane	doc_491521502138_item	2603458	et	4	main
õigesse	doc_491521502138_item	2603462	et	3	main
teiste	doc_491521502138_item	2603472	et	4	main
uued	doc_491521502138_item	2603481	et	3	main
tahan	doc_491521502138_item	2603500	et	3	main
nii	doc_491521502138_item	2603525	et	3	main
vaata	doc_491521502138_item	2603528	et	4	main
v	doc_491521502138_item	2603529	et	4	main
pro	doc_491521502138_item	2603535	et	4	main
aasta	doc_491521502138_item	2603539	et	4	main
preili	doc_491521502138_item	2603541	et	4	main
pre	doc_491521502138_item	2603542	et	4	main
passiivi	doc_491521502139_item	2603551	et	4	main
võtma	doc_491521502139_item	2603569	et	3	main
käsketakse	doc_491521502139_item	2603573	et	4	main
kallilt	doc_491521502139_item	2603590	et	4	main
kinos	doc_491521502139_item	2603591	et	3	main
ei	doc_491521502139_item	2603592	et	4	main
ära	doc_491521502139_item	2603601	et	4	main
2	doc_491521502139_item	2603602	et	2	main
tugeva	doc_491521502139_item	2603607	et	4	main
räägin	doc_491521502139_item	2603626	et	3	main
kukkuma	doc_491521502139_item	2603628	et	3	main
nõrk	doc_491521502139_item	2603630	et	3	main
tugev	doc_491521502139_item	2603633	et	4	main
toa	doc_491521502139_item	2603635	et	3	main
leheda	doc_491521502139_item	2603638	et	4	main
nõrk	doc_491521502139_item	2603639	et	3	main
kiire	doc_491521502139_item	2603649	et	4	main
ilusat	doc_491521502139_item	2603659	et	3	main
hästi	doc_491521502139_item	2603665	et	3	main
vihane	doc_491521502139_item	2603676	et	4	main
lüngad	doc_491521502139_item	2603684	et	3	main
jalutasime	doc_491521502139_item	2603690	et	3	main
sõitis	doc_491521502139_item	2603694	et	3	main
alguses	doc_491521502139_item	2603709	et	4	main
suhkrut	doc_491521502139_item	2603714	et	3	main
minu	doc_491521502139_item	2603717	et	3	main
ukse	doc_491521502139_item	2603722	et	3	main
julgenud	doc_491521502139_item	2603726	et	4	main
kas	doc_491521502139_item	2603729	et	3	main
laul	doc_491521502139_item	2603745	et	4	main
soe	doc_491521502139_item	2603756	et	4	main
vana	doc_491521502139_item	2603757	et	4	main
vanast	doc_491521502139_item	2603758	et	3	main
mõte	doc_491521502139_item	2603759	et	3	main
mõtlema	doc_491521502139_item	2603760	et	3	main
olevad	doc_491521502139_item	2603764	et	4	main
õigesse	doc_491521502139_item	2603766	et	3	main
naera	doc_491521502139_item	2603775	et	4	main
raske	doc_491521502139_item	2603779	et	4	main
tunned	doc_491521502139_item	2603818	et	3	main
sport	doc_491521502139_item	2603821	et	3	main
v	doc_491521502139_item	2603831	et	4	main
ehk	doc_491521502139_item	2603833	et	3	main
pl	doc_491521502139_item	2603841	et	4	main
eksamitöö	doc_491521502140_item	2603847	et	4	main
või	doc_491521502140_item	2603907	et	4	main
nõrga	doc_491521502140_item	2603908	et	3	main
astme	doc_491521502140_item	2603909	et	3	main
vorm	doc_491521502140_item	2603910	et	3	main
oodata	doc_491521502140_item	2603916	et	4	main
räägin	doc_491521502140_item	2603920	et	3	main
kuku	doc_491521502140_item	2603922	et	4	main
õppida	doc_491521502140_item	2603924	et	3	main
toa	doc_491521502140_item	2603926	et	3	main
poiss	doc_491521502140_item	2603930	et	3	main
nende	doc_491521502140_item	2603935	et	4	main
kiire	doc_491521502140_item	2603938	et	4	main
kiiremini	doc_491521502140_item	2603940	et	4	main
kurb	doc_491521502140_item	2603941	et	3	main
kurvalt	doc_491521502140_item	2603942	et	4	main
kurvamalt	doc_491521502140_item	2603943	et	4	main
ilusamalt	doc_491521502140_item	2603949	et	4	main
rõõmsalt	doc_491521502140_item	2603957	et	4	main
trepist	doc_491521502140_item	2603977	et	3	main
üles	doc_491521502140_item	2603980	et	3	main
üles	doc_491521502140_item	2603984	et	3	main
lühenda	doc_491521502138_item	2603523	et	4	main
vrd	doc_491521502138_item	2603531	et	4	main
ehk	doc_491521502138_item	2603532	et	3	main
e	doc_491521502138_item	2603533	et	4	main
tähendab	doc_491521502138_item	2603537	et	3	main
a	doc_491521502138_item	2603540	et	4	main
eksamitöö	doc_491521502139_item	2603547	et	4	main
lapsel	doc_491521502139_item	2603572	et	4	main
õppida	doc_491521502139_item	2603576	et	3	main
ajal	doc_491521502139_item	2603581	et	4	main
maja	doc_491521502139_item	2603587	et	4	main
muuakse	doc_491521502139_item	2603588	et	4	main
müüma	doc_491521502139_item	2603589	et	3	main
kogu	doc_491521502139_item	2603597	et	4	main
toit	doc_491521502139_item	2603598	et	3	main
süüakse	doc_491521502139_item	2603599	et	3	main
kas	doc_491521502139_item	2603606	et	3	main
astme	doc_491521502139_item	2603610	et	3	main
kappi	doc_491521502139_item	2603613	et	4	main
kap	doc_491521502139_item	2603614	et	4	main
tugev	doc_491521502139_item	2603615	et	4	main
lennata	doc_491521502139_item	2603616	et	4	main
lenna	doc_491521502139_item	2603617	et	4	main
nõrk	doc_491521502139_item	2603618	et	3	main
ootan	doc_491521502139_item	2603619	et	3	main
oodale	doc_491521502139_item	2603620	et	4	main
õppime	doc_491521502139_item	2603632	et	4	main
lehed	doc_491521502139_item	2603637	et	3	main
nende	doc_491521502139_item	2603646	et	4	main
keskvõrre	doc_491521502139_item	2603647	et	4	main
aeglasemalt	doc_491521502139_item	2603663	et	4	main
rõõmusamalt	doc_491521502139_item	2603669	et	4	main
aus	doc_491521502139_item	2603673	et	4	main
vihamini	doc_491521502139_item	2603678	et	4	main
täida	doc_491521502139_item	2603683	et	4	main
all	doc_491521502139_item	2603689	et	3	main
silla	doc_491521502139_item	2603696	et	3	main
kohvis	doc_491521502139_item	2603710	et	3	main
on	doc_491521502139_item	2603711	et	4	main
see	doc_491521502139_item	2603715	et	3	main
võõras	doc_491521502139_item	2603720	et	4	main
ja	doc_491521502139_item	2603724	et	3	main
antud	doc_491521502139_item	2603735	et	4	main
sõnadest	doc_491521502139_item	2603736	et	3	main
liidete	doc_491521502139_item	2603737	et	3	main
abil	doc_491521502139_item	2603738	et	4	main
laulia	doc_491521502139_item	2603746	et	4	main
sulgudes	doc_491521502139_item	2603763	et	4	main
sõnad	doc_491521502139_item	2603765	et	4	main
ära	doc_491521502139_item	2603774	et	4	main
ja	doc_491521502139_item	2603824	et	3	main
jne	doc_491521502139_item	2603827	et	4	main
v	doc_491521502139_item	2603829	et	4	main
härra	doc_491521502139_item	2603844	et	4	main
passiivi	doc_491521502140_item	2603850	et	4	main
avatakse	doc_491521502140_item	2603852	et	4	main
kõik	doc_491521502140_item	2603865	et	4	main
ei	doc_491521502140_item	2603891	et	4	main
sööma	doc_491521502140_item	2603899	et	4	main
kappi	doc_491521502140_item	2603911	et	4	main
võrrelda	doc_491521502140_item	2603917	et	4	main
tugev	doc_491521502139_item	2603621	et	4	main
rääkima	doc_491521502139_item	2603625	et	3	main
kukun	doc_491521502139_item	2603629	et	3	main
nt	doc_491521502139_item	2603648	et	4	main
kiiresti	doc_491521502139_item	2603650	et	3	main
kiiremini	doc_491521502139_item	2603651	et	4	main
kurb	doc_491521502139_item	2603652	et	3	main
kurbesti	doc_491521502139_item	2603653	et	4	main
kurbemini	doc_491521502139_item	2603654	et	4	main
julge	doc_491521502139_item	2603655	et	4	main
julgemini	doc_491521502139_item	2603657	et	4	main
hea	doc_491521502139_item	2603664	et	4	main
rõõmusalt	doc_491521502139_item	2603668	et	4	main
soe	doc_491521502139_item	2603679	et	4	main
some	doc_491521502139_item	2603680	et	4	main
soemini	doc_491521502139_item	2603681	et	4	main
4	doc_491521502139_item	2603682	et	2	main
läksime	doc_491521502139_item	2603687	et	3	main
pargi	doc_491521502139_item	2603692	et	4	main
mööda	doc_491521502139_item	2603695	et	4	main
pärast	doc_491521502139_item	2603698	et	4	main
tagasi	doc_491521502139_item	2603700	et	3	main
ääre	doc_491521502139_item	2603703	et	3	main
ta	doc_491521502139_item	2603704	et	4	main
õpib	doc_491521502139_item	2603705	et	3	main
oli	doc_491521502139_item	2603716	et	3	main
parem	doc_491521502139_item	2603666	et	4	main
halb	doc_491521502139_item	2603670	et	3	main
halvemini	doc_491521502139_item	2603672	et	4	main
ausesti	doc_491521502139_item	2603674	et	4	main
auslemini	doc_491521502139_item	2603675	et	4	main
vihanem	doc_491521502139_item	2603677	et	4	main
õigete	doc_491521502139_item	2603685	et	3	main
trepist	doc_491521502139_item	2603688	et	3	main
auto	doc_491521502139_item	2603693	et	4	main
tule	doc_491521502139_item	2603697	et	4	main
lõunat	doc_491521502139_item	2603699	et	3	main
mere	doc_491521502139_item	2603702	et	3	main
siin	doc_491521502139_item	2603706	et	4	main
juba	doc_491521502139_item	2603707	et	3	main
septembrist	doc_491521502139_item	2603708	et	3	main
palju	doc_491521502139_item	2603713	et	4	main
uus	doc_491521502139_item	2603718	et	3	main
ei	doc_491521502139_item	2603725	et	4	main
tulla	doc_491521502139_item	2603728	et	3	main
said	doc_491521502139_item	2603731	et	4	main
kirja	doc_491521502139_item	2603732	et	4	main
5	doc_491521502139_item	2603733	et	2	main
elama	doc_491521502139_item	2603741	et	3	main
elu	doc_491521502139_item	2603742	et	4	main
kasvama	doc_491521502139_item	2603743	et	3	main
lutevik	doc_491521502139_item	2603750	et	4	main
lugema	doc_491521502139_item	2603751	et	4	main
6	doc_491521502139_item	2603761	et	2	main
aru	doc_491521502139_item	2603773	et	4	main
õnnetused	doc_491521502139_item	2603778	et	4	main
on	doc_491521502139_item	2603780	et	4	main
kohaneda	doc_491521502139_item	2603781	et	3	main
uued	doc_491521502139_item	2603783	et	3	main
tingimused	doc_491521502139_item	2603784	et	3	main
laps	doc_491521502139_item	2603785	et	4	main
keeldus	doc_491521502139_item	2603786	et	3	main
sõidame	doc_491521502139_item	2603701	et	3	main
liiga	doc_491521502139_item	2603712	et	4	main
uudis	doc_491521502139_item	2603719	et	3	main
seisis	doc_491521502139_item	2603721	et	4	main
moodusta	doc_491521502139_item	2603734	et	4	main
kasvatamine	doc_491521502139_item	2603744	et	4	main
südamine	doc_491521502139_item	2603748	et	4	main
tema	doc_491521502139_item	2603770	et	4	main
juttut	doc_491521502139_item	2603771	et	4	main
jutt	doc_491521502139_item	2603772	et	3	main
kiiresti	doc_491521502139_item	2603782	et	3	main
huvi	doc_491521502139_item	2603819	et	4	main
sportiga	doc_491521502139_item	2603820	et	4	main
lühenda	doc_491521502139_item	2603823	et	4	main
nii	doc_491521502139_item	2603825	et	3	main
võrdle	doc_491521502139_item	2603830	et	4	main
lehekülg	doc_491521502139_item	2603842	et	3	main
lk	doc_491521502139_item	2603843	et	4	main
1	doc_491521502140_item	2603848	et	2	main
avama	doc_491521502140_item	2603853	et	3	main
kl	doc_491521502140_item	2603854	et	4	main
sõpru	doc_491521502140_item	2603856	et	3	main
hädas	doc_491521502140_item	2603859	et	3	main
eile	doc_491521502140_item	2603860	et	3	main
jääti	doc_491521502140_item	2603861	et	4	main
raamatud	doc_491521502140_item	2603866	et	4	main
käia	doc_491521502140_item	2603892	et	4	main
käima	doc_491521502140_item	2603893	et	4	main
väga	doc_491521502140_item	2603894	et	3	main
tihti	doc_491521502140_item	2603895	et	3	main
ära	doc_491521502140_item	2603900	et	4	main
vastavalt	doc_491521502140_item	2603904	et	4	main
kas	doc_491521502140_item	2603905	et	3	main
tugeva	doc_491521502140_item	2603906	et	4	main
lenda	doc_491521502140_item	2603914	et	4	main
ootan	doc_491521502140_item	2603915	et	3	main
rääkima	doc_491521502140_item	2603919	et	3	main
leht	doc_491521502140_item	2603928	et	3	main
nt	doc_491521502140_item	2603937	et	4	main
julge	doc_491521502140_item	2603944	et	4	main
julgemini	doc_491521502140_item	2603946	et	4	main
aeglaselt	doc_491521502140_item	2603951	et	4	main
paremini	doc_491521502140_item	2603955	et	4	main
halvasti	doc_491521502140_item	2603960	et	3	main
ausamalt	doc_491521502140_item	2603964	et	4	main
vihasemalt	doc_491521502140_item	2603967	et	4	main
lüngad	doc_491521502140_item	2603973	et	3	main
sõitis	doc_491521502140_item	2603983	et	3	main
siin	doc_491521502140_item	2603995	et	4	main
palju	doc_491521502140_item	2604002	et	4	main
minu	doc_491521502140_item	2604006	et	3	main
uudis	doc_491521502140_item	2604008	et	3	main
sõnu	doc_491521502140_item	2604030	et	4	main
elukoht	doc_491521502140_item	2604033	et	3	main
kasvatud	doc_491521502140_item	2604035	et	4	main
südamees	doc_491521502140_item	2604040	et	4	main
tulevik	doc_491521502140_item	2604042	et	3	main
õppima	doc_491521502140_item	2604046	et	3	main
õpejõud	doc_491521502140_item	2604048	et	4	main
suvi	doc_491521502140_item	2604049	et	3	main
suviti	doc_491521502140_item	2604050	et	3	main
vana	doc_491521502140_item	2604051	et	4	main
pane	doc_491521502140_item	2604056	et	4	main
sulgudes	doc_491521502140_item	2604057	et	4	main
vormi	doc_491521502140_item	2604061	et	4	main
tingimused	doc_491521502140_item	2604078	et	3	main
tahan	doc_491521502140_item	2604095	et	3	main
ma	doc_491521502140_item	2604100	et	3	main
oskan	doc_491521502140_item	2604101	et	3	main
üht	doc_491521502140_item	2604103	et	3	main
võõrkeelt	doc_491521502140_item	2604104	et	4	main
üks	doc_491521502140_item	2604105	et	3	main
võõrkeel	doc_491521502140_item	2604106	et	4	main
tutvusin	doc_491521502140_item	2604107	et	3	main
välismaalast	doc_491521502140_item	2604108	et	4	main
huvi	doc_491521502140_item	2604113	et	4	main
sport	doc_491521502140_item	2604115	et	3	main
ja	doc_491521502140_item	2604118	et	3	main
proua	doc_491521502140_item	2604128	et	4	main
aasta	doc_491521502140_item	2604132	et	4	main
preili	doc_491521502140_item	2604134	et	4	main
pril	doc_491521502140_item	2604135	et	4	main
alla	doc_491521502139_item	2603723	et	3	main
labi	doc_491521502139_item	2603727	et	4	main
sa	doc_491521502139_item	2603730	et	3	main
uusi	doc_491521502139_item	2603739	et	3	main
sõnu	doc_491521502139_item	2603740	et	4	main
süda	doc_491521502139_item	2603747	et	3	main
tulema	doc_491521502139_item	2603749	et	4	main
lugemine	doc_491521502139_item	2603752	et	4	main
õppima	doc_491521502139_item	2603753	et	3	main
õppilane	doc_491521502139_item	2603754	et	4	main
suvi	doc_491521502139_item	2603755	et	3	main
pane	doc_491521502139_item	2603762	et	4	main
vormi	doc_491521502139_item	2603767	et	4	main
kas	doc_491521502139_item	2603768	et	3	main
said	doc_491521502139_item	2603769	et	4	main
teiste	doc_491521502139_item	2603776	et	4	main
õnnetusele	doc_491521502139_item	2603777	et	4	main
süüa	doc_491521502139_item	2603787	et	3	main
söök	doc_491521502139_item	2603788	et	3	main
ma	doc_491521502139_item	2603789	et	3	main
kahtlen	doc_491521502139_item	2603790	et	3	main
tema	doc_491521502139_item	2603791	et	4	main
vastuse	doc_491521502139_item	2603792	et	3	main
õigususse	doc_491521502139_item	2603793	et	4	main
õigsus	doc_491521502139_item	2603794	et	3	main
kas	doc_491521502139_item	2603795	et	3	main
sa	doc_491521502139_item	2603796	et	3	main
oled	doc_491521502139_item	2603797	et	3	main
see	doc_491521502139_item	2603798	et	3	main
see	doc_491521502139_item	2603799	et	3	main
kindel	doc_491521502139_item	2603800	et	3	main
tahan	doc_491521502139_item	2603801	et	3	main
võistluses	doc_491521502139_item	2603802	et	3	main
võistlus	doc_491521502139_item	2603803	et	3	main
osa	doc_491521502139_item	2603804	et	4	main
võtta	doc_491521502139_item	2603805	et	3	main
ma	doc_491521502139_item	2603806	et	3	main
oskan	doc_491521502139_item	2603807	et	3	main
ühe	doc_491521502139_item	2603809	et	4	main
võõrkeelt	doc_491521502139_item	2603810	et	4	main
ainult	doc_491521502139_item	2603808	et	4	main
üks	doc_491521502139_item	2603811	et	3	main
võõrkeel	doc_491521502139_item	2603812	et	4	main
tutvusin	doc_491521502139_item	2603813	et	3	main
välismaalase	doc_491521502139_item	2603814	et	3	main
välismaalane	doc_491521502139_item	2603815	et	3	main
kas	doc_491521502139_item	2603816	et	3	main
sa	doc_491521502139_item	2603817	et	3	main
preili	doc_491521502139_item	2603840	et	4	main
eksamitöö	doc_491521502140_item	2603846	et	4	main
kauplused	doc_491521502140_item	2603851	et	3	main
võdetakse	doc_491521502140_item	2603867	et	4	main
võtma	doc_491521502140_item	2603868	et	3	main
kooli	doc_491521502140_item	2603869	et	4	main
kaasa	doc_491521502140_item	2603870	et	4	main
lapsel	doc_491521502140_item	2603871	et	4	main
käskitakse	doc_491521502140_item	2603872	et	4	main
käskima	doc_491521502140_item	2603873	et	4	main
hästi	doc_491521502140_item	2603874	et	3	main
õppida	doc_491521502140_item	2603875	et	3	main
kohal	doc_491521502140_item	2603876	et	4	main
ollakse	doc_491521502140_item	2603877	et	3	main
olema	doc_491521502140_item	2603878	et	4	main
õigel	doc_491521502140_item	2603879	et	3	main
ajal	doc_491521502140_item	2603880	et	4	main
eelmisel	doc_491521502140_item	2603881	et	3	main
aastal	doc_491521502140_item	2603882	et	3	main
vahetati	doc_491521502140_item	2603883	et	4	main
vahetama	doc_491521502140_item	2603884	et	3	main
töökohta	doc_491521502140_item	2603885	et	4	main
maja	doc_491521502140_item	2603886	et	4	main
müüakse	doc_491521502140_item	2603887	et	3	main
müüma	doc_491521502140_item	2603888	et	3	main
kallilt	doc_491521502140_item	2603889	et	4	main
kinos	doc_491521502140_item	2603890	et	3	main
7	doc_491521502139_item	2603822	et	2	main
edasi	doc_491521502139_item	2603826	et	3	main
vaata	doc_491521502139_item	2603828	et	4	main
d	doc_491521502139_item	2603832	et	4	main
proua	doc_491521502139_item	2603834	et	4	main
pr	doc_491521502139_item	2603835	et	4	main
see	doc_491521502139_item	2603836	et	3	main
tähendab	doc_491521502139_item	2603837	et	3	main
st	doc_491521502139_item	2603838	et	3	main
aasta	doc_491521502139_item	2603839	et	4	main
hr	doc_491521502139_item	2603845	et	4	main
kasuta	doc_491521502140_item	2603849	et	4	main
10	doc_491521502140_item	2603855	et	2	main
tunnakse	doc_491521502140_item	2603857	et	4	main
tundma	doc_491521502140_item	2603858	et	3	main
jätma	doc_491521502140_item	2603862	et	3	main
tunnid	doc_491521502140_item	2603863	et	3	main
ära	doc_491521502140_item	2603864	et	4	main
2	doc_491521502140_item	2603901	et	2	main
sõnale	doc_491521502140_item	2603903	et	3	main
kapi	doc_491521502140_item	2603912	et	4	main
lennata	doc_491521502140_item	2603913	et	4	main
võrrata	doc_491521502140_item	2603918	et	4	main
kukkuma	doc_491521502140_item	2603921	et	3	main
lehed	doc_491521502140_item	2603927	et	3	main
keskvõrre	doc_491521502140_item	2603936	et	4	main
kiiresti	doc_491521502140_item	2603939	et	3	main
ilusalt	doc_491521502140_item	2603948	et	4	main
aeglane	doc_491521502140_item	2603950	et	3	main
rõõmus	doc_491521502140_item	2603956	et	4	main
aus	doc_491521502140_item	2603962	et	4	main
vihaselt	doc_491521502140_item	2603966	et	4	main
sojalt	doc_491521502140_item	2603969	et	3	main
auto	doc_491521502140_item	2603982	et	4	main
pärast	doc_491521502140_item	2603987	et	4	main
tagasi	doc_491521502140_item	2603989	et	3	main
ääres	doc_491521502140_item	2603992	et	4	main
ta	doc_491521502140_item	2603993	et	4	main
õpib	doc_491521502140_item	2603994	et	3	main
taga	doc_491521502140_item	2604012	et	4	main
ja	doc_491521502140_item	2604013	et	3	main
kogu	doc_491521502140_item	2603896	et	4	main
toit	doc_491521502140_item	2603897	et	3	main
süüakse	doc_491521502140_item	2603898	et	3	main
kirjuta	doc_491521502140_item	2603902	et	4	main
tuba	doc_491521502140_item	2603925	et	4	main
poisid	doc_491521502140_item	2603929	et	4	main
3	doc_491521502140_item	2603931	et	2	main
moodusta	doc_491521502140_item	2603932	et	4	main
määrsõnad	doc_491521502140_item	2603933	et	4	main
julgesti	doc_491521502140_item	2603945	et	3	main
rõõmsamalt	doc_491521502140_item	2603958	et	4	main
vihane	doc_491521502140_item	2603965	et	4	main
4	doc_491521502140_item	2603971	et	2	main
õigete	doc_491521502140_item	2603974	et	3	main
all	doc_491521502140_item	2603978	et	3	main
pargi	doc_491521502140_item	2603981	et	4	main
juba	doc_491521502140_item	2603996	et	3	main
septembrist	doc_491521502140_item	2603997	et	3	main
polleldi	doc_491521502140_item	2603998	et	4	main
kohvis	doc_491521502140_item	2603999	et	3	main
suhkrut	doc_491521502140_item	2604003	et	3	main
oli	doc_491521502140_item	2604005	et	3	main
jaoks	doc_491521502140_item	2604007	et	4	main
ei	doc_491521502140_item	2604014	et	4	main
abil	doc_491521502140_item	2604028	et	4	main
igavana	doc_491521502140_item	2604052	et	4	main
mõte	doc_491521502140_item	2604053	et	3	main
uued	doc_491521502140_item	2604077	et	3	main
söögi	doc_491521502140_item	2604081	et	4	main
kahtlen	doc_491521502140_item	2604084	et	3	main
vastuse	doc_491521502140_item	2604086	et	3	main
õigsusest	doc_491521502140_item	2604087	et	4	main
oled	doc_491521502140_item	2604091	et	3	main
see	doc_491521502140_item	2604093	et	3	main
võistlus	doc_491521502140_item	2604097	et	3	main
võtta	doc_491521502140_item	2604099	et	3	main
ainult	doc_491521502140_item	2604102	et	4	main
sa	doc_491521502140_item	2604111	et	3	main
spordist	doc_491521502140_item	2604114	et	3	main
lühenda	doc_491521502140_item	2604117	et	4	main
edasi	doc_491521502140_item	2604120	et	3	main
see	doc_491521502140_item	2604130	et	3	main
kasuta	doc_491521502141_item	2604143	et	4	main
passiivi	doc_491521502141_item	2604144	et	4	main
kauplused	doc_491521502141_item	2604145	et	3	main
10	doc_491521502141_item	2604149	et	2	main
tundakse	doc_491521502141_item	2604151	et	4	main
hädas	doc_491521502141_item	2604153	et	3	main
tunnid	doc_491521502141_item	2604157	et	3	main
kooli	doc_491521502141_item	2604163	et	4	main
ollakse	doc_491521502141_item	2604171	et	3	main
ajal	doc_491521502141_item	2604174	et	4	main
vahetatakse	doc_491521502141_item	2604177	et	3	main
töökohta	doc_491521502141_item	2604179	et	4	main
kinos	doc_491521502141_item	2604184	et	3	main
käitud	doc_491521502141_item	2604186	et	3	main
poisid	doc_491521502141_item	2604223	et	4	main
nt	doc_491521502141_item	2604231	et	4	main
ilus	doc_491521502141_item	2604241	et	4	main
hea	doc_491521502141_item	2604247	et	4	main
rõõmsasti	doc_491521502141_item	2604251	et	3	main
halvasti	doc_491521502141_item	2604254	et	3	main
halvemini	doc_491521502141_item	2604255	et	4	main
lüngad	doc_491521502141_item	2604267	et	3	main
trepist	doc_491521502141_item	2604271	et	3	main
läbi	doc_491521502141_item	2604274	et	4	main
pargi	doc_491521502141_item	2604275	et	4	main
tagasi	doc_491521502141_item	2604283	et	3	main
liidete	doc_491521502141_item	2604321	et	3	main
uusi	doc_491521502141_item	2604323	et	3	main
laul	doc_491521502141_item	2604329	et	4	main
laulumine	doc_491521502141_item	2604330	et	4	main
vana	doc_491521502141_item	2604341	et	4	main
sulgudes	doc_491521502141_item	2604347	et	4	main
jutt	doc_491521502141_item	2604356	et	3	main
ma	doc_491521502141_item	2604375	et	3	main
vastuse	doc_491521502141_item	2604378	et	3	main
kas	doc_491521502141_item	2604381	et	3	main
võistluses	doc_491521502141_item	2604388	et	3	main
ainult	doc_491521502141_item	2604394	et	4	main
st	doc_491521502141_item	2604424	et	3	main
aasta	doc_491521502141_item	2604425	et	4	main
õpin	doc_491521502140_item	2603923	et	3	main
ja	doc_491521502140_item	2603934	et	3	main
ilus	doc_491521502140_item	2603947	et	4	main
aeglasemalt	doc_491521502140_item	2603952	et	4	main
hea	doc_491521502140_item	2603953	et	4	main
hästi	doc_491521502140_item	2603954	et	3	main
halb	doc_491521502140_item	2603959	et	3	main
halvemini	doc_491521502140_item	2603961	et	4	main
ausalt	doc_491521502140_item	2603963	et	4	main
soe	doc_491521502140_item	2603968	et	4	main
sojemalt	doc_491521502140_item	2603970	et	4	main
täida	doc_491521502140_item	2603972	et	4	main
määrsõnadega	doc_491521502140_item	2603975	et	4	main
läksime	doc_491521502140_item	2603976	et	3	main
jalutasime	doc_491521502140_item	2603979	et	3	main
silla	doc_491521502140_item	2603985	et	3	main
tule	doc_491521502140_item	2603986	et	4	main
lõunat	doc_491521502140_item	2603988	et	3	main
sõidame	doc_491521502140_item	2603990	et	3	main
liiga	doc_491521502140_item	2604001	et	4	main
see	doc_491521502140_item	2604004	et	3	main
võõras	doc_491521502140_item	2604009	et	4	main
seisis	doc_491521502140_item	2604010	et	4	main
ukse	doc_491521502140_item	2604011	et	3	main
julgenud	doc_491521502140_item	2604015	et	4	main
ette	doc_491521502140_item	2604016	et	4	main
tulla	doc_491521502140_item	2604017	et	3	main
kas	doc_491521502140_item	2604018	et	3	main
sa	doc_491521502140_item	2604019	et	3	main
said	doc_491521502140_item	2604020	et	4	main
aru	doc_491521502140_item	2604022	et	4	main
moodusta	doc_491521502140_item	2604024	et	4	main
antud	doc_491521502140_item	2604025	et	4	main
sõnadest	doc_491521502140_item	2604026	et	3	main
liidete	doc_491521502140_item	2604027	et	3	main
elama	doc_491521502140_item	2604031	et	3	main
kasvama	doc_491521502140_item	2604034	et	3	main
laulutus	doc_491521502140_item	2604037	et	4	main
tulema	doc_491521502140_item	2604041	et	4	main
lugemine	doc_491521502140_item	2604044	et	4	main
loeng	doc_491521502140_item	2604045	et	3	main
õpimine	doc_491521502140_item	2604047	et	4	main
6	doc_491521502140_item	2604055	et	2	main
kindel	doc_491521502140_item	2604094	et	3	main
välismaalane	doc_491521502140_item	2604109	et	3	main
7	doc_491521502140_item	2604116	et	2	main
jne	doc_491521502140_item	2604121	et	4	main
vta	doc_491521502140_item	2604123	et	4	main
võrdle	doc_491521502140_item	2604124	et	4	main
tähendab	doc_491521502140_item	2604131	et	3	main
at	doc_491521502140_item	2604133	et	4	main
lehk	doc_491521502140_item	2604137	et	3	main
härra	doc_491521502140_item	2604138	et	4	main
här	doc_491521502140_item	2604139	et	4	main
eksamitöö	doc_491521502141_item	2604140	et	4	main
avatakse	doc_491521502141_item	2604146	et	4	main
sõpru	doc_491521502141_item	2604150	et	3	main
eile	doc_491521502141_item	2604154	et	3	main
jättakse	doc_491521502141_item	2604155	et	4	main
jätma	doc_491521502141_item	2604156	et	3	main
käskima	doc_491521502141_item	2604167	et	4	main
hästi	doc_491521502141_item	2604168	et	3	main
õppida	doc_491521502141_item	2604169	et	3	main
õigel	doc_491521502141_item	2604173	et	3	main
maja	doc_491521502141_item	2604180	et	4	main
müüakse	doc_491521502141_item	2604181	et	3	main
ei	doc_491521502141_item	2604185	et	4	main
käima	doc_491521502141_item	2604187	et	4	main
lehed	doc_491521502141_item	2604221	et	3	main
3	doc_491521502141_item	2604225	et	2	main
määrsõnad	doc_491521502141_item	2604227	et	4	main
ja	doc_491521502141_item	2604228	et	3	main
nende	doc_491521502141_item	2604229	et	4	main
kiiresti	doc_491521502141_item	2604233	et	3	main
kurvasti	doc_491521502141_item	2604236	et	4	main
julgemalt	doc_491521502141_item	2604240	et	4	main
paremini	doc_491521502141_item	2604249	et	4	main
mere	doc_491521502140_item	2603991	et	3	main
on	doc_491521502140_item	2604000	et	4	main
kirja	doc_491521502140_item	2604021	et	4	main
elu	doc_491521502140_item	2604032	et	4	main
laul	doc_491521502140_item	2604036	et	4	main
süda	doc_491521502140_item	2604038	et	3	main
keeldus	doc_491521502140_item	2604080	et	3	main
söök	doc_491521502140_item	2604082	et	3	main
tema	doc_491521502140_item	2604085	et	4	main
õigsus	doc_491521502140_item	2604088	et	3	main
kas	doc_491521502140_item	2604089	et	3	main
sa	doc_491521502140_item	2604090	et	3	main
tunned	doc_491521502140_item	2604112	et	3	main
nii	doc_491521502140_item	2604119	et	3	main
5	doc_491521502140_item	2604023	et	2	main
uusi	doc_491521502140_item	2604029	et	3	main
südanik	doc_491521502140_item	2604039	et	4	main
lugema	doc_491521502140_item	2604043	et	4	main
mõtekas	doc_491521502140_item	2604054	et	4	main
olevad	doc_491521502140_item	2604058	et	4	main
sõnad	doc_491521502140_item	2604059	et	4	main
õigesse	doc_491521502140_item	2604060	et	3	main
kas	doc_491521502140_item	2604062	et	3	main
said	doc_491521502140_item	2604063	et	4	main
tema	doc_491521502140_item	2604064	et	4	main
juttu	doc_491521502140_item	2604065	et	4	main
jutt	doc_491521502140_item	2604066	et	3	main
aru	doc_491521502140_item	2604067	et	4	main
ära	doc_491521502140_item	2604068	et	4	main
naera	doc_491521502140_item	2604069	et	4	main
teiste	doc_491521502140_item	2604070	et	4	main
õnnestusedest	doc_491521502140_item	2604071	et	4	main
õnnetused	doc_491521502140_item	2604072	et	4	main
raske	doc_491521502140_item	2604073	et	4	main
on	doc_491521502140_item	2604074	et	4	main
kohaneda	doc_491521502140_item	2604075	et	3	main
kiiresti	doc_491521502140_item	2604076	et	3	main
laps	doc_491521502140_item	2604079	et	4	main
ma	doc_491521502140_item	2604083	et	3	main
sellest	doc_491521502140_item	2604092	et	4	main
võistlusest	doc_491521502140_item	2604096	et	4	main
osa	doc_491521502140_item	2604098	et	4	main
kas	doc_491521502140_item	2604110	et	3	main
vaata	doc_491521502140_item	2604122	et	4	main
võrd	doc_491521502140_item	2604125	et	4	main
ehk	doc_491521502140_item	2604126	et	3	main
ek	doc_491521502140_item	2604127	et	4	main
lehekülg	doc_491521502140_item	2604136	et	3	main
raamatud	doc_491521502141_item	2604160	et	4	main
võeldakse	doc_491521502141_item	2604161	et	4	main
kaasa	doc_491521502141_item	2604164	et	4	main
kallilt	doc_491521502141_item	2604183	et	4	main
kiiremini	doc_491521502141_item	2604234	et	4	main
ilusasti	doc_491521502141_item	2604242	et	3	main
ilusamini	doc_491521502141_item	2604243	et	4	main
aeglane	doc_491521502141_item	2604244	et	3	main
hästi	doc_491521502141_item	2604248	et	3	main
rõõmsamini	doc_491521502141_item	2604252	et	4	main
halb	doc_491521502141_item	2604253	et	3	main
vihaselt	doc_491521502141_item	2604260	et	4	main
vihasemalt	doc_491521502141_item	2604261	et	4	main
täida	doc_491521502141_item	2604266	et	4	main
õigete	doc_491521502141_item	2604268	et	3	main
alla	doc_491521502141_item	2604272	et	3	main
pärast	doc_491521502141_item	2604281	et	4	main
ta	doc_491521502141_item	2604287	et	4	main
elav	doc_491521502141_item	2604326	et	4	main
kasvatud	doc_491521502141_item	2604328	et	4	main
süda	doc_491521502141_item	2604331	et	3	main
südamest	doc_491521502141_item	2604332	et	4	main
loetud	doc_491521502141_item	2604336	et	4	main
tema	doc_491521502141_item	2604354	et	4	main
juttust	doc_491521502141_item	2604355	et	3	main
ära	doc_491521502141_item	2604358	et	4	main
kiiresti	doc_491521502141_item	2604366	et	3	main
laps	doc_491521502141_item	2604371	et	4	main
keeldus	doc_491521502141_item	2604372	et	3	main
söögis	doc_491521502141_item	2604373	et	3	main
tema	doc_491521502141_item	2604377	et	4	main
prua	doc_491521502140_item	2604129	et	4	main
eksamitöö	doc_491521502141_item	2604141	et	4	main
1	doc_491521502141_item	2604142	et	2	main
avama	doc_491521502141_item	2604147	et	3	main
tundma	doc_491521502141_item	2604152	et	3	main
ära	doc_491521502141_item	2604158	et	4	main
kõik	doc_491521502141_item	2604159	et	4	main
kohal	doc_491521502141_item	2604170	et	4	main
väga	doc_491521502141_item	2604188	et	3	main
tihti	doc_491521502141_item	2604189	et	3	main
kogu	doc_491521502141_item	2604190	et	4	main
toit	doc_491521502141_item	2604191	et	3	main
süüakse	doc_491521502141_item	2604192	et	3	main
sööma	doc_491521502141_item	2604193	et	4	main
ära	doc_491521502141_item	2604194	et	4	main
2	doc_491521502141_item	2604195	et	2	main
kirjuta	doc_491521502141_item	2604196	et	4	main
sõnale	doc_491521502141_item	2604197	et	3	main
vastavalt	doc_491521502141_item	2604198	et	4	main
kas	doc_491521502141_item	2604199	et	3	main
tugeva	doc_491521502141_item	2604200	et	4	main
või	doc_491521502141_item	2604201	et	4	main
nõrga	doc_491521502141_item	2604202	et	3	main
astme	doc_491521502141_item	2604203	et	3	main
vorm	doc_491521502141_item	2604204	et	3	main
kappi	doc_491521502141_item	2604205	et	4	main
kapp	doc_491521502141_item	2604206	et	3	main
lendma	doc_491521502141_item	2604208	et	4	main
ootan	doc_491521502141_item	2604209	et	3	main
oodata	doc_491521502141_item	2604210	et	4	main
lennata	doc_491521502141_item	2604207	et	4	main
võrrelda	doc_491521502141_item	2604211	et	4	main
võrrlema	doc_491521502141_item	2604212	et	4	main
rääkima	doc_491521502141_item	2604213	et	3	main
räägin	doc_491521502141_item	2604214	et	3	main
kukkuma	doc_491521502141_item	2604215	et	3	main
kukuta	doc_491521502141_item	2604216	et	4	main
õpin	doc_491521502141_item	2604217	et	3	main
õppima	doc_491521502141_item	2604218	et	3	main
tuba	doc_491521502141_item	2604219	et	4	main
toa	doc_491521502141_item	2604220	et	3	main
leht	doc_491521502141_item	2604222	et	3	main
poiss	doc_491521502141_item	2604224	et	3	main
moodusta	doc_491521502141_item	2604226	et	4	main
kiire	doc_491521502141_item	2604232	et	4	main
kurvamini	doc_491521502141_item	2604237	et	4	main
julge	doc_491521502141_item	2604238	et	4	main
aus	doc_491521502141_item	2604256	et	4	main
ausasti	doc_491521502141_item	2604257	et	3	main
soe	doc_491521502141_item	2604262	et	4	main
kl	doc_491521502141_item	2604148	et	4	main
võtma	doc_491521502141_item	2604162	et	3	main
lapsel	doc_491521502141_item	2604165	et	4	main
käskitakse	doc_491521502141_item	2604166	et	4	main
olema	doc_491521502141_item	2604172	et	4	main
eelmisel	doc_491521502141_item	2604175	et	3	main
aastal	doc_491521502141_item	2604176	et	3	main
vahetama	doc_491521502141_item	2604178	et	3	main
müüma	doc_491521502141_item	2604182	et	3	main
keskvõrre	doc_491521502141_item	2604230	et	4	main
kurb	doc_491521502141_item	2604235	et	3	main
julgelt	doc_491521502141_item	2604239	et	4	main
aeglaselt	doc_491521502141_item	2604245	et	4	main
aeglasemalt	doc_491521502141_item	2604246	et	4	main
ausamini	doc_491521502141_item	2604258	et	4	main
vihane	doc_491521502141_item	2604259	et	4	main
4	doc_491521502141_item	2604265	et	2	main
määrsõnadega	doc_491521502141_item	2604269	et	4	main
auto	doc_491521502141_item	2604276	et	4	main
sõitis	doc_491521502141_item	2604277	et	3	main
üle	doc_491521502141_item	2604278	et	3	main
silla	doc_491521502141_item	2604279	et	3	main
sõidame	doc_491521502141_item	2604284	et	3	main
ääres	doc_491521502141_item	2604286	et	4	main
õpib	doc_491521502141_item	2604288	et	3	main
siin	doc_491521502141_item	2604289	et	4	main
juba	doc_491521502141_item	2604290	et	3	main
septembrist	doc_491521502141_item	2604291	et	3	main
kohvis	doc_491521502141_item	2604293	et	3	main
on	doc_491521502141_item	2604294	et	4	main
liiga	doc_491521502141_item	2604295	et	4	main
palju	doc_491521502141_item	2604296	et	4	main
suhkrut	doc_491521502141_item	2604297	et	3	main
see	doc_491521502141_item	2604298	et	3	main
oli	doc_491521502141_item	2604299	et	3	main
minu	doc_491521502141_item	2604300	et	3	main
oma	doc_491521502141_item	2604301	et	4	main
uudis	doc_491521502141_item	2604302	et	3	main
võõras	doc_491521502141_item	2604303	et	4	main
ukse	doc_491521502141_item	2604305	et	3	main
taga	doc_491521502141_item	2604306	et	4	main
ja	doc_491521502141_item	2604307	et	3	main
seisis	doc_491521502141_item	2604304	et	4	main
ei	doc_491521502141_item	2604308	et	4	main
julgenud	doc_491521502141_item	2604309	et	4	main
sisse	doc_491521502141_item	2604310	et	4	main
tulla	doc_491521502141_item	2604311	et	3	main
kas	doc_491521502141_item	2604312	et	3	main
sa	doc_491521502141_item	2604313	et	3	main
said	doc_491521502141_item	2604314	et	4	main
kirja	doc_491521502141_item	2604315	et	4	main
kätte	doc_491521502141_item	2604316	et	4	main
5	doc_491521502141_item	2604317	et	2	main
moodusta	doc_491521502141_item	2604318	et	4	main
antud	doc_491521502141_item	2604319	et	4	main
sõnadest	doc_491521502141_item	2604320	et	3	main
elama	doc_491521502141_item	2604325	et	3	main
tulema	doc_491521502141_item	2604333	et	4	main
mõte	doc_491521502141_item	2604343	et	3	main
mõtlemine	doc_491521502141_item	2604344	et	4	main
6	doc_491521502141_item	2604345	et	2	main
olevad	doc_491521502141_item	2604348	et	4	main
raske	doc_491521502141_item	2604363	et	4	main
rõõmus	doc_491521502141_item	2604250	et	4	main
sojamalt	doc_491521502141_item	2604264	et	4	main
tule	doc_491521502141_item	2604280	et	4	main
mere	doc_491521502141_item	2604285	et	3	main
abil	doc_491521502141_item	2604322	et	4	main
kasvama	doc_491521502141_item	2604327	et	3	main
tulevik	doc_491521502141_item	2604334	et	3	main
vanem	doc_491521502141_item	2604342	et	4	main
said	doc_491521502141_item	2604353	et	4	main
õnnetused	doc_491521502141_item	2604362	et	4	main
söök	doc_491521502141_item	2604374	et	3	main
sa	doc_491521502141_item	2604382	et	3	main
sellest	doc_491521502141_item	2604384	et	4	main
kindel	doc_491521502141_item	2604386	et	3	main
tahan	doc_491521502141_item	2604387	et	3	main
osa	doc_491521502141_item	2604390	et	4	main
ma	doc_491521502141_item	2604392	et	3	main
üht	doc_491521502141_item	2604395	et	3	main
pr	doc_491521502141_item	2604421	et	4	main
järgi	doc_491521502142_item	2604439	et	4	main
ringi	doc_491521502142_item	2604442	et	4	main
vaadates	doc_491521502142_item	2604443	et	3	main
jääb	doc_491521502142_item	2604444	et	3	main
ainsaks	doc_491521502142_item	2604448	et	3	main
mõõdupuuks	doc_491521502142_item	2604449	et	4	main
raha	doc_491521502142_item	2604458	et	4	main
nimed	doc_491521502142_item	2604481	et	3	main
midagi	doc_491521502142_item	2604483	et	4	main
kui	doc_491521502142_item	2604511	et	3	main
annavad	doc_491521502142_item	2604512	et	3	main
oma	doc_491521502142_item	2604513	et	4	main
ole	doc_491521502142_item	2604523	et	4	main
näidatud	doc_491521502142_item	2604536	et	4	main
nõusolekuna	doc_491521502142_item	2604539	et	3	main
võitleb	doc_491521502142_item	2604547	et	3	main
eesti	doc_491521502142_item	2604549	et	4	main
vastu	doc_491521502142_item	2604550	et	3	main
eriti	doc_491521502142_item	2604551	et	3	main
jäi	doc_491521502142_item	2604552	et	3	main
meelde	doc_491521502142_item	2604553	et	3	main
stseen	doc_491521502142_item	2604554	et	3	main
koolimajas	doc_491521502142_item	2604555	et	4	main
oleks	doc_491521502142_item	2604556	et	3	main
ju	doc_491521502142_item	2604557	et	3	main
kodumaad	doc_491521502142_item	2604566	et	4	main
vägede	doc_491521502142_item	2604607	et	3	main
veenmise	doc_491521502142_item	2604613	et	4	main
enamus	doc_491521502142_item	2604616	et	4	main
kõigi	doc_491521502142_item	2604627	et	4	main
halvustavale	doc_491521502142_item	2604628	et	4	main
pilgule	doc_491521502142_item	2604629	et	4	main
mõnitamisele	doc_491521502142_item	2604634	et	4	main
vaatamata	doc_491521502142_item	2604635	et	4	main
karjakesi	doc_491521502142_item	2604649	et	4	main
kujutatud	doc_491521502142_item	2604663	et	4	main
selge	doc_491521502142_item	2604665	et	4	main
jääb	doc_491521502142_item	2604667	et	3	main
inimest	doc_491521502142_item	2604711	et	3	main
platsil	doc_491521502142_item	2604717	et	3	main
kohtuvad	doc_491521502142_item	2604718	et	4	main
tunnistama	doc_491521502142_item	2604720	et	3	main
sojalt	doc_491521502141_item	2604263	et	3	main
läksime	doc_491521502141_item	2604270	et	3	main
jalutasime	doc_491521502141_item	2604273	et	3	main
lõunat	doc_491521502141_item	2604282	et	3	main
ära	doc_491521502141_item	2604292	et	4	main
sõnu	doc_491521502141_item	2604324	et	4	main
lugema	doc_491521502141_item	2604335	et	4	main
õppima	doc_491521502141_item	2604337	et	3	main
õppimine	doc_491521502141_item	2604338	et	4	main
suvi	doc_491521502141_item	2604339	et	3	main
suvelik	doc_491521502141_item	2604340	et	4	main
pane	doc_491521502141_item	2604346	et	4	main
sõnad	doc_491521502141_item	2604349	et	4	main
õigesse	doc_491521502141_item	2604350	et	3	main
vormi	doc_491521502141_item	2604351	et	4	main
kas	doc_491521502141_item	2604352	et	3	main
aru	doc_491521502141_item	2604357	et	4	main
naera	doc_491521502141_item	2604359	et	4	main
teiste	doc_491521502141_item	2604360	et	4	main
õnnetuste	doc_491521502141_item	2604361	et	4	main
tingimusi	doc_491521502141_item	2604368	et	3	main
uued	doc_491521502141_item	2604369	et	3	main
kahtlen	doc_491521502141_item	2604376	et	3	main
õigsuse	doc_491521502141_item	2604379	et	3	main
õigsus	doc_491521502141_item	2604380	et	3	main
see	doc_491521502141_item	2604385	et	3	main
võistlus	doc_491521502141_item	2604389	et	3	main
võtta	doc_491521502141_item	2604391	et	3	main
üks	doc_491521502141_item	2604397	et	3	main
võõrkeel	doc_491521502141_item	2604398	et	4	main
tutvusin	doc_491521502141_item	2604399	et	3	main
välismaalast	doc_491521502141_item	2604400	et	4	main
välismaalane	doc_491521502141_item	2604401	et	3	main
kas	doc_491521502141_item	2604402	et	3	main
sa	doc_491521502141_item	2604403	et	3	main
tunned	doc_491521502141_item	2604404	et	3	main
huvi	doc_491521502141_item	2604405	et	4	main
sportisse	doc_491521502141_item	2604406	et	4	main
sport	doc_491521502141_item	2604407	et	3	main
7	doc_491521502141_item	2604408	et	2	main
lühenda	doc_491521502141_item	2604409	et	4	main
ja	doc_491521502141_item	2604410	et	3	main
nii	doc_491521502141_item	2604411	et	3	main
edasi	doc_491521502141_item	2604412	et	3	main
jne	doc_491521502141_item	2604413	et	4	main
vaata	doc_491521502141_item	2604414	et	4	main
vt	doc_491521502141_item	2604415	et	4	main
võrdle	doc_491521502141_item	2604416	et	4	main
ehk	doc_491521502141_item	2604418	et	3	main
e	doc_491521502141_item	2604419	et	4	main
vl	doc_491521502141_item	2604417	et	4	main
proua	doc_491521502141_item	2604420	et	4	main
lk	doc_491521502141_item	2604430	et	4	main
hr	doc_491521502141_item	2604432	et	4	main
essee	doc_491521502142_item	2604433	et	4	main
esse	doc_491521502142_item	2604434	et	3	main
retsensioon	doc_491521502142_item	2604435	et	3	main
nimed	doc_491521502142_item	2604436	et	3	main
marmortahvlil	doc_491521502142_item	2604437	et	3	main
tänapäeva	doc_491521502142_item	2604440	et	4	main
on	doc_491521502142_item	2604450	et	4	main
huvita	doc_491521502142_item	2604456	et	4	main
viis	doc_491521502142_item	2604460	et	4	main
sellepärast	doc_491521502142_item	2604477	et	3	main
on	doc_491521502141_item	2604364	et	4	main
kohaneda	doc_491521502141_item	2604365	et	3	main
uusi	doc_491521502141_item	2604367	et	3	main
tingimused	doc_491521502141_item	2604370	et	3	main
oled	doc_491521502141_item	2604383	et	3	main
oskan	doc_491521502141_item	2604393	et	3	main
võõrkeelt	doc_491521502141_item	2604396	et	4	main
see	doc_491521502141_item	2604422	et	3	main
tähendab	doc_491521502141_item	2604423	et	3	main
prl	doc_491521502141_item	2604428	et	4	main
härra	doc_491521502141_item	2604431	et	4	main
filmi	doc_491521502142_item	2604438	et	4	main
eestis	doc_491521502142_item	2604441	et	3	main
mulje	doc_491521502142_item	2604445	et	4	main
et	doc_491521502142_item	2604446	et	3	main
inimväärikuse	doc_491521502142_item	2604447	et	4	main
raha	doc_491521502142_item	2604452	et	4	main
ei	doc_491521502142_item	2604455	et	4	main
film	doc_491521502142_item	2604480	et	3	main
kinoelamust	doc_491521502142_item	2604487	et	4	main
eelkõige	doc_491521502142_item	2604488	et	3	main
äratas	doc_491521502142_item	2604489	et	3	main
see	doc_491521502142_item	2604490	et	3	main
vaieldamatult	doc_491521502142_item	2604491	et	4	main
viimasel	doc_491521502142_item	2604492	et	3	main
kõneainet	doc_491521502142_item	2604495	et	3	main
selliseid	doc_491521502142_item	2604506	et	4	main
maa	doc_491521502142_item	2604514	et	4	main
võõra	doc_491521502142_item	2604515	et	3	main
kätte	doc_491521502142_item	2604516	et	4	main
tallata	doc_491521502142_item	2604517	et	4	main
a	doc_491521502141_item	2604426	et	4	main
preili	doc_491521502141_item	2604427	et	4	main
saanud	doc_491521502142_item	2604451	et	4	main
kusjuures	doc_491521502142_item	2604453	et	3	main
paljusi	doc_491521502142_item	2604454	et	4	main
selle	doc_491521502142_item	2604457	et	4	main
teenimise	doc_491521502142_item	2604459	et	4	main
vaid	doc_491521502142_item	2604461	et	3	main
kogus	doc_491521502142_item	2604462	et	4	main
kuigi	doc_491521502142_item	2604463	et	3	main
üha	doc_491521502142_item	2604464	et	3	main
enam	doc_491521502142_item	2604465	et	4	main
leidub	doc_491521502142_item	2604466	et	3	main
ka	doc_491521502142_item	2604467	et	3	main
hindavad	doc_491521502142_item	2604470	et	4	main
inimesi	doc_491521502142_item	2604468	et	4	main
elus	doc_491521502142_item	2604471	et	4	main
kes	doc_491521502142_item	2604469	et	4	main
midagi	doc_491521502142_item	2604472	et	4	main
enam	doc_491521502142_item	2604473	et	4	main
kui	doc_491521502142_item	2604474	et	3	main
kõikvõimsat	doc_491521502142_item	2604475	et	3	main
lehekülg	doc_491521502141_item	2604429	et	3	main
dollarit	doc_491521502142_item	2604476	et	3	main
pakkus	doc_491521502142_item	2604478	et	3	main
tunde	doc_491521502142_item	2604499	et	4	main
sest	doc_491521502142_item	2604500	et	4	main
filmis	doc_491521502142_item	2604501	et	4	main
esile	doc_491521502142_item	2604502	et	3	main
tõstetud	doc_491521502142_item	2604503	et	4	main
noormehed	doc_491521502142_item	2604504	et	3	main
esindasid	doc_491521502142_item	2604505	et	4	main
kes	doc_491521502142_item	2604508	et	4	main
filmi	doc_491521502142_item	2604520	et	4	main
elu	doc_491521502142_item	2604530	et	4	main
patriotismi	doc_491521502142_item	2604532	et	4	main
tunne	doc_491521502142_item	2604533	et	4	main
vastupidi	doc_491521502142_item	2604540	et	3	main
tegelaskuju	doc_491521502142_item	2604543	et	4	main
kahtleb	doc_491521502142_item	2604544	et	3	main
lausa	doc_491521502142_item	2604546	et	4	main
vaba	doc_491521502142_item	2604548	et	4	main
minna	doc_491521502142_item	2604568	et	3	main
kõik	doc_491521502142_item	2604570	et	4	main
vabariiki	doc_491521502142_item	2604598	et	4	main
variandina	doc_491521502142_item	2604605	et	3	main
kuigi	doc_491521502142_item	2604609	et	3	main
ja	doc_491521502142_item	2604612	et	3	main
järel	doc_491521502142_item	2604614	et	4	main
haarata	doc_491521502142_item	2604619	et	4	main
üks	doc_491521502142_item	2604620	et	3	main
osutub	doc_491521502142_item	2604622	et	3	main
asjade	doc_491521502142_item	2604640	et	3	main
reaalsem	doc_491521502142_item	2604646	et	4	main
kui	doc_491521502142_item	2604647	et	3	main
lihtsalt	doc_491521502142_item	2604648	et	4	main
tormamine	doc_491521502142_item	2604652	et	4	main
jätab	doc_491521502142_item	2604654	et	3	main
tõsielulise	doc_491521502142_item	2604656	et	4	main
inimlikult	doc_491521502142_item	2604659	et	4	main
ja	doc_491521502142_item	2604660	et	3	main
oma	doc_491521502142_item	2604678	et	4	main
täiesti	doc_491521502142_item	2604713	et	3	main
raekoja	doc_491521502142_item	2604715	et	3	main
suurt	doc_491521502142_item	2604722	et	3	main
kahega	doc_491521502142_item	2604750	et	3	main
kindel	doc_491521502142_item	2604751	et	3	main
nad	doc_491521502142_item	2604753	et	3	main
viia	doc_491521502142_item	2604756	et	3	main
mulje	doc_491521502142_item	2604759	et	4	main
tõelist	doc_491521502142_item	2604761	et	4	main
oli	doc_491521502142_item	2604782	et	3	main
käitumine	doc_491521502142_item	2604784	et	4	main
esmakordsel	doc_491521502142_item	2604785	et	3	main
relvi	doc_491521502142_item	2604799	et	4	main
nende	doc_491521502142_item	2604805	et	4	main
närviga	doc_491521502142_item	2604820	et	3	main
järgi	doc_491521502142_item	2604825	et	4	main
vaatamata	doc_491521502142_item	2604843	et	4	main
ägedatele	doc_491521502142_item	2604845	et	3	main
mõisteti	doc_491521502142_item	2604847	et	3	main
endast	doc_491521502142_item	2604861	et	4	main
tögamisega	doc_491521502142_item	2604898	et	4	main
et	doc_491521502142_item	2604915	et	3	main
pingeid	doc_491521502142_item	2604918	et	3	main
ning	doc_491521502142_item	2604921	et	3	main
on	doc_491521502142_item	2604923	et	4	main
kui	doc_491521502142_item	2604925	et	3	main
kõrval	doc_491521502142_item	2604926	et	4	main
kes	doc_491521502142_item	2604929	et	4	main
kainelt	doc_491521502142_item	2604933	et	4	main
kunagi	doc_491521502142_item	2604938	et	3	main
meelest	doc_491521502142_item	2604953	et	4	main
näitlejate	doc_491521502142_item	2604966	et	4	main
ja	doc_491521502142_item	2604967	et	3	main
isegi	doc_491521502142_item	2604982	et	4	main
pisara	doc_491521502142_item	2604983	et	3	main
teevad	doc_491521502142_item	2604992	et	3	main
a	doc_491521502142_item	2604996	et	4	main
et	doc_491521502142_item	2605001	et	3	main
ka	doc_491521502142_item	2605003	et	3	main
ka	doc_491521502142_item	2604479	et	3	main
ajal	doc_491521502142_item	2604493	et	4	main
linateos	doc_491521502142_item	2604497	et	4	main
patriotismi	doc_491521502142_item	2604498	et	4	main
eestlasi	doc_491521502142_item	2604507	et	3	main
enne	doc_491521502142_item	2604509	et	4	main
surevad	doc_491521502142_item	2604510	et	4	main
kuna	doc_491521502142_item	2604519	et	3	main
ei	doc_491521502142_item	2604522	et	4	main
ideaalse	doc_491521502142_item	2604524	et	3	main
pildi	doc_491521502142_item	2604525	et	4	main
loomine	doc_491521502142_item	2604526	et	4	main
vaid	doc_491521502142_item	2604527	et	3	main
pigem	doc_491521502142_item	2604528	et	3	main
reaalse	doc_491521502142_item	2604529	et	3	main
ole	doc_491521502142_item	2604535	et	4	main
üksmeelse	doc_491521502142_item	2604538	et	3	main
või	doc_491521502142_item	2604545	et	4	main
kaitsma	doc_491521502142_item	2604567	et	3	main
otsustab	doc_491521502142_item	2604615	et	3	main
siiski	doc_491521502142_item	2604617	et	4	main
relva	doc_491521502142_item	2604618	et	4	main
aga	doc_491521502142_item	2604623	et	3	main
et	doc_491521502142_item	2604626	et	3	main
füüsilisele	doc_491521502142_item	2604633	et	3	main
otsustab	doc_491521502142_item	2604636	et	3	main
selline	doc_491521502142_item	2604639	et	4	main
on	doc_491521502142_item	2604642	et	4	main
arvates	doc_491521502142_item	2604644	et	4	main
igati	doc_491521502142_item	2604645	et	3	main
sõtta	doc_491521502142_item	2604651	et	3	main
väga	doc_491521502142_item	2604658	et	3	main
sõnumina	doc_491521502142_item	2604666	et	3	main
kõlama	doc_491521502142_item	2604668	et	3	main
vaadetele	doc_491521502142_item	2604676	et	3	main
armastuslugu	doc_491521502142_item	2604708	et	4	main
kaks	doc_491521502142_item	2604709	et	3	main
juhuslikult	doc_491521502142_item	2604714	et	4	main
meie	doc_491521502142_item	2604724	et	4	main
saatus	doc_491521502142_item	2604728	et	3	main
kokkusaamised	doc_491521502142_item	2604732	et	4	main
ootamatud	doc_491521502142_item	2604735	et	4	main
seda	doc_491521502142_item	2604740	et	3	main
kokku	doc_491521502142_item	2604755	et	3	main
armastust	doc_491521502142_item	2604762	et	4	main
ei	doc_491521502142_item	2604763	et	4	main
tühisematest	doc_491521502142_item	2604769	et	4	main
suurt	doc_491521502142_item	2604771	et	3	main
meeldejäävamaks	doc_491521502142_item	2604780	et	4	main
kohtumisel	doc_491521502142_item	2604786	et	4	main
vaenlasega	doc_491521502142_item	2604787	et	3	main
õigem	doc_491521502142_item	2604788	et	4	main
ja	doc_491521502142_item	2604797	et	3	main
mõtlematu	doc_491521502142_item	2604810	et	4	main
külma	doc_491521502142_item	2604819	et	4	main
ja	doc_491521502142_item	2604826	et	3	main
korjas	doc_491521502142_item	2604827	et	3	main
kaalaste	doc_491521502142_item	2604835	et	4	main
aga	doc_491521502142_item	2604839	et	3	main
oskuste	doc_491521502142_item	2604850	et	3	main
see	doc_491521502142_item	2604853	et	3	main
ja	doc_491521502142_item	2604855	et	3	main
õige	doc_491521502142_item	2604856	et	4	main
ning	doc_491521502142_item	2604858	et	3	main
ka	doc_491521502142_item	2604867	et	3	main
juhi	doc_491521502142_item	2604868	et	4	main
märkuste	doc_491521502142_item	2604894	et	4	main
teine	doc_491521502142_item	2604896	et	3	main
tõsta	doc_491521502142_item	2604903	et	4	main
ja	doc_491521502142_item	2604904	et	3	main
hetkemuresid	doc_491521502142_item	2604905	et	3	main
unustada	doc_491521502142_item	2604906	et	3	main
parandades	doc_491521502142_item	2604910	et	3	main
see	doc_491521502142_item	2604912	et	3	main
taluvad	doc_491521502142_item	2604917	et	4	main
väga	doc_491521502142_item	2604919	et	3	main
marmortahvlil	doc_491521502142_item	2604482	et	3	main
muud	doc_491521502142_item	2604484	et	4	main
kui	doc_491521502142_item	2604485	et	3	main
tavapärast	doc_491521502142_item	2604486	et	4	main
enim	doc_491521502142_item	2604494	et	4	main
pakkunud	doc_491521502142_item	2604496	et	4	main
kuid	doc_491521502142_item	2604518	et	4	main
eesmärk	doc_491521502142_item	2604521	et	3	main
ei	doc_491521502142_item	2604534	et	4	main
pimedalt	doc_491521502142_item	2604537	et	4	main
mõni	doc_491521502142_item	2604542	et	3	main
imelik	doc_491521502142_item	2604558	et	3	main
klassi	doc_491521502142_item	2604561	et	4	main
vaimne	doc_491521502142_item	2604562	et	3	main
liider	doc_491521502142_item	2604563	et	3	main
teeb	doc_491521502142_item	2604564	et	3	main
kes	doc_491521502142_item	2604602	et	4	main
näeb	doc_491521502142_item	2604603	et	3	main
parima	doc_491521502142_item	2604604	et	4	main
nõukogude	doc_491521502142_item	2604606	et	3	main
võitu	doc_491521502142_item	2604608	et	4	main
vaidluse	doc_491521502142_item	2604611	et	3	main
peegeldamine	doc_491521502142_item	2604531	et	4	main
nii	doc_491521502142_item	2604541	et	3	main
vaadata	doc_491521502142_item	2604559	et	4	main
kuidas	doc_491521502142_item	2604560	et	3	main
ettepaneku	doc_491521502142_item	2604565	et	3	main
ning	doc_491521502142_item	2604569	et	3	main
koolivennad	doc_491521502142_item	2604571	et	3	main
jooksevad	doc_491521502142_item	2604572	et	4	main
end	doc_491521502142_item	2604573	et	4	main
vabatahtlikuna	doc_491521502142_item	2604574	et	3	main
kirja	doc_491521502142_item	2604575	et	4	main
panema	doc_491521502142_item	2604576	et	3	main
selle	doc_491521502142_item	2604577	et	4	main
asemel	doc_491521502142_item	2604578	et	4	main
aga	doc_491521502142_item	2604579	et	3	main
löövad	doc_491521502142_item	2604580	et	4	main
noormeeste	doc_491521502142_item	2604581	et	4	main
vahel	doc_491521502142_item	2604582	et	4	main
kired	doc_491521502142_item	2604583	et	4	main
lõkendama	doc_491521502142_item	2604584	et	3	main
kes	doc_491521502142_item	2604585	et	4	main
on	doc_491521502142_item	2604586	et	4	main
kohe	doc_491521502142_item	2604587	et	4	main
nõus	doc_491521502142_item	2604588	et	4	main
minema	doc_491521502142_item	2604589	et	3	main
kes	doc_491521502142_item	2604590	et	4	main
ei	doc_491521502142_item	2604591	et	4	main
taha	doc_491521502142_item	2604592	et	4	main
sõjast	doc_491521502142_item	2604593	et	3	main
kuuldagi	doc_491521502142_item	2604594	et	4	main
kes	doc_491521502142_item	2604595	et	4	main
et	doc_491521502142_item	2604597	et	3	main
leiab	doc_491521502142_item	2604596	et	3	main
talle	doc_491521502142_item	2604599	et	4	main
pole	doc_491521502142_item	2604600	et	3	main
vaja	doc_491521502142_item	2604601	et	4	main
pika	doc_491521502142_item	2604610	et	4	main
õpilastest	doc_491521502142_item	2604621	et	4	main
isegi	doc_491521502142_item	2604631	et	4	main
vastaspoolele	doc_491521502142_item	2604638	et	3	main
käik	doc_491521502142_item	2604641	et	3	main
minu	doc_491521502142_item	2604643	et	3	main
kohe	doc_491521502142_item	2604650	et	4	main
ning	doc_491521502142_item	2604653	et	3	main
vägagi	doc_491521502142_item	2604655	et	3	main
mulje	doc_491521502142_item	2604657	et	4	main
erapooletult	doc_491521502142_item	2604661	et	4	main
on	doc_491521502142_item	2604662	et	4	main
oma	doc_491521502142_item	2604675	et	4	main
noort	doc_491521502142_item	2604710	et	3	main
esisel	doc_491521502142_item	2604716	et	3	main
pidid	doc_491521502142_item	2604719	et	4	main
osa	doc_491521502142_item	2604723	et	4	main
elus	doc_491521502142_item	2604725	et	4	main
võib	doc_491521502142_item	2604726	et	3	main
mängida	doc_491521502142_item	2604727	et	3	main
edaspidised	doc_491521502142_item	2604731	et	3	main
täiesti	doc_491521502142_item	2604734	et	3	main
suuda	doc_491521502142_item	2604764	et	4	main
rääkimata	doc_491521502142_item	2604768	et	4	main
asjaoludest	doc_491521502142_item	2604770	et	3	main
rõhke	doc_491521502142_item	2604772	et	3	main
on	doc_491521502142_item	2604774	et	4	main
üheks	doc_491521502142_item	2604779	et	3	main
sattusid	doc_491521502142_item	2604794	et	4	main
põhjustanud	doc_491521502142_item	2604808	et	4	main
sedavõrd	doc_491521502142_item	2604624	et	3	main
punaseks	doc_491521502142_item	2604625	et	4	main
ja	doc_491521502142_item	2604630	et	3	main
mõningasele	doc_491521502142_item	2604632	et	3	main
asuda	doc_491521502142_item	2604637	et	3	main
teisitimõtlejad	doc_491521502142_item	2604664	et	3	main
lause	doc_491521502142_item	2604669	et	4	main
et	doc_491521502142_item	2604670	et	3	main
igal	doc_491521502142_item	2604671	et	3	main
inimesel	doc_491521502142_item	2604672	et	3	main
on	doc_491521502142_item	2604673	et	4	main
õigus	doc_491521502142_item	2604674	et	4	main
ja	doc_491521502142_item	2604677	et	3	main
arvamusele	doc_491521502142_item	2604679	et	3	main
loomulikult	doc_491521502142_item	2604680	et	4	main
ei	doc_491521502142_item	2604681	et	4	main
patriotism	doc_491521502142_item	2604683	et	3	main
ja	doc_491521502142_item	2604684	et	3	main
ole	doc_491521502142_item	2604682	et	4	main
mõttevabadus	doc_491521502142_item	2604685	et	4	main
selle	doc_491521502142_item	2604686	et	4	main
ainsad	doc_491521502142_item	2604688	et	3	main
filmi	doc_491521502142_item	2604687	et	4	main
läbivad	doc_491521502142_item	2604689	et	4	main
ideed	doc_491521502142_item	2604690	et	4	main
suurt	doc_491521502142_item	2604691	et	3	main
rõhku	doc_491521502142_item	2604692	et	4	main
on	doc_491521502142_item	2604693	et	4	main
pandud	doc_491521502142_item	2604694	et	4	main
ka	doc_491521502142_item	2604695	et	3	main
inimeste	doc_491521502142_item	2604696	et	3	main
vahelistele	doc_491521502142_item	2604697	et	4	main
suhetele	doc_491521502142_item	2604698	et	3	main
rasketel	doc_491521502142_item	2604699	et	3	main
aegadel	doc_491521502142_item	2604700	et	3	main
eelkõige	doc_491521502142_item	2604701	et	3	main
muidugi	doc_491521502142_item	2604702	et	4	main
on	doc_491521502142_item	2604703	et	4	main
see	doc_491521502142_item	2604704	et	3	main
kogu	doc_491521502142_item	2604705	et	4	main
tegevusega	doc_491521502142_item	2604706	et	4	main
läbipõimunud	doc_491521502142_item	2604707	et	4	main
kes	doc_491521502142_item	2604712	et	4	main
kui	doc_491521502142_item	2604721	et	3	main
ka	doc_491521502142_item	2604729	et	3	main
ning	doc_491521502142_item	2604736	et	3	main
aeg	doc_491521502142_item	2604738	et	3	main
selgemaks	doc_491521502142_item	2604741	et	4	main
saab	doc_491521502142_item	2604742	et	3	main
et	doc_491521502142_item	2604743	et	3	main
vaatamata	doc_491521502142_item	2604744	et	4	main
keerulisele	doc_491521502142_item	2604745	et	4	main
ajale	doc_491521502142_item	2604746	et	3	main
on	doc_491521502142_item	2604747	et	4	main
elul	doc_491521502142_item	2604748	et	3	main
omavahel	doc_491521502142_item	2604754	et	3	main
film	doc_491521502142_item	2604757	et	3	main
isegi	doc_491521502142_item	2604765	et	4	main
sõda	doc_491521502142_item	2604766	et	4	main
sündmuseks	doc_491521502142_item	2604781	et	3	main
öelda	doc_491521502142_item	2604789	et	4	main
põneva	doc_491521502142_item	2604790	et	3	main
vaenlasega	doc_491521502142_item	2604791	et	3	main
noored	doc_491521502142_item	2604792	et	3	main
sõdurid	doc_491521502142_item	2604793	et	3	main
paanikasse	doc_491521502142_item	2604796	et	4	main
kaugusesse	doc_491521502142_item	2604804	et	4	main
ei	doc_491521502142_item	2604807	et	4	main
see	doc_491521502142_item	2604809	et	3	main
suuremat	doc_491521502142_item	2604812	et	4	main
mees	doc_491521502142_item	2604821	et	4	main
tuli	doc_491521502142_item	2604823	et	4	main
nende	doc_491521502142_item	2604824	et	4	main
lõpuks	doc_491521502142_item	2604837	et	4	main
laabus	doc_491521502142_item	2604838	et	3	main
et	doc_491521502142_item	2604848	et	3	main
juures	doc_491521502142_item	2604851	et	4	main
ainuvõimalik	doc_491521502142_item	2604854	et	3	main
tegu	doc_491521502142_item	2604857	et	4	main
sõda	doc_491521502142_item	2604859	et	4	main
kujutab	doc_491521502142_item	2604860	et	3	main
algul	doc_491521502142_item	2604865	et	4	main
ja	doc_491521502142_item	2604895	et	3	main
püüti	doc_491521502142_item	2604900	et	3	main
tuju	doc_491521502142_item	2604902	et	4	main
suudab	doc_491521502142_item	2604930	et	3	main
tegutse	doc_491521502142_item	2604937	et	4	main
oma	doc_491521502142_item	2604939	et	4	main
oleks	doc_491521502142_item	2604946	et	3	main
on	doc_491521502142_item	2604954	et	4	main
see	doc_491521502142_item	2604955	et	3	main
film	doc_491521502142_item	2604956	et	3	main
tõesti	doc_491521502142_item	2604957	et	3	main
ükskõikseks	doc_491521502142_item	2604978	et	4	main
minul	doc_491521502142_item	2604979	et	3	main
suutis	doc_491521502142_item	2604980	et	3	main
kordumatuks	doc_491521502142_item	2604991	et	4	main
filmi	doc_491521502142_item	2604994	et	4	main
kivikase	doc_491521502142_item	2604997	et	3	main
tänapäeval	doc_491521502142_item	2605004	et	3	main
julgeid	doc_491521502142_item	2605007	et	3	main
lähedaste	doc_491521502142_item	2605025	et	3	main
kodumaa	doc_491521502142_item	2605027	et	4	main
selleks	doc_491521502142_item	2605044	et	4	main
et	doc_491521502142_item	2605045	et	3	main
jääksid	doc_491521502142_item	2605048	et	4	main
mitte	doc_491521502142_item	2605049	et	3	main
meie	doc_491521502142_item	2605054	et	4	main
südametesse	doc_491521502142_item	2605055	et	4	main
põhjal	doc_491521502143_item	2605065	et	4	main
elmo	doc_491521502143_item	2605076	et	4	main
olid	doc_491521502143_item	2605080	et	4	main
üleskiitmine	doc_491521502143_item	2605093	et	3	main
peale	doc_491521502143_item	2605098	et	4	main
kiideti	doc_491521502143_item	2605100	et	3	main
nende	doc_491521502142_item	2604730	et	4	main
on	doc_491521502142_item	2604733	et	4	main
mida	doc_491521502142_item	2604737	et	4	main
edasi	doc_491521502142_item	2604739	et	3	main
nende	doc_491521502142_item	2604749	et	4	main
plaan	doc_491521502142_item	2604752	et	3	main
jätab	doc_491521502142_item	2604758	et	3	main
et	doc_491521502142_item	2604760	et	3	main
mõjutada	doc_491521502142_item	2604767	et	3	main
filmis	doc_491521502142_item	2604773	et	4	main
pandud	doc_491521502142_item	2604775	et	4	main
ka	doc_491521502142_item	2604776	et	3	main
inimsuhetele	doc_491521502142_item	2604777	et	3	main
kriisiolukordades	doc_491521502142_item	2604778	et	3	main
noormeeste	doc_491521502142_item	2604783	et	4	main
sellegipoolest	doc_491521502142_item	2604795	et	3	main
jooksid	doc_491521502142_item	2604798	et	4	main
maha	doc_491521502142_item	2604800	et	4	main
jättes	doc_491521502142_item	2604801	et	4	main
püssilaskudest	doc_491521502142_item	2604802	et	3	main
ohutusse	doc_491521502142_item	2604803	et	4	main
õnneks	doc_491521502142_item	2604806	et	4	main
tegu	doc_491521502142_item	2604811	et	4	main
kahju	doc_491521502142_item	2604813	et	4	main
sest	doc_491521502142_item	2604814	et	4	main
rühmajuht	doc_491521502142_item	2604815	et	3	main
oli	doc_491521502142_item	2604816	et	3	main
asjalik	doc_491521502142_item	2604817	et	3	main
ja	doc_491521502142_item	2604818	et	3	main
kes	doc_491521502142_item	2604822	et	4	main
isegi	doc_491521502142_item	2604828	et	4	main
varustuse	doc_491521502142_item	2604829	et	4	main
kokku	doc_491521502142_item	2604830	et	3	main
loomulikult	doc_491521502142_item	2604831	et	4	main
peale	doc_491521502142_item	2604836	et	4	main
kõik	doc_491521502142_item	2604840	et	4	main
hästi	doc_491521502142_item	2604841	et	3	main
sest	doc_491521502142_item	2604842	et	4	main
nende	doc_491521502142_item	2604849	et	4	main
oli	doc_491521502142_item	2604852	et	3	main
midagi	doc_491521502142_item	2604862	et	4	main
muud	doc_491521502142_item	2604863	et	4	main
kuigi	doc_491521502142_item	2604864	et	3	main
süüdistamine	doc_491521502142_item	2604892	et	4	main
sellega	doc_491521502142_item	2604899	et	3	main
ka	doc_491521502142_item	2604908	et	3	main
kambavaimu	doc_491521502142_item	2604909	et	4	main
kogu	doc_491521502142_item	2604911	et	4	main
olukord	doc_491521502142_item	2604913	et	3	main
inimesed	doc_491521502142_item	2604916	et	3	main
alati	doc_491521502142_item	2604922	et	4	main
kasuks	doc_491521502142_item	2604924	et	4	main
igas	doc_491521502142_item	2604931	et	3	main
olukorras	doc_491521502142_item	2604932	et	3	main
ja	doc_491521502142_item	2604935	et	3	main
ei	doc_491521502142_item	2604936	et	4	main
marmortahvlil	doc_491521502142_item	2604944	et	3	main
veel	doc_491521502142_item	2604948	et	4	main
kaasakiskuv	doc_491521502142_item	2604960	et	4	main
mõte	doc_491521502142_item	2604962	et	3	main
kõrgel	doc_491521502142_item	2604964	et	4	main
tasemel	doc_491521502142_item	2604965	et	3	main
režissööri	doc_491521502142_item	2604968	et	2	main
töö	doc_491521502142_item	2604969	et	4	main
olen	doc_491521502142_item	2604970	et	3	main
kindel	doc_491521502142_item	2604971	et	3	main
et	doc_491521502142_item	2604972	et	3	main
see	doc_491521502142_item	2604973	et	3	main
jätnud	doc_491521502142_item	2604976	et	4	main
järelduseni	doc_491521502142_item	2604987	et	4	main
tahaksin	doc_491521502142_item	2604988	et	3	main
ennekõike	doc_491521502142_item	2604995	et	3	main
romaani	doc_491521502142_item	2604998	et	4	main
elus	doc_491521502142_item	2605022	et	4	main
ning	doc_491521502142_item	2605026	et	3	main
õnn	doc_491521502142_item	2605028	et	3	main
ja	doc_491521502142_item	2605029	et	3	main
tunduvalt	doc_491521502142_item	2605035	et	4	main
lihtsam	doc_491521502142_item	2605036	et	4	main
ja	doc_491521502142_item	2605037	et	3	main
stabiilsem	doc_491521502142_item	2605038	et	4	main
me	doc_491521502142_item	2605039	et	4	main
peaksime	doc_491521502142_item	2605040	et	4	main
vihastas	doc_491521502142_item	2604832	et	3	main
ta	doc_491521502142_item	2604833	et	4	main
argpükslike	doc_491521502142_item	2604834	et	3	main
omavahelistele	doc_491521502142_item	2604844	et	4	main
vaidlustele	doc_491521502142_item	2604846	et	3	main
vihastati	doc_491521502142_item	2604866	et	3	main
mõisteti	doc_491521502142_item	2604870	et	3	main
hiljem	doc_491521502142_item	2604871	et	3	main
et	doc_491521502142_item	2604872	et	3	main
peale	doc_491521502142_item	2604869	et	4	main
tema	doc_491521502142_item	2604873	et	4	main
nõudmised	doc_491521502142_item	2604874	et	4	main
olid	doc_491521502142_item	2604875	et	4	main
asjakohased	doc_491521502142_item	2604876	et	4	main
ja	doc_491521502142_item	2604877	et	3	main
suhtumist	doc_491521502142_item	2604878	et	4	main
sõtta	doc_491521502142_item	2604879	et	3	main
on	doc_491521502142_item	2604880	et	4	main
viimane	doc_491521502142_item	2604881	et	3	main
aega	doc_491521502142_item	2604882	et	4	main
muuta	doc_491521502142_item	2604883	et	4	main
kui	doc_491521502142_item	2604884	et	3	main
pinged	doc_491521502142_item	2604885	et	3	main
olid	doc_491521502142_item	2604886	et	4	main
taandunud	doc_491521502142_item	2604887	et	4	main
asendus	doc_491521502142_item	2604888	et	4	main
eneseõigustus	doc_491521502142_item	2604889	et	3	main
ja	doc_491521502142_item	2604890	et	3	main
kaaslaste	doc_491521502142_item	2604891	et	4	main
humorikate	doc_491521502142_item	2604893	et	4	main
teise	doc_491521502142_item	2604897	et	4	main
ilmselt	doc_491521502142_item	2604901	et	4	main
samas	doc_491521502142_item	2604907	et	4	main
näitas	doc_491521502142_item	2604914	et	3	main
erinevalt	doc_491521502142_item	2604920	et	4	main
on	doc_491521502142_item	2604927	et	4	main
mõtelda	doc_491521502142_item	2604934	et	4	main
esmaemotsioonide	doc_491521502142_item	2604940	et	3	main
järgi	doc_491521502142_item	2604941	et	4	main
filmi	doc_491521502142_item	2604942	et	4	main
kohta	doc_491521502142_item	2604945	et	4	main
kindlasti	doc_491521502142_item	2604947	et	3	main
seda	doc_491521502142_item	2604958	et	3	main
sügav	doc_491521502142_item	2604961	et	4	main
ning	doc_491521502142_item	2604963	et	3	main
ei	doc_491521502142_item	2604975	et	4	main
kedagi	doc_491521502142_item	2604977	et	4	main
see	doc_491521502142_item	2604981	et	3	main
silma	doc_491521502142_item	2604984	et	4	main
tuua	doc_491521502142_item	2604985	et	3	main
jõudes	doc_491521502142_item	2604986	et	3	main
arvan	doc_491521502142_item	2605000	et	3	main
selliseid	doc_491521502142_item	2605006	et	4	main
esikohal	doc_491521502142_item	2605023	et	4	main
nimed	doc_491521502142_item	2605047	et	3	main
essee	doc_491521502143_item	2605056	et	4	main
mulle	doc_491521502143_item	2605061	et	4	main
esilinastunud	doc_491521502143_item	2605062	et	4	main
samanimelise	doc_491521502143_item	2605063	et	4	main
lavastajaks	doc_491521502143_item	2605070	et	4	main
oli	doc_491521502143_item	2605071	et	3	main
võib-olla	doc_491521502143_item	2605078	et	3	main
filmi	doc_491521502143_item	2605082	et	4	main
vaatama	doc_491521502143_item	2605083	et	3	main
suured	doc_491521502143_item	2605086	et	3	main
enne	doc_491521502143_item	2605095	et	4	main
taevani	doc_491521502143_item	2605103	et	3	main
siiani	doc_491521502143_item	2605121	et	4	main
kas	doc_491521502143_item	2605124	et	3	main
eestlased	doc_491521502143_item	2605125	et	3	main
teevad	doc_491521502143_item	2605126	et	3	main
siis	doc_491521502143_item	2605127	et	3	main
niivõrd	doc_491521502143_item	2605128	et	3	main
viletsaid	doc_491521502143_item	2605129	et	3	main
filme	doc_491521502143_item	2605130	et	3	main
hea	doc_491521502143_item	2605131	et	4	main
tõesti	doc_491521502143_item	2605138	et	3	main
igal	doc_491521502143_item	2605141	et	3	main
peab	doc_491521502143_item	2605143	et	4	main
ise	doc_491521502143_item	2605145	et	4	main
veenduma	doc_491521502143_item	2605146	et	4	main
jõudsin	doc_491521502143_item	2605151	et	3	main
kinno	doc_491521502143_item	2605153	et	3	main
see	doc_491521502143_item	2605157	et	3	main
sündmused	doc_491521502143_item	2605160	et	3	main
nimed	doc_491521502143_item	2605165	et	3	main
romaan	doc_491521502143_item	2605184	et	3	main
omakorda	doc_491521502143_item	2605192	et	3	main
on	doc_491521502143_item	2605200	et	4	main
veendumusega	doc_491521502143_item	2605230	et	4	main
filmi	doc_491521502143_item	2605241	et	4	main
ma	doc_491521502143_item	2605244	et	3	main
võigemasti	doc_491521502143_item	2605248	et	4	main
ahas	doc_491521502143_item	2605250	et	4	main
või	doc_491521502143_item	2605261	et	4	main
inimlikkus	doc_491521502143_item	2605262	et	4	main
rohkem	doc_491521502143_item	2605267	et	4	main
filmis	doc_491521502143_item	2605303	et	4	main
häiris	doc_491521502143_item	2605310	et	3	main
mulje	doc_491521502143_item	2605323	et	4	main
on	doc_491521502143_item	2605325	et	4	main
aga	doc_491521502143_item	2605338	et	3	main
põhjuste	doc_491521502143_item	2605354	et	3	main
ahase	doc_491521502143_item	2605359	et	4	main
haihtus	doc_491521502143_item	2605370	et	3	main
talust	doc_491521502143_item	2605375	et	3	main
ahas	doc_491521502143_item	2605377	et	4	main
lahkus	doc_491521502143_item	2605378	et	4	main
järsku	doc_491521502143_item	2605379	et	4	main
kui	doc_491521502143_item	2605389	et	3	main
inimene	doc_491521502142_item	2604928	et	3	main
nimed	doc_491521502142_item	2604943	et	3	main
paljugi	doc_491521502142_item	2604949	et	4	main
öelda	doc_491521502142_item	2604950	et	4	main
sest	doc_491521502142_item	2604951	et	4	main
minu	doc_491521502142_item	2604952	et	3	main
väärt	doc_491521502142_item	2604959	et	4	main
linateos	doc_491521502142_item	2604974	et	4	main
öelda	doc_491521502142_item	2604989	et	4	main
et	doc_491521502142_item	2604990	et	3	main
selle	doc_491521502142_item	2604993	et	4	main
kangelased	doc_491521502142_item	2604999	et	3	main
kui	doc_491521502142_item	2605002	et	3	main
leiduks	doc_491521502142_item	2605005	et	4	main
ja	doc_491521502142_item	2605008	et	3	main
vapraid	doc_491521502142_item	2605009	et	3	main
nagu	doc_491521502142_item	2605011	et	3	main
seda	doc_491521502142_item	2605012	et	3	main
olid	doc_491521502142_item	2605013	et	4	main
inimesi	doc_491521502142_item	2605010	et	4	main
henn	doc_491521502142_item	2605014	et	4	main
ahas	doc_491521502142_item	2605015	et	4	main
miljan	doc_491521502142_item	2605017	et	4	main
käsper	doc_491521502142_item	2605016	et	4	main
ja	doc_491521502142_item	2605018	et	3	main
teised	doc_491521502142_item	2605019	et	4	main
kelle	doc_491521502142_item	2605020	et	4	main
jaoks	doc_491521502142_item	2605021	et	4	main
rahu	doc_491521502142_item	2605030	et	4	main
elu	doc_491521502142_item	2605034	et	4	main
kõik	doc_491521502142_item	2605042	et	4	main
võimaliku	doc_491521502142_item	2605043	et	3	main
marmortahvlil	doc_491521502143_item	2605058	et	3	main
27022003	doc_491521502143_item	2605060	et	2	main
filmi	doc_491521502143_item	2605067	et	4	main
nimed	doc_491521502143_item	2605068	et	3	main
marmortahvlil	doc_491521502143_item	2605069	et	3	main
meie	doc_491521502143_item	2605073	et	4	main
parimaid	doc_491521502143_item	2605074	et	4	main
teatrilavastajaid	doc_491521502143_item	2605075	et	3	main
sellele	doc_491521502143_item	2605089	et	4	main
filmi	doc_491521502143_item	2605096	et	4	main
ühelt	doc_491521502143_item	2605101	et	3	main
ajal	doc_491521502143_item	2605134	et	4	main
on	doc_491521502143_item	2605135	et	4	main
jäänud	doc_491521502143_item	2605140	et	4	main
juhul	doc_491521502143_item	2605142	et	3	main
avaldada	doc_491521502143_item	2605149	et	3	main
raamat	doc_491521502143_item	2605162	et	3	main
film	doc_491521502143_item	2605164	et	3	main
jutustavad	doc_491521502143_item	2605167	et	4	main
leiavad	doc_491521502143_item	2605168	et	3	main
eesti	doc_491521502143_item	2605170	et	4	main
vabadussõja	doc_491521502143_item	2605171	et	3	main
päevil	doc_491521502143_item	2605172	et	4	main
1918-1920	doc_491521502143_item	2605173	et	2	main
iseloomustab	doc_491521502143_item	2605185	et	4	main
neid	doc_491521502143_item	2605187	et	4	main
mis	doc_491521502143_item	2605190	et	4	main
põhjuseid	doc_491521502143_item	2605196	et	3	main
filmisüžee	doc_491521502143_item	2605207	et	2	main
teatrinäitlejaid	doc_491521502143_item	2605232	et	3	main
paremini	doc_491521502143_item	2605238	et	4	main
saan	doc_491521502143_item	2605243	et	4	main
puudu	doc_491521502143_item	2605257	et	4	main
sära	doc_491521502143_item	2605260	et	4	main
kivikase	doc_491521502143_item	2605269	et	3	main
hinges	doc_491521502143_item	2605272	et	4	main
on	doc_491521502143_item	2605304	et	4	main
on	doc_491521502142_item	2605024	et	4	main
oleks	doc_491521502142_item	2605031	et	3	main
maailma	doc_491521502142_item	2605032	et	4	main
inimeste	doc_491521502142_item	2605033	et	3	main
need	doc_491521502142_item	2605046	et	3	main
ainult	doc_491521502142_item	2605050	et	4	main
ka	doc_491521502142_item	2605053	et	3	main
valminud	doc_491521502143_item	2605066	et	4	main
nüganen	doc_491521502143_item	2605077	et	4	main
minnes	doc_491521502143_item	2605084	et	3	main
omajagu	doc_491521502143_item	2605087	et	3	main
juba	doc_491521502143_item	2605094	et	3	main
valmimust	doc_491521502143_item	2605097	et	4	main
teiselt	doc_491521502143_item	2605104	et	4	main
poolt	doc_491521502143_item	2605105	et	4	main
aga	doc_491521502143_item	2605106	et	3	main
levis	doc_491521502143_item	2605107	et	4	main
jutt	doc_491521502143_item	2605108	et	3	main
kohta	doc_491521502143_item	2605110	et	4	main
eesti	doc_491521502143_item	2605109	et	4	main
päris	doc_491521502143_item	2605111	et	4	main
heast	doc_491521502143_item	2605112	et	3	main
filmist	doc_491521502143_item	2605113	et	4	main
sellest	doc_491521502143_item	2605114	et	4	main
viimasest	doc_491521502143_item	2605115	et	3	main
väitest	doc_491521502143_item	2605116	et	4	main
ei	doc_491521502143_item	2605117	et	4	main
ole	doc_491521502143_item	2605118	et	4	main
ma	doc_491521502143_item	2605119	et	3	main
suutnud	doc_491521502143_item	2605120	et	4	main
küll	doc_491521502143_item	2605132	et	4	main
nii	doc_491521502143_item	2605150	et	3	main
ma	doc_491521502143_item	2605152	et	3	main
juba	doc_491521502143_item	2605154	et	3	main
kohustuslikuks	doc_491521502143_item	2605158	et	3	main
millest	doc_491521502143_item	2605161	et	3	main
ja	doc_491521502143_item	2605163	et	3	main
marmortahvlil	doc_491521502143_item	2605166	et	3	main
filmi	doc_491521502143_item	2605175	et	4	main
täielikult	doc_491521502143_item	2605176	et	4	main
ajalugu	doc_491521502143_item	2605183	et	4	main
põhjalikult	doc_491521502143_item	2605189	et	4	main
suurimpuudus	doc_491521502143_item	2605194	et	4	main
sündmuste	doc_491521502143_item	2605195	et	3	main
tausta	doc_491521502143_item	2605199	et	4	main
väga	doc_491521502143_item	2605201	et	3	main
raske	doc_491521502143_item	2605202	et	4	main
välja	doc_491521502143_item	2605203	et	4	main
tuua	doc_491521502143_item	2605204	et	3	main
seetõttu	doc_491521502143_item	2605205	et	3	main
mis	doc_491521502143_item	2605221	et	4	main
tollal	doc_491521502143_item	2605223	et	3	main
valitsesid	doc_491521502143_item	2605224	et	4	main
osatäitjate	doc_491521502143_item	2605225	et	3	main
eeskätt	doc_491521502143_item	2605242	et	3	main
peaosatäitja	doc_491521502143_item	2605246	et	4	main
tööd	doc_491521502143_item	2605251	et	4	main
teatrilaval	doc_491521502143_item	2605252	et	3	main
ja	doc_491521502143_item	2605253	et	3	main
kinolinal	doc_491521502143_item	2605254	et	3	main
filmis	doc_491521502143_item	2605255	et	4	main
jäi	doc_491521502143_item	2605256	et	3	main
oli	doc_491521502143_item	2605271	et	3	main
noored	doc_491521502143_item	2605306	et	3	main
tegema	doc_491521502142_item	2605041	et	3	main
marmortahvlile	doc_491521502142_item	2605051	et	3	main
vaid	doc_491521502142_item	2605052	et	3	main
nimed	doc_491521502143_item	2605057	et	3	main
essee	doc_491521502143_item	2605059	et	4	main
romaani	doc_491521502143_item	2605064	et	4	main
üks	doc_491521502143_item	2605072	et	3	main
seetõttu	doc_491521502143_item	2605079	et	3	main
ootused	doc_491521502143_item	2605081	et	3	main
ülearu	doc_491521502143_item	2605085	et	3	main
aitas	doc_491521502143_item	2605088	et	3	main
kaasa	doc_491521502143_item	2605090	et	4	main
meediakära	doc_491521502143_item	2605091	et	4	main
ja	doc_491521502143_item	2605092	et	3	main
esilinastust	doc_491521502143_item	2605099	et	3	main
poolt	doc_491521502143_item	2605102	et	4	main
aru	doc_491521502143_item	2605122	et	4	main
saada	doc_491521502143_item	2605123	et	4	main
meie	doc_491521502143_item	2605136	et	4	main
filmitööstus	doc_491521502143_item	2605137	et	3	main
kõiges	doc_491521502143_item	2605144	et	4	main
enne	doc_491521502143_item	2605155	et	4	main
sai	doc_491521502143_item	2605159	et	4	main
aset	doc_491521502143_item	2605169	et	3	main
ja	doc_491521502143_item	2605182	et	3	main
kõiki	doc_491521502143_item	2605186	et	4	main
tegureid	doc_491521502143_item	2605188	et	4	main
filmi	doc_491521502143_item	2605193	et	4	main
osaliste	doc_491521502143_item	2605198	et	4	main
viimasel	doc_491521502143_item	2605133	et	3	main
vinduma	doc_491521502143_item	2605139	et	3	main
e	doc_491521502143_item	2605147	et	4	main
arvamust	doc_491521502143_item	2605148	et	3	main
kui	doc_491521502143_item	2605156	et	3	main
et	doc_491521502143_item	2605174	et	3	main
mõista	doc_491521502143_item	2605177	et	4	main
peab	doc_491521502143_item	2605178	et	4	main
teadma	doc_491521502143_item	2605179	et	3	main
tolleaegset	doc_491521502143_item	2605180	et	3	main
ühiskonnakorraldust	doc_491521502143_item	2605181	et	3	main
on	doc_491521502143_item	2605191	et	4	main
ja	doc_491521502143_item	2605197	et	3	main
on	doc_491521502143_item	2605206	et	4	main
taandunud	doc_491521502143_item	2605208	et	4	main
inimestele	doc_491521502143_item	2605209	et	3	main
ja	doc_491521502143_item	2605210	et	3	main
nendevahelistele	doc_491521502143_item	2605211	et	4	main
suhetele	doc_491521502143_item	2605212	et	3	main
sõjakeerises	doc_491521502143_item	2605213	et	3	main
andes	doc_491521502143_item	2605214	et	4	main
vähe	doc_491521502143_item	2605215	et	3	main
aimu	doc_491521502143_item	2605216	et	4	main
tegelikest	doc_491521502143_item	2605217	et	3	main
pingetest	doc_491521502143_item	2605218	et	4	main
ja	doc_491521502143_item	2605219	et	3	main
lõhestatusest	doc_491521502143_item	2605220	et	4	main
kohta	doc_491521502143_item	2605226	et	4	main
ma	doc_491521502143_item	2605227	et	3	main
ütlen	doc_491521502143_item	2605228	et	3	main
täie	doc_491521502143_item	2605229	et	3	main
on	doc_491521502143_item	2605231	et	4	main
ja	doc_491521502143_item	2605233	et	3	main
inimene	doc_491521502143_item	2605236	et	3	main
sobib	doc_491521502143_item	2605237	et	3	main
teatrilavale	doc_491521502143_item	2605239	et	3	main
priit	doc_491521502143_item	2605247	et	3	main
henn	doc_491521502143_item	2605249	et	4	main
mingi	doc_491521502143_item	2605258	et	4	main
seletamatu	doc_491521502143_item	2605259	et	4	main
tunded	doc_491521502143_item	2605263	et	3	main
just	doc_491521502143_item	2605264	et	3	main
emotsioone	doc_491521502143_item	2605265	et	3	main
oleks	doc_491521502143_item	2605266	et	3	main
ahas	doc_491521502143_item	2605270	et	4	main
enamus	doc_491521502143_item	2605301	et	4	main
näitlejaid	doc_491521502143_item	2605302	et	4	main
nende	doc_491521502143_item	2605313	et	4	main
ebaloomulik	doc_491521502143_item	2605322	et	3	main
ümber	doc_491521502143_item	2605336	et	3	main
kirjutada	doc_491521502143_item	2605337	et	3	main
filmisüžee	doc_491521502143_item	2605342	et	2	main
arusaamatus	doc_491521502143_item	2605344	et	4	main
kohta	doc_491521502143_item	2605355	et	4	main
kui	doc_491521502143_item	2605358	et	3	main
sümpaatia	doc_491521502143_item	2605360	et	4	main
sealt	doc_491521502143_item	2605366	et	4	main
ta	doc_491521502143_item	2605373	et	4	main
enne	doc_491521502143_item	2605385	et	4	main
mõisahoovi	doc_491521502143_item	2605387	et	4	main
näha	doc_491521502143_item	2605390	et	3	main
oleks	doc_491521502143_item	2605421	et	3	main
rolle	doc_491521502143_item	2605423	et	3	main
rongivaritsusest	doc_491521502143_item	2605449	et	4	main
metsa	doc_491521502143_item	2605453	et	4	main
kui	doc_491521502143_item	2605457	et	3	main
oma	doc_491521502143_item	2605467	et	4	main
elu	doc_491521502143_item	2605468	et	4	main
filmi	doc_491521502143_item	2605472	et	4	main
ühiskonnas	doc_491521502143_item	2605222	et	4	main
kinonäitlejaid	doc_491521502143_item	2605234	et	3	main
mõni	doc_491521502143_item	2605235	et	3	main
teine	doc_491521502143_item	2605240	et	3	main
võrrelda	doc_491521502143_item	2605245	et	4	main
oodanud	doc_491521502143_item	2605268	et	4	main
kahekskistud	doc_491521502143_item	2605273	et	4	main
noormees	doc_491521502143_item	2605274	et	4	main
täis	doc_491521502143_item	2605275	et	4	main
südamevalu	doc_491521502143_item	2605276	et	4	main
ja	doc_491521502143_item	2605277	et	3	main
muret	doc_491521502143_item	2605278	et	3	main
venna	doc_491521502143_item	2605279	et	3	main
ja	doc_491521502143_item	2605280	et	3	main
pärast	doc_491521502143_item	2605282	et	4	main
kodumaa	doc_491521502143_item	2605281	et	4	main
ning	doc_491521502143_item	2605283	et	3	main
viha	doc_491521502143_item	2605284	et	4	main
punaarmee	doc_491521502143_item	2605285	et	4	main
vägivalla	doc_491521502143_item	2605286	et	3	main
vastu	doc_491521502143_item	2605287	et	3	main
minu	doc_491521502143_item	2605288	et	3	main
meelest	doc_491521502143_item	2605289	et	4	main
ei	doc_491521502143_item	2605290	et	4	main
mänginud	doc_491521502143_item	2605291	et	4	main
seda	doc_491521502143_item	2605293	et	3	main
võigemast	doc_491521502143_item	2605292	et	4	main
välja	doc_491521502143_item	2605294	et	4	main
võib-olla	doc_491521502143_item	2605295	et	3	main
on	doc_491521502143_item	2605296	et	4	main
asi	doc_491521502143_item	2605297	et	4	main
ka	doc_491521502143_item	2605298	et	3	main
selles	doc_491521502143_item	2605299	et	4	main
et	doc_491521502143_item	2605300	et	3	main
alles	doc_491521502143_item	2605305	et	3	main
ja	doc_491521502143_item	2605307	et	3	main
muuhulgas	doc_491521502143_item	2605311	et	3	main
võime	doc_491521502143_item	2605314	et	4	main
oma	doc_491521502143_item	2605315	et	4	main
jutt	doc_491521502143_item	2605316	et	3	main
justkui	doc_491521502143_item	2605317	et	3	main
paberilt	doc_491521502143_item	2605318	et	3	main
maha	doc_491521502143_item	2605319	et	4	main
vuristada	doc_491521502143_item	2605320	et	3	main
jäi	doc_491521502143_item	2605321	et	3	main
kogenematud	doc_491521502143_item	2605308	et	4	main
ka	doc_491521502143_item	2605312	et	3	main
arusaadav	doc_491521502143_item	2605324	et	4	main
et	doc_491521502143_item	2605326	et	3	main
niivõrd	doc_491521502143_item	2605327	et	3	main
pikka	doc_491521502143_item	2605328	et	4	main
ja	doc_491521502143_item	2605329	et	3	main
sisutihedat	doc_491521502143_item	2605330	et	3	main
raamatut	doc_491521502143_item	2605331	et	3	main
jäi	doc_491521502143_item	2605341	et	3	main
näiteks	doc_491521502143_item	2605356	et	4	main
ja	doc_491521502143_item	2605362	et	3	main
kuhu	doc_491521502143_item	2605364	et	3	main
vaenlase	doc_491521502143_item	2605380	et	3	main
juba	doc_491521502143_item	2605384	et	3	main
ahast	doc_491521502143_item	2605386	et	4	main
jõudis	doc_491521502143_item	2605388	et	3	main
oli	doc_491521502143_item	2605391	et	3	main
miks	doc_491521502143_item	2605441	et	4	main
noori	doc_491521502143_item	2605443	et	3	main
koos	doc_491521502143_item	2605452	et	4	main
jooksevad	doc_491521502143_item	2605456	et	4	main
romaani	doc_491521502143_item	2605458	et	4	main
andsid	doc_491521502143_item	2605466	et	4	main
kes	doc_491521502143_item	2605480	et	4	main
eufoorias	doc_491521502143_item	2605481	et	3	main
lollusi	doc_491521502143_item	2605482	et	4	main
tegema	doc_491521502143_item	2605483	et	3	main
vabastamisse	doc_491521502143_item	2605521	et	4	main
rahva	doc_491521502143_item	2605525	et	3	main
sotsialismi	doc_491521502143_item	2605539	et	4	main
maksma	doc_491521502143_item	2605540	et	3	main
kodanlikku	doc_491521502143_item	2605547	et	4	main
liikumist	doc_491521502143_item	2605550	et	4	main
eesmärk	doc_491521502143_item	2605552	et	3	main
on	doc_491521502143_item	2605553	et	4	main
iseseisev	doc_491521502143_item	2605554	et	3	main
eesti	doc_491521502143_item	2605555	et	4	main
vabariik	doc_491521502143_item	2605556	et	3	main
pooldaks	doc_491521502143_item	2605557	et	3	main
asjade	doc_491521502143_item	2605558	et	3	main
rahumeelset	doc_491521502143_item	2605559	et	3	main
kommunistide	doc_491521502143_item	2605562	et	3	main
pealetungi	doc_491521502143_item	2605563	et	4	main
ja	doc_491521502143_item	2605572	et	3	main
peaeesmärki	doc_491521502143_item	2605574	et	4	main
eesti	doc_491521502143_item	2605576	et	4	main
all	doc_491521502143_item	2605622	et	3	main
kommunistlik	doc_491521502143_item	2605624	et	3	main
vend	doc_491521502143_item	2605641	et	3	main
seotud	doc_491521502143_item	2605643	et	4	main
eriti	doc_491521502143_item	2605660	et	3	main
seetõttu	doc_491521502143_item	2605662	et	3	main
ta	doc_491521502143_item	2605664	et	4	main
äraootavale	doc_491521502143_item	2605665	et	3	main
seisukohale	doc_491521502143_item	2605666	et	4	main
minu	doc_491521502143_item	2605667	et	3	main
meelest	doc_491521502143_item	2605668	et	4	main
pea	doc_491521502143_item	2605675	et	4	main
kokku	doc_491521502143_item	2605677	et	3	main
ning	doc_491521502143_item	2605679	et	3	main
filmi	doc_491521502143_item	2605689	et	4	main
eesmärk	doc_491521502143_item	2605690	et	3	main
ent	doc_491521502143_item	2605309	et	3	main
jaoks	doc_491521502143_item	2605340	et	4	main
andnud	doc_491521502143_item	2605350	et	4	main
mingeid	doc_491521502143_item	2605351	et	3	main
vihjedki	doc_491521502143_item	2605352	et	3	main
sündmuste	doc_491521502143_item	2605353	et	3	main
marta	doc_491521502143_item	2605357	et	4	main
täiesti	doc_491521502143_item	2605367	et	3	main
kuidas	doc_491521502143_item	2605372	et	3	main
kust	doc_491521502143_item	2605376	et	4	main
sattus	doc_491521502143_item	2605382	et	3	main
ja	doc_491521502143_item	2605383	et	3	main
ei	doc_491521502143_item	2605332	et	4	main
saagi	doc_491521502143_item	2605333	et	4	main
sõna-sõnalt	doc_491521502143_item	2605334	et	3	main
stsenaariumiks	doc_491521502143_item	2605335	et	3	main
minu	doc_491521502143_item	2605339	et	3	main
kohati	doc_491521502143_item	2605343	et	4	main
hüples	doc_491521502143_item	2605345	et	3	main
ühelt	doc_491521502143_item	2605346	et	3	main
stseenilt	doc_491521502143_item	2605347	et	3	main
teisele	doc_491521502143_item	2605348	et	4	main
ega	doc_491521502143_item	2605349	et	3	main
väljailmumine	doc_491521502143_item	2605361	et	3	main
kadumise	doc_491521502143_item	2605363	et	4	main
ta	doc_491521502143_item	2605365	et	4	main
lagedalt	doc_491521502143_item	2605368	et	4	main
lahinguväljalt	doc_491521502143_item	2605369	et	3	main
või	doc_491521502143_item	2605371	et	4	main
oma	doc_491521502143_item	2605374	et	4	main
kätte	doc_491521502143_item	2605381	et	4	main
ainult	doc_491521502143_item	2605392	et	4	main
üks	doc_491521502143_item	2605393	et	3	main
liigeldav	doc_491521502143_item	2605394	et	4	main
tee	doc_491521502143_item	2605395	et	4	main
või	doc_491521502143_item	2605396	et	4	main
siis	doc_491521502143_item	2605397	et	3	main
ahase	doc_491521502143_item	2605398	et	4	main
lahkumine	doc_491521502143_item	2605399	et	4	main
mõisast	doc_491521502143_item	2605400	et	4	main
eelnevalt	doc_491521502143_item	2605401	et	4	main
ülemaga	doc_491521502143_item	2605402	et	3	main
kokku	doc_491521502143_item	2605403	et	3	main
leppimata	doc_491521502143_item	2605404	et	4	main
mille	doc_491521502143_item	2605405	et	3	main
eest	doc_491521502143_item	2605406	et	4	main
võib	doc_491521502143_item	2605407	et	3	main
inimese	doc_491521502143_item	2605408	et	4	main
tembeldada	doc_491521502143_item	2605409	et	3	main
desertööriks	doc_491521502143_item	2605410	et	3	main
soomlast	doc_491521502143_item	2605411	et	3	main
kehastanud	doc_491521502143_item	2605412	et	4	main
jaan	doc_491521502143_item	2605413	et	3	main
tätte	doc_491521502143_item	2605414	et	4	main
roll	doc_491521502143_item	2605415	et	3	main
jäi	doc_491521502143_item	2605416	et	3	main
mulle	doc_491521502143_item	2605417	et	4	main
samuti	doc_491521502143_item	2605418	et	3	main
mõistmatuks	doc_491521502143_item	2605419	et	4	main
üldse	doc_491521502143_item	2605420	et	3	main
lahti	doc_491521502143_item	2605425	et	4	main
neid	doc_491521502143_item	2605427	et	4	main
lähemalt	doc_491521502143_item	2605428	et	4	main
tutvustama	doc_491521502143_item	2605429	et	3	main
mõtestama	doc_491521502143_item	2605426	et	3	main
osa	doc_491521502143_item	2605432	et	4	main
lõpp	doc_491521502143_item	2605440	et	3	main
kangelasi	doc_491521502143_item	2605444	et	3	main
kes	doc_491521502143_item	2605447	et	4	main
ilmsest	doc_491521502143_item	2605448	et	3	main
hoolimata	doc_491521502143_item	2605450	et	4	main
alla	doc_491521502143_item	2605454	et	3	main
lõpp	doc_491521502143_item	2605459	et	3	main
neid	doc_491521502143_item	2605461	et	4	main
kangelastena	doc_491521502143_item	2605464	et	4	main
kodumaa	doc_491521502143_item	2605469	et	4	main
pea	doc_491521502143_item	2605477	et	4	main
kaotanud	doc_491521502143_item	2605478	et	4	main
nolke	doc_491521502143_item	2605479	et	3	main
see	doc_491521502143_item	2605486	et	3	main
labastanud	doc_491521502143_item	2605489	et	4	main
kogu	doc_491521502143_item	2605490	et	4	main
patriotismiideed	doc_491521502143_item	2605491	et	4	main
millel	doc_491521502143_item	2605492	et	3	main
film	doc_491521502143_item	2605493	et	3	main
tundub	doc_491521502143_item	2605494	et	3	main
põhinevat	doc_491521502143_item	2605495	et	4	main
lühidalt	doc_491521502143_item	2605496	et	4	main
peategelastest	doc_491521502143_item	2605497	et	4	main
kes	doc_491521502143_item	2605498	et	4	main
annavad	doc_491521502143_item	2605499	et	3	main
ülevaate	doc_491521502143_item	2605500	et	4	main
vabadussõjaaegsest	doc_491521502143_item	2605501	et	3	main
ühiskonnast	doc_491521502143_item	2605502	et	4	main
selle	doc_491521502143_item	2605503	et	4	main
lõhestatusest	doc_491521502143_item	2605504	et	4	main
ja	doc_491521502143_item	2605505	et	3	main
pingetest	doc_491521502143_item	2605506	et	4	main
erinevate	doc_491521502143_item	2605507	et	4	main
klasside	doc_491521502143_item	2605508	et	3	main
vahel	doc_491521502143_item	2605509	et	4	main
käärmer	doc_491521502143_item	2605510	et	4	main
esindab	doc_491521502143_item	2605511	et	3	main
kommunistlikku	doc_491521502143_item	2605512	et	4	main
ideoloogiat	doc_491521502143_item	2605513	et	3	main
usub	doc_491521502143_item	2605514	et	3	main
eesti	doc_491521502143_item	2605515	et	4	main
ja	doc_491521502143_item	2605516	et	3	main
kogu	doc_491521502143_item	2605517	et	4	main
maailma	doc_491521502143_item	2605518	et	4	main
kapitalistlikust	doc_491521502143_item	2605519	et	4	main
ikkest	doc_491521502143_item	2605520	et	4	main
väärt	doc_491521502143_item	2605535	et	4	main
pidanud	doc_491521502143_item	2605422	et	4	main
rohkem	doc_491521502143_item	2605424	et	4	main
tegevuses	doc_491521502143_item	2605433	et	4	main
muutuks	doc_491521502143_item	2605434	et	4	main
arusaadavamaks	doc_491521502143_item	2605435	et	4	main
kõik	doc_491521502143_item	2605451	et	4	main
näitas	doc_491521502143_item	2605460	et	3	main
poisse	doc_491521502143_item	2605462	et	4	main
tõeliste	doc_491521502143_item	2605463	et	4	main
kes	doc_491521502143_item	2605465	et	4	main
siis	doc_491521502143_item	2605471	et	3	main
mitte	doc_491521502143_item	2605487	et	3	main
ie	doc_491521502143_item	2605488	et	4	main
ülemaiilmse	doc_491521502143_item	2605527	et	3	main
ja	doc_491521502143_item	2605529	et	3	main
oleks	doc_491521502143_item	2605532	et	3	main
panna	doc_491521502143_item	2605541	et	4	main
mille	doc_491521502143_item	2605551	et	3	main
käiku	doc_491521502143_item	2605560	et	4	main
tõtu	doc_491521502143_item	2605564	et	3	main
näeb	doc_491521502143_item	2605568	et	3	main
okupeerida	doc_491521502143_item	2605575	et	3	main
esindab	doc_491521502143_item	2605578	et	3	main
soovi	doc_491521502143_item	2605579	et	4	main
leida	doc_491521502143_item	2605580	et	3	main
kuldne	doc_491521502143_item	2605581	et	3	main
kesktee	doc_491521502143_item	2605582	et	4	main
liikumise	doc_491521502143_item	2605585	et	4	main
tähe	doc_491521502143_item	2605621	et	3	main
sissetungiv	doc_491521502143_item	2605623	et	4	main
rahvusluse	doc_491521502143_item	2605626	et	4	main
sotsialismi	doc_491521502143_item	2605628	et	4	main
liit	doc_491521502143_item	2605629	et	3	main
ise	doc_491521502143_item	2605635	et	4	main
samuti	doc_491521502143_item	2605637	et	3	main
töölisklassihulka	doc_491521502143_item	2605638	et	4	main
kommunistidega	doc_491521502143_item	2605644	et	3	main
samas	doc_491521502143_item	2605646	et	4	main
ainuke	doc_491521502143_item	2605669	et	4	main
säilitab	doc_491521502143_item	2605680	et	3	main
terve	doc_491521502143_item	2605681	et	4	main
mõistuse	doc_491521502143_item	2605682	et	3	main
lõpuni	doc_491521502143_item	2605683	et	3	main
kokkuvõtvalt	doc_491521502143_item	2605684	et	4	main
sellest	doc_491521502143_item	2605728	et	4	main
tekkida	doc_491521502143_item	2605729	et	3	main
sest	doc_491521502143_item	2605730	et	4	main
essee	doc_491521502144_item	2605742	et	4	main
kivikase	doc_491521502144_item	2605745	et	3	main
romaan	doc_491521502144_item	2605746	et	3	main
esiteks	doc_491521502144_item	2605749	et	3	main
natuke	doc_491521502144_item	2605752	et	4	main
teose	doc_491521502144_item	2605755	et	3	main
joonealusena	doc_491521502144_item	2605764	et	4	main
1898-1978	doc_491521502144_item	2605768	et	2	main
nimed	doc_491521502144_item	2605770	et	3	main
kiiresti	doc_491521502144_item	2605778	et	3	main
väga	doc_491521502144_item	2605783	et	3	main
juba	doc_491521502144_item	2605785	et	3	main
aastal	doc_491521502144_item	2605787	et	3	main
raamatuna	doc_491521502144_item	2605793	et	4	main
on	doc_491521502144_item	2605801	et	4	main
autori	doc_491521502144_item	2605802	et	3	main
saksa	doc_491521502144_item	2605815	et	4	main
okupatsioonivõimude	doc_491521502144_item	2605816	et	3	main
ja	doc_491521502144_item	2605830	et	3	main
rahvusriiki	doc_491521502144_item	2605835	et	4	main
kas	doc_491521502144_item	2605842	et	3	main
isamaa	doc_491521502144_item	2605848	et	4	main
sellest	doc_491521502144_item	2605856	et	4	main
peategelaseks	doc_491521502144_item	2605860	et	3	main
igaüht	doc_491521502144_item	2605863	et	3	main
on	doc_491521502144_item	2605867	et	4	main
esiplaanile	doc_491521502144_item	2605873	et	4	main
tõsta	doc_491521502144_item	2605876	et	4	main
kelle	doc_491521502144_item	2605878	et	4	main
saatus	doc_491521502144_item	2605879	et	3	main
ja	doc_491521502144_item	2605880	et	3	main
paranemise	doc_491521502144_item	2605914	et	4	main
jääb	doc_491521502144_item	2605916	et	3	main
et	doc_491521502143_item	2605430	et	3	main
nende	doc_491521502143_item	2605431	et	4	main
pettumust	doc_491521502143_item	2605436	et	4	main
valmistas	doc_491521502143_item	2605437	et	3	main
ka	doc_491521502143_item	2605438	et	3	main
filmi	doc_491521502143_item	2605439	et	4	main
kujutati	doc_491521502143_item	2605442	et	4	main
järsku	doc_491521502143_item	2605445	et	4	main
idiootidena	doc_491521502143_item	2605446	et	3	main
urineerima	doc_491521502143_item	2605455	et	3	main
eest	doc_491521502143_item	2605470	et	4	main
lõpp	doc_491521502143_item	2605473	et	3	main
neid	doc_491521502143_item	2605475	et	4	main
hakkasid	doc_491521502143_item	2605484	et	4	main
iseloomustas	doc_491521502143_item	2605474	et	3	main
kui	doc_491521502143_item	2605476	et	3	main
kas	doc_491521502143_item	2605485	et	3	main
punaarmee	doc_491521502143_item	2605522	et	4	main
nimel	doc_491521502143_item	2605531	et	3	main
ohver	doc_491521502143_item	2605536	et	3	main
ühiskonda	doc_491521502143_item	2605548	et	4	main
võimatuks	doc_491521502143_item	2605567	et	4	main
selgelt	doc_491521502143_item	2605569	et	4	main
utoopilisust	doc_491521502143_item	2605571	et	4	main
ahas	doc_491521502143_item	2605577	et	4	main
radikaalse	doc_491521502143_item	2605584	et	3	main
vahel	doc_491521502143_item	2605586	et	4	main
mõlemas	doc_491521502143_item	2605587	et	3	main
tema	doc_491521502143_item	2605639	et	4	main
on	doc_491521502143_item	2605642	et	4	main
kuid	doc_491521502143_item	2605645	et	4	main
leiab	doc_491521502143_item	2605647	et	3	main
ta	doc_491521502143_item	2605648	et	4	main
et	doc_491521502143_item	2605649	et	3	main
peavad	doc_491521502143_item	2605651	et	4	main
jääma	doc_491521502143_item	2605652	et	4	main
iseseisvaks	doc_491521502143_item	2605653	et	3	main
südame	doc_491521502143_item	2605654	et	3	main
ja	doc_491521502143_item	2605655	et	3	main
mõistuse	doc_491521502143_item	2605656	et	3	main
vastuolu	doc_491521502143_item	2605657	et	4	main
teeb	doc_491521502143_item	2605658	et	3	main
otsustamise	doc_491521502143_item	2605659	et	4	main
jääb	doc_491521502143_item	2605663	et	3	main
kes	doc_491521502143_item	2605671	et	4	main
kirgedel	doc_491521502143_item	2605674	et	3	main
kohal	doc_491521502143_item	2605676	et	4	main
võiks	doc_491521502143_item	2605685	et	4	main
filmi	doc_491521502143_item	2605721	et	4	main
kivikase	doc_491521502143_item	2605723	et	3	main
idee	doc_491521502143_item	2605726	et	4	main
võis	doc_491521502143_item	2605727	et	4	main
väljendatud	doc_491521502143_item	2605734	et	4	main
emotsioonid	doc_491521502143_item	2605735	et	3	main
ja	doc_491521502143_item	2605736	et	3	main
pinged	doc_491521502143_item	2605737	et	3	main
teema	doc_491521502144_item	2605743	et	4	main
marmortahvlil	doc_491521502144_item	2605748	et	3	main
tahaksin	doc_491521502144_item	2605751	et	3	main
ja	doc_491521502144_item	2605757	et	3	main
uus	doc_491521502144_item	2605762	et	3	main
kivikase	doc_491521502144_item	2605767	et	3	main
marmortahvlil	doc_491521502144_item	2605771	et	3	main
mille	doc_491521502144_item	2605774	et	3	main
ongi	doc_491521502144_item	2605776	et	4	main
ülikuulsaks	doc_491521502144_item	2605779	et	4	main
aluseks	doc_491521502144_item	2605795	et	4	main
on	doc_491521502144_item	2605796	et	4	main
mis	doc_491521502144_item	2605800	et	4	main
valitseb	doc_491521502144_item	2605805	et	3	main
aastal	doc_491521502144_item	2605810	et	3	main
trükk	doc_491521502144_item	2605812	et	3	main
on	doc_491521502144_item	2605813	et	4	main
tegelikult	doc_491521502144_item	2605814	et	4	main
romaani	doc_491521502144_item	2605819	et	4	main
tegelasteks	doc_491521502144_item	2605824	et	3	main
kes	doc_491521502144_item	2605827	et	4	main
kõhklustest	doc_491521502144_item	2605829	et	3	main
klassivahedest	doc_491521502144_item	2605831	et	3	main
kõrge	doc_491521502144_item	2605840	et	4	main
või	doc_491521502144_item	2605849	et	4	main
jäävad	doc_491521502144_item	2605850	et	4	main
võib	doc_491521502144_item	2605861	et	3	main
panus	doc_491521502144_item	2605870	et	4	main
sõtta	doc_491521502144_item	2605871	et	3	main
lahingud	doc_491521502144_item	2605919	et	3	main
ülikooli	doc_491521502144_item	2605930	et	4	main
liitub	doc_491521502144_item	2605932	et	3	main
ning	doc_491521502144_item	2605934	et	3	main
toob	doc_491521502144_item	2605956	et	3	main
marmortahvlil	doc_491521502144_item	2605962	et	3	main
on	doc_491521502144_item	2605963	et	4	main
on	doc_491521502144_item	2605976	et	4	main
eestisid	doc_491521502144_item	2605980	et	3	main
sotsiaalne	doc_491521502144_item	2605984	et	3	main
abiga	doc_491521502143_item	2605523	et	3	main
eesti	doc_491521502143_item	2605524	et	4	main
hukk	doc_491521502143_item	2605526	et	3	main
rahu	doc_491521502143_item	2605528	et	4	main
klassivõitluse	doc_491521502143_item	2605530	et	3	main
kangelaslik	doc_491521502143_item	2605533	et	3	main
ja	doc_491521502143_item	2605534	et	3	main
ainuõige	doc_491521502143_item	2605537	et	4	main
viis	doc_491521502143_item	2605538	et	4	main
osutub	doc_491521502143_item	2605565	et	3	main
kahe	doc_491521502143_item	2605583	et	3	main
ideoloogias	doc_491521502143_item	2605588	et	3	main
on	doc_491521502143_item	2605589	et	4	main
nii	doc_491521502143_item	2605590	et	3	main
plusse	doc_491521502143_item	2605591	et	3	main
kui	doc_491521502143_item	2605592	et	3	main
ka	doc_491521502143_item	2605593	et	3	main
miinuseid	doc_491521502143_item	2605594	et	3	main
mis	doc_491521502143_item	2605595	et	4	main
takistavad	doc_491521502143_item	2605596	et	4	main
poole	doc_491521502143_item	2605597	et	4	main
valimist	doc_491521502143_item	2605598	et	4	main
ühest	doc_491521502143_item	2605599	et	4	main
küljest	doc_491521502143_item	2605600	et	4	main
tundub	doc_491521502143_item	2605601	et	3	main
et	doc_491521502143_item	2605602	et	3	main
kodanlusel	doc_491521502143_item	2605603	et	4	main
on	doc_491521502143_item	2605604	et	4	main
soov	doc_491521502143_item	2605605	et	3	main
kaitsta	doc_491521502143_item	2605606	et	4	main
vabariigi	doc_491521502143_item	2605607	et	3	main
väljakuulutamisega	doc_491521502143_item	2605608	et	3	main
pigem	doc_491521502143_item	2605609	et	3	main
oma	doc_491521502143_item	2605610	et	4	main
vara	doc_491521502143_item	2605611	et	4	main
kui	doc_491521502143_item	2605612	et	3	main
teenida	doc_491521502143_item	2605613	et	3	main
eesti	doc_491521502143_item	2605614	et	4	main
rahva	doc_491521502143_item	2605615	et	3	main
huvi	doc_491521502143_item	2605616	et	4	main
teisest	doc_491521502143_item	2605617	et	4	main
küljest	doc_491521502143_item	2605618	et	4	main
töölisklassi	doc_491521502143_item	2605619	et	4	main
vabastamise	doc_491521502143_item	2605620	et	4	main
venemaa	doc_491521502143_item	2605625	et	4	main
tundub	doc_491521502143_item	2605630	et	3	main
utoopiline	doc_491521502143_item	2605632	et	3	main
unistus	doc_491521502143_item	2605633	et	4	main
on	doc_491521502143_item	2605542	et	4	main
vägivaldne	doc_491521502143_item	2605543	et	3	main
pealetung	doc_491521502143_item	2605544	et	3	main
käsper	doc_491521502143_item	2605545	et	4	main
esindab	doc_491521502143_item	2605546	et	3	main
marrahvuslikku	doc_491521502143_item	2605549	et	4	main
kuid	doc_491521502143_item	2605561	et	4	main
see	doc_491521502143_item	2605566	et	3	main
kommunismiidee	doc_491521502143_item	2605570	et	4	main
venemaa	doc_491521502143_item	2605573	et	4	main
ja	doc_491521502143_item	2605627	et	3	main
olevat	doc_491521502143_item	2605631	et	4	main
kuulub	doc_491521502143_item	2605636	et	3	main
raskeks	doc_491521502143_item	2605661	et	3	main
ei	doc_491521502143_item	2605672	et	4	main
lase	doc_491521502143_item	2605673	et	4	main
lüüa	doc_491521502143_item	2605678	et	3	main
oli	doc_491521502143_item	2605691	et	3	main
kassarekordite	doc_491521502143_item	2605692	et	3	main
püstitamine	doc_491521502143_item	2605693	et	4	main
filmi	doc_491521502143_item	2605694	et	4	main
kohustuslikuks	doc_491521502143_item	2605695	et	3	main
muutmisega	doc_491521502143_item	2605696	et	4	main
üldhariduskoolides	doc_491521502143_item	2605697	et	3	main
ja	doc_491521502143_item	2605698	et	3	main
siis	doc_491521502143_item	2605700	et	3	main
ilmselt	doc_491521502143_item	2605701	et	4	main
propaganda	doc_491521502143_item	2605699	et	4	main
on	doc_491521502143_item	2605702	et	4	main
eesmärk	doc_491521502143_item	2605703	et	3	main
saavutatud	doc_491521502143_item	2605704	et	4	main
kui	doc_491521502143_item	2605705	et	3	main
aga	doc_491521502143_item	2605706	et	3	main
taheti	doc_491521502143_item	2605707	et	3	main
näidata	doc_491521502143_item	2605708	et	4	main
eesti	doc_491521502143_item	2605709	et	4	main
noorsugu	doc_491521502143_item	2605710	et	4	main
vabadussõjas	doc_491521502143_item	2605711	et	3	main
on	doc_491521502143_item	2605712	et	4	main
film	doc_491521502143_item	2605713	et	3	main
minu	doc_491521502143_item	2605714	et	3	main
meelest	doc_491521502143_item	2605715	et	4	main
läbi	doc_491521502143_item	2605716	et	4	main
kukkunud	doc_491521502143_item	2605717	et	4	main
ma	doc_491521502143_item	2605718	et	3	main
ei	doc_491521502143_item	2605719	et	4	main
nimetaks	doc_491521502143_item	2605720	et	4	main
põhinevat	doc_491521502143_item	2605722	et	4	main
romaanil	doc_491521502143_item	2605724	et	3	main
romaani	doc_491521502143_item	2605731	et	4	main
mõte	doc_491521502143_item	2605732	et	3	main
jutustada	doc_491521502144_item	2605753	et	3	main
ajalehe	doc_491521502144_item	2605761	et	3	main
eesti	doc_491521502144_item	2605763	et	4	main
ilmus	doc_491521502144_item	2605765	et	4	main
baasil	doc_491521502144_item	2605775	et	3	main
film	doc_491521502144_item	2605781	et	3	main
järgmisel	doc_491521502144_item	2605786	et	3	main
esimene	doc_491521502144_item	2605798	et	3	main
väljaanne	doc_491521502144_item	2605799	et	4	main
redigeeritu	doc_491521502144_item	2605804	et	4	main
1942	doc_491521502144_item	2605809	et	2	main
tema	doc_491521502143_item	2605634	et	4	main
vanem	doc_491521502143_item	2605640	et	4	main
eestlased	doc_491521502143_item	2605650	et	3	main
tegelane	doc_491521502143_item	2605670	et	3	main
öelda	doc_491521502143_item	2605686	et	4	main
et	doc_491521502143_item	2605687	et	3	main
kui	doc_491521502143_item	2605688	et	3	main
jäävad	doc_491521502143_item	2605738	et	4	main
filmis	doc_491521502143_item	2605739	et	4	main
tabamatuks	doc_491521502143_item	2605740	et	4	main
esmakordselt1935	doc_491521502144_item	2605759	et	4	main
romaani	doc_491521502144_item	2605769	et	4	main
osa	doc_491521502144_item	2605773	et	4	main
tehtud	doc_491521502144_item	2605777	et	4	main
romaani	doc_491521502144_item	2605789	et	4	main
ka	doc_491521502144_item	2605791	et	3	main
filmi	doc_491521502144_item	2605794	et	4	main
romaani	doc_491521502144_item	2605797	et	4	main
arusaam	doc_491521502144_item	2605806	et	3	main
raamatu	doc_491521502144_item	2605808	et	4	main
poolt	doc_491521502144_item	2605817	et	4	main
on	doc_491521502144_item	2605821	et	4	main
kuigi	doc_491521502143_item	2605725	et	3	main
seal	doc_491521502143_item	2605733	et	4	main
essee	doc_491521502144_item	2605741	et	4	main
albert	doc_491521502144_item	2605744	et	4	main
nimed	doc_491521502144_item	2605747	et	3	main
ma	doc_491521502144_item	2605750	et	3	main
selle	doc_491521502144_item	2605754	et	4	main
ajaloost	doc_491521502144_item	2605756	et	4	main
süžeest	doc_491521502144_item	2605758	et	2	main
aastal	doc_491521502144_item	2605760	et	3	main
albert	doc_491521502144_item	2605766	et	4	main
esimene	doc_491521502144_item	2605772	et	3	main
osutunud	doc_491521502144_item	2605780	et	4	main
meetus	doc_491521502144_item	2605782	et	4	main
populaarseks	doc_491521502144_item	2605784	et	4	main
võis	doc_491521502144_item	2605788	et	4	main
näha	doc_491521502144_item	2605790	et	3	main
eraldi	doc_491521502144_item	2605792	et	4	main
poolt	doc_491521502144_item	2605803	et	4	main
et	doc_491521502144_item	2605807	et	3	main
kärbitud	doc_491521502144_item	2605818	et	4	main
tegevusajaks	doc_491521502144_item	2605820	et	3	main
tartu	doc_491521502144_item	2605825	et	4	main
gümnasistid	doc_491521502144_item	2605826	et	3	main
oma	doc_491521502144_item	2605828	et	4	main
üle	doc_491521502144_item	2605832	et	3	main
kahjuks	doc_491521502144_item	2605837	et	4	main
hind	doc_491521502144_item	2605841	et	3	main
saavad	doc_491521502144_item	2605844	et	4	main
oma	doc_491521502144_item	2605847	et	4	main
mälestuseks	doc_491521502144_item	2605852	et	4	main
vaid	doc_491521502144_item	2605853	et	3	main
nimed	doc_491521502144_item	2605854	et	3	main
marmortahvlil	doc_491521502144_item	2605855	et	3	main
suur	doc_491521502144_item	2605866	et	3	main
nende	doc_491521502144_item	2605868	et	4	main
isiklik	doc_491521502144_item	2605869	et	3	main
võib	doc_491521502144_item	2605874	et	3	main
sõda	doc_491521502144_item	2605921	et	4	main
lugejani	doc_491521502144_item	2605923	et	4	main
ahase	doc_491521502144_item	2605924	et	4	main
sõprade	doc_491521502144_item	2605925	et	3	main
kirjade	doc_491521502144_item	2605926	et	3	main
kaudu	doc_491521502144_item	2605927	et	3	main
1919	doc_491521502144_item	2605942	et	2	main
aasta	doc_491521502144_item	2605943	et	4	main
poliitikaelu	doc_491521502144_item	2605946	et	4	main
teeb	doc_491521502144_item	2605949	et	3	main
ühekülgsuse	doc_491521502144_item	2605959	et	4	main
põhinev	doc_491521502144_item	2605970	et	4	main
vajalik	doc_491521502144_item	2605973	et	3	main
ja	doc_491521502144_item	2605974	et	3	main
mitu	doc_491521502144_item	2605982	et	4	main
ebavõrdsus	doc_491521502144_item	2605985	et	4	main
on	doc_491521502144_item	2605986	et	4	main
kultuurile	doc_491521502144_item	2605992	et	3	main
väga	doc_491521502144_item	2605994	et	3	main
tehtud	doc_491521502144_item	2606000	et	4	main
iseseisvust	doc_491521502144_item	2606021	et	4	main
eesmärki	doc_491521502144_item	2606040	et	4	main
ühtsuse	doc_491521502144_item	2606041	et	4	main
ajal	doc_491521502144_item	2606047	et	4	main
eriti	doc_491521502144_item	2606048	et	3	main
tagajärjest	doc_491521502144_item	2606060	et	4	main
mitte	doc_491521502144_item	2606069	et	3	main
laiendamise	doc_491521502144_item	2606071	et	4	main
sõda	doc_491521502144_item	2606075	et	4	main
vaid	doc_491521502144_item	2606076	et	3	main
oma	doc_491521502144_item	2606078	et	4	main
kodumaad	doc_491521502144_item	2606079	et	4	main
pessimistlik	doc_491521502144_item	2606088	et	3	main
hävitada	doc_491521502144_item	2606124	et	3	main
järgnenud	doc_491521502144_item	2606133	et	4	main
kes	doc_491521502144_item	2606142	et	4	main
käima	doc_491521502144_item	2606147	et	4	main
ja	doc_491521502144_item	2606153	et	3	main
valmis	doc_491521502144_item	2606156	et	4	main
et	doc_491521502144_item	2606161	et	3	main
päris	doc_491521502144_item	2606168	et	4	main
on	doc_491521502144_item	2606174	et	4	main
ilmunud	doc_491521502144_item	2605811	et	4	main
vabadussõda	doc_491521502144_item	2605822	et	4	main
lähevad	doc_491521502144_item	2605834	et	3	main
kaitsma	doc_491521502144_item	2605836	et	3	main
on	doc_491521502144_item	2605838	et	4	main
vabadusel	doc_491521502144_item	2605839	et	4	main
nad	doc_491521502144_item	2605843	et	3	main
on	doc_491521502144_item	2605857	et	4	main
see	doc_491521502144_item	2605858	et	3	main
kuid	doc_491521502144_item	2605872	et	4	main
siiski	doc_491521502144_item	2605875	et	4	main
ahase	doc_491521502144_item	2605877	et	4	main
järel	doc_491521502144_item	2605915	et	4	main
teenima	doc_491521502144_item	2605918	et	3	main
ja	doc_491521502144_item	2605920	et	3	main
asub	doc_491521502144_item	2605929	et	3	main
teine	doc_491521502144_item	2605938	et	3	main
on	doc_491521502144_item	2605940	et	4	main
kultuuri-	doc_491521502144_item	2605944	et	4	main
kajastus	doc_491521502144_item	2605947	et	4	main
teose	doc_491521502144_item	2605950	et	3	main
film	doc_491521502144_item	2605960	et	3	main
albert	doc_491521502144_item	2605964	et	4	main
kivikase	doc_491521502144_item	2605965	et	3	main
samanimelise	doc_491521502144_item	2605966	et	4	main
romaani	doc_491521502144_item	2605967	et	4	main
esimesel	doc_491521502144_item	2605968	et	3	main
osal	doc_491521502144_item	2605969	et	3	main
tänapäeval	doc_491521502144_item	2605978	et	3	main
on	doc_491521502144_item	2605981	et	4	main
ja	doc_491521502144_item	2605983	et	3	main
oluline	doc_491521502144_item	2605995	et	4	main
raamatu	doc_491521502144_item	2605998	et	4	main
kes	doc_491521502144_item	2606027	et	4	main
surid	doc_491521502144_item	2606028	et	4	main
oma	doc_491521502144_item	2606029	et	4	main
kodumaa	doc_491521502144_item	2606030	et	4	main
sellele	doc_491521502144_item	2606034	et	4	main
on	doc_491521502144_item	2606050	et	4	main
just	doc_491521502144_item	2606056	et	3	main
mille	doc_491521502144_item	2606059	et	3	main
sõltus	doc_491521502144_item	2606061	et	4	main
terve	doc_491521502144_item	2606062	et	4	main
rahva	doc_491521502144_item	2606063	et	3	main
tulevik	doc_491521502144_item	2606064	et	3	main
saatus	doc_491521502144_item	2606065	et	3	main
see	doc_491521502144_item	2606066	et	3	main
ei	doc_491521502144_item	2606067	et	4	main
territooriumi	doc_491521502144_item	2606070	et	4	main
nimel	doc_491521502144_item	2606072	et	3	main
valla	doc_491521502144_item	2606073	et	4	main
kaitsta	doc_491521502144_item	2606082	et	4	main
sõja	doc_491521502144_item	2606083	et	3	main
käigus	doc_491521502144_item	2606084	et	4	main
valitses	doc_491521502144_item	2606085	et	3	main
rahva	doc_491521502144_item	2606086	et	3	main
hulgas	doc_491521502144_item	2606087	et	4	main
lasknud	doc_491521502144_item	2606123	et	4	main
juurdusid	doc_491521502144_item	2606135	et	4	main
inimesi	doc_491521502144_item	2606141	et	4	main
vindunud	doc_491521502144_item	2606145	et	4	main
näitlejad	doc_491521502144_item	2606152	et	4	main
filmi	doc_491521502144_item	2606164	et	4	main
minu	doc_491521502144_item	2606171	et	3	main
rohkem	doc_491521502144_item	2606175	et	4	main
tükk	doc_491521502144_item	2606179	et	3	main
ei	doc_491521502144_item	2606181	et	4	main
mitte	doc_491521502144_item	2606183	et	3	main
romantiline	doc_491521502144_item	2606185	et	3	main
lugu	doc_491521502144_item	2606186	et	4	main
elas	doc_491521502144_item	2606221	et	3	main
elas	doc_491521502144_item	2606228	et	3	main
ja	doc_491521502144_item	2606232	et	3	main
sõbrad	doc_491521502144_item	2606235	et	3	main
vaenlase	doc_491521502144_item	2606237	et	3	main
tähendab	doc_491521502144_item	2606243	et	3	main
väga	doc_491521502144_item	2606250	et	3	main
ma	doc_491521502144_item	2606252	et	3	main
põhjal	doc_491521502144_item	2606261	et	4	main
ausalt	doc_491521502144_item	2606262	et	4	main
öeldes	doc_491521502144_item	2606263	et	3	main
ma	doc_491521502144_item	2606264	et	3	main
ja	doc_491521502144_item	2605823	et	3	main
saades	doc_491521502144_item	2605833	et	3	main
tasuks	doc_491521502144_item	2605845	et	4	main
armastuse	doc_491521502144_item	2605846	et	4	main
neist	doc_491521502144_item	2605851	et	4	main
lugu	doc_491521502144_item	2605859	et	4	main
pidada	doc_491521502144_item	2605862	et	4	main
kangelastest	doc_491521502144_item	2605864	et	4	main
nii	doc_491521502144_item	2605865	et	3	main
armastus	doc_491521502144_item	2605881	et	4	main
oli	doc_491521502144_item	2605882	et	3	main
tihedalt	doc_491521502144_item	2605883	et	4	main
seotud	doc_491521502144_item	2605884	et	4	main
antud	doc_491521502144_item	2605885	et	4	main
vabadussõja	doc_491521502144_item	2605886	et	3	main
perioodiga	doc_491521502144_item	2605887	et	3	main
tahaks	doc_491521502144_item	2605888	et	3	main
öelda	doc_491521502144_item	2605889	et	4	main
et	doc_491521502144_item	2605890	et	3	main
nimed	doc_491521502144_item	2605891	et	3	main
marmortahvlil	doc_491521502144_item	2605892	et	3	main
kuulub	doc_491521502144_item	2605893	et	3	main
eesti	doc_491521502144_item	2605894	et	4	main
elu	doc_491521502144_item	2605895	et	4	main
kõige	doc_491521502144_item	2605896	et	4	main
enam	doc_491521502144_item	2605897	et	4	main
mõjutanud	doc_491521502144_item	2605898	et	4	main
raamatute	doc_491521502144_item	2605899	et	3	main
hulka	doc_491521502144_item	2605900	et	4	main
romaani	doc_491521502144_item	2605901	et	4	main
1948	doc_491521502144_item	2605902	et	2	main
aastal	doc_491521502144_item	2605903	et	3	main
ilmunud	doc_491521502144_item	2605904	et	4	main
teise	doc_491521502144_item	2605905	et	4	main
osa	doc_491521502144_item	2605906	et	4	main
sündmused	doc_491521502144_item	2605907	et	3	main
toimuvad	doc_491521502144_item	2605908	et	4	main
vabadussõjaaegses	doc_491521502144_item	2605909	et	3	main
tartus	doc_491521502144_item	2605910	et	3	main
kuhu	doc_491521502144_item	2605911	et	3	main
ahas	doc_491521502144_item	2605912	et	4	main
haavadest	doc_491521502144_item	2605913	et	3	main
jõuavad	doc_491521502144_item	2605922	et	4	main
ta	doc_491521502144_item	2605931	et	4	main
boheemkonnaga	doc_491521502144_item	2605933	et	3	main
temast	doc_491521502144_item	2605935	et	3	main
kirjanik	doc_491521502144_item	2605937	et	3	main
edasiandmine	doc_491521502144_item	2605955	et	3	main
nimed	doc_491521502144_item	2605961	et	3	main
kui	doc_491521502144_item	2605979	et	3	main
jõudsalt	doc_491521502144_item	2605987	et	4	main
kasvamas	doc_491521502144_item	2605988	et	3	main
arvates	doc_491521502144_item	2605990	et	4	main
staabikirjutajana	doc_491521502144_item	2605917	et	3	main
ahas	doc_491521502144_item	2605928	et	4	main
saab	doc_491521502144_item	2605936	et	3	main
köide	doc_491521502144_item	2605939	et	4	main
peamiselt	doc_491521502144_item	2605941	et	4	main
ja	doc_491521502144_item	2605945	et	3	main
see	doc_491521502144_item	2605948	et	3	main
huvitavaks	doc_491521502144_item	2605951	et	4	main
kuid	doc_491521502144_item	2605952	et	4	main
sündmuste	doc_491521502144_item	2605953	et	3	main
kroonikali	doc_491521502144_item	2605954	et	4	main
kaasa	doc_491521502144_item	2605957	et	4	main
stiililise	doc_491521502144_item	2605958	et	4	main
mängufilm	doc_491521502144_item	2605971	et	3	main
eriti	doc_491521502144_item	2605972	et	3	main
päevakohane	doc_491521502144_item	2605975	et	4	main
film	doc_491521502144_item	2605977	et	3	main
minu	doc_491521502144_item	2605989	et	3	main
rahvuslikule	doc_491521502144_item	2605991	et	3	main
kui	doc_491521502144_item	2605996	et	3	main
põhjal	doc_491521502144_item	2605999	et	4	main
korralik	doc_491521502144_item	2606001	et	3	main
kinotükk	doc_491521502144_item	2606002	et	3	main
tõstab	doc_491521502144_item	2606003	et	3	main
rahva	doc_491521502144_item	2606004	et	3	main
ühtsustunnet	doc_491521502144_item	2606005	et	3	main
see	doc_491521502144_item	2606006	et	3	main
mängufilm	doc_491521502144_item	2606007	et	3	main
sunnib	doc_491521502144_item	2606008	et	3	main
inimesi	doc_491521502144_item	2606009	et	4	main
vabaduse	doc_491521502144_item	2606010	et	4	main
hinna	doc_491521502144_item	2606011	et	3	main
üle	doc_491521502144_item	2606012	et	3	main
mõtlema	doc_491521502144_item	2606013	et	3	main
ning	doc_491521502144_item	2606014	et	3	main
austama	doc_491521502144_item	2606015	et	3	main
neid	doc_491521502144_item	2606016	et	4	main
kes	doc_491521502144_item	2606017	et	4	main
püüdsid	doc_491521502144_item	2606018	et	4	main
kinkida	doc_491521502144_item	2606019	et	3	main
vabariigile	doc_491521502144_item	2606020	et	3	main
kõik	doc_491521502144_item	2606022	et	4	main
peavad	doc_491521502144_item	2606023	et	4	main
meeles	doc_491521502144_item	2606024	et	3	main
pidama	doc_491521502144_item	2606025	et	4	main
kangelasi	doc_491521502144_item	2606026	et	3	main
eesti	doc_491521502144_item	2606031	et	4	main
et	doc_491521502144_item	2606035	et	3	main
on	doc_491521502144_item	2606043	et	4	main
väga	doc_491521502144_item	2606044	et	3	main
tähtis	doc_491521502144_item	2606045	et	4	main
meie	doc_491521502144_item	2606046	et	4	main
et	doc_491521502144_item	2606052	et	3	main
on	doc_491521502144_item	2606055	et	4	main
sõjast	doc_491521502144_item	2606058	et	3	main
vaenlase	doc_491521502144_item	2606080	et	3	main
eest	doc_491521502144_item	2606081	et	4	main
vabatahtlikud	doc_491521502144_item	2606121	et	3	main
olulisemat	doc_491521502144_item	2606126	et	4	main
teadvust	doc_491521502144_item	2606128	et	4	main
iseseisvusele	doc_491521502144_item	2606131	et	4	main
iseseisvusaastatel	doc_491521502144_item	2606134	et	4	main
on	doc_491521502144_item	2605993	et	4	main
seesuguse	doc_491521502144_item	2605997	et	3	main
isegi	doc_491521502144_item	2606032	et	4	main
vaatamata	doc_491521502144_item	2606033	et	4	main
ei	doc_491521502144_item	2606037	et	4	main
oma	doc_491521502144_item	2606039	et	4	main
see	doc_491521502144_item	2606051	et	3	main
jutt	doc_491521502144_item	2606054	et	3	main
vabadussõjast	doc_491521502144_item	2606057	et	3	main
olnud	doc_491521502144_item	2606068	et	4	main
päästatud	doc_491521502144_item	2606074	et	4	main
ja	doc_491521502144_item	2606089	et	3	main
ei	doc_491521502144_item	2606122	et	4	main
nad	doc_491521502144_item	2606036	et	3	main
saavutanud	doc_491521502144_item	2606038	et	4	main
tunne	doc_491521502144_item	2606042	et	4	main
oluline	doc_491521502144_item	2606049	et	4	main
filmis	doc_491521502144_item	2606053	et	4	main
katse	doc_491521502144_item	2606077	et	4	main
kaitseväe	doc_491521502144_item	2606091	et	3	main
eesti	doc_491521502144_item	2606090	et	4	main
võimetes	doc_491521502144_item	2606092	et	4	main
kahtlev	doc_491521502144_item	2606093	et	4	main
meeleolu	doc_491521502144_item	2606094	et	4	main
inimesed	doc_491521502144_item	2606095	et	3	main
mõtlesid	doc_491521502144_item	2606096	et	4	main
et	doc_491521502144_item	2606097	et	3	main
las	doc_491521502144_item	2606098	et	4	main
neid	doc_491521502144_item	2606099	et	4	main
kaitsevad	doc_491521502144_item	2606100	et	4	main
teised	doc_491521502144_item	2606101	et	4	main
riigid	doc_491521502144_item	2606102	et	3	main
kes	doc_491521502144_item	2606103	et	4	main
neist	doc_491521502144_item	2606104	et	4	main
huvitatud	doc_491521502144_item	2606105	et	4	main
on	doc_491521502144_item	2606106	et	4	main
sõjategevuse	doc_491521502144_item	2606107	et	4	main
vastu	doc_491521502144_item	2606108	et	3	main
oli	doc_491521502144_item	2606109	et	3	main
ka	doc_491521502144_item	2606110	et	3	main
osa	doc_491521502144_item	2606111	et	4	main
roogi	doc_491521502144_item	2606112	et	4	main
juhtivtegelastest	doc_491521502144_item	2606113	et	4	main
mis	doc_491521502144_item	2606114	et	4	main
omakorda	doc_491521502144_item	2606115	et	3	main
avaldas	doc_491521502144_item	2606116	et	3	main
mõju	doc_491521502144_item	2606117	et	4	main
kogu	doc_491521502144_item	2606118	et	4	main
rahvale	doc_491521502144_item	2606119	et	3	main
ainult	doc_491521502144_item	2606120	et	4	main
kõige	doc_491521502144_item	2606125	et	4	main
eestluse	doc_491521502144_item	2606127	et	4	main
ja	doc_491521502144_item	2606129	et	3	main
tungi	doc_491521502144_item	2606130	et	4	main
hinge	doc_491521502144_item	2606137	et	4	main
aastaid	doc_491521502144_item	2606144	et	4	main
lavastaja	doc_491521502144_item	2606151	et	4	main
saigi	doc_491521502144_item	2606155	et	4	main
prominendid	doc_491521502144_item	2606157	et	3	main
kohta	doc_491521502144_item	2606165	et	4	main
hea	doc_491521502144_item	2606169	et	4	main
film	doc_491521502144_item	2606173	et	3	main
päris	doc_491521502144_item	2606177	et	4	main
ole	doc_491521502144_item	2606182	et	4	main
mis	doc_491521502144_item	2606132	et	4	main
projekti	doc_491521502144_item	2606146	et	4	main
leidsid	doc_491521502144_item	2606148	et	4	main
raha	doc_491521502144_item	2606149	et	4	main
kaasrahastajad	doc_491521502144_item	2606150	et	4	main
film	doc_491521502144_item	2606154	et	3	main
käisid	doc_491521502144_item	2606158	et	4	main
ja	doc_491521502144_item	2606159	et	3	main
ikkagi	doc_491521502144_item	2606162	et	4	main
eesti	doc_491521502144_item	2606163	et	4	main
tükk	doc_491521502144_item	2606170	et	3	main
noortest	doc_491521502144_item	2606188	et	4	main
vaid	doc_491521502144_item	2606189	et	3	main
hingepõhjani	doc_491521502144_item	2606190	et	3	main
liigutav	doc_491521502144_item	2606191	et	4	main
draama	doc_491521502144_item	2606192	et	4	main
noortest	doc_491521502144_item	2606193	et	4	main
kangelastest	doc_491521502144_item	2606194	et	4	main
kes	doc_491521502144_item	2606195	et	4	main
vabatahtlikult	doc_491521502144_item	2606196	et	4	main
lähevad	doc_491521502144_item	2606197	et	3	main
vabadussõtta	doc_491521502144_item	2606198	et	3	main
ja	doc_491521502144_item	2606199	et	3	main
sõdurite	doc_491521502144_item	2606200	et	3	main
kõrval	doc_491521502144_item	2606201	et	4	main
asuvad	doc_491521502144_item	2606202	et	4	main
kodumaa	doc_491521502144_item	2606203	et	4	main
nimel	doc_491521502144_item	2606204	et	3	main
võitlusse	doc_491521502144_item	2606205	et	3	main
kaitstes	doc_491521502144_item	2606206	et	3	main
oma	doc_491521502144_item	2606207	et	4	main
maad	doc_491521502144_item	2606208	et	4	main
ja	doc_491521502144_item	2606209	et	3	main
aateid	doc_491521502144_item	2606210	et	3	main
pärast	doc_491521502144_item	2606211	et	4	main
filmi	doc_491521502144_item	2606212	et	4	main
vaatamist	doc_491521502144_item	2606213	et	4	main
tekkib	doc_491521502144_item	2606214	et	3	main
vaatajal	doc_491521502144_item	2606215	et	4	main
niisugune	doc_491521502144_item	2606216	et	3	main
tunne	doc_491521502144_item	2606217	et	4	main
et	doc_491521502144_item	2606218	et	3	main
ta	doc_491521502144_item	2606219	et	4	main
ise	doc_491521502144_item	2606220	et	4	main
tema	doc_491521502144_item	2606234	et	4	main
kuulide	doc_491521502144_item	2606238	et	3	main
all	doc_491521502144_item	2606239	et	3	main
arvates	doc_491521502144_item	2606241	et	4	main
põnevaks	doc_491521502144_item	2606251	et	3	main
ajalooromaani	doc_491521502144_item	2606260	et	4	main
eestlase	doc_491521502144_item	2606136	et	3	main
tore	doc_491521502144_item	2606138	et	3	main
et	doc_491521502144_item	2606139	et	3	main
leidus	doc_491521502144_item	2606140	et	4	main
vedasid	doc_491521502144_item	2606143	et	4	main
kiitsid	doc_491521502144_item	2606160	et	4	main
on	doc_491521502144_item	2606166	et	4	main
see	doc_491521502144_item	2606167	et	3	main
arvates	doc_491521502144_item	2606172	et	4	main
hea	doc_491521502144_item	2606178	et	4	main
see	doc_491521502144_item	2606180	et	3	main
kui	doc_491521502144_item	2606176	et	3	main
ajal	doc_491521502144_item	2606224	et	4	main
koos	doc_491521502144_item	2606226	et	4	main
just	doc_491521502144_item	2606233	et	3	main
minu	doc_491521502144_item	2606240	et	3	main
see	doc_491521502144_item	2606242	et	3	main
ja	doc_491521502144_item	2606249	et	3	main
mis	doc_491521502144_item	2606257	et	4	main
see	doc_491521502144_item	2606288	et	3	main
harva	doc_491521502144_item	2606291	et	4	main
meil	doc_491521502144_item	2606325	et	4	main
nendega	doc_491521502144_item	2606328	et	4	main
on	doc_491521502145_item	2606338	et	4	main
sündinud	doc_491521502145_item	2606339	et	4	main
uus	doc_491521502145_item	2606340	et	3	main
selle	doc_491521502145_item	2606344	et	4	main
elmo	doc_491521502145_item	2606354	et	4	main
nüganeni	doc_491521502145_item	2606355	et	4	main
ja	doc_491521502145_item	2606356	et	3	main
kristian	doc_491521502145_item	2606357	et	4	main
nimed	doc_491521502145_item	2606360	et	3	main
eesti	doc_491521502145_item	2606362	et	4	main
film	doc_491521502145_item	2606364	et	3	main
eestis	doc_491521502145_item	2606370	et	3	main
tänaseks	doc_491521502145_item	2606381	et	4	main
koha	doc_491521502145_item	2606385	et	4	main
kirjanduses	doc_491521502145_item	2606387	et	3	main
kivikas	doc_491521502145_item	2606389	et	4	main
oli	doc_491521502145_item	2606390	et	3	main
sündinud	doc_491521502145_item	2606391	et	4	main
1898	doc_491521502145_item	2606392	et	2	main
aastal	doc_491521502145_item	2606393	et	3	main
ja	doc_491521502145_item	2606394	et	3	main
suri	doc_491521502145_item	2606395	et	3	main
80	doc_491521502145_item	2606396	et	2	main
kes	doc_491521502145_item	2606421	et	4	main
koolipingist	doc_491521502145_item	2606423	et	3	main
asusid	doc_491521502145_item	2606425	et	4	main
panid	doc_491521502145_item	2606435	et	4	main
torni	doc_491521502145_item	2606439	et	4	main
siin	doc_491521502145_item	2606450	et	4	main
sõtta	doc_491521502145_item	2606455	et	3	main
kui	doc_491521502145_item	2606459	et	3	main
siis	doc_491521502145_item	2606461	et	3	main
eest	doc_491521502145_item	2606463	et	4	main
sõdida	doc_491521502145_item	2606464	et	3	main
kuid	doc_491521502145_item	2606465	et	4	main
vägivalda	doc_491521502145_item	2606523	et	4	main
hukkumist	doc_491521502145_item	2606528	et	4	main
selles	doc_491521502145_item	2606532	et	4	main
ei	doc_491521502145_item	2606534	et	4	main
tulista	doc_491521502145_item	2606535	et	4	main
vabaduse	doc_491521502145_item	2606548	et	4	main
eest	doc_491521502145_item	2606549	et	4	main
läbi	doc_491521502145_item	2606560	et	4	main
minu	doc_491521502145_item	2606561	et	3	main
väga	doc_491521502145_item	2606565	et	3	main
ajalooline	doc_491521502145_item	2606567	et	4	main
film	doc_491521502145_item	2606572	et	3	main
ka	doc_491521502145_item	2606578	et	3	main
olen	doc_491521502145_item	2606583	et	3	main
rahul	doc_491521502145_item	2606585	et	4	main
selle	doc_491521502145_item	2606586	et	4	main
filmiga	doc_491521502145_item	2606587	et	3	main
kui	doc_491521502145_item	2606588	et	3	main
ahas	doc_491521502145_item	2606589	et	4	main
põrkas	doc_491521502145_item	2606590	et	3	main
kasvas	doc_491521502145_item	2606599	et	3	main
armastuseni	doc_491521502145_item	2606600	et	4	main
vältel	doc_491521502145_item	2606605	et	4	main
me	doc_491521502145_item	2606606	et	4	main
võime	doc_491521502145_item	2606607	et	4	main
said	doc_491521502145_item	2606629	et	4	main
jäid	doc_491521502145_item	2606639	et	4	main
ainult	doc_491521502145_item	2606640	et	4	main
marmortahvlil	doc_491521502145_item	2606642	et	3	main
on	doc_491521502145_item	2606650	et	4	main
rahvuslikult	doc_491521502145_item	2606653	et	4	main
kasulikku	doc_491521502145_item	2606661	et	4	main
ka	doc_491521502145_item	2606662	et	3	main
sain	doc_491521502145_item	2606663	et	3	main
võõrus	doc_491521502146_item	2606698	et	4	main
banaalne	doc_491521502144_item	2606184	et	3	main
eesti	doc_491521502144_item	2606187	et	4	main
raskel	doc_491521502144_item	2606223	et	3	main
kõik	doc_491521502144_item	2606229	et	4	main
üle	doc_491521502144_item	2606231	et	3	main
hukkusid	doc_491521502144_item	2606236	et	4	main
film	doc_491521502144_item	2606245	et	3	main
välja	doc_491521502144_item	2606247	et	4	main
realistlikuks	doc_491521502144_item	2606248	et	3	main
oodanudki	doc_491521502144_item	2606254	et	4	main
filmist	doc_491521502144_item	2606256	et	4	main
originaali	doc_491521502144_item	2606267	et	4	main
lugenud	doc_491521502144_item	2606268	et	4	main
kuid	doc_491521502144_item	2606269	et	4	main
film	doc_491521502144_item	2606270	et	3	main
jättis	doc_491521502144_item	2606271	et	3	main
mulle	doc_491521502144_item	2606272	et	4	main
juhtub	doc_491521502144_item	2606276	et	3	main
mingit	doc_491521502144_item	2606279	et	3	main
inimene	doc_491521502144_item	2606283	et	3	main
minuga	doc_491521502144_item	2606287	et	3	main
väga	doc_491521502144_item	2606290	et	3	main
loodan	doc_491521502144_item	2606321	et	3	main
varsti	doc_491521502144_item	2606323	et	3	main
jälle	doc_491521502144_item	2606327	et	3	main
euroopa	doc_491521502145_item	2606336	et	4	main
kaardile	doc_491521502145_item	2606337	et	3	main
vabariik	doc_491521502145_item	2606343	et	3	main
me	doc_491521502145_item	2606351	et	4	main
kõiki	doc_491521502145_item	2606367	et	4	main
taasiseseisvunud	doc_491521502145_item	2606369	et	4	main
on	doc_491521502145_item	2606373	et	4	main
sõjafilm	doc_491521502145_item	2606375	et	3	main
kivikase	doc_491521502145_item	2606377	et	3	main
sisse	doc_491521502145_item	2606383	et	4	main
aastasena	doc_491521502145_item	2606397	et	4	main
eest	doc_491521502145_item	2606428	et	4	main
võitlusesse	doc_491521502145_item	2606429	et	4	main
raekoja	doc_491521502145_item	2606438	et	3	main
seda	doc_491521502145_item	2606441	et	3	main
kokku	doc_491521502145_item	2606444	et	3	main
tääekr	doc_491521502145_item	2606449	et	4	main
kas	doc_491521502145_item	2606453	et	3	main
või	doc_491521502145_item	2606456	et	4	main
ja	doc_491521502145_item	2606458	et	3	main
selle	doc_491521502145_item	2606480	et	4	main
pataljoni	doc_491521502145_item	2606481	et	4	main
kaasakiskuv	doc_491521502145_item	2606511	et	4	main
alguses	doc_491521502145_item	2606513	et	4	main
mõtlesin	doc_491521502145_item	2606515	et	3	main
see	doc_491521502145_item	2606517	et	3	main
kus	doc_491521502145_item	2606521	et	3	main
kuid	doc_491521502145_item	2606531	et	4	main
filmis	doc_491521502145_item	2606533	et	4	main
romantiline	doc_491521502145_item	2606571	et	3	main
naljakaid	doc_491521502145_item	2606576	et	4	main
kohti	doc_491521502145_item	2606580	et	4	main
ma	doc_491521502145_item	2606582	et	3	main
nende	doc_491521502145_item	2606595	et	4	main
tutvus	doc_491521502145_item	2606596	et	4	main
mis	doc_491521502145_item	2606597	et	4	main
hiljem	doc_491521502145_item	2606598	et	3	main
nii	doc_491521502145_item	2606601	et	3	main
et	doc_491521502145_item	2606602	et	3	main
kogu	doc_491521502145_item	2606603	et	4	main
olid	doc_491521502145_item	2606623	et	4	main
hästi	doc_491521502145_item	2606624	et	3	main
lahingus	doc_491521502145_item	2606626	et	3	main
vabaduse	doc_491521502145_item	2606627	et	4	main
eest	doc_491521502145_item	2606628	et	4	main
surma	doc_491521502145_item	2606630	et	4	main
poisid	doc_491521502145_item	2606634	et	4	main
ahase	doc_491521502145_item	2606636	et	4	main
kõikidest	doc_491521502145_item	2606637	et	4	main
koolipoistest	doc_491521502145_item	2606638	et	3	main
et	doc_491521502145_item	2606648	et	3	main
palju	doc_491521502145_item	2606664	et	4	main
teada	doc_491521502145_item	2606665	et	3	main
vabadussõja	doc_491521502145_item	2606666	et	3	main
kohta	doc_491521502145_item	2606667	et	4	main
ja	doc_491521502145_item	2606668	et	3	main
tol	doc_491521502144_item	2606222	et	3	main
sõdis	doc_491521502144_item	2606225	et	3	main
peategelastega	doc_491521502144_item	2606227	et	3	main
sõjahirmud	doc_491521502144_item	2606230	et	3	main
et	doc_491521502144_item	2606244	et	3	main
tuli	doc_491521502144_item	2606246	et	4	main
ei	doc_491521502144_item	2606253	et	4	main
seda	doc_491521502144_item	2606255	et	3	main
on	doc_491521502144_item	2606258	et	4	main
loodud	doc_491521502144_item	2606259	et	4	main
ole	doc_491521502144_item	2606266	et	4	main
kaasa	doc_491521502144_item	2606284	et	4	main
elama	doc_491521502144_item	2606285	et	3	main
tegelastega	doc_491521502144_item	2606286	et	3	main
juhtub	doc_491521502144_item	2606289	et	3	main
aga	doc_491521502144_item	2606292	et	3	main
nimed	doc_491521502144_item	2606293	et	3	main
marmortahvlil	doc_491521502144_item	2606294	et	3	main
sundis	doc_491521502144_item	2606295	et	3	main
mind	doc_491521502144_item	2606296	et	4	main
nutma	doc_491521502144_item	2606298	et	3	main
ja	doc_491521502144_item	2606299	et	3	main
peaaegu	doc_491521502144_item	2606297	et	3	main
mul	doc_491521502144_item	2606300	et	3	main
tekkis	doc_491521502144_item	2606301	et	3	main
soov	doc_491521502144_item	2606302	et	3	main
lugeda	doc_491521502144_item	2606303	et	3	main
romaani	doc_491521502144_item	2606304	et	4	main
ma	doc_491521502144_item	2606305	et	3	main
arvan	doc_491521502144_item	2606306	et	3	main
et	doc_491521502144_item	2606307	et	3	main
see	doc_491521502144_item	2606308	et	3	main
on	doc_491521502144_item	2606309	et	4	main
režissööri	doc_491521502144_item	2606310	et	2	main
täisedu	doc_491521502144_item	2606311	et	4	main
kohe	doc_491521502144_item	2606312	et	4	main
tekkib	doc_491521502144_item	2606313	et	3	main
huvi	doc_491521502144_item	2606314	et	4	main
mis	doc_491521502144_item	2606315	et	4	main
filmi	doc_491521502144_item	2606316	et	4	main
peategelastest	doc_491521502144_item	2606317	et	4	main
hiljem	doc_491521502144_item	2606318	et	3	main
edasi	doc_491521502144_item	2606319	et	3	main
sai	doc_491521502144_item	2606320	et	4	main
et	doc_491521502144_item	2606322	et	3	main
kokku	doc_491521502144_item	2606329	et	3	main
essee	doc_491521502145_item	2606331	et	4	main
nimed	doc_491521502145_item	2606332	et	3	main
marmortahvlil	doc_491521502145_item	2606333	et	3	main
aasta	doc_491521502145_item	2606334	et	4	main
1918	doc_491521502145_item	2606335	et	2	main
saame	doc_491521502145_item	2606352	et	4	main
teada	doc_491521502145_item	2606353	et	3	main
ei	doc_491521502144_item	2606265	et	4	main
mulje	doc_491521502144_item	2606274	et	4	main
nii	doc_491521502144_item	2606277	et	3	main
filmi	doc_491521502144_item	2606280	et	4	main
vaadates	doc_491521502144_item	2606281	et	3	main
hakkab	doc_491521502144_item	2606282	et	3	main
on	doc_491521502144_item	2606324	et	4	main
saada	doc_491521502144_item	2606330	et	4	main
riik	doc_491521502145_item	2606341	et	3	main
nimel	doc_491521502145_item	2606345	et	3	main
sõtta	doc_491521502145_item	2606347	et	3	main
koolipoisid	doc_491521502145_item	2606349	et	4	main
sellest	doc_491521502145_item	2606350	et	4	main
filmist	doc_491521502145_item	2606359	et	4	main
marmortahvlil	doc_491521502145_item	2606361	et	3	main
vabadussõjast	doc_491521502145_item	2606363	et	3	main
marmortahvlil	doc_491521502145_item	2606372	et	3	main
põhjal	doc_491521502145_item	2606379	et	4	main
mis	doc_491521502145_item	2606380	et	4	main
kindla	doc_491521502145_item	2606384	et	3	main
ta	doc_491521502145_item	2606398	et	4	main
unustamatu	doc_491521502144_item	2606273	et	4	main
tihti	doc_491521502144_item	2606275	et	3	main
et	doc_491521502144_item	2606278	et	3	main
võimalus	doc_491521502144_item	2606326	et	3	main
eesti	doc_491521502145_item	2606342	et	4	main
lähevad	doc_491521502145_item	2606346	et	3	main
sõduritega	doc_491521502145_item	2606348	et	3	main
kassarekordeid	doc_491521502145_item	2606368	et	3	main
nimed	doc_491521502145_item	2606371	et	3	main
albert	doc_491521502145_item	2606376	et	4	main
võttis	doc_491521502145_item	2606382	et	3	main
eesti	doc_491521502145_item	2606386	et	4	main
albert	doc_491521502145_item	2606388	et	4	main
kirjutas	doc_491521502145_item	2606399	et	3	main
rohkem	doc_491521502145_item	2606400	et	4	main
realistlikke	doc_491521502145_item	2606401	et	3	main
jutte	doc_491521502145_item	2606402	et	3	main
ja	doc_491521502145_item	2606403	et	3	main
üks	doc_491521502145_item	2606404	et	3	main
tema	doc_491521502145_item	2606405	et	4	main
viimastest	doc_491521502145_item	2606406	et	3	main
ja	doc_491521502145_item	2606407	et	3	main
teostest	doc_491521502145_item	2606408	et	3	main
oligi	doc_491521502145_item	2606409	et	3	main
romaan	doc_491521502145_item	2606410	et	3	main
nimed	doc_491521502145_item	2606411	et	3	main
marmortahvlil	doc_491521502145_item	2606412	et	3	main
tegevusajaks	doc_491521502145_item	2606413	et	3	main
on	doc_491521502145_item	2606414	et	4	main
vabadussõda	doc_491521502145_item	2606415	et	4	main
ja	doc_491521502145_item	2606416	et	3	main
peategelased	doc_491521502145_item	2606417	et	3	main
on	doc_491521502145_item	2606418	et	4	main
tartu	doc_491521502145_item	2606419	et	4	main
koolipoisid	doc_491521502145_item	2606420	et	4	main
lipu	doc_491521502145_item	2606437	et	3	main
peale	doc_491521502145_item	2606440	et	4	main
said	doc_491521502145_item	2606442	et	4	main
nad	doc_491521502145_item	2606443	et	3	main
arutlevad	doc_491521502145_item	2606452	et	4	main
minna	doc_491521502145_item	2606454	et	3	main
minna	doc_491521502145_item	2606460	et	3	main
välja	doc_491521502145_item	2606469	et	4	main
tartu	doc_491521502145_item	2606470	et	4	main
koolipoiste	doc_491521502145_item	2606471	et	3	main
pataljon	doc_491521502145_item	2606472	et	3	main
ajaloos	doc_491521502145_item	2606475	et	4	main
erilisel	doc_491521502145_item	2606478	et	4	main
kohal	doc_491521502145_item	2606479	et	4	main
film	doc_491521502145_item	2606512	et	3	main
ma	doc_491521502145_item	2606514	et	3	main
on	doc_491521502145_item	2606518	et	4	main
järjekordne	doc_491521502145_item	2606519	et	3	main
film	doc_491521502145_item	2606520	et	3	main
taska	doc_491521502145_item	2606358	et	4	main
on	doc_491521502145_item	2606365	et	4	main
löömas	doc_491521502145_item	2606366	et	4	main
emotsionaalne	doc_491521502145_item	2606374	et	3	main
romaani	doc_491521502145_item	2606378	et	4	main
ja	doc_491521502145_item	2606424	et	3	main
riigi	doc_491521502145_item	2606426	et	3	main
iseseisvuse	doc_491521502145_item	2606427	et	4	main
eesti	doc_491521502145_item	2606436	et	4	main
kohlapuu	doc_491521502145_item	2606447	et	4	main
martinson	doc_491521502145_item	2606448	et	4	main
kelle	doc_491521502145_item	2606462	et	4	main
lõpuks	doc_491521502145_item	2606466	et	4	main
mis	doc_491521502145_item	2606473	et	4	main
ja	doc_491521502145_item	2606477	et	3	main
et	doc_491521502145_item	2606516	et	3	main
näidatakse	doc_491521502145_item	2606522	et	3	main
ainult	doc_491521502145_item	2606524	et	4	main
inimeste	doc_491521502145_item	2606527	et	3	main
ja	doc_491521502145_item	2606529	et	3	main
piinamist	doc_491521502145_item	2606530	et	4	main
võitlevad	doc_491521502145_item	2606544	et	4	main
oma	doc_491521502145_item	2606545	et	4	main
meelest	doc_491521502145_item	2606562	et	4	main
huvitav	doc_491521502145_item	2606566	et	4	main
ja	doc_491521502145_item	2606568	et	3	main
filmis	doc_491521502145_item	2606573	et	4	main
kui	doc_491521502145_item	2606577	et	3	main
kurbi	doc_491521502145_item	2606579	et	4	main
seetõttu	doc_491521502145_item	2606581	et	3	main
tõusid	doc_491521502145_item	2606422	et	4	main
film	doc_491521502145_item	2606430	et	3	main
algab	doc_491521502145_item	2606431	et	3	main
sellega	doc_491521502145_item	2606432	et	3	main
et	doc_491521502145_item	2606433	et	3	main
koolipoisid	doc_491521502145_item	2606434	et	4	main
ahas	doc_491521502145_item	2606445	et	4	main
käsper	doc_491521502145_item	2606446	et	4	main
nad	doc_491521502145_item	2606451	et	3	main
mitte	doc_491521502145_item	2606457	et	3	main
ikkagi	doc_491521502145_item	2606467	et	4	main
kujuneb	doc_491521502145_item	2606468	et	3	main
eesti	doc_491521502145_item	2606474	et	4	main
tähtsal	doc_491521502145_item	2606476	et	3	main
organiseerumist	doc_491521502145_item	2606482	et	4	main
kodumaa	doc_491521502145_item	2606483	et	4	main
kaitseks	doc_491521502145_item	2606484	et	4	main
algas	doc_491521502145_item	2606485	et	3	main
kapten	doc_491521502145_item	2606486	et	3	main
oskar	doc_491521502145_item	2606487	et	4	main
eller	doc_491521502145_item	2606488	et	4	main
algul	doc_491521502145_item	2606489	et	4	main
pataljon	doc_491521502145_item	2606490	et	3	main
lahingutegevuses	doc_491521502145_item	2606491	et	4	main
oli	doc_491521502145_item	2606492	et	3	main
ebakindel	doc_491521502145_item	2606493	et	3	main
kuid	doc_491521502145_item	2606494	et	4	main
poisid	doc_491521502145_item	2606495	et	4	main
kiiresti	doc_491521502145_item	2606496	et	3	main
omandasid	doc_491521502145_item	2606497	et	4	main
lahingulise	doc_491521502145_item	2606498	et	4	main
karastuse	doc_491521502145_item	2606499	et	4	main
meeldis	doc_491521502145_item	2606501	et	3	main
mulle	doc_491521502145_item	2606500	et	4	main
see	doc_491521502145_item	2606502	et	3	main
film	doc_491521502145_item	2606503	et	3	main
nimed	doc_491521502145_item	2606504	et	3	main
marmortahvlil	doc_491521502145_item	2606505	et	3	main
oli	doc_491521502145_item	2606506	et	3	main
tõesti	doc_491521502145_item	2606507	et	3	main
huvitav	doc_491521502145_item	2606508	et	4	main
põnev	doc_491521502145_item	2606509	et	3	main
ja	doc_491521502145_item	2606510	et	3	main
sõdimise	doc_491521502145_item	2606525	et	4	main
ning	doc_491521502145_item	2606526	et	3	main
tappa	doc_491521502145_item	2606537	et	4	main
niisama	doc_491521502145_item	2606539	et	3	main
nagu	doc_491521502145_item	2606540	et	3	main
enamikkes	doc_491521502145_item	2606541	et	3	main
filmides	doc_491521502145_item	2606542	et	4	main
vaid	doc_491521502145_item	2606543	et	3	main
ja	doc_491521502145_item	2606547	et	3	main
romaan	doc_491521502145_item	2606550	et	3	main
kujutab	doc_491521502145_item	2606551	et	3	main
sõda	doc_491521502145_item	2606552	et	4	main
ja	doc_491521502145_item	2606553	et	3	main
tollaseid	doc_491521502145_item	2606554	et	3	main
olusid	doc_491521502145_item	2606555	et	3	main
nagu	doc_491521502145_item	2606556	et	3	main
sõdurite	doc_491521502145_item	2606557	et	3	main
koolipoiste	doc_491521502145_item	2606558	et	3	main
silme	doc_491521502145_item	2606559	et	4	main
on	doc_491521502145_item	2606564	et	4	main
isegi	doc_491521502145_item	2606569	et	4	main
natuke	doc_491521502145_item	2606570	et	4	main
oli	doc_491521502145_item	2606574	et	3	main
ootamatult	doc_491521502145_item	2606591	et	4	main
martaga	doc_491521502145_item	2606592	et	4	main
kokku	doc_491521502145_item	2606593	et	3	main
armastuse	doc_491521502145_item	2606609	et	4	main
lugu	doc_491521502145_item	2606610	et	4	main
ka	doc_491521502145_item	2606621	et	3	main
kõik	doc_491521502145_item	2606631	et	4	main
peale	doc_491521502145_item	2606635	et	4	main
nimed	doc_491521502145_item	2606641	et	3	main
vajalik	doc_491521502145_item	2606651	et	3	main
film	doc_491521502145_item	2606652	et	3	main
arvatavasti	doc_491521502146_item	2606696	et	3	main
ja	doc_491521502146_item	2606699	et	3	main
ajaloo	doc_491521502146_item	2606702	et	4	main
ja	doc_491521502146_item	2606708	et	3	main
seiklusrikas	doc_491521502146_item	2606709	et	4	main
võibolla	doc_491521502146_item	2606712	et	4	main
huvitavgi	doc_491521502146_item	2606714	et	4	main
see	doc_491521502146_item	2606725	et	3	main
veel	doc_491521502146_item	2606734	et	4	main
ka	doc_491521502146_item	2606743	et	3	main
kujutatud	doc_491521502146_item	2606751	et	4	main
seda	doc_491521502146_item	2606759	et	3	main
et	doc_491521502146_item	2606791	et	3	main
saada	doc_491521502146_item	2606797	et	4	main
kui	doc_491521502146_item	2606801	et	3	main
välismaal	doc_491521502146_item	2606815	et	4	main
huvitav	doc_491521502146_item	2606816	et	4	main
see	doc_491521502146_item	2606818	et	3	main
hoopis	doc_491521502146_item	2606822	et	3	main
olen	doc_491521502146_item	2606827	et	3	main
kangekaelse	doc_491521502146_item	2606830	et	3	main
kinnisena	doc_491521502146_item	2606833	et	4	main
lõbusa	doc_491521502146_item	2606835	et	3	main
toimunud	doc_491521502146_item	2606853	et	4	main
eestis	doc_491521502146_item	2606854	et	3	main
siis	doc_491521502146_item	2606855	et	3	main
ju	doc_491521502146_item	2606861	et	3	main
eestipärane	doc_491521502146_item	2606863	et	4	main
ka	doc_491521502146_item	2606867	et	3	main
päris	doc_491521502146_item	2606869	et	4	main
selline	doc_491521502146_item	2606872	et	4	main
lenin	doc_491521502146_item	2606921	et	4	main
nii	doc_491521502146_item	2606923	et	3	main
ka	doc_491521502146_item	2606926	et	3	main
käiku	doc_491521502146_item	2606933	et	4	main
mis	doc_491521502146_item	2606936	et	4	main
ajas	doc_491521502146_item	2606943	et	4	main
segadusse	doc_491521502146_item	2606945	et	3	main
kes	doc_491521502146_item	2606946	et	4	main
oli	doc_491521502146_item	2606947	et	3	main
on	doc_491521502146_item	2606955	et	4	main
kuidas	doc_491521502146_item	2606989	et	3	main
ta	doc_491521502146_item	2606990	et	4	main
huvides	doc_491521502146_item	2606997	et	3	main
ära	doc_491521502146_item	2606998	et	4	main
kasutas	doc_491521502146_item	2606999	et	3	main
näitab	doc_491521502146_item	2607000	et	3	main
ega	doc_491521502145_item	2606536	et	3	main
inimesed	doc_491521502145_item	2606538	et	3	main
kodumaa	doc_491521502145_item	2606546	et	4	main
see	doc_491521502145_item	2606563	et	3	main
nii	doc_491521502145_item	2606575	et	3	main
täitsa	doc_491521502145_item	2606584	et	3	main
algas	doc_491521502145_item	2606594	et	3	main
filmi	doc_491521502145_item	2606604	et	4	main
jälgida	doc_491521502145_item	2606608	et	3	main
meeldis	doc_491521502145_item	2606611	et	3	main
ka	doc_491521502145_item	2606612	et	3	main
see	doc_491521502145_item	2606613	et	3	main
et	doc_491521502145_item	2606614	et	3	main
filmi	doc_491521502145_item	2606615	et	4	main
pilt	doc_491521502145_item	2606616	et	3	main
oli	doc_491521502145_item	2606617	et	3	main
minu	doc_491521502145_item	2606618	et	3	main
meelest	doc_491521502145_item	2606619	et	4	main
kvaliteetne	doc_491521502145_item	2606620	et	3	main
1	doc_491521502145_item	2606632	et	2	main
see	doc_491521502145_item	2606649	et	3	main
mis	doc_491521502145_item	2606655	et	4	main
rahva	doc_491521502145_item	2606656	et	3	main
ühtsustunnet	doc_491521502145_item	2606657	et	3	main
kinnitab	doc_491521502145_item	2606658	et	3	main
sain	doc_491521502145_item	2606659	et	3	main
sellest	doc_491521502145_item	2606660	et	4	main
essee	doc_491521502146_item	2606671	et	4	main
põhjuseks	doc_491521502146_item	2606695	et	3	main
vähene	doc_491521502146_item	2606701	et	4	main
mulle	doc_491521502146_item	2606717	et	4	main
osatäitjad	doc_491521502145_item	2606622	et	3	main
valitud	doc_491521502145_item	2606625	et	4	main
pataljoni	doc_491521502145_item	2606633	et	4	main
vabadusel	doc_491521502145_item	2606643	et	4	main
oli	doc_491521502145_item	2606644	et	3	main
kõrge	doc_491521502145_item	2606645	et	4	main
hind	doc_491521502145_item	2606646	et	3	main
arvan	doc_491521502145_item	2606647	et	3	main
kinokultuurile	doc_491521502145_item	2606654	et	3	main
minu	doc_491521502146_item	2606672	et	3	main
leninid	doc_491521502146_item	2606673	et	4	main
loomulikult	doc_491521502146_item	2606674	et	4	main
oli	doc_491521502146_item	2606675	et	3	main
huvitav	doc_491521502146_item	2606676	et	4	main
jälgida	doc_491521502146_item	2606677	et	3	main
kuidas	doc_491521502146_item	2606678	et	3	main
eestlased	doc_491521502146_item	2606679	et	3	main
on	doc_491521502146_item	2606680	et	4	main
läänelikku	doc_491521502146_item	2606681	et	4	main
elu	doc_491521502146_item	2606682	et	4	main
kujutanud	doc_491521502146_item	2606683	et	4	main
kuna	doc_491521502146_item	2606684	et	3	main
nägin	doc_491521502146_item	2606685	et	3	main
filmi	doc_491521502146_item	2606686	et	4	main
esimest	doc_491521502146_item	2606687	et	4	main
korda	doc_491521502146_item	2606688	et	4	main
siis	doc_491521502146_item	2606689	et	3	main
seda	doc_491521502146_item	2606690	et	3	main
mõista	doc_491521502146_item	2606691	et	4	main
polnud	doc_491521502146_item	2606692	et	3	main
sugugi	doc_491521502146_item	2606693	et	4	main
kerge	doc_491521502146_item	2606694	et	4	main
tollasest	doc_491521502145_item	2606669	et	3	main
olukorrast	doc_491521502145_item	2606670	et	4	main
ajastu	doc_491521502146_item	2606697	et	4	main
ka	doc_491521502146_item	2606700	et	3	main
tundmine	doc_491521502146_item	2606703	et	4	main
muidu	doc_491521502146_item	2606704	et	3	main
oli	doc_491521502146_item	2606705	et	3	main
täitsa	doc_491521502146_item	2606706	et	3	main
humoorikas	doc_491521502146_item	2606707	et	4	main
meeldis	doc_491521502146_item	2606718	et	3	main
hardi	doc_491521502146_item	2606720	et	4	main
näiteks	doc_491521502146_item	2606731	et	4	main
pole	doc_491521502146_item	2606732	et	3	main
ma	doc_491521502146_item	2606733	et	3	main
üksküla	doc_491521502146_item	2606741	et	4	main
üldilme	doc_491521502146_item	2606744	et	4	main
räpast	doc_491521502146_item	2606754	et	4	main
võiks	doc_491521502146_item	2606757	et	4	main
võibolla	doc_491521502146_item	2606758	et	4	main
vahelt	doc_491521502146_item	2606780	et	4	main
või	doc_491521502146_item	2606782	et	4	main
tausta	doc_491521502146_item	2606783	et	4	main
tunda	doc_491521502146_item	2606784	et	3	main
et	doc_491521502146_item	2606785	et	3	main
ja	doc_491521502146_item	2606798	et	3	main
mõtet	doc_491521502146_item	2606799	et	3	main
tabada	doc_491521502146_item	2606800	et	3	main
et	doc_491521502146_item	2606819	et	3	main
harjunud	doc_491521502146_item	2606826	et	4	main
kuivõrd	doc_491521502146_item	2606834	et	3	main
seiklushimulise	doc_491521502146_item	2606836	et	4	main
optimistlikuna	doc_491521502146_item	2606838	et	3	main
intiimstseenid	doc_491521502146_item	2606840	et	3	main
mulle	doc_491521502146_item	2606842	et	4	main
ei	doc_491521502146_item	2606856	et	4	main
film	doc_491521502146_item	2606860	et	3	main
ehk	doc_491521502146_item	2606874	et	3	main
ise	doc_491521502146_item	2606922	et	4	main
kui	doc_491521502146_item	2606925	et	3	main
abikaasana	doc_491521502146_item	2606927	et	3	main
nende	doc_491521502146_item	2606928	et	4	main
võltsleninite	doc_491521502146_item	2606929	et	4	main
oligi	doc_491521502146_item	2606935	et	3	main
kesküla	doc_491521502146_item	2606969	et	4	main
eesti	doc_491521502146_item	2606972	et	4	main
päritolu	doc_491521502146_item	2606973	et	4	main
poliitik	doc_491521502146_item	2606974	et	3	main
läbi	doc_491521502146_item	2606975	et	4	main
unistuseks	doc_491521502146_item	2606978	et	4	main
loomine	doc_491521502146_item	2606982	et	4	main
impeeriumi	doc_491521502146_item	2606985	et	4	main
hävitamine	doc_491521502146_item	2606987	et	4	main
see	doc_491521502146_item	2606988	et	3	main
eesti	doc_491521502146_item	2606996	et	4	main
mängu	doc_491521502146_item	2607008	et	4	main
oma	doc_491521502146_item	2607011	et	4	main
kesküla	doc_491521502146_item	2607016	et	4	main
tegelikult	doc_491521502146_item	2607018	et	4	main
selline	doc_491521502146_item	2607019	et	4	main
oli	doc_491521502146_item	2607020	et	3	main
ajalooline	doc_491521502146_item	2606710	et	4	main
pisut	doc_491521502146_item	2606713	et	3	main
mis	doc_491521502146_item	2606715	et	4	main
selle	doc_491521502146_item	2606719	et	4	main
volmeri	doc_491521502146_item	2606721	et	4	main
juures	doc_491521502146_item	2606723	et	4	main
et	doc_491521502146_item	2606726	et	3	main
olid	doc_491521502146_item	2606728	et	4	main
tuntud	doc_491521502146_item	2606729	et	4	main
eestlased	doc_491521502146_item	2606730	et	3	main
varem	doc_491521502146_item	2606735	et	4	main
abikaasa	doc_491521502146_item	2606742	et	4	main
halli	doc_491521502146_item	2606752	et	4	main
suurtele	doc_491521502146_item	2606761	et	3	main
arvan	doc_491521502146_item	2606790	et	3	main
kindlasti	doc_491521502146_item	2606794	et	3	main
raskem	doc_491521502146_item	2606795	et	4	main
aru	doc_491521502146_item	2606796	et	4	main
vanast	doc_491521502146_item	2606807	et	3	main
filmitudvustusest	doc_491521502146_item	2606808	et	4	main
suurt	doc_491521502146_item	2606812	et	3	main
müügiedu	doc_491521502146_item	2606813	et	4	main
ka	doc_491521502146_item	2606814	et	3	main
oli	doc_491521502146_item	2606817	et	3	main
eestlast	doc_491521502146_item	2606820	et	4	main
mitte	doc_491521502146_item	2606828	et	3	main
tulid	doc_491521502146_item	2606841	et	4	main
üllatusena	doc_491521502146_item	2606843	et	4	main
aga	doc_491521502146_item	2606844	et	3	main
samas	doc_491521502146_item	2606845	et	4	main
mille	doc_491521502146_item	2606846	et	3	main
üle	doc_491521502146_item	2606847	et	3	main
tohtinud	doc_491521502146_item	2606858	et	4	main
väga	doc_491521502146_item	2606862	et	3	main
ollagi	doc_491521502146_item	2606864	et	3	main
kindlasti	doc_491521502146_item	2606866	et	3	main
segu	doc_491521502146_item	2606873	et	4	main
kujutus	doc_491521502146_item	2606876	et	4	main
milline	doc_491521502146_item	2606878	et	3	main
võis	doc_491521502146_item	2606879	et	4	main
elu	doc_491521502146_item	2606880	et	4	main
kunagi	doc_491521502146_item	2606881	et	3	main
olla	doc_491521502146_item	2606882	et	3	main
põnevust	doc_491521502146_item	2606883	et	4	main
üks	doc_491521502146_item	2606888	et	3	main
teisikutest	doc_491521502146_item	2606889	et	4	main
üks	doc_491521502146_item	2606893	et	3	main
film	doc_491521502146_item	2606711	et	3	main
siis	doc_491521502146_item	2606716	et	3	main
kunstiteose	doc_491521502146_item	2606722	et	3	main
kõigepealt	doc_491521502146_item	2606724	et	3	main
osades	doc_491521502146_item	2606727	et	3	main
filmi	doc_491521502146_item	2606736	et	4	main
elektrat	doc_491521502146_item	2606739	et	4	main
näinud	doc_491521502146_item	2606740	et	4	main
oli	doc_491521502146_item	2606745	et	3	main
rõõmsam	doc_491521502146_item	2606747	et	4	main
kirevam	doc_491521502146_item	2606749	et	4	main
ei	doc_491521502146_item	2606750	et	4	main
et	doc_491521502146_item	2606760	et	3	main
ridade	doc_491521502146_item	2606779	et	3	main
lugeda	doc_491521502146_item	2606781	et	3	main
noortel	doc_491521502146_item	2606792	et	3	main
vanematel	doc_491521502146_item	2606803	et	4	main
lugesin	doc_491521502146_item	2606805	et	3	main
ühest	doc_491521502146_item	2606806	et	4	main
et	doc_491521502146_item	2606809	et	3	main
teosele	doc_491521502146_item	2606810	et	3	main
loodeti	doc_491521502146_item	2606811	et	3	main
teistsugusena	doc_491521502146_item	2606823	et	3	main
mina	doc_491521502146_item	2606825	et	4	main
jonnaka	doc_491521502146_item	2606831	et	3	main
ka	doc_491521502146_item	2606839	et	3	main
tegevus	doc_491521502146_item	2606851	et	4	main
ei	doc_491521502146_item	2606852	et	4	main
oleks	doc_491521502146_item	2606857	et	3	main
see	doc_491521502146_item	2606859	et	3	main
aga	doc_491521502146_item	2606865	et	3	main
mitte	doc_491521502146_item	2606868	et	3	main
läänelik	doc_491521502146_item	2606870	et	4	main
pigem	doc_491521502146_item	2606871	et	3	main
tekitas	doc_491521502146_item	2606884	et	3	main
see	doc_491521502146_item	2606885	et	3	main
teisikute	doc_491521502146_item	2606886	et	3	main
jant	doc_491521502146_item	2606887	et	3	main
oli	doc_491521502146_item	2606890	et	3	main
hulluksläinud	doc_491521502146_item	2606891	et	4	main
elektrik	doc_491521502146_item	2606892	et	3	main
poliitiku	doc_491521502146_item	2606924	et	3	main
koolitamine	doc_491521502146_item	2606931	et	4	main
filmi	doc_491521502146_item	2606937	et	4	main
minu	doc_491521502146_item	2606938	et	3	main
arvates	doc_491521502146_item	2606939	et	4	main
kes	doc_491521502146_item	2606948	et	4	main
neist	doc_491521502146_item	2606951	et	4	main
see	doc_491521502146_item	2606952	et	3	main
aegade	doc_491521502146_item	2606976	et	3	main
oli	doc_491521502146_item	2606979	et	3	main
suur-eesti	doc_491521502146_item	2606980	et	4	main
riigi	doc_491521502146_item	2606981	et	3	main
venemaa	doc_491521502146_item	2606993	et	4	main
vahelist	doc_491521502146_item	2606994	et	4	main
pusklemist	doc_491521502146_item	2606995	et	4	main
pani	doc_491521502146_item	2607007	et	4	main
unistusi	doc_491521502146_item	2607012	et	4	main
viia	doc_491521502146_item	2607014	et	3	main
nagu	doc_491521502146_item	2607021	et	3	main
kujutati	doc_491521502146_item	2607023	et	4	main
et	doc_491521502146_item	2607030	et	3	main
ei	doc_491521502146_item	2607031	et	4	main
häiris	doc_491521502146_item	2607047	et	3	main
ka	doc_491521502146_item	2607049	et	3	main
pähetuubitud	doc_491521502146_item	2607052	et	4	main
emotsioonideta	doc_491521502146_item	2607057	et	3	main
need	doc_491521502146_item	2607060	et	3	main
vast	doc_491521502146_item	2607062	et	3	main
oluline	doc_491521502146_item	2607070	et	4	main
keel	doc_491521502146_item	2607073	et	4	main
ei	doc_491521502146_item	2607088	et	4	main
see	doc_491521502146_item	2607090	et	3	main
midagi	doc_491521502146_item	2607093	et	4	main
sellist	doc_491521502146_item	2607094	et	4	main
mis	doc_491521502146_item	2607095	et	4	main
näide	doc_491521502146_item	2607102	et	3	main
noortele	doc_491521502146_item	2607105	et	3	main
ja	doc_491521502146_item	2607108	et	3	main
mehi	doc_491521502146_item	2607110	et	3	main
hiljuti	doc_491521502147_item	2607119	et	4	main
filmi	doc_491521502147_item	2607124	et	4	main
ekraanil	doc_491521502146_item	2606737	et	3	main
dj	doc_491521502146_item	2606738	et	4	main
palju	doc_491521502146_item	2606746	et	4	main
ja	doc_491521502146_item	2606748	et	3	main
ja	doc_491521502146_item	2606753	et	3	main
maaelu	doc_491521502146_item	2606755	et	4	main
kritiseerida	doc_491521502146_item	2606756	et	3	main
massidele	doc_491521502146_item	2606762	et	3	main
see	doc_491521502146_item	2606763	et	3	main
film	doc_491521502146_item	2606764	et	3	main
vast	doc_491521502146_item	2606765	et	3	main
mõeldud	doc_491521502146_item	2606766	et	4	main
ei	doc_491521502146_item	2606767	et	4	main
ole	doc_491521502146_item	2606768	et	4	main
sest	doc_491521502146_item	2606769	et	4	main
palju	doc_491521502146_item	2606770	et	4	main
on	doc_491521502146_item	2606771	et	4	main
ühelt	doc_491521502146_item	2606772	et	3	main
teemalt	doc_491521502146_item	2606773	et	3	main
teisele	doc_491521502146_item	2606774	et	4	main
hüppamisi	doc_491521502146_item	2606775	et	4	main
sageli	doc_491521502146_item	2606776	et	3	main
tuleb	doc_491521502146_item	2606777	et	3	main
ka	doc_491521502146_item	2606778	et	3	main
filmist	doc_491521502146_item	2606786	et	4	main
mingit	doc_491521502146_item	2606787	et	3	main
naudingut	doc_491521502146_item	2606788	et	3	main
leida	doc_491521502146_item	2606789	et	3	main
on	doc_491521502146_item	2606793	et	4	main
nende	doc_491521502146_item	2606802	et	4	main
ometigi	doc_491521502146_item	2606804	et	4	main
kujutati	doc_491521502146_item	2606821	et	4	main
kui	doc_491521502146_item	2606824	et	3	main
niivõrd	doc_491521502146_item	2606829	et	3	main
ja	doc_491521502146_item	2606832	et	3	main
ja	doc_491521502146_item	2606837	et	3	main
siin	doc_491521502146_item	2606848	et	4	main
imestada	doc_491521502146_item	2606849	et	3	main
kuna	doc_491521502146_item	2606850	et	3	main
eestlaste	doc_491521502146_item	2606875	et	4	main
sellest	doc_491521502146_item	2606877	et	4	main
sarimõrtsukas	doc_491521502146_item	2606894	et	4	main
üks	doc_491521502146_item	2606895	et	3	main
joomise	doc_491521502146_item	2606896	et	4	main
pärast	doc_491521502146_item	2606897	et	4	main
kloostrist	doc_491521502146_item	2606898	et	3	main
välja	doc_491521502146_item	2606899	et	4	main
heidetud	doc_491521502146_item	2606900	et	4	main
munk	doc_491521502146_item	2606901	et	3	main
kes	doc_491521502146_item	2606902	et	4	main
hävitab	doc_491521502146_item	2606903	et	3	main
kirikuid	doc_491521502146_item	2606904	et	4	main
ja	doc_491521502146_item	2606905	et	3	main
üks	doc_491521502146_item	2606906	et	3	main
süfiliitik	doc_491521502146_item	2606907	et	3	main
päris	doc_491521502146_item	2606908	et	4	main
karm	doc_491521502146_item	2606909	et	4	main
seltskond	doc_491521502146_item	2606910	et	3	main
ja	doc_491521502146_item	2606911	et	3	main
üks	doc_491521502146_item	2606912	et	3	main
on	doc_491521502146_item	2606913	et	4	main
neist	doc_491521502146_item	2606914	et	4	main
veel	doc_491521502146_item	2606915	et	4	main
mõttes	doc_491521502146_item	2606917	et	3	main
parem	doc_491521502146_item	2606918	et	4	main
kui	doc_491521502146_item	2606919	et	3	main
igas	doc_491521502146_item	2606916	et	3	main
päris	doc_491521502146_item	2606920	et	4	main
ja	doc_491521502146_item	2606932	et	3	main
laskmine	doc_491521502146_item	2606934	et	4	main
tegid	doc_491521502146_item	2606941	et	4	main
aeg-ajalt	doc_491521502146_item	2606942	et	4	main
ainult	doc_491521502146_item	2606944	et	4	main
õige	doc_491521502146_item	2606953	et	4	main
lenin	doc_491521502146_item	2606954	et	4	main
üks	doc_491521502146_item	2606970	et	3	main
suurim	doc_491521502146_item	2606971	et	3	main
kelle	doc_491521502146_item	2606977	et	4	main
venemaa	doc_491521502146_item	2606984	et	4	main
saksamaa	doc_491521502146_item	2606991	et	4	main
ta	doc_491521502146_item	2607002	et	4	main
polnud	doc_491521502146_item	2607003	et	3	main
vaid	doc_491521502146_item	2607004	et	3	main
unistaja	doc_491521502146_item	2607005	et	4	main
kõik	doc_491521502146_item	2607009	et	4	main
täide	doc_491521502146_item	2607013	et	4	main
ma	doc_491521502146_item	2607025	et	3	main
otsimine	doc_491521502146_item	2606930	et	4	main
komöödiaks	doc_491521502146_item	2606940	et	4	main
ja	doc_491521502146_item	2606949	et	3	main
milline	doc_491521502146_item	2606950	et	3	main
kesküla	doc_491521502146_item	2606956	et	4	main
ise	doc_491521502146_item	2606957	et	4	main
mõjus	doc_491521502146_item	2606958	et	4	main
tõelise	doc_491521502146_item	2606959	et	4	main
kangelase	doc_491521502146_item	2606960	et	3	main
ja	doc_491521502146_item	2606961	et	3	main
patrioodina	doc_491521502146_item	2606962	et	3	main
lugesin	doc_491521502146_item	2606963	et	3	main
tema	doc_491521502146_item	2606964	et	4	main
kohta	doc_491521502146_item	2606965	et	4	main
et	doc_491521502146_item	2606966	et	3	main
võibolla	doc_491521502146_item	2606967	et	4	main
on	doc_491521502146_item	2606968	et	4	main
ja	doc_491521502146_item	2606983	et	3	main
ürituse	doc_491521502146_item	2606986	et	4	main
ja	doc_491521502146_item	2606992	et	3	main
vaid	doc_491521502146_item	2607006	et	3	main
et	doc_491521502146_item	2607010	et	3	main
ka	doc_491521502146_item	2607017	et	3	main
filmis	doc_491521502146_item	2607022	et	4	main
seda	doc_491521502146_item	2607024	et	3	main
on	doc_491521502146_item	2607029	et	4	main
kujutluses	doc_491521502146_item	2607035	et	4	main
väljamängitud	doc_491521502146_item	2607038	et	4	main
keskülast	doc_491521502146_item	2607045	et	3	main
sakslased	doc_491521502146_item	2607061	et	3	main
ei	doc_491521502146_item	2607063	et	4	main
räägi	doc_491521502146_item	2607064	et	4	main
aga	doc_491521502146_item	2607065	et	3	main
ka	doc_491521502146_item	2607071	et	3	main
poleks	doc_491521502146_item	2607074	et	3	main
sinna	doc_491521502146_item	2607076	et	3	main
nad	doc_491521502146_item	2607086	et	3	main
eestlaste	doc_491521502146_item	2607096	et	4	main
südameid	doc_491521502146_item	2607097	et	3	main
liigutaks	doc_491521502146_item	2607098	et	4	main
kuid	doc_491521502146_item	2607099	et	4	main
eriti	doc_491521502146_item	2607104	et	3	main
riigis	doc_491521502146_item	2607112	et	3	main
on	doc_491521502146_item	2607114	et	4	main
vaatasime	doc_491521502147_item	2607120	et	3	main
me	doc_491521502147_item	2607121	et	4	main
tunnis	doc_491521502147_item	2607123	et	3	main
minu	doc_491521502147_item	2607125	et	3	main
leninid	doc_491521502147_item	2607126	et	4	main
lõpp	doc_491521502147_item	2607131	et	3	main
oli	doc_491521502147_item	2607132	et	3	main
ja	doc_491521502147_item	2607135	et	3	main
jäi	doc_491521502147_item	2607137	et	3	main
mul	doc_491521502147_item	2607144	et	3	main
sündmustest	doc_491521502147_item	2607158	et	4	main
ka	doc_491521502147_item	2607164	et	3	main
sai	doc_491521502147_item	2607176	et	4	main
ta	doc_491521502147_item	2607177	et	4	main
kesküla	doc_491521502147_item	2607213	et	4	main
kes	doc_491521502147_item	2607217	et	4	main
elas	doc_491521502147_item	2607226	et	3	main
saksamaal	doc_491521502147_item	2607229	et	4	main
seejärel	doc_491521502147_item	2607230	et	3	main
šveitsis	doc_491521502147_item	2607232	et	2	main
osalemist	doc_491521502147_item	2607235	et	4	main
sotsialistlikus	doc_491521502147_item	2607236	et	4	main
abil	doc_491521502147_item	2607261	et	4	main
saab	doc_491521502147_item	2607262	et	3	main
täide	doc_491521502147_item	2607266	et	4	main
kuid	doc_491521502147_item	2607274	et	4	main
iga	doc_491521502147_item	2607275	et	4	main
üks	doc_491521502147_item	2607276	et	3	main
loodab	doc_491521502147_item	2607277	et	3	main
see	doc_491521502147_item	2607321	et	3	main
kes	doc_491521502147_item	2607328	et	4	main
ta	doc_491521502147_item	2607329	et	4	main
üldse	doc_491521502147_item	2607330	et	3	main
trükkisid	doc_491521502147_item	2607337	et	4	main
ja	doc_491521502147_item	2607340	et	3	main
kesküla	doc_491521502147_item	2607348	et	4	main
midagi	doc_491521502147_item	2607353	et	4	main
tal	doc_491521502147_item	2607357	et	3	main
õnnestu	doc_491521502147_item	2607359	et	4	main
otsida	doc_491521502147_item	2607367	et	4	main
tema	doc_491521502147_item	2607369	et	4	main
et	doc_491521502147_item	2607371	et	3	main
leninit	doc_491521502147_item	2607374	et	4	main
igal	doc_491521502147_item	2607375	et	3	main
kool	doc_491521502147_item	2607386	et	4	main
koolilatakse	doc_491521502147_item	2607388	et	4	main
välja	doc_491521502147_item	2607389	et	4	main
sarnased	doc_491521502147_item	2607395	et	4	main
tublem	doc_491521502147_item	2607399	et	4	main
et	doc_491521502146_item	2607001	et	3	main
kas	doc_491521502146_item	2607015	et	3	main
arvata	doc_491521502146_item	2607028	et	4	main
hakkab	doc_491521502146_item	2607036	et	3	main
mõjutama	doc_491521502146_item	2607041	et	4	main
nägemust	doc_491521502146_item	2607042	et	3	main
tekst	doc_491521502146_item	2607054	et	3	main
ilma	doc_491521502146_item	2607056	et	4	main
päris	doc_491521502146_item	2607058	et	4	main
nii	doc_491521502146_item	2607059	et	3	main
päris	doc_491521502146_item	2607078	et	4	main
hästi	doc_491521502146_item	2607079	et	3	main
ma	doc_491521502146_item	2607080	et	3	main
arvan	doc_491521502146_item	2607081	et	3	main
sellest	doc_491521502146_item	2607103	et	4	main
kui	doc_491521502146_item	2607106	et	3	main
kangeid	doc_491521502146_item	2607107	et	3	main
hakkajaid	doc_491521502146_item	2607109	et	4	main
minu	doc_491521502147_item	2607117	et	3	main
leninid	doc_491521502147_item	2607118	et	4	main
vaatamata	doc_491521502147_item	2607127	et	4	main
imelik	doc_491521502147_item	2607134	et	3	main
mul	doc_491521502147_item	2607138	et	3	main
filmist	doc_491521502147_item	2607140	et	4	main
päris	doc_491521502147_item	2607141	et	4	main
tõesti	doc_491521502147_item	2607146	et	3	main
film	doc_491521502147_item	2607150	et	3	main
sellele	doc_491521502147_item	2607154	et	4	main
et	doc_491521502147_item	2607155	et	3	main
peategelaseks	doc_491521502147_item	2607165	et	3	main
on	doc_491521502147_item	2607169	et	4	main
mulle	doc_491521502147_item	2607170	et	4	main
hästi	doc_491521502147_item	2607171	et	3	main
lenini	doc_491521502147_item	2607178	et	4	main
eestist	doc_491521502147_item	2607216	et	3	main
elas	doc_491521502147_item	2607218	et	3	main
mõnda	doc_491521502147_item	2607220	et	4	main
kust	doc_491521502147_item	2607222	et	4	main
põgenema	doc_491521502147_item	2607224	et	3	main
liikumises	doc_491521502147_item	2607237	et	4	main
rikka	doc_491521502147_item	2607242	et	4	main
kes	doc_491521502147_item	2607244	et	4	main
maamaja	doc_491521502147_item	2607249	et	4	main
ainuke	doc_491521502147_item	2607251	et	4	main
oli	doc_491521502147_item	2607253	et	3	main
ja	doc_491521502147_item	2607256	et	3	main
ta	doc_491521502147_item	2607257	et	4	main
arvas	doc_491521502147_item	2607258	et	3	main
leniniga	doc_491521502147_item	2607270	et	4	main
1914	doc_491521502147_item	2607284	et	2	main
läheb	doc_491521502147_item	2607286	et	3	main
uuriks	doc_491521502147_item	2607322	et	4	main
enamlased	doc_491521502147_item	2607336	et	3	main
kihutuskirjandust	doc_491521502147_item	2607339	et	3	main
pidasid	doc_491521502147_item	2607341	et	4	main
sidet	doc_491521502147_item	2607342	et	4	main
kodumaaga	doc_491521502147_item	2607343	et	3	main
põhiliselt	doc_491521502147_item	2607344	et	4	main
saksa	doc_491521502147_item	2607345	et	4	main
rahadega	doc_491521502147_item	2607346	et	3	main
et	doc_491521502147_item	2607350	et	3	main
ja	doc_491521502147_item	2607355	et	3	main
oma	doc_491521502147_item	2607360	et	4	main
plaane	doc_491521502147_item	2607361	et	3	main
leninile	doc_491521502147_item	2607366	et	4	main
ta	doc_491521502147_item	2607372	et	4	main
asendaks	doc_491521502147_item	2607373	et	3	main
lenin	doc_491521502147_item	2607381	et	4	main
kus	doc_491521502147_item	2607387	et	3	main
vaimult	doc_491521502147_item	2607397	et	4	main
nende	doc_491521502147_item	2607401	et	4	main
meeste	doc_491521502147_item	2607402	et	4	main
läks	doc_491521502147_item	2607422	et	3	main
sest	doc_491521502147_item	2607426	et	4	main
lenin	doc_491521502147_item	2607428	et	4	main
eesti	doc_491521502147_item	2607437	et	4	main
parem	doc_491521502147_item	2607445	et	4	main
leninit	doc_491521502147_item	2607450	et	4	main
lenini	doc_491521502147_item	2607452	et	4	main
inimestele	doc_491521502147_item	2607454	et	3	main
nad	doc_491521502147_item	2607456	et	3	main
et	doc_491521502147_item	2607457	et	3	main
kuid	doc_491521502146_item	2607033	et	4	main
minu	doc_491521502146_item	2607034	et	3	main
kindlasti	doc_491521502146_item	2607040	et	3	main
ei	doc_491521502146_item	2607026	et	4	main
tea	doc_491521502146_item	2607027	et	4	main
olnud	doc_491521502146_item	2607032	et	4	main
saaremäe	doc_491521502146_item	2607037	et	3	main
tegelaskuju	doc_491521502146_item	2607039	et	4	main
tegelikust	doc_491521502146_item	2607043	et	4	main
aleksander	doc_491521502146_item	2607044	et	4	main
natukene	doc_491521502146_item	2607048	et	4	main
jäigalt	doc_491521502146_item	2607051	et	4	main
saksakeelne	doc_491521502146_item	2607053	et	3	main
seegi	doc_491521502146_item	2607066	et	4	main
pole	doc_491521502146_item	2607067	et	3	main
päriselt	doc_491521502146_item	2607068	et	3	main
eesti	doc_491521502146_item	2607072	et	4	main
sobinud	doc_491521502146_item	2607075	et	4	main
filmi	doc_491521502146_item	2607077	et	4	main
ka	doc_491521502146_item	2607087	et	3	main
jätnud	doc_491521502146_item	2607089	et	4	main
film	doc_491521502146_item	2607091	et	3	main
ometigi	doc_491521502146_item	2607100	et	4	main
hea	doc_491521502146_item	2607101	et	4	main
kunagi	doc_491521502146_item	2607113	et	3	main
olnud	doc_491521502146_item	2607115	et	4	main
essee	doc_491521502147_item	2607116	et	4	main
võibolla	doc_491521502146_item	2607046	et	4	main
see	doc_491521502146_item	2607050	et	3	main
monotoonne	doc_491521502146_item	2607055	et	3	main
nii	doc_491521502146_item	2607069	et	3	main
kuid	doc_491521502146_item	2607082	et	4	main
õiget	doc_491521502146_item	2607083	et	3	main
välismaalaste	doc_491521502146_item	2607084	et	4	main
muljet	doc_491521502146_item	2607085	et	3	main
pole	doc_491521502146_item	2607092	et	3	main
meie	doc_491521502146_item	2607111	et	4	main
kultuuriloo	doc_491521502147_item	2607122	et	4	main
sellele	doc_491521502147_item	2607128	et	4	main
mulje	doc_491521502147_item	2607143	et	4	main
oli	doc_491521502147_item	2607145	et	3	main
sest	doc_491521502147_item	2607149	et	4	main
oli	doc_491521502147_item	2607151	et	3	main
mis	doc_491521502147_item	2607159	et	4	main
oli	doc_491521502147_item	2607166	et	3	main
kes	doc_491521502147_item	2607168	et	4	main
tuntud	doc_491521502147_item	2607172	et	4	main
ja	doc_491521502147_item	2607173	et	3	main
minu	doc_491521502147_item	2607174	et	3	main
pärit	doc_491521502147_item	2607215	et	3	main
venemaal	doc_491521502147_item	2607219	et	4	main
aga	doc_491521502147_item	2607231	et	3	main
kus	doc_491521502147_item	2607233	et	3	main
seal	doc_491521502147_item	2607238	et	4	main
ka	doc_491521502147_item	2607240	et	3	main
abiellus	doc_491521502147_item	2607241	et	3	main
kaasa	doc_491521502147_item	2607246	et	4	main
ja	doc_491521502147_item	2607248	et	3	main
päris	doc_491521502147_item	2607271	et	4	main
saada	doc_491521502147_item	2607278	et	4	main
berni	doc_491521502147_item	2607290	et	4	main
kust	doc_491521502147_item	2607323	et	4	main
on	doc_491521502147_item	2607331	et	4	main
oma	doc_491521502147_item	2607338	et	4	main
kartis	doc_491521502147_item	2607349	et	3	main
ta	doc_491521502147_item	2607364	et	4	main
nõustus	doc_491521502147_item	2607382	et	4	main
pidid	doc_491521502147_item	2607393	et	4	main
seast	doc_491521502147_item	2607403	et	4	main
oli	doc_491521502147_item	2607404	et	3	main
see	doc_491521502147_item	2607421	et	3	main
tõepoolest	doc_491521502147_item	2607424	et	3	main
ütles	doc_491521502147_item	2607430	et	3	main
ei	doc_491521502147_item	2607433	et	4	main
ei	doc_491521502147_item	2607435	et	4	main
mingit	doc_491521502147_item	2607436	et	3	main
suurriiki	doc_491521502147_item	2607438	et	4	main
otsustas	doc_491521502147_item	2607439	et	3	main
kesküla	doc_491521502147_item	2607440	et	4	main
kui	doc_491521502147_item	2607446	et	3	main
ei	doc_491521502147_item	2607460	et	4	main
päris	doc_491521502147_item	2607465	et	4	main
see	doc_491521502147_item	2607468	et	3	main
ennast	doc_491521502147_item	2607472	et	4	main
a	doc_491521502147_item	2607477	et	4	main
lennates	doc_491521502147_item	2607478	et	3	main
üle	doc_491521502147_item	2607479	et	3	main
ei	doc_491521502147_item	2607483	et	4	main
et	doc_491521502147_item	2607486	et	3	main
kuid	doc_491521502147_item	2607492	et	4	main
teab	doc_491521502147_item	2607494	et	3	main
naeruväärne	doc_491521502147_item	2607504	et	3	main
filmi	doc_491521502147_item	2607130	et	4	main
hea	doc_491521502147_item	2607142	et	4	main
huvitav	doc_491521502147_item	2607147	et	4	main
kaasaegne	doc_491521502147_item	2607152	et	3	main
pärinevad	doc_491521502147_item	2607160	et	4	main
20nda	doc_491521502147_item	2607161	et	4	main
näitleja	doc_491521502147_item	2607167	et	4	main
rolliga	doc_491521502147_item	2607179	et	4	main
väga	doc_491521502147_item	2607180	et	3	main
hästi	doc_491521502147_item	2607181	et	3	main
hakkama	doc_491521502147_item	2607182	et	3	main
sündmused	doc_491521502147_item	2607183	et	3	main
leidsid	doc_491521502147_item	2607184	et	4	main
aset	doc_491521502147_item	2607185	et	3	main
erinevates	doc_491521502147_item	2607186	et	4	main
kohtades	doc_491521502147_item	2607187	et	3	main
pariisis	doc_491521502147_item	2607188	et	4	main
šveitsis	doc_491521502147_item	2607189	et	2	main
berliinis	doc_491521502147_item	2607190	et	4	main
venemaal	doc_491521502147_item	2607191	et	4	main
alguse	doc_491521502147_item	2607192	et	3	main
sai	doc_491521502147_item	2607193	et	4	main
kõik	doc_491521502147_item	2607194	et	4	main
pariisist	doc_491521502147_item	2607195	et	4	main
kus	doc_491521502147_item	2607196	et	3	main
said	doc_491521502147_item	2607197	et	4	main
tuttavaks	doc_491521502147_item	2607198	et	4	main
lenin	doc_491521502147_item	2607199	et	4	main
ja	doc_491521502147_item	2607200	et	3	main
aleksander	doc_491521502147_item	2607201	et	4	main
kesküla	doc_491521502147_item	2607202	et	4	main
lenin	doc_491521502147_item	2607203	et	4	main
oli	doc_491521502147_item	2607204	et	3	main
bolševik	doc_491521502147_item	2607205	et	2	main
ja	doc_491521502147_item	2607206	et	3	main
ta	doc_491521502147_item	2607207	et	4	main
tahtis	doc_491521502147_item	2607208	et	3	main
muuta	doc_491521502147_item	2607209	et	4	main
sotsialistliku	doc_491521502147_item	2607210	et	3	main
et	doc_491521502147_item	2607129	et	3	main
natuke	doc_491521502147_item	2607133	et	4	main
arusaamatu	doc_491521502147_item	2607136	et	4	main
üleüldse	doc_491521502147_item	2607139	et	3	main
vaadata	doc_491521502147_item	2607148	et	4	main
vaatamata	doc_491521502147_item	2607153	et	4	main
rääkis	doc_491521502147_item	2607156	et	3	main
ajaloolistest	doc_491521502147_item	2607157	et	4	main
saj	doc_491521502147_item	2607162	et	4	main
algusest	doc_491521502147_item	2607163	et	4	main
arvates	doc_491521502147_item	2607175	et	4	main
sõja	doc_491521502147_item	2607211	et	3	main
kodusõjaks	doc_491521502147_item	2607212	et	3	main
oli	doc_491521502147_item	2607214	et	3	main
aega	doc_491521502147_item	2607221	et	4	main
pidi	doc_491521502147_item	2607223	et	4	main
pärast	doc_491521502147_item	2607225	et	4	main
aega	doc_491521502147_item	2607228	et	4	main
jätkas	doc_491521502147_item	2607234	et	3	main
ta	doc_491521502147_item	2607239	et	4	main
šveitslannaga	doc_491521502147_item	2607243	et	2	main
kinnisidee	doc_491521502147_item	2607254	et	4	main
suur-eestist	doc_491521502147_item	2607255	et	3	main
ta	doc_491521502147_item	2607263	et	4	main
hästi	doc_491521502147_item	2607272	et	3	main
läbi	doc_491521502147_item	2607273	et	4	main
oma	doc_491521502147_item	2607280	et	4	main
ideede	doc_491521502147_item	2607281	et	3	main
tuli	doc_491521502147_item	2607326	et	4	main
ja	doc_491521502147_item	2607327	et	3	main
et	doc_491521502147_item	2607335	et	3	main
leniniga	doc_491521502147_item	2607351	et	4	main
võib	doc_491521502147_item	2607352	et	3	main
ei	doc_491521502147_item	2607358	et	4	main
täide	doc_491521502147_item	2607362	et	4	main
viia	doc_491521502147_item	2607363	et	3	main
pool	doc_491521502147_item	2607376	et	4	main
tema	doc_491521502147_item	2607377	et	4	main
mõttes	doc_491521502147_item	2607379	et	3	main
ja	doc_491521502147_item	2607380	et	3	main
ilmub	doc_491521502147_item	2607384	et	3	main
olema	doc_491521502147_item	2607394	et	4	main
ivan	doc_491521502147_item	2607405	et	4	main
keskülale	doc_491521502147_item	2607431	et	4	main
iial	doc_491521502147_item	2607434	et	3	main
et	doc_491521502147_item	2607441	et	3	main
ivan	doc_491521502147_item	2607442	et	4	main
asendab	doc_491521502147_item	2607449	et	3	main
vanjaga	doc_491521502147_item	2607451	et	4	main
vaid	doc_491521502147_item	2607463	et	3	main
on	doc_491521502147_item	2607467	et	4	main
elus	doc_491521502147_item	2607488	et	4	main
teisikuid	doc_491521502147_item	2607491	et	4	main
kes	doc_491521502147_item	2607493	et	4	main
kuid	doc_491521502147_item	2607495	et	4	main
minu	doc_491521502147_item	2607496	et	3	main
meelest	doc_491521502147_item	2607497	et	4	main
see	doc_491521502147_item	2607498	et	3	main
teisikute	doc_491521502147_item	2607499	et	3	main
loomulikult	doc_491521502147_item	2607505	et	4	main
hetkeks	doc_491521502147_item	2607527	et	4	main
kujutasin	doc_491521502147_item	2607528	et	3	main
ette	doc_491521502147_item	2607529	et	4	main
et	doc_491521502147_item	2607530	et	3	main
minuga	doc_491521502147_item	2607531	et	3	main
käidaks	doc_491521502147_item	2607532	et	3	main
isegi	doc_491521502147_item	2607541	et	4	main
inimesed	doc_491521502147_item	2607544	et	3	main
hakkas	doc_491521502147_item	2607550	et	3	main
filmis	doc_491521502147_item	2607553	et	4	main
minu	doc_491521502147_item	2607556	et	3	main
kodulinnast	doc_491521502147_item	2607557	et	4	main
pärnust	doc_491521502147_item	2607558	et	4	main
filmi	doc_491521502147_item	2607566	et	4	main
tallinas	doc_491521502147_item	2607570	et	4	main
eesti	doc_491521502147_item	2607573	et	4	main
linnades	doc_491521502147_item	2607574	et	3	main
essee	doc_491521502148_item	2607575	et	4	main
film	doc_491521502148_item	2607576	et	3	main
minu	doc_491521502148_item	2607577	et	3	main
leninid	doc_491521502148_item	2607584	et	4	main
on	doc_491521502148_item	2607585	et	4	main
pseudoajalooline	doc_491521502148_item	2607586	et	4	main
ettevõtlikust	doc_491521502148_item	2607604	et	4	main
see	doc_491521502148_item	2607617	et	3	main
piisavalt	doc_491521502148_item	2607620	et	4	main
temal	doc_491521502148_item	2607624	et	3	main
saada	doc_491521502148_item	2607630	et	4	main
võimu	doc_491521502148_item	2607643	et	4	main
otsustab	doc_491521502148_item	2607645	et	3	main
ära	doc_491521502148_item	2607646	et	4	main
kasutada	doc_491521502148_item	2607647	et	3	main
saksamaa	doc_491521502148_item	2607654	et	4	main
rahadega	doc_491521502148_item	2607655	et	3	main
revolutsioon	doc_491521502148_item	2607656	et	3	main
mõnda	doc_491521502147_item	2607227	et	4	main
tõi	doc_491521502147_item	2607245	et	3	main
jõukuse	doc_491521502147_item	2607247	et	4	main
kesküla	doc_491521502147_item	2607250	et	4	main
idee	doc_491521502147_item	2607252	et	4	main
et	doc_491521502147_item	2607259	et	3	main
lenini	doc_491521502147_item	2607260	et	4	main
oma	doc_491521502147_item	2607264	et	4	main
unistused	doc_491521502147_item	2607265	et	4	main
viia	doc_491521502147_item	2607267	et	3	main
nad	doc_491521502147_item	2607268	et	3	main
saavad	doc_491521502147_item	2607269	et	4	main
kasu	doc_491521502147_item	2607279	et	4	main
täide	doc_491521502147_item	2607282	et	4	main
viimiseks	doc_491521502147_item	2607283	et	4	main
a	doc_491521502147_item	2607285	et	4	main
ak	doc_491521502147_item	2607287	et	4	main
koostööpakkumisega	doc_491521502147_item	2607288	et	3	main
saksamaa	doc_491521502147_item	2607289	et	4	main
saadiku	doc_491521502147_item	2607291	et	3	main
juurde	doc_491521502147_item	2607292	et	4	main
ja	doc_491521502147_item	2607293	et	3	main
teavitas	doc_491521502147_item	2607294	et	4	main
sakslasi	doc_491521502147_item	2607295	et	3	main
vene	doc_491521502147_item	2607296	et	4	main
enamlaste	doc_491521502147_item	2607297	et	4	main
vaadetest	doc_491521502147_item	2607298	et	3	main
ja	doc_491521502147_item	2607299	et	3	main
tegevusest	doc_491521502147_item	2607300	et	4	main
algul	doc_491521502147_item	2607301	et	4	main
saksa	doc_491521502147_item	2607302	et	4	main
saatkond	doc_491521502147_item	2607303	et	3	main
ei	doc_491521502147_item	2607304	et	4	main
usu	doc_491521502147_item	2607305	et	4	main
teda	doc_491521502147_item	2607306	et	4	main
nad	doc_491521502147_item	2607307	et	3	main
arvavad	doc_491521502147_item	2607308	et	4	main
et	doc_491521502147_item	2607309	et	3	main
ta	doc_491521502147_item	2607310	et	4	main
on	doc_491521502147_item	2607311	et	4	main
vene	doc_491521502147_item	2607312	et	4	main
agent	doc_491521502147_item	2607313	et	3	main
ja	doc_491521502147_item	2607314	et	3	main
saadavad	doc_491521502147_item	2607315	et	4	main
oma	doc_491521502147_item	2607316	et	4	main
parema	doc_491521502147_item	2607317	et	4	main
agendi	doc_491521502147_item	2607318	et	3	main
mülleri	doc_491521502147_item	2607319	et	4	main
et	doc_491521502147_item	2607320	et	3	main
see	doc_491521502147_item	2607324	et	3	main
kesküla	doc_491521502147_item	2607325	et	4	main
tulemuseks	doc_491521502147_item	2607332	et	3	main
on	doc_491521502147_item	2607333	et	4	main
see	doc_491521502147_item	2607334	et	3	main
kuid	doc_491521502147_item	2607347	et	4	main
juhtuda	doc_491521502147_item	2607354	et	3	main
siis	doc_491521502147_item	2607356	et	3	main
pakub	doc_491521502147_item	2607365	et	3	main
välja	doc_491521502147_item	2607368	et	4	main
teisik	doc_491521502147_item	2607370	et	3	main
julgeoleku	doc_491521502147_item	2607378	et	3	main
nii	doc_491521502147_item	2607383	et	3	main
leninite	doc_491521502147_item	2607385	et	4	main
lenini	doc_491521502147_item	2607390	et	4	main
koopiaid	doc_491521502147_item	2607391	et	3	main
nad	doc_491521502147_item	2607392	et	3	main
ka	doc_491521502147_item	2607396	et	3	main
kõige	doc_491521502147_item	2607398	et	4	main
õpilane	doc_491521502147_item	2607400	et	3	main
minu	doc_491521502147_item	2607406	et	3	main
meelest	doc_491521502147_item	2607407	et	4	main
oli	doc_491521502147_item	2607408	et	3	main
ta	doc_491521502147_item	2607409	et	4	main
väga	doc_491521502147_item	2607410	et	3	main
kaval	doc_491521502147_item	2607411	et	4	main
ja	doc_491521502147_item	2607412	et	3	main
rääkis	doc_491521502147_item	2607413	et	3	main
ainult	doc_491521502147_item	2607414	et	4	main
seda	doc_491521502147_item	2607415	et	3	main
mida	doc_491521502147_item	2607416	et	4	main
kesküla	doc_491521502147_item	2607417	et	4	main
kuulda	doc_491521502147_item	2607418	et	4	main
tahtis	doc_491521502147_item	2607419	et	3	main
ja	doc_491521502147_item	2607420	et	3	main
talle	doc_491521502147_item	2607423	et	4	main
kasuks	doc_491521502147_item	2607425	et	4	main
kui	doc_491521502147_item	2607427	et	3	main
et	doc_491521502147_item	2607432	et	3	main
on	doc_491521502147_item	2607443	et	4	main
juba	doc_491521502147_item	2607444	et	3	main
ja	doc_491521502147_item	2607448	et	3	main
lähedastele	doc_491521502147_item	2607453	et	3	main
ütlevad	doc_491521502147_item	2607455	et	4	main
vanja	doc_491521502147_item	2607459	et	4	main
lenin	doc_491521502147_item	2607466	et	4	main
peab	doc_491521502147_item	2607471	et	4	main
leniniks	doc_491521502147_item	2607473	et	4	main
lenin	doc_491521502147_item	2607474	et	4	main
hukkus	doc_491521502147_item	2607475	et	3	main
1917	doc_491521502147_item	2607476	et	2	main
ma	doc_491521502147_item	2607482	et	3	main
oli	doc_491521502147_item	2607489	et	3	main
otsimine	doc_491521502147_item	2607500	et	4	main
kõik	doc_491521502147_item	2607508	et	4	main
leninist	doc_491521502147_item	2607521	et	4	main
väga	doc_491521502147_item	2607523	et	3	main
kahju	doc_491521502147_item	2607524	et	4	main
kui	doc_491521502147_item	2607525	et	3	main
ei	doc_491521502147_item	2607537	et	4	main
minu	doc_491521502147_item	2607542	et	3	main
lähedased	doc_491521502147_item	2607543	et	3	main
ei	doc_491521502147_item	2607545	et	4	main
tunne	doc_491521502147_item	2607546	et	4	main
mind	doc_491521502147_item	2607547	et	4	main
märkaksin	doc_491521502147_item	2607552	et	3	main
kool	doc_491521502147_item	2607563	et	4	main
nii	doc_491521502147_item	2607564	et	3	main
lõpuks	doc_491521502147_item	2607429	et	4	main
lenin	doc_491521502147_item	2607447	et	4	main
ole	doc_491521502147_item	2607461	et	4	main
teisik	doc_491521502147_item	2607462	et	3	main
kes	doc_491521502147_item	2607470	et	4	main
laeva	doc_491521502147_item	2607480	et	4	main
käipide	doc_491521502147_item	2607481	et	4	main
päris	doc_491521502147_item	2607487	et	4	main
leninil	doc_491521502147_item	2607490	et	4	main
ja	doc_491521502147_item	2607501	et	3	main
väljaõpetamine	doc_491521502147_item	2607502	et	3	main
oli	doc_491521502147_item	2607506	et	3	main
koomilises	doc_491521502147_item	2607509	et	3	main
vormis	doc_491521502147_item	2607510	et	4	main
tehtud	doc_491521502147_item	2607511	et	4	main
kuid	doc_491521502147_item	2607512	et	4	main
tegelikult	doc_491521502147_item	2607513	et	4	main
oli	doc_491521502147_item	2607514	et	3	main
see	doc_491521502147_item	2607515	et	3	main
päris	doc_491521502147_item	2607516	et	4	main
õudne	doc_491521502147_item	2607517	et	3	main
mitteinimlik	doc_491521502147_item	2607518	et	3	main
mul	doc_491521502147_item	2607519	et	3	main
oli	doc_491521502147_item	2607520	et	3	main
samamoodi	doc_491521502147_item	2607533	et	3	main
läbi	doc_491521502147_item	2607534	et	4	main
et	doc_491521502147_item	2607535	et	3	main
mina	doc_491521502147_item	2607536	et	4	main
ja	doc_491521502147_item	2607540	et	3	main
jube	doc_491521502147_item	2607551	et	4	main
ainult	doc_491521502147_item	2607569	et	4	main
teistes	doc_491521502147_item	2607572	et	4	main
on	doc_491521502148_item	2607580	et	4	main
ajalooline	doc_491521502148_item	2607581	et	4	main
nendest	doc_491521502148_item	2607588	et	4	main
mis	doc_491521502148_item	2607590	et	4	main
tõsiselt	doc_491521502148_item	2607592	et	4	main
on	doc_491521502148_item	2607596	et	4	main
huvitavaid	doc_491521502148_item	2607599	et	4	main
stseene	doc_491521502148_item	2607600	et	3	main
see	doc_491521502148_item	2607601	et	3	main
film	doc_491521502148_item	2607602	et	3	main
jutustab	doc_491521502148_item	2607603	et	3	main
mitte	doc_491521502147_item	2607458	et	3	main
hoopis	doc_491521502147_item	2607464	et	3	main
hull	doc_491521502147_item	2607469	et	3	main
usu	doc_491521502147_item	2607484	et	4	main
hästi	doc_491521502147_item	2607485	et	3	main
oli	doc_491521502147_item	2607503	et	3	main
see	doc_491521502147_item	2607507	et	3	main
isegi	doc_491521502147_item	2607522	et	4	main
mina	doc_491521502147_item	2607539	et	4	main
ära	doc_491521502147_item	2607548	et	4	main
mul	doc_491521502147_item	2607549	et	3	main
ammende	doc_491521502147_item	2607559	et	4	main
villa	doc_491521502147_item	2607560	et	4	main
vanalinna	doc_491521502147_item	2607562	et	4	main
mitte	doc_491521502147_item	2607568	et	3	main
komeedia	doc_491521502148_item	2607582	et	4	main
minu	doc_491521502148_item	2607583	et	3	main
mõjutasid	doc_491521502148_item	2607593	et	4	main
filmis	doc_491521502148_item	2607595	et	4	main
väga	doc_491521502148_item	2607597	et	3	main
palju	doc_491521502148_item	2607598	et	4	main
aleksander	doc_491521502148_item	2607605	et	4	main
kes	doc_491521502148_item	2607607	et	4	main
mees	doc_491521502148_item	2607618	et	4	main
ja	doc_491521502148_item	2607622	et	3	main
plaaniks	doc_491521502148_item	2607639	et	4	main
leninit	doc_491521502148_item	2607650	et	4	main
et	doc_491521502148_item	2607651	et	3	main
tekitada	doc_491521502148_item	2607652	et	3	main
venemaal	doc_491521502148_item	2607653	et	4	main
suur-eesti	doc_491521502148_item	2607660	et	4	main
väga	doc_491521502148_item	2607666	et	3	main
julmus	doc_491521502148_item	2607675	et	4	main
kui	doc_491521502148_item	2607682	et	3	main
kõik	doc_491521502148_item	2607691	et	4	main
otsustas	doc_491521502148_item	2607703	et	3	main
organiseerida	doc_491521502148_item	2607704	et	3	main
on	doc_491521502148_item	2607716	et	4	main
leniniga	doc_491521502148_item	2607719	et	4	main
ma	doc_491521502147_item	2607526	et	3	main
ole	doc_491521502147_item	2607538	et	4	main
tuttavaid	doc_491521502147_item	2607554	et	3	main
kohti	doc_491521502147_item	2607555	et	4	main
ja	doc_491521502147_item	2607561	et	3	main
tehti	doc_491521502147_item	2607567	et	3	main
vaid	doc_491521502147_item	2607571	et	3	main
sündmustest	doc_491521502148_item	2607589	et	4	main
väga	doc_491521502148_item	2607591	et	3	main
keskülast	doc_491521502148_item	2607606	et	3	main
on	doc_491521502148_item	2607608	et	4	main
ka	doc_491521502148_item	2607614	et	3	main
saksa	doc_491521502148_item	2607615	et	4	main
agent	doc_491521502148_item	2607616	et	3	main
on	doc_491521502148_item	2607619	et	4	main
suur	doc_491521502148_item	2607626	et	3	main
kes	doc_491521502148_item	2607634	et	4	main
bolševikute	doc_491521502148_item	2607636	et	2	main
juht	doc_491521502148_item	2607637	et	3	main
nende	doc_491521502148_item	2607638	et	4	main
venemaa	doc_491521502148_item	2607642	et	4	main
loode-venemaast	doc_491521502148_item	2607659	et	3	main
nähtav	doc_491521502148_item	2607674	et	4	main
ta	doc_491521502148_item	2607702	et	4	main
hakkas	doc_491521502148_item	2607709	et	3	main
üks	doc_491521502148_item	2607713	et	3	main
nad	doc_491521502148_item	2607722	et	3	main
nagu	doc_491521502148_item	2607724	et	3	main
teisik	doc_491521502148_item	2607738	et	3	main
oma	doc_491521502148_item	2607739	et	4	main
ideaalse	doc_491521502148_item	2607740	et	3	main
humanistliku	doc_491521502148_item	2607741	et	3	main
on	doc_491521502148_item	2607753	et	4	main
väga	doc_491521502148_item	2607754	et	3	main
egoistlik	doc_491521502148_item	2607755	et	3	main
ja	doc_491521502148_item	2607756	et	3	main
fanaatiline	doc_491521502148_item	2607757	et	3	main
natukene	doc_491521502148_item	2607791	et	4	main
lõbusamaks	doc_491521502148_item	2607793	et	4	main
kogu	doc_491521502148_item	2607804	et	4	main
äravahetamisel	doc_491521502148_item	2607807	et	3	main
et	doc_491521502148_item	2607809	et	3	main
ei	doc_491521502148_item	2607811	et	4	main
sugugi	doc_491521502148_item	2607813	et	4	main
aru	doc_491521502148_item	2607814	et	4	main
et	doc_491521502147_item	2607565	et	3	main
leninid	doc_491521502148_item	2607578	et	4	main
see	doc_491521502148_item	2607579	et	3	main
film	doc_491521502148_item	2607587	et	3	main
ajalood	doc_491521502148_item	2607594	et	4	main
rahvusvaheline	doc_491521502148_item	2607609	et	4	main
avantürist	doc_491521502148_item	2607610	et	3	main
ja	doc_491521502148_item	2607611	et	3	main
aferist	doc_491521502148_item	2607612	et	3	main
enamlane	doc_491521502148_item	2607613	et	3	main
diplomaatne	doc_491521502148_item	2607623	et	4	main
on	doc_491521502148_item	2607625	et	4	main
tahtmine	doc_491521502148_item	2607627	et	4	main
delegatsiooni	doc_491521502148_item	2607628	et	4	main
juhiks	doc_491521502148_item	2607629	et	4	main
oli	doc_491521502148_item	2607635	et	3	main
vallutada	doc_491521502148_item	2607641	et	3	main
on	doc_491521502148_item	2607672	et	4	main
hästi	doc_491521502148_item	2607673	et	3	main
ebaõiglus	doc_491521502148_item	2607677	et	4	main
lõbusaks	doc_491521502148_item	2607679	et	4	main
siis	doc_491521502148_item	2607681	et	3	main
otsustatakse	doc_491521502148_item	2607683	et	3	main
leida	doc_491521502148_item	2607684	et	3	main
koolitada	doc_491521502148_item	2607686	et	3	main
viis	doc_491521502148_item	2607688	et	4	main
teisikut	doc_491521502148_item	2607689	et	3	main
lõpuks	doc_491521502148_item	2607692	et	4	main
revolutsiooni	doc_491521502148_item	2607694	et	4	main
tegema	doc_491521502148_item	2607695	et	3	main
sõidavad	doc_491521502148_item	2607696	et	3	main
kesküla	doc_491521502148_item	2607697	et	4	main
oli	doc_491521502148_item	2607698	et	3	main
kool	doc_491521502148_item	2607707	et	4	main
lenini	doc_491521502148_item	2607711	et	4	main
sarnane	doc_491521502148_item	2607718	et	4	main
nad	doc_491521502148_item	2607730	et	3	main
erinevad	doc_491521502148_item	2607733	et	4	main
loomuse	doc_491521502148_item	2607735	et	3	main
loomu	doc_491521502148_item	2607742	et	4	main
ja	doc_491521502148_item	2607743	et	3	main
intelektuaalse	doc_491521502148_item	2607744	et	4	main
usurpeerib	doc_491521502148_item	2607747	et	3	main
on	doc_491521502148_item	2607760	et	4	main
tunduvalt	doc_491521502148_item	2607762	et	4	main
tall	doc_491521502148_item	2607764	et	3	main
armandi	doc_491521502148_item	2607784	et	4	main
meelest	doc_491521502148_item	2607787	et	4	main
kui	doc_491521502148_item	2607796	et	3	main
otsima	doc_491521502148_item	2607798	et	4	main
leninile	doc_491521502148_item	2607799	et	4	main
toredaid	doc_491521502148_item	2607802	et	3	main
kes	doc_491521502148_item	2607815	et	4	main
on	doc_491521502148_item	2607816	et	4	main
see	doc_491521502148_item	2607817	et	3	main
juurde	doc_491521502148_item	2607836	et	4	main
läks	doc_491521502148_item	2607837	et	3	main
film	doc_491521502148_item	2607842	et	3	main
osavalt	doc_491521502148_item	2607851	et	4	main
ja	doc_491521502148_item	2607852	et	3	main
toredalt	doc_491521502148_item	2607853	et	4	main
tark	doc_491521502148_item	2607621	et	3	main
kesküla	doc_491521502148_item	2607631	et	4	main
aitas	doc_491521502148_item	2607632	et	3	main
leninile	doc_491521502148_item	2607633	et	4	main
oli	doc_491521502148_item	2607640	et	3	main
kesküla	doc_491521502148_item	2607644	et	4	main
enamlaste	doc_491521502148_item	2607648	et	4	main
juhti	doc_491521502148_item	2607649	et	4	main
ja	doc_491521502148_item	2607657	et	3	main
luua	doc_491521502148_item	2607658	et	4	main
arvates	doc_491521502148_item	2607662	et	4	main
film	doc_491521502148_item	2607664	et	3	main
meelelahutuslik	doc_491521502148_item	2607667	et	3	main
hoolimata	doc_491521502148_item	2607668	et	4	main
nendest	doc_491521502148_item	2607669	et	4	main
stseenidest	doc_491521502148_item	2607670	et	3	main
kus	doc_491521502148_item	2607671	et	3	main
eriti	doc_491521502148_item	2607678	et	3	main
ja	doc_491521502148_item	2607685	et	3	main
leninile	doc_491521502148_item	2607687	et	4	main
kes	doc_491521502148_item	2607690	et	4	main
venemaale	doc_491521502148_item	2607693	et	4	main
nn	doc_491521502148_item	2607705	et	4	main
leninite	doc_491521502148_item	2607706	et	4	main
õpetama	doc_491521502148_item	2607710	et	3	main
teisikuid	doc_491521502148_item	2607712	et	4	main
nendest	doc_491521502148_item	2607714	et	4	main
teisikutest	doc_491521502148_item	2607715	et	4	main
kaks	doc_491521502148_item	2607725	et	3	main
vett	doc_491521502148_item	2607727	et	3	main
lenini	doc_491521502148_item	2607737	et	4	main
võimu	doc_491521502148_item	2607745	et	4	main
koha	doc_491521502148_item	2607750	et	4	main
originaalne	doc_491521502148_item	2607751	et	3	main
lenin	doc_491521502148_item	2607752	et	4	main
vastupidi	doc_491521502148_item	2607761	et	3	main
inimlik	doc_491521502148_item	2607763	et	3	main
filmi	doc_491521502148_item	2607788	et	4	main
teisikuid	doc_491521502148_item	2607800	et	4	main
stseene	doc_491521502148_item	2607803	et	3	main
nii	doc_491521502148_item	2607808	et	3	main
oli	doc_491521502148_item	2607821	et	3	main
vale-leninite	doc_491521502148_item	2607823	et	4	main
ja	doc_491521502148_item	2607825	et	3	main
kuidas	doc_491521502148_item	2607829	et	3	main
tahaks	doc_491521502148_item	2607839	et	3	main
öelda	doc_491521502148_item	2607840	et	4	main
päris	doc_491521502148_item	2607844	et	4	main
minu	doc_491521502148_item	2607661	et	3	main
see	doc_491521502148_item	2607663	et	3	main
on	doc_491521502148_item	2607665	et	4	main
ja	doc_491521502148_item	2607676	et	3	main
läheb	doc_491521502148_item	2607680	et	3	main
hea	doc_491521502148_item	2607699	et	4	main
organisaator	doc_491521502148_item	2607700	et	3	main
ja	doc_491521502148_item	2607701	et	3	main
kus	doc_491521502148_item	2607708	et	3	main
väga	doc_491521502148_item	2607717	et	3	main
välimuse	doc_491521502148_item	2607720	et	3	main
poolt	doc_491521502148_item	2607721	et	4	main
on	doc_491521502148_item	2607723	et	4	main
tilka	doc_491521502148_item	2607726	et	4	main
siiski	doc_491521502148_item	2607729	et	4	main
on	doc_491521502148_item	2607731	et	4	main
lenini	doc_491521502148_item	2607749	et	4	main
teisik	doc_491521502148_item	2607759	et	3	main
vastu	doc_491521502148_item	2607785	et	3	main
minu	doc_491521502148_item	2607786	et	3	main
algus	doc_491521502148_item	2607789	et	4	main
igav	doc_491521502148_item	2607792	et	3	main
läheb	doc_491521502148_item	2607794	et	3	main
hakatakse	doc_491521502148_item	2607797	et	3	main
enamus	doc_491521502148_item	2607801	et	4	main
põhinevad	doc_491521502148_item	2607806	et	4	main
saa	doc_491521502148_item	2607812	et	4	main
lenin	doc_491521502148_item	2607819	et	4	main
samuti	doc_491521502148_item	2607820	et	3	main
leidmine	doc_491521502148_item	2607826	et	4	main
meeldis	doc_491521502148_item	2607827	et	3	main
lenini	doc_491521502148_item	2607830	et	4	main
vanja	doc_491521502148_item	2607832	et	4	main
esimest	doc_491521502148_item	2607833	et	4	main
et	doc_491521502148_item	2607841	et	3	main
huvitav	doc_491521502148_item	2607845	et	4	main
ja	doc_491521502148_item	2607846	et	3	main
näitlejad	doc_491521502148_item	2607847	et	4	main
mängisid	doc_491521502148_item	2607848	et	4	main
kui	doc_491521502148_item	2607728	et	3	main
väga	doc_491521502148_item	2607732	et	3	main
oma	doc_491521502148_item	2607734	et	4	main
poolt	doc_491521502148_item	2607736	et	4	main
tõttu	doc_491521502148_item	2607746	et	4	main
originaalse	doc_491521502148_item	2607748	et	3	main
tema	doc_491521502148_item	2607758	et	4	main
on	doc_491521502148_item	2607765	et	4	main
lüüriline	doc_491521502148_item	2607766	et	3	main
iseloom	doc_491521502148_item	2607767	et	3	main
tõesti	doc_491521502148_item	2607769	et	3	main
on	doc_491521502148_item	2607768	et	4	main
nähtav	doc_491521502148_item	2607770	et	4	main
kuidas	doc_491521502148_item	2607771	et	3	main
ta	doc_491521502148_item	2607772	et	4	main
tunneb	doc_491521502148_item	2607773	et	3	main
kaasa	doc_491521502148_item	2607774	et	4	main
nadežda	doc_491521502148_item	2607775	et	2	main
krupskajale	doc_491521502148_item	2607776	et	4	main
ja	doc_491521502148_item	2607777	et	3	main
tunneb	doc_491521502148_item	2607779	et	3	main
kuidas	doc_491521502148_item	2607778	et	3	main
iha	doc_491521502148_item	2607780	et	4	main
armsa	doc_491521502148_item	2607781	et	3	main
revolutsionääri	doc_491521502148_item	2607782	et	4	main
inessa	doc_491521502148_item	2607783	et	4	main
on	doc_491521502148_item	2607790	et	4	main
siis	doc_491521502148_item	2607795	et	3	main
filmis	doc_491521502148_item	2607805	et	4	main
vahepeal	doc_491521502148_item	2607810	et	3	main
õige	doc_491521502148_item	2607818	et	4	main
ka	doc_491521502148_item	2607828	et	3	main
kokkuvõtteks	doc_491521502148_item	2607838	et	3	main
on	doc_491521502148_item	2607843	et	4	main
rolli	doc_491521502148_item	2607850	et	4	main
lõbus	doc_491521502148_item	2607822	et	4	main
otsimine	doc_491521502148_item	2607824	et	4	main
teisik	doc_491521502148_item	2607831	et	3	main
korda	doc_491521502148_item	2607834	et	4	main
krupskaja	doc_491521502148_item	2607835	et	4	main
oma	doc_491521502148_item	2607849	et	4	main
essee	doc_491521502151_item	2608264	et	4	main
minu	doc_491521502151_item	2608265	et	3	main
leninid	doc_491521502151_item	2608266	et	4	main
minu	doc_491521502151_item	2608267	et	3	main
arvates	doc_491521502151_item	2608268	et	4	main
see	doc_491521502151_item	2608269	et	3	main
oli	doc_491521502151_item	2608270	et	3	main
üsna	doc_491521502151_item	2608271	et	3	main
puhas	doc_491521502151_item	2608325	et	3	main
teisikud	doc_491521502151_item	2608336	et	3	main
tõesti	doc_491521502151_item	2608341	et	3	main
vaadates	doc_491521502151_item	2608343	et	3	main
filmi	doc_491521502151_item	2608345	et	4	main
olid	doc_491521502151_item	2608362	et	4	main
kõrged	doc_491521502151_item	2608363	et	3	main
eesmärgid	doc_491521502151_item	2608364	et	3	main
ja	doc_491521502151_item	2608365	et	3	main
suured	doc_491521502151_item	2608366	et	3	main
ootused	doc_491521502151_item	2608367	et	3	main
ja	doc_491521502152_item	2608390	et	3	main
ta	doc_491521502152_item	2608393	et	4	main
ellu	doc_491521502152_item	2608394	et	4	main
vaatamata	doc_491521502152_item	2608401	et	4	main
sellele	doc_491521502152_item	2608402	et	4	main
et	doc_491521502152_item	2608403	et	3	main
pidas	doc_491521502152_item	2608407	et	3	main
väitsid	doc_491521502152_item	2608419	et	4	main
et	doc_491521502152_item	2608420	et	3	main
oma	doc_491521502152_item	2608429	et	4	main
ja	doc_491521502152_item	2608433	et	3	main
huvitav	doc_491521502151_item	2608272	et	4	main
momendid	doc_491521502151_item	2608275	et	3	main
arusaamatud	doc_491521502151_item	2608279	et	4	main
poolest	doc_491521502151_item	2608282	et	4	main
erinevates	doc_491521502151_item	2608287	et	4	main
riikides	doc_491521502151_item	2608288	et	3	main
ja	doc_491521502151_item	2608289	et	3	main
mõnikord	doc_491521502151_item	2608290	et	3	main
oli	doc_491521502151_item	2608291	et	3	main
see	doc_491521502151_item	2608324	et	3	main
väljamõeldis	doc_491521502151_item	2608326	et	3	main
isikutel	doc_491521502151_item	2608333	et	4	main
tavaliselt	doc_491521502151_item	2608334	et	4	main
olid	doc_491521502151_item	2608335	et	4	main
nii	doc_491521502151_item	2608342	et	3	main
tegelane	doc_491521502151_item	2608354	et	3	main
teda	doc_491521502151_item	2608357	et	4	main
et	doc_491521502151_item	2608369	et	3	main
mõningad	doc_491521502152_item	2608395	et	3	main
oma	doc_491521502152_item	2608396	et	4	main
abikaasa	doc_491521502152_item	2608406	et	4	main
rumalusteks	doc_491521502152_item	2608409	et	4	main
nimetasid	doc_491521502152_item	2608411	et	4	main
revolutsionääriks	doc_491521502152_item	2608414	et	3	main
ta	doc_491521502152_item	2608421	et	4	main
ta	doc_491521502152_item	2608428	et	4	main
huvitavaimaks	doc_491521502152_item	2608432	et	4	main
silmapaistvaimaks	doc_491521502152_item	2608434	et	4	main
minu	doc_491521502152_item	2608436	et	3	main
hea	doc_491521502152_item	2608440	et	4	main
film	doc_491521502152_item	2608441	et	3	main
tõsielu	doc_491521502152_item	2608448	et	4	main
näitlejate	doc_491521502152_item	2608450	et	4	main
mäng	doc_491521502152_item	2608452	et	3	main
paneb	doc_491521502152_item	2608460	et	3	main
ootama	doc_491521502152_item	2608462	et	3	main
venemaal	doc_491521502152_item	2608481	et	4	main
ise	doc_491521502152_item	2608488	et	4	main
nende	doc_491521502152_item	2608491	et	4	main
valitsemisviis	doc_491521502152_item	2608493	et	3	main
film	doc_491521502151_item	2608273	et	3	main
natuke	doc_491521502151_item	2608277	et	4	main
keerukad	doc_491521502151_item	2608278	et	3	main
mõned	doc_491521502151_item	2608274	et	3	main
keerukad	doc_491521502151_item	2608280	et	3	main
või	doc_491521502151_item	2608322	et	4	main
küll	doc_491521502151_item	2608328	et	4	main
mind	doc_491521502151_item	2608347	et	4	main
kesküla	doc_491521502151_item	2608350	et	4	main
oli	doc_491521502151_item	2608351	et	3	main
nii	doc_491521502151_item	2608352	et	3	main
tähtis	doc_491521502151_item	2608353	et	4	main
kahju	doc_491521502151_item	2608368	et	4	main
nutikas	doc_491521502152_item	2608389	et	4	main
ideed	doc_491521502152_item	2608397	et	4	main
mis	doc_491521502152_item	2608398	et	4	main
puudutasid	doc_491521502152_item	2608399	et	4	main
suur-eestit	doc_491521502152_item	2608400	et	3	main
neid	doc_491521502152_item	2608408	et	4	main
mõned	doc_491521502152_item	2608410	et	3	main
olid	doc_491521502151_item	2608276	et	4	main
selle	doc_491521502151_item	2608281	et	4	main
et	doc_491521502151_item	2608283	et	3	main
oli	doc_491521502151_item	2608284	et	3	main
palju	doc_491521502151_item	2608285	et	4	main
stseene	doc_491521502151_item	2608286	et	3	main
raske	doc_491521502151_item	2608292	et	4	main
aru	doc_491521502151_item	2608293	et	4	main
saada	doc_491521502151_item	2608294	et	4	main
millist	doc_491521502151_item	2608295	et	3	main
rolli	doc_491521502151_item	2608296	et	4	main
mängivad	doc_491521502151_item	2608297	et	4	main
tegelased	doc_491521502151_item	2608298	et	3	main
ehk	doc_491521502151_item	2608299	et	3	main
keda	doc_491521502151_item	2608300	et	4	main
nad	doc_491521502151_item	2608301	et	3	main
kehastavad	doc_491521502151_item	2608302	et	4	main
ja	doc_491521502151_item	2608303	et	3	main
millised	doc_491521502151_item	2608304	et	3	main
on	doc_491521502151_item	2608305	et	4	main
nende	doc_491521502151_item	2608306	et	4	main
eesmärgid	doc_491521502151_item	2608307	et	3	main
pärast	doc_491521502151_item	2608308	et	4	main
filmi	doc_491521502151_item	2608309	et	4	main
mul	doc_491521502151_item	2608310	et	3	main
tekkis	doc_491521502151_item	2608311	et	3	main
palju	doc_491521502151_item	2608312	et	4	main
küsimusi	doc_491521502151_item	2608313	et	4	main
selle	doc_491521502151_item	2608314	et	4	main
kohta	doc_491521502151_item	2608315	et	4	main
et	doc_491521502151_item	2608316	et	3	main
kas	doc_491521502151_item	2608317	et	3	main
see	doc_491521502151_item	2608318	et	3	main
tõesti	doc_491521502151_item	2608319	et	3	main
juhtus	doc_491521502151_item	2608320	et	3	main
ajaloos	doc_491521502151_item	2608321	et	4	main
kuid	doc_491521502151_item	2608337	et	4	main
oli	doc_491521502151_item	2608340	et	3	main
et	doc_491521502151_item	2608349	et	3	main
aga	doc_491521502151_item	2608356	et	3	main
ei	doc_491521502151_item	2608359	et	4	main
kaval	doc_491521502152_item	2608391	et	4	main
viis	doc_491521502152_item	2608392	et	4	main
tema	doc_491521502152_item	2608405	et	4	main
teda	doc_491521502152_item	2608412	et	4	main
ohtlikuks	doc_491521502152_item	2608413	et	3	main
keda	doc_491521502152_item	2608415	et	4	main
osutus	doc_491521502152_item	2608427	et	4	main
ajastu	doc_491521502152_item	2608430	et	4	main
tegelaseks	doc_491521502152_item	2608435	et	3	main
leninid	doc_491521502152_item	2608437	et	4	main
oli	doc_491521502151_item	2608323	et	3	main
olen	doc_491521502151_item	2608327	et	3	main
teadlik	doc_491521502151_item	2608329	et	3	main
sellest	doc_491521502151_item	2608330	et	4	main
et	doc_491521502151_item	2608331	et	3	main
tähtsatel	doc_491521502151_item	2608332	et	3	main
kas	doc_491521502151_item	2608338	et	3	main
see	doc_491521502151_item	2608339	et	3	main
seda	doc_491521502151_item	2608344	et	3	main
imestas	doc_491521502151_item	2608346	et	3	main
see	doc_491521502151_item	2608348	et	3	main
ajaloos	doc_491521502151_item	2608355	et	4	main
üldse	doc_491521502151_item	2608358	et	3	main
tunta	doc_491521502151_item	2608360	et	3	main
tal	doc_491521502151_item	2608361	et	3	main
tema	doc_491521502151_item	2608370	et	4	main
teod	doc_491521502151_item	2608371	et	4	main
läksid	doc_491521502151_item	2608372	et	4	main
essee	doc_491521502152_item	2608374	et	4	main
raisku	doc_491521502151_item	2608373	et	4	main
arvustus	doc_491521502152_item	2608375	et	4	main
minu	doc_491521502152_item	2608376	et	3	main
leninid	doc_491521502152_item	2608377	et	4	main
1882	doc_491521502152_item	2608378	et	2	main
aastal	doc_491521502152_item	2608379	et	3	main
sündinud	doc_491521502152_item	2608380	et	4	main
aleksander	doc_491521502152_item	2608381	et	4	main
keskküla	doc_491521502152_item	2608382	et	4	main
oli	doc_491521502152_item	2608383	et	3	main
ilmtingimata	doc_491521502152_item	2608384	et	3	main
suur	doc_491521502152_item	2608385	et	3	main
eestimaa	doc_491521502152_item	2608386	et	4	main
patrioot	doc_491521502152_item	2608387	et	3	main
piisavalt	doc_491521502152_item	2608388	et	4	main
isegi	doc_491521502152_item	2608404	et	4	main
tõeliselt	doc_491521502152_item	2608416	et	4	main
kardeti	doc_491521502152_item	2608417	et	3	main
mõned	doc_491521502152_item	2608418	et	3	main
avantürist	doc_491521502152_item	2608424	et	3	main
kuid	doc_491521502152_item	2608425	et	4	main
kahtlemata	doc_491521502152_item	2608426	et	4	main
poliitilised	doc_491521502152_item	2608443	et	3	main
ja	doc_491521502152_item	2608447	et	3	main
sündmustega	doc_491521502152_item	2608449	et	3	main
suurepärane	doc_491521502152_item	2608451	et	4	main
vaatajat	doc_491521502152_item	2608454	et	4	main
sündmuste	doc_491521502152_item	2608463	et	3	main
võimule	doc_491521502152_item	2608482	et	3	main
teevad	doc_491521502152_item	2608483	et	3	main
kõike	doc_491521502152_item	2608484	et	4	main
et	doc_491521502152_item	2608485	et	3	main
venemaa	doc_491521502152_item	2608486	et	4	main
topeltmängu	doc_491521502152_item	2608499	et	4	main
toetades	doc_491521502152_item	2608500	et	3	main
et	doc_491521502152_item	2608521	et	3	main
teksti	doc_491521502152_item	2608534	et	4	main
oli	doc_491521502152_item	2608536	et	3	main
et	doc_491521502152_item	2608539	et	3	main
mis	doc_491521502152_item	2608541	et	4	main
olnud	doc_491521502152_item	2608548	et	4	main
keskküla	doc_491521502152_item	2608551	et	4	main
vaimustavalt	doc_491521502152_item	2608553	et	4	main
kaval	doc_491521502152_item	2608556	et	4	main
ideed	doc_491521502152_item	2608559	et	4	main
uhkuse	doc_491521502152_item	2608568	et	4	main
eesti	doc_491521502152_item	2608582	et	4	main
seal	doc_491521502152_item	2608587	et	4	main
ehtsad	doc_491521502152_item	2608589	et	3	main
patrioodid	doc_491521502152_item	2608590	et	3	main
eest	doc_491521502152_item	2608598	et	4	main
lõpuni	doc_491521502152_item	2608599	et	3	main
ta	doc_491521502152_item	2608622	et	4	main
välja	doc_491521502152_item	2608625	et	4	main
kuulutatud	doc_491521502152_item	2608626	et	4	main
minu	doc_491521502153_item	2608635	et	3	main
tragöödia	doc_491521502153_item	2608652	et	4	main
õpetati	doc_491521502153_item	2608659	et	3	main
et	doc_491521502153_item	2608660	et	3	main
lenin	doc_491521502153_item	2608661	et	4	main
selle	doc_491521502153_item	2608694	et	4	main
saab	doc_491521502153_item	2608699	et	3	main
lenini	doc_491521502153_item	2608713	et	4	main
partei	doc_491521502153_item	2608717	et	4	main
kui	doc_491521502153_item	2608720	et	3	main
ja	doc_491521502153_item	2608724	et	3	main
suheldes	doc_491521502153_item	2608726	et	3	main
tunne	doc_491521502153_item	2608736	et	4	main
et	doc_491521502153_item	2608737	et	3	main
oli	doc_491521502153_item	2608739	et	3	main
täiesti	doc_491521502153_item	2608740	et	3	main
ta	doc_491521502153_item	2608742	et	4	main
oska	doc_491521502153_item	2608747	et	4	main
ning	doc_491521502153_item	2608763	et	3	main
temaga	doc_491521502153_item	2608767	et	3	main
suhelda	doc_491521502153_item	2608769	et	4	main
ja	doc_491521502153_item	2608770	et	3	main
meelest	doc_491521502153_item	2608776	et	4	main
aleksander	doc_491521502153_item	2608781	et	4	main
kindlasti	doc_491521502153_item	2608790	et	3	main
tahab	doc_491521502153_item	2608793	et	3	main
vahel	doc_491521502153_item	2608805	et	4	main
et	doc_491521502153_item	2608808	et	3	main
ehitada	doc_491521502153_item	2608811	et	3	main
vene	doc_491521502153_item	2608814	et	4	main
impeeriumi	doc_491521502153_item	2608815	et	4	main
temal	doc_491521502153_item	2608824	et	3	main
ettevaatlikult	doc_491521502153_item	2608826	et	4	main
küll	doc_491521502153_item	2608834	et	4	main
afääri	doc_491521502153_item	2608838	et	4	main
oli	doc_491521502153_item	2608840	et	3	main
sõber	doc_491521502153_item	2608842	et	3	main
paljud	doc_491521502153_item	2608844	et	3	main
tema	doc_491521502153_item	2608846	et	4	main
oli	doc_491521502152_item	2608422	et	3	main
lihtsalt	doc_491521502152_item	2608423	et	4	main
üheks	doc_491521502152_item	2608431	et	3	main
on	doc_491521502152_item	2608438	et	4	main
mõjuavaldavalt	doc_491521502152_item	2608439	et	3	main
kus	doc_491521502152_item	2608442	et	3	main
vahelduvad	doc_491521502152_item	2608445	et	4	main
sundib	doc_491521502152_item	2608453	et	4	main
sügavalt	doc_491521502152_item	2608455	et	4	main
süveneda	doc_491521502152_item	2608456	et	3	main
kokku	doc_491521502152_item	2608489	et	3	main
mis	doc_491521502152_item	2608503	et	4	main
antud	doc_491521502152_item	2608504	et	4	main
saksa	doc_491521502152_item	2608505	et	4	main
saksa	doc_491521502152_item	2608506	et	4	main
valitsuse	doc_491521502152_item	2608507	et	4	main
poolt	doc_491521502152_item	2608508	et	4	main
ainus	doc_491521502152_item	2608509	et	4	main
eesmärk	doc_491521502152_item	2608510	et	3	main
oli	doc_491521502152_item	2608511	et	3	main
tema	doc_491521502152_item	2608512	et	4	main
kinnis-idee	doc_491521502152_item	2608513	et	4	main
suur-eestist	doc_491521502152_item	2608514	et	3	main
oma	doc_491521502152_item	2608515	et	4	main
idee	doc_491521502152_item	2608516	et	4	main
elluviimist	doc_491521502152_item	2608517	et	3	main
tagas	doc_491521502152_item	2608518	et	3	main
ta	doc_491521502152_item	2608519	et	4	main
sellega	doc_491521502152_item	2608520	et	3	main
leninile	doc_491521502152_item	2608532	et	4	main
kus	doc_491521502152_item	2608535	et	3	main
rahvusvähemused	doc_491521502152_item	2608540	et	4	main
on	doc_491521502152_item	2608545	et	4	main
ajalooliselt	doc_491521502152_item	2608546	et	4	main
iseseisvad	doc_491521502152_item	2608547	et	3	main
sooemaid	doc_491521502152_item	2608563	et	4	main
saksamaale	doc_491521502152_item	2608578	et	4	main
et	doc_491521502152_item	2608579	et	3	main
pisike	doc_491521502152_item	2608580	et	3	main
nõrk	doc_491521502152_item	2608581	et	3	main
et	doc_491521502152_item	2608586	et	3	main
kes	doc_491521502152_item	2608591	et	4	main
võimelised	doc_491521502152_item	2608593	et	4	main
isegi	doc_491521502152_item	2608600	et	4	main
minu	doc_491521502153_item	2608632	et	3	main
film	doc_491521502153_item	2608634	et	3	main
sellest	doc_491521502153_item	2608639	et	4	main
on	doc_491521502153_item	2608648	et	4	main
komöödia	doc_491521502153_item	2608649	et	4	main
see	doc_491521502153_item	2608655	et	3	main
praegusele	doc_491521502153_item	2608656	et	3	main
põlvkonnale	doc_491521502153_item	2608657	et	4	main
sõpradega	doc_491521502153_item	2608715	et	3	main
kaaslastega	doc_491521502153_item	2608718	et	4	main
ka	doc_491521502153_item	2608721	et	3	main
naise	doc_491521502153_item	2608723	et	3	main
ta	doc_491521502153_item	2608728	et	4	main
näidatud	doc_491521502153_item	2608730	et	4	main
lenin	doc_491521502153_item	2608738	et	4	main
segane	doc_491521502153_item	2608741	et	3	main
nt	doc_491521502153_item	2608761	et	4	main
võõras	doc_491521502153_item	2608765	et	4	main
vabalt	doc_491521502153_item	2608768	et	4	main
mängud	doc_491521502152_item	2608444	et	3	main
huumoriga	doc_491521502152_item	2608446	et	3	main
tegevusesse	doc_491521502152_item	2608458	et	4	main
ning	doc_491521502152_item	2608459	et	3	main
lenin	doc_491521502152_item	2608471	et	4	main
ja	doc_491521502152_item	2608472	et	3	main
tema	doc_491521502152_item	2608473	et	4	main
bolševikud	doc_491521502152_item	2608474	et	2	main
on	doc_491521502152_item	2608475	et	4	main
need	doc_491521502152_item	2608476	et	3	main
õiged	doc_491521502152_item	2608477	et	3	main
tegijad	doc_491521502152_item	2608478	et	4	main
variseks	doc_491521502152_item	2608487	et	4	main
olid	doc_491521502152_item	2608494	et	4	main
määratud	doc_491521502152_item	2608496	et	4	main
mängis	doc_491521502152_item	2608498	et	3	main
kinnitust	doc_491521502152_item	2608524	et	4	main
rahulepingu	doc_491521502152_item	2608533	et	3	main
selgelt	doc_491521502152_item	2608537	et	4	main
iseseisvuse	doc_491521502152_item	2608550	et	4	main
ja	doc_491521502152_item	2608555	et	3	main
tekitasid	doc_491521502152_item	2608560	et	4	main
minus	doc_491521502152_item	2608561	et	3	main
kõige	doc_491521502152_item	2608562	et	4	main
ja	doc_491521502152_item	2608564	et	3	main
paremaid	doc_491521502152_item	2608565	et	4	main
tundeid	doc_491521502152_item	2608566	et	3	main
selle	doc_491521502152_item	2608569	et	4	main
polegi	doc_491521502152_item	2608583	et	3	main
olles	doc_491521502152_item	2608601	et	3	main
kaugel	doc_491521502152_item	2608602	et	4	main
filmi	doc_491521502152_item	2608457	et	4	main
pingsalt	doc_491521502152_item	2608461	et	4	main
arenemist	doc_491521502152_item	2608464	et	4	main
peategelane	doc_491521502152_item	2608465	et	3	main
keskküla	doc_491521502152_item	2608466	et	4	main
pani	doc_491521502152_item	2608467	et	4	main
sakslased	doc_491521502152_item	2608468	et	3	main
uskuma	doc_491521502152_item	2608469	et	3	main
et	doc_491521502152_item	2608470	et	3	main
kes	doc_491521502152_item	2608479	et	4	main
jõudes	doc_491521502152_item	2608480	et	3	main
kuna	doc_491521502152_item	2608490	et	3	main
ideed	doc_491521502152_item	2608492	et	4	main
hukkumisele	doc_491521502152_item	2608495	et	4	main
keskküla	doc_491521502152_item	2608497	et	4	main
rahaliselt	doc_491521502152_item	2608501	et	4	main
leninit	doc_491521502152_item	2608502	et	4	main
sakslaselt	doc_491521502152_item	2608523	et	3	main
et	doc_491521502152_item	2608525	et	3	main
saksamaa	doc_491521502152_item	2608526	et	4	main
dikteeris	doc_491521502152_item	2608531	et	3	main
kuid	doc_491521502152_item	2608544	et	4	main
oli	doc_491521502152_item	2608552	et	3	main
enesekindel	doc_491521502152_item	2608554	et	3	main
tema	doc_491521502152_item	2608557	et	4	main
ka	doc_491521502152_item	2608567	et	3	main
inimese	doc_491521502152_item	2608570	et	4	main
kes	doc_491521502152_item	2608572	et	4	main
tõestada	doc_491521502152_item	2608574	et	3	main
suurele	doc_491521502152_item	2608575	et	4	main
ja	doc_491521502152_item	2608576	et	3	main
võimsale	doc_491521502152_item	2608577	et	3	main
nõrk	doc_491521502152_item	2608585	et	3	main
on	doc_491521502152_item	2608592	et	4	main
võistlema	doc_491521502152_item	2608594	et	3	main
oma	doc_491521502152_item	2608595	et	4	main
rahva	doc_491521502152_item	2608596	et	3	main
oma	doc_491521502152_item	2608603	et	4	main
isamaast	doc_491521502152_item	2608604	et	3	main
ning	doc_491521502152_item	2608605	et	3	main
seal	doc_491521502152_item	2608623	et	4	main
revolutsioonilised	doc_491521502152_item	2608628	et	4	main
meeleavaldused	doc_491521502152_item	2608629	et	3	main
leninid	doc_491521502153_item	2608636	et	4	main
natuke	doc_491521502153_item	2608638	et	4	main
filmist	doc_491521502153_item	2608640	et	4	main
oma	doc_491521502153_item	2608641	et	4	main
muljed	doc_491521502153_item	2608642	et	3	main
avaldada	doc_491521502153_item	2608643	et	3	main
ühelt	doc_491521502153_item	2608644	et	3	main
teiselt	doc_491521502153_item	2608650	et	4	main
aga	doc_491521502153_item	2608651	et	3	main
kellele	doc_491521502153_item	2608658	et	4	main
on	doc_491521502153_item	2608668	et	4	main
sündinud	doc_491521502153_item	2608669	et	4	main
filmi	doc_491521502153_item	2608695	et	4	main
vaatama	doc_491521502153_item	2608696	et	3	main
lenin	doc_491521502153_item	2608707	et	4	main
filmis	doc_491521502153_item	2608710	et	4	main
on	doc_491521502153_item	2608711	et	4	main
elu	doc_491521502153_item	2608714	et	4	main
suheldes	doc_491521502153_item	2608719	et	3	main
nõudis	doc_491521502152_item	2608522	et	3	main
ei	doc_491521502152_item	2608527	et	4	main
okupeeri	doc_491521502152_item	2608528	et	4	main
eestit	doc_491521502152_item	2608529	et	3	main
ning	doc_491521502152_item	2608530	et	3	main
kirjas	doc_491521502152_item	2608538	et	4	main
kuuluvad	doc_491521502152_item	2608542	et	4	main
venemaale	doc_491521502152_item	2608543	et	4	main
saavad	doc_491521502152_item	2608549	et	4	main
patriootlikud	doc_491521502152_item	2608558	et	3	main
üle	doc_491521502152_item	2608571	et	3	main
suutis	doc_491521502152_item	2608573	et	3	main
nii	doc_491521502152_item	2608584	et	3	main
sündivad	doc_491521502152_item	2608588	et	4	main
iseseisvuse	doc_491521502152_item	2608597	et	4	main
elades	doc_491521502152_item	2608606	et	4	main
suhteliselt	doc_491521502152_item	2608607	et	4	main
hästi	doc_491521502152_item	2608608	et	3	main
ei	doc_491521502152_item	2608609	et	4	main
suutnud	doc_491521502152_item	2608610	et	4	main
keskküla	doc_491521502152_item	2608611	et	4	main
loobuda	doc_491521502152_item	2608612	et	3	main
sellest	doc_491521502152_item	2608613	et	4	main
millega	doc_491521502152_item	2608614	et	3	main
tegeles	doc_491521502152_item	2608615	et	3	main
ta	doc_491521502152_item	2608616	et	4	main
kodumaal	doc_491521502152_item	2608617	et	4	main
ja	doc_491521502152_item	2608618	et	3	main
mille	doc_491521502152_item	2608619	et	3	main
eest	doc_491521502152_item	2608620	et	4	main
oli	doc_491521502152_item	2608621	et	3	main
tagaotsitavaks	doc_491521502152_item	2608624	et	3	main
leninid	doc_491521502153_item	2608633	et	4	main
poolt	doc_491521502153_item	2608645	et	4	main
võttes	doc_491521502153_item	2608646	et	4	main
see	doc_491521502153_item	2608647	et	3	main
komöödiaks	doc_491521502153_item	2608653	et	4	main
on	doc_491521502153_item	2608662	et	4	main
täitsa	doc_491521502153_item	2608663	et	3	main
õigel	doc_491521502153_item	2608670	et	3	main
ta	doc_491521502153_item	2608698	et	4	main
lausa	doc_491521502153_item	2608700	et	4	main
sest	doc_491521502153_item	2608702	et	4	main
on	doc_491521502153_item	2608708	et	4	main
pühalik	doc_491521502153_item	2608709	et	3	main
ja	doc_491521502153_item	2608716	et	3	main
väga	doc_491521502153_item	2608731	et	3	main
igal	doc_491521502153_item	2608744	et	3	main
lihtsamaid	doc_491521502153_item	2608750	et	4	main
meestetöid	doc_491521502153_item	2608751	et	3	main
teha	doc_491521502153_item	2608752	et	3	main
igaüks	doc_491521502153_item	2608764	et	3	main
polnud	doc_491521502153_item	2608778	et	3	main
näidanud	doc_491521502153_item	2608785	et	4	main
filmis	doc_491521502153_item	2608786	et	4	main
sellise	doc_491521502153_item	2608787	et	4	main
kuidas	doc_491521502153_item	2608796	et	3	main
balanseerib	doc_491521502153_item	2608798	et	4	main
venemaa	doc_491521502153_item	2608801	et	4	main
vahel	doc_491521502153_item	2608802	et	4	main
ja	doc_491521502153_item	2608803	et	3	main
tahtis	doc_491521502153_item	2608810	et	3	main
eestit	doc_491521502153_item	2608813	et	3	main
ning	doc_491521502153_item	2608817	et	3	main
skandinaaviaga	doc_491521502153_item	2608820	et	4	main
ta	doc_491521502153_item	2608832	et	4	main
valitsused	doc_491521502153_item	2608853	et	4	main
nimelt	doc_491521502152_item	2608627	et	4	main
streigid	doc_491521502152_item	2608630	et	4	main
ülestõusud	doc_491521502152_item	2608631	et	3	main
tahaks	doc_491521502153_item	2608637	et	3	main
on	doc_491521502153_item	2608654	et	4	main
tavaline	doc_491521502153_item	2608664	et	4	main
inimene	doc_491521502153_item	2608665	et	3	main
vaid	doc_491521502153_item	2608666	et	3	main
ta	doc_491521502153_item	2608667	et	4	main
ajal	doc_491521502153_item	2608671	et	4	main
sellepärast	doc_491521502153_item	2608672	et	3	main
tal	doc_491521502153_item	2608673	et	3	main
õnnestus	doc_491521502153_item	2608674	et	4	main
maailma	doc_491521502153_item	2608675	et	4	main
ajalugu	doc_491521502153_item	2608676	et	4	main
muuta	doc_491521502153_item	2608677	et	4	main
tänapäevased	doc_491521502153_item	2608678	et	4	main
noored	doc_491521502153_item	2608679	et	3	main
ei	doc_491521502153_item	2608680	et	4	main
tea	doc_491521502153_item	2608681	et	4	main
temast	doc_491521502153_item	2608682	et	3	main
ja	doc_491521502153_item	2608683	et	3	main
tema	doc_491521502153_item	2608684	et	4	main
elust	doc_491521502153_item	2608685	et	3	main
peaaegu	doc_491521502153_item	2608686	et	3	main
mitte	doc_491521502153_item	2608687	et	3	main
midagi	doc_491521502153_item	2608688	et	4	main
kui	doc_491521502153_item	2608689	et	3	main
aga	doc_491521502153_item	2608690	et	3	main
mingi	doc_491521502153_item	2608691	et	4	main
vanaema	doc_491521502153_item	2608692	et	4	main
hakkab	doc_491521502153_item	2608693	et	3	main
siis	doc_491521502153_item	2608697	et	3	main
infarkti	doc_491521502153_item	2608701	et	4	main
tema	doc_491521502153_item	2608703	et	4	main
ajal	doc_491521502153_item	2608704	et	4	main
õpetati	doc_491521502153_item	2608705	et	3	main
et	doc_491521502153_item	2608706	et	3	main
näidatud	doc_491521502153_item	2608712	et	4	main
oma	doc_491521502153_item	2608722	et	4	main
armukesega	doc_491521502153_item	2608725	et	4	main
selline	doc_491521502153_item	2608735	et	4	main
karjub	doc_491521502153_item	2608743	et	3	main
tema	doc_491521502153_item	2608753	et	4	main
igaühet	doc_491521502153_item	2608760	et	3	main
võib	doc_491521502153_item	2608766	et	3	main
on	doc_491521502153_item	2608784	et	4	main
kes	doc_491521502153_item	2608789	et	4	main
huvitav	doc_491521502153_item	2608795	et	4	main
ja	doc_491521502153_item	2608800	et	3	main
ta	doc_491521502153_item	2608809	et	4	main
suurt	doc_491521502153_item	2608812	et	3	main
ühendada	doc_491521502153_item	2608818	et	3	main
ning	doc_491521502153_item	2608727	et	3	main
on	doc_491521502153_item	2608729	et	4	main
negatiivselt	doc_491521502153_item	2608732	et	4	main
sellest	doc_491521502153_item	2608733	et	4	main
tuleb	doc_491521502153_item	2608734	et	3	main
võimalusel	doc_491521502153_item	2608745	et	3	main
ei	doc_491521502153_item	2608746	et	4	main
isegi	doc_491521502153_item	2608748	et	4	main
kõige	doc_491521502153_item	2608749	et	4	main
ei	doc_491521502153_item	2608754	et	4	main
ole	doc_491521502153_item	2608755	et	4	main
partei	doc_491521502153_item	2608756	et	4	main
liider	doc_491521502153_item	2608757	et	3	main
ning	doc_491521502153_item	2608758	et	3	main
usub	doc_491521502153_item	2608759	et	3	main
keskülat	doc_491521502153_item	2608762	et	4	main
heaks	doc_491521502153_item	2608772	et	4	main
sõbraks	doc_491521502153_item	2608773	et	3	main
kuid	doc_491521502153_item	2608774	et	4	main
mu	doc_491521502153_item	2608775	et	3	main
päris	doc_491521502153_item	2608779	et	4	main
kesküla	doc_491521502153_item	2608782	et	4	main
ak	doc_491521502153_item	2608783	et	4	main
inimesena	doc_491521502153_item	2608788	et	3	main
mida	doc_491521502153_item	2608792	et	4	main
enamlaste	doc_491521502153_item	2608804	et	4	main
eestit	doc_491521502153_item	2608819	et	3	main
ja	doc_491521502153_item	2608821	et	3	main
monarhiat	doc_491521502153_item	2608823	et	3	main
tuli	doc_491521502153_item	2608825	et	4	main
käituda	doc_491521502153_item	2608827	et	3	main
et	doc_491521502153_item	2608828	et	3	main
vahele	doc_491521502153_item	2608830	et	4	main
jääda	doc_491521502153_item	2608831	et	4	main
kõikidele	doc_491521502153_item	2608841	et	4	main
ja	doc_491521502153_item	2608843	et	3	main
lenin	doc_491521502153_item	2608849	et	4	main
ja	doc_491521502153_item	2608850	et	3	main
mulle	doc_491521502153_item	2608859	et	4	main
meeldis	doc_491521502153_item	2608860	et	3	main
teisikuid	doc_491521502153_item	2608864	et	4	main
neid	doc_491521502153_item	2608866	et	4	main
kõik	doc_491521502153_item	2608873	et	4	main
leninist	doc_491521502153_item	2608877	et	4	main
on	doc_491521502153_item	2608920	et	4	main
saadab	doc_491521502153_item	2608928	et	3	main
näitab	doc_491521502153_item	2608940	et	3	main
korral	doc_491521502153_item	2608954	et	4	main
ta	doc_491521502153_item	2608961	et	4	main
sellest	doc_491521502153_item	2608972	et	4	main
ei	doc_491521502153_item	2608978	et	4	main
meeldinud	doc_491521502153_item	2608981	et	4	main
päris	doc_491521502153_item	2609017	et	4	main
lenin	doc_491521502153_item	2609032	et	4	main
ta	doc_491521502153_item	2609057	et	4	main
jookseb	doc_491521502153_item	2609058	et	3	main
tekki	doc_491521502153_item	2609063	et	4	main
see	doc_491521502153_item	2609080	et	3	main
mitte	doc_491521502153_item	2609084	et	3	main
kes	doc_491521502153_item	2609086	et	4	main
teinud	doc_491521502153_item	2609088	et	4	main
revolutsiooni	doc_491521502153_item	2609089	et	4	main
saada	doc_491521502153_item	2608771	et	4	main
see	doc_491521502153_item	2608777	et	3	main
nii	doc_491521502153_item	2608780	et	3	main
teab	doc_491521502153_item	2608791	et	3	main
on	doc_491521502153_item	2608794	et	4	main
ta	doc_491521502153_item	2608797	et	4	main
saksamaa	doc_491521502153_item	2608799	et	4	main
teeb	doc_491521502153_item	2608806	et	3	main
imet	doc_491521502153_item	2608807	et	3	main
varemetel	doc_491521502153_item	2608816	et	4	main
teha	doc_491521502153_item	2608822	et	3	main
mitte	doc_491521502153_item	2608829	et	3	main
arukas	doc_491521502153_item	2608835	et	4	main
sest	doc_491521502153_item	2608836	et	4	main
teisikutega	doc_491521502153_item	2608839	et	3	main
euroopa	doc_491521502153_item	2608851	et	4	main
kuidas	doc_491521502153_item	2608861	et	3	main
koolis	doc_491521502153_item	2608868	et	4	main
kuulnud	doc_491521502153_item	2608879	et	4	main
räägimata	doc_491521502153_item	2608880	et	4	main
oli	doc_491521502153_item	2608833	et	3	main
mõtles	doc_491521502153_item	2608837	et	3	main
võtsid	doc_491521502153_item	2608845	et	4	main
isegi	doc_491521502153_item	2608848	et	4	main
neid	doc_491521502153_item	2608855	et	4	main
selles	doc_491521502153_item	2608857	et	4	main
filmis	doc_491521502153_item	2608858	et	4	main
õpetati	doc_491521502153_item	2608867	et	3	main
aga	doc_491521502153_item	2608882	et	3	main
nad	doc_491521502153_item	2608883	et	3	main
olid	doc_491521502153_item	2608884	et	4	main
oma	doc_491521502153_item	2608885	et	4	main
õpingutel	doc_491521502153_item	2608886	et	3	main
nii	doc_491521502153_item	2608887	et	3	main
edukad	doc_491521502153_item	2608888	et	3	main
et	doc_491521502153_item	2608889	et	3	main
filmi	doc_491521502153_item	2608890	et	4	main
lõpuks	doc_491521502153_item	2608891	et	4	main
oli	doc_491521502153_item	2608892	et	3	main
raske	doc_491521502153_item	2608893	et	4	main
aru	doc_491521502153_item	2608894	et	4	main
saada	doc_491521502153_item	2608895	et	4	main
kus	doc_491521502153_item	2608896	et	3	main
on	doc_491521502153_item	2608897	et	4	main
teisik	doc_491521502153_item	2608898	et	3	main
aga	doc_491521502153_item	2608899	et	3	main
kus	doc_491521502153_item	2608900	et	3	main
on	doc_491521502153_item	2608901	et	4	main
lenin	doc_491521502153_item	2608902	et	4	main
oli	doc_491521502153_item	2608903	et	3	main
ka	doc_491521502153_item	2608904	et	3	main
põnev	doc_491521502153_item	2608905	et	3	main
kui	doc_491521502153_item	2608906	et	3	main
lenin	doc_491521502153_item	2608907	et	4	main
näitas	doc_491521502153_item	2608908	et	3	main
end	doc_491521502153_item	2608909	et	4	main
väga	doc_491521502153_item	2608910	et	3	main
impulsiivsena	doc_491521502153_item	2608911	et	3	main
eriti	doc_491521502153_item	2608912	et	3	main
filmi	doc_491521502153_item	2608913	et	4	main
lõpus	doc_491521502153_item	2608914	et	4	main
kus	doc_491521502153_item	2608915	et	3	main
ta	doc_491521502153_item	2608916	et	4	main
tõestab	doc_491521502153_item	2608917	et	3	main
mängureeglid	doc_491521502153_item	2608847	et	3	main
riikide	doc_491521502153_item	2608852	et	3	main
igaltpoolt	doc_491521502153_item	2608862	et	4	main
otsiti	doc_491521502153_item	2608863	et	3	main
kuidas	doc_491521502153_item	2608865	et	3	main
nad	doc_491521502153_item	2608870	et	3	main
omavahel	doc_491521502153_item	2608871	et	3	main
midagi	doc_491521502153_item	2608878	et	4	main
nägemisest	doc_491521502153_item	2608881	et	4	main
ta	doc_491521502153_item	2608927	et	4	main
trükikotta	doc_491521502153_item	2608930	et	4	main
rohkem	doc_491521502153_item	2608932	et	4	main
meeldis	doc_491521502153_item	2608934	et	3	main
kui	doc_491521502153_item	2608935	et	3	main
teisikute	doc_491521502153_item	2608936	et	3	main
koolis	doc_491521502153_item	2608937	et	4	main
teisikutele	doc_491521502153_item	2608941	et	3	main
käed	doc_491521502153_item	2608949	et	3	main
mida	doc_491521502153_item	2608951	et	4	main
ta	doc_491521502153_item	2608956	et	4	main
nii	doc_491521502153_item	2608958	et	3	main
on	doc_491521502153_item	2608962	et	4	main
rolliga	doc_491521502153_item	2608964	et	4	main
kõvasti	doc_491521502153_item	2608966	et	3	main
elanud	doc_491521502153_item	2608968	et	4	main
panna	doc_491521502153_item	2609010	et	4	main
ta	doc_491521502153_item	2609011	et	4	main
hakkab	doc_491521502153_item	2609012	et	3	main
karjuma	doc_491521502153_item	2609013	et	3	main
et	doc_491521502153_item	2609014	et	3	main
ta	doc_491521502153_item	2609015	et	4	main
teistele	doc_491521502153_item	2609022	et	4	main
et	doc_491521502153_item	2609023	et	3	main
lenin	doc_491521502153_item	2609025	et	4	main
kui	doc_491521502153_item	2609028	et	3	main
teisik	doc_491521502153_item	2609029	et	3	main
ja	doc_491521502153_item	2609030	et	3	main
ak	doc_491521502153_item	2609037	et	4	main
päris	doc_491521502153_item	2609042	et	4	main
lukku	doc_491521502153_item	2609045	et	4	main
alla	doc_491521502153_item	2609046	et	3	main
ära	doc_491521502153_item	2609049	et	4	main
ning	doc_491521502153_item	2609051	et	3	main
oma	doc_491521502153_item	2609054	et	4	main
armukest	doc_491521502153_item	2609055	et	4	main
teisikuga	doc_491521502153_item	2609056	et	3	main
saab	doc_491521502153_item	2609066	et	3	main
ootamatu	doc_491521502153_item	2609068	et	4	main
inimese	doc_491521502153_item	2609073	et	4	main
tõsi	doc_491521502153_item	2609082	et	4	main
komöödia	doc_491521502153_item	2609121	et	4	main
meist	doc_491521502153_item	2609130	et	3	main
ning	doc_491521502153_item	2609133	et	3	main
surnud	doc_491521502153_item	2609139	et	4	main
ja	doc_491521502153_item	2609140	et	3	main
nende	doc_491521502153_item	2609141	et	4	main
võib	doc_491521502153_item	2609145	et	3	main
see	doc_491521502153_item	2609148	et	3	main
on	doc_491521502153_item	2609150	et	4	main
üldiselt	doc_491521502153_item	2609152	et	4	main
film	doc_491521502153_item	2609154	et	3	main
seda	doc_491521502153_item	2609164	et	3	main
veel	doc_491521502153_item	2609165	et	4	main
arusaamatutest	doc_491521502153_item	2609171	et	4	main
essee	doc_491521502154_item	2609175	et	4	main
minu	doc_491521502154_item	2609176	et	3	main
leninid	doc_491521502154_item	2609177	et	4	main
leninid	doc_491521502154_item	2609183	et	4	main
võtsid	doc_491521502154_item	2609185	et	4	main
osa	doc_491521502154_item	2609186	et	4	main
väga	doc_491521502154_item	2609187	et	3	main
näitlejad	doc_491521502154_item	2609192	et	4	main
nad	doc_491521502154_item	2609193	et	3	main
oskavad	doc_491521502154_item	2609194	et	4	main
mees	doc_491521502154_item	2609211	et	4	main
tal	doc_491521502154_item	2609212	et	3	main
olid	doc_491521502154_item	2609213	et	4	main
väga	doc_491521502154_item	2609214	et	3	main
suured	doc_491521502154_item	2609215	et	3	main
kohta	doc_491521502154_item	2609218	et	4	main
võtsid	doc_491521502153_item	2608854	et	4	main
vastu	doc_491521502153_item	2608856	et	3	main
kuidas	doc_491521502153_item	2608869	et	3	main
suhtlesid	doc_491521502153_item	2608872	et	4	main
lenini	doc_491521502153_item	2608874	et	4	main
teisikud	doc_491521502153_item	2608875	et	3	main
polnud	doc_491521502153_item	2608876	et	3	main
et	doc_491521502153_item	2608918	et	3	main
ta	doc_491521502153_item	2608919	et	4	main
lenin	doc_491521502153_item	2608922	et	4	main
filmi	doc_491521502153_item	2608924	et	4	main
ta	doc_491521502153_item	2608943	et	4	main
kuidas	doc_491521502153_item	2608945	et	3	main
paneb	doc_491521502153_item	2608948	et	3	main
ja	doc_491521502153_item	2608950	et	3	main
teeb	doc_491521502153_item	2608952	et	3	main
ja	doc_491521502153_item	2608960	et	3	main
õpetaja	doc_491521502153_item	2608963	et	4	main
mis	doc_491521502153_item	2608973	et	4	main
mulle	doc_491521502153_item	2608974	et	4	main
meeldinud	doc_491521502153_item	2608979	et	4	main
leninit	doc_491521502153_item	2609041	et	4	main
pannakse	doc_491521502153_item	2609044	et	3	main
nende	doc_491521502153_item	2609059	et	4	main
merele	doc_491521502153_item	2609064	et	3	main
või	doc_491521502153_item	2609083	et	4	main
aga	doc_491521502153_item	2609124	et	3	main
paneb	doc_491521502153_item	2609126	et	3	main
et	doc_491521502153_item	2609128	et	3	main
asemel	doc_491521502153_item	2609142	et	4	main
küsimus	doc_491521502153_item	2609149	et	4	main
see	doc_491521502153_item	2609153	et	3	main
pärast	doc_491521502153_item	2609163	et	4	main
vaadata	doc_491521502153_item	2609167	et	4	main
midagi	doc_491521502153_item	2609170	et	4	main
saavad	doc_491521502153_item	2609173	et	4	main
tuntud	doc_491521502154_item	2609188	et	4	main
oma	doc_491521502154_item	2609195	et	4	main
filmi	doc_491521502154_item	2609200	et	4	main
plaanid	doc_491521502154_item	2609216	et	4	main
tahtis	doc_491521502154_item	2609220	et	3	main
kõike	doc_491521502154_item	2609235	et	4	main
mis	doc_491521502154_item	2609236	et	4	main
tema	doc_491521502154_item	2609238	et	4	main
oskas	doc_491521502154_item	2609251	et	3	main
ja	doc_491521502154_item	2609253	et	3	main
õppis	doc_491521502154_item	2609266	et	3	main
ühine	doc_491521502154_item	2609278	et	4	main
rahvusele	doc_491521502154_item	2609283	et	3	main
ta	doc_491521502154_item	2609287	et	4	main
selleks	doc_491521502154_item	2609290	et	4	main
kesküla	doc_491521502154_item	2609291	et	4	main
kohas	doc_491521502154_item	2609297	et	4	main
ja	doc_491521502154_item	2609298	et	3	main
keskel	doc_491521502153_item	2608925	et	3	main
kui	doc_491521502153_item	2608926	et	3	main
zinovjevi	doc_491521502153_item	2608929	et	4	main
päris	doc_491521502153_item	2608938	et	4	main
kuidas	doc_491521502153_item	2608942	et	3	main
räägib	doc_491521502153_item	2608946	et	3	main
ohu	doc_491521502153_item	2608953	et	3	main
õpetab	doc_491521502153_item	2608957	et	3	main
impulsiivselt	doc_491521502153_item	2608959	et	4	main
kokku	doc_491521502153_item	2608967	et	3	main
nüüd	doc_491521502153_item	2608969	et	4	main
natuke	doc_491521502153_item	2608970	et	4	main
räägin	doc_491521502153_item	2608971	et	3	main
arusaamatuks	doc_491521502153_item	2608976	et	4	main
ning	doc_491521502153_item	2608977	et	3	main
ei	doc_491521502153_item	2608980	et	4	main
see	doc_491521502153_item	2608982	et	3	main
et	doc_491521502153_item	2608983	et	3	main
missugune	doc_491521502153_item	2608984	et	3	main
oli	doc_491521502153_item	2608985	et	3	main
filmi	doc_491521502153_item	2608986	et	4	main
lõpp	doc_491521502153_item	2608987	et	3	main
film	doc_491521502153_item	2608988	et	3	main
lõppes	doc_491521502153_item	2608989	et	4	main
sellega	doc_491521502153_item	2608990	et	3	main
et	doc_491521502153_item	2608991	et	3	main
leninit	doc_491521502153_item	2608992	et	4	main
pandi	doc_491521502153_item	2608993	et	4	main
eraldi	doc_491521502153_item	2608994	et	4	main
kajutisse	doc_491521502153_item	2608995	et	3	main
kus	doc_491521502153_item	2608996	et	3	main
ta	doc_491521502153_item	2608997	et	4	main
sai	doc_491521502153_item	2608998	et	4	main
aru	doc_491521502153_item	2608999	et	4	main
et	doc_491521502153_item	2609000	et	3	main
temast	doc_491521502153_item	2609001	et	3	main
tahetakse	doc_491521502153_item	2609002	et	4	main
võimu	doc_491521502153_item	2609003	et	4	main
ära	doc_491521502153_item	2609004	et	4	main
võtta	doc_491521502153_item	2609005	et	3	main
ning	doc_491521502153_item	2609006	et	3	main
tema	doc_491521502153_item	2609007	et	4	main
asemele	doc_491521502153_item	2609008	et	4	main
teisikut	doc_491521502153_item	2609009	et	3	main
ehtne	doc_491521502153_item	2608921	et	3	main
ning	doc_491521502153_item	2608923	et	3	main
kõige	doc_491521502153_item	2608931	et	4	main
mulle	doc_491521502153_item	2608933	et	4	main
lenin	doc_491521502153_item	2608939	et	4	main
käitub	doc_491521502153_item	2608944	et	3	main
kuhu	doc_491521502153_item	2608947	et	3	main
ja	doc_491521502153_item	2608955	et	3	main
nii	doc_491521502153_item	2608965	et	3	main
jääks	doc_491521502153_item	2608975	et	4	main
on	doc_491521502153_item	2609016	et	4	main
lenin	doc_491521502153_item	2609018	et	4	main
aga	doc_491521502153_item	2609019	et	3	main
ak	doc_491521502153_item	2609020	et	4	main
tulevad	doc_491521502153_item	2609033	et	4	main
tuppa	doc_491521502153_item	2609034	et	3	main
siis	doc_491521502153_item	2609035	et	3	main
kõik	doc_491521502153_item	2609036	et	4	main
kust	doc_491521502153_item	2609047	et	4	main
ja	doc_491521502153_item	2609065	et	3	main
surma	doc_491521502153_item	2609067	et	4	main
ja	doc_491521502153_item	2609069	et	3	main
imelik	doc_491521502153_item	2609070	et	3	main
surm	doc_491521502153_item	2609071	et	3	main
selle	doc_491521502153_item	2609072	et	4	main
kas	doc_491521502153_item	2609079	et	3	main
ja	doc_491521502153_item	2609085	et	3	main
on	doc_491521502153_item	2609087	et	4	main
lenin	doc_491521502153_item	2609090	et	4	main
ise	doc_491521502153_item	2609091	et	4	main
või	doc_491521502153_item	2609092	et	4	main
tema	doc_491521502153_item	2609093	et	4	main
teisikud	doc_491521502153_item	2609094	et	3	main
keda	doc_491521502153_item	2609095	et	4	main
manipuleeriti	doc_491521502153_item	2609096	et	3	main
mõned	doc_491521502153_item	2609097	et	3	main
jõud	doc_491521502153_item	2609098	et	4	main
tahtsid	doc_491521502153_item	2609099	et	4	main
leninist	doc_491521502153_item	2609100	et	4	main
lahti	doc_491521502153_item	2609101	et	4	main
saada	doc_491521502153_item	2609102	et	4	main
ja	doc_491521502153_item	2609103	et	3	main
teisikud	doc_491521502153_item	2609104	et	3	main
selle	doc_491521502153_item	2609105	et	4	main
jaoks	doc_491521502153_item	2609106	et	4	main
hästi	doc_491521502153_item	2609107	et	3	main
sobisid	doc_491521502153_item	2609108	et	4	main
ning	doc_491521502153_item	2609109	et	3	main
igaüks	doc_491521502153_item	2609110	et	3	main
neist	doc_491521502153_item	2609111	et	4	main
mängis	doc_491521502153_item	2609112	et	3	main
oma	doc_491521502153_item	2609113	et	4	main
rolli	doc_491521502153_item	2609114	et	4	main
mingil	doc_491521502153_item	2609115	et	4	main
ajal	doc_491521502153_item	2609116	et	4	main
see	doc_491521502153_item	2609117	et	3	main
film	doc_491521502153_item	2609118	et	3	main
on	doc_491521502153_item	2609119	et	4	main
tehtud	doc_491521502153_item	2609120	et	4	main
kuid	doc_491521502153_item	2609123	et	4	main
mõtlema	doc_491521502153_item	2609127	et	3	main
igaühel	doc_491521502153_item	2609129	et	3	main
on	doc_491521502153_item	2609131	et	4	main
võib	doc_491521502153_item	2609134	et	3	main
suured	doc_491521502153_item	2609136	et	3	main
seletab	doc_491521502153_item	2609021	et	3	main
ehtne	doc_491521502153_item	2609024	et	3	main
on	doc_491521502153_item	2609026	et	4	main
rahulik	doc_491521502153_item	2609027	et	3	main
päris	doc_491521502153_item	2609031	et	4	main
abil	doc_491521502153_item	2609038	et	4	main
näevad	doc_491521502153_item	2609039	et	3	main
teisikus	doc_491521502153_item	2609040	et	3	main
leninit	doc_491521502153_item	2609043	et	4	main
ta	doc_491521502153_item	2609048	et	4	main
jookseb	doc_491521502153_item	2609050	et	3	main
näeb	doc_491521502153_item	2609052	et	3	main
laeval	doc_491521502153_item	2609053	et	3	main
juurde	doc_491521502153_item	2609060	et	4	main
kukkub	doc_491521502153_item	2609061	et	4	main
üle	doc_491521502153_item	2609062	et	3	main
jaoks	doc_491521502153_item	2609074	et	4	main
aga	doc_491521502153_item	2609075	et	3	main
see	doc_491521502153_item	2609076	et	3	main
paneb	doc_491521502153_item	2609077	et	3	main
mõtlema	doc_491521502153_item	2609078	et	3	main
on	doc_491521502153_item	2609081	et	4	main
see	doc_491521502153_item	2609125	et	3	main
teisikud	doc_491521502153_item	2609132	et	3	main
maailmategijad	doc_491521502153_item	2609137	et	3	main
jäänud	doc_491521502153_item	2609156	et	4	main
häid	doc_491521502153_item	2609157	et	3	main
muljed	doc_491521502153_item	2609158	et	3	main
ja	doc_491521502153_item	2609159	et	3	main
võiks	doc_491521502153_item	2609160	et	4	main
mõne	doc_491521502153_item	2609161	et	3	main
korra	doc_491521502153_item	2609166	et	4	main
arvustus	doc_491521502154_item	2609178	et	4	main
meie	doc_491521502154_item	2609182	et	4	main
mõned	doc_491521502154_item	2609199	et	3	main
tõesti	doc_491521502154_item	2609203	et	3	main
oli	doc_491521502154_item	2609206	et	3	main
kesküla	doc_491521502154_item	2609208	et	4	main
eestist	doc_491521502154_item	2609209	et	3	main
pärit	doc_491521502154_item	2609210	et	3	main
et	doc_491521502154_item	2609221	et	3	main
saaks	doc_491521502154_item	2609223	et	3	main
eestimaa	doc_491521502154_item	2609225	et	4	main
ta	doc_491521502154_item	2609226	et	4	main
tõepoolest	doc_491521502154_item	2609227	et	3	main
et	doc_491521502154_item	2609229	et	3	main
võimalik	doc_491521502154_item	2609232	et	3	main
võimus	doc_491521502154_item	2609239	et	4	main
et	doc_491521502154_item	2609240	et	3	main
see	doc_491521502154_item	2609241	et	3	main
mõte	doc_491521502154_item	2609242	et	3	main
ellu	doc_491521502154_item	2609243	et	4	main
viia	doc_491521502154_item	2609244	et	3	main
kesküla	doc_491521502154_item	2609245	et	4	main
oli	doc_491521502154_item	2609246	et	3	main
haritud	doc_491521502154_item	2609247	et	4	main
pidada	doc_491521502154_item	2609259	et	4	main
nii	doc_491521502154_item	2609260	et	3	main
ühte	doc_491521502154_item	2609261	et	4	main
kui	doc_491521502154_item	2609262	et	3	main
õigusteteaduskonnas	doc_491521502154_item	2609267	et	4	main
oli	doc_491521502154_item	2609269	et	3	main
keel	doc_491521502154_item	2609279	et	4	main
ja	doc_491521502154_item	2609285	et	3	main
oli	doc_491521502154_item	2609288	et	3	main
käed	doc_491521502154_item	2609300	et	3	main
ta	doc_491521502154_item	2609302	et	4	main
inimene	doc_491521502154_item	2609321	et	3	main
teadis	doc_491521502154_item	2609323	et	4	main
kindlalt	doc_491521502154_item	2609324	et	4	main
mida	doc_491521502154_item	2609325	et	4	main
tahtis	doc_491521502154_item	2609326	et	3	main
ja	doc_491521502154_item	2609327	et	3	main
võimeline	doc_491521502154_item	2609336	et	4	main
oma	doc_491521502154_item	2609339	et	4	main
kesküla	doc_491521502154_item	2609341	et	4	main
valis	doc_491521502154_item	2609342	et	3	main
mõted	doc_491521502154_item	2609346	et	4	main
olid	doc_491521502154_item	2609347	et	4	main
kesküla	doc_491521502154_item	2609366	et	4	main
ta	doc_491521502154_item	2609375	et	4	main
leidis	doc_491521502154_item	2609376	et	4	main
stiilis	doc_491521502153_item	2609122	et	4	main
olla	doc_491521502153_item	2609135	et	3	main
on	doc_491521502153_item	2609138	et	4	main
valitsevad	doc_491521502153_item	2609143	et	4	main
teisikud	doc_491521502153_item	2609144	et	3	main
juhtuda	doc_491521502153_item	2609147	et	3	main
aja	doc_491521502153_item	2609162	et	4	main
momendidest	doc_491521502153_item	2609172	et	4	main
selgeks	doc_491521502153_item	2609174	et	3	main
filmi	doc_491521502154_item	2609181	et	4	main
filmis	doc_491521502154_item	2609184	et	4	main
vene	doc_491521502154_item	2609191	et	4	main
tööd	doc_491521502154_item	2609196	et	4	main
suurepäraselt	doc_491521502154_item	2609197	et	4	main
seepärast	doc_491521502154_item	2609198	et	3	main
olid	doc_491521502154_item	2609202	et	4	main
ebameeldivad	doc_491521502154_item	2609204	et	3	main
peategelaseks	doc_491521502154_item	2609205	et	3	main
eestist	doc_491521502154_item	2609222	et	3	main
mõtles	doc_491521502154_item	2609228	et	3	main
mees	doc_491521502154_item	2609248	et	4	main
saksa	doc_491521502154_item	2609252	et	4	main
vene	doc_491521502154_item	2609254	et	4	main
keelt	doc_491521502154_item	2609255	et	4	main
sidet	doc_491521502154_item	2609258	et	4	main
mitmete	doc_491521502154_item	2609270	et	4	main
seltside	doc_491521502154_item	2609271	et	3	main
oli	doc_491521502154_item	2609273	et	3	main
tal	doc_491521502154_item	2609274	et	3	main
iseloomule	doc_491521502154_item	2609284	et	3	main
ei	doc_491521502154_item	2609292	et	4	main
istuda	doc_491521502154_item	2609299	et	3	main
ta	doc_491521502154_item	2609322	et	4	main
ta	doc_491521502154_item	2609333	et	4	main
saada	doc_491521502154_item	2609365	et	4	main
leniniga	doc_491521502154_item	2609369	et	4	main
juhtuda	doc_491521502154_item	2609372	et	3	main
neid	doc_491521502154_item	2609381	et	4	main
kuidas	doc_491521502154_item	2609382	et	3	main
näitab	doc_491521502154_item	2609387	et	3	main
tugevasti	doc_491521502154_item	2609389	et	3	main
püüdis	doc_491521502154_item	2609391	et	3	main
ellu	doc_491521502154_item	2609394	et	4	main
et	doc_491521502154_item	2609399	et	3	main
aleksander	doc_491521502154_item	2609400	et	4	main
võitleja	doc_491521502154_item	2609406	et	4	main
rolli	doc_491521502154_item	2609411	et	4	main
selliseid	doc_491521502154_item	2609416	et	4	main
rohkem	doc_491521502154_item	2609419	et	4	main
meeldis	doc_491521502154_item	2609422	et	3	main
näha	doc_491521502154_item	2609430	et	3	main
tegi	doc_491521502154_item	2609434	et	4	main
kõike	doc_491521502153_item	2609146	et	4	main
vastamata	doc_491521502153_item	2609151	et	4	main
on	doc_491521502153_item	2609155	et	4	main
ja	doc_491521502153_item	2609168	et	3	main
võib-olla	doc_491521502153_item	2609169	et	3	main
meie	doc_491521502154_item	2609179	et	4	main
vaatasime	doc_491521502154_item	2609180	et	3	main
eesti	doc_491521502154_item	2609189	et	4	main
ja	doc_491521502154_item	2609190	et	3	main
tegelased	doc_491521502154_item	2609201	et	3	main
aleksander	doc_491521502154_item	2609207	et	4	main
eesti	doc_491521502154_item	2609217	et	4	main
ta	doc_491521502154_item	2609219	et	4	main
suur	doc_491521502154_item	2609224	et	3	main
see	doc_491521502154_item	2609230	et	3	main
ja	doc_491521502154_item	2609233	et	3	main
väga	doc_491521502154_item	2609249	et	3	main
seega	doc_491521502154_item	2609256	et	4	main
teistega	doc_491521502154_item	2609263	et	4	main
kuna	doc_491521502154_item	2609264	et	3	main
ja	doc_491521502154_item	2609268	et	3	main
iga	doc_491521502154_item	2609280	et	4	main
isikuga	doc_491521502154_item	2609281	et	3	main
sündinud	doc_491521502154_item	2609289	et	4	main
ühes	doc_491521502154_item	2609296	et	4	main
tegevust	doc_491521502154_item	2609304	et	4	main
iga	doc_491521502154_item	2609328	et	4	main
hinnaga	doc_491521502154_item	2609329	et	3	main
püüdis	doc_491521502154_item	2609330	et	3	main
saavutada	doc_491521502154_item	2609332	et	3	main
oli	doc_491521502154_item	2609334	et	3	main
kõigeks	doc_491521502154_item	2609335	et	4	main
nende	doc_491521502154_item	2609345	et	4	main
lenin	doc_491521502154_item	2609361	et	4	main
aitab	doc_491521502154_item	2609362	et	3	main
eestimaale	doc_491521502154_item	2609363	et	4	main
et	doc_491521502154_item	2609368	et	3	main
midagi	doc_491521502154_item	2609371	et	4	main
ja	doc_491521502154_item	2609373	et	3	main
lenini	doc_491521502154_item	2609377	et	4	main
olla	doc_491521502154_item	2609383	et	3	main
kui	doc_491521502154_item	2609388	et	3	main
kesküla	doc_491521502154_item	2609390	et	4	main
viia	doc_491521502154_item	2609395	et	3	main
filmis	doc_491521502154_item	2609396	et	4	main
me	doc_491521502154_item	2609397	et	4	main
näeme	doc_491521502154_item	2609398	et	3	main
vabaduse	doc_491521502154_item	2609405	et	4	main
ta	doc_491521502154_item	2609407	et	4	main
mängis	doc_491521502154_item	2609408	et	3	main
eestimaa	doc_491521502154_item	2609412	et	4	main
inimesi	doc_491521502154_item	2609417	et	4	main
filmis	doc_491521502154_item	2609423	et	4	main
kuidas	doc_491521502154_item	2609424	et	3	main
tõepäraseks	doc_491521502154_item	2609436	et	4	main
on	doc_491521502154_item	2609231	et	4	main
tegi	doc_491521502154_item	2609234	et	4	main
oli	doc_491521502154_item	2609237	et	3	main
tark	doc_491521502154_item	2609250	et	3	main
võis	doc_491521502154_item	2609257	et	4	main
ta	doc_491521502154_item	2609265	et	4	main
liige	doc_491521502154_item	2609272	et	4	main
väga	doc_491521502154_item	2609275	et	3	main
kerge	doc_491521502154_item	2609276	et	4	main
leida	doc_491521502154_item	2609277	et	3	main
vaatamata	doc_491521502154_item	2609282	et	4	main
ideetele	doc_491521502154_item	2609286	et	4	main
olnud	doc_491521502154_item	2609293	et	4	main
võimeline	doc_491521502154_item	2609294	et	4	main
olla	doc_491521502154_item	2609295	et	3	main
rüppes	doc_491521502154_item	2609301	et	4	main
tahtis	doc_491521502154_item	2609303	et	3	main
teha	doc_491521502154_item	2609305	et	3	main
midagi	doc_491521502154_item	2609306	et	4	main
sellist	doc_491521502154_item	2609307	et	4	main
mis	doc_491521502154_item	2609309	et	4	main
võimsat	doc_491521502154_item	2609308	et	3	main
oli	doc_491521502154_item	2609310	et	3	main
liiga	doc_491521502154_item	2609311	et	4	main
raske	doc_491521502154_item	2609312	et	4	main
peaaegu	doc_491521502154_item	2609313	et	3	main
võimatu	doc_491521502154_item	2609314	et	4	main
aleksander	doc_491521502154_item	2609315	et	4	main
kesküla	doc_491521502154_item	2609316	et	4	main
oli	doc_491521502154_item	2609317	et	3	main
iseloomust	doc_491521502154_item	2609318	et	4	main
väga	doc_491521502154_item	2609319	et	3	main
tugev	doc_491521502154_item	2609320	et	4	main
seda	doc_491521502154_item	2609331	et	3	main
saavutada	doc_491521502154_item	2609338	et	3	main
eesmärgi	doc_491521502154_item	2609340	et	4	main
leninit	doc_491521502154_item	2609343	et	4	main
kuna	doc_491521502154_item	2609344	et	3	main
sarnased	doc_491521502154_item	2609348	et	4	main
vabaduse	doc_491521502154_item	2609364	et	4	main
kartis	doc_491521502154_item	2609367	et	3	main
võib	doc_491521502154_item	2609370	et	3	main
seetõttu	doc_491521502154_item	2609374	et	3	main
idee	doc_491521502154_item	2609393	et	4	main
tõeline	doc_491521502154_item	2609403	et	4	main
eestimaa	doc_491521502154_item	2609404	et	4	main
isiklikult	doc_491521502154_item	2609421	et	4	main
näitlejad	doc_491521502154_item	2609425	et	4	main
mängisid	doc_491521502154_item	2609426	et	4	main
professionaalsust	doc_491521502154_item	2609432	et	4	main
et	doc_491521502154_item	2609337	et	3	main
lenin	doc_491521502154_item	2609349	et	4	main
tahtis	doc_491521502154_item	2609350	et	3	main
teha	doc_491521502154_item	2609351	et	3	main
revolutsiooni	doc_491521502154_item	2609352	et	4	main
vene	doc_491521502154_item	2609353	et	4	main
tsaari	doc_491521502154_item	2609354	et	4	main
troonilt	doc_491521502154_item	2609355	et	3	main
kukutada	doc_491521502154_item	2609356	et	3	main
aleksander	doc_491521502154_item	2609357	et	4	main
kesküla	doc_491521502154_item	2609358	et	4	main
mõtles	doc_491521502154_item	2609359	et	3	main
et	doc_491521502154_item	2609360	et	3	main
sarnaseid	doc_491521502154_item	2609378	et	4	main
inimesi	doc_491521502154_item	2609379	et	4	main
õpetas	doc_491521502154_item	2609380	et	3	main
see	doc_491521502154_item	2609385	et	3	main
kesküla	doc_491521502154_item	2609401	et	4	main
oli	doc_491521502154_item	2609402	et	3	main
väga	doc_491521502154_item	2609409	et	3	main
et	doc_491521502154_item	2609415	et	3	main
oleks	doc_491521502154_item	2609418	et	3	main
mulle	doc_491521502154_item	2609420	et	4	main
lenin	doc_491521502154_item	2609384	et	4	main
kõik	doc_491521502154_item	2609386	et	4	main
oma	doc_491521502154_item	2609392	et	4	main
suurt	doc_491521502154_item	2609410	et	3	main
ajaloos	doc_491521502154_item	2609413	et	4	main
tahaks	doc_491521502154_item	2609414	et	3	main
oma	doc_491521502154_item	2609427	et	4	main
rolle	doc_491521502154_item	2609428	et	3	main
oli	doc_491521502154_item	2609429	et	3	main
see	doc_491521502154_item	2609433	et	3	main
leninid	doc_491521502156_item	2609729	et	4	main
vaatasin	doc_491521502156_item	2609734	et	3	main
mis	doc_491521502156_item	2609736	et	4	main
minu	doc_491521502156_item	2609738	et	3	main
see	doc_491521502156_item	2609746	et	3	main
noor	doc_491521502156_item	2609759	et	3	main
revolutsionäär	doc_491521502156_item	2609762	et	3	main
eesmärgiks	doc_491521502156_item	2609764	et	3	main
oli	doc_491521502156_item	2609765	et	3	main
purustatud	doc_491521502156_item	2609766	et	4	main
nende	doc_491521502154_item	2609431	et	4	main
filmi	doc_491521502154_item	2609435	et	4	main
minu	doc_491521502156_item	2609728	et	3	main
eelmisel	doc_491521502156_item	2609731	et	3	main
oli	doc_491521502156_item	2609737	et	3	main
oli	doc_491521502156_item	2609745	et	3	main
teiselt	doc_491521502156_item	2609749	et	4	main
komöödiline	doc_491521502156_item	2609751	et	4	main
aleksander	doc_491521502156_item	2609757	et	4	main
aasta	doc_491521502156_item	2609761	et	4	main
kelle	doc_491521502156_item	2609763	et	4	main
ehitada	doc_491521502156_item	2609769	et	3	main
aga	doc_491521502156_item	2609771	et	3	main
oli	doc_491521502156_item	2609773	et	3	main
tuleks	doc_491521502156_item	2609791	et	4	main
temast	doc_491521502156_item	2609792	et	3	main
ma	doc_491521502156_item	2609733	et	3	main
ajalooline	doc_491521502156_item	2609747	et	4	main
poolt	doc_491521502156_item	2609750	et	4	main
film	doc_491521502156_item	2609752	et	3	main
iroonia	doc_491521502156_item	2609753	et	4	main
peategelaseks	doc_491521502156_item	2609755	et	3	main
1905	doc_491521502156_item	2609760	et	2	main
venemaa	doc_491521502156_item	2609767	et	4	main
iseseisvaks	doc_491521502156_item	2609784	et	3	main
toetust	doc_491521502156_item	2609793	et	4	main
ja	doc_491521502156_item	2609795	et	3	main
juhtis	doc_491521502156_item	2609822	et	3	main
liikumist	doc_491521502156_item	2609824	et	4	main
mis	doc_491521502156_item	2609825	et	4	main
aga	doc_491521502156_item	2609826	et	3	main
aga	doc_491521502156_item	2609832	et	3	main
vägivald	doc_491521502156_item	2609840	et	3	main
kogu	doc_491521502156_item	2609859	et	4	main
maailm	doc_491521502156_item	2609860	et	3	main
kommunistlikuks	doc_491521502156_item	2609861	et	3	main
sest	doc_491521502156_item	2609867	et	4	main
partei	doc_491521502156_item	2609875	et	4	main
lenin	doc_491521502156_item	2609889	et	4	main
selles	doc_491521502156_item	2609890	et	4	main
avaldas	doc_491521502156_item	2609926	et	3	main
maa	doc_491521502156_item	2609936	et	4	main
rahu	doc_491521502156_item	2609938	et	4	main
arenes	doc_491521502156_item	2609939	et	3	main
oli	doc_491521502156_item	2609946	et	3	main
venelaste	doc_491521502156_item	2609947	et	4	main
lenin	doc_491521502156_item	2609956	et	4	main
oli	doc_491521502156_item	2609957	et	3	main
sai	doc_491521502156_item	2609965	et	4	main
kelle	doc_491521502156_item	2609978	et	4	main
eesmärgidest	doc_491521502156_item	2609979	et	3	main
eesti	doc_491521502156_item	2609990	et	4	main
ikkagi	doc_491521502156_item	2609993	et	4	main
oli	doc_491521502156_item	2609999	et	3	main
ebaoluline	doc_491521502156_item	2610003	et	4	main
ta	doc_491521502156_item	2610005	et	4	main
abiellunud	doc_491521502156_item	2610007	et	4	main
tal	doc_491521502156_item	2610009	et	3	main
mitte	doc_491521502156_item	2610035	et	3	main
tahaksin	doc_491521502156_item	2610038	et	3	main
põhjuseks	doc_491521502156_item	2610048	et	3	main
tunne	doc_491521502156_item	2610078	et	4	main
et	doc_491521502156_item	2610079	et	3	main
oled	doc_491521502156_item	2610084	et	3	main
selle	doc_491521502156_item	2610087	et	4	main
sain	doc_491521502156_item	2610090	et	3	main
essee	doc_491521502156_item	2609730	et	4	main
leninid	doc_491521502156_item	2609742	et	4	main
ühelt	doc_491521502156_item	2609743	et	3	main
poolt	doc_491521502156_item	2609744	et	4	main
kesküla	doc_491521502156_item	2609758	et	4	main
asemele	doc_491521502156_item	2609768	et	4	main
suur-eesti	doc_491521502156_item	2609770	et	4	main
selleks	doc_491521502156_item	2609772	et	4	main
tal	doc_491521502156_item	2609774	et	3	main
vaja	doc_491521502156_item	2609775	et	4	main
et	doc_491521502156_item	2609776	et	3	main
lenin	doc_491521502156_item	2609777	et	4	main
lenin	doc_491521502156_item	2609821	et	4	main
tulek	doc_491521502156_item	2609848	et	3	main
nulli	doc_491521502156_item	2609850	et	4	main
nii	doc_491521502156_item	2609851	et	3	main
täna	doc_491521502156_item	2609852	et	4	main
kui	doc_491521502156_item	2609853	et	3	main
ka	doc_491521502156_item	2609854	et	3	main
homme	doc_491521502156_item	2609855	et	3	main
minu	doc_491521502156_item	2609856	et	3	main
arvates	doc_491521502156_item	2609857	et	4	main
muuta	doc_491521502156_item	2609858	et	4	main
ei	doc_491521502156_item	2609869	et	4	main
tunnistanud	doc_491521502156_item	2609870	et	4	main
teised	doc_491521502156_item	2609871	et	4	main
kohe	doc_491521502156_item	2609877	et	4	main
näitas	doc_491521502156_item	2609895	et	3	main
nädalal	doc_491521502156_item	2609732	et	3	main
filmi	doc_491521502156_item	2609735	et	4	main
jaoks	doc_491521502156_item	2609739	et	4	main
ebatavaline	doc_491521502156_item	2609740	et	4	main
minu	doc_491521502156_item	2609741	et	3	main
aga	doc_491521502156_item	2609748	et	3	main
elementidega	doc_491521502156_item	2609754	et	3	main
oli	doc_491521502156_item	2609756	et	3	main
eestimaa	doc_491521502156_item	2609782	et	4	main
saaks	doc_491521502156_item	2609783	et	3	main
sellest	doc_491521502156_item	2609785	et	4	main
küljest	doc_491521502156_item	2609786	et	4	main
oli	doc_491521502156_item	2609787	et	3	main
lenin	doc_491521502156_item	2609788	et	4	main
kasulik	doc_491521502156_item	2609789	et	3	main
siit	doc_491521502156_item	2609790	et	3	main
oodata	doc_491521502156_item	2609794	et	4	main
igaks	doc_491521502156_item	2609797	et	3	main
otsustab	doc_491521502156_item	2609799	et	3	main
kesküla	doc_491521502156_item	2609800	et	4	main
teha	doc_491521502156_item	2609801	et	3	main
lenini	doc_491521502156_item	2609802	et	4	main
teisikuid	doc_491521502156_item	2609803	et	4	main
ja	doc_491521502156_item	2609804	et	3	main
otsib	doc_491521502156_item	2609805	et	3	main
inimesi	doc_491521502156_item	2609806	et	4	main
sarnase	doc_491521502156_item	2609807	et	4	main
välimusega	doc_491521502156_item	2609808	et	3	main
et	doc_491521502156_item	2609809	et	3	main
leninit	doc_491521502156_item	2609810	et	4	main
asendada	doc_491521502156_item	2609811	et	3	main
et	doc_491521502156_item	2609812	et	3	main
näidata	doc_491521502156_item	2609813	et	4	main
lenini	doc_491521502156_item	2609814	et	4	main
võimalust	doc_491521502156_item	2609815	et	3	main
täita	doc_491521502156_item	2609816	et	4	main
oma	doc_491521502156_item	2609817	et	4	main
ülesandeid	doc_491521502156_item	2609818	et	3	main
rahva	doc_491521502156_item	2609819	et	3	main
ees	doc_491521502156_item	2609820	et	4	main
mitte	doc_491521502156_item	2609829	et	3	main
ainult	doc_491521502156_item	2609830	et	4	main
venemaa	doc_491521502156_item	2609831	et	4	main
nii	doc_491521502156_item	2609864	et	3	main
ideed	doc_491521502156_item	2609872	et	4	main
kui	doc_491521502156_item	2609873	et	3	main
kommunistlik	doc_491521502156_item	2609874	et	3	main
teised	doc_491521502156_item	2609879	et	4	main
kellest	doc_491521502156_item	2609883	et	4	main
pilkas	doc_491521502156_item	2609893	et	3	main
küljest	doc_491521502156_item	2609923	et	4	main
inimeste	doc_491521502156_item	2609927	et	3	main
tähtis	doc_491521502156_item	2609951	et	4	main
meie	doc_491521502156_item	2609958	et	4	main
ajaloos	doc_491521502156_item	2609959	et	4	main
isik	doc_491521502156_item	2609962	et	3	main
sõlmiks	doc_491521502156_item	2609778	et	4	main
saksamaaga	doc_491521502156_item	2609779	et	3	main
lepingu	doc_491521502156_item	2609780	et	3	main
et	doc_491521502156_item	2609781	et	3	main
siis	doc_491521502156_item	2609796	et	3	main
juhuks	doc_491521502156_item	2609798	et	3	main
bolševikute	doc_491521502156_item	2609823	et	2	main
pärast	doc_491521502156_item	2609827	et	4	main
maailma	doc_491521502156_item	2609834	et	4	main
jaoks	doc_491521502156_item	2609835	et	4	main
bolševikute	doc_491521502156_item	2609837	et	2	main
eesmärgiks	doc_491521502156_item	2609838	et	3	main
ja	doc_491521502156_item	2609841	et	3	main
bolševikute	doc_491521502156_item	2609846	et	2	main
võimule	doc_491521502156_item	2609847	et	3	main
olnud	doc_491521502156_item	2609863	et	4	main
hea	doc_491521502156_item	2609865	et	4	main
idee	doc_491521502156_item	2609866	et	4	main
keelas	doc_491521502156_item	2609878	et	3	main
parteid	doc_491521502156_item	2609881	et	4	main
aga	doc_491521502156_item	2609882	et	3	main
filmis	doc_491521502156_item	2609891	et	4	main
režissöör	doc_491521502156_item	2609892	et	2	main
harjumusi	doc_491521502156_item	2609897	et	4	main
rääkimist	doc_491521502156_item	2609898	et	4	main
minu	doc_491521502156_item	2609899	et	3	main
tema	doc_491521502156_item	2609896	et	4	main
meelest	doc_491521502156_item	2609900	et	4	main
oli	doc_491521502156_item	2609901	et	3	main
lenin	doc_491521502156_item	2609902	et	4	main
palju	doc_491521502156_item	2609903	et	4	main
teinud	doc_491521502156_item	2609904	et	4	main
venemaa	doc_491521502156_item	2609905	et	4	main
jaoks	doc_491521502156_item	2609906	et	4	main
loomulikult	doc_491521502156_item	2609907	et	4	main
kommunistlik	doc_491521502156_item	2609908	et	3	main
liikumine	doc_491521502156_item	2609909	et	4	main
oli	doc_491521502156_item	2609910	et	3	main
halb	doc_491521502156_item	2609911	et	3	main
sellest	doc_491521502156_item	2609912	et	4	main
küljest	doc_491521502156_item	2609913	et	4	main
inimesi	doc_491521502156_item	2609915	et	4	main
et	doc_491521502156_item	2609914	et	3	main
saadeti	doc_491521502156_item	2609916	et	3	main
siberisse	doc_491521502156_item	2609917	et	4	main
kujunesid	doc_491521502156_item	2609918	et	4	main
vagivalla	doc_491521502156_item	2609919	et	4	main
laagrid	doc_491521502156_item	2609920	et	3	main
liikumine	doc_491521502156_item	2609925	et	4	main
südas	doc_491521502156_item	2609928	et	4	main
kõik	doc_491521502156_item	2609944	et	4	main
ju	doc_491521502156_item	2609945	et	3	main
ja	doc_491521502156_item	2609950	et	3	main
ta	doc_491521502156_item	2609964	et	4	main
aleksander	doc_491521502156_item	2609976	et	4	main
päris	doc_491521502156_item	2609983	et	4	main
aga	doc_491521502156_item	2609992	et	3	main
ei	doc_491521502156_item	2609994	et	4	main
teinud	doc_491521502156_item	2609995	et	4	main
seda	doc_491521502156_item	2609996	et	3	main
teisest	doc_491521502156_item	2609997	et	4	main
oli	doc_491521502156_item	2610006	et	3	main
oli	doc_491521502156_item	2610010	et	3	main
muutus	doc_491521502156_item	2609828	et	4	main
kogu	doc_491521502156_item	2609833	et	4	main
katastroofiliseks	doc_491521502156_item	2609836	et	4	main
oli	doc_491521502156_item	2609839	et	3	main
filmis	doc_491521502156_item	2609842	et	4	main
ka	doc_491521502156_item	2609843	et	3	main
näidatakse	doc_491521502156_item	2609844	et	3	main
et	doc_491521502156_item	2609845	et	3	main
tähendab	doc_491521502156_item	2609849	et	3	main
ei	doc_491521502156_item	2609862	et	4	main
venemaa	doc_491521502156_item	2609868	et	4	main
ja	doc_491521502156_item	2609876	et	3	main
poliitilised	doc_491521502156_item	2609880	et	3	main
mul	doc_491521502156_item	2609884	et	3	main
oli	doc_491521502156_item	2609885	et	3	main
tõesti	doc_491521502156_item	2609886	et	3	main
kahju	doc_491521502156_item	2609887	et	4	main
oli	doc_491521502156_item	2609888	et	3	main
temast	doc_491521502156_item	2609894	et	3	main
aga	doc_491521502156_item	2609921	et	3	main
kommunistlik	doc_491521502156_item	2609924	et	3	main
ja	doc_491521502156_item	2609937	et	3	main
majandus	doc_491521502156_item	2609940	et	4	main
maa	doc_491521502156_item	2609941	et	4	main
jaoks	doc_491521502156_item	2609948	et	4	main
mida	doc_491521502156_item	2609952	et	4	main
ei	doc_491521502156_item	2609954	et	4	main
olnud	doc_491521502156_item	2609955	et	4	main
tähtis	doc_491521502156_item	2609961	et	4	main
tähtsamaks	doc_491521502156_item	2609973	et	4	main
tegelaseks	doc_491521502156_item	2609974	et	3	main
oli	doc_491521502156_item	2609975	et	3	main
saanud	doc_491521502156_item	2609981	et	4	main
ma	doc_491521502156_item	2609982	et	3	main
iseseisvust	doc_491521502156_item	2609991	et	4	main
küljest	doc_491521502156_item	2609998	et	4	main
üks	doc_491521502156_item	2610011	et	3	main
ja	doc_491521502156_item	2610013	et	3	main
väga	doc_491521502156_item	2610015	et	3	main
mida	doc_491521502156_item	2610017	et	4	main
tõesti	doc_491521502156_item	2610019	et	3	main
teisest	doc_491521502156_item	2609922	et	4	main
tuleviku	doc_491521502156_item	2609929	et	4	main
lootust	doc_491521502156_item	2609930	et	4	main
sest	doc_491521502156_item	2609931	et	4	main
bolševikute	doc_491521502156_item	2609932	et	2	main
loosungiks	doc_491521502156_item	2609933	et	3	main
oli	doc_491521502156_item	2609934	et	3	main
leib	doc_491521502156_item	2609935	et	3	main
natsionaliseerimine	doc_491521502156_item	2609942	et	4	main
see	doc_491521502156_item	2609943	et	3	main
uus	doc_491521502156_item	2609949	et	3	main
enne	doc_491521502156_item	2609953	et	4	main
väga	doc_491521502156_item	2609960	et	3	main
teha	doc_491521502156_item	2609966	et	3	main
nii	doc_491521502156_item	2609967	et	3	main
et	doc_491521502156_item	2609968	et	3	main
inimesed	doc_491521502156_item	2609969	et	3	main
usaldasid	doc_491521502156_item	2609970	et	4	main
kesküla	doc_491521502156_item	2609977	et	4	main
aru	doc_491521502156_item	2609984	et	4	main
ühest	doc_491521502156_item	2609985	et	4	main
küljest	doc_491521502156_item	2609986	et	4	main
tahtis	doc_491521502156_item	2609987	et	3	main
ta	doc_491521502156_item	2609988	et	4	main
saavutada	doc_491521502156_item	2609989	et	3	main
poliitika	doc_491521502156_item	2610000	et	4	main
tema	doc_491521502156_item	2610001	et	4	main
sest	doc_491521502156_item	2610004	et	4	main
ja	doc_491521502156_item	2610008	et	3	main
laps	doc_491521502156_item	2610012	et	4	main
oli	doc_491521502156_item	2610014	et	3	main
imelik	doc_491521502156_item	2610016	et	3	main
kesküla	doc_491521502156_item	2610018	et	4	main
ja	doc_491521502156_item	2610025	et	3	main
teadis	doc_491521502156_item	2610026	et	4	main
ei	doc_491521502156_item	2610033	et	4	main
meelest	doc_491521502156_item	2610047	et	4	main
tema	doc_491521502156_item	2610050	et	4	main
teda	doc_491521502156_item	2610055	et	4	main
tundnud	doc_491521502156_item	2610057	et	4	main
et	doc_491521502156_item	2610082	et	3	main
sina	doc_491521502156_item	2610086	et	4	main
filmi	doc_491521502156_item	2610088	et	4	main
vaadates	doc_491521502156_item	2610089	et	3	main
ma	doc_491521502156_item	2610091	et	3	main
aru	doc_491521502156_item	2610092	et	4	main
kui	doc_491521502156_item	2610093	et	3	main
kriitiliseks	doc_491521502156_item	2610094	et	3	main
saab	doc_491521502156_item	2610095	et	3	main
olla	doc_491521502156_item	2610096	et	3	main
kesküla	doc_491521502156_item	2610106	et	4	main
teha	doc_491521502156_item	2610108	et	3	main
idee	doc_491521502156_item	2610113	et	4	main
sest	doc_491521502156_item	2610114	et	4	main
sellega	doc_491521502156_item	2610118	et	3	main
mitte	doc_491521502156_item	2610119	et	3	main
midagi	doc_491521502156_item	2610120	et	4	main
märkida	doc_491521502157_item	2610141	et	4	main
et	doc_491521502157_item	2610142	et	3	main
peaaegu	doc_491521502157_item	2610143	et	3	main
ilmuvad	doc_491521502157_item	2610164	et	4	main
olemas	doc_491521502157_item	2610174	et	4	main
veel	doc_491521502157_item	2610175	et	4	main
selline	doc_491521502157_item	2610176	et	4	main
hakkab	doc_491521502157_item	2610182	et	3	main
ajalugu	doc_491521502157_item	2610183	et	4	main
külje	doc_491521502157_item	2610222	et	3	main
ei	doc_491521502157_item	2610225	et	4	main
sest	doc_491521502157_item	2610230	et	4	main
palju	doc_491521502157_item	2610234	et	4	main
õiguses	doc_491521502157_item	2610239	et	4	main
minusse	doc_491521502157_item	2610244	et	3	main
haridustase	doc_491521502157_item	2610246	et	3	main
enda	doc_491521502157_item	2610256	et	4	main
see	doc_491521502157_item	2610260	et	3	main
tuule	doc_491521502157_item	2610263	et	3	main
ühes	doc_491521502157_item	2610272	et	4	main
elan	doc_491521502157_item	2610276	et	3	main
tema	doc_491521502157_item	2610293	et	4	main
kirjanikude	doc_491521502157_item	2610302	et	3	main
riigi	doc_491521502157_item	2610323	et	3	main
ja	doc_491521502157_item	2610325	et	3	main
sest	doc_491521502156_item	2609963	et	4	main
teda	doc_491521502156_item	2609971	et	4	main
teiseks	doc_491521502156_item	2609972	et	4	main
ei	doc_491521502156_item	2609980	et	4	main
jaoks	doc_491521502156_item	2610002	et	4	main
ta	doc_491521502156_item	2610021	et	4	main
mida	doc_491521502156_item	2610027	et	4	main
saavutanudki	doc_491521502156_item	2610034	et	4	main
lõpuks	doc_491521502156_item	2610037	et	4	main
ka	doc_491521502156_item	2610039	et	3	main
lenin	doc_491521502156_item	2610042	et	4	main
lõpus	doc_491521502156_item	2610043	et	4	main
suri	doc_491521502156_item	2610044	et	3	main
ja	doc_491521502156_item	2610045	et	3	main
minu	doc_491521502156_item	2610046	et	3	main
ebakindel	doc_491521502156_item	2610051	et	3	main
maailmas	doc_491521502156_item	2610054	et	3	main
usu	doc_491521502156_item	2610081	et	4	main
elu	doc_491521502156_item	2610097	et	4	main
rahvas	doc_491521502156_item	2610099	et	4	main
ei	doc_491521502156_item	2610116	et	4	main
ja	doc_491521502156_item	2610121	et	3	main
hispaaniasse	doc_491521502156_item	2610125	et	4	main
küsimusele	doc_491521502157_item	2610146	et	4	main
vastada	doc_491521502157_item	2610150	et	4	main
ja	doc_491521502157_item	2610151	et	3	main
eriti	doc_491521502157_item	2610152	et	3	main
ajalugu	doc_491521502157_item	2610153	et	4	main
on	doc_491521502157_item	2610154	et	4	main
see	doc_491521502157_item	2610155	et	3	main
suund	doc_491521502157_item	2610156	et	3	main
mille	doc_491521502157_item	2610157	et	3	main
üle	doc_491521502157_item	2610158	et	3	main
aeg-ajalt	doc_491521502157_item	2610163	et	4	main
muudavad	doc_491521502157_item	2610168	et	4	main
kuid	doc_491521502157_item	2610172	et	4	main
asi	doc_491521502157_item	2610177	et	4	main
nagu	doc_491521502157_item	2610178	et	3	main
kui	doc_491521502157_item	2610220	et	3	main
mittehuvitanu	doc_491521502157_item	2610221	et	4	main
näiteid	doc_491521502157_item	2610228	et	3	main
et	doc_491521502157_item	2610235	et	3	main
minu	doc_491521502157_item	2610237	et	3	main
mõistetu	doc_491521502157_item	2610241	et	4	main
minu	doc_491521502157_item	2610245	et	3	main
minu	doc_491521502157_item	2610248	et	3	main
veel	doc_491521502157_item	2610253	et	4	main
oma	doc_491521502157_item	2610255	et	4	main
muutubgi	doc_491521502157_item	2610259	et	4	main
suund	doc_491521502157_item	2610264	et	3	main
riigis	doc_491521502157_item	2610273	et	3	main
juba	doc_491521502157_item	2610277	et	3	main
toredast	doc_491521502157_item	2610284	et	3	main
kus	doc_491521502157_item	2610287	et	3	main
olid	doc_491521502157_item	2610290	et	4	main
kus	doc_491521502157_item	2610292	et	3	main
ümber	doc_491521502157_item	2610294	et	3	main
on	doc_491521502157_item	2610295	et	4	main
lapsed	doc_491521502157_item	2610296	et	3	main
lugesin	doc_491521502157_item	2610297	et	3	main
läbi	doc_491521502157_item	2610298	et	4	main
oli	doc_491521502157_item	2610321	et	3	main
aimugi	doc_491521502157_item	2610328	et	4	main
loen	doc_491521502157_item	2610334	et	3	main
vaid	doc_491521502157_item	2610336	et	3	main
teiste	doc_491521502157_item	2610348	et	4	main
filmi	doc_491521502157_item	2610357	et	4	main
huviga	doc_491521502157_item	2610361	et	3	main
polnud	doc_491521502157_item	2610380	et	3	main
ühe	doc_491521502157_item	2610383	et	4	main
tegu	doc_491521502157_item	2610385	et	4	main
revolutsioon	doc_491521502157_item	2610386	et	3	main
üritustel	doc_491521502157_item	2610392	et	4	main
see	doc_491521502157_item	2610393	et	3	main
pole	doc_491521502157_item	2610394	et	3	main
pole	doc_491521502157_item	2610399	et	3	main
oluline	doc_491521502157_item	2610401	et	4	main
leenineid	doc_491521502157_item	2610405	et	4	main
sest	doc_491521502157_item	2610407	et	4	main
leenin	doc_491521502157_item	2610408	et	4	main
ise	doc_491521502157_item	2610409	et	4	main
ei	doc_491521502157_item	2610410	et	4	main
vaid	doc_491521502157_item	2610415	et	3	main
tahtis	doc_491521502156_item	2610020	et	3	main
ta	doc_491521502156_item	2610028	et	4	main
teeb	doc_491521502156_item	2610029	et	3	main
lõpus	doc_491521502156_item	2610030	et	4	main
aga	doc_491521502156_item	2610031	et	3	main
öelda	doc_491521502156_item	2610040	et	4	main
et	doc_491521502156_item	2610041	et	3	main
seisund	doc_491521502156_item	2610052	et	3	main
kui	doc_491521502156_item	2610074	et	3	main
ei	doc_491521502156_item	2610080	et	4	main
just	doc_491521502156_item	2610085	et	3	main
kui	doc_491521502156_item	2610098	et	3	main
pöörab	doc_491521502156_item	2610100	et	3	main
ja	doc_491521502156_item	2610105	et	3	main
vangijatest	doc_491521502156_item	2610109	et	4	main
oli	doc_491521502156_item	2610111	et	3	main
oli	doc_491521502156_item	2610022	et	3	main
kaval	doc_491521502156_item	2610023	et	4	main
inimene	doc_491521502156_item	2610024	et	3	main
ta	doc_491521502156_item	2610032	et	4	main
midagi	doc_491521502156_item	2610036	et	4	main
oli	doc_491521502156_item	2610049	et	3	main
ebakindlas	doc_491521502156_item	2610053	et	3	main
ei	doc_491521502156_item	2610056	et	4	main
ära	doc_491521502156_item	2610058	et	4	main
mitte	doc_491521502156_item	2610059	et	3	main
nadja	doc_491521502156_item	2610060	et	4	main
mitte	doc_491521502156_item	2610061	et	3	main
ühtegi	doc_491521502156_item	2610062	et	4	main
inimene	doc_491521502156_item	2610063	et	3	main
mul	doc_491521502156_item	2610064	et	3	main
oli	doc_491521502156_item	2610065	et	3	main
kahju	doc_491521502156_item	2610066	et	4	main
leninist	doc_491521502156_item	2610067	et	4	main
sest	doc_491521502156_item	2610068	et	4	main
ei	doc_491521502156_item	2610069	et	4	main
ole	doc_491521502156_item	2610070	et	4	main
mitte	doc_491521502156_item	2610071	et	3	main
midagi	doc_491521502156_item	2610072	et	4	main
jubedat	doc_491521502156_item	2610073	et	3	main
sind	doc_491521502156_item	2610075	et	4	main
keegi	doc_491521502156_item	2610076	et	4	main
ei	doc_491521502156_item	2610077	et	4	main
see	doc_491521502156_item	2610083	et	3	main
ees	doc_491521502156_item	2610102	et	4	main
oma	doc_491521502156_item	2610103	et	4	main
idee	doc_491521502156_item	2610107	et	4	main
saavutanud	doc_491521502156_item	2610117	et	4	main
ise	doc_491521502156_item	2610123	et	4	main
leeninid	doc_491521502157_item	2610132	et	3	main
minu	doc_491521502157_item	2610133	et	3	main
suhtumine	doc_491521502157_item	2610134	et	4	main
filmisse	doc_491521502157_item	2610135	et	3	main
minu	doc_491521502157_item	2610136	et	3	main
leeninid	doc_491521502157_item	2610137	et	3	main
ei	doc_491521502157_item	2610147	et	4	main
on	doc_491521502157_item	2610159	et	4	main
alati	doc_491521502157_item	2610160	et	4	main
uued	doc_491521502157_item	2610165	et	3	main
meie	doc_491521502157_item	2610169	et	4	main
möödunust	doc_491521502157_item	2610171	et	4	main
muutuma	doc_491521502157_item	2610186	et	4	main
ma	doc_491521502157_item	2610224	et	3	main
siin	doc_491521502157_item	2610227	et	4	main
on	doc_491521502157_item	2610232	et	4	main
kahelda	doc_491521502157_item	2610236	et	4	main
mis	doc_491521502157_item	2610242	et	4	main
ja	doc_491521502157_item	2610247	et	3	main
teadmised	doc_491521502157_item	2610249	et	4	main
anna	doc_491521502157_item	2610251	et	4	main
seepärast	doc_491521502157_item	2610258	et	3	main
tihedamini	doc_491521502157_item	2610261	et	4	main
asjadu	doc_491521502157_item	2610265	et	4	main
raskemaks	doc_491521502157_item	2610267	et	4	main
sündisin	doc_491521502157_item	2610271	et	3	main
ja	doc_491521502157_item	2610275	et	3	main
teises	doc_491521502157_item	2610278	et	4	main
raamatuid	doc_491521502157_item	2610283	et	3	main
lenist	doc_491521502157_item	2610286	et	4	main
nõukogude	doc_491521502157_item	2610301	et	3	main
sinu	doc_491521502156_item	2610101	et	3	main
selja	doc_491521502156_item	2610104	et	3	main
lenineid	doc_491521502156_item	2610110	et	4	main
tühi	doc_491521502156_item	2610112	et	3	main
ta	doc_491521502156_item	2610115	et	4	main
põgenes	doc_491521502156_item	2610124	et	3	main
elas	doc_491521502156_item	2610127	et	3	main
elu	doc_491521502156_item	2610129	et	4	main
lõpuni	doc_491521502156_item	2610130	et	3	main
minu	doc_491521502157_item	2610131	et	3	main
ühelegi	doc_491521502157_item	2610145	et	4	main
tekkinud	doc_491521502157_item	2610161	et	4	main
arusaamatusi	doc_491521502157_item	2610162	et	4	main
ja	doc_491521502157_item	2610167	et	3	main
sellest	doc_491521502157_item	2610181	et	4	main
palju	doc_491521502157_item	2610184	et	4	main
keerukamaks	doc_491521502157_item	2610185	et	4	main
puhul	doc_491521502157_item	2610223	et	4	main
hakka	doc_491521502157_item	2610226	et	4	main
tooma	doc_491521502157_item	2610229	et	3	main
nii	doc_491521502157_item	2610233	et	3	main
sõnade	doc_491521502157_item	2610238	et	3	main
on	doc_491521502157_item	2610240	et	4	main
puutub	doc_491521502157_item	2610243	et	3	main
ei	doc_491521502157_item	2610250	et	4	main
võimalust	doc_491521502157_item	2610254	et	3	main
teeb	doc_491521502157_item	2610266	et	3	main
see	doc_491521502157_item	2610268	et	3	main
nsvl-is	doc_491521502157_item	2610274	et	3	main
eesti	doc_491521502157_item	2610279	et	4	main
lapsepõlves	doc_491521502157_item	2610281	et	4	main
vanaisast	doc_491521502157_item	2610285	et	4	main
leheküljel	doc_491521502157_item	2610289	et	3	main
fotod	doc_491521502157_item	2610291	et	3	main
palju	doc_491521502157_item	2610300	et	4	main
millest	doc_491521502157_item	2610331	et	3	main
üks	doc_491521502157_item	2610337	et	3	main
tegelikult	doc_491521502157_item	2610339	et	4	main
tasapisi	doc_491521502157_item	2610346	et	3	main
suure	doc_491521502157_item	2610360	et	3	main
kuigi	doc_491521502157_item	2610362	et	3	main
ainult	doc_491521502157_item	2610382	et	4	main
inimese	doc_491521502157_item	2610384	et	4	main
võimalik	doc_491521502157_item	2610397	et	3	main
üldsegi	doc_491521502157_item	2610400	et	3	main
kui	doc_491521502157_item	2610402	et	3	main
selleks	doc_491521502157_item	2610420	et	4	main
midagi	doc_491521502157_item	2610422	et	4	main
peale	doc_491521502157_item	2610434	et	4	main
seda	doc_491521502157_item	2610439	et	3	main
ei	doc_491521502157_item	2610447	et	4	main
toimunud	doc_491521502157_item	2610448	et	4	main
üritustele	doc_491521502157_item	2610454	et	4	main
vältimatu	doc_491521502157_item	2610472	et	4	main
paljud	doc_491521502157_item	2610474	et	3	main
ja	doc_491521502157_item	2610480	et	3	main
kukutamises	doc_491521502157_item	2610482	et	4	main
puutub	doc_491521502157_item	2610484	et	3	main
iga	doc_491521502157_item	2610496	et	4	main
minu	doc_491521502157_item	2610532	et	3	main
filmis	doc_491521502157_item	2610548	et	4	main
esitati	doc_491521502157_item	2610549	et	4	main
sest	doc_491521502157_item	2610550	et	4	main
juhtunud	doc_491521502157_item	2610553	et	4	main
võimatu	doc_491521502157_item	2610555	et	4	main
tõsiselt	doc_491521502157_item	2610556	et	4	main
öeldes	doc_491521502157_item	2610557	et	3	main
nagu	doc_491521502157_item	2610565	et	3	main
ja	doc_491521502157_item	2610568	et	3	main
mingid	doc_491521502157_item	2610571	et	4	main
tähenda	doc_491521502157_item	2610577	et	4	main
test	doc_491521502158_item	2610586	et	3	main
sulgudes	doc_491521502158_item	2610592	et	4	main
toomet	doc_491521502158_item	2610598	et	4	main
nende	doc_491521502158_item	2610631	et	4	main
üllatuma	doc_491521502158_item	2610647	et	3	main
kui	doc_491521502158_item	2610649	et	3	main
audiga	doc_491521502158_item	2610656	et	3	main
lenda	doc_491521502158_item	2610667	et	4	main
kui	doc_491521502158_item	2610672	et	3	main
kohale	doc_491521502158_item	2610683	et	4	main
kartulivõtt	doc_491521502158_item	2610695	et	3	main
lõpuks	doc_491521502156_item	2610122	et	4	main
ja	doc_491521502156_item	2610126	et	3	main
seal	doc_491521502156_item	2610128	et	4	main
essee	doc_491521502157_item	2610138	et	4	main
esialgu	doc_491521502157_item	2610139	et	3	main
tahaksin	doc_491521502157_item	2610140	et	3	main
mitte	doc_491521502157_item	2610144	et	3	main
saa	doc_491521502157_item	2610148	et	4	main
kindlalt	doc_491521502157_item	2610149	et	4	main
faktid	doc_491521502157_item	2610166	et	3	main
ettekujutust	doc_491521502157_item	2610170	et	4	main
on	doc_491521502157_item	2610173	et	4	main
faktide	doc_491521502157_item	2610179	et	3	main
tõlgendamine	doc_491521502157_item	2610180	et	4	main
kui	doc_491521502157_item	2610187	et	3	main
see	doc_491521502157_item	2610188	et	3	main
tegelikult	doc_491521502157_item	2610189	et	4	main
on	doc_491521502157_item	2610190	et	4	main
erinevatel	doc_491521502157_item	2610191	et	4	main
ajajärgudel	doc_491521502157_item	2610192	et	4	main
seletatakse	doc_491521502157_item	2610193	et	3	main
ajalugu	doc_491521502157_item	2610194	et	4	main
erinevalt	doc_491521502157_item	2610195	et	4	main
mõned	doc_491521502157_item	2610196	et	3	main
faktid	doc_491521502157_item	2610197	et	3	main
avanevad	doc_491521502157_item	2610198	et	4	main
ja	doc_491521502157_item	2610199	et	3	main
mõned	doc_491521502157_item	2610200	et	3	main
püütakse	doc_491521502157_item	2610201	et	3	main
hoopiski	doc_491521502157_item	2610202	et	3	main
varjata	doc_491521502157_item	2610203	et	4	main
oluline	doc_491521502157_item	2610204	et	4	main
on	doc_491521502157_item	2610205	et	4	main
ka	doc_491521502157_item	2610206	et	3	main
see	doc_491521502157_item	2610207	et	3	main
kes	doc_491521502157_item	2610208	et	4	main
nende	doc_491521502157_item	2610209	et	4	main
tõlgendamisega	doc_491521502157_item	2610210	et	4	main
tegeleb	doc_491521502157_item	2610211	et	3	main
huvitanu	doc_491521502157_item	2610212	et	4	main
külje	doc_491521502157_item	2610213	et	3	main
puhul	doc_491521502157_item	2610214	et	4	main
juhtunud	doc_491521502157_item	2610216	et	4	main
palju	doc_491521502157_item	2610217	et	4	main
hakkab	doc_491521502157_item	2610215	et	3	main
subjektiivsemalt	doc_491521502157_item	2610218	et	4	main
kõlama	doc_491521502157_item	2610219	et	3	main
neid	doc_491521502157_item	2610231	et	4	main
mulle	doc_491521502157_item	2610252	et	4	main
arvamusele	doc_491521502157_item	2610257	et	3	main
kui	doc_491521502157_item	2610262	et	3	main
et	doc_491521502157_item	2610269	et	3	main
ma	doc_491521502157_item	2610270	et	3	main
vabariigis	doc_491521502157_item	2610280	et	3	main
lugesin	doc_491521502157_item	2610282	et	3	main
igal	doc_491521502157_item	2610288	et	3	main
tohutu	doc_491521502157_item	2610299	et	4	main
raamatuid	doc_491521502157_item	2610303	et	3	main
kus	doc_491521502157_item	2610304	et	3	main
olid	doc_491521502157_item	2610305	et	4	main
kiidetud	doc_491521502157_item	2610306	et	4	main
nõukogude	doc_491521502157_item	2610307	et	3	main
ideaalid	doc_491521502157_item	2610308	et	3	main
ja	doc_491521502157_item	2610309	et	3	main
ma	doc_491521502157_item	2610310	et	3	main
nägin	doc_491521502157_item	2610311	et	3	main
niisugusena	doc_491521502157_item	2610313	et	3	main
maailma	doc_491521502157_item	2610312	et	4	main
nagu	doc_491521502157_item	2610314	et	3	main
mind	doc_491521502157_item	2610315	et	4	main
õpetasid	doc_491521502157_item	2610316	et	4	main
need	doc_491521502157_item	2610317	et	3	main
raamatud	doc_491521502157_item	2610318	et	4	main
nagu	doc_491521502157_item	2610319	et	3	main
see	doc_491521502157_item	2610320	et	3	main
kasulik	doc_491521502157_item	2610322	et	3	main
polnud	doc_491521502157_item	2610327	et	3	main
et	doc_491521502157_item	2610329	et	3	main
on	doc_491521502157_item	2610335	et	4	main
tõsi	doc_491521502157_item	2610338	et	4	main
on	doc_491521502157_item	2610340	et	4	main
neid	doc_491521502157_item	2610341	et	4	main
mis	doc_491521502157_item	2610350	et	4	main
eest	doc_491521502157_item	2610353	et	4	main
leeninid	doc_491521502157_item	2610359	et	3	main
kõik	doc_491521502157_item	2610378	et	4	main
ei	doc_491521502157_item	2610387	et	4	main
toimu	doc_491521502157_item	2610388	et	4	main
teoreetiliselt	doc_491521502157_item	2610396	et	4	main
teinud	doc_491521502157_item	2610411	et	4	main
oma	doc_491521502157_item	2610418	et	4	main
huvides	doc_491521502157_item	2610419	et	3	main
rahva	doc_491521502157_item	2610425	et	3	main
toimuks	doc_491521502157_item	2610427	et	3	main
hulk	doc_491521502157_item	2610431	et	3	main
huvi	doc_491521502157_item	2610435	et	4	main
ka	doc_491521502157_item	2610437	et	3	main
sellest	doc_491521502157_item	2610444	et	4	main
mitte	doc_491521502157_item	2610449	et	3	main
ainult	doc_491521502157_item	2610450	et	4	main
venemaa	doc_491521502157_item	2610462	et	4	main
ajaloo	doc_491521502157_item	2610465	et	4	main
sellel	doc_491521502157_item	2610466	et	4	main
kõik	doc_491521502157_item	2610469	et	4	main
juhtunud	doc_491521502157_item	2610470	et	4	main
oli	doc_491521502157_item	2610471	et	3	main
võimu	doc_491521502157_item	2610478	et	4	main
tegevustesse	doc_491521502157_item	2610487	et	4	main
juhtidele	doc_491521502157_item	2610324	et	3	main
mul	doc_491521502157_item	2610326	et	3	main
ma	doc_491521502157_item	2610332	et	3	main
rohkem	doc_491521502157_item	2610343	et	4	main
praegu	doc_491521502157_item	2610344	et	3	main
tutvungi	doc_491521502157_item	2610345	et	3	main
tõedega	doc_491521502157_item	2610349	et	4	main
enne	doc_491521502157_item	2610351	et	4	main
minu	doc_491521502157_item	2610358	et	3	main
nagu	doc_491521502157_item	2610363	et	3	main
alati	doc_491521502157_item	2610364	et	4	main
kahtlusega	doc_491521502157_item	2610365	et	4	main
tegelikult	doc_491521502157_item	2610366	et	4	main
ei	doc_491521502157_item	2610367	et	4	main
usu	doc_491521502157_item	2610368	et	4	main
ma	doc_491521502157_item	2610369	et	3	main
filmi	doc_491521502157_item	2610370	et	4	main
peamise	doc_491521502157_item	2610371	et	3	main
ideisse	doc_491521502157_item	2610372	et	3	main
et	doc_491521502157_item	2610373	et	3	main
leenineid	doc_491521502157_item	2610374	et	4	main
oli	doc_491521502157_item	2610375	et	3	main
mitu	doc_491521502157_item	2610376	et	4	main
ja	doc_491521502157_item	2610377	et	3	main
see	doc_491521502157_item	2610330	et	3	main
sealt	doc_491521502157_item	2610333	et	4	main
palju	doc_491521502157_item	2610342	et	4	main
nende	doc_491521502157_item	2610347	et	4	main
minu	doc_491521502157_item	2610352	et	3	main
varjatud	doc_491521502157_item	2610354	et	4	main
olid	doc_491521502157_item	2610355	et	4	main
vaatasin	doc_491521502157_item	2610356	et	3	main
mitte	doc_491521502157_item	2610381	et	3	main
ühe	doc_491521502157_item	2610389	et	4	main
ainsa	doc_491521502157_item	2610390	et	3	main
inimese	doc_491521502157_item	2610391	et	4	main
sellepärast	doc_491521502157_item	2610398	et	3	main
neid	doc_491521502157_item	2610404	et	4	main
revolutsiooni	doc_491521502157_item	2610412	et	4	main
et	doc_491521502157_item	2610421	et	3	main
olema	doc_491521502157_item	2610429	et	4	main
protsessi	doc_491521502157_item	2610440	et	4	main
tänu	doc_491521502157_item	2610451	et	4	main
bolševikide	doc_491521502157_item	2610456	et	2	main
oli	doc_491521502157_item	2610463	et	3	main
venemaa	doc_491521502157_item	2610477	et	4	main
isevalitsuse	doc_491521502157_item	2610481	et	3	main
mis	doc_491521502157_item	2610483	et	4	main
kesküla	doc_491521502157_item	2610486	et	4	main
teda	doc_491521502157_item	2610488	et	4	main
milleski	doc_491521502157_item	2610491	et	4	main
süüdistada	doc_491521502157_item	2610492	et	3	main
ta	doc_491521502157_item	2610493	et	4	main
vaid	doc_491521502157_item	2610494	et	3	main
oli	doc_491521502157_item	2610521	et	3	main
nii	doc_491521502157_item	2610539	et	3	main
nii	doc_491521502157_item	2610544	et	3	main
siis	doc_491521502157_item	2610551	et	3	main
sellel	doc_491521502157_item	2610569	et	4	main
polnud	doc_491521502157_item	2610570	et	3	main
reaalsusega	doc_491521502157_item	2610573	et	4	main
ei	doc_491521502157_item	2610576	et	4	main
pakunud	doc_491521502157_item	2610581	et	4	main
huvi	doc_491521502157_item	2610583	et	4	main
keele	doc_491521502158_item	2610585	et	4	main
keele	doc_491521502158_item	2610588	et	4	main
test	doc_491521502158_item	2610589	et	3	main
sõnad	doc_491521502158_item	2610594	et	4	main
õigesse	doc_491521502158_item	2610595	et	3	main
suvel	doc_491521502158_item	2610602	et	3	main
nägema	doc_491521502158_item	2610603	et	3	main
nüüd	doc_491521502158_item	2610623	et	4	main
õpetama	doc_491521502158_item	2610633	et	3	main
tundis	doc_491521502158_item	2610637	et	3	main
siberisse	doc_491521502158_item	2610639	et	4	main
jõudma	doc_491521502158_item	2610640	et	3	main
jõudis	doc_491521502158_item	2610641	et	3	main
et	doc_491521502158_item	2610642	et	3	main
on	doc_491521502158_item	2610643	et	4	main
tuli	doc_491521502158_item	2610652	et	4	main
korralik	doc_491521502158_item	2610654	et	3	main
siber	doc_491521502158_item	2610659	et	4	main
siberi	doc_491521502158_item	2610660	et	4	main
pilt	doc_491521502158_item	2610662	et	3	main
et	doc_491521502158_item	2610663	et	3	main
kasva	doc_491521502158_item	2610670	et	4	main
ja	doc_491521502158_item	2610674	et	3	main
jõudis	doc_491521502158_item	2610684	et	3	main
veel	doc_491521502158_item	2610687	et	4	main
toimunud	doc_491521502157_item	2610379	et	4	main
isegi	doc_491521502157_item	2610395	et	4	main
palju	doc_491521502157_item	2610403	et	4	main
oli	doc_491521502157_item	2610406	et	3	main
venemaal	doc_491521502157_item	2610413	et	4	main
ta	doc_491521502157_item	2610414	et	4	main
kasutas	doc_491521502157_item	2610416	et	3	main
olukorda	doc_491521502157_item	2610417	et	4	main
sellist	doc_491521502157_item	2610423	et	4	main
revolutsioon	doc_491521502157_item	2610426	et	3	main
reguleerida	doc_491521502157_item	2610441	et	3	main
räägin	doc_491521502157_item	2610443	et	3	main
et	doc_491521502157_item	2610445	et	3	main
või	doc_491521502157_item	2610455	et	4	main
või	doc_491521502157_item	2610458	et	4	main
rahalisele	doc_491521502157_item	2610460	et	4	main
toetusele	doc_491521502157_item	2610461	et	4	main
oma	doc_491521502157_item	2610464	et	4	main
olid	doc_491521502157_item	2610475	et	4	main
huvitatud	doc_491521502157_item	2610476	et	4	main
a	doc_491521502157_item	2610485	et	4	main
saa	doc_491521502157_item	2610490	et	4	main
üks	doc_491521502157_item	2610522	et	3	main
terve	doc_491521502157_item	2610524	et	4	main
tegija	doc_491521502157_item	2610526	et	4	main
tänu	doc_491521502157_item	2610527	et	4	main
koos	doc_491521502157_item	2610536	et	4	main
võinud	doc_491521502157_item	2610542	et	4	main
nagu	doc_491521502157_item	2610546	et	3	main
kõik	doc_491521502157_item	2610552	et	4	main
oleks	doc_491521502157_item	2610554	et	3	main
film	doc_491521502157_item	2610563	et	3	main
pistmist	doc_491521502157_item	2610572	et	4	main
et	doc_491521502157_item	2610578	et	3	main
ei	doc_491521502157_item	2610580	et	4	main
i	doc_491521502158_item	2610590	et	4	main
pange	doc_491521502158_item	2610591	et	4	main
piret	doc_491521502158_item	2610597	et	4	main
ta	doc_491521502158_item	2610605	et	4	main
ja	doc_491521502158_item	2610621	et	3	main
nädala	doc_491521502158_item	2610627	et	3	main
väikestele	doc_491521502158_item	2610628	et	4	main
eestlastele	doc_491521502158_item	2610629	et	4	main
need	doc_491521502158_item	2610630	et	3	main
õpetas	doc_491521502158_item	2610634	et	3	main
oodatud	doc_491521502158_item	2610644	et	4	main
üsna	doc_491521502158_item	2610646	et	3	main
üllatanud	doc_491521502158_item	2610648	et	4	main
seal	doc_491521502158_item	2610664	et	4	main
ei	doc_491521502158_item	2610665	et	4	main
lendama	doc_491521502158_item	2610666	et	3	main
rohi	doc_491521502158_item	2610671	et	4	main
tahtmine	doc_491521502158_item	2610675	et	4	main
piret	doc_491521502158_item	2610678	et	4	main
pärast	doc_491521502158_item	2610679	et	4	main
küla	doc_491521502158_item	2610691	et	4	main
võtma	doc_491521502158_item	2610692	et	3	main
võttis	doc_491521502158_item	2610693	et	3	main
kartuleid	doc_491521502158_item	2610694	et	3	main
mitte	doc_491521502158_item	2610721	et	3	main
aktsent	doc_491521502158_item	2610723	et	3	main
aktsentiga	doc_491521502158_item	2610724	et	4	main
vaid	doc_491521502158_item	2610725	et	3	main
mõni	doc_491521502158_item	2610727	et	3	main
mõned	doc_491521502158_item	2610728	et	3	main
kool	doc_491521502158_item	2610734	et	4	main
ja	doc_491521502158_item	2610735	et	3	main
ülejäänud	doc_491521502158_item	2610736	et	4	main
aine	doc_491521502158_item	2610737	et	4	main
õpetatakse	doc_491521502158_item	2610739	et	3	main
vene	doc_491521502158_item	2610740	et	4	main
kõik	doc_491521502158_item	2610752	et	4	main
rääkida	doc_491521502158_item	2610754	et	3	main
päevad	doc_491521502158_item	2610781	et	3	main
ööd	doc_491521502158_item	2610786	et	4	main
juba	doc_491521502158_item	2610791	et	3	main
suure	doc_491521502158_item	2610792	et	3	main
külapood	doc_491521502158_item	2610800	et	3	main
ega	doc_491521502158_item	2610803	et	3	main
naerab	doc_491521502158_item	2610809	et	3	main
lühendatud	doc_491521502158_item	2610815	et	4	main
iii	doc_491521502158_item	2610818	et	4	main
kasutades	doc_491521502158_item	2610828	et	3	main
mehelikum	doc_491521502158_item	2610837	et	4	main
kaunim	doc_491521502158_item	2610839	et	4	main
igaüks	doc_491521502158_item	2610840	et	3	main
kogus	doc_491521502158_item	2610851	et	4	main
stress	doc_491521502158_item	2610852	et	3	main
nagu	doc_491521502157_item	2610424	et	3	main
peab	doc_491521502157_item	2610428	et	4	main
suur	doc_491521502157_item	2610430	et	3	main
huvitanuid	doc_491521502157_item	2610432	et	4	main
kellel	doc_491521502157_item	2610433	et	4	main
oleks	doc_491521502157_item	2610436	et	3	main
võim	doc_491521502157_item	2610438	et	3	main
ma	doc_491521502157_item	2610442	et	3	main
revolutsioon	doc_491521502157_item	2610446	et	3	main
a	doc_491521502157_item	2610452	et	4	main
kesküla	doc_491521502157_item	2610453	et	4	main
tegevusele	doc_491521502157_item	2610457	et	4	main
saksamaa	doc_491521502157_item	2610459	et	4	main
perioodil	doc_491521502157_item	2610467	et	3	main
millal	doc_491521502157_item	2610468	et	3	main
liiga	doc_491521502157_item	2610473	et	4	main
nõrgendamises	doc_491521502157_item	2610479	et	4	main
ei	doc_491521502157_item	2610489	et	4	main
püüdis	doc_491521502157_item	2610495	et	3	main
võimalusega	doc_491521502157_item	2610497	et	3	main
oma	doc_491521502157_item	2610498	et	4	main
riigile	doc_491521502157_item	2610499	et	3	main
iseseisvust	doc_491521502157_item	2610500	et	4	main
saavutada	doc_491521502157_item	2610501	et	3	main
kuigi	doc_491521502157_item	2610502	et	3	main
filmis	doc_491521502157_item	2610503	et	4	main
on	doc_491521502157_item	2610504	et	4	main
see	doc_491521502157_item	2610505	et	3	main
kuidagi	doc_491521502157_item	2610506	et	3	main
naljakalt	doc_491521502157_item	2610507	et	4	main
esitatud	doc_491521502157_item	2610508	et	4	main
tundub	doc_491521502157_item	2610509	et	3	main
nii	doc_491521502157_item	2610510	et	3	main
nagu	doc_491521502157_item	2610511	et	3	main
kõik	doc_491521502157_item	2610512	et	4	main
teised	doc_491521502157_item	2610513	et	4	main
olid	doc_491521502157_item	2610514	et	4	main
lollid	doc_491521502157_item	2610515	et	3	main
lenin	doc_491521502157_item	2610516	et	4	main
saksamaa	doc_491521502157_item	2610517	et	4	main
saatkond	doc_491521502157_item	2610518	et	3	main
aga	doc_491521502157_item	2610519	et	3	main
kesküla	doc_491521502157_item	2610520	et	4	main
ainuke	doc_491521502157_item	2610523	et	4	main
mõistusega	doc_491521502157_item	2610525	et	3	main
arust	doc_491521502157_item	2610533	et	4	main
nii	doc_491521502157_item	2610534	et	3	main
leenin	doc_491521502157_item	2610535	et	4	main
kaastegijatega	doc_491521502157_item	2610538	et	3	main
ei	doc_491521502157_item	2610541	et	4	main
naiivseteks	doc_491521502157_item	2610545	et	4	main
mulle	doc_491521502157_item	2610558	et	4	main
tundus	doc_491521502157_item	2610559	et	3	main
et	doc_491521502157_item	2610560	et	3	main
see	doc_491521502157_item	2610562	et	3	main
lapsemäng	doc_491521502157_item	2610566	et	3	main
kuid	doc_491521502157_item	2610574	et	4	main
see	doc_491521502157_item	2610575	et	3	main
kellele	doc_491521502157_item	2610528	et	4	main
toimuski	doc_491521502157_item	2610529	et	3	main
revolutsioon	doc_491521502157_item	2610530	et	3	main
venemaal	doc_491521502157_item	2610531	et	4	main
oma	doc_491521502157_item	2610537	et	4	main
sakslased	doc_491521502157_item	2610540	et	3	main
olla	doc_491521502157_item	2610543	et	3	main
neid	doc_491521502157_item	2610547	et	4	main
kogu	doc_491521502157_item	2610561	et	4	main
oli	doc_491521502157_item	2610564	et	3	main
revolutsiooni	doc_491521502157_item	2610567	et	4	main
see	doc_491521502157_item	2610579	et	3	main
eesti	doc_491521502158_item	2610584	et	4	main
eesti	doc_491521502158_item	2610587	et	4	main
olevad	doc_491521502158_item	2610593	et	4	main
on	doc_491521502158_item	2610599	et	4	main
ettevõtlik	doc_491521502158_item	2610600	et	3	main
naine	doc_491521502158_item	2610601	et	3	main
nägi	doc_491521502158_item	2610604	et	3	main
ajalehes	doc_491521502158_item	2610606	et	3	main
et	doc_491521502158_item	2610608	et	3	main
kuulutus	doc_491521502158_item	2610607	et	4	main
siberisse	doc_491521502158_item	2610609	et	4	main
ülem-suetuki	doc_491521502158_item	2610610	et	4	main
küla	doc_491521502158_item	2610611	et	4	main
külas	doc_491521502158_item	2610612	et	3	main
otsitakse	doc_491521502158_item	2610613	et	3	main
eesti	doc_491521502158_item	2610614	et	4	main
keele	doc_491521502158_item	2610615	et	4	main
õpetajat	doc_491521502158_item	2610616	et	4	main
piret	doc_491521502158_item	2610617	et	4	main
võitis	doc_491521502158_item	2610618	et	3	main
konkurss	doc_491521502158_item	2610619	et	3	main
konkurssis	doc_491521502158_item	2610620	et	4	main
pireti	doc_491521502158_item	2610635	et	4	main
olin	doc_491521502158_item	2610645	et	3	main
tulema	doc_491521502158_item	2610651	et	4	main
vastu	doc_491521502158_item	2610653	et	3	main
mulle	doc_491521502158_item	2610657	et	4	main
lind	doc_491521502158_item	2610668	et	3	main
ega	doc_491521502158_item	2610669	et	3	main
tahtmitega	doc_491521502158_item	2610676	et	4	main
täis	doc_491521502158_item	2610677	et	4	main
õppeaasta	doc_491521502158_item	2610680	et	4	main
algust	doc_491521502158_item	2610681	et	4	main
koht	doc_491521502158_item	2610682	et	3	main
kool	doc_491521502158_item	2610686	et	4	main
alanud	doc_491521502158_item	2610689	et	4	main
kogu	doc_491521502158_item	2610690	et	4	main
kolmsada	doc_491521502158_item	2610746	et	4	main
saab	doc_491521502158_item	2610751	et	3	main
pireti	doc_491521502158_item	2610755	et	4	main
lapsed	doc_491521502158_item	2610758	et	3	main
varsti	doc_491521502158_item	2610762	et	3	main
uued	doc_491521502158_item	2610766	et	3	main
karda	doc_491521502158_item	2610773	et	4	main
mulle	doc_491521502158_item	2610774	et	4	main
juba	doc_491521502158_item	2610775	et	3	main
tooma	doc_491521502158_item	2610776	et	3	main
juba	doc_491521502158_item	2610787	et	3	main
ahju	doc_491521502158_item	2610794	et	4	main
külapooes	doc_491521502158_item	2610801	et	4	main
seal	doc_491521502158_item	2610804	et	4	main
suurt	doc_491521502158_item	2610805	et	3	main
sõnadest	doc_491521502158_item	2610821	et	3	main
2	doc_491521502158_item	2610830	et	2	main
mulle	doc_491521502157_item	2610582	et	4	main
vormi	doc_491521502158_item	2610596	et	4	main
on	doc_491521502158_item	2610622	et	4	main
juba	doc_491521502158_item	2610624	et	3	main
üle	doc_491521502158_item	2610625	et	3	main
nädal	doc_491521502158_item	2610626	et	3	main
emakeelt	doc_491521502158_item	2610632	et	4	main
kinnitusel	doc_491521502158_item	2610636	et	4	main
ta	doc_491521502158_item	2610638	et	4	main
mulle	doc_491521502158_item	2610650	et	4	main
korralikuga	doc_491521502158_item	2610655	et	3	main
maaliti	doc_491521502158_item	2610658	et	3	main
selline	doc_491521502158_item	2610661	et	4	main
noor	doc_491521502158_item	2610673	et	3	main
polnud	doc_491521502158_item	2610685	et	3	main
algama	doc_491521502158_item	2610688	et	3	main
siin	doc_491521502158_item	2610697	et	4	main
ettevõtmine	doc_491521502158_item	2610701	et	3	main
tänaseks	doc_491521502158_item	2610702	et	4	main
on	doc_491521502158_item	2610703	et	4	main
kartul	doc_491521502158_item	2610704	et	3	main
salv	doc_491521502158_item	2610705	et	3	main
salves	doc_491521502158_item	2610706	et	4	main
ja	doc_491521502158_item	2610707	et	3	main
õppimine	doc_491521502158_item	2610708	et	4	main
käib	doc_491521502158_item	2610709	et	3	main
täie	doc_491521502158_item	2610710	et	3	main
hoog	doc_491521502158_item	2610711	et	3	main
hooga	doc_491521502158_item	2610712	et	3	main
siinsed	doc_491521502158_item	2610713	et	3	main
eestlased	doc_491521502158_item	2610714	et	3	main
räägivad	doc_491521502158_item	2610715	et	3	main
kuidagi	doc_491521502158_item	2610716	et	3	main
teistmoodi	doc_491521502158_item	2610717	et	3	main
mõnus	doc_491521502158_item	2610718	et	4	main
ja	doc_491521502158_item	2610719	et	3	main
mahlakas	doc_491521502158_item	2610720	et	4	main
vene	doc_491521502158_item	2610722	et	4	main
nagu	doc_491521502158_item	2610726	et	3	main
kolmesaja	doc_491521502158_item	2610747	et	4	main
inimene	doc_491521502158_item	2610748	et	3	main
inimisi	doc_491521502158_item	2610749	et	4	main
sõnul	doc_491521502158_item	2610756	et	3	main
poolpõlenud	doc_491521502158_item	2610759	et	4	main
raamatuid	doc_491521502158_item	2610761	et	3	main
eestist	doc_491521502158_item	2610765	et	3	main
siberi	doc_491521502158_item	2610768	et	4	main
toodi	doc_491521502158_item	2610777	et	4	main
veel	doc_491521502158_item	2610782	et	4	main
soojad	doc_491521502158_item	2610784	et	3	main
kuid	doc_491521502158_item	2610785	et	4	main
harjutan	doc_491521502158_item	2610790	et	3	main
vene	doc_491521502158_item	2610793	et	4	main
kütmine	doc_491521502158_item	2610795	et	4	main
kütma	doc_491521502158_item	2610796	et	3	main
kui	doc_491521502158_item	2610797	et	3	main
vildid	doc_491521502158_item	2610802	et	4	main
müüdagi	doc_491521502158_item	2610808	et	3	main
vapralt	doc_491521502158_item	2610814	et	4	main
sõnad	doc_491521502158_item	2610824	et	4	main
kirjavahemärke	doc_491521502158_item	2610829	et	4	main
tegema	doc_491521502158_item	2610832	et	3	main
meie	doc_491521502158_item	2610854	et	4	main
on	doc_491521502158_item	2610696	et	4	main
sügisel	doc_491521502158_item	2610698	et	3	main
kõige	doc_491521502158_item	2610699	et	4	main
tähtis	doc_491521502158_item	2610700	et	4	main
on	doc_491521502158_item	2610731	et	4	main
siiski	doc_491521502158_item	2610732	et	4	main
ained	doc_491521502158_item	2610738	et	3	main
kõik	doc_491521502158_item	2610753	et	4	main
raamatud	doc_491521502158_item	2610760	et	4	main
saavad	doc_491521502158_item	2610764	et	4	main
talve	doc_491521502158_item	2610769	et	4	main
piret	doc_491521502158_item	2610770	et	4	main
ei	doc_491521502158_item	2610771	et	4	main
kartma	doc_491521502158_item	2610772	et	3	main
talvepuud	doc_491521502158_item	2610778	et	4	main
praegu	doc_491521502158_item	2610779	et	3	main
jahe	doc_491521502158_item	2610788	et	3	main
vaja	doc_491521502158_item	2610798	et	4	main
ei	doc_491521502158_item	2610807	et	4	main
valmistuma	doc_491521502158_item	2610811	et	3	main
piret	doc_491521502158_item	2610813	et	4	main
ajalehest	doc_491521502158_item	2610816	et	4	main
murret	doc_491521502158_item	2610729	et	4	main
kool	doc_491521502158_item	2610730	et	4	main
venemaa	doc_491521502158_item	2610733	et	4	main
keeles	doc_491521502158_item	2610741	et	4	main
külas	doc_491521502158_item	2610742	et	3	main
elab	doc_491521502158_item	2610743	et	3	main
veidi	doc_491521502158_item	2610744	et	3	main
üle	doc_491521502158_item	2610745	et	3	main
emakeelt	doc_491521502158_item	2610750	et	4	main
õpivad	doc_491521502158_item	2610757	et	3	main
saatma	doc_491521502158_item	2610763	et	3	main
õpikud	doc_491521502158_item	2610767	et	3	main
on	doc_491521502158_item	2610780	et	4	main
soe	doc_491521502158_item	2610783	et	4	main
jahedad	doc_491521502158_item	2610789	et	3	main
ostan	doc_491521502158_item	2610799	et	3	main
muud	doc_491521502158_item	2610806	et	4	main
talveks	doc_491521502158_item	2610810	et	4	main
valmistuseks	doc_491521502158_item	2610812	et	4	main
slõhtuleht	doc_491521502158_item	2610817	et	4	main
moodustage	doc_491521502158_item	2610819	et	3	main
etteantud	doc_491521502158_item	2610820	et	4	main
pannes	doc_491521502158_item	2610823	et	4	main
õigesse	doc_491521502158_item	2610825	et	3	main
ja	doc_491521502158_item	2610827	et	3	main
naeratus	doc_491521502158_item	2610831	et	4	main
naised	doc_491521502158_item	2610833	et	3	main
mehed	doc_491521502158_item	2610836	et	3	main
igaüks	doc_491521502158_item	2610838	et	3	main
mehi	doc_491521502158_item	2610847	et	3	main
mehelikum	doc_491521502158_item	2610848	et	4	main
3	doc_491521502158_item	2610849	et	2	main
paras	doc_491521502158_item	2610850	et	3	main
paneb	doc_491521502158_item	2610863	et	3	main
ülekoormus	doc_491521502158_item	2610875	et	3	main
6	doc_491521502158_item	2610911	et	2	main
ka	doc_491521502158_item	2610915	et	3	main
segama	doc_491521502158_item	2610919	et	3	main
huvitav	doc_491521502158_item	2610925	et	4	main
huvitava	doc_491521502158_item	2610942	et	4	main
sulgudes	doc_491521502158_item	2610948	et	4	main
olevad	doc_491521502158_item	2610949	et	4	main
sõnad	doc_491521502158_item	2610950	et	4	main
õigesse	doc_491521502158_item	2610951	et	3	main
vormi	doc_491521502158_item	2610952	et	4	main
1	doc_491521502158_item	2610953	et	2	main
ma	doc_491521502158_item	2610954	et	3	main
pean	doc_491521502158_item	2610955	et	4	main
väga	doc_491521502158_item	2610956	et	3	main
oma	doc_491521502158_item	2610960	et	4	main
sest	doc_491521502158_item	2610962	et	4	main
sa	doc_491521502158_item	2610980	et	3	main
7	doc_491521502158_item	2611022	et	2	main
küsimus	doc_491521502158_item	2611024	et	4	main
10	doc_491521502158_item	2611042	et	2	main
v	doc_491521502158_item	2611050	et	4	main
täitke	doc_491521502158_item	2611051	et	3	main
lüngad	doc_491521502158_item	2611052	et	3	main
sobivate	doc_491521502158_item	2611053	et	4	main
sidenditega	doc_491521502158_item	2611054	et	3	main
kõik	doc_491521502158_item	2611066	et	4	main
õpilased	doc_491521502158_item	2611067	et	3	main
jalutama	doc_491521502158_item	2611102	et	3	main
selles	doc_491521502158_item	2611104	et	4	main
töötasid	doc_491521502158_item	2611114	et	4	main
küll	doc_491521502158_item	2611115	et	4	main
sõidad	doc_491521502158_item	2611124	et	3	main
või	doc_491521502158_item	2611126	et	4	main
jääd	doc_491521502158_item	2611127	et	4	main
linna	doc_491521502158_item	2611128	et	4	main
10	doc_491521502158_item	2611129	et	2	main
avasin	doc_491521502158_item	2611130	et	3	main
ukse	doc_491521502158_item	2611131	et	3	main
kui	doc_491521502158_item	2611132	et	3	main
kuulsin	doc_491521502158_item	2611133	et	3	main
keele	doc_491521502159_item	2611139	et	4	main
test	doc_491521502159_item	2611140	et	3	main
sõnad	doc_491521502159_item	2611145	et	4	main
õigesse	doc_491521502159_item	2611146	et	3	main
kuulutusis	doc_491521502159_item	2611159	et	4	main
siberisse	doc_491521502159_item	2611161	et	4	main
laused	doc_491521502158_item	2610822	et	3	main
vormi	doc_491521502158_item	2610826	et	4	main
kaunim	doc_491521502158_item	2610841	et	4	main
naeratus	doc_491521502158_item	2610842	et	4	main
teeb	doc_491521502158_item	2610843	et	3	main
naisi	doc_491521502158_item	2610844	et	3	main
naiselikum	doc_491521502158_item	2610845	et	4	main
ja	doc_491521502158_item	2610846	et	3	main
tooma	doc_491521502158_item	2610859	et	3	main
stress	doc_491521502158_item	2610862	et	3	main
toob	doc_491521502158_item	2610868	et	3	main
sportima	doc_491521502158_item	2610880	et	4	main
ja	doc_491521502158_item	2610881	et	3	main
puhkama	doc_491521502158_item	2610882	et	3	main
5	doc_491521502158_item	2610883	et	2	main
telefon	doc_491521502158_item	2610884	et	3	main
olema	doc_491521502158_item	2610885	et	4	main
tänapäev	doc_491521502158_item	2610886	et	3	main
nii	doc_491521502158_item	2610888	et	3	main
maagiline	doc_491521502158_item	2610889	et	4	main
saama	doc_491521502158_item	2610887	et	4	main
aparaat	doc_491521502158_item	2610890	et	3	main
et	doc_491521502158_item	2610891	et	3	main
see	doc_491521502158_item	2610892	et	3	main
abil	doc_491521502158_item	2610893	et	4	main
lausa	doc_491521502158_item	2610894	et	4	main
elama	doc_491521502158_item	2610895	et	3	main
ja	doc_491521502158_item	2610896	et	3	main
hingama	doc_491521502158_item	2610897	et	3	main
telefon	doc_491521502158_item	2610898	et	3	main
on	doc_491521502158_item	2610899	et	4	main
tänapäeval	doc_491521502158_item	2610900	et	3	main
saanud	doc_491521502158_item	2610901	et	4	main
nii	doc_491521502158_item	2610902	et	3	main
maagilise	doc_491521502158_item	2610903	et	4	main
et	doc_491521502158_item	2610905	et	3	main
tema	doc_491521502158_item	2610906	et	4	main
abil	doc_491521502158_item	2610907	et	4	main
aparaat	doc_491521502158_item	2610904	et	3	main
elame	doc_491521502158_item	2610908	et	3	main
ja	doc_491521502158_item	2610909	et	3	main
hingame	doc_491521502158_item	2610910	et	3	main
naiselikum	doc_491521502158_item	2610834	et	4	main
ja	doc_491521502158_item	2610835	et	3	main
soovimatu	doc_491521502158_item	2610860	et	4	main
tagajärg	doc_491521502158_item	2610861	et	3	main
lisakoormus	doc_491521502158_item	2610866	et	3	main
tagajarg	doc_491521502158_item	2610870	et	4	main
laskma	doc_491521502158_item	2610874	et	3	main
tekkima	doc_491521502158_item	2610876	et	3	main
pühapäev	doc_491521502158_item	2610916	et	3	main
vaatamine	doc_491521502158_item	2610927	et	4	main
pühapäeva	doc_491521502158_item	2610930	et	4	main
segab	doc_491521502158_item	2610932	et	3	main
und	doc_491521502158_item	2610933	et	4	main
katkestab	doc_491521502158_item	2610941	et	3	main
vatamise	doc_491521502158_item	2610944	et	4	main
lugu	doc_491521502158_item	2610957	et	4	main
igaühele	doc_491521502158_item	2610970	et	3	main
kohandasin	doc_491521502158_item	2610972	et	3	main
nõuded	doc_491521502158_item	2610974	et	3	main
3	doc_491521502158_item	2610976	et	2	main
arvasin	doc_491521502158_item	2610978	et	3	main
huvitud	doc_491521502158_item	2610981	et	4	main
aga	doc_491521502158_item	2610984	et	3	main
huvi	doc_491521502158_item	2610987	et	4	main
ainult	doc_491521502158_item	2610988	et	4	main
ilusad	doc_491521502158_item	2610989	et	3	main
panema	doc_491521502158_item	2610853	et	3	main
paras	doc_491521502158_item	2610865	et	3	main
ja	doc_491521502158_item	2610867	et	3	main
ei	doc_491521502158_item	2610872	et	4	main
kuid	doc_491521502158_item	2610912	et	4	main
katkestama	doc_491521502158_item	2610914	et	3	main
tegutsema	doc_491521502158_item	2610855	et	3	main
aga	doc_491521502158_item	2610856	et	3	main
lisakoormus	doc_491521502158_item	2610857	et	3	main
võima	doc_491521502158_item	2610858	et	3	main
meile	doc_491521502158_item	2610864	et	4	main
soovimatu	doc_491521502158_item	2610869	et	4	main
4	doc_491521502158_item	2610871	et	2	main
tohtima	doc_491521502158_item	2610873	et	3	main
pinge	doc_491521502158_item	2610877	et	4	main
saama	doc_491521502158_item	2610878	et	4	main
maandama	doc_491521502158_item	2610879	et	3	main
telefonihelin	doc_491521502158_item	2610913	et	3	main
lõunasöök	doc_491521502158_item	2610920	et	3	main
telesaade	doc_491521502158_item	2610926	et	4	main
telefonihelin	doc_491521502158_item	2610929	et	3	main
varahommikul	doc_491521502158_item	2610931	et	3	main
söömine	doc_491521502158_item	2610939	et	4	main
ja	doc_491521502158_item	2610940	et	3	main
vanemad	doc_491521502158_item	2610959	et	4	main
kõik	doc_491521502158_item	2610965	et	4	main
usaldavad	doc_491521502158_item	2610968	et	4	main
2	doc_491521502158_item	2610971	et	2	main
artikli	doc_491521502158_item	2610973	et	3	main
et	doc_491521502158_item	2610979	et	3	main
teine	doc_491521502158_item	2611026	et	3	main
8	doc_491521502158_item	2611030	et	2	main
ajal	doc_491521502158_item	2611037	et	4	main
hoiduma	doc_491521502158_item	2611039	et	3	main
rõõmu	doc_491521502158_item	2611045	et	4	main
kolmekäigulise	doc_491521502158_item	2611057	et	4	main
ja	doc_491521502158_item	2611068	et	3	main
lapsel	doc_491521502158_item	2611071	et	4	main
alkoholi	doc_491521502158_item	2611110	et	4	main
tarbida	doc_491521502158_item	2611111	et	3	main
8	doc_491521502158_item	2611112	et	2	main
nad	doc_491521502158_item	2611113	et	3	main
tulemust	doc_491521502158_item	2611118	et	4	main
olnud	doc_491521502158_item	2611120	et	4	main
varahommik	doc_491521502158_item	2610917	et	3	main
uni	doc_491521502158_item	2610918	et	3	main
ja	doc_491521502158_item	2610922	et	3	main
söömine	doc_491521502158_item	2610923	et	4	main
aeg	doc_491521502158_item	2610928	et	3	main
ka	doc_491521502158_item	2610934	et	3	main
pahandab	doc_491521502158_item	2610935	et	3	main
telesaade	doc_491521502158_item	2610943	et	4	main
aega	doc_491521502158_item	2610945	et	4	main
iv	doc_491521502158_item	2610946	et	4	main
oma	doc_491521502158_item	2610958	et	4	main
vanematele	doc_491521502158_item	2610961	et	4	main
nad	doc_491521502158_item	2610963	et	3	main
kõike	doc_491521502158_item	2610966	et	4	main
igaüks	doc_491521502158_item	2610969	et	3	main
nõudesse	doc_491521502158_item	2610975	et	4	main
ma	doc_491521502158_item	2610977	et	3	main
sportiga	doc_491521502158_item	2610983	et	4	main
tunned	doc_491521502158_item	2610986	et	3	main
naised	doc_491521502158_item	2610990	et	3	main
ja	doc_491521502158_item	2610991	et	3	main
kiired	doc_491521502158_item	2610992	et	4	main
autod	doc_491521502158_item	2610993	et	3	main
ilusa	doc_491521502158_item	2610994	et	3	main
naisega	doc_491521502158_item	2610995	et	3	main
ja	doc_491521502158_item	2610996	et	3	main
teises	doc_491521502158_item	2611028	et	4	main
valdkonnas	doc_491521502158_item	2611029	et	4	main
närimiskumm	doc_491521502158_item	2611031	et	3	main
püksid	doc_491521502158_item	2611033	et	3	main
9	doc_491521502158_item	2611035	et	2	main
külmetamine	doc_491521502158_item	2611040	et	4	main
suvisel	doc_491521502158_item	2611048	et	4	main
päikesel	doc_491521502158_item	2611049	et	4	main
lõuna	doc_491521502158_item	2611058	et	4	main
aga	doc_491521502158_item	2611059	et	3	main
palju	doc_491521502158_item	2611062	et	4	main
õpetajad	doc_491521502158_item	2611069	et	4	main
paluti	doc_491521502158_item	2611072	et	3	main
tohi	doc_491521502158_item	2611107	et	4	main
suitsetada	doc_491521502158_item	2611108	et	3	main
ega	doc_491521502158_item	2611109	et	3	main
aga	doc_491521502158_item	2611117	et	3	main
kas	doc_491521502158_item	2611122	et	3	main
maale	doc_491521502158_item	2611125	et	4	main
i	doc_491521502159_item	2611141	et	4	main
pange	doc_491521502159_item	2611142	et	4	main
näin	doc_491521502159_item	2611155	et	3	main
pireti	doc_491521502159_item	2611186	et	4	main
oodatud	doc_491521502159_item	2611195	et	4	main
et	doc_491521502159_item	2611213	et	3	main
ega	doc_491521502159_item	2611219	et	3	main
algama	doc_491521502159_item	2611238	et	3	main
tänaseks	doc_491521502159_item	2611252	et	4	main
on	doc_491521502159_item	2611253	et	4	main
kartul	doc_491521502159_item	2611254	et	3	main
salv	doc_491521502159_item	2611255	et	3	main
ja	doc_491521502159_item	2611256	et	3	main
õppimine	doc_491521502159_item	2611257	et	4	main
käib	doc_491521502159_item	2611258	et	3	main
täie	doc_491521502159_item	2611259	et	3	main
hoog	doc_491521502159_item	2611260	et	3	main
siinsed	doc_491521502159_item	2611261	et	3	main
eestlased	doc_491521502159_item	2611262	et	3	main
räägivad	doc_491521502159_item	2611263	et	3	main
kuidagi	doc_491521502159_item	2611264	et	3	main
teistmoodi	doc_491521502159_item	2611265	et	3	main
on	doc_491521502159_item	2611279	et	4	main
vene	doc_491521502159_item	2611287	et	4	main
valmistamine	doc_491521502158_item	2610921	et	4	main
pahandab	doc_491521502158_item	2610924	et	3	main
lõunasööki	doc_491521502158_item	2610936	et	4	main
valmistamine	doc_491521502158_item	2610937	et	4	main
ja	doc_491521502158_item	2610938	et	3	main
pange	doc_491521502158_item	2610947	et	4	main
aitavad	doc_491521502158_item	2610964	et	4	main
ja	doc_491521502158_item	2610967	et	3	main
sport	doc_491521502158_item	2610982	et	3	main
sa	doc_491521502158_item	2610985	et	3	main
kiire	doc_491521502158_item	2610997	et	4	main
autoga	doc_491521502158_item	2610998	et	3	main
4	doc_491521502158_item	2610999	et	2	main
praegu	doc_491521502158_item	2611000	et	3	main
on	doc_491521502158_item	2611001	et	4	main
oht	doc_491521502158_item	2611002	et	3	main
haigestuda	doc_491521502158_item	2611003	et	3	main
difteeria	doc_491521502158_item	2611004	et	4	main
difteeriaks	doc_491521502158_item	2611005	et	3	main
5	doc_491521502158_item	2611006	et	2	main
tüdinesin	doc_491521502158_item	2611007	et	3	main
uus	doc_491521502158_item	2611008	et	3	main
töökoht	doc_491521502158_item	2611009	et	3	main
uue	doc_491521502158_item	2611010	et	3	main
töökoha	doc_491521502158_item	2611011	et	4	main
kiiresti	doc_491521502158_item	2611012	et	3	main
6	doc_491521502158_item	2611013	et	2	main
piirdusime	doc_491521502158_item	2611014	et	3	main
selles	doc_491521502158_item	2611015	et	4	main
küsimuses	doc_491521502158_item	2611016	et	4	main
vaid	doc_491521502158_item	2611017	et	3	main
väikesed	doc_491521502158_item	2611018	et	4	main
muudatused	doc_491521502158_item	2611019	et	3	main
väikesi	doc_491521502158_item	2611020	et	4	main
muudatusi	doc_491521502158_item	2611021	et	3	main
kuulub	doc_491521502158_item	2611025	et	3	main
kleepus	doc_491521502158_item	2611032	et	3	main
püksile	doc_491521502158_item	2611034	et	3	main
ma	doc_491521502158_item	2611043	et	3	main
see	doc_491521502158_item	2611060	et	3	main
2	doc_491521502158_item	2611063	et	2	main
kohal	doc_491521502158_item	2611064	et	4	main
olid	doc_491521502158_item	2611065	et	4	main
3	doc_491521502158_item	2611070	et	2	main
oodata	doc_491521502158_item	2611073	et	4	main
kui	doc_491521502158_item	2611074	et	3	main
vanemad	doc_491521502158_item	2611075	et	4	main
7	doc_491521502158_item	2611103	et	2	main
baaris	doc_491521502158_item	2611105	et	3	main
ei	doc_491521502158_item	2611106	et	4	main
pingsalt	doc_491521502158_item	2611116	et	4	main
ei	doc_491521502158_item	2611119	et	4	main
eesti	doc_491521502159_item	2611135	et	4	main
keele	doc_491521502159_item	2611136	et	4	main
sulgudes	doc_491521502159_item	2611143	et	4	main
toomet	doc_491521502159_item	2611149	et	4	main
on	doc_491521502159_item	2611150	et	4	main
see	doc_491521502158_item	2611023	et	3	main
valdkond	doc_491521502158_item	2611027	et	3	main
külmal	doc_491521502158_item	2611036	et	3	main
peab	doc_491521502158_item	2611038	et	4	main
külmetamiseks	doc_491521502158_item	2611041	et	4	main
tunnen	doc_491521502158_item	2611044	et	3	main
suvine	doc_491521502158_item	2611046	et	4	main
päike	doc_491521502158_item	2611047	et	3	main
1	doc_491521502158_item	2611055	et	2	main
tellisime	doc_491521502158_item	2611056	et	4	main
maksis	doc_491521502158_item	2611061	et	4	main
tagasi	doc_491521502158_item	2611076	et	3	main
tulevad	doc_491521502158_item	2611077	et	4	main
4	doc_491521502158_item	2611078	et	2	main
kõrvallauast	doc_491521502158_item	2611079	et	4	main
kostis	doc_491521502158_item	2611080	et	4	main
naeru	doc_491521502158_item	2611081	et	4	main
et	doc_491521502158_item	2611082	et	3	main
oleks	doc_491521502158_item	2611083	et	3	main
keegi	doc_491521502158_item	2611084	et	4	main
just	doc_491521502158_item	2611085	et	3	main
anekdooti	doc_491521502158_item	2611086	et	4	main
rääkinud	doc_491521502158_item	2611087	et	4	main
5	doc_491521502158_item	2611088	et	2	main
ta	doc_491521502158_item	2611089	et	4	main
ei	doc_491521502158_item	2611090	et	4	main
tule	doc_491521502158_item	2611091	et	4	main
trenni	doc_491521502158_item	2611092	et	4	main
vaid	doc_491521502158_item	2611093	et	3	main
läheb	doc_491521502158_item	2611094	et	3	main
hoopis	doc_491521502158_item	2611095	et	3	main
teatrisse	doc_491521502158_item	2611096	et	3	main
6	doc_491521502158_item	2611097	et	2	main
lõpetage	doc_491521502158_item	2611098	et	3	main
töö	doc_491521502158_item	2611099	et	4	main
siis	doc_491521502158_item	2611100	et	3	main
lähete	doc_491521502158_item	2611101	et	4	main
sa	doc_491521502158_item	2611123	et	3	main
koputust	doc_491521502158_item	2611134	et	4	main
vormi	doc_491521502159_item	2611147	et	4	main
piret	doc_491521502159_item	2611148	et	4	main
ajalehes	doc_491521502159_item	2611157	et	3	main
ülem-suetuki	doc_491521502159_item	2611162	et	4	main
külasse	doc_491521502159_item	2611164	et	3	main
keele	doc_491521502159_item	2611167	et	4	main
otsitakse	doc_491521502159_item	2611165	et	3	main
eesti	doc_491521502159_item	2611166	et	4	main
õpetajat	doc_491521502159_item	2611168	et	4	main
piret	doc_491521502159_item	2611169	et	4	main
konkurss	doc_491521502159_item	2611171	et	3	main
konkursis	doc_491521502159_item	2611172	et	3	main
ja	doc_491521502159_item	2611173	et	3	main
on	doc_491521502159_item	2611174	et	4	main
võitis	doc_491521502159_item	2611170	et	3	main
nüüd	doc_491521502159_item	2611175	et	4	main
juba	doc_491521502159_item	2611176	et	3	main
üle	doc_491521502159_item	2611177	et	3	main
nädal	doc_491521502159_item	2611178	et	3	main
nädala	doc_491521502159_item	2611179	et	3	main
väikestele	doc_491521502159_item	2611180	et	4	main
eestlastele	doc_491521502159_item	2611181	et	4	main
9	doc_491521502158_item	2611121	et	2	main
test	doc_491521502159_item	2611137	et	3	main
eesti	doc_491521502159_item	2611138	et	4	main
olevad	doc_491521502159_item	2611144	et	4	main
ta	doc_491521502159_item	2611156	et	4	main
need	doc_491521502159_item	2611182	et	3	main
tundis	doc_491521502159_item	2611188	et	3	main
jõudnud	doc_491521502159_item	2611192	et	4	main
et	doc_491521502159_item	2611193	et	3	main
on	doc_491521502159_item	2611194	et	4	main
üsna	doc_491521502159_item	2611197	et	3	main
üllatanud	doc_491521502159_item	2611199	et	4	main
ei	doc_491521502159_item	2611215	et	4	main
algust	doc_491521502159_item	2611231	et	4	main
kohta	doc_491521502159_item	2611233	et	4	main
jõudis	doc_491521502159_item	2611234	et	3	main
polnud	doc_491521502159_item	2611235	et	3	main
kõige	doc_491521502159_item	2611248	et	4	main
ettevõtmine	doc_491521502159_item	2611251	et	3	main
ja	doc_491521502159_item	2611267	et	3	main
aktsent	doc_491521502159_item	2611271	et	3	main
venemaa	doc_491521502159_item	2611281	et	4	main
kool	doc_491521502159_item	2611282	et	4	main
ja	doc_491521502159_item	2611283	et	3	main
ööd	doc_491521502159_item	2611329	et	4	main
juba	doc_491521502159_item	2611330	et	3	main
jahe	doc_491521502159_item	2611331	et	3	main
suure	doc_491521502159_item	2611335	et	3	main
kütama	doc_491521502159_item	2611339	et	4	main
külapood	doc_491521502159_item	2611343	et	3	main
ega	doc_491521502159_item	2611346	et	3	main
suurt	doc_491521502159_item	2611348	et	3	main
vapralt	doc_491521502159_item	2611357	et	4	main
pannes	doc_491521502159_item	2611366	et	4	main
sõnad	doc_491521502159_item	2611367	et	4	main
vormi	doc_491521502159_item	2611369	et	4	main
kasutades	doc_491521502159_item	2611371	et	3	main
naeratus	doc_491521502159_item	2611374	et	4	main
tegema	doc_491521502159_item	2611375	et	3	main
naised	doc_491521502159_item	2611376	et	3	main
kaunim	doc_491521502159_item	2611382	et	4	main
tegeb	doc_491521502159_item	2611384	et	4	main
tooma	doc_491521502159_item	2611402	et	3	main
ülekoormus	doc_491521502159_item	2611421	et	3	main
maandama	doc_491521502159_item	2611425	et	3	main
sportima	doc_491521502159_item	2611426	et	4	main
ja	doc_491521502159_item	2611427	et	3	main
ülekoormus	doc_491521502159_item	2611432	et	3	main
5	doc_491521502159_item	2611440	et	2	main
telefon	doc_491521502159_item	2611441	et	3	main
olema	doc_491521502159_item	2611442	et	4	main
tänapäev	doc_491521502159_item	2611443	et	3	main
maagiline	doc_491521502159_item	2611446	et	4	main
abil	doc_491521502159_item	2611450	et	4	main
telefon	doc_491521502159_item	2611455	et	3	main
et	doc_491521502159_item	2611462	et	3	main
abil	doc_491521502159_item	2611464	et	4	main
segab	doc_491521502159_item	2611494	et	3	main
ja	doc_491521502159_item	2611497	et	3	main
söömine	doc_491521502159_item	2611498	et	4	main
iv	doc_491521502159_item	2611504	et	4	main
pange	doc_491521502159_item	2611505	et	4	main
vormi	doc_491521502159_item	2611510	et	4	main
lugu	doc_491521502159_item	2611515	et	4	main
oma	doc_491521502159_item	2611516	et	4	main
ja	doc_491521502159_item	2611525	et	3	main
usaldavad	doc_491521502159_item	2611526	et	4	main
igaühele	doc_491521502159_item	2611528	et	3	main
3	doc_491521502159_item	2611533	et	2	main
arvasin	doc_491521502159_item	2611535	et	3	main
aga	doc_491521502159_item	2611541	et	3	main
oht	doc_491521502159_item	2611559	et	3	main
difteeria	doc_491521502159_item	2611561	et	4	main
difteeriaga	doc_491521502159_item	2611562	et	3	main
töökoht	doc_491521502159_item	2611566	et	3	main
6	doc_491521502159_item	2611570	et	2	main
valdkond	doc_491521502159_item	2611584	et	3	main
ajal	doc_491521502159_item	2611594	et	4	main
hoiduma	doc_491521502159_item	2611596	et	3	main
külmetamisest	doc_491521502159_item	2611598	et	4	main
v	doc_491521502159_item	2611607	et	4	main
täitke	doc_491521502159_item	2611608	et	3	main
ettevõtlik	doc_491521502159_item	2611151	et	3	main
naine	doc_491521502159_item	2611152	et	3	main
suvel	doc_491521502159_item	2611153	et	3	main
nägema	doc_491521502159_item	2611154	et	3	main
kuulutus	doc_491521502159_item	2611158	et	4	main
et	doc_491521502159_item	2611160	et	3	main
küla	doc_491521502159_item	2611163	et	4	main
emakeelt	doc_491521502159_item	2611183	et	4	main
õpetama	doc_491521502159_item	2611184	et	3	main
õpetab	doc_491521502159_item	2611185	et	3	main
ta	doc_491521502159_item	2611189	et	4	main
jõudma	doc_491521502159_item	2611191	et	3	main
siber	doc_491521502159_item	2611209	et	4	main
selline	doc_491521502159_item	2611211	et	4	main
lind	doc_491521502159_item	2611218	et	3	main
kinnitusel	doc_491521502159_item	2611187	et	4	main
siberisse	doc_491521502159_item	2611190	et	4	main
olin	doc_491521502159_item	2611196	et	3	main
üllatuma	doc_491521502159_item	2611198	et	3	main
kui	doc_491521502159_item	2611200	et	3	main
mulle	doc_491521502159_item	2611201	et	4	main
siberis	doc_491521502159_item	2611210	et	4	main
lenda	doc_491521502159_item	2611217	et	4	main
kui	doc_491521502159_item	2611222	et	3	main
noor	doc_491521502159_item	2611223	et	3	main
tahtmine	doc_491521502159_item	2611225	et	4	main
täis	doc_491521502159_item	2611227	et	4	main
võtma	doc_491521502159_item	2611241	et	3	main
mitte	doc_491521502159_item	2611269	et	3	main
aktsenti	doc_491521502159_item	2611272	et	4	main
vaid	doc_491521502159_item	2611273	et	3	main
nagu	doc_491521502159_item	2611274	et	3	main
mõni	doc_491521502159_item	2611275	et	3	main
mõned	doc_491521502159_item	2611276	et	3	main
murret	doc_491521502159_item	2611277	et	4	main
õpetatakse	doc_491521502159_item	2611286	et	3	main
kuid	doc_491521502159_item	2611328	et	4	main
juba	doc_491521502159_item	2611334	et	3	main
ahju	doc_491521502159_item	2611337	et	4	main
kütmine	doc_491521502159_item	2611338	et	4	main
vaja	doc_491521502159_item	2611341	et	4	main
talveks	doc_491521502159_item	2611353	et	4	main
valmistuma	doc_491521502159_item	2611354	et	3	main
valmistamiseks	doc_491521502159_item	2611355	et	4	main
slõhtuleht	doc_491521502159_item	2611360	et	4	main
iii	doc_491521502159_item	2611361	et	4	main
moodustage	doc_491521502159_item	2611362	et	3	main
naiselikum	doc_491521502159_item	2611377	et	4	main
ja	doc_491521502159_item	2611378	et	3	main
mehed	doc_491521502159_item	2611379	et	3	main
mehelikum	doc_491521502159_item	2611380	et	4	main
kogus	doc_491521502159_item	2611394	et	4	main
stress	doc_491521502159_item	2611395	et	3	main
panema	doc_491521502159_item	2611396	et	3	main
meie	doc_491521502159_item	2611397	et	4	main
tegutsema	doc_491521502159_item	2611398	et	3	main
tohi	doc_491521502159_item	2611430	et	4	main
saama	doc_491521502159_item	2611444	et	4	main
et	doc_491521502159_item	2611448	et	3	main
elama	doc_491521502159_item	2611452	et	3	main
hingama	doc_491521502159_item	2611454	et	3	main
tänapäeval	doc_491521502159_item	2611457	et	3	main
kuid	doc_491521502159_item	2611487	et	4	main
telefonihelin	doc_491521502159_item	2611488	et	3	main
katkestab	doc_491521502159_item	2611489	et	3	main
uni	doc_491521502159_item	2611493	et	3	main
õigesse	doc_491521502159_item	2611509	et	3	main
pean	doc_491521502159_item	2611513	et	4	main
vanemad	doc_491521502159_item	2611517	et	4	main
sest	doc_491521502159_item	2611520	et	4	main
aitavad	doc_491521502159_item	2611522	et	4	main
kohandasin	doc_491521502159_item	2611530	et	3	main
nõuded	doc_491521502159_item	2611532	et	3	main
sa	doc_491521502159_item	2611542	et	3	main
huvi	doc_491521502159_item	2611544	et	4	main
ilusad	doc_491521502159_item	2611546	et	3	main
kiired	doc_491521502159_item	2611549	et	4	main
haigestuda	doc_491521502159_item	2611560	et	3	main
uus	doc_491521502159_item	2611565	et	3	main
kiiresti	doc_491521502159_item	2611569	et	3	main
küsimuses	doc_491521502159_item	2611573	et	4	main
vaid	doc_491521502159_item	2611574	et	3	main
kleepus	doc_491521502159_item	2611589	et	3	main
püksid	doc_491521502159_item	2611590	et	3	main
püksistele	doc_491521502159_item	2611591	et	4	main
9	doc_491521502159_item	2611592	et	2	main
suvist	doc_491521502159_item	2611605	et	4	main
sobivate	doc_491521502159_item	2611610	et	4	main
kolmekäigulise	doc_491521502159_item	2611614	et	4	main
kohal	doc_491521502159_item	2611621	et	4	main
olid	doc_491521502159_item	2611622	et	4	main
õpilased	doc_491521502159_item	2611624	et	3	main
ja	doc_491521502159_item	2611625	et	3	main
need	doc_491521502159_item	2611626	et	3	main
kui	doc_491521502159_item	2611632	et	3	main
tulevad	doc_491521502159_item	2611635	et	4	main
tulema	doc_491521502159_item	2611202	et	4	main
tuleb	doc_491521502159_item	2611203	et	3	main
vastu	doc_491521502159_item	2611204	et	3	main
korralik	doc_491521502159_item	2611205	et	3	main
audiga	doc_491521502159_item	2611206	et	3	main
mulle	doc_491521502159_item	2611207	et	4	main
maaliti	doc_491521502159_item	2611208	et	3	main
pilt	doc_491521502159_item	2611212	et	3	main
seal	doc_491521502159_item	2611214	et	4	main
lendama	doc_491521502159_item	2611216	et	3	main
kasva	doc_491521502159_item	2611220	et	4	main
piret	doc_491521502159_item	2611228	et	4	main
kool	doc_491521502159_item	2611236	et	4	main
küla	doc_491521502159_item	2611240	et	4	main
võttis	doc_491521502159_item	2611242	et	3	main
on	doc_491521502159_item	2611245	et	4	main
siin	doc_491521502159_item	2611246	et	4	main
sügisel	doc_491521502159_item	2611247	et	3	main
mahlakas	doc_491521502159_item	2611268	et	4	main
vene	doc_491521502159_item	2611270	et	4	main
kool	doc_491521502159_item	2611278	et	4	main
ülejäänud	doc_491521502159_item	2611284	et	4	main
talvepuud	doc_491521502159_item	2611321	et	4	main
külapoodis	doc_491521502159_item	2611344	et	4	main
vildid	doc_491521502159_item	2611345	et	4	main
ajalehest	doc_491521502159_item	2611359	et	4	main
sõnadest	doc_491521502159_item	2611364	et	3	main
kaunim	doc_491521502159_item	2611391	et	4	main
3	doc_491521502159_item	2611392	et	2	main
paras	doc_491521502159_item	2611393	et	3	main
võima	doc_491521502159_item	2611401	et	3	main
tagajärg	doc_491521502159_item	2611404	et	3	main
kogus	doc_491521502159_item	2611406	et	4	main
paneb	doc_491521502159_item	2611408	et	3	main
meie	doc_491521502159_item	2611409	et	4	main
tegutsema	doc_491521502159_item	2611410	et	3	main
aga	doc_491521502159_item	2611411	et	3	main
tekkima	doc_491521502159_item	2611422	et	3	main
saama	doc_491521502159_item	2611424	et	4	main
laskma	doc_491521502159_item	2611431	et	3	main
pinge	doc_491521502159_item	2611434	et	4	main
nii	doc_491521502159_item	2611445	et	3	main
aparaat	doc_491521502159_item	2611447	et	3	main
see	doc_491521502159_item	2611449	et	3	main
on	doc_491521502159_item	2611456	et	4	main
aparaat	doc_491521502159_item	2611461	et	3	main
ka	doc_491521502159_item	2611490	et	3	main
varahommikul	doc_491521502159_item	2611492	et	3	main
pahandab	doc_491521502159_item	2611499	et	3	main
sulgudes	doc_491521502159_item	2611506	et	4	main
1	doc_491521502159_item	2611511	et	2	main
rohi	doc_491521502159_item	2611221	et	4	main
ja	doc_491521502159_item	2611224	et	3	main
tahti	doc_491521502159_item	2611226	et	4	main
pärast	doc_491521502159_item	2611229	et	4	main
õppeaasta	doc_491521502159_item	2611230	et	4	main
koht	doc_491521502159_item	2611232	et	3	main
veel	doc_491521502159_item	2611237	et	4	main
kogu	doc_491521502159_item	2611239	et	4	main
kartuleid	doc_491521502159_item	2611243	et	3	main
kartulivõtt	doc_491521502159_item	2611244	et	3	main
tähtis	doc_491521502159_item	2611249	et	4	main
tähtsam	doc_491521502159_item	2611250	et	4	main
mõnus	doc_491521502159_item	2611266	et	4	main
siiski	doc_491521502159_item	2611280	et	4	main
aine	doc_491521502159_item	2611285	et	4	main
külas	doc_491521502159_item	2611289	et	3	main
elab	doc_491521502159_item	2611290	et	3	main
veidi	doc_491521502159_item	2611291	et	3	main
üle	doc_491521502159_item	2611292	et	3	main
keeles	doc_491521502159_item	2611288	et	4	main
kolmsada	doc_491521502159_item	2611293	et	4	main
inimene	doc_491521502159_item	2611294	et	3	main
emakeelt	doc_491521502159_item	2611295	et	4	main
saab	doc_491521502159_item	2611296	et	3	main
kõik	doc_491521502159_item	2611297	et	4	main
rääkida	doc_491521502159_item	2611298	et	3	main
pireti	doc_491521502159_item	2611299	et	4	main
sõnul	doc_491521502159_item	2611300	et	3	main
õpivad	doc_491521502159_item	2611301	et	3	main
lapsed	doc_491521502159_item	2611302	et	3	main
poolpõlenud	doc_491521502159_item	2611303	et	4	main
raamatud	doc_491521502159_item	2611304	et	4	main
varsti	doc_491521502159_item	2611305	et	3	main
saatma	doc_491521502159_item	2611306	et	3	main
saavad	doc_491521502159_item	2611307	et	4	main
eestist	doc_491521502159_item	2611308	et	3	main
uued	doc_491521502159_item	2611309	et	3	main
õpikud	doc_491521502159_item	2611310	et	3	main
siberi	doc_491521502159_item	2611311	et	4	main
talve	doc_491521502159_item	2611312	et	4	main
piret	doc_491521502159_item	2611313	et	4	main
ei	doc_491521502159_item	2611314	et	4	main
kartma	doc_491521502159_item	2611315	et	3	main
karda	doc_491521502159_item	2611316	et	4	main
mulle	doc_491521502159_item	2611317	et	4	main
juba	doc_491521502159_item	2611318	et	3	main
tooma	doc_491521502159_item	2611319	et	3	main
toonud	doc_491521502159_item	2611320	et	4	main
praegu	doc_491521502159_item	2611322	et	3	main
päevad	doc_491521502159_item	2611324	et	3	main
veel	doc_491521502159_item	2611325	et	4	main
soe	doc_491521502159_item	2611326	et	4	main
sojad	doc_491521502159_item	2611327	et	3	main
harjutan	doc_491521502159_item	2611333	et	3	main
kui	doc_491521502159_item	2611340	et	3	main
ostan	doc_491521502159_item	2611342	et	3	main
muud	doc_491521502159_item	2611349	et	4	main
ei	doc_491521502159_item	2611350	et	4	main
müüdagi	doc_491521502159_item	2611351	et	3	main
naerab	doc_491521502159_item	2611352	et	3	main
lühendatud	doc_491521502159_item	2611358	et	4	main
etteantud	doc_491521502159_item	2611363	et	4	main
õigesse	doc_491521502159_item	2611368	et	3	main
ja	doc_491521502159_item	2611370	et	3	main
igaüks	doc_491521502159_item	2611381	et	3	main
naised	doc_491521502159_item	2611385	et	3	main
aga	doc_491521502159_item	2611399	et	3	main
paras	doc_491521502159_item	2611405	et	3	main
stress	doc_491521502159_item	2611407	et	3	main
lisakoormus	doc_491521502159_item	2611412	et	3	main
võib	doc_491521502159_item	2611413	et	3	main
tooma	doc_491521502159_item	2611414	et	3	main
soovimatu	doc_491521502159_item	2611415	et	4	main
tagajärg	doc_491521502159_item	2611416	et	3	main
4	doc_491521502159_item	2611417	et	2	main
ei	doc_491521502159_item	2611418	et	4	main
tohtima	doc_491521502159_item	2611419	et	3	main
laskma	doc_491521502159_item	2611420	et	3	main
on	doc_491521502159_item	2611323	et	4	main
jad	doc_491521502159_item	2611332	et	4	main
vene	doc_491521502159_item	2611336	et	4	main
seal	doc_491521502159_item	2611347	et	4	main
piret	doc_491521502159_item	2611356	et	4	main
laused	doc_491521502159_item	2611365	et	3	main
kirjavahemärke	doc_491521502159_item	2611372	et	4	main
2	doc_491521502159_item	2611373	et	2	main
naeratus	doc_491521502159_item	2611383	et	4	main
naiselikum	doc_491521502159_item	2611386	et	4	main
aga	doc_491521502159_item	2611387	et	3	main
mehed	doc_491521502159_item	2611388	et	3	main
mehelikum	doc_491521502159_item	2611389	et	4	main
igaüks	doc_491521502159_item	2611390	et	3	main
lisakoormus	doc_491521502159_item	2611400	et	3	main
soovimatu	doc_491521502159_item	2611403	et	4	main
pinge	doc_491521502159_item	2611423	et	4	main
puhkama	doc_491521502159_item	2611428	et	3	main
ei	doc_491521502159_item	2611429	et	4	main
ja	doc_491521502159_item	2611453	et	3	main
maagiline	doc_491521502159_item	2611460	et	4	main
see	doc_491521502159_item	2611463	et	3	main
lausa	doc_491521502159_item	2611465	et	4	main
elab	doc_491521502159_item	2611466	et	3	main
ja	doc_491521502159_item	2611467	et	3	main
lõunasööki	doc_491521502159_item	2611495	et	4	main
valmistamine	doc_491521502159_item	2611496	et	4	main
huvitav	doc_491521502159_item	2611500	et	4	main
telesaade	doc_491521502159_item	2611501	et	4	main
olevad	doc_491521502159_item	2611507	et	4	main
ma	doc_491521502159_item	2611512	et	3	main
väga	doc_491521502159_item	2611514	et	3	main
vanematele	doc_491521502159_item	2611519	et	4	main
kõik	doc_491521502159_item	2611523	et	4	main
2	doc_491521502159_item	2611529	et	2	main
artikli	doc_491521502159_item	2611531	et	3	main
ma	doc_491521502159_item	2611534	et	3	main
et	doc_491521502159_item	2611536	et	3	main
sa	doc_491521502159_item	2611537	et	3	main
sport	doc_491521502159_item	2611539	et	3	main
ja	doc_491521502159_item	2611548	et	3	main
tüdinesin	doc_491521502159_item	2611564	et	3	main
töökohte	doc_491521502159_item	2611568	et	3	main
piirdusime	doc_491521502159_item	2611571	et	3	main
väikesed	doc_491521502159_item	2611575	et	4	main
muudatused	doc_491521502159_item	2611576	et	3	main
väikese	doc_491521502159_item	2611577	et	4	main
muudatusi	doc_491521502159_item	2611578	et	3	main
7	doc_491521502159_item	2611579	et	2	main
see	doc_491521502159_item	2611580	et	3	main
külmal	doc_491521502159_item	2611593	et	3	main
külmetamine	doc_491521502159_item	2611597	et	4	main
10	doc_491521502159_item	2611599	et	2	main
ma	doc_491521502159_item	2611600	et	3	main
tunnen	doc_491521502159_item	2611601	et	3	main
lüngad	doc_491521502159_item	2611609	et	3	main
tekkima	doc_491521502159_item	2611433	et	3	main
saama	doc_491521502159_item	2611435	et	4	main
maandama	doc_491521502159_item	2611436	et	3	main
sportima	doc_491521502159_item	2611437	et	4	main
ja	doc_491521502159_item	2611438	et	3	main
puhkama	doc_491521502159_item	2611439	et	3	main
lausa	doc_491521502159_item	2611451	et	4	main
saama	doc_491521502159_item	2611458	et	4	main
nii	doc_491521502159_item	2611459	et	3	main
hingib	doc_491521502159_item	2611468	et	4	main
6	doc_491521502159_item	2611469	et	2	main
kuid	doc_491521502159_item	2611470	et	4	main
telefonihelin	doc_491521502159_item	2611471	et	3	main
katkestama	doc_491521502159_item	2611472	et	3	main
ka	doc_491521502159_item	2611473	et	3	main
pühapäev	doc_491521502159_item	2611474	et	3	main
varahommik	doc_491521502159_item	2611475	et	3	main
uni	doc_491521502159_item	2611476	et	3	main
segama	doc_491521502159_item	2611477	et	3	main
lõunasöök	doc_491521502159_item	2611478	et	3	main
valmistamine	doc_491521502159_item	2611479	et	4	main
söömine	doc_491521502159_item	2611481	et	4	main
pahandab	doc_491521502159_item	2611482	et	3	main
huvitav	doc_491521502159_item	2611483	et	4	main
ja	doc_491521502159_item	2611480	et	3	main
telesaade	doc_491521502159_item	2611484	et	4	main
vaatamine	doc_491521502159_item	2611485	et	4	main
aeg	doc_491521502159_item	2611486	et	3	main
pühapäeval	doc_491521502159_item	2611491	et	3	main
vaatamine	doc_491521502159_item	2611502	et	4	main
aeg	doc_491521502159_item	2611503	et	3	main
sõnad	doc_491521502159_item	2611508	et	4	main
oma	doc_491521502159_item	2611518	et	4	main
nad	doc_491521502159_item	2611521	et	3	main
sportiga	doc_491521502159_item	2611540	et	4	main
tunned	doc_491521502159_item	2611543	et	3	main
naised	doc_491521502159_item	2611547	et	3	main
ilusad	doc_491521502159_item	2611551	et	3	main
küsimus	doc_491521502159_item	2611581	et	4	main
kuulub	doc_491521502159_item	2611582	et	3	main
teine	doc_491521502159_item	2611583	et	3	main
teisest	doc_491521502159_item	2611585	et	4	main
valdkonnast	doc_491521502159_item	2611586	et	4	main
8	doc_491521502159_item	2611587	et	2	main
närimiskumm	doc_491521502159_item	2611588	et	3	main
peab	doc_491521502159_item	2611595	et	4	main
päikest	doc_491521502159_item	2611606	et	4	main
sidenditega	doc_491521502159_item	2611611	et	3	main
palju	doc_491521502159_item	2611619	et	4	main
õpetajad	doc_491521502159_item	2611627	et	4	main
kostis	doc_491521502159_item	2611638	et	4	main
rääkinud	doc_491521502159_item	2611645	et	4	main
5	doc_491521502159_item	2611646	et	2	main
läheb	doc_491521502159_item	2611652	et	3	main
lõpetage	doc_491521502159_item	2611656	et	3	main
pärast	doc_491521502159_item	2611658	et	4	main
jalutama	doc_491521502159_item	2611660	et	3	main
8	doc_491521502159_item	2611670	et	2	main
küll	doc_491521502159_item	2611673	et	4	main
kas	doc_491521502159_item	2611680	et	3	main
maale	doc_491521502159_item	2611683	et	4	main
avasin	doc_491521502159_item	2611688	et	3	main
kuulsin	doc_491521502159_item	2611691	et	3	main
eesti	doc_491521502160_item	2611696	et	4	main
sõnad	doc_491521502160_item	2611703	et	4	main
õigesse	doc_491521502160_item	2611704	et	3	main
suvel	doc_491521502160_item	2611711	et	3	main
ja	doc_491521502160_item	2611731	et	3	main
nädal	doc_491521502160_item	2611736	et	3	main
väikestele	doc_491521502160_item	2611738	et	4	main
need	doc_491521502160_item	2611740	et	3	main
nende	doc_491521502160_item	2611741	et	4	main
tundis	doc_491521502160_item	2611747	et	3	main
ta	doc_491521502160_item	2611748	et	4	main
on	doc_491521502160_item	2611753	et	4	main
vastu	doc_491521502160_item	2611763	et	3	main
korraliku	doc_491521502160_item	2611765	et	3	main
seal	doc_491521502160_item	2611774	et	4	main
ei	doc_491521502160_item	2611775	et	4	main
ettevõtmine	doc_491521502160_item	2611812	et	3	main
käib	doc_491521502160_item	2611819	et	3	main
täie	doc_491521502160_item	2611820	et	3	main
eestlased	doc_491521502160_item	2611824	et	3	main
vene	doc_491521502160_item	2611835	et	4	main
vaid	doc_491521502160_item	2611838	et	3	main
kool	doc_491521502160_item	2611847	et	4	main
ülejäänud	doc_491521502160_item	2611849	et	4	main
aine	doc_491521502160_item	2611850	et	4	main
ained	doc_491521502160_item	2611851	et	3	main
õpetatakse	doc_491521502160_item	2611852	et	3	main
vene	doc_491521502160_item	2611853	et	4	main
üle	doc_491521502160_item	2611858	et	3	main
inimest	doc_491521502160_item	2611862	et	3	main
saab	doc_491521502160_item	2611864	et	3	main
järgi	doc_491521502160_item	2611875	et	4	main
talve	doc_491521502160_item	2611883	et	4	main
piret	doc_491521502160_item	2611884	et	4	main
soe	doc_491521502160_item	2611897	et	4	main
suure	doc_491521502160_item	2611906	et	3	main
naerab	doc_491521502160_item	2611923	et	3	main
vormi	doc_491521502160_item	2611940	et	4	main
ja	doc_491521502160_item	2611941	et	3	main
naeratus	doc_491521502160_item	2611954	et	4	main
teeb	doc_491521502160_item	2611955	et	3	main
naisi	doc_491521502160_item	2611956	et	3	main
naiselikumaks	doc_491521502160_item	2611957	et	4	main
kaunimaks	doc_491521502160_item	2611962	et	4	main
kogus	doc_491521502160_item	2611965	et	4	main
lisakoormus	doc_491521502160_item	2611971	et	3	main
kõigile	doc_491521502159_item	2611524	et	4	main
igaüks	doc_491521502159_item	2611527	et	3	main
huvitud	doc_491521502159_item	2611538	et	4	main
ainult	doc_491521502159_item	2611545	et	4	main
autod	doc_491521502159_item	2611550	et	3	main
naiseks	doc_491521502159_item	2611552	et	3	main
ja	doc_491521502159_item	2611553	et	3	main
kiired	doc_491521502159_item	2611554	et	4	main
autoks	doc_491521502159_item	2611555	et	4	main
4	doc_491521502159_item	2611556	et	2	main
praegu	doc_491521502159_item	2611557	et	3	main
on	doc_491521502159_item	2611558	et	4	main
5	doc_491521502159_item	2611563	et	2	main
uude	doc_491521502159_item	2611567	et	3	main
selles	doc_491521502159_item	2611572	et	4	main
rõõmu	doc_491521502159_item	2611602	et	4	main
suvine	doc_491521502159_item	2611603	et	4	main
päike	doc_491521502159_item	2611604	et	3	main
1	doc_491521502159_item	2611612	et	2	main
tellisime	doc_491521502159_item	2611613	et	4	main
lõuna	doc_491521502159_item	2611615	et	4	main
sellepärast	doc_491521502159_item	2611616	et	3	main
see	doc_491521502159_item	2611617	et	3	main
maksis	doc_491521502159_item	2611618	et	4	main
naeru	doc_491521502159_item	2611639	et	4	main
ta	doc_491521502159_item	2611647	et	4	main
hoopis	doc_491521502159_item	2611653	et	3	main
tulemust	doc_491521502159_item	2611676	et	4	main
või	doc_491521502159_item	2611684	et	4	main
jääd	doc_491521502159_item	2611685	et	4	main
et	doc_491521502159_item	2611690	et	3	main
keele	doc_491521502160_item	2611694	et	4	main
sulgudes	doc_491521502160_item	2611701	et	4	main
toomet	doc_491521502160_item	2611707	et	4	main
ajalehes	doc_491521502160_item	2611715	et	3	main
kuulutuse	doc_491521502160_item	2611717	et	4	main
et	doc_491521502160_item	2611718	et	3	main
küla	doc_491521502160_item	2611721	et	4	main
eesti	doc_491521502160_item	2611724	et	4	main
nüüd	doc_491521502160_item	2611733	et	4	main
nädala	doc_491521502160_item	2611737	et	3	main
emakeelt	doc_491521502160_item	2611742	et	4	main
õpetama	doc_491521502160_item	2611743	et	3	main
siberisse	doc_491521502160_item	2611749	et	4	main
jõudma	doc_491521502160_item	2611750	et	3	main
mulle	doc_491521502160_item	2611760	et	4	main
tänaseks	doc_491521502160_item	2611813	et	4	main
õppimine	doc_491521502160_item	2611818	et	4	main
2	doc_491521502159_item	2611620	et	2	main
3	doc_491521502159_item	2611628	et	2	main
paluti	doc_491521502159_item	2611630	et	3	main
vanemad	doc_491521502159_item	2611633	et	4	main
ei	doc_491521502159_item	2611648	et	4	main
teatrisse	doc_491521502159_item	2611654	et	3	main
töö	doc_491521502159_item	2611657	et	4	main
lähete	doc_491521502159_item	2611659	et	4	main
7	doc_491521502159_item	2611661	et	2	main
selles	doc_491521502159_item	2611662	et	4	main
baaris	doc_491521502159_item	2611663	et	3	main
nad	doc_491521502159_item	2611671	et	3	main
pingsalt	doc_491521502159_item	2611674	et	4	main
sest	doc_491521502159_item	2611675	et	4	main
9	doc_491521502159_item	2611679	et	2	main
10	doc_491521502159_item	2611687	et	2	main
eesti	doc_491521502160_item	2611693	et	4	main
test	doc_491521502160_item	2611695	et	3	main
olevad	doc_491521502160_item	2611702	et	4	main
on	doc_491521502160_item	2611708	et	4	main
ettevõtlik	doc_491521502160_item	2611709	et	3	main
naine	doc_491521502160_item	2611710	et	3	main
ta	doc_491521502160_item	2611714	et	4	main
külasse	doc_491521502160_item	2611722	et	3	main
otsitakse	doc_491521502160_item	2611723	et	3	main
keele	doc_491521502160_item	2611725	et	4	main
õpetajat	doc_491521502160_item	2611726	et	4	main
juba	doc_491521502160_item	2611734	et	3	main
õpetanud	doc_491521502160_item	2611744	et	4	main
pireti	doc_491521502160_item	2611745	et	4	main
et	doc_491521502160_item	2611752	et	3	main
olin	doc_491521502160_item	2611755	et	3	main
üsna	doc_491521502160_item	2611756	et	3	main
üllatuma	doc_491521502160_item	2611757	et	3	main
üllatunud	doc_491521502160_item	2611758	et	4	main
kui	doc_491521502160_item	2611759	et	3	main
audiga	doc_491521502160_item	2611766	et	3	main
siber	doc_491521502160_item	2611769	et	4	main
siberist	doc_491521502160_item	2611770	et	4	main
selline	doc_491521502160_item	2611771	et	4	main
pilt	doc_491521502160_item	2611772	et	3	main
et	doc_491521502160_item	2611773	et	3	main
lenda	doc_491521502160_item	2611777	et	4	main
salv	doc_491521502160_item	2611816	et	3	main
siinsed	doc_491521502160_item	2611823	et	3	main
mõnus	doc_491521502160_item	2611828	et	4	main
ja	doc_491521502160_item	2611829	et	3	main
aktsent	doc_491521502160_item	2611836	et	3	main
nagu	doc_491521502160_item	2611839	et	3	main
on	doc_491521502160_item	2611844	et	4	main
siiski	doc_491521502160_item	2611845	et	4	main
veidi	doc_491521502160_item	2611857	et	3	main
karda	doc_491521502160_item	2611887	et	4	main
veel	doc_491521502160_item	2611896	et	4	main
harjutan	doc_491521502160_item	2611904	et	3	main
ahju	doc_491521502160_item	2611908	et	4	main
külapood	doc_491521502160_item	2611914	et	3	main
külapoest	doc_491521502160_item	2611915	et	4	main
ei	doc_491521502160_item	2611921	et	4	main
valmistuv	doc_491521502160_item	2611926	et	4	main
piret	doc_491521502160_item	2611927	et	4	main
pannes	doc_491521502160_item	2611937	et	4	main
sõnad	doc_491521502160_item	2611938	et	4	main
õigesse	doc_491521502160_item	2611939	et	3	main
2	doc_491521502160_item	2611944	et	2	main
naised	doc_491521502160_item	2611947	et	3	main
mehed	doc_491521502160_item	2611950	et	3	main
ja	doc_491521502160_item	2611958	et	3	main
stress	doc_491521502160_item	2611966	et	3	main
meie	doc_491521502160_item	2611968	et	4	main
aga	doc_491521502160_item	2611970	et	3	main
tooma	doc_491521502160_item	2611973	et	3	main
tagajärg	doc_491521502160_item	2611975	et	3	main
paras	doc_491521502160_item	2611976	et	3	main
kogus	doc_491521502160_item	2611977	et	4	main
aga	doc_491521502160_item	2611982	et	3	main
tuua	doc_491521502160_item	2611985	et	3	main
kõik	doc_491521502159_item	2611623	et	4	main
lapsel	doc_491521502159_item	2611629	et	4	main
oodata	doc_491521502159_item	2611631	et	4	main
tagasi	doc_491521502159_item	2611634	et	3	main
4	doc_491521502159_item	2611636	et	2	main
seal	doc_491521502159_item	2611640	et	4	main
oleks	doc_491521502159_item	2611641	et	3	main
kõrvallauast	doc_491521502159_item	2611637	et	4	main
just	doc_491521502159_item	2611643	et	3	main
anekdooti	doc_491521502159_item	2611644	et	4	main
trenni	doc_491521502159_item	2611650	et	4	main
aga	doc_491521502159_item	2611651	et	3	main
suitsetada	doc_491521502159_item	2611666	et	3	main
ning	doc_491521502159_item	2611667	et	3	main
alkoholi	doc_491521502159_item	2611668	et	4	main
tarbida	doc_491521502159_item	2611669	et	3	main
ei	doc_491521502159_item	2611677	et	4	main
olnud	doc_491521502159_item	2611678	et	4	main
sa	doc_491521502159_item	2611681	et	3	main
sõidad	doc_491521502159_item	2611682	et	3	main
linna	doc_491521502159_item	2611686	et	4	main
koputust	doc_491521502159_item	2611692	et	4	main
keele	doc_491521502160_item	2611697	et	4	main
test	doc_491521502160_item	2611698	et	3	main
i	doc_491521502160_item	2611699	et	4	main
vormi	doc_491521502160_item	2611705	et	4	main
nägema	doc_491521502160_item	2611712	et	3	main
kuulutus	doc_491521502160_item	2611716	et	4	main
siberisse	doc_491521502160_item	2611719	et	4	main
ülem-suetuki	doc_491521502160_item	2611720	et	4	main
keegi	doc_491521502159_item	2611642	et	4	main
tule	doc_491521502159_item	2611649	et	4	main
6	doc_491521502159_item	2611655	et	2	main
ei	doc_491521502159_item	2611664	et	4	main
tohi	doc_491521502159_item	2611665	et	4	main
töötasid	doc_491521502159_item	2611672	et	4	main
ukse	doc_491521502159_item	2611689	et	3	main
pange	doc_491521502160_item	2611700	et	4	main
piret	doc_491521502160_item	2611706	et	4	main
nägi	doc_491521502160_item	2611713	et	3	main
piret	doc_491521502160_item	2611727	et	4	main
võitis	doc_491521502160_item	2611728	et	3	main
konkurss	doc_491521502160_item	2611729	et	3	main
on	doc_491521502160_item	2611732	et	4	main
eestlastele	doc_491521502160_item	2611739	et	4	main
kinnitusel	doc_491521502160_item	2611746	et	4	main
tuldi	doc_491521502160_item	2611762	et	3	main
korralik	doc_491521502160_item	2611764	et	3	main
mulle	doc_491521502160_item	2611767	et	4	main
lind	doc_491521502160_item	2611778	et	3	main
on	doc_491521502160_item	2611814	et	4	main
ja	doc_491521502160_item	2611817	et	3	main
hooga	doc_491521502160_item	2611822	et	3	main
aktsendiga	doc_491521502160_item	2611837	et	3	main
mõnd	doc_491521502160_item	2611841	et	3	main
venemaa	doc_491521502160_item	2611846	et	4	main
keeles	doc_491521502160_item	2611854	et	4	main
kolmsada	doc_491521502160_item	2611859	et	4	main
inimene	doc_491521502160_item	2611861	et	3	main
siberi	doc_491521502160_item	2611882	et	4	main
soojad	doc_491521502160_item	2611898	et	3	main
kuid	doc_491521502160_item	2611899	et	4	main
juba	doc_491521502160_item	2611905	et	3	main
moodustage	doc_491521502160_item	2611933	et	3	main
etteantud	doc_491521502160_item	2611934	et	4	main
sõnadest	doc_491521502160_item	2611935	et	3	main
laused	doc_491521502160_item	2611936	et	3	main
kirjavahemärke	doc_491521502160_item	2611943	et	4	main
naeratus	doc_491521502160_item	2611945	et	4	main
naiselikum	doc_491521502160_item	2611948	et	4	main
mehelikum	doc_491521502160_item	2611951	et	4	main
igaüks	doc_491521502160_item	2611952	et	3	main
kaunim	doc_491521502160_item	2611953	et	4	main
igaüht	doc_491521502160_item	2611961	et	3	main
paneb	doc_491521502160_item	2611979	et	3	main
meid	doc_491521502160_item	2611980	et	4	main
abil	doc_491521502160_item	2612024	et	4	main
ja	doc_491521502160_item	2612027	et	3	main
saanud	doc_491521502160_item	2612032	et	4	main
et	doc_491521502160_item	2612036	et	3	main
selle	doc_491521502160_item	2612037	et	4	main
pühapäev	doc_491521502160_item	2612048	et	3	main
segama	doc_491521502160_item	2612051	et	3	main
huvitav	doc_491521502160_item	2612057	et	4	main
söömist	doc_491521502160_item	2612072	et	4	main
pahandab	doc_491521502160_item	2612073	et	3	main
ajal	doc_491521502160_item	2612077	et	4	main
pange	doc_491521502160_item	2612079	et	4	main
sulgudes	doc_491521502160_item	2612080	et	4	main
nad	doc_491521502160_item	2612095	et	3	main
kõik	doc_491521502160_item	2612097	et	4	main
kõiki	doc_491521502160_item	2612098	et	4	main
ja	doc_491521502160_item	2612099	et	3	main
4	doc_491521502160_item	2612132	et	2	main
praegu	doc_491521502160_item	2612133	et	3	main
difteeria	doc_491521502160_item	2612137	et	4	main
töökohast	doc_491521502160_item	2612144	et	4	main
6	doc_491521502160_item	2612146	et	2	main
selles	doc_491521502160_item	2612148	et	4	main
küsimuses	doc_491521502160_item	2612149	et	4	main
vaid	doc_491521502160_item	2612150	et	3	main
teisse	doc_491521502160_item	2612161	et	4	main
pükstele	doc_491521502160_item	2612169	et	3	main
ma	doc_491521502160_item	2612178	et	3	main
just	doc_491521502160_item	2612223	et	3	main
ja	doc_491521502160_item	2612239	et	3	main
7	doc_491521502160_item	2612244	et	2	main
pingsalt	doc_491521502160_item	2612257	et	4	main
kuigi	doc_491521502160_item	2612258	et	3	main
olnud	doc_491521502160_item	2612261	et	4	main
sa	doc_491521502160_item	2612264	et	3	main
maale	doc_491521502160_item	2612266	et	4	main
konkursi	doc_491521502160_item	2611730	et	3	main
üle	doc_491521502160_item	2611735	et	3	main
jõudes	doc_491521502160_item	2611751	et	3	main
oodatud	doc_491521502160_item	2611754	et	4	main
tulema	doc_491521502160_item	2611761	et	4	main
maaliti	doc_491521502160_item	2611768	et	3	main
lendama	doc_491521502160_item	2611776	et	3	main
ega	doc_491521502160_item	2611779	et	3	main
kasva	doc_491521502160_item	2611780	et	4	main
rohi	doc_491521502160_item	2611781	et	4	main
kui	doc_491521502160_item	2611782	et	3	main
noor	doc_491521502160_item	2611783	et	3	main
ja	doc_491521502160_item	2611784	et	3	main
tahtmine	doc_491521502160_item	2611785	et	4	main
tahtmist	doc_491521502160_item	2611786	et	4	main
täis	doc_491521502160_item	2611787	et	4	main
piret	doc_491521502160_item	2611788	et	4	main
pärast	doc_491521502160_item	2611789	et	4	main
õppeaasta	doc_491521502160_item	2611790	et	4	main
algust	doc_491521502160_item	2611791	et	4	main
koht	doc_491521502160_item	2611792	et	3	main
kohale	doc_491521502160_item	2611793	et	4	main
jõudis	doc_491521502160_item	2611794	et	3	main
polnud	doc_491521502160_item	2611795	et	3	main
kool	doc_491521502160_item	2611796	et	4	main
veel	doc_491521502160_item	2611797	et	4	main
algama	doc_491521502160_item	2611798	et	3	main
alanud	doc_491521502160_item	2611799	et	4	main
kogu	doc_491521502160_item	2611800	et	4	main
küla	doc_491521502160_item	2611801	et	4	main
võtma	doc_491521502160_item	2611802	et	3	main
võttis	doc_491521502160_item	2611803	et	3	main
kartuleid	doc_491521502160_item	2611804	et	3	main
kartulivõtt	doc_491521502160_item	2611805	et	3	main
on	doc_491521502160_item	2611806	et	4	main
siin	doc_491521502160_item	2611807	et	4	main
sügisel	doc_491521502160_item	2611808	et	3	main
kõige	doc_491521502160_item	2611809	et	4	main
tähtis	doc_491521502160_item	2611810	et	4	main
tähtsam	doc_491521502160_item	2611811	et	4	main
kartul	doc_491521502160_item	2611815	et	3	main
hoog	doc_491521502160_item	2611821	et	3	main
kuidagi	doc_491521502160_item	2611826	et	3	main
mõnusalt	doc_491521502160_item	2611831	et	4	main
mõni	doc_491521502160_item	2611840	et	3	main
kool	doc_491521502160_item	2611843	et	4	main
elab	doc_491521502160_item	2611856	et	3	main
ei	doc_491521502160_item	2611885	et	4	main
kartma	doc_491521502160_item	2611886	et	3	main
on	doc_491521502160_item	2611894	et	4	main
päevad	doc_491521502160_item	2611895	et	3	main
jahedad	doc_491521502160_item	2611903	et	3	main
vene	doc_491521502160_item	2611907	et	4	main
kütmine	doc_491521502160_item	2611909	et	4	main
kütmist	doc_491521502160_item	2611910	et	4	main
kui	doc_491521502160_item	2611911	et	3	main
müüdagi	doc_491521502160_item	2611922	et	3	main
valmistuma	doc_491521502160_item	2611925	et	3	main
slõhtuleht	doc_491521502160_item	2611931	et	4	main
iii	doc_491521502160_item	2611932	et	4	main
kasutades	doc_491521502160_item	2611942	et	3	main
tegema	doc_491521502160_item	2611946	et	3	main
mehelikumaks	doc_491521502160_item	2611960	et	4	main
paras	doc_491521502160_item	2611964	et	3	main
panema	doc_491521502160_item	2611967	et	3	main
tegutsema	doc_491521502160_item	2611969	et	3	main
tegutsema	doc_491521502160_item	2611981	et	3	main
see	doc_491521502160_item	2612023	et	3	main
lausa	doc_491521502160_item	2612039	et	4	main
elatakse	doc_491521502160_item	2612040	et	3	main
ja	doc_491521502160_item	2612041	et	3	main
hingatakse	doc_491521502160_item	2612042	et	3	main
telesaade	doc_491521502160_item	2612058	et	4	main
aeg	doc_491521502160_item	2612060	et	3	main
vaatamise	doc_491521502160_item	2612076	et	4	main
iv	doc_491521502160_item	2612078	et	4	main
sõnad	doc_491521502160_item	2612082	et	4	main
vanemad	doc_491521502160_item	2612091	et	4	main
sest	doc_491521502160_item	2612094	et	4	main
naised	doc_491521502160_item	2612122	et	3	main
ilusate	doc_491521502160_item	2612126	et	3	main
kiirte	doc_491521502160_item	2612129	et	3	main
on	doc_491521502160_item	2612134	et	4	main
difteeriasse	doc_491521502160_item	2612138	et	3	main
uus	doc_491521502160_item	2612141	et	3	main
kiiresti	doc_491521502160_item	2612145	et	3	main
7	doc_491521502160_item	2612155	et	2	main
see	doc_491521502160_item	2612156	et	3	main
küsimus	doc_491521502160_item	2612157	et	4	main
8	doc_491521502160_item	2612163	et	2	main
püksid	doc_491521502160_item	2612166	et	3	main
külge	doc_491521502160_item	2612168	et	4	main
tunnen	doc_491521502160_item	2612179	et	3	main
v	doc_491521502160_item	2612185	et	4	main
oleks	doc_491521502160_item	2612221	et	3	main
tule	doc_491521502160_item	2612229	et	4	main
trenni	doc_491521502160_item	2612230	et	4	main
teatrisse	doc_491521502160_item	2612234	et	3	main
lõpetage	doc_491521502160_item	2612236	et	3	main
jalutama	doc_491521502160_item	2612243	et	3	main
baaris	doc_491521502160_item	2612246	et	3	main
tohi	doc_491521502160_item	2612248	et	4	main
alkoholi	doc_491521502160_item	2612251	et	4	main
tarbida	doc_491521502160_item	2612252	et	3	main
9	doc_491521502160_item	2612262	et	2	main
sõidad	doc_491521502160_item	2612265	et	3	main
või	doc_491521502160_item	2612267	et	4	main
eesti	doc_491521502161_item	2612276	et	4	main
keele	doc_491521502161_item	2612280	et	4	main
piret	doc_491521502161_item	2612289	et	4	main
suvel	doc_491521502161_item	2612294	et	3	main
nägi	doc_491521502161_item	2612296	et	3	main
ülem-suetuki	doc_491521502161_item	2612303	et	4	main
nüüd	doc_491521502161_item	2612316	et	4	main
juba	doc_491521502161_item	2612317	et	3	main
üle	doc_491521502161_item	2612318	et	3	main
eestlastele	doc_491521502161_item	2612322	et	4	main
need	doc_491521502161_item	2612323	et	3	main
nende	doc_491521502161_item	2612324	et	4	main
siberisse	doc_491521502161_item	2612332	et	4	main
jõudma	doc_491521502161_item	2612333	et	3	main
et	doc_491521502161_item	2612334	et	3	main
räägivad	doc_491521502160_item	2611825	et	3	main
teistmoodi	doc_491521502160_item	2611827	et	3	main
mahlakas	doc_491521502160_item	2611830	et	4	main
ja	doc_491521502160_item	2611832	et	3	main
mahlakalt	doc_491521502160_item	2611833	et	4	main
mitte	doc_491521502160_item	2611834	et	3	main
murret	doc_491521502160_item	2611842	et	4	main
ja	doc_491521502160_item	2611848	et	3	main
külas	doc_491521502160_item	2611855	et	3	main
kolmesaja	doc_491521502160_item	2611860	et	4	main
emakeelt	doc_491521502160_item	2611863	et	4	main
kõik	doc_491521502160_item	2611865	et	4	main
kõigidega	doc_491521502160_item	2611866	et	4	main
rääkida	doc_491521502160_item	2611867	et	3	main
pireti	doc_491521502160_item	2611868	et	4	main
sõnul	doc_491521502160_item	2611869	et	3	main
õpivad	doc_491521502160_item	2611870	et	3	main
lapsed	doc_491521502160_item	2611871	et	3	main
poolpõlenud	doc_491521502160_item	2611872	et	4	main
raamatud	doc_491521502160_item	2611873	et	4	main
raamatute	doc_491521502160_item	2611874	et	3	main
varsti	doc_491521502160_item	2611876	et	3	main
saatma	doc_491521502160_item	2611877	et	3	main
saadetakse	doc_491521502160_item	2611878	et	3	main
eestist	doc_491521502160_item	2611879	et	3	main
uued	doc_491521502160_item	2611880	et	3	main
õpikud	doc_491521502160_item	2611881	et	3	main
mulle	doc_491521502160_item	2611888	et	4	main
juba	doc_491521502160_item	2611889	et	3	main
tooma	doc_491521502160_item	2611890	et	3	main
toodi	doc_491521502160_item	2611891	et	4	main
talvepuud	doc_491521502160_item	2611892	et	4	main
praegu	doc_491521502160_item	2611893	et	3	main
ööd	doc_491521502160_item	2611900	et	4	main
juba	doc_491521502160_item	2611901	et	3	main
jahe	doc_491521502160_item	2611902	et	3	main
vaja	doc_491521502160_item	2611912	et	4	main
ostan	doc_491521502160_item	2611913	et	3	main
vildid	doc_491521502160_item	2611916	et	4	main
ega	doc_491521502160_item	2611917	et	3	main
seal	doc_491521502160_item	2611918	et	4	main
suurt	doc_491521502160_item	2611919	et	3	main
muud	doc_491521502160_item	2611920	et	4	main
talveks	doc_491521502160_item	2611924	et	4	main
vapralt	doc_491521502160_item	2611928	et	4	main
lühendatud	doc_491521502160_item	2611929	et	4	main
ajalehest	doc_491521502160_item	2611930	et	4	main
ja	doc_491521502160_item	2611949	et	3	main
mehi	doc_491521502160_item	2611959	et	3	main
3	doc_491521502160_item	2611963	et	2	main
stressi	doc_491521502160_item	2611978	et	4	main
võib	doc_491521502160_item	2611984	et	3	main
soovimatuid	doc_491521502160_item	2611986	et	4	main
tagajärgi	doc_491521502160_item	2611987	et	4	main
4	doc_491521502160_item	2611988	et	2	main
ei	doc_491521502160_item	2611989	et	4	main
tohtima	doc_491521502160_item	2611990	et	3	main
laskma	doc_491521502160_item	2611991	et	3	main
ülekoormus	doc_491521502160_item	2611992	et	3	main
tekkima	doc_491521502160_item	2611993	et	3	main
pinge	doc_491521502160_item	2611994	et	4	main
saama	doc_491521502160_item	2611995	et	4	main
maandama	doc_491521502160_item	2611996	et	3	main
sportima	doc_491521502160_item	2611997	et	4	main
ja	doc_491521502160_item	2611998	et	3	main
puhkama	doc_491521502160_item	2611999	et	3	main
ei	doc_491521502160_item	2612000	et	4	main
tohi	doc_491521502160_item	2612001	et	4	main
ülekoormusel	doc_491521502160_item	2612003	et	3	main
lasta	doc_491521502160_item	2612002	et	4	main
tekkida	doc_491521502160_item	2612004	et	3	main
aga	doc_491521502160_item	2612005	et	3	main
pinge	doc_491521502160_item	2612006	et	4	main
saab	doc_491521502160_item	2612007	et	3	main
maandada	doc_491521502160_item	2612008	et	3	main
sportimisega	doc_491521502160_item	2612009	et	4	main
sportides	doc_491521502160_item	2612010	et	4	main
ja	doc_491521502160_item	2612011	et	3	main
puhkamisega	doc_491521502160_item	2612012	et	4	main
puhates	doc_491521502160_item	2612013	et	3	main
5	doc_491521502160_item	2612014	et	2	main
telefon	doc_491521502160_item	2612015	et	3	main
olema	doc_491521502160_item	2612016	et	4	main
tänapäev	doc_491521502160_item	2612017	et	3	main
saama	doc_491521502160_item	2612018	et	4	main
nii	doc_491521502160_item	2612019	et	3	main
maagiline	doc_491521502160_item	2612020	et	4	main
et	doc_491521502160_item	2612022	et	3	main
elama	doc_491521502160_item	2612026	et	3	main
võima	doc_491521502160_item	2611972	et	3	main
soovimatu	doc_491521502160_item	2611974	et	4	main
lisakoormus	doc_491521502160_item	2611983	et	3	main
aparaat	doc_491521502160_item	2612021	et	3	main
on	doc_491521502160_item	2612030	et	4	main
6	doc_491521502160_item	2612043	et	2	main
kuid	doc_491521502160_item	2612044	et	4	main
ka	doc_491521502160_item	2612047	et	3	main
uni	doc_491521502160_item	2612050	et	3	main
valmistamine	doc_491521502160_item	2612053	et	4	main
ja	doc_491521502160_item	2612054	et	3	main
pahandab	doc_491521502160_item	2612056	et	3	main
kuid	doc_491521502160_item	2612061	et	4	main
katkestab	doc_491521502160_item	2612063	et	3	main
olevad	doc_491521502160_item	2612081	et	4	main
oma	doc_491521502160_item	2612090	et	4	main
lausa	doc_491521502160_item	2612025	et	4	main
telefon	doc_491521502160_item	2612029	et	3	main
tänapäeval	doc_491521502160_item	2612031	et	3	main
nii	doc_491521502160_item	2612033	et	3	main
maagiliseks	doc_491521502160_item	2612034	et	4	main
aparaadiks	doc_491521502160_item	2612035	et	3	main
telefonihelin	doc_491521502160_item	2612045	et	3	main
katkestama	doc_491521502160_item	2612046	et	3	main
varahommik	doc_491521502160_item	2612049	et	3	main
lõunasöök	doc_491521502160_item	2612052	et	3	main
vaatamine	doc_491521502160_item	2612059	et	4	main
ka	doc_491521502160_item	2612064	et	3	main
varahommikul	doc_491521502160_item	2612066	et	3	main
segab	doc_491521502160_item	2612068	et	3	main
huvitava	doc_491521502160_item	2612074	et	4	main
õigesse	doc_491521502160_item	2612083	et	3	main
1	doc_491521502160_item	2612085	et	2	main
ma	doc_491521502160_item	2612086	et	3	main
pean	doc_491521502160_item	2612087	et	4	main
väga	doc_491521502160_item	2612088	et	3	main
lugu	doc_491521502160_item	2612089	et	4	main
vanematest	doc_491521502160_item	2612093	et	4	main
nõudeid	doc_491521502160_item	2612107	et	3	main
3	doc_491521502160_item	2612108	et	2	main
ma	doc_491521502160_item	2612109	et	3	main
arvasin	doc_491521502160_item	2612110	et	3	main
et	doc_491521502160_item	2612111	et	3	main
sa	doc_491521502160_item	2612112	et	3	main
huvitud	doc_491521502160_item	2612113	et	4	main
sport	doc_491521502160_item	2612114	et	3	main
spordist	doc_491521502160_item	2612115	et	3	main
aga	doc_491521502160_item	2612116	et	3	main
sa	doc_491521502160_item	2612117	et	3	main
tunned	doc_491521502160_item	2612118	et	3	main
huvi	doc_491521502160_item	2612119	et	4	main
ainult	doc_491521502160_item	2612120	et	4	main
ilusad	doc_491521502160_item	2612121	et	3	main
ja	doc_491521502160_item	2612123	et	3	main
autod	doc_491521502160_item	2612125	et	3	main
naiste	doc_491521502160_item	2612127	et	3	main
ja	doc_491521502160_item	2612128	et	3	main
oht	doc_491521502160_item	2612135	et	3	main
5	doc_491521502160_item	2612139	et	2	main
uuest	doc_491521502160_item	2612143	et	3	main
piirdusime	doc_491521502160_item	2612147	et	3	main
kuulub	doc_491521502160_item	2612158	et	3	main
teine	doc_491521502160_item	2612159	et	3	main
valdkond	doc_491521502160_item	2612160	et	3	main
pükste	doc_491521502160_item	2612167	et	3	main
külmal	doc_491521502160_item	2612171	et	3	main
ajal	doc_491521502160_item	2612172	et	4	main
päikest	doc_491521502160_item	2612184	et	4	main
hingama	doc_491521502160_item	2612028	et	3	main
abil	doc_491521502160_item	2612038	et	4	main
söömine	doc_491521502160_item	2612055	et	4	main
telefonihelin	doc_491521502160_item	2612062	et	3	main
pühapäeval	doc_491521502160_item	2612065	et	3	main
und	doc_491521502160_item	2612067	et	4	main
lõunasööki	doc_491521502160_item	2612069	et	4	main
valmistamist	doc_491521502160_item	2612070	et	4	main
ja	doc_491521502160_item	2612071	et	3	main
telesaate	doc_491521502160_item	2612075	et	3	main
vormi	doc_491521502160_item	2612084	et	4	main
oma	doc_491521502160_item	2612092	et	4	main
aitavad	doc_491521502160_item	2612096	et	4	main
usaldavad	doc_491521502160_item	2612100	et	4	main
igaüks	doc_491521502160_item	2612101	et	3	main
igaüht	doc_491521502160_item	2612102	et	3	main
2	doc_491521502160_item	2612103	et	2	main
kohandasin	doc_491521502160_item	2612104	et	3	main
artikli	doc_491521502160_item	2612105	et	3	main
nõuded	doc_491521502160_item	2612106	et	3	main
autode	doc_491521502160_item	2612130	et	3	main
haigestuda	doc_491521502160_item	2612136	et	3	main
tüdinesin	doc_491521502160_item	2612140	et	3	main
töökoht	doc_491521502160_item	2612142	et	3	main
väikeste	doc_491521502160_item	2612153	et	4	main
muudatustega	doc_491521502160_item	2612154	et	3	main
valdkonda	doc_491521502160_item	2612162	et	4	main
külmetamisest	doc_491521502160_item	2612176	et	4	main
10	doc_491521502160_item	2612177	et	2	main
suvine	doc_491521502160_item	2612181	et	4	main
suvisest	doc_491521502160_item	2612183	et	4	main
5	doc_491521502160_item	2612226	et	2	main
ta	doc_491521502160_item	2612227	et	4	main
töö	doc_491521502160_item	2612237	et	4	main
ei	doc_491521502160_item	2612247	et	4	main
suitsetada	doc_491521502160_item	2612249	et	3	main
tulemust	doc_491521502160_item	2612259	et	4	main
eesti	doc_491521502161_item	2612279	et	4	main
pange	doc_491521502161_item	2612283	et	4	main
toomet	doc_491521502161_item	2612290	et	4	main
ettevõtlik	doc_491521502161_item	2612292	et	3	main
keele	doc_491521502161_item	2612308	et	4	main
kiired	doc_491521502160_item	2612124	et	4	main
vastu	doc_491521502160_item	2612131	et	3	main
väikesed	doc_491521502160_item	2612151	et	4	main
muudatused	doc_491521502160_item	2612152	et	3	main
närimiskumm	doc_491521502160_item	2612164	et	3	main
kleepus	doc_491521502160_item	2612165	et	3	main
9	doc_491521502160_item	2612170	et	2	main
peab	doc_491521502160_item	2612173	et	4	main
hoiduma	doc_491521502160_item	2612174	et	3	main
külmetamine	doc_491521502160_item	2612175	et	4	main
rõõmu	doc_491521502160_item	2612180	et	4	main
päike	doc_491521502160_item	2612182	et	3	main
täitke	doc_491521502160_item	2612186	et	3	main
lüngad	doc_491521502160_item	2612187	et	3	main
sobivate	doc_491521502160_item	2612188	et	4	main
sidenditega	doc_491521502160_item	2612189	et	3	main
1	doc_491521502160_item	2612190	et	2	main
kolmekäigulise	doc_491521502160_item	2612192	et	4	main
tellisime	doc_491521502160_item	2612191	et	4	main
lõuna	doc_491521502160_item	2612193	et	4	main
aga	doc_491521502160_item	2612194	et	3	main
kuigi	doc_491521502160_item	2612196	et	3	main
vaid	doc_491521502160_item	2612195	et	3	main
see	doc_491521502160_item	2612197	et	3	main
maksis	doc_491521502160_item	2612198	et	4	main
palju	doc_491521502160_item	2612199	et	4	main
2	doc_491521502160_item	2612200	et	2	main
kohal	doc_491521502160_item	2612201	et	4	main
olid	doc_491521502160_item	2612202	et	4	main
nii	doc_491521502160_item	2612203	et	3	main
õpilased	doc_491521502160_item	2612204	et	3	main
ka	doc_491521502160_item	2612206	et	3	main
kui	doc_491521502160_item	2612205	et	3	main
õpetajad	doc_491521502160_item	2612207	et	4	main
3	doc_491521502160_item	2612208	et	2	main
lapsel	doc_491521502160_item	2612209	et	4	main
paluti	doc_491521502160_item	2612210	et	3	main
oodata	doc_491521502160_item	2612211	et	4	main
kui	doc_491521502160_item	2612212	et	3	main
vanemad	doc_491521502160_item	2612213	et	4	main
tagasi	doc_491521502160_item	2612214	et	3	main
tulevad	doc_491521502160_item	2612215	et	4	main
4	doc_491521502160_item	2612216	et	2	main
kõrvallauast	doc_491521502160_item	2612217	et	4	main
kostis	doc_491521502160_item	2612218	et	4	main
naeru	doc_491521502160_item	2612219	et	4	main
nagu	doc_491521502160_item	2612220	et	3	main
keegi	doc_491521502160_item	2612222	et	4	main
anekdooti	doc_491521502160_item	2612224	et	4	main
rääkinud	doc_491521502160_item	2612225	et	4	main
vaid	doc_491521502160_item	2612231	et	3	main
läheb	doc_491521502160_item	2612232	et	3	main
hoopis	doc_491521502160_item	2612233	et	3	main
6	doc_491521502160_item	2612235	et	2	main
alles	doc_491521502160_item	2612240	et	3	main
lähete	doc_491521502160_item	2612242	et	4	main
küll	doc_491521502160_item	2612256	et	4	main
kas	doc_491521502160_item	2612263	et	3	main
keele	doc_491521502161_item	2612277	et	4	main
test	doc_491521502161_item	2612278	et	3	main
i	doc_491521502161_item	2612282	et	4	main
sulgudes	doc_491521502161_item	2612284	et	4	main
õigesse	doc_491521502161_item	2612287	et	3	main
kuulutus	doc_491521502161_item	2612299	et	4	main
kuulutust	doc_491521502161_item	2612300	et	4	main
et	doc_491521502161_item	2612301	et	3	main
eesti	doc_491521502161_item	2612307	et	4	main
piret	doc_491521502161_item	2612310	et	4	main
võitis	doc_491521502161_item	2612311	et	3	main
konkurss	doc_491521502161_item	2612312	et	3	main
konkurssi	doc_491521502161_item	2612313	et	4	main
ja	doc_491521502161_item	2612314	et	3	main
nädal	doc_491521502161_item	2612319	et	3	main
nädala	doc_491521502161_item	2612320	et	3	main
väikestele	doc_491521502161_item	2612321	et	4	main
oodatud	doc_491521502161_item	2612336	et	4	main
üllatunud	doc_491521502161_item	2612340	et	4	main
mulle	doc_491521502161_item	2612342	et	4	main
korraliku	doc_491521502161_item	2612347	et	3	main
siberi	doc_491521502161_item	2612352	et	4	main
selline	doc_491521502161_item	2612353	et	4	main
pilt	doc_491521502161_item	2612354	et	3	main
et	doc_491521502161_item	2612355	et	3	main
seal	doc_491521502161_item	2612356	et	4	main
kartuleid	doc_491521502161_item	2612386	et	3	main
tähtsam	doc_491521502161_item	2612393	et	4	main
ettevõtmine	doc_491521502161_item	2612394	et	3	main
tänaseks	doc_491521502161_item	2612395	et	4	main
on	doc_491521502161_item	2612396	et	4	main
õppimine	doc_491521502161_item	2612400	et	4	main
käib	doc_491521502161_item	2612401	et	3	main
täie	doc_491521502161_item	2612402	et	3	main
teistmoodi	doc_491521502161_item	2612409	et	3	main
ja	doc_491521502161_item	2612411	et	3	main
mõnusalt	doc_491521502161_item	2612413	et	4	main
mahlakalt	doc_491521502161_item	2612415	et	4	main
mitte	doc_491521502161_item	2612416	et	3	main
nagu	doc_491521502161_item	2612421	et	3	main
venemaa	doc_491521502161_item	2612428	et	4	main
keeles	doc_491521502161_item	2612436	et	4	main
külas	doc_491521502161_item	2612437	et	3	main
elab	doc_491521502161_item	2612438	et	3	main
veidi	doc_491521502161_item	2612439	et	3	main
emakeelt	doc_491521502161_item	2612445	et	4	main
rääkida	doc_491521502161_item	2612449	et	3	main
lapsed	doc_491521502161_item	2612453	et	3	main
poolpõlenud	doc_491521502161_item	2612454	et	4	main
piret	doc_491521502161_item	2612465	et	4	main
ei	doc_491521502161_item	2612466	et	4	main
kuid	doc_491521502161_item	2612480	et	4	main
jaed	doc_491521502161_item	2612484	et	4	main
ostan	doc_491521502161_item	2612494	et	3	main
külapood	doc_491521502161_item	2612495	et	3	main
kirjavahemärke	doc_491521502161_item	2612524	et	4	main
tegema	doc_491521502161_item	2612527	et	3	main
naiselikum	doc_491521502161_item	2612538	et	4	main
mehelikum	doc_491521502161_item	2612541	et	4	main
kogus	doc_491521502161_item	2612546	et	4	main
kogus	doc_491521502161_item	2612558	et	4	main
stress	doc_491521502161_item	2612559	et	3	main
tuua	doc_491521502161_item	2612566	et	3	main
4	doc_491521502161_item	2612569	et	2	main
ja	doc_491521502161_item	2612579	et	3	main
tohi	doc_491521502161_item	2612582	et	4	main
lasta	doc_491521502161_item	2612584	et	4	main
sporti	doc_491521502161_item	2612589	et	4	main
ei	doc_491521502160_item	2612228	et	4	main
siis	doc_491521502160_item	2612238	et	3	main
siis	doc_491521502160_item	2612241	et	3	main
selles	doc_491521502160_item	2612245	et	4	main
ega	doc_491521502160_item	2612250	et	3	main
8	doc_491521502160_item	2612253	et	2	main
nad	doc_491521502160_item	2612254	et	3	main
töötasid	doc_491521502160_item	2612255	et	4	main
ei	doc_491521502160_item	2612260	et	4	main
sest	doc_491521502160_item	2612273	et	4	main
kuulsin	doc_491521502160_item	2612274	et	3	main
koputust	doc_491521502160_item	2612275	et	4	main
sõnad	doc_491521502161_item	2612286	et	4	main
siberisse	doc_491521502161_item	2612302	et	4	main
on	doc_491521502161_item	2612315	et	4	main
pireti	doc_491521502161_item	2612328	et	4	main
kinnitusel	doc_491521502161_item	2612329	et	4	main
tundis	doc_491521502161_item	2612330	et	3	main
ta	doc_491521502161_item	2612331	et	4	main
olin	doc_491521502161_item	2612337	et	3	main
tulema	doc_491521502161_item	2612343	et	4	main
korralik	doc_491521502161_item	2612346	et	3	main
ei	doc_491521502161_item	2612357	et	4	main
võttis	doc_491521502161_item	2612385	et	3	main
siin	doc_491521502161_item	2612389	et	4	main
hooguga	doc_491521502161_item	2612404	et	4	main
kuidagi	doc_491521502161_item	2612408	et	3	main
mahlakas	doc_491521502161_item	2612412	et	4	main
ja	doc_491521502161_item	2612414	et	3	main
mõne	doc_491521502161_item	2612423	et	3	main
kool	doc_491521502161_item	2612425	et	4	main
on	doc_491521502161_item	2612426	et	4	main
siiski	doc_491521502161_item	2612427	et	4	main
üle	doc_491521502161_item	2612440	et	3	main
saab	doc_491521502161_item	2612446	et	3	main
kõike	doc_491521502161_item	2612448	et	4	main
eestist	doc_491521502161_item	2612460	et	3	main
uued	doc_491521502161_item	2612461	et	3	main
õpikud	doc_491521502161_item	2612462	et	3	main
talvepuud	doc_491521502161_item	2612473	et	4	main
praegu	doc_491521502161_item	2612474	et	3	main
on	doc_491521502161_item	2612475	et	4	main
päevad	doc_491521502161_item	2612476	et	3	main
veel	doc_491521502161_item	2612477	et	4	main
ööd	doc_491521502161_item	2612481	et	4	main
suure	doc_491521502161_item	2612487	et	3	main
vaja	doc_491521502161_item	2612493	et	4	main
ja	doc_491521502161_item	2612522	et	3	main
naeratus	doc_491521502161_item	2612526	et	4	main
ja	doc_491521502161_item	2612530	et	3	main
ja	doc_491521502161_item	2612539	et	3	main
panema	doc_491521502161_item	2612548	et	3	main
meid	doc_491521502161_item	2612561	et	4	main
soovimatu	doc_491521502161_item	2612567	et	4	main
ei	doc_491521502161_item	2612570	et	4	main
puhkama	doc_491521502161_item	2612580	et	3	main
ei	doc_491521502161_item	2612581	et	4	main
ülekoormuse	doc_491521502161_item	2612583	et	3	main
tekkib	doc_491521502161_item	2612585	et	3	main
pinge	doc_491521502161_item	2612586	et	4	main
5	doc_491521502161_item	2612592	et	2	main
olema	doc_491521502161_item	2612594	et	4	main
hingama	doc_491521502161_item	2612606	et	3	main
pühapäev	doc_491521502161_item	2612626	et	3	main
segama	doc_491521502161_item	2612629	et	3	main
söömine	doc_491521502161_item	2612633	et	4	main
telesaade	doc_491521502161_item	2612636	et	4	main
vaatamine	doc_491521502161_item	2612637	et	4	main
aeg	doc_491521502161_item	2612638	et	3	main
und	doc_491521502161_item	2612645	et	4	main
huvitavat	doc_491521502161_item	2612652	et	4	main
telesaade	doc_491521502161_item	2612653	et	4	main
pean	doc_491521502161_item	2612665	et	4	main
vanemad	doc_491521502161_item	2612669	et	4	main
oma	doc_491521502161_item	2612670	et	4	main
nõudeid	doc_491521502161_item	2612685	et	3	main
arvasin	doc_491521502161_item	2612688	et	3	main
sa	doc_491521502161_item	2612690	et	3	main
sport	doc_491521502161_item	2612692	et	3	main
tunned	doc_491521502161_item	2612696	et	3	main
4	doc_491521502161_item	2612704	et	2	main
on	doc_491521502161_item	2612706	et	4	main
jääd	doc_491521502160_item	2612268	et	4	main
linna	doc_491521502160_item	2612269	et	4	main
10	doc_491521502160_item	2612270	et	2	main
avasin	doc_491521502160_item	2612271	et	3	main
ukse	doc_491521502160_item	2612272	et	3	main
test	doc_491521502161_item	2612281	et	3	main
olevad	doc_491521502161_item	2612285	et	4	main
vormi	doc_491521502161_item	2612288	et	4	main
on	doc_491521502161_item	2612291	et	4	main
naine	doc_491521502161_item	2612293	et	3	main
nägema	doc_491521502161_item	2612295	et	3	main
ta	doc_491521502161_item	2612297	et	4	main
ajalehes	doc_491521502161_item	2612298	et	3	main
küla	doc_491521502161_item	2612304	et	4	main
külasse	doc_491521502161_item	2612305	et	3	main
otsitakse	doc_491521502161_item	2612306	et	3	main
õpetajat	doc_491521502161_item	2612309	et	4	main
üllatuma	doc_491521502161_item	2612339	et	3	main
kui	doc_491521502161_item	2612341	et	3	main
vastu	doc_491521502161_item	2612345	et	3	main
audiga	doc_491521502161_item	2612348	et	3	main
siber	doc_491521502161_item	2612351	et	4	main
kool	doc_491521502161_item	2612378	et	4	main
veel	doc_491521502161_item	2612379	et	4	main
algama	doc_491521502161_item	2612380	et	3	main
alganud	doc_491521502161_item	2612381	et	4	main
kogu	doc_491521502161_item	2612382	et	4	main
kartulivõtt	doc_491521502161_item	2612387	et	3	main
kõige	doc_491521502161_item	2612391	et	4	main
kartul	doc_491521502161_item	2612397	et	3	main
salv	doc_491521502161_item	2612398	et	3	main
siinsed	doc_491521502161_item	2612405	et	3	main
vene	doc_491521502161_item	2612417	et	4	main
murret	doc_491521502161_item	2612424	et	4	main
ja	doc_491521502161_item	2612430	et	3	main
ülejäänud	doc_491521502161_item	2612431	et	4	main
aine	doc_491521502161_item	2612432	et	4	main
ained	doc_491521502161_item	2612433	et	3	main
õpetatakse	doc_491521502161_item	2612434	et	3	main
vene	doc_491521502161_item	2612435	et	4	main
kõik	doc_491521502161_item	2612447	et	4	main
pireti	doc_491521502161_item	2612450	et	4	main
sõnul	doc_491521502161_item	2612451	et	3	main
õpivad	doc_491521502161_item	2612452	et	3	main
siberi	doc_491521502161_item	2612463	et	4	main
kartma	doc_491521502161_item	2612467	et	3	main
jahe	doc_491521502161_item	2612483	et	3	main
harjutan	doc_491521502161_item	2612485	et	3	main
vormi	doc_491521502161_item	2612521	et	4	main
mehelikum	doc_491521502161_item	2612532	et	4	main
kaunim	doc_491521502161_item	2612534	et	4	main
naeratus	doc_491521502161_item	2612535	et	4	main
teeb	doc_491521502161_item	2612536	et	3	main
naised	doc_491521502161_item	2612537	et	3	main
igaühe	doc_491521502161_item	2612542	et	4	main
paras	doc_491521502161_item	2612545	et	3	main
meie	doc_491521502161_item	2612549	et	4	main
tegutsema	doc_491521502161_item	2612550	et	3	main
aga	doc_491521502161_item	2612551	et	3	main
lisakoormus	doc_491521502161_item	2612552	et	3	main
võima	doc_491521502161_item	2612553	et	3	main
tooma	doc_491521502161_item	2612554	et	3	main
soovimatu	doc_491521502161_item	2612555	et	4	main
tagajärg	doc_491521502161_item	2612556	et	3	main
paras	doc_491521502161_item	2612557	et	3	main
tegutsema	doc_491521502161_item	2612562	et	3	main
lisakoormus	doc_491521502161_item	2612564	et	3	main
saama	doc_491521502161_item	2612596	et	4	main
abil	doc_491521502161_item	2612602	et	4	main
elama	doc_491521502161_item	2612604	et	3	main
ja	doc_491521502161_item	2612605	et	3	main
on	doc_491521502161_item	2612608	et	4	main
tänapäeval	doc_491521502161_item	2612609	et	3	main
6	doc_491521502161_item	2612621	et	2	main
emakeelt	doc_491521502161_item	2612325	et	4	main
õpetama	doc_491521502161_item	2612326	et	3	main
õpetamas	doc_491521502161_item	2612327	et	3	main
on	doc_491521502161_item	2612335	et	4	main
tuli	doc_491521502161_item	2612344	et	4	main
maaliti	doc_491521502161_item	2612350	et	3	main
lenda	doc_491521502161_item	2612359	et	4	main
lind	doc_491521502161_item	2612360	et	3	main
ega	doc_491521502161_item	2612361	et	3	main
kasva	doc_491521502161_item	2612362	et	4	main
rohi	doc_491521502161_item	2612363	et	4	main
kui	doc_491521502161_item	2612364	et	3	main
noor	doc_491521502161_item	2612365	et	3	main
ja	doc_491521502161_item	2612366	et	3	main
tahtmine	doc_491521502161_item	2612367	et	4	main
tahtmisega	doc_491521502161_item	2612368	et	4	main
täis	doc_491521502161_item	2612369	et	4	main
piret	doc_491521502161_item	2612370	et	4	main
pärast	doc_491521502161_item	2612371	et	4	main
õppeaasta	doc_491521502161_item	2612372	et	4	main
koht	doc_491521502161_item	2612374	et	3	main
üsna	doc_491521502161_item	2612338	et	3	main
mulle	doc_491521502161_item	2612349	et	4	main
lendama	doc_491521502161_item	2612358	et	3	main
algust	doc_491521502161_item	2612373	et	4	main
kohale	doc_491521502161_item	2612375	et	4	main
jõudis	doc_491521502161_item	2612376	et	3	main
polnud	doc_491521502161_item	2612377	et	3	main
küla	doc_491521502161_item	2612383	et	4	main
eestlased	doc_491521502161_item	2612406	et	3	main
räägivad	doc_491521502161_item	2612407	et	3	main
aktsent	doc_491521502161_item	2612418	et	3	main
aktsentiga	doc_491521502161_item	2612419	et	4	main
vaid	doc_491521502161_item	2612420	et	3	main
mõni	doc_491521502161_item	2612422	et	3	main
kool	doc_491521502161_item	2612429	et	4	main
kolmsada	doc_491521502161_item	2612441	et	4	main
kolmesaja	doc_491521502161_item	2612442	et	4	main
raamatud	doc_491521502161_item	2612455	et	4	main
raamatuid	doc_491521502161_item	2612456	et	3	main
varsti	doc_491521502161_item	2612457	et	3	main
saatma	doc_491521502161_item	2612458	et	3	main
talve	doc_491521502161_item	2612464	et	4	main
karda	doc_491521502161_item	2612468	et	4	main
mulle	doc_491521502161_item	2612469	et	4	main
juba	doc_491521502161_item	2612470	et	3	main
tooma	doc_491521502161_item	2612471	et	3	main
toodi	doc_491521502161_item	2612472	et	4	main
juba	doc_491521502161_item	2612482	et	3	main
juba	doc_491521502161_item	2612486	et	3	main
vene	doc_491521502161_item	2612488	et	4	main
kütmine	doc_491521502161_item	2612490	et	4	main
kasutades	doc_491521502161_item	2612523	et	3	main
naised	doc_491521502161_item	2612528	et	3	main
igaüks	doc_491521502161_item	2612533	et	3	main
kaunim	doc_491521502161_item	2612543	et	4	main
aga	doc_491521502161_item	2612563	et	3	main
võib	doc_491521502161_item	2612565	et	3	main
tagajärg	doc_491521502161_item	2612568	et	3	main
tohtima	doc_491521502161_item	2612571	et	3	main
laskma	doc_491521502161_item	2612572	et	3	main
ülekoormus	doc_491521502161_item	2612573	et	3	main
tekkima	doc_491521502161_item	2612574	et	3	main
pinge	doc_491521502161_item	2612575	et	4	main
saama	doc_491521502161_item	2612576	et	4	main
maandama	doc_491521502161_item	2612577	et	3	main
saage	doc_491521502161_item	2612587	et	4	main
telefon	doc_491521502161_item	2612593	et	3	main
tänapäev	doc_491521502161_item	2612595	et	3	main
nii	doc_491521502161_item	2612597	et	3	main
et	doc_491521502161_item	2612600	et	3	main
lausa	doc_491521502161_item	2612603	et	4	main
telefon	doc_491521502161_item	2612607	et	3	main
kuid	doc_491521502161_item	2612622	et	4	main
varahommik	doc_491521502161_item	2612627	et	3	main
pahandab	doc_491521502161_item	2612634	et	3	main
telefonihelin	doc_491521502161_item	2612640	et	3	main
katkestab	doc_491521502161_item	2612641	et	3	main
pühapäeva	doc_491521502161_item	2612643	et	4	main
vaatamise	doc_491521502161_item	2612654	et	4	main
aeg	doc_491521502161_item	2612655	et	3	main
sõnad	doc_491521502161_item	2612660	et	4	main
õigesse	doc_491521502161_item	2612661	et	3	main
vanematele	doc_491521502161_item	2612671	et	4	main
usaldavad	doc_491521502161_item	2612678	et	4	main
igaüks	doc_491521502161_item	2612679	et	3	main
igaühele	doc_491521502161_item	2612680	et	3	main
2	doc_491521502161_item	2612681	et	2	main
kohandasin	doc_491521502161_item	2612682	et	3	main
huvi	doc_491521502161_item	2612697	et	4	main
ainult	doc_491521502161_item	2612698	et	4	main
ilusad	doc_491521502161_item	2612699	et	3	main
naised	doc_491521502161_item	2612700	et	3	main
ja	doc_491521502161_item	2612701	et	3	main
oht	doc_491521502161_item	2612707	et	3	main
difteeria	doc_491521502161_item	2612709	et	4	main
vaid	doc_491521502161_item	2612722	et	3	main
valdkond	doc_491521502161_item	2612732	et	3	main
püksid	doc_491521502161_item	2612738	et	3	main
külmal	doc_491521502161_item	2612741	et	3	main
hoiduma	doc_491521502161_item	2612744	et	3	main
külmetamine	doc_491521502161_item	2612745	et	4	main
võtma	doc_491521502161_item	2612384	et	3	main
on	doc_491521502161_item	2612388	et	4	main
sügisel	doc_491521502161_item	2612390	et	3	main
tähtis	doc_491521502161_item	2612392	et	4	main
ja	doc_491521502161_item	2612399	et	3	main
hoog	doc_491521502161_item	2612403	et	3	main
mõnus	doc_491521502161_item	2612410	et	4	main
inimene	doc_491521502161_item	2612443	et	3	main
inimesi	doc_491521502161_item	2612444	et	4	main
saadavad	doc_491521502161_item	2612459	et	4	main
soe	doc_491521502161_item	2612478	et	4	main
soojad	doc_491521502161_item	2612479	et	3	main
ahju	doc_491521502161_item	2612489	et	4	main
kütmisega	doc_491521502161_item	2612491	et	4	main
kui	doc_491521502161_item	2612492	et	3	main
külapojast	doc_491521502161_item	2612496	et	4	main
vildid	doc_491521502161_item	2612497	et	4	main
ega	doc_491521502161_item	2612498	et	3	main
seal	doc_491521502161_item	2612499	et	4	main
suurt	doc_491521502161_item	2612500	et	3	main
muud	doc_491521502161_item	2612501	et	4	main
ei	doc_491521502161_item	2612502	et	4	main
naerab	doc_491521502161_item	2612504	et	3	main
talveks	doc_491521502161_item	2612505	et	4	main
valmistuma	doc_491521502161_item	2612506	et	3	main
müüdagi	doc_491521502161_item	2612503	et	3	main
valmistu	doc_491521502161_item	2612507	et	4	main
piret	doc_491521502161_item	2612508	et	4	main
vapralt	doc_491521502161_item	2612509	et	4	main
lühendatud	doc_491521502161_item	2612510	et	4	main
ajalehest	doc_491521502161_item	2612511	et	4	main
slõhtuleht	doc_491521502161_item	2612512	et	4	main
iii	doc_491521502161_item	2612513	et	4	main
moodustage	doc_491521502161_item	2612514	et	3	main
etteantud	doc_491521502161_item	2612515	et	4	main
sõnadest	doc_491521502161_item	2612516	et	3	main
laused	doc_491521502161_item	2612517	et	3	main
pannes	doc_491521502161_item	2612518	et	4	main
sõnad	doc_491521502161_item	2612519	et	4	main
õigesse	doc_491521502161_item	2612520	et	3	main
2	doc_491521502161_item	2612525	et	2	main
naiselikum	doc_491521502161_item	2612529	et	4	main
mehed	doc_491521502161_item	2612531	et	3	main
mehed	doc_491521502161_item	2612540	et	3	main
3	doc_491521502161_item	2612544	et	2	main
stress	doc_491521502161_item	2612547	et	3	main
paneb	doc_491521502161_item	2612560	et	3	main
sportima	doc_491521502161_item	2612578	et	4	main
maandama	doc_491521502161_item	2612588	et	3	main
puhkuse	doc_491521502161_item	2612591	et	3	main
see	doc_491521502161_item	2612601	et	3	main
nii	doc_491521502161_item	2612610	et	3	main
saama	doc_491521502161_item	2612611	et	4	main
maagiline	doc_491521502161_item	2612612	et	4	main
aparaat	doc_491521502161_item	2612613	et	3	main
et	doc_491521502161_item	2612614	et	3	main
see	doc_491521502161_item	2612615	et	3	main
valmistamine	doc_491521502161_item	2612631	et	4	main
huvitav	doc_491521502161_item	2612635	et	4	main
lõunasööki	doc_491521502161_item	2612647	et	4	main
iv	doc_491521502161_item	2612656	et	4	main
vormi	doc_491521502161_item	2612662	et	4	main
1	doc_491521502161_item	2612663	et	2	main
ma	doc_491521502161_item	2612664	et	3	main
sest	doc_491521502161_item	2612672	et	4	main
artikli	doc_491521502161_item	2612683	et	3	main
kiired	doc_491521502161_item	2612702	et	4	main
muudatused	doc_491521502161_item	2612724	et	3	main
7	doc_491521502161_item	2612727	et	2	main
küsimus	doc_491521502161_item	2612729	et	4	main
teise	doc_491521502161_item	2612733	et	4	main
valdkonale	doc_491521502161_item	2612734	et	4	main
püksidele	doc_491521502161_item	2612739	et	3	main
ajal	doc_491521502161_item	2612742	et	4	main
külmetamist	doc_491521502161_item	2612746	et	4	main
10	doc_491521502161_item	2612747	et	2	main
ma	doc_491521502161_item	2612748	et	3	main
tunnen	doc_491521502161_item	2612749	et	3	main
suvist	doc_491521502161_item	2612753	et	4	main
v	doc_491521502161_item	2612755	et	4	main
kuigi	doc_491521502161_item	2612764	et	3	main
palju	doc_491521502161_item	2612767	et	4	main
kohal	doc_491521502161_item	2612769	et	4	main
paluti	doc_491521502161_item	2612777	et	3	main
alkoholi	doc_491521502161_item	2612815	et	4	main
töötasid	doc_491521502161_item	2612819	et	4	main
küll	doc_491521502161_item	2612820	et	4	main
ja	doc_491521502161_item	2612590	et	3	main
maagiline	doc_491521502161_item	2612598	et	4	main
aparaat	doc_491521502161_item	2612599	et	3	main
lausa	doc_491521502161_item	2612616	et	4	main
abil	doc_491521502161_item	2612617	et	4	main
elama	doc_491521502161_item	2612618	et	3	main
ja	doc_491521502161_item	2612619	et	3	main
hingama	doc_491521502161_item	2612620	et	3	main
katkestama	doc_491521502161_item	2612624	et	3	main
ka	doc_491521502161_item	2612625	et	3	main
lõunasöök	doc_491521502161_item	2612630	et	3	main
segab	doc_491521502161_item	2612646	et	3	main
ja	doc_491521502161_item	2612649	et	3	main
pahandab	doc_491521502161_item	2612651	et	3	main
lugu	doc_491521502161_item	2612667	et	4	main
nad	doc_491521502161_item	2612673	et	3	main
aitavad	doc_491521502161_item	2612674	et	4	main
kõik	doc_491521502161_item	2612675	et	4	main
kõiki	doc_491521502161_item	2612676	et	4	main
ja	doc_491521502161_item	2612677	et	3	main
3	doc_491521502161_item	2612686	et	2	main
huvitud	doc_491521502161_item	2612691	et	4	main
ja	doc_491521502161_item	2612632	et	3	main
telefonihelin	doc_491521502161_item	2612623	et	3	main
uni	doc_491521502161_item	2612628	et	3	main
kuid	doc_491521502161_item	2612639	et	4	main
ka	doc_491521502161_item	2612642	et	3	main
varahommiku	doc_491521502161_item	2612644	et	3	main
valmistamine	doc_491521502161_item	2612648	et	4	main
söömine	doc_491521502161_item	2612650	et	4	main
pange	doc_491521502161_item	2612657	et	4	main
sulgudes	doc_491521502161_item	2612658	et	4	main
olevad	doc_491521502161_item	2612659	et	4	main
väga	doc_491521502161_item	2612666	et	3	main
oma	doc_491521502161_item	2612668	et	4	main
nõuded	doc_491521502161_item	2612684	et	3	main
ma	doc_491521502161_item	2612687	et	3	main
et	doc_491521502161_item	2612689	et	3	main
sporti	doc_491521502161_item	2612693	et	4	main
aga	doc_491521502161_item	2612694	et	3	main
sa	doc_491521502161_item	2612695	et	3	main
autod	doc_491521502161_item	2612703	et	3	main
praegu	doc_491521502161_item	2612705	et	3	main
haigestuda	doc_491521502161_item	2612708	et	3	main
difteriat	doc_491521502161_item	2612710	et	4	main
5	doc_491521502161_item	2612711	et	2	main
tüdinesin	doc_491521502161_item	2612712	et	3	main
uus	doc_491521502161_item	2612713	et	3	main
töökoht	doc_491521502161_item	2612714	et	3	main
uue	doc_491521502161_item	2612715	et	3	main
kiiresti	doc_491521502161_item	2612717	et	3	main
6	doc_491521502161_item	2612718	et	2	main
töökohta	doc_491521502161_item	2612716	et	4	main
piirdusime	doc_491521502161_item	2612719	et	3	main
selles	doc_491521502161_item	2612720	et	4	main
väikesed	doc_491521502161_item	2612723	et	4	main
see	doc_491521502161_item	2612728	et	3	main
kuulub	doc_491521502161_item	2612730	et	3	main
päike	doc_491521502161_item	2612752	et	3	main
lõuna	doc_491521502161_item	2612763	et	4	main
pingsalt	doc_491521502161_item	2612821	et	4	main
tulemust	doc_491521502161_item	2612823	et	4	main
olnud	doc_491521502161_item	2612825	et	4	main
9	doc_491521502161_item	2612826	et	2	main
kas	doc_491521502161_item	2612827	et	3	main
sa	doc_491521502161_item	2612828	et	3	main
sõidad	doc_491521502161_item	2612829	et	3	main
sest	doc_491521502161_item	2612837	et	4	main
keele	doc_491521502162_item	2612844	et	4	main
sõnad	doc_491521502162_item	2612850	et	4	main
õigesse	doc_491521502162_item	2612851	et	3	main
naine	doc_491521502162_item	2612857	et	3	main
konkurss	doc_491521502162_item	2612876	et	3	main
konkursi	doc_491521502162_item	2612877	et	3	main
neid	doc_491521502162_item	2612888	et	4	main
ta	doc_491521502162_item	2612895	et	4	main
et	doc_491521502162_item	2612899	et	3	main
oodatud	doc_491521502162_item	2612901	et	4	main
olin	doc_491521502162_item	2612902	et	3	main
kui	doc_491521502162_item	2612906	et	3	main
audiga	doc_491521502162_item	2612913	et	3	main
maaliti	doc_491521502162_item	2612915	et	3	main
siberi	doc_491521502162_item	2612917	et	4	main
selline	doc_491521502162_item	2612918	et	4	main
pilt	doc_491521502162_item	2612919	et	3	main
lenda	doc_491521502162_item	2612924	et	4	main
lind	doc_491521502162_item	2612925	et	3	main
ega	doc_491521502162_item	2612926	et	3	main
kasva	doc_491521502162_item	2612927	et	4	main
pärast	doc_491521502162_item	2612935	et	4	main
kohta	doc_491521502162_item	2612939	et	4	main
algama	doc_491521502162_item	2612944	et	3	main
kartuleid	doc_491521502162_item	2612950	et	3	main
on	doc_491521502162_item	2612959	et	4	main
väikeses	doc_491521502161_item	2612725	et	4	main
muudatuses	doc_491521502161_item	2612726	et	3	main
8	doc_491521502161_item	2612735	et	2	main
9	doc_491521502161_item	2612740	et	2	main
rõõmu	doc_491521502161_item	2612750	et	4	main
kolmekäigulise	doc_491521502161_item	2612762	et	4	main
maksis	doc_491521502161_item	2612766	et	4	main
lapsel	doc_491521502161_item	2612776	et	4	main
oodata	doc_491521502161_item	2612778	et	4	main
vanemad	doc_491521502161_item	2612780	et	4	main
tagasi	doc_491521502161_item	2612781	et	3	main
tulevad	doc_491521502161_item	2612782	et	4	main
4	doc_491521502161_item	2612783	et	2	main
kõrvallauast	doc_491521502161_item	2612784	et	4	main
kostis	doc_491521502161_item	2612785	et	4	main
naeru	doc_491521502161_item	2612786	et	4	main
kas	doc_491521502161_item	2612787	et	3	main
oleks	doc_491521502161_item	2612788	et	3	main
keegi	doc_491521502161_item	2612789	et	4	main
just	doc_491521502161_item	2612790	et	3	main
anekdooti	doc_491521502161_item	2612791	et	4	main
rääkinud	doc_491521502161_item	2612792	et	4	main
5	doc_491521502161_item	2612793	et	2	main
ta	doc_491521502161_item	2612794	et	4	main
tule	doc_491521502161_item	2612796	et	4	main
ei	doc_491521502161_item	2612795	et	4	main
trenni	doc_491521502161_item	2612797	et	4	main
ta	doc_491521502161_item	2612798	et	4	main
läheb	doc_491521502161_item	2612799	et	3	main
hoopis	doc_491521502161_item	2612800	et	3	main
teatrisse	doc_491521502161_item	2612801	et	3	main
6	doc_491521502161_item	2612802	et	2	main
lõpetage	doc_491521502161_item	2612803	et	3	main
töö	doc_491521502161_item	2612804	et	4	main
siis	doc_491521502161_item	2612805	et	3	main
lähete	doc_491521502161_item	2612806	et	4	main
jalutama	doc_491521502161_item	2612807	et	3	main
7	doc_491521502161_item	2612808	et	2	main
selles	doc_491521502161_item	2612809	et	4	main
baaris	doc_491521502161_item	2612810	et	3	main
ei	doc_491521502161_item	2612811	et	4	main
tohi	doc_491521502161_item	2612812	et	4	main
küsimuses	doc_491521502161_item	2612721	et	4	main
teine	doc_491521502161_item	2612731	et	3	main
närimiskumm	doc_491521502161_item	2612736	et	3	main
kleepus	doc_491521502161_item	2612737	et	3	main
peab	doc_491521502161_item	2612743	et	4	main
tellisime	doc_491521502161_item	2612761	et	4	main
3	doc_491521502161_item	2612775	et	2	main
kuni	doc_491521502161_item	2612779	et	3	main
tarbida	doc_491521502161_item	2612816	et	3	main
nad	doc_491521502161_item	2612818	et	3	main
maale	doc_491521502161_item	2612830	et	4	main
võid	doc_491521502161_item	2612831	et	4	main
koputust	doc_491521502161_item	2612839	et	4	main
toomet	doc_491521502162_item	2612854	et	4	main
on	doc_491521502162_item	2612879	et	4	main
nüüd	doc_491521502162_item	2612880	et	4	main
juba	doc_491521502162_item	2612881	et	3	main
üle	doc_491521502162_item	2612882	et	3	main
nädal	doc_491521502162_item	2612883	et	3	main
nädalat	doc_491521502162_item	2612884	et	3	main
pireti	doc_491521502162_item	2612892	et	4	main
siberisse	doc_491521502162_item	2612896	et	4	main
jõudes	doc_491521502162_item	2612898	et	3	main
on	doc_491521502162_item	2612900	et	4	main
üsna	doc_491521502162_item	2612903	et	3	main
tuli	doc_491521502162_item	2612909	et	4	main
korralik	doc_491521502162_item	2612911	et	3	main
et	doc_491521502162_item	2612920	et	3	main
ei	doc_491521502162_item	2612922	et	4	main
lendama	doc_491521502162_item	2612923	et	3	main
piret	doc_491521502162_item	2612934	et	4	main
polnud	doc_491521502162_item	2612941	et	3	main
kartulivõtt	doc_491521502162_item	2612951	et	3	main
siin	doc_491521502162_item	2612953	et	4	main
teistmoodi	doc_491521502162_item	2612971	et	3	main
on	doc_491521502162_item	2612984	et	4	main
kool	doc_491521502162_item	2612987	et	4	main
aine	doc_491521502162_item	2612990	et	4	main
aineid	doc_491521502162_item	2612991	et	3	main
külas	doc_491521502162_item	2612995	et	3	main
veidi	doc_491521502162_item	2612997	et	3	main
talvepuud	doc_491521502162_item	2613031	et	4	main
praegu	doc_491521502162_item	2613032	et	3	main
ööd	doc_491521502162_item	2613039	et	4	main
juba	doc_491521502162_item	2613040	et	3	main
jahe	doc_491521502162_item	2613041	et	3	main
külapoest	doc_491521502162_item	2613054	et	4	main
ei	doc_491521502162_item	2613060	et	4	main
talveks	doc_491521502162_item	2613063	et	4	main
valmistuma	doc_491521502162_item	2613064	et	3	main
vapralt	doc_491521502162_item	2613067	et	4	main
sõnadest	doc_491521502162_item	2613074	et	3	main
vormi	doc_491521502162_item	2613079	et	4	main
kaunim	doc_491521502162_item	2613092	et	4	main
naised	doc_491521502162_item	2613097	et	3	main
naiselikumad	doc_491521502162_item	2613098	et	4	main
3	doc_491521502162_item	2613102	et	2	main
tegutsema	doc_491521502162_item	2613108	et	3	main
tooma	doc_491521502162_item	2613112	et	3	main
aga	doc_491521502162_item	2613121	et	3	main
võib	doc_491521502162_item	2613123	et	3	main
soovimata	doc_491521502162_item	2613125	et	4	main
ei	doc_491521502162_item	2613128	et	4	main
tekkima	doc_491521502162_item	2613132	et	3	main
ja	doc_491521502162_item	2613137	et	3	main
ei	doc_491521502162_item	2613139	et	4	main
lasta	doc_491521502162_item	2613141	et	4	main
maandada	doc_491521502162_item	2613146	et	3	main
see	doc_491521502162_item	2613173	et	3	main
tänapäevaks	doc_491521502162_item	2613179	et	3	main
maagiliseks	doc_491521502162_item	2613183	et	4	main
6	doc_491521502162_item	2613188	et	2	main
ka	doc_491521502162_item	2613192	et	3	main
uni	doc_491521502162_item	2613195	et	3	main
lõunasöök	doc_491521502162_item	2613197	et	3	main
ja	doc_491521502162_item	2613216	et	3	main
suvine	doc_491521502161_item	2612751	et	4	main
päikest	doc_491521502161_item	2612754	et	4	main
täitke	doc_491521502161_item	2612756	et	3	main
lüngad	doc_491521502161_item	2612757	et	3	main
sobivate	doc_491521502161_item	2612758	et	4	main
sidenditega	doc_491521502161_item	2612759	et	3	main
1	doc_491521502161_item	2612760	et	2	main
see	doc_491521502161_item	2612765	et	3	main
2	doc_491521502161_item	2612768	et	2	main
olid	doc_491521502161_item	2612770	et	4	main
nii	doc_491521502161_item	2612771	et	3	main
õpilased	doc_491521502161_item	2612772	et	3	main
kui	doc_491521502161_item	2612773	et	3	main
õpetajad	doc_491521502161_item	2612774	et	4	main
suitsetada	doc_491521502161_item	2612813	et	3	main
8	doc_491521502161_item	2612817	et	2	main
aga	doc_491521502161_item	2612822	et	3	main
ei	doc_491521502161_item	2612824	et	4	main
keele	doc_491521502162_item	2612841	et	4	main
eesti	doc_491521502162_item	2612843	et	4	main
i	doc_491521502162_item	2612846	et	4	main
pange	doc_491521502162_item	2612847	et	4	main
nägema	doc_491521502162_item	2612859	et	3	main
eestlastele	doc_491521502162_item	2612886	et	4	main
need	doc_491521502162_item	2612887	et	3	main
jõudma	doc_491521502162_item	2612897	et	3	main
üllatunud	doc_491521502162_item	2612905	et	4	main
vastu	doc_491521502162_item	2612910	et	3	main
mulle	doc_491521502162_item	2612914	et	4	main
siber	doc_491521502162_item	2612916	et	4	main
rohi	doc_491521502162_item	2612928	et	4	main
kui	doc_491521502162_item	2612929	et	3	main
noor	doc_491521502162_item	2612930	et	3	main
ja	doc_491521502162_item	2612931	et	3	main
algust	doc_491521502162_item	2612937	et	4	main
küla	doc_491521502162_item	2612947	et	4	main
võtma	doc_491521502162_item	2612948	et	3	main
võti	doc_491521502162_item	2612949	et	4	main
tänaseks	doc_491521502162_item	2612958	et	4	main
ja	doc_491521502162_item	2612962	et	3	main
hoog	doc_491521502162_item	2612966	et	3	main
kuidagi	doc_491521502162_item	2612970	et	3	main
mahlakas	doc_491521502162_item	2612974	et	4	main
vene	doc_491521502162_item	2612976	et	4	main
mõni	doc_491521502162_item	2612981	et	3	main
kool	doc_491521502162_item	2612983	et	4	main
talve	doc_491521502162_item	2613021	et	4	main
ei	doc_491521502162_item	2613025	et	4	main
mulle	doc_491521502162_item	2613027	et	4	main
juba	doc_491521502162_item	2613028	et	3	main
tooma	doc_491521502162_item	2613029	et	3	main
veel	doc_491521502162_item	2613035	et	4	main
harjutan	doc_491521502162_item	2613043	et	3	main
kui	doc_491521502162_item	2613050	et	3	main
vaja	doc_491521502162_item	2613051	et	4	main
ostan	doc_491521502162_item	2613052	et	3	main
külapood	doc_491521502162_item	2613053	et	3	main
muud	doc_491521502162_item	2613059	et	4	main
naerab	doc_491521502162_item	2613062	et	3	main
valmistud	doc_491521502162_item	2613065	et	3	main
ajalehest	doc_491521502162_item	2613069	et	4	main
slõhtuleht	doc_491521502162_item	2613070	et	4	main
õigesse	doc_491521502162_item	2613078	et	3	main
kasutades	doc_491521502162_item	2613081	et	3	main
2	doc_491521502162_item	2613083	et	2	main
naiselikum	doc_491521502162_item	2613087	et	4	main
ja	doc_491521502162_item	2613088	et	3	main
mehed	doc_491521502162_item	2613089	et	3	main
mehelikum	doc_491521502162_item	2613090	et	4	main
igaüks	doc_491521502162_item	2613091	et	3	main
tekevad	doc_491521502162_item	2613096	et	4	main
ja	doc_491521502162_item	2613099	et	3	main
meie	doc_491521502162_item	2613107	et	4	main
stress	doc_491521502162_item	2613117	et	3	main
meie	doc_491521502162_item	2613119	et	4	main
tegutsema	doc_491521502162_item	2613120	et	3	main
lisakoormus	doc_491521502162_item	2613122	et	3	main
4	doc_491521502162_item	2613127	et	2	main
laskma	doc_491521502162_item	2613130	et	3	main
pinge	doc_491521502162_item	2613133	et	4	main
maandama	doc_491521502162_item	2613135	et	3	main
tekkida	doc_491521502162_item	2613143	et	3	main
ega	doc_491521502161_item	2612814	et	3	main
jääd	doc_491521502161_item	2612832	et	4	main
linna	doc_491521502161_item	2612833	et	4	main
10	doc_491521502161_item	2612834	et	2	main
avasin	doc_491521502161_item	2612835	et	3	main
ukse	doc_491521502161_item	2612836	et	3	main
eesti	doc_491521502162_item	2612840	et	4	main
test	doc_491521502162_item	2612842	et	3	main
test	doc_491521502162_item	2612845	et	3	main
vormi	doc_491521502162_item	2612852	et	4	main
piret	doc_491521502162_item	2612853	et	4	main
nägi	doc_491521502162_item	2612860	et	3	main
ja	doc_491521502162_item	2612878	et	3	main
emakeelt	doc_491521502162_item	2612889	et	4	main
õpetama	doc_491521502162_item	2612890	et	3	main
õpetamas	doc_491521502162_item	2612891	et	3	main
üllatuma	doc_491521502162_item	2612904	et	3	main
mulle	doc_491521502162_item	2612907	et	4	main
seal	doc_491521502162_item	2612921	et	4	main
tahtmine	doc_491521502162_item	2612932	et	4	main
täis	doc_491521502162_item	2612933	et	4	main
koht	doc_491521502162_item	2612938	et	3	main
veel	doc_491521502162_item	2612943	et	4	main
alatud	doc_491521502162_item	2612945	et	4	main
kogu	doc_491521502162_item	2612946	et	4	main
on	doc_491521502162_item	2612952	et	4	main
sügisel	doc_491521502162_item	2612954	et	3	main
tähtis	doc_491521502162_item	2612956	et	4	main
kartul	doc_491521502162_item	2612960	et	3	main
täie	doc_491521502162_item	2612965	et	3	main
räägivad	doc_491521502162_item	2612969	et	3	main
ja	doc_491521502162_item	2612973	et	3	main
siiski	doc_491521502162_item	2612985	et	4	main
ülejäänud	doc_491521502162_item	2612989	et	4	main
vene	doc_491521502162_item	2612993	et	4	main
piret	doc_491521502162_item	2613022	et	4	main
päevad	doc_491521502162_item	2613034	et	3	main
soe	doc_491521502162_item	2613036	et	4	main
soojad	doc_491521502162_item	2613037	et	3	main
kuid	doc_491521502162_item	2613038	et	4	main
suure	doc_491521502162_item	2613045	et	3	main
kütmisest	doc_491521502162_item	2613049	et	4	main
müüdagi	doc_491521502162_item	2613061	et	3	main
iii	doc_491521502162_item	2613071	et	4	main
moodustage	doc_491521502162_item	2613072	et	3	main
naised	doc_491521502162_item	2613086	et	3	main
mehed	doc_491521502162_item	2613100	et	3	main
aga	doc_491521502162_item	2613109	et	3	main
võima	doc_491521502162_item	2613111	et	3	main
soovimatu	doc_491521502162_item	2613113	et	4	main
tagajärg	doc_491521502162_item	2613114	et	3	main
paras	doc_491521502162_item	2613115	et	3	main
paneb	doc_491521502162_item	2613118	et	3	main
kuulsin	doc_491521502161_item	2612838	et	3	main
sulgudes	doc_491521502162_item	2612848	et	4	main
olevad	doc_491521502162_item	2612849	et	4	main
on	doc_491521502162_item	2612855	et	4	main
ettevõtlik	doc_491521502162_item	2612856	et	3	main
suvel	doc_491521502162_item	2612858	et	3	main
ta	doc_491521502162_item	2612861	et	4	main
ajalehes	doc_491521502162_item	2612862	et	3	main
kuulutus	doc_491521502162_item	2612863	et	4	main
kuulutust	doc_491521502162_item	2612864	et	4	main
et	doc_491521502162_item	2612865	et	3	main
siberisse	doc_491521502162_item	2612866	et	4	main
küla	doc_491521502162_item	2612868	et	4	main
külas	doc_491521502162_item	2612869	et	3	main
ülem-suetuki	doc_491521502162_item	2612867	et	4	main
otsitakse	doc_491521502162_item	2612870	et	3	main
eesti	doc_491521502162_item	2612871	et	4	main
keele	doc_491521502162_item	2612872	et	4	main
õpetajat	doc_491521502162_item	2612873	et	4	main
piret	doc_491521502162_item	2612874	et	4	main
võitis	doc_491521502162_item	2612875	et	3	main
väikestele	doc_491521502162_item	2612885	et	4	main
kinnitusel	doc_491521502162_item	2612893	et	4	main
tundis	doc_491521502162_item	2612894	et	3	main
tulema	doc_491521502162_item	2612908	et	4	main
korraliku	doc_491521502162_item	2612912	et	3	main
õppeaasta	doc_491521502162_item	2612936	et	4	main
jõudis	doc_491521502162_item	2612940	et	3	main
kool	doc_491521502162_item	2612942	et	4	main
kõige	doc_491521502162_item	2612955	et	4	main
ettevõtmine	doc_491521502162_item	2612957	et	3	main
mõnus	doc_491521502162_item	2612972	et	4	main
aktsent	doc_491521502162_item	2612977	et	3	main
murret	doc_491521502162_item	2612982	et	4	main
venemaa	doc_491521502162_item	2612986	et	4	main
õpetatakse	doc_491521502162_item	2612992	et	3	main
üle	doc_491521502162_item	2612998	et	3	main
kolmsada	doc_491521502162_item	2612999	et	4	main
inimene	doc_491521502162_item	2613000	et	3	main
inimest	doc_491521502162_item	2613001	et	3	main
emakeelt	doc_491521502162_item	2613002	et	4	main
saab	doc_491521502162_item	2613003	et	3	main
kõik	doc_491521502162_item	2613004	et	4	main
kõike	doc_491521502162_item	2613005	et	4	main
rääkida	doc_491521502162_item	2613006	et	3	main
pireti	doc_491521502162_item	2613007	et	4	main
sõnul	doc_491521502162_item	2613008	et	3	main
õpivad	doc_491521502162_item	2613009	et	3	main
lapsed	doc_491521502162_item	2613010	et	3	main
poolpõlenud	doc_491521502162_item	2613011	et	4	main
raamatud	doc_491521502162_item	2613012	et	4	main
raamatuid	doc_491521502162_item	2613013	et	3	main
varsti	doc_491521502162_item	2613014	et	3	main
saatma	doc_491521502162_item	2613015	et	3	main
saadatakse	doc_491521502162_item	2613016	et	3	main
eestist	doc_491521502162_item	2613017	et	3	main
uued	doc_491521502162_item	2613018	et	3	main
õpikud	doc_491521502162_item	2613019	et	3	main
siberi	doc_491521502162_item	2613020	et	4	main
salv	doc_491521502162_item	2612961	et	3	main
õppimine	doc_491521502162_item	2612963	et	4	main
käib	doc_491521502162_item	2612964	et	3	main
siinsed	doc_491521502162_item	2612967	et	3	main
eestlased	doc_491521502162_item	2612968	et	3	main
mitte	doc_491521502162_item	2612975	et	3	main
aktsendiga	doc_491521502162_item	2612978	et	3	main
vaid	doc_491521502162_item	2612979	et	3	main
nagu	doc_491521502162_item	2612980	et	3	main
ja	doc_491521502162_item	2612988	et	3	main
keeles	doc_491521502162_item	2612994	et	4	main
elab	doc_491521502162_item	2612996	et	3	main
ei	doc_491521502162_item	2613023	et	4	main
karda	doc_491521502162_item	2613026	et	4	main
tooti	doc_491521502162_item	2613030	et	4	main
juba	doc_491521502162_item	2613044	et	3	main
piret	doc_491521502162_item	2613066	et	4	main
lühendatud	doc_491521502162_item	2613068	et	4	main
laused	doc_491521502162_item	2613075	et	3	main
ja	doc_491521502162_item	2613080	et	3	main
kirjavahemärke	doc_491521502162_item	2613082	et	4	main
igaüks	doc_491521502162_item	2613093	et	3	main
kaunim	doc_491521502162_item	2613094	et	4	main
naeratuse	doc_491521502162_item	2613095	et	4	main
mehelikumad	doc_491521502162_item	2613101	et	4	main
paras	doc_491521502162_item	2613103	et	3	main
stress	doc_491521502162_item	2613105	et	3	main
lisakoormus	doc_491521502162_item	2613110	et	3	main
ülekoormus	doc_491521502162_item	2613131	et	3	main
saama	doc_491521502162_item	2613134	et	4	main
pinge	doc_491521502162_item	2613144	et	4	main
spordimine	doc_491521502162_item	2613147	et	4	main
abil	doc_491521502162_item	2613160	et	4	main
elama	doc_491521502162_item	2613162	et	3	main
on	doc_491521502162_item	2613166	et	4	main
abil	doc_491521502162_item	2613174	et	4	main
elab	doc_491521502162_item	2613176	et	3	main
hingab	doc_491521502162_item	2613178	et	3	main
ja	doc_491521502162_item	2613199	et	3	main
pahandab	doc_491521502162_item	2613201	et	3	main
söömine	doc_491521502162_item	2613217	et	4	main
telesaade	doc_491521502162_item	2613220	et	4	main
iv	doc_491521502162_item	2613223	et	4	main
vanemad	doc_491521502162_item	2613236	et	4	main
kohandasin	doc_491521502162_item	2613246	et	3	main
3	doc_491521502162_item	2613250	et	2	main
ilusatele	doc_491521502162_item	2613268	et	3	main
naistele	doc_491521502162_item	2613269	et	3	main
oht	doc_491521502162_item	2613276	et	3	main
difteeriaga	doc_491521502162_item	2613279	et	3	main
tüdinesin	doc_491521502162_item	2613281	et	3	main
töökoht	doc_491521502162_item	2613283	et	3	main
6	doc_491521502162_item	2613287	et	2	main
suvist	doc_491521502162_item	2613322	et	4	main
täitke	doc_491521502162_item	2613325	et	3	main
maksis	doc_491521502162_item	2613335	et	4	main
õpetajad	doc_491521502162_item	2613342	et	4	main
3	doc_491521502162_item	2613343	et	2	main
lapsel	doc_491521502162_item	2613344	et	4	main
paluti	doc_491521502162_item	2613345	et	3	main
kostis	doc_491521502162_item	2613353	et	4	main
just	doc_491521502162_item	2613358	et	3	main
ta	doc_491521502162_item	2613362	et	4	main
maale	doc_491521502162_item	2613398	et	4	main
test	doc_491521502163_item	2613410	et	3	main
eesti	doc_491521502163_item	2613411	et	4	main
ettevõtlik	doc_491521502163_item	2613424	et	3	main
ülem-suetuki	doc_491521502163_item	2613435	et	4	main
piret	doc_491521502163_item	2613442	et	4	main
võitis	doc_491521502163_item	2613443	et	3	main
konkurss	doc_491521502163_item	2613444	et	3	main
konkursi	doc_491521502163_item	2613445	et	3	main
nendel	doc_491521502163_item	2613456	et	4	main
siberisse	doc_491521502163_item	2613464	et	4	main
jõudma	doc_491521502163_item	2613465	et	3	main
jõudis	doc_491521502163_item	2613466	et	3	main
et	doc_491521502163_item	2613467	et	3	main
tulema	doc_491521502163_item	2613476	et	4	main
vastu	doc_491521502163_item	2613478	et	3	main
audiga	doc_491521502163_item	2613481	et	3	main
siber	doc_491521502163_item	2613484	et	4	main
kartma	doc_491521502162_item	2613024	et	3	main
on	doc_491521502162_item	2613033	et	4	main
jahedad	doc_491521502162_item	2613042	et	3	main
vene	doc_491521502162_item	2613046	et	4	main
ahju	doc_491521502162_item	2613047	et	4	main
kütmine	doc_491521502162_item	2613048	et	4	main
vildid	doc_491521502162_item	2613055	et	4	main
ega	doc_491521502162_item	2613056	et	3	main
seal	doc_491521502162_item	2613057	et	4	main
suurt	doc_491521502162_item	2613058	et	3	main
etteantud	doc_491521502162_item	2613073	et	4	main
pannes	doc_491521502162_item	2613076	et	4	main
sõnad	doc_491521502162_item	2613077	et	4	main
naeratus	doc_491521502162_item	2613084	et	4	main
tegema	doc_491521502162_item	2613085	et	3	main
kogus	doc_491521502162_item	2613104	et	4	main
panema	doc_491521502162_item	2613106	et	3	main
kogus	doc_491521502162_item	2613116	et	4	main
tuua	doc_491521502162_item	2613124	et	3	main
tagajargi	doc_491521502162_item	2613126	et	4	main
tohtima	doc_491521502162_item	2613129	et	3	main
sportima	doc_491521502162_item	2613136	et	4	main
puhkama	doc_491521502162_item	2613138	et	3	main
tohi	doc_491521502162_item	2613140	et	4	main
ja	doc_491521502162_item	2613148	et	3	main
hingama	doc_491521502162_item	2613164	et	3	main
telefon	doc_491521502162_item	2613180	et	3	main
nii	doc_491521502162_item	2613182	et	3	main
see	doc_491521502162_item	2613186	et	3	main
vaatamine	doc_491521502162_item	2613204	et	4	main
aeg	doc_491521502162_item	2613205	et	3	main
kuid	doc_491521502162_item	2613206	et	4	main
telefonihelin	doc_491521502162_item	2613207	et	3	main
katkestab	doc_491521502162_item	2613208	et	3	main
ka	doc_491521502162_item	2613209	et	3	main
pühapäev	doc_491521502162_item	2613210	et	3	main
varahommikul	doc_491521502162_item	2613211	et	3	main
uni	doc_491521502162_item	2613212	et	3	main
segas	doc_491521502162_item	2613213	et	3	main
lõunasöögi	doc_491521502162_item	2613214	et	3	main
valmistamine	doc_491521502162_item	2613215	et	4	main
huvitava	doc_491521502162_item	2613219	et	4	main
sulgudes	doc_491521502162_item	2613225	et	4	main
olevad	doc_491521502162_item	2613226	et	4	main
õigesse	doc_491521502162_item	2613228	et	3	main
vormi	doc_491521502162_item	2613229	et	4	main
ma	doc_491521502162_item	2613231	et	3	main
pean	doc_491521502162_item	2613232	et	4	main
väga	doc_491521502162_item	2613233	et	3	main
aitavad	doc_491521502162_item	2613239	et	4	main
igaüks	doc_491521502162_item	2613243	et	3	main
ma	doc_491521502162_item	2613251	et	3	main
sa	doc_491521502162_item	2613259	et	3	main
tunned	doc_491521502162_item	2613260	et	3	main
huvi	doc_491521502162_item	2613261	et	4	main
autodele	doc_491521502162_item	2613272	et	3	main
piirdusime	doc_491521502162_item	2613288	et	3	main
muudatusedes	doc_491521502162_item	2613295	et	4	main
küsimus	doc_491521502162_item	2613298	et	4	main
valdkond	doc_491521502162_item	2613301	et	3	main
valdkonda	doc_491521502162_item	2613303	et	4	main
päikest	doc_491521502162_item	2613323	et	4	main
v	doc_491521502162_item	2613324	et	4	main
lüngad	doc_491521502162_item	2613326	et	3	main
sobivate	doc_491521502162_item	2613327	et	4	main
sidenditega	doc_491521502162_item	2613328	et	3	main
1	doc_491521502162_item	2613329	et	2	main
palju	doc_491521502162_item	2613336	et	4	main
2	doc_491521502162_item	2613337	et	2	main
oodata	doc_491521502162_item	2613346	et	4	main
naeru	doc_491521502162_item	2613354	et	4	main
just	doc_491521502162_item	2613355	et	3	main
trenni	doc_491521502162_item	2613365	et	4	main
olnud	doc_491521502162_item	2613393	et	4	main
kas	doc_491521502162_item	2613395	et	3	main
või	doc_491521502162_item	2613399	et	4	main
linna	doc_491521502162_item	2613401	et	4	main
avasin	doc_491521502162_item	2613403	et	3	main
ukse	doc_491521502162_item	2613404	et	3	main
ja	doc_491521502162_item	2613405	et	3	main
keele	doc_491521502163_item	2613412	et	4	main
test	doc_491521502163_item	2613413	et	3	main
i	doc_491521502163_item	2613414	et	4	main
on	doc_491521502163_item	2613423	et	4	main
küla	doc_491521502163_item	2613436	et	4	main
külas	doc_491521502163_item	2613437	et	3	main
otsitakse	doc_491521502163_item	2613438	et	3	main
nüüd	doc_491521502163_item	2613448	et	4	main
ülekoormusi	doc_491521502162_item	2613142	et	4	main
puhkamine	doc_491521502162_item	2613149	et	4	main
5	doc_491521502162_item	2613150	et	2	main
telefon	doc_491521502162_item	2613151	et	3	main
olema	doc_491521502162_item	2613152	et	4	main
tänapäev	doc_491521502162_item	2613153	et	3	main
saama	doc_491521502162_item	2613154	et	4	main
nii	doc_491521502162_item	2613155	et	3	main
maagiline	doc_491521502162_item	2613156	et	4	main
aparaat	doc_491521502162_item	2613157	et	3	main
saab	doc_491521502162_item	2613145	et	3	main
et	doc_491521502162_item	2613158	et	3	main
ja	doc_491521502162_item	2613163	et	3	main
nii	doc_491521502162_item	2613169	et	3	main
aparadiks	doc_491521502162_item	2613171	et	4	main
saab	doc_491521502162_item	2613181	et	3	main
et	doc_491521502162_item	2613185	et	3	main
kuid	doc_491521502162_item	2613189	et	4	main
pühapäev	doc_491521502162_item	2613193	et	3	main
segama	doc_491521502162_item	2613196	et	3	main
söömine	doc_491521502162_item	2613200	et	4	main
huvitav	doc_491521502162_item	2613202	et	4	main
telesaade	doc_491521502162_item	2613203	et	4	main
vaatamise	doc_491521502162_item	2613221	et	4	main
lugu	doc_491521502162_item	2613234	et	4	main
oma	doc_491521502162_item	2613235	et	4	main
ja	doc_491521502162_item	2613241	et	3	main
nõudeid	doc_491521502162_item	2613249	et	3	main
arvasin	doc_491521502162_item	2613252	et	3	main
kiired	doc_491521502162_item	2613266	et	4	main
autod	doc_491521502162_item	2613267	et	3	main
ja	doc_491521502162_item	2613270	et	3	main
praegu	doc_491521502162_item	2613274	et	3	main
difteeria	doc_491521502162_item	2613278	et	4	main
väiksedes	doc_491521502162_item	2613294	et	4	main
teine	doc_491521502162_item	2613300	et	3	main
teisele	doc_491521502162_item	2613302	et	4	main
8	doc_491521502162_item	2613304	et	2	main
närimiskumm	doc_491521502162_item	2613305	et	3	main
kleepus	doc_491521502162_item	2613306	et	3	main
püksid	doc_491521502162_item	2613307	et	3	main
pükseid	doc_491521502162_item	2613308	et	4	main
see	doc_491521502162_item	2613159	et	3	main
lausa	doc_491521502162_item	2613161	et	4	main
telefon	doc_491521502162_item	2613165	et	3	main
tänapäevaks	doc_491521502162_item	2613167	et	3	main
saab	doc_491521502162_item	2613168	et	3	main
maagiliseks	doc_491521502162_item	2613170	et	4	main
et	doc_491521502162_item	2613172	et	3	main
lausa	doc_491521502162_item	2613175	et	4	main
ja	doc_491521502162_item	2613177	et	3	main
aparaadiks	doc_491521502162_item	2613184	et	3	main
abil	doc_491521502162_item	2613187	et	4	main
telefonihelin	doc_491521502162_item	2613190	et	3	main
katkestama	doc_491521502162_item	2613191	et	3	main
varahommik	doc_491521502162_item	2613194	et	3	main
valmistamine	doc_491521502162_item	2613198	et	4	main
pahandab	doc_491521502162_item	2613218	et	3	main
pange	doc_491521502162_item	2613224	et	4	main
kõik	doc_491521502162_item	2613240	et	4	main
igaüksele	doc_491521502162_item	2613244	et	3	main
nõuded	doc_491521502162_item	2613248	et	3	main
sa	doc_491521502162_item	2613254	et	3	main
sport	doc_491521502162_item	2613256	et	3	main
aga	doc_491521502162_item	2613258	et	3	main
ainult	doc_491521502162_item	2613262	et	4	main
ilusad	doc_491521502162_item	2613263	et	3	main
naised	doc_491521502162_item	2613264	et	3	main
ja	doc_491521502162_item	2613265	et	3	main
haigestuda	doc_491521502162_item	2613277	et	3	main
uus	doc_491521502162_item	2613282	et	3	main
töökohti	doc_491521502162_item	2613285	et	4	main
kiiresti	doc_491521502162_item	2613286	et	3	main
selles	doc_491521502162_item	2613289	et	4	main
küsimuses	doc_491521502162_item	2613290	et	4	main
vaid	doc_491521502162_item	2613291	et	3	main
väikesed	doc_491521502162_item	2613292	et	4	main
muudatused	doc_491521502162_item	2613293	et	3	main
see	doc_491521502162_item	2613297	et	3	main
kuulub	doc_491521502162_item	2613299	et	3	main
tellisime	doc_491521502162_item	2613330	et	4	main
kohal	doc_491521502162_item	2613338	et	4	main
kuni	doc_491521502162_item	2613347	et	3	main
vanemad	doc_491521502162_item	2613348	et	4	main
tagasi	doc_491521502162_item	2613349	et	3	main
oleks	doc_491521502162_item	2613356	et	3	main
rääkinud	doc_491521502162_item	2613360	et	4	main
eesti	doc_491521502163_item	2613408	et	4	main
naine	doc_491521502163_item	2613425	et	3	main
nägema	doc_491521502163_item	2613427	et	3	main
ta	doc_491521502163_item	2613429	et	4	main
ja	doc_491521502163_item	2613446	et	3	main
emakeelt	doc_491521502163_item	2613457	et	4	main
õpetab	doc_491521502163_item	2613459	et	3	main
üllatuma	doc_491521502163_item	2613472	et	3	main
kui	doc_491521502163_item	2613474	et	3	main
maaliti	doc_491521502163_item	2613483	et	3	main
ei	doc_491521502163_item	2613490	et	4	main
lendama	doc_491521502163_item	2613491	et	3	main
piret	doc_491521502163_item	2613502	et	4	main
õppeaasta	doc_491521502163_item	2613504	et	4	main
algust	doc_491521502163_item	2613505	et	4	main
koht	doc_491521502163_item	2613506	et	3	main
kool	doc_491521502163_item	2613510	et	4	main
algama	doc_491521502163_item	2613512	et	3	main
kogu	doc_491521502163_item	2613514	et	4	main
sügisel	doc_491521502163_item	2613522	et	3	main
kõige	doc_491521502163_item	2613523	et	4	main
salv	doc_491521502163_item	2613530	et	3	main
täie	doc_491521502163_item	2613535	et	3	main
mõnusad	doc_491521502163_item	2613545	et	3	main
mitte	doc_491521502163_item	2613548	et	3	main
venemaa	doc_491521502163_item	2613560	et	4	main
keeles	doc_491521502163_item	2613567	et	4	main
külas	doc_491521502163_item	2613568	et	3	main
elab	doc_491521502163_item	2613569	et	3	main
inimene	doc_491521502163_item	2613574	et	3	main
emakeelt	doc_491521502163_item	2613576	et	4	main
kütmine	doc_491521502163_item	2613621	et	4	main
kui	doc_491521502163_item	2613623	et	3	main
talveks	doc_491521502163_item	2613636	et	4	main
valmistatud	doc_491521502163_item	2613638	et	4	main
vapralt	doc_491521502163_item	2613640	et	4	main
aeg	doc_491521502162_item	2613222	et	3	main
sõnad	doc_491521502162_item	2613227	et	4	main
1	doc_491521502162_item	2613230	et	2	main
sest	doc_491521502162_item	2613237	et	4	main
nad	doc_491521502162_item	2613238	et	3	main
usaldavad	doc_491521502162_item	2613242	et	4	main
2	doc_491521502162_item	2613245	et	2	main
artikli	doc_491521502162_item	2613247	et	3	main
et	doc_491521502162_item	2613253	et	3	main
huvitud	doc_491521502162_item	2613255	et	4	main
spordi	doc_491521502162_item	2613257	et	4	main
kiirtele	doc_491521502162_item	2613271	et	3	main
4	doc_491521502162_item	2613273	et	2	main
on	doc_491521502162_item	2613275	et	4	main
5	doc_491521502162_item	2613280	et	2	main
uut	doc_491521502162_item	2613284	et	3	main
7	doc_491521502162_item	2613296	et	2	main
9	doc_491521502162_item	2613309	et	2	main
külmal	doc_491521502162_item	2613310	et	3	main
ajal	doc_491521502162_item	2613311	et	4	main
peab	doc_491521502162_item	2613312	et	4	main
hoiduma	doc_491521502162_item	2613313	et	3	main
külmetamine	doc_491521502162_item	2613314	et	4	main
külmetamisest	doc_491521502162_item	2613315	et	4	main
10	doc_491521502162_item	2613316	et	2	main
ma	doc_491521502162_item	2613317	et	3	main
tunnen	doc_491521502162_item	2613318	et	3	main
rõõmu	doc_491521502162_item	2613319	et	4	main
suvine	doc_491521502162_item	2613320	et	4	main
päike	doc_491521502162_item	2613321	et	3	main
olid	doc_491521502162_item	2613339	et	4	main
kui	doc_491521502162_item	2613340	et	3	main
õpilased	doc_491521502162_item	2613341	et	3	main
tulevad	doc_491521502162_item	2613350	et	4	main
4	doc_491521502162_item	2613351	et	2	main
anekdooti	doc_491521502162_item	2613359	et	4	main
5	doc_491521502162_item	2613361	et	2	main
ei	doc_491521502162_item	2613363	et	4	main
tule	doc_491521502162_item	2613364	et	4	main
hoopis	doc_491521502162_item	2613368	et	3	main
6	doc_491521502162_item	2613370	et	2	main
sa	doc_491521502162_item	2613396	et	3	main
keele	doc_491521502163_item	2613409	et	4	main
pange	doc_491521502163_item	2613415	et	4	main
olevad	doc_491521502163_item	2613417	et	4	main
sõnad	doc_491521502163_item	2613418	et	4	main
õigesse	doc_491521502163_item	2613419	et	3	main
vormi	doc_491521502163_item	2613420	et	4	main
kolmekäigulise	doc_491521502162_item	2613331	et	4	main
lõuna	doc_491521502162_item	2613332	et	4	main
aga	doc_491521502162_item	2613333	et	3	main
see	doc_491521502162_item	2613334	et	3	main
kõrvallauast	doc_491521502162_item	2613352	et	4	main
keegi	doc_491521502162_item	2613357	et	4	main
sest	doc_491521502162_item	2613366	et	4	main
läheb	doc_491521502162_item	2613367	et	3	main
teatrisse	doc_491521502162_item	2613369	et	3	main
lõpetage	doc_491521502162_item	2613371	et	3	main
töö	doc_491521502162_item	2613372	et	4	main
pärast	doc_491521502162_item	2613373	et	4	main
lähete	doc_491521502162_item	2613374	et	4	main
jalutama	doc_491521502162_item	2613375	et	3	main
7	doc_491521502162_item	2613376	et	2	main
selles	doc_491521502162_item	2613377	et	4	main
baaris	doc_491521502162_item	2613378	et	3	main
ei	doc_491521502162_item	2613379	et	4	main
tohi	doc_491521502162_item	2613380	et	4	main
suitsetada	doc_491521502162_item	2613381	et	3	main
vaid	doc_491521502162_item	2613382	et	3	main
alkoholi	doc_491521502162_item	2613383	et	4	main
tarbida	doc_491521502162_item	2613384	et	3	main
8	doc_491521502162_item	2613385	et	2	main
nad	doc_491521502162_item	2613386	et	3	main
töötasid	doc_491521502162_item	2613387	et	4	main
küll	doc_491521502162_item	2613388	et	4	main
pingsalt	doc_491521502162_item	2613389	et	4	main
et	doc_491521502162_item	2613390	et	3	main
tulemust	doc_491521502162_item	2613391	et	4	main
ei	doc_491521502162_item	2613392	et	4	main
9	doc_491521502162_item	2613394	et	2	main
sõidad	doc_491521502162_item	2613397	et	3	main
jääd	doc_491521502162_item	2613400	et	4	main
10	doc_491521502162_item	2613402	et	2	main
kuulsin	doc_491521502162_item	2613406	et	3	main
koputust	doc_491521502162_item	2613407	et	4	main
sulgudes	doc_491521502163_item	2613416	et	4	main
piret	doc_491521502163_item	2613421	et	4	main
nägi	doc_491521502163_item	2613428	et	3	main
ajalehes	doc_491521502163_item	2613430	et	3	main
kuulutus	doc_491521502163_item	2613431	et	4	main
kuulutust	doc_491521502163_item	2613432	et	4	main
et	doc_491521502163_item	2613433	et	3	main
siberisse	doc_491521502163_item	2613434	et	4	main
õpetajat	doc_491521502163_item	2613441	et	4	main
nädal	doc_491521502163_item	2613451	et	3	main
õpetama	doc_491521502163_item	2613458	et	3	main
on	doc_491521502163_item	2613468	et	4	main
mulle	doc_491521502163_item	2613475	et	4	main
tuleb	doc_491521502163_item	2613477	et	3	main
korralik	doc_491521502163_item	2613479	et	3	main
pilt	doc_491521502163_item	2613487	et	3	main
rohi	doc_491521502163_item	2613496	et	4	main
kui	doc_491521502163_item	2613497	et	3	main
ja	doc_491521502163_item	2613499	et	3	main
siin	doc_491521502163_item	2613521	et	4	main
salve	doc_491521502163_item	2613531	et	4	main
ja	doc_491521502163_item	2613532	et	3	main
hoog	doc_491521502163_item	2613536	et	3	main
kool	doc_491521502163_item	2613557	et	4	main
veidi	doc_491521502163_item	2613570	et	3	main
muud	doc_491521502163_item	2613632	et	4	main
piret	doc_491521502163_item	2613639	et	4	main
iii	doc_491521502163_item	2613644	et	4	main
kasutades	doc_491521502163_item	2613654	et	3	main
2	doc_491521502163_item	2613656	et	2	main
naiselikum	doc_491521502163_item	2613660	et	4	main
mehelikum	doc_491521502163_item	2613663	et	4	main
igaüks	doc_491521502163_item	2613664	et	3	main
ja	doc_491521502163_item	2613670	et	3	main
pinge	doc_491521502163_item	2613694	et	4	main
tohtnud	doc_491521502163_item	2613701	et	4	main
hingama	doc_491521502163_item	2613716	et	3	main
tänapäeva	doc_491521502163_item	2613719	et	4	main
söömine	doc_491521502163_item	2613736	et	4	main
pahandab	doc_491521502163_item	2613737	et	3	main
katkestab	doc_491521502163_item	2613744	et	3	main
vaatamist	doc_491521502163_item	2613757	et	4	main
olevad	doc_491521502163_item	2613762	et	4	main
1	doc_491521502163_item	2613766	et	2	main
kõik	doc_491521502163_item	2613776	et	4	main
kõiki	doc_491521502163_item	2613777	et	4	main
et	doc_491521502163_item	2613789	et	3	main
selles	doc_491521502163_item	2613824	et	4	main
vaid	doc_491521502163_item	2613826	et	3	main
muudatused	doc_491521502163_item	2613828	et	3	main
kleepus	doc_491521502163_item	2613841	et	3	main
10	doc_491521502163_item	2613851	et	2	main
lõuna	doc_491521502163_item	2613867	et	4	main
sest	doc_491521502163_item	2613893	et	4	main
oleks	doc_491521502163_item	2613894	et	3	main
keegi	doc_491521502163_item	2613895	et	4	main
töö	doc_491521502163_item	2613910	et	4	main
lähete	doc_491521502163_item	2613912	et	4	main
tarbida	doc_491521502163_item	2613922	et	3	main
linna	doc_491521502163_item	2613939	et	4	main
10	doc_491521502163_item	2613940	et	2	main
eesti	doc_491521502164_item	2613949	et	4	main
kuulutus	doc_491521502164_item	2613969	et	4	main
üle	doc_491521502164_item	2613987	et	3	main
siberi	doc_491521502164_item	2614021	et	4	main
seal	doc_491521502164_item	2614025	et	4	main
lenda	doc_491521502164_item	2614028	et	4	main
kasva	doc_491521502164_item	2614031	et	4	main
rohi	doc_491521502164_item	2614032	et	4	main
kui	doc_491521502164_item	2614033	et	3	main
noor	doc_491521502164_item	2614034	et	3	main
ja	doc_491521502164_item	2614035	et	3	main
jõudis	doc_491521502164_item	2614045	et	3	main
kogu	doc_491521502164_item	2614051	et	4	main
küla	doc_491521502164_item	2614052	et	4	main
võtma	doc_491521502164_item	2614053	et	3	main
võtab	doc_491521502164_item	2614054	et	3	main
toomet	doc_491521502163_item	2613422	et	4	main
suvel	doc_491521502163_item	2613426	et	3	main
eesti	doc_491521502163_item	2613439	et	4	main
keele	doc_491521502163_item	2613440	et	4	main
on	doc_491521502163_item	2613447	et	4	main
nädala	doc_491521502163_item	2613452	et	3	main
pireti	doc_491521502163_item	2613460	et	4	main
kinnitusel	doc_491521502163_item	2613461	et	4	main
tundis	doc_491521502163_item	2613462	et	3	main
ta	doc_491521502163_item	2613463	et	4	main
üllatud	doc_491521502163_item	2613473	et	3	main
korraliku	doc_491521502163_item	2613480	et	3	main
siberiast	doc_491521502163_item	2613485	et	3	main
selline	doc_491521502163_item	2613486	et	4	main
lenda	doc_491521502163_item	2613492	et	4	main
lind	doc_491521502163_item	2613493	et	3	main
ega	doc_491521502163_item	2613494	et	3	main
kasva	doc_491521502163_item	2613495	et	4	main
täis	doc_491521502163_item	2613501	et	4	main
jõudis	doc_491521502163_item	2613508	et	3	main
tänaseks	doc_491521502163_item	2613527	et	4	main
käib	doc_491521502163_item	2613534	et	3	main
siinsed	doc_491521502163_item	2613537	et	3	main
räägivad	doc_491521502163_item	2613539	et	3	main
ja	doc_491521502163_item	2613543	et	3	main
ja	doc_491521502163_item	2613546	et	3	main
siiski	doc_491521502163_item	2613559	et	4	main
vene	doc_491521502163_item	2613566	et	4	main
kolmsada	doc_491521502163_item	2613572	et	4	main
poolpõlenud	doc_491521502163_item	2613585	et	4	main
raamatud	doc_491521502163_item	2613586	et	4	main
raamatuid	doc_491521502163_item	2613587	et	3	main
varsti	doc_491521502163_item	2613588	et	3	main
saatma	doc_491521502163_item	2613589	et	3	main
saadavad	doc_491521502163_item	2613590	et	4	main
eestist	doc_491521502163_item	2613591	et	3	main
ostan	doc_491521502163_item	2613625	et	3	main
külapoes	doc_491521502163_item	2613627	et	3	main
ega	doc_491521502163_item	2613629	et	3	main
müüdagi	doc_491521502163_item	2613634	et	3	main
valmistuma	doc_491521502163_item	2613637	et	3	main
õigesse	doc_491521502163_item	2613651	et	3	main
naeratus	doc_491521502163_item	2613657	et	4	main
tegema	doc_491521502163_item	2613658	et	3	main
kaunivad	doc_491521502163_item	2613674	et	4	main
telefon	doc_491521502163_item	2613703	et	3	main
nii	doc_491521502163_item	2613707	et	3	main
see	doc_491521502163_item	2613711	et	3	main
oli	doc_491521502163_item	2613718	et	3	main
saamas	doc_491521502163_item	2613720	et	4	main
ja	doc_491521502163_item	2613735	et	3	main
kuid	doc_491521502163_item	2613742	et	4	main
telefonihelin	doc_491521502163_item	2613743	et	3	main
aega	doc_491521502163_item	2613758	et	4	main
sõnad	doc_491521502163_item	2613763	et	4	main
sest	doc_491521502163_item	2613773	et	4	main
igaühe	doc_491521502163_item	2613781	et	4	main
artikli	doc_491521502163_item	2613784	et	3	main
3	doc_491521502163_item	2613786	et	2	main
arvasin	doc_491521502163_item	2613788	et	3	main
6	doc_491521502163_item	2613822	et	2	main
valdkond	doc_491521502163_item	2613836	et	3	main
teises	doc_491521502163_item	2613837	et	4	main
valdkonnas	doc_491521502163_item	2613838	et	4	main
8	doc_491521502163_item	2613839	et	2	main
närimiskumm	doc_491521502163_item	2613840	et	3	main
9	doc_491521502163_item	2613844	et	2	main
külmetamine	doc_491521502163_item	2613849	et	4	main
sobivate	doc_491521502163_item	2613862	et	4	main
sidenditega	doc_491521502163_item	2613863	et	3	main
tulevad	doc_491521502163_item	2613888	et	4	main
4	doc_491521502163_item	2613889	et	2	main
rääkinud	doc_491521502163_item	2613898	et	4	main
sest	doc_491521502163_item	2613904	et	4	main
6	doc_491521502163_item	2613908	et	2	main
töötasid	doc_491521502163_item	2613925	et	4	main
9	doc_491521502163_item	2613932	et	2	main
kas	doc_491521502163_item	2613933	et	3	main
sa	doc_491521502163_item	2613934	et	3	main
sõidad	doc_491521502163_item	2613935	et	3	main
maale	doc_491521502163_item	2613936	et	4	main
või	doc_491521502163_item	2613937	et	4	main
jääd	doc_491521502163_item	2613938	et	4	main
eesti	doc_491521502164_item	2613946	et	4	main
keele	doc_491521502164_item	2613947	et	4	main
test	doc_491521502164_item	2613948	et	3	main
juba	doc_491521502163_item	2613449	et	3	main
üle	doc_491521502163_item	2613450	et	3	main
väikestele	doc_491521502163_item	2613453	et	4	main
eestlastele	doc_491521502163_item	2613454	et	4	main
need	doc_491521502163_item	2613455	et	3	main
oodatud	doc_491521502163_item	2613469	et	4	main
olin	doc_491521502163_item	2613470	et	3	main
üsna	doc_491521502163_item	2613471	et	3	main
mulle	doc_491521502163_item	2613482	et	4	main
et	doc_491521502163_item	2613488	et	3	main
seal	doc_491521502163_item	2613489	et	4	main
noor	doc_491521502163_item	2613498	et	3	main
kohases	doc_491521502163_item	2613507	et	4	main
tähtis	doc_491521502163_item	2613524	et	4	main
tähtsam	doc_491521502163_item	2613525	et	4	main
ettevõtmine	doc_491521502163_item	2613526	et	3	main
õppimine	doc_491521502163_item	2613533	et	4	main
eestlased	doc_491521502163_item	2613538	et	3	main
kuidagi	doc_491521502163_item	2613540	et	3	main
mõnus	doc_491521502163_item	2613542	et	4	main
on	doc_491521502163_item	2613558	et	4	main
aine	doc_491521502163_item	2613564	et	4	main
õpetatakse	doc_491521502163_item	2613565	et	3	main
kolmesaja	doc_491521502163_item	2613573	et	4	main
inimest	doc_491521502163_item	2613575	et	3	main
kõik	doc_491521502163_item	2613578	et	4	main
tahtmine	doc_491521502163_item	2613500	et	4	main
pärast	doc_491521502163_item	2613503	et	4	main
polnud	doc_491521502163_item	2613509	et	3	main
veel	doc_491521502163_item	2613511	et	4	main
algab	doc_491521502163_item	2613513	et	3	main
küla	doc_491521502163_item	2613515	et	4	main
võtma	doc_491521502163_item	2613516	et	3	main
võtmed	doc_491521502163_item	2613517	et	3	main
kartuleid	doc_491521502163_item	2613518	et	3	main
kartulivõtt	doc_491521502163_item	2613519	et	3	main
on	doc_491521502163_item	2613520	et	4	main
on	doc_491521502163_item	2613528	et	4	main
kartul	doc_491521502163_item	2613529	et	3	main
teistmoodi	doc_491521502163_item	2613541	et	3	main
mahlakas	doc_491521502163_item	2613544	et	4	main
mahlakad	doc_491521502163_item	2613547	et	3	main
vene	doc_491521502163_item	2613549	et	4	main
aktsent	doc_491521502163_item	2613550	et	3	main
aksendi	doc_491521502163_item	2613551	et	4	main
vaid	doc_491521502163_item	2613552	et	3	main
nagu	doc_491521502163_item	2613553	et	3	main
mõni	doc_491521502163_item	2613554	et	3	main
mõned	doc_491521502163_item	2613555	et	3	main
murret	doc_491521502163_item	2613556	et	4	main
kool	doc_491521502163_item	2613561	et	4	main
ja	doc_491521502163_item	2613562	et	3	main
ülejäänud	doc_491521502163_item	2613563	et	4	main
üle	doc_491521502163_item	2613571	et	3	main
saab	doc_491521502163_item	2613577	et	3	main
kõigi	doc_491521502163_item	2613579	et	4	main
rääkida	doc_491521502163_item	2613580	et	3	main
pireti	doc_491521502163_item	2613581	et	4	main
sõnul	doc_491521502163_item	2613582	et	3	main
õpivad	doc_491521502163_item	2613583	et	3	main
lapsed	doc_491521502163_item	2613584	et	3	main
uued	doc_491521502163_item	2613592	et	3	main
õpikud	doc_491521502163_item	2613593	et	3	main
siberi	doc_491521502163_item	2613594	et	4	main
talve	doc_491521502163_item	2613595	et	4	main
piret	doc_491521502163_item	2613596	et	4	main
ei	doc_491521502163_item	2613597	et	4	main
kartma	doc_491521502163_item	2613598	et	3	main
karda	doc_491521502163_item	2613599	et	4	main
mulle	doc_491521502163_item	2613600	et	4	main
juba	doc_491521502163_item	2613601	et	3	main
tooma	doc_491521502163_item	2613602	et	3	main
tõime	doc_491521502163_item	2613603	et	3	main
talvepuud	doc_491521502163_item	2613604	et	4	main
praegu	doc_491521502163_item	2613605	et	3	main
on	doc_491521502163_item	2613606	et	4	main
päevad	doc_491521502163_item	2613607	et	3	main
veel	doc_491521502163_item	2613608	et	4	main
soe	doc_491521502163_item	2613609	et	4	main
soojad	doc_491521502163_item	2613610	et	3	main
kuid	doc_491521502163_item	2613611	et	4	main
ööd	doc_491521502163_item	2613612	et	4	main
juba	doc_491521502163_item	2613613	et	3	main
jahe	doc_491521502163_item	2613614	et	3	main
jahedad	doc_491521502163_item	2613615	et	3	main
harjutan	doc_491521502163_item	2613616	et	3	main
juba	doc_491521502163_item	2613617	et	3	main
suure	doc_491521502163_item	2613618	et	3	main
vene	doc_491521502163_item	2613619	et	4	main
ahju	doc_491521502163_item	2613620	et	4	main
kütmima	doc_491521502163_item	2613622	et	4	main
vildid	doc_491521502163_item	2613628	et	4	main
seal	doc_491521502163_item	2613630	et	4	main
suurt	doc_491521502163_item	2613631	et	3	main
naerab	doc_491521502163_item	2613635	et	3	main
ajalehest	doc_491521502163_item	2613642	et	4	main
slõhtuleht	doc_491521502163_item	2613643	et	4	main
moodustage	doc_491521502163_item	2613645	et	3	main
etteantud	doc_491521502163_item	2613646	et	4	main
sõnadest	doc_491521502163_item	2613647	et	3	main
laused	doc_491521502163_item	2613648	et	3	main
pannes	doc_491521502163_item	2613649	et	4	main
ja	doc_491521502163_item	2613653	et	3	main
kirjavahemärke	doc_491521502163_item	2613655	et	4	main
naised	doc_491521502163_item	2613659	et	3	main
ja	doc_491521502163_item	2613661	et	3	main
mehed	doc_491521502163_item	2613662	et	3	main
naiselikum	doc_491521502163_item	2613669	et	4	main
igaühed	doc_491521502163_item	2613673	et	3	main
paras	doc_491521502163_item	2613676	et	3	main
kogus	doc_491521502163_item	2613677	et	4	main
stress	doc_491521502163_item	2613678	et	3	main
panema	doc_491521502163_item	2613679	et	3	main
meie	doc_491521502163_item	2613680	et	4	main
tegutsema	doc_491521502163_item	2613681	et	3	main
aga	doc_491521502163_item	2613682	et	3	main
lisakoormus	doc_491521502163_item	2613683	et	3	main
võima	doc_491521502163_item	2613684	et	3	main
tooma	doc_491521502163_item	2613685	et	3	main
tagajärg	doc_491521502163_item	2613687	et	3	main
soovimatu	doc_491521502163_item	2613686	et	4	main
ei	doc_491521502163_item	2613689	et	4	main
4	doc_491521502163_item	2613688	et	2	main
tohtima	doc_491521502163_item	2613690	et	3	main
laskma	doc_491521502163_item	2613691	et	3	main
ülekoormus	doc_491521502163_item	2613692	et	3	main
vaja	doc_491521502163_item	2613624	et	4	main
külapood	doc_491521502163_item	2613626	et	3	main
ei	doc_491521502163_item	2613633	et	4	main
sõnad	doc_491521502163_item	2613650	et	4	main
kaunim	doc_491521502163_item	2613665	et	4	main
mehed	doc_491521502163_item	2613671	et	3	main
tekkima	doc_491521502163_item	2613693	et	3	main
saama	doc_491521502163_item	2613695	et	4	main
sportima	doc_491521502163_item	2613697	et	4	main
ja	doc_491521502163_item	2613698	et	3	main
puhkama	doc_491521502163_item	2613699	et	3	main
ei	doc_491521502163_item	2613700	et	4	main
olema	doc_491521502163_item	2613704	et	4	main
saama	doc_491521502163_item	2613706	et	4	main
abil	doc_491521502163_item	2613712	et	4	main
lausa	doc_491521502163_item	2613713	et	4	main
elama	doc_491521502163_item	2613714	et	3	main
maagiline	doc_491521502163_item	2613722	et	4	main
varahommik	doc_491521502163_item	2613730	et	3	main
uni	doc_491521502163_item	2613731	et	3	main
vaatamine	doc_491521502163_item	2613740	et	4	main
aeg	doc_491521502163_item	2613741	et	3	main
ka	doc_491521502163_item	2613745	et	3	main
pühapäeval	doc_491521502163_item	2613746	et	3	main
uni	doc_491521502163_item	2613748	et	3	main
lõunasööki	doc_491521502163_item	2613750	et	4	main
iv	doc_491521502163_item	2613759	et	4	main
pange	doc_491521502163_item	2613760	et	4	main
ma	doc_491521502163_item	2613767	et	3	main
väga	doc_491521502163_item	2613769	et	3	main
lugu	doc_491521502163_item	2613770	et	4	main
oma	doc_491521502163_item	2613771	et	4	main
nõuded	doc_491521502163_item	2613785	et	3	main
ma	doc_491521502163_item	2613787	et	3	main
lühendatud	doc_491521502163_item	2613641	et	4	main
vormi	doc_491521502163_item	2613652	et	4	main
naerad	doc_491521502163_item	2613666	et	3	main
tegi	doc_491521502163_item	2613667	et	4	main
naised	doc_491521502163_item	2613668	et	3	main
mehelikum	doc_491521502163_item	2613672	et	4	main
3	doc_491521502163_item	2613675	et	2	main
5	doc_491521502163_item	2613702	et	2	main
maagiline	doc_491521502163_item	2613708	et	4	main
aparaat	doc_491521502163_item	2613709	et	3	main
et	doc_491521502163_item	2613710	et	3	main
telefon	doc_491521502163_item	2613717	et	3	main
maandama	doc_491521502163_item	2613696	et	3	main
tänapäev	doc_491521502163_item	2613705	et	3	main
ja	doc_491521502163_item	2613715	et	3	main
nii	doc_491521502163_item	2613721	et	3	main
6	doc_491521502163_item	2613724	et	2	main
kuid	doc_491521502163_item	2613725	et	4	main
telefonihelin	doc_491521502163_item	2613726	et	3	main
katkestama	doc_491521502163_item	2613727	et	3	main
ka	doc_491521502163_item	2613728	et	3	main
pühapäev	doc_491521502163_item	2613729	et	3	main
segama	doc_491521502163_item	2613732	et	3	main
lõunasöök	doc_491521502163_item	2613733	et	3	main
valmistamine	doc_491521502163_item	2613734	et	4	main
telesaade	doc_491521502163_item	2613756	et	4	main
sulgudes	doc_491521502163_item	2613761	et	4	main
vormi	doc_491521502163_item	2613765	et	4	main
nad	doc_491521502163_item	2613774	et	3	main
aitavad	doc_491521502163_item	2613775	et	4	main
2	doc_491521502163_item	2613782	et	2	main
kohandasin	doc_491521502163_item	2613783	et	3	main
küsimus	doc_491521502163_item	2613833	et	4	main
kuulub	doc_491521502163_item	2613834	et	3	main
teine	doc_491521502163_item	2613835	et	3	main
ajal	doc_491521502163_item	2613846	et	4	main
peab	doc_491521502163_item	2613847	et	4	main
hoiduma	doc_491521502163_item	2613848	et	3	main
ma	doc_491521502163_item	2613852	et	3	main
tunnen	doc_491521502163_item	2613853	et	3	main
suvine	doc_491521502163_item	2613855	et	4	main
päikest	doc_491521502163_item	2613858	et	4	main
v	doc_491521502163_item	2613859	et	4	main
täitke	doc_491521502163_item	2613860	et	3	main
lüngad	doc_491521502163_item	2613861	et	3	main
kolmekäigulise	doc_491521502163_item	2613866	et	4	main
kõrvallauast	doc_491521502163_item	2613890	et	4	main
naeru	doc_491521502163_item	2613892	et	4	main
just	doc_491521502163_item	2613896	et	3	main
anekdooti	doc_491521502163_item	2613897	et	4	main
tule	doc_491521502163_item	2613902	et	4	main
trenni	doc_491521502163_item	2613903	et	4	main
7	doc_491521502163_item	2613914	et	2	main
baaris	doc_491521502163_item	2613916	et	3	main
alkoholi	doc_491521502163_item	2613921	et	4	main
ei	doc_491521502163_item	2613930	et	4	main
olnud	doc_491521502163_item	2613931	et	4	main
avasin	doc_491521502163_item	2613941	et	3	main
sest	doc_491521502163_item	2613943	et	4	main
i	doc_491521502164_item	2613952	et	4	main
olevad	doc_491521502164_item	2613955	et	4	main
õpetajat	doc_491521502164_item	2613978	et	4	main
piret	doc_491521502164_item	2613979	et	4	main
võitis	doc_491521502164_item	2613980	et	3	main
konkurss	doc_491521502164_item	2613981	et	3	main
konkurssi	doc_491521502164_item	2613982	et	4	main
ja	doc_491521502164_item	2613983	et	3	main
on	doc_491521502164_item	2613984	et	4	main
nädala	doc_491521502164_item	2613989	et	3	main
aparat	doc_491521502163_item	2613723	et	4	main
huvitav	doc_491521502163_item	2613738	et	4	main
telesaade	doc_491521502163_item	2613739	et	4	main
varahommikul	doc_491521502163_item	2613747	et	3	main
segab	doc_491521502163_item	2613749	et	3	main
valmistada	doc_491521502163_item	2613751	et	3	main
ja	doc_491521502163_item	2613752	et	3	main
söömine	doc_491521502163_item	2613753	et	4	main
pahandab	doc_491521502163_item	2613754	et	3	main
huvitava	doc_491521502163_item	2613755	et	4	main
õigesse	doc_491521502163_item	2613764	et	3	main
pean	doc_491521502163_item	2613768	et	4	main
vanemad	doc_491521502163_item	2613772	et	4	main
ja	doc_491521502163_item	2613778	et	3	main
usaldavad	doc_491521502163_item	2613779	et	4	main
igaüks	doc_491521502163_item	2613780	et	3	main
sa	doc_491521502163_item	2613790	et	3	main
huvitud	doc_491521502163_item	2613791	et	4	main
sport	doc_491521502163_item	2613792	et	3	main
sporti	doc_491521502163_item	2613793	et	4	main
aga	doc_491521502163_item	2613794	et	3	main
sa	doc_491521502163_item	2613795	et	3	main
tunned	doc_491521502163_item	2613796	et	3	main
huvi	doc_491521502163_item	2613797	et	4	main
ainult	doc_491521502163_item	2613798	et	4	main
ilusad	doc_491521502163_item	2613799	et	3	main
naised	doc_491521502163_item	2613800	et	3	main
ja	doc_491521502163_item	2613801	et	3	main
kiired	doc_491521502163_item	2613802	et	4	main
autod	doc_491521502163_item	2613803	et	3	main
ilusast	doc_491521502163_item	2613804	et	3	main
naisest	doc_491521502163_item	2613805	et	3	main
kiirest	doc_491521502163_item	2613806	et	4	main
autost	doc_491521502163_item	2613807	et	3	main
4	doc_491521502163_item	2613808	et	2	main
praegu	doc_491521502163_item	2613809	et	3	main
on	doc_491521502163_item	2613810	et	4	main
oht	doc_491521502163_item	2613811	et	3	main
haigestuda	doc_491521502163_item	2613812	et	3	main
difteeria	doc_491521502163_item	2613813	et	4	main
5	doc_491521502163_item	2613815	et	2	main
difteriat	doc_491521502163_item	2613814	et	4	main
tüdinesin	doc_491521502163_item	2613816	et	3	main
uus	doc_491521502163_item	2613817	et	3	main
töökoht	doc_491521502163_item	2613818	et	3	main
uus	doc_491521502163_item	2613819	et	3	main
töökoht	doc_491521502163_item	2613820	et	3	main
kiiresti	doc_491521502163_item	2613821	et	3	main
küsimuses	doc_491521502163_item	2613825	et	4	main
väikesed	doc_491521502163_item	2613827	et	4	main
piirdusime	doc_491521502163_item	2613823	et	3	main
väike	doc_491521502163_item	2613829	et	4	main
muudatus	doc_491521502163_item	2613830	et	4	main
7	doc_491521502163_item	2613831	et	2	main
see	doc_491521502163_item	2613832	et	3	main
püksid	doc_491521502163_item	2613842	et	3	main
külmal	doc_491521502163_item	2613845	et	3	main
külmetama	doc_491521502163_item	2613850	et	3	main
rõõmu	doc_491521502163_item	2613854	et	4	main
päike	doc_491521502163_item	2613856	et	3	main
1	doc_491521502163_item	2613864	et	2	main
see	doc_491521502163_item	2613869	et	3	main
maksis	doc_491521502163_item	2613870	et	4	main
palju	doc_491521502163_item	2613871	et	4	main
2	doc_491521502163_item	2613872	et	2	main
kohal	doc_491521502163_item	2613873	et	4	main
olid	doc_491521502163_item	2613874	et	4	main
palju	doc_491521502163_item	2613875	et	4	main
õpilased	doc_491521502163_item	2613876	et	3	main
ja	doc_491521502163_item	2613877	et	3	main
vähe	doc_491521502163_item	2613878	et	3	main
õpetajad	doc_491521502163_item	2613879	et	4	main
kuid-ehk	doc_491521502163_item	2613880	et	3	main
3	doc_491521502163_item	2613881	et	2	main
lapsel	doc_491521502163_item	2613882	et	4	main
paluti	doc_491521502163_item	2613883	et	3	main
oodata	doc_491521502163_item	2613884	et	4	main
sest	doc_491521502163_item	2613885	et	4	main
vanemad	doc_491521502163_item	2613886	et	4	main
tagasi	doc_491521502163_item	2613887	et	3	main
püksist	doc_491521502163_item	2613843	et	3	main
suvest	doc_491521502163_item	2613857	et	3	main
tellisime	doc_491521502163_item	2613865	et	4	main
aga	doc_491521502163_item	2613868	et	3	main
kostis	doc_491521502163_item	2613891	et	4	main
5	doc_491521502163_item	2613899	et	2	main
ta	doc_491521502163_item	2613900	et	4	main
läheb	doc_491521502163_item	2613905	et	3	main
hoopis	doc_491521502163_item	2613906	et	3	main
teatrisse	doc_491521502163_item	2613907	et	3	main
nad	doc_491521502163_item	2613924	et	3	main
küll	doc_491521502163_item	2613926	et	4	main
ukse	doc_491521502163_item	2613942	et	3	main
kuulsin	doc_491521502163_item	2613944	et	3	main
keele	doc_491521502164_item	2613950	et	4	main
sulgudes	doc_491521502164_item	2613954	et	4	main
sõnad	doc_491521502164_item	2613956	et	4	main
õigesse	doc_491521502164_item	2613957	et	3	main
vormi	doc_491521502164_item	2613958	et	4	main
ajalehes	doc_491521502164_item	2613968	et	3	main
ülem-suetuki	doc_491521502164_item	2613972	et	4	main
külas	doc_491521502164_item	2613974	et	3	main
otsitakse	doc_491521502164_item	2613975	et	3	main
lendama	doc_491521502164_item	2614027	et	3	main
lind	doc_491521502164_item	2614029	et	3	main
tahtmise	doc_491521502164_item	2614037	et	4	main
algust	doc_491521502164_item	2614042	et	4	main
koht	doc_491521502164_item	2614043	et	3	main
kohta	doc_491521502164_item	2614044	et	4	main
sügisel	doc_491521502164_item	2614059	et	3	main
tänaseks	doc_491521502164_item	2614064	et	4	main
salves	doc_491521502164_item	2614068	et	4	main
ja	doc_491521502164_item	2614080	et	3	main
kool	doc_491521502164_item	2614094	et	4	main
ülejäänud	doc_491521502164_item	2614100	et	4	main
saab	doc_491521502164_item	2614115	et	3	main
kõik	doc_491521502164_item	2614116	et	4	main
rääkida	doc_491521502164_item	2614117	et	3	main
piret	doc_491521502164_item	2614132	et	4	main
toodi	doc_491521502164_item	2614139	et	4	main
päevad	doc_491521502164_item	2614143	et	3	main
ahju	doc_491521502164_item	2614156	et	4	main
kui	doc_491521502164_item	2614159	et	3	main
vapralt	doc_491521502164_item	2614176	et	4	main
vormi	doc_491521502164_item	2614188	et	4	main
ja	doc_491521502164_item	2614189	et	3	main
naiselikum	doc_491521502164_item	2614196	et	4	main
soovimatu	doc_491521502164_item	2614222	et	4	main
meie	doc_491521502164_item	2614228	et	4	main
aga	doc_491521502164_item	2614230	et	3	main
võib	doc_491521502164_item	2614232	et	3	main
soovimatu	doc_491521502164_item	2614234	et	4	main
tagajärgi	doc_491521502164_item	2614235	et	4	main
4	doc_491521502164_item	2614236	et	2	main
ei	doc_491521502164_item	2614237	et	4	main
tohtima	doc_491521502164_item	2614238	et	3	main
laskma	doc_491521502164_item	2614239	et	3	main
ülekoormus	doc_491521502164_item	2614240	et	3	main
tekkima	doc_491521502164_item	2614241	et	3	main
tänapäev	doc_491521502164_item	2614251	et	3	main
maagiline	doc_491521502164_item	2614254	et	4	main
see	doc_491521502164_item	2614257	et	3	main
abil	doc_491521502164_item	2614258	et	4	main
lausa	doc_491521502164_item	2614259	et	4	main
elama	doc_491521502164_item	2614260	et	3	main
ja	doc_491521502164_item	2614261	et	3	main
hingama	doc_491521502164_item	2614262	et	3	main
tänapäeval	doc_491521502164_item	2614263	et	3	main
telefon	doc_491521502164_item	2614264	et	3	main
aparaat	doc_491521502164_item	2614268	et	3	main
abil	doc_491521502164_item	2614271	et	4	main
6	doc_491521502164_item	2614276	et	2	main
kuid	doc_491521502164_item	2614277	et	4	main
telefonihelin	doc_491521502164_item	2614278	et	3	main
katkestama	doc_491521502164_item	2614279	et	3	main
ka	doc_491521502164_item	2614280	et	3	main
uni	doc_491521502164_item	2614283	et	3	main
kuid	doc_491521502164_item	2614294	et	4	main
katkestab	doc_491521502164_item	2614296	et	3	main
söömist	doc_491521502164_item	2614305	et	4	main
telesaade	doc_491521502164_item	2614308	et	4	main
ei	doc_491521502163_item	2613901	et	4	main
lõpetage	doc_491521502163_item	2613909	et	3	main
siis	doc_491521502163_item	2613911	et	3	main
jalutama	doc_491521502163_item	2613913	et	3	main
selles	doc_491521502163_item	2613915	et	4	main
ei	doc_491521502163_item	2613917	et	4	main
tohi	doc_491521502163_item	2613918	et	4	main
suitsetada	doc_491521502163_item	2613919	et	3	main
ega	doc_491521502163_item	2613920	et	3	main
8	doc_491521502163_item	2613923	et	2	main
pingsalt	doc_491521502163_item	2613927	et	4	main
sest	doc_491521502163_item	2613928	et	4	main
tulemust	doc_491521502163_item	2613929	et	4	main
koputust	doc_491521502163_item	2613945	et	4	main
test	doc_491521502164_item	2613951	et	3	main
piret	doc_491521502164_item	2613959	et	4	main
et	doc_491521502164_item	2613970	et	3	main
küla	doc_491521502164_item	2613973	et	4	main
nädal	doc_491521502164_item	2613988	et	3	main
eestlastele	doc_491521502164_item	2613991	et	4	main
need	doc_491521502164_item	2613992	et	3	main
nende	doc_491521502164_item	2613993	et	4	main
emakeelt	doc_491521502164_item	2613994	et	4	main
õpetama	doc_491521502164_item	2613995	et	3	main
õpetab	doc_491521502164_item	2613996	et	3	main
pireti	doc_491521502164_item	2613997	et	4	main
kinnitusel	doc_491521502164_item	2613998	et	4	main
tundis	doc_491521502164_item	2613999	et	3	main
ta	doc_491521502164_item	2614000	et	4	main
siberisse	doc_491521502164_item	2614001	et	4	main
jõudma	doc_491521502164_item	2614002	et	3	main
jõudis	doc_491521502164_item	2614003	et	3	main
et	doc_491521502164_item	2614004	et	3	main
on	doc_491521502164_item	2614005	et	4	main
oodatud	doc_491521502164_item	2614006	et	4	main
olin	doc_491521502164_item	2614007	et	3	main
üsna	doc_491521502164_item	2614008	et	3	main
üllatuma	doc_491521502164_item	2614009	et	3	main
üllatunud	doc_491521502164_item	2614010	et	4	main
kui	doc_491521502164_item	2614011	et	3	main
mulle	doc_491521502164_item	2614012	et	4	main
tulema	doc_491521502164_item	2614013	et	4	main
tuleb	doc_491521502164_item	2614014	et	3	main
vastu	doc_491521502164_item	2614015	et	3	main
korralik	doc_491521502164_item	2614016	et	3	main
audiga	doc_491521502164_item	2614017	et	3	main
mulle	doc_491521502164_item	2614018	et	4	main
maaliti	doc_491521502164_item	2614019	et	3	main
siber	doc_491521502164_item	2614020	et	4	main
selline	doc_491521502164_item	2614022	et	4	main
ei	doc_491521502164_item	2614026	et	4	main
ega	doc_491521502164_item	2614030	et	3	main
õppeaasta	doc_491521502164_item	2614041	et	4	main
siin	doc_491521502164_item	2614058	et	4	main
kõige	doc_491521502164_item	2614060	et	4	main
tähtis	doc_491521502164_item	2614061	et	4	main
kartul	doc_491521502164_item	2614066	et	3	main
õppimine	doc_491521502164_item	2614070	et	4	main
teistmoodi	doc_491521502164_item	2614078	et	3	main
vaid	doc_491521502164_item	2614089	et	3	main
nagu	doc_491521502164_item	2614090	et	3	main
venemaa	doc_491521502164_item	2614097	et	4	main
aine	doc_491521502164_item	2614101	et	4	main
vene	doc_491521502164_item	2614104	et	4	main
pange	doc_491521502164_item	2613953	et	4	main
toomet	doc_491521502164_item	2613960	et	4	main
on	doc_491521502164_item	2613961	et	4	main
ettevõtlik	doc_491521502164_item	2613962	et	3	main
naine	doc_491521502164_item	2613963	et	3	main
suvel	doc_491521502164_item	2613964	et	3	main
nägema	doc_491521502164_item	2613965	et	3	main
nägi	doc_491521502164_item	2613966	et	3	main
ta	doc_491521502164_item	2613967	et	4	main
siberisse	doc_491521502164_item	2613971	et	4	main
eesti	doc_491521502164_item	2613976	et	4	main
keele	doc_491521502164_item	2613977	et	4	main
nüüd	doc_491521502164_item	2613985	et	4	main
juba	doc_491521502164_item	2613986	et	3	main
väikestele	doc_491521502164_item	2613990	et	4	main
et	doc_491521502164_item	2614024	et	3	main
piret	doc_491521502164_item	2614039	et	4	main
pärast	doc_491521502164_item	2614040	et	4	main
on	doc_491521502164_item	2614065	et	4	main
salv	doc_491521502164_item	2614067	et	3	main
ja	doc_491521502164_item	2614069	et	3	main
käib	doc_491521502164_item	2614071	et	3	main
täie	doc_491521502164_item	2614072	et	3	main
hoog	doc_491521502164_item	2614073	et	3	main
siinsed	doc_491521502164_item	2614074	et	3	main
eestlased	doc_491521502164_item	2614075	et	3	main
räägivad	doc_491521502164_item	2614076	et	3	main
kuidagi	doc_491521502164_item	2614077	et	3	main
mõnusamalt	doc_491521502164_item	2614082	et	4	main
mahlakalt	doc_491521502164_item	2614084	et	4	main
on	doc_491521502164_item	2614095	et	4	main
siiski	doc_491521502164_item	2614096	et	4	main
õpetatakse	doc_491521502164_item	2614103	et	3	main
külas	doc_491521502164_item	2614106	et	3	main
elab	doc_491521502164_item	2614107	et	3	main
veidi	doc_491521502164_item	2614108	et	3	main
üle	doc_491521502164_item	2614109	et	3	main
pireti	doc_491521502164_item	2614118	et	4	main
poolpõlenud	doc_491521502164_item	2614122	et	4	main
varsti	doc_491521502164_item	2614124	et	3	main
karda	doc_491521502164_item	2614135	et	4	main
talvepuud	doc_491521502164_item	2614140	et	4	main
vene	doc_491521502164_item	2614155	et	4	main
kütmisega	doc_491521502164_item	2614158	et	4	main
külapood	doc_491521502164_item	2614162	et	3	main
vildid	doc_491521502164_item	2614164	et	4	main
naerab	doc_491521502164_item	2614171	et	3	main
ajalehest	doc_491521502164_item	2614178	et	4	main
sõnadest	doc_491521502164_item	2614183	et	3	main
laused	doc_491521502164_item	2614184	et	3	main
naeratus	doc_491521502164_item	2614193	et	4	main
tegema	doc_491521502164_item	2614194	et	3	main
kogus	doc_491521502164_item	2614225	et	4	main
sportima	doc_491521502164_item	2614245	et	4	main
nii	doc_491521502164_item	2614266	et	3	main
selle	doc_491521502164_item	2614270	et	4	main
lausa	doc_491521502164_item	2614272	et	4	main
elab	doc_491521502164_item	2614273	et	3	main
ja	doc_491521502164_item	2614274	et	3	main
hingab	doc_491521502164_item	2614275	et	3	main
valmistamine	doc_491521502164_item	2614286	et	4	main
telefonihelin	doc_491521502164_item	2614295	et	3	main
pühapäeva	doc_491521502164_item	2614298	et	4	main
lõunasööki	doc_491521502164_item	2614302	et	4	main
huvitava	doc_491521502164_item	2614307	et	4	main
vaatamise	doc_491521502164_item	2614309	et	4	main
iv	doc_491521502164_item	2614311	et	4	main
õigesse	doc_491521502164_item	2614316	et	3	main
vanemaid	doc_491521502164_item	2614326	et	4	main
usaldavad	doc_491521502164_item	2614333	et	4	main
igaüks	doc_491521502164_item	2614334	et	3	main
igaüht	doc_491521502164_item	2614335	et	3	main
2	doc_491521502164_item	2614336	et	2	main
kohandasin	doc_491521502164_item	2614337	et	3	main
naised	doc_491521502164_item	2614355	et	3	main
autodeks	doc_491521502164_item	2614363	et	3	main
haigestuda	doc_491521502164_item	2614368	et	3	main
tüdinesin	doc_491521502164_item	2614372	et	3	main
uue	doc_491521502164_item	2614375	et	3	main
6	doc_491521502164_item	2614378	et	2	main
vaid	doc_491521502164_item	2614382	et	3	main
pilt	doc_491521502164_item	2614023	et	3	main
tahtmine	doc_491521502164_item	2614036	et	4	main
täis	doc_491521502164_item	2614038	et	4	main
polnud	doc_491521502164_item	2614046	et	3	main
kool	doc_491521502164_item	2614047	et	4	main
veel	doc_491521502164_item	2614048	et	4	main
algama	doc_491521502164_item	2614049	et	3	main
algab	doc_491521502164_item	2614050	et	3	main
ettevõtmine	doc_491521502164_item	2614063	et	3	main
mõnus	doc_491521502164_item	2614079	et	4	main
ja	doc_491521502164_item	2614083	et	3	main
vene	doc_491521502164_item	2614086	et	4	main
aktsentiga	doc_491521502164_item	2614088	et	4	main
mõni	doc_491521502164_item	2614091	et	3	main
mõnega	doc_491521502164_item	2614092	et	3	main
murret	doc_491521502164_item	2614093	et	4	main
kool	doc_491521502164_item	2614098	et	4	main
ja	doc_491521502164_item	2614099	et	3	main
emakeelt	doc_491521502164_item	2614114	et	4	main
õpivad	doc_491521502164_item	2614120	et	3	main
saatma	doc_491521502164_item	2614125	et	3	main
uued	doc_491521502164_item	2614128	et	3	main
õpikud	doc_491521502164_item	2614129	et	3	main
mulle	doc_491521502164_item	2614136	et	4	main
juba	doc_491521502164_item	2614137	et	3	main
praegu	doc_491521502164_item	2614141	et	3	main
veel	doc_491521502164_item	2614144	et	4	main
sojad	doc_491521502164_item	2614146	et	3	main
kuid	doc_491521502164_item	2614147	et	4	main
ööd	doc_491521502164_item	2614148	et	4	main
juba	doc_491521502164_item	2614149	et	3	main
jahe	doc_491521502164_item	2614150	et	3	main
jahedad	doc_491521502164_item	2614151	et	3	main
harjutan	doc_491521502164_item	2614152	et	3	main
juba	doc_491521502164_item	2614153	et	3	main
suure	doc_491521502164_item	2614154	et	3	main
ostan	doc_491521502164_item	2614161	et	3	main
külapoest	doc_491521502164_item	2614163	et	4	main
suurt	doc_491521502164_item	2614167	et	3	main
muud	doc_491521502164_item	2614168	et	4	main
piret	doc_491521502164_item	2614175	et	4	main
slõhtuleht	doc_491521502164_item	2614179	et	4	main
kasutades	doc_491521502164_item	2614190	et	3	main
kirjavahemärke	doc_491521502164_item	2614191	et	4	main
2	doc_491521502164_item	2614192	et	2	main
ja	doc_491521502164_item	2614197	et	3	main
igaüks	doc_491521502164_item	2614200	et	3	main
tooma	doc_491521502164_item	2614221	et	3	main
stress	doc_491521502164_item	2614226	et	3	main
pinge	doc_491521502164_item	2614242	et	4	main
saama	doc_491521502164_item	2614252	et	4	main
et	doc_491521502164_item	2614256	et	3	main
maagiline	doc_491521502164_item	2614267	et	4	main
lõunasöök	doc_491521502164_item	2614285	et	3	main
ka	doc_491521502164_item	2614297	et	3	main
varahommiku	doc_491521502164_item	2614299	et	3	main
segab	doc_491521502164_item	2614301	et	3	main
valmistamist	doc_491521502164_item	2614303	et	4	main
ja	doc_491521502164_item	2614304	et	3	main
pange	doc_491521502164_item	2614312	et	4	main
vormi	doc_491521502164_item	2614317	et	4	main
pean	doc_491521502164_item	2614320	et	4	main
oma	doc_491521502164_item	2614323	et	4	main
kõik	doc_491521502164_item	2614330	et	4	main
nõudeid	doc_491521502164_item	2614340	et	3	main
sa	doc_491521502164_item	2614345	et	3	main
tunned	doc_491521502164_item	2614351	et	3	main
ja	doc_491521502164_item	2614356	et	3	main
autod	doc_491521502164_item	2614358	et	3	main
naiseks	doc_491521502164_item	2614360	et	3	main
ja	doc_491521502164_item	2614361	et	3	main
praegu	doc_491521502164_item	2614365	et	3	main
oht	doc_491521502164_item	2614367	et	3	main
piirdusime	doc_491521502164_item	2614379	et	3	main
see	doc_491521502164_item	2614388	et	3	main
küsimus	doc_491521502164_item	2614389	et	4	main
kuulub	doc_491521502164_item	2614390	et	3	main
teine	doc_491521502164_item	2614391	et	3	main
valdkond	doc_491521502164_item	2614392	et	3	main
püksidele	doc_491521502164_item	2614399	et	3	main
kolmekäigulise	doc_491521502164_item	2614422	et	4	main
2	doc_491521502164_item	2614429	et	2	main
kohal	doc_491521502164_item	2614430	et	4	main
olid	doc_491521502164_item	2614431	et	4	main
kui	doc_491521502164_item	2614432	et	3	main
õpilased	doc_491521502164_item	2614433	et	3	main
nii	doc_491521502164_item	2614434	et	3	main
tulevad	doc_491521502164_item	2614442	et	4	main
4	doc_491521502164_item	2614443	et	2	main
kartuleid	doc_491521502164_item	2614055	et	3	main
kartulivõtt	doc_491521502164_item	2614056	et	3	main
on	doc_491521502164_item	2614057	et	4	main
tähtsam	doc_491521502164_item	2614062	et	4	main
mahlakas	doc_491521502164_item	2614081	et	4	main
mitte	doc_491521502164_item	2614085	et	3	main
aktsent	doc_491521502164_item	2614087	et	3	main
ained	doc_491521502164_item	2614102	et	3	main
keeles	doc_491521502164_item	2614105	et	4	main
kolmsada	doc_491521502164_item	2614110	et	4	main
kolmesaja	doc_491521502164_item	2614111	et	4	main
inimene	doc_491521502164_item	2614112	et	3	main
inimest	doc_491521502164_item	2614113	et	3	main
sõnul	doc_491521502164_item	2614119	et	3	main
lapsed	doc_491521502164_item	2614121	et	3	main
raamatud	doc_491521502164_item	2614123	et	4	main
saadetakse	doc_491521502164_item	2614126	et	3	main
eestist	doc_491521502164_item	2614127	et	3	main
siberi	doc_491521502164_item	2614130	et	4	main
talve	doc_491521502164_item	2614131	et	4	main
tooma	doc_491521502164_item	2614138	et	3	main
on	doc_491521502164_item	2614142	et	4	main
soe	doc_491521502164_item	2614145	et	4	main
kütmine	doc_491521502164_item	2614157	et	4	main
ega	doc_491521502164_item	2614165	et	3	main
seal	doc_491521502164_item	2614166	et	4	main
naised	doc_491521502164_item	2614195	et	3	main
paras	doc_491521502164_item	2614224	et	3	main
paneb	doc_491521502164_item	2614227	et	3	main
tegutsema	doc_491521502164_item	2614229	et	3	main
tuua	doc_491521502164_item	2614233	et	3	main
maandama	doc_491521502164_item	2614244	et	3	main
nii	doc_491521502164_item	2614253	et	3	main
aparaat	doc_491521502164_item	2614255	et	3	main
et	doc_491521502164_item	2614269	et	3	main
segama	doc_491521502164_item	2614284	et	3	main
söömine	doc_491521502164_item	2614288	et	4	main
huvitav	doc_491521502164_item	2614290	et	4	main
telesaade	doc_491521502164_item	2614291	et	4	main
vaatamine	doc_491521502164_item	2614292	et	4	main
aeg	doc_491521502164_item	2614293	et	3	main
pahandab	doc_491521502164_item	2614306	et	3	main
väga	doc_491521502164_item	2614321	et	3	main
sest	doc_491521502164_item	2614327	et	4	main
nad	doc_491521502164_item	2614328	et	3	main
aitavad	doc_491521502164_item	2614329	et	4	main
nõuded	doc_491521502164_item	2614339	et	3	main
ilusad	doc_491521502164_item	2614354	et	3	main
ilusaks	doc_491521502164_item	2614359	et	4	main
difteeriaks	doc_491521502164_item	2614370	et	3	main
töökoha	doc_491521502164_item	2614376	et	4	main
teises	doc_491521502164_item	2614393	et	4	main
ei	doc_491521502164_item	2614133	et	4	main
kartma	doc_491521502164_item	2614134	et	3	main
vaja	doc_491521502164_item	2614160	et	4	main
ei	doc_491521502164_item	2614169	et	4	main
müüdagi	doc_491521502164_item	2614170	et	3	main
talveks	doc_491521502164_item	2614172	et	4	main
valmistuma	doc_491521502164_item	2614173	et	3	main
valmistunud	doc_491521502164_item	2614174	et	4	main
lühendatud	doc_491521502164_item	2614177	et	4	main
iii	doc_491521502164_item	2614180	et	4	main
moodustage	doc_491521502164_item	2614181	et	3	main
etteantud	doc_491521502164_item	2614182	et	4	main
pannes	doc_491521502164_item	2614185	et	4	main
sõnad	doc_491521502164_item	2614186	et	4	main
õigesse	doc_491521502164_item	2614187	et	3	main
mehed	doc_491521502164_item	2614198	et	3	main
mehelikum	doc_491521502164_item	2614199	et	4	main
kaunim	doc_491521502164_item	2614201	et	4	main
naeratus	doc_491521502164_item	2614202	et	4	main
teeb	doc_491521502164_item	2614203	et	3	main
igaühe	doc_491521502164_item	2614204	et	4	main
kaunim	doc_491521502164_item	2614205	et	4	main
naisi	doc_491521502164_item	2614206	et	3	main
naiselikum	doc_491521502164_item	2614207	et	4	main
ja	doc_491521502164_item	2614208	et	3	main
mehe	doc_491521502164_item	2614209	et	3	main
mehelikum	doc_491521502164_item	2614210	et	4	main
3	doc_491521502164_item	2614211	et	2	main
paras	doc_491521502164_item	2614212	et	3	main
kogus	doc_491521502164_item	2614213	et	4	main
stress	doc_491521502164_item	2614214	et	3	main
panema	doc_491521502164_item	2614215	et	3	main
meie	doc_491521502164_item	2614216	et	4	main
tegutsema	doc_491521502164_item	2614217	et	3	main
aga	doc_491521502164_item	2614218	et	3	main
lisakoormus	doc_491521502164_item	2614219	et	3	main
võima	doc_491521502164_item	2614220	et	3	main
tagajärg	doc_491521502164_item	2614223	et	3	main
lisakoormus	doc_491521502164_item	2614231	et	3	main
saama	doc_491521502164_item	2614243	et	4	main
ja	doc_491521502164_item	2614246	et	3	main
puhkama	doc_491521502164_item	2614247	et	3	main
5	doc_491521502164_item	2614248	et	2	main
telefon	doc_491521502164_item	2614249	et	3	main
olema	doc_491521502164_item	2614250	et	4	main
on	doc_491521502164_item	2614265	et	4	main
pühapäev	doc_491521502164_item	2614281	et	3	main
varahommik	doc_491521502164_item	2614282	et	3	main
ja	doc_491521502164_item	2614287	et	3	main
pahandab	doc_491521502164_item	2614289	et	3	main
uni	doc_491521502164_item	2614300	et	3	main
aega	doc_491521502164_item	2614310	et	4	main
1	doc_491521502164_item	2614318	et	2	main
ma	doc_491521502164_item	2614319	et	3	main
lugu	doc_491521502164_item	2614322	et	4	main
vanemad	doc_491521502164_item	2614324	et	4	main
oma	doc_491521502164_item	2614325	et	4	main
kõike	doc_491521502164_item	2614331	et	4	main
ja	doc_491521502164_item	2614332	et	3	main
3	doc_491521502164_item	2614341	et	2	main
arvasin	doc_491521502164_item	2614343	et	3	main
huvitud	doc_491521502164_item	2614346	et	4	main
sporti	doc_491521502164_item	2614348	et	4	main
sa	doc_491521502164_item	2614350	et	3	main
huvi	doc_491521502164_item	2614352	et	4	main
ainult	doc_491521502164_item	2614353	et	4	main
kiired	doc_491521502164_item	2614357	et	4	main
4	doc_491521502164_item	2614364	et	2	main
difteeria	doc_491521502164_item	2614369	et	4	main
töökoht	doc_491521502164_item	2614374	et	3	main
kiiresti	doc_491521502164_item	2614377	et	3	main
küsimuses	doc_491521502164_item	2614381	et	4	main
valdkonnas	doc_491521502164_item	2614394	et	4	main
närimiskumm	doc_491521502164_item	2614396	et	3	main
lõuna	doc_491521502164_item	2614423	et	4	main
õpetajad	doc_491521502164_item	2614435	et	4	main
lapsel	doc_491521502164_item	2614437	et	4	main
7	doc_491521502164_item	2614468	et	2	main
töötasid	doc_491521502164_item	2614479	et	4	main
sa	doc_491521502164_item	2614488	et	3	main
maale	doc_491521502164_item	2614490	et	4	main
jääd	doc_491521502164_item	2614492	et	4	main
linna	doc_491521502164_item	2614493	et	4	main
i	doc_491521502165_item	2614506	et	4	main
pange	doc_491521502165_item	2614507	et	4	main
vormi	doc_491521502165_item	2614512	et	4	main
on	doc_491521502165_item	2614515	et	4	main
ettevõtlik	doc_491521502165_item	2614516	et	3	main
naine	doc_491521502165_item	2614517	et	3	main
suvel	doc_491521502165_item	2614518	et	3	main
nägi	doc_491521502165_item	2614520	et	3	main
et	doc_491521502165_item	2614525	et	3	main
õpetajat	doc_491521502165_item	2614533	et	4	main
piret	doc_491521502165_item	2614534	et	4	main
võitis	doc_491521502165_item	2614535	et	3	main
konkurss	doc_491521502165_item	2614536	et	3	main
konkurssist	doc_491521502165_item	2614537	et	4	main
ja	doc_491521502165_item	2614538	et	3	main
nädal	doc_491521502165_item	2614543	et	3	main
nädala	doc_491521502165_item	2614544	et	3	main
need	doc_491521502165_item	2614547	et	3	main
emakeelt	doc_491521502165_item	2614549	et	4	main
õpetama	doc_491521502165_item	2614550	et	3	main
siberisse	doc_491521502165_item	2614556	et	4	main
jõudma	doc_491521502165_item	2614557	et	3	main
jõuda	doc_491521502165_item	2614558	et	3	main
üsna	doc_491521502165_item	2614563	et	3	main
mulle	doc_491521502165_item	2614567	et	4	main
tulema	doc_491521502165_item	2614568	et	4	main
kool	doc_491521502165_item	2614603	et	4	main
sügisel	doc_491521502165_item	2614615	et	3	main
kõige	doc_491521502165_item	2614616	et	4	main
tähtis	doc_491521502165_item	2614617	et	4	main
siinsed	doc_491521502165_item	2614631	et	3	main
mahlakas	doc_491521502165_item	2614638	et	4	main
mõnusamalt	doc_491521502165_item	2614639	et	4	main
ja	doc_491521502165_item	2614640	et	3	main
murret	doc_491521502165_item	2614650	et	4	main
on	doc_491521502165_item	2614652	et	4	main
kolmsada	doc_491521502165_item	2614667	et	4	main
emakeelt	doc_491521502165_item	2614671	et	4	main
kõik	doc_491521502165_item	2614673	et	4	main
kõike	doc_491521502165_item	2614674	et	4	main
rääkida	doc_491521502165_item	2614675	et	3	main
eestist	doc_491521502165_item	2614685	et	3	main
kartma	doc_491521502165_item	2614692	et	3	main
sulgudes	doc_491521502164_item	2614313	et	4	main
olevad	doc_491521502164_item	2614314	et	4	main
sõnad	doc_491521502164_item	2614315	et	4	main
artikli	doc_491521502164_item	2614338	et	3	main
ma	doc_491521502164_item	2614342	et	3	main
et	doc_491521502164_item	2614344	et	3	main
sport	doc_491521502164_item	2614347	et	3	main
aga	doc_491521502164_item	2614349	et	3	main
kiireks	doc_491521502164_item	2614362	et	4	main
on	doc_491521502164_item	2614366	et	4	main
5	doc_491521502164_item	2614371	et	2	main
uus	doc_491521502164_item	2614373	et	3	main
selles	doc_491521502164_item	2614380	et	4	main
väikesed	doc_491521502164_item	2614383	et	4	main
8	doc_491521502164_item	2614395	et	2	main
kleepus	doc_491521502164_item	2614397	et	3	main
9	doc_491521502164_item	2614400	et	2	main
külmal	doc_491521502164_item	2614401	et	3	main
ajal	doc_491521502164_item	2614402	et	4	main
peab	doc_491521502164_item	2614403	et	4	main
hoiduma	doc_491521502164_item	2614404	et	3	main
külmetamine	doc_491521502164_item	2614405	et	4	main
külmetamisest	doc_491521502164_item	2614406	et	4	main
10	doc_491521502164_item	2614407	et	2	main
ma	doc_491521502164_item	2614408	et	3	main
tunnen	doc_491521502164_item	2614409	et	3	main
rõõmu	doc_491521502164_item	2614410	et	4	main
suvine	doc_491521502164_item	2614411	et	4	main
päike	doc_491521502164_item	2614412	et	3	main
suvisest	doc_491521502164_item	2614413	et	4	main
päikest	doc_491521502164_item	2614414	et	4	main
v	doc_491521502164_item	2614415	et	4	main
täitke	doc_491521502164_item	2614416	et	3	main
lüngad	doc_491521502164_item	2614417	et	3	main
sidenditega	doc_491521502164_item	2614419	et	3	main
sobivate	doc_491521502164_item	2614418	et	4	main
1	doc_491521502164_item	2614420	et	2	main
tellisime	doc_491521502164_item	2614421	et	4	main
see	doc_491521502164_item	2614426	et	3	main
3	doc_491521502164_item	2614436	et	2	main
oodata	doc_491521502164_item	2614439	et	4	main
vanemad	doc_491521502164_item	2614440	et	4	main
tagasi	doc_491521502164_item	2614441	et	3	main
keegi	doc_491521502164_item	2614448	et	4	main
just	doc_491521502164_item	2614449	et	3	main
lähete	doc_491521502164_item	2614466	et	4	main
küll	doc_491521502164_item	2614480	et	4	main
pingsalt	doc_491521502164_item	2614481	et	4	main
9	doc_491521502164_item	2614486	et	2	main
10	doc_491521502164_item	2614494	et	2	main
kuulsin	doc_491521502164_item	2614498	et	3	main
eesti	doc_491521502165_item	2614500	et	4	main
test	doc_491521502165_item	2614502	et	3	main
eesti	doc_491521502165_item	2614503	et	4	main
sulgudes	doc_491521502165_item	2614508	et	4	main
olevad	doc_491521502165_item	2614509	et	4	main
piret	doc_491521502165_item	2614513	et	4	main
ajalehes	doc_491521502165_item	2614522	et	3	main
keele	doc_491521502165_item	2614532	et	4	main
üle	doc_491521502165_item	2614542	et	3	main
eestlastele	doc_491521502165_item	2614546	et	4	main
kinnitusel	doc_491521502165_item	2614553	et	4	main
tundis	doc_491521502165_item	2614554	et	3	main
oodatud	doc_491521502165_item	2614561	et	4	main
muudatused	doc_491521502164_item	2614384	et	3	main
väikesi	doc_491521502164_item	2614385	et	4	main
muudatusi	doc_491521502164_item	2614386	et	3	main
7	doc_491521502164_item	2614387	et	2	main
püksid	doc_491521502164_item	2614398	et	3	main
kuid	doc_491521502164_item	2614425	et	4	main
maksis	doc_491521502164_item	2614427	et	4	main
läheb	doc_491521502164_item	2614458	et	3	main
6	doc_491521502164_item	2614461	et	2	main
lõpetage	doc_491521502164_item	2614462	et	3	main
töö	doc_491521502164_item	2614463	et	4	main
siis	doc_491521502164_item	2614464	et	3	main
seejärel	doc_491521502164_item	2614465	et	3	main
selles	doc_491521502164_item	2614469	et	4	main
ei	doc_491521502164_item	2614471	et	4	main
suitsetada	doc_491521502164_item	2614473	et	3	main
aga	doc_491521502164_item	2614482	et	3	main
tulemust	doc_491521502164_item	2614483	et	4	main
kas	doc_491521502164_item	2614487	et	3	main
ukse	doc_491521502164_item	2614496	et	3	main
sõnad	doc_491521502165_item	2614510	et	4	main
õigesse	doc_491521502165_item	2614511	et	3	main
toomet	doc_491521502165_item	2614514	et	4	main
nägema	doc_491521502165_item	2614519	et	3	main
kahjuks	doc_491521502164_item	2614424	et	4	main
palju	doc_491521502164_item	2614428	et	4	main
paluti	doc_491521502164_item	2614438	et	3	main
anekdooti	doc_491521502164_item	2614450	et	4	main
rääkinud	doc_491521502164_item	2614451	et	4	main
5	doc_491521502164_item	2614452	et	2	main
ta	doc_491521502164_item	2614453	et	4	main
ei	doc_491521502164_item	2614454	et	4	main
tule	doc_491521502164_item	2614455	et	4	main
trenni	doc_491521502164_item	2614456	et	4	main
kuna	doc_491521502164_item	2614457	et	3	main
kõrvallauast	doc_491521502164_item	2614444	et	4	main
kostis	doc_491521502164_item	2614445	et	4	main
naeru	doc_491521502164_item	2614446	et	4	main
oleks	doc_491521502164_item	2614447	et	3	main
hoopis	doc_491521502164_item	2614459	et	3	main
teatrisse	doc_491521502164_item	2614460	et	3	main
baaris	doc_491521502164_item	2614470	et	3	main
tohi	doc_491521502164_item	2614472	et	4	main
ega	doc_491521502164_item	2614474	et	3	main
alkoholi	doc_491521502164_item	2614475	et	4	main
tarbida	doc_491521502164_item	2614476	et	3	main
8	doc_491521502164_item	2614477	et	2	main
nad	doc_491521502164_item	2614478	et	3	main
ei	doc_491521502164_item	2614484	et	4	main
või	doc_491521502164_item	2614491	et	4	main
avasin	doc_491521502164_item	2614495	et	3	main
keele	doc_491521502165_item	2614504	et	4	main
test	doc_491521502165_item	2614505	et	3	main
kuulutuse	doc_491521502165_item	2614524	et	4	main
ülem-suetuki	doc_491521502165_item	2614527	et	4	main
nüüd	doc_491521502165_item	2614540	et	4	main
õpetanud	doc_491521502165_item	2614551	et	4	main
pireti	doc_491521502165_item	2614552	et	4	main
üllatuma	doc_491521502165_item	2614564	et	3	main
üllatunud	doc_491521502165_item	2614565	et	4	main
tuli	doc_491521502165_item	2614569	et	4	main
vastu	doc_491521502165_item	2614570	et	3	main
korralik	doc_491521502165_item	2614571	et	3	main
korraliku	doc_491521502165_item	2614572	et	3	main
audiga	doc_491521502165_item	2614573	et	3	main
siin	doc_491521502165_item	2614614	et	4	main
tänaseks	doc_491521502165_item	2614620	et	4	main
salv	doc_491521502165_item	2614623	et	3	main
õppimine	doc_491521502165_item	2614626	et	4	main
käib	doc_491521502165_item	2614627	et	3	main
täie	doc_491521502165_item	2614628	et	3	main
hoog	doc_491521502165_item	2614629	et	3	main
hoos	doc_491521502165_item	2614630	et	3	main
mahlakalt	doc_491521502165_item	2614641	et	4	main
mitte	doc_491521502165_item	2614642	et	3	main
venemaa	doc_491521502165_item	2614654	et	4	main
keeles	doc_491521502165_item	2614662	et	4	main
külas	doc_491521502165_item	2614663	et	3	main
elab	doc_491521502165_item	2614664	et	3	main
poolpõlenud	doc_491521502165_item	2614680	et	4	main
siberi	doc_491521502165_item	2614688	et	4	main
karta	doc_491521502165_item	2614693	et	3	main
ei	doc_491521502165_item	2614727	et	4	main
müüdagi	doc_491521502165_item	2614728	et	3	main
naerab	doc_491521502165_item	2614729	et	3	main
moodustage	doc_491521502165_item	2614739	et	3	main
etteantud	doc_491521502165_item	2614740	et	4	main
sõnad	doc_491521502165_item	2614744	et	4	main
mehed	doc_491521502165_item	2614756	et	3	main
naeratus	doc_491521502165_item	2614760	et	4	main
naisi	doc_491521502165_item	2614762	et	3	main
ja	doc_491521502165_item	2614764	et	3	main
mehi	doc_491521502165_item	2614765	et	3	main
mehelikum	doc_491521502165_item	2614766	et	4	main
igaüht	doc_491521502165_item	2614767	et	3	main
tegutsema	doc_491521502165_item	2614787	et	3	main
aga	doc_491521502165_item	2614788	et	3	main
lisakoormus	doc_491521502165_item	2614789	et	3	main
võib	doc_491521502165_item	2614790	et	3	main
tuua	doc_491521502165_item	2614791	et	3	main
soovimatu	doc_491521502165_item	2614792	et	4	main
tagajärjeks	doc_491521502165_item	2614793	et	3	main
4	doc_491521502165_item	2614794	et	2	main
tekkitav	doc_491521502165_item	2614810	et	4	main
sportida	doc_491521502165_item	2614814	et	4	main
puhata	doc_491521502165_item	2614816	et	4	main
jalutama	doc_491521502164_item	2614467	et	3	main
olnud	doc_491521502164_item	2614485	et	4	main
sõidad	doc_491521502164_item	2614489	et	3	main
kuna	doc_491521502164_item	2614497	et	3	main
koputust	doc_491521502164_item	2614499	et	4	main
keele	doc_491521502165_item	2614501	et	4	main
ta	doc_491521502165_item	2614521	et	4	main
siberisse	doc_491521502165_item	2614526	et	4	main
küla	doc_491521502165_item	2614528	et	4	main
külasse	doc_491521502165_item	2614529	et	3	main
otsitakse	doc_491521502165_item	2614530	et	3	main
eesti	doc_491521502165_item	2614531	et	4	main
juba	doc_491521502165_item	2614541	et	3	main
väikestele	doc_491521502165_item	2614545	et	4	main
neid	doc_491521502165_item	2614548	et	4	main
ta	doc_491521502165_item	2614555	et	4	main
olin	doc_491521502165_item	2614562	et	3	main
kui	doc_491521502165_item	2614566	et	3	main
siber	doc_491521502165_item	2614576	et	4	main
siberist	doc_491521502165_item	2614577	et	4	main
on	doc_491521502165_item	2614621	et	4	main
eestlased	doc_491521502165_item	2614632	et	3	main
kuidagi	doc_491521502165_item	2614634	et	3	main
mõnus	doc_491521502165_item	2614636	et	4	main
aktsent	doc_491521502165_item	2614644	et	3	main
aktsendiga	doc_491521502165_item	2614645	et	3	main
mõni	doc_491521502165_item	2614648	et	3	main
pireti	doc_491521502165_item	2614676	et	4	main
sõnul	doc_491521502165_item	2614677	et	3	main
õpivad	doc_491521502165_item	2614678	et	3	main
lapsed	doc_491521502165_item	2614679	et	3	main
ei	doc_491521502165_item	2614691	et	4	main
mulle	doc_491521502165_item	2614694	et	4	main
veel	doc_491521502165_item	2614702	et	4	main
kuulutus	doc_491521502165_item	2614523	et	4	main
on	doc_491521502165_item	2614539	et	4	main
et	doc_491521502165_item	2614559	et	3	main
on	doc_491521502165_item	2614560	et	4	main
mulle	doc_491521502165_item	2614574	et	4	main
selline	doc_491521502165_item	2614578	et	4	main
pilt	doc_491521502165_item	2614579	et	3	main
et	doc_491521502165_item	2614580	et	3	main
seal	doc_491521502165_item	2614581	et	4	main
ei	doc_491521502165_item	2614582	et	4	main
lendama	doc_491521502165_item	2614583	et	3	main
lenda	doc_491521502165_item	2614584	et	4	main
lind	doc_491521502165_item	2614585	et	3	main
ega	doc_491521502165_item	2614586	et	3	main
kasva	doc_491521502165_item	2614587	et	4	main
rohi	doc_491521502165_item	2614588	et	4	main
kui	doc_491521502165_item	2614589	et	3	main
noor	doc_491521502165_item	2614590	et	3	main
ja	doc_491521502165_item	2614591	et	3	main
tahtmine	doc_491521502165_item	2614592	et	4	main
tähtmist	doc_491521502165_item	2614593	et	4	main
täis	doc_491521502165_item	2614594	et	4	main
piret	doc_491521502165_item	2614595	et	4	main
pärast	doc_491521502165_item	2614596	et	4	main
õppeaasta	doc_491521502165_item	2614597	et	4	main
algust	doc_491521502165_item	2614598	et	4	main
koht	doc_491521502165_item	2614599	et	3	main
kohale	doc_491521502165_item	2614600	et	4	main
jõudis	doc_491521502165_item	2614601	et	3	main
polnud	doc_491521502165_item	2614602	et	3	main
veel	doc_491521502165_item	2614604	et	4	main
algama	doc_491521502165_item	2614605	et	3	main
alanud	doc_491521502165_item	2614606	et	4	main
kogu	doc_491521502165_item	2614607	et	4	main
küla	doc_491521502165_item	2614608	et	4	main
võtma	doc_491521502165_item	2614609	et	3	main
võttis	doc_491521502165_item	2614610	et	3	main
kartuleid	doc_491521502165_item	2614611	et	3	main
kartulivõtt	doc_491521502165_item	2614612	et	3	main
on	doc_491521502165_item	2614613	et	4	main
maaliti	doc_491521502165_item	2614575	et	3	main
tähtsaim	doc_491521502165_item	2614618	et	4	main
ettevõtmine	doc_491521502165_item	2614619	et	3	main
kartul	doc_491521502165_item	2614622	et	3	main
salves	doc_491521502165_item	2614624	et	4	main
ja	doc_491521502165_item	2614625	et	3	main
teistmoodi	doc_491521502165_item	2614635	et	3	main
ja	doc_491521502165_item	2614637	et	3	main
nagu	doc_491521502165_item	2614647	et	3	main
kool	doc_491521502165_item	2614651	et	4	main
siiski	doc_491521502165_item	2614653	et	4	main
kool	doc_491521502165_item	2614655	et	4	main
ja	doc_491521502165_item	2614656	et	3	main
veidi	doc_491521502165_item	2614665	et	3	main
üle	doc_491521502165_item	2614666	et	3	main
inimene	doc_491521502165_item	2614669	et	3	main
saab	doc_491521502165_item	2614672	et	3	main
uued	doc_491521502165_item	2614686	et	3	main
talve	doc_491521502165_item	2614689	et	4	main
juba	doc_491521502165_item	2614695	et	3	main
toodi	doc_491521502165_item	2614697	et	4	main
vildid	doc_491521502165_item	2614722	et	4	main
ega	doc_491521502165_item	2614723	et	3	main
seal	doc_491521502165_item	2614724	et	4	main
suurt	doc_491521502165_item	2614725	et	3	main
ajalehest	doc_491521502165_item	2614736	et	4	main
naiselikum	doc_491521502165_item	2614754	et	4	main
ja	doc_491521502165_item	2614755	et	3	main
kaunim	doc_491521502165_item	2614759	et	4	main
teeb	doc_491521502165_item	2614761	et	3	main
laskma	doc_491521502165_item	2614797	et	3	main
ülekoormus	doc_491521502165_item	2614798	et	3	main
tekkima	doc_491521502165_item	2614799	et	3	main
pinge	doc_491521502165_item	2614800	et	4	main
lasta	doc_491521502165_item	2614808	et	4	main
saab	doc_491521502165_item	2614812	et	3	main
ja	doc_491521502165_item	2614815	et	3	main
telefon	doc_491521502165_item	2614833	et	3	main
nii	doc_491521502165_item	2614835	et	3	main
maagiline	doc_491521502165_item	2614836	et	4	main
aparaat	doc_491521502165_item	2614837	et	3	main
et	doc_491521502165_item	2614838	et	3	main
hingata	doc_491521502165_item	2614845	et	4	main
telefonihelin	doc_491521502165_item	2614848	et	3	main
ka	doc_491521502165_item	2614850	et	3	main
varahommik	doc_491521502165_item	2614852	et	3	main
segama	doc_491521502165_item	2614854	et	3	main
valmistamine	doc_491521502165_item	2614856	et	4	main
huvitav	doc_491521502165_item	2614860	et	4	main
katkestab	doc_491521502165_item	2614866	et	3	main
und	doc_491521502165_item	2614870	et	4	main
segab	doc_491521502165_item	2614871	et	3	main
vaatamise	doc_491521502165_item	2614879	et	4	main
pange	doc_491521502165_item	2614882	et	4	main
õigesse	doc_491521502165_item	2614886	et	3	main
1	doc_491521502165_item	2614888	et	2	main
aitavad	doc_491521502165_item	2614899	et	4	main
ja	doc_491521502165_item	2614902	et	3	main
igaüks	doc_491521502165_item	2614904	et	3	main
igaüht	doc_491521502165_item	2614905	et	3	main
kohandasin	doc_491521502165_item	2614907	et	3	main
nõudetele	doc_491521502165_item	2614910	et	4	main
haigestuda	doc_491521502165_item	2614938	et	3	main
5	doc_491521502165_item	2614941	et	2	main
see	doc_491521502165_item	2614958	et	3	main
valdkond	doc_491521502165_item	2614962	et	3	main
valdkonnale	doc_491521502165_item	2614964	et	4	main
külmetamisest	doc_491521502165_item	2614978	et	4	main
tunnen	doc_491521502165_item	2614981	et	3	main
päike	doc_491521502165_item	2614984	et	3	main
suvest	doc_491521502165_item	2614985	et	3	main
päikest	doc_491521502165_item	2614986	et	4	main
v	doc_491521502165_item	2614987	et	4	main
täitke	doc_491521502165_item	2614988	et	3	main
lüngad	doc_491521502165_item	2614989	et	3	main
kolmekäigulise	doc_491521502165_item	2614994	et	4	main
rääkinud	doc_491521502165_item	2615024	et	4	main
alkoholi	doc_491521502165_item	2615047	et	4	main
avasin	doc_491521502165_item	2615067	et	3	main
keele	doc_491521502166_item	2615076	et	4	main
test	doc_491521502166_item	2615077	et	3	main
räägivad	doc_491521502165_item	2614633	et	3	main
vene	doc_491521502165_item	2614643	et	4	main
vaid	doc_491521502165_item	2614646	et	3	main
mõnd	doc_491521502165_item	2614649	et	3	main
ülejäänud	doc_491521502165_item	2614657	et	4	main
aine	doc_491521502165_item	2614658	et	4	main
ained	doc_491521502165_item	2614659	et	3	main
õpetatakse	doc_491521502165_item	2614660	et	3	main
vene	doc_491521502165_item	2614661	et	4	main
kolmesaja	doc_491521502165_item	2614668	et	4	main
inimest	doc_491521502165_item	2614670	et	3	main
raamatud	doc_491521502165_item	2614681	et	4	main
varsti	doc_491521502165_item	2614682	et	3	main
saatma	doc_491521502165_item	2614683	et	3	main
saadetakse	doc_491521502165_item	2614684	et	3	main
õpikud	doc_491521502165_item	2614687	et	3	main
piret	doc_491521502165_item	2614690	et	4	main
soe	doc_491521502165_item	2614703	et	4	main
soojad	doc_491521502165_item	2614704	et	3	main
kuid	doc_491521502165_item	2614705	et	4	main
ööd	doc_491521502165_item	2614706	et	4	main
juba	doc_491521502165_item	2614707	et	3	main
jahe	doc_491521502165_item	2614708	et	3	main
jahedamad	doc_491521502165_item	2614709	et	4	main
harjutan	doc_491521502165_item	2614710	et	3	main
juba	doc_491521502165_item	2614711	et	3	main
suure	doc_491521502165_item	2614712	et	3	main
vene	doc_491521502165_item	2614713	et	4	main
ahju	doc_491521502165_item	2614714	et	4	main
kütmine	doc_491521502165_item	2614715	et	4	main
kütmist	doc_491521502165_item	2614716	et	4	main
kui	doc_491521502165_item	2614717	et	3	main
vaja	doc_491521502165_item	2614718	et	4	main
ostan	doc_491521502165_item	2614719	et	3	main
külapood	doc_491521502165_item	2614720	et	3	main
lühendatud	doc_491521502165_item	2614735	et	4	main
pannes	doc_491521502165_item	2614743	et	4	main
õigesse	doc_491521502165_item	2614745	et	3	main
2	doc_491521502165_item	2614750	et	2	main
naeratus	doc_491521502165_item	2614751	et	4	main
tegema	doc_491521502165_item	2614752	et	3	main
naised	doc_491521502165_item	2614753	et	3	main
igaüks	doc_491521502165_item	2614758	et	3	main
naiselikum	doc_491521502165_item	2614763	et	4	main
ülekoormust	doc_491521502165_item	2614809	et	4	main
maandada	doc_491521502165_item	2614813	et	3	main
5	doc_491521502165_item	2614817	et	2	main
telefon	doc_491521502165_item	2614818	et	3	main
olema	doc_491521502165_item	2614819	et	4	main
tänapäev	doc_491521502165_item	2614820	et	3	main
saama	doc_491521502165_item	2614821	et	4	main
see	doc_491521502165_item	2614826	et	3	main
ja	doc_491521502165_item	2614830	et	3	main
tänapäevaks	doc_491521502165_item	2614832	et	3	main
selle	doc_491521502165_item	2614839	et	4	main
abil	doc_491521502165_item	2614840	et	4	main
saab	doc_491521502165_item	2614841	et	3	main
6	doc_491521502165_item	2614846	et	2	main
pühapäev	doc_491521502165_item	2614851	et	3	main
pahandab	doc_491521502165_item	2614859	et	3	main
valmistamist	doc_491521502165_item	2614873	et	4	main
olevad	doc_491521502165_item	2614884	et	4	main
sõnad	doc_491521502165_item	2614885	et	4	main
vormi	doc_491521502165_item	2614887	et	4	main
tooma	doc_491521502165_item	2614696	et	3	main
talvepuud	doc_491521502165_item	2614698	et	4	main
praegu	doc_491521502165_item	2614699	et	3	main
on	doc_491521502165_item	2614700	et	4	main
päevad	doc_491521502165_item	2614701	et	3	main
külapoest	doc_491521502165_item	2614721	et	4	main
talveks	doc_491521502165_item	2614730	et	4	main
valmistuma	doc_491521502165_item	2614731	et	3	main
valmistutud	doc_491521502165_item	2614732	et	4	main
piret	doc_491521502165_item	2614733	et	4	main
iii	doc_491521502165_item	2614738	et	4	main
laused	doc_491521502165_item	2614742	et	3	main
ei	doc_491521502165_item	2614795	et	4	main
tohtima	doc_491521502165_item	2614796	et	3	main
tohi	doc_491521502165_item	2614807	et	4	main
pinge	doc_491521502165_item	2614811	et	4	main
abil	doc_491521502165_item	2614827	et	4	main
on	doc_491521502165_item	2614834	et	4	main
ja	doc_491521502165_item	2614844	et	3	main
telesaade	doc_491521502165_item	2614861	et	4	main
vaatamine	doc_491521502165_item	2614862	et	4	main
kuid	doc_491521502165_item	2614864	et	4	main
ka	doc_491521502165_item	2614867	et	3	main
varahommikul	doc_491521502165_item	2614869	et	3	main
lõunasööki	doc_491521502165_item	2614872	et	4	main
aega	doc_491521502165_item	2614880	et	4	main
oma	doc_491521502165_item	2614893	et	4	main
vanemad	doc_491521502165_item	2614894	et	4	main
oma	doc_491521502165_item	2614895	et	4	main
kõike	doc_491521502165_item	2614901	et	4	main
huvi	doc_491521502165_item	2614922	et	4	main
ja	doc_491521502165_item	2614926	et	3	main
kiired	doc_491521502165_item	2614927	et	4	main
autod	doc_491521502165_item	2614928	et	3	main
ilusaid	doc_491521502165_item	2614929	et	3	main
naisi	doc_491521502165_item	2614930	et	3	main
ja	doc_491521502165_item	2614931	et	3	main
oht	doc_491521502165_item	2614937	et	3	main
difteeria	doc_491521502165_item	2614939	et	4	main
uus	doc_491521502165_item	2614943	et	3	main
töökoha	doc_491521502165_item	2614946	et	4	main
kiiresti	doc_491521502165_item	2614947	et	3	main
väikeste	doc_491521502165_item	2614955	et	4	main
küsimus	doc_491521502165_item	2614959	et	4	main
teine	doc_491521502165_item	2614961	et	3	main
ma	doc_491521502165_item	2614980	et	3	main
sidenditega	doc_491521502165_item	2614991	et	3	main
muud	doc_491521502165_item	2614726	et	4	main
vapralt	doc_491521502165_item	2614734	et	4	main
slõhtuleht	doc_491521502165_item	2614737	et	4	main
sõnadest	doc_491521502165_item	2614741	et	3	main
vormi	doc_491521502165_item	2614746	et	4	main
ja	doc_491521502165_item	2614747	et	3	main
kasutades	doc_491521502165_item	2614748	et	3	main
kirjavahemärke	doc_491521502165_item	2614749	et	4	main
mehelikum	doc_491521502165_item	2614757	et	4	main
kaunim	doc_491521502165_item	2614768	et	4	main
3	doc_491521502165_item	2614769	et	2	main
paras	doc_491521502165_item	2614770	et	3	main
kogus	doc_491521502165_item	2614771	et	4	main
stress	doc_491521502165_item	2614772	et	3	main
panema	doc_491521502165_item	2614773	et	3	main
meie	doc_491521502165_item	2614774	et	4	main
tegutsema	doc_491521502165_item	2614775	et	3	main
aga	doc_491521502165_item	2614776	et	3	main
lisakoormus	doc_491521502165_item	2614777	et	3	main
tooma	doc_491521502165_item	2614779	et	3	main
võima	doc_491521502165_item	2614778	et	3	main
soovimatu	doc_491521502165_item	2614780	et	4	main
tagajärg	doc_491521502165_item	2614781	et	3	main
kogus	doc_491521502165_item	2614783	et	4	main
paras	doc_491521502165_item	2614782	et	3	main
stress	doc_491521502165_item	2614784	et	3	main
paneb	doc_491521502165_item	2614785	et	3	main
meid	doc_491521502165_item	2614786	et	4	main
saama	doc_491521502165_item	2614801	et	4	main
maandama	doc_491521502165_item	2614802	et	3	main
sportima	doc_491521502165_item	2614803	et	4	main
ja	doc_491521502165_item	2614804	et	3	main
puhkama	doc_491521502165_item	2614805	et	3	main
ei	doc_491521502165_item	2614806	et	4	main
maagiline	doc_491521502165_item	2614823	et	4	main
aparaat	doc_491521502165_item	2614824	et	3	main
lausa	doc_491521502165_item	2614828	et	4	main
elama	doc_491521502165_item	2614829	et	3	main
söömine	doc_491521502165_item	2614858	et	4	main
ja	doc_491521502165_item	2614874	et	3	main
söömine	doc_491521502165_item	2614875	et	4	main
pahandab	doc_491521502165_item	2614876	et	3	main
iv	doc_491521502165_item	2614881	et	4	main
pean	doc_491521502165_item	2614890	et	4	main
väga	doc_491521502165_item	2614891	et	3	main
lugu	doc_491521502165_item	2614892	et	4	main
sest	doc_491521502165_item	2614897	et	4	main
nad	doc_491521502165_item	2614898	et	3	main
artikli	doc_491521502165_item	2614908	et	3	main
tunned	doc_491521502165_item	2614921	et	3	main
ainult	doc_491521502165_item	2614923	et	4	main
ilusad	doc_491521502165_item	2614924	et	3	main
naised	doc_491521502165_item	2614925	et	3	main
on	doc_491521502165_item	2614936	et	4	main
difteeriaks	doc_491521502165_item	2614940	et	3	main
tüdinesin	doc_491521502165_item	2614942	et	3	main
töökoht	doc_491521502165_item	2614944	et	3	main
uue	doc_491521502165_item	2614945	et	3	main
6	doc_491521502165_item	2614948	et	2	main
piirdusime	doc_491521502165_item	2614949	et	3	main
selles	doc_491521502165_item	2614950	et	4	main
muudatusega	doc_491521502165_item	2614956	et	3	main
teisele	doc_491521502165_item	2614963	et	4	main
8	doc_491521502165_item	2614965	et	2	main
närimiskumm	doc_491521502165_item	2614966	et	3	main
kleepus	doc_491521502165_item	2614967	et	3	main
püksid	doc_491521502165_item	2614968	et	3	main
püksidesse	doc_491521502165_item	2614969	et	3	main
pükside	doc_491521502165_item	2614970	et	3	main
peale	doc_491521502165_item	2614971	et	4	main
9	doc_491521502165_item	2614972	et	2	main
peab	doc_491521502165_item	2614975	et	4	main
10	doc_491521502165_item	2614979	et	2	main
rõõmu	doc_491521502165_item	2614982	et	4	main
just	doc_491521502165_item	2615022	et	3	main
ei	doc_491521502165_item	2615027	et	4	main
tule	doc_491521502165_item	2615028	et	4	main
trenni	doc_491521502165_item	2615029	et	4	main
aga	doc_491521502165_item	2615030	et	3	main
läheb	doc_491521502165_item	2615031	et	3	main
hoopis	doc_491521502165_item	2615032	et	3	main
teatrisse	doc_491521502165_item	2615033	et	3	main
6	doc_491521502165_item	2615034	et	2	main
lõpetage	doc_491521502165_item	2615035	et	3	main
tohi	doc_491521502165_item	2615044	et	4	main
suitsetada	doc_491521502165_item	2615045	et	3	main
ja	doc_491521502165_item	2615046	et	3	main
töötasid	doc_491521502165_item	2615051	et	4	main
maale	doc_491521502165_item	2615062	et	4	main
kui	doc_491521502165_item	2615069	et	3	main
kuulsin	doc_491521502165_item	2615070	et	3	main
eesti	doc_491521502166_item	2615072	et	4	main
sõnad	doc_491521502166_item	2615082	et	4	main
õigesse	doc_491521502166_item	2615083	et	3	main
et	doc_491521502166_item	2615097	et	3	main
õpetajat	doc_491521502166_item	2615105	et	4	main
piret	doc_491521502166_item	2615106	et	4	main
pireti	doc_491521502166_item	2615124	et	4	main
ta	doc_491521502166_item	2615127	et	4	main
siberisse	doc_491521502166_item	2615128	et	4	main
jõudma	doc_491521502166_item	2615129	et	3	main
jõudmisel	doc_491521502166_item	2615130	et	4	main
et	doc_491521502166_item	2615131	et	3	main
tulema	doc_491521502166_item	2615140	et	4	main
tuldi	doc_491521502166_item	2615141	et	3	main
seal	doc_491521502166_item	2615153	et	4	main
ei	doc_491521502166_item	2615154	et	4	main
lendama	doc_491521502166_item	2615155	et	3	main
noor	doc_491521502166_item	2615162	et	3	main
veel	doc_491521502166_item	2615176	et	4	main
nii	doc_491521502165_item	2614822	et	3	main
et	doc_491521502165_item	2614825	et	3	main
hingama	doc_491521502165_item	2614831	et	3	main
lausa	doc_491521502165_item	2614842	et	4	main
elada	doc_491521502165_item	2614843	et	3	main
kuid	doc_491521502165_item	2614847	et	4	main
katkestama	doc_491521502165_item	2614849	et	3	main
uni	doc_491521502165_item	2614853	et	3	main
lõunasöök	doc_491521502165_item	2614855	et	3	main
ja	doc_491521502165_item	2614857	et	3	main
aeg	doc_491521502165_item	2614863	et	3	main
telefonihelin	doc_491521502165_item	2614865	et	3	main
pühapäeval	doc_491521502165_item	2614868	et	3	main
huvitava	doc_491521502165_item	2614877	et	4	main
telesaate	doc_491521502165_item	2614878	et	3	main
sulgudes	doc_491521502165_item	2614883	et	4	main
ma	doc_491521502165_item	2614912	et	3	main
arvasin	doc_491521502165_item	2614913	et	3	main
et	doc_491521502165_item	2614914	et	3	main
sa	doc_491521502165_item	2614915	et	3	main
huvitud	doc_491521502165_item	2614916	et	4	main
sport	doc_491521502165_item	2614917	et	3	main
sporti	doc_491521502165_item	2614918	et	4	main
aga	doc_491521502165_item	2614919	et	3	main
sa	doc_491521502165_item	2614920	et	3	main
kiireid	doc_491521502165_item	2614932	et	4	main
autosid	doc_491521502165_item	2614933	et	3	main
praegu	doc_491521502165_item	2614935	et	3	main
küsimuses	doc_491521502165_item	2614951	et	4	main
vaid	doc_491521502165_item	2614952	et	3	main
7	doc_491521502165_item	2614957	et	2	main
kuulub	doc_491521502165_item	2614960	et	3	main
ajal	doc_491521502165_item	2614974	et	4	main
külmetamine	doc_491521502165_item	2614977	et	4	main
sobivate	doc_491521502165_item	2614990	et	4	main
1	doc_491521502165_item	2614992	et	2	main
5	doc_491521502165_item	2615025	et	2	main
8	doc_491521502165_item	2615049	et	2	main
küll	doc_491521502165_item	2615052	et	4	main
linna	doc_491521502165_item	2615065	et	4	main
keele	doc_491521502166_item	2615073	et	4	main
test	doc_491521502166_item	2615074	et	3	main
eesti	doc_491521502166_item	2615075	et	4	main
olevad	doc_491521502166_item	2615081	et	4	main
on	doc_491521502166_item	2615087	et	4	main
suvel	doc_491521502166_item	2615090	et	3	main
ajalehes	doc_491521502166_item	2615094	et	3	main
kuulutus	doc_491521502166_item	2615095	et	4	main
siberisse	doc_491521502166_item	2615098	et	4	main
küla	doc_491521502166_item	2615100	et	4	main
külas	doc_491521502166_item	2615101	et	3	main
otsitakse	doc_491521502166_item	2615102	et	3	main
eesti	doc_491521502166_item	2615103	et	4	main
võitis	doc_491521502166_item	2615107	et	3	main
eestlastele	doc_491521502166_item	2615118	et	4	main
need	doc_491521502166_item	2615119	et	3	main
seda	doc_491521502166_item	2615120	et	3	main
ma	doc_491521502165_item	2614889	et	3	main
vanematele	doc_491521502165_item	2614896	et	4	main
kõik	doc_491521502165_item	2614900	et	4	main
usaldavad	doc_491521502165_item	2614903	et	4	main
2	doc_491521502165_item	2614906	et	2	main
nõuded	doc_491521502165_item	2614909	et	3	main
3	doc_491521502165_item	2614911	et	2	main
4	doc_491521502165_item	2614934	et	2	main
väikesed	doc_491521502165_item	2614953	et	4	main
muudatused	doc_491521502165_item	2614954	et	3	main
külmal	doc_491521502165_item	2614973	et	3	main
hoiduma	doc_491521502165_item	2614976	et	3	main
suvine	doc_491521502165_item	2614983	et	4	main
tellisime	doc_491521502165_item	2614993	et	4	main
lõuna	doc_491521502165_item	2614995	et	4	main
kuid	doc_491521502165_item	2614996	et	4	main
see	doc_491521502165_item	2614997	et	3	main
maksis	doc_491521502165_item	2614998	et	4	main
palju	doc_491521502165_item	2614999	et	4	main
2	doc_491521502165_item	2615000	et	2	main
kohal	doc_491521502165_item	2615001	et	4	main
olid	doc_491521502165_item	2615002	et	4	main
nii	doc_491521502165_item	2615003	et	3	main
õpilased	doc_491521502165_item	2615004	et	3	main
naa	doc_491521502165_item	2615005	et	3	main
õpetajad	doc_491521502165_item	2615006	et	4	main
3	doc_491521502165_item	2615007	et	2	main
lapsel	doc_491521502165_item	2615008	et	4	main
paluti	doc_491521502165_item	2615009	et	3	main
oodata	doc_491521502165_item	2615010	et	4	main
kui	doc_491521502165_item	2615011	et	3	main
vanemad	doc_491521502165_item	2615012	et	4	main
tagasi	doc_491521502165_item	2615013	et	3	main
tulevad	doc_491521502165_item	2615014	et	4	main
4	doc_491521502165_item	2615015	et	2	main
kostis	doc_491521502165_item	2615017	et	4	main
kõrvallauast	doc_491521502165_item	2615016	et	4	main
naeru	doc_491521502165_item	2615018	et	4	main
et	doc_491521502165_item	2615019	et	3	main
oleks	doc_491521502165_item	2615020	et	3	main
keegi	doc_491521502165_item	2615021	et	4	main
töö	doc_491521502165_item	2615036	et	4	main
siis	doc_491521502165_item	2615037	et	3	main
7	doc_491521502165_item	2615040	et	2	main
tarbida	doc_491521502165_item	2615048	et	3	main
või	doc_491521502165_item	2615063	et	4	main
jääd	doc_491521502165_item	2615064	et	4	main
ukse	doc_491521502165_item	2615068	et	3	main
pange	doc_491521502166_item	2615079	et	4	main
sulgudes	doc_491521502166_item	2615080	et	4	main
piret	doc_491521502166_item	2615085	et	4	main
ettevõtlik	doc_491521502166_item	2615088	et	3	main
kuulutust	doc_491521502166_item	2615096	et	4	main
ja	doc_491521502166_item	2615110	et	3	main
on	doc_491521502166_item	2615111	et	4	main
juba	doc_491521502166_item	2615113	et	3	main
üle	doc_491521502166_item	2615114	et	3	main
nädal	doc_491521502166_item	2615115	et	3	main
nädala	doc_491521502166_item	2615116	et	3	main
väikestele	doc_491521502166_item	2615117	et	4	main
õpetama	doc_491521502166_item	2615122	et	3	main
tundis	doc_491521502166_item	2615126	et	3	main
korralik	doc_491521502166_item	2615143	et	3	main
anekdooti	doc_491521502165_item	2615023	et	4	main
ta	doc_491521502165_item	2615026	et	4	main
lähete	doc_491521502165_item	2615038	et	4	main
jalutama	doc_491521502165_item	2615039	et	3	main
selles	doc_491521502165_item	2615041	et	4	main
baaris	doc_491521502165_item	2615042	et	3	main
ei	doc_491521502165_item	2615043	et	4	main
nad	doc_491521502165_item	2615050	et	3	main
pingsalt	doc_491521502165_item	2615053	et	4	main
kuigi	doc_491521502165_item	2615054	et	3	main
tulemust	doc_491521502165_item	2615055	et	4	main
ei	doc_491521502165_item	2615056	et	4	main
olnud	doc_491521502165_item	2615057	et	4	main
9	doc_491521502165_item	2615058	et	2	main
kas	doc_491521502165_item	2615059	et	3	main
sa	doc_491521502165_item	2615060	et	3	main
sõidad	doc_491521502165_item	2615061	et	3	main
10	doc_491521502165_item	2615066	et	2	main
koputust	doc_491521502165_item	2615071	et	4	main
vormi	doc_491521502166_item	2615084	et	4	main
nägi	doc_491521502166_item	2615092	et	3	main
keele	doc_491521502166_item	2615104	et	4	main
konkurss	doc_491521502166_item	2615108	et	3	main
nüüd	doc_491521502166_item	2615112	et	4	main
emakeelt	doc_491521502166_item	2615121	et	4	main
vastu	doc_491521502166_item	2615142	et	3	main
mulle	doc_491521502166_item	2615146	et	4	main
selline	doc_491521502166_item	2615150	et	4	main
pilt	doc_491521502166_item	2615151	et	3	main
et	doc_491521502166_item	2615152	et	3	main
ja	doc_491521502166_item	2615163	et	3	main
kohale	doc_491521502166_item	2615172	et	4	main
jõudis	doc_491521502166_item	2615173	et	3	main
polnud	doc_491521502166_item	2615174	et	3	main
kogu	doc_491521502166_item	2615179	et	4	main
võtis	doc_491521502166_item	2615182	et	3	main
kartulivõtt	doc_491521502166_item	2615184	et	3	main
tähtis	doc_491521502166_item	2615189	et	4	main
ettevõtmine	doc_491521502166_item	2615191	et	3	main
eestlased	doc_491521502166_item	2615203	et	3	main
teistmoodi	doc_491521502166_item	2615206	et	3	main
mahlakasem	doc_491521502166_item	2615212	et	4	main
on	doc_491521502166_item	2615221	et	4	main
külas	doc_491521502166_item	2615232	et	3	main
inimene	doc_491521502166_item	2615238	et	3	main
emakeelt	doc_491521502166_item	2615240	et	4	main
rääkida	doc_491521502166_item	2615243	et	3	main
sõnul	doc_491521502166_item	2615245	et	3	main
õpivad	doc_491521502166_item	2615246	et	3	main
lapsed	doc_491521502166_item	2615247	et	3	main
poolpõlenud	doc_491521502166_item	2615248	et	4	main
õpikud	doc_491521502166_item	2615256	et	3	main
tooma	doc_491521502166_item	2615265	et	3	main
on	doc_491521502166_item	2615269	et	4	main
päevad	doc_491521502166_item	2615270	et	3	main
veel	doc_491521502166_item	2615271	et	4	main
soe	doc_491521502166_item	2615272	et	4	main
sojad	doc_491521502166_item	2615273	et	3	main
lühendatud	doc_491521502166_item	2615304	et	4	main
laused	doc_491521502166_item	2615311	et	3	main
ja	doc_491521502166_item	2615316	et	3	main
kasutades	doc_491521502166_item	2615317	et	3	main
2	doc_491521502166_item	2615319	et	2	main
kaunim	doc_491521502166_item	2615328	et	4	main
naiselikum	doc_491521502166_item	2615334	et	4	main
ja	doc_491521502166_item	2615335	et	3	main
mehe	doc_491521502166_item	2615336	et	3	main
mehelikum	doc_491521502166_item	2615337	et	4	main
3	doc_491521502166_item	2615338	et	2	main
paras	doc_491521502166_item	2615339	et	3	main
võima	doc_491521502166_item	2615347	et	3	main
tagajärg	doc_491521502166_item	2615350	et	3	main
hingata	doc_491521502166_item	2615409	et	4	main
telefonihelin	doc_491521502166_item	2615412	et	3	main
katkestab	doc_491521502166_item	2615430	et	3	main
varahommikku	doc_491521502166_item	2615431	et	4	main
huvitava	doc_491521502166_item	2615440	et	4	main
vaatamise	doc_491521502166_item	2615442	et	4	main
ajal	doc_491521502166_item	2615443	et	4	main
olevad	doc_491521502166_item	2615447	et	4	main
sõnad	doc_491521502166_item	2615448	et	4	main
õigesse	doc_491521502166_item	2615449	et	3	main
3	doc_491521502166_item	2615474	et	2	main
autod	doc_491521502166_item	2615491	et	3	main
kiirde	doc_491521502166_item	2615495	et	4	main
praegu	doc_491521502166_item	2615499	et	3	main
kiiresti	doc_491521502166_item	2615511	et	3	main
selles	doc_491521502166_item	2615514	et	4	main
vaid	doc_491521502166_item	2615516	et	3	main
väikesed	doc_491521502166_item	2615517	et	4	main
i	doc_491521502166_item	2615078	et	4	main
toomet	doc_491521502166_item	2615086	et	4	main
naine	doc_491521502166_item	2615089	et	3	main
nägema	doc_491521502166_item	2615091	et	3	main
ta	doc_491521502166_item	2615093	et	4	main
ülem-suetuki	doc_491521502166_item	2615099	et	4	main
konkurssi	doc_491521502166_item	2615109	et	4	main
õpetamas	doc_491521502166_item	2615123	et	3	main
kinnitusel	doc_491521502166_item	2615125	et	4	main
korraliku	doc_491521502166_item	2615144	et	3	main
maaliti	doc_491521502166_item	2615147	et	3	main
rohi	doc_491521502166_item	2615160	et	4	main
tahtmise	doc_491521502166_item	2615165	et	4	main
algama	doc_491521502166_item	2615177	et	3	main
alganud	doc_491521502166_item	2615178	et	4	main
on	doc_491521502166_item	2615193	et	4	main
mõnus	doc_491521502166_item	2615207	et	4	main
mõnusam	doc_491521502166_item	2615210	et	4	main
venemaa	doc_491521502166_item	2615223	et	4	main
ülejäänud	doc_491521502166_item	2615226	et	4	main
ained	doc_491521502166_item	2615228	et	3	main
veidi	doc_491521502166_item	2615234	et	3	main
kolmsada	doc_491521502166_item	2615236	et	4	main
saab	doc_491521502166_item	2615241	et	3	main
varsti	doc_491521502166_item	2615251	et	3	main
saatma	doc_491521502166_item	2615252	et	3	main
eestist	doc_491521502166_item	2615254	et	3	main
talve	doc_491521502166_item	2615258	et	4	main
toodi	doc_491521502166_item	2615266	et	4	main
vapralt	doc_491521502166_item	2615303	et	4	main
etteantud	doc_491521502166_item	2615309	et	4	main
sõnadest	doc_491521502166_item	2615310	et	3	main
sõnad	doc_491521502166_item	2615313	et	4	main
vormi	doc_491521502166_item	2615315	et	4	main
kirjavahemärke	doc_491521502166_item	2615318	et	4	main
naeratus	doc_491521502166_item	2615320	et	4	main
on	doc_491521502166_item	2615132	et	4	main
oodatud	doc_491521502166_item	2615133	et	4	main
olin	doc_491521502166_item	2615134	et	3	main
üsna	doc_491521502166_item	2615135	et	3	main
üllatuma	doc_491521502166_item	2615136	et	3	main
üllatunud	doc_491521502166_item	2615137	et	4	main
kui	doc_491521502166_item	2615138	et	3	main
mulle	doc_491521502166_item	2615139	et	4	main
audiga	doc_491521502166_item	2615145	et	3	main
kui	doc_491521502166_item	2615161	et	3	main
tahtmine	doc_491521502166_item	2615164	et	4	main
täis	doc_491521502166_item	2615166	et	4	main
piret	doc_491521502166_item	2615167	et	4	main
küla	doc_491521502166_item	2615180	et	4	main
kartuleid	doc_491521502166_item	2615183	et	3	main
kõige	doc_491521502166_item	2615188	et	4	main
tänaseks	doc_491521502166_item	2615192	et	4	main
kartul	doc_491521502166_item	2615194	et	3	main
salv	doc_491521502166_item	2615195	et	3	main
ja	doc_491521502166_item	2615196	et	3	main
õppimine	doc_491521502166_item	2615197	et	4	main
käib	doc_491521502166_item	2615198	et	3	main
täie	doc_491521502166_item	2615199	et	3	main
hoog	doc_491521502166_item	2615200	et	3	main
ja	doc_491521502166_item	2615208	et	3	main
murret	doc_491521502166_item	2615219	et	4	main
kool	doc_491521502166_item	2615220	et	4	main
siber	doc_491521502166_item	2615148	et	4	main
siberist	doc_491521502166_item	2615149	et	4	main
lenda	doc_491521502166_item	2615156	et	4	main
lind	doc_491521502166_item	2615157	et	3	main
ega	doc_491521502166_item	2615158	et	3	main
kasva	doc_491521502166_item	2615159	et	4	main
pärast	doc_491521502166_item	2615168	et	4	main
õppeaasta	doc_491521502166_item	2615169	et	4	main
algust	doc_491521502166_item	2615170	et	4	main
koht	doc_491521502166_item	2615171	et	3	main
kool	doc_491521502166_item	2615175	et	4	main
siin	doc_491521502166_item	2615186	et	4	main
hooguga	doc_491521502166_item	2615201	et	4	main
siinsed	doc_491521502166_item	2615202	et	3	main
kuidagi	doc_491521502166_item	2615205	et	3	main
mahlakas	doc_491521502166_item	2615209	et	4	main
ja	doc_491521502166_item	2615211	et	3	main
mitte	doc_491521502166_item	2615213	et	3	main
vene	doc_491521502166_item	2615214	et	4	main
aktsent	doc_491521502166_item	2615215	et	3	main
vaid	doc_491521502166_item	2615216	et	3	main
nagu	doc_491521502166_item	2615217	et	3	main
mõni	doc_491521502166_item	2615218	et	3	main
kool	doc_491521502166_item	2615224	et	4	main
keeles	doc_491521502166_item	2615231	et	4	main
inimese	doc_491521502166_item	2615239	et	4	main
kõik	doc_491521502166_item	2615242	et	4	main
pireti	doc_491521502166_item	2615244	et	4	main
uued	doc_491521502166_item	2615255	et	3	main
praegu	doc_491521502166_item	2615268	et	3	main
piret	doc_491521502166_item	2615302	et	4	main
iii	doc_491521502166_item	2615307	et	4	main
moodustage	doc_491521502166_item	2615308	et	3	main
mehelikum	doc_491521502166_item	2615326	et	4	main
naeratus	doc_491521502166_item	2615330	et	4	main
igaühe	doc_491521502166_item	2615332	et	4	main
aga	doc_491521502166_item	2615345	et	3	main
soovimatu	doc_491521502166_item	2615349	et	4	main
meid	doc_491521502166_item	2615353	et	4	main
paras	doc_491521502166_item	2615354	et	3	main
kogus	doc_491521502166_item	2615355	et	4	main
tegutsema	doc_491521502166_item	2615356	et	3	main
tagajarje	doc_491521502166_item	2615362	et	4	main
aparat	doc_491521502166_item	2615401	et	4	main
ja	doc_491521502166_item	2615408	et	3	main
pühapäev	doc_491521502166_item	2615415	et	3	main
lõunasöök	doc_491521502166_item	2615419	et	3	main
võtma	doc_491521502166_item	2615181	et	3	main
on	doc_491521502166_item	2615185	et	4	main
sügisel	doc_491521502166_item	2615187	et	3	main
tähtsam	doc_491521502166_item	2615190	et	4	main
räägivad	doc_491521502166_item	2615204	et	3	main
ja	doc_491521502166_item	2615225	et	3	main
aine	doc_491521502166_item	2615227	et	4	main
õpetatakse	doc_491521502166_item	2615229	et	3	main
vene	doc_491521502166_item	2615230	et	4	main
kolmesaja	doc_491521502166_item	2615237	et	4	main
raamatuid	doc_491521502166_item	2615250	et	3	main
saadavad	doc_491521502166_item	2615253	et	4	main
siberi	doc_491521502166_item	2615257	et	4	main
piret	doc_491521502166_item	2615259	et	4	main
ei	doc_491521502166_item	2615260	et	4	main
kartma	doc_491521502166_item	2615261	et	3	main
karta	doc_491521502166_item	2615262	et	3	main
slõhtuleht	doc_491521502166_item	2615306	et	4	main
pannes	doc_491521502166_item	2615312	et	4	main
õigesse	doc_491521502166_item	2615314	et	3	main
ja	doc_491521502166_item	2615324	et	3	main
kogus	doc_491521502166_item	2615340	et	4	main
stress	doc_491521502166_item	2615341	et	3	main
panema	doc_491521502166_item	2615342	et	3	main
tooma	doc_491521502166_item	2615348	et	3	main
aga	doc_491521502166_item	2615357	et	3	main
lisakoormus	doc_491521502166_item	2615358	et	3	main
võib	doc_491521502166_item	2615359	et	3	main
tua	doc_491521502166_item	2615360	et	4	main
4	doc_491521502166_item	2615363	et	2	main
tohtima	doc_491521502166_item	2615365	et	3	main
saama	doc_491521502166_item	2615385	et	4	main
maagiline	doc_491521502166_item	2615387	et	4	main
aparaat	doc_491521502166_item	2615388	et	3	main
et	doc_491521502166_item	2615389	et	3	main
see	doc_491521502166_item	2615390	et	3	main
abil	doc_491521502166_item	2615391	et	4	main
et	doc_491521502166_item	2615402	et	3	main
sul	doc_491521502166_item	2615403	et	3	main
abil	doc_491521502166_item	2615404	et	4	main
saab	doc_491521502166_item	2615405	et	3	main
6	doc_491521502166_item	2615410	et	2	main
ka	doc_491521502166_item	2615414	et	3	main
varahommik	doc_491521502166_item	2615416	et	3	main
segama	doc_491521502166_item	2615418	et	3	main
valmistamine	doc_491521502166_item	2615420	et	4	main
söömine	doc_491521502166_item	2615422	et	4	main
huvitav	doc_491521502166_item	2615424	et	4	main
telesaade	doc_491521502166_item	2615425	et	4	main
vaatamine	doc_491521502166_item	2615426	et	4	main
aeg	doc_491521502166_item	2615427	et	3	main
valmistamisel	doc_491521502166_item	2615435	et	4	main
telesaade	doc_491521502166_item	2615441	et	4	main
sulgudes	doc_491521502166_item	2615446	et	4	main
igaüks	doc_491521502166_item	2615467	et	3	main
igaühte	doc_491521502166_item	2615468	et	4	main
2	doc_491521502166_item	2615469	et	2	main
kohandasin	doc_491521502166_item	2615470	et	3	main
artikli	doc_491521502166_item	2615471	et	3	main
nõuded	doc_491521502166_item	2615472	et	3	main
sportis	doc_491521502166_item	2615481	et	3	main
ilusate	doc_491521502166_item	2615492	et	3	main
piirdusime	doc_491521502166_item	2615513	et	3	main
muudatused	doc_491521502166_item	2615518	et	3	main
kuulub	doc_491521502166_item	2615524	et	3	main
külmetamine	doc_491521502166_item	2615539	et	4	main
külmetamist	doc_491521502166_item	2615540	et	4	main
10	doc_491521502166_item	2615541	et	2	main
ma	doc_491521502166_item	2615542	et	3	main
tunnen	doc_491521502166_item	2615543	et	3	main
päikesest	doc_491521502166_item	2615548	et	4	main
v	doc_491521502166_item	2615549	et	4	main
lüngad	doc_491521502166_item	2615551	et	3	main
sidenditega	doc_491521502166_item	2615553	et	3	main
tellisime	doc_491521502166_item	2615555	et	4	main
kolmekäigulise	doc_491521502166_item	2615556	et	4	main
lapsel	doc_491521502166_item	2615571	et	4	main
paluti	doc_491521502166_item	2615572	et	3	main
oodata	doc_491521502166_item	2615573	et	4	main
nii	doc_491521502166_item	2615574	et	3	main
kaua	doc_491521502166_item	2615575	et	3	main
siiski	doc_491521502166_item	2615222	et	4	main
elab	doc_491521502166_item	2615233	et	3	main
üle	doc_491521502166_item	2615235	et	3	main
raamatud	doc_491521502166_item	2615249	et	4	main
mulle	doc_491521502166_item	2615263	et	4	main
juba	doc_491521502166_item	2615264	et	3	main
talvepuud	doc_491521502166_item	2615267	et	4	main
kuid	doc_491521502166_item	2615274	et	4	main
ööd	doc_491521502166_item	2615275	et	4	main
juba	doc_491521502166_item	2615276	et	3	main
jahe	doc_491521502166_item	2615277	et	3	main
jahedad	doc_491521502166_item	2615278	et	3	main
harjutan	doc_491521502166_item	2615279	et	3	main
juba	doc_491521502166_item	2615280	et	3	main
suure	doc_491521502166_item	2615281	et	3	main
vene	doc_491521502166_item	2615282	et	4	main
ahju	doc_491521502166_item	2615283	et	4	main
kütmine	doc_491521502166_item	2615284	et	4	main
kütmist	doc_491521502166_item	2615285	et	4	main
kui	doc_491521502166_item	2615286	et	3	main
vaja	doc_491521502166_item	2615287	et	4	main
ostan	doc_491521502166_item	2615288	et	3	main
külapood	doc_491521502166_item	2615289	et	3	main
külapoest	doc_491521502166_item	2615290	et	4	main
vildid	doc_491521502166_item	2615291	et	4	main
ega	doc_491521502166_item	2615292	et	3	main
seal	doc_491521502166_item	2615293	et	4	main
suurt	doc_491521502166_item	2615294	et	3	main
muud	doc_491521502166_item	2615295	et	4	main
ei	doc_491521502166_item	2615296	et	4	main
naerab	doc_491521502166_item	2615298	et	3	main
talveks	doc_491521502166_item	2615299	et	4	main
müüdagi	doc_491521502166_item	2615297	et	3	main
valmistuma	doc_491521502166_item	2615300	et	3	main
valmistunud	doc_491521502166_item	2615301	et	4	main
ajalehest	doc_491521502166_item	2615305	et	4	main
tegema	doc_491521502166_item	2615321	et	3	main
naiselikum	doc_491521502166_item	2615323	et	4	main
mehed	doc_491521502166_item	2615325	et	3	main
kaunis	doc_491521502166_item	2615329	et	4	main
meie	doc_491521502166_item	2615343	et	4	main
tegutsema	doc_491521502166_item	2615344	et	3	main
soovimatuid	doc_491521502166_item	2615361	et	4	main
ei	doc_491521502166_item	2615364	et	4	main
lausa	doc_491521502166_item	2615392	et	4	main
elama	doc_491521502166_item	2615393	et	3	main
ja	doc_491521502166_item	2615394	et	3	main
hingama	doc_491521502166_item	2615395	et	3	main
tänapäeval	doc_491521502166_item	2615396	et	3	main
telefon	doc_491521502166_item	2615397	et	3	main
nii	doc_491521502166_item	2615399	et	3	main
maagiline	doc_491521502166_item	2615400	et	4	main
elada	doc_491521502166_item	2615407	et	3	main
kuid	doc_491521502166_item	2615411	et	4	main
katkestama	doc_491521502166_item	2615413	et	3	main
uni	doc_491521502166_item	2615417	et	3	main
kuid	doc_491521502166_item	2615428	et	4	main
telefonihelin	doc_491521502166_item	2615429	et	3	main
ja	doc_491521502166_item	2615436	et	3	main
iv	doc_491521502166_item	2615444	et	4	main
pange	doc_491521502166_item	2615445	et	4	main
pean	doc_491521502166_item	2615453	et	4	main
nõudeid	doc_491521502166_item	2615473	et	3	main
huvitud	doc_491521502166_item	2615479	et	4	main
tunned	doc_491521502166_item	2615484	et	3	main
ainult	doc_491521502166_item	2615486	et	4	main
ilusad	doc_491521502166_item	2615487	et	3	main
naised	doc_491521502166_item	2615488	et	3	main
ja	doc_491521502166_item	2615489	et	3	main
kiired	doc_491521502166_item	2615490	et	4	main
6	doc_491521502166_item	2615512	et	2	main
muudatusi	doc_491521502166_item	2615520	et	3	main
see	doc_491521502166_item	2615522	et	3	main
valdkond	doc_491521502166_item	2615526	et	3	main
valdkonda	doc_491521502166_item	2615528	et	4	main
kleepus	doc_491521502166_item	2615531	et	3	main
püksid	doc_491521502166_item	2615532	et	3	main
pükstele	doc_491521502166_item	2615533	et	3	main
ajal	doc_491521502166_item	2615536	et	4	main
peab	doc_491521502166_item	2615537	et	4	main
hoiduma	doc_491521502166_item	2615538	et	3	main
suvine	doc_491521502166_item	2615545	et	4	main
sobivate	doc_491521502166_item	2615552	et	4	main
kõik	doc_491521502166_item	2615565	et	4	main
õpilased	doc_491521502166_item	2615566	et	3	main
tulevad	doc_491521502166_item	2615579	et	4	main
naeru	doc_491521502166_item	2615583	et	4	main
ei	doc_491521502166_item	2615592	et	4	main
läheb	doc_491521502166_item	2615597	et	3	main
6	doc_491521502166_item	2615600	et	2	main
7	doc_491521502166_item	2615607	et	2	main
naised	doc_491521502166_item	2615322	et	3	main
igaüks	doc_491521502166_item	2615327	et	3	main
teeb	doc_491521502166_item	2615331	et	3	main
naise	doc_491521502166_item	2615333	et	3	main
lisakoormus	doc_491521502166_item	2615346	et	3	main
stress	doc_491521502166_item	2615351	et	3	main
paneb	doc_491521502166_item	2615352	et	3	main
laskma	doc_491521502166_item	2615366	et	3	main
ülekoormus	doc_491521502166_item	2615367	et	3	main
tekkima	doc_491521502166_item	2615368	et	3	main
pinge	doc_491521502166_item	2615369	et	4	main
saama	doc_491521502166_item	2615370	et	4	main
maandama	doc_491521502166_item	2615371	et	3	main
sportima	doc_491521502166_item	2615372	et	4	main
ja	doc_491521502166_item	2615373	et	3	main
puhkama	doc_491521502166_item	2615374	et	3	main
ei	doc_491521502166_item	2615375	et	4	main
tohi	doc_491521502166_item	2615376	et	4	main
ülekoormusel	doc_491521502166_item	2615377	et	3	main
lasta	doc_491521502166_item	2615378	et	4	main
pinget	doc_491521502166_item	2615379	et	3	main
saama	doc_491521502166_item	2615380	et	4	main
5	doc_491521502166_item	2615381	et	2	main
telefon	doc_491521502166_item	2615382	et	3	main
olema	doc_491521502166_item	2615383	et	4	main
tänapäev	doc_491521502166_item	2615384	et	3	main
nii	doc_491521502166_item	2615386	et	3	main
on	doc_491521502166_item	2615398	et	4	main
lausa	doc_491521502166_item	2615406	et	4	main
ja	doc_491521502166_item	2615421	et	3	main
pahandab	doc_491521502166_item	2615423	et	3	main
segab	doc_491521502166_item	2615433	et	3	main
lõunasööki	doc_491521502166_item	2615434	et	4	main
pahandab	doc_491521502166_item	2615438	et	3	main
1	doc_491521502166_item	2615451	et	2	main
ma	doc_491521502166_item	2615452	et	3	main
usaldavad	doc_491521502166_item	2615466	et	4	main
ma	doc_491521502166_item	2615475	et	3	main
sa	doc_491521502166_item	2615478	et	3	main
sport	doc_491521502166_item	2615480	et	3	main
aga	doc_491521502166_item	2615482	et	3	main
ja	doc_491521502166_item	2615494	et	3	main
kohta	doc_491521502166_item	2615497	et	4	main
4	doc_491521502166_item	2615498	et	2	main
on	doc_491521502166_item	2615500	et	4	main
oht	doc_491521502166_item	2615501	et	3	main
haigestuda	doc_491521502166_item	2615502	et	3	main
difteeria	doc_491521502166_item	2615503	et	4	main
difteeriaga	doc_491521502166_item	2615504	et	3	main
5	doc_491521502166_item	2615505	et	2	main
tüdinesin	doc_491521502166_item	2615506	et	3	main
uus	doc_491521502166_item	2615507	et	3	main
töökoht	doc_491521502166_item	2615508	et	3	main
uest	doc_491521502166_item	2615509	et	4	main
küsimus	doc_491521502166_item	2615523	et	4	main
päike	doc_491521502166_item	2615546	et	3	main
täitke	doc_491521502166_item	2615550	et	3	main
1	doc_491521502166_item	2615554	et	2	main
kohal	doc_491521502166_item	2615563	et	4	main
ja	doc_491521502166_item	2615567	et	3	main
õpetajad	doc_491521502166_item	2615569	et	4	main
nagu	doc_491521502166_item	2615584	et	3	main
oleks	doc_491521502166_item	2615585	et	3	main
just	doc_491521502166_item	2615587	et	3	main
tule	doc_491521502166_item	2615593	et	4	main
hoopis	doc_491521502166_item	2615598	et	3	main
töö	doc_491521502166_item	2615602	et	4	main
ei	doc_491521502166_item	2615623	et	4	main
9	doc_491521502166_item	2615625	et	2	main
kas	doc_491521502166_item	2615626	et	3	main
sa	doc_491521502166_item	2615627	et	3	main
sõidad	doc_491521502166_item	2615628	et	3	main
avasin	doc_491521502166_item	2615634	et	3	main
õigesse	doc_491521502167_item	2615650	et	3	main
piret	doc_491521502167_item	2615652	et	4	main
toomet	doc_491521502167_item	2615653	et	4	main
küla	doc_491521502167_item	2615667	et	4	main
külas	doc_491521502167_item	2615668	et	3	main
otsitakse	doc_491521502167_item	2615669	et	3	main
eestlastele	doc_491521502167_item	2615685	et	4	main
emakeelt	doc_491521502167_item	2615688	et	4	main
pireti	doc_491521502167_item	2615691	et	4	main
kinnitusel	doc_491521502167_item	2615692	et	4	main
tundis	doc_491521502167_item	2615693	et	3	main
jõuda	doc_491521502167_item	2615697	et	3	main
kui	doc_491521502167_item	2615705	et	3	main
tulema	doc_491521502167_item	2615707	et	4	main
seal	doc_491521502167_item	2615720	et	4	main
und	doc_491521502166_item	2615432	et	4	main
söömisel	doc_491521502166_item	2615437	et	4	main
ka	doc_491521502166_item	2615439	et	3	main
vormi	doc_491521502166_item	2615450	et	4	main
väga	doc_491521502166_item	2615454	et	3	main
lugu	doc_491521502166_item	2615455	et	4	main
oma	doc_491521502166_item	2615456	et	4	main
vanemad	doc_491521502166_item	2615457	et	4	main
oma	doc_491521502166_item	2615458	et	4	main
vanematest	doc_491521502166_item	2615459	et	4	main
sest	doc_491521502166_item	2615460	et	4	main
nad	doc_491521502166_item	2615461	et	3	main
aitavad	doc_491521502166_item	2615462	et	4	main
kõik	doc_491521502166_item	2615463	et	4	main
kõike	doc_491521502166_item	2615464	et	4	main
ja	doc_491521502166_item	2615465	et	3	main
arvasin	doc_491521502166_item	2615476	et	3	main
et	doc_491521502166_item	2615477	et	3	main
sa	doc_491521502166_item	2615483	et	3	main
huvi	doc_491521502166_item	2615485	et	4	main
naiste	doc_491521502166_item	2615493	et	3	main
autode	doc_491521502166_item	2615496	et	3	main
töökohast	doc_491521502166_item	2615510	et	4	main
küsimuses	doc_491521502166_item	2615515	et	4	main
vaikesi	doc_491521502166_item	2615519	et	4	main
7	doc_491521502166_item	2615521	et	2	main
külmal	doc_491521502166_item	2615535	et	3	main
suvisest	doc_491521502166_item	2615547	et	4	main
maksis	doc_491521502166_item	2615560	et	4	main
palju	doc_491521502166_item	2615561	et	4	main
2	doc_491521502166_item	2615562	et	2	main
nende	doc_491521502166_item	2615568	et	4	main
3	doc_491521502166_item	2615570	et	2	main
tagasi	doc_491521502166_item	2615578	et	3	main
4	doc_491521502166_item	2615580	et	2	main
kõrvallauast	doc_491521502166_item	2615581	et	4	main
anekdooti	doc_491521502166_item	2615588	et	4	main
rääkinud	doc_491521502166_item	2615589	et	4	main
5	doc_491521502166_item	2615590	et	2	main
te	doc_491521502166_item	2615603	et	4	main
varsti	doc_491521502166_item	2615604	et	3	main
baaris	doc_491521502166_item	2615609	et	3	main
jääd	doc_491521502166_item	2615631	et	4	main
linna	doc_491521502166_item	2615632	et	4	main
koputust	doc_491521502166_item	2615638	et	4	main
eesti	doc_491521502167_item	2615639	et	4	main
nägi	doc_491521502167_item	2615659	et	3	main
ajalehes	doc_491521502167_item	2615661	et	3	main
piret	doc_491521502167_item	2615673	et	4	main
võitis	doc_491521502167_item	2615674	et	3	main
konkurss	doc_491521502167_item	2615675	et	3	main
väikestele	doc_491521502167_item	2615684	et	4	main
et	doc_491521502167_item	2615698	et	3	main
oodatud	doc_491521502167_item	2615700	et	4	main
mulle	doc_491521502167_item	2615706	et	4	main
ei	doc_491521502167_item	2615721	et	4	main
kasva	doc_491521502167_item	2615726	et	4	main
piret	doc_491521502167_item	2615734	et	4	main
võttis	doc_491521502167_item	2615749	et	3	main
tähtsam	doc_491521502167_item	2615757	et	4	main
täie	doc_491521502167_item	2615766	et	3	main
kuidagi	doc_491521502167_item	2615771	et	3	main
mahlakas	doc_491521502167_item	2615775	et	4	main
mõnusalt	doc_491521502167_item	2615776	et	4	main
ja	doc_491521502167_item	2615777	et	3	main
aktsentiga	doc_491521502167_item	2615782	et	4	main
mõni	doc_491521502167_item	2615785	et	3	main
murret	doc_491521502167_item	2615787	et	4	main
ja	doc_491521502167_item	2615793	et	3	main
keeles	doc_491521502167_item	2615799	et	4	main
kolmsada	doc_491521502167_item	2615804	et	4	main
kolmesaja	doc_491521502167_item	2615805	et	4	main
inimene	doc_491521502167_item	2615806	et	3	main
inimest	doc_491521502167_item	2615807	et	3	main
poolpõlenud	doc_491521502167_item	2615817	et	4	main
raamatuid	doc_491521502167_item	2615819	et	3	main
varsti	doc_491521502167_item	2615820	et	3	main
talve	doc_491521502167_item	2615827	et	4	main
ei	doc_491521502167_item	2615829	et	4	main
suure	doc_491521502167_item	2615850	et	3	main
ostan	doc_491521502167_item	2615857	et	3	main
muud	doc_491521502167_item	2615864	et	4	main
ei	doc_491521502167_item	2615865	et	4	main
müüdagi	doc_491521502167_item	2615866	et	3	main
naerab	doc_491521502167_item	2615867	et	3	main
lühendatud	doc_491521502167_item	2615873	et	4	main
moodustage	doc_491521502167_item	2615877	et	3	main
naeratus	doc_491521502167_item	2615889	et	4	main
kogus	doc_491521502167_item	2615921	et	4	main
paneb	doc_491521502167_item	2615923	et	3	main
laskma	doc_491521502167_item	2615935	et	3	main
tohi	doc_491521502167_item	2615945	et	4	main
tänapaeval	doc_491521502167_item	2615965	et	4	main
pahandab	doc_491521502167_item	2615992	et	3	main
varahommiku	doc_491521502167_item	2616001	et	3	main
und	doc_491521502167_item	2616002	et	4	main
segab	doc_491521502167_item	2616003	et	3	main
teine	doc_491521502166_item	2615525	et	3	main
teise	doc_491521502166_item	2615527	et	4	main
8	doc_491521502166_item	2615529	et	2	main
närimiskumm	doc_491521502166_item	2615530	et	3	main
9	doc_491521502166_item	2615534	et	2	main
rõõmu	doc_491521502166_item	2615544	et	4	main
lõuna	doc_491521502166_item	2615557	et	4	main
ja	doc_491521502166_item	2615558	et	3	main
see	doc_491521502166_item	2615559	et	3	main
olid	doc_491521502166_item	2615564	et	4	main
vanemad	doc_491521502166_item	2615577	et	4	main
ta	doc_491521502166_item	2615591	et	4	main
sest	doc_491521502166_item	2615595	et	4	main
ta	doc_491521502166_item	2615596	et	4	main
teatrisse	doc_491521502166_item	2615599	et	3	main
lõpetage	doc_491521502166_item	2615601	et	3	main
jalutama	doc_491521502166_item	2615606	et	3	main
ei	doc_491521502166_item	2615610	et	4	main
suitsetada	doc_491521502166_item	2615612	et	3	main
ja	doc_491521502166_item	2615613	et	3	main
tohi	doc_491521502166_item	2615611	et	4	main
alkoholi	doc_491521502166_item	2615614	et	4	main
tarbida	doc_491521502166_item	2615615	et	3	main
8	doc_491521502166_item	2615616	et	2	main
nad	doc_491521502166_item	2615617	et	3	main
töötasid	doc_491521502166_item	2615618	et	4	main
küll	doc_491521502166_item	2615619	et	4	main
pingsalt	doc_491521502166_item	2615620	et	4	main
aga	doc_491521502166_item	2615621	et	3	main
voi	doc_491521502166_item	2615630	et	4	main
10	doc_491521502166_item	2615633	et	2	main
sest	doc_491521502166_item	2615636	et	4	main
kuulsin	doc_491521502166_item	2615637	et	3	main
keele	doc_491521502167_item	2615643	et	4	main
test	doc_491521502167_item	2615644	et	3	main
ta	doc_491521502167_item	2615660	et	4	main
ülem-suetuki	doc_491521502167_item	2615666	et	4	main
eesti	doc_491521502167_item	2615670	et	4	main
keele	doc_491521502167_item	2615671	et	4	main
nüüd	doc_491521502167_item	2615679	et	4	main
juba	doc_491521502167_item	2615680	et	3	main
üle	doc_491521502167_item	2615681	et	3	main
nädal	doc_491521502167_item	2615682	et	3	main
nädalat	doc_491521502167_item	2615683	et	3	main
neid	doc_491521502167_item	2615687	et	4	main
õpetama	doc_491521502167_item	2615689	et	3	main
siberisse	doc_491521502167_item	2615695	et	4	main
üllatunud	doc_491521502167_item	2615704	et	4	main
tuli	doc_491521502167_item	2615708	et	4	main
vastu	doc_491521502167_item	2615709	et	3	main
korralik	doc_491521502167_item	2615710	et	3	main
korraliku	doc_491521502167_item	2615711	et	3	main
audiga	doc_491521502167_item	2615712	et	3	main
mulle	doc_491521502167_item	2615713	et	4	main
maaliti	doc_491521502167_item	2615714	et	3	main
rohi	doc_491521502167_item	2615727	et	4	main
kui	doc_491521502167_item	2615728	et	3	main
noor	doc_491521502167_item	2615729	et	3	main
ja	doc_491521502167_item	2615730	et	3	main
pärast	doc_491521502167_item	2615735	et	4	main
veel	doc_491521502167_item	2615743	et	4	main
võtma	doc_491521502167_item	2615748	et	3	main
kartuleid	doc_491521502167_item	2615750	et	3	main
on	doc_491521502167_item	2615752	et	4	main
kõige	doc_491521502167_item	2615755	et	4	main
tähtis	doc_491521502167_item	2615756	et	4	main
õppimine	doc_491521502167_item	2615764	et	4	main
teistmoodi	doc_491521502167_item	2615772	et	3	main
mahlakalt	doc_491521502167_item	2615778	et	4	main
mitte	doc_491521502167_item	2615779	et	3	main
vaid	doc_491521502167_item	2615783	et	3	main
siiski	doc_491521502167_item	2615790	et	4	main
kui	doc_491521502166_item	2615576	et	3	main
kostis	doc_491521502166_item	2615582	et	4	main
keegi	doc_491521502166_item	2615586	et	4	main
trenni	doc_491521502166_item	2615594	et	4	main
lähete	doc_491521502166_item	2615605	et	4	main
selles	doc_491521502166_item	2615608	et	4	main
maale	doc_491521502166_item	2615629	et	4	main
ukse	doc_491521502166_item	2615635	et	3	main
eesti	doc_491521502167_item	2615642	et	4	main
i	doc_491521502167_item	2615645	et	4	main
pange	doc_491521502167_item	2615646	et	4	main
vormi	doc_491521502167_item	2615651	et	4	main
kuulutus	doc_491521502167_item	2615662	et	4	main
kuulutuse	doc_491521502167_item	2615663	et	4	main
et	doc_491521502167_item	2615664	et	3	main
siberisse	doc_491521502167_item	2615665	et	4	main
konkurssi	doc_491521502167_item	2615676	et	4	main
ja	doc_491521502167_item	2615677	et	3	main
on	doc_491521502167_item	2615678	et	4	main
ta	doc_491521502167_item	2615694	et	4	main
siber	doc_491521502167_item	2615715	et	4	main
tahtmine	doc_491521502167_item	2615731	et	4	main
õppeaasta	doc_491521502167_item	2615736	et	4	main
algama	doc_491521502167_item	2615744	et	3	main
alganud	doc_491521502167_item	2615745	et	4	main
kartulivõtt	doc_491521502167_item	2615751	et	3	main
sügisel	doc_491521502167_item	2615754	et	3	main
salv	doc_491521502167_item	2615762	et	3	main
ja	doc_491521502167_item	2615763	et	3	main
käib	doc_491521502167_item	2615765	et	3	main
mõnus	doc_491521502167_item	2615773	et	4	main
vene	doc_491521502167_item	2615780	et	4	main
venemaa	doc_491521502167_item	2615791	et	4	main
kool	doc_491521502167_item	2615792	et	4	main
ained	doc_491521502167_item	2615796	et	3	main
vene	doc_491521502167_item	2615798	et	4	main
külas	doc_491521502167_item	2615800	et	3	main
elab	doc_491521502167_item	2615801	et	3	main
veidi	doc_491521502167_item	2615802	et	3	main
rääkida	doc_491521502167_item	2615812	et	3	main
mulle	doc_491521502167_item	2615832	et	4	main
juba	doc_491521502167_item	2615833	et	3	main
tooma	doc_491521502167_item	2615834	et	3	main
ööd	doc_491521502167_item	2615844	et	4	main
juba	doc_491521502167_item	2615845	et	3	main
jahe	doc_491521502167_item	2615846	et	3	main
jahedad	doc_491521502167_item	2615847	et	3	main
harjutan	doc_491521502167_item	2615848	et	3	main
juba	doc_491521502167_item	2615849	et	3	main
vene	doc_491521502167_item	2615851	et	4	main
ahju	doc_491521502167_item	2615852	et	4	main
külapood	doc_491521502167_item	2615858	et	3	main
piret	doc_491521502167_item	2615871	et	4	main
etteantud	doc_491521502167_item	2615878	et	4	main
sõnadest	doc_491521502167_item	2615879	et	3	main
pannes	doc_491521502167_item	2615881	et	4	main
stress	doc_491521502167_item	2615922	et	3	main
4	doc_491521502167_item	2615932	et	2	main
tekkima	doc_491521502167_item	2615937	et	3	main
saama	doc_491521502167_item	2615939	et	4	main
olema	doc_491521502167_item	2615952	et	4	main
et	doc_491521502167_item	2615958	et	3	main
selle	doc_491521502167_item	2615972	et	4	main
söömine	doc_491521502167_item	2615991	et	4	main
telesaade	doc_491521502167_item	2615994	et	4	main
ka	doc_491521502167_item	2616008	et	3	main
iv	doc_491521502167_item	2616014	et	4	main
ma	doc_491521502167_item	2616022	et	3	main
2	doc_491521502167_item	2616039	et	2	main
3	doc_491521502167_item	2616044	et	2	main
ma	doc_491521502167_item	2616045	et	3	main
ainult	doc_491521502167_item	2616056	et	4	main
kiired	doc_491521502167_item	2616060	et	4	main
autodele	doc_491521502167_item	2616066	et	3	main
praegu	doc_491521502167_item	2616068	et	3	main
on	doc_491521502167_item	2616069	et	4	main
oht	doc_491521502167_item	2616070	et	3	main
haigestuda	doc_491521502167_item	2616071	et	3	main
difteeria	doc_491521502167_item	2616072	et	4	main
difteeriaga	doc_491521502167_item	2616073	et	3	main
5	doc_491521502167_item	2616074	et	2	main
tüdinesin	doc_491521502167_item	2616075	et	3	main
tulemust	doc_491521502166_item	2615622	et	4	main
olnud	doc_491521502166_item	2615624	et	4	main
keele	doc_491521502167_item	2615640	et	4	main
test	doc_491521502167_item	2615641	et	3	main
sulgudes	doc_491521502167_item	2615647	et	4	main
olevad	doc_491521502167_item	2615648	et	4	main
sõnad	doc_491521502167_item	2615649	et	4	main
on	doc_491521502167_item	2615654	et	4	main
ettevõtlik	doc_491521502167_item	2615655	et	3	main
naine	doc_491521502167_item	2615656	et	3	main
suvel	doc_491521502167_item	2615657	et	3	main
nägema	doc_491521502167_item	2615658	et	3	main
õpetajat	doc_491521502167_item	2615672	et	4	main
need	doc_491521502167_item	2615686	et	3	main
õpetab	doc_491521502167_item	2615690	et	3	main
jõudma	doc_491521502167_item	2615696	et	3	main
on	doc_491521502167_item	2615699	et	4	main
olin	doc_491521502167_item	2615701	et	3	main
üsna	doc_491521502167_item	2615702	et	3	main
üllatuma	doc_491521502167_item	2615703	et	3	main
siberi	doc_491521502167_item	2615716	et	4	main
selline	doc_491521502167_item	2615717	et	4	main
pilt	doc_491521502167_item	2615718	et	3	main
et	doc_491521502167_item	2615719	et	3	main
lendama	doc_491521502167_item	2615722	et	3	main
lenda	doc_491521502167_item	2615723	et	4	main
lind	doc_491521502167_item	2615724	et	3	main
ega	doc_491521502167_item	2615725	et	3	main
täis	doc_491521502167_item	2615733	et	4	main
kohale	doc_491521502167_item	2615739	et	4	main
jõudis	doc_491521502167_item	2615740	et	3	main
polnud	doc_491521502167_item	2615741	et	3	main
kool	doc_491521502167_item	2615742	et	4	main
küla	doc_491521502167_item	2615747	et	4	main
siin	doc_491521502167_item	2615753	et	4	main
on	doc_491521502167_item	2615760	et	4	main
kartul	doc_491521502167_item	2615761	et	3	main
siinsed	doc_491521502167_item	2615768	et	3	main
eestlased	doc_491521502167_item	2615769	et	3	main
ja	doc_491521502167_item	2615774	et	3	main
aktsent	doc_491521502167_item	2615781	et	3	main
üle	doc_491521502167_item	2615803	et	3	main
kõike	doc_491521502167_item	2615811	et	4	main
õpivad	doc_491521502167_item	2615815	et	3	main
raamatud	doc_491521502167_item	2615818	et	4	main
saatma	doc_491521502167_item	2615821	et	3	main
õpikud	doc_491521502167_item	2615825	et	3	main
piret	doc_491521502167_item	2615828	et	4	main
kartma	doc_491521502167_item	2615830	et	3	main
karda	doc_491521502167_item	2615831	et	4	main
praegu	doc_491521502167_item	2615837	et	3	main
päevad	doc_491521502167_item	2615839	et	3	main
kuid	doc_491521502167_item	2615843	et	4	main
vaja	doc_491521502167_item	2615856	et	4	main
vildid	doc_491521502167_item	2615860	et	4	main
seal	doc_491521502167_item	2615862	et	4	main
valmistuv	doc_491521502167_item	2615870	et	4	main
slõhtuleht	doc_491521502167_item	2615875	et	4	main
meid	doc_491521502167_item	2615924	et	4	main
ei	doc_491521502167_item	2615933	et	4	main
ülekoormus	doc_491521502167_item	2615936	et	3	main
ülekoormust	doc_491521502167_item	2615946	et	4	main
lasta	doc_491521502167_item	2615947	et	4	main
tänapäev	doc_491521502167_item	2615953	et	3	main
on	doc_491521502167_item	2615966	et	4	main
telefon	doc_491521502167_item	2615967	et	3	main
nii	doc_491521502167_item	2615968	et	3	main
aparaat	doc_491521502167_item	2615970	et	3	main
saab	doc_491521502167_item	2615974	et	3	main
pühapäeva	doc_491521502167_item	2616000	et	4	main
söömist	doc_491521502167_item	2616007	et	4	main
huvitava	doc_491521502167_item	2616010	et	4	main
olevad	doc_491521502167_item	2616017	et	4	main
sõnad	doc_491521502167_item	2616018	et	4	main
oma	doc_491521502167_item	2616028	et	4	main
kõike	doc_491521502167_item	2616034	et	4	main
ja	doc_491521502167_item	2616035	et	3	main
kohandasin	doc_491521502167_item	2616040	et	3	main
et	doc_491521502167_item	2616047	et	3	main
huvitud	doc_491521502167_item	2616049	et	4	main
aga	doc_491521502167_item	2616052	et	3	main
töökoha	doc_491521502167_item	2616079	et	4	main
kiiresti	doc_491521502167_item	2616080	et	3	main
tahtmise	doc_491521502167_item	2615732	et	4	main
algust	doc_491521502167_item	2615737	et	4	main
koht	doc_491521502167_item	2615738	et	3	main
kogu	doc_491521502167_item	2615746	et	4	main
ettevõtmine	doc_491521502167_item	2615758	et	3	main
tänaseks	doc_491521502167_item	2615759	et	4	main
hoog	doc_491521502167_item	2615767	et	3	main
räägivad	doc_491521502167_item	2615770	et	3	main
nagu	doc_491521502167_item	2615784	et	3	main
mõnet	doc_491521502167_item	2615786	et	4	main
kool	doc_491521502167_item	2615788	et	4	main
on	doc_491521502167_item	2615789	et	4	main
ülejäänud	doc_491521502167_item	2615794	et	4	main
pireti	doc_491521502167_item	2615813	et	4	main
lapsed	doc_491521502167_item	2615816	et	3	main
aine	doc_491521502167_item	2615795	et	4	main
õpetatakse	doc_491521502167_item	2615797	et	3	main
emakeelt	doc_491521502167_item	2615808	et	4	main
saab	doc_491521502167_item	2615809	et	3	main
kõik	doc_491521502167_item	2615810	et	4	main
sõnul	doc_491521502167_item	2615814	et	3	main
saatatakse	doc_491521502167_item	2615822	et	4	main
eestist	doc_491521502167_item	2615823	et	3	main
siberi	doc_491521502167_item	2615826	et	4	main
tooti	doc_491521502167_item	2615835	et	4	main
talvepuud	doc_491521502167_item	2615836	et	4	main
on	doc_491521502167_item	2615838	et	4	main
soe	doc_491521502167_item	2615841	et	4	main
kütmine	doc_491521502167_item	2615853	et	4	main
kütmisele	doc_491521502167_item	2615854	et	4	main
kui	doc_491521502167_item	2615855	et	3	main
külapoest	doc_491521502167_item	2615859	et	4	main
ega	doc_491521502167_item	2615861	et	3	main
suurt	doc_491521502167_item	2615863	et	3	main
vapralt	doc_491521502167_item	2615872	et	4	main
iii	doc_491521502167_item	2615876	et	4	main
laused	doc_491521502167_item	2615880	et	3	main
õigesse	doc_491521502167_item	2615883	et	3	main
vormi	doc_491521502167_item	2615884	et	4	main
ja	doc_491521502167_item	2615885	et	3	main
kasutades	doc_491521502167_item	2615886	et	3	main
kirjavahemärke	doc_491521502167_item	2615887	et	4	main
2	doc_491521502167_item	2615888	et	2	main
uued	doc_491521502167_item	2615824	et	3	main
veel	doc_491521502167_item	2615840	et	4	main
soojad	doc_491521502167_item	2615842	et	3	main
talveks	doc_491521502167_item	2615868	et	4	main
valmistuma	doc_491521502167_item	2615869	et	3	main
ajalehest	doc_491521502167_item	2615874	et	4	main
sõnad	doc_491521502167_item	2615882	et	4	main
tegema	doc_491521502167_item	2615890	et	3	main
naised	doc_491521502167_item	2615891	et	3	main
naiselikum	doc_491521502167_item	2615892	et	4	main
ja	doc_491521502167_item	2615893	et	3	main
mehed	doc_491521502167_item	2615894	et	3	main
igaüks	doc_491521502167_item	2615896	et	3	main
kaunim	doc_491521502167_item	2615897	et	4	main
naeratus	doc_491521502167_item	2615898	et	4	main
teeb	doc_491521502167_item	2615899	et	3	main
naisi	doc_491521502167_item	2615900	et	3	main
mehelikum	doc_491521502167_item	2615895	et	4	main
naiselikum	doc_491521502167_item	2615901	et	4	main
meesteid	doc_491521502167_item	2615902	et	3	main
mehelikum	doc_491521502167_item	2615903	et	4	main
ja	doc_491521502167_item	2615904	et	3	main
igaükse	doc_491521502167_item	2615905	et	3	main
kaunim	doc_491521502167_item	2615906	et	4	main
3	doc_491521502167_item	2615907	et	2	main
paras	doc_491521502167_item	2615908	et	3	main
kogus	doc_491521502167_item	2615909	et	4	main
stress	doc_491521502167_item	2615910	et	3	main
panema	doc_491521502167_item	2615911	et	3	main
meie	doc_491521502167_item	2615912	et	4	main
tegutsema	doc_491521502167_item	2615913	et	3	main
aga	doc_491521502167_item	2615914	et	3	main
lisakoormus	doc_491521502167_item	2615915	et	3	main
võima	doc_491521502167_item	2615916	et	3	main
tooma	doc_491521502167_item	2615917	et	3	main
soovimatu	doc_491521502167_item	2615918	et	4	main
tagajärg	doc_491521502167_item	2615919	et	3	main
paras	doc_491521502167_item	2615920	et	3	main
tagajärgi	doc_491521502167_item	2615931	et	4	main
pinge	doc_491521502167_item	2615948	et	4	main
5	doc_491521502167_item	2615950	et	2	main
saama	doc_491521502167_item	2615954	et	4	main
maagiline	doc_491521502167_item	2615956	et	4	main
abil	doc_491521502167_item	2615960	et	4	main
lausa	doc_491521502167_item	2615961	et	4	main
elama	doc_491521502167_item	2615962	et	3	main
ja	doc_491521502167_item	2615963	et	3	main
hingama	doc_491521502167_item	2615964	et	3	main
et	doc_491521502167_item	2615971	et	3	main
abil	doc_491521502167_item	2615973	et	4	main
ja	doc_491521502167_item	2616006	et	3	main
tegutsemata	doc_491521502167_item	2615925	et	4	main
aga	doc_491521502167_item	2615926	et	3	main
lisakoormus	doc_491521502167_item	2615927	et	3	main
võib	doc_491521502167_item	2615928	et	3	main
tuua	doc_491521502167_item	2615929	et	3	main
soovimatut	doc_491521502167_item	2615930	et	4	main
tohtima	doc_491521502167_item	2615934	et	3	main
pinge	doc_491521502167_item	2615938	et	4	main
maandama	doc_491521502167_item	2615940	et	3	main
sportima	doc_491521502167_item	2615941	et	4	main
ja	doc_491521502167_item	2615942	et	3	main
puhkama	doc_491521502167_item	2615943	et	3	main
ei	doc_491521502167_item	2615944	et	4	main
tekkida	doc_491521502167_item	2615949	et	3	main
telefon	doc_491521502167_item	2615951	et	3	main
nii	doc_491521502167_item	2615955	et	3	main
aparaat	doc_491521502167_item	2615957	et	3	main
see	doc_491521502167_item	2615959	et	3	main
maagiline	doc_491521502167_item	2615969	et	4	main
lausa	doc_491521502167_item	2615975	et	4	main
elada	doc_491521502167_item	2615976	et	3	main
ja	doc_491521502167_item	2615977	et	3	main
hingata	doc_491521502167_item	2615978	et	4	main
6	doc_491521502167_item	2615979	et	2	main
kuid	doc_491521502167_item	2615980	et	4	main
telefonihelin	doc_491521502167_item	2615981	et	3	main
katkestama	doc_491521502167_item	2615982	et	3	main
ka	doc_491521502167_item	2615983	et	3	main
pühapäev	doc_491521502167_item	2615984	et	3	main
varahommik	doc_491521502167_item	2615985	et	3	main
uni	doc_491521502167_item	2615986	et	3	main
segama	doc_491521502167_item	2615987	et	3	main
lõunasöök	doc_491521502167_item	2615988	et	3	main
valmistamine	doc_491521502167_item	2615989	et	4	main
ja	doc_491521502167_item	2615990	et	3	main
huvitav	doc_491521502167_item	2615993	et	4	main
vaatamine	doc_491521502167_item	2615995	et	4	main
aeg	doc_491521502167_item	2615996	et	3	main
kuid	doc_491521502167_item	2615997	et	4	main
telefonihelin	doc_491521502167_item	2615998	et	3	main
katkestab	doc_491521502167_item	2615999	et	3	main
telesaade	doc_491521502167_item	2616011	et	4	main
vaatamise	doc_491521502167_item	2616012	et	4	main
aega	doc_491521502167_item	2616013	et	4	main
sulgudes	doc_491521502167_item	2616016	et	4	main
õigesse	doc_491521502167_item	2616019	et	3	main
vormi	doc_491521502167_item	2616020	et	4	main
lõunasöögi	doc_491521502167_item	2616004	et	3	main
valmistamist	doc_491521502167_item	2616005	et	4	main
1	doc_491521502167_item	2616021	et	2	main
usaldavad	doc_491521502167_item	2616036	et	4	main
nõudeid	doc_491521502167_item	2616043	et	3	main
sport	doc_491521502167_item	2616050	et	3	main
sa	doc_491521502167_item	2616053	et	3	main
tunned	doc_491521502167_item	2616054	et	3	main
huvi	doc_491521502167_item	2616055	et	4	main
ja	doc_491521502167_item	2616059	et	3	main
autod	doc_491521502167_item	2616061	et	3	main
naistele	doc_491521502167_item	2616063	et	3	main
kiirtele	doc_491521502167_item	2616065	et	3	main
4	doc_491521502167_item	2616067	et	2	main
selles	doc_491521502167_item	2616083	et	4	main
küsimuses	doc_491521502167_item	2616084	et	4	main
vaid	doc_491521502167_item	2616085	et	3	main
sidenditega	doc_491521502167_item	2616122	et	3	main
kui	doc_491521502167_item	2616136	et	3	main
3	doc_491521502167_item	2616138	et	2	main
kui	doc_491521502167_item	2616150	et	3	main
rääkinud	doc_491521502167_item	2616155	et	4	main
ta	doc_491521502167_item	2616157	et	4	main
6	doc_491521502167_item	2616165	et	2	main
tohi	doc_491521502167_item	2616175	et	4	main
suitsetada	doc_491521502167_item	2616176	et	3	main
alkoholi	doc_491521502167_item	2616178	et	4	main
aga	doc_491521502167_item	2616185	et	3	main
ei	doc_491521502167_item	2616187	et	4	main
eesti	doc_491521502168_item	2616203	et	4	main
ajalehes	doc_491521502168_item	2616225	et	3	main
siberisse	doc_491521502168_item	2616228	et	4	main
ülem-suetuki	doc_491521502168_item	2616229	et	4	main
piret	doc_491521502168_item	2616236	et	4	main
võitis	doc_491521502168_item	2616237	et	3	main
konkurss	doc_491521502168_item	2616238	et	3	main
üle	doc_491521502168_item	2616244	et	3	main
väikestele	doc_491521502168_item	2616247	et	4	main
emakeelt	doc_491521502168_item	2616251	et	4	main
õpetama	doc_491521502168_item	2616252	et	3	main
õpetamas	doc_491521502168_item	2616253	et	3	main
et	doc_491521502168_item	2616261	et	3	main
et	doc_491521502168_item	2616282	et	3	main
ei	doc_491521502168_item	2616284	et	4	main
ega	doc_491521502168_item	2616288	et	3	main
kui	doc_491521502168_item	2616291	et	3	main
tahtmine	doc_491521502168_item	2616294	et	4	main
tänaseks	doc_491521502168_item	2616322	et	4	main
kartul	doc_491521502168_item	2616324	et	3	main
salvedes	doc_491521502168_item	2616326	et	4	main
ja	doc_491521502168_item	2616327	et	3	main
hoog	doc_491521502168_item	2616331	et	3	main
mahlakalt	doc_491521502168_item	2616343	et	4	main
mitte	doc_491521502168_item	2616344	et	3	main
on	doc_491521502168_item	2616354	et	4	main
raamatud	doc_491521502168_item	2616382	et	4	main
eestist	doc_491521502168_item	2616387	et	3	main
piret	doc_491521502168_item	2616392	et	4	main
soe	doc_491521502168_item	2616405	et	4	main
vene	doc_491521502168_item	2616415	et	4	main
kütmine	doc_491521502168_item	2616417	et	4	main
kütmist	doc_491521502168_item	2616418	et	4	main
kui	doc_491521502168_item	2616419	et	3	main
vildid	doc_491521502168_item	2616424	et	4	main
seal	doc_491521502168_item	2616426	et	4	main
suurt	doc_491521502168_item	2616427	et	3	main
ja	doc_491521502168_item	2616449	et	3	main
naised	doc_491521502168_item	2616455	et	3	main
mehelikum	doc_491521502168_item	2616459	et	4	main
aga	doc_491521502168_item	2616478	et	3	main
tooma	doc_491521502168_item	2616481	et	3	main
paras	doc_491521502168_item	2616484	et	3	main
võib	doc_491521502168_item	2616492	et	3	main
tekkima	doc_491521502168_item	2616501	et	3	main
saama	doc_491521502168_item	2616503	et	4	main
sportima	doc_491521502168_item	2616505	et	4	main
ja	doc_491521502168_item	2616506	et	3	main
puhkama	doc_491521502168_item	2616507	et	3	main
ei	doc_491521502168_item	2616508	et	4	main
sport	doc_491521502168_item	2616521	et	3	main
tekkivaid	doc_491521502168_item	2616525	et	4	main
saama	doc_491521502168_item	2616531	et	4	main
pahandab	doc_491521502167_item	2616009	et	3	main
pange	doc_491521502167_item	2616015	et	4	main
väga	doc_491521502167_item	2616024	et	3	main
vanemaid	doc_491521502167_item	2616029	et	4	main
sest	doc_491521502167_item	2616030	et	4	main
nad	doc_491521502167_item	2616031	et	3	main
aitavad	doc_491521502167_item	2616032	et	4	main
igaüks	doc_491521502167_item	2616037	et	3	main
nõuded	doc_491521502167_item	2616042	et	3	main
arvasin	doc_491521502167_item	2616046	et	3	main
sportiga	doc_491521502167_item	2616051	et	4	main
naised	doc_491521502167_item	2616058	et	3	main
ilusadele	doc_491521502167_item	2616062	et	4	main
ja	doc_491521502167_item	2616064	et	3	main
väikesed	doc_491521502167_item	2616086	et	4	main
muudatused	doc_491521502167_item	2616087	et	3	main
maksis	doc_491521502167_item	2616129	et	4	main
õpilased	doc_491521502167_item	2616135	et	3	main
4	doc_491521502167_item	2616146	et	2	main
keegi	doc_491521502167_item	2616152	et	4	main
5	doc_491521502167_item	2616156	et	2	main
trenni	doc_491521502167_item	2616160	et	4	main
läheb	doc_491521502167_item	2616162	et	3	main
ega	doc_491521502167_item	2616177	et	3	main
pingsalt	doc_491521502167_item	2616184	et	4	main
jääd	doc_491521502167_item	2616195	et	4	main
linna	doc_491521502167_item	2616196	et	4	main
10	doc_491521502167_item	2616197	et	2	main
avasin	doc_491521502167_item	2616198	et	3	main
ukse	doc_491521502167_item	2616199	et	3	main
sest	doc_491521502167_item	2616200	et	4	main
kuulsin	doc_491521502167_item	2616201	et	3	main
suvel	doc_491521502168_item	2616221	et	3	main
nägi	doc_491521502168_item	2616223	et	3	main
otsitakse	doc_491521502168_item	2616232	et	3	main
konkurssi	doc_491521502168_item	2616239	et	4	main
ja	doc_491521502168_item	2616240	et	3	main
on	doc_491521502168_item	2616241	et	4	main
nädala	doc_491521502168_item	2616246	et	3	main
eestlastele	doc_491521502168_item	2616248	et	4	main
on	doc_491521502168_item	2616262	et	4	main
üsna	doc_491521502168_item	2616265	et	3	main
üllatunud	doc_491521502168_item	2616267	et	4	main
mulle	doc_491521502168_item	2616269	et	4	main
tulema	doc_491521502168_item	2616270	et	4	main
tuldi	doc_491521502168_item	2616271	et	3	main
vastu	doc_491521502168_item	2616272	et	3	main
korralik	doc_491521502168_item	2616273	et	3	main
korralikku	doc_491521502168_item	2616274	et	4	main
audiga	doc_491521502168_item	2616275	et	3	main
selline	doc_491521502168_item	2616280	et	4	main
on	doc_491521502168_item	2616323	et	4	main
salv	doc_491521502168_item	2616325	et	3	main
õppimine	doc_491521502168_item	2616328	et	4	main
käib	doc_491521502168_item	2616329	et	3	main
täie	doc_491521502168_item	2616330	et	3	main
teistmoodi	doc_491521502168_item	2616337	et	3	main
ja	doc_491521502168_item	2616339	et	3	main
vaid	doc_491521502168_item	2616348	et	3	main
murret	doc_491521502168_item	2616352	et	4	main
kolmesaja	doc_491521502168_item	2616370	et	4	main
emakeelt	doc_491521502168_item	2616372	et	4	main
õpivad	doc_491521502168_item	2616379	et	3	main
raamatutest	doc_491521502168_item	2616383	et	4	main
õpikud	doc_491521502168_item	2616389	et	3	main
talve	doc_491521502168_item	2616391	et	4	main
ei	doc_491521502168_item	2616393	et	4	main
kartma	doc_491521502168_item	2616394	et	3	main
karda	doc_491521502168_item	2616395	et	4	main
veel	doc_491521502168_item	2616404	et	4	main
jahedad	doc_491521502168_item	2616411	et	3	main
ega	doc_491521502168_item	2616425	et	3	main
pean	doc_491521502167_item	2616023	et	4	main
lugu	doc_491521502167_item	2616025	et	4	main
oma	doc_491521502167_item	2616026	et	4	main
vanemad	doc_491521502167_item	2616027	et	4	main
kõik	doc_491521502167_item	2616033	et	4	main
igaükse	doc_491521502167_item	2616038	et	3	main
artikli	doc_491521502167_item	2616041	et	3	main
sa	doc_491521502167_item	2616048	et	3	main
ilusad	doc_491521502167_item	2616057	et	3	main
töökoht	doc_491521502167_item	2616077	et	3	main
väikeste	doc_491521502167_item	2616088	et	4	main
muudatustega	doc_491521502167_item	2616089	et	3	main
7	doc_491521502167_item	2616090	et	2	main
see	doc_491521502167_item	2616091	et	3	main
küsimus	doc_491521502167_item	2616092	et	4	main
kuulub	doc_491521502167_item	2616093	et	3	main
teine	doc_491521502167_item	2616094	et	3	main
valdkond	doc_491521502167_item	2616095	et	3	main
teisele	doc_491521502167_item	2616096	et	4	main
valdkonnale	doc_491521502167_item	2616097	et	4	main
8	doc_491521502167_item	2616098	et	2	main
närimiskumm	doc_491521502167_item	2616099	et	3	main
kleepus	doc_491521502167_item	2616100	et	3	main
püksid	doc_491521502167_item	2616101	et	3	main
pükstele	doc_491521502167_item	2616102	et	3	main
9	doc_491521502167_item	2616103	et	2	main
külmal	doc_491521502167_item	2616104	et	3	main
ajal	doc_491521502167_item	2616105	et	4	main
peab	doc_491521502167_item	2616106	et	4	main
hoiduma	doc_491521502167_item	2616107	et	3	main
külmetamine	doc_491521502167_item	2616108	et	4	main
külmetamisest	doc_491521502167_item	2616109	et	4	main
10	doc_491521502167_item	2616110	et	2	main
ma	doc_491521502167_item	2616111	et	3	main
tunnen	doc_491521502167_item	2616112	et	3	main
rõõmu	doc_491521502167_item	2616113	et	4	main
suvine	doc_491521502167_item	2616114	et	4	main
päike	doc_491521502167_item	2616115	et	3	main
suviseks	doc_491521502167_item	2616116	et	4	main
päikeseks	doc_491521502167_item	2616117	et	4	main
v	doc_491521502167_item	2616118	et	4	main
täitke	doc_491521502167_item	2616119	et	3	main
lüngad	doc_491521502167_item	2616120	et	3	main
sobivate	doc_491521502167_item	2616121	et	4	main
palju	doc_491521502167_item	2616130	et	4	main
2	doc_491521502167_item	2616131	et	2	main
kohal	doc_491521502167_item	2616132	et	4	main
õpetajad	doc_491521502167_item	2616137	et	4	main
paluti	doc_491521502167_item	2616140	et	3	main
kui	doc_491521502167_item	2616142	et	3	main
kõrvallauast	doc_491521502167_item	2616147	et	4	main
uus	doc_491521502167_item	2616076	et	3	main
uue	doc_491521502167_item	2616078	et	3	main
6	doc_491521502167_item	2616081	et	2	main
piirdusime	doc_491521502167_item	2616082	et	3	main
1	doc_491521502167_item	2616123	et	2	main
tellisime	doc_491521502167_item	2616124	et	4	main
kolmekäigulise	doc_491521502167_item	2616125	et	4	main
olid	doc_491521502167_item	2616133	et	4	main
oodata	doc_491521502167_item	2616141	et	4	main
vanemad	doc_491521502167_item	2616143	et	4	main
just	doc_491521502167_item	2616153	et	3	main
anekdooti	doc_491521502167_item	2616154	et	4	main
tule	doc_491521502167_item	2616159	et	4	main
sest	doc_491521502167_item	2616161	et	4	main
teatrisse	doc_491521502167_item	2616164	et	3	main
lähete	doc_491521502167_item	2616169	et	4	main
jalutama	doc_491521502167_item	2616170	et	3	main
selles	doc_491521502167_item	2616172	et	4	main
baaris	doc_491521502167_item	2616173	et	3	main
ei	doc_491521502167_item	2616174	et	4	main
tarbida	doc_491521502167_item	2616179	et	3	main
töötasid	doc_491521502167_item	2616182	et	4	main
tulemust	doc_491521502167_item	2616186	et	4	main
olnud	doc_491521502167_item	2616188	et	4	main
9	doc_491521502167_item	2616189	et	2	main
kas	doc_491521502167_item	2616190	et	3	main
sa	doc_491521502167_item	2616191	et	3	main
sõidad	doc_491521502167_item	2616192	et	3	main
maale	doc_491521502167_item	2616193	et	4	main
test	doc_491521502168_item	2616205	et	3	main
eesti	doc_491521502168_item	2616206	et	4	main
test	doc_491521502168_item	2616208	et	3	main
küla	doc_491521502168_item	2616230	et	4	main
külasse	doc_491521502168_item	2616231	et	3	main
eesti	doc_491521502168_item	2616233	et	4	main
nädal	doc_491521502168_item	2616245	et	3	main
need	doc_491521502168_item	2616249	et	3	main
nende	doc_491521502168_item	2616250	et	4	main
siberisse	doc_491521502168_item	2616258	et	4	main
jõudma	doc_491521502168_item	2616259	et	3	main
jõudes	doc_491521502168_item	2616260	et	3	main
siber	doc_491521502168_item	2616278	et	4	main
siberist	doc_491521502168_item	2616279	et	4	main
seal	doc_491521502168_item	2616283	et	4	main
lendama	doc_491521502168_item	2616285	et	3	main
lenda	doc_491521502168_item	2616286	et	4	main
noor	doc_491521502168_item	2616292	et	3	main
ettevõtmine	doc_491521502168_item	2616321	et	3	main
siinsed	doc_491521502168_item	2616333	et	3	main
vene	doc_491521502168_item	2616345	et	4	main
aktsendiga	doc_491521502168_item	2616347	et	3	main
nagu	doc_491521502168_item	2616349	et	3	main
saab	doc_491521502168_item	2616373	et	3	main
rääkida	doc_491521502168_item	2616376	et	3	main
sõnul	doc_491521502168_item	2616378	et	3	main
lapsed	doc_491521502168_item	2616380	et	3	main
varsti	doc_491521502168_item	2616384	et	3	main
siberi	doc_491521502168_item	2616390	et	4	main
juba	doc_491521502168_item	2616397	et	3	main
kuid	doc_491521502168_item	2616407	et	4	main
juba	doc_491521502168_item	2616409	et	3	main
harjutan	doc_491521502168_item	2616412	et	3	main
vaja	doc_491521502168_item	2616420	et	4	main
külapood	doc_491521502168_item	2616422	et	3	main
valmistuma	doc_491521502168_item	2616433	et	3	main
valmistuv	doc_491521502168_item	2616434	et	4	main
pannes	doc_491521502168_item	2616445	et	4	main
sõnad	doc_491521502168_item	2616446	et	4	main
tegema	doc_491521502168_item	2616454	et	3	main
mehi	doc_491521502168_item	2616467	et	3	main
igauhe	doc_491521502168_item	2616469	et	4	main
kaunimaks	doc_491521502168_item	2616470	et	4	main
3	doc_491521502168_item	2616471	et	2	main
paras	doc_491521502168_item	2616472	et	3	main
kogus	doc_491521502168_item	2616473	et	4	main
stress	doc_491521502168_item	2616474	et	3	main
panema	doc_491521502168_item	2616475	et	3	main
meid	doc_491521502168_item	2616488	et	4	main
tegutsema	doc_491521502168_item	2616489	et	3	main
laskma	doc_491521502168_item	2616499	et	3	main
pinge	doc_491521502168_item	2616502	et	4	main
ja	doc_491521502168_item	2616522	et	3	main
lõuna	doc_491521502167_item	2616126	et	4	main
ja	doc_491521502167_item	2616127	et	3	main
see	doc_491521502167_item	2616128	et	3	main
nii	doc_491521502167_item	2616134	et	3	main
lapsel	doc_491521502167_item	2616139	et	4	main
tagasi	doc_491521502167_item	2616144	et	3	main
tulevad	doc_491521502167_item	2616145	et	4	main
kostis	doc_491521502167_item	2616148	et	4	main
oleks	doc_491521502167_item	2616151	et	3	main
hoopis	doc_491521502167_item	2616163	et	3	main
töö	doc_491521502167_item	2616167	et	4	main
7	doc_491521502167_item	2616171	et	2	main
8	doc_491521502167_item	2616180	et	2	main
küll	doc_491521502167_item	2616183	et	4	main
keele	doc_491521502168_item	2616204	et	4	main
i	doc_491521502168_item	2616209	et	4	main
pange	doc_491521502168_item	2616210	et	4	main
sulgudes	doc_491521502168_item	2616211	et	4	main
olevad	doc_491521502168_item	2616212	et	4	main
sõnad	doc_491521502168_item	2616213	et	4	main
õigesse	doc_491521502168_item	2616214	et	3	main
vormi	doc_491521502168_item	2616215	et	4	main
toomet	doc_491521502168_item	2616217	et	4	main
on	doc_491521502168_item	2616218	et	4	main
piret	doc_491521502168_item	2616216	et	4	main
ettevõtlik	doc_491521502168_item	2616219	et	3	main
naine	doc_491521502168_item	2616220	et	3	main
et	doc_491521502168_item	2616227	et	3	main
keele	doc_491521502168_item	2616234	et	4	main
juba	doc_491521502168_item	2616243	et	3	main
oodatud	doc_491521502168_item	2616263	et	4	main
mulle	doc_491521502168_item	2616276	et	4	main
maaliti	doc_491521502168_item	2616277	et	3	main
pilt	doc_491521502168_item	2616281	et	3	main
rohi	doc_491521502168_item	2616290	et	4	main
naeru	doc_491521502167_item	2616149	et	4	main
ei	doc_491521502167_item	2616158	et	4	main
lõpetage	doc_491521502167_item	2616166	et	3	main
siis	doc_491521502167_item	2616168	et	3	main
nad	doc_491521502167_item	2616181	et	3	main
või	doc_491521502167_item	2616194	et	4	main
koputust	doc_491521502167_item	2616202	et	4	main
keele	doc_491521502168_item	2616207	et	4	main
nägema	doc_491521502168_item	2616222	et	3	main
ta	doc_491521502168_item	2616224	et	4	main
kuulutus	doc_491521502168_item	2616226	et	4	main
õpetajat	doc_491521502168_item	2616235	et	4	main
nüüd	doc_491521502168_item	2616242	et	4	main
pireti	doc_491521502168_item	2616254	et	4	main
kinnitusel	doc_491521502168_item	2616255	et	4	main
tundis	doc_491521502168_item	2616256	et	3	main
ta	doc_491521502168_item	2616257	et	4	main
olin	doc_491521502168_item	2616264	et	3	main
üllatuma	doc_491521502168_item	2616266	et	3	main
kui	doc_491521502168_item	2616268	et	3	main
lind	doc_491521502168_item	2616287	et	3	main
kasva	doc_491521502168_item	2616289	et	4	main
ja	doc_491521502168_item	2616293	et	3	main
tahtmist	doc_491521502168_item	2616295	et	4	main
täis	doc_491521502168_item	2616296	et	4	main
piret	doc_491521502168_item	2616297	et	4	main
pärast	doc_491521502168_item	2616298	et	4	main
õppeaasta	doc_491521502168_item	2616299	et	4	main
algust	doc_491521502168_item	2616300	et	4	main
koht	doc_491521502168_item	2616301	et	3	main
kohale	doc_491521502168_item	2616302	et	4	main
jõudis	doc_491521502168_item	2616303	et	3	main
polnud	doc_491521502168_item	2616304	et	3	main
kool	doc_491521502168_item	2616305	et	4	main
veel	doc_491521502168_item	2616306	et	4	main
algama	doc_491521502168_item	2616307	et	3	main
alganud	doc_491521502168_item	2616308	et	4	main
kogu	doc_491521502168_item	2616309	et	4	main
küla	doc_491521502168_item	2616310	et	4	main
võtma	doc_491521502168_item	2616311	et	3	main
võttis	doc_491521502168_item	2616312	et	3	main
kartuleid	doc_491521502168_item	2616313	et	3	main
kartulivõtt	doc_491521502168_item	2616314	et	3	main
on	doc_491521502168_item	2616315	et	4	main
siin	doc_491521502168_item	2616316	et	4	main
sügisel	doc_491521502168_item	2616317	et	3	main
kõige	doc_491521502168_item	2616318	et	4	main
tähtis	doc_491521502168_item	2616319	et	4	main
tähtsam	doc_491521502168_item	2616320	et	4	main
hooga	doc_491521502168_item	2616332	et	3	main
kuidagi	doc_491521502168_item	2616336	et	3	main
mõnus	doc_491521502168_item	2616338	et	4	main
mahlakas	doc_491521502168_item	2616340	et	4	main
mõnusalt	doc_491521502168_item	2616341	et	4	main
ja	doc_491521502168_item	2616342	et	3	main
mõnd	doc_491521502168_item	2616351	et	3	main
kool	doc_491521502168_item	2616353	et	4	main
siiski	doc_491521502168_item	2616355	et	4	main
kolmsada	doc_491521502168_item	2616369	et	4	main
kõik	doc_491521502168_item	2616374	et	4	main
saatma	doc_491521502168_item	2616385	et	3	main
uued	doc_491521502168_item	2616388	et	3	main
mulle	doc_491521502168_item	2616396	et	4	main
toodi	doc_491521502168_item	2616399	et	4	main
eestlased	doc_491521502168_item	2616334	et	3	main
räägivad	doc_491521502168_item	2616335	et	3	main
aktsent	doc_491521502168_item	2616346	et	3	main
mõni	doc_491521502168_item	2616350	et	3	main
venemaa	doc_491521502168_item	2616356	et	4	main
kool	doc_491521502168_item	2616357	et	4	main
ja	doc_491521502168_item	2616358	et	3	main
ülejäänud	doc_491521502168_item	2616359	et	4	main
aine	doc_491521502168_item	2616360	et	4	main
ained	doc_491521502168_item	2616361	et	3	main
õpetatakse	doc_491521502168_item	2616362	et	3	main
vene	doc_491521502168_item	2616363	et	4	main
keeles	doc_491521502168_item	2616364	et	4	main
külas	doc_491521502168_item	2616365	et	3	main
elab	doc_491521502168_item	2616366	et	3	main
veidi	doc_491521502168_item	2616367	et	3	main
üle	doc_491521502168_item	2616368	et	3	main
inimene	doc_491521502168_item	2616371	et	3	main
kõigidega	doc_491521502168_item	2616375	et	4	main
pireti	doc_491521502168_item	2616377	et	4	main
poolpõlenud	doc_491521502168_item	2616381	et	4	main
saadetakse	doc_491521502168_item	2616386	et	3	main
tooma	doc_491521502168_item	2616398	et	3	main
talvepuud	doc_491521502168_item	2616400	et	4	main
praegu	doc_491521502168_item	2616401	et	3	main
on	doc_491521502168_item	2616402	et	4	main
päevad	doc_491521502168_item	2616403	et	3	main
ööd	doc_491521502168_item	2616408	et	4	main
jahe	doc_491521502168_item	2616410	et	3	main
juba	doc_491521502168_item	2616413	et	3	main
külapoest	doc_491521502168_item	2616423	et	4	main
muud	doc_491521502168_item	2616428	et	4	main
piret	doc_491521502168_item	2616435	et	4	main
ajalehest	doc_491521502168_item	2616438	et	4	main
õigesse	doc_491521502168_item	2616447	et	3	main
vormi	doc_491521502168_item	2616448	et	4	main
kasutades	doc_491521502168_item	2616450	et	3	main
kirjavahemärke	doc_491521502168_item	2616451	et	4	main
2	doc_491521502168_item	2616452	et	2	main
naiselikum	doc_491521502168_item	2616456	et	4	main
mehed	doc_491521502168_item	2616458	et	3	main
igaüks	doc_491521502168_item	2616460	et	3	main
mehelikumaks	doc_491521502168_item	2616468	et	4	main
võima	doc_491521502168_item	2616480	et	3	main
aga	doc_491521502168_item	2616490	et	3	main
tagajargi	doc_491521502168_item	2616495	et	4	main
tohtima	doc_491521502168_item	2616498	et	3	main
tohi	doc_491521502168_item	2616509	et	4	main
lasta	doc_491521502168_item	2616510	et	4	main
puhkus	doc_491521502168_item	2616523	et	3	main
5	doc_491521502168_item	2616527	et	2	main
see	doc_491521502168_item	2616536	et	3	main
aparaat	doc_491521502168_item	2616549	et	3	main
et	doc_491521502168_item	2616550	et	3	main
selle	doc_491521502168_item	2616551	et	4	main
tanapaeval	doc_491521502168_item	2616563	et	4	main
ja	doc_491521502168_item	2616587	et	3	main
pahandab	doc_491521502168_item	2616589	et	3	main
kui	doc_491521502168_item	2616602	et	3	main
soomist	doc_491521502168_item	2616604	et	4	main
on	doc_491521502168_item	2616614	et	4	main
siiruviiruline	doc_491521502168_item	2616615	et	4	main
olevad	doc_491521502168_item	2616621	et	4	main
õigesse	doc_491521502168_item	2616623	et	3	main
vormi	doc_491521502168_item	2616624	et	4	main
ma	doc_491521502168_item	2616626	et	3	main
lugu	doc_491521502168_item	2616629	et	4	main
usaldavad	doc_491521502168_item	2616639	et	4	main
igaüks	doc_491521502168_item	2616640	et	3	main
igaüht	doc_491521502168_item	2616641	et	3	main
2	doc_491521502168_item	2616642	et	2	main
kohandasin	doc_491521502168_item	2616643	et	3	main
artikli	doc_491521502168_item	2616644	et	3	main
nõuded	doc_491521502168_item	2616645	et	3	main
3	doc_491521502168_item	2616647	et	2	main
et	doc_491521502168_item	2616650	et	3	main
sa	doc_491521502168_item	2616656	et	3	main
huvi	doc_491521502168_item	2616658	et	4	main
naised	doc_491521502168_item	2616661	et	3	main
vastu	doc_491521502168_item	2616670	et	3	main
ilusatest	doc_491521502168_item	2616672	et	3	main
naistest	doc_491521502168_item	2616673	et	4	main
praegu	doc_491521502168_item	2616678	et	3	main
difteeria	doc_491521502168_item	2616682	et	4	main
5	doc_491521502168_item	2616684	et	2	main
külmetamisest	doc_491521502168_item	2616723	et	4	main
v	doc_491521502168_item	2616732	et	4	main
õpilased	doc_491521502168_item	2616749	et	3	main
lapsel	doc_491521502168_item	2616754	et	4	main
paluti	doc_491521502168_item	2616755	et	3	main
kõrvallauast	doc_491521502168_item	2616762	et	4	main
kostis	doc_491521502168_item	2616763	et	4	main
trenni	doc_491521502168_item	2616775	et	4	main
kuna	doc_491521502168_item	2616776	et	3	main
läheb	doc_491521502168_item	2616777	et	3	main
hoopis	doc_491521502168_item	2616778	et	3	main
teatrisse	doc_491521502168_item	2616779	et	3	main
10	doc_491521502168_item	2616812	et	2	main
soojad	doc_491521502168_item	2616406	et	3	main
suure	doc_491521502168_item	2616414	et	3	main
ahju	doc_491521502168_item	2616416	et	4	main
ostan	doc_491521502168_item	2616421	et	3	main
ei	doc_491521502168_item	2616429	et	4	main
müüdagi	doc_491521502168_item	2616430	et	3	main
naerab	doc_491521502168_item	2616431	et	3	main
talveks	doc_491521502168_item	2616432	et	4	main
vapralt	doc_491521502168_item	2616436	et	4	main
naeratus	doc_491521502168_item	2616453	et	4	main
ja	doc_491521502168_item	2616457	et	3	main
kaunim	doc_491521502168_item	2616461	et	4	main
naeratus	doc_491521502168_item	2616462	et	4	main
teeb	doc_491521502168_item	2616463	et	3	main
naisi	doc_491521502168_item	2616464	et	3	main
tagajärg	doc_491521502168_item	2616483	et	3	main
kogus	doc_491521502168_item	2616485	et	4	main
stressi	doc_491521502168_item	2616486	et	4	main
paneb	doc_491521502168_item	2616487	et	3	main
tuua	doc_491521502168_item	2616493	et	3	main
4	doc_491521502168_item	2616496	et	2	main
ülekoormus	doc_491521502168_item	2616500	et	3	main
maandavad	doc_491521502168_item	2616524	et	4	main
olema	doc_491521502168_item	2616529	et	4	main
et	doc_491521502168_item	2616535	et	3	main
elama	doc_491521502168_item	2616539	et	3	main
olevat	doc_491521502168_item	2616544	et	4	main
on	doc_491521502168_item	2616545	et	4	main
tänapäeval	doc_491521502168_item	2616546	et	3	main
nii	doc_491521502168_item	2616547	et	3	main
ei	doc_491521502168_item	2616553	et	4	main
ega	doc_491521502168_item	2616557	et	3	main
on	doc_491521502168_item	2616561	et	4	main
huvitav	doc_491521502168_item	2616590	et	4	main
telesaade	doc_491521502168_item	2616591	et	4	main
vaatamine	doc_491521502168_item	2616592	et	4	main
aeg	doc_491521502168_item	2616593	et	3	main
telefonihelin	doc_491521502168_item	2616594	et	3	main
katkestab	doc_491521502168_item	2616595	et	3	main
inimest	doc_491521502168_item	2616606	et	3	main
iv	doc_491521502168_item	2616618	et	4	main
väga	doc_491521502168_item	2616628	et	3	main
oma	doc_491521502168_item	2616630	et	4	main
sa	doc_491521502168_item	2616651	et	3	main
sport	doc_491521502168_item	2616653	et	3	main
aga	doc_491521502168_item	2616655	et	3	main
tunned	doc_491521502168_item	2616657	et	3	main
ainult	doc_491521502168_item	2616659	et	4	main
ja	doc_491521502168_item	2616662	et	3	main
autodest	doc_491521502168_item	2616676	et	3	main
tüdinesin	doc_491521502168_item	2616685	et	3	main
lõuna	doc_491521502168_item	2616740	et	4	main
kuigi	doc_491521502168_item	2616741	et	3	main
see	doc_491521502168_item	2616742	et	3	main
nii	doc_491521502168_item	2616748	et	3	main
just	doc_491521502168_item	2616768	et	3	main
5	doc_491521502168_item	2616771	et	2	main
tule	doc_491521502168_item	2616774	et	4	main
jääd	doc_491521502168_item	2616810	et	4	main
sulgudes	doc_491521502169_item	2616826	et	4	main
olevad	doc_491521502169_item	2616827	et	4	main
on	doc_491521502169_item	2616833	et	4	main
küla	doc_491521502169_item	2616846	et	4	main
külla	doc_491521502169_item	2616847	et	4	main
otsitakse	doc_491521502169_item	2616848	et	3	main
piret	doc_491521502169_item	2616852	et	4	main
on	doc_491521502169_item	2616857	et	4	main
nädal	doc_491521502169_item	2616861	et	3	main
väikestele	doc_491521502169_item	2616863	et	4	main
need	doc_491521502169_item	2616865	et	3	main
üllatunud	doc_491521502169_item	2616883	et	4	main
kui	doc_491521502169_item	2616884	et	3	main
mulle	doc_491521502169_item	2616885	et	4	main
võtma	doc_491521502169_item	2616927	et	3	main
tähtsam	doc_491521502169_item	2616936	et	4	main
täie	doc_491521502169_item	2616945	et	3	main
siinsed	doc_491521502169_item	2616948	et	3	main
teistmoodi	doc_491521502169_item	2616952	et	3	main
ja	doc_491521502169_item	2616954	et	3	main
mahlakas	doc_491521502169_item	2616955	et	4	main
mõnusasti	doc_491521502169_item	2616956	et	3	main
siiski	doc_491521502169_item	2616970	et	4	main
lühendatud	doc_491521502168_item	2616437	et	4	main
slõhtuleht	doc_491521502168_item	2616439	et	4	main
iii	doc_491521502168_item	2616440	et	4	main
moodustage	doc_491521502168_item	2616441	et	3	main
etteantud	doc_491521502168_item	2616442	et	4	main
sõnadest	doc_491521502168_item	2616443	et	3	main
laused	doc_491521502168_item	2616444	et	3	main
naiselikumaks	doc_491521502168_item	2616465	et	4	main
ja	doc_491521502168_item	2616466	et	3	main
meie	doc_491521502168_item	2616476	et	4	main
tegutsema	doc_491521502168_item	2616477	et	3	main
lisakoormus	doc_491521502168_item	2616479	et	3	main
soovimatu	doc_491521502168_item	2616482	et	4	main
lisakoormus	doc_491521502168_item	2616491	et	3	main
soovitatuid	doc_491521502168_item	2616494	et	4	main
ei	doc_491521502168_item	2616497	et	4	main
maandama	doc_491521502168_item	2616504	et	3	main
ülekoormust	doc_491521502168_item	2616511	et	4	main
tekkida	doc_491521502168_item	2616512	et	3	main
pingeid	doc_491521502168_item	2616513	et	3	main
saab	doc_491521502168_item	2616514	et	3	main
maandada	doc_491521502168_item	2616515	et	3	main
spordi	doc_491521502168_item	2616516	et	4	main
ja	doc_491521502168_item	2616517	et	3	main
puhkehetkede	doc_491521502168_item	2616518	et	3	main
abil	doc_491521502168_item	2616519	et	4	main
parem	doc_491521502168_item	2616520	et	4	main
aparaat	doc_491521502168_item	2616534	et	3	main
lausa	doc_491521502168_item	2616538	et	4	main
hingama	doc_491521502168_item	2616541	et	3	main
telefon	doc_491521502168_item	2616543	et	3	main
abita	doc_491521502168_item	2616552	et	3	main
ei	doc_491521502168_item	2616555	et	4	main
elama	doc_491521502168_item	2616558	et	3	main
maagiline	doc_491521502168_item	2616565	et	4	main
aparaat	doc_491521502168_item	2616566	et	3	main
et	doc_491521502168_item	2616567	et	3	main
ainult	doc_491521502168_item	2616568	et	4	main
selle	doc_491521502168_item	2616569	et	4	main
abil	doc_491521502168_item	2616570	et	4	main
saab	doc_491521502168_item	2616571	et	3	main
lausa	doc_491521502168_item	2616572	et	4	main
elada	doc_491521502168_item	2616573	et	3	main
ja	doc_491521502168_item	2616574	et	3	main
hingata	doc_491521502168_item	2616575	et	4	main
6	doc_491521502168_item	2616576	et	2	main
kuid	doc_491521502168_item	2616577	et	4	main
telefonihelin	doc_491521502168_item	2616578	et	3	main
katkestama	doc_491521502168_item	2616579	et	3	main
ka	doc_491521502168_item	2616580	et	3	main
pühapäev	doc_491521502168_item	2616581	et	3	main
varahommik	doc_491521502168_item	2616582	et	3	main
uni	doc_491521502168_item	2616583	et	3	main
pingeid	doc_491521502168_item	2616526	et	3	main
telefon	doc_491521502168_item	2616528	et	3	main
tänapäev	doc_491521502168_item	2616530	et	3	main
abil	doc_491521502168_item	2616537	et	4	main
ja	doc_491521502168_item	2616540	et	3	main
i	doc_491521502168_item	2616542	et	4	main
saa	doc_491521502168_item	2616554	et	4	main
hingama	doc_491521502168_item	2616556	et	3	main
telefonist	doc_491521502168_item	2616560	et	4	main
segama	doc_491521502168_item	2616584	et	3	main
söömine	doc_491521502168_item	2616588	et	4	main
und	doc_491521502168_item	2616597	et	4	main
nii	doc_491521502168_item	2616599	et	3	main
valmistamist	doc_491521502168_item	2616601	et	4	main
puhkajat	doc_491521502168_item	2616607	et	4	main
telesaade	doc_491521502168_item	2616610	et	4	main
ajal	doc_491521502168_item	2616612	et	4	main
lause	doc_491521502168_item	2616616	et	4	main
pange	doc_491521502168_item	2616619	et	4	main
sõnad	doc_491521502168_item	2616622	et	4	main
sest	doc_491521502168_item	2616633	et	4	main
aitavad	doc_491521502168_item	2616635	et	4	main
arvasin	doc_491521502168_item	2616649	et	3	main
kiirete	doc_491521502168_item	2616668	et	4	main
kiirtest	doc_491521502168_item	2616675	et	3	main
oht	doc_491521502168_item	2616680	et	3	main
külmetamine	doc_491521502168_item	2616722	et	4	main
ma	doc_491521502168_item	2616725	et	3	main
tunnen	doc_491521502168_item	2616726	et	3	main
rõõmu	doc_491521502168_item	2616727	et	4	main
suvine	doc_491521502168_item	2616728	et	4	main
päike	doc_491521502168_item	2616729	et	3	main
maksis	doc_491521502168_item	2616743	et	4	main
palju	doc_491521502168_item	2616744	et	4	main
kui	doc_491521502168_item	2616750	et	3	main
õpetajad	doc_491521502168_item	2616752	et	4	main
naeru	doc_491521502168_item	2616764	et	4	main
anekdooti	doc_491521502168_item	2616769	et	4	main
maale	doc_491521502168_item	2616808	et	4	main
või	doc_491521502168_item	2616809	et	4	main
avasin	doc_491521502168_item	2616813	et	3	main
kuulsin	doc_491521502168_item	2616816	et	3	main
keele	doc_491521502169_item	2616822	et	4	main
pange	doc_491521502169_item	2616825	et	4	main
piret	doc_491521502169_item	2616831	et	4	main
suvel	doc_491521502169_item	2616836	et	3	main
nägi	doc_491521502169_item	2616838	et	3	main
ajalehes	doc_491521502169_item	2616840	et	3	main
ja	doc_491521502169_item	2616856	et	3	main
eestlastele	doc_491521502169_item	2616864	et	4	main
nende	doc_491521502169_item	2616866	et	4	main
emakeelt	doc_491521502169_item	2616867	et	4	main
õpetama	doc_491521502169_item	2616868	et	3	main
siberisse	doc_491521502169_item	2616874	et	4	main
jõudma	doc_491521502169_item	2616875	et	3	main
jõudmas	doc_491521502169_item	2616876	et	3	main
et	doc_491521502169_item	2616877	et	3	main
tulema	doc_491521502169_item	2616886	et	4	main
nii	doc_491521502168_item	2616532	et	3	main
maagiline	doc_491521502168_item	2616533	et	4	main
maagiline	doc_491521502168_item	2616548	et	4	main
ii	doc_491521502168_item	2616559	et	4	main
saanud	doc_491521502168_item	2616562	et	4	main
nii	doc_491521502168_item	2616564	et	3	main
valmistamine	doc_491521502168_item	2616586	et	4	main
segab	doc_491521502168_item	2616598	et	3	main
lõunasooki	doc_491521502168_item	2616600	et	4	main
ka	doc_491521502168_item	2616603	et	3	main
jne	doc_491521502168_item	2616608	et	4	main
vaatamise	doc_491521502168_item	2616611	et	4	main
küll	doc_491521502168_item	2616613	et	4	main
bk	doc_491521502168_item	2616617	et	4	main
lõunasöök	doc_491521502168_item	2616585	et	3	main
varahmmikust	doc_491521502168_item	2616596	et	4	main
pahandab	doc_491521502168_item	2616605	et	3	main
huvitava	doc_491521502168_item	2616609	et	4	main
sulgudes	doc_491521502168_item	2616620	et	4	main
pean	doc_491521502168_item	2616627	et	4	main
vanemad	doc_491521502168_item	2616631	et	4	main
nad	doc_491521502168_item	2616634	et	3	main
kõik	doc_491521502168_item	2616636	et	4	main
kõiki	doc_491521502168_item	2616637	et	4	main
ja	doc_491521502168_item	2616638	et	3	main
huvitud	doc_491521502168_item	2616652	et	4	main
spordist	doc_491521502168_item	2616654	et	3	main
ilusad	doc_491521502168_item	2616660	et	3	main
kiired	doc_491521502168_item	2616663	et	4	main
autod	doc_491521502168_item	2616664	et	3	main
ilusate	doc_491521502168_item	2616665	et	3	main
naiste	doc_491521502168_item	2616666	et	3	main
ja	doc_491521502168_item	2616667	et	3	main
või	doc_491521502168_item	2616671	et	4	main
ja	doc_491521502168_item	2616674	et	3	main
on	doc_491521502168_item	2616679	et	4	main
uus	doc_491521502168_item	2616686	et	3	main
1	doc_491521502168_item	2616625	et	2	main
vanematest	doc_491521502168_item	2616632	et	4	main
nõudeid	doc_491521502168_item	2616646	et	3	main
ma	doc_491521502168_item	2616648	et	3	main
autode	doc_491521502168_item	2616669	et	3	main
4	doc_491521502168_item	2616677	et	2	main
haigestuda	doc_491521502168_item	2616681	et	3	main
difteeriale	doc_491521502168_item	2616683	et	3	main
töökoht	doc_491521502168_item	2616687	et	3	main
uuest	doc_491521502168_item	2616688	et	3	main
töökohast	doc_491521502168_item	2616689	et	4	main
kiiresti	doc_491521502168_item	2616690	et	3	main
6	doc_491521502168_item	2616691	et	2	main
piirdusime	doc_491521502168_item	2616692	et	3	main
selles	doc_491521502168_item	2616693	et	4	main
küsimuses	doc_491521502168_item	2616694	et	4	main
vaid	doc_491521502168_item	2616695	et	3	main
väikesed	doc_491521502168_item	2616696	et	4	main
muudatused	doc_491521502168_item	2616697	et	3	main
väikeste	doc_491521502168_item	2616698	et	4	main
muudatustega	doc_491521502168_item	2616699	et	3	main
7	doc_491521502168_item	2616700	et	2	main
see	doc_491521502168_item	2616701	et	3	main
küsimus	doc_491521502168_item	2616702	et	4	main
kuulub	doc_491521502168_item	2616703	et	3	main
teine	doc_491521502168_item	2616704	et	3	main
valdkond	doc_491521502168_item	2616705	et	3	main
teisele	doc_491521502168_item	2616706	et	4	main
valdkonnale	doc_491521502168_item	2616707	et	4	main
või	doc_491521502168_item	2616708	et	4	main
teise	doc_491521502168_item	2616709	et	4	main
valdkonna	doc_491521502168_item	2616710	et	4	main
8	doc_491521502168_item	2616712	et	2	main
juurde	doc_491521502168_item	2616711	et	4	main
närimiskumm	doc_491521502168_item	2616713	et	3	main
kleepus	doc_491521502168_item	2616714	et	3	main
püksid	doc_491521502168_item	2616715	et	3	main
pükstele	doc_491521502168_item	2616716	et	3	main
9	doc_491521502168_item	2616717	et	2	main
külmal	doc_491521502168_item	2616718	et	3	main
ajal	doc_491521502168_item	2616719	et	4	main
peab	doc_491521502168_item	2616720	et	4	main
suvisest	doc_491521502168_item	2616730	et	4	main
täitke	doc_491521502168_item	2616733	et	3	main
sobivate	doc_491521502168_item	2616735	et	4	main
1	doc_491521502168_item	2616737	et	2	main
2	doc_491521502168_item	2616745	et	2	main
kohal	doc_491521502168_item	2616746	et	4	main
ka	doc_491521502168_item	2616751	et	3	main
hoiduma	doc_491521502168_item	2616721	et	3	main
10	doc_491521502168_item	2616724	et	2	main
päikesest	doc_491521502168_item	2616731	et	4	main
lüngad	doc_491521502168_item	2616734	et	3	main
sidenditega	doc_491521502168_item	2616736	et	3	main
tellisime	doc_491521502168_item	2616738	et	4	main
kolmekäigulise	doc_491521502168_item	2616739	et	4	main
olid	doc_491521502168_item	2616747	et	4	main
tulevad	doc_491521502168_item	2616760	et	4	main
4	doc_491521502168_item	2616761	et	2	main
keegi	doc_491521502168_item	2616767	et	4	main
ta	doc_491521502168_item	2616772	et	4	main
6	doc_491521502168_item	2616780	et	2	main
lõpetage	doc_491521502168_item	2616781	et	3	main
ei	doc_491521502168_item	2616773	et	4	main
töö	doc_491521502168_item	2616782	et	4	main
siis	doc_491521502168_item	2616783	et	3	main
lähete	doc_491521502168_item	2616784	et	4	main
jalutama	doc_491521502168_item	2616785	et	3	main
7	doc_491521502168_item	2616786	et	2	main
selles	doc_491521502168_item	2616787	et	4	main
baaris	doc_491521502168_item	2616788	et	3	main
ei	doc_491521502168_item	2616789	et	4	main
tohi	doc_491521502168_item	2616790	et	4	main
suitsetada	doc_491521502168_item	2616791	et	3	main
ega	doc_491521502168_item	2616792	et	3	main
alkoholi	doc_491521502168_item	2616793	et	4	main
tarbida	doc_491521502168_item	2616794	et	3	main
8	doc_491521502168_item	2616795	et	2	main
nad	doc_491521502168_item	2616796	et	3	main
töötasid	doc_491521502168_item	2616797	et	4	main
küll	doc_491521502168_item	2616798	et	4	main
pingsalt	doc_491521502168_item	2616799	et	4	main
kuid	doc_491521502168_item	2616800	et	4	main
tulemust	doc_491521502168_item	2616801	et	4	main
ei	doc_491521502168_item	2616802	et	4	main
olnud	doc_491521502168_item	2616803	et	4	main
9	doc_491521502168_item	2616804	et	2	main
kas	doc_491521502168_item	2616805	et	3	main
sa	doc_491521502168_item	2616806	et	3	main
sõidad	doc_491521502168_item	2616807	et	3	main
3	doc_491521502168_item	2616753	et	2	main
oodata	doc_491521502168_item	2616756	et	4	main
kuni	doc_491521502168_item	2616757	et	3	main
vanemad	doc_491521502168_item	2616758	et	4	main
tagasi	doc_491521502168_item	2616759	et	3	main
nagu	doc_491521502168_item	2616765	et	3	main
oleks	doc_491521502168_item	2616766	et	3	main
rääkinud	doc_491521502168_item	2616770	et	4	main
ukse	doc_491521502168_item	2616814	et	3	main
eesti	doc_491521502169_item	2616818	et	4	main
linna	doc_491521502168_item	2616811	et	4	main
eesti	doc_491521502169_item	2616821	et	4	main
test	doc_491521502169_item	2616823	et	3	main
i	doc_491521502169_item	2616824	et	4	main
sõnad	doc_491521502169_item	2616828	et	4	main
õigesse	doc_491521502169_item	2616829	et	3	main
naine	doc_491521502169_item	2616835	et	3	main
ta	doc_491521502169_item	2616839	et	4	main
siberisse	doc_491521502169_item	2616844	et	4	main
keele	doc_491521502169_item	2616850	et	4	main
konkurss	doc_491521502169_item	2616854	et	3	main
nüüd	doc_491521502169_item	2616858	et	4	main
üle	doc_491521502169_item	2616860	et	3	main
nädala	doc_491521502169_item	2616862	et	3	main
kinnitusel	doc_491521502169_item	2616871	et	4	main
tundis	doc_491521502169_item	2616872	et	3	main
ta	doc_491521502169_item	2616873	et	4	main
üsna	doc_491521502169_item	2616881	et	3	main
kool	doc_491521502169_item	2616921	et	4	main
kartuleid	doc_491521502169_item	2616929	et	3	main
siin	doc_491521502169_item	2616932	et	4	main
kõige	doc_491521502169_item	2616934	et	4	main
hoog	doc_491521502169_item	2616946	et	3	main
eestlased	doc_491521502169_item	2616949	et	3	main
kuidagi	doc_491521502169_item	2616951	et	3	main
vene	doc_491521502169_item	2616960	et	4	main
vaid	doc_491521502169_item	2616963	et	3	main
mõni	doc_491521502169_item	2616965	et	3	main
kool	doc_491521502169_item	2616972	et	4	main
ja	doc_491521502169_item	2616973	et	3	main
keeles	doc_491521502169_item	2616979	et	4	main
õpivad	doc_491521502169_item	2616995	et	3	main
siberi	doc_491521502169_item	2617006	et	4	main
talve	doc_491521502169_item	2617007	et	4	main
ei	doc_491521502169_item	2617009	et	4	main
kartma	doc_491521502169_item	2617010	et	3	main
toonud	doc_491521502169_item	2617015	et	4	main
on	doc_491521502169_item	2617018	et	4	main
juba	doc_491521502169_item	2617025	et	3	main
juba	doc_491521502169_item	2617029	et	3	main
vene	doc_491521502169_item	2617031	et	4	main
kütmisega	doc_491521502169_item	2617034	et	4	main
kui	doc_491521502169_item	2617035	et	3	main
muud	doc_491521502169_item	2617044	et	4	main
ei	doc_491521502169_item	2617045	et	4	main
naerab	doc_491521502169_item	2617047	et	3	main
ajalehest	doc_491521502169_item	2617054	et	4	main
laused	doc_491521502169_item	2617060	et	3	main
ja	doc_491521502169_item	2617065	et	3	main
naiselikumaks	doc_491521502169_item	2617081	et	4	main
ja	doc_491521502169_item	2617082	et	3	main
igaühest	doc_491521502169_item	2617085	et	4	main
panema	doc_491521502169_item	2617091	et	3	main
meie	doc_491521502169_item	2617092	et	4	main
tegutsema	doc_491521502169_item	2617093	et	3	main
sportima	doc_491521502169_item	2617121	et	4	main
tekkima	doc_491521502169_item	2617129	et	3	main
on	doc_491521502169_item	2617146	et	4	main
elama	doc_491521502169_item	2617156	et	3	main
ka	doc_491521502169_item	2617163	et	3	main
varahommik	doc_491521502169_item	2617165	et	3	main
valmistamine	doc_491521502169_item	2617169	et	4	main
varahommikul	doc_491521502169_item	2617182	et	3	main
2	doc_491521502169_item	2617219	et	2	main
kui	doc_491521502168_item	2616815	et	3	main
koputust	doc_491521502168_item	2616817	et	4	main
keele	doc_491521502169_item	2616819	et	4	main
test	doc_491521502169_item	2616820	et	3	main
toomet	doc_491521502169_item	2616832	et	4	main
nägema	doc_491521502169_item	2616837	et	3	main
kuulutus	doc_491521502169_item	2616841	et	4	main
kuulutust	doc_491521502169_item	2616842	et	4	main
et	doc_491521502169_item	2616843	et	3	main
eesti	doc_491521502169_item	2616849	et	4	main
võitis	doc_491521502169_item	2616853	et	3	main
juba	doc_491521502169_item	2616859	et	3	main
pireti	doc_491521502169_item	2616870	et	4	main
oodatud	doc_491521502169_item	2616879	et	4	main
olin	doc_491521502169_item	2616880	et	3	main
üllatuma	doc_491521502169_item	2616882	et	3	main
küla	doc_491521502169_item	2616926	et	4	main
võttis	doc_491521502169_item	2616928	et	3	main
käib	doc_491521502169_item	2616944	et	3	main
räägivad	doc_491521502169_item	2616950	et	3	main
ja	doc_491521502169_item	2616957	et	3	main
aktsendiga	doc_491521502169_item	2616962	et	3	main
mõnd	doc_491521502169_item	2616966	et	3	main
on	doc_491521502169_item	2616969	et	4	main
ülejäänud	doc_491521502169_item	2616974	et	4	main
emakeelt	doc_491521502169_item	2616988	et	4	main
saab	doc_491521502169_item	2616989	et	3	main
kõik	doc_491521502169_item	2616990	et	4	main
kõikjal	doc_491521502169_item	2616991	et	3	main
varsti	doc_491521502169_item	2617000	et	3	main
saadetakse	doc_491521502169_item	2617002	et	3	main
õpikud	doc_491521502169_item	2617005	et	3	main
mulle	doc_491521502169_item	2617012	et	4	main
juba	doc_491521502169_item	2617013	et	3	main
sojad	doc_491521502169_item	2617022	et	3	main
vaja	doc_491521502169_item	2617036	et	4	main
külapoest	doc_491521502169_item	2617039	et	4	main
vapralt	doc_491521502169_item	2617052	et	4	main
etteantud	doc_491521502169_item	2617058	et	4	main
sõnadest	doc_491521502169_item	2617059	et	3	main
mehelikum	doc_491521502169_item	2617075	et	4	main
igaüks	doc_491521502169_item	2617076	et	3	main
kaunim	doc_491521502169_item	2617077	et	4	main
ülekoormust	doc_491521502169_item	2617127	et	4	main
lausa	doc_491521502169_item	2617141	et	4	main
elama	doc_491521502169_item	2617142	et	3	main
ja	doc_491521502169_item	2617143	et	3	main
hingama	doc_491521502169_item	2617144	et	3	main
telefon	doc_491521502169_item	2617145	et	3	main
lausab	doc_491521502169_item	2617155	et	4	main
telefonihelin	doc_491521502169_item	2617161	et	3	main
söömine	doc_491521502169_item	2617171	et	4	main
huvitav	doc_491521502169_item	2617173	et	4	main
ka	doc_491521502169_item	2617180	et	3	main
nad	doc_491521502169_item	2617211	et	3	main
kõik	doc_491521502169_item	2617213	et	4	main
kõiki	doc_491521502169_item	2617214	et	4	main
ja	doc_491521502169_item	2617215	et	3	main
nõuded	doc_491521502169_item	2617222	et	3	main
3	doc_491521502169_item	2617224	et	2	main
huvitud	doc_491521502169_item	2617229	et	4	main
huvi	doc_491521502169_item	2617235	et	4	main
ilusade	doc_491521502169_item	2617242	et	3	main
ja	doc_491521502169_item	2617244	et	3	main
vastu	doc_491521502169_item	2617247	et	3	main
difteeria	doc_491521502169_item	2617253	et	4	main
difteeriaga	doc_491521502169_item	2617254	et	3	main
6	doc_491521502169_item	2617262	et	2	main
piirdusime	doc_491521502169_item	2617263	et	3	main
muudatused	doc_491521502169_item	2617268	et	3	main
väikeste	doc_491521502169_item	2617269	et	4	main
muudatustega	doc_491521502169_item	2617270	et	3	main
7	doc_491521502169_item	2617271	et	2	main
see	doc_491521502169_item	2617272	et	3	main
valdkonnale	doc_491521502169_item	2617278	et	4	main
kleepus	doc_491521502169_item	2617281	et	3	main
peab	doc_491521502169_item	2617287	et	4	main
külmetamine	doc_491521502169_item	2617289	et	4	main
päike	doc_491521502169_item	2617296	et	3	main
kolmekäigulise	doc_491521502169_item	2617306	et	4	main
lõuna	doc_491521502169_item	2617307	et	4	main
vormi	doc_491521502169_item	2616830	et	4	main
ettevõtlik	doc_491521502169_item	2616834	et	3	main
ülem-suetuki	doc_491521502169_item	2616845	et	4	main
õpetajat	doc_491521502169_item	2616851	et	4	main
konkurssi	doc_491521502169_item	2616855	et	4	main
õpetanud	doc_491521502169_item	2616869	et	4	main
on	doc_491521502169_item	2616878	et	4	main
tuli	doc_491521502169_item	2616887	et	4	main
vastu	doc_491521502169_item	2616888	et	3	main
korralik	doc_491521502169_item	2616889	et	3	main
korraliku	doc_491521502169_item	2616890	et	3	main
audiga	doc_491521502169_item	2616891	et	3	main
mulle	doc_491521502169_item	2616892	et	4	main
maaliti	doc_491521502169_item	2616893	et	3	main
siber	doc_491521502169_item	2616894	et	4	main
siberist	doc_491521502169_item	2616895	et	4	main
selline	doc_491521502169_item	2616896	et	4	main
pilt	doc_491521502169_item	2616897	et	3	main
et	doc_491521502169_item	2616898	et	3	main
seal	doc_491521502169_item	2616899	et	4	main
ei	doc_491521502169_item	2616900	et	4	main
lenda	doc_491521502169_item	2616902	et	4	main
lendama	doc_491521502169_item	2616901	et	3	main
lind	doc_491521502169_item	2616903	et	3	main
ega	doc_491521502169_item	2616904	et	3	main
kasva	doc_491521502169_item	2616905	et	4	main
rohi	doc_491521502169_item	2616906	et	4	main
kui	doc_491521502169_item	2616907	et	3	main
noor	doc_491521502169_item	2616908	et	3	main
ja	doc_491521502169_item	2616909	et	3	main
tahtmine	doc_491521502169_item	2616910	et	4	main
tahtmist	doc_491521502169_item	2616911	et	4	main
täis	doc_491521502169_item	2616912	et	4	main
piret	doc_491521502169_item	2616913	et	4	main
pärast	doc_491521502169_item	2616914	et	4	main
õppeaasta	doc_491521502169_item	2616915	et	4	main
algust	doc_491521502169_item	2616916	et	4	main
koht	doc_491521502169_item	2616917	et	3	main
kohale	doc_491521502169_item	2616918	et	4	main
jõudis	doc_491521502169_item	2616919	et	3	main
polnud	doc_491521502169_item	2616920	et	3	main
veel	doc_491521502169_item	2616922	et	4	main
algama	doc_491521502169_item	2616923	et	3	main
alganud	doc_491521502169_item	2616924	et	4	main
kogu	doc_491521502169_item	2616925	et	4	main
kartulivõtt	doc_491521502169_item	2616930	et	3	main
sügisel	doc_491521502169_item	2616933	et	3	main
ettevõtmine	doc_491521502169_item	2616937	et	3	main
tänaseks	doc_491521502169_item	2616938	et	4	main
mahlakati	doc_491521502169_item	2616958	et	3	main
mitte	doc_491521502169_item	2616959	et	3	main
venemaa	doc_491521502169_item	2616971	et	4	main
aine	doc_491521502169_item	2616975	et	4	main
on	doc_491521502169_item	2616931	et	4	main
tähtis	doc_491521502169_item	2616935	et	4	main
on	doc_491521502169_item	2616939	et	4	main
kartul	doc_491521502169_item	2616940	et	3	main
salv	doc_491521502169_item	2616941	et	3	main
ja	doc_491521502169_item	2616942	et	3	main
õppimine	doc_491521502169_item	2616943	et	4	main
hooaga	doc_491521502169_item	2616947	et	4	main
mõnus	doc_491521502169_item	2616953	et	4	main
aktsent	doc_491521502169_item	2616961	et	3	main
nagu	doc_491521502169_item	2616964	et	3	main
murret	doc_491521502169_item	2616967	et	4	main
kool	doc_491521502169_item	2616968	et	4	main
ained	doc_491521502169_item	2616976	et	3	main
õpetatakse	doc_491521502169_item	2616977	et	3	main
elab	doc_491521502169_item	2616981	et	3	main
veidi	doc_491521502169_item	2616982	et	3	main
kolmsada	doc_491521502169_item	2616984	et	4	main
kolmesaja	doc_491521502169_item	2616985	et	4	main
inimene	doc_491521502169_item	2616986	et	3	main
inimest	doc_491521502169_item	2616987	et	3	main
pireti	doc_491521502169_item	2616993	et	4	main
lapsed	doc_491521502169_item	2616996	et	3	main
raamatud	doc_491521502169_item	2616998	et	4	main
raamatuid	doc_491521502169_item	2616999	et	3	main
eestist	doc_491521502169_item	2617003	et	3	main
tooma	doc_491521502169_item	2617014	et	3	main
veel	doc_491521502169_item	2617020	et	4	main
soe	doc_491521502169_item	2617021	et	4	main
harjutan	doc_491521502169_item	2617028	et	3	main
suure	doc_491521502169_item	2617030	et	3	main
ahju	doc_491521502169_item	2617032	et	4	main
kütmine	doc_491521502169_item	2617033	et	4	main
külapood	doc_491521502169_item	2617038	et	3	main
vildid	doc_491521502169_item	2617040	et	4	main
ega	doc_491521502169_item	2617041	et	3	main
valmistuma	doc_491521502169_item	2617049	et	3	main
slõhtuleht	doc_491521502169_item	2617055	et	4	main
pannes	doc_491521502169_item	2617061	et	4	main
kirjavahemärke	doc_491521502169_item	2617067	et	4	main
naiselikum	doc_491521502169_item	2617072	et	4	main
ja	doc_491521502169_item	2617073	et	3	main
mehed	doc_491521502169_item	2617074	et	3	main
teeb	doc_491521502169_item	2617079	et	3	main
3	doc_491521502169_item	2617087	et	2	main
paras	doc_491521502169_item	2617088	et	3	main
kogus	doc_491521502169_item	2617089	et	4	main
stress	doc_491521502169_item	2617090	et	3	main
ja	doc_491521502169_item	2617122	et	3	main
pinge	doc_491521502169_item	2617128	et	4	main
olema	doc_491521502169_item	2617132	et	4	main
saama	doc_491521502169_item	2617134	et	4	main
saanud	doc_491521502169_item	2617147	et	4	main
tänapäeval	doc_491521502169_item	2617148	et	3	main
ja	doc_491521502169_item	2617157	et	3	main
kuid	doc_491521502169_item	2617177	et	4	main
telefonihelin	doc_491521502169_item	2617178	et	3	main
katkestab	doc_491521502169_item	2617179	et	3	main
aitavad	doc_491521502169_item	2617212	et	4	main
sa	doc_491521502169_item	2617228	et	3	main
4	doc_491521502169_item	2617248	et	2	main
on	doc_491521502169_item	2617250	et	4	main
küsimuses	doc_491521502169_item	2617265	et	4	main
vaid	doc_491521502169_item	2617266	et	3	main
väikesed	doc_491521502169_item	2617267	et	4	main
teisele	doc_491521502169_item	2617277	et	4	main
rõõmu	doc_491521502169_item	2617294	et	4	main
kohal	doc_491521502169_item	2617313	et	4	main
selles	doc_491521502169_item	2617354	et	4	main
tohi	doc_491521502169_item	2617357	et	4	main
tulemust	doc_491521502169_item	2617369	et	4	main
keele	doc_491521502170_item	2617387	et	4	main
test	doc_491521502170_item	2617388	et	3	main
i	doc_491521502170_item	2617392	et	4	main
olevad	doc_491521502170_item	2617395	et	4	main
vene	doc_491521502169_item	2616978	et	4	main
külas	doc_491521502169_item	2616980	et	3	main
üle	doc_491521502169_item	2616983	et	3	main
rääkida	doc_491521502169_item	2616992	et	3	main
talvepuud	doc_491521502169_item	2617016	et	4	main
ööd	doc_491521502169_item	2617024	et	4	main
jahe	doc_491521502169_item	2617026	et	3	main
ostan	doc_491521502169_item	2617037	et	3	main
seal	doc_491521502169_item	2617042	et	4	main
talveks	doc_491521502169_item	2617048	et	4	main
valmistunud	doc_491521502169_item	2617050	et	4	main
piret	doc_491521502169_item	2617051	et	4	main
iii	doc_491521502169_item	2617056	et	4	main
moodustage	doc_491521502169_item	2617057	et	3	main
õigesse	doc_491521502169_item	2617063	et	3	main
naisi	doc_491521502169_item	2617080	et	3	main
mehi	doc_491521502169_item	2617083	et	3	main
sõnul	doc_491521502169_item	2616994	et	3	main
poolpõlenud	doc_491521502169_item	2616997	et	4	main
saatma	doc_491521502169_item	2617001	et	3	main
uued	doc_491521502169_item	2617004	et	3	main
piret	doc_491521502169_item	2617008	et	4	main
kartnud	doc_491521502169_item	2617011	et	4	main
praegu	doc_491521502169_item	2617017	et	3	main
päevad	doc_491521502169_item	2617019	et	3	main
kuid	doc_491521502169_item	2617023	et	4	main
jahedad	doc_491521502169_item	2617027	et	3	main
suurt	doc_491521502169_item	2617043	et	3	main
müüdagi	doc_491521502169_item	2617046	et	3	main
lühendatud	doc_491521502169_item	2617053	et	4	main
sõnad	doc_491521502169_item	2617062	et	4	main
vormi	doc_491521502169_item	2617064	et	4	main
kasutades	doc_491521502169_item	2617066	et	3	main
2	doc_491521502169_item	2617068	et	2	main
naeratus	doc_491521502169_item	2617069	et	4	main
tegema	doc_491521502169_item	2617070	et	3	main
naised	doc_491521502169_item	2617071	et	3	main
naeratus	doc_491521502169_item	2617078	et	4	main
mehilikumaks	doc_491521502169_item	2617084	et	4	main
kaunimaks	doc_491521502169_item	2617086	et	4	main
aga	doc_491521502169_item	2617094	et	3	main
lisakoormus	doc_491521502169_item	2617095	et	3	main
võima	doc_491521502169_item	2617096	et	3	main
tooma	doc_491521502169_item	2617097	et	3	main
soovimatu	doc_491521502169_item	2617098	et	4	main
tagajärg	doc_491521502169_item	2617099	et	3	main
parases	doc_491521502169_item	2617100	et	4	main
koguses	doc_491521502169_item	2617101	et	4	main
stress	doc_491521502169_item	2617102	et	3	main
paneb	doc_491521502169_item	2617103	et	3	main
meid	doc_491521502169_item	2617104	et	4	main
tegutsema	doc_491521502169_item	2617105	et	3	main
aga	doc_491521502169_item	2617106	et	3	main
lisakoormus	doc_491521502169_item	2617107	et	3	main
võib	doc_491521502169_item	2617108	et	3	main
tuua	doc_491521502169_item	2617109	et	3	main
soovimatut	doc_491521502169_item	2617110	et	4	main
tagajärg	doc_491521502169_item	2617111	et	3	main
4	doc_491521502169_item	2617112	et	2	main
ei	doc_491521502169_item	2617113	et	4	main
tohtima	doc_491521502169_item	2617114	et	3	main
laskma	doc_491521502169_item	2617115	et	3	main
ülekoormus	doc_491521502169_item	2617116	et	3	main
tekkima	doc_491521502169_item	2617117	et	3	main
pinge	doc_491521502169_item	2617118	et	4	main
saama	doc_491521502169_item	2617119	et	4	main
maandama	doc_491521502169_item	2617120	et	3	main
puhkama	doc_491521502169_item	2617123	et	3	main
tohi	doc_491521502169_item	2617125	et	4	main
5	doc_491521502169_item	2617130	et	2	main
maagiline	doc_491521502169_item	2617136	et	4	main
aparaat	doc_491521502169_item	2617137	et	3	main
nii	doc_491521502169_item	2617149	et	3	main
maagiliseks	doc_491521502169_item	2617150	et	4	main
aparaadiks	doc_491521502169_item	2617151	et	3	main
et	doc_491521502169_item	2617152	et	3	main
selle	doc_491521502169_item	2617153	et	4	main
abiga	doc_491521502169_item	2617154	et	3	main
6	doc_491521502169_item	2617159	et	2	main
ei	doc_491521502169_item	2617124	et	4	main
lasta	doc_491521502169_item	2617126	et	4	main
telefon	doc_491521502169_item	2617131	et	3	main
tänapäev	doc_491521502169_item	2617133	et	3	main
nii	doc_491521502169_item	2617135	et	3	main
et	doc_491521502169_item	2617138	et	3	main
see	doc_491521502169_item	2617139	et	3	main
abil	doc_491521502169_item	2617140	et	4	main
hingama	doc_491521502169_item	2617158	et	3	main
kuid	doc_491521502169_item	2617160	et	4	main
katkestama	doc_491521502169_item	2617162	et	3	main
pühapäev	doc_491521502169_item	2617164	et	3	main
uni	doc_491521502169_item	2617166	et	3	main
lõunasöök	doc_491521502169_item	2617168	et	3	main
ja	doc_491521502169_item	2617170	et	3	main
pahandab	doc_491521502169_item	2617172	et	3	main
telesaade	doc_491521502169_item	2617174	et	4	main
vaatamine	doc_491521502169_item	2617175	et	4	main
aeg	doc_491521502169_item	2617176	et	3	main
pühapäeval	doc_491521502169_item	2617181	et	3	main
segab	doc_491521502169_item	2617184	et	3	main
lõunasöögi	doc_491521502169_item	2617185	et	3	main
ja	doc_491521502169_item	2617187	et	3	main
valmistamist	doc_491521502169_item	2617186	et	4	main
soomist	doc_491521502169_item	2617188	et	4	main
pahandab	doc_491521502169_item	2617189	et	3	main
huvitava	doc_491521502169_item	2617190	et	4	main
telesaade	doc_491521502169_item	2617191	et	4	main
vaatamise	doc_491521502169_item	2617192	et	4	main
aega	doc_491521502169_item	2617193	et	4	main
iv	doc_491521502169_item	2617194	et	4	main
pange	doc_491521502169_item	2617195	et	4	main
sulgudes	doc_491521502169_item	2617196	et	4	main
olevad	doc_491521502169_item	2617197	et	4	main
sõnad	doc_491521502169_item	2617198	et	4	main
õigesse	doc_491521502169_item	2617199	et	3	main
vormi	doc_491521502169_item	2617200	et	4	main
1	doc_491521502169_item	2617201	et	2	main
ma	doc_491521502169_item	2617202	et	3	main
pean	doc_491521502169_item	2617203	et	4	main
väga	doc_491521502169_item	2617204	et	3	main
lugu	doc_491521502169_item	2617205	et	4	main
oma	doc_491521502169_item	2617206	et	4	main
vanemad	doc_491521502169_item	2617207	et	4	main
oma	doc_491521502169_item	2617208	et	4	main
vanematele	doc_491521502169_item	2617209	et	4	main
segama	doc_491521502169_item	2617167	et	3	main
und	doc_491521502169_item	2617183	et	4	main
sest	doc_491521502169_item	2617210	et	4	main
arvasin	doc_491521502169_item	2617226	et	3	main
sport	doc_491521502169_item	2617230	et	3	main
tunned	doc_491521502169_item	2617234	et	3	main
autod	doc_491521502169_item	2617241	et	3	main
oht	doc_491521502169_item	2617251	et	3	main
kiiresti	doc_491521502169_item	2617261	et	3	main
selles	doc_491521502169_item	2617264	et	4	main
valdkond	doc_491521502169_item	2617276	et	3	main
pükstele	doc_491521502169_item	2617283	et	3	main
suvine	doc_491521502169_item	2617295	et	4	main
päikest	doc_491521502169_item	2617298	et	4	main
kuid	doc_491521502169_item	2617308	et	4	main
see	doc_491521502169_item	2617309	et	3	main
olid	doc_491521502169_item	2617314	et	4	main
3	doc_491521502169_item	2617319	et	2	main
paluti	doc_491521502169_item	2617321	et	3	main
kostis	doc_491521502169_item	2617329	et	4	main
naeru	doc_491521502169_item	2617330	et	4	main
5	doc_491521502169_item	2617338	et	2	main
ei	doc_491521502169_item	2617340	et	4	main
jalutama	doc_491521502169_item	2617352	et	3	main
ei	doc_491521502169_item	2617356	et	4	main
alkoholi	doc_491521502169_item	2617360	et	4	main
8	doc_491521502169_item	2617362	et	2	main
nad	doc_491521502169_item	2617363	et	3	main
töötasid	doc_491521502169_item	2617364	et	4	main
kuid	doc_491521502169_item	2617368	et	4	main
9	doc_491521502169_item	2617372	et	2	main
sõidad	doc_491521502169_item	2617375	et	3	main
eesti	doc_491521502170_item	2617389	et	4	main
keele	doc_491521502170_item	2617390	et	4	main
eestlastele	doc_491521502170_item	2617432	et	4	main
need	doc_491521502170_item	2617433	et	3	main
kinnitusel	doc_491521502170_item	2617439	et	4	main
üllatuma	doc_491521502170_item	2617450	et	3	main
siberist	doc_491521502170_item	2617463	et	4	main
selline	doc_491521502170_item	2617464	et	4	main
pilt	doc_491521502170_item	2617465	et	3	main
et	doc_491521502170_item	2617466	et	3	main
seal	doc_491521502170_item	2617467	et	4	main
ega	doc_491521502170_item	2617472	et	3	main
rohi	doc_491521502170_item	2617474	et	4	main
ja	doc_491521502170_item	2617477	et	3	main
tahtmine	doc_491521502170_item	2617478	et	4	main
piret	doc_491521502170_item	2617481	et	4	main
alganud	doc_491521502170_item	2617492	et	4	main
küla	doc_491521502170_item	2617494	et	4	main
võtma	doc_491521502170_item	2617495	et	3	main
võttis	doc_491521502170_item	2617496	et	3	main
kartuleid	doc_491521502170_item	2617497	et	3	main
kartulivõtt	doc_491521502170_item	2617498	et	3	main
tänaseks	doc_491521502170_item	2617506	et	4	main
õppimine	doc_491521502170_item	2617511	et	4	main
täie	doc_491521502170_item	2617513	et	3	main
hoog	doc_491521502170_item	2617514	et	3	main
mõnus	doc_491521502170_item	2617521	et	4	main
ja	doc_491521502170_item	2617525	et	3	main
aktsent	doc_491521502170_item	2617529	et	3	main
nagu	doc_491521502170_item	2617532	et	3	main
venemaa	doc_491521502170_item	2617539	et	4	main
kool	doc_491521502170_item	2617540	et	4	main
emakeelt	doc_491521502170_item	2617556	et	4	main
saab	doc_491521502170_item	2617557	et	3	main
sõnul	doc_491521502170_item	2617562	et	3	main
poolpõlenud	doc_491521502170_item	2617565	et	4	main
raamatutega	doc_491521502170_item	2617567	et	3	main
saadavad	doc_491521502170_item	2617570	et	4	main
eestist	doc_491521502170_item	2617571	et	3	main
uued	doc_491521502170_item	2617572	et	3	main
õpikud	doc_491521502170_item	2617573	et	3	main
siberi	doc_491521502170_item	2617574	et	4	main
soe	doc_491521502170_item	2617589	et	4	main
soojad	doc_491521502170_item	2617590	et	3	main
vene	doc_491521502170_item	2617599	et	4	main
kütmine	doc_491521502170_item	2617601	et	4	main
usaldavad	doc_491521502169_item	2617216	et	4	main
igaüks	doc_491521502169_item	2617217	et	3	main
igaüht	doc_491521502169_item	2617218	et	3	main
kohandasin	doc_491521502169_item	2617220	et	3	main
artikli	doc_491521502169_item	2617221	et	3	main
nõudeid	doc_491521502169_item	2617223	et	3	main
ma	doc_491521502169_item	2617225	et	3	main
et	doc_491521502169_item	2617227	et	3	main
spordiga	doc_491521502169_item	2617231	et	3	main
sa	doc_491521502169_item	2617233	et	3	main
ja	doc_491521502169_item	2617239	et	3	main
autode	doc_491521502169_item	2617246	et	3	main
praegu	doc_491521502169_item	2617249	et	3	main
haigestuda	doc_491521502169_item	2617252	et	3	main
5	doc_491521502169_item	2617255	et	2	main
tüdinesin	doc_491521502169_item	2617256	et	3	main
uus	doc_491521502169_item	2617257	et	3	main
töökoht	doc_491521502169_item	2617258	et	3	main
uuel	doc_491521502169_item	2617259	et	3	main
küsimus	doc_491521502169_item	2617273	et	4	main
kuulub	doc_491521502169_item	2617274	et	3	main
8	doc_491521502169_item	2617279	et	2	main
külmal	doc_491521502169_item	2617285	et	3	main
suvisest	doc_491521502169_item	2617297	et	4	main
v	doc_491521502169_item	2617299	et	4	main
täitke	doc_491521502169_item	2617300	et	3	main
lüngad	doc_491521502169_item	2617301	et	3	main
1	doc_491521502169_item	2617304	et	2	main
tellisime	doc_491521502169_item	2617305	et	4	main
palju	doc_491521502169_item	2617311	et	4	main
2	doc_491521502169_item	2617312	et	2	main
õpilased	doc_491521502169_item	2617316	et	3	main
nii	doc_491521502169_item	2617331	et	3	main
et	doc_491521502169_item	2617332	et	3	main
oleks	doc_491521502169_item	2617333	et	3	main
keegi	doc_491521502169_item	2617334	et	4	main
just	doc_491521502169_item	2617335	et	3	main
ta	doc_491521502169_item	2617339	et	4	main
tule	doc_491521502169_item	2617341	et	4	main
trenni	doc_491521502169_item	2617342	et	4	main
sest	doc_491521502169_item	2617343	et	4	main
läheb	doc_491521502169_item	2617344	et	3	main
hoopis	doc_491521502169_item	2617345	et	3	main
teatrisse	doc_491521502169_item	2617346	et	3	main
6	doc_491521502169_item	2617347	et	2	main
lõpetage	doc_491521502169_item	2617348	et	3	main
baaris	doc_491521502169_item	2617355	et	3	main
suitsetada	doc_491521502169_item	2617358	et	3	main
ega	doc_491521502169_item	2617359	et	3	main
tarbida	doc_491521502169_item	2617361	et	3	main
pingsalt	doc_491521502169_item	2617366	et	4	main
olnud	doc_491521502169_item	2617371	et	4	main
kas	doc_491521502169_item	2617373	et	3	main
maale	doc_491521502169_item	2617376	et	4	main
või	doc_491521502169_item	2617377	et	4	main
koputust	doc_491521502169_item	2617385	et	4	main
eesti	doc_491521502170_item	2617386	et	4	main
pange	doc_491521502170_item	2617393	et	4	main
õigesse	doc_491521502170_item	2617397	et	3	main
piret	doc_491521502170_item	2617399	et	4	main
võitis	doc_491521502170_item	2617421	et	3	main
konkurssi	doc_491521502170_item	2617423	et	4	main
on	doc_491521502170_item	2617425	et	4	main
nüüd	doc_491521502170_item	2617426	et	4	main
õpetanud	doc_491521502170_item	2617437	et	4	main
on	doc_491521502170_item	2617446	et	4	main
kui	doc_491521502170_item	2617452	et	3	main
tulema	doc_491521502170_item	2617454	et	4	main
kohale	doc_491521502170_item	2617486	et	4	main
jõudis	doc_491521502170_item	2617487	et	3	main
polnud	doc_491521502170_item	2617488	et	3	main
on	doc_491521502170_item	2617499	et	4	main
siin	doc_491521502170_item	2617500	et	4	main
sügisel	doc_491521502170_item	2617501	et	3	main
on	doc_491521502170_item	2617507	et	4	main
kartul	doc_491521502170_item	2617508	et	3	main
aga	doc_491521502169_item	2617232	et	3	main
ainult	doc_491521502169_item	2617236	et	4	main
ilusad	doc_491521502169_item	2617237	et	3	main
naised	doc_491521502169_item	2617238	et	3	main
kiired	doc_491521502169_item	2617240	et	4	main
naiste	doc_491521502169_item	2617243	et	3	main
kiirte	doc_491521502169_item	2617245	et	3	main
töökohal	doc_491521502169_item	2617260	et	4	main
teine	doc_491521502169_item	2617275	et	3	main
närimiskumm	doc_491521502169_item	2617280	et	3	main
püksid	doc_491521502169_item	2617282	et	3	main
9	doc_491521502169_item	2617284	et	2	main
ajal	doc_491521502169_item	2617286	et	4	main
hoiduma	doc_491521502169_item	2617288	et	3	main
külmetamist	doc_491521502169_item	2617290	et	4	main
10	doc_491521502169_item	2617291	et	2	main
ma	doc_491521502169_item	2617292	et	3	main
tunnen	doc_491521502169_item	2617293	et	3	main
sobivate	doc_491521502169_item	2617302	et	4	main
sidenditega	doc_491521502169_item	2617303	et	3	main
maksis	doc_491521502169_item	2617310	et	4	main
nii	doc_491521502169_item	2617315	et	3	main
lapsel	doc_491521502169_item	2617320	et	4	main
oodata	doc_491521502169_item	2617322	et	4	main
vanemad	doc_491521502169_item	2617324	et	4	main
4	doc_491521502169_item	2617327	et	2	main
rääkinud	doc_491521502169_item	2617337	et	4	main
töö	doc_491521502169_item	2617349	et	4	main
siis	doc_491521502169_item	2617350	et	3	main
lähete	doc_491521502169_item	2617351	et	4	main
7	doc_491521502169_item	2617353	et	2	main
küll	doc_491521502169_item	2617365	et	4	main
jääd	doc_491521502169_item	2617378	et	4	main
linna	doc_491521502169_item	2617379	et	4	main
10	doc_491521502169_item	2617380	et	2	main
avasin	doc_491521502169_item	2617381	et	3	main
ukse	doc_491521502169_item	2617382	et	3	main
sulgudes	doc_491521502170_item	2617394	et	4	main
sõnad	doc_491521502170_item	2617396	et	4	main
emakeelt	doc_491521502170_item	2617435	et	4	main
õpetama	doc_491521502170_item	2617436	et	3	main
siberisse	doc_491521502170_item	2617442	et	4	main
jõudma	doc_491521502170_item	2617443	et	3	main
jõudes	doc_491521502170_item	2617444	et	3	main
et	doc_491521502170_item	2617445	et	3	main
üllatunud	doc_491521502170_item	2617451	et	4	main
lendama	doc_491521502170_item	2617469	et	3	main
lind	doc_491521502170_item	2617471	et	3	main
õppeaasta	doc_491521502170_item	2617483	et	4	main
veel	doc_491521502170_item	2617490	et	4	main
kogu	doc_491521502170_item	2617493	et	4	main
tähtsam	doc_491521502170_item	2617504	et	4	main
ettevõtmine	doc_491521502170_item	2617505	et	3	main
mahlakas	doc_491521502170_item	2617523	et	4	main
mõnusalt	doc_491521502170_item	2617524	et	4	main
vaid	doc_491521502170_item	2617531	et	3	main
mõni	doc_491521502170_item	2617534	et	3	main
on	doc_491521502170_item	2617537	et	4	main
siiski	doc_491521502170_item	2617538	et	4	main
aine	doc_491521502170_item	2617543	et	4	main
veidi	doc_491521502170_item	2617550	et	3	main
kõikidega	doc_491521502170_item	2617559	et	4	main
rääkida	doc_491521502170_item	2617560	et	3	main
mulle	doc_491521502170_item	2617580	et	4	main
kuid	doc_491521502170_item	2617591	et	4	main
külapood	doc_491521502170_item	2617606	et	3	main
külapoest	doc_491521502170_item	2617607	et	4	main
ajalehest	doc_491521502170_item	2617622	et	4	main
iii	doc_491521502170_item	2617624	et	4	main
moodustage	doc_491521502170_item	2617625	et	3	main
kirjavahemärke	doc_491521502170_item	2617635	et	4	main
naeratus	doc_491521502170_item	2617646	et	4	main
tooma	doc_491521502170_item	2617665	et	3	main
stress	doc_491521502170_item	2617670	et	3	main
tegutsema	doc_491521502170_item	2617673	et	3	main
võib	doc_491521502170_item	2617676	et	3	main
ülekoormus	doc_491521502170_item	2617684	et	3	main
saama	doc_491521502170_item	2617687	et	4	main
sportima	doc_491521502170_item	2617689	et	4	main
ja	doc_491521502170_item	2617690	et	3	main
kui	doc_491521502169_item	2617317	et	3	main
õpetajad	doc_491521502169_item	2617318	et	4	main
kui	doc_491521502169_item	2617323	et	3	main
tagasi	doc_491521502169_item	2617325	et	3	main
tulevad	doc_491521502169_item	2617326	et	4	main
kõrvallauast	doc_491521502169_item	2617328	et	4	main
anekdooti	doc_491521502169_item	2617336	et	4	main
aga	doc_491521502169_item	2617367	et	3	main
ei	doc_491521502169_item	2617370	et	4	main
sa	doc_491521502169_item	2617374	et	3	main
sest	doc_491521502169_item	2617383	et	4	main
kuulsin	doc_491521502169_item	2617384	et	3	main
test	doc_491521502170_item	2617391	et	3	main
vormi	doc_491521502170_item	2617398	et	4	main
on	doc_491521502170_item	2617401	et	4	main
ettevõtlik	doc_491521502170_item	2617402	et	3	main
naine	doc_491521502170_item	2617403	et	3	main
suvel	doc_491521502170_item	2617404	et	3	main
toomet	doc_491521502170_item	2617400	et	4	main
nägema	doc_491521502170_item	2617405	et	3	main
nägi	doc_491521502170_item	2617406	et	3	main
ta	doc_491521502170_item	2617407	et	4	main
ajalehes	doc_491521502170_item	2617408	et	3	main
kuulutus	doc_491521502170_item	2617409	et	4	main
kuulutuse	doc_491521502170_item	2617410	et	4	main
et	doc_491521502170_item	2617411	et	3	main
siberisse	doc_491521502170_item	2617412	et	4	main
ülem-suetuki	doc_491521502170_item	2617413	et	4	main
küla	doc_491521502170_item	2617414	et	4	main
külasse	doc_491521502170_item	2617415	et	3	main
otsitakse	doc_491521502170_item	2617416	et	3	main
eesti	doc_491521502170_item	2617417	et	4	main
keele	doc_491521502170_item	2617418	et	4	main
õpetajat	doc_491521502170_item	2617419	et	4	main
piret	doc_491521502170_item	2617420	et	4	main
nende	doc_491521502170_item	2617434	et	4	main
tundis	doc_491521502170_item	2617440	et	3	main
ta	doc_491521502170_item	2617441	et	4	main
siber	doc_491521502170_item	2617462	et	4	main
ei	doc_491521502170_item	2617468	et	4	main
tahtmist	doc_491521502170_item	2617479	et	4	main
kool	doc_491521502170_item	2617489	et	4	main
kõige	doc_491521502170_item	2617502	et	4	main
salv	doc_491521502170_item	2617509	et	3	main
käib	doc_491521502170_item	2617512	et	3	main
vene	doc_491521502170_item	2617528	et	4	main
aktsendiga	doc_491521502170_item	2617530	et	3	main
mõni	doc_491521502170_item	2617533	et	3	main
ja	doc_491521502170_item	2617541	et	3	main
õpetatakse	doc_491521502170_item	2617545	et	3	main
kõik	doc_491521502170_item	2617558	et	4	main
õpivad	doc_491521502170_item	2617563	et	3	main
saatma	doc_491521502170_item	2617569	et	3	main
kartnud	doc_491521502170_item	2617579	et	4	main
toodi	doc_491521502170_item	2617583	et	4	main
päevad	doc_491521502170_item	2617587	et	3	main
veel	doc_491521502170_item	2617588	et	4	main
jahedad	doc_491521502170_item	2617595	et	3	main
suure	doc_491521502170_item	2617598	et	3	main
kütmisega	doc_491521502170_item	2617602	et	4	main
kui	doc_491521502170_item	2617603	et	3	main
vaja	doc_491521502170_item	2617604	et	4	main
ostan	doc_491521502170_item	2617605	et	3	main
konkurss	doc_491521502170_item	2617422	et	3	main
ja	doc_491521502170_item	2617424	et	3	main
juba	doc_491521502170_item	2617427	et	3	main
üle	doc_491521502170_item	2617428	et	3	main
nädal	doc_491521502170_item	2617429	et	3	main
nädala	doc_491521502170_item	2617430	et	3	main
väikestele	doc_491521502170_item	2617431	et	4	main
pireti	doc_491521502170_item	2617438	et	4	main
oodatud	doc_491521502170_item	2617447	et	4	main
olin	doc_491521502170_item	2617448	et	3	main
üsna	doc_491521502170_item	2617449	et	3	main
mulle	doc_491521502170_item	2617453	et	4	main
tulid	doc_491521502170_item	2617455	et	4	main
vastu	doc_491521502170_item	2617456	et	3	main
korralik	doc_491521502170_item	2617457	et	3	main
korraliku	doc_491521502170_item	2617458	et	3	main
audiga	doc_491521502170_item	2617459	et	3	main
mulle	doc_491521502170_item	2617460	et	4	main
maaliti	doc_491521502170_item	2617461	et	3	main
lenda	doc_491521502170_item	2617470	et	4	main
kasva	doc_491521502170_item	2617473	et	4	main
kui	doc_491521502170_item	2617475	et	3	main
noor	doc_491521502170_item	2617476	et	3	main
täis	doc_491521502170_item	2617480	et	4	main
pärast	doc_491521502170_item	2617482	et	4	main
algust	doc_491521502170_item	2617484	et	4	main
koht	doc_491521502170_item	2617485	et	3	main
algama	doc_491521502170_item	2617491	et	3	main
tähtis	doc_491521502170_item	2617503	et	4	main
ja	doc_491521502170_item	2617510	et	3	main
hooga	doc_491521502170_item	2617515	et	3	main
siinsed	doc_491521502170_item	2617516	et	3	main
eestlased	doc_491521502170_item	2617517	et	3	main
räägivad	doc_491521502170_item	2617518	et	3	main
kuidagi	doc_491521502170_item	2617519	et	3	main
teistmoodi	doc_491521502170_item	2617520	et	3	main
mahlakalt	doc_491521502170_item	2617526	et	4	main
murret	doc_491521502170_item	2617535	et	4	main
ained	doc_491521502170_item	2617544	et	3	main
keeles	doc_491521502170_item	2617547	et	4	main
külas	doc_491521502170_item	2617548	et	3	main
kolmsada	doc_491521502170_item	2617552	et	4	main
kolmesaja	doc_491521502170_item	2617553	et	4	main
inimene	doc_491521502170_item	2617554	et	3	main
inimest	doc_491521502170_item	2617555	et	3	main
pireti	doc_491521502170_item	2617561	et	4	main
raamatud	doc_491521502170_item	2617566	et	4	main
varsti	doc_491521502170_item	2617568	et	3	main
ei	doc_491521502170_item	2617577	et	4	main
kartma	doc_491521502170_item	2617578	et	3	main
tooma	doc_491521502170_item	2617582	et	3	main
talvepuud	doc_491521502170_item	2617584	et	4	main
ööd	doc_491521502170_item	2617592	et	4	main
harjutan	doc_491521502170_item	2617596	et	3	main
ahju	doc_491521502170_item	2617600	et	4	main
vildid	doc_491521502170_item	2617608	et	4	main
lühendatud	doc_491521502170_item	2617621	et	4	main
slõhtuleht	doc_491521502170_item	2617623	et	4	main
pannes	doc_491521502170_item	2617629	et	4	main
mehelikum	doc_491521502170_item	2617643	et	4	main
igaüks	doc_491521502170_item	2617644	et	3	main
kaunim	doc_491521502170_item	2617645	et	4	main
naiselikumaks	doc_491521502170_item	2617649	et	4	main
kaunimaks	doc_491521502170_item	2617654	et	4	main
3	doc_491521502170_item	2617655	et	2	main
paras	doc_491521502170_item	2617656	et	3	main
kogus	doc_491521502170_item	2617657	et	4	main
stress	doc_491521502170_item	2617658	et	3	main
soovimatu	doc_491521502170_item	2617666	et	4	main
tagajärg	doc_491521502170_item	2617667	et	3	main
kogutud	doc_491521502170_item	2617669	et	4	main
tohtima	doc_491521502170_item	2617682	et	3	main
sportima	doc_491521502170_item	2617700	et	4	main
ei	doc_491521502170_item	2617728	et	4	main
6	doc_491521502170_item	2617733	et	2	main
ja	doc_491521502170_item	2617522	et	3	main
mitte	doc_491521502170_item	2617527	et	3	main
kool	doc_491521502170_item	2617536	et	4	main
ülejäänud	doc_491521502170_item	2617542	et	4	main
vene	doc_491521502170_item	2617546	et	4	main
elab	doc_491521502170_item	2617549	et	3	main
üle	doc_491521502170_item	2617551	et	3	main
lapsed	doc_491521502170_item	2617564	et	3	main
talve	doc_491521502170_item	2617575	et	4	main
piret	doc_491521502170_item	2617576	et	4	main
juba	doc_491521502170_item	2617581	et	3	main
praegu	doc_491521502170_item	2617585	et	3	main
on	doc_491521502170_item	2617586	et	4	main
juba	doc_491521502170_item	2617593	et	3	main
jahe	doc_491521502170_item	2617594	et	3	main
juba	doc_491521502170_item	2617597	et	3	main
ega	doc_491521502170_item	2617609	et	3	main
seal	doc_491521502170_item	2617610	et	4	main
suurt	doc_491521502170_item	2617611	et	3	main
muud	doc_491521502170_item	2617612	et	4	main
ei	doc_491521502170_item	2617613	et	4	main
müüdagi	doc_491521502170_item	2617614	et	3	main
naerab	doc_491521502170_item	2617615	et	3	main
talveks	doc_491521502170_item	2617616	et	4	main
valmistuma	doc_491521502170_item	2617617	et	3	main
valmistumas	doc_491521502170_item	2617618	et	3	main
piret	doc_491521502170_item	2617619	et	4	main
vapralt	doc_491521502170_item	2617620	et	4	main
laused	doc_491521502170_item	2617628	et	3	main
vormi	doc_491521502170_item	2617632	et	4	main
kasutades	doc_491521502170_item	2617634	et	3	main
2	doc_491521502170_item	2617636	et	2	main
naeratus	doc_491521502170_item	2617637	et	4	main
teeb	doc_491521502170_item	2617647	et	3	main
ja	doc_491521502170_item	2617650	et	3	main
mehelikumaks	doc_491521502170_item	2617652	et	4	main
aga	doc_491521502170_item	2617674	et	3	main
tuua	doc_491521502170_item	2617677	et	3	main
soovimatuid	doc_491521502170_item	2617678	et	4	main
tagajargi	doc_491521502170_item	2617679	et	4	main
4	doc_491521502170_item	2617680	et	2	main
pinge	doc_491521502170_item	2617686	et	4	main
lasta	doc_491521502170_item	2617694	et	4	main
ülekoormuse	doc_491521502170_item	2617695	et	3	main
tekkimist	doc_491521502170_item	2617696	et	4	main
ja	doc_491521502170_item	2617701	et	3	main
olema	doc_491521502170_item	2617705	et	4	main
et	doc_491521502170_item	2617724	et	3	main
abil	doc_491521502170_item	2617726	et	4	main
lausa	doc_491521502170_item	2617727	et	4	main
hingata	doc_491521502170_item	2617732	et	4	main
katkestama	doc_491521502170_item	2617736	et	3	main
varahommik	doc_491521502170_item	2617739	et	3	main
segama	doc_491521502170_item	2617741	et	3	main
huvitav	doc_491521502170_item	2617747	et	4	main
telesaade	doc_491521502170_item	2617748	et	4	main
varahommikul	doc_491521502170_item	2617757	et	3	main
ja	doc_491521502170_item	2617761	et	3	main
ja	doc_491521502170_item	2617786	et	3	main
nõuded	doc_491521502170_item	2617793	et	3	main
et	doc_491521502170_item	2617797	et	3	main
huvi	doc_491521502170_item	2617805	et	4	main
ilusad	doc_491521502170_item	2617807	et	3	main
kiired	doc_491521502170_item	2617810	et	4	main
autod	doc_491521502170_item	2617811	et	3	main
ilusate	doc_491521502170_item	2617812	et	3	main
vastu	doc_491521502170_item	2617816	et	3	main
praegu	doc_491521502170_item	2617818	et	3	main
oht	doc_491521502170_item	2617820	et	3	main
difteeriaga	doc_491521502170_item	2617823	et	3	main
sõnad	doc_491521502170_item	2617630	et	4	main
õigesse	doc_491521502170_item	2617631	et	3	main
ja	doc_491521502170_item	2617633	et	3	main
tegema	doc_491521502170_item	2617638	et	3	main
naised	doc_491521502170_item	2617639	et	3	main
naiselikum	doc_491521502170_item	2617640	et	4	main
ja	doc_491521502170_item	2617641	et	3	main
mehed	doc_491521502170_item	2617642	et	3	main
naisi	doc_491521502170_item	2617648	et	3	main
mehi	doc_491521502170_item	2617651	et	3	main
igatühte	doc_491521502170_item	2617653	et	3	main
võima	doc_491521502170_item	2617664	et	3	main
parajasti	doc_491521502170_item	2617668	et	3	main
paneb	doc_491521502170_item	2617671	et	3	main
meid	doc_491521502170_item	2617672	et	4	main
lisakoormus	doc_491521502170_item	2617675	et	3	main
tekkima	doc_491521502170_item	2617685	et	3	main
maandama	doc_491521502170_item	2617688	et	3	main
puhkama	doc_491521502170_item	2617691	et	3	main
pinge	doc_491521502170_item	2617697	et	4	main
saamisel	doc_491521502170_item	2617698	et	4	main
maanduge	doc_491521502170_item	2617699	et	3	main
tänapäev	doc_491521502170_item	2617706	et	3	main
saama	doc_491521502170_item	2617707	et	4	main
nii	doc_491521502170_item	2617708	et	3	main
maagiline	doc_491521502170_item	2617709	et	4	main
aparaat	doc_491521502170_item	2617710	et	3	main
et	doc_491521502170_item	2617711	et	3	main
see	doc_491521502170_item	2617712	et	3	main
abil	doc_491521502170_item	2617713	et	4	main
lausa	doc_491521502170_item	2617714	et	4	main
elama	doc_491521502170_item	2617715	et	3	main
ja	doc_491521502170_item	2617716	et	3	main
hingama	doc_491521502170_item	2617717	et	3	main
telefon	doc_491521502170_item	2617718	et	3	main
on	doc_491521502170_item	2617719	et	4	main
tänapäeval	doc_491521502170_item	2617720	et	3	main
etteantud	doc_491521502170_item	2617626	et	4	main
sõnadest	doc_491521502170_item	2617627	et	3	main
panema	doc_491521502170_item	2617659	et	3	main
meie	doc_491521502170_item	2617660	et	4	main
tegutsema	doc_491521502170_item	2617661	et	3	main
aga	doc_491521502170_item	2617662	et	3	main
lisakoormus	doc_491521502170_item	2617663	et	3	main
ei	doc_491521502170_item	2617681	et	4	main
laskma	doc_491521502170_item	2617683	et	3	main
ei	doc_491521502170_item	2617692	et	4	main
tohi	doc_491521502170_item	2617693	et	4	main
5	doc_491521502170_item	2617703	et	2	main
aparaat	doc_491521502170_item	2617723	et	3	main
selle	doc_491521502170_item	2617725	et	4	main
ja	doc_491521502170_item	2617731	et	3	main
telefonihelin	doc_491521502170_item	2617735	et	3	main
segab	doc_491521502170_item	2617758	et	3	main
valmistamisel	doc_491521502170_item	2617760	et	4	main
telesaade	doc_491521502170_item	2617763	et	4	main
vaatamiseaega	doc_491521502170_item	2617764	et	4	main
sõnad	doc_491521502170_item	2617769	et	4	main
pean	doc_491521502170_item	2617774	et	4	main
väga	doc_491521502170_item	2617775	et	3	main
lugu	doc_491521502170_item	2617776	et	4	main
oma	doc_491521502170_item	2617777	et	4	main
aitavad	doc_491521502170_item	2617783	et	4	main
usaldavad	doc_491521502170_item	2617787	et	4	main
igaühte	doc_491521502170_item	2617789	et	4	main
artikli	doc_491521502170_item	2617792	et	3	main
ma	doc_491521502170_item	2617795	et	3	main
sa	doc_491521502170_item	2617798	et	3	main
sport	doc_491521502170_item	2617800	et	3	main
naised	doc_491521502170_item	2617808	et	3	main
autode	doc_491521502170_item	2617815	et	3	main
puhkama	doc_491521502170_item	2617702	et	3	main
telefon	doc_491521502170_item	2617704	et	3	main
nii	doc_491521502170_item	2617721	et	3	main
elada	doc_491521502170_item	2617730	et	3	main
ka	doc_491521502170_item	2617737	et	3	main
lõunasöök	doc_491521502170_item	2617742	et	3	main
vaatamine	doc_491521502170_item	2617749	et	4	main
olevad	doc_491521502170_item	2617768	et	4	main
vormi	doc_491521502170_item	2617771	et	4	main
ma	doc_491521502170_item	2617773	et	3	main
kõike	doc_491521502170_item	2617785	et	4	main
3	doc_491521502170_item	2617794	et	2	main
arvasin	doc_491521502170_item	2617796	et	3	main
spordiga	doc_491521502170_item	2617801	et	3	main
sa	doc_491521502170_item	2617803	et	3	main
ainult	doc_491521502170_item	2617806	et	4	main
ja	doc_491521502170_item	2617809	et	3	main
naiste	doc_491521502170_item	2617813	et	3	main
piirdusime	doc_491521502170_item	2617832	et	3	main
muudatustega	doc_491521502170_item	2617839	et	3	main
kuulub	doc_491521502170_item	2617843	et	3	main
valdkonnale	doc_491521502170_item	2617847	et	4	main
8	doc_491521502170_item	2617848	et	2	main
närimiskumm	doc_491521502170_item	2617849	et	3	main
kleepus	doc_491521502170_item	2617850	et	3	main
püksid	doc_491521502170_item	2617851	et	3	main
9	doc_491521502170_item	2617853	et	2	main
külmal	doc_491521502170_item	2617854	et	3	main
ajal	doc_491521502170_item	2617855	et	4	main
päikese	doc_491521502170_item	2617867	et	4	main
3	doc_491521502170_item	2617890	et	2	main
tagasi	doc_491521502170_item	2617896	et	3	main
4	doc_491521502170_item	2617898	et	2	main
kõrvallauast	doc_491521502170_item	2617899	et	4	main
tule	doc_491521502170_item	2617911	et	4	main
jalutama	doc_491521502170_item	2617922	et	3	main
baaris	doc_491521502170_item	2617925	et	3	main
alkoholi	doc_491521502170_item	2617931	et	4	main
küll	doc_491521502170_item	2617936	et	4	main
pingsalt	doc_491521502170_item	2617937	et	4	main
aga	doc_491521502170_item	2617938	et	3	main
sõidad	doc_491521502170_item	2617945	et	3	main
keele	doc_491521502171_item	2617960	et	4	main
sõnad	doc_491521502171_item	2617966	et	4	main
eestlastele	doc_491521502171_item	2618002	et	4	main
need	doc_491521502171_item	2618003	et	3	main
pireti	doc_491521502171_item	2618007	et	4	main
ta	doc_491521502171_item	2618010	et	4	main
et	doc_491521502171_item	2618013	et	3	main
on	doc_491521502171_item	2618014	et	4	main
mulle	doc_491521502171_item	2618027	et	4	main
lenda	doc_491521502171_item	2618037	et	4	main
lind	doc_491521502171_item	2618038	et	3	main
ega	doc_491521502171_item	2618039	et	3	main
kasva	doc_491521502171_item	2618040	et	4	main
tahtmise	doc_491521502171_item	2618046	et	4	main
pärast	doc_491521502171_item	2618049	et	4	main
jõudis	doc_491521502171_item	2618054	et	3	main
küla	doc_491521502171_item	2618061	et	4	main
võtma	doc_491521502171_item	2618062	et	3	main
võttis	doc_491521502171_item	2618063	et	3	main
on	doc_491521502171_item	2618066	et	4	main
keeles	doc_491521502171_item	2618114	et	4	main
külas	doc_491521502171_item	2618115	et	3	main
elab	doc_491521502171_item	2618116	et	3	main
veidi	doc_491521502171_item	2618117	et	3	main
üle	doc_491521502171_item	2618118	et	3	main
inimest	doc_491521502171_item	2618122	et	3	main
kõik	doc_491521502171_item	2618125	et	4	main
saadetakse	doc_491521502171_item	2618135	et	3	main
talvepuud	doc_491521502171_item	2618149	et	4	main
on	doc_491521502171_item	2618151	et	4	main
päevad	doc_491521502171_item	2618152	et	3	main
veel	doc_491521502171_item	2618153	et	4	main
kuid	doc_491521502171_item	2618156	et	4	main
juba	doc_491521502171_item	2618158	et	3	main
juba	doc_491521502171_item	2618162	et	3	main
vene	doc_491521502171_item	2618164	et	4	main
kütmine	doc_491521502171_item	2618166	et	4	main
ega	doc_491521502171_item	2618174	et	3	main
muud	doc_491521502171_item	2618177	et	4	main
naerab	doc_491521502171_item	2618180	et	3	main
maagiline	doc_491521502170_item	2617722	et	4	main
saa	doc_491521502170_item	2617729	et	4	main
kuid	doc_491521502170_item	2617734	et	4	main
pühapäev	doc_491521502170_item	2617738	et	3	main
uni	doc_491521502170_item	2617740	et	3	main
valmistamine	doc_491521502170_item	2617743	et	4	main
söömine	doc_491521502170_item	2617745	et	4	main
telefonihelin	doc_491521502170_item	2617752	et	3	main
katkestab	doc_491521502170_item	2617753	et	3	main
kuid	doc_491521502170_item	2617751	et	4	main
und	doc_491521502170_item	2617754	et	4	main
ka	doc_491521502170_item	2617755	et	3	main
pühapäeval	doc_491521502170_item	2617756	et	3	main
ja	doc_491521502170_item	2617744	et	3	main
pahandab	doc_491521502170_item	2617746	et	3	main
aeg	doc_491521502170_item	2617750	et	3	main
lõunasoogi	doc_491521502170_item	2617759	et	4	main
iv	doc_491521502170_item	2617765	et	4	main
sulgudes	doc_491521502170_item	2617767	et	4	main
õigesse	doc_491521502170_item	2617770	et	3	main
1	doc_491521502170_item	2617772	et	2	main
oma	doc_491521502170_item	2617779	et	4	main
vanematest	doc_491521502170_item	2617780	et	4	main
sest	doc_491521502170_item	2617781	et	4	main
nad	doc_491521502170_item	2617782	et	3	main
kohandasin	doc_491521502170_item	2617791	et	3	main
aga	doc_491521502170_item	2617802	et	3	main
tunned	doc_491521502170_item	2617804	et	3	main
4	doc_491521502170_item	2617817	et	2	main
on	doc_491521502170_item	2617819	et	4	main
haigestuda	doc_491521502170_item	2617821	et	3	main
5	doc_491521502170_item	2617824	et	2	main
tüdinesin	doc_491521502170_item	2617825	et	3	main
uue	doc_491521502170_item	2617828	et	3	main
töökohaga	doc_491521502170_item	2617829	et	4	main
väikeste	doc_491521502170_item	2617838	et	4	main
teisele	doc_491521502170_item	2617846	et	4	main
pükstele	doc_491521502170_item	2617852	et	3	main
ma	doc_491521502170_item	2617861	et	3	main
rõõmu	doc_491521502170_item	2617863	et	4	main
suvine	doc_491521502170_item	2617864	et	4	main
päike	doc_491521502170_item	2617865	et	3	main
ka	doc_491521502170_item	2617888	et	3	main
kostis	doc_491521502170_item	2617900	et	4	main
just	doc_491521502170_item	2617905	et	3	main
5	doc_491521502170_item	2617908	et	2	main
ei	doc_491521502170_item	2617910	et	4	main
lühendab	doc_491521502170_item	2617762	et	3	main
pange	doc_491521502170_item	2617766	et	4	main
vanemad	doc_491521502170_item	2617778	et	4	main
kõik	doc_491521502170_item	2617784	et	4	main
igaüks	doc_491521502170_item	2617788	et	3	main
2	doc_491521502170_item	2617790	et	2	main
huvitud	doc_491521502170_item	2617799	et	4	main
kiirete	doc_491521502170_item	2617814	et	4	main
difteeria	doc_491521502170_item	2617822	et	4	main
uus	doc_491521502170_item	2617826	et	3	main
selles	doc_491521502170_item	2617833	et	4	main
vaid	doc_491521502170_item	2617835	et	3	main
muudatused	doc_491521502170_item	2617837	et	3	main
külmetamine	doc_491521502170_item	2617858	et	4	main
külmetamisest	doc_491521502170_item	2617859	et	4	main
kui	doc_491521502170_item	2617887	et	3	main
lapsel	doc_491521502170_item	2617891	et	4	main
keegi	doc_491521502170_item	2617904	et	4	main
rääkinud	doc_491521502170_item	2617907	et	4	main
läheb	doc_491521502170_item	2617913	et	3	main
hoopis	doc_491521502170_item	2617914	et	3	main
teatrisse	doc_491521502170_item	2617915	et	3	main
töö	doc_491521502170_item	2617918	et	4	main
ja	doc_491521502170_item	2617919	et	3	main
siis	doc_491521502170_item	2617920	et	3	main
lähete	doc_491521502170_item	2617921	et	4	main
ei	doc_491521502170_item	2617926	et	4	main
tohi	doc_491521502170_item	2617927	et	4	main
suitsetada	doc_491521502170_item	2617928	et	3	main
8	doc_491521502170_item	2617933	et	2	main
9	doc_491521502170_item	2617942	et	2	main
sa	doc_491521502170_item	2617944	et	3	main
jääd	doc_491521502170_item	2617948	et	4	main
avasin	doc_491521502170_item	2617951	et	3	main
kuulsin	doc_491521502170_item	2617954	et	3	main
vormi	doc_491521502171_item	2617968	et	4	main
konkurssi	doc_491521502171_item	2617993	et	4	main
on	doc_491521502171_item	2617995	et	4	main
nädala	doc_491521502171_item	2618000	et	3	main
väikestele	doc_491521502171_item	2618001	et	4	main
õpetama	doc_491521502171_item	2618006	et	3	main
üllatatud	doc_491521502171_item	2618019	et	4	main
tulema	doc_491521502171_item	2618022	et	4	main
tuli	doc_491521502171_item	2618023	et	4	main
vastu	doc_491521502171_item	2618024	et	3	main
korralik	doc_491521502171_item	2618025	et	3	main
siber	doc_491521502171_item	2618029	et	4	main
pilt	doc_491521502171_item	2618032	et	3	main
rohi	doc_491521502171_item	2618041	et	4	main
kui	doc_491521502171_item	2618042	et	3	main
noor	doc_491521502171_item	2618043	et	3	main
ja	doc_491521502171_item	2618044	et	3	main
koht	doc_491521502171_item	2618052	et	3	main
kool	doc_491521502171_item	2618056	et	4	main
veel	doc_491521502171_item	2618057	et	4	main
algama	doc_491521502171_item	2618058	et	3	main
kartuleid	doc_491521502171_item	2618064	et	3	main
tähtsam	doc_491521502171_item	2618071	et	4	main
ettevõtmine	doc_491521502171_item	2618072	et	3	main
tänaseks	doc_491521502171_item	2618073	et	4	main
on	doc_491521502171_item	2618074	et	4	main
kartul	doc_491521502171_item	2618075	et	3	main
salv	doc_491521502171_item	2618076	et	3	main
vene	doc_491521502171_item	2618113	et	4	main
kolmesaja	doc_491521502171_item	2618120	et	4	main
pireti	doc_491521502171_item	2618127	et	4	main
sõnul	doc_491521502171_item	2618128	et	3	main
lapsed	doc_491521502171_item	2618130	et	3	main
poolpõlenud	doc_491521502171_item	2618131	et	4	main
siberi	doc_491521502171_item	2618139	et	4	main
piret	doc_491521502171_item	2618141	et	4	main
ei	doc_491521502171_item	2618142	et	4	main
kartma	doc_491521502171_item	2618143	et	3	main
praegu	doc_491521502171_item	2618150	et	3	main
soe	doc_491521502171_item	2618155	et	4	main
jahe	doc_491521502171_item	2618160	et	3	main
külapoest	doc_491521502171_item	2618172	et	4	main
talveks	doc_491521502171_item	2618181	et	4	main
valmistuma	doc_491521502171_item	2618182	et	3	main
valmistatud	doc_491521502171_item	2618183	et	4	main
lühendatud	doc_491521502171_item	2618186	et	4	main
töökoht	doc_491521502170_item	2617827	et	3	main
kiiresti	doc_491521502170_item	2617830	et	3	main
7	doc_491521502170_item	2617840	et	2	main
küsimus	doc_491521502170_item	2617842	et	4	main
teine	doc_491521502170_item	2617844	et	3	main
valdkond	doc_491521502170_item	2617845	et	3	main
peab	doc_491521502170_item	2617856	et	4	main
10	doc_491521502170_item	2617860	et	2	main
tunnen	doc_491521502170_item	2617862	et	3	main
suvise	doc_491521502170_item	2617866	et	4	main
vastu	doc_491521502170_item	2617868	et	3	main
v	doc_491521502170_item	2617869	et	4	main
täitke	doc_491521502170_item	2617870	et	3	main
lüngad	doc_491521502170_item	2617871	et	3	main
sobivate	doc_491521502170_item	2617872	et	4	main
sidenditega	doc_491521502170_item	2617873	et	3	main
1	doc_491521502170_item	2617874	et	2	main
tellisime	doc_491521502170_item	2617875	et	4	main
kolmekäigulise	doc_491521502170_item	2617876	et	4	main
lõuna	doc_491521502170_item	2617877	et	4	main
aga	doc_491521502170_item	2617878	et	3	main
see	doc_491521502170_item	2617879	et	3	main
maksis	doc_491521502170_item	2617880	et	4	main
palju	doc_491521502170_item	2617881	et	4	main
2	doc_491521502170_item	2617882	et	2	main
kohal	doc_491521502170_item	2617883	et	4	main
olid	doc_491521502170_item	2617884	et	4	main
nii	doc_491521502170_item	2617885	et	3	main
õpilased	doc_491521502170_item	2617886	et	3	main
6	doc_491521502170_item	2617831	et	2	main
küsimuses	doc_491521502170_item	2617834	et	4	main
väikesed	doc_491521502170_item	2617836	et	4	main
see	doc_491521502170_item	2617841	et	3	main
hoiduma	doc_491521502170_item	2617857	et	3	main
paluti	doc_491521502170_item	2617892	et	3	main
kuna	doc_491521502170_item	2617894	et	3	main
tulevad	doc_491521502170_item	2617897	et	4	main
oleks	doc_491521502170_item	2617903	et	3	main
trenni	doc_491521502170_item	2617912	et	4	main
6	doc_491521502170_item	2617916	et	2	main
7	doc_491521502170_item	2617923	et	2	main
selles	doc_491521502170_item	2617924	et	4	main
ning	doc_491521502170_item	2617930	et	3	main
töötasid	doc_491521502170_item	2617935	et	4	main
tulemust	doc_491521502170_item	2617939	et	4	main
või	doc_491521502170_item	2617947	et	4	main
koputust	doc_491521502170_item	2617955	et	4	main
keele	doc_491521502171_item	2617957	et	4	main
eesti	doc_491521502171_item	2617959	et	4	main
oloevad	doc_491521502171_item	2617965	et	4	main
keele	doc_491521502171_item	2617988	et	4	main
ja	doc_491521502171_item	2617994	et	3	main
oodatud	doc_491521502171_item	2618015	et	4	main
olin	doc_491521502171_item	2618016	et	3	main
üsna	doc_491521502171_item	2618017	et	3	main
üllatuma	doc_491521502171_item	2618018	et	3	main
mulle	doc_491521502171_item	2618021	et	4	main
audiga	doc_491521502171_item	2618026	et	3	main
täis	doc_491521502171_item	2618047	et	4	main
õppeaasta	doc_491521502171_item	2618050	et	4	main
kohale	doc_491521502171_item	2618053	et	4	main
alganud	doc_491521502171_item	2618059	et	4	main
ülejäänud	doc_491521502171_item	2618109	et	4	main
aine	doc_491521502171_item	2618110	et	4	main
ained	doc_491521502171_item	2618111	et	3	main
õpetatakse	doc_491521502171_item	2618112	et	3	main
inimene	doc_491521502171_item	2618121	et	3	main
emakeelt	doc_491521502171_item	2618123	et	4	main
rääkida	doc_491521502171_item	2618126	et	3	main
õpivad	doc_491521502171_item	2618129	et	3	main
õpikud	doc_491521502171_item	2618138	et	3	main
mulle	doc_491521502171_item	2618145	et	4	main
juba	doc_491521502171_item	2618146	et	3	main
tooma	doc_491521502171_item	2618147	et	3	main
toodud	doc_491521502171_item	2618148	et	4	main
ahju	doc_491521502171_item	2618165	et	4	main
kütma	doc_491521502171_item	2618167	et	3	main
kui	doc_491521502171_item	2618168	et	3	main
vaja	doc_491521502171_item	2618169	et	4	main
ostan	doc_491521502171_item	2618170	et	3	main
külapood	doc_491521502171_item	2618171	et	3	main
laused	doc_491521502171_item	2618193	et	3	main
õigesse	doc_491521502171_item	2618196	et	3	main
paras	doc_491521502171_item	2618221	et	3	main
võima	doc_491521502171_item	2618229	et	3	main
lisakoormus	doc_491521502171_item	2618233	et	3	main
ei	doc_491521502171_item	2618246	et	4	main
tekkima	doc_491521502171_item	2618250	et	3	main
5	doc_491521502171_item	2618259	et	2	main
olema	doc_491521502171_item	2618261	et	4	main
tänapäev	doc_491521502171_item	2618262	et	3	main
saama	doc_491521502171_item	2618263	et	4	main
aparaat	doc_491521502171_item	2618279	et	3	main
vormi	doc_491521502171_item	2618326	et	4	main
ma	doc_491521502171_item	2618328	et	3	main
vanemad	doc_491521502171_item	2618333	et	4	main
ja	doc_491521502171_item	2618341	et	3	main
usaldavad	doc_491521502171_item	2618342	et	4	main
igaüks	doc_491521502171_item	2618343	et	3	main
igaühe	doc_491521502171_item	2618344	et	4	main
2	doc_491521502171_item	2618345	et	2	main
kohandasin	doc_491521502171_item	2618346	et	3	main
artikli	doc_491521502171_item	2618347	et	3	main
nõuded	doc_491521502171_item	2618348	et	3	main
autod	doc_491521502171_item	2618367	et	3	main
ilusate	doc_491521502171_item	2618368	et	3	main
naistele	doc_491521502171_item	2618369	et	3	main
ja	doc_491521502171_item	2618370	et	3	main
autodele	doc_491521502171_item	2618372	et	3	main
tüdinesin	doc_491521502171_item	2618381	et	3	main
õpetajad	doc_491521502170_item	2617889	et	4	main
oodata	doc_491521502170_item	2617893	et	4	main
vanemad	doc_491521502170_item	2617895	et	4	main
naeru	doc_491521502170_item	2617901	et	4	main
nagu	doc_491521502170_item	2617902	et	3	main
anekdooti	doc_491521502170_item	2617906	et	4	main
ta	doc_491521502170_item	2617909	et	4	main
lõpetage	doc_491521502170_item	2617917	et	3	main
ja	doc_491521502170_item	2617929	et	3	main
ei	doc_491521502170_item	2617940	et	4	main
linna	doc_491521502170_item	2617949	et	4	main
kui	doc_491521502170_item	2617953	et	3	main
test	doc_491521502171_item	2617961	et	3	main
i	doc_491521502171_item	2617962	et	4	main
pange	doc_491521502171_item	2617963	et	4	main
õigesse	doc_491521502171_item	2617967	et	3	main
õpetajat	doc_491521502171_item	2617989	et	4	main
konkurss	doc_491521502171_item	2617992	et	3	main
nüüd	doc_491521502171_item	2617996	et	4	main
juba	doc_491521502171_item	2617997	et	3	main
üle	doc_491521502171_item	2617998	et	3	main
nädal	doc_491521502171_item	2617999	et	3	main
kinnitusel	doc_491521502171_item	2618008	et	4	main
tundis	doc_491521502171_item	2618009	et	3	main
siberisse	doc_491521502171_item	2618011	et	4	main
jõudma	doc_491521502171_item	2618012	et	3	main
tarbida	doc_491521502170_item	2617932	et	3	main
nad	doc_491521502170_item	2617934	et	3	main
olnud	doc_491521502170_item	2617941	et	4	main
kas	doc_491521502170_item	2617943	et	3	main
maale	doc_491521502170_item	2617946	et	4	main
10	doc_491521502170_item	2617950	et	2	main
ukse	doc_491521502170_item	2617952	et	3	main
eesti	doc_491521502171_item	2617956	et	4	main
test	doc_491521502171_item	2617958	et	3	main
sulgudes	doc_491521502171_item	2617964	et	4	main
toomet	doc_491521502171_item	2617970	et	4	main
piret	doc_491521502171_item	2617969	et	4	main
on	doc_491521502171_item	2617971	et	4	main
ettevõtlik	doc_491521502171_item	2617972	et	3	main
naine	doc_491521502171_item	2617973	et	3	main
suvel	doc_491521502171_item	2617974	et	3	main
nägema	doc_491521502171_item	2617975	et	3	main
nägi	doc_491521502171_item	2617976	et	3	main
ta	doc_491521502171_item	2617977	et	4	main
ajalehes	doc_491521502171_item	2617978	et	3	main
kuulutus	doc_491521502171_item	2617979	et	4	main
kuulutust	doc_491521502171_item	2617980	et	4	main
et	doc_491521502171_item	2617981	et	3	main
siberisse	doc_491521502171_item	2617982	et	4	main
ülem-suetuki	doc_491521502171_item	2617983	et	4	main
küla	doc_491521502171_item	2617984	et	4	main
küllas	doc_491521502171_item	2617985	et	3	main
otsitakse	doc_491521502171_item	2617986	et	3	main
eesti	doc_491521502171_item	2617987	et	4	main
piret	doc_491521502171_item	2617990	et	4	main
võitis	doc_491521502171_item	2617991	et	3	main
neid	doc_491521502171_item	2618004	et	4	main
emakeelt	doc_491521502171_item	2618005	et	4	main
kui	doc_491521502171_item	2618020	et	3	main
seal	doc_491521502171_item	2618034	et	4	main
ei	doc_491521502171_item	2618035	et	4	main
lendama	doc_491521502171_item	2618036	et	3	main
tahtmine	doc_491521502171_item	2618045	et	4	main
algust	doc_491521502171_item	2618051	et	4	main
polnud	doc_491521502171_item	2618055	et	3	main
kogu	doc_491521502171_item	2618060	et	4	main
kartulivõtt	doc_491521502171_item	2618065	et	3	main
siin	doc_491521502171_item	2618067	et	4	main
sügisel	doc_491521502171_item	2618068	et	3	main
kõige	doc_491521502171_item	2618069	et	4	main
kolmsada	doc_491521502171_item	2618119	et	4	main
raamatud	doc_491521502171_item	2618132	et	4	main
varsti	doc_491521502171_item	2618133	et	3	main
saatma	doc_491521502171_item	2618134	et	3	main
uued	doc_491521502171_item	2618137	et	3	main
talve	doc_491521502171_item	2618140	et	4	main
karda	doc_491521502171_item	2618144	et	4	main
ööd	doc_491521502171_item	2618157	et	4	main
jahe	doc_491521502171_item	2618159	et	3	main
harjutan	doc_491521502171_item	2618161	et	3	main
suure	doc_491521502171_item	2618163	et	3	main
seal	doc_491521502171_item	2618175	et	4	main
suurt	doc_491521502171_item	2618176	et	3	main
ei	doc_491521502171_item	2618178	et	4	main
müüdagi	doc_491521502171_item	2618179	et	3	main
vapralt	doc_491521502171_item	2618185	et	4	main
kogus	doc_491521502171_item	2618222	et	4	main
soovimatu	doc_491521502171_item	2618231	et	4	main
paneb	doc_491521502171_item	2618236	et	3	main
meid	doc_491521502171_item	2618237	et	4	main
tegutsema	doc_491521502171_item	2618238	et	3	main
aga	doc_491521502171_item	2618239	et	3	main
stres	doc_491521502171_item	2618240	et	4	main
võib	doc_491521502171_item	2618241	et	3	main
tuua	doc_491521502171_item	2618242	et	3	main
saama	doc_491521502171_item	2618252	et	4	main
nii	doc_491521502171_item	2618264	et	3	main
et	doc_491521502171_item	2618267	et	3	main
abil	doc_491521502171_item	2618269	et	4	main
elama	doc_491521502171_item	2618271	et	3	main
ja	doc_491521502171_item	2618272	et	3	main
on	doc_491521502171_item	2618276	et	4	main
selle	doc_491521502171_item	2618281	et	4	main
lausa	doc_491521502171_item	2618284	et	4	main
elama	doc_491521502171_item	2618285	et	3	main
ja	doc_491521502171_item	2618286	et	3	main
hingama	doc_491521502171_item	2618287	et	3	main
maaliti	doc_491521502171_item	2618028	et	3	main
siberist	doc_491521502171_item	2618030	et	4	main
selline	doc_491521502171_item	2618031	et	4	main
et	doc_491521502171_item	2618033	et	3	main
piret	doc_491521502171_item	2618048	et	4	main
tähtis	doc_491521502171_item	2618070	et	4	main
ja	doc_491521502171_item	2618077	et	3	main
õppimine	doc_491521502171_item	2618078	et	4	main
käib	doc_491521502171_item	2618079	et	3	main
täie	doc_491521502171_item	2618080	et	3	main
hoog	doc_491521502171_item	2618081	et	3	main
hooguga	doc_491521502171_item	2618082	et	4	main
siinsed	doc_491521502171_item	2618083	et	3	main
eestlased	doc_491521502171_item	2618084	et	3	main
räägivad	doc_491521502171_item	2618085	et	3	main
kuidagi	doc_491521502171_item	2618086	et	3	main
teistmoodi	doc_491521502171_item	2618087	et	3	main
mõnus	doc_491521502171_item	2618088	et	4	main
ja	doc_491521502171_item	2618089	et	3	main
mahlakas	doc_491521502171_item	2618090	et	4	main
mõnusalt	doc_491521502171_item	2618091	et	4	main
ja	doc_491521502171_item	2618092	et	3	main
mahlakaselt	doc_491521502171_item	2618093	et	3	main
mitte	doc_491521502171_item	2618094	et	3	main
vene	doc_491521502171_item	2618095	et	4	main
aktsent	doc_491521502171_item	2618096	et	3	main
aktsentiga	doc_491521502171_item	2618097	et	4	main
vaid	doc_491521502171_item	2618098	et	3	main
nagu	doc_491521502171_item	2618099	et	3	main
mõni	doc_491521502171_item	2618100	et	3	main
mõne	doc_491521502171_item	2618101	et	3	main
murret	doc_491521502171_item	2618102	et	4	main
kool	doc_491521502171_item	2618103	et	4	main
on	doc_491521502171_item	2618104	et	4	main
siiski	doc_491521502171_item	2618105	et	4	main
venemaa	doc_491521502171_item	2618106	et	4	main
kool	doc_491521502171_item	2618107	et	4	main
ja	doc_491521502171_item	2618108	et	3	main
saab	doc_491521502171_item	2618124	et	3	main
eestist	doc_491521502171_item	2618136	et	3	main
soe	doc_491521502171_item	2618154	et	4	main
vildid	doc_491521502171_item	2618173	et	4	main
piret	doc_491521502171_item	2618184	et	4	main
naeratus	doc_491521502171_item	2618202	et	4	main
tegema	doc_491521502171_item	2618203	et	3	main
naised	doc_491521502171_item	2618204	et	3	main
naiselikum	doc_491521502171_item	2618205	et	4	main
ja	doc_491521502171_item	2618206	et	3	main
mehed	doc_491521502171_item	2618207	et	3	main
mehelikum	doc_491521502171_item	2618208	et	4	main
igaüks	doc_491521502171_item	2618209	et	3	main
kaunim	doc_491521502171_item	2618210	et	4	main
naeratus	doc_491521502171_item	2618211	et	4	main
teeb	doc_491521502171_item	2618212	et	3	main
naisi	doc_491521502171_item	2618213	et	3	main
naiselikumaks	doc_491521502171_item	2618214	et	4	main
mehi	doc_491521502171_item	2618215	et	3	main
mehelikumaks	doc_491521502171_item	2618216	et	4	main
ja	doc_491521502171_item	2618217	et	3	main
igaühe	doc_491521502171_item	2618218	et	4	main
kaunimaks	doc_491521502171_item	2618219	et	4	main
3	doc_491521502171_item	2618220	et	2	main
tegutsema	doc_491521502171_item	2618226	et	3	main
lisakoormus	doc_491521502171_item	2618228	et	3	main
soovimatu	doc_491521502171_item	2618243	et	4	main
pinge	doc_491521502171_item	2618251	et	4	main
ja	doc_491521502171_item	2618255	et	3	main
nii	doc_491521502171_item	2618277	et	3	main
1	doc_491521502171_item	2618327	et	2	main
lugu	doc_491521502171_item	2618331	et	4	main
aitavad	doc_491521502171_item	2618338	et	4	main
kõik	doc_491521502171_item	2618339	et	4	main
kõiki	doc_491521502171_item	2618340	et	4	main
tunned	doc_491521502171_item	2618360	et	3	main
huvi	doc_491521502171_item	2618361	et	4	main
ainult	doc_491521502171_item	2618362	et	4	main
ilusad	doc_491521502171_item	2618363	et	3	main
naised	doc_491521502171_item	2618364	et	3	main
ja	doc_491521502171_item	2618365	et	3	main
praegu	doc_491521502171_item	2618374	et	3	main
difteeriaga	doc_491521502171_item	2618379	et	3	main
uus	doc_491521502171_item	2618382	et	3	main
väikesed	doc_491521502171_item	2618392	et	4	main
kuulub	doc_491521502171_item	2618399	et	3	main
kleepus	doc_491521502171_item	2618406	et	3	main
9	doc_491521502171_item	2618409	et	2	main
peab	doc_491521502171_item	2618412	et	4	main
suvine	doc_491521502171_item	2618420	et	4	main
sidenditega	doc_491521502171_item	2618428	et	3	main
maksis	doc_491521502171_item	2618435	et	4	main
kõrvallauast	doc_491521502171_item	2618454	et	4	main
just	doc_491521502171_item	2618460	et	3	main
ei	doc_491521502171_item	2618465	et	4	main
ei	doc_491521502171_item	2618481	et	4	main
ajalehest	doc_491521502171_item	2618187	et	4	main
iii	doc_491521502171_item	2618189	et	4	main
moodustage	doc_491521502171_item	2618190	et	3	main
etteantud	doc_491521502171_item	2618191	et	4	main
sõnadest	doc_491521502171_item	2618192	et	3	main
sõnad	doc_491521502171_item	2618195	et	4	main
vormi	doc_491521502171_item	2618197	et	4	main
ja	doc_491521502171_item	2618198	et	3	main
kasutades	doc_491521502171_item	2618199	et	3	main
kirjavahemärke	doc_491521502171_item	2618200	et	4	main
2	doc_491521502171_item	2618201	et	2	main
meie	doc_491521502171_item	2618225	et	4	main
slõhtuleht	doc_491521502171_item	2618188	et	4	main
pannes	doc_491521502171_item	2618194	et	4	main
panema	doc_491521502171_item	2618224	et	3	main
tooma	doc_491521502171_item	2618230	et	3	main
tagajärg	doc_491521502171_item	2618232	et	3	main
tagajärgi	doc_491521502171_item	2618244	et	4	main
4	doc_491521502171_item	2618245	et	2	main
maandama	doc_491521502171_item	2618253	et	3	main
ei	doc_491521502171_item	2618257	et	4	main
maagiline	doc_491521502171_item	2618265	et	4	main
see	doc_491521502171_item	2618268	et	3	main
lausa	doc_491521502171_item	2618270	et	4	main
hingama	doc_491521502171_item	2618273	et	3	main
telefon	doc_491521502171_item	2618274	et	3	main
magiline	doc_491521502171_item	2618278	et	4	main
et	doc_491521502171_item	2618280	et	3	main
abil	doc_491521502171_item	2618282	et	4	main
sulgudes	doc_491521502171_item	2618322	et	4	main
olevad	doc_491521502171_item	2618323	et	4	main
sõnad	doc_491521502171_item	2618324	et	4	main
õigesse	doc_491521502171_item	2618325	et	3	main
väga	doc_491521502171_item	2618330	et	3	main
kiirde	doc_491521502171_item	2618371	et	4	main
on	doc_491521502171_item	2618375	et	4	main
haigestuda	doc_491521502171_item	2618377	et	3	main
6	doc_491521502171_item	2618387	et	2	main
7	doc_491521502171_item	2618396	et	2	main
teine	doc_491521502171_item	2618400	et	3	main
teise	doc_491521502171_item	2618402	et	4	main
8	doc_491521502171_item	2618404	et	2	main
ajal	doc_491521502171_item	2618411	et	4	main
külmetamine	doc_491521502171_item	2618414	et	4	main
suvisest	doc_491521502171_item	2618422	et	4	main
v	doc_491521502171_item	2618424	et	4	main
1	doc_491521502171_item	2618429	et	2	main
2	doc_491521502171_item	2618437	et	2	main
3	doc_491521502171_item	2618445	et	2	main
paluti	doc_491521502171_item	2618447	et	3	main
kuna	doc_491521502171_item	2618449	et	3	main
anekdooti	doc_491521502171_item	2618461	et	4	main
rääkinud	doc_491521502171_item	2618462	et	4	main
siis	doc_491521502171_item	2618475	et	3	main
selles	doc_491521502171_item	2618479	et	4	main
küll	doc_491521502171_item	2618490	et	4	main
ta	doc_491521502172_item	2618531	et	4	main
küla	doc_491521502172_item	2618538	et	4	main
võitis	doc_491521502172_item	2618545	et	3	main
nüüd	doc_491521502172_item	2618550	et	4	main
nädal	doc_491521502172_item	2618553	et	3	main
kinnitusel	doc_491521502172_item	2618563	et	4	main
mulle	doc_491521502172_item	2618584	et	4	main
piret	doc_491521502172_item	2618605	et	4	main
kartuleid	doc_491521502172_item	2618621	et	3	main
ettevõtmine	doc_491521502172_item	2618629	et	3	main
tänaseks	doc_491521502172_item	2618630	et	4	main
on	doc_491521502172_item	2618631	et	4	main
kartul	doc_491521502172_item	2618632	et	3	main
täie	doc_491521502172_item	2618638	et	3	main
siinsed	doc_491521502172_item	2618641	et	3	main
mõnus	doc_491521502172_item	2618646	et	4	main
aktsent	doc_491521502172_item	2618654	et	3	main
mõnd	doc_491521502172_item	2618659	et	3	main
on	doc_491521502172_item	2618662	et	4	main
siiski	doc_491521502172_item	2618663	et	4	main
õpetatakse	doc_491521502172_item	2618670	et	3	main
vene	doc_491521502172_item	2618671	et	4	main
kolmesaja	doc_491521502172_item	2618678	et	4	main
inimene	doc_491521502172_item	2618679	et	3	main
inimest	doc_491521502172_item	2618680	et	3	main
kõikidega	doc_491521502172_item	2618684	et	4	main
kartma	doc_491521502172_item	2618703	et	3	main
talvepuud	doc_491521502172_item	2618708	et	4	main
praegu	doc_491521502172_item	2618709	et	3	main
on	doc_491521502172_item	2618710	et	4	main
päevad	doc_491521502172_item	2618711	et	3	main
jahe	doc_491521502172_item	2618718	et	3	main
jahedad	doc_491521502172_item	2618719	et	3	main
kütmine	doc_491521502172_item	2618725	et	4	main
kui	doc_491521502172_item	2618727	et	3	main
külapood	doc_491521502172_item	2618730	et	3	main
külapoest	doc_491521502172_item	2618731	et	4	main
stress	doc_491521502171_item	2618223	et	3	main
aga	doc_491521502171_item	2618227	et	3	main
parases	doc_491521502171_item	2618234	et	4	main
koguses	doc_491521502171_item	2618235	et	4	main
tohtima	doc_491521502171_item	2618247	et	3	main
laskma	doc_491521502171_item	2618248	et	3	main
ülekoormus	doc_491521502171_item	2618249	et	3	main
sportima	doc_491521502171_item	2618254	et	4	main
puhkama	doc_491521502171_item	2618256	et	3	main
tea	doc_491521502171_item	2618258	et	4	main
telefon	doc_491521502171_item	2618260	et	3	main
aparaat	doc_491521502171_item	2618266	et	3	main
tänapäeval	doc_491521502171_item	2618275	et	3	main
saab	doc_491521502171_item	2618283	et	3	main
6	doc_491521502171_item	2618288	et	2	main
kuid	doc_491521502171_item	2618289	et	4	main
telefonihelin	doc_491521502171_item	2618290	et	3	main
katkestama	doc_491521502171_item	2618291	et	3	main
ka	doc_491521502171_item	2618292	et	3	main
pühapäev	doc_491521502171_item	2618293	et	3	main
varahommik	doc_491521502171_item	2618294	et	3	main
uni	doc_491521502171_item	2618295	et	3	main
segama	doc_491521502171_item	2618296	et	3	main
lõunasöök	doc_491521502171_item	2618297	et	3	main
valmistamine	doc_491521502171_item	2618298	et	4	main
ja	doc_491521502171_item	2618299	et	3	main
söömine	doc_491521502171_item	2618300	et	4	main
pahandab	doc_491521502171_item	2618301	et	3	main
huvitav	doc_491521502171_item	2618302	et	4	main
telesaade	doc_491521502171_item	2618303	et	4	main
vaatamine	doc_491521502171_item	2618304	et	4	main
aeg	doc_491521502171_item	2618305	et	3	main
huvitava	doc_491521502171_item	2618306	et	4	main
telesaate	doc_491521502171_item	2618307	et	3	main
vaatamine	doc_491521502171_item	2618308	et	4	main
segab	doc_491521502171_item	2618309	et	3	main
lõunasöögi	doc_491521502171_item	2618310	et	3	main
valmistamist	doc_491521502171_item	2618311	et	4	main
ja	doc_491521502171_item	2618312	et	3	main
söömist	doc_491521502171_item	2618313	et	4	main
kuid	doc_491521502171_item	2618314	et	4	main
telefonihelin	doc_491521502171_item	2618315	et	3	main
katkestab	doc_491521502171_item	2618316	et	3	main
pühapäeval	doc_491521502171_item	2618317	et	3	main
varahommikul	doc_491521502171_item	2618318	et	3	main
und	doc_491521502171_item	2618319	et	4	main
iv	doc_491521502171_item	2618320	et	4	main
pange	doc_491521502171_item	2618321	et	4	main
pean	doc_491521502171_item	2618329	et	4	main
oma	doc_491521502171_item	2618332	et	4	main
oma	doc_491521502171_item	2618334	et	4	main
nõudeid	doc_491521502171_item	2618349	et	3	main
3	doc_491521502171_item	2618350	et	2	main
ma	doc_491521502171_item	2618351	et	3	main
arvasin	doc_491521502171_item	2618352	et	3	main
et	doc_491521502171_item	2618353	et	3	main
sa	doc_491521502171_item	2618354	et	3	main
huvitud	doc_491521502171_item	2618355	et	4	main
sport	doc_491521502171_item	2618356	et	3	main
aga	doc_491521502171_item	2618358	et	3	main
sporti	doc_491521502171_item	2618357	et	4	main
sa	doc_491521502171_item	2618359	et	3	main
vanematest	doc_491521502171_item	2618335	et	4	main
sest	doc_491521502171_item	2618336	et	4	main
nad	doc_491521502171_item	2618337	et	3	main
kiired	doc_491521502171_item	2618366	et	4	main
5	doc_491521502171_item	2618380	et	2	main
töökoht	doc_491521502171_item	2618383	et	3	main
muudatused	doc_491521502171_item	2618393	et	3	main
see	doc_491521502171_item	2618397	et	3	main
valdkond	doc_491521502171_item	2618401	et	3	main
valdkonda	doc_491521502171_item	2618403	et	4	main
külmetamisest	doc_491521502171_item	2618415	et	4	main
tunnen	doc_491521502171_item	2618418	et	3	main
4	doc_491521502171_item	2618373	et	2	main
oht	doc_491521502171_item	2618376	et	3	main
difteeria	doc_491521502171_item	2618378	et	4	main
uuel	doc_491521502171_item	2618384	et	3	main
kiiresti	doc_491521502171_item	2618386	et	3	main
selles	doc_491521502171_item	2618389	et	4	main
küsimuses	doc_491521502171_item	2618390	et	4	main
väikestel	doc_491521502171_item	2618394	et	4	main
muudatustel	doc_491521502171_item	2618395	et	3	main
küsimus	doc_491521502171_item	2618398	et	4	main
püksid	doc_491521502171_item	2618407	et	3	main
külmal	doc_491521502171_item	2618410	et	3	main
10	doc_491521502171_item	2618416	et	2	main
lüngad	doc_491521502171_item	2618426	et	3	main
palju	doc_491521502171_item	2618436	et	4	main
kohal	doc_491521502171_item	2618438	et	4	main
olid	doc_491521502171_item	2618439	et	4	main
nii	doc_491521502171_item	2618440	et	3	main
õpilased	doc_491521502171_item	2618441	et	3	main
kui	doc_491521502171_item	2618442	et	3	main
lapsel	doc_491521502171_item	2618446	et	4	main
oodata	doc_491521502171_item	2618448	et	4	main
naeru	doc_491521502171_item	2618456	et	4	main
nagu	doc_491521502171_item	2618457	et	3	main
oleks	doc_491521502171_item	2618458	et	3	main
lõpetage	doc_491521502171_item	2618473	et	3	main
töö	doc_491521502171_item	2618474	et	4	main
7	doc_491521502171_item	2618478	et	2	main
tohi	doc_491521502171_item	2618482	et	4	main
suitsetada	doc_491521502171_item	2618483	et	3	main
ning	doc_491521502171_item	2618484	et	3	main
alkoholi	doc_491521502171_item	2618485	et	4	main
tarbida	doc_491521502171_item	2618486	et	3	main
8	doc_491521502171_item	2618487	et	2	main
nad	doc_491521502171_item	2618488	et	3	main
toomet	doc_491521502172_item	2618524	et	4	main
on	doc_491521502172_item	2618525	et	4	main
ettevõtlik	doc_491521502172_item	2618526	et	3	main
naine	doc_491521502172_item	2618527	et	3	main
suvel	doc_491521502172_item	2618528	et	3	main
nägema	doc_491521502172_item	2618529	et	3	main
nägi	doc_491521502172_item	2618530	et	3	main
ülem-suetuki	doc_491521502172_item	2618537	et	4	main
piret	doc_491521502172_item	2618544	et	4	main
ja	doc_491521502172_item	2618548	et	3	main
nende	doc_491521502172_item	2618558	et	4	main
emakeelt	doc_491521502172_item	2618559	et	4	main
õpetama	doc_491521502172_item	2618560	et	3	main
õpetab	doc_491521502172_item	2618561	et	3	main
jõudes	doc_491521502172_item	2618568	et	3	main
olin	doc_491521502172_item	2618572	et	3	main
üllatunud	doc_491521502172_item	2618575	et	4	main
siberist	doc_491521502172_item	2618587	et	4	main
selline	doc_491521502172_item	2618588	et	4	main
lendama	doc_491521502172_item	2618593	et	3	main
rohi	doc_491521502172_item	2618598	et	4	main
kui	doc_491521502172_item	2618599	et	3	main
noor	doc_491521502172_item	2618600	et	3	main
ja	doc_491521502172_item	2618601	et	3	main
täis	doc_491521502172_item	2618604	et	4	main
õppeaasta	doc_491521502172_item	2618607	et	4	main
töökohal	doc_491521502171_item	2618385	et	4	main
piirdusime	doc_491521502171_item	2618388	et	3	main
vaid	doc_491521502171_item	2618391	et	3	main
närimiskumm	doc_491521502171_item	2618405	et	3	main
pükstel	doc_491521502171_item	2618408	et	3	main
hoiduma	doc_491521502171_item	2618413	et	3	main
ma	doc_491521502171_item	2618417	et	3	main
rõõmu	doc_491521502171_item	2618419	et	4	main
päike	doc_491521502171_item	2618421	et	3	main
päikesest	doc_491521502171_item	2618423	et	4	main
täitke	doc_491521502171_item	2618425	et	3	main
kolmekäigulise	doc_491521502171_item	2618431	et	4	main
õpetajad	doc_491521502171_item	2618444	et	4	main
kostis	doc_491521502171_item	2618455	et	4	main
ta	doc_491521502171_item	2618464	et	4	main
tule	doc_491521502171_item	2618466	et	4	main
trenni	doc_491521502171_item	2618467	et	4	main
lähete	doc_491521502171_item	2618476	et	4	main
baaris	doc_491521502171_item	2618480	et	3	main
vormi	doc_491521502172_item	2618522	et	4	main
kuulutus	doc_491521502172_item	2618533	et	4	main
kuulutust	doc_491521502172_item	2618534	et	4	main
et	doc_491521502172_item	2618535	et	3	main
siberisse	doc_491521502172_item	2618536	et	4	main
keele	doc_491521502172_item	2618542	et	4	main
õpetajat	doc_491521502172_item	2618543	et	4	main
konkurssi	doc_491521502172_item	2618547	et	4	main
juba	doc_491521502172_item	2618551	et	3	main
nädalat	doc_491521502172_item	2618554	et	3	main
eestlastele	doc_491521502172_item	2618556	et	4	main
need	doc_491521502172_item	2618557	et	3	main
tundis	doc_491521502172_item	2618564	et	3	main
ta	doc_491521502172_item	2618565	et	4	main
siberisse	doc_491521502172_item	2618566	et	4	main
jõudma	doc_491521502172_item	2618567	et	3	main
oodatud	doc_491521502172_item	2618571	et	4	main
maaliti	doc_491521502172_item	2618585	et	3	main
seal	doc_491521502172_item	2618591	et	4	main
tahtmine	doc_491521502172_item	2618602	et	4	main
siin	doc_491521502172_item	2618624	et	4	main
käib	doc_491521502172_item	2618637	et	3	main
aktsendiga	doc_491521502172_item	2618655	et	3	main
venemaa	doc_491521502172_item	2618664	et	4	main
kool	doc_491521502172_item	2618665	et	4	main
ja	doc_491521502172_item	2618666	et	3	main
emakeelt	doc_491521502172_item	2618681	et	4	main
rääkida	doc_491521502172_item	2618685	et	3	main
sõnul	doc_491521502172_item	2618687	et	3	main
lapsed	doc_491521502172_item	2618689	et	3	main
raamatud	doc_491521502172_item	2618691	et	4	main
raamatutega	doc_491521502172_item	2618692	et	3	main
varsti	doc_491521502172_item	2618693	et	3	main
saatma	doc_491521502172_item	2618694	et	3	main
saadakse	doc_491521502172_item	2618695	et	3	main
eestist	doc_491521502172_item	2618696	et	3	main
uued	doc_491521502172_item	2618697	et	3	main
siberi	doc_491521502172_item	2618699	et	4	main
talve	doc_491521502172_item	2618700	et	4	main
karda	doc_491521502172_item	2618704	et	4	main
juba	doc_491521502172_item	2618706	et	3	main
vene	doc_491521502172_item	2618723	et	4	main
vildid	doc_491521502172_item	2618732	et	4	main
ega	doc_491521502172_item	2618733	et	3	main
valmistunud	doc_491521502172_item	2618742	et	4	main
slõhtuleht	doc_491521502172_item	2618747	et	4	main
sõnad	doc_491521502172_item	2618754	et	4	main
vormi	doc_491521502172_item	2618756	et	4	main
ja	doc_491521502172_item	2618757	et	3	main
kasutades	doc_491521502172_item	2618758	et	3	main
kirjavahemärke	doc_491521502172_item	2618759	et	4	main
2	doc_491521502172_item	2618760	et	2	main
mehelikum	doc_491521502172_item	2618767	et	4	main
naisi	doc_491521502172_item	2618772	et	3	main
stress	doc_491521502172_item	2618782	et	3	main
panema	doc_491521502172_item	2618783	et	3	main
tegutsema	doc_491521502172_item	2618785	et	3	main
stress	doc_491521502172_item	2618794	et	3	main
laskma	doc_491521502172_item	2618807	et	3	main
sportima	doc_491521502172_item	2618813	et	4	main
ei	doc_491521502172_item	2618816	et	4	main
tohi	doc_491521502172_item	2618817	et	4	main
sobivate	doc_491521502171_item	2618427	et	4	main
tellisime	doc_491521502171_item	2618430	et	4	main
lõuna	doc_491521502171_item	2618432	et	4	main
kuid	doc_491521502171_item	2618433	et	4	main
see	doc_491521502171_item	2618434	et	3	main
ka	doc_491521502171_item	2618443	et	3	main
vanemad	doc_491521502171_item	2618450	et	4	main
tagasi	doc_491521502171_item	2618451	et	3	main
tulevad	doc_491521502171_item	2618452	et	4	main
4	doc_491521502171_item	2618453	et	2	main
keegi	doc_491521502171_item	2618459	et	4	main
5	doc_491521502171_item	2618463	et	2	main
sest	doc_491521502171_item	2618468	et	4	main
läheb	doc_491521502171_item	2618469	et	3	main
hoopis	doc_491521502171_item	2618470	et	3	main
teatrisse	doc_491521502171_item	2618471	et	3	main
6	doc_491521502171_item	2618472	et	2	main
jalutama	doc_491521502171_item	2618477	et	3	main
töötasid	doc_491521502171_item	2618489	et	4	main
pingsalt	doc_491521502171_item	2618491	et	4	main
aga	doc_491521502171_item	2618492	et	3	main
tulemust	doc_491521502171_item	2618493	et	4	main
ei	doc_491521502171_item	2618494	et	4	main
olnud	doc_491521502171_item	2618495	et	4	main
9	doc_491521502171_item	2618496	et	2	main
kas	doc_491521502171_item	2618497	et	3	main
sa	doc_491521502171_item	2618498	et	3	main
sõidad	doc_491521502171_item	2618499	et	3	main
maale	doc_491521502171_item	2618500	et	4	main
või	doc_491521502171_item	2618501	et	4	main
jääd	doc_491521502171_item	2618502	et	4	main
linna	doc_491521502171_item	2618503	et	4	main
10	doc_491521502171_item	2618504	et	2	main
avasin	doc_491521502171_item	2618505	et	3	main
ukse	doc_491521502171_item	2618506	et	3	main
kui	doc_491521502171_item	2618507	et	3	main
kuulsin	doc_491521502171_item	2618508	et	3	main
koputust	doc_491521502171_item	2618509	et	4	main
eesti	doc_491521502172_item	2618510	et	4	main
keele	doc_491521502172_item	2618511	et	4	main
test	doc_491521502172_item	2618512	et	3	main
eesti	doc_491521502172_item	2618513	et	4	main
keele	doc_491521502172_item	2618514	et	4	main
test	doc_491521502172_item	2618515	et	3	main
i	doc_491521502172_item	2618516	et	4	main
pange	doc_491521502172_item	2618517	et	4	main
sulgudes	doc_491521502172_item	2618518	et	4	main
olevad	doc_491521502172_item	2618519	et	4	main
sõnad	doc_491521502172_item	2618520	et	4	main
õigesse	doc_491521502172_item	2618521	et	3	main
piret	doc_491521502172_item	2618523	et	4	main
konkurss	doc_491521502172_item	2618546	et	3	main
ajalehes	doc_491521502172_item	2618532	et	3	main
külasse	doc_491521502172_item	2618539	et	3	main
otsitakse	doc_491521502172_item	2618540	et	3	main
eesti	doc_491521502172_item	2618541	et	4	main
on	doc_491521502172_item	2618549	et	4	main
väikestele	doc_491521502172_item	2618555	et	4	main
on	doc_491521502172_item	2618570	et	4	main
üllatuma	doc_491521502172_item	2618574	et	3	main
kui	doc_491521502172_item	2618576	et	3	main
mulle	doc_491521502172_item	2618577	et	4	main
tulema	doc_491521502172_item	2618578	et	4	main
tullakse	doc_491521502172_item	2618579	et	3	main
vastu	doc_491521502172_item	2618580	et	3	main
korralik	doc_491521502172_item	2618581	et	3	main
korraliku	doc_491521502172_item	2618582	et	3	main
audiga	doc_491521502172_item	2618583	et	3	main
ei	doc_491521502172_item	2618592	et	4	main
lenda	doc_491521502172_item	2618594	et	4	main
lind	doc_491521502172_item	2618595	et	3	main
ega	doc_491521502172_item	2618596	et	3	main
kasva	doc_491521502172_item	2618597	et	4	main
kohale	doc_491521502172_item	2618610	et	4	main
jõudis	doc_491521502172_item	2618611	et	3	main
polnud	doc_491521502172_item	2618612	et	3	main
kool	doc_491521502172_item	2618613	et	4	main
veel	doc_491521502172_item	2618614	et	4	main
algama	doc_491521502172_item	2618615	et	3	main
alanud	doc_491521502172_item	2618616	et	4	main
kogu	doc_491521502172_item	2618617	et	4	main
küla	doc_491521502172_item	2618618	et	4	main
võtma	doc_491521502172_item	2618619	et	3	main
võttis	doc_491521502172_item	2618620	et	3	main
tähtsam	doc_491521502172_item	2618628	et	4	main
õppimine	doc_491521502172_item	2618636	et	4	main
hooga	doc_491521502172_item	2618640	et	3	main
vene	doc_491521502172_item	2618653	et	4	main
aine	doc_491521502172_item	2618668	et	4	main
keeles	doc_491521502172_item	2618672	et	4	main
kõik	doc_491521502172_item	2618683	et	4	main
poolpõlenud	doc_491521502172_item	2618690	et	4	main
veel	doc_491521502172_item	2618712	et	4	main
üle	doc_491521502172_item	2618552	et	3	main
pireti	doc_491521502172_item	2618562	et	4	main
et	doc_491521502172_item	2618569	et	3	main
üsna	doc_491521502172_item	2618573	et	3	main
siber	doc_491521502172_item	2618586	et	4	main
pilt	doc_491521502172_item	2618589	et	3	main
et	doc_491521502172_item	2618590	et	3	main
tahtmise	doc_491521502172_item	2618603	et	4	main
pärast	doc_491521502172_item	2618606	et	4	main
algust	doc_491521502172_item	2618608	et	4	main
koht	doc_491521502172_item	2618609	et	3	main
on	doc_491521502172_item	2618623	et	4	main
sügisel	doc_491521502172_item	2618625	et	3	main
salv	doc_491521502172_item	2618633	et	3	main
salves	doc_491521502172_item	2618634	et	4	main
ja	doc_491521502172_item	2618635	et	3	main
eestlased	doc_491521502172_item	2618642	et	3	main
kuidagi	doc_491521502172_item	2618644	et	3	main
mahlakas	doc_491521502172_item	2618648	et	4	main
mahlakamalt	doc_491521502172_item	2618651	et	4	main
mitte	doc_491521502172_item	2618652	et	3	main
nagu	doc_491521502172_item	2618657	et	3	main
mõni	doc_491521502172_item	2618658	et	3	main
murret	doc_491521502172_item	2618660	et	4	main
ülejäänud	doc_491521502172_item	2618667	et	4	main
saab	doc_491521502172_item	2618682	et	3	main
pireti	doc_491521502172_item	2618686	et	4	main
õpivad	doc_491521502172_item	2618688	et	3	main
piret	doc_491521502172_item	2618701	et	4	main
soe	doc_491521502172_item	2618713	et	4	main
soojad	doc_491521502172_item	2618714	et	3	main
ahju	doc_491521502172_item	2618724	et	4	main
piret	doc_491521502172_item	2618743	et	4	main
vapralt	doc_491521502172_item	2618744	et	4	main
iii	doc_491521502172_item	2618748	et	4	main
laused	doc_491521502172_item	2618752	et	3	main
õigesse	doc_491521502172_item	2618755	et	3	main
mehed	doc_491521502172_item	2618766	et	3	main
naeratus	doc_491521502172_item	2618770	et	4	main
kaunimaks	doc_491521502172_item	2618778	et	4	main
3	doc_491521502172_item	2618779	et	2	main
paras	doc_491521502172_item	2618780	et	3	main
lisakoormus	doc_491521502172_item	2618787	et	3	main
tagajärg	doc_491521502172_item	2618791	et	3	main
kogus	doc_491521502172_item	2618793	et	4	main
paneb	doc_491521502172_item	2618795	et	3	main
tegutsema	doc_491521502172_item	2618797	et	3	main
aga	doc_491521502172_item	2618798	et	3	main
lisakoormus	doc_491521502172_item	2618799	et	3	main
võib	doc_491521502172_item	2618800	et	3	main
tuua	doc_491521502172_item	2618801	et	3	main
soovimatu	doc_491521502172_item	2618802	et	4	main
ülekoormus	doc_491521502172_item	2618808	et	3	main
maandama	doc_491521502172_item	2618812	et	3	main
ja	doc_491521502172_item	2618814	et	3	main
kartulivõtt	doc_491521502172_item	2618622	et	3	main
kõige	doc_491521502172_item	2618626	et	4	main
tähtis	doc_491521502172_item	2618627	et	4	main
hoog	doc_491521502172_item	2618639	et	3	main
räägivad	doc_491521502172_item	2618643	et	3	main
teistmoodi	doc_491521502172_item	2618645	et	3	main
ja	doc_491521502172_item	2618647	et	3	main
mõnusamalt	doc_491521502172_item	2618649	et	4	main
ja	doc_491521502172_item	2618650	et	3	main
vaid	doc_491521502172_item	2618656	et	3	main
kool	doc_491521502172_item	2618661	et	4	main
aineid	doc_491521502172_item	2618669	et	3	main
külas	doc_491521502172_item	2618673	et	3	main
elab	doc_491521502172_item	2618674	et	3	main
veidi	doc_491521502172_item	2618675	et	3	main
üle	doc_491521502172_item	2618676	et	3	main
kolmsada	doc_491521502172_item	2618677	et	4	main
õpikud	doc_491521502172_item	2618698	et	3	main
ei	doc_491521502172_item	2618702	et	4	main
mulle	doc_491521502172_item	2618705	et	4	main
tooma	doc_491521502172_item	2618707	et	3	main
kuid	doc_491521502172_item	2618715	et	4	main
ööd	doc_491521502172_item	2618716	et	4	main
juba	doc_491521502172_item	2618717	et	3	main
harjutan	doc_491521502172_item	2618720	et	3	main
juba	doc_491521502172_item	2618721	et	3	main
seal	doc_491521502172_item	2618734	et	4	main
suurt	doc_491521502172_item	2618735	et	3	main
muud	doc_491521502172_item	2618736	et	4	main
etteantud	doc_491521502172_item	2618750	et	4	main
naeratus	doc_491521502172_item	2618761	et	4	main
naiselikum	doc_491521502172_item	2618764	et	4	main
ja	doc_491521502172_item	2618765	et	3	main
kogus	doc_491521502172_item	2618781	et	4	main
võima	doc_491521502172_item	2618788	et	3	main
ei	doc_491521502172_item	2618805	et	4	main
tohtima	doc_491521502172_item	2618806	et	3	main
lasta	doc_491521502172_item	2618818	et	4	main
ülekoormust	doc_491521502172_item	2618819	et	4	main
tekitada	doc_491521502172_item	2618820	et	3	main
pinget	doc_491521502172_item	2618821	et	3	main
sportida	doc_491521502172_item	2618824	et	4	main
on	doc_491521502172_item	2618843	et	4	main
pühapäev	doc_491521502172_item	2618861	et	3	main
segama	doc_491521502172_item	2618864	et	3	main
kuid	doc_491521502172_item	2618874	et	4	main
telefonihelin	doc_491521502172_item	2618875	et	3	main
pühapäeva	doc_491521502172_item	2618878	et	4	main
varahommiku	doc_491521502172_item	2618879	et	3	main
und	doc_491521502172_item	2618880	et	4	main
segab	doc_491521502172_item	2618881	et	3	main
sõnad	doc_491521502172_item	2618895	et	4	main
aitavad	doc_491521502172_item	2618909	et	4	main
ma	doc_491521502172_item	2618922	et	3	main
huvi	doc_491521502172_item	2618931	et	4	main
ainult	doc_491521502172_item	2618932	et	4	main
ilusad	doc_491521502172_item	2618933	et	3	main
naised	doc_491521502172_item	2618934	et	3	main
ja	doc_491521502172_item	2618935	et	3	main
kiired	doc_491521502172_item	2618936	et	4	main
autod	doc_491521502172_item	2618937	et	3	main
autode	doc_491521502172_item	2618942	et	3	main
praegu	doc_491521502172_item	2618945	et	3	main
haigestuda	doc_491521502172_item	2618948	et	3	main
uuest	doc_491521502172_item	2618955	et	3	main
küsimus	doc_491521502172_item	2618969	et	4	main
kuulub	doc_491521502172_item	2618970	et	3	main
teine	doc_491521502172_item	2618971	et	3	main
püksid	doc_491521502172_item	2618978	et	3	main
lapsel	doc_491521502172_item	2619017	et	4	main
4	doc_491521502172_item	2619024	et	2	main
kõrvallauast	doc_491521502172_item	2619025	et	4	main
oleks	doc_491521502172_item	2619029	et	3	main
rääkinud	doc_491521502172_item	2619033	et	4	main
pärast	doc_491521502172_item	2619046	et	4	main
lähete	doc_491521502172_item	2619047	et	4	main
7	doc_491521502172_item	2619049	et	2	main
selles	doc_491521502172_item	2619050	et	4	main
baaris	doc_491521502172_item	2619051	et	3	main
nad	doc_491521502172_item	2619059	et	3	main
pingsalt	doc_491521502172_item	2619062	et	4	main
ei	doc_491521502172_item	2619065	et	4	main
ukse	doc_491521502172_item	2619077	et	3	main
olevad	doc_491521502173_item	2619090	et	4	main
toomet	doc_491521502173_item	2619095	et	4	main
suure	doc_491521502172_item	2618722	et	3	main
kütmist	doc_491521502172_item	2618726	et	4	main
vaja	doc_491521502172_item	2618728	et	4	main
ostan	doc_491521502172_item	2618729	et	3	main
ei	doc_491521502172_item	2618737	et	4	main
müüdagi	doc_491521502172_item	2618738	et	3	main
naerab	doc_491521502172_item	2618739	et	3	main
talveks	doc_491521502172_item	2618740	et	4	main
valmistuma	doc_491521502172_item	2618741	et	3	main
ajalehest	doc_491521502172_item	2618746	et	4	main
sõnadest	doc_491521502172_item	2618751	et	3	main
lühendatud	doc_491521502172_item	2618745	et	4	main
moodustage	doc_491521502172_item	2618749	et	3	main
tegema	doc_491521502172_item	2618762	et	3	main
igaüks	doc_491521502172_item	2618768	et	3	main
kaunim	doc_491521502172_item	2618769	et	4	main
teeb	doc_491521502172_item	2618771	et	3	main
naiselikumateks	doc_491521502172_item	2618773	et	4	main
ja	doc_491521502172_item	2618774	et	3	main
mehi	doc_491521502172_item	2618775	et	3	main
mehelikumateks	doc_491521502172_item	2618776	et	4	main
meie	doc_491521502172_item	2618784	et	4	main
tooma	doc_491521502172_item	2618789	et	3	main
soovimatu	doc_491521502172_item	2618790	et	4	main
paras	doc_491521502172_item	2618792	et	3	main
meid	doc_491521502172_item	2618796	et	4	main
tekkima	doc_491521502172_item	2618809	et	3	main
saab	doc_491521502172_item	2618822	et	3	main
puhata	doc_491521502172_item	2618826	et	4	main
saama	doc_491521502172_item	2618831	et	4	main
aparaat	doc_491521502172_item	2618834	et	3	main
see	doc_491521502172_item	2618836	et	3	main
telefon	doc_491521502172_item	2618842	et	3	main
selle	doc_491521502172_item	2618850	et	4	main
lausa	doc_491521502172_item	2618852	et	4	main
kuid	doc_491521502172_item	2618857	et	4	main
telefonihelin	doc_491521502172_item	2618858	et	3	main
katkestama	doc_491521502172_item	2618859	et	3	main
ka	doc_491521502172_item	2618860	et	3	main
varahommik	doc_491521502172_item	2618862	et	3	main
pahandab	doc_491521502172_item	2618869	et	3	main
telesaade	doc_491521502172_item	2618871	et	4	main
vaatamine	doc_491521502172_item	2618872	et	4	main
aeg	doc_491521502172_item	2618873	et	3	main
lõunasööki	doc_491521502172_item	2618882	et	4	main
pange	doc_491521502172_item	2618892	et	4	main
ma	doc_491521502172_item	2618899	et	3	main
sest	doc_491521502172_item	2618907	et	4	main
kõik	doc_491521502172_item	2618910	et	4	main
igaüks	doc_491521502172_item	2618914	et	3	main
2	doc_491521502172_item	2618916	et	2	main
artikli	doc_491521502172_item	2618918	et	3	main
nõudeid	doc_491521502172_item	2618920	et	3	main
sa	doc_491521502172_item	2618925	et	3	main
sport	doc_491521502172_item	2618927	et	3	main
kiirete	doc_491521502172_item	2618941	et	4	main
4	doc_491521502172_item	2618944	et	2	main
6	doc_491521502172_item	2618958	et	2	main
väikeste	doc_491521502172_item	2618965	et	4	main
muudatustega	doc_491521502172_item	2618966	et	3	main
7	doc_491521502172_item	2618967	et	2	main
see	doc_491521502172_item	2618968	et	3	main
närimiskumm	doc_491521502172_item	2618976	et	3	main
pükstes	doc_491521502172_item	2618979	et	3	main
ajal	doc_491521502172_item	2618982	et	4	main
ka	doc_491521502172_item	2619014	et	3	main
3	doc_491521502172_item	2619016	et	2	main
vanemad	doc_491521502172_item	2619021	et	4	main
naeru	doc_491521502172_item	2619027	et	4	main
anekdooti	doc_491521502172_item	2619032	et	4	main
suitsetada	doc_491521502172_item	2619054	et	3	main
ega	doc_491521502172_item	2619055	et	3	main
alkoholi	doc_491521502172_item	2619056	et	4	main
tarbida	doc_491521502172_item	2619057	et	3	main
kuid	doc_491521502172_item	2619063	et	4	main
tulemust	doc_491521502172_item	2619064	et	4	main
avasin	doc_491521502172_item	2619076	et	3	main
i	doc_491521502173_item	2619087	et	4	main
sulgudes	doc_491521502173_item	2619089	et	4	main
vormi	doc_491521502173_item	2619093	et	4	main
ettevõtlik	doc_491521502173_item	2619097	et	3	main
emakeelt	doc_491521502173_item	2619130	et	4	main
õpetama	doc_491521502173_item	2619131	et	3	main
õpetamas	doc_491521502173_item	2619132	et	3	main
pireti	doc_491521502173_item	2619133	et	4	main
kinnitusel	doc_491521502173_item	2619134	et	4	main
tundis	doc_491521502173_item	2619135	et	3	main
jõudes	doc_491521502173_item	2619139	et	3	main
oodatud	doc_491521502173_item	2619142	et	4	main
üllatuma	doc_491521502173_item	2619145	et	3	main
kui	doc_491521502173_item	2619147	et	3	main
mulle	doc_491521502173_item	2619148	et	4	main
pannes	doc_491521502172_item	2618753	et	4	main
naised	doc_491521502172_item	2618763	et	3	main
igaühe	doc_491521502172_item	2618777	et	4	main
aga	doc_491521502172_item	2618786	et	3	main
tagajärgi	doc_491521502172_item	2618803	et	4	main
4	doc_491521502172_item	2618804	et	2	main
pinge	doc_491521502172_item	2618810	et	4	main
saama	doc_491521502172_item	2618811	et	4	main
puhkama	doc_491521502172_item	2618815	et	3	main
maandada	doc_491521502172_item	2618823	et	3	main
5	doc_491521502172_item	2618827	et	2	main
olema	doc_491521502172_item	2618829	et	4	main
maagiline	doc_491521502172_item	2618833	et	4	main
et	doc_491521502172_item	2618835	et	3	main
elama	doc_491521502172_item	2618839	et	3	main
hingama	doc_491521502172_item	2618841	et	3	main
saanud	doc_491521502172_item	2618845	et	4	main
elatakse	doc_491521502172_item	2618853	et	3	main
ja	doc_491521502172_item	2618854	et	3	main
hingatakse	doc_491521502172_item	2618855	et	3	main
6	doc_491521502172_item	2618856	et	2	main
valmistamine	doc_491521502172_item	2618866	et	4	main
ja	doc_491521502172_item	2618867	et	3	main
huvitav	doc_491521502172_item	2618870	et	4	main
ja	doc_491521502172_item	2618884	et	3	main
söömist	doc_491521502172_item	2618885	et	4	main
aega	doc_491521502172_item	2618890	et	4	main
iv	doc_491521502172_item	2618891	et	4	main
õigesse	doc_491521502172_item	2618896	et	3	main
vormi	doc_491521502172_item	2618897	et	4	main
1	doc_491521502172_item	2618898	et	2	main
lugu	doc_491521502172_item	2618902	et	4	main
vanemad	doc_491521502172_item	2618904	et	4	main
oma	doc_491521502172_item	2618905	et	4	main
vanemaid	doc_491521502172_item	2618906	et	4	main
kõiki	doc_491521502172_item	2618911	et	4	main
nõuded	doc_491521502172_item	2618919	et	3	main
et	doc_491521502172_item	2618924	et	3	main
huvitud	doc_491521502172_item	2618926	et	4	main
aga	doc_491521502172_item	2618928	et	3	main
naiste	doc_491521502172_item	2618939	et	3	main
oht	doc_491521502172_item	2618947	et	3	main
difteeria	doc_491521502172_item	2618949	et	4	main
difteeriasse	doc_491521502172_item	2618950	et	3	main
tüdinesin	doc_491521502172_item	2618952	et	3	main
töökohast	doc_491521502172_item	2618956	et	4	main
selles	doc_491521502172_item	2618960	et	4	main
teise	doc_491521502172_item	2618973	et	4	main
valdkonda	doc_491521502172_item	2618974	et	4	main
kostis	doc_491521502172_item	2619026	et	4	main
just	doc_491521502172_item	2619031	et	3	main
töö	doc_491521502172_item	2619045	et	4	main
tohi	doc_491521502172_item	2619053	et	4	main
töötasid	doc_491521502172_item	2619060	et	4	main
olnud	doc_491521502172_item	2619066	et	4	main
sõidad	doc_491521502172_item	2619070	et	3	main
või	doc_491521502172_item	2619072	et	4	main
jääd	doc_491521502172_item	2619073	et	4	main
eesti	doc_491521502173_item	2619084	et	4	main
keele	doc_491521502173_item	2619085	et	4	main
test	doc_491521502173_item	2619086	et	3	main
õigesse	doc_491521502173_item	2619092	et	3	main
on	doc_491521502173_item	2619096	et	4	main
juba	doc_491521502173_item	2619122	et	3	main
nädala	doc_491521502173_item	2619125	et	3	main
eestlastele	doc_491521502173_item	2619127	et	4	main
nende	doc_491521502173_item	2619129	et	4	main
et	doc_491521502173_item	2619140	et	3	main
on	doc_491521502173_item	2619141	et	4	main
olin	doc_491521502173_item	2619143	et	3	main
üsna	doc_491521502173_item	2619144	et	3	main
mulle	doc_491521502173_item	2619155	et	4	main
selline	doc_491521502173_item	2619159	et	4	main
rohi	doc_491521502173_item	2619169	et	4	main
kui	doc_491521502173_item	2619170	et	3	main
noor	doc_491521502173_item	2619171	et	3	main
ja	doc_491521502173_item	2619172	et	3	main
tahtmine	doc_491521502173_item	2619173	et	4	main
piret	doc_491521502173_item	2619176	et	4	main
võtma	doc_491521502173_item	2619190	et	3	main
võttis	doc_491521502173_item	2619191	et	3	main
siin	doc_491521502173_item	2619195	et	4	main
ja	doc_491521502172_item	2618825	et	3	main
telefon	doc_491521502172_item	2618828	et	3	main
tänapäev	doc_491521502172_item	2618830	et	3	main
lausa	doc_491521502172_item	2618838	et	4	main
ja	doc_491521502172_item	2618840	et	3	main
nii	doc_491521502172_item	2618846	et	3	main
aparaadiks	doc_491521502172_item	2618848	et	3	main
et	doc_491521502172_item	2618849	et	3	main
nii	doc_491521502172_item	2618832	et	3	main
abil	doc_491521502172_item	2618837	et	4	main
tänapäeval	doc_491521502172_item	2618844	et	3	main
maagiliseks	doc_491521502172_item	2618847	et	4	main
abil	doc_491521502172_item	2618851	et	4	main
lõunasöök	doc_491521502172_item	2618865	et	3	main
katkestab	doc_491521502172_item	2618876	et	3	main
ka	doc_491521502172_item	2618877	et	3	main
valmistamist	doc_491521502172_item	2618883	et	4	main
pahandab	doc_491521502172_item	2618886	et	3	main
huvitava	doc_491521502172_item	2618887	et	4	main
telesaade	doc_491521502172_item	2618888	et	4	main
sulgudes	doc_491521502172_item	2618893	et	4	main
pean	doc_491521502172_item	2618900	et	4	main
ja	doc_491521502172_item	2618912	et	3	main
usaldavad	doc_491521502172_item	2618913	et	4	main
igaüht	doc_491521502172_item	2618915	et	3	main
kohandasin	doc_491521502172_item	2618917	et	3	main
3	doc_491521502172_item	2618921	et	2	main
uni	doc_491521502172_item	2618863	et	3	main
söömine	doc_491521502172_item	2618868	et	4	main
vaatamise	doc_491521502172_item	2618889	et	4	main
olevad	doc_491521502172_item	2618894	et	4	main
väga	doc_491521502172_item	2618901	et	3	main
oma	doc_491521502172_item	2618903	et	4	main
nad	doc_491521502172_item	2618908	et	3	main
sa	doc_491521502172_item	2618929	et	3	main
tunned	doc_491521502172_item	2618930	et	3	main
ja	doc_491521502172_item	2618940	et	3	main
vastu	doc_491521502172_item	2618943	et	3	main
kiiresti	doc_491521502172_item	2618957	et	3	main
valdkond	doc_491521502172_item	2618972	et	3	main
kleepus	doc_491521502172_item	2618977	et	3	main
9	doc_491521502172_item	2618980	et	2	main
keegi	doc_491521502172_item	2619030	et	4	main
ta	doc_491521502172_item	2619035	et	4	main
ei	doc_491521502172_item	2619036	et	4	main
jalutama	doc_491521502172_item	2619048	et	3	main
8	doc_491521502172_item	2619058	et	2	main
9	doc_491521502172_item	2619067	et	2	main
kas	doc_491521502172_item	2619068	et	3	main
sa	doc_491521502172_item	2619069	et	3	main
maale	doc_491521502172_item	2619071	et	4	main
10	doc_491521502172_item	2619075	et	2	main
kuulsin	doc_491521502172_item	2619079	et	3	main
sõnad	doc_491521502173_item	2619091	et	4	main
nüüd	doc_491521502173_item	2619121	et	4	main
nädal	doc_491521502173_item	2619124	et	3	main
väikestele	doc_491521502173_item	2619126	et	4	main
need	doc_491521502173_item	2619128	et	3	main
ta	doc_491521502173_item	2619136	et	4	main
tulema	doc_491521502173_item	2619149	et	4	main
tuldi	doc_491521502173_item	2619150	et	3	main
vastu	doc_491521502173_item	2619151	et	3	main
korralik	doc_491521502173_item	2619152	et	3	main
korraliku	doc_491521502173_item	2619153	et	3	main
siber	doc_491521502173_item	2619157	et	4	main
ega	doc_491521502173_item	2619167	et	3	main
kasva	doc_491521502173_item	2619168	et	4	main
algust	doc_491521502173_item	2619179	et	4	main
koht	doc_491521502173_item	2619180	et	3	main
kogu	doc_491521502173_item	2619188	et	4	main
on	doc_491521502173_item	2619194	et	4	main
sügisel	doc_491521502173_item	2619196	et	3	main
tähtis	doc_491521502173_item	2619198	et	4	main
tähtsam	doc_491521502173_item	2619199	et	4	main
ettevõtmine	doc_491521502173_item	2619200	et	3	main
hoog	doc_491521502173_item	2619210	et	3	main
räägivad	doc_491521502173_item	2619214	et	3	main
teistmoodi	doc_491521502173_item	2619216	et	3	main
ja	doc_491521502173_item	2619221	et	3	main
nagu	doc_491521502173_item	2619228	et	3	main
murret	doc_491521502173_item	2619231	et	4	main
on	doc_491521502173_item	2619233	et	4	main
aine	doc_491521502173_item	2619239	et	4	main
ained	doc_491521502173_item	2619240	et	3	main
inimene	doc_491521502173_item	2619250	et	3	main
inimest	doc_491521502173_item	2619251	et	3	main
talvepuud	doc_491521502173_item	2619280	et	4	main
praegu	doc_491521502173_item	2619281	et	3	main
soe	doc_491521502173_item	2619285	et	4	main
laused	doc_491521502173_item	2619324	et	3	main
mehelikum	doc_491521502173_item	2619339	et	4	main
naeratus	doc_491521502173_item	2619342	et	4	main
aga	doc_491521502173_item	2619358	et	3	main
tagajärg	doc_491521502173_item	2619363	et	3	main
tegutsema	doc_491521502173_item	2619369	et	3	main
aga	doc_491521502173_item	2619370	et	3	main
lisakoormus	doc_491521502173_item	2619371	et	3	main
soovimatuid	doc_491521502173_item	2619374	et	4	main
telefon	doc_491521502173_item	2619416	et	3	main
tänapäeval	doc_491521502173_item	2619418	et	3	main
nii	doc_491521502173_item	2619420	et	3	main
maagiliseks	doc_491521502173_item	2619421	et	4	main
katkestama	doc_491521502173_item	2619433	et	3	main
segama	doc_491521502173_item	2619438	et	3	main
kuid	doc_491521502173_item	2619448	et	4	main
telefonihelin	doc_491521502173_item	2619449	et	3	main
katkestab	doc_491521502173_item	2619450	et	3	main
ka	doc_491521502173_item	2619451	et	3	main
pühapäeva	doc_491521502173_item	2619452	et	4	main
arvasin	doc_491521502172_item	2618923	et	3	main
ilusate	doc_491521502172_item	2618938	et	3	main
on	doc_491521502172_item	2618946	et	4	main
5	doc_491521502172_item	2618951	et	2	main
uus	doc_491521502172_item	2618953	et	3	main
töökoht	doc_491521502172_item	2618954	et	3	main
piirdusime	doc_491521502172_item	2618959	et	3	main
küsimuses	doc_491521502172_item	2618961	et	4	main
vaid	doc_491521502172_item	2618962	et	3	main
väikesed	doc_491521502172_item	2618963	et	4	main
muudatused	doc_491521502172_item	2618964	et	3	main
8	doc_491521502172_item	2618975	et	2	main
külmal	doc_491521502172_item	2618981	et	3	main
peab	doc_491521502172_item	2618983	et	4	main
hoiduma	doc_491521502172_item	2618984	et	3	main
külmetamine	doc_491521502172_item	2618985	et	4	main
külmetamisest	doc_491521502172_item	2618986	et	4	main
10	doc_491521502172_item	2618987	et	2	main
ma	doc_491521502172_item	2618988	et	3	main
tunnen	doc_491521502172_item	2618989	et	3	main
rõõmu	doc_491521502172_item	2618990	et	4	main
suvine	doc_491521502172_item	2618991	et	4	main
päike	doc_491521502172_item	2618992	et	3	main
suvisest	doc_491521502172_item	2618993	et	4	main
päikesest	doc_491521502172_item	2618994	et	4	main
v	doc_491521502172_item	2618995	et	4	main
täitke	doc_491521502172_item	2618996	et	3	main
lüngad	doc_491521502172_item	2618997	et	3	main
sobivate	doc_491521502172_item	2618998	et	4	main
sidenditega	doc_491521502172_item	2618999	et	3	main
1	doc_491521502172_item	2619000	et	2	main
tellisime	doc_491521502172_item	2619001	et	4	main
kolmekäigulise	doc_491521502172_item	2619002	et	4	main
lõuna	doc_491521502172_item	2619003	et	4	main
sest	doc_491521502172_item	2619004	et	4	main
see	doc_491521502172_item	2619005	et	3	main
palju	doc_491521502172_item	2619007	et	4	main
2	doc_491521502172_item	2619008	et	2	main
kohal	doc_491521502172_item	2619009	et	4	main
maksis	doc_491521502172_item	2619006	et	4	main
olid	doc_491521502172_item	2619010	et	4	main
nii	doc_491521502172_item	2619011	et	3	main
õpilased	doc_491521502172_item	2619012	et	3	main
kui	doc_491521502172_item	2619013	et	3	main
õpetajad	doc_491521502172_item	2619015	et	4	main
paluti	doc_491521502172_item	2619018	et	3	main
oodata	doc_491521502172_item	2619019	et	4	main
kui	doc_491521502172_item	2619020	et	3	main
tagasi	doc_491521502172_item	2619022	et	3	main
tulevad	doc_491521502172_item	2619023	et	4	main
nagu	doc_491521502172_item	2619028	et	3	main
5	doc_491521502172_item	2619034	et	2	main
tule	doc_491521502172_item	2619037	et	4	main
trenni	doc_491521502172_item	2619038	et	4	main
sest	doc_491521502172_item	2619039	et	4	main
läheb	doc_491521502172_item	2619040	et	3	main
hoopis	doc_491521502172_item	2619041	et	3	main
teatrisse	doc_491521502172_item	2619042	et	3	main
6	doc_491521502172_item	2619043	et	2	main
lõpetage	doc_491521502172_item	2619044	et	3	main
ei	doc_491521502172_item	2619052	et	4	main
küll	doc_491521502172_item	2619061	et	4	main
linna	doc_491521502172_item	2619074	et	4	main
sest	doc_491521502172_item	2619078	et	4	main
koputust	doc_491521502172_item	2619080	et	4	main
eesti	doc_491521502173_item	2619081	et	4	main
keele	doc_491521502173_item	2619082	et	4	main
test	doc_491521502173_item	2619083	et	3	main
pange	doc_491521502173_item	2619088	et	4	main
piret	doc_491521502173_item	2619094	et	4	main
naine	doc_491521502173_item	2619098	et	3	main
suvel	doc_491521502173_item	2619099	et	3	main
nägema	doc_491521502173_item	2619100	et	3	main
nägi	doc_491521502173_item	2619101	et	3	main
ta	doc_491521502173_item	2619102	et	4	main
ajalehes	doc_491521502173_item	2619103	et	3	main
kuulutus	doc_491521502173_item	2619104	et	4	main
kuulutust	doc_491521502173_item	2619105	et	4	main
et	doc_491521502173_item	2619106	et	3	main
siberisse	doc_491521502173_item	2619107	et	4	main
ülem-suetuki	doc_491521502173_item	2619108	et	4	main
küla	doc_491521502173_item	2619109	et	4	main
külasse	doc_491521502173_item	2619110	et	3	main
otsitakse	doc_491521502173_item	2619111	et	3	main
eesti	doc_491521502173_item	2619112	et	4	main
keele	doc_491521502173_item	2619113	et	4	main
õpetajat	doc_491521502173_item	2619114	et	4	main
piret	doc_491521502173_item	2619115	et	4	main
võitis	doc_491521502173_item	2619116	et	3	main
konkurss	doc_491521502173_item	2619117	et	3	main
konkursi	doc_491521502173_item	2619118	et	3	main
ja	doc_491521502173_item	2619119	et	3	main
on	doc_491521502173_item	2619120	et	4	main
siberisse	doc_491521502173_item	2619137	et	4	main
üllatunud	doc_491521502173_item	2619146	et	4	main
maaliti	doc_491521502173_item	2619156	et	3	main
pilt	doc_491521502173_item	2619160	et	3	main
et	doc_491521502173_item	2619161	et	3	main
täis	doc_491521502173_item	2619175	et	4	main
kool	doc_491521502173_item	2619184	et	4	main
veel	doc_491521502173_item	2619185	et	4	main
kartulivõtt	doc_491521502173_item	2619193	et	3	main
kõige	doc_491521502173_item	2619197	et	4	main
salv	doc_491521502173_item	2619204	et	3	main
siinsed	doc_491521502173_item	2619212	et	3	main
kuidagi	doc_491521502173_item	2619215	et	3	main
mõnus	doc_491521502173_item	2619217	et	4	main
ja	doc_491521502173_item	2619218	et	3	main
mahlakas	doc_491521502173_item	2619219	et	4	main
mõnusalt	doc_491521502173_item	2619220	et	4	main
vene	doc_491521502173_item	2619224	et	4	main
aktsendiga	doc_491521502173_item	2619226	et	3	main
mõni	doc_491521502173_item	2619229	et	3	main
kool	doc_491521502173_item	2619232	et	4	main
vene	doc_491521502173_item	2619242	et	4	main
elab	doc_491521502173_item	2619245	et	3	main
üle	doc_491521502173_item	2619247	et	3	main
kolmsada	doc_491521502173_item	2619248	et	4	main
rääkida	doc_491521502173_item	2619256	et	3	main
õpivad	doc_491521502173_item	2619259	et	3	main
raamatutest	doc_491521502173_item	2619263	et	4	main
eestist	doc_491521502173_item	2619267	et	3	main
õpikud	doc_491521502173_item	2619269	et	3	main
talve	doc_491521502173_item	2619271	et	4	main
on	doc_491521502173_item	2619282	et	4	main
päevad	doc_491521502173_item	2619283	et	3	main
soojad	doc_491521502173_item	2619286	et	3	main
kirjavahemärke	doc_491521502173_item	2619331	et	4	main
2	doc_491521502173_item	2619332	et	2	main
igaüks	doc_491521502173_item	2619340	et	3	main
igaühe	doc_491521502173_item	2619349	et	4	main
kaunimaks	doc_491521502173_item	2619350	et	4	main
3	doc_491521502173_item	2619351	et	2	main
paras	doc_491521502173_item	2619352	et	3	main
tegutsema	doc_491521502173_item	2619357	et	3	main
võima	doc_491521502173_item	2619360	et	3	main
tagajärgi	doc_491521502173_item	2619375	et	4	main
tohtima	doc_491521502173_item	2619380	et	3	main
selle	doc_491521502173_item	2619424	et	4	main
pühapäev	doc_491521502173_item	2619435	et	3	main
uni	doc_491521502173_item	2619437	et	3	main
vaatamine	doc_491521502173_item	2619446	et	4	main
segab	doc_491521502173_item	2619455	et	3	main
ja	doc_491521502173_item	2619458	et	3	main
pahandab	doc_491521502173_item	2619460	et	3	main
vaatamise	doc_491521502173_item	2619463	et	4	main
sulgudes	doc_491521502173_item	2619467	et	4	main
olevad	doc_491521502173_item	2619468	et	4	main
oma	doc_491521502173_item	2619477	et	4	main
vanemad	doc_491521502173_item	2619478	et	4	main
praegu	doc_491521502173_item	2619520	et	3	main
haigestuda	doc_491521502173_item	2619523	et	3	main
difteeria	doc_491521502173_item	2619524	et	4	main
uus	doc_491521502173_item	2619528	et	3	main
töökoht	doc_491521502173_item	2619529	et	3	main
uuest	doc_491521502173_item	2619530	et	3	main
6	doc_491521502173_item	2619533	et	2	main
vaid	doc_491521502173_item	2619537	et	3	main
väikeste	doc_491521502173_item	2619540	et	4	main
9	doc_491521502173_item	2619555	et	2	main
suvise	doc_491521502173_item	2619568	et	4	main
päikese	doc_491521502173_item	2619569	et	4	main
üle	doc_491521502173_item	2619570	et	3	main
sobivate	doc_491521502173_item	2619574	et	4	main
kohal	doc_491521502173_item	2619585	et	4	main
baaris	doc_491521502173_item	2619627	et	3	main
tohi	doc_491521502173_item	2619629	et	4	main
tarbida	doc_491521502173_item	2619633	et	3	main
küll	doc_491521502173_item	2619637	et	4	main
ei	doc_491521502173_item	2619641	et	4	main
üle	doc_491521502173_item	2619123	et	3	main
jõudma	doc_491521502173_item	2619138	et	3	main
audiga	doc_491521502173_item	2619154	et	3	main
siberist	doc_491521502173_item	2619158	et	4	main
seal	doc_491521502173_item	2619162	et	4	main
ei	doc_491521502173_item	2619163	et	4	main
lendama	doc_491521502173_item	2619164	et	3	main
kohale	doc_491521502173_item	2619181	et	4	main
jõudis	doc_491521502173_item	2619182	et	3	main
polnud	doc_491521502173_item	2619183	et	3	main
küla	doc_491521502173_item	2619189	et	4	main
kartuleid	doc_491521502173_item	2619192	et	3	main
on	doc_491521502173_item	2619202	et	4	main
kartul	doc_491521502173_item	2619203	et	3	main
hooguga	doc_491521502173_item	2619211	et	4	main
eestlased	doc_491521502173_item	2619213	et	3	main
lenda	doc_491521502173_item	2619165	et	4	main
lind	doc_491521502173_item	2619166	et	3	main
tahtmist	doc_491521502173_item	2619174	et	4	main
pärast	doc_491521502173_item	2619177	et	4	main
õppeaasta	doc_491521502173_item	2619178	et	4	main
algama	doc_491521502173_item	2619186	et	3	main
alanud	doc_491521502173_item	2619187	et	4	main
tänaseks	doc_491521502173_item	2619201	et	4	main
aktsent	doc_491521502173_item	2619225	et	3	main
õpetatakse	doc_491521502173_item	2619241	et	3	main
kolmesaja	doc_491521502173_item	2619249	et	4	main
emakeelt	doc_491521502173_item	2619252	et	4	main
saab	doc_491521502173_item	2619253	et	3	main
pireti	doc_491521502173_item	2619257	et	4	main
poolpõlenud	doc_491521502173_item	2619261	et	4	main
kartma	doc_491521502173_item	2619274	et	3	main
juba	doc_491521502173_item	2619277	et	3	main
toodi	doc_491521502173_item	2619279	et	4	main
ajalehest	doc_491521502173_item	2619318	et	4	main
slõhtuleht	doc_491521502173_item	2619319	et	4	main
salves	doc_491521502173_item	2619205	et	4	main
ja	doc_491521502173_item	2619206	et	3	main
õppimine	doc_491521502173_item	2619207	et	4	main
käib	doc_491521502173_item	2619208	et	3	main
täie	doc_491521502173_item	2619209	et	3	main
mitte	doc_491521502173_item	2619223	et	3	main
vaid	doc_491521502173_item	2619227	et	3	main
siiski	doc_491521502173_item	2619234	et	4	main
venemaa	doc_491521502173_item	2619235	et	4	main
keeles	doc_491521502173_item	2619243	et	4	main
veidi	doc_491521502173_item	2619246	et	3	main
kõik	doc_491521502173_item	2619254	et	4	main
raamatud	doc_491521502173_item	2619262	et	4	main
saadetakse	doc_491521502173_item	2619266	et	3	main
karda	doc_491521502173_item	2619275	et	4	main
veel	doc_491521502173_item	2619284	et	4	main
sõnadest	doc_491521502173_item	2619323	et	3	main
pannes	doc_491521502173_item	2619325	et	4	main
õigesse	doc_491521502173_item	2619327	et	3	main
vormi	doc_491521502173_item	2619328	et	4	main
ja	doc_491521502173_item	2619329	et	3	main
kasutades	doc_491521502173_item	2619330	et	3	main
mehed	doc_491521502173_item	2619338	et	3	main
kaunim	doc_491521502173_item	2619341	et	4	main
teeb	doc_491521502173_item	2619343	et	3	main
naisi	doc_491521502173_item	2619344	et	3	main
naiselikumaks	doc_491521502173_item	2619345	et	4	main
ja	doc_491521502173_item	2619346	et	3	main
mehi	doc_491521502173_item	2619347	et	3	main
mehelikumaks	doc_491521502173_item	2619348	et	4	main
panema	doc_491521502173_item	2619355	et	3	main
lisakoormus	doc_491521502173_item	2619359	et	3	main
paras	doc_491521502173_item	2619364	et	3	main
4	doc_491521502173_item	2619378	et	2	main
hingama	doc_491521502173_item	2619415	et	3	main
on	doc_491521502173_item	2619417	et	4	main
saanud	doc_491521502173_item	2619419	et	4	main
telesaade	doc_491521502173_item	2619445	et	4	main
und	doc_491521502173_item	2619454	et	4	main
huvitava	doc_491521502173_item	2619461	et	4	main
telesaate	doc_491521502173_item	2619462	et	3	main
ma	doc_491521502173_item	2619473	et	3	main
vanematest	doc_491521502173_item	2619480	et	4	main
usaldavad	doc_491521502173_item	2619487	et	4	main
autode	doc_491521502173_item	2619517	et	3	main
4	doc_491521502173_item	2619519	et	2	main
selles	doc_491521502173_item	2619535	et	4	main
küsimus	doc_491521502173_item	2619544	et	4	main
valdkond	doc_491521502173_item	2619547	et	3	main
külmal	doc_491521502173_item	2619556	et	3	main
peab	doc_491521502173_item	2619558	et	4	main
külmetamist	doc_491521502173_item	2619561	et	4	main
10	doc_491521502173_item	2619562	et	2	main
ma	doc_491521502173_item	2619563	et	3	main
tunnen	doc_491521502173_item	2619564	et	3	main
see	doc_491521502173_item	2619581	et	3	main
2	doc_491521502173_item	2619584	et	2	main
töö	doc_491521502173_item	2619621	et	4	main
lähete	doc_491521502173_item	2619623	et	4	main
jalutama	doc_491521502173_item	2619624	et	3	main
ei	doc_491521502173_item	2619628	et	4	main
alkoholi	doc_491521502173_item	2619632	et	4	main
nad	doc_491521502173_item	2619635	et	3	main
jääd	doc_491521502173_item	2619649	et	4	main
linna	doc_491521502173_item	2619650	et	4	main
10	doc_491521502173_item	2619651	et	2	main
avasin	doc_491521502173_item	2619652	et	3	main
eesti	doc_491521502174_item	2619657	et	4	main
sulgudes	doc_491521502174_item	2619665	et	4	main
toomet	doc_491521502174_item	2619671	et	4	main
nägema	doc_491521502174_item	2619676	et	3	main
kuulutus	doc_491521502174_item	2619680	et	4	main
kuulutust	doc_491521502174_item	2619681	et	4	main
korralik	doc_491521502174_item	2619728	et	3	main
korraliku	doc_491521502174_item	2619729	et	3	main
mulle	doc_491521502174_item	2619731	et	4	main
pilt	doc_491521502174_item	2619736	et	3	main
et	doc_491521502174_item	2619737	et	3	main
ei	doc_491521502174_item	2619739	et	4	main
kui	doc_491521502174_item	2619746	et	3	main
ja	doc_491521502174_item	2619748	et	3	main
tahtmist	doc_491521502174_item	2619750	et	4	main
mahlakalt	doc_491521502173_item	2619222	et	4	main
mõnda	doc_491521502173_item	2619230	et	4	main
kool	doc_491521502173_item	2619236	et	4	main
ja	doc_491521502173_item	2619237	et	3	main
ülejäänud	doc_491521502173_item	2619238	et	4	main
külas	doc_491521502173_item	2619244	et	3	main
kõigega	doc_491521502173_item	2619255	et	3	main
sõnul	doc_491521502173_item	2619258	et	3	main
lapsed	doc_491521502173_item	2619260	et	3	main
varsti	doc_491521502173_item	2619264	et	3	main
saatma	doc_491521502173_item	2619265	et	3	main
uued	doc_491521502173_item	2619268	et	3	main
siberi	doc_491521502173_item	2619270	et	4	main
piret	doc_491521502173_item	2619272	et	4	main
ei	doc_491521502173_item	2619273	et	4	main
mulle	doc_491521502173_item	2619276	et	4	main
tooma	doc_491521502173_item	2619278	et	3	main
kuid	doc_491521502173_item	2619287	et	4	main
ööd	doc_491521502173_item	2619288	et	4	main
juba	doc_491521502173_item	2619289	et	3	main
jahe	doc_491521502173_item	2619290	et	3	main
jahedad	doc_491521502173_item	2619291	et	3	main
harjutan	doc_491521502173_item	2619292	et	3	main
juba	doc_491521502173_item	2619293	et	3	main
suure	doc_491521502173_item	2619294	et	3	main
vene	doc_491521502173_item	2619295	et	4	main
ahju	doc_491521502173_item	2619296	et	4	main
kütmine	doc_491521502173_item	2619297	et	4	main
kütmist	doc_491521502173_item	2619298	et	4	main
kui	doc_491521502173_item	2619299	et	3	main
vaja	doc_491521502173_item	2619300	et	4	main
ostan	doc_491521502173_item	2619301	et	3	main
külapood	doc_491521502173_item	2619302	et	3	main
külapoest	doc_491521502173_item	2619303	et	4	main
vildid	doc_491521502173_item	2619304	et	4	main
ega	doc_491521502173_item	2619305	et	3	main
seal	doc_491521502173_item	2619306	et	4	main
suurt	doc_491521502173_item	2619307	et	3	main
muud	doc_491521502173_item	2619308	et	4	main
ei	doc_491521502173_item	2619309	et	4	main
müüdagi	doc_491521502173_item	2619310	et	3	main
naerab	doc_491521502173_item	2619311	et	3	main
talveks	doc_491521502173_item	2619312	et	4	main
valmistuma	doc_491521502173_item	2619313	et	3	main
piret	doc_491521502173_item	2619315	et	4	main
vapralt	doc_491521502173_item	2619316	et	4	main
valmistuv	doc_491521502173_item	2619314	et	4	main
lühendatud	doc_491521502173_item	2619317	et	4	main
iii	doc_491521502173_item	2619320	et	4	main
moodustage	doc_491521502173_item	2619321	et	3	main
naeratus	doc_491521502173_item	2619333	et	4	main
tegema	doc_491521502173_item	2619334	et	3	main
naised	doc_491521502173_item	2619335	et	3	main
naiselikum	doc_491521502173_item	2619336	et	4	main
meie	doc_491521502173_item	2619356	et	4	main
soovimatu	doc_491521502173_item	2619362	et	4	main
stressi	doc_491521502173_item	2619366	et	4	main
paneb	doc_491521502173_item	2619367	et	3	main
tuua	doc_491521502173_item	2619373	et	3	main
tagajärje	doc_491521502173_item	2619377	et	3	main
ei	doc_491521502173_item	2619379	et	4	main
laskma	doc_491521502173_item	2619381	et	3	main
etteantud	doc_491521502173_item	2619322	et	4	main
sõnad	doc_491521502173_item	2619326	et	4	main
ja	doc_491521502173_item	2619337	et	3	main
kogus	doc_491521502173_item	2619353	et	4	main
stress	doc_491521502173_item	2619354	et	3	main
tooma	doc_491521502173_item	2619361	et	3	main
kogus	doc_491521502173_item	2619365	et	4	main
meid	doc_491521502173_item	2619368	et	4	main
võib	doc_491521502173_item	2619372	et	3	main
soovimatu	doc_491521502173_item	2619376	et	4	main
ülekoormus	doc_491521502173_item	2619382	et	3	main
tekkima	doc_491521502173_item	2619383	et	3	main
pinge	doc_491521502173_item	2619384	et	4	main
saama	doc_491521502173_item	2619385	et	4	main
maandama	doc_491521502173_item	2619386	et	3	main
sportima	doc_491521502173_item	2619387	et	4	main
ja	doc_491521502173_item	2619388	et	3	main
puhkama	doc_491521502173_item	2619389	et	3	main
ei	doc_491521502173_item	2619390	et	4	main
tohi	doc_491521502173_item	2619391	et	4	main
lasta	doc_491521502173_item	2619392	et	4	main
ülekoormuse	doc_491521502173_item	2619393	et	3	main
tekkimist	doc_491521502173_item	2619394	et	4	main
pinget	doc_491521502173_item	2619395	et	3	main
saab	doc_491521502173_item	2619396	et	3	main
maandada	doc_491521502173_item	2619397	et	3	main
sportides	doc_491521502173_item	2619398	et	4	main
ja	doc_491521502173_item	2619399	et	3	main
puhates	doc_491521502173_item	2619400	et	3	main
5	doc_491521502173_item	2619401	et	2	main
telefon	doc_491521502173_item	2619402	et	3	main
tänapäev	doc_491521502173_item	2619404	et	3	main
saama	doc_491521502173_item	2619405	et	4	main
nii	doc_491521502173_item	2619406	et	3	main
olema	doc_491521502173_item	2619403	et	4	main
maagiline	doc_491521502173_item	2619407	et	4	main
aparaat	doc_491521502173_item	2619408	et	3	main
et	doc_491521502173_item	2619409	et	3	main
see	doc_491521502173_item	2619410	et	3	main
abil	doc_491521502173_item	2619411	et	4	main
lausa	doc_491521502173_item	2619412	et	4	main
elama	doc_491521502173_item	2619413	et	3	main
ja	doc_491521502173_item	2619414	et	3	main
aparaadiks	doc_491521502173_item	2619422	et	3	main
et	doc_491521502173_item	2619423	et	3	main
abil	doc_491521502173_item	2619425	et	4	main
lausa	doc_491521502173_item	2619426	et	4	main
elatakse	doc_491521502173_item	2619427	et	3	main
ja	doc_491521502173_item	2619428	et	3	main
hingatakse	doc_491521502173_item	2619429	et	3	main
6	doc_491521502173_item	2619430	et	2	main
kuid	doc_491521502173_item	2619431	et	4	main
telefonihelin	doc_491521502173_item	2619432	et	3	main
ka	doc_491521502173_item	2619434	et	3	main
valmistamine	doc_491521502173_item	2619440	et	4	main
söömine	doc_491521502173_item	2619442	et	4	main
pahandab	doc_491521502173_item	2619443	et	3	main
huvitav	doc_491521502173_item	2619444	et	4	main
varahommiku	doc_491521502173_item	2619453	et	3	main
aega	doc_491521502173_item	2619464	et	4	main
sõnad	doc_491521502173_item	2619469	et	4	main
õigesse	doc_491521502173_item	2619470	et	3	main
pean	doc_491521502173_item	2619474	et	4	main
lugu	doc_491521502173_item	2619476	et	4	main
igaüks	doc_491521502173_item	2619488	et	3	main
igaüht	doc_491521502173_item	2619489	et	3	main
2	doc_491521502173_item	2619490	et	2	main
kohandasin	doc_491521502173_item	2619491	et	3	main
artikli	doc_491521502173_item	2619492	et	3	main
nõuded	doc_491521502173_item	2619493	et	3	main
nõuetega	doc_491521502173_item	2619494	et	4	main
3	doc_491521502173_item	2619495	et	2	main
ma	doc_491521502173_item	2619496	et	3	main
arvasin	doc_491521502173_item	2619497	et	3	main
et	doc_491521502173_item	2619498	et	3	main
sa	doc_491521502173_item	2619499	et	3	main
huvitud	doc_491521502173_item	2619500	et	4	main
sport	doc_491521502173_item	2619501	et	3	main
spordist	doc_491521502173_item	2619502	et	3	main
aga	doc_491521502173_item	2619503	et	3	main
sa	doc_491521502173_item	2619504	et	3	main
tunned	doc_491521502173_item	2619505	et	3	main
huvi	doc_491521502173_item	2619506	et	4	main
ainult	doc_491521502173_item	2619507	et	4	main
ilusad	doc_491521502173_item	2619508	et	3	main
naised	doc_491521502173_item	2619509	et	3	main
ja	doc_491521502173_item	2619510	et	3	main
kiired	doc_491521502173_item	2619511	et	4	main
autod	doc_491521502173_item	2619512	et	3	main
ilusate	doc_491521502173_item	2619513	et	3	main
naiste	doc_491521502173_item	2619514	et	3	main
ja	doc_491521502173_item	2619515	et	3	main
varahommik	doc_491521502173_item	2619436	et	3	main
lõunasöök	doc_491521502173_item	2619439	et	3	main
ja	doc_491521502173_item	2619441	et	3	main
aeg	doc_491521502173_item	2619447	et	3	main
lõunasöögi	doc_491521502173_item	2619456	et	3	main
söömist	doc_491521502173_item	2619459	et	4	main
iv	doc_491521502173_item	2619465	et	4	main
pange	doc_491521502173_item	2619466	et	4	main
1	doc_491521502173_item	2619472	et	2	main
sest	doc_491521502173_item	2619481	et	4	main
nad	doc_491521502173_item	2619482	et	3	main
aitavad	doc_491521502173_item	2619483	et	4	main
kõik	doc_491521502173_item	2619484	et	4	main
kiirte	doc_491521502173_item	2619516	et	3	main
vastu	doc_491521502173_item	2619518	et	3	main
valmistamist	doc_491521502173_item	2619457	et	4	main
vormi	doc_491521502173_item	2619471	et	4	main
väga	doc_491521502173_item	2619475	et	3	main
oma	doc_491521502173_item	2619479	et	4	main
kõiki	doc_491521502173_item	2619485	et	4	main
ja	doc_491521502173_item	2619486	et	3	main
on	doc_491521502173_item	2619521	et	4	main
tüdinesin	doc_491521502173_item	2619527	et	3	main
küsimuses	doc_491521502173_item	2619536	et	4	main
muudatused	doc_491521502173_item	2619539	et	3	main
7	doc_491521502173_item	2619542	et	2	main
pükstesse	doc_491521502173_item	2619554	et	3	main
ajal	doc_491521502173_item	2619557	et	4	main
hoiduma	doc_491521502173_item	2619559	et	3	main
külmetamine	doc_491521502173_item	2619560	et	4	main
päike	doc_491521502173_item	2619567	et	3	main
lüngad	doc_491521502173_item	2619573	et	3	main
tellisime	doc_491521502173_item	2619577	et	4	main
kolmekäigulise	doc_491521502173_item	2619578	et	4	main
väikesed	doc_491521502173_item	2619538	et	4	main
püksid	doc_491521502173_item	2619553	et	3	main
rõõmu	doc_491521502173_item	2619565	et	4	main
suvine	doc_491521502173_item	2619566	et	4	main
v	doc_491521502173_item	2619571	et	4	main
1	doc_491521502173_item	2619576	et	2	main
maksis	doc_491521502173_item	2619582	et	4	main
nii	doc_491521502173_item	2619587	et	3	main
õpilased	doc_491521502173_item	2619588	et	3	main
kui	doc_491521502173_item	2619589	et	3	main
ka	doc_491521502173_item	2619590	et	3	main
õpetajad	doc_491521502173_item	2619591	et	4	main
3	doc_491521502173_item	2619592	et	2	main
lapsel	doc_491521502173_item	2619593	et	4	main
paluti	doc_491521502173_item	2619594	et	3	main
oodata	doc_491521502173_item	2619595	et	4	main
kuni	doc_491521502173_item	2619596	et	3	main
vanemad	doc_491521502173_item	2619597	et	4	main
tagasi	doc_491521502173_item	2619598	et	3	main
tulevad	doc_491521502173_item	2619599	et	4	main
4	doc_491521502173_item	2619600	et	2	main
kõrvallauast	doc_491521502173_item	2619601	et	4	main
kostis	doc_491521502173_item	2619602	et	4	main
naeru	doc_491521502173_item	2619603	et	4	main
nagu	doc_491521502173_item	2619604	et	3	main
oleks	doc_491521502173_item	2619605	et	3	main
keegi	doc_491521502173_item	2619606	et	4	main
just	doc_491521502173_item	2619607	et	3	main
anekdooti	doc_491521502173_item	2619608	et	4	main
rääkinud	doc_491521502173_item	2619609	et	4	main
5	doc_491521502173_item	2619610	et	2	main
ta	doc_491521502173_item	2619611	et	4	main
ei	doc_491521502173_item	2619612	et	4	main
tule	doc_491521502173_item	2619613	et	4	main
trenni	doc_491521502173_item	2619614	et	4	main
vaid	doc_491521502173_item	2619615	et	3	main
läheb	doc_491521502173_item	2619616	et	3	main
hoopis	doc_491521502173_item	2619617	et	3	main
teatrisse	doc_491521502173_item	2619618	et	3	main
6	doc_491521502173_item	2619619	et	2	main
lõpetage	doc_491521502173_item	2619620	et	3	main
siis	doc_491521502173_item	2619622	et	3	main
7	doc_491521502173_item	2619625	et	2	main
töötasid	doc_491521502173_item	2619636	et	4	main
pingsalt	doc_491521502173_item	2619638	et	4	main
pange	doc_491521502174_item	2619664	et	4	main
piret	doc_491521502174_item	2619670	et	4	main
suvel	doc_491521502174_item	2619675	et	3	main
oht	doc_491521502173_item	2619522	et	3	main
difteeriasse	doc_491521502173_item	2619525	et	3	main
5	doc_491521502173_item	2619526	et	2	main
töökohast	doc_491521502173_item	2619531	et	4	main
kiiresti	doc_491521502173_item	2619532	et	3	main
piirdusime	doc_491521502173_item	2619534	et	3	main
muudatustega	doc_491521502173_item	2619541	et	3	main
see	doc_491521502173_item	2619543	et	3	main
kuulub	doc_491521502173_item	2619545	et	3	main
teine	doc_491521502173_item	2619546	et	3	main
teisse	doc_491521502173_item	2619548	et	4	main
valdkonda	doc_491521502173_item	2619549	et	4	main
8	doc_491521502173_item	2619550	et	2	main
närimiskumm	doc_491521502173_item	2619551	et	3	main
kleepus	doc_491521502173_item	2619552	et	3	main
täitke	doc_491521502173_item	2619572	et	3	main
sidenditega	doc_491521502173_item	2619575	et	3	main
lõuna	doc_491521502173_item	2619579	et	4	main
kuigi	doc_491521502173_item	2619580	et	3	main
palju	doc_491521502173_item	2619583	et	4	main
olid	doc_491521502173_item	2619586	et	4	main
selles	doc_491521502173_item	2619626	et	4	main
suitsetada	doc_491521502173_item	2619630	et	3	main
8	doc_491521502173_item	2619634	et	2	main
tulemust	doc_491521502173_item	2619640	et	4	main
9	doc_491521502173_item	2619643	et	2	main
maale	doc_491521502173_item	2619647	et	4	main
või	doc_491521502173_item	2619648	et	4	main
koputust	doc_491521502173_item	2619656	et	4	main
test	doc_491521502174_item	2619659	et	3	main
oloevad	doc_491521502174_item	2619666	et	4	main
sõnad	doc_491521502174_item	2619667	et	4	main
õigesse	doc_491521502174_item	2619668	et	3	main
ettevõtlik	doc_491521502174_item	2619673	et	3	main
nägi	doc_491521502174_item	2619677	et	3	main
kui	doc_491521502174_item	2619723	et	3	main
mulle	doc_491521502174_item	2619724	et	4	main
lenda	doc_491521502174_item	2619741	et	4	main
lind	doc_491521502174_item	2619742	et	3	main
ega	doc_491521502174_item	2619743	et	3	main
kasva	doc_491521502174_item	2619744	et	4	main
algust	doc_491521502174_item	2619755	et	4	main
koht	doc_491521502174_item	2619756	et	3	main
kohale	doc_491521502174_item	2619757	et	4	main
jõudis	doc_491521502174_item	2619758	et	3	main
polnud	doc_491521502174_item	2619759	et	3	main
kool	doc_491521502174_item	2619760	et	4	main
küla	doc_491521502174_item	2619765	et	4	main
võttis	doc_491521502174_item	2619767	et	3	main
kartulivõtt	doc_491521502174_item	2619769	et	3	main
on	doc_491521502174_item	2619777	et	4	main
hooga	doc_491521502174_item	2619786	et	3	main
mõnus	doc_491521502174_item	2619792	et	4	main
mahlakas	doc_491521502174_item	2619794	et	4	main
inimest	doc_491521502174_item	2619826	et	3	main
rääkida	doc_491521502174_item	2619831	et	3	main
sõnul	doc_491521502174_item	2619833	et	3	main
poolpõlenud	doc_491521502174_item	2619836	et	4	main
talve	doc_491521502174_item	2619846	et	4	main
piret	doc_491521502174_item	2619847	et	4	main
juba	doc_491521502174_item	2619852	et	3	main
soe	doc_491521502174_item	2619860	et	4	main
naised	doc_491521502174_item	2619910	et	3	main
kaunim	doc_491521502174_item	2619916	et	4	main
naeratus	doc_491521502174_item	2619917	et	4	main
teeb	doc_491521502174_item	2619918	et	3	main
naisi	doc_491521502174_item	2619919	et	3	main
ja	doc_491521502174_item	2619921	et	3	main
igaüks	doc_491521502174_item	2619924	et	3	main
3	doc_491521502174_item	2619926	et	2	main
stress	doc_491521502174_item	2619929	et	3	main
tooma	doc_491521502174_item	2619936	et	3	main
tagajärgi	doc_491521502174_item	2619950	et	4	main
pinge	doc_491521502174_item	2619957	et	4	main
ülekoormusele	doc_491521502174_item	2619966	et	3	main
ja	doc_491521502174_item	2619971	et	3	main
telefon	doc_491521502174_item	2619974	et	3	main
tänapäev	doc_491521502174_item	2619976	et	3	main
telefon	doc_491521502174_item	2619988	et	3	main
nii	doc_491521502174_item	2619992	et	3	main
aparaatiks	doc_491521502174_item	2619994	et	4	main
ega	doc_491521502173_item	2619631	et	3	main
kuid	doc_491521502173_item	2619639	et	4	main
olnud	doc_491521502173_item	2619642	et	4	main
kas	doc_491521502173_item	2619644	et	3	main
sõidad	doc_491521502173_item	2619646	et	3	main
kuulsin	doc_491521502173_item	2619655	et	3	main
test	doc_491521502174_item	2619662	et	3	main
i	doc_491521502174_item	2619663	et	4	main
vormi	doc_491521502174_item	2619669	et	4	main
naine	doc_491521502174_item	2619674	et	3	main
ta	doc_491521502174_item	2619678	et	4	main
ülem-suetuki	doc_491521502174_item	2619684	et	4	main
küla	doc_491521502174_item	2619685	et	4	main
külla	doc_491521502174_item	2619686	et	4	main
otsitakse	doc_491521502174_item	2619687	et	3	main
eesti	doc_491521502174_item	2619688	et	4	main
keele	doc_491521502174_item	2619689	et	4	main
õpetajat	doc_491521502174_item	2619690	et	4	main
piret	doc_491521502174_item	2619691	et	4	main
võitis	doc_491521502174_item	2619692	et	3	main
konkurss	doc_491521502174_item	2619693	et	3	main
konkursi	doc_491521502174_item	2619694	et	3	main
ja	doc_491521502174_item	2619695	et	3	main
on	doc_491521502174_item	2619696	et	4	main
nüüd	doc_491521502174_item	2619697	et	4	main
juba	doc_491521502174_item	2619698	et	3	main
üle	doc_491521502174_item	2619699	et	3	main
nädal	doc_491521502174_item	2619700	et	3	main
nädala	doc_491521502174_item	2619701	et	3	main
väikestele	doc_491521502174_item	2619702	et	4	main
eestlastele	doc_491521502174_item	2619703	et	4	main
need	doc_491521502174_item	2619704	et	3	main
nende	doc_491521502174_item	2619705	et	4	main
emakeelt	doc_491521502174_item	2619706	et	4	main
õpetama	doc_491521502174_item	2619707	et	3	main
õpetamas	doc_491521502174_item	2619708	et	3	main
pireti	doc_491521502174_item	2619709	et	4	main
kinnitusel	doc_491521502174_item	2619710	et	4	main
tundis	doc_491521502174_item	2619711	et	3	main
ta	doc_491521502174_item	2619712	et	4	main
siberisse	doc_491521502174_item	2619713	et	4	main
jõudma	doc_491521502174_item	2619714	et	3	main
jõudmisega	doc_491521502174_item	2619715	et	4	main
et	doc_491521502174_item	2619716	et	3	main
sa	doc_491521502173_item	2619645	et	3	main
ukse	doc_491521502173_item	2619653	et	3	main
kui	doc_491521502173_item	2619654	et	3	main
keele	doc_491521502174_item	2619658	et	4	main
eesti	doc_491521502174_item	2619660	et	4	main
keele	doc_491521502174_item	2619661	et	4	main
on	doc_491521502174_item	2619672	et	4	main
ajalehes	doc_491521502174_item	2619679	et	3	main
et	doc_491521502174_item	2619682	et	3	main
siberisse	doc_491521502174_item	2619683	et	4	main
üllatanud	doc_491521502174_item	2619722	et	4	main
tulema	doc_491521502174_item	2619725	et	4	main
siber	doc_491521502174_item	2619733	et	4	main
seal	doc_491521502174_item	2619738	et	4	main
lendama	doc_491521502174_item	2619740	et	3	main
noor	doc_491521502174_item	2619747	et	3	main
pärast	doc_491521502174_item	2619753	et	4	main
õppeaasta	doc_491521502174_item	2619754	et	4	main
algama	doc_491521502174_item	2619762	et	3	main
algamas	doc_491521502174_item	2619763	et	3	main
siin	doc_491521502174_item	2619771	et	4	main
kõige	doc_491521502174_item	2619773	et	4	main
tähtis	doc_491521502174_item	2619774	et	4	main
ettevõtmine	doc_491521502174_item	2619775	et	3	main
täie	doc_491521502174_item	2619784	et	3	main
mõnusalt	doc_491521502174_item	2619795	et	4	main
ja	doc_491521502174_item	2619796	et	3	main
mahlakaselt	doc_491521502174_item	2619797	et	3	main
mitte	doc_491521502174_item	2619798	et	3	main
on	doc_491521502174_item	2619717	et	4	main
oodatud	doc_491521502174_item	2619718	et	4	main
olin	doc_491521502174_item	2619719	et	3	main
üsna	doc_491521502174_item	2619720	et	3	main
vastu	doc_491521502174_item	2619727	et	3	main
selline	doc_491521502174_item	2619735	et	4	main
veel	doc_491521502174_item	2619761	et	4	main
võtma	doc_491521502174_item	2619766	et	3	main
on	doc_491521502174_item	2619770	et	4	main
sügisel	doc_491521502174_item	2619772	et	3	main
käib	doc_491521502174_item	2619783	et	3	main
hoog	doc_491521502174_item	2619785	et	3	main
siinsed	doc_491521502174_item	2619787	et	3	main
räägivad	doc_491521502174_item	2619789	et	3	main
teistmoodi	doc_491521502174_item	2619791	et	3	main
vene	doc_491521502174_item	2619799	et	4	main
aktsent	doc_491521502174_item	2619800	et	3	main
aktsendita	doc_491521502174_item	2619801	et	3	main
vaid	doc_491521502174_item	2619802	et	3	main
nagu	doc_491521502174_item	2619803	et	3	main
mõni	doc_491521502174_item	2619804	et	3	main
u	doc_491521502174_item	2619806	et	4	main
kool	doc_491521502174_item	2619807	et	4	main
murret	doc_491521502174_item	2619805	et	4	main
on	doc_491521502174_item	2619808	et	4	main
siiski	doc_491521502174_item	2619809	et	4	main
venemaa	doc_491521502174_item	2619810	et	4	main
kool	doc_491521502174_item	2619811	et	4	main
ja	doc_491521502174_item	2619812	et	3	main
ülejäänud	doc_491521502174_item	2619813	et	4	main
aine	doc_491521502174_item	2619814	et	4	main
ained	doc_491521502174_item	2619815	et	3	main
õpetatakse	doc_491521502174_item	2619816	et	3	main
vene	doc_491521502174_item	2619817	et	4	main
keeles	doc_491521502174_item	2619818	et	4	main
külas	doc_491521502174_item	2619819	et	3	main
inimene	doc_491521502174_item	2619825	et	3	main
saab	doc_491521502174_item	2619828	et	3	main
lapsed	doc_491521502174_item	2619835	et	3	main
raamatud	doc_491521502174_item	2619837	et	4	main
ramatutega	doc_491521502174_item	2619838	et	4	main
varsti	doc_491521502174_item	2619839	et	3	main
saatma	doc_491521502174_item	2619840	et	3	main
ei	doc_491521502174_item	2619848	et	4	main
talvepuud	doc_491521502174_item	2619855	et	4	main
on	doc_491521502174_item	2619857	et	4	main
juba	doc_491521502174_item	2619868	et	3	main
laused	doc_491521502174_item	2619899	et	3	main
pannes	doc_491521502174_item	2619900	et	4	main
sõnad	doc_491521502174_item	2619901	et	4	main
õigesse	doc_491521502174_item	2619902	et	3	main
vormi	doc_491521502174_item	2619903	et	4	main
ja	doc_491521502174_item	2619904	et	3	main
kasutades	doc_491521502174_item	2619905	et	3	main
kirjavahemärke	doc_491521502174_item	2619906	et	4	main
üllatuma	doc_491521502174_item	2619721	et	3	main
tulid	doc_491521502174_item	2619726	et	4	main
audiga	doc_491521502174_item	2619730	et	3	main
maaliti	doc_491521502174_item	2619732	et	3	main
siberist	doc_491521502174_item	2619734	et	4	main
rohi	doc_491521502174_item	2619745	et	4	main
tahtmine	doc_491521502174_item	2619749	et	4	main
piret	doc_491521502174_item	2619752	et	4	main
tänaseks	doc_491521502174_item	2619776	et	4	main
õppimine	doc_491521502174_item	2619782	et	4	main
eestlased	doc_491521502174_item	2619788	et	3	main
kuidagi	doc_491521502174_item	2619790	et	3	main
elab	doc_491521502174_item	2619820	et	3	main
veidi	doc_491521502174_item	2619821	et	3	main
kolmsada	doc_491521502174_item	2619823	et	4	main
kõikjal	doc_491521502174_item	2619830	et	3	main
pireti	doc_491521502174_item	2619832	et	4	main
uued	doc_491521502174_item	2619843	et	3	main
mulle	doc_491521502174_item	2619851	et	4	main
tooma	doc_491521502174_item	2619853	et	3	main
kuid	doc_491521502174_item	2619862	et	4	main
ööd	doc_491521502174_item	2619863	et	4	main
juba	doc_491521502174_item	2619864	et	3	main
jahe	doc_491521502174_item	2619865	et	3	main
jahedad	doc_491521502174_item	2619866	et	3	main
vene	doc_491521502174_item	2619870	et	4	main
kütmine	doc_491521502174_item	2619872	et	4	main
kütmist	doc_491521502174_item	2619873	et	4	main
naeratus	doc_491521502174_item	2619908	et	4	main
naiselikum	doc_491521502174_item	2619911	et	4	main
mehed	doc_491521502174_item	2619913	et	3	main
igaüks	doc_491521502174_item	2619915	et	3	main
mehelikumaks	doc_491521502174_item	2619923	et	4	main
lisakoormus	doc_491521502174_item	2619934	et	3	main
tagajärg	doc_491521502174_item	2619938	et	3	main
4	doc_491521502174_item	2619951	et	2	main
tekkima	doc_491521502174_item	2619956	et	3	main
ja	doc_491521502174_item	2619961	et	3	main
puhkama	doc_491521502174_item	2619962	et	3	main
ei	doc_491521502174_item	2619963	et	4	main
abil	doc_491521502174_item	2619983	et	4	main
tänapäeval	doc_491521502174_item	2619990	et	3	main
elada	doc_491521502174_item	2620000	et	3	main
telefonihelin	doc_491521502174_item	2620022	et	3	main
varahommiku	doc_491521502174_item	2620026	et	3	main
pange	doc_491521502174_item	2620039	et	4	main
1	doc_491521502174_item	2620045	et	2	main
usaldavad	doc_491521502174_item	2620060	et	4	main
2	doc_491521502174_item	2620062	et	2	main
artikli	doc_491521502174_item	2620064	et	3	main
et	doc_491521502174_item	2620069	et	3	main
huvitatud	doc_491521502174_item	2620073	et	4	main
aga	doc_491521502174_item	2620075	et	3	main
teise	doc_491521502174_item	2620119	et	4	main
pükste	doc_491521502174_item	2620126	et	3	main
külmal	doc_491521502174_item	2620129	et	3	main
tunnen	doc_491521502174_item	2620137	et	3	main
päike	doc_491521502174_item	2620140	et	3	main
2	doc_491521502174_item	2620156	et	2	main
meie	doc_491521502174_item	2620162	et	4	main
kostis	doc_491521502174_item	2620174	et	4	main
ei	doc_491521502174_item	2620184	et	4	main
tule	doc_491521502174_item	2620185	et	4	main
et	doc_491521502174_item	2620195	et	3	main
töötasid	doc_491521502174_item	2620209	et	4	main
10	doc_491521502174_item	2620224	et	2	main
eesti	doc_491521502175_item	2620233	et	4	main
pange	doc_491521502175_item	2620237	et	4	main
on	doc_491521502175_item	2620245	et	4	main
ettevõtlik	doc_491521502175_item	2620246	et	3	main
naine	doc_491521502175_item	2620247	et	3	main
suvel	doc_491521502175_item	2620248	et	3	main
nägema	doc_491521502175_item	2620249	et	3	main
nägi	doc_491521502175_item	2620250	et	3	main
siberisse	doc_491521502175_item	2620256	et	4	main
küla	doc_491521502175_item	2620258	et	4	main
juba	doc_491521502175_item	2620271	et	3	main
nädala	doc_491521502175_item	2620274	et	3	main
tundis	doc_491521502175_item	2620284	et	3	main
ta	doc_491521502175_item	2620285	et	4	main
mulle	doc_491521502175_item	2620304	et	4	main
maaliti	doc_491521502175_item	2620305	et	3	main
täis	doc_491521502174_item	2619751	et	4	main
kogu	doc_491521502174_item	2619764	et	4	main
kartuleid	doc_491521502174_item	2619768	et	3	main
kartul	doc_491521502174_item	2619778	et	3	main
salv	doc_491521502174_item	2619779	et	3	main
salvetud	doc_491521502174_item	2619780	et	4	main
ja	doc_491521502174_item	2619781	et	3	main
ja	doc_491521502174_item	2619793	et	3	main
kolmesaja	doc_491521502174_item	2619824	et	4	main
kõik	doc_491521502174_item	2619829	et	4	main
õpivad	doc_491521502174_item	2619834	et	3	main
õpikud	doc_491521502174_item	2619844	et	3	main
kartma	doc_491521502174_item	2619849	et	3	main
toodi	doc_491521502174_item	2619854	et	4	main
praegu	doc_491521502174_item	2619856	et	3	main
päevad	doc_491521502174_item	2619858	et	3	main
veel	doc_491521502174_item	2619859	et	4	main
harjutan	doc_491521502174_item	2619867	et	3	main
tegema	doc_491521502174_item	2619909	et	3	main
naiselikumaks	doc_491521502174_item	2619920	et	4	main
võima	doc_491521502174_item	2619935	et	3	main
parases	doc_491521502174_item	2619939	et	4	main
koguses	doc_491521502174_item	2619940	et	4	main
stress	doc_491521502174_item	2619941	et	3	main
paneb	doc_491521502174_item	2619942	et	3	main
laskma	doc_491521502174_item	2619954	et	3	main
saama	doc_491521502174_item	2619958	et	4	main
maandama	doc_491521502174_item	2619959	et	3	main
sportima	doc_491521502174_item	2619960	et	4	main
maandata	doc_491521502174_item	2619969	et	3	main
olema	doc_491521502174_item	2619975	et	4	main
lausa	doc_491521502174_item	2619999	et	4	main
katkestab	doc_491521502174_item	2620023	et	3	main
und	doc_491521502174_item	2620027	et	4	main
lõunasööki	doc_491521502174_item	2620029	et	4	main
aega	doc_491521502174_item	2620037	et	4	main
sõnad	doc_491521502174_item	2620042	et	4	main
õigesse	doc_491521502174_item	2620043	et	3	main
pean	doc_491521502174_item	2620047	et	4	main
vanematest	doc_491521502174_item	2620053	et	4	main
nad	doc_491521502174_item	2620055	et	3	main
nõuded	doc_491521502174_item	2620065	et	3	main
huvitud	doc_491521502174_item	2620071	et	4	main
püksid	doc_491521502174_item	2620124	et	3	main
külga	doc_491521502174_item	2620127	et	4	main
ma	doc_491521502174_item	2620136	et	3	main
suvine	doc_491521502174_item	2620139	et	4	main
suvisest	doc_491521502174_item	2620141	et	4	main
päikesest	doc_491521502174_item	2620142	et	4	main
v	doc_491521502174_item	2620143	et	4	main
täitke	doc_491521502174_item	2620144	et	3	main
lüngad	doc_491521502174_item	2620145	et	3	main
vanemad	doc_491521502174_item	2620169	et	4	main
kõrvallauast	doc_491521502174_item	2620173	et	4	main
keegi	doc_491521502174_item	2620178	et	4	main
töö	doc_491521502174_item	2620194	et	4	main
7	doc_491521502174_item	2620198	et	2	main
ei	doc_491521502174_item	2620201	et	4	main
suitsetada	doc_491521502174_item	2620203	et	3	main
ega	doc_491521502174_item	2620204	et	3	main
alkoholi	doc_491521502174_item	2620205	et	4	main
tarbida	doc_491521502174_item	2620206	et	3	main
8	doc_491521502174_item	2620207	et	2	main
nad	doc_491521502174_item	2620208	et	3	main
ei	doc_491521502174_item	2620214	et	4	main
olnud	doc_491521502174_item	2620215	et	4	main
sõidad	doc_491521502174_item	2620219	et	3	main
üle	doc_491521502174_item	2619822	et	3	main
emakeelt	doc_491521502174_item	2619827	et	4	main
saavad	doc_491521502174_item	2619841	et	4	main
eestist	doc_491521502174_item	2619842	et	3	main
siberi	doc_491521502174_item	2619845	et	4	main
karda	doc_491521502174_item	2619850	et	4	main
soojad	doc_491521502174_item	2619861	et	3	main
suure	doc_491521502174_item	2619869	et	3	main
ahju	doc_491521502174_item	2619871	et	4	main
kui	doc_491521502174_item	2619874	et	3	main
vaja	doc_491521502174_item	2619875	et	4	main
ostan	doc_491521502174_item	2619876	et	3	main
külapood	doc_491521502174_item	2619877	et	3	main
külapoest	doc_491521502174_item	2619878	et	4	main
vildid	doc_491521502174_item	2619879	et	4	main
ega	doc_491521502174_item	2619880	et	3	main
seal	doc_491521502174_item	2619881	et	4	main
suurt	doc_491521502174_item	2619882	et	3	main
muud	doc_491521502174_item	2619883	et	4	main
ei	doc_491521502174_item	2619884	et	4	main
müüdagi	doc_491521502174_item	2619885	et	3	main
naerab	doc_491521502174_item	2619886	et	3	main
talveks	doc_491521502174_item	2619887	et	4	main
valmistuma	doc_491521502174_item	2619888	et	3	main
valmistatud	doc_491521502174_item	2619889	et	4	main
piret	doc_491521502174_item	2619890	et	4	main
vapralt	doc_491521502174_item	2619891	et	4	main
lühendatud	doc_491521502174_item	2619892	et	4	main
ajalehest	doc_491521502174_item	2619893	et	4	main
slõhtuleht	doc_491521502174_item	2619894	et	4	main
iii	doc_491521502174_item	2619895	et	4	main
moodustage	doc_491521502174_item	2619896	et	3	main
etteantud	doc_491521502174_item	2619897	et	4	main
sõnadest	doc_491521502174_item	2619898	et	3	main
2	doc_491521502174_item	2619907	et	2	main
ja	doc_491521502174_item	2619912	et	3	main
mehelikum	doc_491521502174_item	2619914	et	4	main
mehi	doc_491521502174_item	2619922	et	3	main
kaunimaks	doc_491521502174_item	2619925	et	4	main
paras	doc_491521502174_item	2619927	et	3	main
kogus	doc_491521502174_item	2619928	et	4	main
panema	doc_491521502174_item	2619930	et	3	main
tegutsema	doc_491521502174_item	2619932	et	3	main
soovitamatu	doc_491521502174_item	2619949	et	4	main
tohtima	doc_491521502174_item	2619953	et	3	main
sportida	doc_491521502174_item	2619970	et	4	main
5	doc_491521502174_item	2619973	et	2	main
lausa	doc_491521502174_item	2619984	et	4	main
elama	doc_491521502174_item	2619985	et	3	main
ja	doc_491521502174_item	2619986	et	3	main
hingama	doc_491521502174_item	2619987	et	3	main
saanud	doc_491521502174_item	2619991	et	4	main
maagiliks	doc_491521502174_item	2619993	et	4	main
ei	doc_491521502174_item	2619998	et	4	main
hingata	doc_491521502174_item	2620002	et	4	main
uni	doc_491521502174_item	2620010	et	3	main
meie	doc_491521502174_item	2619931	et	4	main
aga	doc_491521502174_item	2619933	et	3	main
soovimatu	doc_491521502174_item	2619937	et	4	main
meid	doc_491521502174_item	2619943	et	4	main
tegutsema	doc_491521502174_item	2619944	et	3	main
aga	doc_491521502174_item	2619945	et	3	main
lisakoormus	doc_491521502174_item	2619946	et	3	main
võib	doc_491521502174_item	2619947	et	3	main
tuua	doc_491521502174_item	2619948	et	3	main
ei	doc_491521502174_item	2619952	et	4	main
ülekoormus	doc_491521502174_item	2619955	et	3	main
tohi	doc_491521502174_item	2619964	et	4	main
lasta	doc_491521502174_item	2619965	et	4	main
tekkida	doc_491521502174_item	2619967	et	3	main
pingele	doc_491521502174_item	2619968	et	4	main
puhata	doc_491521502174_item	2619972	et	4	main
saama	doc_491521502174_item	2619977	et	4	main
nii	doc_491521502174_item	2619978	et	3	main
maagiline	doc_491521502174_item	2619979	et	4	main
aparaat	doc_491521502174_item	2619980	et	3	main
et	doc_491521502174_item	2619981	et	3	main
see	doc_491521502174_item	2619982	et	3	main
on	doc_491521502174_item	2619989	et	4	main
abil	doc_491521502174_item	2619997	et	4	main
6	doc_491521502174_item	2620003	et	2	main
telefonihelin	doc_491521502174_item	2620005	et	3	main
ka	doc_491521502174_item	2620007	et	3	main
varahommik	doc_491521502174_item	2620009	et	3	main
segama	doc_491521502174_item	2620011	et	3	main
lõunasöök	doc_491521502174_item	2620012	et	3	main
valmistamine	doc_491521502174_item	2620013	et	4	main
ja	doc_491521502174_item	2620014	et	3	main
söömine	doc_491521502174_item	2620015	et	4	main
pahandab	doc_491521502174_item	2620016	et	3	main
huvitav	doc_491521502174_item	2620017	et	4	main
telesaade	doc_491521502174_item	2620018	et	4	main
vaatamine	doc_491521502174_item	2620019	et	4	main
aeg	doc_491521502174_item	2620020	et	3	main
ka	doc_491521502174_item	2620024	et	3	main
huvitava	doc_491521502174_item	2620034	et	4	main
sulgudes	doc_491521502174_item	2620040	et	4	main
olevad	doc_491521502174_item	2620041	et	4	main
väga	doc_491521502174_item	2620048	et	3	main
oma	doc_491521502174_item	2620050	et	4	main
kõik	doc_491521502174_item	2620057	et	4	main
kõiki	doc_491521502174_item	2620058	et	4	main
ja	doc_491521502174_item	2620059	et	3	main
ma	doc_491521502174_item	2620067	et	3	main
sport	doc_491521502174_item	2620072	et	3	main
huvi	doc_491521502174_item	2620078	et	4	main
ainult	doc_491521502174_item	2620079	et	4	main
ilusad	doc_491521502174_item	2620080	et	3	main
valdkonda	doc_491521502174_item	2620120	et	4	main
et	doc_491521502174_item	2619995	et	3	main
selle	doc_491521502174_item	2619996	et	4	main
ja	doc_491521502174_item	2620001	et	3	main
kuid	doc_491521502174_item	2620004	et	4	main
katkestama	doc_491521502174_item	2620006	et	3	main
pühapäev	doc_491521502174_item	2620008	et	3	main
kuid	doc_491521502174_item	2620021	et	4	main
segab	doc_491521502174_item	2620028	et	3	main
valmistamise	doc_491521502174_item	2620030	et	4	main
ja	doc_491521502174_item	2620031	et	3	main
söömise	doc_491521502174_item	2620032	et	4	main
pahandab	doc_491521502174_item	2620033	et	3	main
iv	doc_491521502174_item	2620038	et	4	main
vormi	doc_491521502174_item	2620044	et	4	main
sest	doc_491521502174_item	2620054	et	4	main
igaüks	doc_491521502174_item	2620061	et	3	main
3	doc_491521502174_item	2620066	et	2	main
arvasin	doc_491521502174_item	2620068	et	3	main
sa	doc_491521502174_item	2620070	et	3	main
spordist	doc_491521502174_item	2620074	et	3	main
sa	doc_491521502174_item	2620076	et	3	main
tunned	doc_491521502174_item	2620077	et	3	main
väikestega	doc_491521502174_item	2620111	et	4	main
8	doc_491521502174_item	2620121	et	2	main
pükstele	doc_491521502174_item	2620125	et	3	main
9	doc_491521502174_item	2620128	et	2	main
ajal	doc_491521502174_item	2620130	et	4	main
hoiduma	doc_491521502174_item	2620132	et	3	main
lõuna	doc_491521502174_item	2620151	et	4	main
ja	doc_491521502174_item	2620152	et	3	main
see	doc_491521502174_item	2620153	et	3	main
maksis	doc_491521502174_item	2620154	et	4	main
kohal	doc_491521502174_item	2620157	et	4	main
tagasi	doc_491521502174_item	2620170	et	3	main
nagu	doc_491521502174_item	2620176	et	3	main
anekdooti	doc_491521502174_item	2620180	et	4	main
trenni	doc_491521502174_item	2620186	et	4	main
sellepärast	doc_491521502174_item	2620187	et	3	main
et	doc_491521502174_item	2620188	et	3	main
läheb	doc_491521502174_item	2620189	et	3	main
hoopis	doc_491521502174_item	2620190	et	3	main
teatrisse	doc_491521502174_item	2620191	et	3	main
lõpetage	doc_491521502174_item	2620193	et	3	main
selles	doc_491521502174_item	2620199	et	4	main
tulemust	doc_491521502174_item	2620213	et	4	main
9	doc_491521502174_item	2620216	et	2	main
sa	doc_491521502174_item	2620218	et	3	main
ukse	doc_491521502174_item	2620226	et	3	main
ja	doc_491521502174_item	2620227	et	3	main
koputust	doc_491521502174_item	2620229	et	4	main
keele	doc_491521502175_item	2620231	et	4	main
test	doc_491521502175_item	2620232	et	3	main
sõnad	doc_491521502175_item	2620240	et	4	main
ajalehes	doc_491521502175_item	2620252	et	3	main
et	doc_491521502175_item	2620255	et	3	main
nüüd	doc_491521502175_item	2620270	et	4	main
õpetanud	doc_491521502175_item	2620281	et	4	main
pireti	doc_491521502175_item	2620282	et	4	main
jõudnud	doc_491521502175_item	2620288	et	4	main
olin	doc_491521502175_item	2620292	et	3	main
üllatuma	doc_491521502175_item	2620294	et	3	main
kui	doc_491521502175_item	2620296	et	3	main
pilt	doc_491521502175_item	2620309	et	3	main
seal	doc_491521502175_item	2620311	et	4	main
täis	doc_491521502175_item	2620324	et	4	main
piret	doc_491521502175_item	2620325	et	4	main
kohale	doc_491521502175_item	2620330	et	4	main
kogu	doc_491521502175_item	2620337	et	4	main
tähtsam	doc_491521502175_item	2620348	et	4	main
ettevõtmine	doc_491521502175_item	2620349	et	3	main
tänaseks	doc_491521502175_item	2620350	et	4	main
on	doc_491521502175_item	2620351	et	4	main
kartul	doc_491521502175_item	2620352	et	3	main
salv	doc_491521502175_item	2620353	et	3	main
salvis	doc_491521502175_item	2620354	et	4	main
aktsent	doc_491521502175_item	2620374	et	3	main
murret	doc_491521502175_item	2620380	et	4	main
kool	doc_491521502175_item	2620381	et	4	main
kool	doc_491521502175_item	2620385	et	4	main
ja	doc_491521502175_item	2620386	et	3	main
ülejäänud	doc_491521502175_item	2620387	et	4	main
elab	doc_491521502175_item	2620394	et	3	main
pühapäeva	doc_491521502174_item	2620025	et	4	main
telesaade	doc_491521502174_item	2620035	et	4	main
vaatamise	doc_491521502174_item	2620036	et	4	main
ma	doc_491521502174_item	2620046	et	3	main
lugu	doc_491521502174_item	2620049	et	4	main
vanemad	doc_491521502174_item	2620051	et	4	main
oma	doc_491521502174_item	2620052	et	4	main
aitavad	doc_491521502174_item	2620056	et	4	main
kohandasin	doc_491521502174_item	2620063	et	3	main
naised	doc_491521502174_item	2620081	et	3	main
ja	doc_491521502174_item	2620082	et	3	main
kiired	doc_491521502174_item	2620083	et	4	main
autod	doc_491521502174_item	2620084	et	3	main
ilusatest	doc_491521502174_item	2620085	et	3	main
naistest	doc_491521502174_item	2620086	et	4	main
ja	doc_491521502174_item	2620087	et	3	main
kiiredest	doc_491521502174_item	2620088	et	4	main
autodest	doc_491521502174_item	2620089	et	3	main
4	doc_491521502174_item	2620090	et	2	main
praegu	doc_491521502174_item	2620091	et	3	main
on	doc_491521502174_item	2620092	et	4	main
oht	doc_491521502174_item	2620093	et	3	main
haigestuda	doc_491521502174_item	2620094	et	3	main
difteeria	doc_491521502174_item	2620095	et	4	main
difteeriat	doc_491521502174_item	2620096	et	3	main
5	doc_491521502174_item	2620097	et	2	main
tüdinesin	doc_491521502174_item	2620098	et	3	main
uus	doc_491521502174_item	2620099	et	3	main
töökoht	doc_491521502174_item	2620100	et	3	main
uuesse	doc_491521502174_item	2620101	et	3	main
töökta	doc_491521502174_item	2620102	et	4	main
kiiresti	doc_491521502174_item	2620103	et	3	main
6	doc_491521502174_item	2620104	et	2	main
piirdusime	doc_491521502174_item	2620105	et	3	main
selles	doc_491521502174_item	2620106	et	4	main
küsimuses	doc_491521502174_item	2620107	et	4	main
vaid	doc_491521502174_item	2620108	et	3	main
väikesed	doc_491521502174_item	2620109	et	4	main
muudatused	doc_491521502174_item	2620110	et	3	main
muudatustega	doc_491521502174_item	2620112	et	3	main
7	doc_491521502174_item	2620113	et	2	main
see	doc_491521502174_item	2620114	et	3	main
küsimus	doc_491521502174_item	2620115	et	4	main
kuulub	doc_491521502174_item	2620116	et	3	main
teine	doc_491521502174_item	2620117	et	3	main
valdkond	doc_491521502174_item	2620118	et	3	main
närimiskumm	doc_491521502174_item	2620122	et	3	main
külmatamisest	doc_491521502174_item	2620134	et	4	main
10	doc_491521502174_item	2620135	et	2	main
sobivate	doc_491521502174_item	2620146	et	4	main
sidenditega	doc_491521502174_item	2620147	et	3	main
palju	doc_491521502174_item	2620155	et	4	main
olid	doc_491521502174_item	2620158	et	4	main
meie	doc_491521502174_item	2620159	et	4	main
õpilased	doc_491521502174_item	2620160	et	3	main
õpetajad	doc_491521502174_item	2620163	et	4	main
lapsel	doc_491521502174_item	2620165	et	4	main
paluti	doc_491521502174_item	2620166	et	3	main
oodata	doc_491521502174_item	2620167	et	4	main
kuna	doc_491521502174_item	2620168	et	3	main
4	doc_491521502174_item	2620172	et	2	main
naeru	doc_491521502174_item	2620175	et	4	main
oleks	doc_491521502174_item	2620177	et	3	main
just	doc_491521502174_item	2620179	et	3	main
rääkinud	doc_491521502174_item	2620181	et	4	main
5	doc_491521502174_item	2620182	et	2	main
6	doc_491521502174_item	2620192	et	2	main
baaris	doc_491521502174_item	2620200	et	3	main
tohi	doc_491521502174_item	2620202	et	4	main
aga	doc_491521502174_item	2620212	et	3	main
kas	doc_491521502174_item	2620217	et	3	main
maale	doc_491521502174_item	2620220	et	4	main
jääd	doc_491521502174_item	2620222	et	4	main
sulgudes	doc_491521502175_item	2620238	et	4	main
olevad	doc_491521502175_item	2620239	et	4	main
kuulutuse	doc_491521502175_item	2620254	et	4	main
keele	doc_491521502175_item	2620262	et	4	main
nädal	doc_491521502175_item	2620273	et	3	main
on	doc_491521502175_item	2620290	et	4	main
üllatunud	doc_491521502175_item	2620295	et	4	main
siberist	doc_491521502175_item	2620307	et	4	main
algust	doc_491521502175_item	2620328	et	4	main
võttis	doc_491521502175_item	2620340	et	3	main
kartulivõtt	doc_491521502175_item	2620342	et	3	main
täie	doc_491521502175_item	2620358	et	3	main
hooga	doc_491521502175_item	2620360	et	3	main
vaid	doc_491521502175_item	2620376	et	3	main
venemaa	doc_491521502175_item	2620384	et	4	main
veidi	doc_491521502175_item	2620395	et	3	main
inimene	doc_491521502175_item	2620399	et	3	main
päevad	doc_491521502175_item	2620432	et	3	main
soojad	doc_491521502175_item	2620435	et	3	main
ööd	doc_491521502175_item	2620437	et	4	main
kui	doc_491521502175_item	2620448	et	3	main
müüdagi	doc_491521502175_item	2620459	et	3	main
slõhtuleht	doc_491521502175_item	2620468	et	4	main
tegema	doc_491521502175_item	2620483	et	3	main
naiselikumaks	doc_491521502175_item	2620494	et	4	main
mehi	doc_491521502175_item	2620495	et	3	main
tuua	doc_491521502175_item	2620522	et	3	main
tagajärge	doc_491521502175_item	2620524	et	4	main
ei	doc_491521502175_item	2620526	et	4	main
puhkama	doc_491521502175_item	2620536	et	3	main
lasta	doc_491521502175_item	2620540	et	4	main
pinget	doc_491521502175_item	2620542	et	3	main
maandada	doc_491521502175_item	2620544	et	3	main
ja	doc_491521502175_item	2620546	et	3	main
5	doc_491521502175_item	2620548	et	2	main
telefon	doc_491521502175_item	2620549	et	3	main
olema	doc_491521502175_item	2620550	et	4	main
tänapäev	doc_491521502175_item	2620551	et	3	main
see	doc_491521502175_item	2620557	et	3	main
ja	doc_491521502175_item	2620561	et	3	main
abil	doc_491521502175_item	2620572	et	4	main
6	doc_491521502175_item	2620577	et	2	main
pühapäev	doc_491521502175_item	2620582	et	3	main
uni	doc_491521502175_item	2620584	et	3	main
lõunasöök	doc_491521502175_item	2620586	et	3	main
ja	doc_491521502175_item	2620588	et	3	main
vaatamine	doc_491521502175_item	2620593	et	4	main
aeg	doc_491521502175_item	2620594	et	3	main
katkestab	doc_491521502175_item	2620596	et	3	main
kleepus	doc_491521502174_item	2620123	et	3	main
peab	doc_491521502174_item	2620131	et	4	main
külmetamine	doc_491521502174_item	2620133	et	4	main
rõõmu	doc_491521502174_item	2620138	et	4	main
1	doc_491521502174_item	2620148	et	2	main
tellisime	doc_491521502174_item	2620149	et	4	main
kolmekäigulise	doc_491521502174_item	2620150	et	4	main
ja	doc_491521502174_item	2620161	et	3	main
3	doc_491521502174_item	2620164	et	2	main
tulevad	doc_491521502174_item	2620171	et	4	main
ta	doc_491521502174_item	2620183	et	4	main
lähete	doc_491521502174_item	2620196	et	4	main
jalutama	doc_491521502174_item	2620197	et	3	main
küll	doc_491521502174_item	2620210	et	4	main
pingsalt	doc_491521502174_item	2620211	et	4	main
linna	doc_491521502174_item	2620223	et	4	main
eesti	doc_491521502175_item	2620230	et	4	main
keele	doc_491521502175_item	2620234	et	4	main
vormi	doc_491521502175_item	2620242	et	4	main
piret	doc_491521502175_item	2620243	et	4	main
toomet	doc_491521502175_item	2620244	et	4	main
kuulutus	doc_491521502175_item	2620253	et	4	main
eesti	doc_491521502175_item	2620261	et	4	main
õpetajat	doc_491521502175_item	2620263	et	4	main
piret	doc_491521502175_item	2620264	et	4	main
võitis	doc_491521502175_item	2620265	et	3	main
konkurss	doc_491521502175_item	2620266	et	3	main
konkursi	doc_491521502175_item	2620267	et	3	main
üle	doc_491521502175_item	2620272	et	3	main
väikestele	doc_491521502175_item	2620275	et	4	main
need	doc_491521502175_item	2620277	et	3	main
nende	doc_491521502175_item	2620278	et	4	main
emakeelt	doc_491521502175_item	2620279	et	4	main
õpetama	doc_491521502175_item	2620280	et	3	main
siberisse	doc_491521502175_item	2620286	et	4	main
jõudma	doc_491521502175_item	2620287	et	3	main
oodatud	doc_491521502175_item	2620291	et	4	main
üsna	doc_491521502175_item	2620293	et	3	main
mulle	doc_491521502175_item	2620297	et	4	main
tulema	doc_491521502175_item	2620298	et	4	main
tuldi	doc_491521502175_item	2620299	et	3	main
vastu	doc_491521502175_item	2620300	et	3	main
korralik	doc_491521502175_item	2620301	et	3	main
korraliku	doc_491521502175_item	2620302	et	3	main
audiga	doc_491521502175_item	2620303	et	3	main
ei	doc_491521502175_item	2620312	et	4	main
tahtmine	doc_491521502175_item	2620322	et	4	main
õppeaasta	doc_491521502175_item	2620327	et	4	main
polnud	doc_491521502175_item	2620332	et	3	main
veel	doc_491521502175_item	2620334	et	4	main
küla	doc_491521502175_item	2620338	et	4	main
käib	doc_491521502175_item	2620357	et	3	main
mõnus	doc_491521502175_item	2620366	et	4	main
mahlakas	doc_491521502175_item	2620368	et	4	main
mõnusam	doc_491521502175_item	2620369	et	4	main
ja	doc_491521502175_item	2620370	et	3	main
aktsendiga	doc_491521502175_item	2620375	et	3	main
siiski	doc_491521502175_item	2620383	et	4	main
vene	doc_491521502175_item	2620391	et	4	main
kolmsada	doc_491521502175_item	2620397	et	4	main
emakeelt	doc_491521502175_item	2620401	et	4	main
karda	doc_491521502175_item	2620424	et	4	main
mulle	doc_491521502175_item	2620425	et	4	main
juba	doc_491521502175_item	2620426	et	3	main
tooma	doc_491521502175_item	2620427	et	3	main
on	doc_491521502175_item	2620431	et	4	main
kütmist	doc_491521502175_item	2620447	et	4	main
ei	doc_491521502175_item	2620458	et	4	main
naerab	doc_491521502175_item	2620460	et	3	main
iii	doc_491521502175_item	2620469	et	4	main
pannes	doc_491521502175_item	2620474	et	4	main
naised	doc_491521502175_item	2620484	et	3	main
mehelikumaks	doc_491521502175_item	2620496	et	4	main
igaüht	doc_491521502175_item	2620498	et	3	main
sportima	doc_491521502175_item	2620534	et	4	main
tohi	doc_491521502175_item	2620539	et	4	main
puhkamisega	doc_491521502175_item	2620547	et	4	main
et	doc_491521502175_item	2620556	et	3	main
lausa	doc_491521502175_item	2620559	et	4	main
hingama	doc_491521502175_item	2620562	et	3	main
on	doc_491521502175_item	2620564	et	4	main
tänapäeval	doc_491521502175_item	2620565	et	3	main
lausa	doc_491521502175_item	2620573	et	4	main
või	doc_491521502174_item	2620221	et	4	main
avasin	doc_491521502174_item	2620225	et	3	main
kuulsin	doc_491521502174_item	2620228	et	3	main
test	doc_491521502175_item	2620235	et	3	main
i	doc_491521502175_item	2620236	et	4	main
õigesse	doc_491521502175_item	2620241	et	3	main
ta	doc_491521502175_item	2620251	et	4	main
ülem-suetuki	doc_491521502175_item	2620257	et	4	main
külla	doc_491521502175_item	2620259	et	4	main
otsitakse	doc_491521502175_item	2620260	et	3	main
ja	doc_491521502175_item	2620268	et	3	main
on	doc_491521502175_item	2620269	et	4	main
eestlastele	doc_491521502175_item	2620276	et	4	main
kinnitusel	doc_491521502175_item	2620283	et	4	main
et	doc_491521502175_item	2620289	et	3	main
selline	doc_491521502175_item	2620308	et	4	main
et	doc_491521502175_item	2620310	et	3	main
lendama	doc_491521502175_item	2620313	et	3	main
lenda	doc_491521502175_item	2620314	et	4	main
lind	doc_491521502175_item	2620315	et	3	main
ega	doc_491521502175_item	2620316	et	3	main
kasva	doc_491521502175_item	2620317	et	4	main
rohi	doc_491521502175_item	2620318	et	4	main
kui	doc_491521502175_item	2620319	et	3	main
noor	doc_491521502175_item	2620320	et	3	main
ja	doc_491521502175_item	2620321	et	3	main
tahtmist	doc_491521502175_item	2620323	et	4	main
koht	doc_491521502175_item	2620329	et	3	main
jõudis	doc_491521502175_item	2620331	et	3	main
kool	doc_491521502175_item	2620333	et	4	main
algama	doc_491521502175_item	2620335	et	3	main
võtma	doc_491521502175_item	2620339	et	3	main
kartuleid	doc_491521502175_item	2620341	et	3	main
siin	doc_491521502175_item	2620344	et	4	main
sügisel	doc_491521502175_item	2620345	et	3	main
kõige	doc_491521502175_item	2620346	et	4	main
õppimine	doc_491521502175_item	2620356	et	4	main
hoog	doc_491521502175_item	2620359	et	3	main
siinsed	doc_491521502175_item	2620361	et	3	main
räägivad	doc_491521502175_item	2620363	et	3	main
teistmoodi	doc_491521502175_item	2620365	et	3	main
ja	doc_491521502175_item	2620367	et	3	main
vene	doc_491521502175_item	2620373	et	4	main
mõnda	doc_491521502175_item	2620379	et	4	main
on	doc_491521502175_item	2620382	et	4	main
aine	doc_491521502175_item	2620388	et	4	main
ained	doc_491521502175_item	2620389	et	3	main
õpetatakse	doc_491521502175_item	2620390	et	3	main
piret	doc_491521502175_item	2620421	et	4	main
kartma	doc_491521502175_item	2620423	et	3	main
veel	doc_491521502175_item	2620433	et	4	main
kütmine	doc_491521502175_item	2620446	et	4	main
ostan	doc_491521502175_item	2620450	et	3	main
külapood	doc_491521502175_item	2620451	et	3	main
vildid	doc_491521502175_item	2620453	et	4	main
ega	doc_491521502175_item	2620454	et	3	main
seal	doc_491521502175_item	2620455	et	4	main
suurt	doc_491521502175_item	2620456	et	3	main
muud	doc_491521502175_item	2620457	et	4	main
valmistuma	doc_491521502175_item	2620462	et	3	main
piret	doc_491521502175_item	2620464	et	4	main
vapralt	doc_491521502175_item	2620465	et	4	main
kirjavahemärke	doc_491521502175_item	2620480	et	4	main
2	doc_491521502175_item	2620481	et	2	main
naeratus	doc_491521502175_item	2620491	et	4	main
teeb	doc_491521502175_item	2620492	et	3	main
naisi	doc_491521502175_item	2620493	et	3	main
saama	doc_491521502175_item	2620532	et	4	main
ei	doc_491521502175_item	2620538	et	4	main
tekkida	doc_491521502175_item	2620541	et	3	main
saab	doc_491521502175_item	2620543	et	3	main
saanud	doc_491521502175_item	2620566	et	4	main
elaks	doc_491521502175_item	2620574	et	3	main
telesaade	doc_491521502175_item	2620592	et	4	main
telefonihelin	doc_491521502175_item	2620595	et	3	main
pühapäeviti	doc_491521502175_item	2620597	et	4	main
vaatamisaega	doc_491521502175_item	2620610	et	4	main
siber	doc_491521502175_item	2620306	et	4	main
pärast	doc_491521502175_item	2620326	et	4	main
alganud	doc_491521502175_item	2620336	et	4	main
on	doc_491521502175_item	2620343	et	4	main
tähtis	doc_491521502175_item	2620347	et	4	main
ja	doc_491521502175_item	2620355	et	3	main
eestlased	doc_491521502175_item	2620362	et	3	main
kuidagi	doc_491521502175_item	2620364	et	3	main
mahlakam	doc_491521502175_item	2620371	et	4	main
mitte	doc_491521502175_item	2620372	et	3	main
nagu	doc_491521502175_item	2620377	et	3	main
mõni	doc_491521502175_item	2620378	et	3	main
keeles	doc_491521502175_item	2620392	et	4	main
külas	doc_491521502175_item	2620393	et	3	main
üle	doc_491521502175_item	2620396	et	3	main
saab	doc_491521502175_item	2620402	et	3	main
kõik	doc_491521502175_item	2620403	et	4	main
kõigil	doc_491521502175_item	2620404	et	4	main
rääkida	doc_491521502175_item	2620405	et	3	main
pireti	doc_491521502175_item	2620406	et	4	main
sõnul	doc_491521502175_item	2620407	et	3	main
õpivad	doc_491521502175_item	2620408	et	3	main
lapsed	doc_491521502175_item	2620409	et	3	main
poolpõlenud	doc_491521502175_item	2620410	et	4	main
raamatud	doc_491521502175_item	2620411	et	4	main
raamatuid	doc_491521502175_item	2620412	et	3	main
varsti	doc_491521502175_item	2620413	et	3	main
saatma	doc_491521502175_item	2620414	et	3	main
saadetakse	doc_491521502175_item	2620415	et	3	main
eestist	doc_491521502175_item	2620416	et	3	main
uued	doc_491521502175_item	2620417	et	3	main
õpikud	doc_491521502175_item	2620418	et	3	main
siberi	doc_491521502175_item	2620419	et	4	main
talve	doc_491521502175_item	2620420	et	4	main
toodi	doc_491521502175_item	2620428	et	4	main
praegu	doc_491521502175_item	2620430	et	3	main
soe	doc_491521502175_item	2620434	et	4	main
kuid	doc_491521502175_item	2620436	et	4	main
juba	doc_491521502175_item	2620438	et	3	main
jahe	doc_491521502175_item	2620439	et	3	main
jahedad	doc_491521502175_item	2620440	et	3	main
harjutan	doc_491521502175_item	2620441	et	3	main
juba	doc_491521502175_item	2620442	et	3	main
suure	doc_491521502175_item	2620443	et	3	main
vaja	doc_491521502175_item	2620449	et	4	main
külapoest	doc_491521502175_item	2620452	et	4	main
talveks	doc_491521502175_item	2620461	et	4	main
valmistunud	doc_491521502175_item	2620463	et	4	main
moodustage	doc_491521502175_item	2620470	et	3	main
sõnadest	doc_491521502175_item	2620472	et	3	main
laused	doc_491521502175_item	2620473	et	3	main
naeratus	doc_491521502175_item	2620482	et	4	main
naiselikum	doc_491521502175_item	2620485	et	4	main
ja	doc_491521502175_item	2620486	et	3	main
mehed	doc_491521502175_item	2620487	et	3	main
ja	doc_491521502175_item	2620497	et	3	main
kaunimaks	doc_491521502175_item	2620499	et	4	main
4	doc_491521502175_item	2620525	et	2	main
tohtima	doc_491521502175_item	2620527	et	3	main
laskma	doc_491521502175_item	2620528	et	3	main
ülekoormus	doc_491521502175_item	2620529	et	3	main
tekkima	doc_491521502175_item	2620530	et	3	main
pinge	doc_491521502175_item	2620531	et	4	main
kolmesaja	doc_491521502175_item	2620398	et	4	main
inimest	doc_491521502175_item	2620400	et	3	main
ei	doc_491521502175_item	2620422	et	4	main
talvepuud	doc_491521502175_item	2620429	et	4	main
vene	doc_491521502175_item	2620444	et	4	main
ahju	doc_491521502175_item	2620445	et	4	main
lühendatud	doc_491521502175_item	2620466	et	4	main
ajalehest	doc_491521502175_item	2620467	et	4	main
etteantud	doc_491521502175_item	2620471	et	4	main
sõnad	doc_491521502175_item	2620475	et	4	main
õigesse	doc_491521502175_item	2620476	et	3	main
vormi	doc_491521502175_item	2620477	et	4	main
ja	doc_491521502175_item	2620478	et	3	main
kasutades	doc_491521502175_item	2620479	et	3	main
mehelikum	doc_491521502175_item	2620488	et	4	main
igaüks	doc_491521502175_item	2620489	et	3	main
kaunim	doc_491521502175_item	2620490	et	4	main
3	doc_491521502175_item	2620500	et	2	main
paras	doc_491521502175_item	2620501	et	3	main
kogus	doc_491521502175_item	2620502	et	4	main
stress	doc_491521502175_item	2620503	et	3	main
panema	doc_491521502175_item	2620504	et	3	main
meie	doc_491521502175_item	2620505	et	4	main
tegutsema	doc_491521502175_item	2620506	et	3	main
aga	doc_491521502175_item	2620507	et	3	main
lisakoormus	doc_491521502175_item	2620508	et	3	main
võima	doc_491521502175_item	2620509	et	3	main
tooma	doc_491521502175_item	2620510	et	3	main
soovimatu	doc_491521502175_item	2620511	et	4	main
tagajärg	doc_491521502175_item	2620512	et	3	main
parajas	doc_491521502175_item	2620513	et	3	main
kogus	doc_491521502175_item	2620514	et	4	main
stress	doc_491521502175_item	2620515	et	3	main
paneb	doc_491521502175_item	2620516	et	3	main
meid	doc_491521502175_item	2620517	et	4	main
tegutsema	doc_491521502175_item	2620518	et	3	main
aga	doc_491521502175_item	2620519	et	3	main
lisakoormus	doc_491521502175_item	2620520	et	3	main
võib	doc_491521502175_item	2620521	et	3	main
soovimatu	doc_491521502175_item	2620523	et	4	main
maandama	doc_491521502175_item	2620533	et	3	main
ja	doc_491521502175_item	2620535	et	3	main
sportimise-	doc_491521502175_item	2620545	et	4	main
ülekoormusel	doc_491521502175_item	2620537	et	3	main
saama	doc_491521502175_item	2620552	et	4	main
nii	doc_491521502175_item	2620553	et	3	main
maagiline	doc_491521502175_item	2620554	et	4	main
abil	doc_491521502175_item	2620558	et	4	main
elama	doc_491521502175_item	2620560	et	3	main
telefon	doc_491521502175_item	2620563	et	3	main
nii	doc_491521502175_item	2620567	et	3	main
maagiliseks	doc_491521502175_item	2620568	et	4	main
aparaadiks	doc_491521502175_item	2620569	et	3	main
et	doc_491521502175_item	2620570	et	3	main
ja	doc_491521502175_item	2620575	et	3	main
telefonihelin	doc_491521502175_item	2620579	et	3	main
ka	doc_491521502175_item	2620581	et	3	main
segama	doc_491521502175_item	2620585	et	3	main
valmistamine	doc_491521502175_item	2620587	et	4	main
valmistamist	doc_491521502175_item	2620602	et	4	main
ja	doc_491521502175_item	2620603	et	3	main
vormi	doc_491521502175_item	2620617	et	4	main
1	doc_491521502175_item	2620618	et	2	main
ma	doc_491521502175_item	2620619	et	3	main
väga	doc_491521502175_item	2620621	et	3	main
oma	doc_491521502175_item	2620623	et	4	main
2	doc_491521502175_item	2620636	et	2	main
nõuetega	doc_491521502175_item	2620640	et	4	main
sa	doc_491521502175_item	2620645	et	3	main
sport	doc_491521502175_item	2620647	et	3	main
aga	doc_491521502175_item	2620649	et	3	main
ainult	doc_491521502175_item	2620653	et	4	main
naised	doc_491521502175_item	2620655	et	3	main
kiired	doc_491521502175_item	2620657	et	4	main
5	doc_491521502175_item	2620672	et	2	main
tüdinesin	doc_491521502175_item	2620673	et	3	main
uus	doc_491521502175_item	2620674	et	3	main
töökoht	doc_491521502175_item	2620675	et	3	main
selles	doc_491521502175_item	2620681	et	4	main
9	doc_491521502175_item	2620701	et	2	main
ajal	doc_491521502175_item	2620703	et	4	main
kuid	doc_491521502175_item	2620725	et	4	main
õpetajad	doc_491521502175_item	2620736	et	4	main
3	doc_491521502175_item	2620737	et	2	main
lapsel	doc_491521502175_item	2620738	et	4	main
paluti	doc_491521502175_item	2620739	et	3	main
oodata	doc_491521502175_item	2620740	et	4	main
kui	doc_491521502175_item	2620741	et	3	main
vanemad	doc_491521502175_item	2620742	et	4	main
tagasi	doc_491521502175_item	2620743	et	3	main
naeru	doc_491521502175_item	2620748	et	4	main
oleks	doc_491521502175_item	2620750	et	3	main
just	doc_491521502175_item	2620752	et	3	main
rääkinud	doc_491521502175_item	2620754	et	4	main
vaid	doc_491521502175_item	2620760	et	3	main
läheb	doc_491521502175_item	2620761	et	3	main
lõpetage	doc_491521502175_item	2620765	et	3	main
jalutama	doc_491521502175_item	2620769	et	3	main
alkoholi	doc_491521502175_item	2620777	et	4	main
8	doc_491521502175_item	2620779	et	2	main
nägema	doc_491521502176_item	2620821	et	3	main
kuulutust	doc_491521502176_item	2620826	et	4	main
siberisse	doc_491521502176_item	2620828	et	4	main
küla	doc_491521502176_item	2620830	et	4	main
külla	doc_491521502176_item	2620831	et	4	main
otsitakse	doc_491521502176_item	2620832	et	3	main
eestlastele	doc_491521502176_item	2620848	et	4	main
siberisse	doc_491521502176_item	2620858	et	4	main
siber	doc_491521502176_item	2620878	et	4	main
selline	doc_491521502176_item	2620880	et	4	main
pilt	doc_491521502176_item	2620881	et	3	main
et	doc_491521502176_item	2620882	et	3	main
rohi	doc_491521502176_item	2620890	et	4	main
noor	doc_491521502176_item	2620892	et	3	main
algust	doc_491521502176_item	2620900	et	4	main
kohta	doc_491521502176_item	2620902	et	4	main
aparaat	doc_491521502175_item	2620555	et	3	main
selle	doc_491521502175_item	2620571	et	4	main
hingaks	doc_491521502175_item	2620576	et	3	main
kuid	doc_491521502175_item	2620578	et	4	main
katkestama	doc_491521502175_item	2620580	et	3	main
varahommik	doc_491521502175_item	2620583	et	3	main
söömine	doc_491521502175_item	2620589	et	4	main
pahandab	doc_491521502175_item	2620590	et	3	main
huvitav	doc_491521502175_item	2620591	et	4	main
söömist	doc_491521502175_item	2620604	et	4	main
kuid	doc_491521502175_item	2620605	et	4	main
ka	doc_491521502175_item	2620606	et	3	main
pange	doc_491521502175_item	2620612	et	4	main
olevad	doc_491521502175_item	2620614	et	4	main
sõnad	doc_491521502175_item	2620615	et	4	main
õigesse	doc_491521502175_item	2620616	et	3	main
vanematest	doc_491521502175_item	2620626	et	4	main
sest	doc_491521502175_item	2620627	et	4	main
nad	doc_491521502175_item	2620628	et	3	main
aitavad	doc_491521502175_item	2620629	et	4	main
kõik	doc_491521502175_item	2620630	et	4	main
igaüht	doc_491521502175_item	2620635	et	3	main
ma	doc_491521502175_item	2620642	et	3	main
et	doc_491521502175_item	2620644	et	3	main
huvitud	doc_491521502175_item	2620646	et	4	main
ilusate	doc_491521502175_item	2620659	et	3	main
autode	doc_491521502175_item	2620663	et	3	main
piirdusime	doc_491521502175_item	2620680	et	3	main
vaid	doc_491521502175_item	2620683	et	3	main
kleepus	doc_491521502175_item	2620698	et	3	main
1	doc_491521502175_item	2620721	et	2	main
2	doc_491521502175_item	2620729	et	2	main
kõrvallauast	doc_491521502175_item	2620746	et	4	main
nagu	doc_491521502175_item	2620749	et	3	main
tule	doc_491521502175_item	2620758	et	4	main
trenni	doc_491521502175_item	2620759	et	4	main
hoopis	doc_491521502175_item	2620762	et	3	main
6	doc_491521502175_item	2620764	et	2	main
lähete	doc_491521502175_item	2620768	et	4	main
suitsetada	doc_491521502175_item	2620775	et	3	main
nägi	doc_491521502176_item	2620822	et	3	main
eesti	doc_491521502176_item	2620833	et	4	main
keele	doc_491521502176_item	2620834	et	4	main
emakeelt	doc_491521502176_item	2620851	et	4	main
õpetanud	doc_491521502176_item	2620853	et	4	main
kinnitusel	doc_491521502176_item	2620855	et	4	main
ta	doc_491521502176_item	2620857	et	4	main
üllatuma	doc_491521502176_item	2620866	et	3	main
tulema	doc_491521502176_item	2620870	et	4	main
maaliti	doc_491521502176_item	2620877	et	3	main
siberi	doc_491521502176_item	2620879	et	4	main
tahtmine	doc_491521502176_item	2620894	et	4	main
ettevõtmine	doc_491521502176_item	2620921	et	3	main
kartul	doc_491521502176_item	2620924	et	3	main
teistmoodi	doc_491521502176_item	2620936	et	3	main
vene	doc_491521502176_item	2620944	et	4	main
venemaa	doc_491521502176_item	2620954	et	4	main
ülejäänud	doc_491521502176_item	2620957	et	4	main
õpetatakse	doc_491521502176_item	2620960	et	3	main
inimene	doc_491521502176_item	2620968	et	3	main
kõik	doc_491521502176_item	2620972	et	4	main
kõike	doc_491521502176_item	2620973	et	4	main
rääkida	doc_491521502176_item	2620974	et	3	main
pireti	doc_491521502176_item	2620975	et	4	main
sõnul	doc_491521502176_item	2620976	et	3	main
õpivad	doc_491521502176_item	2620977	et	3	main
lapsed	doc_491521502176_item	2620978	et	3	main
saatma	doc_491521502176_item	2620983	et	3	main
uued	doc_491521502176_item	2620986	et	3	main
mulle	doc_491521502176_item	2620994	et	4	main
talvepuud	doc_491521502176_item	2620998	et	4	main
soojad	doc_491521502176_item	2621004	et	3	main
jahedad	doc_491521502176_item	2621009	et	3	main
varahommikul	doc_491521502175_item	2620598	et	3	main
pahandab	doc_491521502175_item	2620607	et	3	main
iv	doc_491521502175_item	2620611	et	4	main
sulgudes	doc_491521502175_item	2620613	et	4	main
usaldavad	doc_491521502175_item	2620633	et	4	main
artikli	doc_491521502175_item	2620638	et	3	main
nõuded	doc_491521502175_item	2620639	et	3	main
huvi	doc_491521502175_item	2620652	et	4	main
ja	doc_491521502175_item	2620656	et	3	main
autod	doc_491521502175_item	2620658	et	3	main
ja	doc_491521502175_item	2620661	et	3	main
4	doc_491521502175_item	2620665	et	2	main
haigestuda	doc_491521502175_item	2620669	et	3	main
difteeriat	doc_491521502175_item	2620671	et	3	main
töökohast	doc_491521502175_item	2620677	et	4	main
kiiresti	doc_491521502175_item	2620678	et	3	main
teise	doc_491521502175_item	2620694	et	4	main
valdkonda	doc_491521502175_item	2620695	et	4	main
8	doc_491521502175_item	2620696	et	2	main
närimiskumm	doc_491521502175_item	2620697	et	3	main
tellisime	doc_491521502175_item	2620722	et	4	main
maksis	doc_491521502175_item	2620727	et	4	main
4	doc_491521502175_item	2620745	et	2	main
anekdooti	doc_491521502175_item	2620753	et	4	main
5	doc_491521502175_item	2620755	et	2	main
ta	doc_491521502175_item	2620756	et	4	main
teatrisse	doc_491521502175_item	2620763	et	3	main
ega	doc_491521502175_item	2620776	et	3	main
tarbida	doc_491521502175_item	2620778	et	3	main
töötasid	doc_491521502175_item	2620781	et	4	main
ta	doc_491521502176_item	2620823	et	4	main
et	doc_491521502176_item	2620827	et	3	main
õpetajat	doc_491521502176_item	2620835	et	4	main
nende	doc_491521502176_item	2620850	et	4	main
õpetama	doc_491521502176_item	2620852	et	3	main
pireti	doc_491521502176_item	2620854	et	4	main
tundis	doc_491521502176_item	2620856	et	3	main
et	doc_491521502176_item	2620861	et	3	main
kui	doc_491521502176_item	2620868	et	3	main
mulle	doc_491521502176_item	2620869	et	4	main
audiga	doc_491521502176_item	2620875	et	3	main
ei	doc_491521502176_item	2620884	et	4	main
lind	doc_491521502176_item	2620887	et	3	main
ega	doc_491521502176_item	2620888	et	3	main
ja	doc_491521502176_item	2620926	et	3	main
täie	doc_491521502176_item	2620929	et	3	main
siinsed	doc_491521502176_item	2620932	et	3	main
kuidagi	doc_491521502176_item	2620935	et	3	main
mõnus	doc_491521502176_item	2620937	et	4	main
aktsent	doc_491521502176_item	2620945	et	3	main
mõni	doc_491521502176_item	2620949	et	3	main
kool	doc_491521502176_item	2620951	et	4	main
on	doc_491521502176_item	2620952	et	4	main
siiski	doc_491521502176_item	2620953	et	4	main
aine	doc_491521502176_item	2620958	et	4	main
aineid	doc_491521502176_item	2620959	et	3	main
külas	doc_491521502176_item	2620963	et	3	main
elab	doc_491521502176_item	2620964	et	3	main
saab	doc_491521502176_item	2620971	et	3	main
raamatudega	doc_491521502176_item	2620981	et	4	main
õpikud	doc_491521502176_item	2620987	et	3	main
talve	doc_491521502176_item	2620989	et	4	main
juba	doc_491521502176_item	2620995	et	3	main
tooti	doc_491521502176_item	2620997	et	4	main
praegu	doc_491521502176_item	2620999	et	3	main
kuid	doc_491521502176_item	2621005	et	4	main
harjutan	doc_491521502176_item	2621010	et	3	main
külapoest	doc_491521502176_item	2621021	et	4	main
piret	doc_491521502176_item	2621033	et	4	main
iii	doc_491521502176_item	2621038	et	4	main
moodustage	doc_491521502176_item	2621039	et	3	main
sõnad	doc_491521502176_item	2621044	et	4	main
tegema	doc_491521502176_item	2621052	et	3	main
mehed	doc_491521502176_item	2621056	et	3	main
kaunim	doc_491521502176_item	2621059	et	4	main
naeratus	doc_491521502176_item	2621060	et	4	main
teeb	doc_491521502176_item	2621061	et	3	main
naisi	doc_491521502176_item	2621062	et	3	main
naiselikum	doc_491521502176_item	2621063	et	4	main
ja	doc_491521502176_item	2621064	et	3	main
mehi	doc_491521502176_item	2621065	et	3	main
lisakoormus	doc_491521502176_item	2621089	et	3	main
und	doc_491521502175_item	2620599	et	4	main
segab	doc_491521502175_item	2620600	et	3	main
lõunasööki	doc_491521502175_item	2620601	et	4	main
huvitava	doc_491521502175_item	2620608	et	4	main
telesaade	doc_491521502175_item	2620609	et	4	main
pean	doc_491521502175_item	2620620	et	4	main
vanemad	doc_491521502175_item	2620624	et	4	main
oma	doc_491521502175_item	2620625	et	4	main
kõiki	doc_491521502175_item	2620631	et	4	main
ja	doc_491521502175_item	2620632	et	3	main
kohandasin	doc_491521502175_item	2620637	et	3	main
3	doc_491521502175_item	2620641	et	2	main
tunned	doc_491521502175_item	2620651	et	3	main
vastu	doc_491521502175_item	2620664	et	3	main
on	doc_491521502175_item	2620667	et	4	main
väikeste	doc_491521502175_item	2620686	et	4	main
muudatustega	doc_491521502175_item	2620687	et	3	main
püksid	doc_491521502175_item	2620699	et	3	main
lugu	doc_491521502175_item	2620622	et	4	main
igaüks	doc_491521502175_item	2620634	et	3	main
arvasin	doc_491521502175_item	2620643	et	3	main
spordist	doc_491521502175_item	2620648	et	3	main
sa	doc_491521502175_item	2620650	et	3	main
ilusad	doc_491521502175_item	2620654	et	3	main
naiste	doc_491521502175_item	2620660	et	3	main
kiirte	doc_491521502175_item	2620662	et	3	main
praegu	doc_491521502175_item	2620666	et	3	main
oht	doc_491521502175_item	2620668	et	3	main
difteeria	doc_491521502175_item	2620670	et	4	main
uuest	doc_491521502175_item	2620676	et	3	main
6	doc_491521502175_item	2620679	et	2	main
küsimuses	doc_491521502175_item	2620682	et	4	main
väikesed	doc_491521502175_item	2620684	et	4	main
muudatused	doc_491521502175_item	2620685	et	3	main
7	doc_491521502175_item	2620688	et	2	main
see	doc_491521502175_item	2620689	et	3	main
küsimus	doc_491521502175_item	2620690	et	4	main
kuulub	doc_491521502175_item	2620691	et	3	main
teine	doc_491521502175_item	2620692	et	3	main
valdkond	doc_491521502175_item	2620693	et	3	main
pükstele	doc_491521502175_item	2620700	et	3	main
külmal	doc_491521502175_item	2620702	et	3	main
peab	doc_491521502175_item	2620704	et	4	main
hoiduma	doc_491521502175_item	2620705	et	3	main
külmetamine	doc_491521502175_item	2620706	et	4	main
külmetamisest	doc_491521502175_item	2620707	et	4	main
10	doc_491521502175_item	2620708	et	2	main
ma	doc_491521502175_item	2620709	et	3	main
tunnen	doc_491521502175_item	2620710	et	3	main
rõõmu	doc_491521502175_item	2620711	et	4	main
suvine	doc_491521502175_item	2620712	et	4	main
päike	doc_491521502175_item	2620713	et	3	main
suvisest	doc_491521502175_item	2620714	et	4	main
v	doc_491521502175_item	2620716	et	4	main
täitke	doc_491521502175_item	2620717	et	3	main
päikesest	doc_491521502175_item	2620715	et	4	main
lüngad	doc_491521502175_item	2620718	et	3	main
sobivate	doc_491521502175_item	2620719	et	4	main
sidenditega	doc_491521502175_item	2620720	et	3	main
lõuna	doc_491521502175_item	2620724	et	4	main
see	doc_491521502175_item	2620726	et	3	main
palju	doc_491521502175_item	2620728	et	4	main
kohal	doc_491521502175_item	2620730	et	4	main
olid	doc_491521502175_item	2620731	et	4	main
nii	doc_491521502175_item	2620732	et	3	main
õpilased	doc_491521502175_item	2620733	et	3	main
kui	doc_491521502175_item	2620734	et	3	main
ka	doc_491521502175_item	2620735	et	3	main
tulevad	doc_491521502175_item	2620744	et	4	main
keegi	doc_491521502175_item	2620751	et	4	main
töö	doc_491521502175_item	2620766	et	4	main
tohi	doc_491521502175_item	2620774	et	4	main
nad	doc_491521502175_item	2620780	et	3	main
küll	doc_491521502175_item	2620782	et	4	main
ajalehes	doc_491521502176_item	2620824	et	3	main
ülem-suetuki	doc_491521502176_item	2620829	et	4	main
piret	doc_491521502176_item	2620836	et	4	main
võitis	doc_491521502176_item	2620837	et	3	main
konkurss	doc_491521502176_item	2620838	et	3	main
konkursi	doc_491521502176_item	2620839	et	3	main
ja	doc_491521502176_item	2620840	et	3	main
on	doc_491521502176_item	2620841	et	4	main
kolmekäigulise	doc_491521502175_item	2620723	et	4	main
kostis	doc_491521502175_item	2620747	et	4	main
ei	doc_491521502175_item	2620757	et	4	main
siis	doc_491521502175_item	2620767	et	3	main
7	doc_491521502175_item	2620770	et	2	main
selles	doc_491521502175_item	2620771	et	4	main
baaris	doc_491521502175_item	2620772	et	3	main
ei	doc_491521502175_item	2620773	et	4	main
pingsalt	doc_491521502175_item	2620783	et	4	main
aga	doc_491521502175_item	2620784	et	3	main
tulemust	doc_491521502175_item	2620785	et	4	main
ei	doc_491521502175_item	2620786	et	4	main
olnud	doc_491521502175_item	2620787	et	4	main
9	doc_491521502175_item	2620788	et	2	main
kas	doc_491521502175_item	2620789	et	3	main
sa	doc_491521502175_item	2620790	et	3	main
sõidad	doc_491521502175_item	2620791	et	3	main
maale	doc_491521502175_item	2620792	et	4	main
või	doc_491521502175_item	2620793	et	4	main
jääd	doc_491521502175_item	2620794	et	4	main
linna	doc_491521502175_item	2620795	et	4	main
10	doc_491521502175_item	2620796	et	2	main
avasin	doc_491521502175_item	2620797	et	3	main
ukse	doc_491521502175_item	2620798	et	3	main
kui	doc_491521502175_item	2620799	et	3	main
kuulsin	doc_491521502175_item	2620800	et	3	main
koputust	doc_491521502175_item	2620801	et	4	main
eesti	doc_491521502176_item	2620802	et	4	main
keele	doc_491521502176_item	2620803	et	4	main
test	doc_491521502176_item	2620804	et	3	main
eesti	doc_491521502176_item	2620805	et	4	main
keele	doc_491521502176_item	2620806	et	4	main
test	doc_491521502176_item	2620807	et	3	main
i	doc_491521502176_item	2620808	et	4	main
pange	doc_491521502176_item	2620809	et	4	main
sulgudes	doc_491521502176_item	2620810	et	4	main
olevad	doc_491521502176_item	2620811	et	4	main
sõnad	doc_491521502176_item	2620812	et	4	main
õigesse	doc_491521502176_item	2620813	et	3	main
vormi	doc_491521502176_item	2620814	et	4	main
piret	doc_491521502176_item	2620815	et	4	main
toomet	doc_491521502176_item	2620816	et	4	main
on	doc_491521502176_item	2620817	et	4	main
ettevõtlik	doc_491521502176_item	2620818	et	3	main
naine	doc_491521502176_item	2620819	et	3	main
suvel	doc_491521502176_item	2620820	et	3	main
kuulutus	doc_491521502176_item	2620825	et	4	main
nüüd	doc_491521502176_item	2620842	et	4	main
juba	doc_491521502176_item	2620843	et	3	main
üle	doc_491521502176_item	2620844	et	3	main
nädal	doc_491521502176_item	2620845	et	3	main
nädala	doc_491521502176_item	2620846	et	3	main
väikestele	doc_491521502176_item	2620847	et	4	main
jõudmisel	doc_491521502176_item	2620860	et	4	main
üllatunud	doc_491521502176_item	2620867	et	4	main
vastu	doc_491521502176_item	2620872	et	3	main
korralik	doc_491521502176_item	2620873	et	3	main
seal	doc_491521502176_item	2620883	et	4	main
kasva	doc_491521502176_item	2620889	et	4	main
ja	doc_491521502176_item	2620893	et	3	main
täis	doc_491521502176_item	2620896	et	4	main
pärast	doc_491521502176_item	2620898	et	4	main
õppeaasta	doc_491521502176_item	2620899	et	4	main
jõudis	doc_491521502176_item	2620903	et	3	main
polnud	doc_491521502176_item	2620904	et	3	main
kool	doc_491521502176_item	2620905	et	4	main
veel	doc_491521502176_item	2620906	et	4	main
algama	doc_491521502176_item	2620907	et	3	main
alganud	doc_491521502176_item	2620908	et	4	main
kogu	doc_491521502176_item	2620909	et	4	main
küla	doc_491521502176_item	2620910	et	4	main
võtma	doc_491521502176_item	2620911	et	3	main
võttis	doc_491521502176_item	2620912	et	3	main
kartuleid	doc_491521502176_item	2620913	et	3	main
kartulivõtt	doc_491521502176_item	2620914	et	3	main
on	doc_491521502176_item	2620915	et	4	main
siin	doc_491521502176_item	2620916	et	4	main
sügisel	doc_491521502176_item	2620917	et	3	main
kõige	doc_491521502176_item	2620918	et	4	main
tähtis	doc_491521502176_item	2620919	et	4	main
tähtsam	doc_491521502176_item	2620920	et	4	main
salv	doc_491521502176_item	2620925	et	3	main
käib	doc_491521502176_item	2620928	et	3	main
hoog	doc_491521502176_item	2620930	et	3	main
ja	doc_491521502176_item	2620938	et	3	main
mõnusalt	doc_491521502176_item	2620940	et	4	main
ja	doc_491521502176_item	2620941	et	3	main
mahlakalt	doc_491521502176_item	2620942	et	4	main
mitte	doc_491521502176_item	2620943	et	3	main
nagu	doc_491521502176_item	2620948	et	3	main
kool	doc_491521502176_item	2620955	et	4	main
keeles	doc_491521502176_item	2620962	et	4	main
veidi	doc_491521502176_item	2620965	et	3	main
poolpõlenud	doc_491521502176_item	2620979	et	4	main
piret	doc_491521502176_item	2620990	et	4	main
ei	doc_491521502176_item	2620991	et	4	main
kartma	doc_491521502176_item	2620992	et	3	main
tooma	doc_491521502176_item	2620996	et	3	main
ööd	doc_491521502176_item	2621006	et	4	main
jahe	doc_491521502176_item	2621008	et	3	main
suurt	doc_491521502176_item	2621025	et	3	main
naerab	doc_491521502176_item	2621029	et	3	main
etteantud	doc_491521502176_item	2621040	et	4	main
sõnadest	doc_491521502176_item	2621041	et	3	main
laused	doc_491521502176_item	2621042	et	3	main
kirjavahemärke	doc_491521502176_item	2621049	et	4	main
naeratus	doc_491521502176_item	2621051	et	4	main
mehelikum	doc_491521502176_item	2621057	et	4	main
igaühte	doc_491521502176_item	2621067	et	4	main
need	doc_491521502176_item	2620849	et	3	main
jõudma	doc_491521502176_item	2620859	et	3	main
on	doc_491521502176_item	2620862	et	4	main
oodatud	doc_491521502176_item	2620863	et	4	main
olin	doc_491521502176_item	2620864	et	3	main
üsna	doc_491521502176_item	2620865	et	3	main
tuli	doc_491521502176_item	2620871	et	4	main
korraliku	doc_491521502176_item	2620874	et	3	main
mulle	doc_491521502176_item	2620876	et	4	main
lendama	doc_491521502176_item	2620885	et	3	main
lenda	doc_491521502176_item	2620886	et	4	main
kui	doc_491521502176_item	2620891	et	3	main
tahtmist	doc_491521502176_item	2620895	et	4	main
piret	doc_491521502176_item	2620897	et	4	main
koht	doc_491521502176_item	2620901	et	3	main
on	doc_491521502176_item	2620923	et	4	main
mahlakas	doc_491521502176_item	2620939	et	4	main
aktsendiga	doc_491521502176_item	2620946	et	3	main
murret	doc_491521502176_item	2620950	et	4	main
ja	doc_491521502176_item	2620956	et	3	main
kolmsada	doc_491521502176_item	2620967	et	4	main
emakeelt	doc_491521502176_item	2620970	et	4	main
raamatud	doc_491521502176_item	2620980	et	4	main
saadavad	doc_491521502176_item	2620984	et	4	main
siberi	doc_491521502176_item	2620988	et	4	main
karda	doc_491521502176_item	2620993	et	4	main
soe	doc_491521502176_item	2621003	et	4	main
juba	doc_491521502176_item	2621011	et	3	main
vildid	doc_491521502176_item	2621022	et	4	main
muud	doc_491521502176_item	2621026	et	4	main
müüdagi	doc_491521502176_item	2621028	et	3	main
talveks	doc_491521502176_item	2621030	et	4	main
valmistuma	doc_491521502176_item	2621031	et	3	main
valmistunud	doc_491521502176_item	2621032	et	4	main
slõhtuleht	doc_491521502176_item	2621037	et	4	main
vormi	doc_491521502176_item	2621046	et	4	main
paras	doc_491521502176_item	2621070	et	3	main
aga	doc_491521502176_item	2621088	et	3	main
4	doc_491521502176_item	2621094	et	2	main
tohtima	doc_491521502176_item	2621096	et	3	main
tekkima	doc_491521502176_item	2621099	et	3	main
tohi	doc_491521502176_item	2621107	et	4	main
hingama	doc_491521502176_item	2621131	et	3	main
telefon	doc_491521502176_item	2621132	et	3	main
on	doc_491521502176_item	2621133	et	4	main
tänapäevaks	doc_491521502176_item	2621134	et	3	main
aparaadikset	doc_491521502176_item	2621138	et	4	main
elada	doc_491521502176_item	2621142	et	3	main
hingata	doc_491521502176_item	2621144	et	4	main
telefonihelin	doc_491521502176_item	2621147	et	3	main
katkestama	doc_491521502176_item	2621148	et	3	main
ka	doc_491521502176_item	2621149	et	3	main
uni	doc_491521502176_item	2621152	et	3	main
ja	doc_491521502176_item	2621156	et	3	main
pahandab	doc_491521502176_item	2621175	et	3	main
pange	doc_491521502176_item	2621181	et	4	main
ma	doc_491521502176_item	2621188	et	3	main
pean	doc_491521502176_item	2621189	et	4	main
vanemaid	doc_491521502176_item	2621195	et	4	main
sest	doc_491521502176_item	2621196	et	4	main
ma	doc_491521502176_item	2621211	et	3	main
arvasin	doc_491521502176_item	2621212	et	3	main
spordiga	doc_491521502176_item	2621217	et	3	main
tunned	doc_491521502176_item	2621220	et	3	main
kiired	doc_491521502176_item	2621226	et	4	main
ilusate	doc_491521502176_item	2621228	et	3	main
ja	doc_491521502176_item	2621230	et	3	main
praegu	doc_491521502176_item	2621234	et	3	main
tüdinesin	doc_491521502176_item	2621241	et	3	main
töökohta	doc_491521502176_item	2621245	et	4	main
piirdusime	doc_491521502176_item	2621248	et	3	main
küsimuses	doc_491521502176_item	2621250	et	4	main
külmetamine	doc_491521502176_item	2621274	et	4	main
tunnen	doc_491521502176_item	2621278	et	3	main
rõõmu	doc_491521502176_item	2621279	et	4	main
suvine	doc_491521502176_item	2621280	et	4	main
päike	doc_491521502176_item	2621281	et	3	main
sobivate	doc_491521502176_item	2621287	et	4	main
aga	doc_491521502176_item	2621293	et	3	main
maksis	doc_491521502176_item	2621295	et	4	main
vanemad	doc_491521502176_item	2621309	et	4	main
tänaseks	doc_491521502176_item	2620922	et	4	main
õppimine	doc_491521502176_item	2620927	et	4	main
hooga	doc_491521502176_item	2620931	et	3	main
eestlased	doc_491521502176_item	2620933	et	3	main
räägivad	doc_491521502176_item	2620934	et	3	main
vaid	doc_491521502176_item	2620947	et	3	main
vene	doc_491521502176_item	2620961	et	4	main
üle	doc_491521502176_item	2620966	et	3	main
inimest	doc_491521502176_item	2620969	et	3	main
varsti	doc_491521502176_item	2620982	et	3	main
eestist	doc_491521502176_item	2620985	et	3	main
on	doc_491521502176_item	2621000	et	4	main
päevad	doc_491521502176_item	2621001	et	3	main
veel	doc_491521502176_item	2621002	et	4	main
juba	doc_491521502176_item	2621007	et	3	main
suure	doc_491521502176_item	2621012	et	3	main
vene	doc_491521502176_item	2621013	et	4	main
ahju	doc_491521502176_item	2621014	et	4	main
kütmine	doc_491521502176_item	2621015	et	4	main
kütida	doc_491521502176_item	2621016	et	4	main
kui	doc_491521502176_item	2621017	et	3	main
vaja	doc_491521502176_item	2621018	et	4	main
ostan	doc_491521502176_item	2621019	et	3	main
külapood	doc_491521502176_item	2621020	et	3	main
ega	doc_491521502176_item	2621023	et	3	main
lühendatud	doc_491521502176_item	2621035	et	4	main
ajalehest	doc_491521502176_item	2621036	et	4	main
pannes	doc_491521502176_item	2621043	et	4	main
ja	doc_491521502176_item	2621047	et	3	main
naiselikum	doc_491521502176_item	2621054	et	4	main
ja	doc_491521502176_item	2621055	et	3	main
mehelikum	doc_491521502176_item	2621066	et	4	main
kogus	doc_491521502176_item	2621071	et	4	main
panema	doc_491521502176_item	2621073	et	3	main
tooma	doc_491521502176_item	2621079	et	3	main
tagajärg	doc_491521502176_item	2621081	et	3	main
võib	doc_491521502176_item	2621090	et	3	main
ei	doc_491521502176_item	2621095	et	4	main
pinge	doc_491521502176_item	2621100	et	4	main
saama	doc_491521502176_item	2621101	et	4	main
maandama	doc_491521502176_item	2621102	et	3	main
maagiline	doc_491521502176_item	2621123	et	4	main
et	doc_491521502176_item	2621125	et	3	main
lausa	doc_491521502176_item	2621141	et	4	main
kuid	doc_491521502176_item	2621146	et	4	main
pühapäev	doc_491521502176_item	2621150	et	3	main
valmistada	doc_491521502176_item	2621172	et	3	main
vormi	doc_491521502176_item	2621186	et	4	main
lugu	doc_491521502176_item	2621191	et	4	main
oma	doc_491521502176_item	2621192	et	4	main
vanemad	doc_491521502176_item	2621193	et	4	main
nad	doc_491521502176_item	2621197	et	3	main
kõike	doc_491521502176_item	2621200	et	4	main
sa	doc_491521502176_item	2621214	et	3	main
seal	doc_491521502176_item	2621024	et	4	main
ei	doc_491521502176_item	2621027	et	4	main
vapralt	doc_491521502176_item	2621034	et	4	main
õigesse	doc_491521502176_item	2621045	et	3	main
kasutades	doc_491521502176_item	2621048	et	3	main
2	doc_491521502176_item	2621050	et	2	main
naised	doc_491521502176_item	2621053	et	3	main
igaüks	doc_491521502176_item	2621058	et	3	main
stress	doc_491521502176_item	2621072	et	3	main
meie	doc_491521502176_item	2621074	et	4	main
aga	doc_491521502176_item	2621076	et	3	main
võima	doc_491521502176_item	2621078	et	3	main
kogus	doc_491521502176_item	2621083	et	4	main
stress	doc_491521502176_item	2621084	et	3	main
paneb	doc_491521502176_item	2621085	et	3	main
meid	doc_491521502176_item	2621086	et	4	main
tegutsema	doc_491521502176_item	2621087	et	3	main
sportima	doc_491521502176_item	2621103	et	4	main
ja	doc_491521502176_item	2621104	et	3	main
puhkama	doc_491521502176_item	2621105	et	3	main
ei	doc_491521502176_item	2621106	et	4	main
ülekoormust	doc_491521502176_item	2621109	et	4	main
tekkida	doc_491521502176_item	2621110	et	3	main
pinge	doc_491521502176_item	2621111	et	4	main
saab	doc_491521502176_item	2621112	et	3	main
maandata	doc_491521502176_item	2621113	et	3	main
spordiga	doc_491521502176_item	2621114	et	3	main
ja	doc_491521502176_item	2621115	et	3	main
puhkusega	doc_491521502176_item	2621116	et	3	main
5	doc_491521502176_item	2621117	et	2	main
telefon	doc_491521502176_item	2621118	et	3	main
olema	doc_491521502176_item	2621119	et	4	main
tänapäev	doc_491521502176_item	2621120	et	3	main
kaunim	doc_491521502176_item	2621068	et	4	main
3	doc_491521502176_item	2621069	et	2	main
tegutsema	doc_491521502176_item	2621075	et	3	main
lisakoormus	doc_491521502176_item	2621077	et	3	main
soovimatu	doc_491521502176_item	2621080	et	4	main
paras	doc_491521502176_item	2621082	et	3	main
tuua	doc_491521502176_item	2621091	et	3	main
tagajärje	doc_491521502176_item	2621093	et	3	main
laskma	doc_491521502176_item	2621097	et	3	main
ülekoormus	doc_491521502176_item	2621098	et	3	main
saama	doc_491521502176_item	2621121	et	4	main
see	doc_491521502176_item	2621126	et	3	main
maagiliseks	doc_491521502176_item	2621137	et	4	main
ja	doc_491521502176_item	2621143	et	3	main
lõunasöök	doc_491521502176_item	2621154	et	3	main
valmistamine	doc_491521502176_item	2621155	et	4	main
söömine	doc_491521502176_item	2621157	et	4	main
pahandab	doc_491521502176_item	2621158	et	3	main
sõnad	doc_491521502176_item	2621184	et	4	main
oma	doc_491521502176_item	2621194	et	4	main
aitavad	doc_491521502176_item	2621198	et	4	main
igaüks	doc_491521502176_item	2621203	et	3	main
huvitud	doc_491521502176_item	2621215	et	4	main
sa	doc_491521502176_item	2621219	et	3	main
huvi	doc_491521502176_item	2621221	et	4	main
ja	doc_491521502176_item	2621225	et	3	main
autodesse	doc_491521502176_item	2621232	et	3	main
uue	doc_491521502176_item	2621244	et	3	main
selles	doc_491521502176_item	2621249	et	4	main
vaid	doc_491521502176_item	2621251	et	3	main
väikesed	doc_491521502176_item	2621252	et	4	main
see	doc_491521502176_item	2621257	et	3	main
teine	doc_491521502176_item	2621260	et	3	main
peab	doc_491521502176_item	2621272	et	4	main
10	doc_491521502176_item	2621276	et	2	main
ma	doc_491521502176_item	2621277	et	3	main
lõuna	doc_491521502176_item	2621292	et	4	main
2	doc_491521502176_item	2621297	et	2	main
kohal	doc_491521502176_item	2621298	et	4	main
olid	doc_491521502176_item	2621299	et	4	main
ka	doc_491521502176_item	2621300	et	3	main
õpilased	doc_491521502176_item	2621301	et	3	main
ja	doc_491521502176_item	2621302	et	3	main
tagasi	doc_491521502176_item	2621310	et	3	main
tule	doc_491521502176_item	2621325	et	4	main
trenni	doc_491521502176_item	2621326	et	4	main
6	doc_491521502176_item	2621331	et	2	main
töö	doc_491521502176_item	2621333	et	4	main
ja	doc_491521502176_item	2621343	et	3	main
nad	doc_491521502176_item	2621347	et	3	main
küll	doc_491521502176_item	2621349	et	4	main
maale	doc_491521502176_item	2621359	et	4	main
linna	doc_491521502176_item	2621362	et	4	main
keele	doc_491521502177_item	2621373	et	4	main
test	doc_491521502177_item	2621374	et	3	main
juba	doc_491521502177_item	2621410	et	3	main
nädalat	doc_491521502177_item	2621413	et	3	main
väikestele	doc_491521502177_item	2621414	et	4	main
eestlastele	doc_491521502177_item	2621415	et	4	main
need	doc_491521502177_item	2621416	et	3	main
soovimatu	doc_491521502176_item	2621092	et	4	main
lasta	doc_491521502176_item	2621108	et	4	main
nii	doc_491521502176_item	2621122	et	3	main
aparaat	doc_491521502176_item	2621124	et	3	main
abil	doc_491521502176_item	2621127	et	4	main
lausa	doc_491521502176_item	2621128	et	4	main
elama	doc_491521502176_item	2621129	et	3	main
ja	doc_491521502176_item	2621130	et	3	main
abil	doc_491521502176_item	2621140	et	4	main
segama	doc_491521502176_item	2621153	et	3	main
iv	doc_491521502176_item	2621180	et	4	main
õigesse	doc_491521502176_item	2621185	et	3	main
väga	doc_491521502176_item	2621190	et	3	main
kõik	doc_491521502176_item	2621199	et	4	main
ja	doc_491521502176_item	2621201	et	3	main
usaldavad	doc_491521502176_item	2621202	et	4	main
sport	doc_491521502176_item	2621216	et	3	main
ainult	doc_491521502176_item	2621222	et	4	main
ilusad	doc_491521502176_item	2621223	et	3	main
on	doc_491521502176_item	2621235	et	4	main
haigestuda	doc_491521502176_item	2621237	et	3	main
difteeriaga	doc_491521502176_item	2621239	et	3	main
uus	doc_491521502176_item	2621242	et	3	main
6	doc_491521502176_item	2621247	et	2	main
muudatuseid	doc_491521502176_item	2621255	et	4	main
kuulub	doc_491521502176_item	2621259	et	3	main
valdkond	doc_491521502176_item	2621261	et	3	main
valdkonda	doc_491521502176_item	2621263	et	4	main
närimiskumm	doc_491521502176_item	2621265	et	3	main
kleepus	doc_491521502176_item	2621266	et	3	main
püksid	doc_491521502176_item	2621267	et	3	main
pükste	doc_491521502176_item	2621268	et	3	main
suvist	doc_491521502176_item	2621282	et	4	main
sidenditega	doc_491521502176_item	2621288	et	3	main
see	doc_491521502176_item	2621294	et	3	main
3	doc_491521502176_item	2621304	et	2	main
lapsel	doc_491521502176_item	2621305	et	4	main
paluti	doc_491521502176_item	2621306	et	3	main
oodata	doc_491521502176_item	2621307	et	4	main
kuna	doc_491521502176_item	2621308	et	3	main
5	doc_491521502176_item	2621322	et	2	main
vaid	doc_491521502176_item	2621327	et	3	main
tohi	doc_491521502176_item	2621341	et	4	main
8	doc_491521502176_item	2621346	et	2	main
töötasid	doc_491521502176_item	2621348	et	4	main
pingsalt	doc_491521502176_item	2621350	et	4	main
vaid	doc_491521502176_item	2621351	et	3	main
tulemust	doc_491521502176_item	2621352	et	4	main
keele	doc_491521502177_item	2621370	et	4	main
test	doc_491521502177_item	2621371	et	3	main
sulgudes	doc_491521502177_item	2621377	et	4	main
üle	doc_491521502177_item	2621411	et	3	main
õpetab	doc_491521502177_item	2621420	et	3	main
kinnitusel	doc_491521502177_item	2621422	et	4	main
et	doc_491521502177_item	2621428	et	3	main
mulle	doc_491521502177_item	2621436	et	4	main
tulema	doc_491521502177_item	2621437	et	4	main
selline	doc_491521502177_item	2621447	et	4	main
pärast	doc_491521502177_item	2621465	et	4	main
õppimine	doc_491521502177_item	2621495	et	4	main
hooaga	doc_491521502177_item	2621499	et	4	main
teistmoodi	doc_491521502177_item	2621504	et	3	main
ja	doc_491521502177_item	2621506	et	3	main
vaid	doc_491521502177_item	2621514	et	3	main
ülejäänud	doc_491521502177_item	2621525	et	4	main
õpetatakse	doc_491521502177_item	2621528	et	3	main
inimest	doc_491521502177_item	2621538	et	3	main
saab	doc_491521502177_item	2621540	et	3	main
eestist	doc_491521502177_item	2621554	et	3	main
karda	doc_491521502177_item	2621562	et	4	main
päevad	doc_491521502177_item	2621570	et	3	main
sõnad	doc_491521502177_item	2621613	et	4	main
igaüks	doc_491521502177_item	2621627	et	3	main
3	doc_491521502177_item	2621638	et	2	main
paras	doc_491521502177_item	2621651	et	3	main
stress	doc_491521502177_item	2621653	et	3	main
lisakoormus	doc_491521502177_item	2621658	et	3	main
võib	doc_491521502177_item	2621659	et	3	main
saama	doc_491521502177_item	2621670	et	4	main
maandama	doc_491521502177_item	2621671	et	3	main
saab	doc_491521502177_item	2621709	et	3	main
uni	doc_491521502177_item	2621721	et	3	main
saanud	doc_491521502176_item	2621135	et	4	main
nii	doc_491521502176_item	2621136	et	3	main
selle	doc_491521502176_item	2621139	et	4	main
6	doc_491521502176_item	2621145	et	2	main
varahommik	doc_491521502176_item	2621151	et	3	main
huvitav	doc_491521502176_item	2621159	et	4	main
telesaade	doc_491521502176_item	2621160	et	4	main
vaatamine	doc_491521502176_item	2621161	et	4	main
aeg	doc_491521502176_item	2621162	et	3	main
kuid	doc_491521502176_item	2621163	et	4	main
telefonihelin	doc_491521502176_item	2621164	et	3	main
katkestab	doc_491521502176_item	2621165	et	3	main
ka	doc_491521502176_item	2621166	et	3	main
varahommiku	doc_491521502176_item	2621168	et	3	main
pühapäeva	doc_491521502176_item	2621167	et	4	main
uni	doc_491521502176_item	2621169	et	3	main
segab	doc_491521502176_item	2621170	et	3	main
lõunasööki	doc_491521502176_item	2621171	et	4	main
ja	doc_491521502176_item	2621173	et	3	main
aega	doc_491521502176_item	2621179	et	4	main
süüa	doc_491521502176_item	2621174	et	3	main
huvitava	doc_491521502176_item	2621176	et	4	main
telesaade	doc_491521502176_item	2621177	et	4	main
vaatamist	doc_491521502176_item	2621178	et	4	main
sulgudes	doc_491521502176_item	2621182	et	4	main
olevad	doc_491521502176_item	2621183	et	4	main
1	doc_491521502176_item	2621187	et	2	main
igaühte	doc_491521502176_item	2621204	et	4	main
2	doc_491521502176_item	2621205	et	2	main
kohandasin	doc_491521502176_item	2621206	et	3	main
artikli	doc_491521502176_item	2621207	et	3	main
nõuded	doc_491521502176_item	2621208	et	3	main
nõudeid	doc_491521502176_item	2621209	et	3	main
3	doc_491521502176_item	2621210	et	2	main
et	doc_491521502176_item	2621213	et	3	main
aga	doc_491521502176_item	2621218	et	3	main
4	doc_491521502176_item	2621233	et	2	main
muudatused	doc_491521502176_item	2621253	et	3	main
väikeseid	doc_491521502176_item	2621254	et	4	main
küsimus	doc_491521502176_item	2621258	et	4	main
hoiduma	doc_491521502176_item	2621273	et	3	main
külmetamist	doc_491521502176_item	2621275	et	4	main
1	doc_491521502176_item	2621289	et	2	main
kolmekäigulise	doc_491521502176_item	2621291	et	4	main
palju	doc_491521502176_item	2621296	et	4	main
4	doc_491521502176_item	2621312	et	2	main
naeru	doc_491521502176_item	2621315	et	4	main
vist	doc_491521502176_item	2621316	et	4	main
oleks	doc_491521502176_item	2621317	et	3	main
keegi	doc_491521502176_item	2621318	et	4	main
just	doc_491521502176_item	2621319	et	3	main
ei	doc_491521502176_item	2621324	et	4	main
läheb	doc_491521502176_item	2621328	et	3	main
teatrisse	doc_491521502176_item	2621330	et	3	main
lõpetage	doc_491521502176_item	2621332	et	3	main
siis	doc_491521502176_item	2621334	et	3	main
lähete	doc_491521502176_item	2621335	et	4	main
jalutama	doc_491521502176_item	2621336	et	3	main
7	doc_491521502176_item	2621337	et	2	main
selles	doc_491521502176_item	2621338	et	4	main
baaris	doc_491521502176_item	2621339	et	3	main
tarbida	doc_491521502176_item	2621345	et	3	main
ei	doc_491521502176_item	2621353	et	4	main
eesti	doc_491521502177_item	2621369	et	4	main
pange	doc_491521502177_item	2621376	et	4	main
nüüd	doc_491521502177_item	2621409	et	4	main
nädal	doc_491521502177_item	2621412	et	3	main
emakeelt	doc_491521502177_item	2621418	et	4	main
jõudma	doc_491521502177_item	2621426	et	3	main
siberist	doc_491521502177_item	2621446	et	4	main
rohi	doc_491521502177_item	2621457	et	4	main
kui	doc_491521502177_item	2621458	et	3	main
noor	doc_491521502177_item	2621459	et	3	main
ja	doc_491521502177_item	2621460	et	3	main
tahtmine	doc_491521502177_item	2621461	et	4	main
õppeaasta	doc_491521502177_item	2621466	et	4	main
küla	doc_491521502177_item	2621477	et	4	main
kartulivõtt	doc_491521502177_item	2621481	et	3	main
siin	doc_491521502177_item	2621483	et	4	main
tähtsam	doc_491521502177_item	2621487	et	4	main
on	doc_491521502177_item	2621490	et	4	main
hoog	doc_491521502177_item	2621498	et	3	main
kuidagi	doc_491521502177_item	2621503	et	3	main
mõnus	doc_491521502177_item	2621505	et	4	main
aktsent	doc_491521502177_item	2621512	et	3	main
aktsendiga	doc_491521502177_item	2621513	et	3	main
siiski	doc_491521502177_item	2621521	et	4	main
kolmesaja	doc_491521502177_item	2621536	et	4	main
inimene	doc_491521502177_item	2621537	et	3	main
rääkida	doc_491521502177_item	2621543	et	3	main
lapsed	doc_491521502177_item	2621547	et	3	main
raamatud	doc_491521502177_item	2621550	et	4	main
varsti	doc_491521502177_item	2621551	et	3	main
mulle	doc_491521502177_item	2621563	et	4	main
juba	doc_491521502177_item	2621564	et	3	main
tooma	doc_491521502177_item	2621565	et	3	main
toodud	doc_491521502177_item	2621566	et	4	main
talvepuud	doc_491521502177_item	2621567	et	4	main
praegu	doc_491521502177_item	2621568	et	3	main
soe	doc_491521502177_item	2621572	et	4	main
kuid	doc_491521502177_item	2621574	et	4	main
pannes	doc_491521502177_item	2621612	et	4	main
naised	doc_491521502176_item	2621224	et	3	main
autod	doc_491521502176_item	2621227	et	3	main
naistesse	doc_491521502176_item	2621229	et	3	main
kiirte	doc_491521502176_item	2621231	et	3	main
oht	doc_491521502176_item	2621236	et	3	main
difteeria	doc_491521502176_item	2621238	et	4	main
5	doc_491521502176_item	2621240	et	2	main
töökoht	doc_491521502176_item	2621243	et	3	main
kiiresti	doc_491521502176_item	2621246	et	3	main
7	doc_491521502176_item	2621256	et	2	main
teiste	doc_491521502176_item	2621262	et	4	main
8	doc_491521502176_item	2621264	et	2	main
9	doc_491521502176_item	2621269	et	2	main
külmal	doc_491521502176_item	2621270	et	3	main
ajal	doc_491521502176_item	2621271	et	4	main
päikest	doc_491521502176_item	2621283	et	4	main
v	doc_491521502176_item	2621284	et	4	main
täitke	doc_491521502176_item	2621285	et	3	main
lüngad	doc_491521502176_item	2621286	et	3	main
tellisime	doc_491521502176_item	2621290	et	4	main
õpetajad	doc_491521502176_item	2621303	et	4	main
tulevad	doc_491521502176_item	2621311	et	4	main
kostis	doc_491521502176_item	2621314	et	4	main
kõrvallauast	doc_491521502176_item	2621313	et	4	main
anekdooti	doc_491521502176_item	2621320	et	4	main
rääkinud	doc_491521502176_item	2621321	et	4	main
hoopis	doc_491521502176_item	2621329	et	3	main
suitsetada	doc_491521502176_item	2621342	et	3	main
olnud	doc_491521502176_item	2621354	et	4	main
sõidad	doc_491521502176_item	2621358	et	3	main
või	doc_491521502176_item	2621360	et	4	main
10	doc_491521502176_item	2621363	et	2	main
avasin	doc_491521502176_item	2621364	et	3	main
eesti	doc_491521502177_item	2621372	et	4	main
olevad	doc_491521502177_item	2621378	et	4	main
ja	doc_491521502177_item	2621407	et	3	main
nende	doc_491521502177_item	2621417	et	4	main
pireti	doc_491521502177_item	2621421	et	4	main
tundis	doc_491521502177_item	2621423	et	3	main
kui	doc_491521502177_item	2621435	et	3	main
tuldi	doc_491521502177_item	2621438	et	3	main
vastu	doc_491521502177_item	2621439	et	3	main
korralik	doc_491521502177_item	2621440	et	3	main
korraliku	doc_491521502177_item	2621441	et	3	main
audiga	doc_491521502177_item	2621442	et	3	main
mulle	doc_491521502177_item	2621443	et	4	main
maaliti	doc_491521502177_item	2621444	et	3	main
et	doc_491521502177_item	2621449	et	3	main
ei	doc_491521502177_item	2621451	et	4	main
lendama	doc_491521502177_item	2621452	et	3	main
tahtmisega	doc_491521502177_item	2621462	et	4	main
kohale	doc_491521502177_item	2621469	et	4	main
polnud	doc_491521502177_item	2621471	et	3	main
veel	doc_491521502177_item	2621473	et	4	main
algama	doc_491521502177_item	2621474	et	3	main
alganud	doc_491521502177_item	2621475	et	4	main
kogu	doc_491521502177_item	2621476	et	4	main
sügisel	doc_491521502177_item	2621484	et	3	main
ettevõtmine	doc_491521502177_item	2621488	et	3	main
käib	doc_491521502177_item	2621496	et	3	main
eestlased	doc_491521502177_item	2621501	et	3	main
mahlakas	doc_491521502177_item	2621507	et	4	main
mõnusalt	doc_491521502177_item	2621508	et	4	main
mahlakalt	doc_491521502177_item	2621509	et	4	main
mitte	doc_491521502177_item	2621510	et	3	main
kool	doc_491521502177_item	2621523	et	4	main
ained	doc_491521502177_item	2621527	et	3	main
vene	doc_491521502177_item	2621529	et	4	main
keeles	doc_491521502177_item	2621530	et	4	main
külas	doc_491521502177_item	2621531	et	3	main
elab	doc_491521502177_item	2621532	et	3	main
veidi	doc_491521502177_item	2621533	et	3	main
üle	doc_491521502177_item	2621534	et	3	main
kõik	doc_491521502177_item	2621542	et	4	main
sõnul	doc_491521502177_item	2621545	et	3	main
õpivad	doc_491521502177_item	2621546	et	3	main
poolpõlenud	doc_491521502177_item	2621548	et	4	main
raamatud	doc_491521502177_item	2621549	et	4	main
uued	doc_491521502177_item	2621555	et	3	main
siberi	doc_491521502177_item	2621557	et	4	main
piret	doc_491521502177_item	2621559	et	4	main
ei	doc_491521502177_item	2621560	et	4	main
kartma	doc_491521502177_item	2621561	et	3	main
veel	doc_491521502177_item	2621571	et	4	main
iii	doc_491521502177_item	2621607	et	4	main
moodustage	doc_491521502177_item	2621608	et	3	main
vormi	doc_491521502177_item	2621615	et	4	main
naised	doc_491521502177_item	2621622	et	3	main
mehelikum	doc_491521502177_item	2621626	et	4	main
kaunim	doc_491521502177_item	2621632	et	4	main
ja	doc_491521502177_item	2621635	et	3	main
paras	doc_491521502177_item	2621639	et	3	main
stress	doc_491521502177_item	2621641	et	3	main
tegutsema	doc_491521502177_item	2621644	et	3	main
lisakoormus	doc_491521502177_item	2621646	et	3	main
soovimatu	doc_491521502177_item	2621649	et	4	main
pinge	doc_491521502177_item	2621669	et	4	main
lasta	doc_491521502177_item	2621677	et	4	main
elada	doc_491521502177_item	2621711	et	3	main
hingata	doc_491521502177_item	2621713	et	4	main
ta	doc_491521502176_item	2621323	et	4	main
ei	doc_491521502176_item	2621340	et	4	main
alkoholi	doc_491521502176_item	2621344	et	4	main
9	doc_491521502176_item	2621355	et	2	main
kas	doc_491521502176_item	2621356	et	3	main
sa	doc_491521502176_item	2621357	et	3	main
jääd	doc_491521502176_item	2621361	et	4	main
ukse	doc_491521502176_item	2621365	et	3	main
sest	doc_491521502176_item	2621366	et	4	main
kuulsin	doc_491521502176_item	2621367	et	3	main
koputust	doc_491521502176_item	2621368	et	4	main
i	doc_491521502177_item	2621375	et	4	main
sõnad	doc_491521502177_item	2621379	et	4	main
õigesse	doc_491521502177_item	2621380	et	3	main
vormi	doc_491521502177_item	2621381	et	4	main
piret	doc_491521502177_item	2621382	et	4	main
toomet	doc_491521502177_item	2621383	et	4	main
on	doc_491521502177_item	2621384	et	4	main
ettevõtlik	doc_491521502177_item	2621385	et	3	main
naine	doc_491521502177_item	2621386	et	3	main
suvel	doc_491521502177_item	2621387	et	3	main
nägema	doc_491521502177_item	2621388	et	3	main
nägi	doc_491521502177_item	2621389	et	3	main
ta	doc_491521502177_item	2621390	et	4	main
ajalehes	doc_491521502177_item	2621391	et	3	main
kuulutus	doc_491521502177_item	2621392	et	4	main
kuulutust	doc_491521502177_item	2621393	et	4	main
et	doc_491521502177_item	2621394	et	3	main
siberisse	doc_491521502177_item	2621395	et	4	main
ülem-suetuki	doc_491521502177_item	2621396	et	4	main
küla	doc_491521502177_item	2621397	et	4	main
külla	doc_491521502177_item	2621398	et	4	main
otsitakse	doc_491521502177_item	2621399	et	3	main
eesti	doc_491521502177_item	2621400	et	4	main
keele	doc_491521502177_item	2621401	et	4	main
õpetajat	doc_491521502177_item	2621402	et	4	main
piret	doc_491521502177_item	2621403	et	4	main
võitis	doc_491521502177_item	2621404	et	3	main
konkurss	doc_491521502177_item	2621405	et	3	main
konkursi	doc_491521502177_item	2621406	et	3	main
on	doc_491521502177_item	2621408	et	4	main
õpetama	doc_491521502177_item	2621419	et	3	main
jõudes	doc_491521502177_item	2621427	et	3	main
on	doc_491521502177_item	2621429	et	4	main
üsna	doc_491521502177_item	2621432	et	3	main
üllatunud	doc_491521502177_item	2621434	et	4	main
siber	doc_491521502177_item	2621445	et	4	main
pilt	doc_491521502177_item	2621448	et	3	main
seal	doc_491521502177_item	2621450	et	4	main
lind	doc_491521502177_item	2621454	et	3	main
ega	doc_491521502177_item	2621455	et	3	main
kasva	doc_491521502177_item	2621456	et	4	main
piret	doc_491521502177_item	2621464	et	4	main
koht	doc_491521502177_item	2621468	et	3	main
jõudis	doc_491521502177_item	2621470	et	3	main
kool	doc_491521502177_item	2621472	et	4	main
kartuleid	doc_491521502177_item	2621480	et	3	main
tähtis	doc_491521502177_item	2621486	et	4	main
tänaseks	doc_491521502177_item	2621489	et	4	main
kartul	doc_491521502177_item	2621491	et	3	main
salv	doc_491521502177_item	2621492	et	3	main
salvis	doc_491521502177_item	2621493	et	4	main
ja	doc_491521502177_item	2621494	et	3	main
nagu	doc_491521502177_item	2621515	et	3	main
mõnd	doc_491521502177_item	2621517	et	3	main
kool	doc_491521502177_item	2621519	et	4	main
on	doc_491521502177_item	2621520	et	4	main
ta	doc_491521502177_item	2621424	et	4	main
siberisse	doc_491521502177_item	2621425	et	4	main
oodatud	doc_491521502177_item	2621430	et	4	main
olin	doc_491521502177_item	2621431	et	3	main
üllatuma	doc_491521502177_item	2621433	et	3	main
lenda	doc_491521502177_item	2621453	et	4	main
täis	doc_491521502177_item	2621463	et	4	main
algust	doc_491521502177_item	2621467	et	4	main
võtma	doc_491521502177_item	2621478	et	3	main
võtis	doc_491521502177_item	2621479	et	3	main
on	doc_491521502177_item	2621482	et	4	main
kõige	doc_491521502177_item	2621485	et	4	main
täie	doc_491521502177_item	2621497	et	3	main
siinsed	doc_491521502177_item	2621500	et	3	main
räägivad	doc_491521502177_item	2621502	et	3	main
vene	doc_491521502177_item	2621511	et	4	main
mõni	doc_491521502177_item	2621516	et	3	main
murret	doc_491521502177_item	2621518	et	4	main
venemaa	doc_491521502177_item	2621522	et	4	main
aine	doc_491521502177_item	2621526	et	4	main
emakeelt	doc_491521502177_item	2621539	et	4	main
saatma	doc_491521502177_item	2621552	et	3	main
on	doc_491521502177_item	2621569	et	4	main
soojem	doc_491521502177_item	2621573	et	3	main
ööd	doc_491521502177_item	2621575	et	4	main
juba	doc_491521502177_item	2621576	et	3	main
õigesse	doc_491521502177_item	2621614	et	3	main
kirjavahemärke	doc_491521502177_item	2621618	et	4	main
ja	doc_491521502177_item	2621524	et	3	main
kolmsada	doc_491521502177_item	2621535	et	4	main
kõik	doc_491521502177_item	2621541	et	4	main
pireti	doc_491521502177_item	2621544	et	4	main
saadakse	doc_491521502177_item	2621553	et	3	main
õpikud	doc_491521502177_item	2621556	et	3	main
talve	doc_491521502177_item	2621558	et	4	main
jahe	doc_491521502177_item	2621577	et	3	main
jahedad	doc_491521502177_item	2621578	et	3	main
harjutan	doc_491521502177_item	2621579	et	3	main
juba	doc_491521502177_item	2621580	et	3	main
suure	doc_491521502177_item	2621581	et	3	main
vene	doc_491521502177_item	2621582	et	4	main
ahju	doc_491521502177_item	2621583	et	4	main
kütmine	doc_491521502177_item	2621584	et	4	main
kütmisega	doc_491521502177_item	2621585	et	4	main
kui	doc_491521502177_item	2621586	et	3	main
vaja	doc_491521502177_item	2621587	et	4	main
ostan	doc_491521502177_item	2621588	et	3	main
külapood	doc_491521502177_item	2621589	et	3	main
külapoest	doc_491521502177_item	2621590	et	4	main
vildid	doc_491521502177_item	2621591	et	4	main
ega	doc_491521502177_item	2621592	et	3	main
seal	doc_491521502177_item	2621593	et	4	main
suurt	doc_491521502177_item	2621594	et	3	main
muud	doc_491521502177_item	2621595	et	4	main
ei	doc_491521502177_item	2621596	et	4	main
müüdagi	doc_491521502177_item	2621597	et	3	main
naerab	doc_491521502177_item	2621598	et	3	main
talveks	doc_491521502177_item	2621599	et	4	main
valmistuma	doc_491521502177_item	2621600	et	3	main
valmistunud	doc_491521502177_item	2621601	et	4	main
piret	doc_491521502177_item	2621602	et	4	main
vapralt	doc_491521502177_item	2621603	et	4	main
lühendatud	doc_491521502177_item	2621604	et	4	main
ajalehest	doc_491521502177_item	2621605	et	4	main
slõhtuleht	doc_491521502177_item	2621606	et	4	main
etteantud	doc_491521502177_item	2621609	et	4	main
sõnadest	doc_491521502177_item	2621610	et	3	main
laused	doc_491521502177_item	2621611	et	3	main
ja	doc_491521502177_item	2621616	et	3	main
naeratus	doc_491521502177_item	2621620	et	4	main
tegema	doc_491521502177_item	2621621	et	3	main
naiselikum	doc_491521502177_item	2621623	et	4	main
mehed	doc_491521502177_item	2621625	et	3	main
teeb	doc_491521502177_item	2621630	et	3	main
naiselikuim	doc_491521502177_item	2621634	et	4	main
kogus	doc_491521502177_item	2621640	et	4	main
panema	doc_491521502177_item	2621642	et	3	main
meie	doc_491521502177_item	2621643	et	4	main
tooma	doc_491521502177_item	2621648	et	3	main
meid	doc_491521502177_item	2621655	et	4	main
aga	doc_491521502177_item	2621657	et	3	main
tuua	doc_491521502177_item	2621660	et	3	main
tagajärge	doc_491521502177_item	2621662	et	4	main
6	doc_491521502177_item	2621714	et	2	main
lõunasöök	doc_491521502177_item	2621723	et	3	main
katkestab	doc_491521502177_item	2621735	et	3	main
telesaate	doc_491521502177_item	2621745	et	3	main
vaatamise	doc_491521502177_item	2621746	et	4	main
aega	doc_491521502177_item	2621747	et	4	main
iv	doc_491521502177_item	2621748	et	4	main
olevad	doc_491521502177_item	2621751	et	4	main
sõnad	doc_491521502177_item	2621752	et	4	main
õigesse	doc_491521502177_item	2621753	et	3	main
vormi	doc_491521502177_item	2621754	et	4	main
1	doc_491521502177_item	2621755	et	2	main
oma	doc_491521502177_item	2621762	et	4	main
2	doc_491521502177_item	2621772	et	2	main
kohandasin	doc_491521502177_item	2621773	et	3	main
nõuded	doc_491521502177_item	2621775	et	3	main
huvitud	doc_491521502177_item	2621782	et	4	main
sa	doc_491521502177_item	2621786	et	3	main
autod	doc_491521502177_item	2621794	et	3	main
ilusade	doc_491521502177_item	2621795	et	3	main
ja	doc_491521502177_item	2621797	et	3	main
vastu	doc_491521502177_item	2621800	et	3	main
kuulub	doc_491521502177_item	2621825	et	3	main
valdkonda	doc_491521502177_item	2621829	et	4	main
kleepus	doc_491521502177_item	2621832	et	3	main
9	doc_491521502177_item	2621835	et	2	main
rõõmu	doc_491521502177_item	2621845	et	4	main
v	doc_491521502177_item	2621850	et	4	main
õpilased	doc_491521502177_item	2621867	et	3	main
kui	doc_491521502177_item	2621868	et	3	main
ka	doc_491521502177_item	2621869	et	3	main
õpetajad	doc_491521502177_item	2621870	et	4	main
oodata	doc_491521502177_item	2621874	et	4	main
tulevad	doc_491521502177_item	2621878	et	4	main
ei	doc_491521502177_item	2621891	et	4	main
teatrisse	doc_491521502177_item	2621897	et	3	main
lõpetage	doc_491521502177_item	2621899	et	3	main
tohi	doc_491521502177_item	2621908	et	4	main
nad	doc_491521502177_item	2621914	et	3	main
linna	doc_491521502177_item	2621929	et	4	main
10	doc_491521502177_item	2621930	et	2	main
avasin	doc_491521502177_item	2621931	et	3	main
ukse	doc_491521502177_item	2621932	et	3	main
keele	doc_491521502178_item	2621940	et	4	main
test	doc_491521502178_item	2621941	et	3	main
i	doc_491521502178_item	2621942	et	4	main
vormi	doc_491521502178_item	2621948	et	4	main
piret	doc_491521502178_item	2621949	et	4	main
toomet	doc_491521502178_item	2621950	et	4	main
nägi	doc_491521502178_item	2621956	et	3	main
külas	doc_491521502178_item	2621965	et	3	main
et	doc_491521502178_item	2621995	et	3	main
olin	doc_491521502178_item	2621998	et	3	main
tulema	doc_491521502178_item	2622004	et	4	main
lenda	doc_491521502178_item	2622020	et	4	main
lind	doc_491521502178_item	2622021	et	3	main
kasva	doc_491521502178_item	2622023	et	4	main
kui	doc_491521502178_item	2622025	et	3	main
pärast	doc_491521502178_item	2622032	et	4	main
veel	doc_491521502178_item	2622040	et	4	main
algama	doc_491521502178_item	2622041	et	3	main
tänaseks	doc_491521502178_item	2622055	et	4	main
on	doc_491521502178_item	2622056	et	4	main
salv	doc_491521502178_item	2622058	et	3	main
kasutades	doc_491521502177_item	2621617	et	3	main
2	doc_491521502177_item	2621619	et	2	main
ja	doc_491521502177_item	2621624	et	3	main
kaunim	doc_491521502177_item	2621628	et	4	main
igaüht	doc_491521502177_item	2621631	et	3	main
mehi	doc_491521502177_item	2621636	et	3	main
aga	doc_491521502177_item	2621645	et	3	main
võima	doc_491521502177_item	2621647	et	3	main
kogus	doc_491521502177_item	2621652	et	4	main
paneb	doc_491521502177_item	2621654	et	3	main
tegutsema	doc_491521502177_item	2621656	et	3	main
soovimatu	doc_491521502177_item	2621661	et	4	main
4	doc_491521502177_item	2621663	et	2	main
ei	doc_491521502177_item	2621664	et	4	main
tohtima	doc_491521502177_item	2621665	et	3	main
laskma	doc_491521502177_item	2621666	et	3	main
ülekoormus	doc_491521502177_item	2621667	et	3	main
tekkima	doc_491521502177_item	2621668	et	3	main
tohi	doc_491521502177_item	2621676	et	4	main
söömine	doc_491521502177_item	2621726	et	4	main
huvitav	doc_491521502177_item	2621728	et	4	main
telesaade	doc_491521502177_item	2621729	et	4	main
hommiku	doc_491521502177_item	2621733	et	3	main
valmistamist	doc_491521502177_item	2621738	et	4	main
ja	doc_491521502177_item	2621739	et	3	main
söömist	doc_491521502177_item	2621740	et	4	main
vanemaid	doc_491521502177_item	2621763	et	4	main
usaldavad	doc_491521502177_item	2621769	et	4	main
3	doc_491521502177_item	2621777	et	2	main
et	doc_491521502177_item	2621780	et	3	main
kiired	doc_491521502177_item	2621793	et	4	main
naiste	doc_491521502177_item	2621796	et	3	main
praegu	doc_491521502177_item	2621802	et	3	main
oht	doc_491521502177_item	2621804	et	3	main
haigestuda	doc_491521502177_item	2621805	et	3	main
7	doc_491521502177_item	2621822	et	2	main
teisesse	doc_491521502177_item	2621828	et	4	main
närimiskumm	doc_491521502177_item	2621831	et	3	main
pükstele	doc_491521502177_item	2621834	et	3	main
külmal	doc_491521502177_item	2621836	et	3	main
suvine	doc_491521502177_item	2621846	et	4	main
päike	doc_491521502177_item	2621847	et	3	main
täitke	doc_491521502177_item	2621851	et	3	main
kostis	doc_491521502177_item	2621881	et	4	main
rääkinud	doc_491521502177_item	2621888	et	4	main
ning	doc_491521502177_item	2621910	et	3	main
tarbida	doc_491521502177_item	2621912	et	3	main
olnud	doc_491521502177_item	2621921	et	4	main
sõidad	doc_491521502177_item	2621925	et	3	main
sest	doc_491521502177_item	2621933	et	4	main
kuulsin	doc_491521502177_item	2621934	et	3	main
sõnad	doc_491521502178_item	2621946	et	4	main
õigesse	doc_491521502178_item	2621947	et	3	main
suvel	doc_491521502178_item	2621954	et	3	main
ajalehes	doc_491521502178_item	2621958	et	3	main
ülem-suetuki	doc_491521502178_item	2621963	et	4	main
eesti	doc_491521502178_item	2621967	et	4	main
kinnitusel	doc_491521502178_item	2621989	et	4	main
tundis	doc_491521502178_item	2621990	et	3	main
ta	doc_491521502178_item	2621991	et	4	main
siberisse	doc_491521502178_item	2621992	et	4	main
jõudma	doc_491521502178_item	2621993	et	3	main
jõuda	doc_491521502178_item	2621994	et	3	main
oodatud	doc_491521502178_item	2621997	et	4	main
üsna	doc_491521502178_item	2621999	et	3	main
mulle	doc_491521502178_item	2622010	et	4	main
maaliti	doc_491521502178_item	2622011	et	3	main
pilt	doc_491521502178_item	2622015	et	3	main
naeratus	doc_491521502177_item	2621629	et	4	main
naisi	doc_491521502177_item	2621633	et	3	main
mehelikuim	doc_491521502177_item	2621637	et	4	main
tagajärg	doc_491521502177_item	2621650	et	3	main
sportima	doc_491521502177_item	2621672	et	4	main
ja	doc_491521502177_item	2621673	et	3	main
puhkama	doc_491521502177_item	2621674	et	3	main
ei	doc_491521502177_item	2621675	et	4	main
ülekoormust	doc_491521502177_item	2621678	et	4	main
tekkiv	doc_491521502177_item	2621679	et	4	main
pinge	doc_491521502177_item	2621680	et	4	main
saab	doc_491521502177_item	2621681	et	3	main
maandada	doc_491521502177_item	2621682	et	3	main
sportides	doc_491521502177_item	2621683	et	4	main
ja	doc_491521502177_item	2621684	et	3	main
puhkades	doc_491521502177_item	2621685	et	4	main
5	doc_491521502177_item	2621686	et	2	main
telefon	doc_491521502177_item	2621687	et	3	main
olema	doc_491521502177_item	2621688	et	4	main
tänapäev	doc_491521502177_item	2621689	et	3	main
saama	doc_491521502177_item	2621690	et	4	main
nii	doc_491521502177_item	2621691	et	3	main
maagiline	doc_491521502177_item	2621692	et	4	main
aparaat	doc_491521502177_item	2621693	et	3	main
et	doc_491521502177_item	2621694	et	3	main
see	doc_491521502177_item	2621695	et	3	main
abil	doc_491521502177_item	2621696	et	4	main
lausa	doc_491521502177_item	2621697	et	4	main
elama	doc_491521502177_item	2621698	et	3	main
ja	doc_491521502177_item	2621699	et	3	main
hingama	doc_491521502177_item	2621700	et	3	main
telefon	doc_491521502177_item	2621701	et	3	main
on	doc_491521502177_item	2621702	et	4	main
nii	doc_491521502177_item	2621703	et	3	main
maagiline	doc_491521502177_item	2621704	et	4	main
aparaat	doc_491521502177_item	2621705	et	3	main
et	doc_491521502177_item	2621706	et	3	main
selle	doc_491521502177_item	2621707	et	4	main
abil	doc_491521502177_item	2621708	et	4	main
lausa	doc_491521502177_item	2621710	et	4	main
ja	doc_491521502177_item	2621712	et	3	main
kuid	doc_491521502177_item	2621715	et	4	main
telefonihelin	doc_491521502177_item	2621716	et	3	main
katkestama	doc_491521502177_item	2621717	et	3	main
ka	doc_491521502177_item	2621718	et	3	main
pühapäev	doc_491521502177_item	2621719	et	3	main
varahommik	doc_491521502177_item	2621720	et	3	main
vaatamine	doc_491521502177_item	2621730	et	4	main
aeg	doc_491521502177_item	2621731	et	3	main
huvitava	doc_491521502177_item	2621744	et	4	main
ma	doc_491521502177_item	2621756	et	3	main
pean	doc_491521502177_item	2621757	et	4	main
väga	doc_491521502177_item	2621758	et	3	main
lugu	doc_491521502177_item	2621759	et	4	main
sest	doc_491521502177_item	2621764	et	4	main
nad	doc_491521502177_item	2621765	et	3	main
igaüks	doc_491521502177_item	2621770	et	3	main
nõudeid	doc_491521502177_item	2621776	et	3	main
muudatused	doc_491521502177_item	2621821	et	3	main
külmetamine	doc_491521502177_item	2621840	et	4	main
külmetamist	doc_491521502177_item	2621841	et	4	main
10	doc_491521502177_item	2621842	et	2	main
ma	doc_491521502177_item	2621843	et	3	main
tunnen	doc_491521502177_item	2621844	et	3	main
sobivate	doc_491521502177_item	2621853	et	4	main
olid	doc_491521502177_item	2621865	et	4	main
paluti	doc_491521502177_item	2621873	et	3	main
kui	doc_491521502177_item	2621875	et	3	main
tagasi	doc_491521502177_item	2621877	et	3	main
4	doc_491521502177_item	2621879	et	2	main
kõrvallauast	doc_491521502177_item	2621880	et	4	main
ta	doc_491521502177_item	2621890	et	4	main
tule	doc_491521502177_item	2621892	et	4	main
läheb	doc_491521502177_item	2621895	et	3	main
tulemust	doc_491521502177_item	2621919	et	4	main
kas	doc_491521502177_item	2621923	et	3	main
koputust	doc_491521502177_item	2621935	et	4	main
pange	doc_491521502178_item	2621943	et	4	main
nägema	doc_491521502178_item	2621955	et	3	main
küla	doc_491521502178_item	2621964	et	4	main
keele	doc_491521502178_item	2621968	et	4	main
on	doc_491521502178_item	2621996	et	4	main
üllatuma	doc_491521502178_item	2622000	et	3	main
üllatunud	doc_491521502178_item	2622001	et	4	main
kui	doc_491521502178_item	2622002	et	3	main
et	doc_491521502178_item	2622016	et	3	main
ei	doc_491521502178_item	2622018	et	4	main
rohi	doc_491521502178_item	2622024	et	4	main
tahtmine	doc_491521502178_item	2622028	et	4	main
õppeaasta	doc_491521502178_item	2622033	et	4	main
alatud	doc_491521502178_item	2622042	et	4	main
sügisel	doc_491521502178_item	2622051	et	3	main
kõige	doc_491521502178_item	2622052	et	4	main
õppimine	doc_491521502178_item	2622061	et	4	main
käib	doc_491521502178_item	2622062	et	3	main
siinsed	doc_491521502178_item	2622066	et	3	main
räägivad	doc_491521502178_item	2622068	et	3	main
mitte	doc_491521502178_item	2622076	et	3	main
aktsenti	doc_491521502178_item	2622079	et	4	main
mõni	doc_491521502178_item	2622082	et	3	main
kool	doc_491521502178_item	2622089	et	4	main
keeles	doc_491521502178_item	2622096	et	4	main
pireti	doc_491521502178_item	2622108	et	4	main
lapsed	doc_491521502178_item	2622111	et	3	main
raamatud	doc_491521502178_item	2622113	et	4	main
raamatutest	doc_491521502178_item	2622114	et	4	main
varsti	doc_491521502178_item	2622115	et	3	main
talve	doc_491521502178_item	2622122	et	4	main
tooma	doc_491521502178_item	2622129	et	3	main
soe	doc_491521502178_item	2622136	et	4	main
jahedad	doc_491521502178_item	2622141	et	3	main
harjutan	doc_491521502178_item	2622142	et	3	main
juba	doc_491521502178_item	2622143	et	3	main
suure	doc_491521502178_item	2622144	et	3	main
vene	doc_491521502178_item	2622145	et	4	main
vaja	doc_491521502178_item	2622150	et	4	main
ostan	doc_491521502178_item	2622151	et	3	main
piret	doc_491521502178_item	2622165	et	4	main
moodustage	doc_491521502178_item	2622171	et	3	main
õigesse	doc_491521502178_item	2622177	et	3	main
2	doc_491521502178_item	2622182	et	2	main
segama	doc_491521502177_item	2621722	et	3	main
ja	doc_491521502177_item	2621725	et	3	main
pühapäeva	doc_491521502177_item	2621732	et	4	main
und	doc_491521502177_item	2621736	et	4	main
sulgudes	doc_491521502177_item	2621750	et	4	main
oma	doc_491521502177_item	2621760	et	4	main
aitavad	doc_491521502177_item	2621766	et	4	main
igaüht	doc_491521502177_item	2621771	et	3	main
artikli	doc_491521502177_item	2621774	et	3	main
arvasin	doc_491521502177_item	2621779	et	3	main
sa	doc_491521502177_item	2621781	et	3	main
sport	doc_491521502177_item	2621783	et	3	main
aga	doc_491521502177_item	2621785	et	3	main
tunned	doc_491521502177_item	2621787	et	3	main
ainult	doc_491521502177_item	2621789	et	4	main
ilusad	doc_491521502177_item	2621790	et	3	main
naised	doc_491521502177_item	2621791	et	3	main
kiirte	doc_491521502177_item	2621798	et	3	main
4	doc_491521502177_item	2621801	et	2	main
difteeriasse	doc_491521502177_item	2621807	et	3	main
5	doc_491521502177_item	2621808	et	2	main
tüdinesin	doc_491521502177_item	2621809	et	3	main
uus	doc_491521502177_item	2621810	et	3	main
difteeria	doc_491521502177_item	2621806	et	4	main
töökoht	doc_491521502177_item	2621811	et	3	main
uuest	doc_491521502177_item	2621812	et	3	main
töökohast	doc_491521502177_item	2621813	et	4	main
kiiresti	doc_491521502177_item	2621814	et	3	main
6	doc_491521502177_item	2621815	et	2	main
piirdusime	doc_491521502177_item	2621816	et	3	main
selles	doc_491521502177_item	2621817	et	4	main
küsimuses	doc_491521502177_item	2621818	et	4	main
vaid	doc_491521502177_item	2621819	et	3	main
väikesed	doc_491521502177_item	2621820	et	4	main
valmistamine	doc_491521502177_item	2621724	et	4	main
pahandab	doc_491521502177_item	2621727	et	3	main
telefonihelin	doc_491521502177_item	2621734	et	3	main
lõunasöögi	doc_491521502177_item	2621737	et	3	main
kuid	doc_491521502177_item	2621741	et	4	main
ka	doc_491521502177_item	2621742	et	3	main
pahandab	doc_491521502177_item	2621743	et	3	main
pange	doc_491521502177_item	2621749	et	4	main
vanemad	doc_491521502177_item	2621761	et	4	main
kõik	doc_491521502177_item	2621767	et	4	main
ja	doc_491521502177_item	2621768	et	3	main
ma	doc_491521502177_item	2621778	et	3	main
spordist	doc_491521502177_item	2621784	et	3	main
huvi	doc_491521502177_item	2621788	et	4	main
ja	doc_491521502177_item	2621792	et	3	main
autode	doc_491521502177_item	2621799	et	3	main
on	doc_491521502177_item	2621803	et	4	main
küsimus	doc_491521502177_item	2621824	et	4	main
valdkond	doc_491521502177_item	2621827	et	3	main
8	doc_491521502177_item	2621830	et	2	main
püksid	doc_491521502177_item	2621833	et	3	main
ajal	doc_491521502177_item	2621837	et	4	main
peab	doc_491521502177_item	2621838	et	4	main
hoiduma	doc_491521502177_item	2621839	et	3	main
suvisest	doc_491521502177_item	2621848	et	4	main
lüngad	doc_491521502177_item	2621852	et	3	main
lapsel	doc_491521502177_item	2621872	et	4	main
5	doc_491521502177_item	2621889	et	2	main
selles	doc_491521502177_item	2621905	et	4	main
baaris	doc_491521502177_item	2621906	et	3	main
ei	doc_491521502177_item	2621907	et	4	main
alkoholi	doc_491521502177_item	2621911	et	4	main
töötasid	doc_491521502177_item	2621915	et	4	main
pingsalt	doc_491521502177_item	2621917	et	4	main
ei	doc_491521502177_item	2621920	et	4	main
see	doc_491521502177_item	2621823	et	3	main
teine	doc_491521502177_item	2621826	et	3	main
päikesest	doc_491521502177_item	2621849	et	4	main
1	doc_491521502177_item	2621855	et	2	main
sidenditega	doc_491521502177_item	2621854	et	3	main
tellisime	doc_491521502177_item	2621856	et	4	main
kolmekäigulise	doc_491521502177_item	2621857	et	4	main
lõuna	doc_491521502177_item	2621858	et	4	main
vaid	doc_491521502177_item	2621859	et	3	main
see	doc_491521502177_item	2621860	et	3	main
maksis	doc_491521502177_item	2621861	et	4	main
2	doc_491521502177_item	2621863	et	2	main
palju	doc_491521502177_item	2621862	et	4	main
kohal	doc_491521502177_item	2621864	et	4	main
nii	doc_491521502177_item	2621866	et	3	main
3	doc_491521502177_item	2621871	et	2	main
vanemad	doc_491521502177_item	2621876	et	4	main
naeru	doc_491521502177_item	2621882	et	4	main
sest	doc_491521502177_item	2621883	et	4	main
oleks	doc_491521502177_item	2621884	et	3	main
keegi	doc_491521502177_item	2621885	et	4	main
just	doc_491521502177_item	2621886	et	3	main
anekdooti	doc_491521502177_item	2621887	et	4	main
trenni	doc_491521502177_item	2621893	et	4	main
vaid	doc_491521502177_item	2621894	et	3	main
hoopis	doc_491521502177_item	2621896	et	3	main
6	doc_491521502177_item	2621898	et	2	main
töö	doc_491521502177_item	2621900	et	4	main
siis	doc_491521502177_item	2621901	et	3	main
lähete	doc_491521502177_item	2621902	et	4	main
jalutama	doc_491521502177_item	2621903	et	3	main
7	doc_491521502177_item	2621904	et	2	main
suitsetada	doc_491521502177_item	2621909	et	3	main
8	doc_491521502177_item	2621913	et	2	main
küll	doc_491521502177_item	2621916	et	4	main
aga	doc_491521502177_item	2621918	et	3	main
9	doc_491521502177_item	2621922	et	2	main
sa	doc_491521502177_item	2621924	et	3	main
eesti	doc_491521502178_item	2621939	et	4	main
olevad	doc_491521502178_item	2621945	et	4	main
on	doc_491521502178_item	2621951	et	4	main
ettevõtlik	doc_491521502178_item	2621952	et	3	main
naine	doc_491521502178_item	2621953	et	3	main
kuulutuse	doc_491521502178_item	2621960	et	4	main
et	doc_491521502178_item	2621961	et	3	main
siberisse	doc_491521502178_item	2621962	et	4	main
tuli	doc_491521502178_item	2622005	et	4	main
vastu	doc_491521502178_item	2622006	et	3	main
korralik	doc_491521502178_item	2622007	et	3	main
korraliku	doc_491521502178_item	2622008	et	3	main
audiga	doc_491521502178_item	2622009	et	3	main
selline	doc_491521502178_item	2622014	et	4	main
lendama	doc_491521502178_item	2622019	et	3	main
noor	doc_491521502178_item	2622026	et	3	main
ja	doc_491521502178_item	2622027	et	3	main
tahtmise	doc_491521502178_item	2622029	et	4	main
algust	doc_491521502178_item	2622034	et	4	main
koht	doc_491521502178_item	2622035	et	3	main
kogu	doc_491521502178_item	2622043	et	4	main
tähtis	doc_491521502178_item	2622053	et	4	main
ettevõtmine	doc_491521502178_item	2622054	et	3	main
salves	doc_491521502178_item	2622059	et	4	main
hooga	doc_491521502178_item	2622065	et	3	main
teistmoodi	doc_491521502178_item	2622070	et	3	main
mõnd	doc_491521502178_item	2622083	et	3	main
kool	doc_491521502178_item	2622085	et	4	main
ja	doc_491521502178_item	2622090	et	3	main
külas	doc_491521502178_item	2622097	et	3	main
üle	doc_491521502178_item	2622100	et	3	main
inimene	doc_491521502178_item	2622102	et	3	main
emakeelt	doc_491521502178_item	2622104	et	4	main
sõnul	doc_491521502178_item	2622109	et	3	main
õpivad	doc_491521502178_item	2622110	et	3	main
siberi	doc_491521502178_item	2622121	et	4	main
piret	doc_491521502178_item	2622123	et	4	main
ei	doc_491521502178_item	2622124	et	4	main
kartma	doc_491521502178_item	2622125	et	3	main
on	doc_491521502178_item	2622133	et	4	main
kuid	doc_491521502178_item	2622137	et	4	main
jahe	doc_491521502178_item	2622140	et	3	main
kütmine	doc_491521502178_item	2622147	et	4	main
külapoest	doc_491521502178_item	2622153	et	4	main
iii	doc_491521502178_item	2622170	et	4	main
ja	doc_491521502178_item	2622179	et	3	main
võib	doc_491521502178_item	2622222	et	3	main
tagajärgu	doc_491521502178_item	2622225	et	3	main
laskma	doc_491521502178_item	2622229	et	3	main
tohti	doc_491521502178_item	2622239	et	4	main
ülekoormust	doc_491521502178_item	2622241	et	4	main
tekkida	doc_491521502178_item	2622242	et	3	main
saama	doc_491521502178_item	2622253	et	4	main
nii	doc_491521502178_item	2622254	et	3	main
ja	doc_491521502178_item	2622262	et	3	main
on	doc_491521502178_item	2622265	et	4	main
telesaade	doc_491521502178_item	2622293	et	4	main
varahommiku	doc_491521502178_item	2622301	et	3	main
valmistamist	doc_491521502178_item	2622305	et	4	main
maale	doc_491521502177_item	2621926	et	4	main
või	doc_491521502177_item	2621927	et	4	main
jääd	doc_491521502177_item	2621928	et	4	main
eesti	doc_491521502178_item	2621936	et	4	main
keele	doc_491521502178_item	2621937	et	4	main
test	doc_491521502178_item	2621938	et	3	main
sulgudes	doc_491521502178_item	2621944	et	4	main
ta	doc_491521502178_item	2621957	et	4	main
kuulutus	doc_491521502178_item	2621959	et	4	main
otsitakse	doc_491521502178_item	2621966	et	3	main
õpetajat	doc_491521502178_item	2621969	et	4	main
piret	doc_491521502178_item	2621970	et	4	main
võitis	doc_491521502178_item	2621971	et	3	main
konkurss	doc_491521502178_item	2621972	et	3	main
konkurssi	doc_491521502178_item	2621973	et	4	main
ja	doc_491521502178_item	2621974	et	3	main
on	doc_491521502178_item	2621975	et	4	main
nüüd	doc_491521502178_item	2621976	et	4	main
juba	doc_491521502178_item	2621977	et	3	main
üle	doc_491521502178_item	2621978	et	3	main
nädal	doc_491521502178_item	2621979	et	3	main
nädalat	doc_491521502178_item	2621980	et	3	main
väikestele	doc_491521502178_item	2621981	et	4	main
eestlastele	doc_491521502178_item	2621982	et	4	main
need	doc_491521502178_item	2621983	et	3	main
nende	doc_491521502178_item	2621984	et	4	main
emakeelt	doc_491521502178_item	2621985	et	4	main
õpetama	doc_491521502178_item	2621986	et	3	main
õpetab	doc_491521502178_item	2621987	et	3	main
pireti	doc_491521502178_item	2621988	et	4	main
mulle	doc_491521502178_item	2622003	et	4	main
siber	doc_491521502178_item	2622012	et	4	main
siberist	doc_491521502178_item	2622013	et	4	main
seal	doc_491521502178_item	2622017	et	4	main
täis	doc_491521502178_item	2622030	et	4	main
piret	doc_491521502178_item	2622031	et	4	main
polnud	doc_491521502178_item	2622038	et	3	main
kool	doc_491521502178_item	2622039	et	4	main
võttis	doc_491521502178_item	2622046	et	3	main
kartuleid	doc_491521502178_item	2622047	et	3	main
kartulivõtt	doc_491521502178_item	2622048	et	3	main
ja	doc_491521502178_item	2622060	et	3	main
kuidagi	doc_491521502178_item	2622069	et	3	main
mõnusalt	doc_491521502178_item	2622074	et	4	main
mahlakalt	doc_491521502178_item	2622075	et	4	main
venemaa	doc_491521502178_item	2622088	et	4	main
veidi	doc_491521502178_item	2622099	et	3	main
kolmsada	doc_491521502178_item	2622101	et	4	main
rääkida	doc_491521502178_item	2622107	et	3	main
karda	doc_491521502178_item	2622126	et	4	main
päevad	doc_491521502178_item	2622134	et	3	main
ööd	doc_491521502178_item	2622138	et	4	main
juba	doc_491521502178_item	2622139	et	3	main
vildid	doc_491521502178_item	2622154	et	4	main
seal	doc_491521502178_item	2622156	et	4	main
naerab	doc_491521502178_item	2622161	et	3	main
talveks	doc_491521502178_item	2622162	et	4	main
valmistuma	doc_491521502178_item	2622163	et	3	main
valmistub	doc_491521502178_item	2622164	et	3	main
slõhtuleht	doc_491521502178_item	2622169	et	4	main
sõnadest	doc_491521502178_item	2622173	et	3	main
vormi	doc_491521502178_item	2622178	et	4	main
kasutades	doc_491521502178_item	2622180	et	3	main
ega	doc_491521502178_item	2622022	et	3	main
kohale	doc_491521502178_item	2622036	et	4	main
jõudis	doc_491521502178_item	2622037	et	3	main
küla	doc_491521502178_item	2622044	et	4	main
võtma	doc_491521502178_item	2622045	et	3	main
on	doc_491521502178_item	2622049	et	4	main
siin	doc_491521502178_item	2622050	et	4	main
kartul	doc_491521502178_item	2622057	et	3	main
hoog	doc_491521502178_item	2622064	et	3	main
eestlased	doc_491521502178_item	2622067	et	3	main
ja	doc_491521502178_item	2622072	et	3	main
aktsent	doc_491521502178_item	2622078	et	3	main
vaid	doc_491521502178_item	2622080	et	3	main
ülejäänud	doc_491521502178_item	2622091	et	4	main
aine	doc_491521502178_item	2622092	et	4	main
elab	doc_491521502178_item	2622098	et	3	main
kõik	doc_491521502178_item	2622106	et	4	main
poolpõlenud	doc_491521502178_item	2622112	et	4	main
saatma	doc_491521502178_item	2622116	et	3	main
saadavad	doc_491521502178_item	2622117	et	4	main
eestist	doc_491521502178_item	2622118	et	3	main
uued	doc_491521502178_item	2622119	et	3	main
õpikud	doc_491521502178_item	2622120	et	3	main
mulle	doc_491521502178_item	2622127	et	4	main
juba	doc_491521502178_item	2622128	et	3	main
veel	doc_491521502178_item	2622135	et	4	main
kütmist	doc_491521502178_item	2622148	et	4	main
kui	doc_491521502178_item	2622149	et	3	main
ega	doc_491521502178_item	2622155	et	3	main
muud	doc_491521502178_item	2622158	et	4	main
ei	doc_491521502178_item	2622159	et	4	main
müüdagi	doc_491521502178_item	2622160	et	3	main
ajalehest	doc_491521502178_item	2622168	et	4	main
etteantud	doc_491521502178_item	2622172	et	4	main
sõnad	doc_491521502178_item	2622176	et	4	main
kirjavahemärke	doc_491521502178_item	2622181	et	4	main
naised	doc_491521502178_item	2622185	et	3	main
naiselikum	doc_491521502178_item	2622186	et	4	main
ja	doc_491521502178_item	2622187	et	3	main
mehed	doc_491521502178_item	2622188	et	3	main
soovimatu	doc_491521502178_item	2622224	et	4	main
saama	doc_491521502178_item	2622233	et	4	main
sportida	doc_491521502178_item	2622246	et	4	main
puhata	doc_491521502178_item	2622248	et	4	main
olema	doc_491521502178_item	2622251	et	4	main
tänapäev	doc_491521502178_item	2622252	et	3	main
elama	doc_491521502178_item	2622261	et	3	main
tänapäeval	doc_491521502178_item	2622266	et	3	main
maagiline	doc_491521502178_item	2622268	et	4	main
vaatamine	doc_491521502178_item	2622294	et	4	main
pühapäeva	doc_491521502178_item	2622300	et	4	main
segab	doc_491521502178_item	2622303	et	3	main
huvitavat	doc_491521502178_item	2622309	et	4	main
pange	doc_491521502178_item	2622314	et	4	main
väga	doc_491521502178_item	2622323	et	3	main
oma	doc_491521502178_item	2622327	et	4	main
aitavad	doc_491521502178_item	2622331	et	4	main
kõike	doc_491521502178_item	2622333	et	4	main
ja	doc_491521502178_item	2622334	et	3	main
usaldavad	doc_491521502178_item	2622335	et	4	main
igaüks	doc_491521502178_item	2622336	et	3	main
igaüht	doc_491521502178_item	2622337	et	3	main
2	doc_491521502178_item	2622338	et	2	main
3	doc_491521502178_item	2622343	et	2	main
et	doc_491521502178_item	2622346	et	3	main
huvitud	doc_491521502178_item	2622348	et	4	main
sa	doc_491521502178_item	2622352	et	3	main
ja	doc_491521502178_item	2622358	et	3	main
töökoht	doc_491521502178_item	2622376	et	3	main
teine	doc_491521502178_item	2622393	et	3	main
täie	doc_491521502178_item	2622063	et	3	main
mõnus	doc_491521502178_item	2622071	et	4	main
mahlakas	doc_491521502178_item	2622073	et	4	main
vene	doc_491521502178_item	2622077	et	4	main
nagu	doc_491521502178_item	2622081	et	3	main
murret	doc_491521502178_item	2622084	et	4	main
on	doc_491521502178_item	2622086	et	4	main
siiski	doc_491521502178_item	2622087	et	4	main
ained	doc_491521502178_item	2622093	et	3	main
õpetatakse	doc_491521502178_item	2622094	et	3	main
vene	doc_491521502178_item	2622095	et	4	main
inimest	doc_491521502178_item	2622103	et	3	main
saab	doc_491521502178_item	2622105	et	3	main
tõid	doc_491521502178_item	2622130	et	4	main
talvepuud	doc_491521502178_item	2622131	et	4	main
praegu	doc_491521502178_item	2622132	et	3	main
ahju	doc_491521502178_item	2622146	et	4	main
külapood	doc_491521502178_item	2622152	et	3	main
suurt	doc_491521502178_item	2622157	et	3	main
vapralt	doc_491521502178_item	2622166	et	4	main
lühendatud	doc_491521502178_item	2622167	et	4	main
laused	doc_491521502178_item	2622174	et	3	main
pannes	doc_491521502178_item	2622175	et	4	main
mehelikum	doc_491521502178_item	2622189	et	4	main
igaüks	doc_491521502178_item	2622190	et	3	main
kaunim	doc_491521502178_item	2622191	et	4	main
naeratus	doc_491521502178_item	2622192	et	4	main
teeb	doc_491521502178_item	2622193	et	3	main
naisi	doc_491521502178_item	2622194	et	3	main
naiselikum	doc_491521502178_item	2622195	et	4	main
ja	doc_491521502178_item	2622196	et	3	main
mehi	doc_491521502178_item	2622197	et	3	main
mehelikum	doc_491521502178_item	2622198	et	4	main
igaühe	doc_491521502178_item	2622199	et	4	main
kaunim	doc_491521502178_item	2622200	et	4	main
paras	doc_491521502178_item	2622202	et	3	main
kogus	doc_491521502178_item	2622203	et	4	main
stress	doc_491521502178_item	2622204	et	3	main
3	doc_491521502178_item	2622201	et	2	main
panema	doc_491521502178_item	2622205	et	3	main
meie	doc_491521502178_item	2622206	et	4	main
tegutsema	doc_491521502178_item	2622207	et	3	main
aga	doc_491521502178_item	2622208	et	3	main
lisakoormus	doc_491521502178_item	2622209	et	3	main
võima	doc_491521502178_item	2622210	et	3	main
tooma	doc_491521502178_item	2622211	et	3	main
soovimatu	doc_491521502178_item	2622212	et	4	main
tagajärg	doc_491521502178_item	2622213	et	3	main
paras	doc_491521502178_item	2622214	et	3	main
kogus	doc_491521502178_item	2622215	et	4	main
stress	doc_491521502178_item	2622216	et	3	main
paneb	doc_491521502178_item	2622217	et	3	main
tegutsema	doc_491521502178_item	2622219	et	3	main
aga	doc_491521502178_item	2622220	et	3	main
meid	doc_491521502178_item	2622218	et	4	main
tuua	doc_491521502178_item	2622223	et	3	main
tekkima	doc_491521502178_item	2622231	et	3	main
sportima	doc_491521502178_item	2622235	et	4	main
ja	doc_491521502178_item	2622236	et	3	main
puhkama	doc_491521502178_item	2622237	et	3	main
ei	doc_491521502178_item	2622238	et	4	main
maandada	doc_491521502178_item	2622245	et	3	main
abil	doc_491521502178_item	2622259	et	4	main
naeratus	doc_491521502178_item	2622183	et	4	main
tegema	doc_491521502178_item	2622184	et	3	main
4	doc_491521502178_item	2622226	et	2	main
tohtima	doc_491521502178_item	2622228	et	3	main
ülekoormus	doc_491521502178_item	2622230	et	3	main
laskma	doc_491521502178_item	2622240	et	3	main
pinget	doc_491521502178_item	2622243	et	3	main
5	doc_491521502178_item	2622249	et	2	main
telefon	doc_491521502178_item	2622250	et	3	main
maagiline	doc_491521502178_item	2622255	et	4	main
aparaat	doc_491521502178_item	2622256	et	3	main
et	doc_491521502178_item	2622257	et	3	main
see	doc_491521502178_item	2622258	et	3	main
hingama	doc_491521502178_item	2622263	et	3	main
nii	doc_491521502178_item	2622267	et	3	main
pahandab	doc_491521502178_item	2622291	et	3	main
huvitav	doc_491521502178_item	2622292	et	4	main
ka	doc_491521502178_item	2622299	et	3	main
une	doc_491521502178_item	2622302	et	3	main
telesaade	doc_491521502178_item	2622310	et	4	main
vaatamise	doc_491521502178_item	2622311	et	4	main
ajal	doc_491521502178_item	2622312	et	4	main
pean	doc_491521502178_item	2622322	et	4	main
lugu	doc_491521502178_item	2622324	et	4	main
sest	doc_491521502178_item	2622329	et	4	main
nõuded	doc_491521502178_item	2622341	et	3	main
sport	doc_491521502178_item	2622349	et	3	main
aga	doc_491521502178_item	2622351	et	3	main
difteeria	doc_491521502178_item	2622371	et	4	main
difteeriad	doc_491521502178_item	2622372	et	3	main
uus	doc_491521502178_item	2622375	et	3	main
kiiresti	doc_491521502178_item	2622379	et	3	main
selles	doc_491521502178_item	2622382	et	4	main
sidenditega	doc_491521502178_item	2622421	et	3	main
lõuna	doc_491521502178_item	2622425	et	4	main
see	doc_491521502178_item	2622427	et	3	main
palju	doc_491521502178_item	2622429	et	4	main
2	doc_491521502178_item	2622430	et	2	main
keegi	doc_491521502178_item	2622451	et	4	main
just	doc_491521502178_item	2622452	et	3	main
anekdooti	doc_491521502178_item	2622453	et	4	main
trenni	doc_491521502178_item	2622459	et	4	main
lõpetage	doc_491521502178_item	2622465	et	3	main
tohi	doc_491521502178_item	2622474	et	4	main
suitsetada	doc_491521502178_item	2622475	et	3	main
ning	doc_491521502178_item	2622476	et	3	main
sõidad	doc_491521502178_item	2622491	et	3	main
või	doc_491521502178_item	2622493	et	4	main
linna	doc_491521502178_item	2622495	et	4	main
10	doc_491521502178_item	2622496	et	2	main
avasin	doc_491521502178_item	2622497	et	3	main
ukse	doc_491521502178_item	2622498	et	3	main
kui	doc_491521502178_item	2622499	et	3	main
kuulsin	doc_491521502178_item	2622500	et	3	main
keele	doc_491521502179_item	2622506	et	4	main
kuulutust	doc_491521502179_item	2622526	et	4	main
piret	doc_491521502179_item	2622536	et	4	main
võitis	doc_491521502179_item	2622537	et	3	main
konkurss	doc_491521502179_item	2622538	et	3	main
eestlastele	doc_491521502179_item	2622548	et	4	main
kinnitusel	doc_491521502179_item	2622555	et	4	main
siberisse	doc_491521502179_item	2622558	et	4	main
jõudma	doc_491521502179_item	2622559	et	3	main
mulle	doc_491521502179_item	2622569	et	4	main
rohi	doc_491521502179_item	2622590	et	4	main
pärast	doc_491521502179_item	2622598	et	4	main
küla	doc_491521502179_item	2622610	et	4	main
võtma	doc_491521502179_item	2622611	et	3	main
võttis	doc_491521502179_item	2622612	et	3	main
kartuleid	doc_491521502179_item	2622613	et	3	main
kartulivõtt	doc_491521502179_item	2622614	et	3	main
on	doc_491521502179_item	2622615	et	4	main
tähtsaim	doc_491521502179_item	2622620	et	4	main
ettevõtmine	doc_491521502179_item	2622621	et	3	main
kartul	doc_491521502179_item	2622624	et	3	main
ja	doc_491521502179_item	2622627	et	3	main
eestlased	doc_491521502179_item	2622634	et	3	main
kuidagi	doc_491521502179_item	2622636	et	3	main
mõnus	doc_491521502179_item	2622638	et	4	main
mahlakas	doc_491521502179_item	2622640	et	4	main
mõnusamalt	doc_491521502179_item	2622641	et	4	main
lisakoormus	doc_491521502178_item	2622221	et	3	main
ei	doc_491521502178_item	2622227	et	4	main
pinge	doc_491521502178_item	2622232	et	4	main
maandama	doc_491521502178_item	2622234	et	3	main
saab	doc_491521502178_item	2622244	et	3	main
ja	doc_491521502178_item	2622247	et	3	main
lausa	doc_491521502178_item	2622260	et	4	main
aparaat	doc_491521502178_item	2622269	et	3	main
et	doc_491521502178_item	2622270	et	3	main
selle	doc_491521502178_item	2622271	et	4	main
abil	doc_491521502178_item	2622272	et	4	main
saab	doc_491521502178_item	2622273	et	3	main
lausa	doc_491521502178_item	2622274	et	4	main
elada	doc_491521502178_item	2622275	et	3	main
ja	doc_491521502178_item	2622276	et	3	main
hingata	doc_491521502178_item	2622277	et	4	main
6	doc_491521502178_item	2622278	et	2	main
kuid	doc_491521502178_item	2622279	et	4	main
telefonihelin	doc_491521502178_item	2622280	et	3	main
katkestama	doc_491521502178_item	2622281	et	3	main
ka	doc_491521502178_item	2622282	et	3	main
pühapäev	doc_491521502178_item	2622283	et	3	main
varahommik	doc_491521502178_item	2622284	et	3	main
uni	doc_491521502178_item	2622285	et	3	main
segama	doc_491521502178_item	2622286	et	3	main
lõunasöök	doc_491521502178_item	2622287	et	3	main
valmistamine	doc_491521502178_item	2622288	et	4	main
ja	doc_491521502178_item	2622289	et	3	main
söömine	doc_491521502178_item	2622290	et	4	main
telefon	doc_491521502178_item	2622264	et	3	main
telefonihelin	doc_491521502178_item	2622297	et	3	main
lõunasööki	doc_491521502178_item	2622304	et	4	main
olevad	doc_491521502178_item	2622316	et	4	main
vanemad	doc_491521502178_item	2622326	et	4	main
kohandasin	doc_491521502178_item	2622339	et	3	main
sa	doc_491521502178_item	2622347	et	3	main
naised	doc_491521502178_item	2622357	et	3	main
autod	doc_491521502178_item	2622360	et	3	main
naisi	doc_491521502178_item	2622362	et	3	main
kiireid	doc_491521502178_item	2622364	et	4	main
autosid	doc_491521502178_item	2622365	et	3	main
uue	doc_491521502178_item	2622377	et	3	main
6	doc_491521502178_item	2622380	et	2	main
küsimuses	doc_491521502178_item	2622383	et	4	main
väikesed	doc_491521502178_item	2622385	et	4	main
väikesi	doc_491521502178_item	2622387	et	4	main
muudatusi	doc_491521502178_item	2622388	et	3	main
7	doc_491521502178_item	2622389	et	2	main
see	doc_491521502178_item	2622390	et	3	main
tellisime	doc_491521502178_item	2622423	et	4	main
kui	doc_491521502178_item	2622435	et	3	main
õpetajad	doc_491521502178_item	2622436	et	4	main
tagasi	doc_491521502178_item	2622443	et	3	main
kõrvallauast	doc_491521502178_item	2622446	et	4	main
naeru	doc_491521502178_item	2622448	et	4	main
see	doc_491521502178_item	2622449	et	3	main
oleks	doc_491521502178_item	2622450	et	3	main
tule	doc_491521502178_item	2622458	et	4	main
teatrisse	doc_491521502178_item	2622463	et	3	main
töö	doc_491521502178_item	2622466	et	4	main
lähete	doc_491521502178_item	2622468	et	4	main
7	doc_491521502178_item	2622470	et	2	main
selles	doc_491521502178_item	2622471	et	4	main
baaris	doc_491521502178_item	2622472	et	3	main
ei	doc_491521502178_item	2622473	et	4	main
8	doc_491521502178_item	2622479	et	2	main
töötasid	doc_491521502178_item	2622481	et	4	main
pingsalt	doc_491521502178_item	2622483	et	4	main
ei	doc_491521502178_item	2622486	et	4	main
9	doc_491521502178_item	2622488	et	2	main
maale	doc_491521502178_item	2622492	et	4	main
jääd	doc_491521502178_item	2622494	et	4	main
eesti	doc_491521502179_item	2622505	et	4	main
nägis	doc_491521502179_item	2622522	et	4	main
on	doc_491521502179_item	2622541	et	4	main
nüüd	doc_491521502179_item	2622542	et	4	main
juba	doc_491521502179_item	2622543	et	3	main
üle	doc_491521502179_item	2622544	et	3	main
nädal	doc_491521502179_item	2622545	et	3	main
nädala	doc_491521502179_item	2622546	et	3	main
väikestele	doc_491521502179_item	2622547	et	4	main
õpetama	doc_491521502179_item	2622552	et	3	main
noor	doc_491521502179_item	2622592	et	3	main
ja	doc_491521502179_item	2622593	et	3	main
õppeaasta	doc_491521502179_item	2622599	et	4	main
kool	doc_491521502179_item	2622605	et	4	main
algama	doc_491521502179_item	2622607	et	3	main
õppimine	doc_491521502179_item	2622628	et	4	main
teistmoodi	doc_491521502179_item	2622637	et	3	main
aktsenti	doc_491521502179_item	2622647	et	4	main
venemaa	doc_491521502179_item	2622656	et	4	main
külas	doc_491521502179_item	2622665	et	3	main
kolmsada	doc_491521502179_item	2622669	et	4	main
inimene	doc_491521502179_item	2622671	et	3	main
saatma	doc_491521502179_item	2622686	et	3	main
saadakse	doc_491521502179_item	2622687	et	3	main
mulle	doc_491521502179_item	2622697	et	4	main
praegu	doc_491521502179_item	2622702	et	3	main
jahe	doc_491521502179_item	2622711	et	3	main
juba	doc_491521502179_item	2622714	et	3	main
ostan	doc_491521502179_item	2622722	et	3	main
külapood	doc_491521502179_item	2622723	et	3	main
vildid	doc_491521502179_item	2622725	et	4	main
ega	doc_491521502179_item	2622726	et	3	main
suurt	doc_491521502179_item	2622728	et	3	main
muud	doc_491521502179_item	2622729	et	4	main
valmistuma	doc_491521502179_item	2622734	et	3	main
naised	doc_491521502179_item	2622756	et	3	main
naiselikum	doc_491521502179_item	2622757	et	4	main
ja	doc_491521502179_item	2622758	et	3	main
aeg	doc_491521502178_item	2622295	et	3	main
kuid	doc_491521502178_item	2622296	et	4	main
katkestab	doc_491521502178_item	2622298	et	3	main
sulgudes	doc_491521502178_item	2622315	et	4	main
ma	doc_491521502178_item	2622321	et	3	main
vanematest	doc_491521502178_item	2622328	et	4	main
nad	doc_491521502178_item	2622330	et	3	main
artikli	doc_491521502178_item	2622340	et	3	main
ma	doc_491521502178_item	2622344	et	3	main
sporti	doc_491521502178_item	2622350	et	4	main
tunned	doc_491521502178_item	2622353	et	3	main
huvi	doc_491521502178_item	2622354	et	4	main
ainult	doc_491521502178_item	2622355	et	4	main
kiired	doc_491521502178_item	2622359	et	4	main
ilusaid	doc_491521502178_item	2622361	et	3	main
ja	doc_491521502178_item	2622363	et	3	main
on	doc_491521502178_item	2622368	et	4	main
haigestuda	doc_491521502178_item	2622370	et	3	main
5	doc_491521502178_item	2622373	et	2	main
tüdinesin	doc_491521502178_item	2622374	et	3	main
küsimus	doc_491521502178_item	2622391	et	4	main
kuulub	doc_491521502178_item	2622392	et	3	main
olid	doc_491521502178_item	2622432	et	4	main
nii	doc_491521502178_item	2622433	et	3	main
õpilased	doc_491521502178_item	2622434	et	3	main
vanemad	doc_491521502178_item	2622442	et	4	main
rääkinud	doc_491521502178_item	2622454	et	4	main
sest	doc_491521502178_item	2622460	et	4	main
hoopis	doc_491521502178_item	2622462	et	3	main
siis	doc_491521502178_item	2622467	et	3	main
tarbida	doc_491521502178_item	2622478	et	3	main
sa	doc_491521502178_item	2622490	et	3	main
ta	doc_491521502179_item	2622523	et	4	main
ja	doc_491521502178_item	2622306	et	3	main
söömist	doc_491521502178_item	2622307	et	4	main
pahandab	doc_491521502178_item	2622308	et	3	main
iv	doc_491521502178_item	2622313	et	4	main
sõnad	doc_491521502178_item	2622317	et	4	main
õigesse	doc_491521502178_item	2622318	et	3	main
vormi	doc_491521502178_item	2622319	et	4	main
1	doc_491521502178_item	2622320	et	2	main
oma	doc_491521502178_item	2622325	et	4	main
kõik	doc_491521502178_item	2622332	et	4	main
nõuetega	doc_491521502178_item	2622342	et	4	main
arvasin	doc_491521502178_item	2622345	et	3	main
ilusad	doc_491521502178_item	2622356	et	3	main
4	doc_491521502178_item	2622366	et	2	main
praegu	doc_491521502178_item	2622367	et	3	main
oht	doc_491521502178_item	2622369	et	3	main
töökoha	doc_491521502178_item	2622378	et	4	main
piirdusime	doc_491521502178_item	2622381	et	3	main
vaid	doc_491521502178_item	2622384	et	3	main
muudatused	doc_491521502178_item	2622386	et	3	main
valdkond	doc_491521502178_item	2622394	et	3	main
teisele	doc_491521502178_item	2622395	et	4	main
valdkonnale	doc_491521502178_item	2622396	et	4	main
8	doc_491521502178_item	2622397	et	2	main
närimiskumm	doc_491521502178_item	2622398	et	3	main
kleepus	doc_491521502178_item	2622399	et	3	main
püksid	doc_491521502178_item	2622400	et	3	main
püksidele	doc_491521502178_item	2622401	et	3	main
9	doc_491521502178_item	2622402	et	2	main
külmal	doc_491521502178_item	2622403	et	3	main
ajal	doc_491521502178_item	2622404	et	4	main
peab	doc_491521502178_item	2622405	et	4	main
hoiduma	doc_491521502178_item	2622406	et	3	main
külmetamine	doc_491521502178_item	2622407	et	4	main
külmetamist	doc_491521502178_item	2622408	et	4	main
10	doc_491521502178_item	2622409	et	2	main
ma	doc_491521502178_item	2622410	et	3	main
tunnen	doc_491521502178_item	2622411	et	3	main
rõõmu	doc_491521502178_item	2622412	et	4	main
suvine	doc_491521502178_item	2622413	et	4	main
päike	doc_491521502178_item	2622414	et	3	main
suvist	doc_491521502178_item	2622415	et	4	main
päikest	doc_491521502178_item	2622416	et	4	main
v	doc_491521502178_item	2622417	et	4	main
täitke	doc_491521502178_item	2622418	et	3	main
lüngad	doc_491521502178_item	2622419	et	3	main
sobivate	doc_491521502178_item	2622420	et	4	main
1	doc_491521502178_item	2622422	et	2	main
maksis	doc_491521502178_item	2622428	et	4	main
kohal	doc_491521502178_item	2622431	et	4	main
tulevad	doc_491521502178_item	2622444	et	4	main
5	doc_491521502178_item	2622455	et	2	main
ta	doc_491521502178_item	2622456	et	4	main
läheb	doc_491521502178_item	2622461	et	3	main
nad	doc_491521502178_item	2622480	et	3	main
tulemust	doc_491521502178_item	2622485	et	4	main
olnud	doc_491521502178_item	2622487	et	4	main
kas	doc_491521502178_item	2622489	et	3	main
eesti	doc_491521502179_item	2622502	et	4	main
keele	doc_491521502179_item	2622503	et	4	main
test	doc_491521502179_item	2622504	et	3	main
i	doc_491521502179_item	2622508	et	4	main
ajalehes	doc_491521502179_item	2622524	et	3	main
et	doc_491521502179_item	2622527	et	3	main
kolmekäigulise	doc_491521502178_item	2622424	et	4	main
kuigi	doc_491521502178_item	2622426	et	3	main
3	doc_491521502178_item	2622437	et	2	main
lapsel	doc_491521502178_item	2622438	et	4	main
paluti	doc_491521502178_item	2622439	et	3	main
oodata	doc_491521502178_item	2622440	et	4	main
kuni	doc_491521502178_item	2622441	et	3	main
4	doc_491521502178_item	2622445	et	2	main
kostis	doc_491521502178_item	2622447	et	4	main
ei	doc_491521502178_item	2622457	et	4	main
6	doc_491521502178_item	2622464	et	2	main
jalutama	doc_491521502178_item	2622469	et	3	main
alkoholi	doc_491521502178_item	2622477	et	4	main
küll	doc_491521502178_item	2622482	et	4	main
aga	doc_491521502178_item	2622484	et	3	main
koputust	doc_491521502178_item	2622501	et	4	main
test	doc_491521502179_item	2622507	et	3	main
pange	doc_491521502179_item	2622509	et	4	main
sulgudes	doc_491521502179_item	2622510	et	4	main
olevad	doc_491521502179_item	2622511	et	4	main
sõnad	doc_491521502179_item	2622512	et	4	main
õigesse	doc_491521502179_item	2622513	et	3	main
vormi	doc_491521502179_item	2622514	et	4	main
piret	doc_491521502179_item	2622515	et	4	main
toomet	doc_491521502179_item	2622516	et	4	main
on	doc_491521502179_item	2622517	et	4	main
ettevõtlik	doc_491521502179_item	2622518	et	3	main
naine	doc_491521502179_item	2622519	et	3	main
suvel	doc_491521502179_item	2622520	et	3	main
nägema	doc_491521502179_item	2622521	et	3	main
eesti	doc_491521502179_item	2622533	et	4	main
emakeelt	doc_491521502179_item	2622551	et	4	main
pireti	doc_491521502179_item	2622554	et	4	main
tundis	doc_491521502179_item	2622556	et	3	main
ta	doc_491521502179_item	2622557	et	4	main
üsna	doc_491521502179_item	2622565	et	3	main
üllatuma	doc_491521502179_item	2622566	et	3	main
üllatunud	doc_491521502179_item	2622567	et	4	main
kui	doc_491521502179_item	2622568	et	3	main
tahtmist	doc_491521502179_item	2622595	et	4	main
täis	doc_491521502179_item	2622596	et	4	main
kuulutus	doc_491521502179_item	2622525	et	4	main
ülem-suetuki	doc_491521502179_item	2622529	et	4	main
küla	doc_491521502179_item	2622530	et	4	main
külas	doc_491521502179_item	2622531	et	3	main
otsitakse	doc_491521502179_item	2622532	et	3	main
konkurssi	doc_491521502179_item	2622539	et	4	main
ja	doc_491521502179_item	2622540	et	3	main
need	doc_491521502179_item	2622549	et	3	main
jõudnud	doc_491521502179_item	2622560	et	4	main
et	doc_491521502179_item	2622561	et	3	main
on	doc_491521502179_item	2622562	et	4	main
oodatud	doc_491521502179_item	2622563	et	4	main
olin	doc_491521502179_item	2622564	et	3	main
tulema	doc_491521502179_item	2622570	et	4	main
tuli	doc_491521502179_item	2622571	et	4	main
vastu	doc_491521502179_item	2622572	et	3	main
korralik	doc_491521502179_item	2622573	et	3	main
korraliku	doc_491521502179_item	2622574	et	3	main
audiga	doc_491521502179_item	2622575	et	3	main
mulle	doc_491521502179_item	2622576	et	4	main
maaliti	doc_491521502179_item	2622577	et	3	main
siber	doc_491521502179_item	2622578	et	4	main
siberist	doc_491521502179_item	2622579	et	4	main
selline	doc_491521502179_item	2622580	et	4	main
pilt	doc_491521502179_item	2622581	et	3	main
et	doc_491521502179_item	2622582	et	3	main
seal	doc_491521502179_item	2622583	et	4	main
ei	doc_491521502179_item	2622584	et	4	main
lendama	doc_491521502179_item	2622585	et	3	main
lenda	doc_491521502179_item	2622586	et	4	main
lind	doc_491521502179_item	2622587	et	3	main
siberisse	doc_491521502179_item	2622528	et	4	main
keele	doc_491521502179_item	2622534	et	4	main
õpetajat	doc_491521502179_item	2622535	et	4	main
neile	doc_491521502179_item	2622550	et	4	main
õpetamast	doc_491521502179_item	2622553	et	3	main
kasva	doc_491521502179_item	2622589	et	4	main
kui	doc_491521502179_item	2622591	et	3	main
tahtmine	doc_491521502179_item	2622594	et	4	main
algust	doc_491521502179_item	2622600	et	4	main
koht	doc_491521502179_item	2622601	et	3	main
kohale	doc_491521502179_item	2622602	et	4	main
jõudis	doc_491521502179_item	2622603	et	3	main
veel	doc_491521502179_item	2622606	et	4	main
siin	doc_491521502179_item	2622616	et	4	main
sügisel	doc_491521502179_item	2622617	et	3	main
kõige	doc_491521502179_item	2622618	et	4	main
tähtis	doc_491521502179_item	2622619	et	4	main
käib	doc_491521502179_item	2622629	et	3	main
räägivad	doc_491521502179_item	2622635	et	3	main
ja	doc_491521502179_item	2622639	et	3	main
mahlasemalt	doc_491521502179_item	2622643	et	4	main
mitte	doc_491521502179_item	2622644	et	3	main
kool	doc_491521502179_item	2622657	et	4	main
ja	doc_491521502179_item	2622658	et	3	main
ülejäänud	doc_491521502179_item	2622659	et	4	main
elab	doc_491521502179_item	2622666	et	3	main
kolmsaja	doc_491521502179_item	2622670	et	4	main
emakeelt	doc_491521502179_item	2622673	et	4	main
kõiged	doc_491521502179_item	2622676	et	4	main
siberi	doc_491521502179_item	2622691	et	4	main
talve	doc_491521502179_item	2622692	et	4	main
tooma	doc_491521502179_item	2622699	et	3	main
ööd	doc_491521502179_item	2622709	et	4	main
suure	doc_491521502179_item	2622715	et	3	main
külapoes	doc_491521502179_item	2622724	et	3	main
valmistudes	doc_491521502179_item	2622735	et	3	main
slõhtuleht	doc_491521502179_item	2622740	et	4	main
etteantud	doc_491521502179_item	2622743	et	4	main
pannes	doc_491521502179_item	2622746	et	4	main
ja	doc_491521502179_item	2622750	et	3	main
igaüks	doc_491521502179_item	2622761	et	3	main
kaunim	doc_491521502179_item	2622762	et	4	main
naeratamine	doc_491521502179_item	2622763	et	4	main
teeb	doc_491521502179_item	2622764	et	3	main
meie	doc_491521502179_item	2622777	et	4	main
tegutsema	doc_491521502179_item	2622778	et	3	main
aga	doc_491521502179_item	2622779	et	3	main
telefon	doc_491521502179_item	2622821	et	3	main
lausa	doc_491521502179_item	2622831	et	4	main
maagilist	doc_491521502179_item	2622840	et	4	main
aparaadi	doc_491521502179_item	2622841	et	3	main
et	doc_491521502179_item	2622842	et	3	main
selle	doc_491521502179_item	2622843	et	4	main
6	doc_491521502179_item	2622849	et	2	main
uni	doc_491521502179_item	2622856	et	3	main
aeg	doc_491521502179_item	2622866	et	3	main
söömisele	doc_491521502179_item	2622878	et	4	main
pahandab	doc_491521502179_item	2622879	et	3	main
huvitavale	doc_491521502179_item	2622880	et	4	main
telesaatele	doc_491521502179_item	2622881	et	3	main
ajale	doc_491521502179_item	2622883	et	3	main
sulgudes	doc_491521502179_item	2622886	et	4	main
pean	doc_491521502179_item	2622893	et	4	main
sa	doc_491521502179_item	2622923	et	3	main
autode	doc_491521502179_item	2622941	et	3	main
uus	doc_491521502179_item	2622952	et	3	main
selles	doc_491521502179_item	2622959	et	4	main
küsimuses	doc_491521502179_item	2622960	et	4	main
vaid	doc_491521502179_item	2622961	et	3	main
see	doc_491521502179_item	2622967	et	3	main
teine	doc_491521502179_item	2622970	et	3	main
9	doc_491521502179_item	2622980	et	2	main
suvine	doc_491521502179_item	2622991	et	4	main
tellisime	doc_491521502179_item	2623001	et	4	main
naeru	doc_491521502179_item	2623027	et	4	main
rääkinud	doc_491521502179_item	2623033	et	4	main
ei	doc_491521502179_item	2623036	et	4	main
või	doc_491521502179_item	2623072	et	4	main
linna	doc_491521502179_item	2623074	et	4	main
10	doc_491521502179_item	2623075	et	2	main
kuid	doc_491521502179_item	2623078	et	4	main
test	doc_491521502180_item	2623086	et	3	main
ega	doc_491521502179_item	2622588	et	3	main
piret	doc_491521502179_item	2622597	et	4	main
polnud	doc_491521502179_item	2622604	et	3	main
alganud	doc_491521502179_item	2622608	et	4	main
kogu	doc_491521502179_item	2622609	et	4	main
on	doc_491521502179_item	2622623	et	4	main
täie	doc_491521502179_item	2622630	et	3	main
siinsed	doc_491521502179_item	2622633	et	3	main
aktsent	doc_491521502179_item	2622646	et	3	main
keeles	doc_491521502179_item	2622664	et	4	main
kõik	doc_491521502179_item	2622675	et	4	main
uued	doc_491521502179_item	2622689	et	3	main
juba	doc_491521502179_item	2622698	et	3	main
on	doc_491521502179_item	2622703	et	4	main
veel	doc_491521502179_item	2622705	et	4	main
vene	doc_491521502179_item	2622716	et	4	main
kütmine	doc_491521502179_item	2622718	et	4	main
kütta	doc_491521502179_item	2622719	et	3	main
kui	doc_491521502179_item	2622720	et	3	main
ei	doc_491521502179_item	2622730	et	4	main
müüdagi	doc_491521502179_item	2622731	et	3	main
iii	doc_491521502179_item	2622741	et	4	main
sõnad	doc_491521502179_item	2622747	et	4	main
vormi	doc_491521502179_item	2622749	et	4	main
kasutades	doc_491521502179_item	2622751	et	3	main
2	doc_491521502179_item	2622753	et	2	main
naeratus	doc_491521502179_item	2622754	et	4	main
tegema	doc_491521502179_item	2622755	et	3	main
igaüht	doc_491521502179_item	2622765	et	3	main
naiselikkuks	doc_491521502179_item	2622768	et	4	main
võima	doc_491521502179_item	2622781	et	3	main
5	doc_491521502179_item	2622820	et	2	main
olema	doc_491521502179_item	2622822	et	4	main
saama	doc_491521502179_item	2622824	et	4	main
nii	doc_491521502179_item	2622825	et	3	main
maagiline	doc_491521502179_item	2622826	et	4	main
aparaat	doc_491521502179_item	2622827	et	3	main
tänapäeval	doc_491521502179_item	2622835	et	3	main
telefon	doc_491521502179_item	2622836	et	3	main
saanud	doc_491521502179_item	2622838	et	4	main
nii	doc_491521502179_item	2622839	et	3	main
kuid	doc_491521502179_item	2622850	et	4	main
katkestama	doc_491521502179_item	2622852	et	3	main
varahommik	doc_491521502179_item	2622855	et	3	main
ja	doc_491521502179_item	2622860	et	3	main
söömine	doc_491521502179_item	2622861	et	4	main
pahandab	doc_491521502179_item	2622862	et	3	main
huvitav	doc_491521502179_item	2622863	et	4	main
kuid	doc_491521502179_item	2622867	et	4	main
ka	doc_491521502179_item	2622870	et	3	main
varahommiku	doc_491521502179_item	2622872	et	3	main
valmistusele	doc_491521502179_item	2622876	et	4	main
ja	doc_491521502179_item	2622877	et	3	main
pange	doc_491521502179_item	2622885	et	4	main
olevad	doc_491521502179_item	2622887	et	4	main
sõnad	doc_491521502179_item	2622888	et	4	main
õigesse	doc_491521502179_item	2622889	et	3	main
lugu	doc_491521502179_item	2622895	et	4	main
vanemad	doc_491521502179_item	2622897	et	4	main
tänaseks	doc_491521502179_item	2622622	et	4	main
salv	doc_491521502179_item	2622625	et	3	main
salvis	doc_491521502179_item	2622626	et	4	main
hoog	doc_491521502179_item	2622631	et	3	main
hooga	doc_491521502179_item	2622632	et	3	main
vene	doc_491521502179_item	2622645	et	4	main
nagu	doc_491521502179_item	2622649	et	3	main
mõni	doc_491521502179_item	2622650	et	3	main
mõnd	doc_491521502179_item	2622651	et	3	main
murret	doc_491521502179_item	2622652	et	4	main
ja	doc_491521502179_item	2622642	et	3	main
vaid	doc_491521502179_item	2622648	et	3	main
on	doc_491521502179_item	2622654	et	4	main
aine	doc_491521502179_item	2622660	et	4	main
ained	doc_491521502179_item	2622661	et	3	main
veidi	doc_491521502179_item	2622667	et	3	main
inimest	doc_491521502179_item	2622672	et	3	main
saab	doc_491521502179_item	2622674	et	3	main
rääkida	doc_491521502179_item	2622677	et	3	main
pireti	doc_491521502179_item	2622678	et	4	main
sõnul	doc_491521502179_item	2622679	et	3	main
õpivad	doc_491521502179_item	2622680	et	3	main
lapsed	doc_491521502179_item	2622681	et	3	main
poolpõlenud	doc_491521502179_item	2622682	et	4	main
õpikud	doc_491521502179_item	2622690	et	3	main
talvepuud	doc_491521502179_item	2622701	et	4	main
päevad	doc_491521502179_item	2622704	et	3	main
soe	doc_491521502179_item	2622706	et	4	main
soojad	doc_491521502179_item	2622707	et	3	main
kuid	doc_491521502179_item	2622708	et	4	main
harjutan	doc_491521502179_item	2622713	et	3	main
vaja	doc_491521502179_item	2622721	et	4	main
seal	doc_491521502179_item	2622727	et	4	main
talveks	doc_491521502179_item	2622733	et	4	main
piret	doc_491521502179_item	2622736	et	4	main
lühendatud	doc_491521502179_item	2622738	et	4	main
moodustage	doc_491521502179_item	2622742	et	3	main
sõnadest	doc_491521502179_item	2622744	et	3	main
õigesse	doc_491521502179_item	2622748	et	3	main
kirjavahemärke	doc_491521502179_item	2622752	et	4	main
naist	doc_491521502179_item	2622767	et	3	main
meest	doc_491521502179_item	2622770	et	4	main
lisakoormus	doc_491521502179_item	2622780	et	3	main
tooma	doc_491521502179_item	2622782	et	3	main
sportiga	doc_491521502179_item	2622817	et	4	main
ja	doc_491521502179_item	2622818	et	3	main
puhkusega	doc_491521502179_item	2622819	et	3	main
tänapäev	doc_491521502179_item	2622823	et	3	main
abil	doc_491521502179_item	2622830	et	4	main
hingama	doc_491521502179_item	2622834	et	3	main
on	doc_491521502179_item	2622837	et	4	main
hingata	doc_491521502179_item	2622848	et	4	main
ka	doc_491521502179_item	2622853	et	3	main
valmistamine	doc_491521502179_item	2622859	et	4	main
telesaade	doc_491521502179_item	2622864	et	4	main
telefonihelin	doc_491521502179_item	2622868	et	3	main
pühapäeva	doc_491521502179_item	2622871	et	4	main
vormi	doc_491521502179_item	2622890	et	4	main
1	doc_491521502179_item	2622891	et	2	main
ma	doc_491521502179_item	2622892	et	3	main
vanemale	doc_491521502179_item	2622899	et	4	main
ainult	doc_491521502179_item	2622926	et	4	main
ilusa	doc_491521502179_item	2622932	et	3	main
naistega	doc_491521502179_item	2622933	et	3	main
kirjade	doc_491521502179_item	2622935	et	3	main
autodega	doc_491521502179_item	2622936	et	3	main
ilusa	doc_491521502179_item	2622937	et	3	main
naiste	doc_491521502179_item	2622938	et	3	main
vastu	doc_491521502179_item	2622942	et	3	main
haigestuda	doc_491521502179_item	2622947	et	3	main
difteeriat	doc_491521502179_item	2622949	et	3	main
väikseid	doc_491521502179_item	2622964	et	4	main
7	doc_491521502179_item	2622966	et	2	main
küsimus	doc_491521502179_item	2622968	et	4	main
valdkond	doc_491521502179_item	2622971	et	3	main
valdkonda	doc_491521502179_item	2622973	et	4	main
rõõmu	doc_491521502179_item	2622990	et	4	main
suvisest	doc_491521502179_item	2622993	et	4	main
kolmekäigulise	doc_491521502179_item	2623002	et	4	main
õpetajad	doc_491521502179_item	2623015	et	4	main
3	doc_491521502179_item	2623016	et	2	main
lapsel	doc_491521502179_item	2623017	et	4	main
paluti	doc_491521502179_item	2623018	et	3	main
tagasi	doc_491521502179_item	2623022	et	3	main
anekdooti	doc_491521502179_item	2623032	et	4	main
ta	doc_491521502179_item	2623035	et	4	main
lähete	doc_491521502179_item	2623047	et	4	main
7	doc_491521502179_item	2623049	et	2	main
jääd	doc_491521502179_item	2623073	et	4	main
kuulsin	doc_491521502179_item	2623079	et	3	main
eesti	doc_491521502180_item	2623081	et	4	main
kool	doc_491521502179_item	2622653	et	4	main
siiski	doc_491521502179_item	2622655	et	4	main
õpetatakse	doc_491521502179_item	2622662	et	3	main
vene	doc_491521502179_item	2622663	et	4	main
üle	doc_491521502179_item	2622668	et	3	main
raamatud	doc_491521502179_item	2622683	et	4	main
raamatuid	doc_491521502179_item	2622684	et	3	main
varsti	doc_491521502179_item	2622685	et	3	main
eestist	doc_491521502179_item	2622688	et	3	main
piret	doc_491521502179_item	2622693	et	4	main
ei	doc_491521502179_item	2622694	et	4	main
kartma	doc_491521502179_item	2622695	et	3	main
karda	doc_491521502179_item	2622696	et	4	main
toodi	doc_491521502179_item	2622700	et	4	main
juba	doc_491521502179_item	2622710	et	3	main
jahedad	doc_491521502179_item	2622712	et	3	main
ahju	doc_491521502179_item	2622717	et	4	main
naerab	doc_491521502179_item	2622732	et	3	main
vapralt	doc_491521502179_item	2622737	et	4	main
ajalehest	doc_491521502179_item	2622739	et	4	main
laused	doc_491521502179_item	2622745	et	3	main
mehelikum	doc_491521502179_item	2622760	et	4	main
kaunim	doc_491521502179_item	2622766	et	4	main
ja	doc_491521502179_item	2622769	et	3	main
3	doc_491521502179_item	2622772	et	2	main
paras	doc_491521502179_item	2622773	et	3	main
kogus	doc_491521502179_item	2622774	et	4	main
stress	doc_491521502179_item	2622775	et	3	main
panema	doc_491521502179_item	2622776	et	3	main
tagajärg	doc_491521502179_item	2622784	et	3	main
lisakoormus	doc_491521502179_item	2622785	et	3	main
paneb	doc_491521502179_item	2622786	et	3	main
meid	doc_491521502179_item	2622787	et	4	main
aga	doc_491521502179_item	2622789	et	3	main
paras	doc_491521502179_item	2622790	et	3	main
stressi	doc_491521502179_item	2622791	et	4	main
kogumine	doc_491521502179_item	2622792	et	4	main
võib	doc_491521502179_item	2622793	et	3	main
tegutsema	doc_491521502179_item	2622788	et	3	main
tuua	doc_491521502179_item	2622794	et	3	main
soovitamatu	doc_491521502179_item	2622795	et	4	main
tagajärjed	doc_491521502179_item	2622796	et	3	main
4	doc_491521502179_item	2622797	et	2	main
ei	doc_491521502179_item	2622798	et	4	main
tohtima	doc_491521502179_item	2622799	et	3	main
laskma	doc_491521502179_item	2622800	et	3	main
ülekoormus	doc_491521502179_item	2622801	et	3	main
tekkima	doc_491521502179_item	2622802	et	3	main
pinge	doc_491521502179_item	2622803	et	4	main
saama	doc_491521502179_item	2622804	et	4	main
maandama	doc_491521502179_item	2622805	et	3	main
sportima	doc_491521502179_item	2622806	et	4	main
ja	doc_491521502179_item	2622807	et	3	main
puhkama	doc_491521502179_item	2622808	et	3	main
ei	doc_491521502179_item	2622809	et	4	main
tohi	doc_491521502179_item	2622810	et	4	main
lasta	doc_491521502179_item	2622811	et	4	main
ülekoormuse	doc_491521502179_item	2622812	et	3	main
tekkimist	doc_491521502179_item	2622813	et	4	main
pinget	doc_491521502179_item	2622814	et	3	main
saab	doc_491521502179_item	2622815	et	3	main
maandada	doc_491521502179_item	2622816	et	3	main
mehed	doc_491521502179_item	2622759	et	3	main
mehelikkuks	doc_491521502179_item	2622771	et	4	main
soovimatu	doc_491521502179_item	2622783	et	4	main
see	doc_491521502179_item	2622829	et	3	main
elama	doc_491521502179_item	2622832	et	3	main
abil	doc_491521502179_item	2622844	et	4	main
lausa	doc_491521502179_item	2622845	et	4	main
elada	doc_491521502179_item	2622846	et	3	main
ja	doc_491521502179_item	2622847	et	3	main
pühapäev	doc_491521502179_item	2622854	et	3	main
lõunasöök	doc_491521502179_item	2622858	et	3	main
vaatamine	doc_491521502179_item	2622865	et	4	main
iv	doc_491521502179_item	2622884	et	4	main
väga	doc_491521502179_item	2622894	et	3	main
oma	doc_491521502179_item	2622898	et	4	main
sest	doc_491521502179_item	2622900	et	4	main
nad	doc_491521502179_item	2622901	et	3	main
aga	doc_491521502179_item	2622922	et	3	main
ja	doc_491521502179_item	2622939	et	3	main
praegu	doc_491521502179_item	2622944	et	3	main
difteeria	doc_491521502179_item	2622948	et	4	main
5	doc_491521502179_item	2622950	et	2	main
uue	doc_491521502179_item	2622954	et	3	main
kiiresti	doc_491521502179_item	2622956	et	3	main
piirdusime	doc_491521502179_item	2622958	et	3	main
teisse	doc_491521502179_item	2622972	et	4	main
8	doc_491521502179_item	2622974	et	2	main
närimiskumm	doc_491521502179_item	2622975	et	3	main
kleepus	doc_491521502179_item	2622976	et	3	main
püksid	doc_491521502179_item	2622977	et	3	main
püksi	doc_491521502179_item	2622978	et	4	main
ajal	doc_491521502179_item	2622982	et	4	main
v	doc_491521502179_item	2622995	et	4	main
lüngad	doc_491521502179_item	2622997	et	3	main
sobivate	doc_491521502179_item	2622998	et	4	main
sidenditega	doc_491521502179_item	2622999	et	3	main
1	doc_491521502179_item	2623000	et	2	main
lõuna	doc_491521502179_item	2623003	et	4	main
see	doc_491521502179_item	2623005	et	3	main
palju	doc_491521502179_item	2623007	et	4	main
kohal	doc_491521502179_item	2623009	et	4	main
olid	doc_491521502179_item	2623010	et	4	main
nii	doc_491521502179_item	2623011	et	3	main
õpilased	doc_491521502179_item	2623012	et	3	main
kui	doc_491521502179_item	2623013	et	3	main
ka	doc_491521502179_item	2623014	et	3	main
et	doc_491521502179_item	2622828	et	3	main
ja	doc_491521502179_item	2622833	et	3	main
telefonihelin	doc_491521502179_item	2622851	et	3	main
segama	doc_491521502179_item	2622857	et	3	main
katkestab	doc_491521502179_item	2622869	et	3	main
und	doc_491521502179_item	2622873	et	4	main
segab	doc_491521502179_item	2622874	et	3	main
lõunasööki	doc_491521502179_item	2622875	et	4	main
vaatamise	doc_491521502179_item	2622882	et	4	main
oma	doc_491521502179_item	2622896	et	4	main
aitavad	doc_491521502179_item	2622902	et	4	main
kõik	doc_491521502179_item	2622903	et	4	main
kõigis	doc_491521502179_item	2622904	et	4	main
ja	doc_491521502179_item	2622905	et	3	main
usaldavad	doc_491521502179_item	2622906	et	4	main
igaüks	doc_491521502179_item	2622907	et	3	main
igaühele	doc_491521502179_item	2622908	et	3	main
2	doc_491521502179_item	2622909	et	2	main
kohandasin	doc_491521502179_item	2622910	et	3	main
artikli	doc_491521502179_item	2622911	et	3	main
nõuded	doc_491521502179_item	2622912	et	3	main
nõudeid	doc_491521502179_item	2622913	et	3	main
3	doc_491521502179_item	2622914	et	2	main
ma	doc_491521502179_item	2622915	et	3	main
arvasin	doc_491521502179_item	2622916	et	3	main
et	doc_491521502179_item	2622917	et	3	main
sa	doc_491521502179_item	2622918	et	3	main
huvitud	doc_491521502179_item	2622919	et	4	main
sport	doc_491521502179_item	2622920	et	3	main
tunned	doc_491521502179_item	2622924	et	3	main
naised	doc_491521502179_item	2622928	et	3	main
ja	doc_491521502179_item	2622929	et	3	main
kiired	doc_491521502179_item	2622930	et	4	main
autod	doc_491521502179_item	2622931	et	3	main
ja	doc_491521502179_item	2622934	et	3	main
kirjade	doc_491521502179_item	2622940	et	3	main
oht	doc_491521502179_item	2622946	et	3	main
tüdinesin	doc_491521502179_item	2622951	et	3	main
väikesed	doc_491521502179_item	2622962	et	4	main
kuulub	doc_491521502179_item	2622969	et	3	main
külmal	doc_491521502179_item	2622981	et	3	main
külmetamine	doc_491521502179_item	2622985	et	4	main
10	doc_491521502179_item	2622987	et	2	main
ma	doc_491521502179_item	2622988	et	3	main
tunnen	doc_491521502179_item	2622989	et	3	main
kuni	doc_491521502179_item	2623020	et	3	main
sest	doc_491521502179_item	2623028	et	4	main
oleks	doc_491521502179_item	2623029	et	3	main
5	doc_491521502179_item	2623034	et	2	main
tule	doc_491521502179_item	2623037	et	4	main
trenni	doc_491521502179_item	2623038	et	4	main
vaid	doc_491521502179_item	2623039	et	3	main
läheb	doc_491521502179_item	2623040	et	3	main
hoopis	doc_491521502179_item	2623041	et	3	main
teatrisse	doc_491521502179_item	2623042	et	3	main
6	doc_491521502179_item	2623043	et	2	main
lõpetage	doc_491521502179_item	2623044	et	3	main
töö	doc_491521502179_item	2623045	et	4	main
siis	doc_491521502179_item	2623046	et	3	main
jalutama	doc_491521502179_item	2623048	et	3	main
ei	doc_491521502179_item	2623052	et	4	main
suitsetada	doc_491521502179_item	2623054	et	3	main
maale	doc_491521502179_item	2623071	et	4	main
spordiga	doc_491521502179_item	2622921	et	3	main
huvi	doc_491521502179_item	2622925	et	4	main
ilusad	doc_491521502179_item	2622927	et	3	main
4	doc_491521502179_item	2622943	et	2	main
on	doc_491521502179_item	2622945	et	4	main
töökoht	doc_491521502179_item	2622953	et	3	main
töökohta	doc_491521502179_item	2622955	et	4	main
6	doc_491521502179_item	2622957	et	2	main
muudatused	doc_491521502179_item	2622963	et	3	main
muudatusi	doc_491521502179_item	2622965	et	3	main
peale	doc_491521502179_item	2622979	et	4	main
peab	doc_491521502179_item	2622983	et	4	main
hoiduma	doc_491521502179_item	2622984	et	3	main
külmetamist	doc_491521502179_item	2622986	et	4	main
päike	doc_491521502179_item	2622992	et	3	main
päikest	doc_491521502179_item	2622994	et	4	main
täitke	doc_491521502179_item	2622996	et	3	main
kuid	doc_491521502179_item	2623004	et	4	main
maksis	doc_491521502179_item	2623006	et	4	main
2	doc_491521502179_item	2623008	et	2	main
oodata	doc_491521502179_item	2623019	et	4	main
tulevad	doc_491521502179_item	2623023	et	4	main
kostis	doc_491521502179_item	2623026	et	4	main
just	doc_491521502179_item	2623031	et	3	main
selles	doc_491521502179_item	2623050	et	4	main
tohi	doc_491521502179_item	2623053	et	4	main
ega	doc_491521502179_item	2623055	et	3	main
alkoholi	doc_491521502179_item	2623056	et	4	main
sõidad	doc_491521502179_item	2623070	et	3	main
ukse	doc_491521502179_item	2623077	et	3	main
koputust	doc_491521502179_item	2623080	et	4	main
i	doc_491521502180_item	2623087	et	4	main
pange	doc_491521502180_item	2623088	et	4	main
küla	doc_491521502180_item	2623109	et	4	main
emakeelt	doc_491521502180_item	2623130	et	4	main
õpetama	doc_491521502180_item	2623131	et	3	main
üsna	doc_491521502180_item	2623144	et	3	main
kui	doc_491521502180_item	2623147	et	3	main
tuli	doc_491521502180_item	2623150	et	4	main
vastu	doc_491521502180_item	2623151	et	3	main
maaliti	doc_491521502180_item	2623156	et	3	main
siber	doc_491521502180_item	2623157	et	4	main
rohi	doc_491521502180_item	2623169	et	4	main
kui	doc_491521502180_item	2623170	et	3	main
noor	doc_491521502180_item	2623171	et	3	main
küla	doc_491521502180_item	2623189	et	4	main
võtma	doc_491521502180_item	2623190	et	3	main
võttis	doc_491521502180_item	2623191	et	3	main
kartuleid	doc_491521502180_item	2623192	et	3	main
kartulivõtt	doc_491521502180_item	2623193	et	3	main
mahlakasem	doc_491521502180_item	2623222	et	4	main
vene	doc_491521502180_item	2623224	et	4	main
aktsent	doc_491521502180_item	2623225	et	3	main
nagu	doc_491521502180_item	2623228	et	3	main
inimest	doc_491521502180_item	2623251	et	3	main
kõikidega	doc_491521502180_item	2623255	et	4	main
õpivad	doc_491521502180_item	2623259	et	3	main
kartma	doc_491521502180_item	2623274	et	3	main
valmistutud	doc_491521502180_item	2623314	et	4	main
etteantud	doc_491521502180_item	2623322	et	4	main
tegema	doc_491521502180_item	2623334	et	3	main
mehed	doc_491521502180_item	2623338	et	3	main
igaüks	doc_491521502180_item	2623340	et	3	main
kaunim	doc_491521502180_item	2623341	et	4	main
ja	doc_491521502180_item	2623348	et	3	main
3	doc_491521502180_item	2623351	et	2	main
telefon	doc_491521502180_item	2623411	et	3	main
on	doc_491521502180_item	2623412	et	4	main
aparaadiks	doc_491521502180_item	2623417	et	3	main
et	doc_491521502180_item	2623418	et	3	main
söömise	doc_491521502180_item	2623454	et	4	main
pahandab	doc_491521502180_item	2623455	et	3	main
õigesse	doc_491521502180_item	2623465	et	3	main
pean	doc_491521502180_item	2623469	et	4	main
sest	doc_491521502180_item	2623476	et	4	main
igaüks	doc_491521502180_item	2623483	et	3	main
3	doc_491521502180_item	2623489	et	2	main
vanemad	doc_491521502179_item	2623021	et	4	main
4	doc_491521502179_item	2623024	et	2	main
kõrvallauast	doc_491521502179_item	2623025	et	4	main
keegi	doc_491521502179_item	2623030	et	4	main
baaris	doc_491521502179_item	2623051	et	3	main
tarbida	doc_491521502179_item	2623057	et	3	main
8	doc_491521502179_item	2623058	et	2	main
nad	doc_491521502179_item	2623059	et	3	main
töötasid	doc_491521502179_item	2623060	et	4	main
küll	doc_491521502179_item	2623061	et	4	main
pingsalt	doc_491521502179_item	2623062	et	4	main
aga	doc_491521502179_item	2623063	et	3	main
tulemust	doc_491521502179_item	2623064	et	4	main
ei	doc_491521502179_item	2623065	et	4	main
olnud	doc_491521502179_item	2623066	et	4	main
9	doc_491521502179_item	2623067	et	2	main
kas	doc_491521502179_item	2623068	et	3	main
sa	doc_491521502179_item	2623069	et	3	main
avasin	doc_491521502179_item	2623076	et	3	main
keele	doc_491521502180_item	2623085	et	4	main
sõnad	doc_491521502180_item	2623091	et	4	main
nägis	doc_491521502180_item	2623101	et	4	main
ülem-suetuki	doc_491521502180_item	2623108	et	4	main
võitis	doc_491521502180_item	2623116	et	3	main
konkurss	doc_491521502180_item	2623117	et	3	main
konkurssi	doc_491521502180_item	2623118	et	4	main
ja	doc_491521502180_item	2623119	et	3	main
väikestele	doc_491521502180_item	2623126	et	4	main
eestlastele	doc_491521502180_item	2623127	et	4	main
need	doc_491521502180_item	2623128	et	3	main
pireti	doc_491521502180_item	2623133	et	4	main
ta	doc_491521502180_item	2623136	et	4	main
siberisse	doc_491521502180_item	2623137	et	4	main
jõudma	doc_491521502180_item	2623138	et	3	main
jõudma	doc_491521502180_item	2623139	et	3	main
korralik	doc_491521502180_item	2623152	et	3	main
korriliku	doc_491521502180_item	2623153	et	4	main
et	doc_491521502180_item	2623161	et	3	main
tahtmine	doc_491521502180_item	2623173	et	4	main
piret	doc_491521502180_item	2623176	et	4	main
veel	doc_491521502180_item	2623185	et	4	main
algama	doc_491521502180_item	2623186	et	3	main
alganud	doc_491521502180_item	2623187	et	4	main
keele	doc_491521502180_item	2623082	et	4	main
test	doc_491521502180_item	2623083	et	3	main
eesti	doc_491521502180_item	2623084	et	4	main
olevad	doc_491521502180_item	2623090	et	4	main
on	doc_491521502180_item	2623096	et	4	main
ettevõtlik	doc_491521502180_item	2623097	et	3	main
naine	doc_491521502180_item	2623098	et	3	main
suvel	doc_491521502180_item	2623099	et	3	main
nägema	doc_491521502180_item	2623100	et	3	main
siberisse	doc_491521502180_item	2623107	et	4	main
otsitakse	doc_491521502180_item	2623111	et	3	main
on	doc_491521502180_item	2623120	et	4	main
nüüd	doc_491521502180_item	2623121	et	4	main
üle	doc_491521502180_item	2623123	et	3	main
kinnitusel	doc_491521502180_item	2623134	et	4	main
üllatuma	doc_491521502180_item	2623145	et	3	main
audiga	doc_491521502180_item	2623154	et	3	main
pilt	doc_491521502180_item	2623160	et	3	main
ja	doc_491521502180_item	2623172	et	3	main
tahtmist	doc_491521502180_item	2623174	et	4	main
pärast	doc_491521502180_item	2623177	et	4	main
on	doc_491521502180_item	2623194	et	4	main
murret	doc_491521502180_item	2623231	et	4	main
on	doc_491521502180_item	2623233	et	4	main
üle	doc_491521502180_item	2623247	et	3	main
rääkida	doc_491521502180_item	2623256	et	3	main
piret	doc_491521502180_item	2623272	et	4	main
müüdagi	doc_491521502180_item	2623310	et	3	main
naerab	doc_491521502180_item	2623311	et	3	main
slõhtuleht	doc_491521502180_item	2623319	et	4	main
sulgudes	doc_491521502180_item	2623089	et	4	main
toomet	doc_491521502180_item	2623095	et	4	main
kuulutust	doc_491521502180_item	2623105	et	4	main
et	doc_491521502180_item	2623106	et	3	main
külla	doc_491521502180_item	2623110	et	4	main
keele	doc_491521502180_item	2623113	et	4	main
õigesse	doc_491521502180_item	2623092	et	3	main
vormi	doc_491521502180_item	2623093	et	4	main
piret	doc_491521502180_item	2623094	et	4	main
ta	doc_491521502180_item	2623102	et	4	main
ajalehes	doc_491521502180_item	2623103	et	3	main
kuulutus	doc_491521502180_item	2623104	et	4	main
eesti	doc_491521502180_item	2623112	et	4	main
õpetajat	doc_491521502180_item	2623114	et	4	main
piret	doc_491521502180_item	2623115	et	4	main
juba	doc_491521502180_item	2623122	et	3	main
nädal	doc_491521502180_item	2623124	et	3	main
õpetab	doc_491521502180_item	2623132	et	3	main
tundis	doc_491521502180_item	2623135	et	3	main
et	doc_491521502180_item	2623140	et	3	main
oodatud	doc_491521502180_item	2623142	et	4	main
olin	doc_491521502180_item	2623143	et	3	main
selline	doc_491521502180_item	2623159	et	4	main
ei	doc_491521502180_item	2623163	et	4	main
kohta	doc_491521502180_item	2623181	et	4	main
jõudis	doc_491521502180_item	2623182	et	3	main
polnud	doc_491521502180_item	2623183	et	3	main
kool	doc_491521502180_item	2623184	et	4	main
sügisel	doc_491521502180_item	2623196	et	3	main
mõni	doc_491521502180_item	2623229	et	3	main
kool	doc_491521502180_item	2623232	et	4	main
siiski	doc_491521502180_item	2623234	et	4	main
venemaa	doc_491521502180_item	2623235	et	4	main
aine	doc_491521502180_item	2623239	et	4	main
ained	doc_491521502180_item	2623240	et	3	main
õpetatakse	doc_491521502180_item	2623241	et	3	main
vene	doc_491521502180_item	2623242	et	4	main
keeles	doc_491521502180_item	2623243	et	4	main
külas	doc_491521502180_item	2623244	et	3	main
elab	doc_491521502180_item	2623245	et	3	main
veidi	doc_491521502180_item	2623246	et	3	main
inimene	doc_491521502180_item	2623250	et	3	main
saab	doc_491521502180_item	2623253	et	3	main
pireti	doc_491521502180_item	2623257	et	4	main
poolpõlenud	doc_491521502180_item	2623261	et	4	main
iii	doc_491521502180_item	2623320	et	4	main
kirjavahemärke	doc_491521502180_item	2623331	et	4	main
2	doc_491521502180_item	2623332	et	2	main
naiselikum	doc_491521502180_item	2623336	et	4	main
ja	doc_491521502180_item	2623337	et	3	main
mehelikum	doc_491521502180_item	2623339	et	4	main
naiselikumaks	doc_491521502180_item	2623345	et	4	main
igaüks	doc_491521502180_item	2623349	et	3	main
meie	doc_491521502180_item	2623356	et	4	main
tegutsema	doc_491521502180_item	2623357	et	3	main
aga	doc_491521502180_item	2623358	et	3	main
lisakoormus	doc_491521502180_item	2623359	et	3	main
võima	doc_491521502180_item	2623360	et	3	main
tooma	doc_491521502180_item	2623361	et	3	main
soovimatu	doc_491521502180_item	2623362	et	4	main
tagajärg	doc_491521502180_item	2623363	et	3	main
paras	doc_491521502180_item	2623364	et	3	main
paneb	doc_491521502180_item	2623365	et	3	main
olema	doc_491521502180_item	2623398	et	4	main
tänapäev	doc_491521502180_item	2623399	et	3	main
elama	doc_491521502180_item	2623408	et	3	main
sellel	doc_491521502180_item	2623419	et	4	main
ja	doc_491521502180_item	2623423	et	3	main
pühapäev	doc_491521502180_item	2623430	et	3	main
segama	doc_491521502180_item	2623433	et	3	main
pahandab	doc_491521502180_item	2623438	et	3	main
telesaade	doc_491521502180_item	2623440	et	4	main
vaatamine	doc_491521502180_item	2623441	et	4	main
aeg	doc_491521502180_item	2623442	et	3	main
kuid	doc_491521502180_item	2623443	et	4	main
telefonihelin	doc_491521502180_item	2623444	et	3	main
katkestab	doc_491521502180_item	2623445	et	3	main
ka	doc_491521502180_item	2623446	et	3	main
pühapäeval	doc_491521502180_item	2623447	et	3	main
varahommikul	doc_491521502180_item	2623448	et	3	main
segab	doc_491521502180_item	2623449	et	3	main
uni	doc_491521502180_item	2623450	et	3	main
aega	doc_491521502180_item	2623459	et	4	main
sõnad	doc_491521502180_item	2623464	et	4	main
nad	doc_491521502180_item	2623477	et	3	main
aitavad	doc_491521502180_item	2623478	et	4	main
kõik	doc_491521502180_item	2623479	et	4	main
nädalat	doc_491521502180_item	2623125	et	3	main
nende	doc_491521502180_item	2623129	et	4	main
on	doc_491521502180_item	2623141	et	4	main
üllatunud	doc_491521502180_item	2623146	et	4	main
mulle	doc_491521502180_item	2623148	et	4	main
tulema	doc_491521502180_item	2623149	et	4	main
mulle	doc_491521502180_item	2623155	et	4	main
siberi	doc_491521502180_item	2623158	et	4	main
seal	doc_491521502180_item	2623162	et	4	main
lendama	doc_491521502180_item	2623164	et	3	main
lenda	doc_491521502180_item	2623165	et	4	main
lind	doc_491521502180_item	2623166	et	3	main
ega	doc_491521502180_item	2623167	et	3	main
kasva	doc_491521502180_item	2623168	et	4	main
täis	doc_491521502180_item	2623175	et	4	main
õppeaasta	doc_491521502180_item	2623178	et	4	main
algust	doc_491521502180_item	2623179	et	4	main
koht	doc_491521502180_item	2623180	et	3	main
kogu	doc_491521502180_item	2623188	et	4	main
siin	doc_491521502180_item	2623195	et	4	main
kõige	doc_491521502180_item	2623197	et	4	main
tähtis	doc_491521502180_item	2623198	et	4	main
tähtsaim	doc_491521502180_item	2623199	et	4	main
ettevõtmine	doc_491521502180_item	2623200	et	3	main
tänaseks	doc_491521502180_item	2623201	et	4	main
on	doc_491521502180_item	2623202	et	4	main
kartul	doc_491521502180_item	2623203	et	3	main
salv	doc_491521502180_item	2623204	et	3	main
salves	doc_491521502180_item	2623205	et	4	main
ja	doc_491521502180_item	2623206	et	3	main
õppimine	doc_491521502180_item	2623207	et	4	main
käib	doc_491521502180_item	2623208	et	3	main
täie	doc_491521502180_item	2623209	et	3	main
hoog	doc_491521502180_item	2623210	et	3	main
hooga	doc_491521502180_item	2623211	et	3	main
siinsed	doc_491521502180_item	2623212	et	3	main
eestlased	doc_491521502180_item	2623213	et	3	main
räägivad	doc_491521502180_item	2623214	et	3	main
kuidagi	doc_491521502180_item	2623215	et	3	main
teistmoodi	doc_491521502180_item	2623216	et	3	main
mõnus	doc_491521502180_item	2623217	et	4	main
ja	doc_491521502180_item	2623218	et	3	main
mahlakas	doc_491521502180_item	2623219	et	4	main
mõnusam	doc_491521502180_item	2623220	et	4	main
ja	doc_491521502180_item	2623221	et	3	main
mitte	doc_491521502180_item	2623223	et	3	main
aktsenti	doc_491521502180_item	2623226	et	4	main
vaid	doc_491521502180_item	2623227	et	3	main
kool	doc_491521502180_item	2623236	et	4	main
kolmesaja	doc_491521502180_item	2623249	et	4	main
emakeelt	doc_491521502180_item	2623252	et	4	main
kõik	doc_491521502180_item	2623254	et	4	main
sõnul	doc_491521502180_item	2623258	et	3	main
lapsed	doc_491521502180_item	2623260	et	3	main
raamatud	doc_491521502180_item	2623262	et	4	main
raamatutega	doc_491521502180_item	2623263	et	3	main
varsti	doc_491521502180_item	2623264	et	3	main
mõnet	doc_491521502180_item	2623230	et	4	main
ja	doc_491521502180_item	2623237	et	3	main
ülejäänud	doc_491521502180_item	2623238	et	4	main
kolmsada	doc_491521502180_item	2623248	et	4	main
talve	doc_491521502180_item	2623271	et	4	main
karda	doc_491521502180_item	2623275	et	4	main
juba	doc_491521502180_item	2623277	et	3	main
tooma	doc_491521502180_item	2623278	et	3	main
tooti	doc_491521502180_item	2623279	et	4	main
talvepuud	doc_491521502180_item	2623280	et	4	main
praegu	doc_491521502180_item	2623281	et	3	main
on	doc_491521502180_item	2623282	et	4	main
päevad	doc_491521502180_item	2623283	et	3	main
veel	doc_491521502180_item	2623284	et	4	main
soe	doc_491521502180_item	2623285	et	4	main
sojad	doc_491521502180_item	2623286	et	3	main
kuid	doc_491521502180_item	2623287	et	4	main
ööd	doc_491521502180_item	2623288	et	4	main
juba	doc_491521502180_item	2623289	et	3	main
jahe	doc_491521502180_item	2623290	et	3	main
jahedad	doc_491521502180_item	2623291	et	3	main
harjutan	doc_491521502180_item	2623292	et	3	main
juba	doc_491521502180_item	2623293	et	3	main
suure	doc_491521502180_item	2623294	et	3	main
vene	doc_491521502180_item	2623295	et	4	main
ahju	doc_491521502180_item	2623296	et	4	main
kütmine	doc_491521502180_item	2623297	et	4	main
kütmist	doc_491521502180_item	2623298	et	4	main
kui	doc_491521502180_item	2623299	et	3	main
vaja	doc_491521502180_item	2623300	et	4	main
ostan	doc_491521502180_item	2623301	et	3	main
külapood	doc_491521502180_item	2623302	et	3	main
külapoodist	doc_491521502180_item	2623303	et	4	main
vildid	doc_491521502180_item	2623304	et	4	main
ega	doc_491521502180_item	2623305	et	3	main
seal	doc_491521502180_item	2623306	et	4	main
suurt	doc_491521502180_item	2623307	et	3	main
muud	doc_491521502180_item	2623308	et	4	main
ei	doc_491521502180_item	2623309	et	4	main
saatma	doc_491521502180_item	2623265	et	3	main
saadetakse	doc_491521502180_item	2623266	et	3	main
eestist	doc_491521502180_item	2623267	et	3	main
uued	doc_491521502180_item	2623268	et	3	main
õpikud	doc_491521502180_item	2623269	et	3	main
siberi	doc_491521502180_item	2623270	et	4	main
ei	doc_491521502180_item	2623273	et	4	main
mulle	doc_491521502180_item	2623276	et	4	main
valmistuma	doc_491521502180_item	2623313	et	3	main
piret	doc_491521502180_item	2623315	et	4	main
lühendatud	doc_491521502180_item	2623317	et	4	main
laused	doc_491521502180_item	2623324	et	3	main
sõnad	doc_491521502180_item	2623326	et	4	main
õigesse	doc_491521502180_item	2623327	et	3	main
vormi	doc_491521502180_item	2623328	et	4	main
ja	doc_491521502180_item	2623329	et	3	main
kasutades	doc_491521502180_item	2623330	et	3	main
teeb	doc_491521502180_item	2623343	et	3	main
mehedmehelikumaks	doc_491521502180_item	2623347	et	4	main
kaunimaks	doc_491521502180_item	2623350	et	4	main
paras	doc_491521502180_item	2623352	et	3	main
kogus	doc_491521502180_item	2623353	et	4	main
stress	doc_491521502180_item	2623354	et	3	main
panema	doc_491521502180_item	2623355	et	3	main
5	doc_491521502180_item	2623396	et	2	main
telefon	doc_491521502180_item	2623397	et	3	main
et	doc_491521502180_item	2623404	et	3	main
ja	doc_491521502180_item	2623409	et	3	main
tänapäeval	doc_491521502180_item	2623414	et	3	main
nii	doc_491521502180_item	2623415	et	3	main
abil	doc_491521502180_item	2623420	et	4	main
hingab	doc_491521502180_item	2623424	et	3	main
kuid	doc_491521502180_item	2623426	et	4	main
katkestama	doc_491521502180_item	2623428	et	3	main
uni	doc_491521502180_item	2623432	et	3	main
valmistamine	doc_491521502180_item	2623435	et	4	main
valmistamist	doc_491521502180_item	2623452	et	4	main
iv	doc_491521502180_item	2623460	et	4	main
pange	doc_491521502180_item	2623461	et	4	main
sulgudes	doc_491521502180_item	2623462	et	4	main
vanemad	doc_491521502180_item	2623473	et	4	main
omadele	doc_491521502180_item	2623474	et	3	main
kõikis	doc_491521502180_item	2623480	et	4	main
ja	doc_491521502180_item	2623481	et	3	main
kohandasin	doc_491521502180_item	2623486	et	3	main
ma	doc_491521502180_item	2623490	et	3	main
sa	doc_491521502180_item	2623493	et	3	main
kiiresti	doc_491521502180_item	2623524	et	3	main
selles	doc_491521502180_item	2623527	et	4	main
vaid	doc_491521502180_item	2623529	et	3	main
9	doc_491521502180_item	2623547	et	2	main
külmal	doc_491521502180_item	2623548	et	3	main
suviselt	doc_491521502180_item	2623560	et	4	main
päikelt	doc_491521502180_item	2623561	et	4	main
v	doc_491521502180_item	2623562	et	4	main
kohal	doc_491521502180_item	2623577	et	4	main
naeru	doc_491521502180_item	2623594	et	4	main
ta	doc_491521502180_item	2623602	et	4	main
trenni	doc_491521502180_item	2623605	et	4	main
seest	doc_491521502180_item	2623606	et	3	main
teatrisse	doc_491521502180_item	2623609	et	3	main
pingsalt	doc_491521502180_item	2623630	et	4	main
aga	doc_491521502180_item	2623631	et	3	main
tulemust	doc_491521502180_item	2623632	et	4	main
jääd	doc_491521502180_item	2623641	et	4	main
linna	doc_491521502180_item	2623642	et	4	main
10	doc_491521502180_item	2623643	et	2	main
avasin	doc_491521502180_item	2623644	et	3	main
ukse	doc_491521502180_item	2623645	et	3	main
seest	doc_491521502180_item	2623646	et	3	main
talveks	doc_491521502180_item	2623312	et	4	main
vapralt	doc_491521502180_item	2623316	et	4	main
ajalehest	doc_491521502180_item	2623318	et	4	main
moodustage	doc_491521502180_item	2623321	et	3	main
sõnadest	doc_491521502180_item	2623323	et	3	main
naeratus	doc_491521502180_item	2623333	et	4	main
ja	doc_491521502180_item	2623346	et	3	main
tooda	doc_491521502180_item	2623371	et	4	main
aparaat	doc_491521502180_item	2623403	et	3	main
abil	doc_491521502180_item	2623406	et	4	main
lausa	doc_491521502180_item	2623407	et	4	main
lausa	doc_491521502180_item	2623421	et	4	main
6	doc_491521502180_item	2623425	et	2	main
telefonihelin	doc_491521502180_item	2623427	et	3	main
ka	doc_491521502180_item	2623429	et	3	main
varahommik	doc_491521502180_item	2623431	et	3	main
lõunasöök	doc_491521502180_item	2623434	et	3	main
ja	doc_491521502180_item	2623436	et	3	main
lõunasööki	doc_491521502180_item	2623451	et	4	main
telesaade	doc_491521502180_item	2623457	et	4	main
vatamise	doc_491521502180_item	2623458	et	4	main
olevad	doc_491521502180_item	2623463	et	4	main
1	doc_491521502180_item	2623467	et	2	main
vanematele	doc_491521502180_item	2623475	et	4	main
usaldavad	doc_491521502180_item	2623482	et	4	main
et	doc_491521502180_item	2623492	et	3	main
uue	doc_491521502180_item	2623522	et	3	main
piirdusime	doc_491521502180_item	2623526	et	3	main
küsimuses	doc_491521502180_item	2623528	et	4	main
väikesed	doc_491521502180_item	2623530	et	4	main
muudatused	doc_491521502180_item	2623531	et	3	main
väikesed	doc_491521502180_item	2623532	et	4	main
muudatused	doc_491521502180_item	2623533	et	3	main
7	doc_491521502180_item	2623534	et	2	main
see	doc_491521502180_item	2623535	et	3	main
peab	doc_491521502180_item	2623550	et	4	main
10	doc_491521502180_item	2623554	et	2	main
tunnen	doc_491521502180_item	2623556	et	3	main
täitke	doc_491521502180_item	2623563	et	3	main
lüngad	doc_491521502180_item	2623564	et	3	main
sobivate	doc_491521502180_item	2623565	et	4	main
sidenditega	doc_491521502180_item	2623566	et	3	main
kolmekäigulise	doc_491521502180_item	2623569	et	4	main
aga	doc_491521502180_item	2623571	et	3	main
õpetajad	doc_491521502180_item	2623582	et	4	main
3	doc_491521502180_item	2623583	et	2	main
kui	doc_491521502180_item	2623587	et	3	main
tagasi	doc_491521502180_item	2623589	et	3	main
kõrvallauast	doc_491521502180_item	2623592	et	4	main
kostis	doc_491521502180_item	2623593	et	4	main
rääkinud	doc_491521502180_item	2623600	et	4	main
5	doc_491521502180_item	2623601	et	2	main
lõpetage	doc_491521502180_item	2623611	et	3	main
tohi	doc_491521502180_item	2623621	et	4	main
ega	doc_491521502180_item	2623623	et	3	main
tarbida	doc_491521502180_item	2623625	et	3	main
8	doc_491521502180_item	2623626	et	2	main
nad	doc_491521502180_item	2623627	et	3	main
olnud	doc_491521502180_item	2623634	et	4	main
9	doc_491521502180_item	2623635	et	2	main
kas	doc_491521502180_item	2623636	et	3	main
sa	doc_491521502180_item	2623637	et	3	main
sõidad	doc_491521502180_item	2623638	et	3	main
sele	doc_491521502180_item	2623647	et	4	main
pärast	doc_491521502180_item	2623648	et	4	main
kuulsin	doc_491521502180_item	2623649	et	3	main
pannes	doc_491521502180_item	2623325	et	4	main
naised	doc_491521502180_item	2623335	et	3	main
naeratus	doc_491521502180_item	2623342	et	4	main
naised	doc_491521502180_item	2623344	et	3	main
meid	doc_491521502180_item	2623366	et	4	main
tegutsema	doc_491521502180_item	2623367	et	3	main
aga	doc_491521502180_item	2623368	et	3	main
lisakoormus	doc_491521502180_item	2623369	et	3	main
võib	doc_491521502180_item	2623370	et	3	main
soovimatu	doc_491521502180_item	2623372	et	4	main
tagajärgi	doc_491521502180_item	2623373	et	4	main
4	doc_491521502180_item	2623374	et	2	main
ei	doc_491521502180_item	2623375	et	4	main
tohtima	doc_491521502180_item	2623376	et	3	main
laskma	doc_491521502180_item	2623377	et	3	main
ülekoormus	doc_491521502180_item	2623378	et	3	main
tekkima	doc_491521502180_item	2623379	et	3	main
pinge	doc_491521502180_item	2623380	et	4	main
saama	doc_491521502180_item	2623381	et	4	main
maandama	doc_491521502180_item	2623382	et	3	main
sportima	doc_491521502180_item	2623383	et	4	main
ja	doc_491521502180_item	2623384	et	3	main
puhkama	doc_491521502180_item	2623385	et	3	main
ei	doc_491521502180_item	2623386	et	4	main
tohi	doc_491521502180_item	2623387	et	4	main
laskuda	doc_491521502180_item	2623388	et	3	main
ülekoormust	doc_491521502180_item	2623389	et	4	main
tekkides	doc_491521502180_item	2623390	et	4	main
pinge	doc_491521502180_item	2623391	et	4	main
saate	doc_491521502180_item	2623392	et	4	main
maandada	doc_491521502180_item	2623393	et	3	main
sportida	doc_491521502180_item	2623394	et	4	main
puhata	doc_491521502180_item	2623395	et	4	main
saama	doc_491521502180_item	2623400	et	4	main
nii	doc_491521502180_item	2623401	et	3	main
maagiline	doc_491521502180_item	2623402	et	4	main
see	doc_491521502180_item	2623405	et	3	main
hingama	doc_491521502180_item	2623410	et	3	main
saanud	doc_491521502180_item	2623413	et	4	main
maagiliseks	doc_491521502180_item	2623416	et	4	main
elab	doc_491521502180_item	2623422	et	3	main
söömine	doc_491521502180_item	2623437	et	4	main
huvitav	doc_491521502180_item	2623439	et	4	main
ja	doc_491521502180_item	2623453	et	3	main
huvitava	doc_491521502180_item	2623456	et	4	main
vormi	doc_491521502180_item	2623466	et	4	main
ma	doc_491521502180_item	2623468	et	3	main
väga	doc_491521502180_item	2623470	et	3	main
lugu	doc_491521502180_item	2623471	et	4	main
oma	doc_491521502180_item	2623472	et	4	main
igaühes	doc_491521502180_item	2623484	et	3	main
artikli	doc_491521502180_item	2623487	et	3	main
huvitud	doc_491521502180_item	2623494	et	4	main
sport	doc_491521502180_item	2623495	et	3	main
spordi	doc_491521502180_item	2623496	et	4	main
aga	doc_491521502180_item	2623497	et	3	main
sa	doc_491521502180_item	2623498	et	3	main
tunned	doc_491521502180_item	2623499	et	3	main
huvi	doc_491521502180_item	2623500	et	4	main
ainult	doc_491521502180_item	2623501	et	4	main
ilusad	doc_491521502180_item	2623502	et	3	main
naised	doc_491521502180_item	2623503	et	3	main
ja	doc_491521502180_item	2623504	et	3	main
kiired	doc_491521502180_item	2623505	et	4	main
autod	doc_491521502180_item	2623506	et	3	main
naistele	doc_491521502180_item	2623508	et	3	main
ilusatele	doc_491521502180_item	2623507	et	3	main
kiirtele	doc_491521502180_item	2623509	et	3	main
autodele	doc_491521502180_item	2623510	et	3	main
4	doc_491521502180_item	2623511	et	2	main
on	doc_491521502180_item	2623513	et	4	main
praegu	doc_491521502180_item	2623512	et	3	main
oht	doc_491521502180_item	2623514	et	3	main
haigestuda	doc_491521502180_item	2623515	et	3	main
difteeria	doc_491521502180_item	2623516	et	4	main
difteeriaga	doc_491521502180_item	2623517	et	3	main
5	doc_491521502180_item	2623518	et	2	main
tüdinesin	doc_491521502180_item	2623519	et	3	main
uus	doc_491521502180_item	2623520	et	3	main
töökoht	doc_491521502180_item	2623521	et	3	main
valdkonnale	doc_491521502180_item	2623541	et	4	main
8	doc_491521502180_item	2623542	et	2	main
närimiskumm	doc_491521502180_item	2623543	et	3	main
kleepus	doc_491521502180_item	2623544	et	3	main
püksid	doc_491521502180_item	2623545	et	3	main
pükstele	doc_491521502180_item	2623546	et	3	main
külmetamist	doc_491521502180_item	2623553	et	4	main
rõõmu	doc_491521502180_item	2623557	et	4	main
suvine	doc_491521502180_item	2623558	et	4	main
päike	doc_491521502180_item	2623559	et	3	main
1	doc_491521502180_item	2623567	et	2	main
lõuna	doc_491521502180_item	2623570	et	4	main
ja	doc_491521502180_item	2623572	et	3	main
see	doc_491521502180_item	2623573	et	3	main
maksis	doc_491521502180_item	2623574	et	4	main
lapsel	doc_491521502180_item	2623584	et	4	main
2	doc_491521502180_item	2623485	et	2	main
nõuded	doc_491521502180_item	2623488	et	3	main
arvasin	doc_491521502180_item	2623491	et	3	main
töökohta	doc_491521502180_item	2623523	et	4	main
kuulub	doc_491521502180_item	2623537	et	3	main
teine	doc_491521502180_item	2623538	et	3	main
valdkond	doc_491521502180_item	2623539	et	3	main
teisele	doc_491521502180_item	2623540	et	4	main
hoiduma	doc_491521502180_item	2623551	et	3	main
külmetamine	doc_491521502180_item	2623552	et	4	main
ma	doc_491521502180_item	2623555	et	3	main
tellisime	doc_491521502180_item	2623568	et	4	main
olid	doc_491521502180_item	2623578	et	4	main
nii	doc_491521502180_item	2623579	et	3	main
õpilased	doc_491521502180_item	2623580	et	3	main
kui	doc_491521502180_item	2623581	et	3	main
oodata	doc_491521502180_item	2623586	et	4	main
kuid	doc_491521502180_item	2623595	et	4	main
oleks	doc_491521502180_item	2623596	et	3	main
ei	doc_491521502180_item	2623603	et	4	main
läheb	doc_491521502180_item	2623607	et	3	main
6	doc_491521502180_item	2623525	et	2	main
küsimus	doc_491521502180_item	2623536	et	4	main
ajal	doc_491521502180_item	2623549	et	4	main
palju	doc_491521502180_item	2623575	et	4	main
2	doc_491521502180_item	2623576	et	2	main
paluti	doc_491521502180_item	2623585	et	3	main
tulevad	doc_491521502180_item	2623590	et	4	main
keegi	doc_491521502180_item	2623597	et	4	main
just	doc_491521502180_item	2623598	et	3	main
anekdooti	doc_491521502180_item	2623599	et	4	main
tule	doc_491521502180_item	2623604	et	4	main
hoopis	doc_491521502180_item	2623608	et	3	main
siis	doc_491521502180_item	2623613	et	3	main
pärast	doc_491521502180_item	2623614	et	4	main
lähete	doc_491521502180_item	2623615	et	4	main
töö	doc_491521502180_item	2623612	et	4	main
jalutama	doc_491521502180_item	2623616	et	3	main
7	doc_491521502180_item	2623617	et	2	main
selles	doc_491521502180_item	2623618	et	4	main
baaris	doc_491521502180_item	2623619	et	3	main
ei	doc_491521502180_item	2623620	et	4	main
alkoholi	doc_491521502180_item	2623624	et	4	main
ei	doc_491521502180_item	2623633	et	4	main
kontrolltöö	doc_491521502182_item	2623829	et	4	main
varane	doc_491521502182_item	2623831	et	4	main
metalliaeg	doc_491521502182_item	2623832	et	3	main
eesti	doc_491521502182_item	2623833	et	4	main
territooriumil	doc_491521502182_item	2623834	et	3	main
2	doc_491521502182_item	2623835	et	2	main
mõiste	doc_491521502182_item	2623836	et	4	main
animism	doc_491521502182_item	2623837	et	3	main
atekr	doc_491521502182_item	2623845	et	4	main
varane	doc_491521502182_item	2623850	et	4	main
ekr-	doc_491521502182_item	2623854	et	4	main
ajaarvamisevahetus	doc_491521502182_item	2623855	et	4	main
pronksiaja	doc_491521502182_item	2623856	et	3	main
esimesel	doc_491521502182_item	2623857	et	3	main
vanemad	doc_491521502180_item	2623588	et	4	main
4	doc_491521502180_item	2623591	et	2	main
6	doc_491521502180_item	2623610	et	2	main
töötasid	doc_491521502180_item	2623628	et	4	main
küll	doc_491521502180_item	2623629	et	4	main
maale	doc_491521502180_item	2623639	et	4	main
1	doc_491521502182_item	2623839	et	2	main
varasele	doc_491521502182_item	2623840	et	4	main
metalliajale	doc_491521502182_item	2623841	et	3	main
kuuluvad	doc_491521502182_item	2623842	et	4	main
pronksiaeg	doc_491521502182_item	2623843	et	3	main
ii	doc_491521502182_item	2623844	et	4	main
v	doc_491521502182_item	2623852	et	4	main
pronksesemeid	doc_491521502182_item	2623860	et	3	main
harva	doc_491521502182_item	2623862	et	4	main
domineerisid	doc_491521502182_item	2623866	et	4	main
kirved	doc_491521502182_item	2623867	et	3	main
ja	doc_491521502182_item	2623868	et	3	main
odaotsad	doc_491521502182_item	2623869	et	3	main
ja	doc_491521502182_item	2623870	et	3	main
siis	doc_491521502182_item	2623871	et	3	main
uus	doc_491521502182_item	2623872	et	3	main
mõju	doc_491521502182_item	2623877	et	4	main
pronksi	doc_491521502182_item	2623914	et	4	main
varasel	doc_491521502182_item	2623916	et	4	main
rauaajal	doc_491521502182_item	2623917	et	3	main
oli	doc_491521502182_item	2623918	et	3	main
suur	doc_491521502182_item	2623919	et	3	main
tähtsus	doc_491521502182_item	2623920	et	4	main
suitsetada	doc_491521502180_item	2623622	et	3	main
või	doc_491521502180_item	2623640	et	4	main
koputust	doc_491521502180_item	2623650	et	4	main
tähendus	doc_491521502182_item	2623838	et	4	main
v	doc_491521502182_item	2623846	et	4	main
saj	doc_491521502182_item	2623847	et	4	main
rauaaeg	doc_491521502182_item	2623851	et	3	main
materjal	doc_491521502182_item	2623873	et	3	main
muutusi	doc_491521502182_item	2623931	et	4	main
kõigis	doc_491521502182_item	2623932	et	4	main
eluvaldkondades	doc_491521502182_item	2623933	et	3	main
muutus	doc_491521502182_item	2623934	et	4	main
ühiskondlik	doc_491521502182_item	2623935	et	3	main
sotsiaalne	doc_491521502182_item	2623936	et	3	main
struktuur	doc_491521502182_item	2623937	et	3	main
inimeste	doc_491521502182_item	2623938	et	3	main
üldine	doc_491521502182_item	2623944	et	4	main
kasvatati	doc_491521502182_item	2623956	et	3	main
nisu	doc_491521502182_item	2623959	et	4	main
lina	doc_491521502182_item	2623961	et	4	main
kari	doc_491521502182_item	2623966	et	4	main
pronksesemeid	doc_491521502182_item	2623968	et	3	main
nende	doc_491521502182_item	2623974	et	4	main
kaitsmiseks	doc_491521502182_item	2623975	et	4	main
ehitati	doc_491521502182_item	2623976	et	3	main
rohkem	doc_491521502182_item	2623983	et	4	main
tuntud	doc_491521502182_item	2623985	et	4	main
kujunes	doc_491521502182_item	2623996	et	3	main
ehitama	doc_491521502182_item	2624006	et	4	main
mille	doc_491521502182_item	2624012	et	3	main
kirst	doc_491521502182_item	2624015	et	3	main
tavaliselt	doc_491521502182_item	2624018	et	4	main
kombeks	doc_491521502182_item	2624028	et	4	main
kaelas	doc_491521502182_item	2624030	et	4	main
merevaigust	doc_491521502182_item	2624036	et	4	main
väikesi	doc_491521502182_item	2624037	et	4	main
järgi	doc_491521502182_item	2624055	et	4	main
olendite	doc_491521502182_item	2624057	et	3	main
arvati	doc_491521502182_item	2624065	et	4	main
et	doc_491521502182_item	2624066	et	3	main
elaval	doc_491521502182_item	2624067	et	4	main
elutul	doc_491521502182_item	2624069	et	4	main
loodusel	doc_491521502182_item	2624070	et	4	main
ja	doc_491521502182_item	2624074	et	3	main
1	doc_491521502182_item	2623830	et	2	main
kohtas	doc_491521502182_item	2623859	et	3	main
nende	doc_491521502182_item	2623864	et	4	main
seas	doc_491521502182_item	2623865	et	4	main
veel	doc_491521502182_item	2623875	et	4	main
majandusele	doc_491521502182_item	2623878	et	4	main
domineeris	doc_491521502182_item	2623880	et	3	main
anastavalt	doc_491521502182_item	2623925	et	4	main
see	doc_491521502182_item	2623928	et	3	main
suhted	doc_491521502182_item	2623940	et	3	main
suhtumine	doc_491521502182_item	2623945	et	4	main
kanapit	doc_491521502182_item	2623963	et	4	main
oli	doc_491521502182_item	2623969	et	3	main
varandused	doc_491521502182_item	2623971	et	3	main
ja	doc_491521502182_item	2623972	et	3	main
oli	doc_491521502182_item	2623980	et	3	main
on	doc_491521502182_item	2623986	et	4	main
asva	doc_491521502182_item	2623987	et	4	main
roll	doc_491521502182_item	2623993	et	3	main
ja	doc_491521502182_item	2623995	et	3	main
uued	doc_491521502182_item	2624003	et	3	main
matmiskombed	doc_491521502182_item	2624004	et	3	main
meest	doc_491521502182_item	2624019	et	4	main
seotud	doc_491521502182_item	2624023	et	4	main
muinasuskumustega	doc_491521502182_item	2624024	et	3	main
küljes	doc_491521502182_item	2624033	et	4	main
inimesi	doc_491521502182_item	2624047	et	4	main
see	doc_491521502182_item	2624048	et	3	main
võib	doc_491521502182_item	2624049	et	3	main
olla	doc_491521502182_item	2624050	et	3	main
seotud	doc_491521502182_item	2624051	et	4	main
kujutelmadega	doc_491521502182_item	2624053	et	3	main
hing	doc_491521502182_item	2624058	et	3	main
inimesi	doc_491521502182_item	2624060	et	4	main
olema	doc_491521502182_item	2624072	et	4	main
vägi	doc_491521502182_item	2624075	et	3	main
ekr	doc_491521502182_item	2623848	et	4	main
ja	doc_491521502182_item	2623849	et	3	main
saj	doc_491521502182_item	2623853	et	4	main
veel	doc_491521502182_item	2623861	et	4	main
ja	doc_491521502182_item	2623863	et	3	main
avaldas	doc_491521502182_item	2623874	et	3	main
see	doc_491521502182_item	2623879	et	3	main
rohkem	doc_491521502182_item	2623881	et	4	main
omaniku	doc_491521502182_item	2623882	et	3	main
rikkust	doc_491521502182_item	2623883	et	3	main
ja	doc_491521502182_item	2623884	et	3	main
ühiskondliku	doc_491521502182_item	2623885	et	3	main
seisundit	doc_491521502182_item	2623886	et	3	main
pronksiaja	doc_491521502182_item	2623887	et	3	main
teisel	doc_491521502182_item	2623888	et	4	main
poolel	doc_491521502182_item	2623889	et	4	main
tänu	doc_491521502182_item	2623890	et	4	main
metallkirvestele	doc_491521502182_item	2623891	et	4	main
hakkas	doc_491521502182_item	2623892	et	3	main
levima	doc_491521502182_item	2623893	et	3	main
alepõllundus	doc_491521502182_item	2623894	et	3	main
kõige	doc_491521502182_item	2623895	et	4	main
tähtsam	doc_491521502182_item	2623896	et	4	main
elatusala	doc_491521502182_item	2623897	et	4	main
oli	doc_491521502182_item	2623898	et	3	main
koduloomapidamine	doc_491521502182_item	2623899	et	3	main
kasvatati	doc_491521502182_item	2623900	et	3	main
veiseid	doc_491521502182_item	2623901	et	3	main
sigu	doc_491521502182_item	2623902	et	3	main
lambaid	doc_491521502182_item	2623903	et	3	main
kitsi	doc_491521502182_item	2623904	et	4	main
ja	doc_491521502182_item	2623905	et	3	main
hobuseid	doc_491521502182_item	2623906	et	4	main
mida	doc_491521502182_item	2623907	et	4	main
kasutati	doc_491521502182_item	2623908	et	4	main
ka	doc_491521502182_item	2623909	et	3	main
veoloomadena	doc_491521502182_item	2623910	et	3	main
hakati	doc_491521502182_item	2623911	et	3	main
ka	doc_491521502182_item	2623912	et	3	main
poolel	doc_491521502182_item	2623858	et	4	main
vähe	doc_491521502182_item	2623876	et	3	main
sulama	doc_491521502182_item	2623915	et	4	main
sest	doc_491521502182_item	2623922	et	4	main
üleminek	doc_491521502182_item	2623924	et	3	main
kaasa	doc_491521502182_item	2623930	et	4	main
vaated	doc_491521502182_item	2623942	et	3	main
uut	doc_491521502182_item	2623949	et	3	main
tüüpi	doc_491521502182_item	2623950	et	4	main
asulad	doc_491521502182_item	2623951	et	3	main
ja	doc_491521502182_item	2623952	et	3	main
peamiselt	doc_491521502182_item	2623957	et	4	main
hirssi	doc_491521502182_item	2623960	et	4	main
ja	doc_491521502182_item	2623962	et	3	main
ajal	doc_491521502182_item	2623965	et	4	main
kindlustatud	doc_491521502182_item	2623977	et	4	main
kõige	doc_491521502182_item	2623982	et	4	main
kasvas	doc_491521502182_item	2623991	et	3	main
mehe	doc_491521502182_item	2623992	et	3	main
ühiskonnas	doc_491521502182_item	2623994	et	4	main
nn	doc_491521502182_item	2623997	et	4	main
patriarhaalne	doc_491521502182_item	2623998	et	3	main
suurpere	doc_491521502182_item	2623999	et	4	main
animism	doc_491521502182_item	2624021	et	3	main
ise	doc_491521502182_item	2623913	et	4	main
ajaloos	doc_491521502182_item	2623921	et	4	main
toimus	doc_491521502182_item	2623923	et	3	main
tõi	doc_491521502182_item	2623929	et	3	main
uskulised	doc_491521502182_item	2623941	et	4	main
ja	doc_491521502182_item	2623943	et	3	main
varasel	doc_491521502182_item	2623954	et	4	main
rauaajal	doc_491521502182_item	2623955	et	3	main
asulaid	doc_491521502182_item	2623978	et	4	main
eestis	doc_491521502182_item	2623979	et	3	main
asula	doc_491521502182_item	2623988	et	4	main
sellest	doc_491521502182_item	2624000	et	4	main
keskel	doc_491521502182_item	2624013	et	3	main
keskele	doc_491521502182_item	2624016	et	3	main
2	doc_491521502182_item	2624020	et	2	main
luuplaadist	doc_491521502182_item	2624034	et	3	main
millesed	doc_491521502182_item	2624039	et	4	main
kujutasid	doc_491521502182_item	2624040	et	4	main
karusid	doc_491521502182_item	2624041	et	3	main
kopraid	doc_491521502182_item	2624042	et	4	main
sigu	doc_491521502182_item	2624043	et	3	main
põtru	doc_491521502182_item	2624044	et	3	main
veelinde	doc_491521502182_item	2624045	et	4	main
vastavate	doc_491521502182_item	2624056	et	4	main
ja	doc_491521502182_item	2624068	et	3	main
majanduselt	doc_491521502182_item	2623926	et	4	main
viljelusmajandusele	doc_491521502182_item	2623927	et	3	main
omavahelised	doc_491521502182_item	2623939	et	4	main
ümbritsevasse	doc_491521502182_item	2623946	et	4	main
maailma	doc_491521502182_item	2623947	et	4	main
tekkisid	doc_491521502182_item	2623948	et	4	main
hooned	doc_491521502182_item	2623953	et	4	main
odra	doc_491521502182_item	2623958	et	3	main
tol	doc_491521502182_item	2623964	et	3	main
ja	doc_491521502182_item	2623967	et	3	main
tõelised	doc_491521502182_item	2623970	et	4	main
siis	doc_491521502182_item	2623973	et	3	main
neid	doc_491521502182_item	2623981	et	4	main
rannikul	doc_491521502182_item	2623984	et	3	main
saaremaal	doc_491521502182_item	2623989	et	4	main
samuti	doc_491521502182_item	2623990	et	3	main
kõnelevad	doc_491521502182_item	2624001	et	4	main
kõigepealt	doc_491521502182_item	2624002	et	3	main
hakati	doc_491521502182_item	2624005	et	3	main
kivikirstkalmed	doc_491521502182_item	2624007	et	4	main
see	doc_491521502182_item	2624008	et	3	main
oli	doc_491521502182_item	2624009	et	3	main
suur	doc_491521502182_item	2624010	et	3	main
kiviring	doc_491521502182_item	2624011	et	3	main
oli	doc_491521502182_item	2624014	et	3	main
sängitati	doc_491521502182_item	2624017	et	3	main
ajal	doc_491521502182_item	2624026	et	4	main
oli	doc_491521502182_item	2624027	et	3	main
kanda	doc_491521502182_item	2624029	et	4	main
või	doc_491521502182_item	2624031	et	4	main
riiete	doc_491521502182_item	2624032	et	3	main
kujukesi	doc_491521502182_item	2624038	et	4	main
või	doc_491521502182_item	2624046	et	4	main
mille	doc_491521502182_item	2624054	et	3	main
peab	doc_491521502182_item	2624071	et	4	main
hing	doc_491521502182_item	2624073	et	3	main
on	doc_491521502182_item	2624022	et	4	main
tol	doc_491521502182_item	2624025	et	3	main
või	doc_491521502182_item	2624035	et	4	main
animistlike	doc_491521502182_item	2624052	et	3	main
võis	doc_491521502182_item	2624059	et	4	main
aidata	doc_491521502182_item	2624061	et	4	main
või	doc_491521502182_item	2624062	et	4	main
ohustada	doc_491521502182_item	2624063	et	3	main
samuti	doc_491521502182_item	2624064	et	3	main
kontrolltöö	doc_491521502191_item	2625946	et	4	main
2	doc_491521502191_item	2625958	et	2	main
pärast	doc_491521502191_item	2625981	et	4	main
seega	doc_491521502191_item	2625982	et	4	main
nimetada	doc_491521502191_item	2625996	et	3	main
valmistas	doc_491521502191_item	2626002	et	3	main
kes	doc_491521502191_item	2625948	et	4	main
tähtsamad	doc_491521502191_item	2625950	et	4	main
1	doc_491521502191_item	2625947	et	2	main
miks	doc_491521502191_item	2625957	et	4	main
mingit	doc_491521502191_item	2625977	et	3	main
eesti	doc_491521502191_item	2625979	et	4	main
ja	doc_491521502191_item	2625993	et	3	main
võib	doc_491521502191_item	2625995	et	3	main
mingis	doc_491521502191_item	2625999	et	4	main
ärkamisaega	doc_491521502191_item	2626001	et	4	main
1819	doc_491521502191_item	2626009	et	2	main
a	doc_491521502191_item	2626010	et	4	main
liivimaal	doc_491521502191_item	2626011	et	4	main
rahvakoolide	doc_491521502191_item	2626023	et	3	main
seminari	doc_491521502191_item	2626033	et	4	main
eestikeelsete	doc_491521502191_item	2626041	et	4	main
on	doc_491521502191_item	2626045	et	4	main
sellepärast	doc_491521502191_item	2626047	et	3	main
perioodil	doc_491521502191_item	2626050	et	3	main
ärkamisaeg	doc_491521502191_item	2626055	et	3	main
pani	doc_491521502191_item	2626056	et	4	main
aluse	doc_491521502191_item	2626057	et	4	main
ajal	doc_491521502191_item	2626062	et	4	main
on	doc_491521502191_item	2626063	et	4	main
iseseisvumise	doc_491521502191_item	2626064	et	3	main
juured	doc_491521502191_item	2626065	et	3	main
nagu	doc_491521502191_item	2626066	et	3	main
on	doc_491521502191_item	2626070	et	4	main
ärkamisaja	doc_491521502191_item	2626074	et	3	main
jannsen	doc_491521502191_item	2626080	et	4	main
koostaja	doc_491521502191_item	2626119	et	4	main
samuti	doc_491521502191_item	2626120	et	3	main
õpetliku	doc_491521502191_item	2626121	et	3	main
rahva	doc_491521502191_item	2626129	et	3	main
ja	doc_491521502191_item	2626134	et	3	main
on	doc_491521502191_item	2626144	et	4	main
koidula	doc_491521502191_item	2626145	et	4	main
ta	doc_491521502191_item	2626154	et	4	main
oli	doc_491521502191_item	2626155	et	3	main
rahva	doc_491521502191_item	2626156	et	3	main
lõpliku	doc_491521502191_item	2626157	et	3	main
ühendaja	doc_491521502191_item	2626158	et	4	main
ja	doc_491521502191_item	2626169	et	3	main
tähtsamate	doc_491521502191_item	2626172	et	4	main
rajaja	doc_491521502191_item	2626203	et	4	main
ta	doc_491521502191_item	2626210	et	4	main
seostas	doc_491521502191_item	2626221	et	3	main
jakobsoniga	doc_491521502191_item	2626225	et	4	main
baltisaksa	doc_491521502191_item	2626226	et	4	main
suunaga	doc_491521502191_item	2626227	et	4	main
valitseja	doc_491521502191_item	2625983	et	4	main
sada	doc_491521502191_item	2625991	et	4	main
rahu	doc_491521502191_item	2625997	et	4	main
1816a	doc_491521502191_item	2626006	et	4	main
muutusid	doc_491521502191_item	2626015	et	4	main
kiiresti	doc_491521502191_item	2626016	et	3	main
ka	doc_491521502191_item	2626017	et	3	main
1850	doc_491521502191_item	2626019	et	2	main
olid	doc_491521502191_item	2625949	et	4	main
esimese	doc_491521502191_item	2625951	et	3	main
rahvusliku	doc_491521502191_item	2625952	et	3	main
ärkamisaja	doc_491521502191_item	2625953	et	3	main
vennastekoguduse	doc_491521502191_item	2625959	et	3	main
panus	doc_491521502191_item	2625961	et	4	main
hariduselu	doc_491521502191_item	2625963	et	4	main
edendamisse	doc_491521502191_item	2625964	et	4	main
1	doc_491521502191_item	2625965	et	2	main
ärkamisaeg	doc_491521502191_item	2625966	et	3	main
on	doc_491521502191_item	2625967	et	4	main
eestlaste	doc_491521502191_item	2625968	et	4	main
jaoks	doc_491521502191_item	2625969	et	4	main
väga	doc_491521502191_item	2625970	et	3	main
tähtis	doc_491521502191_item	2625971	et	4	main
aeg	doc_491521502191_item	2625972	et	3	main
sel	doc_491521502191_item	2625973	et	3	main
perioodil	doc_491521502191_item	2625974	et	3	main
ei	doc_491521502191_item	2625975	et	4	main
toimunud	doc_491521502191_item	2625976	et	4	main
tegelased	doc_491521502191_item	2625954	et	3	main
sinu	doc_491521502191_item	2625955	et	3	main
meelest	doc_491521502191_item	2625956	et	4	main
liikumise	doc_491521502191_item	2625960	et	4	main
eestlaste	doc_491521502191_item	2625962	et	4	main
ei	doc_491521502191_item	2625984	et	4	main
aastat	doc_491521502191_item	2625992	et	3	main
ärkamisaega	doc_491521502191_item	2625994	et	4	main
mõttes	doc_491521502191_item	2626000	et	3	main
ette	doc_491521502191_item	2626003	et	4	main
haridusolud	doc_491521502191_item	2626018	et	3	main
aastaks	doc_491521502191_item	2626020	et	4	main
kasvas	doc_491521502191_item	2626021	et	3	main
a	doc_491521502191_item	2626029	et	4	main
oma	doc_491521502191_item	2626032	et	4	main
selles	doc_491521502191_item	2626035	et	4	main
häid	doc_491521502191_item	2626038	et	3	main
arenes	doc_491521502191_item	2626040	et	3	main
raamatute	doc_491521502191_item	2626042	et	3	main
et	doc_491521502191_item	2626048	et	3	main
eesti	doc_491521502191_item	2626052	et	4	main
ja	doc_491521502191_item	2626054	et	3	main
on	doc_491521502191_item	2626077	et	4	main
faehlmann	doc_491521502191_item	2626078	et	4	main
ja	doc_491521502191_item	2626114	et	3	main
ões	doc_491521502191_item	2626115	et	4	main
autor	doc_491521502191_item	2626123	et	3	main
on	doc_491521502191_item	2626125	et	4	main
ühislooming	doc_491521502191_item	2626130	et	3	main
õnnele	doc_491521502191_item	2626141	et	4	main
samuti	doc_491521502191_item	2626142	et	3	main
te	doc_491521502191_item	2626143	et	4	main
jannsen	doc_491521502191_item	2626149	et	4	main
i	doc_491521502191_item	2626159	et	4	main
postimees	doc_491521502191_item	2626167	et	4	main
kuju	doc_491521502191_item	2626176	et	4	main
radikaalseim	doc_491521502191_item	2626207	et	4	main
seostas	doc_491521502191_item	2626211	et	3	main
aleksandri	doc_491521502191_item	2626214	et	4	main
ja	doc_491521502191_item	2626217	et	3	main
venemaaga	doc_491521502191_item	2626218	et	3	main
hurt	doc_491521502191_item	2626219	et	3	main
kirikuisa	doc_491521502191_item	2626220	et	4	main
sõda	doc_491521502191_item	2625978	et	4	main
alade	doc_491521502191_item	2625980	et	3	main
vahetanud	doc_491521502191_item	2625985	et	4	main
vene	doc_491521502191_item	2625986	et	4	main
võim	doc_491521502191_item	2625987	et	3	main
oli	doc_491521502191_item	2625988	et	3	main
juba	doc_491521502191_item	2625989	et	3	main
umbes	doc_491521502191_item	2625990	et	4	main
perioodiks	doc_491521502191_item	2625998	et	3	main
eestimaal	doc_491521502191_item	2626007	et	4	main
ja	doc_491521502191_item	2626008	et	3	main
kiiresti	doc_491521502191_item	2626022	et	3	main
muudeti	doc_491521502191_item	2626026	et	3	main
seminaris	doc_491521502191_item	2626036	et	3	main
ärkamisaeg	doc_491521502191_item	2626044	et	3	main
tähtis	doc_491521502191_item	2626046	et	4	main
sel	doc_491521502191_item	2626049	et	3	main
rahvus	doc_491521502191_item	2626053	et	3	main
sellel	doc_491521502191_item	2626061	et	4	main
perioodil	doc_491521502191_item	2626069	et	3	main
kõige	doc_491521502191_item	2626075	et	4	main
kreutzwald	doc_491521502191_item	2626079	et	4	main
pärisorjuse	doc_491521502191_item	2626004	et	3	main
kaotamine	doc_491521502191_item	2626005	et	4	main
ja	doc_491521502191_item	2626012	et	3	main
teised	doc_491521502191_item	2626013	et	4	main
talurahvaseadused	doc_491521502191_item	2626014	et	3	main
kirikukoolid	doc_491521502191_item	2626025	et	3	main
1849	doc_491521502191_item	2626028	et	2	main
cimze	doc_491521502191_item	2626030	et	4	main
tõi	doc_491521502191_item	2626031	et	3	main
valmistati	doc_491521502191_item	2626037	et	4	main
õpetajaid	doc_491521502191_item	2626039	et	4	main
kirjastamine	doc_491521502191_item	2626043	et	4	main
vähemalt	doc_491521502191_item	2626060	et	4	main
ajastul	doc_491521502191_item	2626068	et	3	main
silmatorkavamad	doc_491521502191_item	2626076	et	4	main
juht	doc_491521502191_item	2626116	et	3	main
kreutzwald	doc_491521502191_item	2626117	et	4	main
eesti	doc_491521502191_item	2626128	et	4	main
lootust	doc_491521502191_item	2626133	et	4	main
usku	doc_491521502191_item	2626135	et	4	main
kalevi	doc_491521502191_item	2626136	et	3	main
rahva	doc_491521502191_item	2626137	et	3	main
ellujäämisele	doc_491521502191_item	2626138	et	4	main
õpetaja	doc_491521502191_item	2626148	et	4	main
nimetatakse	doc_491521502191_item	2626151	et	3	main
ka	doc_491521502191_item	2626152	et	3	main
1857	doc_491521502191_item	2626168	et	2	main
rajaja	doc_491521502191_item	2626171	et	4	main
ärkamisaja	doc_491521502191_item	2626173	et	3	main
jannseni	doc_491521502191_item	2626178	et	4	main
mis	doc_491521502191_item	2626205	et	4	main
oli	doc_491521502191_item	2626206	et	3	main
arengut	doc_491521502191_item	2626213	et	3	main
ii	doc_491521502191_item	2626215	et	4	main
reformidega	doc_491521502191_item	2626216	et	3	main
nende	doc_491521502191_item	2626229	et	4	main
ta	doc_491521502191_item	2626240	et	4	main
asutas	doc_491521502191_item	2626241	et	3	main
kellel	doc_491521502191_item	2626247	et	4	main
edasiandmisel	doc_491521502191_item	2626254	et	3	main
tema	doc_491521502191_item	2626256	et	4	main
üldlaulupeo	doc_491521502191_item	2626275	et	4	main
ajal	doc_491521502191_item	2626276	et	4	main
ja	doc_491521502191_item	2626277	et	3	main
millele	doc_491521502191_item	2626278	et	3	main
olid	doc_491521502191_item	2626279	et	4	main
alusel	doc_491521502191_item	2626292	et	4	main
vennastekoguduste	doc_491521502191_item	2626299	et	4	main
see	doc_491521502191_item	2626305	et	3	main
hariduse	doc_491521502191_item	2626318	et	3	main
ilmus	doc_491521502191_item	2626325	et	4	main
piibli	doc_491521502191_item	2626326	et	3	main
eestikeelne	doc_491521502191_item	2626327	et	3	main
täielik	doc_491521502191_item	2626328	et	3	main
1739	doc_491521502191_item	2626330	et	2	main
kõik	doc_491521502191_item	2626331	et	4	main
need	doc_491521502191_item	2626332	et	3	main
tegurid	doc_491521502191_item	2626333	et	3	main
mõjutasid	doc_491521502191_item	2626334	et	4	main
eestlaste	doc_491521502191_item	2626335	et	4	main
sest	doc_491521502191_item	2626338	et	4	main
saj	doc_491521502191_item	2626349	et	4	main
protsent	doc_491521502191_item	2626358	et	3	main
arv	doc_491521502191_item	2626024	et	3	main
ilmalikuteks	doc_491521502191_item	2626027	et	4	main
valka	doc_491521502191_item	2626034	et	4	main
tekkis	doc_491521502191_item	2626051	et	3	main
eesti	doc_491521502191_item	2626058	et	4	main
iseseisvumisele	doc_491521502191_item	2626059	et	3	main
igal	doc_491521502191_item	2626067	et	3	main
oma	doc_491521502191_item	2626071	et	4	main
silmapaistvad	doc_491521502191_item	2626072	et	3	main
kujud	doc_491521502191_item	2626073	et	3	main
koidula	doc_491521502191_item	2626081	et	4	main
jakobson	doc_491521502191_item	2626082	et	4	main
hurt	doc_491521502191_item	2626083	et	3	main
köler	doc_491521502191_item	2626084	et	4	main
vennad	doc_491521502191_item	2626085	et	3	main
petersonid	doc_491521502191_item	2626086	et	4	main
on	doc_491521502191_item	2626087	et	4	main
vaja	doc_491521502191_item	2626088	et	4	main
mainida	doc_491521502191_item	2626089	et	3	main
ahrensit	doc_491521502191_item	2626090	et	4	main
veskit	doc_491521502191_item	2626091	et	3	main
wiedemanni	doc_491521502191_item	2626092	et	4	main
kunileud	doc_491521502191_item	2626093	et	4	main
türnpuu	doc_491521502191_item	2626094	et	4	main
härmat	doc_491521502191_item	2626095	et	4	main
faehlmann	doc_491521502191_item	2626096	et	4	main
1838	doc_491521502191_item	2626097	et	2	main
a	doc_491521502191_item	2626098	et	4	main
rajas	doc_491521502191_item	2626099	et	4	main
ões	doc_491521502191_item	2626100	et	4	main
ja	doc_491521502191_item	2626101	et	3	main
1839	doc_491521502191_item	2626102	et	2	main
a	doc_491521502191_item	2626103	et	4	main
seltsi	doc_491521502191_item	2626104	et	4	main
koosolekul	doc_491521502191_item	2626105	et	3	main
esitas	doc_491521502191_item	2626106	et	3	main
kalevipoja	doc_491521502191_item	2626107	et	4	main
visandid	doc_491521502191_item	2626108	et	3	main
ta	doc_491521502191_item	2626109	et	4	main
oli	doc_491521502191_item	2626110	et	3	main
tartu	doc_491521502191_item	2626111	et	4	main
ülikooli	doc_491521502191_item	2626112	et	4	main
lektor	doc_491521502191_item	2626113	et	3	main
kalevipoja	doc_491521502191_item	2626118	et	4	main
ja	doc_491521502191_item	2626127	et	3	main
annab	doc_491521502191_item	2626132	et	3	main
ja	doc_491521502191_item	2626147	et	3	main
teda	doc_491521502191_item	2626150	et	4	main
papaks	doc_491521502191_item	2626153	et	3	main
perno	doc_491521502191_item	2626166	et	4	main
koidula	doc_491521502191_item	2626177	et	4	main
ajaleht	doc_491521502191_item	2626209	et	3	main
eesti	doc_491521502191_item	2626222	et	4	main
arengut	doc_491521502191_item	2626223	et	3	main
a	doc_491521502191_item	2626234	et	4	main
kogumise	doc_491521502191_item	2626244	et	4	main
palvekirjade	doc_491521502191_item	2626251	et	3	main
on	doc_491521502191_item	2626258	et	4	main
võrdlust	doc_491521502191_item	2626310	et	4	main
ja	doc_491521502191_item	2626311	et	3	main
saamine	doc_491521502191_item	2626319	et	4	main
ja	doc_491521502191_item	2626320	et	3	main
valgustamine	doc_491521502191_item	2626322	et	4	main
hariduselu	doc_491521502191_item	2626336	et	4	main
hulgas	doc_491521502191_item	2626355	et	4	main
inimesi	doc_491521502191_item	2626359	et	4	main
oskas	doc_491521502191_item	2626361	et	3	main
kirjanduse	doc_491521502191_item	2626122	et	3	main
kalevipoeg	doc_491521502191_item	2626124	et	3	main
kreutzwaldi	doc_491521502191_item	2626126	et	4	main
mis	doc_491521502191_item	2626131	et	4	main
arenemisele	doc_491521502191_item	2626139	et	4	main
ja	doc_491521502191_item	2626140	et	3	main
inspireerija	doc_491521502191_item	2626146	et	4	main
üldlaulupeo	doc_491521502191_item	2626160	et	4	main
peategelane	doc_491521502191_item	2626161	et	3	main
esimese	doc_491521502191_item	2626162	et	3	main
eestikeelse	doc_491521502191_item	2626163	et	3	main
ajalehe	doc_491521502191_item	2626164	et	3	main
autor	doc_491521502191_item	2626165	et	3	main
vanemuise	doc_491521502191_item	2626170	et	4	main
ürituste	doc_491521502191_item	2626174	et	4	main
tähtis	doc_491521502191_item	2626175	et	4	main
tütar	doc_491521502191_item	2626179	et	3	main
esimese	doc_491521502191_item	2626180	et	3	main
vanemuise	doc_491521502191_item	2626181	et	4	main
näidendi	doc_491521502191_item	2626182	et	3	main
autor	doc_491521502191_item	2626183	et	3	main
säärane	doc_491521502191_item	2626184	et	3	main
mulk	doc_491521502191_item	2626185	et	3	main
üks	doc_491521502191_item	2626186	et	3	main
ärkamisaja	doc_491521502191_item	2626187	et	3	main
poeetidest	doc_491521502191_item	2626188	et	3	main
kelle	doc_491521502191_item	2626189	et	4	main
loomingus	doc_491521502191_item	2626190	et	3	main
kajastub	doc_491521502191_item	2626191	et	3	main
romantismi	doc_491521502191_item	2626192	et	4	main
mõju	doc_491521502191_item	2626193	et	4	main
ja	doc_491521502191_item	2626194	et	3	main
on	doc_491521502191_item	2626195	et	4	main
näidatud	doc_491521502191_item	2626196	et	4	main
tema	doc_491521502191_item	2626197	et	4	main
armastus	doc_491521502191_item	2626198	et	4	main
isamaa	doc_491521502191_item	2626199	et	4	main
vastu	doc_491521502191_item	2626200	et	3	main
jakobson	doc_491521502191_item	2626201	et	4	main
sakala	doc_491521502191_item	2626202	et	4	main
1878a	doc_491521502191_item	2626204	et	4	main
eesti	doc_491521502191_item	2626208	et	4	main
eesti	doc_491521502191_item	2626212	et	4	main
võrreldes	doc_491521502191_item	2626224	et	3	main
tekkiski	doc_491521502191_item	2626231	et	3	main
lõhe	doc_491521502191_item	2626232	et	4	main
1878	doc_491521502191_item	2626233	et	2	main
pärimuste	doc_491521502191_item	2626243	et	4	main
suur	doc_491521502191_item	2626249	et	3	main
tähtsus	doc_491521502191_item	2626250	et	4	main
loomingus	doc_491521502191_item	2626257	et	3	main
koidula	doc_491521502191_item	2626281	et	4	main
luuletuste	doc_491521502191_item	2626282	et	4	main
ahrens	doc_491521502191_item	2626284	et	4	main
on	doc_491521502191_item	2626285	et	4	main
liikumine	doc_491521502191_item	2626300	et	4	main
on	doc_491521502191_item	2626301	et	4	main
18	doc_491521502191_item	2626303	et	2	main
alandlikkust	doc_491521502191_item	2626307	et	4	main
kõlblust	doc_491521502191_item	2626308	et	4	main
sotsiaalset	doc_491521502191_item	2626309	et	3	main
ratsionalismi	doc_491521502191_item	2626316	et	4	main
rahvas	doc_491521502191_item	2626339	et	4	main
euroopa	doc_491521502191_item	2626341	et	4	main
haritud	doc_491521502191_item	2626346	et	4	main
kuigi	doc_491521502191_item	2626347	et	3	main
18	doc_491521502191_item	2626348	et	2	main
eestlaste	doc_491521502191_item	2626354	et	4	main
vahel	doc_491521502191_item	2626230	et	4	main
eesti	doc_491521502191_item	2626242	et	4	main
on	doc_491521502191_item	2626248	et	4	main
petersonid	doc_491521502191_item	2626253	et	4	main
tsaarile	doc_491521502191_item	2626255	et	3	main
tähtsad	doc_491521502191_item	2626259	et	3	main
teemad	doc_491521502191_item	2626260	et	3	main
eesti	doc_491521502191_item	2626261	et	4	main
mütoloogia	doc_491521502191_item	2626262	et	4	main
ja	doc_491521502191_item	2626263	et	3	main
loodus	doc_491521502191_item	2626264	et	4	main
n	doc_491521502191_item	2626265	et	4	main
tütarlaps	doc_491521502191_item	2626266	et	4	main
allikal	doc_491521502191_item	2626267	et	3	main
kunileid	doc_491521502191_item	2626268	et	4	main
oli	doc_491521502191_item	2626269	et	3	main
helilooja	doc_491521502191_item	2626270	et	4	main
kelle	doc_491521502191_item	2626271	et	4	main
muusika	doc_491521502191_item	2626272	et	4	main
sellepärast	doc_491521502191_item	2626228	et	3	main
samuti	doc_491521502191_item	2626235	et	3	main
hurt	doc_491521502191_item	2626236	et	3	main
eks	doc_491521502191_item	2626237	et	3	main
esimees	doc_491521502191_item	2626238	et	4	main
ja	doc_491521502191_item	2626239	et	3	main
köler	doc_491521502191_item	2626245	et	4	main
kunstnik	doc_491521502191_item	2626246	et	3	main
vennad	doc_491521502191_item	2626252	et	3	main
i	doc_491521502191_item	2626274	et	4	main
sõnad	doc_491521502191_item	2626283	et	4	main
keele	doc_491521502191_item	2626288	et	4	main
grammatika	doc_491521502191_item	2626289	et	4	main
soome	doc_491521502191_item	2626290	et	3	main
keele	doc_491521502191_item	2626291	et	4	main
2	doc_491521502191_item	2626298	et	2	main
vendlust	doc_491521502191_item	2626312	et	3	main
siin	doc_491521502191_item	2626313	et	4	main
ideed	doc_491521502191_item	2626317	et	4	main
18	doc_491521502191_item	2626323	et	2	main
mängis	doc_491521502191_item	2626273	et	3	main
pandud	doc_491521502191_item	2626280	et	4	main
loodud	doc_491521502191_item	2626286	et	4	main
eesti	doc_491521502191_item	2626287	et	4	main
veski	doc_491521502191_item	2626293	et	4	main
ja	doc_491521502191_item	2626294	et	3	main
wiedelmann	doc_491521502191_item	2626295	et	4	main
olid	doc_491521502191_item	2626296	et	4	main
keelemehed	doc_491521502191_item	2626297	et	3	main
iseloomulik	doc_491521502191_item	2626302	et	3	main
sajandile	doc_491521502191_item	2626304	et	3	main
propageeris	doc_491521502191_item	2626306	et	3	main
olid	doc_491521502191_item	2626314	et	4	main
kajastatud	doc_491521502191_item	2626315	et	4	main
edenemist	doc_491521502191_item	2626337	et	4	main
tartu	doc_491521502191_item	2626350	et	4	main
ülikool	doc_491521502191_item	2626351	et	4	main
oli	doc_491521502191_item	2626352	et	3	main
suletud	doc_491521502191_item	2626353	et	4	main
suur	doc_491521502191_item	2626357	et	3	main
rahva	doc_491521502191_item	2626321	et	3	main
saj	doc_491521502191_item	2626324	et	4	main
tõlge	doc_491521502191_item	2626329	et	3	main
pööras	doc_491521502191_item	2626340	et	4	main
poole	doc_491521502191_item	2626342	et	4	main
ja	doc_491521502191_item	2626343	et	3	main
soovis	doc_491521502191_item	2626344	et	4	main
olla	doc_491521502191_item	2626345	et	3	main
oli	doc_491521502191_item	2626356	et	3	main
kes	doc_491521502191_item	2626360	et	4	main
lugeda	doc_491521502191_item	2626362	et	3	main
1	doc_491521502195_item	2627226	et	2	main
kultuurielule	doc_491521502195_item	2627234	et	3	main
sisuliselt	doc_491521502195_item	2627245	et	4	main
tähendas	doc_491521502195_item	2627246	et	3	main
tü	doc_491521502195_item	2627248	et	4	main
ka	doc_491521502195_item	2627275	et	3	main
grammatikat	doc_491521502195_item	2627278	et	3	main
ülikoole	doc_491521502195_item	2627302	et	4	main
lätlased	doc_491521502195_item	2627307	et	3	main
raamatukogu	doc_491521502195_item	2627314	et	4	main
ajal	doc_491521502195_item	2627341	et	4	main
halvenes	doc_491521502195_item	2627345	et	3	main
keemia	doc_491521502195_item	2627352	et	4	main
arenesid	doc_491521502195_item	2627353	et	4	main
väga	doc_491521502195_item	2627354	et	3	main
hästi	doc_491521502195_item	2627355	et	3	main
ja	doc_491521502195_item	2627356	et	3	main
kiiresti	doc_491521502195_item	2627357	et	3	main
oli	doc_491521502195_item	2627366	et	3	main
üks	doc_491521502195_item	2627367	et	3	main
1816	doc_491521502195_item	2627377	et	2	main
tähendas	doc_491521502195_item	2627381	et	3	main
seda	doc_491521502195_item	2627382	et	3	main
kuid	doc_491521502195_item	2627388	et	4	main
pidid	doc_491521502195_item	2627394	et	4	main
maksma	doc_491521502195_item	2627395	et	3	main
mõisnikule	doc_491521502195_item	2627396	et	3	main
ülikooli	doc_491521502195_item	2627228	et	4	main
haridus-	doc_491521502195_item	2627232	et	3	main
vabastati	doc_491521502195_item	2627237	et	3	main
pärisorjusest	doc_491521502195_item	2627239	et	4	main
mida	doc_491521502195_item	2627241	et	4	main
nende	doc_491521502195_item	2627243	et	4	main
jaoks	doc_491521502195_item	2627244	et	4	main
aastal	doc_491521502195_item	2627251	et	3	main
g	doc_491521502195_item	2627254	et	4	main
fr	doc_491521502195_item	2627255	et	4	main
eesti	doc_491521502195_item	2627271	et	4	main
ja	doc_491521502195_item	2627273	et	3	main
ja	doc_491521502195_item	2627282	et	3	main
töötasid	doc_491521502195_item	2627284	et	4	main
tüs	doc_491521502195_item	2627285	et	4	main
see	doc_491521502195_item	2627286	et	3	main
sündmus	doc_491521502195_item	2627287	et	3	main
oli	doc_491521502195_item	2627288	et	3	main
kasulik	doc_491521502195_item	2627289	et	3	main
ka	doc_491521502195_item	2627290	et	3	main
sakslastele	doc_491521502195_item	2627291	et	3	main
ja	doc_491521502195_item	2627292	et	3	main
rahvuste	doc_491521502195_item	2627294	et	3	main
siin	doc_491521502195_item	2627303	et	4	main
sakslased	doc_491521502195_item	2627308	et	3	main
karl	doc_491521502195_item	2627318	et	4	main
paljud	doc_491521502195_item	2627320	et	3	main
õpisid	doc_491521502195_item	2627323	et	4	main
von	doc_491521502195_item	2627330	et	4	main
baer	doc_491521502195_item	2627331	et	4	main
teised	doc_491521502195_item	2627338	et	4	main
tähtsus	doc_491521502195_item	2627230	et	4	main
2	doc_491521502195_item	2627235	et	2	main
eestlased	doc_491521502195_item	2627238	et	3	main
1	doc_491521502195_item	2627247	et	2	main
taasavati	doc_491521502195_item	2627249	et	3	main
sai	doc_491521502195_item	2627253	et	4	main
õpiti	doc_491521502195_item	2627274	et	3	main
paljud	doc_491521502195_item	2627279	et	3	main
lektorid	doc_491521502195_item	2627281	et	3	main
inimestele	doc_491521502195_item	2627295	et	3	main
tü	doc_491521502195_item	2627297	et	4	main
oli	doc_491521502195_item	2627298	et	3	main
üks	doc_491521502195_item	2627299	et	3	main
ka	doc_491521502195_item	2627305	et	3	main
jne	doc_491521502195_item	2627309	et	4	main
rajaja	doc_491521502195_item	2627316	et	4	main
oli	doc_491521502195_item	2627317	et	3	main
väljapaistvad	doc_491521502195_item	2627321	et	3	main
ja	doc_491521502195_item	2627324	et	3	main
tüs	doc_491521502195_item	2627326	et	4	main
tol	doc_491521502195_item	2627327	et	3	main
j	doc_491521502195_item	2627332	et	4	main
hurt	doc_491521502195_item	2627333	et	3	main
kuigi	doc_491521502195_item	2627339	et	3	main
venestuspoliitika	doc_491521502195_item	2627340	et	4	main
niisugused	doc_491521502195_item	2627347	et	3	main
nagu	doc_491521502195_item	2627349	et	3	main
ja	doc_491521502195_item	2627351	et	3	main
rohkem	doc_491521502195_item	2627360	et	4	main
taasavamine	doc_491521502195_item	2627365	et	4	main
samm	doc_491521502195_item	2627368	et	3	main
rahvuslikku	doc_491521502195_item	2627369	et	4	main
liikumise	doc_491521502195_item	2627370	et	4	main
aastal	doc_491521502195_item	2627378	et	3	main
see	doc_491521502195_item	2627380	et	3	main
vabad	doc_491521502195_item	2627387	et	3	main
vabastati	doc_491521502195_item	2627390	et	3	main
ilma	doc_491521502195_item	2627391	et	4	main
maata	doc_491521502195_item	2627392	et	3	main
talupojad	doc_491521502195_item	2627393	et	4	main
vabanenud	doc_491521502195_item	2627428	et	4	main
linna	doc_491521502195_item	2627431	et	4	main
otsima	doc_491521502195_item	2627433	et	4	main
leidnud	doc_491521502195_item	2627438	et	4	main
tööd	doc_491521502195_item	2627439	et	4	main
aga	doc_491521502195_item	2627440	et	3	main
eesti	doc_491521502195_item	2627459	et	4	main
sõltuv	doc_491521502195_item	2627463	et	4	main
oma	doc_491521502195_item	2627470	et	4	main
kauba	doc_491521502195_item	2627471	et	3	main
talupoeg	doc_491521502195_item	2627477	et	3	main
ka	doc_491521502195_item	2627485	et	3	main
ja	doc_491521502195_item	2627493	et	3	main
rahvas	doc_491521502195_item	2627500	et	4	main
tugevamaks	doc_491521502195_item	2627501	et	4	main
taasavamise	doc_491521502195_item	2627229	et	4	main
ja	doc_491521502195_item	2627233	et	3	main
ja	doc_491521502195_item	2627240	et	3	main
rektoriks	doc_491521502195_item	2627252	et	3	main
eesti	doc_491521502195_item	2627276	et	4	main
keele	doc_491521502195_item	2627277	et	4	main
eestlastest	doc_491521502195_item	2627280	et	4	main
professorid	doc_491521502195_item	2627283	et	3	main
sest	doc_491521502195_item	2627296	et	4	main
parimaid	doc_491521502195_item	2627300	et	4	main
baltimaade	doc_491521502195_item	2627301	et	3	main
venelased	doc_491521502195_item	2627306	et	3	main
tüs	doc_491521502195_item	2627310	et	4	main
oli	doc_491521502195_item	2627311	et	3	main
väga	doc_491521502195_item	2627312	et	3	main
rikkalik	doc_491521502195_item	2627313	et	3	main
tegelased	doc_491521502195_item	2627322	et	3	main
õpetasid	doc_491521502195_item	2627325	et	4	main
ajal	doc_491521502195_item	2627328	et	4	main
fr	doc_491521502195_item	2627334	et	4	main
areng	doc_491521502195_item	2627344	et	3	main
kontrolltöö	doc_491521502195_item	2627225	et	4	main
tartu	doc_491521502195_item	2627227	et	4	main
eesti	doc_491521502195_item	2627231	et	4	main
millal	doc_491521502195_item	2627236	et	3	main
see	doc_491521502195_item	2627242	et	3	main
1802	doc_491521502195_item	2627250	et	2	main
parrot	doc_491521502195_item	2627256	et	4	main
see	doc_491521502195_item	2627257	et	3	main
oli	doc_491521502195_item	2627258	et	3	main
väga	doc_491521502195_item	2627259	et	3	main
tähtis	doc_491521502195_item	2627260	et	4	main
sündmus	doc_491521502195_item	2627261	et	3	main
hakati	doc_491521502195_item	2627262	et	3	main
õpetama	doc_491521502195_item	2627263	et	3	main
erialasid	doc_491521502195_item	2627265	et	4	main
hakati	doc_491521502195_item	2627266	et	3	main
rohkem	doc_491521502195_item	2627264	et	4	main
läbi	doc_491521502195_item	2627267	et	4	main
viima	doc_491521502195_item	2627268	et	3	main
mõned	doc_491521502195_item	2627269	et	3	main
loengud	doc_491521502195_item	2627270	et	3	main
keeles	doc_491521502195_item	2627272	et	4	main
teiste	doc_491521502195_item	2627293	et	4	main
õpisid	doc_491521502195_item	2627304	et	4	main
mille	doc_491521502195_item	2627315	et	3	main
margenstern	doc_491521502195_item	2627319	et	4	main
k	doc_491521502195_item	2627329	et	4	main
r	doc_491521502195_item	2627335	et	4	main
faehlmann	doc_491521502195_item	2627336	et	4	main
ja	doc_491521502195_item	2627337	et	3	main
paljude	doc_491521502195_item	2627342	et	3	main
hakas	doc_491521502195_item	2627358	et	4	main
2	doc_491521502195_item	2627372	et	2	main
pärisorjuse	doc_491521502195_item	2627373	et	3	main
likvideerimine	doc_491521502195_item	2627374	et	4	main
toimus	doc_491521502195_item	2627375	et	3	main
eestimaal	doc_491521502195_item	2627376	et	4	main
olid	doc_491521502195_item	2627385	et	4	main
maa	doc_491521502195_item	2627397	et	4	main
eest	doc_491521502195_item	2627398	et	4	main
renti	doc_491521502195_item	2627399	et	4	main
et	doc_491521502195_item	2627400	et	3	main
nad	doc_491521502195_item	2627401	et	3	main
saaksid	doc_491521502195_item	2627402	et	4	main
seal	doc_491521502195_item	2627403	et	4	main
töötada	doc_491521502195_item	2627404	et	3	main
küll	doc_491521502195_item	2627405	et	4	main
oli	doc_491521502195_item	2627406	et	3	main
aga	doc_491521502195_item	2627407	et	3	main
võimalus	doc_491521502195_item	2627408	et	3	main
maad	doc_491521502195_item	2627409	et	4	main
ära	doc_491521502195_item	2627410	et	4	main
osta	doc_491521502195_item	2627411	et	4	main
kuid	doc_491521502195_item	2627412	et	4	main
talupojad	doc_491521502195_item	2627413	et	4	main
ei	doc_491521502195_item	2627414	et	4	main
saanud	doc_491521502195_item	2627415	et	4	main
veel	doc_491521502195_item	2627416	et	4	main
nii	doc_491521502195_item	2627417	et	3	main
palju	doc_491521502195_item	2627418	et	4	main
raha	doc_491521502195_item	2627419	et	4	main
koguda	doc_491521502195_item	2627420	et	3	main
paljud	doc_491521502195_item	2627427	et	3	main
tööd	doc_491521502195_item	2627432	et	4	main
kuid	doc_491521502195_item	2627434	et	4	main
enamik	doc_491521502195_item	2627435	et	3	main
mõned	doc_491521502195_item	2627441	et	3	main
likvideerimine	doc_491521502195_item	2627453	et	4	main
tähendas	doc_491521502195_item	2627454	et	3	main
vaimset	doc_491521502195_item	2627456	et	3	main
vabadust	doc_491521502195_item	2627457	et	4	main
rahvas	doc_491521502195_item	2627460	et	4	main
ikka	doc_491521502195_item	2627462	et	4	main
oma	doc_491521502195_item	2627464	et	4	main
kui	doc_491521502195_item	2627476	et	3	main
sai	doc_491521502195_item	2627478	et	4	main
rahasumma	doc_491521502195_item	2627480	et	4	main
koguda	doc_491521502195_item	2627481	et	3	main
siis	doc_491521502195_item	2627482	et	3	main
sai	doc_491521502195_item	2627483	et	4	main
tõttu	doc_491521502195_item	2627497	et	4	main
erialade	doc_491521502195_item	2627343	et	3	main
siiski	doc_491521502195_item	2627346	et	4	main
ained	doc_491521502195_item	2627348	et	3	main
füüsika	doc_491521502195_item	2627350	et	4	main
eesti	doc_491521502195_item	2627361	et	4	main
raamatuid	doc_491521502195_item	2627363	et	3	main
poole	doc_491521502195_item	2627371	et	4	main
nüüd	doc_491521502195_item	2627386	et	4	main
neid	doc_491521502195_item	2627389	et	4	main
ja	doc_491521502195_item	2627421	et	3	main
hakasid	doc_491521502195_item	2627423	et	4	main
sammuti	doc_491521502195_item	2627426	et	3	main
neist	doc_491521502195_item	2627436	et	4	main
leidsid	doc_491521502195_item	2627442	et	4	main
oli	doc_491521502195_item	2627461	et	3	main
said	doc_491521502195_item	2627468	et	4	main
talu	doc_491521502195_item	2627486	et	4	main
ja	doc_491521502195_item	2627489	et	3	main
iseenese	doc_491521502195_item	2627491	et	3	main
palgata	doc_491521502195_item	2627494	et	4	main
töölisi	doc_491521502195_item	2627495	et	3	main
selle	doc_491521502195_item	2627496	et	4	main
ilmuma	doc_491521502195_item	2627359	et	3	main
keelseid	doc_491521502195_item	2627362	et	3	main
tü	doc_491521502195_item	2627364	et	4	main
muidugi	doc_491521502195_item	2627379	et	4	main
et	doc_491521502195_item	2627383	et	3	main
talupojad	doc_491521502195_item	2627384	et	4	main
sõitsid	doc_491521502195_item	2627430	et	4	main
ei	doc_491521502195_item	2627437	et	4	main
ja	doc_491521502195_item	2627443	et	3	main
rajasid	doc_491521502195_item	2627445	et	4	main
äri	doc_491521502195_item	2627447	et	4	main
aga	doc_491521502195_item	2627448	et	3	main
neid	doc_491521502195_item	2627449	et	4	main
oli	doc_491521502195_item	2627450	et	3	main
üksikud	doc_491521502195_item	2627451	et	3	main
pärisorjuse	doc_491521502195_item	2627452	et	3	main
kuid	doc_491521502195_item	2627458	et	4	main
toota	doc_491521502195_item	2627469	et	3	main
ja	doc_491521502195_item	2627472	et	3	main
seda	doc_491521502195_item	2627473	et	3	main
müüa	doc_491521502195_item	2627474	et	3	main
ja	doc_491521502195_item	2627475	et	3	main
ta	doc_491521502195_item	2627484	et	4	main
sai	doc_491521502195_item	2627498	et	4	main
eesti	doc_491521502195_item	2627499	et	4	main
eesti	doc_491521502197_item	2627734	et	4	main
1	doc_491521502197_item	2627740	et	2	main
eestimaal	doc_491521502197_item	2627744	et	4	main
strotug	doc_491521502197_item	2627751	et	4	main
liivi	doc_491521502197_item	2627774	et	4	main
eesti-	doc_491521502197_item	2627805	et	4	main
kuid	doc_491521502197_item	2627812	et	4	main
need	doc_491521502197_item	2627815	et	3	main
kubermangud	doc_491521502197_item	2627816	et	3	main
vahel	doc_491521502197_item	2627844	et	4	main
nad	doc_491521502195_item	2627422	et	3	main
palgatöölisteks	doc_491521502195_item	2627424	et	4	main
mõisadel	doc_491521502195_item	2627425	et	4	main
talupojad	doc_491521502195_item	2627429	et	4	main
isegi	doc_491521502195_item	2627444	et	4	main
oma	doc_491521502195_item	2627446	et	4	main
küll	doc_491521502195_item	2627455	et	4	main
vallutajatest	doc_491521502195_item	2627465	et	4	main
kuigi	doc_491521502195_item	2627466	et	3	main
nad	doc_491521502195_item	2627467	et	3	main
vajaliku	doc_491521502195_item	2627479	et	3	main
välja	doc_491521502195_item	2627487	et	4	main
osta	doc_491521502195_item	2627488	et	4	main
olla	doc_491521502195_item	2627490	et	3	main
peremees	doc_491521502195_item	2627492	et	4	main
erikord	doc_491521502197_item	2627729	et	3	main
peeter	doc_491521502197_item	2627747	et	3	main
i	doc_491521502197_item	2627748	et	4	main
kui	doc_491521502197_item	2627749	et	3	main
saavutada	doc_491521502197_item	2627753	et	3	main
pärast	doc_491521502197_item	2627757	et	4	main
kehtima	doc_491521502197_item	2627764	et	3	main
võetud	doc_491521502197_item	2627771	et	4	main
seadused	doc_491521502197_item	2627772	et	3	main
jõudsid	doc_491521502197_item	2627773	et	4	main
1	doc_491521502197_item	2627725	et	2	main
sinna	doc_491521502197_item	2627738	et	3	main
balti	doc_491521502197_item	2627741	et	3	main
juurdus	doc_491521502197_item	2627743	et	3	main
baltisakslaste	doc_491521502197_item	2627754	et	4	main
ja	doc_491521502197_item	2627762	et	3	main
maksud	doc_491521502197_item	2627768	et	3	main
vastu	doc_491521502197_item	2627770	et	3	main
enda	doc_491521502197_item	2627797	et	4	main
riigi	doc_491521502197_item	2627798	et	3	main
institutsioonidest	doc_491521502197_item	2627799	et	3	main
endiselt	doc_491521502197_item	2627821	et	4	main
selts	doc_491521502197_item	2627735	et	3	main
ja	doc_491521502197_item	2627736	et	3	main
kes	doc_491521502197_item	2627737	et	4	main
pärast	doc_491521502197_item	2627745	et	4	main
põhjasõda	doc_491521502197_item	2627746	et	4	main
otsustas	doc_491521502197_item	2627752	et	3	main
poolehoidu	doc_491521502197_item	2627756	et	4	main
vallutamist	doc_491521502197_item	2627758	et	4	main
jättis	doc_491521502197_item	2627759	et	3	main
ta	doc_491521502197_item	2627760	et	4	main
seadused	doc_491521502197_item	2627766	et	3	main
ja	doc_491521502197_item	2627775	et	3	main
kohad	doc_491521502197_item	2627801	et	4	main
täideti	doc_491521502197_item	2627802	et	3	main
baltisaksasoost	doc_491521502197_item	2627803	et	4	main
ametnikega	doc_491521502197_item	2627804	et	3	main
haridus-	doc_491521502197_item	2627831	et	3	main
ja	doc_491521502197_item	2627832	et	3	main
kui	doc_491521502197_item	2627834	et	3	main
saj	doc_491521502197_item	2627836	et	4	main
lõpuni	doc_491521502197_item	2627837	et	3	main
kehtisid	doc_491521502197_item	2627838	et	4	main
balti	doc_491521502197_item	2627839	et	3	main
kubermangude	doc_491521502197_item	2627840	et	3	main
ja	doc_491521502197_item	2627841	et	3	main
erikorrale	doc_491521502197_item	2627850	et	3	main
oli	doc_491521502197_item	2627851	et	3	main
positiivne	doc_491521502197_item	2627855	et	3	main
ainult	doc_491521502197_item	2627867	et	4	main
vene	doc_491521502197_item	2627922	et	4	main
nekrutisse	doc_491521502197_item	2627924	et	3	main
võib	doc_491521502197_item	2627926	et	3	main
väheste	doc_491521502197_item	2627937	et	3	main
oli	doc_491521502197_item	2627951	et	3	main
peamiselt	doc_491521502197_item	2627961	et	4	main
õpetlased	doc_491521502197_item	2627968	et	3	main
minevikku	doc_491521502197_item	2627974	et	4	main
ja	doc_491521502197_item	2627975	et	3	main
suulist	doc_491521502197_item	2627976	et	4	main
pani	doc_491521502197_item	2627981	et	4	main
suure	doc_491521502197_item	2627982	et	3	main
panuse	doc_491521502197_item	2627983	et	3	main
ka	doc_491521502197_item	2627984	et	3	main
1857	doc_491521502197_item	2627988	et	2	main
mis	doc_491521502197_item	2628000	et	4	main
tegelema	doc_491521502197_item	2628002	et	3	main
kontrolltöö	doc_491521502197_item	2627724	et	4	main
mida	doc_491521502197_item	2627726	et	4	main
tähendab	doc_491521502197_item	2627727	et	3	main
balti	doc_491521502197_item	2627728	et	3	main
2	doc_491521502197_item	2627730	et	2	main
millega	doc_491521502197_item	2627731	et	3	main
tegeles	doc_491521502197_item	2627732	et	3	main
õpetatud	doc_491521502197_item	2627733	et	4	main
kuulusid	doc_491521502197_item	2627739	et	4	main
erikord	doc_491521502197_item	2627742	et	3	main
kaval	doc_491521502197_item	2627750	et	4	main
seas	doc_491521502197_item	2627755	et	4	main
eestimaal	doc_491521502197_item	2627761	et	4	main
liivimaal	doc_491521502197_item	2627763	et	4	main
senised	doc_491521502197_item	2627765	et	3	main
ja	doc_491521502197_item	2627767	et	3	main
venemaal	doc_491521502197_item	2627769	et	4	main
üksnes	doc_491521502197_item	2627777	et	3	main
kui	doc_491521502197_item	2627778	et	3	main
olid	doc_491521502197_item	2627779	et	4	main
kohaliku	doc_491521502197_item	2627780	et	3	main
võimu	doc_491521502197_item	2627781	et	4	main
poolt	doc_491521502197_item	2627782	et	4	main
registreeritud	doc_491521502197_item	2627783	et	4	main
peterbusis	doc_491521502197_item	2627784	et	4	main
asutati	doc_491521502197_item	2627785	et	4	main
isegi	doc_491521502197_item	2627786	et	4	main
eestimaa	doc_491521502197_item	2627787	et	4	main
ja	doc_491521502197_item	2627788	et	3	main
liivimaa	doc_491521502197_item	2627789	et	4	main
asjade	doc_491521502197_item	2627790	et	3	main
pististikolleegium	doc_491521502197_item	2627791	et	4	main
ning	doc_491521502197_item	2627792	et	3	main
kõrgem	doc_491521502197_item	2627793	et	4	main
kohus	doc_491521502197_item	2627794	et	4	main
eraldi	doc_491521502197_item	2627795	et	4	main
venemaa	doc_491521502197_item	2627796	et	4	main
eestimaale	doc_491521502197_item	2627776	et	4	main
ja	doc_491521502197_item	2627806	et	3	main
liivimaa	doc_491521502197_item	2627807	et	4	main
oli	doc_491521502197_item	2627808	et	3	main
vene	doc_491521502197_item	2627809	et	4	main
riigi	doc_491521502197_item	2627810	et	3	main
koosseisus	doc_491521502197_item	2627811	et	4	main
valiseva	doc_491521502197_item	2627818	et	4	main
ikke	doc_491521502197_item	2627819	et	3	main
all	doc_491521502197_item	2627820	et	3	main
luteri	doc_491521502197_item	2627824	et	3	main
kohtukeeleks	doc_491521502197_item	2627833	et	4	main
18	doc_491521502197_item	2627835	et	2	main
venemaa	doc_491521502197_item	2627843	et	4	main
tabamiseks	doc_491521502197_item	2627848	et	4	main
balti	doc_491521502197_item	2627849	et	3	main
iseloomulik	doc_491521502197_item	2627852	et	3	main
üks	doc_491521502197_item	2627854	et	3	main
lugemise	doc_491521502197_item	2627869	et	4	main
ja	doc_491521502197_item	2627870	et	3	main
sai	doc_491521502197_item	2627873	et	4	main
võimalikuks	doc_491521502197_item	2627874	et	3	main
eesti	doc_491521502197_item	2627875	et	4	main
kultuuri	doc_491521502197_item	2627876	et	4	main
venestumine	doc_491521502197_item	2627885	et	4	main
balti	doc_491521502197_item	2627886	et	3	main
armeesse	doc_491521502197_item	2627923	et	4	main
julgelt	doc_491521502197_item	2627927	et	4	main
öelda	doc_491521502197_item	2627928	et	4	main
et	doc_491521502197_item	2627929	et	3	main
põhjasõja-järgsel	doc_491521502197_item	2627930	et	3	main
perioodil	doc_491521502197_item	2627931	et	3	main
suuremal	doc_491521502197_item	2627940	et	4	main
õpetatud	doc_491521502197_item	2627953	et	4	main
pärimust	doc_491521502197_item	2627977	et	4	main
ões	doc_491521502197_item	2627985	et	4	main
1861	doc_491521502197_item	2627989	et	2	main
fr	doc_491521502197_item	2627993	et	4	main
eesti	doc_491521502197_item	2628003	et	4	main
rahvaloo	doc_491521502197_item	2628004	et	4	main
kubermanguvalimise	doc_491521502197_item	2627800	et	3	main
sisuliselt	doc_491521502197_item	2627813	et	4	main
eksisteerisid	doc_491521502197_item	2627814	et	4	main
baltisakslase	doc_491521502197_item	2627817	et	3	main
jäi	doc_491521502197_item	2627822	et	3	main
valitsevaks	doc_491521502197_item	2627823	et	4	main
usk	doc_491521502197_item	2627825	et	3	main
saksa	doc_491521502197_item	2627826	et	4	main
keel	doc_491521502197_item	2627827	et	4	main
jäi	doc_491521502197_item	2627828	et	3	main
kohaliku	doc_491521502197_item	2627829	et	3	main
tollipiirid	doc_491521502197_item	2627845	et	3	main
talupoegade	doc_491521502197_item	2627847	et	3	main
ka	doc_491521502197_item	2627853	et	3	main
nimelt	doc_491521502197_item	2627857	et	4	main
baltisaksa	doc_491521502197_item	2627859	et	4	main
mõisniku	doc_491521502197_item	2627860	et	3	main
põlisrahva	doc_491521502197_item	2627863	et	3	main
elementaarset	doc_491521502197_item	2627868	et	3	main
rehkendamise	doc_491521502197_item	2627871	et	4	main
säilimine	doc_491521502197_item	2627877	et	4	main
ajal	doc_491521502197_item	2627888	et	4	main
tehti	doc_491521502197_item	2627889	et	3	main
eesti	doc_491521502197_item	2627897	et	4	main
kubermangu	doc_491521502197_item	2627898	et	4	main
elanikes	doc_491521502197_item	2627899	et	3	main
oskas	doc_491521502197_item	2627900	et	3	main
lugeda	doc_491521502197_item	2627901	et	3	main
eesti	doc_491521502197_item	2627902	et	4	main
kubermangu	doc_491521502197_item	2627903	et	4	main
sellinne	doc_491521502197_item	2627904	et	4	main
näit	doc_491521502197_item	2627905	et	3	main
oli	doc_491521502197_item	2627906	et	3	main
kõrgeim	doc_491521502197_item	2627907	et	4	main
venemaal	doc_491521502197_item	2627908	et	4	main
üldse	doc_491521502197_item	2627909	et	3	main
võib	doc_491521502197_item	2627910	et	3	main
täheldada	doc_491521502197_item	2627911	et	3	main
ka	doc_491521502197_item	2627912	et	3	main
seda	doc_491521502197_item	2627913	et	3	main
et	doc_491521502197_item	2627914	et	3	main
balti	doc_491521502197_item	2627915	et	3	main
erikorra	doc_491521502197_item	2627916	et	3	main
algusaastatel	doc_491521502197_item	2627917	et	4	main
ei	doc_491521502197_item	2627918	et	4	main
pidanud	doc_491521502197_item	2627919	et	4	main
eesti	doc_491521502197_item	2627920	et	4	main
asjaajamis-	doc_491521502197_item	2627830	et	4	main
ülejäänud	doc_491521502197_item	2627842	et	4	main
põgeneva	doc_491521502197_item	2627846	et	4	main
harimisel	doc_491521502197_item	2627864	et	4	main
suunas	doc_491521502197_item	2627865	et	4	main
õpetati	doc_491521502197_item	2627866	et	3	main
algteadmisi	doc_491521502197_item	2627872	et	3	main
ning	doc_491521502197_item	2627878	et	3	main
välditud	doc_491521502197_item	2627880	et	4	main
assimileerimine	doc_491521502197_item	2627882	et	4	main
saksastumine	doc_491521502197_item	2627883	et	4	main
või	doc_491521502197_item	2627884	et	4	main
panus	doc_491521502197_item	2627891	et	4	main
rajamiseks	doc_491521502197_item	2627894	et	4	main
ligi	doc_491521502197_item	2627895	et	3	main
saadik	doc_491521502197_item	2627932	et	4	main
muutustega	doc_491521502197_item	2627941	et	4	main
kuni	doc_491521502197_item	2627942	et	3	main
20	doc_491521502197_item	2627943	et	2	main
faehmann	doc_491521502197_item	2627950	et	4	main
seltsi	doc_491521502197_item	2627955	et	4	main
1838	doc_491521502197_item	2627957	et	2	main
selts	doc_491521502197_item	2627958	et	3	main
koondas	doc_491521502197_item	2627959	et	3	main
küll	doc_491521502197_item	2627960	et	4	main
hakkasid	doc_491521502197_item	2627969	et	4	main
juures	doc_491521502197_item	2627986	et	4	main
kalevipoega	doc_491521502197_item	2627991	et	4	main
uurimisega	doc_491521502197_item	2628005	et	4	main
külg	doc_491521502197_item	2627856	et	3	main
tänu	doc_491521502197_item	2627858	et	4	main
ägedale	doc_491521502197_item	2627861	et	3	main
vastupanule	doc_491521502197_item	2627862	et	3	main
oli	doc_491521502197_item	2627879	et	3	main
põlisrahva	doc_491521502197_item	2627881	et	3	main
erikorra	doc_491521502197_item	2627887	et	3	main
suur	doc_491521502197_item	2627890	et	3	main
talurahva	doc_491521502197_item	2627892	et	3	main
maakoolide	doc_491521502197_item	2627893	et	3	main
¾	doc_491521502197_item	2627896	et	2	main
mehed	doc_491521502197_item	2627921	et	3	main
minema	doc_491521502197_item	2627925	et	3	main
väiksemal	doc_491521502197_item	2627938	et	4	main
või	doc_491521502197_item	2627939	et	4	main
pooleni	doc_491521502197_item	2627946	et	3	main
friedrich	doc_491521502197_item	2627948	et	4	main
robert	doc_491521502197_item	2627949	et	4	main
saksa	doc_491521502197_item	2627962	et	4	main
soost	doc_491521502197_item	2627963	et	4	main
estofiile	doc_491521502197_item	2627964	et	4	main
ent	doc_491521502197_item	2627965	et	3	main
sinna	doc_491521502197_item	2627966	et	3	main
kuulunud	doc_491521502197_item	2627967	et	4	main
eesti	doc_491521502197_item	2627971	et	4	main
rahva	doc_491521502197_item	2627973	et	3	main
kogumisse	doc_491521502197_item	2627980	et	4	main
tegutsenud	doc_491521502197_item	2627987	et	4	main
hakkas	doc_491521502197_item	2628001	et	3	main
juurdunud	doc_491521502197_item	2627933	et	4	main
balti	doc_491521502197_item	2627934	et	3	main
erikord	doc_491521502197_item	2627935	et	3	main
kehtis	doc_491521502197_item	2627936	et	3	main
saj	doc_491521502197_item	2627944	et	4	main
esimese	doc_491521502197_item	2627945	et	3	main
2	doc_491521502197_item	2627947	et	2	main
üks	doc_491521502197_item	2627952	et	3	main
eesti	doc_491521502197_item	2627954	et	4	main
rajajatest	doc_491521502197_item	2627956	et	4	main
uurima	doc_491521502197_item	2627970	et	3	main
keelt	doc_491521502197_item	2627972	et	4	main
faelmanni	doc_491521502197_item	2627978	et	4	main
vägilasmuistendite	doc_491521502197_item	2627979	et	4	main
aastal	doc_491521502197_item	2627990	et	3	main
kirjutanud	doc_491521502197_item	2627992	et	4	main
kreutzwald	doc_491521502197_item	2627994	et	4	main
ões	doc_491521502197_item	2627995	et	4	main
oli	doc_491521502197_item	2627996	et	3	main
esimene	doc_491521502197_item	2627997	et	3	main
avalik	doc_491521502197_item	2627998	et	3	main
selts	doc_491521502197_item	2627999	et	3	main
valja	doc_491521502199_item	2628334	et	3	main
faelhmanil	doc_491521502199_item	2628342	et	4	main
kalevipoja	doc_491521502199_item	2628349	et	4	main
ta	doc_491521502199_item	2628352	et	4	main
võttis	doc_491521502199_item	2628353	et	3	main
länrotti	doc_491521502199_item	2628354	et	4	main
kalevala	doc_491521502199_item	2628357	et	4	main
oma	doc_491521502199_item	2628359	et	4	main
eesti	doc_491521502199_item	2628366	et	4	main
kreutzwald	doc_491521502199_item	2628380	et	4	main
ka	doc_491521502199_item	2628426	et	3	main
sinna	doc_491521502199_item	2628442	et	3	main
pärast	doc_491521502199_item	2628445	et	4	main
sõda	doc_491521502199_item	2628447	et	4	main
nende	doc_491521502199_item	2628448	et	4	main
privileegid	doc_491521502199_item	2628449	et	3	main
olid	doc_491521502199_item	2628453	et	4	main
enamik	doc_491521502199_item	2628455	et	3	main
valitsusajal	doc_491521502199_item	2628483	et	3	main
viis	doc_491521502199_item	2628487	et	4	main
uue	doc_491521502199_item	2628489	et	3	main
reformi	doc_491521502199_item	2628490	et	4	main
ning	doc_491521502199_item	2628497	et	3	main
pärast	doc_491521502199_item	2628498	et	4	main
kõik	doc_491521502199_item	2628502	et	4	main
eesti	doc_491521502200_item	2628518	et	4	main
sinna	doc_491521502200_item	2628522	et	3	main
balti	doc_491521502200_item	2628527	et	3	main
oli	doc_491521502200_item	2628541	et	3	main
balti	doc_491521502200_item	2628543	et	3	main
mõisnike	doc_491521502200_item	2628553	et	3	main
omandiks	doc_491521502200_item	2628554	et	3	main
need	doc_491521502200_item	2628558	et	3	main
püsima	doc_491521502200_item	2628573	et	3	main
jagada	doc_491521502200_item	2628583	et	3	main
erikord	doc_491521502199_item	2628292	et	3	main
2	doc_491521502199_item	2628293	et	2	main
millega	doc_491521502199_item	2628294	et	3	main
tegeles	doc_491521502199_item	2628295	et	3	main
õpetatud	doc_491521502199_item	2628296	et	4	main
eesti	doc_491521502199_item	2628297	et	4	main
selts	doc_491521502199_item	2628298	et	3	main
ja	doc_491521502199_item	2628299	et	3	main
kes	doc_491521502199_item	2628300	et	4	main
sinna	doc_491521502199_item	2628301	et	3	main
kuulusid	doc_491521502199_item	2628302	et	4	main
2	doc_491521502199_item	2628303	et	2	main
õpetatud	doc_491521502199_item	2628304	et	4	main
eesti	doc_491521502199_item	2628305	et	4	main
selts	doc_491521502199_item	2628306	et	3	main
oli	doc_491521502199_item	2628307	et	3	main
1838	doc_491521502199_item	2628309	et	2	main
rajatud	doc_491521502199_item	2628308	et	4	main
aastal	doc_491521502199_item	2628310	et	3	main
faelhmani	doc_491521502199_item	2628311	et	4	main
algatusel	doc_491521502199_item	2628312	et	4	main
nende	doc_491521502199_item	2628313	et	4	main
huviobjektiks	doc_491521502199_item	2628314	et	3	main
said	doc_491521502199_item	2628315	et	4	main
eestlased	doc_491521502199_item	2628316	et	3	main
nende	doc_491521502199_item	2628317	et	4	main
maa	doc_491521502199_item	2628318	et	4	main
ja	doc_491521502199_item	2628319	et	3	main
kultuur	doc_491521502199_item	2628320	et	3	main
eesti	doc_491521502199_item	2628322	et	4	main
kogumine	doc_491521502199_item	2628331	et	4	main
andmine	doc_491521502199_item	2628335	et	4	main
haritsastest	doc_491521502199_item	2628339	et	4	main
soome	doc_491521502199_item	2628355	et	3	main
kalevipoja	doc_491521502199_item	2628360	et	4	main
ettekandena	doc_491521502199_item	2628364	et	3	main
eepose	doc_491521502199_item	2628374	et	3	main
ettepanekul	doc_491521502199_item	2628377	et	3	main
üle	doc_491521502199_item	2628379	et	3	main
sellest	doc_491521502199_item	2628381	et	4	main
õpetatud	doc_491521502199_item	2628321	et	4	main
seltsi	doc_491521502199_item	2628323	et	4	main
eesmärgiks	doc_491521502199_item	2628324	et	3	main
oli	doc_491521502199_item	2628325	et	3	main
rahvakultuuri	doc_491521502199_item	2628326	et	4	main
ning	doc_491521502199_item	2628332	et	3	main
koosnes	doc_491521502199_item	2628337	et	3	main
sel	doc_491521502199_item	2628340	et	3	main
ajal	doc_491521502199_item	2628341	et	4	main
tekkis	doc_491521502199_item	2628343	et	3	main
mõtte	doc_491521502199_item	2628344	et	3	main
kirjutada	doc_491521502199_item	2628345	et	3	main
tema	doc_491521502199_item	2628346	et	4	main
müütide	doc_491521502199_item	2628347	et	3	main
eepose	doc_491521502199_item	2628356	et	3	main
ning	doc_491521502199_item	2628358	et	3	main
visandid	doc_491521502199_item	2628361	et	3	main
esitas	doc_491521502199_item	2628362	et	3	main
faelhman	doc_491521502199_item	2628363	et	4	main
õpetatud	doc_491521502199_item	2628365	et	4	main
pärast	doc_491521502199_item	2628368	et	4	main
tema	doc_491521502199_item	2628369	et	4	main
surma	doc_491521502199_item	2628370	et	4	main
sai	doc_491521502199_item	2628383	et	4	main
rahva	doc_491521502199_item	2628385	et	3	main
kultuuri	doc_491521502199_item	2628388	et	4	main
kontrolltöö	doc_491521502199_item	2628287	et	4	main
1	doc_491521502199_item	2628288	et	2	main
mida	doc_491521502199_item	2628289	et	4	main
tähendab	doc_491521502199_item	2628290	et	3	main
balti	doc_491521502199_item	2628291	et	3	main
uurimine	doc_491521502199_item	2628327	et	4	main
rahvalaulude	doc_491521502199_item	2628328	et	3	main
ja	doc_491521502199_item	2628329	et	3	main
mustendite	doc_491521502199_item	2628330	et	4	main
valgustuskirjanduse	doc_491521502199_item	2628333	et	3	main
seltsis	doc_491521502199_item	2628367	et	4	main
1850	doc_491521502199_item	2628371	et	2	main
aastal	doc_491521502199_item	2628372	et	3	main
kalevipja	doc_491521502199_item	2628373	et	4	main
eesti	doc_491521502199_item	2628384	et	4	main
elu	doc_491521502199_item	2628386	et	4	main
ja	doc_491521502199_item	2628387	et	3	main
ajalooga	doc_491521502199_item	2628424	et	4	main
selle	doc_491521502199_item	2628427	et	4	main
sinna	doc_491521502199_item	2628429	et	3	main
jt	doc_491521502199_item	2628438	et	4	main
1	doc_491521502199_item	2628439	et	2	main
põhja	doc_491521502199_item	2628446	et	4	main
nad	doc_491521502199_item	2628452	et	3	main
olid	doc_491521502199_item	2628458	et	4	main
reformid	doc_491521502199_item	2628477	et	4	main
toetusid	doc_491521502199_item	2628478	et	4	main
euroopale	doc_491521502199_item	2628479	et	3	main
kuid	doc_491521502199_item	2628480	et	4	main
katariina	doc_491521502199_item	2628481	et	4	main
muutus	doc_491521502199_item	2628485	et	4	main
privileegid	doc_491521502199_item	2628492	et	3	main
vähenesid	doc_491521502199_item	2628493	et	4	main
kuid	doc_491521502199_item	2628494	et	4	main
ii	doc_491521502199_item	2628500	et	4	main
muutus	doc_491521502199_item	2628503	et	4	main
nagu	doc_491521502199_item	2628505	et	3	main
enne	doc_491521502199_item	2628507	et	4	main
selts	doc_491521502200_item	2628519	et	3	main
kuulusid	doc_491521502200_item	2628523	et	4	main
tõttu	doc_491521502200_item	2628529	et	4	main
isanda	doc_491521502200_item	2628531	et	3	main
alla	doc_491521502200_item	2628533	et	3	main
talupoeg	doc_491521502200_item	2628540	et	3	main
pärisorjus	doc_491521502200_item	2628546	et	3	main
varem	doc_491521502200_item	2628561	et	4	main
vabad	doc_491521502200_item	2628563	et	3	main
poolvabad	doc_491521502200_item	2628565	et	3	main
rootsi	doc_491521502200_item	2628569	et	4	main
aegsed	doc_491521502200_item	2628570	et	3	main
seadused	doc_491521502200_item	2628571	et	3	main
jäävad	doc_491521502200_item	2628572	et	4	main
kodukari	doc_491521502200_item	2628576	et	4	main
st	doc_491521502200_item	2628578	et	3	main
nad	doc_491521502200_item	2628579	et	3	main
võisid	doc_491521502200_item	2628580	et	4	main
talupojad	doc_491521502200_item	2628584	et	4	main
tihti	doc_491521502200_item	2628586	et	3	main
kuulusid	doc_491521502200_item	2628622	et	4	main
keelde	doc_491521502200_item	2628640	et	4	main
kus	doc_491521502200_item	2628645	et	3	main
peaks	doc_491521502200_item	2628648	et	4	main
sisuks	doc_491521502200_item	2628651	et	3	main
kui	doc_491521502200_item	2628658	et	3	main
rahvaluulet	doc_491521502200_item	2628674	et	3	main
kuulus	doc_491521502200_item	2628681	et	4	main
ka	doc_491521502200_item	2628682	et	3	main
luua	doc_491521502200_item	2628689	et	4	main
kool	doc_491521502200_item	2628693	et	4	main
mis	doc_491521502200_item	2628694	et	4	main
läks	doc_491521502200_item	2628705	et	3	main
hinge	doc_491521502200_item	2628707	et	4	main
liikumise	doc_491521502200_item	2628712	et	4	main
ões	doc_491521502199_item	2628336	et	4	main
üliõpelastest	doc_491521502199_item	2628338	et	4	main
kõrval	doc_491521502199_item	2628348	et	4	main
eepos	doc_491521502199_item	2628350	et	3	main
eeskujuks	doc_491521502199_item	2628351	et	3	main
koostamise	doc_491521502199_item	2628375	et	4	main
ões-i	doc_491521502199_item	2628376	et	4	main
võttis	doc_491521502199_item	2628378	et	3	main
sümbol	doc_491521502199_item	2628389	et	3	main
väga	doc_491521502199_item	2628390	et	3	main
tähtis	doc_491521502199_item	2628391	et	4	main
oli	doc_491521502199_item	2628392	et	3	main
ka	doc_491521502199_item	2628393	et	3	main
ões-i	doc_491521502199_item	2628394	et	4	main
valgustustegevus	doc_491521502199_item	2628395	et	4	main
näiteks	doc_491521502199_item	2628396	et	4	main
anti	doc_491521502199_item	2628397	et	3	main
välja	doc_491521502199_item	2628398	et	4	main
palju	doc_491521502199_item	2628399	et	4	main
kalendreid	doc_491521502199_item	2628400	et	3	main
mis	doc_491521502199_item	2628401	et	4	main
olid	doc_491521502199_item	2628402	et	4	main
õpetliku	doc_491521502199_item	2628403	et	3	main
sisuga	doc_491521502199_item	2628404	et	3	main
nad	doc_491521502199_item	2628405	et	3	main
olid	doc_491521502199_item	2628406	et	4	main
väga	doc_491521502199_item	2628407	et	3	main
populaarsed	doc_491521502199_item	2628408	et	3	main
rahva	doc_491521502199_item	2628409	et	3	main
sees	doc_491521502199_item	2628410	et	4	main
sest	doc_491521502199_item	2628411	et	4	main
olid	doc_491521502199_item	2628412	et	4	main
odavad	doc_491521502199_item	2628413	et	3	main
ja	doc_491521502199_item	2628414	et	3	main
sellega	doc_491521502199_item	2628415	et	3	main
kättesaadavad	doc_491521502199_item	2628416	et	3	main
ões	doc_491521502199_item	2628417	et	4	main
tegeles	doc_491521502199_item	2628418	et	3	main
nii	doc_491521502199_item	2628419	et	3	main
eesti	doc_491521502199_item	2628420	et	4	main
uurimisega	doc_491521502199_item	2628423	et	4	main
kuulusid	doc_491521502199_item	2628430	et	4	main
faelhman	doc_491521502199_item	2628431	et	4	main
köler	doc_491521502199_item	2628437	et	4	main
kuulusid	doc_491521502199_item	2628443	et	4	main
baltisakslased	doc_491521502199_item	2628444	et	3	main
säilisid	doc_491521502199_item	2628450	et	4	main
ka	doc_491521502199_item	2628457	et	3	main
nende	doc_491521502199_item	2628460	et	4	main
eeposest	doc_491521502199_item	2628382	et	4	main
rahva	doc_491521502199_item	2628421	et	3	main
kreutzwald	doc_491521502199_item	2628432	et	4	main
jannsen	doc_491521502199_item	2628433	et	4	main
koidula	doc_491521502199_item	2628434	et	4	main
hurt	doc_491521502199_item	2628435	et	3	main
j	doc_491521502199_item	2628436	et	4	main
erikord	doc_491521502199_item	2628441	et	3	main
tsaari	doc_491521502199_item	2628476	et	4	main
ii	doc_491521502199_item	2628482	et	4	main
baltisakslaste	doc_491521502199_item	2628491	et	4	main
ikka	doc_491521502199_item	2628495	et	4	main
surma	doc_491521502199_item	2628501	et	4	main
kultuuri	doc_491521502199_item	2628422	et	4	main
kuid	doc_491521502199_item	2628425	et	4	main
arenemisega	doc_491521502199_item	2628428	et	4	main
balti	doc_491521502199_item	2628440	et	3	main
maaomand	doc_491521502199_item	2628451	et	3	main
kõrgem-ametnikud	doc_491521502199_item	2628454	et	3	main
linnakodanikest	doc_491521502199_item	2628456	et	3	main
baltisakslased	doc_491521502199_item	2628459	et	3	main
privileegid	doc_491521502199_item	2628461	et	3	main
säilis	doc_491521502199_item	2628462	et	4	main
peeter	doc_491521502199_item	2628463	et	3	main
i	doc_491521502199_item	2628464	et	4	main
sellega	doc_491521502199_item	2628465	et	3	main
ta	doc_491521502199_item	2628466	et	4	main
tahtis	doc_491521502199_item	2628467	et	3	main
et	doc_491521502199_item	2628468	et	3	main
nad	doc_491521502199_item	2628469	et	3	main
ei	doc_491521502199_item	2628470	et	4	main
olnud	doc_491521502199_item	2628471	et	4	main
tema	doc_491521502199_item	2628472	et	4	main
vastu	doc_491521502199_item	2628473	et	3	main
kuna	doc_491521502199_item	2628474	et	3	main
vene	doc_491521502199_item	2628475	et	4	main
olukord	doc_491521502199_item	2628484	et	3	main
ta	doc_491521502199_item	2628486	et	4	main
läbi	doc_491521502199_item	2628488	et	4	main
säilisid	doc_491521502199_item	2628496	et	4	main
tagasi	doc_491521502199_item	2628504	et	3	main
oli	doc_491521502199_item	2628506	et	3	main
kontrolltöö	doc_491521502200_item	2628508	et	4	main
mida	doc_491521502200_item	2628510	et	4	main
tähendab	doc_491521502200_item	2628511	et	3	main
balti	doc_491521502200_item	2628512	et	3	main
erikord	doc_491521502200_item	2628513	et	3	main
millega	doc_491521502200_item	2628515	et	3	main
tegeles	doc_491521502200_item	2628516	et	3	main
õpetatud	doc_491521502200_item	2628517	et	4	main
sattus	doc_491521502200_item	2628526	et	3	main
erikorra	doc_491521502200_item	2628528	et	3	main
aadliku	doc_491521502200_item	2628539	et	3	main
raames	doc_491521502200_item	2628545	et	4	main
vara	doc_491521502200_item	2628549	et	4	main
igati	doc_491521502200_item	2628551	et	3	main
pärisorjadeks	doc_491521502200_item	2628555	et	3	main
ka	doc_491521502200_item	2628557	et	3	main
talupojad	doc_491521502200_item	2628559	et	4	main
kes	doc_491521502200_item	2628560	et	4	main
otsustati	doc_491521502200_item	2628567	et	3	main
talupoegadele	doc_491521502200_item	2628581	et	3	main
kelle	doc_491521502200_item	2628628	et	4	main
eestvedamisel	doc_491521502200_item	2628629	et	3	main
vajalikkust	doc_491521502200_item	2628633	et	4	main
muistendeid	doc_491521502200_item	2628638	et	3	main
nö	doc_491521502200_item	2628642	et	4	main
kalevipoja	doc_491521502200_item	2628643	et	4	main
temast	doc_491521502200_item	2628652	et	3	main
poleks	doc_491521502200_item	2628660	et	3	main
oli	doc_491521502200_item	2628667	et	3	main
ja	doc_491521502200_item	2628670	et	3	main
jakob	doc_491521502200_item	2628683	et	4	main
hurt	doc_491521502200_item	2628684	et	3	main
kes	doc_491521502200_item	2628685	et	4	main
seal	doc_491521502200_item	2628686	et	4	main
kuulis	doc_491521502200_item	2628687	et	4	main
keelne	doc_491521502200_item	2628691	et	3	main
pidi	doc_491521502200_item	2628695	et	4	main
saama	doc_491521502200_item	2628696	et	4	main
kokku	doc_491521502200_item	2628721	et	3	main
andis	doc_491521502200_item	2628734	et	3	main
välja	doc_491521502200_item	2628735	et	4	main
ka	doc_491521502200_item	2628736	et	3	main
võimalikult	doc_491521502200_item	2628749	et	4	main
ka	doc_491521502200_item	2628756	et	3	main
kellest	doc_491521502200_item	2628758	et	4	main
sai	doc_491521502200_item	2628759	et	4	main
kelle	doc_491521502200_item	2628763	et	4	main
nimi	doc_491521502200_item	2628764	et	3	main
õesi	doc_491521502200_item	2628773	et	4	main
võib	doc_491521502200_item	2628775	et	3	main
pidada	doc_491521502200_item	2628776	et	4	main
alguseks	doc_491521502200_item	2628778	et	4	main
süstis	doc_491521502200_item	2628780	et	4	main
hakati	doc_491521502200_item	2628791	et	3	main
uskuma	doc_491521502200_item	2628792	et	3	main
maailmas	doc_491521502200_item	2628801	et	3	main
näidata	doc_491521502200_item	2628802	et	4	main
katariina	doc_491521502199_item	2628499	et	4	main
1	doc_491521502200_item	2628509	et	2	main
2	doc_491521502200_item	2628514	et	2	main
ja	doc_491521502200_item	2628520	et	3	main
kes	doc_491521502200_item	2628521	et	4	main
1	doc_491521502200_item	2628524	et	2	main
2	doc_491521502200_item	2628530	et	2	main
võimu	doc_491521502200_item	2628532	et	4	main
vene	doc_491521502200_item	2628534	et	4	main
tsaari	doc_491521502200_item	2628535	et	4	main
ja	doc_491521502200_item	2628536	et	3	main
kohaliku	doc_491521502200_item	2628537	et	3	main
pärisori	doc_491521502200_item	2628542	et	4	main
tugevnes	doc_491521502200_item	2628547	et	3	main
talupoegade	doc_491521502200_item	2628548	et	3	main
püüti	doc_491521502200_item	2628550	et	3	main
muuta	doc_491521502200_item	2628552	et	4	main
muudeti	doc_491521502200_item	2628556	et	3	main
olid	doc_491521502200_item	2628562	et	4	main
mõisnikul	doc_491521502200_item	2628574	et	3	main
õigus	doc_491521502200_item	2628577	et	4	main
õesi	doc_491521502200_item	2628621	et	4	main
tolleaegsed	doc_491521502200_item	2628623	et	3	main
hakati	doc_491521502200_item	2628630	et	3	main
arutama	doc_491521502200_item	2628631	et	3	main
eepose	doc_491521502200_item	2628632	et	3	main
eesti	doc_491521502200_item	2628636	et	4	main
eepose	doc_491521502200_item	2628650	et	3	main
saanud	doc_491521502200_item	2628654	et	4	main
kokku	doc_491521502200_item	2628656	et	3	main
ta	doc_491521502200_item	2628659	et	4	main
nii	doc_491521502200_item	2628661	et	3	main
surnud	doc_491521502200_item	2628663	et	4	main
õesi	doc_491521502200_item	2628664	et	4	main
tähtsamateks	doc_491521502200_item	2628665	et	4	main
ja	doc_491521502200_item	2628675	et	3	main
kirja	doc_491521502200_item	2628677	et	4	main
keskastme	doc_491521502200_item	2628692	et	3	main
i	doc_491521502200_item	2628698	et	4	main
auks	doc_491521502200_item	2628699	et	3	main
nime	doc_491521502200_item	2628700	et	4	main
aleksandrikool	doc_491521502200_item	2628701	et	4	main
idee	doc_491521502200_item	2628704	et	4	main
väga	doc_491521502200_item	2628706	et	3	main
ning	doc_491521502200_item	2628708	et	3	main
ta	doc_491521502200_item	2628709	et	4	main
asus	doc_491521502200_item	2628710	et	4	main
keele	doc_491521502200_item	2628725	et	4	main
eestlastele	doc_491521502200_item	2628748	et	4	main
haridust	doc_491521502200_item	2628751	et	4	main
õesi	doc_491521502200_item	2628753	et	4	main
kuulus	doc_491521502200_item	2628754	et	4	main
ning	doc_491521502200_item	2628762	et	3	main
nüüd	doc_491521502200_item	2628766	et	4	main
kalevipoja	doc_491521502200_item	2628768	et	4	main
ões	doc_491521502200_item	2628779	et	4	main
talupoegadesse	doc_491521502200_item	2628782	et	3	main
kõigisse	doc_491521502200_item	2628784	et	4	main
suuresti	doc_491521502200_item	2628787	et	4	main
tänu	doc_491521502200_item	2628788	et	4	main
seltsile	doc_491521502200_item	2628790	et	3	main
taas	doc_491521502200_item	2628793	et	3	main
sellesse	doc_491521502200_item	2628794	et	4	main
et	doc_491521502200_item	2628795	et	3	main
eestlastel	doc_491521502200_item	2628796	et	4	main
end	doc_491521502200_item	2628799	et	4	main
rahvusena	doc_491521502200_item	2628800	et	3	main
et	doc_491521502200_item	2628821	et	3	main
talupoeg	doc_491521502200_item	2628525	et	3	main
baltisaksa	doc_491521502200_item	2628538	et	4	main
erikorra	doc_491521502200_item	2628544	et	3	main
või	doc_491521502200_item	2628564	et	4	main
hiljem	doc_491521502200_item	2628566	et	3	main
et	doc_491521502200_item	2628568	et	3	main
säilis	doc_491521502200_item	2628575	et	4	main
ihunuhtlust	doc_491521502200_item	2628582	et	3	main
põgenesid	doc_491521502200_item	2628585	et	4	main
venemaale	doc_491521502200_item	2628587	et	4	main
kui	doc_491521502200_item	2628588	et	3	main
nad	doc_491521502200_item	2628589	et	3	main
aga	doc_491521502200_item	2628590	et	3	main
üles	doc_491521502200_item	2628591	et	3	main
leiti	doc_491521502200_item	2628592	et	3	main
põletati	doc_491521502200_item	2628593	et	3	main
neile	doc_491521502200_item	2628594	et	4	main
nähtavale	doc_491521502200_item	2628595	et	4	main
kohalehäbimärk	doc_491521502200_item	2628596	et	3	main
balti	doc_491521502200_item	2628597	et	3	main
erikord	doc_491521502200_item	2628598	et	3	main
päästis	doc_491521502200_item	2628599	et	3	main
eesti	doc_491521502200_item	2628600	et	4	main
keele	doc_491521502200_item	2628601	et	4	main
baltisakslased	doc_491521502200_item	2628602	et	3	main
ei	doc_491521502200_item	2628603	et	4	main
tahtnud	doc_491521502200_item	2628604	et	4	main
et	doc_491521502200_item	2628605	et	3	main
siinsed	doc_491521502200_item	2628606	et	3	main
inimesed	doc_491521502200_item	2628607	et	3	main
õpiks	doc_491521502200_item	2628608	et	4	main
ära	doc_491521502200_item	2628609	et	4	main
saksa	doc_491521502200_item	2628610	et	4	main
keele	doc_491521502200_item	2628611	et	4	main
seepärast	doc_491521502200_item	2628612	et	3	main
propageerisid	doc_491521502200_item	2628613	et	4	main
eesti	doc_491521502200_item	2628614	et	4	main
keelt	doc_491521502200_item	2628615	et	4	main
ja	doc_491521502200_item	2628616	et	3	main
õppisid	doc_491521502200_item	2628617	et	4	main
seda	doc_491521502200_item	2628619	et	3	main
2	doc_491521502200_item	2628620	et	2	main
isegi	doc_491521502200_item	2628618	et	4	main
haritlased	doc_491521502200_item	2628625	et	3	main
nt	doc_491521502200_item	2628626	et	4	main
tõlkis	doc_491521502200_item	2628635	et	3	main
keelseid	doc_491521502200_item	2628637	et	3	main
saksa	doc_491521502200_item	2628639	et	4	main
korraldas	doc_491521502200_item	2628641	et	3	main
eesti	doc_491521502200_item	2628624	et	4	main
faehlmann	doc_491521502200_item	2628627	et	4	main
ta	doc_491521502200_item	2628634	et	4	main
õhtuid	doc_491521502200_item	2628644	et	3	main
mis	doc_491521502200_item	2628647	et	4	main
sobima	doc_491521502200_item	2628649	et	3	main
kalevipoja	doc_491521502200_item	2628655	et	4	main
panija	doc_491521502200_item	2628657	et	4	main
noorena	doc_491521502200_item	2628662	et	3	main
eesti	doc_491521502200_item	2628668	et	4	main
kirjandusega	doc_491521502200_item	2628671	et	3	main
tegeleda	doc_491521502200_item	2628672	et	3	main
panna	doc_491521502200_item	2628676	et	4	main
ka	doc_491521502200_item	2628678	et	3	main
ajalugu	doc_491521502200_item	2628679	et	4	main
õesi	doc_491521502200_item	2628680	et	4	main
eesti	doc_491521502200_item	2628690	et	4	main
see	doc_491521502200_item	2628703	et	3	main
etteotsa	doc_491521502200_item	2628713	et	3	main
ões	doc_491521502200_item	2628714	et	4	main
loodi	doc_491521502200_item	2628715	et	4	main
1838	doc_491521502200_item	2628716	et	2	main
tartus	doc_491521502200_item	2628717	et	3	main
kus	doc_491521502200_item	2628718	et	3	main
haritlased	doc_491521502200_item	2628720	et	3	main
said	doc_491521502200_item	2628719	et	4	main
et	doc_491521502200_item	2628722	et	3	main
ões	doc_491521502200_item	2628733	et	4	main
anda	doc_491521502200_item	2628747	et	3	main
muidugi	doc_491521502200_item	2628755	et	4	main
kreutzwald	doc_491521502200_item	2628757	et	4	main
kaunistab	doc_491521502200_item	2628765	et	3	main
ärkamisaja	doc_491521502200_item	2628777	et	3	main
sellele	doc_491521502200_item	2628789	et	4	main
rahvas	doc_491521502200_item	2628803	et	4	main
hakkas	doc_491521502200_item	2628804	et	3	main
rahvus	doc_491521502200_item	2628822	et	3	main
arutati	doc_491521502200_item	2628646	et	4	main
oleks	doc_491521502200_item	2628653	et	3	main
ülesanneteks	doc_491521502200_item	2628666	et	3	main
keele	doc_491521502200_item	2628669	et	4	main
koguda	doc_491521502200_item	2628673	et	3	main
ideest	doc_491521502200_item	2628688	et	4	main
aleksander	doc_491521502200_item	2628697	et	4	main
talle	doc_491521502200_item	2628702	et	4	main
selle	doc_491521502200_item	2628711	et	4	main
arutada	doc_491521502200_item	2628723	et	3	main
ja	doc_491521502200_item	2628726	et	3	main
olevikku	doc_491521502200_item	2628728	et	4	main
eelkõige	doc_491521502200_item	2628731	et	3	main
tulevikku	doc_491521502200_item	2628732	et	4	main
mitmeid	doc_491521502200_item	2628737	et	4	main
raamatuid	doc_491521502200_item	2628738	et	3	main
kalendreid	doc_491521502200_item	2628739	et	3	main
haritlaste	doc_491521502200_item	2628741	et	3	main
eesmärgiks	doc_491521502200_item	2628742	et	3	main
oli	doc_491521502200_item	2628743	et	3	main
harida	doc_491521502200_item	2628744	et	3	main
ning	doc_491521502200_item	2628746	et	3	main
emakeeles	doc_491521502200_item	2628752	et	4	main
mantlipärija	doc_491521502200_item	2628761	et	4	main
koostaja	doc_491521502200_item	2628772	et	4	main
eluisu	doc_491521502200_item	2628781	et	4	main
tähendab	doc_491521502202_item	2629063	et	3	main
2	doc_491521502202_item	2629066	et	2	main
kes	doc_491521502202_item	2629073	et	4	main
kuulusid	doc_491521502202_item	2629075	et	4	main
90	doc_491521502202_item	2629089	et	2	main
tol	doc_491521502202_item	2629090	et	3	main
hiljem	doc_491521502202_item	2629132	et	3	main
a	doc_491521502202_item	2629164	et	4	main
hakati	doc_491521502202_item	2629165	et	3	main
vabastada	doc_491521502202_item	2629172	et	3	main
dogmaatikast	doc_491521502202_item	2629175	et	4	main
prantsusmaa	doc_491521502202_item	2629180	et	4	main
100-aastase	doc_491521502202_item	2629194	et	4	main
erikord	doc_491521502202_item	2629197	et	3	main
baltisaksa	doc_491521502202_item	2629210	et	4	main
õppis	doc_491521502202_item	2629212	et	3	main
keelt	doc_491521502202_item	2629225	et	4	main
talupoegade	doc_491521502202_item	2629226	et	3	main
ka	doc_491521502202_item	2629229	et	3	main
vormi	doc_491521502202_item	2629231	et	4	main
eesti	doc_491521502200_item	2628724	et	4	main
kultuuri	doc_491521502200_item	2628727	et	4	main
minevikku	doc_491521502200_item	2628729	et	4	main
ja	doc_491521502200_item	2628730	et	3	main
sealsete	doc_491521502200_item	2628740	et	4	main
eestlasi	doc_491521502200_item	2628745	et	3	main
palju	doc_491521502200_item	2628750	et	4	main
faehlmanni	doc_491521502200_item	2628760	et	4	main
kõigi	doc_491521502200_item	2628767	et	4	main
trükiste	doc_491521502200_item	2628769	et	3	main
esikaant	doc_491521502200_item	2628770	et	3	main
kui	doc_491521502200_item	2628771	et	3	main
tegevust	doc_491521502200_item	2628774	et	4	main
laiemalt	doc_491521502200_item	2628783	et	4	main
eestlastesse	doc_491521502200_item	2628785	et	4	main
ning	doc_491521502200_item	2628786	et	3	main
on	doc_491521502200_item	2628797	et	4	main
võimalik	doc_491521502200_item	2628798	et	3	main
ärkama	doc_491521502200_item	2628805	et	3	main
mitmeid	doc_491521502200_item	2628806	et	4	main
sajandeid	doc_491521502200_item	2628807	et	3	main
kestnud	doc_491521502200_item	2628808	et	4	main
piinast	doc_491521502200_item	2628809	et	4	main
suurimaks	doc_491521502200_item	2628810	et	4	main
teeneks	doc_491521502200_item	2628811	et	4	main
peetakse	doc_491521502200_item	2628812	et	3	main
eesti	doc_491521502200_item	2628814	et	4	main
muidugi	doc_491521502200_item	2628813	et	4	main
eepose	doc_491521502200_item	2628815	et	3	main
koostamist	doc_491521502200_item	2628816	et	4	main
näitab	doc_491521502200_item	2628817	et	3	main
ju	doc_491521502200_item	2628818	et	3	main
eepose	doc_491521502200_item	2628819	et	3	main
olemasolu	doc_491521502200_item	2628820	et	4	main
eksisteerib	doc_491521502200_item	2628823	et	3	main
tegeles	doc_491521502202_item	2629068	et	3	main
selts	doc_491521502202_item	2629071	et	3	main
sinna	doc_491521502202_item	2629074	et	3	main
1	doc_491521502202_item	2629076	et	2	main
talupojad	doc_491521502202_item	2629077	et	4	main
satuvad	doc_491521502202_item	2629078	et	3	main
elavatest	doc_491521502202_item	2629092	et	4	main
inimestest	doc_491521502202_item	2629093	et	3	main
oli	doc_491521502202_item	2629094	et	3	main
neid	doc_491521502202_item	2629121	et	4	main
ka	doc_491521502202_item	2629130	et	3	main
aegsed	doc_491521502202_item	2629136	et	3	main
jäävad	doc_491521502202_item	2629138	et	4	main
säilis	doc_491521502202_item	2629140	et	4	main
kodukari	doc_491521502202_item	2629141	et	4	main
õigus	doc_491521502202_item	2629142	et	4	main
mõisnik	doc_491521502202_item	2629143	et	3	main
talupojad	doc_491521502202_item	2629151	et	4	main
üles	doc_491521502202_item	2629156	et	3	main
põletati	doc_491521502202_item	2629158	et	3	main
nähtavale	doc_491521502202_item	2629160	et	4	main
kohale	doc_491521502202_item	2629161	et	4	main
häbimärk	doc_491521502202_item	2629162	et	3	main
1571	doc_491521502202_item	2629163	et	2	main
oli	doc_491521502202_item	2629171	et	3	main
valgustusaeg	doc_491521502202_item	2629178	et	3	main
kontrolltöö	doc_491521502202_item	2629060	et	4	main
1	doc_491521502202_item	2629061	et	2	main
õpetatud	doc_491521502202_item	2629069	et	4	main
ja	doc_491521502202_item	2629072	et	3	main
umbes	doc_491521502202_item	2629088	et	4	main
ajal	doc_491521502202_item	2629091	et	4	main
olid	doc_491521502202_item	2629125	et	4	main
vabad	doc_491521502202_item	2629126	et	3	main
rootsi	doc_491521502202_item	2629135	et	4	main
talupoegadele	doc_491521502202_item	2629145	et	3	main
ihunuhtlust	doc_491521502202_item	2629146	et	3	main
üpris	doc_491521502202_item	2629148	et	3	main
põgenesid	doc_491521502202_item	2629150	et	4	main
põgenenud	doc_491521502202_item	2629154	et	4	main
entsüklopeediat	doc_491521502202_item	2629168	et	3	main
mõte	doc_491521502202_item	2629170	et	3	main
oli	doc_491521502202_item	2629176	et	3	main
inglismaa	doc_491521502202_item	2629179	et	4	main
arvati	doc_491521502202_item	2629181	et	4	main
et	doc_491521502202_item	2629182	et	3	main
inimese	doc_491521502202_item	2629183	et	4	main
umbes	doc_491521502202_item	2629193	et	4	main
olid	doc_491521502202_item	2629207	et	4	main
eesti	doc_491521502202_item	2629070	et	4	main
baltisaksa	doc_491521502202_item	2629086	et	4	main
aadlikud	doc_491521502202_item	2629087	et	3	main
maal	doc_491521502202_item	2629096	et	4	main
10	doc_491521502202_item	2629097	et	2	main
maa-aadlikud	doc_491521502202_item	2629098	et	3	main
talupoegi	doc_491521502202_item	2629122	et	4	main
kes	doc_491521502202_item	2629123	et	4	main
varem	doc_491521502202_item	2629124	et	4	main
muudeti	doc_491521502202_item	2629129	et	3	main
et	doc_491521502202_item	2629134	et	3	main
seadused	doc_491521502202_item	2629137	et	3	main
püsima	doc_491521502202_item	2629139	et	3	main
jagada	doc_491521502202_item	2629147	et	3	main
tihti	doc_491521502202_item	2629149	et	3	main
kui	doc_491521502202_item	2629153	et	3	main
talupoeg	doc_491521502202_item	2629155	et	3	main
leiti	doc_491521502202_item	2629157	et	3	main
välja	doc_491521502202_item	2629166	et	4	main
andma	doc_491521502202_item	2629167	et	3	main
inimesed	doc_491521502202_item	2629173	et	3	main
alanud	doc_491521502202_item	2629177	et	4	main
suudab	doc_491521502202_item	2629185	et	3	main
siia	doc_491521502202_item	2629192	et	4	main
keele	doc_491521502202_item	2629200	et	4	main
peeter	doc_491521502202_item	2629201	et	3	main
rootsi	doc_491521502202_item	2629208	et	4	main
ajast	doc_491521502202_item	2629209	et	4	main
ära	doc_491521502202_item	2629213	et	4	main
õpiks	doc_491521502202_item	2629222	et	4	main
omandas	doc_491521502202_item	2629228	et	3	main
usulise	doc_491521502202_item	2629230	et	4	main
1730-1740	doc_491521502202_item	2629232	et	2	main
levisid	doc_491521502202_item	2629233	et	4	main
nad	doc_491521502202_item	2629239	et	3	main
mõisnikud	doc_491521502202_item	2629255	et	3	main
pidi	doc_491521502202_item	2629272	et	4	main
mõtetest	doc_491521502202_item	2629279	et	3	main
pidi	doc_491521502202_item	2629281	et	4	main
mida	doc_491521502202_item	2629062	et	4	main
balti	doc_491521502202_item	2629064	et	3	main
erikord	doc_491521502202_item	2629065	et	3	main
millega	doc_491521502202_item	2629067	et	3	main
2	doc_491521502202_item	2629079	et	2	main
isanda	doc_491521502202_item	2629080	et	3	main
alla	doc_491521502202_item	2629081	et	3	main
vene	doc_491521502202_item	2629082	et	4	main
tsaar	doc_491521502202_item	2629083	et	3	main
ja	doc_491521502202_item	2629084	et	3	main
kohalikud	doc_491521502202_item	2629085	et	3	main
talurahvas	doc_491521502202_item	2629095	et	4	main
talupoeg	doc_491521502202_item	2629099	et	3	main
oli	doc_491521502202_item	2629100	et	3	main
veel	doc_491521502202_item	2629101	et	4	main
pärisori	doc_491521502202_item	2629102	et	4	main
kuigi	doc_491521502202_item	2629103	et	3	main
euroopas	doc_491521502202_item	2629104	et	3	main
oli	doc_491521502202_item	2629105	et	3	main
pärisorjus	doc_491521502202_item	2629106	et	3	main
ammu	doc_491521502202_item	2629107	et	4	main
kaotatud	doc_491521502202_item	2629108	et	4	main
balti	doc_491521502202_item	2629109	et	3	main
erikorra	doc_491521502202_item	2629110	et	3	main
raames	doc_491521502202_item	2629111	et	4	main
pärisorjus	doc_491521502202_item	2629112	et	3	main
isegi	doc_491521502202_item	2629113	et	4	main
tugevnes	doc_491521502202_item	2629114	et	3	main
talupoegade	doc_491521502202_item	2629115	et	3	main
vara	doc_491521502202_item	2629116	et	4	main
püüti	doc_491521502202_item	2629117	et	3	main
muuta	doc_491521502202_item	2629118	et	4	main
mõisnike	doc_491521502202_item	2629119	et	3	main
omandiks	doc_491521502202_item	2629120	et	3	main
või	doc_491521502202_item	2629127	et	4	main
poolvabad	doc_491521502202_item	2629128	et	3	main
pärisorjadeks	doc_491521502202_item	2629131	et	3	main
otsustati	doc_491521502202_item	2629133	et	3	main
võis	doc_491521502202_item	2629144	et	4	main
venemaale	doc_491521502202_item	2629152	et	4	main
talle	doc_491521502202_item	2629159	et	4	main
selle	doc_491521502202_item	2629169	et	4	main
kristlikust	doc_491521502202_item	2629174	et	4	main
ideed	doc_491521502202_item	2629190	et	4	main
hilinemisega	doc_491521502202_item	2629195	et	4	main
balti	doc_491521502202_item	2629196	et	3	main
päästis	doc_491521502202_item	2629198	et	3	main
mõisnik	doc_491521502202_item	2629211	et	3	main
maakeele	doc_491521502202_item	2629214	et	4	main
ja	doc_491521502202_item	2629215	et	3	main
tegi	doc_491521502202_item	2629216	et	4	main
kõik	doc_491521502202_item	2629217	et	4	main
et	doc_491521502202_item	2629218	et	3	main
siinsed	doc_491521502202_item	2629219	et	3	main
inimesed	doc_491521502202_item	2629220	et	3	main
ei	doc_491521502202_item	2629221	et	4	main
ära	doc_491521502202_item	2629223	et	4	main
saksa	doc_491521502202_item	2629224	et	4	main
eestisse	doc_491521502202_item	2629234	et	4	main
hernhuutlikud	doc_491521502202_item	2629235	et	3	main
oma	doc_491521502202_item	2629257	et	4	main
jagama	doc_491521502202_item	2629259	et	3	main
et	doc_491521502202_item	2629260	et	3	main
paradiisi	doc_491521502202_item	2629262	et	4	main
said	doc_491521502202_item	2629265	et	4	main
jumalasõnaraamatuid	doc_491521502202_item	2629267	et	3	main
et	doc_491521502202_item	2629268	et	3	main
vennastekoguduse	doc_491521502202_item	2629269	et	3	main
liikmeks	doc_491521502202_item	2629270	et	3	main
saada	doc_491521502202_item	2629271	et	4	main
kirjutada	doc_491521502202_item	2629275	et	3	main
oma	doc_491521502202_item	2629278	et	4	main
tunnetest	doc_491521502202_item	2629280	et	3	main
faehlmann	doc_491521502202_item	2629322	et	4	main
kalevipoja	doc_491521502202_item	2629331	et	4	main
õhtuid	doc_491521502202_item	2629332	et	3	main
kuulus	doc_491521502202_item	2629344	et	4	main
kes	doc_491521502203_item	2629361	et	4	main
sattub	doc_491521502203_item	2629366	et	3	main
vene	doc_491521502203_item	2629370	et	4	main
kolalikud	doc_491521502203_item	2629372	et	4	main
aadlikud	doc_491521502203_item	2629374	et	3	main
elavatest	doc_491521502203_item	2629378	et	4	main
inimestest	doc_491521502203_item	2629379	et	3	main
oli	doc_491521502203_item	2629380	et	3	main
talurahvas	doc_491521502203_item	2629381	et	4	main
oli	doc_491521502203_item	2629392	et	3	main
erikorra	doc_491521502203_item	2629396	et	3	main
pärisorjus	doc_491521502203_item	2629398	et	3	main
talupoegade	doc_491521502203_item	2629401	et	3	main
muudeti	doc_491521502203_item	2629415	et	3	main
rootsi	doc_491521502203_item	2629421	et	4	main
üpris	doc_491521502203_item	2629434	et	3	main
põgenesid	doc_491521502203_item	2629436	et	4	main
põgenenud	doc_491521502203_item	2629440	et	4	main
põletati	doc_491521502203_item	2629443	et	3	main
talle	doc_491521502203_item	2629444	et	4	main
nähtavale	doc_491521502203_item	2629445	et	4	main
1751a	doc_491521502203_item	2629448	et	4	main
valgustus	doc_491521502203_item	2629464	et	4	main
aeg	doc_491521502203_item	2629465	et	3	main
lahendada	doc_491521502203_item	2629471	et	3	main
probleemid	doc_491521502203_item	2629473	et	3	main
ära	doc_491521502203_item	2629484	et	4	main
ja	doc_491521502203_item	2629536	et	3	main
ka	doc_491521502203_item	2629545	et	3	main
raamatuid	doc_491521502203_item	2629547	et	3	main
kalendreid	doc_491521502203_item	2629548	et	3	main
mõistus	doc_491521502202_item	2629184	et	4	main
lahendada	doc_491521502202_item	2629186	et	3	main
kõik	doc_491521502202_item	2629187	et	4	main
probleemid	doc_491521502202_item	2629188	et	3	main
need	doc_491521502202_item	2629189	et	3	main
jõudsid	doc_491521502202_item	2629191	et	4	main
eesti	doc_491521502202_item	2629199	et	4	main
i	doc_491521502202_item	2629202	et	4	main
säilitas	doc_491521502202_item	2629203	et	3	main
talupoegade	doc_491521502202_item	2629204	et	3	main
privileegid	doc_491521502202_item	2629205	et	3	main
mis	doc_491521502202_item	2629206	et	4	main
protest	doc_491521502202_item	2629227	et	3	main
e	doc_491521502202_item	2629236	et	4	main
kõik	doc_491521502202_item	2629245	et	4	main
võrdsed	doc_491521502202_item	2629246	et	3	main
paradiisi	doc_491521502202_item	2629254	et	4	main
vara	doc_491521502202_item	2629258	et	4	main
pääseda	doc_491521502202_item	2629261	et	3	main
talupojad	doc_491521502202_item	2629266	et	4	main
muusikat	doc_491521502202_item	2629276	et	3	main
kirjutada	doc_491521502202_item	2629277	et	3	main
omama	doc_491521502202_item	2629282	et	4	main
tänapäeva	doc_491521502202_item	2629283	et	4	main
õhutasid	doc_491521502202_item	2629290	et	4	main
talupoegi	doc_491521502202_item	2629291	et	4	main
mässama	doc_491521502202_item	2629292	et	3	main
mõisnikke	doc_491521502202_item	2629293	et	3	main
röövima	doc_491521502202_item	2629294	et	4	main
nuhtlema	doc_491521502202_item	2629295	et	3	main
1õpetatud	doc_491521502202_item	2629296	et	4	main
eesti	doc_491521502202_item	2629297	et	4	main
selts	doc_491521502202_item	2629298	et	3	main
alustas	doc_491521502202_item	2629299	et	3	main
oma	doc_491521502202_item	2629300	et	4	main
1838	doc_491521502202_item	2629302	et	2	main
aastal	doc_491521502202_item	2629303	et	3	main
tartu	doc_491521502202_item	2629304	et	4	main
tegevust	doc_491521502202_item	2629301	et	4	main
ülikooli	doc_491521502202_item	2629305	et	4	main
juures	doc_491521502202_item	2629306	et	4	main
koosolekud	doc_491521502202_item	2629307	et	3	main
toimusid	doc_491521502202_item	2629308	et	4	main
ja	doc_491521502202_item	2629309	et	3	main
toimuvad	doc_491521502202_item	2629310	et	4	main
nüüdki	doc_491521502202_item	2629311	et	4	main
iga	doc_491521502202_item	2629312	et	4	main
kuu	doc_491521502202_item	2629313	et	4	main
viimasel	doc_491521502202_item	2629314	et	3	main
kolmapäeval	doc_491521502202_item	2629315	et	3	main
faehlmanni	doc_491521502202_item	2629316	et	4	main
eestvedamisel	doc_491521502202_item	2629317	et	3	main
hakati	doc_491521502202_item	2629318	et	3	main
arutama	doc_491521502202_item	2629319	et	3	main
eepose	doc_491521502202_item	2629320	et	3	main
tõlkis	doc_491521502202_item	2629323	et	3	main
saksa	doc_491521502202_item	2629326	et	4	main
ning	doc_491521502202_item	2629328	et	3	main
korralda	doc_491521502202_item	2629329	et	4	main
poleks	doc_491521502202_item	2629335	et	3	main
ões-i	doc_491521502202_item	2629343	et	4	main
jakob	doc_491521502202_item	2629346	et	4	main
vennastekoguduslikud	doc_491521502202_item	2629237	et	4	main
uskusid	doc_491521502202_item	2629240	et	4	main
et	doc_491521502202_item	2629241	et	3	main
jumala	doc_491521502202_item	2629242	et	3	main
ees	doc_491521502202_item	2629243	et	4	main
on	doc_491521502202_item	2629244	et	4	main
hakkasid	doc_491521502202_item	2629256	et	4	main
kaudu	doc_491521502202_item	2629264	et	3	main
oskama	doc_491521502202_item	2629273	et	3	main
lausa	doc_491521502202_item	2629285	et	4	main
kõrgemat	doc_491521502202_item	2629286	et	4	main
haridust	doc_491521502202_item	2629287	et	4	main
paljud	doc_491521502202_item	2629288	et	3	main
jutlustajad	doc_491521502202_item	2629289	et	4	main
vajalikkusest	doc_491521502202_item	2629321	et	4	main
faehlmann	doc_491521502202_item	2629334	et	4	main
kalevipoja	doc_491521502202_item	2629341	et	4	main
hurt	doc_491521502202_item	2629347	et	3	main
1	doc_491521502203_item	2629349	et	2	main
mida	doc_491521502203_item	2629350	et	4	main
tähendab	doc_491521502203_item	2629351	et	3	main
talupoeg	doc_491521502203_item	2629365	et	3	main
alla	doc_491521502203_item	2629369	et	3	main
tsaar	doc_491521502203_item	2629371	et	3	main
tol	doc_491521502203_item	2629376	et	3	main
isegi	doc_491521502203_item	2629399	et	4	main
kes	doc_491521502203_item	2629409	et	4	main
poolvabad	doc_491521502203_item	2629414	et	3	main
pärisorjadeks	doc_491521502203_item	2629417	et	3	main
võis	doc_491521502203_item	2629430	et	4	main
talupoegadele	doc_491521502203_item	2629431	et	3	main
venemaale	doc_491521502203_item	2629438	et	4	main
entsüklopeediat	doc_491521502203_item	2629453	et	3	main
vabastada	doc_491521502203_item	2629458	et	3	main
mõistus	doc_491521502203_item	2629469	et	4	main
suudab	doc_491521502203_item	2629470	et	3	main
erikord	doc_491521502203_item	2629476	et	3	main
et	doc_491521502203_item	2629489	et	3	main
ustavaks	doc_491521502203_item	2629521	et	4	main
rahvusele	doc_491521502203_item	2629523	et	3	main
teha	doc_491521502203_item	2629528	et	3	main
õpetatud	doc_491521502203_item	2629540	et	4	main
selts	doc_491521502203_item	2629542	et	3	main
mitmeid	doc_491521502203_item	2629546	et	4	main
jne	doc_491521502203_item	2629549	et	4	main
eestlasi	doc_491521502203_item	2629555	et	3	main
võimalikult	doc_491521502203_item	2629559	et	4	main
1838a	doc_491521502203_item	2629564	et	4	main
hakkas	doc_491521502203_item	2629565	et	3	main
tegutsema	doc_491521502203_item	2629566	et	3	main
tartu	doc_491521502203_item	2629568	et	4	main
ülikooli	doc_491521502203_item	2629569	et	4	main
kolmapäeval	doc_491521502203_item	2629576	et	3	main
faehlmanni	doc_491521502203_item	2629581	et	4	main
eestvedamisel	doc_491521502203_item	2629582	et	3	main
vajalikkusest	doc_491521502203_item	2629586	et	4	main
oleks	doc_491521502203_item	2629601	et	3	main
vaated	doc_491521502202_item	2629238	et	3	main
inimese	doc_491521502202_item	2629247	et	4	main
surm	doc_491521502202_item	2629248	et	3	main
tähendas	doc_491521502202_item	2629249	et	3	main
maisetest	doc_491521502202_item	2629250	et	4	main
piinadest	doc_491521502202_item	2629251	et	3	main
vabanemist	doc_491521502202_item	2629252	et	4	main
pääsemist	doc_491521502202_item	2629253	et	4	main
hernhuutlaste	doc_491521502202_item	2629263	et	3	main
lugeda	doc_491521502202_item	2629274	et	3	main
mõistes	doc_491521502202_item	2629284	et	4	main
muistendid	doc_491521502202_item	2629325	et	3	main
nn	doc_491521502202_item	2629330	et	4	main
temast	doc_491521502202_item	2629339	et	3	main
saanud	doc_491521502202_item	2629340	et	4	main
veel	doc_491521502202_item	2629345	et	4	main
kuulusid	doc_491521502203_item	2629363	et	4	main
isanda	doc_491521502203_item	2629368	et	3	main
oli	doc_491521502203_item	2629386	et	3	main
sel	doc_491521502203_item	2629387	et	3	main
ajal	doc_491521502203_item	2629388	et	4	main
pärisori	doc_491521502203_item	2629389	et	4	main
euroopas	doc_491521502203_item	2629391	et	3	main
püüti	doc_491521502203_item	2629403	et	3	main
mõisnike	doc_491521502203_item	2629405	et	3	main
omandiks	doc_491521502203_item	2629406	et	3	main
neid	doc_491521502203_item	2629407	et	4	main
ka	doc_491521502203_item	2629416	et	3	main
hiljem	doc_491521502203_item	2629418	et	3	main
et	doc_491521502203_item	2629420	et	3	main
jäävad	doc_491521502203_item	2629424	et	4	main
ta	doc_491521502203_item	2629429	et	4	main
jagada	doc_491521502203_item	2629433	et	3	main
kui	doc_491521502203_item	2629439	et	3	main
ülesleiti	doc_491521502203_item	2629442	et	4	main
kohale	doc_491521502203_item	2629446	et	4	main
hakkati	doc_491521502203_item	2629449	et	3	main
välja	doc_491521502203_item	2629451	et	4	main
selle	doc_491521502203_item	2629454	et	4	main
mõte	doc_491521502203_item	2629455	et	3	main
oli	doc_491521502203_item	2629456	et	3	main
ka	doc_491521502203_item	2629457	et	3	main
inimese	doc_491521502203_item	2629468	et	4	main
balti	doc_491521502203_item	2629475	et	3	main
eesti	doc_491521502203_item	2629478	et	4	main
balti	doc_491521502203_item	2629480	et	3	main
maakeele	doc_491521502203_item	2629485	et	4	main
tegi	doc_491521502203_item	2629487	et	4	main
kõik	doc_491521502203_item	2629488	et	4	main
oma	doc_491521502203_item	2629522	et	4	main
tööd	doc_491521502203_item	2629527	et	4	main
rahva	doc_491521502203_item	2629533	et	3	main
vaimuvara	doc_491521502203_item	2629534	et	4	main
rahvaluule	doc_491521502203_item	2629535	et	4	main
tagasiandmist	doc_491521502203_item	2629538	et	3	main
välja	doc_491521502203_item	2629544	et	4	main
sealsete	doc_491521502203_item	2629550	et	4	main
haritlaste	doc_491521502203_item	2629551	et	3	main
eesmärgiks	doc_491521502203_item	2629552	et	3	main
oli	doc_491521502203_item	2629553	et	3	main
harida	doc_491521502203_item	2629554	et	3	main
eestlastele	doc_491521502203_item	2629558	et	4	main
palju	doc_491521502203_item	2629560	et	4	main
haridust	doc_491521502203_item	2629561	et	4	main
oma	doc_491521502203_item	2629562	et	4	main
kuu	doc_491521502203_item	2629574	et	4	main
ka	doc_491521502203_item	2629577	et	3	main
faehlmann	doc_491521502203_item	2629587	et	4	main
keelsed	doc_491521502203_item	2629590	et	3	main
muistendid	doc_491521502203_item	2629591	et	3	main
saksa	doc_491521502203_item	2629592	et	4	main
keelde	doc_491521502203_item	2629593	et	4	main
kalevipoja	doc_491521502203_item	2629598	et	4	main
kui	doc_491521502203_item	2629605	et	3	main
eestikeelsed	doc_491521502202_item	2629324	et	3	main
keelde	doc_491521502202_item	2629327	et	4	main
kui	doc_491521502202_item	2629333	et	3	main
ära	doc_491521502202_item	2629336	et	4	main
surnud	doc_491521502202_item	2629337	et	4	main
oleks	doc_491521502202_item	2629338	et	3	main
kokkupanija	doc_491521502202_item	2629342	et	4	main
balti	doc_491521502203_item	2629352	et	3	main
erikord	doc_491521502203_item	2629353	et	3	main
2	doc_491521502203_item	2629354	et	2	main
millega	doc_491521502203_item	2629355	et	3	main
tegeles	doc_491521502203_item	2629356	et	3	main
õpetatud	doc_491521502203_item	2629357	et	4	main
kontrolltöö	doc_491521502203_item	2629348	et	4	main
1	doc_491521502203_item	2629364	et	2	main
2	doc_491521502203_item	2629367	et	2	main
90	doc_491521502203_item	2629375	et	2	main
pärisorjus	doc_491521502203_item	2629390	et	3	main
kaotatud	doc_491521502203_item	2629394	et	4	main
balti	doc_491521502203_item	2629395	et	3	main
raamees	doc_491521502203_item	2629397	et	3	main
vara	doc_491521502203_item	2629402	et	4	main
muuta	doc_491521502203_item	2629404	et	4	main
talupoegi	doc_491521502203_item	2629408	et	4	main
või	doc_491521502203_item	2629413	et	4	main
eesti	doc_491521502203_item	2629358	et	4	main
selts	doc_491521502203_item	2629359	et	3	main
ja	doc_491521502203_item	2629360	et	3	main
sinna	doc_491521502203_item	2629362	et	3	main
baltisaksa	doc_491521502203_item	2629373	et	4	main
ajal	doc_491521502203_item	2629377	et	4	main
maal	doc_491521502203_item	2629382	et	4	main
10	doc_491521502203_item	2629383	et	2	main
maa-aadlikud	doc_491521502203_item	2629384	et	3	main
talupoeg	doc_491521502203_item	2629385	et	3	main
ammu	doc_491521502203_item	2629393	et	4	main
tugevnes	doc_491521502203_item	2629400	et	3	main
olid	doc_491521502203_item	2629410	et	4	main
varem	doc_491521502203_item	2629411	et	4	main
vabad	doc_491521502203_item	2629412	et	3	main
otsustatakse	doc_491521502203_item	2629419	et	3	main
seadused	doc_491521502203_item	2629423	et	3	main
püsima	doc_491521502203_item	2629425	et	3	main
säilis	doc_491521502203_item	2629426	et	4	main
kodukari	doc_491521502203_item	2629427	et	4	main
tihti	doc_491521502203_item	2629435	et	3	main
prantsusmaal	doc_491521502203_item	2629450	et	4	main
andma	doc_491521502203_item	2629452	et	3	main
kristlikust	doc_491521502203_item	2629460	et	4	main
dogmaatikast	doc_491521502203_item	2629461	et	4	main
oli	doc_491521502203_item	2629462	et	3	main
alanud	doc_491521502203_item	2629463	et	4	main
kõik	doc_491521502203_item	2629472	et	4	main
keele	doc_491521502203_item	2629479	et	4	main
jaoks	doc_491521502203_item	2629526	et	4	main
oluliseks	doc_491521502203_item	2629530	et	4	main
ta	doc_491521502203_item	2629532	et	4	main
rahvale	doc_491521502203_item	2629539	et	3	main
andis	doc_491521502203_item	2629543	et	3	main
anda	doc_491521502203_item	2629557	et	3	main
ões	doc_491521502203_item	2629567	et	4	main
iga	doc_491521502203_item	2629573	et	4	main
tänapäeval	doc_491521502203_item	2629578	et	3	main
eepose	doc_491521502203_item	2629585	et	3	main
tõlkis	doc_491521502203_item	2629588	et	3	main
eesti	doc_491521502203_item	2629589	et	4	main
õhtuid	doc_491521502203_item	2629599	et	3	main
kontrolltöö	doc_491521502205_item	2629746	et	4	main
1	doc_491521502205_item	2629747	et	2	main
põhjasõda	doc_491521502205_item	2629766	et	4	main
läks	doc_491521502205_item	2629768	et	3	main
balti	doc_491521502205_item	2629776	et	3	main
eesti	doc_491521502205_item	2629786	et	4	main
talupoeg	doc_491521502205_item	2629787	et	3	main
sattus	doc_491521502205_item	2629791	et	3	main
aegsed	doc_491521502203_item	2629422	et	3	main
õigusmõisnik	doc_491521502203_item	2629428	et	3	main
ihunuhtlust	doc_491521502203_item	2629432	et	3	main
talupojad	doc_491521502203_item	2629437	et	4	main
talupoeg	doc_491521502203_item	2629441	et	3	main
häbimärk	doc_491521502203_item	2629447	et	3	main
inimesed	doc_491521502203_item	2629459	et	3	main
arvati	doc_491521502203_item	2629466	et	4	main
et	doc_491521502203_item	2629467	et	3	main
ratsionalism	doc_491521502203_item	2629474	et	3	main
päästis	doc_491521502203_item	2629477	et	3	main
saksa	doc_491521502203_item	2629481	et	4	main
mõisnik	doc_491521502203_item	2629482	et	3	main
õppis	doc_491521502203_item	2629483	et	3	main
ja	doc_491521502203_item	2629486	et	3	main
siinsed	doc_491521502203_item	2629490	et	3	main
inimesed	doc_491521502203_item	2629491	et	3	main
ei	doc_491521502203_item	2629492	et	4	main
õpiks	doc_491521502203_item	2629493	et	4	main
ära	doc_491521502203_item	2629494	et	4	main
saksa	doc_491521502203_item	2629495	et	4	main
keelt	doc_491521502203_item	2629496	et	4	main
2	doc_491521502203_item	2629497	et	2	main
eesti	doc_491521502203_item	2629499	et	4	main
õpetatud	doc_491521502203_item	2629498	et	4	main
seltsi	doc_491521502203_item	2629500	et	4	main
kuulusid	doc_491521502203_item	2629501	et	4	main
tolla	doc_491521502203_item	2629502	et	4	main
aegsed	doc_491521502203_item	2629503	et	3	main
haritlased	doc_491521502203_item	2629504	et	3	main
nt	doc_491521502203_item	2629505	et	4	main
faehlmann	doc_491521502203_item	2629506	et	4	main
jakob	doc_491521502203_item	2629507	et	4	main
hurt	doc_491521502203_item	2629508	et	3	main
1839-1907	doc_491521502203_item	2629509	et	2	main
vaatamata	doc_491521502203_item	2629510	et	4	main
paljutõotavatele	doc_491521502203_item	2629511	et	3	main
võimalustele	doc_491521502203_item	2629512	et	3	main
sakslaseks	doc_491521502203_item	2629513	et	3	main
saades	doc_491521502203_item	2629514	et	3	main
kiiresti	doc_491521502203_item	2629515	et	3	main
karjääri	doc_491521502203_item	2629516	et	4	main
teha	doc_491521502203_item	2629517	et	3	main
oli	doc_491521502203_item	2629518	et	3	main
hurt	doc_491521502203_item	2629519	et	3	main
jäänud	doc_491521502203_item	2629520	et	4	main
soovides	doc_491521502203_item	2629524	et	4	main
tema	doc_491521502203_item	2629525	et	4	main
eriti	doc_491521502203_item	2629529	et	3	main
pidas	doc_491521502203_item	2629531	et	3	main
ajaloo	doc_491521502203_item	2629537	et	4	main
eesti	doc_491521502203_item	2629541	et	4	main
ning	doc_491521502203_item	2629556	et	3	main
emakeelest	doc_491521502203_item	2629563	et	4	main
juures	doc_491521502203_item	2629570	et	4	main
koosolekud	doc_491521502203_item	2629571	et	3	main
olid	doc_491521502203_item	2629572	et	4	main
see	doc_491521502203_item	2629580	et	3	main
ta	doc_491521502203_item	2629594	et	4	main
korraldas	doc_491521502203_item	2629595	et	3	main
nii	doc_491521502203_item	2629596	et	3	main
ta	doc_491521502203_item	2629606	et	4	main
poleks	doc_491521502203_item	2629607	et	3	main
ära	doc_491521502203_item	2629608	et	4	main
surnud	doc_491521502203_item	2629609	et	4	main
tegeles	doc_491521502205_item	2629754	et	3	main
eesti	doc_491521502205_item	2629756	et	4	main
langes	doc_491521502205_item	2629785	et	4	main
pärisorjusse	doc_491521502205_item	2629790	et	3	main
kõrgematele	doc_491521502205_item	2629827	et	4	main
kubjaste	doc_491521502205_item	2629832	et	3	main
vastu	doc_491521502205_item	2629833	et	3	main
ka	doc_491521502205_item	2629835	et	3	main
seni	doc_491521502205_item	2629836	et	3	main
viimasel	doc_491521502203_item	2629575	et	3	main
toimib	doc_491521502203_item	2629579	et	3	main
hatti	doc_491521502203_item	2629583	et	4	main
arutama	doc_491521502203_item	2629584	et	3	main
ööedud	doc_491521502203_item	2629597	et	3	main
faehlmann	doc_491521502203_item	2629600	et	4	main
saanud	doc_491521502203_item	2629602	et	4	main
eepose	doc_491521502203_item	2629603	et	3	main
kokkupanijaks	doc_491521502203_item	2629604	et	4	main
tähendab	doc_491521502205_item	2629749	et	3	main
balti	doc_491521502205_item	2629750	et	3	main
erikord	doc_491521502205_item	2629751	et	3	main
millega	doc_491521502205_item	2629753	et	3	main
õpetatud	doc_491521502205_item	2629755	et	4	main
selts	doc_491521502205_item	2629757	et	3	main
ja	doc_491521502205_item	2629758	et	3	main
kuulusid	doc_491521502205_item	2629761	et	4	main
erikord	doc_491521502205_item	2629764	et	3	main
1700-1721	doc_491521502205_item	2629767	et	2	main
mis	doc_491521502205_item	2629778	et	4	main
säilitas	doc_491521502205_item	2629779	et	3	main
privileegid	doc_491521502205_item	2629782	et	3	main
veel	doc_491521502205_item	2629788	et	4	main
anti	doc_491521502205_item	2629822	et	3	main
võimudele	doc_491521502205_item	2629828	et	3	main
allutada	doc_491521502205_item	2629843	et	3	main
sinna	doc_491521502205_item	2629857	et	3	main
eestlastest	doc_491521502205_item	2629863	et	4	main
kirjamehed	doc_491521502205_item	2629865	et	3	main
faehlmanni	doc_491521502205_item	2629866	et	4	main
asuti	doc_491521502205_item	2629868	et	3	main
koostama	doc_491521502205_item	2629869	et	3	main
kalevala	doc_491521502205_item	2629876	et	4	main
tähistatakse	doc_491521502205_item	2629894	et	3	main
ilus	doc_491521502205_item	2629903	et	4	main
ja	doc_491521502205_item	2629904	et	3	main
kõlav	doc_491521502205_item	2629905	et	4	main
keel	doc_491521502205_item	2629906	et	4	main
2	doc_491521502205_item	2629752	et	2	main
sinna	doc_491521502205_item	2629760	et	3	main
1	doc_491521502205_item	2629762	et	2	main
kätte	doc_491521502205_item	2629771	et	4	main
peeter	doc_491521502205_item	2629772	et	3	main
i	doc_491521502205_item	2629773	et	4	main
kuulutas	doc_491521502205_item	2629774	et	3	main
välja	doc_491521502205_item	2629775	et	4	main
mõisnike	doc_491521502205_item	2629781	et	3	main
sügavamale	doc_491521502205_item	2629789	et	4	main
ning	doc_491521502205_item	2629829	et	3	main
vabad	doc_491521502205_item	2629837	et	3	main
talupojad	doc_491521502205_item	2629840	et	4	main
tänapäeval	doc_491521502205_item	2629856	et	3	main
peterson	doc_491521502205_item	2629860	et	4	main
tohtrid	doc_491521502205_item	2629864	et	3	main
saadi	doc_491521502205_item	2629873	et	4	main
ilma	doc_491521502205_item	2629882	et	4	main
eesti	doc_491521502205_item	2629890	et	4	main
emakeelepäeva	doc_491521502205_item	2629895	et	4	main
näidata	doc_491521502205_item	2629897	et	4	main
et	doc_491521502205_item	2629898	et	3	main
ka	doc_491521502205_item	2629899	et	3	main
eesti	doc_491521502205_item	2629900	et	4	main
rahvaluulet	doc_491521502205_item	2629908	et	3	main
mida	doc_491521502205_item	2629748	et	4	main
kes	doc_491521502205_item	2629759	et	4	main
balti	doc_491521502205_item	2629763	et	3	main
peale	doc_491521502205_item	2629765	et	4	main
eesti	doc_491521502205_item	2629769	et	4	main
venemaa	doc_491521502205_item	2629770	et	4	main
erikorra	doc_491521502205_item	2629777	et	3	main
baltisaksa	doc_491521502205_item	2629780	et	4	main
selle	doc_491521502205_item	2629783	et	4	main
läbi	doc_491521502205_item	2629784	et	4	main
kahe	doc_491521502205_item	2629792	et	3	main
isanda	doc_491521502205_item	2629793	et	3	main
vene	doc_491521502205_item	2629794	et	4	main
keisririigi	doc_491521502205_item	2629795	et	3	main
ja	doc_491521502205_item	2629796	et	3	main
baltisaksa	doc_491521502205_item	2629797	et	4	main
mõisnike	doc_491521502205_item	2629798	et	3	main
võimu	doc_491521502205_item	2629799	et	4	main
alla	doc_491521502205_item	2629800	et	3	main
säilis	doc_491521502205_item	2629801	et	4	main
kodukariõigus	doc_491521502205_item	2629802	et	4	main
ihunuhtlus	doc_491521502205_item	2629803	et	3	main
talupoeg	doc_491521502205_item	2629804	et	3	main
ja	doc_491521502205_item	2629805	et	3	main
tema	doc_491521502205_item	2629806	et	4	main
vara	doc_491521502205_item	2629807	et	4	main
kuulus	doc_491521502205_item	2629808	et	4	main
mõisnikule	doc_491521502205_item	2629809	et	3	main
kui	doc_491521502205_item	2629810	et	3	main
talupoeg	doc_491521502205_item	2629811	et	3	main
põgenes	doc_491521502205_item	2629812	et	3	main
ja	doc_491521502205_item	2629813	et	3	main
ta	doc_491521502205_item	2629814	et	4	main
kätte	doc_491521502205_item	2629815	et	4	main
saadi	doc_491521502205_item	2629816	et	4	main
põletati	doc_491521502205_item	2629817	et	3	main
tema	doc_491521502205_item	2629818	et	4	main
kehale	doc_491521502205_item	2629819	et	3	main
häbimärk	doc_491521502205_item	2629820	et	3	main
välja	doc_491521502205_item	2629824	et	4	main
mõisniku	doc_491521502205_item	2629831	et	3	main
ajaks	doc_491521502205_item	2629847	et	4	main
kaotatud	doc_491521502205_item	2629850	et	4	main
kuulusid	doc_491521502205_item	2629858	et	4	main
faehlmann	doc_491521502205_item	2629859	et	4	main
kreutzwald	doc_491521502205_item	2629861	et	4	main
ja	doc_491521502205_item	2629821	et	3	main
mõisnikule	doc_491521502205_item	2629823	et	3	main
talupojad	doc_491521502205_item	2629825	et	4	main
kaebasid	doc_491521502205_item	2629826	et	4	main
kasutasid	doc_491521502205_item	2629830	et	4	main
vägivalda	doc_491521502205_item	2629834	et	4	main
euroopas	doc_491521502205_item	2629844	et	3	main
selleks	doc_491521502205_item	2629846	et	4	main
pärisorjus	doc_491521502205_item	2629848	et	3	main
juba	doc_491521502205_item	2629849	et	3	main
2	doc_491521502205_item	2629851	et	2	main
asutati	doc_491521502205_item	2629852	et	4	main
1838	doc_491521502205_item	2629853	et	2	main
tegutseb	doc_491521502205_item	2629854	et	3	main
ka	doc_491521502205_item	2629855	et	3	main
jt-	doc_491521502205_item	2629862	et	4	main
soome	doc_491521502205_item	2629874	et	3	main
et	doc_491521502205_item	2629878	et	3	main
ei	doc_491521502205_item	2629879	et	4	main
ole	doc_491521502205_item	2629880	et	4	main
peterson	doc_491521502205_item	2629885	et	4	main
tõlkis	doc_491521502205_item	2629886	et	3	main
mütoloogiaid	doc_491521502205_item	2629887	et	3	main
mütoloogiale	doc_491521502205_item	2629891	et	3	main
soovis	doc_491521502205_item	2629896	et	4	main
ja	doc_491521502205_item	2629909	et	3	main
pärimusi	doc_491521502205_item	2629910	et	4	main
propageerisid	doc_491521502205_item	2629911	et	4	main
haridust	doc_491521502205_item	2629912	et	4	main
emakeelset	doc_491521502205_item	2629913	et	3	main
või	doc_491521502205_item	2629838	et	4	main
poolvabad	doc_491521502205_item	2629839	et	3	main
püüti	doc_491521502205_item	2629841	et	3	main
mõisnikele	doc_491521502205_item	2629842	et	3	main
oli	doc_491521502205_item	2629845	et	3	main
eeskuju	doc_491521502205_item	2629872	et	4	main
rahvast	doc_491521502205_item	2629881	et	4	main
keel	doc_491521502205_item	2629901	et	4	main
on	doc_491521502205_item	2629902	et	4	main
kogusid	doc_491521502205_item	2629907	et	4	main
algatusel	doc_491521502205_item	2629867	et	4	main
eesti	doc_491521502205_item	2629870	et	4	main
eepost	doc_491521502205_item	2629871	et	3	main
eeposest	doc_491521502205_item	2629875	et	4	main
leidsid	doc_491521502205_item	2629877	et	4	main
oma	doc_491521502205_item	2629883	et	4	main
eeposeta	doc_491521502205_item	2629884	et	3	main
pani	doc_491521502205_item	2629888	et	4	main
aluse	doc_491521502205_item	2629889	et	4	main
tema	doc_491521502205_item	2629892	et	4	main
auks	doc_491521502205_item	2629893	et	3	main
kontrolltöö	doc_491521502209_item	2630577	et	4	main
üldiseloomustus	doc_491521502209_item	2630581	et	4	main
2	doc_491521502209_item	2630582	et	2	main
edasi	doc_491521502209_item	2630594	et	3	main
neile	doc_491521502209_item	2630607	et	4	main
liha	doc_491521502209_item	2630609	et	4	main
puhkudel	doc_491521502209_item	2630613	et	3	main
loomi	doc_491521502209_item	2630614	et	4	main
ohverdasid	doc_491521502209_item	2630622	et	4	main
selleks	doc_491521502209_item	2630624	et	4	main
nende	doc_491521502209_item	2630630	et	4	main
hiieks	doc_491521502209_item	2630635	et	4	main
mis	doc_491521502209_item	2630640	et	4	main
ja	doc_491521502209_item	2630642	et	3	main
naiste	doc_491521502209_item	2630643	et	3	main
puhul	doc_491521502209_item	2630644	et	4	main
erinevad	doc_491521502209_item	2630649	et	4	main
asjad	doc_491521502209_item	2630650	et	3	main
mida	doc_491521502209_item	2630651	et	4	main
ohverdati	doc_491521502209_item	2630652	et	3	main
olenevalt	doc_491521502209_item	2630653	et	4	main
tegu	doc_491521502209_item	2630656	et	4	main
nt	doc_491521502209_item	2630660	et	4	main
või	doc_491521502209_item	2630662	et	4	main
lõng	doc_491521502209_item	2630667	et	3	main
usuti	doc_491521502209_item	2630668	et	3	main
usuti	doc_491521502209_item	2630700	et	3	main
tark	doc_491521502209_item	2630704	et	3	main
maeti	doc_491521502209_item	2630714	et	3	main
erinesid	doc_491521502209_item	2630718	et	4	main
inimene	doc_491521502209_item	2630729	et	3	main
pidanud	doc_491521502209_item	2630735	et	4	main
kaasnema	doc_491521502209_item	2630736	et	3	main
olenemata	doc_491521502209_item	2630737	et	4	main
vajaminevat	doc_491521502209_item	2630748	et	3	main
mida	doc_491521502209_item	2630759	et	4	main
tahtsid	doc_491521502209_item	2630761	et	4	main
rohkem	doc_491521502209_item	2630770	et	4	main
sellega	doc_491521502209_item	2630783	et	3	main
mindi	doc_491521502209_item	2630790	et	3	main
ja	doc_491521502209_item	2630792	et	3	main
suremise	doc_491521502209_item	2630821	et	4	main
ei	doc_491521502209_item	2630823	et	4	main
et	doc_491521502209_item	2630830	et	3	main
eluta	doc_491521502209_item	2630832	et	3	main
elab	doc_491521502209_item	2630834	et	3	main
selle	doc_491521502209_item	2630841	et	4	main
küsisid	doc_491521502209_item	2630844	et	4	main
maha	doc_491521502209_item	2630851	et	4	main
raiuda	doc_491521502209_item	2630852	et	3	main
kujutama	doc_491521502209_item	2630865	et	3	main
tähenduse	doc_491521502209_item	2630870	et	4	main
eestlased	doc_491521502209_item	2630872	et	3	main
pidasid	doc_491521502209_item	2630873	et	4	main
allikavett	doc_491521502209_item	2630874	et	3	main
ravivaks	doc_491521502209_item	2630875	et	4	main
ja	doc_491521502209_item	2630878	et	3	main
1	doc_491521502209_item	2630578	et	2	main
eestlaste	doc_491521502209_item	2630579	et	4	main
muinasusundi	doc_491521502209_item	2630580	et	3	main
ja	doc_491521502209_item	2630595	et	3	main
kaitsesid	doc_491521502209_item	2630596	et	4	main
selleks	doc_491521502209_item	2630598	et	4	main
et	doc_491521502209_item	2630599	et	3	main
mitte	doc_491521502209_item	2630600	et	3	main
surnute	doc_491521502209_item	2630601	et	4	main
verd	doc_491521502209_item	2630608	et	3	main
hõbemünte	doc_491521502209_item	2630610	et	3	main
mis	doc_491521502209_item	2630583	et	4	main
surnud	doc_491521502209_item	2630592	et	4	main
ära	doc_491521502209_item	2630603	et	4	main
nad	doc_491521502209_item	2630606	et	3	main
tähtsamatel	doc_491521502209_item	2630612	et	4	main
ja	doc_491521502209_item	2630615	et	3	main
inimesi	doc_491521502209_item	2630617	et	4	main
nt	doc_491521502209_item	2630618	et	4	main
hõimud	doc_491521502209_item	2630627	et	4	main
ohverduspaika	doc_491521502209_item	2630633	et	4	main
kombed	doc_491521502209_item	2630639	et	3	main
meeste	doc_491521502209_item	2630641	et	4	main
olid	doc_491521502209_item	2630648	et	4	main
kas	doc_491521502209_item	2630655	et	3	main
oli	doc_491521502209_item	2630657	et	3	main
nt	doc_491521502209_item	2630664	et	4	main
kudumisvardad	doc_491521502209_item	2630665	et	4	main
looduse	doc_491521502209_item	2630671	et	4	main
teda	doc_491521502209_item	2630710	et	4	main
austati	doc_491521502209_item	2630711	et	3	main
või	doc_491521502209_item	2630715	et	4	main
uskusid	doc_491521502209_item	2630721	et	4	main
kui	doc_491521502209_item	2630723	et	3	main
matta	doc_491521502209_item	2630724	et	3	main
ei	doc_491521502209_item	2630726	et	4	main
saa	doc_491521502209_item	2630727	et	4	main
põletamisega	doc_491521502209_item	2630731	et	4	main
seda	doc_491521502209_item	2630733	et	3	main
põletati	doc_491521502209_item	2630742	et	3	main
inimesed	doc_491521502209_item	2630758	et	3	main
nad	doc_491521502209_item	2630760	et	3	main
kaasa	doc_491521502209_item	2630764	et	4	main
kaasa	doc_491521502209_item	2630768	et	4	main
peied	doc_491521502209_item	2630774	et	3	main
päeva	doc_491521502209_item	2630777	et	4	main
söödi	doc_491521502209_item	2630778	et	4	main
rikkalikult	doc_491521502209_item	2630779	et	4	main
tihti	doc_491521502209_item	2630780	et	3	main
matustele	doc_491521502209_item	2630788	et	3	main
võtnud	doc_491521502209_item	2630824	et	4	main
teadsid	doc_491521502209_item	2630829	et	4	main
võivad	doc_491521502209_item	2630849	et	4	main
risti	doc_491521502209_item	2630862	et	4	main
surma	doc_491521502209_item	2630869	et	4	main
mindi	doc_491521502209_item	2630876	et	3	main
või	doc_491521502209_item	2630884	et	4	main
sel	doc_491521502209_item	2630891	et	3	main
nägemist	doc_491521502209_item	2630906	et	4	main
paik	doc_491521502209_item	2630920	et	3	main
kirik	doc_491521502209_item	2630924	et	3	main
seda	doc_491521502209_item	2630928	et	3	main
metsaalast	doc_491521502209_item	2630942	et	4	main
ja	doc_491521502210_item	2630968	et	3	main
igasugused	doc_491521502210_item	2630970	et	3	main
ja	doc_491521502210_item	2630971	et	3	main
arengu	doc_491521502210_item	2630972	et	3	main
protsess	doc_491521502210_item	2630973	et	3	main
kuid	doc_491521502210_item	2630974	et	4	main
võib	doc_491521502210_item	2630975	et	3	main
ja	doc_491521502210_item	2630984	et	3	main
1	doc_491521502209_item	2630586	et	2	main
muistsed	doc_491521502209_item	2630587	et	3	main
eestlased	doc_491521502209_item	2630588	et	3	main
elasid	doc_491521502209_item	2630593	et	4	main
elavaid	doc_491521502209_item	2630597	et	4	main
teenida	doc_491521502209_item	2630604	et	3	main
jms	doc_491521502209_item	2630611	et	4	main
ostsid	doc_491521502209_item	2630619	et	4	main
orja	doc_491521502209_item	2630620	et	4	main
ja	doc_491521502209_item	2630621	et	3	main
omad	doc_491521502209_item	2630638	et	4	main
olid	doc_491521502209_item	2630645	et	4	main
mehe	doc_491521502209_item	2630659	et	3	main
relvad	doc_491521502209_item	2630661	et	3	main
naisega	doc_491521502209_item	2630663	et	3	main
loodusesse	doc_491521502209_item	2630669	et	4	main
ja	doc_491521502209_item	2630670	et	3	main
maagiasse	doc_491521502209_item	2630701	et	4	main
külades	doc_491521502209_item	2630702	et	3	main
kes	doc_491521502209_item	2630705	et	4	main
ennustas	doc_491521502209_item	2630706	et	3	main
ja	doc_491521502209_item	2630707	et	3	main
ravis	doc_491521502209_item	2630708	et	4	main
ning	doc_491521502209_item	2630709	et	3	main
põletati	doc_491521502209_item	2630716	et	3	main
surnud	doc_491521502209_item	2630728	et	4	main
aga	doc_491521502209_item	2630732	et	3	main
ei	doc_491521502209_item	2630734	et	4	main
anti	doc_491521502209_item	2630743	et	3	main
ütlesid	doc_491521502209_item	2630756	et	4	main
nendele	doc_491521502209_item	2630763	et	4	main
rikkamatele	doc_491521502209_item	2630766	et	4	main
lõppesid	doc_491521502209_item	2630781	et	4	main
matused	doc_491521502209_item	2630782	et	3	main
tuli	doc_491521502209_item	2630785	et	4	main
riidu	doc_491521502209_item	2630791	et	4	main
see	doc_491521502209_item	2630793	et	3	main
lõppes	doc_491521502209_item	2630794	et	4	main
on	doc_491521502209_item	2630584	et	4	main
alepõllundus	doc_491521502209_item	2630585	et	3	main
uskusid	doc_491521502209_item	2630589	et	4	main
et	doc_491521502209_item	2630590	et	3	main
nende	doc_491521502209_item	2630591	et	4	main
pahameelt	doc_491521502209_item	2630602	et	4	main
ohverdasid	doc_491521502209_item	2630605	et	4	main
isegi	doc_491521502209_item	2630616	et	4	main
ta	doc_491521502209_item	2630623	et	4	main
et	doc_491521502209_item	2630625	et	3	main
teised	doc_491521502209_item	2630626	et	4	main
alasid	doc_491521502209_item	2630631	et	4	main
rüüstama	doc_491521502209_item	2630632	et	3	main
kaasnesid	doc_491521502209_item	2630637	et	4	main
sellest	doc_491521502209_item	2630654	et	4	main
ja	doc_491521502209_item	2630666	et	3	main
samuti	doc_491521502209_item	2630699	et	3	main
surnud	doc_491521502209_item	2630712	et	4	main
mõned	doc_491521502209_item	2630720	et	3	main
et	doc_491521502209_item	2630722	et	3	main
siis	doc_491521502209_item	2630725	et	3	main
rahu	doc_491521502209_item	2630730	et	4	main
või	doc_491521502209_item	2630741	et	4	main
teise	doc_491521502209_item	2630745	et	4	main
seal	doc_491521502209_item	2630747	et	4	main
meestega	doc_491521502209_item	2630749	et	4	main
maeti	doc_491521502209_item	2630750	et	3	main
surevad	doc_491521502209_item	2630757	et	4	main
muidugi	doc_491521502209_item	2630769	et	4	main
kui	doc_491521502209_item	2630771	et	3	main
nn	doc_491521502209_item	2630773	et	4	main
mitu	doc_491521502209_item	2630776	et	4	main
minna	doc_491521502209_item	2630786	et	3	main
sest	doc_491521502209_item	2630789	et	4	main
metsast	doc_491521502209_item	2630822	et	4	main
eestlased	doc_491521502209_item	2630825	et	3	main
midagi	doc_491521502209_item	2630826	et	4	main
loodus	doc_491521502209_item	2630833	et	4	main
ning	doc_491521502209_item	2630835	et	3	main
raiumine	doc_491521502209_item	2630837	et	4	main
tähendas	doc_491521502209_item	2630838	et	3	main
pärast	doc_491521502209_item	2630842	et	4	main
nad	doc_491521502209_item	2630843	et	3	main
hiljem	doc_491521502209_item	2630864	et	3	main
hauakividel	doc_491521502209_item	2630866	et	3	main
selle	doc_491521502209_item	2630868	et	4	main
vette	doc_491521502209_item	2630880	et	3	main
hõbe	doc_491521502209_item	2630882	et	3	main
selle	doc_491521502209_item	2630887	et	4	main
veega	doc_491521502209_item	2630888	et	3	main
ning	doc_491521502209_item	2630890	et	3	main
haigustest	doc_491521502209_item	2630894	et	4	main
saavat	doc_491521502209_item	2630896	et	4	main
säilitada	doc_491521502209_item	2630901	et	3	main
noorust	doc_491521502209_item	2630903	et	4	main
puuks	doc_491521502209_item	2630908	et	4	main
ning	doc_491521502209_item	2630914	et	3	main
meelerahu	doc_491521502209_item	2630916	et	4	main
oli	doc_491521502209_item	2630918	et	3	main
kristlastel	doc_491521502209_item	2630923	et	3	main
2	doc_491521502209_item	2630925	et	2	main
nimetatakse	doc_491521502209_item	2630927	et	3	main
tegemine	doc_491521502209_item	2630944	et	4	main
eestlaste	doc_491521502210_item	2630947	et	4	main
on	doc_491521502210_item	2630958	et	4	main
ja	doc_491521502210_item	2630988	et	3	main
hauapanused	doc_491521502210_item	2631033	et	3	main
endiselt	doc_491521502210_item	2631035	et	4	main
ja	doc_491521502210_item	2631038	et	3	main
8	doc_491521502210_item	2631040	et	2	main
saj	doc_491521502210_item	2631042	et	4	main
ekr	doc_491521502210_item	2631043	et	4	main
eestis	doc_491521502210_item	2631044	et	3	main
kivimetest	doc_491521502210_item	2631052	et	4	main
kirst	doc_491521502210_item	2631056	et	3	main
ja	doc_491521502210_item	2631058	et	3	main
oli	doc_491521502210_item	2631061	et	3	main
konfliktide	doc_491521502210_item	2631064	et	3	main
avastatud	doc_491521502210_item	2631076	et	4	main
ka	doc_491521502210_item	2631077	et	3	main
õnne	doc_491521502210_item	2631091	et	4	main
ohverdati	doc_491521502210_item	2631095	et	3	main
ei	doc_491521502209_item	2630628	et	4	main
tuleks	doc_491521502209_item	2630629	et	4	main
nim	doc_491521502209_item	2630634	et	4	main
ohverdusega	doc_491521502209_item	2630636	et	4	main
erinevad	doc_491521502209_item	2630646	et	4	main
samuti	doc_491521502209_item	2630647	et	3	main
surnud	doc_491521502209_item	2630658	et	4	main
väesse	doc_491521502209_item	2630672	et	3	main
jumalaks	doc_491521502209_item	2630673	et	3	main
oli	doc_491521502209_item	2630674	et	3	main
taara	doc_491521502209_item	2630675	et	4	main
mõnel	doc_491521502209_item	2630676	et	3	main
pool	doc_491521502209_item	2630677	et	4	main
tooru	doc_491521502209_item	2630678	et	4	main
jumal	doc_491521502209_item	2630679	et	3	main
oli	doc_491521502209_item	2630680	et	3	main
sama	doc_491521502209_item	2630681	et	4	main
kuid	doc_491521502209_item	2630682	et	4	main
nimi	doc_491521502209_item	2630683	et	3	main
erinev	doc_491521502209_item	2630684	et	4	main
see	doc_491521502209_item	2630685	et	3	main
aga	doc_491521502209_item	2630686	et	3	main
et	doc_491521502209_item	2630687	et	3	main
nimi	doc_491521502209_item	2630688	et	3	main
erinev	doc_491521502209_item	2630689	et	4	main
oli	doc_491521502209_item	2630690	et	3	main
tekitas	doc_491521502209_item	2630691	et	3	main
tülisid	doc_491521502209_item	2630692	et	3	main
päris	doc_491521502209_item	2630693	et	4	main
oma	doc_491521502209_item	2630694	et	4	main
jumalani	doc_491521502209_item	2630695	et	3	main
aga	doc_491521502209_item	2630696	et	3	main
ei	doc_491521502209_item	2630697	et	4	main
jõutud	doc_491521502209_item	2630698	et	4	main
elas	doc_491521502209_item	2630703	et	3	main
kas	doc_491521502209_item	2630713	et	3	main
matmiskombed	doc_491521502209_item	2630717	et	3	main
piirkonniti	doc_491521502209_item	2630719	et	3	main
sellest	doc_491521502209_item	2630738	et	4	main
kas	doc_491521502209_item	2630739	et	3	main
maeti	doc_491521502209_item	2630740	et	3	main
kaasa	doc_491521502209_item	2630744	et	4	main
ilma	doc_491521502209_item	2630746	et	4	main
või	doc_491521502209_item	2630751	et	4	main
põletati	doc_491521502209_item	2630752	et	3	main
tema	doc_491521502209_item	2630753	et	4	main
sõjariistu	doc_491521502209_item	2630754	et	3	main
tihti	doc_491521502209_item	2630755	et	3	main
et	doc_491521502209_item	2630762	et	3	main
pandaks	doc_491521502209_item	2630765	et	4	main
pandi	doc_491521502209_item	2630767	et	4	main
vaesematele	doc_491521502209_item	2630772	et	4	main
kestsid	doc_491521502209_item	2630775	et	4	main
et	doc_491521502209_item	2630784	et	3	main
järgmistele	doc_491521502209_item	2630787	et	3	main
ühe	doc_491521502209_item	2630795	et	4	main
poole	doc_491521502209_item	2630796	et	4	main
surmaga	doc_491521502209_item	2630797	et	3	main
eestlased	doc_491521502209_item	2630798	et	3	main
pidasid	doc_491521502209_item	2630799	et	4	main
oluliseks	doc_491521502209_item	2630800	et	4	main
veretasu	doc_491521502209_item	2630801	et	4	main
see	doc_491521502209_item	2630802	et	3	main
tähendas	doc_491521502209_item	2630803	et	3	main
et	doc_491521502209_item	2630804	et	3	main
kui	doc_491521502209_item	2630805	et	3	main
keegi	doc_491521502209_item	2630806	et	4	main
kellegi	doc_491521502209_item	2630807	et	4	main
tappis	doc_491521502209_item	2630808	et	4	main
siis	doc_491521502209_item	2630809	et	3	main
tapetu	doc_491521502209_item	2630810	et	4	main
omaksed	doc_491521502209_item	2630811	et	3	main
tapsid	doc_491521502209_item	2630812	et	4	main
see	doc_491521502209_item	2630814	et	3	main
tapja	doc_491521502209_item	2630813	et	4	main
tõi	doc_491521502209_item	2630815	et	3	main
tihti	doc_491521502209_item	2630816	et	3	main
kaasa	doc_491521502209_item	2630817	et	4	main
mõne	doc_491521502209_item	2630818	et	3	main
suguseltsi	doc_491521502209_item	2630819	et	4	main
välja	doc_491521502209_item	2630820	et	4	main
küsimata	doc_491521502209_item	2630827	et	4	main
puu	doc_491521502209_item	2630845	et	4	main
käest	doc_491521502209_item	2630846	et	4	main
kas	doc_491521502209_item	2630847	et	3	main
nad	doc_491521502209_item	2630848	et	3	main
slaavlastega	doc_491521502209_item	2630853	et	3	main
hakati	doc_491521502209_item	2630863	et	3	main
visati	doc_491521502209_item	2630879	et	3	main
ehteid	doc_491521502209_item	2630886	et	3	main
pesti	doc_491521502209_item	2630889	et	3	main
lahti	doc_491521502209_item	2630895	et	4	main
pesemisega	doc_491521502209_item	2630899	et	4	main
oma	doc_491521502209_item	2630902	et	4	main
ning	doc_491521502209_item	2630904	et	3	main
parandada	doc_491521502209_item	2630905	et	3	main
pühaks	doc_491521502209_item	2630907	et	3	main
oli	doc_491521502209_item	2630909	et	3	main
nad	doc_491521502209_item	2630828	et	3	main
ka	doc_491521502209_item	2630831	et	3	main
puu	doc_491521502209_item	2630836	et	4	main
puu	doc_491521502209_item	2630839	et	4	main
surma	doc_491521502209_item	2630840	et	4	main
ta	doc_491521502209_item	2630850	et	4	main
kokku	doc_491521502209_item	2630854	et	3	main
puutudes	doc_491521502209_item	2630855	et	3	main
tutvuti	doc_491521502209_item	2630856	et	3	main
risti	doc_491521502209_item	2630857	et	4	main
sümboliga	doc_491521502209_item	2630858	et	4	main
mis	doc_491521502209_item	2630859	et	4	main
tähendas	doc_491521502209_item	2630860	et	3	main
surma	doc_491521502209_item	2630861	et	4	main
just	doc_491521502209_item	2630867	et	3	main
pärast	doc_491521502209_item	2630871	et	4	main
allikale	doc_491521502209_item	2630877	et	4	main
hõbedat	doc_491521502209_item	2630881	et	3	main
münte	doc_491521502209_item	2630883	et	3	main
isegi	doc_491521502209_item	2630885	et	4	main
moel	doc_491521502209_item	2630892	et	4	main
arvati	doc_491521502209_item	2630893	et	4	main
näo	doc_491521502209_item	2630898	et	3	main
tamm	doc_491521502209_item	2630910	et	3	main
ohverdati	doc_491521502209_item	2630913	et	3	main
allikaveega	doc_491521502209_item	2630897	et	3	main
loodeti	doc_491521502209_item	2630900	et	3	main
hiis	doc_491521502209_item	2630911	et	4	main
otsiti	doc_491521502209_item	2630915	et	3	main
püha	doc_491521502209_item	2630919	et	4	main
nagu	doc_491521502209_item	2630921	et	3	main
kui	doc_491521502209_item	2630929	et	3	main
raiutakse	doc_491521502209_item	2630931	et	3	main
maa	doc_491521502209_item	2630933	et	4	main
selle	doc_491521502209_item	2630936	et	4	main
alal	doc_491521502209_item	2630937	et	4	main
hakatakse	doc_491521502209_item	2630938	et	3	main
tegelema	doc_491521502209_item	2630939	et	3	main
põllumajandusega	doc_491521502209_item	2630940	et	3	main
ehk	doc_491521502209_item	2630941	et	3	main
kontrolltöö	doc_491521502210_item	2630945	et	4	main
üldiseloomustus	doc_491521502210_item	2630949	et	4	main
üsna	doc_491521502210_item	2630959	et	3	main
raske	doc_491521502210_item	2630960	et	4	main
oli	doc_491521502210_item	2630964	et	3	main
uskumuste	doc_491521502210_item	2630982	et	4	main
surnuid	doc_491521502210_item	2630990	et	4	main
territooriumi	doc_491521502210_item	2631023	et	4	main
ehted	doc_491521502210_item	2631037	et	3	main
9	doc_491521502210_item	2631041	et	2	main
kivikirstkalmed	doc_491521502210_item	2631047	et	4	main
mis	doc_491521502210_item	2631048	et	4	main
hakkati	doc_491521502210_item	2631068	et	3	main
kaasa	doc_491521502210_item	2631070	et	4	main
relvi	doc_491521502210_item	2631073	et	4	main
vahel	doc_491521502210_item	2631074	et	4	main
haudadest	doc_491521502210_item	2631075	et	3	main
elu	doc_491521502210_item	2631079	et	4	main
ja	doc_491521502210_item	2631080	et	3	main
vere	doc_491521502210_item	2631081	et	3	main
sümbol	doc_491521502210_item	2631082	et	3	main
muinasaja	doc_491521502210_item	2631084	et	3	main
edu	doc_491521502210_item	2631089	et	4	main
ja	doc_491521502210_item	2631090	et	3	main
surnute	doc_491521502210_item	2631093	et	4	main
hiljemalt	doc_491521502210_item	2631099	et	3	main
komme	doc_491521502210_item	2631144	et	4	main
mets	doc_491521502210_item	2631163	et	3	main
raiuti	doc_491521502210_item	2631164	et	3	main
mulla	doc_491521502210_item	2631176	et	4	main
ajal	doc_491521502210_item	2631183	et	4	main
tammikus	doc_491521502209_item	2630912	et	3	main
tammik	doc_491521502209_item	2630917	et	3	main
tänapäeval	doc_491521502209_item	2630922	et	3	main
mets	doc_491521502209_item	2630930	et	3	main
maha	doc_491521502209_item	2630932	et	4	main
põletatakse	doc_491521502209_item	2630934	et	3	main
põllumaa	doc_491521502209_item	2630943	et	4	main
1	doc_491521502210_item	2630946	et	2	main
mis	doc_491521502210_item	2630951	et	4	main
alepõllundus	doc_491521502210_item	2630953	et	3	main
kirjeldada	doc_491521502210_item	2630961	et	3	main
kuna	doc_491521502210_item	2630962	et	3	main
muinasaeg	doc_491521502210_item	2630963	et	3	main
pikk	doc_491521502210_item	2630966	et	4	main
toimusid	doc_491521502210_item	2630969	et	4	main
süsteem	doc_491521502210_item	2630983	et	3	main
elust	doc_491521502210_item	2630987	et	3	main
hingest	doc_491521502210_item	2630989	et	4	main
maeti	doc_491521502210_item	2630991	et	3	main
poosis	doc_491521502210_item	2631031	et	3	main
küljel	doc_491521502210_item	2631032	et	3	main
olid	doc_491521502210_item	2631049	et	4	main
ajal	doc_491521502210_item	2631067	et	4	main
ka	doc_491521502210_item	2631072	et	3	main
sõltuvad	doc_491521502210_item	2631092	et	4	main
tarbeesemeid	doc_491521502210_item	2631098	et	3	main
ka	doc_491521502210_item	2631100	et	3	main
oli	doc_491521502210_item	2631104	et	3	main
ilmastiku	doc_491521502210_item	2631121	et	4	main
ei	doc_491521502210_item	2631128	et	4	main
püsis	doc_491521502210_item	2631135	et	4	main
mis	doc_491521502210_item	2631145	et	4	main
on	doc_491521502210_item	2631153	et	4	main
olnud	doc_491521502210_item	2631154	et	4	main
soov	doc_491521502210_item	2631155	et	3	main
suurendada	doc_491521502210_item	2631156	et	3	main
põletati	doc_491521502210_item	2631167	et	3	main
tuhk	doc_491521502210_item	2631168	et	3	main
jäi	doc_491521502210_item	2631169	et	3	main
väetiseks	doc_491521502210_item	2631170	et	3	main
kasutati	doc_491521502210_item	2631171	et	4	main
mõne	doc_491521502210_item	2631172	et	3	main
langes	doc_491521502210_item	2631178	et	4	main
hakkati	doc_491521502210_item	2631179	et	3	main
kasutama	doc_491521502210_item	2631180	et	3	main
varasel	doc_491521502210_item	2631181	et	4	main
alepõllunduseks	doc_491521502209_item	2630926	et	3	main
ja	doc_491521502209_item	2630935	et	3	main
muinasusundi	doc_491521502210_item	2630948	et	3	main
2	doc_491521502210_item	2630950	et	2	main
on	doc_491521502210_item	2630952	et	4	main
1	doc_491521502210_item	2630954	et	2	main
eestlaste	doc_491521502210_item	2630955	et	4	main
muinasusundi	doc_491521502210_item	2630956	et	3	main
üldiselt	doc_491521502210_item	2630957	et	4	main
päris	doc_491521502210_item	2630965	et	4	main
ajajärk	doc_491521502210_item	2630967	et	3	main
kindlasti	doc_491521502210_item	2630976	et	3	main
öelda	doc_491521502210_item	2630977	et	4	main
et	doc_491521502210_item	2630978	et	3	main
inimestel	doc_491521502210_item	2630979	et	3	main
oli	doc_491521502210_item	2630980	et	3	main
keeruline	doc_491521502210_item	2630981	et	4	main
ettekujutus	doc_491521502210_item	2630985	et	4	main
hauatagusest	doc_491521502210_item	2630986	et	3	main
asula	doc_491521502210_item	2630992	et	4	main
territooriumile	doc_491521502210_item	2630993	et	3	main
vahel	doc_491521502210_item	2630994	et	4	main
isegi	doc_491521502210_item	2630995	et	4	main
püstkoja	doc_491521502210_item	2630996	et	3	main
põranda	doc_491521502210_item	2630997	et	3	main
alla	doc_491521502210_item	2630998	et	3	main
kaasa	doc_491521502210_item	2630999	et	4	main
pandi	doc_491521502210_item	2631000	et	4	main
tööriistu	doc_491521502210_item	2631001	et	3	main
tarbeesemeid	doc_491521502210_item	2631002	et	3	main
amuleti	doc_491521502210_item	2631003	et	3	main
ja	doc_491521502210_item	2631004	et	3	main
ehte	doc_491521502210_item	2631005	et	3	main
funktsioonis	doc_491521502210_item	2631006	et	3	main
merevaik	doc_491521502210_item	2631007	et	3	main
mis	doc_491521502210_item	2631008	et	4	main
oli	doc_491521502210_item	2631009	et	3	main
asukate	doc_491521502210_item	2631010	et	4	main
jaoks	doc_491521502210_item	2631011	et	4	main
päikese	doc_491521502210_item	2631012	et	4	main
kivi	doc_491521502210_item	2631013	et	4	main
nöörkeraamika	doc_491521502210_item	2631014	et	4	main
hõimudeni	doc_491521502210_item	2631015	et	3	main
neoliitikumi	doc_491521502210_item	2631016	et	4	main
teisel	doc_491521502210_item	2631017	et	4	main
poolel	doc_491521502210_item	2631018	et	4	main
jõudsid	doc_491521502210_item	2631019	et	4	main
kalmed	doc_491521502210_item	2631020	et	3	main
väljaspool	doc_491521502210_item	2631021	et	3	main
ilmusid	doc_491521502210_item	2631045	et	4	main
nö	doc_491521502210_item	2631046	et	4	main
suurematest	doc_491521502210_item	2631051	et	4	main
asula	doc_491521502210_item	2631022	et	4	main
inimesi	doc_491521502210_item	2631024	et	4	main
sängitati	doc_491521502210_item	2631025	et	3	main
nüüd	doc_491521502210_item	2631026	et	4	main
mitte	doc_491521502210_item	2631027	et	3	main
selili	doc_491521502210_item	2631028	et	3	main
vaid	doc_491521502210_item	2631029	et	3	main
mugavas	doc_491521502210_item	2631030	et	3	main
olid	doc_491521502210_item	2631034	et	4	main
tööriistad	doc_491521502210_item	2631036	et	3	main
tarbeesemed	doc_491521502210_item	2631039	et	3	main
valmistatud	doc_491521502210_item	2631050	et	4	main
ja	doc_491521502210_item	2631053	et	3	main
rajutati	doc_491521502210_item	2631055	et	3	main
rauaaeg	doc_491521502210_item	2631060	et	3	main
aeg	doc_491521502210_item	2631065	et	3	main
surnutele	doc_491521502210_item	2631069	et	4	main
panema	doc_491521502210_item	2631071	et	3	main
okrit	doc_491521502210_item	2631078	et	4	main
kõigi	doc_491521502210_item	2631083	et	4	main
tööriistu	doc_491521502210_item	2631096	et	3	main
näiteks	doc_491521502210_item	2631102	et	4	main
mida	doc_491521502210_item	2631106	et	4	main
rooma	doc_491521502210_item	2631109	et	4	main
rauaajal	doc_491521502210_item	2631110	et	3	main
peamiseks	doc_491521502210_item	2631111	et	3	main
elatusalaks	doc_491521502210_item	2631112	et	3	main
on	doc_491521502210_item	2631113	et	4	main
rahva	doc_491521502210_item	2631114	et	3	main
jaoks	doc_491521502210_item	2631115	et	4	main
erilise	doc_491521502210_item	2631116	et	4	main
tähtsuse	doc_491521502210_item	2631117	et	4	main
omandanud	doc_491521502210_item	2631118	et	4	main
maagilised	doc_491521502210_item	2631119	et	4	main
toimingud	doc_491521502210_item	2631120	et	3	main
lubanud	doc_491521502210_item	2631129	et	4	main
ennast	doc_491521502210_item	2631130	et	4	main
ristida	doc_491521502210_item	2631131	et	4	main
ja	doc_491521502210_item	2631132	et	3	main
sellepärast	doc_491521502210_item	2631133	et	3	main
ulatub	doc_491521502210_item	2631146	et	3	main
rauaaega	doc_491521502210_item	2631148	et	4	main
mille	doc_491521502210_item	2631150	et	3	main
tagamaaks	doc_491521502210_item	2631152	et	3	main
2	doc_491521502210_item	2631159	et	2	main
põllumaa	doc_491521502210_item	2631161	et	4	main
saamiseks	doc_491521502210_item	2631162	et	4	main
maha	doc_491521502210_item	2631165	et	4	main
ja	doc_491521502210_item	2631166	et	3	main
viljakus	doc_491521502210_item	2631177	et	4	main
sisse	doc_491521502210_item	2631054	et	4	main
keskmine	doc_491521502210_item	2631057	et	3	main
noorem	doc_491521502210_item	2631059	et	4	main
sõdade	doc_491521502210_item	2631062	et	3	main
ja	doc_491521502210_item	2631063	et	3	main
sellel	doc_491521502210_item	2631066	et	4	main
jooksul	doc_491521502210_item	2631085	et	4	main
inimesed	doc_491521502210_item	2631086	et	3	main
arvasid	doc_491521502210_item	2631087	et	4	main
et	doc_491521502210_item	2631088	et	3	main
austamisest	doc_491521502210_item	2631094	et	4	main
ja	doc_491521502210_item	2631097	et	3	main
hõbedat	doc_491521502210_item	2631101	et	3	main
ohverdati	doc_491521502210_item	2631107	et	3	main
sirp	doc_491521502210_item	2631103	et	3	main
tööriist	doc_491521502210_item	2631105	et	3	main
jõkke	doc_491521502210_item	2631108	et	3	main
mõjutamiseks	doc_491521502210_item	2631122	et	4	main
on	doc_491521502210_item	2631123	et	4	main
teada	doc_491521502210_item	2631124	et	3	main
et	doc_491521502210_item	2631125	et	3	main
baltimaade	doc_491521502210_item	2631126	et	3	main
rahvad	doc_491521502210_item	2631127	et	3	main
baltimaa	doc_491521502210_item	2631134	et	4	main
on	doc_491521502210_item	2631141	et	4	main
jäänud	doc_491521502210_item	2631142	et	4	main
jaanitule	doc_491521502210_item	2631143	et	4	main
päikese	doc_491521502210_item	2631157	et	4	main
alepõllundus	doc_491521502210_item	2631160	et	3	main
kõige	doc_491521502210_item	2631136	et	4	main
kauem	doc_491521502210_item	2631137	et	4	main
muinasusklikuna	doc_491521502210_item	2631138	et	3	main
tänase	doc_491521502210_item	2631139	et	3	main
päevani	doc_491521502210_item	2631140	et	3	main
rooma	doc_491521502210_item	2631147	et	4	main
ja	doc_491521502210_item	2631149	et	3	main
uskumuslikuks	doc_491521502210_item	2631151	et	4	main
väge	doc_491521502210_item	2631158	et	3	main
aasta	doc_491521502210_item	2631173	et	4	main
vältel	doc_491521502210_item	2631174	et	4	main
kuni	doc_491521502210_item	2631175	et	3	main
metalli	doc_491521502210_item	2631182	et	4	main
1	doc_491521502213_item	2631597	et	2	main
suuremad	doc_491521502213_item	2631622	et	4	main
olid	doc_491521502213_item	2631625	et	4	main
majajärku	doc_491521502213_item	2631634	et	4	main
nahku	doc_491521502213_item	2631651	et	4	main
oder	doc_491521502213_item	2631652	et	3	main
sest	doc_491521502213_item	2631658	et	4	main
venemaad	doc_491521502213_item	2631664	et	4	main
kasvatati	doc_491521502213_item	2631671	et	3	main
odra	doc_491521502213_item	2631673	et	3	main
loomade	doc_491521502213_item	2631677	et	4	main
juba	doc_491521502213_item	2631684	et	3	main
tööriistad	doc_491521502213_item	2631725	et	3	main
puust	doc_491521502213_item	2631730	et	4	main
levitati	doc_491521502213_item	2631744	et	4	main
seda	doc_491521502213_item	2631751	et	3	main
kui	doc_491521502213_item	2631752	et	3	main
keele	doc_491521502213_item	2631755	et	4	main
oskus	doc_491521502213_item	2631756	et	3	main
talupojade	doc_491521502213_item	2631757	et	3	main
hulgas	doc_491521502213_item	2631758	et	4	main
ja	doc_491521502214_item	2631782	et	3	main
sai	doc_491521502214_item	2631800	et	4	main
retkedest	doc_491521502214_item	2631807	et	3	main
jutustavad	doc_491521502214_item	2631808	et	4	main
saagad	doc_491521502214_item	2631809	et	3	main
ka	doc_491521502213_item	2631631	et	3	main
so	doc_491521502213_item	2631636	et	4	main
linnades	doc_491521502213_item	2631639	et	3	main
sisse	doc_491521502213_item	2631643	et	4	main
rauda	doc_491521502213_item	2631646	et	4	main
hea	doc_491521502213_item	2631656	et	4	main
transiitmaa	doc_491521502213_item	2631657	et	4	main
peamiseks	doc_491521502213_item	2631666	et	3	main
oli	doc_491521502213_item	2631668	et	3	main
ja	doc_491521502213_item	2631676	et	3	main
veised	doc_491521502213_item	2631680	et	3	main
viikingiaeg	doc_491521502213_item	2631598	et	3	main
eesti	doc_491521502213_item	2631599	et	4	main
territooriumil	doc_491521502213_item	2631600	et	3	main
2	doc_491521502213_item	2631601	et	2	main
mõiste	doc_491521502213_item	2631602	et	4	main
muinasaeg	doc_491521502213_item	2631603	et	3	main
tähendus	doc_491521502213_item	2631604	et	4	main
1	doc_491521502213_item	2631605	et	2	main
viikingiaeg	doc_491521502213_item	2631606	et	3	main
eesti	doc_491521502213_item	2631607	et	4	main
territooriumil	doc_491521502213_item	2631608	et	3	main
oli	doc_491521502213_item	2631609	et	3	main
5-8saj	doc_491521502213_item	2631610	et	4	main
ekr	doc_491521502213_item	2631611	et	4	main
eestlased	doc_491521502213_item	2631612	et	3	main
elasid	doc_491521502213_item	2631613	et	4	main
enamasti	doc_491521502213_item	2631614	et	4	main
maal	doc_491521502213_item	2631615	et	4	main
kuid	doc_491521502213_item	2631616	et	4	main
mõned	doc_491521502213_item	2631617	et	3	main
ka	doc_491521502213_item	2631618	et	3	main
linnades	doc_491521502213_item	2631619	et	3	main
linnused	doc_491521502213_item	2631620	et	3	main
kõige	doc_491521502213_item	2631621	et	4	main
tolleaegsed	doc_491521502213_item	2631623	et	3	main
tartu	doc_491521502213_item	2631628	et	4	main
kuulusid	doc_491521502213_item	2631630	et	4	main
pärast	doc_491521502213_item	2631632	et	4	main
13saj	doc_491521502213_item	2631633	et	4	main
liit	doc_491521502213_item	2631638	et	3	main
kaubanduslik	doc_491521502213_item	2631641	et	3	main
metallid	doc_491521502213_item	2631647	et	3	main
eestist	doc_491521502213_item	2631649	et	3	main
viidi	doc_491521502213_item	2631650	et	4	main
lina	doc_491521502213_item	2631653	et	4	main
ta	doc_491521502213_item	2631659	et	4	main
seos	doc_491521502213_item	2631660	et	3	main
tegevusalaks	doc_491521502213_item	2631667	et	3	main
jne	doc_491521502213_item	2631675	et	4	main
kasvataminehobused	doc_491521502213_item	2631678	et	4	main
oli	doc_491521502213_item	2631683	et	3	main
tulnud	doc_491521502213_item	2631686	et	4	main
kontrolltöö	doc_491521502213_item	2631596	et	4	main
ja	doc_491521502213_item	2631627	et	3	main
hansaliitu	doc_491521502213_item	2631635	et	4	main
soola	doc_491521502213_item	2631645	et	4	main
viina	doc_491521502213_item	2631648	et	4	main
baltimaad	doc_491521502213_item	2631662	et	4	main
ja	doc_491521502213_item	2631663	et	3	main
põllumajandus	doc_491521502213_item	2631670	et	3	main
tatra	doc_491521502213_item	2631672	et	3	main
lina	doc_491521502213_item	2631674	et	4	main
jne	doc_491521502213_item	2631681	et	4	main
kirikuid	doc_491521502213_item	2631720	et	4	main
isegi	doc_491521502213_item	2631727	et	4	main
so	doc_491521502213_item	2631733	et	4	main
muinasajaks	doc_491521502213_item	2631736	et	3	main
peetakse	doc_491521502213_item	2631737	et	3	main
enne	doc_491521502213_item	2631750	et	4	main
käisid	doc_491521502214_item	2631779	et	4	main
eestis	doc_491521502214_item	2631780	et	3	main
kauba-	doc_491521502214_item	2631781	et	3	main
siinsed	doc_491521502214_item	2631784	et	3	main
müüsid	doc_491521502214_item	2631786	et	4	main
karusnahku	doc_491521502214_item	2631788	et	3	main
mett	doc_491521502214_item	2631789	et	4	main
vaha	doc_491521502214_item	2631790	et	4	main
sündmustest	doc_491521502214_item	2631812	et	4	main
leitud	doc_491521502214_item	2631815	et	4	main
relvade	doc_491521502214_item	2631818	et	3	main
enam	doc_491521502214_item	2631821	et	4	main
nendega	doc_491521502214_item	2631823	et	4	main
et	doc_491521502214_item	2631837	et	3	main
jutustavad	doc_491521502214_item	2631847	et	4	main
ka	doc_491521502214_item	2631848	et	3	main
u	doc_491521502214_item	2631854	et	4	main
tk	doc_491521502214_item	2631856	et	4	main
ja	doc_491521502214_item	2631857	et	3	main
kasutati	doc_491521502214_item	2631864	et	4	main
ruunikirja	doc_491521502214_item	2631865	et	4	main
lühikesed	doc_491521502214_item	2631868	et	4	main
konkreetsed	doc_491521502214_item	2631870	et	3	main
korraldasid	doc_491521502214_item	2631872	et	4	main
perioodil	doc_491521502214_item	2631877	et	3	main
poole	doc_491521502214_item	2631882	et	4	main
pihkva	doc_491521502214_item	2631895	et	4	main
esialgu	doc_491521502214_item	2631898	et	3	main
suhted	doc_491521502214_item	2631899	et	3	main
head	doc_491521502214_item	2631900	et	4	main
kaubitsemas	doc_491521502214_item	2631904	et	3	main
rajas	doc_491521502214_item	2631921	et	4	main
linnuse	doc_491521502214_item	2631923	et	3	main
asukohale	doc_491521502214_item	2631924	et	4	main
tartu	doc_491521502214_item	2631926	et	4	main
linn	doc_491521502214_item	2631927	et	3	main
a	doc_491521502214_item	2631940	et	4	main
võimutsemist	doc_491521502214_item	2631949	et	4	main
eestlased	doc_491521502214_item	2631951	et	3	main
ja	doc_491521502214_item	2631954	et	3	main
hiljem	doc_491521502214_item	2631958	et	3	main
minasaeg	doc_491521502214_item	2631972	et	4	main
algab	doc_491521502214_item	2631976	et	3	main
linnad	doc_491521502213_item	2631624	et	3	main
tallinn	doc_491521502213_item	2631626	et	4	main
mis	doc_491521502213_item	2631629	et	4	main
kaubanduslik	doc_491521502213_item	2631637	et	3	main
toimus	doc_491521502213_item	2631640	et	3	main
areng	doc_491521502213_item	2631642	et	3	main
viidi	doc_491521502213_item	2631644	et	4	main
eesti	doc_491521502213_item	2631654	et	4	main
oli	doc_491521502213_item	2631655	et	3	main
euroopa	doc_491521502213_item	2631661	et	4	main
eestlaste	doc_491521502213_item	2631665	et	4	main
küttimine	doc_491521502213_item	2631669	et	4	main
sead	doc_491521502213_item	2631679	et	4	main
raud	doc_491521502213_item	2631682	et	3	main
eestisse	doc_491521502213_item	2631685	et	4	main
seda	doc_491521502213_item	2631687	et	3	main
hakati	doc_491521502213_item	2631688	et	3	main
ka	doc_491521502213_item	2631689	et	3	main
siin	doc_491521502213_item	2631690	et	4	main
inimesed	doc_491521502213_item	2631692	et	3	main
teha	doc_491521502213_item	2631691	et	3	main
elasid	doc_491521502213_item	2631693	et	4	main
gruppidena	doc_491521502213_item	2631694	et	3	main
koos	doc_491521502213_item	2631695	et	4	main
elati	doc_491521502213_item	2631696	et	3	main
10-20	doc_491521502213_item	2631697	et	2	main
inimest	doc_491521502213_item	2631698	et	3	main
kõik	doc_491521502213_item	2631699	et	4	main
perekond	doc_491521502213_item	2631700	et	3	main
koos	doc_491521502213_item	2631701	et	4	main
vanematega	doc_491521502213_item	2631702	et	4	main
surnuid	doc_491521502213_item	2631703	et	4	main
maeti	doc_491521502213_item	2631704	et	3	main
maa	doc_491521502213_item	2631705	et	4	main
peale	doc_491521502213_item	2631706	et	4	main
kividest	doc_491521502213_item	2631707	et	3	main
ring	doc_491521502213_item	2631708	et	3	main
keskel	doc_491521502213_item	2631709	et	3	main
oli	doc_491521502213_item	2631710	et	3	main
rist	doc_491521502213_item	2631711	et	3	main
esimesed	doc_491521502213_item	2631712	et	3	main
rändjutustajad	doc_491521502213_item	2631713	et	3	main
kolima	doc_491521502213_item	2631715	et	3	main
hakkasid	doc_491521502213_item	2631714	et	4	main
ka	doc_491521502213_item	2631716	et	3	main
baltimaades	doc_491521502213_item	2631717	et	4	main
hakati	doc_491521502213_item	2631718	et	3	main
rajama	doc_491521502213_item	2631719	et	3	main
savist	doc_491521502213_item	2631728	et	4	main
raua	doc_491521502213_item	2631734	et	3	main
aega	doc_491521502213_item	2631738	et	4	main
enne	doc_491521502213_item	2631741	et	4	main
seda	doc_491521502213_item	2631742	et	3	main
kui	doc_491521502213_item	2631743	et	3	main
ja	doc_491521502213_item	2631749	et	3	main
kontrolltöö	doc_491521502214_item	2631759	et	4	main
1	doc_491521502214_item	2631760	et	2	main
viikingiaeg	doc_491521502214_item	2631761	et	3	main
eesti	doc_491521502214_item	2631762	et	4	main
territooriumil	doc_491521502214_item	2631763	et	3	main
2	doc_491521502214_item	2631764	et	2	main
mõiste	doc_491521502214_item	2631765	et	4	main
muinasaeg	doc_491521502214_item	2631766	et	3	main
tähendus	doc_491521502214_item	2631767	et	4	main
1	doc_491521502214_item	2631768	et	2	main
viikingite	doc_491521502214_item	2631769	et	3	main
periood	doc_491521502214_item	2631770	et	3	main
800-1050	doc_491521502214_item	2631771	et	2	main
pkr	doc_491521502214_item	2631772	et	4	main
kus	doc_491521502213_item	2631721	et	3	main
peamised	doc_491521502213_item	2631724	et	3	main
jaid	doc_491521502213_item	2631726	et	4	main
muinasaeg	doc_491521502213_item	2631732	et	3	main
aeg	doc_491521502213_item	2631735	et	3	main
kirjakeel	doc_491521502213_item	2631745	et	4	main
письменность	doc_491521502213_item	2631746	et	2	main
ja	doc_491521502213_item	2631747	et	3	main
eesti	doc_491521502213_item	2631754	et	4	main
noorema	doc_491521502214_item	2631773	et	4	main
omakorda	doc_491521502214_item	2631799	et	3	main
eestist	doc_491521502214_item	2631813	et	3	main
viikingitele	doc_491521502214_item	2631816	et	3	main
iseloomulike	doc_491521502214_item	2631817	et	3	main
osi	doc_491521502214_item	2631819	et	4	main
mõni	doc_491521502214_item	2631826	et	3	main
oskas	doc_491521502214_item	2631828	et	3	main
välismaalastega	doc_491521502214_item	2631830	et	4	main
nende	doc_491521502214_item	2631831	et	4	main
näitab	doc_491521502214_item	2631836	et	3	main
läänemere	doc_491521502214_item	2631838	et	3	main
elanud	doc_491521502214_item	2631840	et	4	main
rahvad	doc_491521502214_item	2631841	et	3	main
kommunikeerisid	doc_491521502214_item	2631842	et	4	main
käikudest	doc_491521502214_item	2631845	et	3	main
ruunikivid	doc_491521502214_item	2631849	et	3	main
leidub	doc_491521502214_item	2631851	et	3	main
mõned	doc_491521502214_item	2631858	et	3	main
ja	doc_491521502214_item	2631869	et	3	main
eestlased	doc_491521502214_item	2631871	et	3	main
tekkis	doc_491521502214_item	2631878	et	3	main
ilmeni	doc_491521502214_item	2631884	et	3	main
tähtsamateks	doc_491521502214_item	2631890	et	4	main
keskusteks	doc_491521502214_item	2631891	et	4	main
said	doc_491521502214_item	2631892	et	4	main
ehteid	doc_491521502214_item	2631909	et	3	main
jurjevi	doc_491521502214_item	2631928	et	4	main
linnuse	doc_491521502214_item	2631929	et	3	main
et	doc_491521502214_item	2631931	et	3	main
lõuna-eestist	doc_491521502214_item	2631933	et	3	main
vene	doc_491521502214_item	2631936	et	4	main
all	doc_491521502214_item	2631938	et	3	main
sundida	doc_491521502214_item	2631943	et	4	main
makse	doc_491521502214_item	2631945	et	4	main
maksma	doc_491521502214_item	2631946	et	3	main
pärast	doc_491521502214_item	2631947	et	4	main
lühiajalist	doc_491521502214_item	2631948	et	4	main
võtsid	doc_491521502214_item	2631950	et	4	main
sigmundi	doc_491521502214_item	2631967	et	4	main
linnuse	doc_491521502214_item	2631968	et	3	main
hävitamine	doc_491521502214_item	2631969	et	4	main
1187a	doc_491521502214_item	2631970	et	4	main
2	doc_491521502214_item	2631971	et	2	main
tähistab	doc_491521502214_item	2631973	et	3	main
esimeste	doc_491521502214_item	2631977	et	4	main
toimusid	doc_491521502213_item	2631722	et	4	main
palvesid	doc_491521502213_item	2631723	et	4	main
kivist	doc_491521502213_item	2631729	et	4	main
2	doc_491521502213_item	2631731	et	2	main
mis	doc_491521502213_item	2631739	et	4	main
oli	doc_491521502213_item	2631740	et	3	main
kristlus	doc_491521502213_item	2631748	et	4	main
levis	doc_491521502213_item	2631753	et	4	main
i	doc_491521502214_item	2631775	et	4	main
p	doc_491521502214_item	2631776	et	4	main
viikingite	doc_491521502214_item	2631777	et	3	main
skandinaavlased	doc_491521502214_item	2631778	et	3	main
inimesed	doc_491521502214_item	2631785	et	3	main
neile	doc_491521502214_item	2631787	et	4	main
neid	doc_491521502214_item	2631792	et	4	main
sõjakäikudelt	doc_491521502214_item	2631794	et	3	main
saadi	doc_491521502214_item	2631796	et	4	main
hõbedat	doc_491521502214_item	2631797	et	3	main
mida	doc_491521502214_item	2631798	et	4	main
erinevate	doc_491521502214_item	2631802	et	4	main
koduloomade	doc_491521502214_item	2631804	et	4	main
vastu	doc_491521502214_item	2631805	et	3	main
lugulaulud	doc_491521502214_item	2631810	et	3	main
tolleaegsetest	doc_491521502214_item	2631811	et	4	main
on	doc_491521502214_item	2631814	et	4	main
nooleotsad	doc_491521502214_item	2631820	et	3	main
suhtlesid	doc_491521502214_item	2631822	et	4	main
emakeeles	doc_491521502214_item	2631832	et	4	main
üksteisega	doc_491521502214_item	2631843	et	3	main
rootsis	doc_491521502214_item	2631853	et	3	main
2500	doc_491521502214_item	2631855	et	2	main
neist	doc_491521502214_item	2631859	et	4	main
on	doc_491521502214_item	2631860	et	4	main
tänapäevani	doc_491521502214_item	2631861	et	3	main
sõnumid	doc_491521502214_item	2631866	et	3	main
turul	doc_491521502214_item	2631902	et	3	main
võeti	doc_491521502214_item	2631906	et	3	main
potikeder	doc_491521502214_item	2631908	et	3	main
uued	doc_491521502214_item	2631910	et	3	main
süsteemid	doc_491521502214_item	2631914	et	3	main
eestlaste	doc_491521502214_item	2631922	et	4	main
oli	doc_491521502214_item	2631934	et	3	main
võimu	doc_491521502214_item	2631937	et	4	main
30	doc_491521502214_item	2631939	et	2	main
eestlasi	doc_491521502214_item	2631941	et	3	main
venemaale	doc_491521502214_item	2631944	et	4	main
ii	doc_491521502214_item	2631961	et	4	main
eestlased	doc_491521502214_item	2631964	et	3	main
venemaal	doc_491521502214_item	2631965	et	4	main
sõjakäikudel	doc_491521502214_item	2631966	et	3	main
perioodi	doc_491521502214_item	2631974	et	4	main
rauaaja	doc_491521502214_item	2631774	et	3	main
röövretkedel	doc_491521502214_item	2631783	et	3	main
orje	doc_491521502214_item	2631791	et	3	main
saadi	doc_491521502214_item	2631793	et	4	main
vastu	doc_491521502214_item	2631795	et	3	main
vahetada	doc_491521502214_item	2631801	et	3	main
riidesortide	doc_491521502214_item	2631803	et	3	main
viikingite	doc_491521502214_item	2631806	et	3	main
elanikud	doc_491521502214_item	2631825	et	3	main
neist	doc_491521502214_item	2631827	et	4	main
isegi	doc_491521502214_item	2631829	et	4	main
see	doc_491521502214_item	2631834	et	3	main
viikingite	doc_491521502214_item	2631844	et	3	main
mida	doc_491521502214_item	2631850	et	4	main
ohtralt	doc_491521502214_item	2631852	et	4	main
teisele	doc_491521502214_item	2631881	et	4	main
peipsi	doc_491521502214_item	2631886	et	4	main
ja	doc_491521502214_item	2631894	et	3	main
olid	doc_491521502214_item	2631897	et	4	main
käidi	doc_491521502214_item	2631903	et	3	main
slaavlastelt	doc_491521502214_item	2631905	et	3	main
ja	doc_491521502214_item	2631912	et	3	main
saarte	doc_491521502214_item	2631824	et	3	main
suhelda	doc_491521502214_item	2631833	et	4	main
fakt	doc_491521502214_item	2631835	et	3	main
ääres	doc_491521502214_item	2631839	et	4	main
eestisse	doc_491521502214_item	2631846	et	4	main
säilinud	doc_491521502214_item	2631862	et	4	main
selleks	doc_491521502214_item	2631863	et	4	main
on	doc_491521502214_item	2631867	et	4	main
ka	doc_491521502214_item	2631873	et	3	main
vastukäike	doc_491521502214_item	2631874	et	3	main
samal	doc_491521502214_item	2631875	et	3	main
viikingite	doc_491521502214_item	2631876	et	3	main
asustus	doc_491521502214_item	2631879	et	4	main
ka	doc_491521502214_item	2631880	et	3	main
9-10saj	doc_491521502214_item	2631883	et	4	main
ja	doc_491521502214_item	2631885	et	3	main
järve	doc_491521502214_item	2631887	et	4	main
taha	doc_491521502214_item	2631888	et	4	main
venemaa	doc_491521502214_item	2631889	et	4	main
novgorod	doc_491521502214_item	2631893	et	4	main
slaavlastega	doc_491521502214_item	2631896	et	3	main
novgorodi	doc_491521502214_item	2631901	et	4	main
üle	doc_491521502214_item	2631907	et	3	main
kaalu-	doc_491521502214_item	2631911	et	4	main
mõõtühiku	doc_491521502214_item	2631913	et	3	main
konflikt	doc_491521502214_item	2631915	et	3	main
tekkis	doc_491521502214_item	2631916	et	3	main
1030a	doc_491521502214_item	2631917	et	4	main
kui	doc_491521502214_item	2631918	et	3	main
jaroslav	doc_491521502214_item	2631919	et	4	main
tark	doc_491521502214_item	2631920	et	3	main
osa	doc_491521502214_item	2631932	et	4	main
end	doc_491521502214_item	2631952	et	4	main
saj	doc_491521502214_item	2631960	et	4	main
käisid	doc_491521502214_item	2631963	et	4	main
saabumisega	doc_491521502214_item	2631979	et	4	main
praegu	doc_491521502214_item	2631925	et	3	main
arvatakse	doc_491521502214_item	2631930	et	3	main
isegi	doc_491521502214_item	2631935	et	4	main
taheti	doc_491521502214_item	2631942	et	3	main
kokku	doc_491521502214_item	2631953	et	3	main
hävitasid	doc_491521502214_item	2631955	et	4	main
venelaste	doc_491521502214_item	2631956	et	4	main
keskuse	doc_491521502214_item	2631957	et	3	main
12	doc_491521502214_item	2631959	et	2	main
poolel	doc_491521502214_item	2631962	et	4	main
mis	doc_491521502214_item	2631975	et	4	main
asukate	doc_491521502214_item	2631978	et	4	main
ja	doc_491521502214_item	2631980	et	3	main
ristiusustamise	doc_491521502214_item	2631982	et	3	main
algusega	doc_491521502214_item	2631983	et	3	main
keskaeg	doc_491521502214_item	2631984	et	3	main
lõpeb	doc_491521502214_item	2631981	et	4	main
arheoloogiline	doc_491521502219_item	2633317	et	4	main
teatud	doc_491521502219_item	2633327	et	4	main
materiaalne	doc_491521502219_item	2633328	et	3	main
kunda	doc_491521502219_item	2633343	et	4	main
kultuur	doc_491521502219_item	2633344	et	3	main
kultuur	doc_491521502219_item	2633348	et	3	main
e	doc_491521502219_item	2633351	et	4	main
at	doc_491521502219_item	2633356	et	4	main
eesti	doc_491521502219_item	2633358	et	4	main
asula	doc_491521502219_item	2633360	et	4	main
tihti	doc_491521502219_item	2633382	et	3	main
ei	doc_491521502219_item	2633388	et	4	main
sooja	doc_491521502219_item	2633439	et	4	main
kivist	doc_491521502219_item	2633447	et	4	main
sarvest	doc_491521502219_item	2633448	et	4	main
ja	doc_491521502219_item	2633449	et	3	main
luust	doc_491521502219_item	2633450	et	4	main
mõiste	doc_491521502219_item	2633312	et	4	main
arheoloogiline	doc_491521502219_item	2633313	et	4	main
kultuur	doc_491521502219_item	2633314	et	3	main
selline	doc_491521502219_item	2633320	et	4	main
teatud	doc_491521502219_item	2633323	et	4	main
on	doc_491521502219_item	2633325	et	4	main
arheoloogid	doc_491521502219_item	2633339	et	3	main
kultuur	doc_491521502219_item	2633346	et	3	main
paleoliitikum	doc_491521502219_item	2633350	et	3	main
ning	doc_491521502219_item	2633366	et	3	main
paleoliitikumi	doc_491521502219_item	2633372	et	4	main
asulaid	doc_491521502219_item	2633376	et	4	main
kuna	doc_491521502219_item	2633377	et	3	main
tolleaegsed	doc_491521502219_item	2633378	et	3	main
inimesed	doc_491521502219_item	2633379	et	3	main
vahetasid	doc_491521502219_item	2633380	et	4	main
väga	doc_491521502219_item	2633381	et	3	main
inimesed	doc_491521502219_item	2633390	et	3	main
olid	doc_491521502219_item	2633423	et	4	main
kaetud	doc_491521502219_item	2633425	et	4	main
okste	doc_491521502219_item	2633426	et	3	main
naha	doc_491521502219_item	2633427	et	3	main
ja	doc_491521502219_item	2633428	et	3	main
süüa	doc_491521502219_item	2633437	et	3	main
puidust	doc_491521502219_item	2633454	et	3	main
väga	doc_491521502219_item	2633458	et	3	main
narva	doc_491521502219_item	2633479	et	4	main
kultuurile	doc_491521502219_item	2633480	et	3	main
oli	doc_491521502219_item	2633485	et	3	main
taimi	doc_491521502219_item	2633494	et	4	main
ja	doc_491521502219_item	2633495	et	3	main
kultuuri	doc_491521502219_item	2633500	et	4	main
territooriumil	doc_491521502219_item	2633310	et	3	main
2	doc_491521502219_item	2633316	et	2	main
kultuur	doc_491521502219_item	2633318	et	3	main
kultuur	doc_491521502219_item	2633321	et	3	main
tähendus	doc_491521502219_item	2633315	et	4	main
on	doc_491521502219_item	2633319	et	4	main
inimestele	doc_491521502219_item	2633324	et	3	main
omane	doc_491521502219_item	2633326	et	3	main
ja	doc_491521502219_item	2633329	et	3	main
vaimne	doc_491521502219_item	2633330	et	3	main
seisund	doc_491521502219_item	2633331	et	3	main
kuid	doc_491521502219_item	2633332	et	4	main
see	doc_491521502219_item	2633333	et	3	main
kultuur	doc_491521502219_item	2633334	et	3	main
selgub	doc_491521502219_item	2633335	et	3	main
1	doc_491521502219_item	2633349	et	2	main
oli	doc_491521502219_item	2633354	et	3	main
ekr	doc_491521502219_item	2633357	et	4	main
vanim	doc_491521502219_item	2633359	et	3	main
pole	doc_491521502219_item	2633374	et	3	main
mistõttu	doc_491521502219_item	2633384	et	3	main
neil	doc_491521502219_item	2633387	et	4	main
olnud	doc_491521502219_item	2633389	et	4	main
püstkodades	doc_491521502219_item	2633421	et	3	main
keskel	doc_491521502219_item	2633431	et	3	main
kolle	doc_491521502219_item	2633433	et	4	main
millel	doc_491521502219_item	2633434	et	3	main
inimesed	doc_491521502219_item	2633435	et	3	main
said	doc_491521502219_item	2633436	et	4	main
töö-	doc_491521502219_item	2633442	et	4	main
ja	doc_491521502219_item	2633443	et	3	main
tarberiistad	doc_491521502219_item	2633444	et	3	main
olid	doc_491521502219_item	2633445	et	4	main
valmistatud	doc_491521502219_item	2633446	et	4	main
ka	doc_491521502219_item	2633453	et	3	main
kuulusid	doc_491521502219_item	2633465	et	4	main
olid	doc_491521502219_item	2633470	et	4	main
sarv-	doc_491521502219_item	2633471	et	3	main
sisse	doc_491521502219_item	2633491	et	4	main
kvartsi-	doc_491521502219_item	2633507	et	4	main
kontrolltöö	doc_491521502219_item	2633306	et	4	main
1	doc_491521502219_item	2633307	et	2	main
kiviaeg	doc_491521502219_item	2633308	et	3	main
eesti	doc_491521502219_item	2633309	et	4	main
2	doc_491521502219_item	2633311	et	2	main
hiljem	doc_491521502219_item	2633337	et	3	main
loovad	doc_491521502219_item	2633340	et	4	main
seoseid	doc_491521502219_item	2633341	et	3	main
n	doc_491521502219_item	2633342	et	4	main
narva	doc_491521502219_item	2633347	et	4	main
vanem	doc_491521502219_item	2633352	et	4	main
8	doc_491521502219_item	2633355	et	2	main
pullis	doc_491521502219_item	2633371	et	4	main
elukohti	doc_491521502219_item	2633383	et	4	main
pikaajalisi	doc_491521502219_item	2633385	et	4	main
tegelesid	doc_491521502219_item	2633391	et	4	main
mis	doc_491521502219_item	2633422	et	4	main
pealt	doc_491521502219_item	2633424	et	4	main
püstkoja	doc_491521502219_item	2633430	et	3	main
teha	doc_491521502219_item	2633438	et	3	main
valgust	doc_491521502219_item	2633441	et	4	main
kuid	doc_491521502219_item	2633455	et	4	main
on	doc_491521502219_item	2633457	et	4	main
säilinud	doc_491521502219_item	2633460	et	4	main
eesti	doc_491521502219_item	2633461	et	4	main
kultuuri	doc_491521502219_item	2633467	et	4	main
võeti	doc_491521502219_item	2633476	et	3	main
kasutusele	doc_491521502219_item	2633477	et	4	main
keraamika	doc_491521502219_item	2633478	et	4	main
jämedast	doc_491521502219_item	2633487	et	3	main
savist	doc_491521502219_item	2633488	et	4	main
ning	doc_491521502219_item	2633489	et	3	main
mille	doc_491521502219_item	2633490	et	3	main
oli	doc_491521502219_item	2633492	et	3	main
segatud	doc_491521502219_item	2633493	et	4	main
segati	doc_491521502219_item	2633503	et	3	main
sisse	doc_491521502219_item	2633505	et	4	main
purustatud	doc_491521502219_item	2633506	et	4	main
augustatud	doc_491521502219_item	2633529	et	4	main
3	doc_491521502219_item	2633536	et	2	main
kirved	doc_491521502219_item	2633538	et	3	main
olid	doc_491521502219_item	2633539	et	4	main
paadikujulised	doc_491521502219_item	2633540	et	4	main
ja	doc_491521502219_item	2633541	et	3	main
nõud	doc_491521502219_item	2633542	et	3	main
olid	doc_491521502219_item	2633543	et	4	main
servadesse	doc_491521502219_item	2633550	et	3	main
neoliitikumi	doc_491521502219_item	2633552	et	4	main
territooriumile	doc_491521502219_item	2633558	et	3	main
territooriumi	doc_491521502219_item	2633575	et	4	main
ning	doc_491521502219_item	2633579	et	3	main
pandi	doc_491521502219_item	2633582	et	4	main
ning	doc_491521502219_item	2633585	et	3	main
olid	doc_491521502219_item	2633589	et	4	main
loomadega	doc_491521502219_item	2633591	et	3	main
mõndasid	doc_491521502219_item	2633592	et	4	main
loomi	doc_491521502219_item	2633593	et	4	main
austati	doc_491521502219_item	2633594	et	3	main
püsiv	doc_491521502219_item	2633604	et	4	main
kiviaeg	doc_491521502220_item	2633608	et	3	main
territooriumil	doc_491521502220_item	2633610	et	3	main
ja	doc_491521502220_item	2633623	et	3	main
arheoloogilise	doc_491521502220_item	2633628	et	4	main
uurimistöö	doc_491521502220_item	2633629	et	4	main
on	doc_491521502220_item	2633634	et	4	main
kiviaeg	doc_491521502220_item	2633646	et	3	main
paleoliitikum	doc_491521502220_item	2633651	et	3	main
kiviaeg	doc_491521502220_item	2633653	et	3	main
at	doc_491521502220_item	2633670	et	4	main
asustus	doc_491521502220_item	2633676	et	4	main
kalevid	doc_491521502220_item	2633699	et	3	main
metshobused	doc_491521502220_item	2633720	et	4	main
kus	doc_491521502219_item	2633322	et	3	main
alles	doc_491521502219_item	2633336	et	3	main
mil	doc_491521502219_item	2633338	et	4	main
neemeri	doc_491521502219_item	2633345	et	4	main
kiviaeg	doc_491521502219_item	2633353	et	3	main
on	doc_491521502219_item	2633361	et	4	main
pärit	doc_491521502219_item	2633362	et	3	main
8	doc_491521502219_item	2633363	et	2	main
atekr	doc_491521502219_item	2633364	et	4	main
keskpaigast	doc_491521502219_item	2633365	et	4	main
asub	doc_491521502219_item	2633367	et	3	main
pärnu	doc_491521502219_item	2633368	et	4	main
jõe	doc_491521502219_item	2633369	et	3	main
ääres	doc_491521502219_item	2633370	et	4	main
algusest	doc_491521502219_item	2633373	et	4	main
avastatud	doc_491521502219_item	2633375	et	4	main
peatuspaiku	doc_491521502219_item	2633386	et	3	main
küttimise	doc_491521502219_item	2633392	et	4	main
kalapüügi	doc_491521502219_item	2633393	et	4	main
ja	doc_491521502219_item	2633394	et	3	main
loodusandide	doc_491521502219_item	2633395	et	3	main
korjamisega	doc_491521502219_item	2633396	et	4	main
neoliitikumis	doc_491521502219_item	2633397	et	3	main
e	doc_491521502219_item	2633398	et	4	main
nooremal	doc_491521502219_item	2633399	et	4	main
kiviajal	doc_491521502219_item	2633400	et	3	main
paranes	doc_491521502219_item	2633401	et	3	main
kliima	doc_491521502219_item	2633402	et	4	main
mistõttu	doc_491521502219_item	2633403	et	3	main
inimestel	doc_491521502219_item	2633404	et	3	main
olid	doc_491521502219_item	2633405	et	4	main
paremad	doc_491521502219_item	2633406	et	4	main
võimalused	doc_491521502219_item	2633407	et	3	main
enda	doc_491521502219_item	2633408	et	4	main
äraelatamiseks	doc_491521502219_item	2633409	et	3	main
kiviajal	doc_491521502219_item	2633410	et	3	main
elasid	doc_491521502219_item	2633411	et	4	main
inimesed	doc_491521502219_item	2633412	et	3	main
20-100-kesti	doc_491521502219_item	2633413	et	4	main
asulates	doc_491521502219_item	2633414	et	4	main
mis	doc_491521502219_item	2633415	et	4	main
paiknesid	doc_491521502219_item	2633416	et	4	main
järvede	doc_491521502219_item	2633417	et	3	main
kallastel	doc_491521502219_item	2633418	et	4	main
tavaliselt	doc_491521502219_item	2633419	et	4	main
elati	doc_491521502219_item	2633420	et	3	main
sammaldega	doc_491521502219_item	2633429	et	3	main
asus	doc_491521502219_item	2633432	et	4	main
ja	doc_491521502219_item	2633440	et	3	main
valmistati	doc_491521502219_item	2633452	et	4	main
neid	doc_491521502219_item	2633456	et	4	main
vähe	doc_491521502219_item	2633459	et	3	main
kunda	doc_491521502219_item	2633466	et	4	main
mille	doc_491521502219_item	2633468	et	3	main
on	doc_491521502219_item	2633481	et	4	main
iseloomulikuks	doc_491521502219_item	2633482	et	3	main
keraamika	doc_491521502219_item	2633483	et	4	main
mis	doc_491521502219_item	2633484	et	4	main
teokarpe	doc_491521502219_item	2633496	et	4	main
lõuna-leedu	doc_491521502219_item	2633497	et	4	main
alla	doc_491521502219_item	2633501	et	3	main
savi	doc_491521502219_item	2633504	et	4	main
graniiditükke	doc_491521502219_item	2633509	et	3	main
umbes	doc_491521502219_item	2633510	et	4	main
4	doc_491521502219_item	2633511	et	2	main
at	doc_491521502219_item	2633512	et	4	main
e	doc_491521502219_item	2633513	et	4	main
tekkis	doc_491521502219_item	2633515	et	3	main
kr	doc_491521502219_item	2633514	et	4	main
kammkeraamika	doc_491521502219_item	2633516	et	4	main
nõud	doc_491521502219_item	2633517	et	3	main
olid	doc_491521502219_item	2633518	et	4	main
kvaliteetsemad	doc_491521502219_item	2633519	et	4	main
ja	doc_491521502219_item	2633520	et	3	main
nagu	doc_491521502219_item	2633523	et	3	main
ääred	doc_491521502219_item	2633528	et	3	main
venekirveste	doc_491521502219_item	2633530	et	4	main
eestisse	doc_491521502219_item	2633535	et	4	main
nii	doc_491521502219_item	2633545	et	3	main
nõõriga	doc_491521502219_item	2633548	et	4	main
asula	doc_491521502219_item	2633557	et	4	main
kägaras	doc_491521502219_item	2633580	et	4	main
kaasa	doc_491521502219_item	2633583	et	4	main
seotud	doc_491521502219_item	2633590	et	4	main
aga	doc_491521502219_item	2633596	et	3	main
kardeti	doc_491521502219_item	2633597	et	3	main
e	doc_491521502219_item	2633600	et	4	main
keskmisel	doc_491521502219_item	2633601	et	3	main
tähendus	doc_491521502220_item	2633615	et	4	main
2	doc_491521502220_item	2633616	et	2	main
iseloomulik	doc_491521502220_item	2633621	et	3	main
mis	doc_491521502220_item	2633626	et	4	main
1	doc_491521502220_item	2633645	et	2	main
jaguneb	doc_491521502220_item	2633647	et	3	main
raske	doc_491521502220_item	2633655	et	4	main
oli	doc_491521502220_item	2633661	et	3	main
püsis	doc_491521502220_item	2633664	et	4	main
iv	doc_491521502220_item	2633672	et	4	main
et	doc_491521502220_item	2633698	et	3	main
tulid	doc_491521502220_item	2633702	et	4	main
lõuna	doc_491521502220_item	2633703	et	4	main
sellel	doc_491521502220_item	2633707	et	4	main
puust	doc_491521502220_item	2633711	et	4	main
nt	doc_491521502220_item	2633713	et	4	main
noolotsad	doc_491521502220_item	2633714	et	3	main
odaotsad	doc_491521502220_item	2633715	et	3	main
elatusaladeks	doc_491521502220_item	2633716	et	3	main
olid	doc_491521502220_item	2633717	et	4	main
siga	doc_491521502220_item	2633721	et	4	main
mesoliitikumist	doc_491521502220_item	2633736	et	4	main
tulnud	doc_491521502220_item	2633737	et	4	main
elementidega	doc_491521502220_item	2633742	et	3	main
ja	doc_491521502220_item	2633743	et	3	main
kalade	doc_491521502220_item	2633744	et	3	main
nimedega	doc_491521502220_item	2633745	et	3	main
esemeid	doc_491521502219_item	2633451	et	3	main
läti	doc_491521502219_item	2633462	et	4	main
ja	doc_491521502219_item	2633463	et	3	main
põhja-leedu	doc_491521502219_item	2633464	et	4	main
eripäraks	doc_491521502219_item	2633469	et	3	main
ja	doc_491521502219_item	2633472	et	3	main
luuesemed	doc_491521502219_item	2633473	et	3	main
nooremal	doc_491521502219_item	2633474	et	4	main
kiviajal	doc_491521502219_item	2633475	et	3	main
tehtud	doc_491521502219_item	2633486	et	4	main
kuulus	doc_491521502219_item	2633498	et	4	main
neemeni	doc_491521502219_item	2633499	et	3	main
seal	doc_491521502219_item	2633502	et	4	main
ja	doc_491521502219_item	2633508	et	3	main
e	doc_491521502219_item	2633531	et	4	main
nõõrkeraamika	doc_491521502219_item	2633532	et	4	main
jõudis	doc_491521502219_item	2633534	et	3	main
inimesed	doc_491521502219_item	2633576	et	3	main
ehteid	doc_491521502219_item	2633586	et	3	main
mesoliitikumis	doc_491521502219_item	2633599	et	3	main
tekkis	doc_491521502219_item	2633603	et	3	main
1	doc_491521502220_item	2633607	et	2	main
2	doc_491521502220_item	2633611	et	2	main
kultuur	doc_491521502220_item	2633618	et	3	main
nii	doc_491521502219_item	2633522	et	3	main
umbes	doc_491521502219_item	2633525	et	4	main
kultuur	doc_491521502219_item	2633533	et	3	main
atekr	doc_491521502219_item	2633537	et	4	main
nagu	doc_491521502219_item	2633546	et	3	main
esimesel	doc_491521502219_item	2633553	et	3	main
maeti	doc_491521502219_item	2633555	et	3	main
ka	doc_491521502219_item	2633560	et	3	main
püstkoja	doc_491521502219_item	2633561	et	3	main
põranda	doc_491521502219_item	2633562	et	3	main
alla	doc_491521502219_item	2633563	et	3	main
inimesed	doc_491521502219_item	2633564	et	3	main
maeti	doc_491521502219_item	2633565	et	3	main
selili	doc_491521502219_item	2633566	et	3	main
asendis	doc_491521502219_item	2633567	et	3	main
ii	doc_491521502219_item	2633569	et	4	main
neoliitikumi	doc_491521502219_item	2633568	et	4	main
poolel	doc_491521502219_item	2633570	et	4	main
hakati	doc_491521502219_item	2633571	et	3	main
matma	doc_491521502219_item	2633572	et	3	main
kaunistatud	doc_491521502219_item	2633521	et	4	main
oleks	doc_491521502219_item	2633524	et	3	main
kammiga	doc_491521502219_item	2633526	et	4	main
kausi	doc_491521502219_item	2633527	et	3	main
kaunistatud	doc_491521502219_item	2633544	et	4	main
oleks	doc_491521502219_item	2633547	et	3	main
tehtud	doc_491521502219_item	2633549	et	4	main
mustreid	doc_491521502219_item	2633551	et	4	main
poolel	doc_491521502219_item	2633554	et	4	main
inimesi	doc_491521502219_item	2633556	et	4	main
vahel	doc_491521502219_item	2633559	et	4	main
maeti	doc_491521502219_item	2633577	et	3	main
külili	doc_491521502219_item	2633578	et	3	main
inimeste	doc_491521502219_item	2633587	et	3	main
teisi	doc_491521502219_item	2633595	et	4	main
alles	doc_491521502219_item	2633598	et	3	main
inimasustus	doc_491521502219_item	2633605	et	3	main
eesti	doc_491521502220_item	2633609	et	4	main
mõiste	doc_491521502220_item	2633612	et	4	main
arheoloogiline	doc_491521502220_item	2633613	et	4	main
kultuur	doc_491521502220_item	2633614	et	3	main
kultuur	doc_491521502220_item	2633625	et	3	main
ilmneb	doc_491521502220_item	2633627	et	3	main
omased	doc_491521502220_item	2633635	et	3	main
ja	doc_491521502220_item	2633643	et	3	main
paleoliitikumiks	doc_491521502220_item	2633648	et	3	main
vanem	doc_491521502220_item	2633652	et	4	main
kuna	doc_491521502220_item	2633659	et	3	main
lõpp	doc_491521502220_item	2633671	et	3	main
kesk	doc_491521502220_item	2633674	et	3	main
kalevid	doc_491521502220_item	2633696	et	3	main
leedu	doc_491521502220_item	2633705	et	4	main
valgevene	doc_491521502220_item	2633706	et	4	main
küttimine	doc_491521502220_item	2633718	et	4	main
hülged	doc_491521502220_item	2633719	et	3	main
karu	doc_491521502220_item	2633722	et	4	main
põder	doc_491521502220_item	2633723	et	3	main
kalapüük	doc_491521502220_item	2633724	et	3	main
loodusandide	doc_491521502220_item	2633725	et	3	main
mets	doc_491521502220_item	2633749	et	3	main
haug	doc_491521502220_item	2633751	et	3	main
et	doc_491521502220_item	2633753	et	3	main
10000	doc_491521502220_item	2633756	et	2	main
a	doc_491521502220_item	2633757	et	4	main
saab	doc_491521502220_item	2633767	et	3	main
ja	doc_491521502220_item	2633785	et	3	main
hakkavad	doc_491521502220_item	2633790	et	4	main
võõrad	doc_491521502220_item	2633794	et	3	main
otsida	doc_491521502220_item	2633797	et	4	main
elati	doc_491521502220_item	2633798	et	3	main
püstkodades	doc_491521502220_item	2633799	et	3	main
süüa	doc_491521502220_item	2633800	et	3	main
tehti	doc_491521502220_item	2633801	et	3	main
on	doc_491521502220_item	2633808	et	4	main
ka	doc_491521502220_item	2633821	et	3	main
keraamikat	doc_491521502220_item	2633827	et	3	main
sisse	doc_491521502220_item	2633831	et	4	main
iv	doc_491521502220_item	2633839	et	4	main
nimi	doc_491521502220_item	2633844	et	3	main
kammi	doc_491521502220_item	2633849	et	4	main
pärast	doc_491521502220_item	2633851	et	4	main
hakati	doc_491521502220_item	2633852	et	3	main
ka	doc_491521502220_item	2633853	et	3	main
geomeetrilisi	doc_491521502220_item	2633854	et	4	main
kujundeid	doc_491521502220_item	2633855	et	3	main
joonistama	doc_491521502220_item	2633856	et	3	main
soome-ugri	doc_491521502220_item	2633857	et	3	main
rahva	doc_491521502220_item	2633858	et	3	main
veel	doc_491521502220_item	2633867	et	4	main
üks	doc_491521502220_item	2633868	et	3	main
keraamika	doc_491521502220_item	2633869	et	4	main
tüüp	doc_491521502220_item	2633870	et	3	main
ekr	doc_491521502220_item	2633874	et	4	main
pool	doc_491521502220_item	2633884	et	4	main
hakati	doc_491521502220_item	2633938	et	3	main
väljas	doc_491521502220_item	2633943	et	4	main
sõltus	doc_491521502220_item	2633946	et	4	main
inimesest	doc_491521502220_item	2633947	et	3	main
austati	doc_491521502220_item	2633948	et	3	main
1	doc_491521502221_item	2633953	et	2	main
mõiste	doc_491521502221_item	2633958	et	4	main
juba	doc_491521502219_item	2633573	et	3	main
väljaspoole	doc_491521502219_item	2633574	et	4	main
surnutele	doc_491521502219_item	2633581	et	4	main
tööriistu	doc_491521502219_item	2633584	et	3	main
uskumused	doc_491521502219_item	2633588	et	3	main
kiviajal	doc_491521502219_item	2633602	et	3	main
kontrolltöö	doc_491521502220_item	2633606	et	4	main
arheoloogiline	doc_491521502220_item	2633617	et	4	main
teatud	doc_491521502220_item	2633619	et	4	main
inimgrupile	doc_491521502220_item	2633620	et	3	main
vaimne	doc_491521502220_item	2633624	et	3	main
käigus	doc_491521502220_item	2633630	et	4	main
igale	doc_491521502220_item	2633631	et	3	main
ajajärk	doc_491521502220_item	2633644	et	3	main
neoliitikumiks	doc_491521502220_item	2633650	et	3	main
väga	doc_491521502220_item	2633654	et	3	main
mingeid	doc_491521502220_item	2633657	et	3	main
õhuke	doc_491521502220_item	2633662	et	4	main
at	doc_491521502220_item	2633673	et	4	main
ekr	doc_491521502220_item	2633675	et	4	main
eesti	doc_491521502220_item	2633677	et	4	main
arvatakse	doc_491521502220_item	2633697	et	3	main
valmistati	doc_491521502220_item	2633710	et	4	main
näoga	doc_491521502220_item	2633731	et	3	main
on	doc_491521502220_item	2633739	et	4	main
mägi	doc_491521502220_item	2633748	et	3	main
soo	doc_491521502220_item	2633750	et	4	main
tagasi	doc_491521502220_item	2633758	et	3	main
pani	doc_491521502220_item	2633759	et	4	main
noorem	doc_491521502220_item	2633764	et	4	main
paikkondlik	doc_491521502220_item	2633783	et	3	main
ajal	doc_491521502220_item	2633789	et	4	main
eesti	doc_491521502220_item	2633791	et	4	main
peal	doc_491521502220_item	2633803	et	4	main
tunnuseks	doc_491521502220_item	2633807	et	3	main
euroopas	doc_491521502220_item	2633825	et	3	main
jämedast	doc_491521502220_item	2633829	et	3	main
isegi	doc_491521502220_item	2633836	et	4	main
ekr	doc_491521502220_item	2633841	et	4	main
kannab	doc_491521502220_item	2633842	et	3	main
tunnus	doc_491521502220_item	2633860	et	3	main
loodusmotiive	doc_491521502220_item	2633861	et	3	main
hilis	doc_491521502220_item	2633864	et	4	main
iii	doc_491521502220_item	2633872	et	4	main
at	doc_491521502220_item	2633873	et	4	main
ii	doc_491521502220_item	2633883	et	4	main
ajal	doc_491521502220_item	2633886	et	4	main
pärast	doc_491521502220_item	2633937	et	4	main
teda	doc_491521502220_item	2633949	et	4	main
või	doc_491521502220_item	2633950	et	4	main
ei	doc_491521502220_item	2633951	et	4	main
siis	doc_491521502221_item	2633972	et	3	main
hakkasid	doc_491521502221_item	2633973	et	4	main
elanud	doc_491521502221_item	2633988	et	4	main
et	doc_491521502221_item	2633994	et	3	main
korjamisega	doc_491521502221_item	2633999	et	4	main
venekirves	doc_491521502221_item	2634021	et	4	main
koos	doc_491521502221_item	2634026	et	4	main
laibaga	doc_491521502221_item	2634027	et	3	main
loomakujukesi	doc_491521502221_item	2634033	et	4	main
religioon	doc_491521502221_item	2634038	et	3	main
veel	doc_491521502221_item	2634041	et	4	main
nii	doc_491521502221_item	2634044	et	3	main
surma	doc_491521502221_item	2634050	et	4	main
on	doc_491521502221_item	2634051	et	4	main
mis	doc_491521502221_item	2634056	et	4	main
ümbritses	doc_491521502221_item	2634057	et	3	main
teda	doc_491521502221_item	2634058	et	4	main
taevast	doc_491521502221_item	2634066	et	4	main
neil	doc_491521502221_item	2634068	et	4	main
2	doc_491521502221_item	2634083	et	2	main
järgi	doc_491521502221_item	2634097	et	4	main
igale	doc_491521502221_item	2634098	et	3	main
kultuurile	doc_491521502221_item	2634099	et	3	main
ajajärg	doc_491521502221_item	2634105	et	3	main
materiaalne	doc_491521502220_item	2633622	et	3	main
arheoloogilise	doc_491521502220_item	2633632	et	4	main
kultuurile	doc_491521502220_item	2633633	et	3	main
sarnased	doc_491521502220_item	2633636	et	4	main
leiud	doc_491521502220_item	2633637	et	3	main
ja	doc_491521502220_item	2633638	et	3	main
muistised	doc_491521502220_item	2633639	et	3	main
ning	doc_491521502220_item	2633640	et	3	main
kindel	doc_491521502220_item	2633641	et	3	main
territoorium	doc_491521502220_item	2633642	et	3	main
mesoliitikumiks	doc_491521502220_item	2633649	et	3	main
avastada	doc_491521502220_item	2633656	et	3	main
peatuspaiku	doc_491521502220_item	2633658	et	3	main
kultuurikiht	doc_491521502220_item	2633660	et	3	main
kaua	doc_491521502220_item	2633663	et	3	main
mandrijää	doc_491521502220_item	2633665	et	4	main
mesoliitikum	doc_491521502220_item	2633666	et	3	main
keskmine	doc_491521502220_item	2633667	et	3	main
kiviaeg	doc_491521502220_item	2633668	et	3	main
ix	doc_491521502220_item	2633669	et	4	main
territooriumil	doc_491521502220_item	2633678	et	3	main
toimus	doc_491521502220_item	2633679	et	3	main
mesoliitikumis	doc_491521502220_item	2633680	et	3	main
kõige	doc_491521502220_item	2633681	et	4	main
vanem	doc_491521502220_item	2633682	et	4	main
asula	doc_491521502220_item	2633683	et	4	main
pulli	doc_491521502220_item	2633684	et	4	main
kütid	doc_491521502220_item	2633685	et	4	main
asub	doc_491521502220_item	2633686	et	3	main
pärnu	doc_491521502220_item	2633687	et	4	main
jõe	doc_491521502220_item	2633688	et	3	main
ääres	doc_491521502220_item	2633689	et	4	main
kunda	doc_491521502220_item	2633690	et	4	main
kultuur	doc_491521502220_item	2633691	et	3	main
on	doc_491521502220_item	2633692	et	4	main
ka	doc_491521502220_item	2633693	et	3	main
väga	doc_491521502220_item	2633694	et	3	main
vana	doc_491521502220_item	2633695	et	4	main
ja	doc_491521502220_item	2633700	et	3	main
kütid	doc_491521502220_item	2633701	et	4	main
poolt	doc_491521502220_item	2633704	et	4	main
ajal	doc_491521502220_item	2633708	et	4	main
tööriistu	doc_491521502220_item	2633709	et	3	main
kivist	doc_491521502220_item	2633712	et	4	main
sõnad	doc_491521502220_item	2633738	et	4	main
meri	doc_491521502220_item	2633747	et	3	main
eesti	doc_491521502220_item	2633761	et	4	main
inimene	doc_491521502220_item	2633766	et	3	main
ja	doc_491521502220_item	2633769	et	3	main
välja	doc_491521502220_item	2633782	et	4	main
sellel	doc_491521502220_item	2633788	et	4	main
narva	doc_491521502220_item	2633826	et	4	main
tehti	doc_491521502220_item	2633828	et	3	main
savist	doc_491521502220_item	2633830	et	4	main
segati	doc_491521502220_item	2633832	et	3	main
kivipudru	doc_491521502220_item	2633833	et	3	main
teokarpe	doc_491521502220_item	2633834	et	4	main
ja	doc_491521502220_item	2633835	et	3	main
at	doc_491521502220_item	2633840	et	4	main
kultuuri	doc_491521502220_item	2633859	et	4	main
nöörkeraamika	doc_491521502220_item	2633871	et	4	main
muster	doc_491521502220_item	2633875	et	3	main
nööri	doc_491521502220_item	2633878	et	4	main
tehtud	doc_491521502220_item	2633880	et	4	main
neoliitikumi	doc_491521502220_item	2633882	et	4	main
sellel	doc_491521502220_item	2633885	et	4	main
magasid	doc_491521502220_item	2633921	et	4	main
tööriistu	doc_491521502220_item	2633924	et	3	main
surmust	doc_491521502220_item	2633925	et	3	main
karti	doc_491521502220_item	2633926	et	4	main
elati	doc_491521502220_item	2633927	et	3	main
35-40	doc_491521502220_item	2633928	et	2	main
aastat	doc_491521502220_item	2633929	et	3	main
maeti	doc_491521502220_item	2633933	et	3	main
inimesi	doc_491521502220_item	2633939	et	4	main
või	doc_491521502220_item	2633942	et	4	main
pool	doc_491521502220_item	2633944	et	4	main
see	doc_491521502220_item	2633945	et	3	main
kontrolltöö	doc_491521502221_item	2633952	et	4	main
kiviaeg	doc_491521502221_item	2633954	et	3	main
eesti	doc_491521502221_item	2633955	et	4	main
9000	doc_491521502221_item	2633969	et	2	main
inimesed	doc_491521502221_item	2633974	et	3	main
elama	doc_491521502221_item	2633976	et	3	main
varasemast	doc_491521502221_item	2633977	et	4	main
kiviajast	doc_491521502221_item	2633978	et	4	main
tegelesid	doc_491521502221_item	2633997	et	4	main
käisid	doc_491521502221_item	2634001	et	4	main
hilisemal	doc_491521502221_item	2634003	et	4	main
sisse	doc_491521502221_item	2634029	et	4	main
ka	doc_491521502221_item	2634036	et	3	main
seda	doc_491521502221_item	2634040	et	3	main
ei	doc_491521502221_item	2634042	et	4	main
tohiks	doc_491521502221_item	2634043	et	3	main
nimetada	doc_491521502221_item	2634045	et	3	main
elus	doc_491521502221_item	2634062	et	4	main
baikaalilt	doc_491521502221_item	2634082	et	4	main
kultuur	doc_491521502221_item	2634092	et	3	main
selgub	doc_491521502221_item	2634094	et	3	main
ja	doc_491521502221_item	2634103	et	3	main
korjamine	doc_491521502220_item	2633726	et	4	main
mesoliitikumi	doc_491521502220_item	2633727	et	4	main
inimene	doc_491521502220_item	2633728	et	3	main
oli	doc_491521502220_item	2633729	et	3	main
kitsa	doc_491521502220_item	2633730	et	3	main
sirgete	doc_491521502220_item	2633732	et	4	main
juustega	doc_491521502220_item	2633733	et	3	main
tumedama	doc_491521502220_item	2633734	et	4	main
hahaga	doc_491521502220_item	2633735	et	3	main
seotud	doc_491521502220_item	2633740	et	4	main
maastiku	doc_491521502220_item	2633741	et	4	main
neem	doc_491521502220_item	2633746	et	3	main
arvatakse	doc_491521502220_item	2633752	et	3	main
kunda	doc_491521502220_item	2633754	et	4	main
kultuur	doc_491521502220_item	2633755	et	3	main
ajaloole	doc_491521502220_item	2633762	et	4	main
neoliitikum	doc_491521502220_item	2633763	et	3	main
neoliitikum	doc_491521502220_item	2633771	et	3	main
küttide	doc_491521502220_item	2633774	et	3	main
ja	doc_491521502220_item	2633775	et	3	main
materiaalne	doc_491521502220_item	2633784	et	3	main
kultuur	doc_491521502220_item	2633787	et	3	main
territooriumile	doc_491521502220_item	2633792	et	3	main
tulema	doc_491521502220_item	2633793	et	4	main
inimesed	doc_491521502220_item	2633795	et	3	main
elamiskohti	doc_491521502220_item	2633796	et	4	main
neoliitikumi	doc_491521502220_item	2633804	et	4	main
kõige	doc_491521502220_item	2633805	et	4	main
keraamika	doc_491521502220_item	2633809	et	4	main
savist	doc_491521502220_item	2633810	et	4	main
nõude	doc_491521502220_item	2633811	et	4	main
tegemine	doc_491521502220_item	2633812	et	4	main
narva	doc_491521502220_item	2633813	et	4	main
keraamika	doc_491521502220_item	2633814	et	4	main
on	doc_491521502220_item	2633815	et	4	main
kõige	doc_491521502220_item	2633816	et	4	main
vanem	doc_491521502220_item	2633817	et	4	main
nii	doc_491521502220_item	2633818	et	3	main
eestis	doc_491521502220_item	2633819	et	3	main
kui	doc_491521502220_item	2633820	et	3	main
ja	doc_491521502220_item	2633823	et	3	main
taimi	doc_491521502220_item	2633837	et	4	main
sest	doc_491521502220_item	2633845	et	4	main
oli	doc_491521502220_item	2633847	et	3	main
kujuline	doc_491521502220_item	2633850	et	4	main
ei	doc_491521502220_item	2633862	et	4	main
neoliitikumis	doc_491521502220_item	2633865	et	3	main
ilmus	doc_491521502220_item	2633866	et	4	main
oli	doc_491521502220_item	2633876	et	3	main
vahendil	doc_491521502220_item	2633879	et	3	main
hilisneoliitikum	doc_491521502220_item	2633881	et	3	main
surnute	doc_491521502220_item	2633930	et	4	main
hoolitseti	doc_491521502220_item	2633932	et	3	main
inimesi	doc_491521502220_item	2633934	et	4	main
püstkoda	doc_491521502220_item	2633935	et	4	main
alla	doc_491521502220_item	2633936	et	3	main
matma	doc_491521502220_item	2633940	et	3	main
2	doc_491521502221_item	2633957	et	2	main
tähendus	doc_491521502221_item	2633961	et	4	main
eesti	doc_491521502221_item	2633966	et	4	main
territoorium	doc_491521502221_item	2633967	et	3	main
umbes	doc_491521502221_item	2633968	et	4	main
on	doc_491521502221_item	2633981	et	4	main
säilinud	doc_491521502221_item	2633983	et	4	main
on	doc_491521502221_item	2633992	et	4	main
teada	doc_491521502221_item	2633993	et	3	main
aluse	doc_491521502220_item	2633760	et	4	main
kiviaeg	doc_491521502220_item	2633765	et	3	main
tarkemaks	doc_491521502220_item	2633768	et	3	main
osalevamaks	doc_491521502220_item	2633770	et	4	main
on	doc_491521502220_item	2633772	et	4	main
kalastajate	doc_491521502220_item	2633773	et	4	main
korilaste	doc_491521502220_item	2633776	et	3	main
õitseaeg	doc_491521502220_item	2633777	et	3	main
eesti	doc_491521502220_item	2633778	et	4	main
territooriumil	doc_491521502220_item	2633779	et	3	main
hakkab	doc_491521502220_item	2633780	et	3	main
kujunema	doc_491521502220_item	2633781	et	3	main
vaimne	doc_491521502220_item	2633786	et	3	main
lõke	doc_491521502220_item	2633802	et	4	main
tähtsamaks	doc_491521502220_item	2633806	et	4	main
venemaal	doc_491521502220_item	2633822	et	4	main
l	doc_491521502220_item	2633824	et	4	main
kammkeraamika	doc_491521502220_item	2633838	et	4	main
sellise	doc_491521502220_item	2633843	et	4	main
esemetel	doc_491521502220_item	2633846	et	3	main
muster	doc_491521502220_item	2633848	et	3	main
kasutatud	doc_491521502220_item	2633863	et	4	main
nagu	doc_491521502220_item	2633877	et	3	main
inimesed	doc_491521502220_item	2633887	et	3	main
kasvatasid	doc_491521502220_item	2633888	et	4	main
loomi	doc_491521502220_item	2633889	et	4	main
veised	doc_491521502220_item	2633890	et	3	main
sead	doc_491521502220_item	2633891	et	4	main
kasvatati	doc_491521502220_item	2633892	et	3	main
neid	doc_491521502220_item	2633893	et	4	main
enda	doc_491521502220_item	2633894	et	4	main
tarbeks	doc_491521502220_item	2633895	et	3	main
on	doc_491521502220_item	2633896	et	4	main
leitud	doc_491521502220_item	2633897	et	4	main
jälge	doc_491521502220_item	2633898	et	4	main
et	doc_491521502220_item	2633899	et	3	main
osati	doc_491521502220_item	2633900	et	3	main
vilja	doc_491521502220_item	2633901	et	4	main
kasvatada	doc_491521502220_item	2633902	et	3	main
sellel	doc_491521502220_item	2633903	et	4	main
ajal	doc_491521502220_item	2633904	et	4	main
tuleb	doc_491521502220_item	2633905	et	3	main
eesti	doc_491521502220_item	2633906	et	4	main
territooriumile	doc_491521502220_item	2633907	et	3	main
uus	doc_491521502220_item	2633908	et	3	main
komme	doc_491521502220_item	2633909	et	4	main
matmiskomme	doc_491521502220_item	2633910	et	4	main
hakati	doc_491521502220_item	2633911	et	3	main
inimesi	doc_491521502220_item	2633912	et	4	main
matma	doc_491521502220_item	2633913	et	3	main
esialgu	doc_491521502220_item	2633914	et	3	main
maeti	doc_491521502220_item	2633915	et	3	main
inimesi	doc_491521502220_item	2633916	et	4	main
nii	doc_491521502220_item	2633917	et	3	main
nagu	doc_491521502220_item	2633918	et	3	main
nad	doc_491521502220_item	2633919	et	3	main
tavaliselt	doc_491521502220_item	2633920	et	4	main
hauda	doc_491521502220_item	2633922	et	4	main
pandi	doc_491521502220_item	2633923	et	4	main
eest	doc_491521502220_item	2633931	et	4	main
asulas	doc_491521502220_item	2633941	et	3	main
territooriumil	doc_491521502221_item	2633956	et	3	main
kultuur	doc_491521502221_item	2633960	et	3	main
1	doc_491521502221_item	2633962	et	2	main
mandrijääst	doc_491521502221_item	2633963	et	3	main
vabanes	doc_491521502221_item	2633964	et	3	main
praeguse	doc_491521502221_item	2633965	et	3	main
tagasi	doc_491521502221_item	2633971	et	3	main
territooriumil	doc_491521502221_item	2633980	et	3	main
ühes	doc_491521502221_item	2633989	et	4	main
kohas	doc_491521502221_item	2633990	et	4	main
kaua	doc_491521502221_item	2633991	et	3	main
kalapüügiga	doc_491521502221_item	2633998	et	3	main
jahil	doc_491521502221_item	2634002	et	3	main
kiviajal	doc_491521502221_item	2634004	et	3	main
ka	doc_491521502221_item	2634008	et	3	main
tööriistad	doc_491521502221_item	2634009	et	3	main
keraamika	doc_491521502221_item	2634010	et	4	main
umbes	doc_491521502221_item	2634011	et	4	main
iv	doc_491521502221_item	2634012	et	4	main
aastatuhandel	doc_491521502221_item	2634013	et	4	main
ilmus	doc_491521502221_item	2634014	et	4	main
kammkeraamika	doc_491521502221_item	2634015	et	4	main
hiljem	doc_491521502221_item	2634016	et	3	main
aastatuhandel	doc_491521502221_item	2634018	et	4	main
iii	doc_491521502221_item	2634017	et	4	main
nöörkeraamika	doc_491521502221_item	2634019	et	4	main
ja	doc_491521502221_item	2634020	et	3	main
maa	doc_491521502221_item	2634024	et	4	main
sisse	doc_491521502221_item	2634025	et	4	main
hauda	doc_491521502221_item	2634028	et	4	main
muidugi	doc_491521502221_item	2634034	et	4	main
oli	doc_491521502221_item	2634035	et	3	main
inimesed	doc_491521502221_item	2634046	et	3	main
et	doc_491521502221_item	2634048	et	3	main
surnul	doc_491521502221_item	2634052	et	4	main
kui	doc_491521502221_item	2634059	et	3	main
ta	doc_491521502221_item	2634060	et	4	main
oli	doc_491521502221_item	2634061	et	3	main
jälgisid	doc_491521502221_item	2634065	et	4	main
kas	doc_491521502221_item	2634067	et	3	main
õnenstub	doc_491521502221_item	2634069	et	4	main
jaht	doc_491521502221_item	2634070	et	3	main
või	doc_491521502221_item	2634071	et	4	main
ei	doc_491521502221_item	2634072	et	4	main
eesti	doc_491521502221_item	2634078	et	4	main
territooriumile	doc_491521502221_item	2634079	et	3	main
volgalt	doc_491521502221_item	2634080	et	4	main
ja	doc_491521502221_item	2634081	et	3	main
teatud	doc_491521502221_item	2634086	et	4	main
omane	doc_491521502221_item	2634088	et	3	main
ja	doc_491521502221_item	2634090	et	3	main
omased	doc_491521502221_item	2634100	et	3	main
mõisted	doc_491521502221_item	2634102	et	3	main
arheoloogiline	doc_491521502221_item	2633959	et	4	main
aastat	doc_491521502221_item	2633970	et	3	main
siin	doc_491521502221_item	2633975	et	4	main
eesti	doc_491521502221_item	2633979	et	4	main
vähe	doc_491521502221_item	2633982	et	3	main
ilmselt	doc_491521502221_item	2633984	et	4	main
sellepärast	doc_491521502221_item	2633985	et	3	main
et	doc_491521502221_item	2633986	et	3	main
ei	doc_491521502221_item	2633987	et	4	main
meie	doc_491521502221_item	2633995	et	4	main
eesvanemad	doc_491521502221_item	2633996	et	4	main
ja	doc_491521502221_item	2634000	et	3	main
on	doc_491521502221_item	2634005	et	4	main
juba	doc_491521502221_item	2634006	et	3	main
ilmunud	doc_491521502221_item	2634007	et	4	main
inimesi	doc_491521502221_item	2634022	et	4	main
oma	doc_491521502221_item	2634037	et	4	main
pärast	doc_491521502221_item	2634049	et	4	main
asju	doc_491521502221_item	2634055	et	3	main
nad	doc_491521502221_item	2634064	et	3	main
jne	doc_491521502221_item	2634073	et	4	main
arvatavasti	doc_491521502221_item	2634074	et	3	main
baltimaade	doc_491521502221_item	2634075	et	3	main
hõimud	doc_491521502221_item	2634076	et	4	main
tulid	doc_491521502221_item	2634077	et	4	main
kultuur	doc_491521502221_item	2634085	et	3	main
moraalne	doc_491521502221_item	2634091	et	3	main
mis	doc_491521502221_item	2634093	et	4	main
sarnased	doc_491521502221_item	2634101	et	4	main
territoorium	doc_491521502221_item	2634106	et	3	main
maeti	doc_491521502221_item	2634023	et	3	main
pandi	doc_491521502221_item	2634030	et	4	main
tööriistu	doc_491521502221_item	2634031	et	3	main
ehti	doc_491521502221_item	2634032	et	4	main
kuigi	doc_491521502221_item	2634039	et	3	main
uskusid	doc_491521502221_item	2634047	et	4	main
vaja	doc_491521502221_item	2634053	et	4	main
neid	doc_491521502221_item	2634054	et	4	main
smmuti	doc_491521502221_item	2634063	et	4	main
arheoloogiline	doc_491521502221_item	2634084	et	4	main
inimgruppile	doc_491521502221_item	2634087	et	4	main
materiaalne	doc_491521502221_item	2634089	et	3	main
arheoloogiliste	doc_491521502221_item	2634095	et	4	main
leidude	doc_491521502221_item	2634096	et	4	main
leiud	doc_491521502221_item	2634104	et	3	main
kontrolltöö	doc_491521502224_item	2634714	et	4	main
ehk	doc_491521502224_item	2634727	et	3	main
siin	doc_491521502224_item	2634739	et	4	main
ei	doc_491521502224_item	2634748	et	4	main
pärnu	doc_491521502224_item	2634773	et	4	main
jõe	doc_491521502224_item	2634774	et	3	main
ehk	doc_491521502224_item	2634784	et	3	main
ääres	doc_491521502224_item	2634822	et	4	main
elati	doc_491521502224_item	2634823	et	3	main
kogukondades	doc_491521502224_item	2634826	et	3	main
vilja	doc_491521502224_item	2634832	et	4	main
sead	doc_491521502224_item	2634840	et	4	main
kultuur	doc_491521502224_item	2634850	et	3	main
taimi	doc_491521502224_item	2634858	et	4	main
ema	doc_491521502224_item	2634863	et	4	main
tekkis	doc_491521502224_item	2634864	et	3	main
tõid	doc_491521502224_item	2634871	et	4	main
soome-ugri	doc_491521502224_item	2634877	et	3	main
relvad	doc_491521502224_item	2634912	et	3	main
vere	doc_491521502224_item	2634915	et	3	main
elu	doc_491521502224_item	2634917	et	4	main
piiresse	doc_491521502224_item	2634921	et	3	main
väljaspoole	doc_491521502224_item	2634931	et	4	main
asulat	doc_491521502224_item	2634932	et	3	main
hakati	doc_491521502224_item	2634934	et	3	main
kiviajal	doc_491521502224_item	2634726	et	3	main
toimunud	doc_491521502224_item	2634730	et	4	main
eesti	doc_491521502224_item	2634731	et	4	main
aladel	doc_491521502224_item	2634732	et	3	main
kui	doc_491521502224_item	2634738	et	3	main
kütid	doc_491521502224_item	2634741	et	4	main
siis	doc_491521502224_item	2634743	et	3	main
nende	doc_491521502224_item	2634744	et	4	main
lühiajalisi	doc_491521502224_item	2634745	et	4	main
peatus	doc_491521502224_item	2634746	et	4	main
ole	doc_491521502224_item	2634749	et	4	main
kultuurikiht	doc_491521502224_item	2634753	et	3	main
liiga	doc_491521502224_item	2634755	et	4	main
õhuke	doc_491521502224_item	2634756	et	4	main
paiksemad	doc_491521502224_item	2634761	et	4	main
kiviajal	doc_491521502224_item	2634764	et	3	main
mesoliitikumis	doc_491521502224_item	2634766	et	3	main
kala	doc_491521502224_item	2634781	et	4	main
noorem	doc_491521502224_item	2634782	et	4	main
kiviaeg	doc_491521502224_item	2634783	et	3	main
ja	doc_491521502224_item	2634788	et	3	main
muutus	doc_491521502224_item	2634828	et	4	main
tähistab	doc_491521502224_item	2634846	et	3	main
narva	doc_491521502224_item	2634849	et	4	main
savist	doc_491521502224_item	2634852	et	4	main
kivipuru	doc_491521502224_item	2634859	et	4	main
u	doc_491521502224_item	2634860	et	4	main
kammkeraamikakultuur	doc_491521502224_item	2634865	et	4	main
kaunistati	doc_491521502224_item	2634867	et	4	main
selle	doc_491521502224_item	2634870	et	4	main
iii	doc_491521502224_item	2634880	et	4	main
at	doc_491521502224_item	2634881	et	4	main
maeti	doc_491521502224_item	2634909	et	3	main
hauapanustega	doc_491521502224_item	2634911	et	3	main
ooker	doc_491521502224_item	2634914	et	3	main
vahel	doc_491521502224_item	2634922	et	4	main
püstkodade	doc_491521502224_item	2634924	et	3	main
austama	doc_491521502224_item	2634937	et	3	main
kiviaeg	doc_491521502224_item	2634716	et	3	main
mõiste	doc_491521502224_item	2634720	et	4	main
arheoloogiline	doc_491521502224_item	2634721	et	4	main
1	doc_491521502224_item	2634724	et	2	main
sest	doc_491521502224_item	2634734	et	4	main
käisid	doc_491521502224_item	2634742	et	4	main
võimalik	doc_491521502224_item	2634750	et	3	main
eesti	doc_491521502224_item	2634757	et	4	main
aladel	doc_491521502224_item	2634758	et	3	main
e	doc_491521502224_item	2634765	et	4	main
at	doc_491521502224_item	2634769	et	4	main
ema	doc_491521502224_item	2634770	et	4	main
neoliitikum	doc_491521502224_item	2634785	et	3	main
territooriumil	doc_491521502224_item	2634718	et	3	main
1	doc_491521502224_item	2634715	et	2	main
eesti	doc_491521502224_item	2634717	et	4	main
2	doc_491521502224_item	2634719	et	2	main
paleoliitikumis	doc_491521502224_item	2634728	et	3	main
siin	doc_491521502224_item	2634735	et	4	main
oli	doc_491521502224_item	2634736	et	3	main
jääaeg	doc_491521502224_item	2634737	et	3	main
paiku	doc_491521502224_item	2634747	et	4	main
esimesed	doc_491521502224_item	2634760	et	3	main
keskmisel	doc_491521502224_item	2634763	et	3	main
kuni	doc_491521502224_item	2634767	et	3	main
ääres	doc_491521502224_item	2634775	et	4	main
tegeldi	doc_491521502224_item	2634776	et	3	main
küttimise	doc_491521502224_item	2634777	et	4	main
korilusega	doc_491521502224_item	2634779	et	4	main
püüti	doc_491521502224_item	2634780	et	3	main
oli	doc_491521502224_item	2634786	et	3	main
korilaste	doc_491521502224_item	2634789	et	3	main
kultuur	doc_491521502224_item	2634722	et	3	main
tähendus	doc_491521502224_item	2634723	et	4	main
vanemal	doc_491521502224_item	2634725	et	4	main
ei	doc_491521502224_item	2634729	et	4	main
midagi	doc_491521502224_item	2634733	et	4	main
ka	doc_491521502224_item	2634740	et	3	main
avastada	doc_491521502224_item	2634751	et	3	main
sest	doc_491521502224_item	2634752	et	4	main
on	doc_491521502224_item	2634754	et	4	main
tekkisid	doc_491521502224_item	2634759	et	4	main
inimasutused	doc_491521502224_item	2634762	et	4	main
iv	doc_491521502224_item	2634768	et	4	main
pulli	doc_491521502224_item	2634771	et	4	main
asula	doc_491521502224_item	2634772	et	4	main
ja	doc_491521502224_item	2634778	et	3	main
küttide	doc_491521502224_item	2634787	et	3	main
õitseaeg	doc_491521502224_item	2634790	et	3	main
tehti	doc_491521502224_item	2634792	et	3	main
luust	doc_491521502224_item	2634794	et	4	main
kivist	doc_491521502224_item	2634793	et	4	main
puidust	doc_491521502224_item	2634795	et	3	main
väiksemad	doc_491521502224_item	2634796	et	4	main
asjad	doc_491521502224_item	2634797	et	3	main
elati	doc_491521502224_item	2634799	et	3	main
püstkodades	doc_491521502224_item	2634800	et	3	main
mille	doc_491521502224_item	2634801	et	3	main
keskel	doc_491521502224_item	2634802	et	3	main
oli	doc_491521502224_item	2634803	et	3	main
tulekivist	doc_491521502224_item	2634798	et	4	main
tulekolle	doc_491521502224_item	2634804	et	4	main
u	doc_491521502224_item	2634805	et	4	main
23	doc_491521502224_item	2634806	et	2	main
kojast	doc_491521502224_item	2634807	et	3	main
oli	doc_491521502224_item	2634808	et	3	main
mõeldud	doc_491521502224_item	2634809	et	4	main
suitsu	doc_491521502224_item	2634810	et	4	main
jaoks	doc_491521502224_item	2634811	et	4	main
koda	doc_491521502224_item	2634812	et	4	main
ehitati	doc_491521502224_item	2634813	et	3	main
roigastest	doc_491521502224_item	2634814	et	3	main
kaeti	doc_491521502224_item	2634815	et	4	main
sambla	doc_491521502224_item	2634816	et	3	main
ja	doc_491521502224_item	2634817	et	3	main
loomanahkadega	doc_491521502224_item	2634818	et	3	main
asutused	doc_491521502224_item	2634819	et	4	main
paiknesid	doc_491521502224_item	2634820	et	4	main
20-40	doc_491521502224_item	2634824	et	2	main
paiksemaks	doc_491521502224_item	2634829	et	4	main
lambad	doc_491521502224_item	2634839	et	3	main
hobused	doc_491521502224_item	2634842	et	4	main
jämedast	doc_491521502224_item	2634851	et	3	main
kammitaolise	doc_491521502224_item	2634868	et	4	main
tööriistad	doc_491521502224_item	2634791	et	3	main
kaupa	doc_491521502224_item	2634825	et	4	main
ka	doc_491521502224_item	2634834	et	3	main
kasutusele	doc_491521502224_item	2634843	et	4	main
tuli	doc_491521502224_item	2634844	et	4	main
keraamika	doc_491521502224_item	2634845	et	4	main
algust	doc_491521502224_item	2634848	et	4	main
potid	doc_491521502224_item	2634853	et	4	main
segati	doc_491521502224_item	2634856	et	3	main
teokarpe	doc_491521502224_item	2634857	et	4	main
iv	doc_491521502224_item	2634861	et	4	main
at	doc_491521502224_item	2634862	et	4	main
siia	doc_491521502224_item	2634872	et	4	main
arvatavasti	doc_491521502224_item	2634873	et	3	main
ida	doc_491521502224_item	2634874	et	4	main
hõimud	doc_491521502224_item	2634878	et	4	main
koos	doc_491521502224_item	2634910	et	4	main
sümbol	doc_491521502224_item	2634918	et	3	main
ka	doc_491521502224_item	2634923	et	3	main
hilisema	doc_491521502224_item	2634926	et	4	main
matma	doc_491521502224_item	2634930	et	3	main
maha	doc_491521502224_item	2634958	et	4	main
põletati	doc_491521502224_item	2634959	et	3	main
kui	doc_491521502224_item	2634964	et	3	main
edasi	doc_491521502224_item	2634968	et	3	main
luustikud	doc_491521502224_item	2634976	et	3	main
kindlat	doc_491521502224_item	2634981	et	3	main
ja	doc_491521502224_item	2634983	et	3	main
kontrolltöö	doc_491521502225_item	2634985	et	4	main
missugused	doc_491521502225_item	2634987	et	3	main
näiliselt	doc_491521502225_item	2635022	et	4	main
paranes	doc_491521502225_item	2635023	et	3	main
ei	doc_491521502225_item	2635033	et	4	main
levis	doc_491521502225_item	2635041	et	4	main
läänelik	doc_491521502225_item	2635042	et	4	main
uudised	doc_491521502225_item	2635046	et	3	main
maailma	doc_491521502225_item	2635050	et	4	main
tunnetamine	doc_491521502225_item	2635051	et	4	main
ja	doc_491521502225_item	2635052	et	3	main
silmaring	doc_491521502225_item	2635053	et	3	main
oli	doc_491521502225_item	2635054	et	3	main
praami-	doc_491521502225_item	2635065	et	4	main
georg	doc_491521502225_item	2635068	et	4	main
välismaist	doc_491521502225_item	2635074	et	4	main
hotelli	doc_491521502225_item	2635081	et	4	main
tegutses	doc_491521502225_item	2635083	et	3	main
looming	doc_491521502225_item	2635088	et	3	main
tegurid	doc_491521502225_item	2635094	et	3	main
kultuuri	doc_491521502225_item	2635101	et	4	main
entel-tentel	doc_491521502225_item	2635106	et	4	main
raklaamfilm	doc_491521502225_item	2635127	et	4	main
ilmus	doc_491521502225_item	2635130	et	4	main
vaadati	doc_491521502225_item	2635139	et	3	main
enammeeldinud	doc_491521502225_item	2635154	et	3	main
sai	doc_491521502225_item	2635157	et	4	main
haaletada	doc_491521502225_item	2635158	et	4	main
saates	doc_491521502225_item	2635159	et	4	main
stuudiosse	doc_491521502225_item	2635160	et	3	main
kajastav	doc_491521502225_item	2635188	et	4	main
tsükkel	doc_491521502225_item	2635195	et	3	main
aastat	doc_491521502225_item	2635198	et	3	main
ajalehti	doc_491521502225_item	2635203	et	4	main
raamatuid	doc_491521502225_item	2635205	et	3	main
olid	doc_491521502225_item	2635209	et	4	main
kaljo	doc_491521502225_item	2635234	et	4	main
libahunt	doc_491521502225_item	2635238	et	3	main
ja	doc_491521502225_item	2635239	et	3	main
olid	doc_491521502225_item	2635245	et	4	main
nsv	doc_491521502225_item	2635251	et	4	main
tolle	doc_491521502225_item	2635261	et	4	main
lemmikuteks	doc_491521502225_item	2635263	et	4	main
kross	doc_491521502225_item	2635268	et	3	main
disidentide	doc_491521502225_item	2635270	et	4	main
aktiivne	doc_491521502225_item	2635271	et	3	main
2	doc_491521502225_item	2635273	et	2	main
arvan	doc_491521502225_item	2635274	et	3	main
ajaloodokument	doc_491521502225_item	2635284	et	3	main
puhas	doc_491521502225_item	2635287	et	3	main
kuuluvad	doc_491521502225_item	2635293	et	4	main
aja	doc_491521502225_item	2635295	et	4	main
filmid	doc_491521502225_item	2635296	et	4	main
mageveehoogude	doc_491521502224_item	2634821	et	3	main
asutus	doc_491521502224_item	2634827	et	4	main
hakati	doc_491521502224_item	2634830	et	3	main
kasvatama	doc_491521502224_item	2634831	et	4	main
hiljem	doc_491521502224_item	2634833	et	3	main
loomi	doc_491521502224_item	2634835	et	4	main
oder	doc_491521502224_item	2634836	et	3	main
hernes	doc_491521502224_item	2634837	et	4	main
uba	doc_491521502224_item	2634838	et	4	main
kitsed	doc_491521502224_item	2634841	et	3	main
neoliitikumi	doc_491521502224_item	2634847	et	4	main
savi	doc_491521502224_item	2634854	et	4	main
sisse	doc_491521502224_item	2634855	et	4	main
savipotte	doc_491521502224_item	2634866	et	3	main
esemega	doc_491521502224_item	2634869	et	3	main
ema	doc_491521502224_item	2634882	et	4	main
venekirve	doc_491521502224_item	2634883	et	3	main
ehk	doc_491521502224_item	2634884	et	3	main
ka	doc_491521502224_item	2634885	et	3	main
nöörkeraamikakultuur	doc_491521502224_item	2634886	et	4	main
mille	doc_491521502224_item	2634887	et	3	main
tõid	doc_491521502224_item	2634888	et	4	main
siia	doc_491521502224_item	2634889	et	4	main
lõuna	doc_491521502224_item	2634890	et	4	main
poolt	doc_491521502224_item	2634891	et	4	main
sisserännanud	doc_491521502224_item	2634892	et	4	main
kes	doc_491521502224_item	2634893	et	4	main
kasvatasid	doc_491521502224_item	2634894	et	4	main
ka	doc_491521502224_item	2634895	et	3	main
eelpool	doc_491521502224_item	2634896	et	4	main
nimed	doc_491521502224_item	2634897	et	3	main
koduloomi	doc_491521502224_item	2634898	et	4	main
nöörkeraamika	doc_491521502224_item	2634899	et	4	main
nöörijäljendid	doc_491521502224_item	2634900	et	3	main
pottidel	doc_491521502224_item	2634901	et	3	main
venekirved	doc_491521502224_item	2634902	et	3	main
vene	doc_491521502224_item	2634903	et	4	main
kujulise	doc_491521502224_item	2634904	et	4	main
peaga	doc_491521502224_item	2634906	et	3	main
kirved	doc_491521502224_item	2634907	et	3	main
surnud	doc_491521502224_item	2634908	et	4	main
kivist	doc_491521502224_item	2634905	et	4	main
poolt	doc_491521502224_item	2634875	et	4	main
sisserännanud	doc_491521502224_item	2634876	et	4	main
u	doc_491521502224_item	2634879	et	4	main
asula	doc_491521502224_item	2634920	et	4	main
ehted	doc_491521502224_item	2634913	et	3	main
ja	doc_491521502224_item	2634916	et	3	main
algselt	doc_491521502224_item	2634919	et	4	main
hakati	doc_491521502224_item	2634929	et	3	main
surnuid	doc_491521502224_item	2634933	et	4	main
kartma	doc_491521502224_item	2634935	et	3	main
ja	doc_491521502224_item	2634936	et	3	main
sarnased	doc_491521502224_item	2634946	et	4	main
oli	doc_491521502224_item	2634949	et	3	main
aastat	doc_491521502224_item	2634951	et	3	main
kogukonnad	doc_491521502224_item	2634953	et	4	main
tegeldi	doc_491521502224_item	2634954	et	3	main
puud	doc_491521502224_item	2634956	et	4	main
üles	doc_491521502224_item	2634963	et	3	main
liiguti	doc_491521502224_item	2634967	et	4	main
2	doc_491521502224_item	2634969	et	2	main
kultuur	doc_491521502224_item	2634971	et	3	main
väljakaevamistel	doc_491521502224_item	2634973	et	3	main
jt	doc_491521502224_item	2634977	et	4	main
jäänused	doc_491521502224_item	2634979	et	3	main
tegurid	doc_491521502225_item	2634989	et	3	main
põhjust	doc_491521502225_item	2634992	et	4	main
kulmkapid	doc_491521502225_item	2635021	et	4	main
majanduslik	doc_491521502225_item	2635025	et	3	main
riietusmood	doc_491521502225_item	2635043	et	3	main
tanu	doc_491521502225_item	2635056	et	4	main
ja	doc_491521502225_item	2635066	et	3	main
ots	doc_491521502225_item	2635069	et	3	main
saadi	doc_491521502225_item	2635071	et	4	main
lapstähtede	doc_491521502225_item	2635102	et	4	main
laulukonkurssedel	doc_491521502225_item	2635105	et	4	main
takti	doc_491521502225_item	2635108	et	4	main
nsv	doc_491521502225_item	2635118	et	4	main
teleekraanidel	doc_491521502225_item	2635121	et	3	main
esimene	doc_491521502225_item	2635123	et	3	main
eesti	doc_491521502225_item	2635126	et	4	main
koomiksiraamat	doc_491521502225_item	2635132	et	3	main
eesti	doc_491521502225_item	2635133	et	4	main
tuli	doc_491521502225_item	2635135	et	4	main
uus	doc_491521502225_item	2635136	et	3	main
ja	doc_491521502225_item	2635140	et	3	main
esimene	doc_491521502225_item	2635162	et	3	main
interaktiivne	doc_491521502225_item	2635163	et	3	main
hakati	doc_491521502225_item	2635165	et	3	main
sarjast	doc_491521502225_item	2635190	et	4	main
panti	doc_491521502225_item	2635193	et	4	main
täna	doc_491521502225_item	2635196	et	4	main
loeti	doc_491521502225_item	2635200	et	3	main
tegutsesid	doc_491521502225_item	2635206	et	4	main
täheldada	doc_491521502225_item	2635219	et	3	main
alla	doc_491521502224_item	2634925	et	3	main
neoliitikumi	doc_491521502224_item	2634927	et	4	main
ajal	doc_491521502224_item	2634928	et	4	main
välja	doc_491521502224_item	2634943	et	4	main
kujunema	doc_491521502224_item	2634944	et	3	main
piirkonniti	doc_491521502224_item	2634945	et	3	main
eluiga	doc_491521502224_item	2634948	et	4	main
alepõllundusega	doc_491521502224_item	2634955	et	3	main
võeti	doc_491521502224_item	2634957	et	3	main
maa	doc_491521502224_item	2634961	et	4	main
arheoloogiline	doc_491521502224_item	2634970	et	4	main
leitud	doc_491521502224_item	2634974	et	4	main
tähistavad	doc_491521502224_item	2634980	et	4	main
andsid	doc_491521502225_item	2634990	et	4	main
nsvl	doc_491521502225_item	2634997	et	4	main
lähisvälismaana	doc_491521502225_item	2634998	et	3	main
2	doc_491521502225_item	2634999	et	2	main
l	doc_491521502225_item	2635000	et	4	main
laiuse	doc_491521502225_item	2635001	et	4	main
mängufilm	doc_491521502225_item	2635002	et	3	main
libahunt	doc_491521502225_item	2635003	et	3	main
kas	doc_491521502225_item	2635004	et	3	main
teie	doc_491521502225_item	2635005	et	4	main
arvates	doc_491521502225_item	2635006	et	4	main
ajaloodokument	doc_491521502225_item	2635007	et	3	main
või	doc_491521502225_item	2635008	et	4	main
ühiskonnakriitika	doc_491521502225_item	2635009	et	4	main
miks	doc_491521502225_item	2635010	et	4	main
majanduslikud	doc_491521502225_item	2635012	et	3	main
tegurid	doc_491521502225_item	2635013	et	3	main
paljusid	doc_491521502225_item	2635014	et	3	main
1	doc_491521502225_item	2635011	et	2	main
kaupu	doc_491521502225_item	2635015	et	3	main
sai	doc_491521502225_item	2635016	et	4	main
osatu	doc_491521502225_item	2635017	et	4	main
järelmaksuga	doc_491521502225_item	2635018	et	3	main
autod	doc_491521502225_item	2635019	et	3	main
vaibad	doc_491521502225_item	2635020	et	3	main
tekkis	doc_491521502224_item	2634938	et	3	main
hauatagusest	doc_491521502224_item	2634940	et	3	main
tavad	doc_491521502224_item	2634947	et	3	main
30-40	doc_491521502224_item	2634950	et	2	main
patriarhaalsed	doc_491521502224_item	2634952	et	3	main
künti	doc_491521502224_item	2634962	et	3	main
väsis	doc_491521502224_item	2634966	et	3	main
esemed	doc_491521502224_item	2634975	et	3	main
piirkonda	doc_491521502224_item	2634982	et	4	main
ajastut	doc_491521502224_item	2634984	et	3	main
1	doc_491521502225_item	2634986	et	2	main
majanduslikud-kultuurilised	doc_491521502225_item	2634988	et	4	main
1970ndatel	doc_491521502225_item	2634991	et	4	main
eesti	doc_491521502225_item	2634993	et	4	main
nsvl	doc_491521502225_item	2634994	et	4	main
tunda	doc_491521502225_item	2634995	et	3	main
korterit	doc_491521502225_item	2635032	et	3	main
oodata	doc_491521502225_item	2635036	et	4	main
soome	doc_491521502225_item	2635038	et	3	main
inimeste	doc_491521502225_item	2635049	et	3	main
sellele	doc_491521502225_item	2635057	et	4	main
õpiti	doc_491521502225_item	2635058	et	3	main
ka	doc_491521502225_item	2635059	et	3	main
aktiivselt	doc_491521502225_item	2635062	et	4	main
viru	doc_491521502225_item	2635080	et	4	main
uku	doc_491521502225_item	2635084	et	4	main
rahvakunsti	doc_491521502225_item	2635085	et	4	main
peamiselt	doc_491521502225_item	2635090	et	4	main
kultuurilised	doc_491521502225_item	2635093	et	4	main
televisioonis	doc_491521502225_item	2635096	et	4	main
esinemine	doc_491521502225_item	2635103	et	4	main
ette	doc_491521502225_item	2635109	et	4	main
mis	doc_491521502225_item	2635110	et	4	main
algul	doc_491521502225_item	2635115	et	4	main
eesti	doc_491521502225_item	2635120	et	4	main
ettekujutus	doc_491521502224_item	2634939	et	4	main
elust	doc_491521502224_item	2634941	et	3	main
hakkasid	doc_491521502224_item	2634942	et	4	main
ja	doc_491521502224_item	2634960	et	3	main
maa	doc_491521502224_item	2634965	et	4	main
arheoloogilistel	doc_491521502224_item	2634972	et	4	main
inimtegevuse	doc_491521502224_item	2634978	et	4	main
end	doc_491521502225_item	2634996	et	4	main
massiliselt	doc_491521502225_item	2635027	et	4	main
ehitama	doc_491521502225_item	2635029	et	4	main
individuaalmaju	doc_491521502225_item	2635030	et	3	main
kuna	doc_491521502225_item	2635031	et	3	main
järjekorras	doc_491521502225_item	2635035	et	3	main
laiem	doc_491521502225_item	2635055	et	4	main
keelt	doc_491521502225_item	2635061	et	4	main
tegutses	doc_491521502225_item	2635063	et	3	main
tallinn-helsinki	doc_491521502225_item	2635064	et	4	main
väljavahetamise	doc_491521502225_item	2635072	et	3	main
teel	doc_491521502225_item	2635073	et	4	main
kaupa	doc_491521502225_item	2635075	et	4	main
kangaid	doc_491521502225_item	2635076	et	3	main
eriti	doc_491521502225_item	2635077	et	3	main
aktiivselt	doc_491521502225_item	2635078	et	4	main
kaubeldi	doc_491521502225_item	2635079	et	3	main
juures	doc_491521502225_item	2635082	et	4	main
kelle	doc_491521502225_item	2635087	et	4	main
läks	doc_491521502225_item	2635089	et	3	main
eesti	doc_491521502225_item	2635095	et	4	main
etv	doc_491521502225_item	2635097	et	4	main
oli	doc_491521502225_item	2635098	et	3	main
margata	doc_491521502225_item	2635099	et	3	main
laste	doc_491521502225_item	2635104	et	4	main
isegi	doc_491521502225_item	2635116	et	4	main
taunitav	doc_491521502225_item	2635117	et	4	main
tegutses	doc_491521502225_item	2635125	et	3	main
1973	doc_491521502225_item	2635128	et	2	main
aastal	doc_491521502225_item	2635129	et	3	main
esimene	doc_491521502225_item	2635131	et	3	main
mälumäng	doc_491521502225_item	2635138	et	3	main
võeti	doc_491521502225_item	2635141	et	3	main
osa	doc_491521502225_item	2635143	et	4	main
samanimelistest	doc_491521502225_item	2635144	et	4	main
saadetest	doc_491521502225_item	2635145	et	3	main
saade	doc_491521502225_item	2635151	et	4	main
horoskoop	doc_491521502225_item	2635152	et	3	main
kus	doc_491521502225_item	2635153	et	3	main
postkaarti	doc_491521502225_item	2635161	et	4	main
koosnev	doc_491521502225_item	2635191	et	4	main
veldo	doc_491521502225_item	2635192	et	4	main
palju	doc_491521502225_item	2635202	et	4	main
külalisteatrid	doc_491521502225_item	2635207	et	3	main
lastele	doc_491521502225_item	2635208	et	4	main
eesti	doc_491521502225_item	2635221	et	4	main
tihengut	doc_491521502225_item	2635223	et	4	main
astusid	doc_491521502225_item	2635226	et	4	main
ette	doc_491521502225_item	2635227	et	4	main
uued	doc_491521502225_item	2635228	et	3	main
ja	doc_491521502225_item	2635233	et	3	main
kõrboja	doc_491521502225_item	2635240	et	4	main
kinokunsti	doc_491521502225_item	2635243	et	4	main
viljelejad	doc_491521502225_item	2635244	et	4	main
väljas	doc_491521502225_item	2635249	et	4	main
j	doc_491521502225_item	2635267	et	4	main
tegevus	doc_491521502225_item	2635272	et	4	main
et	doc_491521502225_item	2635275	et	3	main
saa	doc_491521502225_item	2635277	et	4	main
kindlalt	doc_491521502225_item	2635279	et	4	main
kas	doc_491521502225_item	2635280	et	3	main
minu	doc_491521502225_item	2635289	et	3	main
tolle	doc_491521502225_item	2635294	et	4	main
kõik	doc_491521502225_item	2635297	et	4	main
vähegi	doc_491521502225_item	2635300	et	4	main
vabad	doc_491521502225_item	2635303	et	3	main
ajaloodokumentide	doc_491521502225_item	2635304	et	3	main
hulka	doc_491521502225_item	2635305	et	4	main
16	doc_491521502225_item	2635312	et	2	main
inimeste	doc_491521502225_item	2635314	et	3	main
riietust	doc_491521502225_item	2635315	et	4	main
mina	doc_491521502225_item	2635334	et	4	main
oli	doc_491521502225_item	2635350	et	3	main
otsas	doc_491521502225_item	2635351	et	4	main
inimeste	doc_491521502225_item	2635024	et	3	main
heaolu	doc_491521502225_item	2635026	et	4	main
hakati	doc_491521502225_item	2635028	et	3	main
jõutud	doc_491521502225_item	2635034	et	4	main
vaadeti	doc_491521502225_item	2635037	et	4	main
tekevisiooni	doc_491521502225_item	2635039	et	4	main
kust	doc_491521502225_item	2635040	et	4	main
mõtteviis	doc_491521502225_item	2635044	et	3	main
lääne	doc_491521502225_item	2635045	et	4	main
filmid	doc_491521502225_item	2635047	et	4	main
saadet	doc_491521502225_item	2635048	et	3	main
soome	doc_491521502225_item	2635060	et	3	main
laevaliin	doc_491521502225_item	2635067	et	3	main
turistidelt	doc_491521502225_item	2635070	et	3	main
selt	doc_491521502225_item	2635086	et	3	main
suviniiridena	doc_491521502225_item	2635091	et	4	main
läände	doc_491521502225_item	2635092	et	3	main
läänelikku	doc_491521502225_item	2635100	et	4	main
kaks	doc_491521502225_item	2635107	et	3	main
oli	doc_491521502225_item	2635111	et	3	main
väga	doc_491521502225_item	2635112	et	3	main
uudne	doc_491521502225_item	2635113	et	3	main
ning	doc_491521502225_item	2635114	et	3	main
liidus	doc_491521502225_item	2635119	et	4	main
reklaam	doc_491521502225_item	2635124	et	3	main
keelde	doc_491521502225_item	2635134	et	4	main
sõna	doc_491521502225_item	2635137	et	4	main
populaarne	doc_491521502225_item	2635147	et	3	main
ainulaadne	doc_491521502225_item	2635149	et	3	main
laulu	doc_491521502225_item	2635155	et	4	main
eest	doc_491521502225_item	2635156	et	4	main
mäng	doc_491521502225_item	2635164	et	3	main
saadete	doc_491521502225_item	2635194	et	3	main
mõeldud	doc_491521502225_item	2635210	et	4	main
leiesi	doc_491521502225_item	2635212	et	4	main
saated	doc_491521502225_item	2635213	et	3	main
ja	doc_491521502225_item	2635215	et	3	main
jt	doc_491521502225_item	2635217	et	4	main
ka	doc_491521502225_item	2635220	et	3	main
multifilmi	doc_491521502225_item	2635222	et	4	main
hullumeelsus	doc_491521502225_item	2635224	et	4	main
kinokunstis	doc_491521502225_item	2635225	et	3	main
kaljo	doc_491521502225_item	2635231	et	4	main
leida	doc_491521502225_item	2635236	et	3	main
peremees	doc_491521502225_item	2635241	et	4	main
need	doc_491521502225_item	2635242	et	3	main
ideedega	doc_491521502225_item	2635248	et	3	main
kogu	doc_491521502225_item	2635250	et	4	main
eriti	doc_491521502225_item	2635260	et	3	main
aja	doc_491521502225_item	2635262	et	4	main
olid	doc_491521502225_item	2635264	et	4	main
mast	doc_491521502225_item	2635265	et	3	main
ta	doc_491521502225_item	2635281	et	4	main
oli	doc_491521502225_item	2635282	et	3	main
üksnes	doc_491521502225_item	2635283	et	3	main
ühiskonnakriitika	doc_491521502225_item	2635288	et	4	main
kindlasti	doc_491521502225_item	2635292	et	3	main
mis	doc_491521502225_item	2635299	et	4	main
oskuslikult	doc_491521502225_item	2635308	et	4	main
näidatud	doc_491521502225_item	2635311	et	4	main
ja	doc_491521502225_item	2635321	et	3	main
filmis	doc_491521502225_item	2635324	et	4	main
ärakasutatud	doc_491521502225_item	2635325	et	4	main
vanaaegsete	doc_491521502225_item	2635326	et	4	main
muusikariistade	doc_491521502225_item	2635327	et	3	main
silmaga	doc_491521502225_item	2635340	et	3	main
nähtavat	doc_491521502225_item	2635341	et	4	main
kui	doc_491521502225_item	2635348	et	3	main
ning	doc_491521502225_item	2635352	et	3	main
ma	doc_491521502225_item	2635353	et	3	main
selliselt	doc_491521502225_item	2635365	et	4	main
riiuli	doc_491521502225_item	2635372	et	3	main
ning	doc_491521502225_item	2635383	et	3	main
jääda	doc_491521502225_item	2635385	et	4	main
iseendaks	doc_491521502225_item	2635386	et	3	main
polnud	doc_491521502225_item	2635387	et	3	main
kuidagi	doc_491521502225_item	2635388	et	3	main
kooskõlas	doc_491521502225_item	2635389	et	3	main
inimesest	doc_491521502225_item	2635393	et	3	main
l	doc_491521502226_item	2635424	et	4	main
kas	doc_491521502226_item	2635428	et	3	main
ajaloodokument	doc_491521502226_item	2635431	et	3	main
ilmus	doc_491521502225_item	2635122	et	4	main
aktiivselt	doc_491521502225_item	2635142	et	4	main
eriti	doc_491521502225_item	2635146	et	3	main
ja	doc_491521502225_item	2635148	et	3	main
oli	doc_491521502225_item	2635150	et	3	main
produteerima	doc_491521502225_item	2635166	et	4	main
ka	doc_491521502225_item	2635167	et	3	main
inimesi	doc_491521502225_item	2635168	et	4	main
harivaid	doc_491521502225_item	2635169	et	4	main
saa	doc_491521502225_item	2635170	et	4	main
п	doc_491521502225_item	2635171	et	2	main
eid	doc_491521502225_item	2635172	et	4	main
nagu	doc_491521502225_item	2635173	et	3	main
igasugused	doc_491521502225_item	2635174	et	3	main
telekoolid	doc_491521502225_item	2635175	et	3	main
näidati	doc_491521502225_item	2635176	et	3	main
ka	doc_491521502225_item	2635177	et	3	main
tõsielusarju	doc_491521502225_item	2635178	et	3	main
seebikad9	doc_491521502225_item	2635180	et	4	main
üsna	doc_491521502225_item	2635181	et	3	main
uudne	doc_491521502225_item	2635182	et	3	main
tänapäeva	doc_491521502225_item	2635179	et	4	main
oli	doc_491521502225_item	2635183	et	3	main
ka	doc_491521502225_item	2635184	et	3	main
ms	doc_491521502225_item	2635186	et	4	main
ii	doc_491521502225_item	2635185	et	4	main
sündmusi	doc_491521502225_item	2635187	et	3	main
mitmest	doc_491521502225_item	2635189	et	4	main
25	doc_491521502225_item	2635197	et	2	main
tagasi	doc_491521502225_item	2635199	et	3	main
väga	doc_491521502225_item	2635201	et	3	main
ja	doc_491521502225_item	2635204	et	3	main
uno	doc_491521502225_item	2635211	et	4	main
tipp	doc_491521502225_item	2635214	et	3	main
täpp	doc_491521502225_item	2635216	et	3	main
sai	doc_491521502225_item	2635218	et	4	main
nagu	doc_491521502225_item	2635230	et	3	main
komissarov	doc_491521502225_item	2635235	et	4	main
laius	doc_491521502225_item	2635237	et	4	main
ei	doc_491521502225_item	2635276	et	4	main
väita	doc_491521502225_item	2635278	et	4	main
siis	doc_491521502225_item	2635286	et	3	main
et	doc_491521502225_item	2635291	et	3	main
eranditult	doc_491521502225_item	2635298	et	4	main
tõetruul	doc_491521502225_item	2635310	et	3	main
oskuslikult	doc_491521502225_item	2635323	et	4	main
kõla	doc_491521502225_item	2635328	et	4	main
tekitab	doc_491521502225_item	2635329	et	3	main
filmile	doc_491521502225_item	2635330	et	3	main
kostüüme	doc_491521502225_item	2635343	et	3	main
näitemängu	doc_491521502225_item	2635344	et	4	main
siis	doc_491521502225_item	2635347	et	3	main
tundus	doc_491521502225_item	2635359	et	3	main
et	doc_491521502225_item	2635362	et	3	main
tõe	doc_491521502225_item	2635363	et	4	main
poolest	doc_491521502225_item	2635364	et	4	main
tollases	doc_491521502225_item	2635369	et	3	main
lina	doc_491521502225_item	2635373	et	4	main
tiina	doc_491521502225_item	2635375	et	4	main
tugev	doc_491521502225_item	2635376	et	4	main
jõuline	doc_491521502225_item	2635377	et	4	main
karakter	doc_491521502225_item	2635378	et	3	main
sotsialistliku	doc_491521502225_item	2635390	et	3	main
inimese	doc_491521502225_item	2635394	et	4	main
ennast	doc_491521502225_item	2635397	et	4	main
nsvl	doc_491521502226_item	2635421	et	4	main
libahunt	doc_491521502226_item	2635427	et	3	main
teie	doc_491521502226_item	2635429	et	4	main
baltiest	doc_491521502226_item	2635443	et	4	main
tööstuse	doc_491521502226_item	2635460	et	3	main
võimalus	doc_491521502226_item	2635463	et	3	main
turistidega	doc_491521502226_item	2635465	et	3	main
bej	doc_491521502226_item	2635475	et	4	main
saadavad	doc_491521502226_item	2635482	et	4	main
kultuur	doc_491521502226_item	2635498	et	3	main
ehitatakse	doc_491521502226_item	2635504	et	3	main
filmitegemisele	doc_491521502226_item	2635512	et	3	main
rohkem	doc_491521502226_item	2635516	et	4	main
tsensuuri	doc_491521502226_item	2635524	et	4	main
tase	doc_491521502226_item	2635525	et	3	main
lubatud	doc_491521502226_item	2635527	et	4	main
kritiseerida	doc_491521502226_item	2635528	et	3	main
stalinismi	doc_491521502226_item	2635529	et	4	main
võimalus	doc_491521502226_item	2635530	et	3	main
kirjandusteostega	doc_491521502226_item	2635534	et	3	main
nt	doc_491521502226_item	2635541	et	4	main
professionaalsetele	doc_491521502226_item	2635545	et	4	main
ühingutele	doc_491521502226_item	2635546	et	3	main
kunstnikute	doc_491521502226_item	2635548	et	4	main
esimene	doc_491521502226_item	2635562	et	3	main
oli	doc_491521502226_item	2635570	et	3	main
seetõttu	doc_491521502226_item	2635611	et	3	main
oma	doc_491521502226_item	2635614	et	4	main
eesti	doc_491521502226_item	2635625	et	4	main
kultuur	doc_491521502226_item	2635632	et	3	main
sotsialistlik	doc_491521502226_item	2635635	et	3	main
aga	doc_491521502226_item	2635636	et	3	main
vahend	doc_491521502226_item	2635637	et	3	main
kokkutulek	doc_491521502226_item	2635644	et	3	main
2	doc_491521502226_item	2635671	et	2	main
võib	doc_491521502226_item	2635673	et	3	main
kahte	doc_491521502226_item	2635675	et	4	main
moodi	doc_491521502226_item	2635676	et	4	main
rohkem	doc_491521502226_item	2635681	et	4	main
paralleel	doc_491521502226_item	2635684	et	3	main
sama	doc_491521502226_item	2635696	et	4	main
värk	doc_491521502226_item	2635697	et	3	main
keegi	doc_491521502226_item	2635699	et	4	main
tegijad	doc_491521502225_item	2635229	et	4	main
kiisk	doc_491521502225_item	2635232	et	3	main
väga	doc_491521502225_item	2635246	et	3	main
novaatorlikku	doc_491521502225_item	2635247	et	4	main
liidus	doc_491521502225_item	2635252	et	4	main
loeti	doc_491521502225_item	2635253	et	3	main
luulet	doc_491521502225_item	2635255	et	3	main
eestlane	doc_491521502225_item	2635256	et	3	main
rohkem	doc_491521502225_item	2635254	et	4	main
keskendus	doc_491521502225_item	2635257	et	4	main
aga	doc_491521502225_item	2635258	et	3	main
proosale	doc_491521502225_item	2635259	et	3	main
troot	doc_491521502225_item	2635266	et	4	main
eesti	doc_491521502225_item	2635269	et	4	main
või	doc_491521502225_item	2635285	et	4	main
mõtlen	doc_491521502225_item	2635290	et	3	main
poliitilisest	doc_491521502225_item	2635301	et	3	main
propagandast	doc_491521502225_item	2635302	et	4	main
ja	doc_491521502225_item	2635309	et	3	main
saj	doc_491521502225_item	2635313	et	4	main
kombeid	doc_491521502225_item	2635316	et	4	main
aga	doc_491521502225_item	2635317	et	3	main
ka	doc_491521502225_item	2635318	et	3	main
hirme	doc_491521502225_item	2635322	et	3	main
vaadates	doc_491521502225_item	2635335	et	3	main
seda	doc_491521502225_item	2635336	et	3	main
filmi	doc_491521502225_item	2635337	et	4	main
jälgisin	doc_491521502225_item	2635338	et	3	main
pigem	doc_491521502225_item	2635339	et	3	main
kombeid	doc_491521502225_item	2635345	et	4	main
ainult	doc_491521502225_item	2635346	et	4	main
mulle	doc_491521502225_item	2635360	et	4	main
siiski	doc_491521502225_item	2635361	et	4	main
püüd	doc_491521502225_item	2635379	et	4	main
vaba	doc_491521502225_item	2635382	et	4	main
soov	doc_491521502225_item	2635384	et	3	main
realismi	doc_491521502225_item	2635391	et	4	main
nägemusega	doc_491521502225_item	2635392	et	3	main
vastanduda	doc_491521502225_item	2635396	et	3	main
lähisvälismaana	doc_491521502226_item	2635422	et	3	main
1	doc_491521502226_item	2635435	et	2	main
majanduslikud	doc_491521502226_item	2635436	et	3	main
sissetulek	doc_491521502226_item	2635445	et	3	main
vähemus	doc_491521502226_item	2635448	et	4	main
rahva	doc_491521502226_item	2635450	et	3	main
elutase	doc_491521502226_item	2635451	et	3	main
kompleks	doc_491521502226_item	2635461	et	4	main
avatud	doc_491521502226_item	2635466	et	4	main
omamine	doc_491521502226_item	2635472	et	4	main
eej	doc_491521502226_item	2635476	et	4	main
välismaa	doc_491521502226_item	2635478	et	4	main
mõned	doc_491521502226_item	2635483	et	3	main
toodangud	doc_491521502226_item	2635485	et	3	main
olema	doc_491521502226_item	2635493	et	4	main
eeskuju	doc_491521502226_item	2635494	et	4	main
külade	doc_491521502226_item	2635499	et	3	main
kinni	doc_491521502226_item	2635502	et	3	main
kinomajasi	doc_491521502226_item	2635505	et	4	main
estonia	doc_491521502226_item	2635507	et	4	main
sotskiituslikele	doc_491521502226_item	2635514	et	4	main
rahva	doc_491521502226_item	2635522	et	3	main
välismaa	doc_491521502226_item	2635533	et	4	main
mõned	doc_491521502226_item	2635535	et	3	main
jne	doc_491521502226_item	2635550	et	4	main
koorid	doc_491521502226_item	2635551	et	4	main
elustasid	doc_491521502226_item	2635552	et	4	main
rahva	doc_491521502226_item	2635553	et	3	main
traditsioone	doc_491521502226_item	2635554	et	3	main
soome-ugri	doc_491521502226_item	2635555	et	3	main
rahva	doc_491521502226_item	2635556	et	3	main
prof	doc_491521502226_item	2635563	et	4	main
kontekst	doc_491521502226_item	2635569	et	3	main
peidetud	doc_491521502226_item	2635572	et	4	main
on	doc_491521502226_item	2635608	et	4	main
kollektsiooni	doc_491521502226_item	2635619	et	4	main
hinnad	doc_491521502226_item	2635620	et	3	main
plakati	doc_491521502226_item	2635624	et	3	main
kuni	doc_491521502226_item	2635626	et	3	main
kabinetidest	doc_491521502226_item	2635631	et	3	main
xix	doc_491521502226_item	2635642	et	4	main
kp	doc_491521502226_item	2635643	et	4	main
hoogu	doc_491521502226_item	2635650	et	4	main
edasi	doc_491521502226_item	2635652	et	3	main
rohkem	doc_491521502226_item	2635666	et	4	main
käsitleda	doc_491521502226_item	2635674	et	3	main
on	doc_491521502226_item	2635680	et	4	main
ühiskonnakriitika	doc_491521502226_item	2635682	et	4	main
1947	doc_491521502226_item	2635698	et	2	main
midagi	doc_491521502226_item	2635700	et	4	main
teab	doc_491521502226_item	2635701	et	3	main
naabrist	doc_491521502226_item	2635702	et	3	main
külla	doc_491521502226_item	2635707	et	4	main
rohkem	doc_491521502226_item	2635710	et	4	main
filmis	doc_491521502225_item	2635306	et	4	main
on	doc_491521502225_item	2635307	et	4	main
suhtumist	doc_491521502225_item	2635319	et	4	main
hoiakuid	doc_491521502225_item	2635320	et	3	main
mingi	doc_491521502225_item	2635331	et	4	main
müstilise	doc_491521502225_item	2635332	et	3	main
varjundi	doc_491521502225_item	2635333	et	3	main
poolt	doc_491521502225_item	2635342	et	4	main
film	doc_491521502225_item	2635349	et	3	main
pikemalt	doc_491521502225_item	2635355	et	4	main
asjade	doc_491521502225_item	2635356	et	3	main
üle	doc_491521502225_item	2635357	et	3	main
sotsia	doc_491521502225_item	2635370	et	4	main
ühiskonnas	doc_491521502225_item	2635371	et	4	main
teoseks	doc_491521502225_item	2635374	et	4	main
olla	doc_491521502225_item	2635380	et	3	main
püüd	doc_491521502225_item	2635395	et	4	main
hallile	doc_491521502225_item	2635398	et	4	main
alluvale	doc_491521502225_item	2635400	et	4	main
karjainstinktile	doc_491521502225_item	2635399	et	3	main
massile	doc_491521502225_item	2635401	et	3	main
oli	doc_491521502225_item	2635402	et	3	main
lugu	doc_491521502225_item	2635403	et	4	main
julge	doc_491521502225_item	2635404	et	4	main
ühiskonna	doc_491521502225_item	2635405	et	4	main
kriitika	doc_491521502225_item	2635406	et	4	main
lausa	doc_491521502225_item	2635407	et	4	main
väljakutse	doc_491521502225_item	2635408	et	4	main
kontrolltöö	doc_491521502226_item	2635409	et	4	main
1	doc_491521502226_item	2635410	et	2	main
missugused	doc_491521502226_item	2635411	et	3	main
majanduslikud-kultuurilised	doc_491521502226_item	2635412	et	4	main
tegurid	doc_491521502226_item	2635413	et	3	main
andsid	doc_491521502226_item	2635414	et	4	main
1970ndatel	doc_491521502226_item	2635415	et	4	main
põhjust	doc_491521502226_item	2635416	et	4	main
eesti	doc_491521502226_item	2635417	et	4	main
nsvl	doc_491521502226_item	2635418	et	4	main
tunda	doc_491521502226_item	2635419	et	3	main
end	doc_491521502226_item	2635420	et	4	main
2	doc_491521502226_item	2635423	et	2	main
sain	doc_491521502225_item	2635354	et	3	main
mõelda	doc_491521502225_item	2635358	et	4	main
ülesehitatud	doc_491521502225_item	2635366	et	4	main
film	doc_491521502225_item	2635367	et	3	main
sai	doc_491521502225_item	2635368	et	4	main
eelarvamustest	doc_491521502225_item	2635381	et	4	main
mängufilm	doc_491521502226_item	2635426	et	3	main
arvates	doc_491521502226_item	2635430	et	4	main
või	doc_491521502226_item	2635432	et	4	main
ühiskonnakriitika	doc_491521502226_item	2635433	et	4	main
elektrijaam	doc_491521502226_item	2635442	et	3	main
elektritööstuse	doc_491521502226_item	2635471	et	3	main
saamine	doc_491521502226_item	2635480	et	4	main
välismaa	doc_491521502226_item	2635484	et	4	main
eesti	doc_491521502226_item	2635486	et	4	main
nsvl	doc_491521502226_item	2635487	et	4	main
nõukogude	doc_491521502226_item	2635488	et	3	main
liidu	doc_491521502226_item	2635489	et	3	main
vitriin	doc_491521502226_item	2635490	et	3	main
arenenud	doc_491521502226_item	2635496	et	4	main
algus	doc_491521502226_item	2635510	et	4	main
filmidele	doc_491521502226_item	2635515	et	3	main
tähelepanu	doc_491521502226_item	2635517	et	4	main
rahvaliku	doc_491521502226_item	2635518	et	3	main
kultuurile	doc_491521502226_item	2635519	et	3	main
laiuse	doc_491521502226_item	2635425	et	4	main
miks	doc_491521502226_item	2635434	et	4	main
faktorid	doc_491521502226_item	2635437	et	3	main
kerkisid	doc_491521502226_item	2635438	et	4	main
suuremad	doc_491521502226_item	2635439	et	4	main
tööstus	doc_491521502226_item	2635440	et	3	main
eestlasi	doc_491521502226_item	2635447	et	3	main
kõrgem	doc_491521502226_item	2635449	et	4	main
tehnoloogiate	doc_491521502226_item	2635456	et	3	main
kasutamine	doc_491521502226_item	2635457	et	4	main
eriti	doc_491521502226_item	2635458	et	3	main
sõja	doc_491521502226_item	2635459	et	3	main
keemia	doc_491521502226_item	2635462	et	4	main
kontakteerida	doc_491521502226_item	2635464	et	4	main
ühelt	doc_491521502226_item	2635467	et	3	main
poolt	doc_491521502226_item	2635468	et	4	main
suur	doc_491521502226_item	2635473	et	3	main
tej	doc_491521502226_item	2635477	et	4	main
toodete	doc_491521502226_item	2635479	et	3	main
oli	doc_491521502226_item	2635481	et	3	main
siin	doc_491521502226_item	2635491	et	4	main
pidi	doc_491521502226_item	2635492	et	4	main
liitlsetele	doc_491521502226_item	2635497	et	4	main
kultuurimajad	doc_491521502226_item	2635500	et	4	main
kosmos	doc_491521502226_item	2635506	et	3	main
natsionaalsele	doc_491521502226_item	2635511	et	3	main
alternatiiv	doc_491521502226_item	2635513	et	3	main
püütakse	doc_491521502226_item	2635520	et	3	main
taastada	doc_491521502226_item	2635521	et	3	main
kultuuri	doc_491521502226_item	2635523	et	4	main
nõrgenemine	doc_491521502226_item	2635526	et	4	main
lubatud	doc_491521502226_item	2635532	et	4	main
olid	doc_491521502226_item	2635537	et	4	main
välja	doc_491521502226_item	2635540	et	4	main
shakespeare	doc_491521502226_item	2635542	et	4	main
algus	doc_491521502226_item	2635544	et	4	main
laulud	doc_491521502226_item	2635557	et	3	main
lavastused	doc_491521502226_item	2635565	et	4	main
rohkem	doc_491521502226_item	2635567	et	4	main
politiseeritud	doc_491521502226_item	2635568	et	4	main
vähem	doc_491521502226_item	2635571	et	4	main
avatud	doc_491521502226_item	2635573	et	4	main
rohkem	doc_491521502226_item	2635574	et	4	main
raamatukogusi	doc_491521502226_item	2635575	et	3	main
erinevad	doc_491521502226_item	2635609	et	4	main
luua	doc_491521502226_item	2635617	et	4	main
balti	doc_491521502226_item	2635441	et	3	main
tööjõu	doc_491521502226_item	2635444	et	3	main
linnas	doc_491521502226_item	2635446	et	4	main
võrreldes	doc_491521502226_item	2635452	et	3	main
teistega	doc_491521502226_item	2635453	et	4	main
liitlastega	doc_491521502226_item	2635454	et	3	main
kõrgemate	doc_491521502226_item	2635455	et	4	main
piir	doc_491521502226_item	2635469	et	3	main
võimas	doc_491521502226_item	2635470	et	4	main
elektritööstus	doc_491521502226_item	2635474	et	3	main
vähem	doc_491521502226_item	2635495	et	4	main
pannakse	doc_491521502226_item	2635501	et	3	main
edukalt	doc_491521502226_item	2635503	et	4	main
zveždotška	doc_491521502226_item	2635508	et	2	main
pandud	doc_491521502226_item	2635509	et	4	main
keeldureast	doc_491521502226_item	2635538	et	4	main
võetud	doc_491521502226_item	2635539	et	4	main
eesti	doc_491521502226_item	2635547	et	4	main
ühing	doc_491521502226_item	2635549	et	3	main
tegutsema	doc_491521502226_item	2635559	et	3	main
bändid	doc_491521502226_item	2635560	et	4	main
bänd	doc_491521502226_item	2635564	et	3	main
igaüks	doc_491521502226_item	2635612	et	3	main
võimalustega	doc_491521502226_item	2635615	et	3	main
100	doc_491521502226_item	2635622	et	2	main
kultuur	doc_491521502226_item	2635646	et	3	main
oli	doc_491521502226_item	2635647	et	3	main
mis	doc_491521502226_item	2635651	et	4	main
ühenenud	doc_491521502226_item	2635667	et	4	main
lihtne	doc_491521502226_item	2635683	et	3	main
süžeest	doc_491521502226_item	2635685	et	2	main
tütarlaps	doc_491521502226_item	2635686	et	4	main
nimetab	doc_491521502226_item	2635687	et	3	main
teist	doc_491521502226_item	2635688	et	4	main
libahundiks	doc_491521502226_item	2635689	et	3	main
ja	doc_491521502226_item	2635690	et	3	main
kõik	doc_491521502226_item	2635691	et	4	main
seda	doc_491521502226_item	2635692	et	3	main
usuvad	doc_491521502226_item	2635693	et	3	main
nõukogude	doc_491521502226_item	2635694	et	3	main
liit	doc_491521502226_item	2635695	et	3	main
ja	doc_491521502226_item	2635703	et	3	main
aga	doc_491521502226_item	2635708	et	3	main
mõlemas	doc_491521502226_item	2635713	et	3	main
lihtsalt	doc_491521502226_item	2635718	et	4	main
sotsialismi	doc_491521502226_item	2635734	et	4	main
pooldaja	doc_491521502226_item	2635735	et	4	main
tunne	doc_491521502226_item	2635745	et	4	main
kriitika	doc_491521502226_item	2635752	et	4	main
oli	doc_491521502226_item	2635759	et	3	main
kosmopolit	doc_491521502226_item	2635762	et	4	main
kõik	doc_491521502226_item	2635767	et	4	main
hindan	doc_491521502226_item	2635793	et	3	main
teeb	doc_491521502226_item	2635828	et	3	main
sama	doc_491521502226_item	2635833	et	4	main
1970ndatel	doc_491521502227_item	2635840	et	4	main
l	doc_491521502227_item	2635849	et	4	main
või	doc_491521502227_item	2635857	et	4	main
et	doc_491521502227_item	2635862	et	3	main
ajaloodokument	doc_491521502227_item	2635866	et	3	main
mängufilm	doc_491521502227_item	2635870	et	3	main
sajandeid	doc_491521502227_item	2635873	et	3	main
kuidas	doc_491521502227_item	2635880	et	3	main
elasid	doc_491521502227_item	2635884	et	4	main
töid	doc_491521502227_item	2635891	et	3	main
ajaloodokument	doc_491521502227_item	2635898	et	3	main
võib	doc_491521502227_item	2635900	et	3	main
inimesed	doc_491521502227_item	2635911	et	3	main
see	doc_491521502227_item	2635924	et	3	main
aktiivselt	doc_491521502227_item	2635935	et	4	main
põlevkivi	doc_491521502227_item	2635936	et	4	main
heal	doc_491521502227_item	2635943	et	3	main
tohtinud	doc_491521502227_item	2635947	et	4	main
eestis	doc_491521502227_item	2635963	et	3	main
kasvatatud	doc_491521502227_item	2635964	et	4	main
on	doc_491521502227_item	2635966	et	4	main
olnud	doc_491521502227_item	2635969	et	4	main
oli	doc_491521502227_item	2635971	et	3	main
müüdi	doc_491521502227_item	2635975	et	4	main
järele	doc_491521502227_item	2635981	et	4	main
väga	doc_491521502227_item	2635983	et	3	main
tutvuda	doc_491521502226_item	2635531	et	3	main
autorid	doc_491521502226_item	2635536	et	3	main
pandud	doc_491521502226_item	2635543	et	4	main
hakkasid	doc_491521502226_item	2635558	et	4	main
kukerpillid	doc_491521502226_item	2635561	et	3	main
olid	doc_491521502226_item	2635566	et	4	main
laiem	doc_491521502226_item	2635576	et	4	main
valik	doc_491521502226_item	2635577	et	3	main
hariduse	doc_491521502226_item	2635578	et	3	main
tase	doc_491521502226_item	2635579	et	3	main
kõrg	doc_491521502226_item	2635580	et	4	main
langes	doc_491521502226_item	2635581	et	4	main
õppejõud	doc_491521502226_item	2635582	et	4	main
ei	doc_491521502226_item	2635583	et	4	main
vastanud	doc_491521502226_item	2635584	et	4	main
nõud	doc_491521502226_item	2635585	et	3	main
suurem	doc_491521502226_item	2635586	et	4	main
huvi	doc_491521502226_item	2635587	et	4	main
proosa	doc_491521502226_item	2635588	et	4	main
ja	doc_491521502226_item	2635589	et	3	main
novelli	doc_491521502226_item	2635590	et	4	main
vastu	doc_491521502226_item	2635591	et	3	main
hakkab	doc_491521502226_item	2635592	et	3	main
kerkima	doc_491521502226_item	2635593	et	3	main
avangardism	doc_491521502226_item	2635594	et	3	main
ühine	doc_491521502226_item	2635595	et	4	main
tegevussuund	doc_491521502226_item	2635596	et	3	main
sotsrealism	doc_491521502226_item	2635597	et	3	main
tänapäeval	doc_491521502226_item	2635598	et	3	main
saksamaa	doc_491521502226_item	2635599	et	4	main
oksjonid	doc_491521502226_item	2635600	et	3	main
tunnevad	doc_491521502226_item	2635601	et	3	main
eriti	doc_491521502226_item	2635602	et	3	main
huvi	doc_491521502226_item	2635603	et	4	main
sotsrealismi	doc_491521502226_item	2635604	et	4	main
maalide	doc_491521502226_item	2635605	et	3	main
vastu	doc_491521502226_item	2635606	et	3	main
hinnad	doc_491521502226_item	2635607	et	3	main
ja	doc_491521502226_item	2635610	et	3	main
arvestades	doc_491521502226_item	2635613	et	3	main
võib	doc_491521502226_item	2635616	et	3	main
oma	doc_491521502226_item	2635618	et	4	main
kõikuvad	doc_491521502226_item	2635621	et	4	main
eurot	doc_491521502226_item	2635623	et	3	main
poole	doc_491521502226_item	2635627	et	4	main
miljonini	doc_491521502226_item	2635628	et	3	main
esemed	doc_491521502226_item	2635629	et	3	main
olema	doc_491521502226_item	2635634	et	4	main
natsionaalne	doc_491521502226_item	2635638	et	3	main
kultuurist	doc_491521502226_item	2635641	et	3	main
igatahes	doc_491521502226_item	2635645	et	3	main
saanud	doc_491521502226_item	2635648	et	4	main
ühine	doc_491521502226_item	2635669	et	4	main
minu	doc_491521502226_item	2635677	et	3	main
meelest	doc_491521502226_item	2635678	et	4	main
see	doc_491521502226_item	2635679	et	3	main
siber	doc_491521502226_item	2635705	et	4	main
pööravad	doc_491521502226_item	2635719	et	4	main
poole	doc_491521502226_item	2635722	et	4	main
kui	doc_491521502226_item	2635723	et	3	main
kes	doc_491521502226_item	2635732	et	4	main
pole	doc_491521502226_item	2635733	et	3	main
siin	doc_491521502226_item	2635742	et	4	main
mõjus	doc_491521502226_item	2635743	et	4	main
julgeoleku	doc_491521502226_item	2635744	et	3	main
ühiskonnakriitikat	doc_491521502226_item	2635750	et	3	main
libahunt	doc_491521502226_item	2635757	et	3	main
kauge	doc_491521502226_item	2635760	et	4	main
päev	doc_491521502226_item	2635764	et	3	main
meie	doc_491521502226_item	2635770	et	4	main
suunatakse	doc_491521502226_item	2635772	et	4	main
ja	doc_491521502226_item	2635774	et	3	main
mingi	doc_491521502226_item	2635776	et	4	main
see	doc_491521502226_item	2635789	et	3	main
nagu	doc_491521502226_item	2635796	et	3	main
valitsev	doc_491521502226_item	2635824	et	4	main
lõpu	doc_491521502226_item	2635829	et	3	main
1	doc_491521502227_item	2635835	et	2	main
majanduslikud-kultuurilised	doc_491521502227_item	2635837	et	4	main
põhjust	doc_491521502227_item	2635841	et	4	main
mängufilm	doc_491521502227_item	2635851	et	3	main
teie	doc_491521502227_item	2635854	et	4	main
2	doc_491521502227_item	2635860	et	2	main
libahunt	doc_491521502227_item	2635863	et	3	main
kui	doc_491521502227_item	2635867	et	3	main
kajastab	doc_491521502227_item	2635871	et	3	main
ja	doc_491521502227_item	2635875	et	3	main
ülevaate	doc_491521502227_item	2635879	et	4	main
ajal	doc_491521502227_item	2635883	et	4	main
oli	doc_491521502227_item	2635888	et	3	main
selle	doc_491521502227_item	2635894	et	4	main
on	doc_491521502227_item	2635896	et	4	main
nimetada	doc_491521502227_item	2635902	et	3	main
ühiskonnakriitikaks	doc_491521502227_item	2635904	et	3	main
kuidas	doc_491521502227_item	2635910	et	3	main
oli	doc_491521502227_item	2635915	et	3	main
kritiseetitakse	doc_491521502227_item	2635917	et	4	main
parteisekretäride	doc_491521502226_item	2635630	et	3	main
peab	doc_491521502226_item	2635633	et	4	main
staalin	doc_491521502226_item	2635639	et	4	main
mõtted	doc_491521502226_item	2635640	et	3	main
uut	doc_491521502226_item	2635649	et	3	main
pani	doc_491521502226_item	2635653	et	4	main
inimesi	doc_491521502226_item	2635654	et	4	main
mõtlema	doc_491521502226_item	2635655	et	3	main
ja	doc_491521502226_item	2635656	et	3	main
võitlema	doc_491521502226_item	2635657	et	3	main
oma	doc_491521502226_item	2635658	et	4	main
vabaduse	doc_491521502226_item	2635659	et	4	main
eest	doc_491521502226_item	2635660	et	4	main
mitte	doc_491521502226_item	2635661	et	3	main
miski	doc_491521502226_item	2635662	et	4	main
ei	doc_491521502226_item	2635663	et	4	main
tee	doc_491521502226_item	2635664	et	4	main
inimest	doc_491521502226_item	2635665	et	3	main
kui	doc_491521502226_item	2635668	et	3	main
kultuur	doc_491521502226_item	2635670	et	3	main
seda	doc_491521502226_item	2635672	et	3	main
ootab	doc_491521502226_item	2635706	et	3	main
kõik	doc_491521502226_item	2635717	et	4	main
mis	doc_491521502226_item	2635747	et	4	main
tekistabki	doc_491521502226_item	2635749	et	4	main
võib	doc_491521502226_item	2635753	et	3	main
mitmel	doc_491521502226_item	2635755	et	4	main
ebakompetentne	doc_491521502226_item	2635769	et	3	main
õigesti	doc_491521502226_item	2635773	et	3	main
tekib	doc_491521502226_item	2635775	et	3	main
tõestamatu	doc_491521502226_item	2635777	et	4	main
faktidega	doc_491521502226_item	2635778	et	3	main
kartmine	doc_491521502226_item	2635779	et	4	main
ühiskonda	doc_491521502226_item	2635782	et	4	main
ei	doc_491521502226_item	2635785	et	4	main
märka	doc_491521502226_item	2635786	et	4	main
miks	doc_491521502226_item	2635787	et	4	main
mina	doc_491521502226_item	2635792	et	4	main
seda	doc_491521502226_item	2635794	et	3	main
juba	doc_491521502226_item	2635823	et	3	main
muidugi	doc_491521502226_item	2635827	et	4	main
see	doc_491521502226_item	2635832	et	3	main
andsid	doc_491521502227_item	2635839	et	4	main
tunda	doc_491521502227_item	2635844	et	3	main
nsvl	doc_491521502227_item	2635846	et	4	main
lähisvälismaana	doc_491521502227_item	2635847	et	3	main
libahunt	doc_491521502227_item	2635852	et	3	main
arvates	doc_491521502227_item	2635855	et	4	main
miks	doc_491521502227_item	2635859	et	4	main
arvan	doc_491521502227_item	2635861	et	3	main
nii	doc_491521502227_item	2635865	et	3	main
see	doc_491521502227_item	2635869	et	3	main
tagasi	doc_491521502227_item	2635874	et	3	main
hea	doc_491521502227_item	2635878	et	4	main
kuidas	doc_491521502227_item	2635887	et	3	main
elukorraldus	doc_491521502227_item	2635889	et	3	main
pärast	doc_491521502227_item	2635895	et	4	main
samas	doc_491521502227_item	2635899	et	4	main
põhiideeks	doc_491521502227_item	2635907	et	3	main
näidata	doc_491521502227_item	2635909	et	4	main
suhtused	doc_491521502227_item	2635912	et	4	main
kellessegi	doc_491521502227_item	2635913	et	4	main
ja	doc_491521502227_item	2635921	et	3	main
nimetada	doc_491521502227_item	2635927	et	3	main
ka	doc_491521502227_item	2635929	et	3	main
1	doc_491521502227_item	2635931	et	2	main
1970ndatel	doc_491521502227_item	2635933	et	4	main
tegeleti	doc_491521502227_item	2635934	et	3	main
majanduslikult	doc_491521502227_item	2635941	et	4	main
suhteliselt	doc_491521502227_item	2635942	et	4	main
olla	doc_491521502227_item	2635950	et	3	main
ikkagi	doc_491521502227_item	2635956	et	4	main
seletus	doc_491521502227_item	2635958	et	4	main
müüa	doc_491521502227_item	2635962	et	3	main
alati	doc_491521502227_item	2635967	et	4	main
70ndatel	doc_491521502227_item	2635973	et	4	main
ning	doc_491521502227_item	2635978	et	3	main
vilja	doc_491521502227_item	2635980	et	4	main
eestis	doc_491521502227_item	2635985	et	3	main
mis	doc_491521502227_item	2635989	et	4	main
mujal	doc_491521502227_item	2635991	et	3	main
nsvls	doc_491521502227_item	2635992	et	4	main
mõeldavgi	doc_491521502227_item	2635993	et	4	main
valuutapoed	doc_491521502227_item	2635996	et	3	main
ei	doc_491521502227_item	2636000	et	4	main
müüdi	doc_491521502227_item	2636003	et	4	main
polnud	doc_491521502227_item	2636009	et	3	main
banaan	doc_491521502227_item	2636016	et	3	main
järelmaksuga	doc_491521502227_item	2636022	et	3	main
seda	doc_491521502227_item	2636025	et	3	main
tähendas	doc_491521502227_item	2636035	et	3	main
tallinnas	doc_491521502227_item	2636044	et	4	main
ja	doc_491521502227_item	2636045	et	3	main
mujalgi	doc_491521502227_item	2636046	et	3	main
põhja-eestis	doc_491521502227_item	2636047	et	3	main
said	doc_491521502227_item	2636048	et	4	main
inimesed	doc_491521502227_item	2636049	et	3	main
näha	doc_491521502227_item	2636050	et	3	main
sealt	doc_491521502227_item	2636053	et	4	main
lahke	doc_491521502226_item	2635704	et	4	main
kõige	doc_491521502226_item	2635709	et	4	main
piinlik	doc_491521502226_item	2635711	et	3	main
suhtumine	doc_491521502226_item	2635715	et	4	main
probleemi	doc_491521502226_item	2635716	et	4	main
on	doc_491521502226_item	2635712	et	4	main
stotsiumi	doc_491521502226_item	2635714	et	4	main
nägu	doc_491521502226_item	2635720	et	4	main
seina	doc_491521502226_item	2635721	et	4	main
pooldad	doc_491521502226_item	2635725	et	3	main
sotsialismi	doc_491521502226_item	2635726	et	4	main
vaenlast	doc_491521502226_item	2635727	et	3	main
oled	doc_491521502226_item	2635728	et	3	main
riigi	doc_491521502226_item	2635729	et	3	main
vaenlane	doc_491521502226_item	2635730	et	3	main
see	doc_491521502226_item	2635731	et	3	main
meelest	doc_491521502226_item	2635741	et	4	main
omajärel	doc_491521502226_item	2635748	et	3	main
see	doc_491521502226_item	2635758	et	3	main
on	doc_491521502226_item	2635766	et	4	main
lihtsam	doc_491521502226_item	2635768	et	4	main
mis	doc_491521502226_item	2635780	et	4	main
on	doc_491521502226_item	2635788	et	4	main
nii	doc_491521502226_item	2635791	et	3	main
filmi	doc_491521502226_item	2635795	et	4	main
libahunti	doc_491521502226_item	2635821	et	4	main
režiim	doc_491521502226_item	2635825	et	2	main
neile	doc_491521502226_item	2635830	et	4	main
kontrolltöö	doc_491521502227_item	2635834	et	4	main
tegurid	doc_491521502227_item	2635838	et	3	main
eesti	doc_491521502227_item	2635842	et	4	main
end	doc_491521502227_item	2635845	et	4	main
2	doc_491521502227_item	2635848	et	2	main
kas	doc_491521502227_item	2635853	et	3	main
ajaloodokument	doc_491521502227_item	2635856	et	3	main
on	doc_491521502227_item	2635864	et	4	main
andis	doc_491521502227_item	2635876	et	3	main
inimestel	doc_491521502227_item	2635881	et	3	main
kuidas	doc_491521502227_item	2635885	et	3	main
mis	doc_491521502227_item	2635890	et	4	main
tehit	doc_491521502227_item	2635892	et	4	main
ka	doc_491521502227_item	2635903	et	3	main
sest	doc_491521502227_item	2635905	et	4	main
teistsugune	doc_491521502227_item	2635916	et	3	main
pärast	doc_491521502227_item	2635923	et	4	main
kaevandamisega	doc_491521502227_item	2635937	et	4	main
oli	doc_491521502227_item	2635938	et	3	main
suur	doc_491521502227_item	2635939	et	3	main
eestlastest	doc_491521502227_item	2635940	et	4	main
eestlased	doc_491521502227_item	2635945	et	3	main
küll	doc_491521502227_item	2635949	et	4	main
teine	doc_491521502227_item	2635957	et	3	main
jõukusele	doc_491521502227_item	2635959	et	4	main
on	doc_491521502227_item	2635960	et	4	main
hinnas	doc_491521502227_item	2635968	et	3	main
nsvlu	doc_491521502227_item	2635977	et	4	main
oli	doc_491521502227_item	2635982	et	3	main
turistidele	doc_491521502227_item	2635994	et	3	main
eestlased	doc_491521502227_item	2635998	et	3	main
saanud	doc_491521502227_item	2636001	et	4	main
asju	doc_491521502227_item	2636004	et	3	main
näinud	doc_491521502227_item	2636010	et	4	main
praegu	doc_491521502227_item	2636012	et	3	main
jalgrattaid	doc_491521502227_item	2636017	et	3	main
sai	doc_491521502227_item	2636020	et	4	main
lubada	doc_491521502227_item	2636030	et	3	main
pea	doc_491521502227_item	2636031	et	4	main
oldi	doc_491521502227_item	2636037	et	3	main
astutud	doc_491521502227_item	2636038	et	4	main
üks	doc_491521502227_item	2636040	et	3	main
soome	doc_491521502227_item	2636051	et	3	main
selle	doc_491521502227_item	2636056	et	4	main
väitsid	doc_491521502227_item	2636060	et	4	main
et	doc_491521502227_item	2636062	et	3	main
tõlgiti	doc_491521502227_item	2636070	et	3	main
trükiti	doc_491521502227_item	2636072	et	3	main
eestlased	doc_491521502227_item	2636083	et	3	main
tähtsammad	doc_491521502227_item	2636087	et	3	main
sel	doc_491521502227_item	2636091	et	3	main
nsvls	doc_491521502227_item	2636128	et	4	main
rahvuspark	doc_491521502227_item	2636134	et	3	main
eestis	doc_491521502227_item	2636136	et	3	main
mis	doc_491521502227_item	2636142	et	4	main
oli	doc_491521502227_item	2636143	et	3	main
läänelik	doc_491521502227_item	2636145	et	4	main
tõlgiti	doc_491521502227_item	2636147	et	3	main
ka	doc_491521502227_item	2636148	et	3	main
sa	doc_491521502226_item	2635724	et	3	main
on	doc_491521502226_item	2635736	et	4	main
järelikult	doc_491521502226_item	2635737	et	3	main
ka	doc_491521502226_item	2635738	et	3	main
vaenlane	doc_491521502226_item	2635739	et	3	main
minu	doc_491521502226_item	2635740	et	3	main
puudumine	doc_491521502226_item	2635746	et	4	main
ühiskonna	doc_491521502226_item	2635751	et	4	main
ilmuda	doc_491521502226_item	2635754	et	3	main
viisil	doc_491521502226_item	2635756	et	4	main
minevik	doc_491521502226_item	2635761	et	3	main
eilne	doc_491521502226_item	2635763	et	3	main
tänapäeval	doc_491521502226_item	2635765	et	3	main
ühiskonda	doc_491521502226_item	2635771	et	4	main
häirib	doc_491521502226_item	2635781	et	3	main
ja	doc_491521502226_item	2635783	et	3	main
keegi	doc_491521502226_item	2635784	et	4	main
just	doc_491521502226_item	2635790	et	3	main
nsv	doc_491521502226_item	2635797	et	4	main
režiimi	doc_491521502226_item	2635798	et	2	main
peegeldust	doc_491521502226_item	2635799	et	4	main
või	doc_491521502226_item	2635800	et	4	main
lihtsalt	doc_491521502226_item	2635801	et	4	main
korduvat	doc_491521502226_item	2635802	et	4	main
mitte	doc_491521502226_item	2635803	et	3	main
miski	doc_491521502226_item	2635804	et	4	main
ei	doc_491521502226_item	2635805	et	4	main
teki	doc_491521502226_item	2635806	et	4	main
ega	doc_491521502226_item	2635807	et	3	main
ei	doc_491521502226_item	2635808	et	4	main
kao	doc_491521502226_item	2635809	et	4	main
vaid	doc_491521502226_item	2635810	et	3	main
muudab	doc_491521502226_item	2635811	et	3	main
oma	doc_491521502226_item	2635812	et	4	main
kuju	doc_491521502226_item	2635813	et	4	main
ennem	doc_491521502226_item	2635814	et	4	main
libahundi	doc_491521502226_item	2635815	et	3	main
kartmine	doc_491521502226_item	2635816	et	4	main
pärast	doc_491521502226_item	2635817	et	4	main
juba	doc_491521502226_item	2635818	et	3	main
seesama	doc_491521502226_item	2635819	et	3	main
aga	doc_491521502226_item	2635820	et	3	main
valib	doc_491521502226_item	2635822	et	3	main
ja	doc_491521502226_item	2635826	et	3	main
ka	doc_491521502226_item	2635831	et	3	main
missugused	doc_491521502227_item	2635836	et	3	main
nsvl	doc_491521502227_item	2635843	et	4	main
laiuse	doc_491521502227_item	2635850	et	4	main
ühiskonnakriitika	doc_491521502227_item	2635858	et	4	main
ühiskonnakriitika	doc_491521502227_item	2635868	et	4	main
elu	doc_491521502227_item	2635872	et	4	main
mulle	doc_491521502227_item	2635877	et	4	main
sel	doc_491521502227_item	2635882	et	3	main
sõid	doc_491521502227_item	2635886	et	4	main
jne	doc_491521502227_item	2635893	et	4	main
ta	doc_491521502227_item	2635897	et	4	main
seda	doc_491521502227_item	2635901	et	3	main
filmi	doc_491521502227_item	2635906	et	4	main
on	doc_491521502227_item	2635908	et	4	main
kes	doc_491521502227_item	2635914	et	4	main
kukkamõistu	doc_491521502227_item	2635918	et	4	main
vaid	doc_491521502227_item	2635919	et	3	main
päritolu	doc_491521502227_item	2635920	et	4	main
välimuse	doc_491521502227_item	2635922	et	3	main
annab	doc_491521502227_item	2635925	et	3	main
libahunti	doc_491521502227_item	2635928	et	4	main
ühiskonnakriitikaks	doc_491521502227_item	2635930	et	3	main
kuid	doc_491521502227_item	2635951	et	4	main
teha	doc_491521502227_item	2635955	et	3	main
vili	doc_491521502227_item	2635965	et	3	main
ja	doc_491521502227_item	2635970	et	3	main
seda	doc_491521502227_item	2635974	et	3	main
suur	doc_491521502227_item	2635984	et	3	main
palju	doc_491521502227_item	2635987	et	4	main
turiste	doc_491521502227_item	2635988	et	3	main
polnud	doc_491521502227_item	2635990	et	3	main
kuhu	doc_491521502227_item	2635997	et	3	main
sisse	doc_491521502227_item	2635999	et	4	main
varem	doc_491521502227_item	2636008	et	4	main
näiteks	doc_491521502227_item	2636011	et	4	main
meile	doc_491521502227_item	2636013	et	4	main
nii	doc_491521502227_item	2636014	et	3	main
ja	doc_491521502227_item	2636018	et	3	main
televiisoreid	doc_491521502227_item	2636019	et	3	main
osta	doc_491521502227_item	2636021	et	4	main
mis	doc_491521502227_item	2636023	et	4	main
tähendas	doc_491521502227_item	2636024	et	3	main
aga	doc_491521502227_item	2636034	et	3	main
samm	doc_491521502227_item	2636041	et	3	main
tv-d	doc_491521502227_item	2636052	et	4	main
on	doc_491521502227_item	2636064	et	4	main
siinsete	doc_491521502227_item	2636066	et	4	main
paljud	doc_491521502227_item	2636082	et	3	main
kõige	doc_491521502227_item	2636086	et	4	main
eesti	doc_491521502227_item	2636089	et	4	main
mujal	doc_491521502227_item	2636094	et	3	main
aitas	doc_491521502227_item	2636123	et	3	main
rahvuskultuuri	doc_491521502227_item	2636125	et	4	main
säilitamisele	doc_491521502227_item	2636126	et	4	main
esimesena	doc_491521502227_item	2636127	et	3	main
ala	doc_491521502227_item	2636132	et	4	main
esimesena	doc_491521502227_item	2636138	et	3	main
ka	doc_491521502227_item	2636140	et	3	main
abielust	doc_491521502227_item	2636153	et	3	main
hoitud	doc_491521502227_item	2636162	et	4	main
ehitati	doc_491521502227_item	2636170	et	3	main
betoonimaju	doc_491521502227_item	2636172	et	3	main
esialgu	doc_491521502227_item	2636174	et	3	main
sai	doc_491521502227_item	2636204	et	4	main
oma	doc_491521502227_item	2636208	et	4	main
ringi	doc_491521502227_item	2636210	et	4	main
käia	doc_491521502227_item	2636212	et	4	main
olid	doc_491521502227_item	2636227	et	4	main
läänelikkuse	doc_491521502227_item	2636228	et	4	main
märk	doc_491521502227_item	2636229	et	3	main
lähisvälismaa	doc_491521502227_item	2636243	et	4	main
laiuse	doc_491521502228_item	2636260	et	4	main
miks	doc_491521502228_item	2636269	et	4	main
1	doc_491521502228_item	2636270	et	2	main
tähtsal	doc_491521502228_item	2636276	et	3	main
õiguse	doc_491521502227_item	2635926	et	4	main
kuna	doc_491521502227_item	2635932	et	3	main
järjel	doc_491521502227_item	2635944	et	3	main
ei	doc_491521502227_item	2635946	et	4	main
kaevandustes	doc_491521502227_item	2635948	et	4	main
muid	doc_491521502227_item	2635952	et	4	main
töid	doc_491521502227_item	2635953	et	3	main
said	doc_491521502227_item	2635954	et	4	main
vilja	doc_491521502227_item	2635961	et	4	main
ka	doc_491521502227_item	2635972	et	3	main
mujale	doc_491521502227_item	2635976	et	3	main
nõudlus	doc_491521502227_item	2635979	et	3	main
käis	doc_491521502227_item	2635986	et	4	main
tuttav	doc_491521502227_item	2636015	et	3	main
neid	doc_491521502227_item	2636027	et	4	main
endale	doc_491521502227_item	2636029	et	4	main
et	doc_491521502227_item	2636036	et	3	main
veel	doc_491521502227_item	2636039	et	4	main
läänestumise	doc_491521502227_item	2636042	et	4	main
poole	doc_491521502227_item	2636043	et	4	main
muidugi	doc_491521502227_item	2636061	et	4	main
need	doc_491521502227_item	2636074	et	3	main
ka	doc_491521502227_item	2636076	et	3	main
neidki	doc_491521502227_item	2636080	et	4	main
said	doc_491521502227_item	2636081	et	4	main
olid	doc_491521502227_item	2636088	et	4	main
kui	doc_491521502227_item	2636093	et	3	main
nsvls	doc_491521502227_item	2636095	et	4	main
avati	doc_491521502227_item	2635995	et	3	main
seal	doc_491521502227_item	2636002	et	4	main
mida	doc_491521502227_item	2636005	et	4	main
eestlased	doc_491521502227_item	2636006	et	3	main
kundagi	doc_491521502227_item	2636007	et	4	main
et	doc_491521502227_item	2636026	et	3	main
võisid	doc_491521502227_item	2636028	et	4	main
kõik	doc_491521502227_item	2636032	et	4	main
see	doc_491521502227_item	2636033	et	3	main
nähti	doc_491521502227_item	2636054	et	4	main
nõukogude	doc_491521502227_item	2636058	et	3	main
võimud	doc_491521502227_item	2636059	et	3	main
näitemänguga	doc_491521502227_item	2636065	et	3	main
inimeste	doc_491521502227_item	2636067	et	3	main
petmiseks	doc_491521502227_item	2636068	et	4	main
palju	doc_491521502227_item	2636073	et	4	main
olid	doc_491521502227_item	2636075	et	4	main
nii	doc_491521502227_item	2636078	et	3	main
mid	doc_491521502227_item	2636085	et	4	main
keelsed	doc_491521502227_item	2636090	et	3	main
omakeelseid	doc_491521502227_item	2636096	et	3	main
trükki	doc_491521502227_item	2636098	et	4	main
peaaegu	doc_491521502227_item	2636099	et	3	main
ei	doc_491521502227_item	2636100	et	4	main
läinudki	doc_491521502227_item	2636101	et	4	main
haridust	doc_491521502227_item	2636102	et	4	main
anti	doc_491521502227_item	2636103	et	3	main
eesti	doc_491521502227_item	2636104	et	4	main
keels	doc_491521502227_item	2636105	et	4	main
koolis	doc_491521502227_item	2636106	et	4	main
oli	doc_491521502227_item	2636107	et	3	main
keele	doc_491521502227_item	2636109	et	4	main
vene	doc_491521502227_item	2636108	et	4	main
õpetamise	doc_491521502227_item	2636110	et	4	main
ja	doc_491521502227_item	2636111	et	3	main
õppimine	doc_491521502227_item	2636112	et	4	main
küll	doc_491521502227_item	2636113	et	4	main
esmatähtsal	doc_491521502227_item	2636114	et	3	main
kohal	doc_491521502227_item	2636115	et	4	main
kuid	doc_491521502227_item	2636116	et	4	main
põhiained	doc_491521502227_item	2636117	et	3	main
olid	doc_491521502227_item	2636118	et	4	main
siiski	doc_491521502227_item	2636119	et	4	main
eesit	doc_491521502227_item	2636120	et	4	main
see	doc_491521502227_item	2636122	et	3	main
ilmus	doc_491521502227_item	2636137	et	4	main
nsvls	doc_491521502227_item	2636139	et	4	main
antud	doc_491521502227_item	2636151	et	4	main
kus	doc_491521502227_item	2636154	et	3	main
korda	doc_491521502227_item	2636156	et	4	main
mis	doc_491521502227_item	2636159	et	4	main
seni	doc_491521502227_item	2636160	et	3	main
olid	doc_491521502227_item	2636161	et	4	main
ja	doc_491521502227_item	2636166	et	3	main
mehe-naise	doc_491521502227_item	2636167	et	3	main
suuri	doc_491521502227_item	2636171	et	3	main
eesti	doc_491521502227_item	2636202	et	4	main
silma	doc_491521502227_item	2636209	et	4	main
sai	doc_491521502227_item	2636214	et	4	main
küll	doc_491521502227_item	2636216	et	4	main
ainult	doc_491521502227_item	2636217	et	4	main
palju	doc_491521502227_item	2636225	et	4	main
silmas	doc_491521502227_item	2636232	et	4	main
pidades	doc_491521502227_item	2636233	et	3	main
püüeldi	doc_491521502227_item	2636055	et	3	main
poole	doc_491521502227_item	2636057	et	4	main
tegu	doc_491521502227_item	2636063	et	4	main
raamatuid	doc_491521502227_item	2636069	et	3	main
ja	doc_491521502227_item	2636071	et	3	main
odavad	doc_491521502227_item	2636077	et	3	main
et	doc_491521502227_item	2636079	et	3	main
osta	doc_491521502227_item	2636084	et	4	main
ajal	doc_491521502227_item	2636092	et	4	main
raatmatuid	doc_491521502227_item	2636097	et	4	main
keeles	doc_491521502227_item	2636121	et	4	main
kaasa	doc_491521502227_item	2636124	et	4	main
lahemaa	doc_491521502227_item	2636133	et	4	main
väljka	doc_491521502227_item	2636150	et	4	main
esimest	doc_491521502227_item	2636155	et	4	main
räägiti	doc_491521502227_item	2636157	et	3	main
suhetest	doc_491521502227_item	2636169	et	3	main
siinsetele	doc_491521502227_item	2636175	et	4	main
harimas	doc_491521502227_item	2636206	et	3	main
autosid	doc_491521502227_item	2636213	et	3	main
alusel	doc_491521502227_item	2636219	et	4	main
kuid	doc_491521502227_item	2636220	et	4	main
loodi	doc_491521502227_item	2636129	et	4	main
eestis	doc_491521502227_item	2636130	et	3	main
looduskaitse	doc_491521502227_item	2636131	et	4	main
1974	doc_491521502227_item	2636135	et	2	main
koomiksiraamat	doc_491521502227_item	2636141	et	3	main
väga	doc_491521502227_item	2636144	et	3	main
raamatutest	doc_491521502227_item	2636146	et	4	main
asjadest	doc_491521502227_item	2636158	et	3	main
intiimsusest	doc_491521502227_item	2636165	et	4	main
mis	doc_491521502227_item	2636173	et	4	main
inimestele	doc_491521502227_item	2636176	et	3	main
pilvelõhkujatena	doc_491521502227_item	2636178	et	3	main
nii	doc_491521502227_item	2636179	et	3	main
tundusid	doc_491521502227_item	2636177	et	4	main
kerkisid	doc_491521502227_item	2636180	et	4	main
lasnamäe	doc_491521502227_item	2636181	et	3	main
ja	doc_491521502227_item	2636182	et	3	main
mustamäe	doc_491521502227_item	2636183	et	3	main
5-	doc_491521502227_item	2636184	et	4	main
ja	doc_491521502227_item	2636185	et	3	main
9-kordsed	doc_491521502227_item	2636186	et	3	main
majad	doc_491521502227_item	2636187	et	3	main
oldi	doc_491521502227_item	2636188	et	3	main
harjutud	doc_491521502227_item	2636189	et	4	main
elama	doc_491521502227_item	2636190	et	3	main
tavalistes	doc_491521502227_item	2636191	et	4	main
majades	doc_491521502227_item	2636192	et	3	main
mitte	doc_491521502227_item	2636193	et	3	main
korterites	doc_491521502227_item	2636194	et	3	main
jällegi	doc_491521502227_item	2636195	et	4	main
samm	doc_491521502227_item	2636196	et	3	main
läänelikkuse	doc_491521502227_item	2636197	et	4	main
poole	doc_491521502227_item	2636198	et	4	main
avati	doc_491521502227_item	2636199	et	3	main
muuseume	doc_491521502227_item	2636200	et	3	main
kus	doc_491521502227_item	2636201	et	3	main
soomes	doc_491521502227_item	2636149	et	4	main
avameelselt	doc_491521502227_item	2636152	et	4	main
kapis	doc_491521502227_item	2636163	et	3	main
lukutaga	doc_491521502227_item	2636164	et	4	main
vahelisest	doc_491521502227_item	2636168	et	4	main
inimene	doc_491521502227_item	2636203	et	3	main
end	doc_491521502227_item	2636205	et	4	main
loa	doc_491521502227_item	2636218	et	4	main
autod	doc_491521502227_item	2636226	et	3	main
nsvlu	doc_491521502227_item	2636242	et	4	main
tegurid	doc_491521502228_item	2636248	et	3	main
põhjust	doc_491521502228_item	2636251	et	4	main
2	doc_491521502228_item	2636258	et	2	main
ajaloodokument	doc_491521502228_item	2636266	et	3	main
või	doc_491521502228_item	2636267	et	4	main
arenema	doc_491521502228_item	2636274	et	3	main
olid	doc_491521502228_item	2636310	et	4	main
kirjanduses	doc_491521502228_item	2636332	et	3	main
iseloomustab	doc_491521502228_item	2636333	et	4	main
esialgu	doc_491521502228_item	2636334	et	3	main
kättesaadavaks	doc_491521502228_item	2636339	et	4	main
kontaktid	doc_491521502228_item	2636343	et	3	main
aa	doc_491521502228_item	2636346	et	3	main
i	doc_491521502228_item	2636348	et	4	main
festivall	doc_491521502228_item	2636350	et	4	main
sealt	doc_491521502228_item	2636351	et	4	main
hakatakse	doc_491521502228_item	2636356	et	3	main
pärts	doc_491521502228_item	2636359	et	4	main
oli	doc_491521502228_item	2636383	et	3	main
kõik	doc_491521502228_item	2636384	et	4	main
läänte	doc_491521502228_item	2636422	et	3	main
ainult	doc_491521502228_item	2636433	et	4	main
arvamus	doc_491521502228_item	2636435	et	3	main
ajal	doc_491521502228_item	2636447	et	4	main
arvan	doc_491521502228_item	2636448	et	3	main
seda	doc_491521502228_item	2636449	et	3	main
et	doc_491521502228_item	2636450	et	3	main
iga	doc_491521502228_item	2636451	et	4	main
inimene	doc_491521502228_item	2636452	et	3	main
võis	doc_491521502228_item	2636453	et	4	main
olla	doc_491521502228_item	2636454	et	3	main
ühiskonnale	doc_491521502228_item	2636461	et	4	main
absoluutselt	doc_491521502228_item	2636465	et	4	main
sarnased	doc_491521502228_item	2636470	et	4	main
üks	doc_491521502228_item	2636474	et	3	main
ei	doc_491521502228_item	2636477	et	4	main
teised	doc_491521502228_item	2636491	et	4	main
ühiskonnast	doc_491521502228_item	2636494	et	4	main
ja	doc_491521502227_item	2636207	et	3	main
suurendamas	doc_491521502227_item	2636211	et	3	main
osta	doc_491521502227_item	2636215	et	4	main
neid	doc_491521502227_item	2636221	et	4	main
saadi	doc_491521502227_item	2636223	et	4	main
suhteliselt	doc_491521502227_item	2636224	et	4	main
eelpool	doc_491521502227_item	2636231	et	4	main
nsv	doc_491521502227_item	2636239	et	4	main
oli	doc_491521502227_item	2636240	et	3	main
justkui	doc_491521502227_item	2636241	et	3	main
1	doc_491521502228_item	2636245	et	2	main
andsid	doc_491521502228_item	2636249	et	4	main
1970ndatel	doc_491521502228_item	2636250	et	4	main
libahunt	doc_491521502228_item	2636262	et	3	main
muusikaga	doc_491521502228_item	2636312	et	3	main
olid	doc_491521502228_item	2636321	et	4	main
ajaloolised	doc_491521502228_item	2636323	et	4	main
luule	doc_491521502228_item	2636335	et	4	main
väliseestlaste	doc_491521502228_item	2636340	et	4	main
1970	doc_491521502228_item	2636345	et	2	main
said	doc_491521502228_item	2636352	et	4	main
klassik	doc_491521502228_item	2636362	et	3	main
elanikud	doc_491521502228_item	2636364	et	3	main
vaadata	doc_491521502228_item	2636366	et	4	main
soome	doc_491521502228_item	2636367	et	3	main
tv	doc_491521502228_item	2636368	et	4	main
välismuusika	doc_491521502228_item	2636369	et	4	main
polnud	doc_491521502228_item	2636370	et	3	main
õitses	doc_491521502228_item	2636373	et	4	main
palju	doc_491521502228_item	2636376	et	4	main
arvates	doc_491521502228_item	2636425	et	4	main
minu	doc_491521502228_item	2636434	et	3	main
aga	doc_491521502228_item	2636436	et	3	main
olukorras	doc_491521502228_item	2636456	et	3	main
kõik	doc_491521502228_item	2636467	et	4	main
peavad	doc_491521502228_item	2636468	et	4	main
lubasid	doc_491521502227_item	2636222	et	4	main
kõik	doc_491521502227_item	2636230	et	4	main
eesti	doc_491521502227_item	2636238	et	4	main
kontrolltöö	doc_491521502228_item	2636244	et	4	main
eesti	doc_491521502228_item	2636252	et	4	main
nsvl	doc_491521502228_item	2636253	et	4	main
tunda	doc_491521502228_item	2636254	et	3	main
end	doc_491521502228_item	2636255	et	4	main
nsvl	doc_491521502228_item	2636256	et	4	main
lähisvälismaana	doc_491521502228_item	2636257	et	3	main
mängufilm	doc_491521502228_item	2636261	et	3	main
teie	doc_491521502228_item	2636264	et	4	main
1970-ndatel	doc_491521502228_item	2636271	et	4	main
hakkas	doc_491521502228_item	2636272	et	3	main
eestis	doc_491521502228_item	2636273	et	3	main
kohal	doc_491521502228_item	2636277	et	4	main
televisioon	doc_491521502228_item	2636280	et	4	main
hakatakse	doc_491521502228_item	2636281	et	3	main
näitama	doc_491521502228_item	2636282	et	3	main
oma	doc_491521502228_item	2636283	et	4	main
filme	doc_491521502228_item	2636284	et	3	main
esimesed	doc_491521502228_item	2636285	et	3	main
filmid	doc_491521502228_item	2636286	et	4	main
olid	doc_491521502228_item	2636287	et	4	main
vene	doc_491521502228_item	2636288	et	4	main
režissööride	doc_491521502228_item	2636289	et	2	main
abil	doc_491521502228_item	2636290	et	4	main
tehtud	doc_491521502228_item	2636291	et	4	main
eestis	doc_491521502228_item	2636292	et	3	main
oli	doc_491521502228_item	2636293	et	3	main
populaarne	doc_491521502228_item	2636294	et	3	main
huumorifilm	doc_491521502228_item	2636295	et	3	main
õitsesid	doc_491521502228_item	2636296	et	4	main
ka	doc_491521502228_item	2636297	et	3	main
multufilmid	doc_491521502228_item	2636298	et	4	main
need	doc_491521502228_item	2636299	et	3	main
olid	doc_491521502228_item	2636300	et	4	main
sarnased	doc_491521502228_item	2636301	et	4	main
ameerika	doc_491521502228_item	2636302	et	3	main
multufilmidega	doc_491521502228_item	2636303	et	4	main
võib	doc_491521502227_item	2636234	et	3	main
julgelt	doc_491521502227_item	2636235	et	4	main
öelda	doc_491521502227_item	2636236	et	4	main
et	doc_491521502227_item	2636237	et	3	main
missugused	doc_491521502228_item	2636246	et	3	main
majanduslikud-kultuurilised	doc_491521502228_item	2636247	et	4	main
l	doc_491521502228_item	2636259	et	4	main
kas	doc_491521502228_item	2636263	et	3	main
arvates	doc_491521502228_item	2636265	et	4	main
ühiskonnakriitika	doc_491521502228_item	2636268	et	4	main
kultuurielu	doc_491521502228_item	2636275	et	4	main
oli	doc_491521502228_item	2636278	et	3	main
eesti	doc_491521502228_item	2636279	et	4	main
need	doc_491521502228_item	2636309	et	3	main
järjest	doc_491521502228_item	2636304	et	4	main
seotud	doc_491521502228_item	2636313	et	4	main
siin	doc_491521502228_item	2636314	et	4	main
palju	doc_491521502228_item	2636316	et	4	main
nt	doc_491521502228_item	2636325	et	4	main
täna	doc_491521502228_item	2636326	et	4	main
25	doc_491521502228_item	2636327	et	2	main
aastat	doc_491521502228_item	2636328	et	3	main
tagasi	doc_491521502228_item	2636329	et	3	main
seda	doc_491521502228_item	2636330	et	3	main
eestlastele	doc_491521502228_item	2636337	et	4	main
väliskirjandusega	doc_491521502228_item	2636344	et	3	main
tuntuks	doc_491521502228_item	2636353	et	4	main
mõned	doc_491521502228_item	2636354	et	3	main
näitama	doc_491521502228_item	2636358	et	3	main
tuntud	doc_491521502228_item	2636361	et	4	main
soovitav	doc_491521502228_item	2636371	et	4	main
need	doc_491521502228_item	2636378	et	3	main
siin	doc_491521502228_item	2636382	et	4	main
minu	doc_491521502228_item	2636424	et	3	main
on	doc_491521502228_item	2636427	et	4	main
ajaloodokument	doc_491521502228_item	2636429	et	3	main
see	doc_491521502228_item	2636431	et	3	main
on	doc_491521502228_item	2636432	et	4	main
mis	doc_491521502228_item	2636444	et	4	main
inimene	doc_491521502228_item	2636445	et	3	main
tol	doc_491521502228_item	2636446	et	3	main
sellises	doc_491521502228_item	2636455	et	4	main
sellel	doc_491521502228_item	2636462	et	4	main
ajal	doc_491521502228_item	2636463	et	4	main
propageeriti	doc_491521502228_item	2636464	et	3	main
olema	doc_491521502228_item	2636469	et	4	main
näidatud	doc_491521502228_item	2636473	et	4	main
rohkem	doc_491521502228_item	2636305	et	4	main
ilmusid	doc_491521502228_item	2636306	et	4	main
uued	doc_491521502228_item	2636307	et	3	main
saated	doc_491521502228_item	2636308	et	3	main
peamiselt	doc_491521502228_item	2636311	et	4	main
esines	doc_491521502228_item	2636315	et	3	main
lapsi	doc_491521502228_item	2636317	et	4	main
olid	doc_491521502228_item	2636318	et	4	main
spetsiaalsed	doc_491521502228_item	2636319	et	3	main
saated	doc_491521502228_item	2636320	et	3	main
ka	doc_491521502228_item	2636322	et	3	main
saated	doc_491521502228_item	2636324	et	3	main
pärast-proosa	doc_491521502228_item	2636336	et	4	main
kirjandus	doc_491521502228_item	2636341	et	3	main
rahvusvaheliselt	doc_491521502228_item	2636360	et	4	main
tallinna	doc_491521502228_item	2636363	et	4	main
said	doc_491521502228_item	2636365	et	4	main
eestimuusika	doc_491521502228_item	2636372	et	4	main
ehitati	doc_491521502228_item	2636375	et	3	main
näitemajandeid	doc_491521502228_item	2636377	et	3	main
olid	doc_491521502228_item	2636379	et	4	main
nagu	doc_491521502228_item	2636380	et	3	main
miniriigid	doc_491521502228_item	2636381	et	3	main
pääs	doc_491521502228_item	2636421	et	3	main
mulle	doc_491521502228_item	2636437	et	4	main
tundub	doc_491521502228_item	2636438	et	3	main
et	doc_491521502228_item	2636439	et	3	main
see	doc_491521502228_item	2636440	et	3	main
libahunt	doc_491521502228_item	2636441	et	3	main
on	doc_491521502228_item	2636442	et	4	main
üks	doc_491521502228_item	2636457	et	3	main
vastu	doc_491521502228_item	2636460	et	3	main
filmis	doc_491521502228_item	2636471	et	4	main
inimene	doc_491521502228_item	2636475	et	3	main
olema	doc_491521502228_item	2636488	et	4	main
nagu	doc_491521502228_item	2636489	et	3	main
kõik	doc_491521502228_item	2636490	et	4	main
eraldi	doc_491521502228_item	2636493	et	4	main
perioodi	doc_491521502228_item	2636331	et	4	main
sai	doc_491521502228_item	2636338	et	4	main
tihenesid	doc_491521502228_item	2636342	et	4	main
korraldati	doc_491521502228_item	2636347	et	3	main
dzässi	doc_491521502228_item	2636349	et	4	main
heliloojad	doc_491521502228_item	2636355	et	3	main
baletti	doc_491521502228_item	2636357	et	4	main
eestisse	doc_491521502228_item	2636374	et	4	main
mis	doc_491521502228_item	2636385	et	4	main
inimesel	doc_491521502228_item	2636386	et	3	main
oli	doc_491521502228_item	2636387	et	3	main
viga	doc_491521502228_item	2636388	et	4	main
eestis	doc_491521502228_item	2636389	et	3	main
hakkasid	doc_491521502228_item	2636390	et	4	main
ilmuma	doc_491521502228_item	2636391	et	3	main
luksuskaubad	doc_491521502228_item	2636392	et	3	main
külmkapp	doc_491521502228_item	2636393	et	3	main
auto	doc_491521502228_item	2636394	et	4	main
võis	doc_491521502228_item	2636395	et	4	main
osta	doc_491521502228_item	2636396	et	4	main
neid	doc_491521502228_item	2636397	et	4	main
järelmaksuga	doc_491521502228_item	2636398	et	3	main
ehitati	doc_491521502228_item	2636399	et	3	main
balti	doc_491521502228_item	2636400	et	3	main
soojuselektrijaama	doc_491521502228_item	2636401	et	4	main
bsej	doc_491521502228_item	2636402	et	4	main
siin	doc_491521502228_item	2636403	et	4	main
töötasid	doc_491521502228_item	2636404	et	4	main
valdavalt	doc_491521502228_item	2636405	et	4	main
venelased	doc_491521502228_item	2636406	et	3	main
eestlased	doc_491521502228_item	2636407	et	3	main
ei	doc_491521502228_item	2636408	et	4	main
tehtnuud	doc_491521502228_item	2636409	et	4	main
kodune	doc_491521502228_item	2636410	et	4	main
tehnika	doc_491521502228_item	2636411	et	4	main
sai	doc_491521502228_item	2636412	et	4	main
populaarseks	doc_491521502228_item	2636413	et	4	main
siin	doc_491521502228_item	2636414	et	4	main
eestis	doc_491521502228_item	2636415	et	3	main
on	doc_491521502228_item	2636416	et	4	main
meri	doc_491521502228_item	2636417	et	3	main
see	doc_491521502228_item	2636418	et	3	main
on	doc_491521502228_item	2636419	et	4	main
nagu	doc_491521502228_item	2636420	et	3	main
2	doc_491521502228_item	2636423	et	2	main
libahunt	doc_491521502228_item	2636426	et	3	main
rohkem	doc_491521502228_item	2636428	et	4	main
võib-olla	doc_491521502228_item	2636430	et	3	main
üskkõik	doc_491521502228_item	2636443	et	4	main
inimene	doc_491521502228_item	2636458	et	3	main
seisab	doc_491521502228_item	2636459	et	3	main
võrdsust	doc_491521502228_item	2636466	et	4	main
on	doc_491521502228_item	2636472	et	4	main
kes	doc_491521502228_item	2636476	et	4	main
saa	doc_491521502228_item	2636478	et	4	main
minna	doc_491521502228_item	2636479	et	3	main
vastu	doc_491521502228_item	2636480	et	3	main
teistele	doc_491521502228_item	2636481	et	4	main
see	doc_491521502228_item	2636482	et	3	main
pole	doc_491521502228_item	2636483	et	3	main
võimalik	doc_491521502228_item	2636484	et	3	main
see	doc_491521502228_item	2636485	et	3	main
tähendab	doc_491521502228_item	2636486	et	3	main
pead	doc_491521502228_item	2636487	et	4	main
või	doc_491521502228_item	2636492	et	4	main
varane	doc_491521502230_item	2636845	et	4	main
2	doc_491521502230_item	2636853	et	2	main
loodusnähtustele	doc_491521502230_item	2636857	et	3	main
elusloodusele	doc_491521502230_item	2636860	et	3	main
puudel	doc_491521502230_item	2636865	et	4	main
olemas	doc_491521502230_item	2636869	et	4	main
hing	doc_491521502230_item	2636870	et	3	main
oli	doc_491521502230_item	2636883	et	3	main
e	doc_491521502230_item	2636885	et	4	main
kõige	doc_491521502230_item	2636890	et	4	main
teistele	doc_491521502230_item	2636899	et	4	main
eesti	doc_491521502230_item	2636903	et	4	main
teine	doc_491521502230_item	2636912	et	3	main
kuna	doc_491521502230_item	2636921	et	3	main
ei	doc_491521502230_item	2636923	et	4	main
pronksesemeid	doc_491521502230_item	2636937	et	3	main
koha	doc_491521502230_item	2636939	et	4	main
pronksiaega	doc_491521502230_item	2636944	et	4	main
endiselt	doc_491521502230_item	2636957	et	4	main
saavad	doc_491521502230_item	2636964	et	4	main
üleminek	doc_491521502230_item	2636974	et	3	main
ja	doc_491521502230_item	2636992	et	3	main
hobused	doc_491521502230_item	2636994	et	4	main
peeti	doc_491521502230_item	2636996	et	4	main
enamasti	doc_491521502230_item	2636997	et	4	main
maapealsed	doc_491521502230_item	2637001	et	3	main
lõpupoole	doc_491521502230_item	2637005	et	4	main
hakati	doc_491521502230_item	2637006	et	3	main
animism	doc_491521502230_item	2636854	et	3	main
omistamine	doc_491521502230_item	2636856	et	4	main
elutaloodusele	doc_491521502230_item	2636858	et	4	main
nt	doc_491521502230_item	2636864	et	4	main
ja	doc_491521502230_item	2636866	et	3	main
on	doc_491521502230_item	2636878	et	4	main
pronks	doc_491521502230_item	2636884	et	3	main
sulam	doc_491521502230_item	2636889	et	4	main
esimesena	doc_491521502230_item	2636891	et	3	main
lähisida	doc_491521502230_item	2636894	et	4	main
sealt	doc_491521502230_item	2636896	et	4	main
rahvastele	doc_491521502230_item	2636900	et	4	main
on	doc_491521502230_item	2636914	et	4	main
kontrolltöö	doc_491521502230_item	2636843	et	4	main
1	doc_491521502230_item	2636844	et	2	main
tähendus	doc_491521502230_item	2636852	et	4	main
uskusid	doc_491521502230_item	2636862	et	4	main
kuldesemeid	doc_491521502230_item	2636877	et	3	main
egiptusest	doc_491521502230_item	2636880	et	4	main
vase	doc_491521502230_item	2636886	et	3	main
harutama	doc_491521502230_item	2636893	et	3	main
levis	doc_491521502230_item	2636897	et	4	main
ka	doc_491521502230_item	2636902	et	3	main
arvati	doc_491521502230_item	2636905	et	4	main
volga	doc_491521502230_item	2636910	et	4	main
eestis	doc_491521502230_item	2636922	et	3	main
tina	doc_491521502230_item	2636927	et	4	main
millest	doc_491521502230_item	2636928	et	3	main
seda	doc_491521502230_item	2636929	et	3	main
sulatada	doc_491521502230_item	2636930	et	3	main
esimesed	doc_491521502230_item	2636931	et	3	main
pronksesemed	doc_491521502230_item	2636932	et	3	main
saadud	doc_491521502230_item	2636936	et	4	main
ekr	doc_491521502230_item	2636949	et	4	main
pronksi	doc_491521502230_item	2636954	et	4	main
luust	doc_491521502230_item	2636958	et	4	main
rahva	doc_491521502230_item	2636965	et	3	main
elupaigax	doc_491521502230_item	2636966	et	4	main
kindlustatud	doc_491521502230_item	2636967	et	4	main
hakati	doc_491521502230_item	2636986	et	3	main
veised	doc_491521502230_item	2636991	et	3	main
kohalikust	doc_491521502230_item	2637007	et	4	main
soomaagist	doc_491521502230_item	2637008	et	4	main
hingede	doc_491521502230_item	2636855	et	3	main
inimesed	doc_491521502230_item	2636861	et	3	main
et	doc_491521502230_item	2636863	et	3	main
kividel	doc_491521502230_item	2636867	et	3	main
metall	doc_491521502230_item	2636882	et	3	main
tina	doc_491521502230_item	2636888	et	4	main
ja	doc_491521502230_item	2636901	et	3	main
rahvastelt	doc_491521502230_item	2636911	et	4	main
leidu	doc_491521502230_item	2636924	et	4	main
vaske	doc_491521502230_item	2636925	et	4	main
ja	doc_491521502230_item	2636926	et	3	main
leiti	doc_491521502230_item	2636933	et	3	main
kaubavahetusel	doc_491521502230_item	2636935	et	4	main
õpiti	doc_491521502230_item	2636938	et	3	main
ja	doc_491521502230_item	2636942	et	3	main
ümbertöötlema	doc_491521502230_item	2636943	et	4	main
5	doc_491521502230_item	2636950	et	2	main
ja	doc_491521502230_item	2636959	et	3	main
uut	doc_491521502230_item	2636970	et	3	main
tüüpi	doc_491521502230_item	2636971	et	4	main
toimus	doc_491521502230_item	2636973	et	3	main
levis	doc_491521502230_item	2636976	et	4	main
alepõllundus	doc_491521502230_item	2636977	et	3	main
ja	doc_491521502230_item	2636978	et	3	main
loomakasvatus	doc_491521502230_item	2636979	et	4	main
hakati	doc_491521502230_item	2636980	et	3	main
kasvatama	doc_491521502230_item	2636981	et	4	main
karjatama	doc_491521502230_item	2636985	et	3	main
ja	doc_491521502230_item	2636990	et	3	main
tööjõux	doc_491521502230_item	2636998	et	4	main
kivikirstkalmed	doc_491521502230_item	2637002	et	4	main
metalliaja	doc_491521502230_item	2637004	et	3	main
sulatama	doc_491521502230_item	2637010	et	4	main
metalliaeg	doc_491521502230_item	2636846	et	3	main
eesti	doc_491521502230_item	2636847	et	4	main
territooriumil	doc_491521502230_item	2636848	et	3	main
2	doc_491521502230_item	2636849	et	2	main
mõiste	doc_491521502230_item	2636850	et	4	main
animism	doc_491521502230_item	2636851	et	3	main
ja	doc_491521502230_item	2636859	et	3	main
on	doc_491521502230_item	2636868	et	4	main
1	doc_491521502230_item	2636871	et	2	main
esimene	doc_491521502230_item	2636872	et	3	main
metall	doc_491521502230_item	2636873	et	3	main
oli	doc_491521502230_item	2636874	et	3	main
kuld	doc_491521502230_item	2636875	et	3	main
vanu	doc_491521502230_item	2636876	et	4	main
leitud	doc_491521502230_item	2636879	et	4	main
teine	doc_491521502230_item	2636881	et	3	main
ja	doc_491521502230_item	2636887	et	3	main
hakkasid	doc_491521502230_item	2636892	et	4	main
kõrgkultuurid	doc_491521502230_item	2636895	et	3	main
ta	doc_491521502230_item	2636898	et	4	main
territooriumile	doc_491521502230_item	2636904	et	3	main
et	doc_491521502230_item	2636906	et	3	main
pronks	doc_491521502230_item	2636907	et	3	main
jõudis	doc_491521502230_item	2636908	et	3	main
eestisse	doc_491521502230_item	2636909	et	4	main
väide	doc_491521502230_item	2636913	et	4	main
see	doc_491521502230_item	2636915	et	3	main
et	doc_491521502230_item	2636916	et	3	main
pronks	doc_491521502230_item	2636917	et	3	main
jõudis	doc_491521502230_item	2636918	et	3	main
eestisse	doc_491521502230_item	2636919	et	4	main
skandinaaviast	doc_491521502230_item	2636920	et	3	main
ümbervalama	doc_491521502230_item	2636941	et	4	main
keskel	doc_491521502230_item	2636948	et	3	main
saj	doc_491521502230_item	2636951	et	4	main
peale	doc_491521502230_item	2636953	et	4	main
kasutati	doc_491521502230_item	2636955	et	4	main
veel	doc_491521502230_item	2636956	et	4	main
mitmel	doc_491521502230_item	2636962	et	4	main
pool	doc_491521502230_item	2636963	et	4	main
tekivad	doc_491521502230_item	2636969	et	3	main
asulad-hooned	doc_491521502230_item	2636972	et	4	main
viljelusmajandusele	doc_491521502230_item	2636975	et	3	main
olid	doc_491521502230_item	2636988	et	4	main
levisid	doc_491521502230_item	2636999	et	4	main
varane	doc_491521502230_item	2637003	et	4	main
saaremaalt	doc_491521502230_item	2636934	et	4	main
peal	doc_491521502230_item	2636940	et	4	main
peetakse	doc_491521502230_item	2636945	et	3	main
ii	doc_491521502230_item	2636946	et	4	main
aastatuhande	doc_491521502230_item	2636947	et	4	main
ekr	doc_491521502230_item	2636952	et	4	main
kivist	doc_491521502230_item	2636960	et	4	main
terariistu	doc_491521502230_item	2636961	et	3	main
asulad	doc_491521502230_item	2636968	et	3	main
nisu	doc_491521502230_item	2636982	et	4	main
ja	doc_491521502230_item	2636983	et	3	main
põllusaadusi	doc_491521502230_item	2636984	et	3	main
loomi	doc_491521502230_item	2636987	et	4	main
kitsed	doc_491521502230_item	2636989	et	3	main
ka	doc_491521502230_item	2636993	et	3	main
hobuseid	doc_491521502230_item	2636995	et	4	main
ka	doc_491521502230_item	2637000	et	3	main
rauda	doc_491521502230_item	2637009	et	4	main
kontrolltöö	doc_491521502232_item	2637341	et	4	main
1	doc_491521502232_item	2637342	et	2	main
tooge	doc_491521502232_item	2637343	et	3	main
välja	doc_491521502232_item	2637344	et	4	main
peamised	doc_491521502232_item	2637345	et	3	main
ensv	doc_491521502232_item	2637349	et	4	main
kui	doc_491521502232_item	2637356	et	3	main
nn	doc_491521502232_item	2637360	et	4	main
hrustshovi	doc_491521502232_item	2637361	et	4	main
rahval	doc_491521502232_item	2637368	et	3	main
ise	doc_491521502232_item	2637373	et	4	main
puudus	doc_491521502232_item	2637375	et	4	main
paljusus	doc_491521502232_item	2637388	et	4	main
oli	doc_491521502232_item	2637389	et	3	main
keelatud	doc_491521502232_item	2637390	et	4	main
puudus	doc_491521502232_item	2637395	et	4	main
kohus	doc_491521502232_item	2637397	et	4	main
ning	doc_491521502232_item	2637398	et	3	main
aja	doc_491521502232_item	2637400	et	4	main
kirjandus	doc_491521502232_item	2637401	et	3	main
võim	doc_491521502232_item	2637402	et	3	main
koondus	doc_491521502232_item	2637403	et	4	main
polnud	doc_491521502232_item	2637426	et	3	main
kõik	doc_491521502232_item	2637433	et	4	main
ning	doc_491521502232_item	2637436	et	3	main
neid	doc_491521502232_item	2637440	et	4	main
saadi	doc_491521502232_item	2637441	et	4	main
olles	doc_491521502232_item	2637446	et	3	main
võrdsetes	doc_491521502232_item	2637456	et	4	main
tingimustes	doc_491521502232_item	2637457	et	3	main
kolhooside	doc_491521502232_item	2637473	et	3	main
ning	doc_491521502232_item	2637474	et	3	main
hiljem	doc_491521502232_item	2637475	et	3	main
sohvooside	doc_491521502232_item	2637476	et	4	main
kehtisid	doc_491521502232_item	2637483	et	4	main
majanduses	doc_491521502232_item	2637352	et	4	main
mida	doc_491521502232_item	2637354	et	4	main
ensv	doc_491521502232_item	2637364	et	4	main
tekkis	doc_491521502232_item	2637365	et	3	main
võimalus	doc_491521502232_item	2637370	et	3	main
esindusorganeid	doc_491521502232_item	2637372	et	3	main
vaba	doc_491521502232_item	2637399	et	4	main
ning	doc_491521502232_item	2637421	et	3	main
riigi	doc_491521502232_item	2637423	et	3	main
rahval	doc_491521502232_item	2637425	et	3	main
tegelikult	doc_491521502232_item	2637427	et	4	main
tutvused	doc_491521502232_item	2637432	et	3	main
hüved	doc_491521502232_item	2637437	et	3	main
defitsiitsed	doc_491521502232_item	2637439	et	3	main
või	doc_491521502232_item	2637445	et	4	main
kuid	doc_491521502232_item	2637458	et	4	main
järgi	doc_491521502232_item	2637481	et	4	main
tuli	doc_491521502232_item	2637487	et	4	main
vastavalt	doc_491521502232_item	2637495	et	4	main
ülevalt	doc_491521502232_item	2637496	et	4	main
pädevad	doc_491521502232_item	2637503	et	3	main
viljanormidega	doc_491521502232_item	2637522	et	3	main
astujaid	doc_491521502232_item	2637541	et	4	main
lihtsalt	doc_491521502232_item	2637547	et	4	main
asumisele	doc_491521502232_item	2637551	et	4	main
ühiskonna	doc_491521502232_item	2637555	et	4	main
rehva	doc_491521502232_item	2637559	et	4	main
kirjanikud	doc_491521502232_item	2637566	et	3	main
nende	doc_491521502232_item	2637569	et	4	main
kohtadele	doc_491521502232_item	2637570	et	3	main
pädevad	doc_491521502232_item	2637573	et	3	main
uusi	doc_491521502232_item	2637579	et	3	main
endise	doc_491521502232_item	2637598	et	3	main
taunitav	doc_491521502232_item	2637608	et	4	main
ka	doc_491521502232_item	2637610	et	3	main
erinevused	doc_491521502232_item	2637346	et	4	main
ühiskonnakorralduses	doc_491521502232_item	2637350	et	3	main
reziim	doc_491521502232_item	2637367	et	4	main
valida	doc_491521502232_item	2637374	et	3	main
sõna	doc_491521502232_item	2637376	et	4	main
rahvas	doc_491521502232_item	2637379	et	4	main
keelati	doc_491521502232_item	2637391	et	4	main
ka	doc_491521502232_item	2637392	et	3	main
seltside	doc_491521502232_item	2637393	et	3	main
sõltumatu	doc_491521502232_item	2637396	et	4	main
ja	doc_491521502232_item	2637348	et	3	main
2	doc_491521502232_item	2637353	et	2	main
kutluuriajaloos	doc_491521502232_item	2637358	et	4	main
totalitaarne	doc_491521502232_item	2637366	et	3	main
rahva	doc_491521502232_item	2637371	et	3	main
kogu	doc_491521502232_item	2637378	et	4	main
kontrolli	doc_491521502232_item	2637382	et	4	main
hirmu	doc_491521502232_item	2637383	et	4	main
ning	doc_491521502232_item	2637384	et	3	main
terrori	doc_491521502232_item	2637385	et	3	main
all	doc_491521502232_item	2637386	et	3	main
parteide	doc_491521502232_item	2637387	et	3	main
votsialistlik	doc_491521502232_item	2637409	et	4	main
ühiskonnamudel	doc_491521502232_item	2637410	et	3	main
muudeti	doc_491521502232_item	2637422	et	3	main
omandisk	doc_491521502232_item	2637424	et	4	main
prioriteediks	doc_491521502232_item	2637429	et	3	main
sidemed	doc_491521502232_item	2637431	et	3	main
toit	doc_491521502232_item	2637435	et	3	main
läbi	doc_491521502232_item	2637443	et	4	main
tutvuste	doc_491521502232_item	2637444	et	3	main
nomenklatuuri	doc_491521502232_item	2637448	et	4	main
teelikult	doc_491521502232_item	2637459	et	4	main
nn	doc_491521502232_item	2637484	et	4	main
täita	doc_491521502232_item	2637488	et	4	main
arvestatud	doc_491521502232_item	2637502	et	4	main
miinimumi	doc_491521502232_item	2637512	et	4	main
piirides	doc_491521502232_item	2637513	et	3	main
kätte	doc_491521502232_item	2637514	et	4	main
et	doc_491521502232_item	2637525	et	3	main
ajal	doc_491521502232_item	2637534	et	4	main
ei	doc_491521502232_item	2637535	et	4	main
neid	doc_491521502232_item	2637546	et	4	main
1949	doc_491521502232_item	2637552	et	2	main
muust	doc_491521502232_item	2637577	et	4	main
kehtis	doc_491521502232_item	2637581	et	3	main
ankeedi	doc_491521502232_item	2637583	et	4	main
ülikooli	doc_491521502232_item	2637585	et	4	main
tööle	doc_491521502232_item	2637586	et	3	main
kooli	doc_491521502232_item	2637587	et	4	main
taunitav	doc_491521502232_item	2637595	et	4	main
ev	doc_491521502232_item	2637599	et	4	main
muu	doc_491521502232_item	2637602	et	4	main
järglane	doc_491521502232_item	2637607	et	3	main
ateism	doc_491521502232_item	2637614	et	3	main
ev	doc_491521502232_item	2637347	et	4	main
ja	doc_491521502232_item	2637351	et	3	main
mõeldakse	doc_491521502232_item	2637355	et	3	main
ensv	doc_491521502232_item	2637357	et	4	main
kõneldakse	doc_491521502232_item	2637359	et	3	main
sulast	doc_491521502232_item	2637362	et	4	main
1	doc_491521502232_item	2637363	et	2	main
puudus	doc_491521502232_item	2637369	et	4	main
vabadus	doc_491521502232_item	2637377	et	4	main
oli	doc_491521502232_item	2637380	et	3	main
riigi	doc_491521502232_item	2637381	et	3	main
tegevus	doc_491521502232_item	2637394	et	4	main
ühe	doc_491521502232_item	2637404	et	4	main
partei	doc_491521502232_item	2637405	et	4	main
ladviku	doc_491521502232_item	2637406	et	3	main
kätte	doc_491521502232_item	2637407	et	4	main
valitses	doc_491521502232_item	2637408	et	3	main
majandus	doc_491521502232_item	2637411	et	4	main
oli	doc_491521502232_item	2637412	et	3	main
oma	doc_491521502232_item	2637413	et	4	main
iseloomult	doc_491521502232_item	2637414	et	3	main
plaanimajandus	doc_491521502232_item	2637415	et	3	main
inimestel	doc_491521502232_item	2637416	et	3	main
puudus	doc_491521502232_item	2637417	et	4	main
eraomandiõigus	doc_491521502232_item	2637418	et	4	main
maa	doc_491521502232_item	2637419	et	4	main
natsionaliseeriti	doc_491521502232_item	2637420	et	3	main
väärtust	doc_491521502232_item	2637428	et	4	main
ainult	doc_491521502232_item	2637442	et	4	main
riigi	doc_491521502232_item	2637447	et	3	main
liige	doc_491521502232_item	2637449	et	4	main
kommunistlikku	doc_491521502232_item	2637451	et	4	main
koondunud	doc_491521502232_item	2637472	et	4	main
tööd	doc_491521502232_item	2637482	et	4	main
mida	doc_491521502232_item	2637486	et	4	main
saaki	doc_491521502232_item	2637490	et	4	main
poolt	doc_491521502232_item	2637497	et	4	main
ülemused	doc_491521502232_item	2637504	et	4	main
põllumajanduse	doc_491521502232_item	2637508	et	3	main
saadi	doc_491521502232_item	2637510	et	4	main
said	doc_491521502232_item	2637430	et	4	main
majatarbekaubad	doc_491521502232_item	2637434	et	3	main
olid	doc_491521502232_item	2637438	et	4	main
kuuludes	doc_491521502232_item	2637450	et	3	main
parteisse	doc_491521502232_item	2637452	et	3	main
näilised	doc_491521502232_item	2637453	et	3	main
elasid	doc_491521502232_item	2637454	et	4	main
inimesed	doc_491521502232_item	2637455	et	3	main
jätkus	doc_491521502232_item	2637460	et	4	main
riigi	doc_491521502232_item	2637461	et	3	main
poolt	doc_491521502232_item	2637462	et	4	main
pakutavaid	doc_491521502232_item	2637463	et	4	main
hüvesid	doc_491521502232_item	2637464	et	3	main
vaevaga	doc_491521502232_item	2637466	et	4	main
pooleks	doc_491521502232_item	2637467	et	4	main
ainult	doc_491521502232_item	2637465	et	4	main
ära	doc_491521502232_item	2637468	et	4	main
elamiseks	doc_491521502232_item	2637469	et	4	main
põllumajandus	doc_491521502232_item	2637470	et	3	main
oli	doc_491521502232_item	2637471	et	3	main
võrku	doc_491521502232_item	2637477	et	4	main
kus	doc_491521502232_item	2637478	et	3	main
tehti	doc_491521502232_item	2637479	et	3	main
plaani	doc_491521502232_item	2637480	et	4	main
päevanormid	doc_491521502232_item	2637485	et	3	main
ka	doc_491521502232_item	2637489	et	3	main
tuli	doc_491521502232_item	2637491	et	4	main
külvata	doc_491521502232_item	2637492	et	4	main
tulnud	doc_491521502232_item	2637498	et	4	main
käskudele	doc_491521502232_item	2637499	et	3	main
sageli	doc_491521502232_item	2637500	et	3	main
ei	doc_491521502232_item	2637501	et	4	main
ilmastikku	doc_491521502232_item	2637506	et	4	main
oludega	doc_491521502232_item	2637507	et	3	main
vähegi	doc_491521502232_item	2637515	et	4	main
rikkamad	doc_491521502232_item	2637516	et	4	main
endised	doc_491521502232_item	2637517	et	3	main
talupojad	doc_491521502232_item	2637518	et	4	main
suruti	doc_491521502232_item	2637519	et	3	main
maksudega	doc_491521502232_item	2637520	et	3	main
sinna	doc_491521502232_item	2637523	et	3	main
olid	doc_491521502232_item	2637527	et	4	main
kolhoosidesse	doc_491521502232_item	2637529	et	3	main
tahetud	doc_491521502232_item	2637536	et	4	main
ka	doc_491521502232_item	2637537	et	3	main
omal	doc_491521502232_item	2637538	et	3	main
soovil	doc_491521502232_item	2637539	et	3	main
kolhoosi	doc_491521502232_item	2637540	et	4	main
olid	doc_491521502232_item	2637543	et	4	main
saadeti	doc_491521502232_item	2637550	et	3	main
1941	doc_491521502232_item	2637553	et	2	main
maha	doc_491521502232_item	2637561	et	4	main
surumise	doc_491521502232_item	2637562	et	4	main
kultuuritegelased	doc_491521502232_item	2637565	et	3	main
rahvusest	doc_491521502232_item	2637578	et	4	main
võtmisel	doc_491521502232_item	2637588	et	4	main
esimestena	doc_491521502232_item	2637589	et	3	main
said	doc_491521502232_item	2637590	et	4	main
hariduse	doc_491521502232_item	2637591	et	3	main
proletariaadi	doc_491521502232_item	2637592	et	3	main
perekondadest	doc_491521502232_item	2637593	et	3	main
või	doc_491521502232_item	2637601	et	4	main
teeneka	doc_491521502232_item	2637603	et	3	main
inimese	doc_491521502232_item	2637604	et	4	main
poeg	doc_491521502232_item	2637605	et	3	main
ja	doc_491521502232_item	2637606	et	3	main
teretulnud	doc_491521502232_item	2637612	et	4	main
eesti	doc_491521502232_item	2637615	et	4	main
vabariigi	doc_491521502232_item	2637616	et	3	main
ühiskonna	doc_491521502232_item	2637617	et	4	main
ja	doc_491521502232_item	2637493	et	3	main
korjata	doc_491521502232_item	2637494	et	4	main
siinsete	doc_491521502232_item	2637505	et	4	main
toodangut	doc_491521502232_item	2637509	et	3	main
vaevu	doc_491521502232_item	2637511	et	4	main
ja	doc_491521502232_item	2637521	et	3	main
sunnitud	doc_491521502232_item	2637528	et	4	main
samas	doc_491521502232_item	2637531	et	4	main
esialgu	doc_491521502232_item	2637532	et	3	main
stalini	doc_491521502232_item	2637533	et	4	main
küüditamislained	doc_491521502232_item	2637554	et	3	main
oli	doc_491521502232_item	2637557	et	3	main
ka	doc_491521502232_item	2637558	et	3	main
kultuuri	doc_491521502232_item	2637560	et	4	main
vähe	doc_491521502232_item	2637572	et	3	main
või	doc_491521502232_item	2637575	et	4	main
koguni	doc_491521502232_item	2637576	et	4	main
tegijaid	doc_491521502232_item	2637580	et	4	main
mõiste	doc_491521502232_item	2637584	et	4	main
lapsed	doc_491521502232_item	2637594	et	3	main
oli	doc_491521502232_item	2637596	et	3	main
riigiametniku	doc_491521502232_item	2637600	et	3	main
oli	doc_491521502232_item	2637609	et	3	main
usutunnistus	doc_491521502232_item	2637611	et	3	main
oli	doc_491521502232_item	2637613	et	3	main
maale	doc_491521502232_item	2637524	et	4	main
nad	doc_491521502232_item	2637526	et	3	main
astuma	doc_491521502232_item	2637530	et	3	main
kes	doc_491521502232_item	2637542	et	4	main
nn	doc_491521502232_item	2637544	et	4	main
kulakud	doc_491521502232_item	2637545	et	3	main
represseriti	doc_491521502232_item	2637548	et	4	main
ja	doc_491521502232_item	2637549	et	3	main
korralduses	doc_491521502232_item	2637556	et	4	main
tendents	doc_491521502232_item	2637563	et	3	main
endised	doc_491521502232_item	2637564	et	3	main
teadusearendajad	doc_491521502232_item	2637567	et	3	main
represseeriti	doc_491521502232_item	2637568	et	3	main
paigutati	doc_491521502232_item	2637571	et	3	main
vene-eestlased	doc_491521502232_item	2637574	et	3	main
puhta	doc_491521502232_item	2637582	et	4	main
olla	doc_491521502232_item	2637597	et	3	main
korraldus	doc_491521502232_item	2637618	et	4	main
oli	doc_491521502232_item	2637619	et	3	main
kapitalistlikel	doc_491521502232_item	2637620	et	3	main
arendati	doc_491521502232_item	2637623	et	3	main
ning	doc_491521502232_item	2637625	et	3	main
ning	doc_491521502232_item	2637627	et	3	main
mugandati	doc_491521502232_item	2637630	et	3	main
erinevate	doc_491521502232_item	2637640	et	4	main
meediaallikate	doc_491521502232_item	2637641	et	3	main
leebe	doc_491521502232_item	2637644	et	4	main
kõrgem	doc_491521502232_item	2637649	et	4	main
oli	doc_491521502232_item	2637651	et	3	main
konstitutsiooni	doc_491521502232_item	2637655	et	4	main
kehtis	doc_491521502232_item	2637657	et	3	main
seal	doc_491521502232_item	2637659	et	4	main
töörahva	doc_491521502232_item	2637660	et	3	main
tegelikult	doc_491521502232_item	2637663	et	4	main
ajal	doc_491521502232_item	2637671	et	4	main
oli	doc_491521502232_item	2637672	et	3	main
eesti	doc_491521502232_item	2637674	et	4	main
keel	doc_491521502232_item	2637675	et	4	main
oli	doc_491521502232_item	2637679	et	3	main
mil	doc_491521502232_item	2637682	et	4	main
aastatel	doc_491521502232_item	2637684	et	4	main
autritoorse	doc_491521502232_item	2637686	et	4	main
pätsi	doc_491521502232_item	2637688	et	4	main
ning	doc_491521502232_item	2637693	et	3	main
hirmu	doc_491521502232_item	2637694	et	4	main
ev	doc_491521502232_item	2637699	et	4	main
turumajandus	doc_491521502232_item	2637719	et	3	main
kuhu	doc_491521502232_item	2637723	et	3	main
otseselt	doc_491521502232_item	2637725	et	4	main
sekkunud	doc_491521502232_item	2637727	et	4	main
oli	doc_491521502232_item	2637750	et	3	main
ka	doc_491521502232_item	2637751	et	3	main
tööpuudus	doc_491521502232_item	2637752	et	3	main
mida	doc_491521502232_item	2637753	et	4	main
ei	doc_491521502232_item	2637765	et	4	main
ideoloogilist	doc_491521502232_item	2637768	et	4	main
propagandat	doc_491521502232_item	2637769	et	3	main
inimeselt	doc_491521502232_item	2637770	et	3	main
said	doc_491521502232_item	2637771	et	4	main
et	doc_491521502232_item	2637776	et	3	main
rohkem	doc_491521502232_item	2637780	et	4	main
talupoeg	doc_491521502232_item	2637786	et	3	main
2	doc_491521502232_item	2637791	et	2	main
räägitakse	doc_491521502232_item	2637793	et	3	main
inimesteni	doc_491521502232_item	2637822	et	3	main
seni	doc_491521502232_item	2637824	et	3	main
kulu	doc_491521502232_item	2637825	et	4	main
all	doc_491521502232_item	2637826	et	3	main
raamatukogu	doc_491521502232_item	2637836	et	4	main
esseid	doc_491521502232_item	2637837	et	3	main
inimeste	doc_491521502232_item	2637845	et	3	main
suurenesid	doc_491521502232_item	2637847	et	4	main
tõlke	doc_491521502232_item	2637855	et	4	main
eestis	doc_491521502232_item	2637856	et	3	main
korraldatakse	doc_491521502232_item	2637857	et	3	main
džässifestivale	doc_491521502232_item	2637858	et	2	main
tekkib	doc_491521502232_item	2637859	et	3	main
küll	doc_491521502232_item	2637860	et	4	main
muusika	doc_491521502232_item	2637864	et	4	main
dissidentide	doc_491521502232_item	2637868	et	3	main
tööstust	doc_491521502232_item	2637624	et	4	main
eesti	doc_491521502232_item	2637634	et	4	main
vabariigis	doc_491521502232_item	2637635	et	3	main
valitses	doc_491521502232_item	2637636	et	3	main
sõnavabadus	doc_491521502232_item	2637637	et	4	main
usustunnistuse	doc_491521502232_item	2637638	et	4	main
vabadus	doc_491521502232_item	2637639	et	4	main
kehtis	doc_491521502232_item	2637645	et	3	main
kõige	doc_491521502232_item	2637648	et	4	main
rahvas	doc_491521502232_item	2637653	et	4	main
ülemvõi	doc_491521502232_item	2637661	et	4	main
see	doc_491521502232_item	2637665	et	3	main
partei	doc_491521502232_item	2637667	et	4	main
kätte	doc_491521502232_item	2637668	et	4	main
asjaajamiskeeleks	doc_491521502232_item	2637673	et	4	main
esimese	doc_491521502232_item	2637676	et	3	main
ev	doc_491521502232_item	2637677	et	4	main
riigi	doc_491521502232_item	2637680	et	3	main
korralduse	doc_491521502232_item	2637681	et	4	main
viimastel	doc_491521502232_item	2637683	et	3	main
koondunud	doc_491521502232_item	2637685	et	4	main
kätte	doc_491521502232_item	2637689	et	4	main
valitsust	doc_491521502232_item	2637695	et	4	main
polnud	doc_491521502232_item	2637698	et	3	main
mis	doc_491521502232_item	2637705	et	4	main
lubas	doc_491521502232_item	2637706	et	3	main
vahemusrahvastel	doc_491521502232_item	2637707	et	4	main
algharidust	doc_491521502232_item	2637711	et	4	main
seltsiliikumist	doc_491521502232_item	2637712	et	3	main
ning	doc_491521502232_item	2637713	et	3	main
välja	doc_491521502232_item	2637715	et	4	main
ning	doc_491521502232_item	2637720	et	3	main
kapitalistlikud	doc_491521502232_item	2637721	et	3	main
rahvas	doc_491521502232_item	2637728	et	4	main
sai	doc_491521502232_item	2637729	et	4	main
reaalset	doc_491521502232_item	2637730	et	3	main
palka	doc_491521502232_item	2637731	et	4	main
ning	doc_491521502232_item	2637732	et	3	main
oli	doc_491521502232_item	2637733	et	3	main
stiimul	doc_491521502232_item	2637734	et	3	main
enesearendamiseks	doc_491521502232_item	2637735	et	3	main
ning	doc_491521502232_item	2637736	et	3	main
täiendamiseks	doc_491521502232_item	2637737	et	4	main
parema	doc_491521502232_item	2637740	et	4	main
saadi	doc_491521502232_item	2637742	et	4	main
seda	doc_491521502232_item	2637743	et	3	main
kuid	doc_491521502232_item	2637757	et	4	main
kõikidele	doc_491521502232_item	2637761	et	4	main
demokraatlikele	doc_491521502232_item	2637762	et	3	main
riikidele	doc_491521502232_item	2637763	et	3	main
rahvale	doc_491521502232_item	2637764	et	3	main
peale	doc_491521502232_item	2637767	et	4	main
ning	doc_491521502232_item	2637774	et	3	main
elada	doc_491521502232_item	2637778	et	3	main
tööd	doc_491521502232_item	2637781	et	4	main
kuuluda	doc_491521502232_item	2637785	et	4	main
iseenda	doc_491521502232_item	2637789	et	3	main
kui	doc_491521502232_item	2637792	et	3	main
lõdvenes	doc_491521502232_item	2637821	et	3	main
sidemed	doc_491521502232_item	2637830	et	3	main
ilmus	doc_491521502232_item	2637834	et	4	main
loomingu	doc_491521502232_item	2637835	et	3	main
ning	doc_491521502232_item	2637838	et	3	main
kirjanike	doc_491521502232_item	2637839	et	3	main
teoseid	doc_491521502232_item	2637840	et	3	main
ilmus	doc_491521502232_item	2637841	et	4	main
ka	doc_491521502232_item	2637842	et	3	main
alustel	doc_491521502232_item	2637621	et	4	main
majandust	doc_491521502232_item	2637626	et	4	main
siis	doc_491521502232_item	2637629	et	3	main
valitsev	doc_491521502232_item	2637632	et	4	main
kord	doc_491521502232_item	2637633	et	4	main
oli	doc_491521502232_item	2637643	et	3	main
palju	doc_491521502232_item	2637646	et	4	main
võimukandja	doc_491521502232_item	2637650	et	4	main
ensv	doc_491521502232_item	2637654	et	4	main
ka	doc_491521502232_item	2637658	et	3	main
kuid	doc_491521502232_item	2637662	et	4	main
k	doc_491521502232_item	2637687	et	4	main
terrorit	doc_491521502232_item	2637692	et	3	main
nagu	doc_491521502232_item	2637696	et	3	main
ensv	doc_491521502232_item	2637697	et	4	main
aastas	doc_491521502232_item	2637701	et	3	main
vahemusrahvaste	doc_491521502232_item	2637703	et	4	main
kultuuriautonoomia	doc_491521502232_item	2637704	et	4	main
keelset	doc_491521502232_item	2637710	et	3	main
majanduses	doc_491521502232_item	2637717	et	4	main
valitses	doc_491521502232_item	2637718	et	3	main
sest	doc_491521502232_item	2637738	et	4	main
hariduse	doc_491521502232_item	2637741	et	3	main
paremad	doc_491521502232_item	2637744	et	4	main
tuleviku	doc_491521502232_item	2637745	et	4	main
ja	doc_491521502232_item	2637746	et	3	main
ensv-s	doc_491521502232_item	2637754	et	3	main
näiliselt	doc_491521502232_item	2637755	et	4	main
polnud	doc_491521502232_item	2637756	et	3	main
on	doc_491521502232_item	2637759	et	4	main
omane	doc_491521502232_item	2637760	et	3	main
vabalt	doc_491521502232_item	2637772	et	4	main
selleks	doc_491521502232_item	2637775	et	4	main
tarvitses	doc_491521502232_item	2637779	et	3	main
mitte	doc_491521502232_item	2637783	et	3	main
oli	doc_491521502232_item	2637787	et	3	main
peremee	doc_491521502232_item	2637790	et	3	main
kultuuriloos	doc_491521502232_item	2637795	et	4	main
hruštšovi	doc_491521502232_item	2637797	et	2	main
jõudsid	doc_491521502232_item	2637823	et	4	main
olnud	doc_491521502232_item	2637827	et	4	main
tugevnesid	doc_491521502232_item	2637829	et	4	main
1965	doc_491521502232_item	2637832	et	2	main
palju	doc_491521502232_item	2637843	et	4	main
teos	doc_491521502232_item	2637854	et	4	main
kujul	doc_491521502232_item	2637862	et	4	main
kuulamise	doc_491521502232_item	2637865	et	4	main
peamised	doc_491521502233_item	2637874	et	3	main
majanduses	doc_491521502233_item	2637881	et	4	main
vabariik	doc_491521502233_item	2637895	et	3	main
sotsialistlik	doc_491521502233_item	2637899	et	3	main
ensv	doc_491521502233_item	2637901	et	4	main
valitses	doc_491521502233_item	2637903	et	3	main
majanduses	doc_491521502233_item	2637904	et	4	main
planeerimine	doc_491521502233_item	2637905	et	4	main
tööpäev	doc_491521502233_item	2637906	et	3	main
oli	doc_491521502233_item	2637907	et	3	main
igal	doc_491521502233_item	2637912	et	3	main
poolt	doc_491521502233_item	2637916	et	4	main
ka	doc_491521502233_item	2637918	et	3	main
muud	doc_491521502233_item	2637921	et	4	main
asutused	doc_491521502233_item	2637922	et	4	main
täitma	doc_491521502233_item	2637925	et	3	main
paljud	doc_491521502233_item	2637926	et	3	main
tehased	doc_491521502233_item	2637927	et	3	main
olid	doc_491521502233_item	2637928	et	4	main
kinni	doc_491521502233_item	2637929	et	3	main
olid	doc_491521502233_item	2637937	et	4	main
ei	doc_491521502233_item	2637942	et	4	main
olid	doc_491521502233_item	2637949	et	4	main
riik	doc_491521502233_item	2637953	et	3	main
rasketööstust	doc_491521502233_item	2637956	et	4	main
sinna	doc_491521502233_item	2637972	et	3	main
peamiselt	doc_491521502233_item	2637974	et	4	main
jõukamad	doc_491521502233_item	2637975	et	4	main
inimesed	doc_491521502233_item	2637976	et	3	main
käskis	doc_491521502233_item	2637985	et	4	main
mida	doc_491521502233_item	2637986	et	4	main
rajatud	doc_491521502232_item	2637622	et	4	main
alles	doc_491521502232_item	2637628	et	3	main
sellega	doc_491521502232_item	2637631	et	3	main
tsensuur	doc_491521502232_item	2637642	et	3	main
parteisus	doc_491521502232_item	2637647	et	4	main
riigis	doc_491521502232_item	2637652	et	3	main
järgi	doc_491521502232_item	2637656	et	4	main
oli	doc_491521502232_item	2637664	et	3	main
koondunud	doc_491521502232_item	2637666	et	4	main
kuid	doc_491521502232_item	2637690	et	4	main
kehtis	doc_491521502232_item	2637700	et	3	main
1925	doc_491521502232_item	2637702	et	2	main
oma	doc_491521502232_item	2637709	et	4	main
andmist	doc_491521502232_item	2637716	et	4	main
eesti	doc_491521502232_item	2637669	et	4	main
vabariigi	doc_491521502232_item	2637670	et	3	main
ajal	doc_491521502232_item	2637678	et	4	main
sellist	doc_491521502232_item	2637691	et	4	main
saada	doc_491521502232_item	2637708	et	4	main
ajakirjade	doc_491521502232_item	2637714	et	3	main
tootmissuhted	doc_491521502232_item	2637722	et	3	main
riik	doc_491521502232_item	2637724	et	3	main
ei	doc_491521502232_item	2637726	et	4	main
mida	doc_491521502232_item	2637739	et	4	main
karjääri	doc_491521502232_item	2637747	et	4	main
väljavaated	doc_491521502232_item	2637748	et	3	main
olid	doc_491521502232_item	2637749	et	4	main
see	doc_491521502232_item	2637758	et	3	main
surud	doc_491521502232_item	2637766	et	4	main
reisid	doc_491521502232_item	2637773	et	4	main
paremini	doc_491521502232_item	2637777	et	4	main
teha	doc_491521502232_item	2637782	et	3	main
parteisse	doc_491521502232_item	2637784	et	3	main
omal	doc_491521502232_item	2637788	et	3	main
siis	doc_491521502232_item	2637799	et	3	main
mõeldakse	doc_491521502232_item	2637800	et	3	main
selle	doc_491521502232_item	2637801	et	4	main
all	doc_491521502232_item	2637802	et	3	main
1956	doc_491521502232_item	2637803	et	2	main
a	doc_491521502232_item	2637804	et	4	main
stalini	doc_491521502232_item	2637806	et	4	main
kuritegude	doc_491521502232_item	2637807	et	3	main
toimunud	doc_491521502232_item	2637805	et	4	main
paljastamisega	doc_491521502232_item	2637808	et	4	main
kaasnenud	doc_491521502232_item	2637809	et	4	main
paljude	doc_491521502232_item	2637810	et	3	main
eesti	doc_491521502232_item	2637811	et	4	main
kirjanikke	doc_491521502232_item	2637812	et	3	main
rehabiliteerimist	doc_491521502232_item	2637813	et	4	main
fr	doc_491521502232_item	2637814	et	4	main
tuglas	doc_491521502232_item	2637815	et	4	main
k	doc_491521502232_item	2637816	et	4	main
merilaas	doc_491521502232_item	2637817	et	3	main
j	doc_491521502232_item	2637818	et	4	main
kross	doc_491521502232_item	2637819	et	3	main
tsensuur	doc_491521502232_item	2637820	et	3	main
raamatud	doc_491521502232_item	2637828	et	4	main
paguluskirjanikega	doc_491521502232_item	2637831	et	3	main
aastal	doc_491521502232_item	2637833	et	3	main
tõlkekirjandust	doc_491521502232_item	2637844	et	3	main
ilmus	doc_491521502232_item	2637848	et	4	main
ka	doc_491521502232_item	2637849	et	3	main
bulkakovi	doc_491521502232_item	2637850	et	4	main
meister	doc_491521502232_item	2637851	et	3	main
ja	doc_491521502232_item	2637852	et	3	main
lääneliku	doc_491521502232_item	2637863	et	4	main
võimalus	doc_491521502232_item	2637866	et	3	main
aktiviseerub	doc_491521502232_item	2637867	et	3	main
ensv	doc_491521502233_item	2637878	et	4	main
ühiskonnakorralduses	doc_491521502233_item	2637879	et	3	main
ja	doc_491521502233_item	2637880	et	3	main
ev	doc_491521502233_item	2637893	et	4	main
eesti	doc_491521502233_item	2637897	et	4	main
vabariik	doc_491521502233_item	2637900	et	3	main
ensv	doc_491521502232_item	2637794	et	4	main
nn	doc_491521502232_item	2637796	et	4	main
sulast	doc_491521502232_item	2637798	et	4	main
ensv	doc_491521502233_item	2637886	et	4	main
kutluuriajaloos	doc_491521502233_item	2637887	et	4	main
kõneldakse	doc_491521502233_item	2637888	et	3	main
nn	doc_491521502233_item	2637889	et	4	main
hrustshovi	doc_491521502233_item	2637890	et	4	main
sulast	doc_491521502233_item	2637891	et	4	main
kultuurikontaktid	doc_491521502232_item	2637846	et	3	main
margarita	doc_491521502232_item	2637853	et	4	main
varjatud	doc_491521502232_item	2637861	et	4	main
1	doc_491521502233_item	2637871	et	2	main
erinevused	doc_491521502233_item	2637875	et	4	main
ev	doc_491521502233_item	2637876	et	4	main
ja	doc_491521502233_item	2637877	et	3	main
eesti	doc_491521502233_item	2637894	et	4	main
nõukogude	doc_491521502233_item	2637898	et	3	main
päeval	doc_491521502233_item	2637913	et	3	main
tegevus	doc_491521502232_item	2637869	et	4	main
kontrolltöö	doc_491521502233_item	2637870	et	4	main
tooge	doc_491521502233_item	2637872	et	3	main
välja	doc_491521502233_item	2637873	et	4	main
2	doc_491521502233_item	2637882	et	2	main
mida	doc_491521502233_item	2637883	et	4	main
mõeldakse	doc_491521502233_item	2637884	et	3	main
kui	doc_491521502233_item	2637885	et	3	main
1	doc_491521502233_item	2637892	et	2	main
ensv	doc_491521502233_item	2637896	et	4	main
maht	doc_491521502233_item	2637911	et	3	main
oli	doc_491521502233_item	2637914	et	3	main
ja	doc_491521502233_item	2637920	et	3	main
pidid	doc_491521502233_item	2637923	et	4	main
seda	doc_491521502233_item	2637924	et	3	main
ei	doc_491521502233_item	2637933	et	4	main
jätkunud	doc_491521502233_item	2637934	et	4	main
natsionaliseeritud	doc_491521502233_item	2637940	et	4	main
tohtinud	doc_491521502233_item	2637943	et	4	main
pangad	doc_491521502233_item	2637946	et	3	main
tööstusasutused	doc_491521502233_item	2637948	et	4	main
ära	doc_491521502233_item	2637951	et	4	main
sohvoosid	doc_491521502233_item	2637971	et	4	main
seda	doc_491521502233_item	2638008	et	3	main
muutusid	doc_491521502233_item	2638012	et	4	main
olid	doc_491521502233_item	2638022	et	4	main
ka	doc_491521502233_item	2638023	et	3	main
riigistatud	doc_491521502233_item	2638024	et	4	main
pidi	doc_491521502233_item	2638026	et	4	main
varustama	doc_491521502233_item	2638027	et	3	main
riigisüsteem	doc_491521502233_item	2638036	et	3	main
süsteemile	doc_491521502233_item	2638039	et	3	main
oli	doc_491521502233_item	2638043	et	3	main
see	doc_491521502233_item	2638045	et	3	main
ensv	doc_491521502233_item	2638047	et	4	main
ülemnõukoguks	doc_491521502233_item	2638048	et	3	main
oli	doc_491521502233_item	2638052	et	3	main
täitev	doc_491521502233_item	2638057	et	4	main
peaparteiks	doc_491521502233_item	2638059	et	3	main
sellele	doc_491521502233_item	2638062	et	4	main
mis	doc_491521502233_item	2638069	et	4	main
majandust	doc_491521502233_item	2638073	et	4	main
poliitilist	doc_491521502233_item	2638074	et	3	main
süsteemi	doc_491521502233_item	2638075	et	4	main
see	doc_491521502233_item	2638076	et	3	main
suunda	doc_491521502233_item	2638080	et	4	main
omandab	doc_491521502233_item	2638087	et	3	main
keelatud	doc_491521502233_item	2638121	et	4	main
harrastusi	doc_491521502233_item	2638122	et	4	main
ja	doc_491521502233_item	2638123	et	3	main
eriseltse	doc_491521502233_item	2638124	et	3	main
ja	doc_491521502233_item	2638129	et	3	main
represseeriti	doc_491521502233_item	2638131	et	3	main
kirjasõna	doc_491521502233_item	2638139	et	4	main
nkgb	doc_491521502233_item	2638144	et	4	main
avatakse	doc_491521502233_item	2638155	et	4	main
lastele	doc_491521502233_item	2638157	et	4	main
kus	doc_491521502233_item	2638161	et	3	main
ja	doc_491521502233_item	2638165	et	3	main
tulevad	doc_491521502233_item	2638168	et	4	main
maadest	doc_491521502233_item	2638171	et	4	main
rajoonid	doc_491521502233_item	2638177	et	4	main
isoleeritud	doc_491521502233_item	2638179	et	4	main
rangelt	doc_491521502233_item	2637908	et	4	main
planeeritud	doc_491521502233_item	2637909	et	4	main
riigi	doc_491521502233_item	2637915	et	3	main
planeeritud	doc_491521502233_item	2637917	et	4	main
pandud	doc_491521502233_item	2637930	et	4	main
kõik	doc_491521502233_item	2637935	et	4	main
riigistanud	doc_491521502233_item	2637938	et	4	main
kõik	doc_491521502233_item	2637945	et	4	main
tehased	doc_491521502233_item	2637947	et	3	main
hakkas	doc_491521502233_item	2637954	et	3	main
forseerima	doc_491521502233_item	2637955	et	4	main
toetas	doc_491521502233_item	2637958	et	3	main
kosmonautikat	doc_491521502233_item	2637959	et	4	main
paljud	doc_491521502233_item	2637960	et	3	main
teadusharud	doc_491521502233_item	2637961	et	3	main
olid	doc_491521502233_item	2637962	et	4	main
vaenlasteadusteks	doc_491521502233_item	2637963	et	4	main
tunnistatud	doc_491521502233_item	2637964	et	4	main
ajal	doc_491521502233_item	2637902	et	4	main
tootmise	doc_491521502233_item	2637910	et	4	main
tehased	doc_491521502233_item	2637919	et	3	main
sest	doc_491521502233_item	2637931	et	4	main
töölisi	doc_491521502233_item	2637932	et	3	main
asutused	doc_491521502233_item	2637936	et	4	main
tähendab	doc_491521502233_item	2637939	et	3	main
eraomandust	doc_491521502233_item	2637941	et	3	main
olla	doc_491521502233_item	2637944	et	3	main
omanikutelt	doc_491521502233_item	2637950	et	4	main
võetud	doc_491521502233_item	2637952	et	4	main
küberneetika	doc_491521502233_item	2637965	et	4	main
ja	doc_491521502233_item	2637970	et	3	main
nad	doc_491521502233_item	2637978	et	3	main
oma	doc_491521502233_item	2637980	et	4	main
kaotada	doc_491521502233_item	2637982	et	3	main
kommunistlik	doc_491521502233_item	2637983	et	3	main
partei	doc_491521502233_item	2637984	et	4	main
sellele	doc_491521502233_item	2637990	et	4	main
harud	doc_491521502233_item	2637994	et	3	main
olid	doc_491521502233_item	2637996	et	4	main
oma	doc_491521502233_item	2638004	et	4	main
saaks	doc_491521502233_item	2638010	et	3	main
sest	doc_491521502233_item	2638014	et	4	main
nad	doc_491521502233_item	2638015	et	3	main
len	doc_491521502233_item	2638028	et	4	main
intensiivselt	doc_491521502233_item	2638033	et	4	main
eesti	doc_491521502233_item	2638035	et	4	main
vastavaks	doc_491521502233_item	2638040	et	4	main
ev	doc_491521502233_item	2638041	et	4	main
muutus	doc_491521502233_item	2638046	et	4	main
esimeheks	doc_491521502233_item	2638051	et	3	main
vares-barbarus	doc_491521502233_item	2638054	et	4	main
sai	doc_491521502233_item	2638060	et	4	main
kõik	doc_491521502233_item	2638064	et	4	main
eluharud	doc_491521502233_item	2638065	et	3	main
sotsialism	doc_491521502233_item	2638068	et	3	main
arengu	doc_491521502233_item	2638079	et	3	main
vahendeid	doc_491521502233_item	2638082	et	3	main
privileege	doc_491521502233_item	2638089	et	3	main
tohtinud	doc_491521502233_item	2638126	et	4	main
kunstnikke	doc_491521502233_item	2638128	et	3	main
või	doc_491521502233_item	2638132	et	4	main
oli	doc_491521502233_item	2638135	et	3	main
piiratud	doc_491521502233_item	2638136	et	4	main
tsensuur	doc_491521502233_item	2638137	et	3	main
hävitatakse	doc_491521502233_item	2638140	et	3	main
olid	doc_491521502233_item	2638147	et	4	main
kui	doc_491521502233_item	2638149	et	3	main
majad	doc_491521502233_item	2638160	et	3	main
eestlased	doc_491521502233_item	2638162	et	3	main
194719505	doc_491521502233_item	2638167	et	2	main
ida-virumaale	doc_491521502233_item	2638173	et	4	main
on	doc_491521502233_item	2638175	et	4	main
stalini	doc_491521502233_item	2638203	et	4	main
kultus	doc_491521502233_item	2638204	et	3	main
ja	doc_491521502233_item	2637957	et	3	main
tekkima	doc_491521502233_item	2637968	et	3	main
sest	doc_491521502233_item	2637977	et	4	main
kasvatad	doc_491521502233_item	2637989	et	3	main
loomi	doc_491521502233_item	2638001	et	4	main
ja	doc_491521502233_item	2638002	et	3	main
et	doc_491521502233_item	2638006	et	3	main
ei	doc_491521502233_item	2638009	et	4	main
need	doc_491521502233_item	2638021	et	3	main
sellepärast	doc_491521502233_item	2638031	et	3	main
muutus	doc_491521502233_item	2638037	et	4	main
ajal	doc_491521502233_item	2638042	et	4	main
volikogu	doc_491521502233_item	2638044	et	4	main
presiidiumi	doc_491521502233_item	2638050	et	4	main
oli	doc_491521502233_item	2638056	et	3	main
ekвp	doc_491521502233_item	2638061	et	2	main
riigikorraks	doc_491521502233_item	2638066	et	3	main
kohe	doc_491521502233_item	2638070	et	4	main
hakkas	doc_491521502233_item	2638071	et	3	main
ümberkorraldama	doc_491521502233_item	2638072	et	4	main
ühiskondkiku	doc_491521502233_item	2638078	et	4	main
valis	doc_491521502233_item	2638081	et	3	main
võim	doc_491521502233_item	2638086	et	3	main
läbi	doc_491521502233_item	2638091	et	4	main
viidud	doc_491521502233_item	2638092	et	4	main
haldusreform	doc_491521502233_item	2638093	et	3	main
3	doc_491521502233_item	2638094	et	2	main
oblastit	doc_491521502233_item	2638095	et	3	main
muutus	doc_491521502233_item	2638097	et	4	main
rajooniks	doc_491521502233_item	2638098	et	4	main
vald	doc_491521502233_item	2638099	et	3	main
maakond	doc_491521502233_item	2638096	et	3	main
külanõukoguks	doc_491521502233_item	2638100	et	3	main
tänavad	doc_491521502233_item	2638101	et	4	main
ümbernimetatud	doc_491521502233_item	2638103	et	4	main
2	doc_491521502233_item	2638104	et	2	main
hruštšovi	doc_491521502233_item	2638105	et	2	main
olid	doc_491521502233_item	2638102	et	4	main
sula	doc_491521502233_item	2638106	et	4	main
1957-1968	doc_491521502233_item	2638107	et	2	main
aa	doc_491521502233_item	2638108	et	3	main
sotsialistlik	doc_491521502233_item	2638109	et	3	main
realism	doc_491521502233_item	2638110	et	3	main
põhivool	doc_491521502233_item	2638111	et	4	main
suunatud	doc_491521502233_item	2638112	et	4	main
parema	doc_491521502233_item	2638113	et	4	main
poole	doc_491521502233_item	2638114	et	4	main
euroopa	doc_491521502233_item	2638115	et	4	main
stiile	doc_491521502233_item	2638116	et	3	main
ja	doc_491521502233_item	2638117	et	3	main
voole	doc_491521502233_item	2638118	et	4	main
keelati	doc_491521502233_item	2638119	et	4	main
geneetika	doc_491521502233_item	2637966	et	4	main
hakkasid	doc_491521502233_item	2637967	et	4	main
kolhoosid	doc_491521502233_item	2637969	et	3	main
astusid	doc_491521502233_item	2637973	et	4	main
kartsid	doc_491521502233_item	2637979	et	4	main
varandust	doc_491521502233_item	2637981	et	3	main
kõik	doc_491521502233_item	2637992	et	4	main
pm	doc_491521502233_item	2637993	et	4	main
inimesed	doc_491521502233_item	2637995	et	3	main
selle	doc_491521502233_item	2637997	et	4	main
vastu	doc_491521502233_item	2637998	et	3	main
ja	doc_491521502233_item	2637999	et	3	main
tapsid	doc_491521502233_item	2638000	et	4	main
varandust	doc_491521502233_item	2638005	et	3	main
riik	doc_491521502233_item	2638007	et	3	main
talud	doc_491521502233_item	2638011	et	4	main
eluvõimalitteks	doc_491521502233_item	2638013	et	4	main
pidid	doc_491521502233_item	2638016	et	4	main
maksma	doc_491521502233_item	2638017	et	3	main
riigile	doc_491521502233_item	2638018	et	3	main
suuri	doc_491521502233_item	2638019	et	3	main
makse	doc_491521502233_item	2638020	et	4	main
ja	doc_491521502233_item	2637987	et	3	main
kuidas	doc_491521502233_item	2637988	et	3	main
allusid	doc_491521502233_item	2637991	et	4	main
rikkusid	doc_491521502233_item	2638003	et	4	main
eesti	doc_491521502233_item	2638025	et	4	main
oblastit	doc_491521502233_item	2638029	et	3	main
energiaga	doc_491521502233_item	2638030	et	3	main
kaevandati	doc_491521502233_item	2638032	et	3	main
põlevkivi	doc_491521502233_item	2638034	et	4	main
nk	doc_491521502233_item	2638038	et	4	main
varem	doc_491521502233_item	2638049	et	4	main
j	doc_491521502233_item	2638053	et	4	main
linnades	doc_491521502233_item	2638055	et	3	main
komitee	doc_491521502233_item	2638058	et	4	main
allusid	doc_491521502233_item	2638063	et	4	main
ja	doc_491521502233_item	2638083	et	3	main
poliitiline	doc_491521502233_item	2638085	et	3	main
majanduslikke	doc_491521502233_item	2638088	et	3	main
ei	doc_491521502233_item	2638125	et	4	main
kirjanikke	doc_491521502233_item	2638130	et	3	main
eesti	doc_491521502233_item	2638138	et	4	main
julgeoleku	doc_491521502233_item	2638141	et	3	main
eestis	doc_491521502233_item	2638143	et	3	main
keelatud	doc_491521502233_item	2638148	et	4	main
ei	doc_491521502233_item	2638151	et	4	main
vastanud	doc_491521502233_item	2638152	et	4	main
ekвp	doc_491521502233_item	2638153	et	2	main
eesmärkidele	doc_491521502233_item	2638154	et	3	main
eesti	doc_491521502233_item	2638159	et	4	main
kokku	doc_491521502233_item	2638164	et	3	main
suhtlesid	doc_491521502233_item	2638166	et	4	main
muudest	doc_491521502233_item	2638170	et	4	main
peamiselt	doc_491521502233_item	2638172	et	4	main
ja	doc_491521502233_item	2638178	et	3	main
muutus	doc_491521502233_item	2638067	et	4	main
määras	doc_491521502233_item	2638077	et	4	main
kaade	doc_491521502233_item	2638084	et	4	main
oli	doc_491521502233_item	2638090	et	3	main
seltsitegevus	doc_491521502233_item	2638120	et	4	main
olla	doc_491521502233_item	2638127	et	3	main
vangistati	doc_491521502233_item	2638133	et	4	main
trükivabadus	doc_491521502233_item	2638134	et	4	main
komitee	doc_491521502233_item	2638142	et	4	main
algüksus	doc_491521502233_item	2638145	et	3	main
ajalehed	doc_491521502233_item	2638146	et	3	main
nad	doc_491521502233_item	2638150	et	3	main
pühapäevakoolid	doc_491521502233_item	2638156	et	3	main
avatakse	doc_491521502233_item	2638158	et	4	main
said	doc_491521502233_item	2638163	et	4	main
töölised	doc_491521502233_item	2638169	et	3	main
seal	doc_491521502233_item	2638174	et	4	main
tsoonid	doc_491521502233_item	2638180	et	3	main
berio	doc_491521502233_item	2638181	et	4	main
ideede	doc_491521502233_item	2638182	et	3	main
viimine	doc_491521502233_item	2638184	et	4	main
püüdis	doc_491521502233_item	2638185	et	3	main
metsavendade	doc_491521502233_item	2638186	et	3	main
läbi	doc_491521502233_item	2638183	et	4	main
tegevust	doc_491521502233_item	2638187	et	4	main
suundada	doc_491521502233_item	2638188	et	4	main
tiigi	doc_491521502233_item	2638189	et	3	main
kasuks	doc_491521502233_item	2638190	et	4	main
hakkavad	doc_491521502233_item	2638191	et	4	main
eestisse	doc_491521502233_item	2638192	et	4	main
tagasi	doc_491521502233_item	2638193	et	3	main
tegelased	doc_491521502233_item	2638194	et	3	main
kes	doc_491521502233_item	2638195	et	4	main
olid	doc_491521502233_item	2638196	et	4	main
represseeritu	doc_491521502233_item	2638197	et	4	main
enne	doc_491521502233_item	2638198	et	4	main
sead	doc_491521502233_item	2638199	et	4	main
oli	doc_491521502233_item	2638200	et	3	main
tunnistatud	doc_491521502233_item	2638201	et	4	main
nn	doc_491521502233_item	2638202	et	4	main
majanduslikud	doc_491521502233_item	2638176	et	3	main
tooge	doc_491521502235_item	2638519	et	3	main
peamised	doc_491521502235_item	2638521	et	3	main
erinevused	doc_491521502235_item	2638522	et	4	main
riigikogu	doc_491521502235_item	2638542	et	4	main
nimetati	doc_491521502235_item	2638543	et	4	main
ümber	doc_491521502235_item	2638544	et	3	main
ensv	doc_491521502235_item	2638545	et	4	main
ülemkogu	doc_491521502235_item	2638546	et	4	main
lauristin	doc_491521502235_item	2638556	et	4	main
kolhoseerimise	doc_491521502235_item	2638571	et	4	main
märgatav	doc_491521502235_item	2638583	et	4	main
murrang	doc_491521502235_item	2638584	et	3	main
tugevneva	doc_491521502235_item	2638593	et	4	main
stalinismiga	doc_491521502235_item	2638594	et	4	main
liidus	doc_491521502235_item	2638596	et	4	main
teisalt	doc_491521502235_item	2638597	et	4	main
võimu	doc_491521502235_item	2638600	et	4	main
stalinistide	doc_491521502235_item	2638603	et	4	main
rünnak	doc_491521502235_item	2638604	et	3	main
pealetungiga	doc_491521502235_item	2638606	et	4	main
ja	doc_491521502235_item	2638612	et	3	main
enam	doc_491521502235_item	2638619	et	4	main
ja	doc_491521502235_item	2638623	et	3	main
kõrvaldati	doc_491521502235_item	2638624	et	3	main
eesti	doc_491521502235_item	2638626	et	4	main
teaduse	doc_491521502235_item	2638627	et	3	main
akadeemia	doc_491521502235_item	2638628	et	4	main
allutati	doc_491521502235_item	2638629	et	3	main
stalinistide	doc_491521502235_item	2638637	et	4	main
eesti	doc_491521502235_item	2638640	et	4	main
sotsiaalne	doc_491521502235_item	2638643	et	3	main
1	doc_491521502235_item	2638518	et	2	main
ja	doc_491521502235_item	2638527	et	3	main
majanduses	doc_491521502235_item	2638528	et	4	main
ensv	doc_491521502235_item	2638533	et	4	main
a	doc_491521502235_item	2638541	et	4	main
esimees	doc_491521502235_item	2638548	et	4	main
oma	doc_491521502235_item	2638562	et	4	main
ei	doc_491521502235_item	2638569	et	4	main
üldine	doc_491521502235_item	2638573	et	4	main
vabariigi	doc_491521502235_item	2638577	et	3	main
1947-1948	doc_491521502235_item	2638579	et	2	main
a	doc_491521502235_item	2638580	et	4	main
toimus	doc_491521502235_item	2638581	et	3	main
eesti	doc_491521502235_item	2638582	et	4	main
on	doc_491521502235_item	2638588	et	4	main
see	doc_491521502235_item	2638589	et	3	main
murrang	doc_491521502235_item	2638590	et	3	main
eesti	doc_491521502235_item	2638607	et	4	main
haridussüsteemi	doc_491521502235_item	2638611	et	4	main
eesti	doc_491521502235_item	2638613	et	4	main
üha	doc_491521502235_item	2638618	et	3	main
kontrolltöö	doc_491521502235_item	2638517	et	4	main
ensv	doc_491521502235_item	2638525	et	4	main
ühiskonnakorralduses	doc_491521502235_item	2638526	et	3	main
2	doc_491521502235_item	2638529	et	2	main
mida	doc_491521502235_item	2638530	et	4	main
mõeldakse	doc_491521502235_item	2638531	et	3	main
kui	doc_491521502235_item	2638532	et	3	main
kõneldakse	doc_491521502235_item	2638535	et	3	main
hrustshovi	doc_491521502235_item	2638537	et	4	main
sulast	doc_491521502235_item	2638538	et	4	main
1	doc_491521502235_item	2638539	et	2	main
25081940	doc_491521502235_item	2638540	et	2	main
oli	doc_491521502235_item	2638549	et	3	main
j	doc_491521502235_item	2638555	et	4	main
täitevkomiteediteks	doc_491521502235_item	2638559	et	4	main
oli	doc_491521502235_item	2638561	et	3	main
välisministeerium	doc_491521502235_item	2638563	et	3	main
ja	doc_491521502235_item	2638564	et	3	main
sõjavägi	doc_491521502235_item	2638565	et	3	main
mensavendadele	doc_491521502235_item	2638566	et	4	main
lubati	doc_491521502235_item	2638567	et	3	main
amnestiat	doc_491521502235_item	2638568	et	3	main
välja	doc_491521502235_item	2638520	et	4	main
ev	doc_491521502235_item	2638523	et	4	main
ja	doc_491521502235_item	2638524	et	3	main
kutluuriajaloos	doc_491521502235_item	2638534	et	4	main
nn	doc_491521502235_item	2638536	et	4	main
presiidiumi	doc_491521502235_item	2638547	et	4	main
j	doc_491521502235_item	2638550	et	4	main
vares-barbarus	doc_491521502235_item	2638551	et	4	main
poliitiline	doc_491521502235_item	2638552	et	3	main
liider	doc_491521502235_item	2638553	et	3	main
oli	doc_491521502235_item	2638554	et	3	main
omavalitsused	doc_491521502235_item	2638557	et	3	main
muudeti	doc_491521502235_item	2638558	et	3	main
ensv-l	doc_491521502235_item	2638560	et	3	main
eesti	doc_491521502235_item	2638576	et	4	main
traditsioone	doc_491521502235_item	2638578	et	3	main
suunas	doc_491521502235_item	2638586	et	4	main
üha	doc_491521502235_item	2638592	et	3	main
ensv	doc_491521502235_item	2638595	et	4	main
nõukogude	doc_491521502235_item	2638599	et	3	main
positsioonid	doc_491521502235_item	2638601	et	3	main
senist	doc_491521502235_item	2638610	et	3	main
kõlbmatuks	doc_491521502235_item	2638622	et	3	main
ta-le	doc_491521502235_item	2638632	et	3	main
majanduslik	doc_491521502235_item	2638642	et	3	main
tasalülitamine	doc_491521502235_item	2638646	et	3	main
ülejaanud	doc_491521502235_item	2638647	et	4	main
ensv	doc_491521502235_item	2638648	et	4	main
liiduga	doc_491521502235_item	2638649	et	3	main
1950	doc_491521502235_item	2638650	et	2	main
inimestevahelised	doc_491521502235_item	2638654	et	4	main
suhted	doc_491521502235_item	2638655	et	3	main
kahlustamine	doc_491521502235_item	2638659	et	4	main
sagenes	doc_491521502235_item	2638660	et	3	main
soosimisel	doc_491521502235_item	2638669	et	4	main
vastu	doc_491521502235_item	2638675	et	3	main
kolhoosidesse	doc_491521502235_item	2638705	et	3	main
oli	doc_491521502235_item	2638713	et	3	main
tsiviilühiskond	doc_491521502235_item	2638715	et	3	main
ja	doc_491521502235_item	2638717	et	3	main
äärel	doc_491521502235_item	2638721	et	3	main
raskemaid	doc_491521502235_item	2638727	et	4	main
senises	doc_491521502235_item	2638730	et	3	main
rahva	doc_491521502235_item	2638732	et	3	main
jätkus	doc_491521502235_item	2638740	et	4	main
nii	doc_491521502235_item	2638744	et	3	main
ensv	doc_491521502235_item	2638746	et	4	main
ja	doc_491521502235_item	2638750	et	3	main
keskorganid	doc_491521502235_item	2638752	et	3	main
otsustati	doc_491521502235_item	2638762	et	3	main
1944-1947	doc_491521502235_item	2638766	et	2	main
ensv-s	doc_491521502235_item	2638767	et	3	main
kultuuriajaloost	doc_491521502235_item	2638779	et	4	main
et	doc_491521502235_item	2638786	et	3	main
hakkas	doc_491521502235_item	2638788	et	3	main
sündmused	doc_491521502235_item	2638800	et	3	main
siis	doc_491521502235_item	2638802	et	3	main
rääkida	doc_491521502235_item	2638804	et	3	main
et	doc_491521502235_item	2638811	et	3	main
taastada	doc_491521502235_item	2638813	et	3	main
ev	doc_491521502236_item	2638823	et	4	main
kui	doc_491521502236_item	2638832	et	3	main
kultuuriajaloos	doc_491521502236_item	2638834	et	4	main
1	doc_491521502236_item	2638839	et	2	main
ev	doc_491521502236_item	2638840	et	4	main
ja	doc_491521502236_item	2638841	et	3	main
ensv	doc_491521502236_item	2638842	et	4	main
eesti	doc_491521502236_item	2638849	et	4	main
ei	doc_491521502236_item	2638858	et	4	main
keelanud	doc_491521502236_item	2638870	et	4	main
inimeste	doc_491521502236_item	2638871	et	3	main
kuulevust	doc_491521502236_item	2638872	et	4	main
mingitesse	doc_491521502236_item	2638873	et	3	main
seltsidesse	doc_491521502236_item	2638874	et	3	main
ensv	doc_491521502236_item	2638880	et	4	main
palju	doc_491521502236_item	2638882	et	4	main
haridus	doc_491521502236_item	2638888	et	3	main
eesti	doc_491521502236_item	2638911	et	4	main
liikmed	doc_491521502236_item	2638918	et	3	main
alates	doc_491521502236_item	2638919	et	3	main
vastu	doc_491521502236_item	2638925	et	3	main
kultuuripoliitika	doc_491521502235_item	2638574	et	4	main
stalinismi	doc_491521502235_item	2638585	et	4	main
seotud	doc_491521502235_item	2638591	et	4	main
tugevnesid	doc_491521502235_item	2638598	et	4	main
eestis	doc_491521502235_item	2638602	et	3	main
algaski	doc_491521502235_item	2638605	et	4	main
kultuurielule	doc_491521502235_item	2638608	et	3	main
autorite	doc_491521502235_item	2638614	et	3	main
koostatud	doc_491521502235_item	2638616	et	4	main
kuulutati	doc_491521502235_item	2638621	et	4	main
ensv	doc_491521502235_item	2638630	et	4	main
majanduses	doc_491521502235_item	2638633	et	4	main
sotsialistikud	doc_491521502235_item	2638635	et	4	main
eesmärgiks	doc_491521502235_item	2638638	et	3	main
oli	doc_491521502235_item	2638639	et	3	main
poliitiline	doc_491521502235_item	2638641	et	3	main
ja	doc_491521502235_item	2638644	et	3	main
algul	doc_491521502235_item	2638652	et	4	main
teravnesid	doc_491521502235_item	2638653	et	4	main
arveid	doc_491521502235_item	2638664	et	3	main
ja	doc_491521502235_item	2638667	et	3	main
inimeste	doc_491521502235_item	2638672	et	3	main
äraproovitud	doc_491521502235_item	2638681	et	4	main
stalinlik	doc_491521502235_item	2638682	et	4	main
võte	doc_491521502235_item	2638683	et	3	main
1950	doc_491521502235_item	2638684	et	2	main
a	doc_491521502235_item	2638685	et	4	main
alguseks	doc_491521502235_item	2638686	et	4	main
oli	doc_491521502235_item	2638687	et	3	main
eesti	doc_491521502235_item	2638688	et	4	main
pärast	doc_491521502235_item	2638689	et	4	main
paljusid	doc_491521502235_item	2638690	et	3	main
vapustusi	doc_491521502235_item	2638691	et	4	main
enam-vähem	doc_491521502235_item	2638692	et	3	main
samal	doc_491521502235_item	2638693	et	3	main
tasemel	doc_491521502235_item	2638694	et	3	main
kui	doc_491521502235_item	2638695	et	3	main
ensv	doc_491521502235_item	2638696	et	4	main
liit	doc_491521502235_item	2638697	et	3	main
iseseisvad	doc_491521502235_item	2638698	et	3	main
rõhutatud	doc_491521502235_item	2638570	et	4	main
sundust	doc_491521502235_item	2638572	et	4	main
järgis	doc_491521502235_item	2638575	et	4	main
osalt	doc_491521502235_item	2638587	et	4	main
kritiseeriti	doc_491521502235_item	2638609	et	3	main
poolt	doc_491521502235_item	2638615	et	4	main
õpikud	doc_491521502235_item	2638617	et	3	main
raamatuid	doc_491521502235_item	2638620	et	3	main
käibet	doc_491521502235_item	2638625	et	4	main
liidu	doc_491521502235_item	2638631	et	3	main
süvenes	doc_491521502235_item	2638634	et	3	main
ümberkorraldused	doc_491521502235_item	2638636	et	3	main
a	doc_491521502235_item	2638651	et	4	main
levis	doc_491521502235_item	2638656	et	4	main
hirm	doc_491521502235_item	2638657	et	3	main
vanu	doc_491521502235_item	2638663	et	4	main
teadmisel	doc_491521502235_item	2638666	et	4	main
koguni	doc_491521502235_item	2638668	et	4	main
ässitati	doc_491521502235_item	2638670	et	3	main
seegi	doc_491521502235_item	2638676	et	4	main
ülejaanud	doc_491521502235_item	2638703	et	4	main
hirmuga	doc_491521502235_item	2638704	et	3	main
eesti	doc_491521502235_item	2638714	et	4	main
katastroofi	doc_491521502235_item	2638720	et	4	main
aegu	doc_491521502235_item	2638728	et	4	main
eesti	doc_491521502235_item	2638731	et	4	main
liidu	doc_491521502235_item	2638735	et	3	main
allutatud	doc_491521502235_item	2638738	et	4	main
industrialiseerimine	doc_491521502235_item	2638741	et	4	main
sõjajärgsel	doc_491521502235_item	2638742	et	3	main
partei	doc_491521502235_item	2638748	et	4	main
majanduslikud	doc_491521502235_item	2638751	et	3	main
sel	doc_491521502235_item	2638755	et	3	main
loodud	doc_491521502235_item	2638757	et	4	main
ümberjaotumine	doc_491521502235_item	2638760	et	3	main
moskvas	doc_491521502235_item	2638764	et	4	main
aastal	doc_491521502235_item	2638765	et	3	main
927049	doc_491521502235_item	2638768	et	2	main
2	doc_491521502235_item	2638776	et	2	main
sulast	doc_491521502235_item	2638783	et	4	main
kohanemise	doc_491521502235_item	2638806	et	4	main
süsteemist	doc_491521502235_item	2638807	et	4	main
erinevused	doc_491521502236_item	2638822	et	4	main
mida	doc_491521502236_item	2638830	et	4	main
mõeldakse	doc_491521502236_item	2638831	et	3	main
sulast	doc_491521502236_item	2638838	et	4	main
seisnesid	doc_491521502236_item	2638846	et	4	main
ei	doc_491521502236_item	2638853	et	4	main
andnud	doc_491521502236_item	2638859	et	4	main
käsklusi	doc_491521502236_item	2638860	et	3	main
tegutsemist	doc_491521502236_item	2638879	et	4	main
inimesi	doc_491521502236_item	2638883	et	4	main
keelne	doc_491521502236_item	2638887	et	3	main
valida	doc_491521502236_item	2638916	et	3	main
riigikogu	doc_491521502236_item	2638917	et	4	main
20	doc_491521502236_item	2638920	et	2	main
sai	doc_491521502236_item	2638930	et	4	main
valida	doc_491521502236_item	2638931	et	3	main
milles	doc_491521502236_item	2638932	et	3	main
olid	doc_491521502236_item	2638938	et	4	main
keeles	doc_491521502236_item	2638942	et	4	main
kuulus	doc_491521502236_item	2638949	et	4	main
moskvale	doc_491521502236_item	2638956	et	4	main
paljudesse	doc_491521502236_item	2638970	et	3	main
nimetused	doc_491521502236_item	2638974	et	4	main
kuni	doc_491521502236_item	2639004	et	3	main
oli	doc_491521502236_item	2639007	et	3	main
suurtööstuse	doc_491521502236_item	2639009	et	3	main
majanduse	doc_491521502236_item	2639015	et	4	main
evs	doc_491521502236_item	2639017	et	4	main
evs	doc_491521502236_item	2639018	et	4	main
toimus	doc_491521502236_item	2639019	et	3	main
nii	doc_491521502236_item	2639122	et	3	main
kultuuriline	doc_491521502235_item	2638645	et	4	main
süvenes	doc_491521502235_item	2638658	et	3	main
pealekabamine	doc_491521502235_item	2638661	et	3	main
klaariti	doc_491521502235_item	2638662	et	3	main
riigivõimu	doc_491521502235_item	2638665	et	4	main
terveid	doc_491521502235_item	2638671	et	4	main
gruppe	doc_491521502235_item	2638673	et	3	main
liidus	doc_491521502235_item	2638680	et	4	main
siberisse	doc_491521502235_item	2638701	et	4	main
küüditatud	doc_491521502235_item	2638702	et	4	main
astunud	doc_491521502235_item	2638706	et	4	main
metsavahendus	doc_491521502235_item	2638710	et	3	main
üksteise	doc_491521502235_item	2638674	et	4	main
oli	doc_491521502235_item	2638677	et	3	main
juba	doc_491521502235_item	2638678	et	3	main
ensv	doc_491521502235_item	2638679	et	4	main
põllumehed	doc_491521502235_item	2638699	et	3	main
ja	doc_491521502235_item	2638707	et	3	main
laostunud	doc_491521502235_item	2638709	et	4	main
nõrgenes	doc_491521502235_item	2638711	et	3	main
terve	doc_491521502235_item	2638718	et	4	main
eesti	doc_491521502235_item	2638719	et	4	main
1940-1950	doc_491521502235_item	2638722	et	2	main
vahetus	doc_491521502235_item	2638724	et	4	main
oon	doc_491521502235_item	2638725	et	4	main
kahtlemata	doc_491521502235_item	2638726	et	4	main
kogu	doc_491521502235_item	2638729	et	4	main
ajaloos	doc_491521502235_item	2638733	et	4	main
tsentraliseeritud	doc_491521502235_item	2638736	et	4	main
juhtimissüsteemide	doc_491521502235_item	2638737	et	3	main
eestis	doc_491521502235_item	2638739	et	3	main
nagu	doc_491521502235_item	2638745	et	3	main
pidasid	doc_491521502235_item	2638754	et	4	main
teel	doc_491521502235_item	2638756	et	4	main
väärtuste	doc_491521502235_item	2638758	et	4	main
aga	doc_491521502235_item	2638761	et	3	main
ha	doc_491521502235_item	2638769	et	4	main
maad	doc_491521502235_item	2638770	et	4	main
milles	doc_491521502235_item	2638771	et	3	main
242022	doc_491521502235_item	2638772	et	2	main
ha	doc_491521502235_item	2638773	et	4	main
olid	doc_491521502235_item	2638700	et	4	main
need	doc_491521502235_item	2638708	et	3	main
sisuselt	doc_491521502235_item	2638712	et	4	main
hävitatud	doc_491521502235_item	2638716	et	4	main
a	doc_491521502235_item	2638723	et	4	main
ensv	doc_491521502235_item	2638734	et	4	main
perioodil	doc_491521502235_item	2638743	et	3	main
liidu	doc_491521502235_item	2638747	et	3	main
kasutamine	doc_491521502235_item	2638759	et	4	main
oli	doc_491521502235_item	2638774	et	3	main
ensv	doc_491521502235_item	2638778	et	4	main
nn	doc_491521502235_item	2638781	et	4	main
sis	doc_491521502235_item	2638784	et	3	main
paremini	doc_491521502235_item	2638790	et	4	main
kergemini	doc_491521502235_item	2638792	et	4	main
astusid	doc_491521502235_item	2638794	et	4	main
omatahtel	doc_491521502235_item	2638795	et	3	main
kommun	doc_491521502235_item	2638796	et	4	main
parteisse	doc_491521502235_item	2638797	et	3	main
1956	doc_491521502235_item	2638798	et	2	main
ungaris	doc_491521502235_item	2638801	et	4	main
võib	doc_491521502235_item	2638803	et	3	main
eestlaste	doc_491521502235_item	2638805	et	4	main
said	doc_491521502235_item	2638809	et	4	main
teada	doc_491521502235_item	2638810	et	3	main
ev	doc_491521502235_item	2638812	et	4	main
saa	doc_491521502235_item	2638816	et	4	main
ladvik	doc_491521502235_item	2638749	et	3	main
õigeks	doc_491521502235_item	2638753	et	3	main
põhiliselt	doc_491521502235_item	2638763	et	4	main
põldu	doc_491521502235_item	2638775	et	4	main
kui	doc_491521502235_item	2638777	et	3	main
hrustshovi	doc_491521502235_item	2638782	et	4	main
kõik	doc_491521502235_item	2638787	et	4	main
minema	doc_491521502235_item	2638789	et	3	main
ja	doc_491521502235_item	2638791	et	3	main
inimesed	doc_491521502235_item	2638793	et	3	main
eestlased	doc_491521502235_item	2638808	et	3	main
ei	doc_491521502235_item	2638815	et	4	main
1	doc_491521502236_item	2638818	et	2	main
ja	doc_491521502236_item	2638824	et	3	main
ensv	doc_491521502236_item	2638825	et	4	main
ühiskonnakorralduses	doc_491521502236_item	2638826	et	3	main
hrustshovi	doc_491521502236_item	2638837	et	4	main
peamised	doc_491521502236_item	2638843	et	3	main
erinevused	doc_491521502236_item	2638844	et	4	main
ühiskonnakorralduses	doc_491521502236_item	2638845	et	3	main
vabariigi	doc_491521502236_item	2638850	et	3	main
keegi	doc_491521502236_item	2638852	et	4	main
kontrollinud	doc_491521502236_item	2638854	et	4	main
riigikorraldust	doc_491521502236_item	2638855	et	3	main
tähendab	doc_491521502236_item	2638856	et	3	main
ei	doc_491521502236_item	2638861	et	4	main
ei	doc_491521502236_item	2638869	et	4	main
haritlasi	doc_491521502236_item	2638884	et	3	main
eesti	doc_491521502236_item	2638886	et	4	main
vene	doc_491521502236_item	2638890	et	4	main
keelseks	doc_491521502236_item	2638891	et	4	main
kui	doc_491521502236_item	2638892	et	3	main
ev	doc_491521502236_item	2638893	et	4	main
24021918	doc_491521502236_item	2638894	et	2	main
aastal	doc_491521502236_item	2638895	et	3	main
sai	doc_491521502236_item	2638896	et	4	main
oma	doc_491521502236_item	2638897	et	4	main
iseseisvuse	doc_491521502236_item	2638898	et	4	main
siis	doc_491521502236_item	2638899	et	3	main
moodustati	doc_491521502236_item	2638900	et	3	main
eestis	doc_491521502236_item	2638901	et	3	main
100-liikmeline	doc_491521502236_item	2638902	et	4	main
riigikogu	doc_491521502236_item	2638903	et	4	main
ning	doc_491521502236_item	2638904	et	3	main
esimene	doc_491521502236_item	2638905	et	3	main
riigivanem	doc_491521502236_item	2638906	et	4	main
oli	doc_491521502236_item	2638907	et	3	main
kpäts	doc_491521502236_item	2638908	et	4	main
ühiskonnakorraldus	doc_491521502236_item	2638909	et	3	main
oli	doc_491521502236_item	2638910	et	3	main
kõneldakse	doc_491521502235_item	2638780	et	3	main
mõeldakse	doc_491521502235_item	2638785	et	3	main
a	doc_491521502235_item	2638799	et	4	main
hiljem	doc_491521502235_item	2638814	et	3	main
kontrolltöö	doc_491521502236_item	2638817	et	4	main
tooge	doc_491521502236_item	2638819	et	3	main
välja	doc_491521502236_item	2638820	et	4	main
peamised	doc_491521502236_item	2638821	et	3	main
ja	doc_491521502236_item	2638827	et	3	main
majanduses	doc_491521502236_item	2638828	et	4	main
2	doc_491521502236_item	2638829	et	2	main
ensv	doc_491521502236_item	2638833	et	4	main
kõneldakse	doc_491521502236_item	2638835	et	3	main
nn	doc_491521502236_item	2638836	et	4	main
selles	doc_491521502236_item	2638847	et	4	main
et	doc_491521502236_item	2638848	et	3	main
ajal	doc_491521502236_item	2638851	et	4	main
keegi	doc_491521502236_item	2638857	et	4	main
andnud	doc_491521502236_item	2638862	et	4	main
käsklusi	doc_491521502236_item	2638863	et	3	main
nt	doc_491521502236_item	2638864	et	4	main
moskvast	doc_491521502236_item	2638865	et	4	main
kuidas	doc_491521502236_item	2638866	et	3	main
tuleb	doc_491521502236_item	2638867	et	3	main
elada	doc_491521502236_item	2638868	et	3	main
astumist	doc_491521502236_item	2638875	et	4	main
ega	doc_491521502236_item	2638876	et	3	main
muidugi	doc_491521502236_item	2638877	et	4	main
seltside	doc_491521502236_item	2638878	et	3	main
ajal	doc_491521502236_item	2638881	et	4	main
represeeriti	doc_491521502236_item	2638885	et	4	main
muutus	doc_491521502236_item	2638889	et	4	main
käes	doc_491521502236_item	2638913	et	4	main
kodanikud	doc_491521502236_item	2638914	et	3	main
võisid	doc_491521502236_item	2638915	et	4	main
aastast	doc_491521502236_item	2638921	et	4	main
isegi	doc_491521502236_item	2638922	et	4	main
1925a	doc_491521502236_item	2638923	et	4	main
vähemusrahvaste	doc_491521502236_item	2638926	et	4	main
tähendab	doc_491521502236_item	2638935	et	3	main
sel	doc_491521502236_item	2638936	et	3	main
ajal	doc_491521502236_item	2638937	et	4	main
rootsi	doc_491521502236_item	2638941	et	4	main
algkoolid	doc_491521502236_item	2638944	et	3	main
ajal	doc_491521502236_item	2638947	et	4	main
eesti	doc_491521502236_item	2638948	et	4	main
ja	doc_491521502236_item	2638952	et	3	main
pidi	doc_491521502236_item	2638953	et	4	main
alluma	doc_491521502236_item	2638954	et	3	main
ühiskonnakorralduses	doc_491521502236_item	2638955	et	3	main
eesti	doc_491521502236_item	2638961	et	4	main
olnud	doc_491521502236_item	2638963	et	4	main
iseseisev	doc_491521502236_item	2638964	et	3	main
ühiskonnakorralduses	doc_491521502236_item	2638965	et	3	main
ei	doc_491521502236_item	2638967	et	4	main
tohtinud	doc_491521502236_item	2638968	et	4	main
isegi	doc_491521502236_item	2638972	et	4	main
ja	doc_491521502236_item	2639000	et	3	main
alates	doc_491521502236_item	2639002	et	3	main
1924	doc_491521502236_item	2639005	et	2	main
paranemine	doc_491521502236_item	2639016	et	4	main
perioodil	doc_491521502236_item	2639031	et	3	main
palju	doc_491521502236_item	2639033	et	4	main
ensv	doc_491521502236_item	2639036	et	4	main
eesti	doc_491521502236_item	2639038	et	4	main
liidu	doc_491521502236_item	2639042	et	3	main
rajama	doc_491521502236_item	2639045	et	3	main
kaevandusi	doc_491521502236_item	2639047	et	4	main
harud	doc_491521502236_item	2639051	et	3	main
nagu	doc_491521502236_item	2639052	et	3	main
transport	doc_491521502236_item	2639054	et	3	main
jne	doc_491521502236_item	2639056	et	4	main
said	doc_491521502236_item	2639057	et	4	main
rahvamajanduses	doc_491521502236_item	2639058	et	3	main
1947	doc_491521502236_item	2639065	et	2	main
hakati	doc_491521502236_item	2639066	et	3	main
talud	doc_491521502236_item	2639072	et	4	main
ajal	doc_491521502236_item	2639077	et	4	main
oli	doc_491521502236_item	2639079	et	3	main
mida	doc_491521502236_item	2639084	et	4	main
ensv	doc_491521502236_item	2639091	et	4	main
võeti	doc_491521502236_item	2638924	et	3	main
koolis	doc_491521502236_item	2638933	et	4	main
vene	doc_491521502236_item	2638939	et	4	main
gümnaasiumid	doc_491521502236_item	2638945	et	3	main
tähendab	doc_491521502236_item	2638957	et	3	main
peamine	doc_491521502236_item	2638958	et	3	main
erinevus	doc_491521502236_item	2638959	et	4	main
et	doc_491521502236_item	2638960	et	3	main
kuuluda	doc_491521502236_item	2638969	et	4	main
ajakirjade	doc_491521502236_item	2638973	et	3	main
olid	doc_491521502236_item	2638975	et	4	main
muudetud	doc_491521502236_item	2638976	et	4	main
paljud	doc_491521502236_item	2638977	et	3	main
raamatud	doc_491521502236_item	2638978	et	4	main
kas	doc_491521502236_item	2638979	et	3	main
või	doc_491521502236_item	2638981	et	4	main
hävitatud	doc_491521502236_item	2638982	et	4	main
keelatud	doc_491521502236_item	2638980	et	4	main
ev	doc_491521502236_item	2638983	et	4	main
peamine	doc_491521502236_item	2638984	et	3	main
majanduselu	doc_491521502236_item	2638985	et	4	main
oli	doc_491521502236_item	2638986	et	3	main
suunatud	doc_491521502236_item	2638987	et	4	main
uute	doc_491521502236_item	2638988	et	3	main
välisturgude	doc_491521502236_item	2638989	et	3	main
leidmisele	doc_491521502236_item	2638990	et	4	main
rootsi	doc_491521502236_item	2638991	et	4	main
soome	doc_491521502236_item	2638992	et	3	main
uued	doc_491521502236_item	2638993	et	3	main
vene	doc_491521502236_item	2638994	et	4	main
vana	doc_491521502236_item	2638995	et	4	main
turgpeamised	doc_491521502236_item	2638996	et	4	main
tööstusharud	doc_491521502236_item	2638997	et	3	main
laevaehitus	doc_491521502236_item	2638998	et	4	main
suka-	doc_491521502236_item	2638999	et	3	main
valitsuse	doc_491521502236_item	2638912	et	4	main
autonoomia	doc_491521502236_item	2638927	et	4	main
seaduse	doc_491521502236_item	2638928	et	3	main
pisirahvas	doc_491521502236_item	2638929	et	4	main
käia	doc_491521502236_item	2638934	et	4	main
saksa	doc_491521502236_item	2638940	et	4	main
õppeasutused	doc_491521502236_item	2638943	et	4	main
ensv	doc_491521502236_item	2638946	et	4	main
nsv	doc_491521502236_item	2638950	et	4	main
koosseisu	doc_491521502236_item	2638951	et	4	main
ei	doc_491521502236_item	2638962	et	4	main
inimesed	doc_491521502236_item	2638966	et	3	main
seltsidesse	doc_491521502236_item	2638971	et	3	main
siidikoevabrik	doc_491521502236_item	2639001	et	3	main
eestis	doc_491521502236_item	2639006	et	3	main
kaasnes	doc_491521502236_item	2639013	et	3	main
veel	doc_491521502236_item	2639026	et	4	main
põlevkivitööstuse	doc_491521502236_item	2639027	et	3	main
ja	doc_491521502236_item	2639028	et	3	main
ettevõtteid	doc_491521502236_item	2639035	et	3	main
nsv	doc_491521502236_item	2639041	et	4	main
hakati	doc_491521502236_item	2639044	et	3	main
uusi	doc_491521502236_item	2639046	et	3	main
ja	doc_491521502236_item	2639048	et	3	main
ehitus	doc_491521502236_item	2639055	et	4	main
kolhoose	doc_491521502236_item	2639068	et	3	main
maa	doc_491521502236_item	2639071	et	4	main
1941a	doc_491521502236_item	2639073	et	4	main
siberisse	doc_491521502236_item	2639075	et	4	main
palju	doc_491521502236_item	2639080	et	4	main
ensv	doc_491521502236_item	2639085	et	4	main
ajal	doc_491521502236_item	2639086	et	4	main
keelati	doc_491521502236_item	2639087	et	4	main
püüti	doc_491521502236_item	2639093	et	3	main
hrustsovi	doc_491521502236_item	2639136	et	4	main
paremaks	doc_491521502236_item	2639143	et	4	main
kadus	doc_491521502236_item	2639144	et	3	main
stalini-aegne	doc_491521502236_item	2639145	et	3	main
taastus	doc_491521502236_item	2639149	et	4	main
side	doc_491521502236_item	2639150	et	4	main
varasema	doc_491521502236_item	2639151	et	4	main
laulupeol	doc_491521502236_item	2639160	et	4	main
lauldi	doc_491521502236_item	2639161	et	3	main
hümni	doc_491521502236_item	2639162	et	4	main
mu	doc_491521502236_item	2639163	et	3	main
isamaa	doc_491521502236_item	2639164	et	4	main
arm	doc_491521502236_item	2639165	et	3	main
isegi	doc_491521502236_item	2639172	et	4	main
enam	doc_491521502236_item	2639179	et	4	main
nii	doc_491521502236_item	2639182	et	3	main
nagu	doc_491521502236_item	2639185	et	3	main
1922	doc_491521502236_item	2639003	et	2	main
märgatav	doc_491521502236_item	2639008	et	4	main
brutotoodangu	doc_491521502236_item	2639010	et	3	main
sellega	doc_491521502236_item	2639012	et	3	main
rahareform	doc_491521502236_item	2639020	et	3	main
1928a	doc_491521502236_item	2639021	et	4	main
suur	doc_491521502236_item	2639022	et	3	main
majanduskasv	doc_491521502236_item	2639023	et	3	main
oli	doc_491521502236_item	2639024	et	3	main
metallitööstusega	doc_491521502236_item	2639029	et	3	main
rajati	doc_491521502236_item	2639032	et	3	main
uusi	doc_491521502236_item	2639034	et	3	main
töölisasulaid	doc_491521502236_item	2639049	et	4	main
juhtiva	doc_491521502236_item	2639059	et	4	main
koha	doc_491521502236_item	2639060	et	4	main
põllumajanduses	doc_491521502236_item	2639061	et	3	main
toimus	doc_491521502236_item	2639062	et	3	main
suur	doc_491521502236_item	2639063	et	3	main
muutus	doc_491521502236_item	2639064	et	4	main
võeti	doc_491521502236_item	2639069	et	3	main
ära	doc_491521502236_item	2639070	et	4	main
ev	doc_491521502236_item	2639076	et	4	main
teatreid	doc_491521502236_item	2639081	et	3	main
ajalehti	doc_491521502236_item	2639083	et	4	main
hävitati	doc_491521502236_item	2639089	et	3	main
kultuurielu	doc_491521502236_item	2639096	et	4	main
muidugi	doc_491521502236_item	2639098	et	4	main
peamine	doc_491521502236_item	2639099	et	3	main
vabaduses	doc_491521502236_item	2639101	et	4	main
suurem	doc_491521502236_item	2639102	et	4	main
erinevus	doc_491521502236_item	2639103	et	4	main
on	doc_491521502236_item	2639104	et	4	main
selles	doc_491521502236_item	2639105	et	4	main
ensvs	doc_491521502236_item	2639106	et	4	main
pidid	doc_491521502236_item	2639107	et	4	main
inimesed	doc_491521502236_item	2639108	et	3	main
ja	doc_491521502236_item	2639109	et	3	main
riigikorraldus	doc_491521502236_item	2639110	et	3	main
moskva	doc_491521502236_item	2639111	et	4	main
kontrolli	doc_491521502236_item	2639112	et	4	main
all	doc_491521502236_item	2639113	et	3	main
mulle	doc_491521502236_item	2639114	et	4	main
tundub	doc_491521502236_item	2639115	et	3	main
et	doc_491521502236_item	2639116	et	3	main
ev	doc_491521502236_item	2639117	et	4	main
ajal	doc_491521502236_item	2639118	et	4	main
oli	doc_491521502236_item	2639119	et	3	main
suur	doc_491521502236_item	2639120	et	3	main
ka	doc_491521502236_item	2639125	et	3	main
põllumajanduses	doc_491521502236_item	2639126	et	3	main
perioodiga	doc_491521502236_item	2639129	et	3	main
ensv	doc_491521502236_item	2639132	et	4	main
elu	doc_491521502236_item	2639140	et	4	main
hakkas	doc_491521502236_item	2639141	et	3	main
kultuurielus	doc_491521502236_item	2639148	et	4	main
kultuuriga	doc_491521502236_item	2639153	et	4	main
elu	doc_491521502236_item	2639156	et	4	main
avatus	doc_491521502236_item	2639157	et	4	main
võib	doc_491521502236_item	2639168	et	3	main
kultuuri	doc_491521502236_item	2639170	et	4	main
taaselustumiseks	doc_491521502236_item	2639171	et	4	main
kahekordistamine	doc_491521502236_item	2639011	et	3	main
ka	doc_491521502236_item	2639014	et	3	main
seotud	doc_491521502236_item	2639025	et	4	main
ev	doc_491521502236_item	2639030	et	4	main
oli	doc_491521502236_item	2639037	et	3	main
tihedam	doc_491521502236_item	2639039	et	4	main
integreerumine	doc_491521502236_item	2639040	et	4	main
majandussüsteemi	doc_491521502236_item	2639043	et	4	main
industriaalsed	doc_491521502236_item	2639050	et	3	main
tööstus	doc_491521502236_item	2639053	et	3	main
looma	doc_491521502236_item	2639067	et	4	main
küüditamine	doc_491521502236_item	2639074	et	4	main
ühiskonnakorralduses	doc_491521502236_item	2639078	et	3	main
seltse	doc_491521502236_item	2639082	et	3	main
või	doc_491521502236_item	2639088	et	4	main
ajal	doc_491521502236_item	2639092	et	4	main
suruda	doc_491521502236_item	2639095	et	3	main
kui	doc_491521502236_item	2639124	et	3	main
kui	doc_491521502236_item	2639131	et	3	main
sulast	doc_491521502236_item	2639137	et	4	main
mõeldakse	doc_491521502236_item	2639138	et	3	main
et	doc_491521502236_item	2639139	et	3	main
eksistentsiaalne	doc_491521502236_item	2639146	et	4	main
hirm	doc_491521502236_item	2639147	et	3	main
elavnes	doc_491521502236_item	2639154	et	3	main
ühiskondliku	doc_491521502236_item	2639155	et	3	main
aega	doc_491521502236_item	2639167	et	4	main
60ndatel	doc_491521502236_item	2639173	et	4	main
aastal	doc_491521502236_item	2639174	et	3	main
taastati	doc_491521502236_item	2639175	et	4	main
kontakt	doc_491521502236_item	2639176	et	3	main
ei	doc_491521502236_item	2639180	et	4	main
eestis	doc_491521502236_item	2639090	et	3	main
alla	doc_491521502236_item	2639094	et	3	main
kuid	doc_491521502236_item	2639097	et	4	main
erinevus	doc_491521502236_item	2639100	et	4	main
majanduskasv	doc_491521502236_item	2639121	et	3	main
tööstuses	doc_491521502236_item	2639123	et	3	main
võrreldes	doc_491521502236_item	2639127	et	3	main
ensv	doc_491521502236_item	2639128	et	4	main
2	doc_491521502236_item	2639130	et	2	main
kultuuriajaloos	doc_491521502236_item	2639133	et	4	main
kõneldakse	doc_491521502236_item	2639134	et	3	main
nn	doc_491521502236_item	2639135	et	4	main
muutuma	doc_491521502236_item	2639142	et	4	main
eesti	doc_491521502236_item	2639152	et	4	main
kirjade	doc_491521502236_item	2639158	et	3	main
vahetus	doc_491521502236_item	2639159	et	4	main
seda	doc_491521502236_item	2639166	et	3	main
pidada	doc_491521502236_item	2639169	et	4	main
olnud	doc_491521502236_item	2639181	et	4	main
keelatud	doc_491521502236_item	2639184	et	4	main
varem	doc_491521502236_item	2639186	et	4	main
euroopa	doc_491521502236_item	2639177	et	4	main
vaimueluga	doc_491521502236_item	2639178	et	3	main
palju	doc_491521502236_item	2639183	et	4	main
ev	doc_491521502238_item	2639522	et	4	main
2	doc_491521502238_item	2639528	et	2	main
mida	doc_491521502238_item	2639529	et	4	main
kui	doc_491521502238_item	2639531	et	3	main
hrustshovi	doc_491521502238_item	2639536	et	4	main
1	doc_491521502238_item	2639538	et	2	main
veebruar	doc_491521502238_item	2639540	et	3	main
kirjutati	doc_491521502238_item	2639542	et	3	main
ja	doc_491521502238_item	2639554	et	3	main
igaveseks	doc_491521502238_item	2639556	et	4	main
pidi	doc_491521502238_item	2639561	et	4	main
olema	doc_491521502238_item	2639562	et	4	main
venemaast	doc_491521502238_item	2639563	et	3	main
määrati	doc_491521502238_item	2639569	et	3	main
inimene	doc_491521502238_item	2639573	et	3	main
palju	doc_491521502238_item	2639577	et	4	main
mis	doc_491521502238_item	2639580	et	4	main
mõjutasid	doc_491521502238_item	2639581	et	4	main
elu	doc_491521502238_item	2639586	et	4	main
ev	doc_491521502238_item	2639588	et	4	main
nõukogude	doc_491521502238_item	2639594	et	3	main
barbarus	doc_491521502238_item	2639601	et	4	main
tööjõu	doc_491521502238_item	2639633	et	3	main
piirkondades	doc_491521502238_item	2639636	et	3	main
riigistamine	doc_491521502238_item	2639638	et	4	main
pöörduvad	doc_491521502238_item	2639644	et	4	main
tülli	doc_491521502238_item	2639645	et	4	main
asutati	doc_491521502238_item	2639655	et	4	main
toetas	doc_491521502238_item	2639660	et	3	main
valdkondi	doc_491521502238_item	2639663	et	4	main
kujutav-	doc_491521502238_item	2639670	et	4	main
ja	doc_491521502238_item	2639673	et	3	main
osa	doc_491521502238_item	2639675	et	4	main
elada	doc_491521502238_item	2639683	et	3	main
paljud	doc_491521502238_item	2639686	et	3	main
levinud	doc_491521502238_item	2639688	et	4	main
voolud	doc_491521502238_item	2639689	et	3	main
lammutama	doc_491521502238_item	2639697	et	4	main
represeeriti	doc_491521502238_item	2639702	et	4	main
kirjasõnast	doc_491521502238_item	2639718	et	4	main
otse	doc_491521502238_item	2639731	et	4	main
mitte	doc_491521502238_item	2639733	et	3	main
esimeseks	doc_491521502238_item	2639735	et	3	main
ülempiiskopiks	doc_491521502238_item	2639736	et	3	main
saab	doc_491521502238_item	2639737	et	3	main
noortel	doc_491521502238_item	2639743	et	3	main
leeris	doc_491521502238_item	2639745	et	3	main
petseri	doc_491521502238_item	2639747	et	4	main
klooster	doc_491521502238_item	2639748	et	3	main
püsti	doc_491521502238_item	2639750	et	3	main
erinevused	doc_491521502238_item	2639521	et	4	main
ensv	doc_491521502238_item	2639524	et	4	main
majanduses	doc_491521502238_item	2639527	et	4	main
mõeldakse	doc_491521502238_item	2639530	et	3	main
kultuuriajaloos	doc_491521502238_item	2639533	et	4	main
kõneldakse	doc_491521502238_item	2639534	et	3	main
1	doc_491521502238_item	2639539	et	2	main
1920a	doc_491521502238_item	2639541	et	4	main
alla	doc_491521502238_item	2639543	et	3	main
tartu	doc_491521502238_item	2639544	et	4	main
tingimusteta	doc_491521502238_item	2639550	et	3	main
loobus	doc_491521502238_item	2639555	et	3	main
eesti	doc_491521502238_item	2639560	et	4	main
venemaa	doc_491521502238_item	2639565	et	4	main
kahjutasu	doc_491521502238_item	2639568	et	4	main
riigikogu	doc_491521502238_item	2639571	et	4	main
oli	doc_491521502238_item	2639574	et	3	main
kultuurilist	doc_491521502238_item	2639583	et	4	main
j	doc_491521502238_item	2639599	et	4	main
vares-	doc_491521502238_item	2639600	et	4	main
lauristin	doc_491521502238_item	2639603	et	4	main
omavalitsused	doc_491521502238_item	2639606	et	3	main
täitevkomiteedeks	doc_491521502238_item	2639608	et	3	main
kõik	doc_491521502238_item	2639610	et	4	main
transport	doc_491521502238_item	2639619	et	3	main
muutusid	doc_491521502238_item	2639621	et	4	main
omanikusuhted	doc_491521502238_item	2639622	et	3	main
moskva	doc_491521502238_item	2639626	et	4	main
ettekirjutuste	doc_491521502238_item	2639627	et	3	main
kohaselt	doc_491521502238_item	2639628	et	4	main
arendati	doc_491521502238_item	2639629	et	3	main
puudus	doc_491521502238_item	2639634	et	4	main
maa	doc_491521502238_item	2639637	et	4	main
tekitab	doc_491521502238_item	2639639	et	3	main
sotsiaalseid	doc_491521502238_item	2639640	et	3	main
pingeid	doc_491521502238_item	2639641	et	3	main
inimesed	doc_491521502238_item	2639642	et	3	main
kultuuri	doc_491521502238_item	2639653	et	4	main
hävitada	doc_491521502238_item	2639654	et	3	main
ja	doc_491521502238_item	2639659	et	3	main
erinevaid	doc_491521502238_item	2639661	et	4	main
6	doc_491521502238_item	2639664	et	2	main
oli	doc_491521502238_item	2639667	et	3	main
näitekunst	doc_491521502238_item	2639671	et	3	main
sai	doc_491521502238_item	2639677	et	4	main
stipendiume	doc_491521502238_item	2639678	et	3	main
sellest	doc_491521502238_item	2639679	et	4	main
aktivselt	doc_491521502238_item	2639696	et	4	main
kirjanikke	doc_491521502238_item	2639700	et	3	main
vangi	doc_491521502238_item	2639704	et	4	main
riigi	doc_491521502238_item	2639709	et	3	main
sümboolika	doc_491521502238_item	2639710	et	4	main
hävitab	doc_491521502238_item	2639712	et	3	main
välja	doc_491521502238_item	2639519	et	4	main
kontrolltöö	doc_491521502238_item	2639516	et	4	main
1	doc_491521502238_item	2639517	et	2	main
tooge	doc_491521502238_item	2639518	et	3	main
ja	doc_491521502238_item	2639526	et	3	main
rahu	doc_491521502238_item	2639545	et	4	main
lepingule	doc_491521502238_item	2639546	et	3	main
nõukogude	doc_491521502238_item	2639547	et	3	main
eesti	doc_491521502238_item	2639551	et	4	main
riigi	doc_491521502238_item	2639552	et	3	main
iseseisvust	doc_491521502238_item	2639553	et	4	main
sõltumatu	doc_491521502238_item	2639564	et	4	main
pidi	doc_491521502238_item	2639566	et	4	main
100-liikmeline	doc_491521502238_item	2639570	et	4	main
tähtsaim	doc_491521502238_item	2639572	et	4	main
seadusi	doc_491521502238_item	2639578	et	3	main
kui	doc_491521502238_item	2639584	et	3	main
kuulutati	doc_491521502238_item	2639589	et	4	main
25081940a	doc_491521502238_item	2639591	et	4	main
poliitiline	doc_491521502238_item	2639604	et	3	main
järsult	doc_491521502238_item	2639620	et	4	main
tekib	doc_491521502238_item	2639632	et	3	main
maa	doc_491521502238_item	2639635	et	4	main
ev	doc_491521502238_item	2639646	et	4	main
kultuur	doc_491521502238_item	2639647	et	3	main
nõukogude	doc_491521502238_item	2639648	et	3	main
eesti	doc_491521502238_item	2639652	et	4	main
rahastas	doc_491521502238_item	2639658	et	4	main
kultuuri	doc_491521502238_item	2639662	et	4	main
helikunst	doc_491521502238_item	2639669	et	3	main
ajakirjandus	doc_491521502238_item	2639674	et	3	main
oli	doc_491521502238_item	2639680	et	3	main
seltsitegevust	doc_491521502238_item	2639698	et	4	main
hukkati	doc_491521502238_item	2639707	et	4	main
tsensuur	doc_491521502238_item	2639711	et	3	main
eesti	doc_491521502238_item	2639725	et	4	main
apostliku	doc_491521502238_item	2639726	et	3	main
õigeusu	doc_491521502238_item	2639727	et	3	main
kirikuks	doc_491521502238_item	2639728	et	4	main
seal	doc_491521502238_item	2639739	et	4	main
nõuti	doc_491521502238_item	2639744	et	3	main
kuigi	doc_491521502238_item	2639751	et	3	main
venemaal	doc_491521502238_item	2639753	et	4	main
nsvls	doc_491521502238_item	2639759	et	4	main
saavutati	doc_491521502238_item	2639765	et	3	main
osa	doc_491521502238_item	2639769	et	4	main
palju	doc_491521502238_item	2639779	et	4	main
sotsiolism	doc_491521502238_item	2639782	et	4	main
toimus	doc_491521502238_item	2639783	et	3	main
poliitilise	doc_491521502238_item	2639784	et	3	main
siis	doc_491521502238_item	2639793	et	3	main
aktiviseerusid	doc_491521502238_item	2639795	et	4	main
palju	doc_491521502238_item	2639808	et	4	main
sarnaselt	doc_491521502238_item	2639810	et	4	main
ning	doc_491521502238_item	2639811	et	3	main
hakkab	doc_491521502238_item	2639812	et	3	main
peamised	doc_491521502238_item	2639520	et	3	main
ja	doc_491521502238_item	2639523	et	3	main
ühiskonnakorralduses	doc_491521502238_item	2639525	et	3	main
ensv	doc_491521502238_item	2639532	et	4	main
nn	doc_491521502238_item	2639535	et	4	main
sulast	doc_491521502238_item	2639537	et	4	main
venemaa	doc_491521502238_item	2639548	et	4	main
tunnistas	doc_491521502238_item	2639549	et	3	main
ajaks	doc_491521502238_item	2639557	et	4	main
suveräänsetest	doc_491521502238_item	2639558	et	3	main
õigustest	doc_491521502238_item	2639559	et	4	main
maksma	doc_491521502238_item	2639567	et	3	main
riigivanem	doc_491521502238_item	2639575	et	4	main
vastu	doc_491521502238_item	2639579	et	3	main
nii	doc_491521502238_item	2639582	et	3	main
majanduslikku	doc_491521502238_item	2639585	et	4	main
24021918a-	doc_491521502238_item	2639587	et	4	main
muudeti	doc_491521502238_item	2639593	et	3	main
korrale	doc_491521502238_item	2639595	et	3	main
presiidiumi	doc_491521502238_item	2639597	et	4	main
esimees	doc_491521502238_item	2639598	et	4	main
liider	doc_491521502238_item	2639605	et	3	main
muudeti	doc_491521502238_item	2639607	et	3	main
natsionaliseeriti	doc_491521502238_item	2639609	et	3	main
mida	doc_491521502238_item	2639611	et	4	main
natsionaliseerida	doc_491521502238_item	2639612	et	3	main
sai	doc_491521502238_item	2639613	et	4	main
ettevõtted	doc_491521502238_item	2639614	et	3	main
vabrikud	doc_491521502238_item	2639615	et	3	main
maad	doc_491521502238_item	2639616	et	4	main
tehased	doc_491521502238_item	2639617	et	3	main
võeti	doc_491521502238_item	2639576	et	3	main
välja	doc_491521502238_item	2639590	et	4	main
riigiaparat	doc_491521502238_item	2639592	et	4	main
vastavaks	doc_491521502238_item	2639596	et	4	main
j	doc_491521502238_item	2639602	et	4	main
majad	doc_491521502238_item	2639618	et	3	main
seatakse	doc_491521502238_item	2639623	et	4	main
sisse	doc_491521502238_item	2639624	et	4	main
plaanimajandus	doc_491521502238_item	2639625	et	3	main
raske-	doc_491521502238_item	2639630	et	4	main
sõjatööstust	doc_491521502238_item	2639631	et	4	main
külades	doc_491521502238_item	2639643	et	3	main
poliitika	doc_491521502238_item	2639649	et	4	main
ei	doc_491521502238_item	2639650	et	4	main
suutnud	doc_491521502238_item	2639651	et	4	main
kultuurikapital	doc_491521502238_item	2639656	et	3	main
riik	doc_491521502238_item	2639657	et	3	main
siht	doc_491521502238_item	2639665	et	3	main
kapitali	doc_491521502238_item	2639666	et	4	main
kehakultuur	doc_491521502238_item	2639672	et	3	main
kirjanikke	doc_491521502238_item	2639676	et	3	main
ära	doc_491521502238_item	2639682	et	4	main
ensv	doc_491521502238_item	2639684	et	4	main
saadeti	doc_491521502238_item	2639703	et	3	main
vahetus	doc_491521502238_item	2639708	et	4	main
ka	doc_491521502238_item	2639713	et	3	main
ev	doc_491521502238_item	2639715	et	4	main
ajal	doc_491521502238_item	2639716	et	4	main
hakkas	doc_491521502238_item	2639729	et	3	main
plaaton	doc_491521502238_item	2639738	et	4	main
on	doc_491521502238_item	2639740	et	4	main
jäi	doc_491521502238_item	2639749	et	3	main
ainus	doc_491521502238_item	2639760	et	4	main
ensv-s	doc_491521502238_item	2639767	et	3	main
hävitati	doc_491521502238_item	2639770	et	3	main
ev-s	doc_491521502238_item	2639775	et	3	main
neid	doc_491521502238_item	2639776	et	4	main
hinnati	doc_491521502238_item	2639777	et	3	main
oli	doc_491521502238_item	2639781	et	3	main
majandust	doc_491521502238_item	2639791	et	4	main
võimule	doc_491521502238_item	2639797	et	3	main
n	doc_491521502238_item	2639799	et	4	main
teostama	doc_491521502238_item	2639814	et	3	main
alates	doc_491521502238_item	2639815	et	3	main
1956a	doc_491521502238_item	2639825	et	4	main
sündmused	doc_491521502238_item	2639826	et	3	main
ungaris	doc_491521502238_item	2639827	et	4	main
saada	doc_491521502238_item	2639830	et	4	main
tankkid	doc_491521502238_item	2639837	et	4	main
eestlased	doc_491521502238_item	2639843	et	3	main
said	doc_491521502238_item	2639844	et	4	main
ei	doc_491521502238_item	2639849	et	4	main
sel	doc_491521502238_item	2639853	et	3	main
astuma	doc_491521502238_item	2639858	et	3	main
mitte	doc_491521502238_item	2639862	et	3	main
tihti	doc_491521502238_item	2639866	et	3	main
nt	doc_491521502238_item	2639871	et	4	main
ise	doc_491521502238_item	2639875	et	4	main
minna	doc_491521502238_item	2639878	et	3	main
tihti	doc_491521502238_item	2639879	et	3	main
ei	doc_491521502238_item	2639880	et	4	main
nende	doc_491521502238_item	2639884	et	4	main
keda	doc_491521502238_item	2639886	et	4	main
soovitati	doc_491521502238_item	2639887	et	4	main
ettepaneku	doc_491521502238_item	2639894	et	3	main
kontrolltöö	doc_491521502239_item	2639896	et	4	main
ensv	doc_491521502239_item	2639912	et	4	main
ja	doc_491521502239_item	2639923	et	3	main
1920	doc_491521502239_item	2639925	et	2	main
oli	doc_491521502239_item	2639926	et	3	main
me	doc_491521502239_item	2639932	et	4	main
saame	doc_491521502239_item	2639933	et	4	main
rääkida	doc_491521502239_item	2639934	et	3	main
eestist	doc_491521502239_item	2639935	et	3	main
kui	doc_491521502239_item	2639936	et	3	main
vabariigist	doc_491521502239_item	2639937	et	3	main
ev-st	doc_491521502239_item	2639940	et	3	main
noore	doc_491521502239_item	2639944	et	3	main
majandus	doc_491521502239_item	2639946	et	4	main
ja	doc_491521502239_item	2639947	et	3	main
kujutas	doc_491521502239_item	2639949	et	3	main
endast	doc_491521502239_item	2639950	et	4	main
ühiskonnakorraldus	doc_491521502239_item	2639951	et	3	main
mis	doc_491521502239_item	2639954	et	4	main
intensiivne	doc_491521502239_item	2639957	et	3	main
saa	doc_491521502239_item	2639967	et	4	main
saama	doc_491521502239_item	2639974	et	4	main
vaimult	doc_491521502239_item	2639976	et	4	main
seaduse	doc_491521502239_item	2639986	et	3	main
riiklikku	doc_491521502239_item	2639996	et	4	main
ja	doc_491521502239_item	2640000	et	3	main
kirjandus	doc_491521502238_item	2639668	et	3	main
võimalik	doc_491521502238_item	2639681	et	3	main
kultuur	doc_491521502238_item	2639685	et	3	main
euroopas	doc_491521502238_item	2639687	et	3	main
keelati	doc_491521502238_item	2639690	et	4	main
kirjanduses	doc_491521502238_item	2639691	et	3	main
kunstis	doc_491521502238_item	2639692	et	3	main
tuli	doc_491521502238_item	2639693	et	4	main
viljeleda	doc_491521502238_item	2639694	et	3	main
hakkati	doc_491521502238_item	2639695	et	3	main
palju	doc_491521502238_item	2639699	et	4	main
kunstnikke	doc_491521502238_item	2639701	et	3	main
siberisse	doc_491521502238_item	2639705	et	4	main
või	doc_491521502238_item	2639706	et	4	main
ilmunud	doc_491521502238_item	2639717	et	4	main
pärast	doc_491521502238_item	2639719	et	4	main
ev	doc_491521502238_item	2639720	et	4	main
i	doc_491521502238_item	2639714	et	4	main
loomist	doc_491521502238_item	2639721	et	4	main
ühinesid	doc_491521502238_item	2639722	et	4	main
õigeusu	doc_491521502238_item	2639723	et	3	main
kirikud	doc_491521502238_item	2639724	et	3	main
alluma	doc_491521502238_item	2639730	et	3	main
konstantinoopalile	doc_491521502238_item	2639732	et	4	main
moskvale	doc_491521502238_item	2639734	et	4	main
tarvitusel	doc_491521502238_item	2639741	et	4	main
koguduselaul	doc_491521502238_item	2639742	et	4	main
käimist	doc_491521502238_item	2639746	et	4	main
kõik	doc_491521502238_item	2639755	et	4	main
hävitati	doc_491521502238_item	2639756	et	3	main
see	doc_491521502238_item	2639757	et	3	main
oli	doc_491521502238_item	2639758	et	3	main
mida	doc_491521502238_item	2639764	et	4	main
suurem	doc_491521502238_item	2639768	et	4	main
vaimuinimesed	doc_491521502238_item	2639771	et	3	main
represeeriti	doc_491521502238_item	2639772	et	4	main
kultuuri	doc_491521502238_item	2639789	et	4	main
metsavennad	doc_491521502238_item	2639796	et	3	main
mõtleb	doc_491521502238_item	2639807	et	3	main
rääkida	doc_491521502238_item	2639818	et	3	main
eestlaste	doc_491521502238_item	2639819	et	4	main
üheks	doc_491521502238_item	2639822	et	3	main
põhjuseks	doc_491521502238_item	2639823	et	3	main
on	doc_491521502238_item	2639824	et	4	main
püüab	doc_491521502238_item	2639829	et	3	main
nõukogude	doc_491521502238_item	2639831	et	3	main
tapeti	doc_491521502238_item	2639838	et	3	main
keda	doc_491521502238_item	2639840	et	4	main
õnnestu	doc_491521502238_item	2639850	et	4	main
hakkatakse	doc_491521502238_item	2639855	et	4	main
kommunistlikusse	doc_491521502238_item	2639859	et	4	main
tahtest	doc_491521502238_item	2639865	et	4	main
isegi	doc_491521502238_item	2639869	et	4	main
hästi	doc_491521502238_item	2639882	et	3	main
nende	doc_491521502238_item	2639889	et	4	main
tegi	doc_491521502238_item	2639895	et	4	main
tooge	doc_491521502239_item	2639898	et	3	main
peamised	doc_491521502239_item	2639900	et	3	main
2	doc_491521502239_item	2639908	et	2	main
mida	doc_491521502239_item	2639909	et	4	main
kui	doc_491521502239_item	2639911	et	3	main
kõneldakse	doc_491521502239_item	2639914	et	3	main
vabadussõda	doc_491521502239_item	2639922	et	4	main
0202	doc_491521502239_item	2639924	et	2	main
tartu	doc_491521502239_item	2639928	et	4	main
rahu	doc_491521502239_item	2639929	et	4	main
sellest	doc_491521502239_item	2639930	et	4	main
kuidas	doc_491521502239_item	2639941	et	3	main
alustan	doc_491521502239_item	2639952	et	3	main
väga	doc_491521502239_item	2639956	et	3	main
kuna	doc_491521502239_item	2639964	et	3	main
ei	doc_491521502239_item	2639966	et	4	main
suureks	doc_491521502239_item	2639969	et	4	main
jõult	doc_491521502239_item	2639972	et	3	main
ev	doc_491521502239_item	2639979	et	4	main
ja	doc_491521502239_item	2639984	et	3	main
vastuvõtmine	doc_491521502239_item	2639987	et	3	main
aastal	doc_491521502239_item	2639989	et	3	main
endast	doc_491521502239_item	2639995	et	4	main
rahalist	doc_491521502239_item	2639997	et	4	main
kultuur-	doc_491521502239_item	2639999	et	3	main
ja	doc_491521502239_item	2640007	et	3	main
kirjandus	doc_491521502239_item	2640009	et	3	main
hakkati	doc_491521502239_item	2640019	et	3	main
eest	doc_491521502239_item	2640036	et	4	main
alates	doc_491521502239_item	2640039	et	3	main
hakkati	doc_491521502239_item	2640041	et	3	main
taludega	doc_491521502239_item	2640043	et	3	main
omanikuks	doc_491521502239_item	2640048	et	4	main
b	doc_491521502239_item	2640049	et	4	main
pisirahvad	doc_491521502239_item	2640053	et	3	main
sakslased	doc_491521502239_item	2640058	et	3	main
tähendas	doc_491521502239_item	2640062	et	3	main
see	doc_491521502239_item	2640063	et	3	main
seda	doc_491521502239_item	2640064	et	3	main
et	doc_491521502239_item	2640065	et	3	main
ajakirjandus	doc_491521502239_item	2640078	et	3	main
seltside	doc_491521502239_item	2640084	et	3	main
nõukogude	doc_491521502238_item	2639752	et	3	main
need	doc_491521502238_item	2639754	et	3	main
naiste	doc_491521502238_item	2639761	et	3	main
klooster	doc_491521502238_item	2639762	et	3	main
kõik	doc_491521502238_item	2639763	et	4	main
ev	doc_491521502238_item	2639766	et	4	main
väga	doc_491521502238_item	2639778	et	3	main
ensv-s	doc_491521502238_item	2639780	et	3	main
ja	doc_491521502238_item	2639790	et	3	main
kui	doc_491521502238_item	2639794	et	3	main
sulast	doc_491521502238_item	2639806	et	4	main
beriaga	doc_491521502238_item	2639809	et	4	main
ideid	doc_491521502238_item	2639813	et	3	main
sulast	doc_491521502238_item	2639816	et	4	main
kohale	doc_491521502238_item	2639836	et	4	main
peeti	doc_491521502238_item	2639842	et	4	main
aru	doc_491521502238_item	2639845	et	4	main
et	doc_491521502238_item	2639846	et	3	main
ev	doc_491521502238_item	2639847	et	4	main
taastada	doc_491521502238_item	2639848	et	3	main
pea	doc_491521502238_item	2639852	et	4	main
perioodil	doc_491521502238_item	2639854	et	3	main
üha	doc_491521502238_item	2639856	et	3	main
enam	doc_491521502238_item	2639857	et	4	main
seda	doc_491521502238_item	2639861	et	3	main
vaid	doc_491521502238_item	2639864	et	3	main
oli	doc_491521502238_item	2639867	et	3	main
kohustuslik	doc_491521502238_item	2639870	et	3	main
need	doc_491521502238_item	2639873	et	3	main
vaadati	doc_491521502238_item	2639883	et	3	main
peale	doc_491521502238_item	2639890	et	4	main
ise	doc_491521502238_item	2639892	et	4	main
ensv	doc_491521502239_item	2639904	et	4	main
ühiskonnakorralduses	doc_491521502239_item	2639905	et	3	main
ja	doc_491521502239_item	2639906	et	3	main
majanduses	doc_491521502239_item	2639907	et	4	main
sõlmitud	doc_491521502239_item	2639927	et	4	main
sõnadega	doc_491521502239_item	2639939	et	3	main
siis	doc_491521502239_item	2639942	et	3	main
kultuurist	doc_491521502239_item	2639953	et	3	main
oli	doc_491521502239_item	2639955	et	3	main
üldkultuuriliseks	doc_491521502239_item	2639958	et	4	main
kreedoks	doc_491521502239_item	2639959	et	3	main
j	doc_491521502239_item	2639961	et	4	main
sõnad	doc_491521502239_item	2639963	et	4	main
kunagi	doc_491521502239_item	2639968	et	3	main
arvult	doc_491521502239_item	2639970	et	3	main
suureks	doc_491521502239_item	2639975	et	4	main
saavutuseks	doc_491521502239_item	2639978	et	4	main
said	doc_491521502239_item	2639981	et	4	main
mõlematest	doc_491521502239_item	2639991	et	4	main
eriala-	doc_491521502239_item	2640004	et	4	main
ja	doc_491521502239_item	2640011	et	3	main
jaoks	doc_491521502239_item	2640013	et	4	main
1934	doc_491521502239_item	2640017	et	2	main
keel	doc_491521502239_item	2640122	et	4	main
ensv-s	doc_491521502238_item	2639773	et	3	main
aga	doc_491521502238_item	2639774	et	3	main
võimu	doc_491521502238_item	2639785	et	4	main
haaramine	doc_491521502238_item	2639786	et	4	main
poliitika	doc_491521502238_item	2639787	et	4	main
mõjutas	doc_491521502238_item	2639788	et	3	main
2	doc_491521502238_item	2639792	et	2	main
sai	doc_491521502238_item	2639798	et	4	main
hruštšov	doc_491521502238_item	2639800	et	2	main
sellest	doc_491521502238_item	2639801	et	4	main
perioodist	doc_491521502238_item	2639802	et	3	main
võib	doc_491521502238_item	2639803	et	3	main
rääkida	doc_491521502238_item	2639804	et	3	main
kui	doc_491521502238_item	2639805	et	3	main
võib	doc_491521502238_item	2639817	et	3	main
kohanemisest	doc_491521502238_item	2639820	et	4	main
süsteemiga	doc_491521502238_item	2639821	et	3	main
ungari	doc_491521502238_item	2639828	et	4	main
liidust	doc_491521502238_item	2639832	et	4	main
vabaks	doc_491521502238_item	2639833	et	3	main
nsvl	doc_491521502238_item	2639834	et	4	main
saatis	doc_491521502238_item	2639835	et	3	main
need	doc_491521502238_item	2639839	et	3	main
vajalikuks	doc_491521502238_item	2639841	et	3	main
nii	doc_491521502238_item	2639851	et	3	main
parteisse	doc_491521502238_item	2639860	et	3	main
lojaalsusest	doc_491521502238_item	2639863	et	4	main
see	doc_491521502238_item	2639868	et	3	main
direktorid	doc_491521502238_item	2639872	et	3	main
saanud	doc_491521502238_item	2639881	et	4	main
peale	doc_491521502238_item	2639885	et	4	main
kes	doc_491521502238_item	2639891	et	4	main
selle	doc_491521502238_item	2639893	et	4	main
1	doc_491521502239_item	2639897	et	2	main
välja	doc_491521502239_item	2639899	et	4	main
erinevused	doc_491521502239_item	2639901	et	4	main
mõeldakse	doc_491521502239_item	2639910	et	3	main
kultuuriajaloos	doc_491521502239_item	2639913	et	4	main
nn	doc_491521502239_item	2639915	et	4	main
hrustshovi	doc_491521502239_item	2639916	et	4	main
sulast	doc_491521502239_item	2639917	et	4	main
19	doc_491521502239_item	2639918	et	2	main
0301	doc_491521502239_item	2639919	et	2	main
1920	doc_491521502239_item	2639920	et	2	main
lõppes	doc_491521502239_item	2639921	et	4	main
ajast	doc_491521502239_item	2639931	et	4	main
teiste	doc_491521502239_item	2639938	et	4	main
arenes	doc_491521502239_item	2639943	et	3	main
rigi	doc_491521502239_item	2639945	et	4	main
mis	doc_491521502239_item	2639948	et	4	main
sai	doc_491521502239_item	2639960	et	4	main
hurda	doc_491521502239_item	2639962	et	3	main
me	doc_491521502239_item	2639965	et	4	main
ega	doc_491521502239_item	2639971	et	3	main
peame	doc_491521502239_item	2639973	et	4	main
suurema	doc_491521502239_item	2639977	et	4	main
sisseseadmine	doc_491521502239_item	2639983	et	3	main
kultuurautonoomia	doc_491521502239_item	2639985	et	4	main
lühidalt	doc_491521502239_item	2639990	et	4	main
a	doc_491521502239_item	2639992	et	4	main
kultuurautonoomia	doc_491521502239_item	2639993	et	4	main
kuue	doc_491521502239_item	2640003	et	4	main
näite-	doc_491521502239_item	2640006	et	4	main
ajakirjandus	doc_491521502239_item	2640012	et	3	main
a	doc_491521502239_item	2640018	et	4	main
a	doc_491521502239_item	2640027	et	4	main
amälk	doc_491521502239_item	2640044	et	4	main
lagle	doc_491521502239_item	2640046	et	4	main
talu	doc_491521502239_item	2640047	et	4	main
kõik	doc_491521502239_item	2640052	et	4	main
kuid	doc_491521502239_item	2640054	et	4	main
ja	doc_491521502239_item	2640059	et	3	main
praktiliselt	doc_491521502239_item	2640061	et	4	main
omakeelne	doc_491521502239_item	2640077	et	3	main
oli	doc_491521502239_item	2640081	et	3	main
kes	doc_491521502238_item	2639874	et	4	main
tahtsid	doc_491521502238_item	2639876	et	4	main
parteisse	doc_491521502238_item	2639877	et	3	main
mitte	doc_491521502238_item	2639888	et	3	main
ev	doc_491521502239_item	2639902	et	4	main
ja	doc_491521502239_item	2639903	et	3	main
kultuuriloos	doc_491521502239_item	2639980	et	4	main
kultuurkapitaali	doc_491521502239_item	2639982	et	4	main
1925	doc_491521502239_item	2639988	et	2	main
kujutas	doc_491521502239_item	2639994	et	3	main
toetust	doc_491521502239_item	2639998	et	4	main
hariduselu	doc_491521502239_item	2640001	et	4	main
edendamiseks	doc_491521502239_item	2640002	et	4	main
helikunst	doc_491521502239_item	2640008	et	3	main
kehakultuur	doc_491521502239_item	2640010	et	3	main
selle	doc_491521502239_item	2640026	et	4	main
tõde	doc_491521502239_item	2640030	et	4	main
ja	doc_491521502239_item	2640031	et	3	main
õiguse	doc_491521502239_item	2640032	et	4	main
kahe	doc_491521502239_item	2640033	et	3	main
viimaste	doc_491521502239_item	2640034	et	3	main
köidete	doc_491521502239_item	2640035	et	3	main
1937a	doc_491521502239_item	2640038	et	4	main
kirjanikke	doc_491521502239_item	2640040	et	3	main
premeerima	doc_491521502239_item	2640042	et	4	main
said	doc_491521502239_item	2640051	et	4	main
kasutasid	doc_491521502239_item	2640056	et	4	main
seda	doc_491521502239_item	2640057	et	3	main
tegutsesid	doc_491521502239_item	2640072	et	4	main
igasugused	doc_491521502239_item	2640073	et	3	main
seltsid	doc_491521502239_item	2640074	et	4	main
ning	doc_491521502239_item	2640075	et	3	main
ev	doc_491521502239_item	2640079	et	4	main
erinevate	doc_491521502239_item	2640083	et	4	main
õpetajate	doc_491521502239_item	2640086	et	4	main
eesti	doc_491521502239_item	2640088	et	4	main
ka	doc_491521502239_item	2640094	et	3	main
haridus	doc_491521502239_item	2640097	et	3	main
kõrgel	doc_491521502239_item	2640099	et	4	main
tasemel	doc_491521502239_item	2640100	et	3	main
ja	doc_491521502239_item	2640101	et	3	main
arenesid	doc_491521502239_item	2640102	et	4	main
euroopa	doc_491521502239_item	2640103	et	4	main
tasemele	doc_491521502239_item	2640104	et	3	main
eesti	doc_491521502239_item	2640105	et	4	main
kõrgkoolide	doc_491521502239_item	2640106	et	3	main
peamiselt	doc_491521502239_item	2640107	et	4	main
tü	doc_491521502239_item	2640108	et	4	main
töötas	doc_491521502239_item	2640109	et	3	main
välismaa	doc_491521502239_item	2640110	et	4	main
õppejõud	doc_491521502239_item	2640111	et	4	main
arenes	doc_491521502239_item	2640112	et	3	main
ka	doc_491521502239_item	2640113	et	3	main
eesti	doc_491521502239_item	2640114	et	4	main
keel	doc_491521502239_item	2640115	et	4	main
millest	doc_491521502239_item	2640116	et	3	main
oli	doc_491521502239_item	2640117	et	3	main
saanud	doc_491521502239_item	2640118	et	4	main
rikas	doc_491521502239_item	2640119	et	4	main
uute	doc_491521502239_item	2640120	et	3	main
kujutav-	doc_491521502239_item	2640005	et	4	main
moodustati	doc_491521502239_item	2640014	et	3	main
sihtkapitalide	doc_491521502239_item	2640015	et	4	main
valitsused	doc_491521502239_item	2640016	et	4	main
välja	doc_491521502239_item	2640020	et	4	main
andma	doc_491521502239_item	2640021	et	3	main
riigivanema	doc_491521502239_item	2640022	et	4	main
auhind	doc_491521502239_item	2640023	et	3	main
esimesena	doc_491521502239_item	2640024	et	3	main
sai	doc_491521502239_item	2640025	et	4	main
h	doc_491521502239_item	2640028	et	4	main
tammsaare	doc_491521502239_item	2640029	et	3	main
ning	doc_491521502239_item	2640037	et	3	main
sai	doc_491521502239_item	2640045	et	4	main
kultuurautonoomia	doc_491521502239_item	2640050	et	4	main
maksimaalselt	doc_491521502239_item	2640055	et	4	main
juudid	doc_491521502239_item	2640060	et	3	main
lastele	doc_491521502239_item	2640066	et	4	main
oli	doc_491521502239_item	2640067	et	3	main
võimalik	doc_491521502239_item	2640068	et	3	main
anda	doc_491521502239_item	2640069	et	3	main
emakeelset	doc_491521502239_item	2640070	et	3	main
algharidust	doc_491521502239_item	2640071	et	4	main
ilmus	doc_491521502239_item	2640076	et	4	main
kultuurile	doc_491521502239_item	2640080	et	3	main
iseloomulik	doc_491521502239_item	2640082	et	3	main
liit	doc_491521502239_item	2640087	et	3	main
ja	doc_491521502239_item	2640096	et	3	main
võinud	doc_491521502239_item	2640137	et	4	main
seltside	doc_491521502239_item	2640157	et	3	main
need	doc_491521502239_item	2640159	et	3	main
jäid	doc_491521502239_item	2640165	et	4	main
sellest	doc_491521502239_item	2640166	et	4	main
sest	doc_491521502239_item	2640168	et	4	main
saia	doc_491521502239_item	2640174	et	4	main
alver	doc_491521502239_item	2640177	et	4	main
starkopf	doc_491521502239_item	2640179	et	4	main
kehtestati	doc_491521502239_item	2640181	et	3	main
tsensuur	doc_491521502239_item	2640182	et	3	main
samuti	doc_491521502239_item	2640186	et	3	main
ensv-s	doc_491521502239_item	2640192	et	3	main
politiseeritud	doc_491521502239_item	2640194	et	4	main
muutused	doc_491521502239_item	2640199	et	4	main
ensv	doc_491521502239_item	2640206	et	4	main
ei	doc_491521502239_item	2640216	et	4	main
veel	doc_491521502239_item	2640138	et	4	main
parem	doc_491521502239_item	2640146	et	4	main
võrdlen	doc_491521502239_item	2640147	et	3	main
ev	doc_491521502239_item	2640148	et	4	main
kultuur	doc_491521502239_item	2640149	et	3	main
ja	doc_491521502239_item	2640150	et	3	main
ühiskondlik	doc_491521502239_item	2640151	et	3	main
aktiivsus	doc_491521502239_item	2640085	et	4	main
kirjameeste	doc_491521502239_item	2640089	et	4	main
kunstiühing	doc_491521502239_item	2640091	et	3	main
jt	doc_491521502239_item	2640093	et	4	main
j	doc_491521502239_item	2640123	et	4	main
veskile	doc_491521502239_item	2640124	et	3	main
rohkemgi	doc_491521502239_item	2640139	et	4	main
öelda	doc_491521502239_item	2640140	et	4	main
kuid	doc_491521502239_item	2640141	et	4	main
see	doc_491521502239_item	2640142	et	3	main
elu	doc_491521502239_item	2640152	et	4	main
erinevaid	doc_491521502239_item	2640163	et	4	main
seltse	doc_491521502239_item	2640164	et	3	main
ilma	doc_491521502239_item	2640167	et	4	main
keelatud	doc_491521502239_item	2640172	et	4	main
nii	doc_491521502239_item	2640173	et	3	main
betty	doc_491521502239_item	2640176	et	4	main
lauter	doc_491521502239_item	2640178	et	3	main
25	doc_491521502239_item	2640184	et	2	main
kajastuvaid	doc_491521502239_item	2640188	et	4	main
monumente	doc_491521502239_item	2640189	et	3	main
kui	doc_491521502239_item	2640200	et	3	main
oli	doc_491521502239_item	2640203	et	3	main
ev	doc_491521502239_item	2640209	et	4	main
vaba	doc_491521502239_item	2640212	et	4	main
rääkides	doc_491521502239_item	2640213	et	4	main
ensv-st	doc_491521502239_item	2640214	et	3	main
seal	doc_491521502239_item	2640226	et	4	main
oli	doc_491521502239_item	2640227	et	3	main
tähtsamad	doc_491521502239_item	2640239	et	4	main
majandusharud	doc_491521502239_item	2640240	et	3	main
mida	doc_491521502239_item	2640249	et	4	main
näiteks	doc_491521502239_item	2640257	et	4	main
kalmistusel	doc_491521502239_item	2640261	et	4	main
uued	doc_491521502239_item	2640263	et	3	main
ev	doc_491521502239_item	2640274	et	4	main
inimeste	doc_491521502239_item	2640275	et	3	main
elatustase	doc_491521502239_item	2640276	et	3	main
oli	doc_491521502239_item	2640277	et	3	main
suhteliselt	doc_491521502239_item	2640278	et	4	main
ei	doc_491521502239_item	2640282	et	4	main
ensvst	doc_491521502239_item	2640285	et	4	main
mida	doc_491521502239_item	2640293	et	4	main
kuidas	doc_491521502239_item	2640295	et	3	main
sulast	doc_491521502239_item	2640300	et	4	main
hruštšovi	doc_491521502239_item	2640307	et	2	main
kultuuris	doc_491521502239_item	2640326	et	3	main
muutused	doc_491521502239_item	2640328	et	4	main
hakkas	doc_491521502239_item	2640329	et	3	main
arenema	doc_491521502239_item	2640330	et	3	main
reabiliteeriti	doc_491521502239_item	2640332	et	4	main
ja	doc_491521502239_item	2640334	et	3	main
raamatud	doc_491521502239_item	2640340	et	4	main
lubati	doc_491521502239_item	2640341	et	3	main
kasutama	doc_491521502239_item	2640342	et	3	main
eesti	doc_491521502239_item	2640343	et	4	main
igasugused	doc_491521502239_item	2640346	et	3	main
jazz-muusika	doc_491521502239_item	2640348	et	4	main
enam	doc_491521502239_item	2640352	et	4	main
küüditamist	doc_491521502239_item	2640353	et	4	main
elu	doc_491521502239_item	2640367	et	4	main
määras	doc_491521502239_item	2640377	et	4	main
selts	doc_491521502239_item	2640090	et	3	main
pallas	doc_491521502239_item	2640092	et	4	main
teadus	doc_491521502239_item	2640095	et	4	main
olid	doc_491521502239_item	2640098	et	4	main
sõnadega	doc_491521502239_item	2640121	et	3	main
tänu	doc_491521502239_item	2640125	et	4	main
milles	doc_491521502239_item	2640126	et	3	main
oli	doc_491521502239_item	2640127	et	3	main
võimalik	doc_491521502239_item	2640128	et	3	main
kirjutada	doc_491521502239_item	2640129	et	3	main
teadustöid	doc_491521502239_item	2640130	et	3	main
ja	doc_491521502239_item	2640131	et	3	main
ilukirjandust	doc_491521502239_item	2640132	et	3	main
kultuurist	doc_491521502239_item	2640133	et	3	main
ja	doc_491521502239_item	2640134	et	3	main
teadusest	doc_491521502239_item	2640135	et	4	main
oleksin	doc_491521502239_item	2640136	et	3	main
poleks	doc_491521502239_item	2640143	et	3	main
vastus	doc_491521502239_item	2640144	et	3	main
küsimusele	doc_491521502239_item	2640145	et	4	main
ensv	doc_491521502239_item	2640153	et	4	main
omadega	doc_491521502239_item	2640154	et	3	main
kõigepealt	doc_491521502239_item	2640155	et	3	main
tegevusest	doc_491521502239_item	2640158	et	4	main
kas	doc_491521502239_item	2640160	et	3	main
seltsid	doc_491521502239_item	2640169	et	4	main
ensv-s	doc_491521502239_item	2640170	et	3	main
olid	doc_491521502239_item	2640171	et	4	main
kirjandust	doc_491521502239_item	2640185	et	3	main
vabadussõja	doc_491521502239_item	2640187	et	3	main
korraldus	doc_491521502239_item	2640191	et	4	main
oli	doc_491521502239_item	2640193	et	3	main
ka	doc_491521502239_item	2640195	et	3	main
majanduses	doc_491521502239_item	2640196	et	4	main
toimusid	doc_491521502239_item	2640197	et	4	main
majandus	doc_491521502239_item	2640202	et	4	main
me	doc_491521502239_item	2640215	et	4	main
talupoegi	doc_491521502239_item	2640220	et	4	main
maa	doc_491521502239_item	2640222	et	4	main
riigistatud	doc_491521502239_item	2640224	et	4	main
ja	doc_491521502239_item	2640225	et	3	main
põlevkivi	doc_491521502239_item	2640237	et	4	main
olid	doc_491521502239_item	2640238	et	4	main
ei	doc_491521502239_item	2640250	et	4	main
varem	doc_491521502239_item	2640258	et	4	main
poed	doc_491521502239_item	2640264	et	4	main
1	doc_491521502239_item	2640267	et	2	main
mai	doc_491521502239_item	2640268	et	4	main
7	doc_491521502239_item	2640269	et	2	main
november	doc_491521502239_item	2640270	et	3	main
8	doc_491521502239_item	2640271	et	2	main
märts	doc_491521502239_item	2640272	et	3	main
kõrge	doc_491521502239_item	2640279	et	4	main
öelda	doc_491521502239_item	2640284	et	4	main
kuidas	doc_491521502239_item	2640289	et	3	main
kirjutan	doc_491521502239_item	2640156	et	3	main
varem	doc_491521502239_item	2640161	et	4	main
moodustasid	doc_491521502239_item	2640162	et	4	main
kannatada	doc_491521502239_item	2640175	et	3	main
jt	doc_491521502239_item	2640180	et	4	main
hävitati	doc_491521502239_item	2640183	et	3	main
olulised	doc_491521502239_item	2640198	et	4	main
siis	doc_491521502239_item	2640205	et	3	main
sotsialistlik	doc_491521502239_item	2640208	et	3	main
talupoeg	doc_491521502239_item	2640210	et	3	main
saa	doc_491521502239_item	2640217	et	4	main
üldse	doc_491521502239_item	2640218	et	3	main
sest	doc_491521502239_item	2640221	et	4	main
oli	doc_491521502239_item	2640223	et	3	main
sovhoosid	doc_491521502239_item	2640231	et	3	main
ensv-s	doc_491521502239_item	2640232	et	3	main
arenes	doc_491521502239_item	2640233	et	3	main
rasketööstus	doc_491521502239_item	2640234	et	3	main
elektritootmine	doc_491521502239_item	2640235	et	3	main
planeeritud	doc_491521502239_item	2640243	et	4	main
ning	doc_491521502239_item	2640244	et	3	main
arenes	doc_491521502239_item	2640245	et	3	main
kindlate	doc_491521502239_item	2640246	et	3	main
olnud	doc_491521502239_item	2640251	et	4	main
ev-s	doc_491521502239_item	2640252	et	3	main
muutusid	doc_491521502239_item	2640253	et	4	main
ka	doc_491521502239_item	2640254	et	3	main
inimeste	doc_491521502239_item	2640255	et	3	main
tavad	doc_491521502239_item	2640256	et	3	main
ei	doc_491521502239_item	2640259	et	4	main
jne	doc_491521502239_item	2640273	et	4	main
me	doc_491521502239_item	2640281	et	4	main
ensv-s	doc_491521502239_item	2640286	et	3	main
dikteeris	doc_491521502239_item	2640288	et	3	main
ja	doc_491521502239_item	2640294	et	3	main
1956-	doc_491521502239_item	2640303	et	4	main
suunatud	doc_491521502239_item	2640321	et	4	main
kergendamiseks	doc_491521502239_item	2640324	et	4	main
ka	doc_491521502239_item	2640325	et	3	main
tõlgekirjandus	doc_491521502239_item	2640331	et	4	main
kultuurtegelasi	doc_491521502239_item	2640333	et	3	main
keelt	doc_491521502239_item	2640344	et	4	main
kartnud	doc_491521502239_item	2640351	et	4	main
tõepoolest	doc_491521502239_item	2640356	et	3	main
me	doc_491521502239_item	2640362	et	4	main
muutus	doc_491521502239_item	2640368	et	4	main
ühiskondlik	doc_491521502239_item	2640190	et	3	main
ev	doc_491521502239_item	2640201	et	4	main
kapitalistlik	doc_491521502239_item	2640204	et	3	main
majandus	doc_491521502239_item	2640207	et	4	main
oli	doc_491521502239_item	2640211	et	3	main
mainida	doc_491521502239_item	2640219	et	3	main
moodustatud	doc_491521502239_item	2640228	et	4	main
kolhoosid	doc_491521502239_item	2640229	et	3	main
ja	doc_491521502239_item	2640230	et	3	main
ja	doc_491521502239_item	2640236	et	3	main
majandus	doc_491521502239_item	2640241	et	4	main
oli	doc_491521502239_item	2640242	et	3	main
plaanide	doc_491521502239_item	2640247	et	3	main
järgi	doc_491521502239_item	2640248	et	4	main
käidua	doc_491521502239_item	2640260	et	4	main
ilmusid	doc_491521502239_item	2640262	et	4	main
nagu	doc_491521502239_item	2640265	et	3	main
näiteks	doc_491521502239_item	2640266	et	4	main
mida	doc_491521502239_item	2640280	et	4	main
saa	doc_491521502239_item	2640283	et	4	main
inimesed	doc_491521502239_item	2640290	et	3	main
elama	doc_491521502239_item	2640292	et	3	main
tegema	doc_491521502239_item	2640296	et	3	main
rääkides	doc_491521502239_item	2640298	et	4	main
1968	doc_491521502239_item	2640304	et	2	main
nikita	doc_491521502239_item	2640306	et	4	main
valitsemisaega	doc_491521502239_item	2640308	et	4	main
eesti	doc_491521502239_item	2640309	et	4	main
inimeste	doc_491521502239_item	2640310	et	3	main
elu	doc_491521502239_item	2640311	et	4	main
ei	doc_491521502239_item	2640312	et	4	main
olnud	doc_491521502239_item	2640313	et	4	main
enam	doc_491521502239_item	2640314	et	4	main
nii	doc_491521502239_item	2640315	et	3	main
karm	doc_491521502239_item	2640316	et	4	main
lõpetati	doc_491521502239_item	2640317	et	3	main
repressioonid	doc_491521502239_item	2640318	et	3	main
hruštšovi	doc_491521502239_item	2640319	et	2	main
oli	doc_491521502239_item	2640320	et	3	main
elu	doc_491521502239_item	2640323	et	4	main
välja	doc_491521502239_item	2640337	et	4	main
eestikeelsed	doc_491521502239_item	2640339	et	3	main
toimusid	doc_491521502239_item	2640345	et	4	main
ei	doc_491521502239_item	2640350	et	4	main
oli	doc_491521502239_item	2640355	et	3	main
režiimist	doc_491521502239_item	2640359	et	2	main
saa	doc_491521502239_item	2640364	et	4	main
öelda	doc_491521502239_item	2640365	et	4	main
et	doc_491521502239_item	2640366	et	3	main
partei	doc_491521502239_item	2640287	et	4	main
peavad	doc_491521502239_item	2640291	et	4	main
2	doc_491521502239_item	2640297	et	2	main
hruštšovi	doc_491521502239_item	2640299	et	2	main
mõeldakse	doc_491521502239_item	2640301	et	3	main
ajaperioodi	doc_491521502239_item	2640302	et	4	main
aastani	doc_491521502239_item	2640305	et	3	main
inimeste	doc_491521502239_item	2640322	et	3	main
toimusid	doc_491521502239_item	2640327	et	4	main
dissidente	doc_491521502239_item	2640335	et	3	main
hakkati	doc_491521502239_item	2640336	et	3	main
andma	doc_491521502239_item	2640338	et	3	main
festivalid	doc_491521502239_item	2640347	et	3	main
inimesed	doc_491521502239_item	2640349	et	3	main
see	doc_491521502239_item	2640354	et	3	main
sula	doc_491521502239_item	2640357	et	4	main
stalinistliku	doc_491521502239_item	2640358	et	4	main
kuid	doc_491521502239_item	2640360	et	4	main
endiselt	doc_491521502239_item	2640370	et	4	main
tegutsesid	doc_491521502239_item	2640371	et	4	main
sovhoosid	doc_491521502239_item	2640372	et	3	main
ja	doc_491521502239_item	2640373	et	3	main
kolhoosid	doc_491521502239_item	2640374	et	3	main
ja	doc_491521502239_item	2640375	et	3	main
samas	doc_491521502239_item	2640361	et	4	main
ei	doc_491521502239_item	2640363	et	4	main
demokraatlikuks	doc_491521502239_item	2640369	et	3	main
partei	doc_491521502239_item	2640378	et	4	main
eluviisi	doc_491521502239_item	2640376	et	4	main
ev	doc_491521502241_item	2640847	et	4	main
ja	doc_491521502241_item	2640851	et	3	main
mida	doc_491521502241_item	2640854	et	4	main
kultuuriajaloos	doc_491521502241_item	2640858	et	4	main
hrustshovi	doc_491521502241_item	2640861	et	4	main
1	doc_491521502241_item	2640842	et	2	main
välja	doc_491521502241_item	2640844	et	4	main
erinevused	doc_491521502241_item	2640846	et	4	main
ensv	doc_491521502241_item	2640849	et	4	main
mõeldakse	doc_491521502241_item	2640855	et	3	main
nn	doc_491521502241_item	2640860	et	4	main
riigikogu	doc_491521502241_item	2640871	et	4	main
paljud	doc_491521502241_item	2640875	et	3	main
näiteks	doc_491521502241_item	2640877	et	4	main
haridus	doc_491521502241_item	2640883	et	3	main
väärtuslikuks	doc_491521502241_item	2640885	et	3	main
paljud	doc_491521502241_item	2640886	et	3	main
kus	doc_491521502241_item	2640897	et	3	main
ja	doc_491521502241_item	2640934	et	3	main
ilmumine	doc_491521502241_item	2640943	et	4	main
ühiskondlikud	doc_491521502241_item	2640944	et	3	main
nt	doc_491521502241_item	2640951	et	4	main
tuletõrjujate	doc_491521502241_item	2640953	et	3	main
ensv	doc_491521502241_item	2640956	et	4	main
ajal	doc_491521502241_item	2640957	et	4	main
ka	doc_491521502241_item	2640963	et	3	main
ja	doc_491521502241_item	2640971	et	3	main
valis	doc_491521502241_item	2640976	et	3	main
riigi	doc_491521502241_item	2640980	et	3	main
seega	doc_491521502241_item	2641015	et	4	main
kokkuvõteks	doc_491521502241_item	2641016	et	3	main
tooge	doc_491521502241_item	2640843	et	3	main
peamised	doc_491521502241_item	2640845	et	3	main
ühiskonnakorralduses	doc_491521502241_item	2640850	et	3	main
2	doc_491521502241_item	2640853	et	2	main
kui	doc_491521502241_item	2640856	et	3	main
sulast	doc_491521502241_item	2640862	et	4	main
president	doc_491521502241_item	2640869	et	3	main
kultuurielust	doc_491521502241_item	2640873	et	3	main
ülikoolide	doc_491521502241_item	2640881	et	3	main
said	doc_491521502241_item	2640888	et	4	main
ka	doc_491521502241_item	2640889	et	3	main
kõrgema	doc_491521502241_item	2640890	et	4	main
hariduse	doc_491521502241_item	2640891	et	3	main
sel	doc_491521502241_item	2640892	et	3	main
paljud	doc_491521502241_item	2640899	et	3	main
haritlased	doc_491521502241_item	2640900	et	3	main
välismaalt	doc_491521502241_item	2640902	et	3	main
kui	doc_491521502241_item	2640903	et	3	main
ka	doc_491521502241_item	2640904	et	3	main
eestist	doc_491521502241_item	2640905	et	3	main
pärit	doc_491521502241_item	2640906	et	3	main
nad	doc_491521502241_item	2640907	et	3	main
arendasid	doc_491521502241_item	2640908	et	4	main
palju	doc_491521502241_item	2640909	et	4	main
valdkondi	doc_491521502241_item	2640910	et	4	main
1919	doc_491521502241_item	2640911	et	2	main
eestikeel	doc_491521502241_item	2640912	et	4	main
sai	doc_491521502241_item	2640913	et	4	main
õppimise	doc_491521502241_item	2640914	et	4	main
keeleks	doc_491521502241_item	2640915	et	4	main
tü	doc_491521502241_item	2640916	et	4	main
eesti	doc_491521502241_item	2640917	et	4	main
keele	doc_491521502241_item	2640918	et	4	main
uurimist	doc_491521502241_item	2640919	et	4	main
viisid	doc_491521502241_item	2640920	et	4	main
ev	doc_491521502241_item	2640929	et	4	main
saavutuseks	doc_491521502241_item	2640930	et	4	main
oli	doc_491521502241_item	2640931	et	3	main
eesti	doc_491521502241_item	2640932	et	4	main
viimine	doc_491521502241_item	2640936	et	4	main
kõrgele	doc_491521502241_item	2640937	et	4	main
olid	doc_491521502241_item	2640946	et	4	main
ajal	doc_491521502241_item	2640948	et	4	main
väga	doc_491521502241_item	2640949	et	3	main
selts	doc_491521502241_item	2640954	et	3	main
kultuurielu	doc_491521502241_item	2640961	et	4	main
kui	doc_491521502241_item	2640962	et	3	main
maksta	doc_491521502241_item	2640970	et	4	main
võtta	doc_491521502241_item	2640974	et	3	main
ja	doc_491521502241_item	2640978	et	3	main
eesotsas	doc_491521502241_item	2640981	et	4	main
ja	doc_491521502241_item	2640984	et	3	main
kontrolltöö	doc_491521502241_item	2640841	et	4	main
ja	doc_491521502241_item	2640848	et	3	main
majanduses	doc_491521502241_item	2640852	et	4	main
ensv	doc_491521502241_item	2640857	et	4	main
kõneldakse	doc_491521502241_item	2640859	et	3	main
oli	doc_491521502241_item	2640868	et	3	main
saavutused	doc_491521502241_item	2640876	et	4	main
erinevate	doc_491521502241_item	2640878	et	4	main
seltside	doc_491521502241_item	2640879	et	3	main
avamine	doc_491521502241_item	2640882	et	4	main
sai	doc_491521502241_item	2640884	et	4	main
inimesed	doc_491521502241_item	2640887	et	3	main
riik	doc_491521502241_item	2640896	et	3	main
nii	doc_491521502241_item	2640901	et	3	main
ajal	doc_491521502241_item	2640865	et	4	main
riigi	doc_491521502241_item	2640866	et	3	main
eesotsas	doc_491521502241_item	2640867	et	4	main
ajal	doc_491521502241_item	2640893	et	4	main
tegutsesid	doc_491521502241_item	2640898	et	4	main
läbi	doc_491521502241_item	2640921	et	4	main
nagu	doc_491521502241_item	2640924	et	3	main
ariste	doc_491521502241_item	2640926	et	4	main
mägiste	doc_491521502241_item	2640927	et	4	main
mark	doc_491521502241_item	2640928	et	3	main
kultuuri	doc_491521502241_item	2640933	et	4	main
entsüklopeedia	doc_491521502241_item	2640942	et	4	main
erinevad	doc_491521502241_item	2640950	et	4	main
poliitika	doc_491521502241_item	2640958	et	4	main
reguleeris	doc_491521502241_item	2640959	et	3	main
nii	doc_491521502241_item	2640960	et	3	main
tööle	doc_491521502241_item	2640973	et	3	main
vahendid	doc_491521502241_item	2640977	et	3	main
ülemnõukogu	doc_491521502241_item	2640983	et	4	main
toimus	doc_491521502241_item	2640987	et	3	main
natsionaliseerimine	doc_491521502241_item	2640988	et	4	main
ehk	doc_491521502241_item	2640989	et	3	main
riigistamine	doc_491521502241_item	2640990	et	4	main
seatakse	doc_491521502241_item	2640991	et	4	main
sisse	doc_491521502241_item	2640992	et	4	main
plaanimajandus	doc_491521502241_item	2640993	et	3	main
arenes	doc_491521502241_item	2640994	et	3	main
rasketööstus	doc_491521502241_item	2640995	et	3	main
eriti	doc_491521502241_item	2640996	et	3	main
sõjatehnika	doc_491521502241_item	2640997	et	4	main
toodang	doc_491521502241_item	2640998	et	3	main
14	doc_491521502241_item	2640999	et	2	main
juuni	doc_491521502241_item	2641000	et	4	main
1941	doc_491521502241_item	2641001	et	2	main
esimene	doc_491521502241_item	2641002	et	3	main
suur	doc_491521502241_item	2641003	et	3	main
küüditamine	doc_491521502241_item	2641004	et	4	main
10000	doc_491521502241_item	2641005	et	2	main
inimest	doc_491521502241_item	2641006	et	3	main
viiakse	doc_491521502241_item	2641007	et	3	main
siberisse	doc_491521502241_item	2641008	et	4	main
kuskohas	doc_491521502241_item	2641009	et	4	main
18	doc_491521502241_item	2641010	et	2	main
olid	doc_491521502241_item	2641011	et	4	main
lapsed	doc_491521502241_item	2641012	et	3	main
ja	doc_491521502241_item	2641013	et	3	main
vanurid	doc_491521502241_item	2641014	et	3	main
1	doc_491521502241_item	2640863	et	2	main
ev	doc_491521502241_item	2640864	et	4	main
ja	doc_491521502241_item	2640870	et	3	main
valitsus	doc_491521502241_item	2640872	et	4	main
toimusid	doc_491521502241_item	2640874	et	4	main
loomine	doc_491521502241_item	2640880	et	4	main
eesti	doc_491521502241_item	2640894	et	4	main
oli	doc_491521502241_item	2640895	et	3	main
mitmed	doc_491521502241_item	2640922	et	4	main
haritlased	doc_491521502241_item	2640923	et	3	main
veski	doc_491521502241_item	2640925	et	4	main
rahvateaduse	doc_491521502241_item	2640935	et	3	main
tasemele	doc_491521502241_item	2640938	et	3	main
emakeele	doc_491521502241_item	2640939	et	4	main
arendamine	doc_491521502241_item	2640940	et	4	main
ja	doc_491521502241_item	2640941	et	3	main
organisatsioonid	doc_491521502241_item	2640945	et	3	main
tol	doc_491521502241_item	2640947	et	3	main
kaitseliit	doc_491521502241_item	2640952	et	3	main
jne	doc_491521502241_item	2640955	et	4	main
majandust	doc_491521502241_item	2640964	et	4	main
kommunistlik	doc_491521502241_item	2640965	et	3	main
partei	doc_491521502241_item	2640966	et	4	main
otsustas	doc_491521502241_item	2640967	et	3	main
missugust	doc_491521502241_item	2640968	et	3	main
palka	doc_491521502241_item	2640969	et	4	main
keda	doc_491521502241_item	2640972	et	4	main
partei	doc_491521502241_item	2640975	et	4	main
suunda	doc_491521502241_item	2640979	et	4	main
on	doc_491521502241_item	2640982	et	4	main
j	doc_491521502241_item	2640985	et	4	main
ensv	doc_491521502241_item	2641019	et	4	main
tsentraliseeritud	doc_491521502241_item	2641028	et	4	main
käinud	doc_491521502241_item	2641039	et	4	main
situatsiooni	doc_491521502241_item	2641041	et	4	main
võimalusi	doc_491521502241_item	2641043	et	3	main
eesotsas	doc_491521502241_item	2641046	et	4	main
on	doc_491521502241_item	2641049	et	4	main
eestlasi	doc_491521502241_item	2641052	et	3	main
teavad	doc_491521502241_item	2641056	et	3	main
ajal	doc_491521502241_item	2641062	et	4	main
toimusid	doc_491521502241_item	2641064	et	4	main
statujad	doc_491521502241_item	2641069	et	4	main
likvideeriti	doc_491521502241_item	2641070	et	3	main
ainsaks	doc_491521502241_item	2641075	et	3	main
pidi	doc_491521502241_item	2641115	et	4	main
mille	doc_491521502241_item	2641118	et	3	main
sai	doc_491521502241_item	2641120	et	4	main
paljud	doc_491521502241_item	2641123	et	3	main
kultuuri	doc_491521502241_item	2641124	et	4	main
ja	doc_491521502241_item	2641126	et	3	main
haritlasi	doc_491521502241_item	2641129	et	3	main
viidi	doc_491521502241_item	2641146	et	4	main
tuhanded	doc_491521502241_item	2641154	et	3	main
seal	doc_491521502241_item	2641156	et	4	main
ei	doc_491521502241_item	2641160	et	4	main
ajal	doc_491521502241_item	2641176	et	4	main
valge	doc_491521502241_item	2641179	et	4	main
elu	doc_491521502241_item	2641184	et	4	main
teistega	doc_491521502241_item	2641188	et	4	main
võib	doc_491521502241_item	2641196	et	3	main
üheks	doc_491521502241_item	2641200	et	3	main
kirik	doc_491521502241_item	2641208	et	3	main
usuvabadust	doc_491521502241_item	2641214	et	4	main
riigi	doc_491521502241_item	2641216	et	3	main
ensv-s	doc_491521502241_item	2641231	et	3	main
hakatakse	doc_491521502241_item	2641232	et	3	main
kultuuri	doc_491521502241_item	2641242	et	4	main
hakatakse	doc_491521502241_item	2641243	et	3	main
tähistama	doc_491521502241_item	2641244	et	3	main
uusi	doc_491521502241_item	2641245	et	3	main
peosid	doc_491521502241_item	2641246	et	3	main
majandus	doc_491521502241_item	2641252	et	4	main
enam	doc_491521502241_item	2641255	et	4	main
nii	doc_491521502241_item	2641256	et	3	main
tsentraliseeritud	doc_491521502241_item	2641257	et	4	main
avati	doc_491521502241_item	2641289	et	3	main
ja	doc_491521502242_item	2641303	et	3	main
rahvusteadus	doc_491521502242_item	2641323	et	4	main
arenema	doc_491521502242_item	2641325	et	3	main
siia	doc_491521502242_item	2641344	et	4	main
vers-barbarus	doc_491521502241_item	2640986	et	4	main
ajal	doc_491521502241_item	2641020	et	4	main
ebaeffektiivne	doc_491521502241_item	2641025	et	4	main
ei	doc_491521502241_item	2641030	et	4	main
ja	doc_491521502241_item	2641040	et	3	main
kontrollinud	doc_491521502241_item	2641044	et	4	main
riigi	doc_491521502241_item	2641045	et	3	main
kes	doc_491521502241_item	2641055	et	4	main
toimub	doc_491521502241_item	2641060	et	3	main
anti	doc_491521502241_item	2641072	et	3	main
riigikeeleks	doc_491521502241_item	2641076	et	4	main
sai	doc_491521502241_item	2641077	et	4	main
vene	doc_491521502241_item	2641078	et	4	main
keel	doc_491521502241_item	2641079	et	4	main
kultuuri	doc_491521502241_item	2641080	et	4	main
seltse	doc_491521502241_item	2641081	et	3	main
likvideeriti	doc_491521502241_item	2641082	et	3	main
paljud	doc_491521502241_item	2641083	et	3	main
neist	doc_491521502241_item	2641084	et	4	main
nt	doc_491521502241_item	2641085	et	4	main
ões	doc_491521502241_item	2641086	et	4	main
toimus	doc_491521502241_item	2641087	et	3	main
venestamine	doc_491521502241_item	2641088	et	4	main
maad	doc_491521502241_item	2641089	et	4	main
ja	doc_491521502241_item	2641090	et	3	main
vara	doc_491521502241_item	2641091	et	4	main
isegi	doc_491521502241_item	2641092	et	4	main
loomaid	doc_491521502241_item	2641093	et	4	main
riigistati	doc_491521502241_item	2641094	et	3	main
e	doc_491521502241_item	2641095	et	4	main
natsionaliseeriti	doc_491521502241_item	2641096	et	3	main
ensv	doc_491521502241_item	2641097	et	4	main
ajal	doc_491521502241_item	2641098	et	4	main
ensv	doc_491521502241_item	2641099	et	4	main
ajal	doc_491521502241_item	2641100	et	4	main
50	doc_491521502241_item	2641101	et	2	main
aastatel	doc_491521502241_item	2641102	et	4	main
oli	doc_491521502241_item	2641103	et	3	main
peamiseks	doc_491521502241_item	2641017	et	3	main
erinevuseks	doc_491521502241_item	2641018	et	4	main
plaanimajanduse	doc_491521502241_item	2641021	et	3	main
oli	doc_491521502241_item	2641024	et	3	main
moskvasse	doc_491521502241_item	2641029	et	4	main
kohal	doc_491521502241_item	2641038	et	4	main
ja	doc_491521502241_item	2641042	et	3	main
ensv	doc_491521502241_item	2641047	et	4	main
ajal	doc_491521502241_item	2641048	et	4	main
muurahvased	doc_491521502241_item	2641051	et	4	main
vähe	doc_491521502241_item	2641054	et	3	main
riigis	doc_491521502241_item	2641058	et	3	main
erinevused	doc_491521502241_item	2641065	et	4	main
sest	doc_491521502241_item	2641066	et	4	main
kõik	doc_491521502241_item	2641067	et	4	main
vene	doc_491521502241_item	2641073	et	4	main
loomad	doc_491521502241_item	2641111	et	3	main
ja	doc_491521502241_item	2641114	et	3	main
tegelased	doc_491521502241_item	2641125	et	3	main
siberisse	doc_491521502241_item	2641131	et	4	main
suurt	doc_491521502241_item	2641136	et	3	main
paljud	doc_491521502241_item	2641138	et	3	main
inimestest	doc_491521502241_item	2641139	et	3	main
surma	doc_491521502241_item	2641157	et	4	main
ensv	doc_491521502241_item	2641175	et	4	main
oli	doc_491521502241_item	2641177	et	3	main
ankeet	doc_491521502241_item	2641180	et	3	main
ja	doc_491521502241_item	2641185	et	3	main
toimub	doc_491521502241_item	2641192	et	3	main
nähtus	doc_491521502241_item	2641194	et	4	main
mida	doc_491521502241_item	2641195	et	4	main
sellele	doc_491521502241_item	2641202	et	4	main
1956	doc_491521502241_item	2641204	et	2	main
ning	doc_491521502241_item	2641211	et	3	main
nii	doc_491521502241_item	2641226	et	3	main
homo	doc_491521502241_item	2641234	et	4	main
rikkalikult	doc_491521502241_item	2641247	et	4	main
tähistatakse	doc_491521502241_item	2641248	et	3	main
tehakse	doc_491521502241_item	2641251	et	3	main
ole	doc_491521502241_item	2641254	et	4	main
korda	doc_491521502241_item	2641265	et	4	main
mõistati	doc_491521502241_item	2641266	et	4	main
kõik	doc_491521502241_item	2641267	et	4	main
tagasi	doc_491521502241_item	2641287	et	3	main
raamatukogu	doc_491521502241_item	2641291	et	4	main
uued	doc_491521502241_item	2641293	et	3	main
teadustekeskuseks	doc_491521502242_item	2641329	et	4	main
väga	doc_491521502242_item	2641330	et	3	main
tähtsal	doc_491521502242_item	2641331	et	3	main
eesti	doc_491521502242_item	2641336	et	4	main
keel	doc_491521502242_item	2641337	et	4	main
see	doc_491521502242_item	2641338	et	3	main
oli	doc_491521502242_item	2641339	et	3	main
natuke	doc_491521502242_item	2641342	et	4	main
etnograafia	doc_491521502242_item	2641350	et	4	main
ja	doc_491521502242_item	2641351	et	3	main
probleemiks	doc_491521502242_item	2641360	et	4	main
oli	doc_491521502242_item	2641361	et	3	main
see	doc_491521502242_item	2641362	et	3	main
et	doc_491521502242_item	2641363	et	3	main
jätkunud	doc_491521502242_item	2641364	et	4	main
oma	doc_491521502242_item	2641365	et	4	main
võrreldes	doc_491521502242_item	2641378	et	3	main
kes	doc_491521502242_item	2641381	et	4	main
õppisid	doc_491521502242_item	2641382	et	4	main
tugevkülg	doc_491521502242_item	2641389	et	4	main
filmikunstis	doc_491521502242_item	2641390	et	3	main
oli	doc_491521502242_item	2641391	et	3	main
dokumentalistika	doc_491521502242_item	2641392	et	4	main
käia	doc_491521502242_item	2641397	et	4	main
arenes	doc_491521502242_item	2641401	et	3	main
püüdsid	doc_491521502242_item	2641403	et	4	main
keel	doc_491521502242_item	2641408	et	4	main
teostamine	doc_491521502241_item	2641022	et	4	main
majandus	doc_491521502241_item	2641023	et	4	main
sest	doc_491521502241_item	2641026	et	4	main
oli	doc_491521502241_item	2641027	et	3	main
ole	doc_491521502241_item	2641031	et	4	main
võimalik	doc_491521502241_item	2641032	et	3	main
teha	doc_491521502241_item	2641033	et	3	main
häid	doc_491521502241_item	2641034	et	3	main
otsuseid	doc_491521502241_item	2641035	et	3	main
kui	doc_491521502241_item	2641036	et	3	main
pole	doc_491521502241_item	2641037	et	3	main
paljud	doc_491521502241_item	2641050	et	3	main
on	doc_491521502241_item	2641053	et	4	main
mis	doc_491521502241_item	2641057	et	4	main
hästi	doc_491521502241_item	2641059	et	3	main
haridust	doc_491521502241_item	2641071	et	4	main
vaja	doc_491521502241_item	2641104	et	4	main
astuda	doc_491521502241_item	2641105	et	3	main
kolhoosidesse	doc_491521502241_item	2641106	et	3	main
kuskohas	doc_491521502241_item	2641107	et	4	main
kõigile	doc_491521502241_item	2641112	et	4	main
toitu	doc_491521502241_item	2641121	et	4	main
teadlasi	doc_491521502241_item	2641127	et	3	main
ensv	doc_491521502241_item	2641132	et	4	main
ajal	doc_491521502241_item	2641133	et	4	main
toimus	doc_491521502241_item	2641134	et	3	main
küüditamist	doc_491521502241_item	2641137	et	4	main
olid	doc_491521502241_item	2641140	et	4	main
ka	doc_491521502241_item	2641141	et	3	main
lapsed	doc_491521502241_item	2641142	et	3	main
ja	doc_491521502241_item	2641143	et	3	main
vanurid	doc_491521502241_item	2641144	et	3	main
neid	doc_491521502241_item	2641145	et	4	main
elama	doc_491521502241_item	2641151	et	3	main
ja	doc_491521502241_item	2641152	et	3	main
said	doc_491521502241_item	2641155	et	4	main
sest	doc_491521502241_item	2641158	et	4	main
olnud	doc_491521502241_item	2641161	et	4	main
millega	doc_491521502241_item	2641181	et	3	main
sinu	doc_491521502241_item	2641183	et	3	main
2	doc_491521502241_item	2641189	et	2	main
sule	doc_491521502241_item	2641191	et	4	main
süsteemiga	doc_491521502241_item	2641199	et	3	main
ungaris	doc_491521502241_item	2641207	et	4	main
tähendas	doc_491521502241_item	2641213	et	3	main
maad	doc_491521502241_item	2641217	et	4	main
võeti	doc_491521502241_item	2641218	et	3	main
riigile	doc_491521502241_item	2641219	et	3	main
riigistati	doc_491521502241_item	2641220	et	3	main
ning	doc_491521502241_item	2641221	et	3	main
kirikud	doc_491521502241_item	2641222	et	3	main
pidid	doc_491521502241_item	2641223	et	4	main
nimetama	doc_491521502241_item	2641233	et	3	main
tegutses	doc_491521502241_item	2641237	et	3	main
eesti	doc_491521502241_item	2641239	et	4	main
energetika	doc_491521502241_item	2641258	et	4	main
tööstuse	doc_491521502241_item	2641259	et	3	main
areng	doc_491521502241_item	2641260	et	3	main
stalini	doc_491521502241_item	2641268	et	4	main
isikut	doc_491521502241_item	2641278	et	3	main
st	doc_491521502241_item	2641282	et	3	main
nad	doc_491521502241_item	2641283	et	3	main
said	doc_491521502241_item	2641284	et	4	main
võimaluse	doc_491521502241_item	2641285	et	3	main
kodumaale	doc_491521502241_item	2641286	et	4	main
pöörduma	doc_491521502241_item	2641288	et	3	main
rummo	doc_491521502241_item	2641296	et	4	main
kontrolltöö	doc_491521502242_item	2641298	et	4	main
hakkas	doc_491521502242_item	2641321	et	3	main
ensv	doc_491521502241_item	2641061	et	4	main
kultuurielus	doc_491521502241_item	2641063	et	4	main
ev	doc_491521502241_item	2641068	et	4	main
keeles	doc_491521502241_item	2641074	et	4	main
oma	doc_491521502241_item	2641110	et	4	main
kasutamiseks	doc_491521502241_item	2641113	et	4	main
päevaplaani	doc_491521502241_item	2641117	et	4	main
eest	doc_491521502241_item	2641119	et	4	main
ensv	doc_491521502241_item	2641162	et	4	main
ajal	doc_491521502241_item	2641163	et	4	main
paljud	doc_491521502241_item	2641164	et	3	main
läksid	doc_491521502241_item	2641165	et	4	main
elama	doc_491521502241_item	2641166	et	3	main
kanadasse	doc_491521502241_item	2641167	et	4	main
rootsisse	doc_491521502241_item	2641168	et	3	main
soomesse	doc_491521502241_item	2641169	et	3	main
jne	doc_491521502241_item	2641170	et	4	main
kontaktid	doc_491521502241_item	2641171	et	3	main
nendega	doc_491521502241_item	2641172	et	4	main
olid	doc_491521502241_item	2641173	et	4	main
keelatud	doc_491521502241_item	2641174	et	4	main
rahvas	doc_491521502241_item	2641108	et	4	main
annas	doc_491521502241_item	2641109	et	3	main
tegema	doc_491521502241_item	2641116	et	3	main
palka	doc_491521502241_item	2641122	et	4	main
ning	doc_491521502241_item	2641128	et	3	main
saadeti	doc_491521502241_item	2641130	et	3	main
2	doc_491521502241_item	2641135	et	2	main
siberisse	doc_491521502241_item	2641147	et	4	main
kus	doc_491521502241_item	2641148	et	3	main
nad	doc_491521502241_item	2641149	et	3	main
pidid	doc_491521502241_item	2641150	et	4	main
töötama	doc_491521502241_item	2641153	et	3	main
toitu	doc_491521502241_item	2641159	et	4	main
nn	doc_491521502241_item	2641178	et	4	main
kontrolliti	doc_491521502241_item	2641182	et	3	main
suhted	doc_491521502241_item	2641186	et	3	main
kontaktid	doc_491521502241_item	2641187	et	3	main
hruštšovi	doc_491521502241_item	2641190	et	2	main
niisugune	doc_491521502241_item	2641193	et	3	main
kohanemiseks	doc_491521502241_item	2641198	et	4	main
põhjuseks	doc_491521502241_item	2641201	et	3	main
said	doc_491521502241_item	2641203	et	4	main
a	doc_491521502241_item	2641205	et	4	main
sündmused	doc_491521502241_item	2641206	et	3	main
riigist	doc_491521502241_item	2641210	et	3	main
ise	doc_491521502241_item	2641224	et	4	main
elama	doc_491521502241_item	2641225	et	3	main
kuidas	doc_491521502241_item	2641227	et	3	main
saavad	doc_491521502241_item	2641229	et	4	main
inimesi	doc_491521502241_item	2641230	et	4	main
soveticus	doc_491521502241_item	2641235	et	4	main
ekp	doc_491521502241_item	2641238	et	4	main
kommunistlik	doc_491521502241_item	2641240	et	3	main
partei	doc_491521502241_item	2641241	et	4	main
ei	doc_491521502241_item	2641253	et	4	main
2	doc_491521502241_item	2641264	et	2	main
tegevust	doc_491521502241_item	2641269	et	4	main
ja	doc_491521502241_item	2641270	et	3	main
teda	doc_491521502241_item	2641271	et	4	main
tegid	doc_491521502241_item	2641272	et	4	main
üheks	doc_491521502241_item	2641273	et	3	main
süütjaks	doc_491521502241_item	2641274	et	4	main
mitte	doc_491521502241_item	2641275	et	3	main
režiimi	doc_491521502241_item	2641276	et	2	main
vaid	doc_491521502241_item	2641277	et	3	main
paljud	doc_491521502241_item	2641279	et	3	main
eestlased	doc_491521502241_item	2641280	et	3	main
rehabiliteeriti	doc_491521502241_item	2641281	et	3	main
loomingu	doc_491521502241_item	2641290	et	3	main
paljud	doc_491521502241_item	2641292	et	3	main
traat	doc_491521502241_item	2641295	et	3	main
jne	doc_491521502241_item	2641297	et	4	main
1	doc_491521502242_item	2641299	et	2	main
võrrelge	doc_491521502242_item	2641300	et	3	main
ev	doc_491521502242_item	2641301	et	4	main
aegsest	doc_491521502242_item	2641302	et	3	main
arenema	doc_491521502242_item	2641322	et	3	main
hakkas	doc_491521502242_item	2641324	et	3	main
kohal	doc_491521502242_item	2641332	et	4	main
oli	doc_491521502242_item	2641333	et	3	main
ja	doc_491521502242_item	2641335	et	3	main
eesti	doc_491521502242_item	2641355	et	4	main
arheoloogiast	doc_491521502242_item	2641356	et	3	main
ja	doc_491521502242_item	2641357	et	3	main
ajaloost	doc_491521502242_item	2641358	et	4	main
teadlasi	doc_491521502242_item	2641366	et	3	main
seetõttu	doc_491521502242_item	2641367	et	3	main
kustuti	doc_491521502242_item	2641368	et	4	main
välismaalt	doc_491521502242_item	2641369	et	3	main
haridus	doc_491521502242_item	2641370	et	3	main
oli	doc_491521502242_item	2641371	et	3	main
ka	doc_491521502242_item	2641372	et	3	main
väga	doc_491521502242_item	2641373	et	3	main
jätkasid	doc_491521502242_item	2641383	et	4	main
eesti	doc_491521502242_item	2641407	et	4	main
j	doc_491521502242_item	2641411	et	4	main
uurima	doc_491521502242_item	2641421	et	3	main
avalikud	doc_491521502242_item	2641430	et	3	main
keele	doc_491521502242_item	2641436	et	4	main
kaardistas	doc_491521502242_item	2641439	et	3	main
ettevõtteid	doc_491521502242_item	2641442	et	3	main
nimetada	doc_491521502241_item	2641197	et	3	main
lahutati	doc_491521502241_item	2641209	et	3	main
see	doc_491521502241_item	2641212	et	3	main
kõik	doc_491521502241_item	2641215	et	4	main
nad	doc_491521502241_item	2641228	et	3	main
riigis	doc_491521502241_item	2641236	et	3	main
sünnipäevi	doc_491521502241_item	2641249	et	4	main
laulupeosid	doc_491521502241_item	2641250	et	3	main
majandus	doc_491521502241_item	2641261	et	4	main
kasvas	doc_491521502241_item	2641262	et	3	main
peaaegu	doc_491521502241_item	2641263	et	3	main
autorid	doc_491521502241_item	2641294	et	3	main
ensv	doc_491521502242_item	2641304	et	4	main
pärastsõjajärgset	doc_491521502242_item	2641305	et	3	main
kultuurielu	doc_491521502242_item	2641306	et	4	main
2	doc_491521502242_item	2641307	et	2	main
sotsialistlik	doc_491521502242_item	2641308	et	3	main
realism	doc_491521502242_item	2641309	et	3	main
kui	doc_491521502242_item	2641310	et	3	main
1	doc_491521502242_item	2641312	et	2	main
kirjandusvool	doc_491521502242_item	2641311	et	4	main
kui	doc_491521502242_item	2641313	et	3	main
1918	doc_491521502242_item	2641314	et	2	main
aastal	doc_491521502242_item	2641315	et	3	main
eestit	doc_491521502242_item	2641316	et	3	main
tunnistati	doc_491521502242_item	2641317	et	4	main
eesti	doc_491521502242_item	2641318	et	4	main
vabariigiks	doc_491521502242_item	2641319	et	3	main
kultuurielu	doc_491521502242_item	2641320	et	4	main
tartu	doc_491521502242_item	2641326	et	4	main
ülikool	doc_491521502242_item	2641327	et	4	main
rahvuskirjandus	doc_491521502242_item	2641334	et	3	main
teema	doc_491521502242_item	2641341	et	4	main
hiljem	doc_491521502242_item	2641343	et	3	main
rahvaluule	doc_491521502242_item	2641352	et	4	main
huvitusid	doc_491521502242_item	2641353	et	4	main
ka	doc_491521502242_item	2641354	et	3	main
euroopaga	doc_491521502242_item	2641377	et	3	main
eestlastele	doc_491521502242_item	2641393	et	4	main
kinodes	doc_491521502242_item	2641396	et	3	main
väga	doc_491521502242_item	2641399	et	3	main
i	doc_491521502242_item	2641413	et	4	main
erinevaid	doc_491521502242_item	2641423	et	4	main
raamatukogud	doc_491521502242_item	2641431	et	3	main
murrete	doc_491521502242_item	2641437	et	3	main
maale	doc_491521502242_item	2641440	et	4	main
jõuab	doc_491521502242_item	2641441	et	3	main
raadio	doc_491521502242_item	2641450	et	4	main
uueks	doc_491521502242_item	2641453	et	3	main
jalgratas	doc_491521502242_item	2641456	et	3	main
ilmub	doc_491521502242_item	2641458	et	3	main
see	doc_491521502242_item	2641462	et	3	main
on	doc_491521502242_item	2641467	et	4	main
kultuurielu	doc_491521502242_item	2641483	et	4	main
pidurdavad	doc_491521502242_item	2641495	et	4	main
usuvabadus	doc_491521502242_item	2641504	et	4	main
perekonna	doc_491521502242_item	2641505	et	4	main
rituaalid	doc_491521502242_item	2641506	et	3	main
muudeti	doc_491521502242_item	2641507	et	3	main
välja	doc_491521502242_item	2641528	et	4	main
kirjanikke	doc_491521502242_item	2641529	et	3	main
seltsidest	doc_491521502242_item	2641530	et	3	main
sama	doc_491521502242_item	2641531	et	4	main
sai	doc_491521502242_item	2641328	et	4	main
uus	doc_491521502242_item	2641340	et	3	main
juurdusid	doc_491521502242_item	2641345	et	4	main
sellised	doc_491521502242_item	2641346	et	4	main
teemad	doc_491521502242_item	2641347	et	3	main
nagu	doc_491521502242_item	2641348	et	3	main
eesti	doc_491521502242_item	2641349	et	4	main
isegi	doc_491521502242_item	2641376	et	4	main
õppimist	doc_491521502242_item	2641384	et	4	main
kõrgkoolideni	doc_491521502242_item	2641385	et	3	main
arenes	doc_491521502242_item	2641386	et	3	main
muusika	doc_491521502242_item	2641387	et	4	main
eesti	doc_491521502242_item	2641388	et	4	main
väga	doc_491521502242_item	2641394	et	3	main
euroopa	doc_491521502242_item	2641405	et	4	main
stiile	doc_491521502242_item	2641406	et	3	main
lektor	doc_491521502242_item	2641415	et	3	main
pidas	doc_491521502242_item	2641416	et	3	main
eesti	doc_491521502242_item	2641417	et	4	main
keele	doc_491521502242_item	2641418	et	4	main
loenguid	doc_491521502242_item	2641419	et	4	main
hakatakse	doc_491521502242_item	2641420	et	3	main
tendentse	doc_491521502242_item	2641424	et	3	main
keele	doc_491521502242_item	2641426	et	4	main
ilmub	doc_491521502242_item	2641427	et	3	main
folkloor	doc_491521502242_item	2641428	et	4	main
eesti	doc_491521502242_item	2641435	et	4	main
kuulata	doc_491521502242_item	2641446	et	4	main
saab	doc_491521502242_item	2641451	et	3	main
juba	doc_491521502242_item	2641468	et	3	main
esimene	doc_491521502242_item	2641470	et	3	main
arene	doc_491521502242_item	2641485	et	4	main
kultuurielu	doc_491521502242_item	2641496	et	4	main
formaalseteks	doc_491521502242_item	2641508	et	4	main
ja	doc_491521502242_item	2641535	et	3	main
eesti	doc_491521502242_item	2641550	et	4	main
vabariigi	doc_491521502242_item	2641551	et	3	main
monumendid	doc_491521502242_item	2641552	et	3	main
likvideeriti	doc_491521502242_item	2641553	et	3	main
sümboleid	doc_491521502242_item	2641571	et	3	main
vastu	doc_491521502242_item	2641573	et	3	main
nõukogude	doc_491521502242_item	2641585	et	3	main
sõja	doc_491521502242_item	2641588	et	3	main
huvitas	doc_491521502242_item	2641595	et	3	main
moskvat	doc_491521502242_item	2641597	et	4	main
oli	doc_491521502242_item	2641610	et	3	main
keelatud	doc_491521502242_item	2641611	et	4	main
ilmusid	doc_491521502242_item	2641612	et	4	main
kolhoosid	doc_491521502242_item	2641613	et	3	main
ja	doc_491521502242_item	2641614	et	3	main
koonduvad	doc_491521502242_item	2641620	et	4	main
vaesemad	doc_491521502242_item	2641621	et	4	main
kuid	doc_491521502242_item	2641623	et	4	main
oli	doc_491521502242_item	2641624	et	3	main
ka	doc_491521502242_item	2641626	et	3	main
jõukamaid	doc_491521502242_item	2641627	et	4	main
et	doc_491521502242_item	2641633	et	3	main
küüdiatmist	doc_491521502242_item	2641637	et	4	main
ikkagi	doc_491521502242_item	2641639	et	4	main
toimus	doc_491521502242_item	2641640	et	3	main
1941	doc_491521502242_item	2641643	et	2	main
oli	doc_491521502242_item	2641646	et	3	main
30000	doc_491521502242_item	2641649	et	2	main
inimest	doc_491521502242_item	2641650	et	3	main
hariduses	doc_491521502242_item	2641651	et	3	main
ilmus	doc_491521502242_item	2641652	et	4	main
ankeet	doc_491521502242_item	2641657	et	3	main
tohtinud	doc_491521502242_item	2641659	et	4	main
eks	doc_491521502242_item	2641662	et	3	main
inimesed	doc_491521502242_item	2641667	et	3	main
ja	doc_491521502242_item	2641678	et	3	main
realism	doc_491521502242_item	2641682	et	3	main
kirjandusvool	doc_491521502242_item	2641684	et	4	main
kõik	doc_491521502242_item	2641685	et	4	main
kirjandus	doc_491521502242_item	2641686	et	3	main
algul	doc_491521502242_item	2641359	et	4	main
kõrgel	doc_491521502242_item	2641374	et	4	main
tasemel	doc_491521502242_item	2641375	et	3	main
tavaliselt	doc_491521502242_item	2641379	et	4	main
kõik	doc_491521502242_item	2641380	et	4	main
meeldis	doc_491521502242_item	2641395	et	3	main
see	doc_491521502242_item	2641398	et	3	main
kiiresti	doc_491521502242_item	2641400	et	3	main
arhitektuuris	doc_491521502242_item	2641402	et	3	main
jälgida	doc_491521502242_item	2641404	et	3	main
ka	doc_491521502242_item	2641409	et	3	main
arenes	doc_491521502242_item	2641410	et	3	main
jõgever	doc_491521502242_item	2641412	et	4	main
tü	doc_491521502242_item	2641414	et	4	main
murdeid	doc_491521502242_item	2641422	et	3	main
eesti	doc_491521502242_item	2641425	et	4	main
atlase	doc_491521502242_item	2641438	et	3	main
klassikalist	doc_491521502242_item	2641447	et	4	main
kuid	doc_491521502242_item	2641466	et	4	main
samm	doc_491521502242_item	2641471	et	3	main
ja	doc_491521502242_item	2641474	et	3	main
tõesti	doc_491521502242_item	2641476	et	3	main
euroopa	doc_491521502242_item	2641479	et	4	main
riik	doc_491521502242_item	2641480	et	3	main
ensv	doc_491521502242_item	2641481	et	4	main
pärastsõjajärgne	doc_491521502242_item	2641482	et	3	main
kogu	doc_491521502242_item	2641490	et	4	main
kasvu	doc_491521502242_item	2641497	et	4	main
seetõttu	doc_491521502242_item	2641501	et	3	main
kalendripäevi	doc_491521502242_item	2641509	et	4	main
piiramine	doc_491521502242_item	2641523	et	4	main
kirjanikud	doc_491521502242_item	2641525	et	3	main
on	doc_491521502242_item	2641526	et	4	main
visatud	doc_491521502242_item	2641527	et	4	main
kunstniketega	doc_491521502242_item	2641534	et	4	main
nende	doc_491521502242_item	2641547	et	4	main
aga	doc_491521502242_item	2641581	et	3	main
ehk	doc_491521502242_item	2641587	et	3	main
mille	doc_491521502242_item	2641593	et	3	main
töötlemine	doc_491521502242_item	2641594	et	4	main
kui	doc_491521502242_item	2641598	et	3	main
eestit	doc_491521502242_item	2641599	et	3	main
kirjandus	doc_491521502242_item	2641600	et	3	main
teod	doc_491521502242_item	2641601	et	4	main
talupoegi	doc_491521502242_item	2641628	et	4	main
kartsid	doc_491521502242_item	2641635	et	4	main
selline	doc_491521502242_item	2641653	et	4	main
soetud	doc_491521502242_item	2641664	et	4	main
metsavennad	doc_491521502242_item	2641671	et	3	main
muutusid	doc_491521502242_item	2641672	et	4	main
partei	doc_491521502242_item	2641675	et	4	main
majandust	doc_491521502242_item	2641677	et	4	main
kontrolltöö	doc_491521502243_item	2641727	et	4	main
eesti	doc_491521502243_item	2641728	et	4	main
eesti	doc_491521502243_item	2641733	et	4	main
start1	doc_491521502243_item	2641738	et	3	main
classmsonormalbspan	doc_491521502243_item	2641742	et	4	main
nsv-s	doc_491521502243_item	2641749	et	3	main
span	doc_491521502243_item	2641750	et	4	main
kuidas	doc_491521502243_item	2641755	et	3	main
film	doc_491521502243_item	2641758	et	3	main
mitte-eestlastest	doc_491521502243_item	2641760	et	4	main
ennem	doc_491521502243_item	2641800	et	4	main
tulla	doc_491521502243_item	2641821	et	3	main
eestlased	doc_491521502243_item	2641825	et	3	main
elavad	doc_491521502243_item	2641833	et	4	main
seal	doc_491521502243_item	2641834	et	4	main
tänapäevani	doc_491521502243_item	2641835	et	3	main
kuid	doc_491521502243_item	2641836	et	4	main
minu	doc_491521502243_item	2641837	et	3	main
arenemist	doc_491521502243_item	2641843	et	4	main
2	doc_491521502243_item	2641844	et	2	main
ja	doc_491521502243_item	2641854	et	3	main
film	doc_491521502243_item	2641855	et	3	main
ja	doc_491521502243_item	2641856	et	3	main
põhikooli	doc_491521502243_item	2641860	et	4	main
oleks	doc_491521502243_item	2641862	et	3	main
suhteid	doc_491521502243_item	2641887	et	3	main
lapsed	doc_491521502243_item	2641894	et	3	main
viha	doc_491521502243_item	2641896	et	4	main
ka	doc_491521502243_item	2641910	et	3	main
avatakse	doc_491521502242_item	2641429	et	4	main
a	doc_491521502242_item	2641432	et	4	main
saareste	doc_491521502242_item	2641433	et	4	main
koostas	doc_491521502242_item	2641434	et	4	main
nt	doc_491521502242_item	2641443	et	4	main
on	doc_491521502242_item	2641444	et	4	main
võimalik	doc_491521502242_item	2641445	et	3	main
grammafoonis	doc_491521502242_item	2641449	et	4	main
liikumisvahendiks	doc_491521502242_item	2641454	et	3	main
balett	doc_491521502242_item	2641459	et	4	main
ja	doc_491521502242_item	2641460	et	3	main
ooper	doc_491521502242_item	2641461	et	3	main
on	doc_491521502242_item	2641463	et	4	main
väga	doc_491521502242_item	2641464	et	3	main
primitiivne	doc_491521502242_item	2641465	et	3	main
olemas	doc_491521502242_item	2641469	et	4	main
õitses	doc_491521502242_item	2641473	et	4	main
ei	doc_491521502242_item	2641484	et	4	main
edukalt	doc_491521502242_item	2641489	et	4	main
aeg	doc_491521502242_item	2641491	et	3	main
toimuvad	doc_491521502242_item	2641492	et	4	main
repressioonid	doc_491521502242_item	2641493	et	3	main
mis	doc_491521502242_item	2641494	et	4	main
lahutatakse	doc_491521502242_item	2641499	et	3	main
riigis	doc_491521502242_item	2641502	et	3	main
tähistatakse	doc_491521502242_item	2641510	et	3	main
massiliselt	doc_491521502242_item	2641511	et	4	main
said	doc_491521502242_item	2641512	et	4	main
populaarseteks	doc_491521502242_item	2641513	et	4	main
suvepäevad	doc_491521502242_item	2641514	et	3	main
tekkisid	doc_491521502242_item	2641515	et	4	main
uued	doc_491521502242_item	2641516	et	3	main
tavad	doc_491521502242_item	2641517	et	3	main
riigis	doc_491521502242_item	2641518	et	3	main
on	doc_491521502242_item	2641519	et	4	main
sõna	doc_491521502242_item	2641520	et	4	main
muusikad	doc_491521502242_item	2641448	et	3	main
populaarseks	doc_491521502242_item	2641452	et	4	main
saab	doc_491521502242_item	2641455	et	3	main
eestis	doc_491521502242_item	2641457	et	3	main
eestima	doc_491521502242_item	2641472	et	4	main
oli	doc_491521502242_item	2641475	et	3	main
üks	doc_491521502242_item	2641477	et	3	main
kena	doc_491521502242_item	2641478	et	4	main
enam	doc_491521502242_item	2641486	et	4	main
vähemalt	doc_491521502242_item	2641487	et	4	main
nii	doc_491521502242_item	2641488	et	3	main
kirikut	doc_491521502242_item	2641498	et	3	main
riigist	doc_491521502242_item	2641500	et	3	main
on	doc_491521502242_item	2641503	et	4	main
ja	doc_491521502242_item	2641521	et	3	main
teiste	doc_491521502242_item	2641536	et	4	main
neist	doc_491521502242_item	2641539	et	4	main
paljud	doc_491521502242_item	2641541	et	3	main
raamatud	doc_491521502242_item	2641542	et	4	main
kuhu	doc_491521502242_item	2641564	et	3	main
monument	doc_491521502242_item	2641567	et	3	main
milline	doc_491521502242_item	2641569	et	3	main
nagu	doc_491521502242_item	2641575	et	3	main
neid	doc_491521502242_item	2641577	et	4	main
tõlgendas	doc_491521502242_item	2641578	et	3	main
elektroonikat	doc_491521502242_item	2641580	et	3	main
see	doc_491521502242_item	2641582	et	3	main
jaoks	doc_491521502242_item	2641586	et	4	main
rohkem	doc_491521502242_item	2641596	et	4	main
tondiöömaja	doc_491521502242_item	2641607	et	4	main
mõni	doc_491521502242_item	2641608	et	3	main
aeg	doc_491521502242_item	2641609	et	3	main
arvati	doc_491521502242_item	2641617	et	4	main
et	doc_491521502242_item	2641618	et	3	main
sinna	doc_491521502242_item	2641619	et	3	main
inimesed	doc_491521502242_item	2641622	et	3	main
sellega	doc_491521502242_item	2641632	et	3	main
järjekordset	doc_491521502242_item	2641636	et	3	main
nähtus	doc_491521502242_item	2641654	et	4	main
ei	doc_491521502242_item	2641658	et	4	main
olla	doc_491521502242_item	2641660	et	3	main
sugulasi	doc_491521502242_item	2641661	et	3	main
oleksid	doc_491521502242_item	2641663	et	4	main
valitsusega	doc_491521502242_item	2641665	et	4	main
eriti	doc_491521502242_item	2641673	et	3	main
dikteeris	doc_491521502242_item	2641676	et	3	main
2	doc_491521502242_item	2641680	et	2	main
kui	doc_491521502242_item	2641683	et	3	main
esindajaid	doc_491521502242_item	2641721	et	4	main
oli	doc_491521502242_item	2641723	et	3	main
ii	doc_491521502243_item	2641730	et	4	main
ii	doc_491521502243_item	2641735	et	4	main
stylemargin-top	doc_491521502243_item	2641739	et	4	main
langetmajanduse	doc_491521502243_item	2641743	et	4	main
ja	doc_491521502243_item	2641744	et	3	main
seosed	doc_491521502243_item	2641746	et	3	main
ja	doc_491521502243_item	2641754	et	3	main
õpilastele	doc_491521502243_item	2641762	et	4	main
nõukogude	doc_491521502243_item	2641767	et	3	main
arenema	doc_491521502243_item	2641770	et	3	main
kuigi	doc_491521502243_item	2641783	et	3	main
nüüd	doc_491521502243_item	2641795	et	4	main
pisut	doc_491521502243_item	2641796	et	3	main
kui	doc_491521502243_item	2641799	et	3	main
küsimus	doc_491521502243_item	2641802	et	4	main
trükivabaduse	doc_491521502242_item	2641522	et	4	main
paljud	doc_491521502242_item	2641524	et	3	main
lugu	doc_491521502242_item	2641532	et	4	main
oli	doc_491521502242_item	2641533	et	3	main
hävitamine	doc_491521502242_item	2641548	et	4	main
kõik	doc_491521502242_item	2641549	et	4	main
taheti	doc_491521502242_item	2641555	et	3	main
võimalikult	doc_491521502242_item	2641556	et	4	main
täielikum	doc_491521502242_item	2641557	et	4	main
kustutada	doc_491521502242_item	2641558	et	3	main
rahva	doc_491521502242_item	2641559	et	3	main
mälu	doc_491521502242_item	2641560	et	4	main
folkloor	doc_491521502242_item	2641561	et	4	main
arenes	doc_491521502242_item	2641562	et	3	main
sellega	doc_491521502242_item	2641563	et	3	main
kultuuritegelastega	doc_491521502242_item	2641537	et	3	main
paljusid	doc_491521502242_item	2641538	et	3	main
represseeriti	doc_491521502242_item	2641540	et	3	main
olid	doc_491521502242_item	2641543	et	4	main
keelatud	doc_491521502242_item	2641544	et	4	main
ja	doc_491521502242_item	2641545	et	3	main
toimus	doc_491521502242_item	2641546	et	3	main
sellega	doc_491521502242_item	2641554	et	3	main
pandi	doc_491521502242_item	2641565	et	4	main
võeti	doc_491521502242_item	2641572	et	3	main
nii	doc_491521502242_item	2641574	et	3	main
rohkem	doc_491521502242_item	2641584	et	4	main
põlevkivi	doc_491521502242_item	2641590	et	4	main
maavaraks	doc_491521502242_item	2641592	et	3	main
sohvoosid	doc_491521502242_item	2641615	et	4	main
mingi	doc_491521502242_item	2641566	et	4	main
ja	doc_491521502242_item	2641568	et	3	main
kristlikke	doc_491521502242_item	2641570	et	3	main
partei	doc_491521502242_item	2641576	et	4	main
toodeti	doc_491521502242_item	2641579	et	3	main
oli	doc_491521502242_item	2641583	et	3	main
jaoks	doc_491521502242_item	2641589	et	4	main
oli	doc_491521502242_item	2641591	et	3	main
peegeldasid	doc_491521502242_item	2641602	et	4	main
tolleaegseid	doc_491521502242_item	2641603	et	3	main
sündmusi	doc_491521502242_item	2641604	et	3	main
m	doc_491521502242_item	2641605	et	4	main
kiik	doc_491521502242_item	2641606	et	3	main
algul	doc_491521502242_item	2641616	et	4	main
palju	doc_491521502242_item	2641625	et	4	main
nad	doc_491521502242_item	2641634	et	3	main
2526	doc_491521502242_item	2641641	et	2	main
norm	doc_491521502242_item	2641645	et	3	main
nagu	doc_491521502242_item	2641655	et	3	main
sorteeriti	doc_491521502242_item	2641668	et	3	main
agressiivsemateks	doc_491521502242_item	2641674	et	4	main
kultuurielu	doc_491521502242_item	2641679	et	4	main
sotsialistlik	doc_491521502242_item	2641681	et	3	main
kontrolltöö	doc_491521502243_item	2641732	et	4	main
ol	doc_491521502243_item	2641737	et	4	main
1970ndate	doc_491521502243_item	2641747	et	4	main
see	doc_491521502243_item	2641757	et	3	main
põhikooli	doc_491521502243_item	2641761	et	4	main
majandus	doc_491521502243_item	2641768	et	4	main
põlevkivi	doc_491521502243_item	2641781	et	4	main
ei	doc_491521502243_item	2641785	et	4	main
kasulik	doc_491521502243_item	2641787	et	3	main
eesti	doc_491521502243_item	2641788	et	4	main
paremas	doc_491521502243_item	2641797	et	4	main
seisundis	doc_491521502243_item	2641798	et	3	main
venemaal	doc_491521502243_item	2641827	et	4	main
teistes	doc_491521502243_item	2641829	et	4	main
meelest	doc_491521502243_item	2641838	et	4	main
see	doc_491521502243_item	2641839	et	3	main
kevade	doc_491521502243_item	2641845	et	4	main
kõigepealt	doc_491521502243_item	2641846	et	3	main
tahaks	doc_491521502243_item	2641847	et	3	main
arvan	doc_491521502243_item	2641858	et	3	main
väga	doc_491521502243_item	2641863	et	3	main
mis	doc_491521502243_item	2641876	et	4	main
20-da	doc_491521502243_item	2641878	et	4	main
saksa	doc_491521502243_item	2641893	et	4	main
üksteise	doc_491521502243_item	2641897	et	4	main
vastu	doc_491521502243_item	2641898	et	3	main
aitab	doc_491521502243_item	2641899	et	3	main
paremini	doc_491521502243_item	2641900	et	4	main
mõista	doc_491521502243_item	2641901	et	4	main
selles	doc_491521502243_item	2641907	et	4	main
palju	doc_491521502243_item	2641911	et	4	main
näiteks	doc_491521502243_item	2641913	et	4	main
arno	doc_491521502243_item	2641914	et	4	main
oma	doc_491521502243_item	2641916	et	4	main
kes	doc_491521502243_item	2641918	et	4	main
ta	doc_491521502243_item	2641926	et	4	main
rohkemat	doc_491521502243_item	2641929	et	4	main
film	doc_491521502243_item	2641941	et	3	main
õppevahendina	doc_491521502243_item	2641944	et	3	main
sellest	doc_491521502243_item	2641956	et	4	main
lastele	doc_491521502243_item	2641968	et	4	main
ma	doc_491521502243_item	2641969	et	3	main
ka	doc_491521502243_item	2641972	et	3	main
võivad	doc_491521502243_item	2641975	et	4	main
see	doc_491521502242_item	2641629	et	3	main
oli	doc_491521502242_item	2641630	et	3	main
seotud	doc_491521502242_item	2641631	et	4	main
see	doc_491521502242_item	2641638	et	3	main
märtsil	doc_491521502242_item	2641642	et	3	main
aastal	doc_491521502242_item	2641644	et	3	main
tehtud	doc_491521502242_item	2641647	et	4	main
represseeriti	doc_491521502242_item	2641648	et	3	main
puhas	doc_491521502242_item	2641656	et	3	main
kultuuriga	doc_491521502242_item	2641666	et	4	main
päritolu	doc_491521502242_item	2641669	et	4	main
järgi	doc_491521502242_item	2641670	et	4	main
oli	doc_491521502242_item	2641687	et	3	main
samasugune	doc_491521502242_item	2641688	et	3	main
tüükiline	doc_491521502242_item	2641689	et	4	main
inimestest	doc_491521502242_item	2641690	et	3	main
kasvatati	doc_491521502242_item	2641691	et	3	main
kamuniste	doc_491521502242_item	2641692	et	4	main
kes	doc_491521502242_item	2641693	et	4	main
oleksid	doc_491521502242_item	2641694	et	4	main
truu	doc_491521502242_item	2641695	et	4	main
oma	doc_491521502242_item	2641696	et	4	main
kodumaale	doc_491521502242_item	2641697	et	4	main
kõikides	doc_491521502242_item	2641698	et	4	main
kirjandusteostes	doc_491521502242_item	2641699	et	3	main
oli	doc_491521502242_item	2641700	et	3	main
üks	doc_491521502242_item	2641701	et	3	main
inimestest	doc_491521502242_item	2641703	et	3	main
kommunistideks	doc_491521502242_item	2641704	et	3	main
see	doc_491521502242_item	2641705	et	3	main
oli	doc_491521502242_item	2641706	et	3	main
eesmärk	doc_491521502242_item	2641707	et	3	main
inimeste	doc_491521502242_item	2641708	et	3	main
elu	doc_491521502242_item	2641709	et	4	main
joon	doc_491521502242_item	2641702	et	4	main
oli	doc_491521502242_item	2641710	et	3	main
riigi	doc_491521502242_item	2641711	et	3	main
range	doc_491521502242_item	2641712	et	4	main
kontrolli	doc_491521502242_item	2641713	et	4	main
all	doc_491521502242_item	2641714	et	3	main
eestimaal	doc_491521502242_item	2641715	et	4	main
oli	doc_491521502242_item	2641716	et	3	main
ka	doc_491521502242_item	2641717	et	3	main
mitu	doc_491521502242_item	2641718	et	4	main
selle	doc_491521502242_item	2641719	et	4	main
voolu	doc_491521502242_item	2641720	et	4	main
kultuuriloost	doc_491521502243_item	2641729	et	4	main
kultuuriloost	doc_491521502243_item	2641734	et	4	main
type1li	doc_491521502243_item	2641741	et	4	main
eesti	doc_491521502243_item	2641748	et	4	main
kruusemendilutsu	doc_491521502243_item	2641751	et	4	main
kevade	doc_491521502243_item	2641752	et	4	main
sobiks	doc_491521502243_item	2641756	et	4	main
1	doc_491521502243_item	2641763	et	2	main
1970ndatel	doc_491521502243_item	2641764	et	4	main
hakkas	doc_491521502243_item	2641766	et	3	main
ta	doc_491521502243_item	2641774	et	4	main
hakkasid	doc_491521502243_item	2641776	et	4	main
arenema	doc_491521502243_item	2641777	et	3	main
tehased	doc_491521502243_item	2641778	et	3	main
ja	doc_491521502243_item	2641779	et	3	main
algas	doc_491521502243_item	2641780	et	3	main
see	doc_491521502243_item	2641784	et	3	main
olnud	doc_491521502243_item	2641786	et	4	main
migratsiooni	doc_491521502243_item	2641801	et	4	main
oli	doc_491521502243_item	2641803	et	3	main
aga	doc_491521502243_item	2641804	et	3	main
keeruline	doc_491521502243_item	2641806	et	4	main
endiselt	doc_491521502243_item	2641805	et	4	main
inimesi	doc_491521502243_item	2641807	et	4	main
saadeti	doc_491521502243_item	2641808	et	3	main
tööle	doc_491521502243_item	2641809	et	3	main
kaugele	doc_491521502243_item	2641810	et	4	main
nende	doc_491521502243_item	2641811	et	4	main
kodust	doc_491521502243_item	2641812	et	4	main
ja	doc_491521502243_item	2641813	et	3	main
üsna	doc_491521502243_item	2641814	et	3	main
tihti	doc_491521502243_item	2641815	et	3	main
ei	doc_491521502243_item	2641816	et	4	main
olnud	doc_491521502243_item	2641817	et	4	main
neil	doc_491521502243_item	2641818	et	4	main
võimalust	doc_491521502243_item	2641819	et	3	main
tagasi	doc_491521502243_item	2641820	et	3	main
ja	doc_491521502243_item	2641822	et	3	main
elasid	doc_491521502243_item	2641826	et	4	main
või	doc_491521502243_item	2641828	et	4	main
majanduse	doc_491521502243_item	2641842	et	4	main
suurepärane	doc_491521502243_item	2641852	et	4	main
raamat	doc_491521502243_item	2641853	et	3	main
ma	doc_491521502243_item	2641857	et	3	main
elu	doc_491521502243_item	2641875	et	4	main
näidatud	doc_491521502243_item	2641885	et	4	main
õpilaste	doc_491521502243_item	2641886	et	4	main
kuidas	doc_491521502243_item	2641888	et	3	main
kõrvuti	doc_491521502243_item	2641890	et	3	main
nende	doc_491521502243_item	2641895	et	4	main
ja	doc_491521502243_item	2641904	et	3	main
iseloome	doc_491521502243_item	2641906	et	4	main
filmis	doc_491521502243_item	2641908	et	4	main
õpetajaga	doc_491521502243_item	2641917	et	4	main
õppeprogrammis	doc_491521502242_item	2641722	et	3	main
vene	doc_491521502242_item	2641724	et	4	main
keele	doc_491521502242_item	2641725	et	4	main
suurendamine	doc_491521502242_item	2641726	et	4	main
d	doc_491521502243_item	2641731	et	4	main
d	doc_491521502243_item	2641736	et	4	main
0cm	doc_491521502243_item	2641740	et	4	main
migratsiooni	doc_491521502243_item	2641745	et	4	main
kas	doc_491521502243_item	2641753	et	3	main
õppevahendiks	doc_491521502243_item	2641759	et	3	main
aastatel	doc_491521502243_item	2641765	et	4	main
paremini	doc_491521502243_item	2641769	et	4	main
seega	doc_491521502243_item	2641771	et	4	main
ka	doc_491521502243_item	2641772	et	3	main
eestis	doc_491521502243_item	2641773	et	3	main
tõusis	doc_491521502243_item	2641775	et	4	main
kaevandus	doc_491521502243_item	2641782	et	4	main
loodusele	doc_491521502243_item	2641789	et	4	main
põllumajandus	doc_491521502243_item	2641790	et	3	main
arenes	doc_491521502243_item	2641791	et	3	main
kiiresti	doc_491521502243_item	2641792	et	3	main
kolhoosid	doc_491521502243_item	2641793	et	3	main
olid	doc_491521502243_item	2641794	et	4	main
seetõttu	doc_491521502243_item	2641823	et	3	main
nsv	doc_491521502243_item	2641830	et	4	main
mõned	doc_491521502243_item	2641832	et	3	main
öelda	doc_491521502243_item	2641848	et	4	main
et	doc_491521502243_item	2641849	et	3	main
see	doc_491521502243_item	2641850	et	3	main
et	doc_491521502243_item	2641859	et	3	main
õpilastel	doc_491521502243_item	2641861	et	4	main
huvitav	doc_491521502243_item	2641864	et	4	main
seda	doc_491521502243_item	2641865	et	3	main
näha	doc_491521502243_item	2641866	et	3	main
ja	doc_491521502243_item	2641867	et	3	main
see	doc_491521502243_item	2641868	et	3	main
sobiks	doc_491521502243_item	2641869	et	4	main
kindlasti	doc_491521502243_item	2641870	et	3	main
õppevahendiks	doc_491521502243_item	2641871	et	3	main
see	doc_491521502243_item	2641872	et	3	main
film	doc_491521502243_item	2641873	et	3	main
näitab	doc_491521502243_item	2641874	et	3	main
elasid	doc_491521502243_item	2641889	et	4	main
on	doc_491521502243_item	2641909	et	4	main
inimlikust	doc_491521502243_item	2641912	et	4	main
mitte	doc_491521502243_item	2641922	et	3	main
õpetaja	doc_491521502243_item	2641925	et	4	main
midagi	doc_491521502243_item	2641928	et	4	main
ta	doc_491521502243_item	2641930	et	4	main
kudias	doc_491521502243_item	2641932	et	4	main
elust	doc_491521502243_item	2641933	et	3	main
oleks	doc_491521502243_item	2641942	et	3	main
aga	doc_491521502243_item	2641958	et	3	main
filmi	doc_491521502243_item	2641961	et	4	main
arvan	doc_491521502243_item	2641970	et	3	main
vanemad	doc_491521502243_item	2641973	et	4	main
inimesed	doc_491521502243_item	2641974	et	3	main
õppida	doc_491521502243_item	2641978	et	3	main
paljud	doc_491521502243_item	2641824	et	3	main
riikides	doc_491521502243_item	2641831	et	3	main
võis	doc_491521502243_item	2641840	et	4	main
aidata	doc_491521502243_item	2641841	et	4	main
on	doc_491521502243_item	2641851	et	4	main
oli	doc_491521502243_item	2641877	et	3	main
sajandi	doc_491521502243_item	2641879	et	3	main
alguses	doc_491521502243_item	2641880	et	4	main
eesti	doc_491521502243_item	2641881	et	4	main
külades	doc_491521502243_item	2641882	et	3	main
seal	doc_491521502243_item	2641883	et	4	main
on	doc_491521502243_item	2641884	et	4	main
eesti	doc_491521502243_item	2641891	et	4	main
ja	doc_491521502243_item	2641892	et	3	main
sea	doc_491521502243_item	2641902	et	4	main
ajastut	doc_491521502243_item	2641903	et	3	main
selle	doc_491521502243_item	2641905	et	4	main
suhted	doc_491521502243_item	2641915	et	3	main
arno	doc_491521502243_item	2641920	et	4	main
kooli	doc_491521502243_item	2641924	et	4	main
see	doc_491521502243_item	2641940	et	3	main
sest	doc_491521502243_item	2641947	et	4	main
paljud	doc_491521502243_item	2641948	et	3	main
põhikoolilapsed	doc_491521502243_item	2641949	et	3	main
aru	doc_491521502243_item	2641955	et	4	main
muidu	doc_491521502243_item	2641959	et	3	main
seda	doc_491521502243_item	2641960	et	3	main
vaadata	doc_491521502243_item	2641964	et	4	main
kõikidele	doc_491521502243_item	2641965	et	4	main
mitte	doc_491521502243_item	2641966	et	3	main
ainult	doc_491521502243_item	2641967	et	4	main
sealt	doc_491521502243_item	2641976	et	4	main
oli	doc_491521502243_item	2641919	et	3	main
jaoks	doc_491521502243_item	2641921	et	4	main
ainult	doc_491521502243_item	2641923	et	4	main
et	doc_491521502243_item	2641939	et	3	main
parem	doc_491521502243_item	2641943	et	4	main
gümnaasiumi	doc_491521502243_item	2641945	et	4	main
õpilastele	doc_491521502243_item	2641946	et	4	main
saa	doc_491521502243_item	2641954	et	4	main
õppusest	doc_491521502243_item	2641957	et	4	main
kasulik	doc_491521502243_item	2641963	et	3	main
et	doc_491521502243_item	2641971	et	3	main
oli	doc_491521502243_item	2641927	et	3	main
õpetas	doc_491521502243_item	2641931	et	3	main
rõõmu	doc_491521502243_item	2641934	et	4	main
tunda	doc_491521502243_item	2641935	et	3	main
kuid	doc_491521502243_item	2641936	et	4	main
ma	doc_491521502243_item	2641937	et	3	main
arvan	doc_491521502243_item	2641938	et	3	main
ei	doc_491521502243_item	2641950	et	4	main
märka	doc_491521502243_item	2641951	et	4	main
ja	doc_491521502243_item	2641952	et	3	main
ei	doc_491521502243_item	2641953	et	4	main
oleks	doc_491521502243_item	2641962	et	3	main
midagi	doc_491521502243_item	2641977	et	4	main
loodushoiu	doc_491521502251_item	2644086	et	3	main
1970ndate	doc_491521502251_item	2644088	et	4	main
erikal	doc_491521502251_item	2644099	et	4	main
põhjendage	doc_491521502251_item	2644106	et	3	main
1970	doc_491521502251_item	2644109	et	2	main
suurenev	doc_491521502251_item	2644114	et	4	main
10000	doc_491521502251_item	2644121	et	2	main
kontrolltöö	doc_491521502251_item	2644082	et	4	main
1	doc_491521502251_item	2644083	et	2	main
eesti	doc_491521502251_item	2644089	et	4	main
või	doc_491521502251_item	2644100	et	4	main
oskaril	doc_491521502251_item	2644101	et	4	main
1	doc_491521502251_item	2644107	et	2	main
vastasseis	doc_491521502251_item	2644087	et	3	main
2	doc_491521502251_item	2644091	et	2	main
on	doc_491521502251_item	2644093	et	4	main
kas	doc_491521502251_item	2644098	et	3	main
armastasin	doc_491521502251_item	2644104	et	3	main
sakslast	doc_491521502251_item	2644105	et	3	main
al	doc_491521502251_item	2644108	et	4	main
ja	doc_491521502251_item	2644085	et	3	main
suuremad	doc_491521502251_item	2644096	et	4	main
identiteediprobleemid	doc_491521502251_item	2644097	et	3	main
tammsaare	doc_491521502251_item	2644102	et	3	main
järjest	doc_491521502251_item	2644113	et	4	main
migrantide	doc_491521502251_item	2644115	et	3	main
lisandus	doc_491521502251_item	2644119	et	4	main
teel	doc_491521502251_item	2644124	et	4	main
eestlastel	doc_491521502251_item	2644127	et	4	main
2500	doc_491521502251_item	2644128	et	2	main
muulastel	doc_491521502251_item	2644129	et	4	main
4000	doc_491521502251_item	2644130	et	2	main
197980	doc_491521502251_item	2644138	et	2	main
on	doc_491521502251_item	2644140	et	4	main
on	doc_491521502251_item	2644146	et	4	main
loodi	doc_491521502251_item	2644153	et	4	main
mis	doc_491521502251_item	2644156	et	4	main
kaevandusse	doc_491521502251_item	2644160	et	4	main
tööle	doc_491521502251_item	2644161	et	3	main
kaevandused	doc_491521502251_item	2644168	et	4	main
järve	doc_491521502251_item	2644172	et	4	main
kujunevad	doc_491521502251_item	2644174	et	4	main
pärast	doc_491521502251_item	2644180	et	4	main
kinnised	doc_491521502251_item	2644187	et	4	main
sissepääs	doc_491521502251_item	2644192	et	3	main
nsvl-s	doc_491521502251_item	2644221	et	3	main
et	doc_491521502251_item	2644230	et	3	main
vett	doc_491521502251_item	2644234	et	3	main
mis	doc_491521502251_item	2644247	et	4	main
teiselt	doc_491521502251_item	2644252	et	4	main
tööd	doc_491521502251_item	2644267	et	4	main
koju	doc_491521502251_item	2644269	et	3	main
uus	doc_491521502251_item	2644296	et	3	main
mõttetuid	doc_491521502251_item	2644300	et	4	main
mulle	doc_491521502251_item	2644308	et	4	main
see	doc_491521502251_item	2644310	et	3	main
armastusest	doc_491521502251_item	2644315	et	4	main
identiteediprobleemid	doc_491521502251_item	2644320	et	3	main
nii	doc_491521502251_item	2644322	et	3	main
erika	doc_491521502251_item	2644347	et	4	main
armastas	doc_491521502251_item	2644348	et	3	main
väga	doc_491521502251_item	2644349	et	3	main
elu	doc_491521502251_item	2644360	et	4	main
on	doc_491521502251_item	2644361	et	4	main
situatsioon	doc_491521502251_item	2644372	et	3	main
majanduse	doc_491521502251_item	2644084	et	4	main
nsv-s	doc_491521502251_item	2644090	et	3	main
kellel	doc_491521502251_item	2644092	et	4	main
teie	doc_491521502251_item	2644094	et	4	main
arvates	doc_491521502251_item	2644095	et	4	main
ma	doc_491521502251_item	2644103	et	3	main
sab	doc_491521502251_item	2644111	et	4	main
iseloomulikuks	doc_491521502251_item	2644112	et	3	main
eestisse	doc_491521502251_item	2644117	et	4	main
aastas	doc_491521502251_item	2644118	et	3	main
see	doc_491521502251_item	2644131	et	3	main
hakkas	doc_491521502251_item	2644132	et	3	main
paratamatult	doc_491521502251_item	2644133	et	4	main
eestlaste	doc_491521502251_item	2644141	et	4	main
64	doc_491521502251_item	2644143	et	2	main
toimunud	doc_491521502251_item	2644150	et	4	main
soojuselektrijaam	doc_491521502251_item	2644155	et	3	main
töölisi	doc_491521502251_item	2644158	et	3	main
ei	doc_491521502251_item	2644162	et	4	main
tahtnud	doc_491521502251_item	2644163	et	4	main
sõda	doc_491521502251_item	2644181	et	4	main
n-ö	doc_491521502251_item	2644186	et	4	main
linnad	doc_491521502251_item	2644188	et	3	main
a-st	doc_491521502251_item	2644110	et	3	main
vool	doc_491521502251_item	2644116	et	4	main
ka	doc_491521502251_item	2644120	et	3	main
inimest	doc_491521502251_item	2644122	et	3	main
mõjutama	doc_491521502251_item	2644134	et	4	main
rahvastiku	doc_491521502251_item	2644136	et	3	main
lääne-	doc_491521502251_item	2644147	et	4	main
ja	doc_491521502251_item	2644148	et	3	main
ida-virumaal	doc_491521502251_item	2644149	et	4	main
narva	doc_491521502251_item	2644169	et	4	main
sillamäe	doc_491521502251_item	2644170	et	3	main
tehakse	doc_491521502251_item	2644178	et	3	main
olid	doc_491521502251_item	2644185	et	4	main
teatud	doc_491521502251_item	2644189	et	4	main
põhielanikel	doc_491521502251_item	2644193	et	3	main
narva	doc_491521502251_item	2644197	et	4	main
pidsi	doc_491521502251_item	2644223	et	4	main
hirm	doc_491521502251_item	2644229	et	3	main
jätku	doc_491521502251_item	2644232	et	4	main
hakkas	doc_491521502251_item	2644235	et	3	main
seda	doc_491521502251_item	2644240	et	3	main
olid	doc_491521502251_item	2644259	et	4	main
justkui	doc_491521502251_item	2644260	et	3	main
see	doc_491521502251_item	2644270	et	3	main
eenstiiliks	doc_491521502251_item	2644272	et	4	main
osteti	doc_491521502251_item	2644298	et	3	main
oli	doc_491521502251_item	2644303	et	3	main
wc	doc_491521502251_item	2644305	et	4	main
2	doc_491521502251_item	2644307	et	2	main
et	doc_491521502251_item	2644319	et	3	main
rohkem	doc_491521502251_item	2644330	et	4	main
mulle	doc_491521502251_item	2644331	et	4	main
tundub	doc_491521502251_item	2644332	et	3	main
et	doc_491521502251_item	2644333	et	3	main
mida	doc_491521502251_item	2644337	et	4	main
tahab	doc_491521502251_item	2644339	et	3	main
aga	doc_491521502251_item	2644341	et	3	main
ära	doc_491521502251_item	2644354	et	4	main
jooksma	doc_491521502251_item	2644355	et	3	main
viimasel	doc_491521502251_item	2644356	et	3	main
hetkel	doc_491521502251_item	2644357	et	4	main
oskar	doc_491521502251_item	2644358	et	4	main
keeldus	doc_491521502251_item	2644359	et	3	main
raske	doc_491521502251_item	2644365	et	4	main
ja	doc_491521502251_item	2644366	et	3	main
niisugune	doc_491521502251_item	2644371	et	3	main
migratsiooni	doc_491521502251_item	2644123	et	4	main
loomulik	doc_491521502251_item	2644125	et	3	main
iive	doc_491521502251_item	2644126	et	3	main
koosseisu	doc_491521502251_item	2644137	et	4	main
osakaal	doc_491521502251_item	2644142	et	3	main
selle	doc_491521502251_item	2644144	et	4	main
põhjuseks	doc_491521502251_item	2644145	et	3	main
protsessid	doc_491521502251_item	2644151	et	4	main
1973	doc_491521502251_item	2644152	et	2	main
aseda	doc_491521502251_item	2644164	et	4	main
laienevad	doc_491521502251_item	2644166	et	4	main
põlevkivi	doc_491521502251_item	2644167	et	4	main
piirkonnad	doc_491521502251_item	2644173	et	4	main
vene	doc_491521502251_item	2644175	et	4	main
keelseteks	doc_491521502251_item	2644176	et	4	main
narva	doc_491521502251_item	2644182	et	4	main
elama	doc_491521502251_item	2644183	et	3	main
asumisel	doc_491521502251_item	2644184	et	4	main
oli	doc_491521502251_item	2644191	et	3	main
pääses	doc_491521502251_item	2644201	et	4	main
erilubadega	doc_491521502251_item	2644202	et	3	main
niisama	doc_491521502251_item	2644203	et	3	main
ei	doc_491521502251_item	2644204	et	4	main
saanud	doc_491521502251_item	2644205	et	4	main
sinna	doc_491521502251_item	2644206	et	3	main
keegi	doc_491521502251_item	2644207	et	4	main
küllakutse	doc_491521502251_item	2644208	et	4	main
vms	doc_491521502251_item	2644209	et	4	main
pidi	doc_491521502251_item	2644210	et	4	main
olema	doc_491521502251_item	2644211	et	4	main
ruhnu	doc_491521502251_item	2644212	et	4	main
ei	doc_491521502251_item	2644213	et	4	main
saanud	doc_491521502251_item	2644214	et	4	main
üldse	doc_491521502251_item	2644215	et	3	main
1974	doc_491521502251_item	2644216	et	2	main
mood	doc_491521502251_item	2644217	et	3	main
lahemaa	doc_491521502251_item	2644218	et	4	main
rahvuspark	doc_491521502251_item	2644219	et	3	main
esimene	doc_491521502251_item	2644220	et	3	main
tekkis	doc_491521502251_item	2644228	et	3	main
nappima	doc_491521502251_item	2644236	et	3	main
ja	doc_491521502251_item	2644238	et	3	main
hakati	doc_491521502251_item	2644241	et	3	main
mõtlematult	doc_491521502251_item	2644243	et	4	main
mõned	doc_491521502251_item	2644245	et	3	main
olid	doc_491521502251_item	2644249	et	4	main
riigid	doc_491521502251_item	2644262	et	3	main
sai	doc_491521502251_item	2644263	et	4	main
näppamine	doc_491521502251_item	2644266	et	4	main
toodi	doc_491521502251_item	2644268	et	4	main
paberit	doc_491521502251_item	2644306	et	3	main
romaan	doc_491521502251_item	2644311	et	3	main
see	doc_491521502251_item	2644313	et	3	main
mulle	doc_491521502251_item	2644317	et	4	main
siinset	doc_491521502251_item	2644135	et	3	main
a-ks	doc_491521502251_item	2644139	et	3	main
balit	doc_491521502251_item	2644154	et	4	main
vajad	doc_491521502251_item	2644157	et	4	main
eestlane	doc_491521502251_item	2644159	et	3	main
kohtla-järvel	doc_491521502251_item	2644165	et	4	main
kohtla	doc_491521502251_item	2644171	et	4	main
eestlastele	doc_491521502251_item	2644177	et	4	main
takistusi	doc_491521502251_item	2644179	et	4	main
linnadesse	doc_491521502251_item	2644190	et	3	main
keelatud	doc_491521502251_item	2644194	et	4	main
nt	doc_491521502251_item	2644195	et	4	main
sillamäe	doc_491521502251_item	2644196	et	3	main
paldiski	doc_491521502251_item	2644198	et	4	main
loksa	doc_491521502251_item	2644199	et	4	main
saartele	doc_491521502251_item	2644200	et	3	main
kruusa	doc_491521502251_item	2644237	et	4	main
liiva	doc_491521502251_item	2644239	et	4	main
kaevandama	doc_491521502251_item	2644242	et	3	main
eestlastele	doc_491521502251_item	2644248	et	4	main
pühad	doc_491521502251_item	2644251	et	3	main
poolt	doc_491521502251_item	2644253	et	4	main
tehti	doc_491521502251_item	2644254	et	3	main
eestis	doc_491521502251_item	2644255	et	3	main
näidismajandeid	doc_491521502251_item	2644256	et	3	main
ettevõtteid	doc_491521502251_item	2644257	et	3	main
mis	doc_491521502251_item	2644258	et	4	main
kombeks	doc_491521502251_item	2644264	et	4	main
riigilt	doc_491521502251_item	2644265	et	3	main
tuleb	doc_491521502251_item	2644295	et	3	main
palju	doc_491521502251_item	2644299	et	4	main
asju	doc_491521502251_item	2644301	et	3	main
väga	doc_491521502251_item	2644312	et	3	main
tundub	doc_491521502251_item	2644318	et	3	main
erikal	doc_491521502251_item	2644323	et	4	main
kui	doc_491521502251_item	2644324	et	3	main
ka	doc_491521502251_item	2644325	et	3	main
oskaril	doc_491521502251_item	2644326	et	4	main
oskaril	doc_491521502251_item	2644329	et	4	main
teadnud	doc_491521502251_item	2644336	et	4	main
nad	doc_491521502251_item	2644352	et	3	main
meie	doc_491521502251_item	2644367	et	4	main
ajal	doc_491521502251_item	2644368	et	4	main
loodust	doc_491521502251_item	2644222	et	4	main
kaitsma	doc_491521502251_item	2644224	et	3	main
hakkama	doc_491521502251_item	2644225	et	3	main
päästma	doc_491521502251_item	2644226	et	3	main
hävinemisest	doc_491521502251_item	2644227	et	4	main
ei	doc_491521502251_item	2644231	et	4	main
puhast	doc_491521502251_item	2644233	et	3	main
hävinesid	doc_491521502251_item	2644244	et	4	main
allikakopad	doc_491521502251_item	2644246	et	3	main
ajalooliselt	doc_491521502251_item	2644250	et	4	main
väikseid	doc_491521502251_item	2644261	et	4	main
kujunes	doc_491521502251_item	2644271	et	3	main
uueks	doc_491521502251_item	2644273	et	3	main
fenomeniks	doc_491521502251_item	2644274	et	3	main
sai	doc_491521502251_item	2644275	et	4	main
letialune	doc_491521502251_item	2644276	et	4	main
kaubandus	doc_491521502251_item	2644277	et	3	main
vähe	doc_491521502251_item	2644278	et	3	main
saada	doc_491521502251_item	2644279	et	4	main
olevat	doc_491521502251_item	2644280	et	4	main
kaupa	doc_491521502251_item	2644281	et	4	main
sai	doc_491521502251_item	2644282	et	4	main
teistega	doc_491521502251_item	2644283	et	4	main
vahetada	doc_491521502251_item	2644284	et	3	main
müüjatel	doc_491521502251_item	2644285	et	4	main
oli	doc_491521502251_item	2644286	et	3	main
arvastatav	doc_491521502251_item	2644287	et	4	main
positsioon	doc_491521502251_item	2644288	et	3	main
ühiskonna	doc_491521502251_item	2644289	et	4	main
kunagi	doc_491521502251_item	2644290	et	3	main
ei	doc_491521502251_item	2644291	et	4	main
võinud	doc_491521502251_item	2644292	et	4	main
teada	doc_491521502251_item	2644293	et	3	main
millal	doc_491521502251_item	2644294	et	3	main
kaup	doc_491521502251_item	2644297	et	3	main
delikatess	doc_491521502251_item	2644302	et	3	main
heeringas	doc_491521502251_item	2644304	et	4	main
meeldis	doc_491521502251_item	2644309	et	3	main
on	doc_491521502251_item	2644314	et	4	main
film	doc_491521502251_item	2644316	et	3	main
on	doc_491521502251_item	2644321	et	4	main
võib	doc_491521502251_item	2644327	et	3	main
olla	doc_491521502251_item	2644328	et	3	main
ta	doc_491521502251_item	2644334	et	4	main
oskarit	doc_491521502251_item	2644350	et	4	main
ja	doc_491521502251_item	2644351	et	3	main
tahtsid	doc_491521502251_item	2644353	et	4	main
meie	doc_491521502251_item	2644362	et	4	main
võib	doc_491521502251_item	2644369	et	3	main
ei	doc_491521502251_item	2644335	et	4	main
ta	doc_491521502251_item	2644338	et	4	main
elust	doc_491521502251_item	2644340	et	3	main
erika	doc_491521502251_item	2644342	et	4	main
tahtis	doc_491521502251_item	2644343	et	3	main
ainult	doc_491521502251_item	2644344	et	4	main
abielluda	doc_491521502251_item	2644345	et	3	main
temaga	doc_491521502251_item	2644346	et	3	main
ajal	doc_491521502251_item	2644363	et	4	main
ka	doc_491521502251_item	2644364	et	3	main
juhtuda	doc_491521502251_item	2644370	et	3	main
majanduse	doc_491521502253_item	2644845	et	4	main
ja	doc_491521502253_item	2644846	et	3	main
loodushoiu	doc_491521502253_item	2644847	et	3	main
vastasseis	doc_491521502253_item	2644848	et	3	main
teie	doc_491521502253_item	2644855	et	4	main
oskaril	doc_491521502253_item	2644862	et	4	main
tammsaare	doc_491521502253_item	2644863	et	3	main
ma	doc_491521502253_item	2644864	et	3	main
armastasin	doc_491521502253_item	2644865	et	3	main
sellele	doc_491521502253_item	2644894	et	4	main
looduse	doc_491521502253_item	2644902	et	4	main
jäätma	doc_491521502253_item	2644913	et	4	main
nimetatakse	doc_491521502253_item	2644917	et	3	main
oleku	doc_491521502253_item	2644922	et	3	main
nimetatakse	doc_491521502253_item	2644926	et	3	main
tol	doc_491521502253_item	2644933	et	3	main
eestile	doc_491521502253_item	2644944	et	3	main
ekstensiivne	doc_491521502253_item	2644946	et	3	main
1970ndate	doc_491521502253_item	2644849	et	4	main
arvates	doc_491521502253_item	2644856	et	4	main
sakslast	doc_491521502253_item	2644866	et	3	main
ajaloo	doc_491521502253_item	2644895	et	4	main
saastamine	doc_491521502253_item	2644903	et	4	main
aga	doc_491521502253_item	2644905	et	3	main
kui	doc_491521502253_item	2644914	et	3	main
sulaks	doc_491521502253_item	2644918	et	4	main
eesti	doc_491521502253_item	2644850	et	4	main
nsv-s	doc_491521502253_item	2644851	et	3	main
suuremad	doc_491521502253_item	2644857	et	4	main
põhjendage	doc_491521502253_item	2644867	et	3	main
gigantproektid	doc_491521502253_item	2644893	et	4	main
sest	doc_491521502253_item	2644908	et	4	main
eesti	doc_491521502253_item	2644932	et	4	main
oli	doc_491521502253_item	2644935	et	3	main
oli	doc_491521502253_item	2644941	et	3	main
ja	doc_491521502253_item	2644948	et	3	main
raiskav	doc_491521502253_item	2644950	et	4	main
siinsetel	doc_491521502253_item	2644952	et	4	main
endaga	doc_491521502253_item	2644955	et	4	main
armee	doc_491521502253_item	2644969	et	4	main
eriti	doc_491521502253_item	2645008	et	3	main
näiteks	doc_491521502253_item	2645032	et	4	main
pärlijõe	doc_491521502253_item	2645033	et	3	main
karbid	doc_491521502253_item	2645034	et	3	main
aga	doc_491521502253_item	2645035	et	3	main
suuremad	doc_491521502253_item	2645040	et	4	main
hakati	doc_491521502253_item	2645043	et	3	main
puudu	doc_491521502253_item	2645046	et	4	main
ka	doc_491521502253_item	2645051	et	3	main
see	doc_491521502253_item	2645054	et	3	main
ka	doc_491521502253_item	2645088	et	3	main
jäänuste	doc_491521502253_item	2645090	et	3	main
kasutati	doc_491521502253_item	2645092	et	4	main
mitte	doc_491521502253_item	2645098	et	3	main
kui	doc_491521502253_item	2645103	et	3	main
tähtis	doc_491521502253_item	2645104	et	4	main
on	doc_491521502253_item	2645105	et	4	main
looduse	doc_491521502253_item	2645106	et	4	main
puhkus	doc_491521502253_item	2645107	et	3	main
ka	doc_491521502253_item	2645114	et	3	main
tsensuur	doc_491521502253_item	2645119	et	3	main
neid	doc_491521502253_item	2645120	et	4	main
desidentmõtlemisega	doc_491521502253_item	2645123	et	4	main
öelda	doc_491521502253_item	2645130	et	4	main
aastate	doc_491521502253_item	2645134	et	3	main
ja	doc_491521502253_item	2645137	et	3	main
majanduse	doc_491521502253_item	2645138	et	4	main
oli	doc_491521502253_item	2645140	et	3	main
2	doc_491521502253_item	2645143	et	2	main
armastasin	doc_491521502253_item	2645145	et	3	main
olen	doc_491521502253_item	2645155	et	3	main
läbi	doc_491521502253_item	2645168	et	4	main
vaadanud	doc_491521502253_item	2645169	et	4	main
siin	doc_491521502253_item	2645173	et	4	main
ülikoolis	doc_491521502253_item	2645174	et	4	main
armastuslugu	doc_491521502253_item	2645185	et	4	main
käsitlev	doc_491521502253_item	2645186	et	4	main
filosoofiline	doc_491521502253_item	2645190	et	4	main
kohe	doc_491521502253_item	2645195	et	4	main
2	doc_491521502253_item	2644852	et	2	main
kellel	doc_491521502253_item	2644853	et	4	main
identiteediprobleemid	doc_491521502253_item	2644858	et	3	main
kas	doc_491521502253_item	2644859	et	3	main
erikal	doc_491521502253_item	2644860	et	4	main
1	doc_491521502253_item	2644868	et	2	main
raiskamine	doc_491521502253_item	2644901	et	4	main
varsti	doc_491521502253_item	2644904	et	3	main
hruštšovi	doc_491521502253_item	2644915	et	2	main
siis	doc_491521502253_item	2644919	et	3	main
breznevi	doc_491521502253_item	2644920	et	4	main
riigi	doc_491521502253_item	2644924	et	3	main
iseloomustades	doc_491521502253_item	2644925	et	3	main
koosseisus	doc_491521502253_item	2644938	et	4	main
see	doc_491521502253_item	2644939	et	3	main
eesti	doc_491521502253_item	2644957	et	4	main
halvenemise	doc_491521502253_item	2644960	et	4	main
ajal	doc_491521502253_item	2644962	et	4	main
oeamiseks	doc_491521502253_item	2644964	et	4	main
tööstusrajooniks	doc_491521502253_item	2644974	et	3	main
taseme	doc_491521502253_item	2645002	et	3	main
rahvusvahelise	doc_491521502253_item	2645004	et	4	main
loodushoiust	doc_491521502253_item	2645007	et	4	main
tõttu	doc_491521502253_item	2645031	et	4	main
kaldest	doc_491521502253_item	2645049	et	4	main
maavaradest	doc_491521502253_item	2645052	et	3	main
aga	doc_491521502253_item	2645053	et	3	main
inimestel	doc_491521502253_item	2645079	et	3	main
ja	doc_491521502253_item	2645084	et	3	main
endiselt	doc_491521502253_item	2645093	et	4	main
õhku	doc_491521502253_item	2645097	et	4	main
said	doc_491521502253_item	2645100	et	4	main
aru	doc_491521502253_item	2645101	et	4	main
ringis	doc_491521502253_item	2645110	et	4	main
oli	doc_491521502253_item	2645117	et	3	main
kontrolltöö	doc_491521502253_item	2644843	et	4	main
1	doc_491521502253_item	2644844	et	2	main
on	doc_491521502253_item	2644854	et	4	main
või	doc_491521502253_item	2644861	et	4	main
1970	doc_491521502253_item	2644869	et	2	main
aas	doc_491521502253_item	2644870	et	3	main
tatel	doc_491521502253_item	2644871	et	3	main
nsvl	doc_491521502253_item	2644872	et	4	main
peaks	doc_491521502253_item	2644873	et	4	main
oli	doc_491521502253_item	2644874	et	3	main
breznev	doc_491521502253_item	2644875	et	4	main
majanduselu	doc_491521502253_item	2644876	et	4	main
oli	doc_491521502253_item	2644877	et	3	main
plaani	doc_491521502253_item	2644878	et	4	main
järgi	doc_491521502253_item	2644879	et	4	main
käsumajandus	doc_491521502253_item	2644880	et	3	main
riigis	doc_491521502253_item	2644881	et	3	main
oli	doc_491521502253_item	2644882	et	3	main
büroklaatlik	doc_491521502253_item	2644883	et	4	main
juhtimine	doc_491521502253_item	2644884	et	4	main
priviligeerituks	doc_491521502253_item	2644885	et	4	main
majandusharuks	doc_491521502253_item	2644886	et	3	main
oli	doc_491521502253_item	2644887	et	3	main
sõjatööstus	doc_491521502253_item	2644888	et	3	main
majandus	doc_491521502253_item	2644889	et	4	main
arenes	doc_491521502253_item	2644890	et	3	main
ekstensiivselt	doc_491521502253_item	2644891	et	4	main
põhjendamatud	doc_491521502253_item	2644892	et	4	main
perioodile	doc_491521502253_item	2644896	et	3	main
nsvl-u	doc_491521502253_item	2644897	et	4	main
ajaloos	doc_491521502253_item	2644898	et	4	main
iseloomulik	doc_491521502253_item	2644899	et	3	main
loodusressursside	doc_491521502253_item	2644900	et	3	main
majanduse	doc_491521502253_item	2644906	et	4	main
allakäik	doc_491521502253_item	2644907	et	3	main
nsvl	doc_491521502253_item	2644909	et	4	main
hakkas	doc_491521502253_item	2644910	et	3	main
lääneriikidest	doc_491521502253_item	2644911	et	3	main
maha	doc_491521502253_item	2644912	et	4	main
valitsemisajajärku	doc_491521502253_item	2644916	et	4	main
võimul	doc_491521502253_item	2644921	et	3	main
aega	doc_491521502253_item	2644923	et	4	main
stagnatsiooniks	doc_491521502253_item	2644927	et	3	main
ja	doc_491521502253_item	2644930	et	3	main
ajal	doc_491521502253_item	2644934	et	4	main
veel	doc_491521502253_item	2644936	et	4	main
kõik	doc_491521502253_item	2644940	et	4	main
ka	doc_491521502253_item	2644943	et	3	main
tõi	doc_491521502253_item	2644954	et	3	main
olukorra	doc_491521502253_item	2644959	et	3	main
tol	doc_491521502253_item	2644961	et	3	main
üheks	doc_491521502253_item	2644963	et	3	main
nõukogude	doc_491521502253_item	2644968	et	3	main
oma	doc_491521502253_item	2644970	et	4	main
eestis	doc_491521502253_item	2644972	et	3	main
poliitikas	doc_491521502253_item	2644998	et	3	main
ja	doc_491521502253_item	2645006	et	3	main
mõeldud	doc_491521502253_item	2645010	et	4	main
aga	doc_491521502253_item	2645011	et	3	main
sel	doc_491521502253_item	2645012	et	3	main
ajal	doc_491521502253_item	2645013	et	4	main
olukord	doc_491521502253_item	2645014	et	3	main
halvenes	doc_491521502253_item	2645015	et	3	main
ja	doc_491521502253_item	2645016	et	3	main
halvenes	doc_491521502253_item	2645017	et	3	main
eestis	doc_491521502253_item	2645018	et	3	main
isegi	doc_491521502253_item	2645019	et	4	main
oli	doc_491521502253_item	2645020	et	3	main
e	doc_491521502253_item	2644928	et	4	main
seisakuks	doc_491521502253_item	2644929	et	3	main
kuna	doc_491521502253_item	2644931	et	3	main
nsvl	doc_491521502253_item	2644937	et	4	main
iseloomulik	doc_491521502253_item	2644942	et	3	main
majanduse	doc_491521502253_item	2644945	et	4	main
areng	doc_491521502253_item	2644947	et	3	main
loodusvaresid	doc_491521502253_item	2644949	et	3	main
areng	doc_491521502253_item	2644951	et	3	main
aladel	doc_491521502253_item	2644953	et	3	main
ökoloogilise	doc_491521502253_item	2644958	et	4	main
reostajaks	doc_491521502253_item	2644966	et	4	main
oli	doc_491521502253_item	2644975	et	3	main
ida-virumaa	doc_491521502253_item	2644976	et	4	main
seal	doc_491521502253_item	2644977	et	4	main
oli	doc_491521502253_item	2644978	et	3	main
palju	doc_491521502253_item	2644979	et	4	main
tehaseid	doc_491521502253_item	2644980	et	3	main
mis	doc_491521502253_item	2644981	et	4	main
tootsid	doc_491521502253_item	2644982	et	4	main
igasuguseid	doc_491521502253_item	2644983	et	3	main
asju	doc_491521502253_item	2644984	et	3	main
näiteks	doc_491521502253_item	2644985	et	4	main
mingisuguseid	doc_491521502253_item	2644986	et	3	main
detailid	doc_491521502253_item	2644987	et	3	main
relvade	doc_491521502253_item	2644988	et	3	main
jaoks	doc_491521502253_item	2644989	et	4	main
või	doc_491521502253_item	2644990	et	4	main
keemitehased	doc_491521502253_item	2644991	et	4	main
mis	doc_491521502253_item	2644992	et	4	main
tootsid	doc_491521502253_item	2644993	et	4	main
keemilisi	doc_491521502253_item	2644994	et	4	main
tooteid	doc_491521502253_item	2644995	et	4	main
peamine	doc_491521502253_item	2644996	et	3	main
asi	doc_491521502253_item	2644997	et	4	main
kaasa	doc_491521502253_item	2644956	et	4	main
looduse	doc_491521502253_item	2644965	et	4	main
oli	doc_491521502253_item	2644967	et	3	main
sõjaväebaasidega	doc_491521502253_item	2644971	et	3	main
peamiseks	doc_491521502253_item	2644973	et	3	main
saavutada	doc_491521502253_item	2645000	et	3	main
ei	doc_491521502253_item	2645009	et	4	main
loomaliigid	doc_491521502253_item	2645026	et	3	main
surid	doc_491521502253_item	2645027	et	4	main
kunagi	doc_491521502253_item	2645036	et	3	main
pärlid	doc_491521502253_item	2645041	et	3	main
oli	doc_491521502253_item	2645080	et	3	main
natuke	doc_491521502253_item	2645082	et	4	main
mida	doc_491521502253_item	2645086	et	4	main
jaoks	doc_491521502253_item	2645091	et	4	main
järved	doc_491521502253_item	2645096	et	3	main
see	doc_491521502253_item	2645111	et	3	main
sellepärast	doc_491521502253_item	2645115	et	3	main
oli	doc_491521502253_item	2645122	et	3	main
et	doc_491521502253_item	2645131	et	3	main
päris	doc_491521502253_item	2645141	et	4	main
ma	doc_491521502253_item	2645144	et	3	main
sakslast	doc_491521502253_item	2645146	et	3	main
üks	doc_491521502253_item	2645148	et	3	main
mina	doc_491521502253_item	2645154	et	4	main
tõde	doc_491521502253_item	2645157	et	4	main
õigus	doc_491521502253_item	2645159	et	4	main
elu	doc_491521502253_item	2645160	et	4	main
ja	doc_491521502253_item	2645161	et	3	main
põrgupõhja	doc_491521502253_item	2645170	et	4	main
oskari	doc_491521502253_item	2645184	et	4	main
on	doc_491521502253_item	2645188	et	4	main
teoses	doc_491521502253_item	2645194	et	3	main
mitu	doc_491521502253_item	2645196	et	4	main
vahekorda	doc_491521502253_item	2645200	et	4	main
ühiskonna	doc_491521502253_item	2645201	et	4	main
kihtide	doc_491521502253_item	2645203	et	3	main
identiteedi	doc_491521502253_item	2645210	et	4	main
minu	doc_491521502253_item	2645212	et	3	main
meelest	doc_491521502253_item	2645213	et	4	main
sellepärast	doc_491521502253_item	2645222	et	3	main
mitte	doc_491521502253_item	2645230	et	3	main
palju	doc_491521502253_item	2645232	et	4	main
ja	doc_491521502253_item	2645235	et	3	main
poolest	doc_491521502253_item	2645241	et	4	main
kõla	doc_491521502253_item	2645253	et	4	main
mees	doc_491521502253_item	2645275	et	4	main
armastusest	doc_491521502253_item	2645281	et	4	main
kui	doc_491521502253_item	2645282	et	3	main
mehed	doc_491521502253_item	2645283	et	3	main
ja	doc_491521502253_item	2645284	et	3	main
veel	doc_491521502253_item	2645285	et	4	main
sellepärast	doc_491521502253_item	2645286	et	3	main
et	doc_491521502253_item	2645287	et	3	main
tammsaarel	doc_491521502253_item	2645288	et	3	main
väga	doc_491521502253_item	2645290	et	3	main
suhtumisest	doc_491521502253_item	2645300	et	4	main
aga	doc_491521502253_item	2645301	et	3	main
oskar	doc_491521502253_item	2645302	et	4	main
juba	doc_491521502253_item	2645310	et	3	main
lapsepõlvest	doc_491521502253_item	2645311	et	4	main
mida	doc_491521502253_item	2645314	et	4	main
võib	doc_491521502253_item	2645316	et	3	main
daamile	doc_491521502253_item	2645319	et	3	main
pakkuda	doc_491521502253_item	2645320	et	3	main
peale	doc_491521502253_item	2645321	et	4	main
armastust	doc_491521502253_item	2645323	et	4	main
ta	doc_491521502253_item	2645324	et	4	main
mõttes	doc_491521502253_item	2645329	et	3	main
ta	doc_491521502253_item	2645330	et	4	main
ta	doc_491521502253_item	2645332	et	4	main
filmis	doc_491521502253_item	2645339	et	4	main
et	doc_491521502253_item	2645342	et	3	main
ta	doc_491521502253_item	2645343	et	4	main
lapsepõlve	doc_491521502253_item	2645348	et	4	main
siiski	doc_491521502253_item	2645362	et	4	main
elab	doc_491521502253_item	2645363	et	3	main
siiski	doc_491521502253_item	2645372	et	4	main
kas	doc_491521502254_item	2645403	et	3	main
erikal	doc_491521502254_item	2645404	et	4	main
või	doc_491521502254_item	2645405	et	4	main
põhjendage	doc_491521502254_item	2645411	et	3	main
oli	doc_491521502253_item	2644999	et	3	main
kõrge	doc_491521502253_item	2645001	et	4	main
ja	doc_491521502253_item	2645003	et	3	main
tunnistuse	doc_491521502253_item	2645005	et	4	main
oht	doc_491521502253_item	2645021	et	3	main
joogiveeta	doc_491521502253_item	2645024	et	3	main
välja	doc_491521502253_item	2645028	et	4	main
inimeste	doc_491521502253_item	2645029	et	3	main
ükskõiksuse	doc_491521502253_item	2645030	et	4	main
kõige	doc_491521502253_item	2645039	et	4	main
tundma	doc_491521502253_item	2645045	et	3	main
mõnedest	doc_491521502253_item	2645047	et	3	main
taimeliikidest	doc_491521502253_item	2645048	et	3	main
aga	doc_491521502253_item	2645050	et	3	main
küll	doc_491521502253_item	2645055	et	4	main
polnud	doc_491521502253_item	2645056	et	3	main
kõikjal	doc_491521502253_item	2645057	et	3	main
vaid	doc_491521502253_item	2645058	et	3	main
mõnedes	doc_491521502253_item	2645059	et	3	main
piirkondades	doc_491521502253_item	2645060	et	3	main
kuid	doc_491521502253_item	2645061	et	4	main
maailmavaade	doc_491521502253_item	2645078	et	3	main
ka	doc_491521502253_item	2645081	et	3	main
teine	doc_491521502253_item	2645083	et	3	main
väärtused	doc_491521502253_item	2645085	et	3	main
tehaste	doc_491521502253_item	2645089	et	3	main
vett	doc_491521502253_item	2645094	et	3	main
kõik	doc_491521502253_item	2645099	et	4	main
meie	doc_491521502253_item	2645108	et	4	main
võis	doc_491521502253_item	2645112	et	4	main
range	doc_491521502253_item	2645118	et	4	main
kes	doc_491521502253_item	2645121	et	4	main
kuskile	doc_491521502253_item	2645126	et	4	main
võib	doc_491521502253_item	2645129	et	3	main
vastasseis	doc_491521502253_item	2645135	et	3	main
tugev	doc_491521502253_item	2645142	et	4	main
on	doc_491521502253_item	2645147	et	4	main
lugenud	doc_491521502253_item	2645156	et	4	main
ja	doc_491521502253_item	2645158	et	3	main
teosedki	doc_491521502253_item	2645181	et	3	main
erika	doc_491521502253_item	2645182	et	4	main
ja	doc_491521502253_item	2645183	et	3	main
tammsaare	doc_491521502253_item	2645191	et	3	main
armastava	doc_491521502253_item	2645198	et	4	main
erinevatge	doc_491521502253_item	2645202	et	4	main
erinevate	doc_491521502253_item	2645205	et	4	main
kandjate	doc_491521502253_item	2645207	et	4	main
suuremad	doc_491521502253_item	2645217	et	4	main
jääda	doc_491521502253_item	2645022	et	4	main
ilma	doc_491521502253_item	2645023	et	4	main
mõned	doc_491521502253_item	2645025	et	3	main
seal	doc_491521502253_item	2645037	et	4	main
oli	doc_491521502253_item	2645038	et	3	main
baltikumis	doc_491521502253_item	2645042	et	4	main
rohkem	doc_491521502253_item	2645044	et	4	main
juba	doc_491521502253_item	2645062	et	3	main
see	doc_491521502253_item	2645063	et	3	main
oli	doc_491521502253_item	2645064	et	3	main
valitsuse	doc_491521502253_item	2645065	et	4	main
tähelepanuväärne	doc_491521502253_item	2645066	et	3	main
seetõttu	doc_491521502253_item	2645067	et	3	main
et	doc_491521502253_item	2645068	et	3	main
tol	doc_491521502253_item	2645069	et	3	main
valitsemiskorral	doc_491521502253_item	2645070	et	3	main
peamine	doc_491521502253_item	2645071	et	3	main
oli	doc_491521502253_item	2645072	et	3	main
mitte	doc_491521502253_item	2645073	et	3	main
isik	doc_491521502253_item	2645074	et	3	main
vaid	doc_491521502253_item	2645075	et	3	main
ainult	doc_491521502253_item	2645076	et	4	main
riik	doc_491521502253_item	2645077	et	3	main
hinnati	doc_491521502253_item	2645087	et	3	main
jõed	doc_491521502253_item	2645095	et	3	main
sellest	doc_491521502253_item	2645102	et	4	main
elu	doc_491521502253_item	2645109	et	4	main
olla	doc_491521502253_item	2645113	et	3	main
et	doc_491521502253_item	2645116	et	3	main
kõrvaldati	doc_491521502253_item	2645124	et	3	main
70	doc_491521502253_item	2645132	et	2	main
loodushoiu	doc_491521502253_item	2645136	et	3	main
vanapagan	doc_491521502253_item	2645171	et	3	main
ma	doc_491521502253_item	2645175	et	3	main
armastasin	doc_491521502253_item	2645176	et	3	main
sakslast	doc_491521502253_item	2645177	et	3	main
nagu	doc_491521502253_item	2645178	et	3	main
väga	doc_491521502253_item	2645189	et	3	main
ühes	doc_491521502253_item	2645193	et	4	main
inimeste	doc_491521502253_item	2645199	et	3	main
vahekorda	doc_491521502253_item	2645208	et	4	main
probleemi	doc_491521502253_item	2645211	et	4	main
noormehel	doc_491521502253_item	2645214	et	3	main
erikal	doc_491521502253_item	2645220	et	4	main
armastas	doc_491521502253_item	2645225	et	3	main
nagu	doc_491521502253_item	2645233	et	3	main
ikkagi	doc_491521502253_item	2645238	et	4	main
sest	doc_491521502253_item	2645276	et	4	main
mõttekäigust	doc_491521502253_item	2645295	et	3	main
ei	doc_491521502253_item	2645325	et	4	main
on	doc_491521502253_item	2645333	et	4	main
enese	doc_491521502253_item	2645334	et	4	main
kunstiinimesed	doc_491521502253_item	2645338	et	3	main
on	doc_491521502253_item	2645340	et	4	main
kogu	doc_491521502253_item	2645344	et	4	main
aeg	doc_491521502253_item	2645345	et	3	main
ja	doc_491521502253_item	2645352	et	3	main
nende	doc_491521502253_item	2645355	et	4	main
kodumaal	doc_491521502253_item	2645365	et	4	main
on	doc_491521502253_item	2645368	et	4	main
nendes	doc_491521502253_item	2645375	et	4	main
suhetes	doc_491521502253_item	2645376	et	3	main
ma	doc_491521502254_item	2645408	et	3	main
vajas	doc_491521502254_item	2645419	et	4	main
narva	doc_491521502254_item	2645430	et	4	main
pärast	doc_491521502254_item	2645440	et	4	main
sõda	doc_491521502254_item	2645441	et	4	main
sissepääs	doc_491521502254_item	2645458	et	3	main
nt	doc_491521502254_item	2645459	et	4	main
põliselanikkel	doc_491521502254_item	2645460	et	4	main
lahemaa	doc_491521502254_item	2645472	et	4	main
rahvus	doc_491521502254_item	2645473	et	3	main
park	doc_491521502254_item	2645474	et	3	main
sellele	doc_491521502254_item	2645482	et	4	main
et	doc_491521502254_item	2645483	et	3	main
eestlaste	doc_491521502254_item	2645487	et	4	main
paigad	doc_491521502254_item	2645489	et	3	main
lõhuti	doc_491521502254_item	2645497	et	3	main
mägesid	doc_491521502254_item	2645499	et	3	main
pääsenud	doc_491521502254_item	2645521	et	4	main
ainult	doc_491521502254_item	2645523	et	4	main
pidi	doc_491521502254_item	2645532	et	4	main
ei	doc_491521502254_item	2645547	et	4	main
a	doc_491521502254_item	2645552	et	4	main
tõlgitud	doc_491521502254_item	2645556	et	4	main
eestlastele	doc_491521502254_item	2645577	et	4	main
ära	doc_491521502254_item	2645587	et	4	main
ettevõtteid	doc_491521502254_item	2645593	et	3	main
just	doc_491521502254_item	2645596	et	3	main
sai	doc_491521502254_item	2645600	et	4	main
näppamine	doc_491521502254_item	2645603	et	4	main
riigist	doc_491521502254_item	2645621	et	3	main
nt	doc_491521502254_item	2645625	et	4	main
paber	doc_491521502254_item	2645627	et	3	main
kui	doc_491521502254_item	2645628	et	3	main
kuskilt	doc_491521502254_item	2645629	et	4	main
kohe	doc_491521502254_item	2645633	et	4	main
ja	doc_491521502254_item	2645637	et	3	main
ära	doc_491521502254_item	2645639	et	4	main
tegelikult	doc_491521502254_item	2645640	et	4	main
aga	doc_491521502254_item	2645647	et	3	main
äkki	doc_491521502254_item	2645648	et	3	main
kunagi	doc_491521502254_item	2645649	et	3	main
läheb	doc_491521502254_item	2645650	et	3	main
vaja	doc_491521502254_item	2645651	et	4	main
ühiskonnast	doc_491521502253_item	2645125	et	4	main
ääremaadele	doc_491521502253_item	2645127	et	4	main
kokkuvõtteks	doc_491521502253_item	2645128	et	3	main
ndate	doc_491521502253_item	2645133	et	4	main
vahel	doc_491521502253_item	2645139	et	4	main
tammsaare	doc_491521502253_item	2645149	et	3	main
romaanidest	doc_491521502253_item	2645150	et	3	main
mis	doc_491521502253_item	2645151	et	4	main
on	doc_491521502253_item	2645152	et	4	main
filmistatud	doc_491521502253_item	2645153	et	4	main
armastus	doc_491521502253_item	2645162	et	4	main
ning	doc_491521502253_item	2645163	et	3	main
kõrbeoja	doc_491521502253_item	2645164	et	4	main
peremees	doc_491521502253_item	2645165	et	4	main
ning	doc_491521502253_item	2645166	et	3	main
olen	doc_491521502253_item	2645167	et	3	main
ning	doc_491521502253_item	2645172	et	3	main
kõik	doc_491521502253_item	2645179	et	4	main
tema	doc_491521502253_item	2645180	et	4	main
romaad	doc_491521502253_item	2645187	et	4	main
puudutab	doc_491521502253_item	2645192	et	3	main
oli	doc_491521502253_item	2645215	et	3	main
identiteediga	doc_491521502253_item	2645216	et	4	main
probleemid	doc_491521502253_item	2645218	et	3	main
inimest	doc_491521502253_item	2645226	et	3	main
erines	doc_491521502253_item	2645228	et	3	main
nii	doc_491521502253_item	2645231	et	3	main
eestlased	doc_491521502253_item	2645234	et	3	main
temast	doc_491521502253_item	2645239	et	3	main
kultuuri	doc_491521502253_item	2645240	et	4	main
oskar	doc_491521502253_item	2645242	et	4	main
armastas	doc_491521502253_item	2645243	et	3	main
sakslast	doc_491521502253_item	2645244	et	3	main
pealkiri	doc_491521502253_item	2645245	et	3	main
isegi	doc_491521502253_item	2645246	et	4	main
seda	doc_491521502253_item	2645247	et	3	main
kuidagi	doc_491521502253_item	2645248	et	3	main
rõhutab	doc_491521502253_item	2645249	et	3	main
see	doc_491521502253_item	2645266	et	3	main
on	doc_491521502253_item	2645268	et	4	main
naine	doc_491521502253_item	2645269	et	3	main
ma	doc_491521502253_item	2645270	et	3	main
arvasin	doc_491521502253_item	2645271	et	3	main
et	doc_491521502253_item	2645272	et	3	main
see	doc_491521502253_item	2645273	et	3	main
on	doc_491521502253_item	2645274	et	4	main
kannatavad	doc_491521502253_item	2645280	et	4	main
naistest	doc_491521502253_item	2645293	et	4	main
on	doc_491521502253_item	2645303	et	4	main
ju	doc_491521502253_item	2645304	et	3	main
saadik	doc_491521502253_item	2645312	et	4	main
mingis	doc_491521502253_item	2645328	et	4	main
nagu	doc_491521502253_item	2645336	et	3	main
näha	doc_491521502253_item	2645341	et	3	main
oma	doc_491521502253_item	2645364	et	4	main
nende	doc_491521502253_item	2645373	et	4	main
vahel	doc_491521502253_item	2645374	et	4	main
sakslast	doc_491521502254_item	2645410	et	3	main
balti	doc_491521502254_item	2645416	et	3	main
töölisi	doc_491521502254_item	2645420	et	3	main
eestlane	doc_491521502254_item	2645421	et	3	main
tööle	doc_491521502254_item	2645423	et	3	main
kohtla-järve	doc_491521502254_item	2645432	et	4	main
väga	doc_491521502254_item	2645449	et	3	main
sillamäe	doc_491521502254_item	2645462	et	3	main
loksa	doc_491521502254_item	2645463	et	4	main
esimesena	doc_491521502254_item	2645464	et	3	main
põlevkivi	doc_491521502254_item	2645475	et	4	main
kaevandati	doc_491521502254_item	2645476	et	3	main
need	doc_491521502254_item	2645484	et	3	main
põhad	doc_491521502254_item	2645488	et	4	main
või	doc_491521502254_item	2645496	et	4	main
küllakutse	doc_491521502254_item	2645530	et	4	main
olema	doc_491521502254_item	2645533	et	4	main
loodust	doc_491521502254_item	2645538	et	4	main
pidi	doc_491521502254_item	2645539	et	4	main
kaitsma	doc_491521502254_item	2645540	et	3	main
hakkama	doc_491521502254_item	2645541	et	3	main
1968	doc_491521502254_item	2645551	et	2	main
eesti	doc_491521502254_item	2645554	et	4	main
rõhutati	doc_491521502254_item	2645562	et	4	main
ajalooliselt	doc_491521502254_item	2645579	et	4	main
ka	doc_491521502254_item	2645581	et	3	main
puid	doc_491521502254_item	2645583	et	3	main
teiselt	doc_491521502254_item	2645588	et	4	main
poolt	doc_491521502254_item	2645589	et	4	main
tehti	doc_491521502254_item	2645590	et	3	main
eestis	doc_491521502254_item	2645591	et	3	main
näidimajandeid	doc_491521502254_item	2645592	et	4	main
olid	doc_491521502254_item	2645595	et	4	main
elustiiliks	doc_491521502254_item	2645609	et	3	main
probleemi	doc_491521502253_item	2645197	et	4	main
vahekorda	doc_491521502253_item	2645204	et	4	main
kultuuri	doc_491521502253_item	2645206	et	4	main
ning	doc_491521502253_item	2645209	et	3	main
kui	doc_491521502253_item	2645219	et	3	main
kõigeopealt	doc_491521502253_item	2645221	et	4	main
et	doc_491521502253_item	2645223	et	3	main
venelased	doc_491521502253_item	2645236	et	3	main
näiteks	doc_491521502253_item	2645250	et	4	main
ta	doc_491521502253_item	2645251	et	4	main
ei	doc_491521502253_item	2645252	et	4	main
et	doc_491521502253_item	2645265	et	3	main
tavaliselt	doc_491521502253_item	2645277	et	4	main
naised	doc_491521502253_item	2645278	et	3	main
tuleb	doc_491521502253_item	2645289	et	3	main
ning	doc_491521502253_item	2645296	et	3	main
ja	doc_491521502253_item	2645298	et	3	main
mees	doc_491521502253_item	2645305	et	4	main
ja	doc_491521502253_item	2645306	et	3	main
ta	doc_491521502253_item	2645307	et	4	main
armastab	doc_491521502253_item	2645308	et	3	main
aga	doc_491521502253_item	2645313	et	3	main
ta	doc_491521502253_item	2645315	et	4	main
niisugusele	doc_491521502253_item	2645317	et	3	main
peenele	doc_491521502253_item	2645318	et	3	main
ta	doc_491521502253_item	2645224	et	4	main
kes	doc_491521502253_item	2645227	et	4	main
muidu	doc_491521502253_item	2645229	et	3	main
aga	doc_491521502253_item	2645237	et	3	main
ma	doc_491521502253_item	2645254	et	3	main
armastasin	doc_491521502253_item	2645255	et	3	main
erikat	doc_491521502253_item	2645256	et	4	main
vaid	doc_491521502253_item	2645257	et	3	main
just	doc_491521502253_item	2645258	et	3	main
sakslast	doc_491521502253_item	2645259	et	3	main
enne	doc_491521502253_item	2645260	et	4	main
kui	doc_491521502253_item	2645261	et	3	main
ma	doc_491521502253_item	2645262	et	3	main
sain	doc_491521502253_item	2645263	et	3	main
teada	doc_491521502253_item	2645264	et	3	main
sakslane	doc_491521502253_item	2645267	et	3	main
rohkem	doc_491521502253_item	2645279	et	4	main
hästi	doc_491521502253_item	2645291	et	3	main
kirjutada	doc_491521502253_item	2645292	et	3	main
naiste	doc_491521502253_item	2645294	et	3	main
maailma	doc_491521502253_item	2645297	et	4	main
ellu	doc_491521502253_item	2645299	et	4	main
erikat	doc_491521502253_item	2645309	et	4	main
oma	doc_491521502253_item	2645322	et	4	main
enesekindel	doc_491521502253_item	2645327	et	3	main
kõhkleb	doc_491521502253_item	2645331	et	3	main
tõmbunud	doc_491521502253_item	2645335	et	4	main
meelde	doc_491521502253_item	2645347	et	3	main
saksa	doc_491521502253_item	2645350	et	4	main
see	doc_491521502253_item	2645353	et	3	main
ta	doc_491521502253_item	2645367	et	4	main
rikkas	doc_491521502253_item	2645369	et	4	main
sakslane	doc_491521502253_item	2645370	et	3	main
on	doc_491521502253_item	2645371	et	4	main
olemas	doc_491521502253_item	2645377	et	4	main
armastasin	doc_491521502254_item	2645409	et	3	main
aastal	doc_491521502254_item	2645414	et	3	main
mis	doc_491521502254_item	2645418	et	4	main
tahtnud	doc_491521502254_item	2645425	et	4	main
asuda	doc_491521502254_item	2645426	et	3	main
sillamäe	doc_491521502254_item	2645431	et	3	main
vajalik	doc_491521502254_item	2645450	et	3	main
kinnised	doc_491521502254_item	2645453	et	4	main
linnad	doc_491521502254_item	2645454	et	3	main
1974	doc_491521502254_item	2645465	et	2	main
loodi	doc_491521502254_item	2645468	et	4	main
looduskaitse	doc_491521502254_item	2645470	et	4	main
ala	doc_491521502254_item	2645471	et	4	main
võisid	doc_491521502254_item	2645485	et	4	main
nt	doc_491521502254_item	2645490	et	4	main
maha	doc_491521502254_item	2645492	et	4	main
põha	doc_491521502254_item	2645493	et	4	main
tammed	doc_491521502254_item	2645494	et	3	main
kaevati	doc_491521502254_item	2645495	et	4	main
püha	doc_491521502254_item	2645498	et	4	main
erilubadega	doc_491521502254_item	2645524	et	3	main
ei	doc_491521502254_item	2645535	et	4	main
saanud	doc_491521502254_item	2645536	et	4	main
jätku	doc_491521502254_item	2645548	et	4	main
keeles	doc_491521502254_item	2645555	et	4	main
carson	doc_491521502254_item	2645558	et	4	main
kevad	doc_491521502254_item	2645560	et	3	main
mõtlematult	doc_491521502254_item	2645572	et	4	main
hävinesid	doc_491521502254_item	2645573	et	4	main
mõned	doc_491521502254_item	2645574	et	3	main
allkakohad	doc_491521502254_item	2645575	et	4	main
pühasid	doc_491521502254_item	2645582	et	3	main
riigid	doc_491521502254_item	2645599	et	3	main
kombeks	doc_491521502254_item	2645601	et	4	main
uueks	doc_491521502254_item	2645610	et	3	main
letialune	doc_491521502254_item	2645613	et	4	main
oli	doc_491521502254_item	2645623	et	3	main
lendasid	doc_491521502254_item	2645635	et	4	main
ostsid	doc_491521502254_item	2645638	et	4	main
sai	doc_491521502254_item	2645658	et	4	main
2	doc_491521502254_item	2645667	et	2	main
film	doc_491521502254_item	2645672	et	3	main
ainult	doc_491521502254_item	2645676	et	4	main
filmist	doc_491521502254_item	2645677	et	4	main
mida	doc_491521502254_item	2645725	et	4	main
tahtis	doc_491521502254_item	2645727	et	3	main
ta	doc_491521502254_item	2645728	et	4	main
julguse	doc_491521502254_item	2645743	et	4	main
inimese	doc_491521502254_item	2645754	et	4	main
ikka	doc_491521502254_item	2645760	et	4	main
tagasi	doc_491521502254_item	2645761	et	3	main
erikal	doc_491521502254_item	2645763	et	4	main
kogu	doc_491521502254_item	2645779	et	4	main
kuulas	doc_491521502254_item	2645781	et	3	main
sõna	doc_491521502254_item	2645783	et	4	main
kui	doc_491521502254_item	2645786	et	3	main
põgeneb	doc_491521502254_item	2645796	et	3	main
pärast	doc_491521502254_item	2645801	et	4	main
lõppuks	doc_491521502254_item	2645803	et	3	main
ta	doc_491521502254_item	2645804	et	4	main
tuli	doc_491521502254_item	2645805	et	4	main
inimest	doc_491521502254_item	2645821	et	3	main
ole	doc_491521502253_item	2645326	et	4	main
paljudki	doc_491521502253_item	2645337	et	3	main
tuletab	doc_491521502253_item	2645346	et	3	main
ja	doc_491521502253_item	2645349	et	3	main
tütre	doc_491521502253_item	2645351	et	3	main
piir	doc_491521502253_item	2645354	et	3	main
vahel	doc_491521502253_item	2645356	et	4	main
et	doc_491521502253_item	2645357	et	3	main
ta	doc_491521502253_item	2645358	et	4	main
lihtne	doc_491521502253_item	2645359	et	3	main
eestlane	doc_491521502253_item	2645360	et	3	main
aga	doc_491521502253_item	2645361	et	3	main
ja	doc_491521502253_item	2645366	et	3	main
oskar	doc_491521502253_item	2645378	et	4	main
ei	doc_491521502253_item	2645379	et	4	main
lahenda	doc_491521502253_item	2645380	et	4	main
oma	doc_491521502253_item	2645381	et	4	main
probleemid	doc_491521502253_item	2645382	et	3	main
identiteediga	doc_491521502253_item	2645383	et	4	main
ka	doc_491521502253_item	2645384	et	3	main
lõpus	doc_491521502253_item	2645386	et	4	main
filmi	doc_491521502253_item	2645385	et	4	main
kontrolltöö	doc_491521502254_item	2645387	et	4	main
1	doc_491521502254_item	2645388	et	2	main
majanduse	doc_491521502254_item	2645389	et	4	main
ja	doc_491521502254_item	2645390	et	3	main
loodushoiu	doc_491521502254_item	2645391	et	3	main
vastasseis	doc_491521502254_item	2645392	et	3	main
1970ndate	doc_491521502254_item	2645393	et	4	main
eesti	doc_491521502254_item	2645394	et	4	main
nsv-s	doc_491521502254_item	2645395	et	3	main
2	doc_491521502254_item	2645396	et	2	main
kellel	doc_491521502254_item	2645397	et	4	main
on	doc_491521502254_item	2645398	et	4	main
teie	doc_491521502254_item	2645399	et	4	main
suuremad	doc_491521502254_item	2645401	et	4	main
identiteediprobleemid	doc_491521502254_item	2645402	et	3	main
arvates	doc_491521502254_item	2645400	et	4	main
oskaril	doc_491521502254_item	2645406	et	4	main
tammsaare	doc_491521502254_item	2645407	et	3	main
1	doc_491521502254_item	2645412	et	2	main
loodi	doc_491521502254_item	2645415	et	4	main
laienevad	doc_491521502254_item	2645428	et	4	main
põlevkivi-kaevandused	doc_491521502254_item	2645429	et	4	main
kujunevad	doc_491521502254_item	2645434	et	4	main
vene	doc_491521502254_item	2645435	et	4	main
eestlastele	doc_491521502254_item	2645437	et	4	main
tehakse	doc_491521502254_item	2645438	et	3	main
takistusi	doc_491521502254_item	2645439	et	4	main
olid	doc_491521502254_item	2645451	et	4	main
n-ö	doc_491521502254_item	2645452	et	4	main
teatud	doc_491521502254_item	2645455	et	4	main
linnadesse	doc_491521502254_item	2645456	et	3	main
oli	doc_491521502254_item	2645457	et	3	main
a	doc_491521502254_item	2645466	et	4	main
sealt	doc_491521502254_item	2645477	et	4	main
kus	doc_491521502254_item	2645478	et	3	main
seal	doc_491521502254_item	2645479	et	4	main
oli	doc_491521502254_item	2645480	et	3	main
vaatamata	doc_491521502254_item	2645481	et	4	main
olla	doc_491521502254_item	2645486	et	3	main
rajuti	doc_491521502254_item	2645491	et	4	main
niisama	doc_491521502254_item	2645525	et	3	main
saanud	doc_491521502254_item	2645527	et	4	main
sinna	doc_491521502254_item	2645528	et	3	main
keegi	doc_491521502254_item	2645529	et	4	main
vms	doc_491521502254_item	2645531	et	4	main
ruhnu	doc_491521502254_item	2645534	et	4	main
üldse	doc_491521502254_item	2645537	et	3	main
pühast	doc_491521502254_item	2645549	et	4	main
vett	doc_491521502254_item	2645550	et	3	main
r	doc_491521502254_item	2645557	et	4	main
kruusa	doc_491521502254_item	2645566	et	4	main
ja	doc_491521502254_item	2645567	et	3	main
liiva	doc_491521502254_item	2645568	et	4	main
seda	doc_491521502254_item	2645569	et	3	main
hakkati	doc_491521502254_item	2645570	et	3	main
kaevandama	doc_491521502254_item	2645571	et	3	main
olid	doc_491521502254_item	2645578	et	4	main
mägesid	doc_491521502254_item	2645585	et	3	main
mis	doc_491521502254_item	2645594	et	4	main
kui	doc_491521502254_item	2645597	et	3	main
tillukesed	doc_491521502254_item	2645598	et	4	main
tööd	doc_491521502254_item	2645604	et	4	main
toodi	doc_491521502254_item	2645605	et	4	main
koju	doc_491521502254_item	2645606	et	3	main
see	doc_491521502254_item	2645607	et	3	main
kujunes	doc_491521502254_item	2645608	et	3	main
sai	doc_491521502254_item	2645612	et	4	main
ei	doc_491521502254_item	2645616	et	4	main
tuli	doc_491521502254_item	2645630	et	4	main
mingi	doc_491521502254_item	2645631	et	4	main
ei	doc_491521502254_item	2645641	et	4	main
olnud	doc_491521502254_item	2645642	et	4	main
kaupa	doc_491521502254_item	2645657	et	4	main
keskonnas	doc_491521502254_item	2645666	et	4	main
meeldis	doc_491521502254_item	2645670	et	3	main
huvitav	doc_491521502254_item	2645686	et	4	main
minu	doc_491521502254_item	2645687	et	3	main
teha	doc_491521502254_item	2645723	et	3	main
ei	doc_491521502254_item	2645729	et	4	main
aga	doc_491521502254_item	2645737	et	3	main
siis	doc_491521502254_item	2645738	et	3	main
kui	doc_491521502254_item	2645739	et	3	main
ta	doc_491521502254_item	2645740	et	4	main
üks	doc_491521502254_item	2645741	et	3	main
ja	doc_491521502254_item	2645746	et	3	main
kodust	doc_491521502254_item	2645751	et	4	main
oma	doc_491521502254_item	2645752	et	4	main
armsa	doc_491521502254_item	2645753	et	3	main
ta	doc_491521502254_item	2645758	et	4	main
ei	doc_491521502254_item	2645776	et	4	main
ta	doc_491521502254_item	2645787	et	4	main
armsa	doc_491521502254_item	2645799	et	3	main
saanud	doc_491521502254_item	2645824	et	4	main
segadusse	doc_491521502254_item	2645840	et	3	main
ja	doc_491521502254_item	2645841	et	3	main
üldse	doc_491521502254_item	2645852	et	3	main
käimine	doc_491521502254_item	2645872	et	4	main
oli	doc_491521502254_item	2645873	et	3	main
1973	doc_491521502254_item	2645413	et	2	main
soojuselektrijaam	doc_491521502254_item	2645417	et	3	main
kaevandusse	doc_491521502254_item	2645422	et	4	main
ei	doc_491521502254_item	2645424	et	4	main
kohtla-järve	doc_491521502254_item	2645427	et	4	main
piirkonnad	doc_491521502254_item	2645433	et	4	main
keelseteks	doc_491521502254_item	2645436	et	4	main
narva	doc_491521502254_item	2645442	et	4	main
elama	doc_491521502254_item	2645443	et	3	main
asumisele	doc_491521502254_item	2645444	et	4	main
sissekirjutus	doc_491521502254_item	2645445	et	3	main
oli	doc_491521502254_item	2645446	et	3	main
kohustuslik	doc_491521502254_item	2645447	et	3	main
ja	doc_491521502254_item	2645448	et	3	main
keelatud	doc_491521502254_item	2645461	et	4	main
nsvls	doc_491521502254_item	2645467	et	4	main
eestis	doc_491521502254_item	2645469	et	3	main
kus	doc_491521502254_item	2645500	et	3	main
eestlased	doc_491521502254_item	2645501	et	3	main
käisid	doc_491521502254_item	2645502	et	4	main
jumalaid	doc_491521502254_item	2645503	et	3	main
palvetamas	doc_491521502254_item	2645504	et	3	main
nii	doc_491521502254_item	2645505	et	3	main
et	doc_491521502254_item	2645506	et	3	main
selle	doc_491521502254_item	2645507	et	4	main
peale	doc_491521502254_item	2645508	et	4	main
üldse	doc_491521502254_item	2645509	et	3	main
ei	doc_491521502254_item	2645510	et	4	main
vaadeti	doc_491521502254_item	2645511	et	4	main
mis	doc_491521502254_item	2645512	et	4	main
koht	doc_491521502254_item	2645513	et	3	main
see	doc_491521502254_item	2645514	et	3	main
oli	doc_491521502254_item	2645515	et	3	main
saartele	doc_491521502254_item	2645516	et	3	main
tol	doc_491521502254_item	2645517	et	3	main
üldse	doc_491521502254_item	2645519	et	3	main
ei	doc_491521502254_item	2645520	et	4	main
ajal	doc_491521502254_item	2645518	et	4	main
pääses	doc_491521502254_item	2645522	et	4	main
ei	doc_491521502254_item	2645526	et	4	main
päästa	doc_491521502254_item	2645542	et	4	main
hävitamisest	doc_491521502254_item	2645543	et	4	main
tekkis	doc_491521502254_item	2645544	et	3	main
hirm	doc_491521502254_item	2645545	et	3	main
et	doc_491521502254_item	2645546	et	3	main
ilmus	doc_491521502254_item	2645553	et	4	main
hääletu	doc_491521502254_item	2645559	et	4	main
seal	doc_491521502254_item	2645561	et	4	main
looduhoidu	doc_491521502254_item	2645563	et	4	main
hakkas	doc_491521502254_item	2645564	et	3	main
nappima	doc_491521502254_item	2645565	et	3	main
mis	doc_491521502254_item	2645576	et	4	main
pühad	doc_491521502254_item	2645580	et	3	main
ja	doc_491521502254_item	2645584	et	3	main
veeti	doc_491521502254_item	2645586	et	3	main
riigilt	doc_491521502254_item	2645602	et	3	main
fenomeniks	doc_491521502254_item	2645611	et	3	main
kaubandus	doc_491521502254_item	2645614	et	3	main
viidi	doc_491521502254_item	2645620	et	4	main
eestlastele	doc_491521502254_item	2645615	et	4	main
müüdud	doc_491521502254_item	2645617	et	4	main
midagi	doc_491521502254_item	2645618	et	4	main
kõike	doc_491521502254_item	2645619	et	4	main
defitsiit	doc_491521502254_item	2645624	et	3	main
kaup	doc_491521502254_item	2645632	et	3	main
peale	doc_491521502254_item	2645636	et	4	main
mõtlesid	doc_491521502254_item	2645652	et	4	main
siis	doc_491521502254_item	2645653	et	3	main
inimesed	doc_491521502254_item	2645654	et	3	main
vähese	doc_491521502254_item	2645655	et	3	main
saadavat	doc_491521502254_item	2645656	et	4	main
see	doc_491521502254_item	2645671	et	3	main
rääkida	doc_491521502254_item	2645675	et	3	main
raamatud	doc_491521502254_item	2645679	et	4	main
ma	doc_491521502254_item	2645680	et	3	main
pole	doc_491521502254_item	2645681	et	3	main
lugenud	doc_491521502254_item	2645682	et	4	main
see	doc_491521502254_item	2645683	et	3	main
oli	doc_491521502254_item	2645684	et	3	main
küllalti	doc_491521502254_item	2645685	et	4	main
kõikke	doc_491521502254_item	2645724	et	4	main
ta	doc_491521502254_item	2645726	et	4	main
kord	doc_491521502254_item	2645742	et	4	main
otsustas	doc_491521502254_item	2645747	et	3	main
ta	doc_491521502254_item	2645749	et	4	main
tuli	doc_491521502254_item	2645759	et	4	main
koju	doc_491521502254_item	2645762	et	3	main
polnud	doc_491521502254_item	2645764	et	3	main
üldse	doc_491521502254_item	2645765	et	3	main
vabadust	doc_491521502254_item	2645766	et	4	main
ta	doc_491521502254_item	2645767	et	4	main
ta	doc_491521502254_item	2645773	et	4	main
tahtis	doc_491521502254_item	2645774	et	3	main
iseseisev	doc_491521502254_item	2645778	et	3	main
kodust	doc_491521502254_item	2645797	et	4	main
ikka	doc_491521502254_item	2645806	et	4	main
tagasi	doc_491521502254_item	2645807	et	3	main
koju	doc_491521502254_item	2645808	et	3	main
ja	doc_491521502254_item	2645822	et	3	main
ei	doc_491521502254_item	2645823	et	4	main
temaga	doc_491521502254_item	2645825	et	3	main
koos	doc_491521502254_item	2645826	et	4	main
olla	doc_491521502254_item	2645827	et	3	main
lõppudeks	doc_491521502254_item	2645828	et	3	main
erika	doc_491521502254_item	2645829	et	4	main
siin	doc_491521502254_item	2645836	et	4	main
maailmas	doc_491521502254_item	2645837	et	3	main
mitte	doc_491521502254_item	2645853	et	3	main
mingisugust	doc_491521502254_item	2645854	et	3	main
teatris	doc_491521502254_item	2645856	et	3	main
kätte	doc_491521502254_item	2645870	et	4	main
see	doc_491521502254_item	2645871	et	3	main
kino	doc_491521502254_item	2645881	et	4	main
eestlastele	doc_491521502254_item	2645892	et	4	main
romaanikirjandus	doc_491521502254_item	2645895	et	3	main
kontrolltöö	doc_491521502255_item	2645899	et	4	main
majanduse	doc_491521502255_item	2645901	et	4	main
vastasseis	doc_491521502255_item	2645904	et	3	main
arvates	doc_491521502255_item	2645912	et	4	main
või	doc_491521502255_item	2645917	et	4	main
tammsaare	doc_491521502255_item	2645919	et	3	main
tal	doc_491521502255_item	2645932	et	3	main
polnud	doc_491521502255_item	2645933	et	3	main
isiklikku	doc_491521502255_item	2645934	et	4	main
oli	doc_491521502255_item	2645942	et	3	main
takista	doc_491521502255_item	2645946	et	4	main
suhteid	doc_491521502255_item	2645948	et	3	main
olles	doc_491521502255_item	2645950	et	3	main
ustav	doc_491521502255_item	2645951	et	4	main
tahtnud	doc_491521502255_item	2645957	et	4	main
iseseisev	doc_491521502255_item	2645966	et	3	main
võib	doc_491521502255_item	2645969	et	3	main
teha	doc_491521502255_item	2645970	et	3	main
tegelikult	doc_491521502255_item	2645977	et	4	main
ise	doc_491521502255_item	2645979	et	4	main
ta	doc_491521502255_item	2645983	et	4	main
välja	doc_491521502254_item	2645622	et	4	main
wc	doc_491521502254_item	2645626	et	4	main
kõik	doc_491521502254_item	2645634	et	4	main
neil	doc_491521502254_item	2645643	et	4	main
üldse	doc_491521502254_item	2645644	et	3	main
seda	doc_491521502254_item	2645645	et	3	main
vaja	doc_491521502254_item	2645646	et	4	main
teiste	doc_491521502254_item	2645659	et	4	main
väga	doc_491521502254_item	2645669	et	3	main
ma	doc_491521502254_item	2645673	et	3	main
arvates	doc_491521502254_item	2645688	et	4	main
erikal	doc_491521502254_item	2645689	et	4	main
olid	doc_491521502254_item	2645690	et	4	main
suuremad	doc_491521502254_item	2645691	et	4	main
identiteediprobleemid	doc_491521502254_item	2645692	et	3	main
kui	doc_491521502254_item	2645693	et	3	main
oskaril	doc_491521502254_item	2645694	et	4	main
mulle	doc_491521502254_item	2645695	et	4	main
tundus	doc_491521502254_item	2645696	et	3	main
et	doc_491521502254_item	2645697	et	3	main
oskar	doc_491521502254_item	2645698	et	4	main
teadis	doc_491521502254_item	2645699	et	4	main
kõike	doc_491521502254_item	2645700	et	4	main
mida	doc_491521502254_item	2645701	et	4	main
ta	doc_491521502254_item	2645702	et	4	main
tahtis	doc_491521502254_item	2645703	et	3	main
ja	doc_491521502254_item	2645704	et	3	main
kõike	doc_491521502254_item	2645705	et	4	main
mida	doc_491521502254_item	2645706	et	4	main
ta	doc_491521502254_item	2645707	et	4	main
tegi	doc_491521502254_item	2645708	et	4	main
oli	doc_491521502254_item	2645709	et	3	main
tal	doc_491521502254_item	2645710	et	3	main
alati	doc_491521502254_item	2645711	et	4	main
vastus	doc_491521502254_item	2645712	et	3	main
aga	doc_491521502254_item	2645714	et	3	main
erika	doc_491521502254_item	2645715	et	4	main
tal	doc_491521502254_item	2645716	et	3	main
olemas	doc_491521502254_item	2645713	et	4	main
ei	doc_491521502254_item	2645717	et	4	main
olnud	doc_491521502254_item	2645718	et	4	main
vabadust	doc_491521502254_item	2645719	et	4	main
ta	doc_491521502254_item	2645720	et	4	main
ei	doc_491521502254_item	2645721	et	4	main
inimestega	doc_491521502254_item	2645660	et	3	main
vahetada	doc_491521502254_item	2645661	et	3	main
müüjal	doc_491521502254_item	2645662	et	4	main
oli	doc_491521502254_item	2645663	et	3	main
arvestatav	doc_491521502254_item	2645664	et	4	main
positsioon	doc_491521502254_item	2645665	et	3	main
mulle	doc_491521502254_item	2645668	et	4	main
saan	doc_491521502254_item	2645674	et	4	main
kuna	doc_491521502254_item	2645678	et	3	main
olnud	doc_491521502254_item	2645730	et	4	main
iseseisev	doc_491521502254_item	2645731	et	3	main
kuulas	doc_491521502254_item	2645734	et	3	main
kokku	doc_491521502254_item	2645744	et	3	main
et	doc_491521502254_item	2645748	et	3	main
põgeneb	doc_491521502254_item	2645750	et	3	main
lõppuks	doc_491521502254_item	2645757	et	3	main
saanud	doc_491521502254_item	2645769	et	4	main
teha	doc_491521502254_item	2645770	et	3	main
kõikke	doc_491521502254_item	2645771	et	4	main
mida	doc_491521502254_item	2645772	et	4	main
olnud	doc_491521502254_item	2645777	et	4	main
ta	doc_491521502254_item	2645795	et	4	main
lõppude	doc_491521502254_item	2645802	et	4	main
tema	doc_491521502254_item	2645834	et	4	main
koht	doc_491521502254_item	2645835	et	3	main
mida	doc_491521502254_item	2645844	et	4	main
teha	doc_491521502254_item	2645845	et	3	main
aga	doc_491521502254_item	2645846	et	3	main
oskar	doc_491521502254_item	2645847	et	4	main
minu	doc_491521502254_item	2645848	et	3	main
näinud	doc_491521502254_item	2645851	et	4	main
vaeva	doc_491521502254_item	2645855	et	4	main
inimesed	doc_491521502254_item	2645857	et	3	main
tekkisid	doc_491521502254_item	2645876	et	4	main
mitte	doc_491521502254_item	2645885	et	3	main
meeldib	doc_491521502254_item	2645893	et	3	main
kellel	doc_491521502255_item	2645909	et	4	main
ma	doc_491521502255_item	2645920	et	3	main
põhjendage	doc_491521502255_item	2645923	et	3	main
suuremad	doc_491521502255_item	2645927	et	4	main
siiski	doc_491521502255_item	2645930	et	4	main
ta	doc_491521502255_item	2645936	et	4	main
oma	doc_491521502255_item	2645939	et	4	main
päritolust	doc_491521502255_item	2645940	et	3	main
erika	doc_491521502255_item	2645941	et	4	main
sakslane	doc_491521502255_item	2645943	et	3	main
ei	doc_491521502255_item	2645956	et	4	main
elu	doc_491521502255_item	2645960	et	4	main
peab	doc_491521502255_item	2645975	et	4	main
on	doc_491521502255_item	2645985	et	4	main
kas	doc_491521502255_item	2645986	et	3	main
sakslane	doc_491521502255_item	2645987	et	3	main
või	doc_491521502255_item	2645988	et	4	main
aga	doc_491521502255_item	2646021	et	3	main
ja	doc_491521502255_item	2646028	et	3	main
ja	doc_491521502255_item	2646034	et	3	main
ta	doc_491521502255_item	2646038	et	4	main
oskar	doc_491521502255_item	2646042	et	4	main
jättis	doc_491521502255_item	2646043	et	3	main
parem	doc_491521502255_item	2646050	et	4	main
erika	doc_491521502255_item	2646053	et	4	main
elada	doc_491521502255_item	2646056	et	3	main
eriti	doc_491521502255_item	2646068	et	3	main
see	doc_491521502255_item	2646071	et	3	main
keele	doc_491521502255_item	2646076	et	4	main
saab	doc_491521502255_item	2646078	et	3	main
1	doc_491521502255_item	2646088	et	2	main
et	doc_491521502255_item	2646107	et	3	main
teiseks	doc_491521502255_item	2646131	et	4	main
suuremaks	doc_491521502255_item	2646132	et	4	main
liiva	doc_491521502255_item	2646136	et	4	main
loodusele	doc_491521502255_item	2646152	et	4	main
toomine	doc_491521502255_item	2646158	et	4	main
metsadesse	doc_491521502255_item	2646159	et	3	main
hruštšovi	doc_491521502255_item	2646160	et	2	main
proov	doc_491521502255_item	2646161	et	3	main
väljasuremisele	doc_491521502255_item	2646194	et	3	main
olid	doc_491521502255_item	2646195	et	4	main
ka	doc_491521502255_item	2646196	et	3	main
lõpus	doc_491521502255_item	2646204	et	4	main
hakati	doc_491521502255_item	2646205	et	3	main
eestis	doc_491521502255_item	2646206	et	3	main
saanud	doc_491521502254_item	2645722	et	4	main
kogu	doc_491521502254_item	2645732	et	4	main
aeg	doc_491521502254_item	2645733	et	3	main
vanemate	doc_491521502254_item	2645735	et	4	main
sõna	doc_491521502254_item	2645736	et	4	main
võttis	doc_491521502254_item	2645745	et	3	main
pärast	doc_491521502254_item	2645755	et	4	main
lõppude	doc_491521502254_item	2645756	et	4	main
ei	doc_491521502254_item	2645768	et	4	main
ta	doc_491521502254_item	2645775	et	4	main
aeg	doc_491521502254_item	2645780	et	3	main
vanemate	doc_491521502254_item	2645782	et	4	main
aga	doc_491521502254_item	2645784	et	3	main
siis	doc_491521502254_item	2645785	et	3	main
ükskord	doc_491521502254_item	2645788	et	3	main
julguse	doc_491521502254_item	2645789	et	4	main
kokku	doc_491521502254_item	2645790	et	3	main
võttis	doc_491521502254_item	2645791	et	3	main
ja	doc_491521502254_item	2645792	et	3	main
otsustas	doc_491521502254_item	2645793	et	3	main
et	doc_491521502254_item	2645794	et	3	main
oma	doc_491521502254_item	2645798	et	4	main
inimeses	doc_491521502254_item	2645800	et	3	main
erikal	doc_491521502254_item	2645809	et	4	main
polnud	doc_491521502254_item	2645810	et	3	main
üldse	doc_491521502254_item	2645811	et	3	main
vabadust	doc_491521502254_item	2645812	et	4	main
ta	doc_491521502254_item	2645813	et	4	main
ei	doc_491521502254_item	2645814	et	4	main
tunnud	doc_491521502254_item	2645815	et	4	main
ennast	doc_491521502254_item	2645816	et	4	main
vaba	doc_491521502254_item	2645817	et	4	main
naisena	doc_491521502254_item	2645818	et	3	main
ta	doc_491521502254_item	2645819	et	4	main
armastas	doc_491521502254_item	2645820	et	3	main
ei	doc_491521502254_item	2645830	et	4	main
ta	doc_491521502254_item	2645838	et	4	main
sattus	doc_491521502254_item	2645839	et	3	main
ei	doc_491521502254_item	2645842	et	4	main
teadnud	doc_491521502254_item	2645843	et	4	main
ei	doc_491521502254_item	2645850	et	4	main
käisid	doc_491521502254_item	2645858	et	4	main
hea	doc_491521502254_item	2645859	et	4	main
meelega	doc_491521502254_item	2645860	et	4	main
piletid	doc_491521502254_item	2645861	et	3	main
olid	doc_491521502254_item	2645862	et	4	main
väga	doc_491521502254_item	2645863	et	3	main
soodsad	doc_491521502254_item	2645864	et	4	main
ja	doc_491521502254_item	2645865	et	3	main
igaüks	doc_491521502254_item	2645866	et	3	main
sai	doc_491521502254_item	2645867	et	4	main
põhimõtteliselt	doc_491521502254_item	2645868	et	4	main
need	doc_491521502254_item	2645869	et	3	main
teandus	doc_491521502254_item	2645831	et	4	main
kus	doc_491521502254_item	2645832	et	3	main
on	doc_491521502254_item	2645833	et	4	main
meelest	doc_491521502254_item	2645849	et	4	main
jaoks	doc_491521502254_item	2645887	et	4	main
palju	doc_491521502254_item	2645891	et	4	main
rohkem	doc_491521502254_item	2645894	et	4	main
aga	doc_491521502254_item	2645896	et	3	main
loodushoiu	doc_491521502255_item	2645903	et	3	main
teie	doc_491521502255_item	2645911	et	4	main
väga	doc_491521502254_item	2645874	et	3	main
isegi	doc_491521502254_item	2645877	et	4	main
väiksed	doc_491521502254_item	2645878	et	4	main
teatri	doc_491521502254_item	2645879	et	3	main
ringid	doc_491521502254_item	2645880	et	4	main
iseloomulikult	doc_491521502254_item	2645883	et	4	main
muulastele	doc_491521502254_item	2645897	et	4	main
1	doc_491521502255_item	2645900	et	2	main
ja	doc_491521502255_item	2645902	et	3	main
1970ndate	doc_491521502255_item	2645905	et	4	main
eesti	doc_491521502255_item	2645906	et	4	main
nsv-s	doc_491521502255_item	2645907	et	3	main
2	doc_491521502255_item	2645908	et	2	main
suuremad	doc_491521502255_item	2645913	et	4	main
identiteediprobleemid	doc_491521502255_item	2645914	et	3	main
kas	doc_491521502255_item	2645915	et	3	main
armastasin	doc_491521502255_item	2645921	et	3	main
2	doc_491521502255_item	2645924	et	2	main
arvates	doc_491521502255_item	2645926	et	4	main
identiteediprobleemid	doc_491521502255_item	2645928	et	3	main
vabadust	doc_491521502255_item	2645935	et	4	main
ja	doc_491521502255_item	2645944	et	3	main
oma	doc_491521502255_item	2645959	et	4	main
tundub	doc_491521502255_item	2645962	et	3	main
erika	doc_491521502255_item	2645964	et	4	main
õigeks	doc_491521502255_item	2645976	et	3	main
ei	doc_491521502255_item	2645980	et	4	main
teadnud	doc_491521502255_item	2645981	et	4	main
pigem	doc_491521502255_item	2645984	et	3	main
ta	doc_491521502255_item	2645990	et	4	main
hakkas	doc_491521502255_item	2645991	et	3	main
kahtlema	doc_491521502255_item	2645992	et	3	main
mõne	doc_491521502255_item	2645993	et	3	main
nagu	doc_491521502255_item	2646025	et	3	main
polnud	doc_491521502255_item	2646029	et	3	main
kuhu	doc_491521502255_item	2646031	et	3	main
need	doc_491521502255_item	2646035	et	3	main
rikkusid	doc_491521502255_item	2646037	et	4	main
tulevikku	doc_491521502255_item	2646039	et	4	main
elu	doc_491521502255_item	2646040	et	4	main
ta	doc_491521502255_item	2646044	et	4	main
maha	doc_491521502255_item	2646045	et	4	main
mõeldes	doc_491521502255_item	2646046	et	3	main
ja	doc_491521502255_item	2646051	et	3	main
on	doc_491521502255_item	2646064	et	4	main
alati	doc_491521502255_item	2646065	et	4	main
ja	doc_491521502255_item	2646066	et	3	main
igalühel	doc_491521502255_item	2646067	et	3	main
olukord	doc_491521502255_item	2646072	et	3	main
kõrval	doc_491521502255_item	2646077	et	4	main
mingi	doc_491521502255_item	2646081	et	4	main
teine	doc_491521502255_item	2646082	et	3	main
keel	doc_491521502255_item	2646083	et	4	main
ja	doc_491521502255_item	2646084	et	3	main
ekoloogia	doc_491521502255_item	2646093	et	4	main
öelda	doc_491521502255_item	2646106	et	4	main
mis	doc_491521502255_item	2646122	et	4	main
ekoloogilisi	doc_491521502255_item	2646124	et	4	main
probleeme	doc_491521502255_item	2646125	et	3	main
peeta	doc_491521502255_item	2646135	et	4	main
võõraste	doc_491521502255_item	2646153	et	4	main
loomade	doc_491521502255_item	2646154	et	4	main
ja	doc_491521502255_item	2646155	et	3	main
levitada	doc_491521502255_item	2646162	et	3	main
maisi	doc_491521502255_item	2646165	et	4	main
selle	doc_491521502255_item	2646167	et	4	main
loomade	doc_491521502255_item	2646191	et	4	main
ja	doc_491521502255_item	2646192	et	3	main
puudumine	doc_491521502255_item	2646202	et	4	main
fosforiiti	doc_491521502255_item	2646208	et	4	main
looduskaitsjate	doc_491521502255_item	2646212	et	3	main
fosforiidi	doc_491521502255_item	2646214	et	4	main
ohtlik	doc_491521502255_item	2646218	et	3	main
keskkonna	doc_491521502255_item	2646219	et	3	main
jaoks	doc_491521502255_item	2646220	et	4	main
popularne	doc_491521502254_item	2645875	et	4	main
oli	doc_491521502254_item	2645882	et	3	main
pigem	doc_491521502254_item	2645884	et	3	main
eestlaste	doc_491521502254_item	2645886	et	4	main
lugesid	doc_491521502254_item	2645888	et	4	main
nad	doc_491521502254_item	2645889	et	3	main
ka	doc_491521502254_item	2645890	et	3	main
luule	doc_491521502254_item	2645898	et	4	main
on	doc_491521502255_item	2645910	et	4	main
erikal	doc_491521502255_item	2645916	et	4	main
oskaril	doc_491521502255_item	2645918	et	4	main
sakslast	doc_491521502255_item	2645922	et	3	main
minu	doc_491521502255_item	2645925	et	3	main
on	doc_491521502255_item	2645929	et	4	main
sõltus	doc_491521502255_item	2645937	et	4	main
täielikult	doc_491521502255_item	2645938	et	4	main
isa	doc_491521502255_item	2645953	et	4	main
ideaalidele	doc_491521502255_item	2645954	et	3	main
erika	doc_491521502255_item	2645955	et	4	main
mida	doc_491521502255_item	2645971	et	4	main
ise	doc_491521502255_item	2645972	et	4	main
tahab	doc_491521502255_item	2645973	et	3	main
ja	doc_491521502255_item	2645974	et	3	main
kes	doc_491521502255_item	2645982	et	4	main
eestlane	doc_491521502255_item	2645989	et	3	main
teistele	doc_491521502255_item	2646023	et	4	main
ristmikule	doc_491521502255_item	2646027	et	4	main
edasi	doc_491521502255_item	2646032	et	3	main
et	doc_491521502255_item	2646047	et	3	main
niiviisi	doc_491521502255_item	2646048	et	3	main
juhtub	doc_491521502255_item	2646070	et	3	main
kus	doc_491521502255_item	2646074	et	3	main
rahvus	doc_491521502255_item	2646085	et	3	main
suuremaks	doc_491521502255_item	2646090	et	4	main
erikal	doc_491521502255_item	2645931	et	4	main
see	doc_491521502255_item	2645945	et	3	main
ta	doc_491521502255_item	2645947	et	4	main
oskariga	doc_491521502255_item	2645949	et	4	main
oma	doc_491521502255_item	2645952	et	4	main
siduda	doc_491521502255_item	2645958	et	3	main
mittesakslastega	doc_491521502255_item	2645961	et	3	main
et	doc_491521502255_item	2645963	et	3	main
polnud	doc_491521502255_item	2645965	et	3	main
naine	doc_491521502255_item	2645967	et	3	main
kes	doc_491521502255_item	2645968	et	4	main
erika	doc_491521502255_item	2645978	et	4	main
aja	doc_491521502255_item	2645994	et	4	main
pärast	doc_491521502255_item	2645995	et	4	main
ja	doc_491521502255_item	2645996	et	3	main
see	doc_491521502255_item	2645997	et	3	main
näitab	doc_491521502255_item	2645998	et	3	main
et	doc_491521502255_item	2645999	et	3	main
tal	doc_491521502255_item	2646000	et	3	main
polnud	doc_491521502255_item	2646001	et	3	main
kindlat	doc_491521502255_item	2646002	et	3	main
ja	doc_491521502255_item	2646003	et	3	main
selget	doc_491521502255_item	2646004	et	3	main
mõistust	doc_491521502255_item	2646005	et	4	main
kas	doc_491521502255_item	2646006	et	3	main
ta	doc_491521502255_item	2646007	et	4	main
üldse	doc_491521502255_item	2646008	et	3	main
tahab	doc_491521502255_item	2646009	et	3	main
tulevikus	doc_491521502255_item	2646010	et	4	main
peeta	doc_491521502255_item	2646011	et	4	main
ennast	doc_491521502255_item	2646012	et	4	main
sakslaseks	doc_491521502255_item	2646013	et	3	main
kodus	doc_491521502255_item	2646014	et	4	main
istuv	doc_491521502255_item	2646015	et	4	main
isa	doc_491521502255_item	2646016	et	4	main
kaldus	doc_491521502255_item	2646017	et	4	main
teda	doc_491521502255_item	2646018	et	4	main
ühele	doc_491521502255_item	2646019	et	3	main
poole	doc_491521502255_item	2646020	et	4	main
oskar	doc_491521502255_item	2646022	et	4	main
probleemid	doc_491521502255_item	2646036	et	3	main
on	doc_491521502255_item	2646049	et	4	main
rahulikult	doc_491521502255_item	2646055	et	4	main
riikides	doc_491521502255_item	2646073	et	3	main
nagu	doc_491521502255_item	2646086	et	3	main
tasakaalu	doc_491521502255_item	2646094	et	4	main
70ndatel	doc_491521502255_item	2646096	et	4	main
kui	doc_491521502255_item	2646098	et	3	main
moskva	doc_491521502255_item	2646099	et	4	main
nõudis	doc_491521502255_item	2646100	et	3	main
eestist	doc_491521502255_item	2646101	et	3	main
suures	doc_491521502255_item	2646102	et	3	main
mahus	doc_491521502255_item	2646103	et	3	main
põlevkivi	doc_491521502255_item	2646104	et	4	main
võib	doc_491521502255_item	2646105	et	3	main
ta	doc_491521502255_item	2646024	et	4	main
astus	doc_491521502255_item	2646026	et	3	main
kindel	doc_491521502255_item	2646030	et	3	main
minna	doc_491521502255_item	2646033	et	3	main
sest	doc_491521502255_item	2646041	et	4	main
nüüd	doc_491521502255_item	2646052	et	4	main
saab	doc_491521502255_item	2646054	et	3	main
ta	doc_491521502255_item	2646057	et	4	main
leiab	doc_491521502255_item	2646058	et	3	main
ennast	doc_491521502255_item	2646059	et	4	main
ma	doc_491521502255_item	2646060	et	3	main
arvan	doc_491521502255_item	2646061	et	3	main
et	doc_491521502255_item	2646062	et	3	main
identiteediprobleemid	doc_491521502255_item	2646063	et	3	main
tihti	doc_491521502255_item	2646069	et	3	main
riikliku	doc_491521502255_item	2646075	et	3	main
leviku	doc_491521502255_item	2646079	et	3	main
ka	doc_491521502255_item	2646080	et	3	main
eestis	doc_491521502255_item	2646087	et	3	main
kõige	doc_491521502255_item	2646089	et	4	main
probleemiks	doc_491521502255_item	2646091	et	4	main
sai	doc_491521502255_item	2646092	et	4	main
rikkus	doc_491521502255_item	2646095	et	4	main
aastatel	doc_491521502255_item	2646097	et	4	main
eesti	doc_491521502255_item	2646108	et	4	main
varustas	doc_491521502255_item	2646109	et	3	main
energiaga	doc_491521502255_item	2646110	et	3	main
kogu	doc_491521502255_item	2646111	et	4	main
leningradi	doc_491521502255_item	2646112	et	4	main
oblastit	doc_491521502255_item	2646113	et	3	main
ja	doc_491521502255_item	2646114	et	3	main
selleäärseid	doc_491521502255_item	2646115	et	3	main
rajoone	doc_491521502255_item	2646116	et	3	main
põlevkivi	doc_491521502255_item	2646117	et	4	main
kaevandama	doc_491521502255_item	2646119	et	3	main
liiga	doc_491521502255_item	2646120	et	4	main
hakati	doc_491521502255_item	2646118	et	3	main
neid	doc_491521502255_item	2646140	et	4	main
varad	doc_491521502255_item	2646145	et	3	main
eesti	doc_491521502255_item	2646151	et	4	main
sisse	doc_491521502255_item	2646157	et	4	main
põldudele	doc_491521502255_item	2646163	et	3	main
eestis	doc_491521502255_item	2646164	et	3	main
on	doc_491521502255_item	2646166	et	4	main
taimede	doc_491521502255_item	2646193	et	4	main
70ndate	doc_491521502255_item	2646203	et	4	main
oli	doc_491521502255_item	2646210	et	3	main
kaevandamise	doc_491521502255_item	2646225	et	4	main
mahu	doc_491521502255_item	2646226	et	4	main
vähenemist	doc_491521502255_item	2646227	et	4	main
valitsus	doc_491521502255_item	2646228	et	4	main
ilmuma	doc_491521502255_item	2646238	et	3	main
probleemiks	doc_491521502255_item	2646133	et	4	main
võib	doc_491521502255_item	2646134	et	3	main
kruusi	doc_491521502255_item	2646138	et	4	main
lõppesid	doc_491521502255_item	2646146	et	4	main
ära	doc_491521502255_item	2646147	et	4	main
veel	doc_491521502255_item	2646148	et	4	main
võib	doc_491521502255_item	2646149	et	3	main
nimetada	doc_491521502255_item	2646150	et	3	main
taimede	doc_491521502255_item	2646156	et	4	main
kõige	doc_491521502255_item	2646168	et	4	main
märksamaks	doc_491521502255_item	2646169	et	4	main
näteks	doc_491521502255_item	2646170	et	4	main
veel	doc_491521502255_item	2646171	et	4	main
prooviti	doc_491521502255_item	2646172	et	3	main
sisse	doc_491521502255_item	2646173	et	4	main
tooma	doc_491521502255_item	2646174	et	3	main
kobrast	doc_491521502255_item	2646175	et	4	main
teisi	doc_491521502255_item	2646176	et	4	main
loomi	doc_491521502255_item	2646177	et	4	main
on	doc_491521502255_item	2646179	et	4	main
väga	doc_491521502255_item	2646180	et	3	main
ohtlik	doc_491521502255_item	2646181	et	3	main
sest	doc_491521502255_item	2646182	et	4	main
see	doc_491521502255_item	2646178	et	3	main
see	doc_491521502255_item	2646183	et	3	main
viib	doc_491521502255_item	2646184	et	3	main
loodusliku	doc_491521502255_item	2646185	et	3	main
tasakaalu	doc_491521502255_item	2646186	et	4	main
intensiivselt	doc_491521502255_item	2646121	et	4	main
põhjustas	doc_491521502255_item	2646123	et	3	main
eriti	doc_491521502255_item	2646126	et	3	main
suured	doc_491521502255_item	2646127	et	3	main
kaevandused	doc_491521502255_item	2646128	et	4	main
asusid	doc_491521502255_item	2646129	et	4	main
põhja-eestis	doc_491521502255_item	2646130	et	3	main
ja	doc_491521502255_item	2646137	et	3	main
nappardumist	doc_491521502255_item	2646139	et	4	main
kasutati	doc_491521502255_item	2646141	et	4	main
mõtlematule	doc_491521502255_item	2646142	et	4	main
ja	doc_491521502255_item	2646143	et	3	main
varsti	doc_491521502255_item	2646144	et	3	main
teised	doc_491521502255_item	2646197	et	4	main
kaevandama	doc_491521502255_item	2646207	et	3	main
põhjuseks	doc_491521502255_item	2646211	et	3	main
mõustus	doc_491521502255_item	2646229	et	4	main
said	doc_491521502255_item	2646232	et	4	main
vormi	doc_491521502255_item	2646234	et	4	main
peale	doc_491521502255_item	2646235	et	4	main
ilmus	doc_491521502257_item	2646404	et	4	main
ja	doc_491521502257_item	2646406	et	3	main
sõnavabadus	doc_491521502257_item	2646407	et	4	main
initsiatiivi	doc_491521502257_item	2646410	et	4	main
süsteemile	doc_491521502257_item	2646415	et	3	main
avalikustamine	doc_491521502257_item	2646420	et	4	main
rikkumisele	doc_491521502255_item	2646187	et	4	main
ja	doc_491521502255_item	2646188	et	3	main
järelikult	doc_491521502255_item	2646189	et	3	main
teiste	doc_491521502255_item	2646190	et	4	main
väiksemad	doc_491521502255_item	2646198	et	4	main
probleemid	doc_491521502255_item	2646199	et	3	main
nagu	doc_491521502255_item	2646200	et	3	main
mineraalvee	doc_491521502255_item	2646201	et	3	main
see	doc_491521502255_item	2646209	et	3	main
ja	doc_491521502255_item	2646221	et	3	main
nõudsid	doc_491521502255_item	2646223	et	4	main
sest	doc_491521502255_item	2646230	et	4	main
aktiviseerumisele	doc_491521502255_item	2646213	et	4	main
kaevandamine	doc_491521502255_item	2646215	et	4	main
on	doc_491521502255_item	2646216	et	4	main
väga	doc_491521502255_item	2646217	et	3	main
protestid	doc_491521502255_item	2646231	et	4	main
agressivset	doc_491521502255_item	2646233	et	4	main
hakkasid	doc_491521502255_item	2646237	et	4	main
looduskaitsjate	doc_491521502255_item	2646239	et	3	main
ajakirjanduse	doc_491521502257_item	2646405	et	3	main
üleminek	doc_491521502257_item	2646413	et	3	main
side	doc_491521502257_item	2646417	et	4	main
maailma	doc_491521502257_item	2646418	et	4	main
vaimueluga	doc_491521502257_item	2646419	et	3	main
suletud	doc_491521502257_item	2646422	et	4	main
organisatsioonid	doc_491521502257_item	2646424	et	3	main
algas	doc_491521502257_item	2646425	et	3	main
uute	doc_491521502257_item	2646426	et	3	main
laulev	doc_491521502257_item	2646430	et	4	main
oli	doc_491521502257_item	2646432	et	3	main
tundsid	doc_491521502257_item	2646442	et	4	main
et	doc_491521502257_item	2646443	et	3	main
süsteemi	doc_491521502257_item	2646447	et	4	main
vaimustas	doc_491521502257_item	2646450	et	3	main
ev	doc_491521502258_item	2646459	et	4	main
aegset	doc_491521502258_item	2646460	et	3	main
2	doc_491521502258_item	2646465	et	2	main
1	doc_491521502258_item	2646470	et	2	main
vabariigi	doc_491521502258_item	2646472	et	3	main
ajal	doc_491521502258_item	2646473	et	4	main
kultuuriline	doc_491521502258_item	2646474	et	4	main
kasv	doc_491521502258_item	2646475	et	3	main
oli	doc_491521502258_item	2646476	et	3	main
valitsesid	doc_491521502258_item	2646482	et	4	main
nüüd	doc_491521502258_item	2646483	et	4	main
maal	doc_491521502258_item	2646486	et	4	main
eesti	doc_491521502258_item	2646487	et	4	main
ja	doc_491521502258_item	2646496	et	3	main
kõikidel	doc_491521502258_item	2646502	et	4	main
oli	doc_491521502258_item	2646503	et	3	main
muutus	doc_491521502258_item	2646514	et	4	main
palju	doc_491521502258_item	2646519	et	4	main
haritlasi	doc_491521502258_item	2646520	et	3	main
inimesi	doc_491521502258_item	2646521	et	4	main
oli	doc_491521502258_item	2646527	et	3	main
õpetajate	doc_491521502258_item	2646529	et	4	main
selts	doc_491521502258_item	2646530	et	3	main
tegelevatele	doc_491521502258_item	2646544	et	4	main
suurt	doc_491521502258_item	2646547	et	3	main
püüdliketele	doc_491521502258_item	2646551	et	4	main
looduskaitsjad	doc_491521502255_item	2646222	et	3	main
selle	doc_491521502255_item	2646224	et	4	main
seda	doc_491521502255_item	2646236	et	3	main
ühingud	doc_491521502255_item	2646240	et	3	main
toimus	doc_491521502257_item	2646412	et	3	main
tänu	doc_491521502257_item	2646436	et	4	main
võim	doc_491521502257_item	2646446	et	3	main
ensv	doc_491521502258_item	2646462	et	4	main
sotsialistlik	doc_491521502258_item	2646466	et	3	main
küllatki	doc_491521502258_item	2646477	et	4	main
suur	doc_491521502258_item	2646478	et	3	main
pika	doc_491521502258_item	2646479	et	4	main
eestlased	doc_491521502258_item	2646484	et	3	main
omal	doc_491521502258_item	2646485	et	3	main
oma	doc_491521502258_item	2646493	et	4	main
teha	doc_491521502258_item	2646497	et	3	main
nüüd	doc_491521502258_item	2646504	et	4	main
võimalik	doc_491521502258_item	2646505	et	3	main
õpida	doc_491521502258_item	2646506	et	4	main
keeles	doc_491521502258_item	2646509	et	4	main
tollaste	doc_491521502258_item	2646523	et	3	main
kirjanike	doc_491521502258_item	2646531	et	3	main
teised	doc_491521502258_item	2646534	et	4	main
arenemisel	doc_491521502258_item	2646536	et	4	main
suurt	doc_491521502258_item	2646539	et	3	main
küllaltki	doc_491521502258_item	2646546	et	4	main
preemijaid	doc_491521502258_item	2646553	et	4	main
saadeti	doc_491521502258_item	2646555	et	3	main
õpima	doc_491521502258_item	2646557	et	4	main
kultuuri	doc_491521502258_item	2646561	et	4	main
arengut	doc_491521502258_item	2646562	et	3	main
väga	doc_491521502258_item	2646563	et	3	main
kontrolltöö	doc_491521502257_item	2646380	et	4	main
1	doc_491521502257_item	2646381	et	2	main
muutused	doc_491521502257_item	2646382	et	4	main
ja	doc_491521502257_item	2646383	et	3	main
muudatused	doc_491521502257_item	2646384	et	3	main
taasiseseisvunud	doc_491521502257_item	2646385	et	4	main
eesti	doc_491521502257_item	2646386	et	4	main
poliitilises	doc_491521502257_item	2646387	et	3	main
elus	doc_491521502257_item	2646388	et	4	main
2	doc_491521502257_item	2646389	et	2	main
mida	doc_491521502257_item	2646390	et	4	main
tähendab	doc_491521502257_item	2646391	et	3	main
laulev	doc_491521502257_item	2646392	et	4	main
revolutsioon	doc_491521502257_item	2646393	et	3	main
1	doc_491521502257_item	2646394	et	2	main
1990	doc_491521502257_item	2646395	et	2	main
a	doc_491521502257_item	2646396	et	4	main
toimusid	doc_491521502257_item	2646397	et	4	main
e	doc_491521502257_item	2646398	et	4	main
komiteedi	doc_491521502257_item	2646399	et	4	main
ja	doc_491521502257_item	2646400	et	3	main
e	doc_491521502257_item	2646401	et	4	main
ülemnõukogu	doc_491521502257_item	2646402	et	4	main
valimiskampaania	doc_491521502257_item	2646403	et	4	main
tekkimine	doc_491521502257_item	2646409	et	4	main
tõus	doc_491521502257_item	2646411	et	4	main
taastus	doc_491521502257_item	2646416	et	4	main
2	doc_491521502257_item	2646429	et	2	main
revolutsioon	doc_491521502257_item	2646431	et	3	main
sellele	doc_491521502257_item	2646437	et	4	main
aru	doc_491521502257_item	2646440	et	4	main
ühenduses	doc_491521502257_item	2646444	et	4	main
see	doc_491521502257_item	2646449	et	3	main
julgust	doc_491521502257_item	2646455	et	4	main
ja	doc_491521502258_item	2646461	et	3	main
kirjandusvool	doc_491521502258_item	2646469	et	4	main
aja	doc_491521502258_item	2646480	et	4	main
et	doc_491521502258_item	2646492	et	3	main
omapäraseks	doc_491521502258_item	2646499	et	4	main
haridust	doc_491521502258_item	2646501	et	4	main
koolisüsteem	doc_491521502258_item	2646510	et	3	main
õppimine	doc_491521502258_item	2646513	et	4	main
prestiižseks	doc_491521502258_item	2646515	et	2	main
eestis	doc_491521502258_item	2646516	et	3	main
oli	doc_491521502258_item	2646517	et	3	main
väga	doc_491521502258_item	2646518	et	3	main
ühisfirmade	doc_491521502257_item	2646408	et	3	main
isemajandamisele	doc_491521502257_item	2646414	et	3	main
taastati	doc_491521502257_item	2646421	et	4	main
loomine	doc_491521502257_item	2646428	et	4	main
väga	doc_491521502257_item	2646433	et	3	main
tähtis	doc_491521502257_item	2646434	et	4	main
inimesed	doc_491521502257_item	2646438	et	3	main
said	doc_491521502257_item	2646439	et	4	main
ja	doc_491521502257_item	2646441	et	3	main
vastu	doc_491521502257_item	2646448	et	3	main
pärastsõjajärgset	doc_491521502258_item	2646463	et	3	main
kui	doc_491521502258_item	2646468	et	3	main
eesti	doc_491521502258_item	2646471	et	4	main
jööksul	doc_491521502258_item	2646481	et	4	main
rahvas	doc_491521502258_item	2646488	et	4	main
püüdis	doc_491521502258_item	2646489	et	3	main
kultuuri	doc_491521502258_item	2646494	et	4	main
seda	doc_491521502258_item	2646498	et	3	main
arendadi	doc_491521502258_item	2646500	et	4	main
koolis	doc_491521502258_item	2646507	et	4	main
oli	doc_491521502258_item	2646511	et	3	main
kujunesid	doc_491521502258_item	2646525	et	4	main
ja	doc_491521502258_item	2646533	et	3	main
inimestele	doc_491521502258_item	2646545	et	3	main
ruumi	doc_491521502258_item	2646548	et	4	main
ja	doc_491521502258_item	2646554	et	3	main
välismaale	doc_491521502258_item	2646556	et	4	main
igatepidi	doc_491521502258_item	2646559	et	4	main
soodustas	doc_491521502258_item	2646560	et	3	main
tähtsateks	doc_491521502258_item	2646564	et	3	main
linnas	doc_491521502258_item	2646570	et	4	main
oli	doc_491521502258_item	2646616	et	3	main
aastal	doc_491521502258_item	2646624	et	3	main
oluliselt	doc_491521502258_item	2646628	et	4	main
ta	doc_491521502258_item	2646629	et	4	main
arenes	doc_491521502258_item	2646630	et	3	main
nõukogulike	doc_491521502258_item	2646631	et	3	main
kultuurmudeli	doc_491521502258_item	2646632	et	3	main
kõik	doc_491521502258_item	2646636	et	4	main
seltsid	doc_491521502258_item	2646637	et	4	main
eesti	doc_491521502258_item	2646651	et	4	main
ka	doc_491521502258_item	2646657	et	3	main
lapsi	doc_491521502258_item	2646666	et	4	main
töö-	doc_491521502258_item	2646667	et	4	main
maa	doc_491521502258_item	2646676	et	4	main
nüüd	doc_491521502258_item	2646680	et	4	main
nende	doc_491521502258_item	2646682	et	4	main
jaoks	doc_491521502258_item	2646683	et	4	main
ehitati	doc_491521502258_item	2646684	et	3	main
pansione	doc_491521502258_item	2646685	et	3	main
kirjanike	doc_491521502258_item	2646686	et	3	main
suur	doc_491521502258_item	2646695	et	3	main
sammud	doc_491521502258_item	2646721	et	4	main
hakkati	doc_491521502258_item	2646723	et	3	main
d	doc_491521502258_item	2646728	et	4	main
suund	doc_491521502258_item	2646730	et	3	main
tunnistatut	doc_491521502258_item	2646736	et	4	main
raamatuid	doc_491521502258_item	2646744	et	3	main
vähemaltki	doc_491521502258_item	2646746	et	4	main
vastu	doc_491521502258_item	2646751	et	3	main
1	doc_491521502259_item	2646754	et	2	main
1	doc_491521502259_item	2646767	et	2	main
loodi	doc_491521502259_item	2646770	et	4	main
raha	doc_491521502259_item	2646774	et	4	main
välispasside	doc_491521502259_item	2646781	et	3	main
headele	doc_491521502259_item	2646817	et	3	main
1953a	doc_491521502259_item	2646833	et	4	main
stalin	doc_491521502259_item	2646841	et	4	main
nõudis	doc_491521502259_item	2646842	et	3	main
vastu	doc_491521502259_item	2646850	et	3	main
vaesusest	doc_491521502259_item	2646853	et	4	main
tuua	doc_491521502259_item	2646855	et	3	main
algkooli	doc_491521502259_item	2646868	et	4	main
järgnes	doc_491521502259_item	2646869	et	3	main
5-klassiline	doc_491521502259_item	2646870	et	4	main
haruks	doc_491521502259_item	2646875	et	3	main
sõda	doc_491521502259_item	2646881	et	4	main
7-klassiline	doc_491521502259_item	2646884	et	4	main
algkool	doc_491521502259_item	2646885	et	4	main
riigi	doc_491521502259_item	2646886	et	3	main
kulul	doc_491521502259_item	2646887	et	4	main
seltsid	doc_491521502257_item	2646423	et	4	main
erakondade	doc_491521502257_item	2646427	et	3	main
sest	doc_491521502257_item	2646435	et	4	main
peitub	doc_491521502257_item	2646445	et	3	main
inimesi	doc_491521502257_item	2646451	et	4	main
ja	doc_491521502257_item	2646452	et	3	main
andis	doc_491521502257_item	2646453	et	3	main
neile	doc_491521502257_item	2646454	et	4	main
kontrolltöö	doc_491521502258_item	2646456	et	4	main
1	doc_491521502258_item	2646457	et	2	main
võrrelge	doc_491521502258_item	2646458	et	3	main
kultuurielu	doc_491521502258_item	2646464	et	4	main
realism	doc_491521502258_item	2646467	et	3	main
kõike	doc_491521502258_item	2646490	et	4	main
teha	doc_491521502258_item	2646491	et	3	main
arendada	doc_491521502258_item	2646495	et	3	main
eesti	doc_491521502258_item	2646508	et	4	main
3haruline	doc_491521502258_item	2646512	et	4	main
võrreldes	doc_491521502258_item	2646522	et	3	main
seltsid	doc_491521502258_item	2646526	et	4	main
loodut	doc_491521502258_item	2646528	et	4	main
liit	doc_491521502258_item	2646532	et	3	main
kultuuri	doc_491521502258_item	2646535	et	4	main
see	doc_491521502258_item	2646537	et	3	main
rolli	doc_491521502258_item	2646540	et	4	main
riik	doc_491521502258_item	2646541	et	3	main
andis	doc_491521502258_item	2646542	et	3	main
kultuuriga	doc_491521502258_item	2646543	et	4	main
tegutsemiseks	doc_491521502258_item	2646549	et	4	main
eriti	doc_491521502258_item	2646550	et	3	main
anti	doc_491521502258_item	2646552	et	3	main
teatred	doc_491521502258_item	2646568	et	4	main
keeleteadust	doc_491521502258_item	2646607	et	4	main
kutsuti	doc_491521502258_item	2646608	et	3	main
välismaalt	doc_491521502258_item	2646610	et	3	main
seadus	doc_491521502258_item	2646614	et	4	main
pisirahvastel	doc_491521502258_item	2646615	et	4	main
võimalik	doc_491521502258_item	2646618	et	3	main
muutus	doc_491521502258_item	2646625	et	4	main
kultuur	doc_491521502258_item	2646627	et	3	main
väljaanned	doc_491521502258_item	2646639	et	4	main
all	doc_491521502258_item	2646647	et	3	main
said	doc_491521502258_item	2646648	et	4	main
kannatada	doc_491521502258_item	2646649	et	3	main
ka	doc_491521502258_item	2646650	et	3	main
rikadest	doc_491521502258_item	2646659	et	4	main
ja	doc_491521502258_item	2646668	et	3	main
vaesematest	doc_491521502258_item	2646669	et	4	main
oli	doc_491521502258_item	2646672	et	3	main
hetki	doc_491521502258_item	2646675	et	4	main
õpida	doc_491521502258_item	2646679	et	4	main
ilukirjandusest	doc_491521502258_item	2646697	et	4	main
kirjanduses	doc_491521502258_item	2646722	et	3	main
kirjutama	doc_491521502258_item	2646724	et	3	main
kirjanikut	doc_491521502258_item	2646738	et	4	main
väga	doc_491521502258_item	2646740	et	3	main
tsensuur	doc_491521502258_item	2646742	et	3	main
oli	doc_491521502258_item	2646747	et	3	main
nõukogude	doc_491521502258_item	2646749	et	3	main
korra	doc_491521502258_item	2646750	et	4	main
kontrolltöö	doc_491521502259_item	2646753	et	4	main
kirjandusvool	doc_491521502259_item	2646766	et	4	main
tubakaaktsiisi	doc_491521502259_item	2646775	et	4	main
ka	doc_491521502259_item	2646778	et	3	main
ja	doc_491521502259_item	2646780	et	3	main
riigilõivu	doc_491521502259_item	2646782	et	4	main
auhinnaks	doc_491521502259_item	2646822	et	3	main
oli	doc_491521502259_item	2646824	et	3	main
tuli	doc_491521502259_item	2646829	et	4	main
jstalini	doc_491521502259_item	2646831	et	4	main
keelt	doc_491521502259_item	2646840	et	4	main
riigivaenlaste	doc_491521502259_item	2646847	et	3	main
otsustas	doc_491521502259_item	2646852	et	3	main
kaheastmeline	doc_491521502259_item	2646861	et	4	main
oli	doc_491521502259_item	2646863	et	3	main
kommertsharu	doc_491521502259_item	2646877	et	4	main
need	doc_491521502259_item	2646890	et	3	main
kel	doc_491521502259_item	2646891	et	3	main
see	doc_491521502259_item	2646892	et	3	main
enne	doc_491521502259_item	2646893	et	4	main
ning	doc_491521502259_item	2646924	et	3	main
muud	doc_491521502259_item	2646964	et	4	main
andvad	doc_491521502259_item	2646967	et	4	main
1925a	doc_491521502259_item	2646971	et	4	main
vastukultuurautonoomia	doc_491521502259_item	2646973	et	4	main
kõige	doc_491521502259_item	2646994	et	4	main
euroopaga	doc_491521502258_item	2646524	et	3	main
mängis	doc_491521502258_item	2646538	et	3	main
riik	doc_491521502258_item	2646558	et	3	main
ja	doc_491521502258_item	2646571	et	3	main
suurtemas	doc_491521502258_item	2646573	et	3	main
oli	doc_491521502258_item	2646575	et	3	main
oma	doc_491521502258_item	2646576	et	4	main
teater	doc_491521502258_item	2646577	et	3	main
rahvas	doc_491521502258_item	2646578	et	4	main
käis	doc_491521502258_item	2646579	et	4	main
palju	doc_491521502258_item	2646580	et	4	main
kinodes	doc_491521502258_item	2646581	et	3	main
teaduses	doc_491521502258_item	2646582	et	3	main
oli	doc_491521502258_item	2646583	et	3	main
märgata	doc_491521502258_item	2646584	et	4	main
ka	doc_491521502258_item	2646585	et	3	main
kasvu	doc_491521502258_item	2646586	et	4	main
kuigi	doc_491521502258_item	2646587	et	3	main
oli	doc_491521502258_item	2646588	et	3	main
palju	doc_491521502258_item	2646589	et	4	main
probleeme	doc_491521502258_item	2646590	et	3	main
riik	doc_491521502258_item	2646592	et	3	main
sest	doc_491521502258_item	2646591	et	4	main
oli	doc_491521502258_item	2646593	et	3	main
veel	doc_491521502258_item	2646594	et	4	main
noor	doc_491521502258_item	2646595	et	3	main
ja	doc_491521502258_item	2646596	et	3	main
oli	doc_491521502258_item	2646597	et	3	main
tunda	doc_491521502258_item	2646598	et	3	main
puudu	doc_491521502258_item	2646599	et	4	main
eesti	doc_491521502258_item	2646600	et	4	main
teadlastest	doc_491521502258_item	2646601	et	3	main
eesti	doc_491521502258_item	2646602	et	4	main
keelest	doc_491521502258_item	2646603	et	4	main
terminoloogiast	doc_491521502258_item	2646604	et	3	main
püüdi	doc_491521502258_item	2646605	et	4	main
arendada	doc_491521502258_item	2646606	et	3	main
said	doc_491521502258_item	2646565	et	4	main
kinod	doc_491521502258_item	2646566	et	3	main
ja	doc_491521502258_item	2646567	et	3	main
isegi	doc_491521502258_item	2646572	et	4	main
saada	doc_491521502258_item	2646619	et	4	main
haridust	doc_491521502258_item	2646620	et	4	main
keeles	doc_491521502258_item	2646622	et	4	main
olid	doc_491521502258_item	2646634	et	4	main
paljud	doc_491521502258_item	2646638	et	3	main
koolid	doc_491521502258_item	2646652	et	3	main
venestumis	doc_491521502258_item	2646653	et	4	main
oli	doc_491521502258_item	2646656	et	3	main
liidus	doc_491521502258_item	2646687	et	4	main
toimus	doc_491521502258_item	2646688	et	3	main
suur	doc_491521502258_item	2646689	et	3	main
puhastus	doc_491521502258_item	2646690	et	4	main
toimub	doc_491521502258_item	2646691	et	3	main
suur	doc_491521502258_item	2646692	et	3	main
raamatu	doc_491521502258_item	2646693	et	4	main
hävitamine	doc_491521502258_item	2646694	et	4	main
oli	doc_491521502258_item	2646698	et	3	main
kolhoodest	doc_491521502258_item	2646725	et	4	main
vaarandi	doc_491521502258_item	2646729	et	4	main
oli	doc_491521502258_item	2646731	et	3	main
helge	doc_491521502258_item	2646732	et	4	main
ei	doc_491521502258_item	2646735	et	4	main
negatiivset	doc_491521502258_item	2646737	et	3	main
kus	doc_491521502258_item	2646745	et	3	main
midagi	doc_491521502258_item	2646748	et	4	main
aastal	doc_491521502259_item	2646769	et	3	main
kultuurkapital	doc_491521502259_item	2646771	et	3	main
pealt	doc_491521502259_item	2646776	et	4	main
kultuurkapitali	doc_491521502259_item	2646784	et	4	main
hakati	doc_491521502259_item	2646816	et	3	main
talusid	doc_491521502259_item	2646819	et	4	main
jagama	doc_491521502259_item	2646820	et	3	main
saajaks	doc_491521502259_item	2646823	et	4	main
ajal	doc_491521502259_item	2646828	et	4	main
beria	doc_491521502259_item	2646835	et	4	main
kohalikku	doc_491521502259_item	2646839	et	4	main
beria	doc_491521502259_item	2646845	et	4	main
oli	doc_491521502259_item	2646846	et	3	main
hävitamise	doc_491521502259_item	2646849	et	4	main
välja	doc_491521502259_item	2646854	et	4	main
kolhoosikorra	doc_491521502259_item	2646856	et	3	main
ev	doc_491521502259_item	2646857	et	4	main
koolisüsteem	doc_491521502259_item	2646860	et	3	main
algkool	doc_491521502259_item	2646862	et	4	main
gümnaasium	doc_491521502259_item	2646871	et	3	main
mis	doc_491521502259_item	2646872	et	4	main
jagunes	doc_491521502259_item	2646873	et	3	main
humanitaarharu	doc_491521502259_item	2646876	et	4	main
reaalharu	doc_491521502259_item	2646879	et	4	main
aga	doc_491521502259_item	2646882	et	3	main
loodi	doc_491521502259_item	2646900	et	4	main
ülikoolini	doc_491521502259_item	2646929	et	4	main
kui	doc_491521502259_item	2646930	et	3	main
kirjanikke	doc_491521502259_item	2646935	et	3	main
hakati	doc_491521502259_item	2646939	et	3	main
nagu	doc_491521502259_item	2646944	et	3	main
nt	doc_491521502259_item	2646949	et	4	main
a	doc_491521502259_item	2646950	et	4	main
lauter	doc_491521502259_item	2646951	et	3	main
starkopf	doc_491521502259_item	2646954	et	4	main
kõrgemast	doc_491521502259_item	2646965	et	4	main
pallas	doc_491521502259_item	2646969	et	4	main
võeti	doc_491521502259_item	2646972	et	3	main
seadus	doc_491521502259_item	2646974	et	4	main
puudutas	doc_491521502259_item	2646976	et	3	main
eestis	doc_491521502259_item	2646977	et	3	main
elavaid	doc_491521502259_item	2646978	et	4	main
vähemusrahvaid	doc_491521502259_item	2646979	et	3	main
ajal	doc_491521502259_item	2646988	et	4	main
hävitada	doc_491521502259_item	2646999	et	3	main
omamine	doc_491521502259_item	2647025	et	4	main
keelati	doc_491521502259_item	2647026	et	4	main
vähesed	doc_491521502259_item	2647027	et	3	main
mingil	doc_491521502259_item	2647034	et	4	main
raamatud	doc_491521502259_item	2647038	et	4	main
mis	doc_491521502259_item	2647039	et	4	main
meil	doc_491521502259_item	2647047	et	4	main
igas	doc_491521502258_item	2646569	et	3	main
külades	doc_491521502258_item	2646574	et	3	main
spetsialiste	doc_491521502258_item	2646609	et	3	main
välja	doc_491521502258_item	2646612	et	4	main
väherahvuste	doc_491521502258_item	2646613	et	3	main
omas	doc_491521502258_item	2646621	et	4	main
keelatud	doc_491521502258_item	2646635	et	4	main
samuti	doc_491521502258_item	2646641	et	3	main
keelatud	doc_491521502258_item	2646642	et	4	main
kontrolli	doc_491521502258_item	2646646	et	4	main
poliitika	doc_491521502258_item	2646654	et	4	main
lastel	doc_491521502258_item	2646661	et	4	main
kooli	doc_491521502258_item	2646663	et	4	main
perekondadest	doc_491521502258_item	2646670	et	3	main
ka	doc_491521502258_item	2646673	et	3	main
said	doc_491521502258_item	2646678	et	4	main
linnas	doc_491521502258_item	2646681	et	4	main
tuli	doc_491521502258_item	2646611	et	4	main
nüüd	doc_491521502258_item	2646617	et	4	main
1945	doc_491521502258_item	2646623	et	2	main
eesti	doc_491521502258_item	2646626	et	4	main
järgi	doc_491521502258_item	2646633	et	4	main
olid	doc_491521502258_item	2646640	et	4	main
kõik	doc_491521502258_item	2646643	et	4	main
oli	doc_491521502258_item	2646644	et	3	main
riigi	doc_491521502258_item	2646645	et	3	main
raske	doc_491521502258_item	2646655	et	4	main
endistest	doc_491521502258_item	2646658	et	4	main
perekondadest	doc_491521502258_item	2646660	et	3	main
sest	doc_491521502258_item	2646662	et	4	main
võtmisel	doc_491521502258_item	2646664	et	4	main
eelistati	doc_491521502258_item	2646665	et	4	main
aga	doc_491521502258_item	2646671	et	3	main
häid	doc_491521502258_item	2646674	et	3	main
lapsed	doc_491521502258_item	2646677	et	3	main
osa	doc_491521502258_item	2646696	et	4	main
ära	doc_491521502258_item	2646699	et	4	main
põletatud	doc_491521502258_item	2646700	et	4	main
ideoloogiline	doc_491521502258_item	2646701	et	4	main
terror	doc_491521502258_item	2646702	et	3	main
oli	doc_491521502258_item	2646703	et	3	main
suur	doc_491521502258_item	2646704	et	3	main
keelati	doc_491521502258_item	2646705	et	4	main
voole	doc_491521502258_item	2646707	et	4	main
palju	doc_491521502258_item	2646706	et	4	main
eesti	doc_491521502258_item	2646708	et	4	main
kultuuri	doc_491521502258_item	2646709	et	4	main
arendamine	doc_491521502258_item	2646710	et	4	main
oli	doc_491521502258_item	2646711	et	3	main
tunduvalt	doc_491521502258_item	2646712	et	4	main
piiratud	doc_491521502258_item	2646713	et	4	main
võrreldes	doc_491521502258_item	2646714	et	3	main
ev	doc_491521502258_item	2646715	et	4	main
2	doc_491521502258_item	2646717	et	2	main
ajaga	doc_491521502258_item	2646716	et	3	main
sotsialistlik	doc_491521502258_item	2646718	et	3	main
realismjätis	doc_491521502258_item	2646719	et	4	main
tunduvad	doc_491521502258_item	2646720	et	4	main
tuleviku	doc_491521502258_item	2646733	et	4	main
oli	doc_491521502258_item	2646739	et	3	main
range	doc_491521502258_item	2646741	et	4	main
ev	doc_491521502259_item	2646756	et	4	main
aegset	doc_491521502259_item	2646757	et	3	main
ja	doc_491521502259_item	2646758	et	3	main
1925	doc_491521502259_item	2646768	et	2	main
mis	doc_491521502259_item	2646772	et	4	main
sai	doc_491521502259_item	2646773	et	4	main
samuti	doc_491521502259_item	2646777	et	3	main
prostitutsiooni	doc_491521502259_item	2646779	et	4	main
pealt	doc_491521502259_item	2646783	et	4	main
mälk	doc_491521502259_item	2646826	et	4	main
surma	doc_491521502259_item	2646832	et	4	main
kes	doc_491521502259_item	2646836	et	4	main
edutas	doc_491521502259_item	2646837	et	3	main
asjaajamiskeeleks	doc_491521502259_item	2646838	et	4	main
hüsteerilise	doc_491521502259_item	2646848	et	3	main
peale	doc_491521502259_item	2646867	et	4	main
pärast	doc_491521502259_item	2646880	et	4	main
kehtestati	doc_491521502259_item	2646883	et	3	main
ja	doc_491521502258_item	2646726	et	3	main
sovhoosidest	doc_491521502258_item	2646727	et	3	main
poole	doc_491521502258_item	2646734	et	4	main
need	doc_491521502258_item	2646743	et	3	main
hävitati	doc_491521502258_item	2646752	et	3	main
võrrelge	doc_491521502259_item	2646755	et	3	main
ensv	doc_491521502259_item	2646759	et	4	main
pärastsõjajärgset	doc_491521502259_item	2646760	et	3	main
kultuurielu	doc_491521502259_item	2646761	et	4	main
2	doc_491521502259_item	2646762	et	2	main
sotsialistlik	doc_491521502259_item	2646763	et	3	main
realism	doc_491521502259_item	2646764	et	3	main
kui	doc_491521502259_item	2646765	et	3	main
sihtkapitalideks	doc_491521502259_item	2646785	et	4	main
olid	doc_491521502259_item	2646786	et	4	main
kirjandus	doc_491521502259_item	2646787	et	3	main
helikunst	doc_491521502259_item	2646788	et	3	main
näitekirjandus	doc_491521502259_item	2646789	et	3	main
ajakirjandus	doc_491521502259_item	2646790	et	3	main
kujutav	doc_491521502259_item	2646791	et	4	main
kunst	doc_491521502259_item	2646792	et	3	main
ja	doc_491521502259_item	2646793	et	3	main
kehakultuur	doc_491521502259_item	2646794	et	3	main
1934	doc_491521502259_item	2646795	et	2	main
hakati	doc_491521502259_item	2646797	et	3	main
välja	doc_491521502259_item	2646798	et	4	main
aastast	doc_491521502259_item	2646796	et	4	main
andma	doc_491521502259_item	2646799	et	3	main
riigivanema	doc_491521502259_item	2646800	et	4	main
auhindu	doc_491521502259_item	2646801	et	4	main
kirjanduse	doc_491521502259_item	2646802	et	3	main
vallas	doc_491521502259_item	2646803	et	3	main
esimene	doc_491521502259_item	2646804	et	3	main
preemia	doc_491521502259_item	2646805	et	4	main
kuulus	doc_491521502259_item	2646806	et	4	main
ah	doc_491521502259_item	2646807	et	3	main
tammsaare	doc_491521502259_item	2646808	et	3	main
tõde	doc_491521502259_item	2646809	et	4	main
ja	doc_491521502259_item	2646810	et	3	main
õigus	doc_491521502259_item	2646811	et	4	main
kahele	doc_491521502259_item	2646812	et	4	main
viimasele	doc_491521502259_item	2646813	et	3	main
köitele	doc_491521502259_item	2646814	et	4	main
1937a	doc_491521502259_item	2646815	et	4	main
kirjanikele	doc_491521502259_item	2646818	et	3	main
esimeseks	doc_491521502259_item	2646821	et	3	main
albert	doc_491521502259_item	2646825	et	4	main
ensv	doc_491521502259_item	2646827	et	4	main
peale	doc_491521502259_item	2646830	et	4	main
võimule	doc_491521502259_item	2646834	et	3	main
vene	doc_491521502259_item	2646843	et	4	main
keelt	doc_491521502259_item	2646844	et	4	main
ning	doc_491521502259_item	2646851	et	3	main
ajal	doc_491521502259_item	2646858	et	4	main
oli	doc_491521502259_item	2646859	et	3	main
6-klassiline	doc_491521502259_item	2646864	et	4	main
ja	doc_491521502259_item	2646865	et	3	main
tasuta	doc_491521502259_item	2646866	et	4	main
kolmeks	doc_491521502259_item	2646874	et	4	main
ja	doc_491521502259_item	2646878	et	3	main
jätkasid	doc_491521502259_item	2646889	et	4	main
jaoks	doc_491521502259_item	2646899	et	4	main
internaatkoole	doc_491521502259_item	2646901	et	4	main
ülikoolis	doc_491521502259_item	2646902	et	4	main
hakati	doc_491521502259_item	2646903	et	3	main
ülistama	doc_491521502259_item	2646904	et	3	main
kehvikute	doc_491521502259_item	2646905	et	3	main
lapsi	doc_491521502259_item	2646906	et	4	main
jõukamad	doc_491521502259_item	2646907	et	4	main
jäeti	doc_491521502259_item	2646908	et	3	main
aga	doc_491521502259_item	2646909	et	3	main
ukse	doc_491521502259_item	2646910	et	3	main
taha	doc_491521502259_item	2646911	et	4	main
ev	doc_491521502259_item	2646912	et	4	main
ajal	doc_491521502259_item	2646913	et	4	main
olid	doc_491521502259_item	2646914	et	4	main
kaheks	doc_491521502259_item	2646915	et	4	main
suurimaks	doc_491521502259_item	2646916	et	4	main
saavutuseks	doc_491521502259_item	2646917	et	4	main
rahvuskultuuri	doc_491521502259_item	2646918	et	4	main
ja	doc_491521502259_item	2646919	et	3	main
rahvusteaduste	doc_491521502259_item	2646920	et	3	main
euroopa	doc_491521502259_item	2646922	et	4	main
haridussüsteemi	doc_491521502259_item	2646926	et	4	main
algkoolist	doc_491521502259_item	2646928	et	4	main
ajal	doc_491521502259_item	2646932	et	4	main
siis	doc_491521502259_item	2646936	et	3	main
neid	doc_491521502259_item	2646940	et	4	main
tõrjuma	doc_491521502259_item	2646942	et	3	main
ka	doc_491521502259_item	2646945	et	3	main
1919	doc_491521502259_item	2646955	et	2	main
lisaks	doc_491521502259_item	2646960	et	4	main
hakkasid	doc_491521502259_item	2646961	et	4	main
tegutsema	doc_491521502259_item	2646962	et	3	main
ka	doc_491521502259_item	2646963	et	3	main
ensv	doc_491521502259_item	2646980	et	4	main
hävitati	doc_491521502259_item	2646989	et	3	main
ev	doc_491521502259_item	2646990	et	4	main
aegseid	doc_491521502259_item	2646991	et	3	main
monumente	doc_491521502259_item	2646992	et	3	main
ning	doc_491521502259_item	2646993	et	3	main
rahva	doc_491521502259_item	2647000	et	3	main
ensv	doc_491521502259_item	2647022	et	4	main
inimesed	doc_491521502259_item	2647028	et	3	main
nõukogude	doc_491521502259_item	2647030	et	3	main
väike	doc_491521502259_item	2647049	et	4	main
kooliteed	doc_491521502259_item	2646888	et	4	main
sõda	doc_491521502259_item	2646894	et	4	main
pooleli	doc_491521502259_item	2646895	et	3	main
oli	doc_491521502259_item	2646896	et	3	main
jäänud	doc_491521502259_item	2646897	et	4	main
maalaste	doc_491521502259_item	2646898	et	4	main
väljaarendamine	doc_491521502259_item	2646921	et	3	main
ev	doc_491521502259_item	2646931	et	4	main
auhinnati	doc_491521502259_item	2646933	et	3	main
paljusid	doc_491521502259_item	2646934	et	3	main
ensv	doc_491521502259_item	2646937	et	4	main
kkleis	doc_491521502259_item	2646952	et	4	main
a	doc_491521502259_item	2646956	et	4	main
tü	doc_491521502259_item	2646958	et	4	main
millele	doc_491521502259_item	2646959	et	3	main
1918	doc_491521502259_item	2646970	et	2	main
mis	doc_491521502259_item	2646975	et	4	main
selle	doc_491521502259_item	2646995	et	4	main
eesmärgiks	doc_491521502259_item	2646996	et	3	main
oli	doc_491521502259_item	2646998	et	3	main
kuid	doc_491521502259_item	2647021	et	4	main
ajal	doc_491521502259_item	2647023	et	4	main
nende	doc_491521502259_item	2647024	et	4	main
korrale	doc_491521502259_item	2647031	et	3	main
suutsid	doc_491521502259_item	2647036	et	4	main
on	doc_491521502259_item	2647046	et	4	main
kirjandusteostest	doc_491521502259_item	2647053	et	3	main
estonia	doc_491521502259_item	2647056	et	4	main
teater	doc_491521502259_item	2647057	et	3	main
laulupeo	doc_491521502259_item	2647059	et	4	main
traditsioon	doc_491521502259_item	2647060	et	3	main
eesti	doc_491521502259_item	2647069	et	4	main
kirjanikud	doc_491521502259_item	2647070	et	3	main
hakati	doc_491521502259_item	2647074	et	3	main
e	doc_491521502259_item	2647082	et	4	main
mis	doc_491521502259_item	2647100	et	4	main
andma	doc_491521502259_item	2647106	et	3	main
stalini	doc_491521502259_item	2647107	et	4	main
ajal	doc_491521502259_item	2647125	et	4	main
hävitati	doc_491521502259_item	2647126	et	3	main
aegsed	doc_491521502259_item	2647128	et	3	main
alles	doc_491521502259_item	2647130	et	3	main
jääda	doc_491521502259_item	2647132	et	4	main
vaid	doc_491521502259_item	2647133	et	3	main
sotsialistliku	doc_491521502259_item	2647134	et	3	main
sisuga	doc_491521502259_item	2647135	et	3	main
teosed	doc_491521502259_item	2647136	et	3	main
väga	doc_491521502259_item	2647137	et	3	main
palju	doc_491521502259_item	2647138	et	4	main
kirjutati	doc_491521502259_item	2647139	et	3	main
olid	doc_491521502259_item	2647144	et	4	main
olema	doc_491521502259_item	2647154	et	4	main
inimeste	doc_491521502259_item	2647155	et	3	main
tasemele	doc_491521502259_item	2646923	et	3	main
emakeelse	doc_491521502259_item	2646925	et	3	main
andmine	doc_491521502259_item	2646927	et	4	main
ajal	doc_491521502259_item	2646938	et	4	main
välja	doc_491521502259_item	2646941	et	4	main
samamoodi	doc_491521502259_item	2646943	et	3	main
paljusid	doc_491521502259_item	2646946	et	3	main
muid	doc_491521502259_item	2646947	et	4	main
kultuuritegelasi	doc_491521502259_item	2646948	et	3	main
a	doc_491521502259_item	2646953	et	4	main
taasavati	doc_491521502259_item	2646957	et	3	main
haridust	doc_491521502259_item	2646966	et	4	main
koolid	doc_491521502259_item	2646968	et	3	main
ajal	doc_491521502259_item	2646981	et	4	main
hakati	doc_491521502259_item	2646982	et	3	main
raamatuid	doc_491521502259_item	2646983	et	3	main
hävitama	doc_491521502259_item	2646984	et	4	main
ja	doc_491521502259_item	2646985	et	3	main
keelustama	doc_491521502259_item	2646986	et	3	main
ensv	doc_491521502259_item	2646987	et	4	main
oli	doc_491521502259_item	2646997	et	3	main
kultuurimälu	doc_491521502259_item	2647001	et	4	main
seevastu	doc_491521502259_item	2647002	et	3	main
hakati	doc_491521502259_item	2647003	et	3	main
maanteede	doc_491521502259_item	2647004	et	3	main
äärtesse	doc_491521502259_item	2647005	et	3	main
paigutama	doc_491521502259_item	2647006	et	3	main
punaseid	doc_491521502259_item	2647007	et	4	main
kipsist	doc_491521502259_item	2647008	et	3	main
kujusid	doc_491521502259_item	2647009	et	3	main
linnadesse	doc_491521502259_item	2647010	et	3	main
pandi	doc_491521502259_item	2647011	et	4	main
üles	doc_491521502259_item	2647012	et	3	main
lenini	doc_491521502259_item	2647013	et	4	main
kujusid	doc_491521502259_item	2647014	et	3	main
ev	doc_491521502259_item	2647015	et	4	main
ajal	doc_491521502259_item	2647016	et	4	main
olid	doc_491521502259_item	2647017	et	4	main
raamatud	doc_491521502259_item	2647018	et	4	main
väga	doc_491521502259_item	2647019	et	3	main
hinnas	doc_491521502259_item	2647020	et	3	main
ning	doc_491521502259_item	2647033	et	3	main
moel	doc_491521502259_item	2647035	et	4	main
säilitada	doc_491521502259_item	2647037	et	3	main
tegelikult	doc_491521502259_item	2647040	et	4	main
suunatud	doc_491521502259_item	2647042	et	4	main
hävitamisele	doc_491521502259_item	2647043	et	4	main
tänu	doc_491521502259_item	2647044	et	4	main
neile	doc_491521502259_item	2647045	et	4	main
taastati	doc_491521502259_item	2647055	et	4	main
koondati	doc_491521502259_item	2647068	et	4	main
ajal	doc_491521502259_item	2647073	et	4	main
neid	doc_491521502259_item	2647083	et	4	main
sealt	doc_491521502259_item	2647084	et	4	main
likvideerima	doc_491521502259_item	2647085	et	3	main
praegune	doc_491521502259_item	2647086	et	3	main
2sotsialistlik	doc_491521502259_item	2647095	et	3	main
realism	doc_491521502259_item	2647096	et	3	main
kujutab	doc_491521502259_item	2647097	et	3	main
endast	doc_491521502259_item	2647098	et	4	main
välja	doc_491521502259_item	2647105	et	4	main
astusid	doc_491521502259_item	2647029	et	4	main
vastu	doc_491521502259_item	2647032	et	3	main
olid	doc_491521502259_item	2647041	et	4	main
praegu	doc_491521502259_item	2647048	et	3	main
tolle	doc_491521502259_item	2647051	et	4	main
aja	doc_491521502259_item	2647052	et	4	main
1947a	doc_491521502259_item	2647054	et	4	main
ja	doc_491521502259_item	2647058	et	3	main
1922	doc_491521502259_item	2647061	et	2	main
a	doc_491521502259_item	2647062	et	4	main
kuid	doc_491521502259_item	2647071	et	4	main
nii-öelda	doc_491521502259_item	2647079	et	3	main
1918a	doc_491521502259_item	2647088	et	4	main
ülistasid	doc_491521502259_item	2647101	et	4	main
maailmavaadet	doc_491521502259_item	2647103	et	3	main
preemiaid	doc_491521502259_item	2647108	et	3	main
sel	doc_491521502259_item	2647109	et	3	main
perioodil	doc_491521502259_item	2647110	et	3	main
oli	doc_491521502259_item	2647111	et	3	main
kirjanikuks	doc_491521502259_item	2647113	et	3	main
hans	doc_491521502259_item	2647114	et	4	main
tähtsaimaks	doc_491521502259_item	2647112	et	4	main
leberecht	doc_491521502259_item	2647115	et	4	main
kes	doc_491521502259_item	2647116	et	4	main
sai	doc_491521502259_item	2647117	et	4	main
ka	doc_491521502259_item	2647118	et	3	main
stalini	doc_491521502259_item	2647119	et	4	main
auhinna	doc_491521502259_item	2647120	et	3	main
valgus	doc_491521502259_item	2647121	et	4	main
eest	doc_491521502259_item	2647123	et	4	main
ev	doc_491521502259_item	2647127	et	4	main
loosungid	doc_491521502259_item	2647143	et	3	main
mis	doc_491521502259_item	2647147	et	4	main
teda	doc_491521502259_item	2647148	et	4	main
stalin	doc_491521502259_item	2647151	et	4	main
oli	doc_491521502259_item	2647152	et	3	main
armastasid	doc_491521502259_item	2647158	et	4	main
pidid	doc_491521502259_item	2647159	et	4	main
lapsed	doc_491521502259_item	2647160	et	3	main
vanurid	doc_491521502259_item	2647161	et	3	main
jne	doc_491521502259_item	2647162	et	4	main
aimdus	doc_491521502259_item	2647050	et	3	main
loodi	doc_491521502259_item	2647063	et	4	main
eesti	doc_491521502259_item	2647064	et	4	main
kirjanike	doc_491521502259_item	2647065	et	3	main
liit	doc_491521502259_item	2647066	et	3	main
kuhu	doc_491521502259_item	2647067	et	3	main
neid	doc_491521502259_item	2647075	et	4	main
sealt	doc_491521502259_item	2647077	et	4	main
ttü	doc_491521502259_item	2647087	et	4	main
kirjandusvoolu	doc_491521502259_item	2647099	et	4	main
hakati	doc_491521502259_item	2647104	et	3	main
ensv	doc_491521502259_item	2647072	et	4	main
kirjanikke	doc_491521502259_item	2647076	et	3	main
hoopiski	doc_491521502259_item	2647078	et	3	main
välja	doc_491521502259_item	2647080	et	4	main
koondama	doc_491521502259_item	2647081	et	3	main
kõrgem	doc_491521502259_item	2647089	et	4	main
kunstikool	doc_491521502259_item	2647090	et	4	main
1914	doc_491521502259_item	2647091	et	2	main
triiklik	doc_491521502259_item	2647092	et	4	main
konservatoorium	doc_491521502259_item	2647093	et	3	main
1923	doc_491521502259_item	2647094	et	2	main
sotsialistlikku	doc_491521502259_item	2647102	et	4	main
sel	doc_491521502259_item	2647124	et	3	main
stalini	doc_491521502259_item	2647140	et	4	main
ülistasid	doc_491521502259_item	2647149	et	4	main
keda	doc_491521502259_item	2647157	et	4	main
koordis	doc_491521502259_item	2647122	et	4	main
kirjandusteosed	doc_491521502259_item	2647129	et	3	main
võisid	doc_491521502259_item	2647131	et	4	main
laule	doc_491521502259_item	2647142	et	4	main
loodud	doc_491521502259_item	2647146	et	4	main
ühesõnaga	doc_491521502259_item	2647150	et	3	main
pidi	doc_491521502259_item	2647153	et	4	main
auks	doc_491521502259_item	2647141	et	3	main
temast	doc_491521502259_item	2647145	et	3	main
ideaal	doc_491521502259_item	2647156	et	3	main
ev	doc_491521502262_item	2647730	et	4	main
aegset	doc_491521502262_item	2647731	et	3	main
ja	doc_491521502262_item	2647732	et	3	main
kui	doc_491521502262_item	2647739	et	3	main
selleks	doc_491521502262_item	2647742	et	4	main
tollal	doc_491521502262_item	2647756	et	3	main
sellel	doc_491521502262_item	2647757	et	4	main
ajal	doc_491521502262_item	2647758	et	4	main
tegutsema	doc_491521502262_item	2647768	et	3	main
gaidid	doc_491521502262_item	2647779	et	3	main
et	doc_491521502262_item	2647816	et	3	main
ja	doc_491521502262_item	2647820	et	3	main
rahvateadus	doc_491521502262_item	2647821	et	4	main
euroopa	doc_491521502262_item	2647823	et	4	main
tasandil	doc_491521502262_item	2647824	et	3	main
võib	doc_491521502262_item	2647831	et	3	main
et	doc_491521502262_item	2647833	et	3	main
oli	doc_491521502262_item	2647835	et	3	main
teistsugune	doc_491521502262_item	2647837	et	3	main
õpetatud	doc_491521502262_item	2647845	et	4	main
kasvas	doc_491521502262_item	2647883	et	3	main
mitte	doc_491521502262_item	2647887	et	3	main
17	doc_491521502262_item	2647898	et	2	main
kõrgkoolides	doc_491521502262_item	2647907	et	3	main
ev	doc_491521502262_item	2647918	et	4	main
pleeniumi	doc_491521502262_item	2647925	et	4	main
hakati	doc_491521502262_item	2647928	et	3	main
ja	doc_491521502262_item	2647942	et	3	main
linnad	doc_491521502262_item	2647943	et	3	main
lühidalt	doc_491521502262_item	2647947	et	4	main
öelda	doc_491521502262_item	2647949	et	4	main
ajal	doc_491521502262_item	2647952	et	4	main
tehakse	doc_491521502262_item	2647953	et	3	main
kõik	doc_491521502262_item	2647954	et	4	main
mis	doc_491521502262_item	2647962	et	4	main
kontrolltöö	doc_491521502262_item	2647727	et	4	main
1	doc_491521502262_item	2647728	et	2	main
võrrelge	doc_491521502262_item	2647729	et	3	main
realism	doc_491521502262_item	2647738	et	3	main
pärastsõjajärjgset	doc_491521502262_item	2647749	et	4	main
vaadelda	doc_491521502262_item	2647752	et	4	main
hakkavad	doc_491521502262_item	2647766	et	4	main
maanaisteselts	doc_491521502262_item	2647777	et	3	main
kodutütred	doc_491521502262_item	2647781	et	3	main
sellel	doc_491521502262_item	2647817	et	4	main
rahvakultuur	doc_491521502262_item	2647819	et	3	main
sotsialistlik	doc_491521502262_item	2647737	et	3	main
1	doc_491521502262_item	2647741	et	2	main
võrrelda	doc_491521502262_item	2647744	et	4	main
ev	doc_491521502262_item	2647745	et	4	main
aegset	doc_491521502262_item	2647746	et	3	main
ja	doc_491521502262_item	2647747	et	3	main
tuleb	doc_491521502262_item	2647751	et	3	main
toimus	doc_491521502262_item	2647761	et	3	main
aktiivselt	doc_491521502262_item	2647767	et	4	main
skaudid	doc_491521502262_item	2647778	et	3	main
noorkotkad	doc_491521502262_item	2647780	et	3	main
ajaga	doc_491521502262_item	2647830	et	3	main
eesti	doc_491521502262_item	2647846	et	4	main
vallatamie	doc_491521502262_item	2647854	et	4	main
tuglas	doc_491521502262_item	2647856	et	4	main
raamatud	doc_491521502262_item	2647880	et	4	main
arv	doc_491521502262_item	2647882	et	3	main
populaarne	doc_491521502262_item	2647897	et	3	main
jätkasid	doc_491521502262_item	2647900	et	4	main
emakeelne	doc_491521502262_item	2647905	et	3	main
keeles	doc_491521502262_item	2647915	et	4	main
ensv	doc_491521502262_item	2647733	et	4	main
pärastsõjajärgset	doc_491521502262_item	2647734	et	3	main
ensv	doc_491521502262_item	2647748	et	4	main
mida	doc_491521502262_item	2647759	et	4	main
ev	doc_491521502262_item	2647763	et	4	main
ajal	doc_491521502262_item	2647764	et	4	main
esiteks	doc_491521502262_item	2647765	et	3	main
ja	doc_491521502262_item	2647771	et	3	main
liidud	doc_491521502262_item	2647772	et	3	main
kaitseliit	doc_491521502262_item	2647773	et	3	main
tuletõrjeselts	doc_491521502262_item	2647774	et	3	main
haridusselts	doc_491521502262_item	2647775	et	3	main
karskusselts	doc_491521502262_item	2647776	et	3	main
koonduvad	doc_491521502262_item	2647783	et	4	main
parastsõjajärgse	doc_491521502262_item	2647829	et	4	main
erinevaid	doc_491521502262_item	2647839	et	4	main
voole	doc_491521502262_item	2647840	et	4	main
selts	doc_491521502262_item	2647847	et	3	main
haritlasi	doc_491521502262_item	2647853	et	3	main
k	doc_491521502262_item	2647857	et	4	main
mehilas	doc_491521502262_item	2647858	et	4	main
visati	doc_491521502262_item	2647859	et	3	main
kirjaniku	doc_491521502262_item	2647860	et	3	main
uued	doc_491521502262_item	2647879	et	3	main
eestlastele	doc_491521502262_item	2647884	et	4	main
lugeda	doc_491521502262_item	2647886	et	3	main
meelelahutuseks	doc_491521502262_item	2647889	et	4	main
nad	doc_491521502262_item	2647890	et	3	main
õpingut	doc_491521502262_item	2647901	et	3	main
peeti	doc_491521502262_item	2647912	et	4	main
loenguid	doc_491521502262_item	2647913	et	4	main
a	doc_491521502262_item	2647927	et	4	main
kõrgkoole	doc_491521502262_item	2647930	et	4	main
ka	doc_491521502262_item	2647934	et	3	main
nimetatakse	doc_491521502262_item	2647939	et	3	main
kõik	doc_491521502262_item	2647940	et	4	main
tänavad	doc_491521502262_item	2647941	et	4	main
ümber	doc_491521502262_item	2647944	et	3	main
selles	doc_491521502262_item	2647955	et	4	main
et	doc_491521502262_item	2647956	et	3	main
rahva	doc_491521502262_item	2647958	et	3	main
saavutatud	doc_491521502262_item	2647964	et	4	main
ajal	doc_491521502262_item	2647966	et	4	main
ja	doc_491521502262_item	2647967	et	3	main
veel	doc_491521502262_item	2647968	et	4	main
õigus	doc_491521502262_item	2647973	et	4	main
nõukogude	doc_491521502262_item	2648009	et	3	main
sotsialistlik	doc_491521502262_item	2648010	et	3	main
realism	doc_491521502262_item	2648011	et	3	main
võib	doc_491521502262_item	2648012	et	3	main
arendada	doc_491521502262_item	2648013	et	3	main
ka	doc_491521502262_item	2648014	et	3	main
kultuurielu	doc_491521502262_item	2648015	et	4	main
need	doc_491521502262_item	2648026	et	3	main
sellest	doc_491521502262_item	2648032	et	4	main
et	doc_491521502262_item	2648033	et	3	main
ainult	doc_491521502262_item	2648043	et	4	main
kultuurielu	doc_491521502262_item	2647735	et	4	main
2	doc_491521502262_item	2647736	et	2	main
kirjandusvool	doc_491521502262_item	2647740	et	4	main
et	doc_491521502262_item	2647743	et	3	main
kultuurielu	doc_491521502262_item	2647750	et	4	main
milline	doc_491521502262_item	2647753	et	3	main
ta	doc_491521502262_item	2647754	et	4	main
oli	doc_491521502262_item	2647755	et	3	main
tähtsat	doc_491521502262_item	2647760	et	3	main
kultuurielus	doc_491521502262_item	2647762	et	4	main
erinevad	doc_491521502262_item	2647769	et	4	main
seltsid	doc_491521502262_item	2647770	et	4	main
nad	doc_491521502262_item	2647782	et	3	main
inimesi	doc_491521502262_item	2647785	et	4	main
kokku	doc_491521502262_item	2647786	et	3	main
harituid	doc_491521502262_item	2647784	et	4	main
ja	doc_491521502262_item	2647787	et	3	main
töötavad	doc_491521502262_item	2647788	et	4	main
kultuurielu	doc_491521502262_item	2647789	et	4	main
arenemiseks	doc_491521502262_item	2647790	et	4	main
valitsus	doc_491521502262_item	2647791	et	4	main
finantseeris	doc_491521502262_item	2647792	et	3	main
kultuurielu	doc_491521502262_item	2647793	et	4	main
kulus	doc_491521502262_item	2647794	et	4	main
selle	doc_491521502262_item	2647795	et	4	main
peale	doc_491521502262_item	2647796	et	4	main
palju	doc_491521502262_item	2647797	et	4	main
raha	doc_491521502262_item	2647798	et	4	main
kirjanikud	doc_491521502262_item	2647799	et	3	main
said	doc_491521502262_item	2647800	et	4	main
isegi	doc_491521502262_item	2647801	et	4	main
stipendiumit	doc_491521502262_item	2647802	et	3	main
ja	doc_491521502262_item	2647803	et	3	main
auhinda	doc_491521502262_item	2647804	et	4	main
esimene	doc_491521502262_item	2647805	et	3	main
oli	doc_491521502262_item	2647806	et	3	main
tammsaare	doc_491521502262_item	2647807	et	3	main
ja	doc_491521502262_item	2647809	et	3	main
õigus	doc_491521502262_item	2647810	et	4	main
areneb	doc_491521502262_item	2647811	et	3	main
ka	doc_491521502262_item	2647812	et	3	main
tõde	doc_491521502262_item	2647808	et	4	main
rahvusteadus	doc_491521502262_item	2647813	et	4	main
võib	doc_491521502262_item	2647814	et	3	main
öelda	doc_491521502262_item	2647815	et	4	main
ajal	doc_491521502262_item	2647818	et	4	main
võrrelda	doc_491521502262_item	2647826	et	4	main
situatsiooni	doc_491521502262_item	2647828	et	4	main
üldse	doc_491521502262_item	2647836	et	3	main
keelati	doc_491521502262_item	2647838	et	4	main
seltse	doc_491521502262_item	2647841	et	3	main
lammutati	doc_491521502262_item	2647842	et	3	main
likvideeriti	doc_491521502262_item	2647843	et	3	main
nt	doc_491521502262_item	2647844	et	4	main
akadeemiline	doc_491521502262_item	2647848	et	3	main
selts	doc_491521502262_item	2647850	et	3	main
massiline	doc_491521502262_item	2647852	et	4	main
ajal	doc_491521502262_item	2647875	et	4	main
oli	doc_491521502262_item	2647876	et	3	main
vastupidi	doc_491521502262_item	2647877	et	3	main
raamatukogude	doc_491521502262_item	2647881	et	3	main
oli	doc_491521502262_item	2647896	et	3	main
kõrgkoolides	doc_491521502262_item	2647902	et	3	main
arenes	doc_491521502262_item	2647904	et	3	main
tartu	doc_491521502262_item	2647908	et	4	main
kunsti	doc_491521502262_item	2647910	et	4	main
kõrgkoolis	doc_491521502262_item	2647911	et	4	main
oli	doc_491521502262_item	2647917	et	3	main
on	doc_491521502262_item	2647822	et	4	main
kui	doc_491521502262_item	2647825	et	3	main
seda	doc_491521502262_item	2647827	et	3	main
öelda	doc_491521502262_item	2647832	et	4	main
pilt	doc_491521502262_item	2647834	et	3	main
rahvaluule	doc_491521502262_item	2647849	et	4	main
hakkas	doc_491521502262_item	2647851	et	3	main
f	doc_491521502262_item	2647855	et	4	main
liidust	doc_491521502262_item	2647861	et	4	main
välja	doc_491521502262_item	2647862	et	4	main
paljud	doc_491521502262_item	2647863	et	3	main
raamatud	doc_491521502262_item	2647864	et	4	main
olid	doc_491521502262_item	2647865	et	4	main
keelatud	doc_491521502262_item	2647866	et	4	main
ja	doc_491521502262_item	2647867	et	3	main
üldse	doc_491521502262_item	2647868	et	3	main
hävitatud	doc_491521502262_item	2647869	et	4	main
nt	doc_491521502262_item	2647870	et	4	main
nimed	doc_491521502262_item	2647871	et	3	main
marmortahvlil	doc_491521502262_item	2647872	et	3	main
keelatud	doc_491521502262_item	2647873	et	4	main
ev	doc_491521502262_item	2647874	et	4	main
kirjutati	doc_491521502262_item	2647878	et	3	main
meeldis	doc_491521502262_item	2647885	et	3	main
ainult	doc_491521502262_item	2647888	et	4	main
tahtsid	doc_491521502262_item	2647891	et	4	main
õppida	doc_491521502262_item	2647892	et	3	main
haridus	doc_491521502262_item	2647893	et	3	main
ka	doc_491521502262_item	2647894	et	3	main
kõrgharidus	doc_491521502262_item	2647895	et	3	main
õpilastest	doc_491521502262_item	2647899	et	4	main
aktiivselt	doc_491521502262_item	2647903	et	4	main
haridus	doc_491521502262_item	2647906	et	3	main
ülikoolis	doc_491521502262_item	2647909	et	4	main
eesti	doc_491521502262_item	2647914	et	4	main
jaoks	doc_491521502262_item	2647919	et	4	main
saavutus	doc_491521502262_item	2647921	et	4	main
märtsi	doc_491521502262_item	2647924	et	4	main
häivitatakse	doc_491521502262_item	2647933	et	4	main
ev	doc_491521502262_item	2647935	et	4	main
peale	doc_491521502262_item	2647937	et	4	main
riigisümboolika	doc_491521502262_item	2647946	et	4	main
nõukogude	doc_491521502262_item	2647951	et	3	main
häivitada	doc_491521502262_item	2647960	et	4	main
sead	doc_491521502262_item	2647961	et	4	main
inimestel	doc_491521502262_item	2647971	et	3	main
oli	doc_491521502262_item	2648018	et	3	main
see	doc_491521502262_item	2647916	et	3	main
suur	doc_491521502262_item	2647920	et	3	main
1950	doc_491521502262_item	2647926	et	2	main
likvideeruma	doc_491521502262_item	2647929	et	3	main
ja	doc_491521502262_item	2647931	et	3	main
instituute	doc_491521502262_item	2647932	et	3	main
monumente	doc_491521502262_item	2647936	et	3	main
kultuurimälu	doc_491521502262_item	2647959	et	4	main
ajal	doc_491521502262_item	2647970	et	4	main
oli	doc_491521502262_item	2647972	et	3	main
kirikus	doc_491521502262_item	2647976	et	3	main
ta	doc_491521502262_item	2647978	et	4	main
kogu	doc_491521502262_item	2648016	et	4	main
lubatud	doc_491521502262_item	2648024	et	4	main
range	doc_491521502262_item	2648041	et	4	main
saab	doc_491521502262_item	2648047	et	3	main
helde	doc_491521502262_item	2648049	et	4	main
need	doc_491521502262_item	2648050	et	3	main
raamatud	doc_491521502262_item	2648051	et	4	main
teised	doc_491521502262_item	2648055	et	4	main
kahjuks	doc_491521502262_item	2647922	et	4	main
parast	doc_491521502262_item	2647923	et	3	main
selle	doc_491521502262_item	2647938	et	4	main
vahetub	doc_491521502262_item	2647945	et	3	main
võiks	doc_491521502262_item	2647948	et	4	main
et	doc_491521502262_item	2647950	et	3	main
häivitada	doc_491521502262_item	2647957	et	4	main
ev	doc_491521502262_item	2647965	et	4	main
käia	doc_491521502262_item	2647974	et	4	main
tahab	doc_491521502262_item	2647979	et	3	main
ja	doc_491521502262_item	2647980	et	3	main
uskuda	doc_491521502262_item	2647981	et	3	main
seda	doc_491521502262_item	2647982	et	3	main
mida	doc_491521502262_item	2647983	et	4	main
ta	doc_491521502262_item	2647984	et	4	main
tahab	doc_491521502262_item	2647985	et	3	main
kiriku	doc_491521502262_item	2647986	et	3	main
traditsioonid	doc_491521502262_item	2647987	et	3	main
olid	doc_491521502262_item	2647988	et	4	main
tähtsad	doc_491521502262_item	2647990	et	3	main
nõukogude	doc_491521502262_item	2647991	et	3	main
ajal	doc_491521502262_item	2647992	et	4	main
väga	doc_491521502262_item	2647989	et	3	main
palju	doc_491521502262_item	2647993	et	4	main
tähtsamaks	doc_491521502262_item	2647994	et	4	main
muutusid	doc_491521502262_item	2647995	et	4	main
uued	doc_491521502262_item	2647996	et	3	main
ilmalikud	doc_491521502262_item	2647997	et	3	main
trasitsioonid	doc_491521502262_item	2647998	et	4	main
kombed	doc_491521502262_item	2647999	et	3	main
nt	doc_491521502262_item	2648000	et	4	main
sünnipäeva	doc_491521502262_item	2648001	et	4	main
pidamine	doc_491521502262_item	2648002	et	4	main
ii	doc_491521502262_item	2648003	et	4	main
aastate	doc_491521502262_item	2648005	et	3	main
lõpus	doc_491521502262_item	2648006	et	4	main
1940-ndate	doc_491521502262_item	2648004	et	4	main
usuti	doc_491521502262_item	2648007	et	3	main
et	doc_491521502262_item	2648008	et	3	main
oli	doc_491521502262_item	2647963	et	3	main
ev	doc_491521502262_item	2647969	et	4	main
selles	doc_491521502262_item	2647975	et	4	main
milles	doc_491521502262_item	2647977	et	3	main
kirjandus	doc_491521502262_item	2648017	et	3	main
ramatud	doc_491521502262_item	2648027	et	4	main
kiideti	doc_491521502262_item	2648029	et	3	main
kirjutati	doc_491521502262_item	2648031	et	3	main
igal	doc_491521502262_item	2648036	et	3	main
oli	doc_491521502262_item	2648052	et	3	main
sellel	doc_491521502262_item	2648019	et	4	main
ajal	doc_491521502262_item	2648020	et	4	main
sotsiolismi	doc_491521502262_item	2648021	et	4	main
old	doc_491521502262_item	2648025	et	4	main
kus	doc_491521502262_item	2648028	et	3	main
sotsiolismi	doc_491521502262_item	2648030	et	4	main
peab	doc_491521502262_item	2648035	et	4	main
olema	doc_491521502262_item	2648038	et	4	main
kord	doc_491521502262_item	2648039	et	4	main
sotsialostlik	doc_491521502262_item	2648040	et	4	main
inimeste	doc_491521502262_item	2648045	et	3	main
tulevik	doc_491521502262_item	2648046	et	3	main
olid	doc_491521502262_item	2648056	et	4	main
tsensuuriga	doc_491521502262_item	2648057	et	3	main
keelatud	doc_491521502262_item	2648058	et	4	main
ideed	doc_491521502262_item	2648022	et	4	main
täis	doc_491521502262_item	2648023	et	4	main
elus	doc_491521502262_item	2648034	et	4	main
pool	doc_491521502262_item	2648037	et	4	main
kord	doc_491521502262_item	2648042	et	4	main
siis	doc_491521502262_item	2648044	et	3	main
olla	doc_491521502262_item	2648048	et	3	main
lubatud	doc_491521502262_item	2648053	et	4	main
lugeda	doc_491521502262_item	2648054	et	3	main
kirjandusvool	doc_491521502264_item	2648645	et	4	main
1	doc_491521502264_item	2648646	et	2	main
kui	doc_491521502264_item	2648650	et	3	main
ajal	doc_491521502264_item	2648654	et	4	main
hakkas	doc_491521502264_item	2648656	et	3	main
arenema	doc_491521502264_item	2648658	et	3	main
selleks	doc_491521502264_item	2648661	et	4	main
olid	doc_491521502264_item	2648662	et	4	main
arenes	doc_491521502264_item	2648677	et	3	main
vabalt	doc_491521502264_item	2648679	et	4	main
ja	doc_491521502264_item	2648680	et	3	main
riik	doc_491521502264_item	2648681	et	3	main
enam	doc_491521502264_item	2648684	et	4	main
nõudmisi	doc_491521502264_item	2648686	et	4	main
ajal	doc_491521502264_item	2648688	et	4	main
sõja	doc_491521502264_item	2648689	et	3	main
üle	doc_491521502264_item	2648699	et	3	main
elanud	doc_491521502264_item	2648703	et	4	main
sõja	doc_491521502264_item	2648704	et	3	main
ajal	doc_491521502264_item	2648705	et	4	main
end	doc_491521502264_item	2648714	et	4	main
ajal	doc_491521502264_item	2648717	et	4	main
ajal	doc_491521502264_item	2648724	et	4	main
see	doc_491521502264_item	2648730	et	3	main
nii	doc_491521502264_item	2648647	et	3	main
kiiremini	doc_491521502264_item	2648657	et	4	main
põhjused	doc_491521502264_item	2648660	et	3	main
õnnelikud	doc_491521502264_item	2648693	et	3	main
inimesed	doc_491521502264_item	2648701	et	3	main
kunsti-	doc_491521502264_item	2648706	et	4	main
ja	doc_491521502264_item	2648707	et	3	main
haridusjanus	doc_491521502264_item	2648708	et	3	main
nad	doc_491521502264_item	2648709	et	3	main
väljendada	doc_491521502264_item	2648715	et	3	main
ja	doc_491521502264_item	2648725	et	3	main
oli	doc_491521502264_item	2648727	et	3	main
sõjaga	doc_491521502264_item	2648729	et	3	main
hariduse	doc_491521502264_item	2648733	et	3	main
taastamist	doc_491521502264_item	2648736	et	4	main
nt	doc_491521502264_item	2648737	et	4	main
tööd	doc_491521502264_item	2648743	et	4	main
kõrgel	doc_491521502264_item	2648753	et	4	main
tasemel	doc_491521502264_item	2648754	et	3	main
pärast	doc_491521502264_item	2648772	et	4	main
raamatukogud	doc_491521502264_item	2648775	et	3	main
ev	doc_491521502264_item	2648779	et	4	main
peeti	doc_491521502264_item	2648805	et	4	main
estonia	doc_491521502264_item	2648813	et	4	main
oli	doc_491521502264_item	2648822	et	3	main
aja	doc_491521502264_item	2648829	et	4	main
kirjanikud	doc_491521502264_item	2648833	et	3	main
kultuuri	doc_491521502264_item	2648838	et	4	main
ideoloogiline	doc_491521502264_item	2648847	et	4	main
terror	doc_491521502264_item	2648848	et	3	main
sai	doc_491521502264_item	2648858	et	4	main
suureks	doc_491521502264_item	2648859	et	4	main
kontrolltöö	doc_491521502264_item	2648632	et	4	main
ev	doc_491521502264_item	2648635	et	4	main
aegset	doc_491521502264_item	2648636	et	3	main
ajal	doc_491521502264_item	2648649	et	4	main
ensv	doc_491521502264_item	2648652	et	4	main
vaid	doc_491521502264_item	2648659	et	3	main
esitanud	doc_491521502264_item	2648683	et	4	main
ensv	doc_491521502264_item	2648687	et	4	main
pärast	doc_491521502264_item	2648690	et	4	main
inimesed	doc_491521502264_item	2648691	et	3	main
sest	doc_491521502264_item	2648700	et	4	main
olid	doc_491521502264_item	2648702	et	4	main
arenemine	doc_491521502264_item	2648720	et	4	main
võrrelge	doc_491521502264_item	2648634	et	3	main
ja	doc_491521502264_item	2648637	et	3	main
ev	doc_491521502264_item	2648648	et	4	main
pärastsõjajärgsel	doc_491521502264_item	2648653	et	3	main
kultuur	doc_491521502264_item	2648655	et	3	main
ideoloogilisi	doc_491521502264_item	2648685	et	4	main
olid	doc_491521502264_item	2648692	et	4	main
sõja	doc_491521502264_item	2648695	et	3	main
ja	doc_491521502264_item	2648697	et	3	main
ellujäämise	doc_491521502264_item	2648698	et	4	main
olid	doc_491521502264_item	2648710	et	4	main
õnnelikud	doc_491521502264_item	2648711	et	3	main
võimalust	doc_491521502264_item	2648713	et	3	main
mis	doc_491521502264_item	2648721	et	4	main
ev	doc_491521502264_item	2648723	et	4	main
katkestatud	doc_491521502264_item	2648728	et	4	main
vana	doc_491521502264_item	2648747	et	4	main
kaadri	doc_491521502264_item	2648748	et	3	main
õpetajad	doc_491521502264_item	2648749	et	4	main
sai	doc_491521502264_item	2648769	et	4	main
klassivõitlus	doc_491521502264_item	2648770	et	3	main
sõja	doc_491521502264_item	2648771	et	3	main
töötasid	doc_491521502264_item	2648777	et	4	main
jätkas	doc_491521502264_item	2648781	et	3	main
sai	doc_491521502264_item	2648789	et	4	main
samuti	doc_491521502264_item	2648799	et	3	main
ajal	doc_491521502264_item	2648801	et	4	main
1923	doc_491521502264_item	2648803	et	2	main
aastast	doc_491521502264_item	2648804	et	4	main
ka	doc_491521502264_item	2648817	et	3	main
huvi	doc_491521502264_item	2648824	et	4	main
seas	doc_491521502264_item	2648826	et	4	main
teadlased	doc_491521502264_item	2648830	et	3	main
jätkasid	doc_491521502264_item	2648834	et	4	main
tööd	doc_491521502264_item	2648836	et	4	main
eesti	doc_491521502264_item	2648837	et	4	main
vaatamata	doc_491521502264_item	2648849	et	4	main
sellele	doc_491521502264_item	2648850	et	4	main
et	doc_491521502264_item	2648851	et	3	main
eesti	doc_491521502264_item	2648852	et	4	main
vaimult	doc_491521502264_item	2648860	et	4	main
nagu	doc_491521502264_item	2648865	et	3	main
see	doc_491521502264_item	2648867	et	3	main
võimalik	doc_491521502264_item	2648868	et	3	main
sotsialistlik	doc_491521502264_item	2648870	et	3	main
kirjanduses	doc_491521502264_item	2648879	et	3	main
peegeldasid	doc_491521502264_item	2648883	et	4	main
tolleaegse	doc_491521502264_item	2648921	et	3	main
missugused	doc_491521502266_item	2649069	et	3	main
arvates	doc_491521502266_item	2649088	et	4	main
1	doc_491521502264_item	2648633	et	2	main
ensv	doc_491521502264_item	2648638	et	4	main
pärastsõjajärgset	doc_491521502264_item	2648639	et	3	main
kultuurielu	doc_491521502264_item	2648640	et	4	main
2	doc_491521502264_item	2648641	et	2	main
sotsialistlik	doc_491521502264_item	2648642	et	3	main
realism	doc_491521502264_item	2648643	et	3	main
kui	doc_491521502264_item	2648644	et	3	main
ka	doc_491521502264_item	2648651	et	3	main
erinevad	doc_491521502264_item	2648663	et	4	main
ev	doc_491521502264_item	2648664	et	4	main
aegse	doc_491521502264_item	2648665	et	3	main
kultuuri	doc_491521502264_item	2648666	et	4	main
arenemise	doc_491521502264_item	2648667	et	4	main
põhjuseks	doc_491521502264_item	2648668	et	3	main
sai	doc_491521502264_item	2648669	et	4	main
kõigepealt	doc_491521502264_item	2648670	et	3	main
vene	doc_491521502264_item	2648671	et	4	main
ja	doc_491521502264_item	2648672	et	3	main
saksa	doc_491521502264_item	2648673	et	4	main
mõjust	doc_491521502264_item	2648674	et	3	main
vabanemine	doc_491521502264_item	2648675	et	4	main
kultuur	doc_491521502264_item	2648676	et	3	main
nüüd	doc_491521502264_item	2648678	et	4	main
ei	doc_491521502264_item	2648682	et	4	main
kõigepealt	doc_491521502264_item	2648694	et	3	main
lõpu	doc_491521502264_item	2648696	et	3	main
saada	doc_491521502264_item	2648712	et	4	main
ensv	doc_491521502264_item	2648716	et	4	main
jätkus	doc_491521502264_item	2648718	et	4	main
kultuurielu	doc_491521502264_item	2648719	et	4	main
algas	doc_491521502264_item	2648722	et	3	main
mis	doc_491521502264_item	2648726	et	4	main
ensv	doc_491521502264_item	2648738	et	4	main
ajal	doc_491521502264_item	2648739	et	4	main
koolides	doc_491521502264_item	2648740	et	3	main
kogemustega	doc_491521502264_item	2648744	et	3	main
õppetöö	doc_491521502264_item	2648752	et	4	main
ajal	doc_491521502264_item	2648780	et	4	main
näitemängu	doc_491521502264_item	2648784	et	4	main
rahvatants	doc_491521502264_item	2648790	et	3	main
rahva	doc_491521502264_item	2648791	et	3	main
entusiasmi	doc_491521502264_item	2648792	et	4	main
tulemuseks	doc_491521502264_item	2648793	et	3	main
sai	doc_491521502264_item	2648796	et	4	main
iga	doc_491521502264_item	2648806	et	4	main
viie	doc_491521502264_item	2648807	et	3	main
aasta	doc_491521502264_item	2648808	et	4	main
tagant	doc_491521502264_item	2648809	et	3	main
1947	doc_491521502264_item	2648811	et	2	main
hakkasid	doc_491521502264_item	2648815	et	4	main
teised	doc_491521502264_item	2648818	et	4	main
nende	doc_491521502264_item	2648820	et	4	main
rahvase	doc_491521502264_item	2648825	et	4	main
paljud	doc_491521502264_item	2648827	et	3	main
loomuliku	doc_491521502264_item	2648839	et	3	main
võimu	doc_491521502264_item	2648843	et	4	main
ideoloogilised	doc_491521502264_item	2648844	et	4	main
arendas	doc_491521502264_item	2648862	et	3	main
ilmus	doc_491521502264_item	2648877	et	4	main
ka	doc_491521502264_item	2648884	et	3	main
kirjanikud	doc_491521502264_item	2648887	et	3	main
elu	doc_491521502264_item	2648923	et	4	main
põhjust	doc_491521502266_item	2649074	et	4	main
laiuse	doc_491521502266_item	2649083	et	4	main
mängufilm	doc_491521502266_item	2649084	et	3	main
eksport	doc_491521502266_item	2649123	et	3	main
jt	doc_491521502266_item	2649126	et	4	main
tooteid	doc_491521502266_item	2649148	et	4	main
mida	doc_491521502266_item	2649153	et	4	main
erisoodustuse	doc_491521502266_item	2649155	et	3	main
alusel	doc_491521502266_item	2649156	et	4	main
tuusikud	doc_491521502266_item	2649157	et	3	main
kultuurilised	doc_491521502266_item	2649158	et	4	main
soome	doc_491521502266_item	2649159	et	3	main
ja	doc_491521502266_item	2649169	et	3	main
tooteid	doc_491521502266_item	2649181	et	4	main
ja	doc_491521502266_item	2649182	et	3	main
eesti	doc_491521502266_item	2649191	et	4	main
laulukonkursid	doc_491521502266_item	2649194	et	3	main
entel-tentel	doc_491521502266_item	2649195	et	4	main
ette	doc_491521502266_item	2649199	et	4	main
noortele	doc_491521502266_item	2649200	et	3	main
tähendas	doc_491521502264_item	2648731	et	3	main
ja	doc_491521502264_item	2648734	et	3	main
teaduse	doc_491521502264_item	2648735	et	3	main
oma	doc_491521502264_item	2648742	et	4	main
ev	doc_491521502264_item	2648745	et	4	main
aja	doc_491521502264_item	2648746	et	4	main
eks	doc_491521502264_item	2648750	et	3	main
hoidsid	doc_491521502264_item	2648751	et	4	main
kuid	doc_491521502264_item	2648755	et	4	main
probleemid	doc_491521502264_item	2648756	et	3	main
olid	doc_491521502264_item	2648757	et	4	main
erinevad	doc_491521502264_item	2648758	et	4	main
nõukogude	doc_491521502264_item	2648759	et	3	main
võim	doc_491521502264_item	2648760	et	3	main
avaldas	doc_491521502264_item	2648761	et	3	main
oma	doc_491521502264_item	2648762	et	4	main
rahvakultuuri	doc_491521502264_item	2648732	et	4	main
jätkasid	doc_491521502264_item	2648741	et	4	main
mõju	doc_491521502264_item	2648763	et	4	main
ensv	doc_491521502264_item	2648765	et	4	main
ajal	doc_491521502264_item	2648766	et	4	main
probleemiks	doc_491521502264_item	2648767	et	4	main
koolides	doc_491521502264_item	2648768	et	3	main
mis	doc_491521502264_item	2648776	et	4	main
ensv	doc_491521502264_item	2648794	et	4	main
üldlaulupidu	doc_491521502264_item	2648797	et	4	main
ev	doc_491521502264_item	2648800	et	4	main
alates	doc_491521502264_item	2648802	et	3	main
laulupidu	doc_491521502264_item	2648810	et	4	main
teatri	doc_491521502264_item	2648812	et	3	main
tegutsema	doc_491521502264_item	2648816	et	3	main
teatrid	doc_491521502264_item	2648819	et	3	main
suur	doc_491521502264_item	2648823	et	3	main
haritlased	doc_491521502264_item	2648831	et	3	main
arenemist	doc_491521502264_item	2648840	et	4	main
katkestasid	doc_491521502264_item	2648841	et	4	main
nõukogude	doc_491521502264_item	2648842	et	3	main
nõudmised	doc_491521502264_item	2648845	et	4	main
kunsti	doc_491521502264_item	2648875	et	4	main
see	doc_491521502264_item	2648876	et	3	main
poliitilised	doc_491521502264_item	2648881	et	3	main
kirjanduses	doc_491521502264_item	2648885	et	3	main
ei	doc_491521502264_item	2648888	et	4	main
ja	doc_491521502264_item	2648764	et	3	main
taasavasid	doc_491521502264_item	2648773	et	4	main
rahvamajad	doc_491521502264_item	2648774	et	3	main
juba	doc_491521502264_item	2648778	et	3	main
pilli-	doc_491521502264_item	2648782	et	4	main
ja	doc_491521502264_item	2648783	et	3	main
ning	doc_491521502264_item	2648785	et	3	main
laulukooride	doc_491521502264_item	2648786	et	3	main
traditsioon	doc_491521502264_item	2648787	et	3	main
populaarseks	doc_491521502264_item	2648788	et	4	main
ajal	doc_491521502264_item	2648795	et	4	main
1947	doc_491521502264_item	2648798	et	2	main
taasavamine	doc_491521502264_item	2648814	et	4	main
vastu	doc_491521502264_item	2648821	et	3	main
ev	doc_491521502264_item	2648828	et	4	main
ja	doc_491521502264_item	2648832	et	3	main
oma	doc_491521502264_item	2648835	et	4	main
sõda	doc_491521502264_item	2648846	et	4	main
rahvas	doc_491521502264_item	2648853	et	4	main
polnud	doc_491521502264_item	2648854	et	3	main
suur	doc_491521502264_item	2648855	et	3	main
arvult	doc_491521502264_item	2648856	et	3	main
see	doc_491521502264_item	2648857	et	3	main
ja	doc_491521502264_item	2648861	et	3	main
kultuuri	doc_491521502264_item	2648864	et	4	main
oli	doc_491521502264_item	2648866	et	3	main
2	doc_491521502264_item	2648869	et	2	main
riigikord	doc_491521502264_item	2648871	et	3	main
ka	doc_491521502264_item	2648878	et	3	main
saanud	doc_491521502264_item	2648889	et	4	main
kirjutada	doc_491521502264_item	2648890	et	3	main
millest	doc_491521502264_item	2648891	et	3	main
tahtsid	doc_491521502264_item	2648892	et	4	main
kirjanikud	doc_491521502264_item	2648893	et	3	main
kes	doc_491521502264_item	2648894	et	4	main
kritiseerisid	doc_491521502264_item	2648895	et	4	main
riigikorda	doc_491521502264_item	2648896	et	4	main
ja	doc_491521502264_item	2648897	et	3	main
võimu	doc_491521502264_item	2648898	et	4	main
olid	doc_491521502264_item	2648899	et	4	main
keelatud	doc_491521502264_item	2648900	et	4	main
range	doc_491521502264_item	2648901	et	4	main
tsensuur	doc_491521502264_item	2648902	et	3	main
oli	doc_491521502264_item	2648903	et	3	main
kõikjal	doc_491521502264_item	2648904	et	3	main
romantilised	doc_491521502264_item	2648905	et	3	main
lood	doc_491521502264_item	2648906	et	4	main
polnud	doc_491521502264_item	2648907	et	3	main
väga	doc_491521502264_item	2648908	et	3	main
populaarsed	doc_491521502264_item	2648909	et	3	main
tol	doc_491521502264_item	2648910	et	3	main
ajal	doc_491521502264_item	2648911	et	4	main
populaarne	doc_491521502264_item	2648912	et	3	main
oli	doc_491521502264_item	2648913	et	3	main
kõik	doc_491521502264_item	2648914	et	4	main
mis	doc_491521502264_item	2648915	et	4	main
oli	doc_491521502264_item	2648916	et	3	main
seotud	doc_491521502264_item	2648917	et	4	main
poliitikaga	doc_491521502264_item	2648918	et	3	main
mis	doc_491521502264_item	2648919	et	4	main
puutus	doc_491521502264_item	2648920	et	4	main
inimese	doc_491521502264_item	2648922	et	4	main
oma	doc_491521502264_item	2648863	et	4	main
mõjus	doc_491521502264_item	2648872	et	4	main
tunduvalt	doc_491521502264_item	2648873	et	4	main
ka	doc_491521502264_item	2648874	et	3	main
paljud	doc_491521502264_item	2648880	et	3	main
sündmused	doc_491521502264_item	2648882	et	3	main
tolleaegsed	doc_491521502264_item	2648886	et	3	main
kontrolltöö	doc_491521502266_item	2649067	et	4	main
eesti	doc_491521502266_item	2649075	et	4	main
l	doc_491521502266_item	2649082	et	4	main
kalevi	doc_491521502266_item	2649124	et	3	main
toodangut	doc_491521502266_item	2649129	et	3	main
läände	doc_491521502266_item	2649130	et	3	main
n	doc_491521502266_item	2649131	et	4	main
soodustas	doc_491521502266_item	2649134	et	3	main
tv	doc_491521502266_item	2649160	et	4	main
tallinna	doc_491521502266_item	2649161	et	4	main
ümbruses	doc_491521502266_item	2649162	et	3	main
sealt	doc_491521502266_item	2649163	et	4	main
vaadati	doc_491521502266_item	2649164	et	3	main
kuidas	doc_491521502266_item	2649165	et	3	main
elatakse	doc_491521502266_item	2649166	et	3	main
kapitalismi	doc_491521502266_item	2649167	et	4	main
tingimustes	doc_491521502266_item	2649168	et	3	main
kultuurielus	doc_491521502266_item	2649175	et	4	main
mujal	doc_491521502266_item	2649184	et	3	main
reklaamfilm	doc_491521502266_item	2649192	et	3	main
horoskoop	doc_491521502266_item	2649203	et	3	main
lapsed	doc_491521502266_item	2649222	et	3	main
ise	doc_491521502266_item	2649224	et	4	main
televiktoriinid	doc_491521502266_item	2649229	et	3	main
hääl	doc_491521502266_item	2649232	et	3	main
tsenseeritud	doc_491521502266_item	2649247	et	4	main
laulude	doc_491521502266_item	2649253	et	3	main
õnnestunud	doc_491521502266_item	2649265	et	4	main
läänekultuuri	doc_491521502266_item	2649269	et	4	main
tema	doc_491521502266_item	2649295	et	4	main
vihaga	doc_491521502266_item	2649302	et	4	main
pime	doc_491521502266_item	2649310	et	3	main
ja	doc_491521502266_item	2649312	et	3	main
hirm	doc_491521502266_item	2649313	et	3	main
ka	doc_491521502266_item	2649323	et	3	main
1	doc_491521502266_item	2649068	et	2	main
majanduslikud-kultuurilised	doc_491521502266_item	2649070	et	4	main
tegurid	doc_491521502266_item	2649071	et	3	main
nsvi	doc_491521502266_item	2649076	et	4	main
tunda	doc_491521502266_item	2649077	et	3	main
end	doc_491521502266_item	2649078	et	4	main
2	doc_491521502266_item	2649081	et	2	main
kas	doc_491521502266_item	2649086	et	3	main
kommivabrik	doc_491521502266_item	2649125	et	3	main
eksportisid	doc_491521502266_item	2649127	et	4	main
oma	doc_491521502266_item	2649128	et	4	main
igasuguse	doc_491521502266_item	2649135	et	3	main
osta	doc_491521502266_item	2649147	et	4	main
köögitehnika	doc_491521502266_item	2649151	et	4	main
õpiti	doc_491521502266_item	2649170	et	3	main
suurt	doc_491521502266_item	2649173	et	3	main
n	doc_491521502266_item	2649185	et	4	main
v	doc_491521502266_item	2649201	et	4	main
levimuusikasaade	doc_491521502266_item	2649202	et	4	main
kus	doc_491521502266_item	2649204	et	3	main
ka	doc_491521502266_item	2649206	et	3	main
hunt	doc_491521502266_item	2649215	et	3	main
andsid	doc_491521502266_item	2649072	et	4	main
1970ndatel	doc_491521502266_item	2649073	et	4	main
nsvl	doc_491521502266_item	2649079	et	4	main
lähisvälismaana	doc_491521502266_item	2649080	et	3	main
libahunt	doc_491521502266_item	2649085	et	3	main
teie	doc_491521502266_item	2649087	et	4	main
ajaloodokument	doc_491521502266_item	2649089	et	3	main
või	doc_491521502266_item	2649090	et	4	main
ühiskonnakriitika	doc_491521502266_item	2649091	et	4	main
miks	doc_491521502266_item	2649092	et	4	main
1	doc_491521502266_item	2649093	et	2	main
majanduslikud	doc_491521502266_item	2649094	et	3	main
turism	doc_491521502266_item	2649095	et	3	main
ehitati	doc_491521502266_item	2649096	et	3	main
viru	doc_491521502266_item	2649097	et	4	main
hotell	doc_491521502266_item	2649098	et	3	main
soome	doc_491521502266_item	2649099	et	3	main
turistide	doc_491521502266_item	2649100	et	3	main
jaoks	doc_491521502266_item	2649101	et	4	main
valuutapoed	doc_491521502266_item	2649102	et	3	main
võis	doc_491521502266_item	2649104	et	4	main
kust	doc_491521502266_item	2649103	et	4	main
osta	doc_491521502266_item	2649105	et	4	main
välismaiseid	doc_491521502266_item	2649106	et	4	main
kaupu	doc_491521502266_item	2649107	et	3	main
uku	doc_491521502266_item	2649108	et	4	main
poed	doc_491521502266_item	2649109	et	4	main
käsitöö	doc_491521502266_item	2649110	et	4	main
ja	doc_491521502266_item	2649111	et	3	main
suveniirid	doc_491521502266_item	2649112	et	3	main
turistid	doc_491521502266_item	2649113	et	3	main
omakorda	doc_491521502266_item	2649114	et	3	main
tõid	doc_491521502266_item	2649115	et	4	main
sisse	doc_491521502266_item	2649116	et	4	main
välismaa	doc_491521502266_item	2649117	et	4	main
kaupu	doc_491521502266_item	2649118	et	3	main
mida	doc_491521502266_item	2649119	et	4	main
meilt	doc_491521502266_item	2649120	et	3	main
kohapeal	doc_491521502266_item	2649121	et	3	main
turism	doc_491521502266_item	2649133	et	3	main
tootmist	doc_491521502266_item	2649137	et	4	main
norra	doc_491521502266_item	2649139	et	4	main
osteti	doc_491521502266_item	2649122	et	3	main
liitu	doc_491521502266_item	2649132	et	4	main
pudi-padi	doc_491521502266_item	2649136	et	3	main
nt	doc_491521502266_item	2649138	et	4	main
märgid	doc_491521502266_item	2649140	et	4	main
see	doc_491521502266_item	2649141	et	3	main
suurendas	doc_491521502266_item	2649142	et	3	main
oma	doc_491521502266_item	2649143	et	4	main
elanikkonna	doc_491521502266_item	2649144	et	3	main
sissetulekut	doc_491521502266_item	2649145	et	3	main
võimalus	doc_491521502266_item	2649146	et	3	main
luksuskaubad	doc_491521502266_item	2649150	et	3	main
mööbel	doc_491521502266_item	2649152	et	3	main
etv	doc_491521502266_item	2649171	et	4	main
mida	doc_491521502266_item	2649183	et	4	main
liidus	doc_491521502266_item	2649186	et	4	main
ei	doc_491521502266_item	2649187	et	4	main
olnud	doc_491521502266_item	2649188	et	4	main
firma	doc_491521502266_item	2649190	et	4	main
v	doc_491521502266_item	2649193	et	4	main
lastele	doc_491521502266_item	2649196	et	4	main
välismaiseid	doc_491521502266_item	2649207	et	4	main
hitte	doc_491521502266_item	2649208	et	3	main
mida	doc_491521502266_item	2649209	et	4	main
vaatajad	doc_491521502266_item	2649210	et	4	main
hindasid	doc_491521502266_item	2649211	et	4	main
v	doc_491521502266_item	2649212	et	4	main
lastesaated	doc_491521502266_item	2649213	et	3	main
nukulavastused	doc_491521502266_item	2649214	et	3	main
kriimsilm	doc_491521502266_item	2649216	et	3	main
tipp	doc_491521502266_item	2649217	et	3	main
ja	doc_491521502266_item	2649218	et	3	main
täpp	doc_491521502266_item	2649219	et	3	main
jt	doc_491521502266_item	2649220	et	4	main
telekoolid	doc_491521502266_item	2649228	et	3	main
raadiosaated	doc_491521502266_item	2649230	et	3	main
esimene	doc_491521502266_item	2649234	et	3	main
n	doc_491521502266_item	2649236	et	4	main
donald	doc_491521502266_item	2649241	et	4	main
soome	doc_491521502266_item	2649242	et	3	main
keelest	doc_491521502266_item	2649243	et	4	main
kujul	doc_491521502266_item	2649248	et	4	main
ja	doc_491521502266_item	2649251	et	3	main
ei	doc_491521502266_item	2649264	et	4	main
üle	doc_491521502266_item	2649268	et	3	main
kritiseerib	doc_491521502266_item	2649292	et	3	main
inimest	doc_491521502266_item	2649294	et	3	main
sõnast	doc_491521502266_item	2649304	et	4	main
et	doc_491521502266_item	2649305	et	3	main
teine	doc_491521502266_item	2649306	et	3	main
hävitada	doc_491521502266_item	2649308	et	3	main
mahategemist	doc_491521502266_item	2649329	et	3	main
neile	doc_491521502266_item	2649333	et	4	main
südamerahu	doc_491521502266_item	2649335	et	4	main
tagasi	doc_491521502266_item	2649336	et	3	main
paremasse	doc_491521502266_item	2649339	et	4	main
valgusesse	doc_491521502266_item	2649340	et	4	main
kadedus	doc_491521502266_item	2649348	et	4	main
samas	doc_491521502266_item	2649352	et	4	main
mis	doc_491521502266_item	2649355	et	4	main
võõrasse	doc_491521502266_item	2649359	et	4	main
vii	doc_491521502266_item	2649369	et	4	main
äärmuslike	doc_491521502266_item	2649370	et	3	main
lahti	doc_491521502266_item	2649373	et	4	main
ühiskonnas	doc_491521502266_item	2649376	et	4	main
sellist	doc_491521502266_item	2649377	et	4	main
enam	doc_491521502266_item	2649380	et	4	main
järelmaksuga	doc_491521502266_item	2649149	et	3	main
sai	doc_491521502266_item	2649154	et	4	main
mängis	doc_491521502266_item	2649172	et	3	main
rolli	doc_491521502266_item	2649174	et	4	main
v	doc_491521502266_item	2649176	et	4	main
reklaamisaated	doc_491521502266_item	2649177	et	3	main
mis	doc_491521502266_item	2649178	et	4	main
tutvustasid	doc_491521502266_item	2649179	et	4	main
uusi	doc_491521502266_item	2649180	et	3	main
reklaamiklubi	doc_491521502266_item	2649189	et	4	main
kaks	doc_491521502266_item	2649197	et	3	main
takti	doc_491521502266_item	2649198	et	4	main
lasti	doc_491521502266_item	2649205	et	4	main
said	doc_491521502266_item	2649223	et	4	main
v	doc_491521502266_item	2649227	et	4	main
kirjandus	doc_491521502266_item	2649233	et	3	main
koomiks	doc_491521502266_item	2649235	et	3	main
liidus	doc_491521502266_item	2649237	et	4	main
ilmus	doc_491521502266_item	2649238	et	4	main
eestis	doc_491521502266_item	2649239	et	3	main
piilupart	doc_491521502266_item	2649240	et	4	main
jätkamine	doc_491521502266_item	2649250	et	4	main
esitamine	doc_491521502266_item	2649254	et	4	main
protestivaim	doc_491521502266_item	2649260	et	3	main
mille	doc_491521502266_item	2649261	et	3	main
loodud	doc_491521502266_item	2649296	et	4	main
käituma	doc_491521502266_item	2649321	et	3	main
inimese	doc_491521502266_item	2649327	et	4	main
õnnetust	doc_491521502266_item	2649328	et	4	main
endile	doc_491521502266_item	2649334	et	4	main
ja	doc_491521502266_item	2649338	et	3	main
välja	doc_491521502266_item	2649345	et	4	main
viha	doc_491521502266_item	2649350	et	4	main
kokkukuuluvustunne	doc_491521502266_item	2649354	et	3	main
puutub	doc_491521502266_item	2649356	et	3	main
eestlaste	doc_491521502266_item	2649378	et	4	main
silma	doc_491521502266_item	2649381	et	4	main
ei	doc_491521502266_item	2649382	et	4	main
saata	doc_491521502266_item	2649226	et	3	main
rahvalike	doc_491521502266_item	2649252	et	3	main
tsensuuri	doc_491521502266_item	2649255	et	4	main
üldine	doc_491521502266_item	2649257	et	4	main
ja	doc_491521502266_item	2649259	et	3	main
tõttu	doc_491521502266_item	2649262	et	4	main
venestuspoliitika	doc_491521502266_item	2649263	et	4	main
võeti	doc_491521502266_item	2649267	et	3	main
2	doc_491521502266_item	2649270	et	2	main
libahunt	doc_491521502266_item	2649271	et	3	main
on	doc_491521502266_item	2649272	et	4	main
minu	doc_491521502266_item	2649273	et	3	main
meelest	doc_491521502266_item	2649274	et	4	main
nii	doc_491521502266_item	2649275	et	3	main
ajaloodokument	doc_491521502266_item	2649276	et	3	main
kui	doc_491521502266_item	2649277	et	3	main
ühiskonnakriitika	doc_491521502266_item	2649278	et	4	main
ühelt	doc_491521502266_item	2649279	et	3	main
poolt	doc_491521502266_item	2649280	et	4	main
nõiaprotsessid	doc_491521502266_item	2649281	et	3	main
on	doc_491521502266_item	2649282	et	4	main
ajalooline	doc_491521502266_item	2649283	et	4	main
sündmus	doc_491521502266_item	2649284	et	3	main
samuti	doc_491521502266_item	2649285	et	3	main
kajastub	doc_491521502266_item	2649286	et	3	main
eesti	doc_491521502266_item	2649287	et	4	main
talurahva	doc_491521502266_item	2649288	et	3	main
teiselt	doc_491521502266_item	2649290	et	4	main
eluolu	doc_491521502266_item	2649289	et	4	main
poolt	doc_491521502266_item	2649291	et	4	main
kuhu	doc_491521502266_item	2649221	et	3	main
kirju	doc_491521502266_item	2649225	et	4	main
ameerika	doc_491521502266_item	2649231	et	3	main
tõlgitud	doc_491521502266_item	2649244	et	4	main
avameelselt	doc_491521502266_item	2649245	et	4	main
abielust	doc_491521502266_item	2649246	et	3	main
laulupeotraditsiooni	doc_491521502266_item	2649249	et	4	main
kiuste	doc_491521502266_item	2649256	et	4	main
rahvustunnetus	doc_491521502266_item	2649258	et	3	main
rohkem	doc_491521502266_item	2649266	et	4	main
öeldud	doc_491521502266_item	2649303	et	4	main
inimene	doc_491521502266_item	2649307	et	3	main
viha	doc_491521502266_item	2649311	et	4	main
samas	doc_491521502266_item	2649322	et	4	main
teise	doc_491521502266_item	2649326	et	4	main
kui	doc_491521502266_item	2649331	et	3	main
see	doc_491521502266_item	2649332	et	3	main
annab	doc_491521502266_item	2649337	et	3	main
filmis	doc_491521502266_item	2649342	et	4	main
tuleb	doc_491521502266_item	2649343	et	3	main
igiomane	doc_491521502266_item	2649347	et	3	main
ka	doc_491521502266_item	2649353	et	3	main
teistsugusesse	doc_491521502266_item	2649357	et	4	main
viimane	doc_491521502266_item	2649360	et	3	main
meelest	doc_491521502266_item	2649363	et	4	main
abinõudeni	doc_491521502266_item	2649371	et	4	main
paista	doc_491521502266_item	2649383	et	4	main
nagu	doc_491521502266_item	2649384	et	3	main
nõukogude	doc_491521502266_item	2649385	et	3	main
libahunt	doc_491521502266_item	2649293	et	3	main
keskkonda	doc_491521502266_item	2649297	et	4	main
süsteemi	doc_491521502266_item	2649298	et	4	main
suhtumist	doc_491521502266_item	2649299	et	4	main
piisab	doc_491521502266_item	2649300	et	3	main
ühestainsast	doc_491521502266_item	2649301	et	3	main
inimeste	doc_491521502266_item	2649309	et	3	main
kõige	doc_491521502266_item	2649314	et	4	main
erineva	doc_491521502266_item	2649315	et	4	main
teistsuguse	doc_491521502266_item	2649316	et	3	main
vastu	doc_491521502266_item	2649317	et	3	main
paneb	doc_491521502266_item	2649318	et	3	main
neid	doc_491521502266_item	2649319	et	4	main
mõtlematult	doc_491521502266_item	2649320	et	4	main
inimesed	doc_491521502266_item	2649324	et	3	main
hävitamist	doc_491521502266_item	2649330	et	4	main
seab	doc_491521502266_item	2649341	et	3	main
selgesti	doc_491521502266_item	2649344	et	3	main
ja	doc_491521502266_item	2649349	et	3	main
ja	doc_491521502266_item	2649358	et	3	main
minu	doc_491521502266_item	2649362	et	3	main
positiivne	doc_491521502266_item	2649364	et	3	main
omadus	doc_491521502266_item	2649365	et	4	main
ajal	doc_491521502266_item	2649386	et	4	main
taasiseseisvumise	doc_491521502266_item	2649388	et	3	main
lootuses	doc_491521502266_item	2649389	et	4	main
naudivad	doc_491521502266_item	2649325	et	3	main
eestlaste	doc_491521502266_item	2649346	et	4	main
aga	doc_491521502266_item	2649351	et	3	main
on	doc_491521502266_item	2649361	et	4	main
kui	doc_491521502266_item	2649366	et	3	main
see	doc_491521502266_item	2649367	et	3	main
ei	doc_491521502266_item	2649368	et	4	main
võõrast	doc_491521502266_item	2649372	et	4	main
saamiseks	doc_491521502266_item	2649374	et	4	main
praeguses	doc_491521502266_item	2649375	et	3	main
kokkukuuluvust	doc_491521502266_item	2649379	et	4	main
või	doc_491521502266_item	2649387	et	4	main
majanduslikud-kultuurilised	doc_491521502269_item	2649834	et	4	main
põhjust	doc_491521502269_item	2649838	et	4	main
nsvl	doc_491521502269_item	2649843	et	4	main
2	doc_491521502269_item	2649845	et	2	main
mängufilm	doc_491521502269_item	2649848	et	3	main
libahunt	doc_491521502269_item	2649849	et	3	main
teie	doc_491521502269_item	2649851	et	4	main
arvates	doc_491521502269_item	2649852	et	4	main
1	doc_491521502269_item	2649857	et	2	main
kes	doc_491521502269_item	2649867	et	4	main
end	doc_491521502269_item	2649842	et	4	main
l	doc_491521502269_item	2649846	et	4	main
või	doc_491521502269_item	2649854	et	4	main
inimesi	doc_491521502269_item	2649866	et	4	main
olnud	doc_491521502269_item	2649872	et	4	main
1	doc_491521502269_item	2649832	et	2	main
andsid	doc_491521502269_item	2649836	et	4	main
eesti	doc_491521502269_item	2649839	et	4	main
ajaloodokument	doc_491521502269_item	2649853	et	3	main
räägitakse	doc_491521502269_item	2649859	et	3	main
pärast	doc_491521502269_item	2649862	et	4	main
sõda	doc_491521502269_item	2649863	et	4	main
oli	doc_491521502269_item	2649864	et	3	main
vähe	doc_491521502269_item	2649865	et	3	main
traditsiooni	doc_491521502269_item	2649874	et	4	main
80ndate	doc_491521502269_item	2649875	et	4	main
erisoodustus	doc_491521502269_item	2649922	et	3	main
sportlastel	doc_491521502269_item	2649933	et	4	main
loengud	doc_491521502269_item	2649940	et	3	main
kestma	doc_491521502269_item	2649942	et	3	main
tugevalt	doc_491521502269_item	2649952	et	4	main
televisiooni	doc_491521502269_item	2649984	et	4	main
käib	doc_491521502269_item	2649996	et	3	main
välismaalased	doc_491521502269_item	2650000	et	3	main
eestisse	doc_491521502269_item	2650002	et	4	main
maalapsed	doc_491521502269_item	2650005	et	3	main
kolisid	doc_491521502269_item	2650010	et	4	main
oma	doc_491521502269_item	2650022	et	4	main
nagu	doc_491521502269_item	2650028	et	3	main
majanduslikud-kultuurilised	doc_491521502270_item	2650037	et	4	main
kas	doc_491521502270_item	2650053	et	3	main
1	doc_491521502270_item	2650060	et	2	main
ei	doc_491521502270_item	2650062	et	4	main
pealt	doc_491521502270_item	2650070	et	4	main
etv-d	doc_491521502270_item	2650074	et	4	main
läänelike	doc_491521502270_item	2650077	et	4	main
oli	doc_491521502270_item	2650086	et	3	main
kõrgkoolides	doc_491521502270_item	2650121	et	3	main
eesti	doc_491521502270_item	2650138	et	4	main
artistid	doc_491521502270_item	2650139	et	3	main
venemaal	doc_491521502270_item	2650143	et	4	main
oma	doc_491521502270_item	2650146	et	4	main
läänest	doc_491521502270_item	2650151	et	4	main
eesti	doc_491521502270_item	2650158	et	4	main
filmis	doc_491521502270_item	2650166	et	4	main
heideti	doc_491521502270_item	2650167	et	3	main
sama	doc_491521502270_item	2650175	et	4	main
kust	doc_491521502270_item	2650180	et	4	main
ignoreeriti	doc_491521502270_item	2650188	et	3	main
nsvl	doc_491521502270_item	2650199	et	4	main
väljatõrjumise	doc_491521502270_item	2650203	et	3	main
on	doc_491521502270_item	2650205	et	4	main
on	doc_491521502270_item	2650209	et	4	main
arvati	doc_491521502270_item	2650215	et	4	main
neil	doc_491521502270_item	2650219	et	4	main
kontrolltöö	doc_491521502269_item	2649831	et	4	main
missugused	doc_491521502269_item	2649833	et	3	main
tegurid	doc_491521502269_item	2649835	et	3	main
nsvi	doc_491521502269_item	2649840	et	4	main
lähisvälismaana	doc_491521502269_item	2649844	et	3	main
laiuse	doc_491521502269_item	2649847	et	4	main
kas	doc_491521502269_item	2649850	et	3	main
miks	doc_491521502269_item	2649856	et	4	main
sellest	doc_491521502269_item	2649858	et	4	main
suhteliselt	doc_491521502269_item	2649860	et	4	main
vähe	doc_491521502269_item	2649861	et	3	main
oskasid	doc_491521502269_item	2649868	et	4	main
pille	doc_491521502269_item	2649869	et	3	main
mängida	doc_491521502269_item	2649870	et	3	main
folkloori	doc_491521502269_item	2649879	et	4	main
ülikoolides	doc_491521502269_item	2649880	et	3	main
olid	doc_491521502269_item	2649881	et	4	main
muudatused	doc_491521502269_item	2649882	et	3	main
kontrolliti	doc_491521502269_item	2649883	et	3	main
koolivormi	doc_491521502269_item	2649884	et	4	main
kohalviibimist	doc_491521502269_item	2649885	et	3	main
2	doc_491521502269_item	2649921	et	2	main
tootma	doc_491521502269_item	2649930	et	3	main
lubati	doc_491521502269_item	2649935	et	3	main
kanda	doc_491521502269_item	2649936	et	4	main
pükse	doc_491521502269_item	2649938	et	3	main
hakkasid	doc_491521502269_item	2649941	et	4	main
tundi	doc_491521502269_item	2649944	et	4	main
aktiviseerus	doc_491521502269_item	2649945	et	3	main
kultuuritarbimine	doc_491521502269_item	2649946	et	3	main
andis	doc_491521502269_item	2649953	et	3	main
end	doc_491521502269_item	2649955	et	4	main
süvenes	doc_491521502269_item	2649959	et	3	main
tuli	doc_491521502269_item	2649985	et	4	main
ka	doc_491521502269_item	2649986	et	3	main
uued	doc_491521502269_item	2649987	et	3	main
mälumängud	doc_491521502269_item	2649989	et	3	main
ja	doc_491521502269_item	2649990	et	3	main
tänase	doc_491521502269_item	2649997	et	3	main
koolis	doc_491521502269_item	2650008	et	4	main
kuna	doc_491521502269_item	2650012	et	3	main
varastasid	doc_491521502269_item	2650021	et	4	main
töökohtadelt	doc_491521502269_item	2650023	et	3	main
kodule	doc_491521502269_item	2650025	et	3	main
ja	doc_491521502269_item	2650032	et	3	main
kontrolltöö	doc_491521502270_item	2650034	et	4	main
nsvi	doc_491521502270_item	2650043	et	4	main
tunda	doc_491521502270_item	2650044	et	3	main
end	doc_491521502270_item	2650045	et	4	main
nsvl	doc_491521502270_item	2650046	et	4	main
lähisvälismaana	doc_491521502270_item	2650047	et	3	main
2	doc_491521502270_item	2650048	et	2	main
saadete	doc_491521502270_item	2650078	et	3	main
näit	doc_491521502270_item	2650080	et	3	main
nsvl-s	doc_491521502270_item	2650088	et	3	main
seriaalid	doc_491521502270_item	2650093	et	3	main
eesti	doc_491521502270_item	2650128	et	4	main
turistid	doc_491521502270_item	2650130	et	3	main
siiski	doc_491521502270_item	2650135	et	4	main
veski	doc_491521502270_item	2650141	et	4	main
olid	doc_491521502270_item	2650149	et	4	main
keeles	doc_491521502270_item	2650159	et	4	main
2	doc_491521502270_item	2650160	et	2	main
minu	doc_491521502270_item	2650161	et	3	main
ühiskonnakriitika	doc_491521502270_item	2650164	et	4	main
sest	doc_491521502270_item	2650165	et	4	main
süsteem	doc_491521502270_item	2650176	et	3	main
ka	doc_491521502270_item	2650178	et	3	main
1970ndatel	doc_491521502269_item	2649837	et	4	main
tunda	doc_491521502269_item	2649841	et	3	main
ühiskonnakriitika	doc_491521502269_item	2649855	et	4	main
on	doc_491521502269_item	2649871	et	4	main
hakati	doc_491521502269_item	2649877	et	3	main
igas	doc_491521502269_item	2649886	et	3	main
tunnis	doc_491521502269_item	2649887	et	3	main
pidi	doc_491521502269_item	2649888	et	4	main
käima	doc_491521502269_item	2649889	et	4	main
ülikoolis	doc_491521502269_item	2649890	et	4	main
kestis	doc_491521502269_item	2649891	et	4	main
loeng	doc_491521502269_item	2649892	et	3	main
45	doc_491521502269_item	2649893	et	2	main
minutit	doc_491521502269_item	2649894	et	3	main
kui	doc_491521502269_item	2649895	et	3	main
hakati	doc_491521502269_item	2649896	et	3	main
avaldama	doc_491521502269_item	2649897	et	3	main
majanduslikku	doc_491521502269_item	2649898	et	4	main
survet	doc_491521502269_item	2649899	et	3	main
siis	doc_491521502269_item	2649900	et	3	main
hakkas	doc_491521502269_item	2649901	et	3	main
situatsioon	doc_491521502269_item	2649902	et	3	main
paranema	doc_491521502269_item	2649903	et	3	main
1	doc_491521502269_item	2649904	et	2	main
tarbijakaupu	doc_491521502269_item	2649905	et	3	main
võis	doc_491521502269_item	2649906	et	4	main
osta	doc_491521502269_item	2649907	et	4	main
järelmaksuga	doc_491521502269_item	2649908	et	3	main
vaibad	doc_491521502269_item	2649909	et	3	main
külmkapid	doc_491521502269_item	2649910	et	3	main
selleks	doc_491521502269_item	2649911	et	4	main
et	doc_491521502269_item	2649912	et	3	main
osta	doc_491521502269_item	2649913	et	4	main
nt	doc_491521502269_item	2649914	et	4	main
vaipa	doc_491521502269_item	2649915	et	4	main
inimene	doc_491521502269_item	2649916	et	3	main
pidi	doc_491521502269_item	2649917	et	4	main
enne	doc_491521502269_item	2649918	et	4	main
luba	doc_491521502269_item	2649919	et	4	main
küsima	doc_491521502269_item	2649920	et	3	main
autod	doc_491521502269_item	2649925	et	3	main
vaibad	doc_491521502269_item	2649927	et	3	main
hakati	doc_491521502269_item	2649929	et	3	main
pikki	doc_491521502269_item	2649937	et	4	main
laulude	doc_491521502269_item	2649873	et	3	main
alguses	doc_491521502269_item	2649876	et	4	main
tegema	doc_491521502269_item	2649878	et	3	main
luksus	doc_491521502269_item	2649923	et	4	main
kaupadele	doc_491521502269_item	2649924	et	3	main
telerid	doc_491521502269_item	2649926	et	3	main
70ndatel	doc_491521502269_item	2649928	et	4	main
norma	doc_491521502269_item	2649931	et	4	main
märgid	doc_491521502269_item	2649932	et	4	main
tüdrukutel	doc_491521502269_item	2649934	et	4	main
ülikoolides	doc_491521502269_item	2649939	et	3	main
15	doc_491521502269_item	2649943	et	2	main
teatrikülastajate	doc_491521502269_item	2649950	et	3	main
arvud	doc_491521502269_item	2649951	et	3	main
siis	doc_491521502269_item	2649958	et	3	main
käsitluse	doc_491521502269_item	2649960	et	4	main
pidurdus	doc_491521502269_item	2649962	et	4	main
kaadri	doc_491521502269_item	2649964	et	3	main
saated	doc_491521502269_item	2649988	et	3	main
tõsielusarjad	doc_491521502269_item	2649991	et	3	main
päevani	doc_491521502269_item	2649998	et	3	main
tulid	doc_491521502269_item	2650001	et	4	main
likvideeriti	doc_491521502269_item	2650003	et	3	main
maakoolid	doc_491521502269_item	2650004	et	3	main
hakkasid	doc_491521502269_item	2650006	et	4	main
vajalikke	doc_491521502269_item	2650026	et	3	main
nt	doc_491521502269_item	2650029	et	4	main
tööriistu	doc_491521502269_item	2650031	et	3	main
teisi	doc_491521502269_item	2650033	et	4	main
missugused	doc_491521502270_item	2650036	et	3	main
andsid	doc_491521502270_item	2650039	et	4	main
1970ndatel	doc_491521502270_item	2650040	et	4	main
põhjust	doc_491521502270_item	2650041	et	4	main
l	doc_491521502270_item	2650049	et	4	main
laiuse	doc_491521502270_item	2650050	et	4	main
mängufilm	doc_491521502270_item	2650051	et	3	main
libahunt	doc_491521502270_item	2650052	et	3	main
arvates	doc_491521502270_item	2650055	et	4	main
või	doc_491521502270_item	2650057	et	4	main
olnud	doc_491521502270_item	2650063	et	4	main
kultuuri	doc_491521502270_item	2650068	et	4	main
poole	doc_491521502270_item	2650069	et	4	main
näiteks	doc_491521502270_item	2650072	et	4	main
nimetada	doc_491521502270_item	2650073	et	3	main
mis	doc_491521502270_item	2650085	et	4	main
jõudsid	doc_491521502270_item	2650090	et	4	main
maj	doc_491521502270_item	2650122	et	4	main
tsentraliseerimine	doc_491521502270_item	2650124	et	4	main
soome	doc_491521502270_item	2650126	et	3	main
siin	doc_491521502270_item	2650132	et	4	main
elatustase	doc_491521502270_item	2650134	et	3	main
kõrgem	doc_491521502270_item	2650136	et	4	main
mitmed	doc_491521502270_item	2650137	et	4	main
neid	doc_491521502270_item	2650153	et	4	main
esitati	doc_491521502270_item	2650154	et	4	main
meelest	doc_491521502270_item	2650162	et	4	main
oma	doc_491521502270_item	2650185	et	4	main
väidetavalt	doc_491521502270_item	2650201	et	4	main
ka	doc_491521502270_item	2650206	et	3	main
nsvl	doc_491521502270_item	2650211	et	4	main
kartis	doc_491521502270_item	2650212	et	3	main
teisitimõtlejaid	doc_491521502270_item	2650213	et	3	main
kui	doc_491521502270_item	2650217	et	3	main
omalaadne	doc_491521502270_item	2650232	et	3	main
kerge	doc_491521502270_item	2650244	et	4	main
naissoo	doc_491521502270_item	2650251	et	4	main
võimalik	doc_491521502270_item	2650256	et	3	main
soome	doc_491521502270_item	2650258	et	3	main
mis	doc_491521502270_item	2650260	et	4	main
andis	doc_491521502270_item	2650261	et	3	main
siinsele	doc_491521502270_item	2650262	et	3	main
mis	doc_491521502270_item	2650267	et	4	main
alguse	doc_491521502270_item	2650271	et	3	main
päritolu	doc_491521502270_item	2650273	et	4	main
osaliselt	doc_491521502270_item	2650284	et	4	main
eesti	doc_491521502270_item	2650287	et	4	main
ju	doc_491521502270_item	2650290	et	3	main
a	doc_491521502270_item	2650297	et	4	main
tahtnud	doc_491521502270_item	2650311	et	4	main
olla	doc_491521502270_item	2650312	et	3	main
lihtne	doc_491521502270_item	2650313	et	3	main
etteotsa	doc_491521502269_item	2649947	et	3	main
jõudsid	doc_491521502269_item	2649948	et	4	main
kino-	doc_491521502269_item	2649949	et	4	main
stagnaperiood	doc_491521502269_item	2649954	et	3	main
tunda	doc_491521502269_item	2649956	et	3	main
humanitaarteadustes	doc_491521502269_item	2649957	et	3	main
noore	doc_491521502269_item	2649963	et	3	main
pealekasv	doc_491521502269_item	2649965	et	3	main
ka	doc_491521502269_item	2649966	et	3	main
kasvas	doc_491521502269_item	2649967	et	3	main
televisiooni	doc_491521502269_item	2649968	et	4	main
maht	doc_491521502269_item	2649969	et	3	main
noorte	doc_491521502269_item	2649970	et	3	main
seas	doc_491521502269_item	2649971	et	4	main
tuli	doc_491521502269_item	2649972	et	4	main
rohkem	doc_491521502269_item	2649973	et	4	main
uusi	doc_491521502269_item	2649974	et	3	main
noorte	doc_491521502269_item	2649975	et	3	main
saateid	doc_491521502269_item	2649976	et	3	main
nagu	doc_491521502269_item	2649977	et	3	main
nt	doc_491521502269_item	2649978	et	4	main
entel-tentel	doc_491521502269_item	2649979	et	4	main
ja	doc_491521502269_item	2649980	et	3	main
tipp	doc_491521502269_item	2649981	et	3	main
ja	doc_491521502269_item	2649982	et	3	main
täpp	doc_491521502269_item	2649983	et	3	main
tendentslikus	doc_491521502269_item	2649961	et	4	main
mis	doc_491521502269_item	2649995	et	4	main
linna	doc_491521502269_item	2650007	et	4	main
linna	doc_491521502269_item	2650011	et	4	main
lapsed	doc_491521502269_item	2650014	et	3	main
linna	doc_491521502269_item	2650016	et	4	main
oli	doc_491521502269_item	2650017	et	3	main
ka	doc_491521502269_item	2650018	et	3	main
riigivargus	doc_491521502269_item	2650019	et	3	main
inimesed	doc_491521502269_item	2650020	et	3	main
asju	doc_491521502269_item	2650027	et	3	main
naelu	doc_491521502269_item	2650030	et	3	main
eesti	doc_491521502270_item	2650042	et	4	main
teie	doc_491521502270_item	2650054	et	4	main
ajaloodokument	doc_491521502270_item	2650056	et	3	main
ühiskonnakriitika	doc_491521502270_item	2650058	et	4	main
eestis	doc_491521502270_item	2650061	et	3	main
ideoloogiline	doc_491521502270_item	2650064	et	4	main
surve	doc_491521502270_item	2650065	et	4	main
nii	doc_491521502270_item	2650066	et	3	main
mis	doc_491521502270_item	2650075	et	4	main
ilmusid	doc_491521502270_item	2650081	et	4	main
lapstähed	doc_491521502270_item	2650083	et	3	main
entel-tentel	doc_491521502270_item	2650084	et	4	main
vaatajateni	doc_491521502270_item	2650091	et	4	main
esimesed	doc_491521502270_item	2650092	et	3	main
vähenes	doc_491521502270_item	2650123	et	3	main
püsiühendus	doc_491521502270_item	2650125	et	3	main
ja	doc_491521502270_item	2650127	et	3	main
vahel	doc_491521502270_item	2650129	et	4	main
joala	doc_491521502270_item	2650140	et	4	main
populaarsuse	doc_491521502270_item	2650145	et	4	main
lauludega	doc_491521502270_item	2650147	et	3	main
kuid	doc_491521502270_item	2650152	et	4	main
vene	doc_491521502270_item	2650156	et	4	main
v	doc_491521502270_item	2650157	et	4	main
pigem	doc_491521502270_item	2650163	et	3	main
oma	doc_491521502270_item	2650169	et	4	main
teistsuguse	doc_491521502270_item	2650170	et	3	main
loomuse	doc_491521502270_item	2650171	et	3	main
pärast	doc_491521502270_item	2650172	et	4	main
kogukonnast	doc_491521502270_item	2650173	et	4	main
paljud	doc_491521502270_item	2650181	et	3	main
pidid	doc_491521502270_item	2650183	et	4	main
lahkuma	doc_491521502270_item	2650184	et	3	main
ka	doc_491521502270_item	2650195	et	3	main
invaliide	doc_491521502270_item	2650197	et	4	main
selleks	doc_491521502270_item	2650208	et	4	main
tegutseda	doc_491521502270_item	2650221	et	3	main
nad	doc_491521502270_item	2650223	et	3	main
muutuda	doc_491521502270_item	2650224	et	3	main
tekkis	doc_491521502270_item	2650230	et	3	main
eesti	doc_491521502270_item	2650234	et	4	main
esitati	doc_491521502270_item	2650236	et	4	main
laadis	doc_491521502270_item	2650238	et	4	main
tuule	doc_491521502270_item	2650242	et	3	main
aimu	doc_491521502270_item	2650265	et	4	main
kuid	doc_491521502270_item	2650278	et	4	main
tänu	doc_491521502270_item	2650286	et	4	main
piiririik	doc_491521502270_item	2650291	et	3	main
vaid	doc_491521502270_item	2650299	et	3	main
elanikkonnast	doc_491521502270_item	2650301	et	4	main
lihtsate	doc_491521502270_item	2650305	et	3	main
tööde	doc_491521502270_item	2650306	et	3	main
tegemiseks	doc_491521502270_item	2650307	et	4	main
sest	doc_491521502270_item	2650308	et	4	main
eestlane	doc_491521502270_item	2650309	et	3	main
ei	doc_491521502270_item	2650310	et	4	main
nt	doc_491521502269_item	2649992	et	4	main
õnne	doc_491521502269_item	2649993	et	4	main
13	doc_491521502269_item	2649994	et	2	main
paljud	doc_491521502269_item	2649999	et	3	main
käima	doc_491521502269_item	2650009	et	4	main
enamus	doc_491521502269_item	2650013	et	4	main
kolisid	doc_491521502269_item	2650015	et	4	main
neile	doc_491521502269_item	2650024	et	4	main
1	doc_491521502270_item	2650035	et	2	main
tegurid	doc_491521502270_item	2650038	et	3	main
miks	doc_491521502270_item	2650059	et	4	main
tugev	doc_491521502270_item	2650067	et	4	main
võid	doc_491521502270_item	2650071	et	4	main
alustas	doc_491521502270_item	2650076	et	3	main
tootmist	doc_491521502270_item	2650079	et	4	main
ekraanile	doc_491521502270_item	2650082	et	3	main
ainulaadne	doc_491521502270_item	2650087	et	3	main
samuti	doc_491521502270_item	2650089	et	3	main
tööd	doc_491521502270_item	2650094	et	4	main
alustas	doc_491521502270_item	2650095	et	3	main
eesti	doc_491521502270_item	2650096	et	4	main
reklaamfilm	doc_491521502270_item	2650097	et	3	main
tv-s	doc_491521502270_item	2650098	et	3	main
hakati	doc_491521502270_item	2650099	et	3	main
reklaame	doc_491521502270_item	2650101	et	3	main
näitama	doc_491521502270_item	2650100	et	3	main
nähtus	doc_491521502270_item	2650102	et	4	main
mida	doc_491521502270_item	2650103	et	4	main
venemaal	doc_491521502270_item	2650104	et	4	main
ei	doc_491521502270_item	2650105	et	4	main
tuntud	doc_491521502270_item	2650106	et	4	main
väga	doc_491521502270_item	2650107	et	3	main
populaarseks	doc_491521502270_item	2650108	et	4	main
said	doc_491521502270_item	2650109	et	4	main
mälumängud	doc_491521502270_item	2650110	et	3	main
1970-ndatel	doc_491521502270_item	2650111	et	4	main
ilmus	doc_491521502270_item	2650112	et	4	main
eestis	doc_491521502270_item	2650113	et	3	main
esimene	doc_491521502270_item	2650114	et	3	main
koomiks	doc_491521502270_item	2650115	et	3	main
eestis	doc_491521502270_item	2650116	et	3	main
säilis	doc_491521502270_item	2650117	et	4	main
omakeelne	doc_491521502270_item	2650118	et	3	main
õpe	doc_491521502270_item	2650119	et	3	main
ka	doc_491521502270_item	2650120	et	3	main
valuutapoed	doc_491521502270_item	2650131	et	3	main
oli	doc_491521502270_item	2650133	et	3	main
saavutasid	doc_491521502270_item	2650142	et	4	main
suure	doc_491521502270_item	2650144	et	3	main
mis	doc_491521502270_item	2650148	et	4	main
pärit	doc_491521502270_item	2650150	et	3	main
kas	doc_491521502270_item	2650155	et	3	main
tiina	doc_491521502270_item	2650168	et	4	main
välja	doc_491521502270_item	2650174	et	4	main
toimis	doc_491521502270_item	2650177	et	4	main
nsvl-s	doc_491521502270_item	2650179	et	3	main
loomeinimesed	doc_491521502270_item	2650182	et	3	main
sobimatuse	doc_491521502270_item	2650186	et	4	main
pärast	doc_491521502270_item	2650187	et	4	main
kõiki	doc_491521502270_item	2650189	et	4	main
kes	doc_491521502270_item	2650190	et	4	main
vastanud	doc_491521502270_item	2650192	et	4	main
näit	doc_491521502270_item	2650196	et	3	main
keda	doc_491521502270_item	2650198	et	4	main
s	doc_491521502270_item	2650200	et	4	main
põhjus	doc_491521502270_item	2650204	et	4	main
kuna	doc_491521502270_item	2650214	et	3	main
et	doc_491521502270_item	2650216	et	3	main
vabalt	doc_491521502270_item	2650220	et	4	main
võivad	doc_491521502270_item	2650222	et	4	main
väga	doc_491521502270_item	2650231	et	3	main
jazzilikus	doc_491521502270_item	2650237	et	4	main
üleüldse	doc_491521502270_item	2650239	et	3	main
levimuusika	doc_491521502270_item	2650246	et	4	main
tuntuimad	doc_491521502270_item	2650247	et	4	main
tegijad	doc_491521502270_item	2650248	et	4	main
aoit	doc_491521502270_item	2650252	et	4	main
näha	doc_491521502270_item	2650257	et	3	main
välismaal	doc_491521502270_item	2650269	et	4	main
siiski	doc_491521502270_item	2650279	et	4	main
sai	doc_491521502270_item	2650280	et	4	main
ka	doc_491521502270_item	2650285	et	3	main
asendile	doc_491521502270_item	2650288	et	3	main
oleme	doc_491521502270_item	2650289	et	3	main
jätkus	doc_491521502270_item	2650292	et	4	main
moodustasid	doc_491521502270_item	2650298	et	4	main
60	doc_491521502270_item	2650300	et	2	main
ei	doc_491521502270_item	2650191	et	4	main
nsvl	doc_491521502270_item	2650193	et	4	main
standardile	doc_491521502270_item	2650194	et	4	main
polnud	doc_491521502270_item	2650202	et	3	main
sarnane	doc_491521502270_item	2650207	et	4	main
hirm	doc_491521502270_item	2650210	et	3	main
lasta	doc_491521502270_item	2650218	et	4	main
ohtlikuks	doc_491521502270_item	2650225	et	3	main
süsteemile	doc_491521502270_item	2650227	et	3	main
muusikas	doc_491521502270_item	2650229	et	3	main
folkloormuusikat	doc_491521502270_item	2650235	et	4	main
sai	doc_491521502270_item	2650240	et	4	main
olid	doc_491521502270_item	2650249	et	4	main
u	doc_491521502270_item	2650250	et	4	main
eesti	doc_491521502270_item	2650253	et	4	main
oli	doc_491521502270_item	2650255	et	3	main
tv-d	doc_491521502270_item	2650259	et	4	main
rahvale	doc_491521502270_item	2650263	et	3	main
vähegi	doc_491521502270_item	2650264	et	4	main
toimub	doc_491521502270_item	2650268	et	3	main
välismaist	doc_491521502270_item	2650272	et	4	main
toodete	doc_491521502270_item	2650274	et	3	main
kultus	doc_491521502270_item	2650275	et	3	main
küll	doc_491521502270_item	2650276	et	4	main
piirangutega	doc_491521502270_item	2650277	et	3	main
muu	doc_491521502270_item	2650282	et	4	main
maailmaga	doc_491521502270_item	2650283	et	3	main
tõus	doc_491521502270_item	2650295	et	4	main
1985	doc_491521502270_item	2650296	et	2	main
eestlased	doc_491521502270_item	2650302	et	3	main
vajati	doc_491521502270_item	2650304	et	3	main
valitsevale	doc_491521502270_item	2650226	et	4	main
1	doc_491521502270_item	2650228	et	2	main
suund	doc_491521502270_item	2650233	et	3	main
jazzmuusika	doc_491521502270_item	2650241	et	4	main
tiibadesse	doc_491521502270_item	2650243	et	3	main
e	doc_491521502270_item	2650245	et	4	main
põhjarannikul	doc_491521502270_item	2650254	et	3	main
sellest	doc_491521502270_item	2650266	et	4	main
sai	doc_491521502270_item	2650270	et	4	main
suhelda	doc_491521502270_item	2650281	et	4	main
mitteeestlaste	doc_491521502270_item	2650293	et	4	main
arvu	doc_491521502270_item	2650294	et	4	main
võõrtööjõudu	doc_491521502270_item	2650303	et	4	main
torujüri	doc_491521502270_item	2650314	et	4	main
majanduselus	doc_491521502272_item	2650660	et	4	main
arvati	doc_491521502272_item	2650675	et	4	main
isemajandamisele	doc_491521502272_item	2650680	et	3	main
oli	doc_491521502272_item	2650683	et	3	main
teenima	doc_491521502272_item	2650692	et	3	main
pidu	doc_491521502272_item	2650718	et	4	main
kus	doc_491521502272_item	2650719	et	3	main
lauldi	doc_491521502272_item	2650720	et	3	main
muutused	doc_491521502272_item	2650655	et	4	main
muudatused	doc_491521502272_item	2650657	et	3	main
2	doc_491521502272_item	2650661	et	2	main
roll	doc_491521502272_item	2650663	et	3	main
1	doc_491521502272_item	2650666	et	2	main
rubla	doc_491521502272_item	2650667	et	4	main
võib	doc_491521502272_item	2650678	et	3	main
üleminna	doc_491521502272_item	2650679	et	3	main
sõda	doc_491521502272_item	2650681	et	4	main
ja	doc_491521502272_item	2650685	et	3	main
nüüd	doc_491521502272_item	2650686	et	4	main
sõdurid	doc_491521502272_item	2650690	et	3	main
minema	doc_491521502272_item	2650693	et	3	main
oma	doc_491521502272_item	2650696	et	4	main
pärast	doc_491521502272_item	2650698	et	4	main
esimeseks	doc_491521502272_item	2650699	et	3	main
torni	doc_491521502272_item	2650709	et	4	main
pikaks	doc_491521502272_item	2650713	et	4	main
endil	doc_491521502272_item	2650732	et	4	main
oli	doc_491521502272_item	2650744	et	3	main
oli	doc_491521502272_item	2650747	et	3	main
tasuta	doc_491521502272_item	2650769	et	4	main
väiksemagi	doc_491521502272_item	2650774	et	4	main
ks	doc_491521502272_item	2650780	et	4	main
keelati	doc_491521502272_item	2650785	et	4	main
sisse	doc_491521502272_item	2650791	et	4	main
tooma	doc_491521502272_item	2650792	et	3	main
banaane	doc_491521502272_item	2650793	et	3	main
jogurtit	doc_491521502272_item	2650794	et	3	main
jne	doc_491521502272_item	2650795	et	4	main
vabariigiks	doc_491521502272_item	2650799	et	3	main
et	doc_491521502272_item	2650816	et	3	main
ja	doc_491521502272_item	2650827	et	3	main
et	doc_491521502272_item	2650832	et	3	main
ole	doc_491521502272_item	2650840	et	4	main
1400	doc_491521502272_item	2650846	et	2	main
ja	doc_491521502272_item	2650858	et	3	main
muud	doc_491521502272_item	2650859	et	4	main
abipakkidena	doc_491521502272_item	2650885	et	3	main
taasiseseisvunud	doc_491521502272_item	2650658	et	4	main
eesti	doc_491521502272_item	2650677	et	4	main
lõppenud	doc_491521502272_item	2650684	et	4	main
ei	doc_491521502272_item	2650687	et	4	main
kartes	doc_491521502272_item	2650695	et	3	main
ajaks	doc_491521502272_item	2650714	et	4	main
tallinna	doc_491521502272_item	2650715	et	4	main
lauluväljakul	doc_491521502272_item	2650716	et	3	main
toimus	doc_491521502272_item	2650717	et	3	main
eesti	doc_491521502272_item	2650721	et	4	main
kus	doc_491521502272_item	2650723	et	3	main
et	doc_491521502272_item	2650725	et	3	main
ükskord	doc_491521502272_item	2650726	et	3	main
me	doc_491521502272_item	2650727	et	4	main
võidame	doc_491521502272_item	2650728	et	3	main
veel	doc_491521502272_item	2650733	et	4	main
najaad	doc_491521502272_item	2650736	et	3	main
sisse	doc_491521502272_item	2650742	et	4	main
kellel	doc_491521502272_item	2650746	et	4	main
võim	doc_491521502272_item	2650748	et	3	main
st	doc_491521502272_item	2650763	et	3	main
vesi	doc_491521502272_item	2650766	et	4	main
olid	doc_491521502272_item	2650767	et	4	main
peaaegu	doc_491521502272_item	2650768	et	3	main
võis	doc_491521502272_item	2650777	et	4	main
2	doc_491521502272_item	2650779	et	2	main
eestisse	doc_491521502272_item	2650789	et	4	main
muutus	doc_491521502272_item	2650797	et	4	main
inerrinde	doc_491521502272_item	2650801	et	4	main
oli	doc_491521502272_item	2650804	et	3	main
aitas	doc_491521502272_item	2650807	et	3	main
seda	doc_491521502272_item	2650810	et	3	main
mida	doc_491521502272_item	2650811	et	4	main
taheti	doc_491521502272_item	2650812	et	3	main
alla	doc_491521502272_item	2650821	et	3	main
kinodes	doc_491521502272_item	2650826	et	3	main
ning	doc_491521502272_item	2650829	et	3	main
koolist	doc_491521502272_item	2650835	et	4	main
töölt	doc_491521502272_item	2650837	et	3	main
ära	doc_491521502272_item	2650838	et	4	main
keelati	doc_491521502272_item	2650843	et	4	main
teatud	doc_491521502272_item	2650850	et	4	main
sündisid	doc_491521502272_item	2650863	et	4	main
müüdi	doc_491521502272_item	2650871	et	4	main
neid	doc_491521502272_item	2650872	et	4	main
asju	doc_491521502272_item	2650873	et	3	main
mida	doc_491521502272_item	2650874	et	4	main
vajalikudega	doc_491521502272_item	2650878	et	3	main
tühjad	doc_491521502272_item	2650881	et	3	main
kontrolltöö	doc_491521502272_item	2650653	et	4	main
1	doc_491521502272_item	2650654	et	2	main
ja	doc_491521502272_item	2650656	et	3	main
väärtus	doc_491521502272_item	2650668	et	3	main
oli	doc_491521502272_item	2650669	et	3	main
langenud	doc_491521502272_item	2650670	et	4	main
50	doc_491521502272_item	2650671	et	2	main
toimus	doc_491521502272_item	2650672	et	3	main
üleminek	doc_491521502272_item	2650673	et	3	main
eekile	doc_491521502272_item	2650674	et	4	main
afganistaniga	doc_491521502272_item	2650682	et	4	main
kaugele	doc_491521502272_item	2650694	et	4	main
elu	doc_491521502272_item	2650697	et	4	main
presidendiks	doc_491521502272_item	2650700	et	4	main
hermanni	doc_491521502272_item	2650708	et	4	main
sinna	doc_491521502272_item	2650712	et	3	main
meil	doc_491521502272_item	2650731	et	4	main
kütet	doc_491521502272_item	2650734	et	3	main
ei	doc_491521502272_item	2650737	et	4	main
siis	doc_491521502272_item	2650739	et	3	main
toodi	doc_491521502272_item	2650740	et	4	main
seda	doc_491521502272_item	2650741	et	3	main
traktoritega	doc_491521502272_item	2650756	et	3	main
künda	doc_491521502272_item	2650758	et	3	main
odav	doc_491521502272_item	2650762	et	3	main
ja	doc_491521502272_item	2650765	et	3	main
haiguse	doc_491521502272_item	2650775	et	4	main
tõttu	doc_491521502272_item	2650776	et	4	main
nädalaks	doc_491521502272_item	2650781	et	3	main
koolis	doc_491521502272_item	2650783	et	4	main
hakati	doc_491521502272_item	2650790	et	3	main
saavutada	doc_491521502272_item	2650808	et	3	main
gorbatšov	doc_491521502272_item	2650813	et	2	main
kehtestas	doc_491521502272_item	2650814	et	3	main
selle	doc_491521502272_item	2650815	et	4	main
ei	doc_491521502272_item	2650818	et	4	main
21	doc_491521502272_item	2650822	et	2	main
aastastele	doc_491521502272_item	2650823	et	4	main
käima	doc_491521502272_item	2650825	et	4	main
ei	doc_491521502272_item	2650839	et	4	main
alates	doc_491521502272_item	2650844	et	3	main
hommikuni	doc_491521502272_item	2650848	et	4	main
sellele	doc_491521502272_item	2650853	et	4	main
hakati	doc_491521502272_item	2650854	et	3	main
tarvitama	doc_491521502272_item	2650855	et	3	main
igasuguseid	doc_491521502272_item	2650856	et	3	main
odekolonne	doc_491521502272_item	2650857	et	3	main
peredes	doc_491521502272_item	2650862	et	3	main
väärarenguga	doc_491521502272_item	2650864	et	3	main
ei	doc_491521502272_item	2650875	et	4	main
sai	doc_491521502272_item	2650883	et	4	main
eesti	doc_491521502272_item	2650659	et	4	main
inerrinde	doc_491521502272_item	2650662	et	4	main
eesti	doc_491521502272_item	2650664	et	4	main
taasiseseisvumisprotsessis	doc_491521502272_item	2650665	et	3	main
et	doc_491521502272_item	2650676	et	3	main
pidanud	doc_491521502272_item	2650688	et	4	main
noored	doc_491521502272_item	2650689	et	3	main
enam	doc_491521502272_item	2650691	et	4	main
sai	doc_491521502272_item	2650701	et	4	main
lennart	doc_491521502272_item	2650702	et	4	main
meri	doc_491521502272_item	2650703	et	3	main
heisati	doc_491521502272_item	2650704	et	3	main
sini-must-valge	doc_491521502272_item	2650705	et	4	main
lipp	doc_491521502272_item	2650706	et	3	main
pikka	doc_491521502272_item	2650707	et	4	main
mis	doc_491521502272_item	2650710	et	4	main
jäi	doc_491521502272_item	2650711	et	3	main
laule	doc_491521502272_item	2650722	et	4	main
või	doc_491521502272_item	2650735	et	4	main
see	doc_491521502272_item	2650745	et	3	main
najta	doc_491521502272_item	2650749	et	4	main
palgast	doc_491521502272_item	2650770	et	4	main
võeti	doc_491521502272_item	2650771	et	3	main
saada	doc_491521502272_item	2650778	et	4	main
õpilastel	doc_491521502272_item	2650786	et	4	main
koolivorm	doc_491521502272_item	2650787	et	3	main
ära	doc_491521502272_item	2650788	et	4	main
eesti	doc_491521502272_item	2650798	et	4	main
taasiseseisvumisprotsessis	doc_491521502272_item	2650803	et	3	main
et	doc_491521502272_item	2650806	et	3	main
hakati	doc_491521502272_item	2650824	et	3	main
kontrolli	doc_491521502272_item	2650831	et	4	main
inimesed	doc_491521502272_item	2650833	et	3	main
alkoholi	doc_491521502272_item	2650841	et	4	main
kella	doc_491521502272_item	2650845	et	4	main
kuni	doc_491521502272_item	2650847	et	3	main
ja	doc_491521502272_item	2650849	et	3	main
poodides	doc_491521502272_item	2650851	et	3	main
tänu	doc_491521502272_item	2650852	et	4	main
nendes	doc_491521502272_item	2650861	et	4	main
lapsed	doc_491521502272_item	2650865	et	3	main
toimus	doc_491521502272_item	2650866	et	3	main
müümine	doc_491521502272_item	2650868	et	4	main
st	doc_491521502272_item	2650869	et	3	main
tahetud	doc_491521502272_item	2650876	et	4	main
poeletid	doc_491521502272_item	2650879	et	3	main
lausuti	doc_491521502272_item	2650724	et	4	main
niikuinii	doc_491521502272_item	2650729	et	4	main
kuna	doc_491521502272_item	2650730	et	3	main
olnud	doc_491521502272_item	2650738	et	4	main
jõukas	doc_491521502272_item	2650743	et	4	main
üle	doc_491521502272_item	2650750	et	3	main
kütust	doc_491521502272_item	2650751	et	4	main
oli	doc_491521502272_item	2650752	et	3	main
vaja	doc_491521502272_item	2650753	et	4	main
selleks	doc_491521502272_item	2650754	et	4	main
et	doc_491521502272_item	2650755	et	3	main
maad	doc_491521502272_item	2650757	et	4	main
jne	doc_491521502272_item	2650759	et	4	main
elu	doc_491521502272_item	2650760	et	4	main
oli	doc_491521502272_item	2650761	et	3	main
elekter	doc_491521502272_item	2650764	et	3	main
maha	doc_491521502272_item	2650772	et	4	main
iga	doc_491521502272_item	2650773	et	4	main
haiglasse	doc_491521502272_item	2650782	et	4	main
võeti	doc_491521502272_item	2650784	et	3	main
eesti	doc_491521502272_item	2650796	et	4	main
2	doc_491521502272_item	2650800	et	2	main
roll	doc_491521502272_item	2650802	et	3	main
see	doc_491521502272_item	2650805	et	3	main
koike	doc_491521502272_item	2650809	et	4	main
alkoholi	doc_491521502272_item	2650817	et	4	main
tohi	doc_491521502272_item	2650819	et	4	main
müüja	doc_491521502272_item	2650820	et	4	main
mujal	doc_491521502272_item	2650828	et	3	main
teostama	doc_491521502272_item	2650830	et	3	main
niisama	doc_491521502272_item	2650834	et	3	main
või	doc_491521502272_item	2650836	et	4	main
müüa	doc_491521502272_item	2650842	et	3	main
sarnast	doc_491521502272_item	2650860	et	4	main
sund	doc_491521502272_item	2650867	et	3	main
et	doc_491521502272_item	2650870	et	3	main
koos	doc_491521502272_item	2650877	et	4	main
olid	doc_491521502272_item	2650880	et	4	main
toiduvarusid	doc_491521502272_item	2650882	et	3	main
tellida	doc_491521502272_item	2650884	et	3	main
1	doc_491521502274_item	2651134	et	2	main
eesti	doc_491521502274_item	2651144	et	4	main
aastal	doc_491521502274_item	2651149	et	3	main
president	doc_491521502274_item	2651160	et	3	main
moodustati	doc_491521502274_item	2651163	et	3	main
ja	doc_491521502274_item	2651184	et	3	main
sõlmiti	doc_491521502274_item	2651186	et	3	main
kroon	doc_491521502274_item	2651203	et	3	main
muutused	doc_491521502275_item	2651218	et	4	main
sündmus	doc_491521502275_item	2651226	et	3	main
selle	doc_491521502275_item	2651230	et	4	main
toimusid	doc_491521502275_item	2651242	et	4	main
ainult	doc_491521502275_item	2651245	et	4	main
elus	doc_491521502275_item	2651247	et	4	main
vaid	doc_491521502275_item	2651248	et	3	main
kõik	doc_491521502275_item	2651259	et	4	main
kõige	doc_491521502275_item	2651268	et	4	main
eesti	doc_491521502275_item	2651280	et	4	main
nimetati	doc_491521502275_item	2651289	et	4	main
ümber	doc_491521502275_item	2651290	et	3	main
seega	doc_491521502275_item	2651307	et	4	main
ainult	doc_491521502275_item	2651310	et	4	main
n	doc_491521502275_item	2651318	et	4	main
õpetamisesüsteem	doc_491521502275_item	2651322	et	4	main
teiste	doc_491521502275_item	2651328	et	4	main
hakkasid	doc_491521502275_item	2651330	et	4	main
taas	doc_491521502275_item	2651331	et	3	main
tegutsema	doc_491521502275_item	2651332	et	3	main
ões	doc_491521502275_item	2651333	et	4	main
eestlastega	doc_491521502275_item	2651343	et	4	main
eesti	doc_491521502275_item	2651349	et	4	main
kultuuri	doc_491521502275_item	2651354	et	4	main
mõnedes	doc_491521502275_item	2651356	et	3	main
tsensuur	doc_491521502275_item	2651360	et	3	main
mis	doc_491521502275_item	2651362	et	4	main
on	doc_491521502275_item	2651363	et	4	main
väga	doc_491521502275_item	2651364	et	3	main
jaoks	doc_491521502275_item	2651370	et	4	main
paljud	doc_491521502275_item	2651373	et	3	main
paljud	doc_491521502275_item	2651383	et	3	main
rahva	doc_491521502275_item	2651393	et	3	main
kuna	doc_491521502275_item	2651395	et	3	main
ju	doc_491521502275_item	2651397	et	3	main
on	doc_491521502275_item	2651407	et	4	main
omane	doc_491521502275_item	2651408	et	3	main
öelda	doc_491521502275_item	2651421	et	4	main
inimeste	doc_491521502275_item	2651423	et	3	main
kontrolltöö	doc_491521502274_item	2651133	et	4	main
eesti	doc_491521502274_item	2651139	et	4	main
2	doc_491521502274_item	2651141	et	2	main
inerrinne	doc_491521502274_item	2651147	et	4	main
arvati	doc_491521502274_item	2651150	et	4	main
ametisse	doc_491521502274_item	2651158	et	3	main
riigikogu	doc_491521502274_item	2651164	et	4	main
mille	doc_491521502274_item	2651188	et	3	main
tagajärjel	doc_491521502274_item	2651189	et	3	main
eesti	doc_491521502274_item	2651202	et	4	main
olid	doc_491521502274_item	2651206	et	4	main
uue	doc_491521502274_item	2651208	et	3	main
euro	doc_491521502274_item	2651210	et	4	main
kasutuselevõtust	doc_491521502274_item	2651211	et	3	main
mitu	doc_491521502274_item	2651214	et	4	main
aastat	doc_491521502274_item	2651215	et	3	main
kontrolltöö	doc_491521502275_item	2651216	et	4	main
1	doc_491521502275_item	2651217	et	2	main
et	doc_491521502274_item	2651151	et	3	main
taga	doc_491521502274_item	2651153	et	4	main
seisis	doc_491521502274_item	2651154	et	4	main
esimene	doc_491521502274_item	2651159	et	3	main
ning	doc_491521502274_item	2651162	et	3	main
koosnes	doc_491521502274_item	2651166	et	3	main
talusid	doc_491521502274_item	2651185	et	4	main
eestisse	doc_491521502274_item	2651191	et	4	main
1992	doc_491521502274_item	2651198	et	2	main
aastal	doc_491521502274_item	2651199	et	3	main
võeti	doc_491521502274_item	2651200	et	3	main
kasutusele	doc_491521502274_item	2651201	et	4	main
juba	doc_491521502274_item	2651213	et	3	main
muudatused	doc_491521502275_item	2651220	et	3	main
eesti	doc_491521502275_item	2651222	et	4	main
sai	doc_491521502275_item	2651240	et	4	main
taasiseseisvus	doc_491521502275_item	2651241	et	4	main
mitte	doc_491521502275_item	2651244	et	3	main
poliitilises	doc_491521502275_item	2651246	et	3	main
ka	doc_491521502275_item	2651249	et	3	main
kultuurielus	doc_491521502275_item	2651250	et	4	main
see	doc_491521502275_item	2651258	et	3	main
puudutas	doc_491521502275_item	2651260	et	3	main
rohkem	doc_491521502275_item	2651269	et	4	main
mõju	doc_491521502275_item	2651270	et	4	main
avaldab	doc_491521502275_item	2651271	et	3	main
keskkond	doc_491521502275_item	2651272	et	3	main
ja	doc_491521502275_item	2651273	et	3	main
ümber	doc_491521502275_item	2651274	et	3	main
toimuvad	doc_491521502275_item	2651275	et	4	main
kõigepealt	doc_491521502275_item	2651277	et	3	main
oluliseks	doc_491521502275_item	2651288	et	4	main
tänapäeval	doc_491521502275_item	2651306	et	3	main
koolides	doc_491521502275_item	2651312	et	3	main
tavaliselt	doc_491521502275_item	2651313	et	4	main
tasulistes	doc_491521502275_item	2651314	et	4	main
taastati	doc_491521502275_item	2651315	et	4	main
mõned	doc_491521502275_item	2651316	et	3	main
usuteadus	doc_491521502275_item	2651319	et	4	main
muutused	doc_491521502274_item	2651135	et	4	main
muudatused	doc_491521502274_item	2651137	et	3	main
roll	doc_491521502274_item	2651143	et	3	main
2	doc_491521502274_item	2651146	et	2	main
tuli	doc_491521502274_item	2651157	et	4	main
lmeri	doc_491521502274_item	2651161	et	4	main
kaubavahetusleping	doc_491521502274_item	2651187	et	3	main
sisse	doc_491521502274_item	2651192	et	4	main
tooma	doc_491521502274_item	2651193	et	3	main
nt	doc_491521502274_item	2651194	et	4	main
banaane	doc_491521502274_item	2651195	et	3	main
ja	doc_491521502274_item	2651196	et	3	main
jogurtit	doc_491521502274_item	2651197	et	3	main
selleks	doc_491521502274_item	2651204	et	4	main
läbirääkimised	doc_491521502274_item	2651207	et	3	main
oli	doc_491521502275_item	2651227	et	3	main
1	doc_491521502275_item	2651236	et	2	main
muutused	doc_491521502275_item	2651243	et	4	main
ainult	doc_491521502275_item	2651253	et	4	main
haridust	doc_491521502275_item	2651261	et	4	main
valdkondi	doc_491521502275_item	2651264	et	4	main
kunsti	doc_491521502275_item	2651265	et	4	main
sest	doc_491521502275_item	2651266	et	4	main
kunstile	doc_491521502275_item	2651267	et	3	main
sündmused	doc_491521502275_item	2651276	et	3	main
sai	doc_491521502275_item	2651285	et	4	main
ka	doc_491521502275_item	2651286	et	3	main
väga	doc_491521502275_item	2651287	et	3	main
riiklik	doc_491521502275_item	2651292	et	3	main
tartu	doc_491521502275_item	2651294	et	4	main
tallinna	doc_491521502275_item	2651296	et	4	main
pedagoogika	doc_491521502275_item	2651297	et	4	main
instituut	doc_491521502275_item	2651298	et	3	main
õpetamissuunad	doc_491521502275_item	2651317	et	4	main
tü	doc_491521502275_item	2651320	et	4	main
reorganiseeriti	doc_491521502275_item	2651321	et	3	main
n	doc_491521502275_item	2651323	et	4	main
õppetool	doc_491521502275_item	2651325	et	3	main
vahetused	doc_491521502275_item	2651327	et	4	main
riikidega	doc_491521502275_item	2651329	et	3	main
veljesto	doc_491521502275_item	2651339	et	4	main
katkevad	doc_491521502275_item	2651340	et	4	main
sidemed	doc_491521502275_item	2651341	et	3	main
venemaa	doc_491521502275_item	2651342	et	4	main
ja	doc_491521502275_item	2651352	et	3	main
tähtis	doc_491521502275_item	2651365	et	4	main
kirjanike	doc_491521502275_item	2651366	et	3	main
tulevad	doc_491521502275_item	2651371	et	4	main
tagasi	doc_491521502275_item	2651372	et	3	main
saadetud	doc_491521502275_item	2651375	et	4	main
põgenenud	doc_491521502275_item	2651378	et	4	main
läände	doc_491521502275_item	2651379	et	3	main
eestlased	doc_491521502275_item	2651380	et	3	main
ka	doc_491521502275_item	2651389	et	3	main
jaoks	doc_491521502275_item	2651394	et	4	main
teame	doc_491521502275_item	2651398	et	3	main
et	doc_491521502275_item	2651399	et	3	main
uued	doc_491521502275_item	2651412	et	3	main
mänadzerid	doc_491521502275_item	2651417	et	4	main
ja	doc_491521502274_item	2651136	et	3	main
taasiseseisvunud	doc_491521502274_item	2651138	et	4	main
majanduselus	doc_491521502274_item	2651140	et	4	main
inerrinde	doc_491521502274_item	2651142	et	4	main
taasiseseisvumisprotsessis	doc_491521502274_item	2651145	et	3	main
moodustati	doc_491521502274_item	2651148	et	3	main
selle	doc_491521502274_item	2651152	et	4	main
kgb	doc_491521502274_item	2651155	et	4	main
1	doc_491521502274_item	2651156	et	2	main
mis	doc_491521502274_item	2651165	et	4	main
101-st	doc_491521502274_item	2651167	et	3	main
liikmest	doc_491521502274_item	2651168	et	4	main
uue	doc_491521502274_item	2651169	et	3	main
tuli	doc_491521502274_item	2651171	et	4	main
võimule	doc_491521502274_item	2651172	et	3	main
valitsusega	doc_491521502274_item	2651170	et	4	main
ka	doc_491521502274_item	2651173	et	3	main
edgar	doc_491521502274_item	2651174	et	4	main
savisaar	doc_491521502274_item	2651175	et	3	main
kes	doc_491521502274_item	2651176	et	4	main
viis	doc_491521502274_item	2651177	et	4	main
sisse	doc_491521502274_item	2651178	et	4	main
majandireformi	doc_491521502274_item	2651179	et	4	main
millega	doc_491521502274_item	2651180	et	3	main
lubati	doc_491521502274_item	2651181	et	3	main
tagastada	doc_491521502274_item	2651182	et	3	main
maid	doc_491521502274_item	2651183	et	4	main
hakati	doc_491521502274_item	2651190	et	3	main
ajaks	doc_491521502274_item	2651205	et	4	main
ühisraha	doc_491521502274_item	2651209	et	4	main
kestnud	doc_491521502274_item	2651212	et	4	main
ja	doc_491521502275_item	2651219	et	3	main
taasiseseisvunud	doc_491521502275_item	2651221	et	4	main
kultuurielus	doc_491521502275_item	2651223	et	4	main
2	doc_491521502275_item	2651224	et	2	main
mis	doc_491521502275_item	2651225	et	4	main
kett	doc_491521502275_item	2651229	et	4	main
tähendus	doc_491521502275_item	2651231	et	4	main
baltikumi	doc_491521502275_item	2651232	et	4	main
rahavstele	doc_491521502275_item	2651233	et	4	main
ja	doc_491521502275_item	2651234	et	3	main
muutused	doc_491521502275_item	2651254	et	4	main
vaid	doc_491521502275_item	2651255	et	3	main
ka	doc_491521502275_item	2651256	et	3	main
muudatused	doc_491521502275_item	2651257	et	3	main
sai	doc_491521502275_item	2651279	et	4	main
mõiste	doc_491521502275_item	2651282	et	4	main
eesti	doc_491521502275_item	2651283	et	4	main
kodanik	doc_491521502275_item	2651284	et	3	main
tartu	doc_491521502275_item	2651291	et	4	main
tallinna	doc_491521502275_item	2651299	et	4	main
pedagoogikaülikool	doc_491521502275_item	2651300	et	4	main
tekkis	doc_491521502275_item	2651301	et	3	main
mõiste	doc_491521502275_item	2651302	et	4	main
kolledž	doc_491521502275_item	2651303	et	2	main
kaotati	doc_491521502275_item	2651304	et	3	main
koolivorm	doc_491521502275_item	2651305	et	3	main
on	doc_491521502275_item	2651309	et	4	main
mõnedes	doc_491521502275_item	2651311	et	3	main
kateeder	doc_491521502275_item	2651324	et	3	main
ars	doc_491521502275_item	2651334	et	4	main
tegutsema	doc_491521502275_item	2651335	et	3	main
hakkab	doc_491521502275_item	2651336	et	3	main
üliõpilaste	doc_491521502275_item	2651337	et	4	main
selts	doc_491521502275_item	2651338	et	3	main
on	doc_491521502275_item	2651345	et	4	main
väga	doc_491521502275_item	2651346	et	3	main
kurb	doc_491521502275_item	2651347	et	3	main
keelt	doc_491521502275_item	2651350	et	4	main
ka	doc_491521502275_item	2651353	et	3	main
ja	doc_491521502275_item	2651367	et	3	main
kättesaadavaks	doc_491521502275_item	2651381	et	4	main
väga	doc_491521502275_item	2651390	et	3	main
mõiste	doc_491521502275_item	2651403	et	4	main
rahvale	doc_491521502275_item	2651410	et	3	main
n	doc_491521502275_item	2651414	et	4	main
igasugused	doc_491521502275_item	2651416	et	3	main
elu	doc_491521502275_item	2651424	et	4	main
see	doc_491521502275_item	2651440	et	3	main
ajal	doc_491521502275_item	2651444	et	4	main
toidu	doc_491521502275_item	2651446	et	3	main
puudust	doc_491521502275_item	2651447	et	4	main
defitsiit	doc_491521502275_item	2651448	et	3	main
kuidagi	doc_491521502275_item	2651459	et	3	main
olid	doc_491521502275_item	2651462	et	4	main
kuna	doc_491521502275_item	2651466	et	3	main
olin	doc_491521502275_item	2651468	et	3	main
küll	doc_491521502275_item	2651475	et	4	main
ma	doc_491521502275_item	2651483	et	3	main
esimest	doc_491521502275_item	2651486	et	4	main
ja	doc_491521502275_item	2651488	et	3	main
mu	doc_491521502275_item	2651489	et	3	main
onu	doc_491521502275_item	2651490	et	4	main
oli	doc_491521502275_item	2651494	et	3	main
ei	doc_491521502275_item	2651503	et	4	main
suured	doc_491521502275_item	2651521	et	3	main
et	doc_491521502275_item	2651525	et	3	main
ega	doc_491521502275_item	2651534	et	3	main
balti	doc_491521502275_item	2651538	et	3	main
leedu	doc_491521502275_item	2651560	et	4	main
balti	doc_491521502275_item	2651561	et	3	main
keti	doc_491521502275_item	2651562	et	3	main
eesmärgiks	doc_491521502275_item	2651563	et	3	main
aga	doc_491521502275_item	2651587	et	3	main
peamine	doc_491521502275_item	2651591	et	3	main
sest	doc_491521502275_item	2651593	et	4	main
peamine	doc_491521502275_item	2651600	et	3	main
alad	doc_491521502275_item	2651608	et	3	main
tagused	doc_491521502275_item	2651611	et	3	main
balti	doc_491521502275_item	2651228	et	3	main
maailmale	doc_491521502275_item	2651235	et	4	main
pärast	doc_491521502275_item	2651237	et	4	main
kui	doc_491521502275_item	2651238	et	3	main
eesti	doc_491521502275_item	2651239	et	4	main
olid	doc_491521502275_item	2651251	et	4	main
mitte	doc_491521502275_item	2651252	et	3	main
elu	doc_491521502275_item	2651262	et	4	main
erinevaid	doc_491521502275_item	2651263	et	4	main
riigikeeleks	doc_491521502275_item	2651278	et	4	main
keel	doc_491521502275_item	2651281	et	4	main
ülikool	doc_491521502275_item	2651293	et	4	main
ülikooliks	doc_491521502275_item	2651295	et	4	main
see	doc_491521502275_item	2651308	et	3	main
õpilaste	doc_491521502275_item	2651326	et	4	main
mis	doc_491521502275_item	2651344	et	4	main
õnneks	doc_491521502275_item	2651351	et	4	main
venemaal	doc_491521502275_item	2651358	et	4	main
edasi	doc_491521502275_item	2651359	et	3	main
inimeste	doc_491521502275_item	2651369	et	3	main
välja	doc_491521502275_item	2651374	et	4	main
siberisse	doc_491521502275_item	2651376	et	4	main
ja	doc_491521502275_item	2651377	et	3	main
euroopa	doc_491521502275_item	2651384	et	4	main
kanalid	doc_491521502275_item	2651385	et	3	main
võimalus	doc_491521502275_item	2651386	et	3	main
reisida	doc_491521502275_item	2651387	et	3	main
oluline	doc_491521502275_item	2651391	et	4	main
nagu	doc_491521502275_item	2651404	et	3	main
nipernaadlikkus	doc_491521502275_item	2651405	et	4	main
mis	doc_491521502275_item	2651406	et	4	main
tekivad	doc_491521502275_item	2651411	et	3	main
et	doc_491521502275_item	2651422	et	3	main
aega	doc_491521502275_item	2651432	et	4	main
mäletan	doc_491521502275_item	2651433	et	3	main
sailitanud	doc_491521502275_item	2651439	et	4	main
mina	doc_491521502275_item	2651454	et	4	main
ilusad	doc_491521502275_item	2651464	et	3	main
ajal	doc_491521502275_item	2651470	et	4	main
mänguasjad	doc_491521502275_item	2651476	et	3	main
mälestus	doc_491521502275_item	2651479	et	4	main
see	doc_491521502275_item	2651481	et	3	main
eesti	doc_491521502275_item	2651502	et	4	main
asi	doc_491521502275_item	2651524	et	4	main
inimesed	doc_491521502275_item	2651526	et	3	main
jälgi	doc_491521502275_item	2651533	et	4	main
oli	doc_491521502275_item	2651540	et	3	main
augustil	doc_491521502275_item	2651542	et	3	main
aastal	doc_491521502275_item	2651544	et	3	main
sai	doc_491521502275_item	2651546	et	4	main
kuulda	doc_491521502275_item	2651547	et	4	main
kett	doc_491521502275_item	2651555	et	4	main
eesti	doc_491521502275_item	2651557	et	4	main
ei	doc_491521502275_item	2651589	et	4	main
rahvas	doc_491521502275_item	2651594	et	4	main
see	doc_491521502275_item	2651602	et	3	main
vastavalt	doc_491521502275_item	2651604	et	4	main
rahule	doc_491521502275_item	2651606	et	4	main
territoorium	doc_491521502275_item	2651616	et	3	main
taasiseseisvumist	doc_491521502275_item	2651624	et	3	main
on	doc_491521502275_item	2651631	et	4	main
tähtis	doc_491521502275_item	2651645	et	4	main
revolutsioon	doc_491521502275_item	2651651	et	3	main
sai	doc_491521502275_item	2651654	et	4	main
teada	doc_491521502275_item	2651655	et	3	main
eesti	doc_491521502275_item	2651656	et	4	main
ja	doc_491521502275_item	2651657	et	3	main
üldse	doc_491521502275_item	2651658	et	3	main
ii	doc_491521502275_item	2651661	et	4	main
sõja	doc_491521502275_item	2651663	et	3	main
järel	doc_491521502275_item	2651664	et	4	main
kontrolltöö	doc_491521502276_item	2651665	et	4	main
1	doc_491521502276_item	2651666	et	2	main
taasiseseisvunud	doc_491521502276_item	2651670	et	4	main
kultuurielus	doc_491521502276_item	2651672	et	4	main
tähendus	doc_491521502276_item	2651680	et	4	main
koolis	doc_491521502276_item	2651689	et	4	main
olnud	doc_491521502276_item	2651691	et	4	main
koolivorme	doc_491521502276_item	2651693	et	3	main
eestis	doc_491521502276_item	2651694	et	3	main
1992	doc_491521502276_item	2651728	et	2	main
a	doc_491521502276_item	2651729	et	4	main
eesti	doc_491521502276_item	2651732	et	4	main
kus	doc_491521502276_item	2651738	et	3	main
kuid	doc_491521502275_item	2651348	et	4	main
õpetatakse	doc_491521502275_item	2651355	et	3	main
ülikoolides	doc_491521502275_item	2651357	et	3	main
kaob	doc_491521502275_item	2651361	et	3	main
üldse	doc_491521502275_item	2651368	et	3	main
saavad	doc_491521502275_item	2651382	et	4	main
on	doc_491521502275_item	2651388	et	4	main
siinse	doc_491521502275_item	2651392	et	3	main
me	doc_491521502275_item	2651396	et	4	main
on	doc_491521502275_item	2651400	et	4	main
olemas	doc_491521502275_item	2651401	et	4	main
niisugune	doc_491521502275_item	2651402	et	3	main
eesti	doc_491521502275_item	2651409	et	4	main
ametid	doc_491521502275_item	2651413	et	3	main
sotsaiilpsühholoog	doc_491521502275_item	2651415	et	4	main
kokkuvõtteks	doc_491521502275_item	2651419	et	3	main
võib	doc_491521502275_item	2651420	et	3	main
jne	doc_491521502275_item	2651418	et	4	main
ise	doc_491521502275_item	2651430	et	4	main
seda	doc_491521502275_item	2651431	et	3	main
on	doc_491521502275_item	2651438	et	4	main
pärast	doc_491521502275_item	2651442	et	4	main
hakkasin	doc_491521502275_item	2651456	et	3	main
ennast	doc_491521502275_item	2651457	et	4	main
tundma	doc_491521502275_item	2651458	et	3	main
huvitasid	doc_491521502275_item	2651474	et	4	main
kes	doc_491521502275_item	2651491	et	4	main
meremees	doc_491521502275_item	2651495	et	4	main
teda	doc_491521502275_item	2651497	et	4	main
mulle	doc_491521502275_item	2651498	et	4	main
see	doc_491521502275_item	2651499	et	3	main
aeg	doc_491521502275_item	2651500	et	3	main
millal	doc_491521502275_item	2651501	et	3	main
ole	doc_491521502275_item	2651507	et	4	main
muutus	doc_491521502275_item	2651425	et	4	main
pärast	doc_491521502275_item	2651427	et	4	main
mina	doc_491521502275_item	2651429	et	4	main
mälus	doc_491521502275_item	2651437	et	4	main
perestroika	doc_491521502275_item	2651443	et	4	main
isiklukult	doc_491521502275_item	2651455	et	3	main
kauplustes	doc_491521502275_item	2651461	et	4	main
uued	doc_491521502275_item	2651463	et	3	main
kaubad	doc_491521502275_item	2651465	et	3	main
laps	doc_491521502275_item	2651471	et	4	main
siis	doc_491521502275_item	2651472	et	3	main
mind	doc_491521502275_item	2651473	et	4	main
suurim	doc_491521502275_item	2651478	et	3	main
endale	doc_491521502275_item	2651485	et	4	main
barbie	doc_491521502275_item	2651487	et	4	main
ajal	doc_491521502275_item	2651493	et	4	main
ostis	doc_491521502275_item	2651496	et	4	main
iseseisev	doc_491521502275_item	2651505	et	3	main
ei	doc_491521502275_item	2651506	et	4	main
kauge	doc_491521502275_item	2651508	et	4	main
minevik	doc_491521502275_item	2651509	et	3	main
seega	doc_491521502275_item	2651510	et	4	main
ma	doc_491521502275_item	2651511	et	3	main
mäletan	doc_491521502275_item	2651512	et	3	main
palju	doc_491521502275_item	2651513	et	4	main
ja	doc_491521502275_item	2651514	et	3	main
tihti	doc_491521502275_item	2651515	et	3	main
võrdlen	doc_491521502275_item	2651516	et	3	main
ja	doc_491521502275_item	2651518	et	3	main
muutused	doc_491521502275_item	2651517	et	4	main
muudatused	doc_491521502275_item	2651519	et	3	main
on	doc_491521502275_item	2651520	et	4	main
ei	doc_491521502275_item	2651532	et	4	main
2	doc_491521502275_item	2651537	et	2	main
kett	doc_491521502275_item	2651539	et	4	main
1989	doc_491521502275_item	2651543	et	2	main
sellest	doc_491521502275_item	2651545	et	4	main
inimestest	doc_491521502275_item	2651553	et	3	main
li	doc_491521502275_item	2651564	et	4	main
see	doc_491521502275_item	2651588	et	3	main
nii	doc_491521502275_item	2651597	et	3	main
arvas	doc_491521502275_item	2651598	et	3	main
petseri	doc_491521502275_item	2651607	et	4	main
on	doc_491521502275_item	2651613	et	4	main
mida	doc_491521502275_item	2651617	et	4	main
nsvl	doc_491521502275_item	2651618	et	4	main
tagasi	doc_491521502275_item	2651627	et	3	main
praegu	doc_491521502275_item	2651632	et	3	main
üheks	doc_491521502275_item	2651633	et	3	main
venemaa	doc_491521502275_item	2651637	et	4	main
aga	doc_491521502275_item	2651639	et	3	main
kui	doc_491521502275_item	2651649	et	3	main
loost	doc_491521502275_item	2651660	et	4	main
ja	doc_491521502276_item	2651668	et	3	main
eesti	doc_491521502276_item	2651671	et	4	main
2	doc_491521502276_item	2651673	et	2	main
mis	doc_491521502276_item	2651674	et	4	main
sündmus	doc_491521502276_item	2651675	et	3	main
rahavstele	doc_491521502276_item	2651682	et	4	main
ümber	doc_491521502276_item	2651688	et	3	main
on	doc_491521502276_item	2651699	et	4	main
palju	doc_491521502276_item	2651700	et	4	main
palju	doc_491521502275_item	2651426	et	4	main
taasiseseisvumist	doc_491521502275_item	2651428	et	3	main
kõige	doc_491521502275_item	2651434	et	4	main
rohkem	doc_491521502275_item	2651435	et	4	main
minu	doc_491521502275_item	2651436	et	3	main
et	doc_491521502275_item	2651441	et	3	main
olnud	doc_491521502275_item	2651445	et	4	main
kauplustes	doc_491521502275_item	2651449	et	4	main
oli	doc_491521502275_item	2651450	et	3	main
suur	doc_491521502275_item	2651451	et	3	main
valik	doc_491521502275_item	2651452	et	3	main
ja	doc_491521502275_item	2651453	et	3	main
eurooplastena	doc_491521502275_item	2651460	et	3	main
ma	doc_491521502275_item	2651467	et	3	main
tol	doc_491521502275_item	2651469	et	3	main
seega	doc_491521502275_item	2651477	et	4	main
on	doc_491521502275_item	2651480	et	4	main
kuidas	doc_491521502275_item	2651482	et	3	main
valisin	doc_491521502275_item	2651484	et	3	main
tol	doc_491521502275_item	2651492	et	3	main
olnud	doc_491521502275_item	2651504	et	4	main
aga	doc_491521502275_item	2651522	et	3	main
peamine	doc_491521502275_item	2651523	et	3	main
tunnevad	doc_491521502275_item	2651527	et	3	main
ennast	doc_491521502275_item	2651528	et	4	main
vabadena	doc_491521502275_item	2651529	et	3	main
midagi	doc_491521502275_item	2651536	et	4	main
terve	doc_491521502275_item	2651548	et	4	main
maailm	doc_491521502275_item	2651549	et	3	main
sest	doc_491521502275_item	2651550	et	4	main
koosnev	doc_491521502275_item	2651554	et	4	main
läbi	doc_491521502275_item	2651556	et	4	main
läti	doc_491521502275_item	2651558	et	4	main
ja	doc_491521502275_item	2651559	et	3	main
kui	doc_491521502275_item	2651596	et	3	main
on	doc_491521502275_item	2651601	et	4	main
et	doc_491521502275_item	2651603	et	3	main
tartu	doc_491521502275_item	2651605	et	4	main
ja	doc_491521502275_item	2651609	et	3	main
alad	doc_491521502275_item	2651612	et	3	main
kuuluv	doc_491521502275_item	2651615	et	4	main
ajal	doc_491521502275_item	2651619	et	4	main
venemaale	doc_491521502275_item	2651621	et	4	main
pärast	doc_491521502275_item	2651623	et	4	main
eestile	doc_491521502275_item	2651626	et	3	main
antud	doc_491521502275_item	2651629	et	4	main
mis	doc_491521502275_item	2651630	et	4	main
probleemiks	doc_491521502275_item	2651634	et	4	main
eesti	doc_491521502275_item	2651646	et	4	main
taasiseseisvumisel	doc_491521502275_item	2651647	et	3	main
samuti	doc_491521502275_item	2651648	et	3	main
terve	doc_491521502275_item	2651652	et	4	main
muutused	doc_491521502276_item	2651667	et	4	main
selle	doc_491521502276_item	2651679	et	4	main
nimetati	doc_491521502276_item	2651686	et	4	main
ei	doc_491521502276_item	2651690	et	4	main
enam	doc_491521502276_item	2651692	et	4	main
hakkatakse	doc_491521502276_item	2651695	et	4	main
tegema	doc_491521502276_item	2651696	et	3	main
mobiiltelefone	doc_491521502276_item	2651697	et	3	main
küsimus	doc_491521502276_item	2651723	et	4	main
eesti	doc_491521502276_item	2651724	et	4	main
minevikuks	doc_491521502276_item	2651725	et	3	main
riigikogu	doc_491521502276_item	2651737	et	4	main
lugema	doc_491521502276_item	2651745	et	4	main
ülikoolid	doc_491521502276_item	2651759	et	3	main
eestlased	doc_491521502276_item	2651760	et	3	main
armastavad	doc_491521502276_item	2651761	et	4	main
palju	doc_491521502276_item	2651763	et	4	main
2	doc_491521502276_item	2651773	et	2	main
toimus	doc_491521502276_item	2651776	et	3	main
a	doc_491521502276_item	2651778	et	4	main
sündmus	doc_491521502276_item	2651781	et	3	main
see	doc_491521502276_item	2651787	et	3	main
eesti	doc_491521502277_item	2651796	et	4	main
selle	doc_491521502277_item	2651804	et	4	main
baltikumi	doc_491521502277_item	2651806	et	4	main
andropov	doc_491521502277_item	2651822	et	4	main
tuli	doc_491521502277_item	2651831	et	4	main
a	doc_491521502277_item	2651834	et	4	main
tuli	doc_491521502277_item	2651836	et	4	main
tema	doc_491521502277_item	2651838	et	4	main
keegi	doc_491521502275_item	2651530	et	4	main
neid	doc_491521502275_item	2651531	et	4	main
keela	doc_491521502275_item	2651535	et	4	main
23	doc_491521502275_item	2651541	et	2	main
see	doc_491521502275_item	2651551	et	3	main
oli	doc_491521502275_item	2651552	et	3	main
mrp	doc_491521502275_item	2651565	et	4	main
ja	doc_491521502275_item	2651567	et	3	main
avalikustamine	doc_491521502275_item	2651566	et	4	main
tühjendamine	doc_491521502275_item	2651568	et	4	main
ja	doc_491521502275_item	2651569	et	3	main
see	doc_491521502275_item	2651570	et	3	main
tõigi	doc_491521502275_item	2651571	et	4	main
oma	doc_491521502275_item	2651572	et	4	main
tulemusi	doc_491521502275_item	2651573	et	4	main
mrp	doc_491521502275_item	2651574	et	4	main
tühjendati	doc_491521502275_item	2651575	et	3	main
läti	doc_491521502275_item	2651577	et	4	main
eesti	doc_491521502275_item	2651576	et	4	main
ja	doc_491521502275_item	2651578	et	3	main
leedu	doc_491521502275_item	2651579	et	4	main
sai	doc_491521502275_item	2651580	et	4	main
õiguse	doc_491521502275_item	2651581	et	4	main
kuulutada	doc_491521502275_item	2651582	et	3	main
okupeeritud	doc_491521502275_item	2651583	et	4	main
nsvl	doc_491521502275_item	2651584	et	4	main
poolt	doc_491521502275_item	2651585	et	4	main
aladeks	doc_491521502275_item	2651586	et	3	main
olnud	doc_491521502275_item	2651590	et	4	main
asi	doc_491521502275_item	2651592	et	4	main
nii	doc_491521502275_item	2651595	et	3	main
niimoodi	doc_491521502275_item	2651599	et	3	main
narva	doc_491521502275_item	2651610	et	4	main
eestile	doc_491521502275_item	2651614	et	3	main
kuuluvaks	doc_491521502275_item	2651622	et	4	main
ei	doc_491521502275_item	2651628	et	4	main
eesti	doc_491521502275_item	2651635	et	4	main
üldiselt	doc_491521502275_item	2651640	et	4	main
balti	doc_491521502275_item	2651641	et	3	main
kett	doc_491521502275_item	2651642	et	4	main
oli	doc_491521502275_item	2651643	et	3	main
väga	doc_491521502275_item	2651644	et	3	main
laulev	doc_491521502275_item	2651650	et	4	main
maailm	doc_491521502275_item	2651653	et	3	main
muudatused	doc_491521502276_item	2651669	et	3	main
baltikumi	doc_491521502276_item	2651681	et	4	main
koole	doc_491521502276_item	2651687	et	4	main
aastal	doc_491521502276_item	2651721	et	3	main
euroopa	doc_491521502276_item	2651726	et	4	main
valitakse	doc_491521502276_item	2651730	et	3	main
32	doc_491521502276_item	2651751	et	2	main
kõrgharidust	doc_491521502276_item	2651756	et	4	main
rääkida	doc_491521502276_item	2651764	et	3	main
tõuseb	doc_491521502276_item	2651765	et	3	main
kus	doc_491521502276_item	2651782	et	3	main
2	doc_491521502277_item	2651798	et	2	main
sündmus	doc_491521502277_item	2651800	et	3	main
rahavstele	doc_491521502277_item	2651807	et	4	main
ja	doc_491521502277_item	2651808	et	3	main
tuli	doc_491521502277_item	2651821	et	4	main
alkoholi	doc_491521502277_item	2651823	et	4	main
poliitikaga	doc_491521502277_item	2651824	et	3	main
tema	doc_491521502277_item	2651825	et	4	main
valitsemisaeg	doc_491521502277_item	2651826	et	3	main
oli	doc_491521502277_item	2651827	et	3	main
perstroika	doc_491521502277_item	2651846	et	4	main
selgus	doc_491521502277_item	2651848	et	4	main
ja	doc_491521502277_item	2651849	et	3	main
uutmine	doc_491521502277_item	2651852	et	4	main
ja	doc_491521502277_item	2651853	et	3	main
glasnost	doc_491521502277_item	2651854	et	4	main
kuritegu	doc_491521502277_item	2651858	et	4	main
kontrolliti	doc_491521502277_item	2651862	et	3	main
ehk	doc_491521502277_item	2651864	et	3	main
gorbatsov	doc_491521502277_item	2651873	et	4	main
alkohooli	doc_491521502277_item	2651878	et	3	main
aa	doc_491521502277_item	2651881	et	3	main
moskvas	doc_491521502277_item	2651883	et	4	main
üüritus	doc_491521502277_item	2651885	et	4	main
kirjanikud	doc_491521502277_item	2651886	et	3	main
rr	doc_491521502277_item	2651896	et	4	main
sellele	doc_491521502277_item	2651899	et	4	main
nsvl	doc_491521502277_item	2651905	et	4	main
eesti	doc_491521502277_item	2651925	et	4	main
kodanikuks	doc_491521502277_item	2651926	et	4	main
ilmub	doc_491521502277_item	2651927	et	3	main
poliitiliselt	doc_491521502277_item	2651935	et	4	main
iseseisvaks	doc_491521502277_item	2651936	et	3	main
1988	doc_491521502277_item	2651938	et	2	main
korda	doc_491521502277_item	2651945	et	4	main
avalikult	doc_491521502277_item	2651948	et	4	main
rolli	doc_491521502277_item	2651952	et	4	main
pensionisüsteem	doc_491521502277_item	2651980	et	3	main
ei	doc_491521502277_item	2651982	et	4	main
eesti	doc_491521502277_item	2652006	et	4	main
mis	doc_491521502277_item	2652010	et	4	main
nsvl-s	doc_491521502277_item	2652011	et	3	main
soovitavad	doc_491521502277_item	2652014	et	4	main
kord	doc_491521502277_item	2652025	et	4	main
iseseisvumist	doc_491521502277_item	2652027	et	3	main
eesti	doc_491521502277_item	2652033	et	4	main
kroon	doc_491521502277_item	2652034	et	3	main
valitakse	doc_491521502277_item	2652035	et	3	main
ja	doc_491521502277_item	2652043	et	3	main
süsteemi	doc_491521502277_item	2652055	et	4	main
nt	doc_491521502277_item	2652060	et	4	main
gümnaasium	doc_491521502277_item	2652064	et	3	main
teaduskonnas	doc_491521502277_item	2652067	et	4	main
peeti	doc_491521502275_item	2651620	et	4	main
neid	doc_491521502275_item	2651625	et	4	main
ja	doc_491521502275_item	2651636	et	3	main
vahel	doc_491521502275_item	2651638	et	4	main
baltikumi	doc_491521502275_item	2651659	et	4	main
maailma	doc_491521502275_item	2651662	et	4	main
oli	doc_491521502276_item	2651676	et	3	main
balti	doc_491521502276_item	2651677	et	3	main
kett	doc_491521502276_item	2651678	et	4	main
ja	doc_491521502276_item	2651683	et	3	main
maailmale	doc_491521502276_item	2651684	et	4	main
1	doc_491521502276_item	2651685	et	2	main
televisioon	doc_491521502276_item	2651698	et	4	main
parem	doc_491521502276_item	2651701	et	4	main
1989	doc_491521502276_item	2651702	et	2	main
a	doc_491521502276_item	2651703	et	4	main
toimus	doc_491521502276_item	2651704	et	3	main
rahvalaul	doc_491521502276_item	2651705	et	4	main
paljud	doc_491521502276_item	2651706	et	3	main
eestlased	doc_491521502276_item	2651707	et	3	main
olid	doc_491521502276_item	2651708	et	4	main
kohal	doc_491521502276_item	2651709	et	4	main
ja	doc_491521502276_item	2651710	et	3	main
laulsid	doc_491521502276_item	2651711	et	4	main
eesti	doc_491521502276_item	2651712	et	4	main
rahvalaule	doc_491521502276_item	2651713	et	4	main
1992	doc_491521502276_item	2651714	et	2	main
a	doc_491521502276_item	2651715	et	4	main
tuleb	doc_491521502276_item	2651716	et	3	main
eestisse	doc_491521502276_item	2651717	et	4	main
kroon	doc_491521502276_item	2651718	et	3	main
ja	doc_491521502276_item	2651719	et	3	main
samal	doc_491521502276_item	2651720	et	3	main
lennart	doc_491521502276_item	2651734	et	4	main
meri	doc_491521502276_item	2651735	et	3	main
pärnapikme	doc_491521502276_item	2651741	et	4	main
hakkatakse	doc_491521502276_item	2651744	et	4	main
uusi	doc_491521502276_item	2651746	et	3	main
loenguid	doc_491521502276_item	2651747	et	4	main
tahetakse	doc_491521502276_item	2651748	et	4	main
minna	doc_491521502276_item	2651749	et	3	main
süsteemile	doc_491521502276_item	2651750	et	3	main
kolledž	doc_491521502276_item	2651752	et	2	main
hakkab	doc_491521502276_item	2651753	et	3	main
andma	doc_491521502276_item	2651754	et	3	main
ka	doc_491521502276_item	2651755	et	3	main
mitte	doc_491521502276_item	2651757	et	3	main
ainult	doc_491521502276_item	2651758	et	4	main
kett	doc_491521502276_item	2651775	et	4	main
1989	doc_491521502276_item	2651777	et	2	main
oli	doc_491521502276_item	2651780	et	3	main
ja	doc_491521502276_item	2651785	et	3	main
piiriprobleemi	doc_491521502276_item	2651789	et	4	main
1	doc_491521502277_item	2651791	et	2	main
ja	doc_491521502277_item	2651793	et	3	main
muudatused	doc_491521502277_item	2651794	et	3	main
taasiseseisvunud	doc_491521502277_item	2651795	et	4	main
balti	doc_491521502277_item	2651802	et	3	main
tähendus	doc_491521502277_item	2651805	et	4	main
tõuseb	doc_491521502276_item	2651722	et	3	main
liitu	doc_491521502276_item	2651727	et	4	main
esimene	doc_491521502276_item	2651731	et	3	main
president	doc_491521502276_item	2651733	et	3	main
ja	doc_491521502276_item	2651736	et	3	main
olid	doc_491521502276_item	2651739	et	4	main
keel	doc_491521502276_item	2651769	et	4	main
seda	doc_491521502276_item	2651770	et	3	main
hakatakse	doc_491521502276_item	2651771	et	3	main
arutlema	doc_491521502276_item	2651772	et	3	main
balti	doc_491521502276_item	2651774	et	3	main
leedu	doc_491521502276_item	2651784	et	4	main
eesti	doc_491521502276_item	2651786	et	4	main
tähendas	doc_491521502276_item	2651788	et	3	main
kontrolltöö	doc_491521502277_item	2651790	et	4	main
mis	doc_491521502277_item	2651799	et	4	main
kett	doc_491521502277_item	2651803	et	4	main
maailmale	doc_491521502277_item	2651809	et	4	main
1	doc_491521502277_item	2651810	et	2	main
1980-ndatel	doc_491521502277_item	2651811	et	4	main
aastatel	doc_491521502277_item	2651812	et	4	main
valitsuses	doc_491521502277_item	2651813	et	4	main
hakati	doc_491521502277_item	2651814	et	3	main
juhte	doc_491521502277_item	2651815	et	4	main
vahetama	doc_491521502277_item	2651816	et	3	main
brežnevi	doc_491521502277_item	2651818	et	2	main
pärast	doc_491521502277_item	2651817	et	4	main
surma	doc_491521502277_item	2651819	et	4	main
võimule	doc_491521502277_item	2651820	et	3	main
lühike	doc_491521502277_item	2651828	et	4	main
tsernenko	doc_491521502277_item	2651832	et	4	main
uutmoodi	doc_491521502277_item	2651844	et	3	main
glasnost	doc_491521502277_item	2651847	et	4	main
poliitikas	doc_491521502277_item	2651851	et	3	main
seal	doc_491521502277_item	2651872	et	4	main
selle	doc_491521502277_item	2651887	et	4	main
saab	doc_491521502277_item	2651891	et	3	main
rahvaste	doc_491521502277_item	2651894	et	4	main
keeltega	doc_491521502277_item	2651895	et	3	main
oli	doc_491521502277_item	2651901	et	3	main
see	doc_491521502277_item	2651903	et	3	main
dokument	doc_491521502277_item	2651928	et	3	main
olla	doc_491521502277_item	2651937	et	3	main
eesti	doc_491521502277_item	2651940	et	4	main
toetas	doc_491521502277_item	2651946	et	3	main
ja	doc_491521502277_item	2651971	et	3	main
vett	doc_491521502277_item	2651972	et	3	main
ei	doc_491521502277_item	2651973	et	4	main
kuid	doc_491521502277_item	2651984	et	4	main
hakkas	doc_491521502277_item	2651987	et	3	main
80	doc_491521502277_item	2651989	et	2	main
lõpp	doc_491521502277_item	2651990	et	3	main
rahvarevolutsioon	doc_491521502277_item	2651992	et	3	main
gorbatšov	doc_491521502277_item	2651994	et	2	main
külastab	doc_491521502277_item	2651995	et	3	main
eesti	doc_491521502277_item	2651997	et	4	main
laulis	doc_491521502277_item	2651999	et	4	main
oma	doc_491521502277_item	2652000	et	4	main
kinnitab	doc_491521502277_item	2652023	et	3	main
eesti	doc_491521502277_item	2652026	et	4	main
ev	doc_491521502277_item	2652028	et	4	main
nimetus	doc_491521502277_item	2652029	et	4	main
jälle	doc_491521502277_item	2652030	et	3	main
aasta	doc_491521502277_item	2652039	et	4	main
hiljem	doc_491521502277_item	2652040	et	3	main
vahetati	doc_491521502277_item	2652056	et	4	main
ehk	doc_491521502277_item	2652057	et	3	main
õppetool	doc_491521502277_item	2652062	et	3	main
ilmus	doc_491521502277_item	2652070	et	4	main
101	doc_491521502276_item	2651740	et	2	main
tartu	doc_491521502276_item	2651742	et	4	main
ülikoolis	doc_491521502276_item	2651743	et	4	main
väga	doc_491521502276_item	2651762	et	3	main
küsimus	doc_491521502276_item	2651766	et	4	main
mis	doc_491521502276_item	2651767	et	4	main
on	doc_491521502276_item	2651768	et	4	main
see	doc_491521502276_item	2651779	et	3	main
ühenesid	doc_491521502276_item	2651783	et	4	main
muutused	doc_491521502277_item	2651792	et	4	main
kultuurielus	doc_491521502277_item	2651797	et	4	main
oli	doc_491521502277_item	2651801	et	3	main
järel	doc_491521502277_item	2651830	et	4	main
gorbatšov	doc_491521502277_item	2651837	et	2	main
on	doc_491521502277_item	2651840	et	4	main
2	doc_491521502277_item	2651841	et	2	main
kaasa	doc_491521502277_item	2651856	et	4	main
majandus	doc_491521502277_item	2651859	et	4	main
madalseisu	doc_491521502277_item	2651861	et	4	main
inimesi	doc_491521502277_item	2651863	et	4	main
kas	doc_491521502277_item	2651865	et	3	main
nad	doc_491521502277_item	2651866	et	3	main
tööd	doc_491521502277_item	2651868	et	4	main
poliitikat	doc_491521502277_item	2651879	et	3	main
teemaks	doc_491521502277_item	2651888	et	4	main
nsvl	doc_491521502277_item	2651892	et	4	main
oli	doc_491521502277_item	2651904	et	3	main
kuhu	doc_491521502277_item	2651921	et	3	main
registreerida	doc_491521502277_item	2651924	et	3	main
suveräänsusdeklaratsioon	doc_491521502277_item	2651929	et	3	main
ime	doc_491521502277_item	2651931	et	4	main
eesti	doc_491521502277_item	2651933	et	4	main
a	doc_491521502277_item	2651939	et	4	main
kommunistlik	doc_491521502277_item	2651941	et	3	main
pleenum	doc_491521502277_item	2651943	et	3	main
esimesti	doc_491521502277_item	2651944	et	4	main
rr	doc_491521502277_item	2651947	et	4	main
ekp	doc_491521502277_item	2651949	et	4	main
kaotab	doc_491521502277_item	2651950	et	3	main
see	doc_491521502277_item	2651953	et	3	main
mõõdetud	doc_491521502277_item	2651974	et	4	main
suur	doc_491521502277_item	2651975	et	3	main
avaldus	doc_491521502277_item	2651976	et	4	main
ravimid	doc_491521502277_item	2651978	et	3	main
varem	doc_491521502277_item	2651981	et	4	main
olnud	doc_491521502277_item	2651983	et	4	main
see	doc_491521502277_item	2651986	et	3	main
ammenduma	doc_491521502277_item	2651988	et	3	main
maad	doc_491521502277_item	2652001	et	4	main
vabaks	doc_491521502277_item	2652002	et	3	main
1989	doc_491521502277_item	2652003	et	2	main
24	doc_491521502277_item	2652004	et	2	main
veebruar	doc_491521502277_item	2652005	et	3	main
ei	doc_491521502277_item	2652012	et	4	main
folklooriorganisatsioon	doc_491521502277_item	2652016	et	3	main
aa	doc_491521502277_item	2652018	et	3	main
tema	doc_491521502277_item	2651829	et	4	main
1985	doc_491521502277_item	2651833	et	2	main
võimule	doc_491521502277_item	2651835	et	3	main
märksõna	doc_491521502277_item	2651842	et	4	main
uutmine	doc_491521502277_item	2651843	et	4	main
tõid	doc_491521502277_item	2651855	et	4	main
näitas	doc_491521502277_item	2651860	et	3	main
käivad	doc_491521502277_item	2651871	et	4	main
püütis	doc_491521502277_item	2651874	et	4	main
jätkata	doc_491521502277_item	2651875	et	4	main
andropovi	doc_491521502277_item	2651877	et	4	main
väike	doc_491521502277_item	2651893	et	4	main
massorganisatsioon	doc_491521502277_item	2651898	et	3	main
vastaseks	doc_491521502277_item	2651900	et	3	main
interrinne	doc_491521502277_item	2651902	et	3	main
poolne	doc_491521502277_item	2651906	et	3	main
nõudis	doc_491521502277_item	2651907	et	3	main
nsvl	doc_491521502277_item	2651908	et	4	main
lammutamise	doc_491521502277_item	2651909	et	4	main
peatumist	doc_491521502277_item	2651910	et	4	main
kodanike	doc_491521502277_item	2651911	et	3	main
komitee	doc_491521502277_item	2651912	et	4	main
eesti	doc_491521502277_item	2651913	et	4	main
võiks	doc_491521502277_item	2651914	et	4	main
majanduslikult	doc_491521502277_item	2651915	et	4	main
autonoomseks	doc_491521502277_item	2651916	et	3	main
saada	doc_491521502277_item	2651917	et	4	main
annab	doc_491521502277_item	2651918	et	3	main
välja	doc_491521502277_item	2651919	et	4	main
dokumenti	doc_491521502277_item	2651920	et	4	main
valitsemisel	doc_491521502277_item	2651839	et	4	main
poliitika	doc_491521502277_item	2651845	et	4	main
läbipaistvus	doc_491521502277_item	2651850	et	4	main
stalinismi	doc_491521502277_item	2651857	et	4	main
teevad	doc_491521502277_item	2651867	et	3	main
või	doc_491521502277_item	2651869	et	4	main
lihtsalt	doc_491521502277_item	2651870	et	4	main
samuti	doc_491521502277_item	2651876	et	3	main
1980	doc_491521502277_item	2651880	et	2	main
lõpul	doc_491521502277_item	2651882	et	3	main
toimus	doc_491521502277_item	2651884	et	3	main
oli	doc_491521502277_item	2651889	et	3	main
mis	doc_491521502277_item	2651890	et	4	main
oli	doc_491521502277_item	2651897	et	3	main
idee	doc_491521502277_item	2651932	et	4	main
võiks	doc_491521502277_item	2651934	et	4	main
partei	doc_491521502277_item	2651942	et	4	main
oma	doc_491521502277_item	2651951	et	4	main
ei	doc_491521502277_item	2651954	et	4	main
suuda	doc_491521502277_item	2651955	et	4	main
enamkontrollida	doc_491521502277_item	2651956	et	4	main
meditsiiniks	doc_491521502277_item	2651977	et	3	main
tasapisi	doc_491521502277_item	2651985	et	3	main
laulupidu	doc_491521502277_item	2651991	et	4	main
1987	doc_491521502277_item	2651993	et	2	main
veel	doc_491521502277_item	2652024	et	4	main
kongressi	doc_491521502277_item	2652036	et	4	main
e	doc_491521502277_item	2652037	et	4	main
savisaar	doc_491521502277_item	2652038	et	3	main
presidenti	doc_491521502277_item	2652044	et	4	main
hariduses	doc_491521502277_item	2652050	et	3	main
samuti	doc_491521502277_item	2652051	et	3	main
toimuvad	doc_491521502277_item	2652052	et	4	main
ümbernimetus	doc_491521502277_item	2652058	et	4	main
õppimissuunad	doc_491521502277_item	2652069	et	3	main
saada	doc_491521502277_item	2652074	et	4	main
uut	doc_491521502277_item	2652075	et	3	main
rakendusharidust	doc_491521502277_item	2652076	et	4	main
vanad	doc_491521502277_item	2652077	et	3	main
nimetused	doc_491521502277_item	2652078	et	4	main
taastati	doc_491521502277_item	2652079	et	4	main
koolid	doc_491521502277_item	2652080	et	3	main
hakati	doc_491521502277_item	2652081	et	3	main
nimetama	doc_491521502277_item	2652082	et	3	main
pandud	doc_491521502277_item	2652087	et	4	main
eesti	doc_491521502277_item	2652103	et	4	main
ei	doc_491521502277_item	2652105	et	4	main
rakendusliku	doc_491521502277_item	2652107	et	3	main
vaja	doc_491521502277_item	2652113	et	4	main
pandi	doc_491521502277_item	2652115	et	4	main
juba	doc_491521502277_item	2652116	et	3	main
algkoolidest	doc_491521502277_item	2652117	et	3	main
eesti	doc_491521502277_item	2652123	et	4	main
lätis	doc_491521502277_item	2652127	et	4	main
kuid	doc_491521502277_item	2652138	et	4	main
1994	doc_491521502277_item	2652147	et	2	main
kett	doc_491521502277_item	2652153	et	4	main
aset	doc_491521502277_item	2652156	et	3	main
algul	doc_491521502277_item	2652159	et	4	main
et	doc_491521502277_item	2652162	et	3	main
iseseisvateks	doc_491521502277_item	2652165	et	3	main
oli	doc_491521502277_item	2652167	et	3	main
organiseeritud	doc_491521502277_item	2652169	et	4	main
kinni	doc_491521502277_item	2652176	et	3	main
moodustati	doc_491521502277_item	2652178	et	3	main
ketti	doc_491521502277_item	2652180	et	4	main
miljonit	doc_491521502277_item	2652184	et	3	main
kett	doc_491521502277_item	2652186	et	4	main
arvan	doc_491521502277_item	2652190	et	3	main
rahvas	doc_491521502277_item	2652192	et	4	main
ning	doc_491521502277_item	2652219	et	3	main
nad	doc_491521502277_item	2652221	et	3	main
balti	doc_491521502277_item	2652227	et	3	main
eesti	doc_491521502277_item	2652229	et	4	main
1	doc_491521502277_item	2652240	et	2	main
kord	doc_491521502277_item	2652241	et	4	main
ja	doc_491521502277_item	2652242	et	3	main
võis	doc_491521502277_item	2651922	et	4	main
end	doc_491521502277_item	2651923	et	4	main
1988	doc_491521502277_item	2651930	et	2	main
süsteemi	doc_491521502277_item	2651957	et	4	main
mõni	doc_491521502277_item	2651958	et	3	main
aeg	doc_491521502277_item	2651959	et	3	main
eestis	doc_491521502277_item	2651960	et	3	main
oli	doc_491521502277_item	2651961	et	3	main
dotatsioon	doc_491521502277_item	2651962	et	3	main
seda	doc_491521502277_item	2651963	et	3	main
peeti	doc_491521502277_item	2651964	et	4	main
heaks	doc_491521502277_item	2651965	et	4	main
süsteemiks	doc_491521502277_item	2651966	et	3	main
elekter	doc_491521502277_item	2651967	et	3	main
ei	doc_491521502277_item	2651968	et	4	main
maksnud	doc_491521502277_item	2651969	et	4	main
kütust	doc_491521502277_item	2651970	et	4	main
tasuta	doc_491521502277_item	2651979	et	4	main
eestit	doc_491521502277_item	2651996	et	3	main
rahvas	doc_491521502277_item	2651998	et	4	main
iseseisvuspäev	doc_491521502277_item	2652007	et	3	main
peatakse	doc_491521502277_item	2652008	et	3	main
peod	doc_491521502277_item	2652009	et	4	main
olnud	doc_491521502277_item	2652013	et	4	main
ilmub	doc_491521502277_item	2652015	et	3	main
1990	doc_491521502277_item	2652017	et	2	main
venemaal	doc_491521502277_item	2652019	et	4	main
võimule	doc_491521502277_item	2652020	et	3	main
tuleb	doc_491521502277_item	2652021	et	3	main
kasutusele	doc_491521502277_item	2652031	et	4	main
ilmub	doc_491521502277_item	2652032	et	3	main
valitakse	doc_491521502277_item	2652041	et	3	main
riigikogu	doc_491521502277_item	2652042	et	4	main
muutused	doc_491521502277_item	2652053	et	4	main
toimus	doc_491521502277_item	2652059	et	3	main
keskkool	doc_491521502277_item	2652063	et	4	main
mõned	doc_491521502277_item	2652066	et	3	main
võis	doc_491521502277_item	2652073	et	4	main
enam	doc_491521502277_item	2652085	et	4	main
eesti	doc_491521502277_item	2652093	et	4	main
keelt	doc_491521502277_item	2652094	et	4	main
hakati	doc_491521502277_item	2652095	et	3	main
teistele	doc_491521502277_item	2652098	et	4	main
nsvl	doc_491521502277_item	2652101	et	4	main
olnud	doc_491521502277_item	2652106	et	4	main
see	doc_491521502277_item	2652109	et	3	main
keelt	doc_491521502277_item	2652119	et	4	main
õppima	doc_491521502277_item	2652120	et	3	main
1990	doc_491521502277_item	2652121	et	2	main
hirm	doc_491521502277_item	2652126	et	3	main
ja	doc_491521502277_item	2652128	et	3	main
leedus	doc_491521502277_item	2652129	et	4	main
välja	doc_491521502277_item	2652137	et	4	main
tuli	doc_491521502277_item	2652140	et	4	main
aastal	doc_491521502277_item	2652148	et	3	main
eestist	doc_491521502277_item	2652150	et	3	main
balti	doc_491521502277_item	2652152	et	3	main
leidis	doc_491521502277_item	2652155	et	4	main
inimesed	doc_491521502277_item	2652160	et	3	main
tundsid	doc_491521502277_item	2652161	et	4	main
baltikumis	doc_491521502277_item	2652171	et	4	main
teine	doc_491521502277_item	2652173	et	3	main
teist	doc_491521502277_item	2652174	et	4	main
see	doc_491521502277_item	2652185	et	3	main
üle	doc_491521502277_item	2652188	et	3	main
tõestas	doc_491521502277_item	2652194	et	3	main
väikesed	doc_491521502277_item	2652225	et	4	main
rolli	doc_491521502277_item	2652233	et	4	main
ainult	doc_491521502277_item	2652239	et	4	main
jeltsin	doc_491521502277_item	2652022	et	4	main
l	doc_491521502277_item	2652045	et	4	main
meri	doc_491521502277_item	2652046	et	3	main
pärast	doc_491521502277_item	2652047	et	4	main
eesti	doc_491521502277_item	2652048	et	4	main
iseseisvumist	doc_491521502277_item	2652049	et	3	main
kõrgkooli	doc_491521502277_item	2652054	et	4	main
kateeder	doc_491521502277_item	2652061	et	3	main
taastati	doc_491521502277_item	2652065	et	4	main
siin	doc_491521502277_item	2652072	et	4	main
õpetama	doc_491521502277_item	2652096	et	3	main
kuid	doc_491521502277_item	2652100	et	4	main
kasu	doc_491521502277_item	2652108	et	4	main
vene	doc_491521502277_item	2652118	et	4	main
ja	doc_491521502277_item	2652068	et	3	main
kolledž	doc_491521502277_item	2652071	et	2	main
ei	doc_491521502277_item	2652086	et	4	main
kadusid	doc_491521502277_item	2652089	et	4	main
kõrgkooli	doc_491521502277_item	2652091	et	4	main
mütsid	doc_491521502277_item	2652092	et	3	main
ka	doc_491521502277_item	2652097	et	3	main
ajal	doc_491521502277_item	2652102	et	4	main
eriti	doc_491521502277_item	2652111	et	3	main
algus	doc_491521502277_item	2652122	et	4	main
rahval	doc_491521502277_item	2652124	et	3	main
oli	doc_491521502277_item	2652125	et	3	main
iseseisvumisteele	doc_491521502277_item	2652144	et	3	main
võõrad	doc_491521502277_item	2652145	et	3	main
2	doc_491521502277_item	2652151	et	2	main
võivad	doc_491521502277_item	2652163	et	4	main
see	doc_491521502277_item	2652166	et	3	main
rahvaga	doc_491521502277_item	2652168	et	3	main
inimesed	doc_491521502277_item	2652170	et	3	main
käest	doc_491521502277_item	2652175	et	4	main
nagu	doc_491521502277_item	2652179	et	3	main
selles	doc_491521502277_item	2652181	et	4	main
mängisid	doc_491521502277_item	2652231	et	4	main
teatud	doc_491521502277_item	2652234	et	4	main
oli	doc_491521502277_item	2652238	et	3	main
millegi	doc_491521502277_item	2652083	et	4	main
järgi	doc_491521502277_item	2652084	et	4	main
numbrid	doc_491521502277_item	2652088	et	3	main
erivärvi	doc_491521502277_item	2652090	et	4	main
rahvastele	doc_491521502277_item	2652099	et	4	main
keelel	doc_491521502277_item	2652104	et	4	main
polnud	doc_491521502277_item	2652110	et	3	main
elus	doc_491521502277_item	2652112	et	4	main
lapsi	doc_491521502277_item	2652114	et	4	main
oma	doc_491521502277_item	2652143	et	4	main
sõjaväed	doc_491521502277_item	2652146	et	3	main
lahkusid	doc_491521502277_item	2652149	et	4	main
1990	doc_491521502277_item	2652157	et	2	main
võtsid	doc_491521502277_item	2652172	et	4	main
ja	doc_491521502277_item	2652177	et	3	main
2-3	doc_491521502277_item	2652183	et	2	main
ulatus	doc_491521502277_item	2652187	et	4	main
kõigile	doc_491521502277_item	2652223	et	4	main
rahvapüüed	doc_491521502277_item	2652226	et	4	main
suurt	doc_491521502277_item	2652232	et	3	main
momendil	doc_491521502277_item	2652235	et	3	main
see	doc_491521502277_item	2652236	et	3	main
hetk	doc_491521502277_item	2652237	et	3	main
olid	doc_491521502277_item	2652130	et	4	main
vene	doc_491521502277_item	2652131	et	4	main
sõjaväed	doc_491521502277_item	2652132	et	3	main
kardeti	doc_491521502277_item	2652133	et	3	main
et	doc_491521502277_item	2652134	et	3	main
elekter	doc_491521502277_item	2652135	et	3	main
lülitatakse	doc_491521502277_item	2652136	et	3	main
eesti	doc_491521502277_item	2652139	et	4	main
veretult	doc_491521502277_item	2652141	et	4	main
välja	doc_491521502277_item	2652142	et	4	main
see	doc_491521502277_item	2652154	et	3	main
aa	doc_491521502277_item	2652158	et	3	main
saada	doc_491521502277_item	2652164	et	4	main
osalesid	doc_491521502277_item	2652182	et	4	main
baltikumi	doc_491521502277_item	2652189	et	4	main
et	doc_491521502277_item	2652191	et	3	main
maailmale	doc_491521502277_item	2652195	et	4	main
sellega	doc_491521502277_item	2652193	et	3	main
oma	doc_491521502277_item	2652196	et	4	main
püsivust	doc_491521502277_item	2652197	et	4	main
soovi	doc_491521502277_item	2652198	et	4	main
ja	doc_491521502277_item	2652199	et	3	main
võimet	doc_491521502277_item	2652200	et	3	main
saada	doc_491521502277_item	2652201	et	4	main
iseseisvaks	doc_491521502277_item	2652202	et	3	main
ja	doc_491521502277_item	2652203	et	3	main
eelkõige	doc_491521502277_item	2652204	et	3	main
see	doc_491521502277_item	2652205	et	3	main
oli	doc_491521502277_item	2652206	et	3	main
tähti	doc_491521502277_item	2652207	et	4	main
nendele	doc_491521502277_item	2652208	et	4	main
endale	doc_491521502277_item	2652209	et	4	main
nad	doc_491521502277_item	2652210	et	3	main
said	doc_491521502277_item	2652211	et	4	main
aru	doc_491521502277_item	2652212	et	4	main
et	doc_491521502277_item	2652213	et	3	main
neid	doc_491521502277_item	2652214	et	4	main
seob	doc_491521502277_item	2652215	et	3	main
ühtsustunne	doc_491521502277_item	2652216	et	3	main
ja	doc_491521502277_item	2652217	et	3	main
toetus	doc_491521502277_item	2652218	et	4	main
seda	doc_491521502277_item	2652220	et	3	main
demonstreerisid	doc_491521502277_item	2652222	et	4	main
need	doc_491521502277_item	2652224	et	3	main
kett	doc_491521502277_item	2652228	et	4	main
laul	doc_491521502277_item	2652230	et	4	main
rahvas	doc_491521502277_item	2652243	et	4	main
kasutas	doc_491521502277_item	2652244	et	3	main
seda	doc_491521502277_item	2652245	et	3	main
ning	doc_491521502277_item	2652246	et	3	main
see	doc_491521502277_item	2652247	et	3	main
jääb	doc_491521502277_item	2652248	et	3	main
ajalukku	doc_491521502277_item	2652249	et	4	main
kontrolltöö	doc_491521502280_item	2652962	et	4	main
mida	doc_491521502280_item	2652972	et	4	main
tähendab	doc_491521502280_item	2652973	et	3	main
eesti	doc_491521502280_item	2652980	et	4	main
poliitilises	doc_491521502280_item	2652981	et	3	main
elus	doc_491521502280_item	2652982	et	4	main
oli	doc_491521502280_item	2652989	et	3	main
sellega	doc_491521502280_item	2652990	et	3	main
eesti	doc_491521502280_item	2653022	et	4	main
juhtima	doc_491521502280_item	2653038	et	4	main
tunnistas	doc_491521502280_item	2653044	et	3	main
sellele	doc_491521502280_item	2653069	et	4	main
selle	doc_491521502280_item	2653078	et	4	main
elluviimine	doc_491521502280_item	2653079	et	3	main
maadele	doc_491521502280_item	2653100	et	4	main
tol	doc_491521502280_item	2653104	et	3	main
pankrotti	doc_491521502280_item	2653106	et	4	main
raske	doc_491521502280_item	2653112	et	4	main
põhiseadus	doc_491521502280_item	2653131	et	4	main
kroon	doc_491521502280_item	2653138	et	3	main
margaga	doc_491521502280_item	2653145	et	3	main
reformi	doc_491521502280_item	2653159	et	4	main
taasiseseisvunud	doc_491521502280_item	2652986	et	4	main
tihedalt	doc_491521502280_item	2652991	et	4	main
ja	doc_491521502280_item	2653024	et	3	main
kasutusele	doc_491521502280_item	2653027	et	4	main
eesti	doc_491521502280_item	2653029	et	4	main
1991	doc_491521502280_item	2653041	et	2	main
ametlikult	doc_491521502280_item	2653045	et	4	main
iseseisvust	doc_491521502280_item	2653047	et	4	main
ja	doc_491521502280_item	2653048	et	3	main
siis	doc_491521502280_item	2653049	et	3	main
eestis	doc_491521502280_item	2653050	et	3	main
hakkati	doc_491521502280_item	2653051	et	3	main
ellu	doc_491521502280_item	2653052	et	4	main
viima	doc_491521502280_item	2653053	et	3	main
uut	doc_491521502280_item	2653054	et	3	main
poliitikat	doc_491521502280_item	2653055	et	3	main
mitu	doc_491521502280_item	2653059	et	4	main
jooksul	doc_491521502280_item	2653061	et	4	main
muidugi	doc_491521502280_item	2653063	et	4	main
ime	doc_491521502280_item	2653064	et	4	main
et	doc_491521502280_item	2653070	et	3	main
see	doc_491521502280_item	2653071	et	3	main
peaks	doc_491521502280_item	2653072	et	4	main
tooma	doc_491521502280_item	2653073	et	3	main
oli	doc_491521502280_item	2653080	et	3	main
väga	doc_491521502280_item	2653081	et	3	main
probleemne	doc_491521502280_item	2653082	et	3	main
majandus	doc_491521502280_item	2653086	et	4	main
täiesti	doc_491521502280_item	2653088	et	3	main
nõukogude	doc_491521502280_item	2653089	et	3	main
oli	doc_491521502280_item	2653110	et	3	main
1992	doc_491521502280_item	2653114	et	2	main
1	doc_491521502280_item	2652963	et	2	main
muutused	doc_491521502280_item	2652964	et	4	main
taasiseseisvunud	doc_491521502280_item	2652967	et	4	main
eesti	doc_491521502280_item	2652968	et	4	main
poliitilises	doc_491521502280_item	2652969	et	3	main
elus	doc_491521502280_item	2652970	et	4	main
2	doc_491521502280_item	2652971	et	2	main
iseseisvusele	doc_491521502280_item	2652979	et	4	main
suured	doc_491521502280_item	2652984	et	3	main
edasiarenemine	doc_491521502280_item	2652988	et	3	main
sai	doc_491521502280_item	2652997	et	4	main
toimusid	doc_491521502280_item	2653021	et	4	main
kongressi	doc_491521502280_item	2653023	et	4	main
nimetus	doc_491521502280_item	2653031	et	4	main
algas	doc_491521502280_item	2653032	et	3	main
ülemineku	doc_491521502280_item	2653033	et	3	main
periood	doc_491521502280_item	2653034	et	3	main
uut	doc_491521502280_item	2653035	et	3	main
valitsust	doc_491521502280_item	2653036	et	4	main
hakkas	doc_491521502280_item	2653037	et	3	main
nliit	doc_491521502280_item	2653043	et	4	main
eesti	doc_491521502280_item	2653046	et	4	main
tähtsam	doc_491521502280_item	2653057	et	4	main
aasta	doc_491521502280_item	2653060	et	4	main
oli	doc_491521502280_item	2653062	et	3	main
eesti	doc_491521502280_item	2653067	et	4	main
vaatamata	doc_491521502280_item	2653068	et	4	main
tööstus	doc_491521502280_item	2653084	et	3	main
tuleks	doc_491521502280_item	2653096	et	4	main
orienteeruda	doc_491521502280_item	2653097	et	3	main
rohkem	doc_491521502280_item	2653098	et	4	main
lääne	doc_491521502280_item	2653099	et	4	main
läksid	doc_491521502280_item	2653103	et	4	main
ajal	doc_491521502280_item	2653105	et	4	main
sest	doc_491521502280_item	2653107	et	4	main
uue	doc_491521502280_item	2653108	et	3	main
süsteemiga	doc_491521502280_item	2653109	et	3	main
kõigepealt	doc_491521502280_item	2653121	et	3	main
võeti	doc_491521502280_item	2653136	et	3	main
oli	doc_491521502280_item	2653141	et	3	main
kaotasid	doc_491521502280_item	2653156	et	4	main
oma	doc_491521502280_item	2653157	et	4	main
seotud	doc_491521502280_item	2653163	et	4	main
ka	doc_491521502280_item	2653164	et	3	main
vabanemisega	doc_491521502280_item	2653165	et	4	main
võimalikult	doc_491521502280_item	2653172	et	4	main
maadel	doc_491521502280_item	2653176	et	4	main
tol	doc_491521502280_item	2653178	et	3	main
hakkasid	doc_491521502280_item	2653186	et	4	main
koos	doc_491521502280_item	2653188	et	4	main
nende	doc_491521502280_item	2653189	et	4	main
ja	doc_491521502280_item	2652965	et	3	main
muudatused	doc_491521502280_item	2652966	et	3	main
1	doc_491521502280_item	2652976	et	2	main
oma	doc_491521502280_item	2652977	et	4	main
teel	doc_491521502280_item	2652978	et	4	main
muutused	doc_491521502280_item	2652985	et	4	main
seotud	doc_491521502280_item	2652992	et	4	main
rõõm	doc_491521502280_item	2652993	et	3	main
sellest	doc_491521502280_item	2652994	et	4	main
et	doc_491521502280_item	2652995	et	3	main
eesti	doc_491521502280_item	2652996	et	4	main
lõpuks	doc_491521502280_item	2652998	et	4	main
iseseisvaks	doc_491521502280_item	2652999	et	3	main
ei	doc_491521502280_item	2653000	et	4	main
kestnud	doc_491521502280_item	2653001	et	4	main
väga	doc_491521502280_item	2653002	et	3	main
kaua	doc_491521502280_item	2653003	et	3	main
sest	doc_491521502280_item	2653004	et	4	main
kohe	doc_491521502280_item	2653005	et	4	main
tekkisid	doc_491521502280_item	2653006	et	4	main
ka	doc_491521502280_item	2653007	et	3	main
probleemid	doc_491521502280_item	2653008	et	3	main
eesti	doc_491521502280_item	2653009	et	4	main
ei	doc_491521502280_item	2653010	et	4	main
sõltunud	doc_491521502280_item	2653011	et	4	main
enam	doc_491521502280_item	2653012	et	4	main
nliidust	doc_491521502280_item	2653013	et	4	main
ja	doc_491521502280_item	2653014	et	3	main
peaks	doc_491521502280_item	2653015	et	4	main
ise	doc_491521502280_item	2653016	et	4	main
hakkama	doc_491521502280_item	2653017	et	3	main
saama	doc_491521502280_item	2653018	et	4	main
1989	doc_491521502280_item	2653019	et	2	main
aastal	doc_491521502280_item	2653020	et	3	main
laulev	doc_491521502280_item	2652974	et	4	main
revolutsioon	doc_491521502280_item	2652975	et	3	main
toimusid	doc_491521502280_item	2652983	et	4	main
eesti	doc_491521502280_item	2652987	et	4	main
valimised	doc_491521502280_item	2653026	et	4	main
e	doc_491521502280_item	2653039	et	4	main
savisaar	doc_491521502280_item	2653040	et	3	main
aastal	doc_491521502280_item	2653042	et	3	main
kõige	doc_491521502280_item	2653056	et	4	main
eesti	doc_491521502280_item	2653083	et	4	main
sõltus	doc_491521502280_item	2653087	et	4	main
liidust	doc_491521502280_item	2653090	et	4	main
siis	doc_491521502280_item	2653091	et	3	main
tuleks	doc_491521502280_item	2653092	et	4	main
alustada	doc_491521502280_item	2653093	et	3	main
kaubavahetuse	doc_491521502280_item	2653094	et	4	main
ümberehitamisest	doc_491521502280_item	2653095	et	3	main
paljud	doc_491521502280_item	2653101	et	3	main
väga	doc_491521502280_item	2653111	et	3	main
aasta	doc_491521502280_item	2653115	et	4	main
presidentiks	doc_491521502280_item	2653122	et	4	main
toimus	doc_491521502280_item	2653132	et	3	main
raha	doc_491521502280_item	2653133	et	4	main
reform	doc_491521502280_item	2653134	et	3	main
mille	doc_491521502280_item	2653139	et	3	main
seotud	doc_491521502280_item	2653143	et	4	main
muutused	doc_491521502280_item	2653147	et	4	main
halvenes	doc_491521502280_item	2653154	et	3	main
paljud	doc_491521502280_item	2653155	et	3	main
probleemid	doc_491521502280_item	2653161	et	3	main
olid	doc_491521502280_item	2653162	et	4	main
sedaprotsessi	doc_491521502280_item	2653174	et	4	main
juba	doc_491521502280_item	2653192	et	3	main
maadega	doc_491521502280_item	2653198	et	3	main
aga	doc_491521502280_item	2653200	et	3	main
ja	doc_491521502280_item	2653205	et	3	main
uut	doc_491521502280_item	2653208	et	3	main
eestlased	doc_491521502280_item	2653226	et	3	main
tegevus	doc_491521502280_item	2653237	et	4	main
ühendas	doc_491521502280_item	2653238	et	3	main
saanud	doc_491521502280_item	2653246	et	4	main
eesti	doc_491521502281_item	2653279	et	4	main
taasiseseisvunud	doc_491521502281_item	2653284	et	4	main
elus	doc_491521502281_item	2653287	et	4	main
eesti	doc_491521502281_item	2653305	et	4	main
taasiseseisvaks	doc_491521502281_item	2653307	et	3	main
aastal	doc_491521502281_item	2653309	et	3	main
sellele	doc_491521502281_item	2653311	et	4	main
eelnesid	doc_491521502281_item	2653312	et	4	main
meeleavaldused	doc_491521502281_item	2653313	et	3	main
rahvuslikud	doc_491521502281_item	2653314	et	3	main
tekkimine	doc_491521502281_item	2653325	et	4	main
balti	doc_491521502281_item	2653327	et	3	main
isegi	doc_491521502281_item	2653329	et	4	main
balti	doc_491521502281_item	2653331	et	3	main
miljonit	doc_491521502281_item	2653337	et	3	main
ülemnõukogu	doc_491521502281_item	2653358	et	4	main
1992	doc_491521502281_item	2653385	et	2	main
a	doc_491521502281_item	2653386	et	4	main
võeti	doc_491521502281_item	2653387	et	3	main
vastu	doc_491521502281_item	2653388	et	3	main
uus	doc_491521502281_item	2653389	et	3	main
parei	doc_491521502281_item	2653400	et	4	main
kuulus	doc_491521502281_item	2653403	et	4	main
president	doc_491521502281_item	2653406	et	3	main
suured	doc_491521502281_item	2653416	et	3	main
ülemnõukogu	doc_491521502280_item	2653025	et	4	main
võeti	doc_491521502280_item	2653028	et	3	main
vabariigi	doc_491521502280_item	2653030	et	3	main
juba	doc_491521502280_item	2653058	et	3	main
idee	doc_491521502280_item	2653065	et	4	main
isemajandav	doc_491521502280_item	2653066	et	3	main
kasu	doc_491521502280_item	2653074	et	4	main
kõigepealt	doc_491521502280_item	2653075	et	3	main
eesti	doc_491521502280_item	2653076	et	4	main
majandusele	doc_491521502280_item	2653077	et	4	main
ja	doc_491521502280_item	2653085	et	3	main
ettevõtted	doc_491521502280_item	2653102	et	3	main
kohandada	doc_491521502280_item	2653113	et	3	main
sai	doc_491521502280_item	2653116	et	4	main
väga	doc_491521502280_item	2653117	et	3	main
tähtsaks	doc_491521502280_item	2653118	et	4	main
poliitilise	doc_491521502280_item	2653119	et	3	main
seisukohast	doc_491521502280_item	2653120	et	4	main
sa	doc_491521502280_item	2653123	et	3	main
l	doc_491521502280_item	2653124	et	4	main
vastu	doc_491521502280_item	2653127	et	3	main
võetud	doc_491521502280_item	2653128	et	4	main
eesti	doc_491521502280_item	2653129	et	4	main
vabariigi	doc_491521502280_item	2653130	et	3	main
eesti	doc_491521502280_item	2653137	et	4	main
saksa	doc_491521502280_item	2653144	et	4	main
kelle	doc_491521502280_item	2653152	et	4	main
eluase	doc_491521502280_item	2653153	et	3	main
käigus	doc_491521502280_item	2653160	et	4	main
vene	doc_491521502280_item	2653168	et	4	main
sõjaväest	doc_491521502280_item	2653169	et	3	main
vene	doc_491521502280_item	2653170	et	4	main
balti	doc_491521502280_item	2653175	et	3	main
poliitika	doc_491521502280_item	2653190	et	4	main
oli	doc_491521502280_item	2653191	et	3	main
sõlmiti	doc_491521502280_item	2653195	et	3	main
tundsid	doc_491521502280_item	2653227	et	4	main
tugevam	doc_491521502280_item	2653231	et	4	main
tegutsevad	doc_491521502280_item	2653233	et	4	main
kõik	doc_491521502280_item	2653234	et	4	main
ei	doc_491521502280_item	2653245	et	4	main
rahvast	doc_491521502280_item	2653249	et	4	main
nõuded	doc_491521502280_item	2653253	et	3	main
revolutsioon	doc_491521502280_item	2653255	et	3	main
rahvuse	doc_491521502280_item	2653258	et	3	main
eesti	doc_491521502281_item	2653266	et	4	main
2	doc_491521502281_item	2653269	et	2	main
tähendab	doc_491521502281_item	2653271	et	3	main
laulev	doc_491521502281_item	2653272	et	4	main
revolutsioon	doc_491521502281_item	2653273	et	3	main
1991	doc_491521502281_item	2653276	et	2	main
a	doc_491521502281_item	2653277	et	4	main
kuulutas	doc_491521502281_item	2653278	et	3	main
poliitilises	doc_491521502281_item	2653286	et	3	main
varem	doc_491521502281_item	2653295	et	4	main
liikumised	doc_491521502281_item	2653315	et	4	main
rahvarinne	doc_491521502281_item	2653316	et	3	main
kuhu	doc_491521502281_item	2653317	et	3	main
s	doc_491521502281_item	2653321	et	4	main
riikides	doc_491521502281_item	2653328	et	3	main
kett	doc_491521502281_item	2653332	et	4	main
umbes	doc_491521502281_item	2653335	et	4	main
ei	doc_491521502281_item	2653340	et	4	main
elus	doc_491521502281_item	2653352	et	4	main
aastal	doc_491521502281_item	2653354	et	3	main
valimised	doc_491521502281_item	2653356	et	4	main
eesti	doc_491521502281_item	2653357	et	4	main
võeti	doc_491521502281_item	2653362	et	3	main
järgnesid	doc_491521502281_item	2653392	et	4	main
sai	doc_491521502281_item	2653411	et	4	main
esimeseks	doc_491521502281_item	2653412	et	3	main
eesti	doc_491521502281_item	2653432	et	4	main
poliitiline	doc_491521502281_item	2653433	et	3	main
euroopale	doc_491521502281_item	2653437	et	3	main
allkirjutatud	doc_491521502281_item	2653440	et	3	main
tähendab	doc_491521502281_item	2653445	et	3	main
ürosse	doc_491521502281_item	2653454	et	4	main
eestis	doc_491521502281_item	2653458	et	3	main
ka	doc_491521502281_item	2653460	et	3	main
meri	doc_491521502280_item	2653125	et	3	main
oli	doc_491521502280_item	2653126	et	3	main
kasutusele	doc_491521502280_item	2653135	et	4	main
kurss	doc_491521502280_item	2653140	et	3	main
rangelt	doc_491521502280_item	2653142	et	4	main
kõik	doc_491521502280_item	2653146	et	4	main
said	doc_491521502280_item	2653148	et	4	main
tõeliseks	doc_491521502280_item	2653149	et	4	main
sokiks	doc_491521502280_item	2653150	et	3	main
inimestele	doc_491521502280_item	2653151	et	3	main
raha	doc_491521502280_item	2653158	et	4	main
valitsus	doc_491521502280_item	2653171	et	4	main
oli	doc_491521502280_item	2653177	et	3	main
ajal	doc_491521502280_item	2653179	et	4	main
huvid	doc_491521502280_item	2653181	et	3	main
eesmärgid	doc_491521502280_item	2653183	et	3	main
nad	doc_491521502280_item	2653185	et	3	main
avatud	doc_491521502280_item	2653194	et	4	main
lääne	doc_491521502280_item	2653197	et	4	main
üldse	doc_491521502280_item	2653199	et	3	main
toimus	doc_491521502280_item	2653201	et	3	main
elu	doc_491521502280_item	2653203	et	4	main
elu	doc_491521502280_item	2653209	et	4	main
2	doc_491521502280_item	2653210	et	2	main
laulev	doc_491521502280_item	2653211	et	4	main
revolutsioon	doc_491521502280_item	2653212	et	3	main
sai	doc_491521502280_item	2653213	et	4	main
tähtsaks	doc_491521502280_item	2653214	et	4	main
etapiks	doc_491521502280_item	2653215	et	3	main
eesti	doc_491521502280_item	2653216	et	4	main
iseseisvuse	doc_491521502280_item	2653217	et	4	main
teel	doc_491521502280_item	2653218	et	4	main
1989	doc_491521502280_item	2653219	et	2	main
aastal	doc_491521502280_item	2653220	et	3	main
rahvas	doc_491521502280_item	2653222	et	4	main
et	doc_491521502280_item	2653228	et	3	main
kui	doc_491521502280_item	2653232	et	3	main
aitas	doc_491521502280_item	2653240	et	3	main
näidata	doc_491521502280_item	2653242	et	4	main
eesmärke	doc_491521502280_item	2653243	et	4	main
nende	doc_491521502280_item	2653250	et	4	main
ja	doc_491521502280_item	2653252	et	3	main
võimaluse	doc_491521502280_item	2653257	et	3	main
kontrolltöö	doc_491521502281_item	2653260	et	4	main
poliitilises	doc_491521502281_item	2653267	et	3	main
ülemnõukogu	doc_491521502281_item	2653280	et	4	main
palju	doc_491521502281_item	2653294	et	4	main
ma	doc_491521502281_item	2653303	et	3	main
kallas	doc_491521502281_item	2653322	et	4	main
osales	doc_491521502281_item	2653334	et	3	main
2	doc_491521502281_item	2653336	et	2	main
nime	doc_491521502281_item	2653338	et	4	main
seda	doc_491521502281_item	2653339	et	3	main
saa	doc_491521502281_item	2653341	et	4	main
jätta	doc_491521502281_item	2653342	et	3	main
eesti	doc_491521502281_item	2653350	et	4	main
kongressi	doc_491521502281_item	2653359	et	4	main
muudatus	doc_491521502281_item	2653383	et	4	main
et	doc_491521502281_item	2653384	et	3	main
paremtsentristlik	doc_491521502281_item	2653399	et	3	main
presidendiks	doc_491521502281_item	2653413	et	4	main
toimusid	doc_491521502281_item	2653418	et	4	main
poliitilises	doc_491521502281_item	2653420	et	3	main
elus	doc_491521502281_item	2653421	et	4	main
sellele	doc_491521502281_item	2653423	et	4	main
oli	doc_491521502281_item	2653438	et	3	main
euroopa	doc_491521502281_item	2653441	et	4	main
kaubandusleping	doc_491521502281_item	2653443	et	3	main
koostööd	doc_491521502281_item	2653447	et	4	main
eesti	doc_491521502280_item	2653166	et	4	main
territooriumit	doc_491521502280_item	2653167	et	3	main
pidurdas	doc_491521502280_item	2653173	et	3	main
samasugused	doc_491521502280_item	2653180	et	3	main
ja	doc_491521502280_item	2653182	et	3	main
siis	doc_491521502280_item	2653184	et	3	main
tegutsema	doc_491521502280_item	2653187	et	3	main
rohkem	doc_491521502280_item	2653193	et	4	main
kontaktid	doc_491521502280_item	2653196	et	3	main
poliitilise	doc_491521502280_item	2653202	et	3	main
ümberehitamine	doc_491521502280_item	2653204	et	3	main
eesti	doc_491521502280_item	2653206	et	4	main
algas	doc_491521502280_item	2653207	et	3	main
eesti	doc_491521502280_item	2653221	et	4	main
laulis	doc_491521502280_item	2653223	et	4	main
enda	doc_491521502280_item	2653224	et	4	main
vabaks	doc_491521502280_item	2653225	et	3	main
on	doc_491521502280_item	2653230	et	4	main
koos	doc_491521502280_item	2653235	et	4	main
rahvarinne	doc_491521502280_item	2653236	et	3	main
valitsus	doc_491521502280_item	2653244	et	4	main
ignoreerida	doc_491521502280_item	2653248	et	3	main
püüdlused	doc_491521502280_item	2653251	et	3	main
20	doc_491521502281_item	2653274	et	2	main
augustil	doc_491521502281_item	2653275	et	3	main
taastatuks	doc_491521502281_item	2653282	et	4	main
1	doc_491521502281_item	2653283	et	2	main
kui	doc_491521502281_item	2653296	et	3	main
eesti	doc_491521502281_item	2653297	et	4	main
sa	doc_491521502281_item	2653298	et	3	main
jäle	doc_491521502281_item	2653299	et	3	main
iseseisvaks	doc_491521502281_item	2653300	et	3	main
sest	doc_491521502281_item	2653301	et	4	main
nagu	doc_491521502281_item	2653302	et	3	main
sai	doc_491521502281_item	2653306	et	4	main
kuulusid	doc_491521502281_item	2653318	et	4	main
e	doc_491521502281_item	2653319	et	4	main
nad	doc_491521502280_item	2653229	et	3	main
rahvamasse	doc_491521502280_item	2653239	et	3	main
selgelt	doc_491521502280_item	2653241	et	4	main
enam	doc_491521502280_item	2653247	et	4	main
laulev	doc_491521502280_item	2653254	et	4	main
andis	doc_491521502280_item	2653256	et	3	main
eneseväljendamiseks	doc_491521502280_item	2653259	et	3	main
1	doc_491521502281_item	2653261	et	2	main
muutused	doc_491521502281_item	2653262	et	4	main
ja	doc_491521502281_item	2653263	et	3	main
muudatused	doc_491521502281_item	2653264	et	3	main
taasiseseisvunud	doc_491521502281_item	2653265	et	4	main
elus	doc_491521502281_item	2653268	et	4	main
mida	doc_491521502281_item	2653270	et	4	main
iseseisvuse	doc_491521502281_item	2653281	et	4	main
eesti	doc_491521502281_item	2653285	et	4	main
hakkasid	doc_491521502281_item	2653288	et	4	main
toimuma	doc_491521502281_item	2653289	et	3	main
muutused	doc_491521502281_item	2653290	et	4	main
ja	doc_491521502281_item	2653291	et	3	main
muudatused	doc_491521502281_item	2653292	et	3	main
juba	doc_491521502281_item	2653293	et	3	main
tean	doc_491521502281_item	2653304	et	3	main
1991	doc_491521502281_item	2653308	et	2	main
kuid	doc_491521502281_item	2653310	et	4	main
savisaar	doc_491521502281_item	2653320	et	3	main
tiitma	doc_491521502281_item	2653324	et	4	main
ja	doc_491521502281_item	2653326	et	3	main
milles	doc_491521502281_item	2653333	et	3	main
kui	doc_491521502281_item	2653344	et	3	main
räägime	doc_491521502281_item	2653345	et	3	main
muutuvatest	doc_491521502281_item	2653346	et	4	main
ja	doc_491521502281_item	2653347	et	3	main
muudatustest	doc_491521502281_item	2653348	et	3	main
taasisesisvunud	doc_491521502281_item	2653349	et	4	main
1991	doc_491521502281_item	2653353	et	2	main
enne	doc_491521502281_item	2653360	et	4	main
taasiseseisvumist	doc_491521502281_item	2653361	et	3	main
millele	doc_491521502281_item	2653391	et	3	main
ka	doc_491521502281_item	2653393	et	3	main
põhiseaduslikud	doc_491521502281_item	2653395	et	3	main
enim	doc_491521502281_item	2653397	et	4	main
hääli	doc_491521502281_item	2653398	et	4	main
ka	doc_491521502281_item	2653404	et	3	main
lennart	doc_491521502281_item	2653407	et	4	main
meri	doc_491521502281_item	2653408	et	3	main
lennart	doc_491521502281_item	2653409	et	4	main
meri	doc_491521502281_item	2653410	et	3	main
muudatused	doc_491521502281_item	2653417	et	3	main
eesti	doc_491521502281_item	2653419	et	4	main
ei	doc_491521502281_item	2653426	et	4	main
onud	doc_491521502281_item	2653427	et	3	main
elu	doc_491521502281_item	2653434	et	4	main
võttis	doc_491521502281_item	2653435	et	3	main
liiduga	doc_491521502281_item	2653442	et	3	main
see	doc_491521502281_item	2653444	et	3	main
tihedat	doc_491521502281_item	2653446	et	3	main
euroopa	doc_491521502281_item	2653448	et	4	main
eesti	doc_491521502281_item	2653450	et	4	main
võeti	doc_491521502281_item	2653451	et	3	main
vastu	doc_491521502281_item	2653452	et	3	main
ka	doc_491521502281_item	2653453	et	3	main
peaks	doc_491521502281_item	2653457	et	4	main
referendum	doc_491521502281_item	2653461	et	3	main
euroopa	doc_491521502281_item	2653463	et	4	main
liitu	doc_491521502281_item	2653464	et	4	main
1988	doc_491521502281_item	2653471	et	2	main
tallinnas	doc_491521502281_item	2653474	et	4	main
liikumise	doc_491521502281_item	2653477	et	4	main
nn	doc_491521502281_item	2653479	et	4	main
öölaulupidu	doc_491521502281_item	2653480	et	4	main
millel	doc_491521502281_item	2653481	et	3	main
lauldi	doc_491521502281_item	2653482	et	3	main
isamaalaulud	doc_491521502281_item	2653483	et	3	main
sellega	doc_491521502281_item	2653484	et	3	main
püüti	doc_491521502281_item	2653485	et	3	main
laulude	doc_491521502281_item	2653497	et	3	main
kui	doc_491521502281_item	2653504	et	3	main
kontrolltöö	doc_491521502282_item	2653507	et	4	main
rahvarinde	doc_491521502282_item	2653509	et	4	main
roll	doc_491521502282_item	2653510	et	3	main
eesti	doc_491521502282_item	2653511	et	4	main
võimule	doc_491521502282_item	2653526	et	3	main
glasnost	doc_491521502282_item	2653528	et	4	main
made	doc_491521502281_item	2653323	et	3	main
tehti	doc_491521502281_item	2653330	et	3	main
mainimata	doc_491521502281_item	2653343	et	4	main
poliitilises	doc_491521502281_item	2653351	et	3	main
toimusid	doc_491521502281_item	2653355	et	4	main
vasti	doc_491521502281_item	2653363	et	4	main
balti	doc_491521502281_item	2653364	et	3	main
riikides	doc_491521502281_item	2653365	et	3	main
keeleseadus	doc_491521502281_item	2653366	et	4	main
muidugi	doc_491521502281_item	2653367	et	4	main
see	doc_491521502281_item	2653368	et	3	main
jäi	doc_491521502281_item	2653369	et	3	main
kehtima	doc_491521502281_item	2653370	et	3	main
ka	doc_491521502281_item	2653371	et	3	main
eestis	doc_491521502281_item	2653373	et	3	main
ja	doc_491521502281_item	2653374	et	3	main
hakati	doc_491521502281_item	2653375	et	3	main
läbi	doc_491521502281_item	2653376	et	4	main
viima	doc_491521502281_item	2653377	et	3	main
majandusreform	doc_491521502281_item	2653378	et	3	main
eesti	doc_491521502281_item	2653379	et	4	main
poliitilises	doc_491521502281_item	2653380	et	3	main
pärast	doc_491521502281_item	2653372	et	4	main
elus	doc_491521502281_item	2653381	et	4	main
toimus	doc_491521502281_item	2653382	et	3	main
põhiseadus	doc_491521502281_item	2653390	et	4	main
esimesed	doc_491521502281_item	2653394	et	3	main
sai	doc_491521502281_item	2653396	et	4	main
isamaaliit	doc_491521502281_item	2653401	et	3	main
kuhu	doc_491521502281_item	2653402	et	3	main
tulevane	doc_491521502281_item	2653405	et	3	main
taasiseseisvunud	doc_491521502281_item	2653414	et	4	main
eestis	doc_491521502281_item	2653415	et	3	main
tänu	doc_491521502281_item	2653422	et	4	main
et	doc_491521502281_item	2653424	et	3	main
eesti	doc_491521502281_item	2653425	et	4	main
sõltuv	doc_491521502281_item	2653431	et	4	main
suunda	doc_491521502281_item	2653436	et	4	main
sel	doc_491521502281_item	2653455	et	3	main
korraldatud	doc_491521502281_item	2653473	et	4	main
väljendada	doc_491521502281_item	2653486	et	3	main
mis	doc_491521502281_item	2653494	et	4	main
läbi	doc_491521502281_item	2653496	et	4	main
läks	doc_491521502281_item	2653501	et	3	main
revolutsioon	doc_491521502281_item	2653506	et	3	main
mida	doc_491521502282_item	2653514	et	4	main
enam	doc_491521502281_item	2653428	et	4	main
poliitiliselt	doc_491521502281_item	2653429	et	4	main
moskvast	doc_491521502281_item	2653430	et	4	main
ka	doc_491521502281_item	2653439	et	3	main
astumisest	doc_491521502281_item	2653465	et	4	main
2	doc_491521502281_item	2653466	et	2	main
a	doc_491521502281_item	2653472	et	4	main
oma	doc_491521502281_item	2653487	et	4	main
saada	doc_491521502281_item	2653489	et	4	main
iseseisvaks	doc_491521502281_item	2653490	et	3	main
see	doc_491521502281_item	2653491	et	3	main
on	doc_491521502281_item	2653492	et	4	main
avaldus	doc_491521502281_item	2653495	et	4	main
sündmus	doc_491521502281_item	2653500	et	3	main
taasiseseivumisprotsessis	doc_491521502282_item	2653512	et	4	main
2	doc_491521502282_item	2653513	et	2	main
glasnost	doc_491521502282_item	2653517	et	4	main
ja	doc_491521502282_item	2653518	et	3	main
perestroika	doc_491521502282_item	2653519	et	4	main
2	doc_491521502282_item	2653520	et	2	main
kasutusele	doc_491521502282_item	2653524	et	4	main
tulles	doc_491521502282_item	2653527	et	4	main
uus	doc_491521502282_item	2653536	et	3	main
nimeks	doc_491521502282_item	2653540	et	3	main
seda	doc_491521502282_item	2653542	et	3	main
demokraatiaks	doc_491521502282_item	2653546	et	3	main
rahvarindesse	doc_491521502282_item	2653548	et	4	main
need	doc_491521502282_item	2653550	et	3	main
soovisid	doc_491521502282_item	2653553	et	4	main
nende	doc_491521502282_item	2653558	et	4	main
seas	doc_491521502282_item	2653559	et	4	main
oli	doc_491521502282_item	2653560	et	3	main
nii	doc_491521502282_item	2653561	et	3	main
kultuuripärandist	doc_491521502282_item	2653575	et	3	main
olid	doc_491521502282_item	2653578	et	4	main
ise	doc_491521502282_item	2653621	et	4	main
sini-must-valgeid	doc_491521502282_item	2653625	et	3	main
esitati	doc_491521502282_item	2653635	et	4	main
rr	doc_491521502282_item	2653636	et	4	main
eestvedamisel	doc_491521502282_item	2653637	et	3	main
mattiseni	doc_491521502282_item	2653645	et	4	main
kõigile	doc_491521502282_item	2653656	et	4	main
eestlastele	doc_491521502282_item	2653657	et	4	main
ka	doc_491521502282_item	2653658	et	3	main
veel	doc_491521502282_item	2653663	et	4	main
kui	doc_491521502282_item	2653674	et	3	main
vägivallatsemine	doc_491521502282_item	2653717	et	3	main
suudeti	doc_491521502282_item	2653718	et	3	main
rr	doc_491521502282_item	2653721	et	4	main
lootust	doc_491521502282_item	2653724	et	4	main
ir	doc_491521502282_item	2653733	et	4	main
ning	doc_491521502282_item	2653739	et	3	main
kampaania	doc_491521502282_item	2653744	et	4	main
mille	doc_491521502282_item	2653756	et	3	main
tähendust	doc_491521502282_item	2653757	et	4	main
too	doc_491521502282_item	2653758	et	4	main
aeg	doc_491521502282_item	2653759	et	3	main
ma	doc_491521502282_item	2653760	et	3	main
ju	doc_491521502282_item	2653766	et	3	main
rolli	doc_491521502282_item	2653775	et	4	main
taasiseseisvuuumisel	doc_491521502282_item	2653777	et	4	main
näol	doc_491521502282_item	2653785	et	4	main
riikidega	doc_491521502281_item	2653449	et	3	main
aastal	doc_491521502281_item	2653456	et	3	main
toimuma	doc_491521502281_item	2653459	et	3	main
eesti	doc_491521502281_item	2653462	et	4	main
juuni	doc_491521502281_item	2653469	et	4	main
algul	doc_491521502281_item	2653470	et	4	main
rahvusliku	doc_491521502281_item	2653476	et	3	main
meeleavaldus	doc_491521502281_item	2653493	et	3	main
see	doc_491521502281_item	2653499	et	3	main
ajalukku	doc_491521502281_item	2653503	et	4	main
laulev	doc_491521502281_item	2653505	et	4	main
1	doc_491521502282_item	2653508	et	2	main
uuendamine	doc_491521502282_item	2653530	et	4	main
see	doc_491521502282_item	2653538	et	3	main
inimesed	doc_491521502282_item	2653551	et	3	main
kohviõhtuid	doc_491521502282_item	2653569	et	3	main
kirjade	doc_491521502282_item	2653571	et	3	main
räägiti	doc_491521502282_item	2653573	et	3	main
tegelikult	doc_491521502282_item	2653576	et	4	main
laulev	doc_491521502281_item	2653467	et	4	main
revolutsioon	doc_491521502281_item	2653468	et	3	main
lauluväljakul	doc_491521502281_item	2653475	et	3	main
korraldatud	doc_491521502281_item	2653478	et	4	main
soovi	doc_491521502281_item	2653488	et	4	main
ning	doc_491521502281_item	2653498	et	3	main
eesti	doc_491521502281_item	2653502	et	4	main
tähendavad	doc_491521502282_item	2653515	et	4	main
mõisted	doc_491521502282_item	2653516	et	3	main
mõlemad	doc_491521502282_item	2653521	et	3	main
võeti	doc_491521502282_item	2653523	et	3	main
gorbatšovi	doc_491521502282_item	2653525	et	2	main
gorbašovi	doc_491521502282_item	2653531	et	2	main
võimule	doc_491521502282_item	2653532	et	3	main
tulles	doc_491521502282_item	2653533	et	4	main
sooviti	doc_491521502282_item	2653534	et	3	main
kehtestada	doc_491521502282_item	2653535	et	3	main
sai	doc_491521502282_item	2653539	et	4	main
hellitavalt	doc_491521502282_item	2653544	et	4	main
ka	doc_491521502282_item	2653545	et	3	main
1	doc_491521502282_item	2653547	et	2	main
kuulusid	doc_491521502282_item	2653549	et	4	main
kes	doc_491521502282_item	2653552	et	4	main
näha	doc_491521502282_item	2653554	et	3	main
iseseisva	doc_491521502282_item	2653556	et	3	main
inimesi	doc_491521502282_item	2653566	et	4	main
korraldasid	doc_491521502282_item	2653568	et	4	main
kus	doc_491521502282_item	2653570	et	3	main
eesti	doc_491521502282_item	2653574	et	4	main
nii	doc_491521502282_item	2653580	et	3	main
rahvarinne	doc_491521502282_item	2653627	et	3	main
traditsiooni	doc_491521502282_item	2653630	et	4	main
aasta	doc_491521502282_item	2653633	et	4	main
oli	doc_491521502282_item	2653643	et	3	main
lausus	doc_491521502282_item	2653651	et	4	main
lause	doc_491521502282_item	2653654	et	4	main
kes	doc_491521502282_item	2653660	et	4	main
sel	doc_491521502282_item	2653661	et	3	main
olid	doc_491521502282_item	2653666	et	4	main
nii	doc_491521502282_item	2653673	et	3	main
nii	doc_491521502282_item	2653675	et	3	main
lehvis	doc_491521502282_item	2653677	et	4	main
ka	doc_491521502282_item	2653678	et	3	main
streike	doc_491521502282_item	2653683	et	3	main
on	doc_491521502282_item	2653727	et	4	main
võimalik	doc_491521502282_item	2653728	et	3	main
olla	doc_491521502282_item	2653729	et	3	main
iseenda	doc_491521502282_item	2653730	et	3	main
lased	doc_491521502282_item	2653734	et	3	main
igati	doc_491521502282_item	2653735	et	3	main
forforiidikaevanduste	doc_491521502282_item	2653737	et	4	main
suurendamist	doc_491521502282_item	2653738	et	4	main
olid	doc_491521502282_item	2653749	et	4	main
paljud	doc_491521502282_item	2653751	et	3	main
sis	doc_491521502282_item	2653767	et	3	main
mis	doc_491521502282_item	2653769	et	4	main
on	doc_491521502282_item	2653771	et	4	main
mängis	doc_491521502282_item	2653773	et	3	main
eelkõige	doc_491521502282_item	2653778	et	3	main
ühtsustunde	doc_491521502282_item	2653780	et	4	main
lootuse	doc_491521502282_item	2653783	et	4	main
andmise	doc_491521502282_item	2653784	et	4	main
mõisted	doc_491521502282_item	2653522	et	3	main
eestit	doc_491521502282_item	2653555	et	3	main
riigina	doc_491521502282_item	2653557	et	3	main
eesti	doc_491521502282_item	2653581	et	4	main
ajalugu	doc_491521502282_item	2653582	et	4	main
kultuur	doc_491521502282_item	2653583	et	3	main
kui	doc_491521502282_item	2653584	et	3	main
kõik	doc_491521502282_item	2653585	et	4	main
eestilk	doc_491521502282_item	2653587	et	3	main
mu	doc_491521502282_item	2653586	et	3	main
räägiti	doc_491521502282_item	2653588	et	3	main
ka	doc_491521502282_item	2653589	et	3	main
pätsist	doc_491521502282_item	2653590	et	3	main
ja	doc_491521502282_item	2653591	et	3	main
eesti	doc_491521502282_item	2653592	et	4	main
iseseisvusest	doc_491521502282_item	2653593	et	4	main
üleval	doc_491521502282_item	2653594	et	4	main
olid	doc_491521502282_item	2653595	et	4	main
sini-must-valged	doc_491521502282_item	2653596	et	3	main
lipud	doc_491521502282_item	2653597	et	3	main
seda	doc_491521502282_item	2653598	et	3	main
küll	doc_491521502282_item	2653599	et	4	main
eri	doc_491521502282_item	2653600	et	4	main
kangastel	doc_491521502282_item	2653601	et	4	main
kuid	doc_491521502282_item	2653602	et	4	main
mõistsid	doc_491521502282_item	2653603	et	4	main
nende	doc_491521502282_item	2653604	et	4	main
värvide	doc_491521502282_item	2653605	et	3	main
ideed	doc_491521502282_item	2653606	et	4	main
neil	doc_491521502282_item	2653607	et	4	main
õhtutel	doc_491521502282_item	2653608	et	3	main
oli	doc_491521502282_item	2653609	et	3	main
ka	doc_491521502282_item	2653610	et	3	main
nn	doc_491521502282_item	2653611	et	4	main
koputajaid	doc_491521502282_item	2653612	et	4	main
tänu	doc_491521502282_item	2653613	et	4	main
kellele	doc_491521502282_item	2653614	et	4	main
paljud	doc_491521502282_item	2653615	et	3	main
esinemised	doc_491521502282_item	2653616	et	4	main
ja	doc_491521502282_item	2653617	et	3	main
sõnavõtud	doc_491521502282_item	2653618	et	3	main
perestroika	doc_491521502282_item	2653529	et	4	main
poliitika	doc_491521502282_item	2653537	et	4	main
perestroika	doc_491521502282_item	2653541	et	4	main
kutsuti	doc_491521502282_item	2653543	et	3	main
haritlasi	doc_491521502282_item	2653562	et	3	main
kui	doc_491521502282_item	2653563	et	3	main
ka	doc_491521502282_item	2653564	et	3	main
tavalisi	doc_491521502282_item	2653565	et	4	main
rahvarindlased	doc_491521502282_item	2653567	et	3	main
järgi	doc_491521502282_item	2653572	et	4	main
aga	doc_491521502282_item	2653577	et	3	main
teemadeks	doc_491521502282_item	2653579	et	3	main
keelati	doc_491521502282_item	2653619	et	4	main
ka	doc_491521502282_item	2653623	et	3	main
tihti	doc_491521502282_item	2653624	et	3	main
osa	doc_491521502282_item	2653642	et	4	main
sulest	doc_491521502282_item	2653646	et	4	main
tol	doc_491521502282_item	2653648	et	3	main
laulupeol	doc_491521502282_item	2653650	et	4	main
h	doc_491521502282_item	2653652	et	4	main
valk	doc_491521502282_item	2653653	et	3	main
nendele	doc_491521502282_item	2653659	et	4	main
väga	doc_491521502282_item	2653664	et	3	main
mällu	doc_491521502282_item	2653668	et	3	main
sini-must-valge	doc_491521502282_item	2653679	et	4	main
korralda	doc_491521502282_item	2653682	et	4	main
nähtav	doc_491521502282_item	2653716	et	4	main
süstis	doc_491521502282_item	2653722	et	4	main
inimestesse	doc_491521502282_item	2653723	et	3	main
et	doc_491521502282_item	2653725	et	3	main
neil	doc_491521502282_item	2653726	et	4	main
pooldasid	doc_491521502282_item	2653736	et	4	main
ema	doc_491521502282_item	2653755	et	4	main
rr	doc_491521502282_item	2653772	et	4	main
rahvas	doc_491521502282_item	2653779	et	4	main
rahvarindlased	doc_491521502282_item	2653620	et	3	main
riideid	doc_491521502282_item	2653626	et	3	main
laulupidude	doc_491521502282_item	2653629	et	4	main
1987	doc_491521502282_item	2653632	et	2	main
isamaalisi	doc_491521502282_item	2653638	et	4	main
laule	doc_491521502282_item	2653639	et	4	main
a	doc_491521502282_item	2653644	et	4	main
samal	doc_491521502282_item	2653649	et	3	main
ajal	doc_491521502282_item	2653662	et	4	main
on	doc_491521502282_item	2653667	et	4	main
sööbinud	doc_491521502282_item	2653669	et	4	main
me	doc_491521502282_item	2653671	et	4	main
seal	doc_491521502282_item	2653676	et	4	main
rr	doc_491521502282_item	2653681	et	4	main
ära	doc_491521502282_item	2653719	et	4	main
hoida	doc_491521502282_item	2653720	et	3	main
kandsid	doc_491521502282_item	2653622	et	4	main
taastas	doc_491521502282_item	2653628	et	3	main
ning	doc_491521502282_item	2653631	et	3	main
laulupeol	doc_491521502282_item	2653634	et	4	main
neist	doc_491521502282_item	2653640	et	4	main
suur	doc_491521502282_item	2653641	et	3	main
pärit	doc_491521502282_item	2653647	et	3	main
mis	doc_491521502282_item	2653655	et	4	main
väikesed	doc_491521502282_item	2653665	et	4	main
ükskord	doc_491521502282_item	2653670	et	3	main
võidame	doc_491521502282_item	2653672	et	3	main
lipp	doc_491521502282_item	2653680	et	3	main
ja	doc_491521502282_item	2653684	et	3	main
meeleavaldusi	doc_491521502282_item	2653685	et	3	main
eesti	doc_491521502282_item	2653686	et	4	main
vabariigi	doc_491521502282_item	2653687	et	3	main
taasloomise	doc_491521502282_item	2653688	et	4	main
eesmärgil	doc_491521502282_item	2653689	et	3	main
rr-le	doc_491521502282_item	2653690	et	3	main
töötas	doc_491521502282_item	2653691	et	3	main
vastu	doc_491521502282_item	2653692	et	3	main
kommunistlik	doc_491521502282_item	2653693	et	3	main
interrinneir	doc_491521502282_item	2653694	et	4	main
mis	doc_491521502282_item	2653695	et	4	main
arvatavasti	doc_491521502282_item	2653696	et	3	main
oli	doc_491521502282_item	2653697	et	3	main
seotud	doc_491521502282_item	2653698	et	4	main
kgbga	doc_491521502282_item	2653699	et	4	main
ir	doc_491521502282_item	2653700	et	4	main
laitis	doc_491521502282_item	2653701	et	3	main
ning	doc_491521502282_item	2653703	et	3	main
kahe	doc_491521502282_item	2653704	et	3	main
rr	doc_491521502282_item	2653702	et	4	main
rühmituse	doc_491521502282_item	2653705	et	4	main
vahel	doc_491521502282_item	2653706	et	4	main
toimus	doc_491521502282_item	2653707	et	3	main
pidev	doc_491521502282_item	2653708	et	3	main
kemplus	doc_491521502282_item	2653709	et	3	main
õnneks	doc_491521502282_item	2653710	et	4	main
oli	doc_491521502282_item	2653711	et	3	main
see	doc_491521502282_item	2653712	et	3	main
vaid	doc_491521502282_item	2653713	et	3	main
meeleavalduse	doc_491521502282_item	2653714	et	3	main
näol	doc_491521502282_item	2653715	et	4	main
peremehed	doc_491521502282_item	2653731	et	3	main
kaevamiste	doc_491521502282_item	2653740	et	4	main
korraldasid	doc_491521502282_item	2653742	et	4	main
rrlased	doc_491521502282_item	2653743	et	4	main
ei	doc_491521502282_item	2653745	et	4	main
fosforiidile	doc_491521502282_item	2653746	et	4	main
taolise	doc_491521502282_item	2653747	et	3	main
info-postid	doc_491521502282_item	2653752	et	3	main
oma	doc_491521502282_item	2653754	et	4	main
teadnud	doc_491521502282_item	2653764	et	4	main
ma	doc_491521502282_item	2653765	et	3	main
suurt	doc_491521502282_item	2653774	et	3	main
loomise	doc_491521502282_item	2653781	et	4	main
ning	doc_491521502282_item	2653782	et	3	main
kui	doc_491521502282_item	2653786	et	3	main
poleks	doc_491521502282_item	2653787	et	3	main
olnud	doc_491521502282_item	2653788	et	4	main
aktiivseid	doc_491521502282_item	2653789	et	3	main
rrlasi	doc_491521502282_item	2653790	et	4	main
ega	doc_491521502282_item	2653791	et	3	main
muud	doc_491521502282_item	2653792	et	4	main
taolist	doc_491521502282_item	2653793	et	3	main
rühmitust	doc_491521502282_item	2653794	et	4	main
kes	doc_491521502282_item	2653795	et	4	main
teab	doc_491521502282_item	2653796	et	3	main
kus	doc_491521502282_item	2653797	et	3	main
ja	doc_491521502282_item	2653798	et	3	main
kes	doc_491521502282_item	2653799	et	4	main
me	doc_491521502282_item	2653800	et	4	main
siis	doc_491521502282_item	2653801	et	3	main
täna	doc_491521502282_item	2653802	et	4	main
oleksime	doc_491521502282_item	2653803	et	3	main
kui	doc_491521502282_item	2653732	et	3	main
intensiivistamise	doc_491521502282_item	2653741	et	4	main
loosungiga	doc_491521502282_item	2653748	et	3	main
kaunistatud	doc_491521502282_item	2653750	et	4	main
mäletan	doc_491521502282_item	2653753	et	3	main
ei	doc_491521502282_item	2653761	et	4	main
mõistnud	doc_491521502282_item	2653762	et	4	main
ei	doc_491521502282_item	2653763	et	4	main
veel	doc_491521502282_item	2653768	et	4	main
fosforiitki	doc_491521502282_item	2653770	et	3	main
eesti	doc_491521502282_item	2653776	et	4	main
1	doc_491521502284_item	2654171	et	2	main
mida	doc_491521502284_item	2654177	et	4	main
glasnost	doc_491521502284_item	2654180	et	4	main
perestroika	doc_491521502284_item	2654182	et	4	main
90	doc_491521502284_item	2654184	et	2	main
taasiseseisvaks	doc_491521502284_item	2654188	et	3	main
sellega	doc_491521502284_item	2654189	et	3	main
uures	doc_491521502284_item	2654191	et	3	main
muutused	doc_491521502284_item	2654192	et	4	main
a	doc_491521502284_item	2654194	et	4	main
alguses	doc_491521502284_item	2654195	et	4	main
kaotati	doc_491521502284_item	2654196	et	3	main
mõnikord	doc_491521502284_item	2654204	et	3	main
ja	doc_491521502284_item	2654207	et	3	main
korda	doc_491521502284_item	2654209	et	4	main
taasiseseivumisprotsessis	doc_491521502284_item	2654175	et	4	main
tähendavad	doc_491521502284_item	2654178	et	4	main
paljud	doc_491521502284_item	2654199	et	3	main
muutsid	doc_491521502284_item	2654201	et	4	main
2	doc_491521502284_item	2654206	et	2	main
3	doc_491521502284_item	2654208	et	2	main
ei	doc_491521502284_item	2654211	et	4	main
pidanud	doc_491521502284_item	2654212	et	4	main
jäänud	doc_491521502284_item	2654222	et	4	main
nimetati	doc_491521502284_item	2654224	et	4	main
mitte	doc_491521502284_item	2654228	et	3	main
tõttu	doc_491521502284_item	2654238	et	4	main
arstiabi	doc_491521502284_item	2654241	et	4	main
tola	doc_491521502284_item	2654255	et	4	main
asja	doc_491521502284_item	2654258	et	4	main
kui	doc_491521502284_item	2654264	et	3	main
tänasel	doc_491521502284_item	2654268	et	3	main
tahad	doc_491521502284_item	2654270	et	3	main
midagi	doc_491521502284_item	2654276	et	4	main
siis	doc_491521502284_item	2654278	et	3	main
ei	doc_491521502284_item	2654280	et	4	main
käest	doc_491521502284_item	2654283	et	4	main
pidid	doc_491521502284_item	2654288	et	4	main
kirjaliku	doc_491521502284_item	2654289	et	3	main
mõne	doc_491521502284_item	2654291	et	3	main
on	doc_491521502284_item	2654300	et	4	main
aids	doc_491521502284_item	2654303	et	4	main
ja	doc_491521502284_item	2654304	et	3	main
ne	doc_491521502284_item	2654305	et	4	main
oli	doc_491521502284_item	2654306	et	3	main
ei	doc_491521502284_item	2654311	et	4	main
suhteliselt	doc_491521502284_item	2654316	et	4	main
2	doc_491521502284_item	2654176	et	2	main
ja	doc_491521502284_item	2654181	et	3	main
1	doc_491521502284_item	2654183	et	2	main
aastatel	doc_491521502284_item	2654185	et	4	main
koolivorm	doc_491521502284_item	2654198	et	3	main
enam	doc_491521502284_item	2654213	et	4	main
kandma	doc_491521502284_item	2654214	et	3	main
kuigi	doc_491521502284_item	2654215	et	3	main
praegu	doc_491521502284_item	2654216	et	3	main
mõnedes	doc_491521502284_item	2654217	et	3	main
koolides	doc_491521502284_item	2654218	et	3	main
sotsallaabi	doc_491521502284_item	2654232	et	4	main
2	doc_491521502284_item	2654239	et	2	main
nädalaks	doc_491521502284_item	2654240	et	3	main
oli	doc_491521502284_item	2654242	et	3	main
ajal	doc_491521502284_item	2654256	et	4	main
ei	doc_491521502284_item	2654259	et	4	main
olnud	doc_491521502284_item	2654260	et	4	main
oli	doc_491521502284_item	2654261	et	3	main
päeval	doc_491521502284_item	2654269	et	3	main
vaipa	doc_491521502284_item	2654273	et	4	main
kellegi	doc_491521502284_item	2654282	et	4	main
ajal	doc_491521502284_item	2654287	et	4	main
suurema	doc_491521502284_item	2654292	et	4	main
muutunud	doc_491521502284_item	2654299	et	4	main
hiv-positiivne	doc_491521502284_item	2654302	et	3	main
palju	doc_491521502284_item	2654307	et	4	main
olnud	doc_491521502284_item	2654312	et	4	main
praegu	doc_491521502284_item	2654319	et	3	main
ka	doc_491521502284_item	2654326	et	3	main
tehnikas	doc_491521502284_item	2654330	et	3	main
nad	doc_491521502284_item	2654339	et	3	main
aga	doc_491521502284_item	2654340	et	3	main
nagu	doc_491521502284_item	2654341	et	3	main
siis	doc_491521502284_item	2654344	et	3	main
ja	doc_491521502284_item	2654348	et	3	main
mida	doc_491521502284_item	2654355	et	4	main
eest	doc_491521502284_item	2654360	et	4	main
muudatusi	doc_491521502284_item	2654361	et	3	main
et	doc_491521502284_item	2654367	et	3	main
võimalused	doc_491521502284_item	2654383	et	3	main
uued	doc_491521502284_item	2654386	et	3	main
ja	doc_491521502284_item	2654401	et	3	main
nüüd	doc_491521502284_item	2654404	et	4	main
kontrolltöö	doc_491521502284_item	2654170	et	4	main
rahvarinde	doc_491521502284_item	2654172	et	4	main
roll	doc_491521502284_item	2654173	et	3	main
eesti	doc_491521502284_item	2654174	et	4	main
sai	doc_491521502284_item	2654186	et	4	main
ära	doc_491521502284_item	2654197	et	4	main
ülikoolid	doc_491521502284_item	2654200	et	3	main
isegi	doc_491521502284_item	2654205	et	4	main
on	doc_491521502284_item	2654219	et	4	main
see	doc_491521502284_item	2654220	et	3	main
gümnaasiumiteks	doc_491521502284_item	2654226	et	3	main
pandi	doc_491521502284_item	2654234	et	4	main
minisuguse	doc_491521502284_item	2654235	et	3	main
väikese	doc_491521502284_item	2654236	et	4	main
ka	doc_491521502284_item	2654243	et	3	main
võrreldes	doc_491521502284_item	2654245	et	3	main
praeguga	doc_491521502284_item	2654246	et	4	main
praegu	doc_491521502284_item	2654247	et	3	main
maksab	doc_491521502284_item	2654248	et	3	main
sellist	doc_491521502284_item	2654257	et	4	main
praegu	doc_491521502284_item	2654265	et	3	main
praegu	doc_491521502284_item	2654267	et	3	main
osat	doc_491521502284_item	2654271	et	4	main
külmkappi	doc_491521502284_item	2654274	et	4	main
küsima	doc_491521502284_item	2654285	et	3	main
asja	doc_491521502284_item	2654293	et	4	main
ostmiseks	doc_491521502284_item	2654294	et	4	main
see	doc_491521502284_item	2654295	et	3	main
poole	doc_491521502284_item	2654298	et	4	main
tulnud	doc_491521502284_item	2654301	et	4	main
mida	doc_491521502284_item	2654309	et	4	main
tegelikult	doc_491521502284_item	2654310	et	4	main
leida	doc_491521502284_item	2654318	et	3	main
a	doc_491521502284_item	2654332	et	4	main
olid	doc_491521502284_item	2654333	et	4	main
väikesed	doc_491521502284_item	2654342	et	4	main
olnud	doc_491521502284_item	2654346	et	4	main
muusikakeskuseid	doc_491521502284_item	2654347	et	3	main
palju	doc_491521502284_item	2654349	et	4	main
me	doc_491521502284_item	2654356	et	4	main
võime	doc_491521502284_item	2654357	et	4	main
on	doc_491521502284_item	2654362	et	4	main
ma	doc_491521502284_item	2654365	et	3	main
sisse	doc_491521502284_item	2654377	et	4	main
ja	doc_491521502284_item	2654384	et	3	main
perestroika	doc_491521502284_item	2654389	et	4	main
mis	doc_491521502284_item	2654402	et	4	main
mõisted	doc_491521502284_item	2654179	et	3	main
eesti	doc_491521502284_item	2654187	et	4	main
kaasnesid	doc_491521502284_item	2654190	et	4	main
90	doc_491521502284_item	2654193	et	2	main
oma	doc_491521502284_item	2654202	et	4	main
nime	doc_491521502284_item	2654203	et	4	main
koolimütse	doc_491521502284_item	2654210	et	3	main
alles	doc_491521502284_item	2654221	et	3	main
haiglasse	doc_491521502284_item	2654233	et	4	main
tasuta	doc_491521502284_item	2654244	et	4	main
palju	doc_491521502284_item	2654262	et	4	main
autot	doc_491521502284_item	2654272	et	3	main
või	doc_491521502284_item	2654275	et	4	main
tol	doc_491521502284_item	2654286	et	3	main
loa	doc_491521502284_item	2654290	et	4	main
parema	doc_491521502284_item	2654297	et	4	main
töökohti	doc_491521502284_item	2654308	et	4	main
tööd	doc_491521502284_item	2654314	et	4	main
oli	doc_491521502284_item	2654315	et	3	main
raske	doc_491521502284_item	2654321	et	4	main
leida	doc_491521502284_item	2654324	et	3	main
on	doc_491521502284_item	2654325	et	4	main
on	doc_491521502284_item	2654338	et	4	main
on	doc_491521502284_item	2654352	et	4	main
praegu	doc_491521502284_item	2654353	et	3	main
ja	doc_491521502284_item	2654354	et	3	main
raha	doc_491521502284_item	2654359	et	4	main
ja	doc_491521502284_item	2654364	et	3	main
eesti	doc_491521502284_item	2654368	et	4	main
paremaks	doc_491521502284_item	2654370	et	4	main
need	doc_491521502284_item	2654390	et	3	main
muudatused	doc_491521502284_item	2654392	et	3	main
toimusid	doc_491521502284_item	2654394	et	4	main
iseseisvumisajal	doc_491521502284_item	2654395	et	3	main
on	doc_491521502284_item	2654403	et	4	main
taasiseseivumisprotsessis	doc_491521502286_item	2654573	et	4	main
2	doc_491521502286_item	2654574	et	2	main
siis	doc_491521502286_item	2654583	et	3	main
eesti	doc_491521502286_item	2654598	et	4	main
tuli	doc_491521502286_item	2654611	et	4	main
aega	doc_491521502286_item	2654613	et	4	main
tegema	doc_491521502286_item	2654623	et	3	main
vastu	doc_491521502286_item	2654628	et	3	main
tekkis	doc_491521502286_item	2654632	et	3	main
isemajandav	doc_491521502286_item	2654635	et	3	main
eesti	doc_491521502286_item	2654661	et	4	main
korraldasid	doc_491521502286_item	2654665	et	4	main
igasugused	doc_491521502286_item	2654666	et	3	main
kokkutulekud	doc_491521502286_item	2654667	et	3	main
püüti	doc_491521502286_item	2654668	et	3	main
tõestada	doc_491521502286_item	2654669	et	3	main
molotov-ribbentroppi	doc_491521502286_item	2654670	et	4	main
kuigi	doc_491521502286_item	2654674	et	3	main
venemaa	doc_491521502286_item	2654676	et	4	main
eitas	doc_491521502286_item	2654677	et	3	main
olemasolu	doc_491521502286_item	2654679	et	4	main
lauluvaljakul	doc_491521502286_item	2654683	et	4	main
selleks	doc_491521502286_item	2654684	et	4	main
et	doc_491521502286_item	2654685	et	3	main
koolid	doc_491521502284_item	2654223	et	3	main
ümber	doc_491521502284_item	2654225	et	3	main
aga	doc_491521502284_item	2654227	et	3	main
kõik	doc_491521502284_item	2654229	et	4	main
tasuta	doc_491521502284_item	2654230	et	4	main
oli	doc_491521502284_item	2654231	et	3	main
vigastuse	doc_491521502284_item	2654237	et	4	main
haigekassa	doc_491521502284_item	2654249	et	4	main
mõned	doc_491521502284_item	2654250	et	3	main
kulud	doc_491521502284_item	2654251	et	4	main
aga	doc_491521502284_item	2654252	et	3	main
mitte	doc_491521502284_item	2654253	et	3	main
kõik	doc_491521502284_item	2654254	et	4	main
odavam	doc_491521502284_item	2654263	et	4	main
kui	doc_491521502284_item	2654266	et	3	main
muud	doc_491521502284_item	2654277	et	4	main
sa	doc_491521502284_item	2654279	et	3	main
pea	doc_491521502284_item	2654281	et	4	main
luba	doc_491521502284_item	2654284	et	4	main
on	doc_491521502284_item	2654296	et	4	main
vaja	doc_491521502284_item	2654313	et	4	main
kerge	doc_491521502284_item	2654317	et	4	main
aga	doc_491521502284_item	2654320	et	3	main
ööd	doc_491521502284_item	2654322	et	4	main
head	doc_491521502284_item	2654323	et	4	main
muudatusi	doc_491521502284_item	2654328	et	3	main
nt	doc_491521502284_item	2654329	et	4	main
arvutid	doc_491521502284_item	2654334	et	4	main
hästi	doc_491521502284_item	2654335	et	3	main
suured	doc_491521502284_item	2654336	et	3	main
praegu	doc_491521502284_item	2654337	et	3	main
ei	doc_491521502284_item	2654345	et	4	main
muud	doc_491521502284_item	2654350	et	4	main
mida	doc_491521502284_item	2654351	et	4	main
osta	doc_491521502284_item	2654358	et	4	main
palju	doc_491521502284_item	2654363	et	4	main
arvan	doc_491521502284_item	2654366	et	3	main
euroopa	doc_491521502284_item	2654378	et	4	main
liitu	doc_491521502284_item	2654379	et	4	main
siis	doc_491521502284_item	2654380	et	3	main
arenevad	doc_491521502284_item	2654381	et	4	main
toimuvad	doc_491521502284_item	2654385	et	4	main
muudatused	doc_491521502284_item	2654387	et	3	main
mis	doc_491521502284_item	2654393	et	4	main
mis	doc_491521502284_item	2654396	et	4	main
oli	doc_491521502284_item	2654397	et	3	main
10	doc_491521502284_item	2654398	et	2	main
aastat	doc_491521502284_item	2654399	et	3	main
tagasi	doc_491521502284_item	2654400	et	3	main
palju	doc_491521502284_item	2654327	et	4	main
90	doc_491521502284_item	2654331	et	2	main
telekad	doc_491521502284_item	2654343	et	3	main
läheb	doc_491521502284_item	2654369	et	3	main
tulevad	doc_491521502284_item	2654371	et	4	main
uued	doc_491521502284_item	2654372	et	3	main
võimalused	doc_491521502284_item	2654373	et	3	main
kui	doc_491521502284_item	2654374	et	3	main
eesti	doc_491521502284_item	2654375	et	4	main
astub	doc_491521502284_item	2654376	et	3	main
uued	doc_491521502284_item	2654382	et	3	main
2	doc_491521502284_item	2654388	et	2	main
on	doc_491521502284_item	2654391	et	4	main
kontrolltöö	doc_491521502286_item	2654568	et	4	main
mida	doc_491521502286_item	2654575	et	4	main
tähendavad	doc_491521502286_item	2654576	et	4	main
tšernobolis	doc_491521502286_item	2654585	et	2	main
eesti	doc_491521502286_item	2654589	et	4	main
hakkati	doc_491521502286_item	2654591	et	3	main
tagajargade	doc_491521502286_item	2654594	et	4	main
aja	doc_491521502286_item	2654597	et	4	main
rahvas	doc_491521502286_item	2654608	et	4	main
õige	doc_491521502286_item	2654612	et	4	main
hakkati	doc_491521502286_item	2654621	et	3	main
uute	doc_491521502286_item	2654624	et	3	main
korraldati	doc_491521502286_item	2654629	et	3	main
ime	doc_491521502286_item	2654634	et	4	main
hakkasid	doc_491521502286_item	2654644	et	4	main
uskuma	doc_491521502286_item	2654645	et	3	main
paremasse	doc_491521502286_item	2654646	et	4	main
tulevikku	doc_491521502286_item	2654647	et	4	main
hiljem	doc_491521502286_item	2654648	et	3	main
nende	doc_491521502286_item	2654658	et	4	main
iseseisvuse	doc_491521502286_item	2654662	et	4	main
nad	doc_491521502286_item	2654664	et	3	main
pakti	doc_491521502286_item	2654671	et	4	main
rahvas	doc_491521502286_item	2654682	et	4	main
tunda	doc_491521502286_item	2654695	et	3	main
suunas	doc_491521502286_item	2654709	et	4	main
oma	doc_491521502286_item	2654715	et	4	main
valimised	doc_491521502286_item	2654716	et	4	main
kes	doc_491521502286_item	2654721	et	4	main
rahvarinnet	doc_491521502286_item	2654723	et	3	main
palju	doc_491521502286_item	2654727	et	4	main
iseseisvas	doc_491521502286_item	2654729	et	3	main
1	doc_491521502286_item	2654569	et	2	main
rahvarinde	doc_491521502286_item	2654570	et	4	main
roll	doc_491521502286_item	2654571	et	3	main
mõisted	doc_491521502286_item	2654577	et	3	main
glasnost	doc_491521502286_item	2654578	et	4	main
ja	doc_491521502286_item	2654579	et	3	main
juhtus	doc_491521502286_item	2654586	et	3	main
ja	doc_491521502286_item	2654588	et	3	main
mehi	doc_491521502286_item	2654590	et	3	main
sinna	doc_491521502286_item	2654593	et	3	main
likvideerimiseks	doc_491521502286_item	2654595	et	4	main
poisid	doc_491521502286_item	2654599	et	4	main
ja	doc_491521502286_item	2654600	et	3	main
surid	doc_491521502286_item	2654602	et	4	main
afganistanis	doc_491521502286_item	2654603	et	4	main
võõravõimude	doc_491521502286_item	2654604	et	3	main
eest	doc_491521502286_item	2654605	et	4	main
sai	doc_491521502286_item	2654606	et	4	main
et	doc_491521502286_item	2654610	et	3	main
eesti	doc_491521502286_item	2654572	et	4	main
perestroika	doc_491521502286_item	2654580	et	4	main
1	doc_491521502286_item	2654581	et	2	main
1986	doc_491521502286_item	2654582	et	2	main
saatma	doc_491521502286_item	2654592	et	3	main
eesti	doc_491521502286_item	2654607	et	4	main
midagi	doc_491521502286_item	2654622	et	4	main
kaevanduste	doc_491521502286_item	2654626	et	4	main
tekkimiste	doc_491521502286_item	2654627	et	4	main
rahvalikkused	doc_491521502286_item	2654630	et	4	main
eesti	doc_491521502286_item	2654640	et	4	main
inimesed	doc_491521502286_item	2654643	et	3	main
rajajaks	doc_491521502286_item	2654654	et	4	main
saab	doc_491521502286_item	2654655	et	3	main
pidada	doc_491521502286_item	2654656	et	4	main
saviraari	doc_491521502286_item	2654657	et	4	main
oli	doc_491521502286_item	2654660	et	3	main
taastamine	doc_491521502286_item	2654663	et	4	main
õigust	doc_491521502286_item	2654673	et	4	main
nõukogude	doc_491521502286_item	2654675	et	3	main
selle	doc_491521502286_item	2654678	et	4	main
öeseti	doc_491521502286_item	2654680	et	4	main
laule	doc_491521502286_item	2654690	et	4	main
ettendus	doc_491521502286_item	2654694	et	4	main
eest	doc_491521502286_item	2654697	et	4	main
rahva	doc_491521502286_item	2654699	et	3	main
eest	doc_491521502286_item	2654700	et	4	main
ja	doc_491521502286_item	2654701	et	3	main
tunda	doc_491521502286_item	2654702	et	3	main
ka	doc_491521502286_item	2654703	et	3	main
ühistunnet	doc_491521502286_item	2654704	et	3	main
selles	doc_491521502286_item	2654708	et	4	main
tegid	doc_491521502286_item	2654724	et	4	main
võimule	doc_491521502286_item	2654739	et	3	main
sellised	doc_491521502286_item	2654744	et	4	main
inimestel	doc_491521502286_item	2654777	et	3	main
saab	doc_491521502286_item	2654783	et	3	main
hulga	doc_491521502286_item	2654784	et	4	main
kui	doc_491521502286_item	2654584	et	3	main
katastroof	doc_491521502286_item	2654587	et	3	main
samal	doc_491521502286_item	2654596	et	3	main
mehed	doc_491521502286_item	2654601	et	3	main
aru	doc_491521502286_item	2654609	et	4	main
vabaduse	doc_491521502286_item	2654614	et	4	main
eest	doc_491521502286_item	2654615	et	4	main
võidelda	doc_491521502286_item	2654616	et	4	main
nõrgenes	doc_491521502286_item	2654617	et	3	main
tsensuur	doc_491521502286_item	2654618	et	3	main
surenev	doc_491521502286_item	2654619	et	4	main
avalikkus	doc_491521502286_item	2654620	et	4	main
mõiste	doc_491521502286_item	2654633	et	4	main
eesti	doc_491521502286_item	2654636	et	4	main
samal	doc_491521502286_item	2654637	et	3	main
ajal	doc_491521502286_item	2654638	et	4	main
tekkis	doc_491521502286_item	2654639	et	3	main
eesmärgiks	doc_491521502286_item	2654659	et	3	main
juuridilist	doc_491521502286_item	2654672	et	4	main
olla	doc_491521502286_item	2654686	et	3	main
vaadata	doc_491521502286_item	2654692	et	4	main
uhkust	doc_491521502286_item	2654696	et	4	main
oma	doc_491521502286_item	2654698	et	4	main
palju	doc_491521502286_item	2654707	et	4	main
taastada	doc_491521502286_item	2654711	et	3	main
sümboolikat	doc_491521502286_item	2654713	et	3	main
korraldati	doc_491521502286_item	2654714	et	3	main
ka	doc_491521502286_item	2654726	et	3	main
eestis	doc_491521502286_item	2654730	et	3	main
tuli	doc_491521502286_item	2654738	et	4	main
tulid	doc_491521502286_item	2654743	et	4	main
mõisted	doc_491521502286_item	2654745	et	3	main
glasnost	doc_491521502286_item	2654747	et	4	main
ja	doc_491521502286_item	2654748	et	3	main
perestroika	doc_491521502286_item	2654749	et	4	main
see	doc_491521502286_item	2654750	et	3	main
oli	doc_491521502286_item	2654751	et	3	main
nõukogude	doc_491521502286_item	2654755	et	3	main
majanduslik	doc_491521502286_item	2654758	et	3	main
parata	doc_491521502286_item	2654762	et	3	main
korras	doc_491521502286_item	2654764	et	4	main
olnud	doc_491521502286_item	2654773	et	4	main
nüüd	doc_491521502286_item	2654774	et	4	main
mulje	doc_491521502286_item	2654779	et	4	main
et	doc_491521502286_item	2654780	et	3	main
ajal	doc_491521502286_item	2654788	et	4	main
lõppes	doc_491521502286_item	2654823	et	4	main
fosvoriiti	doc_491521502286_item	2654625	et	4	main
kogumised	doc_491521502286_item	2654631	et	4	main
muinaskogude	doc_491521502286_item	2654641	et	3	main
selts	doc_491521502286_item	2654642	et	3	main
tekks	doc_491521502286_item	2654649	et	4	main
rr	doc_491521502286_item	2654650	et	4	main
rahvarinne	doc_491521502286_item	2654651	et	3	main
idee	doc_491521502286_item	2654652	et	4	main
seltsi	doc_491521502286_item	2654653	et	4	main
kogunes	doc_491521502286_item	2654681	et	3	main
ja	doc_491521502286_item	2654691	et	3	main
eesti	doc_491521502286_item	2654712	et	4	main
pärast	doc_491521502286_item	2654717	et	4	main
paljud	doc_491521502286_item	2654718	et	3	main
noored	doc_491521502286_item	2654719	et	3	main
poliitikud	doc_491521502286_item	2654720	et	3	main
koos	doc_491521502286_item	2654687	et	4	main
kuulata	doc_491521502286_item	2654688	et	4	main
rahva	doc_491521502286_item	2654689	et	3	main
ansamblite	doc_491521502286_item	2654693	et	3	main
rr	doc_491521502286_item	2654705	et	4	main
töötas	doc_491521502286_item	2654706	et	3	main
et	doc_491521502286_item	2654710	et	3	main
juhendasid	doc_491521502286_item	2654722	et	4	main
juba	doc_491521502286_item	2654728	et	3	main
m	doc_491521502286_item	2654740	et	4	main
oli	doc_491521502286_item	2654757	et	3	main
samal	doc_491521502286_item	2654766	et	3	main
informatsiooni	doc_491521502286_item	2654786	et	4	main
samal	doc_491521502286_item	2654787	et	3	main
kuigi	doc_491521502286_item	2654795	et	3	main
ka	doc_491521502286_item	2654725	et	3	main
1985	doc_491521502286_item	2654737	et	2	main
temaga	doc_491521502286_item	2654742	et	3	main
nagu	doc_491521502286_item	2654746	et	3	main
majanduslikku	doc_491521502286_item	2654753	et	4	main
hukkuga	doc_491521502286_item	2654754	et	4	main
mida	doc_491521502286_item	2654760	et	4	main
tuli	doc_491521502286_item	2654761	et	4	main
kiiremas	doc_491521502286_item	2654763	et	4	main
ja	doc_491521502286_item	2654765	et	3	main
selle	doc_491521502286_item	2654769	et	4	main
nii	doc_491521502286_item	2654775	et	3	main
range	doc_491521502286_item	2654776	et	4	main
ta	doc_491521502286_item	2654782	et	4	main
rohkem	doc_491521502286_item	2654785	et	4	main
olid	doc_491521502286_item	2654793	et	4	main
raha	doc_491521502286_item	2654796	et	4	main
oli	doc_491521502286_item	2654798	et	3	main
inimestel	doc_491521502286_item	2654797	et	3	main
riik	doc_491521502286_item	2654799	et	3	main
doteeris	doc_491521502286_item	2654800	et	4	main
palju	doc_491521502286_item	2654801	et	4	main
valdkondi	doc_491521502286_item	2654802	et	4	main
raske	doc_491521502286_item	2654803	et	4	main
oli	doc_491521502286_item	2654804	et	3	main
saada	doc_491521502286_item	2654805	et	4	main
näiteks	doc_491521502286_item	2654806	et	4	main
raamatuid	doc_491521502286_item	2654807	et	3	main
oli	doc_491521502286_item	2654808	et	3	main
palju	doc_491521502286_item	2654809	et	4	main
propagandat	doc_491521502286_item	2654810	et	3	main
näiteks	doc_491521502286_item	2654811	et	4	main
olid	doc_491521502286_item	2654812	et	4	main
teatud	doc_491521502286_item	2654813	et	4	main
propaganda	doc_491521502286_item	2654814	et	4	main
brošuurid	doc_491521502286_item	2654815	et	2	main
mida	doc_491521502286_item	2654816	et	4	main
pidid	doc_491521502286_item	2654817	et	4	main
isegi	doc_491521502286_item	2654818	et	4	main
lapsed	doc_491521502286_item	2654819	et	3	main
koolis	doc_491521502286_item	2654820	et	4	main
lugema	doc_491521502286_item	2654821	et	4	main
venemaa	doc_491521502286_item	2654825	et	4	main
nendest	doc_491521502286_item	2654731	et	4	main
kasvas	doc_491521502286_item	2654732	et	3	main
välja	doc_491521502286_item	2654733	et	4	main
isamaaliidu	doc_491521502286_item	2654734	et	4	main
partei	doc_491521502286_item	2654735	et	4	main
2	doc_491521502286_item	2654736	et	2	main
gorbatšov	doc_491521502286_item	2654741	et	2	main
seotud	doc_491521502286_item	2654752	et	4	main
venemaal	doc_491521502286_item	2654756	et	4	main
kriis	doc_491521502286_item	2654759	et	3	main
ka	doc_491521502286_item	2654767	et	3	main
varjata	doc_491521502286_item	2654768	et	4	main
olemasolu	doc_491521502286_item	2654770	et	4	main
tsensuur	doc_491521502286_item	2654771	et	3	main
ei	doc_491521502286_item	2654772	et	4	main
tekkis	doc_491521502286_item	2654778	et	3	main
nüd	doc_491521502286_item	2654781	et	4	main
olukord	doc_491521502286_item	2654789	et	3	main
oli	doc_491521502286_item	2654790	et	3	main
raske	doc_491521502286_item	2654791	et	4	main
pooed	doc_491521502286_item	2654792	et	4	main
tühjad	doc_491521502286_item	2654794	et	3	main
nõukogude	doc_491521502286_item	2654824	et	3	main
glasnost	doc_491521502288_item	2655060	et	4	main
ja	doc_491521502288_item	2655061	et	3	main
1	doc_491521502288_item	2655063	et	2	main
eesti	doc_491521502288_item	2655064	et	4	main
taasisesesvumise	doc_491521502288_item	2655065	et	4	main
juba	doc_491521502288_item	2655068	et	3	main
lõpus	doc_491521502288_item	2655071	et	4	main
käigus	doc_491521502288_item	2655076	et	4	main
nsvl-st	doc_491521502288_item	2655085	et	3	main
detsembrikuus	doc_491521502288_item	2655086	et	3	main
veebruaris	doc_491521502288_item	2655090	et	3	main
pikk-hermanile	doc_491521502288_item	2655092	et	4	main
perestroika	doc_491521502286_item	2654822	et	4	main
lagunemisega	doc_491521502286_item	2654826	et	4	main
1	doc_491521502288_item	2655051	et	2	main
perestroika	doc_491521502288_item	2655062	et	4	main
80-ndate	doc_491521502288_item	2655069	et	4	main
aastate	doc_491521502288_item	2655070	et	3	main
see	doc_491521502288_item	2655072	et	3	main
protsess	doc_491521502288_item	2655074	et	3	main
tahtsid	doc_491521502288_item	2655082	et	4	main
pandi	doc_491521502288_item	2655091	et	4	main
ja	doc_491521502288_item	2655095	et	3	main
maikuus	doc_491521502288_item	2655096	et	3	main
toetas	doc_491521502288_item	2655125	et	3	main
erinevad	doc_491521502288_item	2655134	et	4	main
poliitikud	doc_491521502288_item	2655137	et	3	main
nsvl-st	doc_491521502288_item	2655145	et	3	main
mis	doc_491521502288_item	2655158	et	4	main
ei	doc_491521502288_item	2655169	et	4	main
oleks	doc_491521502288_item	2655170	et	3	main
nagu	doc_491521502288_item	2655177	et	3	main
rahva	doc_491521502288_item	2655185	et	3	main
oma	doc_491521502288_item	2655189	et	4	main
õiguste	doc_491521502288_item	2655190	et	4	main
iseseisvaks	doc_491521502288_item	2655195	et	3	main
gorbatšovi	doc_491521502288_item	2655200	et	2	main
muudatused	doc_491521502288_item	2655222	et	3	main
eraldasid	doc_491521502288_item	2655224	et	4	main
kaks	doc_491521502288_item	2655237	et	3	main
tol	doc_491521502288_item	2655252	et	3	main
rahaühik	doc_491521502288_item	2655260	et	3	main
jne	doc_491521502288_item	2655273	et	4	main
reziimi	doc_491521502288_item	2655291	et	4	main
roll	doc_491521502288_item	2655053	et	3	main
2	doc_491521502288_item	2655056	et	2	main
protsess	doc_491521502288_item	2655066	et	3	main
oli	doc_491521502288_item	2655073	et	3	main
mille	doc_491521502288_item	2655075	et	3	main
eestlastest	doc_491521502288_item	2655077	et	4	main
saada	doc_491521502288_item	2655083	et	4	main
avaldati	doc_491521502288_item	2655087	et	3	main
rahvarinne	doc_491521502288_item	2655124	et	3	main
avaldasid	doc_491521502288_item	2655138	et	4	main
oma	doc_491521502288_item	2655139	et	4	main
teleris	doc_491521502288_item	2655146	et	3	main
saadet	doc_491521502288_item	2655150	et	3	main
rahvarinnet	doc_491521502288_item	2655153	et	3	main
poliitika	doc_491521502288_item	2655161	et	4	main
võimalik	doc_491521502288_item	2655171	et	3	main
eesi	doc_491521502288_item	2655172	et	4	main
tõuke	doc_491521502288_item	2655178	et	4	main
jõud	doc_491521502288_item	2655181	et	4	main
panna	doc_491521502288_item	2655187	et	4	main
õigus	doc_491521502288_item	2655193	et	4	main
perestroika	doc_491521502288_item	2655198	et	4	main
leedu	doc_491521502288_item	2655228	et	4	main
ümberkorraldusi	doc_491521502288_item	2655242	et	3	main
võimule	doc_491521502288_item	2655243	et	3	main
tulid	doc_491521502288_item	2655244	et	4	main
demokraatlik	doc_491521502288_item	2655245	et	3	main
vaatega	doc_491521502288_item	2655246	et	3	main
poliitikud	doc_491521502288_item	2655247	et	3	main
jeltsini	doc_491521502288_item	2655248	et	4	main
eesotsas	doc_491521502288_item	2655249	et	4	main
eesti	doc_491521502288_item	2655250	et	4	main
ajal	doc_491521502288_item	2655253	et	4	main
uus	doc_491521502288_item	2655259	et	3	main
sai	doc_491521502288_item	2655262	et	4	main
võib	doc_491521502288_item	2655275	et	3	main
perestroika	doc_491521502288_item	2655278	et	4	main
ümberajamine	doc_491521502288_item	2655280	et	4	main
otseselt	doc_491521502288_item	2655281	et	4	main
see	doc_491521502288_item	2655288	et	3	main
isegi	doc_491521502288_item	2655294	et	4	main
režiimi	doc_491521502288_item	2655298	et	2	main
loomine	doc_491521502288_item	2655299	et	4	main
kestva	doc_491521502288_item	2655300	et	4	main
teel	doc_491521502288_item	2655303	et	4	main
see	doc_491521502288_item	2655305	et	3	main
teada	doc_491521502288_item	2655312	et	3	main
pakt	doc_491521502288_item	2655323	et	3	main
seega	doc_491521502288_item	2655326	et	4	main
ka	doc_491521502288_item	2655328	et	3	main
organisatsioonid	doc_491521502288_item	2655339	et	3	main
rahvas	doc_491521502288_item	2655340	et	4	main
1	doc_491521502289_item	2655347	et	2	main
laulev	doc_491521502289_item	2655358	et	4	main
1991	doc_491521502289_item	2655365	et	2	main
rahareform	doc_491521502289_item	2655370	et	3	main
rahvarinne	doc_491521502289_item	2655379	et	3	main
eesotsas	doc_491521502289_item	2655380	et	4	main
mart	doc_491521502289_item	2655386	et	3	main
taasiseseisvunud	doc_491521502289_item	2655392	et	4	main
eestis	doc_491521502289_item	2655393	et	3	main
ka	doc_491521502289_item	2655421	et	3	main
kontrolltöö	doc_491521502288_item	2655050	et	4	main
eesti	doc_491521502288_item	2655054	et	4	main
rahvas	doc_491521502288_item	2655078	et	4	main
ja	doc_491521502288_item	2655079	et	3	main
ka	doc_491521502288_item	2655080	et	3	main
pakt	doc_491521502288_item	2655089	et	3	main
kultuuritegelased	doc_491521502288_item	2655135	et	3	main
ja	doc_491521502288_item	2655136	et	3	main
soovi	doc_491521502288_item	2655142	et	4	main
eraldatamiseks	doc_491521502288_item	2655144	et	4	main
oli	doc_491521502288_item	2655147	et	3	main
näha	doc_491521502288_item	2655149	et	3	main
toetasid	doc_491521502288_item	2655152	et	4	main
ja	doc_491521502288_item	2655154	et	3	main
lõpetuseks	doc_491521502288_item	2655162	et	4	main
see	doc_491521502288_item	2655175	et	3	main
ja	doc_491521502288_item	2655179	et	3	main
ka	doc_491521502288_item	2655184	et	3	main
vabariigiks	doc_491521502288_item	2655196	et	3	main
toimus	doc_491521502288_item	2655199	et	3	main
toimunud	doc_491521502288_item	2655221	et	4	main
eestimaa	doc_491521502288_item	2655226	et	4	main
jne	doc_491521502288_item	2655229	et	4	main
loomine	doc_491521502288_item	2655235	et	4	main
tõid	doc_491521502288_item	2655239	et	4	main
sai	doc_491521502288_item	2655254	et	4	main
e	doc_491521502288_item	2655255	et	4	main
savisaar	doc_491521502288_item	2655256	et	3	main
eestis	doc_491521502288_item	2655257	et	3	main
kehtestati	doc_491521502288_item	2655258	et	3	main
mis	doc_491521502288_item	2655261	et	4	main
nimetuse	doc_491521502288_item	2655263	et	4	main
ja	doc_491521502288_item	2655267	et	3	main
suundamine	doc_491521502288_item	2655268	et	4	main
et	doc_491521502288_item	2655277	et	3	main
tõlgitud	doc_491521502288_item	2655282	et	4	main
kehtestamine	doc_491521502288_item	2655292	et	4	main
glasnost	doc_491521502288_item	2655304	et	4	main
rahvale	doc_491521502288_item	2655309	et	3	main
võimalust	doc_491521502288_item	2655311	et	3	main
ja	doc_491521502288_item	2655324	et	3	main
rahva	doc_491521502288_item	2655329	et	3	main
tegutsema	doc_491521502288_item	2655333	et	3	main
sai	doc_491521502288_item	2655341	et	4	main
hääletusõigus	doc_491521502288_item	2655342	et	4	main
muutused	doc_491521502289_item	2655348	et	4	main
muudatused	doc_491521502289_item	2655350	et	3	main
1	doc_491521502289_item	2655360	et	2	main
kuulutati	doc_491521502289_item	2655362	et	4	main
kroon	doc_491521502289_item	2655372	et	3	main
valitsust	doc_491521502289_item	2655384	et	4	main
esimest	doc_491521502289_item	2655388	et	4	main
uuendustega	doc_491521502289_item	2655399	et	4	main
ning	doc_491521502289_item	2655403	et	3	main
oli	doc_491521502289_item	2655424	et	3	main
e	doc_491521502289_item	2655441	et	4	main
rahvarinde	doc_491521502288_item	2655052	et	4	main
taasiseseivumisprotsessis	doc_491521502288_item	2655055	et	4	main
mida	doc_491521502288_item	2655057	et	4	main
tähendavad	doc_491521502288_item	2655058	et	4	main
mõisted	doc_491521502288_item	2655059	et	3	main
algas	doc_491521502288_item	2655067	et	3	main
muulased	doc_491521502288_item	2655081	et	4	main
iseseisvuse	doc_491521502288_item	2655084	et	4	main
molotov-ribentropi	doc_491521502288_item	2655088	et	4	main
lipp	doc_491521502288_item	2655094	et	3	main
kuulutati	doc_491521502288_item	2655097	et	4	main
eesti	doc_491521502288_item	2655098	et	4	main
suveräänsus	doc_491521502288_item	2655099	et	4	main
nsvl-st	doc_491521502288_item	2655100	et	3	main
kõigele	doc_491521502288_item	2655101	et	4	main
sellele	doc_491521502288_item	2655102	et	4	main
aitas	doc_491521502288_item	2655103	et	3	main
suveräänsust	doc_491521502288_item	2655104	et	4	main
nsvl-st	doc_491521502288_item	2655105	et	3	main
kõigele	doc_491521502288_item	2655106	et	4	main
sellele	doc_491521502288_item	2655107	et	4	main
aitas	doc_491521502288_item	2655108	et	3	main
kaasa	doc_491521502288_item	2655109	et	4	main
väga	doc_491521502288_item	2655110	et	3	main
suurel	doc_491521502288_item	2655111	et	3	main
määral	doc_491521502288_item	2655112	et	3	main
rahvarinne	doc_491521502288_item	2655113	et	3	main
rahvarinne	doc_491521502288_item	2655114	et	3	main
igasuguseid	doc_491521502288_item	2655116	et	3	main
korraldas	doc_491521502288_item	2655115	et	3	main
koosolekuid	doc_491521502288_item	2655117	et	3	main
hääletusi	doc_491521502288_item	2655118	et	4	main
ja	doc_491521502288_item	2655119	et	3	main
kontserti	doc_491521502288_item	2655120	et	4	main
eesti	doc_491521502288_item	2655121	et	4	main
toetamiseks	doc_491521502288_item	2655123	et	4	main
elav	doc_491521502288_item	2655127	et	4	main
nt	doc_491521502288_item	2655132	et	4	main
savisaar	doc_491521502288_item	2655133	et	3	main
ja	doc_491521502288_item	2655141	et	3	main
eesti	doc_491521502288_item	2655143	et	4	main
toetasid	doc_491521502288_item	2655159	et	4	main
gorbatšovi	doc_491521502288_item	2655160	et	2	main
vabariigiks	doc_491521502288_item	2655173	et	3	main
aitas	doc_491521502288_item	2655183	et	3	main
eesti	doc_491521502288_item	2655191	et	4	main
võidelda	doc_491521502288_item	2655192	et	4	main
2	doc_491521502288_item	2655197	et	2	main
läti	doc_491521502288_item	2655227	et	4	main
2	doc_491521502288_item	2655230	et	2	main
nsvl	doc_491521502288_item	2655231	et	4	main
hävenemine	doc_491521502288_item	2655232	et	4	main
ja	doc_491521502288_item	2655233	et	3	main
venemaa	doc_491521502288_item	2655234	et	4	main
teod	doc_491521502288_item	2655238	et	4	main
sinine-must-valge	doc_491521502288_item	2655093	et	4	main
taasiseisvumise	doc_491521502288_item	2655122	et	4	main
eestimaal	doc_491521502288_item	2655126	et	4	main
rahvas	doc_491521502288_item	2655128	et	4	main
ja	doc_491521502288_item	2655129	et	3	main
ka	doc_491521502288_item	2655130	et	3	main
poliitikud	doc_491521502288_item	2655131	et	3	main
arvamust	doc_491521502288_item	2655140	et	3	main
võimalik	doc_491521502288_item	2655148	et	3	main
mis	doc_491521502288_item	2655151	et	4	main
olid	doc_491521502288_item	2655155	et	4	main
vastukaaluks	doc_491521502288_item	2655156	et	3	main
nendele	doc_491521502288_item	2655157	et	4	main
tahask	doc_491521502288_item	2655163	et	4	main
öelda	doc_491521502288_item	2655164	et	4	main
et	doc_491521502288_item	2655165	et	3	main
rahvarinnete	doc_491521502288_item	2655166	et	3	main
võib	doc_491521502288_item	2655167	et	3	main
olla	doc_491521502288_item	2655168	et	3	main
saada	doc_491521502288_item	2655174	et	4	main
oli	doc_491521502288_item	2655176	et	3	main
kaasaaitav	doc_491521502288_item	2655180	et	4	main
see	doc_491521502288_item	2655182	et	3	main
koos	doc_491521502288_item	2655186	et	4	main
ja	doc_491521502288_item	2655188	et	3	main
olla	doc_491521502288_item	2655194	et	3	main
võimu	doc_491521502288_item	2655201	et	4	main
ajal	doc_491521502288_item	2655202	et	4	main
ja	doc_491521502288_item	2655203	et	3	main
lõpetas	doc_491521502288_item	2655204	et	3	main
seda	doc_491521502288_item	2655205	et	3	main
uus	doc_491521502288_item	2655206	et	3	main
venemaa	doc_491521502288_item	2655207	et	4	main
president	doc_491521502288_item	2655208	et	3	main
vladimir	doc_491521502288_item	2655209	et	4	main
jeltsin	doc_491521502288_item	2655210	et	4	main
perestroika	doc_491521502288_item	2655211	et	4	main
tähendas	doc_491521502288_item	2655212	et	3	main
uue	doc_491521502288_item	2655213	et	3	main
riigisüsteemi	doc_491521502288_item	2655214	et	4	main
loomist	doc_491521502288_item	2655215	et	4	main
80-ndate	doc_491521502288_item	2655216	et	4	main
lõpus	doc_491521502288_item	2655217	et	4	main
ja	doc_491521502288_item	2655218	et	3	main
90-ndate	doc_491521502288_item	2655219	et	4	main
alguses	doc_491521502288_item	2655220	et	4	main
1	doc_491521502288_item	2655223	et	2	main
nsv-st	doc_491521502288_item	2655225	et	3	main
need	doc_491521502288_item	2655236	et	3	main
ühesõnaga	doc_491521502288_item	2655274	et	3	main
on	doc_491521502288_item	2655279	et	4	main
seletaks	doc_491521502288_item	2655285	et	3	main
nii	doc_491521502288_item	2655286	et	3	main
uue	doc_491521502288_item	2655290	et	3	main
või	doc_491521502288_item	2655293	et	4	main
parem	doc_491521502288_item	2655295	et	4	main
öeda	doc_491521502288_item	2655296	et	4	main
uue	doc_491521502288_item	2655297	et	3	main
ümberkorraldamise	doc_491521502288_item	2655302	et	3	main
mitmeid	doc_491521502288_item	2655319	et	4	main
fakte	doc_491521502288_item	2655320	et	3	main
molotov-ribentropi	doc_491521502288_item	2655322	et	4	main
kaasnes	doc_491521502288_item	2655327	et	3	main
enesetundmise	doc_491521502288_item	2655330	et	3	main
hakkasid	doc_491521502288_item	2655332	et	4	main
varem	doc_491521502288_item	2655335	et	4	main
keelatud	doc_491521502288_item	2655336	et	4	main
oma	doc_491521502288_item	2655343	et	4	main
tuleviku	doc_491521502288_item	2655344	et	4	main
eesti	doc_491521502289_item	2655352	et	4	main
revolutsioon	doc_491521502289_item	2655359	et	3	main
aastal	doc_491521502289_item	2655366	et	3	main
esimesena	doc_491521502289_item	2655367	et	3	main
vastu	doc_491521502289_item	2655369	et	3	main
eesti	doc_491521502289_item	2655371	et	4	main
eesti	doc_491521502289_item	2655374	et	4	main
ülemnõukogu	doc_491521502289_item	2655375	et	4	main
valimisliiduga	doc_491521502289_item	2655381	et	3	main
seda	doc_491521502289_item	2655383	et	3	main
pärast	doc_491521502289_item	2655394	et	4	main
elatustaseme	doc_491521502289_item	2655401	et	3	main
palju	doc_491521502288_item	2655240	et	4	main
erinevaid	doc_491521502288_item	2655241	et	4	main
esipresidendiks	doc_491521502288_item	2655251	et	4	main
kroon	doc_491521502288_item	2655264	et	3	main
majanduse	doc_491521502288_item	2655265	et	4	main
ümberkorraldamine	doc_491521502288_item	2655266	et	3	main
ka	doc_491521502288_item	2655269	et	3	main
läände	doc_491521502288_item	2655270	et	3	main
haridussüsteemi	doc_491521502288_item	2655271	et	4	main
ümberkorraldamine	doc_491521502288_item	2655272	et	3	main
öelda	doc_491521502288_item	2655276	et	4	main
mis	doc_491521502288_item	2655283	et	4	main
ma	doc_491521502288_item	2655284	et	3	main
et	doc_491521502288_item	2655287	et	3	main
on	doc_491521502288_item	2655289	et	4	main
korra	doc_491521502288_item	2655301	et	4	main
tähendab	doc_491521502288_item	2655306	et	3	main
seda	doc_491521502288_item	2655307	et	3	main
et	doc_491521502288_item	2655308	et	3	main
anti	doc_491521502288_item	2655310	et	3	main
sellest	doc_491521502288_item	2655313	et	4	main
mis	doc_491521502288_item	2655314	et	4	main
tõesti	doc_491521502288_item	2655315	et	3	main
toimus	doc_491521502288_item	2655316	et	3	main
riigis	doc_491521502288_item	2655317	et	3	main
avalikustati	doc_491521502288_item	2655318	et	3	main
nt	doc_491521502288_item	2655321	et	4	main
seltsid	doc_491521502288_item	2655337	et	4	main
ja	doc_491521502288_item	2655338	et	3	main
rajamiseks	doc_491521502288_item	2655345	et	4	main
ja	doc_491521502289_item	2655349	et	3	main
taasiseseisvunud	doc_491521502289_item	2655351	et	4	main
poliitilises	doc_491521502289_item	2655353	et	3	main
2	doc_491521502289_item	2655355	et	2	main
mida	doc_491521502289_item	2655356	et	4	main
tähendab	doc_491521502289_item	2655357	et	3	main
2008	doc_491521502289_item	2655364	et	2	main
valimised	doc_491521502289_item	2655377	et	4	main
võitis	doc_491521502289_item	2655378	et	3	main
isamaa	doc_491521502289_item	2655382	et	4	main
laar	doc_491521502289_item	2655387	et	3	main
ii	doc_491521502289_item	2655395	et	4	main
kaasnes	doc_491521502289_item	2655400	et	3	main
langus	doc_491521502289_item	2655402	et	4	main
varanduslik	doc_491521502289_item	2655404	et	3	main
tööpuudus	doc_491521502289_item	2655422	et	3	main
1994	doc_491521502289_item	2655427	et	2	main
tegi	doc_491521502289_item	2655430	et	4	main
ka	doc_491521502289_item	2655432	et	3	main
suurenev	doc_491521502289_item	2655434	et	4	main
korruptsioon	doc_491521502289_item	2655437	et	3	main
savisaar	doc_491521502289_item	2655442	et	3	main
aitama	doc_491521502289_item	2655449	et	3	main
liberaliseerimine	doc_491521502289_item	2655459	et	4	main
vastu	doc_491521502289_item	2655461	et	3	main
põhiseadus	doc_491521502289_item	2655482	et	4	main
niinimetatud	doc_491521502289_item	2655486	et	3	main
uus	doc_491521502289_item	2655500	et	3	main
osa	doc_491521502289_item	2655508	et	4	main
vene	doc_491521502289_item	2655512	et	4	main
jätkunud	doc_491521502289_item	2655521	et	4	main
elamurajoonid	doc_491521502289_item	2655523	et	3	main
külmaks	doc_491521502289_item	2655525	et	4	main
nüüd	doc_491521502289_item	2655526	et	4	main
suhteline	doc_491521502289_item	2655534	et	4	main
ja	doc_491521502289_item	2655535	et	3	main
otsa	doc_491521502289_item	2655539	et	4	main
90ndatel	doc_491521502289_item	2655542	et	4	main
ka	doc_491521502289_item	2655546	et	3	main
vene	doc_491521502289_item	2655553	et	4	main
inimestel	doc_491521502289_item	2655558	et	3	main
aga	doc_491521502289_item	2655559	et	3	main
aga	doc_491521502289_item	2655566	et	3	main
nii	doc_491521502289_item	2655568	et	3	main
laulev	doc_491521502289_item	2655571	et	4	main
rahul	doc_491521502289_item	2655581	et	4	main
taasiseseisvunud	doc_491521502290_item	2655620	et	4	main
eesti	doc_491521502290_item	2655621	et	4	main
elus	doc_491521502290_item	2655623	et	4	main
isikukultuse	doc_491521502290_item	2655634	et	3	main
afganistani	doc_491521502290_item	2655643	et	4	main
dokumente	doc_491521502288_item	2655325	et	3	main
kõrgendamine	doc_491521502288_item	2655331	et	4	main
mõned	doc_491521502288_item	2655334	et	3	main
kontrolltöö	doc_491521502289_item	2655346	et	4	main
elus	doc_491521502289_item	2655354	et	4	main
eesti	doc_491521502289_item	2655361	et	4	main
taasiseseisvaks	doc_491521502289_item	2655363	et	3	main
võeti	doc_491521502289_item	2655368	et	3	main
1992	doc_491521502289_item	2655373	et	2	main
korraldatud	doc_491521502289_item	2655376	et	4	main
juhtis	doc_491521502289_item	2655385	et	3	main
korda	doc_491521502289_item	2655389	et	4	main
toimusidki	doc_491521502289_item	2655390	et	4	main
valimised	doc_491521502289_item	2655391	et	4	main
maailmasõda	doc_491521502289_item	2655396	et	4	main
aastal	doc_491521502289_item	2655397	et	3	main
1992	doc_491521502289_item	2655398	et	2	main
ebavõrdsus	doc_491521502289_item	2655405	et	4	main
kõige	doc_491521502289_item	2655406	et	4	main
hullemas	doc_491521502289_item	2655407	et	4	main
seisud	doc_491521502289_item	2655408	et	3	main
olid	doc_491521502289_item	2655409	et	4	main
noored	doc_491521502289_item	2655410	et	3	main
lastega	doc_491521502289_item	2655411	et	3	main
pered	doc_491521502289_item	2655412	et	3	main
ja	doc_491521502289_item	2655413	et	3	main
pensionärid	doc_491521502289_item	2655414	et	3	main
riik	doc_491521502289_item	2655415	et	3	main
ei	doc_491521502289_item	2655416	et	4	main
teinud	doc_491521502289_item	2655417	et	4	main
suurt	doc_491521502289_item	2655418	et	3	main
midagi	doc_491521502289_item	2655419	et	4	main
suurenes	doc_491521502289_item	2655420	et	4	main
eestil	doc_491521502289_item	2655423	et	3	main
19	doc_491521502289_item	2655428	et	2	main
üha	doc_491521502289_item	2655433	et	3	main
kuritegevus	doc_491521502289_item	2655435	et	4	main
ja	doc_491521502289_item	2655436	et	3	main
olukorda	doc_491521502289_item	2655438	et	4	main
püüdis	doc_491521502289_item	2655439	et	3	main
ta	doc_491521502289_item	2655444	et	4	main
tagasi	doc_491521502289_item	2655448	et	3	main
võeti	doc_491521502289_item	2655460	et	3	main
võeti	doc_491521502289_item	2655478	et	3	main
ka	doc_491521502289_item	2655480	et	3	main
rahareformi	doc_491521502289_item	2655484	et	4	main
kauplused	doc_491521502289_item	2655489	et	3	main
ka	doc_491521502289_item	2655494	et	3	main
majanduskasv	doc_491521502289_item	2655495	et	3	main
seda	doc_491521502289_item	2655496	et	3	main
seoses	doc_491521502289_item	2655497	et	4	main
siis	doc_491521502289_item	2655498	et	3	main
uuendustega	doc_491521502289_item	2655499	et	4	main
ei	doc_491521502289_item	2655520	et	4	main
jäid	doc_491521502289_item	2655524	et	4	main
head	doc_491521502289_item	2655549	et	4	main
ja	doc_491521502289_item	2655550	et	3	main
kaupa	doc_491521502289_item	2655563	et	4	main
inimesed	doc_491521502289_item	2655579	et	3	main
kardeti	doc_491521502289_item	2655585	et	3	main
aastal	doc_491521502289_item	2655426	et	3	main
muret	doc_491521502289_item	2655431	et	3	main
a	doc_491521502289_item	2655443	et	4	main
pidi	doc_491521502289_item	2655445	et	4	main
lahkuma	doc_491521502289_item	2655447	et	3	main
toimus	doc_491521502289_item	2655450	et	3	main
vahetus	doc_491521502289_item	2655452	et	4	main
ja	doc_491521502289_item	2655453	et	3	main
riigis	doc_491521502289_item	2655454	et	3	main
suudeti	doc_491521502289_item	2655455	et	3	main
majandusolukord	doc_491521502289_item	2655456	et	3	main
stabiliseerida	doc_491521502289_item	2655457	et	3	main
toimus	doc_491521502289_item	2655458	et	3	main
ning	doc_491521502289_item	2655465	et	3	main
viidi	doc_491521502289_item	2655466	et	4	main
läbi	doc_491521502289_item	2655467	et	4	main
ka	doc_491521502289_item	2655468	et	3	main
keelereform	doc_491521502289_item	2655469	et	3	main
saab	doc_491521502289_item	2655470	et	3	main
rääkida	doc_491521502289_item	2655471	et	3	main
riigikeelest	doc_491521502289_item	2655472	et	4	main
pika	doc_491521502289_item	2655473	et	4	main
hermanni	doc_491521502289_item	2655474	et	4	main
tornis	doc_491521502289_item	2655475	et	3	main
lehvib	doc_491521502289_item	2655476	et	3	main
see	doc_491521502289_item	2655425	et	3	main
rahvale	doc_491521502289_item	2655429	et	3	main
parandada	doc_491521502289_item	2655440	et	3	main
hoopis	doc_491521502289_item	2655446	et	3	main
valitsuse	doc_491521502289_item	2655451	et	4	main
hulk	doc_491521502289_item	2655463	et	3	main
baasseadusi	doc_491521502289_item	2655464	et	3	main
rahvuslipp	doc_491521502289_item	2655477	et	3	main
vastu	doc_491521502289_item	2655479	et	3	main
uut	doc_491521502289_item	2655487	et	3	main
kaubaga	doc_491521502289_item	2655491	et	3	main
suurenes	doc_491521502289_item	2655493	et	4	main
poliitika	doc_491521502289_item	2655501	et	4	main
osa	doc_491521502289_item	2655504	et	4	main
eestist	doc_491521502289_item	2655509	et	3	main
oli	doc_491521502289_item	2655516	et	3	main
terve	doc_491521502289_item	2655462	et	4	main
uus	doc_491521502289_item	2655481	et	3	main
turg	doc_491521502289_item	2655488	et	3	main
teeninduse	doc_491521502289_item	2655507	et	4	main
lahkusid	doc_491521502289_item	2655510	et	4	main
enne	doc_491521502289_item	2655514	et	4	main
suur	doc_491521502289_item	2655517	et	3	main
elektrikriis	doc_491521502289_item	2655518	et	3	main
bensiini	doc_491521502289_item	2655519	et	4	main
on	doc_491521502289_item	2655532	et	4	main
kõik	doc_491521502289_item	2655533	et	4	main
on	doc_491521502289_item	2655537	et	4	main
e	doc_491521502289_item	2655543	et	4	main
eesti	doc_491521502289_item	2655547	et	4	main
aja	doc_491521502289_item	2655548	et	4	main
ajal	doc_491521502289_item	2655554	et	4	main
oli	doc_491521502289_item	2655555	et	3	main
kaubapuudus	doc_491521502289_item	2655556	et	3	main
raha	doc_491521502289_item	2655557	et	4	main
oli	doc_491521502289_item	2655560	et	3	main
eesti	doc_491521502289_item	2655576	et	4	main
taasiseseisvumist	doc_491521502289_item	2655577	et	3	main
nimelt	doc_491521502289_item	2655584	et	4	main
nsvl	doc_491521502289_item	2655586	et	4	main
2	doc_491521502290_item	2655624	et	2	main
laulev	doc_491521502290_item	2655627	et	4	main
revolutsioon	doc_491521502290_item	2655628	et	3	main
1	doc_491521502290_item	2655629	et	2	main
1989	doc_491521502290_item	2655630	et	2	main
moskvas	doc_491521502290_item	2655642	et	4	main
kui	doc_491521502290_item	2655661	et	3	main
seotud	doc_491521502290_item	2655671	et	4	main
maa	doc_491521502290_item	2655673	et	4	main
enam	doc_491521502290_item	2655678	et	4	main
väga	doc_491521502290_item	2655679	et	3	main
ikka	doc_491521502290_item	2655696	et	4	main
oli	doc_491521502290_item	2655697	et	3	main
iseseisvust	doc_491521502290_item	2655705	et	4	main
1992	doc_491521502290_item	2655706	et	2	main
ev	doc_491521502290_item	2655721	et	4	main
peale	doc_491521502289_item	2655483	et	4	main
kaob	doc_491521502289_item	2655485	et	3	main
täituvad	doc_491521502289_item	2655490	et	4	main
järsult	doc_491521502289_item	2655492	et	4	main
vähenes	doc_491521502289_item	2655502	et	3	main
põllumajanduse	doc_491521502289_item	2655503	et	3	main
järsult	doc_491521502289_item	2655505	et	4	main
kasvas	doc_491521502289_item	2655506	et	3	main
ka	doc_491521502289_item	2655511	et	3	main
sõjaväeüksused	doc_491521502289_item	2655513	et	3	main
taasiseseisvumist	doc_491521502289_item	2655515	et	3	main
seda	doc_491521502289_item	2655527	et	3	main
probleemi	doc_491521502289_item	2655528	et	4	main
polnud	doc_491521502289_item	2655529	et	3	main
nagu	doc_491521502289_item	2655530	et	3	main
kaks	doc_491521502289_item	2655538	et	3	main
nii	doc_491521502289_item	2655540	et	3	main
siis	doc_491521502289_item	2655544	et	3	main
vene	doc_491521502289_item	2655545	et	4	main
küljed	doc_491521502289_item	2655552	et	3	main
nüüd	doc_491521502289_item	2655561	et	4	main
raha	doc_491521502289_item	2655565	et	4	main
pole	doc_491521502289_item	2655567	et	3	main
palju	doc_491521502289_item	2655569	et	4	main
kui	doc_491521502289_item	2655578	et	3	main
toimuvaga	doc_491521502289_item	2655583	et	4	main
a	doc_491521502290_item	2655631	et	4	main
suri	doc_491521502290_item	2655632	et	3	main
periood	doc_491521502290_item	2655635	et	3	main
mõned	doc_491521502290_item	2655646	et	3	main
tulnud	doc_491521502290_item	2655648	et	4	main
om	doc_491521502290_item	2655649	et	4	main
igapäevaseid	doc_491521502290_item	2655659	et	4	main
tahad	doc_491521502290_item	2655662	et	3	main
raamatu	doc_491521502290_item	2655664	et	4	main
siis	doc_491521502290_item	2655665	et	3	main
peab	doc_491521502290_item	2655666	et	4	main
ka	doc_491521502290_item	2655667	et	3	main
ostma	doc_491521502290_item	2655668	et	3	main
midagi	doc_491521502290_item	2655669	et	4	main
poliitikaga	doc_491521502290_item	2655670	et	3	main
sinine-must-valge	doc_491521502290_item	2655685	et	4	main
poliitiline	doc_491521502290_item	2655690	et	3	main
elu	doc_491521502290_item	2655691	et	4	main
väga	doc_491521502290_item	2655693	et	3	main
muutunud	doc_491521502290_item	2655694	et	4	main
aga	doc_491521502290_item	2655695	et	3	main
eesti	doc_491521502290_item	2655704	et	4	main
valitsused	doc_491521502290_item	2655724	et	4	main
vabakaubanduse	doc_491521502290_item	2655726	et	3	main
euroopaga	doc_491521502290_item	2655727	et	3	main
banaane	doc_491521502290_item	2655728	et	3	main
jogurti	doc_491521502290_item	2655729	et	3	main
esimene	doc_491521502290_item	2655730	et	3	main
eesti	doc_491521502290_item	2655731	et	4	main
esimene	doc_491521502290_item	2655738	et	3	main
laulev	doc_491521502290_item	2655741	et	4	main
1	doc_491521502291_item	2655744	et	2	main
tähtsamad	doc_491521502291_item	2655747	et	4	main
esimese	doc_491521502291_item	2655748	et	3	main
rahvusliku	doc_491521502291_item	2655749	et	3	main
sinu	doc_491521502291_item	2655752	et	3	main
võrdsed	doc_491521502291_item	2655782	et	3	main
muuta	doc_491521502291_item	2655785	et	4	main
olnud	doc_491521502291_item	2655790	et	4	main
koguduse	doc_491521502291_item	2655797	et	3	main
liige	doc_491521502291_item	2655798	et	4	main
olema	doc_491521502291_item	2655800	et	4	main
haritud	doc_491521502291_item	2655801	et	4	main
lugeda	doc_491521502291_item	2655803	et	3	main
kõige	doc_491521502291_item	2655824	et	4	main
rahvusliku	doc_491521502291_item	2655827	et	3	main
teelased	doc_491521502291_item	2655829	et	3	main
minu	doc_491521502291_item	2655830	et	3	main
olid	doc_491521502291_item	2655832	et	4	main
soove	doc_491521502291_item	2655837	et	3	main
üks	doc_491521502291_item	2655844	et	3	main
neid	doc_491521502291_item	2655845	et	4	main
j	doc_491521502291_item	2655847	et	4	main
v	doc_491521502291_item	2655848	et	4	main
1857a	doc_491521502291_item	2655851	et	4	main
terved	doc_491521502289_item	2655522	et	4	main
ikka	doc_491521502289_item	2655531	et	4	main
kõigel	doc_491521502289_item	2655536	et	4	main
ka	doc_491521502289_item	2655541	et	3	main
halvad	doc_491521502289_item	2655551	et	4	main
on	doc_491521502289_item	2655562	et	4	main
ülearugi	doc_491521502289_item	2655564	et	3	main
2	doc_491521502289_item	2655570	et	2	main
revolutsioon	doc_491521502289_item	2655572	et	3	main
see	doc_491521502289_item	2655573	et	3	main
oli	doc_491521502289_item	2655574	et	3	main
enne	doc_491521502289_item	2655575	et	4	main
polnud	doc_491521502289_item	2655580	et	3	main
riigis	doc_491521502289_item	2655582	et	3	main
väiksemate	doc_491521502289_item	2655587	et	4	main
liikmesriikide	doc_491521502289_item	2655588	et	3	main
rahvuskeele	doc_491521502289_item	2655589	et	4	main
kadumist	doc_491521502289_item	2655590	et	4	main
vene	doc_491521502289_item	2655591	et	4	main
keel	doc_491521502289_item	2655592	et	4	main
oli	doc_491521502289_item	2655593	et	3	main
siis	doc_491521502289_item	2655594	et	3	main
nö	doc_491521502289_item	2655595	et	4	main
rahvusvaheline	doc_491521502289_item	2655596	et	4	main
suhtluskeel	doc_491521502289_item	2655597	et	4	main
aastal	doc_491521502289_item	2655598	et	3	main
1989	doc_491521502289_item	2655599	et	2	main
toimus	doc_491521502289_item	2655600	et	3	main
laulupidu	doc_491521502289_item	2655601	et	4	main
kus	doc_491521502289_item	2655602	et	3	main
esitati	doc_491521502289_item	2655603	et	4	main
isamaalisi	doc_491521502289_item	2655604	et	4	main
eesti	doc_491521502289_item	2655605	et	4	main
laule	doc_491521502289_item	2655606	et	4	main
ridade	doc_491521502289_item	2655608	et	3	main
ja	doc_491521502289_item	2655607	et	3	main
vahelt	doc_491521502289_item	2655609	et	4	main
võis	doc_491521502289_item	2655610	et	4	main
välja	doc_491521502289_item	2655611	et	4	main
lugeda	doc_491521502289_item	2655612	et	3	main
kommunismivastase	doc_491521502289_item	2655613	et	4	main
pahameeleprotesti	doc_491521502289_item	2655614	et	4	main
kontrolltöö	doc_491521502290_item	2655615	et	4	main
1	doc_491521502290_item	2655616	et	2	main
muutused	doc_491521502290_item	2655617	et	4	main
ja	doc_491521502290_item	2655618	et	3	main
muudatused	doc_491521502290_item	2655619	et	3	main
poliitilises	doc_491521502290_item	2655622	et	3	main
mida	doc_491521502290_item	2655625	et	4	main
tähendab	doc_491521502290_item	2655626	et	3	main
siis	doc_491521502290_item	2655645	et	3	main
majandus	doc_491521502290_item	2655650	et	4	main
oli	doc_491521502290_item	2655651	et	3	main
osta	doc_491521502290_item	2655658	et	4	main
osta	doc_491521502290_item	2655663	et	4	main
väike	doc_491521502290_item	2655672	et	4	main
majandus	doc_491521502290_item	2655683	et	4	main
kriis	doc_491521502290_item	2655684	et	3	main
eesti	doc_491521502290_item	2655689	et	4	main
on	doc_491521502290_item	2655692	et	4	main
venemaa	doc_491521502290_item	2655702	et	4	main
tunnistub	doc_491521502290_item	2655703	et	4	main
tekkib	doc_491521502290_item	2655709	et	3	main
uue	doc_491521502290_item	2655710	et	3	main
raha	doc_491521502290_item	2655711	et	4	main
idee	doc_491521502290_item	2655712	et	4	main
euro	doc_491521502290_item	2655713	et	4	main
võetakse	doc_491521502290_item	2655714	et	3	main
kasutusele	doc_491521502290_item	2655715	et	4	main
eesti	doc_491521502290_item	2655716	et	4	main
kroon	doc_491521502290_item	2655717	et	3	main
juunis	doc_491521502290_item	2655718	et	3	main
28	doc_491521502290_item	2655719	et	2	main
juuni	doc_491521502290_item	2655720	et	4	main
põhiseadus	doc_491521502290_item	2655722	et	4	main
esimesed	doc_491521502290_item	2655723	et	3	main
1994	doc_491521502290_item	2655725	et	2	main
meri	doc_491521502290_item	2655734	et	3	main
rajas	doc_491521502290_item	2655737	et	4	main
kes	doc_491521502291_item	2655745	et	4	main
panus	doc_491521502291_item	2655758	et	4	main
ja	doc_491521502291_item	2655783	et	3	main
mingeid	doc_491521502291_item	2655793	et	3	main
oskama	doc_491521502291_item	2655802	et	3	main
panna	doc_491521502291_item	2655808	et	4	main
liivimaa	doc_491521502291_item	2655816	et	4	main
kõige	doc_491521502291_item	2655818	et	4	main
osad	doc_491521502291_item	2655822	et	3	main
ja	doc_491521502291_item	2655838	et	3	main
sõnastada	doc_491521502291_item	2655840	et	3	main
kes	doc_491521502291_item	2655850	et	4	main
postimees	doc_491521502291_item	2655857	et	4	main
tere	doc_491521502291_item	2655863	et	3	main
eesti	doc_491521502291_item	2655865	et	4	main
oma	doc_491521502291_item	2655867	et	4	main
tegutses	doc_491521502291_item	2655905	et	3	main
r	doc_491521502291_item	2655910	et	4	main
kes	doc_491521502291_item	2655912	et	4	main
oli	doc_491521502291_item	2655921	et	3	main
köler	doc_491521502291_item	2655925	et	4	main
patriotide	doc_491521502291_item	2655929	et	4	main
eesotsas	doc_491521502291_item	2655931	et	4	main
aluse	doc_491521502291_item	2655934	et	4	main
palvekirjade	doc_491521502291_item	2655935	et	3	main
eesmärke	doc_491521502291_item	2655946	et	4	main
j	doc_491521502291_item	2655949	et	4	main
hurt	doc_491521502291_item	2655950	et	3	main
oli	doc_491521502291_item	2655951	et	3	main
ja	doc_491521502291_item	2655974	et	3	main
sellel	doc_491521502291_item	2655979	et	4	main
kontrolltöö	doc_491521502292_item	2655987	et	4	main
reformatsioon	doc_491521502292_item	2655998	et	3	main
oli	doc_491521502292_item	2656006	et	3	main
kogus	doc_491521502292_item	2656008	et	4	main
makse	doc_491521502292_item	2656009	et	4	main
ja	doc_491521502292_item	2656010	et	3	main
valitses	doc_491521502292_item	2656011	et	3	main
brežnev	doc_491521502290_item	2655633	et	2	main
tema	doc_491521502290_item	2655636	et	4	main
valitsemise	doc_491521502290_item	2655637	et	4	main
viimase	doc_491521502290_item	2655638	et	3	main
ajad	doc_491521502290_item	2655639	et	4	main
1980	doc_491521502290_item	2655640	et	2	main
olümpiamängud	doc_491521502290_item	2655641	et	3	main
sõda	doc_491521502290_item	2655644	et	4	main
madalal	doc_491521502290_item	2655652	et	4	main
tasemel	doc_491521502290_item	2655653	et	3	main
toiduabi	doc_491521502290_item	2655654	et	4	main
pakkid	doc_491521502290_item	2655655	et	4	main
kohustuslik	doc_491521502290_item	2655656	et	3	main
kaupu	doc_491521502290_item	2655660	et	3	main
brošüür	doc_491521502290_item	2655674	et	2	main
kohustuslik	doc_491521502290_item	2655675	et	3	main
kooliõpilastele	doc_491521502290_item	2655676	et	4	main
võetud	doc_491521502290_item	2655682	et	4	main
taasiseseisvunud	doc_491521502290_item	2655688	et	4	main
madalal	doc_491521502290_item	2655698	et	4	main
tasemel	doc_491521502290_item	2655699	et	3	main
majandus	doc_491521502290_item	2655700	et	4	main
1991	doc_491521502290_item	2655701	et	2	main
liidus	doc_491521502290_item	2655708	et	4	main
edgar	doc_491521502290_item	2655735	et	4	main
parter	doc_491521502290_item	2655739	et	3	main
2	doc_491521502291_item	2655762	et	2	main
inimesed	doc_491521502291_item	2655778	et	3	main
on	doc_491521502291_item	2655779	et	4	main
ei	doc_491521502291_item	2655789	et	4	main
maal	doc_491521502291_item	2655796	et	4	main
oma	doc_491521502291_item	2655805	et	4	main
lugu	doc_491521502291_item	2655806	et	4	main
olid	doc_491521502291_item	2655817	et	4	main
mõtteid	doc_491521502291_item	2655839	et	3	main
ja	doc_491521502291_item	2655841	et	3	main
oli	doc_491521502291_item	2655846	et	3	main
jannsen	doc_491521502291_item	2655849	et	4	main
perno	doc_491521502291_item	2655856	et	4	main
ta	doc_491521502291_item	2655862	et	4	main
rahvas	doc_491521502291_item	2655866	et	4	main
tööga	doc_491521502291_item	2655868	et	3	main
sellel	doc_491521502291_item	2655906	et	4	main
ei	doc_491521502290_item	2655647	et	4	main
tuli	doc_491521502290_item	2655657	et	4	main
nliitu	doc_491521502290_item	2655677	et	4	main
tõsiselt	doc_491521502290_item	2655680	et	4	main
ei	doc_491521502290_item	2655681	et	4	main
lipp	doc_491521502290_item	2655686	et	3	main
peale	doc_491521502290_item	2655687	et	4	main
euroopa	doc_491521502290_item	2655707	et	4	main
lennart	doc_491521502290_item	2655733	et	4	main
savisaar	doc_491521502290_item	2655736	et	3	main
2	doc_491521502290_item	2655740	et	2	main
revolutsioon	doc_491521502290_item	2655742	et	3	main
kontrolltöö	doc_491521502291_item	2655743	et	4	main
olid	doc_491521502291_item	2655746	et	4	main
ärkamisaja	doc_491521502291_item	2655750	et	3	main
eestlaste	doc_491521502291_item	2655759	et	4	main
haridusalu	doc_491521502291_item	2655760	et	4	main
ees	doc_491521502291_item	2655781	et	4	main
püüdsid	doc_491521502291_item	2655784	et	4	main
olukorda	doc_491521502291_item	2655786	et	4	main
kus	doc_491521502291_item	2655787	et	3	main
eestlastel	doc_491521502291_item	2655788	et	4	main
mitte	doc_491521502291_item	2655792	et	3	main
pidi	doc_491521502291_item	2655799	et	4	main
kirja	doc_491521502291_item	2655807	et	4	main
eestimaa	doc_491521502291_item	2655814	et	4	main
ja	doc_491521502291_item	2655815	et	3	main
haritud	doc_491521502291_item	2655819	et	4	main
vene	doc_491521502291_item	2655820	et	4	main
president	doc_491521502290_item	2655732	et	3	main
tegelased	doc_491521502291_item	2655751	et	3	main
meelest	doc_491521502291_item	2655753	et	4	main
miks	doc_491521502291_item	2655754	et	4	main
2	doc_491521502291_item	2655755	et	2	main
vennaskoguduse	doc_491521502291_item	2655756	et	3	main
liikumise	doc_491521502291_item	2655757	et	4	main
edendamisse	doc_491521502291_item	2655761	et	4	main
vennastekoguduse	doc_491521502291_item	2655763	et	3	main
liikumine	doc_491521502291_item	2655764	et	4	main
tegutses	doc_491521502291_item	2655765	et	3	main
eesti	doc_491521502291_item	2655766	et	4	main
territooriumil	doc_491521502291_item	2655767	et	3	main
1730-1740	doc_491521502291_item	2655768	et	2	main
aastatel	doc_491521502291_item	2655769	et	4	main
nad	doc_491521502291_item	2655770	et	3	main
olin	doc_491521502291_item	2655771	et	3	main
hernhuutlased	doc_491521502291_item	2655773	et	3	main
nn	doc_491521502291_item	2655772	et	4	main
nemad	doc_491521502291_item	2655774	et	3	main
arvasid	doc_491521502291_item	2655775	et	4	main
et	doc_491521502291_item	2655776	et	3	main
kõik	doc_491521502291_item	2655777	et	4	main
jumala	doc_491521502291_item	2655780	et	3	main
peaaigu	doc_491521502291_item	2655791	et	4	main
õigusi	doc_491521502291_item	2655794	et	4	main
oma	doc_491521502291_item	2655795	et	4	main
ümberjutustada	doc_491521502291_item	2655804	et	4	main
laulda	doc_491521502291_item	2655809	et	4	main
mängida	doc_491521502291_item	2655810	et	3	main
tänu	doc_491521502291_item	2655811	et	4	main
vennastekoguduse	doc_491521502291_item	2655812	et	3	main
liikumisele	doc_491521502291_item	2655813	et	4	main
impeeriumi	doc_491521502291_item	2655821	et	4	main
tähtsamad	doc_491521502291_item	2655825	et	4	main
rahva	doc_491521502291_item	2655836	et	3	main
neid	doc_491521502291_item	2655843	et	4	main
oma	doc_491521502291_item	2655858	et	4	main
esimeses	doc_491521502291_item	2655859	et	3	main
ajalehes	doc_491521502291_item	2655860	et	3	main
a	doc_491521502291_item	2655898	et	4	main
hakkas	doc_491521502291_item	2655899	et	3	main
rahvuslaste	doc_491521502291_item	2655900	et	4	main
ringikesi	doc_491521502291_item	2655901	et	4	main
tekkima	doc_491521502291_item	2655902	et	3	main
alal	doc_491521502291_item	2655907	et	4	main
tähtis	doc_491521502291_item	2655919	et	4	main
maalikunstnik	doc_491521502291_item	2655923	et	3	main
kes	doc_491521502291_item	2655926	et	4	main
akstsioonile	doc_491521502291_item	2655937	et	4	main
olid	doc_491521502291_item	2655981	et	4	main
lidia	doc_491521502291_item	2655983	et	4	main
ristiusustamise	doc_491521502292_item	2655989	et	3	main
eesti	doc_491521502292_item	2655991	et	4	main
ühiskonnakorraldusele	doc_491521502292_item	2655992	et	3	main
sajandils	doc_491521502292_item	2655994	et	4	main
2	doc_491521502292_item	2655995	et	2	main
kirik	doc_491521502292_item	2656001	et	3	main
muutunud	doc_491521502292_item	2656003	et	4	main
riigis	doc_491521502292_item	2656005	et	3	main
lutheri	doc_491521502292_item	2656013	et	4	main
ka	doc_491521502292_item	2656014	et	3	main
kirik	doc_491521502292_item	2656021	et	3	main
inimese	doc_491521502292_item	2656027	et	4	main
oli	doc_491521502292_item	2656030	et	3	main
muuta	doc_491521502292_item	2656038	et	4	main
10	doc_491521502292_item	2656043	et	2	main
hakati	doc_491521502292_item	2656053	et	3	main
neist	doc_491521502292_item	2656071	et	4	main
pühakute	doc_491521502292_item	2656094	et	3	main
austamise	doc_491521502292_item	2656095	et	4	main
vastu	doc_491521502292_item	2656096	et	3	main
polnud	doc_491521502292_item	2656097	et	3	main
külakatoliikluseks	doc_491521502292_item	2656105	et	4	main
kuna	doc_491521502292_item	2656106	et	3	main
katoliiklikud	doc_491521502292_item	2656115	et	3	main
kombed	doc_491521502292_item	2656117	et	3	main
lapsetele	doc_491521502292_item	2656121	et	3	main
õpetama	doc_491521502292_item	2656123	et	3	main
ja	doc_491521502292_item	2656129	et	3	main
käsku	doc_491521502292_item	2656131	et	4	main
külas	doc_491521502292_item	2656133	et	3	main
õpetati	doc_491521502292_item	2656134	et	3	main
üks	doc_491521502292_item	2656136	et	3	main
kes	doc_491521502292_item	2656138	et	4	main
suure	doc_491521502292_item	2656146	et	3	main
tõenäosusega	doc_491521502292_item	2656147	et	3	main
varsti	doc_491521502292_item	2656148	et	3	main
kristlikult	doc_491521502292_item	2656159	et	4	main
mitmed	doc_491521502292_item	2656161	et	4	main
eestlased	doc_491521502292_item	2656162	et	3	main
said	doc_491521502292_item	2656163	et	4	main
tööd	doc_491521502292_item	2656164	et	4	main
rängmunbadena	doc_491521502292_item	2656168	et	4	main
kujunesid	doc_491521502292_item	2656172	et	4	main
oma	doc_491521502292_item	2656174	et	4	main
keelemurre	doc_491521502292_item	2656175	et	4	main
rahvariided	doc_491521502292_item	2656176	et	3	main
pooleni	doc_491521502292_item	2656185	et	3	main
linnad	doc_491521502292_item	2656222	et	3	main
pealt	doc_491521502292_item	2656224	et	4	main
tallinn	doc_491521502292_item	2656225	et	4	main
ja	doc_491521502292_item	2656226	et	3	main
see	doc_491521502292_item	2656232	et	3	main
1	doc_491521502291_item	2655823	et	2	main
esimese	doc_491521502291_item	2655826	et	3	main
ärkamisaja	doc_491521502291_item	2655828	et	3	main
meelest	doc_491521502291_item	2655831	et	4	main
need	doc_491521502291_item	2655833	et	3	main
kes	doc_491521502291_item	2655834	et	4	main
püüdsid	doc_491521502291_item	2655835	et	4	main
arenda	doc_491521502291_item	2655842	et	4	main
andma	doc_491521502291_item	2655854	et	3	main
ajalehte	doc_491521502291_item	2655855	et	4	main
kirjutas	doc_491521502291_item	2655861	et	3	main
ta	doc_491521502291_item	2655869	et	4	main
väärtustada	doc_491521502291_item	2655871	et	3	main
rahvust	doc_491521502291_item	2655873	et	3	main
ja	doc_491521502291_item	2655874	et	3	main
võitis	doc_491521502291_item	2655875	et	3	main
ümberrahvastamise	doc_491521502291_item	2655876	et	3	main
vastu	doc_491521502291_item	2655877	et	3	main
ta	doc_491521502291_item	2655878	et	4	main
sai	doc_491521502291_item	2655879	et	4	main
populaarseks	doc_491521502291_item	2655880	et	4	main
sest	doc_491521502291_item	2655881	et	4	main
lähenes	doc_491521502291_item	2655882	et	3	main
rahvale	doc_491521502291_item	2655883	et	3	main
tema	doc_491521502291_item	2655884	et	4	main
enda	doc_491521502291_item	2655885	et	4	main
tasemel	doc_491521502291_item	2655886	et	3	main
asutas	doc_491521502291_item	2655887	et	3	main
kooride	doc_491521502291_item	2655888	et	3	main
orkestride	doc_491521502291_item	2655889	et	4	main
muusika	doc_491521502291_item	2655890	et	4	main
seltsi	doc_491521502291_item	2655891	et	4	main
korraldas	doc_491521502291_item	2655892	et	3	main
i	doc_491521502291_item	2655893	et	4	main
hakkas	doc_491521502291_item	2655852	et	3	main
välja	doc_491521502291_item	2655853	et	4	main
armas	doc_491521502291_item	2655864	et	3	main
püüdis	doc_491521502291_item	2655870	et	3	main
eesti	doc_491521502291_item	2655872	et	4	main
üldlaulupidu	doc_491521502291_item	2655894	et	4	main
1869	doc_491521502291_item	2655895	et	2	main
võrus	doc_491521502291_item	2655903	et	3	main
f	doc_491521502291_item	2655909	et	4	main
tegelane	doc_491521502291_item	2655920	et	3	main
ja	doc_491521502291_item	2655922	et	3	main
oli	doc_491521502291_item	2655927	et	3	main
saatmise	doc_491521502291_item	2655936	et	4	main
sihe	doc_491521502291_item	2655944	et	4	main
tuntuim	doc_491521502291_item	2655947	et	4	main
keeleteadlane	doc_491521502291_item	2655948	et	3	main
aleksandrikooli	doc_491521502291_item	2655952	et	4	main
liikumise	doc_491521502291_item	2655953	et	4	main
liider	doc_491521502291_item	2655954	et	3	main
ja	doc_491521502291_item	2655955	et	3	main
pidas	doc_491521502291_item	2655956	et	3	main
tuntud	doc_491521502291_item	2655971	et	4	main
oma	doc_491521502291_item	2655972	et	4	main
kirjutistega	doc_491521502291_item	2655976	et	3	main
väga	doc_491521502291_item	2655977	et	3	main
laulud	doc_491521502291_item	2655986	et	3	main
mõjud	doc_491521502292_item	2655990	et	4	main
1316	doc_491521502292_item	2655993	et	2	main
reformatsioon	doc_491521502292_item	2656000	et	3	main
martin	doc_491521502292_item	2656012	et	4	main
hingeelule	doc_491521502292_item	2656028	et	3	main
muutunud	doc_491521502292_item	2656031	et	4	main
seda	doc_491521502292_item	2656036	et	3	main
naelutas	doc_491521502292_item	2656041	et	3	main
teesi	doc_491521502292_item	2656044	et	4	main
sellest	doc_491521502292_item	2656048	et	4	main
sai	doc_491521502292_item	2656049	et	4	main
reformatsioon	doc_491521502292_item	2656050	et	3	main
alguse	doc_491521502292_item	2656051	et	3	main
katoliku	doc_491521502292_item	2656056	et	3	main
talupoegadest	doc_491521502292_item	2656059	et	3	main
aga	doc_491521502292_item	2656064	et	3	main
kombed	doc_491521502292_item	2656067	et	3	main
eestlaste	doc_491521502292_item	2656100	et	4	main
usundit	doc_491521502292_item	2656101	et	3	main
hakati	doc_491521502292_item	2656102	et	3	main
oma	doc_491521502292_item	2656109	et	4	main
usk	doc_491521502292_item	2656110	et	3	main
ja	doc_491521502292_item	2656111	et	3	main
palvet	doc_491521502292_item	2656128	et	3	main
igas	doc_491521502292_item	2656132	et	3	main
talupoeg	doc_491521502292_item	2656137	et	3	main
sai	doc_491521502292_item	2656139	et	4	main
ristida	doc_491521502292_item	2656140	et	4	main
too	doc_491521502292_item	2656151	et	4	main
talupoeg	doc_491521502292_item	2656153	et	3	main
matta	doc_491521502292_item	2656160	et	3	main
territooriumil	doc_491521502292_item	2656170	et	3	main
olukord	doc_491521502292_item	2656179	et	3	main
jäi	doc_491521502292_item	2656180	et	3	main
püsima	doc_491521502292_item	2656181	et	3	main
saj	doc_491521502292_item	2656183	et	4	main
teise	doc_491521502292_item	2656184	et	4	main
tartu	doc_491521502292_item	2656227	et	4	main
leidnud	doc_491521502292_item	2656249	et	4	main
tallinn	doc_491521502292_item	2656254	et	4	main
tartu	doc_491521502292_item	2656255	et	4	main
varem	doc_491521502292_item	2656268	et	4	main
või	doc_491521502292_item	2656283	et	4	main
läks	doc_491521502292_item	2656317	et	3	main
a	doc_491521502291_item	2655896	et	4	main
1860	doc_491521502291_item	2655897	et	2	main
aktiivselt	doc_491521502291_item	2655904	et	4	main
dr	doc_491521502291_item	2655908	et	4	main
kreutzwald	doc_491521502291_item	2655911	et	4	main
iseenesest	doc_491521502291_item	2655913	et	4	main
oli	doc_491521502291_item	2655914	et	3	main
nagu	doc_491521502291_item	2655915	et	3	main
kultuuri	doc_491521502291_item	2655916	et	4	main
keskus	doc_491521502291_item	2655917	et	3	main
ärkamisaja	doc_491521502291_item	2655918	et	3	main
j	doc_491521502291_item	2655924	et	4	main
peterburi	doc_491521502291_item	2655928	et	4	main
grupi	doc_491521502291_item	2655930	et	3	main
aktsioon	doc_491521502291_item	2655938	et	3	main
ei	doc_491521502291_item	2655939	et	4	main
ja	doc_491521502291_item	2655945	et	3	main
olulisemaks	doc_491521502291_item	2655958	et	4	main
kooliraamatute	doc_491521502291_item	2655973	et	3	main
teravate	doc_491521502291_item	2655975	et	3	main
tähtsad	doc_491521502291_item	2655978	et	3	main
mida	doc_491521502292_item	2655996	et	4	main
tähendab	doc_491521502292_item	2655997	et	3	main
ilmalikustunud	doc_491521502292_item	2656007	et	4	main
meelest	doc_491521502292_item	2656016	et	4	main
polnud	doc_491521502292_item	2656017	et	3	main
see	doc_491521502292_item	2656018	et	3	main
õige	doc_491521502292_item	2656019	et	4	main
et	doc_491521502292_item	2656020	et	3	main
ta	doc_491521502291_item	2655932	et	4	main
pani	doc_491521502291_item	2655933	et	4	main
õnnestunud	doc_491521502291_item	2655940	et	4	main
aga	doc_491521502291_item	2655941	et	3	main
märatles	doc_491521502291_item	2655942	et	4	main
rahvusliikumise	doc_491521502291_item	2655943	et	3	main
kõige	doc_491521502291_item	2655957	et	4	main
rahva	doc_491521502291_item	2655959	et	3	main
vaimuvara	doc_491521502291_item	2655960	et	4	main
rahvaluule	doc_491521502291_item	2655961	et	4	main
ja	doc_491521502291_item	2655962	et	3	main
ajaloo	doc_491521502291_item	2655963	et	4	main
tagastamist	doc_491521502291_item	2655964	et	4	main
eesti	doc_491521502291_item	2655965	et	4	main
rahvale	doc_491521502291_item	2655966	et	3	main
c	doc_491521502291_item	2655967	et	4	main
r	doc_491521502291_item	2655968	et	4	main
jakobson	doc_491521502291_item	2655969	et	4	main
oli	doc_491521502291_item	2655970	et	3	main
ajal	doc_491521502291_item	2655980	et	4	main
ka	doc_491521502291_item	2655982	et	3	main
koidula	doc_491521502291_item	2655984	et	4	main
isamaa	doc_491521502291_item	2655985	et	4	main
1	doc_491521502292_item	2655988	et	2	main
2	doc_491521502292_item	2655999	et	2	main
oli	doc_491521502292_item	2656002	et	3	main
riigiks	doc_491521502292_item	2656004	et	3	main
teiste	doc_491521502292_item	2656015	et	4	main
pööras	doc_491521502292_item	2656022	et	4	main
tähelepanu	doc_491521502292_item	2656024	et	4	main
rikastumisele	doc_491521502292_item	2656025	et	4	main
kui	doc_491521502292_item	2656026	et	3	main
ning	doc_491521502292_item	2656035	et	3	main
martin	doc_491521502292_item	2656039	et	4	main
kirikusüsteemi	doc_491521502292_item	2656052	et	4	main
tegi	doc_491521502292_item	2656058	et	4	main
oma	doc_491521502292_item	2656066	et	4	main
ja	doc_491521502292_item	2656068	et	3	main
säilisid	doc_491521502292_item	2656072	et	4	main
midagi	doc_491521502292_item	2656099	et	4	main
üle	doc_491521502292_item	2656113	et	3	main
11-aastatastele	doc_491521502292_item	2656120	et	4	main
elementaarselt	doc_491521502292_item	2656124	et	4	main
välja	doc_491521502292_item	2656135	et	4	main
kui	doc_491521502292_item	2656142	et	3	main
sündis	doc_491521502292_item	2656143	et	3	main
laps	doc_491521502292_item	2656144	et	4	main
kes	doc_491521502292_item	2656145	et	4	main
suri	doc_491521502292_item	2656149	et	3	main
õpetatud	doc_491521502292_item	2656152	et	4	main
juures	doc_491521502292_item	2656166	et	4	main
folkloor	doc_491521502292_item	2656177	et	4	main
15	doc_491521502292_item	2656186	et	2	main
tähendas	doc_491521502292_item	2656233	et	3	main
linnadega	doc_491521502292_item	2656236	et	3	main
liitu	doc_491521502292_item	2656252	et	4	main
kuulusid	doc_491521502292_item	2656253	et	4	main
viljandi	doc_491521502292_item	2656256	et	4	main
ja	doc_491521502292_item	2656257	et	3	main
sugukondliku	doc_491521502292_item	2656264	et	3	main
vormiga	doc_491521502292_item	2656265	et	4	main
palju	doc_491521502292_item	2656269	et	4	main
käigus	doc_491521502292_item	2656273	et	4	main
sellega	doc_491521502292_item	2656277	et	3	main
majandus	doc_491521502292_item	2656315	et	4	main
kätte	doc_491521502292_item	2656319	et	4	main
sal-st	doc_491521502292_item	2656322	et	3	main
talupojal	doc_491521502292_item	2656325	et	4	main
talurahvaks	doc_491521502292_item	2656331	et	3	main
tööriistaks	doc_491521502292_item	2656334	et	4	main
käsitöö	doc_491521502292_item	2656335	et	4	main
põllumajandusega	doc_491521502292_item	2656340	et	3	main
talupojad	doc_491521502292_item	2656342	et	4	main
ristimist	doc_491521502292_item	2656356	et	4	main
omaks	doc_491521502292_item	2656369	et	4	main
aega	doc_491521502292_item	2656370	et	4	main
kohalikud	doc_491521502292_item	2656377	et	3	main
olid	doc_491521502292_item	2656386	et	4	main
võrreldes	doc_491521502292_item	2656394	et	3	main
sellega	doc_491521502292_item	2656395	et	3	main
tulemas	doc_491521502292_item	2656397	et	4	main
kontrolltöö	doc_491521502293_item	2656401	et	4	main
linnakultuur	doc_491521502293_item	2656404	et	3	main
tallinn	doc_491521502293_item	2656427	et	4	main
olid	doc_491521502293_item	2656431	et	4	main
elasid	doc_491521502293_item	2656435	et	4	main
tubakat	doc_491521502293_item	2656442	et	3	main
raekoda	doc_491521502293_item	2656457	et	4	main
ja	doc_491521502293_item	2656458	et	3	main
kaitsemüürid	doc_491521502293_item	2656459	et	3	main
raekojas	doc_491521502293_item	2656460	et	3	main
pidasid	doc_491521502293_item	2656461	et	4	main
istungeid	doc_491521502293_item	2656462	et	3	main
antsid	doc_491521502293_item	2656483	et	4	main
juures	doc_491521502293_item	2656488	et	4	main
toomehäärana	doc_491521502293_item	2656498	et	4	main
mitmes	doc_491521502293_item	2656499	et	4	main
toomekirikus	doc_491521502293_item	2656500	et	3	main
siin	doc_491521502293_item	2656507	et	4	main
oli	doc_491521502293_item	2656515	et	3	main
jumal	doc_491521502292_item	2656029	et	3	main
luther	doc_491521502292_item	2656040	et	4	main
oma	doc_491521502292_item	2656042	et	4	main
kiriku	doc_491521502292_item	2656045	et	3	main
uksele	doc_491521502292_item	2656046	et	3	main
ning	doc_491521502292_item	2656047	et	3	main
muutma	doc_491521502292_item	2656054	et	3	main
sunniviisiliselt	doc_491521502292_item	2656060	et	4	main
kogukondlased	doc_491521502292_item	2656062	et	3	main
säilitasid	doc_491521502292_item	2656065	et	4	main
osad	doc_491521502292_item	2656070	et	3	main
isegi	doc_491521502292_item	2656073	et	4	main
17	doc_491521502292_item	2656074	et	2	main
18	doc_491521502292_item	2656075	et	2	main
sajandini	doc_491521502292_item	2656076	et	3	main
eestlased	doc_491521502292_item	2656077	et	3	main
omandasid	doc_491521502292_item	2656078	et	4	main
katoliku	doc_491521502292_item	2656079	et	3	main
kiriku	doc_491521502292_item	2656080	et	3	main
välised	doc_491521502292_item	2656081	et	4	main
kombed	doc_491521502292_item	2656082	et	3	main
kirikuskäimine	doc_491521502292_item	2656083	et	4	main
pühakute	doc_491521502292_item	2656084	et	3	main
säilmete	doc_491521502292_item	2656085	et	3	main
austamine	doc_491521502292_item	2656086	et	4	main
reliikvia	doc_491521502292_item	2656087	et	4	main
talupoegadele	doc_491521502292_item	2656088	et	3	main
meeldis	doc_491521502292_item	2656089	et	3	main
ka	doc_491521502292_item	2656090	et	3	main
pühitsemine	doc_491521502292_item	2656091	et	4	main
ja	doc_491521502292_item	2656092	et	3	main
õnnistamine	doc_491521502292_item	2656093	et	4	main
rohkem	doc_491521502292_item	2656023	et	4	main
kurjaks	doc_491521502292_item	2656032	et	4	main
ja	doc_491521502292_item	2656033	et	3	main
julmaks	doc_491521502292_item	2656034	et	3	main
tuli	doc_491521502292_item	2656037	et	4	main
1	doc_491521502292_item	2656055	et	2	main
kirik	doc_491521502292_item	2656057	et	3	main
oma	doc_491521502292_item	2656061	et	4	main
eestlased	doc_491521502292_item	2656063	et	3	main
tavad	doc_491521502292_item	2656069	et	3	main
nimetama	doc_491521502292_item	2656103	et	3	main
ka	doc_491521502292_item	2656114	et	3	main
tavad	doc_491521502292_item	2656116	et	3	main
uskumused	doc_491521502292_item	2656118	et	3	main
neil	doc_491521502292_item	2656098	et	4	main
n-ö	doc_491521502292_item	2656104	et	4	main
säilitati	doc_491521502292_item	2656107	et	3	main
osalt	doc_491521502292_item	2656108	et	4	main
võeti	doc_491521502292_item	2656112	et	3	main
umbes	doc_491521502292_item	2656119	et	4	main
hakati	doc_491521502292_item	2656122	et	3	main
piiblit	doc_491521502292_item	2656125	et	3	main
isa	doc_491521502292_item	2656127	et	4	main
kümmet	doc_491521502292_item	2656130	et	4	main
näiteks	doc_491521502292_item	2656141	et	4	main
võis	doc_491521502292_item	2656150	et	4	main
last	doc_491521502292_item	2656157	et	4	main
saaks	doc_491521502292_item	2656158	et	3	main
kirikute	doc_491521502292_item	2656165	et	4	main
ühel	doc_491521502292_item	2656169	et	3	main
kihelkonnas	doc_491521502292_item	2656171	et	3	main
välja	doc_491521502292_item	2656173	et	4	main
19	doc_491521502292_item	2656182	et	2	main
saj	doc_491521502292_item	2656187	et	4	main
hakkasid	doc_491521502292_item	2656188	et	4	main
meie	doc_491521502292_item	2656126	et	4	main
ta	doc_491521502292_item	2656154	et	4	main
ristida	doc_491521502292_item	2656155	et	4	main
et	doc_491521502292_item	2656156	et	3	main
tõlkida	doc_491521502292_item	2656167	et	3	main
selline	doc_491521502292_item	2656178	et	4	main
rändmungad	doc_491521502292_item	2656189	et	3	main
beginid	doc_491521502292_item	2656190	et	4	main
rajama	doc_491521502292_item	2656191	et	3	main
esimesi	doc_491521502292_item	2656192	et	4	main
avalikku	doc_491521502292_item	2656193	et	4	main
haiglaid	doc_491521502292_item	2656194	et	3	main
1434	doc_491521502292_item	2656195	et	2	main
avati	doc_491521502292_item	2656196	et	3	main
oleviste	doc_491521502292_item	2656197	et	4	main
kiriku	doc_491521502292_item	2656198	et	3	main
juures	doc_491521502292_item	2656199	et	4	main
esimene	doc_491521502292_item	2656200	et	3	main
kool	doc_491521502292_item	2656201	et	4	main
lihtrahvale	doc_491521502292_item	2656202	et	3	main
loodi	doc_491521502292_item	2656203	et	4	main
kirikukihelkonnad	doc_491521502292_item	2656204	et	3	main
territoorium	doc_491521502292_item	2656205	et	3	main
kus	doc_491521502292_item	2656206	et	3	main
oli	doc_491521502292_item	2656207	et	3	main
üks	doc_491521502292_item	2656208	et	3	main
peakirik	doc_491521502292_item	2656209	et	3	main
ja	doc_491521502292_item	2656210	et	3	main
kabelid	doc_491521502292_item	2656211	et	3	main
selline	doc_491521502292_item	2656212	et	4	main
jaotus	doc_491521502292_item	2656213	et	4	main
jäi	doc_491521502292_item	2656214	et	3	main
püsima	doc_491521502292_item	2656215	et	3	main
pikaks	doc_491521502292_item	2656216	et	4	main
ajaks	doc_491521502292_item	2656217	et	4	main
ka	doc_491521502292_item	2656218	et	3	main
maakondadena	doc_491521502292_item	2656219	et	3	main
eestisse	doc_491521502292_item	2656220	et	4	main
kerkisid	doc_491521502292_item	2656221	et	4	main
kõige	doc_491521502292_item	2656223	et	4	main
kuuluma	doc_491521502292_item	2656230	et	3	main
hansaliitu	doc_491521502292_item	2656231	et	4	main
soola	doc_491521502292_item	2656241	et	4	main
ja	doc_491521502292_item	2656242	et	3	main
viidi	doc_491521502292_item	2656243	et	4	main
rukist	doc_491521502292_item	2656250	et	3	main
feodaalkord	doc_491521502292_item	2656260	et	4	main
varem	doc_491521502292_item	2656261	et	4	main
oldi	doc_491521502292_item	2656262	et	3	main
mis	doc_491521502292_item	2656228	et	4	main
hakkasid	doc_491521502292_item	2656229	et	4	main
kauplemist	doc_491521502292_item	2656234	et	4	main
peamiselt	doc_491521502292_item	2656240	et	4	main
hansa	doc_491521502292_item	2656251	et	4	main
siin	doc_491521502292_item	2656267	et	4	main
ei	doc_491521502292_item	2656270	et	4	main
ristiusustamise	doc_491521502292_item	2656272	et	3	main
tutvusid	doc_491521502292_item	2656274	et	4	main
siinsed	doc_491521502292_item	2656275	et	3	main
inimesed	doc_491521502292_item	2656276	et	3	main
sageli	doc_491521502292_item	2656281	et	3	main
puudusid	doc_491521502292_item	2656282	et	4	main
olid	doc_491521502292_item	2656284	et	4	main
hajakülad	doc_491521502292_item	2656285	et	3	main
ristiusustamisega	doc_491521502292_item	2656286	et	3	main
kaasnes	doc_491521502292_item	2656287	et	3	main
linnade	doc_491521502292_item	2656288	et	3	main
ehk	doc_491521502292_item	2656290	et	3	main
teke	doc_491521502292_item	2656289	et	3	main
linnakultuuri	doc_491521502292_item	2656291	et	4	main
levik	doc_491521502292_item	2656292	et	3	main
talupojad	doc_491521502292_item	2656293	et	4	main
olid	doc_491521502292_item	2656294	et	4	main
iseenda	doc_491521502292_item	2656295	et	3	main
peremehed	doc_491521502292_item	2656296	et	3	main
varem	doc_491521502292_item	2656297	et	4	main
kuid	doc_491521502292_item	2656298	et	4	main
ristiusustamise	doc_491521502292_item	2656299	et	3	main
käigus	doc_491521502292_item	2656300	et	4	main
hakati	doc_491521502292_item	2656301	et	3	main
talupoegadelt	doc_491521502292_item	2656302	et	3	main
nõudma	doc_491521502292_item	2656303	et	3	main
igal	doc_491521502292_item	2656304	et	3	main
aastal	doc_491521502292_item	2656305	et	3	main
kümnist	doc_491521502292_item	2656306	et	3	main
110	doc_491521502292_item	2656307	et	2	main
kõigilt	doc_491521502292_item	2656308	et	4	main
sissetulekutelt	doc_491521502292_item	2656309	et	3	main
anda	doc_491521502292_item	2656311	et	3	main
tuli	doc_491521502292_item	2656310	et	4	main
kirikule	doc_491521502292_item	2656312	et	3	main
teiste	doc_491521502292_item	2656235	et	4	main
teistes	doc_491521502292_item	2656237	et	4	main
riikides	doc_491521502292_item	2656238	et	3	main
toodi	doc_491521502292_item	2656239	et	4	main
enamasti	doc_491521502292_item	2656244	et	4	main
igal	doc_491521502292_item	2656245	et	3	main
pool	doc_491521502292_item	2656246	et	4	main
maailmas	doc_491521502292_item	2656247	et	3	main
tunnustust	doc_491521502292_item	2656248	et	4	main
pärnu	doc_491521502292_item	2656258	et	4	main
kehtestati	doc_491521502292_item	2656259	et	3	main
kirjakunsti	doc_491521502292_item	2656266	et	4	main
tuntud	doc_491521502292_item	2656271	et	4	main
polnud	doc_491521502292_item	2656323	et	3	main
ta	doc_491521502292_item	2656329	et	4	main
sakste	doc_491521502292_item	2656332	et	3	main
samas	doc_491521502292_item	2656339	et	4	main
abielu	doc_491521502292_item	2656346	et	4	main
ja	doc_491521502292_item	2656347	et	3	main
põletamist	doc_491521502292_item	2656354	et	4	main
ei	doc_491521502292_item	2656359	et	4	main
kuidas	doc_491521502292_item	2656376	et	3	main
nõudeid	doc_491521502292_item	2656379	et	3	main
ja	doc_491521502292_item	2656381	et	3	main
sõjad	doc_491521502292_item	2656387	et	3	main
kuid	doc_491521502292_item	2656388	et	4	main
suhteliselt	doc_491521502292_item	2656392	et	4	main
olid	doc_491521502293_item	2656412	et	4	main
need	doc_491521502293_item	2656422	et	3	main
tartu	doc_491521502293_item	2656428	et	4	main
eestimaale	doc_491521502293_item	2656440	et	4	main
toodi	doc_491521502293_item	2656441	et	4	main
soola	doc_491521502293_item	2656444	et	4	main
heeringat	doc_491521502293_item	2656445	et	3	main
aga	doc_491521502293_item	2656446	et	3	main
toomekirikute	doc_491521502293_item	2656487	et	4	main
kuulusid	doc_491521502293_item	2656493	et	4	main
nad	doc_491521502293_item	2656495	et	3	main
korraga	doc_491521502293_item	2656501	et	4	main
toomekirikute	doc_491521502293_item	2656502	et	4	main
messe	doc_491521502293_item	2656513	et	3	main
levinud	doc_491521502293_item	2656517	et	4	main
hästi	doc_491521502293_item	2656518	et	3	main
laiali	doc_491521502293_item	2656519	et	3	main
tallinnas	doc_491521502293_item	2656520	et	4	main
harjutud	doc_491521502292_item	2656263	et	4	main
lähemalt	doc_491521502292_item	2656278	et	4	main
varem	doc_491521502292_item	2656279	et	4	main
külad	doc_491521502292_item	2656280	et	3	main
üldisemalt	doc_491521502292_item	2656316	et	4	main
alates	doc_491521502292_item	2656320	et	3	main
13	doc_491521502292_item	2656321	et	2	main
sakste	doc_491521502292_item	2656337	et	3	main
ühe	doc_491521502292_item	2656348	et	4	main
naise	doc_491521502292_item	2656349	et	3	main
pidamist	doc_491521502292_item	2656350	et	4	main
surnute	doc_491521502292_item	2656351	et	4	main
matmist	doc_491521502292_item	2656352	et	4	main
mitte	doc_491521502292_item	2656353	et	3	main
neist	doc_491521502292_item	2656357	et	4	main
kohe	doc_491521502292_item	2656361	et	4	main
kinni	doc_491521502292_item	2656362	et	3	main
pidama	doc_491521502292_item	2656363	et	4	main
ristiusu	doc_491521502292_item	2656378	et	3	main
usku	doc_491521502292_item	2656382	et	4	main
mõistsid	doc_491521502292_item	2656383	et	4	main
linnavõimude	doc_491521502292_item	2656384	et	3	main
hästi	doc_491521502292_item	2656393	et	3	main
pärisorjuslik	doc_491521502292_item	2656399	et	3	main
lübecki	doc_491521502293_item	2656425	et	4	main
õigust	doc_491521502293_item	2656426	et	4	main
ühingus	doc_491521502293_item	2656433	et	3	main
terist	doc_491521502293_item	2656449	et	3	main
linnas	doc_491521502293_item	2656454	et	4	main
mis	doc_491521502293_item	2656482	et	4	main
lugema	doc_491521502293_item	2656486	et	4	main
vaimulikud	doc_491521502293_item	2656491	et	3	main
selles	doc_491521502293_item	2656505	et	4	main
et	doc_491521502293_item	2656506	et	3	main
uhkemaid	doc_491521502293_item	2656512	et	4	main
olid	doc_491521502293_item	2656521	et	4	main
meistrid	doc_491521502293_item	2656523	et	3	main
aga	doc_491521502293_item	2656524	et	3	main
töid	doc_491521502293_item	2656526	et	3	main
töö	doc_491521502293_item	2656533	et	4	main
kvaliteet	doc_491521502293_item	2656534	et	3	main
oli	doc_491521502293_item	2656535	et	3	main
madalam	doc_491521502293_item	2656536	et	4	main
meistriks	doc_491521502293_item	2656541	et	3	main
oli	doc_491521502293_item	2656548	et	3	main
tähtsamad	doc_491521502293_item	2656554	et	4	main
käsitöölised	doc_491521502293_item	2656555	et	3	main
olid	doc_491521502293_item	2656556	et	4	main
sakslaste	doc_491521502293_item	2656567	et	3	main
tallinnas	doc_491521502293_item	2656569	et	4	main
vahel	doc_491521502293_item	2656589	et	4	main
ne	doc_491521502293_item	2656600	et	4	main
koel	doc_491521502293_item	2656610	et	3	main
ja	doc_491521502293_item	2656611	et	3	main
kiriku	doc_491521502293_item	2656622	et	3	main
russov	doc_491521502293_item	2656625	et	4	main
vaadeldavad	doc_491521502293_item	2656633	et	4	main
periodil	doc_491521502293_item	2656635	et	4	main
1525	doc_491521502293_item	2656646	et	2	main
aastal	doc_491521502293_item	2656647	et	3	main
saksamaal	doc_491521502293_item	2656648	et	4	main
olid	doc_491521502293_item	2656658	et	4	main
oma	doc_491521502293_item	2656661	et	4	main
pidid	doc_491521502293_item	2656664	et	4	main
maksma	doc_491521502293_item	2656665	et	3	main
osa	doc_491521502293_item	2656671	et	4	main
kuulusid	doc_491521502293_item	2656684	et	4	main
mõisnikule	doc_491521502293_item	2656685	et	3	main
tööriistad	doc_491521502293_item	2656686	et	3	main
mõiste	doc_491521502294_item	2656695	et	4	main
aastal	doc_491521502294_item	2656704	et	3	main
viingute	doc_491521502294_item	2656708	et	4	main
asitõendeid	doc_491521502294_item	2656724	et	3	main
kivipilt	doc_491521502294_item	2656744	et	3	main
sellest	doc_491521502294_item	2656747	et	4	main
maetud	doc_491521502294_item	2656755	et	4	main
kuskil	doc_491521502294_item	2656756	et	3	main
nüüdses	doc_491521502294_item	2656757	et	3	main
harjumaakonna	doc_491521502294_item	2656758	et	4	main
ajal	doc_491521502294_item	2656761	et	4	main
territooriumil	doc_491521502294_item	2656763	et	3	main
kaubandus	doc_491521502292_item	2656313	et	3	main
ja	doc_491521502292_item	2656314	et	3	main
sakste	doc_491521502292_item	2656318	et	3	main
asja	doc_491521502292_item	2656328	et	4	main
jäi	doc_491521502292_item	2656330	et	3	main
sakste	doc_491521502292_item	2656333	et	3	main
kätte	doc_491521502292_item	2656338	et	4	main
tegelesid	doc_491521502292_item	2656341	et	4	main
talupoegadelt	doc_491521502292_item	2656343	et	3	main
nõuti	doc_491521502292_item	2656344	et	3	main
kiriklikku	doc_491521502292_item	2656345	et	4	main
uued	doc_491521502292_item	2656364	et	3	main
kombed	doc_491521502292_item	2656365	et	3	main
ja	doc_491521502292_item	2656366	et	3	main
harjumused	doc_491521502292_item	2656367	et	4	main
võeti	doc_491521502292_item	2656368	et	3	main
kontrollis	doc_491521502292_item	2656375	et	4	main
täitsid	doc_491521502292_item	2656380	et	4	main
vahel	doc_491521502292_item	2656385	et	4	main
vaatamata	doc_491521502292_item	2656390	et	4	main
oli	doc_491521502292_item	2656398	et	3	main
1	doc_491521502293_item	2656409	et	2	main
paldiski	doc_491521502293_item	2656421	et	4	main
linnad	doc_491521502293_item	2656423	et	3	main
omasid	doc_491521502293_item	2656424	et	4	main
viljandi	doc_491521502293_item	2656429	et	4	main
hansa	doc_491521502293_item	2656432	et	4	main
kes	doc_491521502293_item	2656437	et	4	main
tegelesid	doc_491521502293_item	2656438	et	4	main
kaubandusega	doc_491521502293_item	2656439	et	3	main
välja	doc_491521502293_item	2656447	et	4	main
viidi	doc_491521502293_item	2656448	et	4	main
tähtsamad	doc_491521502293_item	2656451	et	4	main
keskaegses	doc_491521502293_item	2656453	et	3	main
olid	doc_491521502293_item	2656455	et	4	main
kirikud	doc_491521502293_item	2656456	et	3	main
haridust	doc_491521502293_item	2656484	et	4	main
õpetasid	doc_491521502293_item	2656485	et	4	main
toomehärrad	doc_491521502293_item	2656490	et	3	main
elasid	doc_491521502293_item	2656508	et	4	main
kõrgemad	doc_491521502293_item	2656509	et	4	main
vaimulikud	doc_491521502293_item	2656510	et	3	main
läbiviidi	doc_491521502293_item	2656511	et	3	main
tegid	doc_491521502293_item	2656527	et	4	main
kohalikude	doc_491521502293_item	2656531	et	3	main
võiks	doc_491521502293_item	2656542	et	4	main
saada	doc_491521502293_item	2656543	et	4	main
ainult	doc_491521502293_item	2656544	et	4	main
see	doc_491521502293_item	2656545	et	3	main
varandus	doc_491521502293_item	2656550	et	3	main
isegi	doc_491521502293_item	2656571	et	4	main
geograafiaasetuses	doc_491521502293_item	2656581	et	4	main
läbi	doc_491521502293_item	2656582	et	4	main
euroopa	doc_491521502293_item	2656586	et	4	main
venemaa	doc_491521502293_item	2656588	et	4	main
viidi	doc_491521502293_item	2656591	et	4	main
karusnahke	doc_491521502293_item	2656593	et	3	main
aga	doc_491521502293_item	2656594	et	3	main
sisse	doc_491521502293_item	2656595	et	4	main
olid	doc_491521502293_item	2656602	et	4	main
kõige	doc_491521502293_item	2656603	et	4	main
benkt	doc_491521502293_item	2656613	et	4	main
notke	doc_491521502293_item	2656614	et	4	main
oli	doc_491521502293_item	2656615	et	3	main
matsil	doc_491521502292_item	2656324	et	4	main
ühiskonnaelu	doc_491521502292_item	2656326	et	4	main
korraldamisesse	doc_491521502292_item	2656327	et	4	main
läks	doc_491521502292_item	2656336	et	3	main
laste	doc_491521502292_item	2656355	et	4	main
nõuetest	doc_491521502292_item	2656358	et	4	main
hakatud	doc_491521502292_item	2656360	et	4	main
mööda	doc_491521502292_item	2656371	et	4	main
kirik	doc_491521502292_item	2656372	et	3	main
teostas	doc_491521502292_item	2656373	et	3	main
visitatsioone	doc_491521502292_item	2656374	et	3	main
sellele	doc_491521502292_item	2656389	et	4	main
elati	doc_491521502292_item	2656391	et	3	main
mis	doc_491521502292_item	2656396	et	4	main
kord	doc_491521502292_item	2656400	et	4	main
1	doc_491521502293_item	2656402	et	2	main
keskaegne	doc_491521502293_item	2656403	et	3	main
2	doc_491521502293_item	2656405	et	2	main
mida	doc_491521502293_item	2656406	et	4	main
tähendab	doc_491521502293_item	2656407	et	3	main
pärisorjus	doc_491521502293_item	2656408	et	3	main
keskajal	doc_491521502293_item	2656410	et	3	main
eestimaal	doc_491521502293_item	2656411	et	4	main
tähtsamad	doc_491521502293_item	2656413	et	4	main
linnad	doc_491521502293_item	2656414	et	3	main
tallinn	doc_491521502293_item	2656415	et	4	main
tartu	doc_491521502293_item	2656416	et	4	main
narva	doc_491521502293_item	2656417	et	4	main
viljandi	doc_491521502293_item	2656418	et	4	main
pärnu	doc_491521502293_item	2656419	et	4	main
võru	doc_491521502293_item	2656420	et	4	main
pärnu	doc_491521502293_item	2656430	et	4	main
linnas	doc_491521502293_item	2656434	et	4	main
sakslased	doc_491521502293_item	2656436	et	3	main
vürtse	doc_491521502293_item	2656443	et	3	main
vina	doc_491521502293_item	2656450	et	4	main
ehitised	doc_491521502293_item	2656452	et	3	main
raehärrad	doc_491521502293_item	2656463	et	3	main
kes	doc_491521502293_item	2656464	et	4	main
tegelesid	doc_491521502293_item	2656465	et	4	main
linnaga	doc_491521502293_item	2656466	et	3	main
seotud	doc_491521502293_item	2656467	et	4	main
küsimustega	doc_491521502293_item	2656468	et	4	main
mõni	doc_491521502293_item	2656469	et	3	main
kord	doc_491521502293_item	2656470	et	4	main
täitsid	doc_491521502293_item	2656471	et	4	main
kohtufunktisoone	doc_491521502293_item	2656472	et	4	main
kirikud	doc_491521502293_item	2656473	et	3	main
olid	doc_491521502293_item	2656474	et	4	main
tähtsad	doc_491521502293_item	2656475	et	3	main
hariduskeskused	doc_491521502293_item	2656476	et	3	main
toomekirikute	doc_491521502293_item	2656477	et	4	main
juures	doc_491521502293_item	2656478	et	4	main
olid	doc_491521502293_item	2656479	et	4	main
esimesed	doc_491521502293_item	2656480	et	3	main
koolid	doc_491521502293_item	2656481	et	3	main
elasid	doc_491521502293_item	2656489	et	4	main
kes	doc_491521502293_item	2656492	et	4	main
kapiituli	doc_491521502293_item	2656494	et	4	main
võisid	doc_491521502293_item	2656496	et	4	main
olla	doc_491521502293_item	2656497	et	3	main
erinevus	doc_491521502293_item	2656503	et	4	main
oli	doc_491521502293_item	2656504	et	3	main
käsitöö	doc_491521502293_item	2656514	et	4	main
linnas	doc_491521502293_item	2656516	et	4	main
oma	doc_491521502293_item	2656522	et	4	main
sakslased	doc_491521502293_item	2656529	et	3	main
oma	doc_491521502293_item	2656539	et	4	main
ühingud	doc_491521502293_item	2656540	et	3	main
kellel	doc_491521502293_item	2656547	et	4	main
õppepoisid	doc_491521502293_item	2656551	et	4	main
kõige	doc_491521502293_item	2656553	et	4	main
eestimaa	doc_491521502293_item	2656577	et	4	main
oli	doc_491521502293_item	2656578	et	3	main
väga	doc_491521502293_item	2656579	et	3	main
kasulikus	doc_491521502293_item	2656580	et	4	main
kauplemine	doc_491521502293_item	2656585	et	4	main
soola	doc_491521502293_item	2656597	et	4	main
tubakat	doc_491521502293_item	2656598	et	3	main
ja	doc_491521502293_item	2656599	et	3	main
pernkt	doc_491521502293_item	2656606	et	4	main
tuntud	doc_491521502293_item	2656616	et	4	main
kaunistas	doc_491521502293_item	2656621	et	3	main
altareid	doc_491521502293_item	2656623	et	3	main
kroonikakirjanik	doc_491521502293_item	2656628	et	3	main
koel	doc_491521502293_item	2656637	et	3	main
a	doc_491521502293_item	2656654	et	4	main
täiesti	doc_491521502293_item	2656659	et	3	main
tegema	doc_491521502293_item	2656673	et	3	main
neil	doc_491521502293_item	2656676	et	4	main
oli	doc_491521502293_item	2656677	et	3	main
talupojale	doc_491521502293_item	2656688	et	4	main
kontrolltöö	doc_491521502294_item	2656689	et	4	main
tähendus	doc_491521502294_item	2656697	et	4	main
viikingiaeg	doc_491521502294_item	2656699	et	3	main
territooriumil	doc_491521502294_item	2656701	et	3	main
algas	doc_491521502294_item	2656702	et	3	main
lõpes	doc_491521502294_item	2656706	et	3	main
räägivad	doc_491521502294_item	2656712	et	3	main
vastanud	doc_491521502294_item	2656717	et	4	main
arheoloogid	doc_491521502294_item	2656721	et	3	main
leidnud	doc_491521502294_item	2656723	et	4	main
viikingutele	doc_491521502294_item	2656728	et	4	main
piltkive	doc_491521502294_item	2656730	et	3	main
esimene	doc_491521502294_item	2656731	et	3	main
retk	doc_491521502294_item	2656733	et	3	main
a	doc_491521502294_item	2656737	et	4	main
hukkus	doc_491521502294_item	2656751	et	3	main
ja	doc_491521502294_item	2656753	et	3	main
4	doc_491521502294_item	2656766	et	2	main
tavaliselt	doc_491521502294_item	2656769	et	4	main
vajatud	doc_491521502294_item	2656796	et	4	main
mis	doc_491521502294_item	2656811	et	4	main
ehteid	doc_491521502294_item	2656819	et	3	main
jane	doc_491521502294_item	2656821	et	4	main
pärast	doc_491521502294_item	2656822	et	4	main
oli	doc_491521502294_item	2656827	et	3	main
oma	doc_491521502294_item	2656830	et	4	main
pärit	doc_491521502294_item	2656837	et	3	main
kaubandussuhted	doc_491521502294_item	2656844	et	3	main
juba	doc_491521502294_item	2656846	et	3	main
tara	doc_491521502294_item	2656858	et	4	main
kelle	doc_491521502294_item	2656862	et	4	main
oli	doc_491521502294_item	2656864	et	3	main
oma	doc_491521502294_item	2656868	et	4	main
tähestik	doc_491521502294_item	2656869	et	3	main
kõik	doc_491521502294_item	2656875	et	4	main
täis	doc_491521502294_item	2656878	et	4	main
26	doc_491521502294_item	2656883	et	2	main
märke	doc_491521502294_item	2656884	et	4	main
nad	doc_491521502294_item	2656885	et	3	main
märke	doc_491521502294_item	2656890	et	4	main
vormidega	doc_491521502294_item	2656904	et	3	main
purskati	doc_491521502294_item	2656907	et	3	main
tuhka	doc_491521502294_item	2656910	et	4	main
peenemaid	doc_491521502293_item	2656525	et	4	main
sest	doc_491521502293_item	2656530	et	4	main
käsitööliste	doc_491521502293_item	2656532	et	4	main
käsitöölistel	doc_491521502293_item	2656537	et	4	main
paras	doc_491521502293_item	2656549	et	3	main
naine	doc_491521502293_item	2656552	et	3	main
keraamika	doc_491521502293_item	2656557	et	4	main
valmistamine	doc_491521502293_item	2656558	et	4	main
relvavalmistamine	doc_491521502293_item	2656559	et	3	main
ehtevalmistamine	doc_491521502293_item	2656560	et	3	main
pärast	doc_491521502293_item	2656561	et	4	main
kõik	doc_491521502293_item	2656562	et	4	main
muud	doc_491521502293_item	2656563	et	4	main
kaubandus	doc_491521502293_item	2656564	et	3	main
oli	doc_491521502293_item	2656565	et	3	main
täuslikult	doc_491521502293_item	2656566	et	4	main
käes	doc_491521502293_item	2656568	et	4	main
siiski	doc_491521502293_item	2656528	et	4	main
olid	doc_491521502293_item	2656538	et	4	main
käsitööline	doc_491521502293_item	2656546	et	4	main
oli	doc_491521502293_item	2656570	et	3	main
tänav	doc_491521502293_item	2656572	et	4	main
kus	doc_491521502293_item	2656573	et	3	main
elasid	doc_491521502293_item	2656574	et	4	main
kaupmehed	doc_491521502293_item	2656575	et	3	main
venemaalt	doc_491521502293_item	2656576	et	3	main
eestimaa	doc_491521502293_item	2656583	et	4	main
toimus	doc_491521502293_item	2656584	et	3	main
ja	doc_491521502293_item	2656587	et	3	main
kunstis	doc_491521502293_item	2656601	et	3	main
notke	doc_491521502293_item	2656607	et	4	main
russov	doc_491521502293_item	2656609	et	4	main
vandrat	doc_491521502293_item	2656612	et	4	main
surmatantsu	doc_491521502293_item	2656618	et	4	main
kaudu	doc_491521502293_item	2656619	et	3	main
ta	doc_491521502293_item	2656620	et	4	main
baltasar	doc_491521502293_item	2656624	et	4	main
tööd	doc_491521502293_item	2656632	et	4	main
ilmus	doc_491521502293_item	2656645	et	4	main
1535	doc_491521502293_item	2656653	et	2	main
makse	doc_491521502293_item	2656666	et	4	main
kümnendik	doc_491521502293_item	2656667	et	3	main
tööd	doc_491521502293_item	2656674	et	4	main
elukohavahetamine	doc_491521502293_item	2656679	et	3	main
maa	doc_491521502293_item	2656681	et	4	main
1050	doc_491521502294_item	2656707	et	2	main
eesti	doc_491521502294_item	2656710	et	4	main
mis	doc_491521502294_item	2656714	et	4	main
ei	doc_491521502294_item	2656722	et	4	main
selle	doc_491521502294_item	2656725	et	4	main
kohta	doc_491521502294_item	2656726	et	4	main
püstitati	doc_491521502294_item	2656729	et	4	main
viikingute	doc_491521502294_item	2656732	et	4	main
dateeritud	doc_491521502294_item	2656735	et	4	main
ingvari	doc_491521502294_item	2656738	et	4	main
eestisse	doc_491521502294_item	2656740	et	4	main
leidus	doc_491521502294_item	2656742	et	4	main
lahingus	doc_491521502294_item	2656752	et	3	main
sel	doc_491521502294_item	2656760	et	3	main
linnuseid	doc_491521502294_item	2656768	et	3	main
eestlased	doc_491521502294_item	2656798	et	3	main
kaitsesid	doc_491521502294_item	2656799	et	4	main
karju	doc_491521502294_item	2656801	et	4	main
ja	doc_491521502294_item	2656802	et	3	main
just	doc_491521502294_item	2656804	et	3	main
olid	doc_491521502294_item	2656812	et	4	main
peidetud	doc_491521502294_item	2656813	et	4	main
vaenlaste	doc_491521502294_item	2656814	et	3	main
eest	doc_491521502294_item	2656815	et	4	main
aaretes	doc_491521502294_item	2656816	et	3	main
leiuti	doc_491521502294_item	2656817	et	4	main
venemaalt	doc_491521502293_item	2656590	et	3	main
välja	doc_491521502293_item	2656592	et	4	main
toodi	doc_491521502293_item	2656596	et	4	main
tähtsamas	doc_491521502293_item	2656604	et	4	main
nimed	doc_491521502293_item	2656605	et	3	main
baltasar	doc_491521502293_item	2656608	et	4	main
oma	doc_491521502293_item	2656617	et	4	main
oli	doc_491521502293_item	2656627	et	3	main
kiriku	doc_491521502293_item	2656629	et	3	main
tema	doc_491521502293_item	2656631	et	4	main
javandrat	doc_491521502293_item	2656638	et	4	main
olid	doc_491521502293_item	2656639	et	4	main
koeli	doc_491521502293_item	2656649	et	4	main
ja	doc_491521502293_item	2656650	et	3	main
vandrati	doc_491521502293_item	2656651	et	4	main
2	doc_491521502293_item	2656655	et	2	main
talupojad	doc_491521502293_item	2656657	et	4	main
oma	doc_491521502293_item	2656668	et	4	main
tootedega	doc_491521502293_item	2656669	et	4	main
rahaga	doc_491521502293_item	2656672	et	4	main
talus	doc_491521502293_item	2656675	et	4	main
keelatud	doc_491521502293_item	2656678	et	4	main
ja	doc_491521502293_item	2656682	et	3	main
kuulusid	doc_491521502293_item	2656687	et	4	main
muinasaeg	doc_491521502294_item	2656696	et	3	main
1	doc_491521502294_item	2656698	et	2	main
eesti	doc_491521502294_item	2656700	et	4	main
800	doc_491521502294_item	2656703	et	2	main
ja	doc_491521502294_item	2656705	et	3	main
saagad	doc_491521502294_item	2656713	et	3	main
ei	doc_491521502294_item	2656716	et	4	main
tõele	doc_491521502294_item	2656718	et	4	main
see	doc_491521502293_item	2656626	et	3	main
juures	doc_491521502293_item	2656630	et	4	main
baltimaad	doc_491521502293_item	2656634	et	4	main
1573	doc_491521502293_item	2656636	et	2	main
tuntud	doc_491521502293_item	2656640	et	4	main
katekismuse	doc_491521502293_item	2656641	et	3	main
järgi	doc_491521502293_item	2656642	et	4	main
esimene	doc_491521502293_item	2656643	et	3	main
raamat	doc_491521502293_item	2656644	et	3	main
katekismus	doc_491521502293_item	2656652	et	3	main
pärisorjus	doc_491521502293_item	2656656	et	3	main
sõltuvad	doc_491521502293_item	2656660	et	4	main
mõisnikustelt	doc_491521502293_item	2656662	et	4	main
nad	doc_491521502293_item	2656663	et	3	main
pärast	doc_491521502293_item	2656670	et	4	main
talupoja	doc_491521502293_item	2656680	et	4	main
elamu	doc_491521502293_item	2656683	et	4	main
1	doc_491521502294_item	2656690	et	2	main
viikingiaeg	doc_491521502294_item	2656691	et	3	main
eesti	doc_491521502294_item	2656692	et	4	main
territooriumil	doc_491521502294_item	2656693	et	3	main
2	doc_491521502294_item	2656694	et	2	main
retkedest	doc_491521502294_item	2656709	et	3	main
territooriumile	doc_491521502294_item	2656711	et	3	main
mõnikord	doc_491521502294_item	2656715	et	3	main
teadlased	doc_491521502294_item	2656719	et	3	main
ja	doc_491521502294_item	2656720	et	3	main
hukkunutele	doc_491521502294_item	2656727	et	4	main
600	doc_491521502294_item	2656736	et	2	main
retk	doc_491521502294_item	2656739	et	3	main
mis	doc_491521502294_item	2656745	et	4	main
räägib	doc_491521502294_item	2656746	et	3	main
et	doc_491521502294_item	2656748	et	3	main
kunigas	doc_491521502294_item	2656749	et	4	main
ingvar	doc_491521502294_item	2656750	et	4	main
on	doc_491521502294_item	2656754	et	4	main
ilmuvad	doc_491521502294_item	2656764	et	4	main
kunstlikult	doc_491521502294_item	2656797	et	4	main
sellest	doc_491521502294_item	2656805	et	4	main
alustasid	doc_491521502294_item	2656807	et	4	main
edukat	doc_491521502294_item	2656823	et	3	main
leiduvad	doc_491521502294_item	2656833	et	4	main
ka	doc_491521502294_item	2656834	et	3	main
ehted	doc_491521502294_item	2656835	et	3	main
rooma	doc_491521502294_item	2656847	et	4	main
on	doc_491521502294_item	2656859	et	4	main
pärit	doc_491521502294_item	2656860	et	3	main
keele	doc_491521502294_item	2656872	et	4	main
nurgalised	doc_491521502294_item	2656887	et	4	main
on	doc_491521502294_item	2656891	et	4	main
lüüa	doc_491521502294_item	2656893	et	3	main
sisse	doc_491521502294_item	2656894	et	4	main
viikingute	doc_491521502294_item	2656895	et	4	main
mattuse	doc_491521502294_item	2656896	et	4	main
rituaal	doc_491521502294_item	2656897	et	3	main
oli	doc_491521502294_item	2656898	et	3	main
surnute	doc_491521502294_item	2656909	et	4	main
vahele	doc_491521502294_item	2656912	et	4	main
882	doc_491521502294_item	2656916	et	2	main
viikinug	doc_491521502294_item	2656918	et	4	main
tol	doc_491521502294_item	2656923	et	3	main
riirikovitš	doc_491521502294_item	2656928	et	2	main
viikingutel	doc_491521502294_item	2656939	et	4	main
nad	doc_491521502294_item	2656944	et	3	main
olid	doc_491521502294_item	2656951	et	4	main
sõudmise	doc_491521502294_item	2656958	et	4	main
olid	doc_491521502294_item	2656962	et	4	main
nahast	doc_491521502294_item	2656963	et	4	main
teravad	doc_491521502294_item	2656966	et	3	main
suvel	doc_491521502294_item	2656973	et	3	main
olid	doc_491521502294_item	2656975	et	4	main
seista	doc_491521502294_item	2656978	et	4	main
muinasaeg	doc_491521502294_item	2657018	et	3	main
oli	doc_491521502294_item	2656734	et	3	main
eestis	doc_491521502294_item	2656741	et	3	main
ka	doc_491521502294_item	2656743	et	3	main
territooriumil	doc_491521502294_item	2656759	et	3	main
eesti	doc_491521502294_item	2656762	et	4	main
tüüpi	doc_491521502294_item	2656767	et	4	main
nad	doc_491521502294_item	2656770	et	3	main
olid	doc_491521502294_item	2656771	et	4	main
ehitatud	doc_491521502294_item	2656772	et	4	main
looduslikult	doc_491521502294_item	2656773	et	4	main
kaitstud	doc_491521502294_item	2656774	et	4	main
alades	doc_491521502294_item	2656775	et	3	main
künkade	doc_491521502294_item	2656776	et	4	main
peal	doc_491521502294_item	2656777	et	4	main
linnus	doc_491521502294_item	2656778	et	4	main
otepää	doc_491521502294_item	2656779	et	4	main
kunstiliselt	doc_491521502294_item	2656780	et	4	main
ehitatud	doc_491521502294_item	2656781	et	4	main
kuivkünkad	doc_491521502294_item	2656782	et	3	main
plaatkivist	doc_491521502294_item	2656783	et	4	main
linnus	doc_491521502294_item	2656784	et	4	main
asva	doc_491521502294_item	2656785	et	4	main
saaremaal	doc_491521502294_item	2656786	et	4	main
voorete	doc_491521502294_item	2656787	et	4	main
peal	doc_491521502294_item	2656788	et	4	main
ehitatud	doc_491521502294_item	2656789	et	4	main
linnused	doc_491521502294_item	2656790	et	3	main
kus	doc_491521502294_item	2656791	et	3	main
kahel	doc_491521502294_item	2656792	et	4	main
pool	doc_491521502294_item	2656793	et	4	main
vallid	doc_491521502294_item	2656794	et	3	main
linnused	doc_491521502294_item	2656765	et	3	main
olid	doc_491521502294_item	2656795	et	4	main
oma	doc_491521502294_item	2656800	et	4	main
metallesmeid	doc_491521502294_item	2656803	et	4	main
ajast	doc_491521502294_item	2656806	et	4	main
oma	doc_491521502294_item	2656808	et	4	main
relvi	doc_491521502294_item	2656820	et	4	main
relvi	doc_491521502294_item	2656831	et	4	main
aaretes	doc_491521502294_item	2656832	et	3	main
see	doc_491521502294_item	2656838	et	3	main
eestlastel	doc_491521502294_item	2656842	et	4	main
skandinaaviaga	doc_491521502294_item	2656845	et	4	main
teadlased	doc_491521502294_item	2656852	et	3	main
arvavad	doc_491521502294_item	2656853	et	4	main
jumal	doc_491521502294_item	2656863	et	3	main
thor	doc_491521502294_item	2656865	et	4	main
tähestiku	doc_491521502294_item	2656873	et	3	main
omapärane	doc_491521502294_item	2656899	et	4	main
nad	doc_491521502294_item	2656900	et	3	main
kividest	doc_491521502294_item	2656902	et	3	main
haudu	doc_491521502294_item	2656905	et	4	main
kutsutud	doc_491521502294_item	2656920	et	4	main
ühendada	doc_491521502294_item	2656922	et	3	main
eksisteerivaid	doc_491521502294_item	2656925	et	4	main
üksusi	doc_491521502294_item	2656927	et	3	main
vallandaslinnuse	doc_491521502294_item	2656933	et	4	main
ja	doc_491521502294_item	2656934	et	3	main
oid	doc_491521502294_item	2656945	et	3	main
purjedega	doc_491521502294_item	2656948	et	3	main
tuule	doc_491521502294_item	2656956	et	3	main
rauast	doc_491521502294_item	2656967	et	4	main
sõjaretki	doc_491521502294_item	2656970	et	4	main
ainult	doc_491521502294_item	2656972	et	4	main
eestlased	doc_491521502294_item	2656974	et	3	main
vähe	doc_491521502294_item	2657017	et	3	main
inimeste	doc_491521502294_item	2657020	et	3	main
elamud	doc_491521502294_item	2657022	et	3	main
1	doc_491521502295_item	2657026	et	2	main
kultuuritegelane	doc_491521502295_item	2657029	et	3	main
kujutatud	doc_491521502295_item	2657031	et	4	main
eesti	doc_491521502295_item	2657032	et	4	main
tema	doc_491521502295_item	2657038	et	4	main
ja	doc_491521502295_item	2657063	et	3	main
keeleteadlane	doc_491521502295_item	2657070	et	3	main
mis	doc_491521502295_item	2657078	et	4	main
annuste	doc_491521502295_item	2657082	et	3	main
aleksandri	doc_491521502295_item	2657093	et	4	main
pärisorjuse	doc_491521502295_item	2657099	et	3	main
ainult	doc_491521502295_item	2657103	et	4	main
2	doc_491521502295_item	2657105	et	2	main
inimesed	doc_491521502295_item	2657107	et	3	main
oli	doc_491521502295_item	2657137	et	3	main
palju	doc_491521502295_item	2657139	et	4	main
oli	doc_491521502295_item	2657143	et	3	main
kiri	doc_491521502295_item	2657144	et	3	main
peterburgi	doc_491521502295_item	2657145	et	4	main
muud	doc_491521502295_item	2657153	et	4	main
mis	doc_491521502295_item	2657155	et	4	main
nende	doc_491521502295_item	2657156	et	4	main
ja	doc_491521502295_item	2657167	et	3	main
võimalikuks	doc_491521502296_item	2657192	et	3	main
sõda	doc_491521502296_item	2657194	et	4	main
oli	doc_491521502296_item	2657198	et	3	main
200	doc_491521502296_item	2657205	et	2	main
maal	doc_491521502296_item	2657208	et	4	main
elu	doc_491521502294_item	2656809	et	4	main
aared	doc_491521502294_item	2656810	et	4	main
münte	doc_491521502294_item	2656818	et	3	main
eestlastel	doc_491521502294_item	2656825	et	4	main
kaevata	doc_491521502294_item	2656828	et	4	main
siise	doc_491521502294_item	2656829	et	4	main
viikingute	doc_491521502294_item	2656836	et	4	main
et	doc_491521502294_item	2656841	et	3	main
tekkisid	doc_491521502294_item	2656843	et	4	main
tarapita	doc_491521502294_item	2656857	et	4	main
ladina	doc_491521502294_item	2656871	et	4	main
piltkivid	doc_491521502294_item	2656876	et	3	main
olid	doc_491521502294_item	2656877	et	4	main
märke	doc_491521502294_item	2656879	et	4	main
ruunid	doc_491521502294_item	2656880	et	3	main
tähestikus	doc_491521502294_item	2656881	et	3	main
oli	doc_491521502294_item	2656882	et	3	main
ladusid	doc_491521502294_item	2656901	et	4	main
surnuid	doc_491521502294_item	2656913	et	4	main
põletati	doc_491521502294_item	2656915	et	3	main
kolm	doc_491521502294_item	2656917	et	3	main
olid	doc_491521502294_item	2656919	et	4	main
lahingud	doc_491521502294_item	2656824	et	3	main
tavaks	doc_491521502294_item	2656826	et	3	main
räägib	doc_491521502294_item	2656839	et	3	main
sellest	doc_491521502294_item	2656840	et	4	main
rauaajal	doc_491521502294_item	2656848	et	3	main
karusnahke	doc_491521502294_item	2656850	et	3	main
vahetati	doc_491521502294_item	2656849	et	4	main
mõned	doc_491521502294_item	2656851	et	3	main
et	doc_491521502294_item	2656854	et	3	main
eestlaste	doc_491521502294_item	2656855	et	4	main
jumal	doc_491521502294_item	2656856	et	3	main
viikingutelt	doc_491521502294_item	2656861	et	4	main
viikingutel	doc_491521502294_item	2656866	et	4	main
oli	doc_491521502294_item	2656867	et	3	main
loodud	doc_491521502294_item	2656870	et	4	main
alusel	doc_491521502294_item	2656874	et	4	main
olid	doc_491521502294_item	2656886	et	4	main
sest	doc_491521502294_item	2656888	et	4	main
selliseid	doc_491521502294_item	2656889	et	4	main
kergem	doc_491521502294_item	2656892	et	4	main
ristliku	doc_491521502294_item	2656903	et	4	main
ja	doc_491521502294_item	2656906	et	3	main
oma	doc_491521502294_item	2656908	et	4	main
kivide	doc_491521502294_item	2656911	et	3	main
ajal	doc_491521502294_item	2656924	et	4	main
territoriaalseid	doc_491521502294_item	2656926	et	3	main
1030	doc_491521502294_item	2656929	et	2	main
a	doc_491521502294_item	2656930	et	4	main
tark	doc_491521502294_item	2656932	et	3	main
rajas	doc_491521502294_item	2656935	et	4	main
uue	doc_491521502294_item	2656936	et	3	main
linna	doc_491521502294_item	2656937	et	4	main
omapärased	doc_491521502294_item	2656941	et	4	main
sõiduvahendid	doc_491521502294_item	2656942	et	3	main
paadi	doc_491521502294_item	2656949	et	3	main
kilbid	doc_491521502294_item	2656953	et	3	main
laev	doc_491521502294_item	2656954	et	3	main
rõivad	doc_491521502294_item	2656961	et	3	main
tehtut	doc_491521502294_item	2656964	et	4	main
tehtud	doc_491521502294_item	2656968	et	4	main
mõõgad	doc_491521502294_item	2656969	et	3	main
lõppeb	doc_491521502294_item	2657009	et	3	main
esimese	doc_491521502294_item	2657010	et	3	main
muinasajavõitlusega	doc_491521502294_item	2657011	et	3	main
milline	doc_491521502295_item	2657027	et	3	main
peal	doc_491521502295_item	2657035	et	4	main
teate	doc_491521502295_item	2657040	et	4	main
milline	doc_491521502295_item	2657046	et	3	main
jakob	doc_491521502295_item	2657053	et	4	main
hurt	doc_491521502295_item	2657054	et	3	main
rahvavaimuvara	doc_491521502295_item	2657061	et	4	main
ajalugu	doc_491521502295_item	2657065	et	4	main
pärast	doc_491521502295_item	2657071	et	4	main
sai	doc_491521502295_item	2657073	et	4	main
liider	doc_491521502295_item	2657075	et	3	main
eksisteerima	doc_491521502295_item	2657080	et	4	main
rahva	doc_491521502295_item	2657081	et	3	main
põhjal	doc_491521502295_item	2657083	et	4	main
saama	doc_491521502295_item	2657092	et	4	main
eestimaal	doc_491521502295_item	2657098	et	4	main
jäigi	doc_491521502295_item	2657102	et	4	main
ideeks	doc_491521502295_item	2657104	et	3	main
estofiilid	doc_491521502295_item	2657106	et	3	main
kes	doc_491521502295_item	2657121	et	4	main
õppinud	doc_491521502295_item	2657123	et	4	main
peterburis	doc_491521502295_item	2657124	et	4	main
ja	doc_491521502295_item	2657126	et	3	main
pärast	doc_491521502295_item	2657127	et	4	main
jättis	doc_491521502295_item	2657128	et	3	main
eestis	doc_491521502295_item	2657132	et	3	main
selles	doc_491521502295_item	2657146	et	4	main
kirjas	doc_491521502295_item	2657147	et	4	main
olid	doc_491521502295_item	2657148	et	4	main
ja	doc_491521502295_item	2657152	et	3	main
nõudmised	doc_491521502295_item	2657154	et	4	main
vene-liivi	doc_491521502296_item	2657193	et	4	main
eestis	doc_491521502296_item	2657201	et	3	main
000	doc_491521502296_item	2657206	et	2	main
kõige	doc_491521502296_item	2657212	et	4	main
ja	doc_491521502296_item	2657230	et	3	main
tähtis	doc_491521502296_item	2657241	et	4	main
transiitlinn	doc_491521502296_item	2657242	et	3	main
kaup	doc_491521502296_item	2657243	et	3	main
viina	doc_491521502296_item	2657253	et	4	main
raud	doc_491521502296_item	2657255	et	3	main
võimu	doc_491521502296_item	2657257	et	4	main
korraldus	doc_491521502296_item	2657258	et	4	main
linnas	doc_491521502296_item	2657259	et	4	main
raat	doc_491521502296_item	2657260	et	3	main
kõrgeim	doc_491521502296_item	2657263	et	4	main
enne	doc_491521502294_item	2656914	et	4	main
jaroslav	doc_491521502294_item	2656931	et	4	main
olid	doc_491521502294_item	2656940	et	4	main
varustatud	doc_491521502294_item	2656946	et	4	main
külge	doc_491521502294_item	2656950	et	4	main
riputatud	doc_491521502294_item	2656952	et	4	main
liikus	doc_491521502294_item	2656955	et	3	main
viikingutele	doc_491521502294_item	2656979	et	4	main
muinasajaseset	doc_491521502294_item	2657012	et	4	main
religioonist	doc_491521502294_item	2657013	et	3	main
on	doc_491521502294_item	2657014	et	4	main
vaadeldab	doc_491521502294_item	2657019	et	4	main
arengut	doc_491521502294_item	2657021	et	3	main
tööriistad	doc_491521502294_item	2657023	et	3	main
10-kroonise	doc_491521502295_item	2657033	et	4	main
rahatähe	doc_491521502295_item	2657034	et	3	main
tegevusest	doc_491521502295_item	2657039	et	4	main
kultuurilukku	doc_491521502295_item	2657051	et	4	main
1	doc_491521502295_item	2657052	et	2	main
tähtis	doc_491521502295_item	2657060	et	4	main
rahva	doc_491521502295_item	2657064	et	3	main
nimega	doc_491521502295_item	2657069	et	3	main
pidi	doc_491521502295_item	2657079	et	4	main
kus	doc_491521502295_item	2657084	et	3	main
pidi	doc_491521502295_item	2657086	et	4	main
eesti	doc_491521502295_item	2657088	et	4	main
pidi	doc_491521502295_item	2657091	et	4	main
kes	doc_491521502295_item	2657096	et	4	main
kaotas	doc_491521502295_item	2657097	et	3	main
aleksandrikool	doc_491521502295_item	2657101	et	4	main
venemaale	doc_491521502294_item	2656921	et	4	main
jurjev	doc_491521502294_item	2656938	et	4	main
viikingulaevad	doc_491521502294_item	2656943	et	4	main
esimestega	doc_491521502294_item	2656947	et	3	main
ja	doc_491521502294_item	2656957	et	3	main
abil	doc_491521502294_item	2656959	et	4	main
viikingute	doc_491521502294_item	2656960	et	4	main
kiivrid	doc_491521502294_item	2656965	et	3	main
tegid	doc_491521502294_item	2656971	et	4	main
võimelised	doc_491521502294_item	2656976	et	4	main
vastu	doc_491521502294_item	2656977	et	3	main
aga	doc_491521502294_item	2656980	et	3	main
siiski	doc_491521502294_item	2656981	et	4	main
nad	doc_491521502294_item	2656982	et	3	main
nendega	doc_491521502294_item	2656984	et	4	main
kauplesid	doc_491521502294_item	2656983	et	4	main
1187	doc_491521502294_item	2656985	et	2	main
a	doc_491521502294_item	2656986	et	4	main
siguldat	doc_491521502294_item	2656987	et	4	main
hävitasid	doc_491521502294_item	2656988	et	4	main
eestlased	doc_491521502294_item	2656989	et	3	main
koos	doc_491521502294_item	2656990	et	4	main
liivlastega	doc_491521502294_item	2656991	et	4	main
2	doc_491521502294_item	2656992	et	2	main
muinasaeg	doc_491521502294_item	2656993	et	3	main
7500	doc_491521502294_item	2656994	et	2	main
ekr-1227	doc_491521502294_item	2656995	et	4	main
see	doc_491521502294_item	2656996	et	3	main
period	doc_491521502294_item	2656997	et	4	main
vaadeldab	doc_491521502294_item	2656998	et	4	main
eestimaa	doc_491521502294_item	2656999	et	4	main
ajalugu	doc_491521502294_item	2657000	et	4	main
mis	doc_491521502294_item	2657001	et	4	main
on	doc_491521502294_item	2657002	et	4	main
teostatut	doc_491521502294_item	2657003	et	4	main
ainult	doc_491521502294_item	2657004	et	4	main
arheoloogiliste	doc_491521502294_item	2657005	et	4	main
leiutiste	doc_491521502294_item	2657006	et	3	main
järgi	doc_491521502294_item	2657007	et	4	main
muinasaeg	doc_491521502294_item	2657008	et	3	main
teada	doc_491521502294_item	2657015	et	3	main
väga	doc_491521502294_item	2657016	et	3	main
kontrolltöö	doc_491521502295_item	2657025	et	4	main
ärkamisaja	doc_491521502295_item	2657028	et	3	main
on	doc_491521502295_item	2657030	et	4	main
kes	doc_491521502295_item	2657042	et	4	main
olid	doc_491521502295_item	2657043	et	4	main
oli	doc_491521502295_item	2657047	et	3	main
nende	doc_491521502295_item	2657048	et	4	main
panus	doc_491521502295_item	2657049	et	4	main
eesti	doc_491521502295_item	2657050	et	4	main
on	doc_491521502295_item	2657059	et	4	main
ta	doc_491521502295_item	2657066	et	4	main
suure	doc_491521502295_item	2657068	et	3	main
temast	doc_491521502295_item	2657072	et	3	main
toimuma	doc_491521502295_item	2657087	et	3	main
keeles	doc_491521502295_item	2657089	et	4	main
aleksandrinimetuse	doc_491521502295_item	2657090	et	4	main
1816-1919	doc_491521502295_item	2657100	et	2	main
isikuid	doc_491521502295_item	2657134	et	4	main
tegutsevaid	doc_491521502295_item	2657135	et	4	main
päris	doc_491521502295_item	2657138	et	4	main
nende	doc_491521502295_item	2657140	et	4	main
suurim	doc_491521502295_item	2657141	et	3	main
pannus	doc_491521502295_item	2657142	et	4	main
kirjutatud	doc_491521502295_item	2657149	et	4	main
kõik	doc_491521502295_item	2657150	et	4	main
pidid	doc_491521502295_item	2657158	et	4	main
võimu	doc_491521502295_item	2657161	et	4	main
usundivabadus	doc_491521502295_item	2657166	et	4	main
ue	doc_491521502295_item	2657168	et	4	main
abiga	doc_491521502295_item	2657170	et	3	main
linnakultuur	doc_491521502296_item	2657196	et	3	main
kui	doc_491521502296_item	2657209	et	3	main
000	doc_491521502296_item	2657222	et	2	main
linnadeks	doc_491521502296_item	2657227	et	3	main
mis	doc_491521502296_item	2657244	et	4	main
viidi	doc_491521502296_item	2657245	et	4	main
kala	doc_491521502296_item	2657248	et	4	main
kangad	doc_491521502296_item	2657254	et	3	main
heringas	doc_491521502296_item	2657256	et	4	main
e	doc_491521502296_item	2657261	et	4	main
24	doc_491521502296_item	2657265	et	2	main
ja	doc_491521502296_item	2657267	et	3	main
valiti	doc_491521502296_item	2657269	et	3	main
oli	doc_491521502296_item	2657278	et	3	main
piiskopi	doc_491521502296_item	2657293	et	4	main
toomkoolid	doc_491521502296_item	2657297	et	3	main
võitlema	doc_491521502296_item	2657304	et	3	main
et	doc_491521502296_item	2657308	et	3	main
tuleb	doc_491521502296_item	2657310	et	3	main
toomkirik	doc_491521502296_item	2657329	et	3	main
hästi	doc_491521502296_item	2657333	et	3	main
pidid	doc_491521502296_item	2657335	et	4	main
kuuluma	doc_491521502296_item	2657336	et	3	main
käsitööliste	doc_491521502296_item	2657339	et	4	main
tööga	doc_491521502296_item	2657347	et	3	main
teisest	doc_491521502296_item	2657349	et	4	main
miks	doc_491521502296_item	2657354	et	4	main
oli	doc_491521502296_item	2657360	et	3	main
hea	doc_491521502296_item	2657362	et	4	main
läänemerele	doc_491521502296_item	2657368	et	3	main
e	doc_491521502296_item	2657369	et	4	main
toimus	doc_491521502296_item	2657375	et	3	main
ivo	doc_491521502296_item	2657387	et	4	main
schenkenberg	doc_491521502296_item	2657388	et	4	main
oli	doc_491521502296_item	2657389	et	3	main
tegi	doc_491521502296_item	2657422	et	4	main
eestimaa	doc_491521502296_item	2657432	et	4	main
territoorium	doc_491521502296_item	2657433	et	3	main
keskpaik	doc_491521502296_item	2657439	et	3	main
vallutas	doc_491521502296_item	2657441	et	3	main
mõne	doc_491521502296_item	2657444	et	3	main
ala	doc_491521502296_item	2657450	et	4	main
jäi	doc_491521502296_item	2657451	et	3	main
rootsi	doc_491521502296_item	2657452	et	4	main
kontrolltöö	doc_491521502297_item	2657457	et	4	main
soodustas	doc_491521502297_item	2657460	et	3	main
tõi	doc_491521502297_item	2657489	et	3	main
usu	doc_491521502297_item	2657493	et	4	main
ristimisega	doc_491521502297_item	2657495	et	4	main
matmiskombed	doc_491521502294_item	2657024	et	3	main
mida	doc_491521502295_item	2657036	et	4	main
te	doc_491521502295_item	2657037	et	4	main
2	doc_491521502295_item	2657041	et	2	main
estofiilid	doc_491521502295_item	2657044	et	3	main
ja	doc_491521502295_item	2657045	et	3	main
1839-1907	doc_491521502295_item	2657055	et	2	main
arvas	doc_491521502295_item	2657056	et	3	main
et	doc_491521502295_item	2657057	et	3	main
rahvale	doc_491521502295_item	2657058	et	3	main
rahvaluule	doc_491521502295_item	2657062	et	4	main
oli	doc_491521502295_item	2657067	et	3	main
aleksandrikooli	doc_491521502295_item	2657074	et	4	main
aleksandrikool	doc_491521502295_item	2657076	et	4	main
õppeasutus	doc_491521502295_item	2657077	et	4	main
õppimisprotsess	doc_491521502295_item	2657085	et	3	main
i	doc_491521502295_item	2657094	et	4	main
puhul	doc_491521502295_item	2657095	et	4	main
kes	doc_491521502295_item	2657108	et	4	main
olid	doc_491521502295_item	2657109	et	4	main
seotud	doc_491521502295_item	2657110	et	4	main
eestiga	doc_491521502295_item	2657111	et	4	main
aga	doc_491521502295_item	2657112	et	3	main
polnud	doc_491521502295_item	2657113	et	3	main
pärit	doc_491521502295_item	2657114	et	3	main
eestimaalt	doc_491521502295_item	2657115	et	3	main
üks	doc_491521502295_item	2657116	et	3	main
sellistest	doc_491521502295_item	2657117	et	4	main
nimedest	doc_491521502295_item	2657118	et	3	main
on	doc_491521502295_item	2657119	et	4	main
köler	doc_491521502295_item	2657120	et	4	main
oma	doc_491521502295_item	2657129	et	4	main
sellised	doc_491521502295_item	2657133	et	4	main
lootes	doc_491521502295_item	2657157	et	4	main
väljaostmisõigused	doc_491521502295_item	2657165	et	4	main
köleri	doc_491521502295_item	2657169	et	4	main
keskaeg	doc_491521502296_item	2657197	et	3	main
saj	doc_491521502296_item	2657200	et	4	main
arv	doc_491521502296_item	2657203	et	3	main
oli	doc_491521502296_item	2657204	et	3	main
linnas	doc_491521502296_item	2657211	et	4	main
suuremad	doc_491521502296_item	2657213	et	4	main
linnad	doc_491521502296_item	2657214	et	3	main
olid	doc_491521502296_item	2657215	et	4	main
6-8	doc_491521502296_item	2657221	et	2	main
igas	doc_491521502296_item	2657224	et	3	main
suuruseks	doc_491521502296_item	2657226	et	4	main
viljandi	doc_491521502296_item	2657231	et	4	main
need	doc_491521502296_item	2657233	et	3	main
välja	doc_491521502296_item	2657246	et	4	main
rasva	doc_491521502296_item	2657249	et	4	main
sisse	doc_491521502296_item	2657251	et	4	main
soola	doc_491521502296_item	2657252	et	4	main
teine	doc_491521502296_item	2657276	et	3	main
kirik	doc_491521502296_item	2657280	et	3	main
suur	doc_491521502296_item	2657283	et	3	main
kirik	doc_491521502296_item	2657285	et	3	main
piiskop	doc_491521502296_item	2657286	et	3	main
vaimulikud	doc_491521502296_item	2657287	et	3	main
ja	doc_491521502296_item	2657298	et	3	main
14	doc_491521502296_item	2657301	et	2	main
saj	doc_491521502296_item	2657302	et	4	main
hakatakse	doc_491521502296_item	2657303	et	3	main
eest	doc_491521502296_item	2657307	et	4	main
oli	doc_491521502295_item	2657122	et	3	main
maalikunsti	doc_491521502295_item	2657125	et	4	main
kunsti	doc_491521502295_item	2657130	et	4	main
jälje	doc_491521502295_item	2657131	et	3	main
eestimaal	doc_491521502295_item	2657136	et	4	main
majanduslikud	doc_491521502295_item	2657151	et	3	main
releerima	doc_491521502295_item	2657159	et	4	main
sakslaste	doc_491521502295_item	2657160	et	3	main
nõudmised	doc_491521502295_item	2657162	et	4	main
olid	doc_491521502295_item	2657163	et	4	main
maapindade	doc_491521502295_item	2657164	et	3	main
kiri	doc_491521502295_item	2657171	et	3	main
jõudis	doc_491521502295_item	2657172	et	3	main
aga	doc_491521502295_item	2657174	et	3	main
elus	doc_491521502295_item	2657175	et	4	main
peterburgi	doc_491521502295_item	2657173	et	4	main
midagi	doc_491521502295_item	2657176	et	4	main
ei	doc_491521502295_item	2657177	et	4	main
eestis	doc_491521502295_item	2657179	et	3	main
muutunud	doc_491521502295_item	2657178	et	4	main
tegutsesid	doc_491521502295_item	2657180	et	4	main
õppejõud	doc_491521502295_item	2657181	et	4	main
välismaalt	doc_491521502295_item	2657182	et	3	main
1	doc_491521502296_item	2657184	et	2	main
missugune	doc_491521502296_item	2657185	et	3	main
oli	doc_491521502296_item	2657186	et	3	main
keskaegne	doc_491521502296_item	2657187	et	3	main
kontrolltöö	doc_491521502296_item	2657183	et	4	main
linnakultuur	doc_491521502296_item	2657188	et	3	main
2	doc_491521502296_item	2657189	et	2	main
miks	doc_491521502296_item	2657190	et	4	main
sa	doc_491521502296_item	2657191	et	3	main
keskaegne	doc_491521502296_item	2657195	et	3	main
13-16	doc_491521502296_item	2657199	et	2	main
elanike	doc_491521502296_item	2657202	et	3	main
nii	doc_491521502296_item	2657207	et	3	main
ka	doc_491521502296_item	2657210	et	3	main
tartu	doc_491521502296_item	2657216	et	4	main
ja	doc_491521502296_item	2657217	et	3	main
tallinn	doc_491521502296_item	2657218	et	4	main
kus	doc_491521502296_item	2657219	et	3	main
elas	doc_491521502296_item	2657220	et	3	main
keskmise	doc_491521502296_item	2657225	et	3	main
olid	doc_491521502296_item	2657228	et	4	main
pärnu	doc_491521502296_item	2657229	et	4	main
kõik	doc_491521502296_item	2657232	et	4	main
kuulusid	doc_491521502296_item	2657234	et	4	main
hansaliitu	doc_491521502296_item	2657235	et	4	main
kaubanduslik	doc_491521502296_item	2657236	et	3	main
tallinn	doc_491521502296_item	2657238	et	4	main
oli	doc_491521502296_item	2657239	et	3	main
väga	doc_491521502296_item	2657240	et	3	main
lina	doc_491521502296_item	2657250	et	4	main
magitraat	doc_491521502296_item	2657262	et	4	main
valituseüksus	doc_491521502296_item	2657264	et	4	main
inimest	doc_491521502296_item	2657266	et	3	main
neid	doc_491521502296_item	2657268	et	4	main
aastaks	doc_491521502296_item	2657271	et	4	main
maahärrad	doc_491521502296_item	2657272	et	3	main
linnaosakonnad	doc_491521502296_item	2657273	et	4	main
gildid	doc_491521502296_item	2657274	et	3	main
osatähtsus	doc_491521502296_item	2657284	et	4	main
kes	doc_491521502296_item	2657288	et	4	main
teostas	doc_491521502296_item	2657292	et	3	main
visitatsioonid	doc_491521502296_item	2657295	et	3	main
linna	doc_491521502296_item	2657299	et	4	main
ka	doc_491521502296_item	2657305	et	3	main
haridust	doc_491521502296_item	2657309	et	4	main
arstiabi	doc_491521502296_item	2657321	et	4	main
rajati	doc_491521502296_item	2657323	et	3	main
oleviste	doc_491521502296_item	2657325	et	4	main
elasid	doc_491521502296_item	2657331	et	4	main
suhteliselt	doc_491521502296_item	2657332	et	4	main
nad	doc_491521502296_item	2657334	et	3	main
eestlased	doc_491521502296_item	2657341	et	3	main
peamiselt	doc_491521502296_item	2657343	et	4	main
käsitööga	doc_491521502296_item	2657344	et	3	main
kuid	doc_491521502296_item	2657345	et	4	main
tegelesid	doc_491521502296_item	2657348	et	4	main
2	doc_491521502296_item	2657353	et	2	main
võimalikuks	doc_491521502296_item	2657356	et	3	main
vene-liivi	doc_491521502296_item	2657357	et	4	main
transiitmaa	doc_491521502296_item	2657371	et	4	main
euroopaga	doc_491521502296_item	2657372	et	3	main
a	doc_491521502296_item	2657386	et	4	main
venemaale	doc_491521502296_item	2657391	et	4	main
selleks	doc_491521502296_item	2657395	et	4	main
saada	doc_491521502296_item	2657397	et	4	main
väljapääsu	doc_491521502296_item	2657398	et	4	main
balti	doc_491521502296_item	2657399	et	3	main
riigile	doc_491521502296_item	2657400	et	3	main
ja	doc_491521502296_item	2657401	et	3	main
sammud	doc_491521502296_item	2657424	et	4	main
eestimaa	doc_491521502296_item	2657425	et	4	main
17	doc_491521502296_item	2657437	et	2	main
aja	doc_491521502296_item	2657445	et	4	main
pärast	doc_491521502296_item	2657446	et	4	main
lepinguga	doc_491521502296_item	2657447	et	3	main
kätte	doc_491521502296_item	2657453	et	4	main
algas	doc_491521502296_item	2657454	et	3	main
1	doc_491521502297_item	2657458	et	2	main
muinasusundi	doc_491521502297_item	2657461	et	3	main
endaga	doc_491521502297_item	2657490	et	4	main
kaasa	doc_491521502297_item	2657491	et	4	main
tekkimist	doc_491521502297_item	2657494	et	4	main
kaasa	doc_491521502297_item	2657504	et	4	main
ka	doc_491521502297_item	2657505	et	3	main
kuid	doc_491521502297_item	2657511	et	4	main
ja	doc_491521502297_item	2657514	et	3	main
kombeid	doc_491521502297_item	2657516	et	4	main
püsima	doc_491521502297_item	2657518	et	3	main
liit	doc_491521502296_item	2657237	et	3	main
inimest	doc_491521502296_item	2657223	et	3	main
teravili	doc_491521502296_item	2657247	et	3	main
võim	doc_491521502296_item	2657277	et	3	main
oli	doc_491521502296_item	2657282	et	3	main
pidasid	doc_491521502296_item	2657289	et	4	main
kohtn	doc_491521502296_item	2657290	et	4	main
kirik	doc_491521502296_item	2657291	et	3	main
korraldusel	doc_491521502296_item	2657294	et	4	main
koolid	doc_491521502296_item	2657300	et	3	main
selle	doc_491521502296_item	2657306	et	4	main
saama	doc_491521502296_item	2657311	et	4	main
kõigile	doc_491521502296_item	2657312	et	4	main
esimesed	doc_491521502296_item	2657313	et	3	main
rändmungad	doc_491521502296_item	2657314	et	3	main
maaelanikele	doc_491521502296_item	2657318	et	3	main
arstina	doc_491521502296_item	2657319	et	3	main
andsid	doc_491521502296_item	2657320	et	4	main
linnaelanikud	doc_491521502296_item	2657330	et	3	main
meistrid	doc_491521502296_item	2657352	et	3	main
sai	doc_491521502296_item	2657355	et	4	main
eesti	doc_491521502296_item	2657359	et	4	main
väga	doc_491521502296_item	2657361	et	3	main
maa	doc_491521502296_item	2657363	et	4	main
1558	doc_491521502296_item	2657373	et	2	main
a	doc_491521502296_item	2657374	et	4	main
sõda	doc_491521502296_item	2657377	et	4	main
saj	doc_491521502296_item	2657379	et	4	main
troonike	doc_491521502296_item	2657381	et	4	main
eestimaal	doc_491521502296_item	2657390	et	4	main
oli	doc_491521502296_item	2657404	et	3	main
heaks	doc_491521502296_item	2657405	et	4	main
üheks	doc_491521502296_item	2657270	et	3	main
tsunftid	doc_491521502296_item	2657275	et	3	main
kindlasti	doc_491521502296_item	2657279	et	3	main
millel	doc_491521502296_item	2657281	et	3	main
haridus	doc_491521502296_item	2657296	et	3	main
eks	doc_491521502296_item	2657315	et	3	main
olid	doc_491521502296_item	2657316	et	4	main
ka	doc_491521502296_item	2657317	et	3	main
mingi	doc_491521502296_item	2657337	et	4	main
peenemate	doc_491521502296_item	2657346	et	4	main
riikidest	doc_491521502296_item	2657351	et	3	main
sõda	doc_491521502296_item	2657358	et	4	main
hea	doc_491521502296_item	2657370	et	4	main
liivi	doc_491521502296_item	2657376	et	4	main
16	doc_491521502296_item	2657378	et	2	main
ivan	doc_491521502296_item	2657383	et	4	main
iv	doc_491521502296_item	2657384	et	4	main
1573	doc_491521502296_item	2657385	et	2	main
vajalik	doc_491521502296_item	2657393	et	3	main
euroopasse	doc_491521502296_item	2657402	et	3	main
transiidimaaks	doc_491521502296_item	2657406	et	3	main
ja	doc_491521502296_item	2657427	et	3	main
jäi	doc_491521502296_item	2657435	et	3	main
rootsi	doc_491521502296_item	2657440	et	4	main
tartu	doc_491521502296_item	2657442	et	4	main
ja	doc_491521502296_item	2657443	et	3	main
aeg	doc_491521502296_item	2657456	et	3	main
mis	doc_491521502297_item	2657459	et	4	main
säilimist	doc_491521502297_item	2657462	et	4	main
eestlaste	doc_491521502297_item	2657463	et	4	main
juures	doc_491521502297_item	2657464	et	4	main
2	doc_491521502297_item	2657465	et	2	main
uue	doc_491521502297_item	2657492	et	3	main
sellega	doc_491521502297_item	2657502	et	3	main
käis	doc_491521502297_item	2657503	et	4	main
rajamine	doc_491521502297_item	2657507	et	4	main
ja	doc_491521502297_item	2657508	et	3	main
kirjaoskuse	doc_491521502297_item	2657509	et	3	main
pühakultused	doc_491521502297_item	2657523	et	3	main
sobitatud	doc_491521502297_item	2657527	et	4	main
olid	doc_491521502297_item	2657532	et	4	main
samastati	doc_491521502297_item	2657540	et	3	main
üks	doc_491521502297_item	2657544	et	3	main
kaua	doc_491521502297_item	2657549	et	3	main
põhjuseks	doc_491521502297_item	2657554	et	3	main
sajandist	doc_491521502297_item	2657570	et	3	main
kuid	doc_491521502297_item	2657576	et	4	main
vaatamata	doc_491521502297_item	2657577	et	4	main
tavapäradega	doc_491521502297_item	2657584	et	3	main
õnnistati	doc_491521502297_item	2657595	et	4	main
kõike	doc_491521502297_item	2657596	et	4	main
ära	doc_491521502297_item	2657621	et	4	main
oli	doc_491521502297_item	2657623	et	3	main
keelatud	doc_491521502297_item	2657624	et	4	main
mitme	doc_491521502297_item	2657625	et	4	main
naise	doc_491521502297_item	2657626	et	3	main
matmine	doc_491521502297_item	2657629	et	4	main
see	doc_491521502297_item	2657632	et	3	main
2	doc_491521502297_item	2657646	et	2	main
lübeck	doc_491521502297_item	2657650	et	4	main
mõne	doc_491521502297_item	2657653	et	3	main
olid	doc_491521502297_item	2657663	et	4	main
saksamaa	doc_491521502297_item	2657665	et	4	main
madalmaad	doc_491521502297_item	2657666	et	4	main
olid	doc_491521502297_item	2657674	et	4	main
viljandi	doc_491521502297_item	2657681	et	4	main
venemaa	doc_491521502297_item	2657682	et	4	main
hansaliidu	doc_491521502297_item	2657683	et	3	main
keskpunkt	doc_491521502297_item	2657684	et	3	main
oli	doc_491521502297_item	2657685	et	3	main
missugune	doc_491521502298_item	2657714	et	3	main
keskaegne	doc_491521502298_item	2657716	et	3	main
miks	doc_491521502298_item	2657719	et	4	main
vene-liivi	doc_491521502298_item	2657722	et	4	main
aastal	doc_491521502298_item	2657725	et	3	main
sai	doc_491521502298_item	2657727	et	4	main
tallinn	doc_491521502298_item	2657728	et	4	main
ajast	doc_491521502298_item	2657733	et	4	main
keskaegses	doc_491521502298_item	2657738	et	3	main
keskaegne	doc_491521502298_item	2657740	et	3	main
võib	doc_491521502298_item	2657747	et	3	main
tallinnas	doc_491521502296_item	2657322	et	4	main
kirikud	doc_491521502296_item	2657324	et	3	main
kirik	doc_491521502296_item	2657326	et	3	main
pühavaimu	doc_491521502296_item	2657327	et	4	main
kirik	doc_491521502296_item	2657328	et	3	main
gildisse	doc_491521502296_item	2657338	et	3	main
liit	doc_491521502296_item	2657340	et	3	main
tegelesid	doc_491521502296_item	2657342	et	4	main
euroopa	doc_491521502296_item	2657350	et	4	main
sest	doc_491521502296_item	2657364	et	4	main
see	doc_491521502296_item	2657365	et	3	main
oli	doc_491521502296_item	2657366	et	3	main
väljapääs	doc_491521502296_item	2657367	et	3	main
keskpaik	doc_491521502296_item	2657380	et	3	main
pääseb	doc_491521502296_item	2657382	et	3	main
oli	doc_491521502296_item	2657392	et	3	main
eesti	doc_491521502296_item	2657394	et	4	main
et	doc_491521502296_item	2657396	et	3	main
eesti	doc_491521502296_item	2657403	et	4	main
kauplemise	doc_491521502296_item	2657407	et	4	main
jaoks	doc_491521502296_item	2657408	et	4	main
1578a	doc_491521502296_item	2657409	et	4	main
pommitati	doc_491521502296_item	2657410	et	4	main
pirita	doc_491521502296_item	2657411	et	4	main
klooster	doc_491521502296_item	2657412	et	3	main
eesti	doc_491521502296_item	2657413	et	4	main
pärast	doc_491521502296_item	2657414	et	4	main
võitlesid	doc_491521502296_item	2657415	et	4	main
mitmed	doc_491521502296_item	2657416	et	4	main
riigid	doc_491521502296_item	2657417	et	3	main
venemaa	doc_491521502296_item	2657418	et	4	main
poola	doc_491521502296_item	2657419	et	4	main
rootsi	doc_491521502296_item	2657420	et	4	main
venemaa	doc_491521502296_item	2657421	et	4	main
talle	doc_491521502296_item	2657428	et	4	main
jäigi	doc_491521502296_item	2657429	et	4	main
alguses	doc_491521502296_item	2657430	et	4	main
peamine	doc_491521502296_item	2657431	et	3	main
saj	doc_491521502296_item	2657438	et	4	main
eesti	doc_491521502296_item	2657449	et	4	main
paljud	doc_491521502297_item	2657522	et	3	main
traditsioonidega	doc_491521502297_item	2657529	et	3	main
teiseks	doc_491521502297_item	2657552	et	4	main
veenvaks	doc_491521502297_item	2657553	et	4	main
see	doc_491521502297_item	2657557	et	3	main
ainult	doc_491521502297_item	2657567	et	4	main
alates	doc_491521502297_item	2657568	et	3	main
eestlastel	doc_491521502297_item	2657572	et	4	main
samastasid	doc_491521502297_item	2657581	et	4	main
ka	doc_491521502297_item	2657587	et	3	main
paljud	doc_491521502297_item	2657588	et	3	main
väga	doc_491521502297_item	2657592	et	3	main
on	doc_491521502297_item	2657600	et	4	main
näiteks	doc_491521502297_item	2657622	et	4	main
surnute	doc_491521502297_item	2657628	et	4	main
kirikukalmistutel	doc_491521502297_item	2657631	et	3	main
ei	doc_491521502297_item	2657633	et	4	main
ka	doc_491521502297_item	2657636	et	3	main
see	doc_491521502297_item	2657637	et	3	main
ja	doc_491521502297_item	2657644	et	3	main
mis	doc_491521502297_item	2657651	et	4	main
liivimaal	doc_491521502297_item	2657669	et	4	main
novgorad	doc_491521502297_item	2657686	et	4	main
hansaliit	doc_491521502297_item	2657687	et	3	main
oli	doc_491521502297_item	2657688	et	3	main
eestlaste	doc_491521502297_item	2657689	et	4	main
kasulik	doc_491521502297_item	2657690	et	3	main
esimesed	doc_491521502296_item	2657423	et	3	main
vallutamiseks	doc_491521502296_item	2657426	et	4	main
lõuna-eesti	doc_491521502296_item	2657434	et	4	main
poolale	doc_491521502296_item	2657436	et	4	main
kõik	doc_491521502296_item	2657448	et	4	main
rootsi	doc_491521502296_item	2657455	et	4	main
mis	doc_491521502297_item	2657466	et	4	main
oli	doc_491521502297_item	2657467	et	3	main
hansa	doc_491521502297_item	2657468	et	4	main
liit	doc_491521502297_item	2657469	et	3	main
1	doc_491521502297_item	2657470	et	2	main
ristisõda	doc_491521502297_item	2657471	et	4	main
oli	doc_491521502297_item	2657472	et	3	main
ka	doc_491521502297_item	2657473	et	3	main
sõda	doc_491521502297_item	2657474	et	4	main
uue	doc_491521502297_item	2657475	et	3	main
ja	doc_491521502297_item	2657476	et	3	main
vana	doc_491521502297_item	2657477	et	4	main
vahel	doc_491521502297_item	2657478	et	4	main
enne	doc_491521502297_item	2657479	et	4	main
12	doc_491521502297_item	2657480	et	2	main
saj	doc_491521502297_item	2657481	et	4	main
eesti	doc_491521502297_item	2657482	et	4	main
territooriumil	doc_491521502297_item	2657483	et	3	main
elas	doc_491521502297_item	2657484	et	3	main
paganlik	doc_491521502297_item	2657485	et	3	main
rahvas	doc_491521502297_item	2657486	et	4	main
ja	doc_491521502297_item	2657487	et	3	main
ristisõda	doc_491521502297_item	2657488	et	4	main
koos	doc_491521502297_item	2657496	et	4	main
koolide	doc_491521502297_item	2657506	et	3	main
enamik	doc_491521502297_item	2657512	et	3	main
paganlike	doc_491521502297_item	2657515	et	3	main
kuni	doc_491521502297_item	2657519	et	3	main
paganate	doc_491521502297_item	2657528	et	3	main
paljud	doc_491521502297_item	2657530	et	3	main
rituaale	doc_491521502297_item	2657539	et	3	main
maagiaga	doc_491521502297_item	2657541	et	3	main
oligi	doc_491521502297_item	2657543	et	3	main
põhjustest	doc_491521502297_item	2657545	et	3	main
muinasusud	doc_491521502297_item	2657547	et	3	main
eestlaste	doc_491521502297_item	2657550	et	4	main
juures	doc_491521502297_item	2657551	et	4	main
oli	doc_491521502297_item	2657555	et	3	main
et	doc_491521502297_item	2657558	et	3	main
algusest	doc_491521502297_item	2657560	et	4	main
olnud	doc_491521502297_item	2657562	et	4	main
läbiviidud	doc_491521502297_item	2657563	et	4	main
rahvakeeles	doc_491521502297_item	2657564	et	4	main
vaid	doc_491521502297_item	2657565	et	3	main
ladinakeeles	doc_491521502297_item	2657566	et	4	main
on	doc_491521502297_item	2657571	et	4	main
pihtida	doc_491521502297_item	2657574	et	3	main
oma	doc_491521502297_item	2657583	et	4	main
olid	doc_491521502297_item	2657585	et	4	main
veel	doc_491521502297_item	2657597	et	4	main
üks	doc_491521502297_item	2657598	et	3	main
põhjustest	doc_491521502297_item	2657599	et	3	main
toimus	doc_491521502297_item	2657630	et	3	main
keelati	doc_491521502297_item	2657639	et	4	main
1143	doc_491521502297_item	2657647	et	2	main
sa	doc_491521502297_item	2657652	et	3	main
venemaa	doc_491521502297_item	2657668	et	4	main
hansaliitu	doc_491521502297_item	2657673	et	4	main
tallinn	doc_491521502297_item	2657676	et	4	main
uus	doc_491521502297_item	2657678	et	3	main
ja	doc_491521502297_item	2657680	et	3	main
siis	doc_491521502297_item	2657692	et	3	main
välja	doc_491521502297_item	2657706	et	4	main
lina	doc_491521502297_item	2657709	et	4	main
kanepit	doc_491521502297_item	2657711	et	3	main
endale	doc_491521502298_item	2657729	et	4	main
lübecki	doc_491521502298_item	2657730	et	4	main
linnaõiguse	doc_491521502298_item	2657731	et	4	main
rääkida	doc_491521502298_item	2657736	et	3	main
mitmepalgeline	doc_491521502298_item	2657744	et	4	main
kaubandust	doc_491521502298_item	2657749	et	3	main
meresõitude	doc_491521502298_item	2657757	et	3	main
tööga	doc_491521502298_item	2657790	et	3	main
liivlased	doc_491521502298_item	2657794	et	3	main
hakkasid	doc_491521502297_item	2657497	et	4	main
tekkima	doc_491521502297_item	2657498	et	3	main
kirikud	doc_491521502297_item	2657499	et	3	main
ja	doc_491521502297_item	2657500	et	3	main
kloostrid	doc_491521502297_item	2657501	et	3	main
levitamine	doc_491521502297_item	2657510	et	4	main
tavasid	doc_491521502297_item	2657513	et	3	main
jäi	doc_491521502297_item	2657517	et	3	main
17-18	doc_491521502297_item	2657520	et	2	main
sajandini	doc_491521502297_item	2657521	et	3	main
olid	doc_491521502297_item	2657524	et	4	main
ja	doc_491521502297_item	2657526	et	3	main
kultused	doc_491521502297_item	2657531	et	3	main
tehtud	doc_491521502297_item	2657533	et	4	main
samas	doc_491521502297_item	2657536	et	4	main
see	doc_491521502297_item	2657542	et	3	main
kirikuteenistus	doc_491521502297_item	2657559	et	3	main
ei	doc_491521502297_item	2657561	et	4	main
sellele	doc_491521502297_item	2657578	et	4	main
et	doc_491521502297_item	2657579	et	3	main
eestlased	doc_491521502297_item	2657580	et	3	main
võetud	doc_491521502297_item	2657586	et	4	main
kombed	doc_491521502297_item	2657589	et	3	main
populaarne	doc_491521502297_item	2657593	et	3	main
veel	doc_491521502297_item	2657601	et	4	main
see	doc_491521502297_item	2657602	et	3	main
et	doc_491521502297_item	2657603	et	3	main
pidamine	doc_491521502297_item	2657627	et	4	main
et	doc_491521502297_item	2657638	et	3	main
oli	doc_491521502297_item	2657641	et	3	main
uus	doc_491521502297_item	2657643	et	3	main
tundmatu	doc_491521502297_item	2657645	et	4	main
rajati	doc_491521502297_item	2657649	et	3	main
maad	doc_491521502297_item	2657670	et	4	main
mis	doc_491521502297_item	2657671	et	4	main
riia	doc_491521502297_item	2657675	et	4	main
pärnu	doc_491521502297_item	2657679	et	4	main
toodi	doc_491521502297_item	2657693	et	4	main
soola	doc_491521502297_item	2657695	et	4	main
kallist	doc_491521502297_item	2657696	et	4	main
riiet	doc_491521502297_item	2657697	et	3	main
heeringat	doc_491521502297_item	2657698	et	3	main
vürtse	doc_491521502297_item	2657699	et	3	main
humalat	doc_491521502297_item	2657700	et	3	main
ja	doc_491521502297_item	2657701	et	3	main
veine	doc_491521502297_item	2657702	et	3	main
eestlased	doc_491521502297_item	2657703	et	3	main
aga	doc_491521502297_item	2657704	et	3	main
viisid	doc_491521502297_item	2657705	et	4	main
karusnahka	doc_491521502297_item	2657708	et	4	main
oli	doc_491521502298_item	2657715	et	3	main
linnakultuur	doc_491521502298_item	2657717	et	3	main
sõda	doc_491521502298_item	2657723	et	4	main
1248	doc_491521502298_item	2657726	et	2	main
ametlikult	doc_491521502298_item	2657735	et	4	main
eestis	doc_491521502298_item	2657739	et	3	main
linnakultuur	doc_491521502298_item	2657741	et	3	main
paigutada	doc_491521502298_item	2657748	et	3	main
vaimuelu	doc_491521502298_item	2657750	et	4	main
aastatel	doc_491521502298_item	2657752	et	4	main
õiguse	doc_491521502298_item	2657758	et	4	main
endale	doc_491521502298_item	2657759	et	4	main
lõplikult	doc_491521502298_item	2657760	et	4	main
linn	doc_491521502298_item	2657761	et	3	main
eeskätt	doc_491521502298_item	2657772	et	3	main
st	doc_491521502298_item	2657782	et	3	main
tegelesid	doc_491521502298_item	2657786	et	4	main
ja	doc_491521502298_item	2657788	et	3	main
puhtama	doc_491521502298_item	2657789	et	4	main
väike	doc_491521502298_item	2657826	et	4	main
kaupmehed	doc_491521502298_item	2657827	et	3	main
neid	doc_491521502298_item	2657828	et	4	main
soost	doc_491521502298_item	2657834	et	4	main
karusnahka	doc_491521502298_item	2657841	et	4	main
vaha	doc_491521502298_item	2657843	et	4	main
linnakultuuri	doc_491521502298_item	2657850	et	4	main
enne	doc_491521502298_item	2657863	et	4	main
oli	doc_491521502298_item	2657866	et	3	main
populaarne	doc_491521502298_item	2657867	et	3	main
abieluinimesed	doc_491521502298_item	2657876	et	3	main
1521	doc_491521502298_item	2657886	et	2	main
samastatud	doc_491521502297_item	2657525	et	4	main
kiriku	doc_491521502297_item	2657534	et	3	main
kalmistutel	doc_491521502297_item	2657535	et	3	main
ristiusu	doc_491521502297_item	2657537	et	3	main
kiriklike	doc_491521502297_item	2657538	et	3	main
miks	doc_491521502297_item	2657546	et	4	main
säilis	doc_491521502297_item	2657548	et	4	main
ka	doc_491521502297_item	2657556	et	3	main
16	doc_491521502297_item	2657569	et	2	main
võimalus	doc_491521502297_item	2657573	et	3	main
emakeeles	doc_491521502297_item	2657575	et	4	main
ristiusku	doc_491521502297_item	2657582	et	4	main
esiteks	doc_491521502297_item	2657590	et	3	main
oli	doc_491521502297_item	2657591	et	3	main
õnnistamine	doc_491521502297_item	2657594	et	4	main
ristiusustamine	doc_491521502297_item	2657604	et	3	main
käis	doc_491521502297_item	2657605	et	4	main
kähku	doc_491521502297_item	2657606	et	3	main
ja	doc_491521502297_item	2657607	et	3	main
paganatele	doc_491521502297_item	2657608	et	3	main
ei	doc_491521502297_item	2657609	et	4	main
olnud	doc_491521502297_item	2657610	et	4	main
selge	doc_491521502297_item	2657611	et	4	main
miks	doc_491521502297_item	2657612	et	4	main
paljud	doc_491521502297_item	2657613	et	3	main
tavad	doc_491521502297_item	2657614	et	3	main
mis	doc_491521502297_item	2657615	et	4	main
olid	doc_491521502297_item	2657616	et	4	main
neile	doc_491521502297_item	2657617	et	4	main
omased	doc_491521502297_item	2657618	et	3	main
nüüd	doc_491521502297_item	2657619	et	4	main
keelati	doc_491521502297_item	2657620	et	4	main
olnud	doc_491521502297_item	2657634	et	4	main
meeltmööda	doc_491521502297_item	2657635	et	3	main
veretasu	doc_491521502297_item	2657640	et	4	main
eestlastele	doc_491521502297_item	2657642	et	4	main
aastal	doc_491521502297_item	2657648	et	3	main
aasta	doc_491521502297_item	2657654	et	4	main
pärast	doc_491521502297_item	2657655	et	4	main
hansaliidu	doc_491521502297_item	2657656	et	3	main
keskpunktiks	doc_491521502297_item	2657657	et	4	main
hansaliit	doc_491521502297_item	2657658	et	3	main
kaupmeeste	doc_491521502297_item	2657659	et	4	main
liit	doc_491521502297_item	2657660	et	3	main
hansaliidu	doc_491521502297_item	2657661	et	3	main
liikmed	doc_491521502297_item	2657662	et	3	main
põhja	doc_491521502297_item	2657664	et	4	main
liivimaa	doc_491521502297_item	2657667	et	4	main
astusid	doc_491521502297_item	2657672	et	4	main
tartu	doc_491521502297_item	2657677	et	4	main
vaha	doc_491521502297_item	2657707	et	4	main
ja	doc_491521502297_item	2657710	et	3	main
kontrolltöö	doc_491521502298_item	2657712	et	4	main
sa	doc_491521502298_item	2657720	et	3	main
võimalikuks	doc_491521502298_item	2657721	et	3	main
1	doc_491521502298_item	2657724	et	2	main
sellest	doc_491521502298_item	2657732	et	4	main
oli	doc_491521502298_item	2657742	et	3	main
alla	doc_491521502298_item	2657746	et	3	main
linna	doc_491521502298_item	2657762	et	4	main
elanikkond	doc_491521502298_item	2657763	et	3	main
jagunes	doc_491521502298_item	2657764	et	3	main
rangelt	doc_491521502298_item	2657765	et	4	main
saksteks	doc_491521502298_item	2657766	et	3	main
ja	doc_491521502298_item	2657767	et	3	main
maamatsideks	doc_491521502298_item	2657768	et	4	main
sakste	doc_491521502298_item	2657769	et	3	main
saksa	doc_491521502298_item	2657773	et	4	main
aadlis	doc_491521502298_item	2657776	et	3	main
kaupmehed	doc_491521502298_item	2657778	et	3	main
rahasepad	doc_491521502298_item	2657781	et	3	main
töölised	doc_491521502298_item	2657784	et	3	main
lihtrahva	doc_491521502298_item	2657791	et	3	main
oskusi	doc_491521502298_item	2657822	et	3	main
käsitöga	doc_491521502298_item	2657824	et	4	main
ja	doc_491521502298_item	2657832	et	3	main
liivlaste	doc_491521502298_item	2657833	et	4	main
rukist	doc_491521502298_item	2657844	et	3	main
edendajad	doc_491521502298_item	2657851	et	4	main
turuplatsile	doc_491521502298_item	2657859	et	4	main
veel	doc_491521502298_item	2657860	et	4	main
ka	doc_491521502298_item	2657861	et	3	main
saj	doc_491521502298_item	2657865	et	4	main
pandi	doc_491521502298_item	2657875	et	4	main
paari	doc_491521502298_item	2657878	et	4	main
ning	doc_491521502298_item	2657879	et	3	main
kirikuisa	doc_491521502298_item	2657880	et	4	main
pühitses	doc_491521502298_item	2657881	et	3	main
enda	doc_491521502298_item	2657896	et	4	main
toomkirikute	doc_491521502298_item	2657905	et	4	main
olid	doc_491521502298_item	2657907	et	4	main
väljaõppeks	doc_491521502298_item	2657917	et	3	main
rootsiajal	doc_491521502298_item	2657921	et	3	main
tuntud	doc_491521502298_item	2657923	et	4	main
kes	doc_491521502298_item	2657927	et	4	main
ka	doc_491521502298_item	2657929	et	3	main
poisse	doc_491521502298_item	2657931	et	4	main
kandsid	doc_491521502298_item	2657935	et	4	main
ka	doc_491521502298_item	2657936	et	3	main
arkitektuur	doc_491521502298_item	2657945	et	4	main
linna	doc_491521502298_item	2657949	et	4	main
lihtsate	doc_491521502298_item	2657958	et	3	main
niguliste	doc_491521502298_item	2657967	et	4	main
kirikus	doc_491521502298_item	2657968	et	3	main
ja	doc_491521502298_item	2657969	et	3	main
määr	doc_491521502298_item	2657976	et	3	main
eeskätt	doc_491521502298_item	2657977	et	3	main
saksamaa	doc_491521502298_item	2657978	et	4	main
stiil	doc_491521502298_item	2657979	et	3	main
ametlikuks	doc_491521502298_item	2657980	et	3	main
linna	doc_491521502298_item	2657994	et	4	main
oma	doc_491521502298_item	2658038	et	4	main
võimsuse	doc_491521502298_item	2658040	et	4	main
ühtsus	doc_491521502298_item	2658052	et	4	main
ka	doc_491521502298_item	2658053	et	3	main
tarvilik	doc_491521502298_item	2658068	et	3	main
pikaajalisteks	doc_491521502298_item	2658073	et	4	main
2	doc_491521502299_item	2658111	et	2	main
huvitus	doc_491521502299_item	2658119	et	4	main
eestis	doc_491521502299_item	2658125	et	3	main
kauplemist	doc_491521502299_item	2658129	et	4	main
moskva	doc_491521502299_item	2658145	et	4	main
tema	doc_491521502299_item	2658148	et	4	main
ümber	doc_491521502299_item	2658149	et	3	main
kujuneb	doc_491521502299_item	2658153	et	3	main
jõudu	doc_491521502299_item	2658156	et	4	main
juurde	doc_491521502299_item	2658158	et	4	main
kuna	doc_491521502297_item	2657691	et	3	main
eestisse	doc_491521502297_item	2657694	et	4	main
1	doc_491521502298_item	2657713	et	2	main
2	doc_491521502298_item	2657718	et	2	main
saab	doc_491521502298_item	2657734	et	3	main
linnakultuurist	doc_491521502298_item	2657737	et	3	main
liivimaal	doc_491521502298_item	2657743	et	4	main
linnakultuur	doc_491521502298_item	2657745	et	3	main
kooliharidust	doc_491521502298_item	2657751	et	4	main
1227-1343	doc_491521502298_item	2657753	et	2	main
sai	doc_491521502298_item	2657754	et	4	main
kaubanduse	doc_491521502298_item	2657755	et	3	main
ja	doc_491521502298_item	2657756	et	3	main
hulka	doc_491521502298_item	2657770	et	4	main
kuulusid	doc_491521502298_item	2657771	et	4	main
saksasoost	doc_491521502298_item	2657777	et	4	main
vasesepad	doc_491521502298_item	2657780	et	3	main
need	doc_491521502298_item	2657783	et	3	main
eestlased	doc_491521502298_item	2657792	et	3	main
alamtööga	doc_491521502298_item	2657797	et	3	main
peamiselt	doc_491521502298_item	2657796	et	4	main
puusepad	doc_491521502298_item	2657798	et	3	main
kingsepad	doc_491521502298_item	2657799	et	3	main
linnas	doc_491521502298_item	2657800	et	4	main
valitses	doc_491521502298_item	2657801	et	3	main
selgelt	doc_491521502298_item	2657802	et	4	main
väljakujunenud	doc_491521502298_item	2657803	et	4	main
tsunftide	doc_491521502298_item	2657804	et	3	main
ja	doc_491521502298_item	2657805	et	3	main
gildide	doc_491521502298_item	2657806	et	3	main
hierarhia	doc_491521502298_item	2657807	et	4	main
ühte	doc_491521502298_item	2657808	et	4	main
ametid	doc_491521502298_item	2657809	et	3	main
pidavad	doc_491521502298_item	2657810	et	4	main
ametimehed	doc_491521502298_item	2657811	et	3	main
kuulusid	doc_491521502298_item	2657812	et	4	main
ühte	doc_491521502298_item	2657813	et	4	main
tsunfti	doc_491521502298_item	2657814	et	4	main
mis	doc_491521502298_item	2657815	et	4	main
kaitses	doc_491521502298_item	2657816	et	4	main
nende	doc_491521502298_item	2657817	et	4	main
meeste	doc_491521502298_item	2657818	et	4	main
õigusi	doc_491521502298_item	2657819	et	4	main
kontrollis	doc_491521502298_item	2657820	et	4	main
nende	doc_491521502298_item	2657821	et	4	main
kohapealese	doc_491521502298_item	2657823	et	4	main
eestlaste	doc_491521502298_item	2657831	et	4	main
transiitkaubandus	doc_491521502298_item	2657835	et	3	main
välismaale	doc_491521502298_item	2657838	et	4	main
töö	doc_491521502298_item	2657849	et	4	main
lisaks	doc_491521502298_item	2657858	et	4	main
16	doc_491521502298_item	2657864	et	2	main
altarite	doc_491521502298_item	2657868	et	3	main
kummardamine	doc_491521502298_item	2657869	et	4	main
jutlustuse	doc_491521502298_item	2657872	et	4	main
kuulamine	doc_491521502298_item	2657873	et	4	main
mulda	doc_491521502298_item	2657883	et	4	main
liivimaal	doc_491521502298_item	2657887	et	4	main
kirik	doc_491521502298_item	2657889	et	3	main
tähtsaks	doc_491521502298_item	2657890	et	4	main
päritoluga	doc_491521502298_item	2657774	et	3	main
vaimulikud	doc_491521502298_item	2657775	et	3	main
kullassepad	doc_491521502298_item	2657779	et	3	main
kes	doc_491521502298_item	2657785	et	4	main
parema	doc_491521502298_item	2657787	et	4	main
ladgolid	doc_491521502298_item	2657793	et	4	main
tegelesid	doc_491521502298_item	2657795	et	4	main
leidus	doc_491521502298_item	2657829	et	4	main
ka	doc_491521502298_item	2657830	et	3	main
müüdi	doc_491521502298_item	2657837	et	4	main
eeskätt	doc_491521502298_item	2657839	et	3	main
venemaale	doc_491521502298_item	2657840	et	4	main
mett	doc_491521502298_item	2657842	et	4	main
saksa	doc_491521502298_item	2657846	et	4	main
kirik	doc_491521502298_item	2657862	et	3	main
ladinakeelse	doc_491521502298_item	2657871	et	3	main
surnute	doc_491521502298_item	2657882	et	4	main
ajal	doc_491521502298_item	2657885	et	4	main
muutus	doc_491521502298_item	2657888	et	4	main
esimene	doc_491521502298_item	2657901	et	3	main
katekismus	doc_491521502298_item	2657904	et	3	main
juures	doc_491521502298_item	2657906	et	4	main
ka	doc_491521502298_item	2657914	et	3	main
ning	doc_491521502298_item	2657918	et	3	main
koolitamiseks	doc_491521502298_item	2657920	et	4	main
edendaja	doc_491521502298_item	2657925	et	4	main
kultuuri	doc_491521502298_item	2657939	et	4	main
oli	doc_491521502298_item	2657943	et	3	main
kirikukooned	doc_491521502298_item	2657947	et	4	main
raad	doc_491521502298_item	2657950	et	4	main
need	doc_491521502298_item	2657952	et	3	main
ehitised	doc_491521502298_item	2657953	et	3	main
sündsuse	doc_491521502298_item	2657954	et	4	main
piirid	doc_491521502298_item	2657955	et	3	main
majade	doc_491521502298_item	2657960	et	3	main
on	doc_491521502298_item	2657964	et	4	main
säilinud	doc_491521502298_item	2657965	et	4	main
eelkõige	doc_491521502298_item	2657966	et	3	main
notke	doc_491521502298_item	2657972	et	4	main
liivimaa	doc_491521502298_item	2657974	et	4	main
oli	doc_491521502298_item	2657982	et	3	main
võis	doc_491521502298_item	2657987	et	4	main
kuulda	doc_491521502298_item	2657989	et	4	main
et	doc_491521502298_item	2658023	et	3	main
sai	doc_491521502298_item	2658029	et	4	main
võimalikuks	doc_491521502298_item	2658030	et	3	main
enam	doc_491521502298_item	2658037	et	4	main
esinesid	doc_491521502298_item	2658042	et	4	main
riia	doc_491521502298_item	2658047	et	4	main
riigis	doc_491521502298_item	2658050	et	3	main
kahurilika	doc_491521502298_item	2658054	et	4	main
onekool	doc_491521502298_item	2658055	et	4	main
vene	doc_491521502298_item	2658057	et	4	main
ivan	doc_491521502298_item	2658060	et	4	main
suurem	doc_491521502298_item	2658063	et	4	main
väljaõppe	doc_491521502298_item	2658072	et	4	main
sõjakäikudeks	doc_491521502298_item	2658074	et	3	main
1	doc_491521502299_item	2658106	et	2	main
linnakultuur	doc_491521502299_item	2658110	et	3	main
võimalikuks	doc_491521502299_item	2658114	et	3	main
2	doc_491521502299_item	2658117	et	2	main
tegelesid	doc_491521502298_item	2657825	et	4	main
kus	doc_491521502298_item	2657836	et	3	main
oli	doc_491521502298_item	2657845	et	3	main
soost	doc_491521502298_item	2657847	et	4	main
kaupmeeste	doc_491521502298_item	2657848	et	4	main
olid	doc_491521502298_item	2657852	et	4	main
eeskätt	doc_491521502298_item	2657853	et	3	main
vaimulikud	doc_491521502298_item	2657854	et	3	main
seega	doc_491521502298_item	2657855	et	4	main
kultuurikeskusteks	doc_491521502298_item	2657856	et	4	main
oli	doc_491521502298_item	2657857	et	3	main
kirikus	doc_491521502298_item	2657870	et	3	main
kirikus	doc_491521502298_item	2657874	et	3	main
ametlikult	doc_491521502298_item	2657877	et	4	main
reformatsiooni	doc_491521502298_item	2657884	et	4	main
emakeeles	doc_491521502298_item	2657897	et	4	main
palveid	doc_491521502298_item	2657898	et	3	main
ilmub	doc_491521502298_item	2657900	et	3	main
ajal	doc_491521502298_item	2657912	et	4	main
avati	doc_491521502298_item	2657913	et	3	main
kirikuõpetajatel	doc_491521502298_item	2657916	et	3	main
oli	doc_491521502298_item	2657922	et	3	main
forselius	doc_491521502298_item	2657926	et	4	main
koolitada	doc_491521502298_item	2657932	et	3	main
tema	doc_491521502298_item	2657933	et	4	main
püüdlused	doc_491521502298_item	2657934	et	3	main
linna	doc_491521502298_item	2657938	et	4	main
tähtsamaks	doc_491521502298_item	2657941	et	4	main
olid	doc_491521502298_item	2657951	et	4	main
mis	doc_491521502298_item	2657956	et	4	main
oleviste	doc_491521502298_item	2657970	et	4	main
linna	doc_491521502298_item	2657985	et	4	main
sageli	doc_491521502298_item	2657988	et	3	main
vene-liivi	doc_491521502298_item	2658027	et	4	main
selle	doc_491521502298_item	2658032	et	4	main
poolest	doc_491521502298_item	2658033	et	4	main
et	doc_491521502298_item	2658034	et	3	main
peapiiskopi	doc_491521502298_item	2658048	et	4	main
oli	doc_491521502298_item	2658056	et	3	main
pealegi	doc_491521502298_item	2658064	et	4	main
ivan	doc_491521502298_item	2658075	et	4	main
innustust	doc_491521502298_item	2658078	et	4	main
missugune	doc_491521502299_item	2658107	et	3	main
miks	doc_491521502299_item	2658112	et	4	main
venemaad	doc_491521502299_item	2658118	et	4	main
arvates	doc_491521502299_item	2658123	et	4	main
taga	doc_491521502299_item	2658126	et	4	main
pidavat	doc_491521502299_item	2658132	et	4	main
troonil	doc_491521502299_item	2658140	et	3	main
asuvad	doc_491521502299_item	2658150	et	4	main
väikesed	doc_491521502299_item	2658151	et	4	main
vürtsiriigid	doc_491521502299_item	2658152	et	3	main
tuleb	doc_491521502299_item	2658157	et	3	main
keskajal	doc_491521502299_item	2658162	et	3	main
omavalitsuslikud	doc_491521502299_item	2658163	et	3	main
esindas	doc_491521502299_item	2658180	et	3	main
maksustada	doc_491521502299_item	2658188	et	3	main
ja	doc_491521502299_item	2658192	et	3	main
linnal	doc_491521502299_item	2658196	et	3	main
võtta	doc_491521502299_item	2658200	et	3	main
gildid	doc_491521502299_item	2658206	et	3	main
käsitöölised	doc_491521502299_item	2658209	et	3	main
eestlastel	doc_491521502299_item	2658218	et	4	main
hariduspunktiks	doc_491521502298_item	2657891	et	4	main
hakati	doc_491521502298_item	2657892	et	3	main
õpetama	doc_491521502298_item	2657893	et	3	main
lihtrahvale	doc_491521502298_item	2657894	et	3	main
tema	doc_491521502298_item	2657895	et	4	main
eestikeelne	doc_491521502298_item	2657902	et	3	main
seminarid	doc_491521502298_item	2657915	et	3	main
1535	doc_491521502298_item	2657899	et	2	main
wandradt-koelli	doc_491521502298_item	2657903	et	4	main
linnarahvale	doc_491521502298_item	2657908	et	3	main
mõeldud	doc_491521502298_item	2657909	et	4	main
koolid	doc_491521502298_item	2657910	et	3	main
rootsi	doc_491521502298_item	2657911	et	4	main
tõlkide	doc_491521502298_item	2657919	et	3	main
vaimuelu	doc_491521502298_item	2657924	et	4	main
eestisoost	doc_491521502298_item	2657930	et	4	main
üheks	doc_491521502298_item	2657940	et	3	main
osaks	doc_491521502298_item	2657942	et	3	main
skulptuur	doc_491521502298_item	2657946	et	3	main
ning	doc_491521502298_item	2657948	et	3	main
määrasid	doc_491521502298_item	2657957	et	4	main
kõrgust	doc_491521502298_item	2657961	et	4	main
maalikultuur	doc_491521502298_item	2657963	et	3	main
kirikus	doc_491521502298_item	2657971	et	3	main
luuleks	doc_491521502298_item	2657981	et	4	main
keel	doc_491521502298_item	2657984	et	4	main
ka	doc_491521502298_item	2657990	et	3	main
taani	doc_491521502298_item	2657991	et	4	main
keelt	doc_491521502298_item	2657992	et	4	main
toonasesse	doc_491521502298_item	2657993	et	3	main
püüdis	doc_491521502298_item	2657928	et	3	main
vilja	doc_491521502298_item	2657937	et	4	main
ka	doc_491521502298_item	2657944	et	3	main
inimeste	doc_491521502298_item	2657959	et	3	main
gootistiilis	doc_491521502298_item	2657962	et	4	main
surmatants	doc_491521502298_item	2657973	et	3	main
linnakultuuri	doc_491521502298_item	2657975	et	4	main
saksa	doc_491521502298_item	2657983	et	4	main
rahvamurrust	doc_491521502298_item	2657986	et	3	main
kultuuri	doc_491521502298_item	2657995	et	4	main
kuuluvad	doc_491521502298_item	2657996	et	4	main
ka	doc_491521502298_item	2657997	et	3	main
vaimulike	doc_491521502298_item	2657998	et	3	main
poolt	doc_491521502298_item	2657999	et	4	main
avatud	doc_491521502298_item	2658000	et	4	main
laatsaretis	doc_491521502298_item	2658001	et	3	main
kus	doc_491521502298_item	2658002	et	3	main
misjonäridest	doc_491521502298_item	2658003	et	3	main
nn	doc_491521502298_item	2658004	et	4	main
soola	doc_491521502298_item	2658005	et	4	main
puhujad	doc_491521502298_item	2658006	et	4	main
osutasid	doc_491521502298_item	2658007	et	4	main
rahvale	doc_491521502298_item	2658008	et	3	main
meditsiinilist	doc_491521502298_item	2658009	et	4	main
abi	doc_491521502298_item	2658010	et	4	main
keskaegesse	doc_491521502298_item	2658011	et	4	main
linna	doc_491521502298_item	2658012	et	4	main
kuulub	doc_491521502298_item	2658014	et	3	main
kultuuri	doc_491521502298_item	2658013	et	4	main
ka	doc_491521502298_item	2658015	et	3	main
tihe	doc_491521502298_item	2658016	et	3	main
majade	doc_491521502298_item	2658017	et	3	main
paidutus	doc_491521502298_item	2658018	et	4	main
mis	doc_491521502298_item	2658019	et	4	main
olid	doc_491521502298_item	2658020	et	4	main
enamasti	doc_491521502298_item	2658021	et	4	main
valtida	doc_491521502298_item	2658024	et	4	main
2	doc_491521502298_item	2658026	et	2	main
liiviordu	doc_491521502298_item	2658035	et	4	main
senise	doc_491521502298_item	2658039	et	3	main
tipus	doc_491521502298_item	2658041	et	3	main
siseriiklikud	doc_491521502298_item	2658043	et	3	main
ja	doc_491521502298_item	2658046	et	3	main
puudus	doc_491521502298_item	2658051	et	4	main
vürstiriigi	doc_491521502298_item	2658058	et	3	main
puudus	doc_491521502298_item	2658065	et	4	main
ka	doc_491521502298_item	2658066	et	3	main
varustus	doc_491521502298_item	2658069	et	4	main
ja	doc_491521502298_item	2658070	et	3	main
sõjaline	doc_491521502298_item	2658071	et	4	main
iv	doc_491521502298_item	2658076	et	4	main
sai	doc_491521502298_item	2658077	et	4	main
oli	doc_491521502299_item	2658108	et	3	main
sa	doc_491521502299_item	2658113	et	3	main
vene-liivi	doc_491521502299_item	2658115	et	4	main
kivist	doc_491521502298_item	2658022	et	4	main
tuleohtu	doc_491521502298_item	2658025	et	4	main
sõda	doc_491521502298_item	2658028	et	4	main
eeskätt	doc_491521502298_item	2658031	et	3	main
polnud	doc_491521502298_item	2658036	et	3	main
lahkhelid	doc_491521502298_item	2658044	et	3	main
ordumeistri	doc_491521502298_item	2658045	et	3	main
vahel	doc_491521502298_item	2658049	et	4	main
peal	doc_491521502298_item	2658059	et	4	main
iv	doc_491521502298_item	2658061	et	4	main
palju	doc_491521502298_item	2658062	et	4	main
lihtrahval	doc_491521502298_item	2658067	et	3	main
ka	doc_491521502298_item	2658079	et	3	main
võitudest	doc_491521502298_item	2658080	et	3	main
fatasi-mongoli	doc_491521502298_item	2658081	et	3	main
lehooniga	doc_491521502298_item	2658082	et	4	main
ning	doc_491521502298_item	2658083	et	3	main
oli	doc_491521502298_item	2658084	et	3	main
oma	doc_491521502298_item	2658085	et	4	main
võidus	doc_491521502298_item	2658086	et	4	main
kindel	doc_491521502298_item	2658087	et	3	main
ajendiks	doc_491521502298_item	2658088	et	3	main
sai	doc_491521502298_item	2658089	et	4	main
siin	doc_491521502298_item	2658090	et	4	main
maal	doc_491521502298_item	2658091	et	4	main
vanausuliste	doc_491521502298_item	2658092	et	4	main
tagakiusamine	doc_491521502298_item	2658093	et	3	main
siinne	doc_491521502298_item	2658094	et	3	main
territoorium	doc_491521502298_item	2658095	et	3	main
on	doc_491521502298_item	2658096	et	4	main
iidsetest	doc_491521502298_item	2658097	et	3	main
aegadest	doc_491521502298_item	2658098	et	3	main
kuulunud	doc_491521502298_item	2658099	et	4	main
venemaale	doc_491521502298_item	2658100	et	4	main
tastu	doc_491521502298_item	2658101	et	4	main
maksu	doc_491521502298_item	2658102	et	4	main
tasumata	doc_491521502298_item	2658103	et	4	main
jätmine	doc_491521502298_item	2658104	et	4	main
kontrolltöö	doc_491521502299_item	2658105	et	4	main
keskaegne	doc_491521502299_item	2658109	et	3	main
sõda	doc_491521502299_item	2658116	et	4	main
merele	doc_491521502299_item	2658121	et	3	main
pealegi	doc_491521502299_item	2658131	et	4	main
eesti	doc_491521502299_item	2658133	et	4	main
iv	doc_491521502299_item	2658142	et	4	main
julm	doc_491521502299_item	2658144	et	3	main
kogus	doc_491521502299_item	2658146	et	4	main
kokku	doc_491521502299_item	2658147	et	3	main
igal	doc_491521502299_item	2658165	et	3	main
kehtis	doc_491521502299_item	2658167	et	3	main
linnaõigus	doc_491521502299_item	2658169	et	4	main
raad	doc_491521502299_item	2658172	et	4	main
peamiselt	doc_491521502299_item	2658174	et	4	main
maade	doc_491521502299_item	2658178	et	3	main
rae	doc_491521502299_item	2658182	et	3	main
igal	doc_491521502299_item	2658195	et	3	main
keda	doc_491521502299_item	2658199	et	4	main
linna	doc_491521502299_item	2658201	et	4	main
kodanikuks	doc_491521502299_item	2658202	et	4	main
tsunftid	doc_491521502299_item	2658208	et	3	main
ka	doc_491521502299_item	2658212	et	3	main
nad	doc_491521502299_item	2658214	et	3	main
elasid	doc_491521502299_item	2658220	et	4	main
säilis	doc_491521502299_item	2658222	et	4	main
omasid	doc_491521502299_item	2658226	et	4	main
tiheda	doc_491521502299_item	2658237	et	3	main
tõttu	doc_491521502299_item	2658239	et	4	main
eesti	doc_491521502299_item	2658259	et	4	main
ka	doc_491521502299_item	2658265	et	3	main
peenemate	doc_491521502299_item	2658266	et	4	main
alade	doc_491521502299_item	2658267	et	3	main
tulnud	doc_491521502299_item	2658270	et	4	main
eesti	doc_491521502299_item	2658275	et	4	main
vili	doc_491521502299_item	2658279	et	3	main
hea	doc_491521502299_item	2658284	et	4	main
hinnaliseks	doc_491521502299_item	2658287	et	4	main
erilise	doc_491521502299_item	2658304	et	4	main
viidi	doc_491521502299_item	2658318	et	4	main
ka	doc_491521502299_item	2658319	et	3	main
hülgerasva	doc_491521502299_item	2658321	et	4	main
lina	doc_491521502299_item	2658322	et	4	main
sest	doc_491521502299_item	2658333	et	4	main
tol	doc_491521502299_item	2658334	et	3	main
teinekord	doc_491521502299_item	2658351	et	3	main
just	doc_491521502299_item	2658361	et	3	main
põleda	doc_491521502299_item	2658366	et	3	main
linnakultuur	doc_491521502300_item	2658372	et	3	main
viljandi	doc_491521502300_item	2658401	et	4	main
kõik	doc_491521502300_item	2658402	et	4	main
kuuluvad	doc_491521502300_item	2658404	et	4	main
hansa	doc_491521502300_item	2658405	et	4	main
on	doc_491521502300_item	2658408	et	4	main
tähtis	doc_491521502300_item	2658411	et	4	main
kaubanduslinn	doc_491521502300_item	2658412	et	3	main
aeg	doc_491521502300_item	2658416	et	3	main
linnavõimude	doc_491521502300_item	2658421	et	3	main
konflikte	doc_491521502300_item	2658426	et	3	main
kirik	doc_491521502300_item	2658433	et	3	main
paganad	doc_491521502300_item	2658440	et	3	main
kasutaks	doc_491521502300_item	2658442	et	4	main
kombeid	doc_491521502300_item	2658444	et	4	main
praegu	doc_491521502300_item	2658445	et	3	main
visitat	doc_491521502300_item	2658446	et	4	main
leida	doc_491521502300_item	2658449	et	3	main
rahvalaule	doc_491521502300_item	2658450	et	4	main
kihelkond	doc_491521502300_item	2658458	et	3	main
ühtne	doc_491521502300_item	2658463	et	3	main
keelemurre	doc_491521502300_item	2658464	et	4	main
ja	doc_491521502300_item	2658471	et	3	main
rõivastus	doc_491521502300_item	2658472	et	4	main
ii	doc_491521502300_item	2658477	et	4	main
paiksus	doc_491521502300_item	2658484	et	4	main
ka	doc_491521502300_item	2658490	et	3	main
arstid	doc_491521502300_item	2658492	et	4	main
a	doc_491521502300_item	2658497	et	4	main
klooster	doc_491521502300_item	2658499	et	3	main
1436	doc_491521502300_item	2658501	et	2	main
a	doc_491521502300_item	2658502	et	4	main
frantsihlased	doc_491521502300_item	2658505	et	4	main
saj	doc_491521502300_item	2658509	et	4	main
pääs	doc_491521502299_item	2658120	et	3	main
venelaste	doc_491521502299_item	2658122	et	4	main
takistati	doc_491521502299_item	2658128	et	3	main
nagunii	doc_491521502299_item	2658134	et	3	main
venemaale	doc_491521502299_item	2658136	et	4	main
kuuluma	doc_491521502299_item	2658137	et	3	main
venemaal	doc_491521502299_item	2658138	et	4	main
oli	doc_491521502299_item	2658139	et	3	main
riik	doc_491521502299_item	2658155	et	3	main
1	doc_491521502299_item	2658159	et	2	main
linnad	doc_491521502299_item	2658160	et	3	main
olid	doc_491521502299_item	2658161	et	4	main
oma	doc_491521502299_item	2658168	et	4	main
linna	doc_491521502299_item	2658170	et	4	main
linna	doc_491521502299_item	2658176	et	4	main
omanikke	doc_491521502299_item	2658179	et	3	main
ülesanne	doc_491521502299_item	2658183	et	4	main
linnas	doc_491521502299_item	2658186	et	4	main
korda	doc_491521502299_item	2658187	et	4	main
pidada	doc_491521502299_item	2658190	et	4	main
müntida	doc_491521502299_item	2658193	et	3	main
otsustada	doc_491521502299_item	2658198	et	3	main
kaupmehed	doc_491521502299_item	2658207	et	3	main
eestlasi	doc_491521502299_item	2658213	et	3	main
maaga	doc_491521502299_item	2658224	et	3	main
elu	doc_491521502299_item	2658230	et	4	main
oli	doc_491521502299_item	2658232	et	3	main
sest	doc_491521502299_item	2658236	et	4	main
haigused	doc_491521502299_item	2658241	et	4	main
tallinn	doc_491521502299_item	2658246	et	4	main
oli	doc_491521502299_item	2658247	et	3	main
seda	doc_491521502299_item	2658280	et	3	main
oli	doc_491521502299_item	2658294	et	3	main
säilinud	doc_491521502299_item	2658295	et	4	main
vilja	doc_491521502299_item	2658296	et	4	main
sisse	doc_491521502299_item	2658306	et	4	main
vürtse	doc_491521502299_item	2658309	et	3	main
veini	doc_491521502299_item	2658310	et	4	main
rauda	doc_491521502299_item	2658313	et	4	main
välja	doc_491521502299_item	2658317	et	4	main
valmistatud	doc_491521502299_item	2658324	et	4	main
köit	doc_491521502299_item	2658325	et	3	main
ajal	doc_491521502299_item	2658335	et	4	main
puitu	doc_491521502299_item	2658339	et	4	main
peatamiseks	doc_491521502299_item	2658350	et	4	main
rootsiajal	doc_491521502299_item	2658356	et	3	main
peamiseks	doc_491521502299_item	2658358	et	3	main
uus-pärnu	doc_491521502300_item	2658400	et	4	main
suhteliselt	doc_491521502300_item	2658413	et	4	main
isegi	doc_491521502300_item	2658417	et	4	main
jaoks	doc_491521502300_item	2658419	et	4	main
palju	doc_491521502300_item	2658425	et	4	main
teostas	doc_491521502300_item	2658434	et	3	main
piiskopi	doc_491521502300_item	2658436	et	4	main
korraldusel	doc_491521502300_item	2658437	et	4	main
ei	doc_491521502300_item	2658441	et	4	main
vanu	doc_491521502300_item	2658443	et	4	main
tähtsaim	doc_491521502300_item	2658456	et	4	main
rahvakultuuri	doc_491521502300_item	2658460	et	4	main
murraks	doc_491521502300_item	2658465	et	3	main
on	doc_491521502300_item	2658466	et	4	main
suuline	doc_491521502300_item	2658467	et	4	main
pärimus	doc_491521502300_item	2658468	et	4	main
ehk	doc_491521502300_item	2658469	et	3	main
saj	doc_491521502300_item	2658476	et	4	main
talupoeg	doc_491521502300_item	2658479	et	3	main
pääse	doc_491521502300_item	2658481	et	4	main
oma	doc_491521502300_item	2658482	et	4	main
tegelesdi	doc_491521502300_item	2658486	et	4	main
olid	doc_491521502300_item	2658489	et	4	main
omapärased	doc_491521502300_item	2658491	et	4	main
õptasid	doc_491521502300_item	2658493	et	4	main
1229	doc_491521502300_item	2658496	et	2	main
begardid	doc_491521502300_item	2658510	et	4	main
rajama	doc_491521502300_item	2658513	et	3	main
suured	doc_491521502300_item	2658527	et	3	main
raekivist	doc_491521502300_item	2658531	et	4	main
hoone	doc_491521502300_item	2658534	et	4	main
2	doc_491521502300_item	2658539	et	2	main
16	doc_491521502300_item	2658549	et	2	main
varem	doc_491521502300_item	2658560	et	4	main
kiusati	doc_491521502299_item	2658124	et	4	main
õigeusklikku	doc_491521502299_item	2658127	et	4	main
euroopaga	doc_491521502299_item	2658130	et	3	main
ajalooliselt	doc_491521502299_item	2658135	et	4	main
ivan	doc_491521502299_item	2658141	et	4	main
ivan	doc_491521502299_item	2658143	et	4	main
ühtne	doc_491521502299_item	2658154	et	3	main
üksused	doc_491521502299_item	2658164	et	3	main
juhtis	doc_491521502299_item	2658171	et	3	main
elanikeks	doc_491521502299_item	2658173	et	3	main
võõramaalased	doc_491521502299_item	2658175	et	3	main
ümbritsevate	doc_491521502299_item	2658177	et	4	main
maahärra	doc_491521502299_item	2658181	et	4	main
pidada	doc_491521502299_item	2658185	et	4	main
kohut	doc_491521502299_item	2658191	et	3	main
keda	doc_491521502299_item	2658203	et	4	main
mitte	doc_491521502299_item	2658204	et	3	main
elas	doc_491521502299_item	2658211	et	3	main
lihtsama	doc_491521502299_item	2658216	et	4	main
kes	doc_491521502299_item	2658219	et	4	main
linnades	doc_491521502299_item	2658221	et	3	main
kui	doc_491521502299_item	2658234	et	3	main
levisid	doc_491521502299_item	2658240	et	4	main
tõttu	doc_491521502299_item	2658243	et	4	main
turul	doc_491521502299_item	2658256	et	3	main
pidid	doc_491521502299_item	2658257	et	4	main
läbima	doc_491521502299_item	2658258	et	4	main
kauplemine	doc_491521502299_item	2658261	et	4	main
olid	doc_491521502299_item	2658269	et	4	main
ehte-	doc_491521502299_item	2658272	et	3	main
oli	doc_491521502299_item	2658278	et	3	main
tunti	doc_491521502299_item	2658281	et	3	main
kvaliteedi	doc_491521502299_item	2658285	et	3	main
eesti	doc_491521502299_item	2658289	et	4	main
sellepärast	doc_491521502299_item	2658291	et	3	main
et	doc_491521502299_item	2658292	et	3	main
siin	doc_491521502299_item	2658293	et	4	main
suits	doc_491521502299_item	2658299	et	3	main
viljast	doc_491521502299_item	2658301	et	4	main
valmistatud	doc_491521502299_item	2658302	et	4	main
leivale	doc_491521502299_item	2658303	et	3	main
toodi	doc_491521502299_item	2658307	et	4	main
heeringat	doc_491521502299_item	2658312	et	3	main
vaske	doc_491521502299_item	2658314	et	4	main
tina	doc_491521502299_item	2658315	et	4	main
humalat	doc_491521502299_item	2658316	et	3	main
kive	doc_491521502299_item	2658326	et	3	main
hukkus	doc_491521502299_item	2658328	et	3	main
ka	doc_491521502299_item	2658330	et	3	main
tulekahjude	doc_491521502299_item	2658331	et	4	main
tõttu	doc_491521502299_item	2658332	et	4	main
peamiselt	doc_491521502299_item	2658338	et	4	main
majad	doc_491521502299_item	2658342	et	3	main
asusid	doc_491521502299_item	2658343	et	4	main
üksteise	doc_491521502299_item	2658345	et	4	main
kõrval	doc_491521502299_item	2658346	et	4	main
siis	doc_491521502299_item	2658347	et	3	main
tuleb	doc_491521502299_item	2658348	et	3	main
isegi	doc_491521502299_item	2658353	et	4	main
hiljem	doc_491521502299_item	2658355	et	3	main
sai	doc_491521502299_item	2658357	et	4	main
ehitusmaterjaliks	doc_491521502299_item	2658359	et	3	main
oma	doc_491521502299_item	2658362	et	4	main
linnad	doc_491521502300_item	2658396	et	3	main
tartu	doc_491521502300_item	2658398	et	4	main
väiksemad	doc_491521502300_item	2658399	et	4	main
riia	doc_491521502300_item	2658407	et	4	main
samuti	doc_491521502300_item	2658409	et	3	main
oli	doc_491521502300_item	2658414	et	3	main
linnal	doc_491521502299_item	2658166	et	3	main
oli	doc_491521502299_item	2658184	et	3	main
elanikke	doc_491521502299_item	2658189	et	3	main
raha	doc_491521502299_item	2658194	et	4	main
oma	doc_491521502299_item	2658197	et	4	main
moodustusid	doc_491521502299_item	2658205	et	4	main
linnades	doc_491521502299_item	2658210	et	3	main
tegelesid	doc_491521502299_item	2658215	et	4	main
käsitööga	doc_491521502299_item	2658217	et	3	main
side	doc_491521502299_item	2658223	et	4	main
väljaspool	doc_491521502299_item	2658227	et	3	main
linnas	doc_491521502299_item	2658231	et	4	main
raskem	doc_491521502299_item	2658233	et	4	main
maal	doc_491521502299_item	2658235	et	4	main
mille	doc_491521502299_item	2658242	et	3	main
paljud	doc_491521502299_item	2658244	et	3	main
oluline	doc_491521502299_item	2658248	et	4	main
transiitsadam	doc_491521502299_item	2658249	et	3	main
novgorodi	doc_491521502299_item	2658255	et	4	main
sadamad	doc_491521502299_item	2658260	et	3	main
käes	doc_491521502299_item	2658264	et	4	main
käsitöölise	doc_491521502299_item	2658268	et	3	main
saksamaalt	doc_491521502299_item	2658271	et	3	main
ja	doc_491521502299_item	2658273	et	3	main
eksportkaup	doc_491521502299_item	2658277	et	3	main
tema	doc_491521502299_item	2658283	et	4	main
vilja	doc_491521502299_item	2658290	et	4	main
taludes	doc_491521502299_item	2658298	et	4	main
kangasid	doc_491521502299_item	2658311	et	4	main
nad	doc_491521502299_item	2658225	et	3	main
linna	doc_491521502299_item	2658228	et	4	main
põlde	doc_491521502299_item	2658229	et	3	main
asustuse	doc_491521502299_item	2658238	et	4	main
surid	doc_491521502299_item	2658245	et	4	main
euroopa	doc_491521502299_item	2658250	et	4	main
kaupmehed	doc_491521502299_item	2658251	et	3	main
kes	doc_491521502299_item	2658252	et	4	main
tahtsid	doc_491521502299_item	2658253	et	4	main
kaubelda	doc_491521502299_item	2658254	et	4	main
oli	doc_491521502299_item	2658262	et	3	main
sakslaste	doc_491521502299_item	2658263	et	3	main
relvameistrid	doc_491521502299_item	2658274	et	3	main
peamine	doc_491521502299_item	2658276	et	3	main
euroopas	doc_491521502299_item	2658282	et	3	main
poolest	doc_491521502299_item	2658286	et	4	main
peeti	doc_491521502299_item	2658288	et	4	main
kuivatamine	doc_491521502299_item	2658297	et	4	main
andis	doc_491521502299_item	2658300	et	3	main
maitse	doc_491521502299_item	2658305	et	4	main
soola	doc_491521502299_item	2658308	et	4	main
kala	doc_491521502299_item	2658320	et	4	main
kanepist	doc_491521502299_item	2658323	et	4	main
linnas	doc_491521502299_item	2658327	et	4	main
ja	doc_491521502299_item	2658340	et	3	main
tihedalt	doc_491521502299_item	2658344	et	4	main
maju	doc_491521502299_item	2658352	et	3	main
lammutada	doc_491521502299_item	2658354	et	3	main
omaduse	doc_491521502299_item	2658363	et	4	main
1	doc_491521502300_item	2658368	et	2	main
keskaegne	doc_491521502300_item	2658371	et	3	main
tähtsamad	doc_491521502300_item	2658395	et	4	main
tallinn	doc_491521502300_item	2658397	et	4	main
liitu	doc_491521502300_item	2658406	et	4	main
väga	doc_491521502300_item	2658410	et	3	main
talupoegade	doc_491521502300_item	2658418	et	3	main
oli	doc_491521502300_item	2658423	et	3	main
protokollides	doc_491521502300_item	2658447	et	4	main
üksus	doc_491521502300_item	2658461	et	3	main
see	doc_491521502300_item	2658473	et	3	main
pooleni	doc_491521502300_item	2658478	et	3	main
ei	doc_491521502300_item	2658480	et	4	main
rändmungad	doc_491521502300_item	2658485	et	3	main
missiooni	doc_491521502300_item	2658487	et	4	main
asju	doc_491521502300_item	2658495	et	3	main
tallinn	doc_491521502300_item	2658500	et	4	main
klooster	doc_491521502300_item	2658504	et	3	main
hallid	doc_491521502300_item	2658506	et	4	main
hakkatakse	doc_491521502300_item	2658512	et	4	main
avalikku	doc_491521502300_item	2658514	et	4	main
kaunistamine	doc_491521502300_item	2658530	et	4	main
kõige	doc_491521502300_item	2658532	et	4	main
gooti	doc_491521502300_item	2658535	et	4	main
sõda	doc_491521502300_item	2658541	et	4	main
b	doc_491521502300_item	2658542	et	4	main
russowi	doc_491521502300_item	2658543	et	4	main
saj	doc_491521502300_item	2658550	et	4	main
agressivseks	doc_491521502300_item	2658558	et	4	main
vaherahu	doc_491521502300_item	2658563	et	4	main
väga	doc_491521502300_item	2658592	et	3	main
pirita	doc_491521502300_item	2658595	et	4	main
alguses	doc_491521502300_item	2658601	et	4	main
kuningriik	doc_491521502300_item	2658605	et	3	main
inimesi	doc_491521502299_item	2658329	et	4	main
kasutati	doc_491521502299_item	2658336	et	4	main
ehitamiseks	doc_491521502299_item	2658337	et	4	main
kuna	doc_491521502299_item	2658341	et	3	main
tule	doc_491521502299_item	2658349	et	4	main
kivi	doc_491521502299_item	2658360	et	4	main
tõttu	doc_491521502299_item	2658364	et	4	main
mitte	doc_491521502299_item	2658365	et	3	main
kontrolltöö	doc_491521502300_item	2658367	et	4	main
missugune	doc_491521502300_item	2658369	et	3	main
oli	doc_491521502300_item	2658370	et	3	main
2	doc_491521502300_item	2658373	et	2	main
miks	doc_491521502300_item	2658374	et	4	main
võimalikuks	doc_491521502300_item	2658376	et	3	main
sa	doc_491521502300_item	2658375	et	3	main
vene-liivi	doc_491521502300_item	2658377	et	4	main
sõda	doc_491521502300_item	2658378	et	4	main
1	doc_491521502300_item	2658379	et	2	main
1270-1558	doc_491521502300_item	2658380	et	2	main
keskaeg	doc_491521502300_item	2658381	et	3	main
inimesed	doc_491521502300_item	2658382	et	3	main
jagunesid	doc_491521502300_item	2658383	et	4	main
matsmaarahvas	doc_491521502300_item	2658384	et	4	main
eestlased	doc_491521502300_item	2658385	et	3	main
sakssakslased	doc_491521502300_item	2658386	et	4	main
linnaelanikud	doc_491521502300_item	2658387	et	3	main
vaimulikud	doc_491521502300_item	2658388	et	3	main
keskaegne	doc_491521502300_item	2658389	et	3	main
elanike	doc_491521502300_item	2658391	et	3	main
linnakultuur	doc_491521502300_item	2658390	et	3	main
200000	doc_491521502300_item	2658393	et	2	main
arv	doc_491521502300_item	2658392	et	3	main
inimesi	doc_491521502300_item	2658394	et	4	main
nad	doc_491521502300_item	2658403	et	3	main
hea	doc_491521502300_item	2658415	et	4	main
aga	doc_491521502300_item	2658420	et	3	main
vaehl	doc_491521502300_item	2658422	et	4	main
jälgiti	doc_491521502300_item	2658438	et	3	main
võib	doc_491521502300_item	2658448	et	3	main
emakirik	doc_491521502300_item	2658455	et	3	main
kirik	doc_491521502300_item	2658457	et	3	main
kujuneb	doc_491521502300_item	2658462	et	3	main
kõik	doc_491521502300_item	2658474	et	4	main
püsib19	doc_491521502300_item	2658475	et	3	main
tegevusega	doc_491521502300_item	2658488	et	4	main
dominiiklaste	doc_491521502300_item	2658498	et	3	main
pirita	doc_491521502300_item	2658503	et	4	main
15	doc_491521502300_item	2658508	et	2	main
olid	doc_491521502300_item	2658521	et	4	main
gooti	doc_491521502300_item	2658523	et	4	main
tartu	doc_491521502300_item	2658537	et	4	main
kroonika	doc_491521502300_item	2658545	et	4	main
talupoegade	doc_491521502300_item	2658547	et	3	main
moskvas	doc_491521502300_item	2658551	et	4	main
valitses	doc_491521502300_item	2658552	et	3	main
iv	doc_491521502300_item	2658554	et	4	main
riigiks	doc_491521502300_item	2658559	et	3	main
sõda	doc_491521502300_item	2658569	et	4	main
ivan	doc_491521502300_item	2658570	et	4	main
julmad	doc_491521502300_item	2658593	et	3	main
kloostri	doc_491521502300_item	2658596	et	3	main
pommitatakse	doc_491521502300_item	2658598	et	3	main
poolakatele	doc_491521502300_item	2658610	et	4	main
katoliklik	doc_491521502300_item	2658614	et	4	main
vanad	doc_491521502300_item	2658617	et	3	main
sajandiks	doc_491521502300_item	2658628	et	3	main
kolleegium	doc_491521502300_item	2658634	et	3	main
peetakse	doc_491521502300_item	2658636	et	3	main
kohalike	doc_491521502300_item	2658641	et	4	main
katoliiklik	doc_491521502300_item	2658648	et	3	main
poole	doc_491521502300_item	2658651	et	4	main
tartu	doc_491521502300_item	2658658	et	4	main
1629a	doc_491521502300_item	2658659	et	4	main
altmarki	doc_491521502300_item	2658660	et	4	main
kontrolltöö	doc_491521502301_item	2658662	et	4	main
1	doc_491521502301_item	2658674	et	2	main
välismaalased	doc_491521502301_item	2658678	et	3	main
ja	doc_491521502301_item	2658680	et	3	main
rahvas	doc_491521502301_item	2658693	et	4	main
võim	doc_491521502301_item	2658697	et	3	main
nad	doc_491521502301_item	2658699	et	3	main
olid	doc_491521502301_item	2658700	et	4	main
meister	doc_491521502301_item	2658707	et	3	main
pidama	doc_491521502301_item	2658711	et	4	main
tallinn	doc_491521502301_item	2658720	et	4	main
väga	doc_491521502300_item	2658424	et	3	main
ii	doc_491521502300_item	2658427	et	4	main
võim	doc_491521502300_item	2658428	et	3	main
kirik	doc_491521502300_item	2658429	et	3	main
piiskop	doc_491521502300_item	2658430	et	3	main
oli	doc_491521502300_item	2658431	et	3	main
vaimulik	doc_491521502300_item	2658432	et	3	main
visitatsioonid	doc_491521502300_item	2658435	et	3	main
et	doc_491521502300_item	2658439	et	3	main
jne	doc_491521502300_item	2658451	et	4	main
kirikukihelkond	doc_491521502300_item	2658452	et	3	main
teatud	doc_491521502300_item	2658453	et	4	main
territoorium	doc_491521502300_item	2658454	et	3	main
väike	doc_491521502300_item	2658459	et	4	main
folkloor	doc_491521502300_item	2658470	et	4	main
kodust	doc_491521502300_item	2658483	et	4	main
uusi	doc_491521502300_item	2658494	et	3	main
mungad	doc_491521502300_item	2658507	et	3	main
kõige	doc_491521502300_item	2658516	et	4	main
tähtsam	doc_491521502300_item	2658517	et	4	main
oli	doc_491521502300_item	2658518	et	3	main
haiglaid	doc_491521502300_item	2658515	et	3	main
raekoda	doc_491521502300_item	2658519	et	4	main
kirikud	doc_491521502300_item	2658520	et	3	main
begiinid	doc_491521502300_item	2658511	et	4	main
stiilils	doc_491521502300_item	2658524	et	4	main
hooned	doc_491521502300_item	2658525	et	4	main
monumentaalsed	doc_491521502300_item	2658528	et	3	main
toomkirik	doc_491521502300_item	2658538	et	3	main
vene-liivi	doc_491521502300_item	2658540	et	4	main
liivimaa	doc_491521502300_item	2658544	et	4	main
julm	doc_491521502300_item	2658555	et	3	main
oli	doc_491521502300_item	2658561	et	3	main
venemaaga	doc_491521502300_item	2658562	et	3	main
1559	doc_491521502300_item	2658566	et	2	main
a	doc_491521502300_item	2658567	et	4	main
vene-liivi	doc_491521502300_item	2658568	et	4	main
olid	doc_491521502300_item	2658591	et	4	main
tugevad	doc_491521502300_item	2658594	et	4	main
hävitamine	doc_491521502300_item	2658597	et	4	main
võimule	doc_491521502300_item	2658603	et	3	main
1582a	doc_491521502300_item	2658611	et	4	main
valitsus	doc_491521502300_item	2658613	et	4	main
taastas	doc_491521502300_item	2658616	et	3	main
kombed	doc_491521502300_item	2658618	et	3	main
1582a	doc_491521502300_item	2658620	et	4	main
uus	doc_491521502300_item	2658621	et	3	main
kümme	doc_491521502300_item	2658624	et	3	main
kalendri	doc_491521502300_item	2658631	et	3	main
koolitati	doc_491521502300_item	2658645	et	4	main
kaotavad	doc_491521502300_item	2658654	et	4	main
rootslased	doc_491521502300_item	2658656	et	3	main
missugune	doc_491521502301_item	2658664	et	3	main
miks	doc_491521502301_item	2658669	et	4	main
võimalikuks	doc_491521502301_item	2658671	et	3	main
linnas	doc_491521502301_item	2658676	et	4	main
vähemuses	doc_491521502301_item	2658681	et	4	main
elas	doc_491521502301_item	2658682	et	3	main
seal	doc_491521502301_item	2658683	et	4	main
ka	doc_491521502301_item	2658684	et	3	main
eestlasi	doc_491521502301_item	2658685	et	3	main
mujalt	doc_491521502301_item	2658686	et	3	main
eesti	doc_491521502301_item	2658692	et	4	main
oli	doc_491521502301_item	2658696	et	3	main
kuna	doc_491521502301_item	2658698	et	3	main
varandust	doc_491521502301_item	2658710	et	3	main
oidusid	doc_491521502301_item	2658713	et	3	main
ja	doc_491521502301_item	2658721	et	3	main
väiksemat	doc_491521502301_item	2658726	et	4	main
viljandi	doc_491521502301_item	2658727	et	4	main
kehtisid	doc_491521502301_item	2658734	et	4	main
kuulus	doc_491521502301_item	2658743	et	4	main
24	doc_491521502301_item	2658744	et	2	main
12	doc_491521502301_item	2658749	et	2	main
otsustas	doc_491521502301_item	2658759	et	3	main
keda	doc_491521502301_item	2658760	et	4	main
võtta	doc_491521502301_item	2658761	et	3	main
ka	doc_491521502301_item	2658765	et	3	main
igal	doc_491521502301_item	2658768	et	3	main
linnal	doc_491521502301_item	2658769	et	3	main
oma	doc_491521502301_item	2658771	et	4	main
olid	doc_491521502301_item	2658779	et	4	main
kuhu	doc_491521502301_item	2658785	et	3	main
palju	doc_491521502301_item	2658795	et	4	main
linnaelanikud	doc_491521502301_item	2658802	et	3	main
põhiliselt	doc_491521502301_item	2658803	et	4	main
tulid	doc_491521502301_item	2658804	et	4	main
piires	doc_491521502301_item	2658811	et	4	main
olid	doc_491521502301_item	2658830	et	4	main
sakslased	doc_491521502301_item	2658831	et	3	main
kaubandus	doc_491521502301_item	2658832	et	3	main
ka	doc_491521502301_item	2658834	et	3	main
eestist	doc_491521502301_item	2658837	et	3	main
ehituseks	doc_491521502301_item	2658846	et	4	main
üldiselt	doc_491521502301_item	2658859	et	4	main
arenes	doc_491521502301_item	2658862	et	3	main
ajal	doc_491521502301_item	2658882	et	4	main
venemaal	doc_491521502301_item	2658883	et	4	main
troonile	doc_491521502301_item	2658884	et	3	main
istus	doc_491521502301_item	2658885	et	4	main
ivan	doc_491521502301_item	2658886	et	4	main
pakus	doc_491521502301_item	2658895	et	3	main
1	doc_491521502301_item	2658912	et	2	main
et	doc_491521502301_item	2658913	et	3	main
seal	doc_491521502301_item	2658914	et	4	main
gootika	doc_491521502300_item	2658522	et	4	main
olid	doc_491521502300_item	2658526	et	4	main
hoonete	doc_491521502300_item	2658529	et	4	main
uhkem	doc_491521502300_item	2658533	et	4	main
stiilis	doc_491521502300_item	2658536	et	4	main
kirjeldab	doc_491521502300_item	2658546	et	3	main
elu	doc_491521502300_item	2658548	et	4	main
ivan	doc_491521502300_item	2658553	et	4	main
venemaa	doc_491521502300_item	2658556	et	4	main
muutus	doc_491521502300_item	2658557	et	4	main
venemaale	doc_491521502300_item	2658564	et	4	main
maksti	doc_491521502300_item	2658565	et	3	main
iv	doc_491521502300_item	2658571	et	4	main
võitles	doc_491521502300_item	2658572	et	3	main
liivimaaga	doc_491521502300_item	2658573	et	3	main
eestiga	doc_491521502300_item	2658574	et	4	main
kiusatakse	doc_491521502300_item	2658575	et	3	main
usklikke	doc_491521502300_item	2658576	et	3	main
oli	doc_491521502300_item	2658577	et	3	main
kauplemine	doc_491521502300_item	2658578	et	4	main
euroopaga	doc_491521502300_item	2658579	et	3	main
a	doc_491521502300_item	2658581	et	4	main
1573	doc_491521502300_item	2658580	et	2	main
ivo	doc_491521502300_item	2658582	et	4	main
schnkenberg	doc_491521502300_item	2658583	et	4	main
viimne	doc_491521502300_item	2658584	et	3	main
reliikvia	doc_491521502300_item	2658585	et	4	main
asub	doc_491521502300_item	2658586	et	3	main
võitlema	doc_491521502300_item	2658587	et	3	main
tatarlaste	doc_491521502300_item	2658588	et	3	main
vastu	doc_491521502300_item	2658589	et	3	main
tatarlased	doc_491521502300_item	2658590	et	3	main
puruksmkivipommidega	doc_491521502300_item	2658599	et	4	main
17saj	doc_491521502300_item	2658600	et	4	main
ajaks	doc_491521502300_item	2658609	et	4	main
kirik	doc_491521502300_item	2658615	et	3	main
tavad	doc_491521502300_item	2658619	et	3	main
gregooriuse	doc_491521502300_item	2658622	et	4	main
jääb	doc_491521502300_item	2658629	et	3	main
1585a	doc_491521502300_item	2658632	et	4	main
ülikooli	doc_491521502300_item	2658638	et	4	main
õpetati	doc_491521502300_item	2658640	et	3	main
läti	doc_491521502300_item	2658643	et	4	main
tõlke	doc_491521502300_item	2658646	et	4	main
poolakad	doc_491521502300_item	2658653	et	4	main
1625a	doc_491521502300_item	2658655	et	4	main
vallutavad	doc_491521502300_item	2658657	et	4	main
oli	doc_491521502301_item	2658665	et	3	main
2	doc_491521502301_item	2658668	et	2	main
vene-liivi	doc_491521502301_item	2658672	et	4	main
tulnud	doc_491521502301_item	2658687	et	4	main
rahvas	doc_491521502301_item	2658688	et	4	main
elas	doc_491521502301_item	2658689	et	3	main
paremini	doc_491521502301_item	2658690	et	4	main
kui	doc_491521502301_item	2658691	et	3	main
käes	doc_491521502301_item	2658695	et	4	main
kullameistrid	doc_491521502301_item	2658705	et	3	main
kuna	doc_491521502301_item	2658706	et	3	main
olid	doc_491521502301_item	2658719	et	4	main
veel	doc_491521502301_item	2658724	et	4	main
paide	doc_491521502301_item	2658731	et	4	main
igas	doc_491521502301_item	2658732	et	3	main
linnas	doc_491521502301_item	2658733	et	4	main
raehärrasid	doc_491521502301_item	2658747	et	3	main
nad	doc_491521502301_item	2658751	et	3	main
linna	doc_491521502301_item	2658762	et	4	main
linnas	doc_491521502301_item	2658778	et	4	main
tsunftid	doc_491521502301_item	2658784	et	3	main
kuigi	doc_491521502301_item	2658792	et	3	main
suri	doc_491521502301_item	2658794	et	3	main
tahtjais	doc_491521502301_item	2658797	et	4	main
vähemaks	doc_491521502301_item	2658798	et	4	main
maalt	doc_491521502301_item	2658805	et	3	main
maaga	doc_491521502301_item	2658806	et	3	main
side	doc_491521502301_item	2658807	et	4	main
hariti	doc_491521502301_item	2658812	et	3	main
oli	doc_491521502301_item	2658817	et	3	main
maahärra	doc_491521502301_item	2658819	et	4	main
linna	doc_491521502301_item	2658825	et	4	main
kuna	doc_491521502301_item	2658827	et	3	main
põhiliselt	doc_491521502301_item	2658828	et	4	main
kaupmehed	doc_491521502301_item	2658829	et	3	main
rukkist	doc_491521502301_item	2658841	et	4	main
ka	doc_491521502301_item	2658842	et	3	main
soola	doc_491521502301_item	2658852	et	4	main
heeringat	doc_491521502301_item	2658853	et	3	main
metalle	doc_491521502301_item	2658857	et	3	main
kaubandus	doc_491521502301_item	2658864	et	3	main
vallutada	doc_491521502301_item	2658892	et	3	main
sellepärast	doc_491521502301_item	2658899	et	3	main
pääs	doc_491521502301_item	2658903	et	3	main
merele	doc_491521502301_item	2658904	et	3	main
põhjust	doc_491521502301_item	2658908	et	4	main
õigeuskliku	doc_491521502301_item	2658917	et	3	main
nad	doc_491521502301_item	2658920	et	3	main
kaubelda	doc_491521502301_item	2658923	et	4	main
3	doc_491521502301_item	2658925	et	2	main
liivimaa	doc_491521502301_item	2658926	et	4	main
grožnõi	doc_491521502301_item	2658936	et	2	main
sõda	doc_491521502301_item	2658939	et	4	main
1	doc_491521502302_item	2658943	et	2	main
oli	doc_491521502302_item	2658945	et	3	main
ristisõdade	doc_491521502302_item	2658958	et	3	main
ja	doc_491521502302_item	2658960	et	3	main
ristiusustamisega	doc_491521502302_item	2658962	et	3	main
eesti	doc_491521502302_item	2658963	et	4	main
palju	doc_491521502302_item	2658966	et	4	main
muistne	doc_491521502302_item	2658968	et	3	main
vikingiajast	doc_491521502302_item	2658971	et	4	main
saatus	doc_491521502302_item	2658974	et	3	main
euroopa	doc_491521502302_item	2658975	et	4	main
kombed	doc_491521502302_item	2658987	et	3	main
hakkasid	doc_491521502302_item	2658989	et	4	main
tuleb	doc_491521502300_item	2658602	et	3	main
rootsi	doc_491521502300_item	2658604	et	4	main
lõuna-eesti	doc_491521502300_item	2658606	et	4	main
läheb	doc_491521502300_item	2658607	et	3	main
mõneks	doc_491521502300_item	2658608	et	3	main
poola	doc_491521502300_item	2658612	et	4	main
kalender	doc_491521502300_item	2658623	et	3	main
päeva	doc_491521502300_item	2658625	et	4	main
2	doc_491521502300_item	2658630	et	2	main
tartu	doc_491521502300_item	2658637	et	4	main
eelkäijaks	doc_491521502300_item	2658639	et	3	main
rahu	doc_491521502300_item	2658661	et	4	main
linnakultuur	doc_491521502301_item	2658667	et	3	main
sai	doc_491521502301_item	2658670	et	4	main
keskajal	doc_491521502301_item	2658675	et	3	main
elasid	doc_491521502301_item	2658703	et	4	main
kaupmehed	doc_491521502301_item	2658704	et	3	main
pidi	doc_491521502301_item	2658708	et	4	main
uhkeid	doc_491521502301_item	2658712	et	4	main
ja	doc_491521502301_item	2658714	et	3	main
ja	doc_491521502301_item	2658723	et	3	main
neli	doc_491521502301_item	2658725	et	3	main
linnas	doc_491521502301_item	2658739	et	4	main
oli	doc_491521502301_item	2658740	et	3	main
raad	doc_491521502301_item	2658741	et	4	main
kuhu	doc_491521502301_item	2658742	et	3	main
oli	doc_491521502301_item	2658748	et	3	main
ja	doc_491521502301_item	2658750	et	3	main
elanikuks	doc_491521502301_item	2658763	et	3	main
kuna	doc_491521502301_item	2658767	et	3	main
raha	doc_491521502301_item	2658772	et	4	main
pidi	doc_491521502301_item	2658774	et	4	main
gildid	doc_491521502301_item	2658782	et	3	main
ei	doc_491521502301_item	2658799	et	4	main
ei	doc_491521502301_item	2658808	et	4	main
linnal	doc_491521502301_item	2658818	et	3	main
kes	doc_491521502301_item	2658820	et	4	main
enne	doc_491521502300_item	2658626	et	4	main
mitmeks	doc_491521502300_item	2658627	et	4	main
jesuiitide	doc_491521502300_item	2658633	et	3	main
seminar	doc_491521502300_item	2658635	et	3	main
keeli	doc_491521502300_item	2658642	et	4	main
eesti	doc_491521502300_item	2658644	et	4	main
misjonäär	doc_491521502300_item	2658647	et	4	main
usk	doc_491521502300_item	2658649	et	3	main
rootsi	doc_491521502300_item	2658650	et	4	main
sõda	doc_491521502300_item	2658652	et	4	main
1	doc_491521502301_item	2658663	et	2	main
keskaegne	doc_491521502301_item	2658666	et	3	main
sõda	doc_491521502301_item	2658673	et	4	main
elasid	doc_491521502301_item	2658677	et	4	main
saksalased	doc_491521502301_item	2658679	et	4	main
sakslaste	doc_491521502301_item	2658694	et	3	main
rikad	doc_491521502301_item	2658701	et	4	main
rikalt	doc_491521502301_item	2658702	et	4	main
omama	doc_491521502301_item	2658709	et	4	main
olema	doc_491521502301_item	2658715	et	4	main
abielumees	doc_491521502301_item	2658716	et	4	main
tähtsamad	doc_491521502301_item	2658717	et	4	main
linnad	doc_491521502301_item	2658718	et	3	main
narva	doc_491521502301_item	2658728	et	4	main
omad	doc_491521502301_item	2658735	et	4	main
seadused	doc_491521502301_item	2658736	et	3	main
raehärrat	doc_491521502301_item	2658745	et	3	main
pidasid	doc_491521502301_item	2658764	et	4	main
oli	doc_491521502301_item	2658770	et	3	main
raha	doc_491521502301_item	2658775	et	4	main
ka	doc_491521502301_item	2658776	et	3	main
mündistama	doc_491521502301_item	2658777	et	4	main
käsitööliste	doc_491521502301_item	2658783	et	4	main
kuulusid	doc_491521502301_item	2658787	et	4	main
eestlased	doc_491521502301_item	2658789	et	3	main
lihttöölised	doc_491521502301_item	2658791	et	3	main
muutunud	doc_491521502301_item	2658800	et	4	main
kuna	doc_491521502301_item	2658801	et	3	main
katkenud	doc_491521502301_item	2658809	et	4	main
põldu	doc_491521502301_item	2658813	et	4	main
taimi	doc_491521502301_item	2658815	et	4	main
väljaspool	doc_491521502301_item	2658835	et	3	main
viidi	doc_491521502301_item	2658838	et	4	main
kivi	doc_491521502301_item	2658845	et	4	main
ja	doc_491521502301_item	2658848	et	3	main
sisse	doc_491521502301_item	2658850	et	4	main
toodi	doc_491521502301_item	2658851	et	4	main
veine	doc_491521502301_item	2658856	et	3	main
jne	doc_491521502301_item	2658858	et	4	main
linnaelu	doc_491521502301_item	2658860	et	4	main
arenes	doc_491521502301_item	2658861	et	3	main
kes	doc_491521502301_item	2658889	et	4	main
väga	doc_491521502301_item	2658890	et	3	main
armastas	doc_491521502301_item	2658891	et	3	main
liivimaa	doc_491521502301_item	2658894	et	4	main
et	doc_491521502301_item	2658900	et	3	main
mittu	doc_491521502301_item	2658907	et	4	main
algatamiseks	doc_491521502301_item	2658911	et	4	main
tartu	doc_491521502301_item	2658722	et	4	main
rapla	doc_491521502301_item	2658729	et	4	main
ja	doc_491521502301_item	2658730	et	3	main
tähtsam	doc_491521502301_item	2658737	et	4	main
võimuorgan	doc_491521502301_item	2658738	et	3	main
hiljem	doc_491521502301_item	2658746	et	3	main
valiti	doc_491521502301_item	2658752	et	3	main
üheks	doc_491521502301_item	2658753	et	3	main
aastaks	doc_491521502301_item	2658754	et	4	main
raad	doc_491521502301_item	2658755	et	4	main
tegeles	doc_491521502301_item	2658756	et	3	main
siseasjadega	doc_491521502301_item	2658757	et	3	main
raad	doc_491521502301_item	2658758	et	4	main
kohut	doc_491521502301_item	2658766	et	3	main
raad	doc_491521502301_item	2658773	et	4	main
ka	doc_491521502301_item	2658780	et	3	main
kaupmeeste	doc_491521502301_item	2658781	et	4	main
põhiliselt	doc_491521502301_item	2658786	et	4	main
sakslased	doc_491521502301_item	2658788	et	3	main
olid	doc_491521502301_item	2658790	et	4	main
linnas	doc_491521502301_item	2658793	et	4	main
inimesi	doc_491521502301_item	2658796	et	4	main
linna	doc_491521502301_item	2658810	et	4	main
kasvatati	doc_491521502301_item	2658814	et	3	main
ka	doc_491521502301_item	2658816	et	3	main
kaubandust	doc_491521502301_item	2658822	et	3	main
toimus	doc_491521502301_item	2658833	et	3	main
eestit	doc_491521502301_item	2658836	et	3	main
kala	doc_491521502301_item	2658843	et	4	main
ka	doc_491521502301_item	2658863	et	3	main
sel	doc_491521502301_item	2658881	et	3	main
ja	doc_491521502301_item	2658893	et	3	main
talle	doc_491521502301_item	2658896	et	4	main
erilist	doc_491521502301_item	2658897	et	4	main
seal	doc_491521502301_item	2658901	et	4	main
oli	doc_491521502301_item	2658902	et	3	main
tõi	doc_491521502301_item	2658906	et	3	main
liivi	doc_491521502301_item	2658909	et	4	main
sõda	doc_491521502301_item	2658910	et	4	main
et	doc_491521502301_item	2658919	et	3	main
ivan	doc_491521502301_item	2658934	et	4	main
koos	doc_491521502302_item	2658957	et	4	main
algusega	doc_491521502302_item	2658959	et	3	main
eestlaste	doc_491521502302_item	2658961	et	4	main
välismaalasi	doc_491521502302_item	2658967	et	3	main
eesti	doc_491521502302_item	2658969	et	4	main
tõid	doc_491521502302_item	2658983	et	4	main
kaasa	doc_491521502302_item	2658985	et	4	main
muistse	doc_491521502302_item	2658996	et	3	main
eesti	doc_491521502302_item	2658997	et	4	main
olid	doc_491521502302_item	2659001	et	4	main
ja	doc_491521502302_item	2659003	et	3	main
samuti	doc_491521502302_item	2659005	et	3	main
ka	doc_491521502302_item	2659006	et	3	main
viljandi	doc_491521502302_item	2659007	et	4	main
raekoda	doc_491521502302_item	2659017	et	4	main
teostas	doc_491521502301_item	2658821	et	3	main
maa	doc_491521502301_item	2658823	et	4	main
ja	doc_491521502301_item	2658824	et	3	main
vahel	doc_491521502301_item	2658826	et	4	main
välja	doc_491521502301_item	2658839	et	4	main
teravilja	doc_491521502301_item	2658840	et	4	main
rasva	doc_491521502301_item	2658844	et	4	main
lina	doc_491521502301_item	2658847	et	4	main
kanepitaimi	doc_491521502301_item	2658849	et	4	main
vürtse	doc_491521502301_item	2658854	et	3	main
humalaid	doc_491521502301_item	2658855	et	3	main
2	doc_491521502301_item	2658865	et	2	main
enne	doc_491521502301_item	2658866	et	4	main
liivi	doc_491521502301_item	2658867	et	4	main
sõda	doc_491521502301_item	2658868	et	4	main
liivimaa	doc_491521502301_item	2658869	et	4	main
aadlikud	doc_491521502301_item	2658870	et	3	main
elasid	doc_491521502301_item	2658871	et	4	main
liiga	doc_491521502301_item	2658872	et	4	main
ja	doc_491521502301_item	2658874	et	3	main
nad	doc_491521502301_item	2658875	et	3	main
hästi	doc_491521502301_item	2658873	et	3	main
muutusid	doc_491521502301_item	2658876	et	4	main
laisaks	doc_491521502301_item	2658877	et	4	main
ja	doc_491521502301_item	2658878	et	3	main
etevaatlikus	doc_491521502301_item	2658879	et	4	main
kadus	doc_491521502301_item	2658880	et	3	main
iv	doc_491521502301_item	2658887	et	4	main
grožnõi	doc_491521502301_item	2658888	et	2	main
huvi	doc_491521502301_item	2658898	et	4	main
ta	doc_491521502301_item	2658905	et	4	main
taga	doc_491521502301_item	2658916	et	4	main
2	doc_491521502301_item	2658918	et	2	main
takkistavad	doc_491521502301_item	2658921	et	4	main
alustas	doc_491521502301_item	2658937	et	3	main
1558	doc_491521502301_item	2658940	et	2	main
keskaegne	doc_491521502302_item	2658946	et	3	main
jõudis	doc_491521502302_item	2658965	et	3	main
saatus	doc_491521502302_item	2658970	et	3	main
1201	doc_491521502302_item	2658992	et	2	main
rajatakse	doc_491521502302_item	2658993	et	4	main
alal	doc_491521502302_item	2658998	et	4	main
olid	doc_491521502302_item	2659015	et	4	main
määrasid	doc_491521502302_item	2659025	et	4	main
kõrguse	doc_491521502302_item	2659028	et	4	main
kui	doc_491521502302_item	2659036	et	3	main
raekoda	doc_491521502302_item	2659037	et	4	main
või	doc_491521502302_item	2659038	et	4	main
toomkirik	doc_491521502302_item	2659039	et	3	main
teed	doc_491521502302_item	2659048	et	4	main
kivist	doc_491521502302_item	2659050	et	4	main
näide	doc_491521502302_item	2659052	et	3	main
linna	doc_491521502302_item	2659059	et	4	main
ja	doc_491521502302_item	2659079	et	3	main
veel	doc_491521502302_item	2659080	et	4	main
piiskopi	doc_491521502302_item	2659084	et	4	main
mille	doc_491521502302_item	2659086	et	3	main
valitsuseks	doc_491521502302_item	2659092	et	4	main
tundja	doc_491521502302_item	2659109	et	4	main
olid	doc_491521502302_item	2659128	et	4	main
rikkastest	doc_491521502302_item	2659132	et	4	main
sakslastest	doc_491521502302_item	2659135	et	3	main
vallalised	doc_491521502302_item	2659141	et	4	main
1	doc_491521502302_item	2659148	et	2	main
seadus	doc_491521502302_item	2659150	et	4	main
selle	doc_491521502302_item	2659153	et	4	main
võis	doc_491521502302_item	2659156	et	4	main
elada	doc_491521502302_item	2659159	et	3	main
kohta	doc_491521502302_item	2659201	et	4	main
on	doc_491521502302_item	2659204	et	4	main
liivimaa	doc_491521502302_item	2659205	et	4	main
kohtus	doc_491521502302_item	2659212	et	4	main
eestikeelseid	doc_491521502302_item	2659214	et	3	main
väljendeid	doc_491521502302_item	2659218	et	3	main
kristlikule	doc_491521502302_item	2659224	et	3	main
suhtes	doc_491521502302_item	2659238	et	4	main
oli	doc_491521502302_item	2659240	et	3	main
linna	doc_491521502302_item	2659244	et	4	main
jaoks	doc_491521502302_item	2659246	et	4	main
all	doc_491521502302_item	2659270	et	3	main
katkud	doc_491521502302_item	2659281	et	4	main
ja	doc_491521502302_item	2659282	et	3	main
õitses	doc_491521502302_item	2659286	et	4	main
vene-liivi	doc_491521502302_item	2659288	et	4	main
võimalikuks	doc_491521502302_item	2659291	et	3	main
tahtis	doc_491521502302_item	2659298	et	3	main
suhetes	doc_491521502302_item	2659308	et	3	main
läbikäiku	doc_491521502302_item	2659313	et	4	main
alguses	doc_491521502302_item	2659321	et	4	main
sõjakäigud	doc_491521502302_item	2659323	et	3	main
venemaale	doc_491521502302_item	2659324	et	4	main
mingit	doc_491521502302_item	2659325	et	3	main
edu	doc_491521502302_item	2659326	et	4	main
venelased	doc_491521502302_item	2659331	et	3	main
välja	doc_491521502302_item	2659333	et	4	main
tartu	doc_491521502302_item	2659335	et	4	main
siinsete	doc_491521502302_item	2659340	et	4	main
1558	doc_491521502302_item	2659346	et	2	main
taani	doc_491521502302_item	2659360	et	4	main
taaniga	doc_491521502302_item	2659380	et	4	main
impeeriumi	doc_491521502302_item	2659397	et	4	main
venelased	doc_491521502302_item	2659403	et	3	main
eesti	doc_491521502302_item	2659412	et	4	main
ainult	doc_491521502302_item	2659416	et	4	main
liusatakse	doc_491521502301_item	2658915	et	3	main
on	doc_491521502301_item	2658927	et	4	main
iidne	doc_491521502301_item	2658928	et	3	main
vene	doc_491521502301_item	2658929	et	4	main
territoorium	doc_491521502301_item	2658930	et	3	main
nende	doc_491521502301_item	2658931	et	4	main
ettekäänete	doc_491521502301_item	2658932	et	3	main
iv	doc_491521502301_item	2658935	et	4	main
liivi	doc_491521502301_item	2658938	et	4	main
kontrolltöö	doc_491521502302_item	2658942	et	4	main
linnakultuur	doc_491521502302_item	2658947	et	3	main
miks	doc_491521502302_item	2658949	et	4	main
keskaega	doc_491521502302_item	2658972	et	4	main
misjonärid	doc_491521502302_item	2658982	et	3	main
endaga	doc_491521502302_item	2658984	et	4	main
linna	doc_491521502302_item	2658995	et	4	main
tähtsamad	doc_491521502302_item	2658999	et	4	main
tartu	doc_491521502302_item	2659004	et	4	main
linnas	doc_491521502302_item	2659014	et	4	main
ja	doc_491521502302_item	2659019	et	3	main
majad	doc_491521502302_item	2659021	et	3	main
tohtinud	doc_491521502302_item	2659033	et	4	main
olla	doc_491521502302_item	2659034	et	3	main
kaitsetonid	doc_491521502302_item	2659042	et	4	main
olid	doc_491521502302_item	2659045	et	4	main
olid	doc_491521502302_item	2659049	et	4	main
hea	doc_491521502302_item	2659051	et	4	main
keskaegsest	doc_491521502302_item	2659053	et	3	main
linnast	doc_491521502302_item	2659054	et	4	main
linnaõigus	doc_491521502302_item	2659071	et	4	main
siinsel	doc_491521502302_item	2659081	et	3	main
koosseisus	doc_491521502302_item	2659096	et	4	main
oli	doc_491521502302_item	2659098	et	3	main
12	doc_491521502302_item	2659101	et	2	main
maahärrad	doc_491521502302_item	2659103	et	3	main
linnafoogt	doc_491521502302_item	2659113	et	3	main
tegevusala	doc_491521502302_item	2659115	et	4	main
kaubandus	doc_491521502302_item	2659117	et	3	main
ühendused	doc_491521502302_item	2659123	et	4	main
suurgild	doc_491521502302_item	2659129	et	3	main
mustpeade	doc_491521502302_item	2659137	et	3	main
gild	doc_491521502302_item	2659138	et	3	main
aasta	doc_491521502302_item	2659146	et	4	main
kohta	doc_491521502302_item	2659167	et	4	main
siit	doc_491521502302_item	2659168	et	3	main
kroonika	doc_491521502302_item	2659207	et	4	main
mis	doc_491521502302_item	2659208	et	4	main
oli	doc_491521502302_item	2659209	et	3	main
ladinakeelne	doc_491521502302_item	2659210	et	3	main
venemaal	doc_491521502301_item	2658922	et	4	main
euroopaga	doc_491521502301_item	2658924	et	3	main
abil	doc_491521502301_item	2658933	et	4	main
aastal	doc_491521502301_item	2658941	et	3	main
missugune	doc_491521502302_item	2658944	et	3	main
2	doc_491521502302_item	2658948	et	2	main
sai	doc_491521502302_item	2658950	et	4	main
võimalikuks	doc_491521502302_item	2658951	et	3	main
vene-liivi	doc_491521502302_item	2658952	et	4	main
sõda	doc_491521502302_item	2658953	et	4	main
1	doc_491521502302_item	2658954	et	2	main
keskaegne	doc_491521502302_item	2658955	et	3	main
linnakultuur	doc_491521502302_item	2658956	et	3	main
aladele	doc_491521502302_item	2658964	et	3	main
ja	doc_491521502302_item	2658973	et	3	main
mõju	doc_491521502302_item	2658976	et	4	main
alla	doc_491521502302_item	2658977	et	3	main
tulnud	doc_491521502302_item	2658978	et	4	main
kaupmehed	doc_491521502302_item	2658979	et	3	main
käsitöölised	doc_491521502302_item	2658980	et	3	main
ja	doc_491521502302_item	2658981	et	3	main
oma	doc_491521502302_item	2658986	et	4	main
kultuuri	doc_491521502302_item	2658988	et	4	main
tekkima	doc_491521502302_item	2658990	et	3	main
linnad	doc_491521502302_item	2658991	et	3	main
linnad	doc_491521502302_item	2659000	et	3	main
tallinn	doc_491521502302_item	2659002	et	4	main
kirikud	doc_491521502302_item	2659016	et	3	main
tööliste	doc_491521502302_item	2659020	et	4	main
ja	doc_491521502302_item	2659023	et	3	main
teiste	doc_491521502302_item	2659026	et	4	main
mitte	doc_491521502302_item	2659029	et	3	main
ehitis	doc_491521502302_item	2659031	et	3	main
linnamüürid	doc_491521502302_item	2659043	et	3	main
on	doc_491521502302_item	2659055	et	4	main
oli	doc_491521502302_item	2659083	et	3	main
linna	doc_491521502302_item	2659091	et	4	main
raad	doc_491521502302_item	2659094	et	4	main
alguses	doc_491521502302_item	2659097	et	4	main
liiget	doc_491521502302_item	2659102	et	3	main
e	doc_491521502302_item	2659105	et	4	main
seaduste	doc_491521502302_item	2659108	et	4	main
esindus	doc_491521502302_item	2659112	et	4	main
ja	doc_491521502302_item	2659118	et	3	main
käsitöö	doc_491521502302_item	2659119	et	4	main
olid	doc_491521502302_item	2659120	et	4	main
riia	doc_491521502302_item	2658994	et	4	main
uus-pärnu	doc_491521502302_item	2659008	et	4	main
ehitusmaterjaliks	doc_491521502302_item	2659009	et	3	main
oli	doc_491521502302_item	2659010	et	3	main
dolomiit	doc_491521502302_item	2659011	et	3	main
telliskivi	doc_491521502302_item	2659012	et	4	main
paekivi	doc_491521502302_item	2659013	et	4	main
kaupmeeste	doc_491521502302_item	2659018	et	4	main
raekoda	doc_491521502302_item	2659024	et	4	main
kõrgem	doc_491521502302_item	2659035	et	4	main
ja	doc_491521502302_item	2659047	et	3	main
vana	doc_491521502302_item	2659057	et	4	main
linn	doc_491521502302_item	2659058	et	3	main
viljandis	doc_491521502302_item	2659076	et	4	main
paides	doc_491521502302_item	2659077	et	4	main
pärnus	doc_491521502302_item	2659078	et	3	main
pärnu	doc_491521502302_item	2659090	et	4	main
rae	doc_491521502302_item	2659095	et	3	main
24	doc_491521502302_item	2659099	et	2	main
hiljem	doc_491521502302_item	2659100	et	3	main
bürgermeistrid	doc_491521502302_item	2659104	et	3	main
raejuhatus	doc_491521502302_item	2659106	et	4	main
sundik	doc_491521502302_item	2659107	et	4	main
maahärrade	doc_491521502302_item	2659111	et	3	main
gildid	doc_491521502302_item	2659121	et	3	main
näiteks	doc_491521502302_item	2659126	et	4	main
siin	doc_491521502302_item	2659127	et	4	main
mis	doc_491521502302_item	2659130	et	4	main
ja	doc_491521502302_item	2659136	et	3	main
kuhu	doc_491521502302_item	2659139	et	3	main
kuulusid	doc_491521502302_item	2659140	et	4	main
kaupmehed	doc_491521502302_item	2659142	et	3	main
1	doc_491521502302_item	2659145	et	2	main
päeva	doc_491521502302_item	2659149	et	4	main
kui	doc_491521502302_item	2659151	et	3	main
inimene	doc_491521502302_item	2659152	et	3	main
linnas	doc_491521502302_item	2659157	et	4	main
välja	doc_491521502302_item	2659158	et	4	main
sai	doc_491521502302_item	2659161	et	4	main
linnakodanik	doc_491521502302_item	2659162	et	3	main
säilis	doc_491521502302_item	2659193	et	4	main
mitu	doc_491521502302_item	2659194	et	4	main
ajaloolist	doc_491521502302_item	2659195	et	4	main
allikat	doc_491521502302_item	2659196	et	3	main
keskaegse	doc_491521502302_item	2659197	et	3	main
henriku	doc_491521502302_item	2659206	et	4	main
kuid	doc_491521502302_item	2659211	et	4	main
sõnu	doc_491521502302_item	2659215	et	4	main
ja	doc_491521502302_item	2659217	et	3	main
b	doc_491521502302_item	2659220	et	4	main
kroonika	doc_491521502302_item	2659222	et	4	main
majanduse	doc_491521502302_item	2659237	et	4	main
keskaeg	doc_491521502302_item	2659239	et	3	main
arenes	doc_491521502302_item	2659247	et	3	main
et	doc_491521502302_item	2659262	et	3	main
arenes	doc_491521502302_item	2659265	et	3	main
ja	doc_491521502302_item	2659267	et	3	main
gooti	doc_491521502302_item	2659272	et	4	main
ja	doc_491521502302_item	2659274	et	3	main
stiilis	doc_491521502302_item	2659276	et	4	main
linnaelu	doc_491521502302_item	2659285	et	4	main
sõda	doc_491521502302_item	2659289	et	4	main
riik	doc_491521502302_item	2659297	et	3	main
oma	doc_491521502302_item	2659299	et	4	main
laiendada	doc_491521502302_item	2659301	et	3	main
liivimaa	doc_491521502302_item	2659302	et	4	main
oli	doc_491521502302_item	2659303	et	3	main
ja	doc_491521502302_item	2659306	et	3	main
aga	doc_491521502302_item	2659310	et	3	main
tahtis	doc_491521502302_item	2659312	et	3	main
ei	doc_491521502302_item	2659327	et	4	main
toonud	doc_491521502302_item	2659328	et	4	main
maksmist	doc_491521502302_item	2659337	et	4	main
aastal	doc_491521502302_item	2659347	et	3	main
aladelt	doc_491521502302_item	2659357	et	3	main
tugevnev	doc_491521502302_item	2659365	et	4	main
kes	doc_491521502302_item	2659367	et	4	main
liivi	doc_491521502302_item	2659371	et	4	main
sõja	doc_491521502302_item	2659372	et	3	main
7-aastane	doc_491521502302_item	2659378	et	4	main
lõuna-eesti	doc_491521502302_item	2659384	et	4	main
ülemvõimu	doc_491521502302_item	2659387	et	4	main
kirik	doc_491521502302_item	2659022	et	3	main
ehitiste	doc_491521502302_item	2659027	et	3	main
mingi	doc_491521502302_item	2659030	et	4	main
ei	doc_491521502302_item	2659032	et	4	main
peakirik	doc_491521502302_item	2659040	et	3	main
olid	doc_491521502302_item	2659041	et	4	main
tänavad	doc_491521502302_item	2659044	et	4	main
kitsad	doc_491521502302_item	2659046	et	3	main
meie	doc_491521502302_item	2659056	et	4	main
korra	doc_491521502302_item	2659060	et	4	main
määras	doc_491521502302_item	2659061	et	4	main
linna	doc_491521502302_item	2659062	et	4	main
õigus	doc_491521502302_item	2659063	et	4	main
tallinnas	doc_491521502302_item	2659065	et	4	main
rakveres	doc_491521502302_item	2659066	et	4	main
ja	doc_491521502302_item	2659067	et	3	main
näiteks	doc_491521502302_item	2659064	et	4	main
narvas	doc_491521502302_item	2659068	et	4	main
oli	doc_491521502302_item	2659069	et	3	main
lüübeki	doc_491521502302_item	2659070	et	4	main
riia	doc_491521502302_item	2659072	et	4	main
linnaõigus	doc_491521502302_item	2659073	et	4	main
oli	doc_491521502302_item	2659074	et	3	main
tartus	doc_491521502302_item	2659075	et	3	main
aladel	doc_491521502302_item	2659082	et	3	main
linnaõigus	doc_491521502302_item	2659085	et	4	main
said	doc_491521502302_item	2659087	et	4	main
haapsalu	doc_491521502302_item	2659088	et	4	main
ja	doc_491521502302_item	2659089	et	3	main
oli	doc_491521502302_item	2659093	et	3	main
ja	doc_491521502302_item	2659110	et	3	main
tähtis	doc_491521502302_item	2659114	et	4	main
oli	doc_491521502302_item	2659116	et	3	main
ühendused	doc_491521502302_item	2659125	et	4	main
kaupmeestest	doc_491521502302_item	2659133	et	4	main
linnas	doc_491521502302_item	2659143	et	4	main
kehtis	doc_491521502302_item	2659144	et	3	main
ja	doc_491521502302_item	2659147	et	3	main
jooksul	doc_491521502302_item	2659155	et	4	main
temast	doc_491521502302_item	2659160	et	3	main
see	doc_491521502302_item	2659163	et	3	main
kehtis	doc_491521502302_item	2659164	et	3	main
näiteks	doc_491521502302_item	2659165	et	4	main
talupoegade	doc_491521502302_item	2659166	et	3	main
linnaelu	doc_491521502302_item	2659198	et	4	main
ja	doc_491521502302_item	2659199	et	3	main
head	doc_491521502302_item	2659202	et	4	main
holnrike	doc_491521502302_item	2659219	et	4	main
tänu	doc_491521502302_item	2659223	et	4	main
usule	doc_491521502302_item	2659225	et	3	main
aladel	doc_491521502302_item	2659227	et	3	main
lugemisoskus	doc_491521502302_item	2659229	et	3	main
soode	doc_491521502302_item	2659242	et	3	main
kaubandus	doc_491521502302_item	2659248	et	3	main
kaupmehed	doc_491521502302_item	2659249	et	3	main
tulusid	doc_491521502302_item	2659251	et	4	main
mille	doc_491521502302_item	2659252	et	3	main
võib	doc_491521502302_item	2659260	et	3	main
keskaegne	doc_491521502302_item	2659263	et	3	main
kiiresti	doc_491521502302_item	2659266	et	3	main
ja	doc_491521502302_item	2659280	et	3	main
teised	doc_491521502302_item	2659283	et	4	main
2	doc_491521502302_item	2659287	et	2	main
16	doc_491521502302_item	2659293	et	2	main
sajandil	doc_491521502302_item	2659294	et	3	main
tugenenud	doc_491521502302_item	2659295	et	4	main
feodaalselt	doc_491521502302_item	2659304	et	4	main
läänemere	doc_491521502302_item	2659314	et	3	main
juurde	doc_491521502302_item	2659315	et	4	main
teha	doc_491521502302_item	2659317	et	3	main
16	doc_491521502302_item	2659319	et	2	main
saj	doc_491521502302_item	2659320	et	4	main
kaupmeeste	doc_491521502302_item	2659122	et	4	main
tsunftide	doc_491521502302_item	2659124	et	3	main
koosnes	doc_491521502302_item	2659131	et	3	main
peamiselt	doc_491521502302_item	2659134	et	4	main
perioodi	doc_491521502302_item	2659154	et	4	main
ka	doc_491521502302_item	2659169	et	3	main
väljend	doc_491521502302_item	2659170	et	3	main
vaba	doc_491521502302_item	2659171	et	4	main
linna	doc_491521502302_item	2659172	et	4	main
õhk	doc_491521502302_item	2659173	et	3	main
vaimuelu	doc_491521502302_item	2659174	et	4	main
keskendus	doc_491521502302_item	2659175	et	4	main
ka	doc_491521502302_item	2659176	et	3	main
linnas	doc_491521502302_item	2659177	et	4	main
siin	doc_491521502302_item	2659178	et	4	main
olid	doc_491521502302_item	2659179	et	4	main
kirikud	doc_491521502302_item	2659180	et	3	main
kloostrid	doc_491521502302_item	2659181	et	3	main
mille	doc_491521502302_item	2659182	et	3	main
juures	doc_491521502302_item	2659183	et	4	main
rajati	doc_491521502302_item	2659184	et	3	main
koole	doc_491521502302_item	2659185	et	4	main
õpetati	doc_491521502302_item	2659186	et	3	main
lugemist	doc_491521502302_item	2659187	et	4	main
tänu	doc_491521502302_item	2659189	et	4	main
jumalasõna	doc_491521502302_item	2659188	et	4	main
õpetatud	doc_491521502302_item	2659190	et	4	main
inimestele	doc_491521502302_item	2659191	et	3	main
meil	doc_491521502302_item	2659192	et	4	main
eluviisi	doc_491521502302_item	2659200	et	4	main
näided	doc_491521502302_item	2659203	et	4	main
ka	doc_491521502302_item	2659213	et	3	main
lauseid	doc_491521502302_item	2659216	et	3	main
russovi	doc_491521502302_item	2659221	et	4	main
levis	doc_491521502302_item	2659228	et	4	main
rootsi	doc_491521502302_item	2659231	et	4	main
võib	doc_491521502302_item	2659233	et	3	main
periood	doc_491521502302_item	2659243	et	3	main
said	doc_491521502302_item	2659250	et	4	main
öelda	doc_491521502302_item	2659261	et	4	main
linnakultuur	doc_491521502302_item	2659264	et	3	main
euroopa	doc_491521502302_item	2659268	et	4	main
mõju	doc_491521502302_item	2659269	et	4	main
romaani	doc_491521502302_item	2659273	et	4	main
hilisgooti	doc_491521502302_item	2659275	et	4	main
kuigi	doc_491521502302_item	2659277	et	3	main
vene	doc_491521502302_item	2659296	et	4	main
killustatud	doc_491521502302_item	2659305	et	4	main
omavahelistes	doc_491521502302_item	2659307	et	4	main
idanaaber	doc_491521502302_item	2659311	et	3	main
endale	doc_491521502302_item	2659316	et	4	main
venemaa	doc_491521502302_item	2659322	et	4	main
sellepärast	doc_491521502302_item	2659330	et	3	main
oli	doc_491521502302_item	2659339	et	3	main
võimude	doc_491521502302_item	2659341	et	3	main
nii	doc_491521502302_item	2659345	et	3	main
alustasid	doc_491521502302_item	2659349	et	4	main
vaid	doc_491521502302_item	2659358	et	3	main
rjetzpospolita	doc_491521502302_item	2659363	et	4	main
mille	doc_491521502302_item	2659374	et	3	main
ka	doc_491521502302_item	2659377	et	3	main
sõna	doc_491521502302_item	2659379	et	4	main
oliwa	doc_491521502302_item	2659390	et	4	main
koosseisu	doc_491521502302_item	2659398	et	4	main
tegi	doc_491521502302_item	2659399	et	4	main
läänemere	doc_491521502302_item	2659400	et	3	main
oma	doc_491521502302_item	2659401	et	4	main
sisemereks	doc_491521502302_item	2659402	et	3	main
kaotajateks	doc_491521502302_item	2659405	et	4	main
saj	doc_491521502302_item	2659409	et	4	main
proovisid	doc_491521502302_item	2659410	et	4	main
eduta	doc_491521502302_item	2659413	et	4	main
1	doc_491521502303_item	2659420	et	2	main
soodustas	doc_491521502303_item	2659422	et	3	main
oli	doc_491521502303_item	2659429	et	3	main
kirik	doc_491521502303_item	2659433	et	3	main
oma	doc_491521502303_item	2659437	et	4	main
kogukondlased	doc_491521502303_item	2659438	et	3	main
eestlased	doc_491521502303_item	2659439	et	3	main
säilisid	doc_491521502303_item	2659448	et	4	main
omandasid	doc_491521502303_item	2659454	et	4	main
välisid	doc_491521502303_item	2659457	et	4	main
pühakute	doc_491521502303_item	2659469	et	3	main
külakatoliiklus	doc_491521502303_item	2659478	et	4	main
katolikud	doc_491521502303_item	2659487	et	4	main
tavad	doc_491521502303_item	2659493	et	3	main
maagiaga	doc_491521502303_item	2659495	et	3	main
üha	doc_491521502303_item	2659505	et	3	main
küladesse	doc_491521502303_item	2659522	et	3	main
umbes	doc_491521502303_item	2659524	et	4	main
käsku	doc_491521502303_item	2659536	et	4	main
külas	doc_491521502303_item	2659538	et	3	main
välja	doc_491521502303_item	2659541	et	4	main
sai	doc_491521502303_item	2659543	et	4	main
said	doc_491521502303_item	2659562	et	4	main
ka	doc_491521502303_item	2659567	et	3	main
sai	doc_491521502303_item	2659576	et	4	main
ise	doc_491521502303_item	2659613	et	4	main
siinsel	doc_491521502302_item	2659226	et	3	main
eriti	doc_491521502302_item	2659230	et	3	main
ajal	doc_491521502302_item	2659232	et	4	main
öelda	doc_491521502302_item	2659234	et	4	main
et	doc_491521502302_item	2659235	et	3	main
ka	doc_491521502302_item	2659236	et	3	main
päris	doc_491521502302_item	2659241	et	4	main
elanikute	doc_491521502302_item	2659245	et	4	main
arvel	doc_491521502302_item	2659253	et	4	main
arenes	doc_491521502302_item	2659254	et	3	main
ka	doc_491521502302_item	2659255	et	3	main
linn	doc_491521502302_item	2659256	et	3	main
üldiselt	doc_491521502302_item	2659257	et	4	main
ja	doc_491521502302_item	2659258	et	3	main
kokkuvõttes	doc_491521502302_item	2659259	et	3	main
ehitised	doc_491521502302_item	2659271	et	3	main
olid	doc_491521502302_item	2659278	et	4	main
ikaldused	doc_491521502302_item	2659279	et	4	main
haigused	doc_491521502302_item	2659284	et	4	main
sai	doc_491521502302_item	2659290	et	4	main
sest	doc_491521502302_item	2659292	et	4	main
territooriumi	doc_491521502302_item	2659300	et	4	main
nõrk	doc_491521502302_item	2659309	et	3	main
tegelikult	doc_491521502302_item	2659318	et	4	main
ja	doc_491521502302_item	2659329	et	3	main
see	doc_491521502302_item	2659338	et	3	main
jaoks	doc_491521502302_item	2659342	et	4	main
ja	doc_491521502302_item	2659344	et	3	main
venelased	doc_491521502302_item	2659348	et	3	main
ka	doc_491521502302_item	2659359	et	3	main
poola-	doc_491521502302_item	2659361	et	4	main
leedu	doc_491521502302_item	2659362	et	4	main
tulemusena	doc_491521502302_item	2659373	et	3	main
ja	doc_491521502302_item	2659381	et	3	main
rahuga	doc_491521502302_item	2659391	et	3	main
õnnestus	doc_491521502302_item	2659415	et	4	main
põhjasõda	doc_491521502302_item	2659418	et	4	main
säilimist	doc_491521502303_item	2659424	et	4	main
juures	doc_491521502303_item	2659426	et	4	main
2	doc_491521502303_item	2659427	et	2	main
liit	doc_491521502303_item	2659431	et	3	main
teeb	doc_491521502303_item	2659434	et	3	main
talupoegadest	doc_491521502303_item	2659436	et	3	main
katoliku	doc_491521502303_item	2659455	et	3	main
kiriku	doc_491521502303_item	2659456	et	3	main
kombed	doc_491521502303_item	2659458	et	3	main
kirikus	doc_491521502303_item	2659459	et	3	main
käimine	doc_491521502303_item	2659460	et	4	main
pühakute	doc_491521502303_item	2659461	et	3	main
säilmete	doc_491521502303_item	2659462	et	3	main
austamine	doc_491521502303_item	2659463	et	4	main
talupoegadele	doc_491521502303_item	2659464	et	3	main
meeldis	doc_491521502303_item	2659465	et	3	main
ka	doc_491521502303_item	2659466	et	3	main
austamise	doc_491521502303_item	2659470	et	4	main
polnud	doc_491521502303_item	2659472	et	3	main
midagi	doc_491521502303_item	2659474	et	4	main
eestlaste	doc_491521502303_item	2659475	et	4	main
usund	doc_491521502303_item	2659476	et	3	main
ja	doc_491521502303_item	2659483	et	3	main
ka	doc_491521502303_item	2659486	et	3	main
kombed	doc_491521502303_item	2659489	et	3	main
paljud	doc_491521502303_item	2659491	et	3	main
saadeti	doc_491521502303_item	2659521	et	3	main
rändmungad	doc_491521502303_item	2659523	et	3	main
aastastele	doc_491521502303_item	2659526	et	4	main
hakati	doc_491521502303_item	2659528	et	3	main
õpetama	doc_491521502303_item	2659529	et	3	main
elementaarselt	doc_491521502303_item	2659530	et	4	main
piiblit	doc_491521502303_item	2659531	et	3	main
10	doc_491521502303_item	2659535	et	2	main
õpetati	doc_491521502303_item	2659537	et	3	main
talupoeg	doc_491521502303_item	2659540	et	3	main
nt	doc_491521502303_item	2659545	et	4	main
kristlikult	doc_491521502303_item	2659558	et	4	main
matta	doc_491521502303_item	2659559	et	3	main
tööd	doc_491521502303_item	2659563	et	4	main
johan	doc_491521502303_item	2659569	et	4	main
kellest	doc_491521502303_item	2659575	et	4	main
saksa	doc_491521502303_item	2659610	et	4	main
hansa	doc_491521502303_item	2659619	et	4	main
taani	doc_491521502303_item	2659622	et	4	main
ja	doc_491521502303_item	2659624	et	3	main
teiste	doc_491521502303_item	2659625	et	4	main
ja	doc_491521502303_item	2659639	et	3	main
taotlesid	doc_491521502303_item	2659642	et	4	main
osasaamist	doc_491521502303_item	2659644	et	4	main
hansa	doc_491521502303_item	2659645	et	4	main
liitu	doc_491521502303_item	2659646	et	4	main
samuti	doc_491521502303_item	2659651	et	3	main
mis	doc_491521502304_item	2659662	et	4	main
soodustas	doc_491521502304_item	2659663	et	3	main
muinasusundi	doc_491521502304_item	2659664	et	3	main
säilimist	doc_491521502304_item	2659665	et	4	main
1	doc_491521502304_item	2659673	et	2	main
mõtlesid	doc_491521502302_item	2659332	et	4	main
nn	doc_491521502302_item	2659334	et	4	main
maksu	doc_491521502302_item	2659336	et	4	main
põhjendamatu	doc_491521502302_item	2659343	et	4	main
sõda	doc_491521502302_item	2659350	et	4	main
mitte	doc_491521502302_item	2659352	et	3	main
kuigi	doc_491521502302_item	2659351	et	3	main
ainult	doc_491521502302_item	2659353	et	4	main
venemaa	doc_491521502302_item	2659354	et	4	main
unistas	doc_491521502302_item	2659355	et	3	main
eesti	doc_491521502302_item	2659356	et	4	main
ning	doc_491521502302_item	2659364	et	3	main
rootsi	doc_491521502302_item	2659366	et	4	main
hiljem	doc_491521502302_item	2659368	et	3	main
kehtestas	doc_491521502302_item	2659369	et	3	main
siin	doc_491521502302_item	2659370	et	4	main
sees	doc_491521502302_item	2659375	et	4	main
oli	doc_491521502302_item	2659376	et	3	main
kokkupõrked	doc_491521502302_item	2659382	et	3	main
poolaga	doc_491521502302_item	2659383	et	3	main
pärast	doc_491521502302_item	2659385	et	4	main
oma	doc_491521502302_item	2659386	et	4	main
kui	doc_491521502302_item	2659392	et	3	main
ka	doc_491521502302_item	2659395	et	3	main
jäid	doc_491521502302_item	2659404	et	4	main
kuigi	doc_491521502302_item	2659406	et	3	main
17	doc_491521502302_item	2659408	et	2	main
pärast	doc_491521502302_item	2659417	et	4	main
mis	doc_491521502303_item	2659428	et	4	main
sunniviisiliselt	doc_491521502303_item	2659435	et	4	main
säilitasid	doc_491521502303_item	2659440	et	4	main
aga	doc_491521502303_item	2659441	et	3	main
oma	doc_491521502303_item	2659442	et	4	main
kombed	doc_491521502303_item	2659443	et	3	main
ja	doc_491521502303_item	2659444	et	3	main
tavad	doc_491521502303_item	2659445	et	3	main
osad	doc_491521502303_item	2659446	et	3	main
isegi	doc_491521502303_item	2659450	et	4	main
eestlased	doc_491521502303_item	2659453	et	3	main
õnnistamine	doc_491521502303_item	2659468	et	4	main
vastu	doc_491521502303_item	2659471	et	3	main
neil	doc_491521502303_item	2659473	et	4	main
säilitati	doc_491521502303_item	2659480	et	3	main
võeti	doc_491521502303_item	2659484	et	3	main
seostati	doc_491521502303_item	2659494	et	3	main
säilisid	doc_491521502303_item	2659496	et	4	main
meie	doc_491521502303_item	2659532	et	4	main
üks	doc_491521502303_item	2659539	et	3	main
kes	doc_491521502303_item	2659542	et	4	main
lapsi	doc_491521502303_item	2659547	et	4	main
haiget	doc_491521502303_item	2659549	et	3	main
olid	doc_491521502303_item	2659550	et	4	main
ja	doc_491521502303_item	2659551	et	3	main
kirikus	doc_491521502303_item	2659564	et	3	main
rändmunkadena	doc_491521502303_item	2659568	et	3	main
pulck	doc_491521502303_item	2659570	et	4	main
esimene	doc_491521502303_item	2659572	et	3	main
talupojast	doc_491521502303_item	2659573	et	4	main
eestlane	doc_491521502303_item	2659574	et	3	main
orduriiri	doc_491521502303_item	2659607	et	4	main
linnad	doc_491521502303_item	2659608	et	3	main
suurkaupmeheks	doc_491521502303_item	2659614	et	3	main
kontrolli	doc_491521502303_item	2659620	et	4	main
all	doc_491521502303_item	2659621	et	3	main
sisemaal	doc_491521502303_item	2659634	et	4	main
ning	doc_491521502303_item	2659635	et	3	main
jõekaubandus	doc_491521502303_item	2659636	et	3	main
polotski	doc_491521502303_item	2659640	et	4	main
müüavisi	doc_491521502303_item	2659659	et	4	main
kontrolltöö	doc_491521502304_item	2659660	et	4	main
1	doc_491521502304_item	2659661	et	2	main
liit	doc_491521502304_item	2659672	et	3	main
katoliku	doc_491521502304_item	2659680	et	3	main
usk	doc_491521502304_item	2659681	et	3	main
eestlaste	doc_491521502304_item	2659683	et	4	main
olid	doc_491521502304_item	2659689	et	4	main
jumalad	doc_491521502304_item	2659693	et	3	main
ladina	doc_491521502304_item	2659723	et	4	main
kõigi	doc_491521502304_item	2659736	et	4	main
kõik	doc_491521502304_item	2659748	et	4	main
joonde	doc_491521502304_item	2659753	et	4	main
oma	doc_491521502304_item	2659757	et	4	main
nii	doc_491521502304_item	2659759	et	3	main
puudus	doc_491521502304_item	2659762	et	4	main
pidev	doc_491521502304_item	2659764	et	3	main
kontroll	doc_491521502304_item	2659765	et	3	main
ka	doc_491521502304_item	2659771	et	3	main
ei	doc_491521502304_item	2659781	et	4	main
või	doc_491521502304_item	2659782	et	4	main
üht	doc_491521502304_item	2659783	et	3	main
erinevate	doc_491521502304_item	2659831	et	4	main
ja	doc_491521502304_item	2659835	et	3	main
sarnanes	doc_491521502304_item	2659838	et	3	main
ja	doc_491521502302_item	2659388	et	3	main
1661a	doc_491521502302_item	2659389	et	4	main
ruhnu	doc_491521502302_item	2659393	et	4	main
sai	doc_491521502302_item	2659394	et	4	main
rootsi	doc_491521502302_item	2659396	et	4	main
pärast	doc_491521502302_item	2659407	et	4	main
vallutada	doc_491521502302_item	2659411	et	3	main
mis	doc_491521502302_item	2659414	et	4	main
kontrolltöö	doc_491521502303_item	2659419	et	4	main
mis	doc_491521502303_item	2659421	et	4	main
muinasusundi	doc_491521502303_item	2659423	et	3	main
eestlaste	doc_491521502303_item	2659425	et	4	main
hansa	doc_491521502303_item	2659430	et	4	main
neist	doc_491521502303_item	2659447	et	4	main
sajni	doc_491521502303_item	2659452	et	4	main
n-ö	doc_491521502303_item	2659477	et	4	main
uskumused	doc_491521502303_item	2659490	et	3	main
kiriklikud	doc_491521502303_item	2659492	et	4	main
veritasu	doc_491521502303_item	2659497	et	4	main
ja	doc_491521502303_item	2659498	et	3	main
naisetõmbamine	doc_491521502303_item	2659499	et	3	main
need	doc_491521502303_item	2659500	et	3	main
ajapikku	doc_491521502303_item	2659501	et	3	main
hääbusid	doc_491521502303_item	2659502	et	4	main
jutlustel	doc_491521502303_item	2659503	et	3	main
katoliku	doc_491521502303_item	2659432	et	3	main
1718	doc_491521502303_item	2659449	et	2	main
19	doc_491521502303_item	2659451	et	2	main
pühitsemine	doc_491521502303_item	2659467	et	4	main
st	doc_491521502303_item	2659479	et	3	main
oma	doc_491521502303_item	2659481	et	4	main
usk	doc_491521502303_item	2659482	et	3	main
üle	doc_491521502303_item	2659485	et	3	main
tavad	doc_491521502303_item	2659488	et	3	main
hakati	doc_491521502303_item	2659504	et	3	main
rohkem	doc_491521502303_item	2659506	et	4	main
käima	doc_491521502303_item	2659507	et	4	main
kui	doc_491521502303_item	2659508	et	3	main
pühapäevased	doc_491521502303_item	2659509	et	4	main
jutlused	doc_491521502303_item	2659510	et	3	main
hakkasid	doc_491521502303_item	2659511	et	4	main
eesti	doc_491521502303_item	2659512	et	4	main
keeles	doc_491521502303_item	2659513	et	4	main
olema	doc_491521502303_item	2659514	et	4	main
et	doc_491521502303_item	2659515	et	3	main
usust	doc_491521502303_item	2659516	et	3	main
paremini	doc_491521502303_item	2659517	et	4	main
talupojad	doc_491521502303_item	2659518	et	4	main
aru	doc_491521502303_item	2659519	et	4	main
saaksid	doc_491521502303_item	2659520	et	4	main
isa	doc_491521502303_item	2659533	et	4	main
ristida	doc_491521502303_item	2659544	et	4	main
tõenäoliselt	doc_491521502303_item	2659552	et	4	main
varsti	doc_491521502303_item	2659553	et	3	main
suri	doc_491521502303_item	2659554	et	3	main
et	doc_491521502303_item	2659555	et	3	main
ta	doc_491521502303_item	2659556	et	4	main
siis	doc_491521502303_item	2659557	et	3	main
tõlkidena	doc_491521502303_item	2659566	et	3	main
teadaolevalt	doc_491521502303_item	2659571	et	4	main
preisimaal	doc_491521502303_item	2659609	et	4	main
kogu	doc_491521502303_item	2659615	et	4	main
läänemere	doc_491521502303_item	2659616	et	3	main
kaubandus	doc_491521502303_item	2659617	et	3	main
oli	doc_491521502303_item	2659618	et	3	main
rootsi	doc_491521502303_item	2659623	et	4	main
maade	doc_491521502303_item	2659626	et	3	main
konkurents	doc_491521502303_item	2659627	et	3	main
suudeti	doc_491521502303_item	2659628	et	3	main
vaos	doc_491521502303_item	2659629	et	3	main
hoida	doc_491521502303_item	2659630	et	3	main
hansakaupmeestel	doc_491521502303_item	2659631	et	4	main
vilniuse	doc_491521502303_item	2659637	et	4	main
pealinnaks	doc_491521502303_item	2659647	et	4	main
lübecki	doc_491521502303_item	2659650	et	4	main
juures	doc_491521502304_item	2659667	et	4	main
2	doc_491521502304_item	2659668	et	2	main
mis	doc_491521502304_item	2659669	et	4	main
see	doc_491521502304_item	2659678	et	3	main
pühakud	doc_491521502304_item	2659688	et	3	main
pealegi	doc_491521502304_item	2659700	et	4	main
nõuti	doc_491521502304_item	2659701	et	3	main
katoliku	doc_491521502304_item	2659702	et	3	main
kiriku	doc_491521502304_item	2659703	et	3	main
ainult	doc_491521502304_item	2659706	et	4	main
kirikuskäimine	doc_491521502304_item	2659708	et	4	main
laulatus	doc_491521502304_item	2659710	et	4	main
see	doc_491521502304_item	2659721	et	3	main
ja	doc_491521502304_item	2659725	et	3	main
seega	doc_491521502304_item	2659726	et	4	main
jäid	doc_491521502304_item	2659727	et	4	main
11	doc_491521502303_item	2659525	et	2	main
lastele	doc_491521502303_item	2659527	et	4	main
palvet	doc_491521502303_item	2659534	et	3	main
sündinud	doc_491521502303_item	2659546	et	4	main
kes	doc_491521502303_item	2659548	et	4	main
mitmed	doc_491521502303_item	2659560	et	4	main
eestlased	doc_491521502303_item	2659561	et	3	main
peamiselt	doc_491521502303_item	2659565	et	4	main
kõrge	doc_491521502303_item	2659577	et	4	main
vaimulik	doc_491521502303_item	2659578	et	3	main
1509	doc_491521502303_item	2659579	et	2	main
aastal	doc_491521502303_item	2659580	et	3	main
võetakse	doc_491521502303_item	2659581	et	3	main
vastu	doc_491521502303_item	2659582	et	3	main
rostocki	doc_491521502303_item	2659583	et	4	main
ülikooli	doc_491521502303_item	2659584	et	4	main
tuleb	doc_491521502303_item	2659585	et	3	main
eestisse	doc_491521502303_item	2659586	et	4	main
ja	doc_491521502303_item	2659587	et	3	main
saab	doc_491521502303_item	2659588	et	3	main
tööd	doc_491521502303_item	2659589	et	4	main
notarina	doc_491521502303_item	2659590	et	3	main
2põhja	doc_491521502303_item	2659591	et	4	main
saksamaa	doc_491521502303_item	2659592	et	4	main
ning	doc_491521502303_item	2659593	et	3	main
läänemere	doc_491521502303_item	2659594	et	3	main
maade	doc_491521502303_item	2659595	et	3	main
kaubalinnu	doc_491521502303_item	2659596	et	4	main
ühendas	doc_491521502303_item	2659597	et	3	main
hansa	doc_491521502303_item	2659598	et	4	main
liit	doc_491521502303_item	2659599	et	3	main
kuhu	doc_491521502303_item	2659600	et	3	main
kuulusid	doc_491521502303_item	2659601	et	4	main
ka	doc_491521502303_item	2659602	et	3	main
12	doc_491521502303_item	2659603	et	2	main
liivimaa	doc_491521502303_item	2659604	et	4	main
linna	doc_491521502303_item	2659605	et	4	main
ja	doc_491521502303_item	2659606	et	3	main
ordu	doc_491521502303_item	2659611	et	4	main
oli	doc_491521502303_item	2659612	et	3	main
keelati	doc_491521502303_item	2659632	et	4	main
kauplemine	doc_491521502303_item	2659633	et	4	main
kaupmehed	doc_491521502303_item	2659641	et	3	main
tuludest	doc_491521502303_item	2659643	et	3	main
võib	doc_491521502303_item	2659648	et	3	main
nimetada	doc_491521502303_item	2659649	et	3	main
mida	doc_491521502303_item	2659658	et	4	main
eestlaste	doc_491521502304_item	2659666	et	4	main
hansa	doc_491521502304_item	2659671	et	4	main
muinasusundi	doc_491521502304_item	2659674	et	3	main
et	doc_491521502304_item	2659679	et	3	main
erinevad	doc_491521502304_item	2659692	et	4	main
kommete	doc_491521502304_item	2659704	et	4	main
surnute	doc_491521502304_item	2659711	et	4	main
pühale	doc_491521502304_item	2659713	et	3	main
oli	doc_491521502304_item	2659722	et	3	main
põhjus	doc_491521502304_item	2659732	et	4	main
palju	doc_491521502304_item	2659744	et	4	main
polnud	doc_491521502304_item	2659745	et	3	main
nii	doc_491521502304_item	2659746	et	3	main
kirik	doc_491521502304_item	2659754	et	3	main
haldusalas	doc_491521502304_item	2659758	et	3	main
ka	doc_491521502304_item	2659763	et	3	main
olukorra	doc_491521502304_item	2659766	et	3	main
lihtsalt	doc_491521502304_item	2659774	et	4	main
ei	doc_491521502304_item	2659775	et	4	main
jõudnud	doc_491521502304_item	2659776	et	4	main
nad	doc_491521502304_item	2659780	et	3	main
teist	doc_491521502304_item	2659785	et	4	main
asja	doc_491521502304_item	2659786	et	4	main
korraldada	doc_491521502304_item	2659787	et	3	main
oma	doc_491521502304_item	2659788	et	4	main
reliikviad	doc_491521502304_item	2659821	et	3	main
austamine	doc_491521502304_item	2659823	et	4	main
oli	doc_491521502304_item	2659826	et	3	main
pühakute	doc_491521502304_item	2659833	et	3	main
õnnistamine	doc_491521502304_item	2659837	et	4	main
eesti	doc_491521502304_item	2659839	et	4	main
üht-teist	doc_491521502304_item	2659847	et	4	main
juurde	doc_491521502304_item	2659848	et	4	main
aluseks	doc_491521502304_item	2659868	et	4	main
linna	doc_491521502304_item	2659871	et	4	main
juhtimiskeskused	doc_491521502304_item	2659892	et	3	main
kvaliteetkangast	doc_491521502304_item	2659895	et	4	main
saanud	doc_491521502304_item	2659903	et	4	main
läks	doc_491521502304_item	2659906	et	3	main
natuke	doc_491521502304_item	2659912	et	4	main
hli	doc_491521502304_item	2659918	et	4	main
õitseajaga	doc_491521502304_item	2659919	et	3	main
oli	doc_491521502304_item	2659922	et	3	main
poolest	doc_491521502304_item	2659925	et	4	main
talupojad	doc_491521502304_item	2659929	et	4	main
kontrolltöö	doc_491521502305_item	2659933	et	4	main
1	doc_491521502305_item	2659934	et	2	main
oli	doc_491521502305_item	2659943	et	3	main
elanike	doc_491521502305_item	2659947	et	3	main
eestimaal	doc_491521502305_item	2659952	et	4	main
ca	doc_491521502305_item	2659953	et	4	main
ei	doc_491521502305_item	2659957	et	4	main
ole	doc_491521502305_item	2659958	et	4	main
linnadeks	doc_491521502305_item	2659962	et	3	main
linnadex	doc_491521502305_item	2659975	et	4	main
kuulusid	doc_491521502305_item	2659983	et	4	main
kaubanduslinnade	doc_491521502305_item	2659989	et	3	main
tähtis	doc_491521502305_item	2659993	et	4	main
maadel	doc_491521502305_item	2660002	et	4	main
talupojad	doc_491521502305_item	2660003	et	4	main
gotlandi	doc_491521502305_item	2660033	et	4	main
saarele	doc_491521502305_item	2660034	et	3	main
ja	doc_491521502305_item	2660035	et	3	main
see	doc_491521502305_item	2660036	et	3	main
kroonika	doc_491521502305_item	2660044	et	4	main
trükiti	doc_491521502305_item	2660045	et	3	main
misjonär	doc_491521502305_item	2660051	et	3	main
võttis	doc_491521502305_item	2660056	et	3	main
kirja	doc_491521502305_item	2660079	et	4	main
pidamine	doc_491521502305_item	2660091	et	4	main
kui	doc_491521502305_item	2660092	et	3	main
sattunud	doc_491521502305_item	2660095	et	4	main
kaunase	doc_491521502303_item	2659638	et	4	main
olid	doc_491521502303_item	2659652	et	4	main
ka	doc_491521502303_item	2659653	et	3	main
hansapäevad	doc_491521502303_item	2659654	et	3	main
kus	doc_491521502303_item	2659655	et	3	main
otsustati	doc_491521502303_item	2659656	et	3	main
kes	doc_491521502303_item	2659657	et	4	main
oli	doc_491521502304_item	2659670	et	3	main
säilimist	doc_491521502304_item	2659675	et	4	main
kindlasti	doc_491521502304_item	2659677	et	3	main
oli	doc_491521502304_item	2659682	et	3	main
küllalt	doc_491521502304_item	2659685	et	4	main
sarnane	doc_491521502304_item	2659686	et	4	main
nagu	doc_491521502304_item	2659690	et	3	main
kaitsevaimud	doc_491521502304_item	2659694	et	3	main
kummardamine	doc_491521502304_item	2659696	et	4	main
täitmist	doc_491521502304_item	2659705	et	4	main
ristimine	doc_491521502304_item	2659709	et	4	main
matmine	doc_491521502304_item	2659712	et	4	main
maale	doc_491521502304_item	2659714	et	4	main
eestlased	doc_491521502304_item	2659715	et	3	main
ei	doc_491521502304_item	2659716	et	4	main
saanud	doc_491521502304_item	2659717	et	4	main
niikuinii	doc_491521502304_item	2659718	et	4	main
jutlusest	doc_491521502304_item	2659719	et	4	main
aru	doc_491521502304_item	2659720	et	4	main
keeles	doc_491521502304_item	2659724	et	4	main
oli	doc_491521502304_item	2659733	et	3	main
ka	doc_491521502304_item	2659734	et	3	main
rahas	doc_491521502304_item	2659735	et	4	main
rituaalide	doc_491521502304_item	2659738	et	3	main
nõuti	doc_491521502304_item	2659740	et	3	main
mida	doc_491521502304_item	2659742	et	4	main
eestlastel	doc_491521502304_item	2659743	et	4	main
vajalikud	doc_491521502304_item	2659749	et	3	main
ikka	doc_491521502304_item	2659751	et	4	main
korraldas	doc_491521502304_item	2659755	et	3	main
tegelikult	doc_491521502304_item	2659761	et	4	main
üle	doc_491521502304_item	2659767	et	3	main
omane	doc_491521502304_item	2659770	et	3	main
põikpäisus	doc_491521502304_item	2659772	et	3	main
neile	doc_491521502304_item	2659773	et	4	main
vahel	doc_491521502304_item	2659777	et	4	main
kohale	doc_491521502304_item	2659778	et	4	main
miks	doc_491521502304_item	2659779	et	4	main
mitmenaisepidamine	doc_491521502304_item	2659792	et	3	main
soodustas	doc_491521502304_item	2659676	et	3	main
omale	doc_491521502304_item	2659684	et	3	main
erinevad	doc_491521502304_item	2659687	et	4	main
muinasusundi	doc_491521502304_item	2659691	et	3	main
nende	doc_491521502304_item	2659695	et	4	main
meenutas	doc_491521502304_item	2659697	et	3	main
eestlaste	doc_491521502304_item	2659698	et	4	main
muinasrituaale	doc_491521502304_item	2659699	et	3	main
väliselt	doc_491521502304_item	2659707	et	4	main
neile	doc_491521502304_item	2659730	et	4	main
kättesaamatuks	doc_491521502304_item	2659731	et	4	main
asjad	doc_491521502304_item	2659750	et	3	main
omamoodi	doc_491521502304_item	2659752	et	3	main
eestlastele	doc_491521502304_item	2659768	et	4	main
on	doc_491521502304_item	2659769	et	4	main
muinasusunditavade	doc_491521502304_item	2659789	et	3	main
järgi	doc_491521502304_item	2659790	et	4	main
vahel	doc_491521502304_item	2659793	et	4	main
oli	doc_491521502304_item	2659794	et	3	main
asi	doc_491521502304_item	2659795	et	4	main
ka	doc_491521502304_item	2659796	et	3	main
lihtsalt	doc_491521502304_item	2659797	et	4	main
jonnis	doc_491521502304_item	2659798	et	4	main
seda	doc_491521502304_item	2659799	et	3	main
näitavad	doc_491521502304_item	2659800	et	4	main
mitmed	doc_491521502304_item	2659801	et	4	main
rahutused	doc_491521502304_item	2659802	et	4	main
võõrvõimu	doc_491521502304_item	2659803	et	4	main
vastu	doc_491521502304_item	2659804	et	3	main
põhjuseid	doc_491521502304_item	2659805	et	3	main
on	doc_491521502304_item	2659806	et	4	main
vast	doc_491521502304_item	2659807	et	3	main
mitmeid	doc_491521502304_item	2659808	et	4	main
aga	doc_491521502304_item	2659809	et	3	main
tõenäoliselt	doc_491521502304_item	2659810	et	4	main
oli	doc_491521502304_item	2659811	et	3	main
kõige	doc_491521502304_item	2659812	et	4	main
suurem	doc_491521502304_item	2659813	et	4	main
põhjus	doc_491521502304_item	2659814	et	4	main
katoliku	doc_491521502304_item	2659815	et	3	main
kiriku	doc_491521502304_item	2659816	et	3	main
rituaalide	doc_491521502304_item	2659817	et	3	main
sarnasus	doc_491521502304_item	2659818	et	4	main
eestlaste	doc_491521502304_item	2659819	et	4	main
usundile	doc_491521502304_item	2659820	et	3	main
kristlaste	doc_491521502304_item	2659824	et	3	main
lihtsalt	doc_491521502304_item	2659827	et	4	main
veel	doc_491521502304_item	2659828	et	4	main
üks	doc_491521502304_item	2659829	et	3	main
paljude	doc_491521502304_item	2659830	et	3	main
palumine	doc_491521502304_item	2659834	et	4	main
oli	doc_491521502304_item	2659869	et	3	main
tallinn	doc_491521502304_item	2659879	et	4	main
narva	doc_491521502304_item	2659886	et	4	main
veeti	doc_491521502304_item	2659894	et	3	main
veine	doc_491521502304_item	2659897	et	3	main
eestist	doc_491521502304_item	2659904	et	3	main
nahk	doc_491521502304_item	2659910	et	3	main
kristlikud	doc_491521502304_item	2659728	et	3	main
põhimõtted	doc_491521502304_item	2659729	et	3	main
kiriklike	doc_491521502304_item	2659737	et	3	main
eest	doc_491521502304_item	2659739	et	4	main
raha	doc_491521502304_item	2659741	et	4	main
aeti	doc_491521502304_item	2659747	et	3	main
visitatsioone	doc_491521502304_item	2659756	et	3	main
et	doc_491521502304_item	2659760	et	3	main
või	doc_491521502304_item	2659784	et	4	main
nt	doc_491521502304_item	2659791	et	4	main
esivanemate	doc_491521502304_item	2659822	et	4	main
jumal	doc_491521502304_item	2659825	et	3	main
veel	doc_491521502304_item	2659846	et	4	main
suuremate	doc_491521502304_item	2659863	et	4	main
läänemere-äärsete	doc_491521502304_item	2659864	et	3	main
kaubanduslinnade	doc_491521502304_item	2659865	et	3	main
mille	doc_491521502304_item	2659867	et	3	main
hli	doc_491521502304_item	2659878	et	4	main
viljandi	doc_491521502304_item	2659881	et	4	main
narva	doc_491521502304_item	2659882	et	4	main
põhiliselt	doc_491521502304_item	2659883	et	4	main
transiitkaubandus	doc_491521502304_item	2659884	et	3	main
novgorodi	doc_491521502304_item	2659890	et	4	main
sisse	doc_491521502304_item	2659893	et	4	main
vürtse	doc_491521502304_item	2659896	et	3	main
jpm	doc_491521502304_item	2659898	et	4	main
jm	doc_491521502304_item	2659908	et	4	main
jaoks	doc_491521502304_item	2659916	et	4	main
jõukuse	doc_491521502304_item	2659924	et	4	main
mis	doc_491521502305_item	2659935	et	4	main
soodustas	doc_491521502305_item	2659936	et	3	main
juures	doc_491521502305_item	2659940	et	4	main
liit	doc_491521502305_item	2659945	et	3	main
13	doc_491521502305_item	2659950	et	2	main
200000	doc_491521502305_item	2659954	et	2	main
arv	doc_491521502305_item	2659956	et	3	main
tähtsamatex	doc_491521502305_item	2659961	et	4	main
keskaja	doc_491521502305_item	2659967	et	3	main
oli	doc_491521502305_item	2659969	et	3	main
tegemist	doc_491521502305_item	2659970	et	4	main
aga	doc_491521502305_item	2659971	et	3	main
suurte	doc_491521502305_item	2659972	et	3	main
linnadega	doc_491521502305_item	2659973	et	3	main
väiksematex	doc_491521502305_item	2659974	et	4	main
kõik	doc_491521502305_item	2659980	et	4	main
need	doc_491521502305_item	2659981	et	3	main
linnad	doc_491521502305_item	2659982	et	3	main
oli	doc_491521502305_item	2659988	et	3	main
ei	doc_491521502305_item	2660004	et	4	main
asus	doc_491521502305_item	2660027	et	4	main
osa	doc_491521502305_item	2660028	et	4	main
hansa	doc_491521502305_item	2660038	et	4	main
liidu	doc_491521502305_item	2660039	et	3	main
aluseks	doc_491521502305_item	2660040	et	4	main
1	doc_491521502305_item	2660041	et	2	main
henriku	doc_491521502305_item	2660042	et	4	main
kes	doc_491521502305_item	2660052	et	4	main
ristiusku	doc_491521502305_item	2660055	et	4	main
eestlaste	doc_491521502305_item	2660058	et	4	main
tema	doc_491521502305_item	2660060	et	4	main
koostas	doc_491521502305_item	2660061	et	4	main
korda	doc_491521502305_item	2660077	et	4	main
eestlaste	doc_491521502305_item	2660084	et	4	main
puude	doc_491521502305_item	2660086	et	4	main
oli	doc_491521502305_item	2660101	et	3	main
väga	doc_491521502305_item	2660102	et	3	main
side	doc_491521502305_item	2660104	et	4	main
euroopaga	doc_491521502305_item	2660105	et	3	main
ühiskondlik	doc_491521502305_item	2660113	et	3	main
ülemvõimu	doc_491521502305_item	2660120	et	4	main
hakkasid	doc_491521502305_item	2660132	et	4	main
maahärrad	doc_491521502305_item	2660133	et	3	main
keelati	doc_491521502305_item	2660141	et	4	main
mitmenaisepidamine	doc_491521502305_item	2660142	et	3	main
maale	doc_491521502305_item	2660150	et	4	main
võeti	doc_491521502305_item	2660154	et	3	main
et	doc_491521502305_item	2660157	et	3	main
jäid	doc_491521502305_item	2660159	et	4	main
võeti	doc_491521502305_item	2660166	et	3	main
põllumajandusse	doc_491521502305_item	2660172	et	3	main
muinasusundi	doc_491521502306_item	2660184	et	3	main
seas	doc_491521502304_item	2659832	et	4	main
kõige	doc_491521502304_item	2659836	et	4	main
muinasusundile	doc_491521502304_item	2659840	et	3	main
taoline	doc_491521502304_item	2659849	et	3	main
külakatoliiklus	doc_491521502304_item	2659850	et	4	main
vana	doc_491521502304_item	2659851	et	4	main
ja	doc_491521502304_item	2659852	et	3	main
uue	doc_491521502304_item	2659853	et	3	main
segu	doc_491521502304_item	2659854	et	4	main
jne	doc_491521502304_item	2659841	et	4	main
rituaalidele	doc_491521502304_item	2659842	et	3	main
lisati	doc_491521502304_item	2659843	et	3	main
oma	doc_491521502304_item	2659844	et	4	main
usundist	doc_491521502304_item	2659845	et	3	main
liit	doc_491521502304_item	2659866	et	3	main
lübecki	doc_491521502304_item	2659870	et	4	main
rajamine	doc_491521502304_item	2659872	et	4	main
saksamaal	doc_491521502304_item	2659873	et	4	main
12	doc_491521502304_item	2659874	et	2	main
sajandil	doc_491521502304_item	2659875	et	3	main
eestis	doc_491521502304_item	2659876	et	3	main
kuulusid	doc_491521502304_item	2659877	et	4	main
pärnu	doc_491521502304_item	2659880	et	4	main
ja	doc_491521502304_item	2659887	et	3	main
tartu	doc_491521502304_item	2659888	et	4	main
olid	doc_491521502304_item	2659889	et	4	main
välja	doc_491521502304_item	2659905	et	4	main
rukkis	doc_491521502304_item	2659907	et	3	main
mesi	doc_491521502304_item	2659911	et	4	main
puitu	doc_491521502304_item	2659913	et	4	main
kivi	doc_491521502304_item	2659914	et	4	main
genotaafide	doc_491521502304_item	2659915	et	4	main
14-15	doc_491521502304_item	2659920	et	2	main
sajandil	doc_491521502304_item	2659921	et	3	main
eesti	doc_491521502304_item	2659923	et	4	main
tasemel	doc_491521502304_item	2659927	et	3	main
ka	doc_491521502304_item	2659928	et	3	main
elasid	doc_491521502304_item	2659930	et	4	main
muinasusundi	doc_491521502305_item	2659937	et	3	main
mis	doc_491521502305_item	2659942	et	4	main
2	doc_491521502305_item	2659946	et	2	main
oli	doc_491521502305_item	2659949	et	3	main
teada	doc_491521502305_item	2659960	et	3	main
ja	doc_491521502305_item	2659965	et	3	main
olid	doc_491521502305_item	2659976	et	4	main
hansa	doc_491521502305_item	2659984	et	4	main
liit	doc_491521502305_item	2659990	et	3	main
kunagine	doc_491521502305_item	2659995	et	3	main
keskus	doc_491521502305_item	2659997	et	3	main
olnud	doc_491521502305_item	2660005	et	4	main
levis	doc_491521502304_item	2659855	et	4	main
tegelikult	doc_491521502304_item	2659856	et	4	main
kõikjal	doc_491521502304_item	2659857	et	3	main
euroopas	doc_491521502304_item	2659858	et	3	main
2	doc_491521502304_item	2659859	et	2	main
hansa	doc_491521502304_item	2659860	et	4	main
liit	doc_491521502304_item	2659861	et	3	main
oli	doc_491521502304_item	2659862	et	3	main
venemaale	doc_491521502304_item	2659885	et	4	main
turu	doc_491521502304_item	2659891	et	3	main
mida	doc_491521502304_item	2659899	et	4	main
kohapeal	doc_491521502304_item	2659900	et	3	main
toota	doc_491521502304_item	2659901	et	3	main
ei	doc_491521502304_item	2659902	et	4	main
teravili	doc_491521502304_item	2659909	et	3	main
seoses	doc_491521502304_item	2659917	et	4	main
euroopa	doc_491521502304_item	2659926	et	4	main
eestlaste	doc_491521502305_item	2659939	et	4	main
2	doc_491521502305_item	2659941	et	2	main
hansa	doc_491521502305_item	2659944	et	4	main
arv	doc_491521502305_item	2659948	et	3	main
eestlaste	doc_491521502305_item	2659955	et	4	main
tallinn	doc_491521502305_item	2659964	et	4	main
tartu	doc_491521502305_item	2659966	et	4	main
lõpuks	doc_491521502305_item	2659968	et	4	main
viljandi	doc_491521502305_item	2659977	et	4	main
ja	doc_491521502305_item	2659978	et	3	main
liitu	doc_491521502305_item	2659985	et	4	main
riia	doc_491521502305_item	2659991	et	4	main
oli	doc_491521502305_item	2659992	et	3	main
l-e	doc_491521502305_item	2659996	et	3	main
elasid	doc_491521502305_item	2659999	et	4	main
linlased	doc_491521502305_item	2660000	et	3	main
nõuti	doc_491521502305_item	2660022	et	3	main
toitu	doc_491521502305_item	2660024	et	4	main
saj	doc_491521502305_item	2660026	et	4	main
visbyru	doc_491521502305_item	2660032	et	4	main
liivimaa	doc_491521502305_item	2660043	et	4	main
henrik	doc_491521502305_item	2660049	et	4	main
oli	doc_491521502305_item	2660050	et	3	main
1205a	doc_491521502305_item	2660054	et	4	main
pandud	doc_491521502305_item	2660080	et	4	main
muinasusundi	doc_491521502305_item	2660081	et	3	main
muude	doc_491521502305_item	2660088	et	4	main
esemete	doc_491521502305_item	2660089	et	3	main
pühadex	doc_491521502305_item	2660090	et	4	main
ühiskonda	doc_491521502305_item	2660099	et	4	main
tihe	doc_491521502305_item	2660103	et	3	main
mentaliteet	doc_491521502305_item	2660115	et	3	main
talupoegadelt	doc_491521502305_item	2660121	et	3	main
nõudma	doc_491521502305_item	2660123	et	3	main
kloostrid	doc_491521502305_item	2660127	et	3	main
maxe	doc_491521502305_item	2660134	et	4	main
nõudma	doc_491521502305_item	2660135	et	3	main
lapsi	doc_491521502305_item	2660143	et	4	main
eestlased	doc_491521502305_item	2660158	et	3	main
ajaks	doc_491521502305_item	2660161	et	4	main
vanade	doc_491521502305_item	2660162	et	3	main
kommete	doc_491521502305_item	2660163	et	4	main
mis	doc_491521502305_item	2660170	et	4	main
puutus	doc_491521502305_item	2660171	et	4	main
mis	doc_491521502306_item	2660182	et	4	main
säilimist	doc_491521502306_item	2660185	et	4	main
eestlaste	doc_491521502306_item	2660186	et	4	main
hansa	doc_491521502306_item	2660191	et	4	main
muinasusundi	doc_491521502306_item	2660194	et	3	main
eestlaste	doc_491521502306_item	2660196	et	4	main
juures	doc_491521502306_item	2660197	et	4	main
soodustas	doc_491521502306_item	2660198	et	3	main
talupoegade	doc_491521502306_item	2660199	et	3	main
iseloom	doc_491521502306_item	2660200	et	3	main
külaelanikud	doc_491521502306_item	2660201	et	3	main
mõisnikud	doc_491521502306_item	2660202	et	3	main
säilitajateks	doc_491521502306_item	2660208	et	4	main
säilitas	doc_491521502306_item	2660210	et	3	main
juures	doc_491521502306_item	2660212	et	4	main
sellepärast	doc_491521502306_item	2660213	et	3	main
enamik	doc_491521502306_item	2660226	et	3	main
19saj	doc_491521502306_item	2660230	et	4	main
rahvatraditsiooniga	doc_491521502306_item	2660241	et	3	main
pandi	doc_491521502306_item	2660248	et	4	main
küllalt	doc_491521502304_item	2659931	et	4	main
hästi	doc_491521502304_item	2659932	et	3	main
säilimist	doc_491521502305_item	2659938	et	4	main
saj	doc_491521502305_item	2659951	et	4	main
eraldi	doc_491521502305_item	2659959	et	4	main
olid	doc_491521502305_item	2659963	et	4	main
uus-pärnu	doc_491521502305_item	2659979	et	4	main
hansa	doc_491521502305_item	2659986	et	4	main
liit	doc_491521502305_item	2659987	et	3	main
kaubanduskeskus	doc_491521502305_item	2659994	et	3	main
hästi	doc_491521502305_item	2659998	et	3	main
ja	doc_491521502305_item	2660001	et	3	main
veel	doc_491521502305_item	2660006	et	4	main
pärisorjastatud	doc_491521502305_item	2660007	et	4	main
seda	doc_491521502305_item	2660008	et	3	main
perioodi	doc_491521502305_item	2660009	et	4	main
peetaxe	doc_491521502305_item	2660010	et	4	main
jõukamaks	doc_491521502305_item	2660011	et	4	main
vahest	doc_491521502305_item	2660012	et	4	main
tuli	doc_491521502305_item	2660013	et	4	main
ette	doc_491521502305_item	2660014	et	4	main
linnadevahelisi	doc_491521502305_item	2660015	et	4	main
relvakonflikte	doc_491521502305_item	2660016	et	3	main
kus	doc_491521502305_item	2660017	et	3	main
kannatasid	doc_491521502305_item	2660018	et	4	main
talupojad	doc_491521502305_item	2660019	et	4	main
sest	doc_491521502305_item	2660020	et	4	main
neilt	doc_491521502305_item	2660021	et	4	main
palju	doc_491521502305_item	2660023	et	4	main
12	doc_491521502305_item	2660025	et	2	main
kaupmeestest	doc_491521502305_item	2660030	et	4	main
ümber	doc_491521502305_item	2660031	et	3	main
on	doc_491521502305_item	2660078	et	4	main
teateid	doc_491521502305_item	2660083	et	3	main
eestlased	doc_491521502305_item	2660093	et	3	main
ühiskonnast	doc_491521502305_item	2660097	et	4	main
sealt	doc_491521502305_item	2660106	et	4	main
hakkasid	doc_491521502305_item	2660107	et	4	main
siia	doc_491521502305_item	2660108	et	4	main
katoliku	doc_491521502305_item	2660116	et	3	main
kehtestas	doc_491521502305_item	2660118	et	3	main
lübecki	doc_491521502305_item	2660029	et	4	main
oli	doc_491521502305_item	2660037	et	3	main
esimest	doc_491521502305_item	2660046	et	4	main
korda	doc_491521502305_item	2660047	et	4	main
1740a	doc_491521502305_item	2660048	et	4	main
levitas	doc_491521502305_item	2660053	et	3	main
osa	doc_491521502305_item	2660057	et	4	main
ristimisest	doc_491521502305_item	2660059	et	4	main
kroonika	doc_491521502305_item	2660062	et	4	main
mis	doc_491521502305_item	2660063	et	4	main
on	doc_491521502305_item	2660064	et	4	main
tähtsax	doc_491521502305_item	2660065	et	4	main
mälestisex	doc_491521502305_item	2660066	et	4	main
eesti	doc_491521502305_item	2660067	et	4	main
kultuurist	doc_491521502305_item	2660068	et	3	main
seal	doc_491521502305_item	2660069	et	4	main
on	doc_491521502305_item	2660070	et	4	main
ära	doc_491521502305_item	2660071	et	4	main
toodud	doc_491521502305_item	2660072	et	4	main
keelseid	doc_491521502305_item	2660074	et	3	main
väljendeid	doc_491521502305_item	2660075	et	3	main
eesti	doc_491521502305_item	2660073	et	4	main
i	doc_491521502305_item	2660076	et	4	main
kohta	doc_491521502305_item	2660082	et	4	main
matmiskombed	doc_491521502305_item	2660085	et	3	main
ja	doc_491521502305_item	2660087	et	3	main
olid	doc_491521502305_item	2660094	et	4	main
viikingiaja	doc_491521502305_item	2660096	et	3	main
keskaja	doc_491521502305_item	2660098	et	3	main
ulatuma	doc_491521502305_item	2660109	et	4	main
uued	doc_491521502305_item	2660110	et	3	main
kombed	doc_491521502305_item	2660111	et	3	main
kord	doc_491521502305_item	2660114	et	4	main
siin	doc_491521502305_item	2660119	et	4	main
kümnist	doc_491521502305_item	2660124	et	3	main
uued	doc_491521502305_item	2660126	et	3	main
jne	doc_491521502305_item	2660129	et	4	main
abielud	doc_491521502305_item	2660136	et	3	main
pidi	doc_491521502305_item	2660144	et	4	main
selliste	doc_491521502305_item	2660151	et	4	main
nii	doc_491521502305_item	2660156	et	3	main
juurde	doc_491521502305_item	2660164	et	4	main
kõik	doc_491521502305_item	2660169	et	4	main
muutumatux	doc_491521502305_item	2660174	et	4	main
sajanditex	doc_491521502305_item	2660175	et	4	main
soodustas	doc_491521502306_item	2660183	et	3	main
jäid	doc_491521502306_item	2660203	et	4	main
põhjustel	doc_491521502306_item	2660225	et	3	main
sobtas	doc_491521502306_item	2660238	et	4	main
rahvatraditsioonide	doc_491521502306_item	2660242	et	3	main
kuulusid	doc_491521502306_item	2660244	et	4	main
austamine	doc_491521502306_item	2660246	et	4	main
vajalikud	doc_491521502306_item	2660253	et	3	main
eluks	doc_491521502306_item	2660255	et	3	main
austamine	doc_491521502306_item	2660258	et	4	main
ei	doc_491521502306_item	2660263	et	4	main
oma	doc_491521502306_item	2660266	et	4	main
elus	doc_491521502306_item	2660267	et	4	main
kõik	doc_491521502306_item	2660268	et	4	main
see	doc_491521502306_item	2660269	et	3	main
soodustas	doc_491521502306_item	2660270	et	3	main
muinasusundi	doc_491521502306_item	2660271	et	3	main
peamiselt	doc_491521502306_item	2660301	et	4	main
suurperedena	doc_491521502306_item	2660302	et	3	main
keskajal	doc_491521502306_item	2660304	et	3	main
madalama	doc_491521502306_item	2660315	et	4	main
siis	doc_491521502305_item	2660100	et	3	main
tavad	doc_491521502305_item	2660112	et	3	main
kirik	doc_491521502305_item	2660117	et	3	main
hakati	doc_491521502305_item	2660122	et	3	main
kirikud	doc_491521502305_item	2660128	et	3	main
selle	doc_491521502305_item	2660130	et	4	main
eest	doc_491521502305_item	2660131	et	4	main
olema	doc_491521502305_item	2660138	et	4	main
kirikus	doc_491521502305_item	2660139	et	3	main
pühitsetud	doc_491521502305_item	2660140	et	4	main
ja	doc_491521502305_item	2660146	et	3	main
maxe	doc_491521502305_item	2660155	et	4	main
pikaks	doc_491521502305_item	2660160	et	4	main
õppisid	doc_491521502305_item	2660177	et	4	main
uusi	doc_491521502305_item	2660178	et	3	main
käsitöövõtteid	doc_491521502305_item	2660179	et	3	main
kontrolltöö	doc_491521502306_item	2660180	et	4	main
1	doc_491521502306_item	2660181	et	2	main
2	doc_491521502306_item	2660188	et	2	main
mis	doc_491521502306_item	2660189	et	4	main
1	doc_491521502306_item	2660193	et	2	main
säilimist	doc_491521502306_item	2660195	et	4	main
eestlaste	doc_491521502306_item	2660211	et	4	main
talupojad	doc_491521502306_item	2660215	et	4	main
võtsid	doc_491521502306_item	2660216	et	4	main
väga	doc_491521502306_item	2660217	et	3	main
raskesti	doc_491521502306_item	2660218	et	3	main
ristiusu	doc_491521502306_item	2660219	et	3	main
vastu	doc_491521502306_item	2660220	et	3	main
tekkisid	doc_491521502305_item	2660125	et	4	main
pidid	doc_491521502305_item	2660137	et	4	main
ristima	doc_491521502305_item	2660145	et	4	main
surnuid	doc_491521502305_item	2660147	et	4	main
matma	doc_491521502305_item	2660148	et	3	main
pühitsetud	doc_491521502305_item	2660149	et	4	main
eest	doc_491521502305_item	2660153	et	4	main
ürituste	doc_491521502305_item	2660152	et	4	main
uus	doc_491521502305_item	2660165	et	3	main
vastu	doc_491521502305_item	2660167	et	3	main
visalt	doc_491521502305_item	2660168	et	4	main
jäi	doc_491521502305_item	2660173	et	3	main
talupojad	doc_491521502305_item	2660176	et	4	main
juures	doc_491521502306_item	2660187	et	4	main
liit	doc_491521502306_item	2660192	et	3	main
traditsioonilise	doc_491521502306_item	2660204	et	4	main
muinasusund	doc_491521502306_item	2660209	et	3	main
nende	doc_491521502306_item	2660221	et	4	main
liikuvusest	doc_491521502306_item	2660223	et	4	main
põllumajanduslikel	doc_491521502306_item	2660224	et	3	main
püsima	doc_491521502306_item	2660229	et	3	main
üle	doc_491521502306_item	2660235	et	3	main
surnuile	doc_491521502306_item	2660247	et	4	main
ja	doc_491521502306_item	2660251	et	3	main
liivlased	doc_491521502306_item	2660262	et	3	main
muutusi	doc_491521502306_item	2660265	et	4	main
külas	doc_491521502306_item	2660303	et	3	main
liivimaal	doc_491521502306_item	2660306	et	4	main
sakslased	doc_491521502306_item	2660307	et	3	main
klassi	doc_491521502306_item	2660316	et	4	main
kombed	doc_491521502306_item	2660335	et	3	main
liit	doc_491521502306_item	2660345	et	3	main
liit	doc_491521502306_item	2660347	et	3	main
kontrolltöö	doc_491521502308_item	2660527	et	4	main
allikad	doc_491521502308_item	2660531	et	3	main
teoorjus	doc_491521502308_item	2660539	et	3	main
millest	doc_491521502308_item	2660544	et	3	main
eestlaste	doc_491521502308_item	2660550	et	4	main
autor	doc_491521502308_item	2660556	et	3	main
sündinud	doc_491521502308_item	2660561	et	4	main
1185	doc_491521502308_item	2660562	et	2	main
usku	doc_491521502308_item	2660574	et	4	main
kroonikas	doc_491521502308_item	2660605	et	3	main
toodud	doc_491521502308_item	2660610	et	4	main
nimesid	doc_491521502308_item	2660616	et	3	main
lauseid	doc_491521502308_item	2660619	et	3	main
palju	doc_491521502308_item	2660622	et	4	main
eesti	doc_491521502308_item	2660624	et	4	main
usundi	doc_491521502308_item	2660625	et	3	main
puud	doc_491521502308_item	2660631	et	4	main
matmistoit	doc_491521502308_item	2660632	et	3	main
ja	doc_491521502308_item	2660633	et	3	main
kombed	doc_491521502308_item	2660634	et	3	main
ning	doc_491521502308_item	2660635	et	3	main
päikese	doc_491521502308_item	2660645	et	4	main
ja	doc_491521502308_item	2660646	et	3	main
thor	doc_491521502308_item	2660649	et	4	main
nimelt	doc_491521502308_item	2660650	et	4	main
kroonika	doc_491521502308_item	2660653	et	4	main
1740a	doc_491521502308_item	2660656	et	4	main
eestikeelne	doc_491521502308_item	2660657	et	3	main
variant	doc_491521502308_item	2660658	et	3	main
kroonika	doc_491521502308_item	2660664	et	4	main
on	doc_491521502308_item	2660683	et	4	main
oli	doc_491521502306_item	2660190	et	3	main
kultuuri	doc_491521502306_item	2660205	et	4	main
ja	doc_491521502306_item	2660206	et	3	main
muinasusundi	doc_491521502306_item	2660207	et	3	main
et	doc_491521502306_item	2660214	et	3	main
jäi	doc_491521502306_item	2660228	et	3	main
eesti	doc_491521502306_item	2660231	et	4	main
talupoegkond	doc_491521502306_item	2660232	et	3	main
võttis	doc_491521502306_item	2660233	et	3	main
kõigepealt	doc_491521502306_item	2660234	et	3	main
hulka	doc_491521502306_item	2660243	et	4	main
surnute	doc_491521502306_item	2660245	et	4	main
kaas	doc_491521502306_item	2660249	et	3	main
ehteid	doc_491521502306_item	2660252	et	3	main
tagapoolseks	doc_491521502306_item	2660254	et	4	main
allikate	doc_491521502306_item	2660256	et	3	main
kuna	doc_491521502306_item	2660261	et	3	main
elasid	doc_491521502306_item	2660305	et	4	main
linnaelanikud	doc_491521502306_item	2660308	et	3	main
ja	doc_491521502306_item	2660309	et	3	main
eestlased	doc_491521502306_item	2660310	et	3	main
talupojad	doc_491521502306_item	2660311	et	4	main
külaelanikud	doc_491521502306_item	2660312	et	3	main
populaarsed	doc_491521502306_item	2660320	et	3	main
relikviiad	doc_491521502306_item	2660322	et	4	main
ja	doc_491521502306_item	2660324	et	3	main
anti	doc_491521502306_item	2660327	et	3	main
säilitasid	doc_491521502306_item	2660333	et	4	main
muinasusundi	doc_491521502306_item	2660334	et	3	main
tavasid	doc_491521502306_item	2660336	et	3	main
jne	doc_491521502306_item	2660337	et	4	main
hansa	doc_491521502306_item	2660344	et	4	main
ja	doc_491521502306_item	2660353	et	3	main
linnad	doc_491521502306_item	2660355	et	3	main
eestist	doc_491521502306_item	2660357	et	3	main
kirjalikud	doc_491521502308_item	2660530	et	3	main
mida	doc_491521502308_item	2660537	et	4	main
kõige	doc_491521502308_item	2660541	et	4	main
võimalik	doc_491521502308_item	2660546	et	3	main
selle	doc_491521502308_item	2660555	et	4	main
tuli	doc_491521502308_item	2660570	et	4	main
välja	doc_491521502308_item	2660609	et	4	main
kohanimesid	doc_491521502308_item	2660613	et	3	main
inimeste	doc_491521502308_item	2660615	et	3	main
ja	doc_491521502308_item	2660618	et	3	main
kroonikas	doc_491521502308_item	2660620	et	3	main
jumalad	doc_491521502308_item	2660636	et	3	main
taara	doc_491521502308_item	2660643	et	4	main
skandinaavlaste	doc_491521502308_item	2660644	et	3	main
1881a	doc_491521502308_item	2660660	et	4	main
tõlgitud	doc_491521502308_item	2660666	et	4	main
keelde	doc_491521502308_item	2660672	et	4	main
ja	doc_491521502308_item	2660675	et	3	main
nimesid	doc_491521502308_item	2660677	et	3	main
palju	doc_491521502308_item	2660685	et	4	main
pärast	doc_491521502308_item	2660691	et	4	main
kirikureformatsiooni	doc_491521502308_item	2660692	et	4	main
vähesest	doc_491521502306_item	2660222	et	3	main
kombeid	doc_491521502306_item	2660227	et	4	main
pühakultuse	doc_491521502306_item	2660236	et	3	main
ja	doc_491521502306_item	2660237	et	3	main
seda	doc_491521502306_item	2660239	et	3	main
kokku	doc_491521502306_item	2660240	et	3	main
pühapaikude	doc_491521502306_item	2660257	et	4	main
edasi	doc_491521502306_item	2660260	et	3	main
eestlaste	doc_491521502306_item	2660273	et	4	main
juures	doc_491521502306_item	2660274	et	4	main
eestlased	doc_491521502306_item	2660275	et	3	main
kaua	doc_491521502306_item	2660276	et	3	main
aega	doc_491521502306_item	2660277	et	4	main
ei	doc_491521502306_item	2660278	et	4	main
tahtnud	doc_491521502306_item	2660279	et	4	main
võtta	doc_491521502306_item	2660280	et	3	main
ristiusu	doc_491521502306_item	2660281	et	3	main
vastu	doc_491521502306_item	2660282	et	3	main
nad	doc_491521502306_item	2660283	et	3	main
isegi	doc_491521502306_item	2660284	et	4	main
1343	doc_491521502306_item	2660285	et	2	main
aastal	doc_491521502306_item	2660286	et	3	main
alustasid	doc_491521502306_item	2660287	et	4	main
vabadussõda	doc_491521502306_item	2660288	et	4	main
oma	doc_491521502306_item	2660289	et	4	main
õiguste	doc_491521502306_item	2660290	et	4	main
eest	doc_491521502306_item	2660291	et	4	main
kuid	doc_491521502306_item	2660292	et	4	main
kaotasid	doc_491521502306_item	2660293	et	4	main
aastal	doc_491521502306_item	2660295	et	3	main
kuna	doc_491521502306_item	2660296	et	3	main
talupojad	doc_491521502306_item	2660297	et	4	main
1345	doc_491521502306_item	2660294	et	2	main
tööriistu	doc_491521502306_item	2660250	et	3	main
säilis	doc_491521502306_item	2660259	et	4	main
armastanud	doc_491521502306_item	2660264	et	4	main
säilimist	doc_491521502306_item	2660272	et	4	main
maal	doc_491521502306_item	2660300	et	4	main
talupojad	doc_491521502306_item	2660313	et	4	main
kuulusid	doc_491521502306_item	2660314	et	4	main
seas	doc_491521502306_item	2660318	et	4	main
põlve	doc_491521502306_item	2660330	et	4	main
maal	doc_491521502306_item	2660338	et	4	main
eripära	doc_491521502306_item	2660342	et	4	main
kuhu	doc_491521502306_item	2660348	et	3	main
praegusest	doc_491521502306_item	2660356	et	3	main
elasid	doc_491521502306_item	2660298	et	4	main
koguaeg	doc_491521502306_item	2660299	et	3	main
eestlaste	doc_491521502306_item	2660317	et	4	main
olid	doc_491521502306_item	2660319	et	4	main
sälmid	doc_491521502306_item	2660321	et	4	main
rahvapärimused	doc_491521502306_item	2660323	et	3	main
elukogumised	doc_491521502306_item	2660325	et	4	main
edasi	doc_491521502306_item	2660328	et	3	main
põlvest	doc_491521502306_item	2660329	et	4	main
selle	doc_491521502306_item	2660331	et	4	main
abil	doc_491521502306_item	2660332	et	4	main
säilis	doc_491521502306_item	2660339	et	4	main
põlisrahva	doc_491521502306_item	2660340	et	3	main
2	doc_491521502306_item	2660343	et	2	main
linnade	doc_491521502306_item	2660346	et	3	main
põhja-saksa	doc_491521502306_item	2660350	et	4	main
liivimaa	doc_491521502306_item	2660352	et	4	main
preisimaa	doc_491521502306_item	2660354	et	4	main
1	doc_491521502308_item	2660528	et	2	main
millised	doc_491521502308_item	2660529	et	3	main
jutustavad	doc_491521502308_item	2660532	et	4	main
tähendab	doc_491521502308_item	2660538	et	3	main
1	doc_491521502308_item	2660540	et	2	main
olulisem	doc_491521502308_item	2660542	et	4	main
teada	doc_491521502308_item	2660547	et	3	main
kohta	doc_491521502308_item	2660551	et	4	main
liivimaa	doc_491521502308_item	2660553	et	4	main
kroonika	doc_491521502308_item	2660554	et	4	main
on	doc_491521502308_item	2660560	et	4	main
hea	doc_491521502308_item	2660566	et	4	main
hariduse	doc_491521502308_item	2660567	et	3	main
kloostrist	doc_491521502308_item	2660568	et	3	main
ning	doc_491521502308_item	2660569	et	3	main
missionääriks	doc_491521502308_item	2660572	et	4	main
esimest	doc_491521502308_item	2660607	et	4	main
korda	doc_491521502308_item	2660608	et	4	main
keelseid	doc_491521502308_item	2660612	et	3	main
väljendeid	doc_491521502308_item	2660617	et	3	main
mis	doc_491521502306_item	2660326	et	4	main
etnilise	doc_491521502306_item	2660341	et	3	main
kuulusid	doc_491521502306_item	2660349	et	4	main
madalmaaa	doc_491521502306_item	2660351	et	4	main
hansa	doc_491521502306_item	2660358	et	4	main
liidus	doc_491521502306_item	2660359	et	4	main
olid	doc_491521502306_item	2660360	et	4	main
tallinn	doc_491521502306_item	2660361	et	4	main
tartu	doc_491521502306_item	2660362	et	4	main
narva	doc_491521502306_item	2660363	et	4	main
uus-pärnu	doc_491521502306_item	2660364	et	4	main
hansa	doc_491521502306_item	2660365	et	4	main
liit	doc_491521502306_item	2660366	et	3	main
tegutses	doc_491521502306_item	2660367	et	3	main
13	doc_491521502306_item	2660368	et	2	main
saj-st	doc_491521502306_item	2660369	et	3	main
16	doc_491521502306_item	2660370	et	2	main
sajandini	doc_491521502306_item	2660371	et	3	main
kaupmeeste	doc_491521502306_item	2660372	et	4	main
linnad	doc_491521502306_item	2660374	et	3	main
tähtsamaid	doc_491521502306_item	2660373	et	4	main
keskajast	doc_491521502308_item	2660535	et	4	main
2	doc_491521502308_item	2660536	et	2	main
on	doc_491521502308_item	2660545	et	4	main
muistse	doc_491521502308_item	2660549	et	3	main
on	doc_491521502308_item	2660552	et	4	main
lettis	doc_491521502308_item	2660559	et	4	main
sai	doc_491521502308_item	2660565	et	4	main
risti	doc_491521502308_item	2660573	et	4	main
levitama	doc_491521502308_item	2660575	et	4	main
hakkas	doc_491521502308_item	2660577	et	3	main
kroonikat	doc_491521502308_item	2660578	et	3	main
eesti	doc_491521502308_item	2660611	et	4	main
ja	doc_491521502308_item	2660614	et	3	main
kohta	doc_491521502308_item	2660626	et	4	main
seal	doc_491521502308_item	2660627	et	4	main
kõige	doc_491521502308_item	2660637	et	4	main
jumala	doc_491521502308_item	2660648	et	3	main
esimest	doc_491521502308_item	2660654	et	4	main
korda	doc_491521502308_item	2660655	et	4	main
ilmus	doc_491521502308_item	2660659	et	4	main
on	doc_491521502308_item	2660665	et	4	main
ja	doc_491521502308_item	2660670	et	3	main
kohtade	doc_491521502308_item	2660674	et	3	main
inimeste	doc_491521502308_item	2660676	et	3	main
võib	doc_491521502308_item	2660678	et	3	main
kohtuda	doc_491521502308_item	2660679	et	3	main
hindamisraamatus	doc_491521502308_item	2660681	et	4	main
seal	doc_491521502308_item	2660682	et	4	main
ning	doc_491521502308_item	2660697	et	3	main
palju	doc_491521502308_item	2660699	et	4	main
teoseid	doc_491521502308_item	2660700	et	3	main
eesti	doc_491521502308_item	2660701	et	4	main
keeles	doc_491521502308_item	2660706	et	4	main
selle	doc_491521502308_item	2660722	et	4	main
koostas	doc_491521502308_item	2660740	et	4	main
käsikirja	doc_491521502308_item	2660741	et	4	main
see	doc_491521502308_item	2660746	et	3	main
oli	doc_491521502308_item	2660756	et	3	main
2	doc_491521502308_item	2660759	et	2	main
töö	doc_491521502308_item	2660762	et	4	main
mõisas	doc_491521502308_item	2660763	et	3	main
sündis	doc_491521502309_item	2660801	et	3	main
arvatakse	doc_491521502309_item	2660803	et	3	main
lähedal	doc_491521502309_item	2660811	et	4	main
kloostrikoolis	doc_491521502309_item	2660813	et	4	main
liivimaale	doc_491521502309_item	2660814	et	4	main
temast	doc_491521502309_item	2660819	et	3	main
vaimulik	doc_491521502309_item	2660821	et	3	main
hästi	doc_491521502309_item	2660826	et	3	main
eestlaste	doc_491521502309_item	2660834	et	4	main
kristimises	doc_491521502309_item	2660835	et	4	main
kroonika	doc_491521502309_item	2660838	et	4	main
eesti	doc_491521502309_item	2660842	et	4	main
esimest	doc_491521502309_item	2660873	et	4	main
jääb	doc_491521502309_item	2660917	et	3	main
meile	doc_491521502308_item	2660533	et	4	main
eestimaa	doc_491521502308_item	2660534	et	4	main
teos	doc_491521502308_item	2660543	et	4	main
saada	doc_491521502308_item	2660548	et	4	main
henricus	doc_491521502308_item	2660557	et	4	main
de	doc_491521502308_item	2660558	et	4	main
a	doc_491521502308_item	2660563	et	4	main
saksamaal	doc_491521502308_item	2660564	et	4	main
eesti	doc_491521502308_item	2660571	et	4	main
ta	doc_491521502308_item	2660576	et	4	main
kirjutama	doc_491521502308_item	2660579	et	3	main
1224	doc_491521502308_item	2660580	et	2	main
aastal	doc_491521502308_item	2660581	et	3	main
ja	doc_491521502308_item	2660582	et	3	main
lõpetas	doc_491521502308_item	2660583	et	3	main
12278	doc_491521502308_item	2660584	et	2	main
a	doc_491521502308_item	2660585	et	4	main
kroonika	doc_491521502308_item	2660586	et	4	main
originaal	doc_491521502308_item	2660587	et	3	main
oli	doc_491521502308_item	2660588	et	3	main
ladina	doc_491521502308_item	2660589	et	4	main
keeles	doc_491521502308_item	2660590	et	4	main
kuid	doc_491521502308_item	2660591	et	4	main
käsikiri	doc_491521502308_item	2660592	et	3	main
ei	doc_491521502308_item	2660593	et	4	main
ole	doc_491521502308_item	2660594	et	4	main
säilinud	doc_491521502308_item	2660595	et	4	main
me	doc_491521502308_item	2660596	et	4	main
võime	doc_491521502308_item	2660597	et	4	main
seda	doc_491521502308_item	2660598	et	3	main
teost	doc_491521502308_item	2660599	et	4	main
uurida	doc_491521502308_item	2660600	et	3	main
ainult	doc_491521502308_item	2660601	et	4	main
hilisemate	doc_491521502308_item	2660602	et	4	main
ümberkirjutiste	doc_491521502308_item	2660603	et	3	main
kaudu	doc_491521502308_item	2660604	et	3	main
on	doc_491521502308_item	2660606	et	4	main
on	doc_491521502308_item	2660628	et	4	main
tähtsamaks	doc_491521502308_item	2660638	et	4	main
jumalaks	doc_491521502308_item	2660639	et	3	main
oli	doc_491521502308_item	2660640	et	3	main
tharapita	doc_491521502308_item	2660641	et	4	main
pikse	doc_491521502308_item	2660647	et	3	main
ilmus	doc_491521502308_item	2660652	et	4	main
jaani	doc_491521502308_item	2660661	et	4	main
jungi	doc_491521502308_item	2660662	et	4	main
tõlges	doc_491521502308_item	2660663	et	3	main
saksa	doc_491521502308_item	2660668	et	4	main
inglise	doc_491521502308_item	2660669	et	4	main
lahingute	doc_491521502308_item	2660687	et	4	main
taanlaste	doc_491521502308_item	2660689	et	3	main
eestikeelne	doc_491521502308_item	2660694	et	3	main
kõige	doc_491521502308_item	2660703	et	4	main
kirju	doc_491521502308_item	2660707	et	4	main
on	doc_491521502308_item	2660710	et	4	main
lübeckis	doc_491521502308_item	2660718	et	4	main
vaimuliku	doc_491521502308_item	2660719	et	3	main
dialoogi	doc_491521502308_item	2660720	et	4	main
on	doc_491521502308_item	2660621	et	4	main
informatsiooni	doc_491521502308_item	2660623	et	4	main
mainitud	doc_491521502308_item	2660629	et	4	main
pühad	doc_491521502308_item	2660630	et	3	main
e	doc_491521502308_item	2660642	et	4	main
trükis	doc_491521502308_item	2660651	et	4	main
vene	doc_491521502308_item	2660667	et	4	main
läti	doc_491521502308_item	2660671	et	4	main
eestikeelseid	doc_491521502308_item	2660673	et	3	main
taani	doc_491521502308_item	2660680	et	4	main
teateid	doc_491521502308_item	2660686	et	3	main
kohta	doc_491521502308_item	2660688	et	4	main
keeles	doc_491521502308_item	2660702	et	4	main
tekst	doc_491521502308_item	2660709	et	3	main
wandradt	doc_491521502308_item	2660711	et	4	main
simon	doc_491521502308_item	2660724	et	4	main
keelde	doc_491521502308_item	2660734	et	4	main
susi	doc_491521502308_item	2660739	et	4	main
vaimulikud	doc_491521502308_item	2660744	et	3	main
mis	doc_491521502308_item	2660755	et	4	main
maksule	doc_491521502308_item	2660776	et	4	main
1	doc_491521502309_item	2660798	et	2	main
sai	doc_491521502309_item	2660809	et	4	main
lübedui	doc_491521502309_item	2660810	et	4	main
sadama	doc_491521502309_item	2660812	et	4	main
ka	doc_491521502308_item	2660684	et	3	main
vägiveod	doc_491521502308_item	2660690	et	3	main
hakkas	doc_491521502308_item	2660693	et	3	main
arenema	doc_491521502308_item	2660696	et	3	main
ilmus	doc_491521502308_item	2660698	et	4	main
eesti	doc_491521502308_item	2660705	et	4	main
tatud	doc_491521502308_item	2660708	et	4	main
1525a	doc_491521502308_item	2660717	et	4	main
kujul	doc_491521502308_item	2660721	et	4	main
autor	doc_491521502308_item	2660723	et	3	main
niguliste	doc_491521502308_item	2660727	et	4	main
jutustaja	doc_491521502308_item	2660729	et	4	main
õpetaja	doc_491521502308_item	2660737	et	4	main
kuhu	doc_491521502308_item	2660742	et	3	main
kirjutatud	doc_491521502308_item	2660757	et	4	main
puutahvlil	doc_491521502308_item	2660758	et	3	main
teoorjus	doc_491521502308_item	2660760	et	3	main
pidid	doc_491521502308_item	2660765	et	4	main
talupojad	doc_491521502308_item	2660767	et	4	main
henrik	doc_491521502309_item	2660802	et	4	main
et	doc_491521502309_item	2660804	et	3	main
sündis	doc_491521502309_item	2660806	et	3	main
põhja-saksamaal	doc_491521502309_item	2660807	et	4	main
hariduse	doc_491521502309_item	2660808	et	3	main
sai	doc_491521502309_item	2660818	et	4	main
kõrgem	doc_491521502309_item	2660820	et	4	main
preester	doc_491521502309_item	2660822	et	4	main
ta	doc_491521502309_item	2660823	et	4	main
hästi	doc_491521502309_item	2660825	et	3	main
võtnud	doc_491521502309_item	2660832	et	4	main
osa	doc_491521502309_item	2660833	et	4	main
kultuurist	doc_491521502309_item	2660843	et	3	main
selles	doc_491521502309_item	2660844	et	4	main
pandud	doc_491521502309_item	2660847	et	4	main
eestlaste	doc_491521502309_item	2660853	et	4	main
muistsed	doc_491521502309_item	2660854	et	3	main
usundid	doc_491521502309_item	2660855	et	3	main
tharapita	doc_491521502309_item	2660859	et	4	main
aastatel	doc_491521502309_item	2660866	et	4	main
kroonikat	doc_491521502309_item	2660871	et	3	main
korda	doc_491521502309_item	2660874	et	4	main
eestisse	doc_491521502309_item	2660876	et	4	main
kalender	doc_491521502309_item	2660909	et	3	main
päeva	doc_491521502309_item	2660913	et	4	main
1585a	doc_491521502309_item	2660920	et	4	main
tartu	doc_491521502309_item	2660925	et	4	main
eelkäijaks	doc_491521502309_item	2660927	et	3	main
eesti	doc_491521502309_item	2660932	et	4	main
maksudeks	doc_491521502309_item	2660947	et	3	main
millised	doc_491521502310_item	2660950	et	3	main
jutustavad	doc_491521502310_item	2660953	et	4	main
mida	doc_491521502310_item	2660958	et	4	main
jutustab	doc_491521502310_item	2660964	et	3	main
tuntakse	doc_491521502310_item	2660978	et	3	main
ta	doc_491521502310_item	2660982	et	4	main
arvatakse	doc_491521502310_item	2660987	et	3	main
ta	doc_491521502310_item	2660994	et	4	main
hariduse	doc_491521502310_item	2660996	et	3	main
lübeckis	doc_491521502310_item	2660998	et	4	main
saab	doc_491521502310_item	2661007	et	3	main
oskas	doc_491521502310_item	2661010	et	3	main
kohalikuid	doc_491521502310_item	2661012	et	4	main
oli	doc_491521502310_item	2661024	et	3	main
1224-1227	doc_491521502310_item	2661026	et	2	main
originaal	doc_491521502310_item	2661028	et	3	main
oli	doc_491521502310_item	2661030	et	3	main
ei	doc_491521502310_item	2661036	et	4	main
ümber	doc_491521502310_item	2661044	et	3	main
aastal	doc_491521502310_item	2661051	et	3	main
esimest	doc_491521502310_item	2661060	et	4	main
keelde	doc_491521502310_item	2661066	et	4	main
esimest	doc_491521502310_item	2661070	et	4	main
kasutatud	doc_491521502310_item	2661074	et	4	main
öelda	doc_491521502310_item	2661080	et	4	main
et	doc_491521502310_item	2661081	et	3	main
kroonikas	doc_491521502310_item	2661082	et	3	main
eesti	doc_491521502310_item	2661086	et	4	main
tõlgitud	doc_491521502310_item	2661093	et	4	main
saksa	doc_491521502310_item	2661094	et	4	main
keelde	doc_491521502310_item	2661098	et	4	main
henriku	doc_491521502310_item	2661099	et	4	main
kirjandus	doc_491521502308_item	2660695	et	3	main
vanem	doc_491521502308_item	2660704	et	4	main
koelli	doc_491521502308_item	2660712	et	4	main
katekismus	doc_491521502308_item	2660713	et	3	main
see	doc_491521502308_item	2660714	et	3	main
oli	doc_491521502308_item	2660715	et	3	main
kirjutatud	doc_491521502308_item	2660716	et	4	main
oli	doc_491521502308_item	2660726	et	3	main
tallinna	doc_491521502308_item	2660735	et	4	main
linnakooli	doc_491521502308_item	2660736	et	4	main
kuulusid	doc_491521502308_item	2660743	et	4	main
sai	doc_491521502308_item	2660747	et	4	main
katekismus	doc_491521502308_item	2660749	et	3	main
1575a	doc_491521502308_item	2660750	et	4	main
füüsiline	doc_491521502308_item	2660761	et	3	main
tegema	doc_491521502308_item	2660766	et	3	main
talupoja	doc_491521502308_item	2660777	et	4	main
2	doc_491521502309_item	2660794	et	2	main
misjonäriks	doc_491521502309_item	2660816	et	3	main
kardetud	doc_491521502309_item	2660837	et	4	main
mälestis	doc_491521502309_item	2660841	et	3	main
eesti	doc_491521502309_item	2660849	et	4	main
keel	doc_491521502309_item	2660850	et	4	main
võideldavat	doc_491521502309_item	2660857	et	4	main
selle	doc_491521502309_item	2660861	et	4	main
raamatud	doc_491521502309_item	2660867	et	4	main
kirjutati	doc_491521502309_item	2660868	et	3	main
käsitsi	doc_491521502309_item	2660869	et	3	main
ümber	doc_491521502309_item	2660870	et	3	main
ilmub	doc_491521502309_item	2660906	et	3	main
ta	doc_491521502309_item	2660910	et	4	main
kümme	doc_491521502309_item	2660912	et	3	main
sajandiks	doc_491521502309_item	2660916	et	3	main
kalendrit	doc_491521502309_item	2660919	et	3	main
jesuiitide	doc_491521502309_item	2660921	et	3	main
seminar	doc_491521502309_item	2660923	et	3	main
teoorjus	doc_491521502309_item	2660936	et	3	main
suurenesid	doc_491521502309_item	2660942	et	4	main
andsid	doc_491521502309_item	2660946	et	4	main
kontrolltöö	doc_491521502310_item	2660948	et	4	main
kirjalikud	doc_491521502310_item	2660951	et	3	main
1	doc_491521502310_item	2660961	et	2	main
keskajast	doc_491521502310_item	2660963	et	4	main
jutustab	doc_491521502310_item	2660965	et	3	main
liivimaa	doc_491521502310_item	2660970	et	4	main
kroonika	doc_491521502310_item	2660971	et	4	main
de	doc_491521502310_item	2660974	et	4	main
balti	doc_491521502310_item	2660980	et	3	main
kroonikut	doc_491521502310_item	2660981	et	3	main
on	doc_491521502310_item	2660983	et	4	main
1185	doc_491521502310_item	2660985	et	2	main
ta	doc_491521502310_item	2660989	et	4	main
pärit	doc_491521502310_item	2660991	et	3	main
missionääriks	doc_491521502310_item	2661004	et	4	main
on	doc_491521502310_item	2661016	et	4	main
väga	doc_491521502310_item	2661017	et	3	main
wandradt	doc_491521502308_item	2660725	et	4	main
kiriku	doc_491521502308_item	2660728	et	3	main
ta	doc_491521502308_item	2660730	et	4	main
tõlgis	doc_491521502308_item	2660731	et	3	main
katekismuse	doc_491521502308_item	2660732	et	3	main
eesti	doc_491521502308_item	2660733	et	4	main
hans	doc_491521502308_item	2660738	et	4	main
laulud	doc_491521502308_item	2660745	et	3	main
nimetuse	doc_491521502308_item	2660748	et	4	main
ilmus	doc_491521502308_item	2660751	et	4	main
esimene	doc_491521502308_item	2660752	et	3	main
eestikeelne	doc_491521502308_item	2660753	et	3	main
aabits	doc_491521502308_item	2660754	et	3	main
mida	doc_491521502308_item	2660764	et	4	main
üle	doc_491521502308_item	2660768	et	3	main
poole	doc_491521502308_item	2660769	et	4	main
seda	doc_491521502308_item	2660770	et	3	main
mida	doc_491521502308_item	2660771	et	4	main
tootis	doc_491521502308_item	2660772	et	3	main
talupoeg	doc_491521502308_item	2660773	et	3	main
läks	doc_491521502308_item	2660774	et	3	main
mõisnikule	doc_491521502308_item	2660775	et	3	main
kohustus	doc_491521502308_item	2660778	et	4	main
kasvab	doc_491521502308_item	2660779	et	3	main
kahekordselt	doc_491521502308_item	2660780	et	4	main
see	doc_491521502308_item	2660781	et	3	main
oli	doc_491521502308_item	2660782	et	3	main
pärisorjuse	doc_491521502308_item	2660783	et	3	main
aluseks	doc_491521502308_item	2660784	et	4	main
1	doc_491521502309_item	2660786	et	2	main
millised	doc_491521502309_item	2660787	et	3	main
kirjalikud	doc_491521502309_item	2660788	et	3	main
allikad	doc_491521502309_item	2660789	et	3	main
jutustavad	doc_491521502309_item	2660790	et	4	main
kontrolltöö	doc_491521502309_item	2660785	et	4	main
meile	doc_491521502309_item	2660791	et	4	main
eestimaa	doc_491521502309_item	2660792	et	4	main
keskajast	doc_491521502309_item	2660793	et	4	main
mida	doc_491521502309_item	2660795	et	4	main
tähendab	doc_491521502309_item	2660796	et	3	main
teoorjus	doc_491521502309_item	2660797	et	3	main
umbes	doc_491521502309_item	2660799	et	4	main
1185a	doc_491521502309_item	2660800	et	4	main
te	doc_491521502309_item	2660805	et	4	main
tuli	doc_491521502309_item	2660815	et	4	main
1208a	doc_491521502309_item	2660817	et	4	main
oskas	doc_491521502309_item	2660824	et	3	main
liivi	doc_491521502309_item	2660827	et	4	main
lõuna-eesti	doc_491521502309_item	2660828	et	4	main
keelt	doc_491521502309_item	2660829	et	4	main
tema	doc_491521502309_item	2660836	et	4	main
on	doc_491521502309_item	2660839	et	4	main
tähtis	doc_491521502309_item	2660840	et	4	main
esmakordselt	doc_491521502309_item	2660848	et	4	main
eetlaste	doc_491521502309_item	2660856	et	4	main
kroonika	doc_491521502309_item	2660862	et	4	main
ta	doc_491521502309_item	2660863	et	4	main
kirjutas	doc_491521502309_item	2660864	et	3	main
1224-1227	doc_491521502309_item	2660865	et	2	main
1740a	doc_491521502309_item	2660875	et	4	main
gregooriuse	doc_491521502309_item	2660908	et	4	main
oli	doc_491521502309_item	2660911	et	3	main
enne	doc_491521502309_item	2660914	et	4	main
kolleegium	doc_491521502309_item	2660922	et	3	main
peetakse	doc_491521502309_item	2660924	et	3	main
ülikooli	doc_491521502309_item	2660926	et	4	main
õpetati	doc_491521502309_item	2660928	et	3	main
kohalike	doc_491521502309_item	2660929	et	4	main
keeli	doc_491521502309_item	2660930	et	4	main
tõlke	doc_491521502309_item	2660934	et	4	main
talupojad	doc_491521502309_item	2660937	et	4	main
kohustused	doc_491521502309_item	2660941	et	4	main
varast	doc_491521502309_item	2660945	et	4	main
allikad	doc_491521502310_item	2660952	et	3	main
meile	doc_491521502310_item	2660954	et	4	main
eestimaa	doc_491521502310_item	2660955	et	4	main
teoorjus	doc_491521502310_item	2660960	et	3	main
rohkem	doc_491521502310_item	2660968	et	4	main
henriku	doc_491521502310_item	2660969	et	4	main
henricus	doc_491521502310_item	2660973	et	4	main
nagu	doc_491521502310_item	2660979	et	3	main
aastal	doc_491521502310_item	2660986	et	3	main
liivimaale	doc_491521502310_item	2661003	et	4	main
temast	doc_491521502310_item	2661006	et	3	main
oluline	doc_491521502310_item	2661018	et	4	main
säilinud	doc_491521502310_item	2661037	et	4	main
1740	doc_491521502310_item	2661050	et	2	main
korda	doc_491521502310_item	2661061	et	4	main
oli	doc_491521502310_item	2661062	et	3	main
kroonika	doc_491521502310_item	2661063	et	4	main
henriku	doc_491521502310_item	2661067	et	4	main
kroonikas	doc_491521502310_item	2661069	et	3	main
esimest	doc_491521502310_item	2661083	et	4	main
on	doc_491521502310_item	2661092	et	4	main
rootsi	doc_491521502310_item	2661097	et	4	main
meile	doc_491521502310_item	2661103	et	4	main
eesti	doc_491521502310_item	2661106	et	4	main
ja	doc_491521502310_item	2661108	et	3	main
korda	doc_491521502310_item	2661112	et	4	main
eestlaste	doc_491521502310_item	2661115	et	4	main
seotud	doc_491521502310_item	2661119	et	4	main
ta	doc_491521502309_item	2660830	et	4	main
oli	doc_491521502309_item	2660831	et	3	main
raamatus	doc_491521502309_item	2660845	et	4	main
on	doc_491521502309_item	2660846	et	4	main
eestlaste	doc_491521502309_item	2660851	et	4	main
nimed	doc_491521502309_item	2660852	et	3	main
jumalat	doc_491521502309_item	2660858	et	3	main
taara	doc_491521502309_item	2660860	et	4	main
trükiti	doc_491521502309_item	2660872	et	3	main
kroonika	doc_491521502309_item	2660877	et	4	main
ilmus	doc_491521502309_item	2660878	et	4	main
1801a	doc_491521502309_item	2660879	et	4	main
see	doc_491521502309_item	2660880	et	3	main
kroonika	doc_491521502309_item	2660881	et	4	main
on	doc_491521502309_item	2660882	et	4	main
tõlgitud	doc_491521502309_item	2660883	et	4	main
inglise	doc_491521502309_item	2660884	et	4	main
saksa	doc_491521502309_item	2660885	et	4	main
ja	doc_491521502309_item	2660886	et	3	main
vene	doc_491521502309_item	2660887	et	4	main
keelde	doc_491521502309_item	2660888	et	4	main
hans	doc_491521502309_item	2660889	et	4	main
susi	doc_491521502309_item	2660890	et	4	main
koostab	doc_491521502309_item	2660891	et	3	main
1551a	doc_491521502309_item	2660892	et	4	main
käsikirja	doc_491521502309_item	2660893	et	4	main
mis	doc_491521502309_item	2660894	et	4	main
sisaldab	doc_491521502309_item	2660895	et	3	main
vaimulike	doc_491521502309_item	2660896	et	3	main
jutustusi	doc_491521502309_item	2660898	et	4	main
evanglumeid	doc_491521502309_item	2660899	et	4	main
laule	doc_491521502309_item	2660897	et	4	main
1575a	doc_491521502309_item	2660900	et	4	main
ilmub	doc_491521502309_item	2660901	et	3	main
eesti	doc_491521502309_item	2660902	et	4	main
keelne	doc_491521502309_item	2660903	et	3	main
aabits	doc_491521502309_item	2660904	et	3	main
1582a	doc_491521502309_item	2660905	et	4	main
uus	doc_491521502309_item	2660907	et	3	main
mitmeks	doc_491521502309_item	2660915	et	4	main
kaks	doc_491521502309_item	2660918	et	3	main
läti	doc_491521502309_item	2660931	et	4	main
tegid	doc_491521502309_item	2660938	et	4	main
mõisas	doc_491521502309_item	2660939	et	3	main
tööd	doc_491521502309_item	2660940	et	4	main
keskajast	doc_491521502310_item	2660956	et	4	main
2	doc_491521502310_item	2660957	et	2	main
henrikut	doc_491521502310_item	2660977	et	4	main
et	doc_491521502310_item	2660988	et	3	main
on	doc_491521502310_item	2660990	et	4	main
põhja-saksamaalt	doc_491521502310_item	2660992	et	3	main
madeburg	doc_491521502310_item	2660993	et	4	main
sai	doc_491521502310_item	2660995	et	4	main
kloostrikoolist	doc_491521502310_item	2660997	et	4	main
1205	doc_491521502310_item	2660999	et	2	main
preester	doc_491521502310_item	2661008	et	4	main
henrik	doc_491521502310_item	2661009	et	4	main
hästi	doc_491521502310_item	2661011	et	3	main
keeli	doc_491521502310_item	2661013	et	4	main
kroonika	doc_491521502310_item	2661015	et	4	main
tähtis	doc_491521502310_item	2661020	et	4	main
teos	doc_491521502310_item	2661021	et	4	main
kuid	doc_491521502310_item	2661034	et	4	main
tänapäevani	doc_491521502310_item	2661035	et	3	main
seda	doc_491521502310_item	2661043	et	3	main
ainult	doc_491521502310_item	2661048	et	4	main
esimest	doc_491521502310_item	2661052	et	4	main
oli	doc_491521502310_item	2661054	et	3	main
korda	doc_491521502310_item	2661071	et	4	main
sõnad	doc_491521502310_item	2661078	et	4	main
võime	doc_491521502310_item	2661079	et	4	main
inglise	doc_491521502310_item	2661095	et	4	main
vene	doc_491521502310_item	2661096	et	4	main
kroonika	doc_491521502310_item	2661101	et	4	main
jutustab	doc_491521502310_item	2661102	et	3	main
rahvusest	doc_491521502310_item	2661105	et	4	main
esimest	doc_491521502310_item	2661111	et	4	main
jumalast	doc_491521502310_item	2661116	et	4	main
oli	doc_491521502310_item	2661118	et	3	main
arvan	doc_491521502310_item	2661122	et	3	main
eestlastest	doc_491521502310_item	2661126	et	4	main
ka	doc_491521502310_item	2661129	et	3	main
wandradt	doc_491521502310_item	2661130	et	4	main
1535	doc_491521502310_item	2661135	et	2	main
ilmus	doc_491521502310_item	2661154	et	4	main
aabits	doc_491521502310_item	2661157	et	3	main
see	doc_491521502310_item	2661161	et	3	main
füüsiline	doc_491521502310_item	2661163	et	3	main
töö	doc_491521502310_item	2661164	et	4	main
suurenes	doc_491521502310_item	2661170	et	4	main
talupojad	doc_491521502310_item	2661171	et	4	main
mõisnikutele	doc_491521502310_item	2661176	et	4	main
raskem	doc_491521502310_item	2661180	et	4	main
ebatahtlikum	doc_491521502310_item	2661181	et	4	main
ja	doc_491521502310_item	2661182	et	3	main
2	doc_491521502311_item	2661196	et	2	main
teoorjus	doc_491521502311_item	2661199	et	3	main
tähtsam	doc_491521502311_item	2661202	et	4	main
kroonika	doc_491521502311_item	2661208	et	4	main
kroonik	doc_491521502311_item	2661214	et	3	main
liivimaa	doc_491521502311_item	2661230	et	4	main
mis	doc_491521502311_item	2661235	et	4	main
kahjuks	doc_491521502311_item	2661241	et	4	main
pole	doc_491521502311_item	2661242	et	3	main
tänaseni	doc_491521502311_item	2661245	et	4	main
kroonika	doc_491521502311_item	2661248	et	4	main
1881	doc_491521502311_item	2661261	et	2	main
lugu	doc_491521502311_item	2661291	et	4	main
1227	doc_491521502311_item	2661297	et	2	main
eesti	doc_491521502311_item	2661305	et	4	main
keelt	doc_491521502311_item	2661306	et	4	main
nimesid	doc_491521502311_item	2661308	et	3	main
eestlaste	doc_491521502311_item	2661309	et	4	main
muistset	doc_491521502311_item	2661310	et	3	main
usundit	doc_491521502311_item	2661311	et	3	main
2	doc_491521502311_item	2661317	et	2	main
on	doc_491521502311_item	2661319	et	4	main
pidi	doc_491521502311_item	2661323	et	4	main
tema	doc_491521502311_item	2661328	et	4	main
kohustused	doc_491521502311_item	2661329	et	4	main
kolitati	doc_491521502309_item	2660933	et	3	main
2	doc_491521502309_item	2660935	et	2	main
pool	doc_491521502309_item	2660943	et	4	main
oma	doc_491521502309_item	2660944	et	4	main
1	doc_491521502310_item	2660949	et	2	main
tähendab	doc_491521502310_item	2660959	et	3	main
eestimaa	doc_491521502310_item	2660962	et	4	main
meile	doc_491521502310_item	2660966	et	4	main
kõige	doc_491521502310_item	2660967	et	4	main
lät	doc_491521502310_item	2660972	et	4	main
lettis	doc_491521502310_item	2660975	et	4	main
teda	doc_491521502310_item	2660976	et	4	main
sündinud	doc_491521502310_item	2660984	et	4	main
aastal	doc_491521502310_item	2661000	et	3	main
ta	doc_491521502310_item	2661001	et	4	main
tuli	doc_491521502310_item	2661002	et	4	main
pärast	doc_491521502310_item	2661005	et	4	main
liivimaa	doc_491521502310_item	2661014	et	4	main
ja	doc_491521502310_item	2661019	et	3	main
see	doc_491521502310_item	2661023	et	3	main
kirjutatud	doc_491521502310_item	2661025	et	4	main
aastatel	doc_491521502310_item	2661027	et	4	main
käsikiri	doc_491521502310_item	2661029	et	3	main
kirjutatud	doc_491521502310_item	2661031	et	4	main
ladina	doc_491521502310_item	2661032	et	4	main
see	doc_491521502310_item	2661038	et	3	main
mõned	doc_491521502310_item	2661039	et	3	main
kirjanikud	doc_491521502310_item	2661040	et	3	main
kirjutada	doc_491521502310_item	2661042	et	3	main
käsitsi	doc_491521502310_item	2661049	et	3	main
korda	doc_491521502310_item	2661053	et	4	main
liivimaa	doc_491521502310_item	2661055	et	4	main
kroonika	doc_491521502310_item	2661056	et	4	main
tõlgitud	doc_491521502310_item	2661064	et	4	main
üldse	doc_491521502310_item	2661072	et	3	main
on	doc_491521502310_item	2661073	et	4	main
on	doc_491521502310_item	2661085	et	4	main
keel	doc_491521502310_item	2661087	et	4	main
tavadest	doc_491521502310_item	2661109	et	3	main
äikesega	doc_491521502310_item	2661120	et	4	main
võime	doc_491521502310_item	2661124	et	4	main
ilmus	doc_491521502310_item	2661134	et	4	main
laulude	doc_491521502310_item	2661141	et	3	main
vaimulikud	doc_491521502310_item	2661142	et	3	main
laulud	doc_491521502310_item	2661143	et	3	main
käsikiri	doc_491521502310_item	2661144	et	3	main
evangeeliumi	doc_491521502310_item	2661145	et	4	main
jutlused	doc_491521502310_item	2661146	et	3	main
eesti	doc_491521502310_item	2661155	et	4	main
on	doc_491521502310_item	2661162	et	4	main
rootsi	doc_491521502310_item	2661167	et	4	main
töötasid	doc_491521502310_item	2661172	et	4	main
eestimaa	doc_491521502311_item	2661194	et	4	main
henricus	doc_491521502311_item	2661209	et	4	main
de	doc_491521502311_item	2661210	et	4	main
kes	doc_491521502311_item	2661215	et	4	main
sündis	doc_491521502311_item	2661216	et	3	main
1185a	doc_491521502311_item	2661218	et	4	main
põhja-saksamaal	doc_491521502311_item	2661219	et	4	main
sai	doc_491521502311_item	2661222	et	4	main
hariduse	doc_491521502311_item	2661225	et	3	main
1205a	doc_491521502311_item	2661226	et	4	main
pühitseti	doc_491521502311_item	2661227	et	3	main
on	doc_491521502311_item	2661232	et	4	main
kirjutatud	doc_491521502311_item	2661237	et	4	main
originaalkäsikiri	doc_491521502311_item	2661244	et	3	main
korda	doc_491521502311_item	2661260	et	4	main
liivimaa	doc_491521502311_item	2661279	et	4	main
eestlaste	doc_491521502311_item	2661284	et	4	main
võõrale	doc_491521502311_item	2661288	et	4	main
võimule	doc_491521502311_item	2661289	et	3	main
allutamise	doc_491521502311_item	2661290	et	4	main
raamatus	doc_491521502311_item	2661300	et	4	main
esmakordselt	doc_491521502311_item	2661302	et	4	main
teoorjus	doc_491521502311_item	2661318	et	3	main
see	doc_491521502311_item	2661320	et	3	main
kasvavad	doc_491521502311_item	2661330	et	4	main
ta	doc_491521502311_item	2661335	et	4	main
mälestis	doc_491521502310_item	2661022	et	3	main
keeles	doc_491521502310_item	2661033	et	4	main
püüdsid	doc_491521502310_item	2661041	et	4	main
religiosset	doc_491521502310_item	2661045	et	4	main
käsikiri	doc_491521502310_item	2661046	et	3	main
kirjutatakse	doc_491521502310_item	2661047	et	3	main
trükitud	doc_491521502310_item	2661057	et	4	main
1881	doc_491521502310_item	2661058	et	2	main
aastal	doc_491521502310_item	2661059	et	3	main
eesti	doc_491521502310_item	2661065	et	4	main
liivimaa	doc_491521502310_item	2661068	et	4	main
kirjutatud	doc_491521502310_item	2661075	et	4	main
eesti	doc_491521502310_item	2661076	et	4	main
keelsed	doc_491521502310_item	2661077	et	3	main
korda	doc_491521502310_item	2661084	et	4	main
kirja	doc_491521502310_item	2661088	et	4	main
pandud	doc_491521502310_item	2661089	et	4	main
praegu	doc_491521502310_item	2661090	et	3	main
kroonika	doc_491521502310_item	2661091	et	4	main
liivimaa	doc_491521502310_item	2661100	et	4	main
kroonika	doc_491521502310_item	2661110	et	4	main
mainitseb	doc_491521502310_item	2661113	et	4	main
ka	doc_491521502310_item	2661114	et	3	main
taarast	doc_491521502310_item	2661117	et	4	main
midagi	doc_491521502310_item	2661125	et	4	main
saada	doc_491521502310_item	2661127	et	4	main
teada	doc_491521502310_item	2661128	et	3	main
mis	doc_491521502310_item	2661133	et	4	main
pärast	doc_491521502310_item	2661147	et	4	main
töötas	doc_491521502310_item	2661148	et	3	main
notarina	doc_491521502310_item	2661149	et	3	main
see	doc_491521502310_item	2661150	et	3	main
järel	doc_491521502310_item	2661151	et	4	main
puust	doc_491521502310_item	2661158	et	4	main
teoorjus	doc_491521502310_item	2661160	et	3	main
kahekordselt	doc_491521502310_item	2661169	et	4	main
kuulusid	doc_491521502310_item	2661175	et	4	main
alandavam	doc_491521502310_item	2661183	et	4	main
1	doc_491521502311_item	2661188	et	2	main
millised	doc_491521502311_item	2661189	et	3	main
keskajast	doc_491521502311_item	2661195	et	4	main
kõige	doc_491521502311_item	2661201	et	4	main
kirjalik	doc_491521502311_item	2661203	et	3	main
allikas	doc_491521502311_item	2661204	et	4	main
on	doc_491521502311_item	2661205	et	4	main
eestimaast	doc_491521502310_item	2661104	et	3	main
usunditest	doc_491521502310_item	2661107	et	4	main
taevasega	doc_491521502310_item	2661121	et	4	main
koelli	doc_491521502310_item	2661131	et	4	main
katekismusest	doc_491521502310_item	2661132	et	4	main
aastal	doc_491521502310_item	2661136	et	3	main
susi	doc_491521502310_item	2661138	et	4	main
1575	doc_491521502310_item	2661152	et	2	main
keelne	doc_491521502310_item	2661156	et	3	main
ajal	doc_491521502310_item	2661168	et	4	main
mõisades	doc_491521502310_item	2661173	et	4	main
see	doc_491521502310_item	2661177	et	3	main
kõige	doc_491521502310_item	2661179	et	4	main
eestlaste	doc_491521502310_item	2661185	et	4	main
kontrolltöö	doc_491521502311_item	2661187	et	4	main
jutustavad	doc_491521502311_item	2661192	et	4	main
meile	doc_491521502311_item	2661193	et	4	main
tähendab	doc_491521502311_item	2661198	et	3	main
1	doc_491521502311_item	2661200	et	2	main
liivimaa	doc_491521502311_item	2661207	et	4	main
oli	doc_491521502311_item	2661212	et	3	main
balti	doc_491521502311_item	2661213	et	3	main
lähedal	doc_491521502311_item	2661221	et	4	main
ta	doc_491521502311_item	2661223	et	4	main
kloostrikooli	doc_491521502311_item	2661224	et	4	main
kroonika	doc_491521502311_item	2661231	et	4	main
on	doc_491521502311_item	2661236	et	4	main
eesti	doc_491521502311_item	2661254	et	4	main
keelde	doc_491521502311_item	2661255	et	4	main
tõlgiti	doc_491521502311_item	2661256	et	3	main
liivimaa	doc_491521502311_item	2661257	et	4	main
aastal	doc_491521502311_item	2661262	et	3	main
lätlaste	doc_491521502311_item	2661282	et	3	main
saabumisega	doc_491521502311_item	2661296	et	4	main
pandud	doc_491521502311_item	2661304	et	4	main
eestlaste	doc_491521502311_item	2661312	et	4	main
väidetavat	doc_491521502311_item	2661313	et	4	main
jumalat	doc_491521502311_item	2661314	et	3	main
talupoeg	doc_491521502311_item	2661322	et	3	main
kahekordselt	doc_491521502311_item	2661331	et	4	main
tootis	doc_491521502311_item	2661336	et	3	main
meile	doc_491521502313_item	2661558	et	4	main
eestimaa	doc_491521502313_item	2661559	et	4	main
tähendab	doc_491521502313_item	2661563	et	3	main
keskajast	doc_491521502313_item	2661575	et	4	main
oma	doc_491521502313_item	2661581	et	4	main
lettis	doc_491521502313_item	2661587	et	4	main
pühitsetakse	doc_491521502313_item	2661623	et	3	main
hästi	doc_491521502313_item	2661628	et	3	main
arvatavasti	doc_491521502313_item	2661649	et	3	main
oli	doc_491521502313_item	2661653	et	3	main
tänaseks	doc_491521502313_item	2661658	et	4	main
säilinud	doc_491521502313_item	2661659	et	4	main
hilisemate	doc_491521502313_item	2661663	et	4	main
tõlkes	doc_491521502313_item	2661678	et	3	main
et	doc_491521502310_item	2661123	et	3	main
hans	doc_491521502310_item	2661137	et	4	main
kirjutas	doc_491521502310_item	2661139	et	3	main
eesti	doc_491521502310_item	2661140	et	4	main
aastal	doc_491521502310_item	2661153	et	3	main
2	doc_491521502310_item	2661159	et	2	main
mõisas	doc_491521502310_item	2661165	et	3	main
mis	doc_491521502310_item	2661166	et	4	main
mis	doc_491521502310_item	2661174	et	4	main
oli	doc_491521502310_item	2661178	et	3	main
töö	doc_491521502310_item	2661184	et	4	main
jaoks	doc_491521502310_item	2661186	et	4	main
kirjalikud	doc_491521502311_item	2661190	et	3	main
allikad	doc_491521502311_item	2661191	et	3	main
mida	doc_491521502311_item	2661197	et	4	main
henriku	doc_491521502311_item	2661206	et	4	main
lettis	doc_491521502311_item	2661211	et	4	main
umbes	doc_491521502311_item	2661217	et	4	main
lüübeki	doc_491521502311_item	2661220	et	4	main
ta	doc_491521502311_item	2661228	et	4	main
preestriks	doc_491521502311_item	2661229	et	4	main
teos	doc_491521502311_item	2661234	et	4	main
säilinud	doc_491521502311_item	2661246	et	4	main
liivimaa	doc_491521502311_item	2661247	et	4	main
trükiti	doc_491521502311_item	2661249	et	3	main
esimest	doc_491521502311_item	2661250	et	4	main
kroonika	doc_491521502311_item	2661258	et	4	main
on	doc_491521502311_item	2661278	et	4	main
liivlaste	doc_491521502311_item	2661281	et	4	main
esivanemate	doc_491521502311_item	2661285	et	4	main
ja	doc_491521502311_item	2661287	et	3	main
preester	doc_491521502311_item	2661294	et	4	main
selles	doc_491521502311_item	2661299	et	4	main
on	doc_491521502311_item	2661301	et	4	main
tharapitat	doc_491521502311_item	2661315	et	4	main
oluline	doc_491521502311_item	2661233	et	4	main
umbes	doc_491521502311_item	2661238	et	4	main
1224-12278	doc_491521502311_item	2661239	et	2	main
aastal	doc_491521502311_item	2661240	et	3	main
aga	doc_491521502311_item	2661243	et	3	main
korda	doc_491521502311_item	2661251	et	4	main
aastal	doc_491521502311_item	2661252	et	3	main
1740	doc_491521502311_item	2661253	et	2	main
esimest	doc_491521502311_item	2661259	et	4	main
j	doc_491521502311_item	2661263	et	4	main
jungi	doc_491521502311_item	2661264	et	4	main
poolt	doc_491521502311_item	2661265	et	4	main
veel	doc_491521502311_item	2661266	et	4	main
on	doc_491521502311_item	2661267	et	4	main
liivimaa	doc_491521502311_item	2661268	et	4	main
kroonikat	doc_491521502311_item	2661269	et	3	main
tõlgitud	doc_491521502311_item	2661270	et	4	main
inglise	doc_491521502311_item	2661271	et	4	main
saksa	doc_491521502311_item	2661272	et	4	main
ja	doc_491521502311_item	2661273	et	3	main
vene	doc_491521502311_item	2661274	et	4	main
keelde	doc_491521502311_item	2661275	et	4	main
henriku	doc_491521502311_item	2661276	et	4	main
kroonika	doc_491521502311_item	2661277	et	4	main
põlisrahvaste	doc_491521502311_item	2661280	et	4	main
ja	doc_491521502311_item	2661283	et	3	main
ristiusustamise	doc_491521502311_item	2661286	et	3	main
see	doc_491521502311_item	2661292	et	3	main
algab	doc_491521502311_item	2661293	et	3	main
meinhardi	doc_491521502311_item	2661295	et	4	main
aastal	doc_491521502311_item	2661298	et	3	main
kirja	doc_491521502311_item	2661303	et	4	main
eestlaste	doc_491521502311_item	2661307	et	4	main
taara	doc_491521502311_item	2661316	et	4	main
kus	doc_491521502311_item	2661321	et	3	main
füüsilist	doc_491521502311_item	2661325	et	3	main
pool	doc_491521502311_item	2661332	et	4	main
läks	doc_491521502311_item	2661337	et	3	main
keskajast	doc_491521502313_item	2661560	et	4	main
teoorjus	doc_491521502313_item	2661564	et	3	main
taani	doc_491521502313_item	2661570	et	4	main
liivimaa	doc_491521502313_item	2661577	et	4	main
kroonika	doc_491521502313_item	2661578	et	4	main
preestriks	doc_491521502313_item	2661625	et	4	main
keli	doc_491521502313_item	2661630	et	4	main
läti	doc_491521502313_item	2661631	et	4	main
liivi	doc_491521502313_item	2661632	et	4	main
p-eesti	doc_491521502313_item	2661633	et	4	main
koht	doc_491521502313_item	2661641	et	3	main
loos	doc_491521502313_item	2661644	et	4	main
liivimaa	doc_491521502313_item	2661645	et	4	main
kirjutatud	doc_491521502313_item	2661648	et	4	main
ladina	doc_491521502313_item	2661654	et	4	main
mõisas	doc_491521502311_item	2661324	et	3	main
tööd	doc_491521502311_item	2661326	et	4	main
tegema	doc_491521502311_item	2661327	et	3	main
sellest	doc_491521502311_item	2661333	et	4	main
mida	doc_491521502311_item	2661334	et	4	main
mõisnikule	doc_491521502311_item	2661339	et	3	main
maksudeks	doc_491521502311_item	2661338	et	3	main
kontrolltöö	doc_491521502313_item	2661552	et	4	main
1	doc_491521502313_item	2661553	et	2	main
millised	doc_491521502313_item	2661554	et	3	main
kirjalikud	doc_491521502313_item	2661555	et	3	main
allikad	doc_491521502313_item	2661556	et	3	main
2	doc_491521502313_item	2661561	et	2	main
jutustavad	doc_491521502313_item	2661572	et	4	main
ladina	doc_491521502313_item	2661583	et	4	main
de	doc_491521502313_item	2661586	et	4	main
henrik	doc_491521502313_item	2661588	et	4	main
misjonärina	doc_491521502313_item	2661621	et	3	main
ilmselt	doc_491521502313_item	2661626	et	4	main
oskas	doc_491521502313_item	2661627	et	3	main
kohalikke	doc_491521502313_item	2661629	et	4	main
tema	doc_491521502313_item	2661636	et	4	main
kroonika	doc_491521502313_item	2661638	et	4	main
eestlaste	doc_491521502313_item	2661642	et	4	main
on	doc_491521502313_item	2661647	et	4	main
originaal	doc_491521502313_item	2661651	et	3	main
kroonika	doc_491521502313_item	2661660	et	4	main
tuntud	doc_491521502313_item	2661662	et	4	main
järgi	doc_491521502313_item	2661665	et	4	main
ilmus	doc_491521502313_item	2661668	et	4	main
saksamaal	doc_491521502313_item	2661671	et	4	main
jjungi	doc_491521502313_item	2661677	et	4	main
kroonikas	doc_491521502313_item	2661680	et	3	main
kirja	doc_491521502313_item	2661694	et	4	main
seal	doc_491521502313_item	2661700	et	4	main
jutustavad	doc_491521502313_item	2661557	et	4	main
1	doc_491521502313_item	2661565	et	2	main
liivimaa	doc_491521502313_item	2661567	et	4	main
henriku	doc_491521502313_item	2661576	et	4	main
nime	doc_491521502313_item	2661582	et	4	main
henrikus	doc_491521502313_item	2661585	et	4	main
mida	doc_491521502313_item	2661562	et	4	main
henriku	doc_491521502313_item	2661566	et	4	main
kroonika	doc_491521502313_item	2661568	et	4	main
ja	doc_491521502313_item	2661569	et	3	main
hindlamisraamat	doc_491521502313_item	2661571	et	4	main
meile	doc_491521502313_item	2661573	et	4	main
eestimaa	doc_491521502313_item	2661574	et	4	main
henrik	doc_491521502313_item	2661579	et	4	main
märkis	doc_491521502313_item	2661580	et	3	main
keeles	doc_491521502313_item	2661584	et	4	main
lätist	doc_491521502313_item	2661589	et	4	main
mujal	doc_491521502313_item	2661590	et	3	main
maailmas	doc_491521502313_item	2661591	et	3	main
teatakse	doc_491521502313_item	2661592	et	3	main
teda	doc_491521502313_item	2661593	et	4	main
kui	doc_491521502313_item	2661594	et	3	main
balti	doc_491521502313_item	2661595	et	3	main
kroonikut	doc_491521502313_item	2661596	et	3	main
elulugu	doc_491521502313_item	2661597	et	4	main
on	doc_491521502313_item	2661598	et	4	main
segane	doc_491521502313_item	2661599	et	3	main
vasturääkiv	doc_491521502313_item	2661600	et	4	main
sündis	doc_491521502313_item	2661601	et	3	main
umbes	doc_491521502313_item	2661602	et	4	main
1185	doc_491521502313_item	2661603	et	2	main
a	doc_491521502313_item	2661604	et	4	main
ja	doc_491521502313_item	2661605	et	3	main
on	doc_491521502313_item	2661606	et	4	main
pärit	doc_491521502313_item	2661607	et	3	main
põhja-saksamaalt	doc_491521502313_item	2661608	et	3	main
magdeburgist	doc_491521502313_item	2661609	et	4	main
kloostrihariduse	doc_491521502313_item	2661610	et	3	main
sai	doc_491521502313_item	2661611	et	4	main
lüübekist	doc_491521502313_item	2661612	et	4	main
arvatakse	doc_491521502313_item	2661613	et	3	main
et	doc_491521502313_item	2661614	et	3	main
ta	doc_491521502313_item	2661615	et	4	main
tuli	doc_491521502313_item	2661616	et	4	main
baltikumi	doc_491521502313_item	2661617	et	4	main
umbes	doc_491521502313_item	2661618	et	4	main
1205	doc_491521502313_item	2661619	et	2	main
a	doc_491521502313_item	2661620	et	4	main
1208a	doc_491521502313_item	2661622	et	4	main
lõuna-eesti	doc_491521502313_item	2661635	et	4	main
ta	doc_491521502313_item	2661624	et	4	main
ja	doc_491521502313_item	2661634	et	3	main
kroonika	doc_491521502313_item	2661646	et	4	main
1224-12278	doc_491521502313_item	2661650	et	2	main
käsikiri	doc_491521502313_item	2661652	et	3	main
esimest	doc_491521502313_item	2661666	et	4	main
korda	doc_491521502313_item	2661667	et	4	main
korda	doc_491521502313_item	2661676	et	4	main
esimest	doc_491521502313_item	2661682	et	4	main
korda	doc_491521502313_item	2661683	et	4	main
ära	doc_491521502313_item	2661684	et	4	main
kirjas	doc_491521502313_item	2661701	et	4	main
palju	doc_491521502313_item	2661704	et	4	main
on	doc_491521502313_item	2661705	et	4	main
teateid	doc_491521502313_item	2661706	et	3	main
eestlaste	doc_491521502313_item	2661707	et	4	main
muistse	doc_491521502313_item	2661708	et	3	main
usundi	doc_491521502313_item	2661709	et	3	main
kohta	doc_491521502313_item	2661710	et	4	main
mainitakse	doc_491521502313_item	2661711	et	3	main
ära	doc_491521502313_item	2661712	et	4	main
ka	doc_491521502313_item	2661713	et	3	main
eesltaste	doc_491521502313_item	2661714	et	4	main
jumal	doc_491521502313_item	2661715	et	3	main
tharapita	doc_491521502313_item	2661716	et	4	main
millest	doc_491521502313_item	2661717	et	3	main
on	doc_491521502313_item	2661718	et	4	main
tultetatud	doc_491521502313_item	2661719	et	4	main
taara	doc_491521502313_item	2661720	et	4	main
arvatakse	doc_491521502313_item	2661722	et	3	main
tulnud	doc_491521502313_item	2661724	et	4	main
oleks	doc_491521502313_item	2661743	et	3	main
on	doc_491521502313_item	2661757	et	4	main
antud	doc_491521502313_item	2661758	et	4	main
2	doc_491521502313_item	2661780	et	2	main
kroonika	doc_491521502313_item	2661789	et	4	main
oli	doc_491521502313_item	2661790	et	3	main
esimene	doc_491521502313_item	2661791	et	3	main
laadina	doc_491521502313_item	2661792	et	3	main
keelne	doc_491521502313_item	2661793	et	3	main
ristisõdu	doc_491521502313_item	2661797	et	3	main
rahvaste	doc_491521502313_item	2661799	et	4	main
koostatud	doc_491521502313_item	2661637	et	4	main
on	doc_491521502313_item	2661639	et	4	main
oluline	doc_491521502313_item	2661640	et	4	main
kultuuri	doc_491521502313_item	2661643	et	4	main
keeles	doc_491521502313_item	2661655	et	4	main
pole	doc_491521502313_item	2661657	et	3	main
ärakirjade	doc_491521502313_item	2661664	et	3	main
teadaolevalt	doc_491521502313_item	2661670	et	4	main
1740a1881a	doc_491521502313_item	2661672	et	3	main
eesti	doc_491521502313_item	2661673	et	4	main
väljendeid	doc_491521502313_item	2661688	et	3	main
esimest	doc_491521502313_item	2661691	et	4	main
korda	doc_491521502313_item	2661692	et	4	main
on	doc_491521502313_item	2661693	et	4	main
samuti	doc_491521502313_item	2661698	et	3	main
on	doc_491521502313_item	2661699	et	4	main
oleva	doc_491521502313_item	2661723	et	4	main
thor	doc_491521502313_item	2661726	et	4	main
äikesejumal	doc_491521502313_item	2661727	et	3	main
õlut	doc_491521502313_item	2661740	et	3	main
et	doc_491521502313_item	2661741	et	3	main
saksa	doc_491521502313_item	2661752	et	4	main
saj	doc_491521502313_item	2661765	et	4	main
eestis	doc_491521502313_item	2661769	et	3	main
inimese	doc_491521502313_item	2661778	et	4	main
teoorjus	doc_491521502313_item	2661781	et	3	main
töö	doc_491521502313_item	2661783	et	4	main
mõisas	doc_491521502313_item	2661785	et	3	main
henriku	doc_491521502313_item	2661787	et	4	main
kroonika	doc_491521502313_item	2661794	et	4	main
sõdimine	doc_491521502315_item	2661971	et	4	main
saj	doc_491521502315_item	2661975	et	4	main
loobub	doc_491521502315_item	2661977	et	3	main
ei	doc_491521502315_item	2661981	et	4	main
mõõgavendade	doc_491521502315_item	2661992	et	3	main
abil	doc_491521502315_item	2661998	et	4	main
eestlaste	doc_491521502315_item	2662037	et	4	main
venelaste	doc_491521502315_item	2662039	et	4	main
kreeka-rooma	doc_491521502315_item	2662044	et	4	main
kiriku	doc_491521502315_item	2662045	et	3	main
killustatus	doc_491521502315_item	2662053	et	4	main
eesti	doc_491521502315_item	2662054	et	4	main
eesti	doc_491521502315_item	2662058	et	4	main
feodaalriigid	doc_491521502315_item	2662067	et	4	main
kesk-	doc_491521502315_item	2662068	et	3	main
liivi	doc_491521502315_item	2662072	et	4	main
põhja-eestit	doc_491521502315_item	2662074	et	3	main
osa	doc_491521502315_item	2662077	et	4	main
taanile	doc_491521502315_item	2662078	et	4	main
saare-lääne	doc_491521502315_item	2662084	et	4	main
piiskopkonna	doc_491521502315_item	2662085	et	3	main
valitseda	doc_491521502315_item	2662086	et	3	main
kagu-eestis	doc_491521502315_item	2662087	et	3	main
maarahvas	doc_491521502315_item	2662094	et	4	main
maarahvas	doc_491521502315_item	2662098	et	4	main
on	doc_491521502315_item	2662099	et	4	main
ühiskondlik	doc_491521502315_item	2662105	et	3	main
see	doc_491521502313_item	2661656	et	3	main
on	doc_491521502313_item	2661661	et	4	main
trükis	doc_491521502313_item	2661669	et	4	main
keeles	doc_491521502313_item	2661674	et	4	main
esimest	doc_491521502313_item	2661675	et	4	main
seal	doc_491521502313_item	2661679	et	4	main
on	doc_491521502313_item	2661681	et	4	main
keelseid	doc_491521502313_item	2661687	et	3	main
lauseid	doc_491521502313_item	2661690	et	3	main
eesti	doc_491521502313_item	2661696	et	4	main
keelt	doc_491521502313_item	2661697	et	4	main
nimesid	doc_491521502313_item	2661703	et	3	main
nimi	doc_491521502313_item	2661721	et	3	main
et	doc_491521502313_item	2661733	et	3	main
see	doc_491521502313_item	2661734	et	3	main
tähendas	doc_491521502313_item	2661736	et	3	main
õlletunni	doc_491521502313_item	2661737	et	3	main
saarlased	doc_491521502313_item	2661738	et	3	main
nõudsid	doc_491521502313_item	2661739	et	4	main
ja	doc_491521502313_item	2661753	et	3	main
taani	doc_491521502313_item	2661760	et	4	main
hindlamisraamat	doc_491521502313_item	2661761	et	4	main
taanlased	doc_491521502313_item	2661768	et	3	main
nimesid	doc_491521502313_item	2661779	et	3	main
füüsilise	doc_491521502313_item	2661782	et	3	main
tegemine	doc_491521502313_item	2661784	et	4	main
mis	doc_491521502313_item	2661795	et	4	main
siinsete	doc_491521502313_item	2661798	et	4	main
elu	doc_491521502313_item	2661800	et	4	main
kombeid	doc_491521502313_item	2661801	et	4	main
tavasid	doc_491521502313_item	2661802	et	3	main
1	doc_491521502315_item	2661968	et	2	main
ristiusustamisega	doc_491521502315_item	2661969	et	3	main
kohaselt	doc_491521502315_item	2661980	et	4	main
ristiusustada	doc_491521502315_item	2661985	et	3	main
ristisõdijad	doc_491521502315_item	2661986	et	3	main
eestlased	doc_491521502315_item	2661994	et	3	main
maeti	doc_491521502315_item	2662028	et	3	main
seadused	doc_491521502315_item	2662030	et	3	main
valul	doc_491521502315_item	2662040	et	3	main
taanlased	doc_491521502315_item	2662047	et	3	main
all	doc_491521502315_item	2662057	et	3	main
omaette	doc_491521502315_item	2662061	et	3	main
ja	doc_491521502315_item	2662069	et	3	main
ordule	doc_491521502315_item	2662073	et	3	main
läänemaa	doc_491521502315_item	2662080	et	4	main
saared	doc_491521502315_item	2662082	et	3	main
toodud	doc_491521502313_item	2661685	et	4	main
eesti	doc_491521502313_item	2661686	et	4	main
ja	doc_491521502313_item	2661689	et	3	main
pandud	doc_491521502313_item	2661695	et	4	main
eestlaste	doc_491521502313_item	2661702	et	4	main
järeldusele	doc_491521502313_item	2661732	et	4	main
tharapita	doc_491521502313_item	2661735	et	4	main
vaenlasele	doc_491521502313_item	2661744	et	3	main
minna	doc_491521502313_item	2661746	et	3	main
on	doc_491521502313_item	2661748	et	4	main
vene	doc_491521502313_item	2661750	et	4	main
läti	doc_491521502313_item	2661751	et	4	main
keelde	doc_491521502313_item	2661755	et	4	main
kordustrükke	doc_491521502313_item	2661756	et	3	main
12-13	doc_491521502313_item	2661764	et	2	main
kirjeldab	doc_491521502313_item	2661766	et	3	main
kuidas	doc_491521502313_item	2661767	et	3	main
vallutusretkeil	doc_491521502313_item	2661770	et	4	main
käisid	doc_491521502313_item	2661771	et	4	main
mainitud	doc_491521502313_item	2661773	et	4	main
kohanimesid	doc_491521502313_item	2661775	et	3	main
ja	doc_491521502313_item	2661776	et	3	main
1	doc_491521502313_item	2661786	et	2	main
liivimaa	doc_491521502313_item	2661788	et	4	main
kirjeldas	doc_491521502313_item	2661796	et	3	main
skandinaaviast	doc_491521502313_item	2661725	et	3	main
parun	doc_491521502313_item	2661728	et	3	main
von	doc_491521502313_item	2661729	et	4	main
luce	doc_491521502313_item	2661730	et	4	main
jõudis	doc_491521502313_item	2661731	et	3	main
julgem	doc_491521502313_item	2661742	et	4	main
vastu	doc_491521502313_item	2661745	et	3	main
seda	doc_491521502313_item	2661747	et	3	main
tõlgitud	doc_491521502313_item	2661749	et	4	main
inglise	doc_491521502313_item	2661754	et	4	main
hiljutigi	doc_491521502313_item	2661759	et	4	main
sako	doc_491521502313_item	2661762	et	4	main
grammaticus	doc_491521502313_item	2661763	et	4	main
on	doc_491521502313_item	2661772	et	4	main
põhja-eesti	doc_491521502313_item	2661774	et	4	main
ka	doc_491521502313_item	2661777	et	3	main
1	doc_491521502315_item	2661957	et	2	main
mõjud	doc_491521502315_item	2661959	et	4	main
eesti	doc_491521502315_item	2661960	et	4	main
ühiskonnakorraldusele	doc_491521502315_item	2661961	et	3	main
1316	doc_491521502315_item	2661962	et	2	main
sajandil	doc_491521502315_item	2661963	et	3	main
2	doc_491521502315_item	2661964	et	2	main
kirik	doc_491521502315_item	2661973	et	3	main
tohi	doc_491521502315_item	2661982	et	4	main
lunastust	doc_491521502315_item	2661990	et	4	main
lätlaste	doc_491521502315_item	2661997	et	3	main
kontrolltöö	doc_491521502315_item	2661956	et	4	main
ristiusustamise	doc_491521502315_item	2661958	et	3	main
kaasnes	doc_491521502315_item	2661970	et	3	main
katolik	doc_491521502315_item	2661972	et	4	main
keskpaiku	doc_491521502315_item	2661976	et	4	main
kedagi	doc_491521502315_item	2661983	et	4	main
1202	doc_491521502315_item	2661991	et	2	main
alistati	doc_491521502315_item	2661995	et	3	main
sunniti	doc_491521502315_item	2662000	et	3	main
rüüstades	doc_491521502315_item	2661999	et	4	main
ristiusku	doc_491521502315_item	2662001	et	4	main
vastu	doc_491521502315_item	2662002	et	3	main
võtma	doc_491521502315_item	2662003	et	3	main
uus	doc_491521502315_item	2662004	et	3	main
oli	doc_491521502315_item	2662005	et	3	main
feodaalkord	doc_491521502315_item	2662006	et	4	main
linna-	doc_491521502315_item	2662007	et	4	main
ja	doc_491521502315_item	2662008	et	3	main
kirjakultuur	doc_491521502315_item	2662009	et	3	main
ristiusustamine	doc_491521502315_item	2662010	et	3	main
lõppes	doc_491521502315_item	2662011	et	4	main
saaremaa	doc_491521502315_item	2662012	et	4	main
saarlastega	doc_491521502315_item	2662014	et	4	main
sõlmiti	doc_491521502315_item	2662015	et	3	main
1241	doc_491521502315_item	2662016	et	2	main
kirjalik	doc_491521502315_item	2662017	et	3	main
leping	doc_491521502315_item	2662018	et	3	main
saarlased	doc_491521502315_item	2662019	et	3	main
pöörduvad	doc_491521502315_item	2662020	et	4	main
alistamine	doc_491521502315_item	2662013	et	4	main
elusalt	doc_491521502315_item	2662029	et	4	main
erinesid	doc_491521502315_item	2662032	et	4	main
muistsest	doc_491521502315_item	2662033	et	3	main
ajast	doc_491521502315_item	2662034	et	4	main
1242	doc_491521502315_item	2662035	et	2	main
jäälahing	doc_491521502315_item	2662036	et	3	main
ja	doc_491521502315_item	2662038	et	3	main
peipsil	doc_491521502315_item	2662041	et	4	main
taani	doc_491521502315_item	2662055	et	4	main
võimu	doc_491521502315_item	2662056	et	4	main
igaühel	doc_491521502315_item	2662063	et	3	main
valitseja	doc_491521502315_item	2662065	et	4	main
väikesed	doc_491521502315_item	2662066	et	4	main
kuulub	doc_491521502315_item	2662071	et	3	main
mingi	doc_491521502315_item	2662076	et	4	main
jäävad	doc_491521502315_item	2662083	et	4	main
moodustatakse	doc_491521502315_item	2662088	et	3	main
kujuneb	doc_491521502315_item	2662092	et	3	main
ülemkiht	doc_491521502315_item	2662096	et	3	main
mentaliteet	doc_491521502315_item	2662104	et	3	main
kord	doc_491521502315_item	2662106	et	4	main
saj	doc_491521502315_item	2662112	et	4	main
mida	doc_491521502315_item	2661965	et	4	main
tähendab	doc_491521502315_item	2661966	et	3	main
reformatsioon	doc_491521502315_item	2661967	et	3	main
11	doc_491521502315_item	2661974	et	2	main
reeglitest	doc_491521502315_item	2661978	et	4	main
mille	doc_491521502315_item	2661979	et	3	main
vägivaldselt	doc_491521502315_item	2661984	et	4	main
vajasid	doc_491521502315_item	2661987	et	4	main
pattudest	doc_491521502315_item	2661988	et	3	main
pääsemiseks	doc_491521502315_item	2661989	et	4	main
ordu	doc_491521502315_item	2661993	et	4	main
liivlaste	doc_491521502315_item	2661996	et	4	main
vabatahtlikult	doc_491521502315_item	2662021	et	4	main
maksta	doc_491521502315_item	2662023	et	4	main
lubati	doc_491521502315_item	2662024	et	3	main
teraviljas	doc_491521502315_item	2662025	et	3	main
varguselt	doc_491521502315_item	2662026	et	3	main
tabatu	doc_491521502315_item	2662027	et	4	main
kirjalikud	doc_491521502315_item	2662031	et	3	main
otsustab	doc_491521502315_item	2662043	et	3	main
kaasneb	doc_491521502315_item	2662052	et	3	main
4	doc_491521502315_item	2662060	et	2	main
piirkonnaks	doc_491521502315_item	2662062	et	4	main
oma	doc_491521502315_item	2662064	et	4	main
rannikueesti	doc_491521502315_item	2662079	et	4	main
rahvas	doc_491521502315_item	2662091	et	4	main
sunnitud	doc_491521502315_item	2662100	et	4	main
ümberorienteeruma	doc_491521502315_item	2662101	et	4	main
kombed	doc_491521502315_item	2662102	et	3	main
tavad	doc_491521502315_item	2662103	et	3	main
stabiilne	doc_491521502315_item	2662107	et	3	main
ehitama	doc_491521502315_item	2662123	et	4	main
kirikud	doc_491521502315_item	2662125	et	3	main
kloostreid	doc_491521502315_item	2662126	et	3	main
loobuma	doc_491521502315_item	2662128	et	3	main
mitmenaisepidamisest	doc_491521502315_item	2662129	et	3	main
lapsed	doc_491521502315_item	2662130	et	3	main
sündides	doc_491521502315_item	2662131	et	4	main
talurahvas	doc_491521502315_item	2662137	et	4	main
kasvavad	doc_491521502315_item	2662154	et	4	main
valdavalt	doc_491521502315_item	2662164	et	4	main
pakkusid	doc_491521502315_item	2662166	et	4	main
rahvale	doc_491521502315_item	2662167	et	3	main
ka	doc_491521502315_item	2662168	et	3	main
haridus	doc_491521502315_item	2662173	et	3	main
kirikuga	doc_491521502315_item	2662175	et	3	main
2	doc_491521502315_item	2662177	et	2	main
olevat	doc_491521502315_item	2662182	et	4	main
materjaalne	doc_491521502315_item	2662184	et	4	main
makse	doc_491521502315_item	2662188	et	4	main
kirik	doc_491521502315_item	2662196	et	3	main
oli	doc_491521502315_item	2662222	et	3	main
1	doc_491521502316_item	2662226	et	2	main
mõjud	doc_491521502316_item	2662228	et	4	main
eesti	doc_491521502316_item	2662229	et	4	main
ühiskonnakorraldusele	doc_491521502316_item	2662230	et	3	main
1	doc_491521502316_item	2662237	et	2	main
roomas	doc_491521502316_item	2662240	et	4	main
põgenikena	doc_491521502316_item	2662245	et	3	main
sest	doc_491521502316_item	2662246	et	4	main
valmis	doc_491521502316_item	2662252	et	4	main
maailma	doc_491521502316_item	2662258	et	4	main
kiriku	doc_491521502316_item	2662260	et	3	main
eestisse	doc_491521502316_item	2662278	et	4	main
suured	doc_491521502316_item	2662289	et	3	main
elasid	doc_491521502316_item	2662293	et	4	main
kas	doc_491521502316_item	2662298	et	3	main
elas	doc_491521502316_item	2662299	et	3	main
maal	doc_491521502316_item	2662300	et	4	main
maksma	doc_491521502316_item	2662309	et	3	main
last	doc_491521502316_item	2662320	et	4	main
matmist	doc_491521502316_item	2662331	et	4	main
ma	doc_491521502316_item	2662332	et	3	main
peale	doc_491521502316_item	2662333	et	4	main
ei	doc_491521502316_item	2662349	et	4	main
aru	doc_491521502316_item	2662352	et	4	main
talupojad	doc_491521502316_item	2662353	et	4	main
muid	doc_491521502316_item	2662361	et	4	main
ristiusku	doc_491521502315_item	2662022	et	4	main
see	doc_491521502315_item	2662042	et	3	main
piirid	doc_491521502315_item	2662046	et	3	main
huvitatud	doc_491521502315_item	2662048	et	4	main
siinsest	doc_491521502315_item	2662049	et	3	main
alast	doc_491521502315_item	2662050	et	4	main
sellega	doc_491521502315_item	2662051	et	3	main
jagatakse	doc_491521502315_item	2662059	et	3	main
lõuna-eesti	doc_491521502315_item	2662070	et	4	main
jääb	doc_491521502315_item	2662075	et	3	main
ja	doc_491521502315_item	2662081	et	3	main
tartu	doc_491521502315_item	2662089	et	4	main
jääb	doc_491521502315_item	2662108	et	3	main
kuni	doc_491521502315_item	2662110	et	3	main
poliitiliseks	doc_491521502315_item	2662113	et	3	main
ülemkihti	doc_491521502315_item	2662139	et	4	main
toiduga	doc_491521502315_item	2662140	et	3	main
varustama	doc_491521502315_item	2662141	et	3	main
uued	doc_491521502315_item	2662142	et	3	main
tööoskused	doc_491521502315_item	2662143	et	3	main
käsitöö	doc_491521502315_item	2662144	et	4	main
maaharimine	doc_491521502315_item	2662145	et	3	main
korraldab	doc_491521502315_item	2662156	et	3	main
ümber	doc_491521502315_item	2662157	et	3	main
adminastriinse	doc_491521502315_item	2662159	et	4	main
jaotuse	doc_491521502315_item	2662160	et	4	main
kirikukihelkond	doc_491521502315_item	2662161	et	3	main
rändmungad	doc_491521502315_item	2662162	et	3	main
tegelesid	doc_491521502315_item	2662163	et	4	main
uusi	doc_491521502315_item	2662171	et	3	main
rikastumine	doc_491521502315_item	2662185	et	4	main
kõigilt	doc_491521502315_item	2662187	et	4	main
ja	doc_491521502315_item	2662192	et	3	main
nõudeks	doc_491521502315_item	2662221	et	4	main
emakeelne	doc_491521502315_item	2662223	et	3	main
sajandil	doc_491521502316_item	2662232	et	3	main
tähendab	doc_491521502316_item	2662235	et	3	main
ristiusk	doc_491521502316_item	2662238	et	3	main
kristlased	doc_491521502316_item	2662242	et	3	main
pidid	doc_491521502316_item	2662243	et	4	main
elama	doc_491521502316_item	2662244	et	3	main
veel	doc_491521502316_item	2662251	et	4	main
roomast	doc_491521502316_item	2662256	et	4	main
kirikuid	doc_491521502316_item	2662273	et	4	main
kuid	doc_491521502316_item	2662291	et	4	main
eesti	doc_491521502316_item	2662296	et	4	main
rahvas	doc_491521502316_item	2662297	et	4	main
talupojad	doc_491521502316_item	2662306	et	4	main
kümnist	doc_491521502316_item	2662310	et	3	main
nad	doc_491521502316_item	2662313	et	3	main
ristida	doc_491521502316_item	2662321	et	4	main
eluaastast	doc_491521502316_item	2662325	et	4	main
mis	doc_491521502316_item	2662334	et	4	main
oli	doc_491521502316_item	2662335	et	3	main
eestis	doc_491521502316_item	2662336	et	3	main
väga	doc_491521502316_item	2662337	et	3	main
levinud	doc_491521502316_item	2662338	et	4	main
kuid	doc_491521502316_item	2662339	et	4	main
jumala	doc_491521502316_item	2662340	et	3	main
ainult	doc_491521502316_item	2662343	et	4	main
nendest	doc_491521502316_item	2662351	et	4	main
vett	doc_491521502316_item	2662357	et	3	main
piima	doc_491521502316_item	2662358	et	4	main
näiteks	doc_491521502316_item	2662388	et	4	main
ka	doc_491521502316_item	2662393	et	3	main
maale	doc_491521502316_item	2662394	et	4	main
kasu	doc_491521502316_item	2662403	et	4	main
aru	doc_491521502316_item	2662412	et	4	main
kõige	doc_491521502316_item	2662430	et	4	main
olulisem	doc_491521502316_item	2662431	et	4	main
läbi	doc_491521502316_item	2662441	et	4	main
enam	doc_491521502316_item	2662448	et	4	main
reformatsioon	doc_491521502316_item	2662453	et	3	main
sõna	doc_491521502316_item	2662468	et	4	main
mida	doc_491521502317_item	2662490	et	4	main
reformatsioon	doc_491521502317_item	2662492	et	3	main
tekkis	doc_491521502317_item	2662497	et	3	main
kasutanud	doc_491521502317_item	2662511	et	4	main
asendus	doc_491521502317_item	2662517	et	4	main
piiskopkond	doc_491521502315_item	2662090	et	3	main
kaheks	doc_491521502315_item	2662093	et	4	main
eestlane	doc_491521502315_item	2662095	et	3	main
sakslane	doc_491521502315_item	2662097	et	3	main
püsima	doc_491521502315_item	2662109	et	3	main
16	doc_491521502315_item	2662111	et	2	main
kümnist	doc_491521502315_item	2662121	et	3	main
kabeleid	doc_491521502315_item	2662124	et	4	main
surnud	doc_491521502315_item	2662133	et	4	main
matma	doc_491521502315_item	2662134	et	3	main
pühitsetudõnnistatud	doc_491521502315_item	2662135	et	4	main
muudkui	doc_491521502315_item	2662153	et	3	main
misjonitööga	doc_491521502315_item	2662165	et	3	main
tundus	doc_491521502315_item	2662181	et	3	main
nõudis	doc_491521502315_item	2662186	et	3	main
tegeleti	doc_491521502315_item	2662194	et	3	main
jumalateenistus	doc_491521502315_item	2662224	et	3	main
kontrolltöö	doc_491521502316_item	2662225	et	4	main
ristiusustamise	doc_491521502316_item	2662227	et	3	main
mida	doc_491521502316_item	2662234	et	4	main
vana	doc_491521502316_item	2662247	et	4	main
maailm	doc_491521502316_item	2662248	et	3	main
ei	doc_491521502316_item	2662249	et	4	main
keskus	doc_491521502316_item	2662261	et	3	main
tuli	doc_491521502316_item	2662263	et	4	main
sajandil	doc_491521502316_item	2662266	et	3	main
esimene	doc_491521502316_item	2662267	et	3	main
oli	doc_491521502316_item	2662269	et	3	main
meinchard	doc_491521502316_item	2662270	et	4	main
hakkati	doc_491521502316_item	2662271	et	3	main
ehitama	doc_491521502316_item	2662272	et	4	main
algasid	doc_491521502316_item	2662284	et	4	main
ristiretked	doc_491521502316_item	2662285	et	3	main
nüüd	doc_491521502316_item	2662286	et	4	main
hakkasid	doc_491521502316_item	2662287	et	4	main
ilmuma	doc_491521502316_item	2662288	et	3	main
linnas	doc_491521502316_item	2662305	et	4	main
nüüd	doc_491521502316_item	2662308	et	4	main
võimuks	doc_491521502315_item	2662114	et	4	main
talupoegadelt	doc_491521502315_item	2662116	et	3	main
hakatakse	doc_491521502315_item	2662117	et	3	main
hakatakse	doc_491521502315_item	2662122	et	3	main
peavad	doc_491521502315_item	2662127	et	4	main
mulda	doc_491521502315_item	2662136	et	4	main
küla	doc_491521502315_item	2662146	et	4	main
talu	doc_491521502315_item	2662147	et	4	main
agraarühiskond	doc_491521502315_item	2662148	et	3	main
jääb	doc_491521502315_item	2662149	et	3	main
kirik	doc_491521502315_item	2662155	et	3	main
maa	doc_491521502315_item	2662158	et	4	main
töövõtteid	doc_491521502315_item	2662172	et	3	main
katoliku	doc_491521502315_item	2662178	et	3	main
eesmärgiks	doc_491521502315_item	2662180	et	3	main
ainult	doc_491521502315_item	2662183	et	4	main
vaimu	doc_491521502315_item	2662191	et	4	main
hingega	doc_491521502315_item	2662193	et	3	main
1316	doc_491521502316_item	2662231	et	2	main
reformatsioon	doc_491521502316_item	2662236	et	3	main
ilmus	doc_491521502316_item	2662239	et	4	main
esimesed	doc_491521502316_item	2662241	et	3	main
olnud	doc_491521502316_item	2662250	et	4	main
kuid	doc_491521502316_item	2662254	et	4	main
varsti	doc_491521502316_item	2662255	et	3	main
12	doc_491521502316_item	2662265	et	2	main
tulid	doc_491521502316_item	2662279	et	4	main
ka	doc_491521502316_item	2662280	et	3	main
vallutajad	doc_491521502316_item	2662281	et	4	main
13	doc_491521502316_item	2662282	et	2	main
sajandil	doc_491521502316_item	2662283	et	3	main
linnad	doc_491521502316_item	2662290	et	3	main
nendes	doc_491521502316_item	2662292	et	4	main
enamasti	doc_491521502316_item	2662294	et	4	main
või	doc_491521502316_item	2662301	et	4	main
oli	doc_491521502316_item	2662302	et	3	main
pidid	doc_491521502316_item	2662307	et	4	main
kirikule	doc_491521502316_item	2662311	et	3	main
kaotasid	doc_491521502316_item	2662314	et	4	main
nüüd	doc_491521502316_item	2662317	et	4	main
oli	doc_491521502316_item	2662318	et	3	main
kohustuslik	doc_491521502316_item	2662319	et	3	main
ja	doc_491521502316_item	2662322	et	3	main
11	doc_491521502316_item	2662324	et	2	main
õpetati	doc_491521502316_item	2662326	et	3	main
olid	doc_491521502316_item	2662342	et	4	main
ladina	doc_491521502316_item	2662344	et	4	main
keeles	doc_491521502316_item	2662345	et	4	main
nii	doc_491521502316_item	2662346	et	3	main
et	doc_491521502316_item	2662347	et	3	main
eestlased	doc_491521502316_item	2662348	et	3	main
kirikus	doc_491521502316_item	2662355	et	3	main
ja	doc_491521502316_item	2662359	et	3	main
linnades	doc_491521502316_item	2662363	et	3	main
mõnikord	doc_491521502316_item	2662391	et	3	main
vähe	doc_491521502316_item	2662402	et	3	main
reformatsioonini	doc_491521502316_item	2662406	et	3	main
enamik	doc_491521502316_item	2662409	et	3	main
kiriku	doc_491521502316_item	2662415	et	3	main
selle	doc_491521502316_item	2662417	et	4	main
kes	doc_491521502316_item	2662422	et	4	main
muutus	doc_491521502316_item	2662432	et	4	main
oli	doc_491521502316_item	2662433	et	3	main
see	doc_491521502316_item	2662434	et	3	main
et	doc_491521502316_item	2662435	et	3	main
viidud	doc_491521502316_item	2662442	et	4	main
nii	doc_491521502316_item	2662449	et	3	main
1521	doc_491521502316_item	2662454	et	2	main
esimesed	doc_491521502316_item	2662469	et	3	main
ristiusustamist	doc_491521502317_item	2662496	et	3	main
rüütlitel	doc_491521502317_item	2662501	et	3	main
ja	doc_491521502317_item	2662502	et	3	main
oma	doc_491521502317_item	2662522	et	4	main
tekkinud	doc_491521502317_item	2662531	et	4	main
nii	doc_491521502317_item	2662533	et	3	main
eestlased	doc_491521502317_item	2662535	et	3	main
majanduse	doc_491521502317_item	2662542	et	4	main
võimu	doc_491521502317_item	2662563	et	4	main
talupoegadele	doc_491521502317_item	2662573	et	3	main
saamine	doc_491521502317_item	2662575	et	4	main
raske	doc_491521502317_item	2662577	et	4	main
ordu	doc_491521502315_item	2662115	et	4	main
nõudma	doc_491521502315_item	2662118	et	3	main
kord	doc_491521502315_item	2662119	et	4	main
aastas	doc_491521502315_item	2662120	et	3	main
ristima	doc_491521502315_item	2662132	et	4	main
peab	doc_491521502315_item	2662138	et	4	main
mitmesajaks	doc_491521502315_item	2662150	et	3	main
aastaks	doc_491521502315_item	2662151	et	4	main
linnad	doc_491521502315_item	2662152	et	3	main
arstiabi	doc_491521502315_item	2662169	et	4	main
õpetasid	doc_491521502315_item	2662170	et	4	main
seotud	doc_491521502315_item	2662174	et	4	main
keskajal	doc_491521502315_item	2662176	et	3	main
kiriku	doc_491521502315_item	2662179	et	3	main
raha	doc_491521502315_item	2662189	et	4	main
vara	doc_491521502315_item	2662190	et	4	main
vähe	doc_491521502315_item	2662195	et	3	main
ilmastus	doc_491521502315_item	2662197	et	3	main
m	doc_491521502315_item	2662198	et	4	main
luther	doc_491521502315_item	2662199	et	4	main
tahtis	doc_491521502315_item	2662200	et	3	main
olukorda	doc_491521502315_item	2662201	et	4	main
muuta	doc_491521502315_item	2662202	et	4	main
reformatsioon	doc_491521502315_item	2662203	et	3	main
algas	doc_491521502315_item	2662204	et	3	main
1517	doc_491521502315_item	2662206	et	2	main
saksamaal	doc_491521502315_item	2662205	et	4	main
liivimaal	doc_491521502315_item	2662207	et	4	main
1521	doc_491521502315_item	2662208	et	2	main
pildirüüsted	doc_491521502315_item	2662209	et	3	main
purustati	doc_491521502315_item	2662210	et	3	main
ikoone	doc_491521502315_item	2662211	et	3	main
lõhuti	doc_491521502315_item	2662212	et	3	main
kirikuvara	doc_491521502315_item	2662213	et	4	main
kirikureformid	doc_491521502315_item	2662214	et	3	main
nõudsid	doc_491521502315_item	2662215	et	4	main
kohalikelt	doc_491521502315_item	2662216	et	3	main
patu	doc_491521502315_item	2662217	et	3	main
õppimist	doc_491521502315_item	2662218	et	4	main
reformatsiooni	doc_491521502315_item	2662219	et	4	main
üheks	doc_491521502315_item	2662220	et	3	main
2	doc_491521502316_item	2662233	et	2	main
muutuma	doc_491521502316_item	2662253	et	4	main
sai	doc_491521502316_item	2662257	et	4	main
katoliikliku	doc_491521502316_item	2662259	et	3	main
eestisse	doc_491521502316_item	2662262	et	4	main
ristiusk	doc_491521502316_item	2662264	et	3	main
misjonäär	doc_491521502316_item	2662268	et	4	main
alguses	doc_491521502316_item	2662274	et	4	main
väikseid	doc_491521502316_item	2662275	et	4	main
koos	doc_491521502316_item	2662276	et	4	main
ristiusuga	doc_491521502316_item	2662277	et	3	main
vallutajad	doc_491521502316_item	2662295	et	4	main
madalam	doc_491521502316_item	2662303	et	4	main
kiht	doc_491521502316_item	2662304	et	3	main
samuti	doc_491521502316_item	2662312	et	3	main
oma	doc_491521502316_item	2662315	et	4	main
vabaduse	doc_491521502316_item	2662316	et	4	main
alates	doc_491521502316_item	2662323	et	3	main
lastele	doc_491521502316_item	2662327	et	4	main
piiblit	doc_491521502316_item	2662328	et	3	main
keelati	doc_491521502316_item	2662329	et	4	main
ka	doc_491521502316_item	2662330	et	3	main
saanud	doc_491521502316_item	2662350	et	4	main
pühitsema	doc_491521502316_item	2662356	et	3	main
ka	doc_491521502316_item	2662360	et	3	main
asju	doc_491521502316_item	2662362	et	3	main
kirikule	doc_491521502316_item	2662387	et	3	main
sest	doc_491521502316_item	2662404	et	4	main
ei	doc_491521502316_item	2662407	et	4	main
inimesi	doc_491521502316_item	2662410	et	4	main
sellest	doc_491521502316_item	2662411	et	4	main
nõudmine	doc_491521502316_item	2662416	et	4	main
martin	doc_491521502316_item	2662420	et	4	main
teenistused	doc_491521502316_item	2662341	et	3	main
käisid	doc_491521502316_item	2662354	et	4	main
ehitati	doc_491521502316_item	2662364	et	3	main
kirikuid	doc_491521502316_item	2662365	et	4	main
kõige	doc_491521502316_item	2662366	et	4	main
vanimad	doc_491521502316_item	2662367	et	3	main
tallinna	doc_491521502316_item	2662368	et	4	main
kirikud	doc_491521502316_item	2662369	et	3	main
on	doc_491521502316_item	2662370	et	4	main
toomkirik	doc_491521502316_item	2662371	et	3	main
oleviste	doc_491521502316_item	2662372	et	4	main
kirik	doc_491521502316_item	2662373	et	3	main
ja	doc_491521502316_item	2662374	et	3	main
pühavaimu	doc_491521502316_item	2662375	et	4	main
kirik	doc_491521502316_item	2662376	et	3	main
igal	doc_491521502316_item	2662377	et	3	main
pühapäeval	doc_491521502316_item	2662378	et	3	main
inimesed	doc_491521502316_item	2662379	et	3	main
käisid	doc_491521502316_item	2662380	et	4	main
kirikus	doc_491521502316_item	2662381	et	3	main
rikkamad	doc_491521502316_item	2662382	et	4	main
neist	doc_491521502316_item	2662383	et	4	main
andsid	doc_491521502316_item	2662384	et	4	main
ka	doc_491521502316_item	2662385	et	3	main
raha	doc_491521502316_item	2662386	et	4	main
pühavaimu	doc_491521502316_item	2662389	et	4	main
kuid	doc_491521502316_item	2662395	et	4	main
kuni	doc_491521502316_item	2662405	et	3	main
2	doc_491521502316_item	2662413	et	2	main
algaja	doc_491521502316_item	2662418	et	4	main
oli	doc_491521502316_item	2662419	et	3	main
saksamaal	doc_491521502316_item	2662424	et	4	main
reformatsioon	doc_491521502316_item	2662425	et	3	main
algas	doc_491521502316_item	2662426	et	3	main
nüüd	doc_491521502316_item	2662436	et	4	main
jumala	doc_491521502316_item	2662437	et	3	main
teenistus	doc_491521502316_item	2662438	et	3	main
pidi	doc_491521502316_item	2662439	et	4	main
eestisse	doc_491521502316_item	2662451	et	4	main
raamatud	doc_491521502316_item	2662466	et	4	main
jumala	doc_491521502316_item	2662467	et	3	main
saksa	doc_491521502317_item	2662498	et	4	main
taani	doc_491521502317_item	2662500	et	4	main
rooma	doc_491521502317_item	2662503	et	4	main
uurijatel	doc_491521502317_item	2662504	et	4	main
jõudu	doc_491521502317_item	2662512	et	4	main
kuid	doc_491521502317_item	2662513	et	4	main
sõjaretkega	doc_491521502317_item	2662518	et	3	main
hõimud	doc_491521502317_item	2662520	et	4	main
vabaduse	doc_491521502317_item	2662523	et	4	main
oli	doc_491521502317_item	2662529	et	3	main
pärisorjus	doc_491521502317_item	2662532	et	3	main
viikingiajast	doc_491521502317_item	2662536	et	4	main
euroopa	doc_491521502317_item	2662537	et	4	main
tsivilisatsiooni	doc_491521502317_item	2662538	et	4	main
algas	doc_491521502317_item	2662539	et	3	main
jäi	doc_491521502317_item	2662545	et	3	main
oli	doc_491521502317_item	2662549	et	3	main
killustunud	doc_491521502317_item	2662551	et	4	main
tööd	doc_491521502317_item	2662555	et	4	main
ja	doc_491521502317_item	2662557	et	3	main
maksma	doc_491521502317_item	2662558	et	3	main
maksu	doc_491521502317_item	2662560	et	4	main
keskuseks	doc_491521502317_item	2662564	et	4	main
oli	doc_491521502317_item	2662565	et	3	main
linn	doc_491521502317_item	2662566	et	3	main
kloostrite	doc_491521502317_item	2662588	et	3	main
juures	doc_491521502317_item	2662591	et	4	main
asusid	doc_491521502317_item	2662592	et	4	main
koolid	doc_491521502317_item	2662593	et	3	main
nii	doc_491521502317_item	2662594	et	3	main
saksamaal	doc_491521502317_item	2662605	et	4	main
luther	doc_491521502317_item	2662608	et	4	main
luther	doc_491521502317_item	2662623	et	4	main
tema	doc_491521502317_item	2662627	et	4	main
keeles	doc_491521502317_item	2662643	et	4	main
tuli	doc_491521502317_item	2662645	et	4	main
õppida	doc_491521502317_item	2662646	et	3	main
pähe	doc_491521502317_item	2662647	et	4	main
see	doc_491521502317_item	2662648	et	3	main
aitas	doc_491521502317_item	2662649	et	3	main
kuid	doc_491521502317_item	2662654	et	4	main
kas	doc_491521502317_item	2662660	et	3	main
on	doc_491521502317_item	2662662	et	4	main
lutherlik	doc_491521502317_item	2662671	et	4	main
kirikule	doc_491521502316_item	2662390	et	3	main
andi	doc_491521502316_item	2662392	et	4	main
ma	doc_491521502316_item	2662396	et	3	main
arvan	doc_491521502316_item	2662397	et	3	main
et	doc_491521502316_item	2662398	et	3	main
jumala	doc_491521502316_item	2662399	et	3	main
sõnast	doc_491521502316_item	2662400	et	4	main
oli	doc_491521502316_item	2662401	et	3	main
saanud	doc_491521502316_item	2662408	et	4	main
reformatsioon	doc_491521502316_item	2662414	et	3	main
luther	doc_491521502316_item	2662421	et	4	main
elas	doc_491521502316_item	2662423	et	3	main
1517	doc_491521502316_item	2662427	et	2	main
aastal	doc_491521502316_item	2662428	et	3	main
saksamaal	doc_491521502316_item	2662429	et	4	main
emakeeles	doc_491521502316_item	2662443	et	4	main
ja	doc_491521502316_item	2662444	et	3	main
kirik	doc_491521502316_item	2662445	et	3	main
ei	doc_491521502316_item	2662446	et	4	main
rikkas	doc_491521502316_item	2662450	et	4	main
aastal	doc_491521502316_item	2662455	et	3	main
tõi	doc_491521502316_item	2662457	et	3	main
ka	doc_491521502316_item	2662459	et	3	main
mõte	doc_491521502317_item	2662494	et	3	main
ja	doc_491521502317_item	2662499	et	3	main
x	doc_491521502317_item	2662506	et	4	main
algul	doc_491521502317_item	2662508	et	4	main
misjonäärid	doc_491521502317_item	2662509	et	4	main
pärast	doc_491521502317_item	2662514	et	4	main
eesti	doc_491521502317_item	2662519	et	4	main
xvi	doc_491521502317_item	2662526	et	4	main
sajandini	doc_491521502317_item	2662527	et	3	main
juba	doc_491521502317_item	2662530	et	3	main
põlisrahvas	doc_491521502317_item	2662544	et	4	main
eesti	doc_491521502317_item	2662548	et	4	main
feodaalselt	doc_491521502317_item	2662550	et	4	main
talupojad	doc_491521502317_item	2662552	et	4	main
poliitika	doc_491521502317_item	2662561	et	4	main
ja	doc_491521502317_item	2662562	et	3	main
raat	doc_491521502317_item	2662570	et	3	main
koosnes	doc_491521502317_item	2662571	et	3	main
tsunft	doc_491521502317_item	2662580	et	3	main
abil	doc_491521502317_item	2662582	et	4	main
võttis	doc_491521502317_item	2662584	et	3	main
kiriku	doc_491521502317_item	2662600	et	3	main
selles	doc_491521502317_item	2662609	et	4	main
tahtis	doc_491521502317_item	2662624	et	3	main
jumalateenused	doc_491521502317_item	2662639	et	3	main
kohalikes	doc_491521502317_item	2662642	et	3	main
kaasa	doc_491521502317_item	2662650	et	4	main
talupoegadele	doc_491521502317_item	2662656	et	3	main
olema	doc_491521502316_item	2662440	et	4	main
olnud	doc_491521502316_item	2662447	et	4	main
jõudis	doc_491521502316_item	2662452	et	3	main
reformatsioon	doc_491521502316_item	2662456	et	3	main
kaasa	doc_491521502316_item	2662458	et	4	main
emakeele	doc_491521502316_item	2662460	et	4	main
kirjanduse	doc_491521502316_item	2662461	et	3	main
hakkasid	doc_491521502316_item	2662462	et	4	main
ilmuma	doc_491521502316_item	2662463	et	3	main
esimesed	doc_491521502316_item	2662464	et	3	main
eestikeelsed	doc_491521502316_item	2662465	et	3	main
kirikuõpetajad	doc_491521502316_item	2662470	et	3	main
kes	doc_491521502316_item	2662471	et	4	main
teadsid	doc_491521502316_item	2662472	et	4	main
eesti	doc_491521502316_item	2662473	et	4	main
keelt	doc_491521502316_item	2662474	et	4	main
ja	doc_491521502316_item	2662475	et	3	main
üldse	doc_491521502316_item	2662476	et	3	main
eesti	doc_491521502316_item	2662477	et	4	main
keel	doc_491521502316_item	2662478	et	4	main
hakkas	doc_491521502316_item	2662479	et	3	main
levima	doc_491521502316_item	2662480	et	3	main
kontrolltöö	doc_491521502317_item	2662481	et	4	main
1	doc_491521502317_item	2662482	et	2	main
ristiusustamise	doc_491521502317_item	2662483	et	3	main
mõjud	doc_491521502317_item	2662484	et	4	main
eesti	doc_491521502317_item	2662485	et	4	main
ühiskonnakorraldusele	doc_491521502317_item	2662486	et	3	main
1316	doc_491521502317_item	2662487	et	2	main
sajandil	doc_491521502317_item	2662488	et	3	main
2	doc_491521502317_item	2662489	et	2	main
tähendab	doc_491521502317_item	2662491	et	3	main
1	doc_491521502317_item	2662493	et	2	main
baltimaade	doc_491521502317_item	2662495	et	3	main
juba	doc_491521502317_item	2662505	et	3	main
s	doc_491521502317_item	2662507	et	4	main
ei	doc_491521502317_item	2662510	et	4	main
rahumeelne	doc_491521502317_item	2662515	et	3	main
misjonitöö	doc_491521502317_item	2662516	et	4	main
võitlesid	doc_491521502317_item	2662521	et	4	main
eest	doc_491521502317_item	2662524	et	4	main
sattusid	doc_491521502317_item	2662534	et	4	main
areng	doc_491521502317_item	2662543	et	3	main
enamikus	doc_491521502317_item	2662546	et	3	main
pidid	doc_491521502317_item	2662553	et	4	main
linna	doc_491521502317_item	2662567	et	4	main
kõrgeim	doc_491521502317_item	2662568	et	4	main
võimuorgan	doc_491521502317_item	2662569	et	3	main
linnakodanikest	doc_491521502317_item	2662572	et	3	main
oli	doc_491521502317_item	2662576	et	3	main
eesti	doc_491521502317_item	2662583	et	4	main
ja	doc_491521502317_item	2662589	et	3	main
kirikute	doc_491521502317_item	2662590	et	4	main
hakkas	doc_491521502317_item	2662595	et	3	main
levima	doc_491521502317_item	2662596	et	3	main
kirjatarkus	doc_491521502317_item	2662597	et	4	main
2	doc_491521502317_item	2662598	et	2	main
1517	doc_491521502317_item	2662603	et	2	main
martin	doc_491521502317_item	2662607	et	4	main
aga	doc_491521502317_item	2662525	et	3	main
eestis	doc_491521502317_item	2662528	et	3	main
kultuuri	doc_491521502317_item	2662540	et	4	main
ja	doc_491521502317_item	2662541	et	3	main
talupoegadeks	doc_491521502317_item	2662547	et	3	main
tegema	doc_491521502317_item	2662554	et	3	main
mõisas	doc_491521502317_item	2662556	et	3	main
mõisale	doc_491521502317_item	2662559	et	3	main
linnakodanikuks	doc_491521502317_item	2662574	et	4	main
vennaskond	doc_491521502317_item	2662578	et	3	main
ristiusustamise	doc_491521502317_item	2662581	et	3	main
kasutusele	doc_491521502317_item	2662585	et	4	main
euroopaliku	doc_491521502317_item	2662586	et	3	main
ühiskondlikusüsteemi	doc_491521502317_item	2662587	et	4	main
reformatsioon	doc_491521502317_item	2662601	et	3	main
algas	doc_491521502317_item	2662602	et	3	main
algataja	doc_491521502317_item	2662606	et	4	main
ajaks	doc_491521502317_item	2662610	et	4	main
katoliku	doc_491521502317_item	2662611	et	3	main
kirikust	doc_491521502317_item	2662612	et	4	main
sai	doc_491521502317_item	2662613	et	4	main
iseseisev	doc_491521502317_item	2662614	et	3	main
feodaalne	doc_491521502317_item	2662615	et	3	main
organisatsioon	doc_491521502317_item	2662616	et	3	main
millel	doc_491521502317_item	2662617	et	3	main
oli	doc_491521502317_item	2662618	et	3	main
materiaalne	doc_491521502317_item	2662619	et	3	main
eesmärk	doc_491521502317_item	2662620	et	3	main
m	doc_491521502317_item	2662622	et	4	main
hävitamist	doc_491521502317_item	2662638	et	4	main
palved	doc_491521502317_item	2662644	et	3	main
tegelikult	doc_491521502317_item	2662655	et	4	main
peaaegu	doc_491521502317_item	2662658	et	3	main
preister	doc_491521502317_item	2662661	et	4	main
katolik	doc_491521502317_item	2662663	et	4	main
või	doc_491521502317_item	2662664	et	4	main
lutherlik	doc_491521502317_item	2662665	et	4	main
juba	doc_491521502317_item	2662666	et	3	main
1526	doc_491521502317_item	2662667	et	2	main
aastaks	doc_491521502317_item	2662668	et	4	main
gild	doc_491521502317_item	2662579	et	3	main
reformatsioon	doc_491521502317_item	2662599	et	3	main
a	doc_491521502317_item	2662604	et	4	main
ning	doc_491521502317_item	2662621	et	3	main
ta	doc_491521502317_item	2662633	et	4	main
nõudis	doc_491521502317_item	2662634	et	3	main
kirikukommete	doc_491521502317_item	2662635	et	4	main
maakabelite	doc_491521502317_item	2662637	et	3	main
toimuma	doc_491521502317_item	2662641	et	3	main
eestikeelsete	doc_491521502317_item	2662651	et	4	main
oli	doc_491521502317_item	2662657	et	3	main
oli	doc_491521502317_item	2662670	et	3	main
voorkeele	doc_491521502319_item	2662881	et	4	main
kodutoo	doc_491521502319_item	2662885	et	4	main
e-posti	doc_491521502319_item	2662893	et	4	main
loomulikus	doc_491521502319_item	2662921	et	4	main
opitud	doc_491521502319_item	2662923	et	4	main
eesti	doc_491521502319_item	2662924	et	4	main
konekeelsed	doc_491521502319_item	2662930	et	4	main
ainult	doc_491521502319_item	2662937	et	4	main
eesnimi	doc_491521502319_item	2662938	et	3	main
oma	doc_491521502319_item	2662945	et	4	main
heale	doc_491521502319_item	2662946	et	3	main
siiski	doc_491521502319_item	2662952	et	4	main
e-kirjadega	doc_491521502319_item	2662953	et	3	main
puuduvad	doc_491521502319_item	2662980	et	4	main
ei	doc_491521502319_item	2662983	et	4	main
et	doc_491521502319_item	2662996	et	3	main
kirjad	doc_491521502319_item	2663001	et	4	main
on	doc_491521502319_item	2663012	et	4	main
o-d	doc_491521502319_item	2663013	et	4	main
kiriavahemargid	doc_491521502319_item	2663019	et	4	main
enamusele	doc_491521502319_item	2663048	et	4	main
soomlastest	doc_491521502319_item	2663049	et	3	main
on	doc_491521502319_item	2663050	et	4	main
pole	doc_491521502319_item	2663057	et	3	main
nende	doc_491521502319_item	2663060	et	4	main
lohakuse	doc_491521502319_item	2663070	et	4	main
moju	doc_491521502319_item	2663072	et	4	main
voi	doc_491521502319_item	2663073	et	4	main
verbist	doc_491521502319_item	2663077	et	3	main
piltistan	doc_491521502319_item	2663084	et	4	main
tehtud	doc_491521502319_item	2663091	et	4	main
jaab	doc_491521502319_item	2663094	et	4	main
2	doc_491521502319_item	2663096	et	2	main
klusiilidega	doc_491521502319_item	2663121	et	3	main
kiri	doc_491521502319_item	2663127	et	3	main
seda	doc_491521502317_item	2662625	et	3	main
muuta	doc_491521502317_item	2662626	et	4	main
arvates	doc_491521502317_item	2662628	et	4	main
vaimne	doc_491521502317_item	2662629	et	3	main
inimene	doc_491521502317_item	2662630	et	3	main
vaene	doc_491521502317_item	2662631	et	4	main
inimene	doc_491521502317_item	2662632	et	3	main
lihtsustamise	doc_491521502317_item	2662636	et	4	main
pidid	doc_491521502317_item	2662640	et	4	main
raamatute	doc_491521502317_item	2662652	et	3	main
väljaandlusele	doc_491521502317_item	2662653	et	3	main
ükskõik	doc_491521502317_item	2662659	et	3	main
eesti	doc_491521502317_item	2662669	et	4	main
pedagoogikaiilikool	doc_491521502319_item	2662876	et	4	main
kontrastiivlingvistika	doc_491521502319_item	2662883	et	4	main
juhendaja	doc_491521502319_item	2662886	et	4	main
2001	doc_491521502319_item	2662888	et	2	main
teel	doc_491521502319_item	2662894	et	4	main
saadetud	doc_491521502319_item	2662895	et	4	main
kirjal	doc_491521502319_item	2662896	et	3	main
need	doc_491521502319_item	2662897	et	3	main
analüüs	doc_491521502319_item	2662874	et	3	main
eesti	doc_491521502319_item	2662878	et	4	main
keele	doc_491521502319_item	2662879	et	4	main
kui	doc_491521502319_item	2662880	et	3	main
kolmel	doc_491521502319_item	2662892	et	4	main
on	doc_491521502319_item	2662899	et	4	main
kirjad	doc_491521502319_item	2662927	et	4	main
on	doc_491521502319_item	2662928	et	4	main
suhteliselt	doc_491521502319_item	2662929	et	4	main
olla	doc_491521502319_item	2662935	et	3	main
tingitud	doc_491521502319_item	2662936	et	4	main
kirjutanud	doc_491521502319_item	2662943	et	4	main
need	doc_491521502319_item	2662944	et	3	main
on	doc_491521502319_item	2662951	et	4	main
oigekiri	doc_491521502319_item	2662973	et	4	main
1	doc_491521502319_item	2662977	et	2	main
probleemiks	doc_491521502319_item	2662994	et	4	main
see	doc_491521502319_item	2662995	et	3	main
ta	doc_491521502319_item	2662999	et	4	main
ei	doc_491521502319_item	2663003	et	4	main
o	doc_491521502319_item	2663005	et	4	main
kasutamist	doc_491521502319_item	2663006	et	4	main
seda	doc_491521502319_item	2663007	et	3	main
kinnitab	doc_491521502319_item	2663008	et	3	main
kiri	doc_491521502319_item	2663009	et	3	main
taiesti	doc_491521502319_item	2663017	et	4	main
veatult	doc_491521502319_item	2663018	et	4	main
nende	doc_491521502319_item	2663031	et	4	main
puudumist	doc_491521502319_item	2663032	et	4	main
siin	doc_491521502319_item	2663033	et	4	main
mitteametlike	doc_491521502319_item	2663039	et	3	main
e-kirj	doc_491521502319_item	2663040	et	4	main
adega	doc_491521502319_item	2663041	et	4	main
klusiilide	doc_491521502319_item	2663042	et	3	main
oi	doc_491521502319_item	2663043	et	3	main
raske	doc_491521502319_item	2663053	et	4	main
on	doc_491521502319_item	2663063	et	4	main
siiski	doc_491521502319_item	2663064	et	4	main
vigase	doc_491521502319_item	2663074	et	4	main
pildistamisele	doc_491521502319_item	2663085	et	4	main
tutavatele	doc_491521502319_item	2663124	et	4	main
1	doc_491521502319_item	2663128	et	2	main
kiri	doc_491521502319_item	2663131	et	3	main
kahtlustada	doc_491521502319_item	2663147	et	3	main
muid	doc_491521502319_item	2663149	et	4	main
loppuni	doc_491521502319_item	2663152	et	4	main
kahtlane	doc_491521502319_item	2663172	et	3	main
soome	doc_491521502319_item	2663174	et	3	main
eesti	doc_491521502319_item	2663183	et	4	main
haaldub	doc_491521502319_item	2663185	et	4	main
on	doc_491521502319_item	2663186	et	4	main
sellist	doc_491521502319_item	2663187	et	4	main
tallinna	doc_491521502319_item	2662875	et	4	main
filoloogiateaduskond	doc_491521502319_item	2662877	et	3	main
veaanaliiusi	doc_491521502319_item	2662884	et	4	main
tallinn	doc_491521502319_item	2662887	et	4	main
kaesolev	doc_491521502319_item	2662889	et	4	main
too	doc_491521502319_item	2662890	et	4	main
kirjutanud	doc_491521502319_item	2662900	et	4	main
27-aastane	doc_491521502319_item	2662901	et	4	main
soomlane	doc_491521502319_item	2662902	et	3	main
eesnimi	doc_491521502319_item	2662903	et	3	main
kes	doc_491521502319_item	2662904	et	4	main
199697	doc_491521502319_item	2662906	et	2	main
oppeaastal	doc_491521502319_item	2662905	et	4	main
oli	doc_491521502319_item	2662907	et	3	main
vahetusuliopilasena	doc_491521502319_item	2662908	et	4	main
eesti	doc_491521502319_item	2662909	et	4	main
kunstiakadeemia	doc_491521502319_item	2662910	et	4	main
tudengiks	doc_491521502319_item	2662911	et	3	main
eesti	doc_491521502319_item	2662912	et	4	main
keele	doc_491521502319_item	2662913	et	4	main
omandas	doc_491521502319_item	2662914	et	3	main
ta	doc_491521502319_item	2662915	et	4	main
suheldes	doc_491521502319_item	2662916	et	3	main
kaasuliopilastega	doc_491521502319_item	2662917	et	4	main
seega	doc_491521502319_item	2662918	et	4	main
on	doc_491521502319_item	2662919	et	4	main
see	doc_491521502319_item	2662920	et	3	main
keelekeskkonnas	doc_491521502319_item	2662922	et	3	main
on	doc_491521502319_item	2662941	et	4	main
kus	doc_491521502319_item	2662954	et	3	main
ja	doc_491521502319_item	2662972	et	3	main
3	doc_491521502319_item	2662979	et	2	main
oelda	doc_491521502319_item	2662985	et	4	main
eesnimi	doc_491521502319_item	2662987	et	3	main
neid	doc_491521502319_item	2662988	et	4	main
kasutada	doc_491521502319_item	2662989	et	3	main
arvuti	doc_491521502319_item	2662997	et	4	main
need	doc_491521502319_item	2663000	et	3	main
voimaldanud	doc_491521502319_item	2663004	et	4	main
kasutatud	doc_491521502319_item	2663014	et	4	main
ja	doc_491521502319_item	2663015	et	3	main
seda	doc_491521502319_item	2663016	et	3	main
kull	doc_491521502319_item	2663022	et	3	main
kirjades	doc_491521502319_item	2663023	et	3	main
komasid	doc_491521502319_item	2663025	et	3	main
tegemist	doc_491521502319_item	2663037	et	4	main
on	doc_491521502319_item	2663038	et	4	main
ja	doc_491521502319_item	2663054	et	3	main
e	doc_491521502319_item	2663056	et	4	main
on	doc_491521502319_item	2663069	et	4	main
oppetool	doc_491521502319_item	2662882	et	4	main
pohineb	doc_491521502319_item	2662891	et	4	main
kirjad	doc_491521502319_item	2662898	et	4	main
keel	doc_491521502319_item	2662925	et	4	main
need	doc_491521502319_item	2662926	et	3	main
kuid	doc_491521502319_item	2662931	et	4	main
see	doc_491521502319_item	2662932	et	3	main
keeleoskusest	doc_491521502319_item	2662939	et	4	main
esiteks	doc_491521502319_item	2662940	et	3	main
tuttavale	doc_491521502319_item	2662947	et	4	main
ja	doc_491521502319_item	2662948	et	3	main
teiseks	doc_491521502319_item	2662949	et	4	main
informaalse	doc_491521502319_item	2662955	et	4	main
lopus	doc_491521502319_item	2662969	et	4	main
haaldus	doc_491521502319_item	2662971	et	4	main
kuigi	doc_491521502319_item	2662975	et	3	main
ja	doc_491521502319_item	2662978	et	3	main
saa	doc_491521502319_item	2662984	et	4	main
et	doc_491521502319_item	2662986	et	3	main
ei	doc_491521502319_item	2662990	et	4	main
oska	doc_491521502319_item	2662991	et	4	main
arvatavasti	doc_491521502319_item	2662992	et	3	main
oli	doc_491521502319_item	2662993	et	3	main
millega	doc_491521502319_item	2662998	et	3	main
2	doc_491521502319_item	2663010	et	2	main
seal	doc_491521502319_item	2663011	et	4	main
e-l	doc_491521502319_item	2663020	et	3	main
on	doc_491521502319_item	2663021	et	4	main
puudu	doc_491521502319_item	2663026	et	4	main
pikemalt	doc_491521502319_item	2663034	et	4	main
see	doc_491521502319_item	2663051	et	3	main
ka	doc_491521502319_item	2663055	et	3	main
raske	doc_491521502319_item	2663065	et	4	main
otsustada	doc_491521502319_item	2663066	et	3	main
vormimoodustusega	doc_491521502319_item	2663075	et	3	main
pildistama	doc_491521502319_item	2663078	et	3	main
kirjas	doc_491521502319_item	2663080	et	4	main
mitu	doc_491521502319_item	2663092	et	4	main
kirju	doc_491521502319_item	2663095	et	4	main
ei	doc_491521502319_item	2662933	et	4	main
pruugi	doc_491521502319_item	2662934	et	4	main
ta	doc_491521502319_item	2662942	et	4	main
tegemist	doc_491521502319_item	2662950	et	4	main
suhtlemise	doc_491521502319_item	2662956	et	4	main
puhul	doc_491521502319_item	2662957	et	4	main
kasutatav	doc_491521502319_item	2662958	et	4	main
keel	doc_491521502319_item	2662959	et	4	main
lahenebki	doc_491521502319_item	2662960	et	3	main
konekeelele	doc_491521502319_item	2662961	et	4	main
koik	doc_491521502319_item	2662962	et	4	main
kirja	doc_491521502319_item	2662964	et	4	main
kolm	doc_491521502319_item	2662963	et	3	main
on	doc_491521502319_item	2662965	et	4	main
ara	doc_491521502319_item	2662966	et	3	main
toodud	doc_491521502319_item	2662967	et	4	main
too	doc_491521502319_item	2662968	et	4	main
l	doc_491521502319_item	2662970	et	4	main
o-kasutamine	doc_491521502319_item	2662974	et	4	main
kirjades	doc_491521502319_item	2662976	et	3	main
grafeemid	doc_491521502319_item	2662981	et	3	main
o	doc_491521502319_item	2662982	et	4	main
kirjutas	doc_491521502319_item	2663002	et	3	main
hulganisti	doc_491521502319_item	2663024	et	3	main
kuid	doc_491521502319_item	2663027	et	4	main
ma	doc_491521502319_item	2663028	et	3	main
ei	doc_491521502319_item	2663029	et	4	main
hakkaks	doc_491521502319_item	2663030	et	3	main
analuusima	doc_491521502319_item	2663035	et	4	main
kuna	doc_491521502319_item	2663036	et	3	main
eg	doc_491521502319_item	2663044	et	4	main
kiri	doc_491521502319_item	2663045	et	3	main
arvan	doc_491521502319_item	2663046	et	3	main
et	doc_491521502319_item	2663047	et	3	main
teema	doc_491521502319_item	2663052	et	4	main
mingi	doc_491521502319_item	2663058	et	4	main
erand	doc_491521502319_item	2663059	et	3	main
vigade	doc_491521502319_item	2663061	et	3	main
puhul	doc_491521502319_item	2663062	et	4	main
kas	doc_491521502319_item	2663067	et	3	main
tegemist	doc_491521502319_item	2663068	et	4	main
emakeele	doc_491521502319_item	2663071	et	4	main
naiteks	doc_491521502319_item	2663076	et	4	main
on	doc_491521502319_item	2663079	et	4	main
1	doc_491521502319_item	2663081	et	2	main
mitu	doc_491521502319_item	2663082	et	4	main
varianti	doc_491521502319_item	2663083	et	4	main
kuigi	doc_491521502319_item	2663089	et	3	main
on	doc_491521502319_item	2663090	et	4	main
viga	doc_491521502319_item	2663093	et	4	main
ja	doc_491521502319_item	2663097	et	3	main
3	doc_491521502319_item	2663098	et	2	main
lugedes	doc_491521502319_item	2663099	et	3	main
mlilje	doc_491521502319_item	2663100	et	4	main
et	doc_491521502319_item	2663101	et	3	main
e	doc_491521502319_item	2663102	et	4	main
teab	doc_491521502319_item	2663103	et	3	main
kuidas	doc_491521502319_item	2663104	et	3	main
seda	doc_491521502319_item	2663105	et	3	main
verbi	doc_491521502319_item	2663106	et	4	main
kasutatakse	doc_491521502319_item	2663107	et	3	main
nii	doc_491521502319_item	2663108	et	3	main
loeksin	doc_491521502319_item	2663109	et	3	main
need	doc_491521502319_item	2663110	et	3	main
vead	doc_491521502319_item	2663111	et	4	main
hooletusest	doc_491521502319_item	2663112	et	4	main
pohjustatuteks	doc_491521502319_item	2663113	et	4	main
raskusi	doc_491521502319_item	2663114	et	4	main
on	doc_491521502319_item	2663115	et	4	main
e-1	doc_491521502319_item	2663116	et	4	main
ka	doc_491521502319_item	2663117	et	3	main
sona	doc_491521502319_item	2663118	et	4	main
keskel	doc_491521502319_item	2663119	et	3	main
asuvate	doc_491521502319_item	2663120	et	4	main
printtimisele	doc_491521502319_item	2663126	et	4	main
kusgilt	doc_491521502319_item	2663130	et	4	main
kindlasti	doc_491521502319_item	2663133	et	3	main
siin	doc_491521502319_item	2663135	et	4	main
oma	doc_491521502319_item	2663136	et	4	main
roll	doc_491521502319_item	2663137	et	3	main
kuid	doc_491521502319_item	2663142	et	4	main
pildisdama	doc_491521502319_item	2663086	et	4	main
ja	doc_491521502319_item	2663087	et	3	main
pildisdamiseks	doc_491521502319_item	2663088	et	4	main
nt	doc_491521502319_item	2663122	et	4	main
loppuni	doc_491521502319_item	2663123	et	4	main
ilmuttamisele	doc_491521502319_item	2663125	et	4	main
emakeele	doc_491521502319_item	2663138	et	4	main
monede	doc_491521502319_item	2663143	et	4	main
kuhu	doc_491521502319_item	2663167	et	3	main
loppuni	doc_491521502319_item	2663168	et	4	main
kuhu	doc_491521502319_item	2663169	et	3	main
maani	doc_491521502319_item	2663170	et	3	main
paris	doc_491521502319_item	2663171	et	3	main
on	doc_491521502319_item	2663173	et	4	main
keele	doc_491521502319_item	2663175	et	4	main
moju	doc_491521502319_item	2663176	et	4	main
kuidas	doc_491521502319_item	2663181	et	3	main
keeles	doc_491521502319_item	2663184	et	4	main
arvata	doc_491521502319_item	2663194	et	4	main
et	doc_491521502319_item	2663195	et	3	main
monigi	doc_491521502319_item	2663201	et	4	main
veel	doc_491521502319_item	2663207	et	4	main
maarsona	doc_491521502319_item	2663208	et	4	main
on	doc_491521502319_item	2663219	et	4	main
voi	doc_491521502319_item	2663221	et	4	main
ja	doc_491521502319_item	2663228	et	3	main
markinud	doc_491521502319_item	2663229	et	4	main
klusiili	doc_491521502319_item	2663230	et	4	main
valesti	doc_491521502319_item	2663231	et	3	main
ka	doc_491521502319_item	2663232	et	3	main
nt	doc_491521502319_item	2663238	et	4	main
kort	doc_491521502319_item	2663249	et	4	main
kiri	doc_491521502319_item	2663250	et	3	main
3	doc_491521502319_item	2663251	et	2	main
kort	doc_491521502319_item	2663256	et	4	main
juhuslikku	doc_491521502319_item	2663259	et	4	main
sest	doc_491521502319_item	2663261	et	4	main
kasutatud	doc_491521502319_item	2663267	et	4	main
vaibad	doc_491521502319_item	2663268	et	3	main
2	doc_491521502319_item	2663275	et	2	main
arvan	doc_491521502319_item	2663277	et	3	main
klusiilide	doc_491521502319_item	2663279	et	3	main
enamuses	doc_491521502319_item	2663283	et	4	main
keele	doc_491521502319_item	2663286	et	4	main
eestlastega	doc_491521502319_item	2663327	et	4	main
tuleb	doc_491521502319_item	2663335	et	3	main
ja	doc_491521502319_item	2663355	et	3	main
2	doc_491521502319_item	2663359	et	2	main
ja	doc_491521502319_item	2663362	et	3	main
sonaj-arg	doc_491521502319_item	2663364	et	3	main
sonajarjega	doc_491521502319_item	2663365	et	4	main
vead	doc_491521502319_item	2663373	et	4	main
pildisdamiseks	doc_491521502319_item	2663381	et	4	main
on	doc_491521502319_item	2663386	et	4	main
jattuksjdttan	doc_491521502319_item	2663129	et	4	main
on	doc_491521502319_item	2663134	et	4	main
tingitud	doc_491521502319_item	2663140	et	4	main
ebakindlusel	doc_491521502319_item	2663141	et	4	main
puhul	doc_491521502319_item	2663145	et	4	main
siin	doc_491521502319_item	2663153	et	4	main
olla	doc_491521502319_item	2663155	et	3	main
pohjuseks	doc_491521502319_item	2663156	et	4	main
emakeel	doc_491521502319_item	2663157	et	4	main
sm	doc_491521502319_item	2663158	et	4	main
loppuun	doc_491521502319_item	2663159	et	4	main
asti	doc_491521502319_item	2663160	et	4	main
voi	doc_491521502319_item	2663161	et	4	main
hoopis	doc_491521502319_item	2663162	et	3	main
vigane	doc_491521502319_item	2663163	et	4	main
vormimoodustus	doc_491521502319_item	2663164	et	3	main
2	doc_491521502319_item	2663132	et	2	main
mojust	doc_491521502319_item	2663139	et	4	main
vigade	doc_491521502319_item	2663144	et	3	main
voib	doc_491521502319_item	2663154	et	4	main
puhul	doc_491521502319_item	2663179	et	4	main
teades	doc_491521502319_item	2663180	et	4	main
kirjapilti	doc_491521502319_item	2663188	et	4	main
valismaalasele	doc_491521502319_item	2663189	et	4	main
raske	doc_491521502319_item	2663190	et	4	main
pahaks	doc_491521502319_item	2663191	et	4	main
siin	doc_491521502319_item	2663196	et	4	main
teeks	doc_491521502319_item	2663197	et	4	main
pohjus	doc_491521502319_item	2663206	et	4	main
t	doc_491521502319_item	2663212	et	4	main
hooletusveaga	doc_491521502319_item	2663220	et	4	main
moelnud	doc_491521502319_item	2663225	et	4	main
sona	doc_491521502319_item	2663226	et	4	main
klusiilidega	doc_491521502319_item	2663234	et	3	main
on	doc_491521502319_item	2663235	et	4	main
inti	doc_491521502319_item	2663240	et	4	main
mille	doc_491521502319_item	2663241	et	3	main
kiri	doc_491521502319_item	2663242	et	3	main
vaib	doc_491521502319_item	2663254	et	4	main
molemat	doc_491521502319_item	2663262	et	4	main
vaipczde	doc_491521502319_item	2663269	et	4	main
kiri	doc_491521502319_item	2663270	et	3	main
ebakindlust	doc_491521502319_item	2663282	et	4	main
eesti	doc_491521502319_item	2663285	et	4	main
grammatikat	doc_491521502319_item	2663287	et	3	main
on	doc_491521502319_item	2663322	et	4	main
oppinud	doc_491521502319_item	2663323	et	4	main
eesti	doc_491521502319_item	2663324	et	4	main
moistetav	doc_491521502319_item	2663331	et	4	main
et	doc_491521502319_item	2663332	et	3	main
monede	doc_491521502319_item	2663339	et	4	main
vigade	doc_491521502319_item	2663340	et	3	main
hooletusvigadega	doc_491521502319_item	2663348	et	4	main
votmu	doc_491521502319_item	2663357	et	4	main
ei	doc_491521502319_item	2663369	et	4	main
ole	doc_491521502319_item	2663370	et	4	main
siiski	doc_491521502319_item	2663375	et	4	main
mojutanud	doc_491521502319_item	2663389	et	4	main
siin	doc_491521502319_item	2663433	et	4	main
mida	doc_491521502319_item	2663438	et	4	main
lseenesest	doc_491521502319_item	2663443	et	4	main
kuid	doc_491521502319_item	2663453	et	4	main
puhul	doc_491521502319_item	2663456	et	4	main
abimaarsonade	doc_491521502319_item	2663464	et	4	main
kasutamisega	doc_491521502319_item	2663465	et	4	main
ostsin	doc_491521502319_item	2663466	et	3	main
nuiid	doc_491521502319_item	2663467	et	4	main
igaljuhul	doc_491521502319_item	2663468	et	3	main
filmi	doc_491521502319_item	2663469	et	4	main
on	doc_491521502319_item	2663483	et	4	main
selline	doc_491521502319_item	2663490	et	4	main
kaas	doc_491521502319_item	2663499	et	3	main
kiri	doc_491521502319_item	2663501	et	3	main
siin	doc_491521502319_item	2663503	et	4	main
arvatavasti	doc_491521502319_item	2663506	et	3	main
jallegi	doc_491521502319_item	2663507	et	4	main
kiri	doc_491521502319_item	2663522	et	3	main
arvatavasti	doc_491521502319_item	2663526	et	3	main
tyosta	doc_491521502319_item	2663531	et	4	main
soome	doc_491521502319_item	2663532	et	3	main
eesti	doc_491521502319_item	2663538	et	4	main
eest	doc_491521502319_item	2663545	et	4	main
sidle	doc_491521502319_item	2663554	et	4	main
on	doc_491521502319_item	2663558	et	4	main
leidsin	doc_491521502319_item	2663564	et	3	main
kaks	doc_491521502319_item	2663565	et	3	main
kus	doc_491521502319_item	2663567	et	3	main
eksitud	doc_491521502319_item	2663569	et	4	main
igas	doc_491521502319_item	2663570	et	3	main
kiri	doc_491521502319_item	2663576	et	3	main
palju	doc_491521502319_item	2663599	et	4	main
endale	doc_491521502319_item	2663619	et	4	main
moned	doc_491521502319_item	2663633	et	4	main
piisavalt	doc_491521502319_item	2663641	et	4	main
tavalised	doc_491521502319_item	2663655	et	4	main
ka	doc_491521502319_item	2663656	et	3	main
eestlaste	doc_491521502319_item	2663657	et	4	main
soome	doc_491521502319_item	2663667	et	3	main
julgen	doc_491521502319_item	2663146	et	3	main
ka	doc_491521502319_item	2663148	et	3	main
pohjusi	doc_491521502319_item	2663150	et	4	main
naiteks	doc_491521502319_item	2663151	et	4	main
lopp	doc_491521502319_item	2663165	et	4	main
printtimisele	doc_491521502319_item	2663178	et	4	main
ka	doc_491521502319_item	2663199	et	3	main
eestlane	doc_491521502319_item	2663202	et	3	main
on	doc_491521502319_item	2663213	et	4	main
tahtnud	doc_491521502319_item	2663214	et	4	main
kirjutada	doc_491521502319_item	2663215	et	3	main
kusagilt	doc_491521502319_item	2663216	et	3	main
ja	doc_491521502319_item	2663217	et	3	main
loppu	doc_491521502319_item	2663166	et	4	main
sona	doc_491521502319_item	2663177	et	4	main
see	doc_491521502319_item	2663182	et	3	main
voib	doc_491521502319_item	2663193	et	4	main
nii	doc_491521502319_item	2663200	et	3	main
segaseks	doc_491521502319_item	2663203	et	4	main
jaab	doc_491521502319_item	2663204	et	4	main
kusgilt	doc_491521502319_item	2663209	et	4	main
juures	doc_491521502319_item	2663210	et	4	main
kas	doc_491521502319_item	2663211	et	3	main
tegemist	doc_491521502319_item	2663218	et	4	main
kuskilt	doc_491521502319_item	2663227	et	4	main
t	doc_491521502319_item	2663236	et	4	main
1	doc_491521502319_item	2663243	et	2	main
vaib	doc_491521502319_item	2663244	et	4	main
ja	doc_491521502319_item	2663255	et	3	main
sona	doc_491521502319_item	2663263	et	4	main
on	doc_491521502319_item	2663264	et	4	main
kord	doc_491521502319_item	2663273	et	4	main
kokkuvotvalt	doc_491521502319_item	2663276	et	4	main
et	doc_491521502319_item	2663278	et	3	main
ka	doc_491521502319_item	2663284	et	3	main
oppinud	doc_491521502319_item	2663288	et	4	main
soomlastes	doc_491521502319_item	2663289	et	3	main
t	doc_491521502319_item	2663321	et	4	main
ette	doc_491521502319_item	2663336	et	4	main
upris	doc_491521502319_item	2663343	et	4	main
et	doc_491521502319_item	2663345	et	3	main
tegemist	doc_491521502319_item	2663346	et	4	main
on	doc_491521502319_item	2663347	et	4	main
algust	doc_491521502319_item	2663350	et	4	main
kiri	doc_491521502319_item	2663358	et	3	main
suntaks	doc_491521502319_item	2663361	et	4	main
morfoloogia	doc_491521502319_item	2663363	et	4	main
probleeme	doc_491521502319_item	2663368	et	3	main
peaksin	doc_491521502319_item	2663374	et	4	main
ara	doc_491521502319_item	2663376	et	3	main
markima	doc_491521502319_item	2663377	et	4	main
kiri	doc_491521502319_item	2663378	et	3	main
1	doc_491521502319_item	2663379	et	2	main
uczipade	doc_491521502319_item	2663380	et	4	main
arvatavasti	doc_491521502319_item	2663388	et	3	main
kuncz	doc_491521502319_item	2663422	et	4	main
ei	doc_491521502319_item	2663431	et	4	main
vormis	doc_491521502319_item	2663436	et	4	main
eksinud	doc_491521502319_item	2663441	et	4	main
see	doc_491521502319_item	2663457	et	3	main
sobi	doc_491521502319_item	2663459	et	4	main
on	doc_491521502319_item	2663461	et	4	main
pildistan	doc_491521502319_item	2663475	et	3	main
sinu	doc_491521502319_item	2663478	et	3	main
soome	doc_491521502319_item	2663485	et	3	main
keele	doc_491521502319_item	2663486	et	4	main
eesti	doc_491521502319_item	2663488	et	4	main
keeles	doc_491521502319_item	2663489	et	4	main
ara	doc_491521502319_item	2663494	et	3	main
pean	doc_491521502319_item	2663498	et	4	main
voi	doc_491521502319_item	2663516	et	4	main
kaandevead	doc_491521502319_item	2663518	et	4	main
too	doc_491521502319_item	2663519	et	4	main
toost	doc_491521502319_item	2663520	et	3	main
panna	doc_491521502319_item	2663192	et	4	main
vea	doc_491521502319_item	2663198	et	4	main
vea	doc_491521502319_item	2663205	et	4	main
sonalopuliste	doc_491521502319_item	2663233	et	4	main
pr	doc_491521502319_item	2663239	et	4	main
nendest	doc_491521502319_item	2663252	et	4	main
vigadest	doc_491521502319_item	2663253	et	3	main
laadi	doc_491521502319_item	2663260	et	4	main
ka	doc_491521502319_item	2663265	et	3	main
oigesti	doc_491521502319_item	2663266	et	4	main
kin	doc_491521502319_item	2663274	et	4	main
tekitab	doc_491521502319_item	2663281	et	3	main
on	doc_491521502319_item	2663222	et	4	main
ta	doc_491521502319_item	2663223	et	4	main
siiski	doc_491521502319_item	2663224	et	4	main
eksinud	doc_491521502319_item	2663237	et	4	main
ainuld	doc_491521502319_item	2663245	et	4	main
kiri	doc_491521502319_item	2663246	et	3	main
2	doc_491521502319_item	2663247	et	2	main
ja	doc_491521502319_item	2663248	et	3	main
tunduvad	doc_491521502319_item	2663257	et	4	main
olevat	doc_491521502319_item	2663258	et	4	main
2	doc_491521502319_item	2663271	et	2	main
ja	doc_491521502319_item	2663272	et	3	main
oigekiri	doc_491521502319_item	2663280	et	4	main
ja	doc_491521502319_item	2663290	et	3	main
sellised	doc_491521502319_item	2663291	et	4	main
vead	doc_491521502319_item	2663292	et	4	main
voivad	doc_491521502319_item	2663293	et	4	main
sisse	doc_491521502319_item	2663294	et	4	main
lipsata	doc_491521502319_item	2663295	et	4	main
ka	doc_491521502319_item	2663296	et	3	main
oigeid	doc_491521502319_item	2663297	et	3	main
vorme	doc_491521502319_item	2663298	et	3	main
teades	doc_491521502319_item	2663299	et	4	main
kokku-	doc_491521502319_item	2663300	et	3	main
ja	doc_491521502319_item	2663301	et	3	main
lahkukirjutamine	doc_491521502319_item	2663302	et	3	main
selliseid	doc_491521502319_item	2663303	et	4	main
vigu	doc_491521502319_item	2663304	et	3	main
leidsin	doc_491521502319_item	2663305	et	3	main
e-1	doc_491521502319_item	2663306	et	4	main
ainult	doc_491521502319_item	2663307	et	4	main
kaks	doc_491521502319_item	2663308	et	3	main
uagu	doc_491521502319_item	2663309	et	4	main
nii	doc_491521502319_item	2663310	et	3	main
pole	doc_491521502319_item	2663311	et	3	main
piisavalt	doc_491521502319_item	2663312	et	4	main
kiri	doc_491521502319_item	2663313	et	3	main
1	doc_491521502319_item	2663314	et	2	main
ja	doc_491521502319_item	2663315	et	3	main
klaasi	doc_491521502319_item	2663316	et	4	main
nditus	doc_491521502319_item	2663317	et	4	main
kiri	doc_491521502319_item	2663318	et	3	main
3	doc_491521502319_item	2663319	et	2	main
kuna	doc_491521502319_item	2663320	et	3	main
keele	doc_491521502319_item	2663325	et	4	main
selliseid	doc_491521502319_item	2663333	et	4	main
vigu	doc_491521502319_item	2663334	et	3	main
puhul	doc_491521502319_item	2663341	et	4	main
olen	doc_491521502319_item	2663342	et	3	main
nt	doc_491521502319_item	2663349	et	4	main
kasitse	doc_491521502319_item	2663352	et	3	main
1	doc_491521502319_item	2663354	et	2	main
ara	doc_491521502319_item	2663326	et	3	main
suheldes	doc_491521502319_item	2663328	et	3	main
on	doc_491521502319_item	2663329	et	4	main
taiesti	doc_491521502319_item	2663330	et	4	main
muud	doc_491521502319_item	2663337	et	4	main
oigekirjavead	doc_491521502319_item	2663338	et	4	main
kindel	doc_491521502319_item	2663344	et	3	main
loppuni	doc_491521502319_item	2663351	et	4	main
kiri	doc_491521502319_item	2663353	et	3	main
e-1	doc_491521502319_item	2663366	et	4	main
paevavalgus	doc_491521502319_item	2663382	et	4	main
oleks	doc_491521502319_item	2663383	et	3	main
hea	doc_491521502319_item	2663384	et	4	main
kirjutajat	doc_491521502319_item	2663387	et	4	main
selliste	doc_491521502319_item	2663391	et	4	main
vigade	doc_491521502319_item	2663392	et	3	main
nagu	doc_491521502319_item	2663393	et	3	main
nii	doc_491521502319_item	2663394	et	3	main
et	doc_491521502319_item	2663395	et	3	main
umbes	doc_491521502319_item	2663396	et	4	main
20ndczl	doc_491521502319_item	2663397	et	4	main
tulen	doc_491521502319_item	2663398	et	3	main
kiri	doc_491521502319_item	2663399	et	3	main
3	doc_491521502319_item	2663400	et	2	main
ja	doc_491521502319_item	2663401	et	3	main
0aatun	doc_491521502319_item	2663402	et	4	main
meile	doc_491521502319_item	2663403	et	4	main
veel	doc_491521502319_item	2663404	et	4	main
tdncz	doc_491521502319_item	2663405	et	4	main
ohtul	doc_491521502319_item	2663406	et	4	main
kindlasti	doc_491521502319_item	2663407	et	3	main
kiri	doc_491521502319_item	2663408	et	3	main
2	doc_491521502319_item	2663409	et	2	main
juures	doc_491521502319_item	2663410	et	4	main
oska	doc_491521502319_item	2663412	et	4	main
ei	doc_491521502319_item	2663411	et	4	main
kahjuks	doc_491521502319_item	2663413	et	4	main
muud	doc_491521502319_item	2663414	et	4	main
pohjust	doc_491521502319_item	2663415	et	4	main
leida	doc_491521502319_item	2663416	et	3	main
kui	doc_491521502319_item	2663417	et	3	main
ainult	doc_491521502319_item	2663418	et	4	main
konekeele	doc_491521502319_item	2663419	et	4	main
moju	doc_491521502319_item	2663420	et	4	main
tegemcz	doc_491521502319_item	2663426	et	4	main
1	doc_491521502319_item	2663428	et	2	main
kui	doc_491521502319_item	2663429	et	3	main
t	doc_491521502319_item	2663430	et	4	main
on	doc_491521502319_item	2663439	et	4	main
on	doc_491521502319_item	2663444	et	4	main
sona	doc_491521502319_item	2663454	et	4	main
ja	doc_491521502319_item	2663474	et	3	main
vaibad	doc_491521502319_item	2663479	et	3	main
kaas	doc_491521502319_item	2663356	et	3	main
2	doc_491521502319_item	2663360	et	2	main
suuremaid	doc_491521502319_item	2663367	et	4	main
kuid	doc_491521502319_item	2663371	et	4	main
moned	doc_491521502319_item	2663372	et	4	main
siin	doc_491521502319_item	2663385	et	4	main
emakeel	doc_491521502319_item	2663390	et	4	main
obiektivead	doc_491521502319_item	2663421	et	4	main
pean	doc_491521502319_item	2663423	et	4	main
koige	doc_491521502319_item	2663424	et	4	main
ole	doc_491521502319_item	2663432	et	4	main
koike	doc_491521502319_item	2663437	et	4	main
kaandevalikuga	doc_491521502319_item	2663442	et	4	main
koik	doc_491521502319_item	2663455	et	4	main
veel	doc_491521502319_item	2663460	et	4	main
e-1	doc_491521502319_item	2663462	et	4	main
probleeme	doc_491521502319_item	2663463	et	3	main
jcz	doc_491521502319_item	2663470	et	4	main
panin	doc_491521502319_item	2663471	et	3	main
kiri	doc_491521502319_item	2663472	et	3	main
ainuld	doc_491521502319_item	2663476	et	4	main
tunda	doc_491521502319_item	2663484	et	3	main
vorm	doc_491521502319_item	2663491	et	3	main
mojutanud	doc_491521502319_item	2663508	et	4	main
konekeel	doc_491521502319_item	2663509	et	4	main
kusimusi	doc_491521502319_item	2663514	et	4	main
sm	doc_491521502319_item	2663529	et	4	main
tyo	doc_491521502319_item	2663530	et	4	main
kaassona	doc_491521502319_item	2663542	et	4	main
valistab	doc_491521502319_item	2663548	et	4	main
anda	doc_491521502319_item	2663562	et	3	main
naidet	doc_491521502319_item	2663566	et	4	main
on	doc_491521502319_item	2663568	et	4	main
oleks	doc_491521502319_item	2663574	et	3	main
teise	doc_491521502319_item	2663583	et	4	main
konekeele	doc_491521502319_item	2663591	et	4	main
kasutatakse	doc_491521502319_item	2663598	et	3	main
siiski	doc_491521502319_item	2663602	et	4	main
puhul	doc_491521502319_item	2663606	et	4	main
kahtlen	doc_491521502319_item	2663607	et	3	main
et	doc_491521502319_item	2663608	et	3	main
kas	doc_491521502319_item	2663609	et	3	main
moni	doc_491521502319_item	2663610	et	4	main
eestlane	doc_491521502319_item	2663611	et	3	main
oleks	doc_491521502319_item	2663612	et	3	main
niimoodi	doc_491521502319_item	2663613	et	3	main
1	doc_491521502319_item	2663621	et	2	main
kaiva	doc_491521502319_item	2663629	et	4	main
konstruktsiooniga	doc_491521502319_item	2663630	et	3	main
konekeelest	doc_491521502319_item	2663635	et	4	main
olen	doc_491521502319_item	2663643	et	3	main
kord	doc_491521502319_item	2663645	et	4	main
see	doc_491521502319_item	2663646	et	3	main
poolt	doc_491521502319_item	2663658	et	4	main
naited	doc_491521502319_item	2663661	et	4	main
pkevavalgus	doc_491521502319_item	2663670	et	4	main
oleks	doc_491521502319_item	2663671	et	3	main
ka	doc_491521502319_item	2663678	et	3	main
et	doc_491521502319_item	2663716	et	3	main
vea	doc_491521502319_item	2663719	et	4	main
keeles	doc_491521502319_item	2663726	et	4	main
loomulikult	doc_491521502319_item	2663732	et	4	main
t	doc_491521502319_item	2663738	et	4	main
on	doc_491521502319_item	2663746	et	4	main
sonas	doc_491521502319_item	2663751	et	4	main
natuke	doc_491521502319_item	2663756	et	4	main
sest	doc_491521502319_item	2663758	et	4	main
samuti	doc_491521502319_item	2663763	et	3	main
sarnane	doc_491521502319_item	2663764	et	4	main
on	doc_491521502319_item	2663768	et	4	main
t-1	doc_491521502319_item	2663769	et	4	main
kuidas	doc_491521502319_item	2663775	et	3	main
dill	doc_491521502319_item	2663779	et	4	main
motlen	doc_491521502319_item	2663781	et	4	main
kui	doc_491521502319_item	2663783	et	3	main
annan	doc_491521502319_item	2663794	et	3	main
vaibast	doc_491521502319_item	2663799	et	4	main
ja	doc_491521502319_item	2663800	et	3	main
kdsitse	doc_491521502319_item	2663425	et	4	main
kiri	doc_491521502319_item	2663427	et	3	main
teinud	doc_491521502319_item	2663434	et	4	main
oigekirjaviga	doc_491521502319_item	2663435	et	4	main
ta	doc_491521502319_item	2663440	et	4	main
ju	doc_491521502319_item	2663445	et	3	main
ka	doc_491521502319_item	2663446	et	3	main
omastav	doc_491521502319_item	2663447	et	4	main
oige	doc_491521502319_item	2663448	et	3	main
pean	doc_491521502319_item	2663449	et	4	main
mille	doc_491521502319_item	2663450	et	3	main
kasitsi	doc_491521502319_item	2663451	et	4	main
tegema	doc_491521502319_item	2663452	et	3	main
ei	doc_491521502319_item	2663458	et	4	main
2	doc_491521502319_item	2663473	et	2	main
need	doc_491521502319_item	2663477	et	3	main
kiri	doc_491521502319_item	2663480	et	3	main
siin	doc_491521502319_item	2663482	et	4	main
abimaarsona	doc_491521502319_item	2663493	et	4	main
teaksin	doc_491521502319_item	2663496	et	3	main
votma	doc_491521502319_item	2663500	et	4	main
on	doc_491521502319_item	2663504	et	4	main
e-d	doc_491521502319_item	2663505	et	4	main
kaasa	doc_491521502319_item	2663511	et	4	main
votma	doc_491521502319_item	2663512	et	4	main
eeldab	doc_491521502319_item	2663513	et	3	main
mojuga	doc_491521502319_item	2663528	et	4	main
on	doc_491521502319_item	2663534	et	4	main
omastav	doc_491521502319_item	2663541	et	4	main
juhuslikkuse	doc_491521502319_item	2663547	et	4	main
kni	doc_491521502319_item	2663553	et	4	main
vaib	doc_491521502319_item	2663557	et	4	main
sellest	doc_491521502319_item	2663559	et	4	main
palju	doc_491521502319_item	2663560	et	4	main
vastu	doc_491521502319_item	2663561	et	3	main
molemad	doc_491521502319_item	2663575	et	4	main
toenaosusega	doc_491521502319_item	2663579	et	4	main
tegemist	doc_491521502319_item	2663581	et	4	main
puhul	doc_491521502319_item	2663585	et	4	main
mojuga	doc_491521502319_item	2663592	et	4	main
3	doc_491521502319_item	2663593	et	2	main
sonatasand	doc_491521502319_item	2663594	et	4	main
stiilivead	doc_491521502319_item	2663595	et	3	main
kliigi	doc_491521502319_item	2663596	et	4	main
leidsin	doc_491521502319_item	2663601	et	3	main
iihe	doc_491521502319_item	2663603	et	4	main
mille	doc_491521502319_item	2663605	et	3	main
mulle	doc_491521502319_item	2663618	et	4	main
ule	doc_491521502319_item	2663627	et	4	main
jou	doc_491521502319_item	2663628	et	4	main
naited	doc_491521502319_item	2663634	et	4	main
ja	doc_491521502319_item	2663642	et	3	main
nadalavahetus	doc_491521502319_item	2663647	et	4	main
eestis	doc_491521502319_item	2663648	et	3	main
molemad	doc_491521502319_item	2663649	et	4	main
kiri	doc_491521502319_item	2663650	et	3	main
1	doc_491521502319_item	2663651	et	2	main
need	doc_491521502319_item	2663652	et	3	main
on	doc_491521502319_item	2663653	et	4	main
juba	doc_491521502319_item	2663654	et	3	main
leidsin	doc_491521502319_item	2663662	et	3	main
uhe	doc_491521502319_item	2663664	et	4	main
voimalikust	doc_491521502319_item	2663666	et	4	main
mojust	doc_491521502319_item	2663669	et	4	main
ilma	doc_491521502319_item	2663677	et	4	main
kid	doc_491521502319_item	2663713	et	4	main
sulle	doc_491521502319_item	2663714	et	3	main
siia	doc_491521502319_item	2663728	et	4	main
muide	doc_491521502319_item	2663729	et	3	main
voi	doc_491521502319_item	2663730	et	4	main
ikkagi	doc_491521502319_item	2663740	et	4	main
lihtsalt	doc_491521502319_item	2663748	et	4	main
kiri	doc_491521502319_item	2663753	et	3	main
mis	doc_491521502319_item	2663761	et	4	main
oma	doc_491521502319_item	2663765	et	4	main
soomekeelsele	doc_491521502319_item	2663766	et	3	main
1	doc_491521502319_item	2663773	et	2	main
oleks	doc_491521502319_item	2663776	et	3	main
ma	doc_491521502319_item	2663784	et	3	main
loppuni	doc_491521502319_item	2663792	et	4	main
ja	doc_491521502319_item	2663793	et	3	main
aega	doc_491521502319_item	2663827	et	4	main
ytleme	doc_491521502319_item	2663830	et	4	main
paeva	doc_491521502319_item	2663838	et	4	main
kuna	doc_491521502319_item	2663839	et	3	main
see	doc_491521502319_item	2663849	et	3	main
koht	doc_491521502319_item	2663850	et	3	main
pildisdama	doc_491521502319_item	2663854	et	4	main
et	doc_491521502319_item	2663857	et	3	main
voimatu	doc_491521502319_item	2663877	et	4	main
interjooris	doc_491521502319_item	2663883	et	4	main
paevavalgust	doc_491521502319_item	2663889	et	4	main
2	doc_491521502319_item	2663481	et	2	main
moju	doc_491521502319_item	2663487	et	4	main
nouab	doc_491521502319_item	2663492	et	4	main
rektsioonivead	doc_491521502319_item	2663495	et	4	main
mis	doc_491521502319_item	2663497	et	4	main
2	doc_491521502319_item	2663502	et	2	main
uhendverb	doc_491521502319_item	2663510	et	4	main
mille	doc_491521502319_item	2663515	et	3	main
mida	doc_491521502319_item	2663517	et	4	main
1	doc_491521502319_item	2663523	et	2	main
sellistel	doc_491521502319_item	2663535	et	4	main
puhkudel	doc_491521502319_item	2663536	et	3	main
seestutlev	doc_491521502319_item	2663537	et	4	main
eesl	doc_491521502319_item	2663543	et	4	main
mille	doc_491521502319_item	2663544	et	3	main
selle	doc_491521502319_item	2663549	et	4	main
kordumine	doc_491521502319_item	2663550	et	4	main
tundub	doc_491521502319_item	2663555	et	3	main
uhildumisvead	doc_491521502319_item	2663563	et	4	main
ja	doc_491521502319_item	2663572	et	3	main
1	doc_491521502319_item	2663577	et	2	main
on	doc_491521502319_item	2663580	et	4	main
hooletusvigadega	doc_491521502319_item	2663582	et	4	main
olla	doc_491521502319_item	2663588	et	3	main
tegemist	doc_491521502319_item	2663589	et	4	main
ka	doc_491521502319_item	2663590	et	3	main
e-kirjades	doc_491521502319_item	2663597	et	3	main
kiri	doc_491521502319_item	2663620	et	3	main
siin	doc_491521502319_item	2663622	et	4	main
moodustanud	doc_491521502319_item	2663626	et	4	main
veel	doc_491521502319_item	2663632	et	4	main
kasutatavad	doc_491521502319_item	2663659	et	4	main
naite	doc_491521502319_item	2663665	et	3	main
kui	doc_491521502319_item	2663673	et	3	main
1	doc_491521502319_item	2663681	et	2	main
arvan	doc_491521502319_item	2663682	et	3	main
2	doc_491521502319_item	2663718	et	2	main
on	doc_491521502319_item	2663720	et	4	main
pohjustanud	doc_491521502319_item	2663721	et	4	main
muuten	doc_491521502319_item	2663723	et	4	main
jos	doc_491521502319_item	2663724	et	4	main
eesti	doc_491521502319_item	2663725	et	4	main
muidugi	doc_491521502319_item	2663731	et	4	main
moelnud	doc_491521502319_item	2663741	et	4	main
kasutada	doc_491521502319_item	2663742	et	3	main
uhte	doc_491521502319_item	2663743	et	3	main
hooletlisvea	doc_491521502319_item	2663749	et	4	main
oli	doc_491521502319_item	2663755	et	3	main
sona	doc_491521502319_item	2663759	et	4	main
interjoor	doc_491521502319_item	2663760	et	4	main
too	doc_491521502319_item	2663777	et	4	main
ma	doc_491521502319_item	2663780	et	3	main
et	doc_491521502319_item	2663782	et	3	main
piltistan	doc_491521502319_item	2663785	et	4	main
teie	doc_491521502319_item	2663786	et	4	main
asjad	doc_491521502319_item	2663787	et	3	main
ara	doc_491521502319_item	2663788	et	3	main
sulle	doc_491521502319_item	2663795	et	3	main
printi	doc_491521502319_item	2663797	et	4	main
endale	doc_491521502319_item	2663822	et	4	main
300	doc_491521502319_item	2663824	et	2	main
fimi	doc_491521502319_item	2663825	et	4	main
yks	doc_491521502319_item	2663831	et	4	main
pean	doc_491521502319_item	2663840	et	4	main
kus	doc_491521502319_item	2663852	et	3	main
see	doc_491521502319_item	2663861	et	3	main
voiks	doc_491521502319_item	2663865	et	4	main
paevavalgus	doc_491521502319_item	2663873	et	4	main
oleks	doc_491521502319_item	2663874	et	3	main
ka	doc_491521502319_item	2663881	et	3	main
pole	doc_491521502319_item	2663887	et	3	main
peab	doc_491521502319_item	2663891	et	4	main
2	doc_491521502319_item	2663900	et	2	main
oleks	doc_491521502319_item	2663923	et	3	main
pean	doc_491521502319_item	2663932	et	4	main
ja	doc_491521502319_item	2663941	et	3	main
homme	doc_491521502319_item	2663944	et	3	main
kui	doc_491521502319_item	2663950	et	3	main
voib	doc_491521502319_item	2663961	et	4	main
need	doc_491521502319_item	2663968	et	3	main
sinu	doc_491521502319_item	2663969	et	3	main
vaibad	doc_491521502319_item	2663970	et	3	main
diil	doc_491521502319_item	2663521	et	4	main
tegemist	doc_491521502319_item	2663524	et	4	main
on	doc_491521502319_item	2663525	et	4	main
emakeele	doc_491521502319_item	2663527	et	4	main
keeles	doc_491521502319_item	2663533	et	4	main
keeles	doc_491521502319_item	2663539	et	4	main
aga	doc_491521502319_item	2663540	et	3	main
vea	doc_491521502319_item	2663546	et	4	main
kirjas	doc_491521502319_item	2663551	et	4	main
2	doc_491521502319_item	2663552	et	2	main
et	doc_491521502319_item	2663556	et	3	main
vuibast	doc_491521502319_item	2663571	et	4	main
kulzld	doc_491521502319_item	2663573	et	4	main
suure	doc_491521502319_item	2663578	et	3	main
naite	doc_491521502319_item	2663584	et	3	main
voib	doc_491521502319_item	2663586	et	4	main
muidugi	doc_491521502319_item	2663587	et	4	main
konekeelt	doc_491521502319_item	2663600	et	4	main
naite	doc_491521502319_item	2663604	et	3	main
kirjutanud	doc_491521502319_item	2663614	et	4	main
materiaali	doc_491521502319_item	2663615	et	4	main
kulud	doc_491521502319_item	2663616	et	4	main
oleks	doc_491521502319_item	2663617	et	3	main
on	doc_491521502319_item	2663623	et	4	main
t	doc_491521502319_item	2663624	et	4	main
arvatavasti	doc_491521502319_item	2663625	et	3	main
lause	doc_491521502319_item	2663631	et	4	main
interjooris	doc_491521502319_item	2663636	et	4	main
kindlasti	doc_491521502319_item	2663637	et	3	main
nagu	doc_491521502319_item	2663638	et	3	main
nii	doc_491521502319_item	2663639	et	3	main
pole	doc_491521502319_item	2663640	et	3	main
jargmine	doc_491521502319_item	2663644	et	4	main
konekeele	doc_491521502319_item	2663660	et	4	main
ka	doc_491521502319_item	2663663	et	3	main
hea	doc_491521502319_item	2663672	et	4	main
hakkama	doc_491521502319_item	2663679	et	3	main
et	doc_491521502319_item	2663683	et	3	main
isegi	doc_491521502319_item	2663684	et	4	main
eesti	doc_491521502319_item	2663685	et	4	main
konekeeles	doc_491521502319_item	2663686	et	4	main
nii	doc_491521502319_item	2663687	et	3	main
luhikest	doc_491521502319_item	2663688	et	4	main
varianti	doc_491521502319_item	2663689	et	4	main
ei	doc_491521502319_item	2663690	et	4	main
kasutata	doc_491521502319_item	2663691	et	3	main
pigem	doc_491521502319_item	2663692	et	3	main
ikkagi	doc_491521502319_item	2663693	et	4	main
kui	doc_491521502319_item	2663694	et	3	main
see	doc_491521502319_item	2663695	et	3	main
on	doc_491521502319_item	2663696	et	4	main
voimatu	doc_491521502319_item	2663697	et	4	main
voi	doc_491521502319_item	2663698	et	4	main
kui	doc_491521502319_item	2663699	et	3	main
pole	doc_491521502319_item	2663700	et	3	main
voimalik	doc_491521502319_item	2663701	et	4	main
sonavead	doc_491521502319_item	2663702	et	4	main
leidsin	doc_491521502319_item	2663703	et	3	main
kaks	doc_491521502319_item	2663704	et	3	main
viga	doc_491521502319_item	2663705	et	4	main
mis	doc_491521502319_item	2663706	et	4	main
arvatavasti	doc_491521502319_item	2663707	et	3	main
on	doc_491521502319_item	2663708	et	4	main
mojutatud	doc_491521502319_item	2663709	et	4	main
soome	doc_491521502319_item	2663710	et	3	main
keelest	doc_491521502319_item	2663711	et	4	main
muidu	doc_491521502319_item	2663712	et	3	main
konekeele	doc_491521502319_item	2663668	et	4	main
voimatu	doc_491521502319_item	2663674	et	4	main
siis	doc_491521502319_item	2663675	et	3	main
saub	doc_491521502319_item	2663676	et	4	main
kiri	doc_491521502319_item	2663680	et	3	main
tundub	doc_491521502319_item	2663715	et	3	main
soomekeelne	doc_491521502319_item	2663722	et	3	main
sobiks	doc_491521502319_item	2663727	et	4	main
ei	doc_491521502319_item	2663733	et	4	main
on	doc_491521502319_item	2663739	et	4	main
teinud	doc_491521502319_item	2663747	et	4	main
materiaali	doc_491521502319_item	2663752	et	4	main
1	doc_491521502319_item	2663754	et	2	main
vastele	doc_491521502319_item	2663767	et	3	main
kiri	doc_491521502319_item	2663772	et	3	main
kuule	doc_491521502319_item	2663774	et	4	main
ytleme	doc_491521502319_item	2663789	et	4	main
et	doc_491521502319_item	2663790	et	3	main
algust	doc_491521502319_item	2663791	et	4	main
yhe	doc_491521502319_item	2663796	et	4	main
igas	doc_491521502319_item	2663798	et	3	main
tutavatele	doc_491521502319_item	2663801	et	4	main
ja	doc_491521502319_item	2663826	et	3	main
laheks	doc_491521502319_item	2663828	et	4	main
pildistamisele	doc_491521502319_item	2663829	et	4	main
printtimisele	doc_491521502319_item	2663836	et	4	main
3-4	doc_491521502319_item	2663837	et	2	main
mis	doc_491521502319_item	2663845	et	4	main
arvad	doc_491521502319_item	2663846	et	3	main
ja	doc_491521502319_item	2663847	et	3	main
kus	doc_491521502319_item	2663848	et	3	main
asub	doc_491521502319_item	2663851	et	3	main
arvan	doc_491521502319_item	2663856	et	3	main
kord	doc_491521502319_item	2663860	et	4	main
eestis	doc_491521502319_item	2663863	et	3	main
akki	doc_491521502319_item	2663867	et	4	main
kohe	doc_491521502319_item	2663868	et	4	main
ara	doc_491521502319_item	2663869	et	3	main
teha	doc_491521502319_item	2663870	et	3	main
vaipade	doc_491521502319_item	2663871	et	3	main
kui	doc_491521502319_item	2663876	et	3	main
saab	doc_491521502319_item	2663879	et	3	main
kindlasti	doc_491521502319_item	2663884	et	3	main
nii	doc_491521502319_item	2663886	et	3	main
mis	doc_491521502319_item	2663896	et	4	main
jouad	doc_491521502319_item	2663922	et	4	main
utled	doc_491521502319_item	2663927	et	4	main
kuidas	doc_491521502319_item	2663928	et	3	main
kaas	doc_491521502319_item	2663933	et	3	main
votma	doc_491521502319_item	2663934	et	4	main
meile	doc_491521502319_item	2663936	et	4	main
veel	doc_491521502319_item	2663937	et	4	main
ka	doc_491521502319_item	2663945	et	3	main
enne	doc_491521502319_item	2663947	et	4	main
on	doc_491521502319_item	2663955	et	4	main
pildistan	doc_491521502319_item	2663966	et	3	main
seal	doc_491521502319_item	2663971	et	4	main
kus	doc_491521502319_item	2663972	et	3	main
nad	doc_491521502319_item	2663973	et	3	main
nuud	doc_491521502319_item	2663974	et	4	main
ara	doc_491521502319_item	2663981	et	3	main
jattan	doc_491521502319_item	2663982	et	4	main
saad	doc_491521502319_item	2663989	et	4	main
saab	doc_491521502319_item	2664007	et	3	main
teha	doc_491521502319_item	2664010	et	3	main
katlini	doc_491521502319_item	2664030	et	4	main
just	doc_491521502319_item	2664039	et	3	main
et	doc_491521502319_item	2664042	et	3	main
nii	doc_491521502319_item	2664060	et	3	main
et	doc_491521502319_item	2664061	et	3	main
asdasdbr	doc_491521502320_item	2664077	et	4	main
br	doc_491521502320_item	2664079	et	4	main
seal	doc_49256336380_item	2664096	et	4	main
ta	doc_49256336380_item	2664097	et	4	main
miks	doc_49256336380_item	2664109	et	4	main
cv	doc_49256336380_item	2664114	et	4	main
peavad	doc_49256336380_item	2664117	et	4	main
olema	doc_49256336380_item	2664118	et	4	main
kes	doc_49256336380_item	2664125	et	4	main
saab	doc_49256336380_item	2664132	et	3	main
mida	doc_49256336380_item	2664145	et	4	main
kui	doc_49256336380_item	2664158	et	3	main
riietus	doc_49256336380_item	2664162	et	4	main
kiri	doc_491521502319_item	2663717	et	3	main
saa	doc_491521502319_item	2663734	et	4	main
taielikult	doc_491521502319_item	2663735	et	4	main
valistada	doc_491521502319_item	2663736	et	4	main
et	doc_491521502319_item	2663737	et	3	main
neist	doc_491521502319_item	2663744	et	4	main
aga	doc_491521502319_item	2663745	et	3	main
viga	doc_491521502319_item	2663750	et	4	main
ullatav	doc_491521502319_item	2663757	et	4	main
on	doc_491521502319_item	2663762	et	4	main
konektselt	doc_491521502319_item	2663770	et	4	main
kirjutatud	doc_491521502319_item	2663771	et	4	main
toost	doc_491521502319_item	2663778	et	3	main
naiteks	doc_491521502319_item	2663802	et	4	main
viis	doc_491521502319_item	2663803	et	4	main
pilti	doc_491521502319_item	2663804	et	4	main
interjoorist	doc_491521502319_item	2663805	et	4	main
siis	doc_491521502319_item	2663806	et	3	main
selle	doc_491521502319_item	2663807	et	4	main
eest	doc_491521502319_item	2663808	et	4	main
saan	doc_491521502319_item	2663809	et	4	main
sinu	doc_491521502319_item	2663810	et	3	main
kaest	doc_491521502319_item	2663811	et	4	main
vaiba	doc_491521502319_item	2663812	et	3	main
ma	doc_491521502319_item	2663813	et	3	main
arvan	doc_491521502319_item	2663814	et	3	main
et	doc_491521502319_item	2663815	et	3	main
sellise	doc_491521502319_item	2663816	et	4	main
too	doc_491521502319_item	2663817	et	4	main
materiaali	doc_491521502319_item	2663818	et	4	main
kulud	doc_491521502319_item	2663819	et	4	main
oleks	doc_491521502319_item	2663820	et	3	main
mulle	doc_491521502319_item	2663821	et	4	main
umbes	doc_491521502319_item	2663823	et	4	main
paev	doc_491521502319_item	2663832	et	4	main
ja	doc_491521502319_item	2663833	et	3	main
ilmuttamisele	doc_491521502319_item	2663834	et	4	main
ja	doc_491521502319_item	2663835	et	3	main
peaks	doc_491521502319_item	2663853	et	4	main
ma	doc_491521502319_item	2663855	et	3	main
olen	doc_491521502319_item	2663858	et	3	main
nadalavahetus	doc_491521502319_item	2663862	et	4	main
ja	doc_491521502319_item	2663864	et	3	main
siis	doc_491521502319_item	2663866	et	3	main
hea	doc_491521502319_item	2663875	et	4	main
hakkama	doc_491521502319_item	2663882	et	3	main
piisavalt	doc_491521502319_item	2663888	et	4	main
arvad	doc_491521502319_item	2663897	et	3	main
eesnimi	doc_491521502319_item	2663898	et	3	main
kiri	doc_491521502319_item	2663899	et	3	main
kuule	doc_491521502319_item	2663901	et	4	main
ostsin	doc_491521502319_item	2663902	et	3	main
nuud	doc_491521502319_item	2663903	et	4	main
igal	doc_491521502319_item	2663904	et	3	main
juhul	doc_491521502319_item	2663905	et	3	main
filmi	doc_491521502319_item	2663906	et	4	main
koige	doc_491521502319_item	2663841	et	4	main
kasitse	doc_491521502319_item	2663842	et	3	main
tegema	doc_491521502319_item	2663843	et	3	main
ytle	doc_491521502319_item	2663844	et	4	main
jargmine	doc_491521502319_item	2663859	et	4	main
pildisdamiseks	doc_491521502319_item	2663872	et	4	main
siis	doc_491521502319_item	2663878	et	3	main
ilma	doc_491521502319_item	2663880	et	4	main
nagu	doc_491521502319_item	2663885	et	3	main
teata	doc_491521502319_item	2663895	et	4	main
ja	doc_491521502319_item	2663907	et	3	main
panin	doc_491521502319_item	2663908	et	3	main
koolist	doc_491521502319_item	2663909	et	4	main
kaamera	doc_491521502319_item	2663910	et	4	main
kinni	doc_491521502319_item	2663911	et	3	main
kuna	doc_491521502319_item	2663912	et	3	main
homme	doc_491521502319_item	2663913	et	3	main
vist	doc_491521502319_item	2663914	et	4	main
enam	doc_491521502319_item	2663915	et	4	main
ei	doc_491521502319_item	2663916	et	4	main
joua	doc_491521502319_item	2663917	et	4	main
seda	doc_491521502319_item	2663918	et	3	main
teha	doc_491521502319_item	2663919	et	3	main
aga	doc_491521502319_item	2663920	et	3	main
on	doc_491521502319_item	2663929	et	4	main
ohtul	doc_491521502319_item	2663939	et	4	main
loodan	doc_491521502319_item	2663942	et	3	main
veel	doc_491521502319_item	2663946	et	4	main
sulle	doc_491521502319_item	2663951	et	3	main
ka	doc_491521502319_item	2663963	et	3	main
et	doc_491521502319_item	2663965	et	3	main
ainuld	doc_491521502319_item	2663967	et	4	main
naiteks	doc_491521502319_item	2663994	et	4	main
morganist	doc_491521502319_item	2663995	et	3	main
tellida	doc_491521502319_item	2663996	et	3	main
seda	doc_491521502319_item	2664006	et	3	main
kort	doc_491521502319_item	2664022	et	4	main
ilmselt	doc_491521502319_item	2664023	et	4	main
kahe	doc_491521502319_item	2664024	et	3	main
nadala	doc_491521502319_item	2664025	et	4	main
parast	doc_491521502319_item	2664026	et	3	main
siis	doc_491521502319_item	2664027	et	3	main
kui	doc_491521502319_item	2664028	et	3	main
see	doc_491521502319_item	2664029	et	3	main
on	doc_491521502319_item	2664036	et	4	main
nii	doc_491521502319_item	2664041	et	3	main
joua	doc_491521502319_item	2664048	et	4	main
kui	doc_491521502319_item	2664051	et	3	main
peab	doc_49256336380_item	2664091	et	4	main
kirjutada	doc_49256336380_item	2664092	et	3	main
cv	doc_49256336380_item	2664093	et	4	main
ta	doc_49256336380_item	2664106	et	4	main
lühikesed	doc_49256336380_item	2664119	et	4	main
ja	doc_49256336380_item	2664120	et	3	main
ja	doc_491521502319_item	2663890	et	3	main
miksima	doc_491521502319_item	2663892	et	4	main
valguga	doc_491521502319_item	2663893	et	3	main
aga	doc_491521502319_item	2663894	et	3	main
kui	doc_491521502319_item	2663921	et	3	main
teaksin	doc_491521502319_item	2663930	et	3	main
kindlasti	doc_491521502319_item	2663940	et	3	main
et	doc_491521502319_item	2663943	et	3	main
tundub	doc_491521502319_item	2663952	et	3	main
vaib	doc_491521502319_item	2663954	et	4	main
sellest	doc_491521502319_item	2663956	et	4	main
palju	doc_491521502319_item	2663957	et	4	main
vastu	doc_491521502319_item	2663958	et	3	main
anda	doc_491521502319_item	2663959	et	3	main
siis	doc_491521502319_item	2663960	et	3	main
olid	doc_491521502319_item	2663975	et	4	main
aga	doc_491521502319_item	2663976	et	3	main
siis	doc_491521502319_item	2663983	et	3	main
filmi	doc_491521502319_item	2663984	et	4	main
sinu	doc_491521502319_item	2663985	et	3	main
et	doc_491521502319_item	2663999	et	3	main
see	doc_491521502319_item	2664000	et	3	main
pildistamine	doc_491521502319_item	2664002	et	4	main
ja	doc_491521502319_item	2664005	et	3	main
juhul	doc_491521502319_item	2664009	et	3	main
jargmine	doc_491521502319_item	2664021	et	4	main
avatakse	doc_491521502319_item	2664033	et	4	main
aga	doc_491521502319_item	2664034	et	3	main
see	doc_491521502319_item	2664035	et	3	main
umbes	doc_491521502319_item	2664038	et	4	main
voib	doc_491521502319_item	2664043	et	4	main
ei	doc_491521502319_item	2664047	et	4	main
aga	doc_491521502319_item	2664050	et	3	main
kontrolltöö	doc_49256336380_item	2664081	et	4	main
vaja	doc_49256336380_item	2664084	et	4	main
valmistuda	doc_49256336380_item	2664085	et	3	main
inimene	doc_49256336380_item	2664086	et	3	main
kes	doc_49256336380_item	2664087	et	4	main
tahab	doc_49256336380_item	2664088	et	3	main
töö	doc_49256336380_item	2664089	et	4	main
leidma	doc_49256336380_item	2664090	et	3	main
avaldus	doc_49256336380_item	2664095	et	4	main
õppis	doc_49256336380_item	2664107	et	3	main
ja	doc_49256336380_item	2664108	et	3	main
ta	doc_49256336380_item	2664110	et	4	main
tahab	doc_49256336380_item	2664111	et	3	main
töötada	doc_49256336380_item	2664112	et	3	main
et	doc_49256336380_item	2664123	et	3	main
tema	doc_49256336380_item	2664124	et	4	main
see	doc_49256336380_item	2664126	et	3	main
cv	doc_49256336380_item	2664127	et	4	main
ja	doc_49256336380_item	2664128	et	3	main
avaldus	doc_49256336380_item	2664129	et	4	main
ei	doc_49256336380_item	2664146	et	4	main
saa	doc_49256336380_item	2664147	et	4	main
on	doc_49256336380_item	2664160	et	4	main
hea	doc_49256336380_item	2664164	et	4	main
aitab	doc_49256336380_item	2664168	et	3	main
leida	doc_49256336380_item	2664170	et	3	main
et	doc_49256336380_item	2664172	et	3	main
vaatavad	doc_49256336380_item	2664174	et	4	main
inimese	doc_49256336380_item	2664175	et	4	main
välimus	doc_49256336380_item	2664176	et	3	main
tööintervjuul	doc_49256336380_item	2664177	et	3	main
tööintervjuul	doc_49256336380_item	2664184	et	3	main
peaks	doc_49256336380_item	2664185	et	4	main
töö	doc_49256336380_item	2664201	et	4	main
on	doc_49256336380_item	2664207	et	4	main
koolis	doc_49256336380_item	2664209	et	4	main
kõige	doc_49256336380_item	2664210	et	4	main
et	doc_49256336380_item	2664218	et	3	main
saa	doc_49256336380_item	2664221	et	4	main
õppida	doc_49256336380_item	2664223	et	3	main
et	doc_49256336380_item	2664225	et	3	main
õppeprogramm	doc_49256336380_item	2664227	et	3	main
väga	doc_49256336380_item	2664229	et	3	main
mille	doc_49256336380_item	2664231	et	3	main
poolest	doc_49256336380_item	2664232	et	4	main
erineb	doc_49256336380_item	2664233	et	3	main
klassijuhatajat	doc_49256336380_item	2664246	et	3	main
ole	doc_49256336380_item	2664250	et	4	main
aga	doc_49256336380_item	2664252	et	3	main
kui	doc_49256336380_item	2664253	et	3	main
on	doc_49256336380_item	2664255	et	4	main
ikkagi	doc_491521502319_item	2663924	et	4	main
hea	doc_491521502319_item	2663925	et	4	main
kui	doc_491521502319_item	2663926	et	3	main
mis	doc_491521502319_item	2663931	et	4	main
vaatan	doc_491521502319_item	2663935	et	3	main
tana	doc_491521502319_item	2663938	et	4	main
kahtteist	doc_491521502319_item	2663948	et	4	main
muidu	doc_491521502319_item	2663949	et	3	main
et	doc_491521502319_item	2663953	et	3	main
nii	doc_491521502319_item	2663962	et	3	main
teha	doc_491521502319_item	2663964	et	3	main
jattaks	doc_491521502319_item	2663977	et	4	main
siis	doc_491521502319_item	2663978	et	3	main
selle	doc_491521502319_item	2663979	et	4	main
katte	doc_491521502319_item	2663986	et	4	main
sa	doc_491521502319_item	2663988	et	3	main
ise	doc_491521502319_item	2663990	et	4	main
need	doc_491521502319_item	2663991	et	3	main
pildid	doc_491521502319_item	2663992	et	3	main
kusgilt	doc_491521502319_item	2663993	et	4	main
vaipade	doc_491521502319_item	2664001	et	3	main
on	doc_491521502319_item	2664003	et	4	main
lihtne	doc_491521502319_item	2664004	et	3	main
noh	doc_491521502319_item	2664011	et	3	main
aga	doc_491521502319_item	2664012	et	3	main
teata	doc_491521502319_item	2664013	et	4	main
siis	doc_491521502319_item	2664014	et	3	main
onju	doc_491521502319_item	2664015	et	4	main
eesnimi	doc_491521502319_item	2664016	et	3	main
kiri	doc_491521502319_item	2664017	et	3	main
3	doc_491521502319_item	2664018	et	2	main
ma	doc_491521502319_item	2664019	et	3	main
tulen	doc_491521502319_item	2664020	et	3	main
interjoori	doc_491521502319_item	2663980	et	4	main
ja	doc_491521502319_item	2663987	et	3	main
onju	doc_491521502319_item	2663997	et	4	main
arvan	doc_491521502319_item	2663998	et	3	main
igal	doc_491521502319_item	2664008	et	3	main
klaasi	doc_491521502319_item	2664031	et	4	main
naitus	doc_491521502319_item	2664032	et	4	main
vist	doc_491521502319_item	2664037	et	4	main
olla	doc_491521502319_item	2664044	et	3	main
onju	doc_491521502319_item	2664059	et	4	main
test	doc_491521502320_item	2664080	et	3	main
kord	doc_49256336380_item	2664104	et	4	main
kus	doc_49256336380_item	2664105	et	3	main
siin	doc_49256336380_item	2664113	et	4	main
avaldus	doc_49256336380_item	2664116	et	4	main
lakoonilised	doc_49256336380_item	2664121	et	3	main
lugeda	doc_49256336380_item	2664131	et	3	main
kiiresti	doc_49256336380_item	2664134	et	3	main
teha	doc_49256336380_item	2664135	et	3	main
ta	doc_49256336380_item	2664142	et	4	main
saab	doc_49256336380_item	2664143	et	3	main
midagi	doc_49256336380_item	2664144	et	4	main
küsida	doc_49256336380_item	2664149	et	3	main
leida	doc_49256336380_item	2664157	et	3	main
sobiv	doc_49256336380_item	2664161	et	4	main
ja	doc_49256336380_item	2664163	et	3	main
välimus	doc_49256336380_item	2664165	et	3	main
saama	doc_49256336380_item	2664195	et	4	main
kas	doc_49256336380_item	2664196	et	3	main
see	doc_49256336380_item	2664197	et	3	main
inimene	doc_49256336380_item	2664198	et	3	main
soobib	doc_49256336380_item	2664199	et	4	main
ei	doc_49256336380_item	2664204	et	4	main
suurem	doc_49256336380_item	2664214	et	4	main
probleem	doc_49256336380_item	2664215	et	3	main
koolis	doc_49256336380_item	2664216	et	4	main
ei	doc_49256336380_item	2664220	et	4	main
kõrgkoolis	doc_49256336380_item	2664235	et	4	main
ei	doc_49256336380_item	2664244	et	4	main
ei	doc_49256336380_item	2664249	et	4	main
ekstruktsiooni	doc_49256336380_item	2664266	et	4	main
lülitama	doc_49256336380_item	2664275	et	4	main
20	doc_491521502319_item	2664040	et	2	main
siis	doc_491521502319_item	2664045	et	3	main
ka	doc_491521502319_item	2664046	et	3	main
pildistada	doc_491521502319_item	2664049	et	3	main
vahemalt	doc_491521502319_item	2664052	et	4	main
kokku	doc_491521502319_item	2664053	et	3	main
saaks	doc_491521502319_item	2664054	et	3	main
siis	doc_491521502319_item	2664055	et	3	main
saaks	doc_491521502319_item	2664056	et	3	main
asja	doc_491521502319_item	2664057	et	4	main
arutada	doc_491521502319_item	2664058	et	3	main
umbes	doc_491521502319_item	2664062	et	4	main
20ndal	doc_491521502319_item	2664063	et	4	main
tulen	doc_491521502319_item	2664064	et	3	main
voi	doc_491521502319_item	2664065	et	4	main
siis	doc_491521502319_item	2664066	et	3	main
paeva	doc_491521502319_item	2664067	et	4	main
enne	doc_491521502319_item	2664068	et	4	main
naiteks	doc_491521502319_item	2664069	et	4	main
kui	doc_491521502319_item	2664070	et	3	main
vaja	doc_491521502319_item	2664071	et	4	main
eesnimi	doc_491521502319_item	2664072	et	3	main
test	doc_491521502320_item	2664073	et	3	main
doc	doc_491521502320_item	2664074	et	4	main
ja	doc_491521502320_item	2664075	et	3	main
trallalala	doc_491521502320_item	2664076	et	4	main
gogogo	doc_491521502320_item	2664078	et	4	main
tööintervjuuks	doc_49256336380_item	2664082	et	3	main
pole	doc_49256336380_item	2664083	et	3	main
ja	doc_49256336380_item	2664094	et	3	main
peab	doc_49256336380_item	2664098	et	4	main
kirjutada	doc_49256336380_item	2664099	et	3	main
kus	doc_49256336380_item	2664100	et	3	main
ta	doc_49256336380_item	2664101	et	4	main
töötas	doc_49256336380_item	2664102	et	3	main
eelmine	doc_49256336380_item	2664103	et	3	main
ja	doc_49256336380_item	2664115	et	3	main
sellepärast	doc_49256336380_item	2664122	et	3	main
peab	doc_49256336380_item	2664130	et	4	main
seda	doc_49256336380_item	2664133	et	3	main
ja	doc_49256336380_item	2664136	et	3	main
aru	doc_49256336380_item	2664148	et	4	main
tööd	doc_49256336380_item	2664156	et	4	main
see	doc_49256336380_item	2664166	et	3	main
tööandjad	doc_49256336380_item	2664173	et	3	main
või	doc_49256336380_item	2664203	et	4	main
suuremad	doc_49256336380_item	2664211	et	4	main
probleemid	doc_49256336380_item	2664212	et	3	main
kõige	doc_49256336380_item	2664213	et	4	main
õpilased	doc_49256336380_item	2664219	et	3	main
kõigest	doc_49256336380_item	2664137	et	4	main
sai	doc_49256336380_item	2664138	et	4	main
aru	doc_49256336380_item	2664139	et	4	main
ja	doc_49256336380_item	2664140	et	3	main
pärast	doc_49256336380_item	2664141	et	4	main
sobiv	doc_49256336380_item	2664150	et	4	main
riietus	doc_49256336380_item	2664151	et	4	main
ja	doc_49256336380_item	2664152	et	3	main
hea	doc_49256336380_item	2664153	et	4	main
välimus	doc_49256336380_item	2664154	et	3	main
aitavad	doc_49256336380_item	2664155	et	4	main
inimesel	doc_49256336380_item	2664159	et	3	main
peaks	doc_49256336380_item	2664178	et	4	main
endast	doc_49256336380_item	2664179	et	4	main
endast	doc_49256336380_item	2664186	et	4	main
et	doc_49256336380_item	2664190	et	3	main
inimesed	doc_49256336380_item	2664192	et	3	main
peavad	doc_49256336380_item	2664193	et	4	main
aru	doc_49256336380_item	2664194	et	4	main
kohal	doc_49256336380_item	2664202	et	4	main
mis	doc_49256336380_item	2664206	et	4	main
praegu	doc_49256336380_item	2664208	et	3	main
see	doc_49256336380_item	2664217	et	3	main
õppimine	doc_49256336380_item	2664234	et	4	main
ole	doc_49256336380_item	2664245	et	4	main
kui	doc_49256336380_item	2664268	et	3	main
tehtud	doc_49256336380_item	2664270	et	4	main
elektriseadmet	doc_49256336380_item	2664271	et	4	main
peab	doc_49256336380_item	2664272	et	4	main
peaks	doc_49256336380_item	2664277	et	4	main
inimene	doc_49256336380_item	2664278	et	3	main
tegema	doc_49256336380_item	2664279	et	3	main
vaja	doc_49256336381_item	2664316	et	4	main
valmistada	doc_49256336381_item	2664317	et	3	main
iseseisvalt	doc_49256336381_item	2664324	et	4	main
avaldus	doc_49256336381_item	2664336	et	4	main
tean	doc_49256336381_item	2664342	et	3	main
kirjutada	doc_49256336381_item	2664348	et	3	main
cvt	doc_49256336381_item	2664349	et	4	main
kirjutatud	doc_49256336381_item	2664355	et	4	main
see	doc_49256336381_item	2664384	et	3	main
ainult	doc_49256336381_item	2664386	et	4	main
klassis	doc_49256336381_item	2664388	et	3	main
erineb	doc_49256336381_item	2664395	et	3	main
õppimisest	doc_49256336381_item	2664398	et	4	main
koolis	doc_49256336381_item	2664400	et	4	main
füüsika	doc_49256336381_item	2664411	et	4	main
sa	doc_49256336381_item	2664423	et	3	main
kontrolltöö	doc_49256336382_item	2664431	et	4	main
see	doc_49256336382_item	2664436	et	3	main
vale	doc_49256336382_item	2664439	et	4	main
parem	doc_49256336382_item	2664441	et	4	main
valmistada	doc_49256336382_item	2664444	et	3	main
tahab	doc_49256336382_item	2664447	et	3	main
lühikesed	doc_49256336382_item	2664461	et	4	main
ja	doc_49256336382_item	2664462	et	3	main
lakoonilised	doc_49256336382_item	2664463	et	3	main
cvis	doc_49256336382_item	2664468	et	4	main
tööd	doc_49256336382_item	2664523	et	4	main
praegu	doc_49256336382_item	2664527	et	3	main
arvan	doc_49256336382_item	2664533	et	3	main
vara	doc_49256336382_item	2664539	et	4	main
tõustmine	doc_49256336382_item	2664541	et	4	main
saa	doc_49256336382_item	2664544	et	4	main
erineb	doc_49256336382_item	2664554	et	3	main
pärast	doc_49256336382_item	2664591	et	4	main
tegurid	doc_503739895319_item	2664603	et	3	main
nsvl	doc_503739895319_item	2664611	et	4	main
lähisvälismaana	doc_503739895319_item	2664612	et	3	main
2	doc_503739895319_item	2664613	et	2	main
l	doc_503739895319_item	2664614	et	4	main
baltiest	doc_503739895319_item	2664633	et	4	main
tööjõu	doc_503739895319_item	2664634	et	3	main
sissetulek	doc_503739895319_item	2664635	et	3	main
linnas	doc_503739895319_item	2664636	et	4	main
eestlasi	doc_503739895319_item	2664637	et	3	main
kompleks	doc_503739895319_item	2664651	et	4	main
kontakteerida	doc_503739895319_item	2664654	et	4	main
poolt	doc_503739895319_item	2664658	et	4	main
võimas	doc_503739895319_item	2664660	et	4	main
saamine	doc_503739895319_item	2664670	et	4	main
eesti	doc_503739895319_item	2664676	et	4	main
vitriin	doc_503739895319_item	2664680	et	3	main
kinomajasi	doc_503739895319_item	2664695	et	4	main
estonia	doc_503739895319_item	2664697	et	4	main
muidugi	doc_49256336380_item	2664167	et	4	main
tööd	doc_49256336380_item	2664169	et	4	main
sellepärast	doc_49256336380_item	2664171	et	3	main
palju	doc_49256336380_item	2664180	et	4	main
rääkima	doc_49256336380_item	2664181	et	3	main
inimene	doc_49256336380_item	2664182	et	3	main
muidugi	doc_49256336380_item	2664183	et	4	main
palju	doc_49256336380_item	2664187	et	4	main
rääkima	doc_49256336380_item	2664188	et	3	main
sellepärast	doc_49256336380_item	2664189	et	3	main
teised	doc_49256336380_item	2664191	et	4	main
sellele	doc_49256336380_item	2664200	et	4	main
soobi	doc_49256336380_item	2664205	et	3	main
hästi	doc_49256336380_item	2664222	et	3	main
sellepärast	doc_49256336380_item	2664224	et	3	main
praegu	doc_49256336380_item	2664226	et	3	main
raske	doc_49256336380_item	2664230	et	4	main
koolis	doc_49256336380_item	2664237	et	4	main
kui	doc_49256336380_item	2664238	et	3	main
sa	doc_49256336380_item	2664239	et	3	main
õppid	doc_49256336380_item	2664240	et	4	main
kõrgkoolis	doc_49256336380_item	2664241	et	4	main
siis	doc_49256336380_item	2664242	et	3	main
sul	doc_49256336380_item	2664243	et	3	main
ka	doc_49256336380_item	2664248	et	3	main
kontrolltööd	doc_49256336380_item	2664251	et	4	main
nad	doc_49256336380_item	2664254	et	3	main
harva	doc_49256336380_item	2664258	et	4	main
kasutada	doc_49256336380_item	2664265	et	3	main
välja	doc_49256336380_item	2664274	et	4	main
ega	doc_49256336381_item	2664318	et	3	main
olema	doc_49256336381_item	2664338	et	4	main
kuidas	doc_49256336381_item	2664347	et	3	main
avaldust	doc_49256336381_item	2664351	et	4	main
on	doc_49256336381_item	2664354	et	4	main
must	doc_49256336381_item	2664364	et	4	main
ilmub	doc_49256336381_item	2664385	et	3	main
see	doc_49256336381_item	2664389	et	3	main
on	doc_49256336381_item	2664401	et	4	main
ole	doc_49256336381_item	2664408	et	4	main
ne	doc_49256336381_item	2664415	et	4	main
aga	doc_49256336381_item	2664416	et	3	main
kui	doc_49256336381_item	2664417	et	3	main
sa	doc_49256336381_item	2664418	et	3	main
ei	doc_49256336381_item	2664424	et	4	main
on	doc_49256336381_item	2664428	et	4	main
teistmodi	doc_49256336381_item	2664430	et	4	main
vaja	doc_49256336382_item	2664434	et	4	main
on	doc_49256336382_item	2664438	et	4	main
sest	doc_49256336382_item	2664440	et	4	main
ette	doc_49256336382_item	2664443	et	4	main
küsimustele	doc_49256336382_item	2664454	et	4	main
vastata	doc_49256336382_item	2664455	et	4	main
cv	doc_49256336382_item	2664456	et	4	main
ja	doc_49256336382_item	2664457	et	3	main
avaldus	doc_49256336382_item	2664458	et	4	main
väide	doc_49256336382_item	2664465	et	4	main
on	doc_49256336382_item	2664466	et	4	main
õige	doc_49256336382_item	2664467	et	4	main
avalduses	doc_49256336382_item	2664470	et	4	main
olema	doc_49256336382_item	2664472	et	4	main
ainult	doc_49256336382_item	2664473	et	4	main
konkreetsed	doc_49256336382_item	2664474	et	3	main
faktid	doc_49256336382_item	2664475	et	3	main
tööd	doc_49256336382_item	2664482	et	4	main
leida	doc_49256336382_item	2664483	et	3	main
see	doc_49256336382_item	2664484	et	3	main
õige	doc_49256336382_item	2664487	et	4	main
mis	doc_49256336382_item	2664525	et	4	main
kõige	doc_49256336382_item	2664535	et	4	main
hommiku	doc_49256336382_item	2664540	et	3	main
ei	doc_49256336382_item	2664543	et	4	main
magada	doc_49256336382_item	2664545	et	3	main
kaua	doc_49256336382_item	2664547	et	3	main
neil	doc_49256336382_item	2664549	et	4	main
on	doc_49256336382_item	2664550	et	4	main
õppimine	doc_49256336382_item	2664555	et	4	main
õppimisest	doc_49256336382_item	2664557	et	4	main
koolis	doc_49256336382_item	2664558	et	4	main
klassijuhatajat	doc_49256336382_item	2664562	et	3	main
ei	doc_49256336382_item	2664564	et	4	main
alati	doc_49256336382_item	2664587	et	4	main
välja	doc_49256336382_item	2664589	et	4	main
triikrauda	doc_49256336382_item	2664590	et	4	main
3	doc_49256336382_item	2664593	et	2	main
on	doc_49256336380_item	2664228	et	4	main
õppimisest	doc_49256336380_item	2664236	et	4	main
kõrgkoolis	doc_49256336380_item	2664247	et	4	main
pange	doc_49256336380_item	2664259	et	4	main
kirja	doc_49256336380_item	2664260	et	4	main
kolm	doc_49256336380_item	2664261	et	3	main
soovitust	doc_49256336380_item	2664262	et	4	main
elektriseadmetega	doc_49256336380_item	2664263	et	3	main
olema	doc_49256336380_item	2664273	et	4	main
et	doc_49256336380_item	2664280	et	3	main
vähendada	doc_49256336380_item	2664281	et	3	main
kuriteo	doc_49256336380_item	2664282	et	4	main
ohvriks	doc_49256336380_item	2664283	et	3	main
sattumise	doc_49256336380_item	2664284	et	4	main
riski	doc_49256336380_item	2664285	et	4	main
inimene	doc_49256336380_item	2664286	et	3	main
peab	doc_49256336380_item	2664287	et	4	main
olema	doc_49256336380_item	2664288	et	4	main
väga	doc_49256336380_item	2664289	et	3	main
ettevatlikult	doc_49256336380_item	2664290	et	4	main
kui	doc_49256336380_item	2664291	et	3	main
ta	doc_49256336380_item	2664292	et	4	main
istus	doc_49256336380_item	2664293	et	4	main
üksi	doc_49256336380_item	2664295	et	4	main
siis	doc_49256336380_item	2664296	et	3	main
kodus	doc_49256336380_item	2664294	et	4	main
kõik	doc_49256336380_item	2664297	et	4	main
uksed	doc_49256336380_item	2664298	et	3	main
peab	doc_49256336380_item	2664299	et	4	main
olema	doc_49256336380_item	2664300	et	4	main
kinni	doc_49256336380_item	2664301	et	3	main
kontrolltöö	doc_49256336381_item	2664302	et	4	main
tööintervjuuks	doc_49256336381_item	2664303	et	3	main
pole	doc_49256336381_item	2664304	et	3	main
vaja	doc_49256336381_item	2664305	et	4	main
valmistuda	doc_49256336381_item	2664306	et	3	main
esiteks	doc_49256336381_item	2664307	et	3	main
kirjutan	doc_49256336381_item	2664308	et	3	main
et	doc_49256336381_item	2664309	et	3	main
olen	doc_49256336381_item	2664310	et	3	main
selle	doc_49256336381_item	2664311	et	4	main
väitega	doc_49256336381_item	2664312	et	3	main
nõus	doc_49256336381_item	2664313	et	4	main
natuke	doc_49256336381_item	2664314	et	4	main
on	doc_49256336381_item	2664315	et	4	main
siis	doc_49256336380_item	2664256	et	3	main
väga	doc_49256336380_item	2664257	et	3	main
töötamiseks	doc_49256336380_item	2664264	et	4	main
eest	doc_49256336380_item	2664267	et	4	main
kõik	doc_49256336380_item	2664269	et	4	main
mida	doc_49256336380_item	2664276	et	4	main
mitte	doc_49256336381_item	2664319	et	3	main
inimene	doc_49256336381_item	2664321	et	3	main
tööle	doc_49256336381_item	2664323	et	3	main
cv	doc_49256336381_item	2664334	et	4	main
ja	doc_49256336381_item	2664335	et	3	main
lakoonilised	doc_49256336381_item	2664341	et	3	main
eksisteerivad	doc_49256336381_item	2664344	et	4	main
täpsed	doc_49256336381_item	2664345	et	3	main
kas	doc_49256336381_item	2664356	et	3	main
lühike	doc_49256336381_item	2664359	et	4	main
pikk	doc_49256336381_item	2664361	et	4	main
puhas	doc_49256336381_item	2664362	et	3	main
või	doc_49256336381_item	2664363	et	4	main
mille	doc_49256336381_item	2664393	et	3	main
kõrgkoolis	doc_49256336381_item	2664397	et	4	main
palju	doc_49256336381_item	2664402	et	4	main
tundi	doc_49256336381_item	2664403	et	4	main
mis	doc_49256336381_item	2664404	et	4	main
sulle	doc_49256336381_item	2664405	et	3	main
üldse	doc_49256336381_item	2664406	et	3	main
ei	doc_49256336381_item	2664407	et	4	main
keemia	doc_49256336381_item	2664412	et	4	main
tööõpetus	doc_49256336381_item	2664413	et	3	main
ja	doc_49256336381_item	2664414	et	3	main
taha	doc_49256336381_item	2664420	et	4	main
seda	doc_49256336381_item	2664421	et	3	main
ülekoolis	doc_49256336381_item	2664427	et	4	main
on	doc_49256336382_item	2664442	et	4	main
tööd	doc_49256336382_item	2664449	et	4	main
olema	doc_49256336382_item	2664460	et	4	main
riietus	doc_49256336382_item	2664477	et	4	main
ja	doc_49256336382_item	2664478	et	3	main
välimus	doc_49256336382_item	2664480	et	3	main
aitavad	doc_49256336382_item	2664481	et	4	main
inimene	doc_49256336382_item	2664490	et	3	main
palju	doc_49256336381_item	2664320	et	4	main
enne	doc_49256336381_item	2664325	et	4	main
seda	doc_49256336381_item	2664326	et	3	main
ta	doc_49256336381_item	2664327	et	4	main
peab	doc_49256336381_item	2664328	et	4	main
tasakaalustada	doc_49256336381_item	2664329	et	3	main
peavad	doc_49256336381_item	2664337	et	4	main
standartid	doc_49256336381_item	2664346	et	4	main
kuidas	doc_49256336381_item	2664352	et	3	main
cv	doc_49256336381_item	2664353	et	4	main
või	doc_49256336381_item	2664360	et	4	main
lõppueksamid	doc_49256336381_item	2664392	et	4	main
õppimine	doc_49256336381_item	2664396	et	4	main
koolis	doc_49256336381_item	2664399	et	4	main
läheb	doc_49256336381_item	2664322	et	3	main
oma	doc_49256336381_item	2664330	et	4	main
võimalusi	doc_49256336381_item	2664331	et	3	main
ja	doc_49256336381_item	2664332	et	3	main
teadmisi	doc_49256336381_item	2664333	et	4	main
lühikesed	doc_49256336381_item	2664339	et	4	main
ja	doc_49256336381_item	2664340	et	3	main
et	doc_49256336381_item	2664343	et	3	main
ja	doc_49256336381_item	2664350	et	3	main
on	doc_49256336381_item	2664357	et	4	main
see	doc_49256336381_item	2664358	et	3	main
nii	doc_49256336381_item	2664365	et	3	main
aravtaks	doc_49256336381_item	2664366	et	4	main
pidakse	doc_49256336381_item	2664367	et	4	main
selle	doc_49256336381_item	2664368	et	4	main
inimesele	doc_49256336381_item	2664369	et	3	main
kohta	doc_49256336381_item	2664370	et	4	main
mis	doc_49256336381_item	2664371	et	4	main
on	doc_49256336381_item	2664372	et	4	main
praegu	doc_49256336381_item	2664373	et	3	main
koolis	doc_49256336381_item	2664374	et	4	main
suuremad	doc_49256336381_item	2664376	et	4	main
kõige	doc_49256336381_item	2664375	et	4	main
probleemid	doc_49256336381_item	2664377	et	3	main
koolis	doc_49256336381_item	2664378	et	4	main
on	doc_49256336381_item	2664379	et	4	main
ainult	doc_49256336381_item	2664380	et	4	main
üks	doc_49256336381_item	2664381	et	3	main
suur	doc_49256336381_item	2664382	et	3	main
probleem	doc_49256336381_item	2664383	et	3	main
12	doc_49256336381_item	2664387	et	2	main
probleem	doc_49256336381_item	2664390	et	3	main
on	doc_49256336381_item	2664391	et	4	main
poolest	doc_49256336381_item	2664394	et	4	main
vaja	doc_49256336381_item	2664409	et	4	main
näiteks	doc_49256336381_item	2664410	et	4	main
ei	doc_49256336381_item	2664419	et	4	main
õppida	doc_49256336381_item	2664422	et	3	main
sul	doc_49256336381_item	2664426	et	3	main
tööintervjuuks	doc_49256336382_item	2664432	et	3	main
väide	doc_49256336382_item	2664437	et	4	main
kes	doc_49256336382_item	2664446	et	4	main
peab	doc_49256336382_item	2664450	et	4	main
olema	doc_49256336382_item	2664451	et	4	main
see	doc_49256336382_item	2664464	et	3	main
ja	doc_49256336382_item	2664469	et	3	main
peavad	doc_49256336382_item	2664471	et	4	main
hea	doc_49256336382_item	2664479	et	4	main
on	doc_49256336382_item	2664486	et	4	main
kui	doc_49256336382_item	2664489	et	3	main
hästi	doc_49256336382_item	2664491	et	3	main
aitab	doc_49256336382_item	2664521	et	3	main
mina	doc_49256336382_item	2664532	et	4	main
et	doc_49256336382_item	2664534	et	3	main
suurem	doc_49256336382_item	2664536	et	4	main
probleem	doc_49256336382_item	2664537	et	3	main
nii	doc_49256336382_item	2664546	et	3	main
kõrgkoolis	doc_49256336382_item	2664559	et	4	main
2	doc_49256336382_item	2664586	et	2	main
järgi	doc_49256336382_item	2664598	et	4	main
kontrolltöö	doc_503739895319_item	2664599	et	4	main
1	doc_503739895319_item	2664600	et	2	main
missugused	doc_503739895319_item	2664601	et	3	main
end	doc_503739895319_item	2664610	et	4	main
arvates	doc_503739895319_item	2664620	et	4	main
tööstus	doc_503739895319_item	2664630	et	3	main
balti	doc_503739895319_item	2664631	et	3	main
teistega	doc_503739895319_item	2664643	et	4	main
liitlastega	doc_503739895319_item	2664644	et	3	main
kõrgemate	doc_503739895319_item	2664645	et	4	main
tehnoloogiate	doc_503739895319_item	2664646	et	3	main
kasutamine	doc_503739895319_item	2664647	et	4	main
keemia	doc_503739895319_item	2664652	et	4	main
piir	doc_503739895319_item	2664659	et	3	main
välismaa	doc_503739895319_item	2664668	et	4	main
toodete	doc_503739895319_item	2664669	et	3	main
nsvl	doc_503739895319_item	2664677	et	4	main
arenenud	doc_503739895319_item	2664686	et	4	main
kultuur	doc_503739895319_item	2664688	et	3	main
kultuurimajad	doc_503739895319_item	2664690	et	4	main
välismaa	doc_503739895319_item	2664723	et	4	main
autorid	doc_503739895319_item	2664726	et	3	main
shakespeare	doc_503739895319_item	2664732	et	4	main
kunstnikute	doc_503739895319_item	2664738	et	4	main
ühing	doc_503739895319_item	2664739	et	3	main
laulud	doc_503739895319_item	2664747	et	3	main
oli	doc_503739895319_item	2664760	et	3	main
langes	doc_503739895319_item	2664771	et	4	main
õppejõud	doc_503739895319_item	2664772	et	4	main
proosa	doc_503739895319_item	2664778	et	4	main
miljonini	doc_503739895319_item	2664818	et	3	main
saa	doc_49256336381_item	2664425	et	4	main
raskem	doc_49256336381_item	2664429	et	4	main
pole	doc_49256336382_item	2664433	et	3	main
valmistuda	doc_49256336382_item	2664435	et	3	main
inimene	doc_49256336382_item	2664445	et	3	main
saata	doc_49256336382_item	2664448	et	3	main
valmis	doc_49256336382_item	2664452	et	4	main
erinevate	doc_49256336382_item	2664453	et	4	main
peavad	doc_49256336382_item	2664459	et	4	main
sobiv	doc_49256336382_item	2664476	et	4	main
väide	doc_49256336382_item	2664485	et	4	main
sest	doc_49256336382_item	2664488	et	4	main
näeb	doc_49256336382_item	2664493	et	3	main
see	doc_49256336382_item	2664494	et	3	main
välja	doc_49256336382_item	2664492	et	4	main
on	doc_49256336382_item	2664495	et	4	main
tema	doc_49256336382_item	2664496	et	4	main
pluss	doc_49256336382_item	2664497	et	3	main
ja	doc_49256336382_item	2664498	et	3	main
tööandja	doc_49256336382_item	2664499	et	4	main
näeb	doc_49256336382_item	2664500	et	3	main
et	doc_49256336382_item	2664501	et	3	main
see	doc_49256336382_item	2664502	et	3	main
on	doc_49256336382_item	2664503	et	4	main
korralik	doc_49256336382_item	2664504	et	3	main
inimene	doc_49256336382_item	2664505	et	3	main
tööintervjuul	doc_49256336382_item	2664506	et	3	main
peaks	doc_49256336382_item	2664507	et	4	main
endast	doc_49256336382_item	2664508	et	4	main
palju	doc_49256336382_item	2664509	et	4	main
see	doc_49256336382_item	2664511	et	3	main
rääkima	doc_49256336382_item	2664510	et	3	main
on	doc_49256336382_item	2664512	et	4	main
aga	doc_49256336382_item	2664514	et	3	main
inimene	doc_49256336382_item	2664515	et	3	main
õige	doc_49256336382_item	2664513	et	4	main
peab	doc_49256336382_item	2664516	et	4	main
rääkima	doc_49256336382_item	2664517	et	3	main
ainult	doc_49256336382_item	2664518	et	4	main
seda	doc_49256336382_item	2664519	et	3	main
mida	doc_49256336382_item	2664520	et	4	main
saata	doc_49256336382_item	2664524	et	3	main
suuremad	doc_49256336382_item	2664530	et	4	main
probleemid	doc_49256336382_item	2664531	et	3	main
on	doc_49256336382_item	2664538	et	4	main
lapsed	doc_49256336382_item	2664542	et	3	main
kui	doc_49256336382_item	2664548	et	3	main
vaja	doc_49256336382_item	2664551	et	4	main
mille	doc_49256336382_item	2664552	et	3	main
poolest	doc_49256336382_item	2664553	et	4	main
kõrgkoolis	doc_49256336382_item	2664556	et	4	main
ole	doc_49256336382_item	2664561	et	4	main
kasutamisel	doc_49256336382_item	2664592	et	4	main
majanduslikud-kultuurilised	doc_503739895319_item	2664602	et	4	main
1970ndatel	doc_503739895319_item	2664605	et	4	main
talle	doc_49256336382_item	2664522	et	4	main
on	doc_49256336382_item	2664526	et	4	main
koolis	doc_49256336382_item	2664528	et	4	main
kõige	doc_49256336382_item	2664529	et	4	main
ei	doc_49256336382_item	2664560	et	4	main
kõrgkoolis	doc_49256336382_item	2664563	et	4	main
ole	doc_49256336382_item	2664565	et	4	main
nii	doc_49256336382_item	2664566	et	3	main
palju	doc_49256336382_item	2664567	et	4	main
kontrolltööid	doc_49256336382_item	2664568	et	4	main
ainult	doc_49256336382_item	2664569	et	4	main
arvestused	doc_49256336382_item	2664570	et	4	main
eksamid	doc_49256336382_item	2664572	et	3	main
või	doc_49256336382_item	2664571	et	4	main
pange	doc_49256336382_item	2664573	et	4	main
kirja	doc_49256336382_item	2664574	et	4	main
kolm	doc_49256336382_item	2664575	et	3	main
soovitust	doc_49256336382_item	2664576	et	4	main
elektriseadmetega	doc_49256336382_item	2664577	et	3	main
töötamiseks	doc_49256336382_item	2664578	et	4	main
1	doc_49256336382_item	2664579	et	2	main
olema	doc_49256336382_item	2664580	et	4	main
alati	doc_49256336382_item	2664581	et	4	main
ettevatlik	doc_49256336382_item	2664582	et	4	main
kui	doc_49256336382_item	2664583	et	3	main
töötad	doc_49256336382_item	2664584	et	3	main
elektriseadmetega	doc_49256336382_item	2664585	et	3	main
lülitada	doc_49256336382_item	2664588	et	3	main
alati	doc_49256336382_item	2664594	et	4	main
laiuse	doc_503739895319_item	2664615	et	4	main
mängufilm	doc_503739895319_item	2664616	et	3	main
libahunt	doc_503739895319_item	2664617	et	3	main
ajaloodokument	doc_503739895319_item	2664621	et	3	main
ühiskonnakriitika	doc_503739895319_item	2664623	et	4	main
1	doc_503739895319_item	2664625	et	2	main
majanduslikud	doc_503739895319_item	2664626	et	3	main
faktorid	doc_503739895319_item	2664627	et	3	main
kerkisid	doc_503739895319_item	2664628	et	4	main
kõrgem	doc_503739895319_item	2664639	et	4	main
rahva	doc_503739895319_item	2664640	et	3	main
elutase	doc_503739895319_item	2664641	et	3	main
võrreldes	doc_503739895319_item	2664642	et	3	main
sõja	doc_503739895319_item	2664649	et	3	main
avatud	doc_503739895319_item	2664656	et	4	main
elektritööstuse	doc_503739895319_item	2664661	et	3	main
omamine	doc_503739895319_item	2664662	et	4	main
suur	doc_503739895319_item	2664663	et	3	main
elektritööstus	doc_503739895319_item	2664664	et	3	main
bej	doc_503739895319_item	2664665	et	4	main
oli	doc_503739895319_item	2664671	et	3	main
saadavad	doc_503739895319_item	2664672	et	4	main
mõned	doc_503739895319_item	2664673	et	3	main
nõukogude	doc_503739895319_item	2664678	et	3	main
vähem	doc_503739895319_item	2664685	et	4	main
liitlsetele	doc_503739895319_item	2664687	et	4	main
külade	doc_503739895319_item	2664689	et	3	main
pannakse	doc_503739895319_item	2664691	et	3	main
kinni	doc_503739895319_item	2664692	et	3	main
edukalt	doc_503739895319_item	2664693	et	4	main
ehitatakse	doc_503739895319_item	2664694	et	3	main
algus	doc_503739895319_item	2664700	et	4	main
võetud	doc_503739895319_item	2664729	et	4	main
algus	doc_503739895319_item	2664734	et	4	main
koorid	doc_503739895319_item	2664741	et	4	main
lavastused	doc_503739895319_item	2664755	et	4	main
kontekst	doc_503739895319_item	2664759	et	3	main
peidetud	doc_503739895319_item	2664762	et	4	main
suurem	doc_503739895319_item	2664776	et	4	main
kõikuvad	doc_503739895319_item	2664811	et	4	main
esemed	doc_503739895319_item	2664819	et	3	main
olema	doc_503739895319_item	2664824	et	4	main
sotsialistlik	doc_503739895319_item	2664825	et	3	main
aga	doc_503739895319_item	2664826	et	3	main
staalin	doc_503739895319_item	2664829	et	4	main
mõtted	doc_503739895319_item	2664830	et	3	main
kultuurist	doc_503739895319_item	2664831	et	3	main
xix	doc_503739895319_item	2664832	et	4	main
mis	doc_503739895319_item	2664841	et	4	main
rohkem	doc_503739895319_item	2664856	et	4	main
tütarlaps	doc_503739895319_item	2664876	et	4	main
nimetab	doc_503739895319_item	2664877	et	3	main
lahke	doc_503739895319_item	2664894	et	4	main
siber	doc_503739895319_item	2664895	et	4	main
ootab	doc_503739895319_item	2664896	et	3	main
on	doc_503739895319_item	2664902	et	4	main
suhtumine	doc_503739895319_item	2664905	et	4	main
kasutada	doc_49256336382_item	2664595	et	3	main
elektritooded	doc_49256336382_item	2664596	et	4	main
instruktsiooni	doc_49256336382_item	2664597	et	4	main
andsid	doc_503739895319_item	2664604	et	4	main
põhjust	doc_503739895319_item	2664606	et	4	main
eesti	doc_503739895319_item	2664607	et	4	main
nsvl	doc_503739895319_item	2664608	et	4	main
tunda	doc_503739895319_item	2664609	et	3	main
kas	doc_503739895319_item	2664618	et	3	main
teie	doc_503739895319_item	2664619	et	4	main
suuremad	doc_503739895319_item	2664629	et	4	main
elektrijaam	doc_503739895319_item	2664632	et	3	main
tööstuse	doc_503739895319_item	2664650	et	3	main
turistidega	doc_503739895319_item	2664655	et	3	main
eej	doc_503739895319_item	2664666	et	4	main
tej	doc_503739895319_item	2664667	et	4	main
toodangud	doc_503739895319_item	2664675	et	3	main
pidi	doc_503739895319_item	2664682	et	4	main
olema	doc_503739895319_item	2664683	et	4	main
kosmos	doc_503739895319_item	2664696	et	3	main
natsionaalsele	doc_503739895319_item	2664701	et	3	main
või	doc_503739895319_item	2664622	et	4	main
miks	doc_503739895319_item	2664624	et	4	main
vähemus	doc_503739895319_item	2664638	et	4	main
eriti	doc_503739895319_item	2664648	et	3	main
võimalus	doc_503739895319_item	2664653	et	3	main
ühelt	doc_503739895319_item	2664657	et	3	main
välismaa	doc_503739895319_item	2664674	et	4	main
liidu	doc_503739895319_item	2664679	et	3	main
siin	doc_503739895319_item	2664681	et	4	main
eeskuju	doc_503739895319_item	2664684	et	4	main
pandud	doc_503739895319_item	2664699	et	4	main
filmitegemisele	doc_503739895319_item	2664702	et	3	main
alternatiiv	doc_503739895319_item	2664703	et	3	main
sotskiituslikele	doc_503739895319_item	2664704	et	4	main
filmidele	doc_503739895319_item	2664705	et	3	main
rohkem	doc_503739895319_item	2664706	et	4	main
tähelepanu	doc_503739895319_item	2664707	et	4	main
rahvaliku	doc_503739895319_item	2664708	et	3	main
kultuurile	doc_503739895319_item	2664709	et	3	main
püütakse	doc_503739895319_item	2664710	et	3	main
taastada	doc_503739895319_item	2664711	et	3	main
rahva	doc_503739895319_item	2664712	et	3	main
kultuuri	doc_503739895319_item	2664713	et	4	main
tsensuuri	doc_503739895319_item	2664714	et	4	main
tase	doc_503739895319_item	2664715	et	3	main
nõrgenemine	doc_503739895319_item	2664716	et	4	main
lubatud	doc_503739895319_item	2664717	et	4	main
kritiseerida	doc_503739895319_item	2664718	et	3	main
stalinismi	doc_503739895319_item	2664719	et	4	main
võimalus	doc_503739895319_item	2664720	et	3	main
tutvuda	doc_503739895319_item	2664721	et	3	main
olid	doc_503739895319_item	2664727	et	4	main
keeldureast	doc_503739895319_item	2664728	et	4	main
pandud	doc_503739895319_item	2664733	et	4	main
jne	doc_503739895319_item	2664740	et	4	main
bändid	doc_503739895319_item	2664750	et	4	main
laiem	doc_503739895319_item	2664766	et	4	main
valik	doc_503739895319_item	2664767	et	3	main
hariduse	doc_503739895319_item	2664768	et	3	main
tase	doc_503739895319_item	2664769	et	3	main
vastanud	doc_503739895319_item	2664774	et	4	main
nõud	doc_503739895319_item	2664775	et	3	main
novelli	doc_503739895319_item	2664780	et	4	main
poole	doc_503739895319_item	2664817	et	4	main
peab	doc_503739895319_item	2664823	et	4	main
vahend	doc_503739895319_item	2664827	et	3	main
hoogu	doc_503739895319_item	2664840	et	4	main
mõtlema	doc_503739895319_item	2664845	et	3	main
võitlema	doc_503739895319_item	2664847	et	3	main
mitte	doc_503739895319_item	2664851	et	3	main
tee	doc_503739895319_item	2664854	et	4	main
inimest	doc_503739895319_item	2664855	et	3	main
kahte	doc_503739895319_item	2664865	et	4	main
rohkem	doc_503739895319_item	2664871	et	4	main
nõukogude	doc_503739895319_item	2664884	et	3	main
1947	doc_503739895319_item	2664888	et	2	main
rohkem	doc_503739895319_item	2664900	et	4	main
stotsiumi	doc_503739895319_item	2664904	et	4	main
probleemi	doc_503739895319_item	2664906	et	4	main
kõik	doc_503739895319_item	2664907	et	4	main
poole	doc_503739895319_item	2664912	et	4	main
zveždotška	doc_503739895319_item	2664698	et	2	main
lubatud	doc_503739895319_item	2664722	et	4	main
kirjandusteostega	doc_503739895319_item	2664724	et	3	main
mõned	doc_503739895319_item	2664725	et	3	main
nt	doc_503739895319_item	2664731	et	4	main
ühingutele	doc_503739895319_item	2664736	et	3	main
eesti	doc_503739895319_item	2664737	et	4	main
elustasid	doc_503739895319_item	2664742	et	4	main
rahva	doc_503739895319_item	2664743	et	3	main
traditsioone	doc_503739895319_item	2664744	et	3	main
soome-ugri	doc_503739895319_item	2664745	et	3	main
hakkasid	doc_503739895319_item	2664748	et	4	main
tegutsema	doc_503739895319_item	2664749	et	3	main
kukerpillid	doc_503739895319_item	2664751	et	3	main
esimene	doc_503739895319_item	2664752	et	3	main
prof	doc_503739895319_item	2664753	et	4	main
bänd	doc_503739895319_item	2664754	et	3	main
politiseeritud	doc_503739895319_item	2664758	et	4	main
kõrg	doc_503739895319_item	2664770	et	4	main
hinnad	doc_503739895319_item	2664810	et	3	main
100	doc_503739895319_item	2664812	et	2	main
eurot	doc_503739895319_item	2664813	et	3	main
plakati	doc_503739895319_item	2664814	et	3	main
eesti	doc_503739895319_item	2664815	et	4	main
kuni	doc_503739895319_item	2664816	et	3	main
kultuur	doc_503739895319_item	2664822	et	3	main
kokkutulek	doc_503739895319_item	2664834	et	3	main
igatahes	doc_503739895319_item	2664835	et	3	main
kultuur	doc_503739895319_item	2664836	et	3	main
oli	doc_503739895319_item	2664837	et	3	main
saanud	doc_503739895319_item	2664838	et	4	main
uut	doc_503739895319_item	2664839	et	3	main
inimesi	doc_503739895319_item	2664844	et	4	main
vabaduse	doc_503739895319_item	2664849	et	4	main
miski	doc_503739895319_item	2664852	et	4	main
ei	doc_503739895319_item	2664853	et	4	main
moodi	doc_503739895319_item	2664866	et	4	main
see	doc_503739895319_item	2664869	et	3	main
libahundiks	doc_503739895319_item	2664879	et	3	main
ja	doc_503739895319_item	2664880	et	3	main
kõik	doc_503739895319_item	2664881	et	4	main
seda	doc_503739895319_item	2664882	et	3	main
usuvad	doc_503739895319_item	2664883	et	3	main
keegi	doc_503739895319_item	2664889	et	4	main
midagi	doc_503739895319_item	2664890	et	4	main
teab	doc_503739895319_item	2664891	et	3	main
naabrist	doc_503739895319_item	2664892	et	3	main
ja	doc_503739895319_item	2664893	et	3	main
piinlik	doc_503739895319_item	2664901	et	3	main
pööravad	doc_503739895319_item	2664909	et	4	main
see	doc_503739895319_item	2664921	et	3	main
ilmuda	doc_503739895319_item	2664944	et	3	main
viisil	doc_503739895319_item	2664946	et	4	main
eilne	doc_503739895319_item	2664953	et	3	main
on	doc_503739895319_item	2664956	et	4	main
kõik	doc_503739895319_item	2664957	et	4	main
ühiskonda	doc_503739895319_item	2664972	et	4	main
keegi	doc_503739895319_item	2664974	et	4	main
nii	doc_503739895319_item	2664981	et	3	main
filmi	doc_503739895319_item	2664985	et	4	main
ei	doc_503739895319_item	2664995	et	4	main
kuju	doc_503739895319_item	2665003	et	4	main
pärast	doc_503739895319_item	2665007	et	4	main
1970ndatel	doc_503739895320_item	2665030	et	4	main
nsvl	doc_503739895320_item	2665036	et	4	main
lähisvälismaana	doc_503739895320_item	2665037	et	3	main
2	doc_503739895320_item	2665038	et	2	main
l	doc_503739895320_item	2665039	et	4	main
ajaloodokument	doc_503739895320_item	2665046	et	3	main
järelmaksuga	doc_503739895320_item	2665057	et	3	main
kulmkapid	doc_503739895320_item	2665060	et	4	main
näiliselt	doc_503739895320_item	2665061	et	4	main
heaolu	doc_503739895320_item	2665065	et	4	main
hakati	doc_503739895320_item	2665067	et	3	main
sellele	doc_503739895320_item	2665096	et	4	main
ka	doc_503739895320_item	2665098	et	3	main
tegutses	doc_503739895320_item	2665102	et	3	main
ots	doc_503739895320_item	2665108	et	3	main
saadi	doc_503739895320_item	2665110	et	4	main
väljavahetamise	doc_503739895320_item	2665111	et	3	main
teel	doc_503739895320_item	2665112	et	4	main
välja	doc_503739895319_item	2664730	et	4	main
professionaalsetele	doc_503739895319_item	2664735	et	4	main
rahva	doc_503739895319_item	2664746	et	3	main
olid	doc_503739895319_item	2664756	et	4	main
rohkem	doc_503739895319_item	2664757	et	4	main
vähem	doc_503739895319_item	2664761	et	4	main
avatud	doc_503739895319_item	2664763	et	4	main
rohkem	doc_503739895319_item	2664764	et	4	main
raamatukogusi	doc_503739895319_item	2664765	et	3	main
ei	doc_503739895319_item	2664773	et	4	main
huvi	doc_503739895319_item	2664777	et	4	main
ja	doc_503739895319_item	2664779	et	3	main
vastu	doc_503739895319_item	2664781	et	3	main
hakkab	doc_503739895319_item	2664782	et	3	main
kerkima	doc_503739895319_item	2664783	et	3	main
avangardism	doc_503739895319_item	2664784	et	3	main
ühine	doc_503739895319_item	2664785	et	4	main
tegevussuund	doc_503739895319_item	2664786	et	3	main
sotsrealism	doc_503739895319_item	2664787	et	3	main
tänapäeval	doc_503739895319_item	2664788	et	3	main
saksamaa	doc_503739895319_item	2664789	et	4	main
oksjonid	doc_503739895319_item	2664790	et	3	main
tunnevad	doc_503739895319_item	2664791	et	3	main
eriti	doc_503739895319_item	2664792	et	3	main
huvi	doc_503739895319_item	2664793	et	4	main
sotsrealismi	doc_503739895319_item	2664794	et	4	main
maalide	doc_503739895319_item	2664795	et	3	main
vastu	doc_503739895319_item	2664796	et	3	main
hinnad	doc_503739895319_item	2664797	et	3	main
on	doc_503739895319_item	2664798	et	4	main
erinevad	doc_503739895319_item	2664799	et	4	main
ja	doc_503739895319_item	2664800	et	3	main
seetõttu	doc_503739895319_item	2664801	et	3	main
igaüks	doc_503739895319_item	2664802	et	3	main
arvestades	doc_503739895319_item	2664803	et	3	main
oma	doc_503739895319_item	2664804	et	4	main
võimalustega	doc_503739895319_item	2664805	et	3	main
võib	doc_503739895319_item	2664806	et	3	main
luua	doc_503739895319_item	2664807	et	4	main
oma	doc_503739895319_item	2664808	et	4	main
kollektsiooni	doc_503739895319_item	2664809	et	4	main
parteisekretäride	doc_503739895319_item	2664820	et	3	main
natsionaalne	doc_503739895319_item	2664828	et	3	main
oma	doc_503739895319_item	2664848	et	4	main
ühenenud	doc_503739895319_item	2664857	et	4	main
kui	doc_503739895319_item	2664858	et	3	main
ühine	doc_503739895319_item	2664859	et	4	main
kultuur	doc_503739895319_item	2664860	et	3	main
minu	doc_503739895319_item	2664867	et	3	main
teist	doc_503739895319_item	2664878	et	4	main
sama	doc_503739895319_item	2664886	et	4	main
lihtsalt	doc_503739895319_item	2664908	et	4	main
sotsialismi	doc_503739895319_item	2664916	et	4	main
vaenlast	doc_503739895319_item	2664917	et	3	main
oled	doc_503739895319_item	2664918	et	3	main
riigi	doc_503739895319_item	2664919	et	3	main
vaenlane	doc_503739895319_item	2664920	et	3	main
meelest	doc_503739895319_item	2664931	et	4	main
siin	doc_503739895319_item	2664932	et	4	main
mis	doc_503739895319_item	2664937	et	4	main
omajärel	doc_503739895319_item	2664938	et	3	main
tekistabki	doc_503739895319_item	2664939	et	4	main
ühiskonnakriitikat	doc_503739895319_item	2664940	et	3	main
mitmel	doc_503739895319_item	2664945	et	4	main
lihtsam	doc_503739895319_item	2664958	et	4	main
tõestamatu	doc_503739895319_item	2664967	et	4	main
häirib	doc_503739895319_item	2664971	et	3	main
see	doc_503739895319_item	2664979	et	3	main
just	doc_503739895319_item	2664980	et	3	main
miski	doc_503739895319_item	2664994	et	4	main
oma	doc_503739895319_item	2665002	et	4	main
neile	doc_503739895319_item	2665020	et	4	main
kabinetidest	doc_503739895319_item	2664821	et	3	main
kp	doc_503739895319_item	2664833	et	4	main
edasi	doc_503739895319_item	2664842	et	3	main
pani	doc_503739895319_item	2664843	et	4	main
ja	doc_503739895319_item	2664846	et	3	main
eest	doc_503739895319_item	2664850	et	4	main
2	doc_503739895319_item	2664861	et	2	main
seda	doc_503739895319_item	2664862	et	3	main
võib	doc_503739895319_item	2664863	et	3	main
käsitleda	doc_503739895319_item	2664864	et	3	main
meelest	doc_503739895319_item	2664868	et	4	main
on	doc_503739895319_item	2664870	et	4	main
ühiskonnakriitika	doc_503739895319_item	2664872	et	4	main
lihtne	doc_503739895319_item	2664873	et	3	main
paralleel	doc_503739895319_item	2664874	et	3	main
süžeest	doc_503739895319_item	2664875	et	2	main
liit	doc_503739895319_item	2664885	et	3	main
värk	doc_503739895319_item	2664887	et	3	main
külla	doc_503739895319_item	2664897	et	4	main
aga	doc_503739895319_item	2664898	et	3	main
kõige	doc_503739895319_item	2664899	et	4	main
mõlemas	doc_503739895319_item	2664903	et	3	main
nägu	doc_503739895319_item	2664910	et	4	main
seina	doc_503739895319_item	2664911	et	4	main
pole	doc_503739895319_item	2664923	et	3	main
pooldaja	doc_503739895319_item	2664925	et	4	main
on	doc_503739895319_item	2664926	et	4	main
järelikult	doc_503739895319_item	2664927	et	3	main
ka	doc_503739895319_item	2664928	et	3	main
vaenlane	doc_503739895319_item	2664929	et	3	main
minu	doc_503739895319_item	2664930	et	3	main
puudumine	doc_503739895319_item	2664936	et	4	main
kriitika	doc_503739895319_item	2664942	et	4	main
see	doc_503739895319_item	2664948	et	3	main
minevik	doc_503739895319_item	2664951	et	3	main
päev	doc_503739895319_item	2664954	et	3	main
suunatakse	doc_503739895319_item	2664962	et	4	main
õigesti	doc_503739895319_item	2664963	et	3	main
ja	doc_503739895319_item	2664964	et	3	main
tekib	doc_503739895319_item	2664965	et	3	main
mingi	doc_503739895319_item	2664966	et	4	main
mis	doc_503739895319_item	2664970	et	4	main
on	doc_503739895319_item	2664978	et	4	main
hindan	doc_503739895319_item	2664983	et	3	main
peegeldust	doc_503739895319_item	2664989	et	4	main
teki	doc_503739895319_item	2664996	et	4	main
ega	doc_503739895319_item	2664997	et	3	main
ei	doc_503739895319_item	2664998	et	4	main
juba	doc_503739895319_item	2665013	et	3	main
režiim	doc_503739895319_item	2665015	et	2	main
ja	doc_503739895319_item	2665016	et	3	main
muidugi	doc_503739895319_item	2665017	et	4	main
teeb	doc_503739895319_item	2665018	et	3	main
lõpu	doc_503739895319_item	2665019	et	3	main
põhjust	doc_503739895320_item	2665031	et	4	main
teie	doc_503739895320_item	2665044	et	4	main
vaibad	doc_503739895320_item	2665059	et	3	main
majanduslik	doc_503739895320_item	2665064	et	3	main
massiliselt	doc_503739895320_item	2665066	et	4	main
ehitama	doc_503739895320_item	2665068	et	4	main
individuaalmaju	doc_503739895320_item	2665069	et	3	main
kuna	doc_503739895320_item	2665070	et	3	main
soome	doc_503739895320_item	2665099	et	3	main
georg	doc_503739895320_item	2665107	et	4	main
turistidelt	doc_503739895320_item	2665109	et	3	main
kaupa	doc_503739895320_item	2665114	et	4	main
rahvakunsti	doc_503739895320_item	2665124	et	4	main
eesti	doc_503739895320_item	2665134	et	4	main
lapstähtede	doc_503739895320_item	2665141	et	4	main
takti	doc_503739895320_item	2665147	et	4	main
taunitav	doc_503739895320_item	2665156	et	4	main
ilmus	doc_503739895320_item	2665169	et	4	main
osa	doc_503739895320_item	2665182	et	4	main
saade	doc_503739895320_item	2665190	et	4	main
horoskoop	doc_503739895320_item	2665191	et	3	main
enammeeldinud	doc_503739895320_item	2665193	et	3	main
esimene	doc_503739895320_item	2665201	et	3	main
interaktiivne	doc_503739895320_item	2665202	et	3	main
ka	doc_503739895320_item	2665206	et	3	main
t	doc_503739895320_item	2665210	et	4	main
eid	doc_503739895320_item	2665211	et	4	main
nagu	doc_503739895320_item	2665212	et	3	main
igasugused	doc_503739895320_item	2665213	et	3	main
telekoolid	doc_503739895320_item	2665214	et	3	main
näidati	doc_503739895320_item	2665215	et	3	main
kui	doc_503739895319_item	2664913	et	3	main
sa	doc_503739895319_item	2664914	et	3	main
pooldad	doc_503739895319_item	2664915	et	3	main
sotsialismi	doc_503739895319_item	2664924	et	4	main
võib	doc_503739895319_item	2664943	et	3	main
libahunt	doc_503739895319_item	2664947	et	3	main
ebakompetentne	doc_503739895319_item	2664959	et	3	main
meie	doc_503739895319_item	2664960	et	4	main
faktidega	doc_503739895319_item	2664968	et	3	main
ei	doc_503739895319_item	2664975	et	4	main
mina	doc_503739895319_item	2664982	et	4	main
seda	doc_503739895319_item	2664984	et	3	main
nagu	doc_503739895319_item	2664986	et	3	main
režiimi	doc_503739895319_item	2664988	et	2	main
või	doc_503739895319_item	2664990	et	4	main
ennem	doc_503739895319_item	2665004	et	4	main
libahundi	doc_503739895319_item	2665005	et	3	main
seesama	doc_503739895319_item	2665009	et	3	main
libahunti	doc_503739895319_item	2665011	et	4	main
valitsev	doc_503739895319_item	2665014	et	4	main
ka	doc_503739895319_item	2665021	et	3	main
1	doc_503739895320_item	2665025	et	2	main
eesti	doc_503739895320_item	2665032	et	4	main
laiuse	doc_503739895320_item	2665040	et	4	main
mängufilm	doc_503739895320_item	2665041	et	3	main
libahunt	doc_503739895320_item	2665042	et	3	main
osatu	doc_503739895320_item	2665056	et	4	main
autod	doc_503739895320_item	2665058	et	3	main
õpiti	doc_503739895320_item	2665097	et	3	main
aktiivselt	doc_503739895320_item	2665101	et	4	main
laevaliin	doc_503739895320_item	2665106	et	3	main
kangaid	doc_503739895320_item	2665115	et	3	main
tegutses	doc_503739895320_item	2665122	et	3	main
selt	doc_503739895320_item	2665125	et	3	main
kelle	doc_503739895320_item	2665126	et	4	main
looming	doc_503739895320_item	2665127	et	3	main
läks	doc_503739895320_item	2665128	et	3	main
televisioonis	doc_503739895320_item	2665135	et	4	main
esinemine	doc_503739895320_item	2665142	et	4	main
ette	doc_503739895320_item	2665148	et	4	main
nsv	doc_503739895320_item	2665157	et	4	main
eesti	doc_503739895320_item	2665172	et	4	main
tuli	doc_503739895320_item	2665174	et	4	main
ainulaadne	doc_503739895320_item	2665188	et	3	main
inimesi	doc_503739895320_item	2665207	et	4	main
saa	doc_503739895320_item	2665209	et	4	main
kes	doc_503739895319_item	2664922	et	4	main
mõjus	doc_503739895319_item	2664933	et	4	main
julgeoleku	doc_503739895319_item	2664934	et	3	main
tunne	doc_503739895319_item	2664935	et	4	main
ühiskonna	doc_503739895319_item	2664941	et	4	main
oli	doc_503739895319_item	2664949	et	3	main
kauge	doc_503739895319_item	2664950	et	4	main
kosmopolit	doc_503739895319_item	2664952	et	4	main
tänapäeval	doc_503739895319_item	2664955	et	3	main
ühiskonda	doc_503739895319_item	2664961	et	4	main
kartmine	doc_503739895319_item	2664969	et	4	main
ja	doc_503739895319_item	2664973	et	3	main
märka	doc_503739895319_item	2664976	et	4	main
miks	doc_503739895319_item	2664977	et	4	main
nsv	doc_503739895319_item	2664987	et	4	main
lihtsalt	doc_503739895319_item	2664991	et	4	main
korduvat	doc_503739895319_item	2664992	et	4	main
mitte	doc_503739895319_item	2664993	et	3	main
kao	doc_503739895319_item	2664999	et	4	main
vaid	doc_503739895319_item	2665000	et	3	main
muudab	doc_503739895319_item	2665001	et	3	main
kartmine	doc_503739895319_item	2665006	et	4	main
juba	doc_503739895319_item	2665008	et	3	main
aga	doc_503739895319_item	2665010	et	3	main
valib	doc_503739895319_item	2665012	et	3	main
sama	doc_503739895319_item	2665023	et	4	main
majanduslikud-kultuurilised	doc_503739895320_item	2665027	et	4	main
tegurid	doc_503739895320_item	2665028	et	3	main
andsid	doc_503739895320_item	2665029	et	4	main
tunda	doc_503739895320_item	2665034	et	3	main
end	doc_503739895320_item	2665035	et	4	main
arvates	doc_503739895320_item	2665045	et	4	main
ühiskonnakriitika	doc_503739895320_item	2665048	et	4	main
1	doc_503739895320_item	2665050	et	2	main
majanduslikud	doc_503739895320_item	2665051	et	3	main
tegurid	doc_503739895320_item	2665052	et	3	main
paljusid	doc_503739895320_item	2665053	et	3	main
kaupu	doc_503739895320_item	2665054	et	3	main
sai	doc_503739895320_item	2665055	et	4	main
inimeste	doc_503739895320_item	2665063	et	3	main
laiem	doc_503739895320_item	2665094	et	4	main
tanu	doc_503739895320_item	2665095	et	4	main
keelt	doc_503739895320_item	2665100	et	4	main
tallinn-helsinki	doc_503739895320_item	2665103	et	4	main
praami-	doc_503739895320_item	2665104	et	4	main
ja	doc_503739895320_item	2665105	et	3	main
eriti	doc_503739895320_item	2665116	et	3	main
viru	doc_503739895320_item	2665119	et	4	main
see	doc_503739895319_item	2665022	et	3	main
kontrolltöö	doc_503739895320_item	2665024	et	4	main
missugused	doc_503739895320_item	2665026	et	3	main
nsvl	doc_503739895320_item	2665033	et	4	main
kas	doc_503739895320_item	2665043	et	3	main
või	doc_503739895320_item	2665047	et	4	main
miks	doc_503739895320_item	2665049	et	4	main
paranes	doc_503739895320_item	2665062	et	3	main
korterit	doc_503739895320_item	2665071	et	3	main
ei	doc_503739895320_item	2665072	et	4	main
jõutud	doc_503739895320_item	2665073	et	4	main
järjekorras	doc_503739895320_item	2665074	et	3	main
oodata	doc_503739895320_item	2665075	et	4	main
vaadeti	doc_503739895320_item	2665076	et	4	main
soome	doc_503739895320_item	2665077	et	3	main
tekevisiooni	doc_503739895320_item	2665078	et	4	main
kust	doc_503739895320_item	2665079	et	4	main
levis	doc_503739895320_item	2665080	et	4	main
läänelik	doc_503739895320_item	2665081	et	4	main
riietusmood	doc_503739895320_item	2665082	et	3	main
mõtteviis	doc_503739895320_item	2665083	et	3	main
lääne	doc_503739895320_item	2665084	et	4	main
uudised	doc_503739895320_item	2665085	et	3	main
filmid	doc_503739895320_item	2665086	et	4	main
saadet	doc_503739895320_item	2665087	et	3	main
inimeste	doc_503739895320_item	2665088	et	3	main
maailma	doc_503739895320_item	2665089	et	4	main
tunnetamine	doc_503739895320_item	2665090	et	4	main
ja	doc_503739895320_item	2665091	et	3	main
silmaring	doc_503739895320_item	2665092	et	3	main
oli	doc_503739895320_item	2665093	et	3	main
välismaist	doc_503739895320_item	2665113	et	4	main
aktiivselt	doc_503739895320_item	2665117	et	4	main
kaubeldi	doc_503739895320_item	2665118	et	3	main
hotelli	doc_503739895320_item	2665120	et	4	main
peamiselt	doc_503739895320_item	2665129	et	4	main
etv	doc_503739895320_item	2665136	et	4	main
oli	doc_503739895320_item	2665137	et	3	main
laste	doc_503739895320_item	2665143	et	4	main
mis	doc_503739895320_item	2665149	et	4	main
oli	doc_503739895320_item	2665150	et	3	main
väga	doc_503739895320_item	2665151	et	3	main
uudne	doc_503739895320_item	2665152	et	3	main
ning	doc_503739895320_item	2665153	et	3	main
aastal	doc_503739895320_item	2665168	et	3	main
esimene	doc_503739895320_item	2665170	et	3	main
keelde	doc_503739895320_item	2665173	et	4	main
sõna	doc_503739895320_item	2665176	et	4	main
mälumäng	doc_503739895320_item	2665177	et	3	main
vaadati	doc_503739895320_item	2665178	et	3	main
ja	doc_503739895320_item	2665179	et	3	main
võeti	doc_503739895320_item	2665180	et	3	main
aktiivselt	doc_503739895320_item	2665181	et	4	main
eest	doc_503739895320_item	2665195	et	4	main
sai	doc_503739895320_item	2665196	et	4	main
haaletada	doc_503739895320_item	2665197	et	4	main
sarjast	doc_503739895320_item	2665229	et	4	main
loeti	doc_503739895320_item	2665239	et	3	main
raamatuid	doc_503739895320_item	2665244	et	3	main
leiesi	doc_503739895320_item	2665251	et	4	main
saated	doc_503739895320_item	2665252	et	3	main
ja	doc_503739895320_item	2665254	et	3	main
jt	doc_503739895320_item	2665256	et	4	main
kaljo	doc_503739895320_item	2665273	et	4	main
ja	doc_503739895320_item	2665278	et	3	main
peremees	doc_503739895320_item	2665280	et	4	main
liidus	doc_503739895320_item	2665291	et	4	main
loeti	doc_503739895320_item	2665292	et	3	main
lemmikuteks	doc_503739895320_item	2665302	et	4	main
kross	doc_503739895320_item	2665307	et	3	main
saa	doc_503739895320_item	2665316	et	4	main
oli	doc_503739895320_item	2665321	et	3	main
või	doc_503739895320_item	2665324	et	4	main
ühiskonnakriitika	doc_503739895320_item	2665327	et	4	main
kõik	doc_503739895320_item	2665336	et	4	main
eranditult	doc_503739895320_item	2665337	et	4	main
ja	doc_503739895320_item	2665348	et	3	main
saj	doc_503739895320_item	2665352	et	4	main
inimeste	doc_503739895320_item	2665353	et	3	main
riietust	doc_503739895320_item	2665354	et	4	main
filmis	doc_503739895320_item	2665363	et	4	main
ärakasutatud	doc_503739895320_item	2665364	et	4	main
kõla	doc_503739895320_item	2665367	et	4	main
vaba	doc_503739895320_item	2665421	et	4	main
jääda	doc_503739895320_item	2665424	et	4	main
iseendaks	doc_503739895320_item	2665425	et	3	main
kuidagi	doc_503739895320_item	2665427	et	3	main
kooskõlas	doc_503739895320_item	2665428	et	3	main
sotsialistliku	doc_503739895320_item	2665429	et	3	main
realismi	doc_503739895320_item	2665430	et	4	main
nägemusega	doc_503739895320_item	2665431	et	3	main
inimesest	doc_503739895320_item	2665432	et	3	main
inimese	doc_503739895320_item	2665433	et	4	main
püüd	doc_503739895320_item	2665434	et	4	main
vastanduda	doc_503739895320_item	2665435	et	3	main
ennast	doc_503739895320_item	2665436	et	4	main
ühiskonna	doc_503739895320_item	2665444	et	4	main
1	doc_503739895321_item	2665449	et	2	main
1	doc_503739895321_item	2665458	et	2	main
juba	doc_503739895321_item	2665467	et	3	main
poole	doc_503739895321_item	2665480	et	4	main
ole	doc_503739895321_item	2665486	et	4	main
avastatud	doc_503739895321_item	2665488	et	4	main
neid	doc_503739895321_item	2665489	et	4	main
suhteliselt	doc_503739895321_item	2665496	et	4	main
aga	doc_503739895321_item	2665499	et	3	main
juures	doc_503739895321_item	2665502	et	4	main
tööriiste	doc_503739895321_item	2665505	et	3	main
taandudes	doc_503739895321_item	2665507	et	3	main
liikusid	doc_503739895321_item	2665508	et	4	main
püüdsid	doc_503739895321_item	2665515	et	4	main
nad	doc_503739895321_item	2665518	et	3	main
suviniiridena	doc_503739895320_item	2665130	et	4	main
margata	doc_503739895320_item	2665138	et	3	main
läänelikku	doc_503739895320_item	2665139	et	4	main
laulukonkurssedel	doc_503739895320_item	2665144	et	4	main
entel-tentel	doc_503739895320_item	2665145	et	4	main
kaks	doc_503739895320_item	2665146	et	3	main
algul	doc_503739895320_item	2665154	et	4	main
isegi	doc_503739895320_item	2665155	et	4	main
liidus	doc_503739895320_item	2665158	et	4	main
eesti	doc_503739895320_item	2665159	et	4	main
teleekraanidel	doc_503739895320_item	2665160	et	3	main
ilmus	doc_503739895320_item	2665161	et	4	main
esimene	doc_503739895320_item	2665162	et	3	main
reklaam	doc_503739895320_item	2665163	et	3	main
tegutses	doc_503739895320_item	2665164	et	3	main
eesti	doc_503739895320_item	2665165	et	4	main
raklaamfilm	doc_503739895320_item	2665166	et	4	main
1973	doc_503739895320_item	2665167	et	2	main
juures	doc_503739895320_item	2665121	et	4	main
uku	doc_503739895320_item	2665123	et	4	main
läände	doc_503739895320_item	2665131	et	3	main
kultuurilised	doc_503739895320_item	2665132	et	4	main
tegurid	doc_503739895320_item	2665133	et	3	main
kultuuri	doc_503739895320_item	2665140	et	4	main
koomiksiraamat	doc_503739895320_item	2665171	et	3	main
samanimelistest	doc_503739895320_item	2665183	et	4	main
saadetest	doc_503739895320_item	2665184	et	3	main
eriti	doc_503739895320_item	2665185	et	3	main
populaarne	doc_503739895320_item	2665186	et	3	main
ja	doc_503739895320_item	2665187	et	3	main
saates	doc_503739895320_item	2665198	et	4	main
stuudiosse	doc_503739895320_item	2665199	et	3	main
postkaarti	doc_503739895320_item	2665200	et	4	main
mäng	doc_503739895320_item	2665203	et	3	main
harivaid	doc_503739895320_item	2665208	et	4	main
ii	doc_503739895320_item	2665224	et	4	main
kajastav	doc_503739895320_item	2665227	et	4	main
panti	doc_503739895320_item	2665232	et	4	main
saadete	doc_503739895320_item	2665233	et	3	main
tsükkel	doc_503739895320_item	2665234	et	3	main
täna	doc_503739895320_item	2665235	et	4	main
25	doc_503739895320_item	2665236	et	2	main
aastat	doc_503739895320_item	2665237	et	3	main
tagasi	doc_503739895320_item	2665238	et	3	main
ajalehti	doc_503739895320_item	2665242	et	4	main
lastele	doc_503739895320_item	2665247	et	4	main
olid	doc_503739895320_item	2665248	et	4	main
tipp	doc_503739895320_item	2665253	et	3	main
komissarov	doc_503739895320_item	2665274	et	4	main
leida	doc_503739895320_item	2665275	et	3	main
ideedega	doc_503739895320_item	2665287	et	3	main
proosale	doc_503739895320_item	2665298	et	3	main
troot	doc_503739895320_item	2665305	et	4	main
j	doc_503739895320_item	2665306	et	4	main
väita	doc_503739895320_item	2665317	et	4	main
mis	doc_503739895320_item	2665338	et	4	main
filmis	doc_503739895320_item	2665345	et	4	main
on	doc_503739895320_item	2665346	et	4	main
näidatud	doc_503739895320_item	2665350	et	4	main
kombeid	doc_503739895320_item	2665355	et	4	main
aga	doc_503739895320_item	2665356	et	3	main
ka	doc_503739895320_item	2665357	et	3	main
mina	doc_503739895320_item	2665373	et	4	main
vaadates	doc_503739895320_item	2665374	et	3	main
seda	doc_503739895320_item	2665375	et	3	main
filmi	doc_503739895320_item	2665376	et	4	main
jälgisin	doc_503739895320_item	2665377	et	3	main
pigem	doc_503739895320_item	2665378	et	3	main
silmaga	doc_503739895320_item	2665379	et	3	main
ainult	doc_503739895320_item	2665385	et	4	main
uus	doc_503739895320_item	2665175	et	3	main
oli	doc_503739895320_item	2665189	et	3	main
kus	doc_503739895320_item	2665192	et	3	main
laulu	doc_503739895320_item	2665194	et	4	main
hakati	doc_503739895320_item	2665204	et	3	main
produteerima	doc_503739895320_item	2665205	et	4	main
seebikad	doc_503739895320_item	2665219	et	4	main
üsna	doc_503739895320_item	2665220	et	3	main
uudne	doc_503739895320_item	2665221	et	3	main
koosnev	doc_503739895320_item	2665230	et	4	main
väga	doc_503739895320_item	2665240	et	3	main
ja	doc_503739895320_item	2665243	et	3	main
uno	doc_503739895320_item	2665250	et	4	main
tegijad	doc_503739895320_item	2665268	et	4	main
laius	doc_503739895320_item	2665276	et	4	main
viljelejad	doc_503739895320_item	2665283	et	4	main
väga	doc_503739895320_item	2665285	et	3	main
keskendus	doc_503739895320_item	2665296	et	4	main
aga	doc_503739895320_item	2665297	et	3	main
tolle	doc_503739895320_item	2665300	et	4	main
aja	doc_503739895320_item	2665301	et	4	main
eesti	doc_503739895320_item	2665308	et	4	main
disidentide	doc_503739895320_item	2665309	et	4	main
aktiivne	doc_503739895320_item	2665310	et	3	main
kindlalt	doc_503739895320_item	2665318	et	4	main
kas	doc_503739895320_item	2665319	et	3	main
suhtumist	doc_503739895320_item	2665358	et	4	main
hoiakuid	doc_503739895320_item	2665359	et	3	main
ja	doc_503739895320_item	2665360	et	3	main
hirme	doc_503739895320_item	2665361	et	3	main
vanaaegsete	doc_503739895320_item	2665365	et	4	main
filmile	doc_503739895320_item	2665369	et	3	main
müstilise	doc_503739895320_item	2665371	et	3	main
poolt	doc_503739895320_item	2665381	et	4	main
kostüüme	doc_503739895320_item	2665382	et	3	main
ning	doc_503739895320_item	2665422	et	3	main
soov	doc_503739895320_item	2665423	et	3	main
lausa	doc_503739895320_item	2665446	et	4	main
algus	doc_503739895321_item	2665461	et	4	main
selle	doc_503739895321_item	2665470	et	4	main
ajajargu	doc_503739895321_item	2665471	et	4	main
leiumaterjal	doc_503739895321_item	2665473	et	3	main
näitab	doc_503739895321_item	2665474	et	3	main
et	doc_503739895321_item	2665475	et	3	main
kuuluvad	doc_503739895321_item	2665482	et	4	main
põhjapõdraküttide	doc_503739895321_item	2665483	et	3	main
peatuspaiku	doc_503739895321_item	2665484	et	3	main
ei	doc_503739895321_item	2665485	et	4	main
inimesed	doc_503739895321_item	2665494	et	3	main
põllu	doc_503739895321_item	2665501	et	3	main
põhjapõder	doc_503739895321_item	2665521	et	3	main
oli	doc_503739895321_item	2665526	et	3	main
sarvi	doc_503739895321_item	2665534	et	4	main
tarberiistade	doc_503739895321_item	2665535	et	3	main
loodusolude	doc_503739895321_item	2665542	et	3	main
paremini	doc_503739895321_item	2665551	et	4	main
nii	doc_503739895321_item	2665558	et	3	main
asulates	doc_503739895321_item	2665570	et	4	main
paiknesid	doc_503739895321_item	2665572	et	4	main
jõgede	doc_503739895321_item	2665573	et	3	main
elati	doc_503739895321_item	2665578	et	3	main
nahkade	doc_503739895321_item	2665588	et	3	main
rolli	doc_503739895321_item	2665623	et	4	main
ahing	doc_503739895321_item	2665628	et	3	main
metsloomi	doc_503739895321_item	2665638	et	4	main
kütiti	doc_503739895321_item	2665641	et	3	main
nii	doc_503739895321_item	2665642	et	3	main
vibu	doc_503739895321_item	2665646	et	4	main
ja	doc_503739895321_item	2665647	et	3	main
nooltega	doc_503739895321_item	2665648	et	3	main
riistad	doc_503739895321_item	2665649	et	3	main
tehti	doc_503739895321_item	2665650	et	3	main
pähklite	doc_503739895321_item	2665663	et	3	main
saagimine	doc_503739895321_item	2665682	et	4	main
meieni	doc_503739895321_item	2665688	et	4	main
soome-ugri	doc_503739895321_item	2665689	et	3	main
on	doc_503739895321_item	2665693	et	4	main
kammi	doc_503739895321_item	2665699	et	4	main
sarnaneva	doc_503739895321_item	2665701	et	4	main
nöörkeraamika	doc_503739895321_item	2665703	et	4	main
paati	doc_503739895321_item	2665704	et	4	main
ka	doc_503739895320_item	2665216	et	3	main
tõsielusarju	doc_503739895320_item	2665217	et	3	main
tänapäeva	doc_503739895320_item	2665218	et	4	main
ms	doc_503739895320_item	2665225	et	4	main
veldo	doc_503739895320_item	2665231	et	4	main
mõeldud	doc_503739895320_item	2665249	et	4	main
uued	doc_503739895320_item	2665267	et	3	main
nagu	doc_503739895320_item	2665269	et	3	main
kaljo	doc_503739895320_item	2665270	et	4	main
kiisk	doc_503739895320_item	2665271	et	3	main
ja	doc_503739895320_item	2665272	et	3	main
libahunt	doc_503739895320_item	2665277	et	3	main
need	doc_503739895320_item	2665281	et	3	main
novaatorlikku	doc_503739895320_item	2665286	et	4	main
kogu	doc_503739895320_item	2665289	et	4	main
eriti	doc_503739895320_item	2665299	et	3	main
ei	doc_503739895320_item	2665315	et	4	main
ajaloodokument	doc_503739895320_item	2665323	et	3	main
siis	doc_503739895320_item	2665325	et	3	main
puhas	doc_503739895320_item	2665326	et	3	main
mõtlen	doc_503739895320_item	2665329	et	3	main
kindlasti	doc_503739895320_item	2665331	et	3	main
kuuluvad	doc_503739895320_item	2665332	et	4	main
tolle	doc_503739895320_item	2665333	et	4	main
aja	doc_503739895320_item	2665334	et	4	main
filmid	doc_503739895320_item	2665335	et	4	main
vähegi	doc_503739895320_item	2665339	et	4	main
poliitilisest	doc_503739895320_item	2665340	et	3	main
propagandast	doc_503739895320_item	2665341	et	4	main
vabad	doc_503739895320_item	2665342	et	3	main
ajaloodokumentide	doc_503739895320_item	2665343	et	3	main
oskuslikult	doc_503739895320_item	2665347	et	4	main
16	doc_503739895320_item	2665351	et	2	main
nähtavat	doc_503739895320_item	2665380	et	4	main
kombeid	doc_503739895320_item	2665384	et	4	main
siis	doc_503739895320_item	2665386	et	3	main
julge	doc_503739895320_item	2665443	et	4	main
kontrolltöö	doc_503739895321_item	2665448	et	4	main
viii	doc_503739895321_item	2665459	et	4	main
avastatud	doc_503739895321_item	2665466	et	4	main
üle	doc_503739895321_item	2665468	et	3	main
asulakoha	doc_503739895321_item	2665472	et	4	main
leedus	doc_503739895321_item	2665476	et	4	main
saabus	doc_503739895321_item	2665477	et	3	main
veel	doc_503739895321_item	2665487	et	4	main
sest	doc_503739895321_item	2665493	et	4	main
ikka	doc_503739895321_item	2665500	et	4	main
leiti	doc_503739895321_item	2665503	et	3	main
palju	doc_503739895321_item	2665504	et	4	main
mandrijää	doc_503739895321_item	2665506	et	4	main
hea	doc_503739895321_item	2665523	et	4	main
kliima	doc_503739895321_item	2665540	et	4	main
valmistama	doc_503739895321_item	2665547	et	3	main
kõige	doc_503739895321_item	2665550	et	4	main
vastavaid	doc_503739895321_item	2665552	et	4	main
välja	doc_503739895321_item	2665560	et	4	main
elasid	doc_503739895321_item	2665567	et	4	main
pealt	doc_503739895321_item	2665585	et	4	main
oli	doc_503739895320_item	2665222	et	3	main
ka	doc_503739895320_item	2665223	et	3	main
sündmusi	doc_503739895320_item	2665226	et	3	main
mitmest	doc_503739895320_item	2665228	et	4	main
palju	doc_503739895320_item	2665241	et	4	main
tegutsesid	doc_503739895320_item	2665245	et	4	main
külalisteatrid	doc_503739895320_item	2665246	et	3	main
täpp	doc_503739895320_item	2665255	et	3	main
sai	doc_503739895320_item	2665257	et	4	main
täheldada	doc_503739895320_item	2665258	et	3	main
ka	doc_503739895320_item	2665259	et	3	main
eesti	doc_503739895320_item	2665260	et	4	main
multifilmi	doc_503739895320_item	2665261	et	4	main
tihengut	doc_503739895320_item	2665262	et	4	main
hullumeelsus	doc_503739895320_item	2665263	et	4	main
kinokunstis	doc_503739895320_item	2665264	et	3	main
astusid	doc_503739895320_item	2665265	et	4	main
ette	doc_503739895320_item	2665266	et	4	main
kõrboja	doc_503739895320_item	2665279	et	4	main
kinokunsti	doc_503739895320_item	2665282	et	4	main
olid	doc_503739895320_item	2665284	et	4	main
väljas	doc_503739895320_item	2665288	et	4	main
nsv	doc_503739895320_item	2665290	et	4	main
rohkem	doc_503739895320_item	2665293	et	4	main
luulet	doc_503739895320_item	2665294	et	3	main
eestlane	doc_503739895320_item	2665295	et	3	main
olid	doc_503739895320_item	2665303	et	4	main
mast	doc_503739895320_item	2665304	et	3	main
tegevus	doc_503739895320_item	2665311	et	4	main
2	doc_503739895320_item	2665312	et	2	main
arvan	doc_503739895320_item	2665313	et	3	main
et	doc_503739895320_item	2665314	et	3	main
ta	doc_503739895320_item	2665320	et	4	main
üksnes	doc_503739895320_item	2665322	et	3	main
minu	doc_503739895320_item	2665328	et	3	main
et	doc_503739895320_item	2665330	et	3	main
hulka	doc_503739895320_item	2665344	et	4	main
tõetruul	doc_503739895320_item	2665349	et	3	main
oskuslikult	doc_503739895320_item	2665362	et	4	main
muusikariistade	doc_503739895320_item	2665366	et	3	main
tekitab	doc_503739895320_item	2665368	et	3	main
mingi	doc_503739895320_item	2665370	et	4	main
varjundi	doc_503739895320_item	2665372	et	3	main
näitemängu	doc_503739895320_item	2665383	et	4	main
kui	doc_503739895320_item	2665387	et	3	main
film	doc_503739895320_item	2665388	et	3	main
oli	doc_503739895320_item	2665389	et	3	main
otsas	doc_503739895320_item	2665390	et	4	main
ma	doc_503739895320_item	2665392	et	3	main
sain	doc_503739895320_item	2665393	et	3	main
pikemalt	doc_503739895320_item	2665394	et	4	main
ning	doc_503739895320_item	2665391	et	3	main
asjade	doc_503739895320_item	2665395	et	3	main
üle	doc_503739895320_item	2665396	et	3	main
mõelda	doc_503739895320_item	2665397	et	4	main
tundus	doc_503739895320_item	2665398	et	3	main
mulle	doc_503739895320_item	2665399	et	4	main
siiski	doc_503739895320_item	2665400	et	4	main
et	doc_503739895320_item	2665401	et	3	main
tõe	doc_503739895320_item	2665402	et	4	main
poolest	doc_503739895320_item	2665403	et	4	main
selliselt	doc_503739895320_item	2665404	et	4	main
ülesehitatud	doc_503739895320_item	2665405	et	4	main
film	doc_503739895320_item	2665406	et	3	main
sai	doc_503739895320_item	2665407	et	4	main
tollases	doc_503739895320_item	2665408	et	3	main
sotsia	doc_503739895320_item	2665409	et	4	main
ühiskonnas	doc_503739895320_item	2665410	et	4	main
riiuli	doc_503739895320_item	2665411	et	3	main
lina	doc_503739895320_item	2665412	et	4	main
teoseks	doc_503739895320_item	2665413	et	4	main
tiina	doc_503739895320_item	2665414	et	4	main
tugev	doc_503739895320_item	2665415	et	4	main
jõuline	doc_503739895320_item	2665416	et	4	main
karakter	doc_503739895320_item	2665417	et	3	main
püüd	doc_503739895320_item	2665418	et	4	main
olla	doc_503739895320_item	2665419	et	3	main
eelarvamustest	doc_503739895320_item	2665420	et	4	main
alluvale	doc_503739895320_item	2665439	et	4	main
massile	doc_503739895320_item	2665440	et	3	main
oli	doc_503739895320_item	2665441	et	3	main
polnud	doc_503739895320_item	2665426	et	3	main
hallile	doc_503739895320_item	2665437	et	4	main
karjainstinktile	doc_503739895320_item	2665438	et	3	main
kriitika	doc_503739895320_item	2665445	et	4	main
kiviaeg	doc_503739895321_item	2665450	et	3	main
eesti	doc_503739895321_item	2665451	et	4	main
territooriumil	doc_503739895321_item	2665452	et	3	main
2	doc_503739895321_item	2665453	et	2	main
mõiste	doc_503739895321_item	2665454	et	4	main
arheoloogiline	doc_503739895321_item	2665455	et	4	main
lugu	doc_503739895320_item	2665442	et	4	main
väljakutse	doc_503739895320_item	2665447	et	4	main
tähendus	doc_503739895321_item	2665457	et	4	main
ast	doc_503739895321_item	2665460	et	3	main
ekr	doc_503739895321_item	2665462	et	4	main
vanakiviaeg	doc_503739895321_item	2665463	et	3	main
leedus	doc_503739895321_item	2665464	et	4	main
saja	doc_503739895321_item	2665469	et	4	main
poleoliitikume	doc_503739895321_item	2665481	et	4	main
raske	doc_503739895321_item	2665491	et	4	main
leida	doc_503739895321_item	2665492	et	3	main
liikuva	doc_503739895321_item	2665497	et	4	main
põhja	doc_503739895321_item	2665509	et	4	main
poole	doc_503739895321_item	2665510	et	4	main
kala	doc_503739895321_item	2665516	et	4	main
valmistamiseks	doc_503739895321_item	2665530	et	4	main
ja	doc_503739895321_item	2665531	et	3	main
püstkodade	doc_503739895321_item	2665532	et	3	main
katmiseks	doc_503739895321_item	2665533	et	4	main
ja	doc_503739895321_item	2665541	et	3	main
tööristu	doc_503739895321_item	2665553	et	4	main
kasutades	doc_503739895321_item	2665554	et	3	main
materiaalne	doc_503739895321_item	2665561	et	3	main
kultuur	doc_503739895321_item	2665564	et	3	main
või	doc_503739895321_item	2665574	et	4	main
ritvadest	doc_503739895321_item	2665579	et	3	main
koonusekujulistes	doc_503739895321_item	2665581	et	4	main
olid	doc_503739895321_item	2665584	et	4	main
riist	doc_503739895321_item	2665625	et	3	main
ka	doc_503739895321_item	2665633	et	3	main
söödavate	doc_503739895321_item	2665661	et	4	main
korjamine	doc_503739895321_item	2665664	et	4	main
ajajargu	doc_503739895321_item	2665672	et	4	main
kiviesemed	doc_503739895321_item	2665676	et	3	main
kammkeraamika	doc_503739895321_item	2665685	et	4	main
kultuuri	doc_503739895321_item	2665686	et	4	main
nõud	doc_503739895321_item	2665692	et	3	main
üleni	doc_503739895321_item	2665698	et	3	main
kirvete	doc_503739895321_item	2665706	et	4	main
hakkati	doc_503739895321_item	2665715	et	3	main
siga	doc_503739895321_item	2665718	et	4	main
kasvatada	doc_503739895321_item	2665723	et	3	main
savikvartsgraniiditükkid	doc_503739895321_item	2665736	et	4	main
kultuur	doc_503739895321_item	2665456	et	3	main
on	doc_503739895321_item	2665465	et	4	main
inimesi	doc_503739895321_item	2665478	et	4	main
eestist	doc_503739895321_item	2665479	et	3	main
on	doc_503739895321_item	2665490	et	4	main
olid	doc_503739895321_item	2665495	et	4	main
eluviisiga	doc_503739895321_item	2665498	et	4	main
salgad	doc_503739895321_item	2665511	et	4	main
esimesed	doc_503739895321_item	2665512	et	3	main
elanikud	doc_503739895321_item	2665513	et	3	main
küttisid	doc_503739895321_item	2665514	et	4	main
korjasid	doc_503739895321_item	2665517	et	4	main
küttisid	doc_503739895321_item	2665519	et	4	main
põhjapõdru	doc_503739895321_item	2665520	et	4	main
liha	doc_503739895321_item	2665525	et	4	main
söök	doc_503739895321_item	2665527	et	3	main
nahka	doc_503739895321_item	2665528	et	4	main
rõivaste	doc_503739895321_item	2665529	et	4	main
noorem	doc_503739895321_item	2665537	et	4	main
kiviaeg	doc_503739895321_item	2665538	et	3	main
neoliitikum	doc_503739895321_item	2665539	et	3	main
paremini-	doc_503739895321_item	2665544	et	4	main
inimesed	doc_503739895321_item	2665545	et	3	main
oludele	doc_503739895321_item	2665549	et	3	main
kujunes	doc_503739895321_item	2665559	et	3	main
asukad	doc_503739895321_item	2665566	et	3	main
järvede	doc_503739895321_item	2665575	et	3	main
kallastel	doc_503739895321_item	2665576	et	4	main
ehitatud	doc_503739895321_item	2665580	et	4	main
püstkodades	doc_503739895321_item	2665582	et	3	main
mis	doc_503739895321_item	2665583	et	4	main
okste	doc_503739895321_item	2665587	et	3	main
tähtsat	doc_503739895321_item	2665622	et	3	main
oli	doc_503739895321_item	2665626	et	3	main
luust	doc_503739895321_item	2665627	et	4	main
õngekonksud	doc_503739895321_item	2665635	et	3	main
võrgud	doc_503739895321_item	2665637	et	3	main
ja	doc_503739895321_item	2665639	et	3	main
viske	doc_503739895321_item	2665643	et	3	main
sarvast	doc_503739895321_item	2665653	et	3	main
kiviajal	doc_503739895321_item	2665655	et	3	main
oli	doc_503739895321_item	2665656	et	3	main
keraamika	doc_503739895321_item	2665665	et	4	main
savinõud	doc_503739895321_item	2665666	et	3	main
neoliitikumis	doc_503739895321_item	2665667	et	3	main
võeti	doc_503739895321_item	2665668	et	3	main
sarv	doc_503739895321_item	2665675	et	3	main
puurimine	doc_503739895321_item	2665683	et	4	main
need	doc_503739895321_item	2665691	et	3	main
kvaliteetsemad	doc_503739895321_item	2665695	et	4	main
kaunistatud	doc_503739895321_item	2665697	et	4	main
järgi	doc_503739895321_item	2665707	et	4	main
tuntakse	doc_503739895321_item	2665708	et	3	main
lammas	doc_503739895321_item	2665720	et	3	main
osati	doc_503739895321_item	2665721	et	3	main
ja	doc_503739895321_item	2665728	et	3	main
neemevi	doc_503739895321_item	2665734	et	4	main
kultuur	doc_503739895321_item	2665735	et	3	main
oli	doc_503739895321_item	2665522	et	3	main
saak	doc_503739895321_item	2665524	et	3	main
tegemiseks	doc_503739895321_item	2665536	et	4	main
läks	doc_503739895321_item	2665543	et	3	main
õppisid	doc_503739895321_item	2665546	et	4	main
kohalikele	doc_503739895321_item	2665548	et	3	main
selleks	doc_503739895321_item	2665555	et	4	main
kohapealseid	doc_503739895321_item	2665556	et	3	main
materjale	doc_503739895321_item	2665557	et	3	main
ja	doc_503739895321_item	2665562	et	3	main
vaimne	doc_503739895321_item	2665563	et	3	main
kiviaja	doc_503739895321_item	2665565	et	3	main
20-40	doc_503739895321_item	2665568	et	2	main
inimesed	doc_503739895321_item	2665569	et	3	main
mis	doc_503739895321_item	2665571	et	4	main
tavaliselt	doc_503739895321_item	2665577	et	4	main
kaetud	doc_503739895321_item	2665586	et	4	main
puukoorte	doc_503739895321_item	2665589	et	3	main
püstkoha	doc_503739895321_item	2665590	et	4	main
keskes	doc_503739895321_item	2665591	et	4	main
asub	doc_503739895321_item	2665592	et	3	main
kolle	doc_503739895321_item	2665593	et	4	main
mis	doc_503739895321_item	2665594	et	4	main
andis	doc_503739895321_item	2665595	et	3	main
valgust	doc_503739895321_item	2665596	et	4	main
ja	doc_503739895321_item	2665597	et	3	main
soojust	doc_503739895321_item	2665598	et	4	main
millel	doc_503739895321_item	2665599	et	3	main
ka	doc_503739895321_item	2665600	et	3	main
küpsetati	doc_503739895321_item	2665601	et	3	main
toitu	doc_503739895321_item	2665602	et	4	main
suur	doc_503739895321_item	2665603	et	3	main
osa	doc_503739895321_item	2665604	et	4	main
töö	doc_503739895321_item	2665605	et	4	main
ja	doc_503739895321_item	2665606	et	3	main
erberiistu	doc_503739895321_item	2665607	et	4	main
oli	doc_503739895321_item	2665608	et	3	main
valmistatud	doc_503739895321_item	2665609	et	4	main
luust	doc_503739895321_item	2665610	et	4	main
sarvest	doc_503739895321_item	2665611	et	4	main
kivist	doc_503739895321_item	2665612	et	4	main
valimistati	doc_503739895321_item	2665613	et	3	main
ka	doc_503739895321_item	2665614	et	3	main
kivikõrveid	doc_503739895321_item	2665615	et	4	main
tahtsaks	doc_503739895321_item	2665616	et	4	main
uuenduseks	doc_503739895321_item	2665617	et	4	main
oli	doc_503739895321_item	2665618	et	3	main
keraamika	doc_503739895321_item	2665619	et	4	main
neoliitikumis	doc_503739895321_item	2665620	et	3	main
kasutusele	doc_503739895321_item	2665632	et	4	main
kui	doc_503739895321_item	2665644	et	3	main
torkeodadega	doc_503739895321_item	2665645	et	3	main
etendas	doc_503739895321_item	2665621	et	3	main
kalapüük	doc_503739895321_item	2665624	et	3	main
aga	doc_503739895321_item	2665629	et	3	main
hiljem	doc_503739895321_item	2665630	et	3	main
tulid	doc_503739895321_item	2665631	et	4	main
luust	doc_503739895321_item	2665634	et	4	main
ja	doc_503739895321_item	2665636	et	3	main
linde	doc_503739895321_item	2665640	et	4	main
luust	doc_503739895321_item	2665652	et	4	main
kasutusele	doc_503739895321_item	2665669	et	4	main
keraamika	doc_503739895321_item	2665670	et	4	main
sel	doc_503739895321_item	2665671	et	3	main
luu	doc_503739895321_item	2665674	et	4	main
levisid	doc_503739895321_item	2665678	et	4	main
kivilihvimine	doc_503739895321_item	2665684	et	3	main
hõimud	doc_503739895321_item	2665690	et	4	main
meenutavate	doc_503739895321_item	2665705	et	4	main
keraamikatüüp	doc_503739895321_item	2665714	et	4	main
koduloomi	doc_503739895321_item	2665717	et	4	main
kits	doc_503739895321_item	2665719	et	3	main
kivist	doc_503739895321_item	2665651	et	4	main
puust	doc_503739895321_item	2665654	et	4	main
tähtis	doc_503739895321_item	2665657	et	4	main
mitmesuguste	doc_503739895321_item	2665658	et	3	main
marjade	doc_503739895321_item	2665659	et	3	main
seente	doc_503739895321_item	2665660	et	3	main
juurte	doc_503739895321_item	2665662	et	3	main
muutused	doc_503739895321_item	2665673	et	4	main
laemalt	doc_503739895321_item	2665677	et	4	main
nende	doc_503739895321_item	2665679	et	4	main
erinevad	doc_503739895321_item	2665680	et	4	main
valmistamisvõtted	doc_503739895321_item	2665681	et	3	main
tõid	doc_503739895321_item	2665687	et	4	main
eesnevatest	doc_503739895321_item	2665694	et	4	main
ja	doc_503739895321_item	2665696	et	3	main
vajutistega	doc_503739895321_item	2665700	et	3	main
ornamendiga	doc_503739895321_item	2665702	et	3	main
seda	doc_503739895321_item	2665709	et	3	main
pidama	doc_503739895321_item	2665716	et	4	main
välja	doc_503739895321_item	2665722	et	4	main
luust	doc_503739895321_item	2665727	et	4	main
keraamika	doc_503739895321_item	2665732	et	4	main
savitaimed	doc_503739895321_item	2665733	et	3	main
kultuuri	doc_503739895321_item	2665710	et	4	main
vahendiks	doc_503739895321_item	2665711	et	3	main
nöörivajutistega	doc_503739895321_item	2665712	et	3	main
kaunistatud	doc_503739895321_item	2665713	et	4	main
kunda	doc_503739895321_item	2665725	et	4	main
kultuur	doc_503739895321_item	2665726	et	3	main
2	doc_503739895321_item	2665724	et	2	main
kivist	doc_503739895321_item	2665729	et	4	main
narva	doc_503739895321_item	2665730	et	4	main
kultuur	doc_503739895321_item	2665731	et	3	main
xxx	doc_516622545497_item	2666016	et	4	main
tamme	doc_516622545497_item	2666025	et	4	main
praegu	doc_516622545497_item	2666030	et	3	main
laupäeval	doc_516622545497_item	2666035	et	3	main
noormees	doc_516622545497_item	2666050	et	4	main
bussis	doc_516622545497_item	2666053	et	3	main
ma	doc_516622545497_item	2666059	et	3	main
üksinda	doc_516622545497_item	2666061	et	4	main
sellepärast	doc_516622545497_item	2666063	et	3	main
osalejäid	doc_516622545497_item	2666065	et	4	main
polnud	doc_516622545497_item	2666066	et	3	main
rahakottis	doc_516622545497_item	2666088	et	4	main
politseile	doc_516622545497_item	2666012	et	3	main
nimi	doc_516622545497_item	2666014	et	3	main
aadressil	doc_516622545497_item	2666024	et	3	main
aga	doc_516622545497_item	2666029	et	3	main
tallinnas	doc_516622545497_item	2666034	et	4	main
03	doc_516622545497_item	2666037	et	2	main
kell	doc_516622545497_item	2666039	et	3	main
sõidsin	doc_516622545497_item	2666042	et	4	main
n	doc_516622545497_item	2666045	et	4	main
mul	doc_516622545497_item	2666047	et	3	main
varastas	doc_516622545497_item	2666048	et	3	main
kotti	doc_516622545497_item	2666049	et	4	main
kui	doc_516622545497_item	2666056	et	3	main
minu	doc_516622545497_item	2666067	et	3	main
nahast	doc_516622545497_item	2666075	et	4	main
gucci	doc_516622545497_item	2666077	et	4	main
kottis	doc_516622545497_item	2666078	et	3	main
olid	doc_516622545497_item	2666079	et	4	main
dokumeendid	doc_516622545497_item	2666080	et	4	main
oli	doc_516622545497_item	2666089	et	3	main
krooni	doc_516622545497_item	2666092	et	4	main
maksumus	doc_516622545497_item	2666094	et	3	main
meie	doc_516622545498_item	2666121	et	4	main
ainult	doc_516622545498_item	2666123	et	4	main
inimene	doc_516622545498_item	2666128	et	3	main
on	doc_516622545498_item	2666129	et	4	main
geneetiline	doc_516622545498_item	2666130	et	3	main
soodumus	doc_516622545498_item	2666131	et	3	main
kellel	doc_516622545498_item	2666141	et	4	main
xyy	doc_516622545498_item	2666142	et	4	main
teadusele	doc_516622545498_item	2666175	et	3	main
mida	doc_516622545498_item	2666177	et	4	main
rohkem	doc_516622545498_item	2666178	et	4	main
on	doc_516622545498_item	2666184	et	4	main
alati	doc_516622545498_item	2666194	et	4	main
peab	doc_516622545498_item	2666201	et	4	main
vabanenuid	doc_516622545498_item	2666203	et	4	main
kes	doc_516622545498_item	2666207	et	4	main
võivad	doc_516622545498_item	2666213	et	4	main
ja	doc_516622545498_item	2666217	et	3	main
parandada	doc_516622545498_item	2666218	et	3	main
oma	doc_516622545498_item	2666219	et	4	main
vigu	doc_516622545498_item	2666220	et	3	main
politseile	doc_516622545497_item	2666010	et	3	main
seletuskiri	doc_516622545497_item	2666011	et	3	main
minu	doc_516622545497_item	2666013	et	3	main
on	doc_516622545497_item	2666015	et	4	main
yyy	doc_516622545497_item	2666017	et	4	main
sünniaeg	doc_516622545497_item	2666018	et	3	main
09	doc_516622545497_item	2666019	et	2	main
07	doc_516622545497_item	2666020	et	2	main
ma	doc_516622545497_item	2666022	et	3	main
tee	doc_516622545497_item	2666026	et	4	main
elan	doc_516622545497_item	2666031	et	3	main
ja	doc_516622545497_item	2666051	et	3	main
jooksis	doc_516622545497_item	2666052	et	4	main
välja	doc_516622545497_item	2666054	et	4	main
teisi	doc_516622545497_item	2666064	et	4	main
värvi	doc_516622545497_item	2666071	et	4	main
ja	doc_516622545497_item	2666072	et	3	main
ta	doc_516622545497_item	2666073	et	4	main
oli	doc_516622545497_item	2666074	et	3	main
pass	doc_516622545497_item	2666081	et	3	main
umbes	doc_516622545497_item	2666090	et	4	main
varastatu	doc_516622545497_item	2666093	et	4	main
meie	doc_516622545498_item	2666125	et	4	main
käes	doc_516622545498_item	2666126	et	4	main
iga	doc_516622545498_item	2666127	et	4	main
agressiivse	doc_516622545498_item	2666144	et	3	main
3	doc_516622545498_item	2666152	et	2	main
sõltub	doc_516622545498_item	2666154	et	3	main
noored	doc_516622545498_item	2666157	et	3	main
või	doc_516622545498_item	2666161	et	4	main
1	doc_516622545498_item	2666176	et	2	main
tänu	doc_516622545498_item	2666186	et	4	main
me	doc_516622545498_item	2666188	et	4	main
politsei	doc_516622545498_item	2666195	et	4	main
abistama	doc_516622545498_item	2666204	et	3	main
vanglast	doc_516622545498_item	2666209	et	4	main
vabanenud	doc_516622545498_item	2666210	et	4	main
need	doc_516622545498_item	2666212	et	3	main
alustada	doc_516622545498_item	2666214	et	3	main
uut	doc_516622545498_item	2666215	et	3	main
elu	doc_516622545498_item	2666216	et	4	main
kurjategijat	doc_516622545498_item	2666229	et	3	main
parandab	doc_516622545498_item	2666234	et	3	main
karistust	doc_516622545498_item	2666241	et	4	main
kodu	doc_516622545498_item	2666250	et	4	main
tagab	doc_516622545498_item	2666251	et	3	main
selle	doc_516622545498_item	2666252	et	4	main
et	doc_516622545498_item	2666253	et	3	main
kurjategijat	doc_516622545498_item	2666257	et	3	main
laps	doc_516622545498_item	2666263	et	4	main
jalutas	doc_516622545499_item	2666276	et	3	main
oma	doc_516622545499_item	2666277	et	4	main
nägi	doc_516622545499_item	2666281	et	3	main
ja	doc_516622545499_item	2666283	et	3	main
oli	doc_516622545499_item	2666288	et	3	main
kaks	doc_516622545499_item	2666289	et	3	main
ja	doc_516622545499_item	2666291	et	3	main
auto	doc_516622545499_item	2666297	et	4	main
auto	doc_516622545499_item	2666321	et	4	main
ta	doc_516622545499_item	2666334	et	4	main
jalgraturit	doc_516622545499_item	2666341	et	4	main
raamatuid	doc_516622545500_item	2666354	et	3	main
ei	doc_516622545500_item	2666360	et	4	main
lugeda	doc_516622545500_item	2666377	et	3	main
iga	doc_516622545500_item	2666386	et	4	main
inimene	doc_516622545500_item	2666387	et	3	main
mina	doc_516622545500_item	2666391	et	4	main
et	doc_516622545500_item	2666393	et	3	main
noored	doc_516622545500_item	2666395	et	3	main
valivad	doc_516622545500_item	2666397	et	4	main
millele	doc_516622545500_item	2666415	et	3	main
firmat	doc_516622545500_item	2666424	et	3	main
inimene	doc_516622545500_item	2666439	et	3	main
87	doc_516622545497_item	2666021	et	2	main
43	doc_516622545497_item	2666027	et	2	main
rae	doc_516622545497_item	2666032	et	3	main
03	doc_516622545497_item	2666038	et	2	main
ma	doc_516622545497_item	2666041	et	3	main
bussiga	doc_516622545497_item	2666044	et	3	main
oli	doc_516622545497_item	2666057	et	3	main
sõidsin	doc_516622545497_item	2666060	et	4	main
ja	doc_516622545497_item	2666062	et	3	main
kott	doc_516622545497_item	2666068	et	3	main
pruuni	doc_516622545497_item	2666070	et	4	main
firma	doc_516622545497_item	2666076	et	4	main
sõidupilet	doc_516622545497_item	2666084	et	3	main
mobilltelefon	doc_516622545497_item	2666085	et	4	main
rahakott	doc_516622545497_item	2666087	et	3	main
750	doc_516622545497_item	2666091	et	2	main
oli	doc_516622545497_item	2666095	et	3	main
umbes	doc_516622545497_item	2666096	et	4	main
on	doc_516622545498_item	2666135	et	4	main
suurem	doc_516622545498_item	2666143	et	4	main
ei	doc_516622545498_item	2666146	et	4	main
aga	doc_516622545498_item	2666148	et	3	main
tekkivad	doc_516622545498_item	2666151	et	4	main
see	doc_516622545498_item	2666155	et	3	main
kuritegelikule	doc_516622545498_item	2666159	et	3	main
seda	doc_516622545498_item	2666182	et	3	main
turvalisem	doc_516622545498_item	2666183	et	4	main
ennast	doc_516622545498_item	2666190	et	4	main
turvalisem	doc_516622545498_item	2666191	et	4	main
päästab	doc_516622545498_item	2666196	et	3	main
riik	doc_516622545498_item	2666200	et	3	main
ka	doc_516622545498_item	2666205	et	3	main
ka	doc_516622545498_item	2666211	et	3	main
ei	doc_516622545498_item	2666222	et	4	main
aidata	doc_516622545498_item	2666225	et	4	main
mitte	doc_516622545498_item	2666232	et	3	main
vangla	doc_516622545498_item	2666235	et	4	main
karistus	doc_516622545498_item	2666236	et	4	main
vahel	doc_516622545498_item	2666237	et	4	main
inimene	doc_516622545498_item	2666238	et	3	main
saab	doc_516622545498_item	2666242	et	3	main
aru	doc_516622545498_item	2666243	et	4	main
et	doc_516622545498_item	2666244	et	3	main
ei	doc_516622545498_item	2666255	et	4	main
kasvatatakse	doc_516622545498_item	2666259	et	3	main
selliseks	doc_516622545498_item	2666261	et	4	main
et	doc_516622545499_item	2666274	et	3	main
pidurdas	doc_516622545499_item	2666295	et	3	main
jooksul	doc_516622545499_item	2666309	et	4	main
koeraga	doc_516622545499_item	2666311	et	3	main
telefoni	doc_516622545499_item	2666313	et	4	main
juurde	doc_516622545499_item	2666314	et	4	main
ja	doc_516622545499_item	2666315	et	3	main
helistas	doc_516622545499_item	2666316	et	3	main
kiirabisse	doc_516622545499_item	2666317	et	3	main
arvan	doc_516622545499_item	2666318	et	3	main
ka	doc_516622545499_item	2666319	et	3	main
et	doc_516622545499_item	2666320	et	3	main
seletuskiri	doc_516622545497_item	2666009	et	3	main
elan	doc_516622545497_item	2666023	et	3	main
narvas	doc_516622545497_item	2666028	et	4	main
87-8	doc_516622545497_item	2666033	et	2	main
26	doc_516622545497_item	2666036	et	2	main
2100	doc_516622545497_item	2666040	et	2	main
koju	doc_516622545497_item	2666043	et	3	main
35	doc_516622545497_item	2666046	et	2	main
poskal	doc_516622545497_item	2666055	et	4	main
peatusbr	doc_516622545497_item	2666058	et	4	main
oli	doc_516622545497_item	2666069	et	3	main
isik-kaart	doc_516622545497_item	2666082	et	4	main
pankakaart	doc_516622545497_item	2666083	et	4	main
ja	doc_516622545497_item	2666086	et	3	main
1500	doc_516622545497_item	2666097	et	2	main
kroonispan	doc_516622545497_item	2666098	et	4	main
span	doc_516622545497_item	2666099	et	4	main
xxx	doc_516622545497_item	2666100	et	4	main
yyy	doc_516622545497_item	2666101	et	4	main
26	doc_516622545497_item	2666102	et	2	main
05	doc_516622545497_item	2666103	et	2	main
03	doc_516622545497_item	2666104	et	2	main
poolt-	doc_516622545498_item	2666105	et	4	main
ja	doc_516622545498_item	2666106	et	3	main
vastuargumendid	doc_516622545498_item	2666107	et	3	main
poolt-	doc_516622545498_item	2666109	et	4	main
esita	doc_516622545498_item	2666108	et	4	main
ja	doc_516622545498_item	2666110	et	3	main
vastuargumente	doc_516622545498_item	2666111	et	3	main
1	doc_516622545498_item	2666112	et	2	main
iga	doc_516622545498_item	2666113	et	4	main
peab	doc_516622545498_item	2666115	et	4	main
ennast	doc_516622545498_item	2666116	et	4	main
inimene	doc_516622545498_item	2666114	et	3	main
ise	doc_516622545498_item	2666117	et	4	main
kuritegude	doc_516622545498_item	2666118	et	3	main
eest	doc_516622545498_item	2666119	et	4	main
kaitsma	doc_516622545498_item	2666120	et	3	main
elu	doc_516622545498_item	2666122	et	4	main
on	doc_516622545498_item	2666124	et	4	main
kuritegevusele	doc_516622545498_item	2666132	et	4	main
1	doc_516622545498_item	2666133	et	2	main
kurjategijatel	doc_516622545498_item	2666134	et	3	main
kurjategija	doc_516622545498_item	2666145	et	4	main
sünnita	doc_516622545498_item	2666147	et	4	main
vaid	doc_516622545498_item	2666150	et	3	main
kuid	doc_516622545498_item	2666192	et	4	main
mitte	doc_516622545498_item	2666193	et	3	main
vangist	doc_516622545498_item	2666202	et	3	main
neid	doc_516622545498_item	2666206	et	4	main
kohustuslik	doc_516622545498_item	2666224	et	3	main
neid	doc_516622545498_item	2666226	et	4	main
1	doc_516622545498_item	2666227	et	2	main
vanglakaristus	doc_516622545498_item	2666228	et	3	main
kes	doc_516622545498_item	2666239	et	4	main
ta	doc_516622545498_item	2666245	et	4	main
saa	doc_516622545498_item	2666256	et	4	main
arvates	doc_516622545499_item	2666273	et	4	main
koeraga	doc_516622545499_item	2666278	et	3	main
geneetiline	doc_516622545498_item	2666136	et	3	main
soodumus	doc_516622545498_item	2666137	et	3	main
kuritegevusele	doc_516622545498_item	2666138	et	4	main
eriti	doc_516622545498_item	2666139	et	3	main
poisid	doc_516622545498_item	2666140	et	4	main
nad	doc_516622545498_item	2666149	et	3	main
kooliharidusest	doc_516622545498_item	2666153	et	4	main
kas	doc_516622545498_item	2666156	et	3	main
lähevad	doc_516622545498_item	2666158	et	3	main
teele	doc_516622545498_item	2666160	et	3	main
mitte	doc_516622545498_item	2666162	et	3	main
saada	doc_516622545498_item	2666163	et	4	main
haridust	doc_516622545498_item	2666164	et	4	main
on	doc_516622545498_item	2666165	et	4	main
iga	doc_516622545498_item	2666166	et	4	main
inimese	doc_516622545498_item	2666167	et	4	main
oma	doc_516622545498_item	2666168	et	4	main
asi	doc_516622545498_item	2666169	et	4	main
kuritegevusele	doc_516622545498_item	2666170	et	4	main
pole	doc_516622545498_item	2666171	et	3	main
vaja	doc_516622545498_item	2666172	et	4	main
haridust	doc_516622545498_item	2666173	et	4	main
ja	doc_516622545498_item	2666174	et	3	main
on	doc_516622545498_item	2666179	et	4	main
riigis	doc_516622545498_item	2666180	et	3	main
politseinikke	doc_516622545498_item	2666181	et	3	main
elu	doc_516622545498_item	2666185	et	4	main
politseile	doc_516622545498_item	2666187	et	3	main
tunneme	doc_516622545498_item	2666189	et	3	main
meid	doc_516622545498_item	2666197	et	4	main
kuritegelikusest	doc_516622545498_item	2666198	et	4	main
1	doc_516622545498_item	2666199	et	2	main
on	doc_516622545498_item	2666208	et	4	main
riik	doc_516622545498_item	2666221	et	3	main
ole	doc_516622545498_item	2666223	et	4	main
ei	doc_516622545498_item	2666230	et	4	main
lapsest	doc_516622545498_item	2666254	et	4	main
kuidas	doc_516622545498_item	2666258	et	3	main
et	doc_516622545498_item	2666260	et	3	main
peale	doc_516622545498_item	2666265	et	4	main
mõjutada	doc_516622545498_item	2666267	et	3	main
ka	doc_516622545498_item	2666268	et	3	main
inimene	doc_516622545499_item	2666275	et	3	main
ja	doc_516622545499_item	2666279	et	3	main
püüdma	doc_516622545499_item	2666285	et	3	main
kõigepealt	doc_516622545499_item	2666293	et	3	main
pärast	doc_516622545499_item	2666302	et	4	main
mees	doc_516622545499_item	2666310	et	4	main
laks	doc_516622545499_item	2666312	et	4	main
kuni	doc_516622545499_item	2666331	et	3	main
sündmuses	doc_516622545499_item	2666344	et	3	main
arvan	doc_516622545500_item	2666356	et	3	main
tihti	doc_516622545500_item	2666364	et	3	main
raamatukokku	doc_516622545500_item	2666372	et	4	main
otsida	doc_516622545500_item	2666373	et	4	main
on	doc_516622545500_item	2666384	et	4	main
hakkavad	doc_516622545500_item	2666409	et	4	main
raamatud	doc_516622545500_item	2666410	et	4	main
lugeda	doc_516622545500_item	2666411	et	3	main
ja	doc_516622545500_item	2666412	et	3	main
raamatukokku	doc_516622545500_item	2666413	et	4	main
peab	doc_516622545500_item	2666416	et	4	main
inimene	doc_516622545500_item	2666418	et	3	main
asutada	doc_516622545500_item	2666423	et	3	main
väga	doc_516622545500_item	2666426	et	3	main
kes	doc_516622545500_item	2666432	et	4	main
kiiresti	doc_516622545500_item	2666433	et	3	main
arvan	doc_516622545500_item	2666437	et	3	main
et	doc_516622545500_item	2666438	et	3	main
firma	doc_516622545500_item	2666445	et	4	main
konkurentid	doc_516622545500_item	2666446	et	4	main
kampaaniat	doc_516622545500_item	2666453	et	3	main
vähendada	doc_516622545500_item	2666456	et	3	main
kui	doc_516622545500_item	2666461	et	3	main
riigis	doc_516622545500_item	2666463	et	3	main
turvalisem	doc_516622545500_item	2666467	et	4	main
võib	doc_516622545500_item	2666477	et	3	main
on	doc_516622545500_item	2666510	et	4	main
inimesed	doc_516622545500_item	2666522	et	3	main
ja	doc_516622545500_item	2666524	et	3	main
sa	doc_516622545500_item	2666538	et	3	main
sa	doc_516622545500_item	2666548	et	3	main
vaja	doc_516622545500_item	2666555	et	4	main
vaja	doc_516622545500_item	2666565	et	4	main
rohkem	doc_516622545500_item	2666572	et	4	main
vähem	doc_516622545500_item	2666574	et	4	main
et	doc_516622545500_item	2666579	et	3	main
on	doc_516622545500_item	2666585	et	4	main
muud	doc_516622545500_item	2666589	et	4	main
uued	doc_516622545500_item	2666590	et	3	main
taha	doc_516622545500_item	2666599	et	4	main
lugeda	doc_516622545500_item	2666600	et	3	main
need	doc_516622545500_item	2666601	et	3	main
ei	doc_516622545500_item	2666605	et	4	main
inimene	doc_516622545500_item	2666609	et	3	main
ta	doc_516622545500_item	2666613	et	4	main
ei	doc_516622545500_item	2666614	et	4	main
areneb	doc_516622545500_item	2666615	et	3	main
edukus	doc_516622545500_item	2666631	et	4	main
sõltub	doc_516622545500_item	2666632	et	3	main
on	doc_516622545500_item	2666638	et	4	main
äriplaani	doc_516622545500_item	2666641	et	4	main
väga	doc_516622545500_item	2666645	et	3	main
hästi	doc_516622545500_item	2666660	et	3	main
saab	doc_516622545501_item	2666663	et	3	main
paranda	doc_516622545498_item	2666231	et	4	main
kõiki	doc_516622545498_item	2666233	et	4	main
kandis	doc_516622545498_item	2666240	et	4	main
tegi	doc_516622545498_item	2666246	et	4	main
vea	doc_516622545498_item	2666247	et	4	main
1	doc_516622545498_item	2666248	et	2	main
korralik	doc_516622545498_item	2666249	et	3	main
kasvab	doc_516622545498_item	2666262	et	3	main
lapse	doc_516622545498_item	2666264	et	4	main
võib	doc_516622545498_item	2666266	et	3	main
välispoolt	doc_516622545498_item	2666269	et	4	main
kodust	doc_516622545498_item	2666270	et	4	main
seletuskiri	doc_516622545499_item	2666271	et	3	main
minu	doc_516622545499_item	2666272	et	3	main
ristmikul	doc_516622545499_item	2666287	et	4	main
auto	doc_516622545499_item	2666303	et	4	main
c	doc_516622545499_item	2666304	et	4	main
mõlkis	doc_516622545499_item	2666305	et	3	main
autole	doc_516622545499_item	2666306	et	3	main
sündmuse	doc_516622545499_item	2666308	et	3	main
arstid	doc_516622545499_item	2666332	et	4	main
tulevad	doc_516622545499_item	2666333	et	4	main
viis	doc_516622545499_item	2666339	et	4	main
aga	doc_516622545499_item	2666342	et	3	main
jäid	doc_516622545499_item	2666346	et	4	main
kontrolltöö	doc_516622545500_item	2666349	et	4	main
tuleviku	doc_516622545500_item	2666351	et	4	main
inimesed	doc_516622545500_item	2666352	et	3	main
nii	doc_516622545500_item	2666363	et	3	main
varem	doc_516622545500_item	2666366	et	4	main
varem	doc_516622545500_item	2666368	et	4	main
oli	doc_516622545500_item	2666369	et	3	main
vaja	doc_516622545500_item	2666370	et	4	main
minna	doc_516622545500_item	2666371	et	3	main
ja	doc_516622545500_item	2666376	et	3	main
kätte	doc_516622545500_item	2666379	et	4	main
ei	doc_516622545500_item	2666380	et	4	main
saa	doc_516622545500_item	2666381	et	4	main
aga	doc_516622545500_item	2666382	et	3	main
praegu	doc_516622545500_item	2666383	et	3	main
leida	doc_516622545500_item	2666389	et	3	main
mõtlen	doc_516622545500_item	2666392	et	3	main
variante	doc_516622545500_item	2666399	et	3	main
istuvad	doc_516622545500_item	2666400	et	4	main
ja	doc_516622545500_item	2666402	et	3	main
otsivad	doc_516622545500_item	2666403	et	4	main
oma	doc_516622545500_item	2666421	et	4	main
mina	doc_516622545500_item	2666428	et	4	main
tean	doc_516622545500_item	2666429	et	3	main
palju	doc_516622545500_item	2666430	et	4	main
firmat	doc_516622545500_item	2666431	et	3	main
ma	doc_516622545500_item	2666436	et	3	main
kõik	doc_516622545500_item	2666441	et	4	main
firma	doc_516622545500_item	2666450	et	4	main
kuidas	doc_516622545500_item	2666454	et	3	main
arvan	doc_516622545500_item	2666459	et	3	main
et	doc_516622545500_item	2666460	et	3	main
elu	doc_516622545500_item	2666469	et	4	main
karistused	doc_516622545500_item	2666475	et	4	main
sa	doc_516622545500_item	2666516	et	3	main
sõidad	doc_516622545500_item	2666517	et	3	main
koer	doc_516622545499_item	2666280	et	3	main
oravat	doc_516622545499_item	2666282	et	3	main
hakkas	doc_516622545499_item	2666284	et	3	main
teda	doc_516622545499_item	2666286	et	4	main
autot	doc_516622545499_item	2666290	et	3	main
jalgratur	doc_516622545499_item	2666292	et	4	main
jalgratur	doc_516622545499_item	2666294	et	4	main
ja	doc_516622545499_item	2666296	et	3	main
b	doc_516622545499_item	2666298	et	4	main
sõitis	doc_516622545499_item	2666299	et	3	main
temale	doc_516622545499_item	2666300	et	3	main
otsa	doc_516622545499_item	2666301	et	4	main
b	doc_516622545499_item	2666307	et	4	main
auto	doc_516622545499_item	2666329	et	4	main
alla	doc_516622545499_item	2666330	et	3	main
lõpuks	doc_516622545499_item	2666337	et	4	main
kiirabi	doc_516622545499_item	2666338	et	4	main
teised	doc_516622545499_item	2666343	et	4	main
osalejad	doc_516622545499_item	2666345	et	4	main
politsei	doc_516622545499_item	2666348	et	4	main
kas	doc_516622545500_item	2666350	et	3	main
loevad	doc_516622545500_item	2666353	et	3	main
et	doc_516622545500_item	2666357	et	3	main
inimesed	doc_516622545500_item	2666359	et	3	main
loe	doc_516622545500_item	2666361	et	4	main
nagu	doc_516622545500_item	2666365	et	3	main
istuda	doc_516622545500_item	2666374	et	3	main
sest	doc_516622545500_item	2666378	et	4	main
võib	doc_516622545500_item	2666388	et	3	main
lihtsemaid	doc_516622545500_item	2666398	et	4	main
kodus	doc_516622545500_item	2666401	et	4	main
internetist	doc_516622545500_item	2666404	et	4	main
aga	doc_516622545500_item	2666405	et	3	main
vanad	doc_516622545500_item	2666406	et	3	main
inimesed	doc_516622545500_item	2666407	et	3	main
on	doc_516622545500_item	2666425	et	4	main
raske	doc_516622545500_item	2666427	et	4	main
bankroti	doc_516622545500_item	2666435	et	4	main
läbi	doc_516622545500_item	2666443	et	4	main
tööjõud	doc_516622545500_item	2666447	et	4	main
on	doc_516622545500_item	2666449	et	4	main
tööpartnirid	doc_516622545500_item	2666451	et	4	main
saaks	doc_516622545500_item	2666455	et	3	main
kuritegevust	doc_516622545500_item	2666457	et	4	main
rohkem	doc_516622545500_item	2666462	et	4	main
teha	doc_516622545500_item	2666472	et	3	main
kõik	doc_516622545500_item	2666521	et	4	main
vaatavad	doc_516622545500_item	2666523	et	4	main
sõltub	doc_516622545500_item	2666535	et	3	main
elad	doc_516622545500_item	2666539	et	3	main
sa	doc_516622545500_item	2666541	et	3	main
vaja	doc_516622545500_item	2666544	et	4	main
kui	doc_516622545500_item	2666547	et	3	main
jõudu	doc_516622545500_item	2666553	et	4	main
end	doc_516622545500_item	2666556	et	4	main
mingi	doc_516622545500_item	2666560	et	4	main
haigus	doc_516622545500_item	2666561	et	4	main
siis	doc_516622545500_item	2666562	et	3	main
kiiresti	doc_516622545500_item	2666563	et	3	main
loetakse	doc_516622545500_item	2666571	et	3	main
varem	doc_516622545500_item	2666576	et	4	main
arvan	doc_516622545500_item	2666578	et	3	main
tänapäeval	doc_516622545500_item	2666580	et	3	main
sest	doc_516622545500_item	2666583	et	4	main
internet	doc_516622545500_item	2666587	et	4	main
on	doc_516622545500_item	2666593	et	4	main
ajaviite	doc_516622545500_item	2666603	et	4	main
inimene	doc_516622545500_item	2666616	et	3	main
vaja	doc_516622545500_item	2666639	et	4	main
hästi	doc_516622545500_item	2666646	et	3	main
läheb	doc_516622545500_item	2666659	et	3	main
erinevaid	doc_516622545501_item	2666690	et	4	main
spordi	doc_516622545501_item	2666702	et	4	main
parandab	doc_516622545501_item	2666704	et	3	main
mobiiltelefonita	doc_516622545501_item	2666718	et	3	main
ilma	doc_516622545501_item	2666719	et	4	main
elada	doc_516622545501_item	2666720	et	3	main
c	doc_516622545499_item	2666322	et	4	main
ei	doc_516622545499_item	2666323	et	4	main
hoidnud	doc_516622545499_item	2666324	et	4	main
normaalset	doc_516622545499_item	2666325	et	3	main
pikivahet	doc_516622545499_item	2666326	et	3	main
jalgratur	doc_516622545499_item	2666327	et	4	main
jäi	doc_516622545499_item	2666328	et	3	main
sai	doc_516622545499_item	2666335	et	4	main
vigastada	doc_516622545499_item	2666336	et	3	main
ära	doc_516622545499_item	2666340	et	4	main
ootama	doc_516622545499_item	2666347	et	3	main
ma	doc_516622545500_item	2666355	et	3	main
praegu	doc_516622545500_item	2666358	et	3	main
raamatud	doc_516622545500_item	2666362	et	4	main
sest	doc_516622545500_item	2666367	et	4	main
raamatukogus	doc_516622545500_item	2666375	et	4	main
lihtsam	doc_516622545500_item	2666385	et	4	main
internetis	doc_516622545500_item	2666390	et	4	main
tulevikus	doc_516622545500_item	2666394	et	4	main
inimesed	doc_516622545500_item	2666396	et	3	main
ikkagi	doc_516622545500_item	2666408	et	4	main
käima	doc_516622545500_item	2666414	et	4	main
mõtlema	doc_516622545500_item	2666417	et	3	main
kes	doc_516622545500_item	2666419	et	4	main
asutab	doc_516622545500_item	2666420	et	3	main
firma	doc_516622545500_item	2666422	et	4	main
läksit	doc_516622545500_item	2666434	et	4	main
peab	doc_516622545500_item	2666440	et	4	main
hästi	doc_516622545500_item	2666442	et	3	main
kes	doc_516622545500_item	2666448	et	4	main
meie	doc_516622545500_item	2666468	et	4	main
vaja	doc_516622545500_item	2666471	et	4	main
rangeimad	doc_516622545500_item	2666474	et	4	main
siis	doc_516622545500_item	2666476	et	3	main
olla	doc_516622545500_item	2666478	et	3	main
kurjategija	doc_516622545500_item	2666479	et	4	main
kardab	doc_516622545500_item	2666480	et	4	main
ja	doc_516622545500_item	2666481	et	3	main
tema	doc_516622545500_item	2666482	et	4	main
ei	doc_516622545500_item	2666483	et	4	main
lähe	doc_516622545500_item	2666484	et	4	main
rohkem	doc_516622545500_item	2666485	et	4	main
kuritegelikke	doc_516622545500_item	2666486	et	3	main
teele	doc_516622545500_item	2666487	et	3	main
millised	doc_516622545500_item	2666488	et	3	main
autod	doc_516622545500_item	2666489	et	3	main
teile	doc_516622545500_item	2666490	et	4	main
meeldivad	doc_516622545500_item	2666491	et	4	main
mulle	doc_516622545500_item	2666492	et	4	main
meeldivad	doc_516622545500_item	2666493	et	4	main
uued	doc_516622545500_item	2666494	et	3	main
autod	doc_516622545500_item	2666495	et	3	main
neid	doc_516622545500_item	2666496	et	4	main
on	doc_516622545500_item	2666497	et	4	main
praegu	doc_516622545500_item	2666498	et	3	main
nii	doc_516622545500_item	2666499	et	3	main
palju	doc_516622545500_item	2666500	et	4	main
et	doc_516622545500_item	2666501	et	3	main
tahan	doc_516622545500_item	2666502	et	3	main
kõike	doc_516622545500_item	2666503	et	4	main
saada	doc_516622545500_item	2666504	et	4	main
meeldivad	doc_516622545500_item	2666505	et	4	main
kõige	doc_516622545500_item	2666506	et	4	main
kallimad	doc_516622545500_item	2666507	et	4	main
mõelda	doc_516622545500_item	2666444	et	4	main
reklaami	doc_516622545500_item	2666452	et	4	main
ma	doc_516622545500_item	2666458	et	3	main
on	doc_516622545500_item	2666464	et	4	main
politseinike	doc_516622545500_item	2666465	et	3	main
seda	doc_516622545500_item	2666466	et	3	main
on	doc_516622545500_item	2666470	et	4	main
väga	doc_516622545500_item	2666473	et	3	main
sest	doc_516622545500_item	2666508	et	4	main
need	doc_516622545500_item	2666509	et	3	main
eluiga	doc_516622545500_item	2666533	et	4	main
kõik	doc_516622545500_item	2666534	et	4	main
sööd	doc_516622545500_item	2666542	et	3	main
õige	doc_516622545500_item	2666545	et	4	main
toituda	doc_516622545500_item	2666546	et	3	main
spordiga	doc_516622545500_item	2666550	et	3	main
on	doc_516622545500_item	2666554	et	4	main
kui	doc_516622545500_item	2666558	et	3	main
arsti	doc_516622545500_item	2666566	et	4	main
juurde	doc_516622545500_item	2666567	et	4	main
minna	doc_516622545500_item	2666568	et	3	main
kas	doc_516622545500_item	2666569	et	3	main
tänapäeval	doc_516622545500_item	2666570	et	3	main
vähem	doc_516622545500_item	2666582	et	4	main
maailm	doc_516622545500_item	2666584	et	3	main
eelistavad	doc_516622545500_item	2666602	et	4	main
ole	doc_516622545500_item	2666606	et	4	main
loe	doc_516622545500_item	2666611	et	4	main
siis	doc_516622545500_item	2666612	et	3	main
peab	doc_516622545500_item	2666617	et	4	main
rohkem	doc_516622545500_item	2666618	et	4	main
lugeda	doc_516622545500_item	2666619	et	3	main
muidu	doc_516622545500_item	2666620	et	3	main
kõige	doc_516622545500_item	2666511	et	4	main
turvalised	doc_516622545500_item	2666512	et	4	main
ja	doc_516622545500_item	2666513	et	3	main
kvaliteetsed	doc_516622545500_item	2666514	et	3	main
kui	doc_516622545500_item	2666515	et	3	main
oma	doc_516622545500_item	2666518	et	4	main
autoga	doc_516622545500_item	2666519	et	3	main
ja	doc_516622545500_item	2666520	et	3	main
kuidas	doc_516622545500_item	2666537	et	3	main
on	doc_516622545500_item	2666543	et	4	main
annab	doc_516622545500_item	2666552	et	3	main
hoidma	doc_516622545500_item	2666557	et	3	main
praegu	doc_516622545500_item	2666592	et	3	main
kohal	doc_516622545500_item	2666595	et	4	main
see	doc_516622545500_item	2666604	et	3	main
õige	doc_516622545500_item	2666607	et	4	main
kui	doc_516622545500_item	2666608	et	3	main
ta	doc_516622545500_item	2666621	et	4	main
millest	doc_516622545500_item	2666626	et	3	main
sõltub	doc_516622545500_item	2666627	et	3	main
firma	doc_516622545500_item	2666628	et	4	main
kõik	doc_516622545500_item	2666643	et	4	main
mõeldud	doc_516622545500_item	2666647	et	4	main
idee	doc_516622545500_item	2666649	et	4	main
kontrolltöö	doc_516622545501_item	2666661	et	4	main
taha	doc_516622545501_item	2666666	et	4	main
oma	doc_516622545501_item	2666667	et	4	main
kasulik	doc_516622545501_item	2666681	et	3	main
süüa	doc_516622545501_item	2666689	et	3	main
putru	doc_516622545501_item	2666691	et	4	main
ei	doc_516622545501_item	2666692	et	4	main
tarbida	doc_516622545501_item	2666699	et	3	main
sõpru	doc_516622545501_item	2666730	et	3	main
öelda	doc_516622545501_item	2666740	et	4	main
olen	doc_516622545501_item	2666745	et	3	main
ja	doc_516622545501_item	2666747	et	3	main
ilma	doc_516622545501_item	2666749	et	4	main
arvutita	doc_516622545501_item	2666750	et	4	main
saan	doc_516622545501_item	2666757	et	4	main
seal	doc_516622545501_item	2666759	et	4	main
oma	doc_516622545501_item	2666761	et	4	main
peab	doc_516622545502_item	2666764	et	4	main
hea	doc_516622545502_item	2666766	et	4	main
juht	doc_516622545502_item	2666767	et	3	main
inimene	doc_516622545502_item	2666777	et	3	main
oma	doc_516622545502_item	2666780	et	4	main
otsustusvõimeline	doc_516622545502_item	2666787	et	4	main
inimene	doc_516622545502_item	2666791	et	3	main
reaalsustaju	doc_516622545502_item	2666794	et	4	main
et	doc_516622545502_item	2666797	et	3	main
on	doc_516622545502_item	2666801	et	4	main
realist	doc_516622545502_item	2666802	et	4	main
täitma	doc_516622545502_item	2666821	et	3	main
lubadusi	doc_516622545502_item	2666824	et	3	main
oma	doc_516622545502_item	2666826	et	4	main
kes	doc_516622545502_item	2666834	et	4	main
ebaedukas	doc_516622545502_item	2666841	et	4	main
saavutamiseks	doc_516622545502_item	2666854	et	4	main
arvestada	doc_516622545502_item	2666857	et	3	main
aga	doc_516622545502_item	2666860	et	3	main
otsustama	doc_516622545502_item	2666864	et	3	main
otsustus	doc_516622545502_item	2666866	et	4	main
ma	doc_516622545502_item	2666867	et	3	main
arvan	doc_516622545502_item	2666868	et	3	main
et	doc_516622545502_item	2666869	et	3	main
juht	doc_516622545502_item	2666870	et	3	main
ei	doc_516622545502_item	2666871	et	4	main
vormitud	doc_516622545502_item	2666914	et	4	main
õmmeldud	doc_516622545502_item	2666919	et	4	main
on	doc_516622545502_item	2666921	et	4	main
ja	doc_516622545502_item	2666923	et	3	main
hea	doc_516622545502_item	2666925	et	4	main
mul	doc_516622545502_item	2666927	et	3	main
on	doc_516622545502_item	2666928	et	4	main
alustada	doc_516622545502_item	2666935	et	3	main
oma	doc_516622545502_item	2666936	et	4	main
on	doc_516622545502_item	2666943	et	4	main
ideed	doc_516622545502_item	2666946	et	4	main
keelt	doc_516622545502_item	2666949	et	4	main
et	doc_516622545502_item	2666957	et	3	main
vormi	doc_516622545502_item	2666964	et	4	main
meie	doc_516622545502_item	2666973	et	4	main
mõtlevad	doc_516622545500_item	2666525	et	4	main
kui	doc_516622545500_item	2666526	et	3	main
tore	doc_516622545500_item	2666527	et	3	main
mul	doc_516622545500_item	2666528	et	3	main
on	doc_516622545500_item	2666529	et	4	main
praegu	doc_516622545500_item	2666530	et	3	main
millest	doc_516622545500_item	2666531	et	3	main
sõltub	doc_516622545500_item	2666532	et	3	main
sellest	doc_516622545500_item	2666536	et	4	main
mida	doc_516622545500_item	2666540	et	4	main
tegeled	doc_516622545500_item	2666549	et	3	main
see	doc_516622545500_item	2666551	et	3	main
tekib	doc_516622545500_item	2666559	et	3	main
on	doc_516622545500_item	2666564	et	4	main
või	doc_516622545500_item	2666573	et	4	main
kui	doc_516622545500_item	2666575	et	3	main
ma	doc_516622545500_item	2666577	et	3	main
loetakse	doc_516622545500_item	2666581	et	3	main
muutunud	doc_516622545500_item	2666586	et	4	main
ja	doc_516622545500_item	2666588	et	3	main
asjad	doc_516622545500_item	2666591	et	3	main
esimesel	doc_516622545500_item	2666594	et	3	main
noor	doc_516622545500_item	2666596	et	3	main
inimene	doc_516622545500_item	2666597	et	3	main
ei	doc_516622545500_item	2666598	et	4	main
ei	doc_516622545500_item	2666610	et	4	main
edukus	doc_516622545500_item	2666629	et	4	main
firma	doc_516622545500_item	2666630	et	4	main
ennekõike	doc_516622545500_item	2666637	et	3	main
moodustada	doc_516622545500_item	2666640	et	3	main
on	doc_516622545500_item	2666644	et	4	main
äri	doc_516622545500_item	2666658	et	4	main
mida	doc_516622545501_item	2666662	et	4	main
inimene	doc_516622545501_item	2666664	et	3	main
tohi	doc_516622545501_item	2666693	et	4	main
suitsetada	doc_516622545501_item	2666694	et	3	main
ega	doc_516622545501_item	2666695	et	3	main
jooma	doc_516622545501_item	2666696	et	4	main
alkohol	doc_516622545501_item	2666697	et	3	main
narkootikumeid	doc_516622545501_item	2666700	et	4	main
veel	doc_516622545501_item	2666701	et	4	main
tegelemine	doc_516622545501_item	2666703	et	4	main
saa	doc_516622545501_item	2666717	et	4	main
ta	doc_516622545501_item	2666721	et	4	main
ma	doc_516622545501_item	2666726	et	3	main
leida	doc_516622545501_item	2666728	et	3	main
või	doc_516622545501_item	2666732	et	4	main
helistada	doc_516622545501_item	2666734	et	3	main
et	doc_516622545501_item	2666743	et	3	main
referaadit	doc_516622545501_item	2666755	et	4	main
milline	doc_516622545502_item	2666768	et	3	main
olema	doc_516622545502_item	2666770	et	4	main
hea	doc_516622545502_item	2666771	et	4	main
juht	doc_516622545502_item	2666772	et	3	main
töö	doc_516622545502_item	2666782	et	4	main
kes	doc_516622545502_item	2666792	et	4	main
juht	doc_516622545502_item	2666799	et	3	main
see	doc_516622545502_item	2666803	et	3	main
on	doc_516622545502_item	2666804	et	4	main
väga	doc_516622545502_item	2666805	et	3	main
tähtis	doc_516622545502_item	2666806	et	4	main
äritegevuses	doc_516622545502_item	2666807	et	4	main
alati	doc_516622545502_item	2666822	et	4	main
olema	doc_516622545502_item	2666825	et	4	main
mõnikord	doc_516622545502_item	2666831	et	3	main
on	doc_516622545502_item	2666835	et	4	main
peab	doc_516622545502_item	2666849	et	4	main
hoiduma	doc_516622545502_item	2666850	et	3	main
harjumustest	doc_516622545502_item	2666852	et	4	main
edu	doc_516622545502_item	2666853	et	4	main
tähtis	doc_516622545502_item	2666856	et	4	main
mõtlema	doc_516622545502_item	2666862	et	3	main
õige	doc_516622545502_item	2666865	et	4	main
olema	doc_516622545502_item	2666874	et	4	main
elegantselt	doc_516622545502_item	2666904	et	4	main
töörõivastuses	doc_516622545502_item	2666908	et	3	main
parem	doc_516622545502_item	2666929	et	4	main
äri	doc_516622545502_item	2666937	et	4	main
praegu	doc_516622545502_item	2666938	et	3	main
palju	doc_516622545502_item	2666944	et	4	main
omama	doc_516622545502_item	2666961	et	4	main
mõtlen	doc_516622545502_item	2666966	et	3	main
et	doc_516622545502_item	2666969	et	3	main
te	doc_516622545502_item	2666971	et	4	main
ajakirjade	doc_516622545502_item	2666976	et	3	main
on	doc_516622545502_item	2666979	et	4	main
tekstis	doc_516622545503_item	2666991	et	3	main
räägitud	doc_516622545503_item	2666993	et	4	main
arengust	doc_516622545503_item	2666995	et	3	main
usa-ga	doc_516622545503_item	2666998	et	3	main
rahandussektori	doc_516622545503_item	2667038	et	3	main
pangad	doc_516622545503_item	2667041	et	3	main
probleemidest	doc_516622545503_item	2667045	et	3	main
ei	doc_516622545500_item	2666622	et	4	main
saa	doc_516622545500_item	2666623	et	4	main
ilusti	doc_516622545500_item	2666624	et	3	main
rääkida	doc_516622545500_item	2666625	et	3	main
eelarvest	doc_516622545500_item	2666633	et	4	main
käivest	doc_516622545500_item	2666634	et	4	main
ja	doc_516622545500_item	2666635	et	3	main
kasumist	doc_516622545500_item	2666636	et	4	main
kui	doc_516622545500_item	2666642	et	3	main
ja	doc_516622545500_item	2666648	et	3	main
on	doc_516622545500_item	2666650	et	4	main
suurepärane	doc_516622545500_item	2666651	et	4	main
siis	doc_516622545500_item	2666652	et	3	main
saab	doc_516622545500_item	2666653	et	3	main
turustada	doc_516622545500_item	2666654	et	3	main
ma	doc_516622545500_item	2666655	et	3	main
arvan	doc_516622545500_item	2666656	et	3	main
et	doc_516622545500_item	2666657	et	3	main
tervise	doc_516622545501_item	2666668	et	3	main
heaks	doc_516622545501_item	2666669	et	4	main
esiteks	doc_516622545501_item	2666670	et	3	main
on	doc_516622545501_item	2666671	et	4	main
väga	doc_516622545501_item	2666672	et	3	main
vaja	doc_516622545501_item	2666673	et	4	main
jälgida	doc_516622545501_item	2666674	et	3	main
sellest	doc_516622545501_item	2666675	et	4	main
mida	doc_516622545501_item	2666676	et	4	main
me	doc_516622545501_item	2666677	et	4	main
sööme	doc_516622545501_item	2666678	et	4	main
on	doc_516622545501_item	2666679	et	4	main
väga	doc_516622545501_item	2666680	et	3	main
ise	doc_516622545501_item	2666665	et	4	main
palju	doc_516622545501_item	2666683	et	4	main
mis	doc_516622545501_item	2666685	et	4	main
sisaldab	doc_516622545501_item	2666686	et	3	main
vitamiinid	doc_516622545501_item	2666687	et	3	main
ja	doc_516622545501_item	2666688	et	3	main
voi	doc_516622545501_item	2666698	et	4	main
meie	doc_516622545501_item	2666705	et	4	main
tervis	doc_516622545501_item	2666706	et	3	main
ilma	doc_516622545501_item	2666707	et	4	main
milliste	doc_516622545501_item	2666708	et	3	main
leiutisteta	doc_516622545501_item	2666709	et	3	main
sa	doc_516622545501_item	2666710	et	3	main
vaja	doc_516622545501_item	2666723	et	4	main
et	doc_516622545501_item	2666725	et	3	main
saaks	doc_516622545501_item	2666727	et	3	main
oma	doc_516622545501_item	2666729	et	4	main
näiteks	doc_516622545501_item	2666733	et	4	main
kiirabil	doc_516622545501_item	2666735	et	3	main
või	doc_516622545501_item	2666736	et	4	main
politseiosakonnal	doc_516622545501_item	2666737	et	4	main
emale	doc_516622545501_item	2666742	et	3	main
korras	doc_516622545501_item	2666746	et	4	main
ja	doc_516622545501_item	2666756	et	3	main
internetil	doc_516622545501_item	2666760	et	4	main
sõpradega	doc_516622545501_item	2666762	et	3	main
on	doc_516622545502_item	2666775	et	4	main
ja	doc_516622545502_item	2666789	et	3	main
omab	doc_516622545502_item	2666793	et	3	main
arvan	doc_516622545502_item	2666796	et	3	main
kinnised	doc_516622545502_item	2666836	et	4	main
kinnine	doc_516622545502_item	2666837	et	3	main
juht	doc_516622545502_item	2666838	et	3	main
see	doc_516622545502_item	2666839	et	3	main
või	doc_516622545502_item	2666845	et	4	main
on	doc_516622545502_item	2666855	et	4	main
pea	doc_516622545502_item	2666872	et	4	main
tähelepanu	doc_516622545502_item	2666875	et	4	main
ei	doc_516622545502_item	2666916	et	4	main
kontorisse	doc_516622545502_item	2666918	et	3	main
rõivad	doc_516622545502_item	2666920	et	3	main
jätavad	doc_516622545502_item	2666924	et	3	main
me	doc_516622545502_item	2666939	et	4	main
õppime	doc_516622545502_item	2666948	et	4	main
inimestega	doc_516622545502_item	2666952	et	3	main
sest	doc_516622545502_item	2666955	et	4	main
head	doc_516622545502_item	2666962	et	4	main
füüsilist	doc_516622545502_item	2666963	et	3	main
tulevikus	doc_516622545502_item	2666970	et	4	main
näete	doc_516622545502_item	2666972	et	3	main
nägusid	doc_516622545502_item	2666974	et	4	main
kaantel	doc_516622545502_item	2666977	et	3	main
edu	doc_516622545502_item	2666981	et	4	main
artikli	doc_516622545503_item	2666989	et	3	main
ja	doc_516622545503_item	2666996	et	3	main
ajal	doc_516622545503_item	2667024	et	4	main
meie	doc_516622545503_item	2667026	et	4	main
liikmed	doc_516622545503_item	2667027	et	3	main
olid	doc_516622545503_item	2667028	et	4	main
olulisemaid	doc_516622545503_item	2667032	et	4	main
rohkem	doc_516622545503_item	2667049	et	4	main
pangandussüsteemid	doc_516622545503_item	2667053	et	3	main
pangandussüsteem	doc_516622545503_item	2667055	et	3	main
it	doc_516622545503_item	2667061	et	4	main
areng	doc_516622545503_item	2667062	et	3	main
toetanud	doc_516622545503_item	2667069	et	4	main
on	doc_516622545503_item	2667078	et	4	main
mujal	doc_516622545503_item	2667089	et	3	main
kirjaniku	doc_516622545503_item	2667091	et	3	main
liitub	doc_516622545503_item	2667094	et	3	main
ja	doc_516622545503_item	2667098	et	3	main
siin	doc_516622545503_item	2667136	et	4	main
enamiku	doc_516622545503_item	2667137	et	3	main
ppangandus-	doc_516622545503_item	2667138	et	4	main
ning	doc_516622545503_item	2667141	et	3	main
eestis	doc_516622545503_item	2667157	et	3	main
puutuvad	doc_516622545503_item	2667161	et	4	main
on	doc_516622545503_item	2667168	et	4	main
filiaalid	doc_516622545503_item	2667170	et	3	main
ise	doc_516622545503_item	2667173	et	4	main
otseses	doc_516622545503_item	2667174	et	3	main
usa	doc_516622545503_item	2667176	et	4	main
süüa	doc_516622545501_item	2666682	et	3	main
juurvilju	doc_516622545501_item	2666684	et	3	main
ei	doc_516622545501_item	2666711	et	4	main
saaks	doc_516622545501_item	2666712	et	3	main
elada	doc_516622545501_item	2666713	et	3	main
esiteks	doc_516622545501_item	2666714	et	3	main
ma	doc_516622545501_item	2666715	et	3	main
ei	doc_516622545501_item	2666716	et	4	main
on	doc_516622545501_item	2666722	et	4	main
kuskil	doc_516622545501_item	2666731	et	3	main
või	doc_516622545501_item	2666738	et	4	main
lihtsalt	doc_516622545501_item	2666739	et	4	main
ma	doc_516622545501_item	2666744	et	3	main
teiseks	doc_516622545501_item	2666748	et	4	main
sealt	doc_516622545501_item	2666751	et	4	main
ma	doc_516622545501_item	2666752	et	3	main
võtan	doc_516622545501_item	2666753	et	3	main
infot	doc_516622545501_item	2666754	et	3	main
milline	doc_516622545502_item	2666763	et	3	main
olema	doc_516622545502_item	2666765	et	4	main
see	doc_516622545502_item	2666776	et	3	main
teab	doc_516622545502_item	2666779	et	3	main
äri	doc_516622545502_item	2666781	et	4	main
täpselt	doc_516622545502_item	2666783	et	4	main
see	doc_516622545502_item	2666784	et	3	main
aus	doc_516622545502_item	2666788	et	4	main
mind	doc_516622545501_item	2666724	et	4	main
minu	doc_516622545501_item	2666741	et	3	main
suhelda	doc_516622545501_item	2666758	et	4	main
peab	doc_516622545502_item	2666769	et	4	main
hea	doc_516622545502_item	2666773	et	4	main
juht	doc_516622545502_item	2666774	et	3	main
kes	doc_516622545502_item	2666778	et	4	main
on	doc_516622545502_item	2666785	et	4	main
muidugi	doc_516622545502_item	2666786	et	4	main
otsekohene	doc_516622545502_item	2666790	et	3	main
ma	doc_516622545502_item	2666795	et	3	main
hea	doc_516622545502_item	2666798	et	4	main
see	doc_516622545502_item	2666800	et	3	main
sest	doc_516622545502_item	2666808	et	4	main
iga	doc_516622545502_item	2666809	et	4	main
päev	doc_516622545502_item	2666810	et	3	main
tema	doc_516622545502_item	2666811	et	4	main
turg	doc_516622545502_item	2666812	et	3	main
muutub	doc_516622545502_item	2666813	et	3	main
teiseks	doc_516622545502_item	2666814	et	4	main
juht	doc_516622545502_item	2666815	et	3	main
peab	doc_516622545502_item	2666816	et	4	main
tundma	doc_516622545502_item	2666817	et	3	main
intuitiivselt	doc_516622545502_item	2666818	et	4	main
turgu	doc_516622545502_item	2666819	et	4	main
peab	doc_516622545502_item	2666820	et	4	main
oma	doc_516622545502_item	2666823	et	4	main
ja	doc_516622545502_item	2666829	et	3	main
kohtuvad	doc_516622545502_item	2666832	et	4	main
inimesed	doc_516622545502_item	2666833	et	3	main
juht	doc_516622545502_item	2666842	et	3	main
ta	doc_516622545502_item	2666843	et	4	main
ei	doc_516622545502_item	2666844	et	4	main
kolleegide	doc_516622545502_item	2666858	et	3	main
pärast	doc_516622545502_item	2666861	et	4	main
ja	doc_516622545502_item	2666903	et	3	main
riietatud	doc_516622545502_item	2666905	et	4	main
päevases	doc_516622545502_item	2666907	et	4	main
on	doc_516622545502_item	2666909	et	4	main
kostüümid	doc_516622545502_item	2666911	et	3	main
ja	doc_516622545502_item	2666912	et	3	main
sobi	doc_516622545502_item	2666917	et	4	main
mulje	doc_516622545502_item	2666926	et	4	main
me	doc_516622545502_item	2666933	et	4	main
tahame	doc_516622545502_item	2666934	et	3	main
meil	doc_516622545502_item	2666942	et	4	main
me	doc_516622545502_item	2666947	et	4	main
vajalike	doc_516622545502_item	2666951	et	3	main
tegeleme	doc_516622545502_item	2666953	et	3	main
ja	doc_516622545502_item	2666967	et	3	main
tuntud	doc_516622545502_item	2666975	et	4	main
aga	doc_516622545502_item	2666983	et	3	main
on	doc_516622545502_item	2666985	et	4	main
p	doc_516622545502_item	2666988	et	4	main
toetada	doc_516622545503_item	2667021	et	3	main
tollal	doc_516622545503_item	2667023	et	3	main
paljud	doc_516622545503_item	2667025	et	3	main
juba	doc_516622545503_item	2667029	et	3	main
aktiivselt	doc_516622545503_item	2667030	et	4	main
olnud	doc_516622545503_item	2667034	et	4	main
pangandus-	doc_516622545503_item	2667036	et	3	main
ja	doc_516622545503_item	2667037	et	3	main
eesti	doc_516622545503_item	2667040	et	4	main
said	doc_516622545503_item	2667042	et	4	main
saavutanud	doc_516622545503_item	2667048	et	4	main
samuti	doc_516622545503_item	2667058	et	3	main
tt	doc_516622545503_item	2667070	et	4	main
hariduse	doc_516622545503_item	2667071	et	3	main
tänu	doc_516622545503_item	2667075	et	4	main
sellele	doc_516622545503_item	2667076	et	4	main
tegevuses	doc_516622545502_item	2666827	et	4	main
visa	doc_516622545502_item	2666828	et	4	main
sihikindel	doc_516622545502_item	2666830	et	3	main
on	doc_516622545502_item	2666840	et	4	main
juhtida	doc_516622545502_item	2666846	et	4	main
firmat	doc_516622545502_item	2666847	et	3	main
tippjuht	doc_516622545502_item	2666848	et	3	main
kahjulikest	doc_516622545502_item	2666851	et	3	main
nõuannetega	doc_516622545502_item	2666859	et	3	main
ja	doc_516622545502_item	2666863	et	3	main
alati	doc_516622545502_item	2666873	et	4	main
keskpunktis	doc_516622545502_item	2666876	et	3	main
muidugi	doc_516622545502_item	2666877	et	4	main
hea	doc_516622545502_item	2666878	et	4	main
juht	doc_516622545502_item	2666879	et	3	main
see	doc_516622545502_item	2666880	et	3	main
on	doc_516622545502_item	2666881	et	4	main
imineme	doc_516622545502_item	2666882	et	4	main
kellel	doc_516622545502_item	2666883	et	4	main
on	doc_516622545502_item	2666884	et	4	main
kõrgharidus	doc_516622545502_item	2666885	et	3	main
kes	doc_516622545502_item	2666886	et	4	main
valdab	doc_516622545502_item	2666887	et	3	main
keelt	doc_516622545502_item	2666888	et	4	main
ja	doc_516622545502_item	2666889	et	3	main
andunud	doc_516622545502_item	2666890	et	4	main
oma	doc_516622545502_item	2666891	et	4	main
tööle	doc_516622545502_item	2666892	et	3	main
juht	doc_516622545502_item	2666893	et	3	main
peab	doc_516622545502_item	2666894	et	4	main
head	doc_516622545502_item	2666896	et	4	main
füüsilist	doc_516622545502_item	2666897	et	3	main
omama	doc_516622545502_item	2666895	et	4	main
vormi	doc_516622545502_item	2666898	et	4	main
ja	doc_516622545502_item	2666899	et	3	main
peab	doc_516622545502_item	2666900	et	4	main
olema	doc_516622545502_item	2666901	et	4	main
lõhnastatud	doc_516622545502_item	2666902	et	4	main
meie	doc_516622545502_item	2666906	et	4	main
leidnud	doc_516622545502_item	2666910	et	4	main
kostüümikleidid	doc_516622545502_item	2666913	et	3	main
trikotaaždžemprid	doc_516622545502_item	2666915	et	2	main
korrektsed	doc_516622545502_item	2666922	et	3	main
hea	doc_516622545502_item	2666930	et	4	main
sõbranna	doc_516622545502_item	2666931	et	4	main
kellega	doc_516622545502_item	2666932	et	3	main
õppime	doc_516622545502_item	2666940	et	4	main
aga	doc_516622545502_item	2666941	et	3	main
head	doc_516622545502_item	2666945	et	4	main
suhtleme	doc_516622545502_item	2666950	et	3	main
spordiga	doc_516622545502_item	2666954	et	3	main
teame	doc_516622545502_item	2666956	et	3	main
hea	doc_516622545502_item	2666958	et	4	main
juht	doc_516622545502_item	2666959	et	3	main
peab	doc_516622545502_item	2666960	et	4	main
ma	doc_516622545502_item	2666965	et	3	main
loodan	doc_516622545502_item	2666968	et	3	main
see	doc_516622545502_item	2666978	et	3	main
saladused	doc_516622545502_item	2666982	et	3	main
kõikidel	doc_516622545502_item	2666984	et	4	main
omad	doc_516622545502_item	2666986	et	4	main
arvamused	doc_516622545502_item	2666987	et	3	main
oli	doc_516622545503_item	2666992	et	3	main
eesti	doc_516622545503_item	2666994	et	4	main
suhetest	doc_516622545503_item	2666997	et	3	main
ja	doc_516622545503_item	2666999	et	3	main
teiste	doc_516622545503_item	2667000	et	4	main
investoritega	doc_516622545503_item	2667001	et	4	main
kõik	doc_516622545503_item	2667002	et	4	main
hakkas	doc_516622545503_item	2667003	et	3	main
arenema	doc_516622545503_item	2667004	et	3	main
umbes	doc_516622545503_item	2667005	et	4	main
10	doc_516622545503_item	2667006	et	2	main
aastat	doc_516622545503_item	2667007	et	3	main
tagasi	doc_516622545503_item	2667008	et	3	main
kui	doc_516622545503_item	2667009	et	3	main
oli	doc_516622545503_item	2667010	et	3	main
loodud	doc_516622545503_item	2667011	et	4	main
acce	doc_516622545503_item	2667012	et	4	main
kuid	doc_516622545503_item	2667013	et	4	main
ikkagi	doc_516622545503_item	2667014	et	4	main
sinne	doc_516622545503_item	2667015	et	4	main
amerika	doc_516622545503_item	2667016	et	4	main
ärikogud	doc_516622545503_item	2667017	et	3	main
ei	doc_516622545503_item	2667018	et	4	main
seda	doc_516622545503_item	2667020	et	3	main
tahtnud	doc_516622545503_item	2667019	et	4	main
äritegevuses	doc_516622545503_item	2667031	et	4	main
eesti	doc_516622545503_item	2667035	et	4	main
üle	doc_516622545503_item	2667043	et	3	main
on	doc_516622545503_item	2667047	et	4	main
paljud	doc_516622545503_item	2667051	et	3	main
meelitab	doc_516622545503_item	2667056	et	3	main
välisinvestoreidbr	doc_516622545503_item	2667057	et	4	main
on	doc_516622545503_item	2667059	et	4	main
aasta	doc_516622545503_item	2667065	et	4	main
meil	doc_516622545503_item	2667077	et	4	main
on	doc_516622545503_item	2667082	et	4	main
arvuti-	doc_516622545503_item	2667084	et	4	main
minu	doc_516622545502_item	2666980	et	3	main
kokkuvõte	doc_516622545503_item	2666990	et	3	main
aga	doc_516622545503_item	2667022	et	3	main
muudatusi	doc_516622545503_item	2667033	et	3	main
stabiliseerimine	doc_516622545503_item	2667039	et	4	main
lühiajalistest	doc_516622545503_item	2667044	et	4	main
ja	doc_516622545503_item	2667046	et	3	main
praegune	doc_516622545503_item	2667054	et	3	main
10	doc_516622545503_item	2667064	et	2	main
jooksul	doc_516622545503_item	2667066	et	4	main
on	doc_516622545503_item	2667067	et	4	main
eesti	doc_516622545503_item	2667068	et	4	main
kasvu	doc_516622545503_item	2667072	et	4	main
ja	doc_516622545503_item	2667073	et	3	main
rohkem	doc_516622545503_item	2667083	et	4	main
ja	doc_516622545503_item	2667085	et	3	main
kui	doc_516622545503_item	2667087	et	3	main
maailmas	doc_516622545503_item	2667090	et	3	main
eesti	doc_516622545503_item	2667093	et	4	main
ta	doc_516622545503_item	2667100	et	4	main
ei	doc_516622545503_item	2667101	et	4	main
suuda	doc_516622545503_item	2667102	et	4	main
säilitada	doc_516622545503_item	2667103	et	3	main
oma	doc_516622545503_item	2667104	et	4	main
arengut	doc_516622545503_item	2667105	et	3	main
põhjuseks	doc_516622545503_item	2667106	et	3	main
on	doc_516622545503_item	2667107	et	4	main
see	doc_516622545503_item	2667108	et	3	main
te	doc_516622545503_item	2667109	et	4	main
eesti	doc_516622545503_item	2667110	et	4	main
on	doc_516622545503_item	2667111	et	4	main
end	doc_516622545503_item	2667112	et	4	main
juba	doc_516622545503_item	2667113	et	3	main
üliliia	doc_516622545503_item	2667114	et	3	main
reguleerinud	doc_516622545503_item	2667115	et	4	main
ja	doc_516622545503_item	2667116	et	3	main
seadused	doc_516622545503_item	2667117	et	3	main
ja	doc_516622545503_item	2667118	et	3	main
reeglid	doc_516622545503_item	2667119	et	3	main
on	doc_516622545503_item	2667120	et	4	main
arengutbr	doc_516622545503_item	2667124	et	4	main
ja	doc_516622545503_item	2667139	et	3	main
tulla	doc_516622545503_item	2667152	et	3	main
ja	doc_516622545503_item	2667153	et	3	main
end	doc_516622545503_item	2667154	et	4	main
seoses	doc_516622545503_item	2667165	et	4	main
ole	doc_516622545503_item	2667181	et	4	main
usa	doc_516622545503_item	2667185	et	4	main
tulekut	doc_516622545503_item	2667187	et	3	main
eestis	doc_516622545503_item	2667192	et	3	main
kasvab	doc_516622545503_item	2667201	et	3	main
liitumisprotsess	doc_516622545503_item	2667203	et	3	main
on	doc_516622545503_item	2667205	et	4	main
hinnad	doc_516622545503_item	2667223	et	3	main
geograafiline	doc_516622545503_item	2667238	et	4	main
minu	doc_516622545504_item	2667243	et	3	main
mu	doc_516622545504_item	2667245	et	3	main
eriala	doc_516622545504_item	2667246	et	4	main
tallinna	doc_516622545504_item	2667252	et	4	main
põnev	doc_516622545504_item	2667263	et	3	main
informatsiooni	doc_516622545504_item	2667284	et	4	main
praegu	doc_516622545504_item	2667286	et	3	main
mõtlen	doc_516622545504_item	2667306	et	3	main
kui	doc_516622545503_item	2667050	et	3	main
ameerika	doc_516622545503_item	2667052	et	3	main
hea	doc_516622545503_item	2667060	et	4	main
viimase	doc_516622545503_item	2667063	et	3	main
arengut	doc_516622545503_item	2667074	et	3	main
tekkinud	doc_516622545503_item	2667079	et	4	main
riik	doc_516622545503_item	2667080	et	3	main
kusagil	doc_516622545503_item	2667088	et	3	main
arvates	doc_516622545503_item	2667092	et	4	main
euroopaga	doc_516622545503_item	2667095	et	3	main
võib-olla	doc_516622545503_item	2667099	et	3	main
ka	doc_516622545503_item	2667121	et	3	main
on	doc_516622545503_item	2667130	et	4	main
rootsi	doc_516622545503_item	2667131	et	4	main
ja	doc_516622545503_item	2667132	et	3	main
soome	doc_516622545503_item	2667133	et	3	main
viisid	doc_516622545503_item	2667142	et	4	main
sellisele	doc_516622545503_item	2667144	et	4	main
arengutasemele	doc_516622545503_item	2667145	et	3	main
et	doc_516622545503_item	2667146	et	3	main
ameeriklased	doc_516622545503_item	2667147	et	3	main
mugavalt	doc_516622545503_item	2667155	et	4	main
tunda	doc_516622545503_item	2667156	et	3	main
30	doc_516622545503_item	2667158	et	2	main
ameerika	doc_516622545503_item	2667162	et	3	main
igasuguses	doc_516622545503_item	2667164	et	3	main
või	doc_516622545503_item	2667172	et	4	main
suhtes	doc_516622545503_item	2667175	et	4	main
turuga	doc_516622545503_item	2667177	et	3	main
praegu	doc_516622545503_item	2667178	et	3	main
aga	doc_516622545503_item	2667179	et	3	main
ei	doc_516622545503_item	2667180	et	4	main
massilist	doc_516622545503_item	2667184	et	4	main
on	doc_516622545503_item	2667193	et	4	main
loodetavasti	doc_516622545503_item	2667197	et	3	main
vastu	doc_516622545503_item	2667199	et	3	main
kus	doc_516622545503_item	2667081	et	3	main
internetikasutajaid	doc_516622545503_item	2667086	et	3	main
liiga	doc_516622545503_item	2667096	et	4	main
vara	doc_516622545503_item	2667097	et	4	main
mis	doc_516622545503_item	2667122	et	4	main
kõige	doc_516622545503_item	2667125	et	4	main
investoriks	doc_516622545503_item	2667127	et	4	main
eesti	doc_516622545503_item	2667128	et	4	main
jaoks	doc_516622545503_item	2667129	et	4	main
nemad	doc_516622545503_item	2667134	et	3	main
it-süsteemi	doc_516622545503_item	2667140	et	4	main
võisid	doc_516622545503_item	2667150	et	4	main
juba	doc_516622545503_item	2667151	et	3	main
kuidagi	doc_516622545503_item	2667160	et	3	main
eriti	doc_516622545503_item	2667183	et	3	main
eestisse	doc_516622545503_item	2667188	et	4	main
pakkuvateks	doc_516622545503_item	2667190	et	4	main
sektoris	doc_516622545503_item	2667191	et	3	main
investeerimise	doc_516622545503_item	2667198	et	4	main
usa	doc_516622545503_item	2667233	et	4	main
ja	doc_516622545503_item	2667234	et	3	main
eesti	doc_516622545503_item	2667235	et	4	main
on	doc_516622545504_item	2667247	et	4	main
väga	doc_516622545504_item	2667248	et	3	main
pedagoogikaülikoolis	doc_516622545504_item	2667253	et	4	main
imagoloogia	doc_516622545504_item	2667256	et	4	main
minu	doc_516622545504_item	2667258	et	3	main
on	doc_516622545504_item	2667261	et	4	main
ja	doc_516622545504_item	2667264	et	3	main
huvitav	doc_516622545504_item	2667265	et	4	main
tegevustes	doc_516622545504_item	2667292	et	4	main
samas	doc_516622545504_item	2667304	et	4	main
ma	doc_516622545504_item	2667305	et	3	main
ja	doc_516622545504_item	2667310	et	3	main
see	doc_516622545504_item	2667315	et	3	main
ei	doc_516622545504_item	2667321	et	4	main
mind	doc_516622545504_item	2667323	et	4	main
tean	doc_516622545504_item	2667328	et	3	main
kindlalt	doc_516622545504_item	2667329	et	4	main
et	doc_516622545504_item	2667330	et	3	main
see	doc_516622545504_item	2667331	et	3	main
kuritegusid	doc_516622545505_item	2667340	et	4	main
madala	doc_516622545505_item	2667342	et	3	main
tõttu	doc_516622545505_item	2667344	et	4	main
olen	doc_516622545505_item	2667346	et	3	main
väidega	doc_516622545505_item	2667348	et	3	main
töökohti	doc_516622545505_item	2667354	et	4	main
raha	doc_516622545505_item	2667357	et	4	main
elutingimused	doc_516622545505_item	2667366	et	3	main
neid	doc_516622545505_item	2667368	et	4	main
peab	doc_516622545505_item	2667373	et	4	main
ise	doc_516622545505_item	2667375	et	4	main
eest	doc_516622545505_item	2667377	et	4	main
kaitsma	doc_516622545505_item	2667378	et	3	main
küll	doc_516622545505_item	2667381	et	4	main
võib	doc_516622545505_item	2667387	et	3	main
seda	doc_516622545505_item	2667398	et	3	main
võivad	doc_516622545505_item	2667409	et	4	main
olla	doc_516622545505_item	2667410	et	3	main
head	doc_516622545505_item	2667411	et	4	main
ei	doc_516622545505_item	2667415	et	4	main
ole	doc_516622545505_item	2667416	et	4	main
pidurdavad	doc_516622545503_item	2667123	et	4	main
olulisemaks	doc_516622545503_item	2667126	et	4	main
rajasid	doc_516622545503_item	2667135	et	4	main
eesti	doc_516622545503_item	2667143	et	4	main
ja	doc_516622545503_item	2667148	et	3	main
teised	doc_516622545503_item	2667149	et	4	main
ettevõtteid	doc_516622545503_item	2667159	et	3	main
turgude	doc_516622545503_item	2667163	et	3	main
50	doc_516622545503_item	2667166	et	2	main
firmat	doc_516622545503_item	2667167	et	3	main
kas	doc_516622545503_item	2667169	et	3	main
esindused	doc_516622545503_item	2667171	et	4	main
näha	doc_516622545503_item	2667182	et	3	main
firmade	doc_516622545503_item	2667186	et	3	main
ja	doc_516622545503_item	2667195	et	3	main
kui	doc_516622545503_item	2667202	et	3	main
el-ga	doc_516622545503_item	2667204	et	3	main
ametlikult	doc_516622545503_item	2667206	et	4	main
lõpule	doc_516622545503_item	2667207	et	3	main
viidudbr	doc_516622545503_item	2667208	et	4	main
kõige	doc_516622545503_item	2667209	et	4	main
olulisemaks	doc_516622545503_item	2667210	et	4	main
eesti	doc_516622545503_item	2667211	et	4	main
eksportkaubaartikkliks	doc_516622545503_item	2667212	et	4	main
peetakse	doc_516622545503_item	2667213	et	3	main
puiduturg	doc_516622545503_item	2667214	et	3	main
ameerika	doc_516622545503_item	2667215	et	3	main
puiduturg	doc_516622545503_item	2667216	et	3	main
on	doc_516622545503_item	2667217	et	4	main
muutlik	doc_516622545503_item	2667218	et	3	main
ning	doc_516622545503_item	2667219	et	3	main
praegu	doc_516622545503_item	2667220	et	3	main
on	doc_516622545503_item	2667221	et	4	main
välispartnerite	doc_516622545503_item	2667229	et	3	main
loomulikult	doc_516622545503_item	2667231	et	4	main
haugutav	doc_516622545503_item	2667237	et	4	main
huvitav	doc_516622545504_item	2667249	et	4	main
jaoks	doc_516622545504_item	2667259	et	4	main
juba	doc_516622545504_item	2667285	et	3	main
tööl	doc_516622545504_item	2667294	et	3	main
sellele	doc_516622545504_item	2667296	et	4	main
erialale	doc_516622545504_item	2667297	et	3	main
mul	doc_516622545504_item	2667298	et	3	main
on	doc_516622545504_item	2667299	et	4	main
suhelda	doc_516622545504_item	2667301	et	4	main
huvitavate	doc_516622545504_item	2667302	et	4	main
inimestega	doc_516622545504_item	2667303	et	3	main
peale	doc_516622545504_item	2667309	et	4	main
et	doc_516622545504_item	2667313	et	3	main
mida	doc_516622545504_item	2667317	et	4	main
ma	doc_516622545504_item	2667318	et	3	main
praegu	doc_516622545504_item	2667319	et	3	main
huvi	doc_516622545503_item	2667189	et	4	main
tootmine	doc_516622545503_item	2667194	et	4	main
turism	doc_516622545503_item	2667196	et	3	main
huvi	doc_516622545503_item	2667200	et	4	main
sealsed	doc_516622545503_item	2667222	et	3	main
tõusnd	doc_516622545503_item	2667225	et	4	main
andes	doc_516622545503_item	2667226	et	4	main
ajendi	doc_516622545503_item	2667228	et	3	main
vahel	doc_516622545503_item	2667236	et	4	main
olulisemaks	doc_516622545503_item	2667240	et	4	main
on	doc_516622545503_item	2667242	et	4	main
eriala	doc_516622545504_item	2667244	et	4	main
reklaami	doc_516622545504_item	2667254	et	4	main
ja	doc_516622545504_item	2667255	et	3	main
erialal	doc_516622545504_item	2667257	et	3	main
saan	doc_516622545504_item	2667287	et	4	main
ma	doc_516622545504_item	2667288	et	3	main
seda	doc_516622545504_item	2667289	et	3	main
kasutada	doc_516622545504_item	2667290	et	3	main
oma	doc_516622545504_item	2667291	et	4	main
tänu	doc_516622545504_item	2667295	et	4	main
võimalus	doc_516622545504_item	2667300	et	3	main
on	doc_516622545504_item	2667332	et	4	main
väga	doc_516622545504_item	2667333	et	3	main
palgaga	doc_516622545504_item	2667335	et	3	main
eriala	doc_516622545504_item	2667336	et	4	main
väidete	doc_516622545505_item	2667337	et	3	main
faktiliselt	doc_516622545505_item	2667361	et	4	main
neil	doc_516622545505_item	2667362	et	4	main
ole	doc_516622545505_item	2667364	et	4	main
inimene	doc_516622545505_item	2667372	et	3	main
peab	doc_516622545505_item	2667380	et	4	main
mis	doc_516622545505_item	2667385	et	4	main
temaga	doc_516622545505_item	2667386	et	3	main
on	doc_516622545505_item	2667391	et	4	main
tegema	doc_516622545505_item	2667399	et	3	main
on	doc_516622545505_item	2667401	et	4	main
soodumus	doc_516622545505_item	2667403	et	3	main
arvates	doc_516622545505_item	2667406	et	4	main
kes	doc_516622545505_item	2667413	et	4	main
võib	doc_516622545505_item	2667425	et	3	main
kuritegijaks	doc_516622545505_item	2667427	et	3	main
kooliharidusest	doc_516622545505_item	2667428	et	4	main
lähevad	doc_516622545505_item	2667433	et	3	main
lähevad	doc_516622545505_item	2667440	et	3	main
ja	doc_516622545505_item	2667447	et	3	main
kõrgharidust	doc_516622545505_item	2667453	et	4	main
rohkem	doc_516622545505_item	2667457	et	4	main
olla	doc_516622545505_item	2667458	et	3	main
jõukus	doc_516622545505_item	2667459	et	4	main
on	doc_516622545505_item	2667465	et	4	main
riigis	doc_516622545505_item	2667466	et	3	main
ei	doc_516622545505_item	2667474	et	4	main
arvates	doc_516622545505_item	2667480	et	4	main
või	doc_516622545505_item	2667492	et	4	main
mitte	doc_516622545505_item	2667493	et	3	main
ole	doc_516622545505_item	2667505	et	4	main
neile	doc_516622545505_item	2667510	et	4	main
aita	doc_516622545505_item	2667512	et	4	main
hakkavad	doc_516622545505_item	2667514	et	4	main
tapma	doc_516622545505_item	2667518	et	3	main
kui	doc_516622545505_item	2667528	et	3	main
kuritegevust	doc_516622545505_item	2667541	et	4	main
on	doc_516622545505_item	2667545	et	4	main
kuri	doc_516622545505_item	2667548	et	4	main
siis	doc_516622545505_item	2667549	et	3	main
selle	doc_516622545505_item	2667557	et	4	main
rangemad	doc_516622545505_item	2667579	et	4	main
varastab	doc_516622545505_item	2667593	et	3	main
siis	doc_516622545505_item	2667594	et	3	main
rajutakse	doc_516622545505_item	2667595	et	3	main
narkotikumit	doc_516622545505_item	2667602	et	4	main
karistused	doc_516622545505_item	2667608	et	4	main
aitavad	doc_516622545505_item	2667609	et	4	main
kuritegevust	doc_516622545505_item	2667611	et	4	main
mina	doc_516622545506_item	2667614	et	4	main
olen	doc_516622545506_item	2667618	et	3	main
töötamine	doc_516622545506_item	2667634	et	4	main
võimaluse	doc_516622545506_item	2667641	et	3	main
reisida	doc_516622545506_item	2667644	et	3	main
töötab	doc_516622545506_item	2667654	et	3	main
inimest	doc_516622545506_item	2667657	et	3	main
taas	doc_516622545503_item	2667224	et	3	main
ettevõtetele	doc_516622545503_item	2667227	et	3	main
otsinguks	doc_516622545503_item	2667230	et	3	main
on	doc_516622545503_item	2667232	et	4	main
kaugus	doc_516622545503_item	2667239	et	4	main
barjääriks	doc_516622545503_item	2667241	et	3	main
ma	doc_516622545504_item	2667250	et	3	main
õpin	doc_516622545504_item	2667251	et	3	main
see	doc_516622545504_item	2667260	et	3	main
väga	doc_516622545504_item	2667262	et	3	main
ja	doc_516622545504_item	2667266	et	3	main
see	doc_516622545504_item	2667267	et	3	main
on	doc_516622545504_item	2667268	et	4	main
see	doc_516622545504_item	2667269	et	3	main
mida	doc_516622545504_item	2667270	et	4	main
ma	doc_516622545504_item	2667271	et	3	main
tahan	doc_516622545504_item	2667272	et	3	main
teha	doc_516622545504_item	2667273	et	3	main
kogu	doc_516622545504_item	2667274	et	4	main
oma	doc_516622545504_item	2667275	et	4	main
elu	doc_516622545504_item	2667276	et	4	main
see	doc_516622545504_item	2667277	et	3	main
eriala	doc_516622545504_item	2667278	et	4	main
pakkub	doc_516622545504_item	2667279	et	4	main
mulle	doc_516622545504_item	2667280	et	4	main
väga	doc_516622545504_item	2667281	et	3	main
palju	doc_516622545504_item	2667282	et	4	main
kasuliku	doc_516622545504_item	2667283	et	3	main
ja	doc_516622545504_item	2667293	et	3	main
tean	doc_516622545504_item	2667311	et	3	main
kindlasti	doc_516622545504_item	2667312	et	3	main
just	doc_516622545504_item	2667314	et	3	main
eriala	doc_516622545504_item	2667316	et	4	main
õpin	doc_516622545504_item	2667320	et	3	main
palju	doc_516622545505_item	2667339	et	4	main
sooritatakse	doc_516622545505_item	2667341	et	3	main
ei	doc_516622545505_item	2667352	et	4	main
ei	doc_516622545505_item	2667355	et	4	main
ei	doc_516622545505_item	2667363	et	4	main
panevad	doc_516622545505_item	2667367	et	4	main
selles	doc_516622545505_item	2667369	et	4	main
raamises	doc_516622545505_item	2667370	et	4	main
ennast	doc_516622545505_item	2667374	et	4	main
kuritegude	doc_516622545505_item	2667376	et	3	main
ja	doc_516622545505_item	2667389	et	3	main
enesekaitsmises	doc_516622545505_item	2667393	et	3	main
siis	doc_516622545505_item	2667394	et	3	main
iga	doc_516622545505_item	2667395	et	4	main
inimene	doc_516622545505_item	2667396	et	3	main
geneetiline	doc_516622545505_item	2667402	et	3	main
see	doc_516622545505_item	2667430	et	3	main
teele	doc_516622545505_item	2667435	et	3	main
kas	doc_516622545505_item	2667438	et	3	main
kuritegelikule	doc_516622545505_item	2667441	et	3	main
sõltub	doc_516622545505_item	2667443	et	3	main
lapse	doc_516622545505_item	2667445	et	4	main
inimestel	doc_516622545505_item	2667449	et	3	main
olla	doc_516622545505_item	2667451	et	3	main
aga	doc_516622545505_item	2667454	et	3	main
meeldib	doc_516622545505_item	2667456	et	3	main
mida	doc_516622545505_item	2667463	et	4	main
kogusest	doc_516622545505_item	2667473	et	4	main
elu	doc_516622545505_item	2667478	et	4	main
minu	doc_516622545505_item	2667479	et	3	main
teise	doc_516622545505_item	2667490	et	4	main
murele	doc_516622545505_item	2667491	et	3	main
vangist	doc_516622545505_item	2667496	et	3	main
vabanenuid	doc_516622545505_item	2667497	et	4	main
nõus	doc_516622545505_item	2667501	et	4	main
vanglakaristus	doc_516622545505_item	2667519	et	3	main
paranda	doc_516622545505_item	2667522	et	4	main
mulle	doc_516622545505_item	2667523	et	4	main
tundub	doc_516622545505_item	2667524	et	3	main
see	doc_516622545505_item	2667525	et	3	main
süüdi	doc_516622545505_item	2667534	et	4	main
ta	doc_516622545505_item	2667536	et	4	main
rohkem	doc_516622545505_item	2667537	et	4	main
ei	doc_516622545505_item	2667538	et	4	main
kõigi	doc_516622545505_item	2667546	et	4	main
kodu	doc_516622545505_item	2667555	et	4	main
tagab	doc_516622545505_item	2667556	et	3	main
saada	doc_516622545505_item	2667576	et	4	main
kuritegijaks	doc_516622545505_item	2667577	et	3	main
mida	doc_516622545505_item	2667578	et	4	main
vähem	doc_516622545505_item	2667582	et	4	main
olen	doc_516622545505_item	2667584	et	3	main
käsi	doc_516622545505_item	2667596	et	4	main
ta	doc_516622545505_item	2667600	et	4	main
eluaegne	doc_516622545505_item	2667605	et	3	main
ja	doc_516622545506_item	2667617	et	3	main
kujundaja	doc_516622545506_item	2667620	et	4	main
mulle	doc_516622545506_item	2667621	et	4	main
ma	doc_516622545506_item	2667626	et	3	main
sellele	doc_516622545506_item	2667629	et	4	main
tööle	doc_516622545506_item	2667630	et	3	main
tunnen	doc_516622545506_item	2667631	et	3	main
ennast	doc_516622545506_item	2667632	et	4	main
vajalikuna	doc_516622545506_item	2667633	et	3	main
head	doc_516622545506_item	2667640	et	4	main
kui	doc_516622545506_item	2667647	et	3	main
väga	doc_516622545506_item	2667663	et	3	main
hakkama	doc_516622545506_item	2667665	et	3	main
oleme	doc_516622545506_item	2667667	et	3	main
rahul	doc_516622545506_item	2667669	et	4	main
kui	doc_516622545507_item	2667674	et	3	main
aus	doc_516622545507_item	2667676	et	4	main
ei	doc_516622545507_item	2667677	et	4	main
viietoaline	doc_516622545507_item	2667689	et	4	main
kõikidele	doc_516622545507_item	2667692	et	4	main
oma	doc_516622545504_item	2667307	et	4	main
tuleviku	doc_516622545504_item	2667308	et	4	main
jätta	doc_516622545504_item	2667322	et	3	main
ilma	doc_516622545504_item	2667324	et	4	main
leivata	doc_516622545504_item	2667325	et	3	main
just	doc_516622545504_item	2667326	et	3	main
vastupidi	doc_516622545504_item	2667327	et	3	main
kommenteerimine	doc_516622545505_item	2667338	et	4	main
elutaseme	doc_516622545505_item	2667343	et	3	main
selle	doc_516622545505_item	2667347	et	4	main
nõus	doc_516622545505_item	2667349	et	4	main
inimestel	doc_516622545505_item	2667350	et	3	main
kellel	doc_516622545505_item	2667351	et	4	main
ole	doc_516622545505_item	2667356	et	4	main
peavad	doc_516622545505_item	2667358	et	4	main
kuidagi	doc_516622545505_item	2667359	et	3	main
elama	doc_516622545505_item	2667360	et	3	main
p	doc_516622545505_item	2667379	et	4	main
keegi	doc_516622545505_item	2667382	et	4	main
ei	doc_516622545505_item	2667383	et	4	main
juhtuda	doc_516622545505_item	2667388	et	3	main
kui	doc_516622545505_item	2667390	et	3	main
vajadus	doc_516622545505_item	2667392	et	3	main
vanemad	doc_516622545505_item	2667412	et	4	main
sõprade	doc_516622545505_item	2667421	et	3	main
ta	doc_516622545505_item	2667424	et	4	main
sõltub	doc_516622545505_item	2667429	et	3	main
mitte	doc_516622545505_item	2667437	et	3	main
noored	doc_516622545505_item	2667439	et	3	main
rohkem	doc_516622545505_item	2667444	et	4	main
arenemisest	doc_516622545505_item	2667446	et	4	main
narkotikumit	doc_516622545505_item	2667462	et	4	main
politseinikke	doc_516622545505_item	2667467	et	3	main
on	doc_516622545505_item	2667470	et	4	main
rohkem	doc_516622545505_item	2667481	et	4	main
ja	doc_516622545505_item	2667485	et	3	main
riik	doc_516622545505_item	2667494	et	3	main
sellega	doc_516622545505_item	2667499	et	3	main
töökohta	doc_516622545505_item	2667506	et	4	main
ja	doc_516622545505_item	2667507	et	3	main
raha	doc_516622545505_item	2667508	et	4	main
ei	doc_516622545505_item	2667511	et	4	main
hea	doc_516622545504_item	2667334	et	4	main
ma	doc_516622545505_item	2667345	et	3	main
ole	doc_516622545505_item	2667353	et	4	main
valikut	doc_516622545505_item	2667365	et	3	main
iga	doc_516622545505_item	2667371	et	4	main
tea	doc_516622545505_item	2667384	et	4	main
peab	doc_516622545505_item	2667397	et	4	main
kuritegijatel	doc_516622545505_item	2667400	et	3	main
kuritegevusele	doc_516622545505_item	2667404	et	4	main
minu	doc_516622545505_item	2667405	et	3	main
et	doc_516622545505_item	2667407	et	3	main
lapsel	doc_516622545505_item	2667408	et	4	main
üldse	doc_516622545505_item	2667414	et	3	main
kuritegijad	doc_516622545505_item	2667417	et	3	main
vaid	doc_516622545505_item	2667418	et	3	main
kui	doc_516622545505_item	2667419	et	3	main
ta	doc_516622545505_item	2667420	et	4	main
all	doc_516622545505_item	2667423	et	3	main
noored	doc_516622545505_item	2667432	et	3	main
või	doc_516622545505_item	2667436	et	4	main
võiks	doc_516622545505_item	2667450	et	4	main
talle	doc_516622545505_item	2667455	et	4	main
ja	doc_516622545505_item	2667460	et	3	main
levima	doc_516622545505_item	2667461	et	3	main
rohkem	doc_516622545505_item	2667464	et	4	main
seda	doc_516622545505_item	2667468	et	3	main
turvalisem	doc_516622545505_item	2667469	et	4	main
sõltu	doc_516622545505_item	2667475	et	4	main
meie	doc_516622545505_item	2667476	et	4	main
sõltub	doc_516622545505_item	2667482	et	3	main
politseinike	doc_516622545505_item	2667483	et	3	main
kvalikfikatsioonist	doc_516622545505_item	2667484	et	4	main
ta	doc_516622545505_item	2667487	et	4	main
tundis	doc_516622545505_item	2667488	et	3	main
kaasa	doc_516622545505_item	2667489	et	4	main
peab	doc_516622545505_item	2667495	et	4	main
abistama	doc_516622545505_item	2667498	et	3	main
olen	doc_516622545505_item	2667500	et	3	main
sest	doc_516622545505_item	2667502	et	4	main
vabanemistel	doc_516622545505_item	2667503	et	4	main
ei	doc_516622545505_item	2667504	et	4	main
nad	doc_516622545505_item	2667513	et	3	main
jälle	doc_516622545505_item	2667515	et	3	main
varastama	doc_516622545505_item	2667516	et	3	main
ja	doc_516622545505_item	2667517	et	3	main
inimestest	doc_516622545505_item	2667527	et	3	main
ise	doc_516622545505_item	2667530	et	4	main
saab	doc_516622545505_item	2667531	et	3	main
aru	doc_516622545505_item	2667532	et	4	main
vaid	doc_516622545505_item	2667542	et	3	main
kui	doc_516622545505_item	2667543	et	3	main
peale	doc_516622545505_item	2667547	et	4	main
et	doc_516622545505_item	2667558	et	3	main
lapsest	doc_516622545505_item	2667559	et	4	main
kuritegija	doc_516622545505_item	2667588	et	4	main
teab	doc_516622545505_item	2667589	et	3	main
et	doc_516622545505_item	2667590	et	3	main
kui	doc_516622545505_item	2667591	et	3	main
ta	doc_516622545505_item	2667592	et	4	main
ta	doc_516622545505_item	2667604	et	4	main
töötan	doc_516622545506_item	2667615	et	3	main
väga	doc_516622545506_item	2667622	et	3	main
meeldib	doc_516622545506_item	2667623	et	3	main
millega	doc_516622545506_item	2667625	et	3	main
tänu	doc_516622545506_item	2667628	et	4	main
pool	doc_516622545506_item	2667643	et	4	main
nii	doc_516622545506_item	2667645	et	3	main
välismaal	doc_516622545506_item	2667648	et	4	main
see	doc_516622545506_item	2667650	et	3	main
perefirma	doc_516622545506_item	2667652	et	4	main
meil	doc_516622545506_item	2667653	et	4	main
vaatamata	doc_516622545506_item	2667659	et	4	main
sellele	doc_516622545506_item	2667660	et	4	main
minu	doc_516622545507_item	2667672	et	3	main
olla	doc_516622545507_item	2667675	et	3	main
rahulda	doc_516622545507_item	2667678	et	4	main
lasnamäel	doc_516622545507_item	2667682	et	3	main
kuuendal	doc_516622545507_item	2667685	et	3	main
mõju	doc_516622545505_item	2667422	et	4	main
saada	doc_516622545505_item	2667426	et	4	main
kas	doc_516622545505_item	2667431	et	3	main
kuritegelikule	doc_516622545505_item	2667434	et	3	main
teele	doc_516622545505_item	2667442	et	3	main
tahtmist	doc_516622545505_item	2667448	et	4	main
kaks	doc_516622545505_item	2667452	et	3	main
elu	doc_516622545505_item	2667471	et	4	main
politseinike	doc_516622545505_item	2667472	et	3	main
turvaline	doc_516622545505_item	2667477	et	4	main
kas	doc_516622545505_item	2667486	et	3	main
kui	doc_516622545505_item	2667509	et	3	main
kuritegijat	doc_516622545505_item	2667520	et	3	main
sõltub	doc_516622545505_item	2667526	et	3	main
ta	doc_516622545505_item	2667529	et	4	main
oma	doc_516622545505_item	2667533	et	4	main
tee	doc_516622545505_item	2667539	et	4	main
seda	doc_516622545505_item	2667540	et	3	main
teda	doc_516622545505_item	2667553	et	4	main
korralik	doc_516622545505_item	2667554	et	3	main
seda	doc_516622545505_item	2667581	et	3	main
nõus	doc_516622545505_item	2667585	et	4	main
sest	doc_516622545505_item	2667586	et	4	main
kui	doc_516622545505_item	2667587	et	3	main
ära	doc_516622545505_item	2667597	et	4	main
siis	doc_516622545505_item	2667603	et	3	main
vanglakaristus	doc_516622545505_item	2667606	et	3	main
minu	doc_516622545506_item	2667612	et	3	main
see	doc_516622545506_item	2667624	et	3	main
selles	doc_516622545506_item	2667635	et	4	main
firmas	doc_516622545506_item	2667636	et	3	main
igal	doc_516622545506_item	2667642	et	3	main
kuna	doc_516622545506_item	2667649	et	3	main
me	doc_516622545506_item	2667661	et	4	main
meil	doc_516622545507_item	2667687	et	4	main
ma	doc_516622545507_item	2667722	et	3	main
ole	doc_516622545507_item	2667724	et	4	main
rahul	doc_516622545507_item	2667725	et	4	main
aga	doc_516622545507_item	2667726	et	3	main
meeldi	doc_516622545507_item	2667731	et	4	main
paneelmajad	doc_516622545507_item	2667732	et	3	main
ja	doc_516622545507_item	2667733	et	3	main
lasnamäe	doc_516622545507_item	2667734	et	3	main
rajoon	doc_516622545507_item	2667735	et	3	main
teha	doc_516622545507_item	2667756	et	3	main
järgi	doc_516622545507_item	2667760	et	4	main
ei	doc_51880851196_item	2667769	et	4	main
läksin	doc_51880851196_item	2667772	et	3	main
koju	doc_51880851196_item	2667773	et	3	main
juurde	doc_51880851196_item	2667783	et	4	main
minuti	doc_51880851196_item	2667784	et	3	main
tuli	doc_51880851196_item	2667788	et	4	main
ei	doc_51880851196_item	2667805	et	4	main
oma	doc_51880851196_item	2667829	et	4	main
12	doc_51880851197_item	2667833	et	2	main
kell	doc_51880851197_item	2667838	et	3	main
ostsin	doc_51880851197_item	2667840	et	3	main
kauplusest	doc_51880851197_item	2667844	et	4	main
maksis	doc_51880851197_item	2667847	et	4	main
pärast	doc_51880851197_item	2667850	et	4	main
esimest	doc_51880851197_item	2667851	et	4	main
ostetud	doc_51880851197_item	2667855	et	4	main
andis	doc_51880851197_item	2667860	et	3	main
oli	doc_51880851197_item	2667867	et	3	main
toode	doc_51880851197_item	2667871	et	3	main
mind	doc_51880851197_item	2667875	et	4	main
vahendada	doc_51880851197_item	2667913	et	3	main
ei	doc_516622545505_item	2667521	et	4	main
siis	doc_516622545505_item	2667535	et	3	main
inimene	doc_516622545505_item	2667544	et	3	main
vanglakaristus	doc_516622545505_item	2667550	et	3	main
ei	doc_516622545505_item	2667551	et	4	main
paranda	doc_516622545505_item	2667552	et	4	main
ei	doc_516622545505_item	2667560	et	4	main
saa	doc_516622545505_item	2667561	et	4	main
kunagi	doc_516622545505_item	2667562	et	3	main
kuritegijat	doc_516622545505_item	2667563	et	3	main
arvan	doc_516622545505_item	2667564	et	3	main
et	doc_516622545505_item	2667565	et	3	main
kui	doc_516622545505_item	2667566	et	3	main
lapsel	doc_516622545505_item	2667567	et	4	main
on	doc_516622545505_item	2667568	et	4	main
korralik	doc_516622545505_item	2667569	et	3	main
kodu	doc_516622545505_item	2667570	et	4	main
siis	doc_516622545505_item	2667571	et	3	main
tal	doc_516622545505_item	2667572	et	3	main
on	doc_516622545505_item	2667573	et	4	main
vähem	doc_516622545505_item	2667574	et	4	main
võimalust	doc_516622545505_item	2667575	et	3	main
karistused	doc_516622545505_item	2667580	et	4	main
kuritegusid	doc_516622545505_item	2667583	et	4	main
või	doc_516622545505_item	2667598	et	4	main
kui	doc_516622545505_item	2667599	et	3	main
levitab	doc_516622545505_item	2667601	et	3	main
niisugused	doc_516622545505_item	2667607	et	3	main
madaldada	doc_516622545505_item	2667610	et	3	main
töö	doc_516622545506_item	2667613	et	4	main
trükkikodas	doc_516622545506_item	2667616	et	4	main
seal	doc_516622545506_item	2667619	et	4	main
tegelen	doc_516622545506_item	2667627	et	3	main
annab	doc_516622545506_item	2667637	et	3	main
mulle	doc_516622545506_item	2667638	et	4	main
väga	doc_516622545506_item	2667639	et	3	main
eestis	doc_516622545506_item	2667646	et	3	main
on	doc_516622545506_item	2667651	et	4	main
ainult	doc_516622545506_item	2667655	et	4	main
viis	doc_516622545506_item	2667656	et	4	main
ja	doc_516622545506_item	2667658	et	3	main
saame	doc_516622545506_item	2667662	et	4	main
hästi	doc_516622545506_item	2667664	et	3	main
ja	doc_516622545506_item	2667666	et	3	main
tulemustega	doc_516622545506_item	2667668	et	3	main
elukoht	doc_516622545507_item	2667671	et	3	main
elukoht	doc_516622545507_item	2667673	et	3	main
ma	doc_516622545507_item	2667680	et	3	main
majas	doc_516622545507_item	2667684	et	3	main
jagub	doc_516622545507_item	2667693	et	3	main
ruumi	doc_516622545507_item	2667694	et	4	main
ja	doc_516622545507_item	2667695	et	3	main
veel	doc_516622545507_item	2667696	et	4	main
kuhjaga	doc_516622545507_item	2667697	et	3	main
korteris	doc_516622545507_item	2667698	et	3	main
elavad	doc_516622545507_item	2667699	et	4	main
minu	doc_516622545507_item	2667700	et	3	main
vanemad	doc_516622545507_item	2667701	et	4	main
ja	doc_516622545507_item	2667702	et	3	main
mina	doc_516622545507_item	2667703	et	4	main
ennem	doc_516622545507_item	2667704	et	4	main
elas	doc_516622545507_item	2667705	et	3	main
meie	doc_516622545507_item	2667706	et	4	main
juures	doc_516622545507_item	2667707	et	4	main
ka	doc_516622545507_item	2667708	et	3	main
mu	doc_516622545507_item	2667709	et	3	main
vend	doc_516622545507_item	2667710	et	3	main
aga	doc_516622545507_item	2667711	et	3	main
nüüd	doc_516622545507_item	2667712	et	4	main
tal	doc_516622545507_item	2667713	et	3	main
on	doc_516622545507_item	2667714	et	4	main
oma	doc_516622545507_item	2667715	et	4	main
elamine	doc_516622545507_item	2667716	et	4	main
nüüd	doc_516622545507_item	2667717	et	4	main
võib	doc_516622545507_item	2667718	et	3	main
tekkida	doc_516622545507_item	2667719	et	3	main
küsimus	doc_516622545507_item	2667720	et	4	main
miks	doc_516622545507_item	2667721	et	4	main
mulle	doc_516622545507_item	2667736	et	4	main
osalen	doc_516622545507_item	2667752	et	3	main
et	doc_516622545507_item	2667755	et	3	main
olnud	doc_51880851196_item	2667770	et	4	main
kaubamaja	doc_51880851196_item	2667782	et	4	main
hakkas	doc_51880851196_item	2667791	et	3	main
tema	doc_51880851196_item	2667793	et	4	main
karjuma	doc_51880851196_item	2667797	et	3	main
tema	doc_51880851196_item	2667821	et	4	main
minu	doc_516622545507_item	2667670	et	3	main
mind	doc_516622545507_item	2667679	et	4	main
elan	doc_516622545507_item	2667681	et	3	main
üheksakorrusselises	doc_516622545507_item	2667683	et	4	main
korrusel	doc_516622545507_item	2667686	et	3	main
on	doc_516622545507_item	2667688	et	4	main
korter	doc_516622545507_item	2667690	et	3	main
lihtsalt	doc_516622545507_item	2667727	et	4	main
rohkem	doc_516622545507_item	2667737	et	4	main
koht	doc_516622545507_item	2667740	et	3	main
mere	doc_516622545507_item	2667741	et	3	main
selle	doc_516622545507_item	2667753	et	4	main
oma	doc_516622545507_item	2667758	et	4	main
käe	doc_516622545507_item	2667759	et	3	main
seletuskiri	doc_51880851196_item	2667761	et	3	main
see	doc_51880851196_item	2667762	et	3	main
juhtus	doc_51880851196_item	2667763	et	3	main
õhtul	doc_51880851196_item	2667764	et	3	main
ümbes	doc_51880851196_item	2667765	et	4	main
kell	doc_51880851196_item	2667766	et	3	main
taga	doc_51880851196_item	2667775	et	4	main
tuli	doc_51880851196_item	2667776	et	4	main
tüdruk	doc_51880851196_item	2667777	et	3	main
ja	doc_51880851196_item	2667778	et	3	main
kiiresti	doc_51880851196_item	2667779	et	3	main
läks	doc_51880851196_item	2667780	et	3	main
maja	doc_51880851196_item	2667786	et	4	main
mees	doc_51880851196_item	2667789	et	4	main
ja	doc_51880851196_item	2667790	et	3	main
ümber	doc_51880851196_item	2667822	et	3	main
et	doc_51880851196_item	2667824	et	3	main
oigatab	doc_51880851196_item	2667826	et	4	main
silma	doc_51880851196_item	2667830	et	4	main
a	doc_51880851197_item	2667836	et	4	main
mina	doc_51880851197_item	2667841	et	4	main
teie	doc_51880851197_item	2667842	et	4	main
toode	doc_51880851197_item	2667846	et	3	main
krooni	doc_51880851197_item	2667849	et	4	main
välja	doc_51880851197_item	2667865	et	4	main
see	doc_51880851197_item	2667870	et	3	main
kirjeldage	doc_51880851198_item	2667916	et	3	main
väike	doc_51880851198_item	2667930	et	4	main
saba	doc_51880851198_item	2667931	et	4	main
mittepikk	doc_51880851198_item	2667935	et	4	main
küüned	doc_51880851198_item	2667938	et	3	main
kihvad	doc_51880851198_item	2667945	et	3	main
kõrvad	doc_51880851198_item	2667947	et	3	main
kehabr	doc_51880851198_item	2667949	et	4	main
pikk	doc_51880851198_item	2667951	et	4	main
ümmargune	doc_51880851198_item	2667954	et	3	main
mitte	doc_51880851198_item	2667974	et	3	main
on	doc_51880851198_item	2667976	et	4	main
haridussüsteemis	doc_51880851199_item	2667988	et	3	main
minu	doc_51880851199_item	2667991	et	3	main
raske	doc_51880851199_item	2667993	et	4	main
küsimus	doc_51880851199_item	2667994	et	4	main
kooli	doc_51880851199_item	2667997	et	4	main
et	doc_51880851199_item	2668003	et	3	main
juba	doc_51880851199_item	2668041	et	3	main
saada	doc_51880851199_item	2668046	et	4	main
on	doc_51880851199_item	2668057	et	4	main
rohkem	doc_51880851199_item	2668060	et	4	main
aga	doc_51880851199_item	2668061	et	3	main
mis	doc_51880851199_item	2668062	et	4	main
vähem	doc_51880851199_item	2668063	et	4	main
ei	doc_51880851199_item	2668068	et	4	main
elada	doc_51880851199_item	2668070	et	3	main
arvan	doc_51880851199_item	2668072	et	3	main
elada	doc_51880851199_item	2668079	et	3	main
arvutita	doc_51880851199_item	2668081	et	4	main
töö-	doc_51880851199_item	2668087	et	4	main
ja	doc_51880851199_item	2668088	et	3	main
õppemisvahend	doc_51880851199_item	2668089	et	3	main
arvuti	doc_51880851199_item	2668090	et	4	main
kohvi	doc_51880851199_item	2668134	et	4	main
juua	doc_51880851199_item	2668135	et	3	main
ja	doc_51880851199_item	2668136	et	3	main
ei	doc_51880851199_item	2668137	et	4	main
kujuta	doc_51880851199_item	2668138	et	4	main
ja	doc_516622545507_item	2667691	et	3	main
ei	doc_516622545507_item	2667723	et	4	main
rahulik	doc_516622545507_item	2667739	et	3	main
ääres	doc_516622545507_item	2667742	et	4	main
tulevikus	doc_516622545507_item	2667743	et	4	main
tahan	doc_516622545507_item	2667744	et	3	main
elada	doc_516622545507_item	2667745	et	3	main
ma	doc_516622545507_item	2667746	et	3	main
suures	doc_516622545507_item	2667747	et	3	main
eramajas	doc_516622545507_item	2667748	et	3	main
mere	doc_516622545507_item	2667749	et	3	main
ääres	doc_516622545507_item	2667750	et	4	main
kindlasti	doc_516622545507_item	2667751	et	3	main
kõik	doc_516622545507_item	2667757	et	4	main
paremale	doc_51880851196_item	2667781	et	4	main
taga	doc_51880851196_item	2667787	et	4	main
jooksma	doc_51880851196_item	2667792	et	3	main
juurde	doc_51880851196_item	2667794	et	4	main
tüdruk	doc_51880851196_item	2667795	et	3	main
hakkas	doc_51880851196_item	2667796	et	3	main
mees	doc_51880851196_item	2667799	et	4	main
võttis	doc_51880851196_item	2667800	et	3	main
teda	doc_51880851196_item	2667801	et	4	main
ümber	doc_51880851196_item	2667802	et	3	main
vaid	doc_51880851196_item	2667803	et	3	main
seda	doc_51880851196_item	2667804	et	3	main
mulle	doc_516622545507_item	2667728	et	4	main
absoluutselt	doc_516622545507_item	2667729	et	4	main
ei	doc_516622545507_item	2667730	et	4	main
istub	doc_516622545507_item	2667738	et	3	main
ehitamisel	doc_516622545507_item	2667754	et	4	main
üheksa	doc_51880851196_item	2667767	et	4	main
õues	doc_51880851196_item	2667768	et	4	main
kedagi	doc_51880851196_item	2667771	et	4	main
maja	doc_51880851196_item	2667774	et	4	main
pärast	doc_51880851196_item	2667785	et	4	main
kui	doc_51880851196_item	2667798	et	3	main
aitanud	doc_51880851196_item	2667806	et	4	main
siis	doc_51880851196_item	2667807	et	3	main
tüdruk	doc_51880851196_item	2667808	et	3	main
lõikas	doc_51880851196_item	2667809	et	3	main
meest	doc_51880851196_item	2667810	et	4	main
kuhu	doc_51880851196_item	2667811	et	3	main
ma	doc_51880851196_item	2667812	et	3	main
ei	doc_51880851196_item	2667813	et	4	main
näidanud	doc_51880851196_item	2667814	et	4	main
vaid	doc_51880851196_item	2667815	et	3	main
ta	doc_51880851196_item	2667816	et	4	main
kukkus	doc_51880851196_item	2667817	et	3	main
maha	doc_51880851196_item	2667818	et	4	main
kui	doc_51880851196_item	2667819	et	3	main
tulin	doc_51880851196_item	2667820	et	3	main
nägin	doc_51880851196_item	2667823	et	3	main
ta	doc_51880851196_item	2667825	et	4	main
ja	doc_51880851196_item	2667827	et	3	main
puudutab	doc_51880851196_item	2667828	et	3	main
kaebus	doc_51880851197_item	2667832	et	3	main
sabo	doc_51880851197_item	2667843	et	4	main
kapsuni	doc_51880851197_item	2667845	et	3	main
750	doc_51880851197_item	2667848	et	2	main
mul	doc_51880851197_item	2667854	et	3	main
probleem	doc_51880851197_item	2667857	et	3	main
kampsun	doc_51880851197_item	2667859	et	3	main
pesus	doc_51880851197_item	2667861	et	3	main
kirjutatud	doc_51880851197_item	2667868	et	4	main
on	doc_51880851197_item	2667872	et	4	main
ja	doc_51880851197_item	2667874	et	3	main
kinnitati	doc_51880851197_item	2667876	et	4	main
p	doc_51880851197_item	2667914	et	4	main
nende	doc_51880851198_item	2667917	et	4	main
välimust	doc_51880851198_item	2667919	et	4	main
küülik	doc_51880851198_item	2667920	et	3	main
vurrud	doc_51880851198_item	2667934	et	3	main
pikkad	doc_51880851198_item	2667937	et	4	main
silmad	doc_51880851198_item	2667939	et	4	main
teravad	doc_51880851198_item	2667944	et	3	main
silmad	doc_51880851198_item	2667958	et	4	main
suured	doc_51880851198_item	2667959	et	3	main
kõrvad	doc_51880851198_item	2667960	et	3	main
kodus	doc_51880851198_item	2667964	et	4	main
minu	doc_51880851198_item	2667966	et	3	main
aga	doc_51880851198_item	2667973	et	3	main
kõike	doc_51880851198_item	2667975	et	4	main
niisugused	doc_51880851198_item	2667977	et	3	main
p	doc_51880851198_item	2667981	et	4	main
kontrolltöö	doc_51880851199_item	2667982	et	4	main
mida	doc_51880851199_item	2667983	et	4	main
sa	doc_51880851199_item	2667984	et	3	main
see	doc_51880851199_item	2667989	et	3	main
jaoks	doc_51880851199_item	2667992	et	4	main
lõpetasi	doc_51880851199_item	2667996	et	4	main
ja	doc_51880851199_item	2668001	et	3	main
tean	doc_51880851199_item	2668002	et	3	main
koolis	doc_51880851199_item	2668014	et	4	main
rohkem	doc_51880851199_item	2668018	et	4	main
lapsed	doc_51880851199_item	2668020	et	3	main
kaebus	doc_51880851197_item	2667831	et	3	main
11	doc_51880851197_item	2667834	et	2	main
teisipäeval	doc_51880851197_item	2667837	et	3	main
1600-1630	doc_51880851197_item	2667839	et	2	main
tekkis	doc_51880851197_item	2667853	et	3	main
kaubaga	doc_51880851197_item	2667856	et	3	main
nimelt	doc_51880851197_item	2667858	et	4	main
värvi	doc_51880851197_item	2667862	et	4	main
ja	doc_51880851197_item	2667863	et	3	main
venis	doc_51880851197_item	2667864	et	4	main
et	doc_51880851197_item	2667877	et	3	main
selle	doc_51880851197_item	2667878	et	4	main
toodega	doc_51880851197_item	2667879	et	4	main
ei	doc_51880851197_item	2667880	et	4	main
ole	doc_51880851197_item	2667881	et	4	main
mingeid	doc_51880851197_item	2667882	et	3	main
probleeme	doc_51880851197_item	2667883	et	3	main
nüüd	doc_51880851197_item	2667884	et	4	main
ei	doc_51880851197_item	2667885	et	4	main
ole	doc_51880851197_item	2667886	et	4	main
võimalust	doc_51880851197_item	2667887	et	3	main
seda	doc_51880851197_item	2667888	et	3	main
kampsunit	doc_51880851197_item	2667889	et	3	main
kanda	doc_51880851197_item	2667890	et	4	main
sest	doc_51880851197_item	2667891	et	4	main
ta	doc_51880851197_item	2667892	et	4	main
on	doc_51880851197_item	2667893	et	4	main
praegu	doc_51880851197_item	2667894	et	3	main
kahele	doc_51880851197_item	2667895	et	4	main
numbrile	doc_51880851197_item	2667896	et	3	main
suurem	doc_51880851197_item	2667897	et	4	main
arvestades	doc_51880851197_item	2667898	et	3	main
kõik	doc_51880851197_item	2667899	et	4	main
üleval	doc_51880851197_item	2667900	et	4	main
kirjutatud	doc_51880851197_item	2667901	et	4	main
ma	doc_51880851197_item	2667902	et	3	main
soovin	doc_51880851197_item	2667903	et	3	main
kaupluselt	doc_51880851197_item	2667904	et	3	main
et	doc_51880851197_item	2667905	et	3	main
mulle	doc_51880851197_item	2667906	et	4	main
tagastaksid	doc_51880851197_item	2667907	et	4	main
raha	doc_51880851197_item	2667908	et	4	main
või	doc_51880851197_item	2667909	et	4	main
annaksid	doc_51880851197_item	2667910	et	4	main
03	doc_51880851197_item	2667835	et	2	main
pesupesemist	doc_51880851197_item	2667852	et	3	main
kuigi	doc_51880851197_item	2667866	et	3	main
et	doc_51880851197_item	2667869	et	3	main
originaalne	doc_51880851197_item	2667873	et	3	main
võimalust	doc_51880851197_item	2667911	et	3	main
toote	doc_51880851197_item	2667912	et	4	main
kass	doc_51880851198_item	2667932	et	3	main
karv	doc_51880851198_item	2667936	et	3	main
saba	doc_51880851198_item	2667952	et	4	main
karv	doc_51880851198_item	2667953	et	3	main
metslooma	doc_51880851198_item	2667962	et	4	main
pidada	doc_51880851198_item	2667972	et	4	main
sooviksid	doc_51880851199_item	2667985	et	4	main
ma	doc_51880851199_item	2667995	et	3	main
viis	doc_51880851199_item	2667998	et	4	main
tean	doc_51880851199_item	2668004	et	3	main
on	doc_51880851199_item	2668008	et	4	main
muutunud	doc_51880851199_item	2668010	et	4	main
ma	doc_51880851199_item	2668011	et	3	main
arvan	doc_51880851199_item	2668012	et	3	main
et	doc_51880851199_item	2668013	et	3	main
võiksid	doc_51880851199_item	2668021	et	4	main
õppemateriaaliga	doc_51880851199_item	2668025	et	4	main
tahavad	doc_51880851199_item	2668027	et	3	main
meeldib	doc_51880851199_item	2668032	et	3	main
ja	doc_51880851199_item	2668034	et	3	main
nii	doc_51880851199_item	2668035	et	3	main
edasi	doc_51880851199_item	2668036	et	3	main
gümnaasiumis	doc_51880851199_item	2668039	et	3	main
õpelased	doc_51880851199_item	2668040	et	4	main
nad	doc_51880851199_item	2668044	et	3	main
on	doc_51880851199_item	2668048	et	4	main
vaja	doc_51880851199_item	2668049	et	4	main
anda	doc_51880851199_item	2668050	et	3	main
teil	doc_51880851199_item	2668056	et	4	main
vaja	doc_51880851199_item	2668058	et	4	main
ilma	doc_51880851199_item	2668064	et	4	main
leiutisteta	doc_51880851199_item	2668066	et	3	main
minu	doc_51880851199_item	2668074	et	3	main
ilma	doc_51880851199_item	2668080	et	4	main
jaoks	doc_51880851199_item	2668094	et	4	main
kodumasin	doc_51880851199_item	2668122	et	3	main
ette	doc_51880851199_item	2668139	et	4	main
kontrolltöö	doc_51880851198_item	2667915	et	4	main
loomade	doc_51880851198_item	2667918	et	4	main
väike	doc_51880851198_item	2667921	et	4	main
karv	doc_51880851198_item	2667923	et	3	main
pikkad	doc_51880851198_item	2667924	et	4	main
kõrvad	doc_51880851198_item	2667925	et	3	main
suured	doc_51880851198_item	2667926	et	3	main
silmad	doc_51880851198_item	2667927	et	4	main
pikkad	doc_51880851198_item	2667928	et	4	main
vurrud	doc_51880851198_item	2667929	et	3	main
pikkad	doc_51880851198_item	2667933	et	4	main
kikkis	doc_51880851198_item	2667946	et	3	main
painduv	doc_51880851198_item	2667948	et	4	main
ahv	doc_51880851198_item	2667950	et	3	main
painduv	doc_51880851198_item	2667955	et	4	main
keha	doc_51880851198_item	2667956	et	4	main
suured	doc_51880851198_item	2667957	et	3	main
saab	doc_51880851198_item	2667963	et	3	main
meelest	doc_51880851198_item	2667967	et	4	main
mets	doc_51880851198_item	2667968	et	3	main
looma	doc_51880851198_item	2667969	et	4	main
saab	doc_51880851198_item	2667970	et	3	main
kodus	doc_51880851198_item	2667971	et	4	main
mis	doc_51880851198_item	2667979	et	4	main
saab	doc_51880851198_item	2667980	et	3	main
on	doc_51880851199_item	2667990	et	4	main
aastat	doc_51880851199_item	2667999	et	3	main
et	doc_51880851199_item	2668005	et	3	main
asjaid	doc_51880851199_item	2668007	et	4	main
juba	doc_51880851199_item	2668009	et	3	main
õpilastel	doc_51880851199_item	2668017	et	4	main
millise	doc_51880851199_item	2668024	et	3	main
missugune	doc_51880851199_item	2668029	et	3	main
arvan	doc_51880851199_item	2668037	et	3	main
tahavad	doc_51880851199_item	2668045	et	3	main
õpeaine	doc_51880851199_item	2668055	et	4	main
ma	doc_51880851199_item	2668071	et	3	main
et	doc_51880851199_item	2668073	et	3	main
väga	doc_51880851199_item	2668077	et	3	main
abil	doc_51880851199_item	2668091	et	4	main
võib	doc_51880851199_item	2668092	et	3	main
õppemise	doc_51880851199_item	2668093	et	4	main
kohev	doc_51880851198_item	2667922	et	3	main
pikk	doc_51880851198_item	2667940	et	4	main
saba	doc_51880851198_item	2667941	et	4	main
käppad	doc_51880851198_item	2667942	et	3	main
pikkad	doc_51880851198_item	2667943	et	4	main
kas	doc_51880851198_item	2667961	et	3	main
pidada	doc_51880851198_item	2667965	et	4	main
loomad	doc_51880851198_item	2667978	et	3	main
muuta	doc_51880851199_item	2667986	et	4	main
meie	doc_51880851199_item	2667987	et	4	main
tagasi	doc_51880851199_item	2668000	et	3	main
palju	doc_51880851199_item	2668006	et	4	main
peaks	doc_51880851199_item	2668015	et	4	main
olema	doc_51880851199_item	2668016	et	4	main
vabadust	doc_51880851199_item	2668019	et	4	main
ise	doc_51880851199_item	2668022	et	4	main
teile	doc_51880851199_item	2668031	et	4	main
rohkem	doc_51880851199_item	2668033	et	4	main
et	doc_51880851199_item	2668038	et	3	main
kelleks	doc_51880851199_item	2668043	et	4	main
mis	doc_51880851199_item	2668054	et	4	main
õppida	doc_51880851199_item	2668059	et	3	main
milliste	doc_51880851199_item	2668065	et	3	main
jaoks	doc_51880851199_item	2668075	et	4	main
oleks	doc_51880851199_item	2668076	et	3	main
raske	doc_51880851199_item	2668078	et	4	main
asi	doc_51880851199_item	2668083	et	4	main
minu	doc_51880851199_item	2668085	et	3	main
uut	doc_51880851199_item	2668095	et	3	main
infot	doc_51880851199_item	2668096	et	3	main
kätte	doc_51880851199_item	2668097	et	4	main
saad	doc_51880851199_item	2668098	et	4	main
võib	doc_51880851199_item	2668099	et	3	main
mingeid	doc_51880851199_item	2668100	et	3	main
tööd	doc_51880851199_item	2668101	et	4	main
teha	doc_51880851199_item	2668102	et	3	main
võib	doc_51880851199_item	2668103	et	3	main
inimestega	doc_51880851199_item	2668104	et	3	main
suhelda	doc_51880851199_item	2668105	et	4	main
võib	doc_51880851199_item	2668107	et	3	main
arvuti	doc_51880851199_item	2668106	et	4	main
kasutada	doc_51880851199_item	2668109	et	3	main
ka	doc_51880851199_item	2668108	et	3	main
nadu	doc_51880851199_item	2668110	et	4	main
telekat	doc_51880851199_item	2668111	et	3	main
ja	doc_51880851199_item	2668112	et	3	main
nagu	doc_51880851199_item	2668113	et	3	main
muusikakeskus	doc_51880851199_item	2668114	et	3	main
ma	doc_51880851199_item	2668115	et	3	main
arvan	doc_51880851199_item	2668116	et	3	main
et	doc_51880851199_item	2668117	et	3	main
arvuti	doc_51880851199_item	2668118	et	4	main
on	doc_51880851199_item	2668119	et	4	main
kõige	doc_51880851199_item	2668120	et	4	main
ilma	doc_51880851199_item	2668141	et	4	main
valida	doc_51880851199_item	2668023	et	3	main
nad	doc_51880851199_item	2668026	et	3	main
töötada	doc_51880851199_item	2668028	et	3	main
õppevorm	doc_51880851199_item	2668030	et	3	main
teavad	doc_51880851199_item	2668042	et	3	main
ja	doc_51880851199_item	2668047	et	3	main
teie	doc_51880851199_item	2668051	et	4	main
võimalus	doc_51880851199_item	2668052	et	3	main
vaalida	doc_51880851199_item	2668053	et	3	main
sa	doc_51880851199_item	2668067	et	3	main
saaks	doc_51880851199_item	2668069	et	3	main
see	doc_51880851199_item	2668082	et	3	main
on	doc_51880851199_item	2668084	et	4	main
lemmik	doc_51880851199_item	2668086	et	3	main
väga	doc_51880851199_item	2668124	et	3	main
kodumasin	doc_51880851199_item	2668126	et	3	main
kohvita	doc_51880851199_item	2668142	et	4	main
22	doc_51880851202_item	2668346	et	2	main
liiklusõnnetus	doc_51880851202_item	2668349	et	4	main
vahel	doc_51880851202_item	2668356	et	4	main
arbu	doc_51880851202_item	2668360	et	4	main
laagna	doc_51880851202_item	2668366	et	4	main
tee	doc_51880851202_item	2668367	et	4	main
kõrval	doc_51880851202_item	2668368	et	4	main
ma	doc_51880851202_item	2668369	et	3	main
vaatasin	doc_51880851202_item	2668370	et	3	main
akna	doc_51880851202_item	2668371	et	3	main
kui	doc_51880851202_item	2668372	et	3	main
nägin	doc_51880851202_item	2668373	et	3	main
et	doc_51880851202_item	2668374	et	3	main
üks	doc_51880851202_item	2668375	et	3	main
juht	doc_51880851202_item	2668376	et	3	main
mööduma	doc_51880851202_item	2668380	et	3	main
juht	doc_51880851202_item	2668389	et	3	main
hakkas	doc_51880851202_item	2668391	et	3	main
juht	doc_51880851202_item	2668396	et	3	main
pidurdama	doc_51880851202_item	2668398	et	3	main
aga	doc_51880851202_item	2668399	et	3	main
vihma	doc_51880851202_item	2668400	et	4	main
sajas	doc_51880851202_item	2668401	et	4	main
ja	doc_51880851202_item	2668402	et	3	main
et	doc_51880851202_item	2668409	et	3	main
auto	doc_51880851202_item	2668413	et	4	main
mitte	doc_51880851202_item	2668417	et	3	main
keegi	doc_51880851202_item	2668418	et	4	main
viie	doc_51880851202_item	2668421	et	3	main
kohale	doc_51880851202_item	2668425	et	4	main
juurest	doc_51880851202_item	2668431	et	4	main
ja	doc_51880851202_item	2668432	et	3	main
tähtsam	doc_51880851199_item	2668121	et	4	main
teine	doc_51880851199_item	2668123	et	3	main
tähtis	doc_51880851199_item	2668125	et	4	main
on	doc_51880851199_item	2668127	et	4	main
minu	doc_51880851199_item	2668128	et	3	main
jaoks	doc_51880851199_item	2668129	et	4	main
kohvimasin	doc_51880851199_item	2668130	et	3	main
ma	doc_51880851199_item	2668131	et	3	main
armastan	doc_51880851199_item	2668132	et	3	main
väga	doc_51880851199_item	2668133	et	3	main
hommikusöök	doc_51880851199_item	2668140	et	3	main
politseile	doc_51880851202_item	2668344	et	3	main
tänaval	doc_51880851202_item	2668361	et	4	main
teise	doc_51880851202_item	2668378	et	4	main
pöörangu	doc_51880851202_item	2668383	et	3	main
ja	doc_51880851202_item	2668385	et	3	main
hetkel	doc_51880851202_item	2668387	et	4	main
libe	doc_51880851202_item	2668406	et	3	main
juht	doc_51880851202_item	2668411	et	3	main
ei	doc_51880851202_item	2668419	et	4	main
minuti	doc_51880851202_item	2668422	et	3	main
ma	doc_51880851202_item	2668427	et	3	main
ära	doc_51880851202_item	2668429	et	4	main
näinud	doc_51880851202_item	2668437	et	4	main
pangateenus	doc_51880851203_item	2668438	et	3	main
teenindust	doc_51880851203_item	2668447	et	4	main
teeninduse	doc_51880851203_item	2668449	et	4	main
tänaks	doc_51880851203_item	2668450	et	3	main
võib	doc_51880851203_item	2668451	et	3	main
maksta	doc_51880851203_item	2668452	et	4	main
mobiilitelefoniga	doc_51880851203_item	2668453	et	4	main
saa	doc_51880851203_item	2668461	et	4	main
kaardiga	doc_51880851203_item	2668462	et	3	main
sularaha	doc_51880851203_item	2668468	et	4	main
maksta	doc_51880851203_item	2668471	et	4	main
tegemiseks	doc_51880851203_item	2668473	et	4	main
tuleb	doc_51880851203_item	2668481	et	3	main
küsib	doc_51880851203_item	2668484	et	3	main
nõustute	doc_51880851203_item	2668486	et	3	main
x	doc_51880851203_item	2668489	et	4	main
liiklusõnnetuse	doc_51880851202_item	2668340	et	4	main
ja	doc_51880851202_item	2668353	et	3	main
kotka	doc_51880851202_item	2668354	et	3	main
sillade	doc_51880851202_item	2668355	et	4	main
mina	doc_51880851202_item	2668357	et	4	main
maja	doc_51880851202_item	2668364	et	4	main
juhi	doc_51880851202_item	2668379	et	4	main
unustas	doc_51880851202_item	2668382	et	3	main
samas	doc_51880851202_item	2668386	et	4	main
rida	doc_51880851202_item	2668393	et	4	main
esimene	doc_51880851202_item	2668395	et	3	main
hakkas	doc_51880851202_item	2668397	et	3	main
juhtus	doc_51880851202_item	2668407	et	3	main
teise	doc_51880851202_item	2668412	et	4	main
lõikus	doc_51880851202_item	2668414	et	4	main
sisse	doc_51880851202_item	2668415	et	4	main
pärast	doc_51880851202_item	2668423	et	4	main
liikluspolitsei	doc_51880851202_item	2668426	et	4	main
läksin	doc_51880851202_item	2668428	et	3	main
akna	doc_51880851202_item	2668430	et	3	main
panga	doc_51880851203_item	2668439	et	3	main
bank	doc_51880851203_item	2668442	et	4	main
uue	doc_51880851203_item	2668446	et	3	main
või	doc_51880851203_item	2668456	et	4	main
juures	doc_51880851203_item	2668458	et	4	main
kus	doc_51880851203_item	2668459	et	3	main
ei	doc_51880851203_item	2668460	et	4	main
on	doc_51880851203_item	2668474	et	4	main
vaja	doc_51880851203_item	2668475	et	4	main
valida	doc_51880851203_item	2668476	et	3	main
lühinumber	doc_51880851203_item	2668477	et	3	main
1214kaupmehe	doc_51880851203_item	2668478	et	3	main
automaatne	doc_51880851203_item	2668482	et	3	main
tehinguga	doc_51880851203_item	2668487	et	3	main
senti	doc_51880851203_item	2668492	et	4	main
makse	doc_51880851203_item	2668493	et	4	main
euroliit	doc_51880851204_item	2668525	et	3	main
on	doc_51880851204_item	2668533	et	4	main
avaneb	doc_51880851204_item	2668587	et	3	main
ettevõtted	doc_51880851204_item	2668595	et	3	main
vähenevad	doc_51880851204_item	2668601	et	4	main
tolli-	doc_51880851204_item	2668602	et	4	main
ja	doc_51880851204_item	2668603	et	3	main
ka	doc_51880851204_item	2668606	et	3	main
muutub	doc_51880851204_item	2668607	et	3	main
eksport	doc_51880851204_item	2668608	et	3	main
ja	doc_51880851204_item	2668609	et	3	main
tõsiselt	doc_51880851204_item	2668620	et	4	main
tõlkekvaliteedist	doc_524344278300_item	2668633	et	3	main
edastada	doc_524344278300_item	2668641	et	3	main
taotlused	doc_524344278300_item	2668643	et	4	main
teose	doc_524344278300_item	2668649	et	3	main
keisri	doc_524344278300_item	2668650	et	3	main
jaan	doc_524344278300_item	2668653	et	3	main
romaanist	doc_524344278300_item	2668655	et	3	main
on	doc_524344278300_item	2668664	et	4	main
mul	doc_524344278300_item	2668665	et	3	main
nüüd	doc_524344278300_item	2668666	et	4	main
klaar	doc_524344278300_item	2668667	et	3	main
tegelikult	doc_524344278300_item	2668670	et	4	main
härrastemaja-ärklist	doc_524344278300_item	2668672	et	4	main
mõte	doc_524344278300_item	2668674	et	3	main
jaoks	doc_524344278300_item	2668679	et	4	main
oma	doc_524344278300_item	2668689	et	4	main
uksel	doc_524344278300_item	2668693	et	3	main
jala	doc_524344278300_item	2668724	et	4	main
käivad	doc_524344278300_item	2668730	et	4	main
kahtlased	doc_524344278300_item	2668732	et	3	main
turgatas	doc_524344278300_item	2668751	et	3	main
märksa	doc_524344278300_item	2668761	et	3	main
mõtlesin	doc_524344278300_item	2668766	et	3	main
selle	doc_524344278300_item	2668768	et	4	main
kirja	doc_524344278300_item	2668774	et	4	main
asjade	doc_524344278300_item	2668781	et	3	main
очень	doc_524344278300_item	2668824	et	2	main
низкие	doc_524344278300_item	2668829	et	2	main
над	doc_524344278300_item	2668835	et	2	main
укрепил	doc_524344278300_item	2668838	et	2	main
pealtnägija	doc_51880851202_item	2668341	et	4	main
kirjeldus	doc_51880851202_item	2668342	et	4	main
avaldus	doc_51880851202_item	2668343	et	4	main
täna	doc_51880851202_item	2668345	et	4	main
laagna	doc_51880851202_item	2668352	et	4	main
xxxyyy	doc_51880851202_item	2668358	et	4	main
elan	doc_51880851202_item	2668359	et	3	main
minu	doc_51880851202_item	2668363	et	3	main
asub	doc_51880851202_item	2668365	et	3	main
näidata	doc_51880851202_item	2668384	et	4	main
ka	doc_51880851202_item	2668390	et	3	main
tee	doc_51880851202_item	2668403	et	4	main
oli	doc_51880851202_item	2668404	et	3	main
väga	doc_51880851202_item	2668405	et	3	main
esimene	doc_51880851202_item	2668410	et	3	main
õnneks	doc_51880851202_item	2668416	et	4	main
jõudis	doc_51880851202_item	2668424	et	3	main
ei	doc_51880851202_item	2668436	et	4	main
hansa	doc_51880851203_item	2668441	et	4	main
pakkub	doc_51880851203_item	2668443	et	4	main
kaupmehe	doc_51880851203_item	2668457	et	3	main
ei	doc_51880851203_item	2668466	et	4	main
võid	doc_51880851203_item	2668469	et	4	main
mobiilimakse	doc_51880851203_item	2668472	et	4	main
kõnekeskus	doc_51880851203_item	2668483	et	3	main
kas	doc_51880851203_item	2668485	et	3	main
x	doc_51880851203_item	2668491	et	4	main
kontoris	doc_51880851203_item	2668523	et	3	main
väikefirmadele	doc_51880851204_item	2668527	et	3	main
uus	doc_51880851204_item	2668528	et	3	main
astumine	doc_51880851204_item	2668532	et	4	main
eestis	doc_51880851204_item	2668544	et	3	main
jaoks	doc_51880851204_item	2668547	et	4	main
sisenemiseks	doc_51880851204_item	2668582	et	4	main
järel	doc_51880851204_item	2668591	et	4	main
riigihangete	doc_51880851204_item	2668593	et	3	main
muude	doc_51880851204_item	2668604	et	4	main
maksmised	doc_51880851204_item	2668605	et	4	main
import	doc_51880851204_item	2668610	et	3	main
odavamaks	doc_51880851204_item	2668611	et	4	main
ka	doc_51880851204_item	2668615	et	3	main
ja	doc_51880851204_item	2668618	et	3	main
mõttekas	doc_51880851204_item	2668621	et	4	main
kasutada	doc_51880851204_item	2668623	et	3	main
avanevaid	doc_51880851204_item	2668624	et	4	main
võimalusi	doc_51880851204_item	2668625	et	3	main
sellele	doc_524344278300_item	2668635	et	4	main
kuivõrd	doc_524344278300_item	2668636	et	3	main
tõlkija	doc_524344278300_item	2668639	et	4	main
autori	doc_524344278300_item	2668642	et	3	main
analüüsi	doc_524344278300_item	2668644	et	4	main
jaoks	doc_524344278300_item	2668645	et	4	main
valisin	doc_524344278300_item	2668646	et	3	main
krossi	doc_524344278300_item	2668654	et	4	main
keisri	doc_524344278300_item	2668656	et	3	main
16-ndal	doc_524344278300_item	2668659	et	4	main
selle	doc_524344278300_item	2668678	et	4	main
uksed	doc_524344278300_item	2668683	et	3	main
võrdlemisi	doc_524344278300_item	2668685	et	4	main
sealtsamast	doc_524344278300_item	2668721	et	3	main
poolteise	doc_524344278300_item	2668723	et	4	main
minu	doc_524344278300_item	2668731	et	3	main
paberid	doc_524344278300_item	2668733	et	3	main
nüüd	doc_524344278300_item	2668734	et	4	main
paberid	doc_524344278300_item	2668738	et	3	main
sest	doc_524344278300_item	2668742	et	4	main
on	doc_524344278300_item	2668744	et	4	main
mul	doc_524344278300_item	2668745	et	3	main
päevasündmuste	doc_524344278300_item	2668746	et	3	main
küll	doc_524344278300_item	2668752	et	4	main
et	doc_524344278300_item	2668754	et	3	main
nende	doc_524344278300_item	2668755	et	4	main
oleks	doc_524344278300_item	2668759	et	3	main
aga	doc_524344278300_item	2668764	et	3	main
on	doc_524344278300_item	2668775	et	4	main
pandud	doc_524344278300_item	2668776	et	4	main
ja	doc_524344278300_item	2668777	et	3	main
ettevaatuse	doc_524344278300_item	2668783	et	3	main
эркер	doc_524344278300_item	2668818	et	2	main
mail	doc_51880851202_item	2668347	et	4	main
juhtus	doc_51880851202_item	2668348	et	3	main
laagna	doc_51880851202_item	2668350	et	4	main
teel	doc_51880851202_item	2668351	et	4	main
ja	doc_51880851202_item	2668362	et	3	main
hakkas	doc_51880851202_item	2668377	et	3	main
aga	doc_51880851202_item	2668381	et	3	main
teine	doc_51880851202_item	2668388	et	3	main
teise	doc_51880851202_item	2668392	et	4	main
sõitma	doc_51880851202_item	2668394	et	3	main
niimoodi	doc_51880851202_item	2668408	et	3	main
kannata	doc_51880851202_item	2668420	et	4	main
enam	doc_51880851202_item	2668433	et	4	main
mitte	doc_51880851202_item	2668434	et	3	main
midagi	doc_51880851202_item	2668435	et	4	main
oma	doc_51880851203_item	2668444	et	4	main
ole	doc_51880851203_item	2668467	et	4	main
mobiiliga	doc_51880851203_item	2668470	et	4	main
siis	doc_51880851203_item	2668480	et	3	main
krooni	doc_51880851203_item	2668490	et	4	main
kinnitamiseks	doc_51880851203_item	2668494	et	4	main
on	doc_51880851203_item	2668495	et	4	main
turvakoodi	doc_51880851203_item	2668497	et	4	main
vaja	doc_51880851203_item	2668496	et	4	main
sisestada	doc_51880851203_item	2668498	et	3	main
mobiiliga	doc_51880851203_item	2668499	et	4	main
maksmiseks	doc_51880851203_item	2668500	et	4	main
on	doc_51880851203_item	2668501	et	4	main
vaja	doc_51880851203_item	2668502	et	4	main
hansapangaga	doc_51880851203_item	2668503	et	3	main
lepingu	doc_51880851203_item	2668504	et	3	main
sõlmida	doc_51880851203_item	2668505	et	4	main
mobiilimakse	doc_51880851203_item	2668506	et	4	main
lepingu	doc_51880851203_item	2668507	et	3	main
sõlmimine	doc_51880851203_item	2668508	et	4	main
on	doc_51880851203_item	2668509	et	4	main
tasuta	doc_51880851203_item	2668510	et	4	main
lepingu	doc_51880851203_item	2668511	et	3	main
sõlmimisel	doc_51880851203_item	2668512	et	4	main
on	doc_51880851203_item	2668513	et	4	main
vaja	doc_51880851203_item	2668514	et	4	main
turvakoodi	doc_51880851203_item	2668515	et	4	main
määrada	doc_51880851203_item	2668516	et	4	main
mobiilimakse	doc_51880851203_item	2668517	et	4	main
lepingut	doc_51880851203_item	2668518	et	3	main
saate	doc_51880851203_item	2668519	et	4	main
sõlmida	doc_51880851203_item	2668520	et	4	main
hansapanga	doc_51880851203_item	2668522	et	3	main
väga	doc_51880851204_item	2668534	et	3	main
tähtis	doc_51880851204_item	2668535	et	4	main
küsimus	doc_51880851204_item	2668536	et	4	main
ja	doc_51880851204_item	2668537	et	3	main
väikefirmade	doc_51880851204_item	2668546	et	3	main
muutud	doc_51880851204_item	2668552	et	4	main
on	doc_51880851204_item	2668554	et	4	main
juba	doc_51880851204_item	2668555	et	3	main
teine	doc_51880851204_item	2668556	et	3	main
liikmesriigid	doc_51880851204_item	2668578	et	3	main
enam	doc_51880851204_item	2668579	et	4	main
nõuda	doc_51880851204_item	2668580	et	3	main
turule	doc_51880851204_item	2668581	et	3	main
hulka	doc_51880851204_item	2668584	et	4	main
ettevõtjatele	doc_51880851204_item	2668589	et	3	main
kolmandaks	doc_51880851204_item	2668600	et	4	main
piirikontrollid	doc_51880851204_item	2668617	et	3	main
teenus	doc_51880851203_item	2668440	et	3	main
klientidele	doc_51880851203_item	2668445	et	3	main
selle	doc_51880851203_item	2668448	et	4	main
iga	doc_51880851203_item	2668454	et	4	main
ettevõtja	doc_51880851203_item	2668455	et	4	main
maksta	doc_51880851203_item	2668463	et	4	main
ja	doc_51880851203_item	2668464	et	3	main
sul	doc_51880851203_item	2668465	et	3	main
koodkroonidsendid	doc_51880851203_item	2668479	et	4	main
sumass	doc_51880851203_item	2668488	et	4	main
iga	doc_51880851203_item	2668521	et	4	main
või	doc_51880851203_item	2668524	et	4	main
on	doc_51880851204_item	2668526	et	4	main
euroopa	doc_51880851204_item	2668530	et	4	main
liidu	doc_51880851204_item	2668531	et	3	main
muidugi	doc_51880851204_item	2668538	et	4	main
euroliidu	doc_51880851204_item	2668539	et	3	main
astumisega	doc_51880851204_item	2668540	et	4	main
elu	doc_51880851204_item	2668541	et	4	main
tervikuna	doc_51880851204_item	2668542	et	3	main
ja	doc_51880851204_item	2668545	et	3	main
ka	doc_51880851204_item	2668548	et	3	main
kuidas	doc_51880851204_item	2668550	et	3	main
uus	doc_51880851204_item	2668573	et	3	main
väljakutse	doc_51880851204_item	2668574	et	4	main
esiteks	doc_51880851204_item	2668575	et	3	main
ei	doc_51880851204_item	2668576	et	4	main
suurt	doc_51880851204_item	2668583	et	3	main
eesti	doc_51880851204_item	2668588	et	4	main
ka	doc_51880851204_item	2668592	et	3	main
turg	doc_51880851204_item	2668594	et	3	main
saavad	doc_51880851204_item	2668596	et	4	main
kiiremaks	doc_51880851204_item	2668612	et	4	main
lihtsamaks	doc_51880851204_item	2668614	et	4	main
kaovad	doc_51880851204_item	2668616	et	3	main
muidu	doc_51880851204_item	2668619	et	3	main
aktiivselt	doc_51880851204_item	2668622	et	4	main
tekstianalüüs	doc_524344278300_item	2668626	et	3	main
kõrvutavlingvistiline	doc_524344278300_item	2668627	et	4	main
analüüs	doc_524344278300_item	2668628	et	3	main
peaks	doc_524344278300_item	2668629	et	4	main
andma	doc_524344278300_item	2668630	et	3	main
põhjendatud	doc_524344278300_item	2668631	et	4	main
arvamuse	doc_524344278300_item	2668632	et	3	main
on	doc_524344278300_item	2668638	et	4	main
see	doc_524344278300_item	2668662	et	3	main
siin	doc_524344278300_item	2668677	et	4	main
liiga	doc_524344278300_item	2668680	et	4	main
on	doc_524344278300_item	2668684	et	4	main
madalad	doc_524344278300_item	2668686	et	3	main
ma	doc_524344278300_item	2668687	et	3	main
võtsin	doc_524344278300_item	2668688	et	3	main
vahelisel	doc_524344278300_item	2668692	et	4	main
magamiskambri	doc_524344278300_item	2668694	et	3	main
piidalaua	doc_524344278300_item	2668697	et	4	main
lahti	doc_524344278300_item	2668698	et	4	main
ja	doc_524344278300_item	2668699	et	3	main
pikkuse	doc_524344278300_item	2668725	et	4	main
sinna	doc_524344278300_item	2668741	et	3	main
täna	doc_524344278300_item	2668743	et	4	main
kirjapanemisega	doc_524344278300_item	2668747	et	3	main
küllalt	doc_524344278300_item	2668748	et	4	main
tegemist	doc_524344278300_item	2668749	et	4	main
panemata	doc_524344278300_item	2668757	et	4	main
targem	doc_524344278300_item	2668762	et	4	main
ma	doc_524344278300_item	2668767	et	3	main
peale	doc_524344278300_item	2668769	et	4	main
mis	doc_524344278300_item	2668770	et	4	main
mul	doc_524344278300_item	2668771	et	3	main
leidsin	doc_524344278300_item	2668778	et	3	main
mahavaikimine	doc_524344278300_item	2668782	et	3	main
на	doc_524344278300_item	2668813	et	2	main
господском	doc_524344278300_item	2668820	et	2	main
двери	doc_524344278300_item	2668827	et	2	main
наличник	doc_524344278300_item	2668834	et	2	main
что	doc_524344278300_item	2668842	et	2	main
наполовину	doc_524344278300_item	2668848	et	2	main
я	doc_524344278300_item	2668854	et	2	main
кусок	doc_524344278300_item	2668859	et	2	main
таким	doc_524344278300_item	2668867	et	2	main
хранятся	doc_524344278300_item	2668870	et	2	main
опасные	doc_524344278300_item	2668873	et	2	main
väljakutse	doc_51880851204_item	2668529	et	4	main
muutub	doc_51880851204_item	2668543	et	3	main
aga	doc_51880851204_item	2668549	et	3	main
olukord	doc_51880851204_item	2668551	et	3	main
see	doc_51880851204_item	2668553	et	3	main
küsimus	doc_51880851204_item	2668557	et	4	main
kas	doc_51880851204_item	2668558	et	3	main
on	doc_51880851204_item	2668559	et	4	main
parem	doc_51880851204_item	2668560	et	4	main
või	doc_51880851204_item	2668561	et	4	main
mitte	doc_51880851204_item	2668562	et	3	main
väikefirmade	doc_51880851204_item	2668563	et	3	main
jaoks	doc_51880851204_item	2668564	et	4	main
need	doc_51880851204_item	2668565	et	3	main
muutused	doc_51880851204_item	2668566	et	4	main
kasulikud	doc_51880851204_item	2668567	et	3	main
sest	doc_51880851204_item	2668568	et	4	main
nende	doc_51880851204_item	2668569	et	4	main
jaoks	doc_51880851204_item	2668570	et	4	main
euroliit	doc_51880851204_item	2668571	et	3	main
on	doc_51880851204_item	2668572	et	4	main
saa	doc_51880851204_item	2668577	et	4	main
dokumente	doc_51880851204_item	2668585	et	3	main
teiseks	doc_51880851204_item	2668586	et	4	main
liitumise	doc_51880851204_item	2668590	et	4	main
teistega	doc_51880851204_item	2668597	et	4	main
võrdselt	doc_51880851204_item	2668598	et	4	main
konkureerida	doc_51880851204_item	2668599	et	3	main
ja	doc_51880851204_item	2668613	et	3	main
jaan	doc_524344278300_item	2668647	et	3	main
hull	doc_524344278300_item	2668651	et	3	main
laupäeval	doc_524344278300_item	2668658	et	3	main
noh	doc_524344278300_item	2668661	et	3	main
peidupaik	doc_524344278300_item	2668663	et	3	main
see	doc_524344278300_item	2668668	et	3	main
kõrged	doc_524344278300_item	2668681	et	3	main
kahe	doc_524344278300_item	2668690	et	3	main
poolt	doc_524344278300_item	2668695	et	4	main
hinnangut	doc_524344278300_item	2668634	et	3	main
adekvaatselt	doc_524344278300_item	2668637	et	4	main
suutnud	doc_524344278300_item	2668640	et	4	main
krossi	doc_524344278300_item	2668648	et	4	main
katkend	doc_524344278300_item	2668652	et	3	main
hull	doc_524344278300_item	2668657	et	3	main
juulil	doc_524344278300_item	2668660	et	3	main
on	doc_524344278300_item	2668669	et	4	main
minu	doc_524344278300_item	2668671	et	3	main
laenatud	doc_524344278300_item	2668673	et	4	main
laed	doc_524344278300_item	2668675	et	4	main
on	doc_524344278300_item	2668676	et	4	main
aga	doc_524344278300_item	2668682	et	3	main
toa	doc_524344278300_item	2668691	et	3	main
ülemise	doc_524344278300_item	2668696	et	4	main
sättisin	doc_524344278300_item	2668700	et	3	main
nii	doc_524344278300_item	2668701	et	3	main
et	doc_524344278300_item	2668702	et	3	main
seda	doc_524344278300_item	2668703	et	3	main
lauda	doc_524344278300_item	2668704	et	4	main
saab	doc_524344278300_item	2668705	et	3	main
ühe	doc_524344278300_item	2668706	et	4	main
käeliigutusega	doc_524344278300_item	2668707	et	4	main
pooles	doc_524344278300_item	2668708	et	4	main
pikkuses	doc_524344278300_item	2668709	et	4	main
pahemale	doc_524344278300_item	2668710	et	4	main
poole	doc_524344278300_item	2668711	et	4	main
lükata	doc_524344278300_item	2668712	et	4	main
nagu	doc_524344278300_item	2668713	et	3	main
küübi	doc_524344278300_item	2668714	et	3	main
kaant	doc_524344278300_item	2668715	et	3	main
ja	doc_524344278300_item	2668716	et	3	main
lauatagusest	doc_524344278300_item	2668717	et	3	main
palgist	doc_524344278300_item	2668718	et	3	main
saagisin	doc_524344278300_item	2668719	et	3	main
ma	doc_524344278300_item	2668720	et	3	main
tüki	doc_524344278300_item	2668726	et	4	main
need	doc_524344278300_item	2668737	et	3	main
jätmine	doc_524344278300_item	2668758	et	4	main
siia	doc_524344278300_item	2668772	et	4	main
juba	doc_524344278300_item	2668773	et	3	main
et	doc_524344278300_item	2668779	et	3	main
oleks	doc_524344278300_item	2668785	et	3	main
меня	doc_524344278300_item	2668816	et	2	main
в	doc_524344278300_item	2668819	et	2	main
здесь	doc_524344278300_item	2668822	et	2	main
а	doc_524344278300_item	2668826	et	2	main
я	doc_524344278300_item	2668830	et	2	main
спальне	doc_524344278300_item	2668833	et	2	main
и	doc_524344278300_item	2668837	et	2	main
образом	doc_524344278300_item	2668841	et	2	main
доску	doc_524344278300_item	2668846	et	2	main
как	doc_524344278300_item	2668851	et	2	main
в	doc_524344278300_item	2668856	et	2	main
балки	doc_524344278300_item	2668860	et	2	main
фута	doc_524344278300_item	2668864	et	2	main
теперь	doc_524344278300_item	2668871	et	2	main
сегодня	doc_524344278300_item	2668875	et	2	main
останутся	doc_524344278300_item	2668879	et	2	main
подробно	doc_524344278300_item	2668884	et	2	main
события	doc_524344278300_item	2668889	et	2	main
гораздо	doc_524344278300_item	2668894	et	2	main
но	doc_524344278300_item	2668900	et	2	main
kohast	doc_524344278300_item	2668722	et	4	main
välja	doc_524344278300_item	2668727	et	4	main
seal	doc_524344278300_item	2668728	et	4	main
tühemikus	doc_524344278300_item	2668729	et	3	main
varjul	doc_524344278300_item	2668735	et	4	main
ja	doc_524344278300_item	2668736	et	3	main
jäävadki	doc_524344278300_item	2668739	et	4	main
täna	doc_524344278300_item	2668740	et	4	main
mulle	doc_524344278300_item	2668750	et	4	main
pähe	doc_524344278300_item	2668753	et	4	main
kirja	doc_524344278300_item	2668756	et	4	main
arvatavasti	doc_524344278300_item	2668760	et	3	main
tegu	doc_524344278300_item	2668763	et	4	main
siis	doc_524344278300_item	2668765	et	3	main
mistahes	doc_524344278300_item	2668780	et	4	main
pärast	doc_524344278300_item	2668784	et	4	main
juba	doc_524344278300_item	2668787	et	3	main
ammu	doc_524344278300_item	2668788	et	4	main
küll	doc_524344278300_item	2668786	et	4	main
mõttetu	doc_524344278300_item	2668789	et	4	main
отрывок	doc_524344278300_item	2668790	et	2	main
из	doc_524344278300_item	2668791	et	2	main
перевода	doc_524344278300_item	2668792	et	2	main
романа	doc_524344278300_item	2668793	et	2	main
яана	doc_524344278300_item	2668794	et	2	main
кросса	doc_524344278300_item	2668795	et	2	main
императорский	doc_524344278300_item	2668796	et	2	main
безумец	doc_524344278300_item	2668797	et	2	main
перевод	doc_524344278300_item	2668798	et	2	main
с	doc_524344278300_item	2668799	et	2	main
о	doc_524344278300_item	2668801	et	2	main
эстонского	doc_524344278300_item	2668800	et	2	main
саама	doc_524344278300_item	2668802	et	2	main
1984	doc_524344278300_item	2668803	et	2	main
суббота	doc_524344278300_item	2668804	et	2	main
16	doc_524344278300_item	2668805	et	2	main
июля	doc_524344278300_item	2668806	et	2	main
ну	doc_524344278300_item	2668807	et	2	main
вот	doc_524344278300_item	2668808	et	2	main
теперь	doc_524344278300_item	2668809	et	2	main
тайник	doc_524344278300_item	2668810	et	2	main
уже	doc_524344278300_item	2668811	et	2	main
готов	doc_524344278300_item	2668812	et	2	main
эту	doc_524344278300_item	2668814	et	2	main
мысль	doc_524344278300_item	2668815	et	2	main
навёл	doc_524344278300_item	2668817	et	2	main
доме	doc_524344278300_item	2668821	et	2	main
высокие	doc_524344278300_item	2668825	et	2	main
оторвал	doc_524344278300_item	2668831	et	2	main
его	doc_524344278300_item	2668839	et	2	main
одним	doc_524344278300_item	2668843	et	2	main
можно	doc_524344278300_item	2668847	et	2	main
крышку	doc_524344278300_item	2668852	et	2	main
этом	doc_524344278300_item	2668857	et	2	main
длиной	doc_524344278300_item	2668861	et	2	main
в	doc_524344278300_item	2668865	et	2	main
образом	doc_524344278300_item	2668868	et	2	main
мои	doc_524344278300_item	2668872	et	2	main
там	doc_524344278300_item	2668877	et	2	main
мне	doc_524344278300_item	2668882	et	2	main
дневник	doc_524344278300_item	2668887	et	2	main
наверно	doc_524344278300_item	2668891	et	2	main
умнее	doc_524344278300_item	2668895	et	2	main
них	doc_524344278300_item	2668899	et	2	main
меня	doc_524344278300_item	2668905	et	2	main
ja	doc_524344278300_item	2668934	et	3	main
luuletõlkijana	doc_524344278300_item	2668935	et	3	main
ta	doc_524344278300_item	2668936	et	4	main
kirjutas	doc_524344278300_item	2668937	et	3	main
ka	doc_524344278300_item	2668938	et	3	main
poeeme	doc_524344278300_item	2668939	et	3	main
1970ndatel	doc_524344278300_item	2668940	et	4	main
krossi	doc_524344278300_item	2668946	et	4	main
jälgib	doc_524344278300_item	2668953	et	3	main
kaudu	doc_524344278300_item	2668959	et	3	main
keisri	doc_524344278300_item	2668961	et	3	main
ja	doc_524344278300_item	2668969	et	3	main
lähtekohaks	doc_524344278300_item	2668976	et	4	main
ja	doc_524344278300_item	2668978	et	3	main
peituvate	doc_524344278300_item	2668980	et	4	main
toore	doc_524344278300_item	2668987	et	4	main
ees	doc_524344278300_item	2668989	et	4	main
bock	doc_524344278300_item	2668992	et	4	main
ohustab	doc_524344278300_item	2668993	et	3	main
hulljulge	doc_524344278300_item	2668995	et	4	main
vähe	doc_524344278300_item	2668998	et	3	main
on	doc_524344278300_item	2668999	et	4	main
teda	doc_524344278300_item	2669001	et	4	main
kindluse	doc_524344278300_item	2669003	et	4	main
kirjutatud	doc_524344278300_item	2669021	et	4	main
mättiku	doc_524344278300_item	2669026	et	4	main
päevik	doc_524344278300_item	2669027	et	3	main
avaldaja	doc_524344278300_item	2669028	et	4	main
autor	doc_524344278300_item	2669030	et	3	main
pärine	doc_524344278300_item	2669038	et	4	main
19	doc_524344278300_item	2669039	et	2	main
sajandi	doc_524344278300_item	2669040	et	3	main
ning	doc_524344278300_item	2669047	et	3	main
tõlkinud	doc_524344278300_item	2669056	et	4	main
ja	doc_524344278300_item	2669057	et	3	main
mõlema	doc_524344278300_item	2669058	et	3	main
loetavaks	doc_524344278300_item	2669063	et	4	main
8	doc_524344278300_item	2669066	et	2	main
on	doc_524344278300_item	2669068	et	4	main
eesmärgiks	doc_524344278300_item	2669071	et	3	main
kirjeldada	doc_524344278300_item	2669073	et	3	main
sündmusi	doc_524344278300_item	2669074	et	3	main
toimusid	doc_524344278300_item	2669076	et	4	main
on	doc_524344278300_item	2669080	et	4	main
element	doc_524344278300_item	2669088	et	3	main
esitluslaad	doc_524344278300_item	2669089	et	3	main
eesti	doc_524344278300_item	2669093	et	4	main
keelde	doc_524344278300_item	2669106	et	4	main
tamm	doc_524344278300_item	2669114	et	3	main
кайзер	doc_524344278300_item	2669122	et	2	main
eesti-vene-eesti	doc_524344278300_item	2669124	et	4	main
sõnastikust	doc_524344278300_item	2669126	et	4	main
nende	doc_524344278300_item	2669128	et	4	main
mitmeti	doc_524344278300_item	2669136	et	3	main
näiteks	doc_524344278300_item	2669138	et	4	main
сумасшедшийhullumeelne	doc_524344278300_item	2669143	et	2	main
псих	doc_524344278300_item	2669148	et	2	main
httpwwwaseeedict	doc_524344278300_item	2669159	et	4	main
antud	doc_524344278300_item	2669164	et	4	main
parem	doc_524344278300_item	2669167	et	4	main
потолки	doc_524344278300_item	2668823	et	2	main
относительно	doc_524344278300_item	2668828	et	2	main
в	doc_524344278300_item	2668832	et	2	main
дверью	doc_524344278300_item	2668836	et	2	main
движением	doc_524344278300_item	2668844	et	2	main
сдвинуть	doc_524344278300_item	2668849	et	2	main
пенала	doc_524344278300_item	2668853	et	2	main
месте	doc_524344278300_item	2668858	et	2	main
полтора	doc_524344278300_item	2668863	et	2	main
пространстве	doc_524344278300_item	2668869	et	2	main
они	doc_524344278300_item	2668876	et	2	main
что	doc_524344278300_item	2668881	et	2	main
в	doc_524344278300_item	2668886	et	2	main
было	doc_524344278300_item	2668892	et	2	main
о	doc_524344278300_item	2668898	et	2	main
вспомнил	doc_524344278300_item	2668902	et	2	main
здесь	doc_524344278300_item	2668906	et	2	main
написано	doc_524344278300_item	2668907	et	2	main
решил	doc_524344278300_item	2668909	et	2	main
то	doc_524344278300_item	2668908	et	2	main
что	doc_524344278300_item	2668910	et	2	main
давно	doc_524344278300_item	2668911	et	2	main
уже	doc_524344278300_item	2668912	et	2	main
бессмысленно	doc_524344278300_item	2668913	et	2	main
из	doc_524344278300_item	2668914	et	2	main
осторожности	doc_524344278300_item	2668915	et	2	main
о	doc_524344278300_item	2668916	et	2	main
чём	doc_524344278300_item	2668917	et	2	main
либо	doc_524344278300_item	2668918	et	2	main
умалчивать	doc_524344278300_item	2668919	et	2	main
teosest	doc_524344278300_item	2668920	et	4	main
jaan	doc_524344278300_item	2668921	et	3	main
publitsist	doc_524344278300_item	2668924	et	3	main
prosaist	doc_524344278300_item	2668925	et	3	main
fantaasiavabadusega	doc_524344278300_item	2668951	et	4	main
tegelasi	doc_524344278300_item	2668954	et	3	main
ja	doc_524344278300_item	2668957	et	3	main
hull	doc_524344278300_item	2668962	et	3	main
keisrikotta	doc_524344278300_item	2668968	et	4	main
ainestik	doc_524344278300_item	2668973	et	3	main
tõukepinnaks	doc_524344278300_item	2668975	et	3	main
esiletoomisel	doc_524344278300_item	2668982	et	4	main
inimvaimu	doc_524344278300_item	2668985	et	4	main
jõu	doc_524344278300_item	2668988	et	3	main
oma	doc_524344278300_item	2668994	et	4	main
käitumisega	doc_524344278300_item	2668996	et	4	main
schlüsserburgi	doc_524344278300_item	2669002	et	4	main
таким	doc_524344278300_item	2668840	et	2	main
руки	doc_524344278300_item	2668845	et	2	main
влево	doc_524344278300_item	2668850	et	2	main
выпилил	doc_524344278300_item	2668855	et	2	main
в	doc_524344278300_item	2668862	et	2	main
образовавшемся	doc_524344278300_item	2668866	et	2	main
бумаги	doc_524344278300_item	2668874	et	2	main
потому	doc_524344278300_item	2668880	et	2	main
записать	doc_524344278300_item	2668885	et	2	main
подумал	doc_524344278300_item	2668890	et	2	main
не	doc_524344278300_item	2668896	et	2	main
когда	doc_524344278300_item	2668901	et	2	main
у	doc_524344278300_item	2668904	et	2	main
kross	doc_524344278300_item	2668922	et	3	main
tõlkija	doc_524344278300_item	2668927	et	4	main
kirjandusse	doc_524344278300_item	2668928	et	3	main
aastatel	doc_524344278300_item	2668941	et	4	main
pöördub	doc_524344278300_item	2668942	et	3	main
ajaloolise	doc_524344278300_item	2668943	et	4	main
temaatika	doc_524344278300_item	2668944	et	4	main
proosat	doc_524344278300_item	2668947	et	3	main
faktitruuduse	doc_524344278300_item	2668949	et	4	main
sidumine	doc_524344278300_item	2668950	et	4	main
kodumaa	doc_524344278300_item	2668964	et	4	main
viiakse	doc_524344278300_item	2668966	et	3	main
lääne	doc_524344278300_item	2668970	et	4	main
sunnib	doc_524344278300_item	2668984	et	3	main
kuuletuma	doc_524344278300_item	2668986	et	3	main
tsaarivõimu	doc_524344278300_item	2668997	et	4	main
romaan	doc_524344278300_item	2669022	et	3	main
naisevenna	doc_524344278300_item	2669024	et	3	main
tähelepanu	doc_524344278300_item	2669033	et	4	main
osalt	doc_524344278300_item	2669045	et	4	main
prantsuse-	doc_524344278300_item	2669048	et	3	main
kihi	doc_524344278300_item	2669059	et	3	main
lugejale	doc_524344278300_item	2669061	et	4	main
ühtlustanudkross	doc_524344278300_item	2669064	et	4	main
tegemist	doc_524344278300_item	2669067	et	4	main
on	doc_524344278300_item	2669072	et	4	main
elus	doc_524344278300_item	2669078	et	4	main
ja	doc_524344278300_item	2669086	et	3	main
kirjeldav	doc_524344278300_item	2669087	et	4	main
kui	doc_524344278300_item	2669094	et	3	main
tõlgitud	doc_524344278300_item	2669107	et	4	main
kui	doc_524344278300_item	2669108	et	3	main
императорский	doc_524344278300_item	2669109	et	2	main
безумец	doc_524344278300_item	2669110	et	2	main
leiame	doc_524344278300_item	2669115	et	3	main
venekeelse	doc_524344278300_item	2669118	et	3	main
и	doc_524344278300_item	2668878	et	2	main
нужно	doc_524344278300_item	2668883	et	2	main
сегодняшние	doc_524344278300_item	2668888	et	2	main
бы	doc_524344278300_item	2668893	et	2	main
писать	doc_524344278300_item	2668897	et	2	main
что	doc_524344278300_item	2668903	et	2	main
on	doc_524344278300_item	2668923	et	4	main
ja	doc_524344278300_item	2668926	et	3	main
1950	doc_524344278300_item	2668931	et	2	main
aastatel	doc_524344278300_item	2668932	et	4	main
luuletajana	doc_524344278300_item	2668933	et	4	main
poole	doc_524344278300_item	2668945	et	4	main
iseloomustab	doc_524344278300_item	2668948	et	4	main
konkreetse	doc_524344278300_item	2668955	et	3	main
romaanis	doc_524344278300_item	2668960	et	3	main
pinnal	doc_524344278300_item	2668965	et	3	main
euroopasse	doc_524344278300_item	2668971	et	3	main
on	doc_524344278300_item	2668974	et	4	main
timotheus	doc_524344278300_item	2668990	et	4	main
panna	doc_524344278300_item	2669000	et	4	main
kasematti	doc_524344278300_item	2669004	et	4	main
saatesõnas	doc_524344278300_item	2669029	et	3	main
eesti-	doc_524344278300_item	2669046	et	4	main
keelde	doc_524344278300_item	2669055	et	4	main
1999	doc_524344278300_item	2669065	et	2	main
mis	doc_524344278300_item	2669075	et	4	main
peategelase	doc_524344278300_item	2669077	et	3	main
olemas	doc_524344278300_item	2669084	et	4	main
on	doc_524344278300_item	2669090	et	4	main
ka	doc_524344278300_item	2669095	et	3	main
keeles	doc_524344278300_item	2669097	et	4	main
alustan	doc_524344278300_item	2669098	et	3	main
pealkirjast	doc_524344278300_item	2669099	et	4	main
teose	doc_524344278300_item	2669100	et	3	main
pealkiri	doc_524344278300_item	2669101	et	3	main
keisri	doc_524344278300_item	2669102	et	3	main
hull	doc_524344278300_item	2669103	et	3	main
on	doc_524344278300_item	2669104	et	4	main
sõnale	doc_524344278300_item	2669116	et	3	main
ja	doc_524344278300_item	2669123	et	3	main
elektroonilisest	doc_524344278300_item	2669125	et	4	main
httpwwwaseeedict	doc_524344278300_item	2669127	et	4	main
juurde	doc_524344278300_item	2669129	et	4	main
hull	doc_524344278300_item	2669133	et	3	main
ka	doc_524344278300_item	2669135	et	3	main
tõlkida	doc_524344278300_item	2669137	et	3	main
безумныйmeeletu	doc_524344278300_item	2669140	et	2	main
сумасбродныйogar	doc_524344278300_item	2669142	et	2	main
юродивый	doc_524344278300_item	2669158	et	2	main
kontekstis	doc_524344278300_item	2669165	et	3	main
vaste	doc_524344278300_item	2669182	et	4	main
tähendusnüanssi	doc_524344278300_item	2669198	et	4	main
hullu	doc_524344278300_item	2669204	et	4	main
сумасшедший	doc_524344278300_item	2669206	et	2	main
nimisõna	doc_524344278300_item	2669208	et	4	main
rollis	doc_524344278300_item	2669209	et	3	main
kõla	doc_524344278300_item	2669216	et	4	main
сумасшедший	doc_524344278300_item	2669220	et	2	main
ka	doc_524344278300_item	2669226	et	3	main
императорский	doc_524344278300_item	2669229	et	2	main
parim	doc_524344278300_item	2669233	et	4	main
see	doc_524344278300_item	2669246	et	3	main
varjatud	doc_524344278300_item	2669250	et	4	main
sündmusi	doc_524344278300_item	2669255	et	3	main
toimusid	doc_524344278300_item	2669257	et	4	main
pidada	doc_524344278300_item	2669264	et	4	main
tuua	doc_524344278300_item	2669283	et	3	main
milleks	doc_524344278300_item	2669286	et	4	main
lausete	doc_524344278300_item	2669323	et	4	main
sidususvahendeid	doc_524344278300_item	2669324	et	4	main
siis	doc_524344278300_item	2669325	et	3	main
tuleb	doc_524344278300_item	2669326	et	3	main
ära	doc_524344278300_item	2669327	et	4	main
keelses	doc_524344278300_item	2669331	et	3	main
siia	doc_524344278300_item	2669337	et	4	main
kahe	doc_524344278300_item	2669339	et	3	main
toa	doc_524344278300_item	2669340	et	3	main
vahelisel	doc_524344278300_item	2669341	et	4	main
uksel	doc_524344278300_item	2669342	et	3	main
piidalaua	doc_524344278300_item	2669346	et	4	main
astus	doc_524344278300_item	2668929	et	3	main
ta	doc_524344278300_item	2668930	et	4	main
ta	doc_524344278300_item	2668952	et	4	main
ajaruumi	doc_524344278300_item	2668956	et	4	main
inimsuhete	doc_524344278300_item	2668958	et	3	main
seistes	doc_524344278300_item	2668963	et	3	main
lugeja	doc_524344278300_item	2668967	et	4	main
ajalooline	doc_524344278300_item	2668972	et	4	main
elus	doc_524344278300_item	2668977	et	4	main
inimestes	doc_524344278300_item	2668979	et	3	main
tahkude	doc_524344278300_item	2668981	et	4	main
mis	doc_524344278300_item	2668983	et	4	main
von	doc_524344278300_item	2668991	et	4	main
ta	doc_524344278300_item	2669005	et	4	main
peab	doc_524344278300_item	2669006	et	4	main
ka	doc_524344278300_item	2669007	et	3	main
hulluks	doc_524344278300_item	2669008	et	4	main
tunnistama	doc_524344278300_item	2669009	et	3	main
kui	doc_524344278300_item	2669010	et	3	main
mõtleb	doc_524344278300_item	2669011	et	3	main
teisiti	doc_524344278300_item	2669012	et	3	main
siis	doc_524344278300_item	2669013	et	3	main
on	doc_524344278300_item	2669014	et	4	main
hull	doc_524344278300_item	2669015	et	3	main
keisri	doc_524344278300_item	2669016	et	3	main
hull	doc_524344278300_item	2669017	et	3	main
on	doc_524344278300_item	2669018	et	4	main
päeviku	doc_524344278300_item	2669019	et	3	main
vormis	doc_524344278300_item	2669020	et	4	main
pöörab	doc_524344278300_item	2669031	et	3	main
algusest	doc_524344278300_item	2669041	et	4	main
jaan	doc_524344278300_item	2669042	et	3	main
kross	doc_524344278300_item	2669043	et	3	main
on	doc_524344278300_item	2669044	et	4	main
osalt	doc_524344278300_item	2669049	et	4	main
käsikirja	doc_524344278300_item	2669051	et	4	main
võõrkeelsed	doc_524344278300_item	2669052	et	3	main
osad	doc_524344278300_item	2669053	et	3	main
eesti	doc_524344278300_item	2669054	et	4	main
enam-vähem	doc_524344278300_item	2669062	et	3	main
tekst	doc_524344278300_item	2669079	et	3	main
jutustava	doc_524344278300_item	2669081	et	4	main
arutlev	doc_524344278300_item	2669085	et	4	main
vene	doc_524344278300_item	2669105	et	4	main
sõnaraamatustjohan	doc_524344278300_item	2669113	et	4	main
keiser	doc_524344278300_item	2669117	et	3	main
ka	doc_524344278300_item	2669130	et	3	main
võib	doc_524344278300_item	2669134	et	3	main
ошалелый	doc_524344278300_item	2669145	et	2	main
оглашённый	doc_524344278300_item	2669147	et	2	main
ненормальный	doc_524344278300_item	2669157	et	2	main
kõikidest	doc_524344278300_item	2669161	et	4	main
venekeelsetest	doc_524344278300_item	2669162	et	4	main
venemaa	doc_524344278300_item	2669175	et	4	main
mis	doc_524344278300_item	2669188	et	4	main
konteksti	doc_524344278300_item	2669196	et	4	main
kuid	doc_524344278300_item	2669210	et	4	main
sel	doc_524344278300_item	2669211	et	3	main
juhul	doc_524344278300_item	2669212	et	3	main
sõnaühendis	doc_524344278300_item	2669213	et	3	main
pealkiri	doc_524344278300_item	2669214	et	3	main
venekeelne	doc_524344278300_item	2669223	et	3	main
царский	doc_524344278300_item	2669227	et	2	main
tundub	doc_524344278300_item	2669232	et	3	main
olevat	doc_524344278300_item	2669234	et	4	main
timo	doc_524344278300_item	2669023	et	4	main
jakob	doc_524344278300_item	2669025	et	4	main
lugeja	doc_524344278300_item	2669032	et	4	main
sellele	doc_524344278300_item	2669034	et	4	main
et	doc_524344278300_item	2669035	et	3	main
tekst	doc_524344278300_item	2669036	et	3	main
ei	doc_524344278300_item	2669037	et	4	main
saksakeelse	doc_524344278300_item	2669050	et	3	main
kaasaegsele	doc_524344278300_item	2669060	et	3	main
ilukirjandusteosega	doc_524344278300_item	2669069	et	3	main
autori	doc_524344278300_item	2669070	et	3	main
laadi	doc_524344278300_item	2669082	et	4	main
on	doc_524344278300_item	2669083	et	4	main
järjestikune	doc_524344278300_item	2669091	et	4	main
nii	doc_524344278300_item	2669092	et	3	main
vene	doc_524344278300_item	2669096	et	4	main
eesti	doc_524344278300_item	2669111	et	4	main
vene	doc_524344278300_item	2669112	et	4	main
vaste	doc_524344278300_item	2669119	et	4	main
император	doc_524344278300_item	2669120	et	2	main
царь	doc_524344278300_item	2669121	et	2	main
кесарь	doc_524344278300_item	2669131	et	2	main
sõna	doc_524344278300_item	2669132	et	4	main
безумец	doc_524344278300_item	2669139	et	2	main
сумасброд	doc_524344278300_item	2669141	et	2	main
полоумный	doc_524344278300_item	2669146	et	2	main
чумной	doc_524344278300_item	2669156	et	2	main
nendest	doc_524344278300_item	2669160	et	4	main
keisri	doc_524344278300_item	2669166	et	3	main
valitseja	doc_524344278300_item	2669176	et	4	main
tiitlile	doc_524344278300_item	2669177	et	3	main
sõna	doc_524344278300_item	2669179	et	4	main
parem	doc_524344278300_item	2669181	et	4	main
on	doc_524344278300_item	2669183	et	4	main
безумец	doc_524344278300_item	2669184	et	2	main
mitte	doc_524344278300_item	2669185	et	3	main
aga	doc_524344278300_item	2669186	et	3	main
сумасброд	doc_524344278300_item	2669187	et	2	main
antud	doc_524344278300_item	2669195	et	4	main
tõttu	doc_524344278300_item	2669199	et	4	main
võimalik	doc_524344278300_item	2669202	et	3	main
императорский	doc_524344278300_item	2669217	et	2	main
või	doc_524344278300_item	2669219	et	4	main
võimalik	doc_524344278300_item	2669222	et	3	main
суббота	doc_524344278300_item	2669243	et	2	main
nagu	doc_524344278300_item	2669248	et	3	main
kirjeldatakse	doc_524344278300_item	2669254	et	3	main
16	doc_524344278300_item	2669258	et	2	main
lõigu	doc_524344278300_item	2669266	et	4	main
teksti	doc_524344278300_item	2669278	et	4	main
et	doc_524344278300_item	2669329	et	3	main
asesõnaline	doc_524344278300_item	2669334	et	4	main
poolt	doc_524344278300_item	2669344	et	4	main
kohast	doc_524344278300_item	2669348	et	4	main
sinna	doc_524344278300_item	2669350	et	3	main
lauda	doc_524344278300_item	2669355	et	4	main
minu	doc_524344278300_item	2669362	et	3	main
need	doc_524344278300_item	2669365	et	3	main
päevasündmused	doc_524344278300_item	2669367	et	3	main
mistahes	doc_524344278300_item	2669373	et	4	main
asjad	doc_524344278300_item	2669374	et	3	main
мысль	doc_524344278300_item	2669382	et	2	main
спальне	doc_524344278300_item	2669384	et	2	main
дверью	doc_524344278300_item	2669389	et	2	main
опасные	doc_524344278300_item	2669394	et	2	main
о	doc_524344278300_item	2669399	et	2	main
над	doc_524344278300_item	2669403	et	2	main
либо	doc_524344278300_item	2669421	et	2	main
venekeelses	doc_524344278300_item	2669428	et	3	main
kasutatakse	doc_524344278300_item	2669430	et	3	main
sidususvahendeid	doc_524344278300_item	2669432	et	4	main
katkendite	doc_524344278300_item	2669433	et	3	main
ajafoon	doc_524344278300_item	2669434	et	3	main
originaalsele	doc_524344278300_item	2669439	et	3	main
võetud	doc_524344278300_item	2669442	et	4	main
on	doc_524344278300_item	2669456	et	4	main
tulevik	doc_524344278300_item	2669459	et	3	main
eestikeelses	doc_524344278300_item	2669461	et	3	main
одержимый	doc_524344278300_item	2669144	et	2	main
чумовой	doc_524344278300_item	2669149	et	2	main
шальнойrumal	doc_524344278300_item	2669150	et	2	main
бешенныйpäärane	doc_524344278300_item	2669151	et	2	main
помешанныйpeast	doc_524344278300_item	2669152	et	2	main
segane	doc_524344278300_item	2669153	et	3	main
умалишённыйhullumeelne	doc_524344278300_item	2669154	et	2	main
угорелый	doc_524344278300_item	2669155	et	2	main
vastetest	doc_524344278300_item	2669163	et	4	main
tõlge	doc_524344278300_item	2669168	et	3	main
император	doc_524344278300_item	2669170	et	2	main
19	doc_524344278300_item	2669173	et	2	main
hull	doc_524344278300_item	2669180	et	3	main
siin	doc_524344278300_item	2669189	et	4	main
tundub	doc_524344278300_item	2669190	et	3	main
vulgaarsena	doc_524344278300_item	2669191	et	3	main
oma	doc_524344278300_item	2669197	et	4	main
sobi	doc_524344278300_item	2669201	et	4	main
ei	doc_524344278300_item	2669215	et	4	main
императора	doc_524344278300_item	2669221	et	2	main
безумец	doc_524344278300_item	2669230	et	2	main
16-ndal	doc_524344278300_item	2669239	et	4	main
juulil	doc_524344278300_item	2669240	et	3	main
venekeelses	doc_524344278300_item	2669241	et	3	main
tekstis	doc_524344278300_item	2669242	et	3	main
июля	doc_524344278300_item	2669245	et	2	main
on	doc_524344278300_item	2669247	et	4	main
selles	doc_524344278300_item	2669252	et	4	main
temaatiliseks	doc_524344278300_item	2669267	et	4	main
mis	doc_524344278300_item	2669271	et	4	main
sissejuhatuses	doc_524344278300_item	2669279	et	4	main
võib	doc_524344278300_item	2669281	et	3	main
kui	doc_524344278300_item	2669321	et	3	main
eesti	doc_524344278300_item	2669330	et	4	main
tekstis	doc_524344278300_item	2669332	et	3	main
see	doc_524344278300_item	2669336	et	3	main
oma	doc_524344278300_item	2669338	et	4	main
sealtsamast	doc_524344278300_item	2669347	et	3	main
seda	doc_524344278300_item	2669354	et	3	main
täna	doc_524344278300_item	2669356	et	4	main
täpsustamine	doc_524344278300_item	2669358	et	4	main
seal	doc_524344278300_item	2669359	et	4	main
tühemikus	doc_524344278300_item	2669360	et	3	main
pandud	doc_524344278300_item	2669372	et	4	main
asendamineтайник	doc_524344278300_item	2669380	et	2	main
здесь	doc_524344278300_item	2669385	et	2	main
в	doc_524344278300_item	2669390	et	2	main
бумаги	doc_524344278300_item	2669395	et	2	main
них	doc_524344278300_item	2669400	et	2	main
в	doc_524344278300_item	2669405	et	2	main
tekstis	doc_524344278300_item	2669425	et	3	main
tekstis	doc_524344278300_item	2669429	et	3	main
vastavalt	doc_524344278300_item	2669438	et	4	main
arvesse	doc_524344278300_item	2669441	et	4	main
päeviku	doc_524344278300_item	2669443	et	3	main
vormi	doc_524344278300_item	2669444	et	4	main
nüanssid	doc_524344278300_item	2669445	et	3	main
ajad	doc_524344278300_item	2669446	et	4	main
tekstis	doc_524344278300_item	2669451	et	3	main
ka	doc_524344278300_item	2669452	et	3	main
täisminevik	doc_524344278300_item	2669453	et	3	main
вот	doc_524344278300_item	2669491	et	2	main
sõnaraamat	doc_524344278300_item	2669505	et	3	main
vene	doc_524344278300_item	2669527	et	4	main
pea	doc_524344278300_item	2669533	et	4	main
sõna	doc_524344278300_item	2669534	et	4	main
sõnalt	doc_524344278300_item	2669535	et	3	main
mis	doc_524344278300_item	2669551	et	4	main
mõtest	doc_524344278300_item	2669556	et	4	main
tegi	doc_524344278300_item	2669566	et	4	main
ja	doc_524344278300_item	2669569	et	3	main
et	doc_524344278300_item	2669571	et	3	main
oli	doc_524344278300_item	2669573	et	3	main
уже	doc_524344278300_item	2669584	et	2	main
on	doc_524344278300_item	2669620	et	4	main
vormistatud	doc_524344278300_item	2669622	et	4	main
2	doc_524344278300_item	2669625	et	2	main
эту	doc_524344278300_item	2669634	et	2	main
меня	doc_524344278300_item	2669636	et	2	main
эркер	doc_524344278300_item	2669638	et	2	main
господском	doc_524344278300_item	2669640	et	2	main
jtammärkel	doc_524344278300_item	2669645	et	4	main
фонорь	doc_524344278300_item	2669647	et	2	main
kõrgusel	doc_524344278300_item	2669653	et	4	main
ja	doc_524344278300_item	2669659	et	3	main
vene	doc_524344278300_item	2669660	et	4	main
keeles	doc_524344278300_item	2669661	et	4	main
vormid	doc_524344278300_item	2669665	et	4	main
on	doc_524344278300_item	2669169	et	4	main
kuna	doc_524344278300_item	2669171	et	3	main
viidab	doc_524344278300_item	2669172	et	3	main
sajandi	doc_524344278300_item	2669174	et	3	main
ja	doc_524344278300_item	2669178	et	3	main
või	doc_524344278300_item	2669192	et	4	main
псих	doc_524344278300_item	2669193	et	2	main
mis	doc_524344278300_item	2669194	et	4	main
ei	doc_524344278300_item	2669200	et	4	main
ka	doc_524344278300_item	2669203	et	3	main
vaste	doc_524344278300_item	2669205	et	4	main
aga	doc_524344278300_item	2669207	et	3	main
сумасшедший	doc_524344278300_item	2669218	et	2	main
on	doc_524344278300_item	2669225	et	4	main
variant	doc_524344278300_item	2669224	et	3	main
безумец	doc_524344278300_item	2669228	et	2	main
siiski	doc_524344278300_item	2669231	et	4	main
16	doc_524344278300_item	2669244	et	2	main
peatükis	doc_524344278300_item	2669253	et	3	main
peateemaks	doc_524344278300_item	2669265	et	4	main
on	doc_524344278300_item	2669269	et	4	main
mikroteemad	doc_524344278300_item	2669280	et	3	main
välja	doc_524344278300_item	2669282	et	4	main
võtmesõnade	doc_524344278300_item	2669284	et	3	main
peidupaikmis	doc_524344278300_item	2669288	et	4	main
on	doc_524344278300_item	2669289	et	4	main
omamoodi	doc_524344278300_item	2669290	et	3	main
antud	doc_524344278300_item	2669291	et	4	main
katkendi	doc_524344278300_item	2669292	et	3	main
temaatiline	doc_524344278300_item	2669293	et	4	main
sõna	doc_524344278300_item	2669294	et	4	main
võtmesõna	doc_524344278300_item	2669295	et	4	main
millest	doc_524344278300_item	2669296	et	3	main
hakatakse	doc_524344278300_item	2669297	et	3	main
edasi	doc_524344278300_item	2669298	et	3	main
rääkima	doc_524344278300_item	2669299	et	3	main
kahtlased	doc_524344278300_item	2669300	et	3	main
paberid	doc_524344278300_item	2669301	et	3	main
jäävad	doc_524344278300_item	2669302	et	4	main
täna	doc_524344278300_item	2669303	et	4	main
päevasündmuste	doc_524344278300_item	2669304	et	3	main
kirjapanemine	doc_524344278300_item	2669305	et	3	main
tekst	doc_524344278300_item	2669307	et	3	main
mahavaikimine	doc_524344278300_item	2669306	et	3	main
on	doc_524344278300_item	2669308	et	4	main
hästi	doc_524344278300_item	2669309	et	3	main
seotud	doc_524344278300_item	2669310	et	4	main
teemade	doc_524344278300_item	2669311	et	4	main
arendus	doc_524344278300_item	2669312	et	4	main
toimub	doc_524344278300_item	2669313	et	3	main
sidususvahendite	doc_524344278300_item	2669314	et	4	main
kaudu	doc_524344278300_item	2669315	et	3	main
mis	doc_524344278300_item	2669316	et	4	main
teevad	doc_524344278300_item	2669317	et	3	main
tekstist	doc_524344278300_item	2669318	et	3	main
loogilist	doc_524344278300_item	2669319	et	4	main
tervikku	doc_524344278300_item	2669320	et	4	main
katkendi	doc_524344278300_item	2669235	et	3	main
pealkirjaks	doc_524344278300_item	2669236	et	3	main
on	doc_524344278300_item	2669237	et	4	main
laupäeval	doc_524344278300_item	2669238	et	3	main
autori	doc_524344278300_item	2669249	et	3	main
sõnum	doc_524344278300_item	2669251	et	3	main
mis	doc_524344278300_item	2669256	et	4	main
juulil	doc_524344278300_item	2669259	et	3	main
laupäeval	doc_524344278300_item	2669260	et	3	main
milletõttu	doc_524344278300_item	2669261	et	4	main
võib	doc_524344278300_item	2669262	et	3	main
seda	doc_524344278300_item	2669263	et	3	main
sõnaks	doc_524344278300_item	2669268	et	4	main
peidupaik	doc_524344278300_item	2669270	et	3	main
esineb	doc_524344278300_item	2669272	et	3	main
lõigu	doc_524344278300_item	2669273	et	4	main
esimeses	doc_524344278300_item	2669274	et	3	main
lauses	doc_524344278300_item	2669275	et	3	main
ja	doc_524344278300_item	2669276	et	3	main
struktuuriliselt	doc_524344278300_item	2669277	et	4	main
näol	doc_524344278300_item	2669285	et	4	main
on	doc_524344278300_item	2669287	et	4	main
vaadelda	doc_524344278300_item	2669322	et	4	main
on	doc_524344278300_item	2669333	et	4	main
asendaminepeidupaik	doc_524344278300_item	2669335	et	4	main
ülemise	doc_524344278300_item	2669345	et	4	main
nende	doc_524344278300_item	2669352	et	4	main
nimisõnakorduspiidalaua	doc_524344278300_item	2669353	et	4	main
paberid	doc_524344278300_item	2669364	et	3	main
on	doc_524344278300_item	2669369	et	4	main
kirja	doc_524344278300_item	2669371	et	4	main
on	doc_524344278300_item	2669377	et	4	main
asesõnaline	doc_524344278300_item	2669379	et	4	main
спальне	doc_524344278300_item	2669387	et	2	main
месте	doc_524344278300_item	2669392	et	2	main
они	doc_524344278300_item	2669396	et	2	main
täpsustamineв	doc_524344278300_item	2669401	et	2	main
märkida	doc_524344278300_item	2669328	et	4	main
magamiskambri	doc_524344278300_item	2669343	et	3	main
päevasündmuste	doc_524344278300_item	2669351	et	3	main
täna	doc_524344278300_item	2669357	et	4	main
kahtlased	doc_524344278300_item	2669363	et	3	main
venekeelses	doc_524344278300_item	2669375	et	3	main
эту	doc_524344278300_item	2669381	et	2	main
в	doc_524344278300_item	2669386	et	2	main
этом	doc_524344278300_item	2669391	et	2	main
сегодняшние	doc_524344278300_item	2669397	et	2	main
спальне	doc_524344278300_item	2669402	et	2	main
этом	doc_524344278300_item	2669406	et	2	main
месте	doc_524344278300_item	2669407	et	2	main
образовавшемся	doc_524344278300_item	2669409	et	2	main
таким	doc_524344278300_item	2669410	et	2	main
образом	doc_524344278300_item	2669411	et	2	main
в	doc_524344278300_item	2669408	et	2	main
пространстве	doc_524344278300_item	2669412	et	2	main
мои	doc_524344278300_item	2669413	et	2	main
опасные	doc_524344278300_item	2669414	et	2	main
бумаги	doc_524344278300_item	2669415	et	2	main
они	doc_524344278300_item	2669416	et	2	main
дневник	doc_524344278300_item	2669417	et	2	main
sõnakordusmehhanismчто	doc_524344278300_item	2669418	et	2	main
о	doc_524344278300_item	2669419	et	2	main
чём	doc_524344278300_item	2669420	et	2	main
eestikeelses	doc_524344278300_item	2669424	et	3	main
ka	doc_524344278300_item	2669427	et	3	main
sarnaseid	doc_524344278300_item	2669431	et	4	main
ühtne	doc_524344278300_item	2669436	et	3	main
tekstile	doc_524344278300_item	2669440	et	3	main
lõigus	doc_524344278300_item	2669455	et	3	main
olemas	doc_524344278300_item	2669457	et	4	main
mis	doc_524344278300_item	2669460	et	4	main
iga	doc_524344278300_item	2669479	et	4	main
erladi	doc_524344278300_item	2669481	et	4	main
noh	doc_524344278300_item	2669483	et	3	main
on	doc_524344278300_item	2669486	et	4	main
mul	doc_524344278300_item	2669487	et	3	main
уже	doc_524344278300_item	2669494	et	2	main
klaar	doc_524344278300_item	2669496	et	3	main
selgeeesti-vene	doc_524344278300_item	2669504	et	4	main
juba	doc_524344278300_item	2669512	et	3	main
убежище	doc_524344278300_item	2669525	et	2	main
tõlgitud	doc_524344278300_item	2669529	et	4	main
ei	doc_524344278300_item	2669532	et	4	main
tõlgimata	doc_524344278300_item	2669548	et	4	main
üldiselt	doc_524344278300_item	2669552	et	4	main
sega	doc_524344278300_item	2669554	et	4	main
lause	doc_524344278300_item	2669555	et	4	main
kuid	doc_524344278300_item	2669558	et	4	main
sellele	doc_524344278300_item	2669561	et	4	main
autor	doc_524344278300_item	2669564	et	3	main
kohmakas	doc_524344278300_item	2669580	et	4	main
tühemikus	doc_524344278300_item	2669349	et	3	main
sinna	doc_524344278300_item	2669361	et	3	main
paberid	doc_524344278300_item	2669366	et	3	main
mis	doc_524344278300_item	2669368	et	4	main
siia	doc_524344278300_item	2669370	et	4	main
tekstis	doc_524344278300_item	2669376	et	3	main
samamoodi	doc_524344278300_item	2669378	et	3	main
в	doc_524344278300_item	2669383	et	2	main
над	doc_524344278300_item	2669388	et	2	main
мои	doc_524344278300_item	2669393	et	2	main
события	doc_524344278300_item	2669398	et	2	main
дверью	doc_524344278300_item	2669404	et	2	main
seega	doc_524344278300_item	2669422	et	4	main
kui	doc_524344278300_item	2669426	et	3	main
variandis	doc_524344278300_item	2669462	et	3	main
теперь	doc_524344278300_item	2669492	et	2	main
selge	doc_524344278300_item	2669497	et	4	main
arusaadav	doc_524344278300_item	2669499	et	4	main
selgub	doc_524344278300_item	2669508	et	3	main
kirjeldab	doc_524344278300_item	2669511	et	3	main
asja	doc_524344278300_item	2669515	et	4	main
seega	doc_524344278300_item	2669516	et	4	main
httpwwwaseeedict	doc_524344278300_item	2669526	et	4	main
keelde	doc_524344278300_item	2669528	et	4	main
edukalt	doc_524344278300_item	2669530	et	4	main
tekst	doc_524344278300_item	2669531	et	3	main
olema	doc_524344278300_item	2669536	et	4	main
sõnad	doc_524344278300_item	2669546	et	4	main
on	doc_524344278300_item	2669547	et	4	main
päeviku	doc_524344278300_item	2669563	et	3	main
ise	doc_524344278300_item	2669565	et	4	main
see	doc_524344278300_item	2669570	et	3	main
peidupaigast	doc_524344278300_item	2669572	et	4	main
juttu	doc_524344278300_item	2669575	et	4	main
venekeelne	doc_524344278300_item	2669578	et	3	main
lause	doc_524344278300_item	2669579	et	4	main
теперь	doc_524344278300_item	2669582	et	2	main
härrastemaja-ärklist	doc_524344278300_item	2669630	et	4	main
ärkel	doc_524344278300_item	2669650	et	3	main
ülakorruste	doc_524344278300_item	2669652	et	3	main
eesti	doc_524344278300_item	2669658	et	4	main
erinevad	doc_524344278300_item	2669663	et	4	main
keeles	doc_524344278300_item	2669667	et	4	main
vene	doc_524344278300_item	2669670	et	4	main
vormistamine	doc_524344278300_item	2669676	et	4	main
siin	doc_524344278300_item	2669677	et	4	main
lauses	doc_524344278300_item	2669681	et	3	main
aga	doc_524344278300_item	2669686	et	3	main
lause	doc_524344278300_item	2669688	et	4	main
samaks	doc_524344278300_item	2669692	et	3	main
kõrged	doc_524344278300_item	2669700	et	3	main
nii	doc_524344278300_item	2669423	et	3	main
on	doc_524344278300_item	2669435	et	4	main
tõlgitud	doc_524344278300_item	2669437	et	4	main
varieeruvad	doc_524344278300_item	2669447	et	4	main
olevik	doc_524344278300_item	2669448	et	3	main
minevik	doc_524344278300_item	2669449	et	3	main
eestikeelses	doc_524344278300_item	2669450	et	3	main
venekeelses	doc_524344278300_item	2669454	et	3	main
ka	doc_524344278300_item	2669458	et	3	main
olevikсегодня	doc_524344278300_item	2669464	et	2	main
они	doc_524344278300_item	2669465	et	2	main
там	doc_524344278300_item	2669466	et	2	main
и	doc_524344278300_item	2669467	et	2	main
останутся	doc_524344278300_item	2669468	et	2	main
потому	doc_524344278300_item	2669469	et	2	main
что	doc_524344278300_item	2669470	et	2	main
ja	doc_524344278300_item	2669471	et	3	main
need	doc_524344278300_item	2669472	et	3	main
paberid	doc_524344278300_item	2669473	et	3	main
jäävadki	doc_524344278300_item	2669474	et	4	main
täna	doc_524344278300_item	2669475	et	4	main
sinna	doc_524344278300_item	2669476	et	3	main
edasi	doc_524344278300_item	2669477	et	3	main
vaatlen	doc_524344278300_item	2669478	et	3	main
on	doc_524344278300_item	2669463	et	4	main
see	doc_524344278300_item	2669484	et	3	main
тайник	doc_524344278300_item	2669493	et	2	main
läbipaistev	doc_524344278300_item	2669498	et	4	main
korras	doc_524344278300_item	2669500	et	4	main
jtamm	doc_524344278300_item	2669506	et	4	main
et	doc_524344278300_item	2669509	et	3	main
valmis	doc_524344278300_item	2669513	et	4	main
loogiline	doc_524344278300_item	2669522	et	4	main
тайник	doc_524344278300_item	2669524	et	2	main
tõlgitud	doc_524344278300_item	2669537	et	4	main
peamine	doc_524344278300_item	2669538	et	3	main
asi	doc_524344278300_item	2669539	et	4	main
et	doc_524344278300_item	2669540	et	3	main
mõte	doc_524344278300_item	2669541	et	3	main
säiliks	doc_524344278300_item	2669542	et	3	main
jäänudsee	doc_524344278300_item	2669549	et	4	main
arusaamist	doc_524344278300_item	2669557	et	4	main
mul	doc_524344278300_item	2669559	et	3	main
viidab	doc_524344278300_item	2669560	et	3	main
et	doc_524344278300_item	2669562	et	3	main
samas	doc_524344278300_item	2669576	et	4	main
tundub	doc_524344278300_item	2669577	et	3	main
ja	doc_524344278300_item	2669583	et	3	main
ühtmoodi	doc_524344278300_item	2669621	et	3	main
mõlemas	doc_524344278300_item	2669623	et	3	main
laenatud	doc_524344278300_item	2669631	et	4	main
mõte	doc_524344278300_item	2669632	et	3	main
на	doc_524344278300_item	2669633	et	2	main
мысль	doc_524344278300_item	2669635	et	2	main
навёл	doc_524344278300_item	2669637	et	2	main
в	doc_524344278300_item	2669639	et	2	main
доме	doc_524344278300_item	2669641	et	2	main
ärkel	doc_524344278300_item	2669642	et	3	main
sõnaraamat	doc_524344278300_item	2669644	et	3	main
эркер	doc_524344278300_item	2669646	et	2	main
eenduv	doc_524344278300_item	2669655	et	4	main
eesti	doc_524344278300_item	2669666	et	4	main
minevik	doc_524344278300_item	2669673	et	3	main
ja	doc_524344278300_item	2669674	et	3	main
venekeelses	doc_524344278300_item	2669680	et	3	main
ärkel	doc_524344278300_item	2669684	et	3	main
aga	doc_524344278300_item	2669691	et	3	main
3	doc_524344278300_item	2669693	et	2	main
jaoks	doc_524344278300_item	2669698	et	4	main
uksed	doc_524344278300_item	2669702	et	3	main
менее	doc_524344278300_item	2669730	et	2	main
о	doc_524344278300_item	2669734	et	2	main
suhteliselt	doc_524344278300_item	2669737	et	4	main
enam	doc_524344278300_item	2669739	et	4	main
millegi	doc_524344278300_item	2669757	et	4	main
sõnaraamat	doc_524344278300_item	2669760	et	3	main
liiga	doc_524344278300_item	2669763	et	4	main
vahelisel	doc_524344278300_item	2669795	et	4	main
ülemise	doc_524344278300_item	2669799	et	4	main
nii	doc_524344278300_item	2669804	et	3	main
lükata	doc_524344278300_item	2669815	et	4	main
оторвал	doc_524344278300_item	2669820	et	2	main
над	doc_524344278300_item	2669824	et	2	main
что	doc_524344278300_item	2669831	et	2	main
наполовину	doc_524344278300_item	2669837	et	2	main
kuid	doc_524344278300_item	2669855	et	4	main
tõlgitud	doc_524344278300_item	2669864	et	4	main
оторвать	doc_524344278300_item	2669866	et	2	main
elektrooniline	doc_524344278300_item	2669869	et	4	main
разъять	doc_524344278300_item	2669875	et	2	main
sõnaraamatusj	doc_524344278300_item	2669882	et	4	main
tamm	doc_524344278300_item	2669883	et	3	main
on	doc_524344278300_item	2669884	et	4	main
ühendust	doc_524344278300_item	2669894	et	4	main
koost	doc_524344278300_item	2669899	et	4	main
разбиратьает	doc_524344278300_item	2669901	et	2	main
võtma	doc_524344278300_item	2669905	et	3	main
оторвать	doc_524344278300_item	2669911	et	2	main
on	doc_524344278300_item	2669913	et	4	main
keeles	doc_524344278300_item	2669915	et	4	main
olemasolev	doc_524344278300_item	2669916	et	3	main
sõnaühend	doc_524344278300_item	2669917	et	3	main
ole	doc_524344278300_item	2669922	et	4	main
õige	doc_524344278300_item	2669924	et	4	main
lause	doc_524344278300_item	2669480	et	4	main
1	doc_524344278300_item	2669482	et	2	main
peidupaik	doc_524344278300_item	2669485	et	3	main
nüüd	doc_524344278300_item	2669488	et	4	main
klaar	doc_524344278300_item	2669489	et	3	main
ну	doc_524344278300_item	2669490	et	2	main
готов	doc_524344278300_item	2669495	et	2	main
valmis	doc_524344278300_item	2669501	et	4	main
õs	doc_524344278300_item	2669502	et	4	main
klaar	doc_524344278300_item	2669503	et	3	main
kontekstist	doc_524344278300_item	2669507	et	3	main
autor	doc_524344278300_item	2669510	et	3	main
olevat	doc_524344278300_item	2669514	et	4	main
klaar	doc_524344278300_item	2669517	et	3	main
tõlgituna	doc_524344278300_item	2669518	et	4	main
nagu	doc_524344278300_item	2669519	et	3	main
готов	doc_524344278300_item	2669520	et	2	main
on	doc_524344278300_item	2669521	et	4	main
peidupaik	doc_524344278300_item	2669523	et	3	main
antud	doc_524344278300_item	2669543	et	4	main
lauses	doc_524344278300_item	2669544	et	3	main
mõned	doc_524344278300_item	2669545	et	3	main
mul	doc_524344278300_item	2669550	et	3	main
ei	doc_524344278300_item	2669553	et	4	main
selle	doc_524344278300_item	2669567	et	4	main
valmis	doc_524344278300_item	2669568	et	4	main
juba	doc_524344278300_item	2669574	et	3	main
sõna	doc_524344278300_item	2669581	et	4	main
võiks	doc_524344278300_item	2669585	et	4	main
asendada	doc_524344278300_item	2669586	et	3	main
наконец	doc_524344278300_item	2669587	et	2	main
ja	doc_524344278300_item	2669588	et	3	main
lisada	doc_524344278300_item	2669589	et	3	main
sinna	doc_524344278300_item	2669590	et	3	main
keelde	doc_524344278300_item	2669592	et	4	main
vene	doc_524344278300_item	2669591	et	4	main
tõlgitud	doc_524344278300_item	2669593	et	4	main
mul-asesõna	doc_524344278300_item	2669594	et	4	main
näiteks	doc_524344278300_item	2669595	et	4	main
ну	doc_524344278300_item	2669596	et	2	main
мой	doc_524344278300_item	2669599	et	2	main
вот	doc_524344278300_item	2669597	et	2	main
тайник	doc_524344278300_item	2669600	et	2	main
наконец	doc_524344278300_item	2669598	et	2	main
готов	doc_524344278300_item	2669601	et	2	main
sest	doc_524344278300_item	2669602	et	4	main
теперь	doc_524344278300_item	2669603	et	2	main
ja	doc_524344278300_item	2669604	et	3	main
уже	doc_524344278300_item	2669605	et	2	main
annavad	doc_524344278300_item	2669606	et	3	main
tähendusnüanssi	doc_524344278300_item	2669608	et	4	main
sellise	doc_524344278300_item	2669607	et	4	main
juurde	doc_524344278300_item	2669609	et	4	main
et	doc_524344278300_item	2669610	et	3	main
asi	doc_524344278300_item	2669611	et	4	main
on	doc_524344278300_item	2669612	et	4	main
tehtud	doc_524344278300_item	2669613	et	4	main
ja	doc_524344278300_item	2669614	et	3	main
pole	doc_524344278300_item	2669615	et	3	main
enam	doc_524344278300_item	2669616	et	4	main
midagi	doc_524344278300_item	2669617	et	4	main
parata	doc_524344278300_item	2669618	et	3	main
alus	doc_524344278300_item	2669619	et	4	main
keeles	doc_524344278300_item	2669624	et	4	main
see	doc_524344278300_item	2669626	et	3	main
монсардаeesti-vene	doc_524344278300_item	2669643	et	2	main
чердак	doc_524344278300_item	2669648	et	2	main
eh	doc_524344278300_item	2669651	et	3	main
seinast	doc_524344278300_item	2669654	et	4	main
hooneosaõs	doc_524344278300_item	2669656	et	4	main
kuigi	doc_524344278300_item	2669657	et	3	main
vahendidverbi	doc_524344278300_item	2669664	et	4	main
isikuline	doc_524344278300_item	2669672	et	4	main
aluse	doc_524344278300_item	2669675	et	4	main
siin	doc_524344278300_item	2669696	et	4	main
liiga	doc_524344278300_item	2669699	et	4	main
võrdlemisi	doc_524344278300_item	2669704	et	4	main
здесь	doc_524344278300_item	2669706	et	2	main
высокие	doc_524344278300_item	2669709	et	2	main
двери	doc_524344278300_item	2669711	et	2	main
сравнительно	doc_524344278300_item	2669721	et	2	main
jtamm	doc_524344278300_item	2669724	et	4	main
более	doc_524344278300_item	2669728	et	2	main
отделался	doc_524344278300_item	2669736	et	2	main
võrdlemisi	doc_524344278300_item	2669738	et	4	main
vähem	doc_524344278300_item	2669740	et	4	main
2предлог	doc_524344278300_item	2669741	et	2	main
с	doc_524344278300_item	2669742	et	2	main
род	doc_524344278300_item	2669743	et	2	main
п	doc_524344278300_item	2669744	et	2	main
ово	doc_524344278300_item	2669745	et	2	main
2	doc_524344278300_item	2669746	et	2	main
знач	doc_524344278300_item	2669747	et	2	main
kohta	doc_524344278300_item	2669756	et	4	main
suhtesvene-eesti	doc_524344278300_item	2669758	et	4	main
seletav	doc_524344278300_item	2669759	et	4	main
on	doc_524344278300_item	2669762	et	4	main
siin	doc_524344278300_item	2669764	et	4	main
kõrged	doc_524344278300_item	2669765	et	3	main
uksed	doc_524344278300_item	2669766	et	3	main
on	doc_524344278300_item	2669767	et	4	main
on	doc_524344278300_item	2669781	et	4	main
ka	doc_524344278300_item	2669782	et	3	main
ja	doc_524344278300_item	2669802	et	3	main
seda	doc_524344278300_item	2669806	et	3	main
saab	doc_524344278300_item	2669808	et	3	main
poole	doc_524344278300_item	2669814	et	4	main
on	doc_524344278300_item	2669627	et	4	main
tegelikult	doc_524344278300_item	2669628	et	4	main
minu	doc_524344278300_item	2669629	et	3	main
httpwwwaseeedict	doc_524344278300_item	2669649	et	4	main
kasutatud	doc_524344278300_item	2669662	et	4	main
keeles	doc_524344278300_item	2669671	et	4	main
on	doc_524344278300_item	2669678	et	4	main
aluseks	doc_524344278300_item	2669682	et	4	main
selle	doc_524344278300_item	2669697	et	4	main
потолки	doc_524344278300_item	2669707	et	2	main
относительно	doc_524344278300_item	2669712	et	2	main
низкие	doc_524344278300_item	2669713	et	2	main
võrdlemisi	doc_524344278300_item	2669714	et	4	main
suhteliselt	doc_524344278300_item	2669715	et	4	main
üsnaõs	doc_524344278300_item	2669716	et	4	main
võrdlemisi	doc_524344278300_item	2669717	et	4	main
относительно	doc_524344278300_item	2669718	et	2	main
httpwwwaseeedict	doc_524344278300_item	2669719	et	4	main
võrdlemisi	doc_524344278300_item	2669720	et	4	main
eesti-vene	doc_524344278300_item	2669722	et	4	main
до	doc_524344278300_item	2669731	et	2	main
легко	doc_524344278300_item	2669735	et	2	main
laed	doc_524344278300_item	2669761	et	4	main
laused	doc_524344278300_item	2669780	et	3	main
sümmeetriliselt	doc_524344278300_item	2669783	et	4	main
koostatud	doc_524344278300_item	2669784	et	4	main
struktuuri	doc_524344278300_item	2669785	et	4	main
poolest	doc_524344278300_item	2669786	et	4	main
väga	doc_524344278300_item	2669787	et	3	main
sarnased	doc_524344278300_item	2669788	et	4	main
4	doc_524344278300_item	2669789	et	2	main
ma	doc_524344278300_item	2669790	et	3	main
võtsin	doc_524344278300_item	2669791	et	3	main
magamiskambri	doc_524344278300_item	2669797	et	3	main
sättisin	doc_524344278300_item	2669803	et	3	main
lauda	doc_524344278300_item	2669807	et	4	main
pikkuses	doc_524344278300_item	2669812	et	4	main
küübi	doc_524344278300_item	2669817	et	3	main
в	doc_524344278300_item	2669821	et	2	main
и	doc_524344278300_item	2669826	et	2	main
одним	doc_524344278300_item	2669832	et	2	main
можно	doc_524344278300_item	2669836	et	2	main
крышку	doc_524344278300_item	2669841	et	2	main
struktuuri	doc_524344278300_item	2669844	et	4	main
on	doc_524344278300_item	2669863	et	4	main
aga	doc_524344278300_item	2669868	et	3	main
разбирать	doc_524344278300_item	2669874	et	2	main
развести	doc_524344278300_item	2669878	et	2	main
vene	doc_524344278300_item	2669881	et	4	main
antud	doc_524344278300_item	2669885	et	4	main
järgmised	doc_524344278300_item	2669886	et	3	main
seletused	doc_524344278300_item	2669887	et	4	main
katkestama	doc_524344278300_item	2669895	et	3	main
обнажитьит	doc_524344278300_item	2669907	et	2	main
vene	doc_524344278300_item	2669914	et	4	main
kontekstis	doc_524344278300_item	2669927	et	3	main
oma	doc_524344278300_item	2669928	et	4	main
наличник	doc_524344278300_item	2669939	et	2	main
дверью	doc_524344278300_item	2669941	et	2	main
siin	doc_524344278300_item	2669942	et	4	main
poolt	doc_524344278300_item	2669949	et	4	main
täpsem	doc_524344278300_item	2669963	et	4	main
ja	doc_524344278300_item	2669964	et	3	main
detailid	doc_524344278300_item	2669969	et	3	main
õs	doc_524344278300_item	2669973	et	4	main
seletab	doc_524344278300_item	2669974	et	3	main
etn	doc_524344278300_item	2669977	et	4	main
piklik	doc_524344278300_item	2669978	et	3	main
seda	doc_524344278300_item	2669981	et	3	main
osast	doc_524344278300_item	2669986	et	4	main
umbisikuline	doc_524344278300_item	2669668	et	4	main
tegumood	doc_524344278300_item	2669669	et	3	main
erinev	doc_524344278300_item	2669679	et	4	main
on	doc_524344278300_item	2669683	et	4	main
eestikeelses	doc_524344278300_item	2669685	et	3	main
mõte	doc_524344278300_item	2669687	et	3	main
mõte	doc_524344278300_item	2669689	et	3	main
jääb	doc_524344278300_item	2669690	et	3	main
laed	doc_524344278300_item	2669694	et	4	main
on	doc_524344278300_item	2669695	et	4	main
aga	doc_524344278300_item	2669701	et	3	main
on	doc_524344278300_item	2669703	et	4	main
madalad	doc_524344278300_item	2669705	et	3	main
очень	doc_524344278300_item	2669708	et	2	main
а	doc_524344278300_item	2669710	et	2	main
относительно	doc_524344278300_item	2669725	et	2	main
или	doc_524344278300_item	2669729	et	2	main
степени	doc_524344278300_item	2669733	et	2	main
по	doc_524344278300_item	2669748	et	2	main
выполнения	doc_524344278300_item	2669754	et	2	main
ja	doc_524344278300_item	2669779	et	3	main
uksel	doc_524344278300_item	2669796	et	3	main
et	doc_524344278300_item	2669805	et	3	main
ühe	doc_524344278300_item	2669809	et	4	main
käeliigutusega	doc_524344278300_item	2669810	et	4	main
pahemale	doc_524344278300_item	2669813	et	4	main
nagu	doc_524344278300_item	2669816	et	3	main
я	doc_524344278300_item	2669819	et	2	main
спальне	doc_524344278300_item	2669822	et	2	main
его	doc_524344278300_item	2669828	et	2	main
движением	doc_524344278300_item	2669833	et	2	main
сдвинуть	doc_524344278300_item	2669838	et	2	main
пенала	doc_524344278300_item	2669842	et	2	main
laused	doc_524344278300_item	2669846	et	3	main
on	doc_524344278300_item	2669852	et	4	main
vormistatud	doc_524344278300_item	2669854	et	4	main
võtma	doc_524344278300_item	2669862	et	3	main
annab	doc_524344278300_item	2669871	et	3	main
lahti	doc_524344278300_item	2669888	et	4	main
võtma	doc_524344278300_item	2669889	et	3	main
раскрытькроет	doc_524344278300_item	2669891	et	2	main
разъединитьит	doc_524344278300_item	2669897	et	2	main
разобратьразберёт	doc_524344278300_item	2669902	et	2	main
paljaks	doc_524344278300_item	2669904	et	3	main
что	doc_524344278300_item	2669909	et	2	main
наличник	doc_524344278300_item	2669912	et	2	main
ei	doc_524344278300_item	2669921	et	4	main
päris	doc_524344278300_item	2669923	et	4	main
vahelisel	doc_524344278300_item	2669931	et	4	main
uksel	doc_524344278300_item	2669932	et	3	main
magamiskambri	doc_524344278300_item	2669933	et	3	main
poolt	doc_524344278300_item	2669934	et	4	main
tõlgimata	doc_524344278300_item	2669944	et	4	main
kahe	doc_524344278300_item	2669945	et	3	main
toa	doc_524344278300_item	2669946	et	3	main
autor	doc_524344278300_item	2669951	et	3	main
lühem	doc_524344278300_item	2669965	et	4	main
aga	doc_524344278300_item	2669966	et	3	main
seda	doc_524344278300_item	2669975	et	3	main
nii	doc_524344278300_item	2669976	et	3	main
lükandkaanega	doc_524344278300_item	2669979	et	3	main
karp	doc_524344278300_item	2669980	et	3	main
eestikeelses	doc_524344278300_item	2669989	et	3	main
vaevalt	doc_524344278300_item	2670024	et	4	main
mis	doc_524344278300_item	2670027	et	4	main
see	doc_524344278300_item	2670029	et	3	main
on	doc_524344278300_item	2670031	et	4	main
ajal	doc_524344278300_item	2670036	et	4	main
oli	doc_524344278300_item	2670037	et	3	main
teos	doc_524344278300_item	2670038	et	4	main
kirjutatud	doc_524344278300_item	2670039	et	4	main
ja	doc_524344278300_item	2670040	et	3	main
saagisin	doc_524344278300_item	2670046	et	3	main
kahtlased	doc_524344278300_item	2670059	et	3	main
varjul	doc_524344278300_item	2670062	et	4	main
в	doc_524344278300_item	2670065	et	2	main
кусок	doc_524344278300_item	2670068	et	2	main
в	doc_524344278300_item	2670071	et	2	main
полтора	doc_524344278300_item	2670072	et	2	main
образовавшемся	doc_524344278300_item	2670075	et	2	main
sõnaraamat	doc_524344278300_item	2669723	et	3	main
1	doc_524344278300_item	2669726	et	2	main
нареч	doc_524344278300_item	2669727	et	2	main
нек-рой	doc_524344278300_item	2669732	et	2	main
отношению	doc_524344278300_item	2669749	et	2	main
по	doc_524344278300_item	2669750	et	2	main
поводу	doc_524344278300_item	2669751	et	2	main
данные	doc_524344278300_item	2669752	et	2	main
о	doc_524344278300_item	2669753	et	2	main
плана	doc_524344278300_item	2669755	et	2	main
võrdlemisi	doc_524344278300_item	2669768	et	4	main
madalad	doc_524344278300_item	2669769	et	3	main
потолки	doc_524344278300_item	2669770	et	2	main
очень	doc_524344278300_item	2669771	et	2	main
высокие	doc_524344278300_item	2669772	et	2	main
а	doc_524344278300_item	2669773	et	2	main
двери	doc_524344278300_item	2669774	et	2	main
относительно	doc_524344278300_item	2669775	et	2	main
низкие	doc_524344278300_item	2669776	et	2	main
täpne	doc_524344278300_item	2669777	et	3	main
tõlge	doc_524344278300_item	2669778	et	3	main
oma	doc_524344278300_item	2669792	et	4	main
kahe	doc_524344278300_item	2669793	et	3	main
toa	doc_524344278300_item	2669794	et	3	main
poolt	doc_524344278300_item	2669798	et	4	main
piidalaua	doc_524344278300_item	2669800	et	4	main
lahti	doc_524344278300_item	2669801	et	4	main
pooles	doc_524344278300_item	2669811	et	4	main
kaant	doc_524344278300_item	2669818	et	3	main
наличник	doc_524344278300_item	2669823	et	2	main
укрепил	doc_524344278300_item	2669827	et	2	main
образом	doc_524344278300_item	2669830	et	2	main
доску	doc_524344278300_item	2669835	et	2	main
влево	doc_524344278300_item	2669839	et	2	main
poolest	doc_524344278300_item	2669845	et	4	main
sarnased	doc_524344278300_item	2669848	et	4	main
ja	doc_524344278300_item	2669850	et	3	main
sihitis	doc_524344278300_item	2669851	et	3	main
sõnastik	doc_524344278300_item	2669870	et	3	main
seletusi	doc_524344278300_item	2669873	et	4	main
отконопатить	doc_524344278300_item	2669876	et	2	main
eesti	doc_524344278300_item	2669880	et	4	main
разъединятьяет	doc_524344278300_item	2669896	et	2	main
что	doc_524344278300_item	2669898	et	2	main
lahti	doc_524344278300_item	2669900	et	4	main
что	doc_524344278300_item	2669903	et	2	main
обнажатьает	doc_524344278300_item	2669906	et	2	main
kuid	doc_524344278300_item	2669918	et	4	main
tundub	doc_524344278300_item	2669919	et	3	main
et	doc_524344278300_item	2669920	et	3	main
antud	doc_524344278300_item	2669926	et	4	main
piidalaua	doc_524344278300_item	2669936	et	4	main
в	doc_524344278300_item	2669937	et	2	main
спальне	doc_524344278300_item	2669938	et	2	main
над	doc_524344278300_item	2669940	et	2	main
venekeelne	doc_524344278300_item	2669960	et	3	main
lause	doc_524344278300_item	2669961	et	4	main
on	doc_524344278300_item	2669962	et	4	main
algteksti	doc_524344278300_item	2669968	et	4	main
leida	doc_524344278300_item	2669983	et	3	main
selgituse	doc_524344278300_item	2669985	et	4	main
aga	doc_524344278300_item	2669987	et	3	main
variandis	doc_524344278300_item	2669990	et	3	main
дверью	doc_524344278300_item	2669825	et	2	main
таким	doc_524344278300_item	2669829	et	2	main
руки	doc_524344278300_item	2669834	et	2	main
как	doc_524344278300_item	2669840	et	2	main
lause	doc_524344278300_item	2669843	et	4	main
on	doc_524344278300_item	2669847	et	4	main
alus	doc_524344278300_item	2669849	et	4	main
ühtmoodi	doc_524344278300_item	2669853	et	3	main
mõned	doc_524344278300_item	2669856	et	3	main
sõnad	doc_524344278300_item	2669857	et	4	main
on	doc_524344278300_item	2669858	et	4	main
osaliselt	doc_524344278300_item	2669859	et	4	main
tõlgitud	doc_524344278300_item	2669860	et	4	main
lahti	doc_524344278300_item	2669861	et	4	main
nagu	doc_524344278300_item	2669865	et	3	main
millele	doc_524344278300_item	2669867	et	3	main
järgmisi	doc_524344278300_item	2669872	et	3	main
почать	doc_524344278300_item	2669877	et	2	main
httpvene-eestiaseee	doc_524344278300_item	2669879	et	4	main
раскрыватьает	doc_524344278300_item	2669890	et	2	main
что	doc_524344278300_item	2669892	et	2	main
tehn	doc_524344278300_item	2669893	et	4	main
кого	doc_524344278300_item	2669908	et	2	main
samas	doc_524344278300_item	2669910	et	4	main
kahe	doc_524344278300_item	2669929	et	3	main
toa	doc_524344278300_item	2669930	et	3	main
on	doc_524344278300_item	2669943	et	4	main
arvatavasti	doc_524344278300_item	2669950	et	3	main
pidanud	doc_524344278300_item	2669953	et	4	main
kadunud	doc_524344278300_item	2669971	et	4	main
teose	doc_524344278300_item	2669984	et	3	main
keelde	doc_524344278300_item	2669992	et	4	main
пенал	doc_524344278300_item	2669994	et	2	main
tõlgitud	doc_524344278300_item	2669993	et	4	main
see	doc_524344278300_item	2669995	et	3	main
sõna	doc_524344278300_item	2669996	et	4	main
tõmbas	doc_524344278300_item	2669997	et	3	main
minu	doc_524344278300_item	2669998	et	3	main
tähelepanu	doc_524344278300_item	2669999	et	4	main
sest	doc_524344278300_item	2670000	et	4	main
kui	doc_524344278300_item	2670001	et	3	main
vanema	doc_524344278300_item	2670002	et	4	main
põlvkonna	doc_524344278300_item	2670003	et	4	main
jaoks	doc_524344278300_item	2670004	et	4	main
venekeelne	doc_524344278300_item	2670005	et	3	main
sõna	doc_524344278300_item	2670006	et	4	main
пенал	doc_524344278300_item	2670007	et	2	main
assitsieerub	doc_524344278300_item	2670008	et	4	main
kooli	doc_524344278300_item	2670009	et	4	main
asjaga	doc_524344278300_item	2670010	et	3	main
ja	doc_524344278300_item	2670011	et	3	main
neil	doc_524344278300_item	2670012	et	4	main
on	doc_524344278300_item	2670013	et	4	main
ettekujutus	doc_524344278300_item	2670014	et	4	main
missugusest	doc_524344278300_item	2670015	et	3	main
karbistvormi	doc_524344278300_item	2670016	et	4	main
poolest	doc_524344278300_item	2670017	et	4	main
räägitakse	doc_524344278300_item	2670018	et	3	main
siis	doc_524344278300_item	2670019	et	3	main
kaasaegne	doc_524344278300_item	2670020	et	3	main
tänapäeva	doc_524344278300_item	2670022	et	4	main
tuleb	doc_524344278300_item	2670032	et	3	main
lauatagusest	doc_524344278300_item	2670044	et	3	main
образом	doc_524344278300_item	2670077	et	2	main
теперь	doc_524344278300_item	2670080	et	2	main
venekeelses	doc_524344278300_item	2670107	et	3	main
asesõnaga	doc_524344278300_item	2670110	et	3	main
jala	doc_524344278300_item	2670112	et	4	main
длиной	doc_524344278300_item	2670115	et	2	main
полтора	doc_524344278300_item	2670117	et	2	main
tõlge	doc_524344278300_item	2669925	et	3	main
ülemise	doc_524344278300_item	2669935	et	4	main
vahelisel	doc_524344278300_item	2669947	et	4	main
ja	doc_524344278300_item	2669948	et	3	main
ei	doc_524344278300_item	2669952	et	4	main
vajalikuks	doc_524344278300_item	2669954	et	3	main
seda	doc_524344278300_item	2669955	et	3	main
tõlkida	doc_524344278300_item	2669956	et	3	main
ja	doc_524344278300_item	2669957	et	3	main
jäi	doc_524344278300_item	2669958	et	3	main
vahele	doc_524344278300_item	2669959	et	4	main
samas	doc_524344278300_item	2669967	et	4	main
on	doc_524344278300_item	2669970	et	4	main
küüp	doc_524344278300_item	2669972	et	3	main
võib	doc_524344278300_item	2669982	et	3	main
lugeja	doc_524344278300_item	2670021	et	4	main
noored	doc_524344278300_item	2670023	et	3	main
sellega	doc_524344278300_item	2670034	et	3	main
mis	doc_524344278300_item	2670035	et	4	main
palgist	doc_524344278300_item	2670045	et	3	main
ma	doc_524344278300_item	2670047	et	3	main
jala	doc_524344278300_item	2670051	et	4	main
pikkuse	doc_524344278300_item	2670052	et	4	main
minu	doc_524344278300_item	2670058	et	3	main
пространстве	doc_524344278300_item	2670078	et	2	main
ühe	doc_524344278300_item	2670091	et	4	main
asesõna	doc_524344278300_item	2670106	et	4	main
tükk	doc_524344278300_item	2670114	et	3	main
on	doc_524344278300_item	2670119	et	4	main
sellest	doc_524344278300_item	2670130	et	4	main
teadlik	doc_524344278300_item	2670131	et	3	main
образом	doc_524344278300_item	2670137	et	2	main
nii	doc_524344278300_item	2670139	et	3	main
keeles	doc_524344278300_item	2670144	et	4	main
on	doc_524344278300_item	2670145	et	4	main
keeles	doc_524344278300_item	2670151	et	4	main
pikemalt	doc_524344278300_item	2670152	et	4	main
teos	doc_524344278300_item	2670165	et	4	main
võimete	doc_524344278300_item	2670190	et	4	main
käivad	doc_524344278300_item	2670194	et	4	main
kuid	doc_524344278300_item	2670196	et	4	main
venekeelses	doc_524344278300_item	2670197	et	3	main
tõlkes	doc_524344278300_item	2670198	et	3	main
autor	doc_524344278300_item	2670199	et	3	main
eelistas	doc_524344278300_item	2670200	et	3	main
neutraalset	doc_524344278300_item	2670201	et	3	main
vormi	doc_524344278300_item	2670202	et	4	main
хранятся	doc_524344278300_item	2670203	et	2	main
6	doc_524344278300_item	2670204	et	2	main
ja	doc_524344278300_item	2670205	et	3	main
need	doc_524344278300_item	2670206	et	3	main
ainult	doc_524344278300_item	2669988	et	4	main
vene	doc_524344278300_item	2669991	et	4	main
saab	doc_524344278300_item	2670025	et	3	main
selline	doc_524344278300_item	2670030	et	4	main
tõlgitud	doc_524344278300_item	2670041	et	4	main
5	doc_524344278300_item	2670042	et	2	main
paberid	doc_524344278300_item	2670060	et	3	main
я	doc_524344278300_item	2670063	et	2	main
этом	doc_524344278300_item	2670066	et	2	main
балки	doc_524344278300_item	2670069	et	2	main
в	doc_524344278300_item	2670074	et	2	main
хранятся	doc_524344278300_item	2670079	et	2	main
бумаги	doc_524344278300_item	2670083	et	2	main
lauset	doc_524344278300_item	2670087	et	3	main
järgmise	doc_524344278300_item	2670103	et	3	main
on	doc_524344278300_item	2670123	et	4	main
eesti	doc_524344278300_item	2670124	et	4	main
tühemikus	doc_524344278300_item	2670133	et	3	main
пространстве	doc_524344278300_item	2670138	et	2	main
ka	doc_524344278300_item	2670142	et	3	main
vene	doc_524344278300_item	2670150	et	4	main
täpsustatakse	doc_524344278300_item	2670153	et	3	main
mis	doc_524344278300_item	2670154	et	4	main
tühemikus-	doc_524344278300_item	2670155	et	3	main
в	doc_524344278300_item	2670156	et	2	main
таким	doc_524344278300_item	2670158	et	2	main
siin	doc_524344278300_item	2670170	et	4	main
kohtub	doc_524344278300_item	2670171	et	3	main
ka	doc_524344278300_item	2670172	et	3	main
metafoore	doc_524344278300_item	2670173	et	4	main
nagu	doc_524344278300_item	2670174	et	3	main
kasutusel	doc_524344278300_item	2670180	et	4	main
liik	doc_524344278300_item	2670183	et	3	main
ehk	doc_524344278300_item	2670186	et	3	main
elusa	doc_524344278300_item	2670188	et	3	main
потому	doc_524344278300_item	2670224	et	2	main
нужно	doc_524344278300_item	2670227	et	2	main
события	doc_524344278300_item	2670233	et	2	main
kahele	doc_524344278300_item	2670237	et	4	main
lausele	doc_524344278300_item	2670239	et	3	main
eesti	doc_524344278300_item	2670241	et	4	main
eelmise	doc_524344278300_item	2670243	et	3	main
lausega	doc_524344278300_item	2670244	et	3	main
seob	doc_524344278300_item	2670245	et	3	main
sõnakordusmehhanism	doc_524344278300_item	2670246	et	3	main
nimisõnakordus-paberid	doc_524344278300_item	2670247	et	3	main
asendamist	doc_524344278300_item	2670263	et	4	main
мои	doc_524344278300_item	2670264	et	2	main
опасные	doc_524344278300_item	2670265	et	2	main
бумаги	doc_524344278300_item	2670266	et	2	main
они	doc_524344278300_item	2670267	et	2	main
дневник	doc_524344278300_item	2670277	et	2	main
keeles	doc_524344278300_item	2670279	et	4	main
täpsustatakse	doc_524344278300_item	2670280	et	3	main
kuhu	doc_524344278300_item	2670281	et	3	main
on	doc_524344278300_item	2670291	et	4	main
ole	doc_524344278300_item	2670296	et	4	main
sünonüüm	doc_524344278300_item	2670297	et	3	main
mida	doc_524344278300_item	2670303	et	4	main
sinna	doc_524344278300_item	2670317	et	3	main
останутся	doc_524344278300_item	2670320	et	2	main
там	doc_524344278300_item	2670322	et	2	main
сегодняшние	doc_524344278300_item	2670326	et	2	main
нужно	doc_524344278300_item	2670349	et	2	main
события	doc_524344278300_item	2670355	et	2	main
see	doc_524344278300_item	2670357	et	3	main
võib	doc_524344278300_item	2670358	et	3	main
targem	doc_524344278300_item	2670376	et	4	main
mis	doc_524344278300_item	2670384	et	4	main
juba	doc_524344278300_item	2670387	et	3	main
on	doc_524344278300_item	2670389	et	4	main
mõttetu	doc_524344278300_item	2670403	et	4	main
подумал	doc_524344278300_item	2670404	et	2	main
наверно	doc_524344278300_item	2670405	et	2	main
не	doc_524344278300_item	2670410	et	2	main
но	doc_524344278300_item	2670414	et	2	main
меня	doc_524344278300_item	2670419	et	2	main
решил	doc_524344278300_item	2670423	et	2	main
либо	doc_524344278300_item	2670432	et	2	main
turgatas	doc_524344278300_item	2670434	et	3	main
aru	doc_524344278300_item	2670026	et	4	main
pinal	doc_524344278300_item	2670028	et	3	main
arvestada	doc_524344278300_item	2670033	et	3	main
ja	doc_524344278300_item	2670043	et	3	main
sealtsamast	doc_524344278300_item	2670048	et	3	main
kohast	doc_524344278300_item	2670049	et	4	main
poolteise	doc_524344278300_item	2670050	et	4	main
tüki	doc_524344278300_item	2670053	et	4	main
välja	doc_524344278300_item	2670054	et	4	main
seal	doc_524344278300_item	2670055	et	4	main
tühemikus	doc_524344278300_item	2670056	et	3	main
käivad	doc_524344278300_item	2670057	et	4	main
nüüd	doc_524344278300_item	2670061	et	4	main
выпилил	doc_524344278300_item	2670064	et	2	main
месте	doc_524344278300_item	2670067	et	2	main
длиной	doc_524344278300_item	2670070	et	2	main
фута	doc_524344278300_item	2670073	et	2	main
таким	doc_524344278300_item	2670076	et	2	main
мои	doc_524344278300_item	2670081	et	2	main
eesti	doc_524344278300_item	2670084	et	4	main
vene	doc_524344278300_item	2670088	et	4	main
keeles	doc_524344278300_item	2670089	et	4	main
tehti	doc_524344278300_item	2670090	et	3	main
palgist-missugusest	doc_524344278300_item	2670093	et	3	main
pole	doc_524344278300_item	2670095	et	3	main
sidussuvahendina	doc_524344278300_item	2670097	et	4	main
eestikeelses	doc_524344278300_item	2670098	et	3	main
kasutatakse	doc_524344278300_item	2670100	et	3	main
ja	doc_524344278300_item	2670102	et	3	main
alustatakse	doc_524344278300_item	2670108	et	3	main
isikulise	doc_524344278300_item	2670109	et	4	main
poolteise	doc_524344278300_item	2670111	et	4	main
pikkuse	doc_524344278300_item	2670113	et	4	main
в	doc_524344278300_item	2670116	et	2	main
on	doc_524344278300_item	2670129	et	4	main
таким	doc_524344278300_item	2670136	et	2	main
kui	doc_524344278300_item	2670141	et	3	main
sidusuvahenditest	doc_524344278300_item	2670147	et	4	main
бумаги	doc_524344278300_item	2670164	et	2	main
kirjutatud	doc_524344278300_item	2670167	et	4	main
ilukirjanduskeelega	doc_524344278300_item	2670168	et	3	main
seega	doc_524344278300_item	2670169	et	4	main
personifitseerimine	doc_524344278300_item	2670185	et	4	main
omistamine	doc_524344278300_item	2670191	et	4	main
asjadele	doc_524344278300_item	2670192	et	3	main
и	doc_524344278300_item	2670222	et	2	main
подробно	doc_524344278300_item	2670228	et	2	main
tõlges	doc_524344278300_item	2670235	et	3	main
küllalt	doc_524344278300_item	2670270	et	4	main
нужно	doc_524344278300_item	2670273	et	2	main
в	doc_524344278300_item	2670276	et	2	main
tõlgitud	doc_524344278300_item	2670289	et	4	main
kui	doc_524344278300_item	2670290	et	3	main
ei	doc_524344278300_item	2670295	et	4	main
mõte	doc_524344278300_item	2670314	et	3	main
jäävad	doc_524344278300_item	2670315	et	4	main
kuhu	doc_524344278300_item	2670316	et	3	main
keeles	doc_524344278300_item	2670319	et	4	main
päevasündmused	doc_524344278300_item	2670325	et	3	main
eesti	doc_524344278300_item	2670328	et	4	main
tamm	doc_524344278300_item	2670331	et	3	main
дня	doc_524344278300_item	2670334	et	2	main
tõlgevariandiks	doc_524344278300_item	2670337	et	4	main
pakuks	doc_524344278300_item	2670338	et	4	main
события	doc_524344278300_item	2670340	et	2	main
они	doc_524344278300_item	2670342	et	2	main
и	doc_524344278300_item	2670344	et	2	main
потому	doc_524344278300_item	2670346	et	2	main
записать	doc_524344278300_item	2670351	et	2	main
kuid	doc_524344278300_item	2670356	et	4	main
sõnavarana	doc_524344278300_item	2670362	et	3	main
7	doc_524344278300_item	2670363	et	2	main
pähe	doc_524344278300_item	2670367	et	4	main
kirja	doc_524344278300_item	2670370	et	4	main
jätmine	doc_524344278300_item	2670372	et	4	main
oleks	doc_524344278300_item	2670373	et	3	main
arvatavasti	doc_524344278300_item	2670374	et	3	main
märksa	doc_524344278300_item	2670375	et	3	main
siia	doc_524344278300_item	2670386	et	4	main
ja	doc_524344278300_item	2670391	et	3	main
mistahes	doc_524344278300_item	2670394	et	4	main
mahavaikimine	doc_524344278300_item	2670396	et	3	main
было	doc_524344278300_item	2670406	et	2	main
когда	doc_524344278300_item	2670415	et	2	main
здесь	doc_524344278300_item	2670420	et	2	main
давно	doc_524344278300_item	2670425	et	2	main
из	doc_524344278300_item	2670428	et	2	main
опасные	doc_524344278300_item	2670082	et	2	main
keeles	doc_524344278300_item	2670085	et	4	main
kaks	doc_524344278300_item	2670086	et	3	main
lauatagusest	doc_524344278300_item	2670092	et	3	main
palgist	doc_524344278300_item	2670094	et	3	main
tõlgitud	doc_524344278300_item	2670096	et	4	main
lauses	doc_524344278300_item	2670099	et	3	main
sidesõna	doc_524344278300_item	2670101	et	4	main
lausega	doc_524344278300_item	2670104	et	3	main
sidumiseks	doc_524344278300_item	2670105	et	4	main
футакусок	doc_524344278300_item	2670118	et	2	main
näha	doc_524344278300_item	2670120	et	3	main
kuivõrd	doc_524344278300_item	2670121	et	3	main
seal	doc_524344278300_item	2670132	et	4	main
в	doc_524344278300_item	2670134	et	2	main
eesti	doc_524344278300_item	2670140	et	4	main
vene	doc_524344278300_item	2670143	et	4	main
kasutatud	doc_524344278300_item	2670148	et	4	main
selles	doc_524344278300_item	2670175	et	4	main
lauses	doc_524344278300_item	2670176	et	3	main
antud	doc_524344278300_item	2670177	et	4	main
juhul	doc_524344278300_item	2670178	et	3	main
on	doc_524344278300_item	2670179	et	4	main
metafoori	doc_524344278300_item	2670182	et	4	main
nagu	doc_524344278300_item	2670184	et	3	main
isikustamine	doc_524344278300_item	2670187	et	4	main
paberid	doc_524344278300_item	2670193	et	3	main
varjul	doc_524344278300_item	2670195	et	4	main
там	doc_524344278300_item	2670221	et	2	main
мне	doc_524344278300_item	2670226	et	2	main
дневник	doc_524344278300_item	2670231	et	2	main
venekeelses	doc_524344278300_item	2670234	et	3	main
eesti	doc_524344278300_item	2670238	et	4	main
keeles	doc_524344278300_item	2670242	et	4	main
täna	doc_524344278300_item	2670248	et	4	main
ja	doc_524344278300_item	2670249	et	3	main
täna	doc_524344278300_item	2670250	et	4	main
jäävad	doc_524344278300_item	2670257	et	4	main
peidukohta	doc_524344278300_item	2670258	et	4	main
kirjapanemisega	doc_524344278300_item	2670269	et	3	main
мне	doc_524344278300_item	2670272	et	2	main
записать	doc_524344278300_item	2670275	et	2	main
vene	doc_524344278300_item	2670278	et	4	main
kirja	doc_524344278300_item	2670283	et	4	main
panna	doc_524344278300_item	2670284	et	4	main
vaja	doc_524344278300_item	2670292	et	4	main
juurde	doc_524344278300_item	2670298	et	4	main
eestikeelses	doc_524344278300_item	2670304	et	3	main
ole	doc_524344278300_item	2670307	et	4	main
kuid	doc_524344278300_item	2670308	et	4	main
tänu	doc_524344278300_item	2670309	et	4	main
niisugusele	doc_524344278300_item	2670310	et	3	main
võttele	doc_524344278300_item	2670311	et	3	main
säilib	doc_524344278300_item	2670312	et	3	main
llause	doc_524344278300_item	2670313	et	4	main
erinevus	doc_524344278300_item	2670324	et	4	main
события	doc_524344278300_item	2670327	et	2	main
sõnaraamatj	doc_524344278300_item	2670330	et	4	main
pakub	doc_524344278300_item	2670332	et	3	main
текущие	doc_524344278300_item	2670335	et	2	main
текущие	doc_524344278300_item	2670339	et	2	main
сегодня	doc_524344278300_item	2670341	et	2	main
там	doc_524344278300_item	2670343	et	2	main
останутся	doc_524344278300_item	2670345	et	2	main
что	doc_524344278300_item	2670347	et	2	main
дневник	doc_524344278300_item	2670353	et	2	main
tunduda	doc_524344278300_item	2670359	et	3	main
keele	doc_524344278300_item	2670361	et	4	main
et	doc_524344278300_item	2670368	et	3	main
tegu	doc_524344278300_item	2670377	et	4	main
mõtlesin	doc_524344278300_item	2670380	et	3	main
mul	doc_524344278300_item	2670385	et	3	main
leidsin	doc_524344278300_item	2670392	et	3	main
ettevaatuse	doc_524344278300_item	2670397	et	3	main
бы	doc_524344278300_item	2670407	et	2	main
о	doc_524344278300_item	2670412	et	2	main
что	doc_524344278300_item	2670417	et	2	main
то	doc_524344278300_item	2670422	et	2	main
чём	doc_524344278300_item	2670431	et	2	main
küll	doc_524344278300_item	2670435	et	4	main
erinev	doc_524344278300_item	2670122	et	4	main
ja	doc_524344278300_item	2670125	et	3	main
vene	doc_524344278300_item	2670126	et	4	main
mõõdusüsteem	doc_524344278300_item	2670127	et	3	main
autor	doc_524344278300_item	2670128	et	3	main
образовавшемся	doc_524344278300_item	2670135	et	2	main
teksti	doc_524344278300_item	2670146	et	4	main
täpsustamine	doc_524344278300_item	2670149	et	4	main
образовавшемся	doc_524344278300_item	2670157	et	2	main
образом	doc_524344278300_item	2670159	et	2	main
käivad	doc_524344278300_item	2670160	et	4	main
varjulkahtlased	doc_524344278300_item	2670161	et	4	main
paberid	doc_524344278300_item	2670162	et	3	main
хранятсяопасные	doc_524344278300_item	2670163	et	2	main
on	doc_524344278300_item	2670166	et	4	main
selline	doc_524344278300_item	2670181	et	4	main
olendi	doc_524344278300_item	2670189	et	3	main
paberid	doc_524344278300_item	2670207	et	3	main
jäävadki	doc_524344278300_item	2670208	et	4	main
täna	doc_524344278300_item	2670209	et	4	main
sinna	doc_524344278300_item	2670210	et	3	main
sest	doc_524344278300_item	2670211	et	4	main
täna	doc_524344278300_item	2670212	et	4	main
on	doc_524344278300_item	2670213	et	4	main
mul	doc_524344278300_item	2670214	et	3	main
päevasündmuste	doc_524344278300_item	2670215	et	3	main
kirjapanemisega	doc_524344278300_item	2670216	et	3	main
küllalt	doc_524344278300_item	2670217	et	4	main
tegemist	doc_524344278300_item	2670218	et	4	main
сегодня	doc_524344278300_item	2670219	et	2	main
они	doc_524344278300_item	2670220	et	2	main
что	doc_524344278300_item	2670225	et	2	main
в	doc_524344278300_item	2670230	et	2	main
vastab	doc_524344278300_item	2670236	et	3	main
on	doc_524344278300_item	2670268	et	4	main
tegemist-	doc_524344278300_item	2670271	et	4	main
подробно	doc_524344278300_item	2670274	et	2	main
on	doc_524344278300_item	2670285	et	4	main
mis	doc_524344278300_item	2670293	et	4	main
iseenesest	doc_524344278300_item	2670294	et	4	main
ka	doc_524344278300_item	2670300	et	3	main
sõna	doc_524344278300_item	2670301	et	4	main
подробно	doc_524344278300_item	2670302	et	2	main
ei	doc_524344278300_item	2670306	et	4	main
vene	doc_524344278300_item	2670318	et	4	main
останутся	doc_524344278300_item	2670223	et	2	main
записать	doc_524344278300_item	2670229	et	2	main
сегодняшние	doc_524344278300_item	2670232	et	2	main
üks	doc_524344278300_item	2670240	et	3	main
ja	doc_524344278300_item	2670251	et	3	main
asesõnakordus-need	doc_524344278300_item	2670252	et	3	main
mis	doc_524344278300_item	2670253	et	4	main
täpsustab	doc_524344278300_item	2670254	et	3	main
mis	doc_524344278300_item	2670255	et	4	main
paberid	doc_524344278300_item	2670256	et	3	main
vene	doc_524344278300_item	2670259	et	4	main
keeles	doc_524344278300_item	2670260	et	4	main
kasutatakse	doc_524344278300_item	2670261	et	3	main
asesõnalist	doc_524344278300_item	2670262	et	4	main
tuleb	doc_524344278300_item	2670282	et	3	main
tegemist	doc_524344278300_item	2670286	et	4	main
vene	doc_524344278300_item	2670287	et	4	main
keelde	doc_524344278300_item	2670288	et	4	main
pandud	doc_524344278300_item	2670299	et	4	main
lauses	doc_524344278300_item	2670305	et	3	main
kus	doc_524344278300_item	2670321	et	3	main
мне	doc_524344278300_item	2670348	et	2	main
текущие	doc_524344278300_item	2670354	et	2	main
ametliku	doc_524344278300_item	2670360	et	3	main
mulle	doc_524344278300_item	2670364	et	4	main
turgatas	doc_524344278300_item	2670365	et	3	main
nende	doc_524344278300_item	2670369	et	4	main
panemata	doc_524344278300_item	2670371	et	4	main
ma	doc_524344278300_item	2670381	et	3	main
pandud	doc_524344278300_item	2670390	et	4	main
asjade	doc_524344278300_item	2670395	et	3	main
гораздо	doc_524344278300_item	2670408	et	2	main
писать	doc_524344278300_item	2670411	et	2	main
вспомнил	doc_524344278300_item	2670416	et	2	main
rektsiooni	doc_524344278300_item	2670323	et	4	main
vene	doc_524344278300_item	2670329	et	4	main
события	doc_524344278300_item	2670333	et	2	main
события	doc_524344278300_item	2670336	et	2	main
подробно	doc_524344278300_item	2670350	et	2	main
в	doc_524344278300_item	2670352	et	2	main
küll	doc_524344278300_item	2670366	et	4	main
aga	doc_524344278300_item	2670378	et	3	main
siis	doc_524344278300_item	2670379	et	3	main
selle	doc_524344278300_item	2670382	et	4	main
peale	doc_524344278300_item	2670383	et	4	main
kirja	doc_524344278300_item	2670388	et	4	main
et	doc_524344278300_item	2670393	et	3	main
pärast	doc_524344278300_item	2670398	et	4	main
oleks	doc_524344278300_item	2670399	et	3	main
küll	doc_524344278300_item	2670400	et	4	main
juba	doc_524344278300_item	2670401	et	3	main
ammu	doc_524344278300_item	2670402	et	4	main
умнее	doc_524344278300_item	2670409	et	2	main
них	doc_524344278300_item	2670413	et	2	main
у	doc_524344278300_item	2670418	et	2	main
написано	doc_524344278300_item	2670421	et	2	main
уже	doc_524344278300_item	2670426	et	2	main
умалчивать	doc_524344278300_item	2670433	et	2	main
sõnaraamatusj	doc_524344278300_item	2670440	et	4	main
чтоvõi	doc_524344278300_item	2670469	et	2	main
мысль	doc_524344278300_item	2670474	et	2	main
puhul	doc_524344278300_item	2670508	et	4	main
oleks	doc_524344278300_item	2670513	et	3	main
бы	doc_524344278300_item	2670518	et	2	main
kuid	doc_524344278300_item	2670529	et	4	main
arusaamist	doc_524344278300_item	2670536	et	4	main
selle	doc_524344278300_item	2670539	et	4	main
peale	doc_524344278300_item	2670540	et	4	main
вспомнил	doc_524344278300_item	2670541	et	2	main
otsene	doc_524344278300_item	2670542	et	3	main
lge	doc_524344278300_item	2670545	et	4	main
об	doc_524344278300_item	2670548	et	2	main
томвспомнить	doc_524344278300_item	2670551	et	2	main
meelde	doc_524344278300_item	2670553	et	3	main
tuletama	doc_524344278300_item	2670554	et	3	main
то	doc_524344278300_item	2670556	et	2	main
leidma	doc_524344278300_item	2670558	et	3	main
обрести	doc_524344278300_item	2670564	et	2	main
встретить	doc_524344278300_item	2670566	et	2	main
287a	doc_524344278300_item	2670571	et	4	main
1	doc_524344278300_item	2670575	et	2	main
ть	doc_524344278300_item	2670580	et	2	main
v	doc_524344278300_item	2670583	et	4	main
что	doc_524344278300_item	2670424	et	2	main
бессмысленно	doc_524344278300_item	2670427	et	2	main
о	doc_524344278300_item	2670430	et	2	main
tamm	doc_524344278300_item	2670441	et	3	main
вдруг	doc_524344278300_item	2670446	et	2	main
на	doc_524344278300_item	2670450	et	2	main
подумал	doc_524344278300_item	2670468	et	2	main
в	doc_524344278300_item	2670472	et	2	main
что	doc_524344278300_item	2670478	et	2	main
kirja	doc_524344278300_item	2670479	et	4	main
panemata	doc_524344278300_item	2670480	et	4	main
jätmine	doc_524344278300_item	2670481	et	4	main
не	doc_524344278300_item	2670482	et	2	main
о	doc_524344278300_item	2670484	et	2	main
писать	doc_524344278300_item	2670483	et	2	main
них	doc_524344278300_item	2670485	et	2	main
eesti	doc_524344278300_item	2670486	et	4	main
ja	doc_524344278300_item	2670487	et	3	main
vene	doc_524344278300_item	2670488	et	4	main
keeles	doc_524344278300_item	2670489	et	4	main
väljendatakse	doc_524344278300_item	2670490	et	3	main
sama	doc_524344278300_item	2670491	et	4	main
mõtet	doc_524344278300_item	2670492	et	3	main
erinevate	doc_524344278300_item	2670493	et	4	main
vahendite	doc_524344278300_item	2670494	et	3	main
abil	doc_524344278300_item	2670495	et	4	main
eesti	doc_524344278300_item	2670496	et	4	main
keeles	doc_524344278300_item	2670497	et	4	main
selleks	doc_524344278300_item	2670498	et	4	main
on	doc_524344278300_item	2670499	et	4	main
mata	doc_524344278300_item	2670500	et	4	main
vorm	doc_524344278300_item	2670501	et	3	main
mis	doc_524344278300_item	2670502	et	4	main
väljendab	doc_524344278300_item	2670503	et	3	main
sooritamata	doc_524344278300_item	2670504	et	4	main
tegevust	doc_524344278300_item	2670505	et	4	main
kinldate	doc_524344278300_item	2670506	et	4	main
verbide	doc_524344278300_item	2670507	et	3	main
осторожности	doc_524344278300_item	2670429	et	2	main
подумал	doc_524344278300_item	2670437	et	2	main
vene	doc_524344278300_item	2670439	et	4	main
придёт	doc_524344278300_item	2670448	et	2	main
кому	doc_524344278300_item	2670452	et	2	main
pähe	doc_524344278300_item	2670455	et	4	main
пришло	doc_524344278300_item	2670457	et	2	main
память	doc_524344278300_item	2670459	et	2	main
осенило	doc_524344278300_item	2670461	et	2	main
kuid	doc_524344278300_item	2670462	et	4	main
tõlgevariandiks	doc_524344278300_item	2670463	et	4	main
pakuks	doc_524344278300_item	2670465	et	4	main
мне	doc_524344278300_item	2670470	et	2	main
меня	doc_524344278300_item	2670475	et	2	main
ta	doc_524344278300_item	2670511	et	4	main
märksa	doc_524344278300_item	2670514	et	3	main
pähe	doc_524344278300_item	2670436	et	4	main
antud	doc_524344278300_item	2670443	et	4	main
meelde	doc_524344278300_item	2670445	et	3	main
пришло	doc_524344278300_item	2670449	et	2	main
talle	doc_524344278300_item	2670453	et	4	main
ma	doc_524344278300_item	2670464	et	3	main
и	doc_524344278300_item	2670466	et	2	main
пришла	doc_524344278300_item	2670471	et	2	main
посетила	doc_524344278300_item	2670476	et	2	main
tegu	doc_524344278300_item	2670516	et	4	main
умнее	doc_524344278300_item	2670520	et	2	main
vene	doc_524344278300_item	2670521	et	4	main
puudub	doc_524344278300_item	2670523	et	3	main
nimisõna	doc_524344278300_item	2670524	et	4	main
tegu	doc_524344278300_item	2670528	et	4	main
vahele	doc_524344278300_item	2670531	et	4	main
изыскивать	doc_524344278300_item	2670567	et	2	main
что	doc_524344278300_item	2670576	et	2	main
otsustama	doc_524344278300_item	2670579	et	3	main
кого	doc_524344278300_item	2670619	et	2	main
ilma	doc_524344278300_item	2670624	et	4	main
kõikidest	doc_524344278300_item	2670629	et	4	main
ilma	doc_524344278300_item	2670631	et	4	main
ть	doc_524344278300_item	2670633	et	2	main
и	doc_524344278300_item	2670635	et	2	main
ilma	doc_524344278300_item	2670640	et	4	main
peavarjuta	doc_524344278300_item	2670644	et	3	main
кого	doc_524344278300_item	2670660	et	2	main
kellelt	doc_524344278300_item	2670668	et	4	main
võtma	doc_524344278300_item	2670670	et	3	main
и	doc_524344278300_item	2670672	et	2	main
lõplikult	doc_524344278300_item	2670674	et	4	main
otsustatud	doc_524344278300_item	2670675	et	4	main
otsus	doc_524344278300_item	2670676	et	3	main
tõlkida	doc_524344278300_item	2670683	et	3	main
on	doc_524344278300_item	2670687	et	4	main
et	doc_524344278300_item	2670691	et	3	main
tõlge	doc_524344278300_item	2670703	et	3	main
öelda	doc_524344278300_item	2670708	et	4	main
tõlkija	doc_524344278300_item	2670710	et	4	main
on	doc_524344278300_item	2670711	et	4	main
suutnud	doc_524344278300_item	2670712	et	4	main
edastada	doc_524344278300_item	2670713	et	3	main
autori	doc_524344278300_item	2670714	et	3	main
sidususvahendeid	doc_524344278300_item	2670720	et	4	main
keeles	doc_524344278300_item	2670729	et	4	main
et	doc_524344278300_item	2670733	et	3	main
on	doc_524344278300_item	2670735	et	4	main
suutnud	doc_524344278300_item	2670736	et	4	main
edastada	doc_524344278300_item	2670737	et	3	main
autori	doc_524344278300_item	2670738	et	3	main
esitluslaad	doc_524344278300_item	2670745	et	3	main
eesti	doc_524344278300_item	2670749	et	4	main
kui	doc_524344278300_item	2670750	et	3	main
2	doc_524344278300_item	2670766	et	2	main
kross	doc_524344278300_item	2670772	et	3	main
1999	doc_524344278300_item	2670774	et	2	main
kogutud	doc_524344278300_item	2670775	et	4	main
5	doc_524344278300_item	2670777	et	2	main
keisri	doc_524344278300_item	2670778	et	3	main
hull	doc_524344278300_item	2670779	et	3	main
tallinn	doc_524344278300_item	2670780	et	4	main
1998	doc_524344278300_item	2670784	et	2	main
jne	doc_524344278301_item	2670826	et	4	main
hunniku	doc_524344278301_item	2670831	et	3	main
tõlgitakse	doc_524344278301_item	2670838	et	4	main
antakse	doc_524344278301_item	2670845	et	3	main
ka	doc_524344278301_item	2670854	et	3	main
lugejad	doc_524344278301_item	2670856	et	4	main
ma	doc_524344278301_item	2670866	et	3	main
raamatus	doc_524344278301_item	2670870	et	4	main
kohtumine	doc_524344278301_item	2670872	et	4	main
jäätiseputka	doc_524344278301_item	2670873	et	4	main
juures	doc_524344278301_item	2670878	et	4	main
ja	doc_524344278301_item	2670887	et	3	main
pidas	doc_524344278301_item	2670898	et	3	main
juures	doc_524344278301_item	2670908	et	4	main
silma	doc_524344278301_item	2670912	et	4	main
oli	doc_524344278301_item	2670914	et	3	main
pehmest	doc_524344278301_item	2670915	et	3	main
habe	doc_524344278301_item	2670917	et	3	main
kasvasid	doc_524344278301_item	2670919	et	4	main
eesti	doc_524344278300_item	2670438	et	4	main
on	doc_524344278300_item	2670442	et	4	main
turgatama	doc_524344278300_item	2670444	et	3	main
прийти	doc_524344278300_item	2670447	et	2	main
память	doc_524344278300_item	2670451	et	2	main
turgatas	doc_524344278300_item	2670454	et	3	main
емуей	doc_524344278300_item	2670456	et	2	main
на	doc_524344278300_item	2670458	et	2	main
егоеё	doc_524344278300_item	2670460	et	2	main
я	doc_524344278300_item	2670467	et	2	main
голову	doc_524344278300_item	2670473	et	2	main
мысль	doc_524344278300_item	2670477	et	2	main
nagu	doc_524344278300_item	2670509	et	3	main
siinjätmaon	doc_524344278300_item	2670510	et	4	main
targem	doc_524344278300_item	2670515	et	4	main
mis	doc_524344278300_item	2670525	et	4	main
t	doc_524344278300_item	2670543	et	4	main
on	doc_524344278300_item	2670546	et	4	main
этом	doc_524344278300_item	2670549	et	2	main
vasteid	doc_524344278300_item	2670562	et	3	main
обнаружить	doc_524344278300_item	2670568	et	2	main
г	doc_524344278300_item	2670572	et	2	main
с	doc_524344278300_item	2670577	et	2	main
участь	doc_524344278300_item	2670582	et	2	main
ristsõnamõistatust	doc_524344278300_item	2670616	et	4	main
чего	doc_524344278300_item	2670620	et	2	main
jätma	doc_524344278300_item	2670625	et	3	main
прав	doc_524344278300_item	2670628	et	2	main
õigustest	doc_524344278300_item	2670630	et	4	main
jätma	doc_524344278300_item	2670632	et	3	main
хлеба	doc_524344278300_item	2670634	et	2	main
жилья	doc_524344278300_item	2670636	et	2	main
leivast	doc_524344278300_item	2670637	et	4	main
4	doc_524344278300_item	2670646	et	2	main
madalk	doc_524344278300_item	2670661	et	4	main
otsa	doc_524344278300_item	2670665	et	4	main
peale	doc_524344278300_item	2670666	et	4	main
elu	doc_524344278300_item	2670669	et	4	main
подписано	doc_524344278300_item	2670673	et	2	main
võiks	doc_524344278300_item	2670682	et	4	main
edasi	doc_524344278300_item	2670699	et	3	main
ja	doc_524344278300_item	2670701	et	3	main
eesti	doc_524344278300_item	2670725	et	4	main
taotlused	doc_524344278300_item	2670739	et	4	main
keele	doc_524344278300_item	2670741	et	4	main
seoseid	doc_524344278300_item	2670743	et	3	main
sidususvahendeid	doc_524344278300_item	2670744	et	4	main
järjestikune	doc_524344278300_item	2670747	et	4	main
erelt	doc_524344278300_item	2670756	et	4	main
m	doc_524344278300_item	2670757	et	4	main
erelt	doc_524344278300_item	2670758	et	4	main
eesti	doc_524344278300_item	2670763	et	4	main
sihtasutus	doc_524344278300_item	2670771	et	4	main
virgela	doc_524344278300_item	2670781	et	4	main
tehtud	doc_524344278301_item	2670821	et	4	main
vahepeal	doc_524344278301_item	2670823	et	3	main
vene	doc_524344278301_item	2670839	et	4	main
keelde	doc_524344278301_item	2670840	et	4	main
tegelaste	doc_524344278301_item	2670841	et	3	main
nimesid	doc_524344278301_item	2670842	et	3	main
deminutiive	doc_524344278301_item	2670843	et	3	main
on	doc_524344278301_item	2670849	et	4	main
nõudlikud	doc_524344278301_item	2670855	et	3	main
valik	doc_524344278301_item	2670858	et	3	main
analüüsin	doc_524344278301_item	2670865	et	3	main
sammalhabe	doc_524344278301_item	2670885	et	4	main
nad	doc_524344278301_item	2670889	et	3	main
neid	doc_524344278301_item	2670899	et	4	main
alguses	doc_524344278301_item	2670900	et	4	main
päkapikkudeks	doc_524344278301_item	2670902	et	4	main
veel	doc_524344278301_item	2670909	et	4	main
samblast	doc_524344278301_item	2670916	et	4	main
kus	doc_524344278301_item	2670918	et	3	main
ilusad	doc_524344278301_item	2670920	et	3	main
mullusuvised	doc_524344278301_item	2670924	et	4	main
pohlad	doc_524344278301_item	2670925	et	3	main
oli	doc_524344278301_item	2670927	et	3	main
kandis	doc_524344278301_item	2670941	et	4	main
seljas	doc_524344278301_item	2670945	et	4	main
peanupp	doc_524344278301_item	2670950	et	3	main
ja	doc_524344278301_item	2670951	et	3	main
sõltuvusmäärus	doc_524344278300_item	2670512	et	4	main
было	doc_524344278300_item	2670517	et	2	main
гораздо	doc_524344278300_item	2670519	et	2	main
keeles	doc_524344278300_item	2670522	et	4	main
sõnale	doc_524344278300_item	2670527	et	3	main
selle	doc_524344278300_item	2670530	et	4	main
jätmine	doc_524344278300_item	2670532	et	4	main
ei	doc_524344278300_item	2670533	et	4	main
mõtlesin	doc_524344278300_item	2670537	et	3	main
õ	doc_524344278300_item	2670544	et	4	main
подумал	doc_524344278300_item	2670547	et	2	main
о	doc_524344278300_item	2670550	et	2	main
решил	doc_524344278300_item	2670557	et	2	main
найти	doc_524344278300_item	2670563	et	2	main
решить	doc_524344278300_item	2670569	et	2	main
совнесов	doc_524344278300_item	2670573	et	2	main
инф	doc_524344278300_item	2670578	et	2	main
судьбу	doc_524344278300_item	2670584	et	2	main
madalk	doc_524344278300_item	2670621	et	4	main
ja	doc_524344278300_item	2670638	et	3	main
jätma	doc_524344278300_item	2670641	et	3	main
ja	doc_524344278300_item	2670643	et	3	main
jätma	doc_524344278300_item	2670645	et	3	main
madalk	doc_524344278300_item	2670648	et	4	main
koksama	doc_524344278300_item	2670650	et	3	main
kellele	doc_524344278300_item	2670662	et	4	main
v	doc_524344278300_item	2670664	et	4	main
käsi	doc_524344278300_item	2670678	et	4	main
all	doc_524344278300_item	2670679	et	3	main
autori	doc_524344278300_item	2670685	et	3	main
põhjustatud	doc_524344278300_item	2670689	et	4	main
tähtis	doc_524344278300_item	2670692	et	4	main
ei	doc_524344278300_item	2670693	et	4	main
vastab	doc_524344278300_item	2670704	et	3	main
originaalile	doc_524344278300_item	2670705	et	3	main
võib	doc_524344278300_item	2670707	et	3	main
kasutades	doc_524344278300_item	2670716	et	3	main
keele	doc_524344278300_item	2670717	et	4	main
analoogia	doc_524344278300_item	2670718	et	4	main
seoseid	doc_524344278300_item	2670719	et	3	main
esitluslaad	doc_524344278300_item	2670721	et	3	main
nii	doc_524344278300_item	2670724	et	3	main
kui	doc_524344278300_item	2670726	et	3	main
võib	doc_524344278300_item	2670731	et	3	main
vene	doc_524344278300_item	2670752	et	4	main
keeles	doc_524344278300_item	2670753	et	4	main
kasutatud	doc_524344278300_item	2670754	et	4	main
kirjandus	doc_524344278300_item	2670755	et	3	main
k	doc_524344278300_item	2670761	et	4	main
keele	doc_524344278300_item	2670764	et	4	main
eesti	doc_524344278300_item	2670769	et	4	main
teosed	doc_524344278300_item	2670776	et	3	main
vastab	doc_524344278300_item	2670526	et	3	main
sega	doc_524344278300_item	2670534	et	4	main
lausest	doc_524344278300_item	2670535	et	4	main
ma	doc_524344278300_item	2670538	et	3	main
meenutama	doc_524344278300_item	2670552	et	4	main
leidsin	doc_524344278300_item	2670555	et	3	main
httpvene-eestiaseee	doc_524344278300_item	2670559	et	4	main
pakub	doc_524344278300_item	2670560	et	3	main
selliseid	doc_524344278300_item	2670561	et	4	main
выкраивать	doc_524344278300_item	2670565	et	2	main
решить	doc_524344278300_item	2670570	et	2	main
решать	doc_524344278300_item	2670574	et	2	main
чью	doc_524344278300_item	2670581	et	2	main
kelle	doc_524344278300_item	2670585	et	4	main
otsustama	doc_524344278300_item	2670587	et	3	main
он	doc_524344278300_item	2670588	et	2	main
saatust	doc_524344278300_item	2670586	et	4	main
л	doc_524344278300_item	2670589	et	2	main
остаться	doc_524344278300_item	2670590	et	2	main
дома	doc_524344278300_item	2670591	et	2	main
ta	doc_524344278300_item	2670592	et	4	main
otsustas	doc_524344278300_item	2670593	et	3	main
koju	doc_524344278300_item	2670594	et	3	main
jääda	doc_524344278300_item	2670595	et	4	main
созвать	doc_524344278300_item	2670597	et	2	main
съезд	doc_524344278300_item	2670598	et	2	main
otsustati	doc_524344278300_item	2670599	et	3	main
ли	doc_524344278300_item	2670596	et	2	main
kongress	doc_524344278300_item	2670600	et	3	main
kokku	doc_524344278300_item	2670601	et	3	main
kutsuda	doc_524344278300_item	2670602	et	3	main
что	doc_524344278300_item	2670604	et	2	main
2	doc_524344278300_item	2670603	et	2	main
lahendama	doc_524344278300_item	2670605	et	3	main
задачу	doc_524344278300_item	2670607	et	2	main
ть	doc_524344278300_item	2670606	et	2	main
ülesannet	doc_524344278300_item	2670608	et	4	main
lahendama	doc_524344278300_item	2670609	et	3	main
ть	doc_524344278300_item	2670610	et	2	main
вопрос	doc_524344278300_item	2670611	et	2	main
küsimust	doc_524344278300_item	2670612	et	4	main
lahendama	doc_524344278300_item	2670613	et	3	main
ть	doc_524344278300_item	2670614	et	2	main
кроссворд	doc_524344278300_item	2670615	et	2	main
lahendama	doc_524344278300_item	2670617	et	3	main
3	doc_524344278300_item	2670618	et	2	main
ära	doc_524344278300_item	2670622	et	4	main
ть	doc_524344278300_item	2670626	et	2	main
кого	doc_524344278300_item	2670647	et	2	main
tegema	doc_524344278300_item	2670667	et	3	main
решено	doc_524344278300_item	2670671	et	2	main
seega	doc_524344278300_item	2670680	et	4	main
leidsin	doc_524344278300_item	2670681	et	3	main
valik	doc_524344278300_item	2670686	et	3	main
ole	doc_524344278300_item	2670694	et	4	main
otsene	doc_524344278300_item	2670695	et	3	main
tõlge	doc_524344278300_item	2670696	et	3	main
vaid	doc_524344278300_item	2670697	et	3	main
tema	doc_524344278300_item	2670702	et	4	main
kokkuvõttes	doc_524344278300_item	2670706	et	3	main
et	doc_524344278300_item	2670709	et	3	main
võtma	doc_524344278300_item	2670623	et	3	main
всех	doc_524344278300_item	2670627	et	2	main
eluasemest	doc_524344278300_item	2670639	et	4	main
söögi	doc_524344278300_item	2670642	et	4	main
maha	doc_524344278300_item	2670649	et	4	main
v	doc_524344278300_item	2670651	et	4	main
nottima	doc_524344278300_item	2670652	et	3	main
otsa	doc_524344278300_item	2670653	et	4	main
peale	doc_524344278300_item	2670654	et	4	main
tegema	doc_524344278300_item	2670655	et	3	main
ть	doc_524344278300_item	2670656	et	2	main
v	doc_524344278300_item	2670657	et	4	main
решать	doc_524344278300_item	2670658	et	2	main
жизни	doc_524344278300_item	2670659	et	2	main
lõppu	doc_524344278300_item	2670663	et	4	main
tehtud	doc_524344278300_item	2670677	et	4	main
нашёл	doc_524344278300_item	2670684	et	2	main
aga	doc_524344278300_item	2670688	et	3	main
sellega	doc_524344278300_item	2670690	et	3	main
mõtte	doc_524344278300_item	2670698	et	3	main
andmine	doc_524344278300_item	2670700	et	4	main
taotlused	doc_524344278300_item	2670715	et	4	main
on	doc_524344278300_item	2670722	et	4	main
järjestikune	doc_524344278300_item	2670723	et	4	main
vene	doc_524344278300_item	2670728	et	4	main
kokkuvõttes	doc_524344278300_item	2670730	et	3	main
öelda	doc_524344278300_item	2670732	et	4	main
tõlkija	doc_524344278300_item	2670734	et	4	main
analoogia	doc_524344278300_item	2670742	et	4	main
t	doc_524344278300_item	2670759	et	4	main
ross	doc_524344278300_item	2670760	et	4	main
keele	doc_524344278300_item	2670770	et	4	main
j	doc_524344278300_item	2670783	et	4	main
kirjandusest	doc_524344278301_item	2670818	et	4	main
ilukirjanduslikud	doc_524344278301_item	2670824	et	3	main
teaduslikud	doc_524344278301_item	2670825	et	3	main
lapades	doc_524344278301_item	2670828	et	4	main
suure	doc_524344278301_item	2670830	et	3	main
materjali	doc_524344278301_item	2670832	et	4	main
huvi	doc_524344278301_item	2670833	et	4	main
naksitrallid	doc_524344278301_item	2670863	et	3	main
katkendi	doc_524344278301_item	2670868	et	3	main
juhuslikult	doc_524344278301_item	2670880	et	4	main
kokku	doc_524344278301_item	2670881	et	3	main
imelikku	doc_524344278301_item	2670883	et	4	main
muhv	doc_524344278301_item	2670888	et	3	main
olid	doc_524344278301_item	2670891	et	4	main
lühikest	doc_524344278301_item	2670893	et	4	main
kasvu	doc_524344278301_item	2670894	et	4	main
nii	doc_524344278301_item	2670895	et	3	main
et	doc_524344278301_item	2670896	et	3	main
nende	doc_524344278301_item	2670907	et	4	main
iseäralikku	doc_524344278301_item	2670911	et	4	main
sammalhabemel	doc_524344278301_item	2670913	et	4	main
punased	doc_524344278301_item	2670922	et	4	main
et	doc_524344278301_item	2670932	et	3	main
oleks	doc_524344278301_item	2670934	et	3	main
lahe	doc_524344278301_item	2670936	et	4	main
varbaid	doc_524344278301_item	2670937	et	3	main
liigutada	doc_524344278301_item	2670938	et	3	main
muhv	doc_524344278301_item	2670939	et	3	main
riiete	doc_524344278301_item	2670943	et	3	main
asemel	doc_524344278301_item	2670944	et	4	main
suurt	doc_524344278301_item	2670946	et	3	main
muhvi	doc_524344278301_item	2670947	et	4	main
jäätist	doc_524344278301_item	2670957	et	3	main
silmitsesid	doc_524344278301_item	2670959	et	4	main
uudishimulikult	doc_524344278301_item	2670961	et	4	main
муфта	doc_524344278301_item	2670963	et	2	main
моховая	doc_524344278301_item	2670966	et	2	main
у	doc_524344278301_item	2670972	et	2	main
полботинка	doc_524344278301_item	2670982	et	2	main
были	doc_524344278301_item	2670987	et	2	main
мороженщица	doc_524344278301_item	2670992	et	2	main
гномов	doc_524344278301_item	2670997	et	2	main
равно	doc_524344278301_item	2671022	et	2	main
полботинка	doc_524344278301_item	2671026	et	2	main
обрезанными	doc_524344278301_item	2671032	et	2	main
а	doc_524344278301_item	2671038	et	2	main
из	doc_524344278301_item	2671046	et	2	main
только	doc_524344278301_item	2671049	et	2	main
они	doc_524344278301_item	2671053	et	2	main
с	doc_524344278301_item	2671057	et	2	main
друга	doc_524344278301_item	2671062	et	2	main
kohtumisest	doc_524344278301_item	2671070	et	4	main
said	doc_524344278301_item	2671092	et	4	main
peategelased-	doc_524344278301_item	2671096	et	3	main
sammalhabe	doc_524344278301_item	2671097	et	4	main
kingpool	doc_524344278301_item	2671098	et	4	main
ja	doc_524344278301_item	2671099	et	3	main
muhv	doc_524344278301_item	2671100	et	3	main
tegelasedmikroteemad	doc_524344278301_item	2671101	et	4	main
paralleelselt	doc_524344278301_item	2671104	et	4	main
ka	doc_524344278300_item	2670727	et	3	main
kasutades	doc_524344278300_item	2670740	et	3	main
on	doc_524344278300_item	2670746	et	4	main
nii	doc_524344278300_item	2670748	et	3	main
ka	doc_524344278300_item	2670751	et	3	main
2000	doc_524344278300_item	2670762	et	2	main
käsiraamat	doc_524344278300_item	2670765	et	3	main
tr	doc_524344278300_item	2670767	et	4	main
tallinn	doc_524344278300_item	2670768	et	4	main
j	doc_524344278300_item	2670773	et	4	main
tamm	doc_524344278300_item	2670782	et	3	main
eesti	doc_524344278300_item	2670785	et	4	main
vene	doc_524344278300_item	2670786	et	4	main
sõnaraamat	doc_524344278300_item	2670787	et	3	main
8	doc_524344278300_item	2670788	et	2	main
tr	doc_524344278300_item	2670789	et	4	main
tallinn	doc_524344278300_item	2670790	et	4	main
valgus	doc_524344278300_item	2670791	et	4	main
vene-eesti	doc_524344278300_item	2670792	et	4	main
seletav	doc_524344278300_item	2670793	et	4	main
sõnaraamat2001	doc_524344278300_item	2670794	et	3	main
tallinn	doc_524344278300_item	2670795	et	4	main
tea	doc_524344278300_item	2670796	et	4	main
loengute	doc_524344278300_item	2670797	et	4	main
konspektid	doc_524344278300_item	2670798	et	4	main
ja	doc_524344278300_item	2670799	et	3	main
kohustuslik	doc_524344278300_item	2670800	et	3	main
kirjandus	doc_524344278300_item	2670801	et	3	main
httpvene-eestiaseee	doc_524344278300_item	2670802	et	4	main
tekstianalüüs	doc_524344278301_item	2670803	et	3	main
teksti	doc_524344278301_item	2670804	et	4	main
kõrvutavlingvistiline	doc_524344278301_item	2670805	et	4	main
analüüs	doc_524344278301_item	2670806	et	3	main
antud	doc_524344278301_item	2670807	et	4	main
tööl	doc_524344278301_item	2670808	et	3	main
oli	doc_524344278301_item	2670809	et	3	main
suur	doc_524344278301_item	2670810	et	3	main
eeltöö	doc_524344278301_item	2670811	et	4	main
nimelt	doc_524344278301_item	2670812	et	4	main
tekstivalik	doc_524344278301_item	2670813	et	3	main
see	doc_524344278301_item	2670814	et	3	main
oli	doc_524344278301_item	2670815	et	3	main
suur	doc_524344278301_item	2670816	et	3	main
alustades	doc_524344278301_item	2670817	et	3	main
lõpetades	doc_524344278301_item	2670819	et	3	main
enda	doc_524344278301_item	2670820	et	4	main
äratasid	doc_524344278301_item	2670834	et	4	main
muinasjutud	doc_524344278301_item	2670835	et	3	main
see	doc_524344278301_item	2670836	et	3	main
kuidas	doc_524344278301_item	2670837	et	3	main
ning	doc_524344278301_item	2670844	et	3	main
lapsed	doc_524344278301_item	2670848	et	3	main
kõige	doc_524344278301_item	2670850	et	4	main
vastuvõtlikumad	doc_524344278301_item	2670851	et	4	main
ja	doc_524344278301_item	2670852	et	3	main
kuid	doc_524344278301_item	2670853	et	4	main
tõlgetega	doc_524344278301_item	2670822	et	3	main
tekstid	doc_524344278301_item	2670827	et	3	main
läbi	doc_524344278301_item	2670829	et	4	main
edasi	doc_524344278301_item	2670846	et	3	main
emotsioone	doc_524344278301_item	2670847	et	3	main
edasi	doc_524344278301_item	2670864	et	3	main
said	doc_524344278301_item	2670876	et	4	main
jäätiseputka	doc_524344278301_item	2670877	et	4	main
mehikest	doc_524344278301_item	2670884	et	3	main
kingpool	doc_524344278301_item	2670886	et	4	main
jäätismüüja	doc_524344278301_item	2670897	et	4	main
isegi	doc_524344278301_item	2670901	et	4	main
peale	doc_524344278301_item	2670904	et	4	main
selle	doc_524344278301_item	2670905	et	4	main
torkas	doc_524344278301_item	2670906	et	3	main
kingpool	doc_524344278301_item	2670926	et	4	main
oma	doc_524344278301_item	2670928	et	4	main
tavaliste	doc_524344278301_item	2670942	et	4	main
paistsid	doc_524344278301_item	2670954	et	4	main
у	doc_524344278301_item	2670969	et	2	main
киоска	doc_524344278301_item	2670973	et	2	main
встретились	doc_524344278301_item	2670977	et	2	main
накситраллей	doc_524344278301_item	2670979	et	2	main
все	doc_524344278301_item	2670985	et	2	main
маленького	doc_524344278301_item	2670989	et	2	main
что	doc_524344278301_item	2670991	et	2	main
за	doc_524344278301_item	2670996	et	2	main
minu	doc_524344278301_item	2670857	et	3	main
osutus	doc_524344278301_item	2670859	et	4	main
eno	doc_524344278301_item	2670860	et	4	main
raua	doc_524344278301_item	2670861	et	3	main
jutudele	doc_524344278301_item	2670862	et	4	main
ühe	doc_524344278301_item	2670867	et	4	main
sellest	doc_524344278301_item	2670869	et	4	main
naksitrallid	doc_524344278301_item	2670871	et	3	main
juures	doc_524344278301_item	2670874	et	4	main
ükskord	doc_524344278301_item	2670875	et	3	main
täiesti	doc_524344278301_item	2670879	et	3	main
kolm	doc_524344278301_item	2670882	et	3	main
kõik	doc_524344278301_item	2670890	et	4	main
väga	doc_524344278301_item	2670892	et	3	main
ja	doc_524344278301_item	2670903	et	3	main
muudki	doc_524344278301_item	2670910	et	4	main
ja	doc_524344278301_item	2670921	et	3	main
maha	doc_524344278301_item	2670930	et	4	main
tal	doc_524344278301_item	2670933	et	3	main
hea	doc_524344278301_item	2670935	et	4	main
aga	doc_524344278301_item	2670940	et	3	main
nad	doc_524344278301_item	2670955	et	3	main
httpwwwestonicaorgestpopupraudnaksidhtm	doc_524344278301_item	2670962	et	4	main
и	doc_524344278301_item	2670965	et	2	main
встреча	doc_524344278301_item	2670968	et	2	main
с	doc_524344278301_item	2670974	et	2	main
борода	doc_524344278301_item	2670981	et	2	main
они	doc_524344278301_item	2670986	et	2	main
их	doc_524344278301_item	2670994	et	2	main
у	doc_524344278301_item	2670999	et	2	main
прекрасные	doc_524344278301_item	2671023	et	2	main
был	doc_524344278301_item	2671027	et	2	main
с	doc_524344278301_item	2671031	et	2	main
шевелить	doc_524344278301_item	2671036	et	2	main
муфта	doc_524344278301_item	2671039	et	2	main
носил	doc_524344278301_item	2671043	et	2	main
торчали	doc_524344278301_item	2671048	et	2	main
ели	doc_524344278301_item	2671054	et	2	main
любопытством	doc_524344278301_item	2671059	et	2	main
on	doc_524344278301_item	2671066	et	4	main
kirjaldada-	doc_524344278301_item	2671068	et	4	main
järjest	doc_524344278301_item	2671106	et	4	main
igaüht	doc_524344278301_item	2671108	et	3	main
kasutatud	doc_524344278301_item	2671111	et	4	main
sammalhabe	doc_524344278301_item	2671116	et	4	main
anafooria	doc_524344278301_item	2671121	et	4	main
ühe	doc_524344278301_item	2671140	et	4	main
lausega	doc_524344278301_item	2671141	et	3	main
ja	doc_524344278301_item	2671142	et	3	main
siis	doc_524344278301_item	2671143	et	3	main
võtab	doc_524344278301_item	2671144	et	3	main
toimunu	doc_524344278301_item	2671145	et	4	main
kokku	doc_524344278301_item	2671146	et	3	main
nad	doc_524344278301_item	2671147	et	3	main
ja	doc_524344278301_item	2671149	et	3	main
analüüs	doc_524344278301_item	2671153	et	3	main
pealkirjast	doc_524344278301_item	2671155	et	4	main
raua	doc_524344278301_item	2671157	et	3	main
raamatu	doc_524344278301_item	2671158	et	4	main
pealkirjast	doc_524344278301_item	2671159	et	4	main
naksitrallid	doc_524344278301_item	2671160	et	3	main
kellest	doc_524344278301_item	2671166	et	4	main
on	doc_524344278301_item	2671180	et	4	main
ilmselt	doc_524344278301_item	2671181	et	4	main
võluda	doc_524344278301_item	2671184	et	3	main
mitu	doc_524344278301_item	2671193	et	4	main
kõlab	doc_524344278301_item	2671200	et	3	main
parraleelid	doc_524344278301_item	2671238	et	4	main
kõlavad	doc_524344278301_item	2671250	et	4	main
lugeja	doc_524344278301_item	2671252	et	4	main
jaoks	doc_524344278301_item	2671253	et	4	main
suht	doc_524344278301_item	2671254	et	4	main
pähe	doc_524344278301_item	2671264	et	4	main
teha	doc_524344278301_item	2671267	et	3	main
raamatu	doc_524344278301_item	2671269	et	4	main
selle	doc_524344278301_item	2671271	et	4	main
tegelasi	doc_524344278301_item	2671272	et	3	main
lugejale	doc_524344278301_item	2671274	et	4	main
lähemaks	doc_524344278301_item	2671275	et	4	main
ja	doc_524344278301_item	2671276	et	3	main
raamatu	doc_524344278301_item	2671289	et	4	main
kuigi	doc_524344278301_item	2670923	et	3	main
kinganinad	doc_524344278301_item	2670929	et	3	main
lõiganud	doc_524344278301_item	2670931	et	4	main
millest	doc_524344278301_item	2670948	et	3	main
ainult	doc_524344278301_item	2670949	et	4	main
limpsisid	doc_524344278301_item	2670956	et	4	main
ja	doc_524344278301_item	2670958	et	3	main
üksteist	doc_524344278301_item	2670960	et	4	main
полботинка	doc_524344278301_item	2670964	et	2	main
борода	doc_524344278301_item	2670967	et	2	main
однажды	doc_524344278301_item	2670971	et	2	main
случайно	doc_524344278301_item	2670976	et	2	main
моховая	doc_524344278301_item	2670980	et	2	main
муфта	doc_524344278301_item	2670984	et	2	main
роста	doc_524344278301_item	2670990	et	2	main
поначалу	doc_524344278301_item	2670995	et	2	main
каждого	doc_524344278301_item	2671000	et	2	main
из	doc_524344278301_item	2671001	et	2	main
них	doc_524344278301_item	2671002	et	2	main
и	doc_524344278301_item	2671003	et	2	main
другие	doc_524344278301_item	2671004	et	2	main
занятные	doc_524344278301_item	2671005	et	2	main
черточки	doc_524344278301_item	2671006	et	2	main
у	doc_524344278301_item	2671007	et	2	main
моховой	doc_524344278301_item	2671008	et	2	main
бороды	doc_524344278301_item	2671009	et	2	main
борода	doc_524344278301_item	2671010	et	2	main
мягкого	doc_524344278301_item	2671012	et	2	main
из	doc_524344278301_item	2671011	et	2	main
мха	doc_524344278301_item	2671013	et	2	main
в	doc_524344278301_item	2671014	et	2	main
которой	doc_524344278301_item	2671015	et	2	main
росли	doc_524344278301_item	2671016	et	2	main
хоть	doc_524344278301_item	2671017	et	2	main
и	doc_524344278301_item	2671018	et	2	main
прошлогодние	doc_524344278301_item	2671019	et	2	main
но	doc_524344278301_item	2671020	et	2	main
все	doc_524344278301_item	2671021	et	2	main
обут	doc_524344278301_item	2671028	et	2	main
носами	doc_524344278301_item	2671033	et	2	main
вместо	doc_524344278301_item	2671040	et	2	main
толстую	doc_524344278301_item	2671044	et	2	main
макушка	doc_524344278301_item	2671050	et	2	main
мороженое	doc_524344278301_item	2671055	et	2	main
разглядывали	doc_524344278301_item	2671060	et	2	main
eesmärgiks	doc_524344278301_item	2671065	et	3	main
kokku	doc_524344278301_item	2671093	et	3	main
esinevad	doc_524344278301_item	2671102	et	4	main
üks	doc_524344278301_item	2671109	et	3	main
sammalhabe	doc_524344278301_item	2671122	et	4	main
toimub	doc_524344278301_item	2671128	et	3	main
silmitsesid	doc_524344278301_item	2671150	et	4	main
võime	doc_524344278301_item	2671161	et	4	main
millest	doc_524344278301_item	2671163	et	3	main
juttu	doc_524344278301_item	2671169	et	4	main
ei	doc_524344278301_item	2671176	et	4	main
täpsusta	doc_524344278301_item	2671177	et	4	main
kes	doc_524344278301_item	2671178	et	4	main
labajalad	doc_524344278301_item	2670952	et	3	main
välja	doc_524344278301_item	2670953	et	4	main
киоска	doc_524344278301_item	2670970	et	2	main
мороженым	doc_524344278301_item	2670975	et	2	main
трое	doc_524344278301_item	2670978	et	2	main
и	doc_524344278301_item	2670983	et	2	main
такого	doc_524344278301_item	2670988	et	2	main
приняла	doc_524344278301_item	2670993	et	2	main
были	doc_524344278301_item	2670998	et	2	main
брусники	doc_524344278301_item	2671025	et	2	main
ботинки	doc_524344278301_item	2671030	et	2	main
так	doc_524344278301_item	2671034	et	2	main
пальцами	doc_524344278301_item	2671037	et	2	main
одежды	doc_524344278301_item	2671042	et	2	main
которой	doc_524344278301_item	2671047	et	2	main
пятки	doc_524344278301_item	2671052	et	2	main
большим	doc_524344278301_item	2671058	et	2	main
httpwwwlibrutalesraudmufta1txt	doc_524344278301_item	2671063	et	4	main
jutustada	doc_524344278301_item	2671067	et	3	main
on	doc_524344278301_item	2671095	et	4	main
reas-	doc_524344278301_item	2671103	et	3	main
autor	doc_524344278301_item	2671105	et	3	main
kirjeldab	doc_524344278301_item	2671107	et	3	main
tekstis	doc_524344278301_item	2671110	et	3	main
sidususvahend	doc_524344278301_item	2671112	et	4	main
on	doc_524344278301_item	2671113	et	4	main
pronominalisatsioonasesõnaline	doc_524344278301_item	2671114	et	4	main
kingpool	doc_524344278301_item	2671117	et	4	main
ja	doc_524344278301_item	2671118	et	3	main
jutustusetegevuse	doc_524344278301_item	2671126	et	4	main
järgmiselt	doc_524344278301_item	2671129	et	4	main
autor	doc_524344278301_item	2671135	et	3	main
kõrvutavlingvistiline	doc_524344278301_item	2671152	et	4	main
algab	doc_524344278301_item	2671154	et	3	main
eno	doc_524344278301_item	2671156	et	4	main
aimata	doc_524344278301_item	2671162	et	4	main
edasi	doc_524344278301_item	2671168	et	3	main
seega	doc_524344278301_item	2671170	et	4	main
tekitada	doc_524344278301_item	2671186	et	3	main
kes	doc_524344278301_item	2671188	et	4	main
need	doc_524344278301_item	2671189	et	3	main
olendid	doc_524344278301_item	2671190	et	3	main
sellised	doc_524344278301_item	2671191	et	4	main
jne	doc_524344278301_item	2671196	et	4	main
selle	doc_524344278301_item	2671201	et	4	main
ягоды	doc_524344278301_item	2671024	et	2	main
в	doc_524344278301_item	2671029	et	2	main
удобнее	doc_524344278301_item	2671035	et	2	main
обычной	doc_524344278301_item	2671041	et	2	main
муфту	doc_524344278301_item	2671045	et	2	main
и	doc_524344278301_item	2671051	et	2	main
и	doc_524344278301_item	2671056	et	2	main
друг	doc_524344278301_item	2671061	et	2	main
autori	doc_524344278301_item	2671064	et	3	main
rääkida	doc_524344278301_item	2671069	et	3	main
antud	doc_524344278301_item	2671071	et	4	main
lõikes	doc_524344278301_item	2671072	et	3	main
toimud	doc_524344278301_item	2671073	et	3	main
sõlmitus	doc_524344278301_item	2671074	et	4	main
sündmus	doc_524344278301_item	2671075	et	3	main
mis	doc_524344278301_item	2671076	et	4	main
toob	doc_524344278301_item	2671077	et	3	main
esile	doc_524344278301_item	2671078	et	3	main
tegelastevahelise	doc_524344278301_item	2671079	et	4	main
vastuolu	doc_524344278301_item	2671080	et	4	main
käivitab	doc_524344278301_item	2671081	et	3	main
tegevustiku	doc_524344278301_item	2671082	et	4	main
temaatiline	doc_524344278301_item	2671083	et	4	main
sõna-	doc_524344278301_item	2671084	et	4	main
kohtumine	doc_524344278301_item	2671085	et	4	main
esimeses	doc_524344278301_item	2671086	et	3	main
lauses	doc_524344278301_item	2671087	et	3	main
on	doc_524344278301_item	2671088	et	4	main
see	doc_524344278301_item	2671089	et	3	main
asendatud	doc_524344278301_item	2671090	et	4	main
sõnaga-	doc_524344278301_item	2671091	et	3	main
mikroteemadeks	doc_524344278301_item	2671094	et	3	main
asendamine	doc_524344278301_item	2671115	et	4	main
muhvkatafoorid	doc_524344278301_item	2671119	et	4	main
nad	doc_524344278301_item	2671120	et	3	main
kingpool	doc_524344278301_item	2671123	et	4	main
areng	doc_524344278301_item	2671127	et	3	main
saavad	doc_524344278301_item	2671131	et	4	main
kirjeldab	doc_524344278301_item	2671136	et	3	main
iga	doc_524344278301_item	2671137	et	4	main
tegelast	doc_524344278301_item	2671138	et	3	main
eraldi	doc_524344278301_item	2671139	et	4	main
teksti	doc_524344278301_item	2671151	et	4	main
läheb	doc_524344278301_item	2671167	et	3	main
mingisugustest	doc_524344278301_item	2671171	et	3	main
väljamõeldud	doc_524344278301_item	2671172	et	4	main
ennekuulmatutest	doc_524344278301_item	2671173	et	3	main
olenditest	doc_524344278301_item	2671174	et	3	main
autor	doc_524344278301_item	2671175	et	3	main
autorisoov	doc_524344278301_item	2671182	et	3	main
lugejat	doc_524344278301_item	2671185	et	4	main
neid	doc_524344278301_item	2671194	et	4	main
tõlkes	doc_524344278301_item	2671199	et	3	main
esialgu	doc_524344278301_item	2671227	et	3	main
võib	doc_524344278301_item	2671228	et	3	main
et	doc_524344278301_item	2671230	et	3	main
kerkivad	doc_524344278301_item	2671233	et	4	main
lastele	doc_524344278301_item	2671240	et	4	main
tuttava	doc_524344278301_item	2671241	et	4	main
тролли	doc_524344278301_item	2671244	et	2	main
ja	doc_524344278301_item	2671245	et	3	main
kuna	doc_524344278301_item	2671246	et	3	main
need	doc_524344278301_item	2671247	et	3	main
vene	doc_524344278301_item	2671273	et	4	main
võõraste	doc_524344278301_item	2671279	et	4	main
ja	doc_524344278301_item	2671281	et	3	main
häälikuühendite	doc_524344278301_item	2671282	et	4	main
kasutab	doc_524344278301_item	2671288	et	3	main
nime	doc_524344278301_item	2671291	et	4	main
omast	doc_524344278301_item	2671301	et	4	main
полботинка	doc_524344278301_item	2671305	et	2	main
борода	doc_524344278301_item	2671308	et	2	main
informatsiooni	doc_524344278301_item	2671312	et	4	main
peategelaste	doc_524344278301_item	2671314	et	3	main
arvust	doc_524344278301_item	2671315	et	4	main
ja	doc_524344278301_item	2671316	et	3	main
nende	doc_524344278301_item	2671317	et	4	main
nimedest	doc_524344278301_item	2671318	et	3	main
муфта-принадлежность	doc_524344278301_item	2671331	et	2	main
род	doc_524344278301_item	2671334	et	2	main
для	doc_524344278301_item	2671342	et	2	main
seega	doc_524344278301_item	2671347	et	4	main
oletada	doc_524344278301_item	2671349	et	3	main
ühel	doc_524344278301_item	2671351	et	3	main
kõigile	doc_524344278301_item	2671361	et	4	main
sünonüüme	doc_524344278301_item	2671414	et	3	main
muhv	doc_524344278301_item	2671124	et	3	main
nadanafooria	doc_524344278301_item	2671125	et	4	main
kokku	doc_524344278301_item	2671130	et	3	main
kolm	doc_524344278301_item	2671132	et	3	main
mehikest	doc_524344278301_item	2671133	et	3	main
siis	doc_524344278301_item	2671134	et	3	main
limpsisid	doc_524344278301_item	2671148	et	4	main
või	doc_524344278301_item	2671164	et	4	main
õigemini	doc_524344278301_item	2671165	et	4	main
küsimust	doc_524344278301_item	2671187	et	4	main
on	doc_524344278301_item	2671195	et	4	main
pealkiri	doc_524344278301_item	2671203	et	3	main
nii	doc_524344278301_item	2671204	et	3	main
муфта	doc_524344278301_item	2671205	et	2	main
полботинка	doc_524344278301_item	2671206	et	2	main
и	doc_524344278301_item	2671207	et	2	main
моховая	doc_524344278301_item	2671208	et	2	main
борода	doc_524344278301_item	2671209	et	2	main
kerkib	doc_524344278301_item	2671210	et	3	main
kohe	doc_524344278301_item	2671211	et	4	main
küsimus	doc_524344278301_item	2671212	et	4	main
miks	doc_524344278301_item	2671213	et	4	main
tõlkija	doc_524344278301_item	2671214	et	4	main
ei	doc_524344278301_item	2671215	et	4	main
teinud	doc_524344278301_item	2671216	et	4	main
otsest	doc_524344278301_item	2671217	et	4	main
tõlget	doc_524344278301_item	2671218	et	3	main
võis	doc_524344278301_item	2671219	et	4	main
ju	doc_524344278301_item	2671220	et	3	main
pealkirjaks	doc_524344278301_item	2671225	et	3	main
oletada	doc_524344278301_item	2671229	et	3	main
tõlkija	doc_524344278301_item	2671231	et	4	main
raamatuga	doc_524344278301_item	2671242	et	4	main
муми-	doc_524344278301_item	2671243	et	2	main
kaks	doc_524344278301_item	2671248	et	3	main
vene	doc_524344278301_item	2671251	et	4	main
antud	doc_524344278301_item	2671268	et	4	main
ja	doc_524344278301_item	2671270	et	3	main
tegelaste	doc_524344278301_item	2671290	et	3	main
arvates	doc_524344278301_item	2671293	et	4	main
vene	doc_524344278301_item	2671294	et	4	main
keelne	doc_524344278301_item	2671295	et	3	main
pealkiri	doc_524344278301_item	2671303	et	3	main
annab	doc_524344278301_item	2671310	et	3	main
raamatu	doc_524344278301_item	2671313	et	4	main
lugeja	doc_524344278301_item	2671321	et	4	main
välja	doc_524344278301_item	2671329	et	4	main
näevad	doc_524344278301_item	2671330	et	3	main
женской	doc_524344278301_item	2671332	et	2	main
открытого	doc_524344278301_item	2671335	et	2	main
меха	doc_524344278301_item	2671341	et	2	main
рук	doc_524344278301_item	2671344	et	2	main
muhv	doc_524344278301_item	2671354	et	3	main
seotud	doc_524344278301_item	2671358	et	4	main
борода-	doc_524344278301_item	2671364	et	2	main
samblast	doc_524344278301_item	2671370	et	4	main
analoogseid	doc_524344278301_item	2671413	et	3	main
tõlge	doc_524344278301_item	2671417	et	3	main
встреча	doc_524344278301_item	2671420	et	2	main
sünonüümsõnastikust	doc_524344278301_item	2671428	et	4	main
прием	doc_524344278301_item	2671433	et	2	main
sobi	doc_524344278301_item	2671443	et	4	main
täitsa	doc_524344278301_item	2671450	et	3	main
need	doc_524344278301_item	2671179	et	3	main
oli	doc_524344278301_item	2671183	et	3	main
on	doc_524344278301_item	2671192	et	4	main
vene	doc_524344278301_item	2671197	et	4	main
keelses	doc_524344278301_item	2671198	et	3	main
raamatu	doc_524344278301_item	2671202	et	4	main
venekeelsele	doc_524344278301_item	2671221	et	3	main
variandile	doc_524344278301_item	2671223	et	3	main
panna	doc_524344278301_item	2671224	et	4	main
накситралли	doc_524344278301_item	2671226	et	2	main
pealkirja	doc_524344278301_item	2671249	et	4	main
vältida	doc_524344278301_item	2671277	et	3	main
sõnade	doc_524344278301_item	2671280	et	3	main
kasutamist	doc_524344278301_item	2671283	et	4	main
kuid	doc_524344278301_item	2671284	et	4	main
edaspidi	doc_524344278301_item	2671285	et	3	main
ta	doc_524344278301_item	2671286	et	4	main
minu	doc_524344278301_item	2671292	et	3	main
eesti	doc_524344278301_item	2671298	et	4	main
муфта	doc_524344278301_item	2671304	et	2	main
juba	doc_524344278301_item	2671309	et	3	main
raamatu	doc_524344278301_item	2671222	et	4	main
arvates	doc_524344278301_item	2671232	et	4	main
tulevasel	doc_524344278301_item	2671234	et	4	main
lugejal	doc_524344278301_item	2671235	et	4	main
nimetusega	doc_524344278301_item	2671236	et	4	main
накситралли	doc_524344278301_item	2671237	et	2	main
juba	doc_524344278301_item	2671239	et	3	main
sarnaselt	doc_524344278301_item	2671255	et	4	main
püüdis	doc_524344278301_item	2671256	et	3	main
tõlkija	doc_524344278301_item	2671257	et	4	main
vältida	doc_524344278301_item	2671258	et	3	main
kordust	doc_524344278301_item	2671259	et	4	main
teine	doc_524344278301_item	2671260	et	3	main
oletus	doc_524344278301_item	2671261	et	4	main
mis	doc_524344278301_item	2671262	et	4	main
tuleb	doc_524344278301_item	2671263	et	3	main
tõlkija	doc_524344278301_item	2671265	et	4	main
püüdis	doc_524344278301_item	2671266	et	3	main
väga	doc_524344278301_item	2671278	et	3	main
julgelt	doc_524344278301_item	2671287	et	4	main
pealkiri	doc_524344278301_item	2671296	et	3	main
keelsele	doc_524344278301_item	2671299	et	3	main
salapärasust	doc_524344278301_item	2671302	et	4	main
моховая	doc_524344278301_item	2671307	et	2	main
täpset	doc_524344278301_item	2671311	et	3	main
hea	doc_524344278301_item	2671319	et	4	main
isegi	doc_524344278301_item	2671323	et	4	main
kujutada	doc_524344278301_item	2671324	et	3	main
ette	doc_524344278301_item	2671325	et	4	main
kuidas	doc_524344278301_item	2671326	et	3	main
need	doc_524344278301_item	2671327	et	3	main
tegelased	doc_524344278301_item	2671328	et	3	main
сторон	doc_524344278301_item	2671337	et	2	main
из	doc_524344278301_item	2671340	et	2	main
словарь	doc_524344278301_item	2671345	et	2	main
võib	doc_524344278301_item	2671348	et	3	main
et	doc_524344278301_item	2671350	et	3	main
tegelasel	doc_524344278301_item	2671352	et	3	main
midagi	doc_524344278301_item	2671356	et	4	main
tuttavad	doc_524344278301_item	2671362	et	4	main
моховая	doc_524344278301_item	2671363	et	2	main
tegelasel	doc_524344278301_item	2671365	et	3	main
minna	doc_524344278301_item	2671372	et	3	main
esimese	doc_524344278301_item	2671374	et	3	main
juurde	doc_524344278301_item	2671377	et	4	main
siis	doc_524344278301_item	2671378	et	3	main
siin	doc_524344278301_item	2671379	et	4	main
pole	doc_524344278301_item	2671415	et	3	main
киоска	doc_524344278301_item	2671422	et	2	main
järgmiseid	doc_524344278301_item	2671430	et	3	main
sünonüüme	doc_524344278301_item	2671431	et	3	main
свидание	doc_524344278301_item	2671435	et	2	main
hulgast	doc_524344278301_item	2671440	et	4	main
midagi	doc_524344278301_item	2671441	et	4	main
meie	doc_524344278301_item	2671444	et	4	main
konteksti	doc_524344278301_item	2671445	et	4	main
seega	doc_524344278301_item	2671446	et	4	main
jäätiseputka	doc_524344278301_item	2671452	et	4	main
on	doc_524344278301_item	2671455	et	4	main
eesti-vene-eesti	doc_524344278301_item	2671457	et	4	main
elektroonilisest	doc_524344278301_item	2671458	et	4	main
киоск	doc_524344278301_item	2671464	et	2	main
цветочный	doc_524344278301_item	2671473	et	2	main
ja	doc_524344278301_item	2671475	et	3	main
vastupidises	doc_524344278301_item	2671476	et	3	main
kasutatud	doc_524344278301_item	2671490	et	4	main
ikka	doc_524344278301_item	2671491	et	4	main
tõlkija	doc_524344278301_item	2671507	et	4	main
kui	doc_524344278301_item	2671512	et	3	main
kuid	doc_524344278301_item	2671515	et	4	main
on	doc_524344278301_item	2671518	et	4	main
jäätiseputka	doc_524344278301_item	2671520	et	4	main
jäätis-	doc_524344278301_item	2671521	et	3	main
järgi	doc_524344278301_item	2671525	et	4	main
seega	doc_524344278301_item	2671526	et	4	main
puudub	doc_524344278301_item	2671536	et	3	main
pöördume	doc_524344278301_item	2671537	et	3	main
jäätiseputka	doc_524344278301_item	2671540	et	4	main
tõlkida	doc_524344278301_item	2671542	et	3	main
киоскларёк	doc_524344278301_item	2671544	et	2	main
tol	doc_524344278301_item	2671547	et	3	main
oli	doc_524344278301_item	2671549	et	3	main
накситраллей	doc_524344278301_item	2671582	et	2	main
и	doc_524344278301_item	2671586	et	2	main
однажды	doc_524344278301_item	2671593	et	2	main
korral	doc_524344278301_item	2671598	et	4	main
kunagi	doc_524344278301_item	2671601	et	3	main
kord	doc_524344278301_item	2671606	et	4	main
kaotab	doc_524344278301_item	2671297	et	3	main
pealkirjale	doc_524344278301_item	2671300	et	3	main
и	doc_524344278301_item	2671306	et	2	main
kujutlusvõimega	doc_524344278301_item	2671320	et	3	main
võib	doc_524344278301_item	2671322	et	3	main
сдвух	doc_524344278301_item	2671336	et	2	main
обычно	doc_524344278301_item	2671339	et	2	main
ожегова	doc_524344278301_item	2671346	et	2	main
või	doc_524344278301_item	2671355	et	4	main
sellega	doc_524344278301_item	2671357	et	3	main
полботинка-	doc_524344278301_item	2671359	et	2	main
sõnad	doc_524344278301_item	2671360	et	4	main
kui	doc_524344278301_item	2671371	et	3	main
edasi	doc_524344278301_item	2671373	et	3	main
peatüki	doc_524344278301_item	2671375	et	3	main
sõnal	doc_524344278301_item	2671412	et	3	main
venekeelne	doc_524344278301_item	2671416	et	3	main
kõlab	doc_524344278301_item	2671418	et	3	main
у	doc_524344278301_item	2671421	et	2	main
leiame	doc_524344278301_item	2671429	et	3	main
аудиенция	doc_524344278301_item	2671434	et	2	main
nende	doc_524344278301_item	2671438	et	4	main
valik	doc_524344278301_item	2671448	et	3	main
on	doc_524344278301_item	2671449	et	4	main
sõnastikust	doc_524344278301_item	2671459	et	4	main
18	doc_524344278301_item	2671465	et	2	main
неод	doc_524344278301_item	2671468	et	2	main
minu	doc_524344278301_item	2671481	et	3	main
antud	doc_524344278301_item	2671483	et	4	main
sõna	doc_524344278301_item	2671492	et	4	main
elektroonilise	doc_524344278301_item	2671499	et	4	main
sõnastiku	doc_524344278301_item	2671500	et	3	main
järgi	doc_524344278301_item	2671501	et	4	main
võis	doc_524344278301_item	2671508	et	4	main
ka	doc_524344278301_item	2671513	et	3	main
liitsõna	doc_524344278301_item	2671519	et	4	main
одежды	doc_524344278301_item	2671333	et	2	main
мешочка	doc_524344278301_item	2671338	et	2	main
согревания	doc_524344278301_item	2671343	et	2	main
on	doc_524344278301_item	2671353	et	4	main
peaks	doc_524344278301_item	2671366	et	4	main
olema	doc_524344278301_item	2671367	et	4	main
näiteks	doc_524344278301_item	2671368	et	4	main
habe	doc_524344278301_item	2671369	et	3	main
pealkirja	doc_524344278301_item	2671376	et	4	main
esineb	doc_524344278301_item	2671380	et	3	main
ka	doc_524344278301_item	2671381	et	3	main
erinevusi	doc_524344278301_item	2671382	et	4	main
eesti	doc_524344278301_item	2671383	et	4	main
ja	doc_524344278301_item	2671384	et	3	main
venekeelse	doc_524344278301_item	2671385	et	3	main
variandi	doc_524344278301_item	2671386	et	4	main
vahel	doc_524344278301_item	2671387	et	4	main
eesti	doc_524344278301_item	2671388	et	4	main
keelsest	doc_524344278301_item	2671389	et	3	main
pealkirjast	doc_524344278301_item	2671390	et	4	main
kohtumine	doc_524344278301_item	2671391	et	4	main
jäätiseputka	doc_524344278301_item	2671392	et	4	main
juures	doc_524344278301_item	2671393	et	4	main
on	doc_524344278301_item	2671394	et	4	main
selgelt	doc_524344278301_item	2671395	et	4	main
arusaadav	doc_524344278301_item	2671396	et	4	main
et	doc_524344278301_item	2671397	et	3	main
mitu	doc_524344278301_item	2671398	et	4	main
olendit	doc_524344278301_item	2671399	et	3	main
kohtuvad	doc_524344278301_item	2671400	et	4	main
putka	doc_524344278301_item	2671401	et	4	main
juures	doc_524344278301_item	2671402	et	4	main
ning	doc_524344278301_item	2671403	et	3	main
autor	doc_524344278301_item	2671404	et	3	main
ka	doc_524344278301_item	2671405	et	3	main
täpsustab	doc_524344278301_item	2671406	et	3	main
millise	doc_524344278301_item	2671407	et	3	main
putka	doc_524344278301_item	2671408	et	4	main
juures-	doc_524344278301_item	2671409	et	4	main
jäätiseputka	doc_524344278301_item	2671410	et	4	main
juuresantud	doc_524344278301_item	2671411	et	4	main
nii	doc_524344278301_item	2671419	et	3	main
kohtumine-	doc_524344278301_item	2671423	et	4	main
on	doc_524344278301_item	2671425	et	4	main
встреча	doc_524344278301_item	2671432	et	2	main
свиданка	doc_524344278301_item	2671436	et	2	main
ei	doc_524344278301_item	2671442	et	4	main
põhjendatud	doc_524344278301_item	2671451	et	4	main
tõlkes	doc_524344278301_item	2671454	et	3	main
sõnale	doc_524344278301_item	2671461	et	3	main
м	doc_524344278301_item	2671467	et	2	main
газетный	doc_524344278301_item	2671471	et	2	main
lillekiosk	doc_524344278301_item	2671474	et	3	main
putka-	doc_524344278301_item	2671478	et	4	main
кутузка	doc_524344278301_item	2671480	et	2	main
tõlge	doc_524344278301_item	2671484	et	3	main
putka	doc_524344278301_item	2671493	et	4	main
vaatame	doc_524344278301_item	2671494	et	3	main
edasi	doc_524344278301_item	2671495	et	3	main
sõna	doc_524344278301_item	2671496	et	4	main
ларь	doc_524344278301_item	2671505	et	2	main
seega	doc_524344278301_item	2671506	et	4	main
kasutada	doc_524344278301_item	2671509	et	3	main
киоск	doc_524344278301_item	2671514	et	2	main
tekstis	doc_524344278301_item	2671517	et	3	main
мороженое	doc_524344278301_item	2671522	et	2	main
liitsõna	doc_524344278301_item	2671534	et	4	main
sotsiaalteadmistele	doc_524344278301_item	2671539	et	3	main
nagu	doc_524344278301_item	2671543	et	3	main
мороженым	doc_524344278301_item	2671546	et	2	main
ajal	doc_524344278301_item	2671548	et	4	main
selline	doc_524344278301_item	2671551	et	4	main
esimest	doc_524344278301_item	2671558	et	4	main
lauset	doc_524344278301_item	2671559	et	3	main
борода	doc_524344278301_item	2671584	et	2	main
н	doc_524344278301_item	2671594	et	2	main
ühel	doc_524344278301_item	2671597	et	3	main
ainult	doc_524344278301_item	2671604	et	4	main
v	doc_524344278301_item	2671607	et	4	main
ühel	doc_524344278301_item	2671608	et	3	main
korral	doc_524344278301_item	2671609	et	4	main
olen	doc_524344278301_item	2671610	et	3	main
v	doc_524344278301_item	2671621	et	4	main
весной	doc_524344278301_item	2671625	et	2	main
antud	doc_524344278301_item	2671630	et	4	main
sõna	doc_524344278301_item	2671631	et	4	main
kasutatakse	doc_524344278301_item	2671632	et	3	main
päris	doc_524344278301_item	2671633	et	4	main
tihti	doc_524344278301_item	2671634	et	3	main
kohane	doc_524344278301_item	2671640	et	4	main
раз	doc_524344278301_item	2671645	et	2	main
juba	doc_524344278301_item	2671647	et	3	main
nagu	doc_524344278301_item	2671652	et	3	main
мороженым	doc_524344278301_item	2671655	et	2	main
mis	doc_524344278301_item	2671656	et	4	main
on	doc_524344278301_item	2671664	et	4	main
tegelased	doc_524344278301_item	2671676	et	3	main
tavapärased-	doc_524344278301_item	2671679	et	4	main
nimetusega-	doc_524344278301_item	2671689	et	4	main
varem	doc_524344278301_item	2671702	et	4	main
ka	doc_524344278301_item	2671703	et	3	main
muidu	doc_524344278301_item	2671705	et	3	main
lambist	doc_524344278301_item	2671709	et	3	main
встреча	doc_524344278301_item	2671424	et	2	main
otsene	doc_524344278301_item	2671426	et	3	main
tõlge	doc_524344278301_item	2671427	et	3	main
рандеву	doc_524344278301_item	2671437	et	2	main
sõnade	doc_524344278301_item	2671439	et	3	main
tõlkija	doc_524344278301_item	2671447	et	4	main
venekeelses	doc_524344278301_item	2671453	et	3	main
киоск	doc_524344278301_item	2671456	et	2	main
leiame	doc_524344278301_item	2671462	et	3	main
с	doc_524344278301_item	2671466	et	2	main
müügiputka	doc_524344278301_item	2671470	et	4	main
будка	doc_524344278301_item	2671479	et	2	main
arvates	doc_524344278301_item	2671482	et	4	main
on	doc_524344278301_item	2671485	et	4	main
puudulik	doc_524344278301_item	2671486	et	3	main
kuna	doc_524344278301_item	2671487	et	3	main
originaaltekstis	doc_524344278301_item	2671488	et	3	main
on	doc_524344278301_item	2671489	et	4	main
on	doc_524344278301_item	2671502	et	4	main
ларек	doc_524344278301_item	2671503	et	2	main
киоск	doc_524344278301_item	2671504	et	2	main
nii	doc_524344278301_item	2671510	et	3	main
sama	doc_524344278301_item	2671523	et	4	main
peatüki	doc_524344278301_item	2671527	et	3	main
pealkiri	doc_524344278301_item	2671528	et	3	main
tõlgitud	doc_524344278301_item	2671530	et	4	main
ka	doc_524344278301_item	2671550	et	3	main
mõiste	doc_524344278301_item	2671552	et	4	main
nagu	doc_524344278301_item	2671553	et	3	main
мороженщик	doc_524344278301_item	2671554	et	2	main
мороженщица	doc_524344278301_item	2671555	et	2	main
said	doc_524344278301_item	2671561	et	4	main
муфта	doc_524344278301_item	2671587	et	2	main
tõlgitud	doc_524344278301_item	2671590	et	4	main
üks	doc_524344278301_item	2671595	et	3	main
слышал	doc_524344278301_item	2671603	et	2	main
уже	doc_524344278301_item	2671613	et	2	main
об	doc_524344278301_item	2671615	et	2	main
ma	doc_524344278301_item	2671617	et	3	main
kunagi	doc_524344278301_item	2671622	et	3	main
v	doc_524344278301_item	2671627	et	4	main
liitsõna	doc_524344278301_item	2671648	et	4	main
jäätiseputka	doc_524344278301_item	2671649	et	4	main
on	doc_524344278301_item	2671657	et	4	main
kolm	doc_524344278301_item	2671660	et	3	main
mehikest	doc_524344278301_item	2671662	et	3	main
venekeelse	doc_524344278301_item	2671691	et	3	main
järgi	doc_524344278301_item	2671693	et	4	main
tunne	doc_524344278301_item	2671695	et	4	main
et	doc_524344278301_item	2671696	et	3	main
see	doc_524344278301_item	2671697	et	3	main
nimetus	doc_524344278301_item	2671698	et	4	main
ta	doc_524344278301_item	2671707	et	4	main
naksitrallid	doc_524344278301_item	2671722	et	3	main
varem	doc_524344278301_item	2671729	et	4	main
ning	doc_524344278301_item	2671731	et	3	main
tuleb	doc_524344278301_item	2671732	et	3	main
nii	doc_524344278301_item	2671735	et	3	main
on	doc_524344278301_item	2671743	et	4	main
vabandage	doc_524344278301_item	2671744	et	3	main
eksida	doc_524344278301_item	2671751	et	4	main
nagu	doc_524344278301_item	2671758	et	3	main
ühist	doc_524344278301_item	2671760	et	3	main
olegi	doc_524344278301_item	2671764	et	4	main
ühed	doc_524344278301_item	2671766	et	3	main
naksitrallid	doc_524344278301_item	2671768	et	3	main
kingpool	doc_524344278301_item	2671770	et	4	main
asendus	doc_524344278301_item	2671778	et	4	main
kolm	doc_524344278301_item	2671779	et	3	main
kohatuks	doc_524344278301_item	2671783	et	4	main
vene	doc_524344278301_item	2671788	et	4	main
три	doc_524344278301_item	2671791	et	2	main
мужичка	doc_524344278301_item	2671793	et	2	main
mis	doc_524344278301_item	2671794	et	4	main
peegeldaks	doc_524344278301_item	2671795	et	3	main
ka	doc_524344278301_item	2671796	et	3	main
autori	doc_524344278301_item	2671797	et	3	main
mõtet	doc_524344278301_item	2671798	et	3	main
näha	doc_524344278301_item	2671802	et	3	main
httpvene-eestiaseee	doc_524344278301_item	2671460	et	4	main
seletuse	doc_524344278301_item	2671463	et	4	main
kiosk	doc_524344278301_item	2671469	et	3	main
ajalehekiosk	doc_524344278301_item	2671472	et	3	main
tõlkes	doc_524344278301_item	2671477	et	3	main
müügiputka	doc_524344278301_item	2671497	et	4	main
mis	doc_524344278301_item	2671498	et	4	main
ларек	doc_524344278301_item	2671511	et	2	main
eestikeelses	doc_524344278301_item	2671516	et	3	main
on	doc_524344278301_item	2671529	et	4	main
osaliselt	doc_524344278301_item	2671531	et	4	main
kuna	doc_524344278301_item	2671532	et	3	main
sünaraamatus	doc_524344278301_item	2671533	et	4	main
võis	doc_524344278301_item	2671541	et	4	main
с	doc_524344278301_item	2671545	et	2	main
edasi	doc_524344278301_item	2671557	et	3	main
ükskord	doc_524344278301_item	2671560	et	3	main
полботинка	doc_524344278301_item	2671585	et	2	main
on	doc_524344278301_item	2671589	et	4	main
nagu	doc_524344278301_item	2671591	et	3	main
kord	doc_524344278301_item	2671599	et	4	main
ükskord	doc_524344278301_item	2671600	et	3	main
kuulnud	doc_524344278301_item	2671611	et	4	main
я	doc_524344278301_item	2671612	et	2	main
слышал	doc_524344278301_item	2671614	et	2	main
sellest	doc_524344278301_item	2671619	et	4	main
kunagi	doc_524344278301_item	2671628	et	3	main
venekeelsetes	doc_524344278301_item	2671635	et	4	main
muinasjuttudes	doc_524344278301_item	2671636	et	3	main
kuid	doc_524344278301_item	2671637	et	4	main
ka	doc_524344278301_item	2671639	et	3	main
väljendit	doc_524344278301_item	2671643	et	3	main
siin	doc_524344278301_item	2671646	et	4	main
с	doc_524344278301_item	2671654	et	2	main
selge	doc_524344278301_item	2671665	et	4	main
et	doc_524344278301_item	2671666	et	3	main
juttu	doc_524344278301_item	2671667	et	4	main
ei	doc_524344278301_item	2671677	et	4	main
nimetatud	doc_524344278301_item	2671688	et	4	main
tõlke	doc_524344278301_item	2671692	et	4	main
esinema	doc_524344278301_item	2671704	et	3	main
tundub	doc_524344278301_item	2671706	et	3	main
originaalis	doc_524344278301_item	2671721	et	3	main
juba	doc_524344278301_item	2671728	et	3	main
räägitud	doc_524344278301_item	2671730	et	4	main
hiljem	doc_524344278301_item	2671734	et	3	main
lugeja	doc_524344278301_item	2671737	et	4	main
saab	doc_524344278301_item	2671738	et	3	main
aru	doc_524344278301_item	2671739	et	4	main
ma	doc_524344278301_item	2671748	et	3	main
eks	doc_524344278301_item	2671761	et	3	main
ju	doc_524344278301_item	2671763	et	3	main
antud	doc_524344278301_item	2671771	et	4	main
juhul	doc_524344278301_item	2671772	et	3	main
tundub	doc_524344278301_item	2671773	et	3	main
mulle	doc_524344278301_item	2671774	et	4	main
imelikku	doc_524344278301_item	2671780	et	4	main
imelikku	doc_524344278301_item	2671785	et	4	main
võiks	doc_524344278301_item	2671787	et	4	main
keeles	doc_524344278301_item	2671789	et	4	main
kõlada	doc_524344278301_item	2671790	et	3	main
странных	doc_524344278301_item	2671792	et	2	main
ka	doc_524344278301_item	2671801	et	3	main
on	doc_524344278301_item	2671805	et	4	main
eesti	doc_524344278301_item	2671807	et	4	main
keeles	doc_524344278301_item	2671808	et	4	main
ei	doc_524344278301_item	2671810	et	4	main
моховая	doc_524344278301_item	2671813	et	2	main
sõnastiku	doc_524344278301_item	2671524	et	3	main
jäätiseputka	doc_524344278301_item	2671535	et	4	main
meie	doc_524344278301_item	2671538	et	4	main
vaatame	doc_524344278301_item	2671556	et	3	main
jäätiseputka	doc_524344278301_item	2671562	et	4	main
juures	doc_524344278301_item	2671563	et	4	main
täiesti	doc_524344278301_item	2671564	et	3	main
juhuslikult	doc_524344278301_item	2671565	et	4	main
kokku	doc_524344278301_item	2671566	et	3	main
kolm	doc_524344278301_item	2671567	et	3	main
imelikku	doc_524344278301_item	2671568	et	4	main
mehikest	doc_524344278301_item	2671569	et	3	main
sammalhabe	doc_524344278301_item	2671570	et	4	main
kingpool	doc_524344278301_item	2671571	et	4	main
ja	doc_524344278301_item	2671572	et	3	main
muhv	doc_524344278301_item	2671573	et	3	main
однажды	doc_524344278301_item	2671574	et	2	main
у	doc_524344278301_item	2671575	et	2	main
киоска	doc_524344278301_item	2671576	et	2	main
с	doc_524344278301_item	2671577	et	2	main
мороженым	doc_524344278301_item	2671578	et	2	main
случайно	doc_524344278301_item	2671579	et	2	main
встретились	doc_524344278301_item	2671580	et	2	main
трое	doc_524344278301_item	2671581	et	2	main
моховая	doc_524344278301_item	2671583	et	2	main
ükskord	doc_524344278301_item	2671588	et	3	main
однажды	doc_524344278301_item	2671592	et	2	main
kord	doc_524344278301_item	2671596	et	4	main
только	doc_524344278301_item	2671602	et	2	main
üks	doc_524344278301_item	2671605	et	3	main
этом	doc_524344278301_item	2671616	et	2	main
olen	doc_524344278301_item	2671618	et	3	main
ükskord	doc_524344278301_item	2671620	et	3	main
kuulnud	doc_524344278301_item	2671624	et	4	main
ükskord	doc_524344278301_item	2671626	et	3	main
kevadel	doc_524344278301_item	2671629	et	4	main
oleks	doc_524344278301_item	2671638	et	3	main
näiteks	doc_524344278301_item	2671642	et	4	main
tõlgitud	doc_524344278301_item	2671651	et	4	main
киоск	doc_524344278301_item	2671653	et	2	main
päris	doc_524344278301_item	2671658	et	4	main
imelikku	doc_524344278301_item	2671661	et	4	main
siit	doc_524344278301_item	2671663	et	3	main
autor	doc_524344278301_item	2671671	et	3	main
tahtis	doc_524344278301_item	2671672	et	3	main
rõhutada	doc_524344278301_item	2671673	et	3	main
tema	doc_524344278301_item	2671675	et	4	main
venekeelses	doc_524344278301_item	2671681	et	3	main
see	doc_524344278301_item	2671683	et	3	main
asendatudtõlgitud	doc_524344278301_item	2671685	et	4	main
tegelaste	doc_524344278301_item	2671686	et	3	main
kuskil	doc_524344278301_item	2671708	et	3	main
raamatu	doc_524344278301_item	2671724	et	4	main
millest	doc_524344278301_item	2671726	et	3	main
mängu	doc_524344278301_item	2671733	et	4	main
et	doc_524344278301_item	2671736	et	3	main
ütles	doc_524344278301_item	2671745	et	3	main
muidugi	doc_524344278301_item	2671750	et	4	main
kuid	doc_524344278301_item	2671752	et	4	main
mulle	doc_524344278301_item	2671753	et	4	main
tundub	doc_524344278301_item	2671754	et	3	main
et	doc_524344278301_item	2671755	et	3	main
kõik	doc_524344278301_item	2671765	et	4	main
kenad	doc_524344278301_item	2671767	et	3	main
naksitrallid	doc_524344278301_item	2671782	et	3	main
mehikest	doc_524344278301_item	2671786	et	3	main
on	doc_524344278301_item	2671800	et	4	main
muhv-	doc_524344278301_item	2671818	et	3	main
juba	doc_524344278301_item	2671623	et	3	main
kasutada	doc_524344278301_item	2671641	et	3	main
как-то	doc_524344278301_item	2671644	et	2	main
on	doc_524344278301_item	2671650	et	4	main
sobiv	doc_524344278301_item	2671659	et	4	main
on	doc_524344278301_item	2671668	et	4	main
mehikestest	doc_524344278301_item	2671669	et	3	main
kuid	doc_524344278301_item	2671670	et	4	main
et	doc_524344278301_item	2671674	et	3	main
ole	doc_524344278301_item	2671678	et	4	main
imelikud	doc_524344278301_item	2671680	et	3	main
tõlkes	doc_524344278301_item	2671682	et	3	main
on	doc_524344278301_item	2671684	et	4	main
nii	doc_524344278301_item	2671687	et	3	main
накситралли	doc_524344278301_item	2671690	et	2	main
tekkib	doc_524344278301_item	2671694	et	3	main
peaks	doc_524344278301_item	2671699	et	4	main
juba	doc_524344278301_item	2671700	et	3	main
kuskil	doc_524344278301_item	2671701	et	3	main
võetuna	doc_524344278301_item	2671710	et	4	main
varem	doc_524344278301_item	2671712	et	4	main
tõlkija	doc_524344278301_item	2671713	et	4	main
pole	doc_524344278301_item	2671714	et	3	main
seda	doc_524344278301_item	2671715	et	3	main
kuid	doc_524344278301_item	2671711	et	4	main
kasutanud	doc_524344278301_item	2671716	et	4	main
pealkirjas	doc_524344278301_item	2671717	et	3	main
ka	doc_524344278301_item	2671718	et	3	main
mitte	doc_524344278301_item	2671719	et	3	main
eestikeelses	doc_524344278301_item	2671720	et	3	main
on	doc_524344278301_item	2671723	et	4	main
pealkiri	doc_524344278301_item	2671725	et	3	main
kes	doc_524344278301_item	2671740	et	4	main
need	doc_524344278301_item	2671741	et	3	main
sellised	doc_524344278301_item	2671742	et	4	main
muhv	doc_524344278301_item	2671747	et	3	main
meil	doc_524344278301_item	2671756	et	4	main
midagi	doc_524344278301_item	2671759	et	4	main
me	doc_524344278301_item	2671762	et	4	main
noogutas	doc_524344278301_item	2671769	et	3	main
poolt	doc_524344278301_item	2671776	et	4	main
tehtud	doc_524344278301_item	2671777	et	4	main
et	doc_524344278301_item	2671803	et	3	main
tegelased	doc_524344278301_item	2671804	et	3	main
grammatiliselt	doc_524344278301_item	2671809	et	4	main
väljendu	doc_524344278301_item	2671811	et	4	main
sammalhabe-	doc_524344278301_item	2671812	et	4	main
борода	doc_524344278301_item	2671814	et	2	main
kingpool-	doc_524344278301_item	2671815	et	4	main
полботинка	doc_524344278301_item	2671816	et	2	main
ja	doc_524344278301_item	2671817	et	3	main
on	doc_524344278301_item	2671727	et	4	main
lõpuks	doc_524344278301_item	2671746	et	4	main
võin	doc_524344278301_item	2671749	et	3	main
oleks	doc_524344278301_item	2671757	et	3	main
tõlkija	doc_524344278301_item	2671775	et	4	main
mehikest	doc_524344278301_item	2671781	et	3	main
kolm	doc_524344278301_item	2671784	et	3	main
sellest	doc_524344278301_item	2671799	et	4	main
meessoostmis	doc_524344278301_item	2671806	et	4	main
муфта-	doc_524344278301_item	2671819	et	2	main
tegelaste	doc_524344278301_item	2671820	et	3	main
otses	doc_524344278301_item	2671825	et	3	main
adekvaatne	doc_524344278301_item	2671828	et	3	main
lühikest	doc_524344278301_item	2671835	et	4	main
kasvu	doc_524344278301_item	2671836	et	4	main
nii	doc_524344278301_item	2671837	et	3	main
et	doc_524344278301_item	2671838	et	3	main
selle	doc_524344278301_item	2671847	et	4	main
torkas	doc_524344278301_item	2671848	et	3	main
nende	doc_524344278301_item	2671849	et	4	main
muudki	doc_524344278301_item	2671852	et	4	main
iseäralikku	doc_524344278301_item	2671853	et	4	main
роста	doc_524344278301_item	2671860	et	2	main
мороженщица	doc_524344278301_item	2671862	et	2	main
их	doc_524344278301_item	2671864	et	2	main
поначалу	doc_524344278301_item	2671865	et	2	main
у	doc_524344278301_item	2671869	et	2	main
и	doc_524344278301_item	2671873	et	2	main
черточки	doc_524344278301_item	2671876	et	2	main
algus	doc_524344278301_item	2671878	et	4	main
komani	doc_524344278301_item	2671879	et	3	main
keelde	doc_524344278301_item	2671882	et	4	main
otse	doc_524344278301_item	2671883	et	4	main
ja	doc_524344278301_item	2671885	et	3	main
кургузый	doc_524344278301_item	2671893	et	2	main
кратковременный	doc_524344278301_item	2671898	et	2	main
tõlgitud	doc_524344278301_item	2671823	et	4	main
venekeelde	doc_524344278301_item	2671824	et	4	main
on	doc_524344278301_item	2671827	et	4	main
nad	doc_524344278301_item	2671831	et	3	main
väga	doc_524344278301_item	2671834	et	3	main
olid	doc_524344278301_item	2671833	et	4	main
pidas	doc_524344278301_item	2671840	et	3	main
neid	doc_524344278301_item	2671841	et	4	main
veel	doc_524344278301_item	2671851	et	4	main
такого	doc_524344278301_item	2671858	et	2	main
приняла	doc_524344278301_item	2671863	et	2	main
за	doc_524344278301_item	2671866	et	2	main
них	doc_524344278301_item	2671872	et	2	main
занятные	doc_524344278301_item	2671875	et	2	main
lause	doc_524344278301_item	2671877	et	4	main
on	doc_524344278301_item	2671880	et	4	main
vene	doc_524344278301_item	2671881	et	4	main
tõlgitud	doc_524344278301_item	2671884	et	4	main
elektroonilises	doc_524344278301_item	2671887	et	4	main
lühike	doc_524344278301_item	2671889	et	4	main
короткий	doc_524344278301_item	2671891	et	2	main
непродолжительный	doc_524344278301_item	2671895	et	2	main
краткосрочный	doc_524344278301_item	2671899	et	2	main
vene	doc_524344278301_item	2671903	et	4	main
kohta	doc_524344278301_item	2671906	et	4	main
keelde	doc_524344278301_item	2671913	et	4	main
nagu	doc_524344278301_item	2671914	et	3	main
leiame	doc_524344278301_item	2671919	et	3	main
seal	doc_524344278301_item	2671920	et	4	main
päris	doc_524344278301_item	2671934	et	4	main
jällegi	doc_524344278301_item	2671937	et	4	main
nimed	doc_524344278301_item	2671821	et	3	main
kõik	doc_524344278301_item	2671832	et	4	main
alguses	doc_524344278301_item	2671842	et	4	main
isegi	doc_524344278301_item	2671843	et	4	main
päkapikkudeks	doc_524344278301_item	2671844	et	4	main
ja	doc_524344278301_item	2671845	et	3	main
peale	doc_524344278301_item	2671846	et	4	main
juures	doc_524344278301_item	2671850	et	4	main
silma	doc_524344278301_item	2671854	et	4	main
все	doc_524344278301_item	2671855	et	2	main
они	doc_524344278301_item	2671856	et	2	main
были	doc_524344278301_item	2671857	et	2	main
что	doc_524344278301_item	2671861	et	2	main
гномов	doc_524344278301_item	2671867	et	2	main
из	doc_524344278301_item	2671871	et	2	main
kuigi	doc_524344278301_item	2671886	et	3	main
sõnastikus	doc_524344278301_item	2671888	et	3	main
недолгий	doc_524344278301_item	2671894	et	2	main
недолговременный	doc_524344278301_item	2671897	et	2	main
невеликий	doc_524344278301_item	2671900	et	2	main
kasutatakse	doc_524344278301_item	2671902	et	3	main
keeles	doc_524344278301_item	2671904	et	4	main
kasvu	doc_524344278301_item	2671905	et	4	main
tõlgitud	doc_524344278301_item	2671911	et	4	main
vene	doc_524344278301_item	2671912	et	4	main
antud	doc_524344278301_item	2671932	et	4	main
tõlge	doc_524344278301_item	2671933	et	3	main
võib	doc_524344278301_item	2671940	et	3	main
oluline	doc_524344278301_item	2671951	et	4	main
saame	doc_524344278301_item	2671956	et	4	main
ajal	doc_524344278301_item	2671960	et	4	main
all	doc_524344278301_item	2671962	et	3	main
kastikesega	doc_524344278301_item	2671971	et	4	main
spetsiaalne	doc_524344278301_item	2671975	et	3	main
venekeeleses	doc_524344278301_item	2672000	et	4	main
antud	doc_524344278301_item	2672005	et	4	main
tõlkija	doc_524344278301_item	2672009	et	4	main
muuda	doc_524344278301_item	2672014	et	4	main
mõtet	doc_524344278301_item	2672016	et	3	main
selle	doc_524344278301_item	2672019	et	4	main
iseäralikku	doc_524344278301_item	2672025	et	4	main
on	doc_524344278301_item	2671822	et	4	main
tõlge	doc_524344278301_item	2671826	et	3	main
ja	doc_524344278301_item	2671829	et	3	main
jäätismüüja	doc_524344278301_item	2671839	et	4	main
были	doc_524344278301_item	2671868	et	2	main
on	doc_524344278301_item	2671890	et	4	main
краткий	doc_524344278301_item	2671892	et	2	main
коротко-	doc_524344278301_item	2671896	et	2	main
немногословный	doc_524344278301_item	2671901	et	2	main
omadussõna	doc_524344278301_item	2671907	et	4	main
jäätisemüüja	doc_524344278301_item	2671909	et	4	main
vaadates	doc_524344278301_item	2671916	et	3	main
sobilik	doc_524344278301_item	2671830	et	3	main
маленького	doc_524344278301_item	2671859	et	2	main
каждого	doc_524344278301_item	2671870	et	2	main
другие	doc_524344278301_item	2671874	et	2	main
on	doc_524344278301_item	2671910	et	4	main
мороженщица	doc_524344278301_item	2671915	et	2	main
ozegovi	doc_524344278301_item	2671917	et	4	main
sõnaraamatut	doc_524344278301_item	2671918	et	3	main
järmise	doc_524344278301_item	2671921	et	4	main
мороженщик	doc_524344278301_item	2671923	et	2	main
м	doc_524344278301_item	2671925	et	2	main
sellest	doc_524344278301_item	2671929	et	4	main
seletusest	doc_524344278301_item	2671930	et	4	main
sugu	doc_524344278301_item	2671938	et	4	main
meessoost	doc_524344278301_item	2671942	et	4	main
kuid	doc_524344278301_item	2671944	et	4	main
uurides	doc_524344278301_item	2671953	et	4	main
teada	doc_524344278301_item	2671957	et	3	main
мороженщица	doc_524344278301_item	2671961	et	2	main
mõistsid	doc_524344278301_item	2671963	et	4	main
inimesed	doc_524344278301_item	2671964	et	3	main
jäätisemüüjat	doc_524344278301_item	2671965	et	3	main
kes	doc_524344278301_item	2671966	et	4	main
oli	doc_524344278301_item	2671974	et	3	main
kaks	doc_524344278301_item	2672002	et	3	main
kahjusta	doc_524344278301_item	2672012	et	4	main
autori	doc_524344278301_item	2672015	et	3	main
peale	doc_524344278301_item	2672018	et	4	main
nende	doc_524344278301_item	2672021	et	4	main
veel	doc_524344278301_item	2672023	et	4	main
muudki	doc_524344278301_item	2672024	et	4	main
väga	doc_524344278301_item	2672033	et	3	main
huvitav	doc_524344278301_item	2672036	et	4	main
kuidas	doc_524344278301_item	2672038	et	3	main
tõlkis	doc_524344278301_item	2672040	et	3	main
другие	doc_524344278301_item	2672047	et	2	main
järgi	doc_524344278301_item	2672060	et	4	main
nimisõna	doc_524344278301_item	2672061	et	4	main
iseäralik	doc_524344278301_item	2672062	et	3	main
брусники	doc_524344278301_item	2672121	et	2	main
asendab	doc_524344278301_item	2672124	et	3	main
vältida	doc_524344278301_item	2672131	et	3	main
asendab	doc_524344278301_item	2672144	et	3	main
прекрасные	doc_524344278301_item	2672147	et	2	main
п	doc_524344278301_item	2672150	et	2	main
ен	doc_524344278301_item	2672154	et	2	main
suurepärane	doc_524344278301_item	2672165	et	4	main
lõiganud	doc_524344278301_item	2672204	et	4	main
et	doc_524344278301_item	2672205	et	3	main
tal	doc_524344278301_item	2672206	et	3	main
oleks	doc_524344278301_item	2672207	et	3	main
в	doc_524344278301_item	2672215	et	2	main
мальнький	doc_524344278301_item	2671908	et	2	main
а	doc_524344278301_item	2671924	et	2	main
мороженого	doc_524344278301_item	2671927	et	2	main
autentne	doc_524344278301_item	2671935	et	3	main
ole	doc_524344278301_item	2671949	et	4	main
nii	doc_524344278301_item	2671950	et	3	main
tol	doc_524344278301_item	2671959	et	3	main
käis	doc_524344278301_item	2671967	et	4	main
või	doc_524344278301_item	2671972	et	4	main
vanker	doc_524344278301_item	2671976	et	3	main
kuid	doc_524344278301_item	2672004	et	4	main
arvates	doc_524344278301_item	2672008	et	4	main
torkas	doc_524344278301_item	2672020	et	3	main
juures	doc_524344278301_item	2672022	et	4	main
kui	doc_524344278301_item	2672027	et	3	main
kohmakalt	doc_524344278301_item	2672034	et	4	main
tõlkija	doc_524344278301_item	2672039	et	4	main
muudki	doc_524344278301_item	2672043	et	4	main
silma	doc_524344278301_item	2672045	et	4	main
vene	doc_524344278301_item	2672050	et	4	main
väljend	doc_524344278301_item	2672052	et	3	main
в	doc_524344278301_item	2672054	et	2	main
ning	doc_524344278301_item	2672065	et	3	main
venekeelde	doc_524344278301_item	2672066	et	4	main
võimalik	doc_524344278301_item	2672069	et	3	main
mida	doc_524344278301_item	2672077	et	4	main
ei	doc_524344278301_item	2672078	et	4	main
on	doc_524344278301_item	2672085	et	4	main
muinasjuttudele	doc_524344278301_item	2672089	et	3	main
sammalhabemel	doc_524344278301_item	2672090	et	4	main
ilusad	doc_524344278301_item	2672097	et	3	main
kordust	doc_524344278301_item	2672132	et	4	main
vt	doc_524344278301_item	2672133	et	4	main
были	doc_524344278301_item	2672136	et	2	main
каждого	doc_524344278301_item	2672138	et	2	main
них	doc_524344278301_item	2672140	et	2	main
ta	doc_524344278301_item	2672145	et	4	main
прекрасный	doc_524344278301_item	2672148	et	2	main
кр	doc_524344278301_item	2672152	et	2	main
ны	doc_524344278301_item	2672157	et	2	main
ülikena	doc_524344278301_item	2672160	et	4	main
imekena	doc_524344278301_item	2672168	et	4	main
kaunis	doc_524344278301_item	2672170	et	4	main
ная	doc_524344278301_item	2672172	et	2	main
tore	doc_524344278301_item	2672174	et	3	main
maha	doc_524344278301_item	2672203	et	4	main
обут	doc_524344278301_item	2672214	et	2	main
обрезанными	doc_524344278301_item	2672218	et	2	main
шевелить	doc_524344278301_item	2672222	et	2	main
keelses	doc_524344278301_item	2672228	et	3	main
maha	doc_524344278301_item	2672234	et	4	main
tegi	doc_524344278301_item	2672248	et	4	main
seda	doc_524344278301_item	2672249	et	3	main
vormi-	doc_524344278301_item	2672252	et	4	main
tõlkida	doc_524344278301_item	2672258	et	3	main
полботинка	doc_524344278301_item	2672261	et	2	main
у	doc_524344278301_item	2672266	et	2	main
arusaadav	doc_524344278301_item	2672287	et	4	main
ja	doc_524344278301_item	2672302	et	3	main
keskne	doc_524344278301_item	2672304	et	3	main
siin	doc_524344278301_item	2672306	et	4	main
väljendab	doc_524344278301_item	2672310	et	3	main
asendas	doc_524344278301_item	2672315	et	3	main
mõtet	doc_524344278301_item	2672330	et	3	main
muuda	doc_524344278301_item	2672332	et	4	main
было	doc_524344278301_item	2672341	et	2	main
пальцами	doc_524344278301_item	2672343	et	2	main
muhvi	doc_524344278301_item	2672352	et	4	main
millest	doc_524344278301_item	2672353	et	3	main
ainult	doc_524344278301_item	2672354	et	4	main
välja	doc_524344278301_item	2672358	et	4	main
муфта	doc_524344278301_item	2672361	et	2	main
толстую	doc_524344278301_item	2672366	et	2	main
макушка	doc_524344278301_item	2672372	et	2	main
и	doc_524344278301_item	2672421	et	2	main
seletuse	doc_524344278301_item	2671922	et	4	main
продавец	doc_524344278301_item	2671926	et	2	main
lähtudes	doc_524344278301_item	2671928	et	3	main
on	doc_524344278301_item	2671931	et	4	main
va	doc_524344278301_item	2671936	et	3	main
nii	doc_524344278301_item	2671941	et	3	main
olla	doc_524344278301_item	2671943	et	3	main
antud	doc_524344278301_item	2671945	et	4	main
juhul	doc_524344278301_item	2671946	et	3	main
see	doc_524344278301_item	2671947	et	3	main
ei	doc_524344278301_item	2671948	et	4	main
et	doc_524344278301_item	2671958	et	3	main
tänavaid	doc_524344278301_item	2671969	et	4	main
kas	doc_524344278301_item	2671970	et	3	main
mida	doc_524344278301_item	2671977	et	4	main
sai	doc_524344278301_item	2671978	et	4	main
samuti	doc_524344278301_item	2671979	et	3	main
ühe	doc_524344278301_item	2671980	et	4	main
koha	doc_524344278301_item	2671981	et	4	main
pealt	doc_524344278301_item	2671982	et	4	main
teisse	doc_524344278301_item	2671983	et	4	main
tõsta	doc_524344278301_item	2671984	et	4	main
meie	doc_524344278301_item	2671985	et	4	main
kontekstis	doc_524344278301_item	2671986	et	3	main
juttu	doc_524344278301_item	2671987	et	4	main
on	doc_524344278301_item	2671988	et	4	main
putkast	doc_524344278301_item	2671989	et	4	main
nii	doc_524344278301_item	2671990	et	3	main
et	doc_524344278301_item	2671991	et	3	main
täpsem	doc_524344278301_item	2671992	et	4	main
oleks	doc_524344278301_item	2671993	et	3	main
tõlkida	doc_524344278301_item	2671994	et	3	main
продавщица	doc_524344278301_item	2671995	et	2	main
мороженого	doc_524344278301_item	2671996	et	2	main
eestikeelne	doc_524344278301_item	2671997	et	3	main
lause	doc_524344278301_item	2671998	et	4	main
moodustub	doc_524344278301_item	2671999	et	3	main
tõlkes	doc_524344278301_item	2672001	et	3	main
jäätisemüüja	doc_524344278301_item	2671939	et	4	main
kuid	doc_524344278301_item	2671952	et	4	main
ajalugu	doc_524344278301_item	2671954	et	4	main
me	doc_524344278301_item	2671955	et	4	main
mööda	doc_524344278301_item	2671968	et	4	main
tal	doc_524344278301_item	2671973	et	3	main
lauset	doc_524344278301_item	2672003	et	3	main
minu	doc_524344278301_item	2672007	et	3	main
loovus	doc_524344278301_item	2672010	et	4	main
ei	doc_524344278301_item	2672011	et	4	main
ja	doc_524344278301_item	2672017	et	3	main
silma	doc_524344278301_item	2672026	et	4	main
tõlkida	doc_524344278301_item	2672028	et	3	main
были	doc_524344278301_item	2672046	et	2	main
omadussõna	doc_524344278301_item	2672064	et	4	main
tõlkija	doc_524344278301_item	2672072	et	4	main
oli	doc_524344278301_item	2672091	et	3	main
pehmest	doc_524344278301_item	2672092	et	3	main
samblast	doc_524344278301_item	2672093	et	4	main
habe	doc_524344278301_item	2672094	et	3	main
siin	doc_524344278301_item	2672122	et	4	main
selleks	doc_524344278301_item	2672129	et	4	main
et	doc_524344278301_item	2672130	et	3	main
punased	doc_524344278301_item	2672143	et	4	main
1	doc_524344278301_item	2672151	et	2	main
но	doc_524344278301_item	2672156	et	2	main
tore	doc_524344278301_item	2672162	et	3	main
õevane	doc_524344278301_item	2672164	et	3	main
vaade	doc_524344278301_item	2672171	et	3	main
oma	doc_524344278301_item	2672201	et	4	main
kinganinad	doc_524344278301_item	2672202	et	3	main
liigutada	doc_524344278301_item	2672211	et	3	main
был	doc_524344278301_item	2672213	et	2	main
так	doc_524344278301_item	2672220	et	2	main
пальцами	doc_524344278301_item	2672223	et	2	main
lauses	doc_524344278301_item	2672226	et	3	main
kasutatud	doc_524344278301_item	2672231	et	4	main
mis	doc_524344278301_item	2672236	et	4	main
minevikuhetkele	doc_524344278301_item	2672238	et	4	main
eelnevat	doc_524344278301_item	2672239	et	4	main
tegevust	doc_524344278301_item	2672240	et	4	main
kasutades	doc_524344278301_item	2672250	et	3	main
võiks	doc_524344278301_item	2672256	et	4	main
nii-	doc_524344278301_item	2672260	et	3	main
ботинок	doc_524344278301_item	2672265	et	2	main
antud	doc_524344278301_item	2672269	et	4	main
ei	doc_524344278301_item	2672271	et	4	main
kuid	doc_524344278301_item	2672278	et	4	main
ole	doc_524344278301_item	2672286	et	4	main
maha	doc_524344278301_item	2672293	et	4	main
interpritatsiooni	doc_524344278301_item	2672301	et	4	main
on	doc_524344278301_item	2672307	et	4	main
teatud	doc_524344278301_item	2672311	et	4	main
põnevust	doc_524344278301_item	2672313	et	4	main
igavam	doc_524344278301_item	2672322	et	4	main
sidesõna	doc_524344278301_item	2672324	et	4	main
asendas	doc_524344278301_item	2672326	et	3	main
веселей	doc_524344278301_item	2672339	et	2	main
riiete	doc_524344278301_item	2672348	et	3	main
ja	doc_524344278301_item	2672356	et	3	main
paistsid	doc_524344278301_item	2672359	et	4	main
обычной	doc_524344278301_item	2672363	et	2	main
носил	doc_524344278301_item	2672365	et	2	main
из	doc_524344278301_item	2672368	et	2	main
торчали	doc_524344278301_item	2672370	et	2	main
пятки	doc_524344278301_item	2672374	et	2	main
ели	doc_524344278301_item	2672419	et	2	main
большим	doc_524344278301_item	2672423	et	2	main
друг	doc_524344278301_item	2672426	et	2	main
antud	doc_524344278301_item	2672428	et	4	main
limpsisid	doc_524344278301_item	2672436	et	4	main
eredaidemotsionaalseid	doc_524344278301_item	2672440	et	4	main
tõlkes	doc_524344278301_item	2672443	et	3	main
emotsionaalsuse	doc_524344278301_item	2672445	et	4	main
täitsa	doc_524344278301_item	2672458	et	3	main
лизать	doc_524344278301_item	2672460	et	2	main
rõhutada	doc_524344278301_item	2672463	et	3	main
emotsionaalsust	doc_524344278301_item	2672464	et	4	main
lisakirjandus	doc_524344278301_item	2672474	et	3	main
наук	doc_524344278301_item	2672479	et	2	main
juhul	doc_524344278301_item	2672006	et	3	main
ega	doc_524344278301_item	2672013	et	3	main
antud	doc_524344278301_item	2672029	et	4	main
lauset	doc_524344278301_item	2672030	et	3	main
otse	doc_524344278301_item	2672031	et	4	main
tuleb	doc_524344278301_item	2672032	et	3	main
välja	doc_524344278301_item	2672035	et	4	main
on	doc_524344278301_item	2672037	et	4	main
torkas	doc_524344278301_item	2672042	et	3	main
iseäralikku	doc_524344278301_item	2672044	et	4	main
черточки	doc_524344278301_item	2672049	et	2	main
on	doc_524344278301_item	2672063	et	4	main
pole	doc_524344278301_item	2672067	et	3	main
ole	doc_524344278301_item	2672079	et	4	main
variandis	doc_524344278301_item	2672082	et	3	main
kuid	doc_524344278301_item	2672083	et	4	main
see	doc_524344278301_item	2672084	et	3	main
väga	doc_524344278301_item	2672086	et	3	main
omane	doc_524344278301_item	2672087	et	3	main
venekeelsetele	doc_524344278301_item	2672088	et	4	main
kasvasid	doc_524344278301_item	2672096	et	4	main
punased	doc_524344278301_item	2672099	et	4	main
mullusuvised	doc_524344278301_item	2672101	et	4	main
pohlad	doc_524344278301_item	2672102	et	3	main
у	doc_524344278301_item	2672103	et	2	main
моховой	doc_524344278301_item	2672104	et	2	main
бороды-	doc_524344278301_item	2672105	et	2	main
борода	doc_524344278301_item	2672106	et	2	main
из	doc_524344278301_item	2672107	et	2	main
мха	doc_524344278301_item	2672109	et	2	main
мягкого	doc_524344278301_item	2672108	et	2	main
в	doc_524344278301_item	2672110	et	2	main
которой	doc_524344278301_item	2672111	et	2	main
хоть	doc_524344278301_item	2672113	et	2	main
росли	doc_524344278301_item	2672112	et	2	main
и	doc_524344278301_item	2672114	et	2	main
прошлогодние	doc_524344278301_item	2672115	et	2	main
но	doc_524344278301_item	2672116	et	2	main
равно	doc_524344278301_item	2672118	et	2	main
все	doc_524344278301_item	2672117	et	2	main
ягоды	doc_524344278301_item	2672120	et	2	main
прекрасные	doc_524344278301_item	2672119	et	2	main
ilmselt	doc_524344278301_item	2672128	et	4	main
ja	doc_524344278301_item	2672142	et	3	main
sõnaga	doc_524344278301_item	2672146	et	3	main
ф	doc_524344278301_item	2672153	et	2	main
ilus	doc_524344278301_item	2672159	et	4	main
kaunis	doc_524344278301_item	2672161	et	4	main
oivaline	doc_524344278301_item	2672163	et	3	main
вид	doc_524344278301_item	2672167	et	2	main
lahe	doc_524344278301_item	2672209	et	4	main
varbaid	doc_524344278301_item	2672210	et	3	main
полботинка	doc_524344278301_item	2672212	et	2	main
с	doc_524344278301_item	2672217	et	2	main
eesti	doc_524344278301_item	2672227	et	4	main
oli	doc_524344278301_item	2672233	et	3	main
seda	doc_524344278301_item	2672242	et	3	main
tõlkida	doc_524344278301_item	2672244	et	3	main
keelde	doc_524344278301_item	2672246	et	4	main
tõlkija	doc_524344278301_item	2672247	et	4	main
samas	doc_524344278301_item	2672255	et	4	main
ka	doc_524344278301_item	2672259	et	3	main
fraasi	doc_524344278301_item	2672041	et	4	main
занятные	doc_524344278301_item	2672048	et	2	main
keeles	doc_524344278301_item	2672051	et	4	main
бросаться	doc_524344278301_item	2672053	et	2	main
глаза	doc_524344278301_item	2672055	et	2	main
silma	doc_524344278301_item	2672056	et	4	main
torkama	doc_524344278301_item	2672057	et	3	main
nõuab	doc_524344278301_item	2672058	et	3	main
enda	doc_524344278301_item	2672059	et	4	main
seda	doc_524344278301_item	2672068	et	3	main
nimisõnana	doc_524344278301_item	2672070	et	3	main
tõlkida	doc_524344278301_item	2672071	et	3	main
kasutas	doc_524344278301_item	2672073	et	3	main
ka	doc_524344278301_item	2672074	et	3	main
deminutiivi	doc_524344278301_item	2672075	et	4	main
черточки	doc_524344278301_item	2672076	et	2	main
küll	doc_524344278301_item	2672080	et	4	main
eestikeelses	doc_524344278301_item	2672081	et	3	main
kus	doc_524344278301_item	2672095	et	3	main
ja	doc_524344278301_item	2672098	et	3	main
kuigi	doc_524344278301_item	2672100	et	3	main
tõlkija	doc_524344278301_item	2672123	et	4	main
tegusõna	doc_524344278301_item	2672125	et	4	main
olema	doc_524344278301_item	2672126	et	4	main
sidkriipsuga	doc_524344278301_item	2672127	et	4	main
eelmises	doc_524344278301_item	2672134	et	3	main
lauses	doc_524344278301_item	2672135	et	3	main
у	doc_524344278301_item	2672137	et	2	main
из	doc_524344278301_item	2672139	et	2	main
ilusad	doc_524344278301_item	2672141	et	3	main
126	doc_524344278301_item	2672149	et	2	main
на	doc_524344278301_item	2672155	et	2	main
väga	doc_524344278301_item	2672158	et	3	main
ный	doc_524344278301_item	2672166	et	2	main
v	doc_524344278301_item	2672169	et	4	main
погода	doc_524344278301_item	2672173	et	2	main
v	doc_524344278301_item	2672175	et	4	main
ilus	doc_524344278301_item	2672176	et	4	main
ilm	doc_524344278301_item	2672177	et	3	main
ное	doc_524344278301_item	2672178	et	2	main
образование	doc_524344278301_item	2672179	et	2	main
väga	doc_524344278301_item	2672180	et	3	main
hea	doc_524344278301_item	2672181	et	4	main
haridus	doc_524344278301_item	2672182	et	3	main
ный	doc_524344278301_item	2672183	et	2	main
человек	doc_524344278301_item	2672184	et	2	main
tore	doc_524344278301_item	2672185	et	3	main
v	doc_524344278301_item	2672186	et	4	main
suurepärane	doc_524344278301_item	2672187	et	4	main
inimene	doc_524344278301_item	2672188	et	3	main
võis	doc_524344278301_item	2672189	et	4	main
tõlkida	doc_524344278301_item	2672190	et	3	main
ka	doc_524344278301_item	2672191	et	3	main
otse	doc_524344278301_item	2672192	et	4	main
ilusad	doc_524344278301_item	2672193	et	3	main
ja	doc_524344278301_item	2672194	et	3	main
punased	doc_524344278301_item	2672195	et	4	main
красивые	doc_524344278301_item	2672196	et	2	main
и	doc_524344278301_item	2672197	et	2	main
красные	doc_524344278301_item	2672198	et	2	main
kingpool	doc_524344278301_item	2672199	et	4	main
oli	doc_524344278301_item	2672200	et	3	main
hea	doc_524344278301_item	2672208	et	4	main
ботинки	doc_524344278301_item	2672216	et	2	main
носами	doc_524344278301_item	2672219	et	2	main
удобнее	doc_524344278301_item	2672221	et	2	main
antud	doc_524344278301_item	2672225	et	4	main
on	doc_524344278301_item	2672230	et	4	main
on	doc_524344278301_item	2672241	et	4	main
был	doc_524344278301_item	2672253	et	2	main
seda	doc_524344278301_item	2672257	et	3	main
носы	doc_524344278301_item	2672263	et	2	main
ботинок	doc_524344278301_item	2672268	et	2	main
tõlge	doc_524344278301_item	2672270	et	3	main
anna	doc_524344278301_item	2672272	et	4	main
aspektuaalsuse	doc_524344278301_item	2672273	et	4	main
momendi	doc_524344278301_item	2672274	et	3	main
nii	doc_524344278301_item	2672275	et	3	main
hästi	doc_524344278301_item	2672276	et	3	main
edasi	doc_524344278301_item	2672277	et	3	main
tõlkija	doc_524344278301_item	2672297	et	4	main
andis	doc_524344278301_item	2672298	et	3	main
ka	doc_524344278301_item	2672299	et	3	main
oma	doc_524344278301_item	2672300	et	4	main
see	doc_524344278301_item	2672309	et	3	main
mis	doc_524344278301_item	2672319	et	4	main
kuna	doc_524344278301_item	2672224	et	3	main
variandis	doc_524344278301_item	2672229	et	3	main
enneminevik	doc_524344278301_item	2672232	et	3	main
lõiganud	doc_524344278301_item	2672235	et	4	main
väljendab	doc_524344278301_item	2672237	et	3	main
keeruline	doc_524344278301_item	2672243	et	4	main
vene	doc_524344278301_item	2672245	et	4	main
umbisikulist	doc_524344278301_item	2672251	et	4	main
обут	doc_524344278301_item	2672254	et	2	main
своих	doc_524344278301_item	2672264	et	2	main
on	doc_524344278301_item	2672279	et	4	main
minu	doc_524344278301_item	2672280	et	3	main
meelest	doc_524344278301_item	2672281	et	4	main
et	doc_524344278301_item	2672288	et	3	main
kingpool	doc_524344278301_item	2672289	et	4	main
lõiganud	doc_524344278301_item	2672294	et	4	main
teisele	doc_524344278301_item	2672295	et	4	main
lauseosale	doc_524344278301_item	2672296	et	3	main
lahe	doc_524344278301_item	2672308	et	4	main
mängulisust	doc_524344278301_item	2672312	et	4	main
seda	doc_524344278301_item	2672316	et	3	main
sõnaga	doc_524344278301_item	2672317	et	3	main
mis	doc_524344278301_item	2672329	et	4	main
можно	doc_524344278301_item	2672340	et	2	main
muhv	doc_524344278301_item	2672344	et	3	main
kandis	doc_524344278301_item	2672346	et	4	main
peanupp	doc_524344278301_item	2672355	et	3	main
siin	doc_524344278301_item	2672375	et	4	main
silmitsesid	doc_524344278301_item	2672415	et	4	main
üksteist	doc_524344278301_item	2672416	et	4	main
uudishimulikult	doc_524344278301_item	2672417	et	4	main
они	doc_524344278301_item	2672418	et	2	main
с	doc_524344278301_item	2672422	et	2	main
autor	doc_524344278301_item	2672431	et	3	main
edasi	doc_524344278301_item	2672433	et	3	main
lapselikkust	doc_524344278301_item	2672435	et	4	main
suurt	doc_524344278301_item	2672437	et	3	main
sõnu	doc_524344278301_item	2672441	et	4	main
värving	doc_524344278301_item	2672446	et	3	main
limpsima	doc_524344278301_item	2672447	et	3	main
sööma	doc_524344278301_item	2672452	et	4	main
kuigi	doc_524344278301_item	2672453	et	3	main
ekvivalent	doc_524344278301_item	2672457	et	3	main
tõlkija	doc_524344278301_item	2672461	et	4	main
polnud	doc_524344278301_item	2672473	et	3	main
филол	doc_524344278301_item	2672478	et	2	main
речевой	doc_524344278301_item	2672483	et	2	main
речевых	doc_524344278301_item	2672486	et	2	main
информации	doc_524344278301_item	2672491	et	2	main
докт	doc_524344278301_item	2672495	et	2	main
ульяновск	doc_524344278301_item	2672499	et	2	main
leidsin	doc_527420171752_item	2672695	et	3	main
august	doc_527420171752_item	2672700	et	4	main
sellele	doc_527420171752_item	2672706	et	4	main
et	doc_527420171752_item	2672707	et	3	main
tranlatsioon	doc_527420171752_item	2672708	et	4	main
kehv	doc_527420171752_item	2672711	et	3	main
обрезал	doc_524344278301_item	2672262	et	2	main
своих	doc_524344278301_item	2672267	et	2	main
täpsem	doc_524344278301_item	2672282	et	4	main
kuna	doc_524344278301_item	2672283	et	3	main
originaaltõlkest	doc_524344278301_item	2672284	et	4	main
ei	doc_524344278301_item	2672285	et	4	main
on	doc_524344278301_item	2672290	et	4	main
kinganinad	doc_524344278301_item	2672291	et	3	main
ise	doc_524344278301_item	2672292	et	4	main
värvingu	doc_524344278301_item	2672303	et	3	main
sõna	doc_524344278301_item	2672305	et	4	main
tõlkija	doc_524344278301_item	2672314	et	4	main
mugav	doc_524344278301_item	2672318	et	3	main
on	doc_524344278301_item	2672320	et	4	main
mõnevõrra	doc_524344278301_item	2672321	et	3	main
kooloniga	doc_524344278301_item	2672328	et	3	main
ei	doc_524344278301_item	2672331	et	4	main
kuid	doc_524344278301_item	2672333	et	4	main
võis	doc_524344278301_item	2672334	et	4	main
ka	doc_524344278301_item	2672335	et	3	main
nii	doc_524344278301_item	2672336	et	3	main
чтобы	doc_524344278301_item	2672337	et	2	main
шевелить	doc_524344278301_item	2672342	et	2	main
aga	doc_524344278301_item	2672345	et	3	main
tavaliste	doc_524344278301_item	2672347	et	4	main
asemel	doc_524344278301_item	2672349	et	4	main
seljas	doc_524344278301_item	2672350	et	4	main
suurt	doc_524344278301_item	2672351	et	3	main
labajalad	doc_524344278301_item	2672357	et	3	main
а	doc_524344278301_item	2672360	et	2	main
вместо	doc_524344278301_item	2672362	et	2	main
одежды	doc_524344278301_item	2672364	et	2	main
муфту	doc_524344278301_item	2672367	et	2	main
которой	doc_524344278301_item	2672369	et	2	main
только	doc_524344278301_item	2672371	et	2	main
и	doc_524344278301_item	2672373	et	2	main
autori	doc_524344278301_item	2672409	et	3	main
mõõtet	doc_524344278301_item	2672410	et	4	main
nad	doc_524344278301_item	2672411	et	3	main
limpsisid	doc_524344278301_item	2672412	et	4	main
jäätist	doc_524344278301_item	2672413	et	3	main
ja	doc_524344278301_item	2672414	et	3	main
мороженое	doc_524344278301_item	2672420	et	2	main
любопытством	doc_524344278301_item	2672424	et	2	main
kaob	doc_524344278301_item	2672444	et	3	main
on	doc_524344278301_item	2672448	et	4	main
любопытством	doc_524344278301_item	2672468	et	2	main
sõna	doc_524344278301_item	2672469	et	4	main
suur	doc_524344278301_item	2672470	et	3	main
algses	doc_524344278301_item	2672471	et	3	main
variandis	doc_524344278301_item	2672472	et	3	main
архарова	doc_524344278301_item	2672476	et	2	main
доцент	doc_524344278301_item	2672480	et	2	main
выполнение	doc_524344278301_item	2672485	et	2	main
основной	doc_524344278301_item	2672490	et	2	main
филол	doc_524344278301_item	2672496	et	2	main
о	doc_524344278301_item	2672500	et	2	main
alistavat	doc_524344278301_item	2672323	et	4	main
et	doc_524344278301_item	2672325	et	3	main
tõlkija	doc_524344278301_item	2672327	et	4	main
свободней	doc_524344278301_item	2672338	et	2	main
autor	doc_524344278301_item	2672376	et	3	main
tahtis	doc_524344278301_item	2672377	et	3	main
näidata	doc_524344278301_item	2672378	et	4	main
kolmanda	doc_524344278301_item	2672379	et	3	main
tegelase	doc_524344278301_item	2672380	et	3	main
iseäralikkust	doc_524344278301_item	2672381	et	4	main
ning	doc_524344278301_item	2672382	et	3	main
see	doc_524344278301_item	2672383	et	3	main
õnnestus	doc_524344278301_item	2672384	et	4	main
ka	doc_524344278301_item	2672385	et	3	main
tõlkijal	doc_524344278301_item	2672386	et	4	main
edasianda	doc_524344278301_item	2672387	et	4	main
kuid	doc_524344278301_item	2672388	et	4	main
viimane	doc_524344278301_item	2672389	et	3	main
millegipärast	doc_524344278301_item	2672390	et	3	main
asendas	doc_524344278301_item	2672391	et	3	main
большую	doc_524344278301_item	2672392	et	2	main
муфту	doc_524344278301_item	2672393	et	2	main
на	doc_524344278301_item	2672394	et	2	main
толстую	doc_524344278301_item	2672395	et	2	main
originaaltekstis	doc_524344278301_item	2672396	et	3	main
suur	doc_524344278301_item	2672397	et	3	main
tõlkes	doc_524344278301_item	2672398	et	3	main
paks	doc_524344278301_item	2672399	et	3	main
minu	doc_524344278301_item	2672400	et	3	main
arvates	doc_524344278301_item	2672401	et	4	main
antud	doc_524344278301_item	2672402	et	4	main
asendus	doc_524344278301_item	2672403	et	4	main
ole	doc_524344278301_item	2672405	et	4	main
ei	doc_524344278301_item	2672404	et	4	main
õigustatud	doc_524344278301_item	2672406	et	4	main
ja	doc_524344278301_item	2672407	et	3	main
muudab	doc_524344278301_item	2672408	et	3	main
разглядывали	doc_524344278301_item	2672425	et	2	main
lausega	doc_524344278301_item	2672429	et	3	main
tahtis	doc_524344278301_item	2672430	et	3	main
anda	doc_524344278301_item	2672432	et	3	main
uudishimu	doc_524344278301_item	2672438	et	4	main
vene	doc_524344278301_item	2672454	et	4	main
keeles	doc_524344278301_item	2672455	et	4	main
on	doc_524344278301_item	2672456	et	4	main
olemas	doc_524344278301_item	2672459	et	4	main
soovides	doc_524344278301_item	2672462	et	4	main
lisas	doc_524344278301_item	2672465	et	4	main
с	doc_524344278301_item	2672466	et	2	main
большим	doc_524344278301_item	2672467	et	2	main
ди	doc_524344278301_item	2672475	et	2	main
канд	doc_524344278301_item	2672477	et	2	main
аспекты	doc_524344278301_item	2672482	et	2	main
способствующих	doc_524344278301_item	2672488	et	2	main
необходимости	doc_524344278301_item	2672501	et	2	main
и	doc_524344278301_item	2672504	et	2	main
ключевых	doc_524344278301_item	2672505	et	2	main
элементов	doc_524344278301_item	2672506	et	2	main
текста	doc_524344278301_item	2672507	et	2	main
при	doc_524344278301_item	2672508	et	2	main
его	doc_524344278301_item	2672509	et	2	main
филологическом	doc_524344278301_item	2672510	et	2	main
анализе	doc_524344278301_item	2672511	et	2	main
друга	doc_524344278301_item	2672427	et	2	main
mängulisust	doc_524344278301_item	2672434	et	4	main
kasutades	doc_524344278301_item	2672439	et	3	main
venekeelses	doc_524344278301_item	2672442	et	3	main
asendatud	doc_524344278301_item	2672449	et	4	main
lihtsalt	doc_524344278301_item	2672450	et	4	main
sõnaga	doc_524344278301_item	2672451	et	3	main
познавательно-личностные	doc_524344278301_item	2672481	et	2	main
действий	doc_524344278301_item	2672487	et	2	main
учебного	doc_524344278301_item	2672492	et	2	main
httpcsnetruconf2006ruslangmaintrendarharovahtm	doc_524344278301_item	2672494	et	4	main
авпузырёв	doc_524344278301_item	2672498	et	2	main
опорных	doc_524344278301_item	2672503	et	2	main
деятельности	doc_524344278301_item	2672484	et	2	main
пониманию	doc_524344278301_item	2672489	et	2	main
текста	doc_524344278301_item	2672493	et	2	main
наук	doc_524344278301_item	2672497	et	2	main
разграничения	doc_524344278301_item	2672502	et	2	main
ma	doc_527420171752_item	2672694	et	3	main
kuidas	doc_527420171752_item	2672697	et	3	main
1991	doc_527420171752_item	2672701	et	2	main
oli	doc_527420171752_item	2672709	et	3	main
mul	doc_527420171752_item	2672712	et	3	main
oma	doc_527420171752_item	2672714	et	4	main
1991	doc_527420171752_item	2672727	et	2	main
elanikud	doc_527420171752_item	2672750	et	3	main
toimus	doc_527420171752_item	2672756	et	3	main
putsh	doc_527420171752_item	2672758	et	4	main
eesti	doc_527420171752_item	2672759	et	4	main
tol	doc_527420171752_item	2672760	et	3	main
ja	doc_527420171752_item	2672762	et	3	main
nagu	doc_527420171752_item	2672763	et	3	main
otsustas	doc_527420171752_item	2672774	et	3	main
vene	doc_527420171752_item	2672775	et	4	main
saada	doc_527420171752_item	2672778	et	4	main
mis	doc_527420171752_item	2672787	et	4	main
vaatamata	doc_527420171752_item	2672705	et	4	main
film	doc_527420171752_item	2672719	et	3	main
tõde	doc_527420171752_item	2672722	et	4	main
kolm	doc_527420171752_item	2672730	et	3	main
päeva	doc_527420171752_item	2672731	et	4	main
täpsustega	doc_527420171752_item	2672733	et	4	main
näitakse	doc_527420171752_item	2672736	et	4	main
korratus	doc_527420171752_item	2672738	et	4	main
põhjus	doc_527420171752_item	2672751	et	4	main
selles	doc_527420171752_item	2672753	et	4	main
palju	doc_527420171752_item	2672769	et	4	main
katseid	doc_527420171752_item	2672772	et	3	main
tallinnasse	doc_527420171752_item	2672777	et	3	main
ma	doc_527420171752_item	2672779	et	3	main
ei	doc_527420171752_item	2672780	et	4	main
eesmärk	doc_527420171752_item	2672788	et	3	main
oli	doc_527420171752_item	2672791	et	3	main
etv	doc_527420171752_item	2672822	et	4	main
samal	doc_527420171752_item	2672830	et	3	main
kanda	doc_527420171752_item	2672839	et	4	main
ainult	doc_527420171752_item	2672846	et	4	main
imestada	doc_527420171752_item	2672847	et	3	main
kui	doc_527420171752_item	2672848	et	3	main
vaprad	doc_527420171752_item	2672849	et	3	main
need	doc_527420171752_item	2672850	et	3	main
inimesed	doc_527420171752_item	2672851	et	3	main
keerulised	doc_527420171752_item	2672856	et	4	main
informatsiooni	doc_527420171752_item	2672859	et	4	main
ja	doc_527420171752_item	2672861	et	3	main
püüda	doc_527420171752_item	2672862	et	3	main
rünnaku	doc_527420171752_item	2672863	et	4	main
selliseid	doc_527420171752_item	2672869	et	4	main
sündmusi	doc_527420171752_item	2672870	et	3	main
vana	doc_527420171752_item	2672879	et	4	main
lihtsalt	doc_527420171752_item	2672883	et	4	main
on	doc_527420171752_item	2672897	et	4	main
olnud	doc_527420171752_item	2672909	et	4	main
iseseisvust	doc_527420171752_item	2672914	et	4	main
saavutas	doc_527420171752_item	2672915	et	3	main
oma	doc_527420171752_item	2672916	et	4	main
ilma	doc_527420171752_item	2672918	et	4	main
1991	doc_527420171752_item	2672924	et	2	main
mäletada	doc_527420171752_item	2672927	et	3	main
essee	doc_527420171753_item	2672931	et	4	main
hästi	doc_527420171753_item	2672933	et	3	main
lugu	doc_527420171753_item	2672940	et	4	main
selles	doc_527420171753_item	2672941	et	4	main
venemaal	doc_527420171753_item	2672948	et	4	main
presidendi	doc_527420171753_item	2672958	et	4	main
siseneb	doc_527420171753_item	2672983	et	3	main
poole	doc_527420171753_item	2672989	et	4	main
isegi	doc_527420171753_item	2673011	et	4	main
võib	doc_527420171753_item	2673012	et	3	main
teha	doc_527420171753_item	2673013	et	3	main
kui	doc_527420171753_item	2673014	et	3	main
sa	doc_527420171753_item	2673015	et	3	main
sündmusi	doc_527420171753_item	2673026	et	3	main
kas	doc_527420171753_item	2673033	et	3	main
hästi	doc_527420171753_item	2673034	et	3	main
ei	doc_527420171753_item	2673040	et	4	main
hästi	doc_527420171753_item	2673052	et	3	main
näidatud	doc_527420171753_item	2673053	et	4	main
ei	doc_527420171753_item	2673067	et	4	main
ülemnõukogu	doc_527420171753_item	2673072	et	4	main
essee	doc_527420171752_item	2672687	et	4	main
eile	doc_527420171752_item	2672688	et	3	main
õhtul	doc_527420171752_item	2672689	et	3	main
mul	doc_527420171752_item	2672690	et	3	main
lõpuks	doc_527420171752_item	2672691	et	4	main
vedas	doc_527420171752_item	2672692	et	4	main
ja	doc_527420171752_item	2672693	et	3	main
filmi	doc_527420171752_item	2672699	et	4	main
väga	doc_527420171752_item	2672710	et	3	main
on	doc_527420171752_item	2672713	et	4	main
muljeid	doc_527420171752_item	2672715	et	3	main
viisi	doc_527420171752_item	2672696	et	4	main
seda	doc_527420171752_item	2672698	et	3	main
vaadata	doc_527420171752_item	2672702	et	4	main
interneti	doc_527420171752_item	2672703	et	4	main
teel	doc_527420171752_item	2672704	et	4	main
see	doc_527420171752_item	2672717	et	3	main
eestis	doc_527420171752_item	2672728	et	3	main
kellaajalise	doc_527420171752_item	2672732	et	4	main
uuritakse	doc_527420171752_item	2672734	et	3	main
milline	doc_527420171752_item	2672737	et	3	main
kaos	doc_527420171752_item	2672739	et	4	main
ja	doc_527420171752_item	2672740	et	3	main
eesti	doc_527420171752_item	2672749	et	4	main
et	doc_527420171752_item	2672754	et	3	main
riigipööre	doc_527420171752_item	2672757	et	4	main
ajal	doc_527420171752_item	2672761	et	4	main
alati	doc_527420171752_item	2672764	et	4	main
tahaks	doc_527420171752_item	2672765	et	3	main
olla	doc_527420171752_item	2672766	et	3	main
iseseisvat	doc_527420171752_item	2672767	et	3	main
ja	doc_527420171752_item	2672771	et	3	main
sõjavägi	doc_527420171752_item	2672776	et	3	main
kaitsa	doc_527420171752_item	2672828	et	4	main
vaatajateni	doc_527420171752_item	2672838	et	4	main
kui	doc_527420171752_item	2672840	et	3	main
saan	doc_527420171752_item	2672845	et	4	main
olid	doc_527420171752_item	2672852	et	4	main
nende	doc_527420171752_item	2672853	et	4	main
ülesanded	doc_527420171752_item	2672857	et	3	main
andmine	doc_527420171752_item	2672860	et	4	main
kanda	doc_527420171752_item	2672866	et	4	main
ei	doc_527420171752_item	2672872	et	4	main
mäleta	doc_527420171752_item	2672873	et	4	main
võib	doc_527420171752_item	2672881	et	3	main
lubanud	doc_527420171752_item	2672889	et	4	main
et	doc_527420171752_item	2672890	et	3	main
mina	doc_527420171752_item	2672891	et	4	main
hea	doc_527420171752_item	2672898	et	4	main
eesti	doc_527420171752_item	2672910	et	4	main
lõpuks	doc_527420171752_item	2672911	et	4	main
formeeritud	doc_527420171752_item	2672716	et	4	main
dokumentaalne	doc_527420171752_item	2672718	et	3	main
avaneb	doc_527420171752_item	2672720	et	3	main
meile	doc_527420171752_item	2672721	et	4	main
sündmustele	doc_527420171752_item	2672723	et	3	main
mis	doc_527420171752_item	2672724	et	4	main
olid	doc_527420171752_item	2672725	et	4	main
augustis	doc_527420171752_item	2672726	et	3	main
ja	doc_527420171752_item	2672735	et	3	main
ebamugavused	doc_527420171752_item	2672747	et	4	main
oli	doc_527420171752_item	2672752	et	3	main
tegi	doc_527420171752_item	2672768	et	4	main
tea	doc_527420171752_item	2672781	et	4	main
kas	doc_527420171752_item	2672782	et	3	main
need	doc_527420171752_item	2672783	et	3	main
sõdurid	doc_527420171752_item	2672784	et	3	main
üldse	doc_527420171752_item	2672785	et	3	main
teadnud	doc_527420171752_item	2672786	et	4	main
nendel	doc_527420171752_item	2672790	et	4	main
oli	doc_527420171752_item	2672792	et	3	main
töötajad	doc_527420171752_item	2672823	et	4	main
tõesti	doc_527420171752_item	2672843	et	3	main
ees	doc_527420171752_item	2672854	et	4	main
seisasid	doc_527420171752_item	2672855	et	4	main
tõrjumuse	doc_527420171752_item	2672864	et	4	main
üldse	doc_527420171752_item	2672871	et	3	main
aga	doc_527420171752_item	2672880	et	3	main
vanemad	doc_527420171752_item	2672884	et	4	main
mind	doc_527420171752_item	2672885	et	4	main
teleri	doc_527420171752_item	2672886	et	3	main
seda	doc_527420171752_item	2672892	et	3	main
ei	doc_527420171752_item	2672893	et	4	main
näeks	doc_527420171752_item	2672894	et	3	main
aga	doc_527420171752_item	2672895	et	3	main
vanasõna	doc_527420171752_item	2672905	et	4	main
ja	doc_527420171752_item	2672906	et	3	main
nii	doc_527420171752_item	2672907	et	3	main
see	doc_527420171752_item	2672908	et	3	main
oma	doc_527420171752_item	2672913	et	4	main
need	doc_527420171752_item	2672922	et	3	main
sündmused	doc_527420171752_item	2672925	et	3	main
hirmus	doc_527420171752_item	2672929	et	4	main
eesti	doc_527420171753_item	2672935	et	4	main
filmis	doc_527420171753_item	2672937	et	4	main
eesti	doc_527420171753_item	2672938	et	4	main
1991	doc_527420171753_item	2672945	et	2	main
sündmusi	doc_527420171753_item	2672946	et	3	main
hoiti	doc_527420171753_item	2672949	et	3	main
endale	doc_527420171753_item	2672957	et	4	main
seda	doc_527420171753_item	2672960	et	3	main
armeed	doc_527420171753_item	2672978	et	4	main
eesti	doc_527420171753_item	2672981	et	4	main
mis	doc_527420171753_item	2672986	et	4	main
said	doc_527420171753_item	2672992	et	4	main
teada	doc_527420171753_item	2672993	et	3	main
pigemraadiost	doc_527420171753_item	2672996	et	4	main
kaudu	doc_527420171753_item	2673000	et	3	main
mida	doc_527420171753_item	2673004	et	4	main
ei	doc_527420171753_item	2673016	et	4	main
edasi	doc_527420171753_item	2673019	et	3	main
toimusid	doc_527420171752_item	2672729	et	4	main
koledus	doc_527420171752_item	2672741	et	4	main
toimus	doc_527420171752_item	2672742	et	3	main
missugused	doc_527420171752_item	2672743	et	3	main
ohvrid	doc_527420171752_item	2672744	et	3	main
kandsid	doc_527420171752_item	2672745	et	4	main
ja	doc_527420171752_item	2672746	et	3	main
tajusid	doc_527420171752_item	2672748	et	4	main
moskvas	doc_527420171752_item	2672755	et	4	main
proove	doc_527420171752_item	2672770	et	3	main
moskva	doc_527420171752_item	2672773	et	4	main
otstarve	doc_527420171752_item	2672789	et	3	main
juba	doc_527420171752_item	2672793	et	3	main
ammu	doc_527420171752_item	2672794	et	4	main
näha	doc_527420171752_item	2672795	et	3	main
et	doc_527420171752_item	2672796	et	3	main
nsv	doc_527420171752_item	2672797	et	4	main
liit	doc_527420171752_item	2672798	et	3	main
elab	doc_527420171752_item	2672799	et	3	main
oma	doc_527420171752_item	2672800	et	4	main
viimased	doc_527420171752_item	2672801	et	3	main
päevadja	doc_527420171752_item	2672802	et	4	main
teda	doc_527420171752_item	2672803	et	4	main
ei	doc_527420171752_item	2672804	et	4	main
aita	doc_527420171752_item	2672805	et	4	main
punaarmee	doc_527420171752_item	2672806	et	4	main
tulekuga	doc_527420171752_item	2672807	et	3	main
tallinnasse	doc_527420171752_item	2672808	et	3	main
olid	doc_527420171752_item	2672809	et	4	main
katsed	doc_527420171752_item	2672810	et	3	main
hõivata	doc_527420171752_item	2672811	et	4	main
tähtsad	doc_527420171752_item	2672812	et	3	main
hooned	doc_527420171752_item	2672813	et	4	main
selle	doc_527420171752_item	2672814	et	4	main
arves	doc_527420171752_item	2672815	et	4	main
ka	doc_527420171752_item	2672816	et	3	main
teletorni	doc_527420171752_item	2672817	et	4	main
oli	doc_527420171752_item	2672818	et	3	main
valus	doc_527420171752_item	2672819	et	4	main
vaadata	doc_527420171752_item	2672820	et	4	main
kuidas	doc_527420171752_item	2672821	et	3	main
kõike	doc_527420171752_item	2672825	et	4	main
võimalikuga	doc_527420171752_item	2672826	et	3	main
ajal	doc_527420171752_item	2672831	et	4	main
sündmused	doc_527420171752_item	2672833	et	3	main
paremal	doc_527420171752_item	2672834	et	4	main
see	doc_527420171752_item	2672841	et	3	main
väike	doc_527420171752_item	2672874	et	4	main
oli	doc_527420171752_item	2672875	et	3	main
olla	doc_527420171752_item	2672882	et	3	main
lõpeb	doc_527420171752_item	2672900	et	4	main
uni	doc_527420171752_item	2672930	et	3	main
teletorni	doc_527420171753_item	2672939	et	4	main
gorbatshovi	doc_527420171753_item	2672950	et	4	main
ajal	doc_527420171753_item	2672952	et	4	main
püüdsid	doc_527420171752_item	2672824	et	4	main
seda	doc_527420171752_item	2672827	et	3	main
ja	doc_527420171752_item	2672829	et	3	main
ajaloolised	doc_527420171752_item	2672832	et	4	main
viisil	doc_527420171752_item	2672835	et	4	main
lindistada	doc_527420171752_item	2672836	et	3	main
et	doc_527420171752_item	2672837	et	3	main
oligi	doc_527420171752_item	2672842	et	3	main
nii	doc_527420171752_item	2672844	et	3	main
jätkata	doc_527420171752_item	2672858	et	4	main
eest	doc_527420171752_item	2672865	et	4	main
mina	doc_527420171752_item	2672867	et	4	main
ise	doc_527420171752_item	2672868	et	4	main
umbes	doc_527420171752_item	2672876	et	4	main
5	doc_527420171752_item	2672877	et	2	main
aastat	doc_527420171752_item	2672878	et	3	main
juurde	doc_527420171752_item	2672887	et	4	main
ei	doc_527420171752_item	2672888	et	4	main
kõik	doc_527420171752_item	2672896	et	4	main
mis	doc_527420171752_item	2672899	et	4	main
hästi	doc_527420171752_item	2672901	et	3	main
on	doc_527420171752_item	2672902	et	4	main
venelastel	doc_527420171752_item	2672903	et	4	main
niisugune	doc_527420171752_item	2672904	et	3	main
sai	doc_527420171752_item	2672912	et	4	main
eesmärki	doc_527420171752_item	2672917	et	4	main
suurte	doc_527420171752_item	2672919	et	3	main
ohvrideta	doc_527420171752_item	2672920	et	4	main
ja	doc_527420171752_item	2672921	et	3	main
augusti	doc_527420171752_item	2672923	et	3	main
tuleb	doc_527420171752_item	2672926	et	3	main
filmis	doc_527420171753_item	2672942	et	4	main
näidatakse	doc_527420171753_item	2672943	et	3	main
augusti	doc_527420171753_item	2672944	et	3	main
eestis	doc_527420171753_item	2672947	et	3	main
tol	doc_527420171753_item	2672951	et	3	main
maailmast	doc_527420171753_item	2672953	et	4	main
äralõigatuna	doc_527420171753_item	2672954	et	3	main
janajev	doc_527420171753_item	2672955	et	4	main
võtab	doc_527420171753_item	2672956	et	3	main
üle	doc_527420171753_item	2672979	et	3	main
dessantväeosa	doc_527420171753_item	2672985	et	4	main
liikub	doc_527420171753_item	2672987	et	4	main
teadnud	doc_527420171753_item	2673003	et	4	main
vaja	doc_527420171753_item	2673006	et	4	main
sellel	doc_527420171753_item	2673007	et	4	main
juhul	doc_527420171753_item	2673008	et	3	main
teha	doc_527420171753_item	2673009	et	3	main
mis	doc_527420171753_item	2673018	et	4	main
juhtub	doc_527420171753_item	2673020	et	3	main
olin	doc_527420171753_item	2673022	et	3	main
ja	doc_527420171753_item	2673024	et	3	main
öelda	doc_527420171753_item	2673032	et	4	main
usutav	doc_527420171753_item	2673046	et	4	main
filmi	doc_527420171753_item	2673047	et	4	main
peategelasteks	doc_527420171753_item	2673048	et	3	main
nende	doc_527420171753_item	2673054	et	4	main
usku	doc_527420171753_item	2673057	et	4	main
puudumist	doc_527420171753_item	2673059	et	4	main
see	doc_527420171753_item	2673062	et	3	main
oli	doc_527420171753_item	2673063	et	3	main
shanss	doc_527420171753_item	2673064	et	4	main
mida	doc_527420171753_item	2673065	et	4	main
eestlased	doc_527420171753_item	2673066	et	3	main
kuid	doc_527420171753_item	2673079	et	4	main
inimesed	doc_527420171753_item	2673083	et	3	main
sattusid	doc_527420171753_item	2673085	et	4	main
vähem	doc_527420171753_item	2673108	et	4	main
t	doc_527420171753_item	2673113	et	4	main
kogunesid	doc_527420171753_item	2673115	et	4	main
inimesed	doc_527420171753_item	2673116	et	3	main
inimesed	doc_527420171753_item	2673121	et	3	main
teletorni	doc_527420171753_item	2673125	et	4	main
tuli	doc_527420171753_item	2673127	et	4	main
toetada	doc_527420171753_item	2673128	et	3	main
edgar	doc_527420171753_item	2673129	et	4	main
savisaar	doc_527420171753_item	2673130	et	3	main
teletorni	doc_527420171753_item	2673139	et	4	main
piiramisel	doc_527420171753_item	2673140	et	4	main
pole	doc_527420171753_item	2673141	et	3	main
suunatud	doc_527420171753_item	2673151	et	4	main
olnud	doc_527420171753_item	2673164	et	4	main
ükskõiksed	doc_527420171753_item	2673165	et	3	main
kui	doc_527420171753_item	2673167	et	3	main
vene	doc_527420171753_item	2673168	et	4	main
nagu	doc_527420171752_item	2672928	et	3	main
kui	doc_527420171753_item	2672932	et	3	main
kajastuvad	doc_527420171753_item	2672934	et	4	main
taasiseseisvumissündmused	doc_527420171753_item	2672936	et	3	main
volitusedpõhjendades	doc_527420171753_item	2672959	et	4	main
mgorbatshovi	doc_527420171753_item	2672961	et	4	main
tervisliku	doc_527420171753_item	2672962	et	3	main
seisundiga	doc_527420171753_item	2672963	et	3	main
19	doc_527420171753_item	2672964	et	2	main
saab	doc_527420171753_item	2672966	et	3	main
augustil	doc_527420171753_item	2672965	et	3	main
riigipööre	doc_527420171753_item	2672967	et	4	main
teatavaks	doc_527420171753_item	2672969	et	4	main
boriss	doc_527420171753_item	2672970	et	4	main
avalikkusele	doc_527420171753_item	2672968	et	4	main
jeltsin	doc_527420171753_item	2672971	et	4	main
kutsub	doc_527420171753_item	2672972	et	3	main
rahvast	doc_527420171753_item	2672973	et	4	main
riigipöörajatele	doc_527420171753_item	2672974	et	4	main
vastu	doc_527420171753_item	2672975	et	3	main
seisma	doc_527420171753_item	2672976	et	3	main
ning	doc_527420171753_item	2672977	et	3	main
tulema	doc_527420171753_item	2672980	et	4	main
territooriumisse	doc_527420171753_item	2672982	et	3	main
pihkva	doc_527420171753_item	2672984	et	4	main
putshist	doc_527420171753_item	2672994	et	4	main
või	doc_527420171753_item	2672997	et	4	main
inimeste	doc_527420171753_item	2672999	et	3	main
nad	doc_527420171753_item	2673001	et	3	main
mida	doc_527420171753_item	2673010	et	4	main
tea	doc_527420171753_item	2673017	et	4	main
mina	doc_527420171753_item	2673021	et	4	main
saa	doc_527420171753_item	2673031	et	4	main
või	doc_527420171753_item	2673039	et	4	main
on	doc_527420171753_item	2673051	et	4	main
kaotanud	doc_527420171753_item	2673068	et	4	main
augustil	doc_527420171753_item	2673070	et	3	main
eesti	doc_527420171753_item	2673073	et	4	main
vene	doc_527420171753_item	2673075	et	4	main
sõjavägi	doc_527420171753_item	2673076	et	3	main
jäudis	doc_527420171753_item	2673077	et	4	main
augustil	doc_527420171753_item	2673090	et	3	main
dessantnikud	doc_527420171753_item	2673092	et	4	main
filmis	doc_527420171753_item	2673099	et	4	main
dokumentaalkaadrid	doc_527420171753_item	2673100	et	3	main
teletorni	doc_527420171753_item	2673106	et	4	main
kümme	doc_527420171753_item	2673110	et	3	main
tallinna	doc_527420171753_item	2672988	et	4	main
estis	doc_527420171753_item	2672990	et	4	main
inimesed	doc_527420171753_item	2672991	et	3	main
moskvast	doc_527420171753_item	2672995	et	4	main
teiste	doc_527420171753_item	2672998	et	4	main
ei	doc_527420171753_item	2673002	et	4	main
on	doc_527420171753_item	2673005	et	4	main
neljaastaseks	doc_527420171753_item	2673023	et	4	main
neid	doc_527420171753_item	2673025	et	4	main
mäleta	doc_527420171753_item	2673028	et	4	main
ja	doc_527420171753_item	2673029	et	3	main
ei	doc_527420171753_item	2673030	et	4	main
aga	doc_527420171753_item	2673041	et	3	main
on	doc_527420171753_item	2673044	et	4	main
küllaltki	doc_527420171753_item	2673045	et	4	main
paanika	doc_527420171753_item	2673056	et	4	main
taasiseseisvumisse	doc_527420171753_item	2673058	et	3	main
venemaal	doc_527420171753_item	2673061	et	4	main
kinnitas	doc_527420171753_item	2673071	et	3	main
tänavatel	doc_527420171753_item	2673084	et	4	main
paanikasse	doc_527420171753_item	2673086	et	4	main
tankide	doc_527420171753_item	2673087	et	3	main
vallutasid	doc_527420171753_item	2673091	et	4	main
tallinna	doc_527420171753_item	2673093	et	4	main
teletorni	doc_527420171753_item	2673094	et	4	main
aitavad	doc_527420171753_item	2673101	et	4	main
inimest	doc_527420171753_item	2673111	et	3	main
minge	doc_527420171753_item	2673118	et	3	main
mõned	doc_527420171753_item	2673120	et	3	main
soldatidel	doc_527420171753_item	2673123	et	4	main
kukkunud	doc_527420171753_item	2673137	et	4	main
ja	doc_527420171753_item	2673138	et	3	main
tehtud	doc_527420171753_item	2673149	et	4	main
ja	doc_527420171753_item	2673150	et	3	main
nad	doc_527420171753_item	2673155	et	3	main
unustaks	doc_527420171753_item	2673157	et	3	main
ei	doc_527420171753_item	2673163	et	4	main
õigesti	doc_527420171753_item	2673170	et	3	main
kujytada	doc_527420171753_item	2673176	et	4	main
reekviem	doc_52744525860_item	2673421	et	3	main
mis	doc_52744525860_item	2673423	et	4	main
koos	doc_52744525860_item	2673438	et	4	main
elada	doc_52744525860_item	2673439	et	3	main
nelja	doc_52744525860_item	2673449	et	4	main
inimese	doc_52744525860_item	2673450	et	4	main
poeg	doc_52744525860_item	2673461	et	3	main
garri	doc_52744525860_item	2673463	et	4	main
merion	doc_52744525860_item	2673471	et	4	main
tairon	doc_52744525860_item	2673473	et	4	main
hiljuti	doc_52744525860_item	2673474	et	4	main
sellepärast	doc_52744525860_item	2673487	et	3	main
avamisest	doc_52744525860_item	2673498	et	4	main
on	doc_52744525860_item	2673500	et	4	main
armunud	doc_52744525860_item	2673501	et	4	main
merionisse	doc_52744525860_item	2673502	et	4	main
ja	doc_52744525860_item	2673503	et	3	main
ei	doc_527420171753_item	2673027	et	4	main
on	doc_527420171753_item	2673035	et	4	main
nad	doc_527420171753_item	2673036	et	3	main
filmis	doc_527420171753_item	2673037	et	4	main
näidatud	doc_527420171753_item	2673038	et	4	main
see	doc_527420171753_item	2673042	et	3	main
film	doc_527420171753_item	2673043	et	3	main
on	doc_527420171753_item	2673049	et	4	main
tavainimesed	doc_527420171753_item	2673050	et	3	main
hirm	doc_527420171753_item	2673055	et	3	main
sündmused	doc_527420171753_item	2673060	et	3	main
20	doc_527420171753_item	2673069	et	2	main
iseseisvust	doc_527420171753_item	2673074	et	4	main
tallinna	doc_527420171753_item	2673078	et	4	main
milleks	doc_527420171753_item	2673082	et	4	main
21	doc_527420171753_item	2673089	et	2	main
näidatud	doc_527420171753_item	2673098	et	4	main
veel	doc_527420171753_item	2673102	et	4	main
kajastama	doc_527420171753_item	2673104	et	3	main
kui	doc_527420171753_item	2673109	et	3	main
sees	doc_527420171753_item	2673112	et	4	main
juures	doc_527420171753_item	2673114	et	4	main
koju	doc_527420171753_item	2673119	et	3	main
ta	doc_527420171753_item	2673131	et	4	main
teatas	doc_527420171753_item	2673132	et	3	main
et	doc_527420171753_item	2673133	et	3	main
enam	doc_527420171753_item	2673142	et	4	main
mõtet	doc_527420171753_item	2673143	et	3	main
pigem	doc_527420171753_item	2673152	et	3	main
ei	doc_527420171753_item	2673156	et	4	main
oma	doc_527420171753_item	2673158	et	4	main
rahva	doc_527420171753_item	2673159	et	3	main
minevikut	doc_527420171753_item	2673160	et	4	main
et	doc_527420171753_item	2673161	et	3	main
nad	doc_527420171753_item	2673162	et	3	main
inimene	doc_527420171753_item	2673169	et	3	main
kuidas	doc_527420171753_item	2673177	et	3	main
rezhisöör	doc_52744525860_item	2673441	et	4	main
on	doc_52744525860_item	2673454	et	4	main
üksildane	doc_52744525860_item	2673456	et	3	main
tarbivad	doc_52744525860_item	2673478	et	4	main
ole	doc_52744525860_item	2673482	et	4	main
välimust	doc_52744525860_item	2673485	et	4	main
nad	doc_52744525860_item	2673490	et	3	main
rõivakaupluse	doc_52744525860_item	2673497	et	3	main
garri	doc_52744525860_item	2673499	et	4	main
ei	doc_527420171753_item	2673080	et	4	main
teadnus	doc_527420171753_item	2673081	et	4	main
nägedes	doc_527420171753_item	2673088	et	4	main
see	doc_527420171753_item	2673095	et	3	main
on	doc_527420171753_item	2673096	et	4	main
hästi	doc_527420171753_item	2673097	et	3	main
täpsem	doc_527420171753_item	2673103	et	4	main
sündmusi	doc_527420171753_item	2673105	et	3	main
kaitsesid	doc_527420171753_item	2673107	et	4	main
plakatidega	doc_527420171753_item	2673117	et	4	main
süüa	doc_527420171753_item	2673124	et	3	main
kaitsjaid	doc_527420171753_item	2673126	et	4	main
arvates	doc_527420171753_item	2673145	et	4	main
see	doc_527420171753_item	2673146	et	3	main
film	doc_527420171753_item	2673147	et	3	main
on	doc_527420171753_item	2673148	et	4	main
noortele	doc_527420171753_item	2673153	et	3	main
saa	doc_527420171753_item	2673173	et	4	main
räägib	doc_52744525860_item	2673424	et	3	main
narkomaanidest	doc_52744525860_item	2673426	et	3	main
see	doc_52744525860_item	2673427	et	3	main
kirjeldab	doc_52744525860_item	2673428	et	3	main
korralikult	doc_52744525860_item	2673436	et	4	main
narkootikumidega	doc_52744525860_item	2673437	et	3	main
väikesest	doc_52744525860_item	2673447	et	4	main
ajavahemikust	doc_52744525860_item	2673448	et	4	main
need	doc_52744525860_item	2673452	et	3	main
ja	doc_52744525860_item	2673466	et	3	main
sõber	doc_52744525860_item	2673468	et	3	main
nad	doc_52744525860_item	2673480	et	3	main
praegusel	doc_52744525860_item	2673488	et	3	main
midagi	doc_52744525860_item	2673493	et	4	main
oma	doc_52744525860_item	2673496	et	4	main
alguses	doc_52744525860_item	2673508	et	4	main
oska	doc_52744525860_item	2673530	et	4	main
andsid	doc_527420171753_item	2673122	et	4	main
putsh	doc_527420171753_item	2673134	et	4	main
on	doc_527420171753_item	2673135	et	4	main
kokku	doc_527420171753_item	2673136	et	3	main
minu	doc_527420171753_item	2673144	et	3	main
et	doc_527420171753_item	2673154	et	3	main
mina	doc_527420171753_item	2673166	et	4	main
olekseestivenelane	doc_527420171753_item	2673171	et	4	main
ei	doc_527420171753_item	2673172	et	4	main
isegi	doc_527420171753_item	2673174	et	4	main
ette	doc_527420171753_item	2673175	et	4	main
tunnes	doc_527420171753_item	2673178	et	3	main
end	doc_527420171753_item	2673179	et	4	main
kui	doc_527420171753_item	2673181	et	3	main
eestlane	doc_527420171753_item	2673180	et	3	main
eesti	doc_527420171753_item	2673182	et	4	main
sai	doc_527420171753_item	2673183	et	4	main
oma	doc_527420171753_item	2673184	et	4	main
vabadust	doc_527420171753_item	2673185	et	4	main
tagasi	doc_527420171753_item	2673186	et	3	main
aga	doc_527420171753_item	2673187	et	3	main
see	doc_527420171753_item	2673188	et	3	main
film	doc_527420171753_item	2673189	et	3	main
annab	doc_527420171753_item	2673190	et	3	main
patriootilist	doc_527420171753_item	2673191	et	3	main
tunnet	doc_527420171753_item	2673192	et	3	main
suurel	doc_527420171753_item	2673193	et	3	main
määral	doc_527420171753_item	2673194	et	3	main
lauluga	doc_527420171753_item	2673195	et	4	main
eestlaseks	doc_527420171753_item	2673196	et	3	main
olen	doc_527420171753_item	2673197	et	3	main
ja	doc_527420171753_item	2673198	et	3	main
eestlaseks	doc_527420171753_item	2673199	et	3	main
jään	doc_527420171753_item	2673200	et	3	main
ei	doc_52744525860_item	2673433	et	4	main
ole	doc_52744525860_item	2673434	et	4	main
võimalik	doc_52744525860_item	2673435	et	3	main
on	doc_52744525860_item	2673442	et	4	main
darren	doc_52744525860_item	2673443	et	4	main
aronofsky	doc_52744525860_item	2673444	et	4	main
film	doc_52744525860_item	2673445	et	3	main
jutustab	doc_52744525860_item	2673446	et	3	main
elus	doc_52744525860_item	2673451	et	4	main
analüüs	doc_52744525860_item	2673417	et	3	main
ma	doc_52744525860_item	2673418	et	3	main
vaatasin	doc_52744525860_item	2673419	et	3	main
filmi	doc_52744525860_item	2673420	et	4	main
unistusele	doc_52744525860_item	2673422	et	4	main
ameerika	doc_52744525860_item	2673425	et	3	main
nende	doc_52744525860_item	2673429	et	4	main
elu	doc_52744525860_item	2673430	et	4	main
ja	doc_52744525860_item	2673431	et	3	main
kuidas	doc_52744525860_item	2673432	et	3	main
filmi	doc_52744525860_item	2673440	et	4	main
inimesed	doc_52744525860_item	2673453	et	3	main
sara	doc_52744525860_item	2673458	et	4	main
tema	doc_52744525860_item	2673460	et	4	main
garri	doc_52744525860_item	2673462	et	4	main
naine	doc_52744525860_item	2673464	et	3	main
merion	doc_52744525860_item	2673465	et	4	main
garri	doc_52744525860_item	2673470	et	4	main
ise	doc_52744525860_item	2673477	et	4	main
kaotanud	doc_52744525860_item	2673486	et	4	main
unistavad	doc_52744525860_item	2673491	et	4	main
plaanivad	doc_52744525860_item	2673492	et	4	main
merion	doc_52744525860_item	2673494	et	4	main
unistab	doc_52744525860_item	2673495	et	3	main
kangelased	doc_52744525860_item	2673509	et	3	main
aga	doc_52744525860_item	2673512	et	3	main
varsti	doc_52744525860_item	2673513	et	3	main
narkootikumid	doc_52744525860_item	2673514	et	3	main
nende	doc_52744525860_item	2673515	et	4	main
linnas	doc_52744525860_item	2673516	et	4	main
lõppevad	doc_52744525860_item	2673517	et	4	main
ja	doc_52744525860_item	2673518	et	3	main
algab	doc_52744525860_item	2673519	et	3	main
sõda	doc_52744525860_item	2673520	et	4	main
narkootikumide	doc_52744525860_item	2673521	et	3	main
nad	doc_52744525860_item	2673528	et	3	main
unistused	doc_52744525860_item	2673534	et	4	main
unustatud	doc_52744525860_item	2673542	et	4	main
narkootikumide	doc_52744525860_item	2673543	et	3	main
teha	doc_52744525860_item	2673547	et	3	main
samal	doc_52744525860_item	2673549	et	3	main
ema	doc_52744525860_item	2673553	et	4	main
kutsuti	doc_52744525860_item	2673554	et	3	main
kleidis	doc_52744525860_item	2673563	et	3	main
seda	doc_52744525860_item	2673566	et	3	main
selga	doc_52744525860_item	2673567	et	4	main
noor	doc_52744525860_item	2673570	et	3	main
aga	doc_52744525860_item	2673571	et	3	main
selleks	doc_52744525860_item	2673572	et	4	main
andnud	doc_52744525860_item	2673578	et	4	main
läks	doc_52744525860_item	2673582	et	3	main
juurde	doc_52744525860_item	2673584	et	4	main
arst	doc_52744525860_item	2673585	et	3	main
andis	doc_52744525860_item	2673586	et	3	main
talle	doc_52744525860_item	2673587	et	4	main
tablette	doc_52744525860_item	2673588	et	3	main
pärast	doc_52744525860_item	2673593	et	4	main
kardab	doc_52744525860_item	2673597	et	4	main
ei	doc_52744525860_item	2673601	et	4	main
söö	doc_52744525860_item	2673602	et	4	main
ja	doc_52744525860_item	2673603	et	3	main
näeb	doc_52744525860_item	2673604	et	3	main
toas	doc_52744525860_item	2673605	et	3	main
viirastusi	doc_52744525860_item	2673606	et	4	main
lõpp	doc_52744525860_item	2673607	et	3	main
on	doc_52744525860_item	2673614	et	4	main
gangreen	doc_52744525860_item	2673615	et	3	main
tema	doc_52744525860_item	2673628	et	4	main
mustadest	doc_52744525860_item	2673629	et	3	main
orgiatest	doc_52744525860_item	2673630	et	3	main
narkootikumide	doc_52744525860_item	2673631	et	3	main
doosi	doc_52744525860_item	2673632	et	4	main
huvitav	doc_52744525860_item	2673637	et	4	main
filmi	doc_52744525860_item	2673639	et	4	main
montaazh	doc_52744525860_item	2673640	et	4	main
see	doc_52744525860_item	2673641	et	3	main
on	doc_52744525860_item	2673642	et	4	main
hoogne	doc_52744525860_item	2673643	et	3	main
ja	doc_52744525860_item	2673644	et	3	main
terav	doc_52744525860_item	2673645	et	3	main
eakas	doc_52744525860_item	2673455	et	4	main
ema	doc_52744525860_item	2673457	et	4	main
goldfarb	doc_52744525860_item	2673459	et	4	main
garri	doc_52744525860_item	2673467	et	4	main
tairon	doc_52744525860_item	2673469	et	4	main
ja	doc_52744525860_item	2673472	et	3	main
müüvad	doc_52744525860_item	2673475	et	4	main
ja	doc_52744525860_item	2673476	et	3	main
narkootikume	doc_52744525860_item	2673479	et	3	main
ei	doc_52744525860_item	2673481	et	4	main
veel	doc_52744525860_item	2673483	et	4	main
inimeste	doc_52744525860_item	2673484	et	3	main
hetkel	doc_52744525860_item	2673489	et	4	main
koos	doc_52744525860_item	2673506	et	4	main
temaga	doc_52744525860_item	2673507	et	3	main
hästi	doc_52744525860_item	2673511	et	3	main
vahel	doc_52744525860_item	2673523	et	4	main
on	doc_52744525860_item	2673525	et	4	main
lõppenud	doc_52744525860_item	2673526	et	4	main
ei	doc_52744525860_item	2673529	et	4	main
on	doc_52744525860_item	2673540	et	4	main
tema	doc_52744525860_item	2673555	et	4	main
lemmiktelesaatele	doc_52744525860_item	2673556	et	3	main
ta	doc_52744525860_item	2673557	et	4	main
tahab	doc_52744525860_item	2673558	et	3	main
tulla	doc_52744525860_item	2673559	et	3	main
sinna	doc_52744525860_item	2673560	et	3	main
ilusas	doc_52744525860_item	2673561	et	3	main
vaja	doc_52744525860_item	2673574	et	4	main
ei	doc_52744525860_item	2673577	et	4	main
sara	doc_52744525860_item	2673581	et	4	main
pärast	doc_52744525860_item	2673592	et	4	main
sara	doc_52744525860_item	2673596	et	4	main
külmkappi	doc_52744525860_item	2673599	et	4	main
tahab	doc_52744525860_item	2673504	et	3	main
olla	doc_52744525860_item	2673505	et	3	main
elavad	doc_52744525860_item	2673510	et	4	main
müüjate	doc_52744525860_item	2673522	et	4	main
noortel	doc_52744525860_item	2673524	et	3	main
armastus	doc_52744525860_item	2673539	et	4	main
nad	doc_52744525860_item	2673545	et	3	main
on	doc_52744525860_item	2673573	et	4	main
ja	doc_52744525860_item	2673580	et	3	main
arsti	doc_52744525860_item	2673583	et	4	main
amfetamiini	doc_52744525860_item	2673591	et	4	main
võtmist	doc_52744525860_item	2673595	et	4	main
on	doc_52744525860_item	2673608	et	4	main
hullumeelseks	doc_52744525860_item	2673636	et	3	main
tunmedad	doc_52744525860_item	2673650	et	4	main
pop-art-i	doc_52744525860_item	2673656	et	4	main
on	doc_52744525860_item	2673659	et	4	main
ja	doc_52744525860_item	2673661	et	3	main
tehtud	doc_52744525861_item	2673720	et	4	main
ka	doc_52744525861_item	2673721	et	3	main
noored	doc_52744525861_item	2673724	et	3	main
see	doc_52744525861_item	2673729	et	3	main
iga	doc_52744525861_item	2673732	et	4	main
aadress	doc_52744525861_item	2673741	et	3	main
httpwwwmolesee	doc_52744525861_item	2673744	et	4	main
kirjutatud	doc_52744525861_item	2673748	et	4	main
kui	doc_52744525861_item	2673749	et	3	main
palju	doc_52744525861_item	2673750	et	4	main
maksab	doc_52744525861_item	2673751	et	3	main
peatoimetaja	doc_52744525861_item	2673754	et	4	main
see	doc_52744525861_item	2673762	et	3	main
neid	doc_52744525862_item	2673804	et	4	main
populaarsem	doc_52744525862_item	2673814	et	4	main
raha	doc_52744525860_item	2673527	et	4	main
elada	doc_52744525860_item	2673531	et	3	main
ära	doc_52744525860_item	2673541	et	4	main
võivad	doc_52744525860_item	2673546	et	4	main
garri	doc_52744525860_item	2673552	et	4	main
punases	doc_52744525860_item	2673562	et	4	main
kui	doc_52744525860_item	2673568	et	3	main
oli	doc_52744525860_item	2673569	et	3	main
tulemusi	doc_52744525860_item	2673579	et	4	main
sisaldavad	doc_52744525860_item	2673590	et	4	main
oma	doc_52744525860_item	2673598	et	4	main
üldse	doc_52744525860_item	2673600	et	3	main
ja	doc_52744525860_item	2673616	et	3	main
arstid	doc_52744525860_item	2673617	et	4	main
amputeerivad	doc_52744525860_item	2673618	et	4	main
tema	doc_52744525860_item	2673619	et	4	main
kätt	doc_52744525860_item	2673620	et	3	main
võtab	doc_52744525860_item	2673626	et	3	main
eest	doc_52744525860_item	2673633	et	4	main
hämarad	doc_52744525860_item	2673651	et	3	main
et	doc_52744525860_item	2673670	et	3	main
ja	doc_52744525861_item	2673708	et	3	main
eesti	doc_52744525861_item	2673723	et	4	main
sain	doc_52744525861_item	2673726	et	3	main
teada	doc_52744525861_item	2673727	et	3	main
ajaleht	doc_52744525861_item	2673730	et	3	main
ilmub	doc_52744525861_item	2673731	et	3	main
päev	doc_52744525861_item	2673733	et	3	main
ja	doc_52744525861_item	2673734	et	3	main
selle	doc_52744525861_item	2673735	et	4	main
on	doc_52744525861_item	2673737	et	4	main
seal	doc_52744525861_item	2673745	et	4	main
ilja	doc_52744525861_item	2673756	et	4	main
nurgas	doc_52744525861_item	2673759	et	3	main
on	doc_52744525861_item	2673760	et	4	main
vene	doc_52744525861_item	2673766	et	4	main
2	doc_52744525862_item	2673797	et	2	main
tüdrukut	doc_52744525862_item	2673798	et	3	main
ja	doc_52744525862_item	2673799	et	3	main
poissi	doc_52744525862_item	2673801	et	4	main
kõige	doc_52744525862_item	2673813	et	4	main
selleks	doc_52744525862_item	2673818	et	4	main
võib	doc_52744525862_item	2673819	et	3	main
kulutada	doc_52744525862_item	2673820	et	3	main
kuud	doc_52744525862_item	2673824	et	4	main
võimalustest	doc_52744525862_item	2673827	et	3	main
soovidest	doc_52744525862_item	2673829	et	3	main
perekonnaga	doc_52744525862_item	2673852	et	4	main
sõpradega	doc_52744525862_item	2673854	et	3	main
aga	doc_52744525862_item	2673866	et	3	main
ilma	doc_52744525860_item	2673532	et	4	main
narkootikumideta	doc_52744525860_item	2673533	et	3	main
kauplusest	doc_52744525860_item	2673535	et	4	main
suur	doc_52744525860_item	2673536	et	3	main
ja	doc_52744525860_item	2673537	et	3	main
puhas	doc_52744525860_item	2673538	et	3	main
eest	doc_52744525860_item	2673544	et	4	main
kõike	doc_52744525860_item	2673548	et	4	main
ajal	doc_52744525860_item	2673550	et	4	main
sarat	doc_52744525860_item	2673551	et	4	main
ta	doc_52744525860_item	2673564	et	4	main
pani	doc_52744525860_item	2673565	et	4	main
kõhnuda	doc_52744525860_item	2673575	et	3	main
dieet	doc_52744525860_item	2673576	et	3	main
mis	doc_52744525860_item	2673589	et	4	main
tablett	doc_52744525860_item	2673594	et	3	main
hirmus	doc_52744525860_item	2673609	et	4	main
garri	doc_52744525860_item	2673610	et	4	main
jääb	doc_52744525860_item	2673611	et	3	main
haigeks	doc_52744525860_item	2673612	et	4	main
tal	doc_52744525860_item	2673613	et	3	main
merion	doc_52744525860_item	2673621	et	4	main
maffiamehega	doc_52744525860_item	2673623	et	3	main
kokku	doc_52744525860_item	2673624	et	3	main
sara	doc_52744525860_item	2673634	et	4	main
on	doc_52744525860_item	2673638	et	4	main
aga	doc_52744525860_item	2673652	et	3	main
eredad	doc_52744525860_item	2673655	et	3	main
see	doc_52744525860_item	2673658	et	3	main
väga	doc_52744525860_item	2673662	et	3	main
aus	doc_52744525860_item	2673663	et	4	main
film	doc_52744525860_item	2673664	et	3	main
seda	doc_52744525860_item	2673665	et	3	main
peab	doc_52744525860_item	2673666	et	4	main
vaatama	doc_52744525860_item	2673667	et	3	main
saada	doc_52744525860_item	2673672	et	4	main
loeb	doc_52744525861_item	2673709	et	3	main
pool	doc_52744525861_item	2673714	et	4	main
lepib	doc_52744525860_item	2673622	et	3	main
ja	doc_52744525860_item	2673625	et	3	main
osa	doc_52744525860_item	2673627	et	4	main
saab	doc_52744525860_item	2673635	et	3	main
värvid	doc_52744525860_item	2673648	et	4	main
on	doc_52744525860_item	2673649	et	4	main
momentidel	doc_52744525860_item	2673654	et	3	main
stiilis	doc_52744525860_item	2673657	et	4	main
iga	doc_52744525860_item	2673668	et	4	main
aru	doc_52744525860_item	2673671	et	4	main
missugune	doc_52744525860_item	2673673	et	3	main
kujus	doc_52744525860_item	2673674	et	3	main
on	doc_52744525860_item	2673675	et	4	main
narkootikumid	doc_52744525860_item	2673676	et	3	main
kirjeldus	doc_52744525861_item	2673677	et	4	main
ma	doc_52744525861_item	2673678	et	3	main
nägin	doc_52744525861_item	2673679	et	3	main
üht	doc_52744525861_item	2673680	et	3	main
huvitavat	doc_52744525861_item	2673681	et	4	main
reklaami	doc_52744525861_item	2673682	et	4	main
internetis	doc_52744525861_item	2673683	et	4	main
reklaam	doc_52744525861_item	2673684	et	3	main
on	doc_52744525861_item	2673685	et	4	main
pühendatud	doc_52744525861_item	2673686	et	4	main
ajalehele	doc_52744525861_item	2673687	et	3	main
noored	doc_52744525861_item	2673689	et	3	main
eesti	doc_52744525861_item	2673688	et	4	main
pool	doc_52744525861_item	2673691	et	4	main
üleval	doc_52744525861_item	2673690	et	4	main
suurte	doc_52744525861_item	2673692	et	3	main
trükitähtedega	doc_52744525861_item	2673693	et	4	main
on	doc_52744525861_item	2673694	et	4	main
kirjutatud	doc_52744525861_item	2673695	et	4	main
lugemine	doc_52744525861_item	2673696	et	4	main
on	doc_52744525861_item	2673697	et	4	main
valgus	doc_52744525861_item	2673698	et	4	main
selle	doc_52744525861_item	2673699	et	4	main
nagu	doc_52744525860_item	2673646	et	3	main
klippides	doc_52744525860_item	2673647	et	3	main
mõnedel	doc_52744525860_item	2673653	et	3	main
raske	doc_52744525860_item	2673660	et	4	main
inimene	doc_52744525860_item	2673669	et	3	main
kes	doc_52744525861_item	2673705	et	4	main
lamab	doc_52744525861_item	2673706	et	3	main
põrandas	doc_52744525861_item	2673707	et	3	main
eesti	doc_52744525861_item	2673711	et	4	main
paaremal	doc_52744525861_item	2673713	et	3	main
on	doc_52744525861_item	2673715	et	4	main
lamp	doc_52744525861_item	2673716	et	3	main
mille	doc_52744525861_item	2673717	et	3	main
abazhuur	doc_52744525861_item	2673718	et	4	main
tiraazh	doc_52744525861_item	2673736	et	4	main
7000	doc_52744525861_item	2673738	et	2	main
eksempläri	doc_52744525861_item	2673739	et	4	main
on	doc_52744525861_item	2673743	et	4	main
nikiforov	doc_52744525861_item	2673757	et	4	main
infotelefonid	doc_52744525861_item	2673761	et	3	main
huvitada	doc_52744525861_item	2673765	et	3	main
just	doc_52744525862_item	2673803	et	3	main
sest	doc_52744525862_item	2673806	et	4	main
istusid	doc_52744525862_item	2673808	et	4	main
minu	doc_52744525862_item	2673809	et	3	main
kõrval	doc_52744525862_item	2673810	et	4	main
minu	doc_52744525862_item	2673811	et	3	main
arvates	doc_52744525862_item	2673812	et	4	main
reisimine	doc_52744525862_item	2673817	et	4	main
reisimisega	doc_52744525862_item	2673830	et	4	main
on	doc_52744525862_item	2673841	et	4	main
vaheaeg	doc_52744525862_item	2673847	et	3	main
aega	doc_52744525862_item	2673851	et	4	main
sõpradega	doc_52744525862_item	2673855	et	3	main
ole	doc_52744525862_item	2673857	et	4	main
igav	doc_52744525862_item	2673859	et	3	main
võib	doc_52744525862_item	2673861	et	3	main
on	doc_52744525862_item	2673868	et	4	main
lähedased	doc_52744525862_item	2673871	et	3	main
kõige	doc_532115409053_item	2674020	et	4	main
tähtsama	doc_532115409053_item	2674021	et	4	main
elus	doc_532115409053_item	2674024	et	4	main
aitasid	doc_532115409053_item	2674038	et	4	main
ja	doc_532115409053_item	2674048	et	3	main
leiutisi	doc_532115409053_item	2674052	et	3	main
väga	doc_532115409053_item	2674060	et	3	main
palju	doc_532115409053_item	2674061	et	4	main
arvuti	doc_532115409053_item	2674062	et	4	main
lihtsam	doc_532115409053_item	2674065	et	4	main
koduseid	doc_532115409053_item	2674067	et	4	main
ülessandeid	doc_532115409053_item	2674068	et	4	main
arvutis	doc_532115409053_item	2674076	et	4	main
rakendada	doc_532115409053_item	2674101	et	3	main
keeli	doc_532115409053_item	2674103	et	4	main
mängida	doc_532115409053_item	2674126	et	3	main
ma	doc_532115409053_item	2674139	et	3	main
oska	doc_532115409053_item	2674152	et	4	main
elaksin	doc_532115409053_item	2674156	et	3	main
on	doc_532115409053_item	2674165	et	4	main
ja	doc_532115409053_item	2674167	et	3	main
kui	doc_532115409053_item	2674168	et	3	main
kasulikuks	doc_532115409053_item	2674169	et	3	main
targemaks	doc_532115409053_item	2674177	et	4	main
ma	doc_532115409054_item	2674221	et	3	main
huvitama	doc_532115409054_item	2674224	et	3	main
ma	doc_532115409054_item	2674235	et	3	main
teadsin	doc_532115409054_item	2674236	et	3	main
juba	doc_532115409054_item	2674237	et	3	main
pealkirja	doc_52744525861_item	2673700	et	4	main
all	doc_52744525861_item	2673701	et	3	main
on	doc_52744525861_item	2673702	et	4	main
kujutatud	doc_52744525861_item	2673703	et	4	main
naine	doc_52744525861_item	2673704	et	3	main
ajalehte	doc_52744525861_item	2673710	et	4	main
noored	doc_52744525861_item	2673712	et	3	main
on	doc_52744525861_item	2673719	et	4	main
ajalehest	doc_52744525861_item	2673722	et	4	main
ma	doc_52744525861_item	2673725	et	3	main
et	doc_52744525861_item	2673728	et	3	main
ajalehe	doc_52744525861_item	2673740	et	3	main
ajalehe	doc_52744525861_item	2673752	et	3	main
reklaami	doc_52744525861_item	2673758	et	4	main
inimesi	doc_52744525861_item	2673767	et	4	main
eestis	doc_52744525861_item	2673768	et	3	main
4	doc_52744525862_item	2673795	et	2	main
inimest	doc_52744525862_item	2673796	et	3	main
2	doc_52744525862_item	2673800	et	2	main
küsitlesin	doc_52744525862_item	2673802	et	3	main
nad	doc_52744525862_item	2673807	et	3	main
on	doc_52744525862_item	2673816	et	4	main
suvel	doc_52744525862_item	2673833	et	3	main
on	doc_52744525862_item	2673835	et	4	main
hea	doc_52744525862_item	2673836	et	4	main
puhkus	doc_52744525862_item	2673844	et	3	main
või	doc_52744525862_item	2673845	et	4	main
veedavad	doc_52744525862_item	2673849	et	3	main
suhelda	doc_52744525862_item	2673865	et	4	main
perekonnaliikmed	doc_52744525862_item	2673867	et	3	main
saaks	doc_532115409053_item	2674018	et	3	main
ilma	doc_532115409053_item	2674043	et	4	main
palju	doc_532115409053_item	2674051	et	4	main
oli	doc_532115409053_item	2674053	et	3	main
abil	doc_532115409053_item	2674055	et	4	main
leiutatud	doc_532115409053_item	2674056	et	4	main
kõige	doc_532115409053_item	2674073	et	4	main
on	doc_532115409053_item	2674077	et	4	main
leida	doc_532115409053_item	2674081	et	3	main
huvi	doc_532115409053_item	2674088	et	4	main
pakkuvad	doc_532115409053_item	2674089	et	4	main
ka	doc_532115409053_item	2674090	et	3	main
interneti	doc_532115409053_item	2674091	et	4	main
kaudu	doc_532115409053_item	2674092	et	3	main
võib	doc_532115409053_item	2674093	et	3	main
leida	doc_532115409053_item	2674094	et	3	main
endale	doc_532115409053_item	2674095	et	4	main
välismaalt	doc_532115409053_item	2674099	et	3	main
mulle	doc_532115409053_item	2674109	et	4	main
vaba	doc_532115409053_item	2674119	et	4	main
ma	doc_532115409053_item	2674124	et	3	main
on	doc_532115409053_item	2674133	et	4	main
olen	doc_532115409053_item	2674140	et	3	main
peal	doc_532115409053_item	2674142	et	4	main
väga	doc_532115409053_item	2674143	et	3	main
kaua	doc_532115409053_item	2674144	et	3	main
harjutanud	doc_532115409053_item	2674145	et	4	main
enam	doc_532115409053_item	2674150	et	4	main
ei	doc_532115409053_item	2674151	et	4	main
sellel	doc_532115409053_item	2674160	et	4	main
kuidas	doc_532115409053_item	2674163	et	3	main
arvutid	doc_532115409053_item	2674173	et	4	main
saavad	doc_532115409053_item	2674176	et	4	main
on	doc_532115409054_item	2674213	et	4	main
mis	doc_532115409054_item	2674218	et	4	main
seotud	doc_532115409054_item	2674219	et	4	main
internetis	doc_52744525861_item	2673742	et	4	main
on	doc_52744525861_item	2673746	et	4	main
ka	doc_52744525861_item	2673747	et	3	main
tellimine	doc_52744525861_item	2673753	et	4	main
on	doc_52744525861_item	2673755	et	4	main
reklaam	doc_52744525861_item	2673763	et	3	main
võib	doc_52744525861_item	2673764	et	3	main
kes	doc_52744525861_item	2673769	et	4	main
tahavad	doc_52744525861_item	2673770	et	3	main
teada	doc_52744525861_item	2673771	et	3	main
viimastest	doc_52744525861_item	2673772	et	3	main
uudistest	doc_52744525861_item	2673773	et	4	main
mind	doc_52744525861_item	2673774	et	4	main
huvitas	doc_52744525861_item	2673775	et	3	main
ainult	doc_52744525861_item	2673776	et	4	main
reklaami	doc_52744525861_item	2673777	et	4	main
kena	doc_52744525861_item	2673778	et	4	main
pilt	doc_52744525861_item	2673779	et	3	main
ja	doc_52744525861_item	2673780	et	3	main
disain	doc_52744525861_item	2673781	et	3	main
kirjeldus	doc_52744525862_item	2673782	et	4	main
kokkuvõtte	doc_52744525862_item	2673783	et	4	main
küsitluse	doc_52744525862_item	2673784	et	4	main
tema	doc_52744525862_item	2673785	et	4	main
oli	doc_52744525862_item	2673786	et	3	main
millega	doc_52744525862_item	2673787	et	3	main
meeldib	doc_52744525862_item	2673788	et	3	main
tegeleda	doc_52744525862_item	2673789	et	3	main
meie	doc_52744525862_item	2673790	et	4	main
klassi	doc_52744525862_item	2673791	et	4	main
õpilastele	doc_52744525862_item	2673792	et	4	main
ma	doc_52744525862_item	2673793	et	3	main
intervjueerisin	doc_52744525862_item	2673794	et	3	main
õpilasi	doc_52744525862_item	2673805	et	3	main
tegevusala	doc_52744525862_item	2673815	et	4	main
mitu	doc_52744525862_item	2673821	et	4	main
nädalat	doc_52744525862_item	2673823	et	3	main
tegeldakse	doc_52744525862_item	2673831	et	3	main
rohkem	doc_52744525862_item	2673832	et	4	main
sest	doc_52744525862_item	2673834	et	4	main
paljudel	doc_52744525862_item	2673840	et	3	main
sellel	doc_52744525862_item	2673842	et	4	main
ajal	doc_52744525862_item	2673843	et	4	main
klassikaaslased	doc_52744525862_item	2673848	et	3	main
kunagi	doc_52744525862_item	2673858	et	3	main
lihtsalt	doc_52744525862_item	2673862	et	4	main
ja	doc_52744525862_item	2673863	et	3	main
mõnusalt	doc_52744525862_item	2673864	et	4	main
kallid	doc_52744525862_item	2673869	et	3	main
päeva	doc_52744525862_item	2673822	et	4	main
see	doc_52744525862_item	2673825	et	3	main
sõltub	doc_52744525862_item	2673826	et	3	main
ja	doc_52744525862_item	2673828	et	3	main
päikesepaisteline	doc_52744525862_item	2673837	et	4	main
ilm	doc_52744525862_item	2673838	et	3	main
ja	doc_52744525862_item	2673839	et	3	main
kooli	doc_52744525862_item	2673846	et	4	main
oma	doc_52744525862_item	2673850	et	4	main
ja	doc_52744525862_item	2673853	et	3	main
ei	doc_52744525862_item	2673856	et	4	main
ja	doc_52744525862_item	2673860	et	3	main
ja	doc_52744525862_item	2673870	et	3	main
inimesed	doc_52744525862_item	2673872	et	3	main
reisimine	doc_52744525862_item	2673873	et	4	main
annab	doc_52744525862_item	2673874	et	3	main
uusi	doc_52744525862_item	2673875	et	3	main
muljeid	doc_52744525862_item	2673876	et	3	main
tutvumisi	doc_52744525862_item	2673877	et	4	main
inimene	doc_52744525862_item	2673878	et	3	main
saab	doc_52744525862_item	2673879	et	3	main
iseseisvamaks	doc_52744525862_item	2673880	et	4	main
ja	doc_52744525862_item	2673882	et	3	main
tugevamaks	doc_52744525862_item	2673881	et	4	main
võib	doc_52744525862_item	2673883	et	3	main
praktiseerida	doc_52744525862_item	2673884	et	3	main
oma	doc_52744525862_item	2673885	et	4	main
võõrkeleoskust	doc_52744525862_item	2673886	et	4	main
ma	doc_532115409053_item	2674025	et	3	main
arvutit	doc_532115409053_item	2674027	et	3	main
arvutit	doc_532115409053_item	2674029	et	3	main
inimesi	doc_532115409053_item	2674039	et	4	main
väga	doc_532115409053_item	2674050	et	3	main
arvuti	doc_532115409053_item	2674054	et	4	main
arvuti	doc_532115409053_item	2674058	et	4	main
peal	doc_532115409053_item	2674063	et	4	main
teha	doc_532115409053_item	2674066	et	3	main
kirjutada	doc_532115409053_item	2674069	et	3	main
referaate	doc_532115409053_item	2674070	et	3	main
ja	doc_532115409053_item	2674071	et	3	main
muidugi	doc_532115409053_item	2674072	et	4	main
mulle	doc_532115409053_item	2674087	et	4	main
väga	doc_532115409053_item	2674096	et	3	main
oma	doc_532115409053_item	2674102	et	4	main
oskusi	doc_532115409053_item	2674104	et	3	main
abi	doc_532115409053_item	2674112	et	4	main
töö	doc_532115409053_item	2674113	et	4	main
ja	doc_532115409053_item	2674114	et	3	main
hariduse	doc_532115409053_item	2674115	et	3	main
suhtes	doc_532115409053_item	2674116	et	4	main
aga	doc_532115409053_item	2674117	et	3	main
ka	doc_532115409053_item	2674118	et	3	main
vabal	doc_532115409053_item	2674122	et	3	main
või	doc_532115409053_item	2674128	et	4	main
internetis	doc_532115409053_item	2674131	et	4	main
mulle	doc_532115409053_item	2674132	et	4	main
minuarust	doc_532115409053_item	2674135	et	4	main
ja	doc_532115409053_item	2674138	et	3	main
igaüks	doc_532115409053_item	2674159	et	3	main
igal	doc_532115409053_item	2674174	et	3	main
päeval	doc_532115409053_item	2674175	et	3	main
kes	doc_532115409053_item	2674179	et	4	main
teab	doc_532115409053_item	2674180	et	3	main
mulle	doc_532115409054_item	2674215	et	4	main
meeldib	doc_532115409054_item	2674216	et	3	main
kõik	doc_532115409054_item	2674217	et	4	main
hakkasin	doc_532115409054_item	2674222	et	3	main
kui	doc_532115409054_item	2674226	et	3	main
nagu	doc_532115409054_item	2674243	et	3	main
opel	doc_532115409054_item	2674248	et	4	main
huvitanud	doc_532115409054_item	2674260	et	4	main
ma	doc_532115409054_item	2674264	et	3	main
vana	doc_532115409054_item	2674268	et	4	main
unistus	doc_532115409054_item	2674279	et	4	main
saada	doc_532115409054_item	2674280	et	4	main
vormel	doc_532115409054_item	2674281	et	4	main
kui	doc_532115409054_item	2674284	et	3	main
nissan	doc_532115409054_item	2674301	et	4	main
primera	doc_532115409054_item	2674302	et	4	main
ole	doc_532115409054_item	2674332	et	4	main
aga	doc_532115409054_item	2674334	et	3	main
ma	doc_532115409054_item	2674335	et	3	main
autod	doc_532115409054_item	2674338	et	3	main
saa	doc_532115409055_item	2674352	et	4	main
maailmas	doc_532115409055_item	2674356	et	3	main
väga	doc_532115409055_item	2674358	et	3	main
imetleda	doc_532115409055_item	2674365	et	3	main
kuidas	doc_532115409055_item	2674366	et	3	main
me	doc_532115409055_item	2674367	et	4	main
leiutised	doc_532115409053_item	2674013	et	3	main
ilma	doc_532115409053_item	2674014	et	4	main
milleta	doc_532115409053_item	2674015	et	3	main
ma	doc_532115409053_item	2674016	et	3	main
ei	doc_532115409053_item	2674017	et	4	main
elada	doc_532115409053_item	2674019	et	3	main
leiutisena	doc_532115409053_item	2674022	et	3	main
pean	doc_532115409053_item	2674026	et	4	main
ilma	doc_532115409053_item	2674028	et	4	main
maailm	doc_532115409053_item	2674031	et	3	main
oleks	doc_532115409053_item	2674032	et	3	main
teissugune	doc_532115409053_item	2674033	et	3	main
selle	doc_532115409053_item	2674040	et	4	main
päevani	doc_532115409053_item	2674041	et	3	main
ja	doc_532115409053_item	2674042	et	3	main
pakkub	doc_532115409053_item	2674059	et	4	main
on	doc_532115409053_item	2674064	et	4	main
asi	doc_532115409053_item	2674075	et	4	main
internet	doc_532115409053_item	2674078	et	4	main
väga	doc_532115409053_item	2674082	et	3	main
informatsiooni	doc_532115409053_item	2674084	et	4	main
mis	doc_532115409053_item	2674086	et	4	main
sõpru	doc_532115409053_item	2674098	et	3	main
mitte	doc_532115409053_item	2674110	et	3	main
ainult	doc_532115409053_item	2674111	et	4	main
aja	doc_532115409053_item	2674120	et	4	main
minu	doc_532115409053_item	2674023	et	3	main
tänapäevane	doc_532115409053_item	2674030	et	4	main
kõik	doc_532115409053_item	2674034	et	4	main
teavad	doc_532115409053_item	2674035	et	3	main
et	doc_532115409053_item	2674036	et	3	main
arvutid	doc_532115409053_item	2674037	et	4	main
nendeta	doc_532115409053_item	2674044	et	4	main
oleks	doc_532115409053_item	2674045	et	3	main
ebamugav	doc_532115409053_item	2674046	et	3	main
projekteerida	doc_532115409053_item	2674047	et	3	main
leiutada	doc_532115409053_item	2674049	et	3	main
mulle	doc_532115409053_item	2674057	et	4	main
kasulikum	doc_532115409053_item	2674074	et	4	main
internetist	doc_532115409053_item	2674079	et	4	main
võib	doc_532115409053_item	2674080	et	3	main
palju	doc_532115409053_item	2674083	et	4	main
asjadest	doc_532115409053_item	2674085	et	3	main
palju	doc_532115409053_item	2674097	et	4	main
et	doc_532115409053_item	2674100	et	3	main
präegusel	doc_532115409053_item	2674105	et	4	main
ajal	doc_532115409053_item	2674106	et	4	main
arvuti	doc_532115409053_item	2674107	et	4	main
pakub	doc_532115409053_item	2674108	et	3	main
veetmises	doc_532115409053_item	2674121	et	4	main
ajal	doc_532115409053_item	2674123	et	4	main
niisama	doc_532115409053_item	2674129	et	3	main
surfata	doc_532115409053_item	2674130	et	4	main
arvuti	doc_532115409053_item	2674134	et	4	main
mina	doc_532115409053_item	2674149	et	4	main
öelda	doc_532115409053_item	2674153	et	4	main
maakeral	doc_532115409053_item	2674161	et	3	main
teab	doc_532115409053_item	2674162	et	3	main
kasulik	doc_532115409053_item	2674164	et	3	main
arvuti	doc_532115409053_item	2674166	et	4	main
ta	doc_532115409053_item	2674170	et	4	main
võiks	doc_532115409053_item	2674171	et	4	main
olla	doc_532115409053_item	2674172	et	3	main
ja	doc_532115409053_item	2674178	et	3	main
mida	doc_532115409053_item	2674181	et	4	main
autodega	doc_532115409054_item	2674223	et	3	main
juba	doc_532115409054_item	2674225	et	3	main
seitse	doc_532115409054_item	2674229	et	3	main
vana	doc_532115409054_item	2674231	et	4	main
vanemad	doc_532115409054_item	2674253	et	4	main
ei	doc_532115409054_item	2674254	et	4	main
ma	doc_532115409054_item	2674258	et	3	main
olin	doc_532115409054_item	2674265	et	3	main
oli	doc_532115409054_item	2674278	et	3	main
ühe	doc_532115409054_item	2674282	et	4	main
olin	doc_532115409054_item	2674286	et	3	main
mulle	doc_532115409054_item	2674297	et	4	main
suur	doc_532115409054_item	2674322	et	3	main
vigu	doc_532115409054_item	2674323	et	3	main
ei	doc_532115409054_item	2674331	et	4	main
auto	doc_532115409054_item	2674333	et	4	main
võtan	doc_532115409054_item	2674336	et	3	main
autorendist	doc_532115409054_item	2674339	et	4	main
võib-olla	doc_532115409054_item	2674340	et	3	main
ma	doc_532115409054_item	2674341	et	3	main
ei	doc_532115409054_item	2674342	et	4	main
ilma	doc_532115409054_item	2674345	et	4	main
autorendist	doc_532115409054_item	2674346	et	4	main
ma	doc_532115409055_item	2674350	et	3	main
ei	doc_532115409055_item	2674371	et	4	main
oleks	doc_532115409055_item	2674372	et	3	main
mõned	doc_532115409055_item	2674373	et	3	main
leiutised	doc_532115409055_item	2674374	et	3	main
on	doc_532115409055_item	2674375	et	4	main
tähtsad	doc_532115409055_item	2674379	et	3	main
gaas	doc_532115409055_item	2674382	et	3	main
ole	doc_532115409055_item	2674421	et	4	main
nendest	doc_532115409055_item	2674423	et	4	main
ajalehti	doc_532115409055_item	2674434	et	4	main
sealt	doc_532115409055_item	2674447	et	4	main
leian	doc_532115409055_item	2674448	et	3	main
infot	doc_532115409055_item	2674449	et	3	main
ei	doc_532115409055_item	2674452	et	4	main
vaja	doc_532115409055_item	2674454	et	4	main
mulle	doc_532115409055_item	2674455	et	4	main
arvuti	doc_532115409055_item	2674461	et	4	main
abil	doc_532115409055_item	2674462	et	4	main
kasutan	doc_532115409055_item	2674463	et	3	main
võin	doc_532115409053_item	2674125	et	3	main
arvutimänge	doc_532115409053_item	2674127	et	3	main
väga	doc_532115409053_item	2674136	et	3	main
kasulikk	doc_532115409053_item	2674137	et	4	main
selle	doc_532115409053_item	2674141	et	4	main
tööd	doc_532115409053_item	2674146	et	4	main
teha	doc_532115409053_item	2674147	et	3	main
et	doc_532115409053_item	2674148	et	3	main
kuidas	doc_532115409053_item	2674154	et	3	main
ma	doc_532115409053_item	2674155	et	3	main
ilma	doc_532115409053_item	2674157	et	4	main
arvutita	doc_532115409053_item	2674158	et	4	main
veel	doc_532115409053_item	2674182	et	4	main
huvitavat	doc_532115409053_item	2674183	et	4	main
võiks	doc_532115409053_item	2674184	et	4	main
arvuti	doc_532115409053_item	2674185	et	4	main
näiteks	doc_532115409053_item	2674186	et	4	main
homme	doc_532115409053_item	2674187	et	3	main
inimkondale	doc_532115409053_item	2674188	et	4	main
pakkuda	doc_532115409053_item	2674189	et	3	main
p	doc_532115409053_item	2674190	et	4	main
essee	doc_532115409054_item	2674191	et	4	main
leiutis	doc_532115409054_item	2674192	et	3	main
ilma	doc_532115409054_item	2674193	et	4	main
milleta	doc_532115409054_item	2674194	et	3	main
ma	doc_532115409054_item	2674195	et	3	main
ei	doc_532115409054_item	2674196	et	4	main
saaks	doc_532115409054_item	2674197	et	3	main
elada	doc_532115409054_item	2674198	et	3	main
see	doc_532115409054_item	2674199	et	3	main
ei	doc_532115409054_item	2674200	et	4	main
ole	doc_532115409054_item	2674201	et	4	main
raske	doc_532115409054_item	2674202	et	4	main
küsimus	doc_532115409054_item	2674203	et	4	main
mulle	doc_532115409054_item	2674204	et	4	main
ja	doc_532115409054_item	2674205	et	3	main
ma	doc_532115409054_item	2674206	et	3	main
võin	doc_532115409054_item	2674207	et	3	main
vastata	doc_532115409054_item	2674208	et	4	main
selles	doc_532115409054_item	2674209	et	4	main
ilma	doc_532115409054_item	2674210	et	4	main
mõtlemist	doc_532115409054_item	2674211	et	4	main
see	doc_532115409054_item	2674212	et	3	main
auto	doc_532115409054_item	2674214	et	4	main
ma	doc_532115409054_item	2674227	et	3	main
aastat	doc_532115409054_item	2674230	et	3	main
sel	doc_532115409054_item	2674233	et	3	main
bmw	doc_532115409054_item	2674244	et	4	main
saanud	doc_532115409054_item	2674255	et	4	main
aru	doc_532115409054_item	2674256	et	4	main
autodega	doc_532115409054_item	2674261	et	3	main
mul	doc_532115409054_item	2674277	et	3	main
sain	doc_532115409054_item	2674291	et	3	main
oma	doc_532115409054_item	2674298	et	4	main
vana	doc_532115409054_item	2674299	et	4	main
auto	doc_532115409054_item	2674300	et	4	main
autoga	doc_532115409054_item	2674220	et	3	main
olin	doc_532115409054_item	2674228	et	3	main
ja	doc_532115409054_item	2674232	et	3	main
ajal	doc_532115409054_item	2674234	et	4	main
suured	doc_532115409054_item	2674239	et	3	main
ja	doc_532115409054_item	2674240	et	3	main
tuntud	doc_532115409054_item	2674241	et	4	main
automargid	doc_532115409054_item	2674242	et	3	main
mercedes	doc_532115409054_item	2674245	et	4	main
audi	doc_532115409054_item	2674247	et	3	main
ja	doc_532115409054_item	2674249	et	3	main
e	doc_532115409054_item	2674251	et	4	main
mu	doc_532115409054_item	2674252	et	3	main
olin	doc_532115409054_item	2674259	et	3	main
aastat	doc_532115409054_item	2674267	et	3	main
teadsin	doc_532115409054_item	2674271	et	3	main
rohkem	doc_532115409054_item	2674272	et	4	main
kui	doc_532115409054_item	2674273	et	3	main
minu	doc_532115409054_item	2674274	et	3	main
isa	doc_532115409054_item	2674275	et	4	main
autodest	doc_532115409054_item	2674276	et	3	main
ma	doc_532115409054_item	2674285	et	3	main
kuusteist	doc_532115409054_item	2674287	et	4	main
vana	doc_532115409054_item	2674289	et	4	main
juhiload	doc_532115409054_item	2674292	et	4	main
ja	doc_532115409054_item	2674293	et	3	main
mu	doc_532115409054_item	2674294	et	3	main
isa	doc_532115409054_item	2674295	et	4	main
andis	doc_532115409054_item	2674296	et	3	main
ma	doc_532115409054_item	2674303	et	3	main
olin	doc_532115409054_item	2674304	et	3	main
väga	doc_532115409054_item	2674305	et	3	main
õnnelik	doc_532115409054_item	2674306	et	3	main
üks	doc_532115409054_item	2674307	et	3	main
aasta	doc_532115409054_item	2674308	et	4	main
ja	doc_532115409054_item	2674309	et	3	main
pärast	doc_532115409054_item	2674310	et	4	main
ühe	doc_532115409054_item	2674311	et	4	main
aasta	doc_532115409054_item	2674312	et	4	main
ükskord	doc_532115409054_item	2674313	et	3	main
ma	doc_532115409054_item	2674314	et	3	main
andsin	doc_532115409054_item	2674315	et	3	main
auto	doc_532115409054_item	2674316	et	4	main
oma	doc_532115409054_item	2674317	et	4	main
sõbrale	doc_532115409054_item	2674318	et	3	main
ja	doc_532115409054_item	2674319	et	3	main
see	doc_532115409054_item	2674320	et	3	main
katki	doc_532115409054_item	2674326	et	4	main
mu	doc_532115409054_item	2674327	et	3	main
praaegu	doc_532115409054_item	2674329	et	4	main
mul	doc_532115409054_item	2674330	et	3	main
leiutis	doc_532115409055_item	2674347	et	3	main
tänapäeval	doc_532115409055_item	2674354	et	3	main
palju	doc_532115409055_item	2674359	et	4	main
leiutisi	doc_532115409055_item	2674360	et	3	main
me	doc_532115409055_item	2674361	et	4	main
ja	doc_532115409055_item	2674378	et	3	main
jne	doc_532115409055_item	2674384	et	4	main
inimene	doc_532115409055_item	2674386	et	3	main
saa	doc_532115409055_item	2674388	et	4	main
elada	doc_532115409055_item	2674389	et	3	main
ilma	doc_532115409055_item	2674390	et	4	main
olen	doc_532115409055_item	2674426	et	3	main
see	doc_532115409055_item	2674436	et	3	main
mulle	doc_532115409055_item	2674437	et	4	main
meeldi	doc_532115409055_item	2674439	et	4	main
kõik	doc_532115409054_item	2674238	et	4	main
benz	doc_532115409054_item	2674246	et	4	main
n	doc_532115409054_item	2674250	et	4	main
miks	doc_532115409054_item	2674257	et	4	main
vaid	doc_532115409054_item	2674262	et	3	main
kui	doc_532115409054_item	2674263	et	3	main
kaksteist	doc_532115409054_item	2674266	et	4	main
ma	doc_532115409054_item	2674269	et	3	main
juba	doc_532115409054_item	2674270	et	3	main
piloodi	doc_532115409054_item	2674283	et	3	main
aastat	doc_532115409054_item	2674288	et	3	main
ma	doc_532115409054_item	2674290	et	3	main
oli	doc_532115409054_item	2674321	et	3	main
ta	doc_532115409054_item	2674324	et	4	main
tihti	doc_532115409054_item	2674337	et	3	main
saaks	doc_532115409054_item	2674343	et	3	main
elada	doc_532115409054_item	2674344	et	3	main
ilma	doc_532115409055_item	2674348	et	4	main
ei	doc_532115409055_item	2674351	et	4	main
isegi	doc_532115409055_item	2674362	et	4	main
ei	doc_532115409055_item	2674363	et	4	main
saa	doc_532115409055_item	2674364	et	4	main
väga	doc_532115409055_item	2674376	et	3	main
vajalikud	doc_532115409055_item	2674377	et	3	main
näiteks	doc_532115409055_item	2674380	et	4	main
elekter	doc_532115409055_item	2674381	et	3	main
sõltuvust	doc_532115409055_item	2674422	et	4	main
asjadest	doc_532115409055_item	2674424	et	3	main
mina	doc_532115409055_item	2674429	et	4	main
väga	doc_532115409055_item	2674430	et	3	main
vähe	doc_532115409055_item	2674431	et	3	main
loen	doc_532115409055_item	2674432	et	3	main
raamatuid	doc_532115409055_item	2674433	et	3	main
ei	doc_532115409055_item	2674438	et	4	main
maailmast	doc_532115409055_item	2674450	et	4	main
jaoks	doc_532115409055_item	2674457	et	4	main
koostamiseks	doc_532115409055_item	2674467	et	4	main
ja	doc_532115409055_item	2674468	et	3	main
öösel	doc_532115409055_item	2674474	et	4	main
vajalikku	doc_532115409055_item	2674476	et	4	main
mulle	doc_532115409055_item	2674498	et	4	main
aitab	doc_532115409055_item	2674499	et	3	main
telefoniga	doc_532115409055_item	2674505	et	4	main
paar	doc_532115409055_item	2674506	et	3	main
lihtsalt	doc_532115409055_item	2674510	et	4	main
praegu	doc_532115409055_item	2674515	et	3	main
võin	doc_532115409055_item	2674524	et	3	main
ma	doc_532115409055_item	2674533	et	3	main
käest	doc_532115409055_item	2674540	et	4	main
mida	doc_532115409055_item	2674541	et	4	main
mul	doc_532115409055_item	2674542	et	3	main
on	doc_532115409055_item	2674543	et	4	main
sõnumit	doc_532115409055_item	2674551	et	3	main
ei	doc_532115409055_item	2674556	et	4	main
saa	doc_532115409055_item	2674557	et	4	main
elada	doc_532115409055_item	2674558	et	3	main
muidugi	doc_532115409055_item	2674569	et	4	main
kui	doc_532115409055_item	2674573	et	3	main
elab	doc_532115409055_item	2674575	et	3	main
tänapäeval	doc_532115409055_item	2674583	et	3	main
kosmososse	doc_532115409056_item	2674643	et	3	main
tähtsad	doc_532115409056_item	2674648	et	3	main
aga	doc_532115409056_item	2674650	et	3	main
jaoks	doc_532115409056_item	2674652	et	4	main
kui	doc_532115409056_item	2674653	et	3	main
tavalise	doc_532115409056_item	2674654	et	4	main
mobiil	doc_532115409056_item	2674660	et	3	main
kui	doc_532115409056_item	2674667	et	3	main
inimesed	doc_532115409056_item	2674687	et	3	main
mobiil	doc_532115409056_item	2674691	et	3	main
annab	doc_532115409056_item	2674693	et	3	main
teiega	doc_532115409056_item	2674699	et	3	main
hetkel	doc_532115409056_item	2674704	et	4	main
kui	doc_532115409056_item	2674717	et	3	main
teie	doc_532115409056_item	2674718	et	4	main
saada	doc_532115409056_item	2674721	et	4	main
kohtumise	doc_532115409056_item	2674730	et	4	main
saate	doc_532115409056_item	2674734	et	4	main
on	doc_532115409056_item	2674739	et	4	main
mobiil	doc_532115409056_item	2674742	et	3	main
telefoni	doc_532115409056_item	2674748	et	4	main
kohta	doc_532115409056_item	2674753	et	4	main
tegi	doc_532115409054_item	2674325	et	4	main
auto	doc_532115409054_item	2674328	et	4	main
milleta	doc_532115409055_item	2674349	et	3	main
elada	doc_532115409055_item	2674353	et	3	main
meie	doc_532115409055_item	2674355	et	4	main
on	doc_532115409055_item	2674357	et	4	main
iga	doc_532115409055_item	2674385	et	4	main
oma	doc_532115409055_item	2674391	et	4	main
leiutiseta	doc_532115409055_item	2674392	et	3	main
keegi	doc_532115409055_item	2674393	et	4	main
ei	doc_532115409055_item	2674394	et	4	main
saa	doc_532115409055_item	2674395	et	4	main
elada	doc_532115409055_item	2674396	et	3	main
ilma	doc_532115409055_item	2674397	et	4	main
õluta	doc_532115409055_item	2674398	et	4	main
keegi	doc_532115409055_item	2674399	et	4	main
ei	doc_532115409055_item	2674400	et	4	main
saa	doc_532115409055_item	2674401	et	4	main
elada	doc_532115409055_item	2674402	et	3	main
ilma	doc_532115409055_item	2674403	et	4	main
raamatuta	doc_532115409055_item	2674404	et	4	main
aga	doc_532115409055_item	2674405	et	3	main
mina	doc_532115409055_item	2674406	et	4	main
kahjuks	doc_532115409055_item	2674407	et	4	main
ei	doc_532115409055_item	2674408	et	4	main
saa	doc_532115409055_item	2674409	et	4	main
elada	doc_532115409055_item	2674410	et	3	main
arvutita	doc_532115409055_item	2674412	et	4	main
aga	doc_532115409055_item	2674413	et	3	main
ilma	doc_532115409055_item	2674411	et	4	main
täpselt	doc_532115409055_item	2674414	et	4	main
internetita	doc_532115409055_item	2674415	et	4	main
telefonita	doc_532115409055_item	2674416	et	3	main
ja	doc_532115409055_item	2674417	et	3	main
televiisorita	doc_532115409055_item	2674418	et	3	main
mul	doc_532115409055_item	2674419	et	3	main
ei	doc_532115409055_item	2674420	et	4	main
elaksime	doc_532115409055_item	2674368	et	3	main
et	doc_532115409055_item	2674369	et	3	main
neid	doc_532115409055_item	2674370	et	4	main
autovedu	doc_532115409055_item	2674383	et	4	main
ei	doc_532115409055_item	2674387	et	4	main
ma	doc_532115409055_item	2674425	et	3	main
et	doc_532115409055_item	2674428	et	3	main
internetis	doc_532115409055_item	2674445	et	4	main
arvuti	doc_532115409055_item	2674451	et	4	main
ole	doc_532115409055_item	2674453	et	4	main
teksti	doc_532115409055_item	2674469	et	4	main
inimesed	doc_532115409055_item	2674484	et	3	main
sõnaraamatuid	doc_532115409055_item	2674490	et	3	main
nad	doc_532115409055_item	2674491	et	3	main
teler	doc_532115409055_item	2674500	et	3	main
tagasi	doc_532115409055_item	2674508	et	3	main
aga	doc_532115409055_item	2674514	et	3	main
öelda	doc_532115409055_item	2674525	et	4	main
emale	doc_532115409055_item	2674526	et	3	main
olen	doc_532115409055_item	2674530	et	3	main
teen	doc_532115409055_item	2674532	et	3	main
küsida	doc_532115409055_item	2674538	et	3	main
või	doc_532115409055_item	2674552	et	4	main
ma	doc_532115409055_item	2674555	et	3	main
elektrita	doc_532115409055_item	2674560	et	3	main
gaasita	doc_532115409055_item	2674562	et	4	main
jalgsi	doc_532115409055_item	2674570	et	3	main
ta	doc_532115409055_item	2674574	et	4	main
teises	doc_532115409055_item	2674576	et	4	main
linnas	doc_532115409055_item	2674577	et	4	main
mina	doc_532115409055_item	2674585	et	4	main
jooksul	doc_532115409056_item	2674624	et	4	main
palju	doc_532115409056_item	2674627	et	4	main
kasulikke	doc_532115409056_item	2674628	et	3	main
leiutisi	doc_532115409056_item	2674629	et	3	main
inimekond	doc_532115409056_item	2674630	et	4	main
olid	doc_532115409056_item	2674635	et	4	main
inimene	doc_532115409056_item	2674641	et	3	main
küll	doc_532115409056_item	2674646	et	4	main
väga	doc_532115409056_item	2674647	et	3	main
leiutised	doc_532115409056_item	2674649	et	3	main
minu	doc_532115409056_item	2674662	et	3	main
kasvas	doc_532115409056_item	2674664	et	3	main
ajal	doc_532115409056_item	2674666	et	4	main
selleta	doc_532115409056_item	2674690	et	3	main
palju	doc_532115409056_item	2674694	et	4	main
helistab	doc_532115409056_item	2674715	et	3	main
nõus	doc_532115409055_item	2674427	et	4	main
lihtsalt	doc_532115409055_item	2674435	et	4	main
ja	doc_532115409055_item	2674446	et	3	main
mängimise	doc_532115409055_item	2674456	et	4	main
programmid	doc_532115409055_item	2674465	et	4	main
tabeli	doc_532115409055_item	2674466	et	3	main
trükkimiseks	doc_532115409055_item	2674470	et	4	main
võin	doc_532115409055_item	2674472	et	3	main
istuvad	doc_532115409055_item	2674485	et	4	main
raamatukogus	doc_532115409055_item	2674486	et	4	main
midagi	doc_532115409055_item	2674487	et	4	main
kirjutavad	doc_532115409055_item	2674488	et	4	main
kõik	doc_532115409055_item	2674495	et	4	main
seda	doc_532115409055_item	2674496	et	3	main
teha	doc_532115409055_item	2674497	et	3	main
seotud	doc_532115409055_item	2674504	et	4	main
ilma	doc_532115409055_item	2674512	et	4	main
saaks	doc_532115409055_item	2674518	et	3	main
ilma	doc_532115409055_item	2674519	et	4	main
telefonita	doc_532115409055_item	2674520	et	3	main
elada	doc_532115409055_item	2674521	et	3	main
kus	doc_532115409055_item	2674528	et	3	main
saan	doc_532115409055_item	2674534	et	4	main
inimest	doc_532115409055_item	2674536	et	3	main
tema	doc_532115409055_item	2674539	et	4	main
alati	doc_532115409055_item	2674549	et	4	main
saadan	doc_532115409055_item	2674550	et	4	main
kui	doc_532115409055_item	2674564	et	3	main
inimene	doc_532115409055_item	2674565	et	3	main
aga	doc_532115409055_item	2674572	et	3	main
siiski	doc_532115409055_item	2674582	et	4	main
ei	doc_532115409056_item	2674619	et	4	main
aga	doc_532115409055_item	2674440	et	3	main
ma	doc_532115409055_item	2674441	et	3	main
väga	doc_532115409055_item	2674442	et	3	main
palju	doc_532115409055_item	2674443	et	4	main
surfin	doc_532115409055_item	2674444	et	4	main
ma	doc_532115409055_item	2674458	et	3	main
isegi	doc_532115409055_item	2674459	et	4	main
töötan	doc_532115409055_item	2674460	et	3	main
ma	doc_532115409055_item	2674471	et	3	main
tea	doc_532115409055_item	2674481	et	4	main
kuidas	doc_532115409055_item	2674482	et	3	main
paljud	doc_532115409055_item	2674483	et	3	main
kasutavad	doc_532115409055_item	2674489	et	4	main
raiskavad	doc_532115409055_item	2674492	et	4	main
arvuti	doc_532115409055_item	2674501	et	4	main
mobiiltelefonita	doc_532115409055_item	2674513	et	3	main
ei	doc_532115409055_item	2674517	et	4	main
mõned	doc_532115409055_item	2674464	et	3	main
isegi	doc_532115409055_item	2674473	et	4	main
leida	doc_532115409055_item	2674475	et	3	main
infot	doc_532115409055_item	2674477	et	3	main
ma	doc_532115409055_item	2674478	et	3	main
juba	doc_532115409055_item	2674479	et	3	main
ei	doc_532115409055_item	2674480	et	4	main
oma	doc_532115409055_item	2674493	et	4	main
aega	doc_532115409055_item	2674494	et	4	main
mis	doc_532115409055_item	2674502	et	4	main
on	doc_532115409055_item	2674503	et	4	main
aastat	doc_532115409055_item	2674507	et	3	main
me	doc_532115409055_item	2674509	et	4	main
elame	doc_532115409055_item	2674511	et	3	main
ma	doc_532115409055_item	2674516	et	3	main
alati	doc_532115409055_item	2674523	et	4	main
näiteks	doc_532115409055_item	2674527	et	4	main
ma	doc_532115409055_item	2674529	et	3	main
mida	doc_532115409055_item	2674531	et	4	main
ja	doc_532115409055_item	2674537	et	3	main
kui	doc_532115409055_item	2674545	et	3	main
midagi	doc_532115409055_item	2674546	et	4	main
juhtus	doc_532115409055_item	2674547	et	3	main
ma	doc_532115409055_item	2674548	et	3	main
helistan	doc_532115409055_item	2674553	et	3	main
muidugi	doc_532115409055_item	2674554	et	4	main
või	doc_532115409055_item	2674561	et	4	main
elab	doc_532115409055_item	2674566	et	3	main
minna	doc_532115409055_item	2674571	et	3	main
just	doc_532115409055_item	2674584	et	3	main
ei	doc_532115409055_item	2674586	et	4	main
sajandi	doc_532115409056_item	2674623	et	3	main
tegid	doc_532115409056_item	2674625	et	4	main
tehtud	doc_532115409056_item	2674636	et	4	main
uuringud	doc_532115409056_item	2674638	et	3	main
inimese	doc_532115409056_item	2674655	et	4	main
telefon	doc_532115409056_item	2674661	et	3	main
telefon	doc_532115409056_item	2674692	et	3	main
igaüks	doc_532115409056_item	2674696	et	3	main
teie	doc_532115409056_item	2674705	et	4	main
leppisite	doc_532115409056_item	2674719	et	3	main
tahate	doc_532115409056_item	2674728	et	3	main
neile	doc_532115409056_item	2674736	et	4	main
kaudu	doc_532115409056_item	2674749	et	3	main
parkimise	doc_532115409056_item	2674752	et	4	main
eest	doc_532115409056_item	2674754	et	4	main
hetkel	doc_532115409056_item	2674770	et	4	main
kunagi	doc_532115409056_item	2674789	et	3	main
on	doc_532115409056_item	2674792	et	4	main
kaasas	doc_532115409056_item	2674793	et	4	main
siis	doc_532115409056_item	2674794	et	3	main
tunnen	doc_532115409056_item	2674795	et	3	main
et	doc_532115409056_item	2674800	et	3	main
ja	doc_532115409056_item	2674808	et	3	main
leiutis	doc_532115409057_item	2674811	et	3	main
maailm	doc_532115409057_item	2674819	et	3	main
saa	doc_532115409057_item	2674821	et	4	main
inimesed	doc_532115409057_item	2674826	et	3	main
elada	doc_532115409057_item	2674828	et	3	main
selle	doc_532115409057_item	2674835	et	4	main
arengusega	doc_532115409057_item	2674836	et	4	main
inimesed	doc_532115409057_item	2674837	et	3	main
leiuvad	doc_532115409057_item	2674838	et	4	main
uued	doc_532115409057_item	2674839	et	3	main
leiutised	doc_532115409057_item	2674840	et	3	main
praegu	doc_532115409057_item	2674841	et	3	main
inimesel	doc_532115409057_item	2674842	et	3	main
on	doc_532115409057_item	2674843	et	4	main
väga	doc_532115409057_item	2674844	et	3	main
varem	doc_532115409057_item	2674852	et	4	main
varem	doc_532115409057_item	2674854	et	4	main
sa	doc_532115409057_item	2674856	et	3	main
pärast	doc_532115409057_item	2674861	et	4	main
läbi	doc_532115409057_item	2674872	et	4	main
tuleb	doc_532115409057_item	2674874	et	3	main
ja	doc_532115409057_item	2674889	et	3	main
sulle	doc_532115409057_item	2674923	et	3	main
on	doc_532115409057_item	2674924	et	4	main
asju	doc_532115409057_item	2674929	et	3	main
saa	doc_532115409057_item	2674934	et	4	main
telefon	doc_532115409057_item	2674938	et	3	main
on	doc_532115409057_item	2674963	et	4	main
mina	doc_532115409055_item	2674522	et	4	main
leida	doc_532115409055_item	2674535	et	3	main
vaja	doc_532115409055_item	2674544	et	4	main
ilma	doc_532115409055_item	2674559	et	4	main
transpordita	doc_532115409055_item	2674563	et	4	main
lähedalt	doc_532115409055_item	2674567	et	4	main
võib	doc_532115409055_item	2674568	et	3	main
mida	doc_532115409055_item	2674578	et	4	main
siis	doc_532115409055_item	2674579	et	3	main
teha	doc_532115409055_item	2674580	et	3	main
aga	doc_532115409055_item	2674581	et	3	main
saa	doc_532115409055_item	2674587	et	4	main
elada	doc_532115409055_item	2674588	et	3	main
ilma	doc_532115409055_item	2674589	et	4	main
arvutita	doc_532115409055_item	2674590	et	4	main
ja	doc_532115409055_item	2674592	et	3	main
televiisorita	doc_532115409055_item	2674591	et	3	main
telefonita	doc_532115409055_item	2674593	et	3	main
ma	doc_532115409055_item	2674594	et	3	main
olen	doc_532115409055_item	2674595	et	3	main
väga	doc_532115409055_item	2674596	et	3	main
rõõmus	doc_532115409055_item	2674597	et	4	main
et	doc_532115409055_item	2674598	et	3	main
need	doc_532115409055_item	2674599	et	3	main
asjad	doc_532115409055_item	2674600	et	3	main
on	doc_532115409055_item	2674601	et	4	main
olemas	doc_532115409055_item	2674602	et	4	main
võib	doc_532115409055_item	2674603	et	3	main
olla	doc_532115409055_item	2674604	et	3	main
neid	doc_532115409055_item	2674605	et	4	main
ei	doc_532115409055_item	2674606	et	4	main
oleks	doc_532115409055_item	2674607	et	3	main
üldse	doc_532115409055_item	2674608	et	3	main
maailmas	doc_532115409055_item	2674609	et	3	main
ma	doc_532115409055_item	2674610	et	3	main
võiks	doc_532115409055_item	2674611	et	4	main
elada	doc_532115409055_item	2674612	et	3	main
kes	doc_532115409055_item	2674613	et	4	main
teab	doc_532115409055_item	2674614	et	3	main
leiutis	doc_532115409056_item	2674615	et	3	main
ilma	doc_532115409056_item	2674616	et	4	main
milleta	doc_532115409056_item	2674617	et	3	main
ma	doc_532115409056_item	2674618	et	3	main
saaks	doc_532115409056_item	2674620	et	3	main
elada	doc_532115409056_item	2674621	et	3	main
erinevad	doc_532115409056_item	2674632	et	4	main
autod	doc_532115409056_item	2674633	et	3	main
lennukid	doc_532115409056_item	2674634	et	3	main
esimene	doc_532115409056_item	2674640	et	3	main
see	doc_532115409056_item	2674644	et	3	main
viimase	doc_532115409056_item	2674622	et	3	main
inimesed	doc_532115409056_item	2674626	et	3	main
leidis	doc_532115409056_item	2674631	et	4	main
tähtsad	doc_532115409056_item	2674637	et	3	main
tuumafüüsikas	doc_532115409056_item	2674639	et	3	main
lendis	doc_532115409056_item	2674642	et	4	main
on	doc_532115409056_item	2674645	et	4	main
minu	doc_532115409056_item	2674651	et	3	main
on	doc_532115409056_item	2674659	et	4	main
põlvkond	doc_532115409056_item	2674663	et	3	main
eestis	doc_532115409056_item	2674668	et	3	main
hakkasid	doc_532115409056_item	2674669	et	4	main
ilmuda	doc_532115409056_item	2674670	et	3	main
esimesed	doc_532115409056_item	2674671	et	3	main
mobiiltelefonid	doc_532115409056_item	2674672	et	3	main
praegu	doc_532115409056_item	2674673	et	3	main
kaks	doc_532115409056_item	2674674	et	3	main
kolmandiku	doc_532115409056_item	2674675	et	3	main
inimest	doc_532115409056_item	2674676	et	3	main
omab	doc_532115409056_item	2674677	et	3	main
see	doc_532115409056_item	2674678	et	3	main
hädavajalik	doc_532115409056_item	2674679	et	3	main
asi	doc_532115409056_item	2674680	et	4	main
tänapäeval	doc_532115409056_item	2674681	et	3	main
on	doc_532115409056_item	2674682	et	4	main
raske	doc_532115409056_item	2674683	et	4	main
kujutada	doc_532115409056_item	2674684	et	3	main
ette	doc_532115409056_item	2674685	et	4	main
kuidas	doc_532115409056_item	2674686	et	3	main
jaoks	doc_532115409056_item	2674656	et	4	main
väga	doc_532115409056_item	2674657	et	3	main
kasulik	doc_532115409056_item	2674658	et	3	main
tol	doc_532115409056_item	2674665	et	3	main
ilma	doc_532115409056_item	2674689	et	4	main
saab	doc_532115409056_item	2674697	et	3	main
ühendust	doc_532115409056_item	2674700	et	4	main
kaudu	doc_532115409056_item	2674702	et	3	main
igal	doc_532115409056_item	2674703	et	3	main
ei	doc_532115409056_item	2674706	et	4	main
istuma	doc_532115409056_item	2674708	et	3	main
kokku	doc_532115409056_item	2674720	et	3	main
oma	doc_532115409056_item	2674722	et	4	main
sõbradega	doc_532115409056_item	2674723	et	4	main
aga	doc_532115409056_item	2674724	et	3	main
teie	doc_532115409056_item	2674725	et	4	main
hilinete	doc_532115409056_item	2674726	et	3	main
paik	doc_532115409056_item	2674731	et	3	main
lihtsalt	doc_532115409056_item	2674733	et	4	main
helistada	doc_532115409056_item	2674735	et	3	main
ja	doc_532115409056_item	2674737	et	3	main
lahendatud	doc_532115409056_item	2674740	et	4	main
võib	doc_532115409056_item	2674744	et	3	main
või	doc_532115409056_item	2674755	et	4	main
mis	doc_532115409056_item	2674768	et	4	main
linnas	doc_532115409056_item	2674771	et	4	main
varem	doc_532115409056_item	2674773	et	4	main
ilma	doc_532115409056_item	2674778	et	4	main
aga	doc_532115409056_item	2674780	et	3	main
ei	doc_532115409056_item	2674783	et	4	main
paremini	doc_532115409056_item	2674797	et	4	main
probleemi	doc_532115409056_item	2674801	et	4	main
saan	doc_532115409056_item	2674803	et	4	main
hetkel	doc_532115409056_item	2674805	et	4	main
ilma	doc_532115409057_item	2674812	et	4	main
ma	doc_532115409057_item	2674814	et	3	main
saaks	doc_532115409057_item	2674816	et	3	main
ei	doc_532115409057_item	2674820	et	4	main
elada	doc_532115409057_item	2674822	et	3	main
leiutiseta	doc_532115409057_item	2674829	et	3	main
palju	doc_532115409057_item	2674845	et	4	main
kergem	doc_532115409057_item	2674850	et	4	main
ja	doc_532115409057_item	2674868	et	3	main
inimestele	doc_532115409057_item	2674876	et	3	main
sa	doc_532115409057_item	2674878	et	3	main
kiri	doc_532115409057_item	2674880	et	3	main
saatab	doc_532115409057_item	2674881	et	4	main
kiri	doc_532115409057_item	2674890	et	3	main
ilma	doc_532115409057_item	2674930	et	4	main
teler	doc_532115409057_item	2674937	et	3	main
et	doc_532115409057_item	2674944	et	3	main
aitava	doc_532115409057_item	2674949	et	4	main
elada	doc_532115409057_item	2674950	et	3	main
nagu	doc_532115409057_item	2674951	et	3	main
et	doc_532115409057_item	2674955	et	3	main
saaks	doc_532115409058_item	2674977	et	3	main
ma	doc_532115409058_item	2674979	et	3	main
kõige	doc_532115409058_item	2674982	et	4	main
tehnoloogia	doc_532115409058_item	2674989	et	4	main
olulised	doc_532115409058_item	2675004	et	4	main
näiteks	doc_532115409058_item	2675005	et	4	main
ja	doc_532115409058_item	2675017	et	3	main
on	doc_532115409058_item	2675020	et	4	main
parem	doc_532115409058_item	2675023	et	4	main
oma	doc_532115409058_item	2675035	et	4	main
rääkida	doc_532115409058_item	2675041	et	3	main
palju	doc_532115409058_item	2675044	et	4	main
leiutised	doc_532115409058_item	2675048	et	3	main
ei	doc_532115409058_item	2675051	et	4	main
ole	doc_532115409058_item	2675052	et	4	main
külmkapp	doc_532115409058_item	2675058	et	3	main
konstrueritud	doc_532115409058_item	2675062	et	4	main
suure	doc_532115409058_item	2675077	et	3	main
söök	doc_532115409058_item	2675121	et	3	main
erinev	doc_532115409058_item	2675125	et	4	main
veel	doc_532115409058_item	2675139	et	4	main
palju	doc_532115409059_item	2675149	et	4	main
erinevaid	doc_532115409059_item	2675150	et	4	main
leiutiseid	doc_532115409059_item	2675151	et	4	main
kasulikud	doc_532115409059_item	2675157	et	3	main
igal	doc_532115409059_item	2675185	et	3	main
inimesel	doc_532115409059_item	2675186	et	3	main
elasid	doc_532115409056_item	2674688	et	4	main
võimalusi	doc_532115409056_item	2674695	et	3	main
võtta	doc_532115409056_item	2674698	et	3	main
telefoni	doc_532115409056_item	2674701	et	4	main
pea	doc_532115409056_item	2674707	et	4	main
kodus	doc_532115409056_item	2674709	et	4	main
ja	doc_532115409056_item	2674710	et	3	main
ootama	doc_532115409056_item	2674711	et	3	main
kui	doc_532115409056_item	2674712	et	3	main
vajalik	doc_532115409056_item	2674713	et	3	main
inimene	doc_532115409056_item	2674714	et	3	main
teile	doc_532115409056_item	2674716	et	4	main
või	doc_532115409056_item	2674727	et	4	main
siis	doc_532115409056_item	2674732	et	3	main
maksu	doc_532115409056_item	2674746	et	4	main
saate	doc_532115409056_item	2674750	et	4	main
maksta	doc_532115409056_item	2674751	et	4	main
üüritustest	doc_532115409056_item	2674767	et	4	main
toimuvad	doc_532115409056_item	2674769	et	4	main
normaalselt	doc_532115409056_item	2674777	et	4	main
ma	doc_532115409056_item	2674782	et	3	main
jätta	doc_532115409056_item	2674784	et	3	main
mobiil	doc_532115409056_item	2674785	et	3	main
telefon	doc_532115409056_item	2674786	et	3	main
mitte	doc_532115409056_item	2674788	et	3	main
kui	doc_532115409056_item	2674790	et	3	main
olen	doc_532115409056_item	2674798	et	3	main
helistada	doc_532115409056_item	2674807	et	3	main
lahendada	doc_532115409056_item	2674810	et	3	main
ei	doc_532115409057_item	2674815	et	4	main
tänapäevane	doc_532115409057_item	2674818	et	4	main
ilma	doc_532115409057_item	2674823	et	4	main
aga	doc_532115409057_item	2674830	et	3	main
ja	doc_532115409057_item	2674834	et	3	main
elu	doc_532115409057_item	2674849	et	4	main
posti	doc_532115409057_item	2674867	et	4	main
päeva	doc_532115409057_item	2674871	et	4	main
ta	doc_532115409057_item	2674873	et	4	main
selle	doc_532115409057_item	2674875	et	4	main
kellele	doc_532115409057_item	2674877	et	4	main
seda	doc_532115409057_item	2674879	et	3	main
aga	doc_532115409057_item	2674882	et	3	main
praegu	doc_532115409057_item	2674883	et	3	main
inimesed	doc_532115409057_item	2674884	et	3	main
saavad	doc_532115409057_item	2674885	et	4	main
seda	doc_532115409057_item	2674886	et	3	main
teha	doc_532115409057_item	2674887	et	3	main
muuda	doc_532115409056_item	2674729	et	4	main
küsimus	doc_532115409056_item	2674738	et	4	main
praegu	doc_532115409056_item	2674741	et	3	main
telefon	doc_532115409056_item	2674743	et	3	main
kasutada	doc_532115409056_item	2674745	et	3	main
vahendiks	doc_532115409056_item	2674747	et	3	main
osta	doc_532115409056_item	2674756	et	4	main
id-pileti	doc_532115409056_item	2674757	et	3	main
telefoni	doc_532115409056_item	2674758	et	4	main
kaudu	doc_532115409056_item	2674759	et	3	main
võib	doc_532115409056_item	2674760	et	3	main
ka	doc_532115409056_item	2674761	et	3	main
teada	doc_532115409056_item	2674762	et	3	main
saada	doc_532115409056_item	2674763	et	4	main
ilmast	doc_532115409056_item	2674764	et	4	main
meelelahutustest	doc_532115409056_item	2674765	et	4	main
ja	doc_532115409056_item	2674766	et	3	main
muidugi	doc_532115409056_item	2674772	et	4	main
inimesed	doc_532115409056_item	2674774	et	3	main
elasid	doc_532115409056_item	2674775	et	4	main
üsna	doc_532115409056_item	2674776	et	3	main
praegu	doc_532115409056_item	2674781	et	3	main
kojju	doc_532115409056_item	2674787	et	4	main
telefon	doc_532115409056_item	2674791	et	3	main
kindel	doc_532115409056_item	2674799	et	3	main
tekkimisel	doc_532115409056_item	2674802	et	4	main
igal	doc_532115409056_item	2674804	et	3	main
seda	doc_532115409056_item	2674809	et	3	main
milleta	doc_532115409057_item	2674813	et	3	main
selleta	doc_532115409056_item	2674779	et	3	main
end	doc_532115409056_item	2674796	et	4	main
keegile	doc_532115409056_item	2674806	et	4	main
elada	doc_532115409057_item	2674817	et	3	main
leiutised	doc_532115409057_item	2674824	et	3	main
mugavused	doc_532115409057_item	2674846	et	4	main
mis	doc_532115409057_item	2674847	et	4	main
teevad	doc_532115409057_item	2674848	et	3	main
näidend	doc_532115409057_item	2674853	et	3	main
kui	doc_532115409057_item	2674855	et	3	main
kirjutada	doc_532115409057_item	2674858	et	3	main
ja	doc_532115409057_item	2674860	et	3	main
saatma	doc_532115409057_item	2674862	et	3	main
sa	doc_532115409057_item	2674864	et	3	main
ainult	doc_532115409057_item	2674869	et	4	main
veel	doc_532115409057_item	2674926	et	4	main
on	doc_532115409057_item	2674927	et	4	main
ei	doc_532115409057_item	2674933	et	4	main
nagu	doc_532115409057_item	2674936	et	3	main
pesumasin	doc_532115409057_item	2674940	et	3	main
ma	doc_532115409057_item	2674942	et	3	main
ei	doc_532115409058_item	2674976	et	4	main
arva	doc_532115409058_item	2674980	et	4	main
meile	doc_532115409058_item	2674992	et	4	main
kõik	doc_532115409058_item	2675001	et	4	main
need	doc_532115409058_item	2675002	et	3	main
omamoodes	doc_532115409058_item	2675003	et	4	main
kõige	doc_532115409058_item	2675008	et	4	main
allikas	doc_532115409058_item	2675011	et	4	main
meie	doc_532115409058_item	2675014	et	4	main
panka	doc_532115409058_item	2675015	et	4	main
operatsioonid	doc_532115409058_item	2675016	et	3	main
selline	doc_532115409058_item	2675031	et	4	main
suhelda	doc_532115409058_item	2675034	et	4	main
palju	doc_532115409058_item	2675040	et	4	main
mugavust	doc_532115409058_item	2675045	et	4	main
need	doc_532115409058_item	2675047	et	3	main
on	doc_532115409058_item	2675056	et	4	main
vaja	doc_532115409058_item	2675057	et	4	main
tarbe	doc_532115409058_item	2675060	et	3	main
toit	doc_532115409058_item	2675070	et	3	main
ja	doc_532115409058_item	2675079	et	3	main
kõike	doc_532115409058_item	2675082	et	4	main
varem	doc_532115409057_item	2674825	et	4	main
saavad	doc_532115409057_item	2674827	et	4	main
meie	doc_532115409057_item	2674831	et	4	main
inimkond	doc_532115409057_item	2674832	et	3	main
aregab	doc_532115409057_item	2674833	et	4	main
kui	doc_532115409057_item	2674851	et	3	main
tahad	doc_532115409057_item	2674857	et	3	main
kiri	doc_532115409057_item	2674859	et	3	main
teda	doc_532115409057_item	2674863	et	4	main
peaks	doc_532115409057_item	2674865	et	4	main
minna	doc_532115409057_item	2674866	et	3	main
paar	doc_532115409057_item	2674870	et	3	main
internetis	doc_532115409057_item	2674888	et	4	main
tuleb	doc_532115409057_item	2674891	et	3	main
kohe	doc_532115409057_item	2674892	et	4	main
inimestele	doc_532115409057_item	2674893	et	3	main
ka	doc_532115409057_item	2674895	et	3	main
mina	doc_532115409057_item	2674894	et	4	main
ei	doc_532115409057_item	2674896	et	4	main
saa	doc_532115409057_item	2674897	et	4	main
elada	doc_532115409057_item	2674898	et	3	main
ilma	doc_532115409057_item	2674899	et	4	main
arvutiseta	doc_532115409057_item	2674900	et	3	main
iga	doc_532115409057_item	2674901	et	4	main
päev	doc_532115409057_item	2674902	et	3	main
ma	doc_532115409057_item	2674903	et	3	main
istun	doc_532115409057_item	2674904	et	3	main
tema	doc_532115409057_item	2674905	et	4	main
ees	doc_532115409057_item	2674906	et	4	main
suhtlen	doc_532115409057_item	2674907	et	3	main
oma	doc_532115409057_item	2674908	et	4	main
internetis	doc_532115409057_item	2674910	et	4	main
sõbradega	doc_532115409057_item	2674909	et	4	main
leian	doc_532115409057_item	2674911	et	3	main
huvitavaks	doc_532115409057_item	2674912	et	4	main
infot	doc_532115409057_item	2674913	et	3	main
ja	doc_532115409057_item	2674914	et	3	main
palju	doc_532115409057_item	2674915	et	4	main
teisi	doc_532115409057_item	2674916	et	4	main
internetis	doc_532115409057_item	2674917	et	4	main
sa	doc_532115409057_item	2674918	et	3	main
sai	doc_532115409057_item	2674919	et	4	main
leida	doc_532115409057_item	2674920	et	3	main
kõik	doc_532115409057_item	2674921	et	4	main
palju	doc_532115409057_item	2674928	et	4	main
ma	doc_532115409057_item	2674932	et	3	main
elada	doc_532115409057_item	2674935	et	3	main
külmkapp	doc_532115409057_item	2674939	et	3	main
kõigile	doc_532115409057_item	2674945	et	4	main
see	doc_532115409057_item	2674947	et	3	main
ma	doc_532115409057_item	2674953	et	3	main
mida	doc_532115409057_item	2674967	et	4	main
nad	doc_532115409057_item	2674968	et	3	main
mis	doc_532115409057_item	2674922	et	4	main
vaja	doc_532115409057_item	2674925	et	4	main
mida	doc_532115409057_item	2674931	et	4	main
jne	doc_532115409057_item	2674941	et	4	main
arvan	doc_532115409057_item	2674943	et	3	main
inimestele	doc_532115409057_item	2674946	et	3	main
leiutised	doc_532115409057_item	2674948	et	3	main
minule	doc_532115409057_item	2674952	et	3	main
loodan	doc_532115409057_item	2674954	et	3	main
tulemuseks	doc_532115409057_item	2674956	et	3	main
inimesed	doc_532115409057_item	2674957	et	3	main
leiuvad	doc_532115409057_item	2674958	et	4	main
rohkem	doc_532115409057_item	2674959	et	4	main
asju	doc_532115409057_item	2674960	et	3	main
mis	doc_532115409057_item	2674961	et	4	main
inimestele	doc_532115409057_item	2674962	et	3	main
vajalik	doc_532115409057_item	2674964	et	3	main
ja	doc_532115409057_item	2674965	et	3	main
milleta	doc_532115409058_item	2674974	et	3	main
et	doc_532115409058_item	2674981	et	3	main
elu	doc_532115409058_item	2674990	et	4	main
andis	doc_532115409058_item	2674991	et	3	main
telerid	doc_532115409058_item	2674999	et	3	main
arvutid	doc_532115409058_item	2675000	et	4	main
tähtsam	doc_532115409058_item	2675009	et	4	main
informatsiooni	doc_532115409058_item	2675010	et	4	main
arvutid	doc_532115409058_item	2675012	et	4	main
kontrollivad	doc_532115409058_item	2675013	et	4	main
teler	doc_532115409058_item	2675019	et	3	main
ilma	doc_532115409057_item	2674966	et	4	main
elada	doc_532115409058_item	2674978	et	3	main
leiutis	doc_532115409058_item	2674984	et	3	main
on	doc_532115409058_item	2674986	et	4	main
palju	doc_532115409058_item	2674993	et	4	main
muud	doc_532115409058_item	2674994	et	4	main
leiutist	doc_532115409058_item	2674995	et	3	main
näiteks	doc_532115409058_item	2674996	et	4	main
mobiil	doc_532115409058_item	2674997	et	3	main
telefonid	doc_532115409058_item	2674998	et	3	main
arvuti	doc_532115409058_item	2675006	et	4	main
maksed	doc_532115409058_item	2675018	et	3	main
praegu	doc_532115409058_item	2675021	et	3	main
on	doc_532115409058_item	2675027	et	4	main
praegu	doc_532115409058_item	2675028	et	3	main
mobiil	doc_532115409058_item	2675029	et	3	main
telefon	doc_532115409058_item	2675030	et	3	main
vanematega	doc_532115409058_item	2675038	et	4	main
võib	doc_532115409058_item	2675039	et	3	main
nende	doc_532115409058_item	2675069	et	4	main
värske	doc_532115409058_item	2675072	et	4	main
enne	doc_532115409058_item	2675074	et	4	main
panid	doc_532115409058_item	2675080	et	4	main
toitu	doc_532115409058_item	2675083	et	4	main
et	doc_532115409058_item	2675084	et	3	main
maa	doc_532115409058_item	2675085	et	4	main
all	doc_532115409058_item	2675086	et	3	main
on	doc_532115409058_item	2675087	et	4	main
külm	doc_532115409058_item	2675088	et	3	main
on	doc_532115409058_item	2675122	et	4	main
ta	doc_532115409058_item	2675127	et	4	main
tervis	doc_532115409058_item	2675130	et	3	main
kõige	doc_532115409058_item	2675132	et	4	main
mis	doc_532115409058_item	2675137	et	4	main
siis	doc_532115409058_item	2675138	et	3	main
leiutised	doc_532115409059_item	2675140	et	3	main
ilma	doc_532115409059_item	2675141	et	4	main
milleta	doc_532115409059_item	2675142	et	3	main
ma	doc_532115409059_item	2675143	et	3	main
mõned	doc_532115409059_item	2675152	et	3	main
on	doc_532115409059_item	2675153	et	4	main
aga	doc_532115409059_item	2675158	et	3	main
päeva	doc_532115409059_item	2675176	et	4	main
ei	doc_532115409059_item	2675179	et	4	main
saa	doc_532115409059_item	2675180	et	4	main
elada	doc_532115409059_item	2675181	et	3	main
ei	doc_532115409059_item	2675192	et	4	main
mõne	doc_532115409059_item	2675197	et	3	main
asi	doc_532115409059_item	2675198	et	4	main
linna	doc_532115409059_item	2675206	et	4	main
taga	doc_532115409059_item	2675207	et	4	main
ja	doc_532115409059_item	2675208	et	3	main
ilma	doc_532115409059_item	2675214	et	4	main
autota	doc_532115409059_item	2675215	et	3	main
autota	doc_532115409059_item	2675216	et	3	main
ma	doc_532115409059_item	2675217	et	3	main
ei	doc_532115409059_item	2675218	et	4	main
saa	doc_532115409059_item	2675219	et	4	main
kui	doc_532115409059_item	2675222	et	3	main
vajalik	doc_532115409059_item	2675225	et	3	main
sõidan	doc_532115409059_item	2675229	et	3	main
igal	doc_532115409059_item	2675231	et	3	main
minu	doc_532115409059_item	2675235	et	3	main
sõbrad	doc_532115409059_item	2675236	et	3	main
kui	doc_532115409059_item	2675243	et	3	main
saa	doc_532115409059_item	2675251	et	4	main
ei	doc_532115409059_item	2675255	et	4	main
aga	doc_532115409059_item	2675262	et	3	main
arvan	doc_532115409059_item	2675263	et	3	main
juba	doc_532115409059_item	2675273	et	3	main
nii	doc_532115409059_item	2675276	et	3	main
kallid	doc_532115409059_item	2675277	et	3	main
te	doc_532115409059_item	2675279	et	4	main
tahate	doc_532115409059_item	2675280	et	3	main
võite	doc_532115409059_item	2675281	et	4	main
töötada	doc_532115409059_item	2675282	et	3	main
ja	doc_532115409059_item	2675283	et	3	main
auto	doc_532115409059_item	2675288	et	4	main
maailma	doc_532115409060_item	2675328	et	4	main
võimalik	doc_532115409060_item	2675332	et	3	main
nendega	doc_532115409060_item	2675336	et	4	main
mis	doc_532115409060_item	2675339	et	4	main
toimub	doc_532115409060_item	2675340	et	3	main
ei	doc_532115409057_item	2674969	et	4	main
saaks	doc_532115409057_item	2674970	et	3	main
elada	doc_532115409057_item	2674971	et	3	main
leiutis	doc_532115409058_item	2674972	et	3	main
ilma	doc_532115409058_item	2674973	et	4	main
ma	doc_532115409058_item	2674975	et	3	main
tähtis	doc_532115409058_item	2674983	et	4	main
tänapäevas	doc_532115409058_item	2674985	et	3	main
külmkapp	doc_532115409058_item	2674987	et	3	main
meie	doc_532115409058_item	2674988	et	4	main
on	doc_532115409058_item	2675007	et	4	main
leiutis	doc_532115409058_item	2675032	et	3	main
aidab	doc_532115409058_item	2675033	et	4	main
sellest	doc_532115409058_item	2675042	et	4	main
annavad	doc_532115409058_item	2675046	et	3	main
aga	doc_532115409058_item	2675049	et	3	main
nad	doc_532115409058_item	2675050	et	3	main
oli	doc_532115409058_item	2675061	et	3	main
väga	doc_532115409058_item	2675063	et	3	main
ammu	doc_532115409058_item	2675064	et	4	main
sellest	doc_532115409058_item	2675067	et	4	main
et	doc_532115409058_item	2675068	et	3	main
auku	doc_532115409058_item	2675078	et	4	main
sinna	doc_532115409058_item	2675081	et	3	main
mada	doc_532115409058_item	2675089	et	4	main
ja	doc_532115409058_item	2675124	et	3	main
on	doc_532115409058_item	2675128	et	4	main
on	doc_532115409058_item	2675131	et	4	main
tähtis	doc_532115409058_item	2675133	et	4	main
asi	doc_532115409058_item	2675134	et	4	main
veel	doc_532115409059_item	2675159	et	4	main
jooksul	doc_532115409059_item	2675177	et	4	main
oma	doc_532115409059_item	2675188	et	4	main
ta	doc_532115409059_item	2675200	et	4	main
ei	doc_532115409059_item	2675210	et	4	main
teha	doc_532115409059_item	2675227	et	3	main
ma	doc_532115409059_item	2675228	et	3	main
väga	doc_532115409059_item	2675240	et	3	main
ja	doc_532115409059_item	2675242	et	3	main
ei	doc_532115409059_item	2675245	et	4	main
ei	doc_532115409059_item	2675250	et	4	main
nendega	doc_532115409059_item	2675252	et	4	main
ta	doc_532115409059_item	2675265	et	4	main
osta	doc_532115409059_item	2675284	et	4	main
odavat	doc_532115409059_item	2675286	et	3	main
me	doc_532115409060_item	2675321	et	4	main
kasutada	doc_532115409060_item	2675323	et	3	main
see	doc_532115409060_item	2675325	et	3	main
on	doc_532115409060_item	2675326	et	4	main
suurim	doc_532115409060_item	2675327	et	3	main
sõpru	doc_532115409060_item	2675334	et	3	main
suhelda	doc_532115409060_item	2675335	et	4	main
uudiseid	doc_532115409060_item	2675337	et	3	main
lugema	doc_532115409060_item	2675338	et	4	main
infot	doc_532115409060_item	2675346	et	3	main
kahjuks	doc_532115409060_item	2675349	et	4	main
võivad	doc_532115409060_item	2675353	et	4	main
interneti	doc_532115409060_item	2675355	et	4	main
sest	doc_532115409060_item	2675356	et	4	main
see	doc_532115409060_item	2675357	et	3	main
ja	doc_532115409060_item	2675368	et	3	main
arvuti	doc_532115409060_item	2675371	et	4	main
mulle	doc_532115409060_item	2675383	et	4	main
me	doc_532115409060_item	2675391	et	4	main
arvuti	doc_532115409060_item	2675402	et	4	main
taga	doc_532115409060_item	2675403	et	4	main
kõige	doc_532115409058_item	2675022	et	4	main
huviala	doc_532115409058_item	2675024	et	4	main
igal	doc_532115409058_item	2675025	et	3	main
inimesel	doc_532115409058_item	2675026	et	3	main
sõbratega	doc_532115409058_item	2675036	et	4	main
ja	doc_532115409058_item	2675037	et	3	main
kui	doc_532115409058_item	2675043	et	3	main
kõige	doc_532115409058_item	2675053	et	4	main
tähtsam	doc_532115409058_item	2675054	et	4	main
millest	doc_532115409058_item	2675055	et	3	main
selline	doc_532115409058_item	2675059	et	4	main
inimesed	doc_532115409058_item	2675065	et	3	main
mõtleid	doc_532115409058_item	2675066	et	4	main
peab	doc_532115409058_item	2675071	et	4	main
olla	doc_532115409058_item	2675073	et	3	main
inimesed	doc_532115409058_item	2675075	et	3	main
kaevusid	doc_532115409058_item	2675076	et	4	main
talvel	doc_532115409058_item	2675090	et	4	main
selle	doc_532115409058_item	2675091	et	4	main
pole	doc_532115409058_item	2675093	et	3	main
küsimusega	doc_532115409058_item	2675092	et	4	main
probleemi	doc_532115409058_item	2675094	et	4	main
toitu	doc_532115409058_item	2675095	et	4	main
võib	doc_532115409058_item	2675096	et	3	main
hoolda	doc_532115409058_item	2675097	et	4	main
õues	doc_532115409058_item	2675098	et	4	main
aga	doc_532115409058_item	2675099	et	3	main
mitte	doc_532115409058_item	2675100	et	3	main
kõiges	doc_532115409058_item	2675101	et	4	main
riigis	doc_532115409058_item	2675102	et	3	main
on	doc_532115409058_item	2675103	et	4	main
külmad	doc_532115409058_item	2675104	et	4	main
talved	doc_532115409058_item	2675105	et	4	main
seepärast	doc_532115409058_item	2675106	et	3	main
oli	doc_532115409058_item	2675107	et	3	main
külmkappid	doc_532115409058_item	2675109	et	4	main
konstrueeritud	doc_532115409058_item	2675108	et	4	main
miks	doc_532115409058_item	2675110	et	4	main
ma	doc_532115409058_item	2675111	et	3	main
saaks	doc_532115409058_item	2675113	et	3	main
elada	doc_532115409058_item	2675114	et	3	main
ilma	doc_532115409058_item	2675115	et	4	main
külmkappi	doc_532115409058_item	2675116	et	4	main
minu	doc_532115409058_item	2675117	et	3	main
ei	doc_532115409058_item	2675112	et	4	main
arvates	doc_532115409058_item	2675118	et	4	main
kui	doc_532115409058_item	2675119	et	3	main
inimeste	doc_532115409058_item	2675120	et	3	main
balanseeritud	doc_532115409058_item	2675123	et	4	main
tervislik	doc_532115409058_item	2675129	et	3	main
meie	doc_532115409058_item	2675135	et	4	main
elus	doc_532115409058_item	2675136	et	4	main
siis	doc_532115409058_item	2675126	et	3	main
ei	doc_532115409059_item	2675144	et	4	main
saaks	doc_532115409059_item	2675145	et	3	main
elada	doc_532115409059_item	2675146	et	3	main
maailmas	doc_532115409059_item	2675147	et	3	main
on	doc_532115409059_item	2675148	et	4	main
mõned	doc_532115409059_item	2675155	et	3	main
on	doc_532115409059_item	2675160	et	4	main
ka	doc_532115409059_item	2675161	et	3	main
ebakasulikud	doc_532115409059_item	2675162	et	3	main
palju	doc_532115409059_item	2675163	et	4	main
inimesi	doc_532115409059_item	2675164	et	4	main
ei	doc_532115409059_item	2675165	et	4	main
saa	doc_532115409059_item	2675166	et	4	main
elada	doc_532115409059_item	2675167	et	3	main
ilma	doc_532115409059_item	2675168	et	4	main
telerita	doc_532115409059_item	2675169	et	3	main
nad	doc_532115409059_item	2675170	et	3	main
vaatavad	doc_532115409059_item	2675171	et	4	main
saateid	doc_532115409059_item	2675172	et	3	main
ja	doc_532115409059_item	2675173	et	3	main
filme	doc_532115409059_item	2675174	et	3	main
huvitavad	doc_532115409059_item	2675154	et	4	main
on	doc_532115409059_item	2675156	et	4	main
ilma	doc_532115409059_item	2675182	et	4	main
telefonita	doc_532115409059_item	2675183	et	3	main
mobiiltelefonita	doc_532115409059_item	2675184	et	3	main
saa	doc_532115409059_item	2675193	et	4	main
see	doc_532115409059_item	2675195	et	3	main
elu	doc_532115409059_item	2675213	et	4	main
on	doc_532115409059_item	2675224	et	4	main
seda	doc_532115409059_item	2675226	et	3	main
autoga	doc_532115409059_item	2675230	et	3	main
kauplusesse	doc_532115409059_item	2675234	et	4	main
auto	doc_532115409059_item	2675247	et	4	main
siis	doc_532115409059_item	2675248	et	3	main
inseneer	doc_532115409059_item	2675261	et	4	main
oli	doc_532115409059_item	2675266	et	3	main
inimene	doc_532115409059_item	2675269	et	3	main
ei	doc_532115409059_item	2675274	et	4	main
internetist	doc_532115409060_item	2675330	et	4	main
mitmesuguseid	doc_532115409060_item	2675343	et	3	main
on	doc_532115409060_item	2675358	et	4	main
inimesed	doc_532115409060_item	2675374	et	3	main
kasutada	doc_532115409060_item	2675376	et	3	main
presintatsiooni	doc_532115409060_item	2675384	et	4	main
suhelda	doc_532115409060_item	2675387	et	4	main
sõpradega	doc_532115409060_item	2675389	et	3	main
kõik	doc_532115409060_item	2675390	et	4	main
otstarbekam	doc_532115409060_item	2675400	et	4	main
istuda	doc_532115409060_item	2675401	et	3	main
pole	doc_532115409060_item	2675426	et	3	main
viimane	doc_532115409060_item	2675428	et	3	main
leiutis	doc_532115409060_item	2675429	et	3	main
millise	doc_532115409060_item	2675430	et	3	main
ilma	doc_532115409061_item	2675434	et	4	main
ma	doc_532115409061_item	2675436	et	3	main
elada	doc_532115409061_item	2675439	et	3	main
kõigel	doc_532115409061_item	2675440	et	4	main
ei	doc_532115409061_item	2675442	et	4	main
ole	doc_532115409061_item	2675443	et	4	main
seda	doc_532115409061_item	2675444	et	3	main
leiutist	doc_532115409061_item	2675445	et	3	main
saaks	doc_532115409061_item	2675450	et	3	main
kui	doc_532115409061_item	2675453	et	3	main
õhkkondades	doc_532115409061_item	2675460	et	3	main
on	doc_532115409061_item	2675466	et	4	main
väga	doc_532115409061_item	2675467	et	3	main
sümboolne	doc_532115409061_item	2675468	et	3	main
see	doc_532115409061_item	2675469	et	3	main
tähendab	doc_532115409061_item	2675470	et	3	main
et	doc_532115409061_item	2675471	et	3	main
ilma	doc_532115409061_item	2675478	et	4	main
teema	doc_532115409061_item	2675485	et	4	main
nii	doc_532115409061_item	2675500	et	3	main
aga	doc_532115409061_item	2675502	et	3	main
muidugi	doc_532115409061_item	2675518	et	4	main
ilma	doc_532115409061_item	2675523	et	4	main
meie	doc_532115409061_item	2675540	et	4	main
selleks	doc_532115409061_item	2675547	et	4	main
et	doc_532115409061_item	2675548	et	3	main
palju	doc_532115409061_item	2675555	et	4	main
minu	doc_532115409061_item	2675556	et	3	main
omada	doc_532115409061_item	2675560	et	3	main
õppimine	doc_532115409062_item	2675610	et	4	main
tehnika	doc_532115409062_item	2675612	et	4	main
ma	doc_532115409062_item	2675618	et	3	main
õppisin	doc_532115409062_item	2675619	et	3	main
vene	doc_532115409062_item	2675620	et	4	main
ja	doc_532115409062_item	2675622	et	3	main
kui	doc_532115409062_item	2675629	et	3	main
mul	doc_532115409062_item	2675635	et	3	main
esimeseks	doc_532115409062_item	2675650	et	3	main
pean	doc_532115409062_item	2675652	et	4	main
kõik	doc_532115409062_item	2675653	et	4	main
mida	doc_532115409062_item	2675654	et	4	main
ainult	doc_532115409062_item	2675661	et	4	main
pärast	doc_532115409062_item	2675662	et	4	main
seda	doc_532115409062_item	2675663	et	3	main
võin	doc_532115409062_item	2675664	et	3	main
tihti	doc_532115409062_item	2675688	et	3	main
kasutab	doc_532115409062_item	2675691	et	3	main
ja	doc_532115409062_item	2675693	et	3	main
eesti	doc_532115409062_item	2675697	et	4	main
kõik	doc_532115409059_item	2675175	et	4	main
teised	doc_532115409059_item	2675178	et	4	main
on	doc_532115409059_item	2675187	et	4	main
leiutis	doc_532115409059_item	2675189	et	3	main
milleta	doc_532115409059_item	2675190	et	3	main
ta	doc_532115409059_item	2675191	et	4	main
on	doc_532115409059_item	2675196	et	4	main
mida	doc_532115409059_item	2675199	et	4	main
kasutab	doc_532115409059_item	2675201	et	3	main
iga	doc_532115409059_item	2675202	et	4	main
päev	doc_532115409059_item	2675203	et	3	main
ma	doc_532115409059_item	2675204	et	3	main
elan	doc_532115409059_item	2675205	et	3	main
oma	doc_532115409059_item	2675212	et	4	main
kuhugi	doc_532115409059_item	2675220	et	4	main
elada	doc_532115409059_item	2675194	et	3	main
sellepärast	doc_532115409059_item	2675209	et	3	main
kujuta	doc_532115409059_item	2675211	et	4	main
minna	doc_532115409059_item	2675221	et	3	main
mul	doc_532115409059_item	2675223	et	3	main
päeval	doc_532115409059_item	2675232	et	3	main
elavad	doc_532115409059_item	2675237	et	4	main
majalt	doc_532115409059_item	2675239	et	3	main
ma	doc_532115409059_item	2675249	et	3	main
suhelda	doc_532115409059_item	2675253	et	4	main
tea	doc_532115409059_item	2675256	et	4	main
et	doc_532115409059_item	2675264	et	3	main
tark	doc_532115409059_item	2675268	et	3	main
autod	doc_532115409059_item	2675272	et	3	main
ole	doc_532115409059_item	2675275	et	4	main
kui	doc_532115409059_item	2675278	et	3	main
autot	doc_532115409059_item	2675287	et	3	main
saame	doc_532115409060_item	2675322	et	4	main
infoallikas	doc_532115409060_item	2675329	et	4	main
leida	doc_532115409060_item	2675333	et	3	main
juhtida	doc_532115409060_item	2675342	et	4	main
protsesse	doc_532115409060_item	2675344	et	3	main
näha	doc_532115409060_item	2675347	et	3	main
kõik	doc_532115409060_item	2675351	et	4	main
inimesed	doc_532115409060_item	2675352	et	3	main
ma	doc_532115409060_item	2675360	et	3	main
arvan	doc_532115409060_item	2675361	et	3	main
on	doc_532115409060_item	2675364	et	4	main
suurepärane	doc_532115409060_item	2675365	et	4	main
kui	doc_532115409060_item	2675366	et	3	main
koolides	doc_532115409060_item	2675367	et	3	main
on	doc_532115409060_item	2675370	et	4	main
saalid	doc_532115409060_item	2675372	et	4	main
interneti	doc_532115409060_item	2675377	et	4	main
mis	doc_532115409060_item	2675378	et	4	main
minusse	doc_532115409060_item	2675379	et	3	main
puutub	doc_532115409060_item	2675380	et	3	main
teha	doc_532115409060_item	2675385	et	3	main
küll	doc_532115409060_item	2675393	et	4	main
arvuti	doc_532115409060_item	2675395	et	4	main
rikkub	doc_532115409060_item	2675396	et	4	main
meie	doc_532115409060_item	2675397	et	4	main
silmi	doc_532115409060_item	2675398	et	4	main
ja	doc_532115409060_item	2675421	et	3	main
usun	doc_532115409060_item	2675423	et	3	main
arvuti	doc_532115409060_item	2675425	et	4	main
elada	doc_532115409061_item	2675451	et	3	main
ma	doc_532115409061_item	2675456	et	3	main
milleta	doc_532115409061_item	2675479	et	3	main
võib	doc_532115409061_item	2675486	et	3	main
olla	doc_532115409061_item	2675487	et	3	main
tähendab	doc_532115409061_item	2675489	et	3	main
teistele	doc_532115409061_item	2675490	et	4	main
nad	doc_532115409061_item	2675491	et	3	main
elada	doc_532115409061_item	2675496	et	3	main
ilma	doc_532115409061_item	2675497	et	4	main
võib	doc_532115409061_item	2675506	et	3	main
õnnelikuks	doc_532115409061_item	2675508	et	3	main
adam	doc_532115409061_item	2675510	et	4	main
eva	doc_532115409061_item	2675512	et	4	main
tahan	doc_532115409061_item	2675513	et	3	main
sellega	doc_532115409061_item	2675514	et	3	main
leiutist	doc_532115409061_item	2675522	et	3	main
ei	doc_532115409061_item	2675526	et	4	main
ütlevad	doc_532115409061_item	2675533	et	4	main
mulle	doc_532115409061_item	2675534	et	4	main
et	doc_532115409061_item	2675535	et	3	main
see	doc_532115409061_item	2675536	et	3	main
vaja	doc_532115409061_item	2675553	et	4	main
mõelda	doc_532115409061_item	2675554	et	4	main
palju	doc_532115409061_item	2675559	et	4	main
vastata	doc_532115409061_item	2675564	et	4	main
meie	doc_532115409061_item	2675576	et	4	main
tallinna	doc_532115409062_item	2675611	et	4	main
keeles	doc_532115409062_item	2675616	et	4	main
on	doc_532115409062_item	2675625	et	4	main
õppida	doc_532115409062_item	2675627	et	3	main
siin	doc_532115409062_item	2675628	et	4	main
vene	doc_532115409062_item	2675633	et	4	main
õpetajat	doc_532115409062_item	2675649	et	4	main
vene	doc_532115409062_item	2675658	et	4	main
keeles	doc_532115409062_item	2675659	et	4	main
kooli	doc_532115409059_item	2675233	et	4	main
minu	doc_532115409059_item	2675238	et	3	main
kaugel	doc_532115409059_item	2675241	et	4	main
mul	doc_532115409059_item	2675244	et	3	main
ole	doc_532115409059_item	2675246	et	4	main
ma	doc_532115409059_item	2675254	et	3	main
kes	doc_532115409059_item	2675257	et	4	main
oli	doc_532115409059_item	2675258	et	3	main
esimene	doc_532115409059_item	2675259	et	3	main
auto	doc_532115409059_item	2675260	et	4	main
väga	doc_532115409059_item	2675267	et	3	main
meie	doc_532115409059_item	2675270	et	4	main
ajal	doc_532115409059_item	2675271	et	4	main
isele	doc_532115409059_item	2675285	et	4	main
tegis	doc_532115409059_item	2675289	et	4	main
minu	doc_532115409059_item	2675290	et	3	main
elu	doc_532115409059_item	2675291	et	4	main
natuke	doc_532115409059_item	2675292	et	4	main
lihtsam	doc_532115409059_item	2675293	et	4	main
ilma	doc_532115409060_item	2675295	et	4	main
milleta	doc_532115409060_item	2675296	et	3	main
ma	doc_532115409060_item	2675297	et	3	main
leiutised	doc_532115409060_item	2675294	et	3	main
ei	doc_532115409060_item	2675298	et	4	main
saaks	doc_532115409060_item	2675299	et	3	main
elada	doc_532115409060_item	2675300	et	3	main
minu	doc_532115409060_item	2675301	et	3	main
arvates	doc_532115409060_item	2675302	et	4	main
kõige	doc_532115409060_item	2675303	et	4	main
tähtsam	doc_532115409060_item	2675304	et	4	main
leiutis	doc_532115409060_item	2675305	et	3	main
ilma	doc_532115409060_item	2675306	et	4	main
milleta	doc_532115409060_item	2675307	et	3	main
inimene	doc_532115409060_item	2675308	et	3	main
ei	doc_532115409060_item	2675309	et	4	main
saaks	doc_532115409060_item	2675310	et	3	main
elada	doc_532115409060_item	2675311	et	3	main
on	doc_532115409060_item	2675312	et	4	main
arvuti	doc_532115409060_item	2675313	et	4	main
arvuti	doc_532115409060_item	2675314	et	4	main
aitab	doc_532115409060_item	2675315	et	3	main
meid	doc_532115409060_item	2675316	et	4	main
igapäevast	doc_532115409060_item	2675317	et	4	main
elust	doc_532115409060_item	2675318	et	3	main
arvuti	doc_532115409060_item	2675319	et	4	main
abil	doc_532115409060_item	2675320	et	4	main
interneti	doc_532115409060_item	2675324	et	4	main
on	doc_532115409060_item	2675331	et	4	main
surfata	doc_532115409060_item	2675345	et	4	main
filme	doc_532115409060_item	2675348	et	3	main
kasutada	doc_532115409060_item	2675354	et	3	main
et	doc_532115409060_item	2675362	et	3	main
ülikkolides	doc_532115409060_item	2675369	et	4	main
arvuti	doc_532115409060_item	2675381	et	4	main
aitab	doc_532115409060_item	2675382	et	3	main
ja	doc_532115409060_item	2675386	et	3	main
teame	doc_532115409060_item	2675392	et	3	main
et	doc_532115409060_item	2675394	et	3	main
on	doc_532115409060_item	2675399	et	4	main
umbes	doc_532115409060_item	2675406	et	4	main
kaks	doc_532115409060_item	2675407	et	3	main
tundi	doc_532115409060_item	2675408	et	4	main
ja	doc_532115409060_item	2675409	et	3	main
pärast	doc_532115409060_item	2675410	et	4	main
teha	doc_532115409060_item	2675411	et	3	main
ka	doc_532115409060_item	2675412	et	3	main
vaheaeg	doc_532115409060_item	2675413	et	3	main
me	doc_532115409060_item	2675414	et	4	main
elame	doc_532115409060_item	2675415	et	3	main
maailmas	doc_532115409060_item	2675416	et	3	main
kus	doc_532115409060_item	2675417	et	3	main
tehakse	doc_532115409060_item	2675418	et	3	main
palju	doc_532115409060_item	2675419	et	4	main
leiutisi	doc_532115409060_item	2675420	et	3	main
et	doc_532115409060_item	2675424	et	3	main
inimene	doc_532115409060_item	2675432	et	3	main
saaks	doc_532115409061_item	2675438	et	3	main
maailmal	doc_532115409061_item	2675441	et	3	main
ei	doc_532115409061_item	2675449	et	4	main
sest	doc_532115409061_item	2675452	et	4	main
sündisin	doc_532115409061_item	2675455	et	3	main
erinevates	doc_532115409061_item	2675459	et	4	main
inimene	doc_532115409061_item	2675461	et	3	main
ei	doc_532115409061_item	2675481	et	4	main
saaks	doc_532115409061_item	2675482	et	3	main
raske	doc_532115409061_item	2675495	et	4	main
telerita	doc_532115409061_item	2675498	et	3	main
ja	doc_532115409061_item	2675499	et	3	main
edasi	doc_532115409061_item	2675501	et	3	main
inimene	doc_532115409061_item	2675505	et	3	main
ja	doc_532115409061_item	2675511	et	3	main
öelda	doc_532115409061_item	2675515	et	4	main
veel	doc_532115409061_item	2675516	et	4	main
et	doc_532115409061_item	2675517	et	3	main
ma	doc_532115409061_item	2675525	et	3	main
saaks	doc_532115409061_item	2675527	et	3	main
inimesed	doc_532115409061_item	2675532	et	3	main
nii	doc_532115409061_item	2675539	et	3	main
meie	doc_532115409061_item	2675542	et	4	main
elus	doc_532115409061_item	2675544	et	4	main
mõttet	doc_532115409061_item	2675562	et	4	main
raske	doc_532115409061_item	2675566	et	4	main
kohta	doc_532115409061_item	2675568	et	4	main
mina	doc_532115409061_item	2675569	et	4	main
arvan	doc_532115409061_item	2675570	et	3	main
nii	doc_532115409061_item	2675571	et	3	main
võib	doc_532115409061_item	2675572	et	3	main
olla	doc_532115409061_item	2675573	et	3	main
paljudele	doc_532115409061_item	2675574	et	3	main
asjadele	doc_532115409061_item	2675575	et	3	main
kõrgkoolis	doc_532115409062_item	2675613	et	4	main
on	doc_532115409062_item	2675614	et	4	main
eesti	doc_532115409062_item	2675615	et	4	main
koolis	doc_532115409062_item	2675621	et	4	main
maailmas	doc_532115409060_item	2675341	et	3	main
pole	doc_532115409060_item	2675350	et	3	main
kallis	doc_532115409060_item	2675359	et	4	main
see	doc_532115409060_item	2675363	et	3	main
kus	doc_532115409060_item	2675373	et	3	main
saavad	doc_532115409060_item	2675375	et	4	main
oma	doc_532115409060_item	2675388	et	4	main
piiratud	doc_532115409060_item	2675404	et	4	main
koguses	doc_532115409060_item	2675405	et	4	main
ma	doc_532115409060_item	2675422	et	3	main
leiutised	doc_532115409061_item	2675433	et	3	main
milleta	doc_532115409061_item	2675435	et	3	main
ei	doc_532115409061_item	2675437	et	4	main
milleta	doc_532115409061_item	2675447	et	3	main
pean	doc_532115409061_item	2675457	et	4	main
inimene	doc_532115409061_item	2675472	et	3	main
peab	doc_532115409061_item	2675473	et	4	main
saavutama	doc_532115409061_item	2675474	et	3	main
kõike	doc_532115409061_item	2675475	et	4	main
ma	doc_532115409061_item	2675480	et	3	main
elada	doc_532115409061_item	2675483	et	3	main
palju	doc_532115409061_item	2675488	et	4	main
ohh	doc_532115409061_item	2675493	et	4	main
kui	doc_532115409061_item	2675494	et	3	main
ilma	doc_532115409061_item	2675503	et	4	main
elada	doc_532115409061_item	2675507	et	3	main
veel	doc_532115409060_item	2675427	et	4	main
avanes	doc_532115409060_item	2675431	et	3	main
ilma	doc_532115409061_item	2675446	et	4	main
ma	doc_532115409061_item	2675448	et	3	main
mina	doc_532115409061_item	2675454	et	4	main
elada	doc_532115409061_item	2675458	et	3	main
sündib	doc_532115409061_item	2675462	et	4	main
ilma	doc_532115409061_item	2675463	et	4	main
riietust	doc_532115409061_item	2675464	et	4	main
see	doc_532115409061_item	2675465	et	3	main
iseseisvalt	doc_532115409061_item	2675476	et	4	main
leiutis	doc_532115409061_item	2675477	et	3	main
see	doc_532115409061_item	2675484	et	3	main
arvavad	doc_532115409061_item	2675492	et	4	main
seda	doc_532115409061_item	2675504	et	3	main
nagu	doc_532115409061_item	2675509	et	3	main
ei	doc_532115409061_item	2675519	et	4	main
ole	doc_532115409061_item	2675520	et	4	main
seda	doc_532115409061_item	2675521	et	3	main
milleta	doc_532115409061_item	2675524	et	3	main
elada	doc_532115409061_item	2675528	et	3	main
võib	doc_532115409061_item	2675529	et	3	main
olla	doc_532115409061_item	2675530	et	3	main
paljud	doc_532115409061_item	2675531	et	3	main
ole	doc_532115409061_item	2675538	et	4	main
ajal	doc_532115409061_item	2675541	et	4	main
tänapäevuse	doc_532115409061_item	2675543	et	4	main
eksivad	doc_532115409061_item	2675545	et	4	main
küll	doc_532115409061_item	2675546	et	4	main
anda	doc_532115409061_item	2675549	et	3	main
oma	doc_532115409061_item	2675550	et	4	main
vastu	doc_532115409061_item	2675551	et	3	main
arvates	doc_532115409061_item	2675557	et	4	main
et	doc_532115409061_item	2675563	et	3	main
küsimuste	doc_532115409061_item	2675567	et	4	main
ei	doc_532115409061_item	2675537	et	4	main
on	doc_532115409061_item	2675552	et	4	main
on	doc_532115409061_item	2675558	et	4	main
filosoofilisi	doc_532115409061_item	2675561	et	4	main
selle	doc_532115409061_item	2675565	et	4	main
elus	doc_532115409061_item	2675577	et	4	main
tuleb	doc_532115409061_item	2675578	et	3	main
suhtuma	doc_532115409061_item	2675579	et	3	main
fülosoofiliselt	doc_532115409061_item	2675580	et	4	main
see	doc_532115409061_item	2675581	et	3	main
on	doc_532115409061_item	2675582	et	4	main
minu	doc_532115409061_item	2675583	et	3	main
isiklik	doc_532115409061_item	2675584	et	3	main
arvamus	doc_532115409061_item	2675585	et	3	main
ja	doc_532115409061_item	2675586	et	3	main
ma	doc_532115409061_item	2675587	et	3	main
ei	doc_532115409061_item	2675588	et	4	main
tahaksin	doc_532115409061_item	2675589	et	3	main
mitte	doc_532115409061_item	2675590	et	3	main
keegi	doc_532115409061_item	2675591	et	4	main
kahetseda	doc_532115409061_item	2675592	et	3	main
või	doc_532115409061_item	2675593	et	4	main
kahju	doc_532115409061_item	2675594	et	4	main
teha	doc_532115409061_item	2675595	et	3	main
mida	doc_532115409062_item	2675596	et	4	main
ma	doc_532115409062_item	2675597	et	3	main
tahaksin	doc_532115409062_item	2675598	et	3	main
õppida	doc_532115409062_item	2675599	et	3	main
eesti	doc_532115409062_item	2675600	et	4	main
keele	doc_532115409062_item	2675601	et	4	main
tundides	doc_532115409062_item	2675602	et	3	main
hiljuti	doc_532115409062_item	2675603	et	4	main
ma	doc_532115409062_item	2675604	et	3	main
astusin	doc_532115409062_item	2675605	et	3	main
õppida	doc_532115409062_item	2675606	et	3	main
tallinna	doc_532115409062_item	2675607	et	4	main
tehnika	doc_532115409062_item	2675608	et	4	main
kõrgkoolisse	doc_532115409062_item	2675609	et	4	main
enne	doc_532115409062_item	2675617	et	4	main
sellepärast	doc_532115409062_item	2675623	et	3	main
oliksid	doc_532115409062_item	2675632	et	4	main
õppimisega	doc_532115409062_item	2675640	et	4	main
aga	doc_532115409062_item	2675641	et	3	main
nüüd	doc_532115409062_item	2675642	et	4	main
kui	doc_532115409062_item	2675643	et	3	main
ma	doc_532115409062_item	2675644	et	3	main
istun	doc_532115409062_item	2675645	et	3	main
tunnis	doc_532115409062_item	2675646	et	3	main
ja	doc_532115409062_item	2675647	et	3	main
kuulan	doc_532115409062_item	2675648	et	3	main
ta	doc_532115409062_item	2675655	et	4	main
ütleb	doc_532115409062_item	2675656	et	3	main
tõlkima	doc_532115409062_item	2675657	et	3	main
mõtelda	doc_532115409062_item	2675665	et	4	main
oma	doc_532115409062_item	2675689	et	4	main
termineid	doc_532115409062_item	2675692	et	3	main
ma	doc_532115409062_item	2675696	et	3	main
tundides	doc_532115409062_item	2675717	et	3	main
mul	doc_532115409062_item	2675624	et	3	main
raske	doc_532115409062_item	2675626	et	4	main
kõik	doc_532115409062_item	2675630	et	4	main
ained	doc_532115409062_item	2675631	et	3	main
ei	doc_532115409062_item	2675637	et	4	main
probleeme	doc_532115409062_item	2675639	et	3	main
ja	doc_532115409062_item	2675660	et	3	main
kõige	doc_532115409062_item	2675667	et	4	main
raskemad	doc_532115409062_item	2675668	et	4	main
ained	doc_532115409062_item	2675669	et	3	main
on	doc_532115409062_item	2675670	et	4	main
füüsika	doc_532115409062_item	2675671	et	4	main
kujutav	doc_532115409062_item	2675672	et	4	main
geomeetria	doc_532115409062_item	2675673	et	4	main
ja	doc_532115409062_item	2675674	et	3	main
ehitusmaterjalid	doc_532115409062_item	2675675	et	3	main
ma	doc_532115409062_item	2675676	et	3	main
ei	doc_532115409062_item	2675677	et	4	main
saa	doc_532115409062_item	2675678	et	4	main
aru	doc_532115409062_item	2675679	et	4	main
üht	doc_532115409062_item	2675680	et	3	main
poolt	doc_532115409062_item	2675681	et	4	main
mida	doc_532115409062_item	2675682	et	4	main
räägib	doc_532115409062_item	2675683	et	3	main
õpetaja	doc_532115409062_item	2675684	et	4	main
sest	doc_532115409062_item	2675685	et	4	main
ta	doc_532115409062_item	2675686	et	4	main
väga	doc_532115409062_item	2675687	et	3	main
keeles	doc_532115409062_item	2675634	et	4	main
üldse	doc_532115409062_item	2675636	et	3	main
ole	doc_532115409062_item	2675638	et	4	main
ma	doc_532115409062_item	2675651	et	3	main
definitsiooneid	doc_532115409062_item	2675694	et	4	main
õpetajad	doc_532115409062_item	2675702	et	4	main
mõned	doc_532115409062_item	2675706	et	3	main
veel	doc_532115409062_item	2675713	et	4	main
eesti	doc_532115409062_item	2675715	et	4	main
keele	doc_532115409062_item	2675716	et	4	main
erialaaine	doc_532115409062_item	2675722	et	4	main
kuidas	doc_532115409062_item	2675724	et	3	main
hooneosasid	doc_532115409062_item	2675727	et	4	main
on	doc_532115409062_item	2675731	et	4	main
minu	doc_532115409062_item	2675734	et	3	main
riigi	doc_532115409063_item	2675761	et	3	main
kui	doc_532115409063_item	2675764	et	3	main
võimalus	doc_532115409063_item	2675766	et	3	main
mitte	doc_532115409063_item	2675768	et	3	main
saada	doc_532115409063_item	2675818	et	4	main
aga	doc_532115409063_item	2675821	et	3	main
oleks	doc_532115409063_item	2675824	et	3	main
näiteks	doc_532115409063_item	2675833	et	4	main
rääkida	doc_532115409063_item	2675836	et	3	main
meil	doc_532115409063_item	2675842	et	4	main
ilmus	doc_532115409063_item	2675843	et	4	main
räägitakse	doc_532115409063_item	2675852	et	3	main
kuulsatest	doc_532115409063_item	2675854	et	3	main
heliloojatest	doc_532115409063_item	2675858	et	4	main
edasi	doc_532115409063_item	2675862	et	3	main
keelet	doc_532115409063_item	2675868	et	4	main
teada	doc_532115409063_item	2675872	et	3	main
mida	doc_532115409064_item	2675879	et	4	main
ma	doc_532115409064_item	2675880	et	3	main
tahan	doc_532115409064_item	2675881	et	3	main
vene	doc_532115409064_item	2675895	et	4	main
ainetest	doc_532115409062_item	2675666	et	4	main
rääkimises	doc_532115409062_item	2675690	et	4	main
tea	doc_532115409062_item	2675700	et	4	main
mõned	doc_532115409062_item	2675701	et	3	main
räägivad	doc_532115409062_item	2675703	et	3	main
kiiresti	doc_532115409062_item	2675705	et	3	main
vaikselt	doc_532115409062_item	2675708	et	4	main
ja	doc_532115409062_item	2675709	et	3	main
see	doc_532115409062_item	2675710	et	3	main
teeb	doc_532115409062_item	2675711	et	3	main
ma	doc_532115409062_item	2675718	et	3	main
rohkem	doc_532115409062_item	2675720	et	4	main
õppida	doc_532115409062_item	2675721	et	3	main
instrumente	doc_532115409062_item	2675729	et	3	main
see	doc_532115409062_item	2675730	et	3	main
mida	doc_532115409063_item	2675737	et	4	main
ma	doc_532115409063_item	2675738	et	3	main
tahaksin	doc_532115409063_item	2675739	et	3	main
õppida	doc_532115409063_item	2675740	et	3	main
eesti	doc_532115409063_item	2675741	et	4	main
mõtlesin	doc_532115409063_item	2675751	et	3	main
hea	doc_532115409063_item	2675754	et	4	main
kui	doc_532115409063_item	2675755	et	3	main
kedagi	doc_532115409063_item	2675756	et	4	main
aitas	doc_532115409063_item	2675757	et	3	main
meie	doc_532115409063_item	2675760	et	4	main
mul	doc_532115409063_item	2675823	et	3	main
poleks	doc_532115409063_item	2675831	et	3	main
keele	doc_532115409063_item	2675845	et	4	main
ja	doc_532115409063_item	2675846	et	3	main
rahva	doc_532115409063_item	2675847	et	3	main
vastu	doc_532115409063_item	2675848	et	3	main
eesti	doc_532115409063_item	2675853	et	4	main
luuletajatest	doc_532115409063_item	2675856	et	4	main
kui	doc_532115409063_item	2675863	et	3	main
me	doc_532115409063_item	2675864	et	4	main
on	doc_532115409063_item	2675870	et	4	main
saada	doc_532115409063_item	2675873	et	4	main
kultuuri	doc_532115409063_item	2675874	et	4	main
siis	doc_532115409063_item	2675875	et	3	main
õppida	doc_532115409064_item	2675882	et	3	main
eesti	doc_532115409064_item	2675883	et	4	main
tallinnas	doc_532115409064_item	2675890	et	4	main
emakeel	doc_532115409064_item	2675893	et	4	main
on	doc_532115409064_item	2675894	et	4	main
kooli	doc_532115409064_item	2675898	et	4	main
lõpetamist	doc_532115409064_item	2675899	et	4	main
ma	doc_532115409064_item	2675900	et	3	main
astusin	doc_532115409064_item	2675901	et	3	main
meie	doc_532115409064_item	2675925	et	4	main
keele	doc_532115409064_item	2675927	et	4	main
tundides	doc_532115409064_item	2675928	et	3	main
ma	doc_532115409064_item	2675929	et	3	main
kõige	doc_532115409064_item	2675939	et	4	main
kohtusin	doc_532115409064_item	2675944	et	4	main
minu	doc_532115409064_item	2675946	et	3	main
sest	doc_532115409064_item	2675957	et	4	main
vaja	doc_532115409064_item	2675960	et	4	main
veel	doc_532115409064_item	2675965	et	4	main
eesti	doc_532115409064_item	2676001	et	4	main
ise	doc_532115409064_item	2676009	et	4	main
tahab	doc_532115409064_item	2676010	et	3	main
ja	doc_532115409064_item	2676011	et	3	main
hakkab	doc_532115409064_item	2676012	et	3	main
kõik	doc_532115409064_item	2676013	et	4	main
ilma	doc_532115409064_item	2676020	et	4	main
inimene	doc_532115409064_item	2676030	et	3	main
isegi	doc_532115409064_item	2676034	et	4	main
eesti	doc_532115409064_item	2676036	et	4	main
minu	doc_532115409065_item	2676050	et	3	main
leiutis	doc_532115409065_item	2676052	et	3	main
meie	doc_532115409065_item	2676093	et	4	main
tähtsam	doc_532115409065_item	2676101	et	4	main
osa	doc_532115409065_item	2676105	et	4	main
internetis	doc_532115409065_item	2676115	et	4	main
istuda	doc_532115409065_item	2676116	et	3	main
siin	doc_532115409065_item	2676117	et	4	main
ma	doc_532115409065_item	2676118	et	3	main
ilma	doc_532115409065_item	2676124	et	4	main
olnud	doc_532115409065_item	2676132	et	4	main
elektriga	doc_532115409065_item	2676137	et	3	main
ei	doc_532115409065_item	2676147	et	4	main
keeles	doc_532115409062_item	2675698	et	4	main
väga	doc_532115409062_item	2675704	et	3	main
väga	doc_532115409062_item	2675707	et	3	main
tahaksin	doc_532115409062_item	2675719	et	3	main
kõik	doc_532115409062_item	2675726	et	4	main
keele	doc_532115409063_item	2675742	et	4	main
tundides	doc_532115409063_item	2675743	et	3	main
eesti	doc_532115409063_item	2675744	et	4	main
keele	doc_532115409063_item	2675745	et	4	main
tund	doc_532115409063_item	2675746	et	3	main
pole	doc_532115409063_item	2675747	et	3	main
kohustuslik	doc_532115409063_item	2675748	et	3	main
aga	doc_532115409063_item	2675749	et	3	main
ma	doc_532115409063_item	2675750	et	3	main
oleks	doc_532115409063_item	2675753	et	3	main
natukene	doc_532115409063_item	2675759	et	4	main
ja	doc_532115409063_item	2675763	et	3	main
miks	doc_532115409063_item	2675767	et	4	main
seda	doc_532115409063_item	2675770	et	3	main
minu	doc_532115409063_item	2675771	et	3	main
keele	doc_532115409063_item	2675774	et	4	main
tunne	doc_532115409063_item	2675844	et	4	main
meil	doc_532115409063_item	2675851	et	4	main
näitlejatest	doc_532115409063_item	2675855	et	4	main
kunstnikutest	doc_532115409063_item	2675859	et	3	main
meil	doc_532115409063_item	2675869	et	4	main
vaja	doc_532115409063_item	2675871	et	4	main
tore	doc_532115409063_item	2675878	et	3	main
mina	doc_532115409064_item	2675886	et	4	main
pärit	doc_532115409064_item	2675888	et	3	main
minu	doc_532115409064_item	2675892	et	3	main
on	doc_532115409064_item	2675921	et	4	main
mida	doc_532115409064_item	2675923	et	4	main
eesti	doc_532115409064_item	2675926	et	4	main
gi	doc_532115409064_item	2675931	et	4	main
rohkem	doc_532115409064_item	2675932	et	4	main
õppida	doc_532115409064_item	2675933	et	3	main
teaduse	doc_532115409064_item	2675934	et	3	main
terminid	doc_532115409064_item	2675935	et	3	main
millega	doc_532115409064_item	2675942	et	3	main
loengutel	doc_532115409064_item	2675945	et	4	main
meeles	doc_532115409064_item	2675947	et	3	main
ole	doc_532115409064_item	2675951	et	4	main
nii	doc_532115409064_item	2675952	et	3	main
väärtuslik	doc_532115409064_item	2675953	et	3	main
kui	doc_532115409064_item	2675954	et	3	main
sõnade	doc_532115409064_item	2675955	et	3	main
õppetud	doc_532115409064_item	2675988	et	4	main
sõnaühendid	doc_532115409064_item	2675989	et	3	main
mõelda	doc_532115409064_item	2675992	et	4	main
kuidas	doc_532115409064_item	2675993	et	3	main
lause	doc_532115409064_item	2675994	et	4	main
teha	doc_532115409064_item	2675995	et	3	main
minu	doc_532115409064_item	2676005	et	3	main
meeles	doc_532115409064_item	2676006	et	3	main
inimene	doc_532115409064_item	2676008	et	3	main
õppida	doc_532115409064_item	2676017	et	3	main
siis	doc_532115409064_item	2676018	et	3	main
kahtlust	doc_532115409064_item	2676021	et	4	main
arusaama	doc_532115409064_item	2676023	et	4	main
keeles	doc_532115409064_item	2676027	et	4	main
aga	doc_532115409064_item	2676028	et	3	main
kui	doc_532115409064_item	2676029	et	3	main
tundid	doc_532115409064_item	2676038	et	4	main
midagi	doc_532115409064_item	2676042	et	4	main
mida	doc_532115409065_item	2676043	et	4	main
ma	doc_532115409065_item	2676044	et	3	main
tahaksin	doc_532115409065_item	2676045	et	3	main
õppida	doc_532115409065_item	2676046	et	3	main
eesti	doc_532115409065_item	2676047	et	4	main
milleta	doc_532115409065_item	2676054	et	3	main
ei	doc_532115409065_item	2676071	et	4	main
üldse	doc_532115409065_item	2676073	et	3	main
ja	doc_532115409065_item	2676076	et	3	main
elasid	doc_532115409065_item	2676082	et	4	main
ilma	doc_532115409065_item	2676085	et	4	main
on	doc_532115409065_item	2676089	et	4	main
teistmoodi	doc_532115409065_item	2676090	et	3	main
ja	doc_532115409065_item	2676091	et	3	main
präegu	doc_532115409065_item	2676092	et	4	main
leiutisi	doc_532115409065_item	2676098	et	3	main
aga	doc_532115409065_item	2676099	et	3	main
mida	doc_532115409062_item	2675695	et	4	main
ei	doc_532115409062_item	2675699	et	4	main
kuulamist	doc_532115409062_item	2675712	et	4	main
raskem	doc_532115409062_item	2675714	et	4	main
keel	doc_532115409062_item	2675723	et	4	main
väga	doc_532115409062_item	2675732	et	3	main
tulevikus	doc_532115409062_item	2675735	et	4	main
töös	doc_532115409062_item	2675736	et	3	main
et	doc_532115409063_item	2675752	et	3	main
keelega	doc_532115409063_item	2675762	et	3	main
eesti	doc_532115409063_item	2675773	et	4	main
on	doc_532115409063_item	2675776	et	4	main
vaja	doc_532115409063_item	2675777	et	4	main
õppida	doc_532115409063_item	2675778	et	3	main
materjali	doc_532115409063_item	2675779	et	4	main
mitte	doc_532115409063_item	2675780	et	3	main
nagu	doc_532115409063_item	2675781	et	3	main
kõigest	doc_532115409063_item	2675819	et	4	main
konspekt	doc_532115409063_item	2675825	et	3	main
prooviksin	doc_532115409063_item	2675827	et	3	main
seda	doc_532115409063_item	2675829	et	3	main
paha	doc_532115409063_item	2675832	et	4	main
traditsioonist	doc_532115409063_item	2675838	et	3	main
ja	doc_532115409063_item	2675839	et	3	main
kommest	doc_532115409063_item	2675840	et	4	main
et	doc_532115409063_item	2675841	et	3	main
võib	doc_532115409063_item	2675849	et	3	main
ja	doc_532115409063_item	2675860	et	3	main
tahame	doc_532115409063_item	2675865	et	3	main
õppida	doc_532115409063_item	2675866	et	3	main
eesti	doc_532115409063_item	2675867	et	4	main
on	doc_532115409063_item	2675877	et	4	main
tundides	doc_532115409064_item	2675885	et	3	main
olen	doc_532115409064_item	2675887	et	3	main
eestit	doc_532115409064_item	2675889	et	3	main
aga	doc_532115409064_item	2675891	et	3	main
pärast	doc_532115409064_item	2675897	et	4	main
arusaamine	doc_532115409064_item	2675922	et	4	main
sest	doc_532115409064_item	2675936	et	4	main
need	doc_532115409064_item	2675937	et	3	main
on	doc_532115409064_item	2675938	et	4	main
rühmade	doc_532115409064_item	2675962	et	3	main
rääkida	doc_532115409064_item	2675964	et	3	main
enamasti	doc_532115409064_item	2675996	et	4	main
meie	doc_532115409064_item	2676000	et	4	main
keele	doc_532115409064_item	2676002	et	4	main
reeglid	doc_532115409064_item	2676016	et	3	main
nimetatakse	doc_532115409062_item	2675725	et	3	main
materjalid	doc_532115409062_item	2675728	et	3	main
vajalik	doc_532115409062_item	2675733	et	3	main
meid	doc_532115409063_item	2675758	et	4	main
on	doc_532115409063_item	2675765	et	4	main
kasutada	doc_532115409063_item	2675769	et	3	main
arvates	doc_532115409063_item	2675772	et	4	main
tundides	doc_532115409063_item	2675775	et	3	main
koolis	doc_532115409063_item	2675782	et	4	main
aga	doc_532115409063_item	2675783	et	3	main
teada	doc_532115409063_item	2675784	et	3	main
saada	doc_532115409063_item	2675785	et	4	main
rohkem	doc_532115409063_item	2675786	et	4	main
uusi	doc_532115409063_item	2675787	et	3	main
sõnu	doc_532115409063_item	2675788	et	4	main
mis	doc_532115409063_item	2675789	et	4	main
on	doc_532115409063_item	2675790	et	4	main
seotud	doc_532115409063_item	2675791	et	4	main
meie	doc_532115409063_item	2675792	et	4	main
erialaga	doc_532115409063_item	2675793	et	3	main
ja	doc_532115409063_item	2675794	et	3	main
ainetega	doc_532115409063_item	2675795	et	3	main
näiteks	doc_532115409063_item	2675796	et	4	main
oleks	doc_532115409063_item	2675797	et	3	main
kasulik	doc_532115409063_item	2675798	et	3	main
õppida	doc_532115409063_item	2675799	et	3	main
matemaatika	doc_532115409063_item	2675800	et	4	main
ja	doc_532115409063_item	2675801	et	3	main
füüsika	doc_532115409063_item	2675802	et	4	main
termineid	doc_532115409063_item	2675803	et	3	main
kõige	doc_532115409063_item	2675804	et	4	main
raskem	doc_532115409063_item	2675805	et	4	main
tund	doc_532115409063_item	2675806	et	3	main
minu	doc_532115409063_item	2675807	et	3	main
jaoks	doc_532115409063_item	2675808	et	4	main
füüsika	doc_532115409063_item	2675810	et	4	main
ma	doc_532115409063_item	2675811	et	3	main
on	doc_532115409063_item	2675809	et	4	main
ei	doc_532115409063_item	2675812	et	4	main
jõua	doc_532115409063_item	2675813	et	4	main
nii	doc_532115409063_item	2675814	et	3	main
kiiresti	doc_532115409063_item	2675815	et	3	main
konspekteerida	doc_532115409063_item	2675816	et	3	main
ja	doc_532115409063_item	2675817	et	3	main
aru	doc_532115409063_item	2675820	et	4	main
kui	doc_532115409063_item	2675822	et	3	main
ma	doc_532115409063_item	2675826	et	3	main
mõista	doc_532115409063_item	2675828	et	4	main
veel	doc_532115409063_item	2675830	et	4	main
üks	doc_532115409063_item	2675834	et	3	main
tund	doc_532115409063_item	2675835	et	3	main
eesti	doc_532115409063_item	2675837	et	4	main
olla	doc_532115409063_item	2675850	et	3	main
kirjanikutest	doc_532115409063_item	2675857	et	3	main
nii	doc_532115409063_item	2675861	et	3	main
kõik	doc_532115409063_item	2675876	et	4	main
keele	doc_532115409064_item	2675884	et	4	main
keel	doc_532115409064_item	2675896	et	4	main
tallinna	doc_532115409064_item	2675902	et	4	main
tehnika	doc_532115409064_item	2675903	et	4	main
kõrgkooli	doc_532115409064_item	2675904	et	4	main
arhitektuuri	doc_532115409064_item	2675905	et	4	main
osakonnale	doc_532115409064_item	2675906	et	4	main
siin	doc_532115409064_item	2675907	et	4	main
kõik	doc_532115409064_item	2675908	et	4	main
loengud	doc_532115409064_item	2675909	et	3	main
toimuvad	doc_532115409064_item	2675910	et	4	main
eesti	doc_532115409064_item	2675911	et	4	main
keeles	doc_532115409064_item	2675912	et	4	main
ja	doc_532115409064_item	2675913	et	3	main
see	doc_532115409064_item	2675914	et	3	main
pärast	doc_532115409064_item	2675915	et	4	main
ma	doc_532115409064_item	2675916	et	3	main
mõtlen	doc_532115409064_item	2675917	et	3	main
et	doc_532115409064_item	2675918	et	3	main
kõige	doc_532115409064_item	2675919	et	4	main
tähtsam	doc_532115409064_item	2675920	et	4	main
sulle	doc_532115409064_item	2675924	et	3	main
ma	doc_532115409064_item	2675943	et	3	main
grammaatika	doc_532115409064_item	2675948	et	4	main
praegu	doc_532115409064_item	2675949	et	3	main
ei	doc_532115409064_item	2675950	et	4	main
mul	doc_532115409064_item	2675958	et	3	main
kaaslastega	doc_532115409064_item	2675963	et	4	main
ja	doc_532115409064_item	2675990	et	3	main
tundid	doc_532115409064_item	2676003	et	4	main
sõnad	doc_532115409064_item	2676014	et	4	main
tal	doc_532115409064_item	2676019	et	3	main
taha	doc_532115409064_item	2676032	et	4	main
ei	doc_532115409064_item	2676039	et	4	main
keele	doc_532115409065_item	2676048	et	4	main
ilma	doc_532115409065_item	2676053	et	4	main
ma	doc_532115409065_item	2676055	et	3	main
olnud	doc_532115409065_item	2676072	et	4	main
vahendeid	doc_532115409065_item	2676075	et	3	main
päris	doc_532115409065_item	2676083	et	4	main
tänapäevane	doc_532115409065_item	2676087	et	4	main
elu	doc_532115409065_item	2676088	et	4	main
elekter	doc_532115409065_item	2676103	et	3	main
mida	doc_532115409065_item	2676107	et	4	main
me	doc_532115409065_item	2676108	et	4	main
kasutame	doc_532115409065_item	2676109	et	3	main
vajab	doc_532115409065_item	2676110	et	3	main
elektri	doc_532115409065_item	2676111	et	3	main
mulle	doc_532115409065_item	2676112	et	4	main
meeldib	doc_532115409065_item	2676113	et	3	main
arvutis	doc_532115409065_item	2676114	et	4	main
lemmik	doc_532115409065_item	2676121	et	3	main
tahaksin	doc_532115409064_item	2675930	et	3	main
raskemad	doc_532115409064_item	2675940	et	4	main
asjad	doc_532115409064_item	2675941	et	3	main
varu	doc_532115409064_item	2675956	et	4	main
on	doc_532115409064_item	2675959	et	4	main
oma	doc_532115409064_item	2675961	et	4	main
mõtlen	doc_532115409064_item	2675967	et	3	main
mina	doc_532115409064_item	2675966	et	4	main
et	doc_532115409064_item	2675968	et	3	main
oleks	doc_532115409064_item	2675969	et	3	main
paremini	doc_532115409064_item	2675970	et	4	main
kui	doc_532115409064_item	2675971	et	3	main
me	doc_532115409064_item	2675972	et	4	main
õppesime	doc_532115409064_item	2675973	et	4	main
mitte	doc_532115409064_item	2675974	et	3	main
reeglid	doc_532115409064_item	2675975	et	3	main
kuidas	doc_532115409064_item	2675976	et	3	main
rääkida	doc_532115409064_item	2675977	et	3	main
ja	doc_532115409064_item	2675978	et	3	main
kirjutada	doc_532115409064_item	2675979	et	3	main
õigesti	doc_532115409064_item	2675980	et	3	main
aga	doc_532115409064_item	2675981	et	3	main
õppesime	doc_532115409064_item	2675982	et	4	main
sõnaühendid	doc_532115409064_item	2675983	et	3	main
on	doc_532115409064_item	2675984	et	4	main
väga	doc_532115409064_item	2675985	et	3	main
lihtsam	doc_532115409064_item	2675986	et	4	main
kasutada	doc_532115409064_item	2675987	et	3	main
mitte	doc_532115409064_item	2675991	et	3	main
mulle	doc_532115409064_item	2675997	et	4	main
meeldib	doc_532115409064_item	2675998	et	3	main
kuidas	doc_532115409064_item	2675999	et	3	main
toimuvad	doc_532115409064_item	2676004	et	4	main
kui	doc_532115409064_item	2676007	et	3	main
ja	doc_532115409064_item	2676015	et	3	main
õnnestub	doc_532115409064_item	2676022	et	3	main
rääkima	doc_532115409064_item	2676025	et	3	main
selles	doc_532115409064_item	2676026	et	4	main
siis	doc_532115409064_item	2676033	et	3	main
head	doc_532115409064_item	2676035	et	4	main
keele	doc_532115409064_item	2676037	et	4	main
tee	doc_532115409064_item	2676040	et	4	main
mitte	doc_532115409064_item	2676041	et	3	main
tundides	doc_532115409065_item	2676049	et	3	main
ööelda	doc_532115409065_item	2676079	et	4	main
et	doc_532115409065_item	2676080	et	3	main
nad	doc_532115409065_item	2676081	et	3	main
seda	doc_532115409065_item	2676086	et	3	main
on	doc_532115409065_item	2676095	et	4	main
palju	doc_532115409065_item	2676096	et	4	main
selliseid	doc_532115409065_item	2676097	et	4	main
suurem	doc_532115409065_item	2676104	et	4	main
asjadest	doc_532115409065_item	2676106	et	3	main
muusikat	doc_532115409065_item	2676122	et	3	main
meil	doc_532115409065_item	2676130	et	4	main
trolli	doc_532115409065_item	2676135	et	4	main
ma	doc_532115409065_item	2676138	et	3	main
televiisorit	doc_532115409065_item	2676140	et	3	main
ilma	doc_532115409065_item	2676144	et	4	main
elektri	doc_532115409065_item	2676145	et	3	main
valgustusi	doc_532115409065_item	2676149	et	4	main
iga	doc_532115409065_item	2676152	et	4	main
päev	doc_532115409065_item	2676153	et	3	main
hetk	doc_532115409065_item	2676155	et	3	main
me	doc_532115409065_item	2676156	et	4	main
kasutame	doc_532115409065_item	2676157	et	3	main
elektrivahendeid	doc_532115409065_item	2676158	et	3	main
gi	doc_532115409065_item	2676176	et	4	main
ja	doc_532115409064_item	2676024	et	3	main
ei	doc_532115409064_item	2676031	et	4	main
meeles	doc_532115409065_item	2676051	et	3	main
ei	doc_532115409065_item	2676056	et	4	main
saaks	doc_532115409065_item	2676057	et	3	main
elada	doc_532115409065_item	2676058	et	3	main
elekter	doc_532115409065_item	2676060	et	3	main
on	doc_532115409065_item	2676059	et	4	main
ja	doc_532115409065_item	2676061	et	3	main
kõik	doc_532115409065_item	2676062	et	4	main
mida	doc_532115409065_item	2676063	et	4	main
sellega	doc_532115409065_item	2676064	et	3	main
kaasneb	doc_532115409065_item	2676065	et	3	main
mitme	doc_532115409065_item	2676066	et	4	main
kümneid	doc_532115409065_item	2676067	et	4	main
aastat	doc_532115409065_item	2676068	et	3	main
tagasi	doc_532115409065_item	2676069	et	3	main
inimesel	doc_532115409065_item	2676070	et	3	main
elektri	doc_532115409065_item	2676074	et	3	main
me	doc_532115409065_item	2676077	et	4	main
võime	doc_532115409065_item	2676078	et	4	main
hästi	doc_532115409065_item	2676084	et	3	main
maailmas	doc_532115409065_item	2676094	et	3	main
on	doc_532115409065_item	2676102	et	4	main
saan	doc_532115409065_item	2676119	et	4	main
ja	doc_532115409065_item	2676134	et	3	main
saan	doc_532115409065_item	2676139	et	4	main
vaadata	doc_532115409065_item	2676141	et	4	main
iga	doc_532115409065_item	2676142	et	4	main
päev	doc_532115409065_item	2676143	et	3	main
meie	doc_532115409065_item	2676159	et	4	main
lähe	doc_532115409065_item	2676164	et	4	main
me	doc_532115409065_item	2676173	et	4	main
ei	doc_532115409065_item	2676174	et	4	main
kohvi	doc_532115409065_item	2676177	et	4	main
teed	doc_532115409065_item	2676179	et	4	main
juua	doc_532115409065_item	2676180	et	3	main
see	doc_532115409065_item	2676181	et	3	main
pärast	doc_532115409065_item	2676182	et	4	main
saaks	doc_532115409065_item	2676194	et	3	main
tahaksin	doc_532115409066_item	2676198	et	3	main
eesti	doc_532115409066_item	2676200	et	4	main
ma	doc_532115409066_item	2676221	et	3	main
väga	doc_532115409066_item	2676223	et	3	main
mida	doc_532115409066_item	2676228	et	4	main
tahan	doc_532115409066_item	2676230	et	3	main
õppida	doc_532115409066_item	2676231	et	3	main
eesti	doc_532115409066_item	2676232	et	4	main
mulle	doc_532115409066_item	2676241	et	4	main
sest	doc_532115409066_item	2676248	et	4	main
nad	doc_532115409066_item	2676249	et	3	main
põhinetakse	doc_532115409066_item	2676250	et	3	main
ja	doc_532115409066_item	2676261	et	3	main
arusaamist	doc_532115409066_item	2676276	et	4	main
mina	doc_532115409066_item	2676277	et	4	main
tahan	doc_532115409066_item	2676278	et	3	main
füüsikas	doc_532115409066_item	2676284	et	3	main
paberil	doc_532115409066_item	2676296	et	3	main
aga	doc_532115409066_item	2676297	et	3	main
palju	doc_532115409066_item	2676299	et	4	main
vaja	doc_532115409066_item	2676311	et	4	main
kõne	doc_532115409066_item	2676321	et	4	main
on	doc_532115409066_item	2676336	et	4	main
õppejõuaga	doc_532115409066_item	2676341	et	4	main
keskkoolis	doc_532115409066_item	2676354	et	4	main
12	doc_532115409066_item	2676355	et	2	main
aastat	doc_532115409066_item	2676356	et	3	main
teame	doc_532115409066_item	2676362	et	3	main
kujutada	doc_532115409066_item	2676371	et	3	main
ma	doc_532115409066_item	2676374	et	3	main
aastat	doc_532115409066_item	2676377	et	3	main
keele	doc_532115409066_item	2676392	et	4	main
õppida	doc_532115409066_item	2676399	et	3	main
ole	doc_532115409066_item	2676407	et	4	main
tähtis	doc_532115409066_item	2676408	et	4	main
õigesti	doc_532115409066_item	2676409	et	3	main
ma	doc_532115409066_item	2676410	et	3	main
räägin	doc_532115409066_item	2676411	et	3	main
kõik	doc_532115409066_item	2676432	et	4	main
keeles	doc_532115409066_item	2676442	et	4	main
see	doc_532115409066_item	2676445	et	3	main
mida	doc_532115409067_item	2676448	et	4	main
mis	doc_532115409067_item	2676461	et	4	main
kõik	doc_532115409067_item	2676469	et	4	main
need	doc_532115409067_item	2676470	et	3	main
uued	doc_532115409067_item	2676471	et	3	main
terminid	doc_532115409067_item	2676472	et	3	main
mis	doc_532115409067_item	2676473	et	4	main
meile	doc_532115409067_item	2676499	et	4	main
lektor	doc_532115409067_item	2676500	et	3	main
saada	doc_532115409067_item	2676509	et	4	main
füüsika	doc_532115409067_item	2676513	et	4	main
väga	doc_532115409067_item	2676517	et	3	main
tund	doc_532115409067_item	2676519	et	3	main
kõige	doc_532115409065_item	2676100	et	4	main
oma	doc_532115409065_item	2676120	et	4	main
kuulada	doc_532115409065_item	2676123	et	4	main
elektri	doc_532115409065_item	2676125	et	3	main
linn	doc_532115409065_item	2676127	et	3	main
ei	doc_532115409065_item	2676131	et	4	main
koos	doc_532115409065_item	2676136	et	4	main
meil	doc_532115409065_item	2676146	et	4	main
toodet	doc_532115409065_item	2676162	et	3	main
ei	doc_532115409065_item	2676163	et	4	main
halvaks	doc_532115409065_item	2676165	et	4	main
kohvi	doc_532115409065_item	2676166	et	4	main
masin	doc_532115409065_item	2676167	et	3	main
ja	doc_532115409065_item	2676168	et	3	main
elektri	doc_532115409065_item	2676169	et	3	main
veekeetja	doc_532115409065_item	2676170	et	4	main
elada	doc_532115409065_item	2676195	et	3	main
tundides	doc_532115409066_item	2676202	et	3	main
tänapäeval	doc_532115409066_item	2676203	et	3	main
ma	doc_532115409066_item	2676204	et	3	main
õpin	doc_532115409066_item	2676205	et	3	main
õppeasutuses	doc_532115409066_item	2676206	et	4	main
kus	doc_532115409066_item	2676207	et	3	main
mulle	doc_532115409066_item	2676208	et	4	main
antakse	doc_532115409066_item	2676209	et	3	main
võimalust	doc_532115409066_item	2676210	et	3	main
õppida	doc_532115409066_item	2676211	et	3	main
eesti	doc_532115409066_item	2676212	et	4	main
keelt	doc_532115409066_item	2676213	et	4	main
õppimine	doc_532115409066_item	2676214	et	4	main
ttk-s	doc_532115409066_item	2676215	et	3	main
toimub	doc_532115409066_item	2676216	et	3	main
ainult	doc_532115409066_item	2676217	et	4	main
eesti	doc_532115409066_item	2676218	et	4	main
keeles	doc_532115409066_item	2676219	et	4	main
ja	doc_532115409066_item	2676220	et	3	main
rõõmus	doc_532115409066_item	2676224	et	4	main
aidatakse	doc_532115409066_item	2676226	et	4	main
protsessis	doc_532115409066_item	2676243	et	4	main
keskkooli	doc_532115409066_item	2676251	et	4	main
12	doc_532115409066_item	2676255	et	2	main
õppeaine	doc_532115409066_item	2676275	et	4	main
põhitermineid	doc_532115409066_item	2676283	et	3	main
matemaatikas	doc_532115409066_item	2676286	et	3	main
kirjutatud	doc_532115409066_item	2676295	et	4	main
meile	doc_532115409066_item	2676298	et	4	main
suulise	doc_532115409066_item	2676302	et	4	main
siis	doc_532115409066_item	2676304	et	3	main
ei	doc_532115409066_item	2676306	et	4	main
saa	doc_532115409066_item	2676307	et	4	main
lugeda	doc_532115409066_item	2676308	et	3	main
ja	doc_532115409066_item	2676309	et	3	main
meie	doc_532115409065_item	2676126	et	4	main
suri	doc_532115409065_item	2676128	et	3	main
välja	doc_532115409065_item	2676129	et	4	main
trammi	doc_532115409065_item	2676133	et	4	main
kogu	doc_532115409065_item	2676150	et	4	main
maailmas	doc_532115409065_item	2676151	et	3	main
iga	doc_532115409065_item	2676154	et	4	main
kus	doc_532115409065_item	2676161	et	3	main
ilma	doc_532115409065_item	2676171	et	4	main
selleta	doc_532115409065_item	2676172	et	3	main
mina	doc_532115409065_item	2676183	et	4	main
mõtlen	doc_532115409065_item	2676184	et	3	main
et	doc_532115409065_item	2676185	et	3	main
elekter	doc_532115409065_item	2676186	et	3	main
on	doc_532115409065_item	2676187	et	4	main
niisugune	doc_532115409065_item	2676188	et	3	main
leiutis	doc_532115409065_item	2676189	et	3	main
ilma	doc_532115409065_item	2676190	et	4	main
mida	doc_532115409066_item	2676196	et	4	main
ma	doc_532115409066_item	2676197	et	3	main
õppida	doc_532115409066_item	2676199	et	3	main
keele	doc_532115409066_item	2676233	et	4	main
tundides	doc_532115409066_item	2676234	et	3	main
õppimise	doc_532115409066_item	2676242	et	4	main
ma	doc_532115409066_item	2676253	et	3	main
õppisin	doc_532115409066_item	2676254	et	3	main
kõik	doc_532115409066_item	2676257	et	4	main
suur	doc_532115409066_item	2676288	et	3	main
et	doc_532115409066_item	2676290	et	3	main
mõista	doc_532115409066_item	2676292	et	4	main
mis	doc_532115409066_item	2676293	et	4	main
on	doc_532115409066_item	2676310	et	4	main
kuulda	doc_532115409066_item	2676319	et	4	main
eakad	doc_532115409066_item	2676325	et	3	main
raske	doc_532115409066_item	2676329	et	4	main
aru	doc_532115409066_item	2676330	et	4	main
nii	doc_532115409066_item	2676340	et	3	main
seas	doc_532115409066_item	2676353	et	4	main
reegleid	doc_532115409066_item	2676364	et	3	main
rääkida	doc_532115409066_item	2676369	et	3	main
12	doc_532115409066_item	2676376	et	2	main
eesti	doc_532115409066_item	2676378	et	4	main
ja	doc_532115409066_item	2676380	et	3	main
ei	doc_532115409066_item	2676381	et	4	main
mõista	doc_532115409066_item	2676386	et	4	main
jaoks	doc_532115409066_item	2676388	et	4	main
tundid	doc_532115409066_item	2676393	et	4	main
suur	doc_532115409066_item	2676397	et	3	main
rääkida	doc_532115409066_item	2676401	et	3	main
keeles	doc_532115409066_item	2676403	et	4	main
alguses	doc_532115409066_item	2676404	et	4	main
see	doc_532115409066_item	2676405	et	3	main
või	doc_532115409066_item	2676412	et	4	main
olnud	doc_532115409065_item	2676148	et	4	main
külmkapp	doc_532115409065_item	2676160	et	3	main
saanud	doc_532115409065_item	2676175	et	4	main
või	doc_532115409065_item	2676178	et	4	main
milleta	doc_532115409065_item	2676191	et	3	main
ma	doc_532115409065_item	2676192	et	3	main
ei	doc_532115409065_item	2676193	et	4	main
keele	doc_532115409066_item	2676201	et	4	main
olen	doc_532115409066_item	2676222	et	3	main
esimeseks	doc_532115409066_item	2676235	et	3	main
see	doc_532115409066_item	2676236	et	3	main
õppeaine	doc_532115409066_item	2676237	et	4	main
muidugi	doc_532115409066_item	2676238	et	4	main
kõige	doc_532115409066_item	2676244	et	4	main
ei	doc_532115409066_item	2676262	et	4	main
raskem	doc_532115409066_item	2676274	et	4	main
keele	doc_532115409066_item	2676280	et	4	main
tundides	doc_532115409066_item	2676281	et	3	main
õppida	doc_532115409066_item	2676282	et	3	main
või	doc_532115409066_item	2676285	et	4	main
teine	doc_532115409066_item	2676287	et	3	main
probleem	doc_532115409066_item	2676289	et	3	main
kergem	doc_532115409066_item	2676291	et	4	main
on	doc_532115409066_item	2676294	et	4	main
loenguid	doc_532115409066_item	2676300	et	4	main
ma	doc_532115409066_item	2676305	et	3	main
eesti	doc_532115409066_item	2676320	et	4	main
lektorid	doc_532115409066_item	2676323	et	3	main
neid	doc_532115409066_item	2676327	et	4	main
kui	doc_532115409066_item	2676342	et	3	main
ka	doc_532115409066_item	2676343	et	3	main
see	doc_532115409066_item	2676347	et	3	main
meid	doc_532115409066_item	2676357	et	4	main
grammatikat	doc_532115409066_item	2676360	et	3	main
ei	doc_532115409066_item	2676367	et	4	main
et	doc_532115409066_item	2676373	et	3	main
keelt	doc_532115409066_item	2676379	et	4	main
saa	doc_532115409066_item	2676382	et	4	main
rääkida	doc_532115409066_item	2676383	et	3	main
siis	doc_532115409066_item	2676384	et	3	main
mille	doc_532115409066_item	2676387	et	3	main
mul	doc_532115409066_item	2676389	et	3	main
olid	doc_532115409066_item	2676390	et	4	main
eesti	doc_532115409066_item	2676391	et	4	main
mul	doc_532115409066_item	2676394	et	3	main
ei	doc_532115409066_item	2676406	et	4	main
mind	doc_532115409066_item	2676421	et	4	main
arvan	doc_532115409066_item	2676423	et	3	main
ja	doc_532115409066_item	2676424	et	3	main
välja	doc_532115409066_item	2676427	et	4	main
see	doc_532115409066_item	2676430	et	3	main
on	doc_532115409066_item	2676431	et	4	main
õppida	doc_532115409066_item	2676440	et	3	main
mind	doc_532115409066_item	2676447	et	4	main
ma	doc_532115409067_item	2676449	et	3	main
tahaksin	doc_532115409067_item	2676450	et	3	main
mis	doc_532115409067_item	2676466	et	4	main
on	doc_532115409067_item	2676467	et	4	main
hooneteehitus	doc_532115409067_item	2676468	et	4	main
vaja	doc_532115409067_item	2676475	et	4	main
ja	doc_532115409067_item	2676478	et	3	main
tähendused	doc_532115409067_item	2676480	et	4	main
mis	doc_532115409067_item	2676497	et	4	main
räägib	doc_532115409067_item	2676498	et	3	main
sellest	doc_532115409067_item	2676504	et	4	main
on	doc_532115409067_item	2676506	et	4	main
aru	doc_532115409067_item	2676508	et	4	main
põhiterminitest	doc_532115409067_item	2676512	et	3	main
on	doc_532115409067_item	2676515	et	4	main
sest	doc_532115409067_item	2676520	et	4	main
tunnil	doc_532115409067_item	2676525	et	3	main
rääkijatele	doc_532115409067_item	2676536	et	4	main
sest	doc_532115409067_item	2676537	et	4	main
ma	doc_532115409067_item	2676538	et	3	main
need	doc_532115409067_item	2676554	et	3	main
läheks	doc_532115409067_item	2676574	et	3	main
ja	doc_532115409067_item	2676576	et	3	main
rohkem	doc_532115409067_item	2676579	et	4	main
eesti	doc_532115409067_item	2676581	et	4	main
keelt	doc_532115409067_item	2676582	et	4	main
tundides	doc_532115409068_item	2676589	et	3	main
saladus	doc_532115409068_item	2676592	et	3	main
et	doc_532115409066_item	2676225	et	3	main
õppimises	doc_532115409066_item	2676227	et	4	main
ma	doc_532115409066_item	2676229	et	3	main
peab	doc_532115409066_item	2676239	et	4	main
aitama	doc_532115409066_item	2676240	et	3	main
raskem	doc_532115409066_item	2676245	et	4	main
õppida	doc_532115409066_item	2676246	et	3	main
üldaineid	doc_532115409066_item	2676247	et	3	main
teadmistel	doc_532115409066_item	2676252	et	4	main
aastat	doc_532115409066_item	2676256	et	3	main
termineid	doc_532115409066_item	2676258	et	3	main
vene	doc_532115409066_item	2676259	et	4	main
keeles	doc_532115409066_item	2676260	et	4	main
saa	doc_532115409066_item	2676263	et	4	main
aru	doc_532115409066_item	2676264	et	4	main
kuidas	doc_532115409066_item	2676265	et	3	main
mulle	doc_532115409066_item	2676266	et	4	main
õppejõud	doc_532115409066_item	2676267	et	4	main
räägib	doc_532115409066_item	2676268	et	3	main
neid	doc_532115409066_item	2676269	et	4	main
eesti	doc_532115409066_item	2676270	et	4	main
keeles	doc_532115409066_item	2676271	et	4	main
see	doc_532115409066_item	2676272	et	3	main
teeb	doc_532115409066_item	2676273	et	3	main
eesti	doc_532115409066_item	2676279	et	4	main
antakse	doc_532115409066_item	2676301	et	3	main
vormis	doc_532115409066_item	2676303	et	4	main
kuulda	doc_532115409066_item	2676312	et	4	main
arvan	doc_532115409066_item	2676313	et	3	main
et	doc_532115409066_item	2676314	et	3	main
oleks	doc_532115409066_item	2676315	et	3	main
väga	doc_532115409066_item	2676316	et	3	main
kasulik	doc_532115409066_item	2676317	et	3	main
rohkem	doc_532115409066_item	2676318	et	4	main
on	doc_532115409066_item	2676324	et	4	main
ja	doc_532115409066_item	2676326	et	3	main
rohkem	doc_532115409066_item	2676337	et	4	main
rääkida	doc_532115409066_item	2676338	et	3	main
vestelda	doc_532115409066_item	2676339	et	4	main
kaaslastega	doc_532115409066_item	2676344	et	4	main
et	doc_532115409066_item	2676346	et	3	main
ainult	doc_532115409066_item	2676359	et	4	main
me	doc_532115409066_item	2676361	et	4	main
siiski	doc_532115409066_item	2676366	et	4	main
saa	doc_532115409066_item	2676368	et	4	main
ette	doc_532115409066_item	2676372	et	4	main
õppisin	doc_532115409066_item	2676375	et	3	main
raske	doc_532115409066_item	2676385	et	4	main
on	doc_532115409066_item	2676395	et	4	main
palve	doc_532115409066_item	2676398	et	4	main
just	doc_532115409066_item	2676400	et	3	main
tähtsam	doc_532115409066_item	2676414	et	4	main
kõik	doc_532115409066_item	2676425	et	4	main
teise	doc_532115409066_item	2676441	et	4	main
on	doc_532115409067_item	2676462	et	4	main
edasi	doc_532115409067_item	2676476	et	3	main
uued	doc_532115409067_item	2676479	et	3	main
on	doc_532115409067_item	2676481	et	4	main
tunnis	doc_532115409067_item	2676489	et	3	main
mul	doc_532115409067_item	2676490	et	3	main
on	doc_532115409067_item	2676491	et	4	main
saada	doc_532115409067_item	2676494	et	4	main
ja	doc_532115409067_item	2676501	et	3	main
tund	doc_532115409067_item	2676514	et	3	main
kõik	doc_532115409067_item	2676521	et	4	main
on	doc_532115409067_item	2676526	et	4	main
arusaamatu	doc_532115409067_item	2676527	et	4	main
eesti	doc_532115409067_item	2676529	et	4	main
rääkijatele	doc_532115409067_item	2676531	et	4	main
kui	doc_532115409067_item	2676532	et	3	main
ka	doc_532115409067_item	2676533	et	3	main
vene	doc_532115409067_item	2676534	et	4	main
ainsad	doc_532115409067_item	2676557	et	3	main
tunnis	doc_532115409067_item	2676565	et	3	main
aga	doc_532115409067_item	2676566	et	3	main
kõige	doc_532115409067_item	2676567	et	4	main
olulisem	doc_532115409067_item	2676568	et	4	main
on	doc_532115409067_item	2676569	et	4	main
et	doc_532115409067_item	2676570	et	3	main
see	doc_532115409067_item	2676571	et	3	main
mida	doc_532115409068_item	2676583	et	4	main
ma	doc_532115409068_item	2676584	et	3	main
tahaksin	doc_532115409068_item	2676585	et	3	main
õppida	doc_532115409068_item	2676586	et	3	main
eesti	doc_532115409068_item	2676587	et	4	main
venelased	doc_532115409068_item	2676601	et	3	main
see	doc_532115409068_item	2676602	et	3	main
tähendab	doc_532115409068_item	2676603	et	3	main
õppida	doc_532115409068_item	2676622	et	3	main
nimekirja	doc_532115409068_item	2676634	et	4	main
suhelda	doc_532115409068_item	2676649	et	4	main
me	doc_532115409068_item	2676656	et	4	main
meid	doc_532115409068_item	2676671	et	4	main
keeles	doc_532115409068_item	2676678	et	4	main
õppida	doc_532115409068_item	2676682	et	3	main
kolmandaks	doc_532115409068_item	2676684	et	4	main
just	doc_532115409068_item	2676696	et	3	main
peame	doc_532115409068_item	2676723	et	4	main
viiendaks	doc_532115409068_item	2676729	et	4	main
on	doc_532115409068_item	2676740	et	4	main
väga	doc_532115409068_item	2676741	et	3	main
tähtis	doc_532115409068_item	2676742	et	4	main
kirjutama	doc_532115409068_item	2676747	et	3	main
ilma	doc_532115409069_item	2676756	et	4	main
me	doc_532115409069_item	2676762	et	4	main
elame	doc_532115409069_item	2676763	et	3	main
paljud	doc_532115409066_item	2676322	et	3	main
üldse	doc_532115409066_item	2676328	et	3	main
saada	doc_532115409066_item	2676331	et	4	main
ja	doc_532115409066_item	2676332	et	3	main
kolmas	doc_532115409066_item	2676333	et	3	main
minu	doc_532115409066_item	2676334	et	3	main
soov	doc_532115409066_item	2676335	et	3	main
arvan	doc_532115409066_item	2676345	et	3	main
on	doc_532115409066_item	2676348	et	4	main
väga	doc_532115409066_item	2676349	et	3	main
suur	doc_532115409066_item	2676350	et	3	main
probleem	doc_532115409066_item	2676351	et	3	main
venelaste	doc_532115409066_item	2676352	et	4	main
õpetati	doc_532115409066_item	2676358	et	3	main
palju	doc_532115409066_item	2676363	et	4	main
aga	doc_532115409066_item	2676365	et	3	main
kui	doc_532115409066_item	2676370	et	3	main
väga	doc_532115409066_item	2676396	et	3	main
eesti	doc_532115409066_item	2676402	et	4	main
mitte	doc_532115409066_item	2676413	et	3	main
ei	doc_532115409066_item	2676415	et	4	main
karda	doc_532115409066_item	2676416	et	4	main
rääkida	doc_532115409066_item	2676417	et	3	main
aga	doc_532115409066_item	2676418	et	3	main
eestlased	doc_532115409066_item	2676419	et	3	main
parandavad	doc_532115409066_item	2676420	et	4	main
niisugune	doc_532115409066_item	2676433	et	3	main
aine	doc_532115409066_item	2676434	et	4	main
antakse	doc_532115409066_item	2676435	et	3	main
meile	doc_532115409066_item	2676436	et	4	main
et	doc_532115409066_item	2676437	et	3	main
oleks	doc_532115409066_item	2676438	et	3	main
loodan	doc_532115409066_item	2676443	et	3	main
et	doc_532115409066_item	2676444	et	3	main
aitab	doc_532115409066_item	2676446	et	3	main
tahaks	doc_532115409067_item	2676458	et	3	main
seotud	doc_532115409067_item	2676463	et	4	main
minu	doc_532115409067_item	2676464	et	3	main
õppimisel	doc_532115409067_item	2676477	et	4	main
tõlke	doc_532115409067_item	2676487	et	4	main
ökonoomika	doc_532115409067_item	2676488	et	4	main
aru	doc_532115409067_item	2676493	et	4	main
et	doc_532115409067_item	2676502	et	3	main
ka	doc_532115409067_item	2676516	et	3	main
raske	doc_532115409067_item	2676518	et	4	main
sellel	doc_532115409067_item	2676524	et	4	main
nii	doc_532115409067_item	2676528	et	3	main
keele	doc_532115409067_item	2676530	et	4	main
ei	doc_532115409067_item	2676539	et	4	main
tea	doc_532115409067_item	2676540	et	4	main
kas	doc_532115409067_item	2676541	et	3	main
oleks	doc_532115409067_item	2676542	et	3	main
keele	doc_532115409067_item	2676551	et	4	main
tundides	doc_532115409067_item	2676552	et	3	main
minu	doc_532115409067_item	2676556	et	3	main
soovid	doc_532115409067_item	2676558	et	4	main
ma	doc_532115409067_item	2676560	et	3	main
tahaks	doc_532115409067_item	2676561	et	3	main
õpida	doc_532115409067_item	2676562	et	4	main
ei	doc_532115409067_item	2676573	et	4	main
ma	doc_532115409067_item	2676577	et	3	main
saaksin	doc_532115409067_item	2676578	et	3	main
teada	doc_532115409067_item	2676580	et	3	main
keele	doc_532115409068_item	2676588	et	4	main
pole	doc_532115409068_item	2676591	et	3	main
õpilased	doc_532115409068_item	2676595	et	3	main
on	doc_532115409068_item	2676600	et	4	main
et	doc_532115409068_item	2676604	et	3	main
meil	doc_532115409068_item	2676605	et	4	main
keele	doc_532115409068_item	2676624	et	4	main
tundides	doc_532115409068_item	2676625	et	3	main
esiteks	doc_532115409068_item	2676626	et	3	main
oleks	doc_532115409068_item	2676627	et	3	main
kui	doc_532115409068_item	2676629	et	3	main
te	doc_532115409068_item	2676630	et	4	main
eestlased	doc_532115409068_item	2676636	et	3	main
ma	doc_532115409066_item	2676422	et	3	main
tuleb	doc_532115409066_item	2676426	et	3	main
arvan	doc_532115409066_item	2676428	et	3	main
et	doc_532115409066_item	2676429	et	3	main
kergem	doc_532115409066_item	2676439	et	4	main
õppida	doc_532115409067_item	2676451	et	3	main
eesti	doc_532115409067_item	2676452	et	4	main
keele	doc_532115409067_item	2676453	et	4	main
tundides	doc_532115409067_item	2676454	et	3	main
eesti	doc_532115409067_item	2676455	et	4	main
keele	doc_532115409067_item	2676456	et	4	main
tunnis	doc_532115409067_item	2676457	et	3	main
õpida	doc_532115409067_item	2676459	et	4	main
kõike	doc_532115409067_item	2676460	et	4	main
erialaga	doc_532115409067_item	2676465	et	3	main
on	doc_532115409067_item	2676474	et	4	main
vaja	doc_532115409067_item	2676482	et	4	main
teada	doc_532115409067_item	2676483	et	3	main
nende	doc_532115409067_item	2676484	et	4	main
tähendust	doc_532115409067_item	2676485	et	4	main
ja	doc_532115409067_item	2676486	et	3	main
raske	doc_532115409067_item	2676492	et	4	main
selle	doc_532115409067_item	2676495	et	4	main
teksti	doc_532115409067_item	2676496	et	4	main
vabaneda	doc_532115409067_item	2676503	et	3	main
probleemist	doc_532115409067_item	2676505	et	4	main
vaja	doc_532115409067_item	2676507	et	4	main
kõikidest	doc_532115409067_item	2676510	et	4	main
nendest	doc_532115409067_item	2676511	et	4	main
mis	doc_532115409067_item	2676522	et	4	main
põhiliselt	doc_532115409067_item	2676553	et	4	main
keele	doc_532115409067_item	2676564	et	4	main
et	doc_532115409068_item	2676593	et	3	main
raskused	doc_532115409068_item	2676607	et	4	main
tahan	doc_532115409068_item	2676621	et	3	main
eesti	doc_532115409068_item	2676623	et	4	main
tore	doc_532115409068_item	2676628	et	3	main
millised	doc_532115409068_item	2676635	et	3	main
kõige	doc_532115409068_item	2676638	et	4	main
ja	doc_532115409068_item	2676640	et	3	main
kui	doc_532115409068_item	2676641	et	3	main
neid	doc_532115409068_item	2676644	et	4	main
siis	doc_532115409068_item	2676645	et	3	main
on	doc_532115409068_item	2676647	et	4	main
kergem	doc_532115409068_item	2676648	et	4	main
venelastega	doc_532115409068_item	2676654	et	4	main
rohkem	doc_532115409068_item	2676658	et	4	main
dialooge	doc_532115409068_item	2676667	et	3	main
peame	doc_532115409068_item	2676675	et	4	main
me	doc_532115409068_item	2676680	et	4	main
tahame	doc_532115409068_item	2676681	et	3	main
teadmise	doc_532115409068_item	2676690	et	4	main
pärast	doc_532115409068_item	2676692	et	4	main
jaani	doc_532115409068_item	2676693	et	4	main
aga	doc_532115409068_item	2676698	et	3	main
loomulikult	doc_532115409068_item	2676721	et	4	main
meie	doc_532115409068_item	2676726	et	4	main
leksikat	doc_532115409068_item	2676728	et	3	main
rohkem	doc_532115409068_item	2676746	et	4	main
mida	doc_532115409068_item	2676751	et	4	main
kirjutada	doc_532115409068_item	2676754	et	3	main
hoida	doc_532115409069_item	2676773	et	3	main
saavad	doc_532115409069_item	2676786	et	4	main
saad	doc_532115409069_item	2676800	et	4	main
on	doc_532115409069_item	2676803	et	4	main
sul	doc_532115409069_item	2676804	et	3	main
võimalus	doc_532115409069_item	2676805	et	3	main
omandada	doc_532115409069_item	2676806	et	3	main
huvitavamaid	doc_532115409069_item	2676807	et	4	main
teadmisi	doc_532115409069_item	2676808	et	4	main
kui	doc_532115409069_item	2676809	et	3	main
sa	doc_532115409069_item	2676810	et	3	main
mulle	doc_532115409069_item	2676814	et	4	main
sest	doc_532115409069_item	2676821	et	4	main
ei	doc_532115409069_item	2676823	et	4	main
ole	doc_532115409069_item	2676824	et	4	main
näema	doc_532115409069_item	2676828	et	4	main
oleks	doc_532115409069_item	2676836	et	3	main
selleta	doc_532115409069_item	2676838	et	3	main
elada	doc_532115409069_item	2676839	et	3	main
ma	doc_532115409069_item	2676846	et	3	main
väga	doc_532115409069_item	2676861	et	3	main
sest	doc_532115409069_item	2676866	et	4	main
sul	doc_532115409069_item	2676869	et	3	main
saada	doc_532115409069_item	2676873	et	4	main
kuidas	doc_532115409069_item	2676904	et	3	main
ma	doc_532115409069_item	2676907	et	3	main
sõber	doc_532115409069_item	2676918	et	3	main
või	doc_532115409069_item	2676919	et	4	main
ei	doc_532115409069_item	2676928	et	4	main
saate	doc_532115409069_item	2676929	et	4	main
räägivad	doc_532115409069_item	2676948	et	3	main
ja	doc_532115409069_item	2676952	et	3	main
on	doc_532115409069_item	2676954	et	4	main
toimub	doc_532115409067_item	2676523	et	3	main
keele	doc_532115409067_item	2676535	et	4	main
sellest	doc_532115409067_item	2676543	et	4	main
kasu	doc_532115409067_item	2676544	et	4	main
kui	doc_532115409067_item	2676545	et	3	main
me	doc_532115409067_item	2676546	et	4	main
õpiksime	doc_532115409067_item	2676547	et	3	main
ka	doc_532115409067_item	2676548	et	3	main
seda	doc_532115409067_item	2676549	et	3	main
eesti	doc_532115409067_item	2676550	et	4	main
on	doc_532115409067_item	2676555	et	4	main
mis	doc_532115409067_item	2676559	et	4	main
eesti	doc_532115409067_item	2676563	et	4	main
tund	doc_532115409067_item	2676572	et	3	main
raisku	doc_532115409067_item	2676575	et	4	main
see	doc_532115409068_item	2676590	et	3	main
kõik	doc_532115409068_item	2676594	et	4	main
kes	doc_532115409068_item	2676596	et	4	main
kirjutavad	doc_532115409068_item	2676597	et	4	main
seda	doc_532115409068_item	2676598	et	3	main
esse	doc_532115409068_item	2676599	et	3	main
eesti	doc_532115409068_item	2676608	et	4	main
keeles	doc_532115409068_item	2676609	et	4	main
ja	doc_532115409068_item	2676610	et	3	main
me	doc_532115409068_item	2676611	et	4	main
peame	doc_532115409068_item	2676612	et	4	main
viibima	doc_532115409068_item	2676614	et	3	main
ja	doc_532115409068_item	2676615	et	3	main
ma	doc_532115409068_item	2676616	et	3	main
tundi	doc_532115409068_item	2676613	et	4	main
tahan	doc_532115409068_item	2676617	et	3	main
kirjutada	doc_532115409068_item	2676618	et	3	main
mida	doc_532115409068_item	2676619	et	4	main
ma	doc_532115409068_item	2676620	et	3	main
annate	doc_532115409068_item	2676631	et	3	main
meile	doc_532115409068_item	2676632	et	4	main
sõnade	doc_532115409068_item	2676633	et	3	main
kasutavad	doc_532115409068_item	2676637	et	4	main
tihedam	doc_532115409068_item	2676639	et	4	main
ainult	doc_532115409068_item	2676653	et	4	main
me	doc_532115409068_item	2676664	et	4	main
koostame	doc_532115409068_item	2676665	et	3	main
aga	doc_532115409068_item	2676668	et	3	main
küsite	doc_532115409068_item	2676670	et	3	main
me	doc_532115409068_item	2676674	et	4	main
eesti	doc_532115409068_item	2676677	et	4	main
näiteksmiks	doc_532115409068_item	2676691	et	3	main
nimetatakse	doc_532115409068_item	2676695	et	3	main
mitte	doc_532115409068_item	2676699	et	3	main
teadma	doc_532115409068_item	2676724	et	3	main
tehnilist	doc_532115409068_item	2676727	et	3	main
peame	doc_532115409068_item	2676731	et	4	main
kasutada	doc_532115409068_item	2676732	et	3	main
ja	doc_532115409068_item	2676743	et	3	main
me	doc_532115409068_item	2676744	et	4	main
see	doc_532115409068_item	2676748	et	3	main
ma	doc_532115409068_item	2676752	et	3	main
leiutised	doc_532115409069_item	2676755	et	3	main
ei	doc_532115409069_item	2676759	et	4	main
elada	doc_532115409069_item	2676761	et	3	main
muutus	doc_532115409069_item	2676766	et	4	main
kiiresti	doc_532115409069_item	2676767	et	3	main
ja	doc_532115409069_item	2676768	et	3	main
ainult	doc_532115409069_item	2676769	et	4	main
üks	doc_532115409069_item	2676770	et	3	main
leiutis	doc_532115409069_item	2676771	et	3	main
saab	doc_532115409069_item	2676772	et	3	main
ajakirjad	doc_532115409069_item	2676782	et	3	main
vananemaks	doc_532115409069_item	2676783	et	3	main
on	doc_532115409068_item	2676606	et	4	main
me	doc_532115409068_item	2676642	et	4	main
eestlastega	doc_532115409068_item	2676650	et	4	main
aga	doc_532115409068_item	2676651	et	3	main
teiseks	doc_532115409068_item	2676655	et	4	main
peame	doc_532115409068_item	2676657	et	4	main
suhelda	doc_532115409068_item	2676659	et	4	main
võiks	doc_532115409068_item	2676660	et	4	main
olla	doc_532115409068_item	2676661	et	3	main
tore	doc_532115409068_item	2676662	et	3	main
kui	doc_532115409068_item	2676663	et	3	main
erinevatelt	doc_532115409068_item	2676672	et	4	main
rääkida	doc_532115409068_item	2676676	et	3	main
kui	doc_532115409068_item	2676679	et	3	main
ttk-s	doc_532115409068_item	2676683	et	3	main
me	doc_532115409068_item	2676685	et	4	main
peame	doc_532115409068_item	2676686	et	4	main
teadma	doc_532115409068_item	2676687	et	3	main
nii	doc_532115409068_item	2676697	et	3	main
miks	doc_532115409068_item	2676701	et	4	main
eestlased	doc_532115409068_item	2676702	et	3	main
armastavad	doc_532115409068_item	2676703	et	4	main
süüa	doc_532115409068_item	2676704	et	3	main
verivorsti	doc_532115409068_item	2676705	et	4	main
jõuludeks	doc_532115409068_item	2676706	et	3	main
ma	doc_532115409068_item	2676707	et	3	main
arvan	doc_532115409068_item	2676708	et	3	main
et	doc_532115409068_item	2676709	et	3	main
kõik	doc_532115409068_item	2676710	et	4	main
see	doc_532115409068_item	2676711	et	3	main
informatsioon	doc_532115409068_item	2676712	et	3	main
on	doc_532115409068_item	2676713	et	4	main
väga	doc_532115409068_item	2676714	et	3	main
tähtis	doc_532115409068_item	2676715	et	4	main
ja	doc_532115409068_item	2676716	et	3	main
loomulikult	doc_532115409068_item	2676717	et	4	main
huvitav	doc_532115409068_item	2676718	et	4	main
ka	doc_532115409068_item	2676719	et	3	main
neljandaks	doc_532115409068_item	2676720	et	4	main
õpime	doc_532115409068_item	2676643	et	3	main
meile	doc_532115409068_item	2676646	et	4	main
mitte	doc_532115409068_item	2676652	et	3	main
igasuguseid	doc_532115409068_item	2676666	et	3	main
teie	doc_532115409068_item	2676669	et	4	main
teemadelt	doc_532115409068_item	2676673	et	3	main
erinevade	doc_532115409068_item	2676688	et	4	main
kultuuri	doc_532115409068_item	2676689	et	4	main
päeva	doc_532115409068_item	2676694	et	4	main
teisiti	doc_532115409068_item	2676700	et	3	main
me	doc_532115409068_item	2676722	et	4	main
peame	doc_532115409068_item	2676745	et	4	main
kõik	doc_532115409068_item	2676750	et	4	main
tahan	doc_532115409068_item	2676753	et	3	main
ma	doc_532115409069_item	2676758	et	3	main
missugune	doc_532115409069_item	2676765	et	3	main
hästi	doc_532115409069_item	2676776	et	3	main
nii	doc_532115409069_item	2676784	et	3	main
ja	doc_532115409069_item	2676788	et	3	main
arvuti	doc_532115409069_item	2676793	et	4	main
hoiab	doc_532115409069_item	2676794	et	3	main
infot	doc_532115409069_item	2676795	et	3	main
hästi	doc_532115409069_item	2676796	et	3	main
ja	doc_532115409069_item	2676797	et	3	main
kui	doc_532115409069_item	2676798	et	3	main
võid	doc_532115409069_item	2676811	et	4	main
töötada	doc_532115409069_item	2676812	et	3	main
ka	doc_532115409069_item	2676817	et	3	main
minu	doc_532115409069_item	2676819	et	3	main
kõike	doc_532115409068_item	2676725	et	4	main
me	doc_532115409068_item	2676730	et	4	main
rohkem	doc_532115409068_item	2676733	et	4	main
sünoonimi	doc_532115409068_item	2676734	et	4	main
kuuendaks	doc_532115409068_item	2676735	et	4	main
aga	doc_532115409068_item	2676736	et	3	main
mitte	doc_532115409068_item	2676737	et	3	main
viimaseks	doc_532115409068_item	2676738	et	3	main
grammatika	doc_532115409068_item	2676739	et	4	main
on	doc_532115409068_item	2676749	et	4	main
milleta	doc_532115409069_item	2676757	et	3	main
saaks	doc_532115409069_item	2676760	et	3	main
informatsioon	doc_532115409069_item	2676774	et	3	main
see	doc_532115409069_item	2676777	et	3	main
arvuti	doc_532115409069_item	2676779	et	4	main
raamatud	doc_532115409069_item	2676780	et	4	main
ajalehed	doc_532115409069_item	2676781	et	3	main
halvemaks	doc_532115409069_item	2676787	et	4	main
on	doc_532115409069_item	2676789	et	4	main
võimalus	doc_532115409069_item	2676790	et	3	main
teadmise	doc_532115409069_item	2676791	et	4	main
vastupidi	doc_532115409069_item	2676792	et	3	main
võimalusi	doc_532115409069_item	2676816	et	3	main
teineteist	doc_532115409069_item	2676827	et	4	main
internetis	doc_532115409069_item	2676830	et	4	main
tore	doc_532115409069_item	2676832	et	3	main
mõtlen	doc_532115409069_item	2676834	et	3	main
raske	doc_532115409069_item	2676837	et	4	main
praegu	doc_532115409069_item	2676840	et	3	main
meeldib	doc_532115409069_item	2676843	et	3	main
saan	doc_532115409069_item	2676847	et	4	main
arvutis	doc_532115409069_item	2676849	et	4	main
minu	doc_532115409069_item	2676850	et	3	main
oluline	doc_532115409069_item	2676862	et	4	main
sinu	doc_532115409069_item	2676917	et	3	main
ia	doc_532115409069_item	2676932	et	4	main
aid	doc_532115409069_item	2676944	et	4	main
tea	doc_532115409069_item	2676950	et	4	main
kellega	doc_532115409069_item	2676951	et	3	main
telefon	doc_532115409069_item	2676962	et	3	main
on	doc_532115409069_item	2676963	et	4	main
väga	doc_532115409069_item	2676964	et	3	main
vaja	doc_532115409069_item	2676965	et	4	main
kui	doc_532115409069_item	2676966	et	3	main
või	doc_532115409069_item	2676968	et	4	main
saab	doc_532115409069_item	2676972	et	3	main
pera	doc_532115409069_item	2676974	et	4	main
kiirabile	doc_532115409069_item	2676976	et	3	main
inimene	doc_532115409069_item	2676979	et	3	main
olla	doc_532115409069_item	2676981	et	3	main
keele	doc_532115409070_item	2677008	et	4	main
oskused	doc_532115409070_item	2677009	et	3	main
pole	doc_532115409070_item	2677010	et	3	main
sellised	doc_532115409070_item	2677011	et	4	main
nagu	doc_532115409070_item	2677012	et	3	main
keel	doc_532115409070_item	2677019	et	4	main
keel	doc_532115409070_item	2677024	et	4	main
tahad	doc_532115409070_item	2677027	et	3	main
selleks	doc_532115409070_item	2677033	et	4	main
momendiks	doc_532115409070_item	2677034	et	3	main
mina	doc_532115409070_item	2677035	et	4	main
kus	doc_532115409070_item	2677039	et	3	main
eesti	doc_532115409070_item	2677043	et	4	main
geomeetria	doc_532115409070_item	2677055	et	4	main
selliseid	doc_532115409070_item	2677062	et	4	main
aineid	doc_532115409070_item	2677063	et	3	main
me	doc_532115409070_item	2677092	et	4	main
sellises	doc_532115409070_item	2677098	et	4	main
tundides	doc_532115409070_item	2677099	et	3	main
tehnika	doc_532115409070_item	2677103	et	4	main
oskused	doc_532115409070_item	2677105	et	3	main
ja	doc_532115409070_item	2677107	et	3	main
muidugi	doc_532115409070_item	2677111	et	4	main
tahaks	doc_532115409070_item	2677112	et	3	main
kirja	doc_532115409070_item	2677119	et	4	main
ja	doc_532115409070_item	2677120	et	3	main
maailmas	doc_532115409069_item	2676764	et	3	main
nii	doc_532115409069_item	2676775	et	3	main
on	doc_532115409069_item	2676778	et	4	main
kiiresti	doc_532115409069_item	2676785	et	3	main
sellega	doc_532115409069_item	2676801	et	3	main
antakse	doc_532115409069_item	2676815	et	3	main
suheldama	doc_532115409069_item	2676829	et	3	main
nii	doc_532115409069_item	2676831	et	3	main
ma	doc_532115409069_item	2676833	et	3	main
mul	doc_532115409069_item	2676835	et	3	main
mulle	doc_532115409069_item	2676841	et	4	main
ka	doc_532115409069_item	2676842	et	3	main
väga	doc_532115409069_item	2676844	et	3	main
wordil	doc_532115409069_item	2676848	et	4	main
osata	doc_532115409069_item	2676863	et	4	main
siis	doc_532115409069_item	2676867	et	3	main
rohkem	doc_532115409069_item	2676870	et	4	main
võimalusi	doc_532115409069_item	2676871	et	3	main
edukamaks	doc_532115409069_item	2676872	et	4	main
mõtlen	doc_532115409069_item	2676908	et	3	main
on	doc_532115409069_item	2676910	et	4	main
väga	doc_532115409069_item	2676911	et	3	main
hästi	doc_532115409069_item	2676912	et	3	main
sõbrana	doc_532115409069_item	2676920	et	3	main
aitavad	doc_532115409069_item	2676921	et	4	main
küll	doc_532115409069_item	2676925	et	4	main
näita	doc_532115409069_item	2676931	et	4	main
on	doc_532115409069_item	2676943	et	4	main
võib	doc_532115409069_item	2676958	et	3	main
hoida	doc_532115409069_item	2676959	et	3	main
nendele	doc_532115409069_item	2676960	et	4	main
ebaõnnestus	doc_532115409069_item	2676967	et	4	main
lõike	doc_532115409069_item	2676969	et	4	main
ja	doc_532115409070_item	2677006	et	3	main
minu	doc_532115409070_item	2677007	et	3	main
ole	doc_532115409070_item	2677021	et	4	main
sa	doc_532115409069_item	2676799	et	3	main
töötada	doc_532115409069_item	2676802	et	3	main
arvutiga	doc_532115409069_item	2676813	et	4	main
suhelda	doc_532115409069_item	2676818	et	4	main
sõbradega	doc_532115409069_item	2676820	et	4	main
vaba	doc_532115409069_item	2676825	et	4	main
aega	doc_532115409069_item	2676826	et	4	main
et	doc_532115409069_item	2676845	et	3	main
tööd	doc_532115409069_item	2676851	et	4	main
ilusasti	doc_532115409069_item	2676852	et	3	main
teha	doc_532115409069_item	2676853	et	3	main
ja	doc_532115409069_item	2676854	et	3	main
tekstid	doc_532115409069_item	2676855	et	3	main
on	doc_532115409069_item	2676856	et	4	main
õiged	doc_532115409069_item	2676857	et	3	main
töötada	doc_532115409069_item	2676864	et	3	main
on	doc_532115409069_item	2676868	et	4	main
kõik	doc_532115409069_item	2676905	et	4	main
see	doc_532115409069_item	2676909	et	3	main
sa	doc_532115409069_item	2676914	et	3	main
ja	doc_532115409069_item	2676916	et	3	main
meil	doc_532115409069_item	2676822	et	4	main
puhtad	doc_532115409069_item	2676858	et	3	main
praegu	doc_532115409069_item	2676859	et	3	main
on	doc_532115409069_item	2676860	et	4	main
arvutiga	doc_532115409069_item	2676865	et	4	main
arvuti	doc_532115409069_item	2676874	et	4	main
suureneb	doc_532115409069_item	2676875	et	3	main
sinu	doc_532115409069_item	2676876	et	3	main
silmas	doc_532115409069_item	2676877	et	4	main
maailm	doc_532115409069_item	2676878	et	3	main
saab	doc_532115409069_item	2676879	et	3	main
hoida	doc_532115409069_item	2676880	et	3	main
millionid	doc_532115409069_item	2676881	et	4	main
informatsiooni	doc_532115409069_item	2676882	et	4	main
mis	doc_532115409069_item	2676883	et	4	main
inimese	doc_532115409069_item	2676884	et	4	main
pea	doc_532115409069_item	2676885	et	4	main
ei	doc_532115409069_item	2676886	et	4	main
saa	doc_532115409069_item	2676887	et	4	main
hoida	doc_532115409069_item	2676888	et	3	main
väga	doc_532115409069_item	2676889	et	3	main
oluline	doc_532115409069_item	2676890	et	4	main
leiutis	doc_532115409069_item	2676891	et	3	main
mulle	doc_532115409069_item	2676892	et	4	main
on	doc_532115409069_item	2676893	et	4	main
telefon	doc_532115409069_item	2676894	et	3	main
ma	doc_532115409069_item	2676895	et	3	main
olen	doc_532115409069_item	2676896	et	3	main
emotsionaalne	doc_532115409069_item	2676897	et	3	main
inimene	doc_532115409069_item	2676898	et	3	main
ja	doc_532115409069_item	2676899	et	3	main
võin	doc_532115409069_item	2676900	et	3	main
saada	doc_532115409069_item	2676901	et	4	main
halvad	doc_532115409069_item	2676902	et	4	main
emotsioonid	doc_532115409069_item	2676903	et	3	main
saavad	doc_532115409069_item	2676906	et	4	main
kui	doc_532115409069_item	2676913	et	3	main
helistad	doc_532115409069_item	2676915	et	3	main
on	doc_532115409069_item	2676924	et	4	main
kui	doc_532115409069_item	2676926	et	3	main
te	doc_532115409069_item	2676927	et	4	main
praegu	doc_532115409069_item	2676934	et	3	main
väga	doc_532115409069_item	2676936	et	3	main
missugused	doc_532115409069_item	2676939	et	3	main
aitavad	doc_532115409069_item	2676940	et	4	main
inimestele	doc_532115409069_item	2676941	et	3	main
kellel	doc_532115409069_item	2676942	et	4	main
nad	doc_532115409069_item	2676947	et	3	main
elu	doc_532115409069_item	2676961	et	4	main
inimesele	doc_532115409069_item	2676971	et	3	main
ja	doc_532115409069_item	2676977	et	3	main
olema	doc_532115409070_item	2677014	et	4	main
ma	doc_532115409070_item	2677015	et	3	main
arvan	doc_532115409070_item	2677016	et	3	main
et	doc_532115409070_item	2677017	et	3	main
ei	doc_532115409070_item	2677020	et	4	main
väga	doc_532115409070_item	2677022	et	3	main
õppin	doc_532115409070_item	2677036	et	4	main
õppimine	doc_532115409070_item	2677041	et	4	main
koolis	doc_532115409070_item	2677045	et	4	main
päris	doc_532115409070_item	2677047	et	4	main
hüdraulika	doc_532115409070_item	2677052	et	4	main
kujutav	doc_532115409070_item	2677054	et	4	main
ökoloogia	doc_532115409070_item	2677056	et	4	main
jne	doc_532115409070_item	2677057	et	4	main
muidugi	doc_532115409070_item	2677058	et	4	main
teada	doc_532115409070_item	2677065	et	3	main
tudengite	doc_532115409070_item	2677089	et	3	main
jaoks	doc_532115409070_item	2677090	et	4	main
kus	doc_532115409070_item	2677091	et	3	main
keelt	doc_532115409070_item	2677096	et	4	main
õppida	doc_532115409070_item	2677097	et	3	main
sõnu	doc_532115409070_item	2677116	et	4	main
lugeda	doc_532115409070_item	2677117	et	3	main
aga	doc_532115409070_item	2677125	et	3	main
eesti	doc_532115409070_item	2677129	et	4	main
keele	doc_532115409070_item	2677130	et	4	main
tunnid	doc_532115409070_item	2677131	et	3	main
koordinaalselt	doc_532115409070_item	2677137	et	4	main
ma	doc_532115409071_item	2677140	et	3	main
keel	doc_532115409071_item	2677150	et	4	main
ja	doc_532115409071_item	2677151	et	3	main
teda	doc_532115409071_item	2677154	et	4	main
me	doc_532115409071_item	2677157	et	4	main
elada	doc_532115409071_item	2677159	et	3	main
siin	doc_532115409071_item	2677170	et	4	main
raske	doc_532115409071_item	2677172	et	4	main
sest	doc_532115409071_item	2677173	et	4	main
asju	doc_532115409071_item	2677181	et	3	main
saa	doc_532115409071_item	2677183	et	4	main
aru	doc_532115409071_item	2677184	et	4	main
et	doc_532115409071_item	2677188	et	3	main
aru	doc_532115409071_item	2677192	et	4	main
ehitusmaterjalides	doc_532115409071_item	2677199	et	3	main
minu	doc_532115409071_item	2677200	et	3	main
rääkida	doc_532115409071_item	2677207	et	3	main
see	doc_532115409071_item	2677221	et	3	main
arvan	doc_532115409071_item	2677248	et	3	main
et	doc_532115409071_item	2677249	et	3	main
me	doc_532115409071_item	2677250	et	4	main
kontrolltöid	doc_532115409071_item	2677255	et	3	main
keelt	doc_532115409071_item	2677280	et	4	main
inseneriks	doc_532115409071_item	2677283	et	3	main
ilma	doc_532115409072_item	2677285	et	4	main
milleta	doc_532115409072_item	2677286	et	3	main
ma	doc_532115409072_item	2677287	et	3	main
ei	doc_532115409072_item	2677288	et	4	main
saaks	doc_532115409072_item	2677289	et	3	main
jaoks	doc_532115409072_item	2677309	et	4	main
mõned	doc_532115409072_item	2677312	et	3	main
minu	doc_532115409072_item	2677321	et	3	main
sõbrad	doc_532115409072_item	2677324	et	3	main
kellega	doc_532115409072_item	2677328	et	3	main
ma	doc_532115409072_item	2677329	et	3	main
suhtlen	doc_532115409072_item	2677330	et	3	main
palju	doc_532115409072_item	2677332	et	4	main
aega	doc_532115409072_item	2677333	et	4	main
sulle	doc_532115409069_item	2676922	et	3	main
telefonis	doc_532115409069_item	2676923	et	3	main
teineteist	doc_532115409069_item	2676930	et	4	main
linnas	doc_532115409069_item	2676933	et	4	main
on	doc_532115409069_item	2676935	et	4	main
palju	doc_532115409069_item	2676937	et	4	main
liine	doc_532115409069_item	2676938	et	4	main
või	doc_532115409069_item	2676945	et	4	main
ja	doc_532115409069_item	2676946	et	3	main
ei	doc_532115409069_item	2676949	et	4	main
see	doc_532115409069_item	2676953	et	3	main
parem	doc_532115409069_item	2676955	et	4	main
nendele	doc_532115409069_item	2676956	et	4	main
see	doc_532115409069_item	2676957	et	3	main
või	doc_532115409069_item	2676970	et	4	main
halvemaks	doc_532115409069_item	2676973	et	4	main
helistab	doc_532115409069_item	2676975	et	3	main
seda	doc_532115409069_item	2676978	et	3	main
võib	doc_532115409069_item	2676980	et	3	main
elab	doc_532115409069_item	2676982	et	3	main
edasi	doc_532115409069_item	2676983	et	3	main
mida	doc_532115409070_item	2676984	et	4	main
tahaksin	doc_532115409070_item	2676986	et	3	main
ma	doc_532115409070_item	2676985	et	3	main
õppida	doc_532115409070_item	2676987	et	3	main
eesti	doc_532115409070_item	2676988	et	4	main
keele	doc_532115409070_item	2676989	et	4	main
tundides	doc_532115409070_item	2676990	et	3	main
eesti	doc_532115409070_item	2676991	et	4	main
keele	doc_532115409070_item	2676992	et	4	main
tunnid	doc_532115409070_item	2676993	et	3	main
on	doc_532115409070_item	2676994	et	4	main
väga	doc_532115409070_item	2676995	et	3	main
tähtsad	doc_532115409070_item	2676996	et	3	main
minu	doc_532115409070_item	2676997	et	3	main
jaoks	doc_532115409070_item	2676998	et	4	main
selle	doc_532115409070_item	2676999	et	4	main
pärast	doc_532115409070_item	2677000	et	4	main
et	doc_532115409070_item	2677001	et	3	main
ma	doc_532115409070_item	2677002	et	3	main
lõpetasin	doc_532115409070_item	2677003	et	3	main
vene	doc_532115409070_item	2677004	et	4	main
kooli	doc_532115409070_item	2677005	et	4	main
peavad	doc_532115409070_item	2677013	et	4	main
kui	doc_532115409070_item	2677026	et	3	main
teda	doc_532115409070_item	2677028	et	4	main
kõik	doc_532115409070_item	2677040	et	4	main
näiteks	doc_532115409070_item	2677050	et	4	main
metalliõpetus	doc_532115409070_item	2677053	et	3	main
on	doc_532115409070_item	2677083	et	4	main
eeste	doc_532115409070_item	2677085	et	4	main
venelaste	doc_532115409070_item	2677088	et	4	main
eesti	doc_532115409070_item	2677095	et	4	main
kui	doc_532115409070_item	2677102	et	3	main
keele	doc_532115409070_item	2677104	et	4	main
nii	doc_532115409070_item	2677106	et	3	main
tavalise	doc_532115409070_item	2677108	et	4	main
keele	doc_532115409070_item	2677109	et	4	main
oskused	doc_532115409070_item	2677110	et	3	main
tehnika	doc_532115409070_item	2677118	et	4	main
mind	doc_532115409070_item	2677127	et	4	main
eesti	doc_532115409071_item	2677143	et	4	main
me	doc_532115409071_item	2677152	et	4	main
kõrgkoolis	doc_532115409071_item	2677166	et	4	main
õppida	doc_532115409071_item	2677169	et	3	main
toimuvad	doc_532115409071_item	2677176	et	4	main
keeles	doc_532115409071_item	2677178	et	4	main
arvan	doc_532115409071_item	2677187	et	3	main
on	doc_532115409071_item	2677202	et	4	main
tundides	doc_532115409071_item	2677206	et	3	main
sellest	doc_532115409071_item	2677208	et	4	main
sest	doc_532115409071_item	2677209	et	4	main
näiteks	doc_532115409071_item	2677210	et	4	main
kõige	doc_532115409071_item	2677223	et	4	main
on	doc_532115409071_item	2677228	et	4	main
peame	doc_532115409071_item	2677237	et	4	main
rohkem	doc_532115409071_item	2677238	et	4	main
tundides	doc_532115409071_item	2677240	et	3	main
ei	doc_532115409071_item	2677251	et	4	main
pea	doc_532115409071_item	2677252	et	4	main
on	doc_532115409071_item	2677266	et	4	main
elada	doc_532115409072_item	2677290	et	3	main
kõigil	doc_532115409072_item	2677304	et	4	main
on	doc_532115409072_item	2677305	et	4	main
saa	doc_532115409072_item	2677318	et	4	main
elada	doc_532115409072_item	2677319	et	3	main
nt	doc_532115409072_item	2677320	et	4	main
eesti	doc_532115409070_item	2677018	et	4	main
aga	doc_532115409070_item	2677025	et	3	main
teada	doc_532115409070_item	2677029	et	3	main
õppima	doc_532115409070_item	2677032	et	3	main
tallinna	doc_532115409070_item	2677037	et	4	main
keeles	doc_532115409070_item	2677044	et	4	main
füüsika	doc_532115409070_item	2677051	et	4	main
vaja	doc_532115409070_item	2677064	et	4	main
saame	doc_532115409070_item	2677093	et	4	main
tehnika	doc_532115409070_item	2677094	et	4	main
üle	doc_532115409070_item	2677101	et	3	main
rohkem	doc_532115409070_item	2677113	et	4	main
õppida	doc_532115409070_item	2677114	et	3	main
suhtelda	doc_532115409070_item	2677121	et	4	main
üldiselt	doc_532115409070_item	2677126	et	4	main
mida	doc_532115409071_item	2677139	et	4	main
tahaksin	doc_532115409071_item	2677141	et	3	main
tundides	doc_532115409071_item	2677145	et	3	main
keel	doc_532115409071_item	2677147	et	4	main
on	doc_532115409071_item	2677148	et	4	main
riigi	doc_532115409071_item	2677149	et	3	main
kui	doc_532115409071_item	2677156	et	3	main
tahame	doc_532115409071_item	2677158	et	3	main
praegu	doc_532115409071_item	2677161	et	3	main
õpin	doc_532115409071_item	2677163	et	3	main
tehnika	doc_532115409071_item	2677165	et	4	main
teaduskonnas	doc_532115409071_item	2677168	et	4	main
veel	doc_532115409071_item	2677185	et	4	main
aga	doc_532115409071_item	2677186	et	3	main
raske	doc_532115409071_item	2677196	et	4	main
füüsikas	doc_532115409071_item	2677197	et	3	main
ja	doc_532115409071_item	2677198	et	3	main
keele	doc_532115409071_item	2677205	et	4	main
selline	doc_532115409071_item	2677229	et	4	main
et	doc_532115409071_item	2677230	et	3	main
siin	doc_532115409071_item	2677231	et	4	main
õpivad	doc_532115409071_item	2677232	et	3	main
palju	doc_532115409071_item	2677233	et	4	main
eestlasi	doc_532115409071_item	2677234	et	3	main
aru	doc_532115409071_item	2677246	et	4	main
ma	doc_532115409071_item	2677247	et	3	main
palju	doc_532115409071_item	2677254	et	4	main
kesktase	doc_532115409071_item	2677267	et	3	main
ma	doc_532115409071_item	2677268	et	3	main
ja	doc_532115409071_item	2677281	et	3	main
asju	doc_532115409072_item	2677296	et	3	main
omad	doc_532115409072_item	2677306	et	4	main
leiutised	doc_532115409072_item	2677307	et	3	main
on	doc_532115409072_item	2677326	et	4	main
veedan	doc_532115409072_item	2677331	et	3	main
omad	doc_532115409072_item	2677341	et	4	main
ma	doc_532115409072_item	2677348	et	3	main
on	doc_532115409072_item	2677350	et	4	main
muusika	doc_532115409072_item	2677351	et	4	main
kui	doc_532115409072_item	2677357	et	3	main
aga	doc_532115409072_item	2677375	et	3	main
pole	doc_532115409072_item	2677378	et	3	main
ei	doc_532115409072_item	2677382	et	4	main
tea	doc_532115409072_item	2677383	et	4	main
mitte	doc_532115409072_item	2677384	et	3	main
sport	doc_532115409072_item	2677390	et	3	main
ise	doc_532115409072_item	2677391	et	4	main
tegelen	doc_532115409072_item	2677392	et	3	main
orienteerumisega	doc_532115409072_item	2677393	et	4	main
ja	doc_532115409072_item	2677394	et	3	main
ei	doc_532115409072_item	2677398	et	4	main
töötama	doc_532115409072_item	2677400	et	3	main
nendel	doc_532115409072_item	2677437	et	4	main
ei	doc_532115409072_item	2677448	et	4	main
mõelnud	doc_532115409072_item	2677449	et	4	main
vajalikud	doc_532115409073_item	2677470	et	3	main
on	doc_532115409073_item	2677474	et	4	main
leiutised	doc_532115409073_item	2677476	et	3	main
vanad	doc_532115409073_item	2677478	et	3	main
ja	doc_532115409073_item	2677479	et	3	main
aasta	doc_532115409073_item	2677528	et	4	main
sellist	doc_532115409073_item	2677537	et	4	main
hind	doc_532115409073_item	2677544	et	3	main
abi	doc_532115409073_item	2677580	et	4	main
10	doc_532115409073_item	2677585	et	2	main
kui	doc_532115409073_item	2677588	et	3	main
see	doc_532115409073_item	2677600	et	3	main
raske	doc_532115409070_item	2677023	et	4	main
pead	doc_532115409070_item	2677030	et	4	main
kõvasti	doc_532115409070_item	2677031	et	3	main
kõrgkoolis	doc_532115409070_item	2677038	et	4	main
käib	doc_532115409070_item	2677042	et	3	main
õpetakse	doc_532115409070_item	2677046	et	4	main
raske	doc_532115409070_item	2677048	et	4	main
ained	doc_532115409070_item	2677049	et	3	main
selleks	doc_532115409070_item	2677059	et	4	main
et	doc_532115409070_item	2677060	et	3	main
õppida	doc_532115409070_item	2677061	et	3	main
keelt	doc_532115409070_item	2677066	et	4	main
kõrgemal	doc_532115409070_item	2677067	et	4	main
klassil	doc_532115409070_item	2677068	et	3	main
kahjuks	doc_532115409070_item	2677069	et	4	main
mina	doc_532115409070_item	2677070	et	4	main
eesti	doc_532115409070_item	2677071	et	4	main
keelt	doc_532115409070_item	2677072	et	4	main
nii	doc_532115409070_item	2677073	et	3	main
hästi	doc_532115409070_item	2677074	et	3	main
ei	doc_532115409070_item	2677075	et	4	main
tea	doc_532115409070_item	2677076	et	4	main
hea	doc_532115409070_item	2677077	et	4	main
on	doc_532115409070_item	2677078	et	4	main
see	doc_532115409070_item	2677079	et	3	main
et	doc_532115409070_item	2677080	et	3	main
meie	doc_532115409070_item	2677081	et	4	main
kõrgkoolis	doc_532115409070_item	2677082	et	4	main
lisad	doc_532115409070_item	2677084	et	4	main
keele	doc_532115409070_item	2677086	et	4	main
tunnid	doc_532115409070_item	2677087	et	3	main
tõstakse	doc_532115409070_item	2677100	et	4	main
tehnika	doc_532115409070_item	2677115	et	4	main
keeles	doc_532115409070_item	2677124	et	4	main
rahuldavad	doc_532115409070_item	2677128	et	4	main
ja	doc_532115409070_item	2677132	et	3	main
mina	doc_532115409070_item	2677133	et	4	main
muutuda	doc_532115409070_item	2677138	et	3	main
õppida	doc_532115409071_item	2677142	et	3	main
eesti	doc_532115409071_item	2677146	et	4	main
peame	doc_532115409071_item	2677153	et	4	main
eestis	doc_532115409071_item	2677160	et	3	main
ma	doc_532115409071_item	2677162	et	3	main
tallinna	doc_532115409071_item	2677164	et	4	main
on	doc_532115409071_item	2677171	et	4	main
eesti	doc_532115409071_item	2677177	et	4	main
pole	doc_532115409071_item	2677179	et	3	main
hakkan	doc_532115409071_item	2677190	et	3	main
ehitusmaterjalides	doc_532115409071_item	2677211	et	3	main
on	doc_532115409071_item	2677212	et	4	main
me	doc_532115409071_item	2677236	et	4	main
me	doc_532115409071_item	2677242	et	4	main
me	doc_532115409071_item	2677257	et	4	main
neid	doc_532115409071_item	2677259	et	4	main
ju	doc_532115409071_item	2677260	et	3	main
saame	doc_532115409071_item	2677282	et	4	main
leiutised	doc_532115409072_item	2677284	et	3	main
on	doc_532115409072_item	2677292	et	4	main
väga	doc_532115409072_item	2677293	et	3	main
erinevaid	doc_532115409072_item	2677295	et	4	main
ilma	doc_532115409072_item	2677297	et	4	main
milleta	doc_532115409072_item	2677298	et	3	main
inimene	doc_532115409072_item	2677299	et	3	main
minu	doc_532115409072_item	2677308	et	3	main
ka	doc_532115409072_item	2677311	et	3	main
asjad	doc_532115409072_item	2677313	et	3	main
milleta	doc_532115409072_item	2677315	et	3	main
ei	doc_532115409072_item	2677317	et	4	main
muretsed	doc_532115409072_item	2677342	et	3	main
inimesega	doc_532115409072_item	2677377	et	3	main
veel	doc_532115409072_item	2677386	et	4	main
olema	doc_532115409072_item	2677405	et	4	main
võimalus	doc_532115409072_item	2677406	et	3	main
töötada	doc_532115409072_item	2677407	et	3	main
nagu	doc_532115409072_item	2677421	et	3	main
räägivad	doc_532115409072_item	2677435	et	3	main
ole	doc_532115409072_item	2677439	et	4	main
on	doc_532115409072_item	2677454	et	4	main
igapäevane	doc_532115409072_item	2677456	et	4	main
elu	doc_532115409072_item	2677457	et	4	main
leiutised	doc_532115409073_item	2677458	et	3	main
leiutisi	doc_532115409073_item	2677482	et	3	main
mobiiltelefon	doc_532115409073_item	2677484	et	3	main
hakkangi	doc_532115409073_item	2677521	et	3	main
on	doc_532115409073_item	2677524	et	4	main
esialgu	doc_532115409073_item	2677530	et	3	main
kõik	doc_532115409073_item	2677533	et	4	main
inimesed	doc_532115409073_item	2677534	et	3	main
lubada	doc_532115409073_item	2677535	et	3	main
endale	doc_532115409073_item	2677536	et	4	main
langes	doc_532115409073_item	2677545	et	4	main
funktionaalsus	doc_532115409073_item	2677547	et	4	main
suurenes	doc_532115409073_item	2677548	et	4	main
praegu	doc_532115409073_item	2677549	et	3	main
mobiiltelefoni	doc_532115409073_item	2677550	et	4	main
olime	doc_532115409073_item	2677570	et	3	main
paanikas	doc_532115409073_item	2677571	et	3	main
rahunesime	doc_532115409073_item	2677575	et	3	main
võitsime	doc_532115409073_item	2677576	et	3	main
mida	doc_532115409073_item	2677582	et	4	main
inimene	doc_532115409073_item	2677584	et	3	main
aastat	doc_532115409073_item	2677586	et	3	main
ta	doc_532115409073_item	2677589	et	4	main
sattuks	doc_532115409073_item	2677590	et	3	main
ei	doc_532115409073_item	2677594	et	4	main
saa	doc_532115409073_item	2677595	et	4	main
isegi	doc_532115409073_item	2677596	et	4	main
seda	doc_532115409073_item	2677597	et	3	main
miks	doc_532115409073_item	2677605	et	4	main
rohkem	doc_532115409070_item	2677122	et	4	main
eesti	doc_532115409070_item	2677123	et	4	main
ei	doc_532115409070_item	2677134	et	4	main
soovi	doc_532115409070_item	2677135	et	4	main
midagi	doc_532115409070_item	2677136	et	4	main
keele	doc_532115409071_item	2677144	et	4	main
teadma	doc_532115409071_item	2677155	et	3	main
teedeehituse	doc_532115409071_item	2677167	et	3	main
kõik	doc_532115409071_item	2677174	et	4	main
ained	doc_532115409071_item	2677175	et	3	main
kõik	doc_532115409071_item	2677180	et	4	main
ei	doc_532115409071_item	2677182	et	4	main
ajaga	doc_532115409071_item	2677189	et	3	main
kõik	doc_532115409071_item	2677191	et	4	main
saama	doc_532115409071_item	2677193	et	4	main
on	doc_532115409071_item	2677194	et	4	main
väga	doc_532115409071_item	2677195	et	3	main
arvates	doc_532115409071_item	2677201	et	4	main
otstarbekam	doc_532115409071_item	2677203	et	4	main
eesti	doc_532115409071_item	2677204	et	4	main
palju	doc_532115409071_item	2677213	et	4	main
uusi	doc_532115409071_item	2677214	et	3	main
sõnu	doc_532115409071_item	2677215	et	4	main
milliseid	doc_532115409071_item	2677216	et	3	main
me	doc_532115409071_item	2677217	et	4	main
ei	doc_532115409071_item	2677218	et	4	main
saa	doc_532115409071_item	2677219	et	4	main
aru	doc_532115409071_item	2677220	et	4	main
on	doc_532115409071_item	2677222	et	4	main
olulisem	doc_532115409071_item	2677224	et	4	main
probleem	doc_532115409071_item	2677225	et	3	main
teine	doc_532115409071_item	2677226	et	3	main
probleem	doc_532115409071_item	2677227	et	3	main
ja	doc_532115409071_item	2677235	et	3	main
suhtlema	doc_532115409071_item	2677239	et	3	main
et	doc_532115409071_item	2677241	et	3	main
saame	doc_532115409071_item	2677243	et	4	main
hästi	doc_532115409071_item	2677244	et	3	main
neid	doc_532115409071_item	2677245	et	4	main
kirjutama	doc_532115409071_item	2677253	et	3	main
sest	doc_532115409071_item	2677256	et	4	main
kirjutasime	doc_532115409071_item	2677258	et	3	main
koolis	doc_532115409071_item	2677261	et	4	main
ja	doc_532115409071_item	2677262	et	3	main
sooritasime	doc_532115409071_item	2677263	et	3	main
eksameid	doc_532115409071_item	2677264	et	3	main
paljudel	doc_532115409071_item	2677265	et	3	main
arvan	doc_532115409071_item	2677269	et	3	main
et	doc_532115409071_item	2677270	et	3	main
me	doc_532115409071_item	2677271	et	4	main
kõik	doc_532115409071_item	2677272	et	4	main
saame	doc_532115409071_item	2677273	et	4	main
sellega	doc_532115409071_item	2677274	et	3	main
toime	doc_532115409071_item	2677275	et	4	main
tulla	doc_532115409071_item	2677276	et	3	main
õpime	doc_532115409071_item	2677277	et	3	main
pähe	doc_532115409071_item	2677278	et	4	main
eesti	doc_532115409071_item	2677279	et	4	main
maailmas	doc_532115409072_item	2677291	et	3	main
palju	doc_532115409072_item	2677294	et	4	main
ei	doc_532115409072_item	2677300	et	4	main
saaks	doc_532115409072_item	2677301	et	3	main
elada	doc_532115409072_item	2677302	et	3	main
aga	doc_532115409072_item	2677303	et	3	main
on	doc_532115409072_item	2677310	et	4	main
ilma	doc_532115409072_item	2677314	et	4	main
ma	doc_532115409072_item	2677316	et	3	main
ja	doc_532115409072_item	2677323	et	3	main
raske	doc_532115409072_item	2677336	et	4	main
elada	doc_532115409072_item	2677337	et	3	main
kellega	doc_532115409072_item	2677338	et	3	main
sa	doc_532115409072_item	2677339	et	3	main
jagad	doc_532115409072_item	2677340	et	3	main
või	doc_532115409072_item	2677343	et	4	main
teine	doc_532115409072_item	2677345	et	3	main
mida	doc_532115409072_item	2677347	et	4	main
raamatud	doc_532115409072_item	2677353	et	4	main
kultuur	doc_532115409072_item	2677356	et	3	main
suhelda	doc_532115409072_item	2677380	et	4	main
ta	doc_532115409072_item	2677381	et	4	main
on	doc_532115409072_item	2677387	et	4	main
korvpalli	doc_532115409072_item	2677396	et	4	main
pea	doc_532115409072_item	2677399	et	4	main
oma	doc_532115409072_item	2677408	et	4	main
välja	doc_532115409072_item	2677415	et	4	main
trennist	doc_532115409072_item	2677417	et	3	main
sa	doc_532115409072_item	2677418	et	3	main
inimesed	doc_532115409072_item	2677434	et	3	main
ta	doc_532115409072_item	2677446	et	4	main
see	doc_532115409072_item	2677453	et	3	main
arust	doc_532115409073_item	2677466	et	4	main
sajandil	doc_532115409073_item	2677473	et	3	main
asendanud	doc_532115409073_item	2677477	et	4	main
mitte	doc_532115409073_item	2677480	et	3	main
näiteks	doc_532115409073_item	2677483	et	4	main
kui	doc_532115409073_item	2677487	et	3	main
lauatelefon	doc_532115409073_item	2677489	et	3	main
mobiiltelefonist	doc_532115409073_item	2677491	et	4	main
leiutatud	doc_532115409073_item	2677525	et	4	main
kallist	doc_532115409073_item	2677538	et	4	main
leiutist	doc_532115409073_item	2677539	et	3	main
aga	doc_532115409073_item	2677540	et	3	main
iga	doc_532115409073_item	2677541	et	4	main
aastaga	doc_532115409073_item	2677542	et	3	main
suvel	doc_532115409073_item	2677560	et	3	main
aga	doc_532115409073_item	2677581	et	3	main
teeks	doc_532115409073_item	2677583	et	4	main
tagasi	doc_532115409073_item	2677587	et	3	main
olema	doc_532115409073_item	2677609	et	4	main
ja	doc_532115409073_item	2677610	et	3	main
võib	doc_532115409073_item	2677618	et	3	main
smsi	doc_532115409073_item	2677625	et	4	main
surfata	doc_532115409073_item	2677628	et	4	main
osta	doc_532115409073_item	2677643	et	4	main
endale	doc_532115409073_item	2677644	et	4	main
sest	doc_532115409073_item	2677652	et	4	main
elan	doc_532115409073_item	2677655	et	3	main
tallinnast	doc_532115409073_item	2677658	et	3	main
pean	doc_532115409073_item	2677661	et	4	main
pidama	doc_532115409073_item	2677663	et	4	main
oma	doc_532115409073_item	2677664	et	4	main
perega	doc_532115409073_item	2677665	et	3	main
ja	doc_532115409073_item	2677666	et	3	main
ma	doc_532115409073_item	2677671	et	3	main
elada	doc_532115409073_item	2677674	et	3	main
mobiiltelefonita	doc_532115409073_item	2677676	et	3	main
ja	doc_532115409073_item	2677677	et	3	main
miks	doc_532115409073_item	2677683	et	4	main
ma	doc_532115409073_item	2677684	et	3	main
on	doc_532115409073_item	2677693	et	4	main
näiteks	doc_532115409073_item	2677696	et	4	main
kasutavad	doc_532115409074_item	2677733	et	4	main
minu	doc_532115409074_item	2677736	et	3	main
ei	doc_532115409074_item	2677743	et	4	main
linnad	doc_532115409074_item	2677750	et	3	main
ja	doc_532115409074_item	2677762	et	3	main
autoga	doc_532115409074_item	2677766	et	3	main
transport	doc_532115409074_item	2677768	et	3	main
tehnikakõrgkoolist	doc_532115409074_item	2677779	et	4	main
nädal	doc_532115409074_item	2677782	et	3	main
pere	doc_532115409072_item	2677322	et	4	main
need	doc_532115409072_item	2677325	et	3	main
inimesed	doc_532115409072_item	2677327	et	3	main
kino	doc_532115409072_item	2677352	et	4	main
ei	doc_532115409072_item	2677359	et	4	main
huvita	doc_532115409072_item	2677360	et	4	main
mitte	doc_532115409072_item	2677361	et	3	main
midagi	doc_532115409072_item	2677362	et	4	main
see	doc_532115409072_item	2677363	et	3	main
pole	doc_532115409072_item	2677364	et	3	main
hea	doc_532115409072_item	2677365	et	4	main
sest	doc_532115409072_item	2677366	et	4	main
sul	doc_532115409072_item	2677367	et	3	main
ei	doc_532115409072_item	2677368	et	4	main
ole	doc_532115409072_item	2677369	et	4	main
võimalust	doc_532115409072_item	2677370	et	3	main
kasvatada	doc_532115409072_item	2677371	et	3	main
ja	doc_532115409072_item	2677372	et	3	main
saada	doc_532115409072_item	2677373	et	4	main
targemaks	doc_532115409072_item	2677374	et	4	main
sõbrata	doc_532115409072_item	2677334	et	3	main
on	doc_532115409072_item	2677335	et	4	main
rõõmus	doc_532115409072_item	2677344	et	4	main
asi	doc_532115409072_item	2677346	et	4	main
vajan	doc_532115409072_item	2677349	et	3	main
muuseumid	doc_532115409072_item	2677354	et	3	main
ühesõnaga	doc_532115409072_item	2677355	et	3	main
sind	doc_532115409072_item	2677358	et	4	main
rumala	doc_532115409072_item	2677376	et	3	main
tunnet	doc_532115409072_item	2677379	et	3	main
tähtis	doc_532115409072_item	2677388	et	4	main
ka	doc_532115409072_item	2677389	et	3	main
inimene	doc_532115409072_item	2677397	et	3	main
ainult	doc_532115409072_item	2677401	et	4	main
peaga	doc_532115409072_item	2677402	et	3	main
tal	doc_532115409072_item	2677403	et	3	main
peab	doc_532115409072_item	2677404	et	4	main
stressi	doc_532115409072_item	2677414	et	4	main
end	doc_532115409072_item	2677420	et	4	main
inimene	doc_532115409072_item	2677423	et	3	main
oled	doc_532115409072_item	2677425	et	3	main
ja	doc_532115409072_item	2677427	et	3	main
et	doc_532115409072_item	2677436	et	3	main
ei	doc_532115409072_item	2677438	et	4	main
leiutist	doc_532115409072_item	2677440	et	3	main
aga	doc_532115409072_item	2677441	et	3	main
see	doc_532115409072_item	2677442	et	3	main
ei	doc_532115409072_item	2677443	et	4	main
ole	doc_532115409072_item	2677444	et	4	main
nii	doc_532115409072_item	2677445	et	3	main
sellest	doc_532115409072_item	2677450	et	4	main
sellepärast	doc_532115409072_item	2677451	et	3	main
et	doc_532115409072_item	2677452	et	3	main
meie	doc_532115409072_item	2677455	et	4	main
kõik	doc_532115409073_item	2677467	et	4	main
leiutised	doc_532115409073_item	2677468	et	3	main
on	doc_532115409073_item	2677469	et	4	main
aga	doc_532115409073_item	2677471	et	3	main
ühed	doc_532115409073_item	2677475	et	3	main
kasulikum	doc_532115409073_item	2677486	et	4	main
võib	doc_532115409073_item	2677492	et	3	main
helistada	doc_532115409073_item	2677493	et	3	main
midagi	doc_532115409072_item	2677385	et	4	main
mängin	doc_532115409072_item	2677395	et	3	main
kehaga	doc_532115409072_item	2677409	et	3	main
ka	doc_532115409072_item	2677410	et	3	main
sport	doc_532115409072_item	2677411	et	3	main
aitab	doc_532115409072_item	2677412	et	3	main
panna	doc_532115409072_item	2677413	et	4	main
pärast	doc_532115409072_item	2677416	et	4	main
tunned	doc_532115409072_item	2677419	et	3	main
uus	doc_532115409072_item	2677422	et	3	main
sa	doc_532115409072_item	2677424	et	3	main
värske	doc_532115409072_item	2677426	et	4	main
võid	doc_532115409072_item	2677428	et	4	main
jätkata	doc_532115409072_item	2677429	et	4	main
oma	doc_532115409072_item	2677430	et	4	main
õpinguid	doc_532115409072_item	2677431	et	3	main
edasi	doc_532115409072_item	2677432	et	3	main
mõned	doc_532115409072_item	2677433	et	3	main
ainult	doc_532115409072_item	2677447	et	4	main
ilma	doc_532115409073_item	2677459	et	4	main
milleta	doc_532115409073_item	2677460	et	3	main
ma	doc_532115409073_item	2677461	et	3	main
ei	doc_532115409073_item	2677462	et	4	main
saaks	doc_532115409073_item	2677463	et	3	main
elada	doc_532115409073_item	2677464	et	3	main
minu	doc_532115409073_item	2677465	et	3	main
21	doc_532115409073_item	2677472	et	2	main
effektiivseid	doc_532115409073_item	2677481	et	4	main
on	doc_532115409073_item	2677485	et	4	main
lihtne	doc_532115409073_item	2677488	et	3	main
sest	doc_532115409073_item	2677490	et	4	main
igast	doc_532115409073_item	2677494	et	3	main
kohast	doc_532115409073_item	2677495	et	4	main
õuest	doc_532115409073_item	2677496	et	4	main
metsast	doc_532115409073_item	2677497	et	4	main
järvelt	doc_532115409073_item	2677498	et	4	main
jne	doc_532115409073_item	2677499	et	4	main
mina	doc_532115409073_item	2677500	et	4	main
isiklikult	doc_532115409073_item	2677501	et	4	main
ei	doc_532115409073_item	2677502	et	4	main
saa	doc_532115409073_item	2677503	et	4	main
elada	doc_532115409073_item	2677504	et	3	main
arvutita	doc_532115409073_item	2677505	et	4	main
televisorita	doc_532115409073_item	2677506	et	4	main
raadiota	doc_532115409073_item	2677507	et	3	main
ja	doc_532115409073_item	2677508	et	3	main
mobiiltelefonita	doc_532115409073_item	2677509	et	3	main
kõige	doc_532115409073_item	2677510	et	4	main
tähtsam	doc_532115409073_item	2677511	et	4	main
minu	doc_532115409073_item	2677512	et	3	main
arust	doc_532115409073_item	2677513	et	4	main
nende	doc_532115409073_item	2677514	et	4	main
asjade	doc_532115409073_item	2677515	et	3	main
hulgast	doc_532115409073_item	2677516	et	4	main
on	doc_532115409073_item	2677517	et	4	main
mobiiltelefon	doc_532115409073_item	2677518	et	3	main
sellest	doc_532115409073_item	2677519	et	4	main
ma	doc_532115409073_item	2677520	et	3	main
10	doc_532115409073_item	2677527	et	2	main
tagasi	doc_532115409073_item	2677529	et	3	main
ei	doc_532115409073_item	2677531	et	4	main
kuulsus	doc_532115409073_item	2677551	et	4	main
esialgu	doc_532115409073_item	2677569	et	3	main
aga	doc_532115409073_item	2677572	et	3	main
rääkima	doc_532115409073_item	2677522	et	3	main
mobiiltelefon	doc_532115409073_item	2677523	et	3	main
üle	doc_532115409073_item	2677526	et	3	main
saanud	doc_532115409073_item	2677532	et	4	main
mobiiltelefoni	doc_532115409073_item	2677543	et	4	main
aga	doc_532115409073_item	2677546	et	3	main
on	doc_532115409073_item	2677552	et	4	main
suur	doc_532115409073_item	2677553	et	3	main
nii	doc_532115409073_item	2677554	et	3	main
eestis	doc_532115409073_item	2677555	et	3	main
kui	doc_532115409073_item	2677556	et	3	main
ka	doc_532115409073_item	2677557	et	3	main
mujal	doc_532115409073_item	2677558	et	3	main
maailmas	doc_532115409073_item	2677559	et	3	main
ma	doc_532115409073_item	2677561	et	3	main
käisin	doc_532115409073_item	2677562	et	3	main
järvel	doc_532115409073_item	2677563	et	4	main
kalapüügil	doc_532115409073_item	2677564	et	3	main
ja	doc_532115409073_item	2677565	et	3	main
ükskord	doc_532115409073_item	2677566	et	3	main
kaatrimootor	doc_532115409073_item	2677567	et	3	main
rikkus	doc_532115409073_item	2677568	et	4	main
pärast	doc_532115409073_item	2677573	et	4	main
olukorda	doc_532115409073_item	2677592	et	4	main
me	doc_532115409073_item	2677593	et	4	main
on	doc_532115409073_item	2677601	et	4	main
ainult	doc_532115409073_item	2677602	et	4	main
üks	doc_532115409073_item	2677603	et	3	main
põhjus	doc_532115409073_item	2677604	et	4	main
miks	doc_532115409073_item	2677611	et	4	main
peaaegu	doc_532115409073_item	2677620	et	3	main
ükskõik	doc_532115409073_item	2677621	et	3	main
võib	doc_532115409073_item	2677623	et	3	main
saata	doc_532115409073_item	2677624	et	3	main
helistada	doc_532115409073_item	2677626	et	3	main
ise	doc_532115409073_item	2677653	et	4	main
kaugel	doc_532115409073_item	2677657	et	4	main
ma	doc_532115409073_item	2677660	et	3	main
saa	doc_532115409073_item	2677673	et	4	main
põhjus	doc_532115409073_item	2677682	et	4	main
selle	doc_532115409073_item	2677689	et	4	main
ka	doc_532115409073_item	2677694	et	3	main
milleta	doc_532115409074_item	2677725	et	3	main
inimesed	doc_532115409074_item	2677732	et	3	main
leiutisi	doc_532115409074_item	2677735	et	3	main
peavad	doc_532115409074_item	2677759	et	4	main
sõitma	doc_532115409074_item	2677760	et	3	main
kaugel	doc_532115409074_item	2677777	et	4	main
tallinna	doc_532115409074_item	2677778	et	4	main
iga	doc_532115409074_item	2677781	et	4	main
ma	doc_532115409074_item	2677783	et	3	main
tallinnasse	doc_532115409074_item	2677785	et	3	main
nende	doc_532115409074_item	2677823	et	4	main
leiutised	doc_532115409074_item	2677831	et	3	main
jaoks	doc_532115409074_item	2677835	et	4	main
transport	doc_532115409074_item	2677844	et	3	main
kõige	doc_532115409074_item	2677847	et	4	main
kohta	doc_532115409075_item	2677871	et	4	main
mõelda	doc_532115409075_item	2677874	et	4	main
inimesel	doc_532115409075_item	2677876	et	3	main
oma	doc_532115409075_item	2677878	et	4	main
üks	doc_532115409075_item	2677888	et	3	main
lähedamat	doc_532115409075_item	2677927	et	4	main
minu	doc_532115409075_item	2677929	et	3	main
ilma	doc_532115409075_item	2677936	et	4	main
armastuse	doc_532115409075_item	2677938	et	4	main
hea	doc_532115409075_item	2677954	et	4	main
ma	doc_532115409075_item	2677961	et	3	main
kõigest	doc_532115409075_item	2677964	et	4	main
elus	doc_532115409075_item	2677978	et	4	main
leiutis	doc_532115409075_item	2678021	et	3	main
milleta	doc_532115409075_item	2678023	et	3	main
elada	doc_532115409075_item	2678027	et	3	main
kaua	doc_532115409075_item	2678034	et	3	main
ilma	doc_532115409076_item	2678037	et	4	main
ma	doc_532115409076_item	2678039	et	3	main
palju	doc_532115409076_item	2678047	et	4	main
leiutisi	doc_532115409076_item	2678048	et	3	main
on	doc_532115409076_item	2678052	et	4	main
kasulikum	doc_532115409076_item	2678054	et	4	main
minu	doc_532115409076_item	2678055	et	3	main
jaoks	doc_532115409076_item	2678056	et	4	main
ma	doc_532115409076_item	2678057	et	3	main
kasutan	doc_532115409076_item	2678058	et	3	main
neid	doc_532115409076_item	2678059	et	4	main
leiutis	doc_532115409076_item	2678089	et	3	main
mina	doc_532115409076_item	2678099	et	4	main
see	doc_532115409076_item	2678106	et	3	main
tean	doc_532115409076_item	2678110	et	3	main
mõned	doc_532115409076_item	2678121	et	3	main
ma	doc_532115409076_item	2678143	et	3	main
ette	doc_532115409076_item	2678146	et	4	main
elu	doc_532115409076_item	2678148	et	4	main
neid	doc_532115409076_item	2678155	et	4	main
asjad	doc_532115409076_item	2678156	et	3	main
elekter	doc_532115409076_item	2678160	et	3	main
leiutis	doc_532115409076_item	2678163	et	3	main
milleta	doc_532115409076_item	2678165	et	3	main
minu	doc_532115409077_item	2678177	et	3	main
leiutis	doc_532115409077_item	2678183	et	3	main
ta	doc_532115409077_item	2678186	et	4	main
minu	doc_532115409077_item	2678190	et	3	main
infot	doc_532115409077_item	2678226	et	3	main
sellel	doc_532115409077_item	2678227	et	4	main
kui	doc_532115409073_item	2677574	et	3	main
mobiiltelefoni	doc_532115409073_item	2677577	et	4	main
ja	doc_532115409073_item	2677578	et	3	main
kutsusime	doc_532115409073_item	2677579	et	3	main
sellise	doc_532115409073_item	2677591	et	4	main
ette	doc_532115409073_item	2677598	et	4	main
kujutada	doc_532115409073_item	2677599	et	3	main
peaks	doc_532115409073_item	2677607	et	4	main
kaasas	doc_532115409073_item	2677608	et	4	main
kalender	doc_532115409073_item	2677634	et	3	main
kell	doc_532115409073_item	2677635	et	3	main
kõik	doc_532115409073_item	2677636	et	4	main
vajalikud	doc_532115409073_item	2677637	et	3	main
asjad	doc_532115409073_item	2677638	et	3	main
praegu	doc_532115409073_item	2677639	et	3	main
mul	doc_532115409073_item	2677650	et	3	main
ja	doc_532115409073_item	2677659	et	3	main
sõbradega	doc_532115409073_item	2677667	et	4	main
jälle	doc_532115409073_item	2677668	et	3	main
põhjus	doc_532115409073_item	2677669	et	4	main
tähtsam	doc_532115409073_item	2677681	et	4	main
ilma	doc_532115409073_item	2677688	et	4	main
põhjused	doc_532115409073_item	2677692	et	3	main
ümbritsevatele	doc_532115409073_item	2677721	et	4	main
leiutised	doc_532115409074_item	2677723	et	3	main
saaks	doc_532115409074_item	2677728	et	3	main
elada	doc_532115409074_item	2677729	et	3	main
tänapäeval	doc_532115409074_item	2677730	et	3	main
kõik	doc_532115409074_item	2677731	et	4	main
erinevaid	doc_532115409074_item	2677734	et	4	main
arvates	doc_532115409074_item	2677737	et	4	main
kõige	doc_532115409074_item	2677738	et	4	main
elada	doc_532115409074_item	2677745	et	3	main
transport	doc_532115409074_item	2677747	et	3	main
esiteks	doc_532115409074_item	2677748	et	3	main
kaasaegsed	doc_532115409074_item	2677749	et	3	main
kooli	doc_532115409074_item	2677761	et	4	main
on	doc_532115409074_item	2677769	et	4	main
vajalik	doc_532115409074_item	2677770	et	3	main
minu	doc_532115409074_item	2677771	et	3	main
jaoks	doc_532115409074_item	2677772	et	4	main
sellepärast	doc_532115409074_item	2677773	et	3	main
et	doc_532115409074_item	2677774	et	3	main
ma	doc_532115409074_item	2677775	et	3	main
elan	doc_532115409074_item	2677776	et	3	main
ja	doc_532115409074_item	2677780	et	3	main
kolmandaks	doc_532115409074_item	2677787	et	4	main
mobiiltelefon	doc_532115409073_item	2677606	et	3	main
mina	doc_532115409073_item	2677612	et	4	main
mida	doc_532115409073_item	2677622	et	4	main
sõbrale	doc_532115409073_item	2677627	et	3	main
on	doc_532115409073_item	2677640	et	4	main
väga	doc_532115409073_item	2677641	et	3	main
trendikas	doc_532115409073_item	2677642	et	4	main
vaja	doc_532115409073_item	2677651	et	4	main
ma	doc_532115409073_item	2677654	et	3	main
tartumaal	doc_532115409073_item	2677656	et	4	main
sidet	doc_532115409073_item	2677662	et	4	main
miks	doc_532115409073_item	2677670	et	4	main
leiutiseta	doc_532115409073_item	2677690	et	3	main
ei	doc_532115409073_item	2677613	et	4	main
saa	doc_532115409073_item	2677614	et	4	main
selleta	doc_532115409073_item	2677615	et	3	main
elada	doc_532115409073_item	2677616	et	3	main
mobiiltelefoniga	doc_532115409073_item	2677617	et	4	main
teha	doc_532115409073_item	2677619	et	3	main
internetis	doc_532115409073_item	2677629	et	4	main
mobiiltelefonis	doc_532115409073_item	2677630	et	3	main
on	doc_532115409073_item	2677631	et	4	main
äratuskell	doc_532115409073_item	2677632	et	3	main
kalkulaator	doc_532115409073_item	2677633	et	3	main
sisseehitatud	doc_532115409073_item	2677645	et	4	main
kaameraga	doc_532115409073_item	2677646	et	3	main
telefon	doc_532115409073_item	2677647	et	3	main
mobiiltelefon	doc_532115409073_item	2677648	et	3	main
on	doc_532115409073_item	2677649	et	4	main
ei	doc_532115409073_item	2677672	et	4	main
ilma	doc_532115409073_item	2677675	et	4	main
see	doc_532115409073_item	2677678	et	3	main
on	doc_532115409073_item	2677679	et	4	main
kõige	doc_532115409073_item	2677680	et	4	main
ei	doc_532115409073_item	2677685	et	4	main
saa	doc_532115409073_item	2677686	et	4	main
elada	doc_532115409073_item	2677687	et	3	main
teised	doc_532115409073_item	2677691	et	4	main
tähtsad	doc_532115409073_item	2677695	et	3	main
hommikul	doc_532115409073_item	2677698	et	3	main
mitte	doc_532115409073_item	2677699	et	3	main
üle	doc_532115409073_item	2677700	et	3	main
magada	doc_532115409073_item	2677701	et	3	main
et	doc_532115409073_item	2677697	et	3	main
ma	doc_532115409073_item	2677702	et	3	main
võin	doc_532115409073_item	2677703	et	3	main
panna	doc_532115409073_item	2677704	et	4	main
äratuskell	doc_532115409073_item	2677705	et	3	main
käima	doc_532115409073_item	2677706	et	4	main
minu	doc_532115409073_item	2677707	et	3	main
arust	doc_532115409073_item	2677708	et	4	main
mobiiltelefon	doc_532115409073_item	2677709	et	3	main
on	doc_532115409073_item	2677710	et	4	main
vajalik	doc_532115409073_item	2677711	et	3	main
asi	doc_532115409073_item	2677712	et	4	main
mitte	doc_532115409073_item	2677713	et	3	main
ainult	doc_532115409073_item	2677714	et	4	main
minule	doc_532115409073_item	2677715	et	3	main
vaid	doc_532115409073_item	2677716	et	3	main
ka	doc_532115409073_item	2677717	et	3	main
kõikidele	doc_532115409073_item	2677718	et	4	main
teistele	doc_532115409073_item	2677719	et	4	main
mind	doc_532115409073_item	2677720	et	4	main
ilma	doc_532115409074_item	2677724	et	4	main
ma	doc_532115409074_item	2677726	et	3	main
ei	doc_532115409074_item	2677727	et	4	main
ma	doc_532115409074_item	2677742	et	3	main
bussiga	doc_532115409074_item	2677764	et	3	main
või	doc_532115409074_item	2677765	et	4	main
teiseks	doc_532115409074_item	2677767	et	4	main
saavutada	doc_532115409074_item	2677822	et	3	main
öelda	doc_532115409074_item	2677828	et	4	main
on	doc_532115409074_item	2677832	et	4	main
neid	doc_532115409074_item	2677841	et	4	main
arvan	doc_532115409074_item	2677842	et	3	main
et	doc_532115409074_item	2677843	et	3	main
raske	doc_532115409075_item	2677867	et	4	main
inimestele	doc_532115409073_item	2677722	et	3	main
olulisem	doc_532115409074_item	2677739	et	4	main
leiutis	doc_532115409074_item	2677740	et	3	main
milleta	doc_532115409074_item	2677741	et	3	main
saaks	doc_532115409074_item	2677744	et	3	main
on	doc_532115409074_item	2677746	et	4	main
on	doc_532115409074_item	2677751	et	4	main
tihti	doc_532115409074_item	2677752	et	3	main
väga	doc_532115409074_item	2677753	et	3	main
suured	doc_532115409074_item	2677754	et	3	main
ja	doc_532115409074_item	2677755	et	3	main
täiskasvanud	doc_532115409074_item	2677756	et	4	main
ja	doc_532115409074_item	2677757	et	3	main
lapsed	doc_532115409074_item	2677758	et	3	main
tööle	doc_532115409074_item	2677763	et	3	main
jaoks	doc_532115409074_item	2677789	et	4	main
on	doc_532115409074_item	2677790	et	4	main
tähtsa	doc_532115409074_item	2677791	et	3	main
erinevad	doc_532115409074_item	2677792	et	4	main
kaubaveod	doc_532115409074_item	2677793	et	3	main
ja	doc_532115409074_item	2677794	et	3	main
teised	doc_532115409074_item	2677795	et	4	main
ilma	doc_532115409074_item	2677797	et	4	main
veod	doc_532115409074_item	2677796	et	3	main
selleta	doc_532115409074_item	2677798	et	3	main
me	doc_532115409074_item	2677799	et	4	main
ei	doc_532115409074_item	2677800	et	4	main
saaks	doc_532115409074_item	2677801	et	3	main
elada	doc_532115409074_item	2677802	et	3	main
meie	doc_532115409074_item	2677803	et	4	main
raskes	doc_532115409074_item	2677804	et	3	main
maailmas	doc_532115409074_item	2677805	et	3	main
neljandaks	doc_532115409074_item	2677806	et	4	main
inimesed	doc_532115409074_item	2677808	et	3	main
paljud	doc_532115409074_item	2677807	et	3	main
reisida	doc_532115409074_item	2677810	et	3	main
tahavad	doc_532115409074_item	2677809	et	3	main
õppida	doc_532115409074_item	2677811	et	3	main
rahvaste	doc_532115409074_item	2677813	et	4	main
teiste	doc_532115409074_item	2677812	et	4	main
keeli	doc_532115409074_item	2677814	et	4	main
ja	doc_532115409074_item	2677815	et	3	main
kultuureid	doc_532115409074_item	2677816	et	4	main
kaasaegne	doc_532115409074_item	2677817	et	3	main
transport	doc_532115409074_item	2677818	et	3	main
võib	doc_532115409074_item	2677819	et	3	main
aidata	doc_532115409074_item	2677820	et	4	main
neile	doc_532115409074_item	2677821	et	4	main
ma	doc_532115409074_item	2677826	et	3	main
et	doc_532115409074_item	2677829	et	3	main
sõidan	doc_532115409074_item	2677784	et	3	main
bussiga	doc_532115409074_item	2677786	et	3	main
inimeste	doc_532115409074_item	2677788	et	3	main
kokkuvõttes	doc_532115409074_item	2677825	et	3	main
kõik	doc_532115409074_item	2677830	et	4	main
inimeste	doc_532115409074_item	2677834	et	3	main
väga	doc_532115409075_item	2677866	et	3	main
väide	doc_532115409075_item	2677868	et	4	main
ja	doc_532115409075_item	2677869	et	3	main
selle	doc_532115409075_item	2677870	et	4	main
igal	doc_532115409075_item	2677875	et	3	main
milleta	doc_532115409075_item	2677880	et	3	main
ei	doc_532115409075_item	2677882	et	4	main
minu	doc_532115409075_item	2677885	et	3	main
ilusam	doc_532115409075_item	2677909	et	4	main
kui	doc_532115409075_item	2677910	et	3	main
keegi	doc_532115409075_item	2677911	et	4	main
armastab	doc_532115409075_item	2677912	et	3	main
kõige	doc_532115409075_item	2677926	et	4	main
inimesed	doc_532115409075_item	2677928	et	3	main
kui	doc_532115409075_item	2677940	et	3	main
midagi	doc_532115409075_item	2677941	et	4	main
juhtus	doc_532115409075_item	2677942	et	3	main
ma	doc_532115409075_item	2677943	et	3	main
lähen	doc_532115409075_item	2677944	et	3	main
sõbra	doc_532115409075_item	2677945	et	3	main
juurde	doc_532115409075_item	2677946	et	4	main
ja	doc_532115409075_item	2677947	et	3	main
räägin	doc_532115409075_item	2677948	et	3	main
temaga	doc_532115409075_item	2677949	et	3	main
mul	doc_532115409075_item	2677950	et	3	main
sõbranna	doc_532115409075_item	2677955	et	4	main
minu	doc_532115409075_item	2677958	et	3	main
võin	doc_532115409075_item	2677962	et	3	main
ja	doc_532115409075_item	2677965	et	3	main
saab	doc_532115409075_item	2677971	et	3	main
aru	doc_532115409075_item	2677973	et	4	main
milleta	doc_532115409075_item	2677975	et	3	main
ei	doc_532115409075_item	2677979	et	4	main
eesmärgid	doc_532115409074_item	2677824	et	3	main
võin	doc_532115409074_item	2677827	et	3	main
harjunud	doc_532115409074_item	2677839	et	4	main
kasutada	doc_532115409074_item	2677840	et	3	main
on	doc_532115409074_item	2677845	et	4	main
üks	doc_532115409074_item	2677846	et	3	main
ei	doc_532115409075_item	2677855	et	4	main
saaks	doc_532115409075_item	2677856	et	3	main
elada	doc_532115409075_item	2677857	et	3	main
ilma	doc_532115409075_item	2677858	et	4	main
milleta	doc_532115409075_item	2677859	et	3	main
ma	doc_532115409075_item	2677860	et	3	main
ei	doc_532115409075_item	2677861	et	4	main
saaks	doc_532115409075_item	2677862	et	3	main
elada	doc_532115409075_item	2677863	et	3	main
see	doc_532115409075_item	2677864	et	3	main
on	doc_532115409075_item	2677865	et	4	main
hädavajalikud	doc_532115409074_item	2677833	et	3	main
sest	doc_532115409074_item	2677836	et	4	main
me	doc_532115409074_item	2677837	et	4	main
oleme	doc_532115409074_item	2677838	et	3	main
olulisematest	doc_532115409074_item	2677848	et	4	main
leitustest	doc_532115409074_item	2677849	et	4	main
maailmas	doc_532115409074_item	2677850	et	3	main
leiutised	doc_532115409075_item	2677851	et	3	main
ilma	doc_532115409075_item	2677852	et	4	main
milleta	doc_532115409075_item	2677853	et	3	main
ma	doc_532115409075_item	2677854	et	3	main
võib	doc_532115409075_item	2677872	et	3	main
asi	doc_532115409075_item	2677879	et	4	main
jaoks	doc_532115409075_item	2677886	et	4	main
nõusavad	doc_532115409075_item	2677899	et	3	main
ilus	doc_532115409075_item	2677905	et	4	main
tunne	doc_532115409075_item	2677906	et	4	main
ja	doc_532115409075_item	2677907	et	3	main
veel	doc_532115409075_item	2677908	et	4	main
jaoks	doc_532115409075_item	2677916	et	4	main
vanemate	doc_532115409075_item	2677919	et	4	main
sest	doc_532115409075_item	2677921	et	4	main
kaua	doc_532115409075_item	2677873	et	3	main
on	doc_532115409075_item	2677877	et	4	main
ta	doc_532115409075_item	2677881	et	4	main
saaks	doc_532115409075_item	2677883	et	3	main
elada	doc_532115409075_item	2677884	et	3	main
kõige	doc_532115409075_item	2677889	et	4	main
leiutis	doc_532115409075_item	2677891	et	3	main
see	doc_532115409075_item	2677892	et	3	main
on	doc_532115409075_item	2677893	et	4	main
armastus	doc_532115409075_item	2677894	et	4	main
arvan	doc_532115409075_item	2677895	et	3	main
et	doc_532115409075_item	2677896	et	3	main
mõned	doc_532115409075_item	2677897	et	3	main
inimesed	doc_532115409075_item	2677898	et	3	main
armastus	doc_532115409075_item	2677901	et	4	main
on	doc_532115409075_item	2677903	et	4	main
nii	doc_532115409075_item	2677904	et	3	main
sind	doc_532115409075_item	2677913	et	4	main
esiteks	doc_532115409075_item	2677914	et	3	main
minu	doc_532115409075_item	2677915	et	3	main
tähtsam	doc_532115409075_item	2677918	et	4	main
isa	doc_532115409075_item	2677922	et	4	main
elus	doc_532115409075_item	2677930	et	4	main
teiseks	doc_532115409075_item	2677931	et	4	main
ma	doc_532115409075_item	2677932	et	3	main
ei	doc_532115409075_item	2677933	et	4	main
saaks	doc_532115409075_item	2677934	et	3	main
see	doc_532115409075_item	2677956	et	3	main
rääkida	doc_532115409075_item	2677963	et	3	main
ma	doc_532115409075_item	2677966	et	3	main
tean	doc_532115409075_item	2677967	et	3	main
täpselt	doc_532115409075_item	2677968	et	4	main
et	doc_532115409075_item	2677969	et	3	main
elada	doc_532115409075_item	2677981	et	3	main
ma	doc_532115409075_item	2678024	et	3	main
selle	doc_532115409075_item	2678030	et	4	main
mõelda	doc_532115409075_item	2678035	et	4	main
raske	doc_532115409076_item	2678049	et	4	main
otsustada	doc_532115409076_item	2678050	et	3	main
kõige	doc_532115409076_item	2678053	et	4	main
arvates	doc_532115409076_item	2678087	et	4	main
on	doc_532115409076_item	2678090	et	4	main
mitte	doc_532115409076_item	2678092	et	3	main
tea	doc_532115409076_item	2678101	et	4	main
aga	doc_532115409076_item	2678108	et	3	main
ilma	doc_532115409076_item	2678112	et	4	main
inimesed	doc_532115409076_item	2678122	et	3	main
suur	doc_532115409076_item	2678138	et	3	main
nagu	doc_532115409076_item	2678140	et	3	main
arvutita	doc_532115409076_item	2678150	et	4	main
elektri	doc_532115409076_item	2678158	et	3	main
elada	doc_532115409077_item	2678176	et	3	main
inimesel	doc_532115409077_item	2678180	et	3	main
ilma	doc_532115409077_item	2678184	et	4	main
saa	doc_532115409077_item	2678188	et	4	main
palju	doc_532115409077_item	2678222	et	4	main
et	doc_532115409077_item	2678224	et	3	main
kõrgkoolisse	doc_532115409077_item	2678230	et	4	main
on	doc_532115409077_item	2678233	et	4	main
vähe	doc_532115409077_item	2678234	et	3	main
kaudu	doc_532115409077_item	2678240	et	3	main
kõiki	doc_532115409077_item	2678243	et	4	main
tahan	doc_532115409077_item	2678245	et	3	main
ja	doc_532115409077_item	2678246	et	3	main
mida	doc_532115409077_item	2678247	et	4	main
saan	doc_532115409077_item	2678254	et	4	main
rääkida	doc_532115409077_item	2678255	et	3	main
mul	doc_532115409077_item	2678259	et	3	main
aga	doc_532115409077_item	2678267	et	3	main
tahan	doc_532115409077_item	2678283	et	3	main
millal	doc_532115409077_item	2678285	et	3	main
et	doc_532115409077_item	2678296	et	3	main
inimese	doc_532115409077_item	2678301	et	4	main
leiutis	doc_532115409077_item	2678302	et	3	main
on	doc_532115409077_item	2678305	et	4	main
elada	doc_532115409077_item	2678307	et	3	main
milleta	doc_532115409078_item	2678310	et	3	main
saaks	doc_532115409078_item	2678313	et	3	main
maailma	doc_532115409078_item	2678322	et	4	main
riige	doc_532115409078_item	2678323	et	4	main
ilma	doc_532115409078_item	2678324	et	4	main
infotehnoloogiateta	doc_532115409078_item	2678326	et	3	main
on	doc_532115409075_item	2677887	et	4	main
tähtis	doc_532115409075_item	2677890	et	4	main
minuga	doc_532115409075_item	2677900	et	3	main
see	doc_532115409075_item	2677902	et	3	main
kõige	doc_532115409075_item	2677917	et	4	main
armastus	doc_532115409075_item	2677920	et	4	main
ja	doc_532115409075_item	2677923	et	3	main
ema	doc_532115409075_item	2677924	et	4	main
on	doc_532115409075_item	2677925	et	4	main
elada	doc_532115409075_item	2677935	et	3	main
on	doc_532115409075_item	2677951	et	4	main
üks	doc_532115409075_item	2677952	et	3	main
väga	doc_532115409075_item	2677953	et	3	main
temaga	doc_532115409075_item	2677960	et	3	main
ta	doc_532115409075_item	2677970	et	4	main
mind	doc_532115409075_item	2677972	et	4	main
veel	doc_532115409075_item	2677976	et	4	main
meie	doc_532115409075_item	2677977	et	4	main
saaks	doc_532115409075_item	2677980	et	3	main
lilled	doc_532115409075_item	2678020	et	3	main
ei	doc_532115409075_item	2678025	et	4	main
aga	doc_532115409075_item	2678028	et	3	main
elada	doc_532115409076_item	2678042	et	3	main
siiamani	doc_532115409076_item	2678043	et	4	main
maailmas	doc_532115409076_item	2678044	et	3	main
tehti	doc_532115409076_item	2678045	et	3	main
väga	doc_532115409076_item	2678046	et	3	main
jaoks	doc_532115409076_item	2678098	et	4	main
tegi	doc_532115409076_item	2678105	et	4	main
mina	doc_532115409076_item	2678109	et	4	main
ilma	doc_532115409076_item	2678125	et	4	main
elektrita	doc_532115409076_item	2678126	et	3	main
lihtsalt	doc_532115409076_item	2678128	et	4	main
sellega	doc_532115409076_item	2678130	et	3	main
ja	doc_532115409076_item	2678131	et	3	main
nende	doc_532115409076_item	2678132	et	4	main
probleem	doc_532115409076_item	2678139	et	3	main
ei	doc_532115409076_item	2678144	et	4	main
ilma	doc_532115409076_item	2678149	et	4	main
jne	doc_532115409076_item	2678152	et	4	main
ja	doc_532115409076_item	2678153	et	3	main
kõik	doc_532115409076_item	2678154	et	4	main
peal	doc_532115409076_item	2678159	et	4	main
ilma	doc_532115409076_item	2678164	et	4	main
ei	doc_532115409076_item	2678167	et	4	main
saaks	doc_532115409076_item	2678168	et	3	main
elada	doc_532115409076_item	2678169	et	3	main
leiutised	doc_532115409077_item	2678170	et	3	main
ilma	doc_532115409077_item	2678171	et	4	main
milleta	doc_532115409077_item	2678172	et	3	main
ma	doc_532115409077_item	2678173	et	3	main
arvates	doc_532115409077_item	2678178	et	4	main
on	doc_532115409077_item	2678181	et	4	main
ei	doc_532115409077_item	2678187	et	4	main
sõpru	doc_532115409075_item	2677937	et	3	main
sest	doc_532115409075_item	2677939	et	4	main
on	doc_532115409075_item	2677957	et	4	main
ema	doc_532115409075_item	2677959	et	4	main
kindlasti	doc_532115409075_item	2677974	et	3	main
muidugi	doc_532115409075_item	2677982	et	4	main
ilma	doc_532115409075_item	2677983	et	4	main
õnnelikku	doc_532115409075_item	2677984	et	4	main
praegu	doc_532115409075_item	2677985	et	3	main
selline	doc_532115409075_item	2677986	et	4	main
aeg	doc_532115409075_item	2677987	et	3	main
et	doc_532115409075_item	2677988	et	3	main
inimestele	doc_532115409075_item	2677989	et	3	main
on	doc_532115409075_item	2677990	et	4	main
väga	doc_532115409075_item	2677991	et	3	main
raske	doc_532115409075_item	2677992	et	4	main
elada	doc_532115409075_item	2677993	et	3	main
aga	doc_532115409075_item	2677994	et	3	main
ükskõik	doc_532115409075_item	2677995	et	3	main
inimesel	doc_532115409075_item	2677996	et	3	main
peab	doc_532115409075_item	2677997	et	4	main
olema	doc_532115409075_item	2677998	et	4	main
see	doc_532115409075_item	2677999	et	3	main
mille	doc_532115409075_item	2678000	et	3	main
jaoks	doc_532115409075_item	2678001	et	4	main
ta	doc_532115409075_item	2678002	et	4	main
tahab	doc_532115409075_item	2678003	et	3	main
elada	doc_532115409075_item	2678004	et	3	main
ja	doc_532115409075_item	2678005	et	3	main
mis	doc_532115409075_item	2678006	et	4	main
teeb	doc_532115409075_item	2678007	et	3	main
teda	doc_532115409075_item	2678008	et	4	main
õnnelikum	doc_532115409075_item	2678009	et	4	main
arvan	doc_532115409075_item	2678010	et	3	main
et	doc_532115409075_item	2678011	et	3	main
elu	doc_532115409075_item	2678012	et	4	main
teevad	doc_532115409075_item	2678013	et	3	main
lapsed	doc_532115409075_item	2678014	et	3	main
õnnelikum	doc_532115409075_item	2678015	et	4	main
sest	doc_532115409075_item	2678016	et	4	main
lapsed	doc_532115409075_item	2678017	et	3	main
on	doc_532115409075_item	2678018	et	4	main
elu	doc_532115409075_item	2678019	et	4	main
ilma	doc_532115409075_item	2678022	et	4	main
võib	doc_532115409075_item	2678033	et	3	main
leiutised	doc_532115409076_item	2678036	et	3	main
ei	doc_532115409076_item	2678040	et	4	main
saaks	doc_532115409076_item	2678041	et	3	main
mis	doc_532115409076_item	2678051	et	4	main
pool	doc_532115409076_item	2678064	et	4	main
näiteks	doc_532115409076_item	2678065	et	4	main
teel	doc_532115409076_item	2678066	et	4	main
kodust	doc_532115409076_item	2678067	et	4	main
kooli	doc_532115409076_item	2678068	et	4	main
automootor	doc_532115409076_item	2678069	et	3	main
see	doc_532115409076_item	2678070	et	3	main
on	doc_532115409076_item	2678071	et	4	main
ju	doc_532115409076_item	2678072	et	3	main
ka	doc_532115409076_item	2678073	et	3	main
leiutis	doc_532115409076_item	2678074	et	3	main
aga	doc_532115409076_item	2678075	et	3	main
kõige	doc_532115409076_item	2678076	et	4	main
tähtsam	doc_532115409076_item	2678077	et	4	main
ja	doc_532115409076_item	2678078	et	3	main
kõige	doc_532115409076_item	2678079	et	4	main
kasulikum	doc_532115409076_item	2678080	et	4	main
leiutis	doc_532115409076_item	2678081	et	3	main
minu	doc_532115409076_item	2678082	et	3	main
jaoks	doc_532115409076_item	2678083	et	4	main
saaks	doc_532115409075_item	2678026	et	3	main
muidugi	doc_532115409075_item	2678029	et	4	main
teema	doc_532115409075_item	2678031	et	4	main
kohta	doc_532115409075_item	2678032	et	4	main
milleta	doc_532115409076_item	2678038	et	3	main
iga	doc_532115409076_item	2678060	et	4	main
päev	doc_532115409076_item	2678061	et	3	main
ja	doc_532115409076_item	2678062	et	3	main
igal	doc_532115409076_item	2678063	et	3	main
on	doc_532115409076_item	2678084	et	4	main
elekter	doc_532115409076_item	2678085	et	3	main
minu	doc_532115409076_item	2678086	et	3	main
ainult	doc_532115409076_item	2678093	et	4	main
minu	doc_532115409076_item	2678094	et	3	main
jaoks	doc_532115409076_item	2678095	et	4	main
vaid	doc_532115409076_item	2678096	et	3	main
paljude	doc_532115409076_item	2678097	et	3	main
kes	doc_532115409076_item	2678102	et	4	main
ja	doc_532115409076_item	2678103	et	3	main
kuna	doc_532115409076_item	2678104	et	3	main
pered	doc_532115409076_item	2678123	et	3	main
nad	doc_532115409076_item	2678127	et	3	main
harjunud	doc_532115409076_item	2678129	et	4	main
jaoks	doc_532115409076_item	2678133	et	4	main
see	doc_532115409076_item	2678134	et	3	main
jaoks	doc_532115409076_item	2678142	et	4	main
kujuta	doc_532115409076_item	2678145	et	4	main
oma	doc_532115409076_item	2678147	et	4	main
telerita	doc_532115409076_item	2678151	et	3	main
see	doc_532115409076_item	2678161	et	3	main
on	doc_532115409076_item	2678162	et	4	main
ma	doc_532115409076_item	2678166	et	3	main
igal	doc_532115409077_item	2678179	et	3	main
erinevatele	doc_532115409077_item	2678237	et	4	main
raamatukogutele	doc_532115409077_item	2678238	et	4	main
interneti	doc_532115409077_item	2678239	et	4	main
oma	doc_532115409077_item	2678256	et	4	main
sõbratega	doc_532115409077_item	2678258	et	4	main
suhelda	doc_532115409077_item	2678266	et	4	main
elavad	doc_532115409077_item	2678276	et	4	main
kus	doc_532115409077_item	2678282	et	3	main
tahan	doc_532115409077_item	2678286	et	3	main
sest	doc_532115409077_item	2678287	et	4	main
arvuti	doc_532115409077_item	2678289	et	4	main
kogu	doc_532115409077_item	2678291	et	4	main
aeg	doc_532115409077_item	2678292	et	3	main
minu	doc_532115409077_item	2678293	et	3	main
oluline	doc_532115409077_item	2678300	et	4	main
sellega	doc_532115409077_item	2678303	et	3	main
leiutised	doc_532115409078_item	2678308	et	3	main
ma	doc_532115409078_item	2678311	et	3	main
mina	doc_532115409078_item	2678316	et	4	main
ette	doc_532115409078_item	2678319	et	4	main
kujutada	doc_532115409078_item	2678320	et	3	main
see	doc_532115409076_item	2678088	et	3	main
tähtis	doc_532115409076_item	2678091	et	4	main
ei	doc_532115409076_item	2678100	et	4	main
leiutis	doc_532115409076_item	2678107	et	3	main
et	doc_532115409076_item	2678111	et	3	main
elektrita	doc_532115409076_item	2678113	et	3	main
on	doc_532115409076_item	2678114	et	4	main
raske	doc_532115409076_item	2678115	et	4	main
elada	doc_532115409076_item	2678116	et	3	main
võib	doc_532115409076_item	2678117	et	3	main
olla	doc_532115409076_item	2678118	et	3	main
kuskil	doc_532115409076_item	2678119	et	3	main
maal	doc_532115409076_item	2678120	et	4	main
elavad	doc_532115409076_item	2678124	et	4	main
ei	doc_532115409076_item	2678135	et	4	main
ole	doc_532115409076_item	2678136	et	4	main
nii	doc_532115409076_item	2678137	et	3	main
minu	doc_532115409076_item	2678141	et	3	main
töötavad	doc_532115409076_item	2678157	et	4	main
ei	doc_532115409077_item	2678174	et	4	main
saaks	doc_532115409077_item	2678175	et	3	main
oma	doc_532115409077_item	2678182	et	4	main
milleta	doc_532115409077_item	2678185	et	3	main
elada	doc_532115409077_item	2678189	et	3	main
jaoks	doc_532115409077_item	2678191	et	4	main
on	doc_532115409077_item	2678192	et	4	main
kõige	doc_532115409077_item	2678193	et	4	main
tähtsaim	doc_532115409077_item	2678194	et	4	main
leiutis	doc_532115409077_item	2678195	et	3	main
on	doc_532115409077_item	2678196	et	4	main
arvuti	doc_532115409077_item	2678197	et	4	main
ma	doc_532115409077_item	2678198	et	3	main
arvan	doc_532115409077_item	2678199	et	3	main
et	doc_532115409077_item	2678200	et	3	main
see	doc_532115409077_item	2678201	et	3	main
on	doc_532115409077_item	2678202	et	4	main
leiutis	doc_532115409077_item	2678203	et	3	main
ilma	doc_532115409077_item	2678204	et	4	main
milleta	doc_532115409077_item	2678205	et	3	main
ei	doc_532115409077_item	2678206	et	4	main
saa	doc_532115409077_item	2678207	et	4	main
elada	doc_532115409077_item	2678208	et	3	main
paljud	doc_532115409077_item	2678209	et	3	main
inimesed	doc_532115409077_item	2678210	et	3	main
ma	doc_532115409077_item	2678211	et	3	main
kasutan	doc_532115409077_item	2678212	et	3	main
arvutit	doc_532115409077_item	2678213	et	3	main
iga	doc_532115409077_item	2678214	et	4	main
päev	doc_532115409077_item	2678215	et	3	main
kui	doc_532115409077_item	2678216	et	3	main
ei	doc_532115409077_item	2678217	et	4	main
oleks	doc_532115409077_item	2678218	et	3	main
arvutit	doc_532115409077_item	2678219	et	3	main
siis	doc_532115409077_item	2678220	et	3	main
raiskaksin	doc_532115409077_item	2678221	et	3	main
aega	doc_532115409077_item	2678223	et	4	main
aega	doc_532115409077_item	2678264	et	4	main
minu	doc_532115409077_item	2678274	et	3	main
vaatan	doc_532115409077_item	2678279	et	3	main
uudised	doc_532115409077_item	2678281	et	3	main
et	doc_532115409077_item	2678288	et	3	main
on	doc_532115409077_item	2678290	et	4	main
arvan	doc_532115409077_item	2678295	et	3	main
väga	doc_532115409077_item	2678299	et	3	main
kergelt	doc_532115409077_item	2678306	et	4	main
ei	doc_532115409078_item	2678312	et	4	main
leida	doc_532115409077_item	2678225	et	3	main
aastal	doc_532115409077_item	2678228	et	3	main
mul	doc_532115409077_item	2678232	et	3	main
aega	doc_532115409077_item	2678235	et	4	main
minna	doc_532115409077_item	2678236	et	3	main
ma	doc_532115409077_item	2678241	et	3	main
vaja	doc_532115409077_item	2678249	et	4	main
veel	doc_532115409077_item	2678250	et	4	main
arvuti	doc_532115409077_item	2678251	et	4	main
kaudu	doc_532115409077_item	2678252	et	3	main
ma	doc_532115409077_item	2678253	et	3	main
astusin	doc_532115409077_item	2678229	et	3	main
seni	doc_532115409077_item	2678231	et	3	main
leian	doc_532115409077_item	2678242	et	3	main
mida	doc_532115409077_item	2678244	et	4	main
on	doc_532115409077_item	2678248	et	4	main
nendega	doc_532115409077_item	2678265	et	4	main
internetis	doc_532115409077_item	2678277	et	4	main
ja	doc_532115409077_item	2678284	et	3	main
arvuti	doc_532115409077_item	2678297	et	4	main
asjaga	doc_532115409077_item	2678304	et	3	main
elada	doc_532115409078_item	2678314	et	3	main
ei	doc_532115409078_item	2678317	et	4	main
saa	doc_532115409078_item	2678318	et	4	main
kõrgarenevateta	doc_532115409078_item	2678325	et	3	main
arvuti	doc_532115409078_item	2678339	et	4	main
saada	doc_532115409078_item	2678343	et	4	main
vajalikku	doc_532115409078_item	2678345	et	4	main
informatsiooni	doc_532115409078_item	2678346	et	4	main
jalgpalli	doc_532115409078_item	2678360	et	4	main
fan	doc_532115409078_item	2678361	et	4	main
mis	doc_532115409078_item	2678376	et	4	main
uudiseid	doc_532115409078_item	2678382	et	3	main
ilmuvad	doc_532115409078_item	2678386	et	4	main
teiseks	doc_532115409078_item	2678390	et	4	main
praegu	doc_532115409078_item	2678391	et	3	main
me	doc_532115409078_item	2678396	et	4	main
kasutame	doc_532115409078_item	2678397	et	3	main
nendega	doc_532115409078_item	2678401	et	4	main
saame	doc_532115409078_item	2678404	et	4	main
cd-sse	doc_532115409078_item	2678409	et	3	main
või	doc_532115409078_item	2678411	et	4	main
neid	doc_532115409078_item	2678413	et	4	main
kaaslastega	doc_532115409077_item	2678257	et	4	main
on	doc_532115409077_item	2678260	et	4	main
väga	doc_532115409077_item	2678261	et	3	main
vähe	doc_532115409077_item	2678262	et	3	main
vaba	doc_532115409077_item	2678263	et	4	main
internet	doc_532115409077_item	2678268	et	4	main
aitab	doc_532115409077_item	2678269	et	3	main
mind	doc_532115409077_item	2678270	et	4	main
üle	doc_532115409077_item	2678271	et	3	main
teada	doc_532115409077_item	2678272	et	3	main
kuidas	doc_532115409077_item	2678273	et	3	main
sõbrad	doc_532115409077_item	2678275	et	3	main
ka	doc_532115409077_item	2678278	et	3	main
maailma	doc_532115409077_item	2678280	et	4	main
käes	doc_532115409077_item	2678294	et	4	main
on	doc_532115409077_item	2678298	et	4	main
ilma	doc_532115409078_item	2678309	et	4	main
nüüdisajal	doc_532115409078_item	2678315	et	3	main
sellel	doc_532115409078_item	2678327	et	4	main
arvan	doc_532115409078_item	2678329	et	3	main
leiutis	doc_532115409078_item	2678331	et	3	main
milleta	doc_532115409078_item	2678333	et	3	main
ma	doc_532115409078_item	2678334	et	3	main
ei	doc_532115409078_item	2678335	et	4	main
saaks	doc_532115409078_item	2678336	et	3	main
elada	doc_532115409078_item	2678337	et	3	main
arvutist	doc_532115409078_item	2678341	et	4	main
kogu	doc_532115409078_item	2678344	et	4	main
olen	doc_532115409078_item	2678359	et	3	main
asjatundja	doc_532115409078_item	2678363	et	4	main
kõik	doc_532115409078_item	2678369	et	4	main
jalgpallimaailmast	doc_532115409078_item	2678372	et	4	main
parem	doc_532115409078_item	2678379	et	4	main
kui	doc_532115409078_item	2678380	et	3	main
oodata	doc_532115409078_item	2678381	et	4	main
vaadates	doc_532115409078_item	2678383	et	3	main
palju	doc_532115409078_item	2678393	et	4	main
igapäevases	doc_532115409078_item	2678399	et	4	main
koos	doc_532115409078_item	2678402	et	4	main
õppimises	doc_532115409078_item	2678415	et	4	main
nii	doc_532115409078_item	2678416	et	3	main
koolides	doc_532115409078_item	2678417	et	3	main
kui	doc_532115409078_item	2678418	et	3	main
email-le	doc_532115409078_item	2678426	et	3	main
on	doc_532115409078_item	2678436	et	4	main
väga	doc_532115409078_item	2678437	et	3	main
vajalik	doc_532115409078_item	2678438	et	3	main
töövahend	doc_532115409078_item	2678439	et	3	main
tänapäeval	doc_532115409078_item	2678440	et	3	main
kujutada	doc_532115409078_item	2678445	et	3	main
paberidel	doc_532115409078_item	2678453	et	4	main
ilma	doc_532115409078_item	2678469	et	4	main
uudist	doc_532115409079_item	2678503	et	3	main
huvitavat	doc_532115409079_item	2678505	et	4	main
informatsionit	doc_532115409079_item	2678506	et	4	main
kahjuks	doc_532115409079_item	2678515	et	4	main
minu	doc_532115409079_item	2678516	et	3	main
ja	doc_532115409079_item	2678522	et	3	main
tahaksin	doc_532115409079_item	2678525	et	3	main
uut	doc_532115409079_item	2678527	et	3	main
teler	doc_532115409079_item	2678528	et	3	main
millest	doc_532115409079_item	2678531	et	3	main
poeg	doc_532115409079_item	2678543	et	3	main
on	doc_532115409079_item	2678547	et	4	main
sellepärast	doc_532115409079_item	2678549	et	3	main
ma	doc_532115409080_item	2678558	et	3	main
ei	doc_532115409080_item	2678563	et	4	main
iga	doc_532115409080_item	2678574	et	4	main
päev	doc_532115409080_item	2678575	et	3	main
filmid	doc_532115409080_item	2678609	et	4	main
ilma	doc_532115409081_item	2678616	et	4	main
milleta	doc_532115409081_item	2678617	et	3	main
ma	doc_532115409081_item	2678618	et	3	main
ei	doc_532115409081_item	2678619	et	4	main
saaks	doc_532115409081_item	2678620	et	3	main
sest	doc_532115409078_item	2678347	et	4	main
tänapäeval	doc_532115409078_item	2678348	et	3	main
ei	doc_532115409078_item	2678349	et	4	main
ole	doc_532115409078_item	2678350	et	4	main
võimalik	doc_532115409078_item	2678351	et	3	main
ette	doc_532115409078_item	2678352	et	4	main
kujutada	doc_532115409078_item	2678353	et	3	main
arvutit	doc_532115409078_item	2678354	et	3	main
ilma	doc_532115409078_item	2678355	et	4	main
internetita	doc_532115409078_item	2678356	et	4	main
esimesi	doc_532115409078_item	2678321	et	4	main
põhjusel	doc_532115409078_item	2678328	et	3	main
et	doc_532115409078_item	2678330	et	3	main
ilma	doc_532115409078_item	2678332	et	4	main
on	doc_532115409078_item	2678338	et	4	main
võib	doc_532115409078_item	2678342	et	3	main
mina	doc_532115409078_item	2678358	et	4	main
ja	doc_532115409078_item	2678362	et	3	main
ning	doc_532115409078_item	2678364	et	3	main
viimaseid	doc_532115409078_item	2678370	et	3	main
vahetult	doc_532115409078_item	2678373	et	4	main
sündmuse	doc_532115409078_item	2678374	et	3	main
kohalt	doc_532115409078_item	2678375	et	4	main
mis	doc_532115409078_item	2678385	et	4	main
kolm	doc_532115409078_item	2678387	et	3	main
korda	doc_532115409078_item	2678388	et	4	main
päevas	doc_532115409078_item	2678389	et	3	main
mida	doc_532115409078_item	2678395	et	4	main
oma	doc_532115409078_item	2678414	et	4	main
erinevatesse	doc_532115409078_item	2678431	et	4	main
kus	doc_532115409078_item	2678449	et	3	main
ainult	doc_532115409078_item	2678452	et	4	main
sest	doc_532115409078_item	2678454	et	4	main
tõepoolest	doc_532115409078_item	2678455	et	3	main
enamus	doc_532115409078_item	2678456	et	4	main
neist	doc_532115409078_item	2678457	et	4	main
saan	doc_532115409078_item	2678461	et	4	main
telerit	doc_532115409079_item	2678494	et	3	main
leiutis	doc_532115409079_item	2678497	et	3	main
kasulik	doc_532115409079_item	2678500	et	3	main
saan	doc_532115409079_item	2678502	et	4	main
telerist	doc_532115409079_item	2678504	et	4	main
kuulan	doc_532115409079_item	2678507	et	3	main
muusikat	doc_532115409079_item	2678508	et	3	main
ja	doc_532115409079_item	2678509	et	3	main
teiset	doc_532115409079_item	2678510	et	4	main
teler	doc_532115409079_item	2678511	et	3	main
aitab	doc_532115409079_item	2678512	et	3	main
minu	doc_532115409079_item	2678513	et	3	main
teler	doc_532115409079_item	2678517	et	3	main
praegu	doc_532115409079_item	2678523	et	3	main
otsa	doc_532115409079_item	2678526	et	4	main
ma	doc_532115409079_item	2678529	et	3	main
mõtlen	doc_532115409079_item	2678530	et	3	main
aga	doc_532115409079_item	2678542	et	3	main
philips	doc_532115409079_item	2678546	et	4	main
ma	doc_532115409079_item	2678550	et	3	main
ei	doc_532115409079_item	2678551	et	4	main
milleta	doc_532115409080_item	2678557	et	3	main
on	doc_532115409080_item	2678569	et	4	main
ja	doc_532115409080_item	2678571	et	3	main
valmistada	doc_532115409080_item	2678577	et	3	main
kõik	doc_532115409080_item	2678607	et	4	main
uudised	doc_532115409080_item	2678608	et	3	main
ilma	doc_532115409081_item	2678625	et	4	main
korda	doc_532115409081_item	2678632	et	4	main
hiina	doc_532115409081_item	2678641	et	3	main
ma	doc_532115409081_item	2678645	et	3	main
pea	doc_532115409081_item	2678660	et	4	main
ja	doc_532115409081_item	2678661	et	3	main
annab	doc_532115409081_item	2678662	et	3	main
internet	doc_532115409081_item	2678667	et	4	main
väga	doc_532115409081_item	2678670	et	3	main
hed	doc_532115409081_item	2678671	et	4	main
tana	doc_532115409081_item	2678673	et	4	main
lugema	doc_532115409081_item	2678676	et	4	main
palju	doc_532115409081_item	2678677	et	4	main
e-mailid	doc_532115409081_item	2678682	et	4	main
leiutised	doc_532115409082_item	2678686	et	3	main
milleta	doc_532115409082_item	2678688	et	3	main
ma	doc_532115409082_item	2678689	et	3	main
ei	doc_532115409082_item	2678690	et	4	main
elada	doc_532115409082_item	2678692	et	3	main
maailmas	doc_532115409082_item	2678695	et	3	main
arvutiga	doc_532115409082_item	2678701	et	4	main
moobiltelefooniga	doc_532115409082_item	2678702	et	4	main
iga	doc_532115409082_item	2678723	et	4	main
mina	doc_532115409082_item	2678725	et	4	main
muusika	doc_532115409082_item	2678728	et	4	main
kasutab	doc_532115409082_item	2678743	et	3	main
tema	doc_532115409082_item	2678746	et	4	main
mulle	doc_532115409082_item	2678750	et	4	main
esiteks	doc_532115409078_item	2678340	et	3	main
saan	doc_532115409078_item	2678367	et	4	main
teada	doc_532115409078_item	2678368	et	3	main
on	doc_532115409078_item	2678377	et	4	main
telerit	doc_532115409078_item	2678384	et	3	main
programmi	doc_532115409078_item	2678394	et	4	main
elus	doc_532115409078_item	2678400	et	4	main
me	doc_532115409078_item	2678403	et	4	main
muusikat	doc_532115409078_item	2678405	et	3	main
koostama	doc_532115409078_item	2678406	et	3	main
viimaseid	doc_532115409078_item	2678407	et	3	main
ka	doc_532115409078_item	2678419	et	3	main
lisaks	doc_532115409078_item	2678421	et	4	main
oma	doc_532115409078_item	2678423	et	4	main
fotod	doc_532115409078_item	2678424	et	3	main
saada	doc_532115409078_item	2678425	et	4	main
viia	doc_532115409078_item	2678429	et	3	main
neid	doc_532115409078_item	2678430	et	4	main
riigidesse	doc_532115409078_item	2678432	et	4	main
maailmas	doc_532115409078_item	2678433	et	3	main
ei	doc_532115409078_item	2678442	et	4	main
riigiasutust	doc_532115409078_item	2678446	et	4	main
kokkuvõtteks	doc_532115409078_item	2678460	et	3	main
arvutita	doc_532115409078_item	2678470	et	4	main
ilma	doc_532115409079_item	2678493	et	4	main
väga	doc_532115409079_item	2678499	et	3	main
ma	doc_532115409079_item	2678524	et	3	main
on	doc_532115409079_item	2678534	et	4	main
parem	doc_532115409079_item	2678536	et	4	main
osta	doc_532115409079_item	2678540	et	4	main
sony	doc_532115409079_item	2678541	et	4	main
parem	doc_532115409079_item	2678548	et	4	main
tea	doc_532115409079_item	2678552	et	4	main
ei	doc_532115409080_item	2678559	et	4	main
perekond	doc_532115409080_item	2678570	et	3	main
ma	doc_532115409080_item	2678572	et	3	main
vaatan	doc_532115409080_item	2678612	et	3	main
tea	doc_532115409081_item	2678622	et	4	main
ma	doc_532115409081_item	2678627	et	3	main
saaks	doc_532115409081_item	2678629	et	3	main
esimene	doc_532115409081_item	2678631	et	3	main
on	doc_532115409081_item	2678634	et	4	main
minu	doc_532115409081_item	2678635	et	3	main
lemmik	doc_532115409081_item	2678636	et	3	main
jook	doc_532115409081_item	2678637	et	3	main
tee	doc_532115409081_item	2678642	et	4	main
ja	doc_532115409081_item	2678647	et	3	main
tea	doc_532115409081_item	2678649	et	4	main
ka	doc_532115409081_item	2678669	et	3	main
leiutis	doc_532115409081_item	2678672	et	3	main
ma	doc_532115409081_item	2678674	et	3	main
kirjutama	doc_532115409081_item	2678681	et	3	main
me	doc_532115409082_item	2678693	et	4	main
on	doc_532115409082_item	2678697	et	4	main
leiutised	doc_532115409082_item	2678700	et	3	main
autoga	doc_532115409082_item	2678703	et	3	main
ja	doc_532115409082_item	2678704	et	3	main
televiisoriga	doc_532115409082_item	2678705	et	3	main
meie	doc_532115409082_item	2678706	et	4	main
ei	doc_532115409082_item	2678709	et	4	main
minu	doc_532115409082_item	2678730	et	3	main
on	doc_532115409082_item	2678732	et	4	main
playerist	doc_532115409082_item	2678745	et	3	main
playerist	doc_532115409082_item	2678755	et	3	main
muusika	doc_532115409082_item	2678756	et	4	main
player	doc_532115409082_item	2678757	et	4	main
see	doc_532115409082_item	2678758	et	3	main
mina	doc_532115409082_item	2678763	et	4	main
leiutus	doc_532115409082_item	2678766	et	4	main
elada	doc_532115409083_item	2678797	et	3	main
meie	doc_532115409083_item	2678812	et	4	main
inimene	doc_532115409083_item	2678826	et	3	main
metsas	doc_532115409083_item	2678828	et	3	main
saarel	doc_532115409083_item	2678830	et	3	main
ilma	doc_532115409083_item	2678831	et	4	main
elanikudest	doc_532115409083_item	2678832	et	3	main
siis	doc_532115409083_item	2678833	et	3	main
vaja	doc_532115409083_item	2678834	et	4	main
soe	doc_532115409083_item	2678839	et	4	main
saaks	doc_532115409084_item	2678845	et	3	main
seal	doc_532115409084_item	2678847	et	4	main
nii	doc_532115409084_item	2678849	et	3	main
näiteks	doc_532115409078_item	2678357	et	4	main
arvuti	doc_532115409078_item	2678365	et	4	main
abil	doc_532115409078_item	2678366	et	4	main
uudiseid	doc_532115409078_item	2678371	et	3	main
ikkagi	doc_532115409078_item	2678378	et	4	main
on	doc_532115409078_item	2678392	et	4	main
oma	doc_532115409078_item	2678398	et	4	main
filme	doc_532115409078_item	2678408	et	3	main
kirjutada	doc_532115409078_item	2678410	et	3	main
kasutada	doc_532115409078_item	2678412	et	3	main
kõrgkoolides	doc_532115409078_item	2678420	et	3	main
saame	doc_532115409078_item	2678422	et	4	main
üle	doc_532115409078_item	2678428	et	3	main
kolmandaks	doc_532115409078_item	2678434	et	4	main
arvuti	doc_532115409078_item	2678435	et	4	main
saa	doc_532115409078_item	2678443	et	4	main
ette	doc_532115409078_item	2678444	et	4	main
firmat	doc_532115409078_item	2678448	et	3	main
andmebaasid	doc_532115409078_item	2678450	et	3	main
on	doc_532115409078_item	2678458	et	4	main
öelda	doc_532115409078_item	2678462	et	4	main
tulevikus	doc_532115409078_item	2678464	et	4	main
sest	doc_532115409079_item	2678495	et	4	main
see	doc_532115409079_item	2678496	et	3	main
väga	doc_532115409079_item	2678520	et	3	main
ning	doc_532115409078_item	2678427	et	3	main
me	doc_532115409078_item	2678441	et	4	main
või	doc_532115409078_item	2678447	et	4	main
säilitakse	doc_532115409078_item	2678451	et	3	main
arvutides	doc_532115409078_item	2678459	et	4	main
et	doc_532115409078_item	2678463	et	3	main
mina	doc_532115409078_item	2678465	et	4	main
kindlasti	doc_532115409078_item	2678466	et	3	main
ei	doc_532115409078_item	2678467	et	4	main
saaks	doc_532115409078_item	2678468	et	3	main
elada	doc_532115409078_item	2678471	et	3	main
sest	doc_532115409078_item	2678472	et	4	main
arvuti	doc_532115409078_item	2678473	et	4	main
on	doc_532115409078_item	2678474	et	4	main
töövahend	doc_532115409078_item	2678475	et	3	main
infohallikas	doc_532115409078_item	2678476	et	4	main
ning	doc_532115409078_item	2678477	et	3	main
väärtuslik	doc_532115409078_item	2678478	et	3	main
side	doc_532115409078_item	2678479	et	4	main
kogu	doc_532115409078_item	2678480	et	4	main
maailmaga	doc_532115409078_item	2678481	et	3	main
leiutised	doc_532115409079_item	2678482	et	3	main
ilma	doc_532115409079_item	2678483	et	4	main
milleta	doc_532115409079_item	2678484	et	3	main
ma	doc_532115409079_item	2678485	et	3	main
ei	doc_532115409079_item	2678486	et	4	main
saaks	doc_532115409079_item	2678487	et	3	main
elada	doc_532115409079_item	2678488	et	3	main
ma	doc_532115409079_item	2678489	et	3	main
ei	doc_532115409079_item	2678490	et	4	main
saaks	doc_532115409079_item	2678491	et	3	main
elada	doc_532115409079_item	2678492	et	3	main
on	doc_532115409079_item	2678498	et	4	main
ma	doc_532115409079_item	2678501	et	3	main
elus	doc_532115409079_item	2678514	et	4	main
ei	doc_532115409079_item	2678518	et	4	main
ole	doc_532115409079_item	2678519	et	4	main
firmast	doc_532115409079_item	2678532	et	4	main
kõge	doc_532115409079_item	2678535	et	4	main
minu	doc_532115409079_item	2678537	et	3	main
arvab	doc_532115409079_item	2678544	et	3	main
mida	doc_532115409079_item	2678553	et	4	main
saaks	doc_532115409080_item	2678560	et	3	main
mina	doc_532115409080_item	2678562	et	4	main
saa	doc_532115409080_item	2678564	et	4	main
elada	doc_532115409080_item	2678565	et	3	main
ilma	doc_532115409080_item	2678566	et	4	main
elektripliidita	doc_532115409080_item	2678567	et	3	main
mull	doc_532115409080_item	2678568	et	3	main
sööki	doc_532115409080_item	2678576	et	4	main
ma	doc_532115409080_item	2678611	et	3	main
telerist	doc_532115409080_item	2678614	et	4	main
leiutised	doc_532115409081_item	2678615	et	3	main
elada	doc_532115409081_item	2678621	et	3	main
see	doc_532115409081_item	2678633	et	3	main
ma	doc_532115409081_item	2678638	et	3	main
joogi	doc_532115409081_item	2678648	et	4	main
mulle	doc_532115409081_item	2678663	et	4	main
ued	doc_532115409081_item	2678664	et	4	main
mõtled	doc_532115409081_item	2678665	et	3	main
raamatud	doc_532115409081_item	2678678	et	4	main
kui	doc_532115409081_item	2678683	et	3	main
elame	doc_532115409082_item	2678694	et	3	main
kus	doc_532115409082_item	2678696	et	3	main
väga	doc_532115409082_item	2678698	et	3	main
palju	doc_532115409082_item	2678699	et	4	main
elu	doc_532115409082_item	2678708	et	4	main
hea	doc_532115409079_item	2678521	et	4	main
teler	doc_532115409079_item	2678533	et	3	main
abikaasa	doc_532115409079_item	2678538	et	4	main
sovitab	doc_532115409079_item	2678539	et	4	main
et	doc_532115409079_item	2678545	et	3	main
teha	doc_532115409079_item	2678554	et	3	main
leiutised	doc_532115409080_item	2678555	et	3	main
ilma	doc_532115409080_item	2678556	et	4	main
elada	doc_532115409080_item	2678561	et	3	main
pean	doc_532115409080_item	2678573	et	4	main
teine	doc_532115409080_item	2678578	et	3	main
leiutis	doc_532115409080_item	2678579	et	3	main
on	doc_532115409080_item	2678580	et	4	main
külmkapp	doc_532115409080_item	2678581	et	3	main
mina	doc_532115409080_item	2678582	et	4	main
ei	doc_532115409080_item	2678583	et	4	main
saa	doc_532115409080_item	2678584	et	4	main
kauplusse	doc_532115409080_item	2678585	et	3	main
minna	doc_532115409080_item	2678586	et	3	main
iga	doc_532115409080_item	2678587	et	4	main
päev	doc_532115409080_item	2678588	et	3	main
ostan	doc_532115409080_item	2678589	et	3	main
toidu	doc_532115409080_item	2678590	et	3	main
üks-kaks	doc_532115409080_item	2678591	et	3	main
korda	doc_532115409080_item	2678592	et	4	main
nädalas	doc_532115409080_item	2678593	et	3	main
ja	doc_532115409080_item	2678594	et	3	main
hojan	doc_532115409080_item	2678595	et	4	main
toidu	doc_532115409080_item	2678596	et	3	main
külmkappis	doc_532115409080_item	2678597	et	4	main
väga	doc_532115409080_item	2678598	et	3	main
raske	doc_532115409080_item	2678599	et	4	main
elada	doc_532115409080_item	2678600	et	3	main
ilma	doc_532115409080_item	2678601	et	4	main
televisorida	doc_532115409080_item	2678602	et	4	main
tema	doc_532115409080_item	2678603	et	4	main
on	doc_532115409080_item	2678604	et	4	main
minu	doc_532115409080_item	2678605	et	3	main
sõber	doc_532115409080_item	2678606	et	3	main
kontserdid	doc_532115409080_item	2678610	et	3	main
ainult	doc_532115409080_item	2678613	et	4	main
on	doc_532115409081_item	2678623	et	4	main
milleta	doc_532115409081_item	2678626	et	3	main
ei	doc_532115409081_item	2678628	et	4	main
elada	doc_532115409081_item	2678630	et	3	main
huvitan	doc_532115409081_item	2678640	et	3	main
tradition	doc_532115409081_item	2678643	et	4	main
hiina	doc_532115409081_item	2678650	et	3	main
mul	doc_532115409081_item	2678652	et	3	main
väga	doc_532115409081_item	2678654	et	3	main
meldib	doc_532115409081_item	2678655	et	4	main
see	doc_532115409081_item	2678656	et	3	main
ja	doc_532115409081_item	2678666	et	3	main
on	doc_532115409081_item	2678668	et	4	main
internetis	doc_532115409081_item	2678679	et	4	main
ja	doc_532115409081_item	2678680	et	3	main
kiirem	doc_532115409081_item	2678684	et	4	main
posti	doc_532115409081_item	2678685	et	4	main
ilma	doc_532115409082_item	2678687	et	4	main
saaks	doc_532115409082_item	2678691	et	3	main
igapäevane	doc_532115409082_item	2678707	et	4	main
kasutan	doc_532115409082_item	2678721	et	3	main
päev	doc_532115409082_item	2678724	et	3	main
armastan	doc_532115409082_item	2678726	et	3	main
kuuluda	doc_532115409082_item	2678729	et	4	main
muusika	doc_532115409082_item	2678747	et	4	main
ei	doc_532115409082_item	2678748	et	4	main
segastada	doc_532115409082_item	2678749	et	3	main
on	doc_532115409082_item	2678759	et	4	main
elada	doc_532115409082_item	2678765	et	3	main
ilma	doc_532115409082_item	2678767	et	4	main
ei	doc_532115409083_item	2678795	et	4	main
on	doc_532115409083_item	2678799	et	4	main
ja	doc_532115409083_item	2678800	et	3	main
ja	doc_532115409083_item	2678802	et	3	main
oskus	doc_532115409083_item	2678803	et	3	main
põle	doc_532115409083_item	2678804	et	4	main
teha	doc_532115409083_item	2678805	et	3	main
ja	doc_532115409083_item	2678806	et	3	main
elekter	doc_532115409083_item	2678807	et	3	main
ja	doc_532115409083_item	2678808	et	3	main
kõikidest	doc_532115409083_item	2678822	et	4	main
mugadest	doc_532115409083_item	2678823	et	4	main
ag	doc_532115409083_item	2678824	et	4	main
toide	doc_532115409083_item	2678837	et	4	main
ja	doc_532115409083_item	2678838	et	3	main
milleta	doc_532115409084_item	2678842	et	3	main
aitavad	doc_532115409084_item	2678853	et	4	main
mulle	doc_532115409084_item	2678854	et	4	main
mobiili	doc_532115409084_item	2678859	et	4	main
edasi	doc_532115409084_item	2678865	et	3	main
leiutis	doc_532115409084_item	2678870	et	3	main
ei	doc_532115409085_item	2678875	et	4	main
elada	doc_532115409085_item	2678877	et	3	main
on	doc_532115409085_item	2678879	et	4	main
öelda	doc_532115409085_item	2678881	et	4	main
kõige	doc_532115409085_item	2678884	et	4	main
arvan	doc_532115409085_item	2678888	et	3	main
ja	doc_532115409085_item	2678895	et	3	main
meie	doc_532115409085_item	2678923	et	4	main
sajandis	doc_532115409085_item	2678927	et	3	main
tehe	doc_532115409085_item	2678946	et	3	main
inimesed	doc_532115409085_item	2678949	et	3	main
mõtelda	doc_532115409085_item	2678959	et	4	main
see	doc_532115409085_item	2678965	et	3	main
saavad	doc_532115409085_item	2678978	et	4	main
ka	doc_532115409085_item	2678979	et	3	main
palju	doc_532115409085_item	2678983	et	4	main
ei	doc_532115409085_item	2678985	et	4	main
elada	doc_532115409085_item	2678990	et	3	main
kõvasti	doc_532115409085_item	2679022	et	3	main
hästi	doc_532115409085_item	2679025	et	3	main
arvan	doc_532115409085_item	2679032	et	3	main
ja	doc_532115409085_item	2679039	et	3	main
milleta	doc_532115409086_item	2679044	et	3	main
sajandil	doc_532115409086_item	2679056	et	3	main
on	doc_532115409086_item	2679058	et	4	main
elu	doc_532115409086_item	2679070	et	4	main
ette	doc_532115409086_item	2679071	et	4	main
kujutada	doc_532115409086_item	2679072	et	3	main
kuna	doc_532115409086_item	2679079	et	3	main
leiutis	doc_532115409081_item	2678624	et	3	main
vaga	doc_532115409081_item	2678639	et	4	main
mõnikord	doc_532115409081_item	2678644	et	3	main
tegen	doc_532115409081_item	2678646	et	4	main
moodi	doc_532115409081_item	2678651	et	4	main
on	doc_532115409081_item	2678653	et	4	main
tea	doc_532115409081_item	2678657	et	4	main
puhastab	doc_532115409081_item	2678658	et	3	main
minu	doc_532115409081_item	2678659	et	3	main
võin	doc_532115409081_item	2678675	et	3	main
ole	doc_532115409082_item	2678710	et	4	main
võimalik	doc_532115409082_item	2678711	et	3	main
köögis	doc_532115409082_item	2678713	et	3	main
meie	doc_532115409082_item	2678712	et	4	main
seisavad	doc_532115409082_item	2678714	et	3	main
külmakapp	doc_532115409082_item	2678715	et	3	main
köögikombain	doc_532115409082_item	2678716	et	3	main
rööster	doc_532115409082_item	2678717	et	4	main
mikrolaenuahju	doc_532115409082_item	2678718	et	4	main
ja	doc_532115409082_item	2678719	et	3	main
mina	doc_532115409082_item	2678720	et	4	main
ilus	doc_532115409082_item	2678727	et	4	main
kodus	doc_532115409082_item	2678731	et	4	main
raadio	doc_532115409082_item	2678733	et	4	main
ja	doc_532115409082_item	2678734	et	3	main
magnetoola	doc_532115409082_item	2678735	et	4	main
minu	doc_532115409082_item	2678736	et	3	main
poeg	doc_532115409082_item	2678737	et	3	main
kuulub	doc_532115409082_item	2678738	et	3	main
hard-rocky	doc_532115409082_item	2678739	et	4	main
muusika	doc_532115409082_item	2678740	et	4	main
mõnikord	doc_532115409082_item	2678741	et	3	main
ja	doc_532115409082_item	2678742	et	3	main
meeldi	doc_532115409082_item	2678754	et	4	main
saan	doc_532115409082_item	2678764	et	4	main
saame	doc_532115409083_item	2678796	et	4	main
need	doc_532115409083_item	2678798	et	3	main
rehvid	doc_532115409083_item	2678801	et	4	main
elu	doc_532115409083_item	2678813	et	4	main
praegu	doc_532115409083_item	2678814	et	3	main
nii	doc_532115409083_item	2678815	et	3	main
mugav	doc_532115409083_item	2678816	et	3	main
et	doc_532115409083_item	2678817	et	3	main
ei	doc_532115409083_item	2678818	et	4	main
tahame	doc_532115409083_item	2678819	et	3	main
elada	doc_532115409083_item	2678820	et	3	main
ilma	doc_532115409083_item	2678821	et	4	main
kui	doc_532115409083_item	2678825	et	3	main
või	doc_532115409083_item	2678829	et	4	main
ainult	doc_532115409083_item	2678835	et	4	main
leiutised	doc_532115409084_item	2678840	et	3	main
ma	doc_532115409084_item	2678843	et	3	main
on	doc_532115409084_item	2678848	et	4	main
elada	doc_532115409084_item	2678855	et	3	main
näiteks	doc_532115409084_item	2678856	et	4	main
elektroonika	doc_532115409084_item	2678857	et	4	main
telefoonid	doc_532115409084_item	2678860	et	4	main
minule	doc_532115409085_item	2678878	et	3	main
raske	doc_532115409085_item	2678880	et	4	main
kõik	doc_532115409085_item	2678890	et	4	main
huvitavad	doc_532115409085_item	2678896	et	4	main
asi	doc_532115409085_item	2678922	et	4	main
kodu	doc_532115409085_item	2678938	et	4	main
mida	doc_532115409085_item	2678948	et	4	main
tegid	doc_532115409085_item	2678953	et	4	main
käega	doc_532115409085_item	2678955	et	3	main
arvutid	doc_532115409085_item	2678956	et	4	main
probleem	doc_532115409085_item	2678966	et	3	main
on	doc_532115409085_item	2678967	et	4	main
kõige	doc_532115409085_item	2678969	et	4	main
tähtsam	doc_532115409085_item	2678970	et	4	main
neid	doc_532115409082_item	2678722	et	4	main
väikest	doc_532115409082_item	2678744	et	4	main
ei	doc_532115409082_item	2678753	et	4	main
milleta	doc_532115409082_item	2678762	et	3	main
milleta	doc_532115409082_item	2678768	et	3	main
ma	doc_532115409082_item	2678769	et	3	main
ei	doc_532115409082_item	2678770	et	4	main
saaks	doc_532115409082_item	2678771	et	3	main
elada	doc_532115409082_item	2678772	et	3	main
see	doc_532115409082_item	2678773	et	3	main
on	doc_532115409082_item	2678774	et	4	main
automaatiline	doc_532115409082_item	2678775	et	4	main
pesumasina	doc_532115409082_item	2678776	et	3	main
leiutised	doc_532115409083_item	2678777	et	3	main
milleta	doc_532115409083_item	2678779	et	3	main
ilma	doc_532115409083_item	2678778	et	4	main
ma	doc_532115409083_item	2678780	et	3	main
ei	doc_532115409083_item	2678781	et	4	main
saaks	doc_532115409083_item	2678782	et	3	main
elada	doc_532115409083_item	2678783	et	3	main
kahjuks	doc_532115409083_item	2678784	et	4	main
ma	doc_532115409083_item	2678785	et	3	main
ei	doc_532115409083_item	2678786	et	4	main
saa	doc_532115409083_item	2678787	et	4	main
öelda	doc_532115409083_item	2678788	et	4	main
on	doc_532115409083_item	2678790	et	4	main
et	doc_532115409083_item	2678789	et	3	main
ainult	doc_532115409083_item	2678791	et	4	main
üks	doc_532115409083_item	2678792	et	3	main
leiutis	doc_532115409083_item	2678793	et	3	main
aga	doc_532115409082_item	2678751	et	3	main
minul	doc_532115409082_item	2678752	et	3	main
leiutis	doc_532115409082_item	2678760	et	3	main
ilma	doc_532115409082_item	2678761	et	4	main
side	doc_532115409083_item	2678809	et	4	main
ja	doc_532115409083_item	2678810	et	3	main
milleta	doc_532115409083_item	2678794	et	3	main
ne	doc_532115409083_item	2678811	et	4	main
ei	doc_532115409084_item	2678844	et	4	main
elada	doc_532115409084_item	2678846	et	3	main
palju	doc_532115409084_item	2678850	et	4	main
leitusid	doc_532115409084_item	2678851	et	4	main
ahjud	doc_532115409084_item	2678862	et	3	main
on	doc_532115409084_item	2678867	et	4	main
ilma	doc_532115409085_item	2678872	et	4	main
milleta	doc_532115409085_item	2678873	et	3	main
milline	doc_532115409085_item	2678882	et	3	main
kasulik	doc_532115409085_item	2678921	et	3	main
selles	doc_532115409085_item	2678926	et	4	main
kõike	doc_532115409085_item	2678933	et	4	main
ma	doc_532115409085_item	2678934	et	3	main
arvan	doc_532115409085_item	2678935	et	3	main
mitte	doc_532115409085_item	2678936	et	3	main
lihtned	doc_532115409085_item	2678937	et	4	main
oskavad	doc_532115409085_item	2678944	et	4	main
sajandi	doc_532115409085_item	2678951	et	3	main
oma	doc_532115409085_item	2678954	et	4	main
ei	doc_532115409085_item	2678957	et	4	main
arvan	doc_532115409085_item	2678963	et	3	main
tänaseks	doc_532115409085_item	2678968	et	4	main
juba	doc_532115409085_item	2678982	et	3	main
ilma	doc_532115409085_item	2678991	et	4	main
arvutita	doc_532115409085_item	2678992	et	4	main
ja	doc_532115409085_item	2678993	et	3	main
väga	doc_532115409085_item	2679024	et	3	main
ma	doc_532115409085_item	2679031	et	3	main
tähtsam	doc_532115409085_item	2679038	et	4	main
leiutised	doc_532115409086_item	2679042	et	3	main
ma	doc_532115409086_item	2679045	et	3	main
öelda	doc_532115409086_item	2679053	et	4	main
et	doc_532115409086_item	2679054	et	3	main
viimasel	doc_532115409086_item	2679055	et	3	main
asju	doc_532115409086_item	2679062	et	3	main
ei	doc_532115409086_item	2679073	et	4	main
mängi	doc_532115409086_item	2679074	et	4	main
mingit	doc_532115409086_item	2679075	et	3	main
rolli	doc_532115409086_item	2679076	et	4	main
ka	doc_532115409086_item	2679077	et	3	main
ka	doc_532115409086_item	2679084	et	3	main
püüavad	doc_532115409086_item	2679086	et	3	main
olla	doc_532115409086_item	2679092	et	3	main
uuringute	doc_532115409086_item	2679094	et	3	main
mõtelda	doc_532115409086_item	2679124	et	4	main
need	doc_532115409086_item	2679130	et	3	main
ja	doc_532115409086_item	2679143	et	3	main
tagasi	doc_532115409086_item	2679147	et	3	main
kõige	doc_532115409086_item	2679163	et	4	main
saa	doc_532115409086_item	2679172	et	4	main
ma	doc_532115409086_item	2679173	et	3	main
selleta	doc_532115409086_item	2679174	et	3	main
elada	doc_532115409086_item	2679175	et	3	main
sest	doc_532115409086_item	2679176	et	4	main
erinevad	doc_532115409086_item	2679185	et	4	main
susteemid	doc_532115409086_item	2679186	et	4	main
on	doc_532115409086_item	2679191	et	4	main
tähelepanu	doc_532115409086_item	2679200	et	4	main
pärast	doc_532115409086_item	2679223	et	4	main
tööta	doc_532115409086_item	2679237	et	4	main
juhtus	doc_532115409086_item	2679239	et	3	main
meil	doc_532115409086_item	2679243	et	4	main
olnud	doc_532115409086_item	2679245	et	4	main
elektrit	doc_532115409086_item	2679246	et	3	main
umbes	doc_532115409086_item	2679247	et	4	main
6	doc_532115409086_item	2679248	et	2	main
arvuti	doc_532115409086_item	2679263	et	4	main
pliit	doc_532115409086_item	2679264	et	3	main
aru	doc_532115409086_item	2679277	et	4	main
mille	doc_532115409086_item	2679309	et	3	main
töötavad	doc_532115409086_item	2679311	et	4	main
elada	doc_532115409087_item	2679320	et	3	main
xx	doc_532115409087_item	2679321	et	4	main
sajandi	doc_532115409087_item	2679322	et	3	main
ei	doc_532115409087_item	2679346	et	4	main
elada	doc_532115409087_item	2679348	et	3	main
televisioonita	doc_532115409087_item	2679350	et	4	main
sajandil	doc_532115409087_item	2679357	et	3	main
elektrita	doc_532115409087_item	2679360	et	3	main
et	doc_532115409087_item	2679364	et	3	main
on	doc_532115409083_item	2678827	et	4	main
vesi	doc_532115409083_item	2678836	et	4	main
ilma	doc_532115409084_item	2678841	et	4	main
ja	doc_532115409084_item	2678863	et	3	main
nii	doc_532115409084_item	2678864	et	3	main
computrid	doc_532115409084_item	2678866	et	4	main
ka	doc_532115409084_item	2678868	et	3	main
leiutised	doc_532115409085_item	2678871	et	3	main
ma	doc_532115409085_item	2678874	et	3	main
saaks	doc_532115409085_item	2678876	et	3	main
on	doc_532115409085_item	2678883	et	4	main
tähtsam	doc_532115409085_item	2678885	et	4	main
leiutis	doc_532115409085_item	2678886	et	3	main
ma	doc_532115409085_item	2678887	et	3	main
et	doc_532115409085_item	2678889	et	3	main
on	doc_532115409085_item	2678892	et	4	main
kasulikud	doc_532115409085_item	2678894	et	3	main
aga	doc_532115409085_item	2678897	et	3	main
21	doc_532115409085_item	2678898	et	2	main
sajand	doc_532115409085_item	2678899	et	3	main
on	doc_532115409085_item	2678900	et	4	main
arvuti	doc_532115409085_item	2678901	et	4	main
sajand	doc_532115409085_item	2678902	et	3	main
personaal	doc_532115409085_item	2678903	et	3	main
kodune	doc_532115409085_item	2678904	et	4	main
arvuti	doc_532115409085_item	2678905	et	4	main
ei	doc_532115409085_item	2678906	et	4	main
ole	doc_532115409085_item	2678907	et	4	main
leiutud	doc_532115409085_item	2678908	et	4	main
ammu	doc_532115409085_item	2678909	et	4	main
umbes	doc_532115409085_item	2678910	et	4	main
pool	doc_532115409085_item	2678911	et	4	main
sajandi	doc_532115409085_item	2678912	et	3	main
tagasi	doc_532115409085_item	2678913	et	3	main
minu	doc_532115409085_item	2678914	et	3	main
arust	doc_532115409085_item	2678915	et	4	main
see	doc_532115409085_item	2678916	et	3	main
on	doc_532115409085_item	2678917	et	4	main
kõige	doc_532115409085_item	2678918	et	4	main
tähtis	doc_532115409085_item	2678919	et	4	main
ja	doc_532115409085_item	2678920	et	3	main
ja	doc_532115409085_item	2678925	et	3	main
arvutid	doc_532115409085_item	2678939	et	4	main
aga	doc_532115409085_item	2678940	et	3	main
laboratooriumi	doc_532115409085_item	2678941	et	4	main
ise	doc_532115409085_item	2678945	et	4	main
paar	doc_532115409085_item	2678950	et	3	main
oska	doc_532115409085_item	2678958	et	4	main
et	doc_532115409085_item	2678964	et	3	main
mõtelda	doc_532115409085_item	2678980	et	4	main
saa	doc_532115409085_item	2678989	et	4	main
ja	doc_532115409085_item	2679023	et	3	main
jätkub	doc_532115409085_item	2679027	et	3	main
sajandil	doc_532115409085_item	2679030	et	3	main
arvuti	doc_532115409085_item	2679034	et	4	main
tänaseks	doc_532115409085_item	2679036	et	4	main
kõige	doc_532115409085_item	2679037	et	4	main
kasulikkum	doc_532115409085_item	2679040	et	4	main
saaks	doc_532115409086_item	2679047	et	3	main
kuid	doc_532115409084_item	2678852	et	4	main
tooted	doc_532115409084_item	2678858	et	3	main
köögikombainid	doc_532115409084_item	2678861	et	3	main
tõsine	doc_532115409084_item	2678869	et	4	main
leiud	doc_532115409085_item	2678891	et	3	main
väga	doc_532115409085_item	2678893	et	3	main
elus	doc_532115409085_item	2678924	et	4	main
selleks	doc_532115409085_item	2678928	et	4	main
päevaks	doc_532115409085_item	2678929	et	3	main
arvuti	doc_532115409085_item	2678930	et	4	main
saab	doc_532115409085_item	2678931	et	3	main
vahetada	doc_532115409085_item	2678932	et	3	main
arvutid	doc_532115409085_item	2678942	et	4	main
nad	doc_532115409085_item	2678943	et	3	main
seda	doc_532115409085_item	2678947	et	3	main
tagasi	doc_532115409085_item	2678952	et	3	main
ainult	doc_532115409085_item	2678960	et	4	main
töötaga	doc_532115409085_item	2678961	et	4	main
ma	doc_532115409085_item	2678962	et	3	main
arvuti	doc_532115409085_item	2678976	et	4	main
protsessorid	doc_532115409085_item	2678977	et	3	main
tänaseks	doc_532115409085_item	2678981	et	4	main
inimesi	doc_532115409085_item	2678984	et	4	main
oska	doc_532115409085_item	2678986	et	4	main
ja	doc_532115409085_item	2678987	et	3	main
sellest	doc_532115409085_item	2678994	et	4	main
saab	doc_532115409085_item	2678995	et	3	main
aru	doc_532115409085_item	2678997	et	4	main
saada	doc_532115409085_item	2678998	et	4	main
tegelikult	doc_532115409085_item	2678999	et	4	main
on	doc_532115409085_item	2679000	et	4	main
päris	doc_532115409085_item	2679001	et	4	main
mugav	doc_532115409085_item	2679002	et	3	main
kontrollida	doc_532115409085_item	2679003	et	4	main
oma	doc_532115409085_item	2679004	et	4	main
postkasti	doc_532115409085_item	2679005	et	4	main
interneti	doc_532115409085_item	2679006	et	4	main
abiks	doc_532115409085_item	2679007	et	3	main
vaadata	doc_532115409085_item	2679008	et	4	main
filme	doc_532115409085_item	2679009	et	3	main
kuulata	doc_532115409085_item	2679010	et	4	main
muusikat	doc_532115409085_item	2679011	et	3	main
ja	doc_532115409085_item	2679012	et	3	main
lihtsalt	doc_532115409085_item	2679013	et	4	main
arve	doc_532115409085_item	2679014	et	4	main
selleks	doc_532115409085_item	2679016	et	4	main
päevaks	doc_532115409085_item	2679017	et	3	main
maksta	doc_532115409085_item	2679015	et	4	main
arvuti	doc_532115409085_item	2679018	et	4	main
aitab	doc_532115409085_item	2679019	et	3	main
meile	doc_532115409085_item	2679020	et	4	main
väga	doc_532115409085_item	2679021	et	3	main
aidata	doc_532115409085_item	2679028	et	4	main
et	doc_532115409085_item	2679033	et	3	main
ei	doc_532115409086_item	2679046	et	4	main
kõige	doc_532115409086_item	2679049	et	4	main
on	doc_532115409086_item	2679051	et	4	main
protsesse	doc_532115409086_item	2679063	et	3	main
oma	doc_532115409086_item	2679069	et	4	main
vanus	doc_532115409086_item	2679078	et	4	main
tänapäeval	doc_532115409086_item	2679080	et	3	main
aga	doc_532115409085_item	2678971	et	3	main
mõned	doc_532115409085_item	2678972	et	3	main
räägivad	doc_532115409085_item	2678973	et	3	main
et	doc_532115409085_item	2678974	et	3	main
varsti	doc_532115409085_item	2678975	et	3	main
ei	doc_532115409085_item	2678988	et	4	main
ikka	doc_532115409085_item	2678996	et	4	main
ja	doc_532115409085_item	2679026	et	3	main
järgmisel	doc_532115409085_item	2679029	et	3	main
on	doc_532115409085_item	2679035	et	4	main
leiutis	doc_532115409085_item	2679041	et	3	main
ilma	doc_532115409086_item	2679043	et	4	main
pealt	doc_532115409086_item	2679050	et	4	main
vaja	doc_532115409086_item	2679052	et	4	main
erinevaid	doc_532115409086_item	2679061	et	4	main
tänapäevane	doc_532115409086_item	2679065	et	4	main
ei	doc_532115409086_item	2679067	et	4	main
saab	doc_532115409086_item	2679068	et	3	main
kui	doc_532115409086_item	2679083	et	3	main
võimalusi	doc_532115409086_item	2679090	et	3	main
kursuses	doc_532115409086_item	2679095	et	3	main
võin	doc_532115409086_item	2679097	et	3	main
mina	doc_532115409086_item	2679096	et	4	main
öelda	doc_532115409086_item	2679098	et	4	main
et	doc_532115409086_item	2679099	et	3	main
olen	doc_532115409086_item	2679100	et	3	main
pigem	doc_532115409086_item	2679101	et	3	main
tavaline	doc_532115409086_item	2679102	et	4	main
inimene	doc_532115409086_item	2679103	et	3	main
oma	doc_532115409086_item	2679104	et	4	main
vajadustega	doc_532115409086_item	2679105	et	3	main
muidugi	doc_532115409086_item	2679106	et	4	main
kasutan	doc_532115409086_item	2679107	et	3	main
mobiiltelefoni	doc_532115409086_item	2679108	et	4	main
arvutit	doc_532115409086_item	2679109	et	3	main
interneti	doc_532115409086_item	2679110	et	4	main
ja	doc_532115409086_item	2679111	et	3	main
erinevaid	doc_532115409086_item	2679112	et	4	main
asju	doc_532115409086_item	2679113	et	3	main
mis	doc_532115409086_item	2679114	et	4	main
on	doc_532115409086_item	2679115	et	4	main
juba	doc_532115409086_item	2679116	et	3	main
ammu	doc_532115409086_item	2679117	et	4	main
muutusid	doc_532115409086_item	2679118	et	4	main
tavapäraseks	doc_532115409086_item	2679119	et	4	main
aga	doc_532115409086_item	2679120	et	3	main
kui	doc_532115409086_item	2679121	et	3	main
hästi	doc_532115409086_item	2679123	et	3	main
kinnitada	doc_532115409086_item	2679127	et	3	main
asendada	doc_532115409086_item	2679142	et	3	main
elasid	doc_532115409086_item	2679148	et	4	main
nendel	doc_532115409086_item	2679152	et	4	main
on	doc_532115409086_item	2679162	et	4	main
linnaelanik	doc_532115409086_item	2679170	et	3	main
ei	doc_532115409086_item	2679171	et	4	main
ja	doc_532115409086_item	2679183	et	3	main
töötavad	doc_532115409086_item	2679187	et	4	main
elektri	doc_532115409086_item	2679188	et	3	main
veel	doc_532115409086_item	2679194	et	4	main
nii	doc_532115409086_item	2679195	et	3	main
paljud	doc_532115409086_item	2679196	et	3	main
inimesed	doc_532115409086_item	2679197	et	3	main
ei	doc_532115409086_item	2679198	et	4	main
neid	doc_532115409086_item	2679203	et	4	main
elada	doc_532115409086_item	2679048	et	3	main
inimkond	doc_532115409086_item	2679057	et	3	main
välja	doc_532115409086_item	2679059	et	4	main
mõelnud	doc_532115409086_item	2679060	et	4	main
milleta	doc_532115409086_item	2679064	et	3	main
inimene	doc_532115409086_item	2679066	et	3	main
noored	doc_532115409086_item	2679082	et	3	main
väga	doc_532115409086_item	2679122	et	3	main
et	doc_532115409086_item	2679128	et	3	main
ei	doc_532115409086_item	2679132	et	4	main
inimesed	doc_532115409086_item	2679144	et	3	main
selleta	doc_532115409086_item	2679150	et	3	main
ei	doc_532115409086_item	2679153	et	4	main
mingeid	doc_532115409086_item	2679155	et	3	main
probleeme	doc_532115409086_item	2679156	et	3	main
nii	doc_532115409086_item	2679157	et	3	main
võin	doc_532115409086_item	2679158	et	3	main
öelda	doc_532115409086_item	2679159	et	4	main
et	doc_532115409086_item	2679160	et	3	main
elekter	doc_532115409086_item	2679161	et	3	main
ajaloos	doc_532115409086_item	2679167	et	4	main
kuna	doc_532115409086_item	2679168	et	3	main
olen	doc_532115409086_item	2679169	et	3	main
paljud	doc_532115409086_item	2679184	et	3	main
pööra	doc_532115409086_item	2679199	et	4	main
nii	doc_532115409086_item	2679081	et	3	main
täiskasvanud	doc_532115409086_item	2679085	et	4	main
rohkem	doc_532115409086_item	2679087	et	4	main
kasutada	doc_532115409086_item	2679088	et	3	main
uusi	doc_532115409086_item	2679089	et	3	main
ja	doc_532115409086_item	2679091	et	3	main
uute	doc_532115409086_item	2679093	et	3	main
kõik	doc_532115409086_item	2679129	et	4	main
ole	doc_532115409086_item	2679133	et	4	main
ma	doc_532115409086_item	2679135	et	3	main
arvan	doc_532115409086_item	2679136	et	3	main
sest	doc_532115409086_item	2679138	et	4	main
neid	doc_532115409086_item	2679139	et	4	main
võib	doc_532115409086_item	2679140	et	3	main
20	doc_532115409086_item	2679145	et	2	main
ilma	doc_532115409086_item	2679149	et	4	main
tähtsam	doc_532115409086_item	2679164	et	4	main
leiutis	doc_532115409086_item	2679165	et	3	main
elekter	doc_532115409086_item	2679190	et	3	main
oluline	doc_532115409086_item	2679193	et	4	main
mis	doc_532115409086_item	2679202	et	4	main
asjad	doc_532115409086_item	2679231	et	3	main
mittevajalikkuks	doc_532115409086_item	2679233	et	4	main
kuna	doc_532115409086_item	2679234	et	3	main
nad	doc_532115409086_item	2679235	et	3	main
ei	doc_532115409086_item	2679236	et	4	main
tundi	doc_532115409086_item	2679249	et	4	main
ja	doc_532115409086_item	2679250	et	3	main
juba	doc_532115409086_item	2679251	et	3	main
siis	doc_532115409086_item	2679252	et	3	main
ma	doc_532115409086_item	2679253	et	3	main
sain	doc_532115409086_item	2679254	et	3	main
kõik	doc_532115409086_item	2679265	et	4	main
ajal	doc_532115409086_item	2679274	et	4	main
ma	doc_532115409086_item	2679275	et	3	main
siis	doc_532115409086_item	2679125	et	3	main
võid	doc_532115409086_item	2679126	et	4	main
mugavused	doc_532115409086_item	2679131	et	4	main
esmavajalikud	doc_532115409086_item	2679134	et	3	main
nii	doc_532115409086_item	2679137	et	3	main
ju	doc_532115409086_item	2679141	et	3	main
aastat	doc_532115409086_item	2679146	et	3	main
ja	doc_532115409086_item	2679151	et	3	main
olnud	doc_532115409086_item	2679154	et	4	main
inimkonna	doc_532115409086_item	2679166	et	4	main
kodutehnika	doc_532115409086_item	2679177	et	4	main
elektrirongid	doc_532115409086_item	2679178	et	3	main
trammid	doc_532115409086_item	2679179	et	3	main
trollid	doc_532115409086_item	2679180	et	4	main
keskküte	doc_532115409086_item	2679181	et	3	main
kodudes	doc_532115409086_item	2679182	et	3	main
abil	doc_532115409086_item	2679189	et	4	main
väga	doc_532115409086_item	2679192	et	3	main
sellele	doc_532115409086_item	2679201	et	4	main
kuidas	doc_532115409086_item	2679206	et	3	main
see	doc_532115409086_item	2679207	et	3	main
töötab	doc_532115409086_item	2679208	et	3	main
nad	doc_532115409086_item	2679209	et	3	main
teavad	doc_532115409086_item	2679210	et	3	main
et	doc_532115409086_item	2679211	et	3	main
on	doc_532115409086_item	2679212	et	4	main
elekter	doc_532115409086_item	2679213	et	3	main
pliit	doc_532115409086_item	2679214	et	3	main
ja	doc_532115409086_item	2679215	et	3	main
sellega	doc_532115409086_item	2679216	et	3	main
võib	doc_532115409086_item	2679217	et	3	main
süüa	doc_532115409086_item	2679218	et	3	main
teha	doc_532115409086_item	2679219	et	3	main
aga	doc_532115409086_item	2679220	et	3	main
kui	doc_532115409086_item	2679221	et	3	main
kaob	doc_532115409086_item	2679225	et	3	main
kõik	doc_532115409086_item	2679230	et	4	main
ka	doc_532115409086_item	2679240	et	3	main
ei	doc_532115409086_item	2679244	et	4	main
ma	doc_532115409086_item	2679258	et	3	main
ei	doc_532115409086_item	2679266	et	4	main
sain	doc_532115409086_item	2679276	et	3	main
ei	doc_532115409087_item	2679318	et	4	main
on	doc_532115409087_item	2679328	et	4	main
paljud	doc_532115409087_item	2679330	et	3	main
saa	doc_532115409087_item	2679347	et	4	main
jne	doc_532115409087_item	2679361	et	4	main
praegu	doc_532115409087_item	2679368	et	3	main
arvuti	doc_532115409087_item	2679384	et	4	main
teeb	doc_532115409087_item	2679385	et	3	main
juba	doc_532115409087_item	2679386	et	3	main
igal	doc_532115409087_item	2679394	et	3	main
arvuti	doc_532115409087_item	2679398	et	4	main
piisut	doc_532115409087_item	2679410	et	4	main
internetist	doc_532115409087_item	2679411	et	4	main
info	doc_532115409087_item	2679416	et	4	main
ümbritseb	doc_532115409086_item	2679204	et	3	main
ja	doc_532115409086_item	2679205	et	3	main
millegigi	doc_532115409086_item	2679222	et	3	main
elekter	doc_532115409086_item	2679224	et	3	main
mingi	doc_532115409086_item	2679227	et	4	main
muutuvad	doc_532115409086_item	2679232	et	4	main
selline	doc_532115409086_item	2679241	et	4	main
sõltun	doc_532115409086_item	2679259	et	3	main
sellest	doc_532115409086_item	2679260	et	4	main
televiisor	doc_532115409086_item	2679261	et	3	main
radio	doc_532115409086_item	2679262	et	4	main
kraanist	doc_532115409086_item	2679268	et	3	main
tuleb	doc_532115409086_item	2679269	et	3	main
ainult	doc_532115409086_item	2679270	et	4	main
kult	doc_532115409086_item	2679271	et	3	main
vesi	doc_532115409086_item	2679272	et	4	main
tol	doc_532115409086_item	2679273	et	3	main
abil	doc_532115409086_item	2679310	et	4	main
teised	doc_532115409086_item	2679312	et	4	main
leiutised	doc_532115409086_item	2679313	et	3	main
ilma	doc_532115409087_item	2679314	et	4	main
milliste	doc_532115409087_item	2679315	et	3	main
leiutisteta	doc_532115409087_item	2679316	et	3	main
ma	doc_532115409087_item	2679317	et	3	main
millal	doc_532115409087_item	2679326	et	3	main
kahekümne	doc_532115409087_item	2679342	et	4	main
juba	doc_532115409087_item	2679345	et	3	main
ilma	doc_532115409087_item	2679349	et	4	main
autota	doc_532115409087_item	2679352	et	3	main
oli	doc_532115409087_item	2679354	et	3	main
aga	doc_532115409087_item	2679355	et	3	main
sain	doc_532115409087_item	2679362	et	3	main
paljud	doc_532115409087_item	2679365	et	3	main
meile	doc_532115409087_item	2679391	et	4	main
väga	doc_532115409087_item	2679392	et	3	main
täna	doc_532115409087_item	2679393	et	4	main
vanematele	doc_532115409087_item	2679406	et	4	main
tööl	doc_532115409087_item	2679407	et	3	main
räägin	doc_532115409087_item	2679408	et	3	main
on	doc_532115409087_item	2679414	et	4	main
kuningas	doc_532115409087_item	2679417	et	4	main
sellega	doc_532115409087_item	2679418	et	3	main
võib	doc_532115409087_item	2679419	et	3	main
teha	doc_532115409087_item	2679420	et	3	main
ei	doc_532115409087_item	2679438	et	4	main
elada	doc_532115409087_item	2679440	et	3	main
elan	doc_532115409088_item	2679444	et	3	main
juba	doc_532115409088_item	2679446	et	3	main
rajooni	doc_532115409088_item	2679453	et	4	main
otsas	doc_532115409088_item	2679454	et	4	main
suvel	doc_532115409088_item	2679461	et	3	main
tihti	doc_532115409088_item	2679463	et	3	main
puhkamas	doc_532115409088_item	2679465	et	3	main
mu	doc_532115409088_item	2679468	et	3	main
on	doc_532115409088_item	2679471	et	4	main
on	doc_532115409088_item	2679475	et	4	main
parema	doc_532115409088_item	2679485	et	4	main
iste	doc_532115409088_item	2679486	et	4	main
minutit	doc_532115409088_item	2679491	et	3	main
minutit	doc_532115409088_item	2679494	et	3	main
see	doc_532115409088_item	2679495	et	3	main
ole	doc_532115409088_item	2679497	et	4	main
väga	doc_532115409088_item	2679498	et	3	main
palju	doc_532115409088_item	2679499	et	4	main
mu	doc_532115409088_item	2679500	et	3	main
korter	doc_532115409088_item	2679501	et	3	main
asub	doc_532115409088_item	2679502	et	3	main
neljandal	doc_532115409088_item	2679503	et	3	main
korrusel	doc_532115409088_item	2679504	et	3	main
see	doc_532115409088_item	2679505	et	3	main
sest	doc_532115409088_item	2679509	et	4	main
lift	doc_532115409088_item	2679511	et	3	main
või	doc_532115409086_item	2679226	et	4	main
avarii	doc_532115409086_item	2679228	et	4	main
juhtub	doc_532115409086_item	2679229	et	3	main
minuga	doc_532115409086_item	2679238	et	3	main
lugu	doc_532115409086_item	2679242	et	4	main
aru	doc_532115409086_item	2679255	et	4	main
kui	doc_532115409086_item	2679256	et	3	main
tugevasti	doc_532115409086_item	2679257	et	3	main
tööta	doc_532115409086_item	2679267	et	4	main
et	doc_532115409086_item	2679278	et	3	main
kui	doc_532115409086_item	2679279	et	3	main
juthub	doc_532115409086_item	2679280	et	4	main
suur	doc_532115409086_item	2679281	et	3	main
avarii	doc_532115409086_item	2679282	et	4	main
sõda	doc_532115409086_item	2679283	et	4	main
või	doc_532115409086_item	2679284	et	4	main
veel	doc_532115409086_item	2679285	et	4	main
midagi	doc_532115409086_item	2679286	et	4	main
siis	doc_532115409086_item	2679287	et	3	main
elu	doc_532115409086_item	2679288	et	4	main
linnades	doc_532115409086_item	2679289	et	3	main
muutub	doc_532115409086_item	2679290	et	3	main
ohutuks	doc_532115409086_item	2679291	et	4	main
kuna	doc_532115409086_item	2679292	et	3	main
valgustust	doc_532115409086_item	2679293	et	4	main
tanavatel	doc_532115409086_item	2679294	et	4	main
ka	doc_532115409086_item	2679295	et	3	main
ei	doc_532115409086_item	2679296	et	4	main
ole	doc_532115409086_item	2679297	et	4	main
ebamugavaks	doc_532115409086_item	2679298	et	3	main
ja	doc_532115409086_item	2679299	et	3	main
igavaks	doc_532115409086_item	2679300	et	4	main
teiste	doc_532115409086_item	2679301	et	4	main
sõnadega	doc_532115409086_item	2679302	et	3	main
minu	doc_532115409086_item	2679303	et	3	main
jaoks	doc_532115409086_item	2679304	et	4	main
on	doc_532115409086_item	2679305	et	4	main
vajalik	doc_532115409086_item	2679306	et	3	main
see	doc_532115409086_item	2679307	et	3	main
leiutis	doc_532115409086_item	2679308	et	3	main
saaks	doc_532115409087_item	2679319	et	3	main
inimesd	doc_532115409087_item	2679327	et	4	main
teinud	doc_532115409087_item	2679329	et	4	main
sajandi	doc_532115409087_item	2679343	et	3	main
lapsed	doc_532115409087_item	2679344	et	3	main
raadiota	doc_532115409087_item	2679351	et	3	main
see	doc_532115409087_item	2679353	et	3	main
xix	doc_532115409087_item	2679356	et	4	main
tele	doc_532115409087_item	2679358	et	4	main
kommunikatsioonita	doc_532115409087_item	2679359	et	3	main
aru	doc_532115409087_item	2679363	et	4	main
on	doc_532115409087_item	2679367	et	4	main
täna	doc_532115409087_item	2679387	et	4	main
palju-palju	doc_532115409087_item	2679388	et	4	main
on	doc_532115409087_item	2679397	et	4	main
siis	doc_532115409087_item	2679409	et	3	main
see	doc_532115409087_item	2679413	et	3	main
nagu	doc_532115409087_item	2679415	et	3	main
kõike	doc_532115409087_item	2679422	et	4	main
arvan	doc_532115409087_item	2679425	et	3	main
et	doc_532115409087_item	2679426	et	3	main
leiutised	doc_532115409087_item	2679428	et	3	main
ilma	doc_532115409087_item	2679435	et	4	main
elukoht	doc_532115409088_item	2679442	et	3	main
lasnamäel	doc_532115409088_item	2679445	et	3	main
paneelmajas	doc_532115409088_item	2679450	et	3	main
me	doc_532115409088_item	2679462	et	4	main
käisime	doc_532115409088_item	2679464	et	3	main
ja	doc_532115409088_item	2679466	et	3	main
maja	doc_532115409088_item	2679469	et	4	main
kesklinnasse	doc_532115409088_item	2679488	et	4	main
töökohale	doc_532115409088_item	2679492	et	4	main
on	doc_532115409088_item	2679506	et	4	main
on	doc_532115409088_item	2679521	et	4	main
fonosüsteemiga	doc_532115409088_item	2679525	et	4	main
vahetamine	doc_532115409088_item	2679537	et	4	main
meeldivad	doc_532115409089_item	2679545	et	4	main
natike	doc_532115409089_item	2679548	et	4	main
palju	doc_532115409089_item	2679556	et	4	main
mugavaid	doc_532115409089_item	2679557	et	3	main
kõik	doc_532115409089_item	2679570	et	4	main
väga	doc_532115409089_item	2679578	et	3	main
kui	doc_532115409089_item	2679580	et	3	main
võimas	doc_532115409089_item	2679592	et	4	main
siis	doc_532115409089_item	2679593	et	3	main
hea	doc_532115409089_item	2679600	et	4	main
vähe	doc_532115409089_item	2679604	et	3	main
aru	doc_532115409089_item	2679613	et	4	main
validatuleb	doc_532115409089_item	2679630	et	4	main
konsulteerida	doc_532115409089_item	2679631	et	3	main
täpselt	doc_532115409089_item	2679647	et	4	main
unistused	doc_532115409089_item	2679660	et	4	main
väga	doc_532115409089_item	2679678	et	3	main
ja	doc_532115409089_item	2679684	et	3	main
on	doc_532115409089_item	2679688	et	4	main
olemas	doc_532115409089_item	2679691	et	4	main
ei	doc_532115409089_item	2679697	et	4	main
ja	doc_532115409089_item	2679702	et	3	main
ma	doc_532115409089_item	2679704	et	3	main
tuleb	doc_532115409089_item	2679709	et	3	main
mingi	doc_532115409089_item	2679712	et	4	main
vähe	doc_532115409089_item	2679713	et	3	main
auto	doc_532115409089_item	2679714	et	4	main
golf	doc_532115409089_item	2679717	et	3	main
see	doc_532115409087_item	2679323	et	3	main
on	doc_532115409087_item	2679324	et	4	main
sajandi	doc_532115409087_item	2679325	et	3	main
leiutised	doc_532115409087_item	2679331	et	3	main
võib	doc_532115409087_item	2679332	et	3	main
ka	doc_532115409087_item	2679333	et	3	main
ööelda	doc_532115409087_item	2679334	et	4	main
et	doc_532115409087_item	2679335	et	3	main
see	doc_532115409087_item	2679336	et	3	main
on	doc_532115409087_item	2679337	et	4	main
leiutiste	doc_532115409087_item	2679338	et	3	main
sajandi	doc_532115409087_item	2679339	et	3	main
ja	doc_532115409087_item	2679340	et	3	main
meie	doc_532115409087_item	2679341	et	4	main
neist	doc_532115409087_item	2679366	et	4	main
nagu	doc_532115409087_item	2679369	et	3	main
osa	doc_532115409087_item	2679370	et	4	main
minu	doc_532115409087_item	2679371	et	3	main
elust	doc_532115409087_item	2679372	et	3	main
aga	doc_532115409087_item	2679373	et	3	main
pealt	doc_532115409087_item	2679375	et	4	main
räägin	doc_532115409087_item	2679376	et	3	main
kasulikumaist	doc_532115409087_item	2679377	et	4	main
need	doc_532115409087_item	2679378	et	3	main
minu	doc_532115409087_item	2679379	et	3	main
meeles	doc_532115409087_item	2679380	et	3	main
kõige	doc_532115409087_item	2679374	et	4	main
on	doc_532115409087_item	2679381	et	4	main
arvuti	doc_532115409087_item	2679382	et	4	main
internet	doc_532115409087_item	2679383	et	4	main
tööt	doc_532115409087_item	2679389	et	4	main
aitab	doc_532115409087_item	2679390	et	3	main
teisel	doc_532115409087_item	2679395	et	4	main
ka	doc_532115409087_item	2679399	et	3	main
mulle	doc_532115409087_item	2679401	et	4	main
see	doc_532115409087_item	2679402	et	3	main
aitab	doc_532115409087_item	2679403	et	3	main
kooli	doc_532115409087_item	2679404	et	4	main
mu	doc_532115409087_item	2679405	et	3	main
internet	doc_532115409087_item	2679412	et	4	main
kõige	doc_532115409087_item	2679430	et	4	main
kasulikumad	doc_532115409087_item	2679431	et	4	main
minu	doc_532115409087_item	2679432	et	3	main
elus	doc_532115409087_item	2679433	et	4	main
ja	doc_532115409087_item	2679434	et	3	main
minu	doc_532115409088_item	2679441	et	3	main
aastat	doc_532115409088_item	2679448	et	3	main
on	doc_532115409088_item	2679457	et	4	main
mets	doc_532115409088_item	2679458	et	3	main
ja	doc_532115409088_item	2679459	et	3	main
jõgi	doc_532115409088_item	2679460	et	3	main
mõnus	doc_532115409088_item	2679476	et	4	main
tipptundides	doc_532115409088_item	2679477	et	3	main
kui	doc_532115409088_item	2679478	et	3	main
astud	doc_532115409088_item	2679479	et	3	main
tee	doc_532115409088_item	2679487	et	4	main
mugav	doc_532115409088_item	2679508	et	3	main
kui	doc_532115409088_item	2679510	et	3	main
lukustatud	doc_532115409088_item	2679522	et	4	main
ei	doc_532115409088_item	2679538	et	4	main
sootuks	doc_532115409088_item	2679541	et	4	main
tahan	doc_532115409089_item	2679546	et	3	main
kuidas	doc_532115409089_item	2679550	et	3	main
võimsaid	doc_532115409089_item	2679559	et	3	main
iga	doc_532115409089_item	2679563	et	4	main
saab	doc_532115409089_item	2679565	et	3	main
osta	doc_532115409089_item	2679567	et	4	main
palju	doc_532115409089_item	2679584	et	4	main
auto	doc_532115409089_item	2679601	et	4	main
kui	doc_532115409089_item	2679605	et	3	main
võib	doc_532115409089_item	2679634	et	3	main
olla	doc_532115409089_item	2679635	et	3	main
kui	doc_532115409089_item	2679637	et	3	main
mida	doc_532115409089_item	2679640	et	4	main
öelda	doc_532115409089_item	2679648	et	4	main
osta	doc_532115409089_item	2679651	et	4	main
autotbr	doc_532115409089_item	2679653	et	4	main
autod	doc_532115409089_item	2679655	et	3	main
meeldivad	doc_532115409089_item	2679657	et	4	main
ja	doc_532115409089_item	2679658	et	3	main
miks	doc_532115409089_item	2679659	et	4	main
mugav	doc_532115409089_item	2679679	et	3	main
teised	doc_532115409089_item	2679692	et	4	main
tüübid	doc_532115409089_item	2679693	et	3	main
kindlasti	doc_532115409089_item	2679695	et	3	main
osta	doc_532115409089_item	2679699	et	4	main
tulevikus	doc_532115409089_item	2679703	et	4	main
arvan	doc_532115409089_item	2679705	et	3	main
arvan	doc_532115409089_item	2679710	et	3	main
et	doc_532115409089_item	2679730	et	3	main
peavad	doc_532115409089_item	2679738	et	4	main
autoteenindusekeskuses	doc_532115409089_item	2679748	et	4	main
minu	doc_532115409089_item	2679751	et	3	main
üks	doc_532115409089_item	2679755	et	3	main
miks	doc_532115409089_item	2679757	et	4	main
autod	doc_532115409089_item	2679764	et	3	main
pärit	doc_532115409089_item	2679768	et	3	main
sõitis	doc_532115409090_item	2679791	et	3	main
jalgratturilte	doc_532115409090_item	2679797	et	4	main
buss	doc_532115409090_item	2679799	et	3	main
kukkus	doc_532115409090_item	2679804	et	3	main
sõitis	doc_532115409090_item	2679814	et	3	main
teiselt	doc_532115409090_item	2679815	et	4	main
teelt	doc_532115409090_item	2679816	et	3	main
samal	doc_532115409090_item	2679818	et	3	main
jalgrattult	doc_532115409090_item	2679823	et	4	main
otsa	doc_532115409090_item	2679825	et	4	main
sõitis	doc_532115409090_item	2679830	et	3	main
paremalt	doc_532115409090_item	2679835	et	4	main
saanud	doc_532115409090_item	2679839	et	4	main
tagant	doc_532115409090_item	2679846	et	3	main
telefoni	doc_532115409090_item	2679850	et	4	main
inimestel	doc_532115409087_item	2679396	et	3	main
kogu	doc_532115409087_item	2679400	et	4	main
lihtsalt	doc_532115409087_item	2679421	et	4	main
mida	doc_532115409087_item	2679423	et	4	main
soovitatakse	doc_532115409087_item	2679424	et	3	main
need	doc_532115409087_item	2679427	et	3	main
on	doc_532115409087_item	2679429	et	4	main
neist	doc_532115409087_item	2679436	et	4	main
ma	doc_532115409087_item	2679437	et	3	main
ma	doc_532115409088_item	2679443	et	3	main
üheksakorruselis	doc_532115409088_item	2679449	et	4	main
maja	doc_532115409088_item	2679451	et	4	main
asetseb	doc_532115409088_item	2679452	et	3	main
bussi	doc_532115409088_item	2679480	et	4	main
sisse	doc_532115409088_item	2679481	et	4	main
võib	doc_532115409088_item	2679482	et	3	main
valida	doc_532115409088_item	2679483	et	3	main
kõige	doc_532115409088_item	2679484	et	4	main
20	doc_532115409088_item	2679490	et	2	main
15	doc_532115409088_item	2679493	et	2	main
ei	doc_532115409088_item	2679496	et	4	main
varustatud	doc_532115409088_item	2679524	et	4	main
seetõttu	doc_532115409088_item	2679526	et	3	main
mulle	doc_532115409088_item	2679530	et	4	main
meeldib	doc_532115409088_item	2679531	et	3	main
mu	doc_532115409088_item	2679532	et	3	main
huvita	doc_532115409088_item	2679539	et	4	main
on	doc_532115409089_item	2679555	et	4	main
pole	doc_532115409089_item	2679562	et	3	main
hea	doc_532115409089_item	2679571	et	4	main
ja	doc_532115409089_item	2679572	et	3	main
mugav	doc_532115409089_item	2679573	et	3	main
ühe	doc_532115409089_item	2679574	et	4	main
palju	doc_532115409089_item	2679579	et	4	main
ei	doc_532115409089_item	2679582	et	4	main
alguses	doc_532115409089_item	2679594	et	4	main
tuleb	doc_532115409089_item	2679595	et	3	main
natuke	doc_532115409089_item	2679596	et	4	main
ei	doc_532115409089_item	2679602	et	4	main
summa	doc_532115409089_item	2679606	et	4	main
käes	doc_532115409089_item	2679608	et	4	main
palju	doc_532115409089_item	2679621	et	4	main
see	doc_532115409089_item	2679623	et	3	main
ei	doc_532115409089_item	2679624	et	4	main
inimestega	doc_532115409089_item	2679633	et	3	main
sõbradega	doc_532115409089_item	2679636	et	4	main
teavad	doc_532115409089_item	2679639	et	3	main
kindlat	doc_532115409089_item	2679652	et	3	main
on	doc_532115409089_item	2679677	et	4	main
spordiauto	doc_532115409089_item	2679689	et	4	main
on	doc_532115409089_item	2679690	et	4	main
ma	doc_532115409089_item	2679696	et	3	main
saa	doc_532115409089_item	2679698	et	4	main
aeg	doc_532115409089_item	2679708	et	3	main
osta	doc_532115409089_item	2679711	et	4	main
nagu	doc_532115409089_item	2679715	et	3	main
või	doc_532115409089_item	2679718	et	4	main
peab	doc_532115409089_item	2679721	et	4	main
peab	doc_532115409089_item	2679731	et	4	main
umbes	doc_532115409089_item	2679733	et	4	main
krooni	doc_532115409089_item	2679735	et	4	main
muidugi	doc_532115409089_item	2679736	et	4	main
vead	doc_532115409089_item	2679741	et	4	main
aga	doc_532115409089_item	2679742	et	3	main
loodan	doc_532115409089_item	2679743	et	3	main
parandada	doc_532115409089_item	2679744	et	3	main
sõbradega	doc_532115409089_item	2679747	et	4	main
või	doc_532115409089_item	2679759	et	4	main
saaksamaast	doc_532115409089_item	2679769	et	3	main
on	doc_532115409089_item	2679770	et	4	main
kõvased	doc_532115409089_item	2679771	et	4	main
sest	doc_532115409089_item	2679772	et	4	main
eile	doc_532115409090_item	2679780	et	3	main
ja	doc_532115409090_item	2679784	et	3	main
väga	doc_532115409090_item	2679786	et	3	main
buss	doc_532115409090_item	2679790	et	3	main
rismikul	doc_532115409090_item	2679795	et	4	main
otsa	doc_532115409090_item	2679798	et	4	main
jalgrattur	doc_532115409090_item	2679803	et	3	main
ja	doc_532115409090_item	2679817	et	3	main
mitte	doc_532115409090_item	2679824	et	3	main
mis	doc_532115409090_item	2679829	et	4	main
saaks	doc_532115409087_item	2679439	et	3	main
20	doc_532115409088_item	2679447	et	2	main
see-eest	doc_532115409088_item	2679455	et	4	main
lähedal	doc_532115409088_item	2679456	et	4	main
päevitamas	doc_532115409088_item	2679467	et	3	main
kõrval	doc_532115409088_item	2679470	et	4	main
esimene	doc_532115409088_item	2679472	et	3	main
bussipeatus	doc_532115409088_item	2679473	et	4	main
see	doc_532115409088_item	2679474	et	3	main
võtab	doc_532115409088_item	2679489	et	3	main
väga	doc_532115409088_item	2679507	et	3	main
on	doc_532115409088_item	2679512	et	4	main
katki	doc_532115409088_item	2679513	et	4	main
ei	doc_532115409088_item	2679514	et	4	main
ole	doc_532115409088_item	2679515	et	4	main
raske	doc_532115409088_item	2679516	et	4	main
üles	doc_532115409088_item	2679517	et	3	main
tõusata	doc_532115409088_item	2679518	et	4	main
jälgsi	doc_532115409088_item	2679519	et	4	main
treppikoda	doc_532115409088_item	2679520	et	4	main
on	doc_532115409088_item	2679528	et	4	main
puhas	doc_532115409088_item	2679529	et	3	main
missugused	doc_532115409089_item	2679542	et	3	main
mulle	doc_532115409089_item	2679544	et	4	main
ja	doc_532115409089_item	2679558	et	3	main
autosid	doc_532115409089_item	2679560	et	3	main
maksab	doc_532115409089_item	2679577	et	3	main
sul	doc_532115409089_item	2679581	et	3	main
ole	doc_532115409089_item	2679583	et	4	main
aga	doc_532115409089_item	2679586	et	3	main
on	doc_532115409089_item	2679588	et	4	main
vaja	doc_532115409089_item	2679589	et	4	main
rohkem	doc_532115409089_item	2679597	et	4	main
teenima	doc_532115409089_item	2679598	et	3	main
maksa	doc_532115409089_item	2679603	et	4	main
on	doc_532115409089_item	2679607	et	4	main
siis	doc_532115409089_item	2679609	et	3	main
muidugi	doc_532115409089_item	2679610	et	4	main
raha	doc_532115409089_item	2679622	et	4	main
palju	doc_532115409089_item	2679632	et	4	main
oskavad	doc_532115409089_item	2679646	et	4	main
võid	doc_532115409089_item	2679650	et	4	main
missugused	doc_532115409089_item	2679654	et	3	main
on	doc_532115409089_item	2679661	et	4	main
väga	doc_532115409089_item	2679673	et	3	main
kallis	doc_532115409089_item	2679674	et	4	main
auto	doc_532115409089_item	2679675	et	4	main
missuguses	doc_532115409089_item	2679676	et	3	main
salong	doc_532115409089_item	2679680	et	3	main
sisseruum	doc_532115409089_item	2679681	et	3	main
võimas	doc_532115409089_item	2679685	et	4	main
see	doc_532115409089_item	2679687	et	3	main
kabr	doc_532115409089_item	2679694	et	4	main
seda	doc_532115409089_item	2679700	et	3	main
ka	doc_532115409089_item	2679706	et	3	main
arvan	doc_532115409089_item	2679729	et	3	main
olema	doc_532115409089_item	2679732	et	4	main
2000	doc_532115409089_item	2679734	et	2	main
olema	doc_532115409089_item	2679739	et	4	main
oma	doc_532115409089_item	2679740	et	4	main
seal	doc_532115409089_item	2679749	et	4	main
ja	doc_532115409089_item	2679753	et	3	main
on	doc_532115409089_item	2679774	et	4	main
samasugune	doc_532115409089_item	2679775	et	3	main
kliima	doc_532115409089_item	2679776	et	4	main
nagu	doc_532115409089_item	2679777	et	3	main
meil	doc_532115409089_item	2679778	et	4	main
seletuskiri	doc_532115409090_item	2679779	et	3	main
olukorda	doc_532115409090_item	2679788	et	4	main
üle	doc_532115409090_item	2679792	et	3	main
ja	doc_532115409090_item	2679794	et	3	main
sõitis	doc_532115409090_item	2679800	et	3	main
ja	doc_532115409090_item	2679806	et	3	main
sai	doc_532115409090_item	2679807	et	4	main
pärast	doc_532115409090_item	2679811	et	4	main
ja	doc_532115409088_item	2679523	et	3	main
treppikoda	doc_532115409088_item	2679527	et	4	main
maja	doc_532115409088_item	2679533	et	4	main
asukoht	doc_532115409088_item	2679534	et	3	main
ja	doc_532115409088_item	2679535	et	3	main
korteri	doc_532115409088_item	2679536	et	3	main
mind	doc_532115409088_item	2679540	et	4	main
autod	doc_532115409089_item	2679543	et	3	main
alguses	doc_532115409089_item	2679547	et	4	main
seletada	doc_532115409089_item	2679549	et	3	main
hea	doc_532115409089_item	2679551	et	4	main
auto	doc_532115409089_item	2679552	et	4	main
osta	doc_532115409089_item	2679553	et	4	main
maailmas	doc_532115409089_item	2679554	et	3	main
aga	doc_532115409089_item	2679561	et	3	main
inimene	doc_532115409089_item	2679564	et	3	main
endale	doc_532115409089_item	2679566	et	4	main
seda	doc_532115409089_item	2679568	et	3	main
sest	doc_532115409089_item	2679569	et	4	main
sõnaga	doc_532115409089_item	2679575	et	3	main
no-how	doc_532115409089_item	2679576	et	4	main
raha	doc_532115409089_item	2679585	et	4	main
sulle	doc_532115409089_item	2679587	et	3	main
ilus	doc_532115409089_item	2679590	et	4	main
ja	doc_532115409089_item	2679591	et	3	main
sest	doc_532115409089_item	2679599	et	4	main
on	doc_532115409089_item	2679611	et	4	main
vaja	doc_532115409089_item	2679612	et	4	main
saama	doc_532115409089_item	2679614	et	4	main
midagi	doc_532115409089_item	2679615	et	4	main
autodes	doc_532115409089_item	2679616	et	3	main
ka	doc_532115409089_item	2679617	et	3	main
kui	doc_532115409089_item	2679618	et	3	main
sul	doc_532115409089_item	2679619	et	3	main
on	doc_532115409089_item	2679620	et	4	main
tähenda	doc_532115409089_item	2679625	et	4	main
et	doc_532115409089_item	2679626	et	3	main
sa	doc_532115409089_item	2679627	et	3	main
oskad	doc_532115409089_item	2679628	et	3	main
autosid	doc_532115409089_item	2679629	et	3	main
nad	doc_532115409089_item	2679638	et	3	main
sa	doc_532115409089_item	2679641	et	3	main
tahad	doc_532115409089_item	2679642	et	3	main
umbes	doc_532115409089_item	2679643	et	4	main
ja	doc_532115409089_item	2679644	et	3	main
ise	doc_532115409089_item	2679645	et	4	main
kus	doc_532115409089_item	2679649	et	3	main
mulle	doc_532115409089_item	2679656	et	4	main
kõikidel	doc_532115409089_item	2679662	et	4	main
kui	doc_532115409089_item	2679663	et	3	main
rääkida	doc_532115409089_item	2679664	et	3	main
autodest	doc_532115409089_item	2679665	et	3	main
minu	doc_532115409089_item	2679666	et	3	main
unistus	doc_532115409089_item	2679667	et	4	main
on	doc_532115409089_item	2679668	et	4	main
dodge	doc_532115409089_item	2679669	et	4	main
viper	doc_532115409089_item	2679670	et	4	main
see	doc_532115409089_item	2679671	et	3	main
on	doc_532115409089_item	2679672	et	4	main
lihtne	doc_532115409089_item	2679682	et	3	main
juhtimine	doc_532115409089_item	2679683	et	4	main
mootor	doc_532115409089_item	2679686	et	3	main
autot	doc_532115409089_item	2679701	et	3	main
kui	doc_532115409089_item	2679707	et	3	main
vw	doc_532115409089_item	2679716	et	4	main
opel	doc_532115409089_item	2679719	et	4	main
see	doc_532115409089_item	2679720	et	3	main
uus	doc_532115409089_item	2679728	et	3	main
või	doc_532115409089_item	2679746	et	4	main
sõbrad	doc_532115409089_item	2679752	et	3	main
asi	doc_532115409089_item	2679756	et	4	main
saksa	doc_532115409089_item	2679763	et	4	main
on	doc_532115409089_item	2679765	et	4	main
kindlad	doc_532115409089_item	2679766	et	3	main
autod	doc_532115409089_item	2679767	et	3	main
oma	doc_532115409090_item	2679782	et	4	main
põnevat	doc_532115409090_item	2679787	et	3	main
suur	doc_532115409090_item	2679789	et	3	main
sõitis	doc_532115409090_item	2679796	et	3	main
edasi	doc_532115409090_item	2679801	et	3	main
auto	doc_532115409090_item	2679813	et	4	main
teine	doc_532115409090_item	2679827	et	3	main
katus	doc_532115409090_item	2679832	et	4	main
seda	doc_532115409090_item	2679840	et	3	main
esimese	doc_532115409090_item	2679844	et	3	main
ma	doc_532115409090_item	2679848	et	3	main
ja	doc_532115409090_item	2679852	et	3	main
jooksul	doc_532115409090_item	2679857	et	4	main
võtis	doc_532115409090_item	2679861	et	3	main
tervis	doc_532115409091_item	2679865	et	3	main
rääkida	doc_532115409091_item	2679870	et	3	main
millest	doc_532115409091_item	2679875	et	3	main
olema	doc_532115409089_item	2679722	et	4	main
muidugi	doc_532115409089_item	2679723	et	4	main
pole	doc_532115409089_item	2679724	et	3	main
kallis	doc_532115409089_item	2679725	et	4	main
ja	doc_532115409089_item	2679726	et	3	main
pole	doc_532115409089_item	2679727	et	3	main
seal	doc_532115409089_item	2679737	et	4	main
iseseisvalt	doc_532115409089_item	2679745	et	4	main
töötavad	doc_532115409089_item	2679750	et	4	main
vell	doc_532115409089_item	2679754	et	4	main
vw	doc_532115409089_item	2679758	et	4	main
opel	doc_532115409089_item	2679760	et	4	main
sellepärast	doc_532115409089_item	2679761	et	3	main
et	doc_532115409089_item	2679762	et	3	main
saksamaal	doc_532115409089_item	2679773	et	4	main
jalutasin	doc_532115409090_item	2679781	et	3	main
koeraga	doc_532115409090_item	2679783	et	3	main
näitsin	doc_532115409090_item	2679785	et	4	main
teel	doc_532115409090_item	2679793	et	4	main
aga	doc_532115409090_item	2679802	et	3	main
maha	doc_532115409090_item	2679805	et	4	main
vigastada	doc_532115409090_item	2679808	et	3	main
veidi	doc_532115409090_item	2679809	et	3	main
aja	doc_532115409090_item	2679810	et	4	main
pidurdas	doc_532115409090_item	2679820	et	3	main
üks	doc_532115409090_item	2679812	et	3	main
rismikul	doc_532115409090_item	2679819	et	4	main
järsult	doc_532115409090_item	2679821	et	4	main
auto	doc_532115409090_item	2679828	et	4	main
mööda	doc_532115409090_item	2679834	et	4	main
poolt	doc_532115409090_item	2679836	et	4	main
sõitis	doc_532115409090_item	2679843	et	3	main
autose	doc_532115409090_item	2679845	et	4	main
minuti	doc_532115409090_item	2679856	et	3	main
inimese	doc_532115409091_item	2679864	et	4	main
tervisest	doc_532115409091_item	2679871	et	4	main
sõltub	doc_532115409091_item	2679876	et	3	main
pärilikkusest	doc_532115409091_item	2679906	et	4	main
inimene	doc_532115409091_item	2679911	et	3	main
suitsutab	doc_532115409091_item	2679920	et	3	main
joob	doc_532115409091_item	2679922	et	3	main
korratult	doc_532115409091_item	2679926	et	4	main
erinevad	doc_532115409091_item	2679930	et	4	main
need	doc_532115409091_item	2679932	et	3	main
on	doc_532115409091_item	2679933	et	4	main
seetõttu	doc_532115409091_item	2679947	et	3	main
küsimusi	doc_532115409091_item	2679949	et	4	main
tervis	doc_532115409091_item	2679952	et	3	main
jah	doc_532115409091_item	2679956	et	3	main
haiguseid	doc_532115409091_item	2679965	et	4	main
ei	doc_532115409091_item	2679994	et	4	main
on	doc_532115409091_item	2679999	et	4	main
sest	doc_532115409091_item	2680001	et	4	main
üks	doc_532115409091_item	2680017	et	3	main
nii	doc_532115409091_item	2680040	et	3	main
ma	doc_532115409092_item	2680049	et	3	main
oli	doc_532115409092_item	2680056	et	3	main
oli	doc_532115409092_item	2680065	et	3	main
ja	doc_532115409092_item	2680068	et	3	main
kuue	doc_532115409092_item	2680079	et	4	main
treppikodaga	doc_532115409092_item	2680080	et	4	main
minu	doc_532115409092_item	2680081	et	3	main
korter	doc_532115409092_item	2680082	et	3	main
asub	doc_532115409092_item	2680083	et	3	main
üheksandal	doc_532115409092_item	2680084	et	3	main
mitte	doc_532115409092_item	2680091	et	3	main
et	doc_532115409090_item	2679822	et	3	main
sõita	doc_532115409090_item	2679826	et	3	main
tagas	doc_532115409090_item	2679831	et	3	main
aga	doc_532115409090_item	2679837	et	3	main
ja	doc_532115409090_item	2679842	et	3	main
esiteks	doc_532115409090_item	2679847	et	3	main
ta	doc_532115409090_item	2679858	et	4	main
jalgratturit	doc_532115409090_item	2679862	et	3	main
sõltub	doc_532115409091_item	2679866	et	3	main
kõigepealt	doc_532115409091_item	2679873	et	3	main
inimese	doc_532115409091_item	2679877	et	4	main
tervist	doc_532115409091_item	2679878	et	4	main
iga	doc_532115409091_item	2679879	et	4	main
inimene	doc_532115409091_item	2679880	et	3	main
elab	doc_532115409091_item	2679881	et	3	main
oma	doc_532115409091_item	2679882	et	4	main
eluks	doc_532115409091_item	2679883	et	3	main
järelikult	doc_532115409091_item	2679884	et	3	main
tema	doc_532115409091_item	2679885	et	4	main
sõltub	doc_532115409091_item	2679887	et	3	main
tervis	doc_532115409091_item	2679886	et	3	main
paljudest	doc_532115409091_item	2679888	et	3	main
faktoritest	doc_532115409091_item	2679889	et	4	main
mõned	doc_532115409091_item	2679890	et	3	main
inimesed	doc_532115409091_item	2679891	et	3	main
haigestuvad	doc_532115409091_item	2679892	et	4	main
väga	doc_532115409091_item	2679893	et	3	main
harva	doc_532115409091_item	2679894	et	4	main
aga	doc_532115409091_item	2679895	et	3	main
teised	doc_532115409091_item	2679896	et	4	main
tihti	doc_532115409091_item	2679898	et	3	main
ma	doc_532115409091_item	2679899	et	3	main
mõtlen	doc_532115409091_item	2679900	et	3	main
et	doc_532115409091_item	2679901	et	3	main
väga	doc_532115409091_item	2679897	et	3	main
see	doc_532115409091_item	2679902	et	3	main
ka	doc_532115409091_item	2679904	et	3	main
sõltub	doc_532115409091_item	2679903	et	3	main
sõita	doc_532115409090_item	2679833	et	3	main
ei	doc_532115409090_item	2679838	et	4	main
teha	doc_532115409090_item	2679841	et	3	main
jooksen	doc_532115409090_item	2679849	et	3	main
juurde	doc_532115409090_item	2679851	et	4	main
kiirabi	doc_532115409090_item	2679854	et	4	main
ja	doc_532115409090_item	2679860	et	3	main
ära	doc_532115409090_item	2679863	et	4	main
selleks	doc_532115409091_item	2679868	et	4	main
tuleb	doc_532115409091_item	2679872	et	3	main
toitumisest	doc_532115409091_item	2679907	et	4	main
läheb	doc_532115409091_item	2679912	et	3	main
hilja	doc_532115409091_item	2679914	et	3	main
magab	doc_532115409091_item	2679915	et	3	main
sööb	doc_532115409091_item	2679917	et	3	main
toidu	doc_532115409091_item	2679919	et	3	main
vägijoogid	doc_532115409091_item	2679923	et	4	main
ta	doc_532115409091_item	2679924	et	4	main
selle	doc_532115409091_item	2679927	et	4	main
kõrge-	doc_532115409091_item	2679935	et	4	main
on	doc_532115409091_item	2679944	et	4	main
närvstressid	doc_532115409091_item	2679946	et	4	main
köögiviljad	doc_532115409091_item	2679992	et	3	main
problemid	doc_532115409091_item	2679996	et	4	main
hea	doc_532115409091_item	2680000	et	4	main
mõtlen	doc_532115409091_item	2680007	et	3	main
tervis	doc_532115409091_item	2680010	et	3	main
hea	doc_532115409091_item	2680012	et	4	main
sellele	doc_532115409091_item	2680013	et	4	main
suitseta	doc_532115409091_item	2680032	et	4	main
ning	doc_532115409091_item	2680033	et	3	main
ei	doc_532115409091_item	2680034	et	4	main
uuesse	doc_532115409092_item	2680062	et	3	main
hooned	doc_532115409092_item	2680067	et	4	main
seisis	doc_532115409092_item	2680071	et	4	main
maja	doc_532115409092_item	2680073	et	4	main
mugav	doc_532115409092_item	2680088	et	3	main
üles	doc_532115409092_item	2680090	et	3	main
keegi	doc_532115409092_item	2680092	et	4	main
ela	doc_532115409092_item	2680094	et	4	main
aga	doc_532115409092_item	2680095	et	3	main
ja	doc_532115409092_item	2680136	et	3	main
aknad	doc_532115409092_item	2680147	et	3	main
ruutmetrit	doc_532115409092_item	2680157	et	4	main
mulle	doc_532115409092_item	2680184	et	4	main
ohtlikult	doc_532115409092_item	2680192	et	4	main
korteris	doc_532115409092_item	2680193	et	3	main
kahetariifne	doc_532115409092_item	2680198	et	3	main
ma	doc_532115409092_item	2680202	et	3	main
asju	doc_532115409092_item	2680206	et	3	main
tubades	doc_532115409092_item	2680208	et	3	main
parkett	doc_532115409092_item	2680210	et	4	main
kutsusin	doc_532115409090_item	2679853	et	3	main
paari	doc_532115409090_item	2679855	et	4	main
tuli	doc_532115409090_item	2679859	et	4	main
elustiilist	doc_532115409091_item	2679867	et	4	main
et	doc_532115409091_item	2679869	et	3	main
otsustada	doc_532115409091_item	2679874	et	3	main
keskkonnast	doc_532115409091_item	2679909	et	4	main
kui	doc_532115409091_item	2679910	et	3	main
ja	doc_532115409091_item	2679921	et	3	main
elab	doc_532115409091_item	2679925	et	3	main
tulemusel	doc_532115409091_item	2679928	et	3	main
südamehaigus	doc_532115409091_item	2679934	et	4	main
või	doc_532115409091_item	2679936	et	4	main
vererõhku	doc_532115409091_item	2679938	et	4	main
põletik	doc_532115409091_item	2679941	et	3	main
on	doc_532115409091_item	2679948	et	4	main
sõltub	doc_532115409091_item	2679953	et	3	main
vastus	doc_532115409091_item	2679955	et	3	main
me	doc_532115409091_item	2679958	et	4	main
elame	doc_532115409091_item	2679959	et	3	main
tervislikku	doc_532115409091_item	2679960	et	4	main
tähendab	doc_532115409091_item	2679967	et	3	main
et	doc_532115409091_item	2679968	et	3	main
tal	doc_532115409091_item	2680002	et	3	main
ole	doc_532115409091_item	2680004	et	4	main
et	doc_532115409091_item	2680008	et	3	main
vaatamata	doc_532115409091_item	2680014	et	4	main
inimene	doc_532115409091_item	2680015	et	3	main
käib	doc_532115409091_item	2680016	et	3	main
juures	doc_532115409091_item	2680021	et	4	main
oma	doc_532115409091_item	2680023	et	4	main
kontrollima	doc_532115409091_item	2680025	et	4	main
on	doc_532115409091_item	2680041	et	4	main
ühiselamu	doc_532115409092_item	2680054	et	4	main
see	doc_532115409092_item	2680055	et	3	main
koolisime	doc_532115409092_item	2680059	et	4	main
lasnamäele	doc_532115409092_item	2680061	et	3	main
kõrval	doc_532115409092_item	2680064	et	4	main
ehitu	doc_532115409092_item	2680066	et	4	main
keskel	doc_532115409092_item	2680070	et	3	main
minu	doc_532115409092_item	2680072	et	3	main
on	doc_532115409092_item	2680075	et	4	main
maja	doc_532115409092_item	2680078	et	4	main
korrusel	doc_532115409092_item	2680085	et	3	main
aastal	doc_532115409092_item	2680125	et	3	main
tpetikoda	doc_532115409092_item	2680129	et	4	main
remonditud	doc_532115409092_item	2680132	et	4	main
on	doc_532115409092_item	2680139	et	4	main
korter	doc_532115409092_item	2680141	et	3	main
plastmassraamiga	doc_532115409092_item	2680146	et	4	main
vaade	doc_532115409092_item	2680148	et	3	main
on	doc_532115409092_item	2680155	et	4	main
rõdu	doc_532115409092_item	2680159	et	4	main
esik	doc_532115409092_item	2680161	et	3	main
soe	doc_532115409092_item	2680176	et	4	main
paigaldatud	doc_532115409092_item	2680196	et	4	main
elektrimõõtjaid	doc_532115409092_item	2680199	et	3	main
teha	doc_532115409092_item	2680205	et	3	main
tapetseeritud	doc_532115409092_item	2680212	et	4	main
vahel	doc_532115409092_item	2680220	et	4	main
ei	doc_532115409092_item	2680221	et	4	main
kandevsein	doc_532115409092_item	2680223	et	4	main
kui	doc_532115409092_item	2680227	et	3	main
haldab	doc_532115409092_item	2680231	et	3	main
ümbrises	doc_532115409092_item	2680234	et	4	main
priisle	doc_532115409092_item	2680241	et	4	main
on	doc_532115409092_item	2680244	et	4	main
pood	doc_532115409092_item	2680246	et	4	main
probleeme	doc_532115409093_item	2680275	et	3	main
hulgast	doc_532115409093_item	2680282	et	4	main
hulgas	doc_532115409093_item	2680302	et	4	main
ka	doc_532115409093_item	2680303	et	3	main
praeguses	doc_532115409093_item	2680304	et	3	main
narkootikumid	doc_532115409093_item	2680316	et	3	main
ja	doc_532115409093_item	2680318	et	3	main
vanusest	doc_532115409091_item	2679905	et	4	main
ja	doc_532115409091_item	2679908	et	3	main
voodi	doc_532115409091_item	2679913	et	4	main
vähe	doc_532115409091_item	2679916	et	3	main
rasvaseid	doc_532115409091_item	2679918	et	4	main
jne	doc_532115409091_item	2679942	et	4	main
ka	doc_532115409091_item	2679945	et	3	main
kas	doc_532115409091_item	2679950	et	3	main
elustiilist	doc_532115409091_item	2679954	et	4	main
kui	doc_532115409091_item	2679957	et	3	main
me	doc_532115409091_item	2679962	et	4	main
vähendame	doc_532115409091_item	2679963	et	3	main
oma	doc_532115409091_item	2679964	et	4	main
inimene	doc_532115409091_item	2679969	et	3	main
ole	doc_532115409091_item	2679995	et	4	main
ma	doc_532115409091_item	2680006	et	3	main
tema	doc_532115409091_item	2680009	et	4	main
on	doc_532115409091_item	2680011	et	4	main
arsti	doc_532115409091_item	2680020	et	4	main
et	doc_532115409091_item	2680022	et	3	main
tervise	doc_532115409091_item	2680024	et	3	main
ma	doc_532115409091_item	2680026	et	3	main
mõtlen	doc_532115409091_item	2680027	et	3	main
ka	doc_532115409091_item	2680028	et	3	main
et	doc_532115409091_item	2680029	et	3	main
inimene	doc_532115409091_item	2680030	et	3	main
ei	doc_532115409091_item	2680031	et	4	main
elame	doc_532115409091_item	2680039	et	3	main
tervis	doc_532115409091_item	2680043	et	3	main
elukoht	doc_532115409092_item	2680045	et	3	main
veel	doc_532115409092_item	2680047	et	4	main
oma	doc_532115409092_item	2680051	et	4	main
korteri	doc_532115409092_item	2680052	et	3	main
pärast	doc_532115409092_item	2680053	et	4	main
me	doc_532115409092_item	2680058	et	4	main
mustamäelt	doc_532115409092_item	2680060	et	3	main
piirkonnasse	doc_532115409092_item	2680063	et	4	main
see	doc_532115409092_item	2680074	et	3	main
üheksanda	doc_532115409092_item	2680076	et	3	main
see	doc_532115409092_item	2680086	et	3	main
ei	doc_532115409092_item	2680093	et	4	main
ning	doc_532115409092_item	2680123	et	3	main
lukustatud	doc_532115409092_item	2680137	et	4	main
kolmetoaline	doc_532115409092_item	2680140	et	4	main
avaneb	doc_532115409092_item	2680149	et	3	main
41	doc_532115409092_item	2680156	et	2	main
suur	doc_532115409092_item	2680160	et	3	main
on	doc_532115409092_item	2680175	et	4	main
vesi	doc_532115409092_item	2680177	et	4	main
ja	doc_532115409092_item	2680178	et	3	main
elektripliit	doc_532115409092_item	2680179	et	3	main
elektripliit	doc_532115409092_item	2680180	et	3	main
on	doc_532115409092_item	2680181	et	4	main
väga	doc_532115409092_item	2680182	et	3	main
mugav	doc_532115409092_item	2680183	et	3	main
on	doc_532115409092_item	2680191	et	4	main
soovi	doc_532115409092_item	2680204	et	4	main
planeeringut	doc_532115409092_item	2680214	et	4	main
lastetoa	doc_532115409092_item	2680217	et	3	main
ole	doc_532115409092_item	2680222	et	4	main
ma	doc_532115409092_item	2680225	et	3	main
tütred	doc_532115409092_item	2680228	et	3	main
elamut	doc_532115409092_item	2680230	et	3	main
maja	doc_532115409092_item	2680233	et	4	main
on	doc_532115409092_item	2680235	et	4	main
bussipeatus	doc_532115409092_item	2680247	et	4	main
on	doc_532115409092_item	2680248	et	4	main
100	doc_532115409092_item	2680249	et	2	main
metrit	doc_532115409092_item	2680250	et	4	main
teele	doc_532115409093_item	2680267	et	3	main
elus	doc_532115409093_item	2680271	et	4	main
ei	doc_532115409093_item	2680277	et	4	main
vaidlemata	doc_532115409093_item	2680285	et	4	main
lapsed	doc_532115409093_item	2680287	et	3	main
statistika	doc_532115409093_item	2680296	et	4	main
kuritegevus	doc_532115409093_item	2680298	et	4	main
kasvab	doc_532115409093_item	2680299	et	3	main
ja	doc_532115409093_item	2680300	et	3	main
lapse	doc_532115409093_item	2680301	et	4	main
tegevusi	doc_532115409093_item	2680309	et	4	main
nii	doc_532115409093_item	2680310	et	3	main
häid	doc_532115409093_item	2680311	et	3	main
tekivad	doc_532115409091_item	2679929	et	3	main
haigused	doc_532115409091_item	2679931	et	4	main
madala	doc_532115409091_item	2679937	et	3	main
maohaavanud	doc_532115409091_item	2679939	et	3	main
söögitoru	doc_532115409091_item	2679940	et	4	main
tihti	doc_532115409091_item	2679943	et	3	main
inimese	doc_532115409091_item	2679951	et	4	main
eluviisi	doc_532115409091_item	2679961	et	4	main
see	doc_532115409091_item	2679966	et	3	main
tõuseb	doc_532115409091_item	2679970	et	3	main
vara	doc_532115409091_item	2679971	et	4	main
hommikul	doc_532115409091_item	2679972	et	3	main
teeb	doc_532115409091_item	2679973	et	3	main
hommikvõimlemist	doc_532115409091_item	2679974	et	3	main
võtab	doc_532115409091_item	2679975	et	3	main
dushshi	doc_532115409091_item	2679976	et	4	main
väga	doc_532115409091_item	2679977	et	3	main
tihti	doc_532115409091_item	2679978	et	3	main
viibib	doc_532115409091_item	2679979	et	3	main
värskes	doc_532115409091_item	2679980	et	4	main
õhus	doc_532115409091_item	2679981	et	3	main
tegeleb	doc_532115409091_item	2679982	et	3	main
spordiga	doc_532115409091_item	2679983	et	3	main
muidugi	doc_532115409091_item	2679984	et	4	main
sööb	doc_532115409091_item	2679985	et	3	main
tervislikku	doc_532115409091_item	2679986	et	4	main
toitu	doc_532115409091_item	2679987	et	4	main
need	doc_532115409091_item	2679988	et	3	main
on	doc_532115409091_item	2679989	et	4	main
puuviljad	doc_532115409091_item	2679990	et	3	main
ja	doc_532115409091_item	2679991	et	3	main
tal	doc_532115409091_item	2679993	et	3	main
tööl	doc_532115409091_item	2679997	et	3	main
tuju	doc_532115409091_item	2679998	et	4	main
ei	doc_532115409091_item	2680003	et	4	main
närvstressi	doc_532115409091_item	2680005	et	4	main
kord	doc_532115409091_item	2680018	et	4	main
aastas	doc_532115409091_item	2680019	et	3	main
võta	doc_532115409091_item	2680035	et	4	main
narkotikut	doc_532115409091_item	2680036	et	4	main
kui	doc_532115409091_item	2680037	et	3	main
me	doc_532115409091_item	2680038	et	4	main
meie	doc_532115409091_item	2680042	et	4	main
minu	doc_532115409092_item	2680044	et	3	main
töötades	doc_532115409092_item	2680046	et	3	main
tehases	doc_532115409092_item	2680048	et	3	main
sain	doc_532115409092_item	2680050	et	3	main
ime	doc_532115409092_item	2680057	et	4	main
piirkonna	doc_532115409092_item	2680069	et	4	main
korruseline	doc_532115409092_item	2680077	et	4	main
väga	doc_532115409092_item	2680087	et	3	main
sellepärast	doc_532115409092_item	2680089	et	3	main
kui	doc_532115409092_item	2680096	et	3	main
lift	doc_532115409092_item	2680097	et	3	main
ei	doc_532115409092_item	2680098	et	4	main
tööta	doc_532115409092_item	2680099	et	4	main
ja	doc_532115409092_item	2680100	et	3	main
teil	doc_532115409092_item	2680101	et	4	main
on	doc_532115409092_item	2680102	et	4	main
suured	doc_532115409092_item	2680103	et	3	main
kotid	doc_532115409092_item	2680104	et	3	main
sest	doc_532115409092_item	2680105	et	4	main
ma	doc_532115409092_item	2680106	et	3	main
mõtlen	doc_532115409092_item	2680107	et	3	main
et	doc_532115409092_item	2680108	et	3	main
allpool	doc_532115409092_item	2680109	et	3	main
elada	doc_532115409092_item	2680110	et	3	main
lihtsalt	doc_532115409092_item	2680111	et	4	main
on	doc_532115409092_item	2680112	et	4	main
üks	doc_532115409092_item	2680113	et	3	main
probleem	doc_532115409092_item	2680114	et	3	main
katus	doc_532115409092_item	2680115	et	4	main
rõõmsaks	doc_532115409092_item	2680116	et	3	main
meie	doc_532115409092_item	2680117	et	4	main
maja	doc_532115409092_item	2680118	et	4	main
katus	doc_532115409092_item	2680119	et	4	main
ei	doc_532115409092_item	2680120	et	4	main
lasta	doc_532115409092_item	2680121	et	4	main
sellel	doc_532115409092_item	2680124	et	4	main
uue	doc_532115409092_item	2680127	et	3	main
ka	doc_532115409092_item	2680130	et	3	main
meil	doc_532115409092_item	2680138	et	4	main
möödunud	doc_532115409092_item	2680142	et	4	main
aastal	doc_532115409092_item	2680143	et	3	main
paigaldasime	doc_532115409092_item	2680144	et	3	main
kahele	doc_532115409092_item	2680150	et	4	main
maja	doc_532115409092_item	2680152	et	4	main
korteri	doc_532115409092_item	2680153	et	3	main
elamispind	doc_532115409092_item	2680154	et	3	main
ei	doc_532115409092_item	2680185	et	4	main
on	doc_532115409092_item	2680194	et	4	main
keskküte	doc_532115409092_item	2680195	et	3	main
ei	doc_532115409092_item	2680200	et	4	main
ei	doc_532115409092_item	2680203	et	4	main
muuta	doc_532115409092_item	2680216	et	4	main
läbi	doc_532115409092_item	2680122	et	4	main
tehati	doc_532115409092_item	2680126	et	4	main
katusekate	doc_532115409092_item	2680128	et	3	main
hiljuti	doc_532115409092_item	2680131	et	4	main
välisuks	doc_532115409092_item	2680133	et	4	main
on	doc_532115409092_item	2680134	et	4	main
metalluks	doc_532115409092_item	2680135	et	4	main
uued	doc_532115409092_item	2680145	et	3	main
poole	doc_532115409092_item	2680151	et	4	main
on	doc_532115409092_item	2680158	et	4	main
tualett	doc_532115409092_item	2680162	et	3	main
ja	doc_532115409092_item	2680163	et	3	main
vannituba	doc_532115409092_item	2680164	et	4	main
on	doc_532115409092_item	2680165	et	4	main
eraldi	doc_532115409092_item	2680166	et	4	main
köök	doc_532115409092_item	2680167	et	3	main
ei	doc_532115409092_item	2680168	et	4	main
ole	doc_532115409092_item	2680169	et	4	main
suur	doc_532115409092_item	2680170	et	3	main
umbes	doc_532115409092_item	2680171	et	4	main
7	doc_532115409092_item	2680172	et	2	main
ruutmetrit	doc_532115409092_item	2680173	et	4	main
aga	doc_532115409092_item	2680174	et	3	main
meeldi	doc_532115409092_item	2680186	et	4	main
gaasipliit	doc_532115409092_item	2680187	et	3	main
minu	doc_532115409092_item	2680188	et	3	main
arvates	doc_532115409092_item	2680189	et	4	main
see	doc_532115409092_item	2680190	et	3	main
veemõõtjad	doc_532115409092_item	2680197	et	3	main
ole	doc_532115409092_item	2680201	et	4	main
õhtuti	doc_532115409092_item	2680207	et	3	main
on	doc_532115409092_item	2680209	et	4	main
seinad	doc_532115409092_item	2680211	et	3	main
korteri	doc_532115409092_item	2680213	et	3	main
võimalik	doc_532115409092_item	2680215	et	3	main
ja	doc_532115409092_item	2680218	et	3	main
mõtlen	doc_532115409092_item	2680226	et	3	main
korteriühistu	doc_532115409092_item	2680232	et	4	main
parkla	doc_532115409092_item	2680237	et	4	main
on	doc_532115409092_item	2680239	et	4	main
apteek	doc_532115409092_item	2680240	et	3	main
nad	doc_532115409093_item	2680264	et	3	main
kuritegelikule	doc_532115409093_item	2680266	et	3	main
et	doc_532115409093_item	2680276	et	3	main
missugune	doc_532115409093_item	2680280	et	3	main
on	doc_532115409093_item	2680288	et	4	main
praegu	doc_532115409093_item	2680295	et	3	main
elus	doc_532115409093_item	2680305	et	4	main
kahtlusi	doc_532115409093_item	2680313	et	4	main
looming	doc_532115409093_item	2680320	et	3	main
klassikaline	doc_532115409093_item	2680321	et	4	main
rock-	doc_532115409093_item	2680324	et	4	main
raskemetall-muusika	doc_532115409093_item	2680325	et	4	main
ilusad	doc_532115409093_item	2680326	et	3	main
on	doc_532115409093_item	2680336	et	4	main
nii	doc_532115409093_item	2680337	et	3	main
kurjus	doc_532115409093_item	2680343	et	4	main
on	doc_532115409093_item	2680354	et	4	main
igaühele	doc_532115409093_item	2680361	et	3	main
minu	doc_532115409093_item	2680365	et	3	main
on	doc_532115409093_item	2680369	et	4	main
õpetada	doc_532115409093_item	2680370	et	3	main
lastele	doc_532115409093_item	2680371	et	4	main
äratundmist	doc_532115409093_item	2680375	et	3	main
raske	doc_532115409093_item	2680378	et	4	main
vanematest	doc_532115409093_item	2680398	et	4	main
teatavasti	doc_532115409093_item	2680399	et	3	main
vormistatakse	doc_532115409093_item	2680403	et	3	main
aastas	doc_532115409093_item	2680406	et	3	main
seda	doc_532115409093_item	2680421	et	3	main
siis	doc_532115409093_item	2680423	et	3	main
kuid	doc_532115409093_item	2680446	et	4	main
mõtet	doc_532115409093_item	2680450	et	3	main
ja	doc_532115409093_item	2680459	et	3	main
seda	doc_532115409093_item	2680476	et	3	main
kunagi	doc_532115409093_item	2680478	et	3	main
mäletasin	doc_532115409094_item	2680504	et	3	main
suurtes	doc_532115409094_item	2680518	et	3	main
jäi	doc_532115409094_item	2680523	et	3	main
köögi	doc_532115409092_item	2680219	et	3	main
sellest	doc_532115409092_item	2680224	et	4	main
tasuline	doc_532115409092_item	2680236	et	4	main
kõrval	doc_532115409092_item	2680238	et	4	main
majas	doc_532115409092_item	2680243	et	3	main
väike	doc_532115409092_item	2680245	et	4	main
kooliharidusest	doc_532115409093_item	2680260	et	4	main
see	doc_532115409093_item	2680262	et	3	main
mitte	doc_532115409093_item	2680269	et	3	main
on	doc_532115409093_item	2680272	et	4	main
nii	doc_532115409093_item	2680273	et	3	main
palju	doc_532115409093_item	2680274	et	4	main
tohi	doc_532115409093_item	2680278	et	4	main
et	doc_532115409093_item	2680286	et	3	main
tulevik	doc_532115409093_item	2680290	et	3	main
ja	doc_532115409093_item	2680291	et	3	main
pakuti	doc_532115409093_item	2680306	et	3	main
lastele	doc_532115409093_item	2680307	et	4	main
ja	doc_532115409093_item	2680315	et	3	main
ebanormaalne	doc_532115409093_item	2680319	et	3	main
filmid	doc_532115409093_item	2680328	et	4	main
filmid	doc_532115409093_item	2680331	et	4	main
ne	doc_532115409093_item	2680333	et	4	main
elus	doc_532115409093_item	2680334	et	4	main
eluseadus	doc_532115409093_item	2680349	et	4	main
siis	doc_532115409093_item	2680356	et	3	main
hinna	doc_532115409093_item	2680358	et	3	main
aga	doc_532115409093_item	2680360	et	3	main
arvates	doc_532115409093_item	2680366	et	4	main
kurjuse	doc_532115409093_item	2680374	et	4	main
hädavajalik	doc_532115409093_item	2680381	et	3	main
sellest	doc_532115409093_item	2680383	et	4	main
kas	doc_532115409093_item	2680385	et	3	main
kuritegelikule	doc_532115409093_item	2680388	et	3	main
inimene	doc_532115409093_item	2680401	et	3	main
ajal	doc_532115409093_item	2680408	et	4	main
nende	doc_532115409093_item	2680429	et	4	main
lastega	doc_532115409093_item	2680430	et	3	main
lapsed	doc_532115409093_item	2680431	et	3	main
tähelepanu	doc_532115409093_item	2680440	et	4	main
õpivad	doc_532115409093_item	2680441	et	3	main
all	doc_532115409093_item	2680445	et	3	main
lüüa	doc_532115409093_item	2680452	et	3	main
õppijad	doc_532115409093_item	2680454	et	4	main
saama	doc_532115409093_item	2680456	et	4	main
tulevik	doc_532115409093_item	2680473	et	3	main
keemiatooted	doc_532115409094_item	2680479	et	3	main
elu	doc_532115409094_item	2680482	et	4	main
ja	doc_532115409094_item	2680484	et	3	main
meie	doc_532115409094_item	2680488	et	4	main
keemiatoodeteid	doc_532115409094_item	2680492	et	4	main
sampoonid	doc_532115409094_item	2680495	et	4	main
ja	doc_532115409094_item	2680500	et	3	main
kui	doc_532115409094_item	2680505	et	3	main
loputas	doc_532115409094_item	2680515	et	3	main
kaua	doc_532115409094_item	2680525	et	3	main
seepi	doc_532115409094_item	2680528	et	4	main
ja	doc_532115409094_item	2680535	et	3	main
tuhmid	doc_532115409094_item	2680536	et	3	main
me	doc_532115409094_item	2680545	et	4	main
tugevdavad	doc_532115409094_item	2680551	et	4	main
kui	doc_532115409094_item	2680556	et	3	main
sobib	doc_532115409094_item	2680571	et	3	main
suurepäraselt	doc_532115409094_item	2680572	et	4	main
kraanikausside	doc_532115409094_item	2680573	et	3	main
ja	doc_532115409094_item	2680576	et	3	main
teevad	doc_532115409094_item	2680581	et	3	main
abielluvad	doc_532115409092_item	2680229	et	4	main
turul	doc_532115409092_item	2680242	et	3	main
kaugusel	doc_532115409092_item	2680251	et	4	main
ja	doc_532115409092_item	2680252	et	3	main
linnani	doc_532115409092_item	2680253	et	3	main
20	doc_532115409092_item	2680254	et	2	main
minutit	doc_532115409092_item	2680255	et	3	main
sõitmine	doc_532115409092_item	2680256	et	4	main
laste	doc_532115409093_item	2680257	et	4	main
kasvatamisest	doc_532115409093_item	2680258	et	4	main
ja	doc_532115409093_item	2680259	et	3	main
sõltub	doc_532115409093_item	2680261	et	3	main
kas	doc_532115409093_item	2680263	et	3	main
lähevad	doc_532115409093_item	2680265	et	3	main
või	doc_532115409093_item	2680268	et	4	main
tänases	doc_532115409093_item	2680270	et	3	main
rääkida	doc_532115409093_item	2680279	et	3	main
nende	doc_532115409093_item	2680281	et	4	main
on	doc_532115409093_item	2680283	et	4	main
pea	doc_532115409093_item	2680284	et	4	main
meie	doc_532115409093_item	2680289	et	4	main
hoolida	doc_532115409093_item	2680292	et	3	main
nendest	doc_532115409093_item	2680293	et	4	main
tasub	doc_532115409093_item	2680294	et	3	main
järgi	doc_532115409093_item	2680297	et	4	main
palju	doc_532115409093_item	2680308	et	4	main
sport	doc_532115409093_item	2680314	et	3	main
kõrgkunst	doc_532115409093_item	2680317	et	3	main
muusika	doc_532115409093_item	2680322	et	4	main
targad	doc_532115409093_item	2680327	et	3	main
õudne	doc_532115409093_item	2680330	et	3	main
on	doc_532115409093_item	2680348	et	4	main
tea	doc_532115409093_item	2680352	et	4	main
mis	doc_532115409093_item	2680353	et	4	main
ei	doc_532115409093_item	2680357	et	4	main
pea	doc_532115409093_item	2680367	et	4	main
probleem	doc_532115409093_item	2680368	et	3	main
on	doc_532115409093_item	2680377	et	4	main
sõltub	doc_532115409093_item	2680384	et	3	main
lähevad	doc_532115409093_item	2680387	et	3	main
või	doc_532115409093_item	2680390	et	4	main
mitte	doc_532115409093_item	2680391	et	3	main
mulle	doc_532115409093_item	2680392	et	4	main
tundub	doc_532115409093_item	2680393	et	3	main
et	doc_532115409093_item	2680394	et	3	main
kõigepealt	doc_532115409093_item	2680395	et	3	main
kõik	doc_532115409093_item	2680396	et	4	main
sõltub	doc_532115409093_item	2680397	et	3	main
esimestes	doc_532115409093_item	2680404	et	4	main
õpitada	doc_532115409093_item	2680422	et	4	main
lasteajas	doc_532115409093_item	2680424	et	3	main
ei	doc_532115409093_item	2680434	et	4	main
murduvad	doc_532115409093_item	2680443	et	4	main
nende	doc_532115409093_item	2680447	et	4	main
käega	doc_532115409093_item	2680451	et	3	main
meie	doc_532115409093_item	2680472	et	4	main
mitte	doc_532115409093_item	2680477	et	3	main
turvalisemaks	doc_532115409094_item	2680485	et	4	main
elus	doc_532115409094_item	2680489	et	4	main
on	doc_532115409094_item	2680494	et	4	main
ma	doc_532115409094_item	2680506	et	3	main
teda	doc_532115409094_item	2680516	et	4	main
aga	doc_532115409094_item	2680520	et	3	main
juukseid	doc_532115409094_item	2680552	et	3	main
värskendavad	doc_532115409094_item	2680554	et	4	main
me	doc_532115409094_item	2680557	et	4	main
me	doc_532115409094_item	2680563	et	4	main
hoiame	doc_532115409094_item	2680564	et	3	main
minu	doc_532115409096_item	2680724	et	3	main
oleme	doc_532115409096_item	2680734	et	3	main
kui	doc_532115409093_item	2680312	et	3	main
ja	doc_532115409093_item	2680329	et	3	main
kõik	doc_532115409093_item	2680335	et	4	main
ja	doc_532115409093_item	2680342	et	3	main
olemas	doc_532115409093_item	2680345	et	4	main
koos	doc_532115409093_item	2680346	et	4	main
niisugune	doc_532115409093_item	2680347	et	3	main
ei	doc_532115409093_item	2680351	et	4	main
võimalust	doc_532115409093_item	2680363	et	3	main
headuse	doc_532115409093_item	2680372	et	4	main
ja	doc_532115409093_item	2680373	et	3	main
töö	doc_532115409093_item	2680379	et	4	main
teele	doc_532115409093_item	2680389	et	3	main
iseloom	doc_532115409093_item	2680402	et	3	main
tuleb	doc_532115409093_item	2680426	et	3	main
rohkem	doc_532115409093_item	2680427	et	4	main
kes	doc_532115409093_item	2680432	et	4	main
varalapsepõlves	doc_532115409093_item	2680433	et	4	main
vanematest	doc_532115409093_item	2680436	et	4	main
piisavalt	doc_532115409093_item	2680437	et	4	main
armastust	doc_532115409093_item	2680438	et	4	main
ja	doc_532115409093_item	2680439	et	3	main
ülekoormuse	doc_532115409093_item	2680444	et	3	main
arengule	doc_532115409093_item	2680448	et	3	main
neile	doc_532115409093_item	2680457	et	4	main
ärge	doc_532115409093_item	2680474	et	3	main
teevad	doc_532115409094_item	2680480	et	3	main
käesoleval	doc_532115409094_item	2680486	et	3	main
erinevaid	doc_532115409094_item	2680491	et	4	main
need	doc_532115409094_item	2680493	et	3	main
küürimispastad	doc_532115409094_item	2680497	et	4	main
nõudevahendid	doc_532115409094_item	2680499	et	3	main
edasi	doc_532115409094_item	2680502	et	3	main
väike	doc_532115409094_item	2680508	et	4	main
pesu	doc_532115409094_item	2680512	et	4	main
seebiga	doc_532115409094_item	2680513	et	3	main
ja	doc_532115409094_item	2680514	et	3	main
seebi	doc_532115409094_item	2680521	et	3	main
kasutasime	doc_532115409094_item	2680527	et	3	main
pesemiseks	doc_532115409094_item	2680531	et	4	main
juuksed	doc_532115409094_item	2680532	et	3	main
müügil	doc_532115409094_item	2680538	et	3	main
kasutame	doc_532115409094_item	2680546	et	3	main
ravivad	doc_532115409094_item	2680549	et	4	main
õhku	doc_532115409094_item	2680555	et	4	main
kasutame	doc_532115409094_item	2680558	et	3	main
nõudepesevahendeid	doc_532115409094_item	2680560	et	4	main
ja	doc_532115409094_item	2680561	et	3	main
küürimispastateid	doc_532115409094_item	2680562	et	4	main
aega	doc_532115409094_item	2680566	et	4	main
vannide	doc_532115409094_item	2680574	et	3	main
nõude	doc_532115409094_item	2680577	et	4	main
kasutatavad	doc_532115409094_item	2680579	et	4	main
kosmeetikavahendid	doc_532115409094_item	2680580	et	3	main
ja	doc_532115409093_item	2680323	et	3	main
ja	doc_532115409093_item	2680332	et	3	main
valge	doc_532115409093_item	2680338	et	4	main
ja	doc_532115409093_item	2680339	et	3	main
must	doc_532115409093_item	2680340	et	4	main
headus	doc_532115409093_item	2680341	et	4	main
on	doc_532115409093_item	2680344	et	4	main
kui	doc_532115409093_item	2680350	et	3	main
kurju	doc_532115409093_item	2680355	et	4	main
headust	doc_532115409093_item	2680359	et	4	main
antakse	doc_532115409093_item	2680362	et	3	main
valida	doc_532115409093_item	2680364	et	3	main
see	doc_532115409093_item	2680376	et	3	main
aga	doc_532115409093_item	2680380	et	3	main
ju	doc_532115409093_item	2680382	et	3	main
lapsed	doc_532115409093_item	2680386	et	3	main
et	doc_532115409093_item	2680400	et	3	main
7	doc_532115409093_item	2680405	et	2	main
sellel	doc_532115409093_item	2680407	et	4	main
laps	doc_532115409093_item	2680409	et	4	main
peab	doc_532115409093_item	2680410	et	4	main
õppima	doc_532115409093_item	2680411	et	3	main
tundma	doc_532115409093_item	2680412	et	3	main
iludust	doc_532115409093_item	2680413	et	4	main
ja	doc_532115409093_item	2680414	et	3	main
harmooniat	doc_532115409093_item	2680415	et	3	main
muidugi	doc_532115409093_item	2680416	et	4	main
mitte	doc_532115409093_item	2680417	et	3	main
kõik	doc_532115409093_item	2680418	et	4	main
vanemad	doc_532115409093_item	2680419	et	4	main
saavad	doc_532115409093_item	2680420	et	4	main
koolis	doc_532115409093_item	2680425	et	4	main
töötada	doc_532115409093_item	2680428	et	3	main
saanud	doc_532115409093_item	2680435	et	4	main
nõrgalt	doc_532115409093_item	2680442	et	4	main
pole	doc_532115409093_item	2680449	et	3	main
aeglasemad	doc_532115409093_item	2680453	et	4	main
peavad	doc_532115409093_item	2680455	et	4	main
jõukohast	doc_532115409093_item	2680458	et	4	main
arendavat	doc_532115409093_item	2680460	et	4	main
tööd	doc_532115409093_item	2680461	et	4	main
ja	doc_532115409093_item	2680462	et	3	main
kindlasti	doc_532115409093_item	2680463	et	3	main
igas	doc_532115409093_item	2680464	et	3	main
rajoonis	doc_532115409093_item	2680465	et	4	main
töötama	doc_532115409093_item	2680467	et	3	main
huviringid	doc_532115409093_item	2680468	et	3	main
peavad	doc_532115409093_item	2680466	et	4	main
tasumata	doc_532115409093_item	2680469	et	4	main
lapsed	doc_532115409093_item	2680470	et	3	main
on	doc_532115409093_item	2680471	et	4	main
unustage	doc_532115409093_item	2680475	et	3	main
meie	doc_532115409094_item	2680481	et	4	main
lihtsamaks	doc_532115409094_item	2680483	et	4	main
ajal	doc_532115409094_item	2680487	et	4	main
kasutatakse	doc_532115409094_item	2680490	et	3	main
pesupulbrid	doc_532115409094_item	2680496	et	3	main
õhuvärskendajad	doc_532115409094_item	2680498	et	3	main
nii	doc_532115409094_item	2680501	et	3	main
ma	doc_532115409094_item	2680503	et	3	main
olin	doc_532115409094_item	2680507	et	3	main
minu	doc_532115409094_item	2680509	et	3	main
ema	doc_532115409094_item	2680510	et	4	main
pesi	doc_532115409094_item	2680511	et	4	main
vee	doc_532115409094_item	2680517	et	3	main
hulgas	doc_532115409094_item	2680519	et	4	main
lõhna	doc_532115409094_item	2680522	et	4	main
me	doc_532115409094_item	2680526	et	4	main
ka	doc_532115409094_item	2680529	et	3	main
juuste	doc_532115409094_item	2680530	et	4	main
praegu	doc_532115409094_item	2680537	et	3	main
erinevad	doc_532115409094_item	2680540	et	4	main
keemiatooted	doc_532115409094_item	2680541	et	3	main
mida	doc_532115409094_item	2680542	et	4	main
kasutatakse	doc_532115409094_item	2680543	et	3	main
tihti	doc_532115409094_item	2680544	et	3	main
meie	doc_532115409094_item	2680565	et	4	main
sest	doc_532115409094_item	2680568	et	4	main
kasutatav	doc_532115409094_item	2680569	et	4	main
küürimispasta	doc_532115409094_item	2680570	et	4	main
seinaplaatide	doc_532115409094_item	2680575	et	3	main
naha	doc_532115409094_item	2680583	et	3	main
väga	doc_532115409096_item	2680727	et	3	main
sarnased	doc_532115409096_item	2680735	et	4	main
teha	doc_532115409096_item	2680741	et	3	main
nii	doc_532115409096_item	2680751	et	3	main
oma	doc_532115409096_item	2680761	et	4	main
oli	doc_532115409096_item	2680763	et	3	main
1980	doc_532115409096_item	2680764	et	2	main
töökohta	doc_532115409096_item	2680772	et	4	main
ja	doc_532115409096_item	2680774	et	3	main
kord	doc_532115409096_item	2680786	et	4	main
oli	doc_532115409096_item	2680787	et	3	main
1994	doc_532115409096_item	2680788	et	2	main
aastal	doc_532115409096_item	2680789	et	3	main
millal	doc_532115409096_item	2680790	et	3	main
ma	doc_532115409096_item	2680791	et	3	main
olin	doc_532115409096_item	2680792	et	3	main
pakuti	doc_532115409096_item	2680797	et	3	main
mul	doc_532115409096_item	2680801	et	3	main
väga	doc_532115409094_item	2680524	et	3	main
olid	doc_532115409094_item	2680533	et	4	main
rasvased	doc_532115409094_item	2680534	et	4	main
on	doc_532115409094_item	2680539	et	4	main
sampoone	doc_532115409094_item	2680547	et	4	main
mis	doc_532115409094_item	2680548	et	4	main
ja	doc_532115409094_item	2680550	et	3	main
õhuvärskendajad	doc_532115409094_item	2680553	et	3	main
erinevaid	doc_532115409094_item	2680559	et	4	main
kokku	doc_532115409094_item	2680567	et	3	main
puhastumiseks	doc_532115409094_item	2680578	et	4	main
meie	doc_532115409094_item	2680582	et	4	main
pehmeks	doc_532115409094_item	2680584	et	3	main
meeldis	doc_532115409096_item	2680728	et	3	main
mulle	doc_532115409096_item	2680738	et	4	main
vaheldusi	doc_532115409096_item	2680742	et	4	main
valisin	doc_532115409096_item	2680770	et	3	main
kus	doc_532115409096_item	2680778	et	3	main
olnud	doc_532115409096_item	2680780	et	4	main
töötada	doc_532115409096_item	2680798	et	3	main
kuigi	doc_532115409096_item	2680800	et	3	main
ei	doc_532115409096_item	2680802	et	4	main
kogemust	doc_532115409096_item	2680804	et	3	main
üldse	doc_532115409096_item	2680805	et	3	main
ja	doc_532115409096_item	2680806	et	3	main
mõned	doc_532115409096_item	2680807	et	3	main
inimesed	doc_532115409096_item	2680808	et	3	main
rabasin	doc_532115409096_item	2680824	et	3	main
minu	doc_532115409096_item	2680838	et	3	main
ka	doc_532115409096_item	2680841	et	3	main
viie	doc_532115409096_item	2680843	et	3	main
sain	doc_532115409096_item	2680853	et	3	main
ole	doc_532115409096_item	2680858	et	4	main
kolmanda	doc_532115409096_item	2680862	et	3	main
1998	doc_532115409096_item	2680866	et	2	main
lõpus	doc_532115409096_item	2680868	et	4	main
millal	doc_532115409096_item	2680869	et	3	main
ma	doc_532115409096_item	2680870	et	3	main
tulin	doc_532115409096_item	2680871	et	3	main
töölt	doc_532115409096_item	2680872	et	3	main
aitavad	doc_532115409096_item	2680897	et	4	main
õluta	doc_532115409097_item	2680922	et	4	main
kommita	doc_532115409097_item	2680928	et	4	main
aga	doc_532115409097_item	2680929	et	3	main
ei	doc_532115409097_item	2680940	et	4	main
riided	doc_532115409097_item	2680949	et	3	main
või	doc_532115409097_item	2680952	et	4	main
lapseta	doc_532115409097_item	2680977	et	3	main
kui	doc_532115409097_item	2680985	et	3	main
armastus	doc_532115409097_item	2680997	et	4	main
korras	doc_532115409097_item	2681006	et	4	main
ja	doc_532115409097_item	2681007	et	3	main
on	doc_532115409097_item	2681016	et	4	main
edasi	doc_532115409097_item	2681022	et	3	main
ja	doc_532115409097_item	2681023	et	3	main
nsvl	doc_532115409098_item	2681041	et	4	main
eesti	doc_532115409098_item	2681047	et	4	main
kui	doc_532115409098_item	2681056	et	3	main
kõigepealt	doc_532115409098_item	2681084	et	3	main
olla	doc_532115409098_item	2681092	et	3	main
12	doc_532115409098_item	2681095	et	2	main
vaid	doc_532115409098_item	2681097	et	3	main
rohkem	doc_532115409098_item	2681102	et	4	main
päris	doc_532115409098_item	2681110	et	4	main
teavad	doc_532115409098_item	2681112	et	3	main
kannapöörded	doc_532115409096_item	2680725	et	4	main
mulle	doc_532115409096_item	2680726	et	4	main
ma	doc_532115409096_item	2680730	et	3	main
et	doc_532115409096_item	2680732	et	3	main
ka	doc_532115409096_item	2680739	et	3	main
elu	doc_532115409096_item	2680744	et	4	main
vaheldused	doc_532115409096_item	2680748	et	4	main
ei	doc_532115409096_item	2680749	et	4	main
ole	doc_532115409096_item	2680750	et	4	main
endale	doc_532115409096_item	2680771	et	4	main
võrrases	doc_532115409096_item	2680775	et	4	main
linnas	doc_532115409096_item	2680776	et	4	main
ei	doc_532115409096_item	2680779	et	4	main
keegi	doc_532115409096_item	2680782	et	4	main
minu	doc_532115409096_item	2680783	et	3	main
tuttavatest	doc_532115409096_item	2680784	et	4	main
teine	doc_532115409096_item	2680785	et	3	main
mulle	doc_532115409096_item	2680796	et	4	main
olnud	doc_532115409096_item	2680803	et	4	main
olid	doc_532115409096_item	2680809	et	4	main
kindel	doc_532115409096_item	2680810	et	3	main
muutus	doc_532115409096_item	2680837	et	4	main
aga	doc_532115409096_item	2680842	et	3	main
väsisin	doc_532115409096_item	2680846	et	3	main
et	doc_532115409096_item	2680855	et	3	main
ma	doc_532115409096_item	2680864	et	3	main
taas	doc_532115409096_item	2680875	et	3	main
praegu	doc_532115409096_item	2680878	et	3	main
on	doc_532115409096_item	2680883	et	4	main
kõige	doc_532115409096_item	2680884	et	4	main
neise	doc_532115409096_item	2680886	et	4	main
ja	doc_532115409096_item	2680892	et	3	main
töö	doc_532115409096_item	2680894	et	4	main
minu	doc_532115409096_item	2680899	et	3	main
keel	doc_532115409096_item	2680903	et	4	main
ilma	doc_532115409097_item	2680921	et	4	main
laps	doc_532115409097_item	2680923	et	4	main
ei	doc_532115409097_item	2680924	et	4	main
külli	doc_532115409096_item	2680729	et	4	main
mõtlen	doc_532115409096_item	2680731	et	3	main
me	doc_532115409096_item	2680733	et	4	main
iseloomu	doc_532115409096_item	2680736	et	4	main
poolt	doc_532115409096_item	2680737	et	4	main
olla	doc_532115409096_item	2680746	et	3	main
järske	doc_532115409096_item	2680752	et	3	main
külli	doc_532115409096_item	2680754	et	4	main
kord	doc_532115409096_item	2680757	et	4	main
millal	doc_532115409096_item	2680758	et	3	main
ma	doc_532115409096_item	2680759	et	3	main
muutasin	doc_532115409096_item	2680760	et	4	main
elu	doc_532115409096_item	2680762	et	4	main
aastal	doc_532115409096_item	2680765	et	3	main
lõpetasin	doc_532115409096_item	2680767	et	3	main
ja	doc_532115409096_item	2680769	et	3	main
tundmatus	doc_532115409096_item	2680773	et	4	main
lihtsalt	doc_532115409096_item	2680793	et	4	main
koduperenaine	doc_532115409096_item	2680794	et	3	main
raamatupidaja	doc_532115409096_item	2680799	et	4	main
et	doc_532115409096_item	2680811	et	3	main
mu	doc_532115409096_item	2680812	et	3	main
kandidatuur	doc_532115409096_item	2680813	et	3	main
on	doc_532115409096_item	2680814	et	4	main
vale	doc_532115409096_item	2680815	et	4	main
ise	doc_532115409096_item	2680816	et	4	main
ma	doc_532115409096_item	2680817	et	3	main
olin	doc_532115409096_item	2680818	et	3	main
nõus	doc_532115409096_item	2680819	et	4	main
ja	doc_532115409096_item	2680820	et	3	main
hakkama	doc_532115409096_item	2680822	et	3	main
külli	doc_532115409096_item	2680826	et	4	main
kasvas	doc_532115409096_item	2680828	et	3	main
professionalne	doc_532115409096_item	2680831	et	4	main
tase	doc_532115409096_item	2680832	et	3	main
ja	doc_532115409096_item	2680833	et	3	main
amet	doc_532115409096_item	2680834	et	3	main
materiaalne	doc_532115409096_item	2680839	et	3	main
aastaga	doc_532115409096_item	2680844	et	3	main
ära	doc_532115409096_item	2680847	et	4	main
kadusin	doc_532115409096_item	2680849	et	3	main
oma	doc_532115409096_item	2680850	et	4	main
pea	doc_532115409096_item	2680859	et	4	main
asi	doc_532115409096_item	2680860	et	4	main
ära	doc_532115409096_item	2680873	et	4	main
arvan	doc_532115409096_item	2680880	et	3	main
lastekasvatamine	doc_532115409096_item	2680882	et	3	main
väga	doc_532115409096_item	2680890	et	3	main
suur	doc_532115409096_item	2680891	et	3	main
veel	doc_532115409096_item	2680895	et	4	main
harrastused	doc_532115409096_item	2680900	et	4	main
eesti	doc_532115409096_item	2680902	et	4	main
elada	doc_532115409097_item	2680926	et	3	main
on	doc_532115409097_item	2680931	et	4	main
nali	doc_532115409097_item	2680932	et	3	main
kui	doc_532115409097_item	2680933	et	3	main
saame	doc_532115409097_item	2680941	et	4	main
õhuta	doc_532115409097_item	2680944	et	4	main
on	doc_532115409097_item	2680947	et	4	main
paljud	doc_532115409097_item	2680954	et	3	main
ei	doc_532115409097_item	2680971	et	4	main
kui	doc_532115409097_item	2680981	et	3	main
tervise	doc_532115409097_item	2680982	et	3	main
ei	doc_532115409097_item	2680986	et	4	main
tahab	doc_532115409097_item	2680990	et	3	main
kodu	doc_532115409097_item	2681002	et	4	main
siis	doc_532115409097_item	2681003	et	3	main
sul	doc_532115409097_item	2681017	et	3	main
eesti	doc_532115409098_item	2681028	et	4	main
siin	doc_532115409098_item	2681038	et	4	main
eestis	doc_532115409098_item	2681039	et	3	main
meeldib	doc_532115409096_item	2680740	et	3	main
oma	doc_532115409096_item	2680743	et	4	main
võib	doc_532115409096_item	2680745	et	3	main
nad	doc_532115409096_item	2680747	et	3	main
nagu	doc_532115409096_item	2680753	et	3	main
kannapöörded	doc_532115409096_item	2680755	et	4	main
esimene	doc_532115409096_item	2680756	et	3	main
ma	doc_532115409096_item	2680766	et	3	main
instituuti	doc_532115409096_item	2680768	et	4	main
tallinnas	doc_532115409096_item	2680777	et	4	main
mitte	doc_532115409096_item	2680781	et	3	main
ja	doc_532115409096_item	2680795	et	3	main
sain	doc_532115409096_item	2680821	et	3	main
nagu	doc_532115409096_item	2680825	et	3	main
minu	doc_532115409096_item	2680830	et	3	main
kasvasid	doc_532115409096_item	2680836	et	4	main
ma	doc_532115409096_item	2680845	et	3	main
ja	doc_532115409096_item	2680848	et	3	main
elumärki	doc_532115409096_item	2680851	et	4	main
aru	doc_532115409096_item	2680854	et	4	main
raha	doc_532115409096_item	2680856	et	4	main
ei	doc_532115409096_item	2680857	et	4	main
elus	doc_532115409096_item	2680861	et	4	main
tegin	doc_532115409096_item	2680865	et	3	main
ja	doc_532115409096_item	2680874	et	3	main
koduperenaiseks	doc_532115409096_item	2680877	et	3	main
ma	doc_532115409096_item	2680879	et	3	main
tähtsaim	doc_532115409096_item	2680885	et	4	main
jaoks	doc_532115409096_item	2680887	et	4	main
on	doc_532115409096_item	2680889	et	4	main
saa	doc_532115409097_item	2680925	et	4	main
ilma	doc_532115409097_item	2680927	et	4	main
see	doc_532115409097_item	2680930	et	3	main
veetta	doc_532115409097_item	2680945	et	4	main
lõbu	doc_532115409097_item	2680972	et	4	main
elada	doc_532115409097_item	2680973	et	3	main
ilma	doc_532115409097_item	2680974	et	4	main
saa	doc_532115409097_item	2680987	et	4	main
no	doc_532115409097_item	2680991	et	3	main
pere	doc_532115409097_item	2680998	et	4	main
töö	doc_532115409097_item	2681000	et	4	main
ja	doc_532115409097_item	2681001	et	3	main
on	doc_532115409097_item	2681004	et	4	main
ja	doc_532115409097_item	2681015	et	3	main
või	doc_532115409097_item	2681019	et	4	main
ma	doc_532115409096_item	2680823	et	3	main
firma	doc_532115409096_item	2680827	et	4	main
ja	doc_532115409096_item	2680829	et	3	main
ka	doc_532115409096_item	2680835	et	3	main
seis	doc_532115409096_item	2680840	et	4	main
ma	doc_532115409096_item	2680852	et	3	main
pöörde	doc_532115409096_item	2680863	et	3	main
aasta	doc_532115409096_item	2680867	et	4	main
sain	doc_532115409096_item	2680876	et	3	main
et	doc_532115409096_item	2680881	et	3	main
see	doc_532115409096_item	2680888	et	3	main
vastutusrikas	doc_532115409096_item	2680893	et	4	main
mulle	doc_532115409096_item	2680896	et	4	main
elada	doc_532115409096_item	2680898	et	3	main
filosoofia	doc_532115409096_item	2680901	et	4	main
tupperware	doc_532115409096_item	2680904	et	4	main
nõud	doc_532115409096_item	2680905	et	3	main
mis	doc_532115409096_item	2680906	et	4	main
on	doc_532115409096_item	2680907	et	4	main
edasi	doc_532115409096_item	2680908	et	3	main
vaatame	doc_532115409096_item	2680909	et	3	main
asjad	doc_532115409097_item	2680910	et	3	main
ilma	doc_532115409097_item	2680911	et	4	main
milleta	doc_532115409097_item	2680912	et	3	main
inimesed	doc_532115409097_item	2680913	et	3	main
saa	doc_532115409097_item	2680915	et	4	main
ei	doc_532115409097_item	2680914	et	4	main
elada	doc_532115409097_item	2680916	et	3	main
mees	doc_532115409097_item	2680917	et	4	main
ei	doc_532115409097_item	2680918	et	4	main
saa	doc_532115409097_item	2680919	et	4	main
elada	doc_532115409097_item	2680920	et	3	main
elada	doc_532115409097_item	2680942	et	3	main
vaja	doc_532115409097_item	2680948	et	4	main
ja	doc_532115409097_item	2680950	et	3	main
saavad	doc_532115409097_item	2680956	et	4	main
ilma	doc_532115409097_item	2680957	et	4	main
autota	doc_532115409097_item	2680958	et	3	main
ja	doc_532115409097_item	2680959	et	3	main
saame	doc_532115409097_item	2680960	et	4	main
aga	doc_532115409097_item	2680961	et	3	main
raske	doc_532115409097_item	2680962	et	4	main
elada	doc_532115409097_item	2680963	et	3	main
ilma	doc_532115409097_item	2680964	et	4	main
rahata	doc_532115409097_item	2680965	et	4	main
ilma	doc_532115409097_item	2680966	et	4	main
tööta	doc_532115409097_item	2680967	et	4	main
ilma	doc_532115409097_item	2680968	et	4	main
pereta	doc_532115409097_item	2680969	et	3	main
ja	doc_532115409097_item	2680970	et	3	main
tõsiselt	doc_532115409097_item	2680934	et	4	main
rääkima	doc_532115409097_item	2680935	et	3	main
siis	doc_532115409097_item	2680936	et	3	main
on	doc_532115409097_item	2680937	et	4	main
juba	doc_532115409097_item	2680938	et	3	main
järjekord	doc_532115409097_item	2680939	et	3	main
ilma	doc_532115409097_item	2680943	et	4	main
tuleta	doc_532115409097_item	2680946	et	4	main
korterid	doc_532115409097_item	2680951	et	3	main
majad	doc_532115409097_item	2680953	et	3	main
ei	doc_532115409097_item	2680955	et	4	main
ilma	doc_532115409097_item	2680976	et	4	main
ja	doc_532115409097_item	2680978	et	3	main
raske	doc_532115409097_item	2680979	et	4	main
elada	doc_532115409097_item	2680980	et	3	main
ei	doc_532115409097_item	2680983	et	4	main
teha	doc_532115409097_item	2680988	et	3	main
muidugi	doc_532115409097_item	2680992	et	4	main
kui	doc_532115409097_item	2680993	et	3	main
sul	doc_532115409097_item	2680994	et	3	main
on	doc_532115409097_item	2680995	et	4	main
tervis	doc_532115409097_item	2680996	et	3	main
kõik	doc_532115409097_item	2681005	et	4	main
ela	doc_532115409097_item	2681021	et	4	main
ole	doc_532115409097_item	2681024	et	4	main
rõõm	doc_532115409097_item	2681025	et	3	main
vene	doc_532115409098_item	2681026	et	4	main
kool	doc_532115409098_item	2681027	et	4	main
muidugi	doc_532115409098_item	2681043	et	4	main
keel	doc_532115409098_item	2681048	et	4	main
me	doc_532115409098_item	2681052	et	4	main
seda	doc_532115409098_item	2681054	et	3	main
me	doc_532115409098_item	2681057	et	4	main
eesti	doc_532115409098_item	2681073	et	4	main
ei	doc_532115409098_item	2681076	et	4	main
võib	doc_532115409098_item	2681091	et	3	main
minimum	doc_532115409098_item	2681098	et	4	main
algklassis	doc_532115409098_item	2681099	et	3	main
9	doc_532115409098_item	2681103	et	2	main
et	doc_532115409098_item	2681107	et	3	main
sest	doc_532115409098_item	2681115	et	4	main
nad	doc_532115409098_item	2681116	et	3	main
armastuseta	doc_532115409097_item	2680975	et	4	main
ole	doc_532115409097_item	2680984	et	4	main
mis	doc_532115409097_item	2680989	et	4	main
usu	doc_532115409097_item	2680999	et	4	main
pole	doc_532115409097_item	2681008	et	3	main
tähtis	doc_532115409097_item	2681009	et	4	main
kui	doc_532115409097_item	2681010	et	3	main
suur	doc_532115409097_item	2681011	et	3	main
palk	doc_532115409097_item	2681012	et	3	main
sul	doc_532115409097_item	2681013	et	3	main
on	doc_532115409097_item	2681014	et	4	main
auto	doc_532115409097_item	2681018	et	4	main
ei	doc_532115409097_item	2681020	et	4	main
keeles	doc_532115409098_item	2681029	et	4	main
ma	doc_532115409098_item	2681030	et	3	main
tahan	doc_532115409098_item	2681031	et	3	main
alustada	doc_532115409098_item	2681032	et	3	main
sellest	doc_532115409098_item	2681033	et	4	main
et	doc_532115409098_item	2681034	et	3	main
lõppu	doc_532115409098_item	2681042	et	4	main
on	doc_532115409098_item	2681049	et	4	main
peame	doc_532115409098_item	2681053	et	4	main
keeles	doc_532115409098_item	2681074	et	4	main
ole	doc_532115409098_item	2681077	et	4	main
nõus	doc_532115409098_item	2681078	et	4	main
sellega	doc_532115409098_item	2681079	et	3	main
iga	doc_532115409098_item	2681085	et	4	main
laps	doc_532115409098_item	2681086	et	4	main
õppima	doc_532115409098_item	2681088	et	3	main
või	doc_532115409098_item	2681100	et	4	main
mõtlen	doc_532115409098_item	2681106	et	3	main
venelased	doc_532115409098_item	2681109	et	3	main
hästi	doc_532115409098_item	2681111	et	3	main
keel	doc_532115409098_item	2681114	et	4	main
saavad	doc_532115409098_item	2681118	et	4	main
töötavad	doc_532115409098_item	2681121	et	4	main
paljud	doc_532115409098_item	2681123	et	3	main
on	doc_532115409098_item	2681124	et	4	main
juba	doc_532115409098_item	2681125	et	3	main
praegu	doc_532115409098_item	2681140	et	3	main
juba	doc_532115409098_item	2681145	et	3	main
ja	doc_532115409098_item	2681153	et	3	main
õppivad	doc_532115409098_item	2681159	et	4	main
venelased	doc_532115409098_item	2681192	et	3	main
näiteks	doc_532115409098_item	2681203	et	4	main
et	doc_532115409098_item	2681210	et	3	main
madalam	doc_532115409098_item	2681224	et	4	main
on	doc_532115409098_item	2681225	et	4	main
vaheta	doc_532115409098_item	2681236	et	4	main
tuleb	doc_532115409098_item	2681242	et	3	main
eestlastel	doc_532115409098_item	2681245	et	4	main
ühte	doc_532115409098_item	2681256	et	4	main
nad	doc_532115409098_item	2681264	et	3	main
parem	doc_532115409098_item	2681271	et	4	main
on	doc_532115409098_item	2681273	et	4	main
kus	doc_532115409098_item	2681275	et	3	main
on	doc_532115409098_item	2681276	et	4	main
suured	doc_532115409098_item	2681277	et	3	main
probleemid	doc_532115409098_item	2681278	et	3	main
tegema	doc_532115409098_item	2681292	et	3	main
me	doc_532115409098_item	2681035	et	4	main
venelased	doc_532115409098_item	2681036	et	3	main
elame	doc_532115409098_item	2681037	et	3	main
me	doc_532115409098_item	2681044	et	4	main
riigikeel	doc_532115409098_item	2681050	et	4	main
ja	doc_532115409098_item	2681051	et	3	main
tahame	doc_532115409098_item	2681058	et	3	main
siin	doc_532115409098_item	2681059	et	4	main
elada	doc_532115409098_item	2681060	et	3	main
ja	doc_532115409098_item	2681061	et	3	main
töötada	doc_532115409098_item	2681062	et	3	main
aga	doc_532115409098_item	2681063	et	3	main
kas	doc_532115409098_item	2681064	et	3	main
see	doc_532115409098_item	2681066	et	3	main
hädavajalik	doc_532115409098_item	2681067	et	3	main
et	doc_532115409098_item	2681068	et	3	main
on	doc_532115409098_item	2681065	et	4	main
vene	doc_532115409098_item	2681069	et	4	main
koolis	doc_532115409098_item	2681070	et	4	main
lapsed	doc_532115409098_item	2681071	et	3	main
ma	doc_532115409098_item	2681075	et	3	main
pärast	doc_532115409098_item	2681040	et	4	main
teame	doc_532115409098_item	2681045	et	3	main
et	doc_532115409098_item	2681046	et	3	main
õppima	doc_532115409098_item	2681055	et	3	main
sest	doc_532115409098_item	2681080	et	4	main
ma	doc_532115409098_item	2681081	et	3	main
arvan	doc_532115409098_item	2681082	et	3	main
peab	doc_532115409098_item	2681087	et	4	main
oma	doc_532115409098_item	2681089	et	4	main
emakelles	doc_532115409098_item	2681090	et	3	main
kõik	doc_532115409098_item	2681094	et	4	main
klassid	doc_532115409098_item	2681096	et	3	main
eesti	doc_532115409098_item	2681113	et	4	main
nad	doc_532115409098_item	2681120	et	3	main
kõik	doc_532115409098_item	2681129	et	4	main
see	doc_532115409098_item	2681130	et	3	main
näeb	doc_532115409098_item	2681131	et	3	main
et	doc_532115409098_item	2681132	et	3	main
me	doc_532115409098_item	2681133	et	4	main
juba	doc_532115409098_item	2681134	et	3	main
teame	doc_532115409098_item	2681135	et	3	main
ja	doc_532115409098_item	2681136	et	3	main
lapsed	doc_532115409098_item	2681141	et	3	main
seda	doc_532115409098_item	2681143	et	3	main
eesti	doc_532115409098_item	2681150	et	4	main
hiljem	doc_532115409098_item	2681154	et	3	main
õppida	doc_532115409098_item	2681194	et	3	main
lapsed	doc_532115409098_item	2681204	et	3	main
ei	doc_532115409098_item	2681205	et	4	main
eesti	doc_532115409098_item	2681215	et	4	main
keeles	doc_532115409098_item	2681216	et	4	main
see	doc_532115409098_item	2681217	et	3	main
vaja	doc_532115409098_item	2681226	et	4	main
kõik	doc_532115409098_item	2681227	et	4	main
hariduseprogramm	doc_532115409098_item	2681231	et	4	main
ei	doc_532115409098_item	2681235	et	4	main
oma	doc_532115409098_item	2681237	et	4	main
madalam	doc_532115409098_item	2681239	et	4	main
siis	doc_532115409098_item	2681241	et	3	main
niimoodi	doc_532115409098_item	2681243	et	3	main
meil	doc_532115409098_item	2681253	et	4	main
pärast	doc_532115409098_item	2681263	et	4	main
rahvustega	doc_532115409098_item	2681279	et	3	main
riik	doc_532115409098_item	2681282	et	3	main
olla	doc_532115409098_item	2681285	et	3	main
nendel	doc_532115409098_item	2681324	et	4	main
võimalus	doc_532115409098_item	2681326	et	3	main
ema	doc_532115409098_item	2681328	et	4	main
keel	doc_532115409098_item	2681329	et	4	main
nagu	doc_532115409098_item	2681330	et	3	main
venelastel	doc_532115409098_item	2681338	et	4	main
silmad	doc_532115409098_item	2681346	et	4	main
nõus	doc_532115409098_item	2681350	et	4	main
eesti	doc_532115409098_item	2681355	et	4	main
kas	doc_532115409098_item	2681374	et	3	main
eesti	doc_532115409098_item	2681375	et	4	main
see	doc_532115409098_item	2681380	et	3	main
on	doc_532115409098_item	2681381	et	4	main
kool	doc_532115409098_item	2681384	et	4	main
kuidas	doc_532115409098_item	2681389	et	3	main
koolis	doc_532115409098_item	2681394	et	4	main
õppida	doc_532115409098_item	2681411	et	3	main
variant	doc_532115409098_item	2681420	et	3	main
lihtsalt	doc_532115409098_item	2681421	et	4	main
koolis	doc_532115409098_item	2681423	et	4	main
paar	doc_532115409098_item	2681424	et	3	main
eesti	doc_532115409098_item	2681425	et	4	main
võib	doc_532115409098_item	2681430	et	3	main
teha	doc_532115409098_item	2681432	et	3	main
eesti	doc_532115409098_item	2681435	et	4	main
keeles	doc_532115409098_item	2681436	et	4	main
muusika	doc_532115409098_item	2681440	et	4	main
kunst	doc_532115409098_item	2681441	et	3	main
siis	doc_532115409098_item	2681442	et	3	main
palju	doc_532115409098_item	2681446	et	4	main
riik	doc_532115409098_item	2681451	et	3	main
tahab	doc_532115409098_item	2681452	et	3	main
et	doc_532115409098_item	2681453	et	3	main
venelased	doc_532115409098_item	2681454	et	3	main
näe	doc_532115409098_item	2681462	et	4	main
palju	doc_532115409098_item	2681466	et	4	main
paremaid	doc_532115409098_item	2681467	et	4	main
õpisid	doc_532115409098_item	2681072	et	4	main
et	doc_532115409098_item	2681083	et	3	main
mitte	doc_532115409098_item	2681093	et	3	main
natukene	doc_532115409098_item	2681101	et	4	main
klassini	doc_532115409098_item	2681104	et	3	main
ma	doc_532115409098_item	2681105	et	3	main
praegu	doc_532115409098_item	2681108	et	3	main
aru	doc_532115409098_item	2681117	et	4	main
keel	doc_532115409098_item	2681139	et	4	main
siis	doc_532115409098_item	2681147	et	3	main
lähevad	doc_532115409098_item	2681156	et	3	main
ja	doc_532115409098_item	2681158	et	3	main
seal	doc_532115409098_item	2681160	et	4	main
kõik	doc_532115409098_item	2681161	et	4	main
probleemi	doc_532115409098_item	2681202	et	4	main
sõnu	doc_532115409098_item	2681209	et	4	main
saada	doc_532115409098_item	2681212	et	4	main
et	doc_532115409098_item	2681221	et	3	main
läheb	doc_532115409098_item	2681223	et	3	main
vahetada	doc_532115409098_item	2681230	et	3	main
hariduseprogramm	doc_532115409098_item	2681238	et	4	main
ja	doc_532115409098_item	2681240	et	3	main
et	doc_532115409098_item	2681244	et	3	main
haridusetase	doc_532115409098_item	2681246	et	4	main
tuleb	doc_532115409098_item	2681247	et	3	main
ei	doc_532115409098_item	2681254	et	4	main
probleemi	doc_532115409098_item	2681257	et	4	main
ja	doc_532115409098_item	2681259	et	3	main
venelaste	doc_532115409098_item	2681260	et	4	main
tulevad	doc_532115409098_item	2681265	et	4	main
on	doc_532115409098_item	2681268	et	4	main
kui	doc_532115409098_item	2681280	et	3	main
tahab	doc_532115409098_item	2681283	et	3	main
edasi	doc_532115409098_item	2681284	et	3	main
rahulikult	doc_532115409098_item	2681286	et	4	main
siis	doc_532115409098_item	2681287	et	3	main
ta	doc_532115409098_item	2681288	et	4	main
sest	doc_532115409098_item	2681293	et	4	main
riigis	doc_532115409098_item	2681322	et	3	main
siis	doc_532115409098_item	2681323	et	3	main
lihtsalt	doc_532115409098_item	2681344	et	4	main
teeb	doc_532115409098_item	2681345	et	3	main
keelt	doc_532115409098_item	2681356	et	4	main
õppida	doc_532115409098_item	2681357	et	3	main
aga	doc_532115409098_item	2681360	et	3	main
mõtlen	doc_532115409098_item	2681362	et	3	main
peab	doc_532115409098_item	2681365	et	4	main
vene	doc_532115409098_item	2681376	et	4	main
demokraatiliselt	doc_532115409098_item	2681382	et	4	main
näide	doc_532115409098_item	2681388	et	3	main
emakeeles	doc_532115409098_item	2681399	et	4	main
aga	doc_532115409098_item	2681400	et	3	main
pärast	doc_532115409098_item	2681401	et	4	main
otsustasime	doc_532115409098_item	2681405	et	3	main
veel	doc_532115409098_item	2681418	et	4	main
üks	doc_532115409098_item	2681419	et	3	main
kõik	doc_532115409098_item	2681119	et	4	main
siin	doc_532115409098_item	2681122	et	4	main
eesti	doc_532115409098_item	2681126	et	4	main
kodanikud	doc_532115409098_item	2681127	et	3	main
ja	doc_532115409098_item	2681128	et	3	main
pärast	doc_532115409098_item	2681148	et	4	main
nad	doc_532115409098_item	2681155	et	3	main
ülikooli	doc_532115409098_item	2681157	et	4	main
siin	doc_532115409098_item	2681177	et	4	main
töötada	doc_532115409098_item	2681178	et	3	main
keelt	doc_532115409098_item	2681180	et	4	main
õppida	doc_532115409098_item	2681181	et	3	main
ja	doc_532115409098_item	2681182	et	3	main
nii	doc_532115409098_item	2681183	et	3	main
edasi	doc_532115409098_item	2681184	et	3	main
aga	doc_532115409098_item	2681185	et	3	main
kui	doc_532115409098_item	2681186	et	3	main
meie	doc_532115409098_item	2681187	et	4	main
riik	doc_532115409098_item	2681188	et	3	main
teeb	doc_532115409098_item	2681189	et	3	main
niimoodi	doc_532115409098_item	2681190	et	3	main
et	doc_532115409098_item	2681191	et	3	main
koolis	doc_532115409098_item	2681195	et	4	main
keeles	doc_532115409098_item	2681197	et	4	main
siis	doc_532115409098_item	2681198	et	3	main
see	doc_532115409098_item	2681199	et	3	main
tea	doc_532115409098_item	2681206	et	4	main
nii	doc_532115409098_item	2681207	et	3	main
aru	doc_532115409098_item	2681211	et	4	main
kõik	doc_532115409098_item	2681213	et	4	main
ained	doc_532115409098_item	2681214	et	3	main
haridusetase	doc_532115409098_item	2681222	et	4	main
õppikud	doc_532115409098_item	2681228	et	4	main
aga	doc_532115409098_item	2681233	et	3	main
vahel	doc_532115409098_item	2681261	et	4	main
siis	doc_532115409098_item	2681262	et	3	main
ja	doc_532115409098_item	2681266	et	3	main
fakt	doc_532115409098_item	2681269	et	3	main
näide	doc_532115409098_item	2681272	et	3	main
läti	doc_532115409098_item	2681274	et	4	main
eesti	doc_532115409098_item	2681281	et	4	main
rahva	doc_532115409098_item	2681321	et	3	main
riigikeel	doc_532115409098_item	2681331	et	4	main
umbes	doc_532115409098_item	2681339	et	4	main
40	doc_532115409098_item	2681340	et	2	main
protsenti	doc_532115409098_item	2681341	et	4	main
ja	doc_532115409098_item	2681342	et	3	main
riik	doc_532115409098_item	2681343	et	3	main
olen	doc_532115409098_item	2681349	et	3	main
et	doc_532115409098_item	2681352	et	3	main
ja	doc_532115409098_item	2681358	et	3	main
ise	doc_532115409098_item	2681366	et	4	main
või	doc_532115409098_item	2681377	et	4	main
kõige	doc_532115409098_item	2681386	et	4	main
on	doc_532115409098_item	2681390	et	4	main
kõik	doc_532115409098_item	2681396	et	4	main
õppisime	doc_532115409098_item	2681397	et	3	main
lõpetamist	doc_532115409098_item	2681403	et	4	main
tahame	doc_532115409098_item	2681407	et	3	main
keeles	doc_532115409098_item	2681409	et	4	main
gümnaasiumis	doc_532115409098_item	2681410	et	3	main
me	doc_532115409098_item	2681413	et	4	main
seda	doc_532115409098_item	2681414	et	3	main
tegime	doc_532115409098_item	2681415	et	3	main
siin	doc_532115409098_item	2681416	et	4	main
liisada	doc_532115409098_item	2681422	et	4	main
nadalas	doc_532115409098_item	2681428	et	4	main
ja	doc_532115409098_item	2681429	et	3	main
ained	doc_532115409098_item	2681434	et	3	main
teavad	doc_532115409098_item	2681455	et	3	main
eesti	doc_532115409098_item	2681456	et	4	main
varianti	doc_532115409098_item	2681468	et	4	main
aga	doc_532115409098_item	2681469	et	3	main
kui	doc_532115409098_item	2681470	et	3	main
riik	doc_532115409098_item	2681471	et	3	main
mõtleb	doc_532115409098_item	2681476	et	3	main
kättemaksta	doc_532115409098_item	2681483	et	4	main
õige	doc_532115409098_item	2681488	et	4	main
lõpetuseks	doc_532115409098_item	2681489	et	4	main
ütlen	doc_532115409098_item	2681490	et	3	main
et	doc_532115409098_item	2681491	et	3	main
on	doc_532115409098_item	2681492	et	4	main
õppime	doc_532115409098_item	2681137	et	4	main
eesti	doc_532115409098_item	2681138	et	4	main
alustavad	doc_532115409098_item	2681142	et	4	main
õppida	doc_532115409098_item	2681144	et	3	main
lasteajast	doc_532115409098_item	2681146	et	4	main
õppivad	doc_532115409098_item	2681149	et	4	main
keelt	doc_532115409098_item	2681151	et	4	main
koolis	doc_532115409098_item	2681152	et	4	main
ained	doc_532115409098_item	2681162	et	3	main
eesti	doc_532115409098_item	2681163	et	4	main
keeles	doc_532115409098_item	2681164	et	4	main
ja	doc_532115409098_item	2681165	et	3	main
see	doc_532115409098_item	2681166	et	3	main
on	doc_532115409098_item	2681167	et	4	main
väga	doc_532115409098_item	2681168	et	3	main
hea	doc_532115409098_item	2681169	et	4	main
tulemus	doc_532115409098_item	2681170	et	3	main
et	doc_532115409098_item	2681171	et	3	main
venelased	doc_532115409098_item	2681172	et	3	main
ikkagi	doc_532115409098_item	2681173	et	4	main
tahavad	doc_532115409098_item	2681174	et	3	main
siin	doc_532115409098_item	2681175	et	4	main
elada	doc_532115409098_item	2681176	et	3	main
eesti	doc_532115409098_item	2681179	et	4	main
alustavad	doc_532115409098_item	2681193	et	4	main
eesti	doc_532115409098_item	2681196	et	4	main
teeb	doc_532115409098_item	2681200	et	3	main
palju	doc_532115409098_item	2681201	et	4	main
palju	doc_532115409098_item	2681208	et	4	main
tekkitab	doc_532115409098_item	2681218	et	4	main
niisugune	doc_532115409098_item	2681219	et	3	main
probleem	doc_532115409098_item	2681220	et	3	main
ületeha	doc_532115409098_item	2681229	et	4	main
vahetada	doc_532115409098_item	2681232	et	3	main
eestlased	doc_532115409098_item	2681234	et	3	main
kõrgem	doc_532115409098_item	2681248	et	4	main
kui	doc_532115409098_item	2681249	et	3	main
venelastel	doc_532115409098_item	2681250	et	4	main
kui	doc_532115409098_item	2681251	et	3	main
praegu	doc_532115409098_item	2681252	et	3	main
ole	doc_532115409098_item	2681255	et	4	main
eestlaste	doc_532115409098_item	2681258	et	4	main
see	doc_532115409098_item	2681267	et	3	main
kõige	doc_532115409098_item	2681270	et	4	main
ei	doc_532115409098_item	2681289	et	4	main
pea	doc_532115409098_item	2681290	et	4	main
seda	doc_532115409098_item	2681291	et	3	main
kõik	doc_532115409098_item	2681294	et	4	main
need	doc_532115409098_item	2681295	et	3	main
probleemid	doc_532115409098_item	2681296	et	3	main
stopivad	doc_532115409098_item	2681297	et	4	main
majandusetase	doc_532115409098_item	2681298	et	3	main
ka	doc_532115409098_item	2681299	et	3	main
praegu	doc_532115409098_item	2681300	et	3	main
me	doc_532115409098_item	2681301	et	4	main
euroliidus	doc_532115409098_item	2681303	et	4	main
oleme	doc_532115409098_item	2681302	et	3	main
aga	doc_532115409098_item	2681304	et	3	main
seal	doc_532115409098_item	2681305	et	4	main
on	doc_532115409098_item	2681306	et	4	main
niisugused	doc_532115409098_item	2681307	et	3	main
reeglid	doc_532115409098_item	2681308	et	3	main
et	doc_532115409098_item	2681309	et	3	main
kui	doc_532115409098_item	2681310	et	3	main
riigis	doc_532115409098_item	2681311	et	3	main
on	doc_532115409098_item	2681312	et	4	main
rahvusevähemus	doc_532115409098_item	2681313	et	4	main
ja	doc_532115409098_item	2681314	et	3	main
nad	doc_532115409098_item	2681315	et	3	main
rohkem	doc_532115409098_item	2681317	et	4	main
koostuvad	doc_532115409098_item	2681316	et	4	main
kui	doc_532115409098_item	2681318	et	3	main
17	doc_532115409098_item	2681319	et	2	main
protsenti	doc_532115409098_item	2681320	et	4	main
ja	doc_532115409098_item	2681332	et	3	main
õppida	doc_532115409098_item	2681333	et	3	main
oma	doc_532115409098_item	2681334	et	4	main
kinni	doc_532115409098_item	2681347	et	3	main
me	doc_532115409098_item	2681353	et	4	main
peame	doc_532115409098_item	2681354	et	4	main
inimene	doc_532115409098_item	2681364	et	3	main
mis	doc_532115409098_item	2681368	et	4	main
koolis	doc_532115409098_item	2681372	et	4	main
õppida	doc_532115409098_item	2681373	et	3	main
keeles	doc_532115409098_item	2681379	et	4	main
peab	doc_532115409098_item	2681391	et	4	main
olema	doc_532115409098_item	2681392	et	4	main
on	doc_532115409098_item	2681325	et	4	main
kasutada	doc_532115409098_item	2681327	et	3	main
keeles	doc_532115409098_item	2681335	et	4	main
eestis	doc_532115409098_item	2681336	et	3	main
on	doc_532115409098_item	2681337	et	4	main
ma	doc_532115409098_item	2681348	et	3	main
sellega	doc_532115409098_item	2681351	et	3	main
teada	doc_532115409098_item	2681359	et	3	main
ma	doc_532115409098_item	2681361	et	3	main
iga	doc_532115409098_item	2681363	et	4	main
otsustama	doc_532115409098_item	2681367	et	3	main
keeles	doc_532115409098_item	2681369	et	4	main
ta	doc_532115409098_item	2681370	et	4	main
tahab	doc_532115409098_item	2681371	et	3	main
inglise	doc_532115409098_item	2681378	et	4	main
meie	doc_532115409098_item	2681383	et	4	main
on	doc_532115409098_item	2681385	et	4	main
parem	doc_532115409098_item	2681387	et	4	main
me	doc_532115409098_item	2681395	et	4	main
põhikooli	doc_532115409098_item	2681402	et	4	main
on	doc_532115409098_item	2681417	et	4	main
keele	doc_532115409098_item	2681426	et	4	main
tundi	doc_532115409098_item	2681427	et	4	main
näiteks	doc_532115409098_item	2681437	et	4	main
kehaline	doc_532115409098_item	2681438	et	4	main
lähevad	doc_532115409098_item	2681444	et	3	main
keel	doc_532115409098_item	2681457	et	4	main
väga	doc_532115409098_item	2681458	et	3	main
hästi	doc_532115409098_item	2681459	et	3	main
probleemi	doc_532115409098_item	2681463	et	4	main
et	doc_532115409098_item	2681477	et	3	main
vene	doc_532115409098_item	2681479	et	4	main
kõik	doc_532115409098_item	2681487	et	4	main
teistel	doc_532115409098_item	2681495	et	4	main
teekida	doc_532115409098_item	2681500	et	4	main
nii	doc_532115409098_item	2681501	et	3	main
eesti	doc_532115409099_item	2681507	et	4	main
me	doc_532115409099_item	2681509	et	4	main
elame	doc_532115409099_item	2681512	et	3	main
et	doc_532115409099_item	2681522	et	3	main
ja	doc_532115409099_item	2681534	et	3	main
neist	doc_532115409099_item	2681536	et	4	main
üldse	doc_532115409099_item	2681537	et	3	main
ei	doc_532115409099_item	2681538	et	4	main
arvan	doc_532115409099_item	2681544	et	3	main
pea	doc_532115409099_item	2681551	et	4	main
järgmisel	doc_532115409099_item	2681561	et	3	main
eesti	doc_532115409099_item	2681574	et	4	main
ta	doc_532115409099_item	2681578	et	4	main
oli	doc_532115409099_item	2681589	et	3	main
vene	doc_532115409099_item	2681590	et	4	main
et	doc_532115409099_item	2681623	et	3	main
ei	doc_532115409099_item	2681625	et	4	main
reformi	doc_532115409099_item	2681629	et	4	main
nii	doc_532115409099_item	2681630	et	3	main
kiiresti	doc_532115409099_item	2681631	et	3	main
ikka	doc_532115409099_item	2681636	et	4	main
tulevad	doc_532115409099_item	2681647	et	4	main
eesti	doc_532115409099_item	2681652	et	4	main
lihtsam	doc_532115409099_item	2681666	et	4	main
pärast	doc_532115409099_item	2681667	et	4	main
inimene	doc_532115409099_item	2681679	et	3	main
mis	doc_532115409099_item	2681683	et	4	main
aga	doc_532115409099_item	2681700	et	3	main
ka	doc_532115409099_item	2681702	et	3	main
keeles	doc_532115409100_item	2681721	et	4	main
on	doc_532115409100_item	2681723	et	4	main
väga	doc_532115409100_item	2681724	et	3	main
probleemidest	doc_532115409100_item	2681745	et	3	main
temmatikaga	doc_532115409100_item	2681750	et	4	main
mitte	doc_532115409100_item	2681756	et	3	main
piisav	doc_532115409100_item	2681769	et	4	main
aga	doc_532115409100_item	2681770	et	3	main
õppematerjalide	doc_532115409100_item	2681791	et	3	main
häid	doc_532115409100_item	2681803	et	3	main
õpetajaid	doc_532115409100_item	2681805	et	4	main
ei	doc_532115409100_item	2681813	et	4	main
aastaks	doc_532115409100_item	2681816	et	4	main
palju	doc_532115409100_item	2681818	et	4	main
trükkida	doc_532115409100_item	2681820	et	3	main
ja	doc_532115409100_item	2681821	et	3	main
nõuab	doc_532115409100_item	2681823	et	3	main
keeles	doc_532115409100_item	2681839	et	4	main
õpetada	doc_532115409100_item	2681840	et	3	main
jäänud	doc_532115409100_item	2681848	et	4	main
päris	doc_532115409100_item	2681849	et	4	main
et	doc_532115409098_item	2681393	et	3	main
oma	doc_532115409098_item	2681398	et	4	main
me	doc_532115409098_item	2681404	et	4	main
et	doc_532115409098_item	2681406	et	3	main
inglise	doc_532115409098_item	2681408	et	4	main
ja	doc_532115409098_item	2681412	et	3	main
inimesd	doc_532115409098_item	2681443	et	4	main
ei	doc_532115409098_item	2681461	et	4	main
on	doc_532115409098_item	2681472	et	4	main
lihtsalt	doc_532115409098_item	2681473	et	4	main
siis	doc_532115409098_item	2681484	et	3	main
vaja	doc_532115409098_item	2681493	et	4	main
proovida	doc_532115409098_item	2681498	et	3	main
ei	doc_532115409098_item	2681499	et	4	main
vene	doc_532115409099_item	2681505	et	4	main
eestis	doc_532115409099_item	2681513	et	3	main
arvan	doc_532115409099_item	2681521	et	3	main
võime	doc_532115409099_item	2681524	et	4	main
õppida	doc_532115409099_item	2681525	et	3	main
venelased	doc_532115409099_item	2681533	et	3	main
keelt	doc_532115409099_item	2681541	et	4	main
seetõttu	doc_532115409099_item	2681542	et	3	main
ma	doc_532115409099_item	2681543	et	3	main
vene	doc_532115409099_item	2681546	et	4	main
koolides	doc_532115409099_item	2681547	et	3	main
eesti	doc_532115409099_item	2681548	et	4	main
õppisekeel	doc_532115409099_item	2681553	et	4	main
aga	doc_532115409099_item	2681560	et	3	main
on	doc_532115409099_item	2681564	et	4	main
bioloogia	doc_532115409099_item	2681585	et	4	main
kõik	doc_532115409099_item	2681644	et	4	main
keeles	doc_532115409099_item	2681662	et	4	main
õppima	doc_532115409099_item	2681663	et	3	main
demokraatlikus	doc_532115409099_item	2681676	et	4	main
valida	doc_532115409099_item	2681682	et	3	main
alati	doc_532115409099_item	2681692	et	4	main
eestis	doc_532115409099_item	2681693	et	3	main
elada	doc_532115409099_item	2681694	et	3	main
on	doc_532115409099_item	2681695	et	4	main
õppida	doc_532115409099_item	2681699	et	3	main
kes	doc_532115409099_item	2681704	et	4	main
pärast	doc_532115409099_item	2681706	et	4	main
koolide	doc_532115409100_item	2681728	et	3	main
eestikeelsele	doc_532115409100_item	2681731	et	3	main
seadus	doc_532115409100_item	2681733	et	4	main
minna	doc_532115409100_item	2681736	et	3	main
juba	doc_532115409100_item	2681737	et	3	main
selles	doc_532115409100_item	2681740	et	4	main
kirjandis	doc_532115409100_item	2681741	et	3	main
põhilistest	doc_532115409100_item	2681744	et	3	main
selles	doc_532115409100_item	2681754	et	4	main
on	doc_532115409100_item	2681781	et	4	main
järgmised	doc_532115409100_item	2681782	et	3	main
koolis	doc_532115409100_item	2681790	et	4	main
paha	doc_532115409100_item	2681797	et	4	main
eestikeelsele	doc_532115409100_item	2681800	et	3	main
nõuab	doc_532115409100_item	2681802	et	3	main
märkida	doc_532115409100_item	2681811	et	4	main
see	doc_532115409100_item	2681822	et	3	main
ka	doc_532115409100_item	2681824	et	3	main
peaaegu	doc_532115409100_item	2681828	et	3	main
ei	doc_532115409100_item	2681831	et	4	main
oma	doc_532115409100_item	2681836	et	4	main
ainet	doc_532115409100_item	2681837	et	3	main
eesti	doc_532115409100_item	2681838	et	4	main
on	doc_532115409100_item	2681847	et	4	main
kui	doc_532115409100_item	2681853	et	3	main
üks	doc_532115409100_item	2681854	et	3	main
aasta	doc_532115409100_item	2681855	et	4	main
rahvale	doc_532115409100_item	2681859	et	3	main
seda	doc_532115409100_item	2681862	et	3	main
vaja	doc_532115409100_item	2681864	et	4	main
või	doc_532115409100_item	2681866	et	4	main
raadios	doc_532115409100_item	2681867	et	3	main
peaks	doc_532115409100_item	2681868	et	4	main
esinema	doc_532115409100_item	2681869	et	3	main
haridusminister	doc_532115409100_item	2681870	et	3	main
et	doc_532115409100_item	2681871	et	3	main
võetud	doc_532115409100_item	2681879	et	4	main
rahvas	doc_532115409100_item	2681883	et	4	main
demonstratsiooniga	doc_532115409100_item	2681897	et	4	main
kui	doc_532115409100_item	2681901	et	3	main
olla	doc_532115409098_item	2681431	et	3	main
mõned	doc_532115409098_item	2681433	et	3	main
kasvatus	doc_532115409098_item	2681439	et	4	main
teada	doc_532115409098_item	2681445	et	3	main
parem	doc_532115409098_item	2681447	et	4	main
eesti	doc_532115409098_item	2681448	et	4	main
keelt	doc_532115409098_item	2681449	et	4	main
kui	doc_532115409098_item	2681450	et	3	main
ja	doc_532115409098_item	2681460	et	3	main
siis	doc_532115409098_item	2681464	et	3	main
on	doc_532115409098_item	2681465	et	4	main
solvunud	doc_532115409098_item	2681474	et	4	main
ja	doc_532115409098_item	2681481	et	3	main
ta	doc_532115409098_item	2681485	et	4	main
õppida	doc_532115409098_item	2681494	et	3	main
probleemi	doc_532115409098_item	2681503	et	4	main
esienesse	doc_532115409098_item	2681504	et	4	main
kes	doc_532115409099_item	2681511	et	4	main
peame	doc_532115409099_item	2681515	et	4	main
ja	doc_532115409098_item	2681475	et	3	main
oli	doc_532115409098_item	2681478	et	3	main
okupatsioon	doc_532115409098_item	2681480	et	3	main
tahab	doc_532115409098_item	2681482	et	3	main
teeb	doc_532115409098_item	2681486	et	3	main
ja	doc_532115409098_item	2681497	et	3	main
kool	doc_532115409099_item	2681506	et	4	main
venelased	doc_532115409099_item	2681510	et	3	main
eesti	doc_532115409099_item	2681529	et	4	main
40	doc_532115409099_item	2681530	et	2	main
inimestest	doc_532115409099_item	2681531	et	3	main
eesti	doc_532115409099_item	2681540	et	4	main
ei	doc_532115409099_item	2681550	et	4	main
näiteks	doc_532115409099_item	2681554	et	4	main
õpib	doc_532115409099_item	2681556	et	3	main
11	doc_532115409099_item	2681558	et	2	main
tal	doc_532115409099_item	2681563	et	3	main
kui	doc_532115409099_item	2681568	et	3	main
keeles	doc_532115409099_item	2681575	et	4	main
kogu	doc_532115409099_item	2681586	et	4	main
aeg	doc_532115409099_item	2681587	et	3	main
terminoloogia	doc_532115409099_item	2681588	et	4	main
ma	doc_532115409099_item	2681621	et	3	main
see	doc_532115409099_item	2681624	et	3	main
olgu	doc_532115409099_item	2681633	et	3	main
nad	doc_532115409099_item	2681635	et	3	main
tahavad	doc_532115409099_item	2681637	et	3	main
seda	doc_532115409099_item	2681638	et	3	main
teha	doc_532115409099_item	2681639	et	3	main
lapsed	doc_532115409099_item	2681645	et	3	main
siis	doc_532115409099_item	2681664	et	3	main
on	doc_532115409099_item	2681668	et	4	main
lõpetuseks	doc_532115409099_item	2681669	et	4	main
riigis	doc_532115409099_item	2681677	et	3	main
võib	doc_532115409099_item	2681680	et	3	main
keeles	doc_532115409099_item	2681684	et	4	main
ta	doc_532115409099_item	2681685	et	4	main
tahab	doc_532115409099_item	2681686	et	3	main
õppida	doc_532115409099_item	2681687	et	3	main
kindlasti	doc_532115409099_item	2681688	et	3	main
neil	doc_532115409099_item	2681689	et	4	main
parem	doc_532115409099_item	2681696	et	4	main
eesti	doc_532115409099_item	2681697	et	4	main
on	doc_532115409099_item	2681701	et	4	main
lapsed	doc_532115409099_item	2681703	et	3	main
vigadel	doc_532115409098_item	2681496	et	3	main
palju	doc_532115409098_item	2681502	et	4	main
keeles	doc_532115409099_item	2681508	et	4	main
kindlasti	doc_532115409099_item	2681514	et	3	main
eesti	doc_532115409099_item	2681516	et	4	main
keelt	doc_532115409099_item	2681517	et	4	main
õppima	doc_532115409099_item	2681518	et	3	main
aga	doc_532115409099_item	2681519	et	3	main
ma	doc_532115409099_item	2681520	et	3	main
me	doc_532115409099_item	2681523	et	4	main
oma	doc_532115409099_item	2681526	et	4	main
keeles	doc_532115409099_item	2681527	et	4	main
praegu	doc_532115409099_item	2681528	et	3	main
tea	doc_532115409099_item	2681539	et	4	main
keel	doc_532115409099_item	2681549	et	4	main
kedagi	doc_532115409099_item	2681555	et	4	main
praegu	doc_532115409099_item	2681557	et	3	main
viimane	doc_532115409099_item	2681565	et	3	main
ja	doc_532115409099_item	2681567	et	3	main
teha	doc_532115409099_item	2681576	et	3	main
ole	doc_532115409099_item	2681626	et	4	main
hea	doc_532115409099_item	2681627	et	4	main
seda	doc_532115409099_item	2681628	et	3	main
võivad	doc_532115409099_item	2681640	et	4	main
kes	doc_532115409099_item	2681646	et	4	main
klassis	doc_532115409099_item	2681649	et	3	main
juba	doc_532115409099_item	2681651	et	3	main
keeles	doc_532115409099_item	2681653	et	4	main
õppima	doc_532115409099_item	2681654	et	3	main
sest	doc_532115409099_item	2681655	et	4	main
kui	doc_532115409099_item	2681656	et	3	main
sa	doc_532115409099_item	2681657	et	3	main
hakkad	doc_532115409099_item	2681658	et	3	main
esimesest	doc_532115409099_item	2681659	et	3	main
klassist	doc_532115409099_item	2681660	et	3	main
palju	doc_532115409099_item	2681665	et	4	main
me	doc_532115409099_item	2681674	et	4	main
elame	doc_532115409099_item	2681675	et	3	main
iga	doc_532115409099_item	2681678	et	4	main
kes	doc_532115409099_item	2681690	et	4	main
tahavad	doc_532115409099_item	2681691	et	3	main
üle	doc_532115409100_item	2681729	et	3	main
minek	doc_532115409100_item	2681730	et	3	main
kohustab	doc_532115409100_item	2681734	et	3	main
2007	doc_532115409100_item	2681738	et	2	main
mis	doc_532115409100_item	2681746	et	4	main
seotud	doc_532115409100_item	2681748	et	4	main
seisneb	doc_532115409100_item	2681753	et	3	main
on	doc_532115409100_item	2681773	et	4	main
nendest	doc_532115409100_item	2681778	et	4	main
kõige	doc_532115409100_item	2681779	et	4	main
olulisemad	doc_532115409100_item	2681780	et	4	main
tahtmist	doc_532115409100_item	2681785	et	4	main
näiteks	doc_532115409100_item	2681793	et	4	main
magnetofoni	doc_532115409100_item	2681796	et	4	main
m	doc_532115409100_item	2681808	et	4	main
võime	doc_532115409100_item	2681809	et	4	main
ka	doc_532115409100_item	2681810	et	3	main
2007	doc_532115409100_item	2681815	et	2	main
õppematerjale	doc_532115409100_item	2681819	et	3	main
on	doc_532115409099_item	2681532	et	4	main
mõned	doc_532115409099_item	2681535	et	3	main
et	doc_532115409099_item	2681545	et	3	main
olema	doc_532115409099_item	2681552	et	4	main
klassis	doc_532115409099_item	2681559	et	3	main
aastal	doc_532115409099_item	2681562	et	3	main
õppeaasta	doc_532115409099_item	2681566	et	4	main
reform	doc_532115409099_item	2681569	et	3	main
jõustub	doc_532115409099_item	2681570	et	3	main
peab	doc_532115409099_item	2681571	et	4	main
ta	doc_532115409099_item	2681572	et	4	main
koolieksamid	doc_532115409099_item	2681573	et	3	main
kindlasti	doc_532115409099_item	2681577	et	3	main
ei	doc_532115409099_item	2681579	et	4	main
saa	doc_532115409099_item	2681580	et	4	main
häid	doc_532115409099_item	2681581	et	3	main
hindeid	doc_532115409099_item	2681582	et	3	main
võtame	doc_532115409099_item	2681583	et	3	main
näiteks	doc_532115409099_item	2681584	et	4	main
keeles	doc_532115409099_item	2681591	et	4	main
aga	doc_532115409099_item	2681592	et	3	main
eksam	doc_532115409099_item	2681593	et	3	main
on	doc_532115409099_item	2681594	et	4	main
eesti	doc_532115409099_item	2681595	et	4	main
keeles	doc_532115409099_item	2681596	et	4	main
mõelge	doc_532115409099_item	2681597	et	3	main
ise	doc_532115409099_item	2681598	et	4	main
mis	doc_532115409099_item	2681599	et	4	main
tuleb	doc_532115409099_item	2681600	et	3	main
välja	doc_532115409099_item	2681601	et	4	main
see	doc_532115409099_item	2681602	et	3	main
on	doc_532115409099_item	2681603	et	4	main
sama	doc_532115409099_item	2681604	et	4	main
moodi	doc_532115409099_item	2681605	et	4	main
nagu	doc_532115409099_item	2681606	et	3	main
eestlane	doc_532115409099_item	2681607	et	3	main
kes	doc_532115409099_item	2681608	et	4	main
on	doc_532115409099_item	2681609	et	4	main
kogu	doc_532115409099_item	2681610	et	4	main
aeg	doc_532115409099_item	2681611	et	3	main
eesti	doc_532115409099_item	2681612	et	4	main
keeles	doc_532115409099_item	2681613	et	4	main
õppinud	doc_532115409099_item	2681614	et	4	main
peaks	doc_532115409099_item	2681615	et	4	main
viimane	doc_532115409099_item	2681616	et	3	main
kooliaasta	doc_532115409099_item	2681617	et	4	main
vene	doc_532115409099_item	2681618	et	4	main
keeles	doc_532115409099_item	2681619	et	4	main
õppima	doc_532115409099_item	2681620	et	3	main
arvan	doc_532115409099_item	2681622	et	3	main
teha	doc_532115409099_item	2681632	et	3	main
kui	doc_532115409099_item	2681634	et	3	main
öelda	doc_532115409099_item	2681641	et	4	main
nii	doc_532115409099_item	2681642	et	3	main
et	doc_532115409099_item	2681643	et	3	main
esimesel	doc_532115409099_item	2681648	et	3	main
peavad	doc_532115409099_item	2681650	et	4	main
eesti	doc_532115409099_item	2681661	et	4	main
tahan	doc_532115409099_item	2681670	et	3	main
öelda	doc_532115409099_item	2681671	et	4	main
et	doc_532115409099_item	2681672	et	3	main
kuna	doc_532115409099_item	2681673	et	3	main
ise	doc_532115409099_item	2681681	et	4	main
keeles	doc_532115409099_item	2681698	et	4	main
tahavad	doc_532115409099_item	2681705	et	3	main
kooli	doc_532115409099_item	2681707	et	4	main
venemaal	doc_532115409099_item	2681708	et	4	main
minna	doc_532115409099_item	2681709	et	3	main
võib	doc_532115409099_item	2681710	et	3	main
olla	doc_532115409099_item	2681711	et	3	main
neile	doc_532115409099_item	2681712	et	4	main
on	doc_532115409099_item	2681713	et	4	main
vaja	doc_532115409099_item	2681714	et	4	main
ka	doc_532115409099_item	2681715	et	3	main
võimalust	doc_532115409099_item	2681716	et	3	main
anda	doc_532115409099_item	2681717	et	3	main
vene	doc_532115409100_item	2681718	et	4	main
kool	doc_532115409100_item	2681719	et	4	main
eesti	doc_532115409100_item	2681720	et	4	main
täna	doc_532115409100_item	2681722	et	4	main
aktuaalne	doc_532115409100_item	2681725	et	3	main
teema	doc_532115409100_item	2681726	et	4	main
kirjutan	doc_532115409100_item	2681743	et	3	main
esimene	doc_532115409100_item	2681751	et	3	main
raskus	doc_532115409100_item	2681752	et	4	main
et	doc_532115409100_item	2681755	et	3	main
koik	doc_532115409100_item	2681757	et	4	main
siin	doc_532115409100_item	2681772	et	4	main
erinevaid	doc_532115409100_item	2681775	et	4	main
ja	doc_532115409100_item	2681777	et	3	main
keelt	doc_532115409100_item	2681786	et	4	main
õppida	doc_532115409100_item	2681787	et	3	main
nõrgad	doc_532115409100_item	2681788	et	3	main
õpetajad	doc_532115409100_item	2681789	et	4	main
puudus	doc_532115409100_item	2681792	et	4	main
keeleklassis	doc_532115409100_item	2681794	et	3	main
üleminek	doc_532115409100_item	2681799	et	3	main
õppematerjale	doc_532115409100_item	2681804	et	3	main
tebeleid	doc_532115409100_item	2681806	et	4	main
nii	doc_532115409100_item	2681817	et	3	main
palju	doc_532115409100_item	2681825	et	4	main
olen	doc_532115409100_item	2681827	et	3	main
et	doc_532115409100_item	2681830	et	3	main
piisa	doc_532115409100_item	2681832	et	4	main
tõsine	doc_532115409100_item	2681845	et	4	main
probleem	doc_532115409100_item	2681846	et	3	main
vähem	doc_532115409100_item	2681852	et	4	main
televiisoris	doc_532115409100_item	2681865	et	3	main
oli	doc_532115409100_item	2681878	et	3	main
lätis	doc_532115409100_item	2681892	et	4	main
jm	doc_532115409100_item	2681912	et	4	main
aastal	doc_532115409100_item	2681916	et	3	main
eestikeelsele	doc_532115409100_item	2681919	et	3	main
mida	doc_532115409100_item	2681921	et	4	main
annaks	doc_532115409100_item	2681923	et	4	main
head	doc_532115409100_item	2681924	et	4	main
toob	doc_532115409100_item	2681930	et	3	main
vene	doc_532115409100_item	2681727	et	4	main
õppele	doc_532115409100_item	2681732	et	3	main
üle	doc_532115409100_item	2681735	et	3	main
aastal	doc_532115409100_item	2681739	et	3	main
ma	doc_532115409100_item	2681742	et	3	main
on	doc_532115409100_item	2681747	et	4	main
selle	doc_532115409100_item	2681749	et	4	main
pole	doc_532115409100_item	2681758	et	3	main
valmis	doc_532115409100_item	2681759	et	4	main
eestikeelsele	doc_532115409100_item	2681760	et	3	main
õppele	doc_532115409100_item	2681761	et	3	main
üle	doc_532115409100_item	2681762	et	3	main
minna	doc_532115409100_item	2681763	et	3	main
sest	doc_532115409100_item	2681764	et	4	main
nende	doc_532115409100_item	2681765	et	4	main
keele	doc_532115409100_item	2681766	et	4	main
oskus	doc_532115409100_item	2681767	et	3	main
pole	doc_532115409100_item	2681768	et	3	main
miks	doc_532115409100_item	2681771	et	4	main
palju	doc_532115409100_item	2681774	et	4	main
põhjusi	doc_532115409100_item	2681776	et	3	main
õpilastel	doc_532115409100_item	2681783	et	4	main
pole	doc_532115409100_item	2681784	et	3	main
pole	doc_532115409100_item	2681795	et	3	main
õppemetoodika	doc_532115409100_item	2681798	et	4	main
õppele	doc_532115409100_item	2681801	et	3	main
j	doc_532115409100_item	2681807	et	4	main
et	doc_532115409100_item	2681812	et	3	main
jõuta	doc_532115409100_item	2681814	et	4	main
raha	doc_532115409100_item	2681826	et	4	main
kindel	doc_532115409100_item	2681829	et	3	main
võiksid	doc_532115409100_item	2681835	et	4	main
päris	doc_532115409100_item	2681844	et	4	main
veel	doc_532115409100_item	2681858	et	4	main
täpselt	doc_532115409100_item	2681872	et	4	main
vastu	doc_532115409100_item	2681880	et	3	main
võib-olla	doc_532115409100_item	2681882	et	3	main
aru	doc_532115409100_item	2681886	et	4	main
reformatsioon	doc_532115409100_item	2681895	et	3	main
väga	doc_532115409100_item	2681899	et	3	main
eestis	doc_532115409100_item	2681902	et	3	main
asi	doc_532115409100_item	2681904	et	4	main
juhtuks	doc_532115409100_item	2681905	et	4	main
kui	doc_532115409100_item	2681906	et	3	main
õppematerjale	doc_532115409100_item	2681910	et	3	main
minna	doc_532115409100_item	2681918	et	3	main
resultaadi	doc_532115409100_item	2681925	et	3	main
kiirustamine	doc_532115409100_item	2681926	et	4	main
ja	doc_532115409100_item	2681933	et	3	main
vene	doc_532115409101_item	2681935	et	4	main
õpivad	doc_532115409101_item	2681946	et	3	main
mina	doc_532115409101_item	2681950	et	4	main
ei	doc_532115409101_item	2681953	et	4	main
kõik	doc_532115409101_item	2681958	et	4	main
kõik	doc_532115409101_item	2681965	et	4	main
õppetöö	doc_532115409101_item	2681966	et	4	main
on	doc_532115409101_item	2681979	et	4	main
11	doc_532115409101_item	2681980	et	2	main
klassis	doc_532115409101_item	2681981	et	3	main
ja	doc_532115409101_item	2681982	et	3	main
keeles	doc_532115409101_item	2681987	et	4	main
õpetajaid	doc_532115409100_item	2681833	et	4	main
kes	doc_532115409100_item	2681834	et	4	main
ja	doc_532115409100_item	2681841	et	3	main
see	doc_532115409100_item	2681842	et	3	main
on	doc_532115409100_item	2681843	et	4	main
keegi	doc_532115409100_item	2681856	et	4	main
pole	doc_532115409100_item	2681857	et	3	main
miks	doc_532115409100_item	2681861	et	4	main
selgitada	doc_532115409100_item	2681873	et	3	main
rahvale	doc_532115409100_item	2681874	et	3	main
miks	doc_532115409100_item	2681875	et	4	main
see	doc_532115409100_item	2681876	et	3	main
otsus	doc_532115409100_item	2681877	et	3	main
saaks	doc_532115409100_item	2681884	et	3	main
sama	doc_532115409100_item	2681893	et	4	main
keele	doc_532115409100_item	2681894	et	4	main
oleks	doc_532115409100_item	2681898	et	3	main
sama	doc_532115409100_item	2681903	et	4	main
kõik	doc_532115409100_item	2681909	et	4	main
võiksime	doc_532115409100_item	2681914	et	3	main
mõistlik	doc_532115409100_item	2681928	et	3	main
vigu	doc_532115409100_item	2681932	et	3	main
keeles	doc_532115409101_item	2681938	et	4	main
räägivad	doc_532115409101_item	2681939	et	3	main
et	doc_532115409101_item	2681940	et	3	main
2007	doc_532115409101_item	2681941	et	2	main
aastal	doc_532115409101_item	2681942	et	3	main
saa	doc_532115409101_item	2681954	et	4	main
toimub	doc_532115409101_item	2681959	et	3	main
õppis	doc_532115409101_item	2681974	et	3	main
isegi	doc_532115409101_item	2682022	et	4	main
need	doc_532115409101_item	2682028	et	3	main
tädid	doc_532115409101_item	2682030	et	3	main
tahavad	doc_532115409101_item	2682032	et	3	main
päev	doc_532115409101_item	2682040	et	3	main
vene	doc_532115409101_item	2682043	et	4	main
olla	doc_532115409101_item	2682053	et	3	main
ja	doc_532115409101_item	2682077	et	3	main
rahulik	doc_532115409101_item	2682078	et	3	main
elu	doc_532115409101_item	2682079	et	4	main
ja	doc_532115409101_item	2682080	et	3	main
kuskil	doc_532115409101_item	2682081	et	3	main
augusti	doc_532115409101_item	2682082	et	3	main
keskel	doc_532115409101_item	2682083	et	3	main
ütlevad	doc_532115409101_item	2682086	et	4	main
läheb	doc_532115409101_item	2682091	et	3	main
piinlik	doc_532115409101_item	2682106	et	3	main
kujutage	doc_532115409101_item	2682108	et	3	main
masendus	doc_532115409101_item	2682112	et	4	main
keeles	doc_532115409101_item	2682128	et	4	main
kõik	doc_532115409101_item	2682139	et	4	main
õpetajad	doc_532115409101_item	2682144	et	4	main
nüüd	doc_532115409101_item	2682156	et	4	main
kujutame	doc_532115409101_item	2682157	et	3	main
8	doc_532115409101_item	2682163	et	2	main
ei	doc_532115409101_item	2682166	et	4	main
vanemad	doc_532115409101_item	2682173	et	4	main
just	doc_532115409101_item	2682175	et	3	main
keeles	doc_532115409101_item	2682206	et	4	main
aga	doc_532115409101_item	2682207	et	3	main
eesti	doc_532115409101_item	2682208	et	4	main
minu	doc_532115409101_item	2682213	et	3	main
see	doc_532115409101_item	2682215	et	3	main
suur	doc_532115409101_item	2682219	et	3	main
vähe	doc_532115409100_item	2681850	et	3	main
aega	doc_532115409100_item	2681851	et	4	main
selgitanud	doc_532115409100_item	2681860	et	4	main
on	doc_532115409100_item	2681863	et	4	main
siis	doc_532115409100_item	2681881	et	3	main
põhjusest	doc_532115409100_item	2681885	et	4	main
ega	doc_532115409100_item	2681887	et	3	main
protesteeriks	doc_532115409100_item	2681888	et	3	main
nagu	doc_532115409100_item	2681889	et	3	main
me	doc_532115409100_item	2681890	et	4	main
mäletame	doc_532115409100_item	2681891	et	3	main
lõpetas	doc_532115409100_item	2681896	et	3	main
kahju	doc_532115409100_item	2681900	et	4	main
jõutakse	doc_532115409100_item	2681907	et	4	main
üle	doc_532115409100_item	2681917	et	3	main
ettevalmistada	doc_532115409100_item	2681908	et	4	main
õpetajaid	doc_532115409100_item	2681911	et	4	main
siis	doc_532115409100_item	2681913	et	3	main
2007	doc_532115409100_item	2681915	et	2	main
õppele	doc_532115409100_item	2681920	et	3	main
tõenäoliselt	doc_532115409100_item	2681922	et	4	main
ja	doc_532115409100_item	2681929	et	3	main
ebaõnnestumisi	doc_532115409100_item	2681934	et	3	main
vene	doc_532115409101_item	2681944	et	4	main
koolid	doc_532115409101_item	2681945	et	3	main
aga	doc_532115409101_item	2681949	et	3	main
veel	doc_532115409101_item	2681951	et	4	main
ikka	doc_532115409101_item	2681952	et	4	main
kas	doc_532115409101_item	2681960	et	3	main
1st	doc_532115409101_item	2681962	et	3	main
on	doc_532115409101_item	2681964	et	4	main
terve	doc_532115409101_item	2681972	et	4	main
keeles	doc_532115409101_item	2681976	et	4	main
nüüd	doc_532115409101_item	2681977	et	4	main
ta	doc_532115409101_item	2681978	et	4	main
eesti	doc_532115409101_item	2681986	et	4	main
ei	doc_532115409101_item	2682023	et	4	main
saanud	doc_532115409101_item	2682024	et	4	main
minust	doc_532115409101_item	2682031	et	3	main
ja	doc_532115409101_item	2682036	et	3	main
ma	doc_532115409101_item	2682041	et	3	main
tulin	doc_532115409101_item	2682042	et	3	main
ja	doc_532115409101_item	2682045	et	3	main
jäin	doc_532115409101_item	2682047	et	3	main
vait	doc_532115409101_item	2682048	et	3	main
oli	doc_532115409101_item	2682050	et	3	main
päris	doc_532115409101_item	2682051	et	4	main
ma	doc_532115409101_item	2682056	et	3	main
seda	doc_532115409101_item	2682057	et	3	main
mõelge	doc_532115409101_item	2682059	et	3	main
tema	doc_532115409101_item	2682084	et	4	main
on	doc_532115409101_item	2682098	et	4	main
stress	doc_532115409101_item	2682099	et	3	main
ta	doc_532115409101_item	2682100	et	4	main
kardab	doc_532115409101_item	2682101	et	4	main
muretseb	doc_532115409101_item	2682102	et	3	main
ja	doc_532115409101_item	2682103	et	3	main
kui	doc_532115409101_item	2682110	et	3	main
saa	doc_532115409101_item	2682121	et	4	main
aru	doc_532115409101_item	2682123	et	4	main
ta	doc_532115409101_item	2682125	et	4	main
klassis	doc_532115409101_item	2682133	et	3	main
on	doc_532115409101_item	2682134	et	4	main
kuskil	doc_532115409101_item	2682135	et	3	main
küll	doc_532115409101_item	2682142	et	4	main
kõik	doc_532115409101_item	2682143	et	4	main
piisavalt	doc_532115409101_item	2682146	et	4	main
et	doc_532115409101_item	2682148	et	3	main
vene	doc_532115409101_item	2682159	et	4	main
eesti	doc_532115409101_item	2682205	et	4	main
nõrk	doc_532115409101_item	2682212	et	3	main
ei	doc_532115409101_item	2682222	et	4	main
selline	doc_532115409101_item	2682242	et	4	main
mõte	doc_532115409101_item	2682243	et	3	main
hea	doc_532115409101_item	2682244	et	4	main
see	doc_532115409101_item	2682245	et	3	main
kohe	doc_532115409101_item	2682250	et	4	main
on	doc_532115409101_item	2682256	et	4	main
et	doc_532115409101_item	2682259	et	3	main
algus	doc_532115409101_item	2682267	et	4	main
on	doc_532115409101_item	2682271	et	4	main
alustada	doc_532115409101_item	2682273	et	3	main
ei	doc_532115409101_item	2682281	et	4	main
alguseks	doc_532115409101_item	2682287	et	4	main
keele	doc_532115409101_item	2682291	et	4	main
keeles	doc_532115409102_item	2682301	et	4	main
tänapäeval	doc_532115409102_item	2682302	et	3	main
planeeritakse	doc_532115409102_item	2682308	et	3	main
vene	doc_532115409102_item	2682310	et	4	main
lihtsalt	doc_532115409102_item	2682319	et	4	main
vene	doc_532115409102_item	2682320	et	4	main
eesti	doc_532115409102_item	2682340	et	4	main
päris	doc_532115409102_item	2682354	et	4	main
eesti	doc_532115409102_item	2682368	et	4	main
lasteaias	doc_532115409102_item	2682369	et	4	main
kui	doc_532115409102_item	2682377	et	3	main
laps	doc_532115409102_item	2682389	et	4	main
pole	doc_532115409100_item	2681927	et	3	main
kaasa	doc_532115409100_item	2681931	et	4	main
kõik	doc_532115409101_item	2681943	et	4	main
keeles	doc_532115409101_item	2681948	et	4	main
kuidas	doc_532115409101_item	2681956	et	3	main
või	doc_532115409101_item	2681969	et	4	main
kui	doc_532115409101_item	2681970	et	3	main
inimene	doc_532115409101_item	2681971	et	3	main
vene	doc_532115409101_item	2681975	et	4	main
õpima	doc_532115409101_item	2681988	et	4	main
see	doc_532115409101_item	2681989	et	3	main
on	doc_532115409101_item	2681990	et	4	main
minu	doc_532115409101_item	2681991	et	3	main
arust	doc_532115409101_item	2681992	et	4	main
üsna	doc_532115409101_item	2681993	et	3	main
raske	doc_532115409101_item	2681994	et	4	main
kui	doc_532115409101_item	2681995	et	3	main
mina	doc_532115409101_item	2681996	et	4	main
olin	doc_532115409101_item	2681997	et	3	main
väike	doc_532115409101_item	2681998	et	4	main
mu	doc_532115409101_item	2681999	et	3	main
emale	doc_532115409101_item	2682000	et	3	main
tuli	doc_532115409101_item	2682001	et	4	main
pähe	doc_532115409101_item	2682002	et	4	main
et	doc_532115409101_item	2682003	et	3	main
ma	doc_532115409101_item	2682004	et	3	main
võiksin	doc_532115409101_item	2682005	et	3	main
eesti	doc_532115409101_item	2682006	et	4	main
lasteaeda	doc_532115409101_item	2682007	et	4	main
käia	doc_532115409101_item	2682008	et	4	main
mind	doc_532115409101_item	2682009	et	4	main
toodi	doc_532115409101_item	2682010	et	4	main
kohe	doc_532115409101_item	2682011	et	4	main
sinna	doc_532115409101_item	2682012	et	3	main
ma	doc_532115409101_item	2682013	et	3	main
olin	doc_532115409101_item	2682014	et	3	main
shokkis	doc_532115409101_item	2682015	et	4	main
ma	doc_532115409101_item	2682016	et	3	main
ei	doc_532115409101_item	2682017	et	4	main
saanud	doc_532115409101_item	2682018	et	4	main
inimessest	doc_532115409101_item	2682019	et	3	main
aru	doc_532115409101_item	2682020	et	4	main
aru	doc_532115409101_item	2682025	et	4	main
kartsin	doc_532115409101_item	2682035	et	3	main
nutsin	doc_532115409101_item	2682037	et	4	main
miks	doc_532115409101_item	2682055	et	4	main
hea	doc_532115409101_item	2682076	et	4	main
talle	doc_532115409101_item	2682087	et	4	main
varsti	doc_532115409101_item	2682089	et	3	main
kooli	doc_532115409101_item	2682092	et	4	main
kool	doc_532115409101_item	2681936	et	4	main
eesti	doc_532115409101_item	2681937	et	4	main
eesti	doc_532115409101_item	2681947	et	4	main
aru	doc_532115409101_item	2681955	et	4	main
see	doc_532115409101_item	2681957	et	3	main
ainult	doc_532115409101_item	2681961	et	4	main
klassist	doc_532115409101_item	2681963	et	3	main
eesti	doc_532115409101_item	2681967	et	4	main
keeles	doc_532115409101_item	2681968	et	4	main
elu	doc_532115409101_item	2681973	et	4	main
järsku	doc_532115409101_item	2681983	et	4	main
peab	doc_532115409101_item	2681984	et	4	main
ta	doc_532115409101_item	2681985	et	4	main
kõik	doc_532115409101_item	2682027	et	4	main
ma	doc_532115409101_item	2682033	et	3	main
järgmine	doc_532115409101_item	2682039	et	3	main
hea	doc_532115409101_item	2682052	et	4	main
aastat	doc_532115409101_item	2682072	et	3	main
vana	doc_532115409101_item	2682073	et	4	main
tal	doc_532115409101_item	2682074	et	3	main
on	doc_532115409101_item	2682075	et	4	main
vanemad	doc_532115409101_item	2682085	et	4	main
et	doc_532115409101_item	2682088	et	3	main
ta	doc_532115409101_item	2682090	et	4	main
on	doc_532115409101_item	2682105	et	4	main
veel	doc_532115409101_item	2682119	et	4	main
ei	doc_532115409101_item	2682120	et	4	main
ma	doc_532115409101_item	2682021	et	3	main
mida	doc_532115409101_item	2682026	et	4	main
suured	doc_532115409101_item	2682029	et	3	main
väga	doc_532115409101_item	2682034	et	3	main
koguaeg	doc_532115409101_item	2682038	et	3	main
lasteaeda	doc_532115409101_item	2682044	et	4	main
kohe	doc_532115409101_item	2682046	et	4	main
mul	doc_532115409101_item	2682049	et	3	main
seal	doc_532115409101_item	2682054	et	4	main
rääkisin	doc_532115409101_item	2682058	et	3	main
nüüd	doc_532115409101_item	2682060	et	4	main
et	doc_532115409101_item	2682061	et	3	main
elab	doc_532115409101_item	2682062	et	3	main
mingi	doc_532115409101_item	2682063	et	4	main
väike	doc_532115409101_item	2682064	et	4	main
ja	doc_532115409101_item	2682066	et	3	main
tagasihoidlik	doc_532115409101_item	2682067	et	3	main
vaikne	doc_532115409101_item	2682065	et	3	main
tüdruk	doc_532115409101_item	2682068	et	3	main
ta	doc_532115409101_item	2682069	et	4	main
on	doc_532115409101_item	2682070	et	4	main
6	doc_532115409101_item	2682071	et	2	main
kui	doc_532115409101_item	2682093	et	3	main
laps	doc_532115409101_item	2682094	et	4	main
läheb	doc_532115409101_item	2682095	et	3	main
tal	doc_532115409101_item	2682104	et	3	main
ette	doc_532115409101_item	2682109	et	4	main
inimesest	doc_532115409101_item	2682122	et	3	main
kui	doc_532115409101_item	2682124	et	3	main
teab	doc_532115409101_item	2682126	et	3	main
eesti	doc_532115409101_item	2682127	et	4	main
30	doc_532115409101_item	2682136	et	2	main
inimesi	doc_532115409101_item	2682137	et	4	main
ja	doc_532115409101_item	2682138	et	3	main
lastele	doc_532115409101_item	2682150	et	4	main
aga	doc_532115409101_item	2682151	et	3	main
see	doc_532115409101_item	2682152	et	3	main
on	doc_532115409101_item	2682153	et	4	main
üks	doc_532115409101_item	2682154	et	3	main
olukord	doc_532115409101_item	2682155	et	3	main
ta	doc_532115409101_item	2682161	et	4	main
käib	doc_532115409101_item	2682162	et	3	main
algab	doc_532115409101_item	2682203	et	3	main
õpima	doc_532115409101_item	2682204	et	4	main
arust	doc_532115409101_item	2682214	et	4	main
on	doc_532115409101_item	2682216	et	4	main
tõesti	doc_532115409101_item	2682217	et	3	main
paljud	doc_532115409101_item	2682221	et	3	main
üldse	doc_532115409101_item	2682224	et	3	main
kaotavad	doc_532115409101_item	2682227	et	4	main
aasta	doc_532115409101_item	2682229	et	4	main
näiteks	doc_532115409101_item	2682230	et	4	main
algusest	doc_532115409101_item	2682251	et	4	main
olema	doc_532115409101_item	2682264	et	4	main
arust	doc_532115409101_item	2682269	et	4	main
rumal	doc_532115409101_item	2682272	et	3	main
õpetust	doc_532115409101_item	2682274	et	4	main
eesti	doc_532115409101_item	2682275	et	4	main
kus	doc_532115409101_item	2682278	et	3	main
üldse	doc_532115409101_item	2682280	et	3	main
keeles	doc_532115409101_item	2682284	et	4	main
riik	doc_532115409101_item	2682285	et	3	main
aidata	doc_532115409101_item	2682288	et	4	main
eesti	doc_532115409102_item	2682300	et	4	main
probleem	doc_532115409102_item	2682306	et	3	main
sulgeda	doc_532115409102_item	2682309	et	3	main
2007	doc_532115409102_item	2682312	et	2	main
ei	doc_532115409102_item	2682315	et	4	main
ole	doc_532115409102_item	2682316	et	4	main
kooli	doc_532115409101_item	2682096	et	4	main
tal	doc_532115409101_item	2682097	et	3	main
aga	doc_532115409101_item	2682107	et	3	main
suur	doc_532115409101_item	2682111	et	3	main
ja	doc_532115409101_item	2682113	et	3	main
kartus	doc_532115409101_item	2682114	et	3	main
tal	doc_532115409101_item	2682115	et	3	main
on	doc_532115409101_item	2682116	et	4	main
kui	doc_532115409101_item	2682117	et	3	main
ta	doc_532115409101_item	2682118	et	4	main
sõna	doc_532115409101_item	2682130	et	4	main
tere	doc_532115409101_item	2682131	et	3	main
aga	doc_532115409101_item	2682132	et	3	main
vaevalt	doc_532115409101_item	2682141	et	4	main
on	doc_532115409101_item	2682145	et	4	main
head	doc_532115409101_item	2682147	et	4	main
ette	doc_532115409101_item	2682158	et	4	main
klassis	doc_532115409101_item	2682164	et	3	main
vene	doc_532115409101_item	2682172	et	4	main
hakkama	doc_532115409101_item	2682225	et	3	main
aga	doc_532115409101_item	2682252	et	3	main
aga	doc_532115409101_item	2682254	et	3	main
aga	doc_532115409101_item	2682258	et	3	main
midagi	doc_532115409101_item	2682261	et	4	main
uut	doc_532115409101_item	2682262	et	3	main
peab	doc_532115409101_item	2682263	et	4	main
keeles	doc_532115409101_item	2682276	et	4	main
räägi	doc_532115409101_item	2682282	et	4	main
eesti	doc_532115409101_item	2682283	et	4	main
kõikjadele	doc_532115409101_item	2682289	et	4	main
et	doc_532115409102_item	2682307	et	3	main
sulgemine	doc_532115409102_item	2682318	et	4	main
õppima	doc_532115409102_item	2682323	et	3	main
ei	doc_532115409102_item	2682329	et	4	main
ma	doc_532115409102_item	2682333	et	3	main
olen	doc_532115409102_item	2682334	et	3	main
nõus	doc_532115409102_item	2682335	et	4	main
et	doc_532115409102_item	2682336	et	3	main
venelased	doc_532115409102_item	2682337	et	3	main
peavad	doc_532115409102_item	2682338	et	4	main
teadma	doc_532115409102_item	2682339	et	3	main
isegi	doc_532115409102_item	2682351	et	4	main
ei	doc_532115409102_item	2682352	et	4	main
käia	doc_532115409102_item	2682370	et	4	main
sellepärast	doc_532115409102_item	2682371	et	3	main
et	doc_532115409102_item	2682372	et	3	main
keelte	doc_532115409102_item	2682373	et	3	main
on	doc_532115409102_item	2682379	et	4	main
aru	doc_532115409102_item	2682392	et	4	main
mida	doc_532115409102_item	2682393	et	4	main
ta	doc_532115409102_item	2682394	et	4	main
õpib	doc_532115409102_item	2682395	et	3	main
tal	doc_532115409102_item	2682396	et	3	main
ma	doc_532115409102_item	2682401	et	3	main
miks	doc_532115409102_item	2682410	et	4	main
siis	doc_532115409102_item	2682411	et	3	main
kanadas	doc_532115409102_item	2682412	et	4	main
prantsuse	doc_532115409102_item	2682420	et	3	main
ei	doc_532115409102_item	2682425	et	4	main
pool	doc_532115409102_item	2682436	et	4	main
elanikkonnas	doc_532115409102_item	2682437	et	3	main
mitte	doc_532115409102_item	2682444	et	3	main
vist	doc_532115409102_item	2682449	et	4	main
meie	doc_532115409102_item	2682450	et	4	main
venelased	doc_532115409102_item	2682457	et	3	main
raske	doc_532115409102_item	2682460	et	4	main
ja	doc_532115409102_item	2682464	et	3	main
loomulikult	doc_532115409102_item	2682467	et	4	main
hea	doc_532115409102_item	2682477	et	4	main
kui	doc_532115409102_item	2682478	et	3	main
inimene	doc_532115409102_item	2682479	et	3	main
tänapäeval	doc_532115409102_item	2682497	et	3	main
oleksid	doc_532115409102_item	2682523	et	4	main
see	doc_532115409102_item	2682529	et	3	main
ainult	doc_532115409101_item	2682129	et	4	main
kardavad	doc_532115409101_item	2682140	et	4	main
aidata	doc_532115409101_item	2682149	et	4	main
poissi	doc_532115409101_item	2682160	et	4	main
ta	doc_532115409101_item	2682165	et	4	main
õpi	doc_532115409101_item	2682167	et	4	main
eriti	doc_532115409101_item	2682168	et	3	main
hästi	doc_532115409101_item	2682169	et	3	main
tal	doc_532115409101_item	2682170	et	3	main
on	doc_532115409101_item	2682171	et	4	main
ta	doc_532115409101_item	2682174	et	4	main
alustas	doc_532115409101_item	2682176	et	3	main
õpima	doc_532115409101_item	2682177	et	4	main
keemiat	doc_532115409101_item	2682178	et	3	main
ja	doc_532115409101_item	2682179	et	3	main
füüsikat	doc_532115409101_item	2682180	et	3	main
ja	doc_532115409101_item	2682181	et	3	main
veel	doc_532115409101_item	2682182	et	4	main
tal	doc_532115409101_item	2682183	et	3	main
on	doc_532115409101_item	2682184	et	4	main
raskused	doc_532115409101_item	2682185	et	4	main
matemaatikaga	doc_532115409101_item	2682186	et	3	main
järgmine	doc_532115409101_item	2682187	et	3	main
aasta	doc_532115409101_item	2682188	et	4	main
on	doc_532115409101_item	2682189	et	4	main
ta	doc_532115409101_item	2682190	et	4	main
elu	doc_532115409101_item	2682191	et	4	main
esimesed	doc_532115409101_item	2682192	et	3	main
eksamid	doc_532115409101_item	2682193	et	3	main
ja	doc_532115409101_item	2682194	et	3	main
järsku	doc_532115409101_item	2682195	et	4	main
ta	doc_532115409101_item	2682196	et	4	main
saab	doc_532115409101_item	2682197	et	3	main
teada	doc_532115409101_item	2682198	et	3	main
et	doc_532115409101_item	2682199	et	3	main
järgmine	doc_532115409101_item	2682200	et	3	main
aasta	doc_532115409101_item	2682201	et	4	main
ta	doc_532115409101_item	2682202	et	4	main
keel	doc_532115409101_item	2682209	et	4	main
tal	doc_532115409101_item	2682210	et	3	main
on	doc_532115409101_item	2682211	et	4	main
väga	doc_532115409101_item	2682218	et	3	main
probleem	doc_532115409101_item	2682220	et	3	main
saa	doc_532115409101_item	2682223	et	4	main
terminoloogia	doc_532115409101_item	2682231	et	4	main
on	doc_532115409101_item	2682241	et	4	main
mitte	doc_532115409101_item	2682249	et	3	main
hiljem	doc_532115409101_item	2682253	et	3	main
siin	doc_532115409101_item	2682255	et	4	main
üks	doc_532115409101_item	2682257	et	3	main
alustada	doc_532115409101_item	2682260	et	3	main
minu	doc_532115409101_item	2682268	et	3	main
valdama	doc_532115409101_item	2682292	et	3	main
aga	doc_532115409101_item	2682293	et	3	main
vene	doc_532115409102_item	2682298	et	4	main
kool	doc_532115409102_item	2682299	et	4	main
tõusis	doc_532115409102_item	2682305	et	4	main
aastal	doc_532115409102_item	2682313	et	3	main
päris	doc_532115409102_item	2682317	et	4	main
õpilased	doc_532115409102_item	2682321	et	3	main
eesti	doc_532115409102_item	2682324	et	4	main
keeles	doc_532115409102_item	2682325	et	4	main
minu	doc_532115409102_item	2682326	et	3	main
arust	doc_532115409102_item	2682327	et	4	main
see	doc_532115409102_item	2682328	et	3	main
keelt	doc_532115409102_item	2682341	et	4	main
pea	doc_532115409102_item	2682348	et	4	main
miks	doc_532115409102_item	2682356	et	4	main
kergemalt	doc_532115409102_item	2682376	et	4	main
ta	doc_532115409102_item	2682383	et	4	main
peab	doc_532115409102_item	2682385	et	4	main
õppima	doc_532115409102_item	2682386	et	3	main
emakeeles	doc_532115409102_item	2682387	et	4	main
siis	doc_532115409102_item	2682388	et	3	main
ei	doc_532115409102_item	2682397	et	4	main
arvan	doc_532115409102_item	2682402	et	3	main
palju	doc_532115409102_item	2682404	et	4	main
annab	doc_532115409102_item	2682406	et	3	main
õpivad	doc_532115409102_item	2682417	et	3	main
keeles	doc_532115409102_item	2682421	et	4	main
kanada	doc_532115409102_item	2682423	et	4	main
keelt	doc_532115409102_item	2682429	et	4	main
koolides	doc_532115409102_item	2682430	et	3	main
sellepärast	doc_532115409102_item	2682431	et	3	main
nad	doc_532115409102_item	2682432	et	3	main
see	doc_532115409102_item	2682441	et	3	main
ilus	doc_532115409102_item	2682445	et	4	main
meie	doc_532115409102_item	2682447	et	4	main
on	doc_532115409102_item	2682456	et	4	main
väga	doc_532115409102_item	2682459	et	3	main
positiivset	doc_532115409102_item	2682470	et	3	main
selles	doc_532115409102_item	2682472	et	4	main
see	doc_532115409102_item	2682474	et	3	main
väga	doc_532115409102_item	2682476	et	3	main
teab	doc_532115409102_item	2682480	et	3	main
mitte	doc_532115409102_item	2682481	et	3	main
ainult	doc_532115409102_item	2682482	et	4	main
üht	doc_532115409102_item	2682483	et	3	main
teised	doc_532115409101_item	2682226	et	4	main
terve	doc_532115409101_item	2682228	et	4	main
õpimisega	doc_532115409101_item	2682232	et	4	main
minu	doc_532115409101_item	2682233	et	3	main
arust	doc_532115409101_item	2682234	et	4	main
on	doc_532115409101_item	2682235	et	4	main
see	doc_532115409101_item	2682236	et	3	main
väga	doc_532115409101_item	2682237	et	3	main
suur	doc_532115409101_item	2682238	et	3	main
probleem	doc_532115409101_item	2682239	et	3	main
iseenesest	doc_532115409101_item	2682240	et	4	main
teeks	doc_532115409101_item	2682246	et	4	main
inimestele	doc_532115409101_item	2682247	et	3	main
head	doc_532115409101_item	2682248	et	4	main
mingi	doc_532115409101_item	2682265	et	4	main
põhi	doc_532115409101_item	2682266	et	3	main
see	doc_532115409101_item	2682270	et	3	main
riigis	doc_532115409101_item	2682277	et	3	main
paljud	doc_532115409101_item	2682279	et	3	main
peab	doc_532115409101_item	2682286	et	4	main
eesti	doc_532115409101_item	2682290	et	4	main
pärast	doc_532115409101_item	2682294	et	4	main
võib	doc_532115409101_item	2682295	et	3	main
tegelema	doc_532115409101_item	2682296	et	3	main
koolidega	doc_532115409101_item	2682297	et	3	main
meie	doc_532115409102_item	2682303	et	4	main
riigis	doc_532115409102_item	2682304	et	3	main
koolid	doc_532115409102_item	2682311	et	3	main
see	doc_532115409102_item	2682314	et	3	main
hakkavad	doc_532115409102_item	2682322	et	4	main
hea	doc_532115409102_item	2682331	et	4	main
keelt	doc_532115409102_item	2682345	et	4	main
nad	doc_532115409102_item	2682346	et	3	main
ei	doc_532115409102_item	2682347	et	4	main
ma	doc_532115409102_item	2682350	et	3	main
saa	doc_532115409102_item	2682353	et	4	main
tulevad	doc_532115409102_item	2682375	et	4	main
inimene	doc_532115409102_item	2682378	et	3	main
väike	doc_532115409102_item	2682380	et	4	main
aga	doc_532115409102_item	2682381	et	3	main
ikka	doc_532115409102_item	2682384	et	4	main
probleeme	doc_532115409102_item	2682400	et	3	main
eksisteerivad	doc_532115409102_item	2682413	et	4	main
koolid	doc_532115409102_item	2682414	et	3	main
kus	doc_532115409102_item	2682415	et	3	main
inglise	doc_532115409102_item	2682418	et	4	main
otsusta	doc_532115409102_item	2682426	et	4	main
prantsuse	doc_532115409102_item	2682428	et	3	main
saavad	doc_532115409102_item	2682433	et	4	main
aru	doc_532115409102_item	2682434	et	4	main
et	doc_532115409102_item	2682435	et	3	main
lihtsalt	doc_532115409102_item	2682443	et	4	main
elanikkonnast	doc_532115409102_item	2682455	et	4	main
et	doc_532115409102_item	2682458	et	3	main
elada	doc_532115409102_item	2682463	et	3	main
on	doc_532115409102_item	2682468	et	4	main
küljed	doc_532115409102_item	2682471	et	3	main
probleemis	doc_532115409102_item	2682473	et	3	main
on	doc_532115409102_item	2682475	et	4	main
mis	doc_532115409102_item	2682493	et	4	main
talle	doc_532115409102_item	2682495	et	4	main
venelased	doc_532115409102_item	2682522	et	3	main
ole	doc_532115409102_item	2682330	et	4	main
idee	doc_532115409102_item	2682332	et	4	main
aga	doc_532115409102_item	2682342	et	3	main
ka	doc_532115409102_item	2682343	et	3	main
oma	doc_532115409102_item	2682344	et	4	main
unustama	doc_532115409102_item	2682349	et	3	main
aru	doc_532115409102_item	2682355	et	4	main
haridusministeerium	doc_532115409102_item	2682357	et	3	main
tegi	doc_532115409102_item	2682358	et	4	main
niisuguse	doc_532115409102_item	2682359	et	3	main
valiku	doc_532115409102_item	2682360	et	3	main
ma	doc_532115409102_item	2682361	et	3	main
arvan	doc_532115409102_item	2682362	et	3	main
et	doc_532115409102_item	2682363	et	3	main
lapsele	doc_532115409102_item	2682364	et	4	main
on	doc_532115409102_item	2682365	et	4	main
väga	doc_532115409102_item	2682366	et	3	main
kasulik	doc_532115409102_item	2682367	et	3	main
oskused	doc_532115409102_item	2682374	et	3	main
koolis	doc_532115409102_item	2682382	et	4	main
teki	doc_532115409102_item	2682398	et	4	main
keelteoskuste	doc_532115409102_item	2682399	et	3	main
põhjusi	doc_532115409102_item	2682405	et	3	main
ka	doc_532115409102_item	2682407	et	3	main
aga	doc_532115409102_item	2682409	et	3	main
ja	doc_532115409102_item	2682419	et	3	main
miks	doc_532115409102_item	2682422	et	4	main
valitsus	doc_532115409102_item	2682424	et	4	main
oleks	doc_532115409102_item	2682442	et	3	main
valik	doc_532115409102_item	2682446	et	3	main
riigis	doc_532115409102_item	2682448	et	3	main
tuleb	doc_532115409102_item	2682462	et	3	main
lapsi	doc_532115409102_item	2682466	et	4	main
aga	doc_532115409102_item	2682485	et	3	main
kui	doc_532115409102_item	2682486	et	3	main
siis	doc_532115409102_item	2682494	et	3	main
teha	doc_532115409102_item	2682496	et	3	main
kui	doc_532115409102_item	2682521	et	3	main
asja	doc_532115409102_item	2682526	et	4	main
oleks	doc_532115409102_item	2682528	et	3	main
saab	doc_532115409102_item	2682390	et	3	main
hästi	doc_532115409102_item	2682391	et	3	main
et	doc_532115409102_item	2682403	et	3	main
ajalugu	doc_532115409102_item	2682408	et	4	main
lapsed	doc_532115409102_item	2682416	et	3	main
keelduda	doc_532115409102_item	2682427	et	3	main
on	doc_532115409102_item	2682438	et	4	main
prantslased	doc_532115409102_item	2682439	et	3	main
ja	doc_532115409102_item	2682440	et	3	main
valitsus	doc_532115409102_item	2682451	et	4	main
unustas	doc_532115409102_item	2682452	et	3	main
et	doc_532115409102_item	2682453	et	3	main
30	doc_532115409102_item	2682454	et	2	main
siis	doc_532115409102_item	2682461	et	3	main
kasvatada	doc_532115409102_item	2682465	et	3	main
ka	doc_532115409102_item	2682469	et	3	main
keelt	doc_532115409102_item	2682484	et	4	main
vene	doc_532115409102_item	2682487	et	4	main
õpilane	doc_532115409102_item	2682488	et	3	main
tahab	doc_532115409102_item	2682489	et	3	main
õppida	doc_532115409102_item	2682490	et	3	main
venemaal	doc_532115409102_item	2682491	et	4	main
ülikoolis	doc_532115409102_item	2682492	et	4	main
eesti	doc_532115409102_item	2682498	et	4	main
keel	doc_532115409102_item	2682499	et	4	main
ei	doc_532115409102_item	2682500	et	4	main
ole	doc_532115409102_item	2682501	et	4	main
nii	doc_532115409102_item	2682502	et	3	main
vajalik	doc_532115409102_item	2682503	et	3	main
kui	doc_532115409102_item	2682504	et	3	main
meie	doc_532115409102_item	2682505	et	4	main
valitsus	doc_532115409102_item	2682506	et	4	main
mõtleb	doc_532115409102_item	2682507	et	3	main
kõiges	doc_532115409102_item	2682508	et	4	main
peab	doc_532115409102_item	2682509	et	4	main
olema	doc_532115409102_item	2682510	et	4	main
piir	doc_532115409102_item	2682511	et	3	main
ma	doc_532115409102_item	2682512	et	3	main
soovitaksin	doc_532115409102_item	2682513	et	3	main
haridusministeeriumile	doc_532115409102_item	2682514	et	3	main
arvamuse	doc_532115409102_item	2682516	et	3	main
üle	doc_532115409102_item	2682517	et	3	main
arutlema	doc_532115409102_item	2682518	et	3	main
kujutage	doc_532115409102_item	2682519	et	3	main
ette	doc_532115409102_item	2682520	et	4	main
oma	doc_532115409102_item	2682515	et	4	main
teinud	doc_532115409102_item	2682524	et	4	main
eestlastele	doc_532115409102_item	2682527	et	4	main
aus	doc_532115409102_item	2682530	et	4	main
võib	doc_532115409102_item	2682531	et	3	main
olla	doc_532115409102_item	2682532	et	3	main
annabe	doc_532115409102_item	2682533	et	4	main
meile	doc_532115409102_item	2682534	et	4	main
võimalust	doc_532115409102_item	2682535	et	3	main
sama	doc_532115409102_item	2682525	et	4	main
keeles	doc_532115409104_item	2682729	et	4	main
ma	doc_532115409104_item	2682730	et	3	main
arvan	doc_532115409104_item	2682731	et	3	main
emakeelt	doc_532115409104_item	2682737	et	4	main
see	doc_532115409104_item	2682738	et	3	main
ei	doc_532115409104_item	2682739	et	4	main
eestikeelt	doc_532115409104_item	2682755	et	4	main
esimesest	doc_532115409104_item	2682756	et	3	main
klassist	doc_532115409104_item	2682757	et	3	main
ja	doc_532115409104_item	2682758	et	3	main
peab	doc_532115409104_item	2682760	et	4	main
eesti	doc_532115409104_item	2682763	et	4	main
arvan	doc_532115409104_item	2682767	et	3	main
oma	doc_532115409104_item	2682778	et	4	main
rahvus	doc_532115409104_item	2682779	et	3	main
venelased	doc_532115409104_item	2682784	et	3	main
eestlased	doc_532115409104_item	2682786	et	3	main
pole	doc_532115409104_item	2682789	et	3	main
siis	doc_532115409104_item	2682796	et	3	main
elama	doc_532115409104_item	2682809	et	3	main
valitsus	doc_532115409104_item	2682816	et	4	main
arvan	doc_532115409104_item	2682830	et	3	main
ei	doc_532115409104_item	2682844	et	4	main
lapsele	doc_532115409104_item	2682848	et	4	main
ei	doc_532115409104_item	2682850	et	4	main
saa	doc_532115409104_item	2682851	et	4	main
et	doc_532115409104_item	2682856	et	3	main
ja	doc_532115409104_item	2682861	et	3	main
olema	doc_532115409104_item	2682875	et	4	main
süvaõpemisega	doc_532115409104_item	2682884	et	4	main
kool	doc_532115409105_item	2682918	et	4	main
eesti	doc_532115409105_item	2682919	et	4	main
keeles	doc_532115409105_item	2682920	et	4	main
vene	doc_532115409104_item	2682726	et	4	main
eesti	doc_532115409104_item	2682728	et	4	main
oma	doc_532115409104_item	2682736	et	4	main
keeled	doc_532115409104_item	2682743	et	3	main
õpima	doc_532115409104_item	2682754	et	4	main
ma	doc_532115409104_item	2682766	et	3	main
eesti	doc_532115409104_item	2682773	et	4	main
pole	doc_532115409104_item	2682782	et	3	main
aga	doc_532115409104_item	2682787	et	3	main
oma	doc_532115409104_item	2682800	et	4	main
muidugi	doc_532115409104_item	2682802	et	4	main
eesti	doc_532115409104_item	2682805	et	4	main
ja	doc_532115409104_item	2682806	et	3	main
aga	doc_532115409104_item	2682811	et	3	main
sellest	doc_532115409104_item	2682820	et	4	main
sest	doc_532115409104_item	2682821	et	4	main
tööta	doc_532115409104_item	2682823	et	4	main
jääb	doc_532115409104_item	2682824	et	3	main
on	doc_532115409104_item	2682841	et	4	main
venelased	doc_532115409104_item	2682842	et	3	main
nad	doc_532115409104_item	2682843	et	3	main
aidata	doc_532115409104_item	2682846	et	4	main
korralikult	doc_532115409104_item	2682852	et	4	main
saab	doc_532115409104_item	2682858	et	3	main
ei	doc_532115409104_item	2682863	et	4	main
saa	doc_532115409104_item	2682870	et	4	main
töötada	doc_532115409104_item	2682871	et	3	main
minu	doc_532115409104_item	2682872	et	3	main
venelased	doc_532115409104_item	2682878	et	3	main
eesti	doc_532115409104_item	2682890	et	4	main
vene	doc_532115409105_item	2682926	et	4	main
üleminema	doc_532115409105_item	2682930	et	4	main
eesti	doc_532115409105_item	2682931	et	4	main
häbi	doc_532115409105_item	2682939	et	4	main
nad	doc_532115409105_item	2682945	et	3	main
venelased	doc_532115409105_item	2682947	et	3	main
mõtlen	doc_532115409105_item	2682954	et	3	main
et	doc_532115409105_item	2682955	et	3	main
nad	doc_532115409105_item	2682963	et	3	main
vastu	doc_532115409105_item	2682966	et	3	main
unistada	doc_532115409105_item	2682975	et	3	main
traditsioonid	doc_532115409105_item	2682977	et	3	main
suhtusring	doc_532115409105_item	2682981	et	4	main
idee	doc_532115409105_item	2682985	et	4	main
on	doc_532115409105_item	2682986	et	4	main
mitte	doc_532115409105_item	2682987	et	3	main
kooli	doc_532115409105_item	2682995	et	4	main
valdavad	doc_532115409105_item	2683009	et	4	main
nad	doc_532115409105_item	2683013	et	3	main
keeles	doc_532115409106_item	2683051	et	4	main
sellest	doc_532115409106_item	2683062	et	4	main
räägib	doc_532115409106_item	2683063	et	3	main
õigustatud	doc_532115409106_item	2683075	et	4	main
seda	doc_532115409106_item	2683076	et	3	main
üleminek	doc_532115409106_item	2683077	et	3	main
kus	doc_532115409106_item	2683081	et	3	main
aktiivsel	doc_532115409106_item	2683117	et	3	main
on	doc_532115409106_item	2683127	et	4	main
sest	doc_532115409106_item	2683130	et	4	main
keel	doc_532115409106_item	2683139	et	4	main
aga	doc_532115409106_item	2683144	et	3	main
sellisel	doc_532115409106_item	2683161	et	4	main
võib	doc_532115409106_item	2683172	et	3	main
tuua	doc_532115409106_item	2683173	et	3	main
ebs	doc_532115409106_item	2683174	et	4	main
kui	doc_532115409106_item	2683178	et	3	main
lütsei	doc_532115409106_item	2683183	et	4	main
frantsuse	doc_532115409106_item	2683187	et	4	main
või	doc_532115409106_item	2683189	et	4	main
oska	doc_532115409104_item	2682735	et	4	main
teised	doc_532115409104_item	2682742	et	4	main
rohkem	doc_532115409104_item	2682762	et	4	main
tundi	doc_532115409104_item	2682765	et	4	main
kui	doc_532115409104_item	2682769	et	3	main
kool	doc_532115409104_item	2682727	et	4	main
et	doc_532115409104_item	2682732	et	3	main
kes	doc_532115409104_item	2682733	et	4	main
ei	doc_532115409104_item	2682734	et	4	main
saa	doc_532115409104_item	2682740	et	4	main
õppida	doc_532115409104_item	2682741	et	3	main
vene	doc_532115409104_item	2682750	et	4	main
koolis	doc_532115409104_item	2682751	et	4	main
ja	doc_532115409104_item	2682752	et	3	main
keele	doc_532115409104_item	2682764	et	4	main
et	doc_532115409104_item	2682768	et	3	main
venelased	doc_532115409104_item	2682770	et	3	main
õppima	doc_532115409104_item	2682772	et	3	main
sest	doc_532115409104_item	2682780	et	4	main
nad	doc_532115409104_item	2682781	et	3	main
see	doc_532115409104_item	2682788	et	3	main
võimalik	doc_532115409104_item	2682790	et	3	main
inimesel	doc_532115409104_item	2682792	et	3	main
rahvust	doc_532115409104_item	2682794	et	3	main
unustavad	doc_532115409104_item	2682797	et	4	main
ajalugu	doc_532115409104_item	2682801	et	4	main
see	doc_532115409104_item	2682803	et	3	main
on	doc_532115409104_item	2682804	et	4	main
eestlased	doc_532115409104_item	2682810	et	3	main
kui	doc_532115409104_item	2682836	et	3	main
õppida	doc_532115409104_item	2682853	et	3	main
tähendab	doc_532115409104_item	2682855	et	3	main
pahad	doc_532115409104_item	2682859	et	4	main
ta	doc_532115409104_item	2682868	et	4	main
ei	doc_532115409104_item	2682869	et	4	main
nii	doc_532115409104_item	2682876	et	3	main
ja	doc_532115409104_item	2682885	et	3	main
kooli	doc_532115409104_item	2682887	et	4	main
nad	doc_532115409104_item	2682888	et	3	main
lähevad	doc_532115409104_item	2682889	et	3	main
ühest	doc_532115409105_item	2682921	et	4	main
ma	doc_532115409105_item	2682923	et	3	main
aravn	doc_532115409105_item	2682924	et	4	main
ei	doc_532115409105_item	2682928	et	4	main
pea	doc_532115409105_item	2682929	et	4	main
emakeel	doc_532115409105_item	2682937	et	4	main
ja	doc_532115409105_item	2682938	et	3	main
keelt	doc_532115409105_item	2682952	et	4	main
ma	doc_532115409105_item	2682953	et	3	main
õppida	doc_532115409105_item	2682956	et	3	main
on	doc_532115409105_item	2682959	et	4	main
ja	doc_532115409105_item	2682962	et	3	main
kõik	doc_532115409105_item	2682967	et	4	main
informatsioon	doc_532115409105_item	2682968	et	3	main
edasijõudmise	doc_532115409105_item	2682969	et	3	main
tase	doc_532115409105_item	2682970	et	3	main
langeb	doc_532115409105_item	2682971	et	3	main
vene	doc_532115409105_item	2682972	et	4	main
lapsed	doc_532115409105_item	2682973	et	3	main
see	doc_532115409105_item	2682984	et	3	main
paha	doc_532115409105_item	2682988	et	4	main
see	doc_532115409105_item	2682989	et	3	main
sobib	doc_532115409105_item	2682990	et	3	main
tahavad	doc_532115409105_item	2682996	et	3	main
eestis	doc_532115409105_item	2682997	et	3	main
nad	doc_532115409105_item	2682999	et	3	main
keel	doc_532115409105_item	2683002	et	4	main
kesktase	doc_532115409105_item	2683015	et	3	main
parem	doc_532115409105_item	2683022	et	4	main
suhtlemine	doc_532115409105_item	2683028	et	4	main
kui	doc_532115409105_item	2683029	et	3	main
sa	doc_532115409105_item	2683030	et	3	main
piisa	doc_532115409105_item	2683036	et	4	main
otsus	doc_532115409105_item	2683042	et	3	main
vene	doc_532115409105_item	2683046	et	4	main
kool	doc_532115409106_item	2683049	et	4	main
eesti	doc_532115409106_item	2683050	et	4	main
olukorda	doc_532115409106_item	2683080	et	4	main
need	doc_532115409106_item	2683125	et	3	main
iseseisev	doc_532115409106_item	2683133	et	3	main
on	doc_532115409106_item	2683137	et	4	main
mis	doc_532115409106_item	2683140	et	4	main
see	doc_532115409104_item	2682744	et	3	main
tähendab	doc_532115409104_item	2682745	et	3	main
et	doc_532115409104_item	2682746	et	3	main
venelased	doc_532115409104_item	2682747	et	3	main
õppima	doc_532115409104_item	2682749	et	3	main
peavad	doc_532115409104_item	2682748	et	4	main
veel	doc_532115409104_item	2682753	et	4	main
et	doc_532115409104_item	2682759	et	3	main
ollema	doc_532115409104_item	2682761	et	4	main
kaotavad	doc_532115409104_item	2682777	et	4	main
enam	doc_532115409104_item	2682783	et	4	main
et	doc_532115409104_item	2682791	et	3	main
pole	doc_532115409104_item	2682793	et	3	main
venelased	doc_532115409104_item	2682795	et	3	main
siin	doc_532115409104_item	2682807	et	4	main
see	doc_532115409104_item	2682812	et	3	main
juba	doc_532115409104_item	2682814	et	3	main
tõsiselt	doc_532115409104_item	2682818	et	4	main
et	doc_532115409104_item	2682831	et	3	main
hakkavad	doc_532115409104_item	2682833	et	4	main
peres	doc_532115409104_item	2682837	et	3	main
saa	doc_532115409104_item	2682845	et	4	main
ta	doc_532115409104_item	2682857	et	4	main
arvates	doc_532115409104_item	2682873	et	4	main
peab	doc_532115409104_item	2682874	et	4	main
õppivad	doc_532115409104_item	2682879	et	4	main
koolis	doc_532115409104_item	2682881	et	4	main
koolid	doc_532115409105_item	2682927	et	3	main
keeles	doc_532115409105_item	2682932	et	4	main
venelased	doc_532115409105_item	2682933	et	3	main
voivad	doc_532115409105_item	2682934	et	4	main
unistama	doc_532115409105_item	2682935	et	3	main
tund	doc_532115409105_item	2682940	et	3	main
vanemat	doc_532115409105_item	2682942	et	4	main
on	doc_532115409105_item	2682946	et	4	main
ja	doc_532115409105_item	2682948	et	3	main
väga	doc_532115409105_item	2682960	et	3	main
ei	doc_532115409105_item	2682964	et	4	main
võtta	doc_532115409105_item	2682965	et	3	main
nad	doc_532115409105_item	2682978	et	3	main
neile	doc_532115409105_item	2682991	et	4	main
jääta	doc_532115409105_item	2682998	et	4	main
koolilõppetamisega	doc_532115409105_item	2683007	et	4	main
nad	doc_532115409105_item	2683008	et	3	main
vabalt	doc_532115409105_item	2683012	et	4	main
ja	doc_532115409105_item	2683016	et	3	main
kõige	doc_532115409105_item	2683021	et	4	main
viis	doc_532115409105_item	2683023	et	4	main
õppetada	doc_532115409105_item	2683024	et	4	main
õppib	doc_532115409105_item	2683031	et	4	main
on	doc_532115409105_item	2683037	et	4	main
on	doc_532115409105_item	2683043	et	4	main
hetkel	doc_532115409106_item	2683052	et	4	main
media	doc_532115409106_item	2683064	et	4	main
ja	doc_532115409106_item	2683065	et	3	main
inimesed	doc_532115409106_item	2683066	et	3	main
peab	doc_532115409106_item	2683078	et	4	main
lapsest	doc_532115409106_item	2683082	et	4	main
kohustatud	doc_532115409106_item	2683084	et	4	main
siis	doc_532115409106_item	2683119	et	3	main
hakkavad	doc_532115409104_item	2682771	et	4	main
keeles	doc_532115409104_item	2682774	et	4	main
siis	doc_532115409104_item	2682775	et	3	main
nad	doc_532115409104_item	2682776	et	3	main
ega	doc_532115409104_item	2682785	et	3	main
oma	doc_532115409104_item	2682798	et	4	main
traditsioon	doc_532115409104_item	2682799	et	3	main
peavad	doc_532115409104_item	2682808	et	4	main
on	doc_532115409104_item	2682813	et	4	main
diskriminatsioon	doc_532115409104_item	2682815	et	3	main
peab	doc_532115409104_item	2682817	et	4	main
mõtlema	doc_532115409104_item	2682819	et	3	main
ilma	doc_532115409104_item	2682822	et	4	main
nii	doc_532115409104_item	2682825	et	3	main
palju	doc_532115409104_item	2682826	et	4	main
õppetajad	doc_532115409104_item	2682827	et	4	main
ja	doc_532115409104_item	2682828	et	3	main
ma	doc_532115409104_item	2682829	et	3	main
venelased	doc_532115409104_item	2682832	et	3	main
protestima	doc_532115409104_item	2682834	et	3	main
ja	doc_532115409104_item	2682835	et	3	main
on	doc_532115409104_item	2682838	et	4	main
mõlemad	doc_532115409104_item	2682839	et	3	main
vanemad	doc_532115409104_item	2682840	et	4	main
oma	doc_532115409104_item	2682847	et	4	main
ta	doc_532115409104_item	2682849	et	4	main
see	doc_532115409104_item	2682854	et	3	main
hinded	doc_532115409104_item	2682860	et	3	main
ta	doc_532115409104_item	2682862	et	4	main
saa	doc_532115409104_item	2682864	et	4	main
minna	doc_532115409104_item	2682865	et	3	main
ülikooli	doc_532115409104_item	2682866	et	4	main
ja	doc_532115409104_item	2682867	et	3	main
et	doc_532115409104_item	2682877	et	3	main
vene	doc_532115409104_item	2682880	et	4	main
eesti	doc_532115409104_item	2682882	et	4	main
keele	doc_532115409104_item	2682883	et	4	main
pärast	doc_532115409104_item	2682886	et	4	main
ülikooli	doc_532115409104_item	2682891	et	4	main
see	doc_532115409104_item	2682892	et	3	main
on	doc_532115409104_item	2682893	et	4	main
kõige	doc_532115409104_item	2682894	et	4	main
ratsenalsem	doc_532115409104_item	2682895	et	4	main
viis	doc_532115409104_item	2682896	et	4	main
see	doc_532115409104_item	2682897	et	3	main
isegi	doc_532115409104_item	2682899	et	4	main
on	doc_532115409104_item	2682898	et	4	main
parem	doc_532115409104_item	2682900	et	4	main
sest	doc_532115409104_item	2682901	et	4	main
inimene	doc_532115409104_item	2682902	et	3	main
juba	doc_532115409104_item	2682903	et	3	main
tead	doc_532115409104_item	2682904	et	4	main
kaks	doc_532115409104_item	2682905	et	3	main
keelt	doc_532115409104_item	2682906	et	4	main
vene	doc_532115409104_item	2682907	et	4	main
ja	doc_532115409104_item	2682908	et	3	main
eesti	doc_532115409104_item	2682909	et	4	main
see	doc_532115409104_item	2682910	et	3	main
tähendab	doc_532115409104_item	2682911	et	3	main
et	doc_532115409104_item	2682912	et	3	main
temal	doc_532115409104_item	2682913	et	3	main
on	doc_532115409104_item	2682914	et	4	main
rohkem	doc_532115409104_item	2682915	et	4	main
võimalusi	doc_532115409104_item	2682916	et	3	main
vene	doc_532115409105_item	2682917	et	4	main
et	doc_532115409105_item	2682925	et	3	main
oma	doc_532115409105_item	2682941	et	4	main
küljest	doc_532115409105_item	2682922	et	4	main
oma	doc_532115409105_item	2682936	et	4	main
sest	doc_532115409105_item	2682943	et	4	main
ei	doc_532115409105_item	2682949	et	4	main
võrras	doc_532115409105_item	2682957	et	4	main
raske	doc_532115409105_item	2682961	et	4	main
võivad	doc_532115409105_item	2682974	et	4	main
oma	doc_532115409105_item	2682976	et	4	main
muutuvad	doc_532115409105_item	2682979	et	4	main
teisest	doc_532115409105_item	2682982	et	4	main
venelastele	doc_532115409105_item	2682992	et	4	main
kes	doc_532115409105_item	2682993	et	4	main
parast	doc_532115409105_item	2682994	et	3	main
võivad	doc_532115409105_item	2683000	et	4	main
keelt	doc_532115409105_item	2683011	et	4	main
leida	doc_532115409105_item	2683018	et	3	main
töö	doc_532115409105_item	2683020	et	4	main
et	doc_532115409105_item	2682944	et	3	main
oska	doc_532115409105_item	2682950	et	4	main
eesti	doc_532115409105_item	2682951	et	4	main
keeles	doc_532115409105_item	2682958	et	4	main
oma	doc_532115409105_item	2682980	et	4	main
küljest	doc_532115409105_item	2682983	et	4	main
eesti	doc_532115409105_item	2683001	et	4	main
väga	doc_532115409105_item	2683003	et	3	main
hästi	doc_532115409105_item	2683004	et	3	main
õppida	doc_532115409105_item	2683005	et	3	main
ja	doc_532115409105_item	2683006	et	3	main
eesti	doc_532115409105_item	2683010	et	4	main
saavad	doc_532115409105_item	2683014	et	4	main
võivad	doc_532115409105_item	2683017	et	4	main
hea	doc_532115409105_item	2683019	et	4	main
eesti	doc_532115409105_item	2683025	et	4	main
keel	doc_532115409105_item	2683026	et	4	main
ainult	doc_532115409105_item	2683032	et	4	main
gramaatika	doc_532115409105_item	2683033	et	4	main
vaja	doc_532115409105_item	2683038	et	4	main
praktika	doc_532115409105_item	2683039	et	4	main
parem	doc_532115409105_item	2683041	et	4	main
mõned	doc_532115409105_item	2683045	et	3	main
vene	doc_532115409106_item	2683048	et	4	main
kes	doc_532115409106_item	2683067	et	4	main
seda	doc_532115409106_item	2683068	et	3	main
otseselt	doc_532115409106_item	2683069	et	4	main
puudutab	doc_532115409106_item	2683070	et	3	main
kas	doc_532115409106_item	2683071	et	3	main
saavutada	doc_532115409106_item	2683079	et	3	main
väiksest	doc_532115409106_item	2683083	et	4	main
austama	doc_532115409106_item	2683085	et	3	main
kasutuses	doc_532115409106_item	2683118	et	4	main
eesti	doc_532115409106_item	2683120	et	4	main
keel	doc_532115409106_item	2683121	et	4	main
väjagi	doc_532115409106_item	2683123	et	4	main
inimesed	doc_532115409106_item	2683126	et	3	main
tegelikult	doc_532115409106_item	2683128	et	4	main
eesti	doc_532115409106_item	2683131	et	4	main
riig	doc_532115409106_item	2683134	et	4	main
tal	doc_532115409106_item	2683136	et	3	main
venekeelest	doc_532115409106_item	2683143	et	4	main
niimoodi	doc_532115409106_item	2683146	et	3	main
eestisse	doc_532115409106_item	2683157	et	4	main
mingi	doc_532115409106_item	2683169	et	4	main
keeles	doc_532115409106_item	2683181	et	4	main
tuuakse	doc_532115409106_item	2683195	et	3	main
keeles	doc_532115409106_item	2683197	et	4	main
kool	doc_532115409106_item	2683206	et	4	main
keeles	doc_532115409106_item	2683210	et	4	main
on	doc_532115409105_item	2683027	et	4	main
see	doc_532115409105_item	2683034	et	3	main
ei	doc_532115409105_item	2683035	et	4	main
kakõige	doc_532115409105_item	2683040	et	4	main
jäta	doc_532115409105_item	2683044	et	4	main
koolid	doc_532115409105_item	2683047	et	3	main
on	doc_532115409106_item	2683053	et	4	main
väga	doc_532115409106_item	2683054	et	3	main
aktuaalne	doc_532115409106_item	2683055	et	3	main
tema	doc_532115409106_item	2683056	et	4	main
vene	doc_532115409106_item	2683057	et	4	main
koolide	doc_532115409106_item	2683058	et	3	main
üleminek	doc_532115409106_item	2683059	et	3	main
eestikeelsele	doc_532115409106_item	2683060	et	3	main
õppekavale	doc_532115409106_item	2683061	et	3	main
on	doc_532115409106_item	2683072	et	4	main
see	doc_532115409106_item	2683073	et	3	main
üleminek	doc_532115409106_item	2683074	et	3	main
ja	doc_532115409106_item	2683086	et	3	main
ära	doc_532115409106_item	2683087	et	4	main
härjutama	doc_532115409106_item	2683088	et	4	main
eestikeelt	doc_532115409106_item	2683089	et	4	main
siis	doc_532115409106_item	2683090	et	3	main
see	doc_532115409106_item	2683091	et	3	main
üsnagi	doc_532115409106_item	2683092	et	3	main
õiglane	doc_532115409106_item	2683093	et	3	main
sest	doc_532115409106_item	2683094	et	4	main
hetkel	doc_532115409106_item	2683095	et	4	main
on	doc_532115409106_item	2683096	et	4	main
suhtlemist	doc_532115409106_item	2683097	et	4	main
inimesed	doc_532115409106_item	2683098	et	3	main
kes	doc_532115409106_item	2683099	et	4	main
riigikeelt	doc_532115409106_item	2683100	et	4	main
ei	doc_532115409106_item	2683101	et	4	main
oska	doc_532115409106_item	2683102	et	4	main
ja	doc_532115409106_item	2683103	et	3	main
isegi	doc_532115409106_item	2683104	et	4	main
ei	doc_532115409106_item	2683105	et	4	main
püüa	doc_532115409106_item	2683106	et	4	main
õppida	doc_532115409106_item	2683107	et	3	main
br	doc_532115409106_item	2683108	et	4	main
mõned	doc_532115409106_item	2683109	et	3	main
inimesed	doc_532115409106_item	2683110	et	3	main
et	doc_532115409106_item	2683112	et	3	main
mõtlevad	doc_532115409106_item	2683111	et	4	main
kui	doc_532115409106_item	2683113	et	3	main
vene	doc_532115409106_item	2683114	et	4	main
keel	doc_532115409106_item	2683115	et	4	main
on	doc_532115409106_item	2683116	et	4	main
pole	doc_532115409106_item	2683122	et	3	main
õppida	doc_532115409106_item	2683124	et	3	main
on	doc_532115409106_item	2683132	et	4	main
ja	doc_532115409106_item	2683135	et	3	main
oma	doc_532115409106_item	2683138	et	4	main
koordinaalselt	doc_532115409106_item	2683141	et	4	main
kui	doc_532115409106_item	2683145	et	3	main
juhul	doc_532115409106_item	2683162	et	3	main
on	doc_532115409106_item	2683164	et	4	main
koolid	doc_532115409106_item	2683165	et	3	main
näiteks	doc_532115409106_item	2683171	et	4	main
coledž	doc_532115409106_item	2683177	et	2	main
õppetakse	doc_532115409106_item	2683179	et	3	main
süva	doc_532115409106_item	2683185	et	4	main
keel	doc_532115409106_item	2683188	et	4	main
nende	doc_532115409106_item	2683217	et	4	main
koolide	doc_532115409106_item	2683218	et	3	main
ei	doc_532115409106_item	2683219	et	4	main
kui	doc_532115409106_item	2683226	et	3	main
õppilased	doc_532115409106_item	2683227	et	4	main
vene	doc_532115409106_item	2683228	et	4	main
koolides	doc_532115409106_item	2683229	et	3	main
vajalik	doc_532115409106_item	2683235	et	3	main
nende	doc_532115409106_item	2683242	et	4	main
ainult	doc_532115409106_item	2683246	et	4	main
vene	doc_532115409107_item	2683278	et	4	main
et	doc_532115409107_item	2683284	et	3	main
keeles	doc_532115409107_item	2683293	et	4	main
kohustasi	doc_532115409107_item	2683303	et	4	main
harridust	doc_532115409107_item	2683306	et	4	main
on	doc_532115409107_item	2683316	et	4	main
inimene	doc_532115409107_item	2683321	et	3	main
minused	doc_532115409107_item	2683326	et	4	main
näteks	doc_532115409107_item	2683329	et	4	main
palju	doc_532115409107_item	2683330	et	4	main
ja	doc_532115409107_item	2683337	et	3	main
ma	doc_532115409107_item	2683338	et	3	main
ette	doc_532115409107_item	2683341	et	4	main
aastal	doc_532115409107_item	2683351	et	3	main
teada	doc_532115409107_item	2683359	et	3	main
venelased	doc_532115409107_item	2683365	et	3	main
2007	doc_532115409107_item	2683388	et	2	main
et	doc_532115409107_item	2683394	et	3	main
õppima	doc_532115409107_item	2683398	et	3	main
lõpetama	doc_532115409107_item	2683412	et	4	main
vene	doc_532115409107_item	2683414	et	4	main
eesti	doc_532115409108_item	2683418	et	4	main
keeles	doc_532115409108_item	2683419	et	4	main
aastal	doc_532115409108_item	2683420	et	3	main
vale	doc_532115409106_item	2683129	et	4	main
juhtus	doc_532115409106_item	2683147	et	3	main
et	doc_532115409106_item	2683148	et	3	main
lapse	doc_532115409106_item	2683149	et	4	main
vanemad	doc_532115409106_item	2683150	et	4	main
noor	doc_532115409106_item	2683152	et	3	main
juba	doc_532115409106_item	2683153	et	3	main
või	doc_532115409106_item	2683151	et	4	main
ise	doc_532115409106_item	2683154	et	4	main
erined	doc_532115409106_item	2683142	et	3	main
teab	doc_532115409106_item	2683155	et	3	main
et	doc_532115409106_item	2683156	et	3	main
taha	doc_532115409106_item	2683160	et	4	main
otsas	doc_532115409106_item	2683163	et	4	main
kus	doc_532115409106_item	2683166	et	3	main
sügavamalt	doc_532115409106_item	2683167	et	4	main
õppetakse	doc_532115409106_item	2683168	et	3	main
ja	doc_532115409106_item	2683175	et	3	main
kus	doc_532115409106_item	2683184	et	3	main
õppetakse	doc_532115409106_item	2683186	et	3	main
kadrioru	doc_532115409106_item	2683190	et	3	main
gümnasium	doc_532115409106_item	2683192	et	4	main
sellesse	doc_532115409106_item	2683203	et	4	main
ise	doc_532115409106_item	2683207	et	4	main
lisa	doc_532115409106_item	2683220	et	4	main
siis	doc_532115409106_item	2683236	et	3	main
see	doc_532115409106_item	2683240	et	3	main
ainult	doc_532115409106_item	2683243	et	4	main
kasuks	doc_532115409106_item	2683244	et	4	main
kaklukstel	doc_532115409106_item	2683245	et	4	main
peavad	doc_532115409106_item	2683250	et	4	main
nad	doc_532115409106_item	2683251	et	3	main
kõike	doc_532115409106_item	2683252	et	4	main
on	doc_532115409106_item	2683265	et	4	main
tööta	doc_532115409106_item	2683274	et	4	main
eesti	doc_532115409107_item	2683280	et	4	main
keeles	doc_532115409107_item	2683281	et	4	main
ma	doc_532115409107_item	2683282	et	3	main
on	doc_532115409107_item	2683286	et	4	main
elame	doc_532115409107_item	2683297	et	3	main
ja	doc_532115409107_item	2683299	et	3	main
anna	doc_532115409107_item	2683304	et	4	main
teemal	doc_532115409107_item	2683308	et	3	main
on	doc_532115409107_item	2683309	et	4	main
kergem	doc_532115409107_item	2683317	et	4	main
oppida	doc_532115409107_item	2683318	et	4	main
jääda	doc_532115409106_item	2683158	et	4	main
ei	doc_532115409106_item	2683159	et	4	main
võõrkeele	doc_532115409106_item	2683170	et	4	main
inglise	doc_532115409106_item	2683176	et	4	main
inglise	doc_532115409106_item	2683180	et	4	main
frantsuse	doc_532115409106_item	2683182	et	4	main
saksa	doc_532115409106_item	2683191	et	4	main
kus	doc_532115409106_item	2683193	et	3	main
süstemile	doc_532115409106_item	2683204	et	4	main
kus	doc_532115409106_item	2683205	et	3	main
mis	doc_532115409106_item	2683209	et	4	main
on	doc_532115409106_item	2683211	et	4	main
riigi	doc_532115409106_item	2683212	et	3	main
õppekava	doc_532115409106_item	2683213	et	4	main
õppetakse	doc_532115409106_item	2683214	et	3	main
ja	doc_532115409106_item	2683215	et	3	main
kõikede	doc_532115409106_item	2683216	et	4	main
ei	doc_532115409106_item	2683230	et	4	main
tunnusta	doc_532115409106_item	2683231	et	4	main
et	doc_532115409106_item	2683232	et	3	main
leian	doc_532115409106_item	2683237	et	3	main
järgi	doc_532115409106_item	2683248	et	4	main
öö	doc_532115409106_item	2683268	et	4	main
kool	doc_532115409107_item	2683279	et	4	main
täis	doc_532115409107_item	2683287	et	4	main
õigus	doc_532115409107_item	2683288	et	4	main
vene	doc_532115409107_item	2683290	et	4	main
õpilased	doc_532115409107_item	2683291	et	3	main
eesti	doc_532115409107_item	2683292	et	4	main
eestis	doc_532115409107_item	2683298	et	3	main
vene	doc_532115409107_item	2683305	et	4	main
sellel	doc_532115409107_item	2683307	et	4	main
pärast	doc_532115409107_item	2683312	et	4	main
kooli	doc_532115409107_item	2683314	et	4	main
lõpetamist	doc_532115409107_item	2683315	et	4	main
töökoha	doc_532115409107_item	2683323	et	4	main
aga	doc_532115409107_item	2683325	et	3	main
õpetajaid	doc_532115409107_item	2683333	et	4	main
saa	doc_532115409107_item	2683340	et	4	main
kujutada	doc_532115409107_item	2683342	et	3	main
mida	doc_532115409107_item	2683343	et	4	main
õpelased	doc_532115409107_item	2683349	et	4	main
asi	doc_532115409107_item	2683354	et	4	main
et	doc_532115409107_item	2683357	et	3	main
viib	doc_532115409107_item	2683362	et	3	main
minu	doc_532115409107_item	2683386	et	3	main
on	doc_532115409107_item	2683390	et	4	main
teha	doc_532115409107_item	2683392	et	3	main
hakkavad	doc_532115409107_item	2683397	et	4	main
lapsed	doc_532115409107_item	2683399	et	3	main
on	doc_532115409107_item	2683401	et	4	main
mitte	doc_532115409107_item	2683402	et	3	main
vanem	doc_532115409107_item	2683403	et	4	main
kui	doc_532115409107_item	2683404	et	3	main
kool	doc_532115409108_item	2683417	et	4	main
kooli	doc_532115409108_item	2683433	et	4	main
õpetajad	doc_532115409108_item	2683434	et	4	main
ja	doc_532115409108_item	2683445	et	3	main
on	doc_532115409108_item	2683446	et	4	main
valmis	doc_532115409108_item	2683447	et	4	main
muutusteks	doc_532115409108_item	2683448	et	4	main
kas	doc_532115409108_item	2683449	et	3	main
aastat	doc_532115409108_item	2683463	et	3	main
seaduse	doc_532115409108_item	2683466	et	3	main
muutus	doc_532115409108_item	2683468	et	4	main
maailma	doc_532115409108_item	2683469	et	4	main
skandaaliks	doc_532115409108_item	2683470	et	3	main
sest	doc_532115409108_item	2683471	et	4	main
protest	doc_532115409108_item	2683472	et	3	main
minu	doc_532115409108_item	2683480	et	3	main
juhtub	doc_532115409108_item	2683483	et	3	main
lätis	doc_532115409108_item	2683486	et	4	main
riigis	doc_532115409108_item	2683488	et	3	main
emakeeles	doc_532115409108_item	2683503	et	4	main
kooli	doc_532115409108_item	2683512	et	4	main
need	doc_532115409108_item	2683520	et	3	main
õpetajad	doc_532115409108_item	2683521	et	4	main
töötavad	doc_532115409108_item	2683523	et	4	main
koolis	doc_532115409108_item	2683524	et	4	main
muutused	doc_532115409108_item	2683532	et	4	main
toovad	doc_532115409108_item	2683533	et	4	main
siis	doc_532115409108_item	2683537	et	3	main
ained	doc_532115409106_item	2683194	et	3	main
saksa	doc_532115409106_item	2683196	et	4	main
miks	doc_532115409106_item	2683198	et	4	main
siis	doc_532115409106_item	2683199	et	3	main
mitte	doc_532115409106_item	2683200	et	3	main
ära	doc_532115409106_item	2683201	et	4	main
minna	doc_532115409106_item	2683202	et	3	main
otsustab	doc_532115409106_item	2683208	et	3	main
veel	doc_532115409106_item	2683221	et	4	main
süvaõppe	doc_532115409106_item	2683223	et	4	main
koolidbr	doc_532115409106_item	2683224	et	4	main
aga	doc_532115409106_item	2683225	et	3	main
riigikeel	doc_532115409106_item	2683233	et	4	main
ma	doc_532115409106_item	2683238	et	3	main
et	doc_532115409106_item	2683239	et	3	main
õpetaja	doc_532115409106_item	2683247	et	4	main
kaks	doc_532115409106_item	2683263	et	3	main
ilma	doc_532115409106_item	2683273	et	4	main
ei	doc_532115409106_item	2683276	et	4	main
taha	doc_532115409106_item	2683277	et	4	main
arvan	doc_532115409107_item	2683283	et	3	main
panna	doc_532115409107_item	2683289	et	4	main
me	doc_532115409107_item	2683296	et	4	main
siin	doc_532115409107_item	2683300	et	4	main
ei	doc_532115409107_item	2683301	et	4	main
näiteks	doc_532115409107_item	2683311	et	4	main
ülikoolis	doc_532115409107_item	2683319	et	4	main
ja	doc_532115409107_item	2683320	et	3	main
kergeminibr	doc_532115409107_item	2683324	et	4	main
ka	doc_532115409107_item	2683328	et	3	main
töid	doc_532115409107_item	2683336	et	3	main
ei	doc_532115409107_item	2683339	et	4	main
12	doc_532115409107_item	2683346	et	2	main
vene	doc_532115409107_item	2683348	et	4	main
veel	doc_532115409107_item	2683352	et	4	main
milleni	doc_532115409107_item	2683360	et	3	main
see	doc_532115409107_item	2683361	et	3	main
meeles	doc_532115409107_item	2683387	et	3	main
4	doc_532115409107_item	2683405	et	2	main
klass	doc_532115409107_item	2683406	et	3	main
aga	doc_532115409107_item	2683407	et	3	main
vanematesele	doc_532115409107_item	2683408	et	4	main
anna	doc_532115409107_item	2683410	et	4	main
kool	doc_532115409107_item	2683413	et	4	main
keeles	doc_532115409107_item	2683415	et	4	main
tahab	doc_532115409108_item	2683422	et	3	main
on	doc_532115409108_item	2683441	et	4	main
lätis	doc_532115409108_item	2683461	et	4	main
tagasi	doc_532115409108_item	2683464	et	3	main
ja	doc_532115409108_item	2683474	et	3	main
liiga	doc_532115409108_item	2683478	et	4	main
suur	doc_532115409108_item	2683479	et	3	main
eestis	doc_532115409108_item	2683482	et	3	main
haridust	doc_532115409108_item	2683502	et	4	main
vene	doc_532115409108_item	2683511	et	4	main
tööd	doc_532115409108_item	2683516	et	4	main
on	doc_532115409108_item	2683518	et	4	main
vene	doc_532115409106_item	2683222	et	4	main
on	doc_532115409106_item	2683234	et	4	main
läks	doc_532115409106_item	2683241	et	3	main
sest	doc_532115409106_item	2683249	et	4	main
oma	doc_532115409106_item	2683253	et	4	main
spetsifilist	doc_532115409106_item	2683254	et	4	main
sõnavara	doc_532115409106_item	2683255	et	4	main
teisestest	doc_532115409106_item	2683256	et	4	main
keelest	doc_532115409106_item	2683257	et	4	main
ära	doc_532115409106_item	2683258	et	4	main
õppeda	doc_532115409106_item	2683259	et	4	main
kuid	doc_532115409106_item	2683260	et	4	main
ka	doc_532115409106_item	2683261	et	3	main
need	doc_532115409106_item	2683262	et	3	main
keeled	doc_532115409106_item	2683264	et	3	main
erinev	doc_532115409106_item	2683266	et	4	main
nagu	doc_532115409106_item	2683267	et	3	main
ja	doc_532115409106_item	2683269	et	3	main
päev	doc_532115409106_item	2683270	et	3	main
kui	doc_532115409106_item	2683271	et	3	main
nad	doc_532115409106_item	2683272	et	3	main
saada	doc_532115409106_item	2683275	et	4	main
valitsusel	doc_532115409107_item	2683285	et	4	main
õppima	doc_532115409107_item	2683294	et	3	main
sest	doc_532115409107_item	2683295	et	4	main
ole	doc_532115409107_item	2683302	et	4	main
plusse	doc_532115409107_item	2683310	et	3	main
eesti	doc_532115409107_item	2683313	et	4	main
vene	doc_532115409107_item	2683331	et	4	main
keelse	doc_532115409107_item	2683332	et	3	main
oma	doc_532115409107_item	2683335	et	4	main
2007	doc_532115409107_item	2683350	et	2	main
üks	doc_532115409107_item	2683353	et	3	main
on	doc_532115409107_item	2683355	et	4	main
see	doc_532115409107_item	2683356	et	3	main
võib	doc_532115409107_item	2683363	et	3	main
keeles	doc_532115409107_item	2683396	et	4	main
kes	doc_532115409107_item	2683400	et	4	main
võimalust	doc_532115409107_item	2683411	et	3	main
2007	doc_532115409108_item	2683421	et	2	main
valitsus	doc_532115409108_item	2683424	et	4	main
seda	doc_532115409108_item	2683442	et	3	main
juba	doc_532115409108_item	2683443	et	3	main
lõpetanud	doc_532115409108_item	2683444	et	4	main
see	doc_532115409108_item	2683451	et	3	main
oli	doc_532115409108_item	2683458	et	3	main
nabririigis	doc_532115409108_item	2683460	et	4	main
õpilaste	doc_532115409108_item	2683473	et	4	main
venelasi	doc_532115409108_item	2683492	et	3	main
ja	doc_532115409108_item	2683493	et	3	main
igaüks	doc_532115409108_item	2683494	et	3	main
tahab	doc_532115409108_item	2683495	et	3	main
õpetajatest	doc_532115409108_item	2683513	et	4	main
võib	doc_532115409108_item	2683514	et	3	main
kaotada	doc_532115409108_item	2683517	et	3	main
ka	doc_532115409108_item	2683519	et	3	main
rohkem	doc_532115409108_item	2683525	et	4	main
kui	doc_532115409108_item	2683526	et	3	main
kakskümmend	doc_532115409108_item	2683527	et	4	main
aastat	doc_532115409108_item	2683528	et	3	main
jä	doc_532115409108_item	2683529	et	4	main
nii	doc_532115409108_item	2683530	et	3	main
muutma	doc_532115409108_item	2683538	et	3	main
meeldib	doc_532115409108_item	2683541	et	3	main
igal	doc_532115409108_item	2683543	et	3	main
rahval	doc_532115409108_item	2683544	et	3	main
võtmist	doc_532115409108_item	2683560	et	4	main
ka	doc_532115409108_item	2683563	et	3	main
mõnikord	doc_532115409108_item	2683566	et	3	main
kasuta	doc_532115409108_item	2683575	et	4	main
seda	doc_532115409108_item	2683576	et	3	main
aga	doc_532115409108_item	2683577	et	3	main
on	doc_532115409108_item	2683580	et	4	main
seadus	doc_532115409108_item	2683591	et	4	main
praegu	doc_532115409108_item	2683596	et	3	main
27072006	doc_534729444675_item	2683602	et	2	main
kell	doc_534729444675_item	2683605	et	3	main
oli	doc_534729444675_item	2683608	et	3	main
pudru	doc_534729444675_item	2683613	et	3	main
mulle	doc_534729444675_item	2683617	et	4	main
maitses	doc_534729444675_item	2683622	et	4	main
pühtitsasse	doc_534729444675_item	2683632	et	4	main
ja	doc_534729444675_item	2683633	et	3	main
siis	doc_534729444675_item	2683634	et	3	main
peipsi	doc_534729444675_item	2683635	et	4	main
huvitav	doc_534729444675_item	2683639	et	4	main
ei	doc_534729444675_item	2683642	et	4	main
elada	doc_534729444675_item	2683644	et	3	main
ma	doc_534729444675_item	2683646	et	3	main
halb	doc_534729444675_item	2683648	et	3	main
väikes	doc_534729444675_item	2683655	et	4	main
unustanud	doc_534729444675_item	2683659	et	4	main
jalutama	doc_534729444675_item	2683675	et	3	main
leiab	doc_532115409107_item	2683322	et	3	main
on	doc_532115409107_item	2683327	et	4	main
kaotavad	doc_532115409107_item	2683334	et	4	main
peavad	doc_532115409107_item	2683344	et	4	main
teha	doc_532115409107_item	2683345	et	3	main
klassi	doc_532115409107_item	2683347	et	4	main
pole	doc_532115409107_item	2683358	et	3	main
olla	doc_532115409107_item	2683364	et	3	main
hakkavad	doc_532115409107_item	2683366	et	4	main
estlaseid	doc_532115409107_item	2683367	et	4	main
vihkama	doc_532115409107_item	2683368	et	3	main
ja	doc_532115409107_item	2683369	et	3	main
korraldama	doc_532115409107_item	2683370	et	3	main
mingi	doc_532115409107_item	2683371	et	4	main
negatiivse	doc_532115409107_item	2683372	et	3	main
häälestatud	doc_532115409107_item	2683373	et	4	main
organizatsioone	doc_532115409107_item	2683374	et	4	main
aga	doc_532115409107_item	2683375	et	3	main
võib	doc_532115409107_item	2683376	et	3	main
olla	doc_532115409107_item	2683377	et	3	main
eestlased	doc_532115409107_item	2683378	et	3	main
ja	doc_532115409107_item	2683379	et	3	main
venelased	doc_532115409107_item	2683380	et	3	main
hakkavad	doc_532115409107_item	2683381	et	4	main
elama	doc_532115409107_item	2683382	et	3	main
nägu	doc_532115409107_item	2683383	et	4	main
üks	doc_532115409107_item	2683384	et	3	main
rahvus	doc_532115409107_item	2683385	et	3	main
aastal	doc_532115409107_item	2683389	et	3	main
vaja	doc_532115409107_item	2683391	et	4	main
nii	doc_532115409107_item	2683393	et	3	main
eesti	doc_532115409107_item	2683395	et	4	main
klassidestele	doc_532115409107_item	2683409	et	4	main
vene	doc_532115409108_item	2683416	et	4	main
kooli	doc_532115409108_item	2683427	et	4	main
õppekeelt	doc_532115409108_item	2683428	et	4	main
eesti	doc_532115409108_item	2683429	et	4	main
keeleks	doc_532115409108_item	2683430	et	4	main
kõik	doc_532115409108_item	2683431	et	4	main
käivad	doc_532115409108_item	2683435	et	4	main
praegu	doc_532115409108_item	2683436	et	3	main
eesti	doc_532115409108_item	2683437	et	4	main
meie	doc_532115409108_item	2683459	et	4	main
mitu	doc_532115409108_item	2683462	et	4	main
järjekordne	doc_532115409108_item	2683465	et	3	main
muutus	doc_532115409108_item	2683467	et	4	main
poolt	doc_532115409108_item	2683476	et	4	main
mis	doc_532115409108_item	2683485	et	4	main
on	doc_532115409108_item	2683489	et	4	main
hästi	doc_532115409108_item	2683490	et	3	main
palju	doc_532115409108_item	2683491	et	4	main
kas	doc_532115409108_item	2683496	et	3	main
või	doc_532115409108_item	2683498	et	4	main
teine	doc_532115409108_item	2683504	et	3	main
asi	doc_532115409108_item	2683505	et	4	main
on	doc_532115409108_item	2683506	et	4	main
see	doc_532115409108_item	2683507	et	3	main
pigem	doc_532115409108_item	2683515	et	3	main
peavalut	doc_532115409108_item	2683535	et	4	main
asja	doc_532115409108_item	2683539	et	4	main
kõikile	doc_532115409108_item	2683542	et	4	main
on	doc_532115409108_item	2683545	et	4	main
olen	doc_532115409108_item	2683562	et	3	main
ei	doc_532115409108_item	2683574	et	4	main
teised	doc_532115409108_item	2683581	et	4	main
seda	doc_532115409108_item	2683583	et	3	main
lahendama	doc_532115409108_item	2683585	et	3	main
ole	doc_532115409108_item	2683593	et	4	main
leiba	doc_534729444675_item	2683614	et	4	main
inimesedele	doc_534729444675_item	2683620	et	4	main
üheksa	doc_534729444675_item	2683628	et	4	main
meie	doc_534729444675_item	2683629	et	4	main
oli	doc_534729444675_item	2683638	et	3	main
seal	doc_534729444675_item	2683645	et	4	main
olen	doc_534729444675_item	2683658	et	3	main
kesklinnas	doc_534729444675_item	2683671	et	4	main
ma	doc_534729444675_item	2683672	et	3	main
emaga	doc_534729444675_item	2683673	et	3	main
läksin	doc_534729444675_item	2683674	et	3	main
palju	doc_534729444675_item	2683681	et	4	main
kaunis	doc_534729444675_item	2683682	et	4	main
kohvidega	doc_534729444675_item	2683683	et	3	main
eestis	doc_534729444675_item	2683684	et	3	main
eesti	doc_532115409108_item	2683423	et	4	main
muuta	doc_532115409108_item	2683425	et	4	main
vene	doc_532115409108_item	2683426	et	4	main
vene	doc_532115409108_item	2683432	et	4	main
keele	doc_532115409108_item	2683438	et	4	main
kursustele	doc_532115409108_item	2683439	et	3	main
mõned	doc_532115409108_item	2683440	et	3	main
on	doc_532115409108_item	2683450	et	4	main
valitsuse	doc_532115409108_item	2683452	et	4	main
idee	doc_532115409108_item	2683453	et	4	main
hea	doc_532115409108_item	2683454	et	4	main
mõte	doc_532115409108_item	2683455	et	3	main
sama	doc_532115409108_item	2683456	et	4	main
situatsioon	doc_532115409108_item	2683457	et	3	main
õpetajate	doc_532115409108_item	2683475	et	4	main
oli	doc_532115409108_item	2683477	et	3	main
arvates	doc_532115409108_item	2683481	et	4	main
sama	doc_532115409108_item	2683484	et	4	main
meie	doc_532115409108_item	2683487	et	4	main
endale	doc_532115409108_item	2683497	et	4	main
oma	doc_532115409108_item	2683499	et	4	main
lastele	doc_532115409108_item	2683500	et	4	main
andma	doc_532115409108_item	2683501	et	3	main
et	doc_532115409108_item	2683508	et	3	main
suur	doc_532115409108_item	2683509	et	3	main
osa	doc_532115409108_item	2683510	et	4	main
neile	doc_532115409108_item	2683534	et	4	main
enne	doc_532115409108_item	2683557	et	4	main
seaduse	doc_532115409108_item	2683558	et	3	main
vastu	doc_532115409108_item	2683559	et	3	main
ei	doc_532115409108_item	2683569	et	4	main
keelt	doc_532115409108_item	2683572	et	4	main
minu	doc_532115409108_item	2683587	et	3	main
õpimiskeele	doc_532115409108_item	2683590	et	4	main
ei	doc_532115409108_item	2683592	et	4	main
vaid	doc_532115409108_item	2683597	et	3	main
ärkasin	doc_534729444675_item	2683604	et	3	main
hommikusöök	doc_534729444675_item	2683607	et	3	main
kaheksa	doc_534729444675_item	2683610	et	4	main
putru	doc_534729444675_item	2683623	et	4	main
grupp	doc_534729444675_item	2683624	et	3	main
lahkusid	doc_534729444675_item	2683625	et	4	main
hotell	doc_534729444675_item	2683626	et	3	main
kell	doc_534729444675_item	2683627	et	3	main
järvele	doc_534729444675_item	2683636	et	4	main
tahaksi	doc_534729444675_item	2683643	et	4	main
nunn	doc_534729444675_item	2683649	et	3	main
peipsi	doc_534729444675_item	2683650	et	4	main
ma	doc_534729444675_item	2683657	et	3	main
me	doc_534729444675_item	2683663	et	4	main
kesklinnas	doc_534729444675_item	2683676	et	4	main
ei	doc_534729444678_item	2683931	et	4	main
meeldi	doc_534729444678_item	2683932	et	4	main
jumalateenistust	doc_534729444678_item	2683933	et	3	main
usun	doc_534729444678_item	2683950	et	3	main
kesklinnas	doc_534729444678_item	2683966	et	4	main
ja	doc_534729444678_item	2683967	et	3	main
ja	doc_534729444678_item	2683971	et	3	main
veel	doc_534729444678_item	2683978	et	4	main
soovisin	doc_534729444678_item	2683979	et	4	main
kes	doc_532115409108_item	2683522	et	4	main
suured	doc_532115409108_item	2683531	et	3	main
miks	doc_532115409108_item	2683536	et	4	main
õigus	doc_532115409108_item	2683546	et	4	main
emakeeles	doc_532115409108_item	2683547	et	4	main
hariduse	doc_532115409108_item	2683548	et	3	main
saamiseks	doc_532115409108_item	2683549	et	4	main
ja	doc_532115409108_item	2683550	et	3	main
mis	doc_532115409108_item	2683540	et	4	main
valitsus	doc_532115409108_item	2683552	et	4	main
jah	doc_532115409108_item	2683561	et	3	main
et	doc_532115409108_item	2683565	et	3	main
õpi	doc_532115409108_item	2683570	et	4	main
minu	doc_532115409108_item	2683578	et	3	main
võimalused	doc_532115409108_item	2683582	et	3	main
situatsiooni	doc_532115409108_item	2683584	et	4	main
p	doc_532115409108_item	2683586	et	4	main
arvates	doc_532115409108_item	2683588	et	4	main
see	doc_532115409108_item	2683589	et	3	main
vajalik	doc_532115409108_item	2683595	et	3	main
ültse	doc_532115409108_item	2683598	et	4	main
sõime	doc_534729444675_item	2683612	et	4	main
jogurtit	doc_534729444675_item	2683616	et	3	main
maitses	doc_534729444675_item	2683618	et	4	main
agapalju	doc_534729444675_item	2683619	et	4	main
eesti	doc_532115409108_item	2683551	et	4	main
peab	doc_532115409108_item	2683553	et	4	main
seda	doc_532115409108_item	2683554	et	3	main
läbi	doc_532115409108_item	2683555	et	4	main
mõelda	doc_532115409108_item	2683556	et	4	main
nõus	doc_532115409108_item	2683564	et	4	main
vene	doc_532115409108_item	2683567	et	4	main
seltskond	doc_532115409108_item	2683568	et	3	main
eesti	doc_532115409108_item	2683571	et	4	main
või	doc_532115409108_item	2683573	et	4	main
arvates	doc_532115409108_item	2683579	et	4	main
nii	doc_532115409108_item	2683594	et	3	main
mite	doc_532115409108_item	2683599	et	4	main
vajalikud	doc_532115409108_item	2683600	et	3	main
päevik	doc_534729444675_item	2683601	et	3	main
ma	doc_534729444675_item	2683603	et	3	main
seitse	doc_534729444675_item	2683606	et	3	main
kell	doc_534729444675_item	2683609	et	3	main
me	doc_534729444675_item	2683611	et	4	main
ja	doc_534729444675_item	2683615	et	3	main
ei	doc_534729444675_item	2683621	et	4	main
reis	doc_534729444675_item	2683630	et	4	main
jätkusis	doc_534729444675_item	2683631	et	4	main
aga	doc_534729444675_item	2683640	et	3	main
oliksin	doc_534729444675_item	2683647	et	4	main
järve	doc_534729444675_item	2683651	et	4	main
ääres	doc_534729444675_item	2683652	et	4	main
me	doc_534729444675_item	2683653	et	4	main
olime	doc_534729444675_item	2683654	et	3	main
nimi	doc_534729444675_item	2683660	et	3	main
viis	doc_534729444675_item	2683662	et	4	main
seal	doc_534729444675_item	2683666	et	4	main
me	doc_534729444675_item	2683667	et	4	main
elame	doc_534729444675_item	2683668	et	3	main
hotellis	doc_534729444675_item	2683669	et	3	main
varsti	doc_534729444675_item	2683670	et	3	main
kaunis	doc_534729444675_item	2683679	et	4	main
linn	doc_534729444675_item	2683680	et	3	main
pühtitsa	doc_534729444675_item	2683637	et	4	main
ma	doc_534729444675_item	2683641	et	3	main
linnas	doc_534729444675_item	2683656	et	4	main
kell	doc_534729444675_item	2683661	et	3	main
saabusime	doc_534729444675_item	2683664	et	3	main
tartusse	doc_534729444675_item	2683665	et	3	main
tartu	doc_534729444675_item	2683677	et	4	main
on	doc_534729444675_item	2683678	et	4	main
me	doc_534729444675_item	2683685	et	4	main
näeme	doc_534729444675_item	2683686	et	3	main
palju	doc_534729444675_item	2683687	et	4	main
aga	doc_534729444675_item	2683688	et	3	main
igal	doc_534729444675_item	2683689	et	3	main
õhtul	doc_534729444675_item	2683690	et	3	main
ma	doc_534729444675_item	2683691	et	3	main
olen	doc_534729444675_item	2683692	et	3	main
väsinud	doc_534729444675_item	2683693	et	4	main
saamuti	doc_534729444675_item	2683694	et	4	main
täna	doc_534729444675_item	2683695	et	4	main
õhtul	doc_534729444675_item	2683696	et	3	main
sellepärast	doc_534729444675_item	2683697	et	3	main
ma	doc_534729444675_item	2683698	et	3	main
lähen	doc_534729444675_item	2683699	et	3	main
magama	doc_534729444675_item	2683700	et	3	main
päevik	doc_534729444678_item	2683911	et	3	main
aru	doc_534729444678_item	2683922	et	4	main
saksamaal	doc_534729444678_item	2683934	et	4	main
jumalteenistuse	doc_534729444678_item	2683935	et	4	main
saksa	doc_534729444678_item	2683938	et	4	main
huvitav	doc_534729444678_item	2683941	et	4	main
aga	doc_534729444678_item	2683942	et	3	main
sellepärast	doc_534729444678_item	2683943	et	3	main
me	doc_534729444678_item	2683944	et	4	main
pidime	doc_534729444678_item	2683945	et	3	main
külastada	doc_534729444678_item	2683946	et	3	main
veel	doc_534729444678_item	2683947	et	4	main
kirikute	doc_534729444678_item	2683955	et	4	main
me	doc_534729444678_item	2683968	et	4	main
sõitsime	doc_534729444678_item	2683969	et	3	main
lauluväljukule	doc_534729444678_item	2683970	et	4	main
eesnimi	doc_534729444678_item	2683972	et	3	main
lugu	doc_534729444678_item	2683975	et	4	main
me	doc_534729444678_item	2683977	et	4	main
30072006	doc_534729444678_item	2683912	et	2	main
saanud	doc_534729444678_item	2683921	et	4	main
väha	doc_534729444678_item	2683923	et	4	main
aga	doc_534729444678_item	2683924	et	3	main
teisele	doc_534729444678_item	2683925	et	4	main
see	doc_534729444678_item	2683926	et	3	main
oli	doc_534729444678_item	2683927	et	3	main
kindlasti	doc_534729444678_item	2683928	et	3	main
igav	doc_534729444678_item	2683929	et	3	main
emale	doc_534729444678_item	2683930	et	3	main
pärast	doc_534729444678_item	2683936	et	4	main
suursaatkonnas	doc_534729444678_item	2683939	et	4	main
kirikute	doc_534729444678_item	2683948	et	4	main
ma	doc_534729444678_item	2683949	et	3	main
kõike	doc_534729444678_item	2683954	et	4	main
ainult	doc_534729444678_item	2683958	et	4	main
ostada	doc_534729444678_item	2683980	et	4	main
suveniirid	doc_534729444678_item	2683981	et	3	main
veel	doc_534729444678_item	2683984	et	4	main
ja	doc_534729444678_item	2683998	et	3	main
oli	doc_534729444678_item	2684000	et	3	main
kaneeliõlu	doc_534729444678_item	2684002	et	3	main
oli	doc_534729444679_item	2684008	et	3	main
meie	doc_534729444679_item	2684009	et	4	main
oli	doc_534729444679_item	2684024	et	3	main
lõunasöögile	doc_534729444679_item	2684026	et	3	main
väga	doc_534729444679_item	2684031	et	3	main
usun	doc_534729444679_item	2684042	et	3	main
eestis	doc_534729444679_item	2684044	et	3	main
nüüd	doc_534729444679_item	2684046	et	4	main
külm	doc_534729444679_item	2684054	et	3	main
kuna	doc_534729444679_item	2684063	et	3	main
ostanud	doc_534729444679_item	2684066	et	4	main
jaki	doc_534729444679_item	2684068	et	3	main
mul	doc_534729444679_item	2684073	et	3	main
kena	doc_534729444679_item	2684075	et	4	main
olen	doc_534729444679_item	2684079	et	3	main
ärkasin	doc_534729444678_item	2683913	et	3	main
kell	doc_534729444678_item	2683914	et	3	main
seitse	doc_534729444678_item	2683915	et	3	main
me	doc_534729444678_item	2683916	et	4	main
läksime	doc_534729444678_item	2683917	et	3	main
jumalateenistusse	doc_534729444678_item	2683918	et	3	main
ma	doc_534729444678_item	2683919	et	3	main
on	doc_534729444678_item	2683920	et	4	main
olime	doc_534729444678_item	2683937	et	3	main
oli	doc_534729444678_item	2683940	et	3	main
et	doc_534729444678_item	2683951	et	3	main
ma	doc_534729444678_item	2683952	et	3	main
ma	doc_534729444678_item	2683957	et	3	main
šoppima	doc_534729444678_item	2683960	et	2	main
aga	doc_534729444678_item	2683961	et	3	main
oli	doc_534729444678_item	2683963	et	3	main
veel	doc_534729444678_item	2683964	et	4	main
lauluväljuku	doc_534729444678_item	2683974	et	4	main
ja	doc_534729444678_item	2683982	et	3	main
olde	doc_534729444678_item	2683991	et	4	main
oli	doc_534729444678_item	2683994	et	3	main
mulle	doc_534729444678_item	2684003	et	4	main
täna	doc_534729444679_item	2684007	et	4	main
päev	doc_534729444679_item	2684011	et	3	main
vabaõhumuseumisse	doc_534729444679_item	2684015	et	4	main
meeldis	doc_534729444679_item	2684017	et	3	main
nii	doc_534729444679_item	2684021	et	3	main
meile	doc_534729444679_item	2684030	et	4	main
ma	doc_534729444679_item	2684033	et	3	main
ostasin	doc_534729444679_item	2684035	et	4	main
olnud	doc_534729444679_item	2684051	et	4	main
aga	doc_534729444679_item	2684058	et	3	main
ei	doc_534729444679_item	2684060	et	4	main
olnud	doc_534729444679_item	2684061	et	4	main
aega	doc_534729444679_item	2684076	et	4	main
näenud	doc_534729444679_item	2684080	et	4	main
ja	doc_534729444679_item	2684082	et	3	main
olen	doc_534729444679_item	2684083	et	3	main
ostanud	doc_534729444679_item	2684084	et	4	main
ja	doc_534729444679_item	2684085	et	3	main
nägin	doc_534729444678_item	2683953	et	3	main
eestis	doc_534729444678_item	2683956	et	3	main
tahtsin	doc_534729444678_item	2683959	et	3	main
meil	doc_534729444678_item	2683962	et	4	main
juhtimine	doc_534729444678_item	2683965	et	4	main
jutustasin	doc_534729444678_item	2683973	et	3	main
sellepärast	doc_534729444678_item	2683976	et	3	main
läksime	doc_534729444678_item	2683983	et	3	main
me	doc_534729444678_item	2683989	et	4	main
meil	doc_534729444678_item	2683993	et	4	main
väga	doc_534729444678_item	2683995	et	3	main
31072006	doc_534729444679_item	2684006	et	2	main
me	doc_534729444679_item	2684013	et	4	main
mulle	doc_534729444679_item	2684016	et	4	main
et	doc_534729444679_item	2684018	et	3	main
meri	doc_534729444679_item	2684019	et	3	main
on	doc_534729444679_item	2684020	et	4	main
maitses	doc_534729444679_item	2684032	et	4	main
ka	doc_534729444679_item	2684034	et	3	main
veini	doc_534729444679_item	2684036	et	4	main
mustsõstuveini	doc_534729444679_item	2684037	et	4	main
ja	doc_534729444679_item	2684038	et	3	main
on	doc_534729444679_item	2684045	et	4	main
sügis	doc_534729444679_item	2684047	et	3	main
ei	doc_534729444679_item	2684050	et	4	main
varem	doc_534729444679_item	2684053	et	4	main
olen	doc_534729444679_item	2684065	et	3	main
uue	doc_534729444679_item	2684067	et	3	main
homme	doc_534729444679_item	2684069	et	3	main
oli	doc_534729444679_item	2684074	et	3	main
palju	doc_534729444679_item	2684081	et	4	main
söönud	doc_534729444679_item	2684086	et	4	main
kord	doc_534729444678_item	2683985	et	4	main
sõime	doc_534729444678_item	2683990	et	4	main
hansas	doc_534729444678_item	2683992	et	3	main
maitses	doc_534729444678_item	2684004	et	4	main
viimne	doc_534729444679_item	2684010	et	3	main
eestis	doc_534729444679_item	2684012	et	3	main
peatne	doc_534729444679_item	2684022	et	3	main
sõime	doc_534729444679_item	2684028	et	4	main
hapukapsasuppi	doc_534729444679_item	2684029	et	4	main
ma	doc_534729444679_item	2684041	et	3	main
täna	doc_534729444679_item	2684048	et	4	main
ilm	doc_534729444679_item	2684049	et	3	main
eriti	doc_534729444679_item	2684055	et	3	main
ääres	doc_534729444679_item	2684057	et	4	main
ma	doc_534729444679_item	2684064	et	3	main
me	doc_534729444679_item	2684070	et	4	main
eestis	doc_534729444679_item	2684077	et	3	main
palju	doc_534729444679_item	2684087	et	4	main
ka	doc_534729444679_item	2684088	et	3	main
kesklinnasse	doc_534729444678_item	2683986	et	4	main
täna	doc_534729444678_item	2683987	et	4	main
õhtul	doc_534729444678_item	2683988	et	3	main
hästi	doc_534729444678_item	2683996	et	3	main
sööki	doc_534729444678_item	2683997	et	4	main
ümbrus	doc_534729444678_item	2683999	et	3	main
imeilus	doc_534729444678_item	2684001	et	4	main
päevik	doc_534729444679_item	2684005	et	3	main
sõitsime	doc_534729444679_item	2684014	et	3	main
museumis	doc_534729444679_item	2684023	et	4	main
vaikne	doc_534729444679_item	2684025	et	3	main
me	doc_534729444679_item	2684027	et	4	main
kaks	doc_534729444679_item	2684039	et	3	main
küünalde	doc_534729444679_item	2684040	et	3	main
et	doc_534729444679_item	2684043	et	3	main
soe	doc_534729444679_item	2684052	et	4	main
meri	doc_534729444679_item	2684056	et	3	main
see	doc_534729444679_item	2684059	et	3	main
probleem	doc_534729444679_item	2684062	et	3	main
lendame	doc_534729444679_item	2684071	et	3	main
berliinisse	doc_534729444679_item	2684072	et	4	main
ja	doc_534729444679_item	2684078	et	3	main
viisin	doc_534729444686_item	2684822	et	3	main
mahutile	doc_534729444686_item	2684825	et	3	main
algul	doc_534729444686_item	2684826	et	4	main
pagarile	doc_534729444686_item	2684838	et	3	main
hiljem	doc_534729444686_item	2684847	et	3	main
raamatus	doc_534729444686_item	2684850	et	4	main
kirjaliku	doc_534729444686_item	2684851	et	3	main
semiaritöö	doc_534729444686_item	2684852	et	4	main
kuus	doc_534729444686_item	2684855	et	4	main
väga	doc_534729444686_item	2684859	et	3	main
vahtisin	doc_534729444686_item	2684863	et	3	main
kord	doc_534729444686_item	2684865	et	4	main
filmi	doc_534729444686_item	2684866	et	4	main
olen	doc_534729444686_item	2684877	et	3	main
ja	doc_534729444686_item	2684880	et	3	main
voodisse	doc_534729444686_item	2684882	et	3	main
25juuli	doc_534729444688_item	2684981	et	4	main
hommikusöök	doc_534729444688_item	2684987	et	3	main
mina	doc_534729444688_item	2684990	et	4	main
paddingtonisse	doc_534729444688_item	2684996	et	4	main
londonilt	doc_534729444688_item	2685005	et	4	main
linna	doc_534729444688_item	2685007	et	4	main
on	doc_534729444688_item	2685008	et	4	main
kaua	doc_534729444688_item	2685030	et	3	main
läbi	doc_534729444688_item	2685033	et	4	main
linnas	doc_534729444688_item	2685035	et	4	main
otsime	doc_534729444688_item	2685037	et	4	main
mõnikord	doc_534729444688_item	2685038	et	3	main
päevik	doc_534729444686_item	2684800	et	3	main
täna	doc_534729444686_item	2684802	et	4	main
on	doc_534729444686_item	2684803	et	4	main
pühapäev	doc_534729444686_item	2684804	et	3	main
ostma	doc_534729444686_item	2684839	et	3	main
pärast	doc_534729444686_item	2684841	et	4	main
ma	doc_534729444686_item	2684843	et	3	main
vahtisin	doc_534729444686_item	2684844	et	3	main
üks	doc_534729444686_item	2684845	et	3	main
film	doc_534729444686_item	2684846	et	3	main
lugesin	doc_534729444686_item	2684849	et	3	main
ma	doc_534729444686_item	2684856	et	3	main
kaua	doc_534729444686_item	2684860	et	3	main
veel	doc_534729444686_item	2684870	et	4	main
kord	doc_534729444686_item	2684871	et	4	main
pargi	doc_534729444686_item	2684874	et	4	main
pesnud	doc_534729444686_item	2684879	et	4	main
heitsin	doc_534729444686_item	2684881	et	3	main
eesnimi	doc_534729444688_item	2684988	et	3	main
läksime	doc_534729444688_item	2684991	et	3	main
rongiga	doc_534729444688_item	2684995	et	4	main
on	doc_534729444688_item	2685003	et	4	main
täis	doc_534729444688_item	2685019	et	4	main
ja	doc_534729444688_item	2685021	et	3	main
me	doc_534729444688_item	2685051	et	4	main
sõitsime	doc_534729444688_item	2685052	et	3	main
seda	doc_534729444688_item	2685059	et	3	main
magasime	doc_534729444688_item	2685071	et	3	main
parg	doc_534729444688_item	2685089	et	4	main
oli	doc_534729444688_item	2685090	et	3	main
juba	doc_534729444688_item	2685091	et	3	main
kinni	doc_534729444688_item	2685092	et	3	main
seega	doc_534729444688_item	2685093	et	4	main
liiga	doc_534729444688_item	2685101	et	4	main
me	doc_534729444688_item	2685104	et	4	main
me	doc_534729444688_item	2685110	et	4	main
jalutasime	doc_534729444688_item	2685111	et	3	main
200806	doc_534729444686_item	2684801	et	2	main
ja	doc_534729444686_item	2684805	et	3	main
ma	doc_534729444686_item	2684806	et	3	main
jäin	doc_534729444686_item	2684807	et	3	main
kauaks	doc_534729444686_item	2684808	et	3	main
voodisse	doc_534729444686_item	2684809	et	3	main
kell	doc_534729444686_item	2684810	et	3	main
kümme	doc_534729444686_item	2684811	et	3	main
ma	doc_534729444686_item	2684812	et	3	main
tõusin	doc_534729444686_item	2684813	et	3	main
üles	doc_534729444686_item	2684814	et	3	main
ja	doc_534729444686_item	2684815	et	3	main
ma	doc_534729444686_item	2684816	et	3	main
läksin	doc_534729444686_item	2684817	et	3	main
xxxga	doc_534729444686_item	2684818	et	4	main
läbi	doc_534729444686_item	2684819	et	4	main
pargi	doc_534729444686_item	2684820	et	4	main
ajalehtesid	doc_534729444686_item	2684824	et	3	main
duši	doc_534729444686_item	2684834	et	2	main
läksin	doc_534729444686_item	2684837	et	3	main
jaoks	doc_534729444686_item	2684853	et	4	main
kesköö	doc_534729444686_item	2684867	et	4	main
ma	doc_534729444686_item	2684868	et	3	main
läksin	doc_534729444686_item	2684869	et	3	main
läbi	doc_534729444686_item	2684873	et	4	main
hambaid	doc_534729444686_item	2684878	et	3	main
ma	doc_534729444686_item	2684821	et	3	main
vanu	doc_534729444686_item	2684823	et	4	main
ma	doc_534729444686_item	2684827	et	3	main
jooksin	doc_534729444686_item	2684828	et	4	main
üks	doc_534729444686_item	2684829	et	3	main
tundi	doc_534729444686_item	2684830	et	4	main
saiakesi	doc_534729444686_item	2684840	et	4	main
jalutasin	doc_534729444686_item	2684857	et	3	main
ma	doc_534729444686_item	2684862	et	3	main
ma	doc_534729444686_item	2684876	et	3	main
ja	doc_534729444688_item	2684985	et	3	main
maitsev	doc_534729444688_item	2684986	et	4	main
camden	doc_534729444688_item	2685006	et	4	main
hull	doc_534729444688_item	2685011	et	3	main
ja	doc_534729444688_item	2685014	et	3	main
palju	doc_534729444688_item	2685028	et	4	main
me	doc_534729444688_item	2685031	et	4	main
camden	doc_534729444688_item	2685034	et	4	main
ja	doc_534729444688_item	2685036	et	3	main
pluus	doc_534729444688_item	2685044	et	3	main
ja	doc_534729444688_item	2685055	et	3	main
asetasime	doc_534729444688_item	2685056	et	3	main
enne	doc_534729444688_item	2685058	et	4	main
otsime	doc_534729444688_item	2685061	et	4	main
meile	doc_534729444688_item	2685062	et	4	main
õlu	doc_534729444688_item	2685063	et	3	main
ja	doc_534729444688_item	2685064	et	3	main
raamatud	doc_534729444688_item	2685074	et	4	main
ja	doc_534729444688_item	2685076	et	3	main
me	doc_534729444688_item	2685094	et	4	main
lahti	doc_534729444688_item	2685097	et	4	main
pärast	doc_534729444688_item	2685099	et	4	main
tiomekas	doc_534729444688_item	2685117	et	4	main
londonis	doc_534729444688_item	2685119	et	4	main
jõudsime	doc_534729444688_item	2685122	et	3	main
koju	doc_534729444688_item	2685133	et	3	main
küsima	doc_534729444688_item	2685139	et	3	main
koju	doc_534729444688_item	2685143	et	3	main
üks	doc_534729444688_item	2685145	et	3	main
jõudsime	doc_534729444688_item	2685147	et	3	main
koju	doc_534729444688_item	2685148	et	3	main
me	doc_534729444688_item	2685150	et	4	main
kiiresti	doc_534729444688_item	2685155	et	3	main
juuli	doc_534729444689_item	2685161	et	4	main
kodus	doc_534729444686_item	2684831	et	4	main
ma	doc_534729444686_item	2684832	et	3	main
käisin	doc_534729444686_item	2684833	et	3	main
all	doc_534729444686_item	2684835	et	3	main
ja	doc_534729444686_item	2684836	et	3	main
hommikusööku	doc_534729444686_item	2684842	et	4	main
ma	doc_534729444686_item	2684848	et	3	main
kell	doc_534729444686_item	2684854	et	3	main
xxxga	doc_534729444686_item	2684858	et	4	main
õhtul	doc_534729444686_item	2684861	et	3	main
veel	doc_534729444686_item	2684864	et	4	main
xxxga	doc_534729444686_item	2684872	et	4	main
pärast	doc_534729444686_item	2684875	et	4	main
pärast	doc_534729444688_item	2684982	et	4	main
üks	doc_534729444688_item	2684983	et	3	main
hea	doc_534729444688_item	2684984	et	4	main
ja	doc_534729444688_item	2684989	et	3	main
kesklinnasse	doc_534729444688_item	2684992	et	4	main
me	doc_534729444688_item	2684993	et	4	main
sõitsime	doc_534729444688_item	2684994	et	3	main
siis	doc_534729444688_item	2684998	et	3	main
camden	doc_534729444688_item	2685000	et	4	main
linnasse	doc_534729444688_item	2685001	et	4	main
see	doc_534729444688_item	2685002	et	3	main
ilus	doc_534729444688_item	2685009	et	4	main
ja	doc_534729444688_item	2685010	et	3	main
kirju	doc_534729444688_item	2685013	et	4	main
hull	doc_534729444688_item	2685015	et	3	main
tänava	doc_534729444688_item	2685017	et	4	main
on	doc_534729444688_item	2685018	et	4	main
päevik	doc_534729444688_item	2684979	et	3	main
teisipäev	doc_534729444688_item	2684980	et	3	main
ja	doc_534729444688_item	2684997	et	3	main
metrooga	doc_534729444688_item	2684999	et	3	main
piirkond	doc_534729444688_item	2685004	et	3	main
piirkond	doc_534729444688_item	2685012	et	3	main
inimesedga	doc_534729444688_item	2685016	et	4	main
inimesedga	doc_534729444688_item	2685020	et	4	main
riidedga	doc_534729444688_item	2685023	et	4	main
liiga	doc_534729444688_item	2685029	et	4	main
nõrk	doc_534729444688_item	2685045	et	3	main
tagasi	doc_534729444688_item	2685054	et	3	main
me	doc_534729444688_item	2685060	et	4	main
šokolaadi	doc_534729444688_item	2685065	et	2	main
see	doc_534729444688_item	2685066	et	3	main
oli	doc_534729444688_item	2685067	et	3	main
väga	doc_534729444688_item	2685068	et	3	main
kallis	doc_534729444688_item	2685069	et	4	main
lugesime	doc_534729444688_item	2685073	et	3	main
pargis	doc_534729444688_item	2685075	et	3	main
vaatlesime	doc_534729444688_item	2685078	et	3	main
teise	doc_534729444688_item	2685079	et	4	main
kell	doc_534729444688_item	2685082	et	3	main
kolmverrand	doc_534729444688_item	2685083	et	4	main
kümme	doc_534729444688_item	2685084	et	3	main
me	doc_534729444688_item	2685085	et	4	main
läksime	doc_534729444688_item	2685086	et	3	main
koju	doc_534729444688_item	2685087	et	3	main
aga	doc_534729444688_item	2685088	et	3	main
kaua	doc_534729444688_item	2685102	et	3	main
otsing	doc_534729444688_item	2685103	et	3	main
leidsime	doc_534729444688_item	2685105	et	3	main
see	doc_534729444688_item	2685106	et	3	main
oli	doc_534729444688_item	2685107	et	3	main
suur	doc_534729444688_item	2685108	et	3	main
lõbus	doc_534729444688_item	2685109	et	4	main
ja	doc_534729444688_item	2685116	et	3	main
me	doc_534729444688_item	2685121	et	4	main
raudteejaam	doc_534729444688_item	2685123	et	3	main
rongi	doc_534729444688_item	2685125	et	4	main
oli	doc_534729444688_item	2685126	et	3	main
juba	doc_534729444688_item	2685127	et	3	main
see	doc_534729444688_item	2685129	et	3	main
me	doc_534729444688_item	2685140	et	4	main
sõitsime	doc_534729444688_item	2685141	et	3	main
väga	doc_534729444688_item	2685152	et	3	main
kesklinnasse	doc_534729444689_item	2685170	et	4	main
tänava	doc_534729444689_item	2685181	et	4	main
kunstnik	doc_534729444689_item	2685182	et	3	main
me	doc_534729444689_item	2685183	et	4	main
puhkasime	doc_534729444689_item	2685184	et	3	main
kaua	doc_534729444689_item	2685186	et	3	main
muusikat	doc_534729444689_item	2685190	et	3	main
väga	doc_534729444689_item	2685194	et	3	main
kohvi	doc_534729444689_item	2685208	et	4	main
siis	doc_534729444689_item	2685210	et	3	main
j	doc_534729444689_item	2685236	et	4	main
vaikselt	doc_534729444689_item	2685240	et	4	main
kaubamaja	doc_534729444688_item	2685022	et	4	main
igal	doc_534729444688_item	2685024	et	3	main
pool	doc_534729444688_item	2685025	et	4	main
meil	doc_534729444688_item	2685026	et	4	main
vaatasime	doc_534729444688_item	2685027	et	3	main
läksime	doc_534729444688_item	2685032	et	3	main
mulle	doc_534729444688_item	2685042	et	4	main
kirju	doc_534729444688_item	2685043	et	4	main
väsinud	doc_534729444688_item	2685047	et	4	main
muljielt	doc_534729444688_item	2685049	et	4	main
eindrücken	doc_534729444688_item	2685050	et	4	main
südalinnasse	doc_534729444688_item	2685053	et	4	main
me	doc_534729444688_item	2685070	et	4	main
me	doc_534729444688_item	2685077	et	4	main
inimesed	doc_534729444688_item	2685080	et	3	main
otsime	doc_534729444688_item	2685095	et	4	main
üks	doc_534729444688_item	2685096	et	3	main
välisuks	doc_534729444688_item	2685098	et	4	main
üks	doc_534729444688_item	2685100	et	3	main
dume	doc_534729444688_item	2685113	et	4	main
aga	doc_534729444688_item	2685114	et	3	main
beleuchteten-valgustama	doc_534729444688_item	2685115	et	3	main
tänava	doc_534729444688_item	2685118	et	4	main
kui	doc_534729444688_item	2685120	et	3	main
meil	doc_534729444688_item	2685124	et	4	main
väljub	doc_534729444688_item	2685128	et	3	main
oli	doc_534729444688_item	2685130	et	3	main
ja	doc_534729444688_item	2685154	et	3	main
magama	doc_534729444688_item	2685157	et	3	main
26	doc_534729444689_item	2685160	et	2	main
sõime	doc_534729444689_item	2685166	et	4	main
hommikusöök	doc_534729444689_item	2685167	et	3	main
ja	doc_534729444689_item	2685168	et	3	main
temse	doc_534729444689_item	2685175	et	4	main
ja	doc_534729444689_item	2685176	et	3	main
puhkasime	doc_534729444689_item	2685177	et	3	main
londonilt	doc_534729444689_item	2685203	et	4	main
ka	doc_534729444689_item	2685204	et	3	main
jõime	doc_534729444689_item	2685207	et	3	main
ja	doc_534729444689_item	2685209	et	3	main
jalutasime	doc_534729444689_item	2685211	et	3	main
tänavad	doc_534729444689_item	2685213	et	4	main
õhtul	doc_534729444689_item	2685214	et	3	main
me	doc_534729444689_item	2685215	et	4	main
läksime	doc_534729444689_item	2685216	et	3	main
jälle	doc_534729444689_item	2685217	et	3	main
pargisse	doc_534729444689_item	2685218	et	3	main
enne	doc_534729444689_item	2685221	et	4	main
koju	doc_534729444689_item	2685235	et	3	main
riided	doc_534729444688_item	2685039	et	3	main
ma	doc_534729444688_item	2685040	et	3	main
otsin	doc_534729444688_item	2685041	et	3	main
ja	doc_534729444688_item	2685046	et	3	main
palju	doc_534729444688_item	2685048	et	4	main
pargis	doc_534729444688_item	2685057	et	3	main
ja	doc_534729444688_item	2685072	et	3	main
pargis	doc_534729444688_item	2685081	et	3	main
läbi	doc_534729444688_item	2685112	et	4	main
viimane	doc_534729444688_item	2685131	et	3	main
liiga	doc_534729444688_item	2685135	et	4	main
bussiga	doc_534729444688_item	2685142	et	3	main
kell	doc_534729444688_item	2685144	et	3	main
me	doc_534729444688_item	2685146	et	4	main
ja	doc_534729444688_item	2685149	et	3	main
olime	doc_534729444688_item	2685151	et	3	main
kolmapäev	doc_534729444689_item	2685159	et	3	main
me	doc_534729444689_item	2685162	et	4	main
jälle	doc_534729444689_item	2685171	et	3	main
me	doc_534729444689_item	2685172	et	4	main
jalutasime	doc_534729444689_item	2685173	et	3	main
liiga	doc_534729444689_item	2685185	et	4	main
ja	doc_534729444689_item	2685187	et	3	main
see	doc_534729444689_item	2685192	et	3	main
ilus	doc_534729444689_item	2685195	et	4	main
gardenisse	doc_534729444689_item	2685199	et	4	main
see	doc_534729444689_item	2685200	et	3	main
on	doc_534729444689_item	2685201	et	4	main
piirkond	doc_534729444689_item	2685202	et	3	main
me	doc_534729444689_item	2685206	et	4	main
läbi	doc_534729444689_item	2685212	et	4	main
rongi	doc_534729444688_item	2685132	et	4	main
pärast	doc_534729444688_item	2685134	et	4	main
kaua	doc_534729444688_item	2685136	et	3	main
otsing	doc_534729444688_item	2685137	et	3	main
ja	doc_534729444688_item	2685138	et	3	main
väsinud	doc_534729444688_item	2685153	et	4	main
heitsime	doc_534729444688_item	2685156	et	3	main
päevik	doc_534729444689_item	2685158	et	3	main
sõitasime	doc_534729444689_item	2685169	et	4	main
pinkil	doc_534729444689_item	2685178	et	4	main
ja	doc_534729444689_item	2685179	et	3	main
jälgisime	doc_534729444689_item	2685180	et	3	main
kuulasime	doc_534729444689_item	2685188	et	3	main
oli	doc_534729444689_item	2685193	et	3	main
sõitasime	doc_534729444689_item	2685197	et	4	main
covent	doc_534729444689_item	2685198	et	4	main
siin	doc_534729444689_item	2685205	et	4	main
ja	doc_534729444689_item	2685219	et	3	main
otsime	doc_534729444689_item	2685220	et	4	main
muffins	doc_534729444689_item	2685224	et	4	main
mmh	doc_534729444689_item	2685225	et	4	main
väga	doc_534729444689_item	2685228	et	3	main
seekord	doc_534729444689_item	2685230	et	3	main
sõitasime	doc_534729444689_item	2685232	et	4	main
kohe	doc_534729444689_item	2685233	et	4	main
bussiga	doc_534729444689_item	2685234	et	3	main
magasime	doc_534729444689_item	2685163	et	3	main
liiga	doc_534729444689_item	2685164	et	4	main
kaua	doc_534729444689_item	2685165	et	3	main
mööda	doc_534729444689_item	2685174	et	4	main
jazz	doc_534729444689_item	2685189	et	4	main
oh	doc_534729444689_item	2685191	et	3	main
me	doc_534729444689_item	2685196	et	4	main
seda	doc_534729444689_item	2685222	et	3	main
see	doc_534729444689_item	2685226	et	3	main
oli	doc_534729444689_item	2685238	et	3	main
šokolaadi	doc_534729444689_item	2685223	et	2	main
oli	doc_534729444689_item	2685227	et	3	main
maitsev	doc_534729444689_item	2685229	et	4	main
me	doc_534729444689_item	2685231	et	4	main
see	doc_534729444689_item	2685237	et	3	main
väga	doc_534729444689_item	2685239	et	3	main
päev	doc_534729444689_item	2685241	et	3	main
magogisse	doc_534729444696_item	2685889	et	4	main
seal	doc_534729444696_item	2685890	et	4	main
ja	doc_534729444696_item	2685899	et	3	main
t-särki	doc_534729444696_item	2685908	et	4	main
eesnimi	doc_534729444696_item	2685914	et	3	main
õhtusöök	doc_534729444696_item	2685922	et	3	main
kanapraadi	doc_534729444696_item	2685924	et	4	main
kust	doc_534729444696_item	2685943	et	4	main
minu	doc_534729444696_item	2685944	et	3	main
kanadas	doc_534729444696_item	2685947	et	4	main
ostasime	doc_534729444696_item	2685951	et	4	main
on	doc_534729444696_item	2685953	et	4	main
suletud	doc_534729444696_item	2685954	et	4	main
kui	doc_534729444696_item	2685955	et	3	main
täna	doc_534729444697_item	2685965	et	4	main
maple	doc_534729444697_item	2685976	et	4	main
ma	doc_534729444697_item	2685981	et	3	main
poed	doc_534729444696_item	2685902	et	4	main
ostasin	doc_534729444696_item	2685907	et	4	main
ja	doc_534729444696_item	2685909	et	3	main
kirsidega	doc_534729444696_item	2685911	et	4	main
ta	doc_534729444696_item	2685918	et	4	main
jääsi	doc_534729444696_item	2685920	et	4	main
õhtusöögiks	doc_534729444696_item	2685921	et	3	main
palju	doc_534729444696_item	2685931	et	4	main
ja	doc_534729444696_item	2685932	et	3	main
sellepärast	doc_534729444696_item	2685933	et	3	main
sõbranna	doc_534729444696_item	2685946	et	4	main
päevik	doc_534729444697_item	2685963	et	3	main
real	doc_534729444697_item	2685969	et	3	main
breakfast	doc_534729444697_item	2685971	et	4	main
on	doc_534729444697_item	2685973	et	4	main
pankooki	doc_534729444697_item	2685974	et	4	main
singi	doc_534729444697_item	2685975	et	3	main
browns	doc_534729444697_item	2685980	et	4	main
ma	doc_534729444697_item	2685985	et	3	main
on	doc_534729444697_item	2685990	et	4	main
olen	doc_534729444697_item	2685994	et	3	main
mitte	doc_534729444697_item	2685996	et	3	main
kunagi	doc_534729444697_item	2685997	et	3	main
sõidsin	doc_534729444697_item	2685998	et	4	main
automaatikaga	doc_534729444697_item	2685999	et	4	main
keegi	doc_534729444697_item	2686014	et	4	main
pärastlõunal	doc_534729444697_item	2686017	et	3	main
grillisime	doc_534729444697_item	2686022	et	3	main
hot	doc_534729444697_item	2686023	et	4	main
elavad	doc_534729444697_item	2686033	et	4	main
magogis	doc_534729444696_item	2685898	et	4	main
šopisime	doc_534729444696_item	2685900	et	2	main
kanadas	doc_534729444696_item	2685901	et	4	main
ja	doc_534729444696_item	2685906	et	3	main
kingapaelid	doc_534729444696_item	2685910	et	3	main
eesnimi	doc_534729444696_item	2685912	et	3	main
külas	doc_534729444696_item	2685916	et	3	main
ka	doc_534729444696_item	2685919	et	3	main
oli	doc_534729444696_item	2685923	et	3	main
ja	doc_534729444696_item	2685926	et	3	main
me	doc_534729444696_item	2685934	et	4	main
me	doc_534729444696_item	2685958	et	4	main
veel	doc_534729444696_item	2685959	et	4	main
söime	doc_534729444696_item	2685960	et	4	main
šokolaadi	doc_534729444696_item	2685961	et	2	main
me	doc_534729444697_item	2685967	et	4	main
canadian	doc_534729444697_item	2685970	et	4	main
ja	doc_534729444697_item	2685978	et	3	main
hash	doc_534729444697_item	2685979	et	4	main
autosõidile	doc_534729444697_item	2685984	et	3	main
kui	doc_534729444697_item	2686000	et	3	main
tulisime	doc_534729444697_item	2686001	et	4	main
tagasi	doc_534729444697_item	2686002	et	3	main
eesnimi	doc_534729444697_item	2686003	et	3	main
eesnimi	doc_534729444697_item	2686004	et	3	main
me	doc_534729444697_item	2686021	et	4	main
nad	doc_534729444697_item	2686028	et	3	main
terve	doc_534729444697_item	2686039	et	4	main
me	doc_534729444696_item	2685891	et	4	main
söime	doc_534729444696_item	2685892	et	4	main
hommikusöögi	doc_534729444696_item	2685893	et	3	main
restoranis	doc_534729444696_item	2685894	et	3	main
siis	doc_534729444696_item	2685895	et	3	main
on	doc_534729444696_item	2685903	et	4	main
oli	doc_534729444696_item	2685915	et	3	main
pärastlõunal	doc_534729444696_item	2685917	et	3	main
päevik	doc_534729444696_item	2685875	et	3	main
392006	doc_534729444696_item	2685876	et	2	main
täna	doc_534729444696_item	2685877	et	4	main
on	doc_534729444696_item	2685878	et	4	main
pühapäev	doc_534729444696_item	2685879	et	3	main
ma	doc_534729444696_item	2685880	et	3	main
ärkasin	doc_534729444696_item	2685881	et	3	main
võtsin	doc_534729444696_item	2685882	et	3	main
dušši	doc_534729444696_item	2685883	et	2	main
ja	doc_534729444696_item	2685884	et	3	main
seejäral	doc_534729444696_item	2685885	et	4	main
me	doc_534729444696_item	2685886	et	4	main
sõitsime	doc_534729444696_item	2685887	et	3	main
jälle	doc_534729444696_item	2685888	et	3	main
me	doc_534729444696_item	2685896	et	4	main
jalutasime	doc_534729444696_item	2685897	et	3	main
avatud	doc_534729444696_item	2685904	et	4	main
pühapäeval	doc_534729444696_item	2685905	et	3	main
vend	doc_534729444696_item	2685913	et	3	main
ma	doc_534729444696_item	2685928	et	3	main
läksime	doc_534729444696_item	2685935	et	3	main
jalutama	doc_534729444696_item	2685936	et	3	main
stansteadi	doc_534729444696_item	2685937	et	4	main
parim	doc_534729444696_item	2685945	et	4	main
eesnimi	doc_534729444696_item	2685948	et	3	main
ma	doc_534729444696_item	2685950	et	3	main
tulesime	doc_534729444696_item	2685956	et	4	main
koju	doc_534729444696_item	2685957	et	3	main
fondue	doc_534729444696_item	2685962	et	4	main
söime	doc_534729444697_item	2685968	et	4	main
syrup	doc_534729444697_item	2685977	et	4	main
eesnimi-ga	doc_534729444697_item	2685983	et	3	main
auto	doc_534729444697_item	2685988	et	4	main
õe	doc_534729444697_item	2686005	et	4	main
sõber	doc_534729444697_item	2686007	et	3	main
ajas	doc_534729444697_item	2686009	et	4	main
et	doc_534729444697_item	2686012	et	3	main
meeldib	doc_534729444697_item	2686016	et	3	main
eesnimi	doc_534729444697_item	2686018	et	3	main
tulisi	doc_534729444697_item	2686020	et	3	main
dogi	doc_534729444697_item	2686024	et	4	main
kõnelesime	doc_534729444697_item	2686026	et	3	main
meeldivad	doc_534729444697_item	2686030	et	4	main
minu	doc_534729444697_item	2686038	et	3	main
perekond	doc_534729444697_item	2686040	et	3	main
närvidele	doc_534729444697_item	2686046	et	3	main
3	doc_534729444700_item	2686259	et	2	main
hommikul	doc_534729444700_item	2686261	et	3	main
mina	doc_534729444700_item	2686264	et	4	main
kolmveerand	doc_534729444700_item	2686272	et	4	main
üksteist	doc_534729444700_item	2686273	et	4	main
ärevil	doc_534729444700_item	2686287	et	4	main
ja	doc_534729444700_item	2686321	et	3	main
oli	doc_534729444700_item	2686323	et	3	main
eestis	doc_534729444700_item	2686332	et	3	main
me	doc_534729444700_item	2686339	et	4	main
väljak	doc_534729444700_item	2686345	et	3	main
ahjukartulid	doc_534729444696_item	2685925	et	3	main
salati	doc_534729444696_item	2685927	et	4	main
söin	doc_534729444696_item	2685929	et	4	main
liiga	doc_534729444696_item	2685930	et	4	main
läbi	doc_534729444696_item	2685938	et	4	main
ma	doc_534729444696_item	2685939	et	3	main
kogesin	doc_534729444696_item	2685940	et	3	main
et	doc_534729444696_item	2685941	et	3	main
pood	doc_534729444696_item	2685942	et	4	main
ja	doc_534729444696_item	2685949	et	3	main
čipsi	doc_534729444696_item	2685952	et	2	main
492006	doc_534729444697_item	2685964	et	2	main
hommikul	doc_534729444697_item	2685966	et	3	main
see	doc_534729444697_item	2685972	et	3	main
läksin	doc_534729444697_item	2685982	et	3	main
võitsin	doc_534729444697_item	2685986	et	3	main
see	doc_534729444697_item	2685989	et	3	main
ma	doc_534729444697_item	2685993	et	3	main
veel	doc_534729444697_item	2685995	et	4	main
uus	doc_534729444697_item	2686006	et	3	main
oli	doc_534729444697_item	2686008	et	3	main
ma	doc_534729444697_item	2686010	et	3	main
usun	doc_534729444697_item	2686011	et	3	main
ta	doc_534729444697_item	2686015	et	4	main
ja	doc_534729444697_item	2686025	et	3	main
palju	doc_534729444697_item	2686027	et	4	main
mulle	doc_534729444697_item	2686029	et	4	main
nad	doc_534729444697_item	2686031	et	3	main
kõik	doc_534729444697_item	2686032	et	4	main
kui	doc_534729444697_item	2686037	et	3	main
elaksi	doc_534729444697_item	2686041	et	4	main
göttingenis	doc_534729444697_item	2686042	et	4	main
see	doc_534729444697_item	2686043	et	3	main
päevik	doc_534729444700_item	2686257	et	3	main
september	doc_534729444700_item	2686260	et	3	main
kell	doc_534729444700_item	2686262	et	3	main
minu	doc_534729444700_item	2686266	et	3	main
sõitasime	doc_534729444700_item	2686268	et	4	main
autoga	doc_534729444700_item	2686269	et	3	main
lennukjaam	doc_534729444700_item	2686270	et	4	main
väljusis	doc_534729444700_item	2686276	et	4	main
tallinnasse	doc_534729444700_item	2686277	et	3	main
minu	doc_534729444700_item	2686278	et	3	main
ma	doc_534729444700_item	2686284	et	3	main
sõitasime	doc_534729444700_item	2686340	et	4	main
kesklinna	doc_534729444700_item	2686342	et	4	main
viru	doc_534729444700_item	2686344	et	4	main
raske	doc_534729444700_item	2686348	et	4	main
mööda	doc_534729444700_item	2686350	et	4	main
pärnu	doc_534729444700_item	2686351	et	4	main
mnt	doc_534729444700_item	2686352	et	4	main
ma	doc_534729444700_item	2686359	et	3	main
läksime	doc_534729444700_item	2686384	et	3	main
pool	doc_534729444701_item	2686397	et	4	main
viru	doc_534729444701_item	2686401	et	4	main
sõidama	doc_534729444697_item	2685987	et	4	main
automaatika	doc_534729444697_item	2685991	et	4	main
ja	doc_534729444697_item	2685992	et	3	main
mitte	doc_534729444697_item	2686013	et	3	main
suguvõsa	doc_534729444697_item	2686019	et	4	main
stansteadis	doc_534729444697_item	2686034	et	4	main
ma	doc_534729444697_item	2686035	et	3	main
usun	doc_534729444697_item	2686036	et	3	main
käiksi	doc_534729444697_item	2686044	et	4	main
mind	doc_534729444697_item	2686045	et	4	main
pühapäev	doc_534729444700_item	2686258	et	3	main
seitse	doc_534729444700_item	2686263	et	3	main
ja	doc_534729444700_item	2686265	et	3	main
vanemad	doc_534729444700_item	2686267	et	4	main
ja	doc_534729444700_item	2686283	et	3	main
väga	doc_534729444700_item	2686286	et	3	main
soe	doc_534729444700_item	2686324	et	4	main
olin	doc_534729444700_item	2686326	et	3	main
ma	doc_534729444700_item	2686329	et	3	main
olime	doc_534729444700_item	2686330	et	3	main
jälle	doc_534729444700_item	2686331	et	3	main
kõike	doc_534729444700_item	2686333	et	4	main
oli	doc_534729444700_item	2686334	et	3	main
väga	doc_534729444700_item	2686335	et	3	main
väljusime	doc_534729444700_item	2686343	et	3	main
läksime	doc_534729444700_item	2686347	et	3	main
plats	doc_534729444700_item	2686372	et	4	main
ja	doc_534729444700_item	2686373	et	3	main
toompeale	doc_534729444700_item	2686374	et	3	main
pärast	doc_534729444700_item	2686375	et	4	main
me	doc_534729444700_item	2686378	et	4	main
päevik	doc_534729444701_item	2686386	et	3	main
september	doc_534729444701_item	2686389	et	3	main
sõime	doc_534729444701_item	2686395	et	4	main
hommikusöök	doc_534729444701_item	2686396	et	3	main
väljak	doc_534729444701_item	2686402	et	3	main
me	doc_534729444701_item	2686412	et	4	main
berlinisse	doc_534729444700_item	2686271	et	4	main
rõõm	doc_534729444700_item	2686279	et	3	main
oli	doc_534729444700_item	2686280	et	3	main
väga	doc_534729444700_item	2686281	et	3	main
suur	doc_534729444700_item	2686282	et	3	main
olin	doc_534729444700_item	2686285	et	3	main
ma	doc_534729444700_item	2686325	et	3	main
pagasiga	doc_534729444700_item	2686349	et	3	main
pärast	doc_534729444700_item	2686355	et	4	main
meie	doc_534729444700_item	2686356	et	4	main
saabumine	doc_534729444700_item	2686357	et	4	main
minu	doc_534729444700_item	2686361	et	3	main
kesklinn	doc_534729444700_item	2686363	et	3	main
meie	doc_534729444700_item	2686376	et	4	main
väsinud	doc_534729444700_item	2686382	et	4	main
esmaspäev	doc_534729444701_item	2686387	et	3	main
kümme	doc_534729444701_item	2686398	et	3	main
mulle	doc_534729444701_item	2686406	et	4	main
kinga	doc_534729444701_item	2686408	et	4	main
teisipäeva	doc_534729444701_item	2686421	et	4	main
kesklinnas	doc_534729444701_item	2686423	et	4	main
me	doc_534729444701_item	2686425	et	4	main
läksime	doc_534729444701_item	2686426	et	3	main
jaoksja	doc_534729444701_item	2686434	et	4	main
taga	doc_534729444701_item	2686442	et	4	main
van	doc_534729444701_item	2686456	et	4	main
on	doc_534729444701_item	2686459	et	4	main
lemmik	doc_534729444701_item	2686461	et	3	main
päevik	doc_534729444702_item	2686463	et	3	main
5	doc_534729444702_item	2686465	et	2	main
me	doc_534729444702_item	2686467	et	4	main
sõime	doc_534729444702_item	2686472	et	4	main
sõitasime	doc_534729444702_item	2686475	et	4	main
pahklasse	doc_534729444702_item	2686489	et	4	main
ma	doc_534729444702_item	2686493	et	3	main
väga	doc_534729444702_item	2686495	et	3	main
meie	doc_534729444700_item	2686274	et	4	main
lennuk	doc_534729444700_item	2686275	et	3	main
minu	doc_534729444700_item	2686288	et	3	main
ema	doc_534729444700_item	2686289	et	4	main
natuke	doc_534729444700_item	2686290	et	4	main
kartsis	doc_534729444700_item	2686291	et	3	main
sest	doc_534729444700_item	2686292	et	4	main
meie	doc_534729444700_item	2686293	et	4	main
lennuk	doc_534729444700_item	2686294	et	3	main
oli	doc_534729444700_item	2686295	et	3	main
vaike	doc_534729444700_item	2686296	et	3	main
ja	doc_534729444700_item	2686297	et	3	main
taevas	doc_534729444700_item	2686298	et	4	main
oli	doc_534729444700_item	2686299	et	3	main
väga	doc_534729444700_item	2686300	et	3	main
pilves	doc_534729444700_item	2686301	et	4	main
nii	doc_534729444700_item	2686302	et	3	main
et	doc_534729444700_item	2686303	et	3	main
meie	doc_534729444700_item	2686304	et	4	main
lend	doc_534729444700_item	2686305	et	3	main
oli	doc_534729444700_item	2686306	et	3	main
natuke	doc_534729444700_item	2686307	et	4	main
ärev	doc_534729444700_item	2686308	et	3	main
viie	doc_534729444700_item	2686309	et	3	main
minuti	doc_534729444700_item	2686310	et	3	main
pärast	doc_534729444700_item	2686311	et	4	main
pool	doc_534729444700_item	2686312	et	4	main
meie	doc_534729444700_item	2686314	et	4	main
kaks	doc_534729444700_item	2686313	et	3	main
lennuk	doc_534729444700_item	2686315	et	3	main
maandusis	doc_534729444700_item	2686316	et	4	main
tallinnasse	doc_534729444700_item	2686317	et	3	main
tallinnas	doc_534729444700_item	2686318	et	4	main
päike	doc_534729444700_item	2686319	et	3	main
paistsis	doc_534729444700_item	2686320	et	4	main
ilm	doc_534729444700_item	2686322	et	3	main
õnelik	doc_534729444700_item	2686327	et	4	main
et	doc_534729444700_item	2686328	et	3	main
tuttav	doc_534729444700_item	2686336	et	3	main
ja	doc_534729444700_item	2686337	et	3	main
tuntud	doc_534729444700_item	2686338	et	4	main
bussiga	doc_534729444700_item	2686341	et	3	main
ja	doc_534729444700_item	2686346	et	3	main
näitasin	doc_534729444700_item	2686360	et	3	main
jälutuskäik	doc_534729444700_item	2686377	et	4	main
sõime	doc_534729444700_item	2686379	et	4	main
old	doc_534729444700_item	2686380	et	4	main
me	doc_534729444700_item	2686383	et	4	main
4	doc_534729444701_item	2686388	et	2	main
pärast	doc_534729444701_item	2686390	et	4	main
me	doc_534729444701_item	2686391	et	4	main
tõusime	doc_534729444701_item	2686392	et	3	main
me	doc_534729444701_item	2686399	et	4	main
sõitasime	doc_534729444701_item	2686413	et	4	main
bussiga	doc_534729444701_item	2686414	et	3	main
lennukjaam	doc_534729444701_item	2686415	et	4	main
sest	doc_534729444701_item	2686416	et	4	main
me	doc_534729444701_item	2686417	et	4	main
soovisime	doc_534729444701_item	2686418	et	3	main
rentima	doc_534729444701_item	2686419	et	3	main
auto	doc_534729444701_item	2686420	et	4	main
mulle	doc_534729444701_item	2686435	et	4	main
kinda	doc_534729444701_item	2686436	et	3	main
rautejaam	doc_534729444701_item	2686443	et	4	main
sõime	doc_534729444701_item	2686454	et	4	main
üksteist	doc_534729444702_item	2686480	et	4	main
me	doc_534729444702_item	2686481	et	4	main
võisime	doc_534729444702_item	2686482	et	3	main
me	doc_534729444702_item	2686487	et	4	main
töökoht	doc_534729444702_item	2686492	et	3	main
kestsis	doc_534729444702_item	2686505	et	4	main
ja	doc_534729444702_item	2686508	et	3	main
kolmverrand	doc_534729444702_item	2686511	et	4	main
näitasin	doc_534729444702_item	2686522	et	3	main
ma	doc_534729444702_item	2686524	et	3	main
kõik	doc_534729444702_item	2686526	et	4	main
mulle	doc_534729444702_item	2686528	et	4	main
väga	doc_534729444702_item	2686529	et	3	main
tuttav	doc_534729444702_item	2686530	et	3	main
tundsin	doc_534729444702_item	2686533	et	3	main
jaoks	doc_534729444702_item	2686539	et	4	main
üks	doc_534729444702_item	2686540	et	3	main
väga	doc_534729444702_item	2686560	et	3	main
ja	doc_534729444702_item	2686574	et	3	main
tallinna	doc_534729444700_item	2686353	et	4	main
cityguesthousesse	doc_534729444700_item	2686354	et	4	main
majutus	doc_534729444700_item	2686358	et	4	main
vanemad	doc_534729444700_item	2686362	et	4	main
tallinnast	doc_534729444700_item	2686364	et	3	main
me	doc_534729444700_item	2686365	et	4	main
jalutasime	doc_534729444700_item	2686366	et	3	main
läbi	doc_534729444700_item	2686367	et	4	main
vana	doc_534729444700_item	2686368	et	4	main
kesklinn	doc_534729444700_item	2686369	et	3	main
üle	doc_534729444700_item	2686370	et	3	main
raekoja	doc_534729444700_item	2686371	et	3	main
hansa	doc_534729444700_item	2686381	et	4	main
magama	doc_534729444700_item	2686385	et	3	main
üles	doc_534729444701_item	2686393	et	3	main
me	doc_534729444701_item	2686394	et	4	main
läksime	doc_534729444701_item	2686400	et	3	main
ja	doc_534729444701_item	2686403	et	3	main
ostsin	doc_534729444701_item	2686405	et	3	main
uue	doc_534729444701_item	2686407	et	3	main
viru	doc_534729444701_item	2686409	et	4	main
keskusse	doc_534729444701_item	2686410	et	4	main
siis	doc_534729444701_item	2686411	et	3	main
müts	doc_534729444701_item	2686432	et	4	main
õde	doc_534729444701_item	2686433	et	4	main
turg	doc_534729444701_item	2686447	et	3	main
pannkoogid	doc_534729444701_item	2686455	et	3	main
minu	doc_534729444701_item	2686460	et	3	main
kõrts	doc_534729444701_item	2686462	et	3	main
tõusime	doc_534729444702_item	2686468	et	3	main
üles	doc_534729444702_item	2686469	et	3	main
kell	doc_534729444702_item	2686470	et	3	main
kaheksa	doc_534729444702_item	2686471	et	4	main
tulema	doc_534729444702_item	2686483	et	4	main
sõitasime	doc_534729444702_item	2686488	et	4	main
olin	doc_534729444702_item	2686494	et	3	main
ärevil	doc_534729444702_item	2686496	et	4	main
minu	doc_534729444702_item	2686498	et	3	main
oli	doc_534729444702_item	2686500	et	3	main
väga	doc_534729444702_item	2686501	et	3	main
suur	doc_534729444702_item	2686502	et	3	main
meie	doc_534729444702_item	2686503	et	4	main
tund	doc_534729444702_item	2686507	et	3	main
vana	doc_534729444702_item	2686519	et	4	main
kus	doc_534729444702_item	2686523	et	3	main
pahkla	doc_534729444702_item	2686536	et	4	main
on	doc_534729444702_item	2686537	et	4	main
väike	doc_534729444702_item	2686541	et	4	main
küla	doc_534729444702_item	2686567	et	4	main
ja	doc_534729444702_item	2686568	et	3	main
ma	doc_534729444702_item	2686569	et	3	main
näitasin	doc_534729444702_item	2686570	et	3	main
minu	doc_534729444702_item	2686571	et	3	main
me	doc_534729444702_item	2686578	et	4	main
me	doc_534729444703_item	2686616	et	4	main
restoranis	doc_534729444703_item	2686620	et	3	main
oli	doc_534729444703_item	2686623	et	3	main
maitseb	doc_534729444703_item	2686625	et	4	main
ma	doc_534729444703_item	2686626	et	3	main
sõin	doc_534729444703_item	2686627	et	3	main
pelmeeni	doc_534729444703_item	2686628	et	4	main
kui	doc_534729444703_item	2686629	et	3	main
tais	doc_534729444703_item	2686634	et	3	main
vaatasime	doc_534729444703_item	2686639	et	3	main
ja	doc_534729444703_item	2686642	et	3	main
üheksa	doc_534729444704_item	2686668	et	4	main
ja	doc_534729444704_item	2686669	et	3	main
sõitasime	doc_534729444704_item	2686679	et	4	main
siis	doc_534729444704_item	2686684	et	3	main
check-in	doc_534729444704_item	2686687	et	4	main
olin	doc_534729444704_item	2686689	et	3	main
oli	doc_534729444704_item	2686713	et	3	main
inimesed	doc_534729444704_item	2686717	et	3	main
aga	doc_534729444704_item	2686725	et	3	main
oli	doc_534729444704_item	2686727	et	3	main
pool	doc_534729444704_item	2686729	et	4	main
kolm	doc_534729444704_item	2686730	et	3	main
me	doc_534729444704_item	2686731	et	4	main
maandusime	doc_534729444704_item	2686732	et	3	main
ootas	doc_534729444704_item	2686737	et	3	main
me	doc_534729444704_item	2686745	et	4	main
vein	doc_534729444704_item	2686756	et	3	main
ma	doc_534729444701_item	2686404	et	3	main
jaoks	doc_534729444701_item	2686422	et	4	main
tagasi	doc_534729444701_item	2686424	et	3	main
siis	doc_534729444701_item	2686437	et	3	main
jalutasime	doc_534729444701_item	2686445	et	3	main
üle	doc_534729444701_item	2686446	et	3	main
ja	doc_534729444701_item	2686448	et	3	main
palju	doc_534729444701_item	2686450	et	4	main
aega	doc_534729444701_item	2686451	et	4	main
õhtul	doc_534729444701_item	2686452	et	3	main
me	doc_534729444701_item	2686453	et	4	main
see	doc_534729444701_item	2686458	et	3	main
teisipäev	doc_534729444702_item	2686464	et	3	main
september	doc_534729444702_item	2686466	et	3	main
ja	doc_534729444702_item	2686474	et	3	main
uuesti	doc_534729444702_item	2686476	et	3	main
lennukjaam	doc_534729444702_item	2686478	et	4	main
järele	doc_534729444702_item	2686484	et	4	main
meie	doc_534729444702_item	2686485	et	4	main
minu	doc_534729444702_item	2686490	et	3	main
me	doc_534729444702_item	2686509	et	4	main
joudsime	doc_534729444702_item	2686510	et	4	main
kaksteist	doc_534729444702_item	2686512	et	4	main
pahklas	doc_534729444702_item	2686513	et	4	main
ma	doc_534729444702_item	2686514	et	3	main
näitasin	doc_534729444702_item	2686515	et	3	main
minu	doc_534729444702_item	2686516	et	3	main
minu	doc_534729444702_item	2686518	et	3	main
küla	doc_534729444702_item	2686520	et	4	main
ja	doc_534729444702_item	2686521	et	3	main
oli	doc_534729444702_item	2686527	et	3	main
ja	doc_534729444702_item	2686531	et	3	main
end	doc_534729444702_item	2686534	et	4	main
kodune	doc_534729444702_item	2686535	et	4	main
sõime	doc_534729444702_item	2686545	et	4	main
on	doc_534729444702_item	2686550	et	4	main
minu	doc_534729444702_item	2686551	et	3	main
oli	doc_534729444702_item	2686559	et	3	main
söök	doc_534729444702_item	2686563	et	3	main
me	doc_534729444702_item	2686564	et	4	main
jalutasime	doc_534729444702_item	2686565	et	3	main
läbi	doc_534729444702_item	2686566	et	4	main
tagasi	doc_534729444702_item	2686577	et	3	main
pirita	doc_534729444702_item	2686581	et	4	main
me	doc_534729444702_item	2686582	et	4	main
vene	doc_534729444703_item	2686619	et	4	main
kõht	doc_534729444703_item	2686632	et	3	main
me	doc_534729444703_item	2686638	et	4	main
kirik	doc_534729444703_item	2686641	et	3	main
läksime	doc_534729444703_item	2686645	et	3	main
auto	doc_534729444703_item	2686649	et	4	main
juurde	doc_534729444703_item	2686650	et	4	main
kui	doc_534729444703_item	2686651	et	3	main
meie	doc_534729444704_item	2686673	et	4	main
ja	doc_534729444704_item	2686675	et	3	main
pakkisime	doc_534729444704_item	2686676	et	3	main
auto	doc_534729444704_item	2686677	et	4	main
ja	doc_534729444704_item	2686683	et	3	main
natuke	doc_534729444704_item	2686690	et	4	main
kurb	doc_534729444704_item	2686691	et	3	main
sest	doc_534729444704_item	2686692	et	4	main
see	doc_534729444704_item	2686693	et	3	main
oli	doc_534729444704_item	2686707	et	3	main
natuke	doc_534729444704_item	2686708	et	4	main
kartsis	doc_534729444704_item	2686709	et	3	main
veel	doc_534729444704_item	2686714	et	4	main
üheksa	doc_534729444704_item	2686716	et	4	main
lendasid	doc_534729444704_item	2686718	et	4	main
meiega	doc_534729444704_item	2686719	et	4	main
see	doc_534729444704_item	2686720	et	3	main
vana	doc_534729444701_item	2686427	et	4	main
linnamüür	doc_534729444701_item	2686428	et	3	main
seal	doc_534729444701_item	2686429	et	4	main
ma	doc_534729444701_item	2686430	et	3	main
ostsin	doc_534729444701_item	2686431	et	3	main
me	doc_534729444701_item	2686438	et	4	main
läksime	doc_534729444701_item	2686439	et	3	main
vene	doc_534729444701_item	2686440	et	4	main
turgisse	doc_534729444701_item	2686441	et	4	main
me	doc_534729444701_item	2686444	et	4	main
kadusis	doc_534729444701_item	2686449	et	4	main
krahlis	doc_534729444701_item	2686457	et	4	main
hommikusööki	doc_534729444702_item	2686473	et	4	main
bussiga	doc_534729444702_item	2686477	et	3	main
kell	doc_534729444702_item	2686479	et	3	main
auto	doc_534729444702_item	2686486	et	4	main
vana	doc_534729444702_item	2686491	et	4	main
ja	doc_534729444702_item	2686497	et	3	main
rööm	doc_534729444702_item	2686499	et	4	main
pool	doc_534729444702_item	2686506	et	4	main
vanemad	doc_534729444702_item	2686517	et	4	main
soit	doc_534729444702_item	2686504	et	4	main
töötasin	doc_534729444702_item	2686525	et	3	main
ma	doc_534729444702_item	2686532	et	3	main
mulle	doc_534729444702_item	2686538	et	4	main
tükk	doc_534729444702_item	2686542	et	3	main
me	doc_534729444702_item	2686544	et	4	main
lounasöök	doc_534729444702_item	2686546	et	4	main
eesnimi	doc_534729444702_item	2686547	et	3	main
majas	doc_534729444702_item	2686548	et	3	main
see	doc_534729444702_item	2686549	et	3	main
maitsev	doc_534729444702_item	2686561	et	4	main
pärast	doc_534729444702_item	2686562	et	4	main
laut	doc_534729444702_item	2686573	et	3	main
põllu	doc_534729444702_item	2686575	et	3	main
sõitasime	doc_534729444702_item	2686579	et	4	main
kõik	doc_534729444702_item	2686580	et	4	main
mmh	doc_534729444703_item	2686621	et	4	main
jalutasime	doc_534729444703_item	2686636	et	3	main
silla	doc_534729444703_item	2686643	et	3	main
me	doc_534729444703_item	2686652	et	4	main
jõudsime	doc_534729444703_item	2686653	et	3	main
jälle	doc_534729444703_item	2686655	et	3	main
pakkisime	doc_534729444703_item	2686657	et	3	main
7	doc_534729444704_item	2686662	et	2	main
september	doc_534729444704_item	2686663	et	3	main
me	doc_534729444704_item	2686664	et	4	main
me	doc_534729444704_item	2686671	et	4	main
me	doc_534729444704_item	2686678	et	4	main
auto	doc_534729444704_item	2686682	et	4	main
me	doc_534729444704_item	2686685	et	4	main
meie	doc_534729444704_item	2686702	et	4	main
lennuk	doc_534729444704_item	2686703	et	3	main
väljub	doc_534729444704_item	2686704	et	3	main
see	doc_534729444704_item	2686711	et	3	main
lend	doc_534729444704_item	2686721	et	3	main
lõbus	doc_534729444704_item	2686724	et	4	main
ja	doc_534729444704_item	2686734	et	3	main
leedus	doc_534729444704_item	2686744	et	4	main
sõime	doc_534729444704_item	2686751	et	4	main
õhtusöök	doc_534729444704_item	2686752	et	3	main
jõime	doc_534729444704_item	2686753	et	3	main
õlud	doc_534729444704_item	2686754	et	4	main
ja	doc_534729444704_item	2686755	et	3	main
pärast	doc_534729444705_item	2686777	et	4	main
hea	doc_534729444705_item	2686785	et	4	main
linnaekskursioon	doc_534729444705_item	2686786	et	3	main
kestis	doc_534729444705_item	2686789	et	4	main
oli	doc_534729444705_item	2686792	et	3	main
kogesime	doc_534729444705_item	2686797	et	3	main
me	doc_534729444705_item	2686801	et	4	main
me	doc_534729444705_item	2686815	et	4	main
kodumaa	doc_534729444702_item	2686543	et	4	main
vana	doc_534729444702_item	2686552	et	4	main
elumaja	doc_534729444702_item	2686553	et	4	main
eesnimi	doc_534729444702_item	2686554	et	3	main
tegis	doc_534729444702_item	2686555	et	4	main
süüa	doc_534729444702_item	2686556	et	3	main
ja	doc_534729444702_item	2686557	et	3	main
ta	doc_534729444702_item	2686558	et	4	main
vanemad	doc_534729444702_item	2686572	et	4	main
tallinnas	doc_534729444702_item	2686576	et	4	main
vaatasime	doc_534729444702_item	2686583	et	3	main
vana	doc_534729444702_item	2686584	et	4	main
klooster	doc_534729444702_item	2686585	et	3	main
ja	doc_534729444702_item	2686586	et	3	main
jalutasime	doc_534729444702_item	2686587	et	3	main
läbi	doc_534729444702_item	2686588	et	4	main
purjetamisadam	doc_534729444702_item	2686589	et	4	main
ja	doc_534729444702_item	2686590	et	3	main
kaifisime	doc_534729444702_item	2686591	et	4	main
ilus	doc_534729444702_item	2686592	et	4	main
päev	doc_534729444702_item	2686593	et	3	main
ja	doc_534729444702_item	2686594	et	3	main
soe	doc_534729444702_item	2686595	et	4	main
päikepaiste	doc_534729444702_item	2686596	et	4	main
päevik	doc_534729444703_item	2686597	et	3	main
6	doc_534729444703_item	2686599	et	2	main
kolmapäev	doc_534729444703_item	2686598	et	3	main
september	doc_534729444703_item	2686600	et	3	main
me	doc_534729444703_item	2686602	et	4	main
pärast	doc_534729444703_item	2686601	et	4	main
sõime	doc_534729444703_item	2686603	et	4	main
hommikust	doc_534729444703_item	2686604	et	4	main
me	doc_534729444703_item	2686605	et	4	main
sõitasime	doc_534729444703_item	2686606	et	4	main
autoga	doc_534729444703_item	2686607	et	3	main
tartusse	doc_534729444703_item	2686608	et	3	main
pärast	doc_534729444703_item	2686609	et	4	main
üks	doc_534729444703_item	2686610	et	3	main
väike	doc_534729444703_item	2686611	et	4	main
jalutuskäik	doc_534729444703_item	2686612	et	3	main
läbi	doc_534729444703_item	2686613	et	4	main
kesklinna	doc_534729444703_item	2686614	et	4	main
tartus	doc_534729444703_item	2686615	et	3	main
sõime	doc_534729444703_item	2686617	et	4	main
lõunat	doc_534729444703_item	2686618	et	3	main
söök	doc_534729444703_item	2686622	et	3	main
on	doc_534729444703_item	2686633	et	4	main
toompeale	doc_534729444703_item	2686637	et	3	main
vana	doc_534729444703_item	2686640	et	4	main
tallinnas	doc_534729444703_item	2686654	et	4	main
me	doc_534729444703_item	2686656	et	4	main
meie	doc_534729444703_item	2686658	et	4	main
pagasi	doc_534729444703_item	2686659	et	3	main
päevik	doc_534729444704_item	2686660	et	3	main
neljapäev	doc_534729444704_item	2686661	et	3	main
koristasime	doc_534729444704_item	2686672	et	3	main
tuba	doc_534729444704_item	2686674	et	4	main
lennukjaamisse	doc_534729444704_item	2686680	et	4	main
tagastasime	doc_534729444704_item	2686681	et	3	main
külastamine	doc_534729444704_item	2686694	et	4	main
eestis	doc_534729444704_item	2686695	et	3	main
minu	doc_534729444704_item	2686705	et	3	main
ema	doc_534729444704_item	2686706	et	4	main
lennuk	doc_534729444704_item	2686712	et	3	main
väga	doc_534729444704_item	2686723	et	3	main
lend	doc_534729444704_item	2686726	et	3	main
hea	doc_534729444704_item	2686728	et	4	main
nüüd	doc_534729444704_item	2686739	et	4	main
olnud	doc_534729444704_item	2686741	et	4	main
sõitasime	doc_534729444704_item	2686746	et	4	main
eesnimi	doc_534729444704_item	2686748	et	3	main
ja	doc_534729444704_item	2686757	et	3	main
reede	doc_534729444705_item	2686762	et	4	main
september	doc_534729444705_item	2686764	et	3	main
kesklinna	doc_534729444705_item	2686770	et	4	main
ja	doc_534729444705_item	2686771	et	3	main
laupäev	doc_534729444705_item	2686774	et	3	main
kolm	doc_534729444705_item	2686787	et	3	main
ja	doc_534729444705_item	2686800	et	3	main
vilnius	doc_534729444705_item	2686805	et	4	main
neljakümmend	doc_534729444705_item	2686807	et	4	main
kiriku	doc_534729444705_item	2686808	et	3	main
see	doc_534729444705_item	2686809	et	3	main
sööki	doc_534729444705_item	2686828	et	4	main
me	doc_534729444705_item	2686830	et	4	main
sõitasime	doc_534729444705_item	2686831	et	4	main
autoga	doc_534729444705_item	2686832	et	3	main
kurgi	doc_534729444705_item	2686840	et	4	main
päev	doc_534729444705_item	2686841	et	3	main
soe	doc_534729444705_item	2686844	et	4	main
palju	doc_534729444705_item	2686850	et	4	main
õhtust	doc_534729444705_item	2686860	et	4	main
ja	doc_534729444705_item	2686861	et	3	main
siis	doc_534729444705_item	2686862	et	3	main
kaua	doc_534729444705_item	2686869	et	3	main
aga	doc_534729444705_item	2686877	et	3	main
parem	doc_534729444705_item	2686881	et	4	main
päevad	doc_534729444705_item	2686882	et	3	main
leedus	doc_534729444705_item	2686883	et	4	main
essee	doc_534729444706_item	2686889	et	4	main
eesti	doc_534729444706_item	2686890	et	4	main
test	doc_534729444706_item	2686895	et	3	main
mis	doc_534729444706_item	2686900	et	4	main
essee	doc_534729444706_item	2686909	et	4	main
ja	doc_534729444706_item	2686914	et	3	main
tuginema	doc_534729444706_item	2686916	et	3	main
loengus	doc_534729444706_item	2686917	et	3	main
esitatud	doc_534729444706_item	2686920	et	4	main
faktidele	doc_534729444706_item	2686921	et	3	main
koostneb	doc_534729444706_item	2686929	et	4	main
laulust	doc_534729444706_item	2686930	et	4	main
tansust	doc_534729444706_item	2686933	et	4	main
kõik	doc_534729444706_item	2686934	et	4	main
väga	doc_534729444706_item	2686939	et	3	main
esimene	doc_534729444706_item	2686948	et	3	main
ja	doc_534729444706_item	2686952	et	3	main
tantsimisega	doc_534729444706_item	2686963	et	4	main
raadiot	doc_534729444706_item	2686967	et	3	main
tantsisid	doc_534729444706_item	2686977	et	4	main
tuju	doc_534729444706_item	2686986	et	4	main
et	doc_534729444706_item	2687023	et	3	main
arust	doc_534729444706_item	2687028	et	4	main
tähtsus	doc_534729444706_item	2687034	et	4	main
1869	doc_534729444706_item	2687038	et	2	main
rahvusliku	doc_534729444706_item	2687050	et	3	main
väga	doc_534729444703_item	2686624	et	3	main
me	doc_534729444703_item	2686630	et	4	main
olime	doc_534729444703_item	2686631	et	3	main
me	doc_534729444703_item	2686635	et	4	main
me	doc_534729444703_item	2686644	et	4	main
läbi	doc_534729444703_item	2686646	et	4	main
supplinna	doc_534729444703_item	2686647	et	4	main
tagasi	doc_534729444703_item	2686648	et	3	main
sõime	doc_534729444704_item	2686665	et	4	main
hommikusöök	doc_534729444704_item	2686666	et	3	main
kell	doc_534729444704_item	2686667	et	3	main
siis	doc_534729444704_item	2686670	et	3	main
läksime	doc_534729444704_item	2686686	et	3	main
ma	doc_534729444704_item	2686688	et	3	main
liiga	doc_534729444704_item	2686696	et	4	main
lühidalt	doc_534729444704_item	2686697	et	4	main
viis	doc_534729444704_item	2686698	et	4	main
minuti	doc_534729444704_item	2686699	et	3	main
pärast	doc_534729444704_item	2686700	et	4	main
üks	doc_534729444704_item	2686701	et	3	main
sest	doc_534729444704_item	2686710	et	4	main
väike	doc_534729444704_item	2686715	et	4	main
vilniusse	doc_534729444704_item	2686733	et	4	main
ema	doc_534729444704_item	2686736	et	4	main
meiele	doc_534729444704_item	2686738	et	4	main
nelja	doc_534729444704_item	2686742	et	4	main
päeva	doc_534729444704_item	2686743	et	4	main
autoga	doc_534729444704_item	2686747	et	3	main
me	doc_534729444704_item	2686750	et	4	main
kaua	doc_534729444704_item	2686759	et	3	main
läbi	doc_534729444705_item	2686769	et	4	main
vaatasime	doc_534729444705_item	2686772	et	3	main
september	doc_534729444705_item	2686776	et	3	main
sõime	doc_534729444705_item	2686779	et	4	main
hommikust	doc_534729444705_item	2686780	et	4	main
tunni	doc_534729444705_item	2686788	et	3	main
see	doc_534729444705_item	2686790	et	3	main
väga	doc_534729444705_item	2686793	et	3	main
palju	doc_534729444705_item	2686803	et	4	main
on	doc_534729444705_item	2686810	et	4	main
hull	doc_534729444705_item	2686812	et	3	main
linnaekskursioon	doc_534729444705_item	2686814	et	3	main
me	doc_534729444705_item	2686822	et	4	main
restorani	doc_534729444705_item	2686824	et	4	main
ja	doc_534729444705_item	2686825	et	3	main
sõime	doc_534729444705_item	2686826	et	4	main
koristade	doc_534729444705_item	2686837	et	4	main
õuna	doc_534729444705_item	2686838	et	4	main
ja	doc_534729444705_item	2686839	et	3	main
mul	doc_534729444705_item	2686848	et	3	main
sõime	doc_534729444705_item	2686859	et	4	main
fotod	doc_534729444705_item	2686866	et	3	main
me	doc_534729444705_item	2686867	et	4	main
olid	doc_534729444705_item	2686884	et	4	main
väga	doc_534729444705_item	2686885	et	3	main
keele	doc_534729444706_item	2686891	et	4	main
kui	doc_534729444706_item	2686892	et	3	main
kirjutage	doc_534729444706_item	2686897	et	3	main
sõna	doc_534729444706_item	2686908	et	4	main
folkloor	doc_534729444706_item	2686928	et	4	main
on	doc_534729444706_item	2686938	et	4	main
esimene	doc_534729444706_item	2686950	et	3	main
pulmapidu	doc_534729444706_item	2686951	et	4	main
teised	doc_534729444706_item	2686954	et	4	main
tähtsad	doc_534729444706_item	2686955	et	3	main
päevad	doc_534729444706_item	2686956	et	3	main
laulmisega	doc_534729444706_item	2686961	et	4	main
hea	doc_534729444706_item	2686985	et	4	main
kindlalt	doc_534729444706_item	2687021	et	4	main
on	doc_534729444706_item	2687025	et	4	main
laulupeodel	doc_534729444706_item	2687030	et	3	main
esimene	doc_534729444706_item	2687035	et	3	main
tartus	doc_534729444706_item	2687040	et	3	main
sai	doc_534729444706_item	2687043	et	4	main
laulupidude	doc_534729444706_item	2687045	et	4	main
ka	doc_534729444706_item	2687048	et	3	main
laulu	doc_534729444706_item	2687056	et	4	main
laulsid	doc_534729444706_item	2687066	et	4	main
kui	doc_534729444706_item	2687067	et	3	main
praegu	doc_534729444706_item	2687079	et	3	main
paremaks	doc_534729444706_item	2687087	et	4	main
eestlastest	doc_534729444706_item	2687088	et	4	main
teevad	doc_534729444706_item	2687089	et	3	main
mitte	doc_534729444706_item	2687091	et	3	main
tihti	doc_534729444706_item	2687096	et	3	main
see	doc_534729444706_item	2687099	et	3	main
laul	doc_534729444706_item	2687108	et	4	main
mis	doc_534729444706_item	2687109	et	4	main
aitas	doc_534729444706_item	2687110	et	3	main
oli	doc_534729444704_item	2686722	et	3	main
sõbranna	doc_534729444704_item	2686735	et	4	main
me	doc_534729444704_item	2686740	et	4	main
koju	doc_534729444704_item	2686749	et	3	main
vestlesime	doc_534729444704_item	2686758	et	3	main
päevik	doc_534729444705_item	2686761	et	3	main
8	doc_534729444705_item	2686763	et	2	main
ainult	doc_534729444705_item	2686767	et	4	main
jalutasime	doc_534729444705_item	2686768	et	3	main
me	doc_534729444705_item	2686781	et	4	main
saime	doc_534729444705_item	2686782	et	3	main
üks	doc_534729444705_item	2686783	et	3	main
väga	doc_534729444705_item	2686784	et	3	main
me	doc_534729444705_item	2686796	et	4	main
leedule	doc_534729444705_item	2686799	et	4	main
kiriku	doc_534729444705_item	2686804	et	3	main
omas	doc_534729444705_item	2686806	et	4	main
väga	doc_534729444705_item	2686811	et	3	main
olime	doc_534729444705_item	2686816	et	3	main
väsinud	doc_534729444705_item	2686817	et	4	main
ja	doc_534729444705_item	2686818	et	3	main
meie	doc_534729444705_item	2686819	et	4	main
jalad	doc_534729444705_item	2686820	et	3	main
läksime	doc_534729444705_item	2686823	et	3	main
pärastlõunal	doc_534729444705_item	2686829	et	3	main
väga	doc_534729444705_item	2686843	et	3	main
päikepaisteline	doc_534729444705_item	2686846	et	4	main
oli	doc_534729444705_item	2686849	et	3	main
lõbus	doc_534729444705_item	2686851	et	4	main
vestlesime	doc_534729444705_item	2686868	et	3	main
vilnius	doc_534729444705_item	2686871	et	4	main
tallinn	doc_534729444705_item	2686878	et	4	main
mulle	doc_534729444705_item	2686880	et	4	main
teise	doc_534729444706_item	2686893	et	4	main
keele	doc_534729444706_item	2686894	et	4	main
essee	doc_534729444706_item	2686898	et	4	main
essee	doc_534729444706_item	2686904	et	4	main
pikkus	doc_534729444706_item	2686905	et	4	main
300	doc_534729444706_item	2686906	et	2	main
350	doc_534729444706_item	2686907	et	2	main
arutlev	doc_534729444706_item	2686912	et	4	main
üldistav	doc_534729444706_item	2686915	et	4	main
ja	doc_534729444706_item	2686918	et	3	main
väiteid	doc_534729444706_item	2686922	et	4	main
soovitatav	doc_534729444706_item	2686924	et	4	main
illustreerida	doc_534729444706_item	2686925	et	3	main
pillimängust	doc_534729444706_item	2686931	et	3	main
kolm	doc_534729444706_item	2686936	et	3	main
tähtsad	doc_534729444706_item	2686940	et	3	main
elus	doc_534729444706_item	2686942	et	4	main
saadavad	doc_534729444706_item	2686944	et	4	main
sünnipäev	doc_534729444706_item	2686949	et	3	main
elus	doc_534729444706_item	2686957	et	4	main
on	doc_534729444706_item	2686958	et	4	main
inimesed	doc_534729444706_item	2686965	et	3	main
ja	doc_534729444706_item	2686968	et	3	main
miks	doc_534729444706_item	2686979	et	4	main
iga	doc_534729444706_item	2686980	et	4	main
õhtusse	doc_534729444704_item	2686760	et	4	main
täna	doc_534729444705_item	2686765	et	4	main
me	doc_534729444705_item	2686766	et	4	main
see	doc_534729444705_item	2686773	et	3	main
9	doc_534729444705_item	2686775	et	2	main
me	doc_534729444705_item	2686778	et	4	main
linnaekskursioon	doc_534729444705_item	2686791	et	3	main
huvitav	doc_534729444705_item	2686794	et	4	main
sest	doc_534729444705_item	2686795	et	4	main
ajalugu	doc_534729444705_item	2686798	et	4	main
vaatasime	doc_534729444705_item	2686802	et	3	main
pärast	doc_534729444705_item	2686813	et	4	main
valutasime	doc_534729444705_item	2686821	et	3	main
me	doc_534729444705_item	2686835	et	4	main
aitasime	doc_534729444705_item	2686836	et	3	main
ilus	doc_534729444705_item	2686875	et	4	main
linn	doc_534729444705_item	2686876	et	3	main
hea	doc_534729444705_item	2686886	et	4	main
teemal	doc_534729444706_item	2686899	et	3	main
teeb	doc_534729444706_item	2686901	et	3	main
laulurahva	doc_534729444706_item	2686903	et	3	main
olema	doc_534729444706_item	2686911	et	4	main
on	doc_534729444706_item	2686923	et	4	main
näidetega	doc_534729444706_item	2686926	et	3	main
eesti	doc_534729444706_item	2686927	et	4	main
ja	doc_534729444706_item	2686932	et	3	main
need	doc_534729444706_item	2686935	et	3	main
asja	doc_534729444706_item	2686937	et	4	main
inimeste	doc_534729444706_item	2686941	et	3	main
nad	doc_534729444706_item	2686943	et	3	main
inimest	doc_534729444706_item	2686945	et	3	main
hauani	doc_534729444706_item	2686947	et	3	main
paljud	doc_534729444706_item	2686953	et	3	main
ja	doc_534729444706_item	2686962	et	3	main
vaatavat	doc_534729444706_item	2686969	et	4	main
telerit	doc_534729444706_item	2686970	et	3	main
aga	doc_534729444706_item	2686971	et	3	main
vanasti	doc_534729444706_item	2686972	et	3	main
nad	doc_534729444706_item	2686973	et	3	main
laulsid	doc_534729444706_item	2686974	et	4	main
rahvatantsu	doc_534729444706_item	2686978	et	4	main
kord	doc_534729444706_item	2686981	et	4	main
kui	doc_534729444706_item	2686982	et	3	main
meil	doc_534729444706_item	2686983	et	4	main
või	doc_534729444706_item	2686987	et	4	main
minu	doc_534729444706_item	2687027	et	3	main
suur	doc_534729444706_item	2687033	et	3	main
toimus	doc_534729444706_item	2687037	et	3	main
ja	doc_534729444706_item	2687041	et	3	main
laulsid	doc_534729444706_item	2687061	et	4	main
kui	doc_534729444706_item	2687062	et	3	main
näidata	doc_534729444706_item	2687069	et	4	main
et	doc_534729444706_item	2687070	et	3	main
rahvas	doc_534729444706_item	2687071	et	4	main
võitleb	doc_534729444706_item	2687072	et	3	main
probleemide	doc_534729444706_item	2687073	et	3	main
rahvas	doc_534729444706_item	2687076	et	4	main
et	doc_534729444706_item	2687080	et	3	main
teistele	doc_534729444706_item	2687082	et	4	main
ja	doc_534729444706_item	2687083	et	3	main
ise	doc_534729444706_item	2687084	et	4	main
ainult	doc_534729444706_item	2687092	et	4	main
mis	doc_534729444706_item	2687094	et	4	main
toimuvad	doc_534729444706_item	2687095	et	4	main
vaid	doc_534729444706_item	2687097	et	3	main
inimeste	doc_534729444706_item	2687101	et	3	main
ja	doc_534729444706_item	2687104	et	3	main
elas	doc_534729444706_item	2687107	et	3	main
rahvalaulud	doc_534729444706_item	2687117	et	3	main
on	doc_534729444706_item	2687118	et	4	main
on	doc_534729444706_item	2687123	et	4	main
väga	doc_534729444706_item	2687124	et	3	main
tähtis	doc_534729444706_item	2687125	et	4	main
oma	doc_534729444706_item	2687132	et	4	main
sugulastele	doc_534729444706_item	2687133	et	4	main
ja	doc_534729444706_item	2687134	et	3	main
levis	doc_534729444706_item	2687137	et	4	main
aga	doc_534729444706_item	2687138	et	3	main
levimist	doc_534729444706_item	2687141	et	4	main
aitas	doc_534729444706_item	2687142	et	3	main
ka	doc_534729444706_item	2687143	et	3	main
bändid	doc_534729444706_item	2687157	et	4	main
maitsev	doc_534729444705_item	2686827	et	4	main
eesnimi	doc_534729444705_item	2686833	et	3	main
aedisse	doc_534729444705_item	2686834	et	4	main
oli	doc_534729444705_item	2686842	et	3	main
ja	doc_534729444705_item	2686845	et	3	main
ja	doc_534729444705_item	2686847	et	3	main
pärast	doc_534729444705_item	2686852	et	4	main
kaks	doc_534729444705_item	2686853	et	3	main
tunni	doc_534729444705_item	2686854	et	3	main
aedis	doc_534729444705_item	2686855	et	4	main
me	doc_534729444705_item	2686856	et	4	main
sõitasime	doc_534729444705_item	2686857	et	4	main
koju	doc_534729444705_item	2686858	et	3	main
me	doc_534729444705_item	2686863	et	4	main
vaatasime	doc_534729444705_item	2686864	et	3	main
vana	doc_534729444705_item	2686865	et	4	main
õhtusse	doc_534729444705_item	2686870	et	4	main
on	doc_534729444705_item	2686872	et	4	main
vana	doc_534729444705_item	2686873	et	4	main
ja	doc_534729444705_item	2686874	et	3	main
meeldib	doc_534729444705_item	2686879	et	3	main
ja	doc_534729444705_item	2686887	et	3	main
kosutav	doc_534729444705_item	2686888	et	4	main
kirjutamine	doc_534729444706_item	2686896	et	4	main
eestlastest	doc_534729444706_item	2686902	et	4	main
peab	doc_534729444706_item	2686910	et	4	main
analüüsiv	doc_534729444706_item	2686913	et	4	main
lugemistekstis	doc_534729444706_item	2686919	et	3	main
hällist	doc_534729444706_item	2686946	et	4	main
alati	doc_534729444706_item	2686959	et	4	main
seotud	doc_534729444706_item	2686960	et	4	main
tänapäevadel	doc_534729444706_item	2686964	et	3	main
kuulavat	doc_534729444706_item	2686966	et	4	main
rahvalaule	doc_534729444706_item	2686975	et	4	main
ja	doc_534729444706_item	2686976	et	3	main
on	doc_534729444706_item	2686984	et	4	main
vastupidi	doc_534729444706_item	2686988	et	3	main
väga	doc_534729444706_item	2686989	et	3	main
kurb	doc_534729444706_item	2686990	et	3	main
me	doc_534729444706_item	2686991	et	4	main
tuletame	doc_534729444706_item	2686992	et	3	main
meelde	doc_534729444706_item	2686993	et	3	main
oma	doc_534729444706_item	2686994	et	4	main
lemmiklaule	doc_534729444706_item	2686995	et	4	main
vist	doc_534729444706_item	2686996	et	4	main
selle	doc_534729444706_item	2686997	et	4	main
pärast	doc_534729444706_item	2686998	et	4	main
et	doc_534729444706_item	2686999	et	3	main
ilma	doc_534729444706_item	2687000	et	4	main
lauluta	doc_534729444706_item	2687001	et	3	main
meie	doc_534729444706_item	2687002	et	4	main
on	doc_534729444706_item	2687004	et	4	main
väga	doc_534729444706_item	2687005	et	3	main
elu	doc_534729444706_item	2687003	et	4	main
tavaline	doc_534729444706_item	2687006	et	4	main
ja	doc_534729444706_item	2687007	et	3	main
hall	doc_534729444706_item	2687008	et	4	main
kuna	doc_534729444706_item	2687009	et	3	main
ma	doc_534729444706_item	2687010	et	3	main
olen	doc_534729444706_item	2687011	et	3	main
sündinud	doc_534729444706_item	2687012	et	4	main
eestis	doc_534729444706_item	2687013	et	3	main
ja	doc_534729444706_item	2687014	et	3	main
mul	doc_534729444706_item	2687015	et	3	main
palju	doc_534729444706_item	2687017	et	4	main
eestisõpru	doc_534729444706_item	2687018	et	3	main
on	doc_534729444706_item	2687016	et	4	main
ma	doc_534729444706_item	2687019	et	3	main
võin	doc_534729444706_item	2687020	et	3	main
eesti	doc_534729444706_item	2687029	et	4	main
väga	doc_534729444706_item	2687032	et	3	main
laulupidu	doc_534729444706_item	2687036	et	4	main
aastal	doc_534729444706_item	2687039	et	3	main
sellest	doc_534729444706_item	2687042	et	4	main
traditsioon	doc_534729444706_item	2687046	et	3	main
liikumise	doc_534729444706_item	2687051	et	4	main
kõrghetk	doc_534729444706_item	2687052	et	3	main
öelda	doc_534729444706_item	2687022	et	4	main
eestlased	doc_534729444706_item	2687024	et	3	main
laulurahvas	doc_534729444706_item	2687026	et	4	main
on	doc_534729444706_item	2687031	et	4	main
alguse	doc_534729444706_item	2687044	et	3	main
samuti	doc_534729444706_item	2687047	et	3	main
kujunes	doc_534729444706_item	2687049	et	3	main
tegid	doc_534729444706_item	2687063	et	4	main
rasket	doc_534729444706_item	2687064	et	3	main
tuju	doc_534729444706_item	2687086	et	4	main
laulupeod	doc_534729444706_item	2687093	et	4	main
elab	doc_534729444706_item	2687103	et	3	main
kõik	doc_534729444706_item	2687114	et	4	main
tänapäevadeni	doc_534729444706_item	2687120	et	3	main
rahvalaulude	doc_534729444706_item	2687121	et	3	main
asi	doc_534729444706_item	2687126	et	4	main
vanasti	doc_534729444706_item	2687127	et	3	main
inimesed	doc_534729444706_item	2687128	et	3	main
pillide	doc_534729444706_item	2687144	et	3	main
sajandist	doc_534729444706_item	2687148	et	3	main
hakkasid	doc_534729444706_item	2687150	et	4	main
rahvasliku	doc_534729444706_item	2687152	et	4	main
segavad	doc_534729444706_item	2687158	et	4	main
tähtsust	doc_534729444706_item	2687180	et	4	main
tahan	doc_534729444706_item	2687183	et	3	main
seda	doc_534729444706_item	2687185	et	3	main
et	doc_534729444706_item	2687226	et	3	main
neil	doc_534729444706_item	2687236	et	4	main
juba	doc_534729444706_item	2687237	et	3	main
seda	doc_534729444706_item	2687244	et	3	main
rahvalaulud	doc_534729444706_item	2687246	et	3	main
säilinud	doc_534729444706_item	2687248	et	4	main
eestis	doc_534729444706_item	2687250	et	3	main
on	doc_534729444706_item	2687261	et	4	main
eesti	doc_534729444707_item	2687264	et	4	main
essee	doc_534729444707_item	2687272	et	4	main
essee	doc_534729444707_item	2687278	et	4	main
300	doc_534729444707_item	2687280	et	2	main
sõna	doc_534729444707_item	2687282	et	4	main
olemas	doc_534729444707_item	2687310	et	4	main
juba	doc_534729444707_item	2687311	et	3	main
vanal	doc_534729444707_item	2687312	et	3	main
edasi	doc_534729444707_item	2687321	et	3	main
palju	doc_534729444707_item	2687323	et	4	main
ja	doc_534729444707_item	2687325	et	3	main
kohe	doc_534729444707_item	2687340	et	4	main
ka	doc_534729444707_item	2687341	et	3	main
mis	doc_534729444707_item	2687347	et	4	main
mida	doc_534729444707_item	2687356	et	4	main
iganes	doc_534729444707_item	2687357	et	4	main
naised	doc_534729444707_item	2687358	et	3	main
kellegile	doc_534729444707_item	2687401	et	4	main
vahel	doc_534729444707_item	2687404	et	4	main
pärandati	doc_534729444707_item	2687415	et	4	main
mälule	doc_534729444707_item	2687420	et	3	main
ja	doc_534729444707_item	2687421	et	3	main
ja	doc_534729444707_item	2687423	et	3	main
sajandil	doc_534729444707_item	2687426	et	3	main
hakkati	doc_534729444707_item	2687428	et	3	main
kannel	doc_534729444707_item	2687440	et	4	main
ja	doc_534729444707_item	2687441	et	3	main
olid	doc_534729444707_item	2687451	et	4	main
meestekoorid	doc_534729444707_item	2687452	et	3	main
ja	doc_534729444707_item	2687453	et	3	main
hakkasid	doc_534729444707_item	2687457	et	4	main
naiskoorid	doc_534729444707_item	2687459	et	3	main
hiljuti	doc_534729444707_item	2687461	et	4	main
mis	doc_534729444707_item	2687469	et	4	main
tekkis	doc_534729444707_item	2687470	et	3	main
kirikus	doc_534729444707_item	2687471	et	3	main
rahvuslik	doc_534729444707_item	2687478	et	3	main
muusika-	doc_534729444707_item	2687482	et	4	main
ning	doc_534729444707_item	2687483	et	3	main
lauluharrastus	doc_534729444707_item	2687484	et	3	main
ja	doc_534729444707_item	2687485	et	3	main
juba	doc_534729444707_item	2687486	et	3	main
1869	doc_534729444707_item	2687487	et	2	main
aastal	doc_534729444707_item	2687488	et	3	main
sündis	doc_534729444707_item	2687489	et	3	main
mis	doc_534729444707_item	2687493	et	4	main
laulupidu	doc_534729444707_item	2687504	et	4	main
korrati	doc_534729444707_item	2687505	et	4	main
ka	doc_534729444707_item	2687506	et	3	main
eesti	doc_534729444706_item	2687053	et	4	main
rahvas	doc_534729444706_item	2687054	et	4	main
viib	doc_534729444706_item	2687055	et	3	main
tööd	doc_534729444706_item	2687065	et	4	main
vastu	doc_534729444706_item	2687074	et	3	main
laulab	doc_534729444706_item	2687077	et	3	main
ka	doc_534729444706_item	2687078	et	3	main
teha	doc_534729444706_item	2687081	et	3	main
endale	doc_534729444706_item	2687085	et	4	main
laulurahva	doc_534729444706_item	2687090	et	3	main
just	doc_534729444706_item	2687098	et	3	main
et	doc_534729444706_item	2687100	et	3	main
säilinud	doc_534729444706_item	2687119	et	4	main
levimine	doc_534729444706_item	2687122	et	4	main
sõnad	doc_534729444706_item	2687131	et	4	main
mõnede	doc_534729444706_item	2687139	et	3	main
19	doc_534729444706_item	2687147	et	2	main
mõned	doc_534729444706_item	2687156	et	3	main
teiste	doc_534729444706_item	2687161	et	4	main
arvates	doc_534729444706_item	2687165	et	4	main
see	doc_534729444706_item	2687166	et	3	main
et	doc_534729444706_item	2687171	et	3	main
ole	doc_534729444706_item	2687176	et	4	main
maani	doc_534729444706_item	2687178	et	3	main
oma	doc_534729444706_item	2687179	et	4	main
palju	doc_534729444706_item	2687188	et	4	main
lauldes	doc_534729444706_item	2687223	et	3	main
rahvas	doc_534729444706_item	2687228	et	4	main
väga	doc_534729444706_item	2687230	et	3	main
sest	doc_534729444706_item	2687233	et	4	main
laul	doc_534729444706_item	2687234	et	4	main
toimuvad	doc_534729444706_item	2687251	et	4	main
kõige	doc_534729444706_item	2687252	et	4	main
eesti	doc_534729444706_item	2687259	et	4	main
laulurahvas	doc_534729444706_item	2687262	et	4	main
kirjutamine	doc_534729444707_item	2687270	et	4	main
kirjutage	doc_534729444707_item	2687271	et	3	main
eestlastest	doc_534729444707_item	2687276	et	4	main
pikkus	doc_534729444707_item	2687279	et	4	main
arutlev	doc_534729444707_item	2687286	et	4	main
analüüsiv	doc_534729444707_item	2687287	et	4	main
ja	doc_534729444707_item	2687288	et	3	main
üldistav	doc_534729444707_item	2687289	et	4	main
esitatud	doc_534729444707_item	2687294	et	4	main
näidetega	doc_534729444707_item	2687300	et	3	main
omad	doc_534729444707_item	2687304	et	4	main
traditsioonid	doc_534729444707_item	2687305	et	3	main
lauldi	doc_534729444707_item	2687324	et	3	main
pandi	doc_534729444707_item	2687326	et	4	main
tähelepanu	doc_534729444707_item	2687327	et	4	main
lauludele	doc_534729444707_item	2687328	et	3	main
laulmine	doc_534729444707_item	2687329	et	4	main
kujunes	doc_534729444707_item	2687330	et	3	main
massiharrastuseks	doc_534729444707_item	2687331	et	3	main
ja	doc_534729444707_item	2687332	et	3	main
eestlase	doc_534729444707_item	2687333	et	3	main
laulupidu	doc_534729444707_item	2687342	et	4	main
ja	doc_534729444707_item	2687343	et	3	main
siis	doc_534729444707_item	2687348	et	3	main
laulmise	doc_534729444707_item	2687353	et	4	main
tehti	doc_534729444707_item	2687355	et	3	main
said	doc_534729444707_item	2687364	et	4	main
või	doc_534729444707_item	2687365	et	4	main
kui	doc_534729444707_item	2687366	et	3	main
nad	doc_534729444707_item	2687367	et	3	main
tegid	doc_534729444707_item	2687368	et	4	main
laulsid	doc_534729444707_item	2687400	et	4	main
läbi	doc_534729444706_item	2687057	et	4	main
terve	doc_534729444706_item	2687058	et	4	main
elu	doc_534729444706_item	2687059	et	4	main
eestlased	doc_534729444706_item	2687060	et	3	main
tahtsid	doc_534729444706_item	2687068	et	4	main
eesti	doc_534729444706_item	2687075	et	4	main
hinges	doc_534729444706_item	2687102	et	4	main
kogu	doc_534729444706_item	2687105	et	4	main
aeg	doc_534729444706_item	2687106	et	3	main
unistused	doc_534729444706_item	2687115	et	4	main
mõned	doc_534729444706_item	2687116	et	3	main
rahvale	doc_534729444706_item	2687111	et	3	main
viia	doc_534729444706_item	2687112	et	3	main
ellu	doc_534729444706_item	2687113	et	4	main
nii	doc_534729444706_item	2687135	et	3	main
see	doc_534729444706_item	2687136	et	3	main
laulude	doc_534729444706_item	2687140	et	3	main
alates	doc_534729444706_item	2687146	et	3	main
kasutama	doc_534729444706_item	2687151	et	3	main
muusika	doc_534729444706_item	2687153	et	4	main
stiili	doc_534729444706_item	2687154	et	4	main
tänapäevadel	doc_534729444706_item	2687155	et	3	main
rahvalaulud	doc_534729444706_item	2687159	et	3	main
näitab	doc_534729444706_item	2687169	et	3	main
jaoks	doc_534729444706_item	2687173	et	4	main
rahvalaul	doc_534729444706_item	2687174	et	4	main
ei	doc_534729444706_item	2687175	et	4	main
kokkuvõtteks	doc_534729444706_item	2687182	et	3	main
ajaloolisi	doc_534729444706_item	2687189	et	4	main
on	doc_534729444706_item	2687191	et	4	main
teha	doc_534729444706_item	2687221	et	3	main
kindel	doc_534729444706_item	2687225	et	3	main
on	doc_534729444706_item	2687229	et	4	main
rahvas	doc_534729444706_item	2687232	et	4	main
ainult	doc_534729444706_item	2687241	et	4	main
laulupeod	doc_534729444706_item	2687242	et	4	main
uhked	doc_534729444706_item	2687255	et	4	main
laulupeod	doc_534729444706_item	2687256	et	4	main
ja	doc_534729444706_item	2687257	et	3	main
loomulikult	doc_534729444706_item	2687258	et	4	main
essee	doc_534729444707_item	2687263	et	4	main
keele	doc_534729444707_item	2687265	et	4	main
kui	doc_534729444707_item	2687266	et	3	main
teise	doc_534729444707_item	2687267	et	4	main
teemal	doc_534729444707_item	2687273	et	3	main
mis	doc_534729444707_item	2687274	et	4	main
teeb	doc_534729444707_item	2687275	et	3	main
olema	doc_534729444707_item	2687285	et	4	main
lugemistekstis	doc_534729444707_item	2687293	et	3	main
faktidele	doc_534729444707_item	2687295	et	3	main
väiteid	doc_534729444707_item	2687296	et	4	main
rahval	doc_534729444707_item	2687302	et	3	main
eestlastel	doc_534729444707_item	2687307	et	4	main
need	doc_534729444707_item	2687308	et	3	main
eriti	doc_534729444707_item	2687322	et	3	main
sõnadega	doc_534729444707_item	2687336	et	3	main
tekkib	doc_534729444707_item	2687344	et	3	main
eestlastest	doc_534729444707_item	2687350	et	4	main
vanasti	doc_534729444707_item	2687352	et	3	main
ajal	doc_534729444707_item	2687354	et	4	main
laulsid	doc_534729444707_item	2687360	et	4	main
kokku	doc_534729444707_item	2687363	et	3	main
või	doc_534729444707_item	2687370	et	4	main
oma	doc_534729444707_item	2687403	et	4	main
tuleb	doc_534729444707_item	2687406	et	3	main
et	doc_534729444707_item	2687408	et	3	main
vanasti	doc_534729444707_item	2687409	et	3	main
oli	doc_534729444707_item	2687410	et	3	main
ainult	doc_534729444707_item	2687411	et	4	main
vokaalne	doc_534729444707_item	2687412	et	3	main
rahvalaul	doc_534729444707_item	2687413	et	4	main
traditsioonidele	doc_534729444707_item	2687422	et	3	main
ainult	doc_534729444707_item	2687424	et	4	main
sellised	doc_534729444707_item	2687437	et	4	main
instrumendid	doc_534729444707_item	2687438	et	3	main
nagu	doc_534729444707_item	2687439	et	3	main
aastal	doc_534729444707_item	2687456	et	3	main
laulma	doc_534729444707_item	2687458	et	3	main
ja	doc_534729444707_item	2687460	et	3	main
lastekoorid	doc_534729444707_item	2687462	et	3	main
ja	doc_534729444707_item	2687463	et	3	main
poistekoorid	doc_534729444707_item	2687464	et	3	main
niimodi	doc_534729444707_item	2687465	et	4	main
sajandi	doc_534729444707_item	2687474	et	3	main
ülemaaline	doc_534729444707_item	2687491	et	4	main
korrati	doc_534729444707_item	2687494	et	4	main
hiljuti	doc_534729444707_item	2687502	et	4	main
on	doc_534729444707_item	2687510	et	4	main
küll	doc_534729444707_item	2687530	et	4	main
et	doc_534729444707_item	2687539	et	3	main
teeb	doc_534729444707_item	2687541	et	3	main
nende	doc_534729444707_item	2687546	et	4	main
rääkisid	doc_534729444706_item	2687129	et	4	main
laulu	doc_534729444706_item	2687130	et	4	main
levimine	doc_534729444706_item	2687145	et	4	main
heliloojad	doc_534729444706_item	2687149	et	3	main
veel	doc_534729444706_item	2687167	et	4	main
kord	doc_534729444706_item	2687168	et	4	main
eestlaste	doc_534729444706_item	2687172	et	4	main
siia	doc_534729444706_item	2687177	et	4	main
kaotanud	doc_534729444706_item	2687181	et	4	main
öelda	doc_534729444706_item	2687184	et	4	main
et	doc_534729444706_item	2687186	et	3	main
väga	doc_534729444706_item	2687187	et	3	main
sündmusi	doc_534729444706_item	2687190	et	3	main
eestlastel	doc_534729444706_item	2687192	et	4	main
seotud	doc_534729444706_item	2687193	et	4	main
lauluga	doc_534729444706_item	2687194	et	4	main
nad	doc_534729444706_item	2687195	et	3	main
ei	doc_534729444706_item	2687196	et	4	main
tee	doc_534729444706_item	2687197	et	4	main
seda	doc_534729444706_item	2687198	et	3	main
meelega	doc_534729444706_item	2687199	et	4	main
vaid	doc_534729444706_item	2687200	et	3	main
see	doc_534729444706_item	2687201	et	3	main
tuleb	doc_534729444706_item	2687202	et	3	main
ise	doc_534729444706_item	2687203	et	4	main
endast	doc_534729444706_item	2687204	et	4	main
inimeste	doc_534729444706_item	2687205	et	3	main
hingedest	doc_534729444706_item	2687206	et	3	main
ma	doc_534729444706_item	2687207	et	3	main
arvan	doc_534729444706_item	2687208	et	3	main
et	doc_534729444706_item	2687209	et	3	main
paljudel	doc_534729444706_item	2687210	et	3	main
rahvadel	doc_534729444706_item	2687211	et	4	main
tuleb	doc_534729444706_item	2687212	et	3	main
eestlastest	doc_534729444706_item	2687213	et	4	main
õppida	doc_534729444706_item	2687214	et	3	main
minna	doc_534729444706_item	2687215	et	3	main
lauluga	doc_534729444706_item	2687216	et	4	main
läbi	doc_534729444706_item	2687217	et	4	main
ellu	doc_534729444706_item	2687218	et	4	main
ja	doc_534729444706_item	2687219	et	3	main
kõike	doc_534729444706_item	2687220	et	4	main
koos	doc_534729444706_item	2687160	et	4	main
muusika	doc_534729444706_item	2687162	et	4	main
stiilidega	doc_534729444706_item	2687163	et	3	main
minu	doc_534729444706_item	2687164	et	3	main
seda	doc_534729444706_item	2687170	et	3	main
eesti	doc_534729444706_item	2687227	et	4	main
õnnelik	doc_534729444706_item	2687231	et	3	main
veres	doc_534729444706_item	2687238	et	3	main
ja	doc_534729444706_item	2687239	et	3	main
mitte	doc_534729444706_item	2687240	et	3	main
eesti	doc_534729444706_item	2687245	et	4	main
ilusamad	doc_534729444706_item	2687253	et	4	main
ja	doc_534729444706_item	2687254	et	3	main
rahvas	doc_534729444706_item	2687260	et	4	main
essee	doc_534729444707_item	2687283	et	4	main
peab	doc_534729444707_item	2687284	et	4	main
tuginema	doc_534729444707_item	2687290	et	3	main
loengus	doc_534729444707_item	2687291	et	3	main
ja	doc_534729444707_item	2687292	et	3	main
igal	doc_534729444707_item	2687301	et	3	main
rahvas	doc_534729444707_item	2687337	et	4	main
ja	doc_534729444707_item	2687338	et	3	main
laul	doc_534729444707_item	2687339	et	4	main
kohe	doc_534729444707_item	2687345	et	4	main
teeb	doc_534729444707_item	2687349	et	3	main
kui	doc_534729444707_item	2687361	et	3	main
nad	doc_534729444707_item	2687362	et	3	main
või	doc_534729444707_item	2687402	et	4	main
siit	doc_534729444707_item	2687405	et	3	main
välja	doc_534729444707_item	2687407	et	4	main
põlvest	doc_534729444707_item	2687416	et	4	main
põlve	doc_534729444707_item	2687417	et	4	main
suuliselt	doc_534729444707_item	2687418	et	4	main
ilmusid	doc_534729444707_item	2687436	et	4	main
kooridest	doc_534729444707_item	2687446	et	3	main
siis	doc_534729444707_item	2687447	et	3	main
kõige	doc_534729444707_item	2687448	et	4	main
esimesed	doc_534729444707_item	2687449	et	3	main
koorid	doc_534729444707_item	2687450	et	4	main
sündis	doc_534729444707_item	2687466	et	3	main
uus	doc_534729444707_item	2687467	et	3	main
rahvalaul	doc_534729444707_item	2687468	et	4	main
lõppus	doc_534729444707_item	2687475	et	4	main
oli	doc_534729444707_item	2687476	et	3	main
esimene	doc_534729444707_item	2687490	et	3	main
oli	doc_534729444707_item	2687497	et	3	main
jannseni	doc_534729444707_item	2687500	et	4	main
tallinnas	doc_534729444707_item	2687507	et	4	main
sest	doc_534729444707_item	2687532	et	4	main
nad	doc_534729444707_item	2687533	et	3	main
nagu	doc_534729444707_item	2687545	et	3	main
traditsioonid	doc_534729444707_item	2687548	et	3	main
väga	doc_534729444707_item	2687552	et	3	main
sest	doc_534729444707_item	2687554	et	4	main
niimoodi	doc_534729444707_item	2687555	et	3	main
nad	doc_534729444707_item	2687556	et	3	main
tuletavad	doc_534729444707_item	2687557	et	4	main
meelde	doc_534729444707_item	2687558	et	3	main
nii	doc_534729444707_item	2687565	et	3	main
halvas	doc_534729444707_item	2687566	et	4	main
kui	doc_534729444707_item	2687568	et	3	main
edasi	doc_534729444707_item	2687582	et	3	main
on	doc_534729444707_item	2687586	et	4	main
hea	doc_534729444707_item	2687587	et	4	main
ainult	doc_534729444706_item	2687222	et	4	main
olen	doc_534729444706_item	2687224	et	3	main
on	doc_534729444706_item	2687235	et	4	main
näitavad	doc_534729444706_item	2687243	et	4	main
on	doc_534729444706_item	2687247	et	4	main
siiamaani	doc_534729444706_item	2687249	et	3	main
keele	doc_534729444707_item	2687268	et	4	main
test	doc_534729444707_item	2687269	et	3	main
laulurahva	doc_534729444707_item	2687277	et	3	main
350	doc_534729444707_item	2687281	et	2	main
on	doc_534729444707_item	2687297	et	4	main
soovitatav	doc_534729444707_item	2687298	et	4	main
illustreerida	doc_534729444707_item	2687299	et	3	main
on	doc_534729444707_item	2687303	et	4	main
ka	doc_534729444707_item	2687306	et	3	main
on	doc_534729444707_item	2687309	et	4	main
ajal	doc_534729444707_item	2687313	et	4	main
eestlased	doc_534729444707_item	2687314	et	3	main
laulsid	doc_534729444707_item	2687315	et	4	main
tantsisid	doc_534729444707_item	2687316	et	4	main
tähistasid	doc_534729444707_item	2687317	et	4	main
peod	doc_534729444707_item	2687318	et	4	main
ja	doc_534729444707_item	2687319	et	3	main
nii	doc_534729444707_item	2687320	et	3	main
jaoks	doc_534729444707_item	2687334	et	4	main
seostub	doc_534729444707_item	2687335	et	3	main
küsimus	doc_534729444707_item	2687346	et	4	main
laulurahva	doc_534729444707_item	2687351	et	3	main
näiteks	doc_534729444707_item	2687359	et	4	main
käsitööid	doc_534729444707_item	2687369	et	4	main
isegi	doc_534729444707_item	2687371	et	4	main
kui	doc_534729444707_item	2687372	et	3	main
ema	doc_534729444707_item	2687373	et	4	main
kiigutas	doc_534729444707_item	2687374	et	3	main
last	doc_534729444707_item	2687375	et	4	main
ja	doc_534729444707_item	2687376	et	3	main
siis	doc_534729444707_item	2687377	et	3	main
samal	doc_534729444707_item	2687378	et	3	main
ajal	doc_534729444707_item	2687379	et	4	main
ta	doc_534729444707_item	2687380	et	4	main
võis	doc_534729444707_item	2687381	et	4	main
laulda	doc_534729444707_item	2687382	et	4	main
muinasjutte	doc_534729444707_item	2687383	et	3	main
ka	doc_534729444707_item	2687384	et	3	main
mehed	doc_534729444707_item	2687385	et	3	main
laulsid	doc_534729444707_item	2687386	et	4	main
näiteks	doc_534729444707_item	2687387	et	4	main
kui	doc_534729444707_item	2687388	et	3	main
tegid	doc_534729444707_item	2687389	et	4	main
mingit	doc_534729444707_item	2687390	et	3	main
tööd	doc_534729444707_item	2687391	et	4	main
või	doc_534729444707_item	2687392	et	4	main
pulmadel	doc_534729444707_item	2687393	et	3	main
kui	doc_534729444707_item	2687394	et	3	main
neid	doc_534729444707_item	2687395	et	4	main
kutsuti	doc_534729444707_item	2687396	et	3	main
sinna	doc_534729444707_item	2687397	et	3	main
ning	doc_534729444707_item	2687398	et	3	main
lapsed	doc_534729444707_item	2687399	et	3	main
mis	doc_534729444707_item	2687414	et	4	main
tuginedes	doc_534729444707_item	2687419	et	3	main
19	doc_534729444707_item	2687425	et	2	main
ja	doc_534729444707_item	2687434	et	3	main
lõtspill	doc_534729444707_item	2687442	et	4	main
aga	doc_534729444707_item	2687443	et	3	main
kui	doc_534729444707_item	2687444	et	3	main
siis	doc_534729444707_item	2687454	et	3	main
19	doc_534729444707_item	2687473	et	2	main
laulupidu	doc_534729444707_item	2687492	et	4	main
tartus	doc_534729444707_item	2687495	et	3	main
see	doc_534729444707_item	2687496	et	3	main
johann	doc_534729444707_item	2687498	et	4	main
voldemar	doc_534729444707_item	2687499	et	4	main
see	doc_534729444707_item	2687503	et	3	main
iga	doc_534729444707_item	2687516	et	4	main
laulurahvas	doc_534729444707_item	2687531	et	4	main
eestlasi	doc_534729444707_item	2687540	et	3	main
sellised	doc_534729444707_item	2687543	et	4	main
see	doc_534729444707_item	2687550	et	3	main
tähtis	doc_534729444707_item	2687553	et	4	main
kes	doc_534729444707_item	2687562	et	4	main
elada	doc_534729444707_item	2687580	et	3	main
ja	doc_534729444707_item	2687584	et	3	main
lahendus	doc_534729444707_item	2687588	et	4	main
rahvalaule	doc_534729444707_item	2687427	et	4	main
esitama	doc_534729444707_item	2687429	et	3	main
pillisaatega	doc_534729444707_item	2687430	et	3	main
hakkasid	doc_534729444707_item	2687431	et	4	main
ilmuma	doc_534729444707_item	2687432	et	3	main
instrumendid	doc_534729444707_item	2687433	et	3	main
koorid	doc_534729444707_item	2687435	et	4	main
rääkid	doc_534729444707_item	2687445	et	4	main
1933	doc_534729444707_item	2687455	et	2	main
ja	doc_534729444707_item	2687472	et	3	main
eestlaste	doc_534729444707_item	2687477	et	4	main
ärkamine	doc_534729444707_item	2687479	et	4	main
mis	doc_534729444707_item	2687480	et	4	main
tekkis	doc_534729444707_item	2687481	et	3	main
idee	doc_534729444707_item	2687501	et	4	main
see	doc_534729444707_item	2687508	et	3	main
laulupidu	doc_534729444707_item	2687509	et	4	main
eestlaste	doc_534729444707_item	2687512	et	4	main
traditsioon	doc_534729444707_item	2687513	et	3	main
mis	doc_534729444707_item	2687514	et	4	main
tähistatakse	doc_534729444707_item	2687515	et	3	main
aasta	doc_534729444707_item	2687517	et	4	main
selle	doc_534729444707_item	2687518	et	4	main
kohta	doc_534729444707_item	2687519	et	4	main
eestlased	doc_534729444707_item	2687520	et	3	main
olla	doc_534729444707_item	2687522	et	3	main
uhked	doc_534729444707_item	2687523	et	4	main
ja	doc_534729444707_item	2687524	et	3	main
mina	doc_534729444707_item	2687525	et	4	main
et	doc_534729444707_item	2687527	et	3	main
eestlased	doc_534729444707_item	2687528	et	3	main
on	doc_534729444707_item	2687529	et	4	main
tantsivad	doc_534729444707_item	2687535	et	4	main
ka	doc_534729444707_item	2687536	et	3	main
tänapäeval	doc_534729444707_item	2687537	et	3	main
arvan	doc_534729444707_item	2687538	et	3	main
laulurahvaks	doc_534729444707_item	2687542	et	3	main
asjad	doc_534729444707_item	2687544	et	3	main
ja	doc_534729444707_item	2687560	et	3	main
teavad	doc_534729444707_item	2687561	et	3	main
üle	doc_534729444707_item	2687579	et	3	main
saada	doc_534729444707_item	2687583	et	4	main
nüüd	doc_534729444707_item	2687511	et	4	main
võivad	doc_534729444707_item	2687521	et	4	main
arvan	doc_534729444707_item	2687526	et	3	main
laulavad	doc_534729444707_item	2687534	et	4	main
kultuur	doc_534729444707_item	2687547	et	3	main
eluviis	doc_534729444707_item	2687549	et	3	main
on	doc_534729444707_item	2687551	et	4	main
nad	doc_534729444707_item	2687563	et	3	main
olukorras	doc_534729444707_item	2687567	et	3	main
ka	doc_534729444707_item	2687569	et	3	main
rahvas	doc_534729444707_item	2687571	et	4	main
sest	doc_534729444707_item	2687574	et	4	main
teavad	doc_534729444707_item	2687575	et	3	main
et	doc_534729444707_item	2687576	et	3	main
kõik	doc_534729444707_item	2687577	et	4	main
saab	doc_534729444707_item	2687578	et	3	main
ajalugu	doc_534729444707_item	2687559	et	4	main
on	doc_534729444707_item	2687564	et	4	main
heas	doc_534729444707_item	2687570	et	3	main
laulab	doc_534729444707_item	2687572	et	3	main
tantsib	doc_534729444707_item	2687573	et	3	main
ja	doc_534729444707_item	2687581	et	3	main
see	doc_534729444707_item	2687585	et	3	main
teeb	doc_534729444711_item	2688356	et	3	main
essee	doc_534729444711_item	2688359	et	4	main
300	doc_534729444711_item	2688361	et	2	main
olema	doc_534729444711_item	2688366	et	4	main
eesti	doc_534729444711_item	2688345	et	4	main
350	doc_534729444711_item	2688362	et	2	main
analüüsiv	doc_534729444711_item	2688368	et	4	main
soovitatav	doc_534729444711_item	2688379	et	4	main
illustreerida	doc_534729444711_item	2688380	et	3	main
oma	doc_534729444711_item	2688391	et	4	main
lauluga	doc_534729444711_item	2688408	et	4	main
koos	doc_534729444711_item	2688409	et	4	main
kõik	doc_534729444711_item	2688416	et	4	main
teeb	doc_534729444711_item	2688417	et	3	main
eestlastest	doc_534729444711_item	2688418	et	4	main
erinevad	doc_534729444711_item	2688428	et	4	main
jooksul	doc_534729444711_item	2688437	et	4	main
tol	doc_534729444711_item	2688438	et	3	main
see	doc_534729444711_item	2688444	et	3	main
infoallikas	doc_534729444711_item	2688447	et	4	main
ka	doc_534729444711_item	2688449	et	3	main
lõbutseda	doc_534729444711_item	2688451	et	3	main
rõõmustada	doc_534729444711_item	2688453	et	3	main
inimesed	doc_534729444711_item	2688455	et	3	main
jooksis	doc_534729444711_item	2688462	et	4	main
vana	doc_534729444711_item	2688465	et	4	main
laulutraditsioon	doc_534729444711_item	2688466	et	3	main
kirjutamine	doc_534729444711_item	2688351	et	4	main
kirjutage	doc_534729444711_item	2688352	et	3	main
essee	doc_534729444711_item	2688353	et	4	main
teemal	doc_534729444711_item	2688354	et	3	main
eestlastest	doc_534729444711_item	2688357	et	4	main
on	doc_534729444711_item	2688378	et	4	main
väga	doc_534729444711_item	2688385	et	3	main
lastele	doc_534729444711_item	2688392	et	4	main
igal	doc_534729444711_item	2688393	et	3	main
peol	doc_534729444711_item	2688394	et	4	main
tähtsam	doc_534729444711_item	2688403	et	4	main
rahvas	doc_534729444711_item	2688411	et	4	main
jätkuvad	doc_534729444711_item	2688422	et	4	main
juba	doc_534729444711_item	2688435	et	3	main
sajandite	doc_534729444711_item	2688436	et	3	main
ajal	doc_534729444711_item	2688439	et	4	main
oli	doc_534729444711_item	2688445	et	3	main
kergeneda	doc_534729444711_item	2688460	et	3	main
kiiremini	doc_534729444711_item	2688463	et	4	main
tehtud	doc_534729444711_item	2688474	et	4	main
vanasti	doc_534729444711_item	2688475	et	3	main
vajalik	doc_534729444711_item	2688480	et	3	main
nii	doc_534729444711_item	2688483	et	3	main
praegu	doc_534729444711_item	2688489	et	3	main
saaksid	doc_534729444711_item	2688491	et	4	main
rahvapidu	doc_534729444711_item	2688525	et	4	main
tallinnasse	doc_534729444711_item	2688526	et	3	main
kus	doc_534729444711_item	2688527	et	3	main
kogu	doc_534729444711_item	2688533	et	4	main
eestist	doc_534729444711_item	2688534	et	3	main
kuulata	doc_534729444711_item	2688536	et	4	main
ja	doc_534729444711_item	2688538	et	3	main
laulda	doc_534729444711_item	2688539	et	4	main
on	doc_534729444711_item	2688546	et	4	main
tunnevad	doc_534729444711_item	2688549	et	3	main
rõõmsaks	doc_534729444711_item	2688551	et	3	main
laulupeol	doc_534729444711_item	2688552	et	4	main
see	doc_534729444711_item	2688565	et	3	main
vabas	doc_534729444711_item	2688569	et	3	main
natsionaalne	doc_534729444711_item	2688571	et	3	main
kui	doc_534729444711_item	2688576	et	3	main
laulmine	doc_534729444711_item	2688587	et	4	main
vana	doc_534729444711_item	2688602	et	4	main
traditsioone	doc_534729444711_item	2688603	et	3	main
on	doc_534729444711_item	2688606	et	4	main
saa	doc_534729444711_item	2688612	et	4	main
edasi	doc_534729444711_item	2688613	et	3	main
elada	doc_534729444711_item	2688614	et	3	main
rahvamuusika	doc_534729444711_item	2688615	et	4	main
essee	doc_534729444711_item	2688344	et	4	main
keele	doc_534729444711_item	2688346	et	4	main
kui	doc_534729444711_item	2688347	et	3	main
mis	doc_534729444711_item	2688355	et	4	main
peab	doc_534729444711_item	2688365	et	4	main
tuginema	doc_534729444711_item	2688371	et	3	main
ja	doc_534729444711_item	2688373	et	3	main
näidetega	doc_534729444711_item	2688381	et	3	main
rahvalaul	doc_534729444711_item	2688382	et	4	main
oli	doc_534729444711_item	2688383	et	3	main
oluline	doc_534729444711_item	2688386	et	4	main
jaoks	doc_534729444711_item	2688388	et	4	main
emad	doc_534729444711_item	2688389	et	3	main
laulsid	doc_534729444711_item	2688390	et	4	main
laul	doc_534729444711_item	2688395	et	4	main
mängis	doc_534729444711_item	2688396	et	3	main
ja	doc_534729444711_item	2688397	et	3	main
praegu	doc_534729444711_item	2688398	et	3	main
mängib	doc_534729444711_item	2688399	et	3	main
suurt	doc_534729444711_item	2688400	et	3	main
rolli	doc_534729444711_item	2688401	et	4	main
on	doc_534729444711_item	2688405	et	4	main
see	doc_534729444711_item	2688406	et	3	main
sai	doc_534729444711_item	2688412	et	4	main
vabaks	doc_534729444711_item	2688413	et	3	main
ja	doc_534729444711_item	2688414	et	3	main
see	doc_534729444711_item	2688415	et	3	main
laulutraditsiooni	doc_534729444711_item	2688421	et	4	main
on	doc_534729444711_item	2688433	et	4	main
eestlaseid	doc_534729444711_item	2688442	et	3	main
aeg	doc_534729444711_item	2688461	et	3	main
niisugune	doc_534729444711_item	2688464	et	3	main
on	doc_534729444711_item	2688478	et	4	main
palju	doc_534729444711_item	2688484	et	4	main
ka	doc_534729444711_item	2688488	et	3	main
säilitada	doc_534729444711_item	2688492	et	3	main
teise	doc_534729444711_item	2688348	et	4	main
keele	doc_534729444711_item	2688349	et	4	main
test	doc_534729444711_item	2688350	et	3	main
laulurahva	doc_534729444711_item	2688358	et	3	main
pikkus	doc_534729444711_item	2688360	et	4	main
sõna	doc_534729444711_item	2688363	et	4	main
essee	doc_534729444711_item	2688364	et	4	main
arutlev	doc_534729444711_item	2688367	et	4	main
ja	doc_534729444711_item	2688369	et	3	main
lugemistekstis	doc_534729444711_item	2688374	et	3	main
kõige	doc_534729444711_item	2688402	et	4	main
aga	doc_534729444711_item	2688404	et	3	main
et	doc_534729444711_item	2688407	et	3	main
laulurahva	doc_534729444711_item	2688419	et	3	main
tänapäeval	doc_534729444711_item	2688420	et	3	main
laulupeod	doc_534729444711_item	2688423	et	4	main
toimuvad	doc_534729444711_item	2688425	et	4	main
ja	doc_534729444711_item	2688427	et	3	main
festivaalid	doc_534729444711_item	2688429	et	4	main
kogu	doc_534729444711_item	2688430	et	4	main
eestis	doc_534729444711_item	2688431	et	3	main
laulutraditsioon	doc_534729444711_item	2688432	et	3	main
laulmine	doc_534729444711_item	2688440	et	4	main
tõi	doc_534729444711_item	2688441	et	3	main
ja	doc_534729444711_item	2688452	et	3	main
lauluga	doc_534729444711_item	2688454	et	4	main
töötasid	doc_534729444711_item	2688456	et	4	main
see	doc_534729444711_item	2688457	et	3	main
aitas	doc_534729444711_item	2688458	et	3	main
töörütmi	doc_534729444711_item	2688459	et	4	main
tegevused	doc_534729444711_item	2688472	et	4	main
on	doc_534729444711_item	2688473	et	4	main
väga	doc_534729444711_item	2688479	et	3	main
aastaid	doc_534729444711_item	2688485	et	4	main
tagasi	doc_534729444711_item	2688486	et	3	main
oma	doc_534729444711_item	2688493	et	4	main
aastal	doc_534729444711_item	2688521	et	3	main
on	doc_534729444711_item	2688523	et	4	main
inimesed	doc_534729444711_item	2688532	et	3	main
koos	doc_534729444711_item	2688541	et	4	main
üks	doc_534729444711_item	2688542	et	3	main
ja	doc_534729444711_item	2688564	et	3	main
toimus	doc_534729444711_item	2688567	et	3	main
1980	doc_534729444711_item	2688574	et	2	main
koolis	doc_534729444711_item	2688584	et	4	main
meil	doc_534729444711_item	2688585	et	4	main
viljandi	doc_534729444711_item	2688588	et	4	main
akadeemias	doc_534729444711_item	2688590	et	3	main
inimene	doc_534729444711_item	2688591	et	3	main
võib	doc_534729444711_item	2688592	et	3	main
õppida	doc_534729444711_item	2688593	et	3	main
laulma	doc_534729444711_item	2688594	et	3	main
rahvalaulu	doc_534729444711_item	2688595	et	4	main
ja	doc_534729444711_item	2688596	et	3	main
mängida	doc_534729444711_item	2688597	et	3	main
rahvainstrumentidel	doc_534729444711_item	2688598	et	3	main
sest	doc_534729444711_item	2688604	et	4	main
meie	doc_534729444711_item	2688607	et	4	main
ajalugu	doc_534729444711_item	2688608	et	4	main
meie	doc_534729444711_item	2688617	et	4	main
aegaga	doc_534729444711_item	2688622	et	4	main
aga	doc_534729444711_item	2688623	et	3	main
kahtlemata	doc_534729444711_item	2688626	et	4	main
eesti	doc_534729444711_item	2688633	et	4	main
pidudel	doc_534729444711_item	2688640	et	4	main
lauldakse	doc_534729444711_item	2688641	et	3	main
end	doc_534729444711_item	2688649	et	4	main
tänu	doc_534729444711_item	2688665	et	4	main
üldistav	doc_534729444711_item	2688370	et	4	main
loengus	doc_534729444711_item	2688372	et	3	main
esitatud	doc_534729444711_item	2688375	et	4	main
faktidele	doc_534729444711_item	2688376	et	3	main
väiteid	doc_534729444711_item	2688377	et	4	main
alati	doc_534729444711_item	2688384	et	4	main
eestlaste	doc_534729444711_item	2688387	et	4	main
eesti	doc_534729444711_item	2688410	et	4	main
mis	doc_534729444711_item	2688424	et	4	main
lauluväljakul	doc_534729444711_item	2688426	et	3	main
säilinud	doc_534729444711_item	2688434	et	4	main
kokku	doc_534729444711_item	2688443	et	3	main
nii	doc_534729444711_item	2688446	et	3	main
kui	doc_534729444711_item	2688448	et	3	main
võimalus	doc_534729444711_item	2688450	et	3	main
laulaga	doc_534729444711_item	2688476	et	4	main
inimeste	doc_534729444711_item	2688481	et	3	main
jaoks	doc_534729444711_item	2688482	et	4	main
kui	doc_534729444711_item	2688487	et	3	main
eestlased	doc_534729444711_item	2688490	et	3	main
kultuuri	doc_534729444711_item	2688494	et	4	main
rahvatraditsiooni	doc_534729444711_item	2688496	et	4	main
raskel	doc_534729444711_item	2688497	et	3	main
ja	doc_534729444711_item	2688495	et	3	main
ajal	doc_534729444711_item	2688498	et	4	main
kui	doc_534729444711_item	2688499	et	3	main
eesti	doc_534729444711_item	2688500	et	4	main
ei	doc_534729444711_item	2688501	et	4	main
olnud	doc_534729444711_item	2688502	et	4	main
veel	doc_534729444711_item	2688503	et	4	main
vabaks	doc_534729444711_item	2688504	et	3	main
see	doc_534729444711_item	2688505	et	3	main
tähendab	doc_534729444711_item	2688506	et	3	main
et	doc_534729444711_item	2688507	et	3	main
eestlastel	doc_534729444711_item	2688508	et	4	main
on	doc_534729444711_item	2688509	et	4	main
väga	doc_534729444711_item	2688510	et	3	main
tugev	doc_534729444711_item	2688511	et	4	main
vaim	doc_534729444711_item	2688512	et	3	main
ja	doc_534729444711_item	2688513	et	3	main
iseloom	doc_534729444711_item	2688514	et	3	main
laulupidu	doc_534729444711_item	2688515	et	4	main
mis	doc_534729444711_item	2688516	et	4	main
sai	doc_534729444711_item	2688517	et	4	main
oma	doc_534729444711_item	2688518	et	4	main
alguse	doc_534729444711_item	2688519	et	3	main
1869	doc_534729444711_item	2688520	et	2	main
laulupidu	doc_534729444711_item	2688530	et	4	main
et	doc_534729444711_item	2688535	et	3	main
rahvalaulu	doc_534729444711_item	2688537	et	4	main
kõik	doc_534729444711_item	2688543	et	4	main
eestlased	doc_534729444711_item	2688548	et	3	main
eestlased	doc_534729444711_item	2688561	et	3	main
algas	doc_534729444711_item	2688573	et	3	main
aastal	doc_534729444711_item	2688575	et	3	main
sai	doc_534729444711_item	2688578	et	4	main
on	doc_534729444711_item	2688586	et	4	main
kultuuri	doc_534729444711_item	2688589	et	4	main
milleta	doc_534729444711_item	2688609	et	3	main
me	doc_534729444711_item	2688610	et	4	main
südametes	doc_534729444711_item	2688618	et	4	main
suurt	doc_534729444711_item	2688629	et	3	main
rolli	doc_534729444711_item	2688630	et	4	main
iseloomustab	doc_534729444711_item	2688467	et	4	main
eestlaseid	doc_534729444711_item	2688468	et	3	main
nagu	doc_534729444711_item	2688469	et	3	main
laulurahva	doc_534729444711_item	2688470	et	3	main
kogu	doc_534729444711_item	2688471	et	4	main
see	doc_534729444711_item	2688477	et	3	main
sõidavad	doc_534729444711_item	2688531	et	3	main
ilm	doc_534729444711_item	2688545	et	3	main
end	doc_534729444711_item	2688550	et	4	main
juba	doc_534729444711_item	2688568	et	3	main
eestis	doc_534729444711_item	2688570	et	3	main
regilaul	doc_534729444711_item	2688577	et	4	main
tratsiooniks	doc_534729444711_item	2688579	et	4	main
laulmine	doc_534729444711_item	2688580	et	4	main
praegu	doc_534729444711_item	2688581	et	3	main
järgnevad	doc_534729444711_item	2688601	et	4	main
ei	doc_534729444711_item	2688611	et	4	main
muusika	doc_534729444711_item	2688619	et	4	main
muutub	doc_534729444711_item	2688620	et	3	main
koos	doc_534729444711_item	2688621	et	4	main
tartus	doc_534729444711_item	2688522	et	3	main
praegu	doc_534729444711_item	2688524	et	3	main
praegu	doc_534729444711_item	2688528	et	3	main
toimub	doc_534729444711_item	2688529	et	3	main
kõik	doc_534729444711_item	2688540	et	4	main
mis	doc_534729444711_item	2688544	et	4	main
tänaval	doc_534729444711_item	2688547	et	4	main
kõige	doc_534729444711_item	2688553	et	4	main
tähtsam	doc_534729444711_item	2688554	et	4	main
sündmus	doc_534729444711_item	2688555	et	3	main
oli	doc_534729444711_item	2688556	et	3	main
1994	doc_534729444711_item	2688557	et	2	main
aastal	doc_534729444711_item	2688558	et	3	main
sest	doc_534729444711_item	2688559	et	4	main
laulupeoga	doc_534729444711_item	2688560	et	4	main
sai	doc_534729444711_item	2688562	et	4	main
iseseisvust	doc_534729444711_item	2688563	et	4	main
rahvapidu	doc_534729444711_item	2688566	et	4	main
ärkamine	doc_534729444711_item	2688572	et	4	main
on	doc_534729444711_item	2688582	et	4	main
massharrastus	doc_534729444711_item	2688583	et	3	main
tänapäevased	doc_534729444711_item	2688599	et	4	main
noored	doc_534729444711_item	2688600	et	3	main
see	doc_534729444711_item	2688605	et	3	main
eesti	doc_534729444711_item	2688627	et	4	main
seltskonnas	doc_534729444711_item	2688628	et	3	main
sümboliks	doc_534729444711_item	2688634	et	4	main
see	doc_534729444711_item	2688635	et	3	main
koos	doc_534729444711_item	2688642	et	4	main
ühina	doc_534729444711_item	2688650	et	4	main
lähedamaks	doc_534729444711_item	2688655	et	4	main
koos	doc_534729444711_item	2688658	et	4	main
eesti	doc_534729444711_item	2688662	et	4	main
rahvas	doc_534729444711_item	2688668	et	4	main
elab	doc_534729444711_item	2688616	et	3	main
rahvalaul	doc_534729444711_item	2688624	et	4	main
mängib	doc_534729444711_item	2688625	et	3	main
sai	doc_534729444711_item	2688632	et	4	main
teistega	doc_534729444711_item	2688651	et	4	main
aitab	doc_534729444711_item	2688656	et	3	main
rahvas	doc_534729444711_item	2688663	et	4	main
ja	doc_534729444711_item	2688664	et	3	main
seda	doc_534729444711_item	2688666	et	3	main
lauluväljakule	doc_534729444711_item	2688643	et	3	main
tulevad	doc_534729444711_item	2688644	et	4	main
palju	doc_534729444711_item	2688645	et	4	main
laulmine	doc_534729444711_item	2688652	et	4	main
teeb	doc_534729444711_item	2688653	et	3	main
arusaamiseks	doc_534729444711_item	2688657	et	4	main
rahvalaul	doc_534729444711_item	2688631	et	4	main
on	doc_534729444711_item	2688636	et	4	main
kultuurielus	doc_534729444711_item	2688637	et	4	main
suur	doc_534729444711_item	2688638	et	3	main
osa	doc_534729444711_item	2688639	et	4	main
inimesi	doc_534729444711_item	2688646	et	4	main
et	doc_534729444711_item	2688647	et	3	main
tunda	doc_534729444711_item	2688648	et	3	main
inimesi	doc_534729444711_item	2688654	et	4	main
laulaga	doc_534729444711_item	2688659	et	4	main
elab	doc_534729444711_item	2688660	et	3	main
kogu	doc_534729444711_item	2688661	et	4	main
vaba	doc_534729444711_item	2688667	et	4	main
essee	doc_534729444716_item	2689729	et	4	main
pikkus	doc_534729444716_item	2689730	et	4	main
300	doc_534729444716_item	2689731	et	2	main
ja	doc_534729444716_item	2689739	et	3	main
on	doc_534729444716_item	2689748	et	4	main
mis	doc_534729444716_item	2689752	et	4	main
teeb	doc_534729444716_item	2689753	et	3	main
eestlastest	doc_534729444716_item	2689754	et	4	main
laulurahva	doc_534729444716_item	2689755	et	3	main
igal	doc_534729444716_item	2689756	et	3	main
traditsioonid	doc_534729444716_item	2689760	et	3	main
on	doc_534729444716_item	2689767	et	4	main
laulmine	doc_534729444716_item	2689769	et	4	main
kasutati	doc_534729444716_item	2689770	et	4	main
eestlased	doc_534729444716_item	2689803	et	3	main
minevikust	doc_534729444716_item	2689808	et	3	main
rahvalaulud	doc_534729444716_item	2689810	et	3	main
ajaloo	doc_534729444716_item	2689812	et	4	main
rahvalaulmine	doc_534729444716_item	2689813	et	3	main
on	doc_534729444716_item	2689814	et	4	main
ka	doc_534729444716_item	2689815	et	3	main
kirikus	doc_534729444716_item	2689816	et	3	main
seal	doc_534729444716_item	2689817	et	4	main
viib	doc_534729444716_item	2689821	et	3	main
rifmad	doc_534729444716_item	2689841	et	4	main
kasutati	doc_534729444716_item	2689844	et	4	main
kirjutamine	doc_534729444716_item	2689721	et	4	main
350	doc_534729444716_item	2689732	et	2	main
sõna	doc_534729444716_item	2689733	et	4	main
väiteid	doc_534729444716_item	2689747	et	4	main
soovitatav	doc_534729444716_item	2689749	et	4	main
illustreerida	doc_534729444716_item	2689750	et	3	main
näidetega	doc_534729444716_item	2689751	et	3	main
oma	doc_534729444716_item	2689759	et	4	main
huvid	doc_534729444716_item	2689762	et	3	main
kultuur	doc_534729444716_item	2689764	et	3	main
eesti	doc_534729444716_item	2689771	et	4	main
juba	doc_534729444716_item	2689772	et	3	main
näitevad	doc_534729444716_item	2689804	et	4	main
jutustavad	doc_534729444716_item	2689806	et	4	main
näitevad	doc_534729444716_item	2689811	et	4	main
kordab	doc_534729444716_item	2689825	et	3	main
ka	doc_534729444716_item	2689838	et	3	main
tänapaeval	doc_534729444716_item	2689843	et	4	main
muusika	doc_534729444716_item	2689847	et	4	main
instrumenti	doc_534729444716_item	2689848	et	4	main
praegu	doc_534729444716_item	2689852	et	3	main
teisele	doc_534729444716_item	2689895	et	4	main
inimesi	doc_534729444716_item	2689903	et	4	main
folklöörides	doc_534729444716_item	2689907	et	4	main
palju	doc_534729444716_item	2689909	et	4	main
ma	doc_534729444716_item	2689911	et	3	main
eestis	doc_534729444716_item	2689915	et	3	main
huvitav	doc_534729444716_item	2689918	et	4	main
eestlastele	doc_534729444716_item	2689921	et	4	main
esteetiline	doc_534729444716_item	2689933	et	3	main
emotsionaalne	doc_534729444716_item	2689935	et	3	main
kasutati	doc_534729444716_item	2689962	et	4	main
laulutöö	doc_534729444716_item	2689966	et	4	main
riikades	doc_534729444716_item	2689971	et	4	main
see	doc_534729444716_item	2689973	et	3	main
võid	doc_534729444716_item	2689976	et	4	main
essee	doc_534729444716_item	2689723	et	4	main
mis	doc_534729444716_item	2689725	et	4	main
eestlastest	doc_534729444716_item	2689727	et	4	main
laulurahva	doc_534729444716_item	2689728	et	3	main
peab	doc_534729444716_item	2689735	et	4	main
analüüsiv	doc_534729444716_item	2689738	et	4	main
tuginema	doc_534729444716_item	2689741	et	3	main
ja	doc_534729444716_item	2689743	et	3	main
rahvas	doc_534729444716_item	2689757	et	4	main
mitu	doc_534729444716_item	2689773	et	4	main
sajandid	doc_534729444716_item	2689774	et	3	main
kultuurinähtus	doc_534729444716_item	2689801	et	4	main
rahva	doc_534729444716_item	2689807	et	3	main
koor	doc_534729444716_item	2689824	et	4	main
ja	doc_534729444716_item	2689830	et	3	main
poistekoorid	doc_534729444716_item	2689831	et	3	main
muutub	doc_534729444716_item	2689833	et	3	main
ja	doc_534729444716_item	2689840	et	3	main
rahvalaulades	doc_534729444716_item	2689842	et	3	main
on	doc_534729444716_item	2689853	et	4	main
palju	doc_534729444716_item	2689854	et	4	main
võib	doc_534729444716_item	2689858	et	3	main
nõudu	doc_534729444716_item	2689869	et	4	main
külalistele	doc_534729444716_item	2689893	et	4	main
ja	doc_534729444716_item	2689894	et	3	main
ja	doc_534729444716_item	2689898	et	3	main
meie	doc_534729444716_item	2689900	et	4	main
kui	doc_534729444716_item	2689922	et	3	main
väljakülalistele	doc_534729444716_item	2689924	et	4	main
see	doc_534729444716_item	2689925	et	3	main
on	doc_534729444716_item	2689926	et	4	main
tuttvus	doc_534729444716_item	2689927	et	4	main
rahvaga	doc_534729444716_item	2689928	et	3	main
ja	doc_534729444716_item	2689929	et	3	main
on	doc_534729444716_item	2689932	et	4	main
ja	doc_534729444716_item	2689934	et	3	main
väljendusvahed	doc_534729444716_item	2689936	et	3	main
palju	doc_534729444716_item	2689949	et	4	main
asjadest	doc_534729444716_item	2689950	et	3	main
kes	doc_534729444716_item	2689951	et	4	main
palju	doc_534729444716_item	2689963	et	4	main
et	doc_534729444716_item	2689969	et	3	main
näidata	doc_534729444716_item	2689977	et	4	main
keele	doc_534729444717_item	2689981	et	4	main
rikkas	doc_534729444717_item	2690020	et	4	main
folkloor	doc_534729444717_item	2690021	et	4	main
tantsidest	doc_534729444717_item	2690025	et	3	main
muusikast	doc_534729444717_item	2690027	et	4	main
aastal	doc_534729444717_item	2690029	et	3	main
lauluväljakul	doc_534729444717_item	2690030	et	3	main
kogunevad	doc_534729444717_item	2690031	et	4	main
tuhanded	doc_534729444717_item	2690032	et	3	main
on	doc_534729444717_item	2690046	et	4	main
meeskoorid	doc_534729444717_item	2690047	et	4	main
ka	doc_534729444717_item	2690051	et	3	main
essee	doc_534729444716_item	2689714	et	4	main
eesti	doc_534729444716_item	2689715	et	4	main
keele	doc_534729444716_item	2689716	et	4	main
kui	doc_534729444716_item	2689717	et	3	main
teise	doc_534729444716_item	2689718	et	4	main
keele	doc_534729444716_item	2689719	et	4	main
test	doc_534729444716_item	2689720	et	3	main
kirjutage	doc_534729444716_item	2689722	et	3	main
teemal	doc_534729444716_item	2689724	et	3	main
teeb	doc_534729444716_item	2689726	et	3	main
essee	doc_534729444716_item	2689734	et	4	main
arutlev	doc_534729444716_item	2689737	et	4	main
esitatud	doc_534729444716_item	2689745	et	4	main
on	doc_534729444716_item	2689758	et	4	main
eestis	doc_534729444716_item	2689766	et	3	main
olema	doc_534729444716_item	2689736	et	4	main
üldistav	doc_534729444716_item	2689740	et	4	main
loengus	doc_534729444716_item	2689742	et	3	main
lugemistekstis	doc_534729444716_item	2689744	et	3	main
faktidele	doc_534729444716_item	2689746	et	3	main
oma	doc_534729444716_item	2689761	et	4	main
oma	doc_534729444716_item	2689763	et	4	main
ja	doc_534729444716_item	2689765	et	3	main
ka	doc_534729444716_item	2689768	et	3	main
eesti	doc_534729444716_item	2689775	et	4	main
koosneb	doc_534729444716_item	2689777	et	3	main
folkloor	doc_534729444716_item	2689776	et	4	main
mitmedest	doc_534729444716_item	2689778	et	4	main
osadest	doc_534729444716_item	2689779	et	3	main
vanal	doc_534729444716_item	2689780	et	3	main
ajal	doc_534729444716_item	2689781	et	4	main
laulasid	doc_534729444716_item	2689782	et	4	main
põhjal	doc_534729444716_item	2689783	et	4	main
naised	doc_534729444716_item	2689784	et	3	main
nad	doc_534729444716_item	2689785	et	3	main
võid	doc_534729444716_item	2689786	et	4	main
laulda	doc_534729444716_item	2689787	et	4	main
töötades	doc_534729444716_item	2689788	et	3	main
kodus	doc_534729444716_item	2689789	et	4	main
last	doc_534729444716_item	2689790	et	4	main
kiigutades	doc_534729444716_item	2689791	et	3	main
erinevad	doc_534729444716_item	2689792	et	4	main
eesti	doc_534729444716_item	2689794	et	4	main
ajal	doc_534729444716_item	2689793	et	4	main
kasutati	doc_534729444716_item	2689795	et	4	main
oma	doc_534729444716_item	2689796	et	4	main
rifmad	doc_534729444716_item	2689797	et	4	main
põhjal	doc_534729444716_item	2689798	et	4	main
rahvalaul	doc_534729444716_item	2689799	et	4	main
on	doc_534729444716_item	2689800	et	4	main
rahvalaulus	doc_534729444716_item	2689802	et	3	main
ja	doc_534729444716_item	2689805	et	3	main
tihti	doc_534729444716_item	2689809	et	3	main
eeslaulja	doc_534729444716_item	2689818	et	4	main
algab	doc_534729444716_item	2689819	et	3	main
ja	doc_534729444716_item	2689820	et	3	main
edasi	doc_534729444716_item	2689823	et	3	main
meil	doc_534729444716_item	2689826	et	4	main
naiskoorid	doc_534729444716_item	2689828	et	3	main
stiilid	doc_534729444716_item	2689839	et	4	main
ka	doc_534729444716_item	2689845	et	3	main
koos	doc_534729444716_item	2689849	et	4	main
kus	doc_534729444716_item	2689857	et	3	main
rahvalaulu	doc_534729444716_item	2689861	et	4	main
ajaloost	doc_534729444716_item	2689862	et	4	main
kes	doc_534729444716_item	2689904	et	4	main
et	doc_534729444716_item	2689913	et	3	main
väga	doc_534729444716_item	2689917	et	3	main
tegevus	doc_534729444716_item	2689919	et	4	main
nii	doc_534729444716_item	2689920	et	3	main
laulu	doc_534729444716_item	2689822	et	4	main
on	doc_534729444716_item	2689827	et	4	main
lastekoorid	doc_534729444716_item	2689829	et	3	main
kui	doc_534729444716_item	2689832	et	3	main
meie	doc_534729444716_item	2689834	et	4	main
elu	doc_534729444716_item	2689835	et	4	main
nii	doc_534729444716_item	2689836	et	3	main
muutub	doc_534729444716_item	2689837	et	3	main
palju	doc_534729444716_item	2689846	et	4	main
erinevaid	doc_534729444716_item	2689855	et	4	main
ringeid	doc_534729444716_item	2689856	et	3	main
palju	doc_534729444716_item	2689860	et	4	main
ja	doc_534729444716_item	2689863	et	3	main
kui	doc_534729444716_item	2689864	et	3	main
tahad	doc_534729444716_item	2689865	et	3	main
võid	doc_534729444716_item	2689866	et	4	main
proovida	doc_534729444716_item	2689867	et	3	main
oma	doc_534729444716_item	2689868	et	4	main
palju	doc_534729444716_item	2689873	et	4	main
erinevaid	doc_534729444716_item	2689874	et	4	main
koorid	doc_534729444716_item	2689875	et	4	main
ansamblid	doc_534729444716_item	2689876	et	3	main
saaremaast	doc_534729444716_item	2689877	et	4	main
kihnust	doc_534729444716_item	2689878	et	3	main
terve	doc_534729444716_item	2689879	et	4	main
eestist	doc_534729444716_item	2689880	et	3	main
tihti	doc_534729444716_item	2689881	et	3	main
võib	doc_534729444716_item	2689882	et	3	main
näidata	doc_534729444716_item	2689883	et	4	main
rahvalaulmine	doc_534729444716_item	2689884	et	3	main
peos	doc_534729444716_item	2689885	et	4	main
koos	doc_534729444716_item	2689886	et	4	main
rahvatantsimine	doc_534729444716_item	2689887	et	3	main
laulmisega	doc_534729444716_item	2689850	et	4	main
ja	doc_534729444716_item	2689851	et	3	main
teada	doc_534729444716_item	2689859	et	3	main
laulupeosel	doc_534729444716_item	2689870	et	4	main
võib	doc_534729444716_item	2689871	et	3	main
näha	doc_534729444716_item	2689872	et	3	main
nähtus	doc_534729444716_item	2689889	et	4	main
jutustab	doc_534729444716_item	2689890	et	3	main
näiteks	doc_534729444716_item	2689891	et	4	main
välja	doc_534729444716_item	2689892	et	4	main
osa	doc_534729444716_item	2689906	et	4	main
ka	doc_534729444716_item	2689908	et	3	main
noored	doc_534729444716_item	2689910	et	3	main
arvan	doc_534729444716_item	2689912	et	3	main
rahvalaulmine	doc_534729444716_item	2689914	et	3	main
see	doc_534729444716_item	2689916	et	3	main
tänapäeval	doc_534729444716_item	2689937	et	3	main
palju	doc_534729444716_item	2689939	et	4	main
igasugused	doc_534729444716_item	2689940	et	3	main
folkloorid	doc_534729444716_item	2689941	et	4	main
kus	doc_534729444716_item	2689942	et	3	main
võtavad	doc_534729444716_item	2689943	et	3	main
osa	doc_534729444716_item	2689944	et	4	main
ka	doc_534729444716_item	2689945	et	3	main
lapsed	doc_534729444716_item	2689946	et	3	main
rahvalaulmine	doc_534729444716_item	2689947	et	3	main
koosneb	doc_534729444716_item	2689948	et	3	main
rifmad	doc_534729444716_item	2689959	et	4	main
kasutad	doc_534729444716_item	2689960	et	3	main
tänapäeval	doc_534729444716_item	2689961	et	3	main
igades	doc_534729444716_item	2689970	et	3	main
on	doc_534729444716_item	2689972	et	4	main
mida	doc_534729444716_item	2689974	et	4	main
koduelanikud	doc_534729444716_item	2689975	et	3	main
eesti	doc_534729444717_item	2689980	et	4	main
see	doc_534729444716_item	2689888	et	3	main
oma	doc_534729444716_item	2689896	et	4	main
iseloomulikust	doc_534729444716_item	2689897	et	4	main
ajaloost	doc_534729444716_item	2689899	et	4	main
ajal	doc_534729444716_item	2689901	et	4	main
palju	doc_534729444716_item	2689902	et	4	main
võtavad	doc_534729444716_item	2689905	et	3	main
kultuuriga	doc_534729444716_item	2689930	et	4	main
laulab	doc_534729444716_item	2689952	et	3	main
kellega	doc_534729444716_item	2689953	et	3	main
laulavad	doc_534729444716_item	2689954	et	4	main
ja	doc_534729444716_item	2689955	et	3	main
missugused	doc_534729444716_item	2689956	et	3	main
stiilid	doc_534729444716_item	2689957	et	4	main
ja	doc_534729444716_item	2689958	et	3	main
ja	doc_534729444716_item	2689965	et	3	main
arvan	doc_534729444716_item	2689968	et	3	main
kui	doc_534729444717_item	2689982	et	3	main
ta	doc_534729444717_item	2690022	et	4	main
koosneb	doc_534729444717_item	2690023	et	3	main
lauludest	doc_534729444717_item	2690024	et	3	main
ja	doc_534729444717_item	2690026	et	3	main
igal	doc_534729444717_item	2690028	et	3	main
laulupeol	doc_534729444717_item	2690034	et	4	main
traditsiooni	doc_534729444717_item	2690038	et	4	main
laulupeo	doc_534729444717_item	2690039	et	4	main
osavõtjate	doc_534729444717_item	2690040	et	3	main
arv	doc_534729444717_item	2690041	et	3	main
on	doc_534729444717_item	2690042	et	4	main
naiskoorid	doc_534729444717_item	2690048	et	3	main
lastekoorid	doc_534729444717_item	2690049	et	3	main
kui	doc_534729444717_item	2690050	et	3	main
essee	doc_534729444719_item	2690342	et	4	main
essee	doc_534729444719_item	2690351	et	4	main
eestlastel	doc_534729444719_item	2690383	et	4	main
elus	doc_534729444719_item	2690388	et	4	main
nad	doc_534729444719_item	2690389	et	3	main
ka	doc_534729444716_item	2689923	et	3	main
see	doc_534729444716_item	2689931	et	3	main
on	doc_534729444716_item	2689938	et	4	main
rahvastiili	doc_534729444716_item	2689964	et	4	main
ma	doc_534729444716_item	2689967	et	3	main
teisele	doc_534729444716_item	2689978	et	4	main
essee	doc_534729444717_item	2689979	et	4	main
teise	doc_534729444717_item	2689983	et	4	main
keele	doc_534729444717_item	2689984	et	4	main
test	doc_534729444717_item	2689985	et	3	main
kirjutamine	doc_534729444717_item	2689986	et	4	main
kirjutage	doc_534729444717_item	2689987	et	3	main
essee	doc_534729444717_item	2689988	et	4	main
teemal	doc_534729444717_item	2689989	et	3	main
mis	doc_534729444717_item	2689990	et	4	main
teeb	doc_534729444717_item	2689991	et	3	main
eestlastest	doc_534729444717_item	2689992	et	4	main
laulurahva	doc_534729444717_item	2689993	et	3	main
essee	doc_534729444717_item	2689994	et	4	main
pikkus	doc_534729444717_item	2689995	et	4	main
300	doc_534729444717_item	2689996	et	2	main
350	doc_534729444717_item	2689997	et	2	main
sõna	doc_534729444717_item	2689998	et	4	main
essee	doc_534729444717_item	2689999	et	4	main
peab	doc_534729444717_item	2690000	et	4	main
olema	doc_534729444717_item	2690001	et	4	main
arutlev	doc_534729444717_item	2690002	et	4	main
analüüsiv	doc_534729444717_item	2690003	et	4	main
ja	doc_534729444717_item	2690004	et	3	main
üldistav	doc_534729444717_item	2690005	et	4	main
tuginema	doc_534729444717_item	2690006	et	3	main
loengus	doc_534729444717_item	2690007	et	3	main
ja	doc_534729444717_item	2690008	et	3	main
lugemistekstis	doc_534729444717_item	2690009	et	3	main
esitatud	doc_534729444717_item	2690010	et	4	main
faktidele	doc_534729444717_item	2690011	et	3	main
väiteid	doc_534729444717_item	2690012	et	4	main
on	doc_534729444717_item	2690013	et	4	main
soovitatav	doc_534729444717_item	2690014	et	4	main
illustreerida	doc_534729444717_item	2690015	et	3	main
näidetega	doc_534729444717_item	2690016	et	3	main
eestlastel	doc_534729444717_item	2690017	et	4	main
on	doc_534729444717_item	2690018	et	4	main
päris	doc_534729444717_item	2690019	et	4	main
et	doc_534729444717_item	2690035	et	3	main
keele	doc_534729444719_item	2690347	et	4	main
test	doc_534729444719_item	2690348	et	3	main
tagasi	doc_534729444719_item	2690382	et	3	main
aga	doc_534729444719_item	2690395	et	3	main
olnud	doc_534729444719_item	2690398	et	4	main
ainult	doc_534729444719_item	2690401	et	4	main
vabad	doc_534729444719_item	2690406	et	3	main
tähistada	doc_534729444717_item	2690036	et	3	main
päris	doc_534729444717_item	2690043	et	4	main
suur	doc_534729444717_item	2690044	et	3	main
siin	doc_534729444717_item	2690045	et	4	main
poistekoorid	doc_534729444717_item	2690052	et	3	main
lauljad	doc_534729444717_item	2690033	et	4	main
laulpidude	doc_534729444717_item	2690037	et	4	main
kirjutage	doc_534729444719_item	2690350	et	3	main
mis	doc_534729444719_item	2690353	et	4	main
sõna	doc_534729444719_item	2690361	et	4	main
essee	doc_534729444719_item	2690362	et	4	main
olnud	doc_534729444719_item	2690385	et	4	main
palju	doc_534729444719_item	2690386	et	4	main
oma	doc_534729444719_item	2690393	et	4	main
maal	doc_534729444719_item	2690394	et	4	main
olla	doc_534729444719_item	2690405	et	3	main
oli	doc_534729444719_item	2690409	et	3	main
ja	doc_534729444719_item	2690411	et	3	main
laulud	doc_534729444719_item	2690416	et	3	main
abistasid	doc_534729444719_item	2690417	et	4	main
salvestada	doc_534729444719_item	2690418	et	3	main
nende	doc_534729444719_item	2690419	et	4	main
järgmised	doc_534729444719_item	2690422	et	3	main
arvan	doc_534729444719_item	2690435	et	3	main
muidugi	doc_534729444719_item	2690455	et	4	main
ega	doc_534729444719_item	2690460	et	3	main
palju	doc_534729444719_item	2690462	et	4	main
laulud	doc_534729444719_item	2690463	et	3	main
mis	doc_534729444719_item	2690464	et	4	main
koor	doc_534729444719_item	2690467	et	4	main
merest	doc_534729444719_item	2690480	et	3	main
laulsid	doc_534729444719_item	2690490	et	4	main
ka	doc_534729444719_item	2690491	et	3	main
viga	doc_534729444719_item	2690502	et	4	main
mõtelda	doc_534729444719_item	2690504	et	4	main
et	doc_534729444719_item	2690505	et	3	main
eesti	doc_534729444719_item	2690506	et	4	main
vaene	doc_534729444719_item	2690510	et	4	main
instrumentid	doc_534729444719_item	2690516	et	4	main
ega	doc_534729444719_item	2690517	et	3	main
nendel	doc_534729444719_item	2690518	et	4	main
oli	doc_534729444719_item	2690519	et	3	main
nende	doc_534729444719_item	2690520	et	4	main
keele	doc_534729444719_item	2690344	et	4	main
kui	doc_534729444719_item	2690345	et	3	main
teise	doc_534729444719_item	2690346	et	4	main
essee	doc_534729444719_item	2690357	et	4	main
pikkus	doc_534729444719_item	2690358	et	4	main
300	doc_534729444719_item	2690359	et	2	main
350	doc_534729444719_item	2690360	et	2	main
olema	doc_534729444719_item	2690364	et	4	main
arutlev	doc_534729444719_item	2690365	et	4	main
analüüsiv	doc_534729444719_item	2690366	et	4	main
ja	doc_534729444719_item	2690367	et	3	main
üldistav	doc_534729444719_item	2690368	et	4	main
tuginema	doc_534729444719_item	2690369	et	3	main
loengus	doc_534729444719_item	2690370	et	3	main
ja	doc_534729444719_item	2690371	et	3	main
lugemistekstis	doc_534729444719_item	2690372	et	3	main
esitatud	doc_534729444719_item	2690373	et	4	main
faktidele	doc_534729444719_item	2690374	et	3	main
väiteid	doc_534729444719_item	2690375	et	4	main
on	doc_534729444719_item	2690376	et	4	main
soovitatav	doc_534729444719_item	2690377	et	4	main
illustreerida	doc_534729444719_item	2690378	et	3	main
eesti	doc_534729444719_item	2690343	et	4	main
kirjutamine	doc_534729444719_item	2690349	et	4	main
teemal	doc_534729444719_item	2690352	et	3	main
teeb	doc_534729444719_item	2690354	et	3	main
eestlastest	doc_534729444719_item	2690355	et	4	main
laulurahva	doc_534729444719_item	2690356	et	3	main
peab	doc_534729444719_item	2690363	et	4	main
näidetega	doc_534729444719_item	2690379	et	3	main
palju	doc_534729444719_item	2690380	et	4	main
ei	doc_534729444719_item	2690384	et	4	main
rõõmsat	doc_534729444719_item	2690387	et	3	main
ja	doc_534729444719_item	2690400	et	3	main
võivad	doc_534729444719_item	2690404	et	4	main
põhiliseld	doc_534729444719_item	2690407	et	4	main
ajalugu	doc_534729444719_item	2690420	et	4	main
põlvkonnad	doc_534729444719_item	2690423	et	4	main
nendest	doc_534729444719_item	2690425	et	4	main
kõige	doc_534729444719_item	2690437	et	4	main
meile	doc_534729444719_item	2690440	et	4	main
ühendasid	doc_534729444719_item	2690445	et	4	main
alati	doc_534729444719_item	2690451	et	4	main
oli	doc_534729444719_item	2690452	et	3	main
ka	doc_534729444719_item	2690458	et	3	main
väga	doc_534729444719_item	2690461	et	3	main
laulma	doc_534729444719_item	2690466	et	3	main
eestis	doc_534729444719_item	2690468	et	3	main
nad	doc_534729444719_item	2690472	et	3	main
mehed	doc_534729444719_item	2690475	et	3	main
laulsid	doc_534729444719_item	2690482	et	4	main
oma	doc_534729444719_item	2690483	et	4	main
ja	doc_534729444719_item	2690485	et	3	main
kui	doc_534729444719_item	2690486	et	3	main
nad	doc_534729444719_item	2690487	et	3	main
töötasid	doc_534729444719_item	2690488	et	4	main
nad	doc_534729444719_item	2690489	et	3	main
aga	doc_534729444719_item	2690499	et	3	main
oleks	doc_534729444719_item	2690501	et	3	main
kui	doc_534729444719_item	2690503	et	3	main
väga	doc_534729444719_item	2690509	et	3	main
nendel	doc_534729444719_item	2690512	et	4	main
põhiliselt	doc_534729444719_item	2690513	et	4	main
kaunised	doc_534729444719_item	2690521	et	4	main
muusika	doc_534729444719_item	2690523	et	4	main
pillimängust	doc_534729444719_item	2690527	et	3	main
varem	doc_534729444719_item	2690533	et	4	main
külas	doc_534729444719_item	2690534	et	3	main
kes	doc_534729444719_item	2690537	et	4	main
laulsid	doc_534729444719_item	2690538	et	4	main
pulmades	doc_534729444719_item	2690539	et	3	main
ja	doc_534729444719_item	2690540	et	3	main
on	doc_534729444719_item	2690548	et	4	main
väga	doc_534729444719_item	2690549	et	3	main
populaarne	doc_534729444719_item	2690550	et	3	main
on	doc_534729444719_item	2690553	et	4	main
lauldatakse	doc_534729444719_item	2690564	et	4	main
rahvalaulud	doc_534729444719_item	2690565	et	3	main
ei	doc_534729444719_item	2690569	et	4	main
aktuaalne	doc_534729444719_item	2690571	et	3	main
külastaksid	doc_534729444719_item	2690575	et	4	main
peod	doc_534729444719_item	2690577	et	4	main
ainult	doc_534729444719_item	2690580	et	4	main
vanadele	doc_534729444719_item	2690581	et	3	main
noortele	doc_534729444719_item	2690586	et	3	main
huvitab	doc_534729444719_item	2690590	et	3	main
palju	doc_534729444719_item	2690594	et	4	main
folklööre	doc_534729444719_item	2690596	et	4	main
rühme	doc_534729444719_item	2690597	et	3	main
kes	doc_534729444719_item	2690598	et	4	main
regilaulud	doc_534729444719_item	2690600	et	3	main
arhivides	doc_534729444719_item	2690604	et	4	main
muusika	doc_534729444719_item	2690607	et	4	main
ma	doc_534729444719_item	2690609	et	3	main
inimestele	doc_534729444719_item	2690613	et	3	main
kes	doc_534729444719_item	2690625	et	4	main
aega	doc_534729444719_item	2690381	et	4	main
töötasid	doc_534729444719_item	2690390	et	4	main
põlvidel	doc_534729444719_item	2690391	et	3	main
ei	doc_534729444719_item	2690397	et	4	main
nad	doc_534729444719_item	2690403	et	3	main
põllumestena	doc_534729444719_item	2690410	et	4	main
saanud	doc_534729444719_item	2690413	et	4	main
aga	doc_534729444719_item	2690415	et	3	main
teavad	doc_534729444719_item	2690424	et	3	main
nende	doc_534729444719_item	2690427	et	4	main
tõttu	doc_534729444719_item	2690430	et	4	main
näitab	doc_534729444719_item	2690439	et	3	main
ja	doc_534729444719_item	2690443	et	3	main
peab	doc_534729444719_item	2690465	et	4	main
laulsid	doc_534729444719_item	2690470	et	4	main
ootasid	doc_534729444719_item	2690473	et	4	main
omad	doc_534729444719_item	2690474	et	4	main
kui	doc_534729444719_item	2690476	et	3	main
nad	doc_534729444719_item	2690477	et	3	main
tulid	doc_534729444719_item	2690478	et	4	main
koju	doc_534729444719_item	2690479	et	3	main
oli	doc_534729444719_item	2690493	et	3	main
nendel	doc_534729444719_item	2690494	et	4	main
esteetiline	doc_534729444719_item	2690495	et	3	main
see	doc_534729444719_item	2690500	et	3	main
oli	doc_534729444719_item	2690508	et	3	main
tol	doc_534729444719_item	2690524	et	3	main
tansust	doc_534729444719_item	2690528	et	4	main
mehed	doc_534729444719_item	2690536	et	3	main
kui	doc_534729444719_item	2690567	et	3	main
ümbertöötlusevad	doc_534729444719_item	2690599	et	4	main
otsivad	doc_534729444719_item	2690602	et	4	main
nende	doc_534729444719_item	2690603	et	4	main
kavatsen	doc_534729444719_item	2690610	et	3	main
kui	doc_534729444719_item	2690612	et	3	main
siis	doc_534729444719_item	2690616	et	3	main
oma	doc_534729444719_item	2690621	et	4	main
aga	doc_534729444719_item	2690623	et	3	main
mäletama	doc_534729444719_item	2690630	et	3	main
oma	doc_534729444719_item	2690631	et	4	main
minevikust	doc_534729444719_item	2690632	et	3	main
elasid	doc_534729444719_item	2690392	et	4	main
nendel	doc_534729444719_item	2690396	et	4	main
peasõnu	doc_534729444719_item	2690399	et	3	main
lauldes	doc_534729444719_item	2690402	et	3	main
nad	doc_534729444719_item	2690408	et	3	main
ei	doc_534729444719_item	2690412	et	4	main
kirjutada	doc_534729444719_item	2690414	et	3	main
et	doc_534729444719_item	2690421	et	3	main
rohkem	doc_534729444719_item	2690438	et	4	main
laulud	doc_534729444719_item	2690442	et	3	main
ja	doc_534729444719_item	2690446	et	3	main
populaarne	doc_534729444719_item	2690453	et	3	main
kodus	doc_534729444719_item	2690459	et	4	main
laul	doc_534729444719_item	2690492	et	4	main
rahvusmuusika	doc_534729444719_item	2690507	et	4	main
muidugi	doc_534729444719_item	2690511	et	4	main
ei	doc_534729444719_item	2690514	et	4	main
laulust	doc_534729444719_item	2690529	et	4	main
nii	doc_534729444719_item	2690531	et	3	main
pidudes	doc_534729444719_item	2690542	et	4	main
minu	doc_534729444719_item	2690543	et	3	main
ja	doc_534729444719_item	2690551	et	3	main
huvitanud	doc_534729444719_item	2690554	et	4	main
see	doc_534729444719_item	2690568	et	3	main
oleks	doc_534729444719_item	2690570	et	3	main
siis	doc_534729444719_item	2690572	et	3	main
need	doc_534729444719_item	2690576	et	3	main
ega	doc_534729444719_item	2690578	et	3	main
praegu	doc_534729444719_item	2690593	et	3	main
rahvalaulud	doc_534729444719_item	2690615	et	3	main
elada	doc_534729444719_item	2690627	et	3	main
ja	doc_534729444719_item	2690426	et	3	main
probleemidest	doc_534729444719_item	2690428	et	3	main
see	doc_534729444719_item	2690429	et	3	main
laulud	doc_534729444719_item	2690431	et	3	main
iseloomustavad	doc_534729444719_item	2690432	et	4	main
iseloomujooned	doc_534729444719_item	2690433	et	3	main
ma	doc_534729444719_item	2690434	et	3	main
et	doc_534729444719_item	2690436	et	3	main
et	doc_534729444719_item	2690441	et	3	main
laulmine	doc_534729444719_item	2690444	et	4	main
ühendavad	doc_534729444719_item	2690447	et	4	main
eestlased	doc_534729444719_item	2690448	et	3	main
et	doc_534729444719_item	2690449	et	3	main
eestis	doc_534729444719_item	2690450	et	3	main
koor	doc_534729444719_item	2690454	et	4	main
nad	doc_534729444719_item	2690456	et	3	main
laulasid	doc_534729444719_item	2690457	et	4	main
põhiliselt	doc_534729444719_item	2690469	et	4	main
naised	doc_534729444719_item	2690471	et	3	main
nad	doc_534729444719_item	2690481	et	3	main
lastele	doc_534729444719_item	2690484	et	4	main
ja	doc_534729444719_item	2690496	et	3	main
emotsionaalne	doc_534729444719_item	2690497	et	3	main
väljendusvahend	doc_534729444719_item	2690498	et	3	main
olnud	doc_534729444719_item	2690515	et	4	main
koosneb	doc_534729444719_item	2690526	et	3	main
teistes	doc_534729444719_item	2690541	et	4	main
pidu	doc_534729444719_item	2690562	et	4	main
kus	doc_534729444719_item	2690563	et	3	main
aga	doc_534729444719_item	2690566	et	3	main
inimesed	doc_534729444719_item	2690573	et	3	main
mitte	doc_534729444719_item	2690579	et	3	main
inimestele	doc_534729444719_item	2690582	et	3	main
meeldib	doc_534729444719_item	2690583	et	3	main
seda	doc_534729444719_item	2690584	et	3	main
muusikat	doc_534729444719_item	2690585	et	3	main
on	doc_534729444719_item	2690588	et	4	main
on	doc_534729444719_item	2690592	et	4	main
noorte	doc_534729444719_item	2690595	et	3	main
ja	doc_534729444719_item	2690605	et	3	main
teevad	doc_534729444719_item	2690606	et	3	main
kättesadavamaks	doc_534729444719_item	2690608	et	3	main
et	doc_534729444719_item	2690611	et	3	main
huvitab	doc_534729444719_item	2690614	et	3	main
ei	doc_534729444719_item	2690618	et	4	main
unistada	doc_534729444719_item	2690620	et	3	main
tahab	doc_534729444719_item	2690626	et	3	main
peab	doc_534729444719_item	2690629	et	4	main
hääled	doc_534729444719_item	2690522	et	3	main
ajal	doc_534729444719_item	2690525	et	4	main
ja	doc_534729444719_item	2690530	et	3	main
edasi	doc_534729444719_item	2690532	et	3	main
oli	doc_534729444719_item	2690535	et	3	main
arvates	doc_534729444719_item	2690544	et	4	main
rahvalaulud	doc_534729444719_item	2690545	et	3	main
ja	doc_534729444719_item	2690546	et	3	main
folkloor	doc_534729444719_item	2690547	et	4	main
inimesed	doc_534729444719_item	2690552	et	3	main
selles	doc_534729444719_item	2690555	et	4	main
sest	doc_534729444719_item	2690556	et	4	main
praegu	doc_534729444719_item	2690557	et	3	main
on	doc_534729444719_item	2690558	et	4	main
palju	doc_534729444719_item	2690559	et	4	main
festivale	doc_534729444719_item	2690560	et	3	main
ja	doc_534729444719_item	2690561	et	3	main
ei	doc_534729444719_item	2690574	et	4	main
see	doc_534729444719_item	2690587	et	3	main
ka	doc_534729444719_item	2690589	et	3	main
eestis	doc_534729444719_item	2690591	et	3	main
nad	doc_534729444719_item	2690601	et	3	main
nad	doc_534729444719_item	2690617	et	3	main
saa	doc_534729444719_item	2690619	et	4	main
ajaloo	doc_534729444719_item	2690622	et	4	main
rahvus	doc_534729444719_item	2690624	et	3	main
edasi	doc_534729444719_item	2690628	et	3	main
keele	doc_534729444722_item	2691100	et	4	main
faktidele	doc_534729444722_item	2691130	et	3	main
on	doc_534729444722_item	2691132	et	4	main
kõikidest	doc_534729444722_item	2691145	et	4	main
suurest	doc_534729444722_item	2691146	et	4	main
mis	doc_534729444722_item	2691167	et	4	main
kes	doc_534729444722_item	2691171	et	4	main
on	doc_534729444722_item	2691172	et	4	main
teemal	doc_534729444722_item	2691108	et	3	main
laulurahva	doc_534729444722_item	2691112	et	3	main
pikkus	doc_534729444722_item	2691114	et	4	main
300	doc_534729444722_item	2691115	et	2	main
eesti	doc_534729444722_item	2691099	et	4	main
keele	doc_534729444722_item	2691103	et	4	main
mis	doc_534729444722_item	2691109	et	4	main
essee	doc_534729444722_item	2691113	et	4	main
350	doc_534729444722_item	2691116	et	2	main
sõna	doc_534729444722_item	2691117	et	4	main
essee	doc_534729444722_item	2691118	et	4	main
üldistav	doc_534729444722_item	2691124	et	4	main
tuginema	doc_534729444722_item	2691125	et	3	main
esitatud	doc_534729444722_item	2691129	et	4	main
näidetega	doc_534729444722_item	2691135	et	3	main
eestis	doc_534729444722_item	2691137	et	3	main
meile	doc_534729444722_item	2691153	et	4	main
rahva	doc_534729444722_item	2691154	et	3	main
kirikut	doc_534729444722_item	2691163	et	3	main
tuntut	doc_534729444722_item	2691173	et	4	main
väljaspool	doc_534729444722_item	2691174	et	3	main
esimene	doc_534729444722_item	2691177	et	3	main
tartus	doc_534729444722_item	2691179	et	3	main
mis	doc_534729444724_item	2691295	et	4	main
teeb	doc_534729444724_item	2691296	et	3	main
sõna	doc_534729444724_item	2691303	et	4	main
on	doc_534729444724_item	2691318	et	4	main
essee	doc_534729444722_item	2691098	et	4	main
teise	doc_534729444722_item	2691102	et	4	main
test	doc_534729444722_item	2691104	et	3	main
teeb	doc_534729444722_item	2691110	et	3	main
peab	doc_534729444722_item	2691119	et	4	main
arutlev	doc_534729444722_item	2691121	et	4	main
lugemistekstis	doc_534729444722_item	2691128	et	3	main
soovitatav	doc_534729444722_item	2691133	et	4	main
alati	doc_534729444722_item	2691139	et	4	main
vanal	doc_534729444722_item	2691142	et	3	main
ajal	doc_534729444722_item	2691143	et	4	main
lauldi	doc_534729444722_item	2691144	et	3	main
tutvumine	doc_534729444722_item	2691151	et	4	main
näitab	doc_534729444722_item	2691152	et	3	main
sündmus	doc_534729444722_item	2691166	et	3	main
eestist	doc_534729444722_item	2691175	et	3	main
oli	doc_534729444722_item	2691176	et	3	main
eestlastest	doc_534729444724_item	2691297	et	4	main
pikkus	doc_534729444724_item	2691300	et	4	main
olema	doc_534729444724_item	2691306	et	4	main
ja	doc_534729444724_item	2691313	et	3	main
lugemistekstis	doc_534729444724_item	2691314	et	3	main
esitatud	doc_534729444724_item	2691315	et	4	main
faktidele	doc_534729444724_item	2691316	et	3	main
näidetega	doc_534729444724_item	2691321	et	3	main
on	doc_534729444724_item	2691323	et	4	main
kultuurinähtus	doc_534729444724_item	2691325	et	4	main
mis	doc_534729444724_item	2691326	et	4	main
arendab	doc_534729444724_item	2691327	et	3	main
laul	doc_534729444724_item	2691337	et	4	main
inimest	doc_534729444724_item	2691338	et	3	main
lauldi	doc_534729444724_item	2691339	et	3	main
üks	doc_534729444724_item	2691340	et	3	main
või	doc_534729444724_item	2691347	et	4	main
teine	doc_534729444724_item	2691348	et	3	main
ammust	doc_534729444724_item	2691352	et	4	main
armastavad	doc_534729444724_item	2691354	et	4	main
vist	doc_534729444724_item	2691358	et	4	main
kui	doc_534729444722_item	2691101	et	3	main
kirjutamine	doc_534729444722_item	2691105	et	4	main
kirjutage	doc_534729444722_item	2691106	et	3	main
essee	doc_534729444722_item	2691107	et	4	main
eestlastest	doc_534729444722_item	2691111	et	4	main
olema	doc_534729444722_item	2691120	et	4	main
analüüsiv	doc_534729444722_item	2691122	et	4	main
loengus	doc_534729444722_item	2691126	et	3	main
väiteid	doc_534729444722_item	2691131	et	4	main
laul	doc_534729444722_item	2691136	et	4	main
oli	doc_534729444722_item	2691138	et	3	main
kultuuri	doc_534729444722_item	2691140	et	4	main
osa	doc_534729444722_item	2691141	et	4	main
üks	doc_534729444722_item	2691165	et	3	main
eestlastest	doc_534729444722_item	2691169	et	4	main
laulupidu	doc_534729444722_item	2691178	et	4	main
ja	doc_534729444722_item	2691123	et	3	main
ja	doc_534729444722_item	2691127	et	3	main
illustreerida	doc_534729444722_item	2691134	et	3	main
sündmusest	doc_534729444722_item	2691147	et	4	main
ja	doc_534729444722_item	2691148	et	3	main
sellepärast	doc_534729444722_item	2691149	et	3	main
rahvalauluga	doc_534729444722_item	2691150	et	4	main
mineviku	doc_534729444722_item	2691155	et	3	main
hiljem	doc_534729444722_item	2691156	et	3	main
levis	doc_534729444722_item	2691157	et	4	main
ka	doc_534729444722_item	2691158	et	3	main
vaimulike	doc_534729444722_item	2691159	et	3	main
laulde	doc_534729444722_item	2691160	et	4	main
laulmine	doc_534729444722_item	2691161	et	4	main
väljaspool	doc_534729444722_item	2691162	et	3	main
veel	doc_534729444722_item	2691164	et	4	main
tegi	doc_534729444722_item	2691168	et	4	main
laulurahva	doc_534729444722_item	2691170	et	3	main
kirjutamine	doc_534729444724_item	2691291	et	4	main
kirjutage	doc_534729444724_item	2691292	et	3	main
essee	doc_534729444724_item	2691293	et	4	main
teemal	doc_534729444724_item	2691294	et	3	main
essee	doc_534729444724_item	2691299	et	4	main
350	doc_534729444724_item	2691302	et	2	main
väiteid	doc_534729444724_item	2691317	et	4	main
inimesi	doc_534729444724_item	2691328	et	4	main
ja	doc_534729444724_item	2691329	et	3	main
minu	doc_534729444724_item	2691349	et	3	main
loodust	doc_534729444724_item	2691364	et	4	main
sugulastesse	doc_534729444724_item	2691371	et	4	main
on	doc_534729444724_item	2691380	et	4	main
minu	doc_534729444724_item	2691384	et	3	main
alustati	doc_534729444724_item	2691387	et	4	main
tunda	doc_534729444724_item	2691388	et	3	main
laulurahva	doc_534729444724_item	2691391	et	3	main
hoidjad	doc_534729444724_item	2691396	et	4	main
ja	doc_534729444724_item	2691397	et	3	main
on	doc_534729444724_item	2691399	et	4	main
peredes	doc_534729444724_item	2691423	et	3	main
praegu	doc_534729444724_item	2691429	et	3	main
elavad	doc_534729444724_item	2691432	et	4	main
selles	doc_534729444724_item	2691437	et	4	main
et	doc_534729444724_item	2691438	et	3	main
nende	doc_534729444724_item	2691439	et	4	main
lapsed	doc_534729444724_item	2691440	et	3	main
peavad	doc_534729444724_item	2691441	et	4	main
oskama	doc_534729444724_item	2691442	et	3	main
huvitav	doc_534729444724_item	2691448	et	4	main
aga	doc_534729444724_item	2691450	et	3	main
kasvatatakse	doc_534729444724_item	2691457	et	3	main
kui	doc_534729444725_item	2691474	et	3	main
teise	doc_534729444725_item	2691475	et	4	main
keele	doc_534729444725_item	2691476	et	4	main
test	doc_534729444725_item	2691477	et	3	main
rahvas	doc_534729444725_item	2691513	et	4	main
laulas	doc_534729444725_item	2691514	et	4	main
lapse	doc_534729444725_item	2691519	et	4	main
naised	doc_534729444725_item	2691522	et	3	main
laulsid	doc_534729444725_item	2691533	et	4	main
sai	doc_534729444725_item	2691542	et	4	main
laul	doc_534729444725_item	2691548	et	4	main
laul	doc_534729444725_item	2691550	et	4	main
mida	doc_534729444725_item	2691551	et	4	main
kirjutati	doc_534729444725_item	2691552	et	3	main
ja	doc_534729444725_item	2691553	et	3	main
vanal	doc_534729444725_item	2691562	et	3	main
autorit	doc_534729444725_item	2691573	et	3	main
algasid	doc_534729444725_item	2691574	et	4	main
kasutada	doc_534729444725_item	2691575	et	3	main
uusi	doc_534729444725_item	2691576	et	3	main
instrumendi	doc_534729444725_item	2691577	et	3	main
ja	doc_534729444725_item	2691578	et	3	main
rahvas	doc_534729444725_item	2691579	et	4	main
üldlaulupidude	doc_534729444725_item	2691612	et	4	main
100	doc_534729444725_item	2691613	et	2	main
tuntud	doc_534729444725_item	2691630	et	4	main
turistid	doc_534729444725_item	2691632	et	3	main
et	doc_534729444725_item	2691637	et	3	main
laulavad	doc_534729444725_item	2691640	et	4	main
mängivad	doc_534729444725_item	2691642	et	4	main
kogu	doc_534729444725_item	2691645	et	4	main
eestist	doc_534729444725_item	2691646	et	3	main
koorid	doc_534729444725_item	2691652	et	4	main
essee	doc_534729444724_item	2691284	et	4	main
eesti	doc_534729444724_item	2691285	et	4	main
keele	doc_534729444724_item	2691286	et	4	main
kui	doc_534729444724_item	2691287	et	3	main
teise	doc_534729444724_item	2691288	et	4	main
keele	doc_534729444724_item	2691289	et	4	main
test	doc_534729444724_item	2691290	et	3	main
300	doc_534729444724_item	2691301	et	2	main
peab	doc_534729444724_item	2691305	et	4	main
analüüsiv	doc_534729444724_item	2691308	et	4	main
tähelepanuväärne	doc_534729444724_item	2691324	et	3	main
hingeid	doc_534729444724_item	2691331	et	4	main
laulda	doc_534729444724_item	2691356	et	4	main
see	doc_534729444724_item	2691357	et	3	main
laule	doc_534729444724_item	2691365	et	4	main
ja	doc_534729444724_item	2691372	et	3	main
oma	doc_534729444724_item	2691373	et	4	main
kõrghetk	doc_534729444724_item	2691381	et	3	main
ajaloos	doc_534729444724_item	2691383	et	4	main
mõttes	doc_534729444724_item	2691385	et	3	main
identiteedi	doc_534729444724_item	2691395	et	4	main
ja	doc_534729444724_item	2691422	et	3	main
lapsi	doc_534729444724_item	2691425	et	4	main
keda	doc_534729444724_item	2691426	et	4	main
huvitatud	doc_534729444724_item	2691436	et	4	main
maal	doc_534729444724_item	2691454	et	4	main
külas	doc_534729444724_item	2691455	et	3	main
tantse	doc_534729444724_item	2691463	et	3	main
selles	doc_534729444724_item	2691466	et	4	main
essee	doc_534729444725_item	2691471	et	4	main
eesti	doc_534729444725_item	2691472	et	4	main
keele	doc_534729444725_item	2691473	et	4	main
palju	doc_534729444725_item	2691515	et	4	main
või	doc_534729444725_item	2691529	et	4	main
üldse	doc_534729444725_item	2691530	et	3	main
kooris	doc_534729444725_item	2691531	et	4	main
mehed	doc_534729444725_item	2691532	et	3	main
rahvasümboliks	doc_534729444725_item	2691543	et	4	main
uus	doc_534729444725_item	2691547	et	3	main
rahvas	doc_534729444725_item	2691557	et	4	main
ajal	doc_534729444725_item	2691563	et	4	main
ei	doc_534729444725_item	2691571	et	4	main
teadnud	doc_534729444725_item	2691572	et	4	main
aastal	doc_534729444725_item	2691610	et	3	main
juba	doc_534729444725_item	2691615	et	3	main
aastal	doc_534729444725_item	2691619	et	3	main
laulurahva	doc_534729444724_item	2691298	et	3	main
essee	doc_534729444724_item	2691304	et	4	main
arutlev	doc_534729444724_item	2691307	et	4	main
ja	doc_534729444724_item	2691309	et	3	main
üldistav	doc_534729444724_item	2691310	et	4	main
tuginema	doc_534729444724_item	2691311	et	3	main
loengus	doc_534729444724_item	2691312	et	3	main
laulmine	doc_534729444724_item	2691322	et	4	main
nende	doc_534729444724_item	2691330	et	4	main
tundeid	doc_534729444724_item	2691332	et	3	main
juba	doc_534729444724_item	2691333	et	3	main
vanal	doc_534729444724_item	2691334	et	3	main
ajal	doc_534729444724_item	2691335	et	4	main
saatis	doc_534729444724_item	2691336	et	3	main
last	doc_534729444724_item	2691345	et	4	main
kiigutades	doc_534729444724_item	2691346	et	3	main
juba	doc_534729444724_item	2691351	et	3	main
sellest	doc_534729444724_item	2691360	et	4	main
et	doc_534729444724_item	2691361	et	3	main
maa	doc_534729444724_item	2691374	et	4	main
teame	doc_534729444724_item	2691377	et	3	main
laulupeod	doc_534729444724_item	2691379	et	4	main
soovitatav	doc_534729444724_item	2691319	et	4	main
illustreerida	doc_534729444724_item	2691320	et	3	main
kõik	doc_534729444724_item	2691341	et	4	main
mis	doc_534729444724_item	2691342	et	4	main
tegemiseks	doc_534729444724_item	2691343	et	4	main
töötades	doc_534729444724_item	2691344	et	3	main
arvates	doc_534729444724_item	2691350	et	4	main
ajast	doc_534729444724_item	2691353	et	4	main
eestlased	doc_534729444724_item	2691355	et	3	main
eestlased	doc_534729444724_item	2691362	et	3	main
armastavad	doc_534729444724_item	2691363	et	4	main
suhtlevad	doc_534729444724_item	2691369	et	4	main
oma	doc_534729444724_item	2691370	et	4	main
et	doc_534729444724_item	2691378	et	3	main
eesti	doc_534729444724_item	2691382	et	4	main
sellega	doc_534729444724_item	2691386	et	3	main
nagu	doc_534729444724_item	2691390	et	3	main
õige	doc_534729444724_item	2691400	et	4	main
eestlased	doc_534729444724_item	2691401	et	3	main
hojavad	doc_534729444724_item	2691402	et	4	main
oma	doc_534729444724_item	2691403	et	4	main
maad	doc_534729444724_item	2691404	et	4	main
oma	doc_534729444724_item	2691405	et	4	main
kombed	doc_534729444724_item	2691406	et	3	main
ja	doc_534729444724_item	2691407	et	3	main
traditsioonid	doc_534729444724_item	2691408	et	3	main
see	doc_534729444724_item	2691409	et	3	main
nõuab	doc_534729444724_item	2691410	et	3	main
lugupidamist	doc_534729444724_item	2691411	et	3	main
suur	doc_534729444724_item	2691412	et	3	main
osa	doc_534729444724_item	2691413	et	4	main
kasvatamist	doc_534729444724_item	2691415	et	4	main
sõltub	doc_534729444724_item	2691414	et	3	main
ja	doc_534729444724_item	2691416	et	3	main
haridust	doc_534729444724_item	2691417	et	4	main
vanal	doc_534729444724_item	2691418	et	3	main
ajal	doc_534729444724_item	2691419	et	4	main
polnud	doc_534729444724_item	2691420	et	3	main
inimesed	doc_534729444724_item	2691430	et	3	main
laulda	doc_534729444724_item	2691443	et	4	main
on	doc_534729444724_item	2691447	et	4	main
mitte	doc_534729444724_item	2691451	et	3	main
lapsi	doc_534729444724_item	2691456	et	4	main
armastama	doc_534729444724_item	2691460	et	3	main
laule	doc_534729444724_item	2691462	et	4	main
arvates	doc_534729444724_item	2691465	et	4	main
ongi	doc_534729444724_item	2691467	et	4	main
eesti	doc_534729444724_item	2691468	et	4	main
nagu	doc_534729444724_item	2691469	et	3	main
kirjutamine	doc_534729444725_item	2691478	et	4	main
kirjutage	doc_534729444725_item	2691479	et	3	main
essee	doc_534729444725_item	2691480	et	4	main
töö	doc_534729444725_item	2691516	et	4	main
laulsid	doc_534729444725_item	2691523	et	4	main
laulsid	doc_534729444725_item	2691526	et	4	main
üksi	doc_534729444725_item	2691527	et	4	main
pulmalaule	doc_534729444725_item	2691535	et	4	main
lauldi	doc_534729444725_item	2691536	et	3	main
riimiline	doc_534729444725_item	2691549	et	4	main
trükiti	doc_534729444725_item	2691554	et	3	main
selleks	doc_534729444725_item	2691555	et	4	main
et	doc_534729444725_item	2691556	et	3	main
sõltub	doc_534729444724_item	2691359	et	3	main
tööd	doc_534729444724_item	2691366	et	4	main
ja	doc_534729444724_item	2691367	et	3	main
lugupidamisega	doc_534729444724_item	2691368	et	3	main
ajaloosse	doc_534729444724_item	2691375	et	4	main
me	doc_534729444724_item	2691376	et	4	main
eestlasi	doc_534729444724_item	2691389	et	3	main
laulupeost	doc_534729444724_item	2691392	et	4	main
kujunesid	doc_534729444724_item	2691393	et	4	main
rahvusliku	doc_534729444724_item	2691394	et	3	main
see	doc_534729444724_item	2691398	et	3	main
kooli	doc_534729444724_item	2691421	et	4	main
laulda	doc_534729444724_item	2691428	et	4	main
ole	doc_534729444724_item	2691435	et	4	main
see	doc_534729444724_item	2691444	et	3	main
tõttu	doc_534729444724_item	2691445	et	4	main
pop-muusika	doc_534729444724_item	2691449	et	4	main
rahvalaul	doc_534729444724_item	2691452	et	4	main
kuid	doc_534729444724_item	2691453	et	4	main
teistmoodi	doc_534729444724_item	2691458	et	3	main
minu	doc_534729444724_item	2691464	et	3	main
hoidmise	doc_534729444725_item	2691520	et	4	main
kasvatati	doc_534729444724_item	2691424	et	3	main
õpetati	doc_534729444724_item	2691427	et	3	main
kes	doc_534729444724_item	2691431	et	4	main
linnas	doc_534729444724_item	2691433	et	4	main
ei	doc_534729444724_item	2691434	et	4	main
lastele	doc_534729444724_item	2691446	et	4	main
õpetakse	doc_534729444724_item	2691459	et	4	main
tööd	doc_534729444724_item	2691461	et	4	main
laulurahv	doc_534729444724_item	2691470	et	4	main
teemal	doc_534729444725_item	2691481	et	3	main
mis	doc_534729444725_item	2691482	et	4	main
teeb	doc_534729444725_item	2691483	et	3	main
eestlastest	doc_534729444725_item	2691484	et	4	main
laulurahva	doc_534729444725_item	2691485	et	3	main
essee	doc_534729444725_item	2691486	et	4	main
pikkus	doc_534729444725_item	2691487	et	4	main
300	doc_534729444725_item	2691488	et	2	main
350	doc_534729444725_item	2691489	et	2	main
sõna	doc_534729444725_item	2691490	et	4	main
essee	doc_534729444725_item	2691491	et	4	main
peab	doc_534729444725_item	2691492	et	4	main
olema	doc_534729444725_item	2691493	et	4	main
arutlev	doc_534729444725_item	2691494	et	4	main
analüüsiv	doc_534729444725_item	2691495	et	4	main
ja	doc_534729444725_item	2691496	et	3	main
üldistav	doc_534729444725_item	2691497	et	4	main
tuginema	doc_534729444725_item	2691498	et	3	main
loengus	doc_534729444725_item	2691499	et	3	main
ja	doc_534729444725_item	2691500	et	3	main
lugemistekstis	doc_534729444725_item	2691501	et	3	main
esitatud	doc_534729444725_item	2691502	et	4	main
faktidele	doc_534729444725_item	2691503	et	3	main
väiteid	doc_534729444725_item	2691504	et	4	main
on	doc_534729444725_item	2691505	et	4	main
soovitatav	doc_534729444725_item	2691506	et	4	main
illustreerida	doc_534729444725_item	2691507	et	3	main
näidetega	doc_534729444725_item	2691508	et	3	main
juba	doc_534729444725_item	2691509	et	3	main
vanal	doc_534729444725_item	2691510	et	3	main
ajal	doc_534729444725_item	2691511	et	4	main
eesti	doc_534729444725_item	2691512	et	4	main
ajal	doc_534729444725_item	2691517	et	4	main
või	doc_534729444725_item	2691518	et	4	main
ajal	doc_534729444725_item	2691521	et	4	main
erinevaid	doc_534729444725_item	2691524	et	4	main
nn	doc_534729444725_item	2691534	et	4	main
sajandil	doc_534729444725_item	2691545	et	3	main
sai	doc_534729444725_item	2691558	et	4	main
laulud	doc_534729444725_item	2691564	et	3	main
põlvest	doc_534729444725_item	2691566	et	4	main
suuliselt	doc_534729444725_item	2691568	et	4	main
ja	doc_534729444725_item	2691569	et	3	main
tallinnas	doc_534729444725_item	2691616	et	4	main
1996	doc_534729444725_item	2691618	et	2	main
korraldama	doc_534729444725_item	2691622	et	3	main
praegusel	doc_534729444725_item	2691624	et	3	main
praegu	doc_534729444725_item	2691626	et	3	main
ülemaailma	doc_534729444725_item	2691631	et	4	main
riikidest	doc_534729444725_item	2691634	et	3	main
kuulama	doc_534729444725_item	2691638	et	3	main
tuhanded	doc_534729444725_item	2691643	et	3	main
inimesed	doc_534729444725_item	2691644	et	3	main
praegu	doc_534729444725_item	2691647	et	3	main
see	doc_534729444725_item	2691648	et	3	main
sai	doc_534729444725_item	2691649	et	4	main
seda	doc_534729444725_item	2691666	et	3	main
on	doc_534729444725_item	2691677	et	4	main
lomingus	doc_534729444725_item	2691681	et	4	main
sajandit	doc_534729444725_item	2691695	et	3	main
selles	doc_534729444725_item	2691707	et	4	main
tegid	doc_534729444725_item	2691721	et	4	main
kus	doc_534729444725_item	2691723	et	3	main
see	doc_534729444725_item	2691731	et	3	main
ei	doc_534729444725_item	2691732	et	4	main
essee	doc_534729444726_item	2691740	et	4	main
kirjutamine	doc_534729444726_item	2691747	et	4	main
kirjutage	doc_534729444726_item	2691748	et	3	main
essee	doc_534729444726_item	2691749	et	4	main
teemal	doc_534729444726_item	2691750	et	3	main
350	doc_534729444726_item	2691758	et	2	main
peab	doc_534729444726_item	2691761	et	4	main
arutlev	doc_534729444726_item	2691763	et	4	main
üksinda	doc_534729444726_item	2691806	et	4	main
vanem	doc_534729444726_item	2691808	et	4	main
rahvalaul	doc_534729444726_item	2691809	et	4	main
on	doc_534729444726_item	2691813	et	4	main
kujunenud	doc_534729444726_item	2691814	et	4	main
rahvalaulu	doc_534729444726_item	2691827	et	4	main
saatel	doc_534729444726_item	2691828	et	4	main
ajal	doc_534729444726_item	2691847	et	4	main
sõnu	doc_534729444726_item	2691861	et	4	main
nad	doc_534729444726_item	2691868	et	3	main
laule	doc_534729444726_item	2691870	et	4	main
mis	doc_534729444726_item	2691893	et	4	main
koosmõju	doc_534729444726_item	2691904	et	4	main
olid	doc_534729444726_item	2691912	et	4	main
rahvalaulud	doc_534729444726_item	2691916	et	3	main
esitatud	doc_534729444726_item	2691922	et	4	main
võib	doc_534729444726_item	2691925	et	3	main
neid	doc_534729444726_item	2691928	et	4	main
sündmusi	doc_534729444726_item	2691929	et	3	main
ja	doc_534729444726_item	2691930	et	3	main
üritusi	doc_534729444726_item	2691931	et	4	main
tantsimiseks	doc_534729444726_item	2691937	et	4	main
ka	doc_534729444726_item	2691938	et	3	main
laulavad	doc_534729444726_item	2691944	et	4	main
rahvalaulu	doc_534729444726_item	2691955	et	4	main
töödeldud	doc_534729444726_item	2691961	et	4	main
välja	doc_534729444726_item	2691966	et	4	main
laulud	doc_534729444726_item	2691969	et	3	main
keeles	doc_534729444726_item	2691972	et	4	main
on	doc_534729444726_item	2691975	et	4	main
üritused	doc_534729444726_item	2691984	et	4	main
laulda	doc_534729444726_item	2692000	et	4	main
ja	doc_534729444726_item	2692001	et	3	main
kogeda	doc_534729444726_item	2692002	et	3	main
seda	doc_534729444726_item	2692003	et	3	main
tunnet	doc_534729444726_item	2692004	et	3	main
samaaegselt	doc_534729444726_item	2692008	et	4	main
sõnu	doc_534729444726_item	2692012	et	4	main
sama	doc_534729444726_item	2692014	et	4	main
laulu	doc_534729444725_item	2691525	et	4	main
kahekesi	doc_534729444725_item	2691528	et	3	main
veel	doc_534729444725_item	2691537	et	4	main
kirikus	doc_534729444725_item	2691538	et	3	main
nii	doc_534729444725_item	2691539	et	3	main
et	doc_534729444725_item	2691540	et	3	main
laul	doc_534729444725_item	2691541	et	4	main
19	doc_534729444725_item	2691544	et	2	main
tekkis	doc_534729444725_item	2691546	et	3	main
teada	doc_534729444725_item	2691559	et	3	main
seda	doc_534729444725_item	2691560	et	3	main
sest	doc_534729444725_item	2691561	et	4	main
pärandati	doc_534729444725_item	2691565	et	4	main
põlve	doc_534729444725_item	2691567	et	4	main
laulma	doc_534729444725_item	2691581	et	3	main
rohkem	doc_534729444725_item	2691582	et	4	main
see	doc_534729444725_item	2691584	et	3	main
tõi	doc_534729444725_item	2691585	et	3	main
kõik	doc_534729444725_item	2691583	et	4	main
selleni	doc_534729444725_item	2691586	et	3	main
et	doc_534729444725_item	2691587	et	3	main
1869	doc_534729444725_item	2691588	et	2	main
aastal	doc_534729444725_item	2691589	et	3	main
tartus	doc_534729444725_item	2691590	et	3	main
oli	doc_534729444725_item	2691591	et	3	main
korraldatus	doc_534729444725_item	2691592	et	4	main
uus	doc_534729444725_item	2691593	et	3	main
pidu	doc_534729444725_item	2691594	et	4	main
laulupidu	doc_534729444725_item	2691595	et	4	main
kus	doc_534729444725_item	2691596	et	3	main
esinesid	doc_534729444725_item	2691597	et	4	main
meeskoorid	doc_534729444725_item	2691598	et	4	main
ja	doc_534729444725_item	2691599	et	3	main
orkestrid	doc_534729444725_item	2691600	et	3	main
kogu	doc_534729444725_item	2691601	et	4	main
eestist	doc_534729444725_item	2691602	et	3	main
see	doc_534729444725_item	2691603	et	3	main
pani	doc_534729444725_item	2691604	et	4	main
aluse	doc_534729444725_item	2691605	et	4	main
järgnevate	doc_534729444725_item	2691606	et	4	main
pidude	doc_534729444725_item	2691607	et	4	main
korraldamisele	doc_534729444725_item	2691608	et	4	main
kegi	doc_534729444725_item	2691570	et	4	main
hakkas	doc_534729444725_item	2691580	et	3	main
aastapäeva	doc_534729444725_item	2691614	et	4	main
hakkati	doc_534729444725_item	2691621	et	3	main
tallinnas	doc_534729444725_item	2691623	et	4	main
traditsiooniks	doc_534729444725_item	2691650	et	3	main
vaatavad	doc_534729444725_item	2691668	et	4	main
nad	doc_534729444725_item	2691670	et	3	main
sest	doc_534729444725_item	2691672	et	4	main
see	doc_534729444725_item	2691673	et	3	main
on	doc_534729444725_item	2691674	et	4	main
kultuur	doc_534729444725_item	2691675	et	3	main
praegu	doc_534729444725_item	2691676	et	3	main
folklöör	doc_534729444725_item	2691686	et	4	main
need	doc_534729444725_item	2691687	et	3	main
vanad	doc_534729444725_item	2691688	et	3	main
rahvalaulud	doc_534729444725_item	2691689	et	3	main
mida	doc_534729444725_item	2691690	et	4	main
lauldi	doc_534729444725_item	2691691	et	3	main
2	doc_534729444725_item	2691692	et	2	main
huvitanud	doc_534729444725_item	2691706	et	4	main
tugev	doc_534729444725_item	2691714	et	4	main
muusitseerivad	doc_534729444725_item	2691728	et	4	main
on	doc_534729444725_item	2691735	et	4	main
ei	doc_534729444725_item	2691738	et	4	main
sure	doc_534729444725_item	2691739	et	4	main
300	doc_534729444726_item	2691757	et	2	main
olema	doc_534729444726_item	2691762	et	4	main
analüüsiv	doc_534729444726_item	2691764	et	4	main
ja	doc_534729444726_item	2691765	et	3	main
olles	doc_534729444726_item	2691805	et	3	main
1969	doc_534729444725_item	2691609	et	2	main
tähistati	doc_534729444725_item	2691611	et	4	main
sest	doc_534729444725_item	2691617	et	4	main
laulupidu	doc_534729444725_item	2691620	et	4	main
lauluväljakul	doc_534729444725_item	2691625	et	3	main
eestipärased	doc_534729444725_item	2691627	et	4	main
laulupeod	doc_534729444725_item	2691628	et	4	main
erinevatest	doc_534729444725_item	2691633	et	4	main
tulevad	doc_534729444725_item	2691635	et	4	main
ja	doc_534729444725_item	2691641	et	3	main
kuulavad	doc_534729444725_item	2691665	et	4	main
kuidas	doc_534729444725_item	2691669	et	3	main
tantsivad	doc_534729444725_item	2691671	et	4	main
suur	doc_534729444725_item	2691682	et	3	main
rool	doc_534729444725_item	2691683	et	4	main
just	doc_534729444725_item	2691685	et	3	main
ja	doc_534729444725_item	2691697	et	3	main
rahvas	doc_534729444725_item	2691699	et	4	main
et	doc_534729444725_item	2691708	et	3	main
kogu	doc_534729444725_item	2691709	et	4	main
maailmas	doc_534729444725_item	2691710	et	3	main
inimesed	doc_534729444725_item	2691711	et	3	main
teadsid	doc_534729444725_item	2691712	et	4	main
see	doc_534729444725_item	2691716	et	3	main
näiteks	doc_534729444725_item	2691718	et	4	main
värskas	doc_534729444725_item	2691719	et	4	main
koolipoisid	doc_534729444725_item	2691720	et	4	main
on	doc_534729444725_item	2691629	et	4	main
eestisse	doc_534729444725_item	2691636	et	4	main
kuidas	doc_534729444725_item	2691639	et	3	main
mitmesugused	doc_534729444725_item	2691651	et	3	main
naiste	doc_534729444725_item	2691654	et	3	main
laste	doc_534729444725_item	2691655	et	4	main
sõidavad	doc_534729444725_item	2691656	et	3	main
tallinnasse	doc_534729444725_item	2691657	et	3	main
et	doc_534729444725_item	2691658	et	3	main
laulma	doc_534729444725_item	2691659	et	3	main
kõik	doc_534729444725_item	2691660	et	4	main
koos	doc_534729444725_item	2691661	et	4	main
lauluväljakul	doc_534729444725_item	2691662	et	3	main
ja	doc_534729444725_item	2691663	et	3	main
inimesed	doc_534729444725_item	2691664	et	3	main
meeste	doc_534729444725_item	2691653	et	4	main
ansambleid	doc_534729444725_item	2691679	et	3	main
tagasi	doc_534729444725_item	2691696	et	3	main
kõik	doc_534729444725_item	2691701	et	4	main
laulud	doc_534729444725_item	2691703	et	3	main
ja	doc_534729444725_item	2691704	et	3	main
on	doc_534729444725_item	2691705	et	4	main
kui	doc_534729444725_item	2691713	et	3	main
nad	doc_534729444725_item	2691724	et	3	main
laulavad	doc_534729444725_item	2691725	et	4	main
setu-keeles	doc_534729444725_item	2691726	et	4	main
aga	doc_534729444725_item	2691727	et	3	main
super	doc_534729444725_item	2691734	et	3	main
niimodi	doc_534729444725_item	2691736	et	4	main
kombed	doc_534729444725_item	2691737	et	3	main
mis	doc_534729444726_item	2691751	et	4	main
teeb	doc_534729444726_item	2691752	et	3	main
eestlastest	doc_534729444726_item	2691753	et	4	main
sõna	doc_534729444726_item	2691759	et	4	main
tuginema	doc_534729444726_item	2691767	et	3	main
loengus	doc_534729444726_item	2691768	et	3	main
kui	doc_534729444726_item	2691816	et	3	main
laulu	doc_534729444726_item	2691821	et	4	main
koor	doc_534729444726_item	2691823	et	4	main
rõhutati	doc_534729444726_item	2691829	et	4	main
rütmi	doc_534729444726_item	2691830	et	4	main
kui	doc_534729444726_item	2691837	et	3	main
uuemast	doc_534729444726_item	2691839	et	4	main
ajast	doc_534729444726_item	2691840	et	4	main
võib	doc_534729444726_item	2691848	et	3	main
kasutavad	doc_534729444726_item	2691860	et	4	main
ja	doc_534729444726_item	2691864	et	3	main
euroopa	doc_534729444726_item	2691902	et	4	main
laulutraditsiooni	doc_534729444726_item	2691903	et	4	main
on	doc_534729444726_item	2691917	et	4	main
ning	doc_534729444726_item	2691946	et	3	main
teised	doc_534729444726_item	2691947	et	4	main
esinejad	doc_534729444726_item	2691948	et	4	main
on	doc_534729444726_item	2691959	et	4	main
kõik	doc_534729444726_item	2691960	et	4	main
noorpoiste	doc_534729444726_item	2691963	et	3	main
andis	doc_534729444726_item	2691965	et	3	main
plaadi	doc_534729444726_item	2691967	et	4	main
kus	doc_534729444726_item	2691968	et	3	main
on	doc_534729444726_item	2691978	et	4	main
väga	doc_534729444726_item	2691979	et	3	main
tore	doc_534729444726_item	2691980	et	3	main
et	doc_534729444726_item	2691981	et	3	main
seal	doc_534729444726_item	2691987	et	4	main
saab	doc_534729444726_item	2691988	et	3	main
mis	doc_534729444726_item	2692005	et	4	main
tekib	doc_534729444726_item	2692006	et	3	main
ja	doc_534729444726_item	2692013	et	3	main
viisi	doc_534729444726_item	2692015	et	4	main
laulda	doc_534729444726_item	2692016	et	4	main
ja	doc_534729444725_item	2691667	et	3	main
palju	doc_534729444725_item	2691678	et	4	main
kelle	doc_534729444725_item	2691680	et	4	main
mängib	doc_534729444725_item	2691684	et	3	main
või	doc_534729444725_item	2691693	et	4	main
3	doc_534729444725_item	2691694	et	2	main
eesti	doc_534729444725_item	2691698	et	4	main
mäletab	doc_534729444725_item	2691700	et	3	main
need	doc_534729444725_item	2691702	et	3	main
on	doc_534729444725_item	2691715	et	4	main
traditsioon	doc_534729444725_item	2691717	et	3	main
rock-stiilis	doc_534729444725_item	2691729	et	4	main
kas	doc_534729444725_item	2691730	et	3	main
ole	doc_534729444725_item	2691733	et	4	main
eesti	doc_534729444726_item	2691741	et	4	main
keele	doc_534729444726_item	2691742	et	4	main
kui	doc_534729444726_item	2691743	et	3	main
teise	doc_534729444726_item	2691744	et	4	main
keele	doc_534729444726_item	2691745	et	4	main
test	doc_534729444726_item	2691746	et	3	main
laulurahva	doc_534729444726_item	2691754	et	3	main
essee	doc_534729444726_item	2691755	et	4	main
essee	doc_534729444726_item	2691760	et	4	main
lugemistekstis	doc_534729444726_item	2691770	et	3	main
faktidele	doc_534729444726_item	2691772	et	3	main
väiteid	doc_534729444726_item	2691773	et	4	main
on	doc_534729444726_item	2691774	et	4	main
on	doc_534729444726_item	2691810	et	4	main
regilaul	doc_534729444726_item	2691811	et	4	main
mis	doc_534729444726_item	2691812	et	4	main
tuhat	doc_534729444726_item	2691817	et	4	main
aastat	doc_534729444726_item	2691818	et	3	main
tagasi	doc_534729444726_item	2691819	et	3	main
seda	doc_534729444726_item	2691820	et	3	main
esitati	doc_534729444726_item	2691822	et	4	main
ja	doc_534729444726_item	2691824	et	3	main
laulja	doc_534729444726_item	2691825	et	4	main
või	doc_534729444726_item	2691834	et	4	main
siis	doc_534729444726_item	2691835	et	3	main
lindistusi	doc_534729444726_item	2691856	et	4	main
tänapäeval	doc_534729444726_item	2691857	et	3	main
paljud	doc_534729444726_item	2691858	et	3	main
muusikud	doc_534729444726_item	2691859	et	4	main
rahvalauludest	doc_534729444726_item	2691863	et	3	main
aga	doc_534729444726_item	2691866	et	3	main
muusika	doc_534729444726_item	2691891	et	4	main
aitasid	doc_534729444726_item	2691894	et	4	main
venemaa	doc_534729444726_item	2691900	et	4	main
ja	doc_534729444726_item	2691901	et	3	main
stiili	doc_534729444726_item	2691910	et	4	main
need	doc_534729444726_item	2691911	et	3	main
rahvalaulud	doc_534729444726_item	2691914	et	3	main
regilauludest	doc_534729444726_item	2691918	et	3	main
muusikaplaati	doc_534729444725_item	2691722	et	4	main
pikkus	doc_534729444726_item	2691756	et	4	main
üldistav	doc_534729444726_item	2691766	et	4	main
ja	doc_534729444726_item	2691769	et	3	main
esitatud	doc_534729444726_item	2691771	et	4	main
soovitatav	doc_534729444726_item	2691775	et	4	main
illustreerida	doc_534729444726_item	2691776	et	3	main
näidetega	doc_534729444726_item	2691777	et	3	main
mis	doc_534729444726_item	2691778	et	4	main
teeb	doc_534729444726_item	2691779	et	3	main
eestlastest	doc_534729444726_item	2691780	et	4	main
laulurahva	doc_534729444726_item	2691781	et	3	main
mida	doc_534729444726_item	2691782	et	4	main
tähendab	doc_534729444726_item	2691783	et	3	main
laulmine	doc_534729444726_item	2691784	et	4	main
laulmine	doc_534729444726_item	2691785	et	4	main
on	doc_534729444726_item	2691786	et	4	main
enese	doc_534729444726_item	2691787	et	4	main
väljendamise	doc_534729444726_item	2691788	et	4	main
vahend	doc_534729444726_item	2691789	et	3	main
vanal	doc_534729444726_item	2691790	et	3	main
ajal	doc_534729444726_item	2691791	et	4	main
saatis	doc_534729444726_item	2691792	et	3	main
laul	doc_534729444726_item	2691793	et	4	main
inimesi	doc_534729444726_item	2691794	et	4	main
sünnist	doc_534729444726_item	2691795	et	4	main
surmani	doc_534729444726_item	2691796	et	3	main
inimesed	doc_534729444726_item	2691797	et	3	main
laulsid	doc_534729444726_item	2691798	et	4	main
pidevalt	doc_534729444726_item	2691799	et	4	main
nii	doc_534729444726_item	2691800	et	3	main
töö	doc_534729444726_item	2691801	et	4	main
jooksul	doc_534729444726_item	2691802	et	4	main
kui	doc_534729444726_item	2691803	et	3	main
ka	doc_534729444726_item	2691804	et	3	main
kõige	doc_534729444726_item	2691807	et	4	main
enam	doc_534729444726_item	2691815	et	4	main
vaheldumisi	doc_534729444726_item	2691826	et	4	main
keha	doc_534729444726_item	2691831	et	4	main
materjali	doc_534729444726_item	2691844	et	4	main
lauludest	doc_534729444726_item	2691845	et	3	main
praegusel	doc_534729444726_item	2691846	et	3	main
voi	doc_534729444726_item	2691850	et	4	main
vaadata	doc_534729444726_item	2691852	et	4	main
vanu	doc_534729444726_item	2691853	et	4	main
salmiraamatuid	doc_534729444726_item	2691854	et	3	main
kuulata	doc_534729444726_item	2691855	et	4	main
neid	doc_534729444726_item	2691869	et	4	main
kasutusele	doc_534729444726_item	2691889	et	4	main
muusikat	doc_534729444726_item	2691895	et	3	main
emotsionaalseks	doc_534729444726_item	2691898	et	3	main
lõi	doc_534729444726_item	2691905	et	4	main
19	doc_534729444726_item	2691906	et	2	main
sajandil	doc_534729444726_item	2691907	et	3	main
uut	doc_534729444726_item	2691908	et	3	main
muusika	doc_534729444726_item	2691909	et	4	main
riimilised	doc_534729444726_item	2691913	et	4	main
riimilised	doc_534729444726_item	2691915	et	4	main
mitmekesisemad	doc_534729444726_item	2691919	et	4	main
ning	doc_534729444726_item	2691920	et	3	main
on	doc_534729444726_item	2691921	et	4	main
pillisaatega	doc_534729444726_item	2691923	et	3	main
tänapäeval	doc_534729444726_item	2691924	et	3	main
näha	doc_534729444726_item	2691927	et	3	main
laulmiseks	doc_534729444726_item	2691935	et	4	main
ja	doc_534729444726_item	2691936	et	3	main
laulupeod	doc_534729444726_item	2691942	et	4	main
kus	doc_534729444726_item	2691943	et	3	main
nad	doc_534729444726_item	2691958	et	3	main
ansambel	doc_534729444726_item	2691964	et	3	main
rock	doc_534729444726_item	2691976	et	4	main
muusika	doc_534729444726_item	2691977	et	4	main
nagu	doc_534729444726_item	2691985	et	3	main
laulupeod	doc_534729444726_item	2691986	et	4	main
oma	doc_534729444726_item	2691990	et	4	main
ja	doc_534729444726_item	2691993	et	3	main
ja	doc_534729444726_item	2692009	et	3	main
ootsutamisele	doc_534729444726_item	2691832	et	4	main
jalgadepõrutustele	doc_534729444726_item	2691833	et	4	main
liikumisele	doc_534729444726_item	2691836	et	4	main
rääkida	doc_534729444726_item	2691838	et	3	main
siis	doc_534729444726_item	2691841	et	3	main
on	doc_534729444726_item	2691842	et	4	main
säilinud	doc_534729444726_item	2691843	et	4	main
muuseumidest	doc_534729444726_item	2691849	et	3	main
arhiividest	doc_534729444726_item	2691851	et	3	main
vanadest	doc_534729444726_item	2691862	et	3	main
salmidest	doc_534729444726_item	2691865	et	3	main
esitavad	doc_534729444726_item	2691867	et	4	main
juba	doc_534729444726_item	2691871	et	3	main
töödelduid	doc_534729444726_item	2691872	et	4	main
süvendume	doc_534729444726_item	2691873	et	4	main
natuke	doc_534729444726_item	2691874	et	4	main
ajaloosse	doc_534729444726_item	2691875	et	4	main
19	doc_534729444726_item	2691876	et	2	main
sajandi	doc_534729444726_item	2691877	et	3	main
esipoolel	doc_534729444726_item	2691878	et	3	main
tuli	doc_534729444726_item	2691879	et	4	main
uudne	doc_534729444726_item	2691880	et	3	main
nähtus	doc_534729444726_item	2691881	et	4	main
rahvalauludest	doc_534729444726_item	2691882	et	3	main
nii	doc_534729444726_item	2691883	et	3	main
lätis	doc_534729444726_item	2691884	et	4	main
kui	doc_534729444726_item	2691885	et	3	main
ka	doc_534729444726_item	2691886	et	3	main
venemaal	doc_534729444726_item	2691887	et	4	main
võeti	doc_534729444726_item	2691888	et	3	main
uued	doc_534729444726_item	2691890	et	3	main
instrumendid	doc_534729444726_item	2691892	et	3	main
elavaks	doc_534729444726_item	2691896	et	4	main
ja	doc_534729444726_item	2691897	et	3	main
muuta	doc_534729444726_item	2691899	et	4	main
mis	doc_534729444726_item	2691932	et	4	main
toimuvad	doc_534729444726_item	2691933	et	4	main
meie	doc_534729444726_item	2691939	et	4	main
pealinnas	doc_534729444726_item	2691940	et	4	main
koorid	doc_534729444726_item	2691945	et	4	main
on	doc_534729444726_item	2691970	et	4	main
saateks	doc_534729444726_item	2691974	et	3	main
tuttavaid	doc_534729444726_item	2691994	et	3	main
muidugi	doc_534729444726_item	2691996	et	4	main
saab	doc_534729444726_item	2691997	et	3	main
ka	doc_534729444726_item	2691998	et	3	main
kaasa	doc_534729444726_item	2691999	et	4	main
üheskoos	doc_534729444726_item	2692010	et	3	main
samu	doc_534729444726_item	2692011	et	3	main
rahvakalendrist	doc_534729444726_item	2691926	et	3	main
spetsiaalselt	doc_534729444726_item	2691934	et	4	main
toimuvad	doc_534729444726_item	2691941	et	4	main
praegu	doc_534729444726_item	2691949	et	3	main
võib	doc_534729444726_item	2691950	et	3	main
väga	doc_534729444726_item	2691951	et	3	main
harva	doc_534729444726_item	2691952	et	4	main
kuulda	doc_534729444726_item	2691953	et	4	main
tõelist	doc_534729444726_item	2691954	et	4	main
sellepärast	doc_534729444726_item	2691956	et	3	main
et	doc_534729444726_item	2691957	et	3	main
hiljuti	doc_534729444726_item	2691962	et	4	main
setu	doc_534729444726_item	2691971	et	4	main
ja	doc_534729444726_item	2691973	et	3	main
toimuvad	doc_534729444726_item	2691982	et	4	main
sellised	doc_534729444726_item	2691983	et	4	main
kohata	doc_534729444726_item	2691989	et	4	main
vanu	doc_534729444726_item	2691991	et	4	main
sõpru	doc_534729444726_item	2691992	et	3	main
ja	doc_534729444726_item	2691995	et	3	main
teistega	doc_534729444726_item	2692007	et	4	main
keele	doc_534729444729_item	2692520	et	4	main
test	doc_534729444729_item	2692521	et	3	main
teeb	doc_534729444729_item	2692527	et	3	main
peab	doc_534729444729_item	2692536	et	4	main
üldistav	doc_534729444729_item	2692541	et	4	main
tuginema	doc_534729444729_item	2692542	et	3	main
loengus	doc_534729444729_item	2692543	et	3	main
näidetega	doc_534729444729_item	2692552	et	3	main
eestlastest	doc_534729444729_item	2692555	et	4	main
mina	doc_534729444729_item	2692557	et	4	main
olla	doc_534729444729_item	2692561	et	3	main
väiksena	doc_534729444729_item	2692571	et	4	main
nagu	doc_534729444729_item	2692574	et	3	main
vabahingeline	doc_534729444729_item	2692631	et	4	main
ja	doc_534729444729_item	2692632	et	3	main
rõõmsameelne	doc_534729444729_item	2692633	et	3	main
inimene	doc_534729444729_item	2692634	et	3	main
häbenematult	doc_534729444729_item	2692635	et	4	main
laulab	doc_534729444729_item	2692636	et	3	main
öelda	doc_534729444729_item	2692640	et	4	main
võib	doc_534729444729_item	2692647	et	3	main
olla	doc_534729444729_item	2692648	et	3	main
et	doc_534729444729_item	2692655	et	3	main
elu	doc_534729444729_item	2692661	et	4	main
essee	doc_534729444729_item	2692524	et	4	main
olema	doc_534729444729_item	2692537	et	4	main
lugemistekstis	doc_534729444729_item	2692545	et	3	main
mis	doc_534729444729_item	2692553	et	4	main
selles	doc_534729444729_item	2692564	et	4	main
kõik	doc_534729444729_item	2692575	et	4	main
pere	doc_534729444729_item	2692579	et	4	main
rahvas	doc_534729444729_item	2692609	et	4	main
suur	doc_534729444729_item	2692612	et	3	main
inimene	doc_534729444729_item	2692615	et	3	main
tunneb	doc_534729444729_item	2692616	et	3	main
rahulikum	doc_534729444729_item	2692618	et	4	main
ja	doc_534729444729_item	2692619	et	3	main
minu	doc_534729444729_item	2692622	et	3	main
olema	doc_534729444729_item	2692626	et	4	main
ja	doc_534729444729_item	2692627	et	3	main
ei	doc_534729444729_item	2692638	et	4	main
selles	doc_534729444729_item	2692649	et	4	main
veel	doc_534729444729_item	2692651	et	4	main
üks	doc_534729444729_item	2692652	et	3	main
põhjus	doc_534729444729_item	2692653	et	4	main
ellu	doc_534729444729_item	2692659	et	4	main
isegi	doc_534729444729_item	2692663	et	4	main
raskem	doc_534729444729_item	2692665	et	4	main
eestlaste	doc_534729444729_item	2692667	et	4	main
kõvem	doc_534729444729_item	2692714	et	4	main
ja	doc_534729444729_item	2692716	et	3	main
raskused	doc_534729444729_item	2692723	et	4	main
aega	doc_534729444729_item	2692729	et	4	main
elab	doc_534729444729_item	2692738	et	3	main
meist	doc_534729444729_item	2692741	et	3	main
pikkus	doc_534729444730_item	2692758	et	4	main
essee	doc_534729444730_item	2692762	et	4	main
ja	doc_534729444730_item	2692771	et	3	main
igal	doc_534729444730_item	2692783	et	3	main
iga	doc_534729444730_item	2692788	et	4	main
jaoks	doc_534729444730_item	2692790	et	4	main
kultuur	doc_534729444730_item	2692791	et	3	main
on	doc_534729444730_item	2692792	et	4	main
väga	doc_534729444730_item	2692793	et	3	main
on	doc_534729444730_item	2692821	et	4	main
kui	doc_534729444730_item	2692823	et	3	main
seetõttu	doc_534729444730_item	2692831	et	3	main
teavad	doc_534729444730_item	2692833	et	3	main
tuntud	doc_534729444730_item	2692840	et	4	main
pidu	doc_534729444730_item	2692843	et	4	main
keele	doc_534729444729_item	2692517	et	4	main
kui	doc_534729444729_item	2692518	et	3	main
kirjutamine	doc_534729444729_item	2692522	et	4	main
essee	doc_534729444729_item	2692535	et	4	main
ja	doc_534729444729_item	2692540	et	3	main
ja	doc_534729444729_item	2692544	et	3	main
võib	doc_534729444729_item	2692560	et	3	main
asi	doc_534729444729_item	2692562	et	4	main
on	doc_534729444729_item	2692563	et	4	main
eesti	doc_534729444729_item	2692567	et	4	main
ja	doc_534729444729_item	2692573	et	3	main
mida	doc_534729444729_item	2692577	et	4	main
nagu	doc_534729444729_item	2692611	et	3	main
end	doc_534729444729_item	2692617	et	4	main
tema	doc_534729444729_item	2692620	et	4	main
essee	doc_534729444729_item	2692515	et	4	main
eesti	doc_534729444729_item	2692516	et	4	main
teise	doc_534729444729_item	2692519	et	4	main
kirjutage	doc_534729444729_item	2692523	et	3	main
mis	doc_534729444729_item	2692526	et	4	main
sõna	doc_534729444729_item	2692534	et	4	main
analüüsiv	doc_534729444729_item	2692539	et	4	main
esitatud	doc_534729444729_item	2692546	et	4	main
on	doc_534729444729_item	2692549	et	4	main
illustreerida	doc_534729444729_item	2692551	et	3	main
teeb	doc_534729444729_item	2692554	et	3	main
laulurahva	doc_534729444729_item	2692556	et	3	main
arvan	doc_534729444729_item	2692558	et	3	main
et	doc_534729444729_item	2692559	et	3	main
kunagi	doc_534729444729_item	2692566	et	3	main
oli	doc_534729444729_item	2692569	et	3	main
hästi	doc_534729444729_item	2692570	et	3	main
olnud	doc_534729444729_item	2692572	et	4	main
väiksem	doc_534729444729_item	2692578	et	4	main
pere	doc_534729444729_item	2692613	et	4	main
iga	doc_534729444729_item	2692614	et	4	main
hing	doc_534729444729_item	2692621	et	3	main
peab	doc_534729444729_item	2692624	et	4	main
tavaliselt	doc_534729444729_item	2692629	et	4	main
teeb	doc_534729444729_item	2692630	et	3	main
kerge	doc_534729444729_item	2692646	et	4	main
sellele	doc_534729444729_item	2692654	et	4	main
laulutahtmine	doc_534729444729_item	2692657	et	3	main
üks	doc_534729444729_item	2692689	et	3	main
elu	doc_534729444729_item	2692700	et	4	main
seda	doc_534729444729_item	2692701	et	3	main
nad	doc_534729444729_item	2692702	et	3	main
rohkem	doc_534729444729_item	2692703	et	4	main
laulsid	doc_534729444729_item	2692704	et	4	main
neil	doc_534729444729_item	2692705	et	4	main
olid	doc_534729444729_item	2692706	et	4	main
hääl	doc_534729444729_item	2692715	et	3	main
muutunud	doc_534729444729_item	2692727	et	4	main
palju	doc_534729444729_item	2692728	et	4	main
ja	doc_534729444729_item	2692737	et	3	main
keele	doc_534729444730_item	2692747	et	4	main
kirjutamine	doc_534729444730_item	2692749	et	4	main
kirjutage	doc_534729444730_item	2692750	et	3	main
essee	doc_534729444730_item	2692757	et	4	main
sõna	doc_534729444730_item	2692761	et	4	main
peab	doc_534729444730_item	2692763	et	4	main
olema	doc_534729444730_item	2692764	et	4	main
loengus	doc_534729444730_item	2692770	et	3	main
lugemistekstis	doc_534729444730_item	2692772	et	3	main
soovitatav	doc_534729444730_item	2692777	et	4	main
igal	doc_534729444730_item	2692780	et	3	main
oluline	doc_534729444730_item	2692794	et	4	main
meie	doc_534729444730_item	2692829	et	4	main
kultuurisündmusi	doc_534729444730_item	2692835	et	3	main
on	doc_534729444730_item	2692838	et	4	main
jaoks	doc_534729444730_item	2692859	et	4	main
kultuuris	doc_534729444730_item	2692861	et	3	main
laul	doc_534729444730_item	2692862	et	4	main
meie	doc_534729444730_item	2692902	et	4	main
korraldati	doc_534729444730_item	2692915	et	3	main
laulufestivale	doc_534729444730_item	2692917	et	3	main
meie	doc_534729444730_item	2692922	et	4	main
laulupeod	doc_534729444730_item	2692923	et	4	main
nad	doc_534729444730_item	2692924	et	3	main
tulesid	doc_534729444730_item	2692926	et	3	main
sajandidel	doc_534729444730_item	2692935	et	4	main
meie	doc_534729444730_item	2692947	et	4	main
on	doc_534729444730_item	2692949	et	4	main
eesti	doc_534729444730_item	2692956	et	4	main
euroopa	doc_534729444730_item	2692958	et	4	main
ja	doc_534729444730_item	2692959	et	3	main
venemaa	doc_534729444730_item	2692960	et	4	main
laulust	doc_534729444730_item	2692961	et	4	main
sellepärast	doc_534729444730_item	2692962	et	3	main
me	doc_534729444730_item	2692965	et	4	main
väga	doc_534729444730_item	2692967	et	3	main
mulle	doc_534729444730_item	2692982	et	4	main
mõnikord	doc_534729444730_item	2692983	et	3	main
ise	doc_534729444730_item	2692984	et	4	main
meeldib	doc_534729444730_item	2692985	et	3	main
teemal	doc_534729444729_item	2692525	et	3	main
eestlastest	doc_534729444729_item	2692528	et	4	main
laulurahva	doc_534729444729_item	2692529	et	3	main
essee	doc_534729444729_item	2692530	et	4	main
pikkus	doc_534729444729_item	2692531	et	4	main
300	doc_534729444729_item	2692532	et	2	main
350	doc_534729444729_item	2692533	et	2	main
arutlev	doc_534729444729_item	2692538	et	4	main
faktidele	doc_534729444729_item	2692547	et	3	main
väiteid	doc_534729444729_item	2692548	et	4	main
soovitatav	doc_534729444729_item	2692550	et	4	main
et	doc_534729444729_item	2692565	et	3	main
rahvas	doc_534729444729_item	2692568	et	4	main
teavad	doc_534729444729_item	2692576	et	3	main
seda	doc_534729444729_item	2692580	et	3	main
lähedam	doc_534729444729_item	2692581	et	4	main
on	doc_534729444729_item	2692582	et	4	main
pereliikmed	doc_534729444729_item	2692583	et	3	main
teine	doc_534729444729_item	2692584	et	3	main
teisele	doc_534729444729_item	2692585	et	4	main
kui	doc_534729444729_item	2692586	et	3	main
inimesed	doc_534729444729_item	2692587	et	3	main
teavad	doc_534729444729_item	2692588	et	3	main
teine	doc_534729444729_item	2692589	et	3	main
teist	doc_534729444729_item	2692590	et	4	main
hästi	doc_534729444729_item	2692591	et	3	main
siis	doc_534729444729_item	2692592	et	3	main
pole	doc_534729444729_item	2692593	et	3	main
neil	doc_534729444729_item	2692594	et	4	main
mõttet	doc_534729444729_item	2692595	et	4	main
iseend	doc_534729444729_item	2692596	et	3	main
peita	doc_534729444729_item	2692597	et	3	main
nad	doc_534729444729_item	2692598	et	3	main
võivad	doc_534729444729_item	2692599	et	4	main
teha	doc_534729444729_item	2692600	et	3	main
kõike	doc_534729444729_item	2692601	et	4	main
mida	doc_534729444729_item	2692602	et	4	main
tahavad	doc_534729444729_item	2692603	et	3	main
ja	doc_534729444729_item	2692604	et	3	main
mitte	doc_534729444729_item	2692605	et	3	main
mõelda	doc_534729444729_item	2692606	et	4	main
piiridestest	doc_534729444729_item	2692607	et	4	main
kui	doc_534729444729_item	2692608	et	3	main
elab	doc_534729444729_item	2692610	et	3	main
arust	doc_534729444729_item	2692623	et	4	main
keegi	doc_534729444729_item	2692637	et	4	main
et	doc_534729444729_item	2692641	et	3	main
rahvase	doc_534729444729_item	2692643	et	4	main
on	doc_534729444729_item	2692645	et	4	main
on	doc_534729444729_item	2692650	et	4	main
eestlaste	doc_534729444729_item	2692656	et	4	main
vanalajal	doc_534729444729_item	2692660	et	4	main
teised	doc_534729444729_item	2692694	et	4	main
võtsit	doc_534729444729_item	2692696	et	4	main
kõik	doc_534729444729_item	2692707	et	4	main
probleemid	doc_534729444729_item	2692708	et	3	main
ühined	doc_534729444729_item	2692709	et	3	main
mida	doc_534729444729_item	2692710	et	4	main
probleem	doc_534729444729_item	2692712	et	3	main
et	doc_534729444729_item	2692718	et	3	main
hakkama	doc_534729444729_item	2692721	et	3	main
praegu	doc_534729444729_item	2692724	et	3	main
läks	doc_534729444729_item	2692730	et	3	main
mööda	doc_534729444729_item	2692731	et	4	main
aga	doc_534729444729_item	2692732	et	3	main
eestlaste	doc_534729444729_item	2692733	et	4	main
laulutahtmine	doc_534729444729_item	2692734	et	3	main
jäi	doc_534729444729_item	2692735	et	3	main
hinges	doc_534729444729_item	2692739	et	4	main
test	doc_534729444730_item	2692748	et	3	main
mis	doc_534729444730_item	2692753	et	4	main
teeb	doc_534729444730_item	2692754	et	3	main
laulurahva	doc_534729444730_item	2692756	et	3	main
arutlev	doc_534729444730_item	2692765	et	4	main
riigil	doc_534729444730_item	2692781	et	3	main
on	doc_534729444730_item	2692785	et	4	main
kultuur	doc_534729444730_item	2692787	et	3	main
asi	doc_534729444730_item	2692795	et	4	main
kultuur	doc_534729444730_item	2692824	et	3	main
ajalugu	doc_534729444730_item	2692830	et	4	main
eestlased	doc_534729444730_item	2692832	et	3	main
üks	doc_534729444730_item	2692836	et	3	main
neist	doc_534729444730_item	2692837	et	4	main
väga	doc_534729444730_item	2692839	et	3	main
see	doc_534729444730_item	2692842	et	3	main
on	doc_534729444730_item	2692844	et	4	main
väga	doc_534729444730_item	2692845	et	3	main
tähtis	doc_534729444730_item	2692846	et	4	main
eesti	doc_534729444730_item	2692847	et	4	main
laul	doc_534729444730_item	2692855	et	4	main
on	doc_534729444730_item	2692856	et	4	main
kultuuri	doc_534729444730_item	2692858	et	4	main
võtab	doc_534729444730_item	2692863	et	3	main
laulupidude	doc_534729444730_item	2692867	et	4	main
ilusam	doc_534729444730_item	2692912	et	4	main
ja	doc_534729444730_item	2692913	et	3	main
on	doc_534729444730_item	2692919	et	4	main
väga	doc_534729444730_item	2692920	et	3	main
tuntud	doc_534729444730_item	2692921	et	4	main
ka	doc_534729444730_item	2692925	et	3	main
eestisse	doc_534729444730_item	2692927	et	4	main
osalevad	doc_534729444730_item	2692937	et	4	main
inimesi	doc_534729444730_item	2692940	et	4	main
on	doc_534729444730_item	2692943	et	4	main
väga	doc_534729444730_item	2692944	et	3	main
populaarne	doc_534729444730_item	2692945	et	3	main
meelelahutus	doc_534729444730_item	2692946	et	4	main
palju	doc_534729444730_item	2692954	et	4	main
laul	doc_534729444730_item	2692957	et	4	main
ja	doc_534729444730_item	2692970	et	3	main
euroopaga	doc_534729444730_item	2692971	et	3	main
ma	doc_534729444730_item	2692972	et	3	main
mõtlen	doc_534729444730_item	2692973	et	3	main
et	doc_534729444730_item	2692974	et	3	main
see	doc_534729444730_item	2692975	et	3	main
on	doc_534729444730_item	2692976	et	4	main
vaba	doc_534729444729_item	2692625	et	4	main
mida	doc_534729444729_item	2692628	et	4	main
saa	doc_534729444729_item	2692639	et	4	main
eesti	doc_534729444729_item	2692642	et	4	main
ajalugu	doc_534729444729_item	2692644	et	4	main
jääb	doc_534729444729_item	2692658	et	3	main
palju	doc_534729444729_item	2692664	et	4	main
aga	doc_534729444729_item	2692666	et	3	main
elujõud	doc_534729444729_item	2692668	et	4	main
oli	doc_534729444729_item	2692669	et	3	main
selles	doc_534729444729_item	2692670	et	4	main
et	doc_534729444729_item	2692671	et	3	main
nad	doc_534729444729_item	2692672	et	3	main
tegid	doc_534729444729_item	2692673	et	4	main
kõike	doc_534729444729_item	2692674	et	4	main
koos	doc_534729444729_item	2692675	et	4	main
kui	doc_534729444729_item	2692676	et	3	main
on	doc_534729444729_item	2692677	et	4	main
pidu	doc_534729444729_item	2692678	et	4	main
pidutsevad	doc_534729444729_item	2692679	et	4	main
kõik	doc_534729444729_item	2692680	et	4	main
kui	doc_534729444729_item	2692681	et	3	main
on	doc_534729444729_item	2692682	et	4	main
tööaeg	doc_534729444729_item	2692683	et	3	main
töötavad	doc_534729444729_item	2692684	et	4	main
kõik	doc_534729444729_item	2692685	et	4	main
vaatamata	doc_534729444729_item	2692686	et	4	main
vanusele	doc_534729444729_item	2692687	et	4	main
kui	doc_534729444729_item	2692688	et	3	main
oli	doc_534729444729_item	2692662	et	3	main
inimene	doc_534729444729_item	2692690	et	3	main
siis	doc_534729444729_item	2692693	et	3	main
ka	doc_534729444729_item	2692695	et	3	main
edasi	doc_534729444729_item	2692697	et	3	main
suurem	doc_534729444729_item	2692711	et	4	main
seda	doc_534729444729_item	2692713	et	3	main
hakkas	doc_534729444729_item	2692691	et	3	main
laulma	doc_534729444729_item	2692692	et	3	main
mida	doc_534729444729_item	2692698	et	4	main
raskem	doc_534729444729_item	2692699	et	4	main
kindlus	doc_534729444729_item	2692717	et	4	main
kõik	doc_534729444729_item	2692719	et	4	main
saavad	doc_534729444729_item	2692720	et	4	main
elu	doc_534729444729_item	2692722	et	4	main
on	doc_534729444729_item	2692725	et	4	main
kõik	doc_534729444729_item	2692726	et	4	main
igaühel	doc_534729444729_item	2692740	et	3	main
essee	doc_534729444730_item	2692742	et	4	main
keele	doc_534729444730_item	2692744	et	4	main
kui	doc_534729444730_item	2692745	et	3	main
teise	doc_534729444730_item	2692746	et	4	main
teemal	doc_534729444730_item	2692752	et	3	main
eestlastest	doc_534729444730_item	2692755	et	4	main
350	doc_534729444730_item	2692760	et	2	main
analüüsiv	doc_534729444730_item	2692766	et	4	main
ja	doc_534729444730_item	2692767	et	3	main
üldistav	doc_534729444730_item	2692768	et	4	main
tuginema	doc_534729444730_item	2692769	et	3	main
esitatud	doc_534729444730_item	2692773	et	4	main
faktidele	doc_534729444730_item	2692774	et	3	main
väiteid	doc_534729444730_item	2692775	et	4	main
näidetega	doc_534729444730_item	2692779	et	3	main
rahval	doc_534729444730_item	2692784	et	3	main
rahvade	doc_534729444730_item	2692789	et	4	main
ellu	doc_534729444729_item	2692736	et	4	main
eesti	doc_534729444730_item	2692743	et	4	main
essee	doc_534729444730_item	2692751	et	4	main
300	doc_534729444730_item	2692759	et	2	main
on	doc_534729444730_item	2692776	et	4	main
illustreerida	doc_534729444730_item	2692778	et	3	main
ja	doc_534729444730_item	2692782	et	3	main
oma	doc_534729444730_item	2692786	et	4	main
ja	doc_534729444730_item	2692796	et	3	main
kultuuri	doc_534729444730_item	2692797	et	4	main
kaudu	doc_534729444730_item	2692798	et	3	main
rahvas	doc_534729444730_item	2692799	et	4	main
proovib	doc_534729444730_item	2692800	et	3	main
ja	doc_534729444730_item	2692801	et	3	main
püüab	doc_534729444730_item	2692802	et	3	main
näidata	doc_534729444730_item	2692803	et	4	main
ise	doc_534729444730_item	2692804	et	4	main
ennast	doc_534729444730_item	2692805	et	4	main
eestis	doc_534729444730_item	2692806	et	3	main
on	doc_534729444730_item	2692807	et	4	main
samasugune	doc_534729444730_item	2692808	et	3	main
olukord	doc_534729444730_item	2692809	et	3	main
mis	doc_534729444730_item	2692810	et	4	main
on	doc_534729444730_item	2692811	et	4	main
teistes	doc_534729444730_item	2692812	et	4	main
riikides	doc_534729444730_item	2692813	et	3	main
ma	doc_534729444730_item	2692814	et	3	main
mõtlen	doc_534729444730_item	2692815	et	3	main
et	doc_534729444730_item	2692816	et	3	main
eesti	doc_534729444730_item	2692817	et	4	main
rahva	doc_534729444730_item	2692818	et	3	main
jaoks	doc_534729444730_item	2692819	et	4	main
kultuur	doc_534729444730_item	2692820	et	3	main
elu	doc_534729444730_item	2692828	et	4	main
laulupidu	doc_534729444730_item	2692841	et	4	main
elus	doc_534729444730_item	2692848	et	4	main
niisugune	doc_534729444730_item	2692849	et	3	main
sündmus	doc_534729444730_item	2692850	et	3	main
näitab	doc_534729444730_item	2692851	et	3	main
kui	doc_534729444730_item	2692853	et	3	main
teisega	doc_534729444730_item	2692872	et	4	main
nad	doc_534729444730_item	2692873	et	3	main
kuidagi	doc_534729444730_item	2692874	et	3	main
jooksul	doc_534729444730_item	2692904	et	4	main
põnevam	doc_534729444730_item	2692914	et	4	main
ajaloost	doc_534729444730_item	2692928	et	4	main
19	doc_534729444730_item	2692932	et	2	main
ja	doc_534729444730_item	2692933	et	3	main
väga	doc_534729444730_item	2692938	et	3	main
praegu	doc_534729444730_item	2692941	et	3	main
ka	doc_534729444730_item	2692950	et	3	main
teised	doc_534729444730_item	2692951	et	4	main
kultuurid	doc_534729444730_item	2692952	et	3	main
väga	doc_534729444730_item	2692953	et	3	main
võttis	doc_534729444730_item	2692955	et	3	main
ajaloo	doc_534729444730_item	2692963	et	4	main
seotud	doc_534729444730_item	2692968	et	4	main
rohkem	doc_534729444730_item	2692822	et	4	main
see	doc_534729444730_item	2692825	et	3	main
on	doc_534729444730_item	2692826	et	4	main
meie	doc_534729444730_item	2692827	et	4	main
erinevaid	doc_534729444730_item	2692834	et	4	main
meile	doc_534729444730_item	2692852	et	4	main
eesti	doc_534729444730_item	2692857	et	4	main
eesti	doc_534729444730_item	2692860	et	4	main
palju	doc_534729444730_item	2692865	et	4	main
ühinevad	doc_534729444730_item	2692875	et	4	main
üldse	doc_534729444730_item	2692876	et	3	main
laulmine	doc_534729444730_item	2692877	et	4	main
on	doc_534729444730_item	2692878	et	4	main
väga	doc_534729444730_item	2692879	et	3	main
vana	doc_534729444730_item	2692880	et	4	main
asi	doc_534729444730_item	2692881	et	4	main
eestlaste	doc_534729444730_item	2692882	et	4	main
jaoks	doc_534729444730_item	2692883	et	4	main
vanal	doc_534729444730_item	2692884	et	3	main
ajal	doc_534729444730_item	2692885	et	4	main
inimesed	doc_534729444730_item	2692886	et	3	main
võiksid	doc_534729444730_item	2692887	et	4	main
laulda	doc_534729444730_item	2692888	et	4	main
kui	doc_534729444730_item	2692889	et	3	main
nad	doc_534729444730_item	2692890	et	3	main
näiteks	doc_534729444730_item	2692891	et	4	main
töötasid	doc_534729444730_item	2692892	et	4	main
või	doc_534729444730_item	2692893	et	4	main
laulsid	doc_534729444730_item	2692894	et	4	main
nii	doc_534729444730_item	2692895	et	3	main
sama	doc_534729444730_item	2692896	et	4	main
meie	doc_534729444730_item	2692897	et	4	main
laulmine	doc_534729444730_item	2692898	et	4	main
ja	doc_534729444730_item	2692899	et	3	main
laul	doc_534729444730_item	2692900	et	4	main
arenes	doc_534729444730_item	2692901	et	3	main
tähtis	doc_534729444730_item	2692854	et	4	main
väga	doc_534729444730_item	2692864	et	3	main
ruumi	doc_534729444730_item	2692866	et	4	main
kaudu	doc_534729444730_item	2692868	et	3	main
inimesed	doc_534729444730_item	2692869	et	3	main
suhtlevad	doc_534729444730_item	2692870	et	4	main
teine	doc_534729444730_item	2692871	et	3	main
eestlasid	doc_534729444730_item	2692905	et	4	main
mõtlema	doc_534729444730_item	2692907	et	3	main
oma	doc_534729444730_item	2692910	et	4	main
tänapäeval	doc_534729444730_item	2692918	et	3	main
laulupeos	doc_534729444730_item	2692936	et	4	main
laulukultuuris	doc_534729444730_item	2692948	et	3	main
jooksul	doc_534729444730_item	2692964	et	4	main
olime	doc_534729444730_item	2692966	et	3	main
pluss	doc_534729444730_item	2692978	et	3	main
sellest	doc_534729444730_item	2693022	et	4	main
palju	doc_534729444730_item	2693024	et	4	main
essee	doc_534729444732_item	2693264	et	4	main
eesti	doc_534729444732_item	2693265	et	4	main
essee	doc_534729444732_item	2693273	et	4	main
teemal	doc_534729444732_item	2693274	et	3	main
sõna	doc_534729444732_item	2693283	et	4	main
surevad	doc_534729444732_item	2693322	et	4	main
sõdurid	doc_534729444732_item	2693323	et	3	main
ka	doc_534729444732_item	2693325	et	3	main
sünnivad	doc_534729444732_item	2693326	et	3	main
lapsed	doc_534729444732_item	2693327	et	3	main
oli	doc_534729444732_item	2693329	et	3	main
vanal	doc_534729444732_item	2693330	et	3	main
ajal	doc_534729444732_item	2693331	et	4	main
samad	doc_534729444732_item	2693332	et	3	main
vaheldumisi	doc_534729444732_item	2693354	et	4	main
eeslaulja	doc_534729444732_item	2693355	et	4	main
hakkas	doc_534729444732_item	2693356	et	3	main
naiskoorit	doc_534729444732_item	2693402	et	4	main
1994	doc_534729444732_item	2693406	et	2	main
tol	doc_534729444732_item	2693412	et	3	main
eesti	doc_534729444732_item	2693415	et	4	main
ajaloo	doc_534729444730_item	2692903	et	4	main
hakkasid	doc_534729444730_item	2692906	et	4	main
kuidas	doc_534729444730_item	2692908	et	3	main
teha	doc_534729444730_item	2692909	et	3	main
laulukultuuri	doc_534729444730_item	2692911	et	4	main
erinevaid	doc_534729444730_item	2692916	et	4	main
praegu	doc_534729444730_item	2692929	et	3	main
ja	doc_534729444730_item	2692930	et	3	main
ka	doc_534729444730_item	2692931	et	3	main
20	doc_534729444730_item	2692934	et	2	main
palju	doc_534729444730_item	2692939	et	4	main
see	doc_534729444730_item	2692942	et	3	main
ainult	doc_534729444730_item	2692977	et	4	main
kultuuri	doc_534729444730_item	2692980	et	4	main
asi	doc_534729444730_item	2692991	et	4	main
ma	doc_534729444730_item	2692992	et	3	main
tihti	doc_534729444730_item	2692993	et	3	main
külastasin	doc_534729444730_item	2692994	et	3	main
laulupidusid	doc_534729444730_item	2692995	et	4	main
mulle	doc_534729444730_item	2692997	et	4	main
väga	doc_534729444730_item	2692998	et	3	main
meeldis	doc_534729444730_item	2692999	et	3	main
arvan	doc_534729444730_item	2693000	et	3	main
et	doc_534729444730_item	2693001	et	3	main
teistele	doc_534729444730_item	2693002	et	4	main
inimestele	doc_534729444730_item	2693003	et	3	main
ka	doc_534729444730_item	2693004	et	3	main
meeldis	doc_534729444730_item	2693005	et	3	main
ma	doc_534729444730_item	2693006	et	3	main
võin	doc_534729444730_item	2693007	et	3	main
ainult	doc_534729444730_item	2693008	et	4	main
loota	doc_534729444730_item	2693009	et	4	main
et	doc_534729444730_item	2693010	et	3	main
meie	doc_534729444730_item	2693011	et	4	main
laulukultuur	doc_534729444730_item	2693012	et	3	main
hakkab	doc_534729444730_item	2693013	et	3	main
edasi	doc_534729444730_item	2693014	et	3	main
arenema	doc_534729444730_item	2693015	et	3	main
ja	doc_534729444730_item	2693016	et	3	main
me	doc_534729444730_item	2693017	et	4	main
tavalised	doc_534729444730_item	2693018	et	4	main
inimesed	doc_534729444730_item	2693019	et	3	main
võime	doc_534729444730_item	2693020	et	4	main
venemaa	doc_534729444730_item	2692969	et	4	main
meie	doc_534729444730_item	2692979	et	4	main
jaoks	doc_534729444730_item	2692981	et	4	main
ja	doc_534729444730_item	2692996	et	3	main
saada	doc_534729444730_item	2693021	et	4	main
väga	doc_534729444730_item	2693023	et	3	main
häid	doc_534729444730_item	2693025	et	3	main
asju	doc_534729444730_item	2693026	et	3	main
laulma	doc_534729444730_item	2692986	et	3	main
see	doc_534729444730_item	2692987	et	3	main
on	doc_534729444730_item	2692988	et	4	main
väga	doc_534729444730_item	2692989	et	3	main
tore	doc_534729444730_item	2692990	et	3	main
keele	doc_534729444732_item	2693269	et	4	main
test	doc_534729444732_item	2693270	et	3	main
kirjutamine	doc_534729444732_item	2693271	et	4	main
kirjutage	doc_534729444732_item	2693272	et	3	main
olema	doc_534729444732_item	2693286	et	4	main
ja	doc_534729444732_item	2693289	et	3	main
laulaga	doc_534729444732_item	2693321	et	4	main
on	doc_534729444732_item	2693334	et	4	main
laul	doc_534729444732_item	2693337	et	4	main
omandab	doc_534729444732_item	2693338	et	3	main
suur	doc_534729444732_item	2693339	et	3	main
ja	doc_534729444732_item	2693340	et	3	main
huvitav	doc_534729444732_item	2693341	et	4	main
regivärsilised	doc_534729444732_item	2693347	et	4	main
laulud	doc_534729444732_item	2693348	et	3	main
eeslaulja	doc_534729444732_item	2693351	et	4	main
ja	doc_534729444732_item	2693352	et	3	main
ka	doc_534729444732_item	2693362	et	3	main
muusikat	doc_534729444732_item	2693368	et	3	main
pärast	doc_534729444732_item	2693369	et	4	main
vanemuise	doc_534729444732_item	2693390	et	4	main
olla	doc_534729444732_item	2693395	et	3	main
nüüd	doc_534729444732_item	2693398	et	4	main
lastekoorid	doc_534729444732_item	2693403	et	3	main
aastal	doc_534729444732_item	2693407	et	3	main
laulupeo	doc_534729444732_item	2693409	et	4	main
suvel	doc_534729444732_item	2693413	et	3	main
ja	doc_534729444732_item	2693421	et	3	main
massivne	doc_534729444732_item	2693428	et	4	main
on	doc_534729444732_item	2693431	et	4	main
massiharrastuseks	doc_534729444732_item	2693435	et	3	main
et	doc_534729444732_item	2693439	et	3	main
eestlase	doc_534729444732_item	2693441	et	3	main
kohe	doc_534729444732_item	2693448	et	4	main
mis	doc_534729444732_item	2693462	et	4	main
nendele	doc_534729444732_item	2693476	et	4	main
kui	doc_534729444733_item	2693482	et	3	main
kirjutamine	doc_534729444733_item	2693486	et	4	main
keele	doc_534729444732_item	2693266	et	4	main
teeb	doc_534729444732_item	2693276	et	3	main
essee	doc_534729444732_item	2693284	et	4	main
asjad	doc_534729444732_item	2693333	et	3	main
eesti	doc_534729444732_item	2693336	et	4	main
on	doc_534729444732_item	2693346	et	4	main
koor	doc_534729444732_item	2693357	et	4	main
aga	doc_534729444732_item	2693358	et	3	main
kordab	doc_534729444732_item	2693359	et	3	main
ütelda	doc_534729444732_item	2693363	et	4	main
toimus	doc_534729444732_item	2693380	et	3	main
laulupidu	doc_534729444732_item	2693383	et	4	main
korraldamise	doc_534729444732_item	2693385	et	4	main
ja	doc_534729444732_item	2693387	et	3	main
seltsist	doc_534729444732_item	2693391	et	4	main
ja	doc_534729444732_item	2693392	et	3	main
see	doc_534729444732_item	2693393	et	3	main
hakkas	doc_534729444732_item	2693394	et	3	main
teise	doc_534729444732_item	2693268	et	4	main
eestlastest	doc_534729444732_item	2693277	et	4	main
laulurahva	doc_534729444732_item	2693278	et	3	main
essee	doc_534729444732_item	2693279	et	4	main
pikkus	doc_534729444732_item	2693280	et	4	main
300	doc_534729444732_item	2693281	et	2	main
350	doc_534729444732_item	2693282	et	2	main
peab	doc_534729444732_item	2693285	et	4	main
analüüsiv	doc_534729444732_item	2693288	et	4	main
üldistav	doc_534729444732_item	2693290	et	4	main
tuginema	doc_534729444732_item	2693291	et	3	main
loengus	doc_534729444732_item	2693292	et	3	main
ja	doc_534729444732_item	2693293	et	3	main
täna	doc_534729444732_item	2693335	et	4	main
kõige	doc_534729444732_item	2693343	et	4	main
vanemad	doc_534729444732_item	2693344	et	4	main
laulud	doc_534729444732_item	2693345	et	3	main
esitavad	doc_534729444732_item	2693350	et	4	main
on	doc_534729444732_item	2693360	et	4	main
vaja	doc_534729444732_item	2693361	et	4	main
nendel	doc_534729444732_item	2693365	et	4	main
pole	doc_534729444732_item	2693367	et	3	main
hakkasid	doc_534729444732_item	2693370	et	4	main
populaarselt	doc_534729444732_item	2693371	et	4	main
olla	doc_534729444732_item	2693372	et	3	main
kirikus	doc_534729444732_item	2693373	et	3	main
laulmine	doc_534729444732_item	2693374	et	4	main
18	doc_534729444732_item	2693375	et	2	main
sajandil	doc_534729444732_item	2693376	et	3	main
1896	doc_534729444732_item	2693377	et	2	main
aastal	doc_534729444732_item	2693378	et	3	main
tartus	doc_534729444732_item	2693379	et	3	main
ülemaaline	doc_534729444732_item	2693382	et	4	main
mille	doc_534729444732_item	2693384	et	3	main
idee	doc_534729444732_item	2693386	et	4	main
teostus	doc_534729444732_item	2693388	et	4	main
hea	doc_534729444732_item	2693396	et	4	main
osalevad	doc_534729444732_item	2693399	et	4	main
sellel	doc_534729444732_item	2693400	et	4	main
peol	doc_534729444732_item	2693401	et	4	main
sünnipäev	doc_534729444732_item	2693411	et	3	main
kui	doc_534729444732_item	2693267	et	3	main
mis	doc_534729444732_item	2693275	et	4	main
arutlev	doc_534729444732_item	2693287	et	4	main
lugemistekstis	doc_534729444732_item	2693294	et	3	main
esitatud	doc_534729444732_item	2693295	et	4	main
faktidele	doc_534729444732_item	2693296	et	3	main
väiteid	doc_534729444732_item	2693297	et	4	main
on	doc_534729444732_item	2693298	et	4	main
soovitatav	doc_534729444732_item	2693299	et	4	main
illustreerida	doc_534729444732_item	2693300	et	3	main
näidetega	doc_534729444732_item	2693301	et	3	main
mis	doc_534729444732_item	2693302	et	4	main
teeb	doc_534729444732_item	2693303	et	3	main
eestlastest	doc_534729444732_item	2693304	et	4	main
laulurahva	doc_534729444732_item	2693305	et	3	main
laulmine	doc_534729444732_item	2693306	et	4	main
oli	doc_534729444732_item	2693307	et	3	main
koguaeg	doc_534729444732_item	2693308	et	3	main
eesti	doc_534729444732_item	2693309	et	4	main
vanem	doc_534729444732_item	2693310	et	4	main
traditsioon	doc_534729444732_item	2693311	et	3	main
mis	doc_534729444732_item	2693312	et	4	main
aitas	doc_534729444732_item	2693313	et	3	main
elada	doc_534729444732_item	2693314	et	3	main
ja	doc_534729444732_item	2693315	et	3	main
tõi	doc_534729444732_item	2693316	et	3	main
õnn	doc_534729444732_item	2693317	et	3	main
ja	doc_534729444732_item	2693318	et	3	main
rõõm	doc_534729444732_item	2693319	et	3	main
koju	doc_534729444732_item	2693320	et	3	main
laulaga	doc_534729444732_item	2693324	et	4	main
nii	doc_534729444732_item	2693328	et	3	main
ajalugu	doc_534729444732_item	2693342	et	4	main
neid	doc_534729444732_item	2693349	et	4	main
koor	doc_534729444732_item	2693353	et	4	main
et	doc_534729444732_item	2693364	et	3	main
lauladel	doc_534729444732_item	2693366	et	3	main
esimene	doc_534729444732_item	2693381	et	3	main
tuli	doc_534729444732_item	2693389	et	4	main
traditsiooniks	doc_534729444732_item	2693397	et	3	main
ja	doc_534729444732_item	2693404	et	3	main
korraldati	doc_534729444732_item	2693414	et	3	main
üldlaulupidu	doc_534729444732_item	2693416	et	4	main
kahekümne	doc_534729444732_item	2693417	et	4	main
teist	doc_534729444732_item	2693418	et	4	main
korda	doc_534729444732_item	2693419	et	4	main
tartus	doc_534729444732_item	2693420	et	3	main
samal	doc_534729444732_item	2693423	et	3	main
rahvapeo	doc_534729444732_item	2693429	et	4	main
koorilaul	doc_534729444732_item	2693430	et	4	main
hulgas	doc_534729444732_item	2693433	et	4	main
on	doc_534729444732_item	2693437	et	4	main
rahvastele	doc_534729444732_item	2693461	et	4	main
koos	doc_534729444732_item	2693467	et	4	main
koguaeg	doc_534729444732_item	2693468	et	3	main
ja	doc_534729444732_item	2693469	et	3	main
laul	doc_534729444732_item	2693470	et	4	main
koos	doc_534729444732_item	2693477	et	4	main
olla	doc_534729444732_item	2693478	et	3	main
keele	doc_534729444733_item	2693484	et	4	main
sõna	doc_534729444733_item	2693498	et	4	main
analüüsiv	doc_534729444733_item	2693503	et	4	main
ja	doc_534729444733_item	2693504	et	3	main
lugemistekstis	doc_534729444733_item	2693509	et	3	main
arvavad	doc_534729444733_item	2693519	et	4	main
et	doc_534729444733_item	2693520	et	3	main
meil	doc_534729444733_item	2693523	et	4	main
aitab	doc_534729444733_item	2693526	et	3	main
ajal	doc_534729444733_item	2693528	et	4	main
kõikede	doc_534729444733_item	2693529	et	4	main
probleemidega	doc_534729444733_item	2693530	et	3	main
hästi	doc_534729444733_item	2693531	et	3	main
näitusi	doc_534729444733_item	2693549	et	3	main
laulud	doc_534729444733_item	2693553	et	3	main
mis	doc_534729444733_item	2693571	et	4	main
teeb	doc_534729444733_item	2693572	et	3	main
laulmine	doc_534729444733_item	2693580	et	4	main
unustada	doc_534729444733_item	2693591	et	3	main
on	doc_534729444733_item	2693594	et	4	main
kes	doc_534729444733_item	2693630	et	4	main
miks	doc_534729444733_item	2693635	et	4	main
oli	doc_534729444733_item	2693639	et	3	main
oli	doc_534729444733_item	2693645	et	3	main
laulda	doc_534729444733_item	2693647	et	4	main
oma	doc_534729444733_item	2693653	et	4	main
või	doc_534729444733_item	2693657	et	4	main
vähem	doc_534729444733_item	2693671	et	4	main
üldse	doc_534729444733_item	2693702	et	3	main
öelda	doc_534729444733_item	2693704	et	4	main
et	doc_534729444733_item	2693705	et	3	main
ja	doc_534729444733_item	2693708	et	3	main
muusikantid	doc_534729444733_item	2693710	et	4	main
vastust	doc_534729444733_item	2693719	et	4	main
anda	doc_534729444733_item	2693720	et	3	main
tundub	doc_534729444733_item	2693724	et	3	main
on	doc_534729444733_item	2693727	et	4	main
raske	doc_534729444733_item	2693729	et	4	main
ei	doc_534729444733_item	2693732	et	4	main
kõik	doc_534729444733_item	2693739	et	4	main
see	doc_534729444733_item	2693750	et	3	main
laul	doc_534729444733_item	2693752	et	4	main
aitab	doc_534729444733_item	2693753	et	3	main
meil	doc_534729444733_item	2693754	et	4	main
elada	doc_534729444733_item	2693755	et	3	main
nõustage	doc_534729444733_item	2693756	et	3	main
et	doc_534729444733_item	2693757	et	3	main
vanal	doc_534729444733_item	2693758	et	3	main
eestlastel	doc_534729444733_item	2693762	et	4	main
meestekoorid	doc_534729444732_item	2693405	et	3	main
oli	doc_534729444732_item	2693408	et	3	main
125	doc_534729444732_item	2693410	et	2	main
see	doc_534729444732_item	2693425	et	3	main
oli	doc_534729444732_item	2693426	et	3	main
eestlaste	doc_534729444732_item	2693432	et	4	main
loomulik	doc_534729444732_item	2693438	et	3	main
tavalise	doc_534729444732_item	2693440	et	4	main
jaoks	doc_534729444732_item	2693442	et	4	main
seostub	doc_534729444732_item	2693443	et	3	main
sõnadega	doc_534729444732_item	2693444	et	3	main
rahvas	doc_534729444732_item	2693445	et	4	main
ja	doc_534729444732_item	2693446	et	3	main
laulupidu	doc_534729444732_item	2693450	et	4	main
väike	doc_534729444732_item	2693464	et	4	main
aga	doc_534729444732_item	2693465	et	3	main
asi	doc_534729444732_item	2693473	et	4	main
eesti	doc_534729444733_item	2693480	et	4	main
keele	doc_534729444733_item	2693481	et	4	main
essee	doc_534729444733_item	2693488	et	4	main
eestlastest	doc_534729444733_item	2693492	et	4	main
laulurahva	doc_534729444733_item	2693493	et	3	main
essee	doc_534729444733_item	2693494	et	4	main
pikkus	doc_534729444733_item	2693495	et	4	main
300	doc_534729444733_item	2693496	et	2	main
350	doc_534729444733_item	2693497	et	2	main
arutlev	doc_534729444733_item	2693502	et	4	main
ja	doc_534729444733_item	2693508	et	3	main
faktidele	doc_534729444733_item	2693511	et	3	main
on	doc_534729444733_item	2693513	et	4	main
laul	doc_534729444733_item	2693521	et	4	main
või	doc_534729444733_item	2693539	et	4	main
et	doc_534729444733_item	2693545	et	3	main
mis	doc_534729444733_item	2693550	et	4	main
muusika	doc_534729444733_item	2693555	et	4	main
et	doc_534729444733_item	2693562	et	3	main
kõik	doc_534729444733_item	2693563	et	4	main
eestlastest	doc_534729444733_item	2693573	et	4	main
tundub	doc_534729444733_item	2693574	et	3	main
et	doc_534729444733_item	2693575	et	3	main
oleks	doc_534729444733_item	2693576	et	3	main
õige	doc_534729444733_item	2693577	et	4	main
on	doc_534729444733_item	2693581	et	4	main
on	doc_534729444733_item	2693585	et	4	main
suurepärane	doc_534729444733_item	2693586	et	4	main
väljendusvahend	doc_534729444733_item	2693587	et	3	main
aga	doc_534729444733_item	2693588	et	3	main
ei	doc_534729444733_item	2693589	et	4	main
tegevus	doc_534729444733_item	2693596	et	4	main
laulutraditsioonist	doc_534729444733_item	2693624	et	3	main
olulisemad	doc_534729444733_item	2693628	et	4	main
küsimused	doc_534729444733_item	2693629	et	4	main
laulis	doc_534729444733_item	2693636	et	4	main
hea	doc_534729444733_item	2693651	et	4	main
ära	doc_534729444733_item	2693655	et	4	main
meestel	doc_534729444733_item	2693669	et	4	main
laulda	doc_534729444733_item	2693674	et	4	main
tänapäevast	doc_534729444733_item	2693701	et	4	main
tallinnas	doc_534729444732_item	2693422	et	4	main
tõesti	doc_534729444732_item	2693427	et	3	main
kujunenud	doc_534729444732_item	2693434	et	4	main
ka	doc_534729444732_item	2693449	et	3	main
eestlased	doc_534729444732_item	2693451	et	3	main
laulavad	doc_534729444732_item	2693452	et	4	main
koguaeg	doc_534729444732_item	2693453	et	3	main
perega	doc_534729444732_item	2693454	et	3	main
sõbradega	doc_534729444732_item	2693455	et	4	main
tuttavatega	doc_534729444732_item	2693456	et	3	main
see	doc_534729444732_item	2693457	et	3	main
ajal	doc_534729444732_item	2693424	et	4	main
sellepärast	doc_534729444732_item	2693436	et	3	main
laul	doc_534729444732_item	2693447	et	4	main
annab	doc_534729444732_item	2693458	et	3	main
jõudu	doc_534729444732_item	2693459	et	4	main
inimestele	doc_534729444732_item	2693460	et	3	main
kõik	doc_534729444732_item	2693466	et	4	main
mis	doc_534729444732_item	2693474	et	4	main
aitab	doc_534729444732_item	2693475	et	3	main
teemal	doc_534729444733_item	2693489	et	3	main
essee	doc_534729444733_item	2693499	et	4	main
üldistav	doc_534729444733_item	2693505	et	4	main
see	doc_534729444733_item	2693535	et	3	main
on	doc_534729444733_item	2693536	et	4	main
tõesti	doc_534729444733_item	2693537	et	3	main
nii	doc_534729444733_item	2693538	et	3	main
maailmas	doc_534729444733_item	2693546	et	3	main
on	doc_534729444733_item	2693547	et	4	main
ja	doc_534729444733_item	2693554	et	3	main
mõjuvad	doc_534729444733_item	2693556	et	4	main
inimestele	doc_534729444733_item	2693557	et	3	main
loomulikult	doc_534729444733_item	2693558	et	4	main
ei	doc_534729444733_item	2693559	et	4	main
öelda	doc_534729444733_item	2693578	et	4	main
et	doc_534729444733_item	2693579	et	3	main
et	doc_534729444733_item	2693592	et	3	main
ka	doc_534729444733_item	2693597	et	3	main
on	doc_534729444732_item	2693463	et	4	main
on	doc_534729444732_item	2693471	et	4	main
see	doc_534729444732_item	2693472	et	3	main
essee	doc_534729444733_item	2693479	et	4	main
teise	doc_534729444733_item	2693483	et	4	main
test	doc_534729444733_item	2693485	et	3	main
kirjutage	doc_534729444733_item	2693487	et	3	main
olema	doc_534729444733_item	2693501	et	4	main
loengus	doc_534729444733_item	2693507	et	3	main
esitatud	doc_534729444733_item	2693510	et	4	main
väiteid	doc_534729444733_item	2693512	et	4	main
soovitatav	doc_534729444733_item	2693514	et	4	main
illustreerida	doc_534729444733_item	2693515	et	3	main
näidetega	doc_534729444733_item	2693516	et	3	main
mõned	doc_534729444733_item	2693517	et	3	main
inimesed	doc_534729444733_item	2693518	et	3	main
toime	doc_534729444733_item	2693532	et	4	main
tulla	doc_534729444733_item	2693533	et	3	main
kas	doc_534729444733_item	2693534	et	3	main
nõustage	doc_534729444733_item	2693544	et	3	main
palju	doc_534729444733_item	2693548	et	4	main
kuidas	doc_534729444733_item	2693552	et	3	main
jätku	doc_534729444733_item	2693560	et	4	main
aega	doc_534729444733_item	2693561	et	4	main
kultuurinähtus	doc_534729444733_item	2693582	et	4	main
laul	doc_534729444733_item	2693584	et	4	main
arvatakse	doc_534729444733_item	2693598	et	3	main
räägime	doc_534729444733_item	2693621	et	3	main
tekkivad	doc_534729444733_item	2693626	et	4	main
väga	doc_534729444733_item	2693627	et	3	main
laulis	doc_534729444733_item	2693633	et	4	main
unustada	doc_534729444733_item	2693656	et	3	main
toime	doc_534729444733_item	2693659	et	4	main
oli	doc_534729444733_item	2693670	et	3	main
on	doc_534729444733_item	2693713	et	4	main
miks	doc_534729444733_item	2693721	et	4	main
väga	doc_534729444733_item	2693728	et	3	main
räägida	doc_534729444733_item	2693736	et	4	main
aga	doc_534729444733_item	2693737	et	3	main
tõenäoliselt	doc_534729444733_item	2693738	et	4	main
lihtne	doc_534729444733_item	2693742	et	3	main
ma	doc_534729444733_item	2693744	et	3	main
ajal	doc_534729444733_item	2693759	et	4	main
aitas	doc_534729444733_item	2693761	et	3	main
võimalus	doc_534729444733_item	2693776	et	3	main
tutvustada	doc_534729444733_item	2693780	et	3	main
eesti	doc_534729444733_item	2693782	et	4	main
folklooriga	doc_534729444733_item	2693783	et	4	main
ja	doc_534729444733_item	2693784	et	3	main
on	doc_534729444733_item	2693789	et	4	main
ka	doc_534729444733_item	2693790	et	3	main
praegusel	doc_534729444733_item	2693791	et	3	main
rahvusluse	doc_534729444733_item	2693797	et	4	main
külastuskäik	doc_534729444733_item	2693798	et	3	main
eestis	doc_534729444733_item	2693799	et	3	main
tore	doc_534729444733_item	2693806	et	3	main
sa	doc_534729444733_item	2693809	et	3	main
tulla	doc_534729444733_item	2693811	et	3	main
koos	doc_534729444733_item	2693813	et	4	main
võid	doc_534729444733_item	2693816	et	4	main
tutvuda	doc_534729444733_item	2693817	et	3	main
palju	doc_534729444733_item	2693818	et	4	main
inimestega	doc_534729444733_item	2693819	et	3	main
ja	doc_534729444733_item	2693820	et	3	main
kust	doc_534729444733_item	2693821	et	4	main
mis	doc_534729444733_item	2693490	et	4	main
teeb	doc_534729444733_item	2693491	et	3	main
peab	doc_534729444733_item	2693500	et	4	main
tuginema	doc_534729444733_item	2693506	et	3	main
aitab	doc_534729444733_item	2693522	et	3	main
elada	doc_534729444733_item	2693524	et	3	main
ja	doc_534729444733_item	2693525	et	3	main
halval	doc_534729444733_item	2693527	et	3	main
mitte	doc_534729444733_item	2693540	et	3	main
püüame	doc_534729444733_item	2693541	et	3	main
natukene	doc_534729444733_item	2693542	et	4	main
arutlema	doc_534729444733_item	2693543	et	3	main
näitavad	doc_534729444733_item	2693551	et	4	main
neid	doc_534729444733_item	2693564	et	4	main
näitused	doc_534729444733_item	2693565	et	3	main
ümber	doc_534729444733_item	2693566	et	3	main
vaadata	doc_534729444733_item	2693567	et	4	main
ja	doc_534729444733_item	2693568	et	3	main
siis	doc_534729444733_item	2693569	et	3	main
räägime	doc_534729444733_item	2693570	et	3	main
tõesti	doc_534729444733_item	2693583	et	3	main
tohi	doc_534729444733_item	2693590	et	4	main
see	doc_534729444733_item	2693593	et	3	main
sotsiaalne	doc_534729444733_item	2693595	et	3	main
et	doc_534729444733_item	2693599	et	3	main
eestlased	doc_534729444733_item	2693600	et	3	main
on	doc_534729444733_item	2693601	et	4	main
väga	doc_534729444733_item	2693602	et	3	main
muusikalne	doc_534729444733_item	2693603	et	4	main
rahvas	doc_534729444733_item	2693604	et	4	main
sest	doc_534729444733_item	2693605	et	4	main
juba	doc_534729444733_item	2693606	et	3	main
vanast	doc_534729444733_item	2693607	et	3	main
ajast	doc_534729444733_item	2693608	et	4	main
eestlased	doc_534729444733_item	2693609	et	3	main
koguaeg	doc_534729444733_item	2693610	et	3	main
laulsid	doc_534729444733_item	2693611	et	4	main
lauldi	doc_534729444733_item	2693612	et	3	main
üksi	doc_534729444733_item	2693613	et	4	main
olles	doc_534729444733_item	2693614	et	3	main
lauldi	doc_534729444733_item	2693615	et	3	main
töötades	doc_534729444733_item	2693616	et	3	main
lauldi	doc_534729444733_item	2693617	et	3	main
peos	doc_534729444733_item	2693618	et	4	main
kui	doc_534729444733_item	2693619	et	3	main
me	doc_534729444733_item	2693620	et	4	main
ja	doc_534729444733_item	2693623	et	3	main
laulis	doc_534729444733_item	2693631	et	4	main
kus	doc_534729444733_item	2693632	et	3	main
kui	doc_534729444733_item	2693637	et	3	main
öelnud	doc_534729444733_item	2693640	et	4	main
lauldi	doc_534729444733_item	2693642	et	3	main
kui	doc_534729444733_item	2693644	et	3	main
võimalus	doc_534729444733_item	2693646	et	3	main
võimalus	doc_534729444733_item	2693652	et	3	main
probleemidega	doc_534729444733_item	2693658	et	3	main
tulla	doc_534729444733_item	2693660	et	3	main
arvatakse	doc_534729444733_item	2693661	et	3	main
et	doc_534729444733_item	2693662	et	3	main
laulsid	doc_534729444733_item	2693663	et	4	main
ainult	doc_534729444733_item	2693664	et	4	main
naised	doc_534729444733_item	2693665	et	3	main
ja	doc_534729444733_item	2693666	et	3	main
lapsed	doc_534729444733_item	2693667	et	3	main
laulukultuurist	doc_534729444733_item	2693622	et	3	main
sest	doc_534729444733_item	2693625	et	4	main
ja	doc_534729444733_item	2693634	et	3	main
juba	doc_534729444733_item	2693638	et	3	main
et	doc_534729444733_item	2693641	et	3	main
kõikjal	doc_534729444733_item	2693643	et	3	main
sest	doc_534729444733_item	2693648	et	4	main
laul	doc_534729444733_item	2693649	et	4	main
oli	doc_534729444733_item	2693650	et	3	main
probleemidest	doc_534729444733_item	2693654	et	3	main
sest	doc_534729444733_item	2693668	et	4	main
et	doc_534729444733_item	2693673	et	3	main
see	doc_534729444733_item	2693675	et	3	main
mõiste	doc_534729444733_item	2693676	et	4	main
pole	doc_534729444733_item	2693677	et	3	main
õige	doc_534729444733_item	2693678	et	4	main
sest	doc_534729444733_item	2693679	et	4	main
palju	doc_534729444733_item	2693680	et	4	main
meremehi	doc_534729444733_item	2693681	et	3	main
kes	doc_534729444733_item	2693682	et	4	main
istusid	doc_534729444733_item	2693683	et	4	main
merekaldal	doc_534729444733_item	2693684	et	3	main
ja	doc_534729444733_item	2693685	et	3	main
püüdsid	doc_534729444733_item	2693686	et	4	main
kaulu	doc_534729444733_item	2693687	et	4	main
laulsid	doc_534729444733_item	2693688	et	4	main
ka	doc_534729444733_item	2693689	et	3	main
peale	doc_534729444733_item	2693690	et	4	main
selle	doc_534729444733_item	2693691	et	4	main
mehed	doc_534729444733_item	2693692	et	3	main
laulsid	doc_534729444733_item	2693693	et	4	main
pulmapidudel	doc_534729444733_item	2693694	et	4	main
ja	doc_534729444733_item	2693695	et	3	main
koorides	doc_534729444733_item	2693696	et	4	main
aga	doc_534729444733_item	2693697	et	3	main
kui	doc_534729444733_item	2693698	et	3	main
me	doc_534729444733_item	2693699	et	4	main
aega	doc_534729444733_item	2693672	et	4	main
räägime	doc_534729444733_item	2693700	et	3	main
võib	doc_534729444733_item	2693703	et	3	main
tuttavamaid	doc_534729444733_item	2693707	et	4	main
andekaid	doc_534729444733_item	2693709	et	4	main
ja	doc_534729444733_item	2693711	et	3	main
ikkagi	doc_534729444733_item	2693714	et	4	main
lõpude	doc_534729444733_item	2693716	et	4	main
lõpuks	doc_534729444733_item	2693717	et	4	main
püüame	doc_534729444733_item	2693718	et	3	main
laulavad	doc_534729444733_item	2693723	et	4	main
tohi	doc_534729444733_item	2693733	et	4	main
sellest	doc_534729444733_item	2693734	et	4	main
ühesõnaga	doc_534729444733_item	2693735	et	3	main
on	doc_534729444733_item	2693740	et	4	main
ja	doc_534729444733_item	2693743	et	3	main
et	doc_534729444733_item	2693751	et	3	main
kultuuri	doc_534729444733_item	2693768	et	4	main
hoida	doc_534729444733_item	2693769	et	3	main
tänapäeval	doc_534729444733_item	2693770	et	3	main
hea	doc_534729444733_item	2693775	et	4	main
näiteks	doc_534729444733_item	2693786	et	4	main
üleestiline	doc_534729444733_item	2693787	et	4	main
on	doc_534729444733_item	2693801	et	4	main
rahvapidu	doc_534729444733_item	2693807	et	4	main
kindlasti	doc_534729444733_item	2693823	et	3	main
hea	doc_534729444733_item	2693826	et	4	main
tujuga	doc_534729444733_item	2693827	et	3	main
koos	doc_534729444733_item	2693828	et	4	main
mis	doc_534729444733_item	2693842	et	4	main
ühendab	doc_534729444733_item	2693843	et	3	main
meid	doc_534729444733_item	2693844	et	4	main
kokkuvõttes	doc_534729444733_item	2693845	et	3	main
tahaks	doc_534729444733_item	2693846	et	3	main
mängisid	doc_534729444733_item	2693853	et	4	main
suurt	doc_534729444733_item	2693854	et	3	main
rolli	doc_534729444733_item	2693855	et	4	main
aitasid	doc_534729444733_item	2693860	et	4	main
vormistada	doc_534729444733_item	2693861	et	3	main
oma	doc_534729444733_item	2693862	et	4	main
viia	doc_534729444733_item	2693866	et	3	main
keele	doc_534729444734_item	2693885	et	4	main
eestlastest	doc_534729444734_item	2693896	et	4	main
laulurahva	doc_534729444734_item	2693897	et	3	main
essee	doc_534729444734_item	2693898	et	4	main
lugemistekstis	doc_534729444734_item	2693913	et	3	main
sageli	doc_534729444734_item	2693939	et	3	main
niisuguste	doc_534729444734_item	2693941	et	3	main
on	doc_534729444734_item	2693955	et	4	main
tööd	doc_534729444734_item	2693982	et	4	main
eesti	doc_534729444734_item	2693991	et	4	main
on	doc_534729444734_item	2693993	et	4	main
koor	doc_534729444734_item	2694002	et	4	main
tuhat	doc_534729444734_item	2694010	et	4	main
täna	doc_534729444734_item	2694017	et	4	main
teiseks	doc_534729444734_item	2694028	et	4	main
mitmekesine	doc_534729444734_item	2694038	et	4	main
aja	doc_534729444734_item	2694053	et	4	main
puhkpilliorkestrite	doc_534729444734_item	2694067	et	3	main
uus	doc_534729444734_item	2694081	et	3	main
rahvalaul	doc_534729444734_item	2694084	et	4	main
asemele	doc_534729444734_item	2694088	et	4	main
lõpetavad	doc_534729444734_item	2694095	et	4	main
on	doc_534729444734_item	2694102	et	4	main
aidates	doc_534729444734_item	2694109	et	3	main
säilitada	doc_534729444734_item	2694110	et	3	main
linnas	doc_534729444734_item	2694118	et	4	main
ajaloolise	doc_534729444734_item	2694120	et	4	main
laulupidu	doc_534729444734_item	2694132	et	4	main
jannseni	doc_534729444734_item	2694139	et	4	main
1869	doc_534729444734_item	2694141	et	2	main
aastal	doc_534729444734_item	2694142	et	3	main
alguses	doc_534729444734_item	2694144	et	4	main
ja	doc_534729444734_item	2694149	et	3	main
liitusid	doc_534729444734_item	2694152	et	4	main
1896	doc_534729444734_item	2694159	et	2	main
toimuvad	doc_534729444734_item	2694161	et	4	main
sellele	doc_534729444734_item	2694165	et	4	main
pidid	doc_534729444734_item	2694169	et	4	main
laule	doc_534729444734_item	2694173	et	4	main
rahvas	doc_534729444734_item	2694176	et	4	main
kõige	doc_534729444733_item	2693706	et	4	main
heliloojad	doc_534729444733_item	2693712	et	3	main
mehed	doc_534729444733_item	2693715	et	3	main
et	doc_534729444733_item	2693725	et	3	main
küsimus	doc_534729444733_item	2693730	et	4	main
ja	doc_534729444733_item	2693731	et	3	main
väga	doc_534729444733_item	2693741	et	3	main
on	doc_534729444733_item	2693749	et	4	main
laul	doc_534729444733_item	2693760	et	4	main
muusika	doc_534729444733_item	2693771	et	4	main
ja	doc_534729444733_item	2693772	et	3	main
laulud	doc_534729444733_item	2693773	et	3	main
ennast	doc_534729444733_item	2693777	et	4	main
ja	doc_534729444733_item	2693779	et	3	main
inimesi	doc_534729444733_item	2693781	et	4	main
laulupidu	doc_534729444733_item	2693788	et	4	main
massilisem	doc_534729444733_item	2693796	et	4	main
ja	doc_534729444733_item	2693805	et	3	main
kuhu	doc_534729444733_item	2693808	et	3	main
lähed	doc_534729444733_item	2693824	et	3	main
selles	doc_534729444733_item	2693831	et	4	main
laulu-	doc_534729444733_item	2693833	et	4	main
meil	doc_534729444733_item	2693839	et	4	main
jõud	doc_534729444733_item	2693841	et	4	main
et	doc_534729444733_item	2693851	et	3	main
ikkagi	doc_534729444733_item	2693858	et	4	main
seda	doc_534729444733_item	2693867	et	3	main
aega	doc_534729444733_item	2693869	et	4	main
elu	doc_534729444733_item	2693882	et	4	main
kui	doc_534729444734_item	2693886	et	3	main
keele	doc_534729444734_item	2693888	et	4	main
350	doc_534729444734_item	2693901	et	2	main
essee	doc_534729444734_item	2693903	et	4	main
tuginema	doc_534729444734_item	2693910	et	3	main
huvitav	doc_534729444734_item	2693928	et	4	main
selle	doc_534729444734_item	2693929	et	4	main
õppides	doc_534729444734_item	2693937	et	4	main
nagu	doc_534729444734_item	2693943	et	3	main
nimetatakse	doc_534729444734_item	2693945	et	3	main
üle	doc_534729444734_item	2693948	et	3	main
mitu	doc_534729444734_item	2693951	et	4	main
sotsiaaltegevus	doc_534729444734_item	2693980	et	4	main
ning	doc_534729444734_item	2693987	et	3	main
loomulikult	doc_534729444734_item	2693988	et	4	main
kokku	doc_534729444734_item	2693989	et	3	main
saames	doc_534729444734_item	2693990	et	3	main
laul	doc_534729444734_item	2693996	et	4	main
see	doc_534729444734_item	2694005	et	3	main
ja	doc_534729444734_item	2694013	et	3	main
ka	doc_534729444734_item	2694016	et	3	main
võiks	doc_534729444734_item	2694018	et	4	main
öelda	doc_534729444734_item	2694019	et	4	main
et	doc_534729444734_item	2694020	et	3	main
inimesed	doc_534729444733_item	2693722	et	3	main
see	doc_534729444733_item	2693726	et	3	main
arvan	doc_534729444733_item	2693745	et	3	main
et	doc_534729444733_item	2693746	et	3	main
õige	doc_534729444733_item	2693747	et	4	main
vastus	doc_534729444733_item	2693748	et	3	main
sõjaid	doc_534729444733_item	2693763	et	4	main
ümber	doc_534729444733_item	2693764	et	3	main
elada	doc_534729444733_item	2693765	et	3	main
ja	doc_534729444733_item	2693766	et	3	main
oma	doc_534729444733_item	2693767	et	4	main
kultuuriga	doc_534729444733_item	2693785	et	4	main
ajal	doc_534729444733_item	2693792	et	4	main
lisaks	doc_534729444733_item	2693800	et	4	main
sa	doc_534729444733_item	2693822	et	3	main
ja	doc_534729444733_item	2693834	et	3	main
jõud	doc_534729444733_item	2693836	et	4	main
aitab	doc_534729444733_item	2693838	et	3	main
elada	doc_534729444733_item	2693840	et	3	main
elus	doc_534729444733_item	2693857	et	4	main
ja	doc_534729444733_item	2693864	et	3	main
laul	doc_534729444733_item	2693880	et	4	main
on	doc_534729444733_item	2693881	et	4	main
essee	doc_534729444734_item	2693892	et	4	main
teemal	doc_534729444734_item	2693893	et	3	main
pikkus	doc_534729444734_item	2693899	et	4	main
olema	doc_534729444734_item	2693905	et	4	main
analüüsiv	doc_534729444734_item	2693907	et	4	main
ja	doc_534729444734_item	2693912	et	3	main
eestlastest	doc_534729444734_item	2693923	et	4	main
eestimaa	doc_534729444734_item	2693925	et	4	main
on	doc_534729444734_item	2693926	et	4	main
igati	doc_534729444734_item	2693927	et	3	main
kultuuri	doc_534729444734_item	2693936	et	4	main
küsimuste	doc_534729444734_item	2693942	et	4	main
miks	doc_534729444734_item	2693944	et	4	main
laulurahvaks	doc_534729444734_item	2693947	et	3	main
on	doc_534729444734_item	2693950	et	4	main
olnud	doc_534729444734_item	2693957	et	4	main
suur	doc_534729444734_item	2693958	et	3	main
osa	doc_534729444734_item	2693959	et	4	main
eesti	doc_534729444734_item	2693960	et	4	main
kultuurist	doc_534729444734_item	2693961	et	3	main
regivärsiline	doc_534729444734_item	2693995	et	4	main
esitavad	doc_534729444734_item	2693998	et	4	main
eeslaulja	doc_534729444734_item	2694000	et	4	main
ja	doc_534729444734_item	2694001	et	3	main
rohkem	doc_534729444734_item	2694008	et	4	main
kui	doc_534729444734_item	2694009	et	3	main
niiviisi	doc_534729444734_item	2694014	et	3	main
eesti	doc_534729444734_item	2694021	et	4	main
hindab	doc_534729444734_item	2694023	et	3	main
ja	doc_534729444734_item	2694024	et	3	main
säilitab	doc_534729444734_item	2694025	et	3	main
kaheksateistkümnendal	doc_534729444734_item	2694039	et	4	main
sajandil	doc_534729444734_item	2694040	et	3	main
näiteks	doc_534729444734_item	2694041	et	4	main
peale	doc_534729444734_item	2694042	et	4	main
vaimulike	doc_534729444734_item	2694043	et	3	main
laulude	doc_534729444734_item	2694044	et	3	main
sajandist	doc_534729444734_item	2694070	et	3	main
peab	doc_534729444734_item	2694072	et	4	main
seda	doc_534729444734_item	2694074	et	3	main
eesti	doc_534729444734_item	2694076	et	4	main
laulutraditsioon	doc_534729444734_item	2694077	et	3	main
muutus	doc_534729444734_item	2694078	et	4	main
oli	doc_534729444734_item	2694079	et	3	main
regilaulu	doc_534729444734_item	2694087	et	4	main
salmi	doc_534729444734_item	2694094	et	4	main
omavahel	doc_534729444734_item	2694098	et	3	main
laul	doc_534729444734_item	2694101	et	4	main
alati	doc_534729444734_item	2694103	et	4	main
mänginud	doc_534729444734_item	2694104	et	4	main
eestis	doc_534729444734_item	2694105	et	3	main
tähtsat	doc_534729444734_item	2694106	et	3	main
nii	doc_534729444734_item	2694115	et	3	main
kui	doc_534729444734_item	2694117	et	3	main
sündmuseks	doc_534729444734_item	2694122	et	3	main
kogu	doc_534729444734_item	2694129	et	4	main
meestekoorid	doc_534729444734_item	2694148	et	3	main
nendega	doc_534729444734_item	2694153	et	4	main
kui	doc_534729444734_item	2694156	et	3	main
et	doc_534729444734_item	2694166	et	3	main
ajal	doc_534729444734_item	2694168	et	4	main
pealesunnitud	doc_534729444734_item	2694172	et	4	main
on	doc_534729444734_item	2694174	et	4	main
g	doc_534729444734_item	2694183	et	4	main
on	doc_534729444734_item	2694214	et	4	main
on	doc_534729444733_item	2693774	et	4	main
väljenduda	doc_534729444733_item	2693778	et	3	main
kõige	doc_534729444733_item	2693793	et	4	main
tähelepanuväärsem	doc_534729444733_item	2693794	et	4	main
ja	doc_534729444733_item	2693795	et	3	main
laulupidu	doc_534729444733_item	2693802	et	4	main
ka	doc_534729444733_item	2693803	et	3	main
suur	doc_534729444733_item	2693804	et	3	main
võid	doc_534729444733_item	2693810	et	4	main
perega	doc_534729444733_item	2693812	et	3	main
kus	doc_534729444733_item	2693814	et	3	main
sa	doc_534729444733_item	2693815	et	3	main
arvan	doc_534729444733_item	2693829	et	3	main
muusikajõud	doc_534729444733_item	2693835	et	4	main
mis	doc_534729444733_item	2693837	et	4	main
öelda	doc_534729444733_item	2693847	et	4	main
et	doc_534729444733_item	2693848	et	3	main
ma	doc_534729444733_item	2693849	et	3	main
arvan	doc_534729444733_item	2693850	et	3	main
laulud	doc_534729444733_item	2693852	et	3	main
laulud	doc_534729444733_item	2693859	et	3	main
aitasid	doc_534729444733_item	2693865	et	4	main
läbi	doc_534729444733_item	2693868	et	4	main
laul	doc_534729444733_item	2693870	et	4	main
ühendab	doc_534729444733_item	2693871	et	3	main
meid	doc_534729444733_item	2693872	et	4	main
ja	doc_534729444733_item	2693873	et	3	main
lubab	doc_534729444733_item	2693874	et	3	main
essee	doc_534729444734_item	2693883	et	4	main
teise	doc_534729444734_item	2693887	et	4	main
test	doc_534729444734_item	2693889	et	3	main
kirjutamine	doc_534729444734_item	2693890	et	4	main
kirjutage	doc_534729444734_item	2693891	et	3	main
peab	doc_534729444734_item	2693904	et	4	main
arutlev	doc_534729444734_item	2693906	et	4	main
ja	doc_534729444734_item	2693908	et	3	main
loengus	doc_534729444734_item	2693911	et	3	main
esitatud	doc_534729444734_item	2693914	et	4	main
on	doc_534729444734_item	2693917	et	4	main
soovitatav	doc_534729444734_item	2693918	et	4	main
illustreerida	doc_534729444734_item	2693919	et	3	main
ära	doc_534729444733_item	2693825	et	4	main
et	doc_534729444733_item	2693830	et	3	main
on	doc_534729444733_item	2693832	et	4	main
eestlaste	doc_534729444733_item	2693856	et	4	main
kultuuri	doc_534729444733_item	2693863	et	4	main
meid	doc_534729444733_item	2693875	et	4	main
julgeks	doc_534729444733_item	2693876	et	4	main
ja	doc_534729444733_item	2693877	et	3	main
tugevaks	doc_534729444733_item	2693878	et	4	main
olla	doc_534729444733_item	2693879	et	3	main
eesti	doc_534729444734_item	2693884	et	4	main
mis	doc_534729444734_item	2693894	et	4	main
teeb	doc_534729444734_item	2693895	et	3	main
300	doc_534729444734_item	2693900	et	2	main
sõna	doc_534729444734_item	2693902	et	4	main
üldistav	doc_534729444734_item	2693909	et	4	main
faktidele	doc_534729444734_item	2693915	et	3	main
väiteid	doc_534729444734_item	2693916	et	4	main
näidetega	doc_534729444734_item	2693920	et	3	main
mis	doc_534729444734_item	2693921	et	4	main
kultuuri	doc_534729444734_item	2693930	et	4	main
tavade	doc_534729444734_item	2693931	et	3	main
ning	doc_534729444734_item	2693932	et	3	main
rahva	doc_534729444734_item	2693933	et	3	main
poolt	doc_534729444734_item	2693934	et	4	main
seda	doc_534729444734_item	2693935	et	3	main
peab	doc_534729444734_item	2693938	et	4	main
eestlasi	doc_534729444734_item	2693946	et	3	main
põhjust	doc_534729444734_item	2693952	et	4	main
esiteks	doc_534729444734_item	2693953	et	3	main
laul	doc_534729444734_item	2693954	et	4	main
ka	doc_534729444734_item	2693979	et	3	main
vaheldumisi	doc_534729444734_item	2694003	et	4	main
kuna	doc_534729444734_item	2694004	et	3	main
aastat	doc_534729444734_item	2694011	et	3	main
lauldakse	doc_534729444734_item	2694015	et	3	main
piduõhtuti	doc_534729444734_item	2694051	et	4	main
võiks	doc_534729444734_item	2694055	et	4	main
nimetada	doc_534729444734_item	2694056	et	3	main
vaimulike	doc_534729444734_item	2694057	et	3	main
laule	doc_534729444734_item	2694058	et	4	main
ning	doc_534729444734_item	2694059	et	3	main
uute	doc_534729444734_item	2694060	et	3	main
tekkinud	doc_534729444734_item	2694080	et	4	main
tuli	doc_534729444734_item	2694089	et	4	main
uus	doc_534729444734_item	2694090	et	3	main
iga	doc_534729444734_item	2694093	et	4	main
rolli	doc_534729444734_item	2694107	et	4	main
näiteks	doc_534729444734_item	2694108	et	4	main
rahvusliku	doc_534729444734_item	2694111	et	3	main
identiteedi	doc_534729444734_item	2694112	et	4	main
tunnet	doc_534729444734_item	2694113	et	3	main
lauldi	doc_534729444734_item	2694114	et	3	main
tähtsusega	doc_534729444734_item	2694121	et	4	main
kujunes	doc_534729444734_item	2694123	et	3	main
millest	doc_534729444734_item	2694125	et	3	main
võtsid	doc_534729444734_item	2694126	et	4	main
esimene	doc_534729444734_item	2694131	et	3	main
ja	doc_534729444734_item	2694136	et	3	main
j	doc_534729444734_item	2694137	et	4	main
tartus	doc_534729444734_item	2694143	et	3	main
naiste	doc_534729444734_item	2694155	et	3	main
ka	doc_534729444734_item	2694157	et	3	main
aastast	doc_534729444734_item	2694160	et	4	main
nõukogude	doc_534729444734_item	2694167	et	3	main
endas	doc_534729444734_item	2694178	et	4	main
ja	doc_534729444734_item	2694221	et	3	main
teeb	doc_534729444734_item	2694224	et	3	main
laulurahva	doc_534729444734_item	2694226	et	3	main
teeb	doc_534729444734_item	2693922	et	3	main
laulurahva	doc_534729444734_item	2693924	et	3	main
mõtlema	doc_534729444734_item	2693940	et	3	main
selleks	doc_534729444734_item	2693949	et	4	main
alati	doc_534729444734_item	2693956	et	4	main
rahvalaul	doc_534729444734_item	2693962	et	4	main
on	doc_534729444734_item	2693963	et	4	main
olnud	doc_534729444734_item	2693964	et	4	main
ja	doc_534729444734_item	2693965	et	3	main
siiani	doc_534729444734_item	2693966	et	4	main
on	doc_534729444734_item	2693967	et	4	main
osa	doc_534729444734_item	2693968	et	4	main
igapäevasest	doc_534729444734_item	2693969	et	4	main
elust	doc_534729444734_item	2693970	et	3	main
vanadel	doc_534729444734_item	2693971	et	3	main
aegadel	doc_534729444734_item	2693972	et	3	main
laulmine	doc_534729444734_item	2693973	et	4	main
polnud	doc_534729444734_item	2693974	et	3	main
ainult	doc_534729444734_item	2693975	et	4	main
emotsionaalne	doc_534729444734_item	2693976	et	3	main
väljendusvahend	doc_534729444734_item	2693977	et	3	main
vaid	doc_534729444734_item	2693978	et	3	main
lauldi	doc_534729444734_item	2693981	et	3	main
tehes	doc_534729444734_item	2693983	et	3	main
lapsi	doc_534729444734_item	2693984	et	4	main
kasvatades	doc_534729444734_item	2693985	et	3	main
meisterdades	doc_534729444734_item	2693986	et	3	main
rahvale	doc_534729444734_item	2693992	et	3	main
iseloomulik	doc_534729444734_item	2693994	et	3	main
mida	doc_534729444734_item	2693997	et	4	main
tavaliselt	doc_534729444734_item	2693999	et	4	main
on	doc_534729444734_item	2694006	et	4	main
kujunenud	doc_534729444734_item	2694007	et	4	main
tagasi	doc_534729444734_item	2694012	et	3	main
võiks	doc_534729444734_item	2694029	et	4	main
mainida	doc_534729444734_item	2694030	et	3	main
ka	doc_534729444734_item	2694031	et	3	main
seda	doc_534729444734_item	2694032	et	3	main
et	doc_534729444734_item	2694033	et	3	main
eesti	doc_534729444734_item	2694034	et	4	main
laul	doc_534729444734_item	2694035	et	4	main
peamiselt	doc_534729444734_item	2694050	et	4	main
koorilaulu	doc_534729444734_item	2694063	et	4	main
levikuga	doc_534729444734_item	2694064	et	3	main
kaasnes	doc_534729444734_item	2694065	et	3	main
ka	doc_534729444734_item	2694066	et	3	main
üheksateistkümnendast	doc_534729444734_item	2694069	et	3	main
nn	doc_534729444734_item	2694082	et	4	main
sõnad	doc_534729444734_item	2694096	et	4	main
riimis	doc_534729444734_item	2694099	et	4	main
eestist	doc_534729444734_item	2694130	et	3	main
vanemuise	doc_534729444734_item	2694135	et	4	main
abiga	doc_534729444734_item	2694140	et	3	main
esinesid	doc_534729444734_item	2694145	et	4	main
seal	doc_534729444734_item	2694146	et	4	main
ainult	doc_534729444734_item	2694147	et	4	main
hiljem	doc_534729444734_item	2694151	et	3	main
vaatamata	doc_534729444734_item	2694164	et	4	main
inimesed	doc_534729444734_item	2694170	et	3	main
laul	doc_534729444734_item	2694213	et	4	main
see	doc_534729444734_item	2694222	et	3	main
eestlastest	doc_534729444734_item	2694225	et	4	main
rahvas	doc_534729444734_item	2694022	et	4	main
oma	doc_534729444734_item	2694026	et	4	main
laulukultuuri	doc_534729444734_item	2694027	et	4	main
on	doc_534729444734_item	2694036	et	4	main
väga	doc_534729444734_item	2694037	et	3	main
laulmist	doc_534729444734_item	2694045	et	4	main
lauldi	doc_534729444734_item	2694046	et	3	main
ning	doc_534729444734_item	2694047	et	3	main
musitseeriti	doc_534729444734_item	2694048	et	3	main
ka	doc_534729444734_item	2694049	et	3	main
selle	doc_534729444734_item	2694052	et	4	main
muusikat	doc_534729444734_item	2694054	et	3	main
muusikatendentsite	doc_534729444734_item	2694061	et	4	main
sümbioosiks	doc_534729444734_item	2694062	et	3	main
asutamine	doc_534729444734_item	2694068	et	4	main
rääkides	doc_534729444734_item	2694071	et	4	main
mainima	doc_534729444734_item	2694073	et	3	main
et	doc_534729444734_item	2694075	et	3	main
riimiline	doc_534729444734_item	2694083	et	4	main
koorilaulu	doc_534729444734_item	2694085	et	4	main
ning	doc_534729444734_item	2694086	et	3	main
laul	doc_534729444734_item	2694091	et	4	main
kus	doc_534729444734_item	2694092	et	3	main
peaksid	doc_534729444734_item	2694097	et	4	main
olema	doc_534729444734_item	2694100	et	4	main
maal	doc_534729444734_item	2694116	et	4	main
kuid	doc_534729444734_item	2694119	et	4	main
laulupidu	doc_534729444734_item	2694124	et	4	main
osa	doc_534729444734_item	2694127	et	4	main
inimesed	doc_534729444734_item	2694128	et	3	main
oli	doc_534729444734_item	2694133	et	3	main
korraldatud	doc_534729444734_item	2694134	et	4	main
v	doc_534729444734_item	2694138	et	4	main
puhkpilleorkestrid	doc_534729444734_item	2694150	et	4	main
nii	doc_534729444734_item	2694154	et	3	main
lastekoorid	doc_534729444734_item	2694158	et	3	main
laulupeod	doc_534729444734_item	2694162	et	4	main
tallinnas	doc_534729444734_item	2694163	et	4	main
laulma	doc_534729444734_item	2694171	et	3	main
eesti	doc_534729444734_item	2694175	et	4	main
leidnud	doc_534729444734_item	2694177	et	4	main
jõudu	doc_534729444734_item	2694179	et	4	main
säilitada	doc_534729444734_item	2694180	et	3	main
enda	doc_534729444734_item	2694181	et	4	main
väärtusi	doc_534729444734_item	2694182	et	3	main
laul	doc_534729444734_item	2694185	et	4	main
mu	doc_534729444734_item	2694186	et	3	main
isamaa	doc_534729444734_item	2694187	et	4	main
on	doc_534729444734_item	2694188	et	4	main
minu	doc_534729444734_item	2694189	et	3	main
arm	doc_534729444734_item	2694190	et	3	main
tõestab	doc_534729444734_item	2694191	et	3	main
seda	doc_534729444734_item	2694192	et	3	main
laul	doc_534729444734_item	2694193	et	4	main
on	doc_534729444734_item	2694194	et	4	main
aidanud	doc_534729444734_item	2694195	et	4	main
inimestel	doc_534729444734_item	2694196	et	3	main
elada	doc_534729444734_item	2694197	et	3	main
ning	doc_534729444734_item	2694198	et	3	main
oli	doc_534729444734_item	2694199	et	3	main
osaks	doc_534729444734_item	2694200	et	3	main
eesti	doc_534729444734_item	2694201	et	4	main
inimesest	doc_534729444734_item	2694202	et	3	main
juba	doc_534729444734_item	2694203	et	3	main
tuhandeid	doc_534729444734_item	2694204	et	3	main
aastaid	doc_534729444734_item	2694205	et	4	main
on	doc_534729444734_item	2694206	et	4	main
see	doc_534729444734_item	2694207	et	3	main
eestlastele	doc_534729444734_item	2694208	et	4	main
abiks	doc_534729444734_item	2694209	et	3	main
ja	doc_534729444734_item	2694210	et	3	main
toeks	doc_534729444734_item	2694211	et	3	main
olnud	doc_534729444734_item	2694212	et	4	main
ernesaksa	doc_534729444734_item	2694184	et	4	main
kõik	doc_534729444734_item	2694223	et	4	main
tähtis	doc_534729444734_item	2694215	et	4	main
aspekt	doc_534729444734_item	2694216	et	3	main
eesti	doc_534729444734_item	2694217	et	4	main
kultuuris	doc_534729444734_item	2694218	et	3	main
ning	doc_534729444734_item	2694219	et	3	main
ajaloos	doc_534729444734_item	2694220	et	4	main
teise	doc_534729444736_item	2694518	et	4	main
test	doc_534729444736_item	2694520	et	3	main
kirjutage	doc_534729444736_item	2694522	et	3	main
keele	doc_534729444736_item	2694516	et	4	main
laulurahva	doc_534729444736_item	2694528	et	3	main
essee	doc_534729444736_item	2694534	et	4	main
peab	doc_534729444736_item	2694535	et	4	main
olema	doc_534729444736_item	2694536	et	4	main
ja	doc_534729444736_item	2694543	et	3	main
väiteid	doc_534729444736_item	2694547	et	4	main
laul	doc_534729444736_item	2694554	et	4	main
on	doc_534729444736_item	2694559	et	4	main
nähtus	doc_534729444736_item	2694562	et	4	main
eesti	doc_534729444736_item	2694568	et	4	main
rahvalaulus	doc_534729444736_item	2694569	et	3	main
kuhu	doc_534729444736_item	2694574	et	3	main
kuulub	doc_534729444736_item	2694575	et	3	main
ja	doc_534729444736_item	2694577	et	3	main
sõnad	doc_534729444736_item	2694580	et	4	main
ühest	doc_534729444736_item	2694582	et	4	main
tähest	doc_534729444736_item	2694583	et	4	main
teine	doc_534729444736_item	2694584	et	3	main
kokku	doc_534729444736_item	2694591	et	3	main
hakkasid	doc_534729444736_item	2694592	et	4	main
olla	doc_534729444736_item	2694625	et	3	main
oma	doc_534729444736_item	2694627	et	4	main
arenema	doc_534729444736_item	2694637	et	3	main
see	doc_534729444736_item	2694639	et	3	main
viis	doc_534729444736_item	2694643	et	4	main
seda	doc_534729444736_item	2694657	et	3	main
hea	doc_534729444736_item	2694682	et	4	main
kes	doc_534729444736_item	2694732	et	4	main
elab	doc_534729444736_item	2694733	et	3	main
eestis	doc_534729444736_item	2694734	et	3	main
peab	doc_534729444736_item	2694735	et	4	main
on	doc_534729444736_item	2694748	et	4	main
pidudel	doc_534729444736_item	2694768	et	4	main
saavutanud	doc_534729444736_item	2694780	et	4	main
päris	doc_534729444736_item	2694781	et	4	main
näiteks	doc_534729444736_item	2694783	et	4	main
vanilla	doc_534729444736_item	2694784	et	4	main
midagi	doc_534729444736_item	2694792	et	4	main
saavutada	doc_534729444736_item	2694793	et	3	main
keele	doc_534729444736_item	2694519	et	4	main
kui	doc_534729444736_item	2694517	et	3	main
essee	doc_534729444736_item	2694514	et	4	main
eesti	doc_534729444736_item	2694515	et	4	main
kirjutamine	doc_534729444736_item	2694521	et	4	main
eestlastest	doc_534729444736_item	2694527	et	4	main
350	doc_534729444736_item	2694532	et	2	main
on	doc_534729444736_item	2694555	et	4	main
väga	doc_534729444736_item	2694556	et	3	main
tähelepanuväärne	doc_534729444736_item	2694560	et	3	main
kultuuri	doc_534729444736_item	2694561	et	4	main
ja	doc_534729444736_item	2694563	et	3	main
mõnes	doc_534729444736_item	2694564	et	3	main
ka	doc_534729444736_item	2694565	et	3	main
sotsiaalne	doc_534729444736_item	2694566	et	3	main
kõik	doc_534729444736_item	2694579	et	4	main
on	doc_534729444736_item	2694586	et	4	main
siis	doc_534729444736_item	2694587	et	3	main
salmi	doc_534729444736_item	2694594	et	4	main
ei	doc_534729444736_item	2694623	et	4	main
tegi	doc_534729444736_item	2694645	et	4	main
eestlasi	doc_534729444736_item	2694646	et	3	main
ja	doc_534729444736_item	2694655	et	3	main
üritused	doc_534729444736_item	2694664	et	4	main
selle	doc_534729444736_item	2694736	et	4	main
aegadeks	doc_534729444736_item	2694743	et	3	main
traditsiooni	doc_534729444736_item	2694746	et	4	main
ei	doc_534729444736_item	2694759	et	4	main
rahvalaulu	doc_534729444736_item	2694767	et	4	main
on	doc_534729444736_item	2694772	et	4	main
väga	doc_534729444736_item	2694773	et	3	main
häid	doc_534729444736_item	2694774	et	3	main
kes	doc_534729444736_item	2694778	et	4	main
palju	doc_534729444736_item	2694782	et	4	main
ilus	doc_534729444736_item	2694789	et	4	main
ühine	doc_534729444736_item	2694795	et	4	main
vaimne	doc_534729444736_item	2694796	et	3	main
faktidele	doc_534729444737_item	2694833	et	3	main
vana	doc_534729444737_item	2694840	et	4	main
nendele	doc_534729444737_item	2694869	et	4	main
teistpidi	doc_534729444737_item	2694877	et	3	main
on	doc_534729444737_item	2694881	et	4	main
mingisugune	doc_534729444737_item	2694882	et	3	main
saladus	doc_534729444737_item	2694883	et	3	main
siin	doc_534729444737_item	2694884	et	4	main
kajastub	doc_534729444737_item	2694885	et	3	main
uurimine	doc_534729444737_item	2694898	et	4	main
räägime	doc_534729444737_item	2694899	et	3	main
natuke	doc_534729444737_item	2694900	et	4	main
essee	doc_534729444736_item	2694529	et	4	main
arutlev	doc_534729444736_item	2694537	et	4	main
lugemistekstis	doc_534729444736_item	2694544	et	3	main
faktidele	doc_534729444736_item	2694546	et	3	main
on	doc_534729444736_item	2694548	et	4	main
eestlaste	doc_534729444736_item	2694552	et	4	main
jaoks	doc_534729444736_item	2694553	et	4	main
see	doc_534729444736_item	2694558	et	3	main
kaks	doc_534729444736_item	2694571	et	3	main
hakkavad	doc_534729444736_item	2694581	et	4	main
lõppuriimiline	doc_534729444736_item	2694588	et	4	main
eestlased	doc_534729444736_item	2694589	et	3	main
said	doc_534729444736_item	2694590	et	4	main
panema	doc_534729444736_item	2694595	et	3	main
sellest	doc_534729444736_item	2694596	et	4	main
edasi	doc_534729444736_item	2694597	et	3	main
arenesid	doc_534729444736_item	2694598	et	4	main
laulud	doc_534729444736_item	2694599	et	3	main
neid	doc_534729444736_item	2694600	et	4	main
ühendas	doc_534729444736_item	2694601	et	3	main
üks	doc_534729444736_item	2694602	et	3	main
võim	doc_534729444736_item	2694603	et	3	main
mis	doc_534729444736_item	2694604	et	4	main
pani	doc_534729444736_item	2694605	et	4	main
neid	doc_534729444736_item	2694606	et	4	main
tegema	doc_534729444736_item	2694607	et	3	main
midagi	doc_534729444736_item	2694608	et	4	main
head	doc_534729444736_item	2694609	et	4	main
ja	doc_534729444736_item	2694610	et	3	main
uut	doc_534729444736_item	2694611	et	3	main
koos	doc_534729444736_item	2694612	et	4	main
juba	doc_534729444736_item	2694613	et	3	main
vanast	doc_534729444736_item	2694614	et	3	main
ajast	doc_534729444736_item	2694615	et	4	main
tuleb	doc_534729444736_item	2694616	et	3	main
see	doc_534729444736_item	2694617	et	3	main
traditsioon	doc_534729444736_item	2694618	et	3	main
midagi	doc_534729444736_item	2694619	et	4	main
koos	doc_534729444736_item	2694620	et	4	main
saa	doc_534729444736_item	2694624	et	4	main
peab	doc_534729444736_item	2694631	et	4	main
kellegiga	doc_534729444736_item	2694632	et	4	main
suhtlema	doc_534729444736_item	2694633	et	3	main
vaidlema	doc_534729444736_item	2694634	et	3	main
ja	doc_534729444736_item	2694638	et	3	main
väga	doc_534729444736_item	2694641	et	3	main
mis	doc_534729444736_item	2694644	et	4	main
sobiv	doc_534729444736_item	2694654	et	4	main
andma	doc_534729444736_item	2694659	et	3	main
edasi	doc_534729444736_item	2694665	et	3	main
rahvapeod	doc_534729444736_item	2694673	et	4	main
kuhu	doc_534729444736_item	2694674	et	3	main
tuldi	doc_534729444736_item	2694675	et	3	main
koos	doc_534729444736_item	2694676	et	4	main
sõbratega	doc_534729444736_item	2694678	et	4	main
oli	doc_534729444736_item	2694681	et	3	main
saada	doc_534729444736_item	2694684	et	4	main
essee	doc_534729444736_item	2694523	et	4	main
pikkus	doc_534729444736_item	2694530	et	4	main
analüüsiv	doc_534729444736_item	2694538	et	4	main
loengus	doc_534729444736_item	2694542	et	3	main
soovitatav	doc_534729444736_item	2694549	et	4	main
näidetega	doc_534729444736_item	2694551	et	3	main
tegevus	doc_534729444736_item	2694567	et	4	main
astet	doc_534729444736_item	2694572	et	4	main
regilaul	doc_534729444736_item	2694576	et	4	main
algriim	doc_534729444736_item	2694578	et	3	main
teha	doc_534729444736_item	2694621	et	3	main
hea	doc_534729444736_item	2694642	et	4	main
laulurahvaks	doc_534729444736_item	2694647	et	3	main
nad	doc_534729444736_item	2694648	et	3	main
leitsid	doc_534729444736_item	2694649	et	4	main
tegevuse	doc_534729444736_item	2694650	et	4	main
hakkasid	doc_534729444736_item	2694656	et	4	main
sellest	doc_534729444736_item	2694660	et	4	main
laulutraditsioonid	doc_534729444736_item	2694662	et	3	main
igasugused	doc_534729444736_item	2694663	et	3	main
hakkasid	doc_534729444736_item	2694666	et	4	main
laulupeod	doc_534729444736_item	2694668	et	4	main
olid	doc_534729444736_item	2694670	et	4	main
ka	doc_534729444736_item	2694671	et	3	main
uued	doc_534729444736_item	2694672	et	3	main
jägada	doc_534729444736_item	2694721	et	4	main
laulud	doc_534729444736_item	2694723	et	3	main
on	doc_534729444736_item	2694724	et	4	main
läbi	doc_534729444736_item	2694725	et	4	main
kujunenud	doc_534729444736_item	2694727	et	4	main
iga	doc_534729444736_item	2694730	et	4	main
inime	doc_534729444736_item	2694731	et	4	main
üle	doc_534729444736_item	2694737	et	3	main
jäi	doc_534729444736_item	2694744	et	3	main
üle	doc_534729444736_item	2694749	et	3	main
kuulus	doc_534729444736_item	2694751	et	4	main
rahval	doc_534729444736_item	2694753	et	3	main
vaimselt	doc_534729444736_item	2694761	et	4	main
peale	doc_534729444736_item	2694769	et	4	main
kuulsaid	doc_534729444736_item	2694775	et	3	main
eesti	doc_534729444736_item	2694776	et	4	main
ines	doc_534729444736_item	2694786	et	3	main
üks	doc_534729444736_item	2694790	et	3	main
analüüsiv	doc_534729444737_item	2694825	et	4	main
soovitatav	doc_534729444737_item	2694836	et	4	main
illustreerida	doc_534729444737_item	2694837	et	3	main
näidetega	doc_534729444737_item	2694838	et	3	main
juba	doc_534729444737_item	2694839	et	3	main
armastasid	doc_534729444737_item	2694843	et	4	main
laulda	doc_534729444737_item	2694846	et	4	main
tegid	doc_534729444737_item	2694848	et	4	main
kui	doc_534729444737_item	2694850	et	3	main
töötasid	doc_534729444737_item	2694851	et	4	main
laulda	doc_534729444737_item	2694858	et	4	main
maitsvat	doc_534729444737_item	2694870	et	4	main
puuvilju	doc_534729444737_item	2694871	et	3	main
ja	doc_534729444737_item	2694872	et	3	main
rahva	doc_534729444737_item	2694886	et	3	main
minevik	doc_534729444737_item	2694887	et	3	main
praegused	doc_534729444737_item	2694888	et	3	main
uurijad	doc_534729444737_item	2694889	et	4	main
kõige	doc_534729444737_item	2694922	et	4	main
esitasid	doc_534729444737_item	2694931	et	4	main
ta	doc_534729444737_item	2694939	et	4	main
on	doc_534729444737_item	2694959	et	4	main
olid	doc_534729444737_item	2694967	et	4	main
pillidega	doc_534729444737_item	2694989	et	3	main
eesti	doc_534729444737_item	2695003	et	4	main
eestlastel	doc_534729444737_item	2695017	et	4	main
oli	doc_534729444737_item	2695018	et	3	main
mingi	doc_534729444737_item	2695019	et	4	main
põhjus	doc_534729444737_item	2695020	et	4	main
teemal	doc_534729444736_item	2694524	et	3	main
mis	doc_534729444736_item	2694525	et	4	main
teeb	doc_534729444736_item	2694526	et	3	main
300	doc_534729444736_item	2694531	et	2	main
sõna	doc_534729444736_item	2694533	et	4	main
ja	doc_534729444736_item	2694539	et	3	main
üldistav	doc_534729444736_item	2694540	et	4	main
tuginema	doc_534729444736_item	2694541	et	3	main
esitatud	doc_534729444736_item	2694545	et	4	main
illustreerida	doc_534729444736_item	2694550	et	3	main
oluline	doc_534729444736_item	2694557	et	4	main
on	doc_534729444736_item	2694570	et	4	main
vanem	doc_534729444736_item	2694573	et	4	main
aste	doc_534729444736_item	2694585	et	4	main
riimi	doc_534729444736_item	2694593	et	4	main
inimene	doc_534729444736_item	2694622	et	3	main
kogu	doc_534729444736_item	2694626	et	4	main
elu	doc_534729444736_item	2694628	et	4	main
üksik	doc_534729444736_item	2694629	et	3	main
ta	doc_534729444736_item	2694630	et	4	main
peab	doc_534729444736_item	2694635	et	4	main
edasi	doc_534729444736_item	2694636	et	3	main
oli	doc_534729444736_item	2694640	et	3	main
mis	doc_534729444736_item	2694651	et	4	main
oli	doc_534729444736_item	2694652	et	3	main
kõikidele	doc_534729444736_item	2694653	et	4	main
edasi	doc_534729444736_item	2694658	et	3	main
arenesid	doc_534729444736_item	2694661	et	4	main
toimuma	doc_534729444736_item	2694667	et	3	main
mis	doc_534729444736_item	2694669	et	4	main
perega	doc_534729444736_item	2694677	et	3	main
ja	doc_534729444736_item	2694679	et	3	main
see	doc_534729444736_item	2694680	et	3	main
eeldus	doc_534729444736_item	2694683	et	4	main
kus	doc_534729444736_item	2694688	et	3	main
sai	doc_534729444736_item	2694689	et	4	main
kohata	doc_534729444736_item	2694690	et	4	main
oma	doc_534729444736_item	2694691	et	4	main
sugulasi	doc_534729444736_item	2694692	et	3	main
jne	doc_534729444736_item	2694693	et	4	main
eestlastest	doc_534729444736_item	2694694	et	4	main
teeb	doc_534729444736_item	2694695	et	3	main
laulurahvast	doc_534729444736_item	2694696	et	4	main
kõige	doc_534729444736_item	2694697	et	4	main
pealt	doc_534729444736_item	2694698	et	4	main
see	doc_534729444736_item	2694699	et	3	main
et	doc_534729444736_item	2694700	et	3	main
neil	doc_534729444736_item	2694701	et	4	main
on	doc_534729444736_item	2694702	et	4	main
tahe	doc_534729444736_item	2694703	et	4	main
midagi	doc_534729444736_item	2694704	et	4	main
teha	doc_534729444736_item	2694705	et	3	main
ja	doc_534729444736_item	2694706	et	3	main
sellega	doc_534729444736_item	2694707	et	3	main
kogeda	doc_534729444736_item	2694708	et	3	main
uusi	doc_534729444736_item	2694709	et	3	main
väljakutseid	doc_534729444736_item	2694710	et	3	main
neid	doc_534729444736_item	2694711	et	4	main
ühendab	doc_534729444736_item	2694712	et	3	main
üks	doc_534729444736_item	2694713	et	3	main
suur	doc_534729444736_item	2694714	et	3	main
vaimne	doc_534729444736_item	2694715	et	3	main
võim	doc_534729444736_item	2694716	et	3	main
mida	doc_534729444736_item	2694717	et	4	main
nad	doc_534729444736_item	2694718	et	3	main
enda	doc_534729444736_item	2694685	et	4	main
uusi	doc_534729444736_item	2694686	et	3	main
tuttavaid	doc_534729444736_item	2694687	et	3	main
saavad	doc_534729444736_item	2694719	et	4	main
teistega	doc_534729444736_item	2694720	et	4	main
nende	doc_534729444736_item	2694722	et	4	main
meil	doc_534729444736_item	2694741	et	4	main
vanadest	doc_534729444736_item	2694742	et	3	main
selline	doc_534729444736_item	2694745	et	4	main
maailma	doc_534729444736_item	2694750	et	4	main
igal	doc_534729444736_item	2694752	et	3	main
ühenda	doc_534729444736_item	2694760	et	4	main
nii	doc_534729444736_item	2694762	et	3	main
palju	doc_534729444736_item	2694763	et	4	main
rahvalaulu	doc_534729444736_item	2694770	et	4	main
lauljaid	doc_534729444736_item	2694777	et	4	main
maarja	doc_534729444736_item	2694787	et	3	main
tegigi	doc_534729444736_item	2694798	et	3	main
eestlastest	doc_534729444736_item	2694799	et	4	main
laulurahva	doc_534729444736_item	2694800	et	3	main
essee	doc_534729444737_item	2694801	et	4	main
eesti	doc_534729444737_item	2694802	et	4	main
keele	doc_534729444737_item	2694803	et	4	main
kui	doc_534729444737_item	2694804	et	3	main
teise	doc_534729444737_item	2694805	et	4	main
keele	doc_534729444737_item	2694806	et	4	main
test	doc_534729444737_item	2694807	et	3	main
kirjutage	doc_534729444737_item	2694809	et	3	main
kirjutamine	doc_534729444737_item	2694808	et	4	main
essee	doc_534729444737_item	2694810	et	4	main
teemal	doc_534729444737_item	2694811	et	3	main
mis	doc_534729444737_item	2694812	et	4	main
teeb	doc_534729444737_item	2694813	et	3	main
eestlastest	doc_534729444737_item	2694814	et	4	main
laulurahva	doc_534729444737_item	2694815	et	3	main
essee	doc_534729444737_item	2694816	et	4	main
pikkus	doc_534729444737_item	2694817	et	4	main
300	doc_534729444737_item	2694818	et	2	main
350	doc_534729444737_item	2694819	et	2	main
sõna	doc_534729444737_item	2694820	et	4	main
ja	doc_534729444737_item	2694826	et	3	main
loengus	doc_534729444737_item	2694829	et	3	main
inimesed	doc_534729444737_item	2694842	et	3	main
tantsida	doc_534729444737_item	2694844	et	3	main
pidutsesid	doc_534729444737_item	2694854	et	4	main
ühesõnaga	doc_534729444737_item	2694855	et	3	main
millal	doc_534729444737_item	2694856	et	3	main
võiks	doc_534729444737_item	2694857	et	4	main
metsades	doc_534729444737_item	2694863	et	3	main
ja	doc_534729444737_item	2694864	et	3	main
juurvilju	doc_534729444737_item	2694873	et	3	main
päikest	doc_534729444737_item	2694878	et	4	main
lauludes	doc_534729444737_item	2694880	et	3	main
ajaloo	doc_534729444737_item	2694897	et	4	main
vanem	doc_534729444737_item	2694923	et	4	main
eeslaulja	doc_534729444737_item	2694932	et	4	main
ja	doc_534729444737_item	2694933	et	3	main
koor	doc_534729444737_item	2694934	et	4	main
hakkab	doc_534729444737_item	2694940	et	3	main
laulma	doc_534729444737_item	2694941	et	3	main
kohe	doc_534729444737_item	2694942	et	4	main
koor	doc_534729444737_item	2694943	et	4	main
kordas	doc_534729444737_item	2694944	et	3	main
aja	doc_534729444736_item	2694726	et	4	main
rahvalikeks	doc_534729444736_item	2694728	et	3	main
sümboliteks	doc_534729444736_item	2694729	et	3	main
uhke	doc_534729444736_item	2694738	et	4	main
olema	doc_534729444736_item	2694739	et	4	main
et	doc_534729444736_item	2694740	et	3	main
mis	doc_534729444736_item	2694747	et	4	main
on	doc_534729444736_item	2694754	et	4	main
omad	doc_534729444736_item	2694755	et	4	main
traditsioonid	doc_534729444736_item	2694756	et	3	main
aga	doc_534729444736_item	2694757	et	3	main
nad	doc_534729444736_item	2694758	et	3	main
rahvast	doc_534729444736_item	2694764	et	4	main
nagu	doc_534729444736_item	2694765	et	3	main
eestlasi	doc_534729444736_item	2694766	et	3	main
meil	doc_534729444736_item	2694771	et	4	main
on	doc_534729444736_item	2694779	et	4	main
ninja	doc_534729444736_item	2694785	et	4	main
liis	doc_534729444736_item	2694788	et	3	main
tahe	doc_534729444736_item	2694791	et	4	main
ja	doc_534729444736_item	2694794	et	3	main
kokkusobivus	doc_534729444736_item	2694797	et	4	main
essee	doc_534729444737_item	2694821	et	4	main
olema	doc_534729444737_item	2694823	et	4	main
arutlev	doc_534729444737_item	2694824	et	4	main
tuginema	doc_534729444737_item	2694828	et	3	main
lugemistekstis	doc_534729444737_item	2694831	et	3	main
väiteid	doc_534729444737_item	2694834	et	4	main
on	doc_534729444737_item	2694835	et	4	main
ajal	doc_534729444737_item	2694841	et	4	main
ja	doc_534729444737_item	2694845	et	3	main
nad	doc_534729444737_item	2694847	et	3	main
seda	doc_534729444737_item	2694849	et	3	main
laulasid	doc_534729444737_item	2694860	et	4	main
ja	doc_534729444737_item	2694861	et	3	main
põlludes	doc_534729444737_item	2694865	et	4	main
palusid	doc_534729444737_item	2694866	et	4	main
jumalat	doc_534729444737_item	2694867	et	3	main
anda	doc_534729444737_item	2694868	et	3	main
või	doc_534729444737_item	2694876	et	4	main
nende	doc_534729444737_item	2694879	et	4	main
on	doc_534729444737_item	2694895	et	4	main
nagu	doc_534729444737_item	2694896	et	3	main
vana	doc_534729444737_item	2694901	et	4	main
lauludest	doc_534729444737_item	2694924	et	3	main
eesti	doc_534729444737_item	2694926	et	4	main
rahvalaul	doc_534729444737_item	2694928	et	4	main
seda	doc_534729444737_item	2694929	et	3	main
eeslaulja	doc_534729444737_item	2694935	et	4	main
mõtles	doc_534729444737_item	2694936	et	3	main
jne	doc_534729444737_item	2694964	et	4	main
need	doc_534729444737_item	2694965	et	3	main
laulud	doc_534729444737_item	2694966	et	3	main
ilma	doc_534729444737_item	2694972	et	4	main
riimiline	doc_534729444737_item	2694983	et	4	main
rahvalaul	doc_534729444737_item	2694991	et	4	main
regilaulust	doc_534729444737_item	2694993	et	4	main
et	doc_534729444737_item	2694995	et	3	main
esimesed	doc_534729444737_item	2695005	et	3	main
mis	doc_534729444737_item	2695011	et	4	main
palju	doc_534729444737_item	2695035	et	4	main
laulupidu	doc_534729444737_item	2695043	et	4	main
arvan	doc_534729444737_item	2695050	et	3	main
armastus	doc_534729444737_item	2695056	et	4	main
meeldib	doc_534729444737_item	2695072	et	3	main
laulumist	doc_534729444737_item	2695076	et	4	main
võib	doc_534729444737_item	2695078	et	3	main
näha	doc_534729444737_item	2695079	et	3	main
kuidas	doc_534729444737_item	2695080	et	3	main
muutub	doc_534729444737_item	2695081	et	3	main
inimese	doc_534729444737_item	2695082	et	4	main
ta	doc_534729444737_item	2695085	et	4	main
kurva	doc_534729444737_item	2695087	et	3	main
või	doc_534729444737_item	2695088	et	4	main
lõbusa	doc_534729444737_item	2695089	et	3	main
me	doc_534729444737_item	2695100	et	4	main
nukrad	doc_534729444737_item	2695102	et	3	main
peab	doc_534729444737_item	2694822	et	4	main
üldistav	doc_534729444737_item	2694827	et	4	main
ja	doc_534729444737_item	2694830	et	3	main
esitatud	doc_534729444737_item	2694832	et	4	main
või	doc_534729444737_item	2694852	et	4	main
kui	doc_534729444737_item	2694853	et	3	main
nad	doc_534729444737_item	2694859	et	3	main
tantsisid	doc_534729444737_item	2694862	et	4	main
palusid	doc_534729444737_item	2694874	et	4	main
vihma	doc_534729444737_item	2694875	et	4	main
proovivad	doc_534729444737_item	2694890	et	4	main
tutvuda	doc_534729444737_item	2694891	et	3	main
rahvaluulega	doc_534729444737_item	2694892	et	3	main
ja	doc_534729444737_item	2694893	et	3	main
see	doc_534729444737_item	2694894	et	3	main
eestlaste	doc_534729444737_item	2694902	et	4	main
loomingust	doc_534729444737_item	2694903	et	3	main
võib	doc_534729444737_item	2694904	et	3	main
alustada	doc_534729444737_item	2694905	et	3	main
sellest	doc_534729444737_item	2694906	et	4	main
et	doc_534729444737_item	2694907	et	3	main
eesti	doc_534729444737_item	2694908	et	4	main
folkloor	doc_534729444737_item	2694909	et	4	main
koosneb	doc_534729444737_item	2694910	et	3	main
kolmast	doc_534729444737_item	2694911	et	3	main
osast	doc_534729444737_item	2694912	et	4	main
esimene	doc_534729444737_item	2694913	et	3	main
osa	doc_534729444737_item	2694914	et	4	main
on	doc_534729444737_item	2694915	et	4	main
laul	doc_534729444737_item	2694916	et	4	main
teine	doc_534729444737_item	2694917	et	3	main
tants	doc_534729444737_item	2694918	et	3	main
ja	doc_534729444737_item	2694919	et	3	main
kolmas	doc_534729444737_item	2694920	et	3	main
pillimäng	doc_534729444737_item	2694921	et	3	main
regivärsiline	doc_534729444737_item	2694927	et	4	main
laulu	doc_534729444737_item	2694930	et	4	main
sellest	doc_534729444737_item	2694937	et	4	main
lause	doc_534729444737_item	2694946	et	4	main
vokaalsed	doc_534729444737_item	2694968	et	3	main
ja	doc_534729444737_item	2694969	et	3	main
pillideta	doc_534729444737_item	2694973	et	3	main
ilmus	doc_534729444737_item	2694976	et	4	main
rahvalaulu	doc_534729444737_item	2694978	et	4	main
rahvalaule	doc_534729444737_item	2694986	et	4	main
lauldi	doc_534729444737_item	2694987	et	3	main
riimiline	doc_534729444737_item	2694990	et	4	main
erineb	doc_534729444737_item	2694992	et	3	main
sellega	doc_534729444737_item	2694994	et	3	main
sellel	doc_534729444737_item	2694996	et	4	main
rahvalaulul	doc_534729444737_item	2694997	et	3	main
on	doc_534729444737_item	2694998	et	4	main
kirjalik	doc_534729444737_item	2694999	et	3	main
ülestähendus	doc_534729444737_item	2695000	et	3	main
need	doc_534729444737_item	2695001	et	3	main
laulud	doc_534729444737_item	2695006	et	3	main
võib	doc_534729444737_item	2695009	et	3	main
eestlastest	doc_534729444737_item	2695013	et	4	main
laulurahva	doc_534729444737_item	2695014	et	3	main
minu	doc_534729444737_item	2695015	et	3	main
arust	doc_534729444737_item	2695016	et	4	main
võib	doc_534729444737_item	2695028	et	3	main
on	doc_534729444737_item	2694925	et	4	main
mida	doc_534729444737_item	2694938	et	4	main
mis	doc_534729444737_item	2694947	et	4	main
eeslaulja	doc_534729444737_item	2694948	et	4	main
sel	doc_534729444737_item	2694950	et	3	main
ütles	doc_534729444737_item	2694949	et	3	main
ajal	doc_534729444737_item	2694951	et	4	main
eeslaulja	doc_534729444737_item	2694952	et	4	main
mõtleb	doc_534729444737_item	2694953	et	3	main
välja	doc_534729444737_item	2694954	et	4	main
seda	doc_534729444737_item	2694945	et	3	main
lause	doc_534729444737_item	2694956	et	4	main
lauldud	doc_534729444737_item	2694960	et	4	main
üksi	doc_534729444737_item	2694961	et	4	main
kahekesi	doc_534729444737_item	2694962	et	3	main
kooriga	doc_534729444737_item	2694963	et	4	main
lauldi	doc_534729444737_item	2694971	et	3	main
19	doc_534729444737_item	2694974	et	2	main
rahvalaul	doc_534729444737_item	2694984	et	4	main
riimilisi	doc_534729444737_item	2694985	et	4	main
rahva	doc_534729444737_item	2695004	et	3	main
nüüd	doc_534729444737_item	2695008	et	4	main
küsida	doc_534729444737_item	2695010	et	3	main
teeb	doc_534729444737_item	2695012	et	3	main
laulda	doc_534729444737_item	2695021	et	4	main
see	doc_534729444737_item	2695023	et	3	main
väga	doc_534729444737_item	2695025	et	3	main
väga	doc_534729444737_item	2695030	et	3	main
laulupidusid	doc_534729444737_item	2695036	et	4	main
seganud	doc_534729444737_item	2695046	et	4	main
sõda	doc_534729444737_item	2695048	et	4	main
ma	doc_534729444737_item	2695049	et	3	main
oma	doc_534729444737_item	2695053	et	4	main
teevad	doc_534729444737_item	2695068	et	3	main
laulda	doc_534729444737_item	2695073	et	4	main
kui	doc_534729444737_item	2695084	et	3	main
on	doc_534729444737_item	2695093	et	4	main
kui	doc_534729444737_item	2695123	et	3	main
laulma	doc_534729444737_item	2695127	et	3	main
teised	doc_534729444737_item	2695129	et	4	main
kohe	doc_534729444737_item	2695130	et	4	main
inimesed	doc_534729444737_item	2695138	et	3	main
usklikud	doc_534729444737_item	2695141	et	3	main
ja	doc_534729444737_item	2695143	et	3	main
inimeste	doc_534729444737_item	2695145	et	3	main
iseloom	doc_534729444737_item	2695146	et	3	main
pidusi	doc_534729444737_item	2695154	et	4	main
ja	doc_534729444737_item	2695163	et	3	main
teise	doc_534729444737_item	2694955	et	4	main
neid	doc_534729444737_item	2694957	et	4	main
laulu	doc_534729444737_item	2694958	et	4	main
seda	doc_534729444737_item	2694970	et	3	main
sajandil	doc_534729444737_item	2694975	et	3	main
uus	doc_534729444737_item	2694977	et	3	main
laulmine	doc_534729444737_item	2694979	et	4	main
viis	doc_534729444737_item	2694980	et	4	main
see	doc_534729444737_item	2694981	et	3	main
oli	doc_534729444737_item	2694982	et	3	main
juba	doc_534729444737_item	2694988	et	3	main
on	doc_534729444737_item	2695002	et	4	main
ja	doc_534729444737_item	2695007	et	3	main
nendele	doc_534729444737_item	2695022	et	4	main
tegevus	doc_534729444737_item	2695024	et	4	main
meeldis	doc_534729444737_item	2695026	et	3	main
sellest	doc_534729444737_item	2695027	et	4	main
julgelt	doc_534729444737_item	2695031	et	4	main
eestlasid	doc_534729444737_item	2695033	et	4	main
ja	doc_534729444737_item	2695037	et	3	main
toimumist	doc_534729444737_item	2695044	et	4	main
armastus	doc_534729444737_item	2695052	et	4	main
isamaa	doc_534729444737_item	2695054	et	4	main
sugulaste	doc_534729444737_item	2695058	et	4	main
parem	doc_534729444737_item	2695062	et	4	main
kui	doc_534729444737_item	2695063	et	3	main
praegu	doc_534729444737_item	2695064	et	3	main
armastus	doc_534729444737_item	2695065	et	4	main
ja	doc_534729444737_item	2695074	et	3	main
laulu	doc_534729444737_item	2695090	et	4	main
on	doc_534729444737_item	2695098	et	4	main
vana	doc_534729444737_item	2695105	et	4	main
inimestel	doc_534729444737_item	2695107	et	3	main
polnud	doc_534729444737_item	2695108	et	3	main
nii	doc_534729444737_item	2695109	et	3	main
aga	doc_534729444737_item	2695122	et	3	main
ütlevad	doc_534729444737_item	2695131	et	4	main
et	doc_534729444737_item	2695132	et	3	main
sul	doc_534729444737_item	2695133	et	3	main
peaga	doc_534729444737_item	2695134	et	3	main
enne	doc_534729444737_item	2695137	et	4	main
laulurahva	doc_534729444737_item	2695149	et	3	main
rohkem	doc_534729444737_item	2695153	et	4	main
selleks	doc_534729444737_item	2695158	et	4	main
et	doc_534729444737_item	2695159	et	3	main
inimesed	doc_534729444737_item	2695160	et	3	main
oma	doc_534729444737_item	2695161	et	4	main
vanavanaisade	doc_534729444737_item	2695162	et	3	main
saab	doc_534729444737_item	2695170	et	3	main
laulurahvas	doc_534729444737_item	2695173	et	4	main
ütelda	doc_534729444737_item	2695029	et	4	main
sest	doc_534729444737_item	2695032	et	4	main
tegid	doc_534729444737_item	2695034	et	4	main
oma	doc_534729444737_item	2695057	et	4	main
loodamine	doc_534729444737_item	2695060	et	4	main
elama	doc_534729444737_item	2695061	et	3	main
vastu	doc_534729444737_item	2695067	et	3	main
eestlastest	doc_534729444737_item	2695069	et	4	main
inimestele	doc_534729444737_item	2695071	et	3	main
kuulata	doc_534729444737_item	2695075	et	4	main
kohe	doc_534729444737_item	2695077	et	4	main
tuju	doc_534729444737_item	2695083	et	4	main
kuleb	doc_534729444737_item	2695086	et	4	main
meie	doc_534729444737_item	2695094	et	4	main
hing	doc_534729444737_item	2695095	et	3	main
kui	doc_534729444737_item	2695096	et	3	main
muusika	doc_534729444737_item	2695097	et	4	main
oleme	doc_534729444737_item	2695101	et	3	main
ja	doc_534729444737_item	2695103	et	3	main
kui	doc_534729444737_item	2695112	et	3	main
meil	doc_534729444737_item	2695113	et	4	main
praegu	doc_534729444737_item	2695114	et	3	main
vanad	doc_534729444737_item	2695115	et	3	main
eestlased	doc_534729444737_item	2695116	et	3	main
laulasid	doc_534729444737_item	2695117	et	4	main
töötades	doc_534729444737_item	2695118	et	3	main
mängides	doc_534729444737_item	2695119	et	4	main
pulmades	doc_534729444737_item	2695120	et	3	main
matustes	doc_534729444737_item	2695121	et	3	main
praegu	doc_534729444737_item	2695125	et	3	main
lahked	doc_534729444737_item	2695140	et	3	main
abivalmis	doc_534729444737_item	2695142	et	3	main
me	doc_534729444737_item	2695150	et	4	main
tegema	doc_534729444737_item	2695152	et	3	main
ja	doc_534729444737_item	2695156	et	3	main
emade	doc_534729444737_item	2695164	et	3	main
praegune	doc_534729444737_item	2695167	et	3	main
lainesid	doc_534729444737_item	2695038	et	4	main
need	doc_534729444737_item	2695039	et	3	main
rohkem	doc_534729444737_item	2695040	et	4	main
ja	doc_534729444737_item	2695041	et	3	main
rohkem	doc_534729444737_item	2695042	et	4	main
ei	doc_534729444737_item	2695045	et	4	main
isegi	doc_534729444737_item	2695047	et	4	main
et	doc_534729444737_item	2695051	et	3	main
vastu	doc_534729444737_item	2695055	et	3	main
vastu	doc_534729444737_item	2695059	et	3	main
looduse	doc_534729444737_item	2695066	et	4	main
laulurahva	doc_534729444737_item	2695070	et	3	main
muusika	doc_534729444737_item	2695091	et	4	main
see	doc_534729444737_item	2695092	et	3	main
kurb	doc_534729444737_item	2695099	et	3	main
teistpidi	doc_534729444737_item	2695104	et	3	main
ajal	doc_534729444737_item	2695106	et	4	main
palju	doc_534729444737_item	2695110	et	4	main
probleeme	doc_534729444737_item	2695111	et	3	main
on	doc_534729444737_item	2695135	et	4	main
olid	doc_534729444737_item	2695139	et	4	main
selline	doc_534729444737_item	2695144	et	4	main
tegi	doc_534729444737_item	2695147	et	4	main
eestlastest	doc_534729444737_item	2695148	et	4	main
peame	doc_534729444737_item	2695151	et	4	main
laulupidusi	doc_534729444737_item	2695155	et	4	main
rahvatantsu	doc_534729444737_item	2695157	et	4	main
meeleolu	doc_534729444737_item	2695165	et	4	main
rahvas	doc_534729444737_item	2695169	et	4	main
olla	doc_534729444737_item	2695171	et	3	main
ka	doc_534729444737_item	2695172	et	3	main
nagu	doc_534729444737_item	2695174	et	3	main
vanasti	doc_534729444737_item	2695175	et	3	main
meie	doc_534729444737_item	2695124	et	4	main
hakkame	doc_534729444737_item	2695126	et	3	main
õues	doc_534729444737_item	2695128	et	4	main
probleemid	doc_534729444737_item	2695136	et	3	main
siis	doc_534729444737_item	2695166	et	3	main
eesti	doc_534729444737_item	2695168	et	4	main
mis	doc_534729444739_item	2695528	et	4	main
teeb	doc_534729444739_item	2695529	et	3	main
peab	doc_534729444739_item	2695538	et	4	main
olema	doc_534729444739_item	2695539	et	4	main
ja	doc_534729444739_item	2695546	et	3	main
pidudes	doc_534729444739_item	2695566	et	4	main
tegevus	doc_534729444739_item	2695576	et	4	main
laulupidu	doc_534729444739_item	2695583	et	4	main
koos	doc_534729444739_item	2695587	et	4	main
perega	doc_534729444739_item	2695588	et	3	main
lootuses	doc_534729444739_item	2695589	et	4	main
üle	doc_534729444739_item	2695597	et	3	main
mis	doc_534729444739_item	2695610	et	4	main
on	doc_534729444739_item	2695615	et	4	main
aja	doc_534729444739_item	2695617	et	4	main
kujunenud	doc_534729444739_item	2695618	et	4	main
rahvuslikeks	doc_534729444739_item	2695619	et	3	main
sümboliteks	doc_534729444739_item	2695620	et	3	main
teise	doc_534729444739_item	2695521	et	4	main
test	doc_534729444739_item	2695523	et	3	main
tuginema	doc_534729444739_item	2695544	et	3	main
loengus	doc_534729444739_item	2695545	et	3	main
esitatud	doc_534729444739_item	2695548	et	4	main
faktidele	doc_534729444739_item	2695549	et	3	main
väiteid	doc_534729444739_item	2695550	et	4	main
me	doc_534729444739_item	2695564	et	4	main
tantsime	doc_534729444739_item	2695565	et	3	main
on	doc_534729444739_item	2695568	et	4	main
emotsionaalne	doc_534729444739_item	2695571	et	3	main
ka	doc_534729444739_item	2695574	et	3	main
kõik	doc_534729444739_item	2695577	et	4	main
teavad	doc_534729444739_item	2695579	et	3	main
mis	doc_534729444739_item	2695580	et	4	main
on	doc_534729444739_item	2695581	et	4	main
rahva	doc_534729444739_item	2695582	et	3	main
me	doc_534729444739_item	2695585	et	4	main
kuulame	doc_534729444739_item	2695612	et	4	main
läbi	doc_534729444739_item	2695616	et	4	main
on	doc_534729444739_item	2695631	et	4	main
rahvuslik	doc_534729444739_item	2695632	et	3	main
identiteeditunne	doc_534729444739_item	2695633	et	3	main
ja	doc_534729444739_item	2695634	et	3	main
mis	doc_534729444739_item	2695638	et	4	main
pärinevad	doc_534729444739_item	2695640	et	4	main
folkloorist	doc_534729444739_item	2695641	et	4	main
ning	doc_534729444739_item	2695642	et	3	main
saavutamiseks	doc_534729444739_item	2695648	et	4	main
või	doc_534729444739_item	2695664	et	4	main
eestlastest	doc_534729444739_item	2695677	et	4	main
kõigepealt	doc_534729444739_item	2695680	et	3	main
nende	doc_534729444739_item	2695683	et	4	main
kultuur	doc_534729444739_item	2695684	et	3	main
seoutud	doc_534729444739_item	2695685	et	4	main
kuidas	doc_534729444739_item	2695690	et	3	main
euroopas	doc_534729444739_item	2695694	et	3	main
laulupeod	doc_534729444739_item	2695703	et	4	main
tähtsamad	doc_534729444739_item	2695706	et	4	main
itaalia	doc_534729444739_item	2695712	et	4	main
olemas	doc_534729444739_item	2695715	et	4	main
muidugi	doc_534729444739_item	2695716	et	4	main
essee	doc_534729444739_item	2695517	et	4	main
eesti	doc_534729444739_item	2695518	et	4	main
keele	doc_534729444739_item	2695519	et	4	main
kui	doc_534729444739_item	2695520	et	3	main
keele	doc_534729444739_item	2695522	et	4	main
essee	doc_534729444739_item	2695537	et	4	main
üldistav	doc_534729444739_item	2695543	et	4	main
lugemistekstis	doc_534729444739_item	2695547	et	3	main
üksi	doc_534729444739_item	2695561	et	4	main
see	doc_534729444739_item	2695567	et	3	main
ja	doc_534729444739_item	2695570	et	3	main
aga	doc_534729444739_item	2695573	et	3	main
kohata	doc_534729444739_item	2695590	et	4	main
sõpru	doc_534729444739_item	2695591	et	3	main
sugulasi	doc_534729444739_item	2695592	et	3	main
pidu	doc_534729444739_item	2695607	et	4	main
need	doc_534729444739_item	2695608	et	3	main
laulud	doc_534729444739_item	2695609	et	3	main
kultuur	doc_534729444739_item	2695635	et	3	main
algselt	doc_534729444739_item	2695639	et	4	main
rakendatud	doc_534729444739_item	2695645	et	4	main
kooris	doc_534729444739_item	2695665	et	4	main
aga	doc_534729444739_item	2695666	et	3	main
poistekoor	doc_534729444739_item	2695673	et	4	main
teeb	doc_534729444739_item	2695678	et	3	main
see	doc_534729444739_item	2695681	et	3	main
kultuuriloaga	doc_534729444739_item	2695688	et	4	main
aga	doc_534729444739_item	2695689	et	3	main
me	doc_534729444739_item	2695691	et	4	main
teame	doc_534729444739_item	2695693	et	3	main
kõige	doc_534729444739_item	2695705	et	4	main
eestlastest	doc_534729444739_item	2695530	et	4	main
laulurahva	doc_534729444739_item	2695531	et	3	main
essee	doc_534729444739_item	2695532	et	4	main
pikkus	doc_534729444739_item	2695533	et	4	main
300	doc_534729444739_item	2695534	et	2	main
350	doc_534729444739_item	2695535	et	2	main
analüüsiv	doc_534729444739_item	2695541	et	4	main
ja	doc_534729444739_item	2695542	et	3	main
soovitatav	doc_534729444739_item	2695552	et	4	main
laulame	doc_534729444739_item	2695560	et	4	main
või	doc_534729444739_item	2695562	et	4	main
kooris	doc_534729444739_item	2695563	et	4	main
esteetiline	doc_534729444739_item	2695569	et	3	main
väljendusvahed	doc_534729444739_item	2695572	et	3	main
sotsiaalne	doc_534729444739_item	2695575	et	3	main
eestlased	doc_534729444739_item	2695578	et	3	main
ja	doc_534729444739_item	2695593	et	3	main
tuttavaid	doc_534729444739_item	2695594	et	3	main
kes	doc_534729444739_item	2695595	et	4	main
kogu	doc_534729444739_item	2695598	et	4	main
me	doc_534729444739_item	2695611	et	4	main
see	doc_534729444739_item	2695621	et	3	main
on	doc_534729444739_item	2695626	et	4	main
meie	doc_534729444739_item	2695627	et	4	main
kultuur	doc_534729444739_item	2695628	et	3	main
üsna	doc_534729444739_item	2695629	et	3	main
sageli	doc_534729444739_item	2695630	et	3	main
sümbolitele	doc_534729444739_item	2695637	et	3	main
kindla	doc_534729444739_item	2695646	et	3	main
eesmärgi	doc_534729444739_item	2695647	et	4	main
laulsid	doc_534729444739_item	2695658	et	4	main
naised	doc_534729444739_item	2695659	et	3	main
lapsed	doc_534729444739_item	2695660	et	3	main
laulsid	doc_534729444739_item	2695661	et	4	main
üksi	doc_534729444739_item	2695662	et	4	main
kahekesi	doc_534729444739_item	2695663	et	3	main
ka	doc_534729444739_item	2695672	et	3	main
mõtlen	doc_534729444739_item	2695675	et	3	main
laulurahva	doc_534729444739_item	2695679	et	3	main
et	doc_534729444739_item	2695682	et	3	main
nende	doc_534729444739_item	2695702	et	4	main
või	doc_534729444739_item	2695711	et	4	main
on	doc_534729444739_item	2695714	et	4	main
venemaa	doc_534729444739_item	2695728	et	4	main
on	doc_534729444739_item	2695729	et	4	main
palju	doc_534729444739_item	2695736	et	4	main
tuli	doc_534729444739_item	2695749	et	4	main
johann	doc_534729444739_item	2695753	et	4	main
jannseniga	doc_534729444739_item	2695755	et	4	main
saamine	doc_534729444739_item	2695772	et	4	main
keerukaks	doc_534729444739_item	2695775	et	3	main
eestlaste	doc_534729444739_item	2695780	et	4	main
laulupeoga	doc_534729444739_item	2695786	et	4	main
võin	doc_534729444739_item	2695790	et	3	main
et	doc_534729444739_item	2695792	et	3	main
teeb	doc_534729444739_item	2695794	et	3	main
keele	doc_534729444740_item	2695801	et	4	main
kui	doc_534729444740_item	2695802	et	3	main
kirjutage	doc_534729444740_item	2695807	et	3	main
faktidele	doc_534729444740_item	2695831	et	3	main
on	doc_534729444740_item	2695833	et	4	main
eestlastest	doc_534729444740_item	2695839	et	4	main
suvi	doc_534729444740_item	2695841	et	3	main
on	doc_534729444740_item	2695848	et	4	main
üsna	doc_534729444740_item	2695849	et	3	main
ja	doc_534729444740_item	2695857	et	3	main
laul	doc_534729444740_item	2695903	et	4	main
mehed	doc_534729444740_item	2695909	et	3	main
sai	doc_534729444740_item	2695929	et	4	main
inimesed	doc_534729444740_item	2695938	et	3	main
väga	doc_534729444740_item	2695942	et	3	main
paremini	doc_534729444740_item	2695948	et	4	main
läheks	doc_534729444740_item	2695949	et	3	main
kirjutamine	doc_534729444739_item	2695524	et	4	main
kirjutage	doc_534729444739_item	2695525	et	3	main
essee	doc_534729444739_item	2695526	et	4	main
teemal	doc_534729444739_item	2695527	et	3	main
sõna	doc_534729444739_item	2695536	et	4	main
arutlev	doc_534729444739_item	2695540	et	4	main
on	doc_534729444739_item	2695551	et	4	main
illustreerida	doc_534729444739_item	2695553	et	3	main
näidetega	doc_534729444739_item	2695554	et	3	main
laulmine	doc_534729444739_item	2695555	et	4	main
aitab	doc_534729444739_item	2695556	et	3	main
inimestele	doc_534729444739_item	2695557	et	3	main
palju	doc_534729444739_item	2695558	et	4	main
me	doc_534729444739_item	2695559	et	4	main
seal	doc_534729444739_item	2695584	et	4	main
tuleme	doc_534729444739_item	2695586	et	3	main
on	doc_534729444739_item	2695596	et	4	main
maailma	doc_534729444739_item	2695599	et	4	main
kokku	doc_534729444739_item	2695600	et	3	main
sõitnud	doc_534729444739_item	2695601	et	4	main
jah	doc_534729444739_item	2695602	et	3	main
see	doc_534729444739_item	2695603	et	3	main
on	doc_534729444739_item	2695604	et	4	main
tõesti	doc_534729444739_item	2695605	et	3	main
suur	doc_534729444739_item	2695606	et	3	main
sellel	doc_534729444739_item	2695613	et	4	main
pidul	doc_534729444739_item	2695614	et	3	main
on	doc_534729444739_item	2695622	et	4	main
eesti	doc_534729444739_item	2695623	et	4	main
see	doc_534729444739_item	2695625	et	3	main
mida	doc_534729444739_item	2695643	et	4	main
linnas	doc_534729444739_item	2695655	et	4	main
maal	doc_534729444739_item	2695657	et	4	main
ma	doc_534729444739_item	2695674	et	3	main
et	doc_534729444739_item	2695676	et	3	main
palju	doc_534729444739_item	2695686	et	4	main
on	doc_534729444739_item	2695704	et	4	main
teine	doc_534729444739_item	2695717	et	3	main
arvamus	doc_534729444739_item	2695718	et	3	main
mõtlen	doc_534729444739_item	2695719	et	3	main
et	doc_534729444739_item	2695720	et	3	main
eestlased	doc_534729444739_item	2695721	et	3	main
laulavad	doc_534729444739_item	2695735	et	4	main
kujunes	doc_534729444739_item	2695740	et	3	main
laulupidu	doc_534729444739_item	2695743	et	4	main
korraldamise	doc_534729444739_item	2695745	et	4	main
idee	doc_534729444739_item	2695746	et	4	main
ja	doc_534729444739_item	2695747	et	3	main
seitse	doc_534729444739_item	2695757	et	3	main
üldlaulupidu	doc_534729444739_item	2695759	et	4	main
venemaa	doc_534729444739_item	2695768	et	4	main
koosseisus	doc_534729444739_item	2695769	et	4	main
kus	doc_534729444739_item	2695770	et	3	main
kõik	doc_534729444739_item	2695776	et	4	main
faktid	doc_534729444739_item	2695778	et	3	main
palju	doc_534729444739_item	2695783	et	4	main
selle	doc_534729444739_item	2695787	et	4	main
ma	doc_534729444739_item	2695789	et	3	main
essee	doc_534729444740_item	2695799	et	4	main
test	doc_534729444740_item	2695805	et	3	main
mis	doc_534729444740_item	2695810	et	4	main
pikkus	doc_534729444740_item	2695815	et	4	main
ja	doc_534729444740_item	2695828	et	3	main
väiteid	doc_534729444740_item	2695832	et	4	main
tänavatel	doc_534729444740_item	2695847	et	4	main
palju	doc_534729444740_item	2695850	et	4	main
rahvast	doc_534729444740_item	2695851	et	4	main
inimesed	doc_534729444740_item	2695852	et	3	main
rahvariietes	doc_534729444740_item	2695853	et	3	main
lähevad	doc_534729444740_item	2695854	et	3	main
isegi	doc_534729444740_item	2695858	et	4	main
on	doc_534729444740_item	2695866	et	4	main
eesti	doc_534729444740_item	2695873	et	4	main
siis	doc_534729444740_item	2695912	et	3	main
tegevus	doc_534729444740_item	2695915	et	4	main
kui	doc_534729444740_item	2695920	et	3	main
aastat	doc_534729444740_item	2695922	et	3	main
oli	doc_534729444740_item	2695924	et	3	main
regivärsiline	doc_534729444740_item	2695926	et	4	main
rahvalaul	doc_534729444740_item	2695927	et	4	main
millest	doc_534729444740_item	2695928	et	3	main
sugulaste	doc_534729444740_item	2695935	et	4	main
kaudu	doc_534729444740_item	2695936	et	3	main
lauldes	doc_534729444740_item	2695937	et	3	main
töötasid	doc_534729444740_item	2695944	et	4	main
ning	doc_534729444740_item	2695945	et	3	main
et	doc_534729444740_item	2695946	et	3	main
töö	doc_534729444740_item	2695947	et	4	main
nad	doc_534729444740_item	2695959	et	3	main
oma	doc_534729444740_item	2695963	et	4	main
milles	doc_534729444740_item	2695965	et	3	main
rolli	doc_534729444740_item	2695983	et	4	main
mängis	doc_534729444740_item	2695984	et	3	main
kombeid	doc_534729444740_item	2695989	et	4	main
alguses	doc_534729444740_item	2695997	et	4	main
kiiremini	doc_534729444740_item	2696022	et	4	main
kultuur	doc_534729444739_item	2695624	et	3	main
rajatud	doc_534729444739_item	2695636	et	4	main
on	doc_534729444739_item	2695644	et	4	main
muusikaseltse	doc_534729444739_item	2695649	et	3	main
loodi	doc_534729444739_item	2695650	et	4	main
baltisaksa	doc_534729444739_item	2695651	et	4	main
kogukonna	doc_534729444739_item	2695652	et	4	main
eeskuju	doc_534729444739_item	2695653	et	4	main
nii	doc_534729444739_item	2695654	et	3	main
kui	doc_534729444739_item	2695656	et	3	main
ilma	doc_534729444739_item	2695667	et	4	main
muusika	doc_534729444739_item	2695668	et	4	main
instrumente	doc_534729444739_item	2695669	et	3	main
hiljem	doc_534729444739_item	2695670	et	3	main
tekkis	doc_534729444739_item	2695671	et	3	main
euroopa	doc_534729444739_item	2695687	et	4	main
kõik	doc_534729444739_item	2695692	et	4	main
on	doc_534729444739_item	2695695	et	4	main
palju	doc_534729444739_item	2695696	et	4	main
rikke	doc_534729444739_item	2695697	et	3	main
kus	doc_534729444739_item	2695698	et	3	main
inimesed	doc_534729444739_item	2695699	et	3	main
laulavad	doc_534729444739_item	2695700	et	4	main
ja	doc_534729444739_item	2695701	et	3	main
aga	doc_534729444739_item	2695713	et	3	main
võtsid	doc_534729444739_item	2695722	et	4	main
ka	doc_534729444739_item	2695724	et	3	main
nende	doc_534729444739_item	2695730	et	4	main
naabrid	doc_534729444739_item	2695731	et	3	main
venemaal	doc_534729444739_item	2695732	et	4	main
1869	doc_534729444739_item	2695737	et	2	main
ülemaaline	doc_534729444739_item	2695742	et	4	main
mille	doc_534729444739_item	2695744	et	3	main
vanemuise	doc_534729444739_item	2695750	et	4	main
seltsist	doc_534729444739_item	2695751	et	4	main
voldemar	doc_534729444739_item	2695754	et	4	main
esimest	doc_534729444739_item	2695758	et	4	main
mil	doc_534729444739_item	2695760	et	4	main
eestlased	doc_534729444739_item	2695761	et	3	main
võitlesid	doc_534729444739_item	2695762	et	4	main
osutus	doc_534729444739_item	2695773	et	4	main
lauluajaloost	doc_534729444739_item	2695781	et	4	main
on	doc_534729444739_item	2695782	et	4	main
öelda	doc_534729444739_item	2695791	et	4	main
eesti	doc_534729444740_item	2695800	et	4	main
teemal	doc_534729444740_item	2695809	et	3	main
eestlastest	doc_534729444740_item	2695812	et	4	main
300	doc_534729444740_item	2695816	et	2	main
olema	doc_534729444740_item	2695821	et	4	main
analüüsiv	doc_534729444740_item	2695823	et	4	main
esitatud	doc_534729444740_item	2695830	et	4	main
näidetega	doc_534729444740_item	2695836	et	3	main
soe	doc_534729444740_item	2695845	et	4	main
mööda	doc_534729444740_item	2695855	et	4	main
teed	doc_534729444740_item	2695856	et	4	main
muidugi	doc_534729444740_item	2695867	et	4	main
täna	doc_534729444740_item	2695868	et	4	main
lemmikutest	doc_534729444740_item	2695874	et	4	main
töö	doc_534729444740_item	2695906	et	4	main
töötasid	doc_534729444740_item	2695911	et	4	main
nende	doc_534729444740_item	2695914	et	4	main
oli	doc_534729444740_item	2695916	et	3	main
tagasi	doc_534729444740_item	2695923	et	3	main
teada	doc_534729444740_item	2695930	et	3	main
rütmi	doc_534729444740_item	2695940	et	4	main
palju	doc_534729444740_item	2695943	et	4	main
rahvas	doc_534729444740_item	2695953	et	4	main
usus	doc_534729444740_item	2695954	et	3	main
paljudesse	doc_534729444740_item	2695955	et	3	main
igale	doc_534729444740_item	2695961	et	3	main
laulu	doc_534729444740_item	2695964	et	4	main
palusid	doc_534729444740_item	2695966	et	4	main
et	doc_534729444740_item	2695967	et	3	main
oleks	doc_534729444740_item	2695968	et	3	main
rikkas	doc_534729444740_item	2695974	et	4	main
hea	doc_534729444740_item	2695978	et	4	main
igal	doc_534729444740_item	2695980	et	3	main
on	doc_534729444740_item	2695987	et	4	main
mehed	doc_534729444740_item	2695993	et	3	main
ja	doc_534729444739_item	2695707	et	3	main
olulisemad	doc_534729444739_item	2695708	et	4	main
näiteks	doc_534729444739_item	2695709	et	4	main
prantsusmaa	doc_534729444739_item	2695710	et	4	main
palju	doc_534729444739_item	2695723	et	4	main
venemaalt	doc_534729444739_item	2695725	et	3	main
sest	doc_534729444739_item	2695726	et	4	main
geograafiliselt	doc_534729444739_item	2695727	et	4	main
inimesed	doc_534729444739_item	2695733	et	3	main
aastal	doc_534729444739_item	2695738	et	3	main
tartus	doc_534729444739_item	2695739	et	3	main
esimene	doc_534729444739_item	2695741	et	3	main
eesotsas	doc_534729444739_item	2695752	et	4	main
oma	doc_534729444739_item	2695763	et	4	main
loa	doc_534729444739_item	2695771	et	4	main
aeganõudvalt	doc_534729444739_item	2695774	et	4	main
sündmusi	doc_534729444739_item	2695784	et	3	main
seotud	doc_534729444739_item	2695785	et	4	main
pärast	doc_534729444739_item	2695788	et	4	main
see	doc_534729444739_item	2695793	et	3	main
eestlastest	doc_534729444739_item	2695795	et	4	main
laulurahva	doc_534729444739_item	2695796	et	3	main
laulame	doc_534729444739_item	2695797	et	4	main
teise	doc_534729444740_item	2695803	et	4	main
kirjutamine	doc_534729444740_item	2695806	et	4	main
teeb	doc_534729444740_item	2695811	et	3	main
laulurahva	doc_534729444740_item	2695813	et	3	main
ka	doc_534729444739_item	2695734	et	3	main
teostus	doc_534729444739_item	2695748	et	4	main
aga	doc_534729444739_item	2695756	et	3	main
tunnustamise	doc_534729444739_item	2695764	et	4	main
eest	doc_534729444739_item	2695765	et	4	main
korraldati	doc_534729444739_item	2695766	et	3	main
tsaristliku	doc_534729444739_item	2695767	et	3	main
need	doc_534729444739_item	2695777	et	3	main
räägivad	doc_534729444739_item	2695779	et	3	main
koos	doc_534729444739_item	2695798	et	4	main
keele	doc_534729444740_item	2695804	et	4	main
essee	doc_534729444740_item	2695808	et	4	main
essee	doc_534729444740_item	2695814	et	4	main
350	doc_534729444740_item	2695817	et	2	main
sõna	doc_534729444740_item	2695818	et	4	main
essee	doc_534729444740_item	2695819	et	4	main
peab	doc_534729444740_item	2695820	et	4	main
arutlev	doc_534729444740_item	2695822	et	4	main
ja	doc_534729444740_item	2695824	et	3	main
üldistav	doc_534729444740_item	2695825	et	4	main
tuginema	doc_534729444740_item	2695826	et	3	main
loengus	doc_534729444740_item	2695827	et	3	main
soovitatav	doc_534729444740_item	2695834	et	4	main
teeb	doc_534729444740_item	2695838	et	3	main
õues	doc_534729444740_item	2695842	et	4	main
on	doc_534729444740_item	2695843	et	4	main
väga	doc_534729444740_item	2695844	et	3	main
ei	doc_534729444740_item	2695860	et	4	main
neid	doc_534729444740_item	2695862	et	4	main
mis	doc_534729444740_item	2695863	et	4	main
päev	doc_534729444740_item	2695864	et	3	main
on	doc_534729444740_item	2695869	et	4	main
ju	doc_534729444740_item	2695870	et	3	main
elu	doc_534729444740_item	2695901	et	4	main
esimeseks	doc_534729444740_item	2695902	et	3	main
osa	doc_534729444740_item	2695907	et	4	main
kui	doc_534729444740_item	2695908	et	3	main
iga	doc_534729444740_item	2695913	et	4	main
esitatud	doc_534729444740_item	2695917	et	4	main
lauluga	doc_534729444740_item	2695918	et	4	main
tuhat	doc_534729444740_item	2695921	et	4	main
iga	doc_534729444740_item	2695931	et	4	main
põlvkond	doc_534729444740_item	2695932	et	3	main
oma	doc_534729444740_item	2695933	et	4	main
rõhutasid	doc_534729444740_item	2695939	et	4	main
laulsid	doc_534729444740_item	2695951	et	4	main
eesti	doc_534729444740_item	2695952	et	4	main
seepärast	doc_534729444740_item	2695958	et	3	main
loomad	doc_534729444740_item	2695975	et	3	main
ilm	doc_534729444740_item	2695977	et	3	main
eestlastel	doc_534729444740_item	2695986	et	4	main
ja	doc_534729444740_item	2695990	et	3	main
laulsid	doc_534729444740_item	2695995	et	4	main
põhjus	doc_534729444740_item	2696030	et	4	main
et	doc_534729444740_item	2696031	et	3	main
on	doc_534729444740_item	2696035	et	4	main
et	doc_534729444740_item	2696037	et	3	main
ajalood	doc_534729444740_item	2696039	et	4	main
võib	doc_534729444740_item	2696040	et	3	main
folkloorisse	doc_534729444740_item	2696048	et	4	main
ja	doc_534729444740_item	2696049	et	3	main
paljud	doc_534729444740_item	2696050	et	3	main
heliloojad	doc_534729444740_item	2696051	et	3	main
hakkasid	doc_534729444740_item	2696052	et	4	main
kasutama	doc_534729444740_item	2696053	et	3	main
eestilt	doc_534729444740_item	2696067	et	3	main
laulupidu	doc_534729444740_item	2696069	et	4	main
eesti	doc_534729444740_item	2696073	et	4	main
rahvas	doc_534729444740_item	2696074	et	4	main
midagi	doc_534729444740_item	2696081	et	4	main
katkeda	doc_534729444740_item	2696086	et	3	main
on	doc_534729444740_item	2696088	et	4	main
arhiividest	doc_534729444740_item	2696095	et	3	main
rahvalaule	doc_534729444740_item	2696096	et	4	main
eesti	doc_534729444740_item	2696098	et	4	main
vaim	doc_534729444740_item	2696099	et	3	main
elaks	doc_534729444740_item	2696100	et	3	main
on	doc_534729444740_item	2696106	et	4	main
lugemistekstis	doc_534729444740_item	2695829	et	3	main
illustreerida	doc_534729444740_item	2695835	et	3	main
mis	doc_534729444740_item	2695837	et	4	main
laulurahva	doc_534729444740_item	2695840	et	3	main
ja	doc_534729444740_item	2695846	et	3	main
ühistransport	doc_534729444740_item	2695859	et	3	main
sega	doc_534729444740_item	2695861	et	4	main
täna	doc_534729444740_item	2695865	et	4	main
laulupidu	doc_534729444740_item	2695871	et	4	main
üks	doc_534729444740_item	2695872	et	3	main
üritusest	doc_534729444740_item	2695875	et	4	main
see	doc_534729444740_item	2695876	et	3	main
on	doc_534729444740_item	2695877	et	4	main
väga	doc_534729444740_item	2695878	et	3	main
vana	doc_534729444740_item	2695879	et	4	main
traditsioon	doc_534729444740_item	2695880	et	3	main
mis	doc_534729444740_item	2695881	et	4	main
võtab	doc_534729444740_item	2695882	et	3	main
alguse	doc_534729444740_item	2695883	et	3	main
1869	doc_534729444740_item	2695884	et	2	main
aastal	doc_534729444740_item	2695885	et	3	main
eestlased	doc_534729444740_item	2695886	et	3	main
on	doc_534729444740_item	2695887	et	4	main
küll	doc_534729444740_item	2695888	et	4	main
laulurahvas	doc_534729444740_item	2695889	et	4	main
laul	doc_534729444740_item	2695890	et	4	main
aitab	doc_534729444740_item	2695891	et	3	main
neid	doc_534729444740_item	2695892	et	4	main
lapsepõlvest	doc_534729444740_item	2695893	et	4	main
hauani	doc_534729444740_item	2695894	et	3	main
ning	doc_534729444740_item	2695895	et	3	main
nendes	doc_534729444740_item	2695896	et	4	main
lauldes	doc_534729444740_item	2695897	et	3	main
on	doc_534729444740_item	2695898	et	4	main
kogu	doc_534729444740_item	2695899	et	4	main
eesti	doc_534729444740_item	2695900	et	4	main
on	doc_534729444740_item	2695904	et	4	main
iga	doc_534729444740_item	2695905	et	4	main
vanasti	doc_534729444740_item	2695910	et	3	main
enam	doc_534729444740_item	2695919	et	4	main
kujunenud	doc_534729444740_item	2695925	et	4	main
vanemate	doc_534729444740_item	2695934	et	4	main
talumehed	doc_534729444740_item	2695941	et	3	main
ja	doc_534729444740_item	2695957	et	3	main
hea	doc_534729444740_item	2695969	et	4	main
vili	doc_534729444740_item	2695970	et	3	main
et	doc_534729444740_item	2695971	et	3	main
maa	doc_534729444740_item	2695972	et	4	main
terved	doc_534729444740_item	2695976	et	4	main
teiseks	doc_534729444740_item	2695979	et	4	main
pidutsemisel	doc_534729444740_item	2695981	et	4	main
suurt	doc_534729444740_item	2695982	et	3	main
palju	doc_534729444740_item	2695988	et	4	main
näiteks	doc_534729444740_item	2695992	et	4	main
igal	doc_534729444740_item	2695998	et	3	main
esines	doc_534729444740_item	2696000	et	3	main
koor	doc_534729444740_item	2696001	et	4	main
ja	doc_534729444740_item	2696002	et	3	main
esilaulja	doc_534729444740_item	2696003	et	4	main
pärast	doc_534729444740_item	2696004	et	4	main
rahvamuusikale	doc_534729444740_item	2696005	et	4	main
pöörati	doc_534729444740_item	2696006	et	3	main
rohkem	doc_534729444740_item	2696007	et	4	main
tähelepanu	doc_534729444740_item	2696008	et	4	main
ja	doc_534729444740_item	2696009	et	3	main
neid	doc_534729444740_item	2696010	et	4	main
laule	doc_534729444740_item	2696011	et	4	main
hakati	doc_534729444740_item	2696012	et	3	main
üles	doc_534729444740_item	2696013	et	3	main
kirjutada	doc_534729444740_item	2696014	et	3	main
salmikutesse	doc_534729444740_item	2696015	et	3	main
emad	doc_534729444740_item	2696016	et	3	main
oma	doc_534729444740_item	2696018	et	4	main
lastele	doc_534729444740_item	2696019	et	4	main
laulsid	doc_534729444740_item	2696017	et	4	main
et	doc_534729444740_item	2696020	et	3	main
magaks	doc_534729444740_item	2696023	et	3	main
sest	doc_534729444740_item	2696024	et	4	main
eestlased	doc_534729444740_item	2696032	et	3	main
nende	doc_534729444740_item	2696038	et	4	main
vaadata	doc_534729444740_item	2696041	et	4	main
laulude	doc_534729444740_item	2696042	et	3	main
sajandil	doc_534729444740_item	2696058	et	3	main
korraldati	doc_534729444740_item	2696059	et	3	main
ka	doc_534729444740_item	2696060	et	3	main
laulupidusid	doc_534729444740_item	2696061	et	4	main
kus	doc_534729444740_item	2696062	et	3	main
esinesid	doc_534729444740_item	2696063	et	4	main
on	doc_534729444740_item	2696075	et	4	main
ei	doc_534729444740_item	2696082	et	4	main
vaimu	doc_534729444740_item	2696085	et	4	main
otsivad	doc_534729444740_item	2696094	et	4	main
laule	doc_534729444740_item	2696112	et	4	main
nad	doc_534729444740_item	2695950	et	3	main
jumalatesse	doc_534729444740_item	2695956	et	3	main
laulsid	doc_534729444740_item	2695960	et	4	main
jumalale	doc_534729444740_item	2695962	et	3	main
oleks	doc_534729444740_item	2695973	et	3	main
laul	doc_534729444740_item	2695985	et	4	main
traditsioone	doc_534729444740_item	2695991	et	3	main
alati	doc_534729444740_item	2695994	et	4	main
pulmadel	doc_534729444740_item	2695996	et	3	main
peol	doc_534729444740_item	2695999	et	4	main
nad	doc_534729444740_item	2696021	et	3	main
laulurahvas	doc_534729444740_item	2696034	et	4	main
hoolikalt	doc_534729444740_item	2696046	et	4	main
suhtusid	doc_534729444740_item	2696047	et	4	main
loomingus	doc_534729444740_item	2696056	et	3	main
19	doc_534729444740_item	2696057	et	2	main
seda	doc_534729444740_item	2696071	et	3	main
kihnu	doc_534729444740_item	2696102	et	4	main
ja	doc_534729444740_item	2696104	et	3	main
tähtpäeval	doc_534729444740_item	2696115	et	3	main
igal	doc_534729444740_item	2696121	et	3	main
isegi	doc_534729444740_item	2696131	et	4	main
inimesi	doc_534729444740_item	2696144	et	4	main
naabreid	doc_534729444740_item	2696152	et	3	main
eestist	doc_534729444740_item	2696154	et	3	main
laulupeol	doc_534729444740_item	2696167	et	4	main
minevikust	doc_534729444740_item	2696172	et	3	main
aitasid	doc_534729444740_item	2696178	et	4	main
ajal	doc_534729444740_item	2696184	et	4	main
need	doc_534729444740_item	2696188	et	3	main
tulevikusse	doc_534729444740_item	2696192	et	4	main
eestlased	doc_534729444740_item	2696199	et	3	main
kogu	doc_534729444740_item	2696200	et	4	main
see	doc_534729444740_item	2696205	et	3	main
tõesti	doc_534729444740_item	2696207	et	3	main
essee	doc_534729444741_item	2696209	et	4	main
eestlastest	doc_534729444741_item	2696222	et	4	main
essee	doc_534729444741_item	2696224	et	4	main
sõna	doc_534729444741_item	2696228	et	4	main
peab	doc_534729444741_item	2696230	et	4	main
ja	doc_534729444741_item	2696238	et	3	main
väiteid	doc_534729444741_item	2696242	et	4	main
soovitatav	doc_534729444741_item	2696244	et	4	main
mis	doc_534729444741_item	2696254	et	4	main
läheb	doc_534729444741_item	2696255	et	3	main
oma	doc_534729444741_item	2696291	et	4	main
nad	doc_534729444741_item	2696296	et	3	main
osa	doc_534729444741_item	2696299	et	4	main
igalpool	doc_534729444741_item	2696310	et	4	main
kodus	doc_534729444741_item	2696311	et	4	main
töötades	doc_534729444741_item	2696312	et	3	main
rohkem	doc_534729444741_item	2696319	et	4	main
olid	doc_534729444740_item	2696026	et	4	main
meloodilised	doc_534729444740_item	2696027	et	3	main
veel	doc_534729444740_item	2696028	et	4	main
üks	doc_534729444740_item	2696029	et	3	main
järgi	doc_534729444740_item	2696043	et	4	main
eestlased	doc_534729444740_item	2696044	et	3	main
väga	doc_534729444740_item	2696045	et	3	main
rahvalaule	doc_534729444740_item	2696054	et	4	main
kogu	doc_534729444740_item	2696066	et	4	main
koos	doc_534729444740_item	2696076	et	4	main
traditsioonid	doc_534729444740_item	2696077	et	3	main
veel	doc_534729444740_item	2696078	et	4	main
elavad	doc_534729444740_item	2696079	et	4	main
ja	doc_534729444740_item	2696080	et	3	main
nende	doc_534729444740_item	2696084	et	4	main
eestlased	doc_534729444740_item	2696087	et	3	main
laulurahvas	doc_534729444740_item	2696089	et	4	main
sest	doc_534729444740_item	2696090	et	4	main
meie	doc_534729444740_item	2696091	et	4	main
ajani	doc_534729444740_item	2696092	et	3	main
folkloristid	doc_534729444740_item	2696093	et	3	main
kauem	doc_534729444740_item	2696101	et	4	main
jäänud	doc_534729444740_item	2696107	et	4	main
igal	doc_534729444740_item	2696114	et	3	main
peavad	doc_534729444740_item	2696116	et	4	main
vanu	doc_534729444740_item	2696117	et	4	main
kombeid	doc_534729444740_item	2696118	et	4	main
viljandis	doc_534729444740_item	2696119	et	4	main
toimub	doc_534729444740_item	2696120	et	3	main
muusikafestivaal	doc_534729444740_item	2696123	et	4	main
oli	doc_534729444740_item	2696128	et	3	main
kogunevad	doc_534729444740_item	2696145	et	4	main
oma	doc_534729444740_item	2696151	et	4	main
rahvas	doc_534729444740_item	2696160	et	4	main
jälgib	doc_534729444740_item	2696161	et	3	main
traditsioone	doc_534729444740_item	2696162	et	3	main
igal	doc_534729444740_item	2696163	et	3	main
aastal	doc_534729444740_item	2696164	et	3	main
ma	doc_534729444740_item	2696165	et	3	main
käin	doc_534729444740_item	2696166	et	3	main
ma	doc_534729444740_item	2696185	et	3	main
usun	doc_534729444740_item	2696186	et	3	main
laulud	doc_534729444740_item	2696189	et	3	main
elu	doc_534729444740_item	2696202	et	4	main
laulavad	doc_534729444740_item	2696203	et	4	main
teeb	doc_534729444741_item	2696221	et	3	main
350	doc_534729444741_item	2696227	et	2	main
loengus	doc_534729444741_item	2696237	et	3	main
esitatud	doc_534729444741_item	2696240	et	4	main
oma	doc_534729444741_item	2696252	et	4	main
kultuur	doc_534729444741_item	2696253	et	3	main
suur	doc_534729444741_item	2696258	et	3	main
ajal	doc_534729444741_item	2696282	et	4	main
kurb	doc_534729444741_item	2696286	et	3	main
inimesed	doc_534729444741_item	2696289	et	3	main
tundeid	doc_534729444741_item	2696294	et	3	main
ennast	doc_534729444741_item	2696300	et	4	main
sündib	doc_534729444741_item	2696304	et	4	main
vanal	doc_534729444741_item	2696306	et	3	main
rahvalaul	doc_534729444741_item	2696316	et	4	main
on	doc_534729444741_item	2696317	et	4	main
tuhat	doc_534729444741_item	2696321	et	4	main
tagasi	doc_534729444741_item	2696323	et	3	main
rahvalaulaks	doc_534729444741_item	2696325	et	4	main
peetakse	doc_534729444741_item	2696326	et	3	main
regilaul	doc_534729444741_item	2696327	et	4	main
siit	doc_534729444741_item	2696328	et	3	main
algab	doc_534729444741_item	2696329	et	3	main
ajalugu	doc_534729444741_item	2696330	et	4	main
tehti	doc_534729444741_item	2696341	et	3	main
seda	doc_534729444741_item	2696342	et	3	main
eeslaulja	doc_534729444741_item	2696343	et	4	main
ja	doc_534729444741_item	2696344	et	3	main
erines	doc_534729444741_item	2696371	et	3	main
ka	doc_534729444741_item	2696376	et	3	main
kirik	doc_534729444741_item	2696378	et	3	main
eestis	doc_534729444741_item	2696386	et	3	main
laulud	doc_534729444740_item	2696025	et	3	main
on	doc_534729444740_item	2696033	et	4	main
see	doc_534729444740_item	2696036	et	3	main
oma	doc_534729444740_item	2696055	et	4	main
koorid	doc_534729444740_item	2696064	et	4	main
üle	doc_534729444740_item	2696065	et	3	main
iga	doc_534729444740_item	2696068	et	4	main
tähendas	doc_534729444740_item	2696070	et	3	main
et	doc_534729444740_item	2696072	et	3	main
saa	doc_534729444740_item	2696083	et	4	main
et	doc_534729444740_item	2696097	et	3	main
saarel	doc_534729444740_item	2696103	et	3	main
lõuna-eestis	doc_534729444740_item	2696105	et	3	main
kes	doc_534729444740_item	2696109	et	4	main
mäletavad	doc_534729444740_item	2696110	et	4	main
eesti	doc_534729444740_item	2696111	et	4	main
näiteks	doc_534729444740_item	2696124	et	4	main
selle	doc_534729444740_item	2696125	et	4	main
muusika	doc_534729444740_item	2696130	et	4	main
pop-muusika	doc_534729444740_item	2696132	et	4	main
seotud	doc_534729444740_item	2696134	et	4	main
rahvalauludega	doc_534729444740_item	2696135	et	3	main
ja	doc_534729444740_item	2696136	et	3	main
tänapäevased	doc_534729444740_item	2696137	et	4	main
noored	doc_534729444740_item	2696138	et	3	main
tuhat	doc_534729444740_item	2696143	et	4	main
vaadata	doc_534729444740_item	2696150	et	4	main
kogu	doc_534729444740_item	2696153	et	4	main
rahvariided	doc_534729444740_item	2696155	et	3	main
laulud	doc_534729444740_item	2696170	et	3	main
sellest	doc_534729444740_item	2696175	et	4	main
kuidas	doc_534729444740_item	2696176	et	3	main
nad	doc_534729444740_item	2696177	et	3	main
nii	doc_534729444740_item	2696179	et	3	main
heal	doc_534729444740_item	2696180	et	3	main
kui	doc_534729444740_item	2696181	et	3	main
ka	doc_534729444740_item	2696182	et	3	main
halval	doc_534729444740_item	2696183	et	3	main
ei	doc_534729444740_item	2696195	et	4	main
oma	doc_534729444740_item	2696201	et	4	main
300	doc_534729444741_item	2696226	et	2	main
olema	doc_534729444741_item	2696231	et	4	main
analüüsiv	doc_534729444741_item	2696233	et	4	main
üldistav	doc_534729444741_item	2696235	et	4	main
on	doc_534729444741_item	2696251	et	4	main
minevikku	doc_534729444741_item	2696257	et	4	main
eesti	doc_534729444741_item	2696260	et	4	main
seisneb	doc_534729444741_item	2696262	et	3	main
laulmises	doc_534729444741_item	2696263	et	4	main
mõtteid	doc_534729444741_item	2696292	et	3	main
nagu	doc_534729444741_item	2696297	et	3	main
niimodi	doc_534729444741_item	2696302	et	4	main
ajalugu	doc_534729444741_item	2696305	et	4	main
tegemas	doc_534729444741_item	2696315	et	3	main
kui	doc_534729444741_item	2696320	et	3	main
eestlastest	doc_534729444741_item	2696333	et	4	main
laulurahva	doc_534729444741_item	2696334	et	3	main
koor	doc_534729444741_item	2696345	et	4	main
tihti	doc_534729444741_item	2696346	et	3	main
lauldi	doc_534729444741_item	2696347	et	3	main
laulsid	doc_534729444741_item	2696358	et	4	main
pulmadel	doc_534729444741_item	2696359	et	3	main
ja	doc_534729444741_item	2696360	et	3	main
rahvalaul	doc_534729444741_item	2696369	et	4	main
täiesti	doc_534729444741_item	2696370	et	3	main
rahvalaulu	doc_534729444741_item	2696380	et	4	main
ning	doc_534729444741_item	2696383	et	3	main
osa	doc_534729444741_item	2696385	et	4	main
nagu	doc_534729444741_item	2696391	et	3	main
peale	doc_534729444741_item	2696394	et	4	main
kapp	doc_534729444741_item	2696412	et	3	main
inimesed	doc_534729444740_item	2696108	et	3	main
ja	doc_534729444740_item	2696113	et	3	main
aastal	doc_534729444740_item	2696122	et	3	main
suve	doc_534729444740_item	2696126	et	4	main
teema	doc_534729444740_item	2696127	et	4	main
võivad	doc_534729444740_item	2696139	et	4	main
seda	doc_534729444740_item	2696140	et	3	main
laulda	doc_534729444740_item	2696141	et	4	main
lauluväljakul	doc_534729444740_item	2696146	et	3	main
et	doc_534729444740_item	2696147	et	3	main
kuulata	doc_534729444740_item	2696148	et	4	main
ja	doc_534729444740_item	2696149	et	3	main
need	doc_534729444740_item	2696169	et	3	main
räägivad	doc_534729444740_item	2696174	et	3	main
inimestega	doc_534729444740_item	2696191	et	3	main
sest	doc_534729444740_item	2696193	et	4	main
laulurahvas	doc_534729444740_item	2696194	et	4	main
nendeta	doc_534729444740_item	2696198	et	4	main
ja	doc_534729444740_item	2696204	et	3	main
laulurahva	doc_534729444741_item	2696223	et	3	main
pikkus	doc_534729444741_item	2696225	et	4	main
essee	doc_534729444741_item	2696229	et	4	main
arutlev	doc_534729444741_item	2696232	et	4	main
tuginema	doc_534729444741_item	2696236	et	3	main
lugemistekstis	doc_534729444741_item	2696239	et	3	main
on	doc_534729444741_item	2696243	et	4	main
rahvasel	doc_534729444741_item	2696250	et	4	main
laulmine	doc_534729444741_item	2696264	et	4	main
kui	doc_534729444741_item	2696285	et	3	main
laulades	doc_534729444741_item	2696288	et	3	main
ja	doc_534729444741_item	2696293	et	3	main
pärandavad	doc_534729444741_item	2696298	et	4	main
laulades	doc_534729444741_item	2696303	et	3	main
ajal	doc_534729444741_item	2696307	et	4	main
eestlased	doc_534729444741_item	2696308	et	3	main
laulsid	doc_534729444741_item	2696309	et	4	main
põllul	doc_534729444741_item	2696313	et	3	main
käsitöö	doc_534729444741_item	2696314	et	4	main
mis	doc_534729444741_item	2696331	et	4	main
teeb	doc_534729444741_item	2696332	et	3	main
esitati	doc_534729444741_item	2696336	et	4	main
vokaalsel	doc_534729444741_item	2696338	et	3	main
viisil	doc_534729444741_item	2696339	et	4	main
koos	doc_534729444741_item	2696348	et	4	main
liikumisega	doc_534729444741_item	2696349	et	4	main
uuem	doc_534729444741_item	2696368	et	4	main
andis	doc_534729444741_item	2696374	et	3	main
uuema	doc_534729444741_item	2696379	et	4	main
lõppriim	doc_534729444741_item	2696382	et	3	main
bajaan	doc_534729444741_item	2696392	et	3	main
rahvalaule	doc_534729444741_item	2696406	et	4	main
saar	doc_534729444741_item	2696410	et	3	main
kogu	doc_534729444741_item	2696415	et	4	main
kultuuri	doc_534729444741_item	2696417	et	4	main
ka	doc_534729444741_item	2696418	et	3	main
muusikat	doc_534729444741_item	2696419	et	3	main
toimus	doc_534729444741_item	2696426	et	3	main
lõuna-	doc_534729444741_item	2696436	et	4	main
ja	doc_534729444741_item	2696437	et	3	main
lääne-eestis	doc_534729444741_item	2696438	et	3	main
kus	doc_534729444741_item	2696439	et	3	main
linna	doc_534729444741_item	2696443	et	4	main
folkloori	doc_534729444741_item	2696445	et	4	main
kasutatakse	doc_534729444741_item	2696446	et	3	main
ka	doc_534729444741_item	2696447	et	3	main
praeguses	doc_534729444741_item	2696448	et	3	main
pop-muusikas	doc_534729444741_item	2696449	et	3	main
ja	doc_534729444741_item	2696450	et	3	main
paljudes	doc_534729444741_item	2696451	et	3	main
eesti	doc_534729444741_item	2696452	et	4	main
rahvamuusika	doc_534729444741_item	2696456	et	4	main
folk	doc_534729444741_item	2696460	et	4	main
eesti	doc_534729444741_item	2696469	et	4	main
eesti	doc_534729444741_item	2696473	et	4	main
rahvaseks	doc_534729444741_item	2696474	et	4	main
laulmiseta	doc_534729444741_item	2696476	et	4	main
teebki	doc_534729444741_item	2696478	et	3	main
laulurahva	doc_534729444741_item	2696480	et	3	main
mis	doc_534729444742_item	2696492	et	4	main
pikkus	doc_534729444742_item	2696497	et	4	main
350	doc_534729444742_item	2696499	et	2	main
torupilli	doc_534729444740_item	2696129	et	4	main
on	doc_534729444740_item	2696133	et	4	main
mitu	doc_534729444740_item	2696142	et	4	main
sümboliseerivad	doc_534729444740_item	2696156	et	4	main
seda	doc_534729444740_item	2696157	et	3	main
et	doc_534729444740_item	2696158	et	3	main
eesti	doc_534729444740_item	2696159	et	4	main
sest	doc_534729444740_item	2696168	et	4	main
tulevad	doc_534729444740_item	2696171	et	4	main
ja	doc_534729444740_item	2696173	et	3	main
et	doc_534729444740_item	2696187	et	3	main
lähevad	doc_534729444740_item	2696190	et	3	main
saa	doc_534729444740_item	2696196	et	4	main
ilma	doc_534729444740_item	2696197	et	4	main
on	doc_534729444740_item	2696206	et	4	main
tore	doc_534729444740_item	2696208	et	3	main
eesti	doc_534729444741_item	2696210	et	4	main
keele	doc_534729444741_item	2696211	et	4	main
kui	doc_534729444741_item	2696212	et	3	main
teise	doc_534729444741_item	2696213	et	4	main
keele	doc_534729444741_item	2696214	et	4	main
test	doc_534729444741_item	2696215	et	3	main
kirjutamine	doc_534729444741_item	2696216	et	4	main
kirjutage	doc_534729444741_item	2696217	et	3	main
essee	doc_534729444741_item	2696218	et	4	main
teemal	doc_534729444741_item	2696219	et	3	main
mis	doc_534729444741_item	2696220	et	4	main
ja	doc_534729444741_item	2696234	et	3	main
faktidele	doc_534729444741_item	2696241	et	3	main
illustreerida	doc_534729444741_item	2696245	et	3	main
näidetega	doc_534729444741_item	2696246	et	3	main
eestlastel	doc_534729444741_item	2696247	et	4	main
nagu	doc_534729444741_item	2696248	et	3	main
igal	doc_534729444741_item	2696249	et	3	main
kaugesse	doc_534729444741_item	2696256	et	3	main
osa	doc_534729444741_item	2696259	et	4	main
kultuuri	doc_534729444741_item	2696261	et	4	main
oli	doc_534729444741_item	2696265	et	3	main
on	doc_534729444741_item	2696266	et	4	main
ja	doc_534729444741_item	2696267	et	3	main
jääb	doc_534729444741_item	2696268	et	3	main
alati	doc_534729444741_item	2696269	et	4	main
tähtsaks	doc_534729444741_item	2696270	et	4	main
eestlastele	doc_534729444741_item	2696271	et	4	main
sest	doc_534729444741_item	2696272	et	4	main
just	doc_534729444741_item	2696273	et	3	main
laulmine	doc_534729444741_item	2696274	et	4	main
on	doc_534729444741_item	2696275	et	4	main
saatnud	doc_534729444741_item	2696276	et	4	main
inimesi	doc_534729444741_item	2696277	et	4	main
nii	doc_534729444741_item	2696278	et	3	main
halval	doc_534729444741_item	2696279	et	3	main
kui	doc_534729444741_item	2696280	et	3	main
heal	doc_534729444741_item	2696281	et	3	main
nii	doc_534729444741_item	2696283	et	3	main
rõõmustades	doc_534729444741_item	2696284	et	3	main
olles	doc_534729444741_item	2696287	et	3	main
väljendavad	doc_534729444741_item	2696290	et	4	main
sellega	doc_534729444741_item	2696295	et	3	main
teistele	doc_534729444741_item	2696301	et	4	main
sündinud	doc_534729444741_item	2696318	et	4	main
esimeseks	doc_534729444741_item	2696324	et	3	main
regilaulu	doc_534729444741_item	2696335	et	4	main
ainult	doc_534729444741_item	2696337	et	4	main
muusika	doc_534729444741_item	2696367	et	4	main
regilaulust	doc_534729444741_item	2696372	et	4	main
pillid	doc_534729444741_item	2696390	et	4	main
ema-lapse	doc_534729444741_item	2696399	et	4	main
laul	doc_534729444741_item	2696400	et	4	main
xix	doc_534729444741_item	2696401	et	4	main
sajandil	doc_534729444741_item	2696402	et	3	main
oma	doc_534729444741_item	2696407	et	4	main
ja	doc_534729444741_item	2696411	et	3	main
eestlaste	doc_534729444741_item	2696420	et	4	main
rahvasliku	doc_534729444741_item	2696421	et	4	main
kõrghetk	doc_534729444741_item	2696423	et	3	main
üldlaulupidu	doc_534729444741_item	2696428	et	4	main
kulda	doc_534729444741_item	2696435	et	4	main
eriti	doc_534729444741_item	2696442	et	3	main
ka	doc_534729444741_item	2696455	et	3	main
rahvas	doc_534729444741_item	2696470	et	4	main
oleks	doc_534729444741_item	2696472	et	3	main
see	doc_534729444741_item	2696477	et	3	main
teise	doc_534729444742_item	2696485	et	4	main
essee	doc_534729444742_item	2696501	et	4	main
üldistav	doc_534729444742_item	2696507	et	4	main
tuginema	doc_534729444742_item	2696508	et	3	main
ja	doc_534729444742_item	2696510	et	3	main
muljest	doc_534729444742_item	2696534	et	4	main
ja	doc_534729444742_item	2696535	et	3	main
ajaloost	doc_534729444742_item	2696556	et	4	main
sellest	doc_534729444742_item	2696559	et	4	main
teada	doc_534729444742_item	2696605	et	3	main
lauldi	doc_534729444742_item	2696609	et	3	main
põllul	doc_534729444742_item	2696621	et	3	main
marju	doc_534729444742_item	2696631	et	3	main
endale	doc_534729444742_item	2696637	et	4	main
et	doc_534729444742_item	2696639	et	3	main
pulmas	doc_534729444742_item	2696640	et	3	main
jaoks	doc_534729444742_item	2696643	et	4	main
meeste	doc_534729444742_item	2696644	et	4	main
muutusid	doc_534729444742_item	2696648	et	4	main
toimuma	doc_534729444742_item	2696656	et	3	main
oli	doc_534729444742_item	2696668	et	3	main
pani	doc_534729444742_item	2696672	et	4	main
korraldamisele	doc_534729444742_item	2696676	et	4	main
tolel	doc_534729444742_item	2696677	et	4	main
juulis	doc_534729444742_item	2696700	et	3	main
ja	doc_534729444742_item	2696704	et	3	main
hulgas	doc_534729444742_item	2696715	et	4	main
eestlane	doc_534729444742_item	2696719	et	3	main
rahva	doc_534729444742_item	2696723	et	3	main
rahvalaulud	doc_534729444742_item	2696728	et	3	main
rikas	doc_534729444742_item	2696755	et	4	main
et	doc_534729444742_item	2696760	et	3	main
eestis	doc_534729444742_item	2696775	et	3	main
palju	doc_534729444742_item	2696787	et	4	main
ilusaid	doc_534729444742_item	2696788	et	3	main
aastat	doc_534729444741_item	2696322	et	3	main
tavaliselt	doc_534729444741_item	2696340	et	4	main
tööd	doc_534729444741_item	2696350	et	4	main
tehes	doc_534729444741_item	2696351	et	3	main
ja	doc_534729444741_item	2696352	et	3	main
kodus	doc_534729444741_item	2696353	et	4	main
laulsid	doc_534729444741_item	2696354	et	4	main
peamiselt	doc_534729444741_item	2696355	et	4	main
naised	doc_534729444741_item	2696356	et	3	main
mehed	doc_534729444741_item	2696357	et	3	main
teistel	doc_534729444741_item	2696361	et	4	main
pidudel	doc_534729444741_item	2696362	et	4	main
muutub	doc_534729444741_item	2696363	et	3	main
aeg	doc_534729444741_item	2696364	et	3	main
muutub	doc_534729444741_item	2696365	et	3	main
ka	doc_534729444741_item	2696366	et	3	main
sellele	doc_534729444741_item	2696373	et	4	main
mõju	doc_534729444741_item	2696375	et	4	main
lühteri	doc_534729444741_item	2696377	et	3	main
iseloomustab	doc_534729444741_item	2696381	et	4	main
instrumentaalne	doc_534729444741_item	2696384	et	3	main
karjalaul	doc_534729444741_item	2696398	et	4	main
ärkamisaeg	doc_534729444741_item	2696413	et	3	main
mõjus	doc_534729444741_item	2696414	et	4	main
eesti	doc_534729444741_item	2696416	et	4	main
liikumise	doc_534729444741_item	2696422	et	4	main
filmides	doc_534729444741_item	2696453	et	4	main
eraldumata	doc_534729444741_item	2696464	et	4	main
osa	doc_534729444741_item	2696465	et	4	main
essee	doc_534729444742_item	2696481	et	4	main
eesti	doc_534729444742_item	2696482	et	4	main
teeb	doc_534729444742_item	2696493	et	3	main
eestlastest	doc_534729444742_item	2696494	et	4	main
essee	doc_534729444742_item	2696496	et	4	main
300	doc_534729444742_item	2696498	et	2	main
esitatud	doc_534729444742_item	2696512	et	4	main
südames	doc_534729444742_item	2696521	et	3	main
laul	doc_534729444742_item	2696525	et	4	main
kui	doc_534729444742_item	2696527	et	3	main
see	doc_534729444742_item	2696528	et	3	main
laul	doc_534729444742_item	2696529	et	4	main
jutustab	doc_534729444742_item	2696530	et	3	main
sinu	doc_534729444742_item	2696531	et	3	main
rahva	doc_534729444742_item	2696532	et	3	main
on	doc_534729444742_item	2696540	et	4	main
minu	doc_534729444742_item	2696549	et	3	main
rahva	doc_534729444742_item	2696555	et	3	main
elasid	doc_534729444742_item	2696564	et	4	main
kalevipojast	doc_534729444742_item	2696583	et	4	main
vabadusest	doc_534729444742_item	2696586	et	4	main
rahva	doc_534729444742_item	2696588	et	3	main
looming	doc_534729444742_item	2696589	et	3	main
viib	doc_534729444742_item	2696590	et	3	main
meid	doc_534729444742_item	2696591	et	4	main
vanadele	doc_534729444742_item	2696592	et	3	main
ajale	doc_534729444742_item	2696593	et	3	main
ja	doc_534729444742_item	2696594	et	3	main
kui	doc_534729444742_item	2696595	et	3	main
on	doc_534729444742_item	2696598	et	4	main
siis	doc_534729444742_item	2696599	et	3	main
rohkem	doc_534729444742_item	2696600	et	4	main
kasulikku	doc_534729444742_item	2696601	et	4	main
juba	doc_534729444742_item	2696606	et	3	main
igas	doc_534729444742_item	2696610	et	3	main
töötades	doc_534729444742_item	2696612	et	3	main
või	doc_534729444742_item	2696630	et	4	main
hinnatud	doc_534729444742_item	2696634	et	4	main
pulmalaulud	doc_534729444742_item	2696635	et	3	main
ette	doc_534729444742_item	2696638	et	4	main
lauldi	doc_534729444742_item	2696641	et	3	main
muutusid	doc_534729444742_item	2696651	et	4	main
see	doc_534729444742_item	2696667	et	3	main
suursündmus	doc_534729444742_item	2696670	et	3	main
mis	doc_534729444742_item	2696671	et	4	main
1994	doc_534729444742_item	2696698	et	2	main
aastal	doc_534729444742_item	2696699	et	3	main
lauljad	doc_534729444742_item	2696702	et	4	main
eestlaste	doc_534729444742_item	2696714	et	4	main
seepärast	doc_534729444742_item	2696718	et	3	main
et	doc_534729444742_item	2696721	et	3	main
hakkasid	doc_534729444741_item	2696387	et	4	main
levima	doc_534729444741_item	2696388	et	3	main
niisugused	doc_534729444741_item	2696389	et	3	main
kannel	doc_534729444741_item	2696393	et	4	main
rahvalaulu	doc_534729444741_item	2696395	et	4	main
olid	doc_534729444741_item	2696396	et	4	main
ka	doc_534729444741_item	2696397	et	3	main
hakkasid	doc_534729444741_item	2696403	et	4	main
heliloojad	doc_534729444741_item	2696404	et	3	main
kasutama	doc_534729444741_item	2696405	et	3	main
loomingus	doc_534729444741_item	2696408	et	3	main
nt	doc_534729444741_item	2696409	et	4	main
millal	doc_534729444741_item	2696425	et	3	main
esimene	doc_534729444741_item	2696427	et	3	main
mis	doc_534729444741_item	2696429	et	4	main
toimub	doc_534729444741_item	2696430	et	3	main
praeguni	doc_534729444741_item	2696431	et	4	main
praegu	doc_534729444741_item	2696432	et	3	main
rahvamuusikat	doc_534729444741_item	2696433	et	3	main
võib	doc_534729444741_item	2696434	et	3	main
ole	doc_534729444741_item	2696441	et	4	main
muusikamõju	doc_534729444741_item	2696444	et	4	main
festevaalid	doc_534729444741_item	2696457	et	4	main
viljandi	doc_534729444741_item	2696459	et	4	main
nii	doc_534729444741_item	2696461	et	3	main
kogu	doc_534729444741_item	2696466	et	4	main
eesti	doc_534729444741_item	2696467	et	4	main
kultuurist	doc_534729444741_item	2696468	et	3	main
ilma	doc_534729444741_item	2696475	et	4	main
eestlastest	doc_534729444741_item	2696479	et	4	main
keele	doc_534729444742_item	2696486	et	4	main
test	doc_534729444742_item	2696487	et	3	main
kirjutamine	doc_534729444742_item	2696488	et	4	main
kirjutage	doc_534729444742_item	2696489	et	3	main
essee	doc_534729444742_item	2696490	et	4	main
loengus	doc_534729444742_item	2696509	et	3	main
oli	doc_534729444741_item	2696424	et	3	main
ei	doc_534729444741_item	2696440	et	4	main
toimuvad	doc_534729444741_item	2696454	et	4	main
nt	doc_534729444741_item	2696458	et	4	main
laulmine	doc_534729444741_item	2696462	et	4	main
on	doc_534729444741_item	2696463	et	4	main
ei	doc_534729444741_item	2696471	et	4	main
keele	doc_534729444742_item	2696483	et	4	main
kui	doc_534729444742_item	2696484	et	3	main
teemal	doc_534729444742_item	2696491	et	3	main
laulurahva	doc_534729444742_item	2696495	et	3	main
peab	doc_534729444742_item	2696502	et	4	main
olema	doc_534729444742_item	2696503	et	4	main
lugemistekstis	doc_534729444742_item	2696511	et	3	main
faktidele	doc_534729444742_item	2696513	et	3	main
väiteid	doc_534729444742_item	2696514	et	4	main
on	doc_534729444742_item	2696515	et	4	main
soovitatav	doc_534729444742_item	2696516	et	4	main
illustreerida	doc_534729444742_item	2696517	et	3	main
näidetega	doc_534729444742_item	2696518	et	3	main
iga	doc_534729444742_item	2696519	et	4	main
inimese	doc_534729444742_item	2696520	et	4	main
ajaloost	doc_534729444742_item	2696533	et	4	main
uhkuda	doc_534729444742_item	2696546	et	4	main
sellega	doc_534729444742_item	2696547	et	3	main
arvates	doc_534729444742_item	2696550	et	4	main
inimesed	doc_534729444742_item	2696557	et	3	main
kuulda	doc_534729444742_item	2696581	et	4	main
lauludes	doc_534729444742_item	2696582	et	3	main
võidlemisest	doc_534729444742_item	2696585	et	4	main
eesti	doc_534729444742_item	2696587	et	4	main
informatsiooni	doc_534729444742_item	2696602	et	4	main
vanadel	doc_534729444742_item	2696607	et	3	main
teel	doc_534729444742_item	2696618	et	4	main
puhkades	doc_534729444742_item	2696620	et	4	main
on	doc_534729444742_item	2696623	et	4	main
jaoks	doc_534729444742_item	2696645	et	4	main
külaliste	doc_534729444742_item	2696646	et	4	main
ja	doc_534729444742_item	2696650	et	3	main
ja	doc_534729444742_item	2696653	et	3	main
hakkasid	doc_534729444742_item	2696655	et	4	main
järgnevate	doc_534729444742_item	2696674	et	4	main
laulsid	doc_534729444742_item	2696703	et	4	main
koos	doc_534729444742_item	2696706	et	4	main
see	doc_534729444742_item	2696707	et	3	main
oli	doc_534729444742_item	2696708	et	3	main
suur	doc_534729444742_item	2696709	et	3	main
vabaduse	doc_534729444742_item	2696710	et	4	main
tants	doc_534729444742_item	2696711	et	3	main
laulud	doc_534729444742_item	2696724	et	3	main
riimilised	doc_534729444742_item	2696727	et	4	main
kujunenud	doc_534729444742_item	2696732	et	4	main
rahvuslikeks	doc_534729444742_item	2696733	et	3	main
sumboliteks	doc_534729444742_item	2696734	et	4	main
kui	doc_534729444742_item	2696735	et	3	main
inimene	doc_534729444742_item	2696736	et	3	main
elab	doc_534729444742_item	2696737	et	3	main
eestis	doc_534729444742_item	2696738	et	3	main
ja	doc_534729444742_item	2696739	et	3	main
armastab	doc_534729444742_item	2696740	et	3	main
ta	doc_534729444742_item	2696747	et	4	main
on	doc_534729444742_item	2696752	et	4	main
inimene	doc_534729444742_item	2696758	et	3	main
teab	doc_534729444742_item	2696759	et	3	main
selline	doc_534729444742_item	2696763	et	4	main
kangelane	doc_534729444742_item	2696764	et	3	main
nagu	doc_534729444742_item	2696765	et	3	main
tal	doc_534729444742_item	2696768	et	3	main
linda	doc_534729444742_item	2696771	et	4	main
kui	doc_534729444742_item	2696772	et	3	main
inimene	doc_534729444742_item	2696773	et	3	main
sõna	doc_534729444742_item	2696500	et	4	main
arutlev	doc_534729444742_item	2696504	et	4	main
analüüsiv	doc_534729444742_item	2696505	et	4	main
ja	doc_534729444742_item	2696506	et	3	main
olemas	doc_534729444742_item	2696523	et	4	main
ja	doc_534729444742_item	2696526	et	3	main
iseloomust	doc_534729444742_item	2696536	et	4	main
sellele	doc_534729444742_item	2696538	et	4	main
lauluga	doc_534729444742_item	2696548	et	4	main
rahva	doc_534729444742_item	2696552	et	3	main
sõltub	doc_534729444742_item	2696554	et	3	main
millega	doc_534729444742_item	2696563	et	3	main
toimub	doc_534729444742_item	2696566	et	3	main
me	doc_534729444742_item	2696579	et	4	main
armastusest	doc_534729444742_item	2696584	et	4	main
vanem	doc_534729444742_item	2696596	et	4	main
me	doc_534729444742_item	2696603	et	4	main
saame	doc_534729444742_item	2696604	et	4	main
ajal	doc_534729444742_item	2696608	et	4	main
kohas	doc_534729444742_item	2696611	et	4	main
maal	doc_534729444742_item	2696613	et	4	main
last	doc_534729444742_item	2696614	et	4	main
kiigutades	doc_534729444742_item	2696615	et	3	main
või	doc_534729444742_item	2696619	et	4	main
on	doc_534729444742_item	2696522	et	4	main
armas	doc_534729444742_item	2696524	et	3	main
peale	doc_534729444742_item	2696537	et	4	main
ta	doc_534729444742_item	2696539	et	4	main
väga	doc_534729444742_item	2696541	et	3	main
ilus	doc_534729444742_item	2696542	et	4	main
siis	doc_534729444742_item	2696543	et	3	main
inimene	doc_534729444742_item	2696544	et	3	main
saab	doc_534729444742_item	2696545	et	3	main
iga	doc_534729444742_item	2696551	et	4	main
looming	doc_534729444742_item	2696553	et	3	main
laulavad	doc_534729444742_item	2696558	et	4	main
mida	doc_534729444742_item	2696560	et	4	main
nad	doc_534729444742_item	2696561	et	3	main
tundsid	doc_534729444742_item	2696562	et	4	main
mis	doc_534729444742_item	2696565	et	4	main
nende	doc_534729444742_item	2696567	et	4	main
südames	doc_534729444742_item	2696568	et	3	main
ja	doc_534729444742_item	2696569	et	3	main
hinges	doc_534729444742_item	2696570	et	4	main
paljudes	doc_534729444742_item	2696571	et	3	main
eesti	doc_534729444742_item	2696572	et	4	main
lauludes	doc_534729444742_item	2696573	et	3	main
on	doc_534729444742_item	2696574	et	4	main
olemas	doc_534729444742_item	2696575	et	4	main
eesti	doc_534729444742_item	2696576	et	4	main
rahva	doc_534729444742_item	2696577	et	3	main
ajalugu	doc_534729444742_item	2696578	et	4	main
saame	doc_534729444742_item	2696580	et	4	main
laul	doc_534729444742_item	2696597	et	4	main
kodus	doc_534729444742_item	2696616	et	4	main
jalutades	doc_534729444742_item	2696617	et	3	main
saartel	doc_534729444742_item	2696632	et	3	main
ajad	doc_534729444742_item	2696649	et	4	main
laulud	doc_534729444742_item	2696652	et	3	main
tantsud	doc_534729444742_item	2696654	et	3	main
mitmed	doc_534729444742_item	2696657	et	4	main
eestlaste	doc_534729444742_item	2696658	et	4	main
hiljem	doc_534729444742_item	2696660	et	3	main
muusikaline	doc_534729444742_item	2696669	et	4	main
aluse	doc_534729444742_item	2696673	et	4	main
on	doc_534729444742_item	2696713	et	4	main
rahvuslikeks	doc_534729444742_item	2696717	et	3	main
räägib	doc_534729444742_item	2696720	et	3	main
vanad	doc_534729444742_item	2696722	et	3	main
aja	doc_534729444742_item	2696731	et	4	main
ta	doc_534729444742_item	2696744	et	4	main
sündis	doc_534729444742_item	2696745	et	3	main
eestis	doc_534729444742_item	2696746	et	3	main
eesti	doc_534729444742_item	2696750	et	4	main
rahvastel	doc_534729444742_item	2696751	et	4	main
pikk	doc_534729444742_item	2696753	et	4	main
ja	doc_534729444742_item	2696754	et	3	main
meil	doc_534729444742_item	2696761	et	4	main
kalevipoeg	doc_534729444742_item	2696766	et	3	main
naine	doc_534729444742_item	2696770	et	3	main
elab	doc_534729444742_item	2696774	et	3	main
siin	doc_534729444742_item	2696779	et	4	main
nii	doc_534729444742_item	2696781	et	3	main
palju	doc_534729444742_item	2696782	et	4	main
ilusaid	doc_534729444742_item	2696783	et	3	main
laulu	doc_534729444742_item	2696784	et	4	main
ja	doc_534729444742_item	2696785	et	3	main
nii	doc_534729444742_item	2696786	et	3	main
näiteks	doc_534729444742_item	2696622	et	4	main
sellised	doc_534729444742_item	2696624	et	4	main
laulud	doc_534729444742_item	2696625	et	3	main
millised	doc_534729444742_item	2696626	et	3	main
lauldakse	doc_534729444742_item	2696627	et	3	main
korjades	doc_534729444742_item	2696628	et	4	main
seeni	doc_534729444742_item	2696629	et	3	main
on	doc_534729444742_item	2696633	et	4	main
kujutage	doc_534729444742_item	2696636	et	3	main
pruudi	doc_534729444742_item	2696642	et	3	main
jaoks	doc_534729444742_item	2696647	et	4	main
ühislaulmised	doc_534729444742_item	2696659	et	3	main
1869	doc_534729444742_item	2696661	et	2	main
aastal	doc_534729444742_item	2696662	et	3	main
toimus	doc_534729444742_item	2696663	et	3	main
esimene	doc_534729444742_item	2696664	et	3	main
laulupidu	doc_534729444742_item	2696665	et	4	main
tartus	doc_534729444742_item	2696666	et	3	main
üldlaulupidude	doc_534729444742_item	2696675	et	4	main
aastal	doc_534729444742_item	2696678	et	3	main
eestlaste	doc_534729444742_item	2696679	et	4	main
jaoks	doc_534729444742_item	2696680	et	4	main
muusika	doc_534729444742_item	2696681	et	4	main
oli	doc_534729444742_item	2696682	et	3	main
juba	doc_534729444742_item	2696683	et	3	main
rohkem	doc_534729444742_item	2696684	et	4	main
kui	doc_534729444742_item	2696685	et	3	main
meelelahutus	doc_534729444742_item	2696686	et	4	main
see	doc_534729444742_item	2696687	et	3	main
oli	doc_534729444742_item	2696688	et	3	main
vabaduse	doc_534729444742_item	2696689	et	4	main
helilooja	doc_534729444742_item	2696690	et	4	main
iga	doc_534729444742_item	2696691	et	4	main
aastaga	doc_534729444742_item	2696692	et	3	main
sellised	doc_534729444742_item	2696693	et	4	main
peod	doc_534729444742_item	2696694	et	4	main
arenesid	doc_534729444742_item	2696695	et	4	main
ja	doc_534729444742_item	2696696	et	3	main
juba	doc_534729444742_item	2696697	et	3	main
tuhandeid	doc_534729444742_item	2696701	et	3	main
tantsisid	doc_534729444742_item	2696705	et	4	main
laul	doc_534729444742_item	2696712	et	4	main
kujunenud	doc_534729444742_item	2696716	et	4	main
regilaulud	doc_534729444742_item	2696726	et	3	main
on	doc_534729444742_item	2696729	et	4	main
läbi	doc_534729444742_item	2696730	et	4	main
oma	doc_534729444742_item	2696741	et	4	main
riiki	doc_534729444742_item	2696742	et	4	main
kui	doc_534729444742_item	2696743	et	3	main
tunneb	doc_534729444742_item	2696748	et	3	main
ajalugu	doc_534729444742_item	2696756	et	4	main
oli	doc_534729444742_item	2696762	et	3	main
et	doc_534729444742_item	2696767	et	3	main
oli	doc_534729444742_item	2696769	et	3	main
ta	doc_534729444742_item	2696776	et	4	main
ii	doc_535144239974_item	2697123	et	4	main
ahtaamsare	doc_535144239974_item	2697130	et	4	main
ja	doc_535144239974_item	2697135	et	3	main
õigus	doc_535144239974_item	2697136	et	4	main
tarapita	doc_535144239974_item	2697144	et	4	main
oli	doc_535144239974_item	2697146	et	3	main
maria	doc_535144239974_item	2697158	et	4	main
tuglas	doc_535144239974_item	2697160	et	4	main
elu	doc_535144239974_item	2697165	et	4	main
kiirestiarendama	doc_535144239974_item	2697167	et	4	main
radio	doc_535144239974_item	2697170	et	4	main
kino	doc_535144239974_item	2697171	et	4	main
draaamateater	doc_535144239974_item	2697176	et	4	main
oli	doc_535144239974_item	2697178	et	3	main
kaubandus	doc_535144239974_item	2697189	et	3	main
inimese	doc_535144239974_item	2697192	et	4	main
seltsid	doc_535144239974_item	2697196	et	4	main
koorilaulud	doc_534729444742_item	2696725	et	3	main
et	doc_534729444742_item	2696749	et	3	main
selline	doc_534729444742_item	2696757	et	4	main
teab	doc_534729444742_item	2696777	et	3	main
et	doc_534729444742_item	2696778	et	3	main
on	doc_534729444742_item	2696780	et	4	main
tantsu	doc_534729444742_item	2696789	et	4	main
mida	doc_535144239974_item	2697121	et	4	main
1	doc_535144239974_item	2697127	et	2	main
ilmuvad	doc_535144239974_item	2697140	et	4	main
igasuguseid	doc_535144239974_item	2697141	et	3	main
under	doc_535144239974_item	2697159	et	4	main
teised	doc_535144239974_item	2697163	et	4	main
hakkas	doc_535144239974_item	2697166	et	3	main
estonis	doc_535144239974_item	2697175	et	4	main
vanemuine	doc_535144239974_item	2697177	et	4	main
saada	doc_535144239974_item	2697180	et	4	main
kõrg	doc_535144239974_item	2697181	et	4	main
haridus	doc_535144239974_item	2697182	et	3	main
töötasid	doc_535144239974_item	2697194	et	4	main
liit	doc_535144239974_item	2697199	et	3	main
eestis	doc_535144239974_item	2697200	et	3	main
kirjandus	doc_535144239974_item	2697201	et	3	main
arenes	doc_535144239974_item	2697202	et	3	main
nagu	doc_535144239974_item	2697203	et	3	main
euroopas	doc_535144239974_item	2697204	et	3	main
jaoks	doc_535144239974_item	2697126	et	4	main
ew	doc_535144239974_item	2697128	et	4	main
kirjanduselu	doc_535144239974_item	2697129	et	4	main
tõde	doc_535144239974_item	2697134	et	4	main
kirjanduserühmid	doc_535144239974_item	2697142	et	3	main
pooleli	doc_535144239974_item	2697147	et	3	main
poliitiline	doc_535144239974_item	2697148	et	3	main
ja	doc_535144239974_item	2697149	et	3	main
pooleli	doc_535144239974_item	2697150	et	3	main
kirjanduslik	doc_535144239974_item	2697151	et	3	main
ühend	doc_535144239974_item	2697152	et	3	main
rühm	doc_535144239974_item	2697156	et	3	main
kultuuri	doc_535144239974_item	2697164	et	4	main
raamatukauplused	doc_535144239974_item	2697168	et	3	main
raamatukogud	doc_535144239974_item	2697169	et	3	main
erinevad	doc_535144239974_item	2697183	et	4	main
erialad	doc_535144239974_item	2697184	et	3	main
majandus	doc_535144239974_item	2697188	et	4	main
kasvas	doc_535144239974_item	2697190	et	3	main
arv	doc_535144239974_item	2697193	et	3	main
ilmuma	doc_535144239974_item	2697208	et	3	main
aga	doc_535144239974_item	2697211	et	3	main
ei	doc_535144239974_item	2697213	et	4	main
majanduse	doc_535144239974_item	2697216	et	4	main
eesti	doc_535144239974_item	2697240	et	4	main
valgus	doc_535144239974_item	2697242	et	4	main
näiteks	doc_535144239974_item	2697261	et	4	main
teine	doc_535144239974_item	2697278	et	3	main
näiteks	doc_535144239974_item	2697281	et	4	main
ukrainas	doc_535144239974_item	2697282	et	4	main
ei	doc_535144239974_item	2697288	et	4	main
kuulus	doc_535144239974_item	2697291	et	4	main
venema	doc_535144239974_item	2697304	et	4	main
ja	doc_535144239974_item	2697305	et	3	main
euroopa	doc_535144239974_item	2697306	et	4	main
et	doc_535144239974_item	2697319	et	3	main
kontrolltöö	doc_535144239974_item	2697107	et	4	main
1	doc_535144239974_item	2697108	et	2	main
iseloomustage	doc_535144239974_item	2697109	et	4	main
ew	doc_535144239974_item	2697110	et	4	main
kirjanduselu	doc_535144239974_item	2697111	et	4	main
2	doc_535144239974_item	2697112	et	2	main
milliseid	doc_535144239974_item	2697113	et	3	main
muudatusi	doc_535144239974_item	2697114	et	3	main
tõi	doc_535144239974_item	2697115	et	3	main
pärastsõjajärgne	doc_535144239974_item	2697116	et	3	main
kollektiviseerimine	doc_535144239974_item	2697117	et	4	main
kaasa	doc_535144239974_item	2697118	et	4	main
külaühiskonda	doc_535144239974_item	2697119	et	4	main
3	doc_535144239974_item	2697120	et	2	main
kuulsam	doc_535144239974_item	2697132	et	4	main
teos	doc_535144239974_item	2697133	et	4	main
siuri	doc_535144239974_item	2697157	et	4	main
alle	doc_535144239974_item	2697161	et	4	main
ja	doc_535144239974_item	2697162	et	3	main
humanitaar	doc_535144239974_item	2697185	et	4	main
arstiteaduskond	doc_535144239974_item	2697186	et	3	main
igasuguseid	doc_535144239974_item	2697195	et	3	main
õpetajate	doc_535144239974_item	2697197	et	4	main
kolhosid	doc_535144239974_item	2697209	et	4	main
andnus	doc_535144239974_item	2697214	et	4	main
eestile	doc_535144239974_item	2697215	et	3	main
eest	doc_535144239974_item	2697227	et	4	main
valgus	doc_535144239974_item	2697236	et	4	main
on	doc_535144239974_item	2697244	et	4	main
et	doc_535144239974_item	2697265	et	3	main
teraviljad	doc_535144239974_item	2697268	et	3	main
aga	doc_535144239974_item	2697269	et	3	main
väga	doc_535144239974_item	2697271	et	3	main
kasvatade	doc_535144239974_item	2697273	et	4	main
teravilju	doc_535144239974_item	2697274	et	3	main
sest	doc_535144239974_item	2697275	et	4	main
seda	doc_535144239974_item	2697287	et	3	main
huvitas	doc_535144239974_item	2697289	et	3	main
kolhoosile	doc_535144239974_item	2697292	et	3	main
maailmasõda	doc_535144239974_item	2697299	et	4	main
kui	doc_535144239974_item	2697308	et	3	main
ii	doc_535144239974_item	2697310	et	4	main
mõned	doc_535144239974_item	2697325	et	3	main
metsavenad	doc_535144239974_item	2697337	et	4	main
on	doc_535144239974_item	2697338	et	4	main
andsid	doc_535144239974_item	2697350	et	4	main
maailmasõda	doc_535144239974_item	2697355	et	4	main
oli	doc_535144239974_item	2697357	et	3	main
okupeeritud	doc_535144239974_item	2697358	et	4	main
venemaaga	doc_535144239974_item	2697359	et	3	main
3	doc_535144239974_item	2697360	et	2	main
1949	doc_535144239974_item	2697361	et	2	main
aastal	doc_535144239974_item	2697362	et	3	main
25	doc_535144239974_item	2697363	et	2	main
29	doc_535144239974_item	2697364	et	2	main
märts	doc_535144239974_item	2697365	et	3	main
toimus	doc_535144239974_item	2697366	et	3	main
inimesi	doc_535144239974_item	2697369	et	4	main
rongiga	doc_535144239974_item	2697372	et	4	main
nad	doc_535144239974_item	2697373	et	3	main
olid	doc_535144239974_item	2697374	et	4	main
sures	doc_535144239974_item	2697383	et	4	main
see	doc_535144239974_item	2697385	et	3	main
ja	doc_535144239974_item	2697395	et	3	main
seal	doc_535144239974_item	2697396	et	4	main
inimesed	doc_535144239974_item	2697402	et	3	main
linda	doc_535144239974_item	2697413	et	4	main
põlevad	doc_535144239974_item	2697416	et	4	main
kelle	doc_535144239975_item	2697420	et	4	main
loosung	doc_535144239975_item	2697432	et	3	main
aktuaalne	doc_535144239975_item	2697433	et	3	main
ka	doc_535144239975_item	2697434	et	3	main
või	doc_535144239975_item	2697444	et	4	main
oli	doc_535144239975_item	2697453	et	3	main
rahva	doc_535144239975_item	2697455	et	3	main
intelligentsi	doc_535144239975_item	2697474	et	4	main
ja	doc_535144239975_item	2697475	et	3	main
oli	doc_535144239975_item	2697480	et	3	main
arenemiseks	doc_535144239975_item	2697494	et	4	main
avaldamiseks	doc_535144239975_item	2697498	et	4	main
et	doc_535144239975_item	2697501	et	3	main
loosung	doc_535144239975_item	2697503	et	3	main
tänases	doc_535144239975_item	2697505	et	3	main
olema	doc_535144239975_item	2697515	et	4	main
toimuvad	doc_535144239975_item	2697523	et	4	main
majanduspoliitikas	doc_535144239975_item	2697527	et	3	main
nagu	doc_535144239975_item	2697536	et	3	main
õigus	doc_535144239975_item	2697539	et	4	main
unistus	doc_535144239975_item	2697568	et	4	main
2	doc_535144239975_item	2697575	et	2	main
et	doc_535144239975_item	2697578	et	3	main
iseseisvumine	doc_535144239975_item	2697580	et	3	main
tähendas	doc_535144239974_item	2697122	et	3	main
maailmasõda	doc_535144239974_item	2697124	et	4	main
eestlaste	doc_535144239974_item	2697125	et	4	main
kõige	doc_535144239974_item	2697131	et	4	main
iii-köide	doc_535144239974_item	2697137	et	4	main
saab	doc_535144239974_item	2697138	et	3	main
preemiat	doc_535144239974_item	2697139	et	3	main
näiteks	doc_535144239974_item	2697143	et	4	main
mis	doc_535144239974_item	2697145	et	4	main
veel	doc_535144239974_item	2697153	et	4	main
üks	doc_535144239974_item	2697154	et	3	main
kirjanduse	doc_535144239974_item	2697155	et	3	main
teatrid	doc_535144239974_item	2697172	et	3	main
ajalehed	doc_535144239974_item	2697173	et	3	main
trükikojad	doc_535144239974_item	2697174	et	3	main
võimalik	doc_535144239974_item	2697179	et	3	main
tehnika	doc_535144239974_item	2697187	et	4	main
tark	doc_535144239974_item	2697191	et	3	main
hakkavad	doc_535144239974_item	2697207	et	4	main
koostöö	doc_535144239974_item	2697210	et	4	main
tõusu	doc_535144239974_item	2697217	et	4	main
vaid	doc_535144239974_item	2697218	et	3	main
vastupidi	doc_535144239974_item	2697219	et	3	main
hans	doc_535144239974_item	2697220	et	4	main
kirjutas	doc_535144239974_item	2697222	et	3	main
valgus	doc_535144239974_item	2697224	et	4	main
koordis	doc_535144239974_item	2697225	et	4	main
mille	doc_535144239974_item	2697226	et	3	main
teos	doc_535144239974_item	2697233	et	4	main
ekraniseeriti	doc_535144239974_item	2697234	et	3	main
film	doc_535144239974_item	2697235	et	3	main
esimene	doc_535144239974_item	2697239	et	3	main
seal	doc_535144239974_item	2697262	et	4	main
siin	doc_535144239974_item	2697276	et	4	main
või	doc_535144239974_item	2697283	et	4	main
maa	doc_535144239974_item	2697290	et	4	main
kõik	doc_535144239974_item	2697293	et	4	main
seal	doc_535144239974_item	2697295	et	4	main
3	doc_535144239974_item	2697297	et	2	main
eestlaste	doc_535144239974_item	2697300	et	4	main
maailmasõda	doc_535144239974_item	2697311	et	4	main
olla	doc_535144239974_item	2697314	et	3	main
riigiks	doc_535144239974_item	2697316	et	3	main
arvasid	doc_535144239974_item	2697318	et	4	main
peavad	doc_535144239974_item	2697320	et	4	main
mõned	doc_535144239974_item	2697323	et	3	main
raha	doc_535144239974_item	2697343	et	4	main
aga	doc_535144239974_item	2697345	et	3	main
inimestele	doc_535144239974_item	2697352	et	3	main
ii	doc_535144239974_item	2697354	et	4	main
eesti	doc_535144239974_item	2697356	et	4	main
viidi	doc_535144239974_item	2697370	et	4	main
vagunis	doc_535144239974_item	2697376	et	3	main
rongu	doc_535144239974_item	2697379	et	4	main
veoautod	doc_535144239974_item	2697382	et	3	main
suur	doc_535144239974_item	2697399	et	3	main
sellest	doc_535144239974_item	2697404	et	4	main
kell	doc_535144239974_item	2697407	et	3	main
kõrval	doc_535144239974_item	2697410	et	4	main
on	doc_535144239974_item	2697411	et	4	main
skulptuur	doc_535144239974_item	2697412	et	3	main
küünlad	doc_535144239974_item	2697417	et	3	main
1	doc_535144239975_item	2697419	et	2	main
selts	doc_535144239974_item	2697198	et	3	main
2	doc_535144239974_item	2697205	et	2	main
kollektiviseerimine	doc_535144239974_item	2697206	et	4	main
kolhosid	doc_535144239974_item	2697212	et	4	main
teos	doc_535144239974_item	2697223	et	4	main
stalini	doc_535144239974_item	2697229	et	4	main
preemia	doc_535144239974_item	2697230	et	4	main
hiljem	doc_535144239974_item	2697231	et	3	main
see	doc_535144239974_item	2697232	et	3	main
oli	doc_535144239974_item	2697238	et	3	main
värvifilm	doc_535144239974_item	2697241	et	3	main
koordis	doc_535144239974_item	2697243	et	4	main
tüüpiline	doc_535144239974_item	2697245	et	3	main
naiivne	doc_535144239974_item	2697246	et	3	main
nõukogude	doc_535144239974_item	2697247	et	3	main
film	doc_535144239974_item	2697248	et	3	main
ta	doc_535144239974_item	2697249	et	4	main
jutustas	doc_535144239974_item	2697250	et	3	main
hea	doc_535144239974_item	2697260	et	4	main
kasvab	doc_535144239974_item	2697267	et	3	main
eestis	doc_535144239974_item	2697270	et	3	main
raske	doc_535144239974_item	2697272	et	4	main
venemaal	doc_535144239974_item	2697284	et	4	main
aga	doc_535144239974_item	2697285	et	3	main
poliitikuid	doc_535144239974_item	2697286	et	3	main
ii	doc_535144239974_item	2697298	et	4	main
jaoks	doc_535144239974_item	2697301	et	4	main
eesti	doc_535144239974_item	2697302	et	4	main
asub	doc_535144239974_item	2697303	et	3	main
vahel	doc_535144239974_item	2697307	et	4	main
algas	doc_535144239974_item	2697309	et	3	main
tahtis	doc_535144239974_item	2697313	et	3	main
vabaks	doc_535144239974_item	2697315	et	3	main
sõdima	doc_535144239974_item	2697321	et	3	main
metsa	doc_535144239974_item	2697332	et	4	main
nõukogude	doc_535144239974_item	2697333	et	3	main
liit	doc_535144239974_item	2697334	et	3	main
ütles	doc_535144239974_item	2697335	et	3	main
et	doc_535144239974_item	2697336	et	3	main
nad	doc_535144239974_item	2697341	et	3	main
vaesele	doc_535144239974_item	2697351	et	4	main
siberisse	doc_535144239974_item	2697368	et	4	main
siberisse	doc_535144239974_item	2697371	et	4	main
19	doc_535144239974_item	2697378	et	2	main
ümbes	doc_535144239974_item	2697380	et	4	main
vana	doc_535144239974_item	2697391	et	4	main
teel	doc_535144239974_item	2697393	et	4	main
siberisse	doc_535144239974_item	2697394	et	4	main
inimeste	doc_535144239974_item	2697400	et	3	main
tompea	doc_535144239974_item	2697409	et	4	main
inimesed	doc_535144239974_item	2697415	et	3	main
kreedo	doc_535144239975_item	2697422	et	4	main
oli	doc_535144239975_item	2697423	et	3	main
olgem	doc_535144239975_item	2697424	et	3	main
eestlased	doc_535144239975_item	2697425	et	3	main
põhjenda	doc_535144239975_item	2697446	et	4	main
3	doc_535144239975_item	2697447	et	2	main
eesti	doc_535144239975_item	2697454	et	4	main
eestlasteks	doc_535144239975_item	2697460	et	4	main
ka	doc_535144239975_item	2697464	et	3	main
ma	doc_535144239975_item	2697466	et	3	main
see	doc_535144239975_item	2697468	et	3	main
kreedo	doc_535144239975_item	2697470	et	4	main
oli	doc_535144239975_item	2697471	et	3	main
eelkõige	doc_535144239975_item	2697472	et	3	main
haritud	doc_535144239975_item	2697473	et	4	main
euroopaga	doc_535144239975_item	2697478	et	3	main
ja	doc_535144239975_item	2697495	et	3	main
arvan	doc_535144239975_item	2697500	et	3	main
see	doc_535144239975_item	2697502	et	3	main
ka	doc_535144239975_item	2697504	et	3	main
eesti	doc_535144239975_item	2697506	et	4	main
valmis	doc_535144239975_item	2697516	et	4	main
l	doc_535144239974_item	2697221	et	4	main
sai	doc_535144239974_item	2697228	et	4	main
koordis	doc_535144239974_item	2697237	et	4	main
et	doc_535144239974_item	2697251	et	3	main
kolhoos	doc_535144239974_item	2697252	et	3	main
on	doc_535144239974_item	2697253	et	4	main
surepärane	doc_535144239974_item	2697254	et	4	main
asi	doc_535144239974_item	2697255	et	4	main
et	doc_535144239974_item	2697256	et	3	main
seal	doc_535144239974_item	2697257	et	4	main
on	doc_535144239974_item	2697258	et	4	main
kõik	doc_535144239974_item	2697259	et	4	main
oli	doc_535144239974_item	2697263	et	3	main
näidatud	doc_535144239974_item	2697264	et	4	main
eestis	doc_535144239974_item	2697266	et	3	main
on	doc_535144239974_item	2697277	et	4	main
kliima	doc_535144239974_item	2697279	et	4	main
kui	doc_535144239974_item	2697280	et	3	main
pidid	doc_535144239974_item	2697294	et	4	main
töötama	doc_535144239974_item	2697296	et	3	main
eesti	doc_535144239974_item	2697312	et	4	main
mõned	doc_535144239974_item	2697317	et	3	main
sakslastega	doc_535144239974_item	2697322	et	3	main
tahtnud	doc_535144239974_item	2697327	et	4	main
sõdida	doc_535144239974_item	2697328	et	3	main
ja	doc_535144239974_item	2697329	et	3	main
nad	doc_535144239974_item	2697330	et	3	main
läksid	doc_535144239974_item	2697331	et	4	main
et	doc_535144239974_item	2697340	et	3	main
varastasid	doc_535144239974_item	2697342	et	4	main
rongid	doc_535144239974_item	2697344	et	3	main
pärast	doc_535144239974_item	2697353	et	4	main
küüditamine	doc_535144239974_item	2697367	et	4	main
2500	doc_535144239974_item	2697381	et	2	main
osas	doc_535144239974_item	2697384	et	4	main
olid	doc_535144239974_item	2697386	et	4	main
naised	doc_535144239974_item	2697387	et	3	main
ja	doc_535144239974_item	2697388	et	3	main
lapsed	doc_535144239974_item	2697389	et	3	main
ja	doc_535144239974_item	2697390	et	3	main
kohal	doc_535144239974_item	2697397	et	4	main
suri	doc_535144239974_item	2697398	et	3	main
mäletavad	doc_535144239974_item	2697403	et	4	main
märtsil	doc_535144239974_item	2697406	et	3	main
1600	doc_535144239974_item	2697408	et	2	main
seal	doc_535144239974_item	2697414	et	4	main
loominguline	doc_535144239975_item	2697421	et	4	main
saagem	doc_535144239975_item	2697427	et	3	main
ka	doc_535144239975_item	2697428	et	3	main
eurooplasteks	doc_535144239975_item	2697429	et	3	main
on	doc_535144239975_item	2697430	et	4	main
see	doc_535144239975_item	2697431	et	3	main
tänases	doc_535144239975_item	2697435	et	3	main
seaduspärasus	doc_535144239975_item	2697445	et	4	main
kreedo	doc_535144239975_item	2697456	et	4	main
kodanluse	doc_535144239975_item	2697476	et	4	main
enese	doc_535144239975_item	2697493	et	4	main
oskusi	doc_535144239975_item	2697497	et	3	main
et	doc_535144239975_item	2697514	et	3	main
igasugused	doc_535144239975_item	2697524	et	3	main
muutused	doc_535144239975_item	2697525	et	4	main
oludes	doc_535144239975_item	2697530	et	3	main
samuti	doc_535144239975_item	2697532	et	3	main
väiksel	doc_535144239975_item	2697534	et	4	main
on	doc_535144239975_item	2697538	et	4	main
olema	doc_535144239975_item	2697540	et	4	main
euroopa	doc_535144239975_item	2697541	et	4	main
liidu	doc_535144239975_item	2697542	et	3	main
liikmeks	doc_535144239975_item	2697543	et	3	main
euroopa	doc_535144239975_item	2697547	et	4	main
toob	doc_535144239975_item	2697553	et	3	main
edasiliikumine	doc_535144239975_item	2697564	et	3	main
paljude	doc_535144239975_item	2697566	et	3	main
tol	doc_535144239975_item	2697570	et	3	main
tänapäeval	doc_535144239975_item	2697574	et	3	main
juhus	doc_535144239975_item	2697585	et	4	main
et	doc_535144239975_item	2697589	et	3	main
ja	doc_535144239975_item	2697594	et	3	main
kerises	doc_535144239975_item	2697596	et	3	main
tähendab	doc_535144239975_item	2697598	et	3	main
iseseisusele	doc_535144239975_item	2697600	et	3	main
ühiskondliku	doc_535144239975_item	2697603	et	3	main
ja	doc_535144239975_item	2697605	et	3	main
ei	doc_535144239975_item	2697636	et	4	main
muuta	doc_535144239975_item	2697639	et	4	main
ja	doc_535144239975_item	2697640	et	3	main
rahvas	doc_535144239975_item	2697641	et	4	main
nõudma	doc_535144239975_item	2697642	et	3	main
poliitilise	doc_535144239975_item	2697643	et	3	main
ja	doc_535144239975_item	2697644	et	3	main
majanduse	doc_535144239975_item	2697645	et	4	main
olukorra	doc_535144239975_item	2697646	et	3	main
puudusid	doc_535144239975_item	2697649	et	4	main
venelastega	doc_535144239974_item	2697324	et	4	main
ei	doc_535144239974_item	2697326	et	4	main
kuritegijad	doc_535144239974_item	2697339	et	3	main
see	doc_535144239974_item	2697346	et	3	main
raha	doc_535144239974_item	2697347	et	4	main
nad	doc_535144239974_item	2697348	et	3	main
osaliselt	doc_535144239974_item	2697349	et	4	main
looma	doc_535144239974_item	2697375	et	4	main
oli	doc_535144239974_item	2697377	et	3	main
inimesed	doc_535144239974_item	2697392	et	3	main
arv	doc_535144239974_item	2697401	et	3	main
25	doc_535144239974_item	2697405	et	2	main
kontrolltöö	doc_535144239975_item	2697418	et	4	main
eesti	doc_535144239975_item	2697436	et	4	main
ühiskonnas	doc_535144239975_item	2697437	et	4	main
2	doc_535144239975_item	2697438	et	2	main
kas	doc_535144239975_item	2697439	et	3	main
eesti	doc_535144239975_item	2697440	et	4	main
iseseisvumine	doc_535144239975_item	2697441	et	3	main
oli	doc_535144239975_item	2697442	et	3	main
ahtammsaare	doc_535144239975_item	2697448	et	4	main
looming	doc_535144239975_item	2697449	et	3	main
ew-s	doc_535144239975_item	2697450	et	3	main
see	doc_535144239975_item	2697452	et	3	main
jätta	doc_535144239975_item	2697461	et	3	main
integreerida	doc_535144239975_item	2697463	et	3	main
euroopasse	doc_535144239975_item	2697465	et	3	main
oma	doc_535144239975_item	2697477	et	4	main
seotud	doc_535144239975_item	2697481	et	4	main
heatasemeline	doc_535144239975_item	2697483	et	4	main
üldse	doc_535144239975_item	2697489	et	3	main
oli	doc_535144239975_item	2697490	et	3	main
rohkem	doc_535144239975_item	2697491	et	4	main
võimalusi	doc_535144239975_item	2697492	et	3	main
oma	doc_535144239975_item	2697496	et	4	main
ma	doc_535144239975_item	2697499	et	3	main
ühiskonnas	doc_535144239975_item	2697507	et	4	main
päris	doc_535144239975_item	2697508	et	4	main
aktuaalne	doc_535144239975_item	2697509	et	3	main
tänapäeval	doc_535144239975_item	2697510	et	3	main
tehakse	doc_535144239975_item	2697511	et	3	main
ju	doc_535144239975_item	2697512	et	3	main
riigil	doc_535144239975_item	2697535	et	3	main
loodan	doc_535144239975_item	2697545	et	3	main
tsiviliseerimisse	doc_535144239975_item	2697562	et	4	main
nii	doc_535144239975_item	2697569	et	3	main
ka	doc_535144239975_item	2697573	et	3	main
ma	doc_535144239975_item	2697576	et	3	main
ma	doc_535144239975_item	2697586	et	3	main
sõdade	doc_535144239975_item	2697595	et	3	main
et	doc_535144239975_item	2697599	et	3	main
kuid	doc_535144239975_item	2697426	et	4	main
juhus	doc_535144239975_item	2697443	et	4	main
1	doc_535144239975_item	2697451	et	2	main
kes	doc_535144239975_item	2697457	et	4	main
tahtis	doc_535144239975_item	2697458	et	3	main
nii	doc_535144239975_item	2697459	et	3	main
kuid	doc_535144239975_item	2697462	et	4	main
arvan	doc_535144239975_item	2697467	et	3	main
loominguline	doc_535144239975_item	2697469	et	4	main
ju	doc_535144239975_item	2697479	et	3	main
kõrgharidus	doc_535144239975_item	2697482	et	3	main
teadus	doc_535144239975_item	2697484	et	4	main
kunst	doc_535144239975_item	2697485	et	3	main
ja	doc_535144239975_item	2697486	et	3	main
üldse	doc_535144239975_item	2697487	et	3	main
kultuurseal	doc_535144239975_item	2697488	et	3	main
kõik	doc_535144239975_item	2697513	et	4	main
heaks	doc_535144239975_item	2697517	et	4	main
euroopa	doc_535144239975_item	2697518	et	4	main
liidu	doc_535144239975_item	2697519	et	3	main
liikmeks	doc_535144239975_item	2697520	et	3	main
meie	doc_535144239975_item	2697521	et	4	main
ka	doc_535144239975_item	2697526	et	3	main
poliitilistes	doc_535144239975_item	2697529	et	3	main
nii	doc_535144239975_item	2697533	et	3	main
et	doc_535144239975_item	2697546	et	3	main
liidu	doc_535144239975_item	2697548	et	3	main
mis	doc_535144239975_item	2697550	et	4	main
meile	doc_535144239975_item	2697554	et	4	main
rohkem	doc_535144239975_item	2697555	et	4	main
häid	doc_535144239975_item	2697556	et	3	main
kui	doc_535144239975_item	2697557	et	3	main
halbu	doc_535144239975_item	2697558	et	3	main
mul	doc_535144239975_item	2697559	et	3	main
tundub	doc_535144239975_item	2697560	et	3	main
et	doc_535144239975_item	2697561	et	3	main
on	doc_535144239975_item	2697565	et	4	main
kui	doc_535144239975_item	2697572	et	3	main
arvan	doc_535144239975_item	2697577	et	3	main
eesti	doc_535144239975_item	2697579	et	4	main
oli	doc_535144239975_item	2697581	et	3	main
alustan	doc_535144239975_item	2697587	et	3	main
eesti	doc_535144239975_item	2697590	et	4	main
wabariik	doc_535144239975_item	2697591	et	4	main
palju	doc_535144239975_item	2697602	et	4	main
muid	doc_535144239975_item	2697606	et	4	main
protsesse	doc_535144239975_item	2697607	et	3	main
teine	doc_535144239975_item	2697608	et	3	main
on	doc_535144239975_item	2697627	et	4	main
väike	doc_535144239975_item	2697682	et	4	main
identiteedi	doc_535144239975_item	2697687	et	4	main
ei	doc_535144239975_item	2697697	et	4	main
teistest	doc_535144239975_item	2697710	et	4	main
ma	doc_535144239975_item	2697717	et	3	main
et	doc_535144239975_item	2697720	et	3	main
üldse	doc_535144239975_item	2697721	et	3	main
arenesid	doc_535144239975_item	2697730	et	4	main
hannsen	doc_535144239975_item	2697737	et	4	main
ajal	doc_535144239975_item	2697741	et	4	main
ja	doc_535144239975_item	2697755	et	3	main
sündima	doc_535144239975_item	2697760	et	3	main
köiteline	doc_535144239975_item	2697763	et	4	main
sai	doc_535144239975_item	2697770	et	4	main
ta	doc_535144239975_item	2697771	et	4	main
riigi	doc_535144239975_item	2697772	et	3	main
auhinna	doc_535144239975_item	2697773	et	3	main
presidentist	doc_535144239975_item	2697774	et	4	main
1926	doc_535144239975_item	2697775	et	2	main
aastal	doc_535144239975_item	2697776	et	3	main
teine	doc_535144239975_item	2697780	et	3	main
juttusi	doc_535144239975_item	2697787	et	4	main
parem	doc_535144239975_item	2697795	et	4	main
partei	doc_535144239976_item	2697831	et	4	main
juhtis	doc_535144239976_item	2697832	et	3	main
oli	doc_535144239976_item	2697840	et	3	main
oli	doc_535144239976_item	2697844	et	3	main
ja	doc_535144239976_item	2697846	et	3	main
valitseja	doc_535144239976_item	2697848	et	4	main
ühiskonnas	doc_535144239975_item	2697522	et	4	main
sotsiaalsfääris	doc_535144239975_item	2697528	et	3	main
muidugi	doc_535144239975_item	2697531	et	4	main
eestil	doc_535144239975_item	2697537	et	3	main
ma	doc_535144239975_item	2697544	et	3	main
sisseastumine	doc_535144239975_item	2697549	et	3	main
toimus	doc_535144239975_item	2697551	et	3	main
juba	doc_535144239975_item	2697552	et	3	main
euroopasse	doc_535144239975_item	2697563	et	3	main
rahvaste	doc_535144239975_item	2697567	et	4	main
ajal	doc_535144239975_item	2697571	et	4	main
rohkem	doc_535144239975_item	2697582	et	4	main
revolutsioonide	doc_535144239975_item	2697593	et	3	main
see	doc_535144239975_item	2697597	et	3	main
eelnevad	doc_535144239975_item	2697601	et	4	main
poliitilisi	doc_535144239975_item	2697604	et	3	main
sõda	doc_535144239975_item	2697610	et	4	main
tõi	doc_535144239975_item	2697611	et	3	main
eestile	doc_535144239975_item	2697612	et	3	main
tohutut	doc_535144239975_item	2697613	et	4	main
kahju	doc_535144239975_item	2697614	et	4	main
need	doc_535144239975_item	2697615	et	3	main
sõjad	doc_535144239975_item	2697616	et	3	main
ja	doc_535144239975_item	2697617	et	3	main
segadused	doc_535144239975_item	2697618	et	3	main
mõjusid	doc_535144239975_item	2697619	et	4	main
inimeste	doc_535144239975_item	2697620	et	3	main
kultuurielule	doc_535144239975_item	2697621	et	3	main
enesekindlusele	doc_535144239975_item	2697623	et	4	main
viisid	doc_535144239975_item	2697624	et	4	main
midagi	doc_535144239975_item	2697629	et	4	main
parandada	doc_535144239975_item	2697630	et	3	main
inimeste	doc_535144239975_item	2697631	et	3	main
silmade	doc_535144239975_item	2697632	et	3	main
ees	doc_535144239975_item	2697633	et	4	main
poliitiline	doc_535144239975_item	2697634	et	3	main
võim	doc_535144239975_item	2697635	et	3	main
midagi	doc_535144239975_item	2697638	et	4	main
riigis	doc_535144239975_item	2697648	et	3	main
inimõigused	doc_535144239975_item	2697651	et	4	main
sotsiaalsed	doc_535144239975_item	2697652	et	3	main
pärast	doc_535144239975_item	2697675	et	4	main
ta	doc_535144239975_item	2697679	et	4	main
ja	doc_535144239975_item	2697688	et	3	main
võõrast	doc_535144239975_item	2697693	et	4	main
nendest	doc_535144239975_item	2697707	et	4	main
vaid	doc_535144239975_item	2697708	et	3	main
paljudest	doc_535144239975_item	2697709	et	3	main
3	doc_535144239975_item	2697716	et	2	main
eesti	doc_535144239975_item	2697722	et	4	main
teadus	doc_535144239975_item	2697734	et	4	main
tol	doc_535144239975_item	2697740	et	3	main
väga	doc_535144239975_item	2697742	et	3	main
tähtsaks	doc_535144239975_item	2697743	et	4	main
figuriiks	doc_535144239975_item	2697744	et	4	main
vaid	doc_535144239975_item	2697753	et	3	main
tol	doc_535144239975_item	2697757	et	3	main
3-me	doc_535144239975_item	2697762	et	4	main
õigus	doc_535144239975_item	2697767	et	4	main
mille	doc_535144239975_item	2697768	et	3	main
eest	doc_535144239975_item	2697769	et	4	main
romaani	doc_535144239975_item	2697779	et	4	main
ta	doc_535144239975_item	2697782	et	4	main
kirjutas	doc_535144239975_item	2697783	et	3	main
palju	doc_535144239975_item	2697784	et	4	main
tõde	doc_535144239975_item	2697790	et	4	main
ja	doc_535144239975_item	2697791	et	3	main
õigus	doc_535144239975_item	2697792	et	4	main
tänapäevani	doc_535144239975_item	2697793	et	3	main
kõige	doc_535144239975_item	2697794	et	4	main
süsteem	doc_535144239976_item	2697822	et	3	main
seaduspärasus	doc_535144239975_item	2697583	et	4	main
kui	doc_535144239975_item	2697584	et	3	main
sellest	doc_535144239975_item	2697588	et	4	main
sündis	doc_535144239975_item	2697592	et	3	main
maailma	doc_535144239975_item	2697609	et	4	main
vaja	doc_535144239975_item	2697628	et	4	main
saanud	doc_535144239975_item	2697637	et	4	main
parandamist	doc_535144239975_item	2697647	et	4	main
peamised	doc_535144239975_item	2697650	et	3	main
erinevused	doc_535144239975_item	2697653	et	4	main
kodanluse	doc_535144239975_item	2697654	et	4	main
ja	doc_535144239975_item	2697655	et	3	main
selle	doc_535144239975_item	2697674	et	4	main
alati	doc_535144239975_item	2697677	et	4	main
rahvas	doc_535144239975_item	2697683	et	4	main
tahtis	doc_535144239975_item	2697684	et	3	main
säilitada	doc_535144239975_item	2697685	et	3	main
kultuuri	doc_535144239975_item	2697689	et	4	main
peab	doc_535144239975_item	2697691	et	4	main
ta	doc_535144239975_item	2697692	et	4	main
miks	doc_535144239975_item	2697696	et	4	main
tal	doc_535144239975_item	2697699	et	3	main
et	doc_535144239975_item	2697701	et	3	main
faktoridest	doc_535144239975_item	2697711	et	4	main
ka	doc_535144239975_item	2697712	et	3	main
sündis	doc_535144239975_item	2697713	et	3	main
eesti	doc_535144239975_item	2697714	et	4	main
tahan	doc_535144239975_item	2697718	et	3	main
wabariigis	doc_535144239975_item	2697723	et	4	main
oli	doc_535144239975_item	2697724	et	3	main
kultuuri	doc_535144239975_item	2697725	et	4	main
õitse	doc_535144239975_item	2697726	et	4	main
aeg	doc_535144239975_item	2697727	et	3	main
krjandus	doc_535144239975_item	2697732	et	4	main
anton	doc_535144239975_item	2697736	et	4	main
tammsaare	doc_535144239975_item	2697738	et	3	main
kirjanduseuurija	doc_535144239975_item	2697754	et	4	main
tema	doc_535144239975_item	2697761	et	4	main
romaan	doc_535144239975_item	2697764	et	3	main
tõde	doc_535144239975_item	2697765	et	4	main
ja	doc_535144239975_item	2697766	et	3	main
muinasjuttusi	doc_535144239975_item	2697785	et	4	main
ja	doc_535144239975_item	2697786	et	3	main
poliitiline	doc_535144239976_item	2697821	et	3	main
selline	doc_535144239976_item	2697824	et	4	main
kõige	doc_535144239976_item	2697826	et	4	main
olulisem	doc_535144239976_item	2697827	et	4	main
oli	doc_535144239976_item	2697828	et	3	main
stalini	doc_535144239976_item	2697841	et	4	main
see	doc_535144239976_item	2697843	et	3	main
stalini	doc_535144239976_item	2697862	et	4	main
talud	doc_535144239976_item	2697875	et	4	main
karju	doc_535144239976_item	2697880	et	4	main
oli	doc_535144239976_item	2697921	et	3	main
nenede	doc_535144239975_item	2697622	et	4	main
arusaamisele	doc_535144239975_item	2697625	et	4	main
et	doc_535144239975_item	2697626	et	3	main
vahel	doc_535144239975_item	2697657	et	4	main
olid	doc_535144239975_item	2697658	et	4	main
väga	doc_535144239975_item	2697659	et	3	main
tugevad	doc_535144239975_item	2697660	et	4	main
aga	doc_535144239975_item	2697661	et	3	main
kõige	doc_535144239975_item	2697662	et	4	main
oluline	doc_535144239975_item	2697663	et	4	main
oli	doc_535144239975_item	2697664	et	3	main
see	doc_535144239975_item	2697665	et	3	main
faktor	doc_535144239975_item	2697666	et	3	main
et	doc_535144239975_item	2697667	et	3	main
eestlased	doc_535144239975_item	2697668	et	3	main
muidugi	doc_535144239975_item	2697669	et	4	main
tahtsid	doc_535144239975_item	2697670	et	4	main
olla	doc_535144239975_item	2697671	et	3	main
vabaks	doc_535144239975_item	2697672	et	3	main
vabrikutööliste	doc_535144239975_item	2697656	et	4	main
et	doc_535144239975_item	2697676	et	3	main
oli	doc_535144239975_item	2697678	et	3	main
mõju	doc_535144239975_item	2697680	et	4	main
all	doc_535144239975_item	2697681	et	3	main
kultuuri	doc_535144239975_item	2697694	et	4	main
omandama	doc_535144239975_item	2697695	et	3	main
saama	doc_535144239975_item	2697703	et	4	main
ma	doc_535144239975_item	2697704	et	3	main
arvan	doc_535144239975_item	2697705	et	3	main
mitteainult	doc_535144239975_item	2697706	et	4	main
iseseisvumine	doc_535144239975_item	2697715	et	3	main
selles	doc_535144239975_item	2697728	et	4	main
keel	doc_535144239975_item	2697731	et	4	main
ew-kirjanduselus	doc_535144239975_item	2697745	et	4	main
ja	doc_535144239975_item	2697746	et	3	main
tõlkija	doc_535144239975_item	2697756	et	4	main
ajal	doc_535144239975_item	2697758	et	4	main
hakkas	doc_535144239975_item	2697759	et	3	main
tema	doc_535144239975_item	2697778	et	4	main
köite	doc_535144239975_item	2697781	et	4	main
rahvaks	doc_535144239975_item	2697673	et	3	main
oma	doc_535144239975_item	2697686	et	4	main
miks	doc_535144239975_item	2697690	et	4	main
ole	doc_535144239975_item	2697698	et	4	main
jõudu	doc_535144239975_item	2697700	et	4	main
iseseisvaks	doc_535144239975_item	2697702	et	3	main
öelda	doc_535144239975_item	2697719	et	4	main
ajas	doc_535144239975_item	2697729	et	4	main
ajakirjandus	doc_535144239975_item	2697733	et	3	main
teatrikunst	doc_535144239975_item	2697735	et	3	main
oli	doc_535144239975_item	2697739	et	3	main
kultuurielus	doc_535144239975_item	2697747	et	4	main
ta	doc_535144239975_item	2697748	et	4	main
oli	doc_535144239975_item	2697749	et	3	main
mitte	doc_535144239975_item	2697750	et	3	main
ainult	doc_535144239975_item	2697751	et	4	main
kirjanik	doc_535144239975_item	2697752	et	3	main
ilmus	doc_535144239975_item	2697777	et	4	main
aga	doc_535144239975_item	2697788	et	3	main
tema	doc_535144239975_item	2697789	et	4	main
iseloomustab	doc_535144239975_item	2697796	et	4	main
teda	doc_535144239975_item	2697797	et	4	main
loomingu	doc_535144239975_item	2697798	et	3	main
kontrolltöö	doc_535144239976_item	2697799	et	4	main
1	doc_535144239976_item	2697800	et	2	main
mis	doc_535144239976_item	2697801	et	4	main
iseloomustab	doc_535144239976_item	2697802	et	4	main
nõukogude	doc_535144239976_item	2697803	et	3	main
ühiskonna	doc_535144239976_item	2697804	et	4	main
poliitilist	doc_535144239976_item	2697805	et	3	main
ja	doc_535144239976_item	2697806	et	3	main
majanduslikku	doc_535144239976_item	2697807	et	4	main
süsteemi	doc_535144239976_item	2697808	et	4	main
2	doc_535144239976_item	2697809	et	2	main
millised	doc_535144239976_item	2697810	et	3	main
olid	doc_535144239976_item	2697811	et	4	main
vabadussõja	doc_535144239976_item	2697812	et	3	main
võidu	doc_535144239976_item	2697813	et	4	main
peamised	doc_535144239976_item	2697814	et	3	main
põhjused	doc_535144239976_item	2697815	et	3	main
3	doc_535144239976_item	2697816	et	2	main
iseloomustage	doc_535144239976_item	2697817	et	4	main
ew	doc_535144239976_item	2697818	et	4	main
teaduselu	doc_535144239976_item	2697819	et	4	main
1	doc_535144239976_item	2697820	et	2	main
et	doc_535144239976_item	2697825	et	3	main
riigi	doc_535144239976_item	2697834	et	3	main
elu	doc_535144239976_item	2697835	et	4	main
otsustas	doc_535144239976_item	2697836	et	3	main
kõike	doc_535144239976_item	2697837	et	4	main
majanduslikke	doc_535144239976_item	2697838	et	3	main
partei	doc_535144239976_item	2697864	et	4	main
oli	doc_535144239976_item	2697867	et	3	main
kus	doc_535144239976_item	2697870	et	3	main
raha	doc_535144239976_item	2697878	et	4	main
saa	doc_535144239976_item	2697915	et	4	main
sest	doc_535144239976_item	2697916	et	4	main
see	doc_535144239976_item	2697917	et	3	main
oli	doc_535144239976_item	2697918	et	3	main
töötas	doc_535144239976_item	2697925	et	3	main
hulk	doc_535144239976_item	2697927	et	3	main
oli	doc_535144239976_item	2697931	et	3	main
muidugi	doc_535144239976_item	2697932	et	4	main
partei	doc_535144239976_item	2697829	et	4	main
ja	doc_535144239976_item	2697830	et	3	main
küsimusi	doc_535144239976_item	2697839	et	4	main
ainult	doc_535144239976_item	2697847	et	4	main
keda	doc_535144239976_item	2697849	et	4	main
kõik	doc_535144239976_item	2697850	et	4	main
ja	doc_535144239976_item	2697859	et	3	main
käes	doc_535144239976_item	2697863	et	4	main
pidid	doc_535144239976_item	2697876	et	4	main
loome	doc_535144239976_item	2697881	et	4	main
ja	doc_535144239976_item	2697882	et	3	main
kõik	doc_535144239976_item	2697883	et	4	main
oma	doc_535144239976_item	2697884	et	4	main
maad	doc_535144239976_item	2697885	et	4	main
anda	doc_535144239976_item	2697886	et	3	main
kolhoosile	doc_535144239976_item	2697887	et	3	main
või	doc_535144239976_item	2697888	et	4	main
sovhoosile	doc_535144239976_item	2697889	et	3	main
ja	doc_535144239976_item	2697890	et	3	main
peaaegu	doc_535144239976_item	2697891	et	3	main
raha	doc_535144239976_item	2697893	et	4	main
kõik	doc_535144239976_item	2697892	et	4	main
või	doc_535144239976_item	2697894	et	4	main
vilju	doc_535144239976_item	2697895	et	4	main
mis	doc_535144239976_item	2697896	et	4	main
see	doc_535144239976_item	2697897	et	3	main
kolhoos	doc_535144239976_item	2697898	et	3	main
annab	doc_535144239976_item	2697899	et	3	main
läks	doc_535144239976_item	2697900	et	3	main
riigile	doc_535144239976_item	2697901	et	3	main
talumehed	doc_535144239976_item	2697902	et	3	main
muidugi	doc_535144239976_item	2697903	et	4	main
oli	doc_535144239976_item	2697904	et	3	main
väga	doc_535144239976_item	2697905	et	3	main
ja	doc_535144239976_item	2697907	et	3	main
ebaõnnestunud	doc_535144239976_item	2697908	et	4	main
vaevad	doc_535144239976_item	2697906	et	4	main
aga	doc_535144239976_item	2697909	et	3	main
mitte	doc_535144239976_item	2697910	et	3	main
midagi	doc_535144239976_item	2697911	et	4	main
vastu	doc_535144239976_item	2697912	et	3	main
teha	doc_535144239976_item	2697913	et	3	main
ei	doc_535144239976_item	2697914	et	4	main
oli	doc_535144239976_item	2697823	et	3	main
kogu	doc_535144239976_item	2697833	et	4	main
ideoloogia	doc_535144239976_item	2697842	et	4	main
üks	doc_535144239976_item	2697845	et	3	main
pidati	doc_535144239976_item	2697851	et	4	main
nagu	doc_535144239976_item	2697852	et	3	main
jumalat	doc_535144239976_item	2697853	et	3	main
kõik	doc_535144239976_item	2697854	et	4	main
otsused	doc_535144239976_item	2697860	et	3	main
käes	doc_535144239976_item	2697865	et	4	main
majanduses	doc_535144239976_item	2697866	et	4	main
kollektivisatsiooni	doc_535144239976_item	2697868	et	4	main
süsteem	doc_535144239976_item	2697869	et	3	main
oma	doc_535144239976_item	2697877	et	4	main
linnades	doc_535144239976_item	2697920	et	3	main
palju	doc_535144239976_item	2697922	et	4	main
kes	doc_535144239976_item	2697924	et	4	main
inimesi	doc_535144239976_item	2697928	et	4	main
ja	doc_535144239976_item	2697929	et	3	main
see	doc_535144239976_item	2697930	et	3	main
majanduslikku	doc_535144239976_item	2697937	et	4	main
peamised	doc_535144239976_item	2697951	et	3	main
erinevad	doc_535144239976_item	2697954	et	4	main
võidu	doc_535144239976_item	2697965	et	4	main
tahtejõudu	doc_535144239976_item	2697974	et	4	main
ja	doc_535144239976_item	2697975	et	3	main
saa	doc_535144239976_item	2697978	et	4	main
ja	doc_535144239976_item	2697981	et	3	main
abi	doc_535144239976_item	2697983	et	4	main
teaduselu	doc_535144239976_item	2697990	et	4	main
ew	doc_535144239976_item	2697991	et	4	main
tol	doc_535144239976_item	2697992	et	3	main
tü	doc_535144239976_item	2697998	et	4	main
oli	doc_535144239976_item	2697999	et	3	main
neist	doc_535144239976_item	2698002	et	4	main
ja	doc_535144239976_item	2698003	et	3	main
kirjanduselu	doc_535144239977_item	2698013	et	4	main
2	doc_535144239977_item	2698014	et	2	main
milliseid	doc_535144239977_item	2698015	et	3	main
muudatusi	doc_535144239977_item	2698016	et	3	main
tõi	doc_535144239977_item	2698017	et	3	main
pärastsõjajärgne	doc_535144239977_item	2698018	et	3	main
kollektiviseerimine	doc_535144239977_item	2698019	et	4	main
tähendas	doc_535144239977_item	2698024	et	3	main
jaoks	doc_535144239977_item	2698034	et	4	main
rohkem	doc_535144239977_item	2698035	et	4	main
ebameeldivaid	doc_535144239977_item	2698036	et	3	main
oli	doc_535144239977_item	2698040	et	3	main
kaotud	doc_535144239977_item	2698043	et	4	main
tase	doc_535144239977_item	2698045	et	3	main
pärast	doc_535144239977_item	2698048	et	4	main
ii	doc_535144239977_item	2698049	et	4	main
tõusma	doc_535144239977_item	2698052	et	3	main
elu	doc_535144239977_item	2698055	et	4	main
enamus	doc_535144239977_item	2698065	et	4	main
luuletuseid	doc_535144239977_item	2698074	et	4	main
palju	doc_535144239977_item	2698077	et	4	main
isamaast	doc_535144239977_item	2698080	et	3	main
ja	doc_535144239977_item	2698081	et	3	main
2	doc_535144239977_item	2698083	et	2	main
häid	doc_535144239977_item	2698087	et	3	main
pärast	doc_535144239977_item	2698090	et	4	main
oli	doc_535144239977_item	2698092	et	3	main
seadused	doc_535144239976_item	2697855	et	3	main
kõik	doc_535144239976_item	2697856	et	4	main
sõja	doc_535144239976_item	2697857	et	3	main
küsimused	doc_535144239976_item	2697858	et	4	main
olid	doc_535144239976_item	2697861	et	4	main
kõik	doc_535144239976_item	2697871	et	4	main
maad	doc_535144239976_item	2697872	et	4	main
külad	doc_535144239976_item	2697873	et	3	main
ja	doc_535144239976_item	2697874	et	3	main
oma	doc_535144239976_item	2697879	et	4	main
kohustuslik	doc_535144239976_item	2697919	et	3	main
tehaseid	doc_535144239976_item	2697923	et	3	main
suur	doc_535144239976_item	2697926	et	3	main
tekstiilist	doc_535144239976_item	2697946	et	4	main
muidugi	doc_535144239976_item	2697955	et	4	main
ja	doc_535144239976_item	2697958	et	3	main
tahtmine	doc_535144239976_item	2697966	et	4	main
ja	doc_535144239976_item	2697967	et	3	main
ühtne	doc_535144239976_item	2697968	et	3	main
vaim	doc_535144239976_item	2697969	et	3	main
kõik	doc_535144239976_item	2697970	et	4	main
eitada	doc_535144239976_item	2697979	et	3	main
inglismaale	doc_535144239976_item	2697986	et	4	main
poolt	doc_535144239976_item	2697987	et	4	main
3	doc_535144239976_item	2697988	et	2	main
ajal	doc_535144239976_item	2697993	et	4	main
töötasid	doc_535144239976_item	2697994	et	4	main
arenenud	doc_535144239976_item	2698001	et	4	main
kasvatas	doc_535144239976_item	2698004	et	3	main
head	doc_535144239976_item	2698005	et	4	main
spetsialiste	doc_535144239976_item	2698006	et	3	main
omal	doc_535144239976_item	2698007	et	3	main
erialal	doc_535144239976_item	2698008	et	3	main
3	doc_535144239977_item	2698022	et	2	main
maailmasõda	doc_535144239977_item	2698031	et	4	main
tõi	doc_535144239977_item	2698032	et	3	main
ilmusid	doc_535144239977_item	2698064	et	4	main
ajaleht	doc_535144239977_item	2698070	et	3	main
poliitikaelust	doc_535144239977_item	2698073	et	3	main
muudatusi	doc_535144239977_item	2698088	et	3	main
sõda	doc_535144239977_item	2698091	et	4	main
saagem	doc_535144239978_item	2698123	et	3	main
on	doc_535144239978_item	2698126	et	4	main
aktuaalne	doc_535144239978_item	2698129	et	3	main
sõjaväkke	doc_535144239978_item	2698140	et	3	main
või	doc_535144239978_item	2698141	et	4	main
valikuvõimalused	doc_535144239978_item	2698146	et	3	main
tuntumaid	doc_535144239978_item	2698152	et	4	main
ew	doc_535144239978_item	2698153	et	4	main
hansen	doc_535144239978_item	2698161	et	4	main
tammsaare	doc_535144239978_item	2698162	et	3	main
õigus	doc_535144239978_item	2698168	et	4	main
osa	doc_535144239978_item	2698173	et	4	main
kirjanduspreemiat	doc_535144239978_item	2698180	et	3	main
viimase	doc_535144239978_item	2698182	et	3	main
eest	doc_535144239978_item	2698184	et	4	main
eestlaste	doc_535144239978_item	2698187	et	4	main
siuru	doc_535144239978_item	2698189	et	4	main
fr	doc_535144239978_item	2698195	et	4	main
töötas	doc_535144239978_item	2698197	et	3	main
eesti	doc_535144239978_item	2698202	et	4	main
kirjanikke	doc_535144239978_item	2698203	et	3	main
liidu	doc_535144239978_item	2698204	et	3	main
kirte	doc_535144239978_item	2698210	et	3	main
saksa	doc_535144239978_item	2698222	et	4	main
vabatahtlikust	doc_535144239978_item	2698224	et	4	main
allüksusi	doc_535144239978_item	2698225	et	3	main
1943	doc_535144239978_item	2698226	et	2	main
a	doc_535144239978_item	2698227	et	4	main
järgnes	doc_535144239978_item	2698228	et	3	main
tahtsid	doc_535144239978_item	2698236	et	4	main
mõeldud	doc_535144239978_item	2698241	et	4	main
punaarmeesse	doc_535144239978_item	2698251	et	4	main
tähendas	doc_535144239978_item	2698252	et	3	main
ennast	doc_535144239978_item	2698254	et	4	main
küüditamisest	doc_535144239978_item	2698255	et	4	main
töölaagritest	doc_535144239978_item	2698257	et	4	main
saaks	doc_535144239978_item	2698259	et	3	main
ainult	doc_535144239978_item	2698261	et	4	main
tavalised	doc_535144239978_item	2698275	et	4	main
inimesed	doc_535144239978_item	2698276	et	3	main
tähtsamaid	doc_535144239976_item	2697935	et	4	main
süsteemis	doc_535144239976_item	2697938	et	3	main
oli	doc_535144239976_item	2697941	et	3	main
tehtud	doc_535144239976_item	2697942	et	4	main
ja	doc_535144239976_item	2697943	et	3	main
vaemistatud	doc_535144239976_item	2697944	et	4	main
kõik	doc_535144239976_item	2697945	et	4	main
vabadussõja	doc_535144239976_item	2697949	et	3	main
võidu	doc_535144239976_item	2697950	et	4	main
ka	doc_535144239976_item	2697933	et	3	main
üks	doc_535144239976_item	2697934	et	3	main
nõukogude	doc_535144239976_item	2697939	et	3	main
raudemasideni	doc_535144239976_item	2697947	et	4	main
2	doc_535144239976_item	2697948	et	2	main
olid	doc_535144239976_item	2697953	et	4	main
oluline	doc_535144239976_item	2697957	et	4	main
meelest	doc_535144239976_item	2697960	et	4	main
tähtsam	doc_535144239976_item	2697962	et	4	main
oli	doc_535144239976_item	2697963	et	3	main
eestlaste	doc_535144239976_item	2697964	et	4	main
oma	doc_535144239976_item	2697973	et	4	main
ew	doc_535144239976_item	2697989	et	4	main
juba	doc_535144239976_item	2697995	et	3	main
kõige	doc_535144239976_item	2698000	et	4	main
ii	doc_535144239977_item	2698025	et	4	main
eestlaste	doc_535144239977_item	2698027	et	4	main
ii	doc_535144239977_item	2698030	et	4	main
palju	doc_535144239977_item	2698038	et	4	main
tappetud	doc_535144239977_item	2698041	et	4	main
ja	doc_535144239977_item	2698042	et	3	main
kukkus	doc_535144239977_item	2698046	et	3	main
hakkas	doc_535144239977_item	2698051	et	3	main
kirjanduselu	doc_535144239977_item	2698061	et	4	main
palju	doc_535144239977_item	2698062	et	4	main
ajalehte	doc_535144239977_item	2698063	et	4	main
ka	doc_535144239977_item	2698072	et	3	main
tõi	doc_535144239977_item	2698086	et	3	main
eestlased	doc_535144239978_item	2698121	et	3	main
ka	doc_535144239978_item	2698124	et	3	main
ka	doc_535144239978_item	2698130	et	3	main
eesti	doc_535144239978_item	2698132	et	4	main
ühiskonnas	doc_535144239978_item	2698133	et	4	main
2	doc_535144239978_item	2698134	et	2	main
millised	doc_535144239978_item	2698143	et	3	main
ms	doc_535144239978_item	2698148	et	4	main
3	doc_535144239978_item	2698150	et	2	main
anton	doc_535144239978_item	2698160	et	4	main
aastal	doc_535144239978_item	2698175	et	3	main
sai	doc_535144239978_item	2698177	et	4	main
riigivanema	doc_535144239978_item	2698178	et	4	main
suhted	doc_535144239978_item	2698188	et	3	main
luuletaja	doc_535144239978_item	2698194	et	4	main
mihkelson	doc_535144239978_item	2698196	et	4	main
gustav	doc_535144239978_item	2698208	et	4	main
kõik	doc_535144239978_item	2698213	et	4	main
kokku	doc_535144239978_item	2698215	et	3	main
unenägu	doc_535144239978_item	2698216	et	4	main
eesti	doc_535144239978_item	2698231	et	4	main
moodustatud	doc_535144239978_item	2698238	et	4	main
pataljonid	doc_535144239978_item	2698239	et	3	main
olid	doc_535144239978_item	2698240	et	4	main
tegelikult	doc_535144239978_item	2698268	et	4	main
surma	doc_535144239978_item	2698271	et	4	main
sõja	doc_535144239978_item	2698272	et	3	main
ajal	doc_535144239978_item	2698273	et	4	main
ka	doc_535144239978_item	2698274	et	3	main
jaoks	doc_535144239978_item	2698280	et	4	main
1	doc_535144239978_item	2698281	et	2	main
niisugune	doc_535144239978_item	2698282	et	3	main
loosung	doc_535144239978_item	2698283	et	3	main
loominguline	doc_535144239978_item	2698286	et	4	main
noor-eesti	doc_535144239978_item	2698288	et	4	main
rühmituses	doc_535144239978_item	2698289	et	4	main
tõsta	doc_535144239978_item	2698322	et	4	main
enda	doc_535144239978_item	2698332	et	4	main
me	doc_535144239978_item	2698336	et	4	main
võib-olla	doc_535144239978_item	2698345	et	3	main
raha	doc_535144239978_item	2698349	et	4	main
kroon	doc_535144239978_item	2698351	et	3	main
nagu	doc_535144239978_item	2698352	et	3	main
rahvas	doc_535144239978_item	2698360	et	4	main
on	doc_535144239978_item	2698364	et	4	main
oma	doc_535144239978_item	2698365	et	4	main
kultuur	doc_535144239978_item	2698366	et	3	main
ajalugu	doc_535144239978_item	2698370	et	4	main
ja	doc_535144239978_item	2698371	et	3	main
me	doc_535144239978_item	2698372	et	4	main
tahame	doc_535144239978_item	2698373	et	3	main
seda	doc_535144239978_item	2698374	et	3	main
säilida	doc_535144239978_item	2698375	et	3	main
3	doc_535144239978_item	2698376	et	2	main
osa	doc_535144239976_item	2697936	et	4	main
riigidel	doc_535144239976_item	2697940	et	4	main
minu	doc_535144239976_item	2697959	et	3	main
võimu	doc_535144239976_item	2697976	et	4	main
tugev	doc_535144239976_item	2697980	et	4	main
tugevasti	doc_535144239976_item	2697996	et	3	main
kontrolltöö	doc_535144239977_item	2698009	et	4	main
1	doc_535144239977_item	2698010	et	2	main
kaasa	doc_535144239977_item	2698020	et	4	main
põhjused	doc_535144239976_item	2697952	et	3	main
väga	doc_535144239976_item	2697956	et	3	main
kõige	doc_535144239976_item	2697961	et	4	main
panid	doc_535144239976_item	2697971	et	4	main
kokku	doc_535144239976_item	2697972	et	3	main
ei	doc_535144239976_item	2697977	et	4	main
kasulik	doc_535144239976_item	2697982	et	3	main
soome	doc_535144239976_item	2697984	et	3	main
ja	doc_535144239976_item	2697985	et	3	main
ülikoolid	doc_535144239976_item	2697997	et	3	main
iseloomustage	doc_535144239977_item	2698011	et	4	main
ew	doc_535144239977_item	2698012	et	4	main
külaühiskonda	doc_535144239977_item	2698021	et	4	main
maailmasõda	doc_535144239977_item	2698026	et	4	main
jaoks	doc_535144239977_item	2698028	et	4	main
3	doc_535144239977_item	2698029	et	2	main
tulemusi	doc_535144239977_item	2698037	et	4	main
eesti	doc_535144239977_item	2698053	et	4	main
ew	doc_535144239977_item	2698060	et	4	main
nendest	doc_535144239977_item	2698066	et	4	main
ka	doc_535144239977_item	2698075	et	3	main
kirjutati	doc_535144239977_item	2698076	et	3	main
teema	doc_535144239977_item	2698078	et	4	main
oli	doc_535144239977_item	2698079	et	3	main
sõjast	doc_535144239977_item	2698082	et	3	main
p	doc_535144239977_item	2698084	et	4	main
sest	doc_535144239977_item	2698089	et	4	main
millest	doc_535144239978_item	2698135	et	3	main
sõltus	doc_535144239978_item	2698136	et	4	main
inimeste	doc_535144239978_item	2698137	et	3	main
punaarmeesse	doc_535144239978_item	2698142	et	4	main
ii	doc_535144239978_item	2698147	et	4	main
keerises	doc_535144239978_item	2698149	et	3	main
nimetage	doc_535144239978_item	2698151	et	3	main
teoseid	doc_535144239978_item	2698158	et	3	main
3	doc_535144239978_item	2698159	et	2	main
tõde	doc_535144239978_item	2698166	et	4	main
ja	doc_535144239978_item	2698167	et	3	main
välja	doc_535144239978_item	2698171	et	4	main
esimene	doc_535144239978_item	2698172	et	3	main
1934	doc_535144239978_item	2698174	et	2	main
ahtammsaare	doc_535144239978_item	2698176	et	4	main
kahe	doc_535144239978_item	2698181	et	3	main
köide	doc_535144239978_item	2698183	et	4	main
baltisakslaste	doc_535144239978_item	2698185	et	4	main
lüürika	doc_535144239978_item	2698190	et	4	main
novellistika	doc_535144239978_item	2698191	et	4	main
kontoris	doc_535144239978_item	2698199	et	3	main
tuglas	doc_535144239978_item	2698200	et	4	main
suits	doc_535144239978_item	2698209	et	3	main
on	doc_535144239978_item	2698214	et	4	main
2	doc_535144239978_item	2698219	et	2	main
sõjaväeosades	doc_535144239978_item	2698221	et	3	main
rahvast	doc_535144239978_item	2698232	et	4	main
suri	doc_535144239978_item	2698233	et	3	main
sõja	doc_535144239978_item	2698234	et	3	main
välismaal	doc_535144239978_item	2698242	et	4	main
punaarmees	doc_535144239978_item	2698246	et	3	main
moodustamine	doc_535144239978_item	2698249	et	4	main
astuda	doc_535144239978_item	2698250	et	3	main
mis	doc_535144239978_item	2698267	et	4	main
ka	doc_535144239978_item	2698270	et	3	main
sõjaväkkede	doc_535144239978_item	2698279	et	4	main
noor-eesti	doc_535144239978_item	2698285	et	4	main
gustav	doc_535144239978_item	2698291	et	4	main
tahame	doc_535144239978_item	2698321	et	3	main
euroopa	doc_535144239978_item	2698325	et	4	main
tahame	doc_535144239978_item	2698337	et	3	main
keeles	doc_535144239978_item	2698340	et	4	main
ja	doc_535144239978_item	2698341	et	3	main
säilib	doc_535144239978_item	2698346	et	3	main
ima	doc_535144239978_item	2698355	et	4	main
eestlased	doc_535144239978_item	2698356	et	3	main
ei	doc_535144239978_item	2698357	et	4	main
ole	doc_535144239978_item	2698358	et	4	main
suur	doc_535144239978_item	2698359	et	3	main
ka	doc_535144239978_item	2698362	et	3	main
tuglas	doc_535144239978_item	2698386	et	4	main
fr	doc_535144239978_item	2698387	et	4	main
juhatas	doc_535144239978_item	2698389	et	3	main
eesti	doc_535144239978_item	2698390	et	4	main
mida	doc_535144239977_item	2698023	et	4	main
eestlase	doc_535144239977_item	2698033	et	3	main
sõjamehi	doc_535144239977_item	2698039	et	3	main
ekonoomika	doc_535144239977_item	2698044	et	4	main
aga	doc_535144239977_item	2698047	et	3	main
ms	doc_535144239977_item	2698050	et	4	main
kultuuri	doc_535144239977_item	2698054	et	4	main
ii	doc_535144239977_item	2698056	et	4	main
ms	doc_535144239977_item	2698057	et	4	main
tähendas	doc_535144239977_item	2698058	et	3	main
1	doc_535144239977_item	2698059	et	2	main
olid	doc_535144239977_item	2698067	et	4	main
kultuurielust	doc_535144239977_item	2698068	et	3	main
üks	doc_535144239977_item	2698069	et	3	main
oli	doc_535144239977_item	2698071	et	3	main
kollektiviseerimine	doc_535144239977_item	2698085	et	4	main
raske	doc_535144239977_item	2698093	et	4	main
aeg	doc_535144239977_item	2698094	et	3	main
ja	doc_535144239977_item	2698095	et	3	main
ainult	doc_535144239977_item	2698096	et	4	main
koos	doc_535144239977_item	2698097	et	4	main
võiksid	doc_535144239977_item	2698098	et	4	main
inimesed	doc_535144239977_item	2698099	et	3	main
kõiki	doc_535144239977_item	2698100	et	4	main
parandata	doc_535144239977_item	2698101	et	3	main
hakkasid	doc_535144239977_item	2698102	et	4	main
koosneva	doc_535144239977_item	2698103	et	4	main
erinevad	doc_535144239977_item	2698104	et	4	main
parteid	doc_535144239977_item	2698105	et	4	main
nt	doc_535144239977_item	2698106	et	4	main
eestimaa	doc_535144239977_item	2698107	et	4	main
töökoda	doc_535144239977_item	2698108	et	4	main
partei	doc_535144239977_item	2698109	et	4	main
rohkem	doc_535144239977_item	2698110	et	4	main
tähendust	doc_535144239977_item	2698111	et	4	main
sai	doc_535144239977_item	2698112	et	4	main
põllumajandus	doc_535144239977_item	2698113	et	3	main
kontrolltöö	doc_535144239978_item	2698114	et	4	main
1	doc_535144239978_item	2698115	et	2	main
kelle	doc_535144239978_item	2698116	et	4	main
loominguline	doc_535144239978_item	2698117	et	4	main
kreedo	doc_535144239978_item	2698118	et	4	main
oli	doc_535144239978_item	2698119	et	3	main
olgem	doc_535144239978_item	2698120	et	3	main
kuid	doc_535144239978_item	2698122	et	4	main
eurooplasteks	doc_535144239978_item	2698125	et	3	main
see	doc_535144239978_item	2698127	et	3	main
loosung	doc_535144239978_item	2698128	et	3	main
tänases	doc_535144239978_item	2698131	et	3	main
saksa	doc_535144239978_item	2698139	et	4	main
olid	doc_535144239978_item	2698144	et	4	main
kirjanikkeluuletajad	doc_535144239978_item	2698154	et	4	main
prosaistid	doc_535144239978_item	2698155	et	3	main
ja	doc_535144239978_item	2698156	et	3	main
astumine	doc_535144239978_item	2698138	et	4	main
inimeste	doc_535144239978_item	2698145	et	3	main
peremees	doc_535144239978_item	2698164	et	4	main
1922	doc_535144239978_item	2698165	et	2	main
1926a	doc_535144239978_item	2698169	et	4	main
marie	doc_535144239978_item	2698192	et	4	main
kitzberg	doc_535144239978_item	2698217	et	4	main
eestlased	doc_535144239978_item	2698220	et	3	main
nende	doc_535144239978_item	2698157	et	4	main
kõrboja	doc_535144239978_item	2698163	et	4	main
ilmus	doc_535144239978_item	2698170	et	4	main
kpätsi	doc_535144239978_item	2698179	et	4	main
ja	doc_535144239978_item	2698186	et	3	main
under	doc_535144239978_item	2698193	et	4	main
postimehe	doc_535144239978_item	2698198	et	3	main
juhatas	doc_535144239978_item	2698201	et	3	main
1922	doc_535144239978_item	2698205	et	2	main
visnapuu	doc_535144239978_item	2698206	et	4	main
lüürika	doc_535144239978_item	2698207	et	4	main
raskuse	doc_535144239978_item	2698211	et	4	main
vaim	doc_535144239978_item	2698212	et	3	main
libahunt	doc_535144239978_item	2698218	et	3	main
moodustati	doc_535144239978_item	2698223	et	3	main
ajal	doc_535144239978_item	2698235	et	4	main
nt	doc_535144239978_item	2698244	et	4	main
leningradis	doc_535144239978_item	2698245	et	4	main
eesti	doc_535144239978_item	2698247	et	4	main
rahvuslikeväeosade	doc_535144239978_item	2698248	et	4	main
päästa	doc_535144239978_item	2698253	et	4	main
vahel	doc_535144239978_item	2698266	et	4	main
tähendas	doc_535144239978_item	2698269	et	3	main
ainult	doc_535144239978_item	2698278	et	4	main
kultuuri	doc_535144239978_item	2698333	et	4	main
enda	doc_535144239978_item	2698334	et	4	main
keele	doc_535144239978_item	2698335	et	4	main
oma	doc_535144239978_item	2698339	et	4	main
ka	doc_535144239978_item	2698347	et	3	main
kuid	doc_535144239978_item	2698361	et	4	main
meil	doc_535144239978_item	2698363	et	4	main
1922	doc_535144239978_item	2698383	et	2	main
andson	doc_535144239978_item	2698385	et	4	main
1922	doc_535144239978_item	2698393	et	2	main
töötas	doc_535144239978_item	2698394	et	3	main
postimehe	doc_535144239978_item	2698395	et	3	main
kontoris	doc_535144239978_item	2698396	et	3	main
3	doc_535144239979_item	2698421	et	2	main
rahvas	doc_535144239979_item	2698438	et	4	main
nõutis	doc_535144239979_item	2698439	et	4	main
sotsialistliku	doc_535144239979_item	2698440	et	3	main
ja	doc_535144239979_item	2698441	et	3	main
rahvuse	doc_535144239979_item	2698442	et	3	main
vabadust	doc_535144239979_item	2698443	et	4	main
nad	doc_535144239979_item	2698444	et	3	main
palga	doc_535144239979_item	2698449	et	3	main
väiksed	doc_535144239979_item	2698451	et	4	main
autonoomiat	doc_535144239979_item	2698454	et	3	main
mässamine	doc_535144239979_item	2698464	et	4	main
põletamine	doc_535144239979_item	2698469	et	4	main
kindral	doc_535144239979_item	2698473	et	4	main
ja	doc_535144239979_item	2698475	et	3	main
püüdsid	doc_535144239979_item	2698481	et	4	main
panna	doc_535144239979_item	2698483	et	4	main
talupojad	doc_535144239979_item	2698488	et	4	main
üldmobiliseerimine	doc_535144239978_item	2698229	et	3	main
palju	doc_535144239978_item	2698230	et	4	main
kättemaksta	doc_535144239978_item	2698237	et	4	main
kasutamiseks	doc_535144239978_item	2698243	et	4	main
hukatuslikest	doc_535144239978_item	2698256	et	3	main
inimene	doc_535144239978_item	2698258	et	3	main
valida	doc_535144239978_item	2698260	et	3	main
töölaagrite	doc_535144239978_item	2698262	et	3	main
surma	doc_535144239978_item	2698263	et	4	main
või	doc_535144239978_item	2698264	et	4	main
väeosade	doc_535144239978_item	2698265	et	3	main
töötasid	doc_535144239978_item	2698277	et	4	main
olid	doc_535144239978_item	2698290	et	4	main
suits	doc_535144239978_item	2698292	et	3	main
johannes	doc_535144239978_item	2698293	et	4	main
aavik	doc_535144239978_item	2698294	et	4	main
kitzberg	doc_535144239978_item	2698295	et	4	main
kuid	doc_535144239978_item	2698296	et	4	main
ta	doc_535144239978_item	2698297	et	4	main
oli	doc_535144239978_item	2698298	et	3	main
vanema	doc_535144239978_item	2698299	et	4	main
põlvkonna	doc_535144239978_item	2698300	et	4	main
inimene	doc_535144239978_item	2698301	et	3	main
tõnisson	doc_535144239978_item	2698302	et	4	main
noor-eesti	doc_535144239978_item	2698303	et	4	main
oli	doc_535144239978_item	2698304	et	3	main
kirjanduslik	doc_535144239978_item	2698305	et	3	main
rühmitus	doc_535144239978_item	2698306	et	4	main
see	doc_535144239978_item	2698307	et	3	main
loosung	doc_535144239978_item	2698308	et	3	main
on	doc_535144239978_item	2698309	et	4	main
aktuaalne	doc_535144239978_item	2698310	et	3	main
ka	doc_535144239978_item	2698311	et	3	main
tänases	doc_535144239978_item	2698312	et	3	main
eesti	doc_535144239978_item	2698313	et	4	main
ühiskonnas	doc_535144239978_item	2698314	et	4	main
eesti	doc_535144239978_item	2698315	et	4	main
just	doc_535144239978_item	2698316	et	3	main
astus	doc_535144239978_item	2698317	et	3	main
euroopa	doc_535144239978_item	2698318	et	4	main
liidu	doc_535144239978_item	2698319	et	3	main
me	doc_535144239978_item	2698320	et	4	main
oma	doc_535144239978_item	2698323	et	4	main
tasa	doc_535144239978_item	2698326	et	3	main
piirini	doc_535144239978_item	2698327	et	4	main
kuid	doc_535144239978_item	2698328	et	4	main
me	doc_535144239978_item	2698329	et	4	main
tahame	doc_535144239978_item	2698330	et	3	main
areneda	doc_535144239978_item	2698331	et	3	main
keeles	doc_535144239978_item	2698344	et	4	main
oma	doc_535144239978_item	2698367	et	4	main
ja	doc_535144239978_item	2698381	et	3	main
oli	doc_535144239978_item	2698284	et	3	main
kreedo	doc_535144239978_item	2698287	et	4	main
elatustasa	doc_535144239978_item	2698324	et	4	main
rääkida	doc_535144239978_item	2698338	et	3	main
õppida	doc_535144239978_item	2698342	et	3	main
eesti	doc_535144239978_item	2698343	et	4	main
meie	doc_535144239978_item	2698348	et	4	main
eesti	doc_535144239978_item	2698350	et	4	main
rootsi	doc_535144239978_item	2698353	et	4	main
säilis	doc_535144239978_item	2698354	et	4	main
keel	doc_535144239978_item	2698368	et	4	main
oma	doc_535144239978_item	2698369	et	4	main
soovere	doc_535144239978_item	2698379	et	4	main
surm	doc_535144239978_item	2698382	et	3	main
ms	doc_535144239978_item	2698399	et	4	main
tähendas	doc_535144239978_item	2698400	et	3	main
okupeerimist	doc_535144239978_item	2698401	et	4	main
küüdatamist	doc_535144239978_item	2698402	et	4	main
elatustase	doc_535144239978_item	2698403	et	3	main
langes	doc_535144239978_item	2698404	et	4	main
kontrolltöö	doc_535144239979_item	2698405	et	4	main
1	doc_535144239979_item	2698406	et	2	main
anna	doc_535144239979_item	2698407	et	4	main
ülevaade	doc_535144239979_item	2698408	et	3	main
rahvusteaduste	doc_535144239979_item	2698409	et	3	main
arengust	doc_535144239979_item	2698410	et	3	main
eesti	doc_535144239979_item	2698411	et	4	main
wabariigis	doc_535144239979_item	2698412	et	4	main
2	doc_535144239979_item	2698413	et	2	main
hinda	doc_535144239979_item	2698414	et	4	main
1905	doc_535144239979_item	2698415	et	2	main
aasta	doc_535144239979_item	2698416	et	4	main
sündmuste	doc_535144239979_item	2698417	et	3	main
tähtsust	doc_535144239979_item	2698418	et	4	main
eesti	doc_535144239979_item	2698419	et	4	main
ajaloos	doc_535144239979_item	2698420	et	4	main
sotsialistlikku	doc_535144239979_item	2698423	et	4	main
filmi	doc_535144239979_item	2698427	et	4	main
aastal	doc_535144239979_item	2698434	et	3	main
toimus	doc_535144239979_item	2698435	et	3	main
revolutsioon	doc_535144239979_item	2698436	et	3	main
eesti	doc_535144239979_item	2698437	et	4	main
nõutsid	doc_535144239979_item	2698445	et	4	main
tööpäeva	doc_535144239979_item	2698446	et	4	main
riigid	doc_535144239979_item	2698452	et	3	main
töökatkestamisega	doc_535144239979_item	2698459	et	3	main
narvas	doc_535144239979_item	2698460	et	4	main
14	doc_535144239979_item	2698461	et	2	main
17	doc_535144239979_item	2698462	et	2	main
detsember	doc_535144239979_item	2698463	et	3	main
100	doc_535144239979_item	2698470	et	2	main
eestisse	doc_535144239979_item	2698471	et	4	main
bezobrazov	doc_535144239979_item	2698474	et	4	main
et	doc_535144239979_item	2698491	et	3	main
see	doc_535144239979_item	2698492	et	3	main
ei	doc_535144239979_item	2698493	et	4	main
aastal	doc_535144239979_item	2698500	et	3	main
bernhard	doc_535144239979_item	2698535	et	4	main
rohkem	doc_535144239979_item	2698554	et	4	main
eesti	doc_535144239979_item	2698564	et	4	main
eesti	doc_535144239979_item	2698572	et	4	main
usuvabadusest	doc_535144239979_item	2698579	et	4	main
sai	doc_535144239979_item	2698581	et	4	main
mmetsanurg	doc_535144239978_item	2698377	et	4	main
taavet	doc_535144239978_item	2698378	et	3	main
elu	doc_535144239978_item	2698380	et	4	main
jsemper	doc_535144239978_item	2698384	et	4	main
valgus	doc_535144239979_item	2698428	et	4	main
koordis	doc_535144239979_item	2698429	et	4	main
tõstmist	doc_535144239979_item	2698450	et	4	main
nõutsid	doc_535144239979_item	2698453	et	4	main
rahvas	doc_535144239979_item	2698455	et	4	main
näitas	doc_535144239979_item	2698456	et	3	main
tuli	doc_535144239979_item	2698465	et	4	main
jõudis	doc_535144239979_item	2698472	et	3	main
karistussalk	doc_535144239979_item	2698477	et	3	main
nad	doc_535144239979_item	2698480	et	3	main
kuulma	doc_535144239979_item	2698482	et	3	main
karistada	doc_535144239979_item	2698487	et	3	main
said	doc_535144239979_item	2698489	et	4	main
aru	doc_535144239979_item	2698490	et	4	main
õigusi	doc_535144239979_item	2698497	et	4	main
nõuda	doc_535144239979_item	2698498	et	3	main
1909	doc_535144239979_item	2698499	et	2	main
korraldaja	doc_535144239979_item	2698521	et	4	main
valis	doc_535144239979_item	2698525	et	3	main
peksmise	doc_535144239979_item	2698526	et	4	main
1912	doc_535144239979_item	2698532	et	2	main
aastal	doc_535144239979_item	2698533	et	3	main
novelli	doc_535144239979_item	2698534	et	4	main
1992	doc_535144239979_item	2698538	et	2	main
oli	doc_535144239979_item	2698540	et	3	main
sai	doc_535144239979_item	2698553	et	4	main
eestlastele	doc_535144239979_item	2698563	et	4	main
tsaari	doc_535144239979_item	2698577	et	4	main
inimene	doc_535144239979_item	2698580	et	3	main
millesse	doc_535144239979_item	2698583	et	3	main
sotsid	doc_535144239979_item	2698589	et	3	main
võidelta	doc_535144239979_item	2698591	et	4	main
olid	doc_535144239979_item	2698604	et	4	main
eesti	doc_535144239979_item	2698607	et	4	main
1920	doc_535144239979_item	2698610	et	2	main
ja	doc_535144239979_item	2698621	et	3	main
neurokirurg	doc_535144239979_item	2698625	et	3	main
eestis	doc_535144239979_item	2698631	et	3	main
haritlaskond	doc_535144239979_item	2698633	et	3	main
asutakse	doc_535144239979_item	2698634	et	4	main
3-astmeliseks	doc_535144239979_item	2698656	et	4	main
tasuta	doc_535144239979_item	2698659	et	4	main
õppida	doc_535144239979_item	2698661	et	3	main
eesti	doc_535144239979_item	2698663	et	4	main
tasuline	doc_535144239979_item	2698668	et	4	main
ülikool	doc_535144239979_item	2698669	et	4	main
süstemaatiline	doc_535144239979_item	2698682	et	3	main
ahtammsaare	doc_535144239979_item	2698686	et	4	main
riigivanema	doc_535144239979_item	2698688	et	4	main
kpätsi	doc_535144239979_item	2698689	et	4	main
kirjanduspreemiat	doc_535144239979_item	2698690	et	3	main
ametlikuks	doc_535144239979_item	2698736	et	3	main
antakse	doc_535144239979_item	2698740	et	3	main
1928	doc_535144239979_item	2698756	et	2	main
eesti	doc_535144239979_item	2698758	et	4	main
tsensuur	doc_535144239979_item	2698766	et	3	main
elamisviisi	doc_535144239979_item	2698771	et	4	main
kirjanduslik	doc_535144239979_item	2698773	et	3	main
ajal	doc_535144239979_item	2698776	et	4	main
kus	doc_535144239979_item	2698777	et	3	main
filmis	doc_535144239979_item	2698781	et	4	main
valgus	doc_535144239979_item	2698782	et	4	main
kõikide	doc_535144239979_item	2698789	et	4	main
elu	doc_535144239979_item	2698799	et	4	main
filmi	doc_535144239979_item	2698807	et	4	main
sotsialism	doc_535144239979_item	2698821	et	3	main
arheoloogiline	doc_53629148792_item	2698833	et	4	main
kultuur	doc_53629148792_item	2698834	et	3	main
inimgrupile	doc_53629148792_item	2698836	et	3	main
iseloomulik	doc_53629148792_item	2698837	et	3	main
materiaalne	doc_53629148792_item	2698838	et	3	main
ja	doc_53629148792_item	2698839	et	3	main
vaimne	doc_53629148792_item	2698840	et	3	main
kultuur	doc_53629148792_item	2698841	et	3	main
mis	doc_53629148792_item	2698842	et	4	main
ilmneb	doc_53629148792_item	2698843	et	3	main
käigus	doc_53629148792_item	2698846	et	4	main
mihkelson	doc_535144239978_item	2698388	et	4	main
kirjanikke	doc_535144239978_item	2698391	et	3	main
liidu	doc_535144239978_item	2698392	et	3	main
2	doc_535144239978_item	2698397	et	2	main
ii	doc_535144239978_item	2698398	et	4	main
kirjelda	doc_535144239979_item	2698422	et	4	main
realismi	doc_535144239979_item	2698424	et	4	main
kui	doc_535144239979_item	2698425	et	3	main
loomismeetodit	doc_535144239979_item	2698426	et	3	main
põhjal	doc_535144239979_item	2698431	et	4	main
2	doc_535144239979_item	2698432	et	2	main
1905	doc_535144239979_item	2698433	et	2	main
ja	doc_535144239979_item	2698448	et	3	main
oma	doc_535144239979_item	2698457	et	4	main
protesti	doc_535144239979_item	2698458	et	4	main
mõisade	doc_535144239979_item	2698468	et	4	main
tema	doc_535144239979_item	2698476	et	4	main
relvi	doc_535144239979_item	2698478	et	4	main
abiga	doc_535144239979_item	2698479	et	3	main
talupojad	doc_535144239979_item	2698485	et	4	main
ja	doc_535144239979_item	2698486	et	3	main
ole	doc_535144239979_item	2698494	et	4	main
asemele	doc_535144239979_item	2698527	et	4	main
tapmist	doc_535144239979_item	2698528	et	4	main
br	doc_535144239979_item	2698542	et	4	main
eesti	doc_535144239979_item	2698543	et	4	main
seega	doc_535144239979_item	2698545	et	4	main
lühenes	doc_535144239979_item	2698546	et	3	main
10	doc_535144239979_item	2698549	et	2	main
eesti	doc_535144239979_item	2698551	et	4	main
keel	doc_535144239979_item	2698552	et	4	main
õigusi	doc_535144239979_item	2698555	et	4	main
koolis	doc_535144239979_item	2698556	et	4	main
said	doc_535144239979_item	2698567	et	4	main
õppida	doc_535144239979_item	2698568	et	3	main
kõrgkoolides	doc_535144239979_item	2698569	et	3	main
võimalus	doc_535144239979_item	2698570	et	3	main
erakoole	doc_535144239979_item	2698574	et	4	main
ukaasiga	doc_535144239979_item	2698578	et	3	main
jumalat	doc_535144239979_item	2698588	et	3	main
võimu	doc_535144239979_item	2698595	et	4	main
vastu	doc_535144239979_item	2698596	et	3	main
võitlus	doc_535144239979_item	2698597	et	3	main
usuõpetamise	doc_535144239979_item	2698598	et	3	main
vastu	doc_535144239979_item	2698599	et	3	main
koolides	doc_535144239979_item	2698600	et	3	main
on	doc_535144239979_item	2698613	et	4	main
monoetniline	doc_535144239979_item	2698614	et	3	main
domineerib	doc_535144239979_item	2698615	et	3	main
üks	doc_535144239979_item	2698616	et	3	main
esimesena	doc_535144239979_item	2698626	et	3	main
hakkas	doc_535144239979_item	2698628	et	3	main
eesti	doc_535144239979_item	2698638	et	4	main
juht	doc_535144239979_item	2698641	et	3	main
6-klassiline	doc_535144239979_item	2698657	et	4	main
põhikool	doc_535144239979_item	2698658	et	4	main
võib	doc_535144239979_item	2698660	et	3	main
5-klassiline	doc_535144239979_item	2698665	et	4	main
gümnaasium	doc_535144239979_item	2698666	et	3	main
humanitaar-	doc_535144239979_item	2698674	et	4	main
ja	doc_535144239979_item	2698675	et	3	main
reaalharu	doc_535144239979_item	2698676	et	4	main
1934	doc_535144239979_item	2698677	et	2	main
aastal	doc_535144239979_item	2698678	et	3	main
koolireform	doc_535144239979_item	2698679	et	3	main
kunstiõpetus	doc_535144239979_item	2698683	et	3	main
sai	doc_535144239979_item	2698687	et	4	main
riigi	doc_535144239979_item	2698722	et	3	main
sini-must-valge	doc_535144239979_item	2698733	et	4	main
trikoloor	doc_535144239979_item	2698734	et	3	main
võetakse	doc_535144239979_item	2698735	et	3	main
kultuurautonoomiat	doc_535144239979_item	2698741	et	3	main
piirides	doc_535144239979_item	2698744	et	3	main
nad	doc_535144239979_item	2698747	et	3	main
enda	doc_535144239979_item	2698754	et	4	main
kroon	doc_535144239979_item	2698759	et	3	main
markaga	doc_535144239979_item	2698761	et	4	main
näitakse	doc_535144239979_item	2698778	et	4	main
hea	doc_535144239979_item	2698785	et	4	main
kui	doc_535144239979_item	2698786	et	3	main
maa	doc_535144239979_item	2698787	et	4	main
harida	doc_535144239979_item	2698793	et	3	main
nähtu	doc_535144239979_item	2698430	et	4	main
lühenemist	doc_535144239979_item	2698447	et	4	main
maale	doc_535144239979_item	2698466	et	4	main
algas	doc_535144239979_item	2698467	et	3	main
rahvas	doc_535144239979_item	2698484	et	4	main
õige	doc_535144239979_item	2698495	et	4	main
tee	doc_535144239979_item	2698496	et	4	main
bozobrazov	doc_535144239979_item	2698501	et	4	main
koos	doc_535144239979_item	2698502	et	4	main
oma	doc_535144239979_item	2698503	et	4	main
karistussalgiga	doc_535144239979_item	2698504	et	3	main
tegi	doc_535144239979_item	2698505	et	4	main
veresaun	doc_535144239979_item	2698506	et	3	main
tol	doc_535144239979_item	2698507	et	3	main
ajal	doc_535144239979_item	2698508	et	4	main
suri	doc_535144239979_item	2698509	et	3	main
eesti	doc_535144239979_item	2698510	et	4	main
kangelane	doc_535144239979_item	2698511	et	3	main
bernhard	doc_535144239979_item	2698512	et	4	main
laipmann	doc_535144239979_item	2698513	et	3	main
kes	doc_535144239979_item	2698514	et	4	main
oli	doc_535144239979_item	2698515	et	3	main
paiba	doc_535144239979_item	2698516	et	4	main
talu	doc_535144239979_item	2698517	et	4	main
peremees	doc_535144239979_item	2698518	et	4	main
vigala	doc_535144239979_item	2698519	et	4	main
seltsielu	doc_535144239979_item	2698520	et	4	main
juht	doc_535144239979_item	2698523	et	3	main
ta	doc_535144239979_item	2698524	et	4	main
kallas	doc_535144239979_item	2698530	et	4	main
kirjutas	doc_535144239979_item	2698531	et	3	main
ja	doc_535144239979_item	2698537	et	3	main
aastal	doc_535144239979_item	2698539	et	3	main
avati	doc_535144239979_item	2698557	et	3	main
kutsekoolid	doc_535144239979_item	2698558	et	3	main
kohustuslik	doc_535144239979_item	2698559	et	3	main
algklassiline	doc_535144239979_item	2698560	et	4	main
haridus	doc_535144239979_item	2698561	et	3	main
ka	doc_535144239979_item	2698562	et	3	main
avada	doc_535144239979_item	2698571	et	3	main
aastal	doc_535144239979_item	2698576	et	3	main
eitati	doc_535144239979_item	2698587	et	4	main
sest	doc_535144239979_item	2698601	et	4	main
baltisakslased	doc_535144239979_item	2698605	et	3	main
põllumajanduslik	doc_535144239979_item	2698619	et	3	main
puusepp	doc_535144239979_item	2698623	et	3	main
maailmas	doc_535144239979_item	2698627	et	3	main
tegema	doc_535144239979_item	2698629	et	3	main
kasvab	doc_535144239979_item	2698632	et	3	main
jaavik	doc_535144239979_item	2698642	et	4	main
eesti	doc_535144239979_item	2698648	et	4	main
ooper	doc_535144239979_item	2698649	et	3	main
keeles	doc_535144239979_item	2698664	et	4	main
osaliselt	doc_535144239979_item	2698667	et	4	main
avatakse	doc_535144239979_item	2698680	et	4	main
kutsekoolid	doc_535144239979_item	2698681	et	3	main
1934	doc_535144239979_item	2698684	et	2	main
dets	doc_535144239979_item	2698721	et	4	main
vallutada	doc_535144239979_item	2698725	et	3	main
objekte	doc_535144239979_item	2698727	et	3	main
nt	doc_535144239979_item	2698728	et	4	main
muusikaseltsi	doc_535144239979_item	2698522	et	4	main
aino	doc_535144239979_item	2698529	et	4	main
riives	doc_535144239979_item	2698536	et	4	main
esitlus	doc_535144239979_item	2698541	et	4	main
draamateatris	doc_535144239979_item	2698544	et	3	main
tööpäev	doc_535144239979_item	2698547	et	3	main
umbes	doc_535144239979_item	2698548	et	4	main
tundi	doc_535144239979_item	2698550	et	4	main
soost	doc_535144239979_item	2698565	et	4	main
tüdrukud	doc_535144239979_item	2698566	et	3	main
keelseid	doc_535144239979_item	2698573	et	3	main
1905	doc_535144239979_item	2698575	et	2	main
valida	doc_535144239979_item	2698582	et	3	main
usuõpetajatest	doc_535144239979_item	2698603	et	4	main
1	doc_535144239979_item	2698606	et	2	main
wabariigi	doc_535144239979_item	2698608	et	4	main
aeg	doc_535144239979_item	2698609	et	3	main
1939	doc_535144239979_item	2698611	et	2	main
eesti	doc_535144239979_item	2698612	et	4	main
rahvas	doc_535144239979_item	2698617	et	4	main
arstiteadus	doc_535144239979_item	2698620	et	4	main
põllumajandus	doc_535144239979_item	2698622	et	3	main
tuntud	doc_535144239979_item	2698624	et	4	main
ajuoperatsioone	doc_535144239979_item	2698630	et	3	main
usi	doc_535144239979_item	2698635	et	4	main
liite	doc_535144239979_item	2698636	et	4	main
lauljate	doc_535144239979_item	2698639	et	4	main
areneb	doc_535144239979_item	2698643	et	3	main
kultuurielu	doc_535144239979_item	2698645	et	4	main
esimene	doc_535144239979_item	2698647	et	3	main
ka	doc_535144239979_item	2698662	et	3	main
harud	doc_535144239979_item	2698673	et	3	main
juuni	doc_535144239979_item	2698731	et	4	main
1922	doc_535144239979_item	2698732	et	2	main
1925	doc_535144239979_item	2698738	et	2	main
saavad	doc_535144239979_item	2698748	et	4	main
õppida	doc_535144239979_item	2698749	et	3	main
ema	doc_535144239979_item	2698750	et	4	main
keeles	doc_535144239979_item	2698751	et	4	main
emakeelne	doc_535144239979_item	2698752	et	3	main
1934	doc_535144239979_item	2698763	et	2	main
3	doc_535144239979_item	2698768	et	2	main
realism	doc_535144239979_item	2698770	et	3	main
meetod	doc_535144239979_item	2698774	et	3	main
koordis	doc_535144239979_item	2698783	et	4	main
kui	doc_535144239979_item	2698784	et	3	main
kõik	doc_535144239979_item	2698795	et	4	main
on	doc_535144239979_item	2698800	et	4	main
kolhoosides	doc_535144239979_item	2698801	et	3	main
ja	doc_535144239979_item	2698802	et	3	main
tähendus	doc_53629148792_item	2698831	et	4	main
2	doc_53629148792_item	2698832	et	2	main
igale	doc_53629148792_item	2698847	et	3	main
ja	doc_53629148792_item	2698854	et	3	main
kindel	doc_53629148792_item	2698857	et	3	main
territoorium	doc_53629148792_item	2698858	et	3	main
ja	doc_53629148792_item	2698859	et	3	main
ajajärk	doc_53629148792_item	2698860	et	3	main
paleoliitikumiks	doc_53629148792_item	2698864	et	3	main
kiviaeg	doc_53629148792_item	2698869	et	3	main
mesoliitikum	doc_53629148792_item	2698882	et	3	main
valgevene	doc_53629148792_item	2698922	et	4	main
mesoliitikumi	doc_53629148792_item	2698943	et	4	main
tumedama	doc_53629148792_item	2698950	et	4	main
mesoliitikumist	doc_53629148792_item	2698952	et	4	main
on	doc_53629148792_item	2698955	et	4	main
seotud	doc_53629148792_item	2698956	et	4	main
haug	doc_53629148792_item	2698967	et	3	main
eesti	doc_53629148792_item	2698977	et	4	main
küttide	doc_53629148792_item	2698990	et	3	main
ja	doc_53629148792_item	2698991	et	3	main
korilaste	doc_53629148792_item	2698992	et	3	main
tegemine	doc_53629148792_item	2699028	et	4	main
narva	doc_53629148792_item	2699029	et	4	main
vanem	doc_53629148792_item	2699033	et	4	main
nii	doc_53629148792_item	2699034	et	3	main
eestis	doc_53629148792_item	2699035	et	3	main
kui	doc_53629148792_item	2699036	et	3	main
venemaal	doc_53629148792_item	2699038	et	4	main
sisse	doc_53629148792_item	2699047	et	4	main
sellise	doc_53629148792_item	2699059	et	4	main
esemetel	doc_53629148792_item	2699062	et	3	main
ka	doc_53629148792_item	2699069	et	3	main
soome-ugri	doc_53629148792_item	2699073	et	3	main
kultuuri	doc_53629148792_item	2699075	et	4	main
ei	doc_53629148792_item	2699078	et	4	main
eesti	doc_53629148792_item	2699122	et	4	main
hakati	doc_53629148792_item	2699127	et	3	main
inimesi	doc_53629148792_item	2699132	et	4	main
tavaliselt	doc_53629148792_item	2699136	et	4	main
kirikusse	doc_535144239979_item	2698584	et	4	main
kuuluda	doc_535144239979_item	2698585	et	4	main
ateism	doc_535144239979_item	2698586	et	3	main
tahtsid	doc_535144239979_item	2698590	et	4	main
kiriku	doc_535144239979_item	2698592	et	3	main
ja	doc_535144239979_item	2698593	et	3	main
religiose	doc_535144239979_item	2698594	et	4	main
74	doc_535144239979_item	2698602	et	2	main
agraarriik	doc_535144239979_item	2698618	et	3	main
nt	doc_535144239979_item	2698637	et	4	main
liit	doc_535144239979_item	2698640	et	3	main
haridus	doc_535144239979_item	2698644	et	3	main
teadus	doc_535144239979_item	2698646	et	4	main
vikerlased	doc_535144239979_item	2698650	et	3	main
aav	doc_535144239979_item	2698651	et	4	main
tekkivad	doc_535144239979_item	2698652	et	4	main
ühtlaskoolid	doc_535144239979_item	2698653	et	4	main
koolisüsteem	doc_535144239979_item	2698654	et	3	main
muutub	doc_535144239979_item	2698655	et	3	main
tasuline	doc_535144239979_item	2698670	et	4	main
gümnaasiumis	doc_535144239979_item	2698671	et	3	main
kaks	doc_535144239979_item	2698672	et	3	main
aastal	doc_535144239979_item	2698685	et	3	main
tõde	doc_535144239979_item	2698691	et	4	main
ja	doc_535144239979_item	2698692	et	3	main
õigus	doc_535144239979_item	2698693	et	4	main
2	doc_535144239979_item	2698694	et	2	main
viimase	doc_535144239979_item	2698695	et	3	main
köide	doc_535144239979_item	2698696	et	4	main
eest	doc_535144239979_item	2698697	et	4	main
baltisakslaste	doc_535144239979_item	2698698	et	4	main
ja	doc_535144239979_item	2698699	et	3	main
eestlaste	doc_535144239979_item	2698700	et	4	main
suhted	doc_535144239979_item	2698701	et	3	main
1920	doc_535144239979_item	2698702	et	2	main
aastal	doc_535144239979_item	2698703	et	3	main
esimene	doc_535144239979_item	2698704	et	3	main
põhiseadus	doc_535144239979_item	2698705	et	4	main
1937	doc_535144239979_item	2698706	et	2	main
uuendatud	doc_535144239979_item	2698707	et	4	main
põhiseadus	doc_535144239979_item	2698708	et	4	main
1919	doc_535144239979_item	2698709	et	2	main
aastal	doc_535144239979_item	2698710	et	3	main
maareform	doc_535144239979_item	2698711	et	3	main
kirikumaad	doc_535144239979_item	2698712	et	4	main
mõistnikude	doc_535144239979_item	2698713	et	4	main
baltisaksa	doc_535144239979_item	2698714	et	4	main
maad	doc_535144239979_item	2698715	et	4	main
jagatakse	doc_535144239979_item	2698716	et	3	main
talupoegade	doc_535144239979_item	2698717	et	3	main
vahel	doc_535144239979_item	2698718	et	4	main
1924	doc_535144239979_item	2698719	et	2	main
1	doc_535144239979_item	2698720	et	2	main
pördekatse	doc_535144239979_item	2698723	et	4	main
püüti	doc_535144239979_item	2698724	et	3	main
olulisemaid	doc_535144239979_item	2698726	et	4	main
kõigidele	doc_535144239979_item	2698742	et	4	main
kirikud	doc_535144239979_item	2698755	et	3	main
aastal	doc_535144239979_item	2698757	et	3	main
seotud	doc_535144239979_item	2698762	et	4	main
vaikivperiood	doc_535144239979_item	2698765	et	4	main
kontroll	doc_535144239979_item	2698767	et	3	main
sotsialistlik	doc_535144239979_item	2698769	et	3	main
oma	doc_535144239979_item	2698790	et	4	main
kui	doc_535144239979_item	2698791	et	3	main
hea	doc_535144239979_item	2698792	et	4	main
sofhoosides	doc_535144239979_item	2698803	et	4	main
kirjutasid	doc_535144239979_item	2698805	et	4	main
sellest	doc_535144239979_item	2698806	et	4	main
tegid	doc_535144239979_item	2698809	et	4	main
süzheedid	doc_535144239979_item	2698810	et	4	main
sellel	doc_535144239979_item	2698811	et	4	main
teemal	doc_535144239979_item	2698812	et	3	main
igal	doc_535144239979_item	2698813	et	3	main
pool	doc_535144239979_item	2698814	et	4	main
oli	doc_535144239979_item	2698815	et	3	main
vaja	doc_535144239979_item	2698816	et	4	main
näidata	doc_535144239979_item	2698817	et	4	main
kui	doc_535144239979_item	2698818	et	3	main
hea	doc_535144239979_item	2698819	et	4	main
on	doc_535144239979_item	2698820	et	4	main
kontrolltöö	doc_53629148792_item	2698822	et	4	main
kiviaeg	doc_53629148792_item	2698824	et	3	main
territooriumil	doc_53629148792_item	2698826	et	3	main
mõiste	doc_53629148792_item	2698828	et	4	main
arheoloogiline	doc_53629148792_item	2698829	et	4	main
kultuur	doc_53629148792_item	2698830	et	3	main
arheoloogilise	doc_53629148792_item	2698844	et	4	main
paleoliitikum	doc_53629148792_item	2698867	et	3	main
vanem	doc_53629148792_item	2698868	et	4	main
avastada	doc_53629148792_item	2698872	et	3	main
oli	doc_53629148792_item	2698877	et	3	main
kiviaeg	doc_53629148792_item	2698884	et	3	main
kitsa	doc_53629148792_item	2698946	et	3	main
juustega	doc_53629148792_item	2698949	et	3	main
hahaga	doc_53629148792_item	2698951	et	3	main
sõnad	doc_53629148792_item	2698954	et	4	main
soo	doc_53629148792_item	2698966	et	4	main
kunda	doc_53629148792_item	2698970	et	4	main
aluse	doc_53629148792_item	2698976	et	4	main
saab	doc_53629148792_item	2698983	et	3	main
on	doc_53629148792_item	2699024	et	4	main
l	doc_53629148792_item	2699040	et	4	main
tehti	doc_53629148792_item	2699044	et	3	main
savist	doc_53629148792_item	2699046	et	4	main
segati	doc_53629148792_item	2699048	et	3	main
kivipudru	doc_53629148792_item	2699049	et	3	main
at	doc_53629148792_item	2699056	et	4	main
pärast	doc_53629148792_item	2699067	et	4	main
kujundeid	doc_53629148792_item	2699071	et	3	main
tunnus	doc_53629148792_item	2699076	et	3	main
loodusmotiive	doc_53629148792_item	2699077	et	3	main
veel	doc_53629148792_item	2699083	et	4	main
matmiskomme	doc_53629148792_item	2699126	et	4	main
esialgu	doc_53629148792_item	2699130	et	3	main
nagu	doc_53629148792_item	2699134	et	3	main
karti	doc_53629148792_item	2699142	et	4	main
elati	doc_53629148792_item	2699143	et	3	main
35-40	doc_53629148792_item	2699144	et	2	main
pärast	doc_53629148792_item	2699153	et	4	main
hakati	doc_53629148792_item	2699154	et	3	main
sõltus	doc_53629148792_item	2699162	et	4	main
raudteejaamad	doc_535144239979_item	2698729	et	3	main
27	doc_535144239979_item	2698730	et	2	main
lipuks	doc_535144239979_item	2698737	et	3	main
aastal	doc_535144239979_item	2698739	et	3	main
eesti	doc_535144239979_item	2698743	et	4	main
elavatele	doc_535144239979_item	2698745	et	4	main
vähemusrahvustele	doc_535144239979_item	2698746	et	3	main
trükkisõna	doc_535144239979_item	2698753	et	4	main
saksa	doc_535144239979_item	2698760	et	4	main
aastal	doc_535144239979_item	2698764	et	3	main
meetod	doc_535144239979_item	2698772	et	3	main
vene	doc_535144239979_item	2698775	et	4	main
nagu	doc_535144239979_item	2698779	et	3	main
esitatud	doc_535144239979_item	2698780	et	4	main
on	doc_535144239979_item	2698788	et	4	main
seda	doc_535144239979_item	2698794	et	3	main
kui	doc_535144239979_item	2698797	et	3	main
hea	doc_535144239979_item	2698798	et	4	main
tegijad	doc_535144239979_item	2698808	et	4	main
koos	doc_535144239979_item	2698796	et	4	main
kirjanikud	doc_535144239979_item	2698804	et	3	main
teatud	doc_53629148792_item	2698835	et	4	main
arheoloogilise	doc_53629148792_item	2698848	et	4	main
on	doc_53629148792_item	2698850	et	4	main
sarnased	doc_53629148792_item	2698852	et	4	main
muistised	doc_53629148792_item	2698855	et	3	main
mesoliitikumiks	doc_53629148792_item	2698865	et	3	main
raske	doc_53629148792_item	2698871	et	4	main
peatuspaiku	doc_53629148792_item	2698874	et	3	main
kuna	doc_53629148792_item	2698875	et	3	main
keskmine	doc_53629148792_item	2698883	et	3	main
1	doc_53629148792_item	2698823	et	2	main
eesti	doc_53629148792_item	2698825	et	4	main
2	doc_53629148792_item	2698827	et	2	main
uurimistöö	doc_53629148792_item	2698845	et	4	main
kultuurile	doc_53629148792_item	2698849	et	3	main
omased	doc_53629148792_item	2698851	et	3	main
leiud	doc_53629148792_item	2698853	et	3	main
ning	doc_53629148792_item	2698856	et	3	main
1	doc_53629148792_item	2698861	et	2	main
kiviaeg	doc_53629148792_item	2698862	et	3	main
jaguneb	doc_53629148792_item	2698863	et	3	main
mandrijää	doc_53629148792_item	2698881	et	4	main
ix	doc_53629148792_item	2698885	et	4	main
lõpp	doc_53629148792_item	2698887	et	3	main
iv	doc_53629148792_item	2698888	et	4	main
at	doc_53629148792_item	2698886	et	4	main
at	doc_53629148792_item	2698889	et	4	main
kesk	doc_53629148792_item	2698890	et	3	main
ekr	doc_53629148792_item	2698891	et	4	main
asustus	doc_53629148792_item	2698892	et	4	main
eesti	doc_53629148792_item	2698893	et	4	main
territooriumil	doc_53629148792_item	2698894	et	3	main
toimus	doc_53629148792_item	2698895	et	3	main
mesoliitikumis	doc_53629148792_item	2698896	et	3	main
kõige	doc_53629148792_item	2698897	et	4	main
vanem	doc_53629148792_item	2698898	et	4	main
asula	doc_53629148792_item	2698899	et	4	main
pulli	doc_53629148792_item	2698900	et	4	main
kütid	doc_53629148792_item	2698901	et	4	main
asub	doc_53629148792_item	2698902	et	3	main
pärnu	doc_53629148792_item	2698903	et	4	main
jõe	doc_53629148792_item	2698904	et	3	main
ääres	doc_53629148792_item	2698905	et	4	main
kunda	doc_53629148792_item	2698906	et	4	main
kultuur	doc_53629148792_item	2698907	et	3	main
on	doc_53629148792_item	2698908	et	4	main
väga	doc_53629148792_item	2698910	et	3	main
ka	doc_53629148792_item	2698909	et	3	main
vana	doc_53629148792_item	2698911	et	4	main
kalevid	doc_53629148792_item	2698912	et	3	main
arvatakse	doc_53629148792_item	2698913	et	3	main
et	doc_53629148792_item	2698914	et	3	main
kalevid	doc_53629148792_item	2698915	et	3	main
ja	doc_53629148792_item	2698916	et	3	main
kütid	doc_53629148792_item	2698917	et	4	main
tulid	doc_53629148792_item	2698918	et	4	main
lõuna	doc_53629148792_item	2698919	et	4	main
poolt	doc_53629148792_item	2698920	et	4	main
valmistati	doc_53629148792_item	2698926	et	4	main
neoliitikumiks	doc_53629148792_item	2698866	et	3	main
väga	doc_53629148792_item	2698870	et	3	main
mingeid	doc_53629148792_item	2698873	et	3	main
kultuurikiht	doc_53629148792_item	2698876	et	3	main
õhuke	doc_53629148792_item	2698878	et	4	main
kaua	doc_53629148792_item	2698879	et	3	main
püsis	doc_53629148792_item	2698880	et	4	main
leedu	doc_53629148792_item	2698921	et	4	main
kivist	doc_53629148792_item	2698928	et	4	main
nt	doc_53629148792_item	2698929	et	4	main
noolotsad	doc_53629148792_item	2698930	et	3	main
odaotsad	doc_53629148792_item	2698931	et	3	main
elatusaladeks	doc_53629148792_item	2698932	et	3	main
karu	doc_53629148792_item	2698938	et	4	main
põder	doc_53629148792_item	2698939	et	3	main
kalapüük	doc_53629148792_item	2698940	et	3	main
loodusandide	doc_53629148792_item	2698941	et	3	main
korjamine	doc_53629148792_item	2698942	et	4	main
näoga	doc_53629148792_item	2698947	et	3	main
sirgete	doc_53629148792_item	2698948	et	4	main
mets	doc_53629148792_item	2698965	et	3	main
ajaloole	doc_53629148792_item	2698978	et	4	main
neoliitikum	doc_53629148792_item	2698979	et	3	main
osalevamaks	doc_53629148792_item	2698986	et	4	main
savist	doc_53629148792_item	2699026	et	4	main
nõude	doc_53629148792_item	2699027	et	4	main
kõige	doc_53629148792_item	2699032	et	4	main
euroopas	doc_53629148792_item	2699041	et	3	main
keraamikat	doc_53629148792_item	2699043	et	3	main
jämedast	doc_53629148792_item	2699045	et	3	main
ja	doc_53629148792_item	2699051	et	3	main
isegi	doc_53629148792_item	2699052	et	4	main
kannab	doc_53629148792_item	2699058	et	3	main
hakati	doc_53629148792_item	2699068	et	3	main
joonistama	doc_53629148792_item	2699072	et	3	main
rahva	doc_53629148792_item	2699074	et	3	main
kasutatud	doc_53629148792_item	2699079	et	4	main
hilis	doc_53629148792_item	2699080	et	4	main
neoliitikumis	doc_53629148792_item	2699081	et	3	main
keraamika	doc_53629148792_item	2699085	et	4	main
tuleb	doc_53629148792_item	2699121	et	3	main
territooriumile	doc_53629148792_item	2699123	et	3	main
inimesi	doc_53629148792_item	2699128	et	4	main
nii	doc_53629148792_item	2699133	et	3	main
inimesi	doc_53629148792_item	2699155	et	4	main
asulas	doc_53629148792_item	2699157	et	3	main
see	doc_53629148792_item	2699161	et	3	main
austati	doc_53629148792_item	2699164	et	3	main
sellel	doc_53629148792_item	2698923	et	4	main
ajal	doc_53629148792_item	2698924	et	4	main
tööriistu	doc_53629148792_item	2698925	et	3	main
olid	doc_53629148792_item	2698933	et	4	main
oli	doc_53629148792_item	2698945	et	3	main
maastiku	doc_53629148792_item	2698957	et	4	main
elementidega	doc_53629148792_item	2698958	et	3	main
ja	doc_53629148792_item	2698959	et	3	main
kalade	doc_53629148792_item	2698960	et	3	main
nimedega	doc_53629148792_item	2698961	et	3	main
neem	doc_53629148792_item	2698962	et	3	main
meri	doc_53629148792_item	2698963	et	3	main
mägi	doc_53629148792_item	2698964	et	3	main
10000	doc_53629148792_item	2698972	et	2	main
noorem	doc_53629148792_item	2698980	et	4	main
tarkemaks	doc_53629148792_item	2698984	et	3	main
on	doc_53629148792_item	2698988	et	4	main
õitseaeg	doc_53629148792_item	2698993	et	3	main
eesti	doc_53629148792_item	2698994	et	4	main
territooriumil	doc_53629148792_item	2698995	et	3	main
hakkab	doc_53629148792_item	2698996	et	3	main
kujunema	doc_53629148792_item	2698997	et	3	main
paikkondlik	doc_53629148792_item	2698999	et	3	main
materiaalne	doc_53629148792_item	2699000	et	3	main
ja	doc_53629148792_item	2699001	et	3	main
välja	doc_53629148792_item	2698998	et	4	main
vaimne	doc_53629148792_item	2699002	et	3	main
kultuur	doc_53629148792_item	2699003	et	3	main
sellel	doc_53629148792_item	2699004	et	4	main
ajal	doc_53629148792_item	2699005	et	4	main
hakkavad	doc_53629148792_item	2699006	et	4	main
eesti	doc_53629148792_item	2699007	et	4	main
territooriumile	doc_53629148792_item	2699008	et	3	main
tulema	doc_53629148792_item	2699009	et	4	main
võõrad	doc_53629148792_item	2699010	et	3	main
inimesed	doc_53629148792_item	2699011	et	3	main
elamiskohti	doc_53629148792_item	2699012	et	4	main
otsida	doc_53629148792_item	2699013	et	4	main
elati	doc_53629148792_item	2699014	et	3	main
püstkodades	doc_53629148792_item	2699015	et	3	main
süüa	doc_53629148792_item	2699016	et	3	main
tehti	doc_53629148792_item	2699017	et	3	main
lõke	doc_53629148792_item	2699018	et	4	main
peal	doc_53629148792_item	2699019	et	4	main
neoliitikumi	doc_53629148792_item	2699020	et	4	main
on	doc_53629148792_item	2699031	et	4	main
ja	doc_53629148792_item	2699039	et	3	main
narva	doc_53629148792_item	2699042	et	4	main
teokarpe	doc_53629148792_item	2699050	et	4	main
taimi	doc_53629148792_item	2699053	et	4	main
kammkeraamika	doc_53629148792_item	2699054	et	4	main
ekr	doc_53629148792_item	2699057	et	4	main
sest	doc_53629148792_item	2699061	et	4	main
muster	doc_53629148792_item	2699064	et	3	main
kujuline	doc_53629148792_item	2699066	et	4	main
ilmus	doc_53629148792_item	2699082	et	4	main
puust	doc_53629148792_item	2698927	et	4	main
küttimine	doc_53629148792_item	2698934	et	4	main
hülged	doc_53629148792_item	2698935	et	3	main
metshobused	doc_53629148792_item	2698936	et	4	main
siga	doc_53629148792_item	2698937	et	4	main
inimene	doc_53629148792_item	2698944	et	3	main
tulnud	doc_53629148792_item	2698953	et	4	main
arvatakse	doc_53629148792_item	2698968	et	3	main
et	doc_53629148792_item	2698969	et	3	main
kultuur	doc_53629148792_item	2698971	et	3	main
a	doc_53629148792_item	2698973	et	4	main
tagasi	doc_53629148792_item	2698974	et	3	main
pani	doc_53629148792_item	2698975	et	4	main
kiviaeg	doc_53629148792_item	2698981	et	3	main
inimene	doc_53629148792_item	2698982	et	3	main
ja	doc_53629148792_item	2698985	et	3	main
neoliitikum	doc_53629148792_item	2698987	et	3	main
kalastajate	doc_53629148792_item	2698989	et	4	main
kõige	doc_53629148792_item	2699021	et	4	main
tähtsamaks	doc_53629148792_item	2699022	et	4	main
tunnuseks	doc_53629148792_item	2699023	et	3	main
keraamika	doc_53629148792_item	2699025	et	4	main
keraamika	doc_53629148792_item	2699030	et	4	main
ka	doc_53629148792_item	2699037	et	3	main
iv	doc_53629148792_item	2699055	et	4	main
nimi	doc_53629148792_item	2699060	et	3	main
oli	doc_53629148792_item	2699063	et	3	main
kammi	doc_53629148792_item	2699065	et	4	main
geomeetrilisi	doc_53629148792_item	2699070	et	4	main
nöörkeraamika	doc_53629148792_item	2699087	et	4	main
iii	doc_53629148792_item	2699088	et	4	main
at	doc_53629148792_item	2699089	et	4	main
ekr	doc_53629148792_item	2699090	et	4	main
muster	doc_53629148792_item	2699091	et	3	main
oli	doc_53629148792_item	2699092	et	3	main
nagu	doc_53629148792_item	2699093	et	3	main
nööri	doc_53629148792_item	2699094	et	4	main
vahendil	doc_53629148792_item	2699095	et	3	main
tehtud	doc_53629148792_item	2699096	et	4	main
hilisneoliitikum	doc_53629148792_item	2699097	et	3	main
neoliitikumi	doc_53629148792_item	2699098	et	4	main
ii	doc_53629148792_item	2699099	et	4	main
pool	doc_53629148792_item	2699100	et	4	main
sellel	doc_53629148792_item	2699101	et	4	main
ajal	doc_53629148792_item	2699102	et	4	main
inimesed	doc_53629148792_item	2699103	et	3	main
kasvatasid	doc_53629148792_item	2699104	et	4	main
loomi	doc_53629148792_item	2699105	et	4	main
veised	doc_53629148792_item	2699106	et	3	main
sead	doc_53629148792_item	2699107	et	4	main
kasvatati	doc_53629148792_item	2699108	et	3	main
neid	doc_53629148792_item	2699109	et	4	main
enda	doc_53629148792_item	2699110	et	4	main
tarbeks	doc_53629148792_item	2699111	et	3	main
on	doc_53629148792_item	2699112	et	4	main
leitud	doc_53629148792_item	2699113	et	4	main
jälge	doc_53629148792_item	2699114	et	4	main
et	doc_53629148792_item	2699115	et	3	main
osati	doc_53629148792_item	2699116	et	3	main
vilja	doc_53629148792_item	2699117	et	4	main
kasvatada	doc_53629148792_item	2699118	et	3	main
sellel	doc_53629148792_item	2699119	et	4	main
ajal	doc_53629148792_item	2699120	et	4	main
komme	doc_53629148792_item	2699125	et	4	main
maeti	doc_53629148792_item	2699131	et	3	main
nad	doc_53629148792_item	2699135	et	3	main
magasid	doc_53629148792_item	2699137	et	4	main
surnute	doc_53629148792_item	2699146	et	4	main
matma	doc_53629148792_item	2699156	et	3	main
või	doc_53629148792_item	2699158	et	4	main
üks	doc_53629148792_item	2699084	et	3	main
tüüp	doc_53629148792_item	2699086	et	3	main
uus	doc_53629148792_item	2699124	et	3	main
matma	doc_53629148792_item	2699129	et	3	main
aastat	doc_53629148792_item	2699145	et	3	main
eest	doc_53629148792_item	2699147	et	4	main
hoolitseti	doc_53629148792_item	2699148	et	3	main
maeti	doc_53629148792_item	2699149	et	3	main
inimesi	doc_53629148792_item	2699150	et	4	main
pool	doc_53629148792_item	2699160	et	4	main
või	doc_53629148792_item	2699166	et	4	main
hauda	doc_53629148792_item	2699138	et	4	main
pandi	doc_53629148792_item	2699139	et	4	main
tööriistu	doc_53629148792_item	2699140	et	3	main
surmust	doc_53629148792_item	2699141	et	3	main
püstkoda	doc_53629148792_item	2699151	et	4	main
alla	doc_53629148792_item	2699152	et	3	main
väljas	doc_53629148792_item	2699159	et	4	main
inimesest	doc_53629148792_item	2699163	et	3	main
ei	doc_53629148792_item	2699167	et	4	main
teda	doc_53629148792_item	2699165	et	4	main
essee	doc_536541856858_item	2699787	et	4	main
inimese	doc_536541856858_item	2699829	et	4	main
elus	doc_536541856858_item	2699830	et	4	main
eelkõige	doc_536541856858_item	2699831	et	3	main
peegeldub	doc_536541856858_item	2699835	et	3	main
sisemine	doc_536541856858_item	2699839	et	3	main
tema	doc_536541856858_item	2699841	et	4	main
enda	doc_536541856858_item	2699852	et	4	main
võib	doc_536541856858_item	2699856	et	3	main
keele	doc_536541856858_item	2699789	et	4	main
teise	doc_536541856858_item	2699791	et	4	main
on	doc_536541856858_item	2699821	et	4	main
illustreerida	doc_536541856858_item	2699823	et	3	main
näidetega	doc_536541856858_item	2699824	et	3	main
sellepärast	doc_536541856858_item	2699832	et	3	main
et	doc_536541856858_item	2699833	et	3	main
laulus	doc_536541856858_item	2699834	et	3	main
laulu	doc_536541856858_item	2699848	et	4	main
üks	doc_536541856858_item	2699849	et	3	main
viideks	doc_536541856858_item	2699854	et	3	main
palju	doc_536541856858_item	2699858	et	4	main
lauldi	doc_536541856858_item	2699877	et	3	main
nii	doc_536541856858_item	2699878	et	3	main
tööd	doc_536541856858_item	2699879	et	4	main
tehes	doc_536541856858_item	2699880	et	3	main
kui	doc_536541856858_item	2699881	et	3	main
kannatusi	doc_536541856858_item	2699890	et	4	main
olek	doc_536541856858_item	2699895	et	3	main
põhjustest	doc_536541856858_item	2699901	et	3	main
see	doc_536541856858_item	2699912	et	3	main
ülemaailmne	doc_536541856858_item	2699928	et	3	main
oli	doc_536541856858_item	2699945	et	3	main
ärkamisaega	doc_536541856858_item	2699956	et	4	main
milliseid	doc_536541856858_item	2699957	et	3	main
rahvalaule	doc_536541856858_item	2699965	et	4	main
regivärsiline	doc_536541856858_item	2699972	et	4	main
ja	doc_536541856858_item	2699973	et	3	main
oma	doc_536541856858_item	2700001	et	4	main
kirjutasid	doc_536541856858_item	2700003	et	4	main
sellisteks	doc_536541856858_item	2700004	et	4	main
heliloojateks	doc_536541856858_item	2700005	et	3	main
ja	doc_536541856858_item	2700010	et	3	main
tormis	doc_536541856858_item	2700012	et	3	main
kasutatakse	doc_536541856858_item	2700015	et	3	main
tänapäeval	doc_536541856858_item	2700017	et	3	main
programmide	doc_536541856858_item	2700019	et	3	main
test	doc_536541856858_item	2699793	et	3	main
maailm	doc_536541856858_item	2699840	et	3	main
kultuuriline	doc_536541856858_item	2699842	et	4	main
ja	doc_536541856858_item	2699843	et	3	main
sotsiaalne	doc_536541856858_item	2699844	et	3	main
taust	doc_536541856858_item	2699845	et	4	main
see	doc_536541856858_item	2699846	et	3	main
millist	doc_536541856858_item	2699847	et	3	main
aja	doc_536541856858_item	2699853	et	4	main
öelda	doc_536541856858_item	2699857	et	4	main
inimese	doc_536541856858_item	2699859	et	4	main
hetkelisest	doc_536541856858_item	2699860	et	4	main
kes	doc_536541856858_item	2699867	et	4	main
ka	doc_536541856858_item	2699882	et	3	main
mida	doc_536541856858_item	2699891	et	4	main
võõrvõimude	doc_536541856858_item	2699893	et	3	main
võimalik	doc_536541856858_item	2699896	et	3	main
see	doc_536541856858_item	2699898	et	3	main
üks	doc_536541856858_item	2699900	et	3	main
säilisid	doc_536541856858_item	2699905	et	4	main
rahvalaulule	doc_536541856858_item	2699907	et	3	main
pühenduse	doc_536541856858_item	2699908	et	4	main
põhjuseks	doc_536541856858_item	2699909	et	3	main
rahvalaulu	doc_536541856858_item	2699915	et	4	main
määravaks	doc_536541856858_item	2699923	et	4	main
laulupidude	doc_536541856858_item	2699924	et	4	main
läbiviimise	doc_536541856858_item	2699925	et	3	main
laulupidu	doc_536541856858_item	2699929	et	4	main
osa	doc_536541856858_item	2699931	et	4	main
aastal	doc_536541856858_item	2699933	et	3	main
kujunes	doc_536541856858_item	2699937	et	3	main
korraldamise	doc_536541856858_item	2699940	et	4	main
traditsioon	doc_536541856858_item	2699941	et	3	main
just	doc_536541856858_item	2699942	et	3	main
see	doc_536541856858_item	2699943	et	3	main
traditsioon	doc_536541856858_item	2699944	et	3	main
tuli	doc_536541856858_item	2699951	et	4	main
pärast	doc_536541856858_item	2699952	et	4	main
nii	doc_536541856858_item	2699954	et	3	main
lauldi	doc_536541856858_item	2699960	et	3	main
riimiline	doc_536541856858_item	2699974	et	4	main
nad	doc_536541856858_item	2700000	et	3	main
olid	doc_536541856858_item	2700006	et	4	main
ka	doc_536541856858_item	2700016	et	3	main
laulupidude	doc_536541856858_item	2700018	et	4	main
noorte	doc_536541856858_item	2700041	et	3	main
järeldada	doc_536541856858_item	2700045	et	3	main
austamise	doc_536541856858_item	2700048	et	4	main
on	doc_536541856858_item	2700057	et	4	main
keele	doc_536541856859_item	2700063	et	4	main
kui	doc_536541856859_item	2700064	et	3	main
mis	doc_536541856859_item	2700072	et	4	main
essee	doc_536541856859_item	2700076	et	4	main
arutlev	doc_536541856859_item	2700084	et	4	main
faktidele	doc_536541856859_item	2700093	et	3	main
on	doc_536541856859_item	2700095	et	4	main
illustreerida	doc_536541856859_item	2700097	et	3	main
näidetega	doc_536541856859_item	2700098	et	3	main
kas	doc_536541856859_item	2700099	et	3	main
eestlased	doc_536541856859_item	2700100	et	3	main
kui	doc_536541856858_item	2699790	et	3	main
keele	doc_536541856858_item	2699792	et	4	main
kirjutage	doc_536541856858_item	2699795	et	3	main
teemal	doc_536541856858_item	2699797	et	3	main
mis	doc_536541856858_item	2699798	et	4	main
teeb	doc_536541856858_item	2699799	et	3	main
essee	doc_536541856858_item	2699796	et	4	main
eestlastest	doc_536541856858_item	2699800	et	4	main
laulurahva	doc_536541856858_item	2699801	et	3	main
essee	doc_536541856858_item	2699802	et	4	main
pikkus	doc_536541856858_item	2699803	et	4	main
300	doc_536541856858_item	2699804	et	2	main
350	doc_536541856858_item	2699805	et	2	main
sõna	doc_536541856858_item	2699806	et	4	main
essee	doc_536541856858_item	2699807	et	4	main
peab	doc_536541856858_item	2699808	et	4	main
olema	doc_536541856858_item	2699809	et	4	main
arutlev	doc_536541856858_item	2699810	et	4	main
analüüsiv	doc_536541856858_item	2699811	et	4	main
ja	doc_536541856858_item	2699812	et	3	main
üldistav	doc_536541856858_item	2699813	et	4	main
tuginema	doc_536541856858_item	2699814	et	3	main
loengus	doc_536541856858_item	2699815	et	3	main
ja	doc_536541856858_item	2699816	et	3	main
lugemistekstis	doc_536541856858_item	2699817	et	3	main
esitatud	doc_536541856858_item	2699818	et	4	main
faktidele	doc_536541856858_item	2699819	et	3	main
väiteid	doc_536541856858_item	2699820	et	4	main
eesti	doc_536541856858_item	2699788	et	4	main
kirjutamine	doc_536541856858_item	2699794	et	4	main
soovitatav	doc_536541856858_item	2699822	et	4	main
on	doc_536541856858_item	2699826	et	4	main
suur	doc_536541856858_item	2699827	et	3	main
tuju	doc_536541856858_item	2699837	et	4	main
tema	doc_536541856858_item	2699838	et	4	main
või	doc_536541856858_item	2699850	et	4	main
teine	doc_536541856858_item	2699851	et	3	main
valib	doc_536541856858_item	2699855	et	3	main
seisundist	doc_536541856858_item	2699861	et	3	main
seda	doc_536541856858_item	2699862	et	3	main
laulab	doc_536541856858_item	2699869	et	3	main
rahvalaul	doc_536541856858_item	2699872	et	4	main
psühholoogiliselt	doc_536541856858_item	2699887	et	4	main
üle	doc_536541856858_item	2699888	et	3	main
oli	doc_536541856858_item	2699899	et	3	main
eestlased	doc_536541856858_item	2699903	et	3	main
teiseks	doc_536541856858_item	2699906	et	4	main
laulul	doc_536541856858_item	2699825	et	3	main
tähtsus	doc_536541856858_item	2699828	et	4	main
inimese	doc_536541856858_item	2699836	et	4	main
rahvalaul	doc_536541856858_item	2699865	et	4	main
rahvast	doc_536541856858_item	2699866	et	4	main
eestlast	doc_536541856858_item	2699870	et	4	main
saadas	doc_536541856858_item	2699871	et	4	main
kogu	doc_536541856858_item	2699873	et	4	main
elu	doc_536541856858_item	2699875	et	4	main
puhates	doc_536541856858_item	2699883	et	3	main
laulmine	doc_536541856858_item	2699884	et	4	main
aitas	doc_536541856858_item	2699885	et	3	main
inimesi	doc_536541856858_item	2699886	et	4	main
miks	doc_536541856858_item	2699902	et	4	main
laulurahvana	doc_536541856858_item	2699904	et	3	main
asjaolu	doc_536541856858_item	2699913	et	4	main
et	doc_536541856858_item	2699914	et	3	main
laulmine	doc_536541856858_item	2699916	et	4	main
võimaldab	doc_536541856858_item	2699917	et	3	main
säilitada	doc_536541856858_item	2699918	et	3	main
rahvuslikku	doc_536541856858_item	2699919	et	4	main
identiteedi	doc_536541856858_item	2699920	et	4	main
saigi	doc_536541856858_item	2699922	et	4	main
siis	doc_536541856858_item	2699959	et	3	main
mida	doc_536541856858_item	2699966	et	4	main
nagu	doc_536541856858_item	2699967	et	3	main
teada	doc_536541856858_item	2699968	et	3	main
rahvalaul	doc_536541856858_item	2699975	et	4	main
noortepärased	doc_536541856858_item	2700031	et	4	main
rahvalaulude	doc_536541856858_item	2700034	et	3	main
mis	doc_536541856858_item	2700038	et	4	main
seas	doc_536541856858_item	2700042	et	4	main
sellest	doc_536541856858_item	2700043	et	4	main
võib	doc_536541856858_item	2700044	et	3	main
väide	doc_536541856858_item	2700054	et	4	main
eestlased	doc_536541856858_item	2700056	et	3	main
laulurahvas	doc_536541856858_item	2700058	et	4	main
essee	doc_536541856859_item	2700061	et	4	main
keele	doc_536541856859_item	2700066	et	4	main
test	doc_536541856859_item	2700067	et	3	main
kirjutamine	doc_536541856859_item	2700068	et	4	main
kirjutage	doc_536541856859_item	2700069	et	3	main
laulurahva	doc_536541856859_item	2700075	et	3	main
analüüsiv	doc_536541856859_item	2700085	et	4	main
laulurahvas	doc_536541856859_item	2700103	et	4	main
arvan	doc_536541856859_item	2700104	et	3	main
et	doc_536541856859_item	2700105	et	3	main
muidugi	doc_536541856859_item	2700106	et	4	main
traditsioonid	doc_536541856859_item	2700112	et	3	main
muidugi	doc_536541856859_item	2700115	et	4	main
kuid	doc_536541856859_item	2700130	et	4	main
peaan	doc_536541856859_item	2700131	et	4	main
et	doc_536541856859_item	2700132	et	3	main
eestlased	doc_536541856859_item	2700133	et	3	main
väga	doc_536541856859_item	2700145	et	3	main
eesti	doc_536541856859_item	2700157	et	4	main
kultuuris	doc_536541856859_item	2700158	et	3	main
rahvalaul	doc_536541856859_item	2700159	et	4	main
nii	doc_536541856859_item	2700168	et	3	main
lapsele	doc_536541856859_item	2700175	et	4	main
laulsid	doc_536541856859_item	2700179	et	4	main
ise	doc_536541856859_item	2700180	et	4	main
mehed	doc_536541856859_item	2700181	et	3	main
ühe	doc_536541856859_item	2700191	et	4	main
aitab	doc_536541856859_item	2700196	et	3	main
on	doc_536541856859_item	2700225	et	4	main
laulu	doc_536541856859_item	2700231	et	4	main
öelda	doc_536541856859_item	2700239	et	4	main
et	doc_536541856859_item	2700240	et	3	main
folkloris	doc_536541856859_item	2700241	et	3	main
19	doc_536541856859_item	2700248	et	2	main
oli	doc_536541856859_item	2700250	et	3	main
rahvuslik	doc_536541856859_item	2700252	et	3	main
muusika-	doc_536541856859_item	2700258	et	4	main
ja	doc_536541856859_item	2700259	et	3	main
lauluharrastused	doc_536541856859_item	2700260	et	3	main
enam	doc_536541856858_item	2699863	et	4	main
ütleb	doc_536541856858_item	2699864	et	3	main
seda	doc_536541856858_item	2699868	et	3	main
tema	doc_536541856858_item	2699874	et	4	main
jooksul	doc_536541856858_item	2699876	et	4	main
elada	doc_536541856858_item	2699889	et	3	main
põhjustas	doc_536541856858_item	2699892	et	3	main
all	doc_536541856858_item	2699894	et	3	main
et	doc_536541856858_item	2699897	et	3	main
võiks	doc_536541856858_item	2699910	et	4	main
olla	doc_536541856858_item	2699911	et	3	main
esimene	doc_536541856858_item	2699927	et	3	main
võttis	doc_536541856858_item	2699930	et	3	main
tartus	doc_536541856858_item	2699934	et	3	main
millest	doc_536541856858_item	2699935	et	3	main
välja	doc_536541856858_item	2699938	et	4	main
laulupidude	doc_536541856858_item	2699939	et	4	main
oluliseks	doc_536541856858_item	2699946	et	4	main
teel	doc_536541856858_item	2699949	et	4	main
mis	doc_536541856858_item	2699950	et	4	main
teist	doc_536541856858_item	2699953	et	4	main
nimetatud	doc_536541856858_item	2699955	et	4	main
loomulikult	doc_536541856858_item	2699964	et	4	main
sorti	doc_536541856858_item	2699971	et	4	main
näiteks	doc_536541856858_item	2700007	et	4	main
mart	doc_536541856858_item	2700008	et	3	main
saarnik	doc_536541856858_item	2700009	et	4	main
loomingut	doc_536541856858_item	2700014	et	3	main
koostamisel	doc_536541856858_item	2700020	et	4	main
erinevad	doc_536541856858_item	2700030	et	4	main
modernseid	doc_536541856858_item	2700036	et	3	main
tunnustust	doc_536541856858_item	2700040	et	4	main
et	doc_536541856858_item	2700046	et	3	main
traditsioon	doc_536541856858_item	2700049	et	3	main
ole	doc_536541856858_item	2700051	et	4	main
surnud	doc_536541856858_item	2700052	et	4	main
ning	doc_536541856858_item	2700053	et	3	main
tõele	doc_536541856858_item	2700060	et	4	main
teeb	doc_536541856859_item	2700073	et	3	main
300	doc_536541856859_item	2700078	et	2	main
esitatud	doc_536541856859_item	2700092	et	4	main
soovitatav	doc_536541856859_item	2700096	et	4	main
on	doc_536541856859_item	2700110	et	4	main
ja	doc_536541856859_item	2700114	et	3	main
keskid	doc_536541856859_item	2700138	et	4	main
on	doc_536541856859_item	2700144	et	4	main
sündmusi	doc_536541856859_item	2700147	et	3	main
olulust	doc_536541856859_item	2700153	et	3	main
kui	doc_536541856859_item	2700170	et	3	main
ka	doc_536541856859_item	2700182	et	3	main
see	doc_536541856858_item	2699921	et	3	main
põhjuseks	doc_536541856858_item	2699926	et	3	main
1869	doc_536541856858_item	2699932	et	2	main
hiljem	doc_536541856858_item	2699936	et	3	main
sammuks	doc_536541856858_item	2699947	et	4	main
iseseisvumisese	doc_536541856858_item	2699948	et	3	main
laule	doc_536541856858_item	2699958	et	4	main
nendel	doc_536541856858_item	2699961	et	4	main
laulupidul	doc_536541856858_item	2699962	et	3	main
otse	doc_536541856858_item	2699963	et	4	main
on	doc_536541856858_item	2699969	et	4	main
kahte	doc_536541856858_item	2699970	et	4	main
vanem	doc_536541856858_item	2699976	et	4	main
neist	doc_536541856858_item	2699977	et	4	main
on	doc_536541856858_item	2699978	et	4	main
regivärsiline	doc_536541856858_item	2699979	et	4	main
laul	doc_536541856858_item	2699980	et	4	main
ning	doc_536541856858_item	2699981	et	3	main
just	doc_536541856858_item	2699982	et	3	main
seda	doc_536541856858_item	2699983	et	3	main
eelistasid	doc_536541856858_item	2699984	et	4	main
laulupeo	doc_536541856858_item	2699985	et	4	main
korraldajad	doc_536541856858_item	2699986	et	4	main
kui	doc_536541856858_item	2699987	et	3	main
nad	doc_536541856858_item	2699988	et	3	main
koostasid	doc_536541856858_item	2699989	et	4	main
laulukogumikke	doc_536541856858_item	2699990	et	4	main
sellist	doc_536541856858_item	2699991	et	4	main
laulu	doc_536541856858_item	2699992	et	4	main
võtsid	doc_536541856858_item	2699993	et	4	main
aluseks	doc_536541856858_item	2699994	et	4	main
ka	doc_536541856858_item	2699995	et	3	main
paljud	doc_536541856858_item	2699996	et	3	main
ärkamisaja	doc_536541856858_item	2699997	et	3	main
heliloojad	doc_536541856858_item	2699998	et	3	main
kui	doc_536541856858_item	2699999	et	3	main
loomingud	doc_536541856858_item	2700002	et	3	main
vello	doc_536541856858_item	2700011	et	4	main
nende	doc_536541856858_item	2700013	et	4	main
eesti	doc_536541856858_item	2700021	et	4	main
seas	doc_536541856858_item	2700029	et	4	main
teevad	doc_536541856858_item	2700033	et	3	main
et	doc_536541856858_item	2700055	et	3	main
eesti	doc_536541856859_item	2700062	et	4	main
essee	doc_536541856859_item	2700070	et	4	main
teemal	doc_536541856859_item	2700071	et	3	main
pikkus	doc_536541856859_item	2700077	et	4	main
350	doc_536541856859_item	2700079	et	2	main
essee	doc_536541856859_item	2700081	et	4	main
ja	doc_536541856859_item	2700086	et	3	main
väiteid	doc_536541856859_item	2700094	et	4	main
on	doc_536541856859_item	2700107	et	4	main
igal	doc_536541856859_item	2700108	et	3	main
rahval	doc_536541856859_item	2700109	et	3	main
muusika	doc_536541856859_item	2700117	et	4	main
ajal	doc_536541856859_item	2700129	et	4	main
rohkem	doc_536541856859_item	2700135	et	4	main
kui	doc_536541856859_item	2700137	et	3	main
teised	doc_536541856859_item	2700139	et	4	main
sellepärast	doc_536541856859_item	2700140	et	3	main
et	doc_536541856859_item	2700141	et	3	main
eesti	doc_536541856859_item	2700142	et	4	main
ajaloos	doc_536541856859_item	2700143	et	4	main
muusikaga	doc_536541856859_item	2700149	et	3	main
rolli	doc_536541856859_item	2700154	et	4	main
ajaloos	doc_536541856859_item	2700155	et	4	main
ja	doc_536541856859_item	2700156	et	3	main
ja	doc_536541856859_item	2700164	et	3	main
on	doc_536541856859_item	2700165	et	4	main
ajal	doc_536541856859_item	2700172	et	4	main
naised	doc_536541856859_item	2700173	et	3	main
omavahel	doc_536541856859_item	2700177	et	3	main
kui	doc_536541856859_item	2700184	et	3	main
ühekoos	doc_536541856859_item	2700187	et	4	main
tuvastatav	doc_536541856859_item	2700228	et	4	main
on	doc_536541856859_item	2700232	et	4	main
pillisaatega	doc_536541856859_item	2700235	et	3	main
praegu	doc_536541856859_item	2700237	et	3	main
pani	doc_536541856859_item	2700268	et	4	main
kõike	doc_536541856859_item	2700274	et	4	main
laulurahvas	doc_536541856859_item	2700282	et	4	main
eesti	doc_536541856859_item	2700286	et	4	main
on	doc_536541856859_item	2700288	et	4	main
on	doc_536541856859_item	2700299	et	4	main
aastatel	doc_536541856859_item	2700306	et	4	main
rahvas	doc_536541856859_item	2700308	et	4	main
taastas	doc_536541856859_item	2700309	et	3	main
inimesed	doc_536541856859_item	2700318	et	3	main
tallinnas	doc_536541856859_item	2700321	et	4	main
kaelast	doc_536541856859_item	2700325	et	4	main
ja	doc_536541856859_item	2700327	et	3	main
toimusid	doc_536541856859_item	2700332	et	4	main
kus	doc_536541856859_item	2700348	et	3	main
olid	doc_536541856859_item	2700350	et	4	main
kuid	doc_536541856859_item	2700358	et	4	main
eestis	doc_536541856859_item	2700361	et	3	main
on	doc_536541856859_item	2700375	et	4	main
tuginema	doc_536541856860_item	2700431	et	3	main
eesti	doc_536541856860_item	2700442	et	4	main
eesti	doc_536541856860_item	2700451	et	4	main
tavaliselt	doc_536541856860_item	2700470	et	4	main
eeslaulja	doc_536541856860_item	2700476	et	4	main
seda	doc_536541856860_item	2700482	et	3	main
on	doc_536541856860_item	2700494	et	4	main
esindamine	doc_536541856860_item	2700509	et	4	main
rahvalaul	doc_536541856858_item	2700022	et	4	main
on	doc_536541856858_item	2700023	et	4	main
ka	doc_536541856858_item	2700024	et	3	main
tänapäeval	doc_536541856858_item	2700025	et	3	main
väga	doc_536541856858_item	2700026	et	3	main
populaarne	doc_536541856858_item	2700027	et	3	main
noorte	doc_536541856858_item	2700028	et	3	main
ansamblid	doc_536541856858_item	2700032	et	3	main
värside	doc_536541856858_item	2700035	et	4	main
töötlusi	doc_536541856858_item	2700037	et	3	main
leiavad	doc_536541856858_item	2700039	et	3	main
rahvalaulu	doc_536541856858_item	2700047	et	4	main
ei	doc_536541856858_item	2700050	et	4	main
vastab	doc_536541856858_item	2700059	et	3	main
teise	doc_536541856859_item	2700065	et	4	main
eestlastest	doc_536541856859_item	2700074	et	4	main
sõna	doc_536541856859_item	2700080	et	4	main
peab	doc_536541856859_item	2700082	et	4	main
olema	doc_536541856859_item	2700083	et	4	main
üldistav	doc_536541856859_item	2700087	et	4	main
tuginema	doc_536541856859_item	2700088	et	3	main
loengus	doc_536541856859_item	2700089	et	3	main
ja	doc_536541856859_item	2700090	et	3	main
lugemistekstis	doc_536541856859_item	2700091	et	3	main
oma	doc_536541856859_item	2700111	et	4	main
väga	doc_536541856859_item	2700119	et	3	main
oluline	doc_536541856859_item	2700120	et	4	main
osa	doc_536541856859_item	2700121	et	4	main
elus	doc_536541856859_item	2700123	et	4	main
ja	doc_536541856859_item	2700124	et	3	main
oli	doc_536541856859_item	2700126	et	3	main
on	doc_536541856859_item	2700134	et	4	main
palju	doc_536541856859_item	2700146	et	4	main
seotud	doc_536541856859_item	2700148	et	4	main
mis	doc_536541856859_item	2700150	et	4	main
mängis	doc_536541856859_item	2700151	et	3	main
väga	doc_536541856859_item	2700152	et	3	main
ilmus	doc_536541856859_item	2700160	et	4	main
eestis	doc_536541856859_item	2700161	et	3	main
väga	doc_536541856859_item	2700162	et	3	main
ammu	doc_536541856859_item	2700163	et	4	main
heal	doc_536541856859_item	2700171	et	3	main
inimesed	doc_536541856859_item	2700185	et	3	main
laulavad	doc_536541856859_item	2700186	et	4	main
nad	doc_536541856859_item	2700188	et	3	main
tunnevad	doc_536541856859_item	2700189	et	3	main
ja	doc_536541856859_item	2700193	et	3	main
tunne	doc_536541856859_item	2700195	et	4	main
on	doc_536541856859_item	2700222	et	4	main
tema	doc_536541856859_item	2700226	et	4	main
isik	doc_536541856859_item	2700227	et	3	main
ka	doc_536541856859_item	2700234	et	3	main
nii	doc_536541856859_item	2700236	et	3	main
pillimängist	doc_536541856859_item	2700247	et	4	main
eestlaste	doc_536541856859_item	2700251	et	4	main
1869	doc_536541856859_item	2700261	et	2	main
toimus	doc_536541856859_item	2700264	et	3	main
järgnevate	doc_536541856859_item	2700270	et	4	main
pärast	doc_536541856859_item	2700276	et	4	main
juba	doc_536541856859_item	2700284	et	3	main
tähtsaim	doc_536541856859_item	2700297	et	4	main
toimus	doc_536541856859_item	2700303	et	3	main
iseseisvuse	doc_536541856859_item	2700312	et	4	main
see	doc_536541856859_item	2700313	et	3	main
tulid	doc_536541856859_item	2700319	et	4	main
nad	doc_536541856859_item	2700322	et	3	main
öösed	doc_536541856859_item	2700333	et	4	main
laulupeod	doc_536541856859_item	2700334	et	4	main
kus	doc_536541856859_item	2700335	et	3	main
kett	doc_536541856859_item	2700347	et	4	main
vabariik	doc_536541856859_item	2700357	et	3	main
praegu	doc_536541856859_item	2700360	et	3	main
laulakse	doc_536541856859_item	2700367	et	4	main
nii	doc_536541856859_item	2700368	et	3	main
uue	doc_536541856859_item	2700369	et	3	main
laulu	doc_536541856859_item	2700370	et	4	main
kui	doc_536541856859_item	2700371	et	3	main
ka	doc_536541856859_item	2700372	et	3	main
ajalugu	doc_536541856859_item	2700383	et	4	main
nende	doc_536541856859_item	2700384	et	4	main
üldse	doc_536541856859_item	2700101	et	3	main
on	doc_536541856859_item	2700102	et	4	main
folklor	doc_536541856859_item	2700113	et	4	main
muusika	doc_536541856859_item	2700116	et	4	main
on	doc_536541856859_item	2700118	et	4	main
meie	doc_536541856859_item	2700122	et	4	main
see	doc_536541856859_item	2700125	et	3	main
nii	doc_536541856859_item	2700127	et	3	main
kõikidel	doc_536541856859_item	2700128	et	4	main
laulurahvas	doc_536541856859_item	2700136	et	4	main
saatnud	doc_536541856859_item	2700166	et	4	main
eestlasi	doc_536541856859_item	2700167	et	3	main
halval	doc_536541856859_item	2700169	et	3	main
laulsid	doc_536541856859_item	2700174	et	4	main
ja	doc_536541856859_item	2700176	et	3	main
lapsed	doc_536541856859_item	2700178	et	3	main
laulsid	doc_536541856859_item	2700183	et	4	main
end	doc_536541856859_item	2700190	et	4	main
rahvana	doc_536541856859_item	2700192	et	3	main
see	doc_536541856859_item	2700194	et	3	main
halval	doc_536541856859_item	2700197	et	3	main
ajal	doc_536541856859_item	2700198	et	4	main
ja	doc_536541856859_item	2700199	et	3	main
rõõmustab	doc_536541856859_item	2700200	et	3	main
rahvalauludes	doc_536541856859_item	2700202	et	3	main
heal	doc_536541856859_item	2700201	et	3	main
kajastub	doc_536541856859_item	2700203	et	3	main
rahva	doc_536541856859_item	2700204	et	3	main
minevik	doc_536541856859_item	2700205	et	3	main
olid	doc_536541856859_item	2700207	et	4	main
regivärsilised	doc_536541856859_item	2700208	et	4	main
rahvalaulud	doc_536541856859_item	2700209	et	3	main
alguses	doc_536541856859_item	2700206	et	4	main
neid	doc_536541856859_item	2700210	et	4	main
pärandati	doc_536541856859_item	2700211	et	4	main
põlvest	doc_536541856859_item	2700212	et	4	main
põlve	doc_536541856859_item	2700213	et	4	main
suuliselt	doc_536541856859_item	2700214	et	4	main
hiljem	doc_536541856859_item	2700215	et	3	main
ilmusid	doc_536541856859_item	2700216	et	4	main
juba	doc_536541856859_item	2700217	et	3	main
rahvalaulud	doc_536541856859_item	2700219	et	3	main
riimilised	doc_536541856859_item	2700218	et	4	main
milliste	doc_536541856859_item	2700220	et	3	main
autor	doc_536541856859_item	2700221	et	3	main
teada	doc_536541856859_item	2700223	et	3	main
või	doc_536541856859_item	2700224	et	4	main
sajandis	doc_536541856859_item	2700249	et	3	main
seotud	doc_536541856859_item	2700257	et	4	main
aluse	doc_536541856859_item	2700269	et	4	main
selle	doc_536541856859_item	2700275	et	4	main
nagu	doc_536541856859_item	2700283	et	3	main
nendest	doc_536541856859_item	2700298	et	4	main
1987	doc_536541856859_item	2700304	et	2	main
eesti	doc_536541856859_item	2700307	et	4	main
eesti	doc_536541856859_item	2700310	et	4	main
riigi	doc_536541856859_item	2700311	et	3	main
hoidsid	doc_536541856859_item	2700323	et	4	main
laulsid	doc_536541856859_item	2700328	et	4	main
tundsid	doc_536541856859_item	2700337	et	4	main
end	doc_536541856859_item	2700338	et	4	main
rahvalaulad	doc_536541856859_item	2700341	et	4	main
neid	doc_536541856859_item	2700343	et	4	main
veel	doc_536541856859_item	2700229	et	4	main
neid	doc_536541856859_item	2700230	et	4	main
esitatud	doc_536541856859_item	2700233	et	4	main
võime	doc_536541856859_item	2700238	et	4	main
rahvalaul	doc_536541856859_item	2700242	et	4	main
koostab	doc_536541856859_item	2700243	et	3	main
tantsist	doc_536541856859_item	2700244	et	3	main
laulust	doc_536541856859_item	2700245	et	4	main
ja	doc_536541856859_item	2700246	et	3	main
ärkamine	doc_536541856859_item	2700253	et	4	main
millega	doc_536541856859_item	2700254	et	3	main
on	doc_536541856859_item	2700255	et	4	main
tihedalt	doc_536541856859_item	2700256	et	4	main
aastal	doc_536541856859_item	2700262	et	3	main
esimene	doc_536541856859_item	2700265	et	3	main
üldlaulupidude	doc_536541856859_item	2700271	et	4	main
võin	doc_536541856859_item	2700277	et	3	main
öelda	doc_536541856859_item	2700278	et	4	main
et	doc_536541856859_item	2700279	et	3	main
ütlesin	doc_536541856859_item	2700285	et	3	main
ajaloos	doc_536541856859_item	2700287	et	4	main
palju	doc_536541856859_item	2700289	et	4	main
sündmusi	doc_536541856859_item	2700290	et	3	main
seotud	doc_536541856859_item	2700291	et	4	main
muusikaga	doc_536541856859_item	2700292	et	3	main
ma	doc_536541856859_item	2700293	et	3	main
lauluv	doc_536541856859_item	2700300	et	4	main
revolutsioon	doc_536541856859_item	2700301	et	3	main
1988	doc_536541856859_item	2700305	et	2	main
lauluväljakule	doc_536541856859_item	2700320	et	3	main
ühekoos	doc_536541856859_item	2700329	et	4	main
sel	doc_536541856859_item	2700330	et	3	main
ajal	doc_536541856859_item	2700331	et	4	main
eestlased	doc_536541856859_item	2700336	et	3	main
rahvana	doc_536541856859_item	2700340	et	3	main
inimesed	doc_536541856859_item	2700349	et	3	main
koos	doc_536541856859_item	2700351	et	4	main
ja	doc_536541856859_item	2700352	et	3	main
praegu	doc_536541856859_item	2700353	et	3	main
eesti	doc_536541856859_item	2700354	et	4	main
on	doc_536541856859_item	2700355	et	4	main
iseseisev	doc_536541856859_item	2700356	et	3	main
isegi	doc_536541856859_item	2700359	et	4	main
on	doc_536541856859_item	2700362	et	4	main
palju	doc_536541856859_item	2700363	et	4	main
vana	doc_536541856859_item	2700373	et	4	main
eestlased	doc_536541856859_item	2700374	et	3	main
mälu	doc_536541856859_item	2700387	et	4	main
arutlev	doc_536541856860_item	2700427	et	4	main
üldistav	doc_536541856860_item	2700430	et	4	main
on	doc_536541856860_item	2700438	et	4	main
soovitatav	doc_536541856860_item	2700439	et	4	main
illustreerida	doc_536541856860_item	2700440	et	3	main
näidetega	doc_536541856860_item	2700441	et	3	main
läänemeresoome	doc_536541856860_item	2700455	et	3	main
iseloomulik	doc_536541856860_item	2700457	et	3	main
esitasid	doc_536541856860_item	2700469	et	4	main
vaheldumisi	doc_536541856860_item	2700474	et	4	main
ja	doc_536541856860_item	2700480	et	3	main
mõtteaga	doc_536541856860_item	2700492	et	4	main
laul	doc_536541856860_item	2700502	et	4	main
võisid	doc_536541856860_item	2700525	et	4	main
kaasneda	doc_536541856860_item	2700526	et	3	main
ka	doc_536541856860_item	2700543	et	3	main
tantsulise	doc_536541856860_item	2700544	et	4	main
laulsid	doc_536541856860_item	2700548	et	4	main
tavaliselt	doc_536541856860_item	2700549	et	4	main
naised	doc_536541856860_item	2700550	et	3	main
igakord	doc_536541856860_item	2700551	et	3	main
kui	doc_536541856860_item	2700552	et	3	main
nad	doc_536541856860_item	2700553	et	3	main
laulmisest	doc_536541856860_item	2700571	et	4	main
rahvalaul	doc_536541856860_item	2700577	et	4	main
laulud	doc_536541856860_item	2700579	et	3	main
riimilise	doc_536541856860_item	2700591	et	4	main
et	doc_536541856860_item	2700596	et	3	main
esitatud	doc_536541856860_item	2700608	et	4	main
pillisaatega	doc_536541856860_item	2700610	et	3	main
ümber	doc_536541856860_item	2700621	et	3	main
laulude	doc_536541856860_item	2700628	et	3	main
laiemale	doc_536541856860_item	2700629	et	4	main
kõige	doc_536541856860_item	2700631	et	4	main
tähtsam	doc_536541856860_item	2700632	et	4	main
rahva	doc_536541856860_item	2700638	et	3	main
korraldamise	doc_536541856860_item	2700654	et	4	main
ja	doc_536541856860_item	2700656	et	3	main
eesotsas	doc_536541856860_item	2700661	et	4	main
johann	doc_536541856860_item	2700662	et	4	main
voldemar	doc_536541856860_item	2700663	et	4	main
kõrghetk	doc_536541856860_item	2700670	et	3	main
korraldamisel	doc_536541856860_item	2700677	et	4	main
laulupidude	doc_536541856860_item	2700685	et	4	main
suur	doc_536541856860_item	2700699	et	3	main
üldlaulupidude	doc_536541856860_item	2700705	et	4	main
tartus	doc_536541856859_item	2700263	et	3	main
laulupidu	doc_536541856859_item	2700266	et	4	main
mis	doc_536541856859_item	2700267	et	4	main
korraldamisele	doc_536541856859_item	2700272	et	4	main
juba	doc_536541856859_item	2700273	et	3	main
eestlased	doc_536541856859_item	2700280	et	3	main
on	doc_536541856859_item	2700281	et	4	main
pean	doc_536541856859_item	2700294	et	4	main
et	doc_536541856859_item	2700295	et	3	main
üks	doc_536541856859_item	2700296	et	3	main
mis	doc_536541856859_item	2700302	et	4	main
on	doc_536541856859_item	2700314	et	4	main
revolutsioon	doc_536541856859_item	2700315	et	3	main
ilma	doc_536541856859_item	2700316	et	4	main
verevalamiseta	doc_536541856859_item	2700317	et	3	main
teineteist	doc_536541856859_item	2700324	et	4	main
kinni	doc_536541856859_item	2700326	et	3	main
ühe	doc_536541856859_item	2700339	et	4	main
aitasid	doc_536541856859_item	2700342	et	4	main
tõesti	doc_536541856859_item	2700376	et	3	main
mida	doc_536541856859_item	2700378	et	4	main
neid	doc_536541856859_item	2700380	et	4	main
ja	doc_536541856859_item	2700388	et	3	main
muidugi	doc_536541856859_item	2700389	et	4	main
ise	doc_536541856859_item	2700390	et	4	main
eestlased	doc_536541856859_item	2700391	et	3	main
kes	doc_536541856859_item	2700392	et	4	main
kirjutavad	doc_536541856859_item	2700393	et	4	main
uut	doc_536541856859_item	2700394	et	3	main
laulu	doc_536541856859_item	2700395	et	4	main
ja	doc_536541856859_item	2700396	et	3	main
muusikat	doc_536541856859_item	2700397	et	3	main
kuid	doc_536541856859_item	2700398	et	4	main
samal	doc_536541856859_item	2700399	et	3	main
ajal	doc_536541856859_item	2700400	et	4	main
lauluvad	doc_536541856859_item	2700401	et	4	main
vana	doc_536541856859_item	2700402	et	4	main
rahvalaulu	doc_536541856859_item	2700403	et	4	main
essee	doc_536541856860_item	2700404	et	4	main
eesti	doc_536541856860_item	2700405	et	4	main
keele	doc_536541856860_item	2700406	et	4	main
kui	doc_536541856860_item	2700407	et	3	main
teise	doc_536541856860_item	2700408	et	4	main
keele	doc_536541856860_item	2700409	et	4	main
test	doc_536541856860_item	2700410	et	3	main
kirjutamine	doc_536541856860_item	2700411	et	4	main
kirjutage	doc_536541856860_item	2700412	et	3	main
essee	doc_536541856860_item	2700413	et	4	main
teemal	doc_536541856860_item	2700414	et	3	main
mis	doc_536541856860_item	2700415	et	4	main
teeb	doc_536541856860_item	2700416	et	3	main
eestlastest	doc_536541856860_item	2700417	et	4	main
laulurahva	doc_536541856860_item	2700418	et	3	main
essee	doc_536541856860_item	2700419	et	4	main
pikkus	doc_536541856860_item	2700420	et	4	main
pärast	doc_536541856859_item	2700344	et	4	main
oli	doc_536541856859_item	2700345	et	3	main
balti	doc_536541856859_item	2700346	et	3	main
erinevaid	doc_536541856859_item	2700364	et	4	main
uut	doc_536541856859_item	2700365	et	3	main
laulu	doc_536541856859_item	2700366	et	4	main
laulurahvas	doc_536541856859_item	2700377	et	4	main
teeb	doc_536541856859_item	2700379	et	3	main
laulurahva	doc_536541856859_item	2700381	et	3	main
nende	doc_536541856859_item	2700382	et	4	main
300	doc_536541856860_item	2700421	et	2	main
essee	doc_536541856860_item	2700424	et	4	main
ja	doc_536541856860_item	2700429	et	3	main
lugemistekstis	doc_536541856860_item	2700434	et	3	main
faktidele	doc_536541856860_item	2700436	et	3	main
folkloor	doc_536541856860_item	2700443	et	4	main
koosneb	doc_536541856860_item	2700444	et	3	main
kolmest	doc_536541856860_item	2700445	et	4	main
vanemat	doc_536541856860_item	2700452	et	4	main
rahvalaul	doc_536541856860_item	2700459	et	4	main
mis	doc_536541856860_item	2700460	et	4	main
enam	doc_536541856860_item	2700463	et	4	main
eeslaulja	doc_536541856860_item	2700471	et	4	main
ja	doc_536541856860_item	2700472	et	3	main
viis	doc_536541856860_item	2700477	et	4	main
aga	doc_536541856860_item	2700483	et	3	main
koor	doc_536541856860_item	2700484	et	4	main
tema	doc_536541856860_item	2700486	et	4	main
andes	doc_536541856860_item	2700489	et	4	main
sellega	doc_536541856860_item	2700490	et	3	main
eesti	doc_536541856860_item	2700495	et	4	main
rahvalaulus	doc_536541856860_item	2700496	et	3	main
kaks	doc_536541856860_item	2700497	et	3	main
regilaul	doc_536541856860_item	2700499	et	4	main
või	doc_536541856860_item	2700503	et	4	main
rahvalaul	doc_536541856860_item	2700505	et	4	main
vanasti	doc_536541856860_item	2700506	et	3	main
oli	doc_536541856860_item	2700507	et	3	main
laulude	doc_536541856860_item	2700508	et	3	main
mitmekesine	doc_536541856860_item	2700510	et	4	main
rütmi	doc_536541856860_item	2700533	et	4	main
õõtsutamise	doc_536541856860_item	2700537	et	4	main
liikumise	doc_536541856860_item	2700545	et	4	main
omavahel	doc_536541856860_item	2700554	et	3	main
või	doc_536541856860_item	2700557	et	4	main
mehed	doc_536541856860_item	2700560	et	3	main
19	doc_536541856860_item	2700572	et	2	main
kujunenud	doc_536541856860_item	2700582	et	4	main
muusika	doc_536541856860_item	2700586	et	4	main
kui	doc_536541856860_item	2700588	et	3	main
kinnitada	doc_536541856860_item	2700595	et	3	main
ka	doc_536541856860_item	2700609	et	3	main
rahvalaulu	doc_536541856860_item	2700612	et	4	main
käsitsi	doc_536541856860_item	2700622	et	3	main
ajalooline	doc_536541856860_item	2700633	et	4	main
on	doc_536541856860_item	2700643	et	4	main
minu	doc_536541856860_item	2700644	et	3	main
meelest	doc_536541856860_item	2700645	et	4	main
1869	doc_536541856860_item	2700646	et	2	main
aastal	doc_536541856860_item	2700647	et	3	main
vanemuise	doc_536541856860_item	2700659	et	4	main
jannseniga	doc_536541856860_item	2700664	et	4	main
liikumise	doc_536541856860_item	2700669	et	4	main
tol	doc_536541856860_item	2700678	et	3	main
ajal	doc_536541856860_item	2700679	et	4	main
oli	doc_536541856860_item	2700680	et	3	main
üsna	doc_536541856860_item	2700681	et	3	main
100	doc_536541856860_item	2700706	et	2	main
isamaalaul	doc_536541856860_item	2700712	et	4	main
mu	doc_536541856860_item	2700713	et	3	main
isamaa	doc_536541856860_item	2700714	et	4	main
on	doc_536541856860_item	2700715	et	4	main
minu	doc_536541856860_item	2700716	et	3	main
arm	doc_536541856860_item	2700717	et	3	main
1980	doc_536541856860_item	2700718	et	2	main
ärkamisajaks	doc_536541856860_item	2700723	et	3	main
võin	doc_536541856860_item	2700735	et	3	main
1994	doc_536541856860_item	2700737	et	2	main
mis	doc_536541856860_item	2700741	et	4	main
kahes	doc_536541856860_item	2700743	et	4	main
linnas	doc_536541856860_item	2700744	et	4	main
tartus	doc_536541856860_item	2700745	et	3	main
kultuur	doc_536541856859_item	2700385	et	3	main
rahva	doc_536541856859_item	2700386	et	3	main
350	doc_536541856860_item	2700422	et	2	main
analüüsiv	doc_536541856860_item	2700428	et	4	main
väiteid	doc_536541856860_item	2700437	et	4	main
alast	doc_536541856860_item	2700446	et	4	main
laulust	doc_536541856860_item	2700447	et	4	main
pillimängust	doc_536541856860_item	2700448	et	3	main
ja	doc_536541856860_item	2700449	et	3	main
tantsust	doc_536541856860_item	2700450	et	3	main
laulutraditsiooni	doc_536541856860_item	2700453	et	4	main
on	doc_536541856860_item	2700461	et	4	main
kui	doc_536541856860_item	2700464	et	3	main
koor	doc_536541856860_item	2700473	et	4	main
laulu	doc_536541856860_item	2700478	et	4	main
edasi	doc_536541856860_item	2700479	et	3	main
talle	doc_536541856860_item	2700491	et	4	main
kahe	doc_536541856860_item	2700521	et	3	main
seejuures	doc_536541856860_item	2700523	et	3	main
rõhutamine	doc_536541856860_item	2700534	et	4	main
näiteks	doc_536541856860_item	2700535	et	4	main
või	doc_536541856860_item	2700538	et	4	main
lüroeepilisi	doc_536541856860_item	2700540	et	4	main
regilaule	doc_536541856860_item	2700547	et	4	main
kokku	doc_536541856860_item	2700555	et	3	main
lastega	doc_536541856860_item	2700559	et	3	main
laulsid	doc_536541856860_item	2700562	et	4	main
ka	doc_536541856860_item	2700563	et	3	main
sajandil	doc_536541856860_item	2700573	et	3	main
uus	doc_536541856860_item	2700575	et	3	main
on	doc_536541856860_item	2700580	et	4	main
välja	doc_536541856860_item	2700581	et	4	main
ja	doc_536541856860_item	2700584	et	3	main
mõjul	doc_536541856860_item	2700587	et	4	main
lauluga	doc_536541856860_item	2700592	et	4	main
on	doc_536541856860_item	2700607	et	4	main
aitas	doc_536541856860_item	2700624	et	3	main
kaasa	doc_536541856860_item	2700627	et	4	main
idee	doc_536541856860_item	2700655	et	4	main
sellest	doc_536541856860_item	2700665	et	4	main
üldlaulupidude	doc_536541856860_item	2700676	et	4	main
saada	doc_536541856860_item	2700683	et	4	main
laulupeost	doc_536541856860_item	2700694	et	4	main
osavõtjate	doc_536541856860_item	2700695	et	3	main
arv	doc_536541856860_item	2700696	et	3	main
oli	doc_536541856860_item	2700697	et	3	main
üsna	doc_536541856860_item	2700698	et	3	main
1969	doc_536541856860_item	2700700	et	2	main
aastal	doc_536541856860_item	2700701	et	3	main
kui	doc_536541856860_item	2700702	et	3	main
tähistati	doc_536541856860_item	2700703	et	4	main
aastapäeva	doc_536541856860_item	2700707	et	4	main
gustav	doc_536541856860_item	2700709	et	4	main
nimetatakse	doc_536541856860_item	2700721	et	3	main
sest	doc_536541856860_item	2700724	et	4	main
oli	doc_536541856860_item	2700727	et	3	main
isamaalisi	doc_536541856860_item	2700729	et	4	main
laule	doc_536541856860_item	2700730	et	4	main
aastal	doc_536541856860_item	2700738	et	3	main
suur	doc_536541856860_item	2700751	et	3	main
laulud	doc_536541856860_item	2700755	et	3	main
muutunud	doc_536541856860_item	2700768	et	4	main
massiharrastuseks	doc_536541856860_item	2700769	et	3	main
muusika-	doc_536541856860_item	2700778	et	4	main
osa	doc_536541856860_item	2700791	et	4	main
kord	doc_536541856860_item	2700801	et	4	main
aastas	doc_536541856860_item	2700802	et	3	main
lauluvõistlused	doc_536541856860_item	2700804	et	3	main
ja	doc_536541856860_item	2700805	et	3	main
eesti	doc_536541856860_item	2700809	et	4	main
rahvast	doc_536541856860_item	2700810	et	4	main
mitte	doc_536541856860_item	2700811	et	3	main
võit	doc_536541856860_item	2700822	et	3	main
see	doc_536541856860_item	2700825	et	3	main
lauljad	doc_536541856860_item	2700830	et	4	main
essee	doc_536541856861_item	2700843	et	4	main
pikkus	doc_536541856861_item	2700859	et	4	main
300	doc_536541856861_item	2700860	et	2	main
350	doc_536541856861_item	2700861	et	2	main
arutlev	doc_536541856861_item	2700866	et	4	main
tuginema	doc_536541856861_item	2700870	et	3	main
sõna	doc_536541856860_item	2700423	et	4	main
peab	doc_536541856860_item	2700425	et	4	main
olema	doc_536541856860_item	2700426	et	4	main
loengus	doc_536541856860_item	2700432	et	3	main
ja	doc_536541856860_item	2700433	et	3	main
esitatud	doc_536541856860_item	2700435	et	4	main
esindab	doc_536541856860_item	2700454	et	3	main
kultuurile	doc_536541856860_item	2700456	et	3	main
regivärsiline	doc_536541856860_item	2700458	et	4	main
kujunenud	doc_536541856860_item	2700462	et	4	main
tuhat	doc_536541856860_item	2700465	et	4	main
aastat	doc_536541856860_item	2700466	et	3	main
tagasi	doc_536541856860_item	2700467	et	3	main
regilaulu	doc_536541856860_item	2700468	et	4	main
näiteks	doc_536541856860_item	2700475	et	4	main
arendas	doc_536541856860_item	2700481	et	3	main
kordas	doc_536541856860_item	2700485	et	3	main
esitatud	doc_536541856860_item	2700487	et	4	main
värsse	doc_536541856860_item	2700488	et	3	main
üldiselt	doc_536541856860_item	2700493	et	4	main
kihistust	doc_536541856860_item	2700498	et	4	main
ja	doc_536541856860_item	2700500	et	3	main
riimiline	doc_536541856860_item	2700501	et	4	main
uuem	doc_536541856860_item	2700504	et	4	main
lauldi	doc_536541856860_item	2700511	et	3	main
kas	doc_536541856860_item	2700512	et	3	main
või	doc_536541856860_item	2700513	et	4	main
üksi	doc_536541856860_item	2700514	et	4	main
kahekesi	doc_536541856860_item	2700515	et	3	main
kooriga	doc_536541856860_item	2700516	et	4	main
eeslauljaga	doc_536541856860_item	2700517	et	3	main
ja	doc_536541856860_item	2700518	et	3	main
ilma	doc_536541856860_item	2700519	et	4	main
ka	doc_536541856860_item	2700520	et	3	main
kooriga	doc_536541856860_item	2700522	et	4	main
tegevused	doc_536541856860_item	2700528	et	4	main
saatel	doc_536541856860_item	2700546	et	4	main
tekkis	doc_536541856860_item	2700574	et	3	main
riimiline	doc_536541856860_item	2700576	et	4	main
need	doc_536541856860_item	2700578	et	3	main
euroopa	doc_536541856860_item	2700583	et	4	main
siis	doc_536541856860_item	2700593	et	3	main
laul	doc_536541856860_item	2700598	et	4	main
ja	doc_536541856860_item	2700601	et	3	main
viisilt	doc_536541856860_item	2700602	et	3	main
laulmisega	doc_536541856860_item	2700524	et	4	main
järgmised	doc_536541856860_item	2700527	et	3	main
laulmine	doc_536541856860_item	2700529	et	4	main
ilma	doc_536541856860_item	2700530	et	4	main
muusikaalsete	doc_536541856860_item	2700531	et	4	main
instrumendita	doc_536541856860_item	2700532	et	3	main
keha	doc_536541856860_item	2700536	et	4	main
jalapõrutamisega	doc_536541856860_item	2700539	et	3	main
laule	doc_536541856860_item	2700541	et	4	main
esitati	doc_536541856860_item	2700542	et	4	main
said	doc_536541856860_item	2700556	et	4	main
tegelesin	doc_536541856860_item	2700558	et	3	main
aga	doc_536541856860_item	2700561	et	3	main
regilaul	doc_536541856860_item	2700564	et	4	main
levis	doc_536541856860_item	2700565	et	4	main
18	doc_536541856860_item	2700566	et	2	main
sajandil	doc_536541856860_item	2700567	et	3	main
kirikus	doc_536541856860_item	2700568	et	3	main
ja	doc_536541856860_item	2700569	et	3	main
külakoolides	doc_536541856860_item	2700570	et	3	main
venemaa	doc_536541856860_item	2700585	et	4	main
võrrelda	doc_536541856860_item	2700589	et	4	main
regilaulu	doc_536541856860_item	2700590	et	4	main
võib	doc_536541856860_item	2700594	et	3	main
riimiline	doc_536541856860_item	2700597	et	4	main
on	doc_536541856860_item	2700599	et	4	main
värsimõõdult	doc_536541856860_item	2700600	et	3	main
regilauludest	doc_536541856860_item	2700603	et	3	main
mitmekesisem	doc_536541856860_item	2700604	et	4	main
ja	doc_536541856860_item	2700605	et	3	main
seda	doc_536541856860_item	2700606	et	3	main
uuemat	doc_536541856860_item	2700611	et	4	main
iseloomustab	doc_536541856860_item	2700613	et	4	main
ka	doc_536541856860_item	2700614	et	3	main
kirjalik	doc_536541856860_item	2700615	et	3	main
ületähendus	doc_536541856860_item	2700616	et	3	main
laulikuid	doc_536541856860_item	2700617	et	3	main
ja	doc_536541856860_item	2700618	et	3	main
salmikuid	doc_536541856860_item	2700619	et	4	main
kirjutati	doc_536541856860_item	2700620	et	3	main
üldine	doc_536541856860_item	2700625	et	4	main
kirjaoskus	doc_536541856860_item	2700626	et	3	main
sündmus	doc_536541856860_item	2700634	et	3	main
mis	doc_536541856860_item	2700635	et	4	main
mõjutas	doc_536541856860_item	2700636	et	3	main
kujunemist	doc_536541856860_item	2700639	et	4	main
kui	doc_536541856860_item	2700640	et	3	main
laulurahva	doc_536541856860_item	2700641	et	3	main
kujunemist	doc_536541856860_item	2700642	et	4	main
teostus	doc_536541856860_item	2700657	et	4	main
tuli	doc_536541856860_item	2700658	et	4	main
rahvusliku	doc_536541856860_item	2700668	et	3	main
pani	doc_536541856860_item	2700672	et	4	main
raske	doc_536541856860_item	2700682	et	4	main
korraldamiseks	doc_536541856860_item	2700686	et	4	main
venemaa	doc_536541856860_item	2700691	et	4	main
koosseisus	doc_536541856860_item	2700692	et	4	main
ning	doc_536541856860_item	2700693	et	3	main
hingestatud	doc_536541856860_item	2700711	et	4	main
lõppu	doc_536541856860_item	2700720	et	4	main
nii	doc_536541856860_item	2700623	et	3	main
levikule	doc_536541856860_item	2700630	et	3	main
eesti	doc_536541856860_item	2700637	et	4	main
tartus	doc_536541856860_item	2700648	et	3	main
toimunud	doc_536541856860_item	2700649	et	4	main
esimene	doc_536541856860_item	2700650	et	3	main
ülemaaline	doc_536541856860_item	2700651	et	4	main
laulupidu	doc_536541856860_item	2700652	et	4	main
mille	doc_536541856860_item	2700653	et	3	main
seltsist	doc_536541856860_item	2700660	et	4	main
kujuneski	doc_536541856860_item	2700666	et	3	main
eestlaste	doc_536541856860_item	2700667	et	4	main
mis	doc_536541856860_item	2700671	et	4	main
aluse	doc_536541856860_item	2700673	et	4	main
ka	doc_536541856860_item	2700674	et	3	main
järgnevate	doc_536541856860_item	2700675	et	4	main
luba	doc_536541856860_item	2700684	et	4	main
sest	doc_536541856860_item	2700687	et	4	main
neid	doc_536541856860_item	2700688	et	4	main
korraldati	doc_536541856860_item	2700689	et	3	main
tsaristliku	doc_536541856860_item	2700690	et	3	main
juubelilaulupeoga	doc_536541856860_item	2700704	et	4	main
kõlas	doc_536541856860_item	2700708	et	4	main
ernesaksa	doc_536541856860_item	2700710	et	4	main
ndate	doc_536541856860_item	2700719	et	4	main
teiseks	doc_536541856860_item	2700731	et	4	main
üsna	doc_536541856860_item	2700732	et	3	main
korraldatud	doc_536541856860_item	2700739	et	4	main
kus	doc_536541856860_item	2700749	et	3	main
need	doc_536541856860_item	2700754	et	3	main
koorilaul	doc_536541856860_item	2700766	et	4	main
palju	doc_536541856860_item	2700774	et	4	main
noortefestivaalidest	doc_536541856860_item	2700795	et	4	main
arvates	doc_536541856860_item	2700797	et	4	main
tänapäeval	doc_536541856860_item	2700798	et	3	main
korraldatavad	doc_536541856860_item	2700799	et	4	main
üks	doc_536541856860_item	2700800	et	3	main
teeb	doc_536541856860_item	2700808	et	3	main
tõi	doc_536541856860_item	2700821	et	3	main
paljud	doc_536541856860_item	2700828	et	3	main
said	doc_536541856860_item	2700831	et	4	main
test	doc_536541856861_item	2700849	et	3	main
teemal	doc_536541856861_item	2700853	et	3	main
eestlastest	doc_536541856861_item	2700856	et	4	main
laulurahva	doc_536541856861_item	2700857	et	3	main
peab	doc_536541856861_item	2700864	et	4	main
repertuaaris	doc_536541856860_item	2700726	et	3	main
tähtsamaks	doc_536541856860_item	2700733	et	4	main
nimetada	doc_536541856860_item	2700736	et	3	main
laulupidu	doc_536541856860_item	2700740	et	4	main
toimus	doc_536541856860_item	2700742	et	3	main
esines	doc_536541856860_item	2700750	et	3	main
eestlaste	doc_536541856860_item	2700757	et	4	main
hulgas	doc_536541856860_item	2700758	et	4	main
olnud	doc_536541856860_item	2700760	et	4	main
peaaegu	doc_536541856860_item	2700762	et	3	main
sada	doc_536541856860_item	2700763	et	4	main
aastat	doc_536541856860_item	2700764	et	3	main
aga	doc_536541856860_item	2700765	et	3	main
olemas	doc_536541856860_item	2700773	et	4	main
võtta	doc_536541856860_item	2700792	et	3	main
ja	doc_536541856860_item	2700794	et	3	main
eurovisiooni	doc_536541856860_item	2700803	et	4	main
osavõtmine	doc_536541856860_item	2700807	et	3	main
tantsurahvaks	doc_536541856860_item	2700816	et	3	main
näiteks	doc_536541856860_item	2700817	et	4	main
palju	doc_536541856860_item	2700818	et	4	main
uhkust	doc_536541856860_item	2700819	et	4	main
eestlastele	doc_536541856860_item	2700820	et	4	main
just	doc_536541856860_item	2700823	et	3	main
praegu	doc_536541856860_item	2700827	et	3	main
paremat	doc_536541856860_item	2700841	et	4	main
laulurahva	doc_536541856860_item	2700842	et	3	main
keele	doc_536541856861_item	2700848	et	4	main
essee	doc_536541856861_item	2700852	et	4	main
teeb	doc_536541856861_item	2700855	et	3	main
essee	doc_536541856861_item	2700858	et	4	main
olema	doc_536541856861_item	2700865	et	4	main
üldistav	doc_536541856861_item	2700869	et	4	main
loengus	doc_536541856861_item	2700871	et	3	main
väiteid	doc_536541856861_item	2700876	et	4	main
hällist	doc_536541856861_item	2700904	et	4	main
hauani	doc_536541856861_item	2700905	et	3	main
inimesed	doc_536541856861_item	2700906	et	3	main
väljenduvad	doc_536541856861_item	2700907	et	4	main
laulmine	doc_536541856861_item	2700915	et	4	main
ainult	doc_536541856861_item	2700919	et	4	main
esteetiline	doc_536541856861_item	2700920	et	3	main
väljendusvahend	doc_536541856861_item	2700923	et	3	main
ka	doc_536541856861_item	2700925	et	3	main
tegevus	doc_536541856861_item	2700927	et	4	main
ja	doc_536541856861_item	2700932	et	3	main
ajal	doc_536541856861_item	2700944	et	4	main
üksi	doc_536541856861_item	2700952	et	4	main
kooriga	doc_536541856861_item	2700980	et	4	main
enamik	doc_536541856861_item	2700981	et	3	main
ajal	doc_536541856861_item	2700986	et	4	main
meeslauljad	doc_536541856861_item	2700989	et	3	main
esinesid	doc_536541856861_item	2700991	et	4	main
sajandeid	doc_536541856861_item	2701006	et	3	main
nii	doc_536541856861_item	2701016	et	3	main
lauluga	doc_536541856861_item	2701019	et	4	main
tantsudega	doc_536541856861_item	2701034	et	3	main
inimeste	doc_536541856861_item	2701035	et	3	main
huvi	doc_536541856861_item	2701036	et	4	main
laulamise	doc_536541856861_item	2701039	et	4	main
vastu	doc_536541856861_item	2701040	et	3	main
iga	doc_536541856861_item	2701042	et	4	main
aastaga	doc_536541856861_item	2701043	et	3	main
ilmusid	doc_536541856861_item	2701044	et	4	main
1869	doc_536541856861_item	2701048	et	2	main
aastal	doc_536541856861_item	2701049	et	3	main
kujunes	doc_536541856861_item	2701050	et	3	main
esimene	doc_536541856861_item	2701051	et	3	main
mis	doc_536541856861_item	2701054	et	4	main
veel	doc_536541856861_item	2701061	et	4	main
ilmuvad	doc_536541856861_item	2701077	et	4	main
uued	doc_536541856861_item	2701078	et	3	main
stiilid	doc_536541856861_item	2701087	et	4	main
inimesed	doc_536541856861_item	2701088	et	3	main
ja	doc_536541856861_item	2701093	et	3	main
rahval	doc_536541856861_item	2701151	et	3	main
teiseks	doc_536541856860_item	2700722	et	4	main
muusika	doc_536541856860_item	2700725	et	4	main
palju	doc_536541856860_item	2700728	et	4	main
sündmuseks	doc_536541856860_item	2700734	et	3	main
tallinnas	doc_536541856860_item	2700747	et	4	main
ja	doc_536541856860_item	2700748	et	3	main
on	doc_536541856860_item	2700756	et	4	main
populaarsed	doc_536541856860_item	2700759	et	3	main
juba	doc_536541856860_item	2700761	et	3	main
tänapäeval	doc_536541856860_item	2700770	et	3	main
on	doc_536541856860_item	2700771	et	4	main
eestis	doc_536541856860_item	2700772	et	3	main
ning	doc_536541856860_item	2700779	et	3	main
tantsustuudioid	doc_536541856860_item	2700780	et	3	main
mis	doc_536541856860_item	2700781	et	4	main
pakuvad	doc_536541856860_item	2700782	et	3	main
paljudele	doc_536541856860_item	2700783	et	3	main
noortele	doc_536541856860_item	2700784	et	3	main
võimalust	doc_536541856860_item	2700785	et	3	main
laulda	doc_536541856860_item	2700786	et	4	main
ja	doc_536541856860_item	2700787	et	3	main
esineda	doc_536541856860_item	2700788	et	3	main
erinevatel	doc_536541856860_item	2700789	et	4	main
lauluväljakutel	doc_536541856860_item	2700790	et	3	main
minu	doc_536541856860_item	2700796	et	3	main
ja	doc_536541856860_item	2700746	et	3	main
hulk	doc_536541856860_item	2700752	et	3	main
inimesi	doc_536541856860_item	2700753	et	4	main
on	doc_536541856860_item	2700767	et	4	main
erinevaid	doc_536541856860_item	2700775	et	4	main
laulustuudioid	doc_536541856860_item	2700776	et	3	main
ja	doc_536541856860_item	2700777	et	3	main
kontsertidest	doc_536541856860_item	2700793	et	3	main
nendest	doc_536541856860_item	2700806	et	4	main
ainult	doc_536541856860_item	2700812	et	4	main
laulurahvaks	doc_536541856860_item	2700813	et	3	main
vaid	doc_536541856860_item	2700814	et	3	main
ka	doc_536541856860_item	2700815	et	3	main
ka	doc_536541856860_item	2700833	et	3	main
väljaspool	doc_536541856860_item	2700834	et	3	main
näiteks	doc_536541856860_item	2700836	et	4	main
euroopas	doc_536541856860_item	2700837	et	3	main
teebki	doc_536541856860_item	2700838	et	3	main
eestlastest	doc_536541856860_item	2700839	et	4	main
eesti	doc_536541856861_item	2700844	et	4	main
keele	doc_536541856861_item	2700845	et	4	main
kui	doc_536541856861_item	2700846	et	3	main
kirjutamine	doc_536541856861_item	2700850	et	4	main
sõna	doc_536541856861_item	2700862	et	4	main
analüüsiv	doc_536541856861_item	2700867	et	4	main
faktidele	doc_536541856861_item	2700875	et	3	main
oma	doc_536541856861_item	2700908	et	4	main
mõted	doc_536541856861_item	2700909	et	4	main
ja	doc_536541856861_item	2700910	et	3	main
tunded	doc_536541856861_item	2700911	et	3	main
aga	doc_536541856861_item	2700914	et	3	main
emotsionaalne	doc_536541856861_item	2700922	et	3	main
on	doc_536541856861_item	2700934	et	4	main
laulsid	doc_536541856861_item	2700945	et	4	main
inimesed	doc_536541856861_item	2700946	et	3	main
peaaegu	doc_536541856861_item	2700947	et	3	main
kogu	doc_536541856861_item	2700948	et	4	main
aeg	doc_536541856861_item	2700949	et	3	main
inimesed	doc_536541856861_item	2700950	et	3	main
laulsid	doc_536541856861_item	2700951	et	4	main
lauljaid	doc_536541856861_item	2700982	et	4	main
põlve	doc_536541856861_item	2700998	et	4	main
mööda	doc_536541856861_item	2701005	et	4	main
ja	doc_536541856861_item	2701009	et	3	main
sellega	doc_536541856861_item	2701011	et	3	main
ka	doc_536541856861_item	2701018	et	3	main
sajandil	doc_536541856861_item	2701021	et	3	main
muusika	doc_536541856861_item	2701037	et	4	main
ükskord	doc_536541856861_item	2701062	et	3	main
näitab	doc_536541856861_item	2701063	et	3	main
käib	doc_536541856861_item	2701066	et	3	main
eluga	doc_536541856861_item	2701068	et	3	main
muusika	doc_536541856861_item	2701079	et	4	main
instrumendid	doc_536541856861_item	2701080	et	3	main
ja	doc_536541856861_item	2701081	et	3	main
korraldavad	doc_536541856861_item	2701089	et	4	main
esinevad	doc_536541856861_item	2701122	et	4	main
neid	doc_536541856861_item	2701126	et	4	main
rahvamuusikat	doc_536541856861_item	2701138	et	3	main
on	doc_536541856861_item	2701140	et	4	main
huvi	doc_536541856861_item	2701145	et	4	main
ja	doc_536541856861_item	2701147	et	3	main
et	doc_536541856861_item	2701163	et	3	main
lastele	doc_536541856861_item	2701171	et	4	main
laulu	doc_536541856861_item	2701172	et	4	main
koolis	doc_536541856861_item	2701173	et	4	main
ka	doc_536541856861_item	2701174	et	3	main
õpetakse	doc_536541856861_item	2701175	et	4	main
tekib	doc_536541856861_item	2701180	et	3	main
muusika	doc_536541856861_item	2701182	et	4	main
veel	doc_536541856861_item	2701192	et	4	main
üks	doc_536541856861_item	2701193	et	3	main
väga	doc_536541856861_item	2701194	et	3	main
nende	doc_536541856861_item	2701211	et	4	main
kombed	doc_536541856861_item	2701212	et	3	main
on	doc_536541856861_item	2701218	et	4	main
ajaloo	doc_536541856861_item	2701220	et	4	main
rahvalaul	doc_536541856861_item	2701222	et	4	main
korralikult	doc_536541856861_item	2701232	et	4	main
ning	doc_536541856861_item	2701233	et	3	main
seda	doc_536541856861_item	2701235	et	3	main
see	doc_536541856861_item	2701239	et	3	main
eurovisioonil	doc_536541856860_item	2700824	et	3	main
et	doc_536541856860_item	2700826	et	3	main
eestimaa	doc_536541856860_item	2700829	et	4	main
populaarseteks	doc_536541856860_item	2700832	et	4	main
eestit	doc_536541856860_item	2700835	et	3	main
veelgi	doc_536541856860_item	2700840	et	4	main
teise	doc_536541856861_item	2700847	et	4	main
kirjutage	doc_536541856861_item	2700851	et	3	main
mis	doc_536541856861_item	2700854	et	4	main
essee	doc_536541856861_item	2700863	et	4	main
ja	doc_536541856861_item	2700868	et	3	main
ja	doc_536541856861_item	2700872	et	3	main
soovitatav	doc_536541856861_item	2700878	et	4	main
on	doc_536541856861_item	2700877	et	4	main
illustreerida	doc_536541856861_item	2700879	et	3	main
näidetega	doc_536541856861_item	2700880	et	3	main
mis	doc_536541856861_item	2700881	et	4	main
teeb	doc_536541856861_item	2700882	et	3	main
eestlastest	doc_536541856861_item	2700883	et	4	main
laulurahva	doc_536541856861_item	2700884	et	3	main
laulmine	doc_536541856861_item	2700885	et	4	main
on	doc_536541856861_item	2700886	et	4	main
alati	doc_536541856861_item	2700887	et	4	main
olnud	doc_536541856861_item	2700888	et	4	main
populaarne	doc_536541856861_item	2700889	et	3	main
nii	doc_536541856861_item	2700890	et	3	main
noorte	doc_536541856861_item	2700891	et	3	main
kui	doc_536541856861_item	2700892	et	3	main
ka	doc_536541856861_item	2700893	et	3	main
vanemate	doc_536541856861_item	2700894	et	4	main
inimeste	doc_536541856861_item	2700895	et	3	main
hulgas	doc_536541856861_item	2700896	et	4	main
eestlased	doc_536541856861_item	2700897	et	3	main
isegi	doc_536541856861_item	2700898	et	4	main
ütlevad	doc_536541856861_item	2700899	et	4	main
et	doc_536541856861_item	2700900	et	3	main
laulmine	doc_536541856861_item	2700901	et	4	main
lugemistekstis	doc_536541856861_item	2700873	et	3	main
esitatud	doc_536541856861_item	2700874	et	4	main
viib	doc_536541856861_item	2700902	et	3	main
inimest	doc_536541856861_item	2700903	et	3	main
laulude	doc_536541856861_item	2700912	et	3	main
kaudu	doc_536541856861_item	2700913	et	3	main
ei	doc_536541856861_item	2700916	et	4	main
ole	doc_536541856861_item	2700917	et	4	main
olemas	doc_536541856861_item	2700935	et	4	main
põhjust	doc_536541856861_item	2700937	et	4	main
laulutraditsioon	doc_536541856861_item	2700939	et	3	main
olles	doc_536541856861_item	2700953	et	3	main
last	doc_536541856861_item	2700960	et	4	main
hällis	doc_536541856861_item	2700961	et	4	main
kiigutades	doc_536541856861_item	2700962	et	3	main
tol	doc_536541856861_item	2700963	et	3	main
eeslaulja	doc_536541856861_item	2700978	et	4	main
koos	doc_536541856861_item	2700979	et	4	main
samal	doc_536541856861_item	2700985	et	3	main
kes	doc_536541856861_item	2700990	et	4	main
pulmadest	doc_536541856861_item	2700992	et	3	main
suuliselt	doc_536541856861_item	2700999	et	4	main
niiviisi	doc_536541856861_item	2701000	et	3	main
läks	doc_536541856861_item	2701001	et	3	main
rahvalaul	doc_536541856861_item	2701002	et	4	main
aeg	doc_536541856861_item	2701007	et	3	main
koos	doc_536541856861_item	2701010	et	4	main
muutuvad	doc_536541856861_item	2701012	et	4	main
ka	doc_536541856861_item	2701013	et	3	main
paljud	doc_536541856861_item	2701014	et	3	main
millest	doc_536541856861_item	2701024	et	3	main
esitati	doc_536541856861_item	2701028	et	4	main
juba	doc_536541856861_item	2701029	et	3	main
koos	doc_536541856861_item	2701030	et	4	main
muusikainstrumentidega	doc_536541856861_item	2701031	et	3	main
ja	doc_536541856861_item	2701032	et	3	main
ka	doc_536541856861_item	2701033	et	3	main
järgnevate	doc_536541856861_item	2701057	et	4	main
üldlaulupidude	doc_536541856861_item	2701058	et	4	main
on	doc_536541856861_item	2701071	et	4	main
muusika	doc_536541856861_item	2701074	et	4	main
väga	doc_536541856861_item	2701075	et	3	main
populaarne	doc_536541856861_item	2701076	et	3	main
muusika	doc_536541856861_item	2701084	et	4	main
žaanrid	doc_536541856861_item	2701085	et	2	main
ja	doc_536541856861_item	2701086	et	3	main
erinevaid	doc_536541856861_item	2701090	et	4	main
mitte	doc_536541856861_item	2700918	et	3	main
ja	doc_536541856861_item	2700921	et	3	main
eestlasi	doc_536541856861_item	2700928	et	3	main
selleks	doc_536541856861_item	2700933	et	4	main
ja	doc_536541856861_item	2700954	et	3	main
saamises	doc_536541856861_item	2700956	et	4	main
tehes	doc_536541856861_item	2700958	et	3	main
neid	doc_536541856861_item	2700975	et	4	main
olid	doc_536541856861_item	2700983	et	4	main
naised	doc_536541856861_item	2700984	et	3	main
ka	doc_536541856861_item	2700988	et	3	main
pärandasid	doc_536541856861_item	2700994	et	4	main
neid	doc_536541856861_item	2700995	et	4	main
põlvest	doc_536541856861_item	2700997	et	4	main
muutub	doc_536541856861_item	2701008	et	3	main
juhtus	doc_536541856861_item	2701017	et	3	main
19	doc_536541856861_item	2701020	et	2	main
kirikulaulud	doc_536541856861_item	2701023	et	3	main
laulupidu	doc_536541856861_item	2701053	et	4	main
korraldamisele	doc_536541856861_item	2701059	et	4	main
rahvalaul	doc_536541856861_item	2701065	et	4	main
inimeste	doc_536541856861_item	2701067	et	3	main
tänapäeval	doc_536541856861_item	2701070	et	3	main
laulmine	doc_536541856861_item	2701072	et	4	main
ja	doc_536541856861_item	2701073	et	3	main
kontserte	doc_536541856861_item	2701091	et	3	main
mis	doc_536541856861_item	2701121	et	4	main
rahvatantsudega	doc_536541856861_item	2701125	et	3	main
kutsutakse	doc_536541856861_item	2701127	et	3	main
laulupidudele	doc_536541856861_item	2701128	et	4	main
ning	doc_536541856861_item	2701129	et	3	main
teistele	doc_536541856861_item	2701130	et	4	main
oma	doc_536541856861_item	2701135	et	4	main
sajandeid	doc_536541856861_item	2701153	et	3	main
tagasi	doc_536541856861_item	2701154	et	3	main
iga	doc_536541856861_item	2701164	et	4	main
vastu	doc_536541856861_item	2701183	et	3	main
ei	doc_536541856861_item	2701185	et	4	main
kao	doc_536541856861_item	2701186	et	4	main
see	doc_536541856861_item	2701187	et	3	main
tähtis	doc_536541856861_item	2701195	et	4	main
tähendus	doc_536541856861_item	2701196	et	4	main
seotud	doc_536541856861_item	2701199	et	4	main
saab	doc_536541856861_item	2701202	et	3	main
kuidas	doc_536541856861_item	2701204	et	3	main
on	doc_536541856861_item	2701223	et	4	main
rahvatraditsioonidest	doc_536541856861_item	2701227	et	3	main
säilitavad	doc_536541856861_item	2701229	et	4	main
ongi	doc_536541856861_item	2701238	et	4	main
laulurahva	doc_536541856861_item	2701244	et	3	main
essee	doc_536541856862_item	2701245	et	4	main
keele	doc_536541856862_item	2701250	et	4	main
test	doc_536541856862_item	2701251	et	3	main
kirjutamine	doc_536541856862_item	2701252	et	4	main
kirjutage	doc_536541856862_item	2701253	et	3	main
essee	doc_536541856862_item	2701254	et	4	main
teemal	doc_536541856862_item	2701255	et	3	main
sõna	doc_536541856862_item	2701264	et	4	main
esitatud	doc_536541856862_item	2701276	et	4	main
laulmise	doc_536541856862_item	2701290	et	4	main
abil	doc_536541856862_item	2701291	et	4	main
inimesed	doc_536541856862_item	2701292	et	3	main
hetki	doc_536541856862_item	2701296	et	4	main
see	doc_536541856862_item	2701322	et	3	main
nad	doc_536541856862_item	2701333	et	3	main
võisid	doc_536541856862_item	2701337	et	4	main
üksi	doc_536541856862_item	2701339	et	4	main
olles	doc_536541856862_item	2701340	et	3	main
töötades	doc_536541856862_item	2701341	et	3	main
last	doc_536541856862_item	2701342	et	4	main
kiigutades	doc_536541856862_item	2701343	et	3	main
juba	doc_536541856862_item	2701344	et	3	main
vanast	doc_536541856862_item	2701345	et	3	main
osast	doc_536541856862_item	2701359	et	4	main
koorilaulud	doc_536541856862_item	2701367	et	3	main
kus	doc_536541856862_item	2701368	et	3	main
ja	doc_536541856862_item	2701410	et	3	main
nad	doc_536541856862_item	2701411	et	3	main
suuri	doc_536541856862_item	2701414	et	3	main
kuid	doc_536541856861_item	2700924	et	4	main
sotsiaalne	doc_536541856861_item	2700926	et	3	main
tihti	doc_536541856861_item	2700929	et	3	main
kutsutakse	doc_536541856861_item	2700930	et	3	main
laulurahvaks	doc_536541856861_item	2700931	et	3	main
mitu	doc_536541856861_item	2700936	et	4	main
eesti	doc_536541856861_item	2700938	et	4	main
on	doc_536541856861_item	2700940	et	4	main
väga	doc_536541856861_item	2700941	et	3	main
vana	doc_536541856861_item	2700942	et	4	main
tol	doc_536541856861_item	2700943	et	3	main
kokku	doc_536541856861_item	2700955	et	3	main
tööd	doc_536541856861_item	2700957	et	4	main
ja	doc_536541856861_item	2700959	et	3	main
ajal	doc_536541856861_item	2700964	et	4	main
oli	doc_536541856861_item	2700965	et	3	main
laiali	doc_536541856861_item	2700966	et	3	main
levitud	doc_536541856861_item	2700967	et	4	main
regivärsiline	doc_536541856861_item	2700968	et	4	main
rahvalaul	doc_536541856861_item	2700969	et	4	main
nendes	doc_536541856861_item	2700970	et	4	main
lauludes	doc_536541856861_item	2700971	et	3	main
ei	doc_536541856861_item	2700972	et	4	main
olnud	doc_536541856861_item	2700973	et	4	main
riimi	doc_536541856861_item	2700974	et	4	main
laule	doc_536541856861_item	2700976	et	4	main
esitas	doc_536541856861_item	2700977	et	3	main
olid	doc_536541856861_item	2700987	et	4	main
inimesed	doc_536541856861_item	2700993	et	3	main
laule	doc_536541856861_item	2700996	et	4	main
koos	doc_536541856861_item	2701003	et	4	main
inimestega	doc_536541856861_item	2701004	et	3	main
asja	doc_536541856861_item	2701015	et	4	main
ilmusid	doc_536541856861_item	2701022	et	4	main
kujunes	doc_536541856861_item	2701025	et	3	main
riimilaul	doc_536541856861_item	2701026	et	4	main
seda	doc_536541856861_item	2701027	et	3	main
ja	doc_536541856861_item	2701038	et	3	main
suurenes	doc_536541856861_item	2701041	et	4	main
laulukoorid	doc_536541856861_item	2701045	et	3	main
ja	doc_536541856861_item	2701046	et	3	main
orkestrid	doc_536541856861_item	2701047	et	3	main
ülemaailmne	doc_536541856861_item	2701052	et	3	main
pani	doc_536541856861_item	2701055	et	4	main
aluse	doc_536541856861_item	2701056	et	4	main
see	doc_536541856861_item	2701060	et	3	main
et	doc_536541856861_item	2701064	et	3	main
kooskõlas	doc_536541856861_item	2701069	et	3	main
nendega	doc_536541856861_item	2701082	et	4	main
koos	doc_536541856861_item	2701083	et	4	main
lauljaid	doc_536541856861_item	2701092	et	4	main
ansamble	doc_536541856861_item	2701094	et	4	main
pidudele	doc_536541856861_item	2701096	et	4	main
kutsutake	doc_536541856861_item	2701095	et	4	main
neid	doc_536541856861_item	2701097	et	4	main
võib	doc_536541856861_item	2701098	et	3	main
näha	doc_536541856861_item	2701099	et	3	main
televisioonil	doc_536541856861_item	2701100	et	4	main
enamik	doc_536541856861_item	2701101	et	3	main
inimesi	doc_536541856861_item	2701102	et	4	main
kuulavad	doc_536541856861_item	2701103	et	4	main
rohkem	doc_536541856861_item	2701104	et	4	main
populaarset	doc_536541856861_item	2701105	et	3	main
kaasaegset	doc_536541856861_item	2701106	et	3	main
muusikat	doc_536541856861_item	2701107	et	3	main
on	doc_536541856861_item	2701108	et	4	main
aga	doc_536541856861_item	2701109	et	3	main
olemas	doc_536541856861_item	2701110	et	4	main
need	doc_536541856861_item	2701111	et	3	main
kes	doc_536541856861_item	2701112	et	4	main
eelistavad	doc_536541856861_item	2701113	et	4	main
rahvamuusikat	doc_536541856861_item	2701114	et	3	main
on	doc_536541856861_item	2701115	et	4	main
olemas	doc_536541856861_item	2701116	et	4	main
palju	doc_536541856861_item	2701117	et	4	main
ansamble	doc_536541856861_item	2701118	et	4	main
ja	doc_536541856861_item	2701119	et	3	main
koore	doc_536541856861_item	2701120	et	4	main
rahvalauludega	doc_536541856861_item	2701123	et	3	main
ja	doc_536541856861_item	2701124	et	3	main
kasutavad	doc_536541856861_item	2701134	et	4	main
muusika	doc_536541856861_item	2701146	et	4	main
eestlane	doc_536541856861_item	2701165	et	3	main
lapsepõlvest	doc_536541856861_item	2701168	et	4	main
huvi	doc_536541856861_item	2701188	et	4	main
surmani	doc_536541856861_item	2701189	et	3	main
rahvalauludel	doc_536541856861_item	2701190	et	3	main
üritustele	doc_536541856861_item	2701131	et	4	main
paljud	doc_536541856861_item	2701132	et	3	main
heliloojad	doc_536541856861_item	2701133	et	3	main
loomingus	doc_536541856861_item	2701136	et	3	main
ka	doc_536541856861_item	2701137	et	3	main
laulmine	doc_536541856861_item	2701139	et	4	main
alati	doc_536541856861_item	2701141	et	4	main
olnud	doc_536541856861_item	2701142	et	4	main
tähelepanuväärne	doc_536541856861_item	2701143	et	3	main
kultuurisündmus	doc_536541856861_item	2701144	et	3	main
laulmise	doc_536541856861_item	2701148	et	4	main
vastu	doc_536541856861_item	2701149	et	3	main
tekis	doc_536541856861_item	2701150	et	3	main
ja	doc_536541856861_item	2701155	et	3	main
see	doc_536541856861_item	2701156	et	3	main
ei	doc_536541856861_item	2701157	et	4	main
palju	doc_536541856861_item	2701152	et	4	main
kao	doc_536541856861_item	2701158	et	4	main
ka	doc_536541856861_item	2701159	et	3	main
täpäeval	doc_536541856861_item	2701160	et	4	main
ma	doc_536541856861_item	2701161	et	3	main
laulmist	doc_536541856861_item	2701167	et	4	main
vanemad	doc_536541856861_item	2701169	et	4	main
laulavad	doc_536541856861_item	2701170	et	4	main
laulmist	doc_536541856861_item	2701176	et	4	main
kui	doc_536541856861_item	2701177	et	3	main
inimesel	doc_536541856861_item	2701178	et	3	main
huvi	doc_536541856861_item	2701181	et	4	main
siis	doc_536541856861_item	2701184	et	3	main
on	doc_536541856861_item	2701198	et	4	main
ajalooga	doc_536541856861_item	2701200	et	4	main
rahvalauludest	doc_536541856861_item	2701201	et	3	main
inimesed	doc_536541856861_item	2701205	et	3	main
ajal	doc_536541856861_item	2701207	et	4	main
mis	doc_536541856861_item	2701209	et	4	main
nagu	doc_536541856861_item	2701219	et	3	main
üheks	doc_536541856861_item	2701225	et	3	main
inimesed	doc_536541856861_item	2701228	et	3	main
jälgivad	doc_536541856861_item	2701234	et	4	main
ja	doc_536541856861_item	2701236	et	3	main
asi	doc_536541856861_item	2701240	et	4	main
teeb	doc_536541856861_item	2701242	et	3	main
eestlastest	doc_536541856861_item	2701243	et	4	main
essee	doc_536541856862_item	2701260	et	4	main
pikkus	doc_536541856862_item	2701261	et	4	main
300	doc_536541856862_item	2701262	et	2	main
350	doc_536541856862_item	2701263	et	2	main
arutlev	doc_536541856862_item	2701268	et	4	main
analüüsiv	doc_536541856862_item	2701269	et	4	main
ja	doc_536541856862_item	2701270	et	3	main
faktidele	doc_536541856862_item	2701277	et	3	main
on	doc_536541856862_item	2701279	et	4	main
näidetega	doc_536541856862_item	2701282	et	3	main
inimesed	doc_536541856862_item	2701283	et	3	main
hakkasid	doc_536541856862_item	2701284	et	4	main
juba	doc_536541856862_item	2701285	et	3	main
laulma	doc_536541856862_item	2701286	et	3	main
väljendasid	doc_536541856862_item	2701293	et	4	main
häid	doc_536541856862_item	2701295	et	3	main
elus	doc_536541856862_item	2701297	et	4	main
ja	doc_536541856862_item	2701298	et	3	main
just	doc_536541856862_item	2701321	et	3	main
laulurahva	doc_536541856862_item	2701325	et	3	main
et	doc_536541856862_item	2701326	et	3	main
võisid	doc_536541856862_item	2701328	et	4	main
laulda	doc_536541856862_item	2701329	et	4	main
tahtsid	doc_536541856862_item	2701334	et	4	main
ajast	doc_536541856862_item	2701346	et	4	main
nad	doc_536541856862_item	2701347	et	3	main
hakkasid	doc_536541856862_item	2701348	et	4	main
koosnes	doc_536541856862_item	2701356	et	3	main
ja	doc_536541856862_item	2701362	et	3	main
rahvalaulust	doc_536541856862_item	2701364	et	4	main
olid	doc_536541856862_item	2701365	et	4	main
eeslaulja	doc_536541856862_item	2701370	et	4	main
ja	doc_536541856862_item	2701371	et	3	main
ja	doc_536541856862_item	2701377	et	3	main
hakkasid	doc_536541856862_item	2701412	et	4	main
algusest	doc_536541856862_item	2701416	et	4	main
suure	doc_536541856862_item	2701418	et	3	main
korraldati	doc_536541856862_item	2701420	et	3	main
ja	doc_536541856862_item	2701422	et	3	main
mis	doc_536541856862_item	2701433	et	4	main
ühe	doc_536541856862_item	2701451	et	4	main
oma	doc_536541856862_item	2701455	et	4	main
maast	doc_536541856862_item	2701456	et	3	main
see	doc_536541856862_item	2701457	et	3	main
minu	doc_536541856862_item	2701464	et	3	main
arm	doc_536541856862_item	2701465	et	3	main
mis	doc_536541856862_item	2701466	et	4	main
oli	doc_536541856862_item	2701475	et	3	main
pered	doc_536541856862_item	2701481	et	3	main
näha	doc_536541856862_item	2701483	et	3	main
tuttavaid	doc_536541856862_item	2701484	et	3	main
sugulasi	doc_536541856862_item	2701485	et	3	main
ja	doc_536541856862_item	2701486	et	3	main
aja	doc_536541856862_item	2701494	et	4	main
rahvuslikeks	doc_536541856862_item	2701496	et	3	main
arvan	doc_536541856861_item	2701162	et	3	main
õpib	doc_536541856861_item	2701166	et	3	main
lapsepõlves	doc_536541856861_item	2701179	et	4	main
on	doc_536541856861_item	2701191	et	4	main
teada	doc_536541856861_item	2701203	et	3	main
vanal	doc_536541856861_item	2701206	et	3	main
elasid	doc_536541856861_item	2701208	et	4	main
isegi	doc_536541856861_item	2701213	et	4	main
öeldakse	doc_536541856861_item	2701214	et	3	main
et	doc_536541856861_item	2701215	et	3	main
rahvalauluga	doc_536541856861_item	2701216	et	4	main
uurimine	doc_536541856861_item	2701221	et	4	main
paljudest	doc_536541856861_item	2701226	et	3	main
selle	doc_536541856861_item	2701230	et	4	main
see	doc_536541856861_item	2701237	et	3	main
keele	doc_536541856862_item	2701247	et	4	main
mis	doc_536541856862_item	2701256	et	4	main
teeb	doc_536541856862_item	2701257	et	3	main
essee	doc_536541856862_item	2701265	et	4	main
üldistav	doc_536541856862_item	2701271	et	4	main
tuginema	doc_536541856862_item	2701272	et	3	main
loengus	doc_536541856862_item	2701273	et	3	main
lugemistekstis	doc_536541856862_item	2701275	et	3	main
oma	doc_536541856862_item	2701294	et	4	main
nad	doc_536541856861_item	2701197	et	3	main
olid	doc_536541856861_item	2701210	et	4	main
tutvumine	doc_536541856861_item	2701217	et	4	main
saanud	doc_536541856861_item	2701224	et	4	main
traditsiooni	doc_536541856861_item	2701231	et	4	main
eesti	doc_536541856862_item	2701246	et	4	main
ja	doc_536541856862_item	2701274	et	3	main
väiteid	doc_536541856862_item	2701278	et	4	main
soovitatav	doc_536541856862_item	2701280	et	4	main
illustreerida	doc_536541856862_item	2701281	et	3	main
ka	doc_536541856862_item	2701299	et	3	main
halvaid	doc_536541856862_item	2701300	et	4	main
hetki	doc_536541856862_item	2701301	et	4	main
vanal	doc_536541856862_item	2701302	et	3	main
ajal	doc_536541856862_item	2701303	et	4	main
laul	doc_536541856862_item	2701304	et	4	main
saatis	doc_536541856862_item	2701305	et	3	main
eestast	doc_536541856862_item	2701306	et	3	main
sellest	doc_536541856862_item	2701307	et	4	main
ajast	doc_536541856862_item	2701308	et	4	main
kui	doc_536541856862_item	2701309	et	3	main
ta	doc_536541856862_item	2701310	et	4	main
sündis	doc_536541856862_item	2701311	et	3	main
ja	doc_536541856862_item	2701312	et	3	main
selle	doc_536541856862_item	2701313	et	4	main
ajani	doc_536541856862_item	2701314	et	3	main
kuni	doc_536541856862_item	2701315	et	3	main
ta	doc_536541856862_item	2701316	et	4	main
suri	doc_536541856862_item	2701317	et	3	main
ära	doc_536541856862_item	2701318	et	4	main
minu	doc_536541856862_item	2701319	et	3	main
meelest	doc_536541856862_item	2701320	et	4	main
eestlastest	doc_536541856862_item	2701324	et	4	main
erinevad	doc_536541856862_item	2701350	et	4	main
ilmuma	doc_536541856862_item	2701353	et	3	main
neil	doc_536541856862_item	2701357	et	4	main
erinevad	doc_536541856862_item	2701366	et	4	main
olid	doc_536541856862_item	2701369	et	4	main
koor	doc_536541856862_item	2701372	et	4	main
eeslaulja	doc_536541856862_item	2701373	et	4	main
korraldama	doc_536541856862_item	2701413	et	3	main
tartus	doc_536541856862_item	2701421	et	3	main
teeb	doc_536541856862_item	2701434	et	3	main
see	doc_536541856862_item	2701438	et	3	main
kõik	doc_536541856862_item	2701440	et	4	main
hingest	doc_536541856862_item	2701445	et	4	main
nad	doc_536541856862_item	2701453	et	3	main
kirjutasid	doc_536541856862_item	2701454	et	4	main
hingestatud	doc_536541856862_item	2701459	et	4	main
isamaalaul	doc_536541856862_item	2701460	et	4	main
mu	doc_536541856862_item	2701461	et	3	main
on	doc_536541856862_item	2701467	et	4	main
eestimaa	doc_536541856862_item	2701470	et	4	main
suur	doc_536541856862_item	2701477	et	3	main
kus	doc_536541856862_item	2701479	et	3	main
laulud	doc_536541856862_item	2701491	et	3	main
kujunenud	doc_536541856862_item	2701495	et	4	main
öelda	doc_536541856862_item	2701500	et	4	main
et	doc_536541856862_item	2701501	et	3	main
pikkus	doc_536541856863_item	2701524	et	4	main
ja	doc_536541856863_item	2701533	et	3	main
üldistav	doc_536541856863_item	2701534	et	4	main
tihti	doc_536541856863_item	2701547	et	3	main
mis	doc_536541856861_item	2701241	et	4	main
kui	doc_536541856862_item	2701248	et	3	main
teise	doc_536541856862_item	2701249	et	4	main
eestlastest	doc_536541856862_item	2701258	et	4	main
laulurahva	doc_536541856862_item	2701259	et	3	main
peab	doc_536541856862_item	2701266	et	4	main
olema	doc_536541856862_item	2701267	et	4	main
mittu	doc_536541856862_item	2701287	et	4	main
sajandit	doc_536541856862_item	2701288	et	3	main
tagasi	doc_536541856862_item	2701289	et	3	main
teebki	doc_536541856862_item	2701323	et	3	main
nad	doc_536541856862_item	2701327	et	3	main
iga	doc_536541856862_item	2701330	et	4	main
hetk	doc_536541856862_item	2701331	et	3	main
kui	doc_536541856862_item	2701332	et	3	main
laulupeod	doc_536541856862_item	2701351	et	4	main
rahvalaulud	doc_536541856862_item	2701354	et	3	main
kahest	doc_536541856862_item	2701358	et	4	main
rahvalaulust	doc_536541856862_item	2701361	et	4	main
regivärsilisest	doc_536541856862_item	2701363	et	4	main
viis	doc_536541856862_item	2701374	et	4	main
laulu	doc_536541856862_item	2701375	et	4	main
esimese	doc_536541856862_item	2701417	et	3	main
seejärel	doc_536541856862_item	2701424	et	3	main
juba	doc_536541856862_item	2701426	et	3	main
laulupeod	doc_536541856862_item	2701427	et	4	main
ka	doc_536541856862_item	2701428	et	3	main
et	doc_536541856862_item	2701439	et	3	main
need	doc_536541856862_item	2701441	et	3	main
laulud	doc_536541856862_item	2701442	et	3	main
nad	doc_536541856862_item	2701443	et	3	main
laulsid	doc_536541856862_item	2701444	et	4	main
laule	doc_536541856862_item	2701449	et	4	main
ja	doc_536541856862_item	2701450	et	3	main
isamaa	doc_536541856862_item	2701462	et	4	main
hümn	doc_536541856862_item	2701471	et	3	main
nende	doc_536541856862_item	2701473	et	4	main
laulupidudele	doc_536541856862_item	2701474	et	4	main
rahvapidu	doc_536541856862_item	2701478	et	4	main
tulid	doc_536541856862_item	2701480	et	4	main
lootes	doc_536541856862_item	2701482	et	4	main
sõpru	doc_536541856862_item	2701487	et	3	main
laulupeod	doc_536541856862_item	2701489	et	4	main
läbi	doc_536541856862_item	2701493	et	4	main
seega	doc_536541856862_item	2701498	et	4	main
essee	doc_536541856863_item	2701523	et	4	main
essee	doc_536541856863_item	2701528	et	4	main
olema	doc_536541856863_item	2701530	et	4	main
esitatud	doc_536541856863_item	2701539	et	4	main
faktidele	doc_536541856863_item	2701540	et	3	main
väiteid	doc_536541856863_item	2701541	et	4	main
edu	doc_536541856863_item	2701567	et	4	main
hõivatud	doc_536541856863_item	2701585	et	4	main
tööga	doc_536541856863_item	2701586	et	3	main
enne	doc_536541856863_item	2701587	et	4	main
13	doc_536541856863_item	2701588	et	2	main
sajandit	doc_536541856863_item	2701589	et	3	main
pidusid	doc_536541856863_item	2701599	et	4	main
oli	doc_536541856863_item	2701609	et	3	main
lauluharrastusega	doc_536541856863_item	2701613	et	3	main
aastal	doc_536541856863_item	2701615	et	3	main
korraldamise	doc_536541856863_item	2701622	et	4	main
tuli	doc_536541856863_item	2701626	et	4	main
mis	doc_536541856863_item	2701634	et	4	main
pani	doc_536541856863_item	2701635	et	4	main
laulupeod	doc_536541856863_item	2701640	et	4	main
aitanud	doc_536541856863_item	2701643	et	4	main
säilitada	doc_536541856863_item	2701648	et	3	main
seotud	doc_536541856863_item	2701662	et	4	main
kultuur	doc_536541856863_item	2701669	et	3	main
aitas	doc_536541856863_item	2701670	et	3	main
järeldust	doc_536541856863_item	2701679	et	4	main
eestis	doc_536541856863_item	2701723	et	3	main
festivale	doc_536541856863_item	2701726	et	3	main
ja	doc_536541856863_item	2701728	et	3	main
rahva-	doc_536541856863_item	2701732	et	3	main
ka	doc_536541856863_item	2701734	et	3	main
nendest	doc_536541856863_item	2701740	et	4	main
folkloori	doc_536541856863_item	2701743	et	4	main
kogu	doc_536541856863_item	2701799	et	4	main
eesti	doc_536541856863_item	2701801	et	4	main
seda	doc_536541856862_item	2701335	et	3	main
nad	doc_536541856862_item	2701336	et	3	main
laulda	doc_536541856862_item	2701338	et	4	main
korraldama	doc_536541856862_item	2701349	et	3	main
hakkasid	doc_536541856862_item	2701352	et	4	main
rahvalaul	doc_536541856862_item	2701355	et	4	main
lõppriimilisest	doc_536541856862_item	2701360	et	4	main
edasi	doc_536541856862_item	2701376	et	3	main
arendas	doc_536541856862_item	2701378	et	3	main
seda	doc_536541856862_item	2701379	et	3	main
aga	doc_536541856862_item	2701380	et	3	main
koor	doc_536541856862_item	2701381	et	4	main
kordas	doc_536541856862_item	2701382	et	3	main
eeslaulja	doc_536541856862_item	2701383	et	4	main
andes	doc_536541856862_item	2701385	et	4	main
sellega	doc_536541856862_item	2701386	et	3	main
värsse	doc_536541856862_item	2701384	et	3	main
talle	doc_536541856862_item	2701387	et	4	main
mõtteaega	doc_536541856862_item	2701388	et	4	main
alguses	doc_536541856862_item	2701389	et	4	main
üksnes	doc_536541856862_item	2701391	et	3	main
laulsid	doc_536541856862_item	2701390	et	4	main
ainult	doc_536541856862_item	2701392	et	4	main
mehed	doc_536541856862_item	2701393	et	3	main
kuid	doc_536541856862_item	2701394	et	4	main
hiljem	doc_536541856862_item	2701395	et	3	main
lubati	doc_536541856862_item	2701396	et	3	main
esineda	doc_536541856862_item	2701397	et	3	main
ja	doc_536541856862_item	2701398	et	3	main
laulda	doc_536541856862_item	2701399	et	4	main
ka	doc_536541856862_item	2701400	et	3	main
naistele	doc_536541856862_item	2701401	et	3	main
ja	doc_536541856862_item	2701402	et	3	main
lastele	doc_536541856862_item	2701403	et	4	main
edaspidi	doc_536541856862_item	2701404	et	3	main
ei	doc_536541856862_item	2701406	et	4	main
eestlased	doc_536541856862_item	2701405	et	3	main
peatanud	doc_536541856862_item	2701407	et	4	main
pidudega	doc_536541856862_item	2701409	et	4	main
väikeste	doc_536541856862_item	2701408	et	4	main
pidusid	doc_536541856862_item	2701415	et	4	main
laulupeo	doc_536541856862_item	2701419	et	4	main
juba	doc_536541856862_item	2701423	et	3	main
asi	doc_536541856862_item	2701432	et	4	main
laulurahva	doc_536541856862_item	2701436	et	3	main
on	doc_536541856862_item	2701437	et	4	main
neid	doc_536541856862_item	2701448	et	4	main
laulu	doc_536541856862_item	2701452	et	4	main
nüüd	doc_536541856862_item	2701468	et	4	main
need	doc_536541856862_item	2701488	et	3	main
on	doc_536541856862_item	2701492	et	4	main
sümboliteks	doc_536541856862_item	2701497	et	3	main
võib	doc_536541856862_item	2701499	et	3	main
kõik	doc_536541856862_item	2701502	et	4	main
need	doc_536541856862_item	2701503	et	3	main
eestlastest	doc_536541856863_item	2701521	et	4	main
350	doc_536541856863_item	2701526	et	2	main
on	doc_536541856863_item	2701542	et	4	main
erinevaid	doc_536541856863_item	2701553	et	4	main
põhjusi	doc_536541856863_item	2701554	et	3	main
tänapäevane	doc_536541856863_item	2701562	et	4	main
saatis	doc_536541856863_item	2701571	et	3	main
tol	doc_536541856863_item	2701576	et	3	main
eestis	doc_536541856863_item	2701591	et	3	main
usk	doc_536541856863_item	2701594	et	3	main
ja	doc_536541856863_item	2701595	et	3	main
muusika-	doc_536541856863_item	2701611	et	4	main
1869	doc_536541856863_item	2701614	et	2	main
tartus	doc_536541856863_item	2701617	et	3	main
teostus	doc_536541856863_item	2701625	et	4	main
korraldamisele	doc_536541856863_item	2701639	et	4	main
kultuuri	doc_536541856863_item	2701647	et	4	main
sest	doc_536541856863_item	2701649	et	4	main
toimusid	doc_536541856863_item	2701651	et	4	main
vene	doc_536541856863_item	2701653	et	4	main
eestlased	doc_536541856863_item	2701681	et	3	main
laulurahvas	doc_536541856863_item	2701683	et	4	main
tänapäeval	doc_536541856863_item	2701721	et	3	main
palju	doc_536541856863_item	2701725	et	4	main
kontserte	doc_536541856863_item	2701727	et	3	main
muid	doc_536541856863_item	2701729	et	4	main
nii	doc_536541856863_item	2701731	et	3	main
kuulsamad	doc_536541856863_item	2701739	et	4	main
viljandi	doc_536541856863_item	2701742	et	4	main
saaremaa	doc_536541856863_item	2701745	et	4	main
rahvamuusika	doc_536541856863_item	2701746	et	4	main
festival	doc_536541856863_item	2701747	et	3	main
jaanipäeval	doc_536541856863_item	2701748	et	3	main
ja	doc_536541856863_item	2701749	et	3	main
asi	doc_536541856863_item	2701758	et	4	main
eestlastest	doc_536541856863_item	2701761	et	4	main
arvan	doc_536541856863_item	2701764	et	3	main
meenutada	doc_536541856863_item	2701767	et	3	main
populaarsed	doc_536541856863_item	2701798	et	3	main
laulukultuur	doc_536541856863_item	2701802	et	3	main
ja	doc_536541856863_item	2701805	et	3	main
minevikus	doc_536541856863_item	2701813	et	3	main
areneb	doc_536541856863_item	2701814	et	3	main
olevikus	doc_536541856863_item	2701815	et	3	main
ka	doc_536541856863_item	2701820	et	3	main
tants	doc_536541856863_item	2701824	et	3	main
on	doc_536541856863_item	2701825	et	4	main
saatnud	doc_536541856863_item	2701826	et	4	main
eestlasi	doc_536541856863_item	2701827	et	3	main
nii	doc_536541856863_item	2701828	et	3	main
halval	doc_536541856863_item	2701829	et	3	main
kui	doc_536541856863_item	2701830	et	3	main
heal	doc_536541856863_item	2701831	et	3	main
on	doc_536541856863_item	2701840	et	4	main
aitab	doc_536541856863_item	2701843	et	3	main
ühist	doc_536541856863_item	2701845	et	3	main
leida	doc_536541856863_item	2701847	et	3	main
minu	doc_536541856863_item	2701848	et	3	main
meelest	doc_536541856863_item	2701849	et	4	main
eestlased	doc_536541856863_item	2701850	et	3	main
on	doc_536541856863_item	2701851	et	4	main
meie	doc_536541856863_item	2701855	et	4	main
kus	doc_536541856863_item	2701860	et	3	main
kohtuda	doc_536541856863_item	2701862	et	3	main
paganlikke	doc_536541856863_item	2701864	et	3	main
ka	doc_536541856863_item	2701869	et	3	main
olid	doc_536541856862_item	2701425	et	4	main
tallinnas	doc_536541856862_item	2701429	et	4	main
veel	doc_536541856862_item	2701430	et	4	main
üks	doc_536541856862_item	2701431	et	3	main
eestastes	doc_536541856862_item	2701435	et	4	main
ise	doc_536541856862_item	2701446	et	4	main
kirjutasid	doc_536541856862_item	2701447	et	4	main
oli	doc_536541856862_item	2701458	et	3	main
on	doc_536541856862_item	2701463	et	4	main
meie	doc_536541856862_item	2701469	et	4	main
tänu	doc_536541856862_item	2701472	et	4	main
ka	doc_536541856862_item	2701476	et	3	main
ja	doc_536541856862_item	2701490	et	3	main
tegud	doc_536541856862_item	2701504	et	4	main
tegidki	doc_536541856862_item	2701505	et	4	main
eestlastest	doc_536541856862_item	2701506	et	4	main
laulurahva	doc_536541856862_item	2701507	et	3	main
essee	doc_536541856863_item	2701508	et	4	main
eesti	doc_536541856863_item	2701509	et	4	main
keele	doc_536541856863_item	2701510	et	4	main
kui	doc_536541856863_item	2701511	et	3	main
teise	doc_536541856863_item	2701512	et	4	main
keele	doc_536541856863_item	2701513	et	4	main
test	doc_536541856863_item	2701514	et	3	main
kirjutamine	doc_536541856863_item	2701515	et	4	main
kirjutage	doc_536541856863_item	2701516	et	3	main
essee	doc_536541856863_item	2701517	et	4	main
teemal	doc_536541856863_item	2701518	et	3	main
mis	doc_536541856863_item	2701519	et	4	main
teeb	doc_536541856863_item	2701520	et	3	main
laulurahva	doc_536541856863_item	2701522	et	3	main
sõna	doc_536541856863_item	2701527	et	4	main
peab	doc_536541856863_item	2701529	et	4	main
tuginema	doc_536541856863_item	2701535	et	3	main
loengus	doc_536541856863_item	2701536	et	3	main
ja	doc_536541856863_item	2701537	et	3	main
lugemistekstis	doc_536541856863_item	2701538	et	3	main
laulurahvaks	doc_536541856863_item	2701549	et	3	main
on	doc_536541856863_item	2701551	et	4	main
palju	doc_536541856863_item	2701552	et	4	main
kombed	doc_536541856863_item	2701556	et	3	main
kultuuri	doc_536541856863_item	2701557	et	4	main
abil	doc_536541856863_item	2701558	et	4	main
saadud	doc_536541856863_item	2701559	et	4	main
iseseisvus	doc_536541856863_item	2701560	et	4	main
ning	doc_536541856863_item	2701561	et	3	main
300	doc_536541856863_item	2701525	et	2	main
arutlev	doc_536541856863_item	2701531	et	4	main
analüüsiv	doc_536541856863_item	2701532	et	4	main
soovitatav	doc_536541856863_item	2701543	et	4	main
illustreerida	doc_536541856863_item	2701544	et	3	main
näidetega	doc_536541856863_item	2701545	et	3	main
eestlasi	doc_536541856863_item	2701546	et	3	main
nimetatakse	doc_536541856863_item	2701548	et	3	main
muised	doc_536541856863_item	2701555	et	4	main
maailmas	doc_536541856863_item	2701568	et	3	main
vanal	doc_536541856863_item	2701569	et	3	main
ajal	doc_536541856863_item	2701570	et	4	main
naissoost	doc_536541856863_item	2701581	et	4	main
kuna	doc_536541856863_item	2701582	et	3	main
mehed	doc_536541856863_item	2701583	et	3	main
tantsimises	doc_536541856863_item	2701600	et	4	main
sajandil	doc_536541856863_item	2701604	et	3	main
rahvuslik	doc_536541856863_item	2701606	et	3	main
mis	doc_536541856863_item	2701608	et	4	main
sai	doc_536541856863_item	2701632	et	4	main
sündmuseks	doc_536541856863_item	2701633	et	3	main
üldlaulupidude	doc_536541856863_item	2701638	et	4	main
alati	doc_536541856863_item	2701642	et	4	main
rahvast	doc_536541856863_item	2701645	et	4	main
nõukogude	doc_536541856863_item	2701656	et	3	main
1980ndate	doc_536541856863_item	2701665	et	4	main
teha	doc_536541856863_item	2701678	et	3	main
sellest	doc_536541856863_item	2701685	et	4	main
kui	doc_536541856863_item	2701686	et	3	main
hästi	doc_536541856863_item	2701687	et	3	main
selleks	doc_536541856863_item	2701550	et	4	main
laul	doc_536541856863_item	2701572	et	4	main
hauani	doc_536541856863_item	2701575	et	3	main
olid	doc_536541856863_item	2701584	et	4	main
levinenud	doc_536541856863_item	2701592	et	4	main
paganlik	doc_536541856863_item	2701593	et	3	main
pidas	doc_536541856863_item	2701597	et	3	main
erinevaid	doc_536541856863_item	2701598	et	4	main
lauldes	doc_536541856863_item	2701602	et	3	main
ärkamine	doc_536541856863_item	2701607	et	4	main
seotud	doc_536541856863_item	2701610	et	4	main
ning	doc_536541856863_item	2701612	et	3	main
korraldati	doc_536541856863_item	2701616	et	3	main
laulupidu	doc_536541856863_item	2701620	et	4	main
eesti	doc_536541856863_item	2701563	et	4	main
rahva-	doc_536541856863_item	2701564	et	3	main
ja	doc_536541856863_item	2701565	et	3	main
poppmuusika	doc_536541856863_item	2701566	et	4	main
eestlast	doc_536541856863_item	2701573	et	4	main
hällist	doc_536541856863_item	2701574	et	4	main
ajal	doc_536541856863_item	2701577	et	4	main
enamus	doc_536541856863_item	2701578	et	4	main
lauljaid	doc_536541856863_item	2701579	et	4	main
oli	doc_536541856863_item	2701580	et	3	main
oli	doc_536541856863_item	2701590	et	3	main
rahvas	doc_536541856863_item	2701596	et	4	main
ja	doc_536541856863_item	2701601	et	3	main
19	doc_536541856863_item	2701603	et	2	main
hakkas	doc_536541856863_item	2701605	et	3	main
esimest	doc_536541856863_item	2701618	et	4	main
ülemaalist	doc_536541856863_item	2701619	et	4	main
mille	doc_536541856863_item	2701621	et	3	main
ja	doc_536541856863_item	2701624	et	3	main
voldemar	doc_536541856863_item	2701628	et	4	main
see	doc_536541856863_item	2701630	et	3	main
üritus	doc_536541856863_item	2701631	et	4	main
aluse	doc_536541856863_item	2701636	et	4	main
on	doc_536541856863_item	2701641	et	4	main
eesti	doc_536541856863_item	2701644	et	4	main
tsaari	doc_536541856863_item	2701654	et	4	main
ja	doc_536541856863_item	2701655	et	3	main
liidu	doc_536541856863_item	2701657	et	3	main
rahvusmuusikaga	doc_536541856863_item	2701659	et	3	main
on	doc_536541856863_item	2701660	et	4	main
ka	doc_536541856863_item	2701661	et	3	main
teine	doc_536541856863_item	2701663	et	3	main
ärkamine	doc_536541856863_item	2701664	et	4	main
iseseisvust	doc_536541856863_item	2701672	et	4	main
saada	doc_536541856863_item	2701673	et	4	main
ma	doc_536541856863_item	2701674	et	3	main
arvan	doc_536541856863_item	2701675	et	3	main
et	doc_536541856863_item	2701676	et	3	main
võib	doc_536541856863_item	2701677	et	3	main
kultuurüritusi	doc_536541856863_item	2701730	et	3	main
kaasaegse	doc_536541856863_item	2701735	et	3	main
muusika	doc_536541856863_item	2701736	et	4	main
armastajatele	doc_536541856863_item	2701737	et	4	main
on	doc_536541856863_item	2701741	et	4	main
festival	doc_536541856863_item	2701744	et	3	main
vabaõhumuuseumis	doc_536541856863_item	2701750	et	3	main
toimuvad	doc_536541856863_item	2701751	et	4	main
kontserdid	doc_536541856863_item	2701752	et	3	main
aga	doc_536541856863_item	2701753	et	3	main
rahvakultuur	doc_536541856863_item	2701754	et	3	main
ja	doc_536541856863_item	2701771	et	3	main
euroopas	doc_536541856863_item	2701800	et	3	main
on	doc_536541856863_item	2701803	et	4	main
ainulaadne	doc_536541856863_item	2701804	et	3	main
väga	doc_536541856863_item	2701806	et	3	main
levimist	doc_536541856863_item	2701819	et	4	main
ajal	doc_536541856863_item	2701832	et	4	main
nii	doc_536541856863_item	2701833	et	3	main
tööd	doc_536541856863_item	2701834	et	4	main
tehes	doc_536541856863_item	2701835	et	3	main
kui	doc_536541856863_item	2701836	et	3	main
ka	doc_536541856863_item	2701837	et	3	main
kultuur	doc_536541856863_item	2701839	et	3	main
tõeline	doc_536541856863_item	2701852	et	4	main
imeilusat	doc_536541856863_item	2701866	et	3	main
kirikulaulmist	doc_536541856863_item	2701867	et	3	main
kaasaegse	doc_536541856863_item	2701871	et	3	main
muusika	doc_536541856863_item	2701872	et	4	main
rütme	doc_536541856863_item	2701873	et	3	main
keele	doc_536541856864_item	2701876	et	4	main
kui	doc_536541856864_item	2701877	et	3	main
teise	doc_536541856864_item	2701878	et	4	main
keele	doc_536541856864_item	2701879	et	4	main
test	doc_536541856864_item	2701880	et	3	main
essee	doc_536541856864_item	2701889	et	4	main
sõna	doc_536541856864_item	2701893	et	4	main
peab	doc_536541856864_item	2701895	et	4	main
said	doc_536541856864_item	2701926	et	4	main
end	doc_536541856864_item	2701932	et	4	main
vabaks	doc_536541856864_item	2701933	et	3	main
eestlased	doc_536541856864_item	2701940	et	3	main
idee	doc_536541856863_item	2701623	et	4	main
johann	doc_536541856863_item	2701627	et	4	main
jannsenist	doc_536541856863_item	2701629	et	4	main
järgnevate	doc_536541856863_item	2701637	et	4	main
oma	doc_536541856863_item	2701646	et	4	main
nad	doc_536541856863_item	2701650	et	3	main
isegi	doc_536541856863_item	2701652	et	4	main
ajal	doc_536541856863_item	2701658	et	4	main
lõpus	doc_536541856863_item	2701666	et	4	main
millal	doc_536541856863_item	2701667	et	3	main
rikkas	doc_536541856863_item	2701668	et	4	main
eestile	doc_536541856863_item	2701671	et	3	main
et	doc_536541856863_item	2701680	et	3	main
on	doc_536541856863_item	2701682	et	4	main
ka	doc_536541856863_item	2701684	et	3	main
on	doc_536541856863_item	2701688	et	4	main
rahvakultuur	doc_536541856863_item	2701689	et	3	main
säilinud	doc_536541856863_item	2701690	et	4	main
tänapäevani	doc_536541856863_item	2701691	et	3	main
ja	doc_536541856863_item	2701692	et	3	main
kui	doc_536541856863_item	2701693	et	3	main
suur	doc_536541856863_item	2701694	et	3	main
huvi	doc_536541856863_item	2701695	et	4	main
on	doc_536541856863_item	2701696	et	4	main
noortel	doc_536541856863_item	2701697	et	3	main
selle	doc_536541856863_item	2701698	et	4	main
vastu	doc_536541856863_item	2701699	et	3	main
viimastel	doc_536541856863_item	2701700	et	3	main
aastatel	doc_536541856863_item	2701701	et	4	main
on	doc_536541856863_item	2701702	et	4	main
väga	doc_536541856863_item	2701703	et	3	main
populaarne	doc_536541856863_item	2701704	et	3	main
ehtsa	doc_536541856863_item	2701705	et	3	main
rahvamuusika	doc_536541856863_item	2701706	et	4	main
otsimine	doc_536541856863_item	2701707	et	4	main
öeldakse	doc_536541856863_item	2701708	et	3	main
et	doc_536541856863_item	2701709	et	3	main
setumaal	doc_536541856863_item	2701710	et	4	main
on	doc_536541856863_item	2701711	et	4	main
hetkel	doc_536541856863_item	2701712	et	4	main
kõige	doc_536541856863_item	2701713	et	4	main
ehtsam	doc_536541856863_item	2701714	et	4	main
rahvamuusika	doc_536541856863_item	2701715	et	4	main
kuna	doc_536541856863_item	2701716	et	3	main
seal	doc_536541856863_item	2701717	et	4	main
ei	doc_536541856863_item	2701718	et	4	main
ole	doc_536541856863_item	2701719	et	4	main
linnamõju	doc_536541856863_item	2701720	et	4	main
päris	doc_536541856863_item	2701724	et	4	main
korraldatakse	doc_536541856863_item	2701722	et	3	main
kuid	doc_536541856863_item	2701733	et	4	main
ole	doc_536541856863_item	2701756	et	4	main
ainus	doc_536541856863_item	2701757	et	4	main
teeb	doc_536541856863_item	2701760	et	3	main
laulurahva	doc_536541856863_item	2701762	et	3	main
et	doc_536541856863_item	2701765	et	3	main
ka	doc_536541856863_item	2701768	et	3	main
popp	doc_536541856863_item	2701772	et	3	main
muusikute	doc_536541856863_item	2701773	et	3	main
edu	doc_536541856863_item	2701774	et	4	main
maailmas	doc_536541856863_item	2701775	et	3	main
eesti	doc_536541856863_item	2701776	et	4	main
dirigent	doc_536541856863_item	2701777	et	3	main
klas	doc_536541856863_item	2701779	et	4	main
eri	doc_536541856863_item	2701778	et	4	main
on	doc_536541856863_item	2701780	et	4	main
töötanud	doc_536541856863_item	2701781	et	4	main
ameerikas	doc_536541856863_item	2701782	et	4	main
ja	doc_536541856863_item	2701783	et	3	main
rootsis	doc_536541856863_item	2701784	et	3	main
tanel	doc_536541856863_item	2701785	et	4	main
padar	doc_536541856863_item	2701786	et	4	main
ja	doc_536541856863_item	2701787	et	3	main
dave	doc_536541856863_item	2701788	et	4	main
benton	doc_536541856863_item	2701789	et	4	main
tõid	doc_536541856863_item	2701790	et	4	main
eurolaulu	doc_536541856863_item	2701791	et	4	main
võistluse	doc_536541856863_item	2701792	et	3	main
võidu	doc_536541856863_item	2701793	et	4	main
vanilla	doc_536541856863_item	2701794	et	4	main
ninja	doc_536541856863_item	2701795	et	4	main
laulud	doc_536541856863_item	2701796	et	3	main
kõige	doc_536541856863_item	2701738	et	4	main
ei	doc_536541856863_item	2701755	et	4	main
mis	doc_536541856863_item	2701759	et	4	main
ma	doc_536541856863_item	2701763	et	3	main
tuleb	doc_536541856863_item	2701766	et	3	main
eesti	doc_536541856863_item	2701769	et	4	main
klassikaliste	doc_536541856863_item	2701770	et	4	main
on	doc_536541856863_item	2701797	et	4	main
on	doc_536541856863_item	2701810	et	4	main
sündinud	doc_536541856863_item	2701811	et	4	main
kauges	doc_536541856863_item	2701812	et	3	main
ja	doc_536541856863_item	2701816	et	3	main
see	doc_536541856863_item	2701841	et	3	main
inimesi	doc_536541856863_item	2701844	et	4	main
riik	doc_536541856863_item	2701856	et	3	main
on	doc_536541856863_item	2701857	et	4	main
nii	doc_536541856863_item	2701863	et	3	main
kuid	doc_536541856863_item	2701868	et	4	main
kirjutamine	doc_536541856864_item	2701881	et	4	main
kirjutage	doc_536541856864_item	2701882	et	3	main
eriline	doc_536541856863_item	2701807	et	4	main
sündmus	doc_536541856863_item	2701808	et	3	main
mis	doc_536541856863_item	2701809	et	4	main
jätkab	doc_536541856863_item	2701817	et	3	main
tulevikus	doc_536541856863_item	2701821	et	4	main
ja	doc_536541856863_item	2701823	et	3	main
mis	doc_536541856863_item	2701842	et	4	main
keelt	doc_536541856863_item	2701846	et	4	main
ainus	doc_536541856863_item	2701858	et	4	main
võib	doc_536541856863_item	2701861	et	3	main
300	doc_536541856864_item	2701891	et	2	main
essee	doc_536541856864_item	2701894	et	4	main
arutlev	doc_536541856864_item	2701897	et	4	main
juured	doc_536541856864_item	2701922	et	3	main
siis	doc_536541856864_item	2701928	et	3	main
kui	doc_536541856864_item	2701929	et	3	main
nad	doc_536541856864_item	2701930	et	3	main
laulsid	doc_536541856864_item	2701931	et	4	main
lauludele	doc_536541856864_item	2701939	et	3	main
ja	doc_536541856864_item	2701943	et	3	main
nimel	doc_536541856864_item	2701960	et	3	main
ajalukku	doc_536541856864_item	2701965	et	4	main
põlvest	doc_536541856864_item	2701977	et	4	main
aastal	doc_536541856864_item	2702020	et	3	main
sellest	doc_536541856864_item	2702022	et	4	main
rahvusliku	doc_536541856864_item	2702024	et	3	main
kõrg	doc_536541856864_item	2702026	et	4	main
hetk	doc_536541856864_item	2702027	et	3	main
ja	doc_536541856864_item	2702036	et	3	main
millegi	doc_536541856864_item	2702040	et	4	main
kõlas	doc_536541856864_item	2702064	et	4	main
polnud	doc_536541856864_item	2702073	et	3	main
järel	doc_536541856864_item	2702086	et	4	main
said	doc_536541856864_item	2702088	et	4	main
laulvaks	doc_536541856864_item	2702089	et	4	main
rahvaks	doc_536541856864_item	2702090	et	3	main
relvi	doc_536541856864_item	2702104	et	4	main
oligi	doc_536541856864_item	2702107	et	3	main
ongi	doc_536541856864_item	2702116	et	4	main
oma	doc_536541856863_item	2701818	et	4	main
laul	doc_536541856863_item	2701822	et	4	main
pidutsedes	doc_536541856863_item	2701838	et	3	main
laulurahvas	doc_536541856863_item	2701853	et	4	main
sest	doc_536541856863_item	2701854	et	4	main
koht	doc_536541856863_item	2701859	et	3	main
kombeid	doc_536541856863_item	2701865	et	4	main
essee	doc_536541856864_item	2701874	et	4	main
essee	doc_536541856864_item	2701883	et	4	main
teemal	doc_536541856864_item	2701884	et	3	main
mis	doc_536541856864_item	2701885	et	4	main
teeb	doc_536541856864_item	2701886	et	3	main
eestlastest	doc_536541856864_item	2701887	et	4	main
laulurahva	doc_536541856864_item	2701888	et	3	main
350	doc_536541856864_item	2701892	et	2	main
loengus	doc_536541856864_item	2701902	et	3	main
ja	doc_536541856864_item	2701903	et	3	main
lugemistekstis	doc_536541856864_item	2701904	et	3	main
esitatud	doc_536541856864_item	2701905	et	4	main
faktidele	doc_536541856864_item	2701906	et	3	main
väiteid	doc_536541856864_item	2701907	et	4	main
on	doc_536541856864_item	2701908	et	4	main
soovitatav	doc_536541856864_item	2701909	et	4	main
illustreerida	doc_536541856864_item	2701910	et	3	main
näidetega	doc_536541856864_item	2701911	et	3	main
mis	doc_536541856864_item	2701912	et	4	main
teeb	doc_536541856864_item	2701913	et	3	main
eestlastest	doc_536541856864_item	2701914	et	4	main
laulurahva	doc_536541856864_item	2701915	et	3	main
eestlastest	doc_536541856864_item	2701916	et	4	main
teeb	doc_536541856864_item	2701917	et	3	main
laulurahva	doc_536541856864_item	2701918	et	3	main
rikkalik	doc_536541856864_item	2701919	et	3	main
folkloor	doc_536541856864_item	2701920	et	4	main
ja	doc_536541856864_item	2701923	et	3	main
jõud	doc_536541856864_item	2701951	et	4	main
et	doc_536541856864_item	2701952	et	3	main
ja	doc_536541856864_item	2701958	et	3	main
lähevad	doc_536541856864_item	2701963	et	3	main
kui	doc_536541856864_item	2701966	et	3	main
esimene	doc_536541856864_item	2701968	et	3	main
regilaul	doc_536541856864_item	2701970	et	4	main
oli	doc_536541856864_item	2701980	et	3	main
lõbusaid	doc_536541856863_item	2701870	et	3	main
eesti	doc_536541856864_item	2701875	et	4	main
pikkus	doc_536541856864_item	2701890	et	4	main
olema	doc_536541856864_item	2701896	et	4	main
analüüsiv	doc_536541856864_item	2701898	et	4	main
ja	doc_536541856864_item	2701899	et	3	main
üldistav	doc_536541856864_item	2701900	et	4	main
tuginema	doc_536541856864_item	2701901	et	3	main
kauged	doc_536541856864_item	2701921	et	3	main
mis	doc_536541856864_item	2701934	et	4	main
toimus	doc_536541856864_item	2701935	et	3	main
laulupeol	doc_536541856864_item	2701936	et	4	main
just	doc_536541856864_item	2701937	et	3	main
on	doc_536541856864_item	2701941	et	4	main
ühised	doc_536541856864_item	2701942	et	3	main
on	doc_536541856864_item	2701946	et	4	main
koos	doc_536541856864_item	2701947	et	4	main
siis	doc_536541856864_item	2701948	et	3	main
on	doc_536541856864_item	2701949	et	4	main
ka	doc_536541856864_item	2701950	et	3	main
oma	doc_536541856864_item	2701956	et	4	main
rahva	doc_536541856864_item	2701957	et	3	main
laulu	doc_536541856864_item	2701961	et	4	main
laulutraditsioon	doc_536541856864_item	2701969	et	3	main
neid	doc_536541856864_item	2701975	et	4	main
anti	doc_536541856864_item	2701976	et	3	main
suuliselt	doc_536541856864_item	2701979	et	4	main
mis	doc_536541856864_item	2702017	et	4	main
esimene	doc_536541856864_item	2702043	et	3	main
kõrghetk	doc_536541856864_item	2702044	et	3	main
toimus	doc_536541856864_item	2702045	et	3	main
1969	doc_536541856864_item	2702046	et	2	main
aastal	doc_536541856864_item	2702047	et	3	main
on	doc_536541856864_item	2702056	et	4	main
isamaa	doc_536541856864_item	2702068	et	4	main
minu	doc_536541856864_item	2702070	et	3	main
jaksu	doc_536541856864_item	2702075	et	4	main
eestlastest	doc_536541856864_item	2702087	et	4	main
ja	doc_536541856864_item	2702091	et	3	main
laulnud	doc_536541856864_item	2702095	et	4	main
nii	doc_536541856864_item	2702099	et	3	main
ilusti	doc_536541856864_item	2702100	et	3	main
polnud	doc_536541856864_item	2702101	et	3	main
vaja	doc_536541856864_item	2702102	et	4	main
ust	doc_536541856864_item	2702111	et	4	main
arvates	doc_536541856864_item	2702113	et	4	main
keele	doc_536541856865_item	2702123	et	4	main
essee	doc_536541856865_item	2702130	et	4	main
teemal	doc_536541856865_item	2702131	et	3	main
sõna	doc_536541856865_item	2702140	et	4	main
arutlev	doc_536541856865_item	2702144	et	4	main
tuginema	doc_536541856865_item	2702148	et	3	main
ja	doc_536541856865_item	2702150	et	3	main
on	doc_536541856865_item	2702155	et	4	main
illustreerida	doc_536541856865_item	2702157	et	3	main
suure	doc_536541856865_item	2702159	et	3	main
võin	doc_536541856865_item	2702161	et	3	main
öelda	doc_536541856865_item	2702162	et	4	main
muusika	doc_536541856865_item	2702187	et	4	main
festivaalist	doc_536541856865_item	2702188	et	4	main
alati	doc_536541856865_item	2702193	et	4	main
osaleb	doc_536541856865_item	2702194	et	3	main
kuid	doc_536541856865_item	2702199	et	4	main
peo	doc_536541856865_item	2702201	et	4	main
on	doc_536541856865_item	2702203	et	4	main
ka	doc_536541856865_item	2702214	et	3	main
eestlased	doc_536541856865_item	2702217	et	3	main
ühinemine	doc_536541856864_item	2701924	et	4	main
eestlastest	doc_536541856864_item	2701925	et	4	main
laulurahvaks	doc_536541856864_item	2701927	et	3	main
tänu	doc_536541856864_item	2701938	et	4	main
inimesed	doc_536541856864_item	2701945	et	3	main
eest	doc_536541856864_item	2701955	et	4	main
kaugele	doc_536541856864_item	2701964	et	4	main
tekis	doc_536541856864_item	2701967	et	3	main
põlve	doc_536541856864_item	2701978	et	4	main
kontakt	doc_536541856864_item	2701982	et	3	main
ajaga	doc_536541856864_item	2701983	et	3	main
mis	doc_536541856864_item	2701984	et	4	main
on	doc_536541856864_item	2701985	et	4	main
praegu	doc_536541856864_item	2701986	et	3	main
ja	doc_536541856864_item	2701987	et	3	main
mis	doc_536541856864_item	2701988	et	4	main
oli	doc_536541856864_item	2701989	et	3	main
kauges	doc_536541856864_item	2701990	et	3	main
ajaloos	doc_536541856864_item	2701991	et	4	main
laulu	doc_536541856864_item	2701992	et	4	main
arenemisega	doc_536541856864_item	2701993	et	4	main
ja	doc_536541856864_item	2701994	et	3	main
aja	doc_536541856864_item	2701995	et	4	main
muutumisega	doc_536541856864_item	2701996	et	4	main
lauludest	doc_536541856864_item	2701997	et	3	main
on	doc_536541856864_item	2701998	et	4	main
saanud	doc_536541856864_item	2701999	et	4	main
teised	doc_536541856864_item	2702000	et	4	main
riimilisteks	doc_536541856864_item	2702001	et	4	main
neid	doc_536541856864_item	2702002	et	4	main
juba	doc_536541856864_item	2702003	et	3	main
kirjutati	doc_536541856864_item	2702004	et	3	main
ümber	doc_536541856864_item	2702005	et	3	main
ja	doc_536541856864_item	2702006	et	3	main
nad	doc_536541856864_item	2702007	et	3	main
kiiruga	doc_536541856864_item	2702008	et	4	main
üle	doc_536541856864_item	2702010	et	3	main
levisid	doc_536541856864_item	2702009	et	4	main
eesti	doc_536541856864_item	2702011	et	4	main
laulurahvaks	doc_536541856864_item	2702012	et	3	main
teeb	doc_536541856864_item	2702013	et	3	main
esimene	doc_536541856864_item	2702014	et	3	main
ülemaaline	doc_536541856864_item	2702015	et	4	main
laulupidu	doc_536541856864_item	2702016	et	4	main
kui	doc_536541856864_item	2701944	et	3	main
seista	doc_536541856864_item	2701953	et	4	main
enda	doc_536541856864_item	2701954	et	4	main
riigi	doc_536541856864_item	2701959	et	3	main
juured	doc_536541856864_item	2701962	et	3	main
regilaule	doc_536541856864_item	2701971	et	4	main
ei	doc_536541856864_item	2701972	et	4	main
kirjutati	doc_536541856864_item	2701973	et	3	main
vaid	doc_536541856864_item	2701974	et	3	main
tihe	doc_536541856864_item	2701981	et	3	main
toimus	doc_536541856864_item	2702018	et	3	main
neid	doc_536541856864_item	2702033	et	4	main
on	doc_536541856864_item	2702034	et	4	main
meil	doc_536541856864_item	2702038	et	4	main
on	doc_536541856864_item	2702039	et	4	main
kui	doc_536541856864_item	2702049	et	3	main
100	doc_536541856864_item	2702051	et	2	main
meeliülendavamaks	doc_536541856864_item	2702055	et	4	main
hingestatud	doc_536541856864_item	2702065	et	4	main
sam	doc_536541856864_item	2702084	et	4	main
samu	doc_536541856864_item	2702085	et	3	main
mitte	doc_536541856864_item	2702103	et	3	main
midagi	doc_536541856864_item	2702106	et	4	main
vaja	doc_536541856864_item	2702108	et	4	main
ainult	doc_536541856864_item	2702109	et	4	main
kõik	doc_536541856864_item	2702115	et	4	main
laulurahvaks	doc_536541856864_item	2702120	et	3	main
kui	doc_536541856865_item	2702124	et	3	main
laulurahva	doc_536541856865_item	2702135	et	3	main
essee	doc_536541856865_item	2702136	et	4	main
pikkus	doc_536541856865_item	2702137	et	4	main
300	doc_536541856865_item	2702138	et	2	main
350	doc_536541856865_item	2702139	et	2	main
ja	doc_536541856865_item	2702146	et	3	main
lugemistekstis	doc_536541856865_item	2702151	et	3	main
faktidele	doc_536541856865_item	2702153	et	3	main
soovitatav	doc_536541856865_item	2702156	et	4	main
näidetega	doc_536541856865_item	2702158	et	3	main
muusika	doc_536541856865_item	2702181	et	4	main
üüritusi	doc_536541856865_item	2702184	et	4	main
laulupidu	doc_536541856865_item	2702191	et	4	main
selle	doc_536541856865_item	2702200	et	4	main
seotud	doc_536541856865_item	2702205	et	4	main
heliloominguga	doc_536541856865_item	2702206	et	3	main
iga	doc_536541856865_item	2702207	et	4	main
on	doc_536541856865_item	2702218	et	4	main
muusikas	doc_536541856865_item	2702220	et	3	main
tantsimises	doc_536541856865_item	2702221	et	4	main
näha	doc_536541856865_item	2702224	et	3	main
kuidas	doc_536541856865_item	2702225	et	3	main
muusika	doc_536541856865_item	2702232	et	4	main
regivärsiline	doc_536541856865_item	2702239	et	4	main
esitasid	doc_536541856865_item	2702242	et	4	main
ilma	doc_536541856865_item	2702248	et	4	main
lauldes	doc_536541856865_item	2702250	et	3	main
võidi	doc_536541856865_item	2702251	et	4	main
rõhutada	doc_536541856865_item	2702252	et	3	main
rütmi	doc_536541856865_item	2702253	et	4	main
õõtsutamise	doc_536541856865_item	2702255	et	4	main
pillisaatega	doc_536541856865_item	2702265	et	3	main
aja	doc_536541856865_item	2702276	et	4	main
saavutus	doc_536541856865_item	2702280	et	4	main
lõbutsimine	doc_536541856865_item	2702288	et	4	main
on	doc_536541856865_item	2702289	et	4	main
laulmise	doc_536541856865_item	2702291	et	4	main
tantsimisega	doc_536541856865_item	2702293	et	4	main
rahva	doc_536541856865_item	2702302	et	3	main
perega	doc_536541856865_item	2702321	et	3	main
tihti	doc_536541856865_item	2702328	et	3	main
ja	doc_536541856865_item	2702332	et	3	main
sel	doc_536541856865_item	2702333	et	3	main
hetkel	doc_536541856865_item	2702334	et	4	main
on	doc_536541856865_item	2702340	et	4	main
aitab	doc_536541856865_item	2702347	et	3	main
1869	doc_536541856864_item	2702019	et	2	main
tartus	doc_536541856864_item	2702021	et	3	main
kujunes	doc_536541856864_item	2702023	et	3	main
liikumise	doc_536541856864_item	2702025	et	4	main
see	doc_536541856864_item	2702028	et	3	main
ühindas	doc_536541856864_item	2702029	et	4	main
rahva	doc_536541856864_item	2702030	et	3	main
näitas	doc_536541856864_item	2702031	et	3	main
et	doc_536541856864_item	2702032	et	3	main
et	doc_536541856864_item	2702037	et	3	main
tähistati	doc_536541856864_item	2702050	et	4	main
aastapäeva	doc_536541856864_item	2702052	et	4	main
siis	doc_536541856864_item	2702053	et	3	main
isamaalaul	doc_536541856864_item	2702066	et	4	main
arm	doc_536541856864_item	2702071	et	3	main
enam	doc_536541856864_item	2702074	et	4	main
eesti	doc_536541856864_item	2702076	et	4	main
rahval	doc_536541856864_item	2702077	et	3	main
olla	doc_536541856864_item	2702078	et	3	main
vait	doc_536541856864_item	2702079	et	3	main
nad	doc_536541856864_item	2702080	et	3	main
laulsid	doc_536541856864_item	2702081	et	4	main
ja	doc_536541856864_item	2702082	et	3	main
niimoodi	doc_536541856864_item	2702083	et	3	main
on	doc_536541856864_item	2702093	et	4	main
end	doc_536541856864_item	2702094	et	4	main
vaks	doc_536541856864_item	2702096	et	3	main
see	doc_536541856864_item	2702097	et	3	main
kõlab	doc_536541856864_item	2702098	et	3	main
mitte	doc_536541856864_item	2702105	et	3	main
minu	doc_536541856864_item	2702112	et	3	main
see	doc_536541856864_item	2702114	et	3	main
eestlaseid	doc_536541856864_item	2702118	et	3	main
teise	doc_536541856865_item	2702125	et	4	main
keele	doc_536541856865_item	2702126	et	4	main
kirjutamine	doc_536541856865_item	2702128	et	4	main
kirjutage	doc_536541856865_item	2702129	et	3	main
mis	doc_536541856865_item	2702132	et	4	main
teeb	doc_536541856865_item	2702133	et	3	main
essee	doc_536541856865_item	2702141	et	4	main
üldistav	doc_536541856865_item	2702147	et	4	main
esitatud	doc_536541856865_item	2702152	et	4	main
väiteid	doc_536541856865_item	2702154	et	4	main
on	doc_536541856865_item	2702189	et	4	main
palju	doc_536541856865_item	2702195	et	4	main
lauljaid	doc_536541856865_item	2702198	et	4	main
kuulajate	doc_536541856865_item	2702215	et	4	main
huvitatud	doc_536541856865_item	2702219	et	4	main
näiteks	doc_536541856865_item	2702227	et	4	main
teiseks	doc_536541856865_item	2702230	et	4	main
eesti	doc_536541856865_item	2702231	et	4	main
alguses	doc_536541856865_item	2702237	et	4	main
oli	doc_536541856865_item	2702238	et	3	main
regilaulu	doc_536541856865_item	2702241	et	4	main
on	doc_536541856865_item	2702263	et	4	main
loodi	doc_536541856865_item	2702267	et	4	main
stiile	doc_536541856865_item	2702269	et	3	main
instrumente	doc_536541856865_item	2702272	et	3	main
näiteks	doc_536541856865_item	2702273	et	4	main
bajaan	doc_536541856865_item	2702274	et	3	main
muusika	doc_536541856865_item	2702279	et	4	main
eestlased	doc_536541856865_item	2702284	et	3	main
aga	doc_536541856865_item	2702287	et	3	main
seotud	doc_536541856865_item	2702290	et	4	main
ja	doc_536541856865_item	2702292	et	3	main
oma	doc_536541856865_item	2702298	et	4	main
natukene	doc_536541856865_item	2702304	et	4	main
läänest	doc_536541856865_item	2702306	et	4	main
festivaalis	doc_536541856865_item	2702316	et	4	main
sõpru	doc_536541856865_item	2702323	et	3	main
nad	doc_536541856865_item	2702327	et	3	main
on	doc_536541856865_item	2702336	et	4	main
armastus	doc_536541856865_item	2702343	et	4	main
ja	doc_536541856865_item	2702345	et	3	main
arendada	doc_536541856865_item	2702349	et	3	main
palju	doc_536541856864_item	2702035	et	4	main
eest	doc_536541856864_item	2702041	et	4	main
seista	doc_536541856864_item	2702042	et	4	main
juubelilaulupeol	doc_536541856864_item	2702048	et	4	main
kõige	doc_536541856864_item	2702054	et	4	main
saanud	doc_536541856864_item	2702057	et	4	main
moment	doc_536541856864_item	2702058	et	3	main
kui	doc_536541856864_item	2702059	et	3	main
vallandusid	doc_536541856864_item	2702060	et	4	main
rahvuslikud	doc_536541856864_item	2702061	et	3	main
tunded	doc_536541856864_item	2702062	et	3	main
ja	doc_536541856864_item	2702063	et	3	main
mu	doc_536541856864_item	2702067	et	3	main
on	doc_536541856864_item	2702069	et	4	main
siis	doc_536541856864_item	2702072	et	3	main
nad	doc_536541856864_item	2702092	et	3	main
ühis	doc_536541856864_item	2702110	et	4	main
miks	doc_536541856864_item	2702117	et	4	main
kutsutakse	doc_536541856864_item	2702119	et	3	main
essee	doc_536541856865_item	2702121	et	4	main
test	doc_536541856865_item	2702127	et	3	main
analüüsiv	doc_536541856865_item	2702145	et	4	main
loengus	doc_536541856865_item	2702149	et	3	main
festivaale	doc_536541856865_item	2702182	et	4	main
tähtsam	doc_536541856865_item	2702186	et	4	main
peol	doc_536541856865_item	2702192	et	4	main
esinevaid	doc_536541856865_item	2702197	et	4	main
repertuaar	doc_536541856865_item	2702202	et	3	main
ka	doc_536541856865_item	2702204	et	3	main
arv	doc_536541856865_item	2702216	et	3	main
inimesed	doc_536541856865_item	2702228	et	3	main
on	doc_536541856865_item	2702234	et	4	main
väga	doc_536541856865_item	2702235	et	3	main
mitmekesine	doc_536541856865_item	2702236	et	4	main
regilaulu	doc_536541856865_item	2702246	et	4	main
neid	doc_536541856865_item	2702262	et	4	main
pärast	doc_536541856865_item	2702266	et	4	main
uusi	doc_536541856865_item	2702268	et	3	main
kasutati	doc_536541856865_item	2702270	et	4	main
uusi	doc_536541856865_item	2702271	et	3	main
kuulsam	doc_536541856865_item	2702278	et	4	main
eurovisioonil	doc_536541856865_item	2702283	et	3	main
linnas	doc_536541856865_item	2702296	et	4	main
on	doc_536541856865_item	2702297	et	4	main
laulu	doc_536541856865_item	2702300	et	4	main
riided	doc_536541856865_item	2702303	et	3	main
eestlastele	doc_536541856865_item	2702312	et	4	main
meeldib	doc_536541856865_item	2702313	et	3	main
olla	doc_536541856865_item	2702314	et	3	main
muusika	doc_536541856865_item	2702315	et	4	main
eesti	doc_536541856865_item	2702122	et	4	main
eestlastest	doc_536541856865_item	2702134	et	4	main
peab	doc_536541856865_item	2702142	et	4	main
olema	doc_536541856865_item	2702143	et	4	main
tõenäolisega	doc_536541856865_item	2702160	et	4	main
et	doc_536541856865_item	2702163	et	3	main
eestlased	doc_536541856865_item	2702164	et	3	main
on	doc_536541856865_item	2702165	et	4	main
laulurahv	doc_536541856865_item	2702166	et	4	main
aga	doc_536541856865_item	2702167	et	3	main
mis	doc_536541856865_item	2702168	et	4	main
teeb	doc_536541856865_item	2702169	et	3	main
eestlastest	doc_536541856865_item	2702170	et	4	main
laulurahva	doc_536541856865_item	2702171	et	3	main
esiteks	doc_536541856865_item	2702172	et	3	main
tahaksin	doc_536541856865_item	2702173	et	3	main
öelda	doc_536541856865_item	2702174	et	4	main
et	doc_536541856865_item	2702175	et	3	main
eestis	doc_536541856865_item	2702176	et	3	main
korraldati	doc_536541856865_item	2702177	et	3	main
ja	doc_536541856865_item	2702178	et	3	main
korraldatakse	doc_536541856865_item	2702179	et	3	main
palju	doc_536541856865_item	2702180	et	4	main
ja	doc_536541856865_item	2702183	et	3	main
üks	doc_536541856865_item	2702185	et	3	main
muidugi	doc_536541856865_item	2702190	et	4	main
koori	doc_536541856865_item	2702196	et	4	main
aasta	doc_536541856865_item	2702208	et	4	main
kasvab	doc_536541856865_item	2702209	et	3	main
nii	doc_536541856865_item	2702210	et	3	main
osavõtjate	doc_536541856865_item	2702211	et	3	main
arv	doc_536541856865_item	2702212	et	3	main
kui	doc_536541856865_item	2702213	et	3	main
me	doc_536541856865_item	2702222	et	4	main
võime	doc_536541856865_item	2702223	et	4	main
laulavad	doc_536541856865_item	2702226	et	4	main
arendamine	doc_536541856865_item	2702233	et	4	main
lauldi	doc_536541856865_item	2702247	et	3	main
instrumentina	doc_536541856865_item	2702249	et	4	main
keha	doc_536541856865_item	2702254	et	4	main
või	doc_536541856865_item	2702256	et	4	main
jalapõrutusega	doc_536541856865_item	2702257	et	3	main
pärast	doc_536541856865_item	2702258	et	4	main
oli	doc_536541856865_item	2702259	et	3	main
riimiline	doc_536541856865_item	2702260	et	4	main
rahvalaul	doc_536541856865_item	2702261	et	4	main
esitatud	doc_536541856865_item	2702264	et	4	main
kõige	doc_536541856865_item	2702277	et	4	main
võit	doc_536541856865_item	2702282	et	3	main
lõbutseda	doc_536541856865_item	2702286	et	3	main
rahvatraditsioone	doc_536541856865_item	2702299	et	3	main
kõiki	doc_536541856865_item	2702311	et	4	main
kohtuvad	doc_536541856865_item	2702322	et	4	main
koos	doc_536541856865_item	2702330	et	4	main
lauljaga	doc_536541856865_item	2702331	et	4	main
rahv	doc_536541856865_item	2702342	et	4	main
muusikale	doc_536541856865_item	2702344	et	4	main
tantsimisele	doc_536541856865_item	2702346	et	4	main
eestlasi	doc_536541856865_item	2702348	et	3	main
oma	doc_536541856865_item	2702350	et	4	main
kultuuri	doc_536541856865_item	2702351	et	4	main
ja	doc_536541856865_item	2702352	et	3	main
identiteeditunne	doc_536541856865_item	2702353	et	3	main
jalutades	doc_536541856865_item	2702229	et	3	main
rahvalaul	doc_536541856865_item	2702240	et	4	main
eeslaulja	doc_536541856865_item	2702243	et	4	main
ja	doc_536541856865_item	2702244	et	3	main
koor	doc_536541856865_item	2702245	et	4	main
meie	doc_536541856865_item	2702275	et	4	main
on	doc_536541856865_item	2702281	et	4	main
meeldivad	doc_536541856865_item	2702285	et	4	main
muidugi	doc_536541856865_item	2702294	et	4	main
igas	doc_536541856865_item	2702295	et	3	main
isegi	doc_536541856865_item	2702301	et	4	main
muutuvad	doc_536541856865_item	2702305	et	4	main
idasse	doc_536541856865_item	2702307	et	3	main
aga	doc_536541856865_item	2702308	et	3	main
minu	doc_536541856865_item	2702309	et	3	main
meelest	doc_536541856865_item	2702310	et	4	main
nad	doc_536541856865_item	2702317	et	3	main
tulevad	doc_536541856865_item	2702318	et	4	main
seal	doc_536541856865_item	2702319	et	4	main
koos	doc_536541856865_item	2702320	et	4	main
ja	doc_536541856865_item	2702325	et	3	main
neil	doc_536541856865_item	2702335	et	4	main
ühtne	doc_536541856865_item	2702341	et	3	main
sugulasi	doc_536541856865_item	2702324	et	3	main
tuttavaid	doc_536541856865_item	2702326	et	3	main
lauluvad	doc_536541856865_item	2702329	et	4	main
tunne	doc_536541856865_item	2702337	et	4	main
et	doc_536541856865_item	2702338	et	3	main
nad	doc_536541856865_item	2702339	et	3	main
essee	doc_536541856868_item	2702843	et	4	main
teise	doc_536541856868_item	2702847	et	4	main
kirjutamine	doc_536541856868_item	2702850	et	4	main
essee	doc_536541856868_item	2702852	et	4	main
essee	doc_536541856868_item	2702858	et	4	main
350	doc_536541856868_item	2702861	et	2	main
arutlev	doc_536541856868_item	2702866	et	4	main
ja	doc_536541856868_item	2702868	et	3	main
tuginema	doc_536541856868_item	2702870	et	3	main
loengus	doc_536541856868_item	2702871	et	3	main
rahvustantsud	doc_536541856868_item	2702887	et	3	main
folkloor	doc_536541856868_item	2702888	et	4	main
üks	doc_536541856868_item	2702892	et	3	main
kus	doc_536541856868_item	2702895	et	3	main
rahva	doc_536541856868_item	2702897	et	3	main
nimetada	doc_536541856868_item	2702923	et	3	main
laulurahvas	doc_536541856868_item	2702931	et	4	main
ei	doc_536541856868_item	2702935	et	4	main
veel	doc_536541856868_item	2702937	et	4	main
kirjutada	doc_536541856868_item	2702938	et	3	main
ja	doc_536541856868_item	2702939	et	3	main
isegi	doc_536541856868_item	2702955	et	4	main
rahvastel	doc_536541856868_item	2702958	et	4	main
kes	doc_536541856868_item	2702959	et	4	main
palju	doc_536541856868_item	2702977	et	4	main
pühi	doc_536541856868_item	2702979	et	4	main
ning	doc_536541856868_item	2702980	et	3	main
kommeid	doc_536541856868_item	2702981	et	4	main
esimene	doc_536541856868_item	2702987	et	3	main
meie	doc_536541856868_item	2702991	et	4	main
laulurahvaks	doc_536541856868_item	2702993	et	3	main
teiseks	doc_536541856868_item	2702995	et	4	main
kui	doc_536541856868_item	2703014	et	3	main
maailma	doc_536541856868_item	2703017	et	4	main
keele	doc_536541856868_item	2702845	et	4	main
test	doc_536541856868_item	2702849	et	3	main
mis	doc_536541856868_item	2702854	et	4	main
olema	doc_536541856868_item	2702865	et	4	main
esitatud	doc_536541856868_item	2702874	et	4	main
faktidele	doc_536541856868_item	2702875	et	3	main
oma	doc_536541856868_item	2702884	et	4	main
rahvuslaulud	doc_536541856868_item	2702885	et	3	main
ning	doc_536541856868_item	2702886	et	3	main
rahva	doc_536541856868_item	2702890	et	3	main
tähtsamatest	doc_536541856868_item	2702893	et	4	main
kajastub	doc_536541856868_item	2702896	et	3	main
keele	doc_536541856868_item	2702848	et	4	main
teeb	doc_536541856868_item	2702855	et	3	main
essee	doc_536541856868_item	2702863	et	4	main
lugemistekstis	doc_536541856868_item	2702873	et	3	main
on	doc_536541856868_item	2702877	et	4	main
soovitatav	doc_536541856868_item	2702878	et	4	main
illustreerida	doc_536541856868_item	2702879	et	3	main
näidetega	doc_536541856868_item	2702880	et	3	main
igal	doc_536541856868_item	2702881	et	3	main
rahval	doc_536541856868_item	2702882	et	3	main
on	doc_536541856868_item	2702883	et	4	main
kultuuri	doc_536541856868_item	2702891	et	4	main
nii	doc_536541856868_item	2702922	et	3	main
arvates	doc_536541856868_item	2702925	et	4	main
rahvas	doc_536541856868_item	2702927	et	4	main
on	doc_536541856868_item	2702928	et	4	main
siis	doc_536541856868_item	2702932	et	3	main
oli	doc_536541856868_item	2702941	et	3	main
eesti	doc_536541856868_item	2702844	et	4	main
kirjutage	doc_536541856868_item	2702851	et	3	main
teemal	doc_536541856868_item	2702853	et	3	main
laulurahva	doc_536541856868_item	2702857	et	3	main
pikkus	doc_536541856868_item	2702859	et	4	main
peab	doc_536541856868_item	2702864	et	4	main
üldistav	doc_536541856868_item	2702869	et	4	main
ja	doc_536541856868_item	2702872	et	3	main
väiteid	doc_536541856868_item	2702876	et	4	main
on	doc_536541856868_item	2702889	et	4	main
saab	doc_536541856868_item	2702921	et	3	main
kui	doc_536541856868_item	2702933	et	3	main
laul	doc_536541856868_item	2702942	et	4	main
parem	doc_536541856868_item	2702944	et	4	main
väljendusvahend	doc_536541856868_item	2702945	et	3	main
tänapäevadel	doc_536541856868_item	2702956	et	3	main
ookeaania	doc_536541856868_item	2702961	et	4	main
ja	doc_536541856868_item	2702967	et	3	main
saavad	doc_536541856868_item	2702969	et	4	main
kaasnesid	doc_536541856868_item	2702983	et	4	main
põhjus	doc_536541856868_item	2702988	et	4	main
meil	doc_536541856868_item	2703000	et	4	main
ajalooline	doc_536541856868_item	2703006	et	4	main
koha	doc_536541856868_item	2703010	et	4	main
siis	doc_536541856868_item	2703013	et	3	main
teine	doc_536541856868_item	2703016	et	3	main
sõda	doc_536541856868_item	2703018	et	4	main
nii	doc_536541856868_item	2703024	et	3	main
ka	doc_536541856868_item	2703026	et	3	main
ristiusuga	doc_536541856868_item	2703028	et	3	main
laulud	doc_536541856868_item	2703031	et	3	main
võimuga	doc_536541856868_item	2703033	et	3	main
teised	doc_536541856868_item	2703034	et	4	main
saksarüütlitega	doc_536541856868_item	2703035	et	3	main
kolmaks	doc_536541856868_item	2703047	et	4	main
mainida	doc_536541856868_item	2703049	et	3	main
laulutraditsioone	doc_536541856868_item	2703051	et	3	main
nende	doc_536541856868_item	2703054	et	4	main
esimest	doc_536541856868_item	2703059	et	4	main
korda	doc_536541856868_item	2703060	et	4	main
korraldati	doc_536541856868_item	2703061	et	3	main
tartus	doc_536541856868_item	2703064	et	3	main
mida	doc_536541856868_item	2703066	et	4	main
korraldatakse	doc_536541856868_item	2703067	et	3	main
tänapäevani	doc_536541856868_item	2703068	et	3	main
kui	doc_536541856868_item	2702846	et	3	main
eestlastest	doc_536541856868_item	2702856	et	4	main
300	doc_536541856868_item	2702860	et	2	main
sõna	doc_536541856868_item	2702862	et	4	main
analüüsiv	doc_536541856868_item	2702867	et	4	main
osadest	doc_536541856868_item	2702894	et	3	main
minevik	doc_536541856868_item	2702898	et	3	main
ja	doc_536541856868_item	2702899	et	3	main
iseloom	doc_536541856868_item	2702900	et	3	main
vanasti	doc_536541856868_item	2702901	et	3	main
saatis	doc_536541856868_item	2702902	et	3	main
laul	doc_536541856868_item	2702903	et	4	main
inimest	doc_536541856868_item	2702904	et	3	main
hällist	doc_536541856868_item	2702905	et	4	main
hauani	doc_536541856868_item	2702906	et	3	main
nii	doc_536541856868_item	2702907	et	3	main
oligi	doc_536541856868_item	2702908	et	3	main
ka	doc_536541856868_item	2702909	et	3	main
eestis	doc_536541856868_item	2702910	et	3	main
aga	doc_536541856868_item	2702911	et	3	main
mis	doc_536541856868_item	2702912	et	4	main
üldse	doc_536541856868_item	2702913	et	3	main
teeb	doc_536541856868_item	2702914	et	3	main
eestlastest	doc_536541856868_item	2702915	et	4	main
laulurahva	doc_536541856868_item	2702916	et	3	main
ja	doc_536541856868_item	2702917	et	3	main
kas	doc_536541856868_item	2702918	et	3	main
eestlaseid	doc_536541856868_item	2702919	et	3	main
üldse	doc_536541856868_item	2702920	et	3	main
minu	doc_536541856868_item	2702924	et	3	main
mõttes	doc_536541856868_item	2702930	et	3	main
talumehed	doc_536541856868_item	2702934	et	3	main
osanud	doc_536541856868_item	2702936	et	4	main
lugeda	doc_536541856868_item	2702940	et	3	main
või	doc_536541856868_item	2702963	et	4	main
kesk-ameerika	doc_536541856868_item	2702964	et	3	main
vihmametsades	doc_536541856868_item	2702965	et	3	main
tants	doc_536541856868_item	2702968	et	3	main
erinevaid	doc_536541856868_item	2702978	et	4	main
pidada	doc_536541856868_item	2702994	et	4	main
põhjuseks	doc_536541856868_item	2702996	et	3	main
on	doc_536541856868_item	2702997	et	4	main
see	doc_536541856868_item	2702998	et	3	main
et	doc_536541856868_item	2702999	et	3	main
iga	doc_536541856868_item	2703005	et	4	main
oma	doc_536541856868_item	2703009	et	4	main
kohe	doc_536541856868_item	2703019	et	4	main
sõjalaule	doc_536541856868_item	2703023	et	4	main
eestis	doc_536541856868_item	2703027	et	3	main
kõiki	doc_536541856868_item	2703039	et	4	main
ja	doc_536541856868_item	2703042	et	3	main
tahaks	doc_536541856868_item	2703048	et	3	main
meie	doc_536541856868_item	2703050	et	4	main
iga	doc_536541856868_item	2702926	et	4	main
minges	doc_536541856868_item	2702929	et	3	main
nagu	doc_536541856868_item	2702948	et	3	main
maagiline	doc_536541856868_item	2702949	et	4	main
rituaal	doc_536541856868_item	2702950	et	3	main
ja	doc_536541856868_item	2702951	et	3	main
nii	doc_536541856868_item	2702952	et	3	main
see	doc_536541856868_item	2702953	et	3	main
jääb	doc_536541856868_item	2702954	et	3	main
kõige	doc_536541856868_item	2702943	et	4	main
laulmine	doc_536541856868_item	2702946	et	4	main
oli	doc_536541856868_item	2702947	et	3	main
elavad	doc_536541856868_item	2702960	et	4	main
talismaaniks	doc_536541856868_item	2702970	et	4	main
kurjade	doc_536541856868_item	2702971	et	4	main
vaimude	doc_536541856868_item	2702972	et	4	main
vastu	doc_536541856868_item	2702973	et	3	main
oli	doc_536541856868_item	2702975	et	3	main
mida	doc_536541856868_item	2702982	et	4	main
selleks	doc_536541856868_item	2702989	et	4	main
rahva	doc_536541856868_item	2702992	et	3	main
on	doc_536541856868_item	2703001	et	4	main
väga	doc_536541856868_item	2703002	et	3	main
rikas	doc_536541856868_item	2703003	et	4	main
ajalugu	doc_536541856868_item	2703004	et	4	main
leiab	doc_536541856868_item	2703008	et	3	main
laulus	doc_536541856868_item	2703011	et	3	main
tekkis	doc_536541856868_item	2703015	et	3	main
neid	doc_536541856868_item	2703038	et	4	main
üks	doc_536541856868_item	2703041	et	3	main
tähtsam	doc_536541856868_item	2703053	et	4	main
on	doc_536541856868_item	2703056	et	4	main
1869	doc_536541856868_item	2703062	et	2	main
aastal	doc_536541856868_item	2703063	et	3	main
ja	doc_536541856868_item	2703065	et	3	main
lapsed	doc_536541856868_item	2703069	et	3	main
ja	doc_536541856868_item	2703070	et	3	main
noorukid	doc_536541856868_item	2703071	et	3	main
vaatamata	doc_536541856868_item	2703084	et	4	main
nõukogude	doc_536541856868_item	2703086	et	3	main
rahvustantsu	doc_536541856868_item	2703096	et	4	main
ansambleid	doc_536541856868_item	2703097	et	3	main
eesti	doc_536541856868_item	2703101	et	4	main
rahvast	doc_536541856868_item	2703126	et	4	main
võib	doc_536541856868_item	2703127	et	3	main
muidugi	doc_536541856868_item	2703135	et	4	main
rikas	doc_536541856868_item	2703136	et	4	main
üldlaulupidude	doc_536541856868_item	2703143	et	4	main
traditsioon	doc_536541856868_item	2703144	et	3	main
pole	doc_536541856868_item	2703145	et	3	main
ainukesed	doc_536541856868_item	2703146	et	4	main
põhjused	doc_536541856868_item	2703147	et	3	main
ja	doc_536541856868_item	2703148	et	3	main
mitte	doc_536541856868_item	2703153	et	3	main
nõutuda	doc_536541856868_item	2703154	et	4	main
jääme	doc_536541856868_item	2703168	et	4	main
mäletame	doc_536541856868_item	2703173	et	3	main
ajalood	doc_536541856868_item	2703175	et	4	main
ja	doc_536541856868_item	2703176	et	3	main
oma	doc_536541856868_item	2703177	et	4	main
muinasaegseid	doc_536541856868_item	2703178	et	3	main
essee	doc_536541856869_item	2703180	et	4	main
väiteid	doc_536541856869_item	2703213	et	4	main
on	doc_536541856869_item	2703214	et	4	main
öelda	doc_536541856869_item	2703220	et	4	main
tavalise	doc_536541856869_item	2703228	et	4	main
seostub	doc_536541856869_item	2703231	et	3	main
et	doc_536541856869_item	2703249	et	3	main
vaja	doc_536541856869_item	2703254	et	4	main
tutvuda	doc_536541856869_item	2703255	et	3	main
ajalooga	doc_536541856869_item	2703256	et	4	main
kõige	doc_536541856869_item	2703257	et	4	main
regilaul	doc_536541856869_item	2703260	et	4	main
sai	doc_536541856869_item	2703261	et	4	main
alguse	doc_536541856869_item	2703262	et	3	main
18	doc_536541856869_item	2703264	et	2	main
riimilised	doc_536541856869_item	2703274	et	4	main
rahvalaulud	doc_536541856869_item	2703275	et	3	main
võib	doc_536541856869_item	2703276	et	3	main
naiste-	doc_536541856869_item	2703296	et	3	main
tõesti	doc_536541856869_item	2703300	et	3	main
sul	doc_536541856869_item	2703305	et	3	main
on	doc_536541856869_item	2703306	et	4	main
kui	doc_536541856869_item	2703308	et	3	main
sul	doc_536541856869_item	2703309	et	3	main
liiga	doc_536541856869_item	2703311	et	4	main
palju	doc_536541856869_item	2703312	et	4	main
tuju	doc_536541856869_item	2703317	et	4	main
kui	doc_536541856869_item	2703318	et	3	main
mõnedel	doc_536541856868_item	2702957	et	3	main
saartel	doc_536541856868_item	2702962	et	3	main
laul	doc_536541856868_item	2702966	et	4	main
eestlastel	doc_536541856868_item	2702974	et	4	main
väga	doc_536541856868_item	2702976	et	3	main
laulud	doc_536541856868_item	2702984	et	3	main
see	doc_536541856868_item	2702985	et	3	main
on	doc_536541856868_item	2702986	et	4	main
et	doc_536541856868_item	2702990	et	3	main
sündmus	doc_536541856868_item	2703007	et	3	main
näiteks	doc_536541856868_item	2703012	et	4	main
ilmus	doc_536541856868_item	2703020	et	4	main
suur	doc_536541856868_item	2703021	et	3	main
oligi	doc_536541856868_item	2703025	et	3	main
tulid	doc_536541856868_item	2703029	et	4	main
sama	doc_536541856868_item	2703043	et	4	main
eesti	doc_536541856868_item	2703045	et	4	main
kõige	doc_536541856868_item	2703052	et	4	main
laulavad	doc_536541856868_item	2703072	et	4	main
tänapäevased	doc_536541856868_item	2703088	et	4	main
toimuvad	doc_536541856868_item	2703098	et	4	main
huvi	doc_536541856868_item	2703104	et	4	main
hulk	doc_536541856868_item	2703022	et	3	main
ühed	doc_536541856868_item	2703030	et	3	main
rootsi	doc_536541856868_item	2703032	et	4	main
kolmased	doc_536541856868_item	2703036	et	4	main
aga	doc_536541856868_item	2703037	et	3	main
laulis	doc_536541856868_item	2703040	et	4	main
rahvas	doc_536541856868_item	2703044	et	4	main
rahvas	doc_536541856868_item	2703046	et	4	main
mida	doc_536541856868_item	2703058	et	4	main
mis	doc_536541856868_item	2703074	et	4	main
läbi	doc_536541856868_item	2703076	et	4	main
aegade	doc_536541856868_item	2703077	et	3	main
kujunenud	doc_536541856868_item	2703078	et	4	main
rahvuslikeks	doc_536541856868_item	2703079	et	3	main
sümboliteks	doc_536541856868_item	2703080	et	3	main
režiimile	doc_536541856868_item	2703087	et	2	main
oma	doc_536541856868_item	2703091	et	4	main
rahvamuusika	doc_536541856868_item	2703099	et	4	main
üritused	doc_536541856868_item	2703100	et	4	main
tunneb	doc_536541856868_item	2703103	et	3	main
oma	doc_536541856868_item	2703105	et	4	main
mineviku	doc_536541856868_item	2703106	et	3	main
vastu	doc_536541856868_item	2703107	et	3	main
ja	doc_536541856868_item	2703108	et	3	main
laulab	doc_536541856868_item	2703109	et	3	main
samaid	doc_536541856868_item	2703110	et	4	main
regivärsiliseid	doc_536541856868_item	2703111	et	4	main
laule	doc_536541856868_item	2703112	et	4	main
mida	doc_536541856868_item	2703113	et	4	main
laulasid	doc_536541856868_item	2703114	et	4	main
naised	doc_536541856868_item	2703115	et	3	main
muinasaegsel	doc_536541856868_item	2703116	et	3	main
kihnu	doc_536541856868_item	2703117	et	4	main
saarel	doc_536541856868_item	2703118	et	3	main
kuna	doc_536541856868_item	2703119	et	3	main
nende	doc_536541856868_item	2703120	et	4	main
öelda	doc_536541856868_item	2703133	et	4	main
et	doc_536541856868_item	2703134	et	3	main
ning	doc_536541856868_item	2703142	et	3	main
minuga	doc_536541856868_item	2703152	et	3	main
mina	doc_536541856868_item	2703156	et	4	main
arvan	doc_536541856868_item	2703157	et	3	main
et	doc_536541856868_item	2703158	et	3	main
just	doc_536541856868_item	2703159	et	3	main
asju	doc_536541856868_item	2703162	et	3	main
laulurahvaks	doc_536541856868_item	2703169	et	3	main
soovitatav	doc_536541856869_item	2703215	et	4	main
illustreerida	doc_536541856869_item	2703216	et	3	main
näidetega	doc_536541856869_item	2703217	et	3	main
seas	doc_536541856868_item	2703055	et	4	main
üldlaulupidu	doc_536541856868_item	2703057	et	4	main
laule	doc_536541856868_item	2703073	et	4	main
on	doc_536541856868_item	2703075	et	4	main
sõjadele	doc_536541856868_item	2703085	et	4	main
rahvas	doc_536541856868_item	2703102	et	4	main
lõpuks	doc_536541856868_item	2703131	et	4	main
tahaks	doc_536541856868_item	2703132	et	3	main
kombeid	doc_536541856868_item	2703141	et	4	main
muidugi	doc_536541856868_item	2703151	et	4	main
aga	doc_536541856868_item	2703155	et	3	main
kolm	doc_536541856868_item	2703161	et	3	main
teevad	doc_536541856868_item	2703163	et	3	main
kaua	doc_536541856868_item	2703171	et	3	main
oma	doc_536541856868_item	2703174	et	4	main
esitatud	doc_536541856869_item	2703211	et	4	main
võib	doc_536541856869_item	2703219	et	3	main
eestlased	doc_536541856869_item	2703222	et	3	main
eestlase	doc_536541856869_item	2703229	et	3	main
laulupidu	doc_536541856869_item	2703235	et	4	main
sai	doc_536541856869_item	2703238	et	4	main
väga	doc_536541856869_item	2703240	et	3	main
arvates	doc_536541856869_item	2703248	et	4	main
laul	doc_536541856869_item	2703259	et	4	main
see	doc_536541856869_item	2703266	et	3	main
natuke	doc_536541856869_item	2703269	et	4	main
hiljem	doc_536541856869_item	2703270	et	3	main
19	doc_536541856869_item	2703271	et	2	main
sajandil	doc_536541856869_item	2703272	et	3	main
saa	doc_536541856869_item	2703281	et	4	main
üldse	doc_536541856869_item	2703282	et	3	main
tekkisid	doc_536541856869_item	2703293	et	4	main
igasugused	doc_536541856869_item	2703294	et	3	main
tööd	doc_536541856869_item	2703313	et	4	main
või	doc_536541856869_item	2703314	et	4	main
laulda	doc_536541856869_item	2703322	et	4	main
oma	doc_536541856869_item	2703332	et	4	main
kultuuriga	doc_536541856869_item	2703333	et	4	main
teeb	doc_536541856869_item	2703334	et	3	main
rahvast	doc_536541856869_item	2703339	et	4	main
mitu	doc_536541856869_item	2703346	et	4	main
tähtsat	doc_536541856869_item	2703347	et	3	main
eesti	doc_536541856869_item	2703348	et	4	main
sündmust	doc_536541856869_item	2703349	et	3	main
1980	doc_536541856869_item	2703362	et	2	main
pärit	doc_536541856869_item	2703368	et	3	main
laulupidu	doc_536541856869_item	2703376	et	4	main
ja	doc_536541856869_item	2703380	et	3	main
kultuur	doc_536541856869_item	2703392	et	3	main
toimub	doc_536541856869_item	2703399	et	3	main
lõpuks	doc_536541856869_item	2703422	et	4	main
teistele	doc_536541856869_item	2703431	et	4	main
kõik	doc_536541856869_item	2703435	et	4	main
test	doc_536541856870_item	2703445	et	3	main
kirjutamine	doc_536541856870_item	2703446	et	4	main
kirjutage	doc_536541856870_item	2703447	et	3	main
eestlastest	doc_536541856870_item	2703452	et	4	main
pikkus	doc_536541856870_item	2703455	et	4	main
350	doc_536541856870_item	2703457	et	2	main
analüüsiv	doc_536541856870_item	2703463	et	4	main
ja	doc_536541856870_item	2703464	et	3	main
koolis	doc_536541856870_item	2703488	et	4	main
tõstab	doc_536541856870_item	2703494	et	3	main
et	doc_536541856870_item	2703504	et	3	main
oma	doc_536541856870_item	2703512	et	4	main
käivad	doc_536541856870_item	2703521	et	4	main
kes	doc_536541856870_item	2703523	et	4	main
tahavad	doc_536541856870_item	2703524	et	3	main
mängida	doc_536541856870_item	2703525	et	3	main
ja	doc_536541856870_item	2703526	et	3	main
ja	doc_536541856870_item	2703528	et	3	main
muidugi	doc_536541856870_item	2703529	et	4	main
need	doc_536541856870_item	2703530	et	3	main
see	doc_536541856870_item	2703545	et	3	main
pani	doc_536541856870_item	2703549	et	4	main
lauljat	doc_536541856870_item	2703569	et	4	main
populaarsemaks	doc_536541856870_item	2703572	et	4	main
üle-eestiline	doc_536541856870_item	2703573	et	3	main
laulupidu	doc_536541856870_item	2703574	et	4	main
ka	doc_536541856870_item	2703582	et	3	main
rahvapidu	doc_536541856870_item	2703586	et	4	main
kuhu	doc_536541856870_item	2703587	et	3	main
laulupidude	doc_536541856868_item	2703081	et	4	main
traditsioon	doc_536541856868_item	2703082	et	3	main
elab	doc_536541856868_item	2703083	et	3	main
heliloojad	doc_536541856868_item	2703089	et	3	main
kasutavad	doc_536541856868_item	2703090	et	4	main
loomingus	doc_536541856868_item	2703092	et	3	main
rahvalaule	doc_536541856868_item	2703093	et	4	main
luuakse	doc_536541856868_item	2703094	et	3	main
uusi	doc_536541856868_item	2703095	et	3	main
mehed	doc_536541856868_item	2703121	et	3	main
käisid	doc_536541856868_item	2703123	et	4	main
eesti	doc_536541856868_item	2703125	et	4	main
julgelt	doc_536541856868_item	2703128	et	4	main
laulurahvaks	doc_536541856868_item	2703129	et	3	main
nimetada	doc_536541856868_item	2703130	et	3	main
ajalugu	doc_536541856868_item	2703137	et	4	main
suur	doc_536541856868_item	2703138	et	3	main
hulk	doc_536541856868_item	2703139	et	3	main
keegi	doc_536541856868_item	2703149	et	4	main
võib	doc_536541856868_item	2703150	et	3	main
muidugi	doc_536541856869_item	2703218	et	4	main
et	doc_536541856869_item	2703221	et	3	main
laulurahvas	doc_536541856869_item	2703224	et	4	main
laulupidude	doc_536541856869_item	2703236	et	4	main
laulurahva	doc_536541856869_item	2703246	et	3	main
minu	doc_536541856869_item	2703247	et	3	main
vastata	doc_536541856869_item	2703250	et	4	main
sellele	doc_536541856869_item	2703251	et	4	main
sajandil	doc_536541856869_item	2703265	et	3	main
levis	doc_536541856869_item	2703267	et	4	main
suuliselt	doc_536541856869_item	2703268	et	4	main
öelda	doc_536541856869_item	2703277	et	4	main
et	doc_536541856869_item	2703278	et	3	main
eestlased	doc_536541856869_item	2703279	et	3	main
ei	doc_536541856869_item	2703280	et	4	main
ükskõik	doc_536541856869_item	2703289	et	3	main
mida	doc_536541856869_item	2703290	et	4	main
tehas	doc_536541856869_item	2703291	et	3	main
niimodi	doc_536541856869_item	2703292	et	4	main
meeste-	doc_536541856869_item	2703297	et	4	main
kui	doc_536541856869_item	2703304	et	3	main
teised	doc_536541856869_item	2703324	et	4	main
tahtmine	doc_536541856869_item	2703328	et	4	main
olla	doc_536541856869_item	2703329	et	3	main
laulupidu	doc_536541856869_item	2703337	et	4	main
seotud	doc_536541856869_item	2703345	et	4	main
gustavi	doc_536541856869_item	2703353	et	4	main
on	doc_536541856869_item	2703359	et	4	main
minu	doc_536541856869_item	2703360	et	3	main
hakkasid	doc_536541856869_item	2703364	et	4	main
eelmisest	doc_536541856869_item	2703366	et	3	main
isamaalisi	doc_536541856869_item	2703369	et	4	main
ja	doc_536541856869_item	2703371	et	3	main
isegi	doc_536541856869_item	2703372	et	4	main
tsaari-venemaa	doc_536541856869_item	2703373	et	4	main
eestlased	doc_536541856869_item	2703377	et	3	main
laulda	doc_536541856869_item	2703379	et	4	main
seda	doc_536541856869_item	2703383	et	3	main
üldse	doc_536541856869_item	2703385	et	3	main
ilma	doc_536541856869_item	2703393	et	4	main
lauluta	doc_536541856869_item	2703394	et	3	main
keele	doc_536541856870_item	2703441	et	4	main
kui	doc_536541856870_item	2703442	et	3	main
mis	doc_536541856870_item	2703450	et	4	main
essee	doc_536541856870_item	2703454	et	4	main
300	doc_536541856870_item	2703456	et	2	main
arutlev	doc_536541856870_item	2703462	et	4	main
laulmine	doc_536541856870_item	2703490	et	4	main
ta	doc_536541856870_item	2703493	et	4	main
ja	doc_536541856870_item	2703496	et	3	main
laengut	doc_536541856870_item	2703498	et	3	main
võime	doc_536541856870_item	2703506	et	4	main
nimetada	doc_536541856870_item	2703508	et	3	main
austavad	doc_536541856870_item	2703511	et	4	main
ja	doc_536541856870_item	2703514	et	3	main
kombeid	doc_536541856870_item	2703515	et	4	main
toimuvad	doc_536541856870_item	2703518	et	4	main
mis	doc_536541856870_item	2703548	et	4	main
esimesel	doc_536541856870_item	2703554	et	3	main
võtab	doc_536541856870_item	2703563	et	3	main
000	doc_536541856870_item	2703568	et	2	main
meres	doc_536541856868_item	2703122	et	3	main
seepärast	doc_536541856868_item	2703124	et	3	main
erinevaid	doc_536541856868_item	2703140	et	4	main
need	doc_536541856868_item	2703160	et	3	main
eestlastest	doc_536541856868_item	2703164	et	4	main
laulurahva	doc_536541856868_item	2703165	et	3	main
ja	doc_536541856868_item	2703166	et	3	main
me	doc_536541856868_item	2703167	et	4	main
nii	doc_536541856868_item	2703170	et	3	main
kui	doc_536541856868_item	2703172	et	3	main
laule	doc_536541856868_item	2703179	et	4	main
eesti	doc_536541856869_item	2703181	et	4	main
keele	doc_536541856869_item	2703182	et	4	main
kui	doc_536541856869_item	2703183	et	3	main
teise	doc_536541856869_item	2703184	et	4	main
keele	doc_536541856869_item	2703185	et	4	main
test	doc_536541856869_item	2703186	et	3	main
kirjutamine	doc_536541856869_item	2703187	et	4	main
kirjutage	doc_536541856869_item	2703188	et	3	main
essee	doc_536541856869_item	2703189	et	4	main
teemal	doc_536541856869_item	2703190	et	3	main
mis	doc_536541856869_item	2703191	et	4	main
teeb	doc_536541856869_item	2703192	et	3	main
eestlastest	doc_536541856869_item	2703193	et	4	main
laulurahva	doc_536541856869_item	2703194	et	3	main
essee	doc_536541856869_item	2703195	et	4	main
pikkus	doc_536541856869_item	2703196	et	4	main
300	doc_536541856869_item	2703197	et	2	main
350	doc_536541856869_item	2703198	et	2	main
sõna	doc_536541856869_item	2703199	et	4	main
essee	doc_536541856869_item	2703200	et	4	main
peab	doc_536541856869_item	2703201	et	4	main
olema	doc_536541856869_item	2703202	et	4	main
arutlev	doc_536541856869_item	2703203	et	4	main
analüüsiv	doc_536541856869_item	2703204	et	4	main
ja	doc_536541856869_item	2703205	et	3	main
üldistav	doc_536541856869_item	2703206	et	4	main
tuginema	doc_536541856869_item	2703207	et	3	main
loengus	doc_536541856869_item	2703208	et	3	main
ja	doc_536541856869_item	2703209	et	3	main
lugemistekstis	doc_536541856869_item	2703210	et	3	main
faktidele	doc_536541856869_item	2703212	et	3	main
on	doc_536541856869_item	2703223	et	4	main
kõik	doc_536541856869_item	2703225	et	4	main
teavad	doc_536541856869_item	2703226	et	3	main
traditsioon	doc_536541856869_item	2703237	et	3	main
aluse	doc_536541856869_item	2703239	et	4	main
ammu	doc_536541856869_item	2703241	et	4	main
mis	doc_536541856869_item	2703242	et	4	main
siis	doc_536541856869_item	2703243	et	3	main
teeb	doc_536541856869_item	2703244	et	3	main
küsimustele	doc_536541856869_item	2703252	et	4	main
vanem	doc_536541856869_item	2703258	et	4	main
tekkisid	doc_536541856869_item	2703273	et	4	main
ilma	doc_536541856869_item	2703283	et	4	main
lauluta	doc_536541856869_item	2703284	et	3	main
nemad	doc_536541856869_item	2703285	et	3	main
koorid	doc_536541856869_item	2703295	et	4	main
lapse-	doc_536541856869_item	2703298	et	4	main
igav	doc_536541856869_item	2703307	et	3	main
on	doc_536541856869_item	2703310	et	4	main
hea	doc_536541856869_item	2703316	et	4	main
mõte	doc_536541856869_item	2703321	et	3	main
ühineb	doc_536541856869_item	2703338	et	3	main
rahvast	doc_536541856869_item	2703341	et	4	main
laulupeoga	doc_536541856869_item	2703343	et	4	main
on	doc_536541856869_item	2703344	et	4	main
kõlas	doc_536541856869_item	2703352	et	4	main
ernesaksa	doc_536541856869_item	2703354	et	4	main
hingestatud	doc_536541856869_item	2703355	et	4	main
isamaalaul	doc_536541856869_item	2703356	et	4	main
mu	doc_536541856869_item	2703357	et	3	main
korraldati	doc_536541856869_item	2703375	et	3	main
tahtsid	doc_536541856869_item	2703378	et	4	main
tegid	doc_536541856869_item	2703382	et	4	main
mina	doc_536541856869_item	2703384	et	4	main
ei	doc_536541856869_item	2703386	et	4	main
kujuta	doc_536541856869_item	2703387	et	4	main
siiamani	doc_536541856869_item	2703395	et	4	main
inimesed	doc_536541856869_item	2703396	et	3	main
koguvad	doc_536541856869_item	2703397	et	4	main
populaarne	doc_536541856869_item	2703401	et	3	main
veel	doc_536541856869_item	2703403	et	4	main
lõppude	doc_536541856869_item	2703421	et	4	main
see	doc_536541856869_item	2703434	et	3	main
eestlastest	doc_536541856869_item	2703437	et	4	main
laulurahva	doc_536541856869_item	2703438	et	3	main
essee	doc_536541856870_item	2703439	et	4	main
teise	doc_536541856870_item	2703443	et	4	main
keele	doc_536541856870_item	2703444	et	4	main
peab	doc_536541856870_item	2703460	et	4	main
päevaks	doc_536541856870_item	2703500	et	3	main
imestada	doc_536541856870_item	2703503	et	3	main
kultuuri	doc_536541856870_item	2703513	et	4	main
iga	doc_536541856870_item	2703516	et	4	main
aasta	doc_536541856870_item	2703517	et	4	main
kes	doc_536541856870_item	2703531	et	4	main
tahavad	doc_536541856870_item	2703532	et	3	main
kuulata	doc_536541856870_item	2703533	et	4	main
laulupeosid	doc_536541856870_item	2703534	et	3	main
korraldatakse	doc_536541856870_item	2703535	et	3	main
juba	doc_536541856870_item	2703536	et	3	main
toimus	doc_536541856870_item	2703541	et	3	main
aastal	doc_536541856870_item	2703543	et	3	main
oli	doc_536541856870_item	2703546	et	3	main
ülslaulupidude	doc_536541856870_item	2703552	et	4	main
peolt	doc_536541856870_item	2703564	et	4	main
30	doc_536541856870_item	2703567	et	2	main
saab	doc_536541856870_item	2703571	et	3	main
ajal	doc_536541856870_item	2703578	et	4	main
tähelepanuväärsem	doc_536541856870_item	2703579	et	4	main
eestlasi	doc_536541856870_item	2703597	et	3	main
mitte	doc_536541856870_item	2703598	et	3	main
unustada	doc_536541856870_item	2703599	et	3	main
oma	doc_536541856870_item	2703600	et	4	main
see	doc_536541856870_item	2703604	et	3	main
on	doc_536541856870_item	2703605	et	4	main
laulmine	doc_536541856870_item	2703615	et	4	main
eksisteerib	doc_536541856870_item	2703616	et	3	main
on	doc_536541856870_item	2703642	et	4	main
eestlaste	doc_536541856870_item	2703646	et	4	main
et	doc_536541856869_item	2703227	et	3	main
jaoks	doc_536541856869_item	2703230	et	4	main
sõnadega	doc_536541856869_item	2703232	et	3	main
rahvas	doc_536541856869_item	2703233	et	4	main
laul	doc_536541856869_item	2703234	et	4	main
eestlastest	doc_536541856869_item	2703245	et	4	main
on	doc_536541856869_item	2703253	et	4	main
juba	doc_536541856869_item	2703263	et	3	main
laulavad	doc_536541856869_item	2703286	et	4	main
ükskõik	doc_536541856869_item	2703287	et	3	main
kus	doc_536541856869_item	2703288	et	3	main
aga	doc_536541856869_item	2703299	et	3	main
miks	doc_536541856869_item	2703301	et	4	main
mitte	doc_536541856869_item	2703302	et	3	main
laulda	doc_536541856869_item	2703303	et	4	main
lihtsalt	doc_536541856869_item	2703315	et	4	main
keegil	doc_536541856869_item	2703319	et	4	main
tuli	doc_536541856869_item	2703320	et	4	main
siis	doc_536541856869_item	2703323	et	3	main
ühinesid	doc_536541856869_item	2703325	et	4	main
arvan	doc_536541856869_item	2703326	et	3	main
et	doc_536541856869_item	2703327	et	3	main
eestlastest	doc_536541856869_item	2703335	et	4	main
laulurahva	doc_536541856869_item	2703336	et	3	main
1969	doc_536541856869_item	2703350	et	2	main
aastal	doc_536541856869_item	2703351	et	3	main
arm	doc_536541856869_item	2703361	et	3	main
aastal	doc_536541856869_item	2703363	et	3	main
esindama	doc_536541856869_item	2703365	et	3	main
laule	doc_536541856869_item	2703370	et	4	main
ette	doc_536541856869_item	2703388	et	4	main
kuidas	doc_536541856869_item	2703389	et	3	main
arendaks	doc_536541856869_item	2703390	et	3	main
koos	doc_536541856869_item	2703330	et	4	main
iseseisev	doc_536541856869_item	2703331	et	3	main
eesti	doc_536541856869_item	2703340	et	4	main
näiteks	doc_536541856869_item	2703342	et	4	main
isamaa	doc_536541856869_item	2703358	et	4	main
sajandist	doc_536541856869_item	2703367	et	3	main
ajal	doc_536541856869_item	2703374	et	4	main
nemad	doc_536541856869_item	2703381	et	3	main
eesti	doc_536541856869_item	2703391	et	4	main
laulaväljakul	doc_536541856869_item	2703398	et	4	main
väga	doc_536541856869_item	2703400	et	3	main
laulupidu	doc_536541856869_item	2703402	et	4	main
eestlased	doc_536541856869_item	2703404	et	3	main
esinevad	doc_536541856869_item	2703405	et	4	main
kontsertidel	doc_536541856869_item	2703406	et	3	main
korraldavad	doc_536541856869_item	2703407	et	4	main
oma	doc_536541856869_item	2703408	et	4	main
üritusi	doc_536541856869_item	2703409	et	4	main
folkloorefestivali	doc_536541856869_item	2703410	et	4	main
ja	doc_536541856869_item	2703411	et	3	main
muidugi	doc_536541856869_item	2703412	et	4	main
kõik	doc_536541856869_item	2703413	et	4	main
tantsivad	doc_536541856869_item	2703415	et	4	main
laulavad	doc_536541856869_item	2703414	et	4	main
kõikidel	doc_536541856869_item	2703416	et	4	main
on	doc_536541856869_item	2703417	et	4	main
ainult	doc_536541856869_item	2703418	et	4	main
hea	doc_536541856869_item	2703419	et	4	main
tuju	doc_536541856869_item	2703420	et	4	main
koos	doc_536541856869_item	2703428	et	4	main
ja	doc_536541856869_item	2703429	et	3	main
näidata	doc_536541856869_item	2703430	et	4	main
kultuuri	doc_536541856869_item	2703433	et	4	main
teeb	doc_536541856870_item	2703451	et	3	main
sõna	doc_536541856870_item	2703458	et	4	main
essee	doc_536541856870_item	2703459	et	4	main
üldistav	doc_536541856870_item	2703465	et	4	main
tuginema	doc_536541856870_item	2703466	et	3	main
loengus	doc_536541856870_item	2703467	et	3	main
kõikidel	doc_536541856870_item	2703484	et	4	main
kohtadel	doc_536541856870_item	2703485	et	3	main
kodus	doc_536541856870_item	2703486	et	4	main
tööl	doc_536541856870_item	2703487	et	3	main
on	doc_536541856870_item	2703491	et	4	main
seejärel	doc_536541856870_item	2703501	et	3	main
laularahvaks	doc_536541856870_item	2703509	et	4	main
eestlased	doc_536541856870_item	2703510	et	3	main
laulupeod	doc_536541856870_item	2703519	et	4	main
võin	doc_536541856869_item	2703423	et	3	main
öelda	doc_536541856869_item	2703424	et	4	main
et	doc_536541856869_item	2703425	et	3	main
tahtmine	doc_536541856869_item	2703426	et	4	main
olla	doc_536541856869_item	2703427	et	3	main
oma	doc_536541856869_item	2703432	et	4	main
teeb	doc_536541856869_item	2703436	et	3	main
eesti	doc_536541856870_item	2703440	et	4	main
essee	doc_536541856870_item	2703448	et	4	main
teemal	doc_536541856870_item	2703449	et	3	main
laulurahva	doc_536541856870_item	2703453	et	3	main
olema	doc_536541856870_item	2703461	et	4	main
ja	doc_536541856870_item	2703468	et	3	main
lugemistekstis	doc_536541856870_item	2703469	et	3	main
esitatud	doc_536541856870_item	2703470	et	4	main
faktidele	doc_536541856870_item	2703471	et	3	main
väiteid	doc_536541856870_item	2703472	et	4	main
soovitatav	doc_536541856870_item	2703474	et	4	main
illustreerida	doc_536541856870_item	2703475	et	3	main
näidetega	doc_536541856870_item	2703476	et	3	main
on	doc_536541856870_item	2703473	et	4	main
juba	doc_536541856870_item	2703477	et	3	main
vanal	doc_536541856870_item	2703478	et	3	main
ajal	doc_536541856870_item	2703479	et	4	main
inimesed	doc_536541856870_item	2703480	et	3	main
armastasid	doc_536541856870_item	2703481	et	4	main
laulda	doc_536541856870_item	2703482	et	4	main
lauldi	doc_536541856870_item	2703483	et	3	main
õues	doc_536541856870_item	2703489	et	4	main
väljendusvahe	doc_536541856870_item	2703492	et	4	main
tuju	doc_536541856870_item	2703495	et	4	main
annab	doc_536541856870_item	2703497	et	3	main
kogu	doc_536541856870_item	2703499	et	4	main
pole	doc_536541856870_item	2703502	et	3	main
me	doc_536541856870_item	2703505	et	4	main
eestlasi	doc_536541856870_item	2703507	et	3	main
kus	doc_536541856870_item	2703520	et	3	main
laulda	doc_536541856870_item	2703527	et	4	main
tartus	doc_536541856870_item	2703544	et	3	main
järgnevate	doc_536541856870_item	2703551	et	4	main
peol	doc_536541856870_item	2703555	et	4	main
osales	doc_536541856870_item	2703556	et	3	main
1000	doc_536541856870_item	2703558	et	2	main
lauljat	doc_536541856870_item	2703559	et	4	main
praegu	doc_536541856870_item	2703560	et	3	main
21	doc_536541856870_item	2703561	et	2	main
sajandil	doc_536541856870_item	2703562	et	3	main
umbes	doc_536541856870_item	2703566	et	4	main
perega	doc_536541856870_item	2703589	et	3	main
üksinda	doc_536541856870_item	2703592	et	4	main
nautida	doc_536541856870_item	2703593	et	3	main
muusikat	doc_536541856870_item	2703594	et	3	main
aitab	doc_536541856870_item	2703596	et	3	main
ajalugu	doc_536541856870_item	2703603	et	4	main
kombe	doc_536541856870_item	2703606	et	4	main
mis	doc_536541856870_item	2703607	et	4	main
mitte	doc_536541856870_item	2703617	et	3	main
kuuluvad	doc_536541856870_item	2703630	et	4	main
ühesse	doc_536541856870_item	2703631	et	3	main
ajalugu	doc_536541856870_item	2703639	et	4	main
need	doc_536541856870_item	2703640	et	3	main
laulud	doc_536541856870_item	2703641	et	3	main
rahvuslikud	doc_536541856870_item	2703643	et	3	main
150	doc_536541856870_item	2703538	et	2	main
need	doc_536541856870_item	2703522	et	3	main
peaaegu	doc_536541856870_item	2703537	et	3	main
aastat	doc_536541856870_item	2703539	et	3	main
esimene	doc_536541856870_item	2703540	et	3	main
1869	doc_536541856870_item	2703542	et	2	main
sündmus	doc_536541856870_item	2703547	et	3	main
aluse	doc_536541856870_item	2703550	et	4	main
korraldamisele	doc_536541856870_item	2703553	et	4	main
umbes	doc_536541856870_item	2703557	et	4	main
osa	doc_536541856870_item	2703565	et	4	main
on	doc_536541856870_item	2703575	et	4	main
ka	doc_536541856870_item	2703576	et	3	main
praegusel	doc_536541856870_item	2703577	et	3	main
laulupidu	doc_536541856870_item	2703583	et	4	main
suur	doc_536541856870_item	2703585	et	3	main
tullakse	doc_536541856870_item	2703588	et	3	main
ja	doc_536541856870_item	2703602	et	3	main
läbi	doc_536541856870_item	2703609	et	4	main
aja	doc_536541856870_item	2703610	et	4	main
kujunenud	doc_536541856870_item	2703611	et	4	main
rahvuslikuks	doc_536541856870_item	2703612	et	3	main
sümboliks	doc_536541856870_item	2703613	et	4	main
ainult	doc_536541856870_item	2703618	et	4	main
inimeste	doc_536541856870_item	2703619	et	3	main
vaba	doc_536541856870_item	2703620	et	4	main
veetmiseks	doc_536541856870_item	2703622	et	4	main
rahvasse	doc_536541856870_item	2703632	et	3	main
nendel	doc_536541856870_item	2703633	et	4	main
on	doc_536541856870_item	2703634	et	4	main
laulmine	doc_536541856870_item	2703570	et	4	main
sündmus	doc_536541856870_item	2703580	et	3	main
lisaks	doc_536541856870_item	2703581	et	4	main
on	doc_536541856870_item	2703584	et	4	main
sõpradega	doc_536541856870_item	2703590	et	3	main
on	doc_536541856870_item	2703608	et	4	main
rahvalaule	doc_536541856870_item	2703614	et	4	main
aja	doc_536541856870_item	2703621	et	4	main
eesmärk	doc_536541856870_item	2703623	et	3	main
on	doc_536541856870_item	2703624	et	4	main
teatada	doc_536541856870_item	2703625	et	3	main
inimestele	doc_536541856870_item	2703626	et	3	main
et	doc_536541856870_item	2703627	et	3	main
nad	doc_536541856870_item	2703628	et	3	main
kõik	doc_536541856870_item	2703629	et	4	main
ja	doc_536541856870_item	2703645	et	3	main
uhkus	doc_536541856870_item	2703647	et	4	main
või	doc_536541856870_item	2703591	et	4	main
laulmine	doc_536541856870_item	2703595	et	4	main
kultuuri	doc_536541856870_item	2703601	et	4	main
ühine	doc_536541856870_item	2703635	et	4	main
kultuur	doc_536541856870_item	2703636	et	3	main
ja	doc_536541856870_item	2703637	et	3	main
ühine	doc_536541856870_item	2703638	et	4	main
sümbolid	doc_536541856870_item	2703644	et	3	main
350	doc_536541856875_item	2704723	et	2	main
analüüsiv	doc_536541856875_item	2704729	et	4	main
ja	doc_536541856875_item	2704730	et	3	main
üldistav	doc_536541856875_item	2704731	et	4	main
tuginema	doc_536541856875_item	2704732	et	3	main
loengus	doc_536541856875_item	2704733	et	3	main
ja	doc_536541856875_item	2704734	et	3	main
lugemistekstis	doc_536541856875_item	2704735	et	3	main
esitatud	doc_536541856875_item	2704736	et	4	main
faktidele	doc_536541856875_item	2704737	et	3	main
mis	doc_536541856875_item	2704743	et	4	main
riigina	doc_536541856875_item	2704751	et	3	main
temal	doc_536541856875_item	2704753	et	3	main
ajalugu	doc_536541856875_item	2704759	et	4	main
eestil	doc_536541856875_item	2704760	et	3	main
on	doc_536541856875_item	2704761	et	4	main
oma	doc_536541856875_item	2704762	et	4	main
ja	doc_536541856875_item	2704766	et	3	main
laulupeod	doc_536541856875_item	2704773	et	4	main
need	doc_536541856875_item	2704786	et	3	main
etendus	doc_536541856875_item	2704790	et	4	main
100	doc_536541856875_item	2704794	et	2	main
tagasi	doc_536541856875_item	2704796	et	3	main
vanemuise	doc_536541856875_item	2704805	et	4	main
jannseniga	doc_536541856875_item	2704810	et	4	main
pikkus	doc_536541856875_item	2704721	et	4	main
sõna	doc_536541856875_item	2704724	et	4	main
essee	doc_536541856875_item	2704725	et	4	main
peab	doc_536541856875_item	2704726	et	4	main
eestlastest	doc_536541856875_item	2704745	et	4	main
rikkas	doc_536541856875_item	2704756	et	4	main
ja	doc_536541856875_item	2704757	et	3	main
maailma	doc_536541856875_item	2704763	et	4	main
mis	doc_536541856875_item	2704774	et	4	main
ehitatud	doc_536541856875_item	2704782	et	4	main
toimuvad	doc_536541856875_item	2704785	et	4	main
tuntud	doc_536541856875_item	2704787	et	4	main
lauluväljakul	doc_536541856875_item	2704791	et	3	main
aastat	doc_536541856875_item	2704795	et	3	main
tuli	doc_536541856875_item	2704804	et	4	main
v	doc_536541856875_item	2704809	et	4	main
see	doc_536541856875_item	2704820	et	3	main
aluse	doc_536541856875_item	2704825	et	4	main
pärast	doc_536541856875_item	2704843	et	4	main
ka	doc_536541856875_item	2704844	et	3	main
võisid	doc_536541856875_item	2704845	et	4	main
poistekoorid	doc_536541856875_item	2704850	et	3	main
arv	doc_536541856875_item	2704858	et	3	main
üritustes	doc_536541856875_item	2704867	et	4	main
tallinnas	doc_536541856875_item	2704876	et	4	main
palju	doc_536541856875_item	2704880	et	4	main
ja	doc_536541856875_item	2704883	et	3	main
esinesid	doc_536541856875_item	2704886	et	4	main
nad	doc_536541856875_item	2704895	et	3	main
kõikidel	doc_536541856875_item	2704900	et	4	main
oma	doc_536541856875_item	2704903	et	4	main
esitlus	doc_536541856875_item	2704908	et	4	main
oli	doc_536541856875_item	2704909	et	3	main
teise	doc_536541856875_item	2704921	et	4	main
keelega	doc_536541856875_item	2704923	et	3	main
kõlab	doc_536541856875_item	2704924	et	3	main
laulda	doc_536541856875_item	2704944	et	4	main
teevad	doc_536541856875_item	2704946	et	3	main
kuna	doc_536541856875_item	2704949	et	3	main
koordatakse	doc_536541856875_item	2704963	et	4	main
kus	doc_536541856875_item	2704966	et	3	main
oma	doc_536541856875_item	2704968	et	4	main
300	doc_536541856875_item	2704722	et	2	main
soovitatav	doc_536541856875_item	2704740	et	4	main
illustreerida	doc_536541856875_item	2704741	et	3	main
näidetega	doc_536541856875_item	2704742	et	3	main
eesti	doc_536541856875_item	2704747	et	4	main
tundub	doc_536541856875_item	2704749	et	3	main
aga	doc_536541856875_item	2704752	et	3	main
on	doc_536541856875_item	2704754	et	4	main
oma	doc_536541856875_item	2704755	et	4	main
heliloojad	doc_536541856875_item	2704765	et	3	main
on	doc_536541856875_item	2704775	et	4	main
tartus	doc_536541856875_item	2704778	et	3	main
lauluväljakud	doc_536541856875_item	2704783	et	3	main
tartu	doc_536541856875_item	2704797	et	4	main
idee	doc_536541856875_item	2704801	et	4	main
teostus	doc_536541856875_item	2704803	et	4	main
j	doc_536541856875_item	2704808	et	4	main
ajal	doc_536541856875_item	2704812	et	4	main
peol	doc_536541856875_item	2704814	et	4	main
keelatud	doc_536541856875_item	2704821	et	4	main
üritus	doc_536541856875_item	2704823	et	4	main
korraldamisele	doc_536541856875_item	2704828	et	4	main
kuni	doc_536541856875_item	2704829	et	3	main
1983	doc_536541856875_item	2704830	et	2	main
aastani	doc_536541856875_item	2704831	et	3	main
ei	doc_536541856875_item	2704832	et	4	main
ürituses	doc_536541856875_item	2704838	et	4	main
kui	doc_536541856875_item	2704839	et	3	main
nad	doc_536541856875_item	2704840	et	3	main
said	doc_536541856875_item	2704841	et	4	main
võimalusi	doc_536541856875_item	2704842	et	3	main
osavõtjate	doc_536541856875_item	2704853	et	3	main
kui	doc_536541856875_item	2704855	et	3	main
see	doc_536541856875_item	2704859	et	3	main
tähendas	doc_536541856875_item	2704861	et	3	main
olid	doc_536541856875_item	2704864	et	4	main
niisugustes	doc_536541856875_item	2704866	et	3	main
mis	doc_536541856875_item	2704870	et	4	main
tartus	doc_536541856875_item	2704878	et	3	main
inimesi	doc_536541856875_item	2704881	et	4	main
lavas	doc_536541856875_item	2704885	et	3	main
ansamblid	doc_536541856875_item	2704887	et	3	main
eestist	doc_536541856875_item	2704892	et	3	main
ja	doc_536541856875_item	2704893	et	3	main
kõik	doc_536541856875_item	2704894	et	4	main
oma	doc_536541856875_item	2704897	et	4	main
põnev	doc_536541856875_item	2704911	et	3	main
mitte	doc_536541856875_item	2704912	et	3	main
ainult	doc_536541856875_item	2704913	et	4	main
eestlased	doc_536541856875_item	2704932	et	3	main
nad	doc_536541856875_item	2704935	et	3	main
olema	doc_536541856875_item	2704727	et	4	main
väiteid	doc_536541856875_item	2704738	et	4	main
laulurahva	doc_536541856875_item	2704746	et	3	main
ainult	doc_536541856875_item	2704748	et	4	main
väikese	doc_536541856875_item	2704750	et	4	main
tuntud	doc_536541856875_item	2704764	et	4	main
sellel	doc_536541856875_item	2704768	et	4	main
balti	doc_536541856875_item	2704770	et	3	main
riigil	doc_536541856875_item	2704771	et	3	main
toimuvad	doc_536541856875_item	2704772	et	4	main
ja	doc_536541856875_item	2704779	et	3	main
tallinnas	doc_536541856875_item	2704780	et	4	main
on	doc_536541856875_item	2704781	et	4	main
laulupeod	doc_536541856875_item	2704788	et	4	main
umbes	doc_536541856875_item	2704793	et	4	main
lauluväljakul	doc_536541856875_item	2704798	et	3	main
mille	doc_536541856875_item	2704799	et	3	main
seltsist	doc_536541856875_item	2704806	et	4	main
tol	doc_536541856875_item	2704811	et	3	main
ainult	doc_536541856875_item	2704815	et	4	main
mehed	doc_536541856875_item	2704816	et	3	main
sest	doc_536541856875_item	2704817	et	4	main
naistel	doc_536541856875_item	2704818	et	3	main
oli	doc_536541856875_item	2704819	et	3	main
selline	doc_536541856875_item	2704822	et	4	main
pani	doc_536541856875_item	2704824	et	4	main
siis	doc_536541856875_item	2704851	et	3	main
kahes	doc_536541856875_item	2704872	et	4	main
ja	doc_536541856875_item	2704877	et	3	main
eestist	doc_536541856875_item	2704890	et	3	main
essee	doc_536541856875_item	2704705	et	4	main
eesti	doc_536541856875_item	2704706	et	4	main
keele	doc_536541856875_item	2704707	et	4	main
kui	doc_536541856875_item	2704708	et	3	main
teise	doc_536541856875_item	2704709	et	4	main
keele	doc_536541856875_item	2704710	et	4	main
test	doc_536541856875_item	2704711	et	3	main
kirjutamine	doc_536541856875_item	2704712	et	4	main
kirjutage	doc_536541856875_item	2704713	et	3	main
essee	doc_536541856875_item	2704714	et	4	main
teemal	doc_536541856875_item	2704715	et	3	main
mis	doc_536541856875_item	2704716	et	4	main
teeb	doc_536541856875_item	2704717	et	3	main
eestlastest	doc_536541856875_item	2704718	et	4	main
laulurahva	doc_536541856875_item	2704719	et	3	main
essee	doc_536541856875_item	2704720	et	4	main
arutlev	doc_536541856875_item	2704728	et	4	main
on	doc_536541856875_item	2704739	et	4	main
teeb	doc_536541856875_item	2704744	et	3	main
huvitav	doc_536541856875_item	2704758	et	4	main
ka	doc_536541856875_item	2704767	et	3	main
väikesel	doc_536541856875_item	2704769	et	4	main
tundud	doc_536541856875_item	2704776	et	3	main
euroopas	doc_536541856875_item	2704777	et	3	main
kus	doc_536541856875_item	2704784	et	3	main
esimene	doc_536541856875_item	2704789	et	3	main
toimus	doc_536541856875_item	2704792	et	3	main
korraldamise	doc_536541856875_item	2704800	et	4	main
ja	doc_536541856875_item	2704802	et	3	main
eesotsas	doc_536541856875_item	2704807	et	4	main
osalesid	doc_536541856875_item	2704813	et	4	main
saanud	doc_536541856875_item	2704833	et	4	main
naised	doc_536541856875_item	2704834	et	3	main
osa	doc_536541856875_item	2704835	et	4	main
võtta	doc_536541856875_item	2704836	et	3	main
suurenes	doc_536541856875_item	2704852	et	4	main
arv	doc_536541856875_item	2704854	et	3	main
pealvaatajate	doc_536541856875_item	2704857	et	3	main
ainult	doc_536541856875_item	2704860	et	4	main
inimised	doc_536541856875_item	2704863	et	4	main
huvitatud	doc_536541856875_item	2704865	et	4	main
ühel	doc_536541856875_item	2704874	et	3	main
ajal	doc_536541856875_item	2704875	et	4	main
välismaalt	doc_536541856875_item	2704882	et	3	main
saaremaalt	doc_536541856875_item	2704888	et	4	main
lõuna	doc_536541856875_item	2704889	et	4	main
olid	doc_536541856875_item	2704896	et	4	main
uskumatu	doc_536541856875_item	2704910	et	4	main
maailma	doc_536541856875_item	2704922	et	4	main
kõnelevad	doc_536541856875_item	2704936	et	4	main
kes	doc_536541856875_item	2704940	et	4	main
nende	doc_536541856875_item	2704959	et	4	main
naised	doc_536541856875_item	2704960	et	3	main
paljudel	doc_536541856875_item	2704961	et	3	main
saartel	doc_536541856875_item	2704962	et	3	main
lavaesindusi	doc_536541856875_item	2704965	et	3	main
täpselt	doc_536541856875_item	2705000	et	4	main
eestlastel	doc_536541856875_item	2705006	et	4	main
kombedel	doc_536541856875_item	2705009	et	4	main
essee	doc_536541856876_item	2705014	et	4	main
keele	doc_536541856876_item	2705019	et	4	main
essee	doc_536541856876_item	2705023	et	4	main
teeb	doc_536541856876_item	2705026	et	3	main
eestlastest	doc_536541856876_item	2705027	et	4	main
laulurahva	doc_536541856876_item	2705028	et	3	main
arutlev	doc_536541856876_item	2705037	et	4	main
analüüsiv	doc_536541856876_item	2705038	et	4	main
ja	doc_536541856876_item	2705039	et	3	main
üldistav	doc_536541856876_item	2705040	et	4	main
tuginema	doc_536541856876_item	2705041	et	3	main
loengus	doc_536541856876_item	2705042	et	3	main
ja	doc_536541856876_item	2705043	et	3	main
lugemistekstis	doc_536541856876_item	2705044	et	3	main
esitatud	doc_536541856876_item	2705045	et	4	main
faktidele	doc_536541856876_item	2705046	et	3	main
väiteid	doc_536541856876_item	2705047	et	4	main
eestlaste	doc_536541856876_item	2705059	et	4	main
nii	doc_536541856876_item	2705061	et	3	main
ka	doc_536541856876_item	2705064	et	3	main
peavad	doc_536541856876_item	2705075	et	4	main
ajal	doc_536541856876_item	2705079	et	4	main
ei	doc_536541856876_item	2705082	et	4	main
kujundanud	doc_536541856876_item	2705083	et	4	main
järgnevate	doc_536541856875_item	2704826	et	4	main
üldlaulupidude	doc_536541856875_item	2704827	et	4	main
selles	doc_536541856875_item	2704837	et	4	main
osaleda	doc_536541856875_item	2704846	et	3	main
ka	doc_536541856875_item	2704847	et	3	main
lastekoorid	doc_536541856875_item	2704848	et	3	main
ja	doc_536541856875_item	2704849	et	3	main
ka	doc_536541856875_item	2704856	et	3	main
et	doc_536541856875_item	2704862	et	3	main
viimane	doc_536541856875_item	2704868	et	3	main
kontsert	doc_536541856875_item	2704869	et	3	main
toimus	doc_536541856875_item	2704871	et	3	main
linnas	doc_536541856875_item	2704873	et	4	main
kogunes	doc_536541856875_item	2704879	et	3	main
eestist	doc_536541856875_item	2704884	et	3	main
rahvariietusega	doc_536541856875_item	2704898	et	3	main
valdkonnal	doc_536541856875_item	2704901	et	4	main
siis	doc_536541856875_item	2704905	et	3	main
kõik	doc_536541856875_item	2704906	et	4	main
see	doc_536541856875_item	2704907	et	3	main
muutuvad	doc_536541856875_item	2704915	et	4	main
eestlasi	doc_536541856875_item	2704916	et	3	main
laulurahvaks	doc_536541856875_item	2704917	et	3	main
eesti	doc_536541856875_item	2704918	et	4	main
keel	doc_536541856875_item	2704919	et	4	main
võrreldes	doc_536541856875_item	2704920	et	3	main
ida	doc_536541856875_item	2704891	et	4	main
kuna	doc_536541856875_item	2704899	et	3	main
on	doc_536541856875_item	2704902	et	4	main
rahvariietus	doc_536541856875_item	2704904	et	3	main
laulupeod	doc_536541856875_item	2704914	et	4	main
välismaalistele	doc_536541856875_item	2704929	et	4	main
tundub	doc_536541856875_item	2704930	et	3	main
et	doc_536541856875_item	2704931	et	3	main
laulavad	doc_536541856875_item	2704933	et	4	main
millal	doc_536541856875_item	2704934	et	3	main
inimesed	doc_536541856875_item	2704938	et	3	main
nad	doc_536541856875_item	2704945	et	3	main
mehed	doc_536541856875_item	2704950	et	3	main
saa	doc_536541856875_item	2704952	et	4	main
näitaks	doc_536541856875_item	2704955	et	3	main
käivad	doc_536541856875_item	2704956	et	4	main
meres	doc_536541856875_item	2704957	et	3	main
laulavad	doc_536541856875_item	2704958	et	4	main
et	doc_536541856875_item	2704995	et	3	main
võib	doc_536541856875_item	2705004	et	3	main
või	doc_536541856875_item	2705010	et	4	main
isegi	doc_536541856875_item	2705011	et	4	main
eesti	doc_536541856875_item	2705012	et	4	main
keele	doc_536541856876_item	2705016	et	4	main
kui	doc_536541856876_item	2705017	et	3	main
teise	doc_536541856876_item	2705018	et	4	main
300	doc_536541856876_item	2705031	et	2	main
olema	doc_536541856876_item	2705036	et	4	main
muidugi	doc_536541856876_item	2705054	et	4	main
laulud	doc_536541856876_item	2705055	et	3	main
mängivad	doc_536541856876_item	2705056	et	4	main
tähtsat	doc_536541856876_item	2705057	et	3	main
elus	doc_536541856876_item	2705060	et	4	main
kui	doc_536541856876_item	2705063	et	3	main
põlvkond	doc_536541856876_item	2705069	et	3	main
neid	doc_536541856876_item	2705076	et	4	main
vanal	doc_536541856876_item	2705078	et	3	main
üldse	doc_536541856876_item	2705081	et	3	main
ilma	doc_536541856876_item	2705086	et	4	main
abikaasa	doc_536541856876_item	2705092	et	4	main
sest	doc_536541856876_item	2705093	et	4	main
et	doc_536541856876_item	2705094	et	3	main
väga	doc_536541856876_item	2705123	et	3	main
sellest	doc_536541856876_item	2705138	et	4	main
tallinnas	doc_536541856876_item	2705151	et	4	main
kuulus	doc_536541856876_item	2705156	et	4	main
seotud	doc_536541856876_item	2705165	et	4	main
pole	doc_536541856876_item	2705174	et	3	main
tõesti	doc_536541856876_item	2705181	et	3	main
nii	doc_536541856876_item	2705182	et	3	main
rahvalaule	doc_536541856876_item	2705188	et	4	main
kiigutasid	doc_536541856876_item	2705192	et	4	main
last	doc_536541856876_item	2705194	et	4	main
talumehed	doc_536541856876_item	2705195	et	3	main
kuid	doc_536541856876_item	2705207	et	4	main
tänapäevani	doc_536541856876_item	2705208	et	3	main
ei	doc_536541856876_item	2705215	et	4	main
huvitanud	doc_536541856876_item	2705222	et	4	main
ei	doc_536541856876_item	2705226	et	4	main
ette	doc_536541856876_item	2705228	et	4	main
kujundada	doc_536541856876_item	2705229	et	3	main
jaanipäeva	doc_536541856876_item	2705230	et	4	main
oma	doc_536541856876_item	2705238	et	4	main
repertuaaris	doc_536541856876_item	2705239	et	3	main
rahvalaule	doc_536541856876_item	2705240	et	4	main
veeta	doc_536541856876_item	2705246	et	4	main
aega	doc_536541856876_item	2705248	et	4	main
ja	doc_536541856876_item	2705249	et	3	main
nautida	doc_536541856876_item	2705250	et	3	main
rahvamuusikaga	doc_536541856876_item	2705251	et	3	main
laulupeol	doc_536541856876_item	2705252	et	4	main
kokkuvõtes	doc_536541856876_item	2705253	et	3	main
tahaks	doc_536541856876_item	2705254	et	3	main
väga	doc_536541856876_item	2705260	et	3	main
suurt	doc_536541856876_item	2705264	et	3	main
on	doc_536541856876_item	2705271	et	4	main
väga	doc_536541856876_item	2705272	et	3	main
ka	doc_536541856876_item	2705279	et	3	main
kombeid	doc_536541856876_item	2705289	et	4	main
uhke	doc_536541856876_item	2705296	et	4	main
soovija	doc_536541856876_item	2705299	et	4	main
võib	doc_536541856876_item	2705300	et	3	main
pehmelt	doc_536541856875_item	2704925	et	4	main
meloodiliselt	doc_536541856875_item	2704926	et	4	main
ja	doc_536541856875_item	2704927	et	3	main
paljudele	doc_536541856875_item	2704928	et	3	main
omavahel	doc_536541856875_item	2704937	et	3	main
eestlased	doc_536541856875_item	2704939	et	3	main
seda	doc_536541856875_item	2704947	et	3	main
teha	doc_536541856875_item	2704954	et	3	main
kalurid	doc_536541856875_item	2704971	et	3	main
kes	doc_536541856875_item	2704972	et	4	main
käivad	doc_536541856875_item	2704973	et	4	main
meres	doc_536541856875_item	2704974	et	3	main
oma	doc_536541856875_item	2704975	et	4	main
naistega	doc_536541856875_item	2704976	et	3	main
mõnikord	doc_536541856875_item	2704977	et	3	main
nad	doc_536541856875_item	2704978	et	3	main
võitlevad	doc_536541856875_item	2704979	et	4	main
koos	doc_536541856875_item	2704980	et	4	main
teise	doc_536541856875_item	2704981	et	4	main
saarega	doc_536541856875_item	2704982	et	3	main
aga	doc_536541856875_item	2704983	et	3	main
nende	doc_536541856875_item	2704984	et	4	main
eesmärk	doc_536541856875_item	2704985	et	3	main
alati	doc_536541856875_item	2704986	et	4	main
on	doc_536541856875_item	2704987	et	4	main
meelahustus	doc_536541856875_item	2704988	et	3	main
mis	doc_536541856875_item	2704989	et	4	main
teeb	doc_536541856875_item	2704990	et	3	main
eestlastest	doc_536541856875_item	2704991	et	4	main
laulurahva	doc_536541856875_item	2704992	et	3	main
mulle	doc_536541856875_item	2704993	et	4	main
tundub	doc_536541856875_item	2704994	et	3	main
elavad	doc_536541856875_item	2704941	et	4	main
saartel	doc_536541856875_item	2704942	et	3	main
meeldivad	doc_536541856875_item	2704943	et	4	main
alati	doc_536541856875_item	2704948	et	4	main
ei	doc_536541856875_item	2704951	et	4	main
seda	doc_536541856875_item	2704953	et	3	main
üritusi	doc_536541856875_item	2704964	et	4	main
tansivad	doc_536541856875_item	2704967	et	4	main
rahvatantsu	doc_536541856875_item	2704969	et	4	main
need	doc_536541856875_item	2704970	et	3	main
tea	doc_536541856875_item	2704999	et	4	main
põhjus	doc_536541856875_item	2705003	et	4	main
test	doc_536541856876_item	2705020	et	3	main
kirjutage	doc_536541856876_item	2705022	et	3	main
350	doc_536541856876_item	2705032	et	2	main
sõna	doc_536541856876_item	2705033	et	4	main
on	doc_536541856876_item	2705048	et	4	main
rahvalaule	doc_536541856876_item	2705073	et	4	main
ja	doc_536541856876_item	2705074	et	3	main
lugu	doc_536541856876_item	2705077	et	4	main
elu	doc_536541856876_item	2705085	et	4	main
oluline	doc_536541856876_item	2705091	et	4	main
ja	doc_536541856876_item	2705097	et	3	main
sajandi	doc_536541856876_item	2705121	et	3	main
oluliseks	doc_536541856876_item	2705124	et	4	main
sündmuseks	doc_536541856876_item	2705125	et	3	main
ülemaaline	doc_536541856876_item	2705131	et	4	main
laulpidu	doc_536541856876_item	2705132	et	4	main
sai	doc_536541856876_item	2705139	et	4	main
traditsioon	doc_536541856876_item	2705142	et	3	main
eestis	doc_536541856876_item	2705144	et	3	main
riigi	doc_536541856876_item	2705153	et	3	main
pealinnas	doc_536541856876_item	2705154	et	4	main
on	doc_536541856876_item	2705155	et	4	main
alati	doc_536541856876_item	2705159	et	4	main
erinevaid	doc_536541856876_item	2705161	et	4	main
võib	doc_536541856876_item	2705169	et	3	main
ja	doc_536541856876_item	2705176	et	3	main
kas	doc_536541856876_item	2705178	et	3	main
see	doc_536541856876_item	2705180	et	3	main
rohkem	doc_536541856876_item	2705187	et	4	main
lasterahvaansamblid	doc_536541856876_item	2705212	et	3	main
ka	doc_536541856876_item	2705221	et	3	main
ilma	doc_536541856876_item	2705231	et	4	main
me	doc_536541856876_item	2705243	et	4	main
eesti	doc_536541856876_item	2705257	et	4	main
rahvafolklor	doc_536541856876_item	2705258	et	4	main
rikkas	doc_536541856876_item	2705261	et	4	main
mitmekülgne	doc_536541856876_item	2705263	et	3	main
kõrvalt	doc_536541856876_item	2705273	et	4	main
seotud	doc_536541856876_item	2705274	et	4	main
on	doc_536541856876_item	2705278	et	4	main
tähelepanuväärsemam	doc_536541856876_item	2705282	et	4	main
peame	doc_536541856876_item	2705286	et	4	main
säilitama	doc_536541856876_item	2705287	et	4	main
meie	doc_536541856876_item	2705288	et	4	main
et	doc_536541856876_item	2705297	et	3	main
saada	doc_536541856876_item	2705301	et	4	main
isegi	doc_536541856875_item	2704996	et	4	main
eestlased	doc_536541856875_item	2704997	et	3	main
ei	doc_536541856875_item	2704998	et	4	main
vastust	doc_536541856875_item	2705001	et	4	main
eesti	doc_536541856876_item	2705015	et	4	main
aga	doc_536541856875_item	2705002	et	3	main
olla	doc_536541856875_item	2705005	et	3	main
või	doc_536541856875_item	2705007	et	4	main
nende	doc_536541856875_item	2705008	et	4	main
keelel	doc_536541856875_item	2705013	et	4	main
kirjutamine	doc_536541856876_item	2705021	et	4	main
teemal	doc_536541856876_item	2705024	et	3	main
mis	doc_536541856876_item	2705025	et	4	main
pikkus	doc_536541856876_item	2705030	et	4	main
soovitatav	doc_536541856876_item	2705049	et	4	main
illustreerida	doc_536541856876_item	2705050	et	3	main
näidetega	doc_536541856876_item	2705051	et	3	main
muusika	doc_536541856876_item	2705052	et	4	main
ja	doc_536541856876_item	2705053	et	3	main
tulevane	doc_536541856876_item	2705068	et	3	main
ei	doc_536541856876_item	2705070	et	4	main
unusta	doc_536541856876_item	2705071	et	4	main
oma	doc_536541856876_item	2705072	et	4	main
oma	doc_536541856876_item	2705084	et	4	main
väha	doc_536541856876_item	2705090	et	4	main
aitas	doc_536541856876_item	2705096	et	3	main
1896	doc_536541856876_item	2705146	et	2	main
erinevad	doc_536541856876_item	2705148	et	4	main
rahvapeod	doc_536541856876_item	2705149	et	4	main
korraldati	doc_536541856876_item	2705150	et	3	main
laulsid	doc_536541856876_item	2705190	et	4	main
oma	doc_536541856876_item	2705193	et	4	main
kas	doc_536541856876_item	2705213	et	3	main
näiteks	doc_536541856876_item	2705225	et	4	main
saa	doc_536541856876_item	2705227	et	4	main
ansamblid	doc_536541856876_item	2705235	et	3	main
perega	doc_536541856876_item	2705242	et	3	main
vaba	doc_536541856876_item	2705247	et	4	main
on	doc_536541856876_item	2705259	et	4	main
on	doc_536541856876_item	2705267	et	4	main
rahvalauludel	doc_536541856876_item	2705268	et	3	main
vana	doc_536541856876_item	2705275	et	4	main
rahvamuusikaga	doc_536541856876_item	2705276	et	3	main
me	doc_536541856876_item	2705285	et	4	main
meie	doc_536541856876_item	2705302	et	4	main
350	doc_536541856877_item	2705330	et	2	main
sõna	doc_536541856877_item	2705331	et	4	main
essee	doc_536541856877_item	2705332	et	4	main
soovitatav	doc_536541856877_item	2705347	et	4	main
illustreerida	doc_536541856877_item	2705348	et	3	main
näidetega	doc_536541856877_item	2705349	et	3	main
terve	doc_536541856877_item	2705352	et	4	main
kui	doc_536541856877_item	2705356	et	3	main
väikesed	doc_536541856877_item	2705359	et	4	main
ema	doc_536541856877_item	2705360	et	4	main
laulab	doc_536541856877_item	2705361	et	3	main
meie	doc_536541856877_item	2705366	et	4	main
lastele	doc_536541856877_item	2705370	et	4	main
kasvame	doc_536541856877_item	2705373	et	3	main
ise	doc_536541856877_item	2705376	et	4	main
kodus	doc_536541856877_item	2705404	et	4	main
või	doc_536541856877_item	2705412	et	4	main
marju	doc_536541856877_item	2705417	et	3	main
nendega	doc_536541856877_item	2705421	et	4	main
hakkasid	doc_536541856877_item	2705423	et	4	main
olulisem	doc_536541856877_item	2705443	et	4	main
lõkket	doc_536541856877_item	2705455	et	4	main
see	doc_536541856877_item	2705459	et	3	main
ja	doc_536541856877_item	2705465	et	3	main
on	doc_536541856877_item	2705466	et	4	main
kes	doc_536541856877_item	2705469	et	4	main
ei	doc_536541856877_item	2705476	et	4	main
mis	doc_536541856877_item	2705486	et	4	main
toimub	doc_536541856877_item	2705487	et	3	main
praegu	doc_536541856877_item	2705488	et	3	main
tallinnas	doc_536541856877_item	2705489	et	4	main
ka	doc_536541856877_item	2705522	et	3	main
laul	doc_536541856877_item	2705532	et	4	main
on	doc_536541856877_item	2705533	et	4	main
elu	doc_536541856877_item	2705535	et	4	main
et	doc_536541856877_item	2705550	et	3	main
nad	doc_536541856877_item	2705553	et	3	main
essee	doc_536541856876_item	2705029	et	4	main
essee	doc_536541856876_item	2705034	et	4	main
peab	doc_536541856876_item	2705035	et	4	main
rolli	doc_536541856876_item	2705058	et	4	main
minevikus	doc_536541856876_item	2705062	et	3	main
tänapäeval	doc_536541856876_item	2705065	et	3	main
loodan	doc_536541856876_item	2705066	et	3	main
et	doc_536541856876_item	2705067	et	3	main
eestlased	doc_536541856876_item	2705080	et	3	main
lauluta	doc_536541856876_item	2705087	et	3	main
laul	doc_536541856876_item	2705088	et	4	main
on	doc_536541856876_item	2705089	et	4	main
see	doc_536541856876_item	2705095	et	3	main
aitab	doc_536541856876_item	2705098	et	3	main
eestlasi	doc_536541856876_item	2705099	et	3	main
nii	doc_536541856876_item	2705100	et	3	main
mures	doc_536541856876_item	2705101	et	3	main
kui	doc_536541856876_item	2705102	et	3	main
ka	doc_536541856876_item	2705103	et	3	main
rõõmus	doc_536541856876_item	2705104	et	4	main
väga	doc_536541856876_item	2705105	et	3	main
raske	doc_536541856876_item	2705106	et	4	main
ja	doc_536541856876_item	2705107	et	3	main
isegi	doc_536541856876_item	2705108	et	4	main
võimatu	doc_536541856876_item	2705109	et	4	main
ette	doc_536541856876_item	2705110	et	4	main
kujundada	doc_536541856876_item	2705111	et	3	main
erinevaid	doc_536541856876_item	2705112	et	4	main
tähtpäevi	doc_536541856876_item	2705113	et	4	main
ilma	doc_536541856876_item	2705114	et	4	main
rahvalauludeta	doc_536541856876_item	2705115	et	3	main
eestlaste	doc_536541856876_item	2705116	et	4	main
rahvuslik	doc_536541856876_item	2705117	et	3	main
ärkamine	doc_536541856876_item	2705118	et	4	main
toimus	doc_536541856876_item	2705119	et	3	main
19	doc_536541856876_item	2705120	et	2	main
lõpupool	doc_536541856876_item	2705122	et	4	main
jaoks	doc_536541856876_item	2705128	et	4	main
sai	doc_536541856876_item	2705129	et	4	main
esimene	doc_536541856876_item	2705130	et	3	main
alguse	doc_536541856876_item	2705140	et	3	main
juba	doc_536541856876_item	2705145	et	3	main
meie	doc_536541856876_item	2705152	et	4	main
lauluväljak	doc_536541856876_item	2705157	et	3	main
kõigepealt	doc_536541856876_item	2705166	et	3	main
rahvamuusikaga	doc_536541856876_item	2705167	et	3	main
keegi	doc_536541856876_item	2705168	et	4	main
kui	doc_536541856876_item	2705191	et	3	main
töötades	doc_536541856876_item	2705196	et	3	main
tänapäevased	doc_536541856876_item	2705197	et	4	main
noored	doc_536541856876_item	2705198	et	3	main
ja	doc_536541856876_item	2705199	et	3	main
vanem	doc_536541856876_item	2705200	et	4	main
põlvkond	doc_536541856876_item	2705201	et	3	main
lõuna-eestis	doc_536541856876_item	2705209	et	3	main
on	doc_536541856876_item	2705210	et	4	main
koolides	doc_536541856876_item	2705211	et	3	main
eesti	doc_536541856876_item	2705126	et	4	main
rahvamuusika	doc_536541856876_item	2705127	et	4	main
mis	doc_536541856876_item	2705133	et	4	main
toimus	doc_536541856876_item	2705134	et	3	main
1869	doc_536541856876_item	2705135	et	2	main
aastal	doc_536541856876_item	2705136	et	3	main
tartus	doc_536541856876_item	2705137	et	3	main
laulupidude	doc_536541856876_item	2705141	et	4	main
kogu	doc_536541856876_item	2705143	et	4	main
aastaks	doc_536541856876_item	2705147	et	4	main
kus	doc_536541856876_item	2705158	et	3	main
organiseeritakse	doc_536541856876_item	2705160	et	3	main
suurüritusi	doc_536541856876_item	2705162	et	3	main
mis	doc_536541856876_item	2705163	et	4	main
on	doc_536541856876_item	2705164	et	4	main
öelda	doc_536541856876_item	2705170	et	4	main
et	doc_536541856876_item	2705171	et	3	main
tänapäevasel	doc_536541856876_item	2705172	et	4	main
rahvalaul	doc_536541856876_item	2705173	et	4	main
oluline	doc_536541856876_item	2705175	et	4	main
tähelepanuväärne	doc_536541856876_item	2705177	et	3	main
on	doc_536541856876_item	2705179	et	4	main
loomulikult	doc_536541856876_item	2705183	et	4	main
vanal	doc_536541856876_item	2705184	et	3	main
ajal	doc_536541856876_item	2705185	et	4	main
lauldi	doc_536541856876_item	2705186	et	3	main
naised	doc_536541856876_item	2705189	et	3	main
eelistavad	doc_536541856876_item	2705202	et	4	main
mitte	doc_536541856876_item	2705203	et	3	main
laulda	doc_536541856876_item	2705204	et	4	main
aga	doc_536541856876_item	2705205	et	3	main
kuulata	doc_536541856876_item	2705206	et	4	main
see	doc_536541856876_item	2705214	et	3	main
tähenda	doc_536541856876_item	2705216	et	4	main
et	doc_536541856876_item	2705217	et	3	main
xxi-sajandi	doc_536541856876_item	2705218	et	3	main
elanikud	doc_536541856876_item	2705219	et	3	main
on	doc_536541856876_item	2705220	et	4	main
rahvamuusikas	doc_536541856876_item	2705223	et	3	main
populaarsed	doc_536541856876_item	2705233	et	3	main
eesti	doc_536541856876_item	2705234	et	4	main
ka	doc_536541856876_item	2705236	et	3	main
omandavad	doc_536541856876_item	2705237	et	4	main
võime	doc_536541856876_item	2705244	et	4	main
öelda	doc_536541856876_item	2705255	et	4	main
tänapäevane	doc_536541856876_item	2705269	et	4	main
looming	doc_536541856876_item	2705270	et	3	main
praeguseni	doc_536541856876_item	2705280	et	3	main
sündmused	doc_536541856876_item	2705283	et	3	main
ja	doc_536541856876_item	2705290	et	3	main
ja	doc_536541856876_item	2705292	et	3	main
ka	doc_536541856876_item	2705294	et	3	main
iga	doc_536541856876_item	2705298	et	4	main
mis	doc_536541856877_item	2705323	et	4	main
teeb	doc_536541856877_item	2705324	et	3	main
peab	doc_536541856877_item	2705333	et	4	main
ja	doc_536541856877_item	2705341	et	3	main
esitatud	doc_536541856877_item	2705343	et	4	main
on	doc_536541856877_item	2705351	et	4	main
koos	doc_536541856877_item	2705355	et	4	main
me	doc_536541856877_item	2705357	et	4	main
meile	doc_536541856877_item	2705362	et	4	main
meie	doc_536541856877_item	2705369	et	4	main
kui	doc_536541856877_item	2705380	et	3	main
sureb	doc_536541856877_item	2705382	et	3	main
laulavad	doc_536541856877_item	2705384	et	4	main
vanal	doc_536541856877_item	2705385	et	3	main
eestlased	doc_536541856877_item	2705387	et	3	main
väga	doc_536541856877_item	2705388	et	3	main
tihti	doc_536541856877_item	2705389	et	3	main
lauluga	doc_536541856877_item	2705395	et	4	main
põhiliselt	doc_536541856877_item	2705405	et	4	main
laulsid	doc_536541856877_item	2705406	et	4	main
sööki	doc_536541856877_item	2705414	et	4	main
laul	doc_536541856877_item	2705418	et	4	main
eriti	doc_536541856877_item	2705420	et	3	main
ma	doc_536541856876_item	2705224	et	3	main
rahvalaule	doc_536541856876_item	2705232	et	4	main
koos	doc_536541856876_item	2705241	et	4	main
hästi	doc_536541856876_item	2705245	et	3	main
et	doc_536541856876_item	2705256	et	3	main
ja	doc_536541856876_item	2705262	et	3	main
osa	doc_536541856876_item	2705265	et	4	main
selles	doc_536541856876_item	2705266	et	4	main
laulpeod	doc_536541856876_item	2705277	et	4	main
kõige	doc_536541856876_item	2705281	et	4	main
eestis	doc_536541856876_item	2705284	et	3	main
traditsioonid	doc_536541856876_item	2705291	et	3	main
peame	doc_536541856876_item	2705293	et	4	main
olema	doc_536541856876_item	2705295	et	4	main
rahvamuusika	doc_536541856876_item	2705303	et	4	main
osaks	doc_536541856876_item	2705304	et	3	main
kui	doc_536541856876_item	2705305	et	3	main
osaleb	doc_536541856876_item	2705306	et	3	main
ülemaalises	doc_536541856876_item	2705307	et	4	main
laulpeos	doc_536541856876_item	2705308	et	4	main
mis	doc_536541856876_item	2705309	et	4	main
toimub	doc_536541856876_item	2705310	et	3	main
eestis	doc_536541856876_item	2705311	et	3	main
essee	doc_536541856877_item	2705312	et	4	main
eesti	doc_536541856877_item	2705313	et	4	main
keele	doc_536541856877_item	2705314	et	4	main
kui	doc_536541856877_item	2705315	et	3	main
teise	doc_536541856877_item	2705316	et	4	main
keele	doc_536541856877_item	2705317	et	4	main
test	doc_536541856877_item	2705318	et	3	main
kirjutamine	doc_536541856877_item	2705319	et	4	main
kirjutage	doc_536541856877_item	2705320	et	3	main
pikkus	doc_536541856877_item	2705328	et	4	main
300	doc_536541856877_item	2705329	et	2	main
on	doc_536541856877_item	2705346	et	4	main
elu	doc_536541856877_item	2705353	et	4	main
pärast	doc_536541856877_item	2705367	et	4	main
kui	doc_536541856877_item	2705371	et	3	main
suureks	doc_536541856877_item	2705374	et	4	main
laulma	doc_536541856877_item	2705378	et	3	main
ajal	doc_536541856877_item	2705386	et	4	main
laulsid	doc_536541856877_item	2705390	et	4	main
läks	doc_536541856877_item	2705396	et	3	main
kiiremini	doc_536541856877_item	2705397	et	4	main
nende	doc_536541856877_item	2705400	et	4	main
põllul	doc_536541856877_item	2705402	et	3	main
eesti	doc_536541856877_item	2705407	et	4	main
naised	doc_536541856877_item	2705408	et	3	main
kui	doc_536541856877_item	2705409	et	3	main
nad	doc_536541856877_item	2705410	et	3	main
kudusid	doc_536541856877_item	2705411	et	4	main
korjasid	doc_536541856877_item	2705416	et	4	main
nad	doc_536541856877_item	2705426	et	3	main
kirikus	doc_536541856877_item	2705428	et	3	main
on	doc_536541856877_item	2705430	et	4	main
alati	doc_536541856877_item	2705435	et	4	main
ajal	doc_536541856877_item	2705441	et	4	main
kõige	doc_536541856877_item	2705442	et	4	main
kiikude	doc_536541856877_item	2705457	et	4	main
lõbus	doc_536541856877_item	2705464	et	4	main
vanalaule	doc_536541856877_item	2705471	et	4	main
ja	doc_536541856877_item	2705472	et	3	main
vanansu	doc_536541856877_item	2705473	et	4	main
aga	doc_536541856877_item	2705474	et	3	main
essee	doc_536541856877_item	2705321	et	4	main
arutlev	doc_536541856877_item	2705335	et	4	main
analüüsiv	doc_536541856877_item	2705336	et	4	main
ja	doc_536541856877_item	2705337	et	3	main
üldistav	doc_536541856877_item	2705338	et	4	main
teemal	doc_536541856877_item	2705322	et	3	main
eestlastest	doc_536541856877_item	2705325	et	4	main
laulurahva	doc_536541856877_item	2705326	et	3	main
essee	doc_536541856877_item	2705327	et	4	main
olema	doc_536541856877_item	2705334	et	4	main
lugemistekstis	doc_536541856877_item	2705342	et	3	main
faktidele	doc_536541856877_item	2705344	et	3	main
väiteid	doc_536541856877_item	2705345	et	4	main
meiega	doc_536541856877_item	2705354	et	4	main
oleme	doc_536541856877_item	2705358	et	3	main
erinevad	doc_536541856877_item	2705363	et	4	main
laulud	doc_536541856877_item	2705364	et	3	main
mis	doc_536541856877_item	2705365	et	4	main
me	doc_536541856877_item	2705372	et	4	main
hakkame	doc_536541856877_item	2705377	et	3	main
ja	doc_536541856877_item	2705379	et	3	main
inimene	doc_536541856877_item	2705381	et	3	main
laul	doc_536541856877_item	2705391	et	4	main
aitas	doc_536541856877_item	2705392	et	3	main
ja	doc_536541856877_item	2705398	et	3	main
tegid	doc_536541856877_item	2705413	et	4	main
hiljem	doc_536541856877_item	2705422	et	3	main
palju	doc_536541856877_item	2705432	et	4	main
lauluga	doc_536541856877_item	2705437	et	4	main
ja	doc_536541856877_item	2705438	et	3	main
tansu	doc_536541856877_item	2705446	et	4	main
jaaipäev	doc_536541856877_item	2705449	et	4	main
kiikusid	doc_536541856877_item	2705456	et	4	main
praeguni	doc_536541856877_item	2705462	et	4	main
väga	doc_536541856877_item	2705463	et	3	main
esitavad	doc_536541856877_item	2705470	et	4	main
ainuke	doc_536541856877_item	2705478	et	4	main
kus	doc_536541856877_item	2705480	et	3	main
laulavad	doc_536541856877_item	2705481	et	4	main
eestis	doc_536541856877_item	2705482	et	3	main
tuginema	doc_536541856877_item	2705339	et	3	main
loengus	doc_536541856877_item	2705340	et	3	main
laul	doc_536541856877_item	2705350	et	4	main
laulame	doc_536541856877_item	2705368	et	4	main
siis	doc_536541856877_item	2705375	et	3	main
talle	doc_536541856877_item	2705383	et	4	main
nendele	doc_536541856877_item	2705393	et	4	main
sest	doc_536541856877_item	2705394	et	4	main
kergem	doc_536541856877_item	2705399	et	4	main
töö	doc_536541856877_item	2705401	et	4	main
või	doc_536541856877_item	2705403	et	4	main
või	doc_536541856877_item	2705415	et	4	main
oli	doc_536541856877_item	2705419	et	3	main
tekkima	doc_536541856877_item	2705424	et	3	main
päris	doc_536541856877_item	2705431	et	4	main
toimusid	doc_536541856877_item	2705436	et	4	main
ja	doc_536541856877_item	2705445	et	3	main
pidu	doc_536541856877_item	2705447	et	4	main
kõik	doc_536541856877_item	2705451	et	4	main
tansesid	doc_536541856877_item	2705453	et	4	main
tegid	doc_536541856877_item	2705454	et	4	main
on	doc_536541856877_item	2705483	et	4	main
1869	doc_536541856877_item	2705490	et	2	main
aastal	doc_536541856877_item	2705491	et	3	main
kujunes	doc_536541856877_item	2705492	et	3	main
esimene	doc_536541856877_item	2705493	et	3	main
ülemaaline	doc_536541856877_item	2705494	et	4	main
laulupidu	doc_536541856877_item	2705495	et	4	main
mis	doc_536541856877_item	2705496	et	4	main
toimus	doc_536541856877_item	2705497	et	3	main
tartus	doc_536541856877_item	2705498	et	3	main
laulupeo	doc_536541856877_item	2705499	et	4	main
korraldamis	doc_536541856877_item	2705500	et	4	main
idee	doc_536541856877_item	2705501	et	4	main
oli	doc_536541856877_item	2705502	et	3	main
lydia	doc_536541856877_item	2705503	et	4	main
koidula	doc_536541856877_item	2705504	et	4	main
isa	doc_536541856877_item	2705505	et	4	main
johann	doc_536541856877_item	2705506	et	4	main
jannseni	doc_536541856877_item	2705508	et	4	main
voldemar	doc_536541856877_item	2705507	et	4	main
hiljem	doc_536541856877_item	2705509	et	3	main
1896	doc_536541856877_item	2705510	et	2	main
aastalt	doc_536541856877_item	2705511	et	3	main
hakkas	doc_536541856877_item	2705512	et	3	main
laulupidu	doc_536541856877_item	2705513	et	4	main
toimuma	doc_536541856877_item	2705514	et	3	main
tallinnas	doc_536541856877_item	2705515	et	4	main
täna	doc_536541856877_item	2705516	et	4	main
ajal	doc_536541856877_item	2705517	et	4	main
laulupeole	doc_536541856877_item	2705518	et	4	main
tulevad	doc_536541856877_item	2705519	et	4	main
eestist	doc_536541856877_item	2705520	et	3	main
välismaal	doc_536541856877_item	2705523	et	4	main
laulmine	doc_536541856877_item	2705524	et	4	main
arvan	doc_536541856877_item	2705530	et	3	main
nende	doc_536541856877_item	2705534	et	4	main
on	doc_536541856877_item	2705536	et	4	main
väga	doc_536541856877_item	2705537	et	3	main
tore	doc_536541856877_item	2705538	et	3	main
et	doc_536541856877_item	2705539	et	3	main
noored	doc_536541856877_item	2705540	et	3	main
laulude	doc_536541856877_item	2705548	et	3	main
arvan	doc_536541856877_item	2705552	et	3	main
koorid	doc_536541856877_item	2705425	et	4	main
laulsid	doc_536541856877_item	2705427	et	4	main
eestlastel	doc_536541856877_item	2705429	et	4	main
peod	doc_536541856877_item	2705433	et	4	main
neid	doc_536541856877_item	2705434	et	4	main
tansiga	doc_536541856877_item	2705439	et	4	main
vanal	doc_536541856877_item	2705440	et	3	main
laulu	doc_536541856877_item	2705444	et	4	main
oli	doc_536541856877_item	2705448	et	3	main
jaanipäeval	doc_536541856877_item	2705450	et	3	main
laulsid	doc_536541856877_item	2705452	et	4	main
peal	doc_536541856877_item	2705458	et	4	main
pidu	doc_536541856877_item	2705460	et	4	main
on	doc_536541856877_item	2705461	et	4	main
olemas	doc_536541856877_item	2705467	et	4	main
ansamblid	doc_536541856877_item	2705468	et	3	main
see	doc_536541856877_item	2705475	et	3	main
ole	doc_536541856877_item	2705477	et	4	main
pidu	doc_536541856877_item	2705479	et	4	main
laulupidu	doc_536541856877_item	2705485	et	4	main
kui	doc_536541856877_item	2705521	et	3	main
ma	doc_536541856877_item	2705529	et	3	main
laulavad	doc_536541856877_item	2705541	et	4	main
veel	doc_536541856877_item	2705484	et	4	main
on	doc_536541856877_item	2705525	et	4	main
väga	doc_536541856877_item	2705526	et	3	main
oluline	doc_536541856877_item	2705527	et	4	main
et	doc_536541856877_item	2705531	et	3	main
rahvalaule	doc_536541856877_item	2705543	et	4	main
eestlased	doc_536541856877_item	2705544	et	3	main
nii	doc_536541856877_item	2705545	et	3	main
jaoks	doc_536541856877_item	2705549	et	4	main
ma	doc_536541856877_item	2705551	et	3	main
eestlastele	doc_536541856877_item	2705528	et	4	main
ka	doc_536541856877_item	2705542	et	3	main
palju	doc_536541856877_item	2705546	et	4	main
tegid	doc_536541856877_item	2705547	et	4	main
on	doc_536541856877_item	2705554	et	4	main
laulurahv	doc_536541856877_item	2705555	et	4	main
teemal	doc_536541856883_item	2707070	et	3	main
laulurahva	doc_536541856883_item	2707074	et	3	main
sõna	doc_536541856883_item	2707079	et	4	main
analüüsiv	doc_536541856883_item	2707084	et	4	main
loengus	doc_536541856883_item	2707088	et	3	main
esitatud	doc_536541856883_item	2707091	et	4	main
keele	doc_536541856883_item	2707062	et	4	main
kui	doc_536541856883_item	2707063	et	3	main
teise	doc_536541856883_item	2707064	et	4	main
pikkus	doc_536541856883_item	2707076	et	4	main
300	doc_536541856883_item	2707077	et	2	main
350	doc_536541856883_item	2707078	et	2	main
peab	doc_536541856883_item	2707081	et	4	main
olema	doc_536541856883_item	2707082	et	4	main
olulisemaid	doc_536541856883_item	2707122	et	4	main
see	doc_536541856883_item	2707124	et	3	main
tantsud	doc_536541856883_item	2707133	et	3	main
tähelepanuväärsed	doc_536541856883_item	2707135	et	3	main
eestis	doc_536541856883_item	2707137	et	3	main
eesti	doc_536541856883_item	2707140	et	4	main
rahvalaul	doc_536541856883_item	2707141	et	4	main
1869	doc_536541856883_item	2707153	et	2	main
oli	doc_536541856883_item	2707167	et	3	main
j	doc_536541856883_item	2707168	et	4	main
et	doc_536541856883_item	2707173	et	3	main
tähtsus	doc_536541856883_item	2707176	et	4	main
on	doc_536541856883_item	2707177	et	4	main
väga	doc_536541856883_item	2707178	et	3	main
oluline	doc_536541856883_item	2707179	et	4	main
liikumise	doc_536541856883_item	2707185	et	4	main
kõrghetk	doc_536541856883_item	2707186	et	3	main
ja	doc_536541856883_item	2707187	et	3	main
sai	doc_536541856883_item	2707188	et	4	main
alguse	doc_536541856883_item	2707189	et	3	main
veel	doc_536541856883_item	2707193	et	4	main
rahvalaulupidu	doc_536541856883_item	2707202	et	4	main
selle	doc_536541856883_item	2707208	et	4	main
laulurahva	doc_536541856883_item	2707224	et	3	main
kuhu	doc_536541856883_item	2707230	et	3	main
tullakse	doc_536541856883_item	2707231	et	3	main
koos	doc_536541856883_item	2707232	et	4	main
laulavad	doc_536541856883_item	2707240	et	4	main
tansivad	doc_536541856883_item	2707241	et	4	main
arendavad	doc_536541856883_item	2707246	et	4	main
laulakse	doc_536541856883_item	2707253	et	4	main
juba	doc_536541856883_item	2707255	et	3	main
läbi	doc_536541856883_item	2707256	et	4	main
aja	doc_536541856883_item	2707257	et	4	main
rahvastele	doc_536541856883_item	2707269	et	4	main
tantsud	doc_536541856883_item	2707272	et	3	main
ja	doc_536541856883_item	2707278	et	3	main
on	doc_536541856883_item	2707284	et	4	main
laulurahvas	doc_536541856883_item	2707285	et	4	main
juba	doc_536541856883_item	2707286	et	3	main
ammu	doc_536541856883_item	2707287	et	4	main
inimesed	doc_536541856883_item	2707325	et	3	main
essee	doc_536541856883_item	2707060	et	4	main
eesti	doc_536541856883_item	2707061	et	4	main
essee	doc_536541856883_item	2707069	et	4	main
üldistav	doc_536541856883_item	2707086	et	4	main
tuginema	doc_536541856883_item	2707087	et	3	main
lugemistekstis	doc_536541856883_item	2707090	et	3	main
faktidele	doc_536541856883_item	2707092	et	3	main
levinud	doc_536541856883_item	2707129	et	4	main
kui	doc_536541856883_item	2707145	et	3	main
esimene	doc_536541856883_item	2707149	et	3	main
laulupidu	doc_536541856883_item	2707151	et	4	main
juht	doc_536541856883_item	2707166	et	3	main
esimese	doc_536541856883_item	2707174	et	3	main
kujunes	doc_536541856883_item	2707182	et	3	main
eestlaste	doc_536541856883_item	2707183	et	4	main
rahvusliku	doc_536541856883_item	2707184	et	3	main
traditsioon	doc_536541856883_item	2707191	et	3	main
näiteks	doc_536541856883_item	2707198	et	4	main
kõige	doc_536541856883_item	2707204	et	4	main
tähelepanuväärsem	doc_536541856883_item	2707205	et	4	main
sündmus	doc_536541856883_item	2707206	et	3	main
eestis	doc_536541856883_item	2707207	et	3	main
ka	doc_536541856883_item	2707221	et	3	main
see	doc_536541856883_item	2707226	et	3	main
on	doc_536541856883_item	2707227	et	4	main
rahvapidu	doc_536541856883_item	2707229	et	4	main
pere	doc_536541856883_item	2707233	et	4	main
sõprade	doc_536541856883_item	2707234	et	3	main
suhtlevad	doc_536541856883_item	2707242	et	4	main
laulud	doc_536541856883_item	2707250	et	3	main
öelda	doc_536541856883_item	2707264	et	4	main
et	doc_536541856883_item	2707265	et	3	main
nagu	doc_536541856883_item	2707267	et	3	main
laulmine	doc_536541856883_item	2707270	et	4	main
on	doc_536541856883_item	2707273	et	4	main
esteetilised	doc_536541856883_item	2707274	et	3	main
ja	doc_536541856883_item	2707275	et	3	main
emotsionaalsed	doc_536541856883_item	2707276	et	3	main
väljendusvahed	doc_536541856883_item	2707277	et	3	main
näiteks	doc_536541856883_item	2707288	et	4	main
kõike	doc_536541856883_item	2707321	et	4	main
elada	doc_536541856883_item	2707323	et	3	main
kui	doc_536541856883_item	2707324	et	3	main
laulavad	doc_536541856883_item	2707326	et	4	main
keele	doc_536541856883_item	2707065	et	4	main
test	doc_536541856883_item	2707066	et	3	main
mis	doc_536541856883_item	2707071	et	4	main
essee	doc_536541856883_item	2707075	et	4	main
arutlev	doc_536541856883_item	2707083	et	4	main
ja	doc_536541856883_item	2707089	et	3	main
väiteid	doc_536541856883_item	2707093	et	4	main
on	doc_536541856883_item	2707094	et	4	main
on	doc_536541856883_item	2707127	et	4	main
ja	doc_536541856883_item	2707132	et	3	main
on	doc_536541856883_item	2707134	et	4	main
esimene	doc_536541856883_item	2707139	et	3	main
kujunenud	doc_536541856883_item	2707143	et	4	main
aastat	doc_536541856883_item	2707147	et	3	main
tartus	doc_536541856883_item	2707155	et	3	main
v	doc_536541856883_item	2707169	et	4	main
sest	doc_536541856883_item	2707180	et	4	main
koorid	doc_536541856883_item	2707200	et	4	main
tänapäeval	doc_536541856883_item	2707201	et	3	main
repertuaar	doc_536541856883_item	2707210	et	3	main
on	doc_536541856883_item	2707211	et	4	main
seotud	doc_536541856883_item	2707212	et	4	main
professionaalse	doc_536541856883_item	2707213	et	3	main
heliloomingu	doc_536541856883_item	2707214	et	3	main
teeb	doc_536541856883_item	2707222	et	3	main
seal	doc_536541856883_item	2707238	et	4	main
teiste	doc_536541856883_item	2707243	et	4	main
mida	doc_536541856883_item	2707251	et	4	main
on	doc_536541856883_item	2707254	et	4	main
eestlastele	doc_536541856883_item	2707266	et	4	main
muidugi	doc_536541856883_item	2707279	et	4	main
vanal	doc_536541856883_item	2707289	et	3	main
kirjutamine	doc_536541856883_item	2707067	et	4	main
kirjutage	doc_536541856883_item	2707068	et	3	main
teeb	doc_536541856883_item	2707072	et	3	main
eestlastest	doc_536541856883_item	2707073	et	4	main
essee	doc_536541856883_item	2707080	et	4	main
ja	doc_536541856883_item	2707085	et	3	main
soovitatav	doc_536541856883_item	2707095	et	4	main
illustreerida	doc_536541856883_item	2707096	et	3	main
näidetega	doc_536541856883_item	2707097	et	3	main
ma	doc_536541856883_item	2707098	et	3	main
tahaksin	doc_536541856883_item	2707099	et	3	main
alustada	doc_536541856883_item	2707100	et	3	main
sellega	doc_536541856883_item	2707101	et	3	main
et	doc_536541856883_item	2707102	et	3	main
on	doc_536541856883_item	2707103	et	4	main
võimalik	doc_536541856883_item	2707104	et	3	main
täpsusega	doc_536541856883_item	2707105	et	4	main
öelda	doc_536541856883_item	2707106	et	4	main
et	doc_536541856883_item	2707107	et	3	main
eesti	doc_536541856883_item	2707108	et	4	main
rahvas	doc_536541856883_item	2707109	et	4	main
on	doc_536541856883_item	2707110	et	4	main
laulurahvas	doc_536541856883_item	2707111	et	4	main
ja	doc_536541856883_item	2707112	et	3	main
selle	doc_536541856883_item	2707113	et	4	main
kohta	doc_536541856883_item	2707114	et	4	main
on	doc_536541856883_item	2707115	et	4	main
väga	doc_536541856883_item	2707116	et	3	main
palju	doc_536541856883_item	2707117	et	4	main
põhjusi	doc_536541856883_item	2707118	et	3	main
minu	doc_536541856883_item	2707119	et	3	main
meelest	doc_536541856883_item	2707120	et	4	main
kõige	doc_536541856883_item	2707121	et	4	main
on	doc_536541856883_item	2707123	et	4	main
et	doc_536541856883_item	2707125	et	3	main
eestlastel	doc_536541856883_item	2707126	et	4	main
laulmine	doc_536541856883_item	2707131	et	4	main
kultuurinähtused	doc_536541856883_item	2707136	et	3	main
näiteks	doc_536541856883_item	2707138	et	4	main
enam	doc_536541856883_item	2707144	et	4	main
aastal	doc_536541856883_item	2707154	et	3	main
arvan	doc_536541856883_item	2707172	et	3	main
sellest	doc_536541856883_item	2707181	et	4	main
laulupidude	doc_536541856883_item	2707190	et	4	main
hakkas	doc_536541856883_item	2707194	et	3	main
eesti	doc_536541856883_item	2707196	et	4	main
erinevad	doc_536541856883_item	2707199	et	4	main
peo	doc_536541856883_item	2707209	et	4	main
ja	doc_536541856883_item	2707215	et	3	main
koorilauluga	doc_536541856883_item	2707216	et	4	main
eestlastest	doc_536541856883_item	2707223	et	4	main
sugulaste	doc_536541856883_item	2707235	et	4	main
ja	doc_536541856883_item	2707236	et	3	main
tuttavatega	doc_536541856883_item	2707237	et	3	main
väga	doc_536541856883_item	2707128	et	3	main
laulutraditsioonid	doc_536541856883_item	2707130	et	3	main
on	doc_536541856883_item	2707142	et	4	main
tuhat	doc_536541856883_item	2707146	et	4	main
tagasi	doc_536541856883_item	2707148	et	3	main
ülemaaline	doc_536541856883_item	2707150	et	4	main
oli	doc_536541856883_item	2707152	et	3	main
mille	doc_536541856883_item	2707156	et	3	main
korraldamise	doc_536541856883_item	2707157	et	4	main
idee	doc_536541856883_item	2707158	et	4	main
ja	doc_536541856883_item	2707159	et	3	main
teostus	doc_536541856883_item	2707160	et	4	main
tuli	doc_536541856883_item	2707161	et	4	main
vanemuise	doc_536541856883_item	2707162	et	4	main
seltsist	doc_536541856883_item	2707163	et	4	main
selle	doc_536541856883_item	2707164	et	4	main
seltsi	doc_536541856883_item	2707165	et	4	main
jannsen	doc_536541856883_item	2707170	et	4	main
ma	doc_536541856883_item	2707171	et	3	main
laulupeo	doc_536541856883_item	2707175	et	4	main
ja	doc_536541856883_item	2707192	et	3	main
arenema	doc_536541856883_item	2707195	et	3	main
laulukunst	doc_536541856883_item	2707197	et	3	main
on	doc_536541856883_item	2707203	et	4	main
ma	doc_536541856883_item	2707217	et	3	main
arvan	doc_536541856883_item	2707218	et	3	main
et	doc_536541856883_item	2707219	et	3	main
laulupidu	doc_536541856883_item	2707220	et	4	main
sest	doc_536541856883_item	2707225	et	4	main
suur	doc_536541856883_item	2707228	et	3	main
inimestega	doc_536541856883_item	2707244	et	3	main
peol	doc_536541856883_item	2707252	et	4	main
kujunenud	doc_536541856883_item	2707258	et	4	main
rahvuslikeks	doc_536541856883_item	2707259	et	3	main
sümboliteks	doc_536541856883_item	2707260	et	3	main
ma	doc_536541856883_item	2707261	et	3	main
tahaksin	doc_536541856883_item	2707262	et	3	main
teistele	doc_536541856883_item	2707268	et	4	main
ja	doc_536541856883_item	2707271	et	3	main
ka	doc_536541856883_item	2707280	et	3	main
eestlased	doc_536541856883_item	2707283	et	3	main
ajal	doc_536541856883_item	2707290	et	4	main
laulsid	doc_536541856883_item	2707292	et	4	main
töötades	doc_536541856883_item	2707293	et	3	main
ja	doc_536541856883_item	2707294	et	3	main
isegi	doc_536541856883_item	2707295	et	4	main
ja	doc_536541856883_item	2707297	et	3	main
muidugi	doc_536541856883_item	2707298	et	4	main
kirikus	doc_536541856883_item	2707299	et	3	main
eestlased	doc_536541856883_item	2707300	et	3	main
armastavad	doc_536541856883_item	2707301	et	4	main
kiigutades	doc_536541856883_item	2707296	et	3	main
laulda	doc_536541856883_item	2707302	et	4	main
ja	doc_536541856883_item	2707303	et	3	main
tantsida	doc_536541856883_item	2707304	et	3	main
sest	doc_536541856883_item	2707305	et	4	main
see	doc_536541856883_item	2707306	et	3	main
annab	doc_536541856883_item	2707307	et	3	main
hea	doc_536541856883_item	2707308	et	4	main
tuju	doc_536541856883_item	2707309	et	4	main
eesti	doc_536541856883_item	2707310	et	4	main
elus	doc_536541856883_item	2707311	et	4	main
on	doc_536541856883_item	2707312	et	4	main
olnud	doc_536541856883_item	2707313	et	4	main
väga	doc_536541856883_item	2707314	et	3	main
palju	doc_536541856883_item	2707315	et	4	main
raskusi	doc_536541856883_item	2707316	et	4	main
laulmine	doc_536541856883_item	2707317	et	4	main
annab	doc_536541856883_item	2707318	et	3	main
võimalusi	doc_536541856883_item	2707319	et	3	main
seda	doc_536541856883_item	2707320	et	3	main
on	doc_536541856883_item	2707331	et	4	main
inimesed	doc_536541856883_item	2707239	et	3	main
ja	doc_536541856883_item	2707245	et	3	main
oma	doc_536541856883_item	2707247	et	4	main
silmaringi	doc_536541856883_item	2707248	et	4	main
need	doc_536541856883_item	2707249	et	3	main
veel	doc_536541856883_item	2707263	et	4	main
sotsiaalne	doc_536541856883_item	2707281	et	3	main
tegevus	doc_536541856883_item	2707282	et	4	main
nad	doc_536541856883_item	2707291	et	3	main
suhtlevad	doc_536541856883_item	2707329	et	4	main
on	doc_536541856883_item	2707334	et	4	main
läbi	doc_536541856883_item	2707322	et	4	main
nad	doc_536541856883_item	2707330	et	3	main
nad	doc_536541856883_item	2707333	et	3	main
tantsivad	doc_536541856883_item	2707327	et	4	main
ja	doc_536541856883_item	2707328	et	3	main
koos	doc_536541856883_item	2707332	et	4	main
rahvas	doc_536541856883_item	2707335	et	4	main
eesti	doc_536541856887_item	2708200	et	4	main
keele	doc_536541856887_item	2708201	et	4	main
test	doc_536541856887_item	2708205	et	3	main
kirjutamine	doc_536541856887_item	2708206	et	4	main
kirjutage	doc_536541856887_item	2708207	et	3	main
essee	doc_536541856887_item	2708208	et	4	main
teemal	doc_536541856887_item	2708209	et	3	main
olema	doc_536541856887_item	2708221	et	4	main
analüüsiv	doc_536541856887_item	2708223	et	4	main
ja	doc_536541856887_item	2708224	et	3	main
lugemistekstis	doc_536541856887_item	2708229	et	3	main
esitatud	doc_536541856887_item	2708230	et	4	main
väiteid	doc_536541856887_item	2708232	et	4	main
on	doc_536541856887_item	2708233	et	4	main
soovitatav	doc_536541856887_item	2708234	et	4	main
illustreerida	doc_536541856887_item	2708235	et	3	main
näidetega	doc_536541856887_item	2708236	et	3	main
omab	doc_536541856887_item	2708246	et	3	main
ajalugu	doc_536541856887_item	2708248	et	4	main
tol	doc_536541856887_item	2708252	et	3	main
inimesed	doc_536541856887_item	2708255	et	3	main
kui	doc_536541856887_item	2708259	et	3	main
teise	doc_536541856887_item	2708203	et	4	main
essee	doc_536541856887_item	2708214	et	4	main
pikkus	doc_536541856887_item	2708215	et	4	main
300	doc_536541856887_item	2708216	et	2	main
350	doc_536541856887_item	2708217	et	2	main
sõna	doc_536541856887_item	2708218	et	4	main
loengus	doc_536541856887_item	2708227	et	3	main
eestlastest	doc_536541856887_item	2708239	et	4	main
laulurahva	doc_536541856887_item	2708240	et	3	main
eesti	doc_536541856887_item	2708241	et	4	main
teisedki	doc_536541856887_item	2708245	et	4	main
mis	doc_536541856887_item	2708249	et	4	main
ajal	doc_536541856887_item	2708253	et	4	main
muud	doc_536541856887_item	2708258	et	4	main
põllul	doc_536541856887_item	2708263	et	3	main
karjas	doc_536541856887_item	2708265	et	3	main
et	doc_536541856887_item	2708267	et	3	main
oma	doc_536541856887_item	2708268	et	4	main
ja	doc_536541856887_item	2708275	et	3	main
regivärsiline	doc_536541856887_item	2708282	et	4	main
põlvest	doc_536541856887_item	2708288	et	4	main
suuliselt	doc_536541856887_item	2708290	et	4	main
tuginedes	doc_536541856887_item	2708291	et	3	main
ajaloole	doc_536541856887_item	2708295	et	4	main
essee	doc_536541856887_item	2708199	et	4	main
kui	doc_536541856887_item	2708202	et	3	main
mis	doc_536541856887_item	2708210	et	4	main
teeb	doc_536541856887_item	2708211	et	3	main
essee	doc_536541856887_item	2708219	et	4	main
arutlev	doc_536541856887_item	2708222	et	4	main
üldistav	doc_536541856887_item	2708225	et	4	main
mis	doc_536541856887_item	2708237	et	4	main
kõik	doc_536541856887_item	2708244	et	4	main
elasid	doc_536541856887_item	2708254	et	4	main
raske	doc_536541856887_item	2708261	et	4	main
kõkjal	doc_536541856887_item	2708272	et	4	main
seda	doc_536541856887_item	2708278	et	3	main
pärindatud	doc_536541856887_item	2708287	et	4	main
põlve	doc_536541856887_item	2708289	et	4	main
mälule	doc_536541856887_item	2708292	et	3	main
võeti	doc_536541856887_item	2708322	et	3	main
mõju	doc_536541856887_item	2708325	et	4	main
enda	doc_536541856887_item	2708326	et	4	main
on	doc_536541856887_item	2708351	et	4	main
viibis	doc_536541856887_item	2708368	et	3	main
1869	doc_536541856887_item	2708377	et	2	main
ja	doc_536541856887_item	2708388	et	3	main
aeg	doc_536541856887_item	2708392	et	3	main
eesti	doc_536541856887_item	2708397	et	4	main
ühendust	doc_536541856887_item	2708404	et	4	main
eriti	doc_536541856887_item	2708405	et	3	main
meeliülendavaks	doc_536541856887_item	2708406	et	3	main
rahvusliku	doc_536541856887_item	2708419	et	3	main
paljud	doc_536541856887_item	2708426	et	3	main
kasutanud	doc_536541856887_item	2708436	et	4	main
ka	doc_536541856887_item	2708437	et	3	main
eesti	doc_536541856887_item	2708443	et	4	main
ajalugu	doc_536541856887_item	2708444	et	4	main
rahvas	doc_536541856887_item	2708450	et	4	main
keda	doc_536541856887_item	2708451	et	4	main
nimetada	doc_536541856887_item	2708453	et	3	main
lauludest	doc_536541856887_item	2708455	et	3	main
kommetest	doc_536541856887_item	2708459	et	4	main
ja	doc_536541856887_item	2708460	et	3	main
ei	doc_536541856887_item	2708474	et	4	main
palju	doc_536541856887_item	2708479	et	4	main
koore	doc_536541856887_item	2708481	et	4	main
mis	doc_536541856887_item	2708482	et	4	main
selliseid	doc_536541856887_item	2708489	et	4	main
koori	doc_536541856887_item	2708490	et	4	main
kihnus	doc_536541856887_item	2708495	et	3	main
et	doc_536541856887_item	2708499	et	3	main
meelega	doc_536541856887_item	2708522	et	4	main
sellega	doc_536541856887_item	2708524	et	3	main
keele	doc_536541856888_item	2708531	et	4	main
kirjutamine	doc_536541856888_item	2708533	et	4	main
laulurahva	doc_536541856888_item	2708540	et	3	main
essee	doc_536541856888_item	2708541	et	4	main
pikkus	doc_536541856888_item	2708542	et	4	main
300	doc_536541856888_item	2708543	et	2	main
350	doc_536541856888_item	2708544	et	2	main
olema	doc_536541856888_item	2708548	et	4	main
tuginema	doc_536541856888_item	2708553	et	3	main
väiteid	doc_536541856888_item	2708559	et	4	main
soovitatav	doc_536541856888_item	2708561	et	4	main
suure	doc_536541856888_item	2708570	et	3	main
riik	doc_536541856888_item	2708576	et	3	main
laul	doc_536541856888_item	2708580	et	4	main
mehed	doc_536541856888_item	2708588	et	3	main
keele	doc_536541856887_item	2708204	et	4	main
tuginema	doc_536541856887_item	2708226	et	3	main
faktidele	doc_536541856887_item	2708231	et	3	main
rahvas	doc_536541856887_item	2708242	et	4	main
nagu	doc_536541856887_item	2708243	et	3	main
omapärase	doc_536541856887_item	2708247	et	4	main
ammu-ammu	doc_536541856887_item	2708251	et	4	main
ja	doc_536541856887_item	2708257	et	3	main
tuju	doc_536541856887_item	2708269	et	4	main
lapsi	doc_536541856887_item	2708276	et	4	main
iseloomustab	doc_536541856887_item	2708281	et	4	main
rahvalaul	doc_536541856887_item	2708283	et	4	main
laulud	doc_536541856887_item	2708285	et	3	main
on	doc_536541856887_item	2708286	et	4	main
nad	doc_536541856887_item	2708323	et	3	main
nende	doc_536541856887_item	2708324	et	4	main
soome	doc_536541856887_item	2708331	et	3	main
tekkisid	doc_536541856887_item	2708335	et	4	main
iseloomustab	doc_536541856887_item	2708340	et	4	main
ülestähendus	doc_536541856887_item	2708342	et	3	main
salmialbumid	doc_536541856887_item	2708345	et	3	main
trükitult	doc_536541856887_item	2708347	et	4	main
või	doc_536541856887_item	2708348	et	4	main
käsitsi	doc_536541856887_item	2708349	et	3	main
laulud	doc_536541856887_item	2708350	et	3	main
linnas	doc_536541856887_item	2708357	et	4	main
aastal	doc_536541856887_item	2708378	et	3	main
ühendamiseks	doc_536541856887_item	2708387	et	4	main
vabadusetundmiseks	doc_536541856887_item	2708389	et	3	main
sest	doc_536541856887_item	2708390	et	4	main
väga	doc_536541856887_item	2708394	et	3	main
vabadust	doc_536541856887_item	2708402	et	4	main
ja	doc_536541856887_item	2708403	et	3	main
hingestatud	doc_536541856887_item	2708410	et	4	main
arm	doc_536541856887_item	2708416	et	3	main
hakkasid	doc_536541856887_item	2708428	et	4	main
mõjutas	doc_536541856887_item	2708445	et	3	main
seda	doc_536541856887_item	2708446	et	3	main
eestlastest	doc_536541856887_item	2708448	et	4	main
on	doc_536541856887_item	2708463	et	4	main
ajaga	doc_536541856887_item	2708476	et	3	main
aega	doc_536541856887_item	2708485	et	4	main
just	doc_536541856887_item	2708486	et	3	main
laulmiseks	doc_536541856887_item	2708488	et	4	main
tähendab	doc_536541856887_item	2708497	et	3	main
seda	doc_536541856887_item	2708498	et	3	main
eestlastest	doc_536541856887_item	2708212	et	4	main
laulurahva	doc_536541856887_item	2708213	et	3	main
peab	doc_536541856887_item	2708220	et	4	main
ja	doc_536541856887_item	2708228	et	3	main
teeb	doc_536541856887_item	2708238	et	3	main
algas	doc_536541856887_item	2708250	et	3	main
maal	doc_536541856887_item	2708256	et	4	main
tegelesid	doc_536541856887_item	2708260	et	4	main
või	doc_536541856887_item	2708264	et	4	main
selleks	doc_536541856887_item	2708266	et	4	main
tööl	doc_536541856887_item	2708273	et	3	main
puhkamisel	doc_536541856887_item	2708274	et	4	main
kiigutades	doc_536541856887_item	2708277	et	3	main
vanemat	doc_536541856887_item	2708279	et	4	main
traditsioonile	doc_536541856887_item	2708293	et	3	main
ristiuskuga	doc_536541856887_item	2708296	et	4	main
ilmnesid	doc_536541856887_item	2708297	et	4	main
vaimulikud	doc_536541856887_item	2708298	et	3	main
laulud	doc_536541856887_item	2708299	et	3	main
mis	doc_536541856887_item	2708300	et	4	main
levisid	doc_536541856887_item	2708301	et	4	main
ka	doc_536541856887_item	2708302	et	3	main
väljaspool	doc_536541856887_item	2708303	et	3	main
kirikut	doc_536541856887_item	2708304	et	3	main
näiteks	doc_536541856887_item	2708305	et	4	main
koolides	doc_536541856887_item	2708306	et	3	main
õpetati	doc_536541856887_item	2708307	et	3	main
vaimulikke	doc_536541856887_item	2708308	et	3	main
koorilaule	doc_536541856887_item	2708309	et	4	main
19	doc_536541856887_item	2708310	et	2	main
sajandil	doc_536541856887_item	2708311	et	3	main
kui	doc_536541856887_item	2708312	et	3	main
eestlased	doc_536541856887_item	2708313	et	3	main
hakkasid	doc_536541856887_item	2708314	et	4	main
suhtlema	doc_536541856887_item	2708315	et	3	main
euroopa	doc_536541856887_item	2708316	et	4	main
riikidega	doc_536541856887_item	2708317	et	3	main
ja	doc_536541856887_item	2708318	et	3	main
venemaaga	doc_536541856887_item	2708319	et	3	main
siis	doc_536541856887_item	2708320	et	3	main
muidugi	doc_536541856887_item	2708321	et	4	main
rootsi	doc_536541856887_item	2708330	et	4	main
ja	doc_536541856887_item	2708332	et	3	main
riimilised	doc_536541856887_item	2708336	et	4	main
neid	doc_536541856887_item	2708338	et	4	main
tihedalt	doc_536541856887_item	2708352	et	4	main
seotud	doc_536541856887_item	2708353	et	4	main
rahvusliku	doc_536541856887_item	2708354	et	3	main
selles	doc_536541856887_item	2708369	et	4	main
et	doc_536541856887_item	2708370	et	3	main
hakati	doc_536541856887_item	2708371	et	3	main
tartus	doc_536541856887_item	2708379	et	3	main
laulupeod	doc_536541856887_item	2708381	et	4	main
olnud	doc_536541856887_item	2708383	et	4	main
meelelahutamisek	doc_536541856887_item	2708384	et	4	main
vaid	doc_536541856887_item	2708385	et	3	main
rahva	doc_536541856887_item	2708386	et	3	main
raske	doc_536541856887_item	2708395	et	4	main
kõlas	doc_536541856887_item	2708407	et	4	main
tööga	doc_536541856887_item	2708262	et	3	main
tõsta	doc_536541856887_item	2708270	et	4	main
lauldi	doc_536541856887_item	2708271	et	3	main
laulutraditsiooni	doc_536541856887_item	2708280	et	4	main
sest	doc_536541856887_item	2708284	et	4	main
ja	doc_536541856887_item	2708294	et	3	main
muusikasse	doc_536541856887_item	2708327	et	4	main
eelkõige	doc_536541856887_item	2708328	et	3	main
mõjutas	doc_536541856887_item	2708329	et	3	main
niimoodi	doc_536541856887_item	2708334	et	3	main
rahvalaulu	doc_536541856887_item	2708339	et	4	main
laulupidusid	doc_536541856887_item	2708372	et	4	main
korraldama	doc_536541856887_item	2708373	et	3	main
esimene	doc_536541856887_item	2708374	et	3	main
toimus	doc_536541856887_item	2708376	et	3	main
esimesed	doc_536541856887_item	2708380	et	3	main
oli	doc_536541856887_item	2708393	et	3	main
pidi	doc_536541856887_item	2708399	et	4	main
isamaalaul	doc_536541856887_item	2708411	et	4	main
mu	doc_536541856887_item	2708412	et	3	main
isamaa	doc_536541856887_item	2708413	et	4	main
on	doc_536541856887_item	2708414	et	4	main
minu	doc_536541856887_item	2708415	et	3	main
identiteedi	doc_536541856887_item	2708420	et	4	main
hoidjaks	doc_536541856887_item	2708421	et	4	main
sajanditel	doc_536541856887_item	2708425	et	3	main
heliloojad	doc_536541856887_item	2708427	et	3	main
rahvalaule	doc_536541856887_item	2708430	et	4	main
töös	doc_536541856887_item	2708432	et	3	main
rahvalaule	doc_536541856887_item	2708438	et	4	main
öelda	doc_536541856887_item	2708441	et	4	main
sai	doc_536541856887_item	2708449	et	4	main
laulurahvaks	doc_536541856887_item	2708454	et	3	main
teada	doc_536541856887_item	2708457	et	3	main
usk	doc_536541856887_item	2708464	et	3	main
ja	doc_536541856887_item	2708467	et	3	main
tulevikusse	doc_536541856887_item	2708468	et	4	main
tähtis	doc_536541856887_item	2708469	et	4	main
praegu	doc_536541856887_item	2708477	et	3	main
erinevaid	doc_536541856887_item	2708480	et	4	main
on	doc_536541856887_item	2708491	et	4	main
see	doc_536541856887_item	2708496	et	3	main
keele	doc_536541856888_item	2708528	et	4	main
kui	doc_536541856888_item	2708529	et	3	main
teemal	doc_536541856888_item	2708536	et	3	main
teeb	doc_536541856888_item	2708538	et	3	main
ja	doc_536541856888_item	2708555	et	3	main
esitatud	doc_536541856888_item	2708557	et	4	main
kuid	doc_536541856888_item	2708569	et	4	main
ning	doc_536541856888_item	2708571	et	3	main
rika	doc_536541856888_item	2708572	et	4	main
kultuuriga	doc_536541856888_item	2708573	et	4	main
ja	doc_536541856888_item	2708574	et	3	main
saatis	doc_536541856888_item	2708579	et	3	main
eestlast	doc_536541856888_item	2708581	et	4	main
hällist	doc_536541856888_item	2708582	et	4	main
hauani	doc_536541856888_item	2708583	et	3	main
kogu	doc_536541856888_item	2708584	et	4	main
regivärsilisi	doc_536541856888_item	2708592	et	4	main
oli	doc_536541856888_item	2708596	et	3	main
töötada	doc_536541856888_item	2708598	et	3	main
kui	doc_536541856888_item	2708633	et	3	main
see	doc_536541856888_item	2708639	et	3	main
mitu	doc_536541856888_item	2708641	et	4	main
mina	doc_536541856888_item	2708644	et	4	main
tantsisin	doc_536541856888_item	2708645	et	3	main
koreograafiaansamblis	doc_536541856888_item	2708646	et	4	main
mille	doc_536541856888_item	2708647	et	3	main
ja	doc_536541856888_item	2708651	et	3	main
esineda	doc_536541856888_item	2708654	et	3	main
ere	doc_536541856888_item	2708659	et	3	main
päev	doc_536541856888_item	2708662	et	3	main
et	doc_536541856888_item	2708665	et	3	main
suur	doc_536541856888_item	2708672	et	3	main
pere	doc_536541856888_item	2708674	et	4	main
veel	doc_536541856888_item	2708676	et	4	main
toimub	doc_536541856888_item	2708679	et	3	main
väga-väga	doc_536541856888_item	2708681	et	3	main
tähtis	doc_536541856888_item	2708682	et	4	main
sündmus	doc_536541856888_item	2708683	et	3	main
ning	doc_536541856888_item	2708684	et	3	main
slaavimuusika	doc_536541856887_item	2708333	et	4	main
rahvalaulud	doc_536541856887_item	2708337	et	3	main
kirjalik	doc_536541856887_item	2708341	et	3	main
laululehed	doc_536541856887_item	2708343	et	3	main
ja	doc_536541856887_item	2708344	et	3	main
levisid	doc_536541856887_item	2708346	et	4	main
ärkamisega	doc_536541856887_item	2708355	et	4	main
nii	doc_536541856887_item	2708356	et	3	main
kui	doc_536541856887_item	2708358	et	3	main
maal	doc_536541856887_item	2708359	et	4	main
19	doc_536541856887_item	2708360	et	2	main
sajandi	doc_536541856887_item	2708361	et	3	main
toimusid	doc_536541856887_item	2708363	et	4	main
erinevad	doc_536541856887_item	2708364	et	4	main
algusel	doc_536541856887_item	2708362	et	4	main
eestlaste	doc_536541856887_item	2708365	et	4	main
ühislaulmised	doc_536541856887_item	2708366	et	3	main
see	doc_536541856887_item	2708367	et	3	main
pidu	doc_536541856887_item	2708375	et	4	main
ei	doc_536541856887_item	2708382	et	4	main
nõukogude	doc_536541856887_item	2708391	et	3	main
ja	doc_536541856887_item	2708396	et	3	main
rahvas	doc_536541856887_item	2708398	et	4	main
tundma	doc_536541856887_item	2708400	et	3	main
oma	doc_536541856887_item	2708401	et	4	main
ernesaksa	doc_536541856887_item	2708409	et	4	main
kujunesid	doc_536541856887_item	2708418	et	4	main
19	doc_536541856887_item	2708422	et	2	main
20	doc_536541856887_item	2708424	et	2	main
kasutama	doc_536541856887_item	2708429	et	3	main
kaasaaegsed	doc_536541856887_item	2708433	et	3	main
helinaid	doc_536541856887_item	2708439	et	3	main
võib	doc_536541856887_item	2708440	et	3	main
et	doc_536541856887_item	2708442	et	3	main
traditsioonidest	doc_536541856887_item	2708461	et	3	main
laulud	doc_536541856887_item	2708462	et	3	main
rahvasse	doc_536541856887_item	2708466	et	3	main
on	doc_536541856887_item	2708470	et	4	main
see	doc_536541856887_item	2708471	et	3	main
et	doc_536541856887_item	2708472	et	3	main
rahvalaulud	doc_536541856887_item	2708473	et	3	main
pühendasid	doc_536541856887_item	2708483	et	4	main
ja	doc_536541856887_item	2708494	et	3	main
essee	doc_536541856888_item	2708526	et	4	main
kirjutage	doc_536541856888_item	2708534	et	3	main
mis	doc_536541856888_item	2708537	et	4	main
eestlastest	doc_536541856888_item	2708539	et	4	main
arutlev	doc_536541856888_item	2708549	et	4	main
loengus	doc_536541856888_item	2708554	et	3	main
lugemistekstis	doc_536541856888_item	2708556	et	3	main
on	doc_536541856888_item	2708560	et	4	main
illustreerida	doc_536541856888_item	2708562	et	3	main
näidetega	doc_536541856888_item	2708563	et	3	main
eestimaa	doc_536541856888_item	2708564	et	4	main
vanal	doc_536541856888_item	2708577	et	3	main
ja	doc_536541856888_item	2708587	et	3	main
laulsid	doc_536541856888_item	2708589	et	4	main
kergem	doc_536541856888_item	2708597	et	4	main
ja	doc_536541856888_item	2708599	et	3	main
tegeleda	doc_536541856888_item	2708601	et	3	main
eesti	doc_536541856888_item	2708604	et	4	main
on	doc_536541856888_item	2708611	et	4	main
olnud	doc_536541856888_item	2708612	et	4	main
päevat	doc_536541856888_item	2708632	et	4	main
esimest	doc_536541856888_item	2708635	et	4	main
on	doc_536541856888_item	2708649	et	4	main
tantsijad	doc_536541856888_item	2708669	et	4	main
armas	doc_536541856888_item	2708673	et	3	main
ja	doc_536541856888_item	2708675	et	3	main
mingi	doc_536541856888_item	2708680	et	4	main
venelane	doc_536541856888_item	2708690	et	3	main
vanemad	doc_536541856888_item	2708692	et	4	main
on	doc_536541856888_item	2708703	et	4	main
nii	doc_536541856888_item	2708704	et	3	main
uskumatu	doc_536541856888_item	2708705	et	4	main
tore	doc_536541856888_item	2708707	et	3	main
tundus	doc_536541856888_item	2708711	et	3	main
on	doc_536541856888_item	2708721	et	4	main
eestlaste	doc_536541856888_item	2708724	et	4	main
laulud	doc_536541856888_item	2708725	et	3	main
üldse	doc_536541856888_item	2708728	et	3	main
karda	doc_536541856888_item	2708744	et	4	main
mitte	doc_536541856888_item	2708750	et	3	main
lauldes	doc_536541856888_item	2708778	et	3	main
kasutavat	doc_536541856888_item	2708779	et	4	main
ka	doc_536541856888_item	2708780	et	3	main
sellised	doc_536541856888_item	2708784	et	4	main
kasutavad	doc_536541856888_item	2708796	et	4	main
säilivad	doc_536541856888_item	2708817	et	4	main
ümbertöötlusi	doc_536541856888_item	2708822	et	3	main
kihnus	doc_536541856888_item	2708827	et	3	main
setul	doc_536541856888_item	2708829	et	3	main
on	doc_536541856888_item	2708837	et	4	main
tuntud	doc_536541856888_item	2708838	et	4	main
euroopas	doc_536541856888_item	2708840	et	3	main
need	doc_536541856888_item	2708842	et	3	main
5	doc_536541856888_item	2708847	et	2	main
tagasi	doc_536541856888_item	2708849	et	3	main
oma	doc_536541856888_item	2708851	et	4	main
gustav	doc_536541856887_item	2708408	et	4	main
laulupeod	doc_536541856887_item	2708417	et	4	main
ja	doc_536541856887_item	2708423	et	3	main
oma	doc_536541856887_item	2708431	et	4	main
rokkbändid	doc_536541856887_item	2708434	et	4	main
on	doc_536541856887_item	2708435	et	4	main
et	doc_536541856887_item	2708447	et	3	main
saab	doc_536541856887_item	2708452	et	3	main
saab	doc_536541856887_item	2708456	et	3	main
vanadest	doc_536541856887_item	2708458	et	3	main
endasse	doc_536541856887_item	2708465	et	4	main
surnud	doc_536541856887_item	2708475	et	4	main
on	doc_536541856887_item	2708478	et	4	main
oma	doc_536541856887_item	2708484	et	4	main
vanalaulude	doc_536541856887_item	2708487	et	3	main
setumaal	doc_536541856887_item	2708492	et	4	main
lõuna-eesti	doc_536541856887_item	2708493	et	4	main
eesti	doc_536541856887_item	2708500	et	4	main
rahvas	doc_536541856887_item	2708501	et	4	main
hindab	doc_536541856887_item	2708502	et	3	main
oma	doc_536541856887_item	2708503	et	4	main
ajalugu	doc_536541856887_item	2708504	et	4	main
oma	doc_536541856887_item	2708505	et	4	main
folkloori	doc_536541856887_item	2708506	et	4	main
ja	doc_536541856887_item	2708507	et	3	main
laule	doc_536541856887_item	2708508	et	4	main
eestlast	doc_536541856887_item	2708509	et	4	main
teeb	doc_536541856887_item	2708510	et	3	main
laulurahva	doc_536541856887_item	2708511	et	3	main
see	doc_536541856887_item	2708512	et	3	main
et	doc_536541856887_item	2708513	et	3	main
nad	doc_536541856887_item	2708514	et	3	main
on	doc_536541856887_item	2708515	et	4	main
säilinud	doc_536541856887_item	2708516	et	4	main
oma	doc_536541856887_item	2708517	et	4	main
vanalaule	doc_536541856887_item	2708518	et	4	main
siiamaani	doc_536541856887_item	2708519	et	3	main
ja	doc_536541856887_item	2708520	et	3	main
hea	doc_536541856887_item	2708521	et	4	main
tegelevad	doc_536541856887_item	2708523	et	4	main
praegugi	doc_536541856887_item	2708525	et	3	main
test	doc_536541856888_item	2708532	et	3	main
essee	doc_536541856888_item	2708546	et	4	main
peab	doc_536541856888_item	2708547	et	4	main
üldistav	doc_536541856888_item	2708552	et	4	main
väike	doc_536541856888_item	2708568	et	4	main
folklooriga	doc_536541856888_item	2708575	et	4	main
nii	doc_536541856888_item	2708595	et	3	main
praegu	doc_536541856888_item	2708603	et	3	main
rahvalaul	doc_536541856888_item	2708605	et	4	main
on	doc_536541856888_item	2708606	et	4	main
populaarne	doc_536541856888_item	2708607	et	3	main
ning	doc_536541856888_item	2708608	et	3	main
armastatud	doc_536541856888_item	2708609	et	4	main
alati	doc_536541856888_item	2708613	et	4	main
eesti	doc_536541856888_item	2708527	et	4	main
teise	doc_536541856888_item	2708530	et	4	main
essee	doc_536541856888_item	2708535	et	4	main
sõna	doc_536541856888_item	2708545	et	4	main
analüüsiv	doc_536541856888_item	2708550	et	4	main
ja	doc_536541856888_item	2708551	et	3	main
faktidele	doc_536541856888_item	2708558	et	3	main
on	doc_536541856888_item	2708565	et	4	main
noor	doc_536541856888_item	2708566	et	3	main
ja	doc_536541856888_item	2708567	et	3	main
ajal	doc_536541856888_item	2708578	et	4	main
elu	doc_536541856888_item	2708585	et	4	main
naised	doc_536541856888_item	2708586	et	3	main
lõbusaid	doc_536541856888_item	2708591	et	3	main
laule	doc_536541856888_item	2708593	et	4	main
sest	doc_536541856888_item	2708594	et	4	main
lastega	doc_536541856888_item	2708600	et	3	main
ka	doc_536541856888_item	2708602	et	3	main
rahvuslaul	doc_536541856888_item	2708610	et	4	main
väga	doc_536541856888_item	2708614	et	3	main
oluliseks	doc_536541856888_item	2708615	et	4	main
eluosaks	doc_536541856888_item	2708616	et	3	main
väga	doc_536541856888_item	2708617	et	3	main
tähtsaks	doc_536541856888_item	2708618	et	4	main
kultuurisündmuseks	doc_536541856888_item	2708619	et	3	main
pidetakse	doc_536541856888_item	2708620	et	3	main
laulupeos	doc_536541856888_item	2708638	et	4	main
oli	doc_536541856888_item	2708640	et	3	main
aastat	doc_536541856888_item	2708642	et	3	main
pääsuke	doc_536541856888_item	2708650	et	4	main
lauluväljakule	doc_536541856888_item	2708655	et	3	main
unustamatu	doc_536541856888_item	2708658	et	4	main
tore	doc_536541856888_item	2708661	et	3	main
on	doc_536541856888_item	2708670	et	4	main
mina	doc_536541856888_item	2708688	et	4	main
vene	doc_536541856888_item	2708699	et	4	main
et	doc_536541856888_item	2708708	et	3	main
et	doc_536541856888_item	2708712	et	3	main
lihtsaid	doc_536541856888_item	2708590	et	3	main
üleeestilist	doc_536541856888_item	2708621	et	4	main
mis	doc_536541856888_item	2708623	et	4	main
ma	doc_536541856888_item	2708634	et	3	main
osalesin	doc_536541856888_item	2708637	et	3	main
tagasi	doc_536541856888_item	2708643	et	3	main
kutsuti	doc_536541856888_item	2708653	et	3	main
oli	doc_536541856888_item	2708657	et	3	main
tundus	doc_536541856888_item	2708664	et	3	main
minu	doc_536541856888_item	2708671	et	3	main
ja	doc_536541856888_item	2708695	et	3	main
meie	doc_536541856888_item	2708696	et	4	main
kõik	doc_536541856888_item	2708697	et	4	main
räägime	doc_536541856888_item	2708698	et	3	main
ja	doc_536541856888_item	2708706	et	3	main
laulupeol	doc_536541856888_item	2708710	et	4	main
selles	doc_536541856888_item	2708722	et	4	main
tantsud	doc_536541856888_item	2708726	et	3	main
ja	doc_536541856888_item	2708727	et	3	main
on	doc_536541856888_item	2708730	et	4	main
mulle	doc_536541856888_item	2708737	et	4	main
inimestele	doc_536541856888_item	2708740	et	3	main
rahvuslaul	doc_536541856888_item	2708742	et	4	main
ei	doc_536541856888_item	2708743	et	4	main
praegu	doc_536541856888_item	2708747	et	3	main
põnevat	doc_536541856888_item	2708781	et	3	main
ümbertöötlused	doc_536541856888_item	2708785	et	3	main
palju	doc_536541856888_item	2708793	et	4	main
pop-ansamble	doc_536541856888_item	2708794	et	4	main
ja	doc_536541856888_item	2708799	et	3	main
ongi	doc_536541856888_item	2708801	et	4	main
eestlased	doc_536541856888_item	2708804	et	3	main
oma	doc_536541856888_item	2708806	et	4	main
folkloori	doc_536541856888_item	2708807	et	4	main
eest	doc_536541856888_item	2708810	et	4	main
folkloori	doc_536541856888_item	2708818	et	4	main
vaid	doc_536541856888_item	2708819	et	3	main
loovad	doc_536541856888_item	2708820	et	4	main
laulupidu	doc_536541856888_item	2708622	et	4	main
praegu	doc_536541856888_item	2708624	et	3	main
toimub	doc_536541856888_item	2708625	et	3	main
tallinna	doc_536541856888_item	2708626	et	4	main
lauluväljakul	doc_536541856888_item	2708627	et	3	main
väga	doc_536541856888_item	2708628	et	3	main
hästi	doc_536541856888_item	2708629	et	3	main
mäletan	doc_536541856888_item	2708630	et	3	main
toda	doc_536541856888_item	2708631	et	3	main
korda	doc_536541856888_item	2708636	et	4	main
nimetus	doc_536541856888_item	2708648	et	4	main
meid	doc_536541856888_item	2708652	et	4	main
see	doc_536541856888_item	2708656	et	3	main
ja	doc_536541856888_item	2708660	et	3	main
mulle	doc_536541856888_item	2708663	et	4	main
kõik	doc_536541856888_item	2708666	et	4	main
lauljad	doc_536541856888_item	2708667	et	4	main
ja	doc_536541856888_item	2708668	et	3	main
tundus	doc_536541856888_item	2708677	et	3	main
et	doc_536541856888_item	2708678	et	3	main
olen	doc_536541856888_item	2708689	et	3	main
mu	doc_536541856888_item	2708691	et	3	main
on	doc_536541856888_item	2708693	et	4	main
venelased	doc_536541856888_item	2708694	et	3	main
keelt	doc_536541856888_item	2708700	et	4	main
ja	doc_536541856888_item	2708701	et	3	main
see	doc_536541856888_item	2708702	et	3	main
üks	doc_536541856888_item	2708714	et	3	main
olen	doc_536541856888_item	2708713	et	3	main
perekond	doc_536541856888_item	2708715	et	3	main
eestlastega	doc_536541856888_item	2708716	et	4	main
ma	doc_536541856888_item	2708717	et	3	main
mõtlen	doc_536541856888_item	2708718	et	3	main
et	doc_536541856888_item	2708719	et	3	main
asi	doc_536541856888_item	2708720	et	4	main
ja	doc_536541856888_item	2708738	et	3	main
eesti	doc_536541856888_item	2708741	et	4	main
ja	doc_536541856888_item	2708746	et	3	main
seda	doc_536541856888_item	2708748	et	3	main
vähem	doc_536541856888_item	2708751	et	4	main
kui	doc_536541856888_item	2708752	et	3	main
nt	doc_536541856888_item	2708753	et	4	main
ansamblidesse	doc_536541856888_item	2708774	et	4	main
ja	doc_536541856888_item	2708775	et	3	main
vanade	doc_536541856888_item	2708776	et	3	main
laulde	doc_536541856888_item	2708777	et	4	main
rahvuslikku	doc_536541856888_item	2708797	et	4	main
et	doc_536541856888_item	2708803	et	3	main
rahvuslaulu	doc_536541856888_item	2708824	et	4	main
võib	doc_536541856888_item	2708825	et	3	main
ja	doc_536541856888_item	2708828	et	3	main
see	doc_536541856888_item	2708831	et	3	main
eestimaa	doc_536541856888_item	2708833	et	4	main
oma	doc_536541856888_item	2708859	et	4	main
on	doc_536541856888_item	2708884	et	4	main
laulurahvas	doc_536541856888_item	2708889	et	4	main
igavene	doc_536541856888_item	2708894	et	4	main
keele	doc_536541856889_item	2708900	et	4	main
test	doc_536541856889_item	2708901	et	3	main
kirjutamine	doc_536541856889_item	2708902	et	4	main
kirjutage	doc_536541856889_item	2708903	et	3	main
essee	doc_536541856889_item	2708915	et	4	main
nii	doc_536541856888_item	2708685	et	3	main
see	doc_536541856888_item	2708686	et	3	main
oligi	doc_536541856888_item	2708687	et	3	main
tol	doc_536541856888_item	2708709	et	3	main
folkloor	doc_536541856888_item	2708729	et	4	main
nii	doc_536541856888_item	2708731	et	3	main
armastatud	doc_536541856888_item	2708732	et	4	main
et	doc_536541856888_item	2708733	et	3	main
see	doc_536541856888_item	2708734	et	3	main
armastus	doc_536541856888_item	2708735	et	4	main
teistele	doc_536541856888_item	2708739	et	4	main
aega	doc_536541856888_item	2708745	et	4	main
laudakse	doc_536541856888_item	2708749	et	4	main
näiteks	doc_536541856888_item	2708770	et	4	main
koolides	doc_536541856888_item	2708771	et	3	main
noorukid	doc_536541856888_item	2708772	et	3	main
kogunevad	doc_536541856888_item	2708773	et	4	main
rokk-muusikat	doc_536541856888_item	2708782	et	3	main
on	doc_536541856888_item	2708786	et	4	main
huvitavad	doc_536541856888_item	2708787	et	4	main
ja	doc_536541856888_item	2708788	et	3	main
ebatavalised	doc_536541856888_item	2708789	et	4	main
eestis	doc_536541856888_item	2708790	et	3	main
on	doc_536541856888_item	2708791	et	4	main
ka	doc_536541856888_item	2708792	et	3	main
mis	doc_536541856888_item	2708795	et	4	main
muusikad	doc_536541856888_item	2708798	et	3	main
ja	doc_536541856888_item	2708808	et	3	main
hea	doc_536541856888_item	2708812	et	4	main
peremees	doc_536541856888_item	2708813	et	4	main
ning	doc_536541856888_item	2708814	et	3	main
mitte	doc_536541856888_item	2708815	et	3	main
ainult	doc_536541856888_item	2708816	et	4	main
ehtsat	doc_536541856888_item	2708823	et	3	main
uhkus	doc_536541856888_item	2708834	et	4	main
sõnad	doc_536541856888_item	2708846	et	4	main
aastat	doc_536541856888_item	2708848	et	3	main
meie	doc_536541856888_item	2708857	et	4	main
esindasime	doc_536541856888_item	2708858	et	3	main
seal	doc_536541856888_item	2708862	et	4	main
ka	doc_536541856888_item	2708864	et	3	main
tugev	doc_536541856888_item	2708886	et	4	main
eesti	doc_536541856888_item	2708891	et	4	main
keele	doc_536541856889_item	2708897	et	4	main
teise	doc_536541856889_item	2708899	et	4	main
arutlev	doc_536541856889_item	2708918	et	4	main
analüüsiv	doc_536541856889_item	2708919	et	4	main
soovitatav	doc_536541856889_item	2708930	et	4	main
illustreerida	doc_536541856889_item	2708931	et	3	main
näidetega	doc_536541856889_item	2708932	et	3	main
on	doc_536541856889_item	2708950	et	4	main
sest	doc_536541856889_item	2708953	et	4	main
pärandati	doc_536541856889_item	2708961	et	4	main
südametes	doc_536541856889_item	2708968	et	4	main
eestlased	doc_536541856889_item	2708969	et	3	main
pikk	doc_536541856889_item	2708976	et	4	main
laulutraditsioon	doc_536541856889_item	2708977	et	3	main
juba	doc_536541856889_item	2708978	et	3	main
mitu	doc_536541856889_item	2708979	et	4	main
sajandit	doc_536541856889_item	2708980	et	3	main
tagasi	doc_536541856889_item	2708981	et	3	main
regilaul	doc_536541856889_item	2708982	et	4	main
oli	doc_536541856889_item	2708983	et	3	main
tavaliselt	doc_536541856889_item	2708998	et	4	main
üksi	doc_536541856889_item	2709012	et	4	main
et	doc_536541856888_item	2708723	et	3	main
pärandab	doc_536541856888_item	2708736	et	3	main
sada	doc_536541856888_item	2708754	et	4	main
aastat	doc_536541856888_item	2708755	et	3	main
tagasi	doc_536541856888_item	2708756	et	3	main
aga	doc_536541856888_item	2708757	et	3	main
praegu	doc_536541856888_item	2708758	et	3	main
see	doc_536541856888_item	2708759	et	3	main
ikkagi	doc_536541856888_item	2708760	et	4	main
muutus	doc_536541856888_item	2708761	et	4	main
noorte	doc_536541856888_item	2708762	et	3	main
seas	doc_536541856888_item	2708763	et	4	main
on	doc_536541856888_item	2708764	et	4	main
populaarne	doc_536541856888_item	2708766	et	3	main
ka	doc_536541856888_item	2708765	et	3	main
laulda	doc_536541856888_item	2708767	et	4	main
vanu	doc_536541856888_item	2708768	et	4	main
rahvalaule	doc_536541856888_item	2708769	et	4	main
ja	doc_536541856888_item	2708783	et	3	main
see	doc_536541856888_item	2708800	et	3	main
tore	doc_536541856888_item	2708802	et	3	main
hoolitsevad	doc_536541856888_item	2708805	et	4	main
kultuuri	doc_536541856888_item	2708809	et	4	main
nagu	doc_536541856888_item	2708811	et	3	main
kuulata	doc_536541856888_item	2708826	et	4	main
ning	doc_536541856888_item	2708830	et	3	main
rahvalaul	doc_536541856888_item	2708836	et	4	main
ja	doc_536541856888_item	2708841	et	3	main
ainult	doc_536541856888_item	2708844	et	4	main
koreograafiaansambliga	doc_536541856888_item	2708852	et	4	main
bulgaarias	doc_536541856888_item	2708853	et	4	main
ja	doc_536541856888_item	2708854	et	3	main
ungaris	doc_536541856888_item	2708855	et	4	main
kus	doc_536541856888_item	2708856	et	3	main
oli	doc_536541856888_item	2708863	et	3	main
vapper	doc_536541856888_item	2708888	et	3	main
essee	doc_536541856889_item	2708895	et	4	main
mis	doc_536541856889_item	2708906	et	4	main
teeb	doc_536541856889_item	2708907	et	3	main
essee	doc_536541856889_item	2708910	et	4	main
pikkus	doc_536541856889_item	2708911	et	4	main
300	doc_536541856889_item	2708912	et	2	main
350	doc_536541856889_item	2708913	et	2	main
sõna	doc_536541856889_item	2708914	et	4	main
lugemistekstis	doc_536541856889_item	2708925	et	3	main
faktidele	doc_536541856889_item	2708927	et	3	main
väiteid	doc_536541856889_item	2708928	et	4	main
teeb	doc_536541856889_item	2708934	et	3	main
mõju	doc_536541856889_item	2708949	et	4	main
mida	doc_536541856889_item	2708960	et	4	main
elavad	doc_536541856889_item	2708966	et	4	main
inimeste	doc_536541856889_item	2708967	et	3	main
on	doc_536541856889_item	2708974	et	4	main
tõesti	doc_536541856889_item	2708975	et	3	main
eesti	doc_536541856889_item	2708986	et	4	main
ka	doc_536541856889_item	2708992	et	3	main
pulmalaule	doc_536541856889_item	2708995	et	4	main
kahekesi	doc_536541856889_item	2709013	et	3	main
kahe	doc_536541856889_item	2709014	et	3	main
eestlased	doc_536541856889_item	2709022	et	3	main
alati	doc_536541856889_item	2709033	et	4	main
rahvalaul	doc_536541856889_item	2709042	et	4	main
arenes	doc_536541856889_item	2709043	et	3	main
koos	doc_536541856889_item	2709044	et	4	main
ristiusk	doc_536541856889_item	2709051	et	3	main
et	doc_536541856889_item	2709053	et	3	main
rahvalaul	doc_536541856889_item	2709055	et	4	main
1869	doc_536541856889_item	2709060	et	2	main
aastal	doc_536541856889_item	2709061	et	3	main
tartus	doc_536541856889_item	2709062	et	3	main
korraldati	doc_536541856889_item	2709063	et	3	main
esimene	doc_536541856889_item	2709064	et	3	main
ülemaaline	doc_536541856889_item	2709065	et	4	main
loomulikult	doc_536541856889_item	2709081	et	4	main
traditsiooni	doc_536541856889_item	2709100	et	4	main
kuid	doc_536541856889_item	2709108	et	4	main
eesti	doc_536541856889_item	2709110	et	4	main
külalisi	doc_536541856889_item	2709121	et	4	main
huvi	doc_536541856889_item	2709125	et	4	main
huvitav	doc_536541856889_item	2709133	et	4	main
et	doc_536541856889_item	2709134	et	3	main
noored	doc_536541856889_item	2709135	et	3	main
samuti	doc_536541856889_item	2709136	et	3	main
tantsudest	doc_536541856889_item	2709148	et	3	main
ajal	doc_536541856889_item	2709150	et	4	main
vana	doc_536541856889_item	2709152	et	4	main
muusikute	doc_536541856889_item	2709165	et	3	main
kasutavad	doc_536541856889_item	2709180	et	4	main
eesti	doc_536541856889_item	2709184	et	4	main
ants	doc_536541856889_item	2709189	et	4	main
rahvalauludest	doc_536541856889_item	2709195	et	3	main
üle	doc_536541856889_item	2709198	et	3	main
üritused	doc_536541856889_item	2709203	et	4	main
kus	doc_536541856889_item	2709204	et	3	main
saab	doc_536541856889_item	2709205	et	3	main
tallinna	doc_536541856889_item	2709213	et	4	main
ülikooli	doc_536541856889_item	2709214	et	4	main
poolt	doc_536541856889_item	2709215	et	4	main
uusi	doc_536541856888_item	2708821	et	3	main
on	doc_536541856888_item	2708832	et	4	main
eesti	doc_536541856888_item	2708835	et	4	main
kogu	doc_536541856888_item	2708839	et	4	main
pole	doc_536541856888_item	2708843	et	3	main
suured	doc_536541856888_item	2708845	et	3	main
käisin	doc_536541856888_item	2708850	et	3	main
riiki	doc_536541856888_item	2708860	et	4	main
rahvustantsudega	doc_536541856888_item	2708861	et	3	main
palju	doc_536541856888_item	2708865	et	4	main
laste-	doc_536541856888_item	2708866	et	4	main
ja	doc_536541856888_item	2708867	et	3	main
poistekoore	doc_536541856888_item	2708868	et	4	main
tallinnast	doc_536541856888_item	2708869	et	3	main
ning	doc_536541856888_item	2708870	et	3	main
kuulajad	doc_536541856888_item	2708871	et	4	main
ja	doc_536541856888_item	2708872	et	3	main
pealtvaatajad	doc_536541856888_item	2708873	et	3	main
olid	doc_536541856888_item	2708874	et	4	main
vapustatud	doc_536541856888_item	2708875	et	4	main
ja	doc_536541856888_item	2708876	et	3	main
igal	doc_536541856888_item	2708877	et	3	main
etendusel	doc_536541856888_item	2708878	et	4	main
oli	doc_536541856888_item	2708879	et	3	main
saal	doc_536541856888_item	2708880	et	3	main
täis	doc_536541856888_item	2708881	et	4	main
inimesi	doc_536541856888_item	2708882	et	4	main
eestlased	doc_536541856888_item	2708883	et	3	main
laulurahvas	doc_536541856888_item	2708885	et	4	main
ning	doc_536541856888_item	2708890	et	3	main
on	doc_536541856888_item	2708893	et	4	main
kui	doc_536541856889_item	2708898	et	3	main
essee	doc_536541856889_item	2708904	et	4	main
teemal	doc_536541856889_item	2708905	et	3	main
peab	doc_536541856889_item	2708916	et	4	main
ja	doc_536541856889_item	2708920	et	3	main
üldistav	doc_536541856889_item	2708921	et	4	main
loengus	doc_536541856889_item	2708923	et	3	main
mis	doc_536541856889_item	2708933	et	4	main
laulurahva	doc_536541856889_item	2708936	et	3	main
võib	doc_536541856889_item	2708938	et	3	main
inimesi	doc_536541856889_item	2708940	et	4	main
põllutööl	doc_536541856889_item	2708944	et	3	main
ja	doc_536541856889_item	2708945	et	3	main
pulmas	doc_536541856889_item	2708946	et	3	main
eriti	doc_536541856889_item	2708947	et	3	main
tugev	doc_536541856889_item	2708948	et	4	main
rahvalaulul	doc_536541856889_item	2708952	et	3	main
see	doc_536541856889_item	2708954	et	3	main
põlvest	doc_536541856889_item	2708962	et	4	main
põlve	doc_536541856889_item	2708963	et	4	main
ja	doc_536541856889_item	2708964	et	3	main
enamasti	doc_536541856889_item	2708987	et	4	main
mehed	doc_536541856889_item	2708993	et	3	main
alustas	doc_536541856889_item	2709000	et	3	main
ja	doc_536541856889_item	2709002	et	3	main
koor	doc_536541856889_item	2709006	et	4	main
kuid	doc_536541856889_item	2709007	et	4	main
mõnikord	doc_536541856889_item	2709008	et	3	main
lauldi	doc_536541856889_item	2709009	et	3	main
ka	doc_536541856889_item	2709010	et	3	main
eeslauljata	doc_536541856889_item	2709011	et	3	main
elu	doc_536541856889_item	2709027	et	4	main
end	doc_536541856889_item	2709032	et	4	main
riimilised	doc_536541856889_item	2709039	et	4	main
rahvalaulud	doc_536541856889_item	2709040	et	3	main
sest	doc_536541856889_item	2709041	et	4	main
mõjutas	doc_536541856889_item	2709048	et	3	main
suurel	doc_536541856889_item	2709049	et	3	main
ajal	doc_536541856889_item	2709068	et	4	main
see	doc_536541856889_item	2709069	et	3	main
paremini	doc_536541856889_item	2709076	et	4	main
eestlaste	doc_536541856889_item	2709090	et	4	main
kultuuri	doc_536541856889_item	2709107	et	4	main
aga	doc_536541856889_item	2709109	et	3	main
rahvas	doc_536541856889_item	2709111	et	4	main
ja	doc_536541856888_item	2708887	et	3	main
laul	doc_536541856888_item	2708892	et	4	main
eesti	doc_536541856889_item	2708896	et	4	main
eestlastest	doc_536541856889_item	2708908	et	4	main
laulurahva	doc_536541856889_item	2708909	et	3	main
olema	doc_536541856889_item	2708917	et	4	main
ja	doc_536541856889_item	2708924	et	3	main
eestlastest	doc_536541856889_item	2708935	et	4	main
laul	doc_536541856889_item	2708937	et	4	main
ühendada	doc_536541856889_item	2708939	et	3	main
hädas	doc_536541856889_item	2708941	et	3	main
ja	doc_536541856889_item	2708942	et	3	main
sama	doc_536541856889_item	2708958	et	4	main
laulusõnu	doc_536541856889_item	2708959	et	3	main
mis	doc_536541856889_item	2708965	et	4	main
kellel	doc_536541856889_item	2708973	et	4	main
levinud	doc_536541856889_item	2708984	et	4	main
üle	doc_536541856889_item	2708985	et	3	main
vahel	doc_536541856889_item	2708991	et	4	main
käimisel	doc_536541856889_item	2708997	et	4	main
eeslaulja	doc_536541856889_item	2709001	et	4	main
teda	doc_536541856889_item	2709004	et	4	main
vanasti	doc_536541856889_item	2709021	et	3	main
ei	doc_536541856889_item	2709023	et	4	main
ette	doc_536541856889_item	2709025	et	4	main
oma	doc_536541856889_item	2709026	et	4	main
lauluga	doc_536541856889_item	2709031	et	4	main
uuemad	doc_536541856889_item	2709037	et	4	main
rahvalaulud	doc_536541856889_item	2709038	et	3	main
seda	doc_536541856889_item	2709047	et	3	main
aitas	doc_536541856889_item	2709070	et	3	main
eestlastel	doc_536541856889_item	2709071	et	4	main
väljendada	doc_536541856889_item	2709077	et	3	main
püüdes	doc_536541856889_item	2709078	et	4	main
vabaduse	doc_536541856889_item	2709079	et	4	main
ideest	doc_536541856889_item	2709085	et	4	main
uus	doc_536541856889_item	2709088	et	3	main
erinevad	doc_536541856889_item	2709102	et	4	main
poliitilised	doc_536541856889_item	2709103	et	3	main
olud	doc_536541856889_item	2709104	et	3	main
ohustasid	doc_536541856889_item	2709105	et	4	main
suutis	doc_536541856889_item	2709112	et	3	main
tänapäevani	doc_536541856889_item	2709115	et	3	main
iga	doc_536541856889_item	2709117	et	4	main
tuleb	doc_536541856889_item	2709122	et	3	main
sellele	doc_536541856889_item	2709123	et	4	main
üritusele	doc_536541856889_item	2709124	et	4	main
eesti	doc_536541856889_item	2709131	et	4	main
suur	doc_536541856889_item	2709132	et	3	main
isamaa	doc_536541856889_item	2709141	et	4	main
kunstist	doc_536541856889_item	2709144	et	4	main
tegutsevad	doc_536541856889_item	2709151	et	4	main
kasutatud	doc_536541856889_item	2709161	et	4	main
ka	doc_536541856889_item	2709162	et	3	main
paljude	doc_536541856889_item	2709163	et	3	main
heliloojade	doc_536541856889_item	2709167	et	4	main
eriti	doc_536541856889_item	2709169	et	3	main
teeb	doc_536541856889_item	2709190	et	3	main
iga	doc_536541856889_item	2709196	et	4	main
toimuvad	doc_536541856889_item	2709200	et	4	main
erinevad	doc_536541856889_item	2709201	et	4	main
festivalid	doc_536541856889_item	2709202	et	3	main
näiteks	doc_536541856889_item	2709208	et	4	main
seas	doc_536541856889_item	2709220	et	4	main
tallinna	doc_536541856889_item	2709221	et	4	main
kui	doc_536541856889_item	2709225	et	3	main
peedab	doc_536541856889_item	2709243	et	4	main
oma	doc_536541856889_item	2709245	et	4	main
kultuuri	doc_536541856889_item	2709247	et	4	main
laulurahva	doc_536541856890_item	2709263	et	3	main
300	doc_536541856890_item	2709266	et	2	main
sõna	doc_536541856890_item	2709268	et	4	main
essee	doc_536541856890_item	2709269	et	4	main
üldistav	doc_536541856890_item	2709275	et	4	main
tuginema	doc_536541856890_item	2709276	et	3	main
loengus	doc_536541856890_item	2709277	et	3	main
ja	doc_536541856890_item	2709278	et	3	main
lugemistekstis	doc_536541856890_item	2709279	et	3	main
mitu	doc_536541856890_item	2709293	et	4	main
suuliselt	doc_536541856890_item	2709327	et	4	main
saksa	doc_536541856890_item	2709333	et	4	main
tuginema	doc_536541856889_item	2708922	et	3	main
esitatud	doc_536541856889_item	2708926	et	4	main
on	doc_536541856889_item	2708929	et	4	main
rõõmus	doc_536541856889_item	2708943	et	4	main
loomulikult	doc_536541856889_item	2708951	et	4	main
võimaldab	doc_536541856889_item	2708955	et	3	main
kaasa	doc_536541856889_item	2708956	et	4	main
laulda	doc_536541856889_item	2708957	et	4	main
on	doc_536541856889_item	2708970	et	4	main
üks	doc_536541856889_item	2708971	et	3	main
rahvastest	doc_536541856889_item	2708972	et	4	main
seda	doc_536541856889_item	2708988	et	3	main
laulsid	doc_536541856889_item	2708989	et	4	main
naised	doc_536541856889_item	2708990	et	3	main
näiteks	doc_536541856889_item	2708994	et	4	main
pulmades	doc_536541856889_item	2708996	et	3	main
regilaulu	doc_536541856889_item	2708999	et	4	main
pärast	doc_536541856889_item	2709003	et	4	main
aitas	doc_536541856889_item	2709005	et	3	main
kooriga	doc_536541856889_item	2709015	et	4	main
jnd	doc_536541856889_item	2709016	et	4	main
see	doc_536541856889_item	2709017	et	3	main
näitab	doc_536541856889_item	2709018	et	3	main
et	doc_536541856889_item	2709019	et	3	main
juba	doc_536541856889_item	2709020	et	3	main
ilma	doc_536541856889_item	2709028	et	4	main
ühiskonnaga	doc_536541856889_item	2709045	et	4	main
laulupidu	doc_536541856889_item	2709066	et	4	main
tol	doc_536541856889_item	2709067	et	3	main
unikaalsuse	doc_536541856889_item	2709075	et	4	main
poole	doc_536541856889_item	2709080	et	4	main
voldemar	doc_536541856889_item	2709083	et	4	main
jannseni	doc_536541856889_item	2709084	et	4	main
välja	doc_536541856889_item	2709087	et	4	main
jaoks	doc_536541856889_item	2709091	et	4	main
korraldamine	doc_536541856889_item	2709093	et	4	main
küll	doc_536541856889_item	2709094	et	4	main
see	doc_536541856889_item	2709095	et	3	main
polnud	doc_536541856889_item	2709096	et	3	main
lihtne	doc_536541856889_item	2709097	et	3	main
säilitada	doc_536541856889_item	2709098	et	3	main
uut	doc_536541856889_item	2709099	et	3	main
eesti	doc_536541856889_item	2709106	et	4	main
ka	doc_536541856889_item	2709114	et	3	main
kord	doc_536541856889_item	2709118	et	4	main
laulupidude	doc_536541856889_item	2709126	et	4	main
ja	doc_536541856889_item	2709127	et	3	main
ajaloost	doc_536541856889_item	2709142	et	4	main
ka	doc_536541856889_item	2709145	et	3	main
bändid	doc_536541856889_item	2709179	et	4	main
muusikat	doc_536541856889_item	2709183	et	3	main
muusikat	doc_536541856889_item	2709191	et	3	main
teksti	doc_536541856889_item	2709193	et	4	main
kuulata	doc_536541856889_item	2709206	et	4	main
on	doc_536541856889_item	2709211	et	4	main
on	doc_536541856889_item	2709216	et	4	main
eriti	doc_536541856889_item	2709217	et	3	main
populaarne	doc_536541856889_item	2709218	et	3	main
päevadel	doc_536541856889_item	2709222	et	3	main
noored	doc_536541856889_item	2709224	et	3	main
nautida	doc_536541856889_item	2709229	et	3	main
eesti	doc_536541856889_item	2709241	et	4	main
keele	doc_536541856890_item	2709254	et	4	main
test	doc_536541856890_item	2709255	et	3	main
kirjutage	doc_536541856890_item	2709257	et	3	main
eestlastest	doc_536541856890_item	2709262	et	4	main
pikkus	doc_536541856890_item	2709265	et	4	main
olema	doc_536541856890_item	2709271	et	4	main
arutlev	doc_536541856890_item	2709272	et	4	main
eestlasi	doc_536541856890_item	2709287	et	3	main
nimetatakse	doc_536541856890_item	2709289	et	3	main
põhjus	doc_536541856890_item	2709296	et	4	main
nendest	doc_536541856890_item	2709322	et	4	main
levisid	doc_536541856890_item	2709326	et	4	main
sajandil	doc_536541856890_item	2709332	et	3	main
slaavi	doc_536541856890_item	2709337	et	3	main
kujutanud	doc_536541856889_item	2709024	et	4	main
laulmiseta	doc_536541856889_item	2709029	et	4	main
püüades	doc_536541856889_item	2709030	et	4	main
aidata	doc_536541856889_item	2709034	et	4	main
hiljem	doc_536541856889_item	2709035	et	3	main
tekkisid	doc_536541856889_item	2709036	et	4	main
näiteks	doc_536541856889_item	2709046	et	4	main
määral	doc_536541856889_item	2709050	et	3	main
paistab	doc_536541856889_item	2709052	et	3	main
eestlaste	doc_536541856889_item	2709054	et	4	main
tuli	doc_536541856889_item	2709056	et	4	main
uuele	doc_536541856889_item	2709057	et	3	main
tasemele	doc_536541856889_item	2709058	et	3	main
kui	doc_536541856889_item	2709059	et	3	main
oma	doc_536541856889_item	2709072	et	4	main
kultuuri	doc_536541856889_item	2709073	et	4	main
ja	doc_536541856889_item	2709074	et	3	main
johann	doc_536541856889_item	2709082	et	4	main
kujunes	doc_536541856889_item	2709086	et	3	main
traditsioon	doc_536541856889_item	2709089	et	3	main
laulupidude	doc_536541856889_item	2709092	et	4	main
sest	doc_536541856889_item	2709101	et	4	main
laulupeosid	doc_536541856889_item	2709113	et	3	main
säilitada	doc_536541856889_item	2709116	et	3	main
üsna	doc_536541856889_item	2709119	et	3	main
rohkem	doc_536541856889_item	2709120	et	4	main
on	doc_536541856889_item	2709137	et	4	main
väga	doc_536541856889_item	2709138	et	3	main
huvitatud	doc_536541856889_item	2709139	et	4	main
ja	doc_536541856889_item	2709147	et	3	main
praegusel	doc_536541856889_item	2709149	et	3	main
on	doc_536541856889_item	2709160	et	4	main
ja	doc_536541856889_item	2709166	et	3	main
töödes	doc_536541856889_item	2709168	et	3	main
imelik	doc_536541856889_item	2709170	et	3	main
see	doc_536541856889_item	2709172	et	3	main
et	doc_536541856889_item	2709173	et	3	main
luule	doc_536541856889_item	2709181	et	4	main
rahvalauludest	doc_536541856889_item	2709185	et	3	main
rock-ansambel	doc_536541856889_item	2709187	et	3	main
kasutades	doc_536541856889_item	2709192	et	3	main
aasta	doc_536541856889_item	2709197	et	4	main
eesti	doc_536541856889_item	2709199	et	4	main
rahvalaule	doc_536541856889_item	2709207	et	4	main
korraldatud	doc_536541856889_item	2709212	et	4	main
noorikute	doc_536541856889_item	2709219	et	3	main
nii	doc_536541856889_item	2709223	et	3	main
vähene	doc_536541856889_item	2709237	et	4	main
see	doc_536541856889_item	2709238	et	3	main
folkloori	doc_536541856889_item	2709246	et	4	main
kirjutamine	doc_536541856890_item	2709256	et	4	main
mis	doc_536541856890_item	2709260	et	4	main
essee	doc_536541856890_item	2709264	et	4	main
350	doc_536541856890_item	2709267	et	2	main
analüüsiv	doc_536541856890_item	2709273	et	4	main
ja	doc_536541856890_item	2709274	et	3	main
väiteid	doc_536541856890_item	2709282	et	4	main
soovitatav	doc_536541856890_item	2709284	et	4	main
illustreerida	doc_536541856890_item	2709285	et	3	main
näidetega	doc_536541856890_item	2709286	et	3	main
laulurahvaks	doc_536541856890_item	2709290	et	3	main
on	doc_536541856890_item	2709297	et	4	main
see	doc_536541856890_item	2709298	et	3	main
rahvas	doc_536541856890_item	2709301	et	4	main
põlvkonnast	doc_536541856890_item	2709328	et	4	main
hiljem	doc_536541856890_item	2709330	et	3	main
ja	doc_536541856890_item	2709336	et	3	main
neid	doc_536541856890_item	2709344	et	4	main
unustada	doc_536541856890_item	2709346	et	3	main
aastat	doc_536541856890_item	2709351	et	3	main
esimene	doc_536541856890_item	2709353	et	3	main
tartus	doc_536541856890_item	2709355	et	3	main
hoides	doc_536541856890_item	2709401	et	4	main
ja	doc_536541856890_item	2709402	et	3	main
rohkem	doc_536541856890_item	2709406	et	4	main
kui	doc_536541856890_item	2709408	et	3	main
tankidel	doc_536541856890_item	2709409	et	3	main
elab	doc_536541856890_item	2709414	et	3	main
rahva	doc_536541856890_item	2709423	et	3	main
rahvalaulu	doc_536541856889_item	2709128	et	4	main
vastu	doc_536541856889_item	2709129	et	3	main
on	doc_536541856889_item	2709130	et	4	main
oma	doc_536541856889_item	2709140	et	4	main
folkloorist	doc_536541856889_item	2709143	et	4	main
rahvalauludest	doc_536541856889_item	2709146	et	3	main
rahvalaulu	doc_536541856889_item	2709153	et	4	main
ansamblid	doc_536541856889_item	2709154	et	3	main
kihnu	doc_536541856889_item	2709155	et	4	main
saarel	doc_536541856889_item	2709156	et	3	main
ja	doc_536541856889_item	2709157	et	3	main
setumaal	doc_536541856889_item	2709158	et	4	main
rahvalaulu	doc_536541856889_item	2709159	et	4	main
eesti	doc_536541856889_item	2709164	et	4	main
on	doc_536541856889_item	2709171	et	4	main
isegi	doc_536541856889_item	2709174	et	4	main
pop-kultuurile	doc_536541856889_item	2709175	et	3	main
mõjub	doc_536541856889_item	2709176	et	3	main
rahvalaul	doc_536541856889_item	2709177	et	4	main
noorte	doc_536541856889_item	2709178	et	3	main
ja	doc_536541856889_item	2709182	et	3	main
nii	doc_536541856889_item	2709186	et	3	main
raud	doc_536541856889_item	2709188	et	3	main
vanadest	doc_536541856889_item	2709194	et	3	main
pedafolk	doc_536541856889_item	2709209	et	4	main
mis	doc_536541856889_item	2709210	et	4	main
vanad	doc_536541856889_item	2709227	et	3	main
tähendab	doc_536541856889_item	2709239	et	3	main
et	doc_536541856889_item	2709240	et	3	main
iseseisvust	doc_536541856889_item	2709248	et	4	main
essee	doc_536541856890_item	2709249	et	4	main
eesti	doc_536541856890_item	2709250	et	4	main
keele	doc_536541856890_item	2709251	et	4	main
kui	doc_536541856890_item	2709252	et	3	main
teise	doc_536541856890_item	2709253	et	4	main
essee	doc_536541856890_item	2709258	et	4	main
peab	doc_536541856890_item	2709270	et	4	main
esitatud	doc_536541856890_item	2709280	et	4	main
on	doc_536541856890_item	2709283	et	4	main
tihti	doc_536541856890_item	2709288	et	3	main
selleks	doc_536541856890_item	2709291	et	4	main
on	doc_536541856890_item	2709292	et	4	main
et	doc_536541856890_item	2709299	et	3	main
19	doc_536541856890_item	2709331	et	2	main
ka	doc_536541856889_item	2709226	et	3	main
saavad	doc_536541856889_item	2709228	et	4	main
head	doc_536541856889_item	2709230	et	4	main
rahvamuusikat	doc_536541856889_item	2709231	et	3	main
aastatega	doc_536541856889_item	2709232	et	3	main
huvi	doc_536541856889_item	2709233	et	4	main
rahvalaulude	doc_536541856889_item	2709234	et	3	main
vastu	doc_536541856889_item	2709235	et	3	main
ei	doc_536541856889_item	2709236	et	4	main
rahvas	doc_536541856889_item	2709242	et	4	main
tähtsaks	doc_536541856889_item	2709244	et	4	main
teemal	doc_536541856890_item	2709259	et	3	main
teeb	doc_536541856890_item	2709261	et	3	main
faktidele	doc_536541856890_item	2709281	et	3	main
põhjust	doc_536541856890_item	2709294	et	4	main
esimene	doc_536541856890_item	2709295	et	3	main
eesti	doc_536541856890_item	2709300	et	4	main
on	doc_536541856890_item	2709302	et	4	main
väga	doc_536541856890_item	2709303	et	3	main
patriootiline	doc_536541856890_item	2709304	et	3	main
ja	doc_536541856890_item	2709305	et	3	main
püüab	doc_536541856890_item	2709306	et	3	main
säilitada	doc_536541856890_item	2709307	et	3	main
oma	doc_536541856890_item	2709308	et	4	main
kultuuri	doc_536541856890_item	2709309	et	4	main
laul	doc_536541856890_item	2709310	et	4	main
on	doc_536541856890_item	2709311	et	4	main
kultuuri	doc_536541856890_item	2709312	et	4	main
osa	doc_536541856890_item	2709313	et	4	main
rahvuslaulude	doc_536541856890_item	2709314	et	3	main
laulmine	doc_536541856890_item	2709315	et	4	main
on	doc_536541856890_item	2709316	et	4	main
eestlastel	doc_536541856890_item	2709317	et	4	main
oli	doc_536541856890_item	2709318	et	3	main
alati	doc_536541856890_item	2709319	et	4	main
kombes	doc_536541856890_item	2709320	et	4	main
esimesed	doc_536541856890_item	2709321	et	3	main
nimetati	doc_536541856890_item	2709323	et	4	main
regilauludeks	doc_536541856890_item	2709324	et	3	main
nemad	doc_536541856890_item	2709325	et	3	main
soome	doc_536541856890_item	2709335	et	3	main
mõjul	doc_536541856890_item	2709339	et	4	main
korraldatatakse	doc_536541856890_item	2709348	et	4	main
laulupeo	doc_536541856890_item	2709352	et	4	main
toimus	doc_536541856890_item	2709354	et	3	main
rahvas	doc_536541856890_item	2709359	et	4	main
minnakse	doc_536541856890_item	2709366	et	3	main
selleks	doc_536541856890_item	2709368	et	4	main
rahvuslaul	doc_536541856890_item	2709412	et	4	main
põlvkonna	doc_536541856890_item	2709329	et	4	main
rootsi	doc_536541856890_item	2709334	et	4	main
mitte	doc_536541856890_item	2709345	et	3	main
eestis	doc_536541856890_item	2709347	et	3	main
iga	doc_536541856890_item	2709349	et	4	main
laulupeol	doc_536541856890_item	2709358	et	4	main
ja	doc_536541856890_item	2709362	et	3	main
kuuluvus	doc_536541856890_item	2709372	et	4	main
rikka	doc_536541856890_item	2709373	et	4	main
eesti	doc_536541856890_item	2709374	et	4	main
kultuuri	doc_536541856890_item	2709375	et	4	main
teine	doc_536541856890_item	2709376	et	3	main
põhjus	doc_536541856890_item	2709377	et	4	main
on	doc_536541856890_item	2709378	et	4	main
seotud	doc_536541856890_item	2709379	et	4	main
laulurevolutsiooniga	doc_536541856890_item	2709380	et	3	main
ehk	doc_536541856890_item	2709381	et	3	main
teise	doc_536541856890_item	2709382	et	4	main
eesti	doc_536541856890_item	2709383	et	4	main
iseseisvusega	doc_536541856890_item	2709384	et	4	main
ükski	doc_536541856890_item	2709385	et	4	main
inimene	doc_536541856890_item	2709386	et	3	main
ei	doc_536541856890_item	2709387	et	4	main
olnud	doc_536541856890_item	2709388	et	4	main
tapetud	doc_536541856890_item	2709389	et	4	main
sellel	doc_536541856890_item	2709390	et	4	main
ajal	doc_536541856890_item	2709391	et	4	main
eesti	doc_536541856890_item	2709392	et	4	main
rahvas	doc_536541856890_item	2709393	et	4	main
võitles	doc_536541856890_item	2709394	et	3	main
oma	doc_536541856890_item	2709395	et	4	main
iseseisvuse	doc_536541856890_item	2709396	et	4	main
eest	doc_536541856890_item	2709397	et	4	main
muusika	doc_536541856890_item	2709338	et	4	main
ilmusid	doc_536541856890_item	2709340	et	4	main
riimilised	doc_536541856890_item	2709341	et	4	main
rahvalaulud	doc_536541856890_item	2709342	et	3	main
et	doc_536541856890_item	2709343	et	3	main
4	doc_536541856890_item	2709350	et	2	main
1869	doc_536541856890_item	2709356	et	2	main
aastal	doc_536541856890_item	2709357	et	3	main
ühendatud	doc_536541856890_item	2709361	et	4	main
laulab	doc_536541856890_item	2709363	et	3	main
sinna	doc_536541856890_item	2709365	et	3	main
perega	doc_536541856890_item	2709367	et	3	main
et	doc_536541856890_item	2709369	et	3	main
tähistada	doc_536541856890_item	2709370	et	3	main
oma	doc_536541856890_item	2709371	et	4	main
lauldes	doc_536541856890_item	2709398	et	3	main
ja	doc_536541856890_item	2709399	et	3	main
laulul	doc_536541856890_item	2709404	et	3	main
ajal	doc_536541856890_item	2709411	et	4	main
ka	doc_536541856890_item	2709440	et	3	main
tutvustada	doc_536541856890_item	2709460	et	3	main
rahvamuusikat	doc_536541856890_item	2709463	et	3	main
laulud	doc_536541856890_item	2709466	et	3	main
on	doc_536541856890_item	2709467	et	4	main
on	doc_536541856890_item	2709480	et	4	main
on	doc_536541856890_item	2709484	et	4	main
toetavad	doc_536541856890_item	2709497	et	4	main
kultuurile	doc_536541856890_item	2709498	et	3	main
rahvariiete	doc_536541856890_item	2709503	et	3	main
ka	doc_536541856890_item	2709506	et	3	main
on	doc_536541856890_item	2709512	et	4	main
mu	doc_536541856890_item	2709513	et	3	main
on	doc_536541856890_item	2709360	et	4	main
koos	doc_536541856890_item	2709364	et	4	main
sellel	doc_536541856890_item	2709403	et	4	main
ikka	doc_536541856890_item	2709413	et	4	main
on	doc_536541856890_item	2709416	et	4	main
isegi	doc_536541856890_item	2709417	et	4	main
moodne	doc_536541856890_item	2709418	et	3	main
tänapäeva	doc_536541856890_item	2709419	et	4	main
muusikas	doc_536541856890_item	2709420	et	3	main
kasutatakse	doc_536541856890_item	2709422	et	3	main
saar	doc_536541856890_item	2709426	et	3	main
festivalis	doc_536541856890_item	2709443	et	3	main
iga	doc_536541856890_item	2709446	et	4	main
ta	doc_536541856890_item	2709449	et	4	main
erineb	doc_536541856890_item	2709450	et	3	main
sinna	doc_536541856890_item	2709454	et	3	main
iga	doc_536541856890_item	2709464	et	4	main
säilitamine	doc_536541856890_item	2709472	et	4	main
kultuuri	doc_536541856890_item	2709474	et	4	main
mis	doc_536541856890_item	2709483	et	4	main
nende	doc_536541856890_item	2709485	et	4	main
kuni	doc_536541856890_item	2709487	et	3	main
isamaa	doc_536541856890_item	2709514	et	4	main
on	doc_536541856890_item	2709515	et	4	main
minu	doc_536541856890_item	2709516	et	3	main
armastust	doc_536541856890_item	2709521	et	4	main
vastu	doc_536541856890_item	2709523	et	3	main
ülendab	doc_536541856890_item	2709537	et	3	main
eestlastele	doc_536541856890_item	2709539	et	4	main
meeldib	doc_536541856890_item	2709540	et	3	main
laulda	doc_536541856890_item	2709541	et	4	main
see	doc_536541856890_item	2709542	et	3	main
annab	doc_536541856890_item	2709543	et	3	main
vaba	doc_536541856890_item	2709555	et	4	main
jooksul	doc_536541856890_item	2709557	et	4	main
nais-	doc_536541856890_item	2709561	et	3	main
sündmusi	doc_536541856890_item	2709564	et	3	main
lauluga	doc_536541856890_item	2709566	et	4	main
isegi	doc_536541856890_item	2709569	et	4	main
350	doc_536541856891_item	2709601	et	2	main
analüüsiv	doc_536541856891_item	2709607	et	4	main
ja	doc_536541856891_item	2709608	et	3	main
ja	doc_536541856891_item	2709637	et	3	main
kui	doc_536541856891_item	2709640	et	3	main
sündmuste	doc_536541856891_item	2709641	et	3	main
rikkas	doc_536541856891_item	2709642	et	4	main
erinevaid	doc_536541856891_item	2709647	et	4	main
on	doc_536541856891_item	2709656	et	4	main
näha	doc_536541856891_item	2709668	et	3	main
regilaul	doc_536541856891_item	2709673	et	4	main
seda	doc_536541856891_item	2709674	et	3	main
ütlevad	doc_536541856891_item	2709675	et	4	main
ennemgi	doc_536541856891_item	2709683	et	4	main
eestlastel	doc_536541856891_item	2709688	et	4	main
istudes	doc_536541856891_item	2709697	et	4	main
nii	doc_536541856891_item	2709704	et	3	main
sest	doc_536541856891_item	2709716	et	4	main
käsi	doc_536541856890_item	2709400	et	4	main
oli	doc_536541856890_item	2709405	et	3	main
võimu	doc_536541856890_item	2709407	et	4	main
meie	doc_536541856890_item	2709410	et	4	main
ja	doc_536541856890_item	2709415	et	3	main
tihti	doc_536541856890_item	2709421	et	3	main
jüri	doc_536541856890_item	2709425	et	4	main
praktiseerima	doc_536541856890_item	2709432	et	3	main
rahvusmuusikat	doc_536541856890_item	2709434	et	3	main
saab	doc_536541856890_item	2709435	et	3	main
kuulata	doc_536541856890_item	2709436	et	4	main
mitte	doc_536541856890_item	2709437	et	3	main
folk	doc_536541856890_item	2709442	et	4	main
mis	doc_536541856890_item	2709444	et	4	main
laulupeost	doc_536541856890_item	2709451	et	4	main
et	doc_536541856890_item	2709453	et	3	main
tulevad	doc_536541856890_item	2709456	et	4	main
külalised	doc_536541856890_item	2709457	et	4	main
välismaalt	doc_536541856890_item	2709458	et	3	main
et	doc_536541856890_item	2709459	et	3	main
laulde	doc_536541856890_item	2709471	et	4	main
on	doc_536541856890_item	2709476	et	4	main
meenutus	doc_536541856890_item	2709477	et	4	main
noortele	doc_536541856890_item	2709478	et	3	main
kus	doc_536541856890_item	2709479	et	3	main
rahvalaul	doc_536541856890_item	2709490	et	4	main
eestis	doc_536541856890_item	2709492	et	3	main
nõuab	doc_536541856890_item	2709501	et	3	main
ka	doc_536541856890_item	2709502	et	3	main
kandmist	doc_536541856890_item	2709504	et	4	main
kultuuri	doc_536541856890_item	2709508	et	4	main
mis	doc_536541856890_item	2709524	et	4	main
laulatakse	doc_536541856890_item	2709532	et	4	main
laulupeo	doc_536541856890_item	2709533	et	4	main
naudingu	doc_536541856890_item	2709546	et	3	main
selle	doc_536541856890_item	2709547	et	4	main
on	doc_536541856890_item	2709549	et	4	main
nii	doc_536541856890_item	2709550	et	3	main
populaarne	doc_536541856890_item	2709551	et	3	main
on	doc_536541856890_item	2709552	et	4	main
aja	doc_536541856890_item	2709556	et	4	main
teemal	doc_536541856891_item	2709593	et	3	main
mis	doc_536541856891_item	2709594	et	4	main
teeb	doc_536541856891_item	2709595	et	3	main
eestlastest	doc_536541856891_item	2709596	et	4	main
olema	doc_536541856891_item	2709605	et	4	main
juba	doc_536541856890_item	2709427	et	3	main
sajandil	doc_536541856890_item	2709429	et	3	main
laulupeol	doc_536541856890_item	2709438	et	4	main
aga	doc_536541856890_item	2709439	et	3	main
rahvases	doc_536541856890_item	2709465	et	4	main
sümboolikast	doc_536541856890_item	2709470	et	4	main
hoiab	doc_536541856890_item	2709473	et	3	main
laulud	doc_536541856890_item	2709475	et	3	main
kodumaa	doc_536541856890_item	2709486	et	4	main
elab	doc_536541856890_item	2709488	et	3	main
sest	doc_536541856890_item	2709493	et	4	main
riik	doc_536541856890_item	2709494	et	3	main
ja	doc_536541856890_item	2709495	et	3	main
rahvas	doc_536541856890_item	2709496	et	4	main
laulamine	doc_536541856890_item	2709500	et	4	main
säilib	doc_536541856890_item	2709507	et	3	main
eestlaste	doc_536541856890_item	2709509	et	4	main
lemmik	doc_536541856890_item	2709510	et	3	main
laul	doc_536541856890_item	2709511	et	4	main
arm	doc_536541856890_item	2709517	et	3	main
ta	doc_536541856890_item	2709518	et	4	main
näitab	doc_536541856890_item	2709519	et	3	main
imesuurt	doc_536541856890_item	2709520	et	3	main
rahva	doc_536541856890_item	2709526	et	3	main
selle	doc_536541856890_item	2709528	et	4	main
see	doc_536541856890_item	2709536	et	3	main
meeli	doc_536541856890_item	2709538	et	4	main
vaimse	doc_536541856890_item	2709545	et	3	main
lastekoorid	doc_536541856890_item	2709562	et	3	main
essee	doc_536541856891_item	2709598	et	4	main
pikkus	doc_536541856891_item	2709599	et	4	main
arutlev	doc_536541856891_item	2709606	et	4	main
üldistav	doc_536541856891_item	2709609	et	4	main
tuginema	doc_536541856891_item	2709610	et	3	main
loengus	doc_536541856891_item	2709611	et	3	main
ja	doc_536541856891_item	2709612	et	3	main
lugemistekstis	doc_536541856891_item	2709613	et	3	main
on	doc_536541856891_item	2709617	et	4	main
illustreerida	doc_536541856891_item	2709619	et	3	main
näidetega	doc_536541856891_item	2709620	et	3	main
kellegi	doc_536541856891_item	2709633	et	4	main
teise	doc_536541856891_item	2709634	et	4	main
muresid	doc_536541856891_item	2709635	et	3	main
ajaloos	doc_536541856891_item	2709655	et	4	main
eesti	doc_536541856891_item	2709666	et	4	main
vanem	doc_536541856891_item	2709670	et	4	main
olid	doc_536541856891_item	2709687	et	4	main
või	doc_536541856891_item	2709695	et	4	main
aga	doc_536541856891_item	2709698	et	3	main
teada	doc_536541856891_item	2709703	et	3	main
palju	doc_536541856891_item	2709715	et	4	main
põlve	doc_536541856891_item	2709720	et	4	main
kui	doc_536541856891_item	2709722	et	3	main
levima	doc_536541856891_item	2709724	et	3	main
rahvalaulule	doc_536541856891_item	2709727	et	3	main
hilisemad	doc_536541856891_item	2709732	et	4	main
on	doc_536541856891_item	2709735	et	4	main
konkreetsemad	doc_536541856891_item	2709737	et	4	main
esitati	doc_536541856891_item	2709740	et	4	main
teksti	doc_536541856891_item	2709743	et	4	main
eestlane	doc_536541856891_item	2709753	et	3	main
laulnud	doc_536541856891_item	2709755	et	4	main
alati	doc_536541856891_item	2709756	et	4	main
laulud	doc_536541856891_item	2709760	et	3	main
ka	doc_536541856891_item	2709765	et	3	main
kuulda	doc_536541856891_item	2709774	et	4	main
eestlastest	doc_536541856891_item	2709791	et	4	main
kui	doc_536541856891_item	2709792	et	3	main
nii	doc_536541856891_item	2709804	et	3	main
ainult	doc_536541856891_item	2709818	et	4	main
tõelised	doc_536541856891_item	2709819	et	4	main
patrioodid	doc_536541856891_item	2709820	et	3	main
see	doc_536541856891_item	2709821	et	3	main
tahab	doc_536541856891_item	2709828	et	3	main
ei	doc_536541856891_item	2709844	et	4	main
rahvas	doc_536541856891_item	2709847	et	4	main
säilis	doc_536541856891_item	2709848	et	4	main
motiive	doc_536541856890_item	2709424	et	3	main
eelmisel	doc_536541856890_item	2709428	et	3	main
hakkas	doc_536541856890_item	2709430	et	3	main
seda	doc_536541856890_item	2709431	et	3	main
eesti	doc_536541856890_item	2709433	et	4	main
viljand	doc_536541856890_item	2709441	et	4	main
toimub	doc_536541856890_item	2709445	et	3	main
aasta	doc_536541856890_item	2709447	et	4	main
juulis	doc_536541856890_item	2709448	et	3	main
selles	doc_536541856890_item	2709452	et	4	main
ka	doc_536541856890_item	2709455	et	3	main
eestlastele	doc_536541856890_item	2709461	et	4	main
oma	doc_536541856890_item	2709462	et	4	main
osa	doc_536541856890_item	2709468	et	4	main
nende	doc_536541856890_item	2709469	et	4	main
nende	doc_536541856890_item	2709481	et	4	main
juured	doc_536541856890_item	2709482	et	3	main
rahvamuusika	doc_536541856890_item	2709489	et	4	main
elabgi	doc_536541856890_item	2709491	et	4	main
rahvalaulde	doc_536541856890_item	2709499	et	4	main
mis	doc_536541856890_item	2709505	et	4	main
elab	doc_536541856890_item	2709525	et	3	main
südametes	doc_536541856890_item	2709527	et	4	main
pärastki	doc_536541856890_item	2709529	et	4	main
seda	doc_536541856890_item	2709530	et	3	main
alati	doc_536541856890_item	2709531	et	4	main
lõpus	doc_536541856890_item	2709534	et	4	main
laulda	doc_536541856890_item	2709553	et	4	main
koorides	doc_536541856890_item	2709554	et	4	main
on	doc_536541856890_item	2709558	et	4	main
olemas	doc_536541856890_item	2709559	et	4	main
põllutööd	doc_536541856890_item	2709570	et	4	main
peab	doc_536541856891_item	2709604	et	4	main
esitatud	doc_536541856891_item	2709614	et	4	main
faktidele	doc_536541856891_item	2709615	et	3	main
laul	doc_536541856891_item	2709621	et	4	main
selline	doc_536541856891_item	2709623	et	4	main
kunsti	doc_536541856891_item	2709624	et	4	main
enamasti	doc_536541856891_item	2709628	et	4	main
õnnehetki	doc_536541856891_item	2709636	et	4	main
teisi	doc_536541856891_item	2709638	et	4	main
emotsioone	doc_536541856891_item	2709639	et	3	main
seda	doc_536541856891_item	2709645	et	3	main
on	doc_536541856891_item	2709652	et	4	main
kõige	doc_536541856891_item	2709669	et	4	main
aga	doc_536541856891_item	2709679	et	3	main
arvata	doc_536541856891_item	2709681	et	4	main
õhtul	doc_536541856891_item	2709696	et	3	main
muutus	doc_536541856891_item	2709714	et	4	main
põlvest	doc_536541856891_item	2709719	et	4	main
suuliselt	doc_536541856891_item	2709721	et	4	main
avaldas	doc_536541856891_item	2709729	et	3	main
riimilised	doc_536541856891_item	2709733	et	4	main
juba	doc_536541856891_item	2709736	et	3	main
sest	doc_536541856891_item	2709738	et	4	main
neid	doc_536541856891_item	2709739	et	4	main
nõnda	doc_536541856891_item	2709749	et	3	main
sest	doc_536541856891_item	2709757	et	4	main
räägivad	doc_536541856891_item	2709761	et	3	main
elust	doc_536541856891_item	2709767	et	3	main
nendes	doc_536541856891_item	2709769	et	4	main
võib	doc_536541856891_item	2709771	et	3	main
lauludes	doc_536541856891_item	2709779	et	3	main
tahtis	doc_536541856891_item	2709781	et	3	main
looduse	doc_536541856891_item	2709785	et	4	main
laulupidusid	doc_536541856891_item	2709796	et	4	main
see	doc_536541856891_item	2709797	et	3	main
oli	doc_536541856891_item	2709798	et	3	main
kangelastegu	doc_536541856891_item	2709801	et	4	main
sest	doc_536541856891_item	2709802	et	4	main
korjama	doc_536541856891_item	2709803	et	3	main
rahvast	doc_536541856891_item	2709806	et	4	main
eriti	doc_536541856891_item	2709833	et	3	main
laulutraditsioone	doc_536541856891_item	2709834	et	3	main
isegi	doc_536541856891_item	2709835	et	4	main
kukkunud	doc_536541856891_item	2709845	et	4	main
ei	doc_536541856891_item	2709890	et	4	main
saa	doc_536541856891_item	2709891	et	4	main
unustada	doc_536541856891_item	2709892	et	3	main
ka	doc_536541856891_item	2709893	et	3	main
nii	doc_536541856891_item	2709904	et	3	main
oma	doc_536541856891_item	2709909	et	4	main
eesti	doc_536541856890_item	2709522	et	4	main
ja	doc_536541856890_item	2709535	et	3	main
neile	doc_536541856890_item	2709544	et	4	main
pärast	doc_536541856890_item	2709548	et	4	main
mees-	doc_536541856890_item	2709560	et	4	main
palju	doc_536541856890_item	2709563	et	4	main
tähistatakse	doc_536541856890_item	2709565	et	3	main
pulmad	doc_536541856890_item	2709567	et	3	main
peod	doc_536541856890_item	2709568	et	4	main
laulaga	doc_536541856890_item	2709571	et	4	main
väljendatakse	doc_536541856890_item	2709572	et	3	main
emotsioone	doc_536541856890_item	2709573	et	3	main
laul	doc_536541856890_item	2709575	et	4	main
kunagi	doc_536541856890_item	2709576	et	3	main
eesti	doc_536541856890_item	2709574	et	4	main
ei	doc_536541856890_item	2709577	et	4	main
sure	doc_536541856890_item	2709578	et	4	main
sest	doc_536541856890_item	2709579	et	4	main
rahvas	doc_536541856890_item	2709580	et	4	main
armastab	doc_536541856890_item	2709581	et	3	main
seda	doc_536541856890_item	2709582	et	3	main
essee	doc_536541856891_item	2709583	et	4	main
eesti	doc_536541856891_item	2709584	et	4	main
keele	doc_536541856891_item	2709585	et	4	main
kui	doc_536541856891_item	2709586	et	3	main
teise	doc_536541856891_item	2709587	et	4	main
keele	doc_536541856891_item	2709588	et	4	main
test	doc_536541856891_item	2709589	et	3	main
kirjutamine	doc_536541856891_item	2709590	et	4	main
kirjutage	doc_536541856891_item	2709591	et	3	main
essee	doc_536541856891_item	2709592	et	4	main
laulurahva	doc_536541856891_item	2709597	et	3	main
300	doc_536541856891_item	2709600	et	2	main
sõna	doc_536541856891_item	2709602	et	4	main
essee	doc_536541856891_item	2709603	et	4	main
väiteid	doc_536541856891_item	2709616	et	4	main
soovitatav	doc_536541856891_item	2709618	et	4	main
on	doc_536541856891_item	2709622	et	4	main
kõige	doc_536541856891_item	2709627	et	4	main
peegeldub	doc_536541856891_item	2709629	et	3	main
iseenda	doc_536541856891_item	2709630	et	3	main
rahva	doc_536541856891_item	2709631	et	3	main
või	doc_536541856891_item	2709632	et	4	main
rahvas	doc_536541856891_item	2709644	et	4	main
laule	doc_536541856891_item	2709648	et	4	main
on	doc_536541856891_item	2709650	et	4	main
rahvalaul	doc_536541856891_item	2709671	et	4	main
on	doc_536541856891_item	2709672	et	4	main
ja	doc_536541856891_item	2709677	et	3	main
omad	doc_536541856891_item	2709689	et	4	main
laulud	doc_536541856891_item	2709691	et	3	main
põlul	doc_536541856891_item	2709693	et	3	main
ei	doc_536541856891_item	2709702	et	4	main
regilaulu	doc_536541856891_item	2709706	et	4	main
ilma	doc_536541856891_item	2709708	et	4	main
pilli	doc_536541856891_item	2709709	et	4	main
ja	doc_536541856891_item	2709711	et	3	main
see	doc_536541856891_item	2709712	et	3	main
laul	doc_536541856891_item	2709713	et	4	main
rahvalaulud	doc_536541856891_item	2709734	et	3	main
pillisaatega	doc_536541856891_item	2709741	et	3	main
laululehti	doc_536541856891_item	2709745	et	4	main
et	doc_536541856891_item	2709752	et	3	main
nii	doc_536541856891_item	2709762	et	3	main
lauludes	doc_536541856891_item	2709770	et	3	main
loodushääli	doc_536541856891_item	2709773	et	3	main
oma	doc_536541856891_item	2709783	et	4	main
laulurahvast	doc_536541856891_item	2709793	et	4	main
ka	doc_536541856891_item	2709794	et	3	main
kuulsaid	doc_536541856891_item	2709795	et	3	main
pöörates	doc_536541856891_item	2709812	et	3	main
tähelepanu	doc_536541856891_item	2709813	et	4	main
ka	doc_536541856891_item	2709814	et	3	main
tollase	doc_536541856891_item	2709815	et	3	main
ajale	doc_536541856891_item	2709816	et	3	main
tugev	doc_536541856891_item	2709823	et	4	main
et	doc_536541856891_item	2709826	et	3	main
rahvas	doc_536541856891_item	2709827	et	4	main
säilitada	doc_536541856891_item	2709829	et	3	main
oma	doc_536541856891_item	2709830	et	4	main
traditsioone	doc_536541856891_item	2709831	et	3	main
ja	doc_536541856891_item	2709832	et	3	main
eestlaste	doc_536541856891_item	2709842	et	4	main
unustanud	doc_536541856891_item	2709853	et	4	main
oma	doc_536541856891_item	2709854	et	4	main
traditsioone	doc_536541856891_item	2709855	et	3	main
ja	doc_536541856891_item	2709856	et	3	main
rahvakultuuri	doc_536541856891_item	2709857	et	4	main
korraldatakse	doc_536541856891_item	2709858	et	3	main
igasuguseid	doc_536541856891_item	2709859	et	3	main
koos	doc_536541856891_item	2709880	et	4	main
nii	doc_536541856891_item	2709882	et	3	main
lauluvõistlusel	doc_536541856891_item	2709897	et	3	main
vabariik	doc_536541856891_item	2709900	et	3	main
tehtes	doc_536541856891_item	2709916	et	3	main
tänapäevani	doc_536541856891_item	2709925	et	3	main
edukalt	doc_536541856891_item	2709926	et	4	main
säilinud	doc_536541856891_item	2709927	et	4	main
mis	doc_536541856891_item	2709933	et	4	main
teevad	doc_536541856891_item	2709938	et	3	main
laulurahvaks	doc_536541856891_item	2709941	et	3	main
arvata	doc_536541856891_item	2709944	et	4	main
jääb	doc_536541856891_item	2709947	et	3	main
oma	doc_536541856891_item	2709955	et	4	main
osa	doc_536541856891_item	2709625	et	4	main
mis	doc_536541856891_item	2709626	et	4	main
on	doc_536541856891_item	2709643	et	4	main
rohkem	doc_536541856891_item	2709646	et	4	main
tal	doc_536541856891_item	2709649	et	3	main
nagu	doc_536541856891_item	2709651	et	3	main
teada	doc_536541856891_item	2709653	et	3	main
eesti	doc_536541856891_item	2709654	et	4	main
olnud	doc_536541856891_item	2709657	et	4	main
väga	doc_536541856891_item	2709658	et	3	main
palju	doc_536541856891_item	2709659	et	4	main
häid	doc_536541856891_item	2709660	et	3	main
ja	doc_536541856891_item	2709661	et	3	main
pahu	doc_536541856891_item	2709662	et	3	main
sündmusi	doc_536541856891_item	2709663	et	3	main
seda	doc_536541856891_item	2709664	et	3	main
ongi	doc_536541856891_item	2709665	et	4	main
rahvalauludes	doc_536541856891_item	2709667	et	3	main
uurijad	doc_536541856891_item	2709676	et	4	main
teadlased	doc_536541856891_item	2709678	et	3	main
võib	doc_536541856891_item	2709680	et	3	main
et	doc_536541856891_item	2709682	et	3	main
rahvas	doc_536541856891_item	2709684	et	4	main
laulis	doc_536541856891_item	2709685	et	4	main
ja	doc_536541856891_item	2709686	et	3	main
kindlad	doc_536541856891_item	2709690	et	3	main
näiteks	doc_536541856891_item	2709692	et	4	main
töötamises	doc_536541856891_item	2709694	et	4	main
lihtsalt	doc_536541856891_item	2709699	et	4	main
tollest	doc_536541856891_item	2709700	et	4	main
ajast	doc_536541856891_item	2709701	et	4	main
palju	doc_536541856891_item	2709705	et	4	main
lauldi	doc_536541856891_item	2709707	et	3	main
saadeta	doc_536541856891_item	2709710	et	3	main
ta	doc_536541856891_item	2709717	et	4	main
levis	doc_536541856891_item	2709718	et	4	main
hakkas	doc_536541856891_item	2709723	et	3	main
ristiusk	doc_536541856891_item	2709725	et	3	main
eestis	doc_536541856891_item	2709726	et	3	main
see	doc_536541856891_item	2709728	et	3	main
ka	doc_536541856891_item	2709730	et	3	main
on	doc_536541856891_item	2709754	et	4	main
vanad	doc_536541856891_item	2709759	et	3	main
kui	doc_536541856891_item	2709764	et	3	main
see	doc_536541856891_item	2709775	et	3	main
isegi	doc_536541856891_item	2709778	et	4	main
eestlane	doc_536541856891_item	2709780	et	3	main
edastada	doc_536541856891_item	2709782	et	3	main
vastu	doc_536541856891_item	2709786	et	3	main
tohi	doc_536541856891_item	2709788	et	4	main
unustada	doc_536541856891_item	2709789	et	3	main
rääkides	doc_536541856891_item	2709790	et	4	main
suur	doc_536541856891_item	2709800	et	3	main
palju	doc_536541856891_item	2709805	et	4	main
ja	doc_536541856891_item	2709807	et	3	main
korrladama	doc_536541856891_item	2709808	et	4	main
nii	doc_536541856891_item	2709809	et	3	main
suurt	doc_536541856891_item	2709810	et	3	main
üritust	doc_536541856891_item	2709811	et	4	main
mõju	doc_536541856891_item	2709731	et	4	main
ja	doc_536541856891_item	2709742	et	3	main
ja	doc_536541856891_item	2709744	et	3	main
trükiti	doc_536541856891_item	2709746	et	3	main
ja	doc_536541856891_item	2709747	et	3	main
võib	doc_536541856891_item	2709750	et	3	main
ümberkirjutati	doc_536541856891_item	2709748	et	4	main
öelda	doc_536541856891_item	2709751	et	4	main
need	doc_536541856891_item	2709758	et	3	main
tööst	doc_536541856891_item	2709763	et	3	main
peodest	doc_536541856891_item	2709766	et	3	main
ajaloost	doc_536541856891_item	2709768	et	4	main
ka	doc_536541856891_item	2709772	et	3	main
tähendab	doc_536541856891_item	2709776	et	3	main
et	doc_536541856891_item	2709777	et	3	main
armastuse	doc_536541856891_item	2709784	et	4	main
ei	doc_536541856891_item	2709787	et	4	main
rahva	doc_536541856891_item	2709799	et	3	main
võivad	doc_536541856891_item	2709817	et	4	main
laulupidude	doc_536541856891_item	2709822	et	4	main
süsteem	doc_536541856891_item	2709824	et	3	main
näitab	doc_536541856891_item	2709825	et	3	main
tsaari	doc_536541856891_item	2709837	et	4	main
ajastul	doc_536541856891_item	2709838	et	3	main
ja	doc_536541856891_item	2709839	et	3	main
nõukogude	doc_536541856891_item	2709840	et	3	main
ajal	doc_536541856891_item	2709841	et	4	main
laulupidu	doc_536541856891_item	2709849	et	4	main
tänapäeval	doc_536541856891_item	2709850	et	3	main
noored	doc_536541856891_item	2709851	et	3	main
ei	doc_536541856891_item	2709852	et	4	main
kus	doc_536541856891_item	2709878	et	3	main
kui	doc_536541856891_item	2709884	et	3	main
kaasaegset	doc_536541856891_item	2709886	et	3	main
eestlaste	doc_536541856891_item	2709894	et	4	main
unusta	doc_536541856891_item	2709908	et	4	main
kultuuri	doc_536541856891_item	2709911	et	4	main
oma	doc_536541856891_item	2709917	et	4	main
kuulsaks	doc_536541856891_item	2709919	et	4	main
laulukultuuriga	doc_536541856891_item	2709920	et	4	main
venemaa	doc_536541856891_item	2709836	et	4	main
patriotism	doc_536541856891_item	2709843	et	3	main
ja	doc_536541856891_item	2709846	et	3	main
festivale	doc_536541856891_item	2709860	et	3	main
ja	doc_536541856891_item	2709861	et	3	main
lauluüritusi	doc_536541856891_item	2709862	et	3	main
tehakse	doc_536541856891_item	2709863	et	3	main
ansambleid	doc_536541856891_item	2709864	et	3	main
kus	doc_536541856891_item	2709865	et	3	main
võib	doc_536541856891_item	2709866	et	3	main
kuulda	doc_536541856891_item	2709867	et	4	main
regilaule	doc_536541856891_item	2709868	et	4	main
setulaule	doc_536541856891_item	2709869	et	4	main
nendele	doc_536541856891_item	2709870	et	4	main
kes	doc_536541856891_item	2709871	et	4	main
eelistab	doc_536541856891_item	2709872	et	3	main
kaasaegset	doc_536541856891_item	2709873	et	3	main
muusikat	doc_536541856891_item	2709874	et	3	main
on	doc_536541856891_item	2709875	et	4	main
niisugused	doc_536541856891_item	2709876	et	3	main
laulud	doc_536541856891_item	2709877	et	3	main
võib	doc_536541856891_item	2709879	et	3	main
kuulda	doc_536541856891_item	2709881	et	4	main
rahvamuusikat	doc_536541856891_item	2709883	et	3	main
ka	doc_536541856891_item	2709885	et	3	main
popi	doc_536541856891_item	2709887	et	3	main
või	doc_536541856891_item	2709888	et	4	main
rocki	doc_536541856891_item	2709889	et	4	main
eurovisiooni	doc_536541856891_item	2709896	et	4	main
eesti	doc_536541856891_item	2709899	et	4	main
isegi	doc_536541856891_item	2709902	et	4	main
et	doc_536541856891_item	2709905	et	3	main
noored	doc_536541856891_item	2709906	et	3	main
ei	doc_536541856891_item	2709907	et	4	main
mis	doc_536541856891_item	2709923	et	4	main
armastus	doc_536541856891_item	2709932	et	4	main
vastu	doc_536541856891_item	2709937	et	3	main
võib	doc_536541856891_item	2709943	et	3	main
et	doc_536541856891_item	2709945	et	3	main
see	doc_536541856891_item	2709946	et	3	main
veel	doc_536541856891_item	2709948	et	4	main
kauaks	doc_536541856891_item	2709949	et	3	main
sest	doc_536541856891_item	2709950	et	4	main
noor	doc_536541856891_item	2709951	et	3	main
põlvkond	doc_536541856891_item	2709952	et	3	main
ei	doc_536541856891_item	2709953	et	4	main
traditsioone	doc_536541856891_item	2709956	et	3	main
kirjutamine	doc_536541856893_item	2710302	et	4	main
kirjutage	doc_536541856893_item	2710303	et	3	main
mis	doc_536541856893_item	2710306	et	4	main
laulurahva	doc_536541856893_item	2710309	et	3	main
300	doc_536541856893_item	2710312	et	2	main
edu	doc_536541856891_item	2709895	et	4	main
kus	doc_536541856891_item	2709898	et	3	main
oli	doc_536541856891_item	2709901	et	3	main
esimene	doc_536541856891_item	2709903	et	3	main
rahva	doc_536541856891_item	2709910	et	3	main
vaid	doc_536541856891_item	2709912	et	3	main
need	doc_536541856891_item	2709921	et	3	main
on	doc_536541856891_item	2709924	et	4	main
eestlastel	doc_536541856891_item	2709935	et	4	main
laulu	doc_536541856891_item	2709936	et	4	main
rahvast	doc_536541856891_item	2709940	et	4	main
ja	doc_536541856891_item	2709942	et	3	main
unusta	doc_536541856891_item	2709954	et	4	main
peab	doc_536541856891_item	2709958	et	4	main
nagu	doc_536541856891_item	2709960	et	3	main
jätkavad	doc_536541856891_item	2709913	et	4	main
samas	doc_536541856891_item	2709914	et	4	main
tempos	doc_536541856891_item	2709915	et	3	main
maad	doc_536541856891_item	2709918	et	4	main
eesti	doc_536541856891_item	2709928	et	4	main
rahvakultuuris	doc_536541856891_item	2709929	et	3	main
ja	doc_536541856891_item	2709930	et	3	main
see	doc_536541856891_item	2709931	et	3	main
eesti	doc_536541856891_item	2709939	et	4	main
lugu	doc_536541856891_item	2709963	et	4	main
traditsioonid	doc_536541856891_item	2709922	et	3	main
on	doc_536541856891_item	2709934	et	4	main
ja	doc_536541856891_item	2709957	et	3	main
laulust	doc_536541856891_item	2709959	et	4	main
rahvakultuuri	doc_536541856891_item	2709961	et	4	main
osast	doc_536541856891_item	2709962	et	4	main
essee	doc_536541856893_item	2710295	et	4	main
keele	doc_536541856893_item	2710297	et	4	main
essee	doc_536541856893_item	2710304	et	4	main
teemal	doc_536541856893_item	2710305	et	3	main
analüüsiv	doc_536541856893_item	2710319	et	4	main
eesti	doc_536541856893_item	2710296	et	4	main
kui	doc_536541856893_item	2710298	et	3	main
teise	doc_536541856893_item	2710299	et	4	main
eestlastest	doc_536541856893_item	2710308	et	4	main
essee	doc_536541856893_item	2710310	et	4	main
pikkus	doc_536541856893_item	2710311	et	4	main
350	doc_536541856893_item	2710313	et	2	main
peab	doc_536541856893_item	2710316	et	4	main
olema	doc_536541856893_item	2710317	et	4	main
lugemistekstis	doc_536541856893_item	2710325	et	3	main
faktidele	doc_536541856893_item	2710327	et	3	main
maailmas	doc_536541856893_item	2710337	et	3	main
mingit	doc_536541856893_item	2710338	et	3	main
teist	doc_536541856893_item	2710339	et	4	main
rahva	doc_536541856893_item	2710340	et	3	main
peale	doc_536541856893_item	2710341	et	4	main
eestlasi	doc_536541856893_item	2710342	et	3	main
laul	doc_536541856893_item	2710345	et	4	main
mängiksid	doc_536541856893_item	2710348	et	4	main
suurt	doc_536541856893_item	2710350	et	3	main
muusikaga	doc_536541856893_item	2710352	et	3	main
rahvuslik	doc_536541856893_item	2710356	et	3	main
toimus	doc_536541856893_item	2710359	et	3	main
on	doc_536541856893_item	2710396	et	4	main
üks	doc_536541856893_item	2710397	et	3	main
laulupeod	doc_536541856893_item	2710403	et	4	main
olid	doc_536541856893_item	2710404	et	4	main
nõukogudeajal	doc_536541856893_item	2710412	et	3	main
lõpus	doc_536541856893_item	2710425	et	4	main
sel	doc_536541856893_item	2710429	et	3	main
ajaloos	doc_536541856893_item	2710440	et	4	main
eesti	doc_536541856893_item	2710451	et	4	main
rahva	doc_536541856893_item	2710472	et	3	main
ajal	doc_536541856893_item	2710482	et	4	main
sajandil	doc_536541856893_item	2710492	et	3	main
üritusi	doc_536541856893_item	2710526	et	4	main
on	doc_536541856893_item	2710541	et	4	main
mida	doc_536541856893_item	2710544	et	4	main
rahvalaule	doc_536541856893_item	2710549	et	4	main
võib	doc_536541856893_item	2710551	et	3	main
eesti	doc_536541856893_item	2710560	et	4	main
ja	doc_536541856893_item	2710564	et	3	main
rahva	doc_536541856893_item	2710567	et	3	main
teeb	doc_536541856893_item	2710307	et	3	main
sõna	doc_536541856893_item	2710314	et	4	main
ja	doc_536541856893_item	2710320	et	3	main
soovitatav	doc_536541856893_item	2710330	et	4	main
illustreerida	doc_536541856893_item	2710331	et	3	main
näidetega	doc_536541856893_item	2710332	et	3	main
kelle	doc_536541856893_item	2710343	et	4	main
seotud	doc_536541856893_item	2710354	et	4	main
ärkamine	doc_536541856893_item	2710357	et	4	main
mida	doc_536541856893_item	2710358	et	4	main
19	doc_536541856893_item	2710360	et	2	main
sajandi	doc_536541856893_item	2710361	et	3	main
lõpus	doc_536541856893_item	2710362	et	4	main
keel	doc_536541856893_item	2710398	et	4	main
ja	doc_536541856893_item	2710399	et	3	main
kultuur	doc_536541856893_item	2710401	et	3	main
hakkas	doc_536541856893_item	2710421	et	3	main
ndate	doc_536541856893_item	2710424	et	4	main
eesti	doc_536541856893_item	2710439	et	4	main
revolutsiooni	doc_536541856893_item	2710449	et	4	main
millal	doc_536541856893_item	2710450	et	3	main
oma	doc_536541856893_item	2710454	et	4	main
iseseisav	doc_536541856893_item	2710457	et	4	main
selle	doc_536541856893_item	2710459	et	4	main
muusika	doc_536541856893_item	2710460	et	4	main
ja	doc_536541856893_item	2710461	et	3	main
laulud	doc_536541856893_item	2710462	et	3	main
rahvalauludes	doc_536541856893_item	2710470	et	3	main
olid	doc_536541856893_item	2710483	et	4	main
seas	doc_536541856893_item	2710523	et	4	main
ka	doc_536541856893_item	2710542	et	3	main
pop-ansamblid	doc_536541856893_item	2710543	et	3	main
repertuaaris	doc_536541856893_item	2710547	et	3	main
lõpuks	doc_536541856893_item	2710550	et	4	main
öelda	doc_536541856893_item	2710552	et	4	main
et	doc_536541856893_item	2710553	et	3	main
kõigepealt	doc_536541856893_item	2710554	et	3	main
muusika	doc_536541856893_item	2710555	et	4	main
ja	doc_536541856893_item	2710556	et	3	main
ajaloos	doc_536541856893_item	2710561	et	4	main
identiteedi	doc_536541856893_item	2710568	et	4	main
ja	doc_536541856893_item	2710572	et	3	main
laul	doc_536541856893_item	2710573	et	4	main
ka	doc_536541856893_item	2710575	et	3	main
keele	doc_536541856893_item	2710300	et	4	main
test	doc_536541856893_item	2710301	et	3	main
arutlev	doc_536541856893_item	2710318	et	4	main
loengus	doc_536541856893_item	2710323	et	3	main
ja	doc_536541856893_item	2710324	et	3	main
esitatud	doc_536541856893_item	2710326	et	4	main
raske	doc_536541856893_item	2710335	et	4	main
leida	doc_536541856893_item	2710336	et	3	main
ajaloos	doc_536541856893_item	2710344	et	4	main
on	doc_536541856893_item	2710353	et	4	main
tipphetkeks	doc_536541856893_item	2710364	et	4	main
oli	doc_536541856893_item	2710365	et	3	main
eestlastele	doc_536541856893_item	2710388	et	4	main
üks	doc_536541856893_item	2710393	et	3	main
rahvas	doc_536541856893_item	2710394	et	4	main
need	doc_536541856893_item	2710402	et	3	main
identiteedi	doc_536541856893_item	2710405	et	4	main
hoidjaks	doc_536541856893_item	2710406	et	4	main
ka	doc_536541856893_item	2710407	et	3	main
tsaristliku	doc_536541856893_item	2710408	et	3	main
laulmisega	doc_536541856893_item	2710413	et	4	main
lauldi	doc_536541856893_item	2710431	et	3	main
aru	doc_536541856893_item	2710443	et	4	main
kui	doc_536541856893_item	2710445	et	3	main
mäletada	doc_536541856893_item	2710446	et	3	main
olnud	doc_536541856893_item	2710464	et	4	main
tähtsad	doc_536541856893_item	2710466	et	3	main
sellepärast	doc_536541856893_item	2710468	et	3	main
minevik	doc_536541856893_item	2710473	et	3	main
sündmusest	doc_536541856893_item	2710479	et	4	main
surmani	doc_536541856893_item	2710480	et	3	main
vanal	doc_536541856893_item	2710481	et	3	main
19	doc_536541856893_item	2710491	et	2	main
noorte	doc_536541856893_item	2710521	et	3	main
palju	doc_536541856893_item	2710525	et	4	main
on	doc_536541856893_item	2710528	et	4	main
ka	doc_536541856893_item	2710537	et	3	main
vanu	doc_536541856893_item	2710548	et	4	main
alati	doc_536541856893_item	2710559	et	4	main
teiseks	doc_536541856893_item	2710570	et	4	main
olid	doc_536541856893_item	2710574	et	4	main
kultuurilise	doc_536541856893_item	2710576	et	4	main
tavapära	doc_536541856893_item	2710577	et	4	main
essee	doc_536541856893_item	2710315	et	4	main
üldistav	doc_536541856893_item	2710321	et	4	main
väiteid	doc_536541856893_item	2710328	et	4	main
on	doc_536541856893_item	2710329	et	4	main
tants	doc_536541856893_item	2710347	et	3	main
nii	doc_536541856893_item	2710349	et	3	main
selle	doc_536541856893_item	2710363	et	4	main
andsid	doc_536541856893_item	2710387	et	4	main
et	doc_536541856893_item	2710390	et	3	main
nendel	doc_536541856893_item	2710395	et	4	main
ajal	doc_536541856893_item	2710410	et	4	main
on	doc_536541856893_item	2710414	et	4	main
nn	doc_536541856893_item	2710417	et	4	main
toimuma	doc_536541856893_item	2710422	et	3	main
viis	doc_536541856893_item	2710427	et	4	main
ajal	doc_536541856893_item	2710430	et	4	main
isamaalisi	doc_536541856893_item	2710433	et	4	main
laulu	doc_536541856893_item	2710434	et	4	main
kui	doc_536541856893_item	2710435	et	3	main
suurt	doc_536541856893_item	2710436	et	3	main
laul	doc_536541856893_item	2710441	et	4	main
rahvas	doc_536541856893_item	2710452	et	4	main
väljendas	doc_536541856893_item	2710453	et	3	main
olla	doc_536541856893_item	2710456	et	3	main
peale	doc_536541856893_item	2710458	et	4	main
nii	doc_536541856893_item	2710465	et	3	main
et	doc_536541856893_item	2710469	et	3	main
ajal	doc_536541856893_item	2710475	et	4	main
regivärsilised	doc_536541856893_item	2710484	et	4	main
laulud	doc_536541856893_item	2710485	et	3	main
siis	doc_536541856893_item	2710486	et	3	main
tulid	doc_536541856893_item	2710487	et	4	main
vaimulikud	doc_536541856893_item	2710488	et	3	main
laulud	doc_536541856893_item	2710489	et	3	main
ja	doc_536541856893_item	2710490	et	3	main
inimeste	doc_536541856893_item	2710522	et	3	main
viljandi	doc_536541856893_item	2710532	et	4	main
folkloori	doc_536541856893_item	2710533	et	4	main
festivaal	doc_536541856893_item	2710534	et	4	main
kus	doc_536541856893_item	2710535	et	3	main
muinasjuttude	doc_536541856893_item	2710538	et	4	main
jutustamine	doc_536541856893_item	2710539	et	4	main
populaarsed	doc_536541856893_item	2710540	et	3	main
oma	doc_536541856893_item	2710546	et	4	main
laul	doc_536541856893_item	2710557	et	4	main
ühinevat	doc_536541856893_item	2710562	et	4	main
olid	doc_536541856893_item	2710565	et	4	main
tuginema	doc_536541856893_item	2710322	et	3	main
arvatavasti	doc_536541856893_item	2710333	et	3	main
on	doc_536541856893_item	2710334	et	4	main
ja	doc_536541856893_item	2710346	et	3	main
rolli	doc_536541856893_item	2710351	et	4	main
eestlaste	doc_536541856893_item	2710355	et	4	main
esimene	doc_536541856893_item	2710366	et	3	main
ülemaaline	doc_536541856893_item	2710367	et	4	main
laulupidu	doc_536541856893_item	2710368	et	4	main
1869	doc_536541856893_item	2710369	et	2	main
aastal	doc_536541856893_item	2710370	et	3	main
tartus	doc_536541856893_item	2710371	et	3	main
see	doc_536541856893_item	2710372	et	3	main
esimene	doc_536541856893_item	2710373	et	3	main
laulupidu	doc_536541856893_item	2710374	et	4	main
ja	doc_536541856893_item	2710375	et	3	main
teised	doc_536541856893_item	2710376	et	4	main
laulupidusid	doc_536541856893_item	2710377	et	4	main
mida	doc_536541856893_item	2710378	et	4	main
korraldati	doc_536541856893_item	2710379	et	3	main
hiljem	doc_536541856893_item	2710380	et	3	main
olid	doc_536541856893_item	2710381	et	4	main
väga	doc_536541856893_item	2710382	et	3	main
tähtsad	doc_536541856893_item	2710383	et	3	main
eestlaste	doc_536541856893_item	2710384	et	4	main
jaoks	doc_536541856893_item	2710385	et	4	main
nad	doc_536541856893_item	2710386	et	3	main
arusaam	doc_536541856893_item	2710389	et	3	main
nad	doc_536541856893_item	2710391	et	3	main
on	doc_536541856893_item	2710392	et	4	main
üks	doc_536541856893_item	2710400	et	3	main
venemaa	doc_536541856893_item	2710409	et	4	main
ja	doc_536541856893_item	2710411	et	3	main
seotud	doc_536541856893_item	2710415	et	4	main
ka	doc_536541856893_item	2710416	et	3	main
teine	doc_536541856893_item	2710418	et	3	main
ärkamisaeg	doc_536541856893_item	2710419	et	3	main
mida	doc_536541856893_item	2710420	et	4	main
1980	doc_536541856893_item	2710423	et	2	main
ja	doc_536541856893_item	2710426	et	3	main
taasiseseisvumiseni	doc_536541856893_item	2710428	et	3	main
laulupidudel	doc_536541856893_item	2710432	et	4	main
rolli	doc_536541856893_item	2710437	et	4	main
mängib	doc_536541856893_item	2710438	et	3	main
võib	doc_536541856893_item	2710442	et	3	main
saada	doc_536541856893_item	2710444	et	4	main
nn	doc_536541856893_item	2710447	et	4	main
laulevat	doc_536541856893_item	2710448	et	4	main
soovi	doc_536541856893_item	2710455	et	4	main
on	doc_536541856893_item	2710463	et	4	main
ka	doc_536541856893_item	2710467	et	3	main
kajastab	doc_536541856893_item	2710471	et	3	main
vanal	doc_536541856893_item	2710474	et	3	main
saatis	doc_536541856893_item	2710476	et	3	main
laul	doc_536541856893_item	2710477	et	4	main
eestlast	doc_536541856893_item	2710478	et	4	main
tekkis	doc_536541856893_item	2710493	et	3	main
uus	doc_536541856893_item	2710494	et	3	main
riimiline	doc_536541856893_item	2710495	et	4	main
rahvalaul	doc_536541856893_item	2710496	et	4	main
palju	doc_536541856893_item	2710497	et	4	main
oli	doc_536541856893_item	2710498	et	3	main
võetud	doc_536541856893_item	2710499	et	4	main
ka	doc_536541856893_item	2710500	et	3	main
läti	doc_536541856893_item	2710501	et	4	main
ja	doc_536541856893_item	2710502	et	3	main
vene	doc_536541856893_item	2710503	et	4	main
muusikast	doc_536541856893_item	2710504	et	4	main
ka	doc_536541856893_item	2710505	et	3	main
praegu	doc_536541856893_item	2710506	et	3	main
jääb	doc_536541856893_item	2710507	et	3	main
rahvalaul	doc_536541856893_item	2710508	et	4	main
populaarsemaks	doc_536541856893_item	2710509	et	4	main
eestis	doc_536541856893_item	2710510	et	3	main
ja	doc_536541856893_item	2710511	et	3	main
tore	doc_536541856893_item	2710512	et	3	main
on	doc_536541856893_item	2710513	et	4	main
ka	doc_536541856893_item	2710514	et	3	main
see	doc_536541856893_item	2710515	et	3	main
et	doc_536541856893_item	2710516	et	3	main
rahvalaulud	doc_536541856893_item	2710517	et	3	main
populaarsed	doc_536541856893_item	2710519	et	3	main
ka	doc_536541856893_item	2710520	et	3	main
on	doc_536541856893_item	2710518	et	4	main
toimub	doc_536541856893_item	2710524	et	3	main
mis	doc_536541856893_item	2710527	et	4	main
seotud	doc_536541856893_item	2710529	et	4	main
rahvamuusikaga	doc_536541856893_item	2710530	et	3	main
näiteks	doc_536541856893_item	2710531	et	4	main
toimub	doc_536541856893_item	2710536	et	3	main
kasutavad	doc_536541856893_item	2710545	et	4	main
mängisid	doc_536541856893_item	2710558	et	4	main
rolli	doc_536541856893_item	2710563	et	4	main
eesti	doc_536541856893_item	2710566	et	4	main
muusika	doc_536541856893_item	2710571	et	4	main
hoidjaks	doc_536541856893_item	2710578	et	4	main
hoidjaks	doc_536541856893_item	2710569	et	4	main
teise	doc_536541856896_item	2711153	et	4	main
laulurahva	doc_536541856896_item	2711163	et	3	main
essee	doc_536541856896_item	2711164	et	4	main
sõna	doc_536541856896_item	2711168	et	4	main
peab	doc_536541856896_item	2711170	et	4	main
olema	doc_536541856896_item	2711171	et	4	main
keele	doc_536541856896_item	2711151	et	4	main
kui	doc_536541856896_item	2711152	et	3	main
350	doc_536541856896_item	2711167	et	2	main
essee	doc_536541856896_item	2711169	et	4	main
ja	doc_536541856896_item	2711174	et	3	main
loengus	doc_536541856896_item	2711177	et	3	main
väiteid	doc_536541856896_item	2711182	et	4	main
näidetega	doc_536541856896_item	2711186	et	3	main
mis	doc_536541856896_item	2711187	et	4	main
teeb	doc_536541856896_item	2711188	et	3	main
ehk	doc_536541856896_item	2711201	et	3	main
et	doc_536541856896_item	2711214	et	3	main
laulurahvas	doc_536541856896_item	2711217	et	4	main
peab	doc_536541856896_item	2711219	et	4	main
essee	doc_536541856896_item	2711149	et	4	main
eesti	doc_536541856896_item	2711150	et	4	main
300	doc_536541856896_item	2711166	et	2	main
tuginema	doc_536541856896_item	2711176	et	3	main
lugemistekstis	doc_536541856896_item	2711179	et	3	main
eestlastest	doc_536541856896_item	2711189	et	4	main
sarnaseid	doc_536541856896_item	2711191	et	4	main
teemasid	doc_536541856896_item	2711192	et	3	main
võib	doc_536541856896_item	2711193	et	3	main
üsna	doc_536541856896_item	2711194	et	3	main
tähtsaks	doc_536541856896_item	2711210	et	4	main
miks	doc_536541856896_item	2711211	et	4	main
siis	doc_536541856896_item	2711212	et	3	main
arvatakse	doc_536541856896_item	2711213	et	3	main
eestlased	doc_536541856896_item	2711215	et	3	main
selleks	doc_536541856896_item	2711218	et	4	main
keele	doc_536541856896_item	2711154	et	4	main
test	doc_536541856896_item	2711155	et	3	main
kirjutamine	doc_536541856896_item	2711156	et	4	main
kirjutage	doc_536541856896_item	2711157	et	3	main
essee	doc_536541856896_item	2711158	et	4	main
teemal	doc_536541856896_item	2711159	et	3	main
mis	doc_536541856896_item	2711160	et	4	main
teeb	doc_536541856896_item	2711161	et	3	main
eestlastest	doc_536541856896_item	2711162	et	4	main
pikkus	doc_536541856896_item	2711165	et	4	main
analüüsiv	doc_536541856896_item	2711173	et	4	main
esitatud	doc_536541856896_item	2711180	et	4	main
faktidele	doc_536541856896_item	2711181	et	3	main
laulurahva	doc_536541856896_item	2711190	et	3	main
tihti	doc_536541856896_item	2711195	et	3	main
keelt	doc_536541856896_item	2711198	et	4	main
kultuuri	doc_536541856896_item	2711203	et	4	main
teemat	doc_536541856896_item	2711204	et	3	main
käsitletakse	doc_536541856896_item	2711205	et	3	main
igalpool	doc_536541856896_item	2711206	et	4	main
ja	doc_536541856896_item	2711207	et	3	main
peetakse	doc_536541856896_item	2711208	et	3	main
väga	doc_536541856896_item	2711209	et	3	main
on	doc_536541856896_item	2711216	et	4	main
ja	doc_536541856896_item	2711224	et	3	main
algusaegu	doc_536541856896_item	2711227	et	3	main
laulmine	doc_536541856896_item	2711228	et	4	main
üsna	doc_536541856896_item	2711230	et	3	main
tähtis	doc_536541856896_item	2711231	et	4	main
kultuuris	doc_536541856896_item	2711236	et	3	main
ära	doc_536541856896_item	2711246	et	4	main
laulmine	doc_536541856896_item	2711274	et	4	main
suur	doc_536541856896_item	2711277	et	3	main
eestlaste	doc_536541856896_item	2711279	et	4	main
elust	doc_536541856896_item	2711280	et	3	main
rääkida	doc_536541856896_item	2711289	et	3	main
ja	doc_536541856896_item	2711291	et	3	main
kuid	doc_536541856896_item	2711332	et	4	main
ja	doc_536541856896_item	2711337	et	3	main
nii	doc_536541856896_item	2711339	et	3	main
levinud	doc_536541856896_item	2711341	et	4	main
eestlaste	doc_536541856896_item	2711342	et	4	main
pärandamine	doc_536541856896_item	2711347	et	4	main
suulisel	doc_536541856896_item	2711348	et	4	main
teeks	doc_536541856896_item	2711351	et	4	main
18st	doc_536541856896_item	2711367	et	3	main
sajandist	doc_536541856896_item	2711368	et	3	main
millal	doc_536541856896_item	2711369	et	3	main
ka	doc_536541856896_item	2711373	et	3	main
laulmine	doc_536541856896_item	2711376	et	4	main
levimine	doc_536541856896_item	2711378	et	4	main
eestlase	doc_536541856896_item	2711381	et	3	main
mille	doc_536541856896_item	2711386	et	3	main
folkloor	doc_536541856896_item	2711392	et	4	main
seda	doc_536541856896_item	2711393	et	3	main
näitab	doc_536541856896_item	2711394	et	3	main
lõpus	doc_536541856896_item	2711403	et	4	main
muutusid	doc_536541856896_item	2711410	et	4	main
populaarsed	doc_536541856896_item	2711417	et	3	main
seas	doc_536541856896_item	2711419	et	4	main
iga	doc_536541856896_item	2711420	et	4	main
arutlev	doc_536541856896_item	2711172	et	4	main
on	doc_536541856896_item	2711183	et	4	main
soovitatav	doc_536541856896_item	2711184	et	4	main
illustreerida	doc_536541856896_item	2711185	et	3	main
kohata	doc_536541856896_item	2711196	et	4	main
tuletama	doc_536541856896_item	2711221	et	3	main
kultuurinähtus	doc_536541856896_item	2711232	et	4	main
märkima	doc_536541856896_item	2711247	et	4	main
seda	doc_536541856896_item	2711248	et	3	main
et	doc_536541856896_item	2711249	et	3	main
koos	doc_536541856896_item	2711253	et	4	main
erinevatel	doc_536541856896_item	2711258	et	4	main
mehed	doc_536541856896_item	2711261	et	3	main
kui	doc_536541856896_item	2711262	et	3	main
sellisel	doc_536541856896_item	2711281	et	4	main
viisil	doc_536541856896_item	2711282	et	4	main
taheti	doc_536541856896_item	2711283	et	3	main
elu	doc_536541856896_item	2711286	et	4	main
heast	doc_536541856896_item	2711290	et	3	main
või	doc_536541856896_item	2711296	et	4	main
rõõmudest	doc_536541856896_item	2711298	et	3	main
muust	doc_536541856896_item	2711331	et	4	main
oli	doc_536541856896_item	2711335	et	3	main
laulmiskultuur	doc_536541856896_item	2711338	et	3	main
palju	doc_536541856896_item	2711340	et	4	main
seas	doc_536541856896_item	2711343	et	4	main
ainuüksi	doc_536541856896_item	2711344	et	3	main
viisil	doc_536541856896_item	2711349	et	4	main
seda	doc_536541856896_item	2711352	et	3	main
ristiusu	doc_536541856896_item	2711370	et	3	main
vaimulike	doc_536541856896_item	2711374	et	3	main
väga	doc_536541856896_item	2711383	et	3	main
suureosaliselt	doc_536541856896_item	2711389	et	4	main
toimunud	doc_536541856896_item	2711406	et	4	main
laulupeod	doc_536541856896_item	2711409	et	4	main
ajaloolise	doc_536541856896_item	2711411	et	4	main
tähtsusega	doc_536541856896_item	2711412	et	4	main
sündmusteks	doc_536541856896_item	2711413	et	3	main
ja	doc_536541856896_item	2711414	et	3	main
ja	doc_536541856896_item	2711438	et	3	main
kaotanud	doc_536541856896_item	2711453	et	4	main
nad	doc_536541856896_item	2711454	et	3	main
suurenes	doc_536541856896_item	2711460	et	4	main
osavõtjate	doc_536541856896_item	2711461	et	3	main
30	doc_536541856896_item	2711463	et	2	main
peod	doc_536541856896_item	2711469	et	4	main
rahvusliku	doc_536541856896_item	2711471	et	3	main
hoidjaks	doc_536541856896_item	2711473	et	4	main
ja	doc_536541856896_item	2711474	et	3	main
nagu	doc_536541856896_item	2711475	et	3	main
arvata	doc_536541856896_item	2711476	et	4	main
võib	doc_536541856896_item	2711483	et	3	main
et	doc_536541856896_item	2711485	et	3	main
süvenedes	doc_536541856896_item	2711498	et	3	main
sellesse	doc_536541856896_item	2711499	et	4	main
natuke	doc_536541856896_item	2711500	et	4	main
saada	doc_536541856896_item	2711505	et	4	main
laul	doc_536541856896_item	2711507	et	4	main
kultuuri	doc_536541856896_item	2711517	et	4	main
et	doc_536541856896_item	2711521	et	3	main
on	doc_536541856896_item	2711523	et	4	main
üheks	doc_536541856896_item	2711525	et	3	main
kõige	doc_536541856896_item	2711526	et	4	main
soovida	doc_536541856896_item	2711535	et	4	main
edaspidiseks	doc_536541856896_item	2711537	et	4	main
üldistav	doc_536541856896_item	2711175	et	4	main
ja	doc_536541856896_item	2711178	et	3	main
eesti	doc_536541856896_item	2711197	et	4	main
õppides	doc_536541856896_item	2711199	et	4	main
seda	doc_536541856896_item	2711200	et	3	main
laulurahva	doc_536541856896_item	2711202	et	3	main
eesti	doc_536541856896_item	2711222	et	4	main
peaaegu	doc_536541856896_item	2711233	et	3	main
kui	doc_536541856896_item	2711237	et	3	main
räägime	doc_536541856896_item	2711239	et	3	main
eesti	doc_536541856896_item	2711241	et	4	main
kultuurist	doc_536541856896_item	2711242	et	3	main
siis	doc_536541856896_item	2711243	et	3	main
peame	doc_536541856896_item	2711244	et	4	main
kindlasti	doc_536541856896_item	2711245	et	3	main
laul	doc_536541856896_item	2711250	et	4	main
näidata	doc_536541856896_item	2711284	et	4	main
olu	doc_536541856896_item	2711288	et	4	main
väikestest	doc_536541856896_item	2711294	et	4	main
tähtpäevade	doc_536541856896_item	2711301	et	3	main
pidude	doc_536541856896_item	2711303	et	4	main
paljust	doc_536541856896_item	2711330	et	4	main
miks	doc_536541856896_item	2711334	et	4	main
pika	doc_536541856896_item	2711362	et	4	main
kaasnes	doc_536541856896_item	2711372	et	3	main
oli	doc_536541856896_item	2711380	et	3	main
jaoks	doc_536541856896_item	2711382	et	4	main
alusel	doc_536541856896_item	2711387	et	4	main
arenema	doc_536541856896_item	2711390	et	3	main
ka	doc_536541856896_item	2711395	et	3	main
rahvuslik	doc_536541856896_item	2711397	et	3	main
korda	doc_536541856896_item	2711405	et	4	main
1869	doc_536541856896_item	2711408	et	2	main
eestlaste	doc_536541856896_item	2711418	et	4	main
näiteks	doc_536541856896_item	2711428	et	4	main
senistele	doc_536541856896_item	2711429	et	3	main
meeskooridele	doc_536541856896_item	2711430	et	4	main
laste-	doc_536541856896_item	2711437	et	4	main
poistekoorid	doc_536541856896_item	2711439	et	3	main
sajandi	doc_536541856896_item	2711444	et	3	main
kommunistliku	doc_536541856896_item	2711448	et	3	main
need	doc_536541856896_item	2711468	et	3	main
identiteedi	doc_536541856896_item	2711472	et	4	main
viis	doc_536541856896_item	2711478	et	4	main
see	doc_536541856896_item	2711479	et	3	main
eesti	doc_536541856896_item	2711480	et	4	main
taasiseseisvumiseni	doc_536541856896_item	2711481	et	3	main
kokkuvõtteks	doc_536541856896_item	2711482	et	3	main
eesti	doc_536541856896_item	2711494	et	4	main
rohkem	doc_536541856896_item	2711501	et	4	main
aru	doc_536541856896_item	2711504	et	4	main
oma	doc_536541856896_item	2711514	et	4	main
rikastada	doc_536541856896_item	2711518	et	3	main
selleni	doc_536541856896_item	2711520	et	3	main
laulvamaks	doc_536541856896_item	2711527	et	4	main
ei	doc_536541856896_item	2711530	et	4	main
lisada	doc_536541856896_item	2711532	et	3	main
edu	doc_536541856896_item	2711536	et	4	main
folkloori	doc_536541856896_item	2711538	et	4	main
meelde	doc_536541856896_item	2711220	et	3	main
kultuuri	doc_536541856896_item	2711223	et	4	main
kultuuri	doc_536541856896_item	2711226	et	4	main
et	doc_536541856896_item	2711234	et	3	main
me	doc_536541856896_item	2711238	et	4	main
eestlasega	doc_536541856896_item	2711252	et	3	main
sündimisest	doc_536541856896_item	2711254	et	4	main
nii	doc_536541856896_item	2711260	et	3	main
ka	doc_536541856896_item	2711263	et	3	main
laulsid	doc_536541856896_item	2711265	et	4	main
tööd	doc_536541856896_item	2711266	et	4	main
tehes	doc_536541856896_item	2711267	et	3	main
kokku	doc_536541856896_item	2711268	et	3	main
saades	doc_536541856896_item	2711269	et	3	main
lauldi	doc_536541856896_item	2711270	et	3	main
ka	doc_536541856896_item	2711271	et	3	main
lastega	doc_536541856896_item	2711272	et	3	main
tegeledes	doc_536541856896_item	2711273	et	3	main
päris	doc_536541856896_item	2711276	et	4	main
ja	doc_536541856896_item	2711287	et	3	main
oma	doc_536541856896_item	2711293	et	4	main
probleemidest	doc_536541856896_item	2711295	et	3	main
lauldi	doc_536541856896_item	2711300	et	3	main
ajal	doc_536541856896_item	2711302	et	4	main
me	doc_536541856896_item	2711321	et	4	main
teame	doc_536541856896_item	2711323	et	3	main
folkloor	doc_536541856896_item	2711325	et	4	main
tantsudest	doc_536541856896_item	2711327	et	3	main
kirjandusest	doc_536541856896_item	2711328	et	4	main
ja	doc_536541856896_item	2711329	et	3	main
põlve	doc_536541856896_item	2711346	et	4	main
selle	doc_536541856896_item	2711359	et	4	main
identiteeditunne	doc_536541856896_item	2711385	et	3	main
hakkas	doc_536541856896_item	2711388	et	3	main
eesti	doc_536541856896_item	2711391	et	4	main
eestlaste	doc_536541856896_item	2711396	et	4	main
ärkamine	doc_536541856896_item	2711398	et	4	main
esimest	doc_536541856896_item	2711404	et	4	main
osalejate	doc_536541856896_item	2711422	et	4	main
liitusid	doc_536541856896_item	2711431	et	4	main
ka	doc_536541856896_item	2711432	et	3	main
vaatamata	doc_536541856896_item	2711440	et	4	main
xx	doc_536541856896_item	2711443	et	4	main
keskel	doc_536541856896_item	2711445	et	3	main
arv	doc_536541856896_item	2711462	et	3	main
000	doc_536541856896_item	2711464	et	2	main
laulja	doc_536541856896_item	2711465	et	4	main
ja	doc_536541856896_item	2711466	et	3	main
rahvas	doc_536541856896_item	2711487	et	4	main
võime	doc_536541856896_item	2711502	et	4	main
eestlastega	doc_536541856896_item	2711509	et	4	main
ja	doc_536541856896_item	2711516	et	3	main
selle	doc_536541856896_item	2711225	et	4	main
on	doc_536541856896_item	2711229	et	4	main
igas	doc_536541856896_item	2711235	et	3	main
konkreetselt	doc_536541856896_item	2711240	et	4	main
oli	doc_536541856896_item	2711251	et	3	main
surmani	doc_536541856896_item	2711255	et	3	main
lauldi	doc_536541856896_item	2711256	et	3	main
tihti	doc_536541856896_item	2711257	et	3	main
põhjustel	doc_536541856896_item	2711259	et	3	main
naised	doc_536541856896_item	2711264	et	3	main
oli	doc_536541856896_item	2711275	et	3	main
osa	doc_536541856896_item	2711278	et	4	main
oma	doc_536541856896_item	2711285	et	4	main
halvast	doc_536541856896_item	2711292	et	3	main
suurtest	doc_536541856896_item	2711297	et	4	main
samuti	doc_536541856896_item	2711299	et	3	main
ajal	doc_536541856896_item	2711304	et	4	main
ja	doc_536541856896_item	2711305	et	3	main
paljudel	doc_536541856896_item	2711306	et	3	main
muudel	doc_536541856896_item	2711307	et	4	main
põhjustel	doc_536541856896_item	2711308	et	3	main
võib	doc_536541856896_item	2711309	et	3	main
arvata	doc_536541856896_item	2711310	et	4	main
et	doc_536541856896_item	2711311	et	3	main
laulud	doc_536541856896_item	2711312	et	3	main
moodustasid	doc_536541856896_item	2711313	et	4	main
1	doc_536541856896_item	2711314	et	2	main
suure	doc_536541856896_item	2711315	et	3	main
osa	doc_536541856896_item	2711316	et	4	main
kogu	doc_536541856896_item	2711317	et	4	main
eesti	doc_536541856896_item	2711318	et	4	main
folkloorist	doc_536541856896_item	2711319	et	4	main
nagu	doc_536541856896_item	2711320	et	3	main
kõik	doc_536541856896_item	2711322	et	4	main
koosneb	doc_536541856896_item	2711324	et	3	main
ka	doc_536541856896_item	2711326	et	3	main
siiski	doc_536541856896_item	2711333	et	4	main
laul	doc_536541856896_item	2711336	et	4	main
põlvest	doc_536541856896_item	2711345	et	4	main
ei	doc_536541856896_item	2711350	et	4	main
kultuuri	doc_536541856896_item	2711353	et	4	main
nii	doc_536541856896_item	2711354	et	3	main
massiliseks	doc_536541856896_item	2711355	et	4	main
ma	doc_536541856896_item	2711356	et	3	main
arvan	doc_536541856896_item	2711357	et	3	main
et	doc_536541856896_item	2711358	et	3	main
ja	doc_536541856896_item	2711361	et	3	main
suure	doc_536541856896_item	2711360	et	3	main
teekonna	doc_536541856896_item	2711363	et	4	main
alguse	doc_536541856896_item	2711364	et	3	main
võime	doc_536541856896_item	2711365	et	4	main
leida	doc_536541856896_item	2711366	et	3	main
levimisega	doc_536541856896_item	2711371	et	4	main
laulude	doc_536541856896_item	2711375	et	3	main
ja	doc_536541856896_item	2711377	et	3	main
samuti	doc_536541856896_item	2711379	et	3	main
tähtis	doc_536541856896_item	2711384	et	4	main
mis	doc_536541856896_item	2711399	et	4	main
toimus	doc_536541856896_item	2711400	et	3	main
19	doc_536541856896_item	2711401	et	2	main
sajandi	doc_536541856896_item	2711402	et	3	main
aastal	doc_536541856896_item	2711407	et	3	main
olid	doc_536541856896_item	2711415	et	4	main
väga	doc_536541856896_item	2711416	et	3	main
korraga	doc_536541856896_item	2711421	et	4	main
arv	doc_536541856896_item	2711423	et	3	main
ja	doc_536541856896_item	2711424	et	3	main
ringkond	doc_536541856896_item	2711425	et	3	main
aina	doc_536541856896_item	2711426	et	4	main
erinevatel	doc_536541856896_item	2711433	et	4	main
sellele	doc_536541856896_item	2711441	et	4	main
näiteks	doc_536541856896_item	2711457	et	4	main
aastaks	doc_536541856896_item	2711458	et	4	main
1960	doc_536541856896_item	2711459	et	2	main
öelda	doc_536541856896_item	2711484	et	4	main
on	doc_536541856896_item	2711488	et	4	main
alati	doc_536541856896_item	2711490	et	4	main
kultuuri	doc_536541856896_item	2711495	et	4	main
ajalugu	doc_536541856896_item	2711496	et	4	main
ja	doc_536541856896_item	2711497	et	3	main
folkloori	doc_536541856896_item	2711515	et	4	main
muud	doc_536541856896_item	2711529	et	4	main
oskagi	doc_536541856896_item	2711531	et	4	main
kui	doc_536541856896_item	2711533	et	3	main
arendamiseks	doc_536541856896_item	2711539	et	4	main
suurenes	doc_536541856896_item	2711427	et	4	main
aastatel	doc_536541856896_item	2711434	et	4	main
segakoorid	doc_536541856896_item	2711435	et	3	main
naiste-	doc_536541856896_item	2711436	et	3	main
et	doc_536541856896_item	2711442	et	3	main
olid	doc_536541856896_item	2711446	et	4	main
laulupeod	doc_536541856896_item	2711447	et	4	main
partei	doc_536541856896_item	2711449	et	4	main
kontrolli	doc_536541856896_item	2711450	et	4	main
all	doc_536541856896_item	2711451	et	3	main
ei	doc_536541856896_item	2711452	et	4	main
oma	doc_536541856896_item	2711455	et	4	main
populaarsust	doc_536541856896_item	2711456	et	4	main
pillimängijani	doc_536541856896_item	2711467	et	3	main
kujunesid	doc_536541856896_item	2711470	et	4	main
võis	doc_536541856896_item	2711477	et	4	main
eesti	doc_536541856896_item	2711486	et	4	main
tõesti	doc_536541856896_item	2711489	et	3	main
olnud	doc_536541856896_item	2711491	et	4	main
laulurahvana	doc_536541856896_item	2711492	et	3	main
uurides	doc_536541856896_item	2711493	et	4	main
kergelt	doc_536541856896_item	2711503	et	4	main
et	doc_536541856896_item	2711506	et	3	main
oli	doc_536541856896_item	2711508	et	3	main
koos	doc_536541856896_item	2711510	et	4	main
hällist	doc_536541856896_item	2711511	et	4	main
hauani	doc_536541856896_item	2711512	et	3	main
soov	doc_536541856896_item	2711513	et	3	main
viis	doc_536541856896_item	2711519	et	4	main
rahvuseks	doc_536541856896_item	2711528	et	4	main
vaid	doc_536541856896_item	2711534	et	3	main
eestlased	doc_536541856896_item	2711522	et	3	main
saanud	doc_536541856896_item	2711524	et	4	main
essee	doc_536541856898_item	2711816	et	4	main
kirjutamine	doc_536541856898_item	2711823	et	4	main
essee	doc_536541856898_item	2711825	et	4	main
teemal	doc_536541856898_item	2711826	et	3	main
mis	doc_536541856898_item	2711827	et	4	main
teeb	doc_536541856898_item	2711828	et	3	main
essee	doc_536541856898_item	2711836	et	4	main
loengus	doc_536541856898_item	2711844	et	3	main
lugemistekstis	doc_536541856898_item	2711846	et	3	main
faktidele	doc_536541856898_item	2711848	et	3	main
on	doc_536541856898_item	2711850	et	4	main
soovitatav	doc_536541856898_item	2711851	et	4	main
aegadest	doc_536541856898_item	2711858	et	3	main
eestlased	doc_536541856898_item	2711862	et	3	main
kui	doc_536541856898_item	2711864	et	3	main
eestlastest	doc_536541856898_item	2711886	et	4	main
komme	doc_536541856898_item	2711890	et	4	main
ajalooliselt	doc_536541856898_item	2711892	et	4	main
võib	doc_536541856898_item	2711893	et	3	main
kaheks	doc_536541856898_item	2711897	et	4	main
ja	doc_536541856898_item	2711900	et	3	main
rahvalaul	doc_536541856898_item	2711902	et	4	main
illustreerib	doc_536541856898_item	2711905	et	3	main
lauludes	doc_536541856898_item	2711910	et	3	main
silt	doc_536541856898_item	2711915	et	4	main
see	doc_536541856898_item	2711916	et	3	main
eestlastel	doc_536541856898_item	2711920	et	4	main
kujunenud	doc_536541856898_item	2711924	et	4	main
uuem	doc_536541856898_item	2711927	et	4	main
18	doc_536541856898_item	2711930	et	2	main
sajandi	doc_536541856898_item	2711931	et	3	main
alguses	doc_536541856898_item	2711932	et	4	main
keele	doc_536541856898_item	2711821	et	4	main
kirjutage	doc_536541856898_item	2711824	et	3	main
350	doc_536541856898_item	2711834	et	2	main
peab	doc_536541856898_item	2711837	et	4	main
tuginema	doc_536541856898_item	2711843	et	3	main
ja	doc_536541856898_item	2711845	et	3	main
esitatud	doc_536541856898_item	2711847	et	4	main
näidetega	doc_536541856898_item	2711853	et	3	main
olid	doc_536541856898_item	2711866	et	4	main
teeb	doc_536541856898_item	2711888	et	3	main
jagada	doc_536541856898_item	2711896	et	3	main
rahvalaul	doc_536541856898_item	2711908	et	4	main
vanemates	doc_536541856898_item	2711909	et	4	main
näitab	doc_536541856898_item	2711918	et	3	main
aastatega	doc_536541856898_item	2711926	et	3	main
rahvalaul	doc_536541856898_item	2711928	et	4	main
tekkis	doc_536541856898_item	2711929	et	3	main
sajandil	doc_536541856898_item	2711945	et	3	main
oli	doc_536541856898_item	2711946	et	3	main
riim	doc_536541856898_item	2711947	et	3	main
kui	doc_536541856898_item	2711819	et	3	main
teise	doc_536541856898_item	2711820	et	4	main
eesti	doc_536541856898_item	2711817	et	4	main
keele	doc_536541856898_item	2711818	et	4	main
test	doc_536541856898_item	2711822	et	3	main
analüüsiv	doc_536541856898_item	2711840	et	4	main
ja	doc_536541856898_item	2711841	et	3	main
väiteid	doc_536541856898_item	2711849	et	4	main
eesti	doc_536541856898_item	2711854	et	4	main
rahvas	doc_536541856898_item	2711855	et	4	main
laulurahvas	doc_536541856898_item	2711860	et	4	main
vanasti	doc_536541856898_item	2711861	et	3	main
laulu	doc_536541856898_item	2711895	et	4	main
vanem	doc_536541856898_item	2711899	et	4	main
uuem	doc_536541856898_item	2711901	et	4	main
laulutraditsiooni	doc_536541856898_item	2711904	et	4	main
regiväeline	doc_536541856898_item	2711907	et	4	main
on	doc_536541856898_item	2711911	et	4	main
olnud	doc_536541856898_item	2711912	et	4	main
fakt	doc_536541856898_item	2711917	et	3	main
et	doc_536541856898_item	2711919	et	3	main
eestlastest	doc_536541856898_item	2711829	et	4	main
laulurahva	doc_536541856898_item	2711830	et	3	main
essee	doc_536541856898_item	2711831	et	4	main
pikkus	doc_536541856898_item	2711832	et	4	main
300	doc_536541856898_item	2711833	et	2	main
üldistav	doc_536541856898_item	2711842	et	4	main
muistsetest	doc_536541856898_item	2711857	et	3	main
nende	doc_536541856898_item	2711889	et	4	main
laulda	doc_536541856898_item	2711891	et	4	main
eesti	doc_536541856898_item	2711894	et	4	main
perioodiks	doc_536541856898_item	2711898	et	3	main
vanemat	doc_536541856898_item	2711903	et	4	main
läänemeresoome	doc_536541856898_item	2711906	et	3	main
maje	doc_536541856898_item	2711914	et	4	main
komme	doc_536541856898_item	2711921	et	4	main
on	doc_536541856898_item	2711923	et	4	main
erinevuseks	doc_536541856898_item	2711943	et	4	main
19	doc_536541856898_item	2711944	et	2	main
sõnad	doc_536541856898_item	2711951	et	4	main
põlvest	doc_536541856898_item	2711967	et	4	main
koore	doc_536541856898_item	2711993	et	4	main
kasutama	doc_536541856898_item	2711997	et	3	main
sajandil	doc_536541856898_item	2712003	et	3	main
palju	doc_536541856898_item	2712005	et	4	main
heliloojasid	doc_536541856898_item	2712006	et	4	main
nad	doc_536541856898_item	2712007	et	3	main
kasutasid	doc_536541856898_item	2712008	et	4	main
nii	doc_536541856898_item	2712009	et	3	main
need	doc_536541856898_item	2712015	et	3	main
m	doc_536541856898_item	2712017	et	4	main
kapp	doc_536541856898_item	2712019	et	3	main
see	doc_536541856898_item	2712021	et	3	main
et	doc_536541856898_item	2712025	et	3	main
laulupidu	doc_536541856898_item	2712038	et	4	main
1896	doc_536541856898_item	2712044	et	2	main
eestlaste	doc_536541856898_item	2712054	et	4	main
praegu	doc_536541856898_item	2712063	et	3	main
kohad	doc_536541856898_item	2712072	et	4	main
kus	doc_536541856898_item	2712073	et	3	main
et	doc_536541856898_item	2712090	et	3	main
eestlastest	doc_536541856898_item	2712091	et	4	main
sõna	doc_536541856898_item	2711835	et	4	main
olema	doc_536541856898_item	2711838	et	4	main
arutlev	doc_536541856898_item	2711839	et	4	main
illustreerida	doc_536541856898_item	2711852	et	3	main
on	doc_536541856898_item	2711856	et	4	main
olnud	doc_536541856898_item	2711859	et	4	main
laulasid	doc_536541856898_item	2711863	et	4	main
töötasid	doc_536541856898_item	2711865	et	4	main
üksi	doc_536541856898_item	2711867	et	4	main
kiigutasid	doc_536541856898_item	2711868	et	4	main
last	doc_536541856898_item	2711869	et	4	main
laulda	doc_536541856898_item	2711870	et	4	main
on	doc_536541856898_item	2711871	et	4	main
olnud	doc_536541856898_item	2711872	et	4	main
eestlastel	doc_536541856898_item	2711873	et	4	main
kombeks	doc_536541856898_item	2711874	et	4	main
laulud	doc_536541856898_item	2711875	et	3	main
olid	doc_536541856898_item	2711876	et	4	main
igasugused	doc_536541856898_item	2711877	et	3	main
peo	doc_536541856898_item	2711878	et	4	main
ja	doc_536541856898_item	2711879	et	3	main
pulma	doc_536541856898_item	2711880	et	4	main
laulud	doc_536541856898_item	2711881	et	3	main
surma	doc_536541856898_item	2711882	et	4	main
laulud	doc_536541856898_item	2711883	et	3	main
arvan	doc_536541856898_item	2711884	et	3	main
et	doc_536541856898_item	2711885	et	3	main
laulurahva	doc_536541856898_item	2711887	et	3	main
alati	doc_536541856898_item	2711913	et	4	main
juba	doc_536541856898_item	2711925	et	3	main
sai	doc_536541856898_item	2711934	et	4	main
selle	doc_536541856898_item	2711942	et	4	main
see	doc_536541856898_item	2711954	et	3	main
tähendab	doc_536541856898_item	2711955	et	3	main
polnud	doc_536541856898_item	2711958	et	3	main
see	doc_536541856898_item	2711960	et	3	main
ja	doc_536541856898_item	2711963	et	3	main
looma	doc_536541856898_item	2711992	et	4	main
ajal	doc_536541856898_item	2711995	et	4	main
vanu	doc_536541856898_item	2712010	et	4	main
kui	doc_536541856898_item	2712011	et	3	main
ka	doc_536541856898_item	2712012	et	3	main
olid	doc_536541856898_item	2712016	et	4	main
kaotanud	doc_536541856898_item	2712034	et	4	main
aastal	doc_536541856898_item	2712036	et	3	main
toimunud	doc_536541856898_item	2712037	et	4	main
eestlase	doc_536541856898_item	2712040	et	3	main
liikumise	doc_536541856898_item	2712042	et	4	main
jaoks	doc_536541856898_item	2712055	et	4	main
oma	doc_536541856898_item	2712061	et	4	main
traditsioone	doc_536541856898_item	2712062	et	3	main
laulavad	doc_536541856898_item	2712065	et	4	main
ja	doc_536541856898_item	2712068	et	3	main
laulupidudes	doc_536541856898_item	2712081	et	4	main
ka	doc_536541856898_item	2712083	et	3	main
üritused	doc_536541856898_item	2712085	et	4	main
vabaõhumuuseumis	doc_536541856898_item	2712086	et	3	main
laulda	doc_536541856898_item	2711922	et	4	main
oma	doc_536541856898_item	2711935	et	4	main
aluse	doc_536541856898_item	2711936	et	4	main
kiriku	doc_536541856898_item	2711937	et	3	main
laulust	doc_536541856898_item	2711938	et	4	main
ja	doc_536541856898_item	2711939	et	3	main
vanematest	doc_536541856898_item	2711940	et	4	main
lauludest	doc_536541856898_item	2711941	et	3	main
lõpus	doc_536541856898_item	2711950	et	4	main
kadunud	doc_536541856898_item	2711959	et	4	main
alles	doc_536541856898_item	2711962	et	3	main
suuliselt	doc_536541856898_item	2711969	et	4	main
jõudma	doc_536541856898_item	2711971	et	3	main
vaid	doc_536541856898_item	2711972	et	3	main
ka	doc_536541856898_item	2711973	et	3	main
hiljem	doc_536541856898_item	2711974	et	3	main
19	doc_536541856898_item	2711975	et	2	main
sajandi	doc_536541856898_item	2711976	et	3	main
algul	doc_536541856898_item	2711977	et	4	main
laululehtede	doc_536541856898_item	2711978	et	4	main
ja	doc_536541856898_item	2711979	et	3	main
salmialbumite	doc_536541856898_item	2711980	et	3	main
peal	doc_536541856898_item	2711981	et	4	main
edasi	doc_536541856898_item	2711982	et	3	main
jõudma	doc_536541856898_item	2711983	et	3	main
rahvuslik	doc_536541856898_item	2711985	et	3	main
ärkamine	doc_536541856898_item	2711986	et	4	main
eesti	doc_536541856898_item	2711984	et	4	main
oli	doc_536541856898_item	2711987	et	3	main
19	doc_536541856898_item	2711988	et	2	main
sajandi	doc_536541856898_item	2711989	et	3	main
lõpupoole	doc_536541856898_item	2711990	et	4	main
see	doc_536541856898_item	2711933	et	3	main
laulu	doc_536541856898_item	2711949	et	4	main
sind	doc_536541856898_item	2711952	et	4	main
et	doc_536541856898_item	2711956	et	3	main
põlve	doc_536541856898_item	2711968	et	4	main
hakkati	doc_536541856898_item	2711996	et	3	main
muusikainstrumente	doc_536541856898_item	2711998	et	3	main
ilmusid	doc_536541856898_item	2712004	et	4	main
traditsioone	doc_536541856898_item	2712014	et	3	main
näiteks	doc_536541856898_item	2711948	et	4	main
mind	doc_536541856898_item	2711953	et	4	main
laul	doc_536541856898_item	2711957	et	4	main
jäi	doc_536541856898_item	2711961	et	3	main
sai	doc_536541856898_item	2711964	et	4	main
mitte	doc_536541856898_item	2711965	et	3	main
ainult	doc_536541856898_item	2711966	et	4	main
edasi	doc_536541856898_item	2711970	et	3	main
sellel	doc_536541856898_item	2711994	et	4	main
19	doc_536541856898_item	2711999	et	2	main
ja	doc_536541856898_item	2712001	et	3	main
uusi	doc_536541856898_item	2712013	et	3	main
rtobias	doc_536541856898_item	2712020	et	4	main
tendents	doc_536541856898_item	2712022	et	3	main
kombe	doc_536541856898_item	2712027	et	4	main
ja	doc_536541856898_item	2712028	et	3	main
tavad	doc_536541856898_item	2712029	et	3	main
muusikas	doc_536541856898_item	2712030	et	3	main
polnud	doc_536541856898_item	2712031	et	3	main
oma	doc_536541856898_item	2712032	et	4	main
aastal	doc_536541856898_item	2712045	et	3	main
see	doc_536541856898_item	2712047	et	3	main
tallinnasse	doc_536541856898_item	2712049	et	3	main
on	doc_536541856898_item	2712051	et	4	main
suureks	doc_536541856898_item	2712056	et	4	main
sündmusteks	doc_536541856898_item	2712057	et	3	main
sest	doc_536541856898_item	2712058	et	4	main
eestlased	doc_536541856898_item	2712059	et	3	main
kihnu	doc_536541856898_item	2712067	et	4	main
setu	doc_536541856898_item	2712069	et	4	main
on	doc_536541856898_item	2712070	et	4	main
need	doc_536541856898_item	2712071	et	3	main
võtavad	doc_536541856898_item	2712078	et	3	main
on	doc_536541856898_item	2712082	et	4	main
rahvamuusika	doc_536541856898_item	2712084	et	4	main
ansamblid	doc_536541856898_item	2712087	et	3	main
laulurahva	doc_536541856898_item	2712092	et	3	main
hakkati	doc_536541856898_item	2711991	et	3	main
sajandil	doc_536541856898_item	2712000	et	3	main
20	doc_536541856898_item	2712002	et	2	main
saar	doc_536541856898_item	2712018	et	3	main
näitab	doc_536541856898_item	2712023	et	3	main
vanu	doc_536541856898_item	2712026	et	4	main
aktuaalsuse	doc_536541856898_item	2712033	et	4	main
sai	doc_536541856898_item	2712039	et	4	main
kõrghetkeks	doc_536541856898_item	2712043	et	4	main
kandus	doc_536541856898_item	2712046	et	3	main
eestlased	doc_536541856898_item	2712064	et	3	main
regilaul	doc_536541856898_item	2712074	et	4	main
pole	doc_536541856898_item	2712075	et	3	main
kadunud	doc_536541856898_item	2712076	et	4	main
noored	doc_536541856898_item	2712077	et	3	main
sellepärast	doc_536541856898_item	2712088	et	3	main
meile	doc_536541856898_item	2712024	et	4	main
1869	doc_536541856898_item	2712035	et	2	main
rahvusliku	doc_536541856898_item	2712041	et	3	main
traditsioon	doc_536541856898_item	2712048	et	3	main
laulupidu	doc_536541856898_item	2712050	et	4	main
alati	doc_536541856898_item	2712052	et	4	main
olnud	doc_536541856898_item	2712053	et	4	main
hinnavad	doc_536541856898_item	2712060	et	4	main
ka	doc_536541856898_item	2712066	et	3	main
osa	doc_536541856898_item	2712079	et	4	main
igasugustes	doc_536541856898_item	2712080	et	3	main
arvan	doc_536541856898_item	2712089	et	3	main
teeb	doc_536541856898_item	2712093	et	3	main
nende	doc_536541856898_item	2712094	et	4	main
läbi	doc_536541856898_item	2712095	et	4	main
aegade	doc_536541856898_item	2712096	et	3	main
olnud	doc_536541856898_item	2712097	et	4	main
traditsioonid	doc_536541856898_item	2712098	et	3	main
ja	doc_536541856898_item	2712099	et	3	main
kombeid	doc_536541856898_item	2712100	et	4	main
laulda	doc_536541856898_item	2712101	et	4	main
laul	doc_536541856898_item	2712102	et	4	main
aitab	doc_536541856898_item	2712103	et	3	main
eestlastele	doc_536541856898_item	2712104	et	4	main
üle	doc_536541856898_item	2712105	et	3	main
elada	doc_536541856898_item	2712106	et	3	main
raskemaid	doc_536541856898_item	2712107	et	4	main
hetki	doc_536541856898_item	2712108	et	4	main
annab	doc_536541856898_item	2712109	et	3	main
võimaluse	doc_536541856898_item	2712110	et	3	main
väljendada	doc_536541856898_item	2712111	et	3	main
ennast	doc_536541856898_item	2712112	et	4	main
ja	doc_536541856898_item	2712113	et	3	main
on	doc_536541856898_item	2712114	et	4	main
alati	doc_536541856898_item	2712115	et	4	main
nendega	doc_536541856898_item	2712116	et	4	main
pulmas	doc_536541856898_item	2712117	et	3	main
või	doc_536541856898_item	2712118	et	4	main
peol	doc_536541856898_item	2712119	et	4	main
peab	doc_536541856900_item	2712507	et	4	main
olema	doc_536541856900_item	2712508	et	4	main
arutlev	doc_536541856900_item	2712509	et	4	main
lugemistekstis	doc_536541856900_item	2712516	et	3	main
küll	doc_536541856900_item	2712525	et	4	main
palju	doc_536541856900_item	2712533	et	4	main
just	doc_536541856900_item	2712539	et	3	main
seega	doc_536541856900_item	2712542	et	4	main
ongi	doc_536541856900_item	2712544	et	4	main
laulurahvas	doc_536541856900_item	2712545	et	4	main
oleks	doc_536541856900_item	2712546	et	3	main
põhjusteni	doc_536541856900_item	2712558	et	3	main
tingimusteni	doc_536541856900_item	2712561	et	3	main
ajalukku	doc_536541856900_item	2712566	et	4	main
see	doc_536541856900_item	2712568	et	3	main
osa	doc_536541856900_item	2712572	et	4	main
laulurahvas	doc_536541856900_item	2712578	et	4	main
kui	doc_536541856900_item	2712628	et	3	main
koos	doc_536541856900_item	2712637	et	4	main
kuna	doc_536541856900_item	2712644	et	3	main
juba	doc_536541856900_item	2712653	et	3	main
külamastaabne	doc_536541856900_item	2712654	et	4	main
pidu	doc_536541856900_item	2712655	et	4	main
siis	doc_536541856900_item	2712656	et	3	main
mingit	doc_536541856900_item	2712660	et	3	main
sellest	doc_536541856900_item	2712683	et	4	main
ja	doc_536541856900_item	2712687	et	3	main
loomine	doc_536541856900_item	2712690	et	4	main
koha	doc_536541856900_item	2712693	et	4	main
kuid	doc_536541856900_item	2712696	et	4	main
maailm	doc_536541856900_item	2712697	et	3	main
kohal	doc_536541856900_item	2712700	et	4	main
areneb	doc_536541856900_item	2712702	et	3	main
eestlastel	doc_536541856900_item	2712530	et	4	main
ning	doc_536541856900_item	2712541	et	3	main
liiga	doc_536541856900_item	2712548	et	4	main
sellega	doc_536541856900_item	2712552	et	3	main
ei	doc_536541856900_item	2712553	et	4	main
rahuldata	doc_536541856900_item	2712554	et	3	main
nende	doc_536541856900_item	2712560	et	4	main
tuleb	doc_536541856900_item	2712562	et	3	main
kaugele	doc_536541856900_item	2712565	et	4	main
aga	doc_536541856900_item	2712567	et	3	main
tähtis	doc_536541856900_item	2712571	et	4	main
minusuguste	doc_536541856900_item	2712573	et	3	main
oma	doc_536541856900_item	2712582	et	4	main
alguse	doc_536541856900_item	2712583	et	3	main
püüdmisest	doc_536541856900_item	2712584	et	4	main
ja	doc_536541856900_item	2712623	et	3	main
isegi	doc_536541856900_item	2712625	et	4	main
olles	doc_536541856900_item	2712631	et	3	main
olid	doc_536541856900_item	2712646	et	4	main
pandi	doc_536541856900_item	2712657	et	4	main
ning	doc_536541856900_item	2712663	et	3	main
niisuguseid	doc_536541856900_item	2712671	et	3	main
regivärsilisteks	doc_536541856900_item	2712674	et	4	main
võib-olla	doc_536541856900_item	2712675	et	3	main
koosneski	doc_536541856900_item	2712684	et	3	main
maailmas	doc_536541856900_item	2712694	et	3	main
leidmine	doc_536541856900_item	2712695	et	4	main
välismaalt	doc_536541856900_item	2712721	et	3	main
ja	doc_536541856900_item	2712724	et	3	main
kus	doc_536541856900_item	2712726	et	3	main
olid	doc_536541856900_item	2712727	et	4	main
arenemas	doc_536541856900_item	2712728	et	3	main
venemaalt	doc_536541856900_item	2712732	et	3	main
mängitakse	doc_536541856900_item	2712735	et	3	main
poolt	doc_536541856900_item	2712739	et	4	main
ja	doc_536541856900_item	2712749	et	3	main
ja	doc_536541856900_item	2712758	et	3	main
sellised	doc_536541856900_item	2712761	et	4	main
ja	doc_536541856900_item	2712766	et	3	main
on	doc_536541856900_item	2712769	et	4	main
parimad	doc_536541856900_item	2712771	et	4	main
helikiirusega	doc_536541856900_item	2712780	et	4	main
ning	doc_536541856900_item	2712781	et	3	main
aitavad	doc_536541856900_item	2712782	et	4	main
sajandil	doc_536541856900_item	2712798	et	3	main
identiteet	doc_536541856900_item	2712807	et	4	main
nende	doc_536541856900_item	2712809	et	4	main
ning	doc_536541856900_item	2712811	et	3	main
jääbki	doc_536541856900_item	2712813	et	3	main
on	doc_536541856900_item	2712817	et	4	main
lahtine	doc_536541856900_item	2712818	et	3	main
nii	doc_536541856900_item	2712819	et	3	main
essee	doc_536541856900_item	2712506	et	4	main
üldistav	doc_536541856900_item	2712512	et	4	main
tuginema	doc_536541856900_item	2712513	et	3	main
loengus	doc_536541856900_item	2712514	et	3	main
illustreerida	doc_536541856900_item	2712522	et	3	main
võib	doc_536541856900_item	2712524	et	3	main
lihtsalt	doc_536541856900_item	2712526	et	4	main
öelda	doc_536541856900_item	2712527	et	4	main
et	doc_536541856900_item	2712528	et	3	main
kuna	doc_536541856900_item	2712529	et	3	main
laule	doc_536541856900_item	2712534	et	4	main
millest	doc_536541856900_item	2712535	et	3	main
enamiku	doc_536541856900_item	2712536	et	3	main
moodustavad	doc_536541856900_item	2712537	et	4	main
üks	doc_536541856900_item	2712570	et	3	main
tööst	doc_536541856900_item	2712574	et	3	main
miks	doc_536541856900_item	2712575	et	4	main
siis	doc_536541856900_item	2712576	et	3	main
just	doc_536541856900_item	2712577	et	3	main
võib-olla	doc_536541856900_item	2712624	et	3	main
sõnu	doc_536541856900_item	2712626	et	4	main
lihtsalt	doc_536541856900_item	2712630	et	4	main
midagi	doc_536541856900_item	2712639	et	4	main
kududes	doc_536541856900_item	2712640	et	4	main
naised	doc_536541856900_item	2712643	et	3	main
tuli	doc_536541856900_item	2712652	et	4	main
arvates	doc_536541856900_item	2712677	et	4	main
aga	doc_536541856900_item	2712681	et	3	main
lõbu	doc_536541856900_item	2712686	et	4	main
ei	doc_536541856900_item	2712698	et	4	main
ennekõige	doc_536541856900_item	2712722	et	4	main
lätist	doc_536541856900_item	2712725	et	4	main
ning	doc_536541856900_item	2712731	et	3	main
juhtuvad	doc_536541856900_item	2712746	et	4	main
võib	doc_536541856900_item	2712755	et	3	main
rahvalaulude	doc_536541856900_item	2712757	et	3	main
pärt	doc_536541856900_item	2712765	et	4	main
rahvuslikule	doc_536541856900_item	2712783	et	3	main
loomisele	doc_536541856900_item	2712788	et	4	main
säilitatud	doc_536541856900_item	2712794	et	4	main
20	doc_536541856900_item	2712797	et	2	main
aitasid	doc_536541856900_item	2712800	et	4	main
iseseisvust	doc_536541856900_item	2712803	et	4	main
pälvida	doc_536541856900_item	2712804	et	3	main
kui	doc_536541856900_item	2712821	et	3	main
eestis	doc_536541856900_item	2712826	et	3	main
selleks	doc_536541856900_item	2712828	et	4	main
oma	doc_536541856900_item	2712847	et	4	main
isegi	doc_536541856900_item	2712849	et	4	main
pole	doc_536541856900_item	2712870	et	3	main
ka	doc_536541856900_item	2712871	et	3	main
ning	doc_536541856900_item	2712873	et	3	main
meie	doc_536541856900_item	2712875	et	4	main
eestlaste	doc_536541856900_item	2712876	et	4	main
oleme	doc_536541856900_item	2712884	et	3	main
essee	doc_536541856900_item	2712486	et	4	main
eesti	doc_536541856900_item	2712487	et	4	main
keele	doc_536541856900_item	2712488	et	4	main
kui	doc_536541856900_item	2712489	et	3	main
teise	doc_536541856900_item	2712490	et	4	main
keele	doc_536541856900_item	2712491	et	4	main
test	doc_536541856900_item	2712492	et	3	main
kirjutamine	doc_536541856900_item	2712493	et	4	main
kirjutage	doc_536541856900_item	2712494	et	3	main
essee	doc_536541856900_item	2712495	et	4	main
teemal	doc_536541856900_item	2712496	et	3	main
mis	doc_536541856900_item	2712497	et	4	main
teeb	doc_536541856900_item	2712498	et	3	main
laulurahva	doc_536541856900_item	2712500	et	3	main
pikkus	doc_536541856900_item	2712502	et	4	main
350	doc_536541856900_item	2712504	et	2	main
sõna	doc_536541856900_item	2712505	et	4	main
analüüsiv	doc_536541856900_item	2712510	et	4	main
ja	doc_536541856900_item	2712511	et	3	main
esitatud	doc_536541856900_item	2712517	et	4	main
väiteid	doc_536541856900_item	2712519	et	4	main
eestlastest	doc_536541856900_item	2712499	et	4	main
essee	doc_536541856900_item	2712501	et	4	main
300	doc_536541856900_item	2712503	et	2	main
ja	doc_536541856900_item	2712515	et	3	main
faktidele	doc_536541856900_item	2712518	et	3	main
on	doc_536541856900_item	2712520	et	4	main
soovitatav	doc_536541856900_item	2712521	et	4	main
näidetega	doc_536541856900_item	2712523	et	3	main
võib-olla	doc_536541856900_item	2712538	et	3	main
nad	doc_536541856900_item	2712543	et	3	main
lihtsalt	doc_536541856900_item	2712547	et	4	main
tõelist	doc_536541856900_item	2712550	et	4	main
olgugi	doc_536541856900_item	2712555	et	4	main
et	doc_536541856900_item	2712556	et	3	main
kaevata	doc_536541856900_item	2712557	et	4	main
antud	doc_536541856900_item	2712563	et	4	main
üldiselt	doc_536541856900_item	2712579	et	4	main
saada	doc_536541856900_item	2712585	et	4	main
oma	doc_536541856900_item	2712621	et	4	main
enamasti	doc_536541856900_item	2712632	et	4	main
kogunedi	doc_536541856900_item	2712633	et	4	main
kampaaniadesse	doc_536541856900_item	2712634	et	4	main
ja	doc_536541856900_item	2712635	et	3	main
lauldi	doc_536541856900_item	2712636	et	3	main
laulsid	doc_536541856900_item	2712641	et	4	main
kooreid	doc_536541856900_item	2712659	et	4	main
polnud	doc_536541856900_item	2712662	et	3	main
mittevokaalsed	doc_536541856900_item	2712665	et	3	main
rütmisliikumine	doc_536541856900_item	2712670	et	4	main
tähistatakse	doc_536541856900_item	2712673	et	3	main
meie	doc_536541856900_item	2712676	et	4	main
olid	doc_536541856900_item	2712678	et	4	main
nad	doc_536541856900_item	2712679	et	3	main
rahva	doc_536541856900_item	2712685	et	3	main
ka	doc_536541856900_item	2712688	et	3	main
oma	doc_536541856900_item	2712692	et	4	main
saksamaalt	doc_536541856900_item	2712723	et	3	main
üha	doc_536541856900_item	2712733	et	3	main
lõbusaid	doc_536541856900_item	2712736	et	3	main
kokkusulamine	doc_536541856900_item	2712747	et	4	main
ka	doc_536541856900_item	2712750	et	3	main
muusikaga	doc_536541856900_item	2712752	et	3	main
heliloojad	doc_536541856900_item	2712762	et	3	main
tormis	doc_536541856900_item	2712768	et	3	main
näided	doc_536541856900_item	2712773	et	4	main
ehk	doc_536541856900_item	2712785	et	3	main
identiteedi	doc_536541856900_item	2712787	et	4	main
vaatamata	doc_536541856900_item	2712789	et	4	main
raskustele	doc_536541856900_item	2712790	et	4	main
need	doc_536541856900_item	2712791	et	3	main
tendentsid	doc_536541856900_item	2712792	et	3	main
ka	doc_536541856900_item	2712795	et	3	main
sest	doc_536541856900_item	2712805	et	4	main
lauludes	doc_536541856900_item	2712810	et	3	main
21	doc_536541856900_item	2712815	et	2	main
uuete	doc_536541856900_item	2712823	et	4	main
mõjude	doc_536541856900_item	2712824	et	3	main
on	doc_536541856900_item	2712827	et	4	main
uuetes	doc_536541856900_item	2712850	et	4	main
esinejates	doc_536541856900_item	2712851	et	4	main
ning	doc_536541856900_item	2712852	et	3	main
annab	doc_536541856900_item	2712859	et	3	main
kindlust	doc_536541856900_item	2712861	et	4	main
kaota	doc_536541856900_item	2712867	et	4	main
siis	doc_536541856900_item	2712883	et	3	main
essee	doc_536541856901_item	2712887	et	4	main
keele	doc_536541856901_item	2712889	et	4	main
kui	doc_536541856901_item	2712890	et	3	main
kirjutage	doc_536541856901_item	2712895	et	3	main
eestlastest	doc_536541856901_item	2712900	et	4	main
laulurahva	doc_536541856901_item	2712901	et	3	main
essee	doc_536541856901_item	2712902	et	4	main
sõna	doc_536541856901_item	2712906	et	4	main
on	doc_536541856900_item	2712531	et	4	main
õudsalt	doc_536541856900_item	2712532	et	4	main
rahvalaulud	doc_536541856900_item	2712540	et	3	main
kuiv	doc_536541856900_item	2712549	et	3	main
teadlast	doc_536541856900_item	2712551	et	3	main
ja	doc_536541856900_item	2712559	et	3	main
juhul	doc_536541856900_item	2712564	et	3	main
ongi	doc_536541856900_item	2712569	et	4	main
laulud	doc_536541856900_item	2712580	et	3	main
said	doc_536541856900_item	2712581	et	4	main
aru	doc_536541856900_item	2712586	et	4	main
ja	doc_536541856900_item	2712587	et	3	main
kirjeldada	doc_536541856900_item	2712588	et	3	main
maailm	doc_536541856900_item	2712589	et	3	main
mis	doc_536541856900_item	2712590	et	4	main
on	doc_536541856900_item	2712591	et	4	main
igaühe	doc_536541856900_item	2712592	et	4	main
ümber	doc_536541856900_item	2712593	et	3	main
juba	doc_536541856900_item	2712594	et	3	main
sajandeid	doc_536541856900_item	2712595	et	3	main
tagasi	doc_536541856900_item	2712596	et	3	main
laulsid	doc_536541856900_item	2712597	et	4	main
eestlased	doc_536541856900_item	2712598	et	3	main
üldiselt	doc_536541856900_item	2712599	et	4	main
küla-	doc_536541856900_item	2712600	et	4	main
ja	doc_536541856900_item	2712601	et	3	main
isiklikust	doc_536541856900_item	2712602	et	4	main
elust	doc_536541856900_item	2712603	et	3	main
ning	doc_536541856900_item	2712604	et	3	main
need	doc_536541856900_item	2712605	et	3	main
laulud	doc_536541856900_item	2712606	et	3	main
saatsid	doc_536541856900_item	2712607	et	4	main
inimesi	doc_536541856900_item	2712608	et	4	main
hällist	doc_536541856900_item	2712609	et	4	main
hauani	doc_536541856900_item	2712610	et	3	main
mõlemad	doc_536541856900_item	2712611	et	3	main
kaasarvatud	doc_536541856900_item	2712612	et	4	main
laulda	doc_536541856900_item	2712613	et	4	main
võis	doc_536541856900_item	2712614	et	4	main
nii	doc_536541856900_item	2712615	et	3	main
midagi	doc_536541856900_item	2712616	et	4	main
tehes	doc_536541856900_item	2712617	et	3	main
kusjuures	doc_536541856900_item	2712618	et	3	main
lauldes	doc_536541856900_item	2712619	et	3	main
just	doc_536541856900_item	2712620	et	3	main
tegust	doc_536541856900_item	2712622	et	4	main
väljamõeldes	doc_536541856900_item	2712627	et	4	main
ka	doc_536541856900_item	2712629	et	3	main
näiteks	doc_536541856900_item	2712638	et	4	main
enamasti	doc_536541856900_item	2712642	et	4	main
kodutööd	doc_536541856900_item	2712645	et	4	main
ikka	doc_536541856900_item	2712647	et	4	main
igavamad	doc_536541856900_item	2712648	et	4	main
põllutöödest	doc_536541856900_item	2712649	et	3	main
kui	doc_536541856900_item	2712650	et	3	main
aga	doc_536541856900_item	2712651	et	3	main
koos	doc_536541856900_item	2712658	et	4	main
pillisaatmist	doc_536541856900_item	2712661	et	3	main
ainukesed	doc_536541856900_item	2712664	et	4	main
tegevused	doc_536541856900_item	2712666	et	4	main
olid	doc_536541856900_item	2712667	et	4	main
tants	doc_536541856900_item	2712668	et	3	main
ja	doc_536541856900_item	2712669	et	3	main
laule	doc_536541856900_item	2712672	et	4	main
igavad	doc_536541856900_item	2712680	et	3	main
just	doc_536541856900_item	2712682	et	3	main
identiteedi	doc_536541856900_item	2712689	et	4	main
ehk	doc_536541856900_item	2712691	et	3	main
seisa	doc_536541856900_item	2712699	et	4	main
ning	doc_536541856900_item	2712701	et	3	main
areneb	doc_536541856900_item	2712703	et	3	main
ka	doc_536541856900_item	2712704	et	3	main
üha	doc_536541856900_item	2712706	et	3	main
rahvamuusika	doc_536541856900_item	2712705	et	4	main
rohkem	doc_536541856900_item	2712707	et	4	main
laule	doc_536541856900_item	2712708	et	4	main
mõjutab	doc_536541856900_item	2712709	et	3	main
luterlus	doc_536541856900_item	2712710	et	4	main
ning	doc_536541856900_item	2712711	et	3	main
lauldakse	doc_536541856900_item	2712712	et	3	main
ristiusu	doc_536541856900_item	2712713	et	3	main
teemadele	doc_536541856900_item	2712714	et	3	main
19	doc_536541856900_item	2712715	et	2	main
sajandil	doc_536541856900_item	2712716	et	3	main
sellele	doc_536541856900_item	2712717	et	4	main
lisanduvad	doc_536541856900_item	2712718	et	4	main
ka	doc_536541856900_item	2712719	et	3	main
mõjud	doc_536541856900_item	2712720	et	4	main
mõttelaadid	doc_536541856900_item	2712730	et	3	main
laule	doc_536541856900_item	2712737	et	4	main
ning	doc_536541856900_item	2712740	et	3	main
laule	doc_536541856900_item	2712742	et	4	main
omavahel	doc_536541856900_item	2712748	et	3	main
tänapäeval	doc_536541856900_item	2712754	et	3	main
kohtuda	doc_536541856900_item	2712756	et	3	main
sümbioosiga	doc_536541856900_item	2712760	et	3	main
veljo	doc_536541856900_item	2712767	et	4	main
levivad	doc_536541856900_item	2712779	et	4	main
uue	doc_536541856900_item	2712786	et	3	main
olid	doc_536541856900_item	2712793	et	4	main
ka	doc_536541856900_item	2712802	et	3	main
on	doc_536541856900_item	2712808	et	4	main
nii	doc_536541856900_item	2712812	et	3	main
sajand	doc_536541856900_item	2712816	et	3	main
rahvalaulude	doc_536541856900_item	2712820	et	3	main
kõik	doc_536541856900_item	2712829	et	4	main
tingimused	doc_536541856900_item	2712830	et	3	main
on	doc_536541856900_item	2712843	et	4	main
juba	doc_536541856900_item	2712844	et	3	main
romantistlikud	doc_536541856900_item	2712729	et	4	main
rohkem	doc_536541856900_item	2712734	et	4	main
ühelt	doc_536541856900_item	2712738	et	3	main
vanamoodsaid	doc_536541856900_item	2712741	et	3	main
teiselt	doc_536541856900_item	2712743	et	4	main
poolt	doc_536541856900_item	2712744	et	4	main
tihtipeale	doc_536541856900_item	2712745	et	3	main
klassikalise	doc_536541856900_item	2712751	et	4	main
ka	doc_536541856900_item	2712753	et	3	main
popmuusika	doc_536541856900_item	2712759	et	4	main
nagu	doc_536541856900_item	2712763	et	3	main
arvo	doc_536541856900_item	2712764	et	4	main
ehk	doc_536541856900_item	2712770	et	3	main
ülemaailmsed	doc_536541856900_item	2712772	et	3	main
19	doc_536541856900_item	2712774	et	2	main
sajandi	doc_536541856900_item	2712775	et	3	main
uus	doc_536541856900_item	2712776	et	3	main
muusika	doc_536541856900_item	2712777	et	4	main
riimilaulud	doc_536541856900_item	2712778	et	4	main
ärkamisele	doc_536541856900_item	2712784	et	4	main
keerulisel	doc_536541856900_item	2712796	et	4	main
ning	doc_536541856900_item	2712799	et	3	main
meil	doc_536541856900_item	2712801	et	4	main
eestlaste	doc_536541856900_item	2712806	et	4	main
uus	doc_536541856900_item	2712814	et	3	main
ka	doc_536541856900_item	2712822	et	3	main
jaoks	doc_536541856900_item	2712825	et	4	main
rahvas	doc_536541856900_item	2712832	et	4	main
hoiab	doc_536541856900_item	2712833	et	3	main
oma	doc_536541856900_item	2712834	et	4	main
juuretest	doc_536541856900_item	2712835	et	4	main
kinni	doc_536541856900_item	2712836	et	3	main
samas	doc_536541856900_item	2712837	et	4	main
kasvades	doc_536541856900_item	2712838	et	3	main
ja	doc_536541856900_item	2712839	et	3	main
minnes	doc_536541856900_item	2712840	et	3	main
edasi	doc_536541856900_item	2712841	et	3	main
rahvalaulud	doc_536541856900_item	2712842	et	3	main
leidnud	doc_536541856900_item	2712846	et	4	main
sest	doc_536541856900_item	2712857	et	4	main
see	doc_536541856900_item	2712858	et	3	main
mulle	doc_536541856900_item	2712860	et	4	main
et	doc_536541856900_item	2712862	et	3	main
ilma	doc_536541856900_item	2712868	et	4	main
rahvast	doc_536541856900_item	2712872	et	4	main
essee	doc_536541856901_item	2712896	et	4	main
300	doc_536541856901_item	2712904	et	2	main
ja	doc_536541856901_item	2712912	et	3	main
üldistav	doc_536541856901_item	2712913	et	4	main
teeb	doc_536541856901_item	2712926	et	3	main
keeruline	doc_536541856901_item	2712935	et	4	main
vastata	doc_536541856901_item	2712942	et	4	main
laulurahvas	doc_536541856901_item	2712945	et	4	main
elu	doc_536541856901_item	2712947	et	4	main
ta	doc_536541856901_item	2712955	et	4	main
on	doc_536541856901_item	2712956	et	4	main
muusikaga	doc_536541856901_item	2712957	et	3	main
laulmine	doc_536541856901_item	2712967	et	4	main
see	doc_536541856901_item	2713003	et	3	main
meie	doc_536541856901_item	2713006	et	4	main
ajalugu	doc_536541856901_item	2713007	et	4	main
ja	doc_536541856901_item	2713027	et	3	main
nagu	doc_536541856901_item	2713030	et	3	main
mainisin	doc_536541856901_item	2713033	et	3	main
see	doc_536541856901_item	2713035	et	3	main
sotsiaalne	doc_536541856901_item	2713037	et	3	main
osaleb	doc_536541856901_item	2713040	et	3	main
palju	doc_536541856901_item	2713041	et	4	main
öelda	doc_536541856901_item	2713051	et	4	main
tahtmine	doc_536541856901_item	2713053	et	4	main
koos	doc_536541856901_item	2713056	et	4	main
viibida	doc_536541856901_item	2713057	et	3	main
eestlaste	doc_536541856901_item	2713075	et	4	main
kõrghetk	doc_536541856901_item	2713078	et	3	main
lauldakse	doc_536541856901_item	2713102	et	3	main
tunne	doc_536541856901_item	2713110	et	4	main
olla	doc_536541856901_item	2713111	et	3	main
1896	doc_536541856901_item	2713119	et	2	main
tartust	doc_536541856901_item	2713122	et	3	main
nüüd	doc_536541856901_item	2713124	et	4	main
mis	doc_536541856901_item	2713135	et	4	main
teeb	doc_536541856901_item	2713136	et	3	main
ausalt	doc_536541856901_item	2713142	et	4	main
tahtmine	doc_536541856901_item	2713144	et	4	main
olla	doc_536541856901_item	2713145	et	3	main
koos	doc_536541856901_item	2713146	et	4	main
laul	doc_536541856901_item	2713156	et	4	main
ja	doc_536541856901_item	2713157	et	3	main
laulda	doc_536541856901_item	2713170	et	4	main
haruldane	doc_536541856900_item	2712831	et	3	main
ammu	doc_536541856900_item	2712845	et	4	main
aset	doc_536541856900_item	2712848	et	3	main
oma	doc_536541856900_item	2712864	et	4	main
kui	doc_536541856900_item	2712874	et	3	main
eripära	doc_536541856900_item	2712877	et	4	main
laulurahvas	doc_536541856900_item	2712886	et	4	main
kirjutamine	doc_536541856901_item	2712894	et	4	main
pikkus	doc_536541856901_item	2712903	et	4	main
essee	doc_536541856901_item	2712907	et	4	main
olema	doc_536541856901_item	2712909	et	4	main
arutlev	doc_536541856901_item	2712910	et	4	main
loengus	doc_536541856901_item	2712915	et	3	main
ja	doc_536541856901_item	2712916	et	3	main
lugemistekstis	doc_536541856901_item	2712917	et	3	main
esitatud	doc_536541856901_item	2712918	et	4	main
faktidele	doc_536541856901_item	2712919	et	3	main
väiteid	doc_536541856901_item	2712920	et	4	main
soovitatav	doc_536541856901_item	2712922	et	4	main
eestlastest	doc_536541856901_item	2712927	et	4	main
laulurahva	doc_536541856901_item	2712928	et	3	main
on	doc_536541856901_item	2712930	et	4	main
hea	doc_536541856901_item	2712932	et	4	main
ikka	doc_536541856901_item	2712938	et	4	main
huvitav	doc_536541856901_item	2712939	et	4	main
mina	doc_536541856901_item	2712940	et	4	main
proovin	doc_536541856901_item	2712941	et	3	main
on	doc_536541856901_item	2712949	et	4	main
laulurahva	doc_536541856901_item	2712950	et	3	main
ja	doc_536541856901_item	2712958	et	3	main
lauludega	doc_536541856901_item	2712959	et	3	main
täis	doc_536541856901_item	2712960	et	4	main
on	doc_536541856901_item	2712968	et	4	main
tähelepanuväärne	doc_536541856901_item	2712969	et	3	main
sellepärast	doc_536541856901_item	2712986	et	3	main
laulmisel	doc_536541856901_item	2712987	et	4	main
on	doc_536541856901_item	2712997	et	4	main
olevik	doc_536541856901_item	2712999	et	3	main
kuid	doc_536541856901_item	2713008	et	4	main
seda	doc_536541856900_item	2712853	et	3	main
on	doc_536541856900_item	2712854	et	4	main
rõõm	doc_536541856900_item	2712855	et	3	main
teada	doc_536541856900_item	2712856	et	3	main
me	doc_536541856900_item	2712863	et	4	main
eripära	doc_536541856900_item	2712865	et	4	main
ei	doc_536541856900_item	2712866	et	4	main
temata	doc_536541856900_item	2712869	et	3	main
on	doc_536541856900_item	2712878	et	4	main
nii-öelda	doc_536541856900_item	2712879	et	3	main
arhiveeritud	doc_536541856900_item	2712880	et	4	main
just	doc_536541856900_item	2712881	et	3	main
rahvalauludes	doc_536541856900_item	2712882	et	3	main
järelikult	doc_536541856900_item	2712885	et	3	main
eesti	doc_536541856901_item	2712888	et	4	main
teise	doc_536541856901_item	2712891	et	4	main
keele	doc_536541856901_item	2712892	et	4	main
test	doc_536541856901_item	2712893	et	3	main
mis	doc_536541856901_item	2712898	et	4	main
350	doc_536541856901_item	2712905	et	2	main
peab	doc_536541856901_item	2712908	et	4	main
tuginema	doc_536541856901_item	2712914	et	3	main
mis	doc_536541856901_item	2712925	et	4	main
see	doc_536541856901_item	2712929	et	3	main
küsimus	doc_536541856901_item	2712936	et	4	main
mis	doc_536541856901_item	2712943	et	4	main
mis	doc_536541856901_item	2712946	et	4	main
temal	doc_536541856901_item	2712948	et	3	main
elu	doc_536541856901_item	2712951	et	4	main
last	doc_536541856901_item	2712965	et	4	main
kiigutades	doc_536541856901_item	2712966	et	3	main
esteetiline	doc_536541856901_item	2712976	et	3	main
ja	doc_536541856901_item	2712977	et	3	main
emotsionaalne	doc_536541856901_item	2712978	et	3	main
väljendusvahend	doc_536541856901_item	2712979	et	3	main
aga	doc_536541856901_item	2712980	et	3	main
ka	doc_536541856901_item	2712981	et	3	main
tegevus	doc_536541856901_item	2712983	et	4	main
miks	doc_536541856901_item	2712984	et	4	main
sotsiaalne	doc_536541856901_item	2712985	et	3	main
palju	doc_536541856901_item	2712990	et	4	main
rahvast	doc_536541856901_item	2712991	et	4	main
minevik	doc_536541856901_item	2712995	et	3	main
ja	doc_536541856901_item	2713000	et	3	main
ka	doc_536541856901_item	2713002	et	3	main
on	doc_536541856901_item	2713004	et	4	main
ma	doc_536541856901_item	2713009	et	3	main
siis	doc_536541856901_item	2713021	et	3	main
pean	doc_536541856901_item	2713023	et	4	main
rahvalaulu	doc_536541856901_item	2713028	et	4	main
ka	doc_536541856901_item	2713029	et	3	main
rahvast	doc_536541856901_item	2713042	et	4	main
laulupidu	doc_536541856901_item	2713048	et	4	main
ma	doc_536541856901_item	2713049	et	3	main
võin	doc_536541856901_item	2713050	et	3	main
sellest	doc_536541856901_item	2713073	et	4	main
sellel	doc_536541856901_item	2713085	et	4	main
peol	doc_536541856901_item	2713086	et	4	main
46	doc_536541856901_item	2713088	et	2	main
meeskoori	doc_536541856901_item	2713089	et	4	main
5	doc_536541856901_item	2713091	et	2	main
puhkpilliorkestri	doc_536541856901_item	2713092	et	3	main
ma	doc_536541856901_item	2713093	et	3	main
võin	doc_536541856901_item	2713094	et	3	main
kus	doc_536541856901_item	2713101	et	3	main
mängitakse	doc_536541856901_item	2713105	et	3	main
on	doc_536541856901_item	2713107	et	4	main
liikmena	doc_536541856901_item	2713112	et	3	main
liikmena	doc_536541856901_item	2713114	et	3	main
ees	doc_536541856901_item	2713132	et	4	main
oli	doc_536541856901_item	2713133	et	3	main
küsimus	doc_536541856901_item	2713134	et	4	main
laulurahva	doc_536541856901_item	2713138	et	3	main
võin	doc_536541856901_item	2713141	et	3	main
öelda	doc_536541856901_item	2713143	et	4	main
muusika	doc_536541856901_item	2713158	et	4	main
meie	doc_536541856901_item	2713161	et	4	main
meiega	doc_536541856901_item	2713166	et	4	main
ja	doc_536541856901_item	2713167	et	3	main
me	doc_536541856901_item	2713168	et	4	main
tahame	doc_536541856901_item	2713169	et	3	main
tuju	doc_536541856901_item	2713173	et	4	main
teemal	doc_536541856901_item	2712897	et	3	main
teeb	doc_536541856901_item	2712899	et	3	main
analüüsiv	doc_536541856901_item	2712911	et	4	main
on	doc_536541856901_item	2712921	et	4	main
illustreerida	doc_536541856901_item	2712923	et	3	main
aga	doc_536541856901_item	2712937	et	3	main
on	doc_536541856901_item	2712952	et	4	main
väga	doc_536541856901_item	2712953	et	3	main
rahvas	doc_536541856901_item	2712961	et	4	main
laulab	doc_536541856901_item	2712962	et	3	main
kultuurinähtus	doc_536541856901_item	2712970	et	4	main
tahaks	doc_536541856901_item	2712971	et	3	main
lisada	doc_536541856901_item	2712972	et	3	main
et	doc_536541856901_item	2712973	et	3	main
see	doc_536541856901_item	2712974	et	3	main
on	doc_536541856901_item	2712975	et	4	main
sotsiaalne	doc_536541856901_item	2712982	et	3	main
osaleda	doc_536541856901_item	2712989	et	3	main
rahvalauludes	doc_536541856901_item	2712992	et	3	main
kajastub	doc_536541856901_item	2712993	et	3	main
rahvalauludes	doc_536541856901_item	2712996	et	3	main
meie	doc_536541856901_item	2712998	et	4	main
tulevik	doc_536541856901_item	2713001	et	3	main
ju	doc_536541856901_item	2713005	et	3	main
sündisin	doc_536541856901_item	2713010	et	3	main
teadma	doc_536541856901_item	2713024	et	3	main
ajalugu	doc_536541856901_item	2713026	et	4	main
juba	doc_536541856901_item	2713032	et	3	main
laulmine	doc_536541856901_item	2713034	et	4	main
on	doc_536541856901_item	2713036	et	4	main
kõige	doc_536541856901_item	2713043	et	4	main
koos	doc_536541856901_item	2713054	et	4	main
aastal	doc_536541856901_item	2713071	et	3	main
rahvusliku	doc_536541856901_item	2713076	et	3	main
ja	doc_536541856901_item	2713079	et	3	main
osales	doc_536541856901_item	2713087	et	3	main
kohal	doc_536541856901_item	2713100	et	4	main
ja	doc_536541856901_item	2713104	et	3	main
see	doc_536541856901_item	2713106	et	3	main
laulurahva	doc_536541856901_item	2713113	et	3	main
see	doc_536541856901_item	2713117	et	3	main
aastal	doc_536541856901_item	2713120	et	3	main
tuli	doc_536541856901_item	2713121	et	4	main
suurepäärane	doc_536541856901_item	2713127	et	4	main
võimalus	doc_536541856901_item	2713128	et	3	main
laulupidu	doc_536541856901_item	2713129	et	4	main
nautida	doc_536541856901_item	2713130	et	3	main
minu	doc_536541856901_item	2713131	et	3	main
eestlastest	doc_536541856901_item	2713137	et	4	main
ma	doc_536541856901_item	2713140	et	3	main
laulda	doc_536541856901_item	2713148	et	4	main
elada	doc_536541856901_item	2713149	et	3	main
erksalt	doc_536541856901_item	2713150	et	4	main
elada	doc_536541856901_item	2713151	et	3	main
räägib	doc_536541856901_item	2713165	et	3	main
tujust	doc_536541856901_item	2713177	et	3	main
tahaks	doc_536541856901_item	2713179	et	3	main
1994	doc_536541856901_item	2713182	et	2	main
praegusel	doc_536541856901_item	2713221	et	3	main
see	doc_536541856901_item	2713232	et	3	main
olla	doc_536541856901_item	2713235	et	3	main
on	doc_536541856901_item	2713249	et	4	main
rahvapidu	doc_536541856901_item	2713250	et	4	main
lootuses	doc_536541856901_item	2713255	et	4	main
kohata	doc_536541856901_item	2713256	et	4	main
aja	doc_536541856901_item	2713269	et	4	main
mul	doc_536541856901_item	2713273	et	3	main
tänapäeval	doc_536541856901_item	2713278	et	3	main
regilaul	doc_536541856901_item	2713286	et	4	main
teha	doc_536541856901_item	2713301	et	3	main
laulurahva	doc_536541856901_item	2713306	et	3	main
elu	doc_536541856901_item	2713308	et	4	main
näidetega	doc_536541856901_item	2712924	et	3	main
väga	doc_536541856901_item	2712931	et	3	main
küsimus	doc_536541856901_item	2712933	et	4	main
tegelikult	doc_536541856901_item	2712934	et	4	main
on	doc_536541856901_item	2712944	et	4	main
huvitav	doc_536541856901_item	2712954	et	4	main
töö	doc_536541856901_item	2712963	et	4	main
tehes	doc_536541856901_item	2712964	et	3	main
võib	doc_536541856901_item	2712988	et	3	main
rahva	doc_536541856901_item	2712994	et	3	main
eestis	doc_536541856901_item	2713011	et	3	main
siis	doc_536541856901_item	2713012	et	3	main
see	doc_536541856901_item	2713013	et	3	main
maa	doc_536541856901_item	2713014	et	4	main
on	doc_536541856901_item	2713015	et	4	main
minu	doc_536541856901_item	2713016	et	3	main
kodumaa	doc_536541856901_item	2713017	et	4	main
on	doc_536541856901_item	2713018	et	4	main
minu	doc_536541856901_item	2713019	et	3	main
isamaa	doc_536541856901_item	2713020	et	4	main
tegevus	doc_536541856901_item	2713038	et	4	main
milles	doc_536541856901_item	2713039	et	3	main
sellest	doc_536541856901_item	2713046	et	4	main
on	doc_536541856901_item	2713047	et	4	main
et	doc_536541856901_item	2713052	et	3	main
tartumaal	doc_536541856901_item	2713072	et	4	main
liikumise	doc_536541856901_item	2713077	et	4	main
laulupidude	doc_536541856901_item	2713083	et	4	main
traditsioon	doc_536541856901_item	2713084	et	3	main
kujutada	doc_536541856901_item	2713095	et	3	main
olla	doc_536541856901_item	2713099	et	3	main
ju	doc_536541856901_item	2713108	et	3	main
osana	doc_536541856901_item	2713116	et	3	main
ja	doc_536541856901_item	2713139	et	3	main
tahtmine	doc_536541856901_item	2713147	et	4	main
sellepärast	doc_536541856901_item	2713155	et	3	main
on	doc_536541856901_item	2713160	et	4	main
hinge	doc_536541856901_item	2713162	et	4	main
jutt	doc_536541856901_item	2713163	et	3	main
hing	doc_536541856901_item	2713164	et	3	main
laulu	doc_536541856901_item	2713172	et	4	main
meie	doc_536541856901_item	2713175	et	4	main
veel	doc_536541856901_item	2713178	et	4	main
mainida	doc_536541856901_item	2713180	et	3	main
et	doc_536541856901_item	2713181	et	3	main
aastal	doc_536541856901_item	2713183	et	3	main
eestis	doc_536541856901_item	2713184	et	3	main
kahekordne	doc_536541856901_item	2713186	et	3	main
ma	doc_536541856901_item	2713022	et	3	main
oma	doc_536541856901_item	2713025	et	4	main
ma	doc_536541856901_item	2713031	et	3	main
silmapaistvam	doc_536541856901_item	2713044	et	4	main
näide	doc_536541856901_item	2713045	et	3	main
olla	doc_536541856901_item	2713055	et	3	main
ühes	doc_536541856901_item	2713058	et	4	main
kohas	doc_536541856901_item	2713059	et	4	main
teeb	doc_536541856901_item	2713060	et	3	main
eestlastest	doc_536541856901_item	2713061	et	4	main
laulurahva	doc_536541856901_item	2713062	et	3	main
mulle	doc_536541856901_item	2713063	et	4	main
tundub	doc_536541856901_item	2713064	et	3	main
nii	doc_536541856901_item	2713065	et	3	main
esimene	doc_536541856901_item	2713066	et	3	main
ülemaaline	doc_536541856901_item	2713067	et	4	main
kujunes	doc_536541856901_item	2713069	et	3	main
laulupidu	doc_536541856901_item	2713068	et	4	main
1869	doc_536541856901_item	2713070	et	2	main
kujunes	doc_536541856901_item	2713074	et	3	main
sellest	doc_536541856901_item	2713080	et	4	main
sai	doc_536541856901_item	2713081	et	4	main
alguse	doc_536541856901_item	2713082	et	3	main
ja	doc_536541856901_item	2713090	et	3	main
ette	doc_536541856901_item	2713096	et	4	main
kui	doc_536541856901_item	2713097	et	3	main
tore	doc_536541856901_item	2713098	et	3	main
tantsitakse	doc_536541856901_item	2713103	et	3	main
suurepäärane	doc_536541856901_item	2713109	et	4	main
ja	doc_536541856901_item	2713115	et	3	main
traditsioon	doc_536541856901_item	2713118	et	3	main
tallinnasse	doc_536541856901_item	2713123	et	3	main
pealinnaelanikel	doc_536541856901_item	2713125	et	3	main
oli	doc_536541856901_item	2713126	et	3	main
koos	doc_536541856901_item	2713152	et	4	main
muusikaga	doc_536541856901_item	2713153	et	3	main
miks	doc_536541856901_item	2713154	et	4	main
see	doc_536541856901_item	2713159	et	3	main
oli	doc_536541856901_item	2713185	et	3	main
pidu	doc_536541856901_item	2713187	et	4	main
kahekordne	doc_536541856901_item	2713190	et	3	main
rõõm	doc_536541856901_item	2713191	et	3	main
ja	doc_536541856901_item	2713192	et	3	main
laulupidu	doc_536541856901_item	2713193	et	4	main
tol	doc_536541856901_item	2713194	et	3	main
suvel	doc_536541856901_item	2713195	et	3	main
korraldati	doc_536541856901_item	2713196	et	3	main
eesti	doc_536541856901_item	2713197	et	4	main
üldlaulupidu	doc_536541856901_item	2713198	et	4	main
kahes	doc_536541856901_item	2713199	et	4	main
tartus	doc_536541856901_item	2713201	et	3	main
ja	doc_536541856901_item	2713202	et	3	main
linnas	doc_536541856901_item	2713200	et	4	main
tallinnas	doc_536541856901_item	2713203	et	4	main
tavalise	doc_536541856901_item	2713204	et	4	main
eestlase	doc_536541856901_item	2713205	et	3	main
jaoks	doc_536541856901_item	2713206	et	4	main
koorilaul	doc_536541856901_item	2713207	et	4	main
rahvalaul	doc_536541856901_item	2713208	et	4	main
seostub	doc_536541856901_item	2713209	et	3	main
sõnadega	doc_536541856901_item	2713210	et	3	main
rahvas	doc_536541856901_item	2713211	et	4	main
ja	doc_536541856901_item	2713212	et	3	main
laul	doc_536541856901_item	2713213	et	4	main
kohe	doc_536541856901_item	2713214	et	4	main
ka	doc_536541856901_item	2713215	et	3	main
laulupidu	doc_536541856901_item	2713216	et	4	main
aga	doc_536541856901_item	2713217	et	3	main
see	doc_536541856901_item	2713218	et	3	main
on	doc_536541856901_item	2713219	et	4	main
ka	doc_536541856901_item	2713220	et	3	main
ja	doc_536541856901_item	2713225	et	3	main
laulurahva	doc_536541856901_item	2713231	et	3	main
tunne	doc_536541856901_item	2713234	et	4	main
seal	doc_536541856901_item	2713236	et	4	main
kus	doc_536541856901_item	2713237	et	3	main
lauldakse	doc_536541856901_item	2713238	et	3	main
olla	doc_536541856901_item	2713239	et	3	main
sellina	doc_536541856901_item	2713240	et	3	main
kogu	doc_536541856901_item	2713261	et	4	main
läbi	doc_536541856901_item	2713268	et	4	main
kahjuks	doc_536541856901_item	2713285	et	4	main
meie	doc_536541856901_item	2713171	et	4	main
hinge	doc_536541856901_item	2713176	et	4	main
tähendab	doc_536541856901_item	2713189	et	3	main
ajal	doc_536541856901_item	2713222	et	4	main
massilisem	doc_536541856901_item	2713226	et	4	main
mis	doc_536541856901_item	2713228	et	4	main
oskab	doc_536541856901_item	2713242	et	3	main
miks	doc_536541856901_item	2713244	et	4	main
inimene	doc_536541856901_item	2713245	et	3	main
tuleb	doc_536541856901_item	2713246	et	3	main
koos	doc_536541856901_item	2713253	et	4	main
sõpru	doc_536541856901_item	2713257	et	3	main
kes	doc_536541856901_item	2713258	et	4	main
on	doc_536541856901_item	2713259	et	4	main
üle	doc_536541856901_item	2713260	et	3	main
on	doc_536541856901_item	2713267	et	4	main
sümboliteks	doc_536541856901_item	2713272	et	3	main
rõõm	doc_536541856901_item	2713275	et	3	main
võin	doc_536541856901_item	2713300	et	3	main
kokkuvõte	doc_536541856901_item	2713303	et	3	main
eestlastest	doc_536541856901_item	2713305	et	4	main
sõltub	doc_536541856901_item	2713174	et	3	main
see	doc_536541856901_item	2713188	et	3	main
kõige	doc_536541856901_item	2713223	et	4	main
eestlastest	doc_536541856901_item	2713230	et	4	main
kuhu	doc_536541856901_item	2713251	et	3	main
tullakse	doc_536541856901_item	2713252	et	3	main
maailma	doc_536541856901_item	2713262	et	4	main
kokku	doc_536541856901_item	2713263	et	3	main
rahvalikeks	doc_536541856901_item	2713271	et	3	main
et	doc_536541856901_item	2713277	et	3	main
folkloorpäevi	doc_536541856901_item	2713280	et	4	main
kus	doc_536541856901_item	2713281	et	3	main
osalevad	doc_536541856901_item	2713282	et	4	main
enamasti	doc_536541856901_item	2713283	et	4	main
noored	doc_536541856901_item	2713284	et	3	main
tänapäeval	doc_536541856901_item	2713287	et	3	main
on	doc_536541856901_item	2713290	et	4	main
teeb	doc_536541856901_item	2713307	et	3	main
tähelepanuväärsem	doc_536541856901_item	2713224	et	4	main
rahvapidu	doc_536541856901_item	2713227	et	4	main
teeb	doc_536541856901_item	2713229	et	3	main
ülendav	doc_536541856901_item	2713233	et	4	main
kes	doc_536541856901_item	2713241	et	4	main
laulda	doc_536541856901_item	2713243	et	4	main
peole	doc_536541856901_item	2713247	et	4	main
laulupidu	doc_536541856901_item	2713248	et	4	main
perega	doc_536541856901_item	2713254	et	3	main
sõitnud	doc_536541856901_item	2713264	et	4	main
need	doc_536541856901_item	2713265	et	3	main
peod	doc_536541856901_item	2713266	et	4	main
kujunenud	doc_536541856901_item	2713270	et	4	main
on	doc_536541856901_item	2713274	et	4	main
teada	doc_536541856901_item	2713276	et	3	main
korraldatakse	doc_536541856901_item	2713279	et	3	main
kaob	doc_536541856901_item	2713288	et	3	main
kihnu	doc_536541856901_item	2713291	et	4	main
omapäärane	doc_536541856901_item	2713294	et	4	main
kombe	doc_536541856901_item	2713295	et	4	main
ja	doc_536541856901_item	2713296	et	3	main
traditsioon	doc_536541856901_item	2713297	et	3	main
ja	doc_536541856901_item	2713298	et	3	main
ma	doc_536541856901_item	2713299	et	3	main
väikese	doc_536541856901_item	2713302	et	4	main
et	doc_536541856901_item	2713304	et	3	main
essee	doc_536541856903_item	2713619	et	4	main
keele	doc_536541856903_item	2713621	et	4	main
sõna	doc_536541856903_item	2713638	et	4	main
olema	doc_536541856903_item	2713641	et	4	main
lugemistekstis	doc_536541856903_item	2713649	et	3	main
faktidele	doc_536541856903_item	2713651	et	3	main
illustreerida	doc_536541856903_item	2713655	et	3	main
selle	doc_536541856903_item	2713663	et	4	main
ajalugu	doc_536541856903_item	2713664	et	4	main
öeldakse	doc_536541856903_item	2713665	et	3	main
et	doc_536541856903_item	2713666	et	3	main
inimesed	doc_536541856903_item	2713667	et	3	main
kes	doc_536541856903_item	2713668	et	4	main
oma	doc_536541856903_item	2713671	et	4	main
aga	doc_536541856901_item	2713289	et	3	main
saarel	doc_536541856901_item	2713292	et	3	main
nagu	doc_536541856901_item	2713293	et	3	main
eesti	doc_536541856903_item	2713620	et	4	main
teise	doc_536541856903_item	2713623	et	4	main
kirjutamine	doc_536541856903_item	2713626	et	4	main
mis	doc_536541856903_item	2713630	et	4	main
teeb	doc_536541856903_item	2713631	et	3	main
eestlastest	doc_536541856903_item	2713632	et	4	main
laulurahva	doc_536541856903_item	2713633	et	3	main
essee	doc_536541856903_item	2713639	et	4	main
peab	doc_536541856903_item	2713640	et	4	main
arutlev	doc_536541856903_item	2713642	et	4	main
analüüsiv	doc_536541856903_item	2713643	et	4	main
ja	doc_536541856903_item	2713644	et	3	main
väiteid	doc_536541856903_item	2713652	et	4	main
soovitatav	doc_536541856903_item	2713654	et	4	main
iga	doc_536541856903_item	2713657	et	4	main
rahva	doc_536541856903_item	2713658	et	3	main
jaoks	doc_536541856903_item	2713659	et	4	main
tea	doc_536541856903_item	2713670	et	4	main
tuleviku	doc_536541856903_item	2713674	et	4	main
see	doc_536541856903_item	2713675	et	3	main
on	doc_536541856903_item	2713676	et	4	main
minu	doc_536541856903_item	2713677	et	3	main
meeles	doc_536541856903_item	2713678	et	3	main
õige	doc_536541856903_item	2713679	et	4	main
ka	doc_536541856903_item	2713680	et	3	main
rahva	doc_536541856903_item	2713681	et	3	main
osa	doc_536541856903_item	2713686	et	4	main
teeb	doc_536541856903_item	2713690	et	3	main
laulurahva	doc_536541856903_item	2713691	et	3	main
kui	doc_536541856903_item	2713622	et	3	main
essee	doc_536541856903_item	2713634	et	4	main
pikkus	doc_536541856903_item	2713635	et	4	main
tuginema	doc_536541856903_item	2713646	et	3	main
esitatud	doc_536541856903_item	2713650	et	4	main
tähtis	doc_536541856903_item	2713662	et	4	main
ei	doc_536541856903_item	2713669	et	4	main
mineviku	doc_536541856903_item	2713672	et	3	main
eestlaste	doc_536541856903_item	2713683	et	4	main
oma	doc_536541856903_item	2713698	et	4	main
regilaule	doc_536541856903_item	2713727	et	4	main
tuli	doc_536541856903_item	2713740	et	4	main
ristiusk	doc_536541856903_item	2713741	et	3	main
siis	doc_536541856903_item	2713742	et	3	main
algas	doc_536541856903_item	2713743	et	3	main
traditsioon	doc_536541856903_item	2713766	et	3	main
maalt	doc_536541856903_item	2713768	et	3	main
inimesed	doc_536541856903_item	2713769	et	3	main
et	doc_536541856903_item	2713775	et	3	main
traditsioon	doc_536541856903_item	2713785	et	3	main
saada	doc_536541856903_item	2713790	et	4	main
niimoodi	doc_536541856903_item	2713794	et	3	main
rahva	doc_536541856903_item	2713801	et	3	main
ühinemise	doc_536541856903_item	2713802	et	4	main
sümbol	doc_536541856903_item	2713803	et	3	main
selle	doc_536541856903_item	2713804	et	4	main
tunnevad	doc_536541856903_item	2713811	et	3	main
mõne	doc_536541856903_item	2713813	et	3	main
osana	doc_536541856903_item	2713816	et	3	main
tahavad	doc_536541856903_item	2713818	et	3	main
test	doc_536541856903_item	2713625	et	3	main
essee	doc_536541856903_item	2713628	et	4	main
teemal	doc_536541856903_item	2713629	et	3	main
300	doc_536541856903_item	2713636	et	2	main
üldistav	doc_536541856903_item	2713645	et	4	main
ja	doc_536541856903_item	2713648	et	3	main
on	doc_536541856903_item	2713660	et	4	main
väga	doc_536541856903_item	2713661	et	3	main
jaoks	doc_536541856903_item	2713682	et	4	main
on	doc_536541856903_item	2713687	et	4	main
austavad	doc_536541856903_item	2713697	et	4	main
ajalugu	doc_536541856903_item	2713699	et	4	main
traditsioone	doc_536541856903_item	2713700	et	3	main
pärandati	doc_536541856903_item	2713728	et	4	main
järgmine	doc_536541856903_item	2713744	et	3	main
etapp	doc_536541856903_item	2713745	et	3	main
laulude	doc_536541856903_item	2713746	et	3	main
ajaloos	doc_536541856903_item	2713747	et	4	main
ja	doc_536541856903_item	2713756	et	3	main
kasutamine	doc_536541856903_item	2713761	et	4	main
19	doc_536541856903_item	2713762	et	2	main
laulupeode	doc_536541856903_item	2713765	et	3	main
tallinnasse	doc_536541856903_item	2713774	et	3	main
lihtsalt	doc_536541856903_item	2713776	et	4	main
aitas	doc_536541856903_item	2713786	et	3	main
on	doc_536541856903_item	2713798	et	4	main
minu	doc_536541856903_item	2713799	et	3	main
arvamisel	doc_536541856903_item	2713800	et	4	main
suure	doc_536541856903_item	2713814	et	3	main
ei	doc_536541856903_item	2713824	et	4	main
rahvalaulude	doc_536541856903_item	2713838	et	3	main
jaoks	doc_536541856903_item	2713839	et	4	main
iga	doc_536541856903_item	2713843	et	4	main
toob	doc_536541856903_item	2713846	et	3	main
midagi	doc_536541856903_item	2713848	et	4	main
hea	doc_536541856903_item	2713863	et	4	main
on	doc_536541856903_item	2713867	et	4	main
grupp	doc_536541856903_item	2713868	et	3	main
väga	doc_536541856903_item	2713880	et	3	main
tõepoolest	doc_536541856903_item	2713882	et	3	main
mitte	doc_536541856903_item	2713886	et	3	main
sõna	doc_536541856903_item	2713888	et	4	main
mõne	doc_536541856903_item	2713894	et	3	main
vana	doc_536541856903_item	2713895	et	4	main
eesti	doc_536541856903_item	2713896	et	4	main
iseseisvuse	doc_536541856903_item	2713921	et	4	main
oma	doc_536541856903_item	2713935	et	4	main
keele	doc_536541856903_item	2713624	et	4	main
kirjutage	doc_536541856903_item	2713627	et	3	main
350	doc_536541856903_item	2713637	et	2	main
loengus	doc_536541856903_item	2713647	et	3	main
on	doc_536541856903_item	2713653	et	4	main
näidetega	doc_536541856903_item	2713656	et	3	main
tähtis	doc_536541856903_item	2713685	et	4	main
eestlastest	doc_536541856903_item	2713689	et	4	main
et	doc_536541856903_item	2713693	et	3	main
mäletavad	doc_536541856903_item	2713695	et	4	main
ja	doc_536541856903_item	2713701	et	3	main
kombeid	doc_536541856903_item	2713702	et	4	main
eesti	doc_536541856903_item	2713703	et	4	main
laulude	doc_536541856903_item	2713704	et	3	main
ajalugu	doc_536541856903_item	2713705	et	4	main
on	doc_536541856903_item	2713706	et	4	main
hästi	doc_536541856903_item	2713707	et	3	main
mitu	doc_536541856903_item	2713708	et	4	main
huvitavaid	doc_536541856903_item	2713709	et	4	main
momente	doc_536541856903_item	2713710	et	3	main
esimene	doc_536541856903_item	2713711	et	3	main
tähtis	doc_536541856903_item	2713712	et	4	main
etapp	doc_536541856903_item	2713713	et	3	main
oli	doc_536541856903_item	2713714	et	3	main
regilaulude	doc_536541856903_item	2713715	et	3	main
levimine	doc_536541856903_item	2713716	et	4	main
neid	doc_536541856903_item	2713717	et	4	main
laule	doc_536541856903_item	2713718	et	4	main
esindati	doc_536541856903_item	2713719	et	3	main
vokaalselt	doc_536541856903_item	2713720	et	4	main
mis	doc_536541856903_item	2713721	et	4	main
põlve	doc_536541856903_item	2713730	et	4	main
ilmus	doc_536541856903_item	2713748	et	4	main
uus	doc_536541856903_item	2713749	et	3	main
laulmisstiil	doc_536541856903_item	2713750	et	3	main
trüki	doc_536541856903_item	2713757	et	4	main
ja	doc_536541856903_item	2713759	et	3	main
pärast	doc_536541856903_item	2713773	et	4	main
mõnes	doc_536541856903_item	2713787	et	3	main
miks	doc_536541856903_item	2713792	et	4	main
arvan	doc_536541856903_item	2713795	et	3	main
sest	doc_536541856903_item	2713796	et	4	main
inimesed	doc_536541856903_item	2713810	et	3	main
saavutada	doc_536541856903_item	2713820	et	3	main
miski	doc_536541856903_item	2713823	et	4	main
jah	doc_536541856903_item	2713840	et	3	main
põlvkond	doc_536541856903_item	2713845	et	3	main
endaga	doc_536541856903_item	2713847	et	4	main
uut	doc_536541856903_item	2713849	et	3	main
noored	doc_536541856903_item	2713850	et	3	main
teevad	doc_536541856903_item	2713851	et	3	main
rahvalauludele	doc_536541856903_item	2713852	et	3	main
remikse	doc_536541856903_item	2713853	et	4	main
tekkis	doc_536541856903_item	2713854	et	3	main
uus	doc_536541856903_item	2713855	et	3	main
nimi	doc_536541856903_item	2713858	et	3	main
minu	doc_536541856903_item	2713861	et	3	main
selle	doc_536541856903_item	2713865	et	4	main
jaoks	doc_536541856903_item	2713866	et	4	main
mulle	doc_536541856903_item	2713876	et	4	main
laul	doc_536541856903_item	2713879	et	4	main
laulavad	doc_536541856903_item	2713892	et	4	main
pole	doc_536541856903_item	2713673	et	3	main
ajaloo	doc_536541856903_item	2713684	et	4	main
laulud	doc_536541856903_item	2713688	et	3	main
see	doc_536541856903_item	2713692	et	3	main
nad	doc_536541856903_item	2713694	et	3	main
ja	doc_536541856903_item	2713696	et	3	main
tähendas	doc_536541856903_item	2713722	et	3	main
et	doc_536541856903_item	2713723	et	3	main
ei	doc_536541856903_item	2713725	et	4	main
selles	doc_536541856903_item	2713751	et	4	main
aitas	doc_536541856903_item	2713752	et	3	main
vaimulike	doc_536541856903_item	2713753	et	3	main
oma	doc_536541856903_item	2713778	et	4	main
ma	doc_536541856903_item	2713780	et	3	main
arvan	doc_536541856903_item	2713781	et	3	main
et	doc_536541856903_item	2713782	et	3	main
just	doc_536541856903_item	2713783	et	3	main
laulupidude	doc_536541856903_item	2713784	et	4	main
eestile	doc_536541856903_item	2713789	et	3	main
kõik	doc_536541856903_item	2713809	et	4	main
asja	doc_536541856903_item	2713815	et	4	main
ja	doc_536541856903_item	2713817	et	3	main
midagi	doc_536541856903_item	2713819	et	4	main
mitte	doc_536541856903_item	2713822	et	3	main
saa	doc_536541856903_item	2713825	et	4	main
noored	doc_536541856903_item	2713835	et	3	main
tunnevad	doc_536541856903_item	2713836	et	3	main
huvi	doc_536541856903_item	2713837	et	4	main
suund	doc_536541856903_item	2713856	et	3	main
mille	doc_536541856903_item	2713857	et	3	main
pop-folk	doc_536541856903_item	2713860	et	4	main
neiokõsõ	doc_536541856903_item	2713869	et	4	main
aastal	doc_536541856903_item	2713875	et	3	main
ei	doc_536541856903_item	2713883	et	4	main
ma	doc_536541856903_item	2713885	et	3	main
aru	doc_536541856903_item	2713889	et	4	main
sest	doc_536541856903_item	2713890	et	4	main
naised	doc_536541856903_item	2713891	et	3	main
kõnel	doc_536541856903_item	2713897	et	3	main
laulurahva	doc_536541856903_item	2713901	et	3	main
laulud	doc_536541856903_item	2713906	et	3	main
alati	doc_536541856903_item	2713908	et	4	main
väga	doc_536541856903_item	2713909	et	3	main
saamise	doc_536541856903_item	2713922	et	4	main
ajalugu	doc_536541856903_item	2713936	et	4	main
ja	doc_536541856903_item	2713937	et	3	main
traditsioonide	doc_536541856903_item	2713938	et	3	main
keele	doc_536541856904_item	2713945	et	4	main
test	doc_536541856904_item	2713946	et	3	main
eestlastest	doc_536541856904_item	2713953	et	4	main
sõna	doc_536541856904_item	2713959	et	4	main
peab	doc_536541856904_item	2713961	et	4	main
olema	doc_536541856904_item	2713962	et	4	main
ja	doc_536541856904_item	2713969	et	3	main
väiteid	doc_536541856904_item	2713973	et	4	main
on	doc_536541856904_item	2713974	et	4	main
näidetega	doc_536541856904_item	2713977	et	3	main
eestlased	doc_536541856904_item	2713978	et	3	main
nagu	doc_536541856904_item	2713979	et	3	main
teised	doc_536541856904_item	2713980	et	4	main
rahvad	doc_536541856904_item	2713981	et	3	main
juba	doc_536541856904_item	2713982	et	3	main
osa	doc_536541856904_item	2713989	et	4	main
olid	doc_536541856904_item	2714027	et	4	main
tähtsad	doc_536541856904_item	2714029	et	3	main
ajaloos	doc_536541856904_item	2714039	et	4	main
aitasid	doc_536541856904_item	2714040	et	4	main
olla	doc_536541856904_item	2714041	et	3	main
pärast	doc_536541856904_item	2714058	et	4	main
laul	doc_536541856904_item	2714059	et	4	main
ei	doc_536541856904_item	2714070	et	4	main
tähenda	doc_536541856904_item	2714071	et	4	main
et	doc_536541856904_item	2714072	et	3	main
kirik	doc_536541856904_item	2714073	et	3	main
mõtlevad	doc_536541856904_item	2714087	et	4	main
laulud	doc_536541856904_item	2714088	et	3	main
loodus	doc_536541856904_item	2714093	et	4	main
musikaalinstrumente	doc_536541856903_item	2713724	et	4	main
kasutati	doc_536541856903_item	2713726	et	4	main
põlvest	doc_536541856903_item	2713729	et	4	main
suuliselt	doc_536541856903_item	2713731	et	4	main
see	doc_536541856903_item	2713732	et	3	main
aitas	doc_536541856903_item	2713733	et	3	main
säilitada	doc_536541856903_item	2713734	et	3	main
kombeid	doc_536541856903_item	2713735	et	4	main
ja	doc_536541856903_item	2713736	et	3	main
traditsioone	doc_536541856903_item	2713737	et	3	main
kui	doc_536541856903_item	2713738	et	3	main
eestisse	doc_536541856903_item	2713739	et	4	main
laulude	doc_536541856903_item	2713754	et	3	main
levimine	doc_536541856903_item	2713755	et	4	main
laululehtede	doc_536541856903_item	2713758	et	4	main
salmialbumite	doc_536541856903_item	2713760	et	3	main
sajandilt	doc_536541856903_item	2713763	et	3	main
pärineb	doc_536541856903_item	2713764	et	3	main
kogu	doc_536541856903_item	2713767	et	4	main
tulid	doc_536541856903_item	2713770	et	4	main
tartusse	doc_536541856903_item	2713771	et	3	main
ja	doc_536541856903_item	2713772	et	3	main
esineda	doc_536541856903_item	2713777	et	3	main
rahvalaule	doc_536541856903_item	2713779	et	4	main
mõttes	doc_536541856903_item	2713788	et	3	main
iseseisvaks	doc_536541856903_item	2713791	et	3	main
ma	doc_536541856903_item	2713793	et	3	main
laulupidu	doc_536541856903_item	2713797	et	4	main
ajalugu	doc_536541856903_item	2713805	et	4	main
kaudu	doc_536541856903_item	2713806	et	3	main
ja	doc_536541856903_item	2713807	et	3	main
kui	doc_536541856903_item	2713808	et	3	main
iseenda	doc_536541856903_item	2713812	et	3	main
siis	doc_536541856903_item	2713821	et	3	main
neid	doc_536541856903_item	2713826	et	4	main
peatuda	doc_536541856903_item	2713827	et	3	main
aga	doc_536541856903_item	2713828	et	3	main
ajaloost	doc_536541856903_item	2713829	et	4	main
piisab	doc_536541856903_item	2713830	et	3	main
kindlasti	doc_536541856903_item	2713841	et	3	main
uus	doc_536541856903_item	2713844	et	3	main
on	doc_536541856903_item	2713859	et	4	main
kes	doc_536541856903_item	2713870	et	4	main
esindasid	doc_536541856903_item	2713871	et	4	main
laulu	doc_536541856903_item	2713872	et	4	main
eurovisioonil	doc_536541856903_item	2713873	et	3	main
2004	doc_536541856903_item	2713874	et	2	main
meeldib	doc_536541856903_item	2713877	et	3	main
kuidki	doc_536541856903_item	2713881	et	3	main
saa	doc_536541856903_item	2713884	et	4	main
teeb	doc_536541856903_item	2713899	et	3	main
eestlastest	doc_536541856903_item	2713900	et	4	main
et	doc_536541856903_item	2713905	et	3	main
tähtsad	doc_536541856903_item	2713910	et	3	main
ja	doc_536541856903_item	2713924	et	3	main
tähtsam	doc_536541856903_item	2713926	et	4	main
et	doc_536541856903_item	2713929	et	3	main
vastu	doc_536541856903_item	2713939	et	3	main
essee	doc_536541856904_item	2713940	et	4	main
kirjutamine	doc_536541856904_item	2713947	et	4	main
laulurahva	doc_536541856904_item	2713954	et	3	main
350	doc_536541856904_item	2713958	et	2	main
ammu	doc_536541856904_item	2713983	et	4	main
kuulub	doc_536541856904_item	2713990	et	3	main
vene	doc_536541856904_item	2713994	et	4	main
palju	doc_536541856904_item	2714021	et	4	main
esse	doc_536541856904_item	2714023	et	3	main
kohta	doc_536541856904_item	2714025	et	4	main
või	doc_536541856904_item	2714048	et	4	main
hea	doc_536541856904_item	2714049	et	4	main
esimesed	doc_536541856904_item	2714050	et	3	main
laulud	doc_536541856904_item	2714051	et	3	main
olid	doc_536541856904_item	2714052	et	4	main
lihtsad	doc_536541856904_item	2714053	et	3	main
paar	doc_536541856904_item	2714054	et	3	main
kirikusse	doc_536541856904_item	2714063	et	4	main
andis	doc_536541856904_item	2714074	et	3	main
mõte	doc_536541856904_item	2714075	et	3	main
vaid	doc_536541856904_item	2714076	et	3	main
ta	doc_536541856904_item	2714077	et	4	main
aitas	doc_536541856904_item	2714078	et	3	main
rahvale	doc_536541856904_item	2714079	et	3	main
olid	doc_536541856904_item	2714089	et	4	main
ajal	doc_536541856904_item	2714125	et	4	main
aega	doc_536541856904_item	2714129	et	4	main
mis	doc_536541856903_item	2713831	et	4	main
juhtub	doc_536541856903_item	2713832	et	3	main
tänapäeval	doc_536541856903_item	2713833	et	3	main
kas	doc_536541856903_item	2713834	et	3	main
aga	doc_536541856903_item	2713842	et	3	main
meeles	doc_536541856903_item	2713862	et	3	main
näide	doc_536541856903_item	2713864	et	3	main
see	doc_536541856903_item	2713878	et	3	main
ühestki	doc_536541856903_item	2713887	et	4	main
seal	doc_536541856903_item	2713893	et	4	main
mis	doc_536541856903_item	2713898	et	4	main
meeles	doc_536541856903_item	2713903	et	3	main
olid	doc_536541856903_item	2713907	et	4	main
eestlaste	doc_536541856903_item	2713911	et	4	main
jaoks	doc_536541856903_item	2713912	et	4	main
nad	doc_536541856903_item	2713913	et	3	main
mängisid	doc_536541856903_item	2713914	et	4	main
väga	doc_536541856903_item	2713915	et	3	main
suurt	doc_536541856903_item	2713916	et	3	main
rolli	doc_536541856903_item	2713917	et	4	main
rahva	doc_536541856903_item	2713918	et	3	main
ülestõusmise	doc_536541856903_item	2713919	et	3	main
ja	doc_536541856903_item	2713920	et	3	main
ajal	doc_536541856903_item	2713923	et	4	main
keele	doc_536541856904_item	2713942	et	4	main
kui	doc_536541856904_item	2713943	et	3	main
mis	doc_536541856904_item	2713951	et	4	main
essee	doc_536541856904_item	2713955	et	4	main
faktidele	doc_536541856904_item	2713972	et	3	main
kujunesid	doc_536541856904_item	2713984	et	4	main
oma	doc_536541856904_item	2713985	et	4	main
kultuur	doc_536541856904_item	2713986	et	3	main
suur	doc_536541856904_item	2713988	et	3	main
rääkides	doc_536541856904_item	2713992	et	4	main
või	doc_536541856904_item	2713996	et	4	main
saksa	doc_536541856904_item	2713997	et	4	main
inimestega	doc_536541856904_item	2713998	et	3	main
esimene	doc_536541856904_item	2713999	et	3	main
teema	doc_536541856904_item	2714024	et	4	main
laulud	doc_536541856904_item	2714026	et	3	main
eesti	doc_536541856904_item	2714030	et	4	main
rahvale	doc_536541856904_item	2714031	et	3	main
sest	doc_536541856904_item	2714032	et	4	main
nad	doc_536541856904_item	2714033	et	3	main
aitasid	doc_536541856904_item	2714034	et	4	main
ühes	doc_536541856904_item	2714042	et	4	main
koos	doc_536541856904_item	2714043	et	4	main
arenes	doc_536541856904_item	2714060	et	3	main
ja	doc_536541856904_item	2714061	et	3	main
sai	doc_536541856904_item	2714062	et	4	main
laul	doc_536541856904_item	2714085	et	4	main
erinevatele	doc_536541856904_item	2714091	et	4	main
televiisor	doc_536541856904_item	2714121	et	3	main
aga	doc_536541856904_item	2714123	et	3	main
oma	doc_536541856904_item	2714128	et	4	main
olid	doc_536541856904_item	2714143	et	4	main
kolisid	doc_536541856904_item	2714147	et	4	main
laulu	doc_536541856904_item	2714160	et	4	main
laulupeo	doc_536541856904_item	2714162	et	4	main
me	doc_536541856904_item	2714164	et	4	main
muusikud	doc_536541856904_item	2714168	et	4	main
igasugused	doc_536541856904_item	2714173	et	3	main
jääb	doc_536541856904_item	2714180	et	3	main
rahvapeoks	doc_536541856904_item	2714181	et	4	main
kus	doc_536541856904_item	2714182	et	3	main
saab	doc_536541856904_item	2714183	et	3	main
kuulata	doc_536541856904_item	2714184	et	4	main
arvates	doc_536541856904_item	2714224	et	4	main
võrdsest	doc_536541856904_item	2714228	et	3	main
oma	doc_536541856904_item	2714235	et	4	main
kultuuriilu	doc_536541856904_item	2714236	et	4	main
laulades	doc_536541856904_item	2714237	et	3	main
selles	doc_536541856904_item	2714238	et	4	main
eestiga	doc_536541856904_item	2714244	et	4	main
aga	doc_536541856904_item	2714245	et	3	main
minu	doc_536541856903_item	2713902	et	3	main
see	doc_536541856903_item	2713904	et	3	main
kõige	doc_536541856903_item	2713925	et	4	main
on	doc_536541856903_item	2713927	et	4	main
see	doc_536541856903_item	2713928	et	3	main
inimesed	doc_536541856903_item	2713930	et	3	main
mäletavad	doc_536541856903_item	2713931	et	4	main
ja	doc_536541856903_item	2713932	et	3	main
tunnevad	doc_536541856903_item	2713933	et	3	main
huvi	doc_536541856903_item	2713934	et	4	main
eesti	doc_536541856904_item	2713941	et	4	main
kirjutage	doc_536541856904_item	2713948	et	3	main
essee	doc_536541856904_item	2713949	et	4	main
teemal	doc_536541856904_item	2713950	et	3	main
pikkus	doc_536541856904_item	2713956	et	4	main
arutlev	doc_536541856904_item	2713963	et	4	main
analüüsiv	doc_536541856904_item	2713964	et	4	main
ja	doc_536541856904_item	2713965	et	3	main
tuginema	doc_536541856904_item	2713967	et	3	main
esitatud	doc_536541856904_item	2713971	et	4	main
soovitatav	doc_536541856904_item	2713975	et	4	main
illustreerida	doc_536541856904_item	2713976	et	3	main
millest	doc_536541856904_item	2713987	et	3	main
lauladele	doc_536541856904_item	2713991	et	3	main
näiteks	doc_536541856904_item	2713993	et	4	main
soome	doc_536541856904_item	2713995	et	3	main
mis	doc_536541856904_item	2714001	et	4	main
tuleb	doc_536541856904_item	2714002	et	3	main
meelde	doc_536541856904_item	2714003	et	3	main
fraasiga	doc_536541856904_item	2714004	et	3	main
eesti	doc_536541856904_item	2714005	et	4	main
kultuur	doc_536541856904_item	2714006	et	3	main
ongi	doc_536541856904_item	2714007	et	4	main
laul	doc_536541856904_item	2714008	et	4	main
või	doc_536541856904_item	2714009	et	4	main
laulupidu	doc_536541856904_item	2714010	et	4	main
mina	doc_536541856904_item	2714011	et	4	main
hästi	doc_536541856904_item	2714012	et	3	main
mäletan	doc_536541856904_item	2714013	et	3	main
eesti	doc_536541856904_item	2714015	et	4	main
kirjanduse	doc_536541856904_item	2714016	et	3	main
tunnid	doc_536541856904_item	2714017	et	3	main
kus	doc_536541856904_item	2714018	et	3	main
me	doc_536541856904_item	2714019	et	4	main
väga	doc_536541856904_item	2714020	et	3	main
oma	doc_536541856904_item	2714014	et	4	main
alati	doc_536541856904_item	2714028	et	4	main
mistahes	doc_536541856904_item	2714044	et	4	main
sõnu	doc_536541856904_item	2714055	et	4	main
ja	doc_536541856904_item	2714056	et	3	main
kust	doc_536541856904_item	2714064	et	4	main
olla	doc_536541856904_item	2714080	et	3	main
tõsisem	doc_536541856904_item	2714081	et	4	main
kui	doc_536541856904_item	2714082	et	3	main
nad	doc_536541856904_item	2714083	et	3	main
uus	doc_536541856904_item	2714084	et	3	main
pühendatud	doc_536541856904_item	2714090	et	4	main
lastelaul	doc_536541856904_item	2714094	et	4	main
inimesed	doc_536541856904_item	2714126	et	3	main
ja	doc_536541856904_item	2714131	et	3	main
täna	doc_536541856904_item	2714133	et	4	main
ma	doc_536541856904_item	2714134	et	3	main
sain	doc_536541856904_item	2714135	et	3	main
rohkem	doc_536541856904_item	2714136	et	4	main
teise	doc_536541856904_item	2713944	et	4	main
teeb	doc_536541856904_item	2713952	et	3	main
300	doc_536541856904_item	2713957	et	2	main
essee	doc_536541856904_item	2713960	et	4	main
üldistav	doc_536541856904_item	2713966	et	4	main
loengus	doc_536541856904_item	2713968	et	3	main
lugemistekstis	doc_536541856904_item	2713970	et	3	main
sõna	doc_536541856904_item	2714000	et	4	main
rääkisime	doc_536541856904_item	2714022	et	3	main
läbi	doc_536541856904_item	2714035	et	4	main
elada	doc_536541856904_item	2714036	et	3	main
kriitilised	doc_536541856904_item	2714037	et	3	main
momendid	doc_536541856904_item	2714038	et	3	main
kas	doc_536541856904_item	2714045	et	3	main
on	doc_536541856904_item	2714046	et	4	main
halb	doc_536541856904_item	2714047	et	3	main
rütm	doc_536541856904_item	2714057	et	3	main
sai	doc_536541856904_item	2714065	et	4	main
juba	doc_536541856904_item	2714066	et	3	main
mõttega	doc_536541856904_item	2714067	et	3	main
laulutekstid	doc_536541856904_item	2714068	et	3	main
see	doc_536541856904_item	2714069	et	3	main
välja	doc_536541856904_item	2714086	et	4	main
teemale	doc_536541856904_item	2714092	et	4	main
laul	doc_536541856904_item	2714095	et	4	main
armastusest	doc_536541856904_item	2714096	et	4	main
töölaul	doc_536541856904_item	2714097	et	4	main
pulmalaul	doc_536541856904_item	2714098	et	4	main
ja	doc_536541856904_item	2714099	et	3	main
nii	doc_536541856904_item	2714100	et	3	main
edasi	doc_536541856904_item	2714101	et	3	main
laulu	doc_536541856904_item	2714102	et	4	main
juurde	doc_536541856904_item	2714103	et	4	main
tulid	doc_536541856904_item	2714104	et	4	main
ka	doc_536541856904_item	2714105	et	3	main
tantsuliikumised	doc_536541856904_item	2714106	et	3	main
igasugused	doc_536541856904_item	2714107	et	3	main
muusika	doc_536541856904_item	2714108	et	4	main
koos	doc_536541856904_item	2714110	et	4	main
instrumendid	doc_536541856904_item	2714109	et	3	main
seda	doc_536541856904_item	2714111	et	3	main
võiks	doc_536541856904_item	2714112	et	4	main
nimetada	doc_536541856904_item	2714113	et	3	main
pidu	doc_536541856904_item	2714114	et	4	main
või	doc_536541856904_item	2714115	et	4	main
aja	doc_536541856904_item	2714116	et	4	main
veetmine	doc_536541856904_item	2714117	et	4	main
näiteks	doc_536541856904_item	2714118	et	4	main
meil	doc_536541856904_item	2714119	et	4	main
on	doc_536541856904_item	2714120	et	4	main
inimesi	doc_536541856904_item	2714151	et	4	main
osalemisest	doc_536541856904_item	2714156	et	4	main
laulupeode	doc_536541856904_item	2714157	et	3	main
korraldamisel	doc_536541856904_item	2714158	et	4	main
ja	doc_536541856904_item	2714159	et	3	main
kirjutamisel	doc_536541856904_item	2714161	et	4	main
tõttu	doc_536541856904_item	2714163	et	4	main
heliloojad	doc_536541856904_item	2714167	et	3	main
ka	doc_536541856904_item	2714172	et	3	main
igasugust	doc_536541856904_item	2714185	et	3	main
leab	doc_536541856904_item	2714188	et	4	main
laul	doc_536541856904_item	2714190	et	4	main
mis	doc_536541856904_item	2714191	et	4	main
vastab	doc_536541856904_item	2714192	et	3	main
arvutid	doc_536541856904_item	2714122	et	4	main
tol	doc_536541856904_item	2714124	et	3	main
veetsid	doc_536541856904_item	2714127	et	4	main
muusikaga	doc_536541856904_item	2714130	et	3	main
lauludega	doc_536541856904_item	2714132	et	3	main
teada	doc_536541856904_item	2714137	et	3	main
ka	doc_536541856904_item	2714138	et	3	main
laulupeodest	doc_536541856904_item	2714139	et	3	main
hästi	doc_536541856904_item	2714140	et	3	main
tuntud	doc_536541856904_item	2714141	et	4	main
laulupeod	doc_536541856904_item	2714142	et	4	main
siis	doc_536541856904_item	2714146	et	3	main
tallinnasse	doc_536541856904_item	2714148	et	3	main
veel	doc_536541856904_item	2714153	et	4	main
sai	doc_536541856904_item	2714171	et	4	main
muusikat	doc_536541856904_item	2714186	et	3	main
tema	doc_536541856904_item	2714193	et	4	main
näha	doc_536541856904_item	2714204	et	3	main
on	doc_536541856904_item	2714208	et	4	main
võru	doc_536541856904_item	2714209	et	4	main
folkloorfestival	doc_536541856904_item	2714210	et	4	main
sellel	doc_536541856904_item	2714211	et	4	main
festivalil	doc_536541856904_item	2714212	et	3	main
esinevad	doc_536541856904_item	2714213	et	4	main
igasugused	doc_536541856904_item	2714214	et	3	main
rahvad	doc_536541856904_item	2714215	et	3	main
külalised	doc_536541856904_item	2714216	et	4	main
üle	doc_536541856904_item	2714217	et	3	main
maailma	doc_536541856904_item	2714218	et	4	main
kes	doc_536541856904_item	2714219	et	4	main
näitavad	doc_536541856904_item	2714220	et	4	main
kultuur	doc_536541856904_item	2714222	et	3	main
kultuur	doc_536541856904_item	2714227	et	3	main
teistega	doc_536541856904_item	2714229	et	4	main
saa	doc_536541856904_item	2714241	et	4	main
olla	doc_536541856904_item	2714242	et	3	main
ainult	doc_536541856904_item	2714248	et	4	main
meeldiv	doc_536541856904_item	2714252	et	4	main
ei	doc_536541856904_item	2714257	et	4	main
laulud	doc_536541856904_item	2714260	et	3	main
laulukolektiividest	doc_536541856904_item	2714266	et	4	main
see	doc_536541856904_item	2714267	et	3	main
on	doc_536541856904_item	2714268	et	4	main
saame	doc_536541856904_item	2714273	et	4	main
veel	doc_536541856904_item	2714277	et	4	main
eest	doc_536541856904_item	2714282	et	4	main
esialgu	doc_536541856904_item	2714144	et	3	main
tuntumaks	doc_536541856904_item	2714154	et	4	main
pärast	doc_536541856904_item	2714155	et	4	main
head	doc_536541856904_item	2714166	et	4	main
lauluväljakud	doc_536541856904_item	2714174	et	3	main
laulupidu	doc_536541856904_item	2714177	et	4	main
igaüks	doc_536541856904_item	2714187	et	3	main
endale	doc_536541856904_item	2714189	et	4	main
maitsele	doc_536541856904_item	2714194	et	3	main
rääkida	doc_536541856904_item	2714198	et	3	main
ühest	doc_536541856904_item	2714200	et	4	main
peost	doc_536541856904_item	2714201	et	4	main
kus	doc_536541856904_item	2714202	et	3	main
võib	doc_536541856904_item	2714203	et	3	main
laulukolektiivid	doc_536541856904_item	2714206	et	4	main
minu	doc_536541856904_item	2714223	et	3	main
kelle	doc_536541856904_item	2714226	et	4	main
võrdne	doc_536541856904_item	2714243	et	3	main
minu	doc_536541856904_item	2714249	et	3	main
kõige	doc_536541856904_item	2714251	et	4	main
on	doc_536541856904_item	2714253	et	4	main
unusta	doc_536541856904_item	2714258	et	4	main
oma	doc_536541856904_item	2714259	et	4	main
alati	doc_536541856904_item	2714261	et	4	main
hämmastav	doc_536541856904_item	2714269	et	4	main
seepärast	doc_536541856904_item	2714270	et	3	main
et	doc_536541856904_item	2714271	et	3	main
säilitada	doc_536541856904_item	2714274	et	3	main
kultuur	doc_536541856904_item	2714276	et	3	main
ja	doc_536541856904_item	2714279	et	3	main
tartus	doc_536541856904_item	2714145	et	3	main
palju	doc_536541856904_item	2714149	et	4	main
tuntud	doc_536541856904_item	2714150	et	4	main
sai	doc_536541856904_item	2714152	et	4	main
saime	doc_536541856904_item	2714165	et	3	main
eesti	doc_536541856904_item	2714169	et	4	main
rahvas	doc_536541856904_item	2714170	et	4	main
üle	doc_536541856904_item	2714175	et	3	main
eesti	doc_536541856904_item	2714176	et	4	main
oli	doc_536541856904_item	2714178	et	3	main
ja	doc_536541856904_item	2714179	et	3	main
aga	doc_536541856904_item	2714195	et	3	main
veel	doc_536541856904_item	2714197	et	4	main
veel	doc_536541856904_item	2714199	et	4	main
eestlased	doc_536541856904_item	2714225	et	3	main
ei	doc_536541856904_item	2714230	et	4	main
ole	doc_536541856904_item	2714231	et	4	main
nii	doc_536541856904_item	2714232	et	3	main
keegi	doc_536541856904_item	2714239	et	4	main
on	doc_536541856904_item	2714247	et	4	main
see	doc_536541856904_item	2714254	et	3	main
noored	doc_536541856904_item	2714256	et	3	main
tahan	doc_536541856904_item	2714196	et	3	main
head	doc_536541856904_item	2714205	et	4	main
see	doc_536541856904_item	2714207	et	3	main
oma	doc_536541856904_item	2714221	et	4	main
vana	doc_536541856904_item	2714233	et	4	main
näitab	doc_536541856904_item	2714234	et	3	main
ei	doc_536541856904_item	2714240	et	4	main
arust	doc_536541856904_item	2714250	et	4	main
et	doc_536541856904_item	2714255	et	3	main
võttavad	doc_536541856904_item	2714262	et	4	main
me	doc_536541856904_item	2714272	et	4	main
oma	doc_536541856904_item	2714275	et	4	main
kaua	doc_536541856904_item	2714278	et	3	main
olla	doc_536541856904_item	2714280	et	3	main
see	doc_536541856904_item	2714246	et	3	main
osa	doc_536541856904_item	2714263	et	4	main
laulupeodest	doc_536541856904_item	2714264	et	3	main
ja	doc_536541856904_item	2714265	et	3	main
selle	doc_536541856904_item	2714281	et	4	main
uhke	doc_536541856904_item	2714283	et	4	main
teise	doc_536541856907_item	2714933	et	4	main
mis	doc_536541856907_item	2714940	et	4	main
teeb	doc_536541856907_item	2714941	et	3	main
eestlastest	doc_536541856907_item	2714942	et	4	main
laulurahva	doc_536541856907_item	2714943	et	3	main
keele	doc_536541856907_item	2714931	et	4	main
kui	doc_536541856907_item	2714932	et	3	main
essee	doc_536541856907_item	2714949	et	4	main
analüüsiv	doc_536541856907_item	2714953	et	4	main
lugemistekstis	doc_536541856907_item	2714959	et	3	main
laulavad	doc_536541856907_item	2714969	et	4	main
kui	doc_536541856907_item	2714970	et	3	main
neid	doc_536541856907_item	2714996	et	4	main
tegi	doc_536541856907_item	2714998	et	4	main
tugevamaks	doc_536541856907_item	2714999	et	4	main
et	doc_536541856907_item	2715000	et	3	main
eesti	doc_536541856907_item	2715005	et	4	main
laulud	doc_536541856907_item	2715012	et	3	main
väga	doc_536541856907_item	2715023	et	3	main
ja	doc_536541856907_item	2715025	et	3	main
neid	doc_536541856907_item	2715027	et	4	main
see	doc_536541856907_item	2715031	et	3	main
ei	doc_536541856907_item	2715032	et	4	main
asi	doc_536541856907_item	2715038	et	4	main
et	doc_536541856907_item	2715039	et	3	main
oma	doc_536541856907_item	2715043	et	4	main
oma	doc_536541856907_item	2715046	et	4	main
arhiivides	doc_536541856907_item	2715050	et	3	main
palju	doc_536541856907_item	2715052	et	4	main
laulda	doc_536541856907_item	2715063	et	4	main
nad	doc_536541856907_item	2715095	et	3	main
erinevate	doc_536541856907_item	2715098	et	4	main
rahvuste	doc_536541856907_item	2715099	et	3	main
huvitav	doc_536541856907_item	2715108	et	4	main
setu	doc_536541856907_item	2715118	et	4	main
sellest	doc_536541856907_item	2715124	et	4	main
on	doc_536541856907_item	2715127	et	4	main
esimene	doc_536541856907_item	2715129	et	3	main
konkurssil	doc_536541856907_item	2715132	et	4	main
ja	doc_536541856907_item	2715142	et	3	main
eesti	doc_536541856907_item	2715145	et	4	main
essee	doc_536541856907_item	2714929	et	4	main
kirjutamine	doc_536541856907_item	2714936	et	4	main
kirjutage	doc_536541856907_item	2714937	et	3	main
essee	doc_536541856907_item	2714938	et	4	main
teemal	doc_536541856907_item	2714939	et	3	main
350	doc_536541856907_item	2714947	et	2	main
sõna	doc_536541856907_item	2714948	et	4	main
arutlev	doc_536541856907_item	2714952	et	4	main
loengus	doc_536541856907_item	2714957	et	3	main
ja	doc_536541856907_item	2714997	et	3	main
kätte	doc_536541856907_item	2715003	et	4	main
saada	doc_536541856907_item	2715004	et	4	main
on	doc_536541856907_item	2715008	et	4	main
tuhat	doc_536541856907_item	2715018	et	4	main
aastat	doc_536541856907_item	2715019	et	3	main
tagasi	doc_536541856907_item	2715020	et	3	main
eesti	doc_536541856907_item	2714930	et	4	main
pikkus	doc_536541856907_item	2714945	et	4	main
300	doc_536541856907_item	2714946	et	2	main
üldistav	doc_536541856907_item	2714955	et	4	main
ja	doc_536541856907_item	2714958	et	3	main
faktidele	doc_536541856907_item	2714961	et	3	main
on	doc_536541856907_item	2714963	et	4	main
keele	doc_536541856907_item	2714934	et	4	main
test	doc_536541856907_item	2714935	et	3	main
essee	doc_536541856907_item	2714944	et	4	main
olema	doc_536541856907_item	2714951	et	4	main
tuginema	doc_536541856907_item	2714956	et	3	main
esitatud	doc_536541856907_item	2714960	et	4	main
alati	doc_536541856907_item	2714968	et	4	main
päike	doc_536541856907_item	2714971	et	3	main
paistab	doc_536541856907_item	2714972	et	3	main
ja	doc_536541856907_item	2714973	et	3	main
kui	doc_536541856907_item	2714974	et	3	main
vihma	doc_536541856907_item	2714975	et	4	main
sajab	doc_536541856907_item	2714976	et	3	main
kui	doc_536541856907_item	2714977	et	3	main
aeg	doc_536541856907_item	2714978	et	3	main
on	doc_536541856907_item	2714979	et	4	main
hea	doc_536541856907_item	2714980	et	4	main
ja	doc_536541856907_item	2714981	et	3	main
kui	doc_536541856907_item	2714982	et	3	main
aeg	doc_536541856907_item	2714983	et	3	main
on	doc_536541856907_item	2714984	et	4	main
halb	doc_536541856907_item	2714985	et	3	main
ajalugu	doc_536541856907_item	2714986	et	4	main
näitab	doc_536541856907_item	2714987	et	3	main
meile	doc_536541856907_item	2714988	et	4	main
et	doc_536541856907_item	2714989	et	3	main
laul	doc_536541856907_item	2714990	et	4	main
alati	doc_536541856907_item	2714991	et	4	main
oli	doc_536541856907_item	2714992	et	3	main
koos	doc_536541856907_item	2714993	et	4	main
eestlastega	doc_536541856907_item	2714994	et	4	main
ühendas	doc_536541856907_item	2714995	et	3	main
peab	doc_536541856907_item	2714950	et	4	main
ja	doc_536541856907_item	2714954	et	3	main
väiteid	doc_536541856907_item	2714962	et	4	main
oma	doc_536541856907_item	2715001	et	4	main
vabadust	doc_536541856907_item	2715002	et	4	main
ajalugu	doc_536541856907_item	2715007	et	4	main
esimesed	doc_536541856907_item	2715011	et	3	main
olid	doc_536541856907_item	2715022	et	4	main
lihtsad	doc_536541856907_item	2715024	et	3	main
muusika	doc_536541856907_item	2715028	et	4	main
instrumendita	doc_536541856907_item	2715029	et	3	main
aga	doc_536541856907_item	2715030	et	3	main
selline	doc_536541856907_item	2715037	et	4	main
lastele	doc_536541856907_item	2715044	et	4	main
eesti	doc_536541856907_item	2715049	et	4	main
ja	doc_536541856907_item	2715061	et	3	main
eesti	doc_536541856907_item	2715064	et	4	main
on	doc_536541856907_item	2715089	et	4	main
selle	doc_536541856907_item	2715092	et	4	main
laule	doc_536541856907_item	2715105	et	4	main
välja	doc_536541856907_item	2715116	et	4	main
eurovisioon	doc_536541856907_item	2715120	et	3	main
ka	doc_536541856907_item	2715121	et	3	main
eestlased	doc_536541856907_item	2715126	et	3	main
koht	doc_536541856907_item	2715130	et	3	main
andis	doc_536541856907_item	2715164	et	3	main
eestlaste	doc_536541856907_item	2715171	et	4	main
rahvusliku	doc_536541856907_item	2715172	et	3	main
kooride	doc_536541856907_item	2715175	et	3	main
laulurahv	doc_536541856907_item	2715182	et	4	main
pikkus	doc_536541856908_item	2715223	et	4	main
essee	doc_536541856908_item	2715227	et	4	main
peab	doc_536541856908_item	2715228	et	4	main
olema	doc_536541856908_item	2715229	et	4	main
tuginema	doc_536541856908_item	2715234	et	3	main
faktidele	doc_536541856908_item	2715239	et	3	main
on	doc_536541856908_item	2715241	et	4	main
soovitatav	doc_536541856908_item	2715242	et	4	main
illustreerida	doc_536541856908_item	2715243	et	3	main
näidetega	doc_536541856908_item	2715244	et	3	main
folkloor	doc_536541856908_item	2715253	et	4	main
koosneb	doc_536541856908_item	2715254	et	3	main
eesti	doc_536541856908_item	2715261	et	4	main
regivärsiline	doc_536541856908_item	2715265	et	4	main
rahvalaulu	doc_536541856908_item	2715267	et	4	main
laulmisega	doc_536541856908_item	2715268	et	4	main
rõhutamine	doc_536541856908_item	2715275	et	4	main
jalapõrutus	doc_536541856908_item	2715279	et	4	main
ja	doc_536541856908_item	2715286	et	3	main
õpetasid	doc_536541856908_item	2715288	et	4	main
koorilaulu	doc_536541856908_item	2715294	et	4	main
levikuga	doc_536541856908_item	2715295	et	3	main
koosnes	doc_536541856908_item	2715296	et	3	main
ka	doc_536541856908_item	2715303	et	3	main
neil	doc_536541856908_item	2715315	et	4	main
kus	doc_536541856908_item	2715323	et	3	main
lauldi	doc_536541856908_item	2715324	et	3	main
on	doc_536541856908_item	2715336	et	4	main
lauldi	doc_536541856908_item	2715337	et	3	main
kooris	doc_536541856908_item	2715338	et	4	main
üksi	doc_536541856908_item	2715339	et	4	main
kõige	doc_536541856908_item	2715343	et	4	main
rohkem	doc_536541856908_item	2715344	et	4	main
on	doc_536541856908_item	2715377	et	4	main
19	doc_536541856908_item	2715380	et	2	main
uuemas	doc_536541856908_item	2715393	et	4	main
läti	doc_536541856908_item	2715395	et	4	main
ja	doc_536541856908_item	2715396	et	3	main
venemaa	doc_536541856908_item	2715397	et	4	main
kujunes	doc_536541856908_item	2715402	et	3	main
laulupeost	doc_536541856908_item	2715417	et	4	main
osavõtjate	doc_536541856908_item	2715418	et	3	main
arv	doc_536541856908_item	2715419	et	3	main
aastal	doc_536541856908_item	2715423	et	3	main
tallinna	doc_536541856908_item	2715434	et	4	main
lauluväljakule	doc_536541856908_item	2715435	et	3	main
üle-eestiline	doc_536541856908_item	2715444	et	3	main
ajal	doc_536541856908_item	2715449	et	4	main
tähelepanuväärsem	doc_536541856908_item	2715451	et	4	main
ja	doc_536541856908_item	2715452	et	3	main
massilisem	doc_536541856908_item	2715453	et	4	main
soovitatav	doc_536541856907_item	2714964	et	4	main
illustreerida	doc_536541856907_item	2714965	et	3	main
näidetega	doc_536541856907_item	2714966	et	3	main
eestlased	doc_536541856907_item	2714967	et	3	main
väga	doc_536541856907_item	2715009	et	3	main
on	doc_536541856907_item	2715014	et	4	main
ole	doc_536541856907_item	2715033	et	4	main
regilaulu	doc_536541856907_item	2715040	et	4	main
kokkusaades	doc_536541856907_item	2715048	et	4	main
on	doc_536541856907_item	2715051	et	4	main
folkloori	doc_536541856907_item	2715053	et	4	main
ja	doc_536541856907_item	2715054	et	3	main
see	doc_536541856907_item	2715055	et	3	main
räägib	doc_536541856907_item	2715056	et	3	main
armastavad	doc_536541856907_item	2715062	et	4	main
folkloor	doc_536541856907_item	2715065	et	4	main
on	doc_536541856907_item	2715066	et	4	main
väga	doc_536541856907_item	2715090	et	3	main
pärast	doc_536541856907_item	2715093	et	4	main
kujunenud	doc_536541856907_item	2715097	et	4	main
on	doc_536541856907_item	2715101	et	4	main
tore	doc_536541856907_item	2715102	et	3	main
et	doc_536541856907_item	2715103	et	3	main
vanasid	doc_536541856907_item	2715104	et	3	main
värskast	doc_536541856907_item	2715114	et	4	main
andis	doc_536541856907_item	2715115	et	3	main
keeles	doc_536541856907_item	2715119	et	4	main
hästi	doc_536541856907_item	2715122	et	3	main
on	doc_536541856907_item	2715133	et	4	main
uni	doc_536541856907_item	2715135	et	3	main
meie	doc_536541856907_item	2715136	et	4	main
temaatilised	doc_536541856907_item	2715143	et	4	main
saada	doc_536541856907_item	2715154	et	4	main
laulupidu	doc_536541856907_item	2715159	et	4	main
pidu	doc_536541856907_item	2715163	et	4	main
teist	doc_536541856907_item	2715166	et	4	main
tähendamist	doc_536541856907_item	2715167	et	4	main
räägib	doc_536541856907_item	2715178	et	3	main
eestlaste	doc_536541856907_item	2715187	et	4	main
laulurahva	doc_536541856908_item	2715221	et	3	main
sõna	doc_536541856908_item	2715226	et	4	main
ja	doc_536541856908_item	2715232	et	3	main
ja	doc_536541856908_item	2715236	et	3	main
nende	doc_536541856908_item	2715248	et	4	main
laul	doc_536541856908_item	2715257	et	4	main
nimetatakse	doc_536541856908_item	2715264	et	3	main
rahvalaul	doc_536541856908_item	2715266	et	4	main
rütmi	doc_536541856908_item	2715274	et	4	main
mitu	doc_536541856908_item	2715282	et	4	main
lastele	doc_536541856908_item	2715309	et	4	main
sellest	doc_536541856908_item	2715322	et	4	main
laul	doc_536541856908_item	2715335	et	4	main
kiikudes	doc_536541856908_item	2715340	et	4	main
ka	doc_536541856908_item	2715361	et	3	main
välja	doc_536541856908_item	2715365	et	4	main
teine	doc_536541856908_item	2715372	et	3	main
regilaul	doc_536541856908_item	2715378	et	4	main
eeskujudel	doc_536541856908_item	2715392	et	3	main
aastal	doc_536541856908_item	2715400	et	3	main
laulupidu	doc_536541856908_item	2715405	et	4	main
sellest	doc_536541856908_item	2715406	et	4	main
rahvalaulu	doc_536541856907_item	2715006	et	4	main
pikk	doc_536541856907_item	2715010	et	4	main
regilaulud	doc_536541856907_item	2715013	et	3	main
kujunenud	doc_536541856907_item	2715015	et	4	main
enam	doc_536541856907_item	2715016	et	4	main
kui	doc_536541856907_item	2715017	et	3	main
nad	doc_536541856907_item	2715021	et	3	main
lauldi	doc_536541856907_item	2715026	et	3	main
põhimõtte	doc_536541856907_item	2715034	et	3	main
lauldi	doc_536541856907_item	2715041	et	3	main
lauldi	doc_536541856907_item	2715045	et	3	main
vahel	doc_536541856907_item	2715047	et	4	main
rahvalaulud	doc_536541856907_item	2715088	et	3	main
on	doc_536541856907_item	2715096	et	4	main
mõjul	doc_536541856907_item	2715100	et	4	main
oli	doc_536541856907_item	2715109	et	3	main
see	doc_536541856907_item	2715110	et	3	main
et	doc_536541856907_item	2715111	et	3	main
rock	doc_536541856907_item	2715112	et	4	main
bänd	doc_536541856907_item	2715113	et	3	main
et	doc_536541856907_item	2715125	et	3	main
nagu	doc_536541856907_item	2715134	et	3	main
võimalust	doc_536541856907_item	2715148	et	3	main
mängis	doc_536541856907_item	2715157	et	3	main
arvates	doc_536541856907_item	2715161	et	4	main
peolt	doc_536541856907_item	2715169	et	4	main
kujunes	doc_536541856907_item	2715170	et	3	main
ka	doc_536541856907_item	2715177	et	3	main
eestlased	doc_536541856907_item	2715180	et	3	main
harrastus	doc_536541856907_item	2715188	et	4	main
et	doc_536541856907_item	2715192	et	3	main
300	doc_536541856908_item	2715224	et	2	main
üldistav	doc_536541856908_item	2715233	et	4	main
esitatud	doc_536541856908_item	2715238	et	4	main
laulurahva	doc_536541856908_item	2715247	et	3	main
kultuuriidentiteet	doc_536541856908_item	2715249	et	4	main
ja	doc_536541856908_item	2715250	et	3	main
laulutraditsioon	doc_536541856908_item	2715251	et	3	main
eesti	doc_536541856908_item	2715252	et	4	main
pillimäng	doc_536541856908_item	2715258	et	3	main
ja	doc_536541856908_item	2715259	et	3	main
tants	doc_536541856908_item	2715260	et	3	main
võiksid	doc_536541856908_item	2715269	et	4	main
kaasneda	doc_536541856908_item	2715270	et	3	main
õõtsutamine	doc_536541856908_item	2715277	et	4	main
regilaulul	doc_536541856908_item	2715280	et	3	main
ehitust	doc_536541856908_item	2715284	et	4	main
koorilaulu	doc_536541856908_item	2715293	et	4	main
ka	doc_536541856908_item	2715297	et	3	main
peale	doc_536541856908_item	2715300	et	4	main
telefoni	doc_536541856908_item	2715314	et	4	main
tähtis	doc_536541856907_item	2715035	et	4	main
on	doc_536541856907_item	2715036	et	4	main
naised	doc_536541856907_item	2715042	et	3	main
sellest	doc_536541856907_item	2715057	et	4	main
et	doc_536541856907_item	2715058	et	3	main
eestlased	doc_536541856907_item	2715059	et	3	main
armastasid	doc_536541856907_item	2715060	et	4	main
väga	doc_536541856907_item	2715067	et	3	main
rikkas	doc_536541856907_item	2715068	et	4	main
näiteks	doc_536541856907_item	2715069	et	4	main
mulle	doc_536541856907_item	2715070	et	4	main
meeldivad	doc_536541856907_item	2715071	et	4	main
karjaste	doc_536541856907_item	2715072	et	4	main
laulud	doc_536541856907_item	2715073	et	3	main
nad	doc_536541856907_item	2715074	et	3	main
on	doc_536541856907_item	2715075	et	4	main
omapärased	doc_536541856907_item	2715076	et	4	main
ja	doc_536541856907_item	2715077	et	3	main
nende	doc_536541856907_item	2715078	et	4	main
sisu	doc_536541856907_item	2715079	et	4	main
ka	doc_536541856907_item	2715080	et	3	main
meeldib	doc_536541856907_item	2715081	et	3	main
mulle	doc_536541856907_item	2715082	et	4	main
ma	doc_536541856907_item	2715083	et	3	main
sain	doc_536541856907_item	2715084	et	3	main
aru	doc_536541856907_item	2715085	et	4	main
et	doc_536541856907_item	2715086	et	3	main
eestlaste	doc_536541856907_item	2715087	et	4	main
spetsiifilised	doc_536541856907_item	2715091	et	3	main
et	doc_536541856907_item	2715094	et	3	main
ei	doc_536541856907_item	2715106	et	4	main
unustatakse	doc_536541856907_item	2715107	et	3	main
plaadi	doc_536541856907_item	2715117	et	4	main
räägib	doc_536541856907_item	2715123	et	3	main
laulurahv	doc_536541856907_item	2715128	et	4	main
sellel	doc_536541856907_item	2715131	et	4	main
ajal	doc_536541856907_item	2715137	et	4	main
tihti	doc_536541856907_item	2715138	et	3	main
korraldatakse	doc_536541856907_item	2715139	et	3	main
folkloori	doc_536541856907_item	2715140	et	4	main
festivalid	doc_536541856907_item	2715141	et	3	main
peod	doc_536541856907_item	2715144	et	4	main
andis	doc_536541856907_item	2715147	et	3	main
suurt	doc_536541856907_item	2715155	et	3	main
rolli	doc_536541856907_item	2715156	et	4	main
esimene	doc_536541856907_item	2715158	et	3	main
lauludele	doc_536541856907_item	2715165	et	3	main
liikumise	doc_536541856907_item	2715173	et	4	main
kõrghetk	doc_536541856907_item	2715174	et	3	main
aga	doc_536541856907_item	2715189	et	3	main
ma	doc_536541856907_item	2715190	et	3	main
arvan	doc_536541856907_item	2715191	et	3	main
harrastus	doc_536541856907_item	2715194	et	4	main
on	doc_536541856907_item	2715195	et	4	main
eestlased	doc_536541856907_item	2715197	et	3	main
laulavad	doc_536541856907_item	2715198	et	4	main
nii	doc_536541856907_item	2715199	et	3	main
linnas	doc_536541856907_item	2715200	et	4	main
kui	doc_536541856907_item	2715201	et	3	main
maal	doc_536541856907_item	2715202	et	4	main
nii	doc_536541856907_item	2715203	et	3	main
palju	doc_536541856907_item	2715204	et	4	main
nad	doc_536541856907_item	2715205	et	3	main
laulavad	doc_536541856907_item	2715206	et	4	main
essee	doc_536541856908_item	2715207	et	4	main
eesti	doc_536541856908_item	2715208	et	4	main
keele	doc_536541856908_item	2715209	et	4	main
kui	doc_536541856908_item	2715210	et	3	main
teise	doc_536541856908_item	2715211	et	4	main
keele	doc_536541856908_item	2715212	et	4	main
test	doc_536541856908_item	2715213	et	3	main
kirjutamine	doc_536541856908_item	2715214	et	4	main
kirjutage	doc_536541856908_item	2715215	et	3	main
essee	doc_536541856908_item	2715216	et	4	main
teemal	doc_536541856908_item	2715217	et	3	main
mis	doc_536541856908_item	2715218	et	4	main
teeb	doc_536541856908_item	2715219	et	3	main
eestlastest	doc_536541856908_item	2715220	et	4	main
laulutraditsioon	doc_536541856907_item	2715146	et	3	main
oma	doc_536541856907_item	2715149	et	4	main
kultuuri	doc_536541856907_item	2715150	et	4	main
säilida	doc_536541856907_item	2715151	et	3	main
ja	doc_536541856907_item	2715152	et	3	main
iidentiteeti	doc_536541856907_item	2715153	et	4	main
minu	doc_536541856907_item	2715160	et	3	main
see	doc_536541856907_item	2715162	et	3	main
sellelt	doc_536541856907_item	2715168	et	4	main
arv	doc_536541856907_item	2715176	et	3	main
et	doc_536541856907_item	2715179	et	3	main
on	doc_536541856907_item	2715181	et	4	main
muusika	doc_536541856907_item	2715183	et	4	main
ja	doc_536541856907_item	2715184	et	3	main
laulud	doc_536541856907_item	2715185	et	3	main
on	doc_536541856907_item	2715186	et	4	main
see	doc_536541856907_item	2715193	et	3	main
hea	doc_536541856907_item	2715196	et	4	main
350	doc_536541856908_item	2715225	et	2	main
analüüsiv	doc_536541856908_item	2715231	et	4	main
eestlastest	doc_536541856908_item	2715245	et	4	main
teeb	doc_536541856908_item	2715246	et	3	main
kolmest	doc_536541856908_item	2715255	et	4	main
osast	doc_536541856908_item	2715256	et	4	main
vanemat	doc_536541856908_item	2715262	et	4	main
sellised	doc_536541856908_item	2715271	et	4	main
tegevused	doc_536541856908_item	2715272	et	4	main
nagu	doc_536541856908_item	2715273	et	3	main
või	doc_536541856908_item	2715278	et	4	main
järgivat	doc_536541856908_item	2715291	et	4	main
mitmehäälset	doc_536541856908_item	2715292	et	3	main
asutamine	doc_536541856908_item	2715299	et	4	main
rahvalaulu	doc_536541856908_item	2715301	et	4	main
vokaalseid	doc_536541856908_item	2715305	et	3	main
emad	doc_536541856908_item	2715307	et	3	main
lapsed	doc_536541856908_item	2715310	et	3	main
kõikasid	doc_536541856908_item	2715311	et	4	main
üksteisele	doc_536541856908_item	2715312	et	3	main
kuna	doc_536541856908_item	2715313	et	3	main
mõelda	doc_536541856908_item	2715333	et	4	main
millest	doc_536541856908_item	2715334	et	3	main
laulsid	doc_536541856908_item	2715345	et	4	main
naised	doc_536541856908_item	2715346	et	3	main
kuna	doc_536541856908_item	2715347	et	3	main
mehed	doc_536541856908_item	2715348	et	3	main
mehed	doc_536541856908_item	2715362	et	3	main
hakkab	doc_536541856908_item	2715373	et	3	main
saj	doc_536541856908_item	2715381	et	4	main
pooles	doc_536541856908_item	2715383	et	4	main
oli	doc_536541856908_item	2715384	et	3	main
see	doc_536541856908_item	2715385	et	3	main
uus	doc_536541856908_item	2715386	et	3	main
nähtus	doc_536541856908_item	2715387	et	4	main
suur	doc_536541856908_item	2715388	et	3	main
roll	doc_536541856908_item	2715389	et	3	main
mängis	doc_536541856908_item	2715390	et	3	main
kirjanduslikul	doc_536541856908_item	2715391	et	3	main
rahvalaulas	doc_536541856908_item	2715394	et	4	main
tartus	doc_536541856908_item	2715401	et	3	main
ülemaaline	doc_536541856908_item	2715404	et	4	main
eestlaste	doc_536541856908_item	2715408	et	4	main
liikumise	doc_536541856908_item	2715410	et	4	main
kõrghetk	doc_536541856908_item	2715411	et	3	main
ja	doc_536541856908_item	2715412	et	3	main
alguse	doc_536541856908_item	2715414	et	3	main
ja	doc_536541856908_item	2715421	et	3	main
muutusid	doc_536541856908_item	2715424	et	4	main
muusika	doc_536541856908_item	2715426	et	4	main
suurüritusteks	doc_536541856908_item	2715427	et	3	main
1994	doc_536541856908_item	2715428	et	2	main
aasta	doc_536541856908_item	2715429	et	4	main
juulis	doc_536541856908_item	2715430	et	3	main
on	doc_536541856908_item	2715446	et	4	main
lisaks	doc_536541856908_item	2715456	et	4	main
koos	doc_536541856908_item	2715464	et	4	main
tuhandel	doc_536541856908_item	2715477	et	3	main
sõnu	doc_536541856908_item	2715480	et	4	main
ja	doc_536541856908_item	2715481	et	3	main
sama	doc_536541856908_item	2715482	et	4	main
keele	doc_536541856909_item	2715490	et	4	main
kirjutage	doc_536541856909_item	2715493	et	3	main
essee	doc_536541856908_item	2715222	et	4	main
arutlev	doc_536541856908_item	2715230	et	4	main
loengus	doc_536541856908_item	2715235	et	3	main
lugemistekstis	doc_536541856908_item	2715237	et	3	main
väiteid	doc_536541856908_item	2715240	et	4	main
rahvalaulu	doc_536541856908_item	2715263	et	4	main
keha	doc_536541856908_item	2715276	et	4	main
on	doc_536541856908_item	2715281	et	4	main
ajaloo	doc_536541856908_item	2715283	et	4	main
kirik	doc_536541856908_item	2715285	et	3	main
külakoolid	doc_536541856908_item	2715287	et	3	main
saksa	doc_536541856908_item	2715289	et	4	main
eeskuju	doc_536541856908_item	2715290	et	4	main
puhkpilliorkestrite	doc_536541856908_item	2715298	et	3	main
on	doc_536541856908_item	2715302	et	4	main
muid	doc_536541856908_item	2715304	et	4	main
žanre	doc_536541856908_item	2715306	et	2	main
laulsid	doc_536541856908_item	2715308	et	4	main
ei	doc_536541856908_item	2715316	et	4	main
olnud	doc_536541856908_item	2715317	et	4	main
lauldi	doc_536541856908_item	2715318	et	3	main
see	doc_536541856908_item	2715320	et	3	main
erinevalt	doc_536541856908_item	2715319	et	4	main
suhtus	doc_536541856908_item	2715321	et	3	main
kellega	doc_536541856908_item	2715326	et	3	main
lauldi	doc_536541856908_item	2715327	et	3	main
kordas	doc_536541856908_item	2715329	et	3	main
lause	doc_536541856908_item	2715330	et	4	main
selleks	doc_536541856908_item	2715331	et	4	main
et	doc_536541856908_item	2715332	et	3	main
jne	doc_536541856908_item	2715341	et	4	main
aga	doc_536541856908_item	2715342	et	3	main
või	doc_536541856908_item	2715351	et	4	main
tuldi	doc_536541856908_item	2715364	et	3	main
spontaalsed	doc_536541856908_item	2715366	et	4	main
laulud	doc_536541856908_item	2715367	et	3	main
üks	doc_536541856908_item	2715368	et	3	main
inimene	doc_536541856908_item	2715369	et	3	main
alustab	doc_536541856908_item	2715370	et	3	main
ja	doc_536541856908_item	2715371	et	3	main
kaasa	doc_536541856908_item	2715374	et	4	main
laulma	doc_536541856908_item	2715375	et	3	main
tänaseks	doc_536541856908_item	2715376	et	4	main
kadunud	doc_536541856908_item	2715379	et	4	main
ii	doc_536541856908_item	2715382	et	4	main
mõju	doc_536541856908_item	2715398	et	4	main
1869	doc_536541856908_item	2715399	et	2	main
esimene	doc_536541856908_item	2715403	et	3	main
kasvas	doc_536541856908_item	2715420	et	3	main
laulupidude	doc_536541856908_item	2715442	et	4	main
ka	doc_536541856908_item	2715447	et	3	main
ka	doc_536541856908_item	2715459	et	3	main
suur	doc_536541856908_item	2715460	et	3	main
rahvapidu	doc_536541856908_item	2715461	et	4	main
kuhu	doc_536541856908_item	2715462	et	3	main
kaasa	doc_536541856908_item	2715470	et	4	main
sellist	doc_536541856908_item	2715472	et	4	main
teeb	doc_536541856909_item	2715497	et	3	main
350	doc_536541856909_item	2715503	et	2	main
essee	doc_536541856909_item	2715505	et	4	main
analüüsiv	doc_536541856909_item	2715509	et	4	main
tuginema	doc_536541856909_item	2715512	et	3	main
lugemistekstis	doc_536541856909_item	2715515	et	3	main
ja	doc_536541856909_item	2715524	et	3	main
ja	doc_536541856909_item	2715532	et	3	main
ajalooga	doc_536541856909_item	2715538	et	4	main
et	doc_536541856909_item	2715541	et	3	main
palju	doc_536541856909_item	2715552	et	4	main
laulutraditsioone	doc_536541856909_item	2715553	et	3	main
aranema	doc_536541856909_item	2715557	et	4	main
tagasi	doc_536541856909_item	2715561	et	3	main
regilaul	doc_536541856909_item	2715564	et	4	main
koor	doc_536541856909_item	2715569	et	4	main
kasutama	doc_536541856909_item	2715606	et	3	main
muusikas	doc_536541856909_item	2715607	et	3	main
erinevaid	doc_536541856909_item	2715608	et	4	main
ja	doc_536541856908_item	2715325	et	3	main
koor	doc_536541856908_item	2715328	et	4	main
käisid	doc_536541856908_item	2715349	et	4	main
merel	doc_536541856908_item	2715350	et	3	main
tööl	doc_536541856908_item	2715352	et	3	main
nad	doc_536541856908_item	2715353	et	3	main
laulsid	doc_536541856908_item	2715354	et	4	main
omavahel	doc_536541856908_item	2715355	et	3	main
ja	doc_536541856908_item	2715356	et	3	main
laulsid	doc_536541856908_item	2715357	et	4	main
lastega	doc_536541856908_item	2715358	et	3	main
tegeldes	doc_536541856908_item	2715359	et	3	main
laulsid	doc_536541856908_item	2715360	et	4	main
pidudel	doc_536541856908_item	2715363	et	4	main
kujunes	doc_536541856908_item	2715407	et	3	main
rahvusliku	doc_536541856908_item	2715409	et	3	main
sai	doc_536541856908_item	2715413	et	4	main
laulupidude	doc_536541856908_item	2715415	et	4	main
traditsioon	doc_536541856908_item	2715416	et	3	main
1918	doc_536541856908_item	2715422	et	2	main
kogunesid	doc_536541856908_item	2715431	et	4	main
tuhanded	doc_536541856908_item	2715432	et	3	main
lauljad	doc_536541856908_item	2715433	et	4	main
traditsiooni	doc_536541856908_item	2715443	et	4	main
laulupidu	doc_536541856908_item	2715458	et	4	main
perega	doc_536541856908_item	2715465	et	3	main
kogedes	doc_536541856908_item	2715471	et	4	main
lauldes	doc_536541856908_item	2715484	et	3	main
essee	doc_536541856909_item	2715485	et	4	main
teise	doc_536541856909_item	2715489	et	4	main
mis	doc_536541856909_item	2715496	et	4	main
laulurahva	doc_536541856909_item	2715499	et	3	main
pikkus	doc_536541856909_item	2715501	et	4	main
on	doc_536541856909_item	2715519	et	4	main
laul	doc_536541856909_item	2715523	et	4	main
ajad	doc_536541856909_item	2715531	et	4	main
on	doc_536541856909_item	2715534	et	4	main
otseselt	doc_536541856909_item	2715536	et	4	main
seotud	doc_536541856909_item	2715537	et	4	main
sest	doc_536541856909_item	2715548	et	4	main
eestis	doc_536541856909_item	2715549	et	3	main
on	doc_536541856909_item	2715550	et	4	main
laul	doc_536541856909_item	2715555	et	4	main
tuhat	doc_536541856909_item	2715559	et	4	main
kes	doc_536541856909_item	2715570	et	4	main
kordas	doc_536541856909_item	2715571	et	3	main
tema	doc_536541856909_item	2715572	et	4	main
muusika	doc_536541856909_item	2715609	et	4	main
instrumente	doc_536541856909_item	2715610	et	3	main
või	doc_536541856909_item	2715613	et	4	main
eestis	doc_536541856909_item	2715616	et	3	main
säilinud	doc_536541856909_item	2715618	et	4	main
laulupeod	doc_536541856909_item	2715619	et	4	main
ja	doc_536541856909_item	2715620	et	3	main
rahvas	doc_536541856909_item	2715627	et	4	main
ajal	doc_536541856909_item	2715631	et	4	main
seal	doc_536541856909_item	2715642	et	4	main
eestis	doc_536541856909_item	2715645	et	3	main
rahvalaulu	doc_536541856909_item	2715654	et	4	main
kombed	doc_536541856909_item	2715655	et	3	main
muusika	doc_536541856909_item	2715661	et	4	main
iga	doc_536541856909_item	2715671	et	4	main
üritusi	doc_536541856909_item	2715679	et	4	main
eesti	doc_536541856909_item	2715693	et	4	main
koori	doc_536541856909_item	2715697	et	4	main
orthodox	doc_536541856909_item	2715698	et	4	main
laulsid	doc_536541856909_item	2715701	et	4	main
rahvast	doc_536541856909_item	2715728	et	4	main
ja	doc_536541856909_item	2715729	et	3	main
vanasti	doc_536541856909_item	2715735	et	3	main
kuhugi	doc_536541856909_item	2715744	et	4	main
laulupeod	doc_536541856908_item	2715425	et	4	main
laulupeole	doc_536541856908_item	2715436	et	4	main
et	doc_536541856908_item	2715437	et	3	main
tähistada	doc_536541856908_item	2715438	et	3	main
125	doc_536541856908_item	2715439	et	2	main
aastat	doc_536541856908_item	2715440	et	3	main
kestnud	doc_536541856908_item	2715441	et	4	main
laulupidu	doc_536541856908_item	2715445	et	4	main
praegusel	doc_536541856908_item	2715448	et	3	main
kõige	doc_536541856908_item	2715450	et	4	main
on	doc_536541856908_item	2715457	et	4	main
ja	doc_536541856908_item	2715466	et	3	main
kus	doc_536541856908_item	2715467	et	3	main
laulda	doc_536541856908_item	2715469	et	4	main
tunnet	doc_536541856908_item	2715473	et	3	main
mis	doc_536541856908_item	2715474	et	4	main
tekib	doc_536541856908_item	2715475	et	3	main
ka	doc_536541856908_item	2715476	et	3	main
inimestel	doc_536541856908_item	2715478	et	3	main
samu	doc_536541856908_item	2715479	et	3	main
eesti	doc_536541856909_item	2715486	et	4	main
test	doc_536541856909_item	2715491	et	3	main
300	doc_536541856909_item	2715502	et	2	main
faktidele	doc_536541856909_item	2715517	et	3	main
väiteid	doc_536541856909_item	2715518	et	4	main
manifestatsioon	doc_536541856908_item	2715454	et	3	main
eestis	doc_536541856908_item	2715455	et	3	main
tullakse	doc_536541856908_item	2715463	et	3	main
võib	doc_536541856908_item	2715468	et	3	main
viisi	doc_536541856908_item	2715483	et	4	main
keele	doc_536541856909_item	2715487	et	4	main
kui	doc_536541856909_item	2715488	et	3	main
kirjutamine	doc_536541856909_item	2715492	et	4	main
essee	doc_536541856909_item	2715494	et	4	main
teemal	doc_536541856909_item	2715495	et	3	main
arutlev	doc_536541856909_item	2715508	et	4	main
üldistav	doc_536541856909_item	2715511	et	4	main
ja	doc_536541856909_item	2715514	et	3	main
esitatud	doc_536541856909_item	2715516	et	4	main
nad	doc_536541856909_item	2715533	et	3	main
laulurahvaks	doc_536541856909_item	2715547	et	3	main
hakkas	doc_536541856909_item	2715556	et	3	main
kujunes	doc_536541856909_item	2715563	et	3	main
regilaulu	doc_536541856909_item	2715565	et	4	main
esitas	doc_536541856909_item	2715566	et	3	main
eeslaulja	doc_536541856909_item	2715567	et	4	main
ja	doc_536541856909_item	2715568	et	3	main
sellest	doc_536541856909_item	2715624	et	4	main
vanematel	doc_536541856909_item	2715630	et	4	main
laul	doc_536541856909_item	2715632	et	4	main
ja	doc_536541856909_item	2715633	et	3	main
tants	doc_536541856909_item	2715634	et	3	main
elas	doc_536541856909_item	2715635	et	3	main
eesti	doc_536541856909_item	2715636	et	4	main
praegu	doc_536541856909_item	2715643	et	3	main
on	doc_536541856909_item	2715646	et	4	main
rühmi	doc_536541856909_item	2715650	et	4	main
püüjavad	doc_536541856909_item	2715652	et	4	main
jälgima	doc_536541856909_item	2715653	et	4	main
aitab	doc_536541856909_item	2715665	et	3	main
säilitama	doc_536541856909_item	2715667	et	4	main
vanad	doc_536541856909_item	2715668	et	3	main
traditsioonid	doc_536541856909_item	2715669	et	3	main
viljandis	doc_536541856909_item	2715670	et	4	main
mis	doc_536541856909_item	2715680	et	4	main
rahvalauluga	doc_536541856909_item	2715683	et	4	main
käinud	doc_536541856909_item	2715686	et	4	main
niisugustele	doc_536541856909_item	2715687	et	3	main
üüritusele	doc_536541856909_item	2715688	et	4	main
paar	doc_536541856909_item	2715689	et	3	main
kus	doc_536541856909_item	2715695	et	3	main
singers	doc_536541856909_item	2715699	et	4	main
eestlastest	doc_536541856909_item	2715498	et	4	main
essee	doc_536541856909_item	2715500	et	4	main
sõna	doc_536541856909_item	2715504	et	4	main
peab	doc_536541856909_item	2715506	et	4	main
olema	doc_536541856909_item	2715507	et	4	main
ja	doc_536541856909_item	2715510	et	3	main
loengus	doc_536541856909_item	2715513	et	3	main
soovitatav	doc_536541856909_item	2715520	et	4	main
illustreerida	doc_536541856909_item	2715521	et	3	main
tants	doc_536541856909_item	2715525	et	3	main
eestlastele	doc_536541856909_item	2715527	et	4	main
halvad	doc_536541856909_item	2715530	et	4	main
arvan	doc_536541856909_item	2715540	et	3	main
eesti	doc_536541856909_item	2715542	et	4	main
rahvast	doc_536541856909_item	2715543	et	4	main
võib	doc_536541856909_item	2715544	et	3	main
kindlasti	doc_536541856909_item	2715545	et	3	main
nimetada	doc_536541856909_item	2715546	et	3	main
eesti	doc_536541856909_item	2715554	et	4	main
juba	doc_536541856909_item	2715558	et	3	main
aastat	doc_536541856909_item	2715560	et	3	main
lauldes	doc_536541856909_item	2715578	et	3	main
kannell	doc_536541856909_item	2715614	et	4	main
see	doc_536541856909_item	2715621	et	3	main
laulurahvas	doc_536541856909_item	2715629	et	4	main
südames	doc_536541856909_item	2715638	et	3	main
ja	doc_536541856909_item	2715639	et	3	main
elab	doc_536541856909_item	2715641	et	3	main
ka	doc_536541856909_item	2715644	et	3	main
folkloori	doc_536541856909_item	2715649	et	4	main
kes	doc_536541856909_item	2715651	et	4	main
nendele	doc_536541856909_item	2715666	et	4	main
seotud	doc_536541856909_item	2715682	et	4	main
olen	doc_536541856909_item	2715684	et	3	main
kontserdisaalis	doc_536541856909_item	2715694	et	3	main
rahvale	doc_536541856909_item	2715721	et	3	main
hea	doc_536541856909_item	2715724	et	4	main
ta	doc_536541856909_item	2715726	et	4	main
ühineb	doc_536541856909_item	2715727	et	3	main
oli	doc_536541856909_item	2715734	et	3	main
ajal	doc_536541856909_item	2715737	et	4	main
möödub	doc_536541856909_item	2715739	et	3	main
näidetega	doc_536541856909_item	2715522	et	3	main
aitas	doc_536541856909_item	2715526	et	3	main
üle	doc_536541856909_item	2715528	et	3	main
elada	doc_536541856909_item	2715529	et	3	main
ka	doc_536541856909_item	2715535	et	3	main
ma	doc_536541856909_item	2715539	et	3	main
säilinud	doc_536541856909_item	2715551	et	4	main
kui	doc_536541856909_item	2715562	et	3	main
sõnu	doc_536541856909_item	2715573	et	4	main
nad	doc_536541856909_item	2715574	et	3	main
on	doc_536541856909_item	2715575	et	4	main
ka	doc_536541856909_item	2715576	et	3	main
liikusid	doc_536541856909_item	2715577	et	4	main
kiriku	doc_536541856909_item	2715579	et	3	main
laulmine	doc_536541856909_item	2715580	et	4	main
oli	doc_536541856909_item	2715581	et	3	main
ka	doc_536541856909_item	2715582	et	3	main
väga	doc_536541856909_item	2715583	et	3	main
populaarne	doc_536541856909_item	2715584	et	3	main
eestis	doc_536541856909_item	2715585	et	3	main
19	doc_536541856909_item	2715586	et	2	main
sajandil	doc_536541856909_item	2715587	et	3	main
lääne	doc_536541856909_item	2715588	et	4	main
eestis	doc_536541856909_item	2715589	et	3	main
oli	doc_536541856909_item	2715590	et	3	main
ka	doc_536541856909_item	2715591	et	3	main
populaarne	doc_536541856909_item	2715592	et	3	main
pulma	doc_536541856909_item	2715593	et	4	main
laul	doc_536541856909_item	2715594	et	4	main
need	doc_536541856909_item	2715595	et	3	main
laulud	doc_536541856909_item	2715596	et	3	main
laulsid	doc_536541856909_item	2715597	et	4	main
praaktiliselt	doc_536541856909_item	2715598	et	4	main
mehed	doc_536541856909_item	2715599	et	3	main
19	doc_536541856909_item	2715601	et	2	main
pulmades	doc_536541856909_item	2715600	et	3	main
20	doc_536541856909_item	2715602	et	2	main
sajandi	doc_536541856909_item	2715603	et	3	main
vahel	doc_536541856909_item	2715604	et	4	main
hakati	doc_536541856909_item	2715605	et	3	main
näiteks	doc_536541856909_item	2715611	et	4	main
lõtspill	doc_536541856909_item	2715612	et	4	main
siiamani	doc_536541856909_item	2715615	et	4	main
on	doc_536541856909_item	2715617	et	4	main
meile	doc_536541856909_item	2715623	et	4	main
eesti	doc_536541856909_item	2715626	et	4	main
raha	doc_536541856909_item	2715637	et	4	main
säilinud	doc_536541856909_item	2715647	et	4	main
inimestel	doc_536541856909_item	2715657	et	3	main
ei	doc_536541856909_item	2715658	et	4	main
ole	doc_536541856909_item	2715659	et	4	main
linna	doc_536541856909_item	2715660	et	4	main
korraldatakse	doc_536541856909_item	2715673	et	3	main
folkloori	doc_536541856909_item	2715674	et	4	main
festivalid	doc_536541856909_item	2715675	et	3	main
eestis	doc_536541856909_item	2715676	et	3	main
on	doc_536541856909_item	2715677	et	4	main
palju	doc_536541856909_item	2715678	et	4	main
on	doc_536541856909_item	2715681	et	4	main
ka	doc_536541856909_item	2715685	et	3	main
nad	doc_536541856909_item	2715700	et	3	main
ja	doc_536541856909_item	2715723	et	3	main
teeb	doc_536541856909_item	2715730	et	3	main
tugevamaks	doc_536541856909_item	2715731	et	4	main
nõukogude	doc_536541856909_item	2715736	et	3	main
rahvalaul	doc_536541856909_item	2715741	et	4	main
räägib	doc_536541856909_item	2715622	et	3	main
et	doc_536541856909_item	2715625	et	3	main
on	doc_536541856909_item	2715628	et	4	main
ta	doc_536541856909_item	2715640	et	4	main
ka	doc_536541856909_item	2715648	et	3	main
nendel	doc_536541856909_item	2715656	et	4	main
mõju	doc_536541856909_item	2715662	et	4	main
ja	doc_536541856909_item	2715663	et	3	main
see	doc_536541856909_item	2715664	et	3	main
aasta	doc_536541856909_item	2715672	et	4	main
korda	doc_536541856909_item	2715690	et	4	main
viimati	doc_536541856909_item	2715691	et	3	main
käisin	doc_536541856909_item	2715692	et	3	main
kuulsin	doc_536541856909_item	2715696	et	3	main
nii	doc_536541856909_item	2715702	et	3	main
regilaulu	doc_536541856909_item	2715703	et	4	main
kui	doc_536541856909_item	2715704	et	3	main
ka	doc_536541856909_item	2715705	et	3	main
kiriku	doc_536541856909_item	2715706	et	3	main
laulu	doc_536541856909_item	2715707	et	4	main
öelda	doc_536541856909_item	2715709	et	4	main
et	doc_536541856909_item	2715710	et	3	main
see	doc_536541856909_item	2715711	et	3	main
tahan	doc_536541856909_item	2715708	et	3	main
on	doc_536541856909_item	2715712	et	4	main
väärt	doc_536541856909_item	2715713	et	4	main
kuulamist	doc_536541856909_item	2715714	et	4	main
ma	doc_536541856909_item	2715715	et	3	main
arvan	doc_536541856909_item	2715716	et	3	main
et	doc_536541856909_item	2715717	et	3	main
rahvalaul	doc_536541856909_item	2715718	et	4	main
annab	doc_536541856909_item	2715719	et	3	main
eesti	doc_536541856909_item	2715720	et	4	main
enesekindlust	doc_536541856909_item	2715722	et	4	main
mõistust	doc_536541856909_item	2715725	et	4	main
see	doc_536541856909_item	2715733	et	3	main
aeg	doc_536541856909_item	2715738	et	3	main
aga	doc_536541856909_item	2715740	et	3	main
nagu	doc_536541856909_item	2715732	et	3	main
ei	doc_536541856909_item	2715742	et	4	main
kao	doc_536541856909_item	2715743	et	4	main
eesti	doc_536541856912_item	2716349	et	4	main
300	doc_536541856912_item	2716365	et	2	main
sõna	doc_536541856912_item	2716367	et	4	main
essee	doc_536541856912_item	2716368	et	4	main
arutlev	doc_536541856912_item	2716371	et	4	main
väiteid	doc_536541856912_item	2716381	et	4	main
soovitatav	doc_536541856912_item	2716383	et	4	main
illustreerida	doc_536541856912_item	2716384	et	3	main
näidetega	doc_536541856912_item	2716385	et	3	main
mängis	doc_536541856912_item	2716391	et	3	main
ja	doc_536541856912_item	2716394	et	3	main
mängib	doc_536541856912_item	2716396	et	3	main
väga	doc_536541856912_item	2716397	et	3	main
saa	doc_536541856912_item	2716408	et	4	main
saatnud	doc_536541856912_item	2716415	et	4	main
eestlasi	doc_536541856912_item	2716416	et	3	main
nii	doc_536541856912_item	2716417	et	3	main
heal	doc_536541856912_item	2716418	et	3	main
kui	doc_536541856912_item	2716419	et	3	main
halval	doc_536541856912_item	2716420	et	3	main
kultuuris	doc_536541856912_item	2716434	et	3	main
säilitades	doc_536541856912_item	2716435	et	3	main
rahvalaulu	doc_536541856912_item	2716436	et	4	main
eestlased	doc_536541856912_item	2716437	et	3	main
et	doc_536541856912_item	2716445	et	3	main
muistsed	doc_536541856912_item	2716446	et	3	main
pärandasid	doc_536541856912_item	2716448	et	4	main
keele	doc_536541856912_item	2716353	et	4	main
faktidele	doc_536541856912_item	2716380	et	3	main
seotud	doc_536541856912_item	2716403	et	4	main
lauluga	doc_536541856912_item	2716404	et	4	main
ja	doc_536541856912_item	2716405	et	3	main
me	doc_536541856912_item	2716406	et	4	main
ajal	doc_536541856912_item	2716421	et	4	main
mitte	doc_536541856912_item	2716427	et	3	main
sest	doc_536541856912_item	2716429	et	4	main
on	doc_536541856912_item	2716431	et	4	main
kui	doc_536541856912_item	2716351	et	3	main
teise	doc_536541856912_item	2716352	et	4	main
peab	doc_536541856912_item	2716369	et	4	main
tõenäoliselt	doc_536541856912_item	2716386	et	4	main
on	doc_536541856912_item	2716387	et	4	main
eestlased	doc_536541856912_item	2716388	et	3	main
mängib	doc_536541856912_item	2716392	et	3	main
suurt	doc_536541856912_item	2716398	et	3	main
on	doc_536541856912_item	2716402	et	4	main
ilma	doc_536541856912_item	2716410	et	4	main
rahvalauludeta	doc_536541856912_item	2716411	et	3	main
kujutama	doc_536541856912_item	2716412	et	3	main
laul	doc_536541856912_item	2716413	et	4	main
nad	doc_536541856912_item	2716423	et	3	main
tänu	doc_536541856912_item	2716443	et	4	main
põlvest	doc_536541856912_item	2716450	et	4	main
põlve	doc_536541856912_item	2716451	et	4	main
nende	doc_536541856912_item	2716457	et	4	main
elust	doc_536541856912_item	2716458	et	3	main
sest	doc_536541856912_item	2716459	et	4	main
zanreid	doc_536541856912_item	2716473	et	4	main
see	doc_536541856912_item	2716474	et	3	main
ja	doc_536541856912_item	2716480	et	3	main
see	doc_536541856912_item	2716516	et	3	main
traditsioon	doc_536541856912_item	2716517	et	3	main
ühineb	doc_536541856912_item	2716518	et	3	main
põlvkonde	doc_536541856912_item	2716519	et	3	main
laulavad	doc_536541856912_item	2716529	et	4	main
sama	doc_536541856912_item	2716532	et	4	main
siis	doc_536541856912_item	2716533	et	3	main
on	doc_536541856912_item	2716534	et	4	main
ja	doc_536541856912_item	2716540	et	3	main
19	doc_536541856912_item	2716556	et	2	main
aga	doc_536541856912_item	2716565	et	3	main
traditsioon	doc_536541856912_item	2716581	et	3	main
oli	doc_536541856912_item	2716585	et	3	main
poliitiline	doc_536541856912_item	2716587	et	3	main
see	doc_536541856912_item	2716600	et	3	main
ning	doc_536541856912_item	2716621	et	3	main
see	doc_536541856912_item	2716625	et	3	main
ärkamisaeg	doc_536541856912_item	2716627	et	3	main
aitas	doc_536541856912_item	2716629	et	3	main
nõukogude	doc_536541856912_item	2716631	et	3	main
see	doc_536541856912_item	2716633	et	3	main
ärkamisaeg	doc_536541856912_item	2716636	et	3	main
rahvalaulud	doc_536541856912_item	2716642	et	3	main
levinunud	doc_536541856912_item	2716655	et	4	main
eestlased	doc_536541856912_item	2716656	et	3	main
säilitasid	doc_536541856912_item	2716657	et	4	main
rahvalaulu	doc_536541856912_item	2716688	et	4	main
huvitatud	doc_536541856912_item	2716696	et	4	main
aastatel	doc_538656299206_item	2716712	et	4	main
iseloomustage	doc_538656299206_item	2716721	et	4	main
endast	doc_538656299206_item	2716730	et	4	main
kiri	doc_538656299206_item	2716732	et	3	main
kirja	doc_538656299206_item	2716739	et	4	main
on	doc_538656299206_item	2716742	et	4	main
vastu	doc_538656299206_item	2716743	et	3	main
venestust	doc_538656299206_item	2716744	et	4	main
1988	doc_538656299206_item	2716755	et	2	main
2	doc_538656299206_item	2716757	et	2	main
et	doc_538656299206_item	2716772	et	3	main
n	doc_538656299206_item	2716777	et	4	main
juba	doc_538656299206_item	2716778	et	3	main
et	doc_538656299206_item	2716797	et	3	main
keele	doc_536541856912_item	2716350	et	4	main
kirjutamine	doc_536541856912_item	2716355	et	4	main
essee	doc_536541856912_item	2716363	et	4	main
pikkus	doc_536541856912_item	2716364	et	4	main
laulurahvas	doc_536541856912_item	2716389	et	4	main
ei	doc_536541856912_item	2716407	et	4	main
on	doc_536541856912_item	2716414	et	4	main
aga	doc_536541856912_item	2716422	et	3	main
ei	doc_536541856912_item	2716424	et	4	main
unustanud	doc_536541856912_item	2716425	et	4	main
säilitavad	doc_536541856912_item	2716438	et	4	main
oma	doc_536541856912_item	2716439	et	4	main
fakte	doc_536541856912_item	2716456	et	3	main
saatis	doc_536541856912_item	2716462	et	3	main
rahvalaulu	doc_536541856912_item	2716472	et	4	main
üht	doc_536541856912_item	2716530	et	3	main
huvid	doc_536541856912_item	2716538	et	3	main
harjunud	doc_536541856912_item	2716546	et	4	main
end	doc_536541856912_item	2716547	et	4	main
ja	doc_536541856912_item	2716549	et	3	main
sajandil	doc_536541856912_item	2716557	et	3	main
laulupeod	doc_536541856912_item	2716564	et	4	main
see	doc_536541856912_item	2716568	et	3	main
sest	doc_536541856912_item	2716570	et	4	main
spetsiaalne	doc_536541856912_item	2716571	et	3	main
loa	doc_536541856912_item	2716572	et	4	main
oli	doc_536541856912_item	2716573	et	3	main
ja	doc_536541856912_item	2716580	et	3	main
niisugustel	doc_536541856912_item	2716583	et	3	main
kohas	doc_536541856912_item	2716592	et	4	main
laulu	doc_536541856912_item	2716595	et	4	main
võistlema	doc_536541856912_item	2716624	et	3	main
said	doc_536541856912_item	2716639	et	4	main
tol	doc_536541856912_item	2716640	et	3	main
selle	doc_536541856912_item	2716647	et	4	main
tänapäeval	doc_536541856912_item	2716650	et	3	main
on	doc_536541856912_item	2716671	et	4	main
aga	doc_536541856912_item	2716674	et	3	main
ansambleid	doc_536541856912_item	2716689	et	3	main
põlvkond	doc_536541856912_item	2716694	et	3	main
1990	doc_538656299206_item	2716711	et	2	main
kultuurielu	doc_538656299206_item	2716726	et	4	main
3	doc_538656299206_item	2716727	et	2	main
mida	doc_538656299206_item	2716728	et	4	main
kiri	doc_538656299206_item	2716735	et	3	main
kirjutasid	doc_538656299206_item	2716738	et	4	main
et	doc_538656299206_item	2716740	et	3	main
rohkem	doc_538656299206_item	2716747	et	4	main
kui	doc_538656299206_item	2716748	et	3	main
1000	doc_538656299206_item	2716749	et	2	main
inimesi	doc_538656299206_item	2716750	et	4	main
see	doc_538656299206_item	2716751	et	3	main
kiri	doc_538656299206_item	2716752	et	3	main
maad	doc_538656299206_item	2716775	et	4	main
35000	doc_538656299206_item	2716784	et	2	main
uude	doc_538656299206_item	2716786	et	3	main
kohades	doc_538656299206_item	2716787	et	4	main
nad	doc_538656299206_item	2716788	et	3	main
tean	doc_538656299206_item	2716796	et	3	main
floridas	doc_538656299206_item	2716805	et	4	main
pärast	doc_538656299206_item	2716814	et	4	main
elusse	doc_538656299206_item	2716818	et	3	main
20	doc_538656299206_item	2716820	et	2	main
augustil	doc_538656299206_item	2716821	et	3	main
taastati	doc_538656299206_item	2716824	et	4	main
sel	doc_538656299206_item	2716826	et	3	main
aastal	doc_538656299206_item	2716827	et	3	main
kuritegumisi	doc_538656299206_item	2716844	et	4	main
1990	doc_538656299206_item	2716845	et	2	main
essee	doc_536541856912_item	2716348	et	4	main
test	doc_536541856912_item	2716354	et	3	main
kirjutage	doc_536541856912_item	2716356	et	3	main
essee	doc_536541856912_item	2716357	et	4	main
mis	doc_536541856912_item	2716359	et	4	main
teeb	doc_536541856912_item	2716360	et	3	main
teemal	doc_536541856912_item	2716358	et	3	main
eestlastest	doc_536541856912_item	2716361	et	4	main
laulurahva	doc_536541856912_item	2716362	et	3	main
350	doc_536541856912_item	2716366	et	2	main
olema	doc_536541856912_item	2716370	et	4	main
analüüsiv	doc_536541856912_item	2716372	et	4	main
ja	doc_536541856912_item	2716373	et	3	main
üldistav	doc_536541856912_item	2716374	et	4	main
tuginema	doc_536541856912_item	2716375	et	3	main
loengus	doc_536541856912_item	2716376	et	3	main
ja	doc_536541856912_item	2716377	et	3	main
lugemistekstis	doc_536541856912_item	2716378	et	3	main
esitatud	doc_536541856912_item	2716379	et	4	main
on	doc_536541856912_item	2716382	et	4	main
rahvalaul	doc_536541856912_item	2716390	et	4	main
praegu	doc_536541856912_item	2716393	et	3	main
tulevikus	doc_536541856912_item	2716395	et	4	main
rolli	doc_536541856912_item	2716399	et	4	main
eestlaste	doc_536541856912_item	2716400	et	4	main
ajalugu	doc_536541856912_item	2716401	et	4	main
selle	doc_536541856912_item	2716409	et	4	main
selle	doc_536541856912_item	2716426	et	4	main
kunagi	doc_536541856912_item	2716428	et	3	main
see	doc_536541856912_item	2716430	et	3	main
kultuuri	doc_536541856912_item	2716440	et	4	main
ja	doc_536541856912_item	2716441	et	3	main
sellele	doc_536541856912_item	2716444	et	4	main
eestlased	doc_536541856912_item	2716447	et	3	main
just	doc_536541856912_item	2716460	et	3	main
hauani	doc_536541856912_item	2716465	et	3	main
väga	doc_536541856912_item	2716469	et	3	main
mida	doc_536541856912_item	2716475	et	4	main
lauldi	doc_536541856912_item	2716476	et	3	main
kellega	doc_536541856912_item	2716481	et	3	main
ja	doc_536541856912_item	2716484	et	3	main
mida	doc_536541856912_item	2716485	et	4	main
ta	doc_536541856912_item	2716486	et	4	main
tegi	doc_536541856912_item	2716487	et	4	main
laulma	doc_536541856912_item	2716488	et	3	main
laulu	doc_536541856912_item	2716489	et	4	main
oli	doc_536541856912_item	2716490	et	3	main
traditsioon	doc_536541856912_item	2716491	et	3	main
lauldes	doc_536541856912_item	2716492	et	3	main
võib	doc_536541856912_item	2716493	et	3	main
olla	doc_536541856912_item	2716494	et	3	main
kergem	doc_536541856912_item	2716495	et	4	main
oma	doc_536541856912_item	2716496	et	4	main
tööd	doc_536541856912_item	2716497	et	4	main
teha	doc_536541856912_item	2716498	et	3	main
ja	doc_536541856912_item	2716499	et	3	main
kindlasti	doc_536541856912_item	2716500	et	3	main
lõbusam	doc_536541856912_item	2716501	et	4	main
seepärast	doc_536541856912_item	2716502	et	3	main
mehed	doc_536541856912_item	2716503	et	3	main
naised	doc_536541856912_item	2716504	et	3	main
ja	doc_536541856912_item	2716505	et	3	main
lapsed	doc_536541856912_item	2716506	et	3	main
laulsid	doc_536541856912_item	2716507	et	4	main
igas	doc_536541856912_item	2716508	et	3	main
situatsioonis	doc_536541856912_item	2716509	et	3	main
käsitöö	doc_536541856912_item	2716510	et	4	main
tehes	doc_536541856912_item	2716511	et	3	main
põllul	doc_536541856912_item	2716512	et	3	main
töötades	doc_536541856912_item	2716513	et	3	main
ja	doc_536541856912_item	2716514	et	3	main
pidudes	doc_536541856912_item	2716515	et	4	main
suur	doc_536541856912_item	2716432	et	3	main
osa	doc_536541856912_item	2716433	et	4	main
ajaloo	doc_536541856912_item	2716442	et	4	main
me	doc_536541856912_item	2716452	et	4	main
nüüd	doc_536541856912_item	2716453	et	4	main
teame	doc_536541856912_item	2716454	et	3	main
palju	doc_536541856912_item	2716455	et	4	main
laul	doc_536541856912_item	2716461	et	4	main
hällist	doc_536541856912_item	2716464	et	4	main
vanal	doc_536541856912_item	2716466	et	3	main
palju	doc_536541856912_item	2716470	et	4	main
erinevaid	doc_536541856912_item	2716471	et	4	main
oli	doc_536541856912_item	2716482	et	3	main
ja	doc_536541856912_item	2716520	et	3	main
selles	doc_536541856912_item	2716521	et	4	main
neil	doc_536541856912_item	2716535	et	4	main
juba	doc_536541856912_item	2716536	et	3	main
abil	doc_536541856912_item	2716543	et	4	main
rahvas	doc_536541856912_item	2716544	et	4	main
väljendama	doc_536541856912_item	2716548	et	3	main
näidata	doc_536541856912_item	2716550	et	4	main
oma	doc_536541856912_item	2716551	et	4	main
just	doc_536541856912_item	2716558	et	3	main
ajal	doc_536541856912_item	2716560	et	4	main
organiseerima	doc_536541856912_item	2716562	et	3	main
vaja	doc_536541856912_item	2716574	et	4	main
aga	doc_536541856912_item	2716575	et	3	main
rahvas	doc_536541856912_item	2716576	et	4	main
ei	doc_536541856912_item	2716577	et	4	main
alla	doc_536541856912_item	2716578	et	3	main
andnud	doc_536541856912_item	2716579	et	4	main
roll	doc_536541856912_item	2716588	et	3	main
kogunes	doc_536541856912_item	2716590	et	3	main
ja	doc_536541856912_item	2716593	et	3	main
mis	doc_536541856912_item	2716596	et	4	main
äratasid	doc_536541856912_item	2716597	et	4	main
natsionaalsed	doc_536541856912_item	2716598	et	3	main
tundeid	doc_536541856912_item	2716599	et	3	main
mängis	doc_536541856912_item	2716601	et	3	main
pearolli	doc_536541856912_item	2716602	et	4	main
peavad	doc_536541856912_item	2716623	et	4	main
rahvalaul	doc_536541856912_item	2716628	et	4	main
ka	doc_536541856912_item	2716630	et	3	main
teine	doc_536541856912_item	2716635	et	3	main
ajal	doc_536541856912_item	2716641	et	4	main
kasutasid	doc_536541856912_item	2716646	et	4	main
motiive	doc_536541856912_item	2716648	et	3	main
zanr	doc_536541856912_item	2716652	et	4	main
on	doc_536541856912_item	2716653	et	4	main
väga	doc_536541856912_item	2716654	et	3	main
lauluga	doc_536541856912_item	2716673	et	4	main
ainult	doc_536541856912_item	2716676	et	4	main
minevik	doc_536541856912_item	2716677	et	3	main
vaid	doc_536541856912_item	2716678	et	3	main
praegune	doc_536541856912_item	2716679	et	3	main
elu	doc_536541856912_item	2716680	et	4	main
ning	doc_536541856912_item	2716681	et	3	main
kindlasti	doc_536541856912_item	2716682	et	3	main
tulevik	doc_536541856912_item	2716683	et	3	main
paljud	doc_536541856912_item	2716684	et	3	main
noored	doc_536541856912_item	2716685	et	3	main
loovad	doc_536541856912_item	2716686	et	4	main
tänapäeval	doc_536541856912_item	2716687	et	3	main
et	doc_536541856912_item	2716692	et	3	main
eesti	doc_538656299206_item	2716709	et	4	main
taasiseseisvumise	doc_538656299206_item	2716710	et	3	main
väljaspool	doc_538656299206_item	2716715	et	3	main
mis	doc_538656299206_item	2716717	et	4	main
lühidalt	doc_538656299206_item	2716722	et	4	main
ka	doc_538656299206_item	2716723	et	3	main
kujutas	doc_538656299206_item	2716729	et	3	main
40	doc_538656299206_item	2716731	et	2	main
40	doc_538656299206_item	2716736	et	2	main
lootsid	doc_538656299206_item	2716771	et	4	main
nad	doc_538656299206_item	2716773	et	3	main
saavad	doc_538656299206_item	2716774	et	4	main
aastal	doc_538656299206_item	2716780	et	3	main
isegi	doc_538656299206_item	2716793	et	4	main
tänapäeval	doc_538656299206_item	2716794	et	3	main
ma	doc_538656299206_item	2716795	et	3	main
new	doc_538656299206_item	2716799	et	4	main
koolitused	doc_538656299206_item	2716802	et	4	main
rahvalaule	doc_536541856912_item	2716449	et	4	main
eestlasi	doc_536541856912_item	2716463	et	3	main
ajal	doc_536541856912_item	2716467	et	4	main
oli	doc_536541856912_item	2716468	et	3	main
sõltus	doc_536541856912_item	2716477	et	4	main
sellest	doc_536541856912_item	2716478	et	4	main
kus	doc_536541856912_item	2716479	et	3	main
inimene	doc_536541856912_item	2716483	et	3	main
on	doc_536541856912_item	2716522	et	4	main
selle	doc_536541856912_item	2716523	et	4	main
sotsiaalne	doc_536541856912_item	2716524	et	3	main
roll	doc_536541856912_item	2716525	et	3	main
sest	doc_536541856912_item	2716526	et	4	main
kui	doc_536541856912_item	2716527	et	3	main
inimesed	doc_536541856912_item	2716528	et	3	main
ühised	doc_536541856912_item	2716537	et	3	main
laulu	doc_536541856912_item	2716542	et	4	main
on	doc_536541856912_item	2716545	et	4	main
positsiooni	doc_536541856912_item	2716552	et	4	main
nagu	doc_536541856912_item	2716553	et	3	main
see	doc_536541856912_item	2716554	et	3	main
hakati	doc_536541856912_item	2716561	et	3	main
esimesed	doc_536541856912_item	2716563	et	3	main
oli	doc_536541856912_item	2716567	et	3	main
raske	doc_536541856912_item	2716569	et	4	main
jätkus	doc_536541856912_item	2716582	et	4	main
peodel	doc_536541856912_item	2716584	et	3	main
juba	doc_536541856912_item	2716586	et	3	main
rahvas	doc_536541856912_item	2716589	et	4	main
oli	doc_536541856912_item	2716626	et	3	main
ajal	doc_536541856912_item	2716632	et	4	main
oli	doc_536541856912_item	2716634	et	3	main
veel	doc_536541856912_item	2716637	et	4	main
populaarsemaks	doc_536541856912_item	2716638	et	4	main
loomingus	doc_536541856912_item	2716644	et	3	main
näitab	doc_536541856912_item	2716691	et	3	main
noor	doc_536541856912_item	2716693	et	3	main
selles	doc_536541856912_item	2716697	et	4	main
eestlased	doc_536541856912_item	2716699	et	3	main
millised	doc_538656299206_item	2716704	et	3	main
kultuurilis-poliitilised	doc_538656299206_item	2716705	et	3	main
tegurid	doc_538656299206_item	2716706	et	3	main
tegid	doc_538656299206_item	2716707	et	4	main
võimalikuks	doc_538656299206_item	2716708	et	3	main
eestlased	doc_538656299206_item	2716714	et	3	main
ja	doc_536541856912_item	2716531	et	3	main
mõtted	doc_536541856912_item	2716539	et	3	main
tunded	doc_536541856912_item	2716541	et	3	main
juhtus	doc_536541856912_item	2716555	et	3	main
tol	doc_536541856912_item	2716559	et	3	main
tsaari-venemaal	doc_536541856912_item	2716566	et	4	main
ühes	doc_536541856912_item	2716591	et	4	main
kuulas	doc_536541856912_item	2716594	et	3	main
eestimaa	doc_536541856912_item	2716603	et	4	main
iseseivuse	doc_536541856912_item	2716604	et	4	main
saamiseks	doc_536541856912_item	2716605	et	4	main
tänu	doc_536541856912_item	2716606	et	4	main
rahvalaulule	doc_536541856912_item	2716607	et	3	main
inimesed	doc_536541856912_item	2716608	et	3	main
mõistsid	doc_536541856912_item	2716609	et	4	main
et	doc_536541856912_item	2716610	et	3	main
kõik	doc_536541856912_item	2716611	et	4	main
nad	doc_536541856912_item	2716612	et	3	main
on	doc_536541856912_item	2716613	et	4	main
eestlased	doc_536541856912_item	2716614	et	3	main
neil	doc_536541856912_item	2716615	et	4	main
on	doc_536541856912_item	2716616	et	4	main
ühine	doc_536541856912_item	2716617	et	4	main
kultuur	doc_536541856912_item	2716618	et	3	main
ja	doc_536541856912_item	2716619	et	3	main
ajalugu	doc_536541856912_item	2716620	et	4	main
nad	doc_536541856912_item	2716622	et	3	main
oma	doc_536541856912_item	2716643	et	4	main
heliloojad	doc_536541856912_item	2716645	et	3	main
ja	doc_536541856912_item	2716649	et	3	main
see	doc_536541856912_item	2716651	et	3	main
oma	doc_536541856912_item	2716658	et	4	main
rahvalaulutraditsiooni	doc_536541856912_item	2716659	et	4	main
ja	doc_536541856912_item	2716660	et	3	main
selle	doc_536541856912_item	2716661	et	4	main
eest	doc_536541856912_item	2716662	et	4	main
neid	doc_536541856912_item	2716663	et	4	main
peab	doc_536541856912_item	2716664	et	4	main
laulurahvaks	doc_536541856912_item	2716665	et	3	main
kutsuma	doc_536541856912_item	2716666	et	3	main
paljud	doc_536541856912_item	2716667	et	3	main
sündmused	doc_536541856912_item	2716668	et	3	main
eesti	doc_536541856912_item	2716669	et	4	main
ajaloos	doc_536541856912_item	2716670	et	4	main
seotud	doc_536541856912_item	2716672	et	4	main
mitte	doc_536541856912_item	2716675	et	3	main
see	doc_536541856912_item	2716690	et	3	main
on	doc_536541856912_item	2716695	et	4	main
et	doc_536541856912_item	2716698	et	3	main
jääks	doc_536541856912_item	2716700	et	4	main
laulurahvaks	doc_536541856912_item	2716701	et	3	main
kontrolltöö	doc_538656299206_item	2716702	et	4	main
1	doc_538656299206_item	2716703	et	2	main
2	doc_538656299206_item	2716713	et	2	main
kodumaad	doc_538656299206_item	2716716	et	4	main
põhjustel	doc_538656299206_item	2716718	et	3	main
ja	doc_538656299206_item	2716719	et	3	main
kus	doc_538656299206_item	2716720	et	3	main
40	doc_538656299206_item	2716734	et	2	main
allkirja	doc_538656299206_item	2716745	et	4	main
pandi	doc_538656299206_item	2716746	et	4	main
kirjutatud	doc_538656299206_item	2716754	et	4	main
nad	doc_538656299206_item	2716770	et	3	main
1980	doc_538656299206_item	2716779	et	2	main
kolis	doc_538656299206_item	2716782	et	4	main
eestlasi	doc_538656299206_item	2716785	et	3	main
asusid	doc_538656299206_item	2716789	et	4	main
uued	doc_538656299206_item	2716790	et	3	main
külad	doc_538656299206_item	2716791	et	3	main
koolid	doc_538656299206_item	2716792	et	3	main
eesti	doc_538656299206_item	2716801	et	4	main
lihtsalt	doc_538656299206_item	2716811	et	4	main
ka	doc_538656299206_item	2716812	et	3	main
1991	doc_538656299206_item	2716822	et	2	main
sain	doc_538656299206_item	2716829	et	3	main
tuli	doc_538656299206_item	2716832	et	4	main
78	doc_538656299206_item	2716851	et	2	main
häletas	doc_538656299206_item	2716852	et	4	main
majandusreformid	doc_538656299206_item	2716858	et	3	main
eesti	doc_538656299206_item	2716861	et	4	main
ülekaalukas	doc_538656299206_item	2716863	et	4	main
mõjus	doc_538656299206_item	2716867	et	4	main
kett	doc_538656299206_item	2716870	et	4	main
vaikne	doc_538656299206_item	2716874	et	3	main
osales	doc_538656299206_item	2716879	et	3	main
see	doc_538656299206_item	2716882	et	3	main
vilnus	doc_538656299206_item	2716886	et	4	main
pange	doc_541512374224_item	2716889	et	4	main
sulgudes	doc_541512374224_item	2716890	et	4	main
piret	doc_541512374224_item	2716895	et	4	main
toomet	doc_541512374224_item	2716896	et	4	main
nn	doc_538656299206_item	2716724	et	4	main
väliseesti	doc_538656299206_item	2716725	et	4	main
1	doc_538656299206_item	2716733	et	2	main
haritlasi	doc_538656299206_item	2716737	et	3	main
nad	doc_538656299206_item	2716741	et	3	main
oli	doc_538656299206_item	2716753	et	3	main
aastal	doc_538656299206_item	2716756	et	3	main
20	doc_538656299206_item	2716758	et	2	main
sajandis	doc_538656299206_item	2716759	et	3	main
palju	doc_538656299206_item	2716760	et	4	main
eestlasi	doc_538656299206_item	2716761	et	3	main
kolis	doc_538656299206_item	2716762	et	4	main
eestist	doc_538656299206_item	2716763	et	3	main
paljud	doc_538656299206_item	2716764	et	3	main
sõitsid	doc_538656299206_item	2716765	et	4	main
venemaale	doc_538656299206_item	2716766	et	4	main
ja	doc_538656299206_item	2716767	et	3	main
ameerikasse	doc_538656299206_item	2716768	et	4	main
sest	doc_538656299206_item	2716769	et	4	main
endale	doc_538656299206_item	2716776	et	4	main
skandinaaviass	doc_538656299206_item	2716781	et	3	main
umbes	doc_538656299206_item	2716783	et	4	main
on	doc_538656299206_item	2716798	et	4	main
paremasse	doc_538656299206_item	2716817	et	4	main
3	doc_538656299206_item	2716819	et	2	main
yorgis	doc_538656299206_item	2716800	et	4	main
ja	doc_538656299206_item	2716803	et	3	main
ka	doc_538656299206_item	2716804	et	3	main
lahkusid	doc_538656299206_item	2716807	et	4	main
ka	doc_538656299206_item	2716808	et	3	main
repressioonide	doc_538656299206_item	2716809	et	3	main
pärast	doc_538656299206_item	2716810	et	4	main
et	doc_538656299206_item	2716815	et	3	main
ja	doc_538656299206_item	2716831	et	3	main
täita	doc_538656299206_item	2716843	et	4	main
poolt	doc_538656299206_item	2716854	et	4	main
märtsis	doc_538656299206_item	2716855	et	3	main
1990	doc_538656299206_item	2716856	et	2	main
valiti	doc_538656299206_item	2716860	et	3	main
kongress	doc_538656299206_item	2716862	et	3	main
võit	doc_538656299206_item	2716864	et	3	main
balti	doc_538656299206_item	2716869	et	3	main
mis	doc_538656299206_item	2716872	et	4	main
demonstratsioon	doc_538656299206_item	2716875	et	3	main
oli	doc_538656299206_item	2716884	et	3	main
i	doc_541512374224_item	2716888	et	4	main
õigesse	doc_541512374224_item	2716893	et	3	main
nüüd	doc_541512374224_item	2716922	et	4	main
nädalat	doc_541512374224_item	2716926	et	3	main
pireti	doc_541512374224_item	2716934	et	4	main
kinnitusel	doc_541512374224_item	2716935	et	4	main
tundis	doc_541512374224_item	2716936	et	3	main
üsna	doc_541512374224_item	2716945	et	3	main
üllatuma	doc_541512374224_item	2716946	et	3	main
üllatunud	doc_541512374224_item	2716947	et	4	main
kui	doc_541512374224_item	2716948	et	3	main
audiga	doc_541512374224_item	2716955	et	3	main
ega	doc_541512374224_item	2716968	et	3	main
õppeaasta	doc_541512374224_item	2716979	et	4	main
alatud	doc_541512374224_item	2716988	et	4	main
siin	doc_541512374224_item	2716996	et	4	main
on	doc_541512374224_item	2717002	et	4	main
kartul	doc_541512374224_item	2717003	et	3	main
kuidagi	doc_541512374224_item	2717015	et	3	main
mõnd	doc_541512374224_item	2717029	et	3	main
kool	doc_541512374224_item	2717031	et	4	main
siiski	doc_541512374224_item	2717033	et	4	main
vene	doc_541512374224_item	2717041	et	4	main
raamatud	doc_541512374224_item	2717059	et	4	main
varsti	doc_541512374224_item	2717061	et	3	main
saadavad	doc_541512374224_item	2717063	et	4	main
külapood	doc_541512374224_item	2717098	et	3	main
ei	doc_541512374224_item	2717105	et	4	main
müüdagi	doc_541512374224_item	2717106	et	3	main
naerab	doc_541512374224_item	2717107	et	3	main
sõnad	doc_541512374224_item	2717122	et	4	main
kasutades	doc_541512374224_item	2717126	et	3	main
naeratus	doc_541512374224_item	2717129	et	4	main
naiselikum	doc_541512374224_item	2717132	et	4	main
mehelikum	doc_541512374224_item	2717135	et	4	main
kaunim	doc_541512374224_item	2717137	et	4	main
naeratus	doc_541512374224_item	2717138	et	4	main
teeb	doc_541512374224_item	2717139	et	3	main
naisi	doc_541512374224_item	2717140	et	3	main
soovimatu	doc_541512374224_item	2717158	et	4	main
tagajärg	doc_541512374224_item	2717159	et	3	main
paras	doc_541512374224_item	2717160	et	3	main
tegutsema	doc_541512374224_item	2717165	et	3	main
4	doc_541512374224_item	2717172	et	2	main
maagiline	doc_541512374224_item	2717201	et	4	main
aparaat	doc_541512374224_item	2717202	et	3	main
ja	doc_541512374224_item	2717222	et	3	main
telesaade	doc_541512374224_item	2717239	et	4	main
segab	doc_541512374224_item	2717249	et	3	main
ja	doc_541512374224_item	2717252	et	3	main
pahandab	doc_541512374224_item	2717254	et	3	main
telesaade	doc_541512374224_item	2717256	et	4	main
vaatamise	doc_541512374224_item	2717257	et	4	main
pange	doc_541512374224_item	2717260	et	4	main
sulgudes	doc_541512374224_item	2717261	et	4	main
1	doc_541512374224_item	2717266	et	2	main
lugu	doc_541512374224_item	2717270	et	4	main
oma	doc_541512374224_item	2717271	et	4	main
3	doc_541512374224_item	2717289	et	2	main
et	doc_541512374224_item	2717292	et	3	main
huvitud	doc_541512374224_item	2717294	et	4	main
paljud	doc_538656299206_item	2716806	et	3	main
selle	doc_538656299206_item	2716813	et	4	main
ususid	doc_538656299206_item	2716816	et	4	main
presidentiks	doc_538656299206_item	2716830	et	4	main
tallinna	doc_538656299206_item	2716833	et	4	main
ja	doc_538656299206_item	2716834	et	3	main
kirjutas	doc_538656299206_item	2716835	et	3	main
alla	doc_538656299206_item	2716836	et	3	main
lepingut	doc_538656299206_item	2716837	et	3	main
et	doc_538656299206_item	2716838	et	3	main
kutsutakse	doc_538656299206_item	2716839	et	3	main
vene	doc_538656299206_item	2716840	et	4	main
sõdureid	doc_538656299206_item	2716841	et	3	main
mitte	doc_538656299206_item	2716842	et	3	main
iseseisvuse	doc_538656299206_item	2716853	et	4	main
240290	doc_538656299206_item	2716859	et	2	main
ka	doc_538656299206_item	2716868	et	3	main
venestuse	doc_538656299206_item	2716876	et	4	main
milles	doc_538656299206_item	2716878	et	3	main
kett	doc_538656299206_item	2716883	et	4	main
olevad	doc_541512374224_item	2716891	et	4	main
nende	doc_541512374224_item	2716930	et	4	main
siberisse	doc_541512374224_item	2716938	et	4	main
jõudma	doc_541512374224_item	2716939	et	3	main
jõuda	doc_541512374224_item	2716940	et	3	main
noor	doc_541512374224_item	2716972	et	3	main
algust	doc_541512374224_item	2716980	et	4	main
koht	doc_541512374224_item	2716981	et	3	main
polnud	doc_541512374224_item	2716984	et	3	main
on	doc_541512374224_item	2716995	et	4	main
siinsed	doc_541512374224_item	2717012	et	3	main
teistmoodi	doc_541512374224_item	2717016	et	3	main
mahlakas	doc_541512374224_item	2717019	et	4	main
mõni	doc_541512374224_item	2717028	et	3	main
kool	doc_541512374224_item	2717035	et	4	main
üle	doc_541512374224_item	2717046	et	3	main
raamatutest	doc_541512374224_item	2717060	et	4	main
saatma	doc_541512374224_item	2717062	et	3	main
talve	doc_541512374224_item	2717068	et	4	main
kui	doc_541512374224_item	2717095	et	3	main
talveks	doc_541512374224_item	2717108	et	4	main
valmistuma	doc_541512374224_item	2717109	et	3	main
valmistub	doc_541512374224_item	2717110	et	3	main
piret	doc_541512374224_item	2717111	et	4	main
slõhtuleht	doc_541512374224_item	2717115	et	4	main
ja	doc_541512374224_item	2717125	et	3	main
naiselikum	doc_541512374224_item	2717141	et	4	main
ja	doc_541512374224_item	2717142	et	3	main
mehi	doc_541512374224_item	2717143	et	3	main
kaunim	doc_541512374224_item	2717146	et	4	main
paneb	doc_541512374224_item	2717163	et	3	main
võib	doc_541512374224_item	2717168	et	3	main
elama	doc_541512374224_item	2717207	et	3	main
ja	doc_541512374224_item	2717208	et	3	main
hingama	doc_541512374224_item	2717209	et	3	main
telefon	doc_541512374224_item	2717210	et	3	main
on	doc_541512374224_item	2717211	et	4	main
tänapäeval	doc_541512374224_item	2717212	et	3	main
nii	doc_541512374224_item	2717213	et	3	main
saab	doc_541512374224_item	2717219	et	3	main
eestis	doc_538656299206_item	2716823	et	3	main
iseseisvus	doc_538656299206_item	2716825	et	4	main
jeltsin	doc_538656299206_item	2716828	et	4	main
olid	doc_538656299206_item	2716857	et	4	main
vastu	doc_538656299206_item	2716877	et	3	main
2000000	doc_538656299206_item	2716880	et	2	main
eksamitöö	doc_541512374224_item	2716887	et	4	main
vormi	doc_541512374224_item	2716894	et	4	main
on	doc_541512374224_item	2716897	et	4	main
ettevõtlik	doc_541512374224_item	2716898	et	3	main
naine	doc_541512374224_item	2716899	et	3	main
suvel	doc_541512374224_item	2716900	et	3	main
nägema	doc_541512374224_item	2716901	et	3	main
nägi	doc_541512374224_item	2716902	et	3	main
ta	doc_541512374224_item	2716903	et	4	main
ajalehes	doc_541512374224_item	2716904	et	3	main
kuulutus	doc_541512374224_item	2716905	et	4	main
kuulutuse	doc_541512374224_item	2716906	et	4	main
et	doc_541512374224_item	2716907	et	3	main
siberisse	doc_541512374224_item	2716908	et	4	main
ülem-suetuki	doc_541512374224_item	2716909	et	4	main
küla	doc_541512374224_item	2716910	et	4	main
külas	doc_541512374224_item	2716911	et	3	main
otsitakse	doc_541512374224_item	2716912	et	3	main
eesti	doc_541512374224_item	2716913	et	4	main
keele	doc_541512374224_item	2716914	et	4	main
õpetajat	doc_541512374224_item	2716915	et	4	main
piret	doc_541512374224_item	2716916	et	4	main
võitis	doc_541512374224_item	2716917	et	3	main
konkurss	doc_541512374224_item	2716918	et	3	main
konkurssi	doc_541512374224_item	2716919	et	4	main
ja	doc_541512374224_item	2716920	et	3	main
emakeelt	doc_541512374224_item	2716931	et	4	main
õpetama	doc_541512374224_item	2716932	et	3	main
õpetab	doc_541512374224_item	2716933	et	3	main
et	doc_541512374224_item	2716941	et	3	main
on	doc_541512374224_item	2716942	et	4	main
oodatud	doc_541512374224_item	2716943	et	4	main
olin	doc_541512374224_item	2716944	et	3	main
korraliku	doc_541512374224_item	2716954	et	3	main
kasva	doc_541512374224_item	2716969	et	4	main
tahtmine	doc_541512374224_item	2716974	et	4	main
kohale	doc_541512374224_item	2716982	et	4	main
küla	doc_541512374224_item	2716990	et	4	main
võtma	doc_541512374224_item	2716991	et	3	main
võttis	doc_541512374224_item	2716992	et	3	main
kartuleid	doc_541512374224_item	2716993	et	3	main
kõige	doc_541512374224_item	2716998	et	4	main
ettevõtmine	doc_541512374224_item	2717000	et	3	main
tänaseks	doc_541512374224_item	2717001	et	4	main
hooga	doc_541512374224_item	2717011	et	3	main
räägivad	doc_541512374224_item	2717014	et	3	main
mõnusalt	doc_541512374224_item	2717020	et	4	main
mahlakalt	doc_541512374224_item	2717021	et	4	main
vene	doc_541512374224_item	2717023	et	4	main
aktsenti	doc_541512374224_item	2717025	et	4	main
ja	doc_541512374224_item	2717036	et	3	main
oli	doc_538656299206_item	2716846	et	3	main
nsv	doc_538656299206_item	2716847	et	4	main
liidu	doc_538656299206_item	2716848	et	3	main
referendum	doc_538656299206_item	2716849	et	3	main
ja	doc_538656299206_item	2716850	et	3	main
iseseisvuse	doc_538656299206_item	2716865	et	4	main
toetajal	doc_538656299206_item	2716866	et	4	main
230888a	doc_538656299206_item	2716871	et	4	main
oli	doc_538656299206_item	2716873	et	3	main
inimest	doc_538656299206_item	2716881	et	3	main
tallinn	doc_538656299206_item	2716885	et	4	main
sõnad	doc_541512374224_item	2716892	et	4	main
on	doc_541512374224_item	2716921	et	4	main
juba	doc_541512374224_item	2716923	et	3	main
üle	doc_541512374224_item	2716924	et	3	main
väikestele	doc_541512374224_item	2716927	et	4	main
eestlastele	doc_541512374224_item	2716928	et	4	main
need	doc_541512374224_item	2716929	et	3	main
ta	doc_541512374224_item	2716937	et	4	main
mulle	doc_541512374224_item	2716949	et	4	main
rohi	doc_541512374224_item	2716970	et	4	main
kui	doc_541512374224_item	2716971	et	3	main
tahtmise	doc_541512374224_item	2716975	et	4	main
piret	doc_541512374224_item	2716977	et	4	main
kogu	doc_541512374224_item	2716989	et	4	main
sügisel	doc_541512374224_item	2716997	et	3	main
tähtis	doc_541512374224_item	2716999	et	4	main
õppimine	doc_541512374224_item	2717007	et	4	main
käib	doc_541512374224_item	2717008	et	3	main
täie	doc_541512374224_item	2717009	et	3	main
hoog	doc_541512374224_item	2717010	et	3	main
eestlased	doc_541512374224_item	2717013	et	3	main
mõnus	doc_541512374224_item	2717017	et	4	main
nädal	doc_541512374224_item	2716925	et	3	main
tulema	doc_541512374224_item	2716950	et	4	main
tuli	doc_541512374224_item	2716951	et	4	main
vastu	doc_541512374224_item	2716952	et	3	main
korralik	doc_541512374224_item	2716953	et	3	main
mulle	doc_541512374224_item	2716956	et	4	main
maaliti	doc_541512374224_item	2716957	et	3	main
siber	doc_541512374224_item	2716958	et	4	main
selline	doc_541512374224_item	2716960	et	4	main
pilt	doc_541512374224_item	2716961	et	3	main
siberist	doc_541512374224_item	2716959	et	4	main
et	doc_541512374224_item	2716962	et	3	main
seal	doc_541512374224_item	2716963	et	4	main
ei	doc_541512374224_item	2716964	et	4	main
lendama	doc_541512374224_item	2716965	et	3	main
lenda	doc_541512374224_item	2716966	et	4	main
lind	doc_541512374224_item	2716967	et	3	main
ja	doc_541512374224_item	2716973	et	3	main
täis	doc_541512374224_item	2716976	et	4	main
pärast	doc_541512374224_item	2716978	et	4	main
jõudis	doc_541512374224_item	2716983	et	3	main
kool	doc_541512374224_item	2716985	et	4	main
veel	doc_541512374224_item	2716986	et	4	main
algama	doc_541512374224_item	2716987	et	3	main
kartulivõtt	doc_541512374224_item	2716994	et	3	main
salv	doc_541512374224_item	2717004	et	3	main
salves	doc_541512374224_item	2717005	et	4	main
ja	doc_541512374224_item	2717006	et	3	main
ja	doc_541512374224_item	2717018	et	3	main
mitte	doc_541512374224_item	2717022	et	3	main
aktsent	doc_541512374224_item	2717024	et	3	main
vaid	doc_541512374224_item	2717026	et	3	main
nagu	doc_541512374224_item	2717027	et	3	main
venemaa	doc_541512374224_item	2717034	et	4	main
keeles	doc_541512374224_item	2717042	et	4	main
külas	doc_541512374224_item	2717043	et	3	main
elab	doc_541512374224_item	2717044	et	3	main
veidi	doc_541512374224_item	2717045	et	3	main
piret	doc_541512374224_item	2717069	et	4	main
vaja	doc_541512374224_item	2717096	et	4	main
vildid	doc_541512374224_item	2717100	et	4	main
muud	doc_541512374224_item	2717104	et	4	main
lühendatud	doc_541512374224_item	2717113	et	4	main
moodustage	doc_541512374224_item	2717117	et	3	main
murret	doc_541512374224_item	2717030	et	4	main
on	doc_541512374224_item	2717032	et	4	main
aine	doc_541512374224_item	2717038	et	4	main
ained	doc_541512374224_item	2717039	et	3	main
õpetatakse	doc_541512374224_item	2717040	et	3	main
poolpõlenud	doc_541512374224_item	2717058	et	4	main
eestist	doc_541512374224_item	2717064	et	3	main
uued	doc_541512374224_item	2717065	et	3	main
õpikud	doc_541512374224_item	2717066	et	3	main
siberi	doc_541512374224_item	2717067	et	4	main
ei	doc_541512374224_item	2717070	et	4	main
kartma	doc_541512374224_item	2717071	et	3	main
karda	doc_541512374224_item	2717072	et	4	main
mulle	doc_541512374224_item	2717073	et	4	main
juba	doc_541512374224_item	2717074	et	3	main
tooma	doc_541512374224_item	2717075	et	3	main
tõid	doc_541512374224_item	2717076	et	4	main
talvepuud	doc_541512374224_item	2717077	et	4	main
praegu	doc_541512374224_item	2717078	et	3	main
on	doc_541512374224_item	2717079	et	4	main
päevad	doc_541512374224_item	2717080	et	3	main
veel	doc_541512374224_item	2717081	et	4	main
soe	doc_541512374224_item	2717082	et	4	main
kuid	doc_541512374224_item	2717083	et	4	main
ööd	doc_541512374224_item	2717084	et	4	main
juba	doc_541512374224_item	2717085	et	3	main
jahe	doc_541512374224_item	2717086	et	3	main
jahedad	doc_541512374224_item	2717087	et	3	main
harjutan	doc_541512374224_item	2717088	et	3	main
juba	doc_541512374224_item	2717089	et	3	main
suure	doc_541512374224_item	2717090	et	3	main
ülejäänud	doc_541512374224_item	2717037	et	4	main
kolmsada	doc_541512374224_item	2717047	et	4	main
inimene	doc_541512374224_item	2717048	et	3	main
inimest	doc_541512374224_item	2717049	et	3	main
emakeelt	doc_541512374224_item	2717050	et	4	main
saab	doc_541512374224_item	2717051	et	3	main
kõik	doc_541512374224_item	2717052	et	4	main
rääkida	doc_541512374224_item	2717053	et	3	main
pireti	doc_541512374224_item	2717054	et	4	main
sõnul	doc_541512374224_item	2717055	et	3	main
õpivad	doc_541512374224_item	2717056	et	3	main
lapsed	doc_541512374224_item	2717057	et	3	main
ahju	doc_541512374224_item	2717092	et	4	main
ostan	doc_541512374224_item	2717097	et	3	main
külapoest	doc_541512374224_item	2717099	et	4	main
ega	doc_541512374224_item	2717101	et	3	main
seal	doc_541512374224_item	2717102	et	4	main
suurt	doc_541512374224_item	2717103	et	3	main
vapralt	doc_541512374224_item	2717112	et	4	main
iii	doc_541512374224_item	2717116	et	4	main
vormi	doc_541512374224_item	2717124	et	4	main
kirjavahemärke	doc_541512374224_item	2717127	et	4	main
ja	doc_541512374224_item	2717133	et	3	main
igaühe	doc_541512374224_item	2717145	et	4	main
kogus	doc_541512374224_item	2717149	et	4	main
meie	doc_541512374224_item	2717152	et	4	main
tegutsema	doc_541512374224_item	2717153	et	3	main
aga	doc_541512374224_item	2717154	et	3	main
lisakoormus	doc_541512374224_item	2717155	et	3	main
võima	doc_541512374224_item	2717156	et	3	main
tooma	doc_541512374224_item	2717157	et	3	main
kogus	doc_541512374224_item	2717161	et	4	main
stress	doc_541512374224_item	2717162	et	3	main
hingata	doc_541512374224_item	2717223	et	4	main
kuid	doc_541512374224_item	2717225	et	4	main
katkestama	doc_541512374224_item	2717227	et	3	main
segama	doc_541512374224_item	2717232	et	3	main
valmistamine	doc_541512374224_item	2717234	et	4	main
ja	doc_541512374224_item	2717235	et	3	main
söömine	doc_541512374224_item	2717236	et	4	main
lõunasööki	doc_541512374224_item	2717250	et	4	main
huvitavat	doc_541512374224_item	2717255	et	4	main
ma	doc_541512374224_item	2717267	et	3	main
oma	doc_541512374224_item	2717273	et	4	main
sest	doc_541512374224_item	2717275	et	4	main
nad	doc_541512374224_item	2717276	et	3	main
aitavad	doc_541512374224_item	2717277	et	4	main
nõuded	doc_541512374224_item	2717287	et	3	main
tunned	doc_541512374224_item	2717299	et	3	main
ilusaid	doc_541512374224_item	2717307	et	3	main
ja	doc_541512374224_item	2717309	et	3	main
autosid	doc_541512374224_item	2717311	et	3	main
praegu	doc_541512374224_item	2717313	et	3	main
on	doc_541512374224_item	2717314	et	4	main
oht	doc_541512374224_item	2717315	et	3	main
haigestuda	doc_541512374224_item	2717316	et	3	main
vene	doc_541512374224_item	2717091	et	4	main
kütmine	doc_541512374224_item	2717093	et	4	main
kütmist	doc_541512374224_item	2717094	et	4	main
ajalehest	doc_541512374224_item	2717114	et	4	main
etteantud	doc_541512374224_item	2717118	et	4	main
sõnadest	doc_541512374224_item	2717119	et	3	main
laused	doc_541512374224_item	2717120	et	3	main
pannes	doc_541512374224_item	2717121	et	4	main
naised	doc_541512374224_item	2717131	et	3	main
mehed	doc_541512374224_item	2717134	et	3	main
igaüks	doc_541512374224_item	2717136	et	3	main
3	doc_541512374224_item	2717147	et	2	main
paras	doc_541512374224_item	2717148	et	3	main
stress	doc_541512374224_item	2717150	et	3	main
aga	doc_541512374224_item	2717166	et	3	main
soovimatu	doc_541512374224_item	2717170	et	4	main
et	doc_541512374224_item	2717203	et	3	main
see	doc_541512374224_item	2717204	et	3	main
abil	doc_541512374224_item	2717205	et	4	main
lausa	doc_541512374224_item	2717206	et	4	main
abil	doc_541512374224_item	2717218	et	4	main
6	doc_541512374224_item	2717224	et	2	main
telefonihelin	doc_541512374224_item	2717226	et	3	main
pühapäev	doc_541512374224_item	2717229	et	3	main
varahommik	doc_541512374224_item	2717230	et	3	main
vaatamine	doc_541512374224_item	2717240	et	4	main
aeg	doc_541512374224_item	2717241	et	3	main
kuid	doc_541512374224_item	2717242	et	4	main
telefonihelin	doc_541512374224_item	2717243	et	3	main
katkestab	doc_541512374224_item	2717244	et	3	main
pühapäeva	doc_541512374224_item	2717246	et	4	main
varahommiku	doc_541512374224_item	2717247	et	3	main
iv	doc_541512374224_item	2717259	et	4	main
pean	doc_541512374224_item	2717268	et	4	main
nõuetega	doc_541512374224_item	2717288	et	4	main
arvasin	doc_541512374224_item	2717291	et	3	main
difteeria	doc_541512374224_item	2717317	et	4	main
töökoht	doc_541512374224_item	2717322	et	3	main
kiiresti	doc_541512374224_item	2717325	et	3	main
küsimuses	doc_541512374224_item	2717329	et	4	main
vaid	doc_541512374224_item	2717330	et	3	main
väikesed	doc_541512374224_item	2717331	et	4	main
muudatused	doc_541512374224_item	2717332	et	3	main
kleepus	doc_541512374224_item	2717345	et	3	main
õpilased	doc_541512374224_item	2717380	et	3	main
kõrvallauast	doc_541512374224_item	2717392	et	4	main
oleks	doc_541512374224_item	2717396	et	3	main
teatrisse	doc_541512374224_item	2717409	et	3	main
töö	doc_541512374224_item	2717412	et	4	main
baaris	doc_541512374224_item	2717418	et	3	main
suitsetada	doc_541512374224_item	2717421	et	3	main
ei	doc_541512374224_item	2717432	et	4	main
9	doc_541512374224_item	2717434	et	2	main
küsimusele	doc_542009824736_item	2717449	et	4	main
kultuur	doc_542009824736_item	2717461	et	3	main
ette	doc_542009824736_item	2717468	et	4	main
väärtusta	doc_542009824736_item	2717477	et	4	main
enda	doc_542009824736_item	2717478	et	4	main
rahva	doc_542009824736_item	2717479	et	3	main
kultuur	doc_542009824736_item	2717483	et	3	main
mina	doc_542009824737_item	2717512	et	4	main
kuulen	doc_542009824737_item	2717513	et	3	main
sõna	doc_542009824737_item	2717514	et	4	main
mina	doc_542009824737_item	2717522	et	4	main
kirjandusest	doc_542009824737_item	2717525	et	4	main
sest	doc_542009824737_item	2717527	et	4	main
et	doc_542009824737_item	2717528	et	3	main
raamatute	doc_542009824737_item	2717529	et	3	main
järgi	doc_542009824737_item	2717530	et	4	main
me	doc_542009824737_item	2717531	et	4	main
kultuur	doc_542009824737_item	2717538	et	3	main
milline	doc_542009824737_item	2717539	et	3	main
milline	doc_542009824737_item	2717544	et	3	main
ta	doc_542009824737_item	2717546	et	4	main
1	doc_542009824737_item	2717549	et	2	main
aga	doc_542009824737_item	2717553	et	3	main
eesti	doc_542009824737_item	2717555	et	4	main
võin	doc_542009824737_item	2717557	et	3	main
et	doc_542009824737_item	2717559	et	3	main
kohal	doc_542009824737_item	2717572	et	4	main
1	doc_542009824738_item	2717578	et	2	main
õigesse	doc_541512374224_item	2717123	et	3	main
2	doc_541512374224_item	2717128	et	2	main
tegema	doc_541512374224_item	2717130	et	3	main
mehelikum	doc_541512374224_item	2717144	et	4	main
panema	doc_541512374224_item	2717151	et	3	main
meid	doc_541512374224_item	2717164	et	4	main
lisakoormus	doc_541512374224_item	2717167	et	3	main
tuua	doc_541512374224_item	2717169	et	3	main
tagajärgu	doc_541512374224_item	2717171	et	3	main
ei	doc_541512374224_item	2717173	et	4	main
tohtima	doc_541512374224_item	2717174	et	3	main
laskma	doc_541512374224_item	2717175	et	3	main
ülekoormus	doc_541512374224_item	2717176	et	3	main
tekkima	doc_541512374224_item	2717177	et	3	main
pinge	doc_541512374224_item	2717178	et	4	main
saama	doc_541512374224_item	2717179	et	4	main
maandama	doc_541512374224_item	2717180	et	3	main
sportima	doc_541512374224_item	2717181	et	4	main
ja	doc_541512374224_item	2717182	et	3	main
puhkama	doc_541512374224_item	2717183	et	3	main
ei	doc_541512374224_item	2717184	et	4	main
tohti	doc_541512374224_item	2717185	et	4	main
laskma	doc_541512374224_item	2717186	et	3	main
ülekoormust	doc_541512374224_item	2717187	et	4	main
tekkida	doc_541512374224_item	2717188	et	3	main
pinget	doc_541512374224_item	2717189	et	3	main
saab	doc_541512374224_item	2717190	et	3	main
maandada	doc_541512374224_item	2717191	et	3	main
sportida	doc_541512374224_item	2717192	et	4	main
ja	doc_541512374224_item	2717193	et	3	main
puhata	doc_541512374224_item	2717194	et	4	main
5	doc_541512374224_item	2717195	et	2	main
telefon	doc_541512374224_item	2717196	et	3	main
olema	doc_541512374224_item	2717197	et	4	main
tänapäev	doc_541512374224_item	2717198	et	3	main
saama	doc_541512374224_item	2717199	et	4	main
nii	doc_541512374224_item	2717200	et	3	main
maagiline	doc_541512374224_item	2717214	et	4	main
aparaat	doc_541512374224_item	2717215	et	3	main
et	doc_541512374224_item	2717216	et	3	main
selle	doc_541512374224_item	2717217	et	4	main
lausa	doc_541512374224_item	2717220	et	4	main
pahandab	doc_541512374224_item	2717237	et	3	main
huvitav	doc_541512374224_item	2717238	et	4	main
ka	doc_541512374224_item	2717245	et	3	main
une	doc_541512374224_item	2717248	et	3	main
ajal	doc_541512374224_item	2717258	et	4	main
sõnad	doc_541512374224_item	2717263	et	4	main
õigesse	doc_541512374224_item	2717264	et	3	main
vormi	doc_541512374224_item	2717265	et	4	main
kõik	doc_541512374224_item	2717278	et	4	main
kõike	doc_541512374224_item	2717279	et	4	main
ja	doc_541512374224_item	2717280	et	3	main
usaldavad	doc_541512374224_item	2717281	et	4	main
igaüks	doc_541512374224_item	2717282	et	3	main
igaüht	doc_541512374224_item	2717283	et	3	main
2	doc_541512374224_item	2717284	et	2	main
kohandasin	doc_541512374224_item	2717285	et	3	main
ma	doc_541512374224_item	2717290	et	3	main
sport	doc_541512374224_item	2717295	et	3	main
sa	doc_541512374224_item	2717298	et	3	main
autod	doc_541512374224_item	2717306	et	3	main
4	doc_541512374224_item	2717312	et	2	main
5	doc_541512374224_item	2717319	et	2	main
väikesi	doc_541512374224_item	2717333	et	4	main
muudatusi	doc_541512374224_item	2717334	et	3	main
7	doc_541512374224_item	2717335	et	2	main
see	doc_541512374224_item	2717336	et	3	main
küsimus	doc_541512374224_item	2717337	et	4	main
külmal	doc_541512374224_item	2717349	et	3	main
külmetamine	doc_541512374224_item	2717353	et	4	main
külmetamist	doc_541512374224_item	2717354	et	4	main
10	doc_541512374224_item	2717355	et	2	main
ma	doc_541512374224_item	2717356	et	3	main
v	doc_541512374224_item	2717363	et	4	main
täitke	doc_541512374224_item	2717364	et	3	main
1	doc_541512374224_item	2717368	et	2	main
kolmekäigulise	doc_541512374224_item	2717370	et	4	main
lõuna	doc_541512374224_item	2717371	et	4	main
kuigi	doc_541512374224_item	2717372	et	3	main
see	doc_541512374224_item	2717373	et	3	main
maksis	doc_541512374224_item	2717374	et	4	main
õpetajad	doc_541512374224_item	2717382	et	4	main
rääkinud	doc_541512374224_item	2717400	et	4	main
5	doc_541512374224_item	2717401	et	2	main
sest	doc_541512374224_item	2717406	et	4	main
hoopis	doc_541512374224_item	2717408	et	3	main
siis	doc_541512374224_item	2717413	et	3	main
jalutama	doc_541512374224_item	2717415	et	3	main
elada	doc_541512374224_item	2717221	et	3	main
ka	doc_541512374224_item	2717228	et	3	main
uni	doc_541512374224_item	2717231	et	3	main
lõunasöök	doc_541512374224_item	2717233	et	3	main
valmistamist	doc_541512374224_item	2717251	et	4	main
söömist	doc_541512374224_item	2717253	et	4	main
olevad	doc_541512374224_item	2717262	et	4	main
väga	doc_541512374224_item	2717269	et	3	main
vanemad	doc_541512374224_item	2717272	et	4	main
vanematest	doc_541512374224_item	2717274	et	4	main
artikli	doc_541512374224_item	2717286	et	3	main
sa	doc_541512374224_item	2717293	et	3	main
sporti	doc_541512374224_item	2717296	et	4	main
aga	doc_541512374224_item	2717297	et	3	main
huvi	doc_541512374224_item	2717300	et	4	main
ainult	doc_541512374224_item	2717301	et	4	main
ilusad	doc_541512374224_item	2717302	et	3	main
naised	doc_541512374224_item	2717303	et	3	main
ja	doc_541512374224_item	2717304	et	3	main
difteeriad	doc_541512374224_item	2717318	et	3	main
töökoha	doc_541512374224_item	2717324	et	4	main
9	doc_541512374224_item	2717348	et	2	main
päike	doc_541512374224_item	2717360	et	3	main
suvist	doc_541512374224_item	2717361	et	4	main
päikest	doc_541512374224_item	2717362	et	4	main
sidenditega	doc_541512374224_item	2717367	et	3	main
palju	doc_541512374224_item	2717375	et	4	main
lapsel	doc_541512374224_item	2717384	et	4	main
kuni	doc_541512374224_item	2717387	et	3	main
tagasi	doc_541512374224_item	2717389	et	3	main
tulevad	doc_541512374224_item	2717390	et	4	main
4	doc_541512374224_item	2717391	et	2	main
naeru	doc_541512374224_item	2717394	et	4	main
keegi	doc_541512374224_item	2717397	et	4	main
just	doc_541512374224_item	2717398	et	3	main
anekdooti	doc_541512374224_item	2717399	et	4	main
trenni	doc_541512374224_item	2717405	et	4	main
6	doc_541512374224_item	2717410	et	2	main
nad	doc_541512374224_item	2717426	et	3	main
maale	doc_541512374224_item	2717438	et	4	main
või	doc_541512374224_item	2717439	et	4	main
linna	doc_541512374224_item	2717441	et	4	main
on	doc_542009824736_item	2717460	et	4	main
maade	doc_542009824736_item	2717463	et	3	main
aegade	doc_542009824736_item	2717464	et	3	main
kultuurist	doc_542009824736_item	2717465	et	3	main
mõeldes	doc_542009824736_item	2717466	et	3	main
kujutan	doc_542009824736_item	2717467	et	3	main
kultuuri	doc_542009824736_item	2717480	et	4	main
laulupeod	doc_542009824736_item	2717495	et	4	main
kultur	doc_542009824737_item	2717515	et	4	main
mina	doc_542009824737_item	2717516	et	4	main
esiteks	doc_542009824737_item	2717521	et	3	main
raamatutest	doc_542009824737_item	2717526	et	4	main
mingi	doc_542009824737_item	2717536	et	4	main
oli	doc_542009824737_item	2717541	et	3	main
kuultuur	doc_542009824737_item	2717551	et	3	main
kui	doc_542009824737_item	2717552	et	3	main
ta	doc_542009824737_item	2717560	et	4	main
seostub	doc_542009824737_item	2717561	et	3	main
mul	doc_542009824737_item	2717562	et	3	main
kirjandusega	doc_542009824737_item	2717563	et	3	main
ka	doc_542009824737_item	2717564	et	3	main
raske	doc_542009824737_item	2717565	et	4	main
seda	doc_542009824737_item	2717566	et	3	main
kultuuri	doc_542009824737_item	2717569	et	4	main
kirjandusega	doc_542009824737_item	2717573	et	3	main
istuma	doc_542009824738_item	2717621	et	3	main
vaja	doc_542009824738_item	2717625	et	4	main
inimene	doc_542009824738_item	2717630	et	3	main
muidugi	doc_542009824738_item	2717637	et	4	main
see	doc_542009824738_item	2717638	et	3	main
ka	doc_542009824738_item	2717644	et	3	main
öelda	doc_542009824738_item	2717645	et	4	main
et	doc_542009824738_item	2717646	et	3	main
see	doc_542009824738_item	2717647	et	3	main
inimene	doc_542009824738_item	2717648	et	3	main
on	doc_542009824738_item	2717649	et	4	main
kultuurne	doc_542009824738_item	2717650	et	3	main
ja	doc_542009824738_item	2717651	et	3	main
hästikasvatud	doc_542009824738_item	2717652	et	3	main
küsimusele	doc_542009824739_item	2717662	et	4	main
laste	doc_542009824739_item	2717665	et	4	main
see	doc_542009824739_item	2717674	et	3	main
seda	doc_542009824739_item	2717682	et	3	main
kiired	doc_541512374224_item	2717305	et	4	main
naisi	doc_541512374224_item	2717308	et	3	main
kiireid	doc_541512374224_item	2717310	et	4	main
tüdinesin	doc_541512374224_item	2717320	et	3	main
uus	doc_541512374224_item	2717321	et	3	main
uue	doc_541512374224_item	2717323	et	3	main
6	doc_541512374224_item	2717326	et	2	main
kuulub	doc_541512374224_item	2717338	et	3	main
teine	doc_541512374224_item	2717339	et	3	main
valdkond	doc_541512374224_item	2717340	et	3	main
teisele	doc_541512374224_item	2717341	et	4	main
ajal	doc_541512374224_item	2717350	et	4	main
hoiduma	doc_541512374224_item	2717352	et	3	main
suvine	doc_541512374224_item	2717359	et	4	main
sobivate	doc_541512374224_item	2717366	et	4	main
tellisime	doc_541512374224_item	2717369	et	4	main
kohal	doc_541512374224_item	2717377	et	4	main
olid	doc_541512374224_item	2717378	et	4	main
nii	doc_541512374224_item	2717379	et	3	main
kui	doc_541512374224_item	2717381	et	3	main
3	doc_541512374224_item	2717383	et	2	main
oodata	doc_541512374224_item	2717386	et	4	main
ta	doc_541512374224_item	2717402	et	4	main
läheb	doc_541512374224_item	2717407	et	3	main
7	doc_541512374224_item	2717416	et	2	main
ning	doc_541512374224_item	2717422	et	3	main
tarbida	doc_541512374224_item	2717424	et	3	main
küll	doc_541512374224_item	2717428	et	4	main
pingsalt	doc_541512374224_item	2717429	et	4	main
aga	doc_541512374224_item	2717430	et	3	main
sa	doc_541512374224_item	2717436	et	3	main
jääd	doc_541512374224_item	2717440	et	4	main
10	doc_541512374224_item	2717442	et	2	main
avasin	doc_541512374224_item	2717443	et	3	main
ukse	doc_541512374224_item	2717444	et	3	main
kui	doc_541512374224_item	2717445	et	3	main
kuulsin	doc_541512374224_item	2717446	et	3	main
koputust	doc_541512374224_item	2717447	et	4	main
vastus	doc_542009824736_item	2717448	et	3	main
mõtlen	doc_542009824736_item	2717473	et	3	main
eesti	doc_542009824736_item	2717482	et	4	main
meie	doc_542009824736_item	2717485	et	4	main
kuulame	doc_542009824737_item	2717502	et	4	main
mõtlema	doc_542009824737_item	2717518	et	3	main
kultuurist	doc_542009824737_item	2717520	et	3	main
muidugi	doc_542009824737_item	2717524	et	4	main
ta	doc_542009824737_item	2717540	et	4	main
ühel	doc_542009824737_item	2717571	et	3	main
vastus	doc_542009824738_item	2717576	et	3	main
küsimusele	doc_542009824738_item	2717577	et	4	main
meid	doc_542009824738_item	2717617	et	4	main
kuidas	doc_542009824738_item	2717618	et	3	main
me	doc_542009824738_item	2717619	et	4	main
õpis	doc_542009824738_item	2717622	et	3	main
end	doc_542009824738_item	2717627	et	4	main
sisse	doc_542009824738_item	2717632	et	4	main
ta	doc_542009824738_item	2717634	et	4	main
tere	doc_542009824738_item	2717636	et	3	main
on	doc_542009824738_item	2717639	et	4	main
kuidas	doc_542009824739_item	2717680	et	3	main
ka	doc_542009824739_item	2717709	et	3	main
see	doc_542009824739_item	2717710	et	3	main
võib	doc_542009824739_item	2717720	et	3	main
kultuur	doc_542009824739_item	2717723	et	3	main
suhtuda	doc_542009824739_item	2717731	et	3	main
ja	doc_542009824739_item	2717741	et	3	main
endas	doc_542009824739_item	2717743	et	4	main
kombed	doc_542009824739_item	2717767	et	3	main
eesti	doc_542009824739_item	2717775	et	4	main
kultuur	doc_542009824739_item	2717776	et	3	main
on	doc_542009824739_item	2717777	et	4	main
ka	doc_542009824739_item	2717823	et	3	main
1	doc_542009824740_item	2717828	et	2	main
sõna	doc_542009824740_item	2717831	et	4	main
mõtlema	doc_542009824740_item	2717835	et	3	main
kultuurne	doc_542009824740_item	2717840	et	3	main
end	doc_542009824740_item	2717851	et	4	main
käituma	doc_542009824740_item	2717852	et	3	main
et	doc_542009824740_item	2717857	et	3	main
algab	doc_542009824740_item	2717859	et	3	main
ise	doc_542009824740_item	2717861	et	4	main
olema	doc_542009824740_item	2717863	et	4	main
piirdusime	doc_541512374224_item	2717327	et	3	main
selles	doc_541512374224_item	2717328	et	4	main
valdkonnale	doc_541512374224_item	2717342	et	4	main
8	doc_541512374224_item	2717343	et	2	main
närimiskumm	doc_541512374224_item	2717344	et	3	main
püksid	doc_541512374224_item	2717346	et	3	main
püksidele	doc_541512374224_item	2717347	et	3	main
peab	doc_541512374224_item	2717351	et	4	main
tunnen	doc_541512374224_item	2717357	et	3	main
rõõmu	doc_541512374224_item	2717358	et	4	main
lüngad	doc_541512374224_item	2717365	et	3	main
2	doc_541512374224_item	2717376	et	2	main
paluti	doc_541512374224_item	2717385	et	3	main
vanemad	doc_541512374224_item	2717388	et	4	main
kostis	doc_541512374224_item	2717393	et	4	main
see	doc_541512374224_item	2717395	et	3	main
ei	doc_541512374224_item	2717403	et	4	main
tule	doc_541512374224_item	2717404	et	4	main
lõpetage	doc_541512374224_item	2717411	et	3	main
lähete	doc_541512374224_item	2717414	et	4	main
selles	doc_541512374224_item	2717417	et	4	main
ei	doc_541512374224_item	2717419	et	4	main
tohi	doc_541512374224_item	2717420	et	4	main
alkoholi	doc_541512374224_item	2717423	et	4	main
8	doc_541512374224_item	2717425	et	2	main
töötasid	doc_541512374224_item	2717427	et	4	main
olnud	doc_541512374224_item	2717433	et	4	main
kas	doc_541512374224_item	2717435	et	3	main
inimestest	doc_542009824736_item	2717474	et	3	main
joonistused	doc_542009824736_item	2717494	et	4	main
vastus	doc_542009824737_item	2717496	et	3	main
1	doc_542009824737_item	2717498	et	2	main
kultuur	doc_542009824737_item	2717499	et	3	main
kui	doc_542009824737_item	2717500	et	3	main
me	doc_542009824737_item	2717501	et	4	main
kultuur	doc_542009824737_item	2717504	et	3	main
inimesed	doc_542009824737_item	2717506	et	3	main
seletavad	doc_542009824737_item	2717507	et	4	main
seda	doc_542009824737_item	2717508	et	3	main
maailma	doc_542009824737_item	2717519	et	4	main
räägiksin	doc_542009824737_item	2717523	et	3	main
võime	doc_542009824737_item	2717532	et	4	main
näha	doc_542009824737_item	2717533	et	3	main
kuidas	doc_542009824737_item	2717534	et	3	main
muutus	doc_542009824737_item	2717535	et	4	main
eile	doc_542009824737_item	2717542	et	3	main
on	doc_542009824737_item	2717545	et	4	main
praegu	doc_542009824737_item	2717547	et	3	main
tänapäeval	doc_542009824737_item	2717548	et	3	main
eesti	doc_542009824737_item	2717550	et	4	main
rääkida	doc_542009824737_item	2717554	et	3	main
kultuurist	doc_542009824737_item	2717556	et	3	main
ööelda	doc_542009824737_item	2717558	et	4	main
eesti	doc_542009824737_item	2717568	et	4	main
kuulamisel	doc_542009824737_item	2717570	et	4	main
muusika	doc_542009824737_item	2717575	et	4	main
peame	doc_542009824738_item	2717620	et	4	main
tulemust	doc_541512374224_item	2717431	et	4	main
sõidad	doc_541512374224_item	2717437	et	3	main
1	doc_542009824736_item	2717450	et	2	main
sõna	doc_542009824736_item	2717452	et	4	main
kuuldes	doc_542009824736_item	2717451	et	4	main
kultuur	doc_542009824736_item	2717453	et	3	main
kohe	doc_542009824736_item	2717454	et	4	main
tuleb	doc_542009824736_item	2717455	et	3	main
meelde	doc_542009824736_item	2717456	et	3	main
teater	doc_542009824736_item	2717457	et	3	main
ka	doc_542009824736_item	2717458	et	3	main
käitumine	doc_542009824736_item	2717459	et	4	main
iidsete	doc_542009824736_item	2717462	et	3	main
kreekat	doc_542009824736_item	2717469	et	4	main
kurb	doc_542009824736_item	2717470	et	3	main
hakkab	doc_542009824736_item	2717471	et	3	main
kui	doc_542009824736_item	2717472	et	3	main
kes	doc_542009824736_item	2717475	et	4	main
ei	doc_542009824736_item	2717476	et	4	main
2	doc_542009824736_item	2717481	et	2	main
on	doc_542009824736_item	2717484	et	4	main
maa	doc_542009824736_item	2717486	et	4	main
iseloomujoon	doc_542009824736_item	2717487	et	3	main
kogudus	doc_542009824736_item	2717488	et	3	main
mitmest	doc_542009824736_item	2717489	et	4	main
kultuurist	doc_542009824736_item	2717490	et	3	main
kalevipoeg	doc_542009824736_item	2717491	et	3	main
kristjan	doc_542009824736_item	2717492	et	4	main
raua	doc_542009824736_item	2717493	et	3	main
küsimusele	doc_542009824737_item	2717497	et	4	main
sõna	doc_542009824737_item	2717503	et	4	main
erinevad	doc_542009824737_item	2717505	et	4	main
erinevalt	doc_542009824737_item	2717509	et	4	main
kui	doc_542009824737_item	2717510	et	3	main
näiteks	doc_542009824737_item	2717511	et	4	main
hakkan	doc_542009824737_item	2717517	et	3	main
riiga	doc_542009824737_item	2717537	et	4	main
ja	doc_542009824737_item	2717543	et	3	main
seletada	doc_542009824737_item	2717567	et	3	main
seisab	doc_542009824737_item	2717574	et	3	main
kultuur	doc_542009824738_item	2717579	et	3	main
all	doc_542009824738_item	2717581	et	3	main
mõistetakse	doc_542009824738_item	2717582	et	3	main
muuseum	doc_542009824738_item	2717583	et	3	main
teater	doc_542009824738_item	2717584	et	3	main
näitus	doc_542009824738_item	2717585	et	3	main
kirjandus	doc_542009824738_item	2717586	et	3	main
ning	doc_542009824738_item	2717587	et	3	main
ka	doc_542009824738_item	2717588	et	3	main
kultuuri	doc_542009824738_item	2717580	et	4	main
igal	doc_542009824738_item	2717589	et	3	main
rahval	doc_542009824738_item	2717590	et	3	main
on	doc_542009824738_item	2717591	et	4	main
oma	doc_542009824738_item	2717592	et	4	main
kultuur	doc_542009824738_item	2717593	et	3	main
kuidas	doc_542009824738_item	2717594	et	3	main
nad	doc_542009824738_item	2717595	et	3	main
elavad	doc_542009824738_item	2717596	et	4	main
kuidas	doc_542009824738_item	2717597	et	3	main
nad	doc_542009824738_item	2717598	et	3	main
räägivad	doc_542009824738_item	2717599	et	3	main
mis	doc_542009824738_item	2717600	et	4	main
on	doc_542009824738_item	2717601	et	4	main
nende	doc_542009824738_item	2717602	et	4	main
kombeid	doc_542009824738_item	2717603	et	4	main
ja	doc_542009824738_item	2717604	et	3	main
nii	doc_542009824738_item	2717605	et	3	main
edasi	doc_542009824738_item	2717606	et	3	main
juba	doc_542009824738_item	2717607	et	3	main
lapsepõlvest	doc_542009824738_item	2717608	et	4	main
ema	doc_542009824738_item	2717609	et	4	main
ütles	doc_542009824738_item	2717610	et	3	main
meile	doc_542009824738_item	2717611	et	4	main
mis	doc_542009824738_item	2717612	et	4	main
on	doc_542009824738_item	2717613	et	4	main
kultuur	doc_542009824738_item	2717614	et	3	main
ta	doc_542009824738_item	2717615	et	4	main
õpis	doc_542009824738_item	2717616	et	3	main
kuidas	doc_542009824738_item	2717623	et	3	main
kui	doc_542009824738_item	2717629	et	3	main
aga	doc_542009824738_item	2717641	et	3	main
me	doc_542009824738_item	2717642	et	4	main
kultuur	doc_542009824739_item	2717663	et	3	main
on	doc_542009824739_item	2717673	et	4	main
ta	doc_542009824739_item	2717681	et	4	main
sõltub	doc_542009824739_item	2717684	et	3	main
on	doc_542009824739_item	2717688	et	4	main
kuidas	doc_542009824739_item	2717690	et	3	main
kui	doc_542009824739_item	2717695	et	3	main
tall	doc_542009824739_item	2717700	et	3	main
kuidas	doc_542009824739_item	2717711	et	3	main
oskab	doc_542009824739_item	2717713	et	3	main
teisest	doc_542009824739_item	2717715	et	4	main
valdkonnast	doc_542009824739_item	2717716	et	4	main
õppetada	doc_542009824739_item	2717722	et	4	main
minu	doc_542009824739_item	2717725	et	3	main
kuidas	doc_542009824739_item	2717728	et	3	main
oskad	doc_542009824739_item	2717730	et	3	main
teistesse	doc_542009824739_item	2717732	et	4	main
ja	doc_542009824739_item	2717734	et	3	main
läheb	doc_542009824739_item	2717736	et	3	main
hoida	doc_542009824739_item	2717738	et	3	main
oma	doc_542009824739_item	2717739	et	4	main
mõtteid	doc_542009824739_item	2717742	et	3	main
kultuur	doc_542009824739_item	2717747	et	3	main
on	doc_542009824739_item	2717748	et	4	main
täpselt	doc_542009824739_item	2717752	et	4	main
ole	doc_542009824739_item	2717755	et	4	main
kuid	doc_542009824739_item	2717756	et	4	main
võib	doc_542009824739_item	2717757	et	3	main
olla	doc_542009824739_item	2717758	et	3	main
leidub	doc_542009824739_item	2717759	et	3	main
sarnaseid	doc_542009824739_item	2717760	et	4	main
kultuure	doc_542009824739_item	2717761	et	3	main
traditsioonid	doc_542009824739_item	2717768	et	3	main
keel	doc_542009824739_item	2717770	et	4	main
oma	doc_542009824739_item	2717773	et	4	main
eesti	doc_542009824739_item	2717787	et	4	main
käitumisviisi	doc_542009824739_item	2717789	et	4	main
kui	doc_542009824739_item	2717822	et	3	main
kui	doc_542009824740_item	2717829	et	3	main
siis	doc_542009824740_item	2717833	et	3	main
olen	doc_542009824740_item	2717839	et	3	main
kultuurseks	doc_542009824740_item	2717864	et	4	main
liidu	doc_542009824740_item	2717892	et	3	main
sõna	doc_542009824742_item	2718021	et	4	main
kultuur	doc_542009824742_item	2718024	et	3	main
võib	doc_542009824742_item	2718027	et	3	main
käitumisega	doc_542009824742_item	2718038	et	4	main
iga	doc_542009824742_item	2718041	et	4	main
annab	doc_542009824742_item	2718047	et	3	main
eesti	doc_542009824742_item	2718055	et	4	main
tahan	doc_542009824742_item	2718064	et	3	main
nende	doc_542009824742_item	2718068	et	4	main
kultuur	doc_542009824742_item	2718069	et	3	main
teiste	doc_542009824742_item	2718079	et	4	main
ainult	doc_542009824742_item	2718091	et	4	main
lugeda	doc_542009824742_item	2718092	et	3	main
õppida	doc_542009824742_item	2718093	et	3	main
saada	doc_542009824742_item	2718097	et	4	main
mõttes	doc_542009824742_item	2718099	et	3	main
on	doc_542009824742_item	2718102	et	4	main
on	doc_542009824738_item	2717624	et	4	main
käituda	doc_542009824738_item	2717626	et	3	main
ja	doc_542009824738_item	2717633	et	3	main
ütleb	doc_542009824738_item	2717635	et	3	main
võime	doc_542009824738_item	2717643	et	4	main
1	doc_542009824738_item	2717653	et	2	main
eesti	doc_542009824738_item	2717654	et	4	main
kultuur	doc_542009824738_item	2717655	et	3	main
eesti	doc_542009824738_item	2717656	et	4	main
kultuur	doc_542009824738_item	2717657	et	3	main
koosneb	doc_542009824738_item	2717658	et	3	main
eesti	doc_542009824738_item	2717659	et	4	main
kirjandusest	doc_542009824738_item	2717660	et	4	main
vastus	doc_542009824739_item	2717661	et	3	main
ühiskonnas	doc_542009824738_item	2717628	et	4	main
tuleb	doc_542009824738_item	2717631	et	3	main
loomulikult	doc_542009824738_item	2717640	et	4	main
oma	doc_542009824739_item	2717664	et	4	main
või	doc_542009824739_item	2717666	et	4	main
nooremate	doc_542009824739_item	2717667	et	4	main
mida	doc_542009824739_item	2717675	et	4	main
inimene	doc_542009824739_item	2717676	et	3	main
arendab	doc_542009824739_item	2717677	et	3	main
endas	doc_542009824739_item	2717678	et	4	main
ja	doc_542009824739_item	2717679	et	3	main
enesest	doc_542009824739_item	2717686	et	4	main
see	doc_542009824739_item	2717689	et	3	main
inimene	doc_542009824739_item	2717691	et	3	main
käituda	doc_542009824739_item	2717693	et	3	main
maailmast	doc_542009824739_item	2717703	et	4	main
ümbritseb	doc_542009824739_item	2717706	et	3	main
on	doc_542009824739_item	2717708	et	4	main
olla	doc_542009824739_item	2717721	et	3	main
on	doc_542009824739_item	2717724	et	4	main
kui	doc_542009824739_item	2717735	et	3	main
tarvis	doc_542009824739_item	2717737	et	3	main
eesti	doc_542009824739_item	2717744	et	4	main
kindlasti	doc_542009824739_item	2717749	et	3	main
on	doc_542009824739_item	2717764	et	4	main
omad	doc_542009824739_item	2717765	et	4	main
tavad	doc_542009824739_item	2717766	et	3	main
dikteerib	doc_542009824739_item	2717786	et	3	main
on	doc_542009824739_item	2717794	et	4	main
see	doc_542009824739_item	2717795	et	3	main
kodudes	doc_542009824739_item	2717821	et	3	main
rahu	doc_542009824739_item	2717825	et	4	main
kuulen	doc_542009824740_item	2717830	et	3	main
kultuur	doc_542009824740_item	2717832	et	3	main
ma	doc_542009824740_item	2717837	et	3	main
ise	doc_542009824740_item	2717838	et	4	main
või	doc_542009824740_item	2717842	et	4	main
e	doc_542009824740_item	2717855	et	4	main
arvan	doc_542009824740_item	2717856	et	3	main
inimestest	doc_542009824740_item	2717860	et	3	main
püüan	doc_542009824740_item	2717862	et	3	main
see	doc_542009824740_item	2717886	et	3	main
arvamus	doc_542009824740_item	2717889	et	3	main
euroopa	doc_542009824740_item	2717891	et	4	main
aga	doc_542009824740_item	2717893	et	3	main
tuleb	doc_542009824740_item	2717897	et	3	main
assemeleerimine	doc_542009824740_item	2717898	et	4	main
ja	doc_542009824740_item	2717899	et	3	main
eesti	doc_542009824742_item	2718023	et	4	main
rääkida	doc_542009824742_item	2718030	et	3	main
minu	doc_542009824742_item	2718032	et	3	main
kultuur	doc_542009824742_item	2718034	et	3	main
on	doc_542009824742_item	2718043	et	4	main
kultuur	doc_542009824742_item	2718045	et	3	main
neile	doc_542009824742_item	2718048	et	4	main
sugulaste	doc_542009824739_item	2717668	et	4	main
vendade	doc_542009824739_item	2717669	et	3	main
õdede	doc_542009824739_item	2717670	et	3	main
kasvatamine	doc_542009824739_item	2717671	et	4	main
kultuur	doc_542009824739_item	2717672	et	3	main
teeb	doc_542009824739_item	2717683	et	3	main
kultuur	doc_542009824739_item	2717687	et	3	main
oskab	doc_542009824739_item	2717692	et	3	main
ja	doc_542009824739_item	2717694	et	3	main
palju	doc_542009824739_item	2717696	et	4	main
ja	doc_542009824739_item	2717697	et	3	main
milliseid	doc_542009824739_item	2717698	et	3	main
on	doc_542009824739_item	2717701	et	4	main
sellest	doc_542009824739_item	2717702	et	4	main
teda	doc_542009824739_item	2717705	et	4	main
kultuur	doc_542009824739_item	2717707	et	3	main
inimene	doc_542009824739_item	2717712	et	3	main
ühestvõi	doc_542009824739_item	2717714	et	4	main
meelest	doc_542009824739_item	2717726	et	4	main
inimestesse	doc_542009824739_item	2717733	et	3	main
tundeid	doc_542009824739_item	2717740	et	3	main
kultuur	doc_542009824739_item	2717745	et	3	main
teisi	doc_542009824739_item	2717751	et	4	main
ei	doc_542009824739_item	2717754	et	4	main
oma	doc_542009824739_item	2717769	et	4	main
oma	doc_542009824739_item	2717771	et	4	main
kirjandus	doc_542009824739_item	2717772	et	3	main
ajalooline	doc_542009824739_item	2717778	et	4	main
pärand	doc_542009824739_item	2717779	et	3	main
mis	doc_542009824739_item	2717780	et	4	main
tuleb	doc_542009824739_item	2717781	et	3	main
iidsetest	doc_542009824739_item	2717782	et	3	main
aegadest	doc_542009824739_item	2717783	et	3	main
rahvale	doc_542009824739_item	2717788	et	3	main
toitumistavasid	doc_542009824739_item	2717790	et	3	main
kasvatamisviisi	doc_542009824739_item	2717791	et	4	main
eesti	doc_542009824739_item	2717792	et	4	main
kultuur	doc_542009824739_item	2717793	et	3	main
inimese	doc_542009824739_item	2717685	et	4	main
teadmisi	doc_542009824739_item	2717699	et	4	main
mis	doc_542009824739_item	2717704	et	4	main
midagi	doc_542009824739_item	2717717	et	4	main
rääkida	doc_542009824739_item	2717718	et	3	main
seletada	doc_542009824739_item	2717719	et	3	main
see	doc_542009824739_item	2717727	et	3	main
sa	doc_542009824739_item	2717729	et	3	main
eesti	doc_542009824739_item	2717746	et	4	main
ainulaadne	doc_542009824739_item	2717750	et	3	main
samasuguseid	doc_542009824739_item	2717753	et	3	main
eesti	doc_542009824739_item	2717762	et	4	main
kultuur	doc_542009824739_item	2717763	et	3	main
rahvas	doc_542009824739_item	2717774	et	4	main
eesti	doc_542009824739_item	2717784	et	4	main
kultuur	doc_542009824739_item	2717785	et	3	main
mis	doc_542009824739_item	2717796	et	4	main
on	doc_542009824739_item	2717797	et	4	main
kõikide	doc_542009824739_item	2717798	et	4	main
eestlaste	doc_542009824739_item	2717799	et	4	main
ja	doc_542009824739_item	2717800	et	3	main
võib	doc_542009824739_item	2717801	et	3	main
olla	doc_542009824739_item	2717802	et	3	main
ka	doc_542009824739_item	2717803	et	3	main
teiste	doc_542009824739_item	2717804	et	4	main
rahvuste	doc_542009824739_item	2717805	et	3	main
jaoks	doc_542009824739_item	2717806	et	4	main
ühine	doc_542009824739_item	2717807	et	4	main
võib	doc_542009824739_item	2717808	et	3	main
olla	doc_542009824739_item	2717809	et	3	main
on	doc_542009824739_item	2717810	et	4	main
see	doc_542009824739_item	2717811	et	3	main
mis	doc_542009824739_item	2717812	et	4	main
aitab	doc_542009824739_item	2717813	et	3	main
inimestel	doc_542009824739_item	2717814	et	3	main
olla	doc_542009824739_item	2717815	et	3	main
koos	doc_542009824739_item	2717816	et	4	main
ja	doc_542009824739_item	2717817	et	3	main
hoida	doc_542009824739_item	2717818	et	3	main
nii	doc_542009824739_item	2717819	et	3	main
oma	doc_542009824739_item	2717820	et	4	main
vastus	doc_542009824740_item	2717826	et	3	main
kas	doc_542009824740_item	2717836	et	3	main
inimene	doc_542009824740_item	2717841	et	3	main
ei	doc_542009824740_item	2717843	et	4	main
mulle	doc_542009824740_item	2717844	et	4	main
tuleb	doc_542009824740_item	2717845	et	3	main
meelde	doc_542009824740_item	2717846	et	3	main
kuidas	doc_542009824740_item	2717847	et	3	main
kultuurne	doc_542009824740_item	2717848	et	3	main
inimene	doc_542009824740_item	2717849	et	3	main
n	doc_542009824740_item	2717854	et	4	main
kultuur	doc_542009824740_item	2717858	et	3	main
keel	doc_542009824740_item	2717901	et	4	main
kaotab	doc_542009824740_item	2717902	et	3	main
riigis	doc_542009824739_item	2717824	et	3	main
küsimusele	doc_542009824740_item	2717827	et	4	main
hakkan	doc_542009824740_item	2717834	et	3	main
peab	doc_542009824740_item	2717850	et	4	main
ja	doc_542009824740_item	2717853	et	3	main
2	doc_542009824740_item	2717865	et	2	main
eesti	doc_542009824740_item	2717866	et	4	main
kultuur	doc_542009824740_item	2717867	et	3	main
tähendab	doc_542009824740_item	2717868	et	3	main
rahvakultuur	doc_542009824740_item	2717869	et	3	main
rahvalooming	doc_542009824740_item	2717870	et	3	main
tulevad	doc_542009824740_item	2717871	et	4	main
meelde	doc_542009824740_item	2717872	et	3	main
tuntuvad	doc_542009824740_item	2717873	et	4	main
eesti	doc_542009824740_item	2717874	et	4	main
kirjanikud	doc_542009824740_item	2717875	et	3	main
luuletajad	doc_542009824740_item	2717876	et	4	main
peame	doc_542009824740_item	2717877	et	4	main
hoidma	doc_542009824740_item	2717878	et	3	main
eesti	doc_542009824740_item	2717879	et	4	main
kultuur	doc_542009824740_item	2717880	et	3	main
sest	doc_542009824740_item	2717881	et	4	main
eestlased	doc_542009824740_item	2717882	et	3	main
on	doc_542009824740_item	2717883	et	4	main
väike	doc_542009824740_item	2717884	et	4	main
rahvas	doc_542009824740_item	2717885	et	4	main
mu	doc_542009824740_item	2717888	et	3	main
astusime	doc_542009824740_item	2717890	et	3	main
kardan	doc_542009824740_item	2717895	et	4	main
kultuur	doc_542009824742_item	2718022	et	3	main
1	doc_542009824742_item	2718025	et	2	main
kultuuridest	doc_542009824742_item	2718026	et	3	main
palju	doc_542009824742_item	2718029	et	4	main
aga	doc_542009824742_item	2718031	et	3	main
arenemisega	doc_542009824742_item	2718039	et	4	main
kombedest	doc_542009824742_item	2718053	et	4	main
et	doc_542009824742_item	2718066	et	3	main
eestlastel	doc_542009824742_item	2718067	et	4	main
on	doc_542009824742_item	2718070	et	4	main
tegelikult	doc_542009824742_item	2718087	et	4	main
mina	doc_542009824742_item	2718088	et	4	main
venelane	doc_542009824742_item	2718089	et	3	main
saan	doc_542009824742_item	2718090	et	4	main
aru	doc_542009824742_item	2718096	et	4	main
mõne	doc_542009824742_item	2718105	et	3	main
ara	doc_542009824742_item	2718107	et	3	main
saada	doc_542009824742_item	2718108	et	4	main
näiteks	doc_542009824742_item	2718109	et	4	main
anekdoote	doc_542009824742_item	2718110	et	3	main
sõna	doc_542009824744_item	2718243	et	4	main
kultuur	doc_542009824744_item	2718244	et	3	main
ma	doc_542009824744_item	2718245	et	3	main
kujutan	doc_542009824744_item	2718246	et	3	main
muusika	doc_542009824744_item	2718251	et	4	main
meelde	doc_542009824744_item	2718256	et	3	main
paljude	doc_542009824744_item	2718277	et	3	main
on	doc_542009824744_item	2718294	et	4	main
laulupeod	doc_542009824744_item	2718300	et	4	main
lauluväljakul	doc_542009824744_item	2718301	et	3	main
on	doc_542009824740_item	2717887	et	4	main
ma	doc_542009824740_item	2717894	et	3	main
et	doc_542009824740_item	2717896	et	3	main
eesti	doc_542009824740_item	2717900	et	4	main
vastus	doc_542009824742_item	2718014	et	3	main
küsimusele	doc_542009824742_item	2718015	et	4	main
mida	doc_542009824742_item	2718016	et	4	main
te	doc_542009824742_item	2718017	et	4	main
mõtlete	doc_542009824742_item	2718018	et	3	main
kui	doc_542009824742_item	2718019	et	3	main
kuulete	doc_542009824742_item	2718020	et	4	main
väga	doc_542009824742_item	2718028	et	3	main
arvates	doc_542009824742_item	2718033	et	4	main
on	doc_542009824742_item	2718035	et	4	main
seotud	doc_542009824742_item	2718036	et	4	main
traditsioonidega	doc_542009824742_item	2718040	et	3	main
oma	doc_542009824742_item	2718044	et	4	main
mis	doc_542009824742_item	2718046	et	4	main
tekkimisest	doc_542009824742_item	2718051	et	4	main
rohkem	doc_542009824742_item	2718071	et	4	main
või	doc_542009824742_item	2718076	et	4	main
kopeeritud	doc_542009824742_item	2718077	et	4	main
eesti	doc_542009824742_item	2718081	et	4	main
on	doc_542009824742_item	2718083	et	4	main
huvitav	doc_542009824742_item	2718085	et	4	main
mitte	doc_542009824742_item	2718095	et	3	main
selles	doc_542009824742_item	2718098	et	4	main
et	doc_542009824742_item	2718100	et	3	main
elu	doc_542009824742_item	2718119	et	4	main
inimese	doc_542009824742_item	2718037	et	4	main
rahvastel	doc_542009824742_item	2718042	et	4	main
ja	doc_542009824742_item	2718052	et	3	main
on	doc_542009824742_item	2718057	et	4	main
väga	doc_542009824742_item	2718058	et	3	main
teistest	doc_542009824742_item	2718059	et	4	main
kultuuridest	doc_542009824742_item	2718060	et	3	main
erinev	doc_542009824742_item	2718061	et	4	main
sellega	doc_542009824742_item	2718062	et	3	main
ma	doc_542009824742_item	2718063	et	3	main
ise	doc_542009824742_item	2718072	et	4	main
mingi	doc_542009824742_item	2718078	et	4	main
kultuur	doc_542009824742_item	2718082	et	3	main
väga	doc_542009824742_item	2718084	et	3	main
aga	doc_542009824742_item	2718086	et	3	main
aga	doc_542009824742_item	2718094	et	3	main
mulle	doc_542009824742_item	2718101	et	4	main
aga	doc_542009824742_item	2718111	et	3	main
see	doc_542009824742_item	2718112	et	3	main
ongi	doc_542009824742_item	2718113	et	4	main
see	doc_542009824742_item	2718114	et	3	main
kultuur	doc_542009824742_item	2718115	et	3	main
meie	doc_542009824742_item	2718118	et	4	main
huvitamaks	doc_542009824742_item	2718120	et	3	main
või	doc_542009824744_item	2718252	et	4	main
tuleb	doc_542009824744_item	2718255	et	3	main
ajalugu	doc_542009824744_item	2718257	et	4	main
2	doc_542009824744_item	2718271	et	2	main
nimedega	doc_542009824744_item	2718279	et	3	main
krewtzwald	doc_542009824744_item	2718281	et	4	main
ernesaks	doc_542009824744_item	2718285	et	4	main
jne	doc_542009824744_item	2718287	et	4	main
meie	doc_542009824744_item	2718295	et	4	main
ühiskond	doc_542009824746_item	2718424	et	3	main
ajalugu	doc_542009824746_item	2718426	et	4	main
see	doc_542009824746_item	2718434	et	3	main
pärit	doc_542009824746_item	2718448	et	3	main
kõik	doc_542009824746_item	2718451	et	4	main
inimesed	doc_542009824746_item	2718453	et	3	main
külad	doc_542009824746_item	2718460	et	3	main
rahva	doc_542009824746_item	2718461	et	3	main
riietus	doc_542009824746_item	2718463	et	4	main
ja	doc_542009824746_item	2718466	et	3	main
eesti	doc_542009824746_item	2718470	et	4	main
kaidi	doc_542009824747_item	2718505	et	4	main
kuidas	doc_542009824747_item	2718506	et	3	main
oli	doc_542009824747_item	2718507	et	3	main
moodne	doc_542009824747_item	2718508	et	3	main
informatsioone	doc_542009824742_item	2718049	et	3	main
linna	doc_542009824742_item	2718050	et	4	main
2	doc_542009824742_item	2718054	et	2	main
kultuur	doc_542009824742_item	2718056	et	3	main
öelda	doc_542009824742_item	2718065	et	4	main
tehtud	doc_542009824742_item	2718073	et	4	main
mitte	doc_542009824742_item	2718074	et	3	main
võetud	doc_542009824742_item	2718075	et	4	main
rahvastega	doc_542009824742_item	2718080	et	4	main
raske	doc_542009824742_item	2718104	et	4	main
teeb	doc_542009824742_item	2718117	et	3	main
väga	doc_542009824742_item	2718103	et	3	main
aju	doc_542009824742_item	2718106	et	4	main
mis	doc_542009824742_item	2718116	et	4	main
vastus	doc_542009824744_item	2718237	et	3	main
küsimusele	doc_542009824744_item	2718238	et	4	main
1	doc_542009824744_item	2718239	et	2	main
kui	doc_542009824744_item	2718240	et	3	main
ma	doc_542009824744_item	2718241	et	3	main
kuulen	doc_542009824744_item	2718242	et	3	main
kunst	doc_542009824744_item	2718253	et	3	main
eesti	doc_542009824744_item	2718272	et	4	main
kultuur	doc_542009824744_item	2718273	et	3	main
minu	doc_542009824744_item	2718274	et	3	main
meeles	doc_542009824744_item	2718275	et	3	main
seotud	doc_542009824744_item	2718276	et	4	main
näiteks	doc_542009824744_item	2718280	et	4	main
koidula	doc_542009824744_item	2718282	et	4	main
luts	doc_542009824744_item	2718283	et	3	main
aga	doc_542009824744_item	2718288	et	3	main
ja	doc_542009824744_item	2718298	et	3	main
meie	doc_542009824746_item	2718425	et	4	main
inimese	doc_542009824746_item	2718427	et	4	main
käitumise	doc_542009824746_item	2718428	et	4	main
kultuur	doc_542009824746_item	2718429	et	3	main
2	doc_542009824746_item	2718430	et	2	main
kunstnikud	doc_542009824746_item	2718442	et	3	main
heliloojad	doc_542009824746_item	2718443	et	3	main
poeedid	doc_542009824746_item	2718444	et	3	main
kirjanikud	doc_542009824746_item	2718445	et	3	main
kes	doc_542009824746_item	2718446	et	4	main
kultuuri	doc_542009824746_item	2718457	et	4	main
arengus	doc_542009824746_item	2718458	et	3	main
toit	doc_542009824746_item	2718462	et	3	main
kaunistused	doc_542009824746_item	2718464	et	4	main
sümboleid	doc_542009824746_item	2718465	et	3	main
vanasti	doc_542009824747_item	2718503	et	3	main
riides	doc_542009824747_item	2718504	et	4	main
arvan	doc_542009824747_item	2718512	et	3	main
kõige	doc_542009824747_item	2718514	et	4	main
esimesel	doc_542009824747_item	2718518	et	3	main
hetkel	doc_542009824747_item	2718519	et	4	main
meelde	doc_542009824747_item	2718520	et	3	main
ette	doc_542009824744_item	2718247	et	4	main
mingisugust	doc_542009824744_item	2718248	et	3	main
väärtust	doc_542009824744_item	2718249	et	4	main
näiteks	doc_542009824744_item	2718250	et	4	main
ja	doc_542009824744_item	2718258	et	3	main
üldse	doc_542009824744_item	2718259	et	3	main
tsivilisatioon	doc_542009824744_item	2718260	et	4	main
veel	doc_542009824744_item	2718261	et	4	main
kultuuri	doc_542009824744_item	2718262	et	4	main
osad	doc_542009824744_item	2718263	et	3	main
on	doc_542009824744_item	2718264	et	4	main
ka	doc_542009824744_item	2718265	et	3	main
teater	doc_542009824744_item	2718266	et	3	main
kino	doc_542009824744_item	2718267	et	4	main
ja	doc_542009824744_item	2718268	et	3	main
muidugi	doc_542009824744_item	2718269	et	4	main
kirjandus	doc_542009824744_item	2718270	et	3	main
veel	doc_542009824744_item	2718254	et	4	main
gustav	doc_542009824744_item	2718284	et	4	main
kalevipoeg	doc_542009824744_item	2718297	et	3	main
meie	doc_542009824746_item	2718423	et	4	main
eesti	doc_542009824746_item	2718431	et	4	main
kultuur	doc_542009824746_item	2718432	et	3	main
on	doc_542009824746_item	2718435	et	4	main
minu	doc_542009824746_item	2718436	et	3	main
jaoks	doc_542009824746_item	2718437	et	4	main
inimeste	doc_542009824746_item	2718438	et	3	main
mentaliteet	doc_542009824746_item	2718439	et	3	main
riigi	doc_542009824746_item	2718440	et	3	main
areng	doc_542009824746_item	2718441	et	3	main
eestist	doc_542009824746_item	2718449	et	3	main
osalised	doc_542009824746_item	2718455	et	4	main
eesti	doc_542009824746_item	2718456	et	4	main
keel	doc_542009824746_item	2718471	et	4	main
kuidas	doc_542009824747_item	2718502	et	3	main
mulgi	doc_542009824747_item	2718525	et	4	main
on	doc_542009824747_item	2718532	et	4	main
praegu	doc_542009824747_item	2718533	et	3	main
silme	doc_542009824747_item	2718534	et	4	main
ees	doc_542009824747_item	2718535	et	4	main
vargamäe	doc_542009824747_item	2718543	et	3	main
iluga	doc_542009824747_item	2718549	et	3	main
tumedates	doc_542009824747_item	2718551	et	3	main
vastus	doc_542009824748_item	2718553	et	3	main
1	doc_542009824748_item	2718556	et	2	main
mida	doc_542009824748_item	2718557	et	4	main
sõna	doc_542009824748_item	2718562	et	4	main
minu	doc_542009824748_item	2718565	et	3	main
ajaloost	doc_542009824748_item	2718581	et	4	main
tsivilisatsioonist	doc_542009824748_item	2718583	et	3	main
inimesed	doc_542009824748_item	2718585	et	3	main
rahvaomapärasusega	doc_542009824748_item	2718605	et	4	main
see	doc_542009824748_item	2718606	et	3	main
kui	doc_542009824748_item	2718621	et	3	main
eesti	doc_542009824744_item	2718278	et	4	main
tammsaare	doc_542009824744_item	2718286	et	3	main
muidugi	doc_542009824744_item	2718289	et	4	main
esimene	doc_542009824744_item	2718290	et	3	main
assotsiatsioon	doc_542009824744_item	2718291	et	3	main
minu	doc_542009824744_item	2718292	et	3	main
arvates	doc_542009824744_item	2718293	et	4	main
rahvuseepos	doc_542009824744_item	2718296	et	3	main
kuulsamad	doc_542009824744_item	2718299	et	4	main
maailma	doc_542009824746_item	2718421	et	4	main
vastus	doc_542009824746_item	2718416	et	3	main
küsimusele	doc_542009824746_item	2718417	et	4	main
1	doc_542009824746_item	2718418	et	2	main
kultuur	doc_542009824746_item	2718419	et	3	main
areng	doc_542009824746_item	2718420	et	3	main
ja	doc_542009824746_item	2718450	et	3	main
need	doc_542009824746_item	2718452	et	3	main
kes	doc_542009824746_item	2718454	et	4	main
väikesed	doc_542009824746_item	2718459	et	4	main
eesti	doc_542009824746_item	2718468	et	4	main
vastus	doc_542009824747_item	2718472	et	3	main
kultuur	doc_542009824747_item	2718511	et	3	main
on	doc_542009824747_item	2718521	et	4	main
pärast	doc_542009824747_item	2718531	et	4	main
koidula	doc_542009824747_item	2718537	et	4	main
tallinna	doc_542009824747_item	2718546	et	4	main
küsimusele	doc_542009824748_item	2718554	et	4	main
kultuur	doc_542009824748_item	2718555	et	3	main
1	doc_542009824748_item	2718564	et	2	main
osa	doc_542009824748_item	2718599	et	4	main
elus	doc_542009824748_item	2718601	et	4	main
saavad	doc_542009824748_item	2718642	et	4	main
uhke	doc_542009824748_item	2718644	et	4	main
eesti	doc_542009824748_item	2718654	et	4	main
laulufestivaalidest	doc_542009824748_item	2718660	et	4	main
mul	doc_542009824748_item	2718661	et	3	main
lilli	doc_542009824748_item	2718671	et	4	main
keeles	doc_542009824748_item	2718678	et	4	main
arfitektuur	doc_542009824746_item	2718422	et	4	main
esmakordselt	doc_542009824746_item	2718433	et	4	main
on	doc_542009824746_item	2718447	et	4	main
lipp	doc_542009824746_item	2718467	et	3	main
ajalugu	doc_542009824746_item	2718469	et	4	main
küsimusele	doc_542009824747_item	2718473	et	4	main
kultuur	doc_542009824747_item	2718474	et	3	main
hakkan	doc_542009824747_item	2718475	et	3	main
kohe	doc_542009824747_item	2718476	et	4	main
mõtlema	doc_542009824747_item	2718477	et	3	main
kreeka	doc_542009824747_item	2718478	et	4	main
kultuuri	doc_542009824747_item	2718479	et	4	main
sünnist	doc_542009824747_item	2718480	et	4	main
siis	doc_542009824747_item	2718481	et	3	main
peas	doc_542009824747_item	2718482	et	4	main
keerleb	doc_542009824747_item	2718483	et	3	main
kuidas	doc_542009824747_item	2718484	et	3	main
tekkis	doc_542009824747_item	2718485	et	3	main
kiri	doc_542009824747_item	2718486	et	3	main
mingi	doc_542009824747_item	2718487	et	4	main
rahva	doc_542009824747_item	2718488	et	3	main
oma	doc_542009824747_item	2718489	et	4	main
raamatud	doc_542009824747_item	2718490	et	4	main
laua	doc_542009824747_item	2718491	et	3	main
peal	doc_542009824747_item	2718492	et	4	main
sümboliseerivad	doc_542009824747_item	2718494	et	4	main
ilmset	doc_542009824747_item	2718493	et	3	main
minu	doc_542009824747_item	2718495	et	3	main
jaoks	doc_542009824747_item	2718496	et	4	main
rahvaluulet	doc_542009824747_item	2718497	et	3	main
poeesiat	doc_542009824747_item	2718498	et	3	main
huvitav	doc_542009824747_item	2718499	et	4	main
oleks	doc_542009824747_item	2718500	et	3	main
teada	doc_542009824747_item	2718501	et	3	main
keeleuurimused	doc_542009824747_item	2718509	et	3	main
et	doc_542009824747_item	2718513	et	3	main
rahva	doc_542009824747_item	2718522	et	3	main
mis	doc_542009824747_item	2718527	et	4	main
rahvatoiduks	doc_542009824747_item	2718529	et	3	main
millegi	doc_542009824747_item	2718530	et	4	main
lydia	doc_542009824747_item	2718536	et	4	main
suitsusaun	doc_542009824747_item	2718544	et	3	main
kogu	doc_542009824747_item	2718548	et	4	main
aga	doc_542009824747_item	2718550	et	3	main
värvides	doc_542009824747_item	2718552	et	4	main
kuulete	doc_542009824748_item	2718561	et	4	main
traditsioonid	doc_542009824748_item	2718572	et	3	main
kui	doc_542009824748_item	2718574	et	3	main
ja	doc_542009824748_item	2718582	et	3	main
kohustuslik	doc_542009824748_item	2718598	et	3	main
kultuur	doc_542009824748_item	2718602	et	3	main
kuulete	doc_542009824748_item	2718622	et	4	main
1	doc_542009824748_item	2718626	et	2	main
eesti	doc_542009824748_item	2718631	et	4	main
mõtlen	doc_542009824748_item	2718634	et	3	main
meeles	doc_542009824748_item	2718640	et	3	main
kultuuri	doc_542009824748_item	2718646	et	4	main
sõna	doc_542009824748_item	2718653	et	4	main
oskar	doc_542009824748_item	2718666	et	4	main
luts	doc_542009824748_item	2718667	et	3	main
ja	doc_542009824748_item	2718668	et	3	main
mulle	doc_542009824748_item	2718669	et	4	main
meeldib	doc_542009824748_item	2718670	et	3	main
vene	doc_542009824748_item	2718677	et	4	main
huvitav	doc_542009824750_item	2718839	et	4	main
see	doc_542009824750_item	2718841	et	3	main
mänguasja	doc_542009824750_item	2718847	et	4	main
nimi	doc_542009824750_item	2718848	et	3	main
teddyl	doc_542009824750_item	2718859	et	4	main
ei	doc_542009824750_item	2718873	et	4	main
on	doc_542009824750_item	2718880	et	4	main
teddy	doc_542009824750_item	2718883	et	4	main
kõik	doc_542009824750_item	2718885	et	4	main
sõbral	doc_542009824750_item	2718887	et	3	main
ilus	doc_542009824751_item	2718897	et	4	main
on	doc_542009824751_item	2718900	et	4	main
kadakast	doc_542009824751_item	2718902	et	4	main
signe	doc_542009824751_item	2718922	et	4	main
on	doc_542009824751_item	2718923	et	4	main
inimese	doc_542009824751_item	2718924	et	4	main
perekonnanimi	doc_542009824751_item	2718925	et	3	main
hiiumaa	doc_542009824751_item	2718932	et	4	main
2006	doc_542009824751_item	2718933	et	2	main
see	doc_542009824751_item	2718936	et	3	main
toodud	doc_542009824751_item	2718938	et	4	main
see	doc_542009824751_item	2718942	et	3	main
vaga	doc_542009824751_item	2718944	et	4	main
eesti	doc_542009824747_item	2718510	et	4	main
tüüpilisem	doc_542009824747_item	2718515	et	4	main
mis	doc_542009824747_item	2718516	et	4	main
tuleb	doc_542009824747_item	2718517	et	3	main
eestlaste	doc_542009824747_item	2718524	et	4	main
kapsas	doc_542009824747_item	2718526	et	4	main
on	doc_542009824747_item	2718528	et	4	main
saaremaal	doc_542009824747_item	2718545	et	4	main
vanalinn	doc_542009824747_item	2718547	et	3	main
kultuur	doc_542009824748_item	2718563	et	3	main
arvates	doc_542009824748_item	2718566	et	4	main
on	doc_542009824748_item	2718568	et	4	main
tavad	doc_542009824748_item	2718570	et	3	main
ja	doc_542009824748_item	2718571	et	3	main
2	doc_542009824748_item	2718573	et	2	main
kuulen	doc_542009824748_item	2718576	et	3	main
kultuur	doc_542009824748_item	2718578	et	3	main
ma	doc_542009824748_item	2718579	et	3	main
elasid	doc_542009824748_item	2718586	et	4	main
tol	doc_542009824748_item	2718587	et	3	main
ajal	doc_542009824748_item	2718588	et	4	main
nad	doc_542009824748_item	2718590	et	3	main
inimeste	doc_542009824748_item	2718600	et	3	main
alati	doc_542009824748_item	2718603	et	4	main
seotud	doc_542009824748_item	2718604	et	4	main
kultuur	doc_542009824748_item	2718625	et	3	main
ma	doc_542009824748_item	2718628	et	3	main
sõna	doc_542009824748_item	2718630	et	4	main
kultuur	doc_542009824748_item	2718632	et	3	main
eesti	doc_542009824748_item	2718635	et	4	main
kirjanikutest	doc_542009824748_item	2718636	et	3	main
ja	doc_542009824748_item	2718637	et	3	main
kunstnikutest	doc_542009824748_item	2718638	et	3	main
minu	doc_542009824748_item	2718639	et	3	main
olema	doc_542009824748_item	2718643	et	4	main
oma	doc_542009824748_item	2718663	et	4	main
lemmik	doc_542009824748_item	2718664	et	3	main
mina	doc_542009824748_item	2718673	et	4	main
lugesin	doc_542009824748_item	2718674	et	3	main
nende	doc_542009824748_item	2718675	et	4	main
raamatuid	doc_542009824748_item	2718676	et	3	main
on	doc_542009824750_item	2718837	et	4	main
mänguasi	doc_542009824750_item	2718840	et	3	main
on	doc_542009824750_item	2718842	et	4	main
riided	doc_542009824750_item	2718844	et	3	main
see	doc_542009824750_item	2718845	et	3	main
on	doc_542009824750_item	2718846	et	4	main
teddy	doc_542009824750_item	2718851	et	4	main
midagi	doc_542009824750_item	2718857	et	4	main
joonistatud	doc_542009824750_item	2718858	et	4	main
silmad	doc_542009824750_item	2718860	et	4	main
on	doc_542009824750_item	2718861	et	4	main
väga	doc_542009824750_item	2718862	et	3	main
mänguasi	doc_542009824750_item	2718867	et	3	main
nii	doc_542009824750_item	2718869	et	3	main
tea	doc_542009824750_item	2718874	et	4	main
maksab	doc_542009824750_item	2718877	et	3	main
armastab	doc_542009824750_item	2718884	et	3	main
minul	doc_542009824750_item	2718886	et	3	main
ja	doc_542009824751_item	2718899	et	3	main
tehtud	doc_542009824751_item	2718901	et	4	main
tantsud	doc_542009824747_item	2718523	et	3	main
portree	doc_542009824747_item	2718538	et	4	main
ka	doc_542009824747_item	2718539	et	3	main
tammsaare	doc_542009824747_item	2718540	et	3	main
raamatu	doc_542009824747_item	2718541	et	4	main
pealkiri	doc_542009824747_item	2718542	et	3	main
te	doc_542009824748_item	2718558	et	4	main
mõtlete	doc_542009824748_item	2718559	et	3	main
kui	doc_542009824748_item	2718560	et	3	main
see	doc_542009824748_item	2718567	et	3	main
inimeste	doc_542009824748_item	2718569	et	3	main
ma	doc_542009824748_item	2718575	et	3	main
sõna	doc_542009824748_item	2718577	et	4	main
mõtlen	doc_542009824748_item	2718580	et	3	main
kuidas	doc_542009824748_item	2718584	et	3	main
millega	doc_542009824748_item	2718589	et	3	main
tegelesid	doc_542009824748_item	2718591	et	4	main
ma	doc_542009824748_item	2718592	et	3	main
arvan	doc_542009824748_item	2718593	et	3	main
et	doc_542009824748_item	2718594	et	3	main
kultuur	doc_542009824748_item	2718595	et	3	main
see	doc_542009824748_item	2718596	et	3	main
on	doc_542009824748_item	2718597	et	4	main
on	doc_542009824748_item	2718607	et	4	main
oluline	doc_542009824748_item	2718608	et	4	main
veel	doc_542009824748_item	2718609	et	4	main
ma	doc_542009824748_item	2718610	et	3	main
meenutan	doc_542009824748_item	2718611	et	3	main
kultuursetest	doc_542009824748_item	2718612	et	4	main
inimestest	doc_542009824748_item	2718613	et	3	main
intelligentsusest	doc_542009824748_item	2718614	et	4	main
ja	doc_542009824748_item	2718615	et	3	main
etikeedist	doc_542009824748_item	2718616	et	4	main
1	doc_542009824748_item	2718617	et	2	main
mida	doc_542009824748_item	2718618	et	4	main
mõtlete	doc_542009824748_item	2718620	et	3	main
te	doc_542009824748_item	2718619	et	4	main
sõna	doc_542009824748_item	2718623	et	4	main
kuulen	doc_542009824748_item	2718629	et	3	main
ma	doc_542009824748_item	2718633	et	3	main
oma	doc_542009824748_item	2718645	et	4	main
on	doc_542009824748_item	2718662	et	4	main
promet	doc_542009824748_item	2718672	et	4	main
eesti	doc_542009824748_item	2718624	et	4	main
kui	doc_542009824748_item	2718627	et	3	main
eestlased	doc_542009824748_item	2718641	et	3	main
traditsioonide	doc_542009824748_item	2718647	et	3	main
eest	doc_542009824748_item	2718648	et	4	main
veel	doc_542009824748_item	2718649	et	4	main
kui	doc_542009824748_item	2718650	et	3	main
ma	doc_542009824748_item	2718651	et	3	main
kuulen	doc_542009824748_item	2718652	et	3	main
kultuur	doc_542009824748_item	2718655	et	3	main
ma	doc_542009824748_item	2718656	et	3	main
meenutan	doc_542009824748_item	2718657	et	3	main
tantsu	doc_542009824748_item	2718658	et	4	main
ja	doc_542009824748_item	2718659	et	3	main
kirjanik	doc_542009824748_item	2718665	et	3	main
essee	doc_542009824750_item	2718832	et	4	main
see	doc_542009824750_item	2718833	et	3	main
on	doc_542009824750_item	2718834	et	4	main
mänguasi	doc_542009824750_item	2718835	et	3	main
tehtud	doc_542009824750_item	2718843	et	4	main
temale	doc_542009824750_item	2718855	et	3	main
rõmsad	doc_542009824750_item	2718863	et	4	main
ja	doc_542009824750_item	2718864	et	3	main
et	doc_542009824750_item	2718871	et	3	main
minu	doc_542009824750_item	2718881	et	3	main
omal	doc_542009824750_item	2718882	et	3	main
see	doc_542009824751_item	2718892	et	3	main
on	doc_542009824751_item	2718893	et	4	main
märk	doc_542009824751_item	2718894	et	3	main
see	doc_542009824751_item	2718895	et	3	main
on	doc_542009824751_item	2718896	et	4	main
sõna	doc_542009824751_item	2718921	et	4	main
suveniir	doc_542009824751_item	2718929	et	3	main
ja	doc_542009824751_item	2718930	et	3	main
sõna	doc_542009824751_item	2718931	et	4	main
kust	doc_542009824751_item	2718935	et	4	main
on	doc_542009824751_item	2718937	et	4	main
ja	doc_542009824751_item	2718939	et	3	main
ajal	doc_542009824751_item	2718941	et	4	main
vaja	doc_542009824751_item	2718958	et	4	main
kaelas	doc_542009824751_item	2718960	et	4	main
ja	doc_542009824751_item	2718961	et	3	main
meenutab	doc_542009824751_item	2718963	et	3	main
sugulastest	doc_542009824751_item	2718964	et	4	main
ja	doc_542009824751_item	2718965	et	3	main
sõbradest	doc_542009824751_item	2718966	et	4	main
märk	doc_542009824751_item	2718967	et	3	main
ühe	doc_542009824752_item	2718972	et	4	main
eseme	doc_542009824752_item	2718973	et	3	main
on	doc_542009824752_item	2718976	et	4	main
ma	doc_542009824752_item	2718982	et	3	main
tea	doc_542009824752_item	2718984	et	4	main
palju	doc_542009824752_item	2718986	et	4	main
see	doc_542009824752_item	2718987	et	3	main
on	doc_542009824752_item	2718988	et	4	main
sõrmus	doc_542009824752_item	2718989	et	3	main
jah	doc_542009824752_item	2718990	et	3	main
see	doc_542009824752_item	2718991	et	3	main
on	doc_542009824752_item	2718997	et	4	main
esse	doc_542009824752_item	2719003	et	3	main
tehtub	doc_542009824753_item	2719026	et	4	main
hõbe	doc_542009824753_item	2719027	et	3	main
see	doc_542009824753_item	2719028	et	3	main
asi	doc_542009824753_item	2719029	et	4	main
värv	doc_542009824753_item	2719030	et	3	main
lüsikas	doc_542009824753_item	2719045	et	4	main
oli	doc_542009824753_item	2719046	et	3	main
maksab	doc_542009824753_item	2719053	et	3	main
kasutatub	doc_542009824753_item	2719068	et	4	main
minu	doc_542009824753_item	2719069	et	3	main
te	doc_542009824754_item	2719116	et	4	main
see	doc_542009824750_item	2718836	et	3	main
on	doc_542009824750_item	2718849	et	4	main
mitte	doc_542009824750_item	2718856	et	3	main
maksab	doc_542009824750_item	2718868	et	3	main
palju	doc_542009824750_item	2718870	et	4	main
kui	doc_542009824750_item	2718875	et	3	main
tõsisel	doc_542009824750_item	2718878	et	4	main
teddy	doc_542009824750_item	2718879	et	4	main
essee	doc_542009824751_item	2718888	et	4	main
ühe	doc_542009824751_item	2718889	et	4	main
eseme	doc_542009824751_item	2718890	et	3	main
see	doc_542009824751_item	2718903	et	3	main
on	doc_542009824751_item	2718904	et	4	main
valge	doc_542009824751_item	2718905	et	4	main
ja	doc_542009824751_item	2718906	et	3	main
pruuni	doc_542009824751_item	2718907	et	4	main
värvi	doc_542009824751_item	2718908	et	4	main
sellel	doc_542009824751_item	2718909	et	4	main
märgil	doc_542009824751_item	2718910	et	3	main
on	doc_542009824751_item	2718911	et	4	main
kirjutatud	doc_542009824751_item	2718912	et	4	main
hiiumaa	doc_542009824751_item	2718913	et	4	main
2006	doc_542009824751_item	2718914	et	2	main
sinise	doc_542009824751_item	2718915	et	4	main
värvi	doc_542009824751_item	2718916	et	4	main
ja	doc_542009824751_item	2718917	et	3	main
signe	doc_542009824751_item	2718918	et	4	main
punase	doc_542009824751_item	2718919	et	4	main
värvi	doc_542009824751_item	2718920	et	4	main
kes	doc_542009824751_item	2718926	et	4	main
millisel	doc_542009824751_item	2718940	et	3	main
sugulastelt	doc_542009824751_item	2718950	et	4	main
kes	doc_542009824751_item	2718951	et	4	main
vormi	doc_542009824751_item	2718970	et	4	main
essee	doc_542009824752_item	2718971	et	4	main
minu	doc_542009824752_item	2718977	et	3	main
tehtud	doc_542009824752_item	2718979	et	4	main
ei	doc_542009824752_item	2718983	et	4	main
kui	doc_542009824752_item	2718985	et	3	main
kallis	doc_542009824752_item	2718994	et	4	main
ring	doc_542009824752_item	2719001	et	3	main
ma	doc_542009824752_item	2719007	et	3	main
lüsikas	doc_542009824753_item	2719023	et	4	main
todud	doc_542009824753_item	2719042	et	4	main
finland	doc_542009824753_item	2719043	et	4	main
see	doc_542009824753_item	2719044	et	3	main
minule	doc_542009824753_item	2719048	et	3	main
selle	doc_542009824753_item	2719050	et	4	main
euro	doc_542009824753_item	2719055	et	4	main
kaaluga	doc_542009824753_item	2719062	et	3	main
teise	doc_542009824753_item	2719074	et	4	main
see	doc_542009824753_item	2719076	et	3	main
võtmehoidja	doc_542009824754_item	2719112	et	4	main
epfeli	doc_542009824754_item	2719114	et	4	main
toru	doc_542009824754_item	2719115	et	4	main
ja	doc_542009824754_item	2719121	et	3	main
kaalub	doc_542009824754_item	2719123	et	3	main
grammid	doc_542009824754_item	2719125	et	3	main
tema	doc_542009824754_item	2719126	et	4	main
kerge	doc_542009824754_item	2719127	et	4	main
ja	doc_542009824754_item	2719128	et	3	main
mugav	doc_542009824754_item	2719129	et	3	main
minu	doc_542009824754_item	2719130	et	3	main
välismaale	doc_542009824754_item	2719134	et	4	main
väga	doc_542009824750_item	2718838	et	3	main
teddy	doc_542009824750_item	2718850	et	4	main
värv	doc_542009824750_item	2718852	et	3	main
on	doc_542009824750_item	2718853	et	4	main
valge-kollane	doc_542009824750_item	2718854	et	4	main
ilusad	doc_542009824750_item	2718865	et	3	main
see	doc_542009824750_item	2718866	et	3	main
ma	doc_542009824750_item	2718872	et	3	main
palju	doc_542009824750_item	2718876	et	4	main
lugu	doc_542009824751_item	2718891	et	4	main
suveniir	doc_542009824751_item	2718898	et	3	main
tähtsab	doc_542009824751_item	2718934	et	4	main
kingitus	doc_542009824751_item	2718949	et	4	main
on	doc_542009824751_item	2718957	et	4	main
ringane	doc_542009824751_item	2718969	et	4	main
lugu	doc_542009824752_item	2718974	et	4	main
hõbe	doc_542009824752_item	2718981	et	3	main
on	doc_542009824752_item	2718992	et	4	main
must	doc_542009824752_item	2718998	et	4	main
see	doc_542009824752_item	2719002	et	3	main
on	doc_542009824752_item	2719004	et	4	main
tahan	doc_542009824752_item	2719008	et	3	main
sai	doc_542009824751_item	2718927	et	4	main
selle	doc_542009824751_item	2718928	et	4	main
on	doc_542009824751_item	2718943	et	4	main
on	doc_542009824751_item	2718948	et	4	main
elavad	doc_542009824751_item	2718952	et	4	main
hiiumaa	doc_542009824751_item	2718953	et	4	main
saarel	doc_542009824751_item	2718954	et	3	main
see	doc_542009824751_item	2718955	et	3	main
ese	doc_542009824751_item	2718956	et	3	main
kanda	doc_542009824751_item	2718959	et	4	main
see	doc_542009824751_item	2718962	et	3	main
see	doc_542009824752_item	2718975	et	3	main
sõrmus	doc_542009824752_item	2718980	et	3	main
punane	doc_542009824752_item	2719000	et	4	main
et	doc_542009824752_item	2719006	et	3	main
näita	doc_542009824752_item	2719009	et	4	main
ta	doc_542009824752_item	2719010	et	4	main
on	doc_542009824752_item	2719011	et	4	main
ta	doc_542009824752_item	2719012	et	4	main
kalug	doc_542009824752_item	2719013	et	4	main
on	doc_542009824752_item	2719014	et	4	main
viis	doc_542009824752_item	2719015	et	4	main
kümend	doc_542009824752_item	2719016	et	4	main
grammi	doc_542009824752_item	2719017	et	4	main
essee	doc_542009824753_item	2719018	et	4	main
see	doc_542009824753_item	2719019	et	3	main
on	doc_542009824753_item	2719020	et	4	main
ilus	doc_542009824753_item	2719022	et	4	main
ta	doc_542009824753_item	2719024	et	4	main
on	doc_542009824753_item	2719025	et	4	main
joonistus	doc_542009824753_item	2719035	et	4	main
riigilipp	doc_542009824753_item	2719038	et	3	main
kinkitama	doc_542009824753_item	2719047	et	4	main
asta	doc_542009824753_item	2719051	et	4	main
on	doc_542009824753_item	2719057	et	4	main
väike	doc_542009824753_item	2719059	et	4	main
ja	doc_542009824753_item	2719060	et	3	main
on	doc_542009824753_item	2719061	et	4	main
kuuskümend	doc_542009824753_item	2719064	et	4	main
ta	doc_542009824753_item	2719071	et	4	main
söö	doc_542009824753_item	2719073	et	4	main
ese	doc_542009824753_item	2719077	et	3	main
metallist	doc_542009824754_item	2719110	et	4	main
on	doc_542009824754_item	2719118	et	4	main
tema	doc_542009824754_item	2719122	et	4	main
sõber	doc_542009824754_item	2719132	et	3	main
frantsusmaale	doc_542009824754_item	2719136	et	4	main
ese	doc_542009824754_item	2719144	et	3	main
võtsin	doc_542009824754_item	2719153	et	3	main
tema	doc_542009824754_item	2719156	et	4	main
rippus	doc_542009824754_item	2719171	et	3	main
selle	doc_542009824754_item	2719181	et	4	main
ilus	doc_542009824754_item	2719182	et	4	main
esed	doc_542009824754_item	2719197	et	4	main
kujuga	doc_542009824754_item	2719198	et	3	main
soovitan	doc_542009824754_item	2719202	et	3	main
essee	doc_542009824755_item	2719210	et	4	main
väiksem	doc_542009824755_item	2719226	et	4	main
formis	doc_542009824755_item	2719227	et	4	main
veel	doc_542009824755_item	2719236	et	4	main
meeldib	doc_542009824755_item	2719240	et	3	main
ja	doc_542009824755_item	2719250	et	3	main
ja	doc_542009824755_item	2719252	et	3	main
internetis	doc_542009824755_item	2719254	et	4	main
kuulan	doc_542009824755_item	2719256	et	3	main
muusika	doc_542009824755_item	2719257	et	4	main
ja	doc_542009824755_item	2719258	et	3	main
armastavad	doc_542009824755_item	2719263	et	4	main
kirjutada	doc_542009824755_item	2719264	et	3	main
väga	doc_542009824755_item	2719272	et	3	main
kerge	doc_542009824751_item	2718945	et	4	main
märk	doc_542009824751_item	2718946	et	3	main
see	doc_542009824751_item	2718947	et	3	main
on	doc_542009824751_item	2718968	et	4	main
sõrmus	doc_542009824752_item	2718978	et	3	main
sõrmus	doc_542009824752_item	2718993	et	3	main
kingitus	doc_542009824752_item	2718995	et	4	main
värvis	doc_542009824752_item	2718996	et	4	main
ja	doc_542009824752_item	2718999	et	3	main
siin	doc_542009824752_item	2719005	et	4	main
lüsikas	doc_542009824753_item	2719034	et	4	main
põder	doc_542009824753_item	2719036	et	3	main
lüsikas	doc_542009824753_item	2719040	et	4	main
oli	doc_542009824753_item	2719041	et	3	main
30	doc_542009824753_item	2719054	et	2	main
ümbes	doc_542009824753_item	2719063	et	4	main
graami	doc_542009824753_item	2719065	et	4	main
see	doc_542009824753_item	2719066	et	3	main
lüsikas	doc_542009824753_item	2719067	et	4	main
see	doc_542009824754_item	2719111	et	3	main
on	doc_542009824754_item	2719113	et	4	main
pruuni	doc_542009824754_item	2719119	et	4	main
värvi	doc_542009824754_item	2719120	et	4	main
sõitis	doc_542009824754_item	2719133	et	3	main
ja	doc_542009824754_item	2719137	et	3	main
seal	doc_542009824754_item	2719140	et	4	main
see	doc_542009824754_item	2719143	et	3	main
sellepärast	doc_542009824754_item	2719151	et	3	main
tasuta	doc_542009824754_item	2719154	et	4	main
veel	doc_542009824754_item	2719155	et	4	main
oma	doc_542009824754_item	2719159	et	4	main
sugulasedele	doc_542009824754_item	2719160	et	3	main
rõõmsad	doc_542009824754_item	2719169	et	3	main
pikkus	doc_542009824754_item	2719184	et	4	main
ma	doc_542009824754_item	2719192	et	3	main
ma	doc_542009824754_item	2719201	et	3	main
omada	doc_542009824754_item	2719204	et	3	main
ilus	doc_542009824754_item	2719206	et	4	main
mugav	doc_542009824754_item	2719208	et	3	main
võtmehoidja	doc_542009824754_item	2719209	et	4	main
mobiiltelefon	doc_542009824755_item	2719213	et	3	main
model	doc_542009824755_item	2719220	et	4	main
sellepärast	doc_542009824755_item	2719221	et	3	main
mugav	doc_542009824755_item	2719229	et	3	main
mulle	doc_542009824755_item	2719238	et	4	main
menüü	doc_542009824755_item	2719241	et	4	main
kasutan	doc_542009824755_item	2719243	et	3	main
mobiiltelefon	doc_542009824755_item	2719244	et	3	main
laialt	doc_542009824755_item	2719245	et	4	main
kirjutan	doc_542009824755_item	2719246	et	3	main
sõnumid	doc_542009824755_item	2719247	et	3	main
salvestan	doc_542009824755_item	2719248	et	3	main
radio	doc_542009824755_item	2719259	et	4	main
sõnumid	doc_542009824755_item	2719265	et	3	main
mulle	doc_542009824755_item	2719273	et	4	main
see	doc_542009824755_item	2719275	et	3	main
edasi	doc_542009824755_item	2719312	et	3	main
on	doc_542009824755_item	2719314	et	4	main
millal	doc_542009824755_item	2719317	et	3	main
kui	doc_542009824755_item	2719320	et	3	main
selge	doc_542009824755_item	2719334	et	4	main
tähtsem	doc_542009824756_item	2719340	et	4	main
oma	doc_542009824756_item	2719346	et	4	main
mobiiltelefoni	doc_542009824756_item	2719349	et	4	main
täna	doc_542009824756_item	2719351	et	4	main
tegeme	doc_542009824756_item	2719352	et	4	main
kasutada	doc_542009824756_item	2719362	et	3	main
kuulan	doc_542009824756_item	2719392	et	3	main
salvestada	doc_542009824756_item	2719399	et	3	main
ja	doc_542009824756_item	2719401	et	3	main
nimid	doc_542009824756_item	2719402	et	4	main
on	doc_542009824756_item	2719410	et	4	main
valitan	doc_542009824756_item	2719417	et	4	main
salvesta	doc_542009824756_item	2719422	et	4	main
telefoninumber	doc_542009824756_item	2719429	et	3	main
väga	doc_542009824756_item	2719435	et	3	main
kerge	doc_542009824756_item	2719438	et	4	main
et	doc_542009824756_item	2719439	et	3	main
mulle	doc_542009824756_item	2719440	et	4	main
essee	doc_542009824757_item	2719443	et	4	main
seisab	doc_542009824757_item	2719449	et	3	main
on	doc_542009824757_item	2719452	et	4	main
väga	doc_542009824753_item	2719021	et	3	main
on	doc_542009824753_item	2719031	et	4	main
hele	doc_542009824753_item	2719032	et	3	main
hall	doc_542009824753_item	2719033	et	4	main
ja	doc_542009824753_item	2719037	et	3	main
see	doc_542009824753_item	2719039	et	3	main
õde	doc_542009824753_item	2719049	et	4	main
ta	doc_542009824753_item	2719052	et	4	main
ta	doc_542009824753_item	2719056	et	4	main
väga	doc_542009824753_item	2719058	et	3	main
laps	doc_542009824753_item	2719070	et	4	main
ei	doc_542009824753_item	2719072	et	4	main
lüsikas	doc_542009824753_item	2719075	et	4	main
on	doc_542009824753_item	2719078	et	4	main
siin	doc_542009824753_item	2719079	et	4	main
et	doc_542009824753_item	2719080	et	3	main
ma	doc_542009824753_item	2719081	et	3	main
tahan	doc_542009824753_item	2719082	et	3	main
näita	doc_542009824753_item	2719083	et	4	main
minu	doc_542009824753_item	2719084	et	3	main
sõbr	doc_542009824753_item	2719085	et	4	main
ta	doc_542009824753_item	2719086	et	4	main
on	doc_542009824753_item	2719087	et	4	main
mustriline	doc_542009824753_item	2719088	et	4	main
kujuga	doc_542009824753_item	2719089	et	3	main
essee	doc_542009824754_item	2719090	et	4	main
ühe	doc_542009824754_item	2719091	et	4	main
eseme	doc_542009824754_item	2719092	et	3	main
lugu	doc_542009824754_item	2719093	et	4	main
mulle	doc_542009824754_item	2719094	et	4	main
kinkisid	doc_542009824754_item	2719095	et	4	main
võtmehoidja	doc_542009824754_item	2719096	et	4	main
see	doc_542009824754_item	2719097	et	3	main
on	doc_542009824754_item	2719098	et	4	main
väga	doc_542009824754_item	2719099	et	3	main
ilus	doc_542009824754_item	2719100	et	4	main
ja	doc_542009824754_item	2719101	et	3	main
huvitav	doc_542009824754_item	2719102	et	4	main
ese	doc_542009824754_item	2719103	et	3	main
see	doc_542009824754_item	2719104	et	3	main
ese	doc_542009824754_item	2719105	et	3	main
võitmete	doc_542009824754_item	2719106	et	4	main
jaoks	doc_542009824754_item	2719107	et	4	main
tema	doc_542009824754_item	2719108	et	4	main
tehtud	doc_542009824754_item	2719109	et	4	main
võtmehoidja	doc_542009824754_item	2719117	et	4	main
hea	doc_542009824754_item	2719131	et	4	main
minu	doc_542009824754_item	2719145	et	3	main
kinkis	doc_542009824754_item	2719147	et	3	main
meenis	doc_542009824754_item	2719150	et	3	main
samuti	doc_542009824754_item	2719157	et	3	main
kõik	doc_542009824754_item	2719167	et	4	main
olid	doc_542009824754_item	2719168	et	4	main
minul	doc_542009824754_item	2719172	et	3	main
kodusedele	doc_542009824754_item	2719173	et	3	main
nüüd	doc_542009824754_item	2719175	et	4	main
tahan	doc_542009824754_item	2719177	et	3	main
ka	doc_542009824754_item	2719178	et	3	main
ja	doc_542009824754_item	2719183	et	3	main
reisis	doc_542009824754_item	2719189	et	4	main
et	doc_542009824754_item	2719191	et	3	main
epfeli	doc_542009824754_item	2719199	et	4	main
torni	doc_542009824754_item	2719200	et	4	main
minul	doc_542009824755_item	2719211	et	3	main
model	doc_542009824755_item	2719214	et	4	main
on	doc_542009824755_item	2719215	et	4	main
mitu	doc_542009824754_item	2719124	et	4	main
reisis	doc_542009824754_item	2719135	et	4	main
tema	doc_542009824754_item	2719138	et	4	main
ostis	doc_542009824754_item	2719139	et	4	main
võtmehoidja	doc_542009824754_item	2719142	et	4	main
selle	doc_542009824754_item	2719141	et	4	main
mulle	doc_542009824754_item	2719148	et	4	main
kinkis	doc_542009824754_item	2719158	et	3	main
kõigele	doc_542009824754_item	2719161	et	4	main
selle	doc_542009824754_item	2719162	et	4	main
võtmehoidja	doc_542009824754_item	2719163	et	4	main
võtmehoidja	doc_542009824754_item	2719170	et	4	main
võitmetele	doc_542009824754_item	2719174	et	4	main
ma	doc_542009824754_item	2719176	et	3	main
vaadata	doc_542009824754_item	2719179	et	4	main
frantsusmaale	doc_542009824754_item	2719180	et	4	main
epfeli	doc_542009824754_item	2719185	et	4	main
ma	doc_542009824754_item	2719188	et	3	main
toimetasin	doc_542009824754_item	2719193	et	3	main
kohale	doc_542009824754_item	2719194	et	4	main
veel	doc_542009824754_item	2719195	et	4	main
tema	doc_542009824755_item	2719223	et	4	main
meeskonnas	doc_542009824755_item	2719261	et	4	main
on	doc_542009824755_item	2719279	et	4	main
vaja	doc_542009824755_item	2719280	et	4	main
ja	doc_542009824755_item	2719316	et	3	main
tahan	doc_542009824755_item	2719318	et	3	main
palju	doc_542009824755_item	2719321	et	4	main
jätku	doc_542009824755_item	2719323	et	4	main
tegin	doc_542009824755_item	2719327	et	3	main
alguses	doc_542009824755_item	2719329	et	4	main
mulle	doc_542009824755_item	2719332	et	4	main
kõik	doc_542009824755_item	2719333	et	4	main
elus	doc_542009824756_item	2719338	et	4	main
on	doc_542009824756_item	2719339	et	4	main
inimene	doc_542009824756_item	2719344	et	3	main
ärid	doc_542009824756_item	2719354	et	3	main
sõbradega	doc_542009824756_item	2719357	et	4	main
ja	doc_542009824756_item	2719358	et	3	main
sugulasedega	doc_542009824756_item	2719359	et	3	main
mulle	doc_542009824756_item	2719360	et	4	main
meeldib	doc_542009824756_item	2719361	et	3	main
asi	doc_542009824756_item	2719365	et	4	main
minul	doc_542009824756_item	2719367	et	3	main
ma	doc_542009824756_item	2719391	et	3	main
telefonil	doc_542009824756_item	2719397	et	3	main
klahvi	doc_542009824756_item	2719421	et	4	main
ja	doc_542009824756_item	2719425	et	3	main
siis	doc_542009824756_item	2719426	et	3	main
kõik	doc_542009824756_item	2719427	et	4	main
on	doc_542009824756_item	2719430	et	4	main
ja	doc_542009824756_item	2719441	et	3	main
on	doc_542009824757_item	2719446	et	4	main
teda	doc_542009824757_item	2719456	et	4	main
on	doc_542009824757_item	2719461	et	4	main
potis	doc_542009824757_item	2719474	et	4	main
pruun	doc_542009824757_item	2719479	et	3	main
kirjutatud	doc_542009824758_item	2719518	et	4	main
selle	doc_542009824758_item	2719520	et	4	main
järgi	doc_542009824758_item	2719521	et	4	main
et	doc_542009824758_item	2719524	et	3	main
et	doc_542009824758_item	2719533	et	3	main
uus	doc_542009824758_item	2719538	et	3	main
vormistatud	doc_542009824758_item	2719551	et	4	main
on	doc_542009824758_item	2719555	et	4	main
soomes	doc_542009824758_item	2719566	et	4	main
või	doc_542009824758_item	2719567	et	4	main
kallis	doc_542009824758_item	2719580	et	4	main
on	doc_542009824758_item	2719583	et	4	main
on	doc_542009824758_item	2719586	et	4	main
lõpetama	doc_542009824759_item	2719628	et	4	main
essee	doc_542009824760_item	2719635	et	4	main
lugu	doc_542009824760_item	2719638	et	4	main
see	doc_542009824760_item	2719639	et	3	main
on	doc_542009824760_item	2719640	et	4	main
medal	doc_542009824760_item	2719641	et	3	main
tehtud	doc_542009824760_item	2719644	et	4	main
on	doc_542009824760_item	2719647	et	4	main
lehtedega	doc_542009824760_item	2719664	et	4	main
selle	doc_542009824760_item	2719670	et	4	main
üks	doc_542009824760_item	2719673	et	3	main
on	doc_542009824760_item	2719686	et	4	main
tehtuma	doc_542009824760_item	2719693	et	3	main
see	doc_542009824761_item	2719721	et	3	main
meeldib	doc_542009824761_item	2719723	et	3	main
see	doc_542009824761_item	2719737	et	3	main
see	doc_542009824761_item	2719745	et	3	main
sõber	doc_542009824754_item	2719146	et	3	main
kui	doc_542009824754_item	2719149	et	3	main
tema	doc_542009824754_item	2719152	et	4	main
kõigele	doc_542009824754_item	2719164	et	4	main
meeldis	doc_542009824754_item	2719165	et	3	main
ja	doc_542009824754_item	2719166	et	3	main
torni	doc_542009824754_item	2719186	et	4	main
kui	doc_542009824754_item	2719187	et	3	main
sinna	doc_542009824754_item	2719190	et	3	main
erinevad	doc_542009824754_item	2719196	et	4	main
kõigele	doc_542009824754_item	2719203	et	4	main
niisugune	doc_542009824754_item	2719205	et	3	main
ja	doc_542009824754_item	2719207	et	3	main
on	doc_542009824755_item	2719212	et	4	main
nokia	doc_542009824755_item	2719216	et	4	main
mulle	doc_542009824755_item	2719217	et	4	main
meeldib	doc_542009824755_item	2719218	et	3	main
seda	doc_542009824755_item	2719219	et	3	main
kerge	doc_542009824755_item	2719225	et	4	main
ja	doc_542009824755_item	2719228	et	3	main
mina	doc_542009824755_item	2719230	et	4	main
alati	doc_542009824755_item	2719231	et	4	main
kasutan	doc_542009824755_item	2719232	et	3	main
nokia	doc_542009824755_item	2719233	et	4	main
et	doc_542009824755_item	2719234	et	3	main
sellepärast	doc_542009824755_item	2719235	et	3	main
helinad	doc_542009824755_item	2719249	et	3	main
meil	doc_542009824755_item	2719260	et	4	main
seepärast	doc_542009824755_item	2719266	et	3	main
kirjutan	doc_542009824755_item	2719269	et	3	main
ja	doc_542009824755_item	2719271	et	3	main
teha	doc_542009824755_item	2719276	et	3	main
kuhu	doc_542009824755_item	2719313	et	3	main
vaja	doc_542009824755_item	2719315	et	4	main
teada	doc_542009824755_item	2719319	et	3	main
et	doc_542009824755_item	2719222	et	3	main
on	doc_542009824755_item	2719224	et	4	main
seal	doc_542009824755_item	2719237	et	4	main
väga	doc_542009824755_item	2719239	et	3	main
mina	doc_542009824755_item	2719242	et	4	main
logod	doc_542009824755_item	2719251	et	3	main
olen	doc_542009824755_item	2719253	et	3	main
veel	doc_542009824755_item	2719255	et	4	main
kõik	doc_542009824755_item	2719262	et	4	main
mina	doc_542009824755_item	2719267	et	4	main
sõnumid	doc_542009824755_item	2719268	et	3	main
kiiresti	doc_542009824755_item	2719270	et	3	main
mulle	doc_542009824755_item	2719278	et	4	main
vaadata	doc_542009824755_item	2719281	et	4	main
kui	doc_542009824755_item	2719282	et	3	main
palju	doc_542009824755_item	2719283	et	4	main
maksab	doc_542009824755_item	2719284	et	3	main
viimasena	doc_542009824755_item	2719285	et	3	main
peetud	doc_542009824755_item	2719286	et	4	main
kõne	doc_542009824755_item	2719287	et	4	main
ma	doc_542009824755_item	2719288	et	3	main
vajutan	doc_542009824755_item	2719289	et	3	main
tärn	doc_542009824755_item	2719290	et	3	main
üks	doc_542009824755_item	2719291	et	3	main
kolm	doc_542009824755_item	2719292	et	3	main
viis	doc_542009824755_item	2719293	et	4	main
tärn	doc_542009824755_item	2719294	et	3	main
üks	doc_542009824755_item	2719295	et	3	main
ja	doc_542009824755_item	2719296	et	3	main
ruut	doc_542009824755_item	2719297	et	3	main
pärast	doc_542009824755_item	2719298	et	4	main
saan	doc_542009824755_item	2719299	et	4	main
sõnum	doc_542009824755_item	2719300	et	3	main
kus	doc_542009824755_item	2719301	et	3	main
ma	doc_542009824755_item	2719302	et	3	main
näen	doc_542009824755_item	2719303	et	3	main
kui	doc_542009824755_item	2719304	et	3	main
palju	doc_542009824755_item	2719305	et	4	main
minul	doc_542009824755_item	2719306	et	3	main
on	doc_542009824755_item	2719307	et	4	main
saldo	doc_542009824755_item	2719308	et	4	main
kõneaeg	doc_542009824755_item	2719309	et	3	main
siis	doc_542009824755_item	2719310	et	3	main
meeldib	doc_542009824755_item	2719274	et	3	main
näiteks	doc_542009824755_item	2719277	et	4	main
ma	doc_542009824755_item	2719326	et	3	main
ja	doc_542009824755_item	2719330	et	3	main
iga	doc_542009824756_item	2719343	et	4	main
abiga	doc_542009824756_item	2719348	et	3	main
meie	doc_542009824756_item	2719355	et	4	main
kui	doc_542009824756_item	2719364	et	3	main
suhtlemine	doc_542009824756_item	2719366	et	4	main
nissugune	doc_542009824756_item	2719390	et	4	main
alati	doc_542009824756_item	2719393	et	4	main
et	doc_542009824756_item	2719396	et	3	main
nokias	doc_542009824756_item	2719403	et	4	main
on	doc_542009824756_item	2719404	et	4	main
väga	doc_542009824756_item	2719405	et	3	main
mugav	doc_542009824756_item	2719406	et	3	main
telefoniraamat	doc_542009824756_item	2719407	et	3	main
telefoninumber	doc_542009824756_item	2719413	et	3	main
sõpru	doc_542009824756_item	2719415	et	3	main
pärast	doc_542009824756_item	2719419	et	4	main
vajutan	doc_542009824756_item	2719420	et	3	main
helistan	doc_542009824755_item	2719311	et	3	main
minul	doc_542009824755_item	2719322	et	3	main
kõneaeg	doc_542009824755_item	2719324	et	3	main
ja	doc_542009824755_item	2719325	et	3	main
essee	doc_542009824756_item	2719335	et	4	main
mobiiltelefon	doc_542009824756_item	2719336	et	3	main
asi	doc_542009824756_item	2719341	et	4	main
praegu	doc_542009824756_item	2719342	et	3	main
omab	doc_542009824756_item	2719345	et	3	main
meie	doc_542009824756_item	2719350	et	4	main
räägime	doc_542009824756_item	2719356	et	3	main
veel	doc_542009824756_item	2719394	et	4	main
näiteks	doc_542009824756_item	2719408	et	4	main
vaja	doc_542009824756_item	2719411	et	4	main
mina	doc_542009824756_item	2719416	et	4	main
numbrimärksed	doc_542009824756_item	2719418	et	4	main
kõik	doc_542009824756_item	2719432	et	4	main
muutuda	doc_542009824756_item	2719434	et	3	main
kiiresti	doc_542009824756_item	2719436	et	3	main
meeldib	doc_542009824756_item	2719442	et	3	main
asi	doc_542009824757_item	2719445	et	4	main
kodus	doc_542009824757_item	2719448	et	4	main
põrandal	doc_542009824757_item	2719450	et	3	main
ei	doc_542009824757_item	2719457	et	4	main
ohtlik	doc_542009824757_item	2719462	et	3	main
on	doc_542009824757_item	2719464	et	4	main
nagu	doc_542009824757_item	2719465	et	3	main
üks	doc_542009824757_item	2719469	et	3	main
värv	doc_542009824757_item	2719470	et	3	main
roheline	doc_542009824757_item	2719471	et	4	main
pot	doc_542009824757_item	2719477	et	4	main
finlandia	doc_542009824758_item	2719519	et	4	main
on	doc_542009824758_item	2719531	et	4	main
näha	doc_542009824758_item	2719532	et	3	main
see	doc_542009824758_item	2719539	et	3	main
oli	doc_542009824758_item	2719541	et	3	main
ainuke	doc_542009824758_item	2719543	et	4	main
kui	doc_542009824758_item	2719546	et	3	main
võib	doc_542009824758_item	2719552	et	3	main
see	doc_542009824758_item	2719554	et	3	main
selle	doc_542009824758_item	2719557	et	4	main
selle	doc_542009824758_item	2719570	et	4	main
suveniri	doc_542009824758_item	2719572	et	4	main
ta	doc_542009824758_item	2719582	et	4	main
hõbedast	doc_542009824758_item	2719584	et	4	main
ehtimine	doc_542009824759_item	2719618	et	4	main
lillekuiuline	doc_542009824759_item	2719621	et	4	main
otsas	doc_542009824759_item	2719627	et	4	main
vöö	doc_542009824759_item	2719634	et	4	main
eseme	doc_542009824760_item	2719637	et	3	main
joonistatud	doc_542009824760_item	2719648	et	4	main
puu	doc_542009824760_item	2719661	et	4	main
kirjulise	doc_542009824760_item	2719662	et	4	main
veel	doc_542009824760_item	2719665	et	4	main
seal	doc_542009824760_item	2719666	et	4	main
mururoheline	doc_542009824760_item	2719668	et	4	main
padi	doc_542009824760_item	2719669	et	3	main
isa	doc_542009824760_item	2719690	et	4	main
puust	doc_542009824760_item	2719692	et	4	main
medali	doc_542009824760_item	2719694	et	3	main
nüüd	doc_542009824761_item	2719732	et	4	main
ta	doc_542009824761_item	2719733	et	4	main
kasvas	doc_542009824761_item	2719734	et	3	main
isetehtud	doc_542009824761_item	2719753	et	3	main
väga	doc_542009824761_item	2719757	et	3	main
ja	doc_542009824761_item	2719760	et	3	main
see	doc_542009824761_item	2719765	et	3	main
essee	doc_542009824762_item	2719772	et	4	main
ja	doc_542009824762_item	2719780	et	3	main
mänguasjad	doc_542009824762_item	2719820	et	3	main
kollektsioon	doc_542009824762_item	2719824	et	3	main
ta	doc_542009824763_item	2719826	et	4	main
mina	doc_542009824763_item	2719835	et	4	main
ei	doc_542009824763_item	2719836	et	4	main
frantsuse	doc_542009824763_item	2719842	et	4	main
alustame	doc_542009824763_item	2719845	et	3	main
algasid	doc_542009824763_item	2719847	et	4	main
läbirääkimised	doc_542009824763_item	2719848	et	3	main
helistad	doc_542009824763_item	2719869	et	3	main
auto	doc_542009824763_item	2719882	et	4	main
tantsida	doc_542009824763_item	2719884	et	3	main
mängu	doc_542009824763_item	2719886	et	4	main
kõik	doc_542009824755_item	2719328	et	4	main
siis	doc_542009824755_item	2719331	et	3	main
meie	doc_542009824756_item	2719337	et	4	main
mobiiltelefon	doc_542009824756_item	2719347	et	3	main
palju	doc_542009824756_item	2719353	et	4	main
mobiiltelefon	doc_542009824756_item	2719363	et	3	main
model	doc_542009824756_item	2719368	et	4	main
mobiiltelefon	doc_542009824756_item	2719369	et	3	main
nokia	doc_542009824756_item	2719370	et	4	main
väga	doc_542009824756_item	2719372	et	3	main
meeldib	doc_542009824756_item	2719373	et	3	main
see	doc_542009824756_item	2719374	et	3	main
telefon	doc_542009824756_item	2719375	et	3	main
mulle	doc_542009824756_item	2719371	et	4	main
tema	doc_542009824756_item	2719376	et	4	main
väga	doc_542009824756_item	2719377	et	3	main
mugav	doc_542009824756_item	2719378	et	3	main
ja	doc_542009824756_item	2719379	et	3	main
stiilne	doc_542009824756_item	2719380	et	3	main
selles	doc_542009824756_item	2719381	et	4	main
modelis	doc_542009824756_item	2719382	et	4	main
veel	doc_542009824756_item	2719383	et	4	main
mugav	doc_542009824756_item	2719384	et	3	main
menüü	doc_542009824756_item	2719385	et	4	main
menüüs	doc_542009824756_item	2719386	et	3	main
on	doc_542009824756_item	2719387	et	4	main
muusikalne	doc_542009824756_item	2719388	et	4	main
pleier	doc_542009824756_item	2719389	et	3	main
meeldib	doc_542009824756_item	2719395	et	3	main
kerge	doc_542009824756_item	2719398	et	4	main
telefoninumbrid	doc_542009824756_item	2719400	et	3	main
mulle	doc_542009824756_item	2719409	et	4	main
salvestada	doc_542009824756_item	2719412	et	3	main
oma	doc_542009824756_item	2719414	et	4	main
selle	doc_542009824756_item	2719428	et	4	main
telefoniraamatuses	doc_542009824756_item	2719431	et	4	main
see	doc_542009824756_item	2719433	et	3	main
ja	doc_542009824756_item	2719437	et	3	main
see	doc_542009824757_item	2719444	et	3	main
pikk	doc_542009824757_item	2719455	et	4	main
tal	doc_542009824757_item	2719467	et	3	main
mulla	doc_542009824757_item	2719475	et	4	main
sees	doc_542009824757_item	2719476	et	4	main
ja	doc_542009824758_item	2719516	et	3	main
vajutan	doc_542009824756_item	2719423	et	3	main
ok	doc_542009824756_item	2719424	et	4	main
mul	doc_542009824757_item	2719447	et	3	main
ta	doc_542009824757_item	2719451	et	4	main
tohi	doc_542009824757_item	2719458	et	4	main
puutuda	doc_542009824757_item	2719459	et	3	main
ta	doc_542009824757_item	2719472	et	4	main
seisab	doc_542009824757_item	2719473	et	3	main
on	doc_542009824757_item	2719478	et	4	main
ise	doc_542009824757_item	2719482	et	4	main
asi	doc_542009824757_item	2719481	et	4	main
on	doc_542009824757_item	2719483	et	4	main
üks	doc_542009824757_item	2719484	et	3	main
meeter	doc_542009824757_item	2719485	et	3	main
pikk	doc_542009824757_item	2719486	et	4	main
see	doc_542009824757_item	2719487	et	3	main
asi	doc_542009824757_item	2719488	et	4	main
on	doc_542009824757_item	2719489	et	4	main
kaktus	doc_542009824757_item	2719490	et	3	main
essee	doc_542009824758_item	2719491	et	4	main
ühe	doc_542009824758_item	2719492	et	4	main
eseme	doc_542009824758_item	2719493	et	3	main
lugu	doc_542009824758_item	2719494	et	4	main
minu	doc_542009824758_item	2719495	et	3	main
ees	doc_542009824758_item	2719496	et	4	main
laua	doc_542009824758_item	2719497	et	3	main
peal	doc_542009824758_item	2719498	et	4	main
on	doc_542009824758_item	2719499	et	4	main
üks	doc_542009824758_item	2719500	et	3	main
lusikas	doc_542009824758_item	2719501	et	4	main
see	doc_542009824758_item	2719502	et	3	main
on	doc_542009824758_item	2719503	et	4	main
teelusikas	doc_542009824758_item	2719504	et	4	main
ma	doc_542009824758_item	2719505	et	3	main
mõtlen	doc_542009824758_item	2719506	et	3	main
see	doc_542009824758_item	2719507	et	3	main
on	doc_542009824758_item	2719508	et	4	main
hõbelusikas	doc_542009824758_item	2719509	et	4	main
lusika	doc_542009824758_item	2719510	et	3	main
peal	doc_542009824758_item	2719511	et	4	main
on	doc_542009824758_item	2719512	et	4	main
kujtatud	doc_542009824758_item	2719513	et	4	main
soome	doc_542009824758_item	2719514	et	3	main
lipp	doc_542009824758_item	2719515	et	3	main
peenike	doc_542009824757_item	2719453	et	4	main
ja	doc_542009824757_item	2719454	et	3	main
ta	doc_542009824757_item	2719460	et	4	main
ta	doc_542009824757_item	2719463	et	4	main
torn	doc_542009824757_item	2719466	et	3	main
on	doc_542009824757_item	2719468	et	4	main
ja	doc_542009824757_item	2719480	et	3	main
on	doc_542009824758_item	2719517	et	4	main
lusikas	doc_542009824758_item	2719526	et	4	main
ostetud	doc_542009824758_item	2719528	et	4	main
soomest	doc_542009824758_item	2719529	et	3	main
välimuselt	doc_542009824758_item	2719530	et	3	main
asi	doc_542009824758_item	2719535	et	4	main
karp	doc_542009824758_item	2719545	et	3	main
lusikas	doc_542009824758_item	2719548	et	4	main
on	doc_542009824758_item	2719549	et	4	main
ilusti	doc_542009824758_item	2719550	et	3	main
suveniir	doc_542009824758_item	2719556	et	3	main
on	doc_542009824758_item	2719560	et	4	main
turist	doc_542009824758_item	2719563	et	3	main
käis	doc_542009824758_item	2719565	et	4	main
on	doc_542009824758_item	2719578	et	4	main
vist	doc_542009824758_item	2719579	et	4	main
ja	doc_542009824758_item	2719585	et	3	main
samuti	doc_542009824759_item	2719615	et	3	main
metall	doc_542009824759_item	2719620	et	3	main
ehtimine	doc_542009824759_item	2719623	et	4	main
pärlid	doc_542009824759_item	2719625	et	3	main
vöö	doc_542009824759_item	2719626	et	4	main
medal	doc_542009824760_item	2719642	et	3	main
žaas	doc_542009824760_item	2719650	et	2	main
ilus	doc_542009824760_item	2719653	et	4	main
taevas	doc_542009824760_item	2719655	et	4	main
tumesinine	doc_542009824760_item	2719656	et	4	main
mere	doc_542009824760_item	2719657	et	3	main
keskel	doc_542009824760_item	2719658	et	3	main
on	doc_542009824760_item	2719659	et	4	main
suur	doc_542009824760_item	2719660	et	3	main
joonistas	doc_542009824760_item	2719672	et	3	main
tüdruk	doc_542009824760_item	2719674	et	3	main
tegis	doc_542009824760_item	2719676	et	4	main
toodud	doc_542009824760_item	2719687	et	4	main
aitas	doc_542009824760_item	2719691	et	3	main
väga	doc_542009824761_item	2719725	et	3	main
suureks	doc_542009824761_item	2719735	et	4	main
toas	doc_542009824761_item	2719742	et	3	main
mulle	doc_542009824761_item	2719747	et	4	main
ka	doc_542009824761_item	2719748	et	3	main
linnud	doc_542009824761_item	2719759	et	3	main
on	doc_542009824761_item	2719766	et	4	main
väga	doc_542009824761_item	2719767	et	3	main
armas	doc_542009824761_item	2719768	et	3	main
võib	doc_542009824758_item	2719522	et	3	main
on	doc_542009824758_item	2719527	et	4	main
on	doc_542009824758_item	2719536	et	4	main
üsna	doc_542009824758_item	2719537	et	3	main
lusikas	doc_542009824758_item	2719540	et	4	main
karbis	doc_542009824758_item	2719542	et	3	main
nii	doc_542009824758_item	2719544	et	3	main
ka	doc_542009824758_item	2719547	et	3	main
olla	doc_542009824758_item	2719553	et	3	main
omanik	doc_542009824758_item	2719559	et	3	main
arvatavasti	doc_542009824758_item	2719561	et	3	main
kes	doc_542009824758_item	2719564	et	4	main
kinkis	doc_542009824758_item	2719569	et	3	main
ilusa	doc_542009824758_item	2719571	et	3	main
tema	doc_542009824758_item	2719573	et	4	main
sõber	doc_542009824758_item	2719574	et	3	main
soomest	doc_542009824758_item	2719575	et	3	main
see	doc_542009824758_item	2719576	et	3	main
ese	doc_542009824758_item	2719577	et	3	main
sest	doc_542009824758_item	2719581	et	4	main
võib	doc_542009824758_item	2719587	et	3	main
olla	doc_542009824758_item	2719588	et	3	main
eksklussiivne	doc_542009824758_item	2719589	et	4	main
essee	doc_542009824759_item	2719590	et	4	main
ühe	doc_542009824759_item	2719591	et	4	main
eseme	doc_542009824759_item	2719592	et	3	main
lugu	doc_542009824759_item	2719593	et	4	main
vöö	doc_542009824759_item	2719594	et	4	main
see	doc_542009824759_item	2719595	et	3	main
on	doc_542009824759_item	2719596	et	4	main
vöö	doc_542009824759_item	2719597	et	4	main
sell	doc_542009824759_item	2719598	et	3	main
aasta	doc_542009824759_item	2719599	et	4	main
väga	doc_542009824759_item	2719600	et	3	main
moodne	doc_542009824759_item	2719601	et	3	main
kandma	doc_542009824759_item	2719602	et	3	main
mitmesugune	doc_542009824759_item	2719603	et	3	main
vööd	doc_542009824759_item	2719604	et	4	main
ma	doc_542009824759_item	2719605	et	3	main
tahan	doc_542009824759_item	2719606	et	3	main
esitama	doc_542009824759_item	2719607	et	3	main
itaalia	doc_542009824759_item	2719608	et	4	main
vöö	doc_542009824759_item	2719609	et	4	main
vööb	doc_542009824759_item	2719610	et	4	main
on	doc_542009824759_item	2719611	et	4	main
tehtud	doc_542009824759_item	2719612	et	4	main
vastupidav	doc_542009824759_item	2719613	et	4	main
riie	doc_542009824759_item	2719614	et	3	main
arvasa	doc_542009824758_item	2719523	et	3	main
see	doc_542009824758_item	2719525	et	3	main
see	doc_542009824758_item	2719534	et	3	main
hõbelusika	doc_542009824758_item	2719558	et	3	main
eesti	doc_542009824758_item	2719562	et	4	main
omanikule	doc_542009824758_item	2719568	et	3	main
vöö	doc_542009824759_item	2719616	et	4	main
omama	doc_542009824759_item	2719617	et	4	main
tehtud	doc_542009824759_item	2719619	et	4	main
lillekuiuline	doc_542009824759_item	2719622	et	4	main
bež	doc_542009824759_item	2719624	et	2	main
see	doc_542009824759_item	2719633	et	3	main
ühe	doc_542009824760_item	2719636	et	4	main
pei	doc_542009824760_item	2719649	et	4	main
on	doc_542009824760_item	2719652	et	4	main
on	doc_542009824760_item	2719667	et	4	main
joonistus	doc_542009824760_item	2719671	et	4	main
ta	doc_542009824760_item	2719675	et	4	main
seda	doc_542009824760_item	2719677	et	3	main
medali	doc_542009824760_item	2719678	et	3	main
oma	doc_542009824760_item	2719679	et	4	main
õele	doc_542009824760_item	2719680	et	3	main
see	doc_542009824760_item	2719681	et	3	main
medal	doc_542009824760_item	2719682	et	3	main
tähendab	doc_542009824760_item	2719683	et	3	main
sõprust	doc_542009824760_item	2719684	et	3	main
medal	doc_542009824760_item	2719685	et	3	main
kodus	doc_542009824760_item	2719688	et	4	main
sõlm	doc_542009824759_item	2719629	et	3	main
ma	doc_542009824759_item	2719630	et	3	main
soovitan	doc_542009824759_item	2719631	et	3	main
hankima	doc_542009824759_item	2719632	et	3	main
on	doc_542009824760_item	2719643	et	4	main
puust	doc_542009824760_item	2719645	et	4	main
medalil	doc_542009824760_item	2719646	et	3	main
peižaasis	doc_542009824760_item	2719651	et	2	main
helesinine	doc_542009824760_item	2719654	et	4	main
rohelise	doc_542009824760_item	2719663	et	4	main
tüdrukutele	doc_542009824760_item	2719689	et	4	main
aga	doc_542009824760_item	2719695	et	3	main
noorõde	doc_542009824760_item	2719696	et	4	main
joonistas	doc_542009824760_item	2719697	et	3	main
see	doc_542009824760_item	2719698	et	3	main
loo	doc_542009824760_item	2719699	et	4	main
oli	doc_542009824760_item	2719700	et	3	main
ühel	doc_542009824760_item	2719701	et	3	main
kuud	doc_542009824760_item	2719702	et	4	main
tagasi	doc_542009824760_item	2719703	et	3	main
see	doc_542009824760_item	2719704	et	3	main
medal	doc_542009824760_item	2719705	et	3	main
oli	doc_542009824760_item	2719706	et	3	main
tehtud	doc_542009824760_item	2719707	et	4	main
armastusega	doc_542009824760_item	2719708	et	4	main
essee	doc_542009824761_item	2719709	et	4	main
ühe	doc_542009824761_item	2719710	et	4	main
eseme	doc_542009824761_item	2719711	et	3	main
lugu	doc_542009824761_item	2719712	et	4	main
see	doc_542009824761_item	2719713	et	3	main
on	doc_542009824761_item	2719714	et	4	main
küünlajalg	doc_542009824761_item	2719715	et	3	main
see	doc_542009824761_item	2719716	et	3	main
on	doc_542009824761_item	2719717	et	4	main
tehtud	doc_542009824761_item	2719718	et	4	main
pruunist	doc_542009824761_item	2719719	et	3	main
savist	doc_542009824761_item	2719720	et	4	main
küünlajalg	doc_542009824761_item	2719722	et	3	main
mulle	doc_542009824761_item	2719724	et	4	main
seda	doc_542009824761_item	2719727	et	3	main
tegi	doc_542009824761_item	2719728	et	4	main
mu	doc_542009824761_item	2719729	et	3	main
väike	doc_542009824761_item	2719730	et	4	main
vend	doc_542009824761_item	2719731	et	3	main
aga	doc_542009824761_item	2719736	et	3	main
ikka	doc_542009824761_item	2719739	et	4	main
mu	doc_542009824761_item	2719741	et	3	main
laua	doc_542009824761_item	2719743	et	3	main
peal	doc_542009824761_item	2719744	et	4	main
asi	doc_542009824761_item	2719754	et	4	main
vennale	doc_542009824761_item	2719756	et	3	main
linnukujuliseks	doc_542009824761_item	2719764	et	4	main
see	doc_542009824762_item	2719778	et	3	main
ma	doc_542009824762_item	2719782	et	3	main
ja	doc_542009824762_item	2719821	et	3	main
sõbra	doc_542009824763_item	2719830	et	3	main
sest	doc_542009824761_item	2719726	et	4	main
küünlajalg	doc_542009824761_item	2719738	et	3	main
seisab	doc_542009824761_item	2719740	et	3	main
selle	doc_542009824761_item	2719763	et	4	main
see	doc_542009824762_item	2719773	et	3	main
mänguasi	doc_542009824762_item	2719775	et	3	main
kingiti	doc_542009824762_item	2719777	et	3	main
sest	doc_542009824762_item	2719781	et	4	main
ei	doc_542009824762_item	2719783	et	4	main
tea	doc_542009824762_item	2719784	et	4	main
kui	doc_542009824762_item	2719785	et	3	main
palju	doc_542009824762_item	2719786	et	4	main
see	doc_542009824762_item	2719787	et	3	main
maksab	doc_542009824762_item	2719788	et	3	main
see	doc_542009824762_item	2719789	et	3	main
on	doc_542009824762_item	2719790	et	4	main
ja	doc_542009824762_item	2719792	et	3	main
pehme	doc_542009824762_item	2719791	et	4	main
vaga	doc_542009824762_item	2719793	et	4	main
ilus	doc_542009824762_item	2719794	et	4	main
mänguasi	doc_542009824762_item	2719795	et	3	main
see	doc_542009824762_item	2719796	et	3	main
on	doc_542009824762_item	2719797	et	4	main
hüljes	doc_542009824762_item	2719798	et	3	main
ja	doc_542009824762_item	2719799	et	3	main
ta	doc_542009824762_item	2719800	et	4	main
on	doc_542009824762_item	2719801	et	4	main
kollane	doc_542009824762_item	2719802	et	4	main
täpselt	doc_542009824762_item	2719803	et	4	main
hele	doc_542009824762_item	2719804	et	3	main
kollane	doc_542009824762_item	2719805	et	4	main
mul	doc_542009824762_item	2719806	et	3	main
oli	doc_542009824762_item	2719807	et	3	main
sünnipäev	doc_542009824762_item	2719808	et	3	main
ja	doc_542009824762_item	2719809	et	3	main
minu	doc_542009824762_item	2719810	et	3	main
sõber	doc_542009824762_item	2719811	et	3	main
on	doc_542009824762_item	2719812	et	4	main
kinkinud	doc_542009824762_item	2719813	et	4	main
mulle	doc_542009824762_item	2719814	et	4	main
see	doc_542009824762_item	2719815	et	3	main
kingitus	doc_542009824762_item	2719816	et	4	main
mulle	doc_542009824762_item	2719817	et	4	main
väga	doc_542009824762_item	2719818	et	3	main
meeldivad	doc_542009824762_item	2719819	et	4	main
meeldib	doc_542009824761_item	2719746	et	3	main
sellepärast	doc_542009824761_item	2719749	et	3	main
et	doc_542009824761_item	2719750	et	3	main
see	doc_542009824761_item	2719751	et	3	main
on	doc_542009824761_item	2719752	et	4	main
mu	doc_542009824761_item	2719755	et	3	main
meeldivad	doc_542009824761_item	2719758	et	4	main
ta	doc_542009824761_item	2719761	et	4	main
tegi	doc_542009824761_item	2719762	et	4	main
asi	doc_542009824761_item	2719769	et	4	main
minu	doc_542009824761_item	2719770	et	3	main
südamele	doc_542009824761_item	2719771	et	3	main
on	doc_542009824762_item	2719774	et	4	main
mulle	doc_542009824762_item	2719776	et	4	main
mänguasi	doc_542009824762_item	2719779	et	3	main
on	doc_542009824762_item	2719823	et	4	main
harjutus	doc_542009824763_item	2719825	et	4	main
käis	doc_542009824763_item	2719827	et	4	main
äratama	doc_542009824763_item	2719828	et	3	main
oska	doc_542009824763_item	2719837	et	4	main
õpetama	doc_542009824763_item	2719838	et	3	main
ma	doc_542009824763_item	2719839	et	3	main
lõpetama	doc_542009824763_item	2719850	et	4	main
teid	doc_542009824763_item	2719863	et	4	main
teid	doc_542009824763_item	2719866	et	4	main
sa	doc_542009824763_item	2719868	et	3	main
politsei	doc_542009824763_item	2719880	et	4	main
peatuda	doc_542009824763_item	2719883	et	3	main
gruppis	doc_542009824763_item	2719885	et	4	main
saa	doc_542009824763_item	2719895	et	4	main
saa	doc_542009824763_item	2719900	et	4	main
uute	doc_542009824763_item	2719902	et	3	main
mina	doc_542009824763_item	2719904	et	4	main
soovin	doc_542009824763_item	2719905	et	3	main
oma	doc_542009824763_item	2719906	et	4	main
soovitan	doc_542009824763_item	2719912	et	3	main
teile	doc_542009824763_item	2719913	et	4	main
vähem	doc_542009824763_item	2719914	et	4	main
toitu	doc_542009824763_item	2719928	et	4	main
saama	doc_542009824763_item	2719934	et	4	main
tõlge	doc_542009824764_item	2719935	et	3	main
отходы	doc_542009824764_item	2719937	et	2	main
здоровья	doc_542009824764_item	2719939	et	2	main
природы	doc_542009824764_item	2719941	et	2	main
наше	doc_542009824764_item	2719944	et	2	main
предприятия	doc_542009824764_item	2719948	et	2	main
опасных	doc_542009824764_item	2719952	et	2	main
черезвычайно	doc_542009824764_item	2719956	et	2	main
они	doc_542009824764_item	2719961	et	2	main
алергию	doc_542009824764_item	2719964	et	2	main
сок	doc_542009824764_item	2719969	et	2	main
красители	doc_542009824764_item	2719972	et	2	main
вызвать	doc_542009824764_item	2719977	et	2	main
опасны	doc_542009824764_item	2719982	et	2	main
этих	doc_542009824764_item	2720016	et	2	main
начинаются	doc_542009824764_item	2720019	et	2	main
также	doc_542009824764_item	2720022	et	2	main
рыб	doc_542009824764_item	2720027	et	2	main
впитывают	doc_542009824764_item	2720029	et	2	main
воду	doc_542009824764_item	2720034	et	2	main
мясо	doc_542009824764_item	2720038	et	2	main
почвы	doc_542009824764_item	2720046	et	2	main
собой	doc_542009824764_item	2720051	et	2	main
для	doc_542009824764_item	2720054	et	2	main
о	doc_542009824764_item	2720062	et	2	main
keemiatooted	doc_542009824764_item	2720064	et	3	main
loodusele	doc_542009824764_item	2720068	et	4	main
ohtlikud	doc_542009824764_item	2720069	et	3	main
mida	doc_542009824764_item	2720076	et	4	main
palju	doc_542009824764_item	2720078	et	4	main
jäätmeid	doc_542009824764_item	2720080	et	3	main
on	doc_542009824764_item	2720083	et	4	main
ohtlikud	doc_542009824764_item	2720084	et	3	main
nad	doc_542009824764_item	2720122	et	3	main
mullasse	doc_542009824764_item	2720124	et	4	main
veekogudesse	doc_542009824764_item	2720125	et	3	main
ja	doc_542009824764_item	2720126	et	3	main
ohku	doc_542009824764_item	2720127	et	4	main
veekogud	doc_542009824764_item	2720128	et	3	main
looma	doc_542009824764_item	2720135	et	4	main
võivad	doc_542009824764_item	2720139	et	4	main
keel	doc_542009824763_item	2719843	et	4	main
tähtaeg	doc_542009824763_item	2719851	et	3	main
on	doc_542009824763_item	2719852	et	4	main
lõpenud	doc_542009824763_item	2719853	et	4	main
last	doc_542009824763_item	2719854	et	4	main
magama	doc_542009824763_item	2719855	et	3	main
uinutama	doc_542009824763_item	2719856	et	4	main
koer	doc_542009824763_item	2719857	et	3	main
uinuma	doc_542009824763_item	2719858	et	3	main
kardab	doc_542009824763_item	2719859	et	4	main
ma	doc_542009824763_item	2719860	et	3	main
tahan	doc_542009824763_item	2719861	et	3	main
mul	doc_542009824762_item	2719822	et	3	main
oma	doc_542009824763_item	2719829	et	4	main
õhtul	doc_542009824763_item	2719831	et	3	main
ma	doc_542009824763_item	2719832	et	3	main
ärkan	doc_542009824763_item	2719834	et	3	main
õppima	doc_542009824763_item	2719841	et	3	main
tutvustama	doc_542009824763_item	2719862	et	3	main
tutvume	doc_542009824763_item	2719865	et	3	main
miks	doc_542009824763_item	2719867	et	4	main
mulle	doc_542009824763_item	2719870	et	4	main
kogu	doc_542009824763_item	2719871	et	4	main
aeg	doc_542009824763_item	2719872	et	3	main
kell	doc_542009824763_item	2719873	et	3	main
heliseb	doc_542009824763_item	2719874	et	3	main
peatab	doc_542009824763_item	2719881	et	3	main
laps	doc_542009824763_item	2719893	et	4	main
ei	doc_542009824763_item	2719894	et	4	main
ei	doc_542009824763_item	2719899	et	4	main
nõudmistega	doc_542009824763_item	2719903	et	4	main
terve	doc_542009824763_item	2719910	et	4	main
mina	doc_542009824763_item	2719911	et	4	main
tahab	doc_542009824763_item	2719921	et	3	main
postiga	doc_542009824763_item	2719929	et	4	main
химические	doc_542009824764_item	2719936	et	2	main
для	doc_542009824764_item	2719938	et	2	main
и	doc_542009824764_item	2719940	et	2	main
в	doc_542009824764_item	2719943	et	2	main
время	doc_542009824764_item	2719945	et	2	main
химические	doc_542009824764_item	2719947	et	2	main
выпускают	doc_542009824764_item	2719950	et	2	main
отходов	doc_542009824764_item	2719953	et	2	main
для	doc_542009824764_item	2719958	et	2	main
отравление	doc_542009824764_item	2719966	et	2	main
консерванты	doc_542009824764_item	2719974	et	2	main
химические	doc_542009824764_item	2719979	et	2	main
люди	doc_542009824764_item	2720013	et	2	main
и	doc_542009824764_item	2720018	et	2	main
заболевания	doc_542009824764_item	2720021	et	2	main
для	doc_542009824764_item	2720026	et	2	main
вещества	doc_542009824764_item	2720031	et	2	main
ест	doc_542009824764_item	2720037	et	2	main
своё	doc_542009824764_item	2720042	et	2	main
и	doc_542009824764_item	2720047	et	2	main
и	doc_542009824764_item	2720052	et	2	main
жизни	doc_542009824764_item	2720055	et	2	main
нашей	doc_542009824764_item	2720059	et	2	main
tervisele	doc_542009824764_item	2720066	et	3	main
need	doc_542009824764_item	2720081	et	3	main
võib	doc_542009824764_item	2720119	et	3	main
on	doc_542009824764_item	2720129	et	4	main
toit	doc_542009824764_item	2720130	et	3	main
lihaga	doc_542009824764_item	2720136	et	3	main
jääda	doc_542009824764_item	2720140	et	4	main
mis	doc_542009824764_item	2720151	et	4	main
vette	doc_542009824764_item	2720153	et	3	main
oma	doc_542009824764_item	2720161	et	4	main
praetud	doc_542009824765_item	2720193	et	4	main
loomaliha	doc_542009824765_item	2720194	et	4	main
värskekapsasupp	doc_542009824765_item	2720199	et	4	main
kanasupp	doc_542009824765_item	2720201	et	3	main
lisandid	doc_542009824765_item	2720202	et	3	main
tatar	doc_542009824765_item	2720206	et	3	main
rosolje	doc_542009824766_item	2720221	et	4	main
vitamiinisalat	doc_542009824766_item	2720223	et	3	main
kana	doc_542009824766_item	2720226	et	4	main
šnitsel	doc_542009824766_item	2720229	et	2	main
kana	doc_542009824766_item	2720230	et	4	main
makaroonid	doc_542009824766_item	2720242	et	4	main
jäätis	doc_542009824766_item	2720248	et	3	main
tort	doc_542009824766_item	2720250	et	3	main
alkohooli	doc_542009824766_item	2720252	et	3	main
whiskey	doc_542009824766_item	2720266	et	4	main
vadimka	doc_542009824767_item	2720269	et	4	main
menüü	doc_542009824767_item	2720270	et	4	main
frii	doc_542009824767_item	2720275	et	4	main
praetud	doc_542009824767_item	2720277	et	4	main
kohe	doc_542009824763_item	2719833	et	4	main
tahan	doc_542009824763_item	2719840	et	3	main
me	doc_542009824763_item	2719844	et	4	main
pidu	doc_542009824763_item	2719846	et	4	main
tööd	doc_542009824763_item	2719849	et	4	main
me	doc_542009824763_item	2719864	et	4	main
olukord	doc_542009824763_item	2719877	et	3	main
ilma	doc_542009824763_item	2719891	et	4	main
jäi	doc_542009824763_item	2719892	et	3	main
harjuma	doc_542009824763_item	2719901	et	3	main
õnne	doc_542009824763_item	2719908	et	4	main
jõua	doc_542009824763_item	2719915	et	4	main
põhjani	doc_542009824763_item	2719916	et	3	main
jooma	doc_542009824763_item	2719917	et	4	main
oma	doc_542009824763_item	2719918	et	4	main
kokteili	doc_542009824763_item	2719919	et	4	main
ema	doc_542009824763_item	2719920	et	4	main
eluviisi	doc_542009824763_item	2719875	et	4	main
muutma	doc_542009824763_item	2719876	et	3	main
muutub	doc_542009824763_item	2719878	et	3	main
pidevalt	doc_542009824763_item	2719879	et	4	main
sõbralle	doc_542009824763_item	2719907	et	4	main
söötma	doc_542009824763_item	2719922	et	3	main
pere	doc_542009824763_item	2719924	et	4	main
peab	doc_542009824763_item	2719926	et	4	main
sööma	doc_542009824763_item	2719927	et	4	main
kirja	doc_542009824763_item	2719933	et	4	main
вредны	doc_542009824764_item	2719957	et	2	main
могут	doc_542009824764_item	2719962	et	2	main
и	doc_542009824764_item	2719965	et	2	main
и	doc_542009824764_item	2719973	et	2	main
также	doc_542009824764_item	2719981	et	2	main
животных	doc_542009824764_item	2720017	et	2	main
pooleli	doc_542009824763_item	2719887	et	3	main
jätma	doc_542009824763_item	2719888	et	3	main
andrus	doc_542009824763_item	2719889	et	3	main
kõigest	doc_542009824763_item	2719890	et	4	main
vöö	doc_542009824763_item	2719896	et	4	main
harutama	doc_542009824763_item	2719897	et	3	main
andrus	doc_542009824763_item	2719898	et	3	main
ja	doc_542009824763_item	2719909	et	3	main
oma	doc_542009824763_item	2719923	et	4	main
oma	doc_542009824763_item	2719931	et	4	main
vanaemale	doc_542009824763_item	2719932	et	3	main
много	doc_542009824764_item	2719951	et	2	main
отходы	doc_542009824764_item	2719955	et	2	main
человека	doc_542009824764_item	2719960	et	2	main
например	doc_542009824764_item	2719967	et	2	main
различные	doc_542009824764_item	2719971	et	2	main
может	doc_542009824764_item	2719976	et	2	main
рак	doc_542009824764_item	2719978	et	2	main
для	doc_542009824764_item	2720011	et	2	main
мясо	doc_542009824764_item	2720015	et	2	main
разные	doc_542009824764_item	2720020	et	2	main
водоемы	doc_542009824764_item	2720023	et	2	main
рыбы	doc_542009824764_item	2720028	et	2	main
в	doc_542009824764_item	2720033	et	2	main
который	doc_542009824764_item	2720036	et	2	main
портит	doc_542009824764_item	2720041	et	2	main
воды	doc_542009824764_item	2720045	et	2	main
воздуха	doc_542009824764_item	2720048	et	2	main
опасны	doc_542009824764_item	2720053	et	2	main
о	doc_542009824764_item	2720058	et	2	main
себе	doc_542009824764_item	2720063	et	2	main
ja	doc_542009824764_item	2720067	et	3	main
ajal	doc_542009824764_item	2720071	et	4	main
olemas	doc_542009824764_item	2720073	et	4	main
keemilised	doc_542009824764_item	2720074	et	4	main
tööstused	doc_542009824764_item	2720075	et	3	main
sellest	doc_542009824764_item	2720118	et	4	main
lõunas	doc_542009824763_item	2719925	et	3	main
kirja	doc_542009824763_item	2719930	et	4	main
опасны	doc_542009824764_item	2719942	et	2	main
существуют	doc_542009824764_item	2719946	et	2	main
которые	doc_542009824764_item	2719949	et	2	main
эти	doc_542009824764_item	2719954	et	2	main
здоровья	doc_542009824764_item	2719959	et	2	main
вызывать	doc_542009824764_item	2719963	et	2	main
в	doc_542009824764_item	2719968	et	2	main
добавляют	doc_542009824764_item	2719970	et	2	main
что	doc_542009824764_item	2719975	et	2	main
отходы	doc_542009824764_item	2719980	et	2	main
для	doc_542009824764_item	2719983	et	2	main
природы	doc_542009824764_item	2719984	et	2	main
продукты	doc_542009824764_item	2719985	et	2	main
которые	doc_542009824764_item	2719986	et	2	main
выкидывают	doc_542009824764_item	2719987	et	2	main
на	doc_542009824764_item	2719988	et	2	main
начинают	doc_542009824764_item	2719990	et	2	main
со	doc_542009824764_item	2719991	et	2	main
свалки	doc_542009824764_item	2719989	et	2	main
временем	doc_542009824764_item	2719992	et	2	main
разлагаться	doc_542009824764_item	2719993	et	2	main
может	doc_542009824764_item	2719995	et	2	main
что	doc_542009824764_item	2719994	et	2	main
привести	doc_542009824764_item	2719996	et	2	main
к	doc_542009824764_item	2719997	et	2	main
болезням	doc_542009824764_item	2719998	et	2	main
они	doc_542009824764_item	2719999	et	2	main
поступают	doc_542009824764_item	2720000	et	2	main
в	doc_542009824764_item	2720001	et	2	main
почву	doc_542009824764_item	2720002	et	2	main
в	doc_542009824764_item	2720003	et	2	main
воздух	doc_542009824764_item	2720004	et	2	main
и	doc_542009824764_item	2720005	et	2	main
в	doc_542009824764_item	2720006	et	2	main
воду	doc_542009824764_item	2720007	et	2	main
это	doc_542009824764_item	2720009	et	2	main
водоёмы	doc_542009824764_item	2720008	et	2	main
питание	doc_542009824764_item	2720010	et	2	main
животных	doc_542009824764_item	2720012	et	2	main
едят	doc_542009824764_item	2720014	et	2	main
среда	doc_542009824764_item	2720024	et	2	main
токсичные	doc_542009824764_item	2720030	et	2	main
человек	doc_542009824764_item	2720035	et	2	main
этой	doc_542009824764_item	2720039	et	2	main
загрязнение	doc_542009824764_item	2720044	et	2	main
связаны	doc_542009824764_item	2720049	et	2	main
люди	doc_542009824764_item	2720056	et	2	main
и	doc_542009824764_item	2720061	et	2	main
meie	doc_542009824764_item	2720070	et	4	main
haigused	doc_542009824764_item	2720121	et	4	main
loomadele	doc_542009824764_item	2720131	et	3	main
inimesed	doc_542009824764_item	2720132	et	3	main
söövad	doc_542009824764_item	2720133	et	4	main
selle	doc_542009824764_item	2720134	et	4	main
nad	doc_542009824764_item	2720138	et	3	main
toksidilised	doc_542009824764_item	2720149	et	4	main
inimene	doc_542009824764_item	2720154	et	3	main
rosolje	doc_542009824765_item	2720187	et	4	main
kohv	doc_542009824765_item	2720214	et	3	main
menüü	doc_542009824766_item	2720218	et	4	main
kartulisalat	doc_542009824766_item	2720220	et	3	main
kook	doc_542009824766_item	2720247	et	3	main
šokolaadi-pähkli	doc_542009824766_item	2720249	et	2	main
mahl	doc_542009824766_item	2720254	et	3	main
valge	doc_542009824766_item	2720261	et	4	main
restoran	doc_542009824767_item	2720268	et	3	main
175	doc_542009824767_item	2720273	et	2	main
koha	doc_542009824767_item	2720278	et	4	main
supid	doc_542009824767_item	2720281	et	3	main
65	doc_542009824767_item	2720284	et	2	main
kalmaarisalat	doc_542009824767_item	2720290	et	4	main
40	doc_542009824767_item	2720321	et	2	main
menüü	doc_542009824768_item	2720323	et	4	main
lihaga	doc_542009824768_item	2720330	et	3	main
kaste	doc_542009824768_item	2720332	et	4	main
valge	doc_542009824768_item	2720333	et	4	main
kartulid	doc_542009824768_item	2720338	et	3	main
vormiroog	doc_542009824768_item	2720342	et	3	main
vahvlid	doc_542009824768_item	2720344	et	3	main
обитания	doc_542009824764_item	2720025	et	2	main
попавшие	doc_542009824764_item	2720032	et	2	main
рыбы	doc_542009824764_item	2720040	et	2	main
здоровье	doc_542009824764_item	2720043	et	2	main
между	doc_542009824764_item	2720050	et	2	main
заботесть	doc_542009824764_item	2720057	et	2	main
природе	doc_542009824764_item	2720060	et	2	main
on	doc_542009824764_item	2720065	et	4	main
on	doc_542009824764_item	2720072	et	4	main
tekkitavad	doc_542009824764_item	2720077	et	4	main
ohtlik	doc_542009824764_item	2720079	et	3	main
jäätmeid	doc_542009824764_item	2720082	et	3	main
inimese	doc_542009824764_item	2720085	et	4	main
tervisele	doc_542009824764_item	2720086	et	3	main
need	doc_542009824764_item	2720087	et	3	main
võivad	doc_542009824764_item	2720088	et	4	main
tekkitada	doc_542009824764_item	2720089	et	4	main
alergiat	doc_542009824764_item	2720090	et	4	main
ja	doc_542009824764_item	2720091	et	3	main
iiveldust	doc_542009824764_item	2720092	et	4	main
näiteks	doc_542009824764_item	2720093	et	4	main
mahlasse	doc_542009824764_item	2720094	et	3	main
pannakse	doc_542009824764_item	2720095	et	3	main
värv	doc_542009824764_item	2720096	et	3	main
ained	doc_542009824764_item	2720097	et	3	main
ja	doc_542009824764_item	2720098	et	3	main
konservantid	doc_542009824764_item	2720099	et	4	main
mis	doc_542009824764_item	2720100	et	4	main
võib	doc_542009824764_item	2720101	et	3	main
tekkitada	doc_542009824764_item	2720102	et	4	main
vähk	doc_542009824764_item	2720103	et	3	main
keemilised	doc_542009824764_item	2720104	et	4	main
tooted	doc_542009824764_item	2720105	et	3	main
on	doc_542009824764_item	2720106	et	4	main
ka	doc_542009824764_item	2720107	et	3	main
ohtlikud	doc_542009824764_item	2720108	et	3	main
loodusele	doc_542009824764_item	2720109	et	4	main
tooted	doc_542009824764_item	2720110	et	3	main
mida	doc_542009824764_item	2720111	et	4	main
viisatakse	doc_542009824764_item	2720112	et	4	main
prügimäele	doc_542009824764_item	2720113	et	3	main
aega	doc_542009824764_item	2720114	et	4	main
ajalt	doc_542009824764_item	2720115	et	4	main
hakkab	doc_542009824764_item	2720116	et	3	main
madanema	doc_542009824764_item	2720117	et	4	main
tekkitada	doc_542009824764_item	2720120	et	4	main
tabavad	doc_542009824764_item	2720123	et	4	main
imbuvad	doc_542009824764_item	2720148	et	4	main
sööb	doc_542009824764_item	2720156	et	3	main
kala	doc_542009824764_item	2720158	et	4	main
liha	doc_542009824764_item	2720159	et	4	main
kahjustab	doc_542009824764_item	2720160	et	3	main
krabisalat	doc_542009824765_item	2720186	et	3	main
porgandisalat	doc_542009824765_item	2720188	et	3	main
praed	doc_542009824765_item	2720189	et	4	main
kapsarullid	doc_542009824765_item	2720190	et	3	main
praetud	doc_542009824765_item	2720191	et	4	main
supid	doc_542009824765_item	2720197	et	3	main
seljanka	doc_542009824765_item	2720200	et	4	main
kartul	doc_542009824765_item	2720203	et	3	main
masikakompot	doc_542009824765_item	2720209	et	4	main
jäätis	doc_542009824765_item	2720211	et	3	main
õlu	doc_542009824765_item	2720216	et	3	main
mooritud	doc_542009824766_item	2720227	et	4	main
liha	doc_542009824766_item	2720228	et	4	main
vaba	doc_542009824766_item	2720253	et	4	main
kohv	doc_542009824766_item	2720256	et	3	main
limonaad	doc_542009824766_item	2720257	et	3	main
vein	doc_542009824766_item	2720259	et	3	main
šampinjonidega	doc_542009824767_item	2720279	et	2	main
kalasupp	doc_542009824767_item	2720282	et	3	main
kalaseljanka	doc_542009824767_item	2720285	et	4	main
salatid	doc_542009824767_item	2720287	et	3	main
krevetisalat	doc_542009824767_item	2720288	et	3	main
40	doc_542009824767_item	2720289	et	2	main
45	doc_542009824767_item	2720291	et	2	main
aedviljasalat	doc_542009824767_item	2720292	et	3	main
30	doc_542009824767_item	2720293	et	2	main
kapsasupp	doc_542009824768_item	2720325	et	3	main
punane	doc_542009824768_item	2720335	et	4	main
kaste	doc_542009824768_item	2720336	et	4	main
keedetud	doc_542009824768_item	2720337	et	4	main
riis	doc_542009824768_item	2720339	et	3	main
marmelaad	doc_542009824768_item	2720341	et	3	main
želee	doc_542009824768_item	2720343	et	2	main
morss	doc_542009824768_item	2720347	et	3	main
liköör	doc_542009824768_item	2720350	et	3	main
ja	doc_542009824764_item	2720137	et	3	main
ained	doc_542009824764_item	2720150	et	3	main
saatus	doc_542009824764_item	2720152	et	3	main
kes	doc_542009824764_item	2720155	et	4	main
vee	doc_542009824764_item	2720164	et	3	main
mulla	doc_542009824764_item	2720165	et	4	main
ja	doc_542009824764_item	2720166	et	3	main
õhu	doc_542009824764_item	2720167	et	3	main
on	doc_542009824764_item	2720168	et	4	main
omavahel	doc_542009824764_item	2720169	et	3	main
kinni	doc_542009824764_item	2720170	et	3	main
seotud	doc_542009824764_item	2720171	et	4	main
ja	doc_542009824764_item	2720172	et	3	main
ohtlik	doc_542009824764_item	2720173	et	3	main
elule	doc_542009824764_item	2720174	et	3	main
inimesed	doc_542009824764_item	2720175	et	3	main
hoidke	doc_542009824764_item	2720176	et	3	main
meie	doc_542009824764_item	2720177	et	4	main
loodust	doc_542009824764_item	2720178	et	4	main
ja	doc_542009824764_item	2720179	et	3	main
ennest	doc_542009824764_item	2720180	et	3	main
harjutus	doc_542009824765_item	2720181	et	4	main
menüü	doc_542009824765_item	2720182	et	4	main
salatid	doc_542009824765_item	2720183	et	3	main
kartulisalat	doc_542009824765_item	2720184	et	3	main
haigeks	doc_542009824764_item	2720141	et	4	main
veekogud	doc_542009824764_item	2720142	et	3	main
on	doc_542009824764_item	2720143	et	4	main
ka	doc_542009824764_item	2720144	et	3	main
elukoht	doc_542009824764_item	2720145	et	3	main
kaladele	doc_542009824764_item	2720146	et	3	main
kaladesse	doc_542009824764_item	2720147	et	3	main
selle	doc_542009824764_item	2720157	et	4	main
tervist	doc_542009824764_item	2720162	et	4	main
saastatud	doc_542009824764_item	2720163	et	4	main
singiga	doc_542009824765_item	2720185	et	3	main
sealiha	doc_542009824765_item	2720195	et	4	main
kotletid	doc_542009824765_item	2720196	et	3	main
riis	doc_542009824765_item	2720205	et	3	main
magustoidud	doc_542009824765_item	2720207	et	3	main
tee	doc_542009824765_item	2720213	et	4	main
salatid	doc_542009824766_item	2720219	et	3	main
singisalat	doc_542009824766_item	2720222	et	4	main
praed	doc_542009824766_item	2720224	et	4	main
praetud	doc_542009824766_item	2720225	et	4	main
riis	doc_542009824766_item	2720238	et	3	main
köögiviljad	doc_542009824766_item	2720240	et	3	main
maasika	doc_542009824766_item	2720244	et	3	main
alkohooli	doc_542009824766_item	2720258	et	3	main
punane	doc_542009824766_item	2720260	et	4	main
viin	doc_542009824766_item	2720262	et	4	main
õlu	doc_542009824766_item	2720263	et	3	main
tume	doc_542009824766_item	2720264	et	3	main
hele	doc_542009824766_item	2720265	et	3	main
praed	doc_542009824767_item	2720271	et	4	main
155	doc_542009824767_item	2720276	et	2	main
serbiapäraselt	doc_542009824767_item	2720283	et	4	main
55	doc_542009824767_item	2720286	et	2	main
harjutus	doc_542009824768_item	2720322	et	4	main
külmsupp	doc_542009824768_item	2720326	et	3	main
makaronid	doc_542009824768_item	2720340	et	3	main
rulaad	doc_542009824768_item	2720346	et	3	main
konjak	doc_542009824768_item	2720351	et	3	main
grintvein	doc_542009824768_item	2720352	et	4	main
kana	doc_542009824765_item	2720192	et	4	main
borš	doc_542009824765_item	2720198	et	2	main
makaronid	doc_542009824765_item	2720204	et	3	main
mannavaht	doc_542009824765_item	2720208	et	3	main
marjažele	doc_542009824765_item	2720210	et	2	main
joogit	doc_542009824765_item	2720212	et	3	main
apelsinimahl	doc_542009824765_item	2720215	et	3	main
harjutus	doc_542009824766_item	2720217	et	4	main
pilaf	doc_542009824766_item	2720231	et	4	main
supid	doc_542009824766_item	2720232	et	3	main
kilpkonnasupp	doc_542009824766_item	2720233	et	3	main
hernesupp	doc_542009824766_item	2720234	et	3	main
seenesupp	doc_542009824766_item	2720235	et	3	main
peedisupp	doc_542009824766_item	2720236	et	3	main
lisandid	doc_542009824766_item	2720237	et	3	main
praetud	doc_542009824766_item	2720239	et	4	main
kartul	doc_542009824766_item	2720241	et	3	main
magustoidud	doc_542009824766_item	2720243	et	3	main
vahukoorega	doc_542009824766_item	2720245	et	3	main
glasuuri	doc_542009824766_item	2720246	et	4	main
joogid	doc_542009824766_item	2720251	et	4	main
tee	doc_542009824766_item	2720255	et	4	main
harjutus	doc_542009824767_item	2720267	et	4	main
lambaruulad	doc_542009824767_item	2720272	et	4	main
kalmaarirõngad	doc_542009824767_item	2720274	et	4	main
220	doc_542009824767_item	2720280	et	2	main
lisandid	doc_542009824767_item	2720294	et	3	main
riis	doc_542009824767_item	2720295	et	3	main
10	doc_542009824767_item	2720296	et	2	main
20	doc_542009824767_item	2720298	et	2	main
keedukartul	doc_542009824767_item	2720297	et	3	main
spinat	doc_542009824767_item	2720299	et	3	main
15	doc_542009824767_item	2720300	et	2	main
magustoidud	doc_542009824767_item	2720301	et	3	main
mandlikovrike	doc_542009824767_item	2720302	et	4	main
jäätisega	doc_542009824767_item	2720303	et	3	main
65	doc_542009824767_item	2720304	et	2	main
vene	doc_542009824767_item	2720305	et	4	main
šokolaadi	doc_542009824767_item	2720306	et	2	main
50	doc_542009824767_item	2720308	et	2	main
charlotte	doc_542009824767_item	2720307	et	4	main
pannkoogid	doc_542009824767_item	2720309	et	3	main
vaniljekastmega	doc_542009824767_item	2720310	et	3	main
50	doc_542009824767_item	2720311	et	2	main
joodid	doc_542009824767_item	2720312	et	4	main
roosa	doc_542009824767_item	2720313	et	4	main
majavein	doc_542009824767_item	2720314	et	3	main
35	doc_542009824767_item	2720315	et	2	main
rumm	doc_542009824767_item	2720316	et	3	main
bacardi	doc_542009824767_item	2720317	et	4	main
40	doc_542009824767_item	2720318	et	2	main
vana	doc_542009824767_item	2720319	et	4	main
tallinn	doc_542009824767_item	2720320	et	4	main
rostbiif	doc_542009824768_item	2720328	et	3	main
seen	doc_542009824768_item	2720331	et	3	main
kissell	doc_542009824768_item	2720348	et	3	main
limonaad	doc_542009824768_item	2720349	et	3	main
borš	doc_542009824768_item	2720324	et	2	main
biifsteeks	doc_542009824768_item	2720327	et	4	main
hakklihapallid	doc_542009824768_item	2720329	et	3	main
kaste	doc_542009824768_item	2720334	et	4	main
kulitš	doc_542009824768_item	2720345	et	2	main
vastus	doc_542009824772_item	2720649	et	3	main
plussiks	doc_542009824772_item	2720655	et	4	main
tegema	doc_542009824772_item	2720658	et	3	main
on	doc_542009824772_item	2720674	et	4	main
suur	doc_542009824772_item	2720677	et	3	main
5	doc_542009824772_item	2720719	et	2	main
eriti	doc_542009824772_item	2720720	et	3	main
kaupade	doc_542009824772_item	2720730	et	3	main
proovi	doc_542009824772_item	2720731	et	4	main
näidiseid	doc_542009824772_item	2720732	et	3	main
on	doc_542009824772_item	2720656	et	4	main
teha	doc_542009824772_item	2720665	et	3	main
kaupluses	doc_542009824772_item	2720667	et	3	main
ja	doc_542009824772_item	2720669	et	3	main
kaubamajas	doc_542009824772_item	2720670	et	3	main
sellepärast	doc_542009824772_item	2720671	et	3	main
et	doc_542009824772_item	2720672	et	3	main
seal	doc_542009824772_item	2720673	et	4	main
head	doc_542009824772_item	2720679	et	4	main
võib	doc_542009824772_item	2720682	et	3	main
vaatama	doc_542009824772_item	2720684	et	3	main
juures	doc_542009824772_item	2720724	et	4	main
mõnede	doc_542009824772_item	2720737	et	3	main
kataloogide	doc_542009824772_item	2720738	et	3	main
head	doc_542009824772_item	2720744	et	4	main
1	doc_542009824772_item	2720746	et	2	main
ja	doc_542009824772_item	2720753	et	3	main
tihti	doc_542009824772_item	2720757	et	3	main
kvaliteedile	doc_542009824772_item	2720759	et	3	main
häirib	doc_542009824772_item	2720762	et	3	main
kauba	doc_542009824772_item	2720763	et	3	main
kriitika	doc_542009824772_item	2720783	et	4	main
minu	doc_542009824773_item	2720821	et	3	main
3	doc_542009824773_item	2720837	et	2	main
5	doc_542009824773_item	2720855	et	2	main
tänapäeva	doc_542009824773_item	2720869	et	4	main
väga	doc_542009824773_item	2720873	et	3	main
igas	doc_542009824773_item	2720877	et	3	main
hea	doc_542009824773_item	2720885	et	4	main
maksab	doc_542009824773_item	2720887	et	3	main
meeldiv	doc_542009824773_item	2720895	et	4	main
klient	doc_542009824773_item	2720910	et	3	main
päevas	doc_542009824773_item	2720922	et	3	main
sooja	doc_542009824773_item	2720923	et	4	main
toitu	doc_542009824773_item	2720924	et	4	main
16	doc_542009824773_item	2720925	et	2	main
supermarketis	doc_542009824773_item	2720926	et	4	main
pidasime	doc_542009824774_item	2720936	et	3	main
laulsime	doc_542009824774_item	2720950	et	3	main
mulle	doc_542009824774_item	2720953	et	4	main
soe	doc_542009824774_item	2720955	et	4	main
laps	doc_542009824774_item	2720959	et	4	main
küsimusele	doc_542009824772_item	2720650	et	4	main
1	doc_542009824772_item	2720651	et	2	main
sisseoste	doc_542009824772_item	2720659	et	3	main
istudes	doc_542009824772_item	2720661	et	4	main
ma	doc_542009824772_item	2720663	et	3	main
valik	doc_542009824772_item	2720678	et	3	main
ja	doc_542009824772_item	2720681	et	3	main
järele	doc_542009824772_item	2720683	et	4	main
meeldiv	doc_542009824772_item	2720721	et	4	main
kataloogide	doc_542009824772_item	2720723	et	3	main
see	doc_542009824772_item	2720725	et	3	main
et	doc_542009824772_item	2720726	et	3	main
paljud	doc_542009824772_item	2720727	et	3	main
kataloogid	doc_542009824772_item	2720728	et	4	main
läbivaatamist	doc_542009824772_item	2720739	et	3	main
on	doc_542009824772_item	2720749	et	4	main
pikk	doc_542009824772_item	2720750	et	4	main
ootamis	doc_542009824772_item	2720751	et	4	main
tähtaeg	doc_542009824772_item	2720752	et	3	main
ei	doc_542009824772_item	2720755	et	4	main
oodatud	doc_542009824772_item	2720758	et	4	main
ei	doc_542009824772_item	2720769	et	4	main
hästi	doc_542009824772_item	2720771	et	3	main
halastamatu	doc_542009824772_item	2720782	et	4	main
5	doc_542009824772_item	2720784	et	2	main
võib	doc_542009824772_item	2720786	et	3	main
liiga	doc_542009824772_item	2720788	et	4	main
liiga	doc_542009824772_item	2720791	et	4	main
tallinnas	doc_542009824773_item	2720829	et	4	main
2	doc_542009824773_item	2720830	et	2	main
paljude	doc_542009824773_item	2720831	et	3	main
kaupade	doc_542009824773_item	2720832	et	3	main
hind	doc_542009824773_item	2720833	et	3	main
oli	doc_542009824773_item	2720834	et	3	main
väga	doc_542009824773_item	2720835	et	3	main
soodne	doc_542009824773_item	2720836	et	3	main
mõnedes	doc_542009824773_item	2720838	et	3	main
poedes	doc_542009824773_item	2720839	et	4	main
saab	doc_542009824773_item	2720840	et	3	main
näitab	doc_542009824773_item	2720846	et	3	main
ostes	doc_542009824773_item	2720848	et	4	main
kallist	doc_542009824773_item	2720850	et	4	main
tuleb	doc_542009824773_item	2720851	et	3	main
kõike	doc_542009824773_item	2720852	et	4	main
hästi	doc_542009824773_item	2720853	et	3	main
tarbial	doc_542009824773_item	2720864	et	4	main
õigus	doc_542009824773_item	2720867	et	4	main
9	doc_542009824773_item	2720884	et	2	main
kaup	doc_542009824773_item	2720886	et	3	main
on	doc_542009824773_item	2720891	et	4	main
11	doc_542009824773_item	2720894	et	2	main
teenindus	doc_542009824773_item	2720896	et	4	main
hea	doc_542009824773_item	2720898	et	4	main
12	doc_542009824773_item	2720900	et	2	main
aga	doc_542009824773_item	2720901	et	3	main
negatiivne	doc_542009824773_item	2720902	et	3	main
suhtumise	doc_542009824773_item	2720903	et	4	main
13	doc_542009824773_item	2720904	et	2	main
on	doc_542009824773_item	2720927	et	4	main
palju	doc_542009824773_item	2720929	et	4	main
asju	doc_542009824773_item	2720930	et	3	main
osta	doc_542009824773_item	2720931	et	4	main
klassiõhtul	doc_542009824774_item	2720940	et	3	main
kooke	doc_542009824774_item	2720942	et	4	main
puuvilju	doc_542009824774_item	2720944	et	3	main
lasteaijas	doc_542009824774_item	2720965	et	4	main
sõime	doc_542009824775_item	2721014	et	4	main
küpsid	doc_542009824775_item	2721015	et	3	main
ja	doc_542009824775_item	2721016	et	3	main
bluus	doc_542009824775_item	2721039	et	3	main
klassiõhtul	doc_542009824775_item	2721041	et	3	main
ei	doc_542009824775_item	2721052	et	4	main
selleks	doc_542009824775_item	2721054	et	4	main
et	doc_542009824775_item	2721055	et	3	main
väga	doc_542009824775_item	2721056	et	3	main
vähem	doc_542009824775_item	2721057	et	4	main
inimesed	doc_542009824775_item	2721058	et	3	main
kataloogika	doc_542009824772_item	2720652	et	4	main
ubandused	doc_542009824772_item	2720653	et	4	main
suureks	doc_542009824772_item	2720654	et	4	main
võimalus	doc_542009824772_item	2720657	et	3	main
2	doc_542009824772_item	2720662	et	2	main
eelistan	doc_542009824772_item	2720664	et	3	main
sisseoste	doc_542009824772_item	2720666	et	3	main
marketis	doc_542009824772_item	2720668	et	4	main
madalad	doc_542009824772_item	2720675	et	3	main
kvalited	doc_542009824772_item	2720680	et	4	main
kaubad	doc_542009824772_item	2720685	et	3	main
näiteid	doc_542009824772_item	2720686	et	3	main
aga	doc_542009824772_item	2720687	et	3	main
siiski	doc_542009824772_item	2720688	et	4	main
mitte	doc_542009824772_item	2720689	et	3	main
pildikesi	doc_542009824772_item	2720690	et	4	main
3	doc_542009824772_item	2720691	et	2	main
kataloogikaubandused	doc_542009824772_item	2720692	et	3	main
peamine	doc_542009824772_item	2720693	et	3	main
eelis	doc_542009824772_item	2720694	et	3	main
teiste	doc_542009824772_item	2720695	et	4	main
kohtade	doc_542009824772_item	2720696	et	3	main
ees	doc_542009824772_item	2720697	et	4	main
on	doc_542009824772_item	2720698	et	4	main
see	doc_542009824772_item	2720699	et	3	main
et	doc_542009824772_item	2720700	et	3	main
võib	doc_542009824772_item	2720701	et	3	main
osta	doc_542009824772_item	2720702	et	4	main
firma	doc_542009824772_item	2720703	et	4	main
kaupu	doc_542009824772_item	2720704	et	3	main
madala	doc_542009824772_item	2720705	et	3	main
hinnaga	doc_542009824772_item	2720706	et	3	main
4	doc_542009824772_item	2720707	et	2	main
ma	doc_542009824772_item	2720708	et	3	main
olen	doc_542009824772_item	2720709	et	3	main
ülimalt	doc_542009824772_item	2720710	et	4	main
rahul	doc_542009824772_item	2720711	et	4	main
kataloogiga	doc_542009824772_item	2720712	et	3	main
kui	doc_542009824772_item	2720713	et	3	main
tema	doc_542009824772_item	2720714	et	4	main
omanikud	doc_542009824772_item	2720715	et	3	main
tegid	doc_542009824772_item	2720716	et	4	main
kvaliteetseid	doc_542009824772_item	2720717	et	3	main
diivanil	doc_542009824772_item	2720660	et	3	main
hinnad	doc_542009824772_item	2720676	et	3	main
fotosid	doc_542009824772_item	2720718	et	3	main
on	doc_542009824772_item	2720722	et	4	main
tasuta	doc_542009824772_item	2720733	et	4	main
6	doc_542009824772_item	2720734	et	2	main
ma	doc_542009824772_item	2720735	et	3	main
naudin	doc_542009824772_item	2720736	et	3	main
on	doc_542009824772_item	2720743	et	4	main
tasemel	doc_542009824772_item	2720745	et	3	main
kataloogid	doc_542009824772_item	2720747	et	4	main
puuduseks	doc_542009824772_item	2720748	et	4	main
kaup	doc_542009824772_item	2720754	et	3	main
4	doc_542009824772_item	2720775	et	2	main
võib	doc_542009824772_item	2720777	et	3	main
valmistada	doc_542009824772_item	2720778	et	3	main
tarbijaid	doc_542009824772_item	2720785	et	4	main
ehmatada	doc_542009824772_item	2720787	et	3	main
kõrged	doc_542009824772_item	2720789	et	3	main
kvaliteet	doc_542009824772_item	2720793	et	3	main
või	doc_542009824772_item	2720794	et	4	main
liiga	doc_542009824772_item	2720795	et	4	main
pikad	doc_542009824772_item	2720796	et	4	main
ootamise	doc_542009824772_item	2720797	et	4	main
tähtajad	doc_542009824772_item	2720798	et	3	main
6	doc_542009824772_item	2720799	et	2	main
kuidagi	doc_542009824772_item	2720800	et	3	main
ei	doc_542009824772_item	2720801	et	4	main
saa	doc_542009824772_item	2720802	et	4	main
rahule	doc_542009824772_item	2720803	et	4	main
jääda	doc_542009824772_item	2720804	et	4	main
riknenud	doc_542009824772_item	2720805	et	4	main
kaupadega	doc_542009824772_item	2720806	et	3	main
7	doc_542009824772_item	2720807	et	2	main
kindlasti	doc_542009824772_item	2720808	et	3	main
vajaks	doc_542009824772_item	2720809	et	4	main
ümberkorraldamist	doc_542009824772_item	2720810	et	3	main
trükis	doc_542009824772_item	2720811	et	4	main
avaldatavate	doc_542009824772_item	2720812	et	4	main
fotode	doc_542009824772_item	2720813	et	3	main
kvaliteet	doc_542009824772_item	2720814	et	3	main
ja	doc_542009824772_item	2720815	et	3	main
toodangu	doc_542009824772_item	2720816	et	3	main
kvaliteedi	doc_542009824772_item	2720817	et	3	main
tõstmine	doc_542009824772_item	2720818	et	4	main
harjutus	doc_542009824773_item	2720819	et	4	main
1	doc_542009824773_item	2720820	et	2	main
saadavad	doc_542009824772_item	2720729	et	4	main
7	doc_542009824772_item	2720740	et	2	main
vasta	doc_542009824772_item	2720756	et	4	main
valimusest	doc_542009824772_item	2720764	et	4	main
piiratus	doc_542009824772_item	2720765	et	4	main
3	doc_542009824772_item	2720766	et	2	main
väga	doc_542009824772_item	2720767	et	3	main
ärritadan	doc_542009824772_item	2720768	et	4	main
võimalda	doc_542009824772_item	2720770	et	4	main
nägema	doc_542009824772_item	2720773	et	3	main
jaoks	doc_542009824773_item	2720822	et	4	main
käia	doc_542009824773_item	2720826	et	4	main
suurtes	doc_542009824773_item	2720827	et	3	main
lisapakkumise	doc_542009824773_item	2720842	et	3	main
oma	doc_542009824773_item	2720844	et	4	main
mul	doc_542009824773_item	2720859	et	3	main
on	doc_542009824773_item	2720865	et	4	main
toimub	doc_542009824773_item	2720880	et	3	main
kauba	doc_542009824773_item	2720881	et	3	main
tagasise	doc_542009824773_item	2720882	et	4	main
vastuvõtt	doc_542009824773_item	2720883	et	3	main
10	doc_542009824773_item	2720889	et	2	main
päev	doc_542009824773_item	2720893	et	3	main
loob	doc_542009824773_item	2720897	et	3	main
ise	doc_542009824773_item	2720906	et	4	main
olen	doc_542009824773_item	2720907	et	3	main
kord	doc_542009824773_item	2720921	et	4	main
väga	doc_542009824773_item	2720932	et	3	main
soodsalt	doc_542009824773_item	2720933	et	4	main
essee	doc_542009824774_item	2720934	et	4	main
klassiõhtuid	doc_542009824774_item	2720937	et	3	main
tansisime	doc_542009824774_item	2720949	et	4	main
õhkkond	doc_542009824774_item	2720956	et	3	main
ei	doc_542009824775_item	2721002	et	4	main
jõime	doc_542009824775_item	2721009	et	3	main
kui	doc_542009824775_item	2721020	et	3	main
riided	doc_542009824775_item	2721025	et	3	main
teksaga	doc_542009824775_item	2721032	et	4	main
tüdrukul	doc_542009824775_item	2721034	et	3	main
ilusaid	doc_542009824775_item	2721037	et	3	main
mängime	doc_542009824775_item	2721044	et	3	main
räägime	doc_542009824775_item	2721046	et	3	main
meeldi	doc_542009824775_item	2721053	et	4	main
me	doc_542009824775_item	2721065	et	4	main
istume	doc_542009824775_item	2721066	et	3	main
kodus	doc_542009824775_item	2721069	et	4	main
klassiõhtud	doc_542009824776_item	2721078	et	3	main
me	doc_542009824776_item	2721079	et	4	main
teed	doc_542009824776_item	2721092	et	4	main
sõime	doc_542009824776_item	2721094	et	4	main
magusaid	doc_542009824776_item	2721095	et	3	main
või	doc_542009824776_item	2721100	et	4	main
küpsiseid	doc_542009824776_item	2721101	et	3	main
tavaliselt	doc_542009824776_item	2721107	et	4	main
vist	doc_542009824776_item	2721138	et	4	main
kokku	doc_542009824776_item	2721147	et	3	main
sest	doc_542009824776_item	2721148	et	4	main
ma	doc_542009824776_item	2721154	et	3	main
kus	doc_542009824776_item	2721158	et	3	main
elab	doc_542009824776_item	2721160	et	3	main
ja	doc_542009824776_item	2721161	et	3	main
aga	doc_542009824776_item	2721165	et	3	main
juba	doc_542009824777_item	2721218	et	3	main
jalas	doc_542009824777_item	2721220	et	4	main
poisid	doc_542009824777_item	2721236	et	4	main
nüüd	doc_542009824777_item	2721239	et	4	main
harva	doc_542009824777_item	2721245	et	4	main
se	doc_542009824777_item	2721246	et	4	main
sõitis	doc_542009824777_item	2721259	et	3	main
eestist	doc_542009824777_item	2721261	et	3	main
europas	doc_542009824777_item	2721268	et	4	main
koos	doc_542009824777_item	2721271	et	4	main
peavad	doc_542009824777_item	2721274	et	4	main
klassiõhtuid	doc_542009824777_item	2721275	et	3	main
midagi	doc_542009824777_item	2721285	et	4	main
teevad	doc_542009824777_item	2721286	et	3	main
see	doc_542009824777_item	2721288	et	3	main
saladus	doc_542009824777_item	2721290	et	3	main
klassiõhtud	doc_542009824778_item	2721292	et	3	main
meeldib	doc_542009824778_item	2721322	et	3	main
sest	doc_542009824778_item	2721324	et	4	main
ma	doc_542009824778_item	2721326	et	3	main
paljud	doc_542009824772_item	2720741	et	3	main
kaubad	doc_542009824772_item	2720742	et	3	main
2	doc_542009824772_item	2720760	et	2	main
pisut	doc_542009824772_item	2720761	et	3	main
ära	doc_542009824772_item	2720772	et	4	main
kaupad	doc_542009824772_item	2720774	et	4	main
pettumuse	doc_542009824772_item	2720776	et	4	main
kummardajate	doc_542009824772_item	2720779	et	4	main
ja	doc_542009824772_item	2720780	et	3	main
austajate	doc_542009824772_item	2720781	et	4	main
hinnad	doc_542009824772_item	2720790	et	3	main
halb	doc_542009824772_item	2720792	et	3	main
suur	doc_542009824773_item	2720824	et	3	main
klient	doc_542009824773_item	2720841	et	3	main
et	doc_542009824773_item	2720847	et	3	main
midagi	doc_542009824773_item	2720849	et	4	main
oma	doc_542009824773_item	2720856	et	4	main
mälestus	doc_542009824773_item	2720861	et	4	main
tarbiakaitse	doc_542009824773_item	2720866	et	4	main
7	doc_542009824773_item	2720868	et	2	main
kauplustes	doc_542009824773_item	2720870	et	4	main
on	doc_542009824773_item	2720871	et	4	main
suur	doc_542009824773_item	2720874	et	3	main
peaaegu	doc_542009824773_item	2720876	et	3	main
täna	doc_542009824773_item	2720890	et	4	main
kordaläinud	doc_542009824773_item	2720892	et	4	main
mina	doc_542009824773_item	2720905	et	4	main
oli	doc_542009824773_item	2720823	et	3	main
elamus	doc_542009824773_item	2720825	et	4	main
marketites	doc_542009824773_item	2720828	et	4	main
4	doc_542009824773_item	2720843	et	2	main
kogemus	doc_542009824773_item	2720845	et	3	main
kontrollida	doc_542009824773_item	2720854	et	4	main
puhkusest	doc_542009824773_item	2720857	et	4	main
jäi	doc_542009824773_item	2720858	et	3	main
hea	doc_542009824773_item	2720860	et	4	main
6	doc_542009824773_item	2720862	et	2	main
igal	doc_542009824773_item	2720863	et	3	main
kaubavalik	doc_542009824773_item	2720872	et	3	main
8	doc_542009824773_item	2720875	et	2	main
müügi	doc_542009824773_item	2720878	et	4	main
kohas	doc_542009824773_item	2720879	et	4	main
rohkem	doc_542009824773_item	2720888	et	4	main
tuju	doc_542009824773_item	2720899	et	4	main
üpris	doc_542009824773_item	2720908	et	3	main
rahulolev	doc_542009824773_item	2720909	et	4	main
14	doc_542009824773_item	2720911	et	2	main
juhuslik	doc_542009824773_item	2720912	et	3	main
tutvus	doc_542009824773_item	2720913	et	4	main
võib	doc_542009824773_item	2720914	et	3	main
olla	doc_542009824773_item	2720915	et	3	main
saatuslik	doc_542009824773_item	2720916	et	3	main
15	doc_542009824773_item	2720917	et	2	main
inimene	doc_542009824773_item	2720918	et	3	main
vajab	doc_542009824773_item	2720919	et	3	main
vähemalt	doc_542009824773_item	2720920	et	4	main
koolis	doc_542009824774_item	2720938	et	4	main
sõime	doc_542009824774_item	2720941	et	4	main
ja	doc_542009824774_item	2720945	et	3	main
limonaadi	doc_542009824774_item	2720947	et	4	main
me	doc_542009824774_item	2720948	et	4	main
mängisime	doc_542009824774_item	2720952	et	3	main
meeldis	doc_542009824774_item	2720954	et	3	main
klassiõhtul	doc_542009824774_item	2720957	et	3	main
tulevad	doc_542009824774_item	2720966	et	4	main
kokku	doc_542009824774_item	2720967	et	3	main
lapsed	doc_542009824774_item	2720968	et	3	main
vanemad	doc_542009824774_item	2720969	et	4	main
ja	doc_542009824774_item	2720970	et	3	main
õpetajad	doc_542009824774_item	2720971	et	4	main
kõik	doc_542009824774_item	2720973	et	4	main
palju	doc_542009824775_item	2721004	et	4	main
toitu	doc_542009824775_item	2721005	et	4	main
tordi	doc_542009824775_item	2721019	et	3	main
võimalik	doc_542009824773_item	2720928	et	3	main
me	doc_542009824774_item	2720935	et	4	main
me	doc_542009824774_item	2720939	et	4	main
salatid	doc_542009824774_item	2720943	et	3	main
jõime	doc_542009824774_item	2720946	et	3	main
ja	doc_542009824774_item	2720951	et	3	main
minu	doc_542009824774_item	2720958	et	3	main
veedab	doc_542009824774_item	2720960	et	3	main
me	doc_542009824774_item	2720972	et	4	main
tuleme	doc_542009824774_item	2720974	et	3	main
oma	doc_542009824774_item	2720975	et	4	main
kookide	doc_542009824774_item	2720976	et	3	main
tortidega	doc_542009824774_item	2720977	et	3	main
küpsistega	doc_542009824774_item	2720978	et	3	main
esiljagu	doc_542009824774_item	2720979	et	4	main
mängime	doc_542009824774_item	2720980	et	3	main
erinevaid	doc_542009824774_item	2720981	et	4	main
mängu	doc_542009824774_item	2720982	et	4	main
pärast	doc_542009824774_item	2720983	et	4	main
joome	doc_542009824774_item	2720985	et	4	main
seda	doc_542009824774_item	2720984	et	3	main
teed	doc_542009824774_item	2720986	et	4	main
majustustega	doc_542009824774_item	2720987	et	4	main
loodan	doc_542009824774_item	2720988	et	3	main
et	doc_542009824774_item	2720989	et	3	main
see	doc_542009824774_item	2720990	et	3	main
traditsioon	doc_542009824774_item	2720991	et	3	main
ei	doc_542009824774_item	2720992	et	4	main
ununie	doc_542009824774_item	2720993	et	4	main
essee	doc_542009824775_item	2720994	et	4	main
kõik	doc_542009824775_item	2720995	et	4	main
klassiõhtuid	doc_542009824775_item	2720996	et	3	main
me	doc_542009824775_item	2720997	et	4	main
peame	doc_542009824775_item	2720998	et	4	main
oma	doc_542009824775_item	2720999	et	4	main
kooliklassist	doc_542009824775_item	2721000	et	3	main
meil	doc_542009824775_item	2721001	et	4	main
oli	doc_542009824775_item	2721003	et	3	main
aega	doc_542009824774_item	2720961	et	4	main
oma	doc_542009824774_item	2720962	et	4	main
vanusega	doc_542009824774_item	2720963	et	4	main
lastega	doc_542009824774_item	2720964	et	3	main
nagu	doc_542009824775_item	2721006	et	3	main
me	doc_542009824775_item	2721008	et	4	main
tee	doc_542009824775_item	2721010	et	4	main
või	doc_542009824775_item	2721011	et	4	main
limonaad	doc_542009824775_item	2721012	et	3	main
ja	doc_542009824775_item	2721013	et	3	main
suur	doc_542009824775_item	2721022	et	3	main
poistel	doc_542009824775_item	2721024	et	3	main
oli	doc_542009824775_item	2721026	et	3	main
igapäeval	doc_542009824775_item	2721028	et	3	main
või	doc_542009824775_item	2721030	et	4	main
oli	doc_542009824775_item	2721036	et	3	main
tantsime	doc_542009824775_item	2721043	et	3	main
ja	doc_542009824775_item	2721045	et	3	main
ja	doc_542009824775_item	2721070	et	3	main
oma	doc_542009824775_item	2721072	et	4	main
elu	doc_542009824775_item	2721076	et	4	main
täpsemalt	doc_542009824776_item	2721084	et	4	main
kohvi	doc_542009824776_item	2721090	et	4	main
ning	doc_542009824776_item	2721093	et	3	main
toitu	doc_542009824776_item	2721096	et	4	main
keegi	doc_542009824776_item	2721097	et	4	main
või	doc_542009824776_item	2721102	et	4	main
me	doc_542009824776_item	2721103	et	4	main
ostsime	doc_542009824776_item	2721104	et	3	main
erinevate	doc_542009824776_item	2721116	et	4	main
ülikondid	doc_542009824776_item	2721121	et	3	main
ei	doc_542009824776_item	2721130	et	4	main
mäleta	doc_542009824776_item	2721131	et	4	main
mida	doc_542009824776_item	2721132	et	4	main
pärast	doc_542009824776_item	2721136	et	4	main
kõik	doc_542009824776_item	2721139	et	4	main
me	doc_542009824776_item	2721142	et	4	main
mida	doc_542009824776_item	2721162	et	4	main
temaga	doc_542009824776_item	2721163	et	3	main
juhtub	doc_542009824776_item	2721164	et	3	main
ja	doc_542009824776_item	2721169	et	3	main
baaris	doc_542009824776_item	2721171	et	3	main
lõõbusaid	doc_542009824776_item	2721176	et	4	main
toredad	doc_542009824777_item	2721213	et	3	main
teksapüksid	doc_542009824777_item	2721221	et	3	main
tantsime	doc_542009824777_item	2721224	et	3	main
ja	doc_542009824777_item	2721225	et	3	main
väga	doc_542009824777_item	2721244	et	3	main
toimub	doc_542009824777_item	2721247	et	3	main
koolimajas	doc_542009824777_item	2721248	et	4	main
palju	doc_542009824777_item	2721257	et	4	main
inimest	doc_542009824777_item	2721258	et	3	main
ära	doc_542009824777_item	2721260	et	4	main
kui	doc_542009824777_item	2721266	et	3	main
poeg	doc_542009824777_item	2721270	et	3	main
oma	doc_542009824777_item	2721272	et	4	main
tantsivad	doc_542009824777_item	2721279	et	4	main
ja	doc_542009824777_item	2721280	et	3	main
olla	doc_542009824777_item	2721283	et	3	main
aga	doc_542009824777_item	2721287	et	3	main
on	doc_542009824777_item	2721289	et	4	main
praadi	doc_542009824778_item	2721299	et	4	main
klassiõhtuid	doc_542009824779_item	2721335	et	3	main
koolis	doc_542009824779_item	2721337	et	4	main
klassis	doc_542009824779_item	2721339	et	3	main
koos	doc_542009824779_item	2721346	et	4	main
tordiga	doc_542009824779_item	2721347	et	3	main
me	doc_542009824779_item	2721348	et	4	main
olime	doc_542009824779_item	2721349	et	3	main
meie	doc_542009824779_item	2721362	et	4	main
me	doc_542009824779_item	2721372	et	4	main
harva	doc_542009824779_item	2721374	et	4	main
klassikaaslastega	doc_542009824779_item	2721375	et	4	main
kokku	doc_542009824779_item	2721376	et	3	main
me	doc_542009824779_item	2721377	et	4	main
kokku	doc_542009824779_item	2721378	et	3	main
saame	doc_542009824779_item	2721379	et	4	main
räägitasime	doc_542009824779_item	2721382	et	4	main
tütar	doc_542009824779_item	2721389	et	3	main
õpib	doc_542009824779_item	2721391	et	3	main
klassis	doc_542009824779_item	2721393	et	3	main
me	doc_542009824779_item	2721395	et	4	main
restoraanis	doc_542009824775_item	2721007	et	4	main
kommid	doc_542009824775_item	2721017	et	3	main
või	doc_542009824775_item	2721018	et	4	main
oli	doc_542009824775_item	2721021	et	3	main
pidu	doc_542009824775_item	2721023	et	4	main
nagu	doc_542009824775_item	2721027	et	3	main
t-särg	doc_542009824775_item	2721029	et	3	main
aga	doc_542009824775_item	2721033	et	3	main
seljas	doc_542009824775_item	2721035	et	4	main
seelik	doc_542009824775_item	2721040	et	3	main
tulevad	doc_542009824775_item	2721059	et	4	main
kui	doc_542009824775_item	2721061	et	3	main
õpetajal	doc_542009824775_item	2721068	et	4	main
oma	doc_542009824776_item	2721085	et	4	main
ja	doc_542009824776_item	2721091	et	3	main
torti	doc_542009824776_item	2721099	et	4	main
aga	doc_542009824776_item	2721106	et	3	main
küpsetasime	doc_542009824776_item	2721109	et	3	main
mängu	doc_542009824776_item	2721117	et	4	main
poistel	doc_542009824776_item	2721118	et	3	main
olid	doc_542009824776_item	2721119	et	4	main
meeldinud	doc_542009824776_item	2721135	et	4	main
klassikaaslastega	doc_542009824776_item	2721146	et	4	main
isegi	doc_542009824776_item	2721153	et	4	main
tea	doc_542009824776_item	2721156	et	4	main
keegi	doc_542009824776_item	2721159	et	4	main
kohtume	doc_542009824776_item	2721168	et	3	main
koolist	doc_542009824776_item	2721173	et	4	main
elust	doc_542009824776_item	2721174	et	3	main
juba	doc_542009824776_item	2721181	et	3	main
mul	doc_542009824776_item	2721182	et	3	main
palju	doc_542009824777_item	2721223	et	4	main
mulle	doc_542009824777_item	2721227	et	4	main
klassiõhtud	doc_542009824777_item	2721228	et	3	main
ilusaid	doc_542009824777_item	2721235	et	3	main
saame	doc_542009824777_item	2721238	et	4	main
oma	doc_542009824777_item	2721240	et	4	main
vanade	doc_542009824777_item	2721241	et	3	main
klassikaaslastega	doc_542009824777_item	2721242	et	4	main
elavad	doc_542009824777_item	2721263	et	4	main
venemaal	doc_542009824777_item	2721265	et	4	main
nad	doc_542009824777_item	2721278	et	3	main
me	doc_542009824778_item	2721293	et	4	main
pidasime	doc_542009824778_item	2721294	et	3	main
klassiõhtud	doc_542009824778_item	2721295	et	3	main
restoranis	doc_542009824778_item	2721296	et	3	main
me	doc_542009824778_item	2721297	et	4	main
klassiõhtud	doc_542009824778_item	2721323	et	3	main
kohtun	doc_542009824778_item	2721327	et	3	main
essee	doc_542009824779_item	2721331	et	4	main
klassiõhtud	doc_542009824779_item	2721332	et	3	main
me	doc_542009824779_item	2721333	et	4	main
ja	doc_542009824779_item	2721343	et	3	main
õpisime	doc_542009824779_item	2721357	et	4	main
koos	doc_542009824779_item	2721358	et	4	main
õpetajad	doc_542009824779_item	2721363	et	4	main
vee	doc_542009824779_item	2721365	et	3	main
meie	doc_542009824779_item	2721367	et	4	main
ringi	doc_542009824779_item	2721370	et	4	main
sõitma	doc_542009824779_item	2721371	et	3	main
peredest	doc_542009824779_item	2721386	et	3	main
ta	doc_542009824779_item	2721390	et	4	main
3	doc_542009824779_item	2721392	et	2	main
lapsedega	doc_542009824779_item	2721398	et	3	main
kooku	doc_542009824779_item	2721400	et	4	main
ja	doc_542009824779_item	2721401	et	3	main
tansime	doc_542009824779_item	2721402	et	4	main
sõime	doc_542009824780_item	2721420	et	4	main
kampsun	doc_542009824775_item	2721031	et	3	main
kleit	doc_542009824775_item	2721038	et	3	main
me	doc_542009824775_item	2721042	et	4	main
oma	doc_542009824775_item	2721047	et	4	main
asja	doc_542009824775_item	2721048	et	4	main
päras	doc_542009824775_item	2721049	et	3	main
õhtuklassi	doc_542009824775_item	2721050	et	4	main
mulle	doc_542009824775_item	2721051	et	4	main
kokku	doc_542009824775_item	2721060	et	3	main
me	doc_542009824775_item	2721062	et	4	main
kokku	doc_542009824775_item	2721063	et	3	main
saame	doc_542009824775_item	2721064	et	4	main
räägime	doc_542009824775_item	2721071	et	3	main
elu	doc_542009824775_item	2721073	et	4	main
ja	doc_542009824775_item	2721074	et	3	main
kooli	doc_542009824775_item	2721075	et	4	main
tavaliselt	doc_542009824776_item	2721080	et	4	main
pidasime	doc_542009824776_item	2721081	et	3	main
klassiõhtuid	doc_542009824776_item	2721082	et	3	main
koolis	doc_542009824776_item	2721083	et	4	main
peamiselt	doc_542009824776_item	2721089	et	4	main
midagi	doc_542009824776_item	2721105	et	4	main
me	doc_542009824776_item	2721108	et	4	main
ise	doc_542009824776_item	2721110	et	4	main
midagi	doc_542009824776_item	2721111	et	4	main
klassiõhtul	doc_542009824776_item	2721112	et	3	main
seljas	doc_542009824776_item	2721120	et	4	main
oma	doc_542009824775_item	2721067	et	4	main
essee	doc_542009824776_item	2721077	et	4	main
klassis	doc_542009824776_item	2721086	et	3	main
me	doc_542009824776_item	2721087	et	4	main
jõime	doc_542009824776_item	2721088	et	3	main
tõid	doc_542009824776_item	2721098	et	4	main
me	doc_542009824776_item	2721113	et	4	main
tantsime	doc_542009824776_item	2721114	et	3	main
mängisime	doc_542009824776_item	2721115	et	3	main
tüdrukutel	doc_542009824776_item	2721123	et	4	main
seljas	doc_542009824776_item	2721125	et	4	main
kleidid	doc_542009824776_item	2721127	et	3	main
mulle	doc_542009824776_item	2721133	et	4	main
klassiõhtud	doc_542009824776_item	2721137	et	3	main
praegu	doc_542009824776_item	2721141	et	3	main
kõik	doc_542009824776_item	2721149	et	4	main
elavad	doc_542009824776_item	2721150	et	4	main
ei	doc_542009824776_item	2721155	et	4	main
üldse	doc_542009824776_item	2721157	et	3	main
me	doc_542009824776_item	2721167	et	4	main
käime	doc_542009824776_item	2721170	et	4	main
räägime	doc_542009824776_item	2721172	et	3	main
meenutame	doc_542009824776_item	2721175	et	3	main
jutte	doc_542009824776_item	2721177	et	3	main
lapsed	doc_542009824776_item	2721180	et	3	main
kleidid	doc_542009824777_item	2721214	et	3	main
moodsa	doc_542009824777_item	2721216	et	3	main
olid	doc_542009824777_item	2721219	et	4	main
me	doc_542009824777_item	2721222	et	4	main
mängisime	doc_542009824777_item	2721226	et	3	main
meeldisid	doc_542009824777_item	2721229	et	4	main
sellepärast	doc_542009824777_item	2721230	et	3	main
me	doc_542009824777_item	2721237	et	4	main
kokku	doc_542009824777_item	2721243	et	3	main
nad	doc_542009824777_item	2721262	et	3	main
nii	doc_542009824777_item	2721264	et	3	main
ka	doc_542009824777_item	2721267	et	3	main
minu	doc_542009824777_item	2721269	et	3	main
koolimajas	doc_542009824777_item	2721276	et	4	main
keeglisaalis	doc_542009824777_item	2721277	et	3	main
veel	doc_542009824777_item	2721284	et	4	main
sõime	doc_542009824778_item	2721298	et	4	main
mul	doc_542009824778_item	2721321	et	3	main
pidasime	doc_542009824779_item	2721334	et	3	main
meie	doc_542009824779_item	2721338	et	4	main
jõime	doc_542009824779_item	2721344	et	3	main
seljas	doc_542009824779_item	2721350	et	4	main
meenutasime	doc_542009824779_item	2721354	et	3	main
kaheksa	doc_542009824779_item	2721359	et	4	main
väga	doc_542009824779_item	2721373	et	3	main
meie	doc_542009824779_item	2721380	et	4	main
asjalikult	doc_542009824779_item	2721383	et	4	main
ja	doc_542009824779_item	2721385	et	3	main
mul	doc_542009824779_item	2721387	et	3	main
ja	doc_542009824779_item	2721394	et	3	main
joome	doc_542009824779_item	2721405	et	4	main
küpsitega	doc_542009824779_item	2721408	et	3	main
klassiõhtud	doc_542009824780_item	2721410	et	3	main
klassiõhtuid	doc_542009824780_item	2721413	et	3	main
esimisel	doc_542009824780_item	2721417	et	4	main
korrusel	doc_542009824780_item	2721418	et	3	main
me	doc_542009824780_item	2721419	et	4	main
küpsised	doc_542009824780_item	2721425	et	3	main
me	doc_542009824780_item	2721439	et	4	main
jõime	doc_542009824780_item	2721449	et	3	main
rägisime	doc_542009824780_item	2721452	et	4	main
ole	doc_542009824780_item	2721470	et	4	main
kunagi	doc_542009824780_item	2721471	et	3	main
18aastane	doc_542009824780_item	2721486	et	4	main
reedel	doc_542009824780_item	2721493	et	3	main
ta	doc_542009824780_item	2721494	et	4	main
jööb	doc_542009824780_item	2721495	et	4	main
sõpradega	doc_542009824780_item	2721501	et	3	main
me	doc_542009824781_item	2721507	et	4	main
jõime	doc_542009824781_item	2721508	et	3	main
sõime	doc_542009824781_item	2721511	et	4	main
tüdrukutel	doc_542009824781_item	2721513	et	4	main
nüüd	doc_542009824781_item	2721528	et	4	main
oma	doc_542009824781_item	2721529	et	4	main
vanade	doc_542009824781_item	2721530	et	3	main
essee	doc_542009824782_item	2721536	et	4	main
aga	doc_542009824776_item	2721122	et	3	main
olid	doc_542009824776_item	2721124	et	4	main
ilusad	doc_542009824776_item	2721126	et	3	main
täpselt	doc_542009824776_item	2721128	et	4	main
ma	doc_542009824776_item	2721129	et	3	main
ei	doc_542009824776_item	2721134	et	4	main
meeldis	doc_542009824776_item	2721140	et	3	main
ei	doc_542009824776_item	2721143	et	4	main
saa	doc_542009824776_item	2721144	et	4	main
vanade	doc_542009824776_item	2721145	et	3	main
erinevates	doc_542009824776_item	2721151	et	4	main
linnades	doc_542009824776_item	2721152	et	3	main
mõnega	doc_542009824776_item	2721166	et	3	main
keegil	doc_542009824776_item	2721178	et	4	main
on	doc_542009824776_item	2721179	et	4	main
ei	doc_542009824776_item	2721183	et	4	main
ole	doc_542009824776_item	2721184	et	4	main
veel	doc_542009824776_item	2721185	et	4	main
lapsi	doc_542009824776_item	2721186	et	4	main
essee	doc_542009824777_item	2721187	et	4	main
me	doc_542009824777_item	2721188	et	4	main
pidasime	doc_542009824777_item	2721189	et	3	main
klassiõhtuid	doc_542009824777_item	2721190	et	3	main
tavaliselt	doc_542009824777_item	2721191	et	4	main
koolimajas	doc_542009824777_item	2721192	et	4	main
me	doc_542009824777_item	2721193	et	4	main
sõime	doc_542009824777_item	2721194	et	4	main
kringlit	doc_542009824777_item	2721195	et	3	main
kompvekid	doc_542009824777_item	2721196	et	3	main
torti	doc_542009824777_item	2721197	et	4	main
ja	doc_542009824777_item	2721198	et	3	main
jõime	doc_542009824777_item	2721199	et	3	main
limonaadi	doc_542009824777_item	2721200	et	4	main
ja	doc_542009824777_item	2721201	et	3	main
teet	doc_542009824777_item	2721202	et	4	main
poistel	doc_542009824777_item	2721203	et	3	main
seljas	doc_542009824777_item	2721204	et	4	main
olid	doc_542009824777_item	2721205	et	4	main
džemprid	doc_542009824777_item	2721206	et	2	main
ja	doc_542009824777_item	2721207	et	3	main
jalas	doc_542009824777_item	2721208	et	4	main
viigipüksid	doc_542009824777_item	2721209	et	3	main
tüdrukutel	doc_542009824777_item	2721210	et	4	main
olid	doc_542009824777_item	2721211	et	4	main
seljas	doc_542009824777_item	2721212	et	4	main
aga	doc_542009824777_item	2721215	et	3	main
noorusel	doc_542009824777_item	2721217	et	4	main
meies	doc_542009824777_item	2721231	et	4	main
klassis	doc_542009824777_item	2721232	et	3	main
olid	doc_542009824777_item	2721233	et	4	main
targaid	doc_542009824777_item	2721234	et	4	main
me	doc_542009824777_item	2721249	et	4	main
räägime	doc_542009824777_item	2721250	et	3	main
elust	doc_542009824777_item	2721251	et	3	main
tööst	doc_542009824777_item	2721252	et	3	main
meenutame	doc_542009824777_item	2721253	et	3	main
kooliaeg	doc_542009824777_item	2721254	et	3	main
aga	doc_542009824777_item	2721255	et	3	main
kahjuks	doc_542009824777_item	2721256	et	4	main
klassikaaslastega	doc_542009824777_item	2721273	et	4	main
mängivad	doc_542009824777_item	2721281	et	4	main
võib	doc_542009824777_item	2721282	et	3	main
essee	doc_542009824778_item	2721291	et	4	main
kringlit	doc_542009824778_item	2721300	et	3	main
ja	doc_542009824778_item	2721301	et	3	main
jõime	doc_542009824778_item	2721302	et	3	main
tee	doc_542009824778_item	2721303	et	4	main
naised	doc_542009824778_item	2721304	et	3	main
olid	doc_542009824778_item	2721305	et	4	main
seljas	doc_542009824778_item	2721306	et	4	main
õhtu	doc_542009824778_item	2721307	et	4	main
kleitid	doc_542009824778_item	2721308	et	4	main
aga	doc_542009824778_item	2721309	et	3	main
mehed	doc_542009824778_item	2721310	et	3	main
olid	doc_542009824778_item	2721311	et	4	main
seljas	doc_542009824778_item	2721312	et	4	main
ülikondid	doc_542009824778_item	2721313	et	3	main
paljudel	doc_542009824778_item	2721314	et	3	main
on	doc_542009824778_item	2721315	et	4	main
lapsed	doc_542009824778_item	2721316	et	3	main
räägitakse	doc_542009824778_item	2721317	et	3	main
tööst	doc_542009824778_item	2721318	et	3	main
ja	doc_542009824778_item	2721319	et	3	main
peredest	doc_542009824778_item	2721320	et	3	main
seal	doc_542009824778_item	2721325	et	4	main
minu	doc_542009824778_item	2721328	et	3	main
me	doc_542009824779_item	2721340	et	4	main
ostime	doc_542009824779_item	2721341	et	4	main
tort	doc_542009824779_item	2721342	et	3	main
tee	doc_542009824779_item	2721345	et	4	main
õpilane	doc_542009824778_item	2721329	et	3	main
sõbrad	doc_542009824778_item	2721330	et	3	main
meie	doc_542009824779_item	2721336	et	4	main
tavaliselt	doc_542009824779_item	2721351	et	4	main
kuidas	doc_542009824779_item	2721355	et	3	main
me	doc_542009824779_item	2721356	et	4	main
aastat	doc_542009824779_item	2721360	et	3	main
kuidas	doc_542009824779_item	2721366	et	3	main
maad	doc_542009824779_item	2721368	et	4	main
mööda	doc_542009824779_item	2721369	et	4	main
koolis	doc_542009824779_item	2721381	et	4	main
on	doc_542009824779_item	2721388	et	4	main
meie	doc_542009824779_item	2721397	et	4	main
tee	doc_542009824779_item	2721406	et	4	main
essee	doc_542009824780_item	2721409	et	4	main
ja	doc_542009824780_item	2721426	et	3	main
mõnicord	doc_542009824780_item	2721428	et	4	main
tortid	doc_542009824780_item	2721429	et	4	main
ja	doc_542009824780_item	2721430	et	3	main
sellepärast	doc_542009824780_item	2721437	et	3	main
poisiga	doc_542009824780_item	2721462	et	3	main
mina	doc_542009824780_item	2721472	et	4	main
kohtuda	doc_542009824780_item	2721473	et	3	main
õpisin	doc_542009824780_item	2721481	et	4	main
minu	doc_542009824780_item	2721483	et	3	main
ja	doc_542009824780_item	2721497	et	3	main
suhtleb	doc_542009824780_item	2721499	et	3	main
essee	doc_542009824781_item	2721502	et	4	main
toort	doc_542009824781_item	2721512	et	4	main
olid	doc_542009824781_item	2721514	et	4	main
seljas	doc_542009824781_item	2721515	et	4	main
toredad	doc_542009824781_item	2721516	et	3	main
viigipüksid	doc_542009824781_item	2721521	et	3	main
ei	doc_542009824781_item	2721533	et	4	main
saa	doc_542009824781_item	2721534	et	4	main
kokku	doc_542009824781_item	2721535	et	3	main
kõik	doc_542009824782_item	2721542	et	4	main
olid	doc_542009824782_item	2721549	et	4	main
seljas	doc_542009824782_item	2721550	et	4	main
pidurõivad	doc_542009824782_item	2721551	et	3	main
poistel	doc_542009824782_item	2721552	et	3	main
tüdrukud	doc_542009824782_item	2721556	et	3	main
juhatajana	doc_542009824783_item	2721568	et	4	main
kui	doc_542009824783_item	2721595	et	3	main
ettevõtetes	doc_542009824783_item	2721619	et	3	main
ja	doc_542009824783_item	2721620	et	3	main
kes	doc_542009824783_item	2721621	et	4	main
täiendõpetamisesse	doc_542009824783_item	2721623	et	3	main
minu	doc_542009824783_item	2721625	et	3	main
peamised	doc_542009824783_item	2721626	et	3	main
töö	doc_542009824783_item	2721639	et	4	main
arvuti	doc_542009824783_item	2721655	et	4	main
elektronpost	doc_542009824783_item	2721657	et	3	main
oma	doc_542009824783_item	2721660	et	4	main
millal	doc_542009824783_item	2721662	et	3	main
tunde	doc_542009824783_item	2721664	et	4	main
ma	doc_542009824783_item	2721665	et	3	main
töötan	doc_542009824783_item	2721666	et	3	main
käskkiri	doc_542009824783_item	2721677	et	3	main
mul	doc_542009824783_item	2721679	et	3	main
tunde	doc_542009824783_item	2721681	et	4	main
tulen	doc_542009824783_item	2721723	et	3	main
ajal	doc_542009824783_item	2721726	et	4	main
mulle	doc_542009824783_item	2721739	et	4	main
või	doc_542009824783_item	2721744	et	4	main
tööruumi	doc_542009824783_item	2721748	et	4	main
on	doc_542009824783_item	2721749	et	4	main
seal	doc_542009824783_item	2721754	et	4	main
on	doc_542009824783_item	2721755	et	4	main
kirjulaud	doc_542009824783_item	2721756	et	4	main
kus	doc_542009824783_item	2721757	et	3	main
seisab	doc_542009824783_item	2721764	et	3	main
oma	doc_542009824783_item	2721772	et	4	main
diivan	doc_542009824783_item	2721775	et	3	main
mul	doc_542009824783_item	2721792	et	3	main
on	doc_542009824783_item	2721793	et	4	main
pikkus	doc_542009824783_item	2721795	et	4	main
ja	doc_542009824783_item	2721796	et	3	main
kaal	doc_542009824783_item	2721797	et	3	main
on	doc_542009824783_item	2721801	et	4	main
ja	doc_542009824783_item	2721805	et	3	main
koolis	doc_542009824784_item	2721821	et	4	main
riided	doc_542009824779_item	2721352	et	3	main
me	doc_542009824779_item	2721353	et	4	main
meenutasime	doc_542009824779_item	2721361	et	3	main
ja	doc_542009824779_item	2721364	et	3	main
tööst	doc_542009824779_item	2721384	et	3	main
koos	doc_542009824779_item	2721403	et	4	main
ja	doc_542009824779_item	2721404	et	3	main
koos	doc_542009824779_item	2721407	et	4	main
koolimajas	doc_542009824780_item	2721414	et	4	main
klassirummis	doc_542009824780_item	2721416	et	3	main
ainult	doc_542009824780_item	2721424	et	4	main
kommid	doc_542009824780_item	2721431	et	3	main
me	doc_542009824780_item	2721432	et	4	main
olime	doc_542009824780_item	2721433	et	3	main
riided	doc_542009824780_item	2721436	et	3	main
ei	doc_542009824780_item	2721442	et	4	main
me	doc_542009824780_item	2721446	et	4	main
tantsisime	doc_542009824780_item	2721447	et	3	main
istusime	doc_542009824780_item	2721450	et	3	main
klassiõhtud	doc_542009824780_item	2721456	et	3	main
ma	doc_542009824780_item	2721459	et	3	main
esimene	doc_542009824780_item	2721467	et	3	main
sellepärast	doc_542009824780_item	2721475	et	3	main
et	doc_542009824780_item	2721476	et	3	main
ma	doc_542009824780_item	2721477	et	3	main
eestis	doc_542009824780_item	2721479	et	3	main
venemaal	doc_542009824780_item	2721482	et	4	main
pojeg	doc_542009824780_item	2721484	et	4	main
on	doc_542009824780_item	2721485	et	4	main
kokteili	doc_542009824780_item	2721496	et	4	main
tantsib	doc_542009824780_item	2721498	et	3	main
klassiõhtul	doc_542009824781_item	2721522	et	3	main
tantsisime	doc_542009824781_item	2721524	et	3	main
lõbus	doc_542009824781_item	2721527	et	4	main
kõik	doc_542009824782_item	2721539	et	4	main
klassiõhtud	doc_542009824782_item	2721540	et	3	main
jõid	doc_542009824782_item	2721546	et	4	main
limonaad	doc_542009824782_item	2721547	et	3	main
tüdrukutel	doc_542009824782_item	2721548	et	4	main
seljas	doc_542009824782_item	2721554	et	4	main
poisid	doc_542009824782_item	2721558	et	4	main
tantsisid	doc_542009824782_item	2721559	et	4	main
x-linna	doc_542009824783_item	2721564	et	4	main
kutsekooli	doc_542009824783_item	2721565	et	4	main
erialaainete	doc_542009824783_item	2721566	et	3	main
lõpetasin	doc_542009824783_item	2721596	et	3	main
1	doc_542009824783_item	2721600	et	2	main
keskkooli	doc_542009824783_item	2721609	et	4	main
õhtuosakonnas	doc_542009824783_item	2721611	et	4	main
juhtima	doc_542009824783_item	2721631	et	4	main
õpetajatega	doc_542009824783_item	2721641	et	4	main
vaatan	doc_542009824783_item	2721656	et	3	main
ja	doc_542009824783_item	2721658	et	3	main
allutatud	doc_542009824783_item	2721661	et	4	main
veod	doc_542009824783_item	2721671	et	3	main
väga	doc_542009824783_item	2721721	et	3	main
kontrollima	doc_542009824783_item	2721729	et	4	main
tööd	doc_542009824783_item	2721731	et	4	main
tavaliselt	doc_542009824783_item	2721732	et	4	main
ma	doc_542009824783_item	2721733	et	3	main
kursusel	doc_542009824783_item	2721743	et	3	main
minu	doc_542009824783_item	2721747	et	3	main
kaksteist	doc_542009824783_item	2721752	et	4	main
ruutmeetrit	doc_542009824783_item	2721753	et	3	main
palju	doc_542009824783_item	2721759	et	4	main
ja	doc_542009824783_item	2721761	et	3	main
riietuse	doc_542009824783_item	2721773	et	4	main
ja	doc_542009824783_item	2721774	et	3	main
ma	doc_542009824783_item	2721777	et	3	main
mul	doc_542009824783_item	2721782	et	3	main
see	doc_542009824783_item	2721800	et	3	main
naised	doc_542009824783_item	2721804	et	3	main
mehed	doc_542009824783_item	2721806	et	3	main
koos	doc_542009824779_item	2721396	et	4	main
saame	doc_542009824779_item	2721399	et	4	main
me	doc_542009824780_item	2721411	et	4	main
pidasime	doc_542009824780_item	2721412	et	3	main
oma	doc_542009824780_item	2721415	et	4	main
ja	doc_542009824780_item	2721421	et	3	main
vähe	doc_542009824780_item	2721423	et	3	main
limonaadid	doc_542009824780_item	2721427	et	3	main
tavalised	doc_542009824780_item	2721435	et	4	main
olime	doc_542009824780_item	2721440	et	3	main
ole	doc_542009824780_item	2721443	et	4	main
rikkad	doc_542009824780_item	2721444	et	4	main
klassiõhtul	doc_542009824780_item	2721445	et	3	main
mulle	doc_542009824780_item	2721453	et	4	main
meie	doc_542009824780_item	2721455	et	4	main
et	doc_542009824780_item	2721458	et	3	main
oma	doc_542009824780_item	2721461	et	4	main
alati	doc_542009824780_item	2721463	et	4	main
oli	doc_542009824780_item	2721465	et	3	main
klassikaaslastega	doc_542009824780_item	2721474	et	4	main
ning	doc_542009824780_item	2721480	et	3	main
agro	doc_542009824780_item	2721490	et	4	main
nädal	doc_542009824780_item	2721492	et	3	main
koolis	doc_542009824781_item	2721506	et	4	main
ja	doc_542009824781_item	2721510	et	3	main
me	doc_542009824781_item	2721523	et	4	main
klassiõhtul	doc_542009824781_item	2721525	et	3	main
oli	doc_542009824781_item	2721526	et	3	main
me	doc_542009824781_item	2721532	et	4	main
koolis	doc_542009824782_item	2721541	et	4	main
essee	doc_542009824783_item	2721560	et	4	main
töötan	doc_542009824783_item	2721563	et	3	main
kutsekoolis	doc_542009824783_item	2721569	et	4	main
ma	doc_542009824783_item	2721570	et	3	main
ja	doc_542009824783_item	2721581	et	3	main
polütehniline	doc_542009824783_item	2721598	et	3	main
meie	doc_542009824783_item	2721601	et	4	main
õppivad	doc_542009824783_item	2721604	et	4	main
põhikooli	doc_542009824783_item	2721607	et	4	main
vajavad	doc_542009824783_item	2721622	et	4	main
õppetöökorraldamine	doc_542009824783_item	2721629	et	3	main
noor	doc_542009824783_item	2721640	et	3	main
1	doc_542009824783_item	2721642	et	2	main
minu	doc_542009824783_item	2721643	et	3	main
tavaline	doc_542009824783_item	2721644	et	4	main
päev	doc_542009824783_item	2721645	et	3	main
kirjutan	doc_542009824783_item	2721674	et	3	main
ma	doc_542009824783_item	2721722	et	3	main
tulen	doc_542009824783_item	2721734	et	3	main
koju	doc_542009824783_item	2721735	et	3	main
kell	doc_542009824783_item	2721736	et	3	main
kuus	doc_542009824783_item	2721737	et	4	main
kui	doc_542009824783_item	2721738	et	3	main
umbes	doc_542009824783_item	2721751	et	4	main
väga	doc_542009824783_item	2721758	et	3	main
paberid	doc_542009824783_item	2721760	et	3	main
arvuti	doc_542009824783_item	2721765	et	4	main
printeriga	doc_542009824783_item	2721767	et	3	main
kus	doc_542009824783_item	2721769	et	3	main
vana	doc_542009824783_item	2721779	et	4	main
naine	doc_542009824783_item	2721781	et	3	main
on	doc_542009824783_item	2721783	et	4	main
must	doc_542009824783_item	2721784	et	4	main
juuksed	doc_542009824783_item	2721785	et	3	main
prillid	doc_542009824783_item	2721791	et	3	main
kolleegid	doc_542009824783_item	2721799	et	3	main
väga	doc_542009824783_item	2721802	et	3	main
huvitav	doc_542009824783_item	2721803	et	4	main
essee	doc_542009824784_item	2721807	et	4	main
esimene	doc_542009824784_item	2721808	et	3	main
kohtumine	doc_542009824784_item	2721809	et	4	main
kui	doc_542009824784_item	2721810	et	3	main
ma	doc_542009824784_item	2721811	et	3	main
õppisime	doc_542009824784_item	2721822	et	3	main
ühes	doc_542009824784_item	2721824	et	4	main
klassis	doc_542009824784_item	2721825	et	3	main
tunnd	doc_542009824784_item	2721836	et	4	main
gruppitöö	doc_542009824784_item	2721841	et	4	main
gruppis	doc_542009824784_item	2721846	et	4	main
me	doc_542009824784_item	2721847	et	4	main
pidime	doc_542009824784_item	2721848	et	3	main
lugeda	doc_542009824784_item	2721853	et	3	main
jõime	doc_542009824780_item	2721422	et	3	main
seljas	doc_542009824780_item	2721434	et	4	main
et	doc_542009824780_item	2721438	et	3	main
vaelased	doc_542009824780_item	2721441	et	4	main
sõime	doc_542009824780_item	2721448	et	4	main
ja	doc_542009824780_item	2721451	et	3	main
meeldisid	doc_542009824780_item	2721454	et	4	main
sellepärast	doc_542009824780_item	2721457	et	3	main
tantsisin	doc_542009824780_item	2721460	et	3	main
ta	doc_542009824780_item	2721464	et	4	main
minu	doc_542009824780_item	2721466	et	3	main
armastus	doc_542009824780_item	2721468	et	4	main
ei	doc_542009824780_item	2721469	et	4	main
elan	doc_542009824780_item	2721478	et	3	main
ta	doc_542009824780_item	2721487	et	4	main
käib	doc_542009824780_item	2721488	et	3	main
ööklubis	doc_542009824780_item	2721489	et	3	main
iga	doc_542009824780_item	2721491	et	4	main
oma	doc_542009824780_item	2721500	et	4	main
me	doc_542009824781_item	2721503	et	4	main
klassiõhtuid	doc_542009824781_item	2721504	et	3	main
pidaksime	doc_542009824781_item	2721505	et	4	main
limonaadi	doc_542009824781_item	2721509	et	4	main
kleidid	doc_542009824781_item	2721517	et	3	main
ning	doc_542009824781_item	2721518	et	3	main
poistel	doc_542009824781_item	2721519	et	3	main
jalas	doc_542009824781_item	2721520	et	4	main
klassikaaslastega	doc_542009824781_item	2721531	et	4	main
me	doc_542009824782_item	2721537	et	4	main
pidasime	doc_542009824782_item	2721538	et	3	main
torti	doc_542009824782_item	2721544	et	4	main
ja	doc_542009824782_item	2721545	et	3	main
olid	doc_542009824782_item	2721553	et	4	main
ja	doc_542009824782_item	2721557	et	3	main
1	doc_542009824783_item	2721561	et	2	main
ma	doc_542009824783_item	2721562	et	3	main
töötan	doc_542009824783_item	2721571	et	3	main
kakskümmend	doc_542009824783_item	2721572	et	4	main
neli	doc_542009824783_item	2721573	et	3	main
aastat	doc_542009824783_item	2721574	et	3	main
kakskümmend	doc_542009824783_item	2721575	et	4	main
üks	doc_542009824783_item	2721576	et	3	main
aastat	doc_542009824783_item	2721577	et	3	main
ma	doc_542009824783_item	2721578	et	3	main
töötasin	doc_542009824783_item	2721579	et	3	main
elektrotehnika	doc_542009824783_item	2721580	et	4	main
arvutiõpetuse	doc_542009824783_item	2721582	et	3	main
õpetajana	doc_542009824783_item	2721583	et	4	main
ja	doc_542009824783_item	2721584	et	3	main
kolm	doc_542009824783_item	2721585	et	3	main
aastat	doc_542009824783_item	2721586	et	3	main
töötan	doc_542009824783_item	2721587	et	3	main
erialaainete	doc_542009824783_item	2721588	et	3	main
osakonna	doc_542009824783_item	2721589	et	4	main
juhatajana	doc_542009824783_item	2721590	et	4	main
sellele	doc_542009824783_item	2721591	et	4	main
tööle	doc_542009824783_item	2721592	et	3	main
ma	doc_542009824783_item	2721593	et	3	main
sattusin	doc_542009824783_item	2721594	et	3	main
sõid	doc_542009824782_item	2721543	et	4	main
pühapäevaülikond	doc_542009824782_item	2721555	et	3	main
osakonna	doc_542009824783_item	2721567	et	4	main
instituut	doc_542009824783_item	2721599	et	3	main
kutsekooli	doc_542009824783_item	2721602	et	4	main
päevaosakonnas	doc_542009824783_item	2721603	et	4	main
pärast	doc_542009824783_item	2721606	et	4	main
on	doc_542009824783_item	2721628	et	4	main
tunde	doc_542009824783_item	2721630	et	4	main
uue	doc_542009824783_item	2721635	et	3	main
õppekavade	doc_542009824783_item	2721636	et	3	main
töötlemine	doc_542009824783_item	2721637	et	4	main
metoodiline	doc_542009824783_item	2721638	et	3	main
ma	doc_542009824783_item	2721649	et	3	main
lähen	doc_542009824783_item	2721650	et	3	main
tööle	doc_542009824783_item	2721651	et	3	main
kell	doc_542009824783_item	2721652	et	3	main
kaheksa	doc_542009824783_item	2721653	et	4	main
lülitan	doc_542009824783_item	2721654	et	3	main
kontrollin	doc_542009824783_item	2721659	et	3	main
omas	doc_542009824783_item	2721667	et	4	main
kabinetis	doc_542009824783_item	2721668	et	3	main
kus	doc_542009824783_item	2721669	et	3	main
õppekavades	doc_542009824783_item	2721673	et	3	main
ja	doc_542009824783_item	2721676	et	3	main
kui	doc_542009824783_item	2721678	et	3	main
on	doc_542009824783_item	2721680	et	4	main
ma	doc_542009824783_item	2721682	et	3	main
juhin	doc_542009824783_item	2721683	et	3	main
nende	doc_542009824783_item	2721684	et	4	main
väga	doc_542009824783_item	2721685	et	3	main
tihti	doc_542009824783_item	2721686	et	3	main
ma	doc_542009824783_item	2721687	et	3	main
rägin	doc_542009824783_item	2721688	et	3	main
õpilastega	doc_542009824783_item	2721689	et	4	main
koju	doc_542009824783_item	2721724	et	3	main
sellel	doc_542009824783_item	2721725	et	4	main
millest	doc_542009824783_item	2721727	et	3	main
õhtuosakonna	doc_542009824783_item	2721730	et	4	main
koosolekul	doc_542009824783_item	2721745	et	3	main
kus	doc_542009824783_item	2721763	et	3	main
ma	doc_542009824783_item	2721770	et	3	main
6	doc_542009824783_item	2721776	et	2	main
olen	doc_542009824783_item	2721778	et	3	main
hiir	doc_542009824783_item	2721780	et	4	main
keskmine	doc_542009824783_item	2721794	et	3	main
minu	doc_542009824783_item	2721798	et	3	main
tutvusime	doc_542009824784_item	2721828	et	4	main
kui	doc_542009824784_item	2721829	et	3	main
ma	doc_542009824784_item	2721830	et	3	main
pidin	doc_542009824784_item	2721831	et	3	main
meeles	doc_542009824784_item	2721832	et	3	main
meil	doc_542009824784_item	2721833	et	4	main
oli	doc_542009824784_item	2721834	et	3	main
alaloo	doc_542009824784_item	2721835	et	4	main
me	doc_542009824784_item	2721843	et	4	main
koostada	doc_542009824784_item	2721850	et	3	main
ajal	doc_542009824784_item	2721879	et	4	main
tutvusime	doc_542009824784_item	2721881	et	4	main
me	doc_542009824784_item	2721883	et	4	main
teineteist	doc_542009824784_item	2721885	et	4	main
hakkasime	doc_542009824784_item	2721887	et	3	main
koolisse	doc_542009824784_item	2721889	et	4	main
minema	doc_542009824784_item	2721890	et	3	main
ja	doc_542009824784_item	2721891	et	3	main
koolist	doc_542009824784_item	2721892	et	4	main
dukumendid	doc_542009824784_item	2721904	et	4	main
ühele	doc_542009824784_item	2721905	et	3	main
jalutama	doc_542009824784_item	2721942	et	3	main
või	doc_542009824784_item	2721943	et	4	main
et	doc_542009824784_item	2721955	et	3	main
teineteist	doc_542009824784_item	2721958	et	4	main
aru	doc_542009824784_item	2721959	et	4	main
essee	doc_542009824785_item	2721960	et	4	main
minu	doc_542009824785_item	2721961	et	3	main
neli	doc_542009824785_item	2721984	et	3	main
oppisin	doc_542009824785_item	2721988	et	4	main
mäetaguse	doc_542009824785_item	2721989	et	3	main
põhikool	doc_542009824785_item	2721990	et	4	main
ja	doc_542009824785_item	2721991	et	3	main
ajalugu	doc_542009824785_item	2722001	et	4	main
raskusi	doc_542009824785_item	2722008	et	4	main
tallina	doc_542009824783_item	2721597	et	3	main
lapsi	doc_542009824783_item	2721605	et	4	main
ja	doc_542009824783_item	2721608	et	3	main
lõpetamist	doc_542009824783_item	2721610	et	4	main
õppivad	doc_542009824783_item	2721612	et	4	main
mehed	doc_542009824783_item	2721613	et	3	main
ja	doc_542009824783_item	2721614	et	3	main
naised	doc_542009824783_item	2721615	et	3	main
kes	doc_542009824783_item	2721616	et	4	main
töötab	doc_542009824783_item	2721617	et	3	main
mitmesuguste	doc_542009824783_item	2721618	et	3	main
1	doc_542009824783_item	2721624	et	2	main
töökohustused	doc_542009824783_item	2721627	et	3	main
kontroll	doc_542009824783_item	2721632	et	3	main
õpetajate	doc_542009824783_item	2721633	et	4	main
tarifikatsioon	doc_542009824783_item	2721634	et	3	main
seisab	doc_542009824783_item	2721646	et	3	main
järgmisest	doc_542009824783_item	2721647	et	3	main
osast	doc_542009824783_item	2721648	et	4	main
algavad	doc_542009824783_item	2721663	et	4	main
parandan	doc_542009824783_item	2721670	et	3	main
uute	doc_542009824783_item	2721672	et	3	main
kiri	doc_542009824783_item	2721675	et	3	main
kes	doc_542009824783_item	2721690	et	4	main
on	doc_542009824783_item	2721691	et	4	main
tunnist	doc_542009824783_item	2721692	et	4	main
poppi	doc_542009824783_item	2721693	et	4	main
tegema	doc_542009824783_item	2721694	et	3	main
ma	doc_542009824783_item	2721695	et	3	main
käin	doc_542009824783_item	2721696	et	3	main
õppetöökojas	doc_542009824783_item	2721697	et	3	main
kus	doc_542009824783_item	2721698	et	3	main
toimub	doc_542009824783_item	2721699	et	3	main
praktika	doc_542009824783_item	2721700	et	4	main
tunde	doc_542009824783_item	2721701	et	4	main
päeval	doc_542009824783_item	2721702	et	3	main
mul	doc_542009824783_item	2721703	et	3	main
on	doc_542009824783_item	2721704	et	4	main
lõuna	doc_542009824783_item	2721705	et	4	main
ma	doc_542009824783_item	2721706	et	3	main
lähen	doc_542009824783_item	2721707	et	3	main
sööklas	doc_542009824783_item	2721708	et	3	main
söön	doc_542009824783_item	2721709	et	3	main
ja	doc_542009824783_item	2721710	et	3	main
tulen	doc_542009824783_item	2721711	et	3	main
tagasi	doc_542009824783_item	2721712	et	3	main
oma	doc_542009824783_item	2721713	et	4	main
kabinetis	doc_542009824783_item	2721714	et	3	main
minu	doc_542009824783_item	2721715	et	3	main
tööpäev	doc_542009824783_item	2721716	et	3	main
lõpeb	doc_542009824783_item	2721717	et	4	main
kell	doc_542009824783_item	2721718	et	3	main
seitseteist	doc_542009824783_item	2721719	et	4	main
aga	doc_542009824783_item	2721720	et	3	main
vaja	doc_542009824783_item	2721728	et	4	main
ei	doc_542009824783_item	2721740	et	4	main
vaja	doc_542009824783_item	2721741	et	4	main
minema	doc_542009824783_item	2721742	et	3	main
1	doc_542009824783_item	2721746	et	2	main
väike	doc_542009824783_item	2721750	et	4	main
arvutilaud	doc_542009824783_item	2721762	et	4	main
koos	doc_542009824783_item	2721766	et	4	main
riidekapp	doc_542009824783_item	2721768	et	3	main
hoian	doc_542009824783_item	2721771	et	3	main
hall	doc_542009824783_item	2721786	et	4	main
silmad	doc_542009824783_item	2721787	et	4	main
niinas	doc_542009824783_item	2721788	et	4	main
mul	doc_542009824783_item	2721789	et	3	main
on	doc_542009824783_item	2721790	et	4	main
mõtlen	doc_542009824784_item	2721812	et	3	main
esimesest	doc_542009824784_item	2721813	et	3	main
kohtumisest	doc_542009824784_item	2721814	et	4	main
siis	doc_542009824784_item	2721815	et	3	main
tuleb	doc_542009824784_item	2721816	et	3	main
meelde	doc_542009824784_item	2721817	et	3	main
minu	doc_542009824784_item	2721818	et	3	main
sõpranna	doc_542009824784_item	2721819	et	4	main
leena	doc_542009824784_item	2721820	et	3	main
me	doc_542009824784_item	2721840	et	4	main
ja	doc_542009824784_item	2721851	et	3	main
hinnele	doc_542009824784_item	2721854	et	4	main
mulle	doc_542009824784_item	2721855	et	4	main
meeldis	doc_542009824784_item	2721856	et	3	main
leena	doc_542009824784_item	2721857	et	3	main
esimesest	doc_542009824784_item	2721858	et	3	main
ensekindel	doc_542009824784_item	2721865	et	4	main
ka	doc_542009824784_item	2721871	et	3	main
lähedamalt	doc_542009824784_item	2721882	et	4	main
kojusse	doc_542009824784_item	2721893	et	4	main
seal	doc_542009824784_item	2721910	et	4	main
kohtume	doc_542009824784_item	2721922	et	3	main
vaga	doc_542009824784_item	2721924	et	4	main
harva	doc_542009824784_item	2721925	et	4	main
või	doc_542009824784_item	2721927	et	4	main
kui	doc_542009824784_item	2721928	et	3	main
me	doc_542009824784_item	2721939	et	4	main
läheme	doc_542009824784_item	2721940	et	3	main
erinevatest	doc_542009824784_item	2721950	et	4	main
probleemidest	doc_542009824784_item	2721951	et	3	main
me	doc_542009824784_item	2721956	et	4	main
lõpetasin	doc_542009824785_item	2721992	et	3	main
sillamäe	doc_542009824785_item	2721993	et	3	main
kutsehariduskeskus	doc_542009824785_item	2721994	et	3	main
minu	doc_542009824785_item	2721995	et	3	main
lemmikõppeaine	doc_542009824785_item	2721996	et	4	main
kasvatus	doc_542009824785_item	2722004	et	4	main
aga	doc_542009824785_item	2722005	et	3	main
aine	doc_542009824785_item	2722006	et	4	main
valmistas	doc_542009824785_item	2722007	et	3	main
ma	doc_542009824785_item	2722013	et	3	main
on	doc_542009824785_item	2722022	et	4	main
ja	doc_542009824785_item	2722024	et	3	main
mule	doc_542009824785_item	2722025	et	4	main
meeldib	doc_542009824785_item	2722026	et	3	main
silmad	doc_542009824785_item	2722047	et	4	main
värvitud	doc_542009824785_item	2722051	et	4	main
juuksed	doc_542009824785_item	2722052	et	3	main
hea	doc_542009824786_item	2722057	et	4	main
inimene	doc_542009824786_item	2722058	et	3	main
see	doc_542009824786_item	2722059	et	3	main
tähendab	doc_542009824786_item	2722060	et	3	main
et	doc_542009824786_item	2722061	et	3	main
mina	doc_542009824786_item	2722062	et	4	main
reibas	doc_542009824786_item	2722063	et	3	main
ilus	doc_542009824786_item	2722092	et	4	main
ilm	doc_542009824786_item	2722093	et	3	main
kui	doc_542009824786_item	2722094	et	3	main
olime	doc_542009824784_item	2721844	et	3	main
korrast	doc_542009824784_item	2721859	et	4	main
sellepärast	doc_542009824784_item	2721860	et	3	main
et	doc_542009824784_item	2721861	et	3	main
ta	doc_542009824784_item	2721862	et	4	main
oli	doc_542009824784_item	2721863	et	3	main
ja	doc_542009824784_item	2721866	et	3	main
tüdruk	doc_542009824784_item	2721868	et	3	main
on	doc_542009824784_item	2721870	et	4	main
niisugune	doc_542009824784_item	2721872	et	3	main
ja	doc_542009824784_item	2721886	et	3	main
koos	doc_542009824784_item	2721888	et	4	main
pärast	doc_542009824784_item	2721895	et	4	main
me	doc_542009824784_item	2721901	et	4	main
andsime	doc_542009824784_item	2721902	et	3	main
koos	doc_542009824784_item	2721903	et	4	main
ametile	doc_542009824784_item	2721906	et	3	main
ajalooõpetaja	doc_542009824784_item	2721907	et	4	main
ma	doc_542009824784_item	2721908	et	3	main
õppisin	doc_542009824784_item	2721909	et	3	main
ainult	doc_542009824784_item	2721911	et	4	main
2-3	doc_542009824784_item	2721912	et	2	main
kuu	doc_542009824784_item	2721913	et	4	main
praegu	doc_542009824784_item	2721914	et	3	main
leena	doc_542009824784_item	2721915	et	3	main
õpib	doc_542009824784_item	2721916	et	3	main
tü-s	doc_542009824784_item	2721917	et	3	main
3	doc_542009824784_item	2721919	et	2	main
juba	doc_542009824784_item	2721918	et	3	main
aastat	doc_542009824784_item	2721920	et	3	main
me	doc_542009824784_item	2721823	et	4	main
nii	doc_542009824784_item	2721826	et	3	main
me	doc_542009824784_item	2721827	et	4	main
sellel	doc_542009824784_item	2721837	et	4	main
tunnil	doc_542009824784_item	2721838	et	3	main
tegime	doc_542009824784_item	2721839	et	3	main
ja	doc_542009824784_item	2721842	et	3	main
ühes	doc_542009824784_item	2721845	et	4	main
jutustust	doc_542009824784_item	2721849	et	4	main
teda	doc_542009824784_item	2721852	et	4	main
tark	doc_542009824784_item	2721867	et	3	main
praegu	doc_542009824784_item	2721869	et	3	main
tunnipärast	doc_542009824784_item	2721873	et	4	main
läksime	doc_542009824784_item	2721874	et	3	main
me	doc_542009824784_item	2721875	et	4	main
süüa	doc_542009824784_item	2721877	et	3	main
sel	doc_542009824784_item	2721878	et	3	main
meeldisime	doc_542009824784_item	2721884	et	3	main
tahaksime	doc_542009824784_item	2721896	et	3	main
me	doc_542009824784_item	2721897	et	4	main
ülikoolis	doc_542009824784_item	2721899	et	4	main
õppida	doc_542009824784_item	2721900	et	3	main
me	doc_542009824784_item	2721921	et	4	main
praegu	doc_542009824784_item	2721923	et	3	main
tartus	doc_542009824784_item	2721926	et	3	main
oleme	doc_542009824784_item	2721936	et	3	main
koos	doc_542009824784_item	2721937	et	4	main
siis	doc_542009824784_item	2721938	et	3	main
nägimes	doc_542009824784_item	2721947	et	4	main
ja	doc_542009824784_item	2721948	et	3	main
vesteldes	doc_542009824784_item	2721949	et	3	main
nimi	doc_542009824785_item	2721962	et	3	main
aastat	doc_542009824785_item	2721985	et	3	main
vana	doc_542009824785_item	2721986	et	4	main
englise	doc_542009824785_item	2721999	et	4	main
eesti	doc_542009824785_item	2722010	et	4	main
olen	doc_542009824785_item	2722014	et	3	main
kaks	doc_542009824785_item	2722018	et	3	main
lapsed	doc_542009824785_item	2722019	et	3	main
lõbus	doc_542009824784_item	2721864	et	4	main
koolibaarisse	doc_542009824784_item	2721876	et	3	main
me	doc_542009824784_item	2721880	et	4	main
kooli	doc_542009824784_item	2721894	et	4	main
tartu	doc_542009824784_item	2721898	et	4	main
ta	doc_542009824784_item	2721929	et	4	main
sõidab	doc_542009824784_item	2721930	et	3	main
tartust	doc_542009824784_item	2721931	et	3	main
kojju	doc_542009824784_item	2721932	et	4	main
jõhvisse	doc_542009824784_item	2721933	et	3	main
kui	doc_542009824784_item	2721934	et	3	main
me	doc_542009824784_item	2721935	et	4	main
istume	doc_542009824784_item	2721944	et	3	main
kodus	doc_542009824784_item	2721945	et	4	main
filme	doc_542009824784_item	2721946	et	3	main
olen	doc_542009824785_item	2721982	et	3	main
koolis	doc_542009824785_item	2721997	et	4	main
oli	doc_542009824785_item	2722009	et	3	main
mul	doc_542009824785_item	2722016	et	3	main
minu	doc_542009824785_item	2722020	et	3	main
lugeda	doc_542009824785_item	2722027	et	3	main
raamatud	doc_542009824785_item	2722028	et	4	main
aga	doc_542009824785_item	2722029	et	3	main
mul	doc_542009824785_item	2722030	et	3	main
mul	doc_542009824785_item	2722042	et	3	main
on	doc_542009824785_item	2722043	et	4	main
keskmis	doc_542009824785_item	2722044	et	3	main
juuksed	doc_542009824785_item	2722049	et	3	main
essee	doc_542009824786_item	2722053	et	4	main
mere	doc_542009824786_item	2722085	et	3	main
ääres	doc_542009824786_item	2722086	et	4	main
olukord	doc_542009824786_item	2722098	et	3	main
ma	doc_542009824786_item	2722102	et	3	main
parandada	doc_542009824786_item	2722105	et	3	main
lähen	doc_542009824786_item	2722108	et	3	main
näidaks	doc_542009824786_item	2722110	et	3	main
mul	doc_542009824786_item	2722111	et	3	main
pärast	doc_542009824786_item	2722118	et	4	main
ja	doc_542009824786_item	2722121	et	3	main
aitan	doc_542009824786_item	2722125	et	3	main
palju	doc_542009824786_item	2722146	et	4	main
sõbrad	doc_542009824786_item	2722147	et	3	main
ja	doc_542009824786_item	2722148	et	3	main
me	doc_542009824786_item	2722149	et	4	main
sõber	doc_542009824786_item	2722157	et	3	main
appi	doc_542009824786_item	2722164	et	4	main
olukordi	doc_542009824786_item	2722165	et	4	main
aitan	doc_542009824787_item	2722223	et	3	main
mul	doc_542009824787_item	2722225	et	3	main
hea	doc_542009824787_item	2722227	et	4	main
kui	doc_542009824787_item	2722229	et	3	main
mul	doc_542009824787_item	2722230	et	3	main
jalutama	doc_542009824787_item	2722238	et	3	main
aru	doc_542009824787_item	2722247	et	4	main
sellega	doc_542009824787_item	2722258	et	3	main
siis	doc_542009824787_item	2722265	et	3	main
see	doc_542009824787_item	2722273	et	3	main
see	doc_542009824787_item	2722308	et	3	main
mulle	doc_542009824787_item	2722310	et	4	main
inimestele	doc_542009824787_item	2722314	et	3	main
ei	doc_542009824787_item	2722322	et	4	main
kohustusi	doc_542009824787_item	2722325	et	4	main
siis	doc_542009824787_item	2722326	et	3	main
ma	doc_542009824787_item	2722327	et	3	main
magan	doc_542009824787_item	2722328	et	3	main
on	doc_542009824787_item	2722338	et	4	main
lihtsalt	doc_542009824787_item	2722342	et	4	main
jaoks	doc_542009824788_item	2722355	et	4	main
teha	doc_542009824788_item	2722359	et	3	main
karjääri	doc_542009824788_item	2722360	et	4	main
et	doc_542009824788_item	2722372	et	3	main
minna	doc_542009824788_item	2722373	et	3	main
kursustele	doc_542009824788_item	2722374	et	3	main
et	doc_542009824788_item	2722378	et	3	main
on	doc_542009824788_item	2722381	et	4	main
pärast	doc_542009824789_item	2722408	et	4	main
telerit	doc_542009824789_item	2722420	et	3	main
püüan	doc_542009824789_item	2722431	et	3	main
olla	doc_542009824789_item	2722432	et	3	main
mõtelda	doc_542009824789_item	2722435	et	4	main
kui	doc_542009824789_item	2722440	et	3	main
helistan	doc_542009824789_item	2722448	et	3	main
linnasse	doc_542009824784_item	2721941	et	4	main
me	doc_542009824784_item	2721952	et	4	main
sõbrustame	doc_542009824784_item	2721953	et	3	main
sellepärast	doc_542009824784_item	2721954	et	3	main
saame	doc_542009824784_item	2721957	et	4	main
on	doc_542009824785_item	2721963	et	4	main
eesnimi	doc_542009824785_item	2721964	et	3	main
ma	doc_542009824785_item	2721965	et	3	main
olin	doc_542009824785_item	2721966	et	3	main
praegu	doc_542009824785_item	2721968	et	3	main
kohtla-järvel	doc_542009824785_item	2721967	et	4	main
ma	doc_542009824785_item	2721969	et	3	main
elan	doc_542009824785_item	2721970	et	3	main
purus	doc_542009824785_item	2721971	et	3	main
m	doc_542009824785_item	2721972	et	4	main
a	doc_542009824785_item	2721973	et	4	main
olen	doc_542009824785_item	2721974	et	3	main
venelane	doc_542009824785_item	2721975	et	3	main
mul	doc_542009824785_item	2721976	et	3	main
on	doc_542009824785_item	2721977	et	4	main
vene	doc_542009824785_item	2721978	et	4	main
riigi	doc_542009824785_item	2721979	et	3	main
kodakondsus	doc_542009824785_item	2721980	et	3	main
ma	doc_542009824785_item	2721981	et	3	main
kolmkümmend	doc_542009824785_item	2721983	et	4	main
ma	doc_542009824785_item	2721987	et	3	main
oli	doc_542009824785_item	2721998	et	3	main
keel	doc_542009824785_item	2722000	et	4	main
ja	doc_542009824785_item	2722002	et	3	main
kehaline	doc_542009824785_item	2722003	et	4	main
praegu	doc_542009824785_item	2722012	et	3	main
on	doc_542009824785_item	2722017	et	4	main
kasvu	doc_542009824785_item	2722045	et	4	main
selle	doc_542009824786_item	2722083	et	4	main
pingeline	doc_542009824786_item	2722097	et	4	main
asja	doc_542009824786_item	2722104	et	4	main
või	doc_542009824786_item	2722107	et	4	main
on	doc_542009824786_item	2722113	et	4	main
probleem	doc_542009824786_item	2722114	et	3	main
rägin	doc_542009824786_item	2722122	et	3	main
oma	doc_542009824786_item	2722127	et	4	main
heal	doc_542009824786_item	2722131	et	3	main
siis	doc_542009824786_item	2722135	et	3	main
rõmmus	doc_542009824786_item	2722138	et	4	main
mule	doc_542009824786_item	2722140	et	4	main
juure	doc_542009824786_item	2722144	et	3	main
televad	doc_542009824786_item	2722145	et	4	main
koos	doc_542009824786_item	2722150	et	4	main
soome	doc_542009824786_item	2722153	et	3	main
mu	doc_542009824786_item	2722156	et	3	main
mul	doc_542009824786_item	2722167	et	3	main
olen	doc_542009824787_item	2722183	et	3	main
keel	doc_542009824785_item	2722011	et	4	main
vallaline	doc_542009824785_item	2722015	et	4	main
hobisid	doc_542009824785_item	2722021	et	3	main
floristika	doc_542009824785_item	2722023	et	4	main
aega	doc_542009824785_item	2722033	et	4	main
inimene	doc_542009824785_item	2722034	et	3	main
ma	doc_542009824785_item	2722035	et	3	main
olen	doc_542009824785_item	2722036	et	3	main
sõbralik	doc_542009824785_item	2722037	et	3	main
korralik	doc_542009824785_item	2722038	et	3	main
ja	doc_542009824785_item	2722039	et	3	main
külalislahke	doc_542009824785_item	2722040	et	4	main
välimus	doc_542009824785_item	2722041	et	3	main
tumedad	doc_542009824785_item	2722048	et	3	main
alati	doc_542009824786_item	2722056	et	4	main
pargis	doc_542009824786_item	2722082	et	3	main
состояние	doc_542009824786_item	2722100	et	2	main
lähen	doc_542009824786_item	2722116	et	3	main
tööd	doc_542009824786_item	2722119	et	4	main
on	doc_542009824786_item	2722133	et	4	main
et	doc_542009824786_item	2722139	et	3	main
meeldib	doc_542009824786_item	2722141	et	3	main
joome	doc_542009824786_item	2722151	et	4	main
lauame	doc_542009824786_item	2722152	et	4	main
mind	doc_542009824786_item	2722159	et	4	main
siis	doc_542009824786_item	2722161	et	3	main
ma	doc_542009824786_item	2722162	et	3	main
mingeid	doc_542009824786_item	2722170	et	3	main
kohustusi	doc_542009824786_item	2722171	et	4	main
magama	doc_542009824786_item	2722175	et	3	main
et	doc_542009824786_item	2722176	et	3	main
ma	doc_542009824786_item	2722177	et	3	main
ettevaatlik	doc_542009824787_item	2722185	et	3	main
see	doc_542009824787_item	2722187	et	3	main
et	doc_542009824787_item	2722189	et	3	main
pingeline	doc_542009824787_item	2722232	et	4	main
lähen	doc_542009824787_item	2722236	et	3	main
see	doc_542009824787_item	2722239	et	3	main
mulle	doc_542009824787_item	2722241	et	4	main
aitab	doc_542009824787_item	2722244	et	3	main
mulle	doc_542009824787_item	2722245	et	4	main
saada	doc_542009824787_item	2722246	et	4	main
pingeline	doc_542009824787_item	2722250	et	4	main
olukord	doc_542009824787_item	2722251	et	3	main
heal	doc_542009824787_item	2722261	et	3	main
on	doc_542009824787_item	2722263	et	4	main
ma	doc_542009824787_item	2722266	et	3	main
armasta	doc_542009824787_item	2722270	et	4	main
sest	doc_542009824787_item	2722272	et	4	main
elu	doc_542009824787_item	2722333	et	4	main
ja	doc_542009824787_item	2722334	et	3	main
hetkel	doc_542009824787_item	2722335	et	4	main
millal	doc_542009824787_item	2722336	et	3	main
mul	doc_542009824787_item	2722337	et	3	main
harjutus	doc_542009824788_item	2722344	et	4	main
läksid	doc_542009824788_item	2722346	et	4	main
on	doc_542009824788_item	2722356	et	4	main
elu	doc_542009824788_item	2722369	et	4	main
jäoks	doc_542009824788_item	2722370	et	4	main
see	doc_542009824788_item	2722377	et	3	main
asja	doc_542009824789_item	2722407	et	4	main
ei	doc_542009824789_item	2722409	et	4	main
taga	doc_542009824789_item	2722418	et	4	main
puhata	doc_542009824789_item	2722423	et	4	main
mida	doc_542009824789_item	2722436	et	4	main
järjekorras	doc_542009824789_item	2722439	et	3	main
on	doc_542009824789_item	2722444	et	4	main
tähistab	doc_542009824789_item	2722456	et	3	main
siis	doc_542009824789_item	2722461	et	3	main
tema	doc_542009824789_item	2722464	et	4	main
juurde	doc_542009824789_item	2722465	et	4	main
uurin	doc_542009824789_item	2722475	et	3	main
vaatan	doc_542009824789_item	2722480	et	3	main
saan	doc_542009824789_item	2722483	et	4	main
kui	doc_542009824789_item	2722485	et	3	main
ei	doc_542009824785_item	2722031	et	4	main
ole	doc_542009824785_item	2722032	et	4	main
pruunised	doc_542009824785_item	2722046	et	4	main
praegu	doc_542009824785_item	2722050	et	3	main
ma	doc_542009824786_item	2722054	et	3	main
olen	doc_542009824786_item	2722055	et	3	main
добрый	doc_542009824786_item	2722064	et	2	main
ja	doc_542009824786_item	2722065	et	3	main
rahulike	doc_542009824786_item	2722066	et	4	main
спокойный	doc_542009824786_item	2722067	et	2	main
naine	doc_542009824786_item	2722068	et	3	main
et	doc_542009824786_item	2722069	et	3	main
mulle	doc_542009824786_item	2722070	et	4	main
ei	doc_542009824786_item	2722071	et	4	main
meeldib	doc_542009824786_item	2722072	et	3	main
konfliktid	doc_542009824786_item	2722073	et	3	main
mulle	doc_542009824786_item	2722074	et	4	main
meeldib	doc_542009824786_item	2722075	et	3	main
matkama	doc_542009824786_item	2722076	et	3	main
ходить	doc_542009824786_item	2722077	et	2	main
в	doc_542009824786_item	2722078	et	2	main
поход	doc_542009824786_item	2722079	et	2	main
või	doc_542009824786_item	2722080	et	4	main
jalutama	doc_542009824786_item	2722081	et	3	main
pärast	doc_542009824786_item	2722084	et	4	main
ja	doc_542009824786_item	2722087	et	3	main
metsas	doc_542009824786_item	2722088	et	3	main
ja	doc_542009824786_item	2722089	et	3	main
pargis	doc_542009824786_item	2722090	et	3	main
on	doc_542009824786_item	2722091	et	4	main
напряжонное	doc_542009824786_item	2722099	et	2	main
tahan	doc_542009824786_item	2722103	et	3	main
исправить	doc_542009824786_item	2722106	et	2	main
magama	doc_542009824786_item	2722109	et	3	main
kolleegil	doc_542009824786_item	2722112	et	3	main
talle	doc_542009824786_item	2722117	et	4	main
mul	doc_542009824786_item	2722095	et	3	main
on	doc_542009824786_item	2722096	et	4	main
siis	doc_542009824786_item	2722101	et	3	main
mina	doc_542009824786_item	2722115	et	4	main
kulla	doc_542009824786_item	2722120	et	4	main
temaga	doc_542009824786_item	2722123	et	3	main
tuttaval	doc_542009824786_item	2722132	et	4	main
olen	doc_542009824786_item	2722137	et	3	main
kui	doc_542009824786_item	2722155	et	3	main
kui	doc_542009824786_item	2722166	et	3	main
ei	doc_542009824786_item	2722168	et	4	main
ole	doc_542009824786_item	2722169	et	4	main
alati	doc_542009824787_item	2722184	et	4	main
inimene	doc_542009824787_item	2722186	et	3	main
tähendab	doc_542009824787_item	2722188	et	3	main
ma	doc_542009824787_item	2722190	et	3	main
olukord	doc_542009824787_item	2722233	et	3	main
ma	doc_542009824787_item	2722235	et	3	main
aitab	doc_542009824787_item	2722240	et	3	main
miks	doc_542009824787_item	2722248	et	4	main
see	doc_542009824787_item	2722249	et	3	main
mida	doc_542009824787_item	2722254	et	4	main
ma	doc_542009824787_item	2722269	et	3	main
sest	doc_542009824787_item	2722311	et	4	main
ma	doc_542009824787_item	2722315	et	3	main
end	doc_542009824787_item	2722317	et	4	main
inimesena	doc_542009824787_item	2722319	et	3	main
kui	doc_542009824787_item	2722320	et	3	main
ole	doc_542009824787_item	2722323	et	4	main
mingeid	doc_542009824787_item	2722324	et	3	main
mul	doc_542009824787_item	2722329	et	3	main
on	doc_542009824787_item	2722330	et	4	main
väga	doc_542009824787_item	2722331	et	3	main
vaba	doc_542009824787_item	2722339	et	4	main
maganvale	doc_542009824787_item	2722343	et	4	main
asjad	doc_542009824788_item	2722345	et	3	main
ülesmäge	doc_542009824788_item	2722347	et	3	main
suurim	doc_542009824788_item	2722357	et	3	main
vist	doc_542009824788_item	2722376	et	4	main
keele	doc_542009824788_item	2722379	et	4	main
kiirusta	doc_542009824789_item	2722414	et	4	main
vaadata	doc_542009824789_item	2722421	et	4	main
mul	doc_542009824789_item	2722425	et	3	main
on	doc_542009824789_item	2722426	et	4	main
pingeline	doc_542009824789_item	2722427	et	4	main
olukord	doc_542009824789_item	2722428	et	3	main
siis	doc_542009824789_item	2722429	et	3	main
ma	doc_542009824789_item	2722430	et	3	main
ja	doc_542009824789_item	2722434	et	3	main
esemeses	doc_542009824789_item	2722438	et	4	main
ja	doc_542009824789_item	2722458	et	3	main
mind	doc_542009824789_item	2722460	et	4	main
ma	doc_542009824789_item	2722462	et	3	main
mind	doc_542009824789_item	2722471	et	4	main
mis	doc_542009824789_item	2722476	et	4	main
on	doc_542009824789_item	2722478	et	4	main
mingeid	doc_542009824789_item	2722493	et	3	main
siiras	doc_542009824790_item	2722521	et	4	main
ma	doc_542009824790_item	2722523	et	3	main
venemaal	doc_542009824790_item	2722526	et	4	main
elan	doc_542009824790_item	2722529	et	3	main
estimaa	doc_542009824790_item	2722530	et	4	main
riik	doc_542009824790_item	2722536	et	3	main
liin	doc_542009824790_item	2722539	et	3	main
hääldamine	doc_542009824790_item	2722556	et	4	main
ja	doc_542009824790_item	2722557	et	3	main
pean	doc_542009824790_item	2722558	et	4	main
kõnepraktikat	doc_542009824790_item	2722567	et	3	main
õpisin	doc_542009824790_item	2722569	et	4	main
on	doc_542009824790_item	2722602	et	4	main
pildistan	doc_542009824790_item	2722623	et	3	main
veel	doc_542009824790_item	2722638	et	4	main
me	doc_542009824790_item	2722645	et	4	main
essee	doc_542009824791_item	2722657	et	4	main
minu	doc_542009824791_item	2722658	et	3	main
perekonnanimi	doc_542009824791_item	2722665	et	3	main
ma	doc_542009824791_item	2722671	et	3	main
pärit	doc_542009824791_item	2722673	et	3	main
sündinud	doc_542009824791_item	2722677	et	4	main
kaheksakümne	doc_542009824791_item	2722679	et	4	main
kahekümne	doc_542009824791_item	2722682	et	4	main
on	doc_542009824791_item	2722691	et	4	main
ma	doc_542009824791_item	2722728	et	3	main
mina	doc_542009824786_item	2722124	et	4	main
kõiki	doc_542009824786_item	2722126	et	4	main
sõpru	doc_542009824786_item	2722128	et	3	main
kui	doc_542009824786_item	2722129	et	3	main
mu	doc_542009824786_item	2722130	et	3	main
sünipäev	doc_542009824786_item	2722134	et	4	main
ma	doc_542009824786_item	2722136	et	3	main
sünnipäev	doc_542009824786_item	2722142	et	3	main
tema	doc_542009824786_item	2722143	et	4	main
tansime	doc_542009824786_item	2722154	et	4	main
palub	doc_542009824786_item	2722158	et	3	main
appi	doc_542009824786_item	2722160	et	4	main
lähen	doc_542009824786_item	2722163	et	3	main
siis	doc_542009824786_item	2722172	et	3	main
ma	doc_542009824786_item	2722173	et	3	main
lähen	doc_542009824786_item	2722174	et	3	main
väga	doc_542009824786_item	2722178	et	3	main
armastan	doc_542009824786_item	2722179	et	3	main
magama	doc_542009824786_item	2722180	et	3	main
essee	doc_542009824787_item	2722181	et	4	main
ma	doc_542009824787_item	2722182	et	3	main
alati	doc_542009824787_item	2722191	et	4	main
mõtlen	doc_542009824787_item	2722192	et	3	main
kui	doc_542009824787_item	2722193	et	3	main
tahan	doc_542009824787_item	2722194	et	3	main
midagi	doc_542009824787_item	2722195	et	4	main
teha	doc_542009824787_item	2722196	et	3	main
ma	doc_542009824787_item	2722197	et	3	main
ei	doc_542009824787_item	2722198	et	4	main
riski	doc_542009824787_item	2722199	et	4	main
mulle	doc_542009824787_item	2722200	et	4	main
meldib	doc_542009824787_item	2722201	et	4	main
aitama	doc_542009824787_item	2722202	et	3	main
kõiki	doc_542009824787_item	2722203	et	4	main
oma	doc_542009824787_item	2722204	et	4	main
sõpru	doc_542009824787_item	2722205	et	3	main
ma	doc_542009824787_item	2722206	et	3	main
arvan	doc_542009824787_item	2722207	et	3	main
et	doc_542009824787_item	2722208	et	3	main
kui	doc_542009824787_item	2722209	et	3	main
ma	doc_542009824787_item	2722210	et	3	main
aitan	doc_542009824787_item	2722211	et	3	main
sõbrale	doc_542009824787_item	2722212	et	3	main
siis	doc_542009824787_item	2722213	et	3	main
ta	doc_542009824787_item	2722214	et	4	main
aitab	doc_542009824787_item	2722215	et	3	main
mulle	doc_542009824787_item	2722216	et	4	main
tulevikus	doc_542009824787_item	2722217	et	4	main
kui	doc_542009824787_item	2722218	et	3	main
ma	doc_542009824787_item	2722219	et	3	main
vajan	doc_542009824787_item	2722220	et	3	main
kui	doc_542009824787_item	2722221	et	3	main
ma	doc_542009824787_item	2722222	et	3	main
siis	doc_542009824787_item	2722234	et	3	main
jalutamine	doc_542009824787_item	2722243	et	4	main
tekkis	doc_542009824787_item	2722252	et	3	main
oskan	doc_542009824787_item	2722256	et	3	main
kui	doc_542009824787_item	2722259	et	3	main
millal	doc_542009824787_item	2722276	et	3	main
kinkitakse	doc_542009824787_item	2722277	et	4	main
kingitused	doc_542009824787_item	2722278	et	4	main
ma	doc_542009824787_item	2722279	et	3	main
tihti	doc_542009824787_item	2722280	et	3	main
tähistan	doc_542009824787_item	2722281	et	3	main
sõpradega	doc_542009824787_item	2722282	et	3	main
sünnipäevi	doc_542009824787_item	2722283	et	4	main
kui	doc_542009824787_item	2722284	et	3	main
mu	doc_542009824787_item	2722285	et	3	main
sõber	doc_542009824787_item	2722286	et	3	main
palub	doc_542009824787_item	2722287	et	3	main
mind	doc_542009824787_item	2722288	et	4	main
appi	doc_542009824787_item	2722289	et	4	main
siis	doc_542009824787_item	2722290	et	3	main
ma	doc_542009824787_item	2722291	et	3	main
aitan	doc_542009824787_item	2722292	et	3	main
talle	doc_542009824787_item	2722293	et	4	main
kui	doc_542009824787_item	2722294	et	3	main
mul	doc_542009824787_item	2722295	et	3	main
on	doc_542009824787_item	2722296	et	4	main
võimalus	doc_542009824787_item	2722297	et	3	main
seda	doc_542009824787_item	2722298	et	3	main
teha	doc_542009824787_item	2722299	et	3	main
ma	doc_542009824787_item	2722300	et	3	main
tihti	doc_542009824787_item	2722301	et	3	main
aitan	doc_542009824787_item	2722302	et	3	main
sõpradele	doc_542009824787_item	2722303	et	3	main
kui	doc_542009824787_item	2722304	et	3	main
nad	doc_542009824787_item	2722305	et	3	main
paluvad	doc_542009824787_item	2722306	et	4	main
inimesele	doc_542009824787_item	2722224	et	3	main
on	doc_542009824787_item	2722226	et	4	main
meel	doc_542009824787_item	2722228	et	4	main
on	doc_542009824787_item	2722231	et	4	main
välja	doc_542009824787_item	2722237	et	4	main
rahunema	doc_542009824787_item	2722242	et	3	main
ja	doc_542009824787_item	2722253	et	3	main
ma	doc_542009824787_item	2722255	et	3	main
teha	doc_542009824787_item	2722257	et	3	main
mu	doc_542009824787_item	2722260	et	3	main
tuttaval	doc_542009824787_item	2722262	et	4	main
sünnipäev	doc_542009824787_item	2722264	et	3	main
õnnitlen	doc_542009824787_item	2722267	et	3	main
teda	doc_542009824787_item	2722268	et	4	main
sünnipäevad	doc_542009824787_item	2722271	et	3	main
on	doc_542009824787_item	2722274	et	4	main
aeg	doc_542009824787_item	2722275	et	3	main
mind	doc_542009824787_item	2722307	et	4	main
ma	doc_542009824787_item	2722312	et	3	main
tunnen	doc_542009824787_item	2722316	et	3	main
hea	doc_542009824787_item	2722318	et	4	main
mul	doc_542009824787_item	2722321	et	3	main
meeldib	doc_542009824787_item	2722309	et	3	main
aitan	doc_542009824787_item	2722313	et	3	main
aeg	doc_542009824787_item	2722340	et	3	main
põhjus	doc_542009824788_item	2722371	et	4	main
oli	doc_542009824788_item	2722375	et	3	main
oskus	doc_542009824788_item	2722380	et	3	main
tülitse	doc_542009824789_item	2722410	et	4	main
ei	doc_542009824789_item	2722411	et	4	main
mulle	doc_542009824789_item	2722415	et	4	main
meeldib	doc_542009824789_item	2722416	et	3	main
aktivne	doc_542009824787_item	2722332	et	4	main
ma	doc_542009824787_item	2722341	et	3	main
iga	doc_542009824788_item	2722348	et	4	main
inimene	doc_542009824788_item	2722349	et	3	main
tahab	doc_542009824788_item	2722350	et	3	main
tunda	doc_542009824788_item	2722351	et	3	main
end	doc_542009824788_item	2722352	et	4	main
vajalikuna	doc_542009824788_item	2722353	et	3	main
minu	doc_542009824788_item	2722354	et	3	main
väljakutse	doc_542009824788_item	2722358	et	4	main
ma	doc_542009824788_item	2722361	et	3	main
unistan	doc_542009824788_item	2722362	et	3	main
luua	doc_542009824788_item	2722363	et	4	main
mugavad	doc_542009824788_item	2722364	et	3	main
ja	doc_542009824788_item	2722365	et	3	main
head	doc_542009824788_item	2722366	et	4	main
tingimused	doc_542009824788_item	2722367	et	3	main
oma	doc_542009824788_item	2722368	et	4	main
tanapäeval	doc_542009824788_item	2722382	et	4	main
vajalik	doc_542009824788_item	2722383	et	3	main
endaga	doc_542009824788_item	2722384	et	4	main
rahulolev	doc_542009824788_item	2722385	et	4	main
inimene	doc_542009824788_item	2722386	et	3	main
on	doc_542009824788_item	2722387	et	4	main
alati	doc_542009824788_item	2722388	et	4	main
rõõmus	doc_542009824788_item	2722389	et	4	main
tema	doc_542009824788_item	2722390	et	4	main
kutsumus	doc_542009824788_item	2722391	et	3	main
on	doc_542009824788_item	2722392	et	4	main
saada	doc_542009824788_item	2722393	et	4	main
arstiks	doc_542009824788_item	2722394	et	4	main
essee	doc_542009824789_item	2722395	et	4	main
ma	doc_542009824789_item	2722396	et	3	main
olen	doc_542009824789_item	2722397	et	3	main
alati	doc_542009824789_item	2722398	et	4	main
rahulik	doc_542009824789_item	2722399	et	3	main
see	doc_542009824789_item	2722400	et	3	main
tähendab	doc_542009824789_item	2722401	et	3	main
et	doc_542009824789_item	2722402	et	3	main
ma	doc_542009824789_item	2722403	et	3	main
ei	doc_542009824789_item	2722404	et	4	main
närveeri	doc_542009824789_item	2722405	et	4	main
iga	doc_542009824789_item	2722406	et	4	main
karju	doc_542009824789_item	2722412	et	4	main
ei	doc_542009824789_item	2722413	et	4	main
arvuti	doc_542009824789_item	2722417	et	4	main
istuda	doc_542009824789_item	2722419	et	3	main
ja	doc_542009824789_item	2722422	et	3	main
kui	doc_542009824789_item	2722424	et	3	main
mu	doc_542009824789_item	2722441	et	3	main
ta	doc_542009824789_item	2722455	et	4	main
appi	doc_542009824789_item	2722472	et	4	main
siis	doc_542009824789_item	2722473	et	3	main
ma	doc_542009824789_item	2722482	et	3	main
saan	doc_542009824789_item	2722486	et	4	main
siis	doc_542009824789_item	2722487	et	3	main
aitan	doc_542009824789_item	2722488	et	3	main
kui	doc_542009824789_item	2722489	et	3	main
mul	doc_542009824789_item	2722490	et	3	main
ei	doc_542009824789_item	2722491	et	4	main
olen	doc_542009824790_item	2722524	et	3	main
minu	doc_542009824790_item	2722538	et	3	main
ma	doc_542009824790_item	2722547	et	3	main
tahaksis	doc_542009824790_item	2722549	et	4	main
keel	doc_542009824790_item	2722551	et	4	main
raske	doc_542009824790_item	2722553	et	4	main
veel	doc_542009824790_item	2722559	et	4	main
ma	doc_542009824790_item	2722568	et	3	main
ja	doc_542009824790_item	2722572	et	3	main
lõpetasin	doc_542009824790_item	2722573	et	3	main
sellel	doc_542009824790_item	2722574	et	4	main
aastal	doc_542009824790_item	2722575	et	3	main
praegu	doc_542009824790_item	2722576	et	3	main
ma	doc_542009824790_item	2722577	et	3	main
õpin	doc_542009824790_item	2722578	et	3	main
minu	doc_542009824790_item	2722582	et	3	main
operaatori	doc_542009824790_item	2722586	et	3	main
minu	doc_542009824790_item	2722587	et	3	main
nimi	doc_542009824790_item	2722594	et	3	main
meil	doc_542009824790_item	2722597	et	4	main
on	doc_542009824790_item	2722598	et	4	main
poeg	doc_542009824790_item	2722599	et	3	main
ta	doc_542009824790_item	2722600	et	4	main
nimi	doc_542009824790_item	2722601	et	3	main
käib	doc_542009824790_item	2722608	et	3	main
ilus	doc_542009824790_item	2722625	et	4	main
poega	doc_542009824790_item	2722629	et	4	main
pildil	doc_542009824790_item	2722631	et	3	main
ma	doc_542009824790_item	2722632	et	3	main
ja	doc_542009824790_item	2722633	et	3	main
minu	doc_542009824790_item	2722634	et	3	main
poeg	doc_542009824790_item	2722635	et	3	main
siin	doc_542009824790_item	2722636	et	4	main
vana	doc_542009824790_item	2722644	et	4	main
toila	doc_542009824790_item	2722649	et	4	main
on	doc_542009824791_item	2722660	et	4	main
perekonnanimi	doc_542009824791_item	2722663	et	3	main
ma	doc_542009824791_item	2722666	et	3	main
kakskümmendkaks	doc_542009824791_item	2722668	et	4	main
olen	doc_542009824791_item	2722672	et	3	main
kohtla-järves	doc_542009824791_item	2722674	et	4	main
tuhandeüheksasaja	doc_542009824791_item	2722678	et	4	main
eesti	doc_542009824791_item	2722692	et	4	main
protsesside	doc_542009824791_item	2722722	et	3	main
operaator	doc_542009824791_item	2722723	et	3	main
loodan	doc_542009824791_item	2722725	et	3	main
elan	doc_542009824791_item	2722746	et	3	main
on	doc_542009824791_item	2722762	et	4	main
eesnimi	doc_542009824791_item	2722763	et	3	main
laste	doc_542009824791_item	2722771	et	4	main
südamlik	doc_542009824791_item	2722779	et	3	main
ta	doc_542009824791_item	2722782	et	4	main
vaba	doc_542009824791_item	2722794	et	4	main
aeg	doc_542009824791_item	2722795	et	3	main
iseloom	doc_542009824791_item	2722806	et	3	main
looduses	doc_542009824791_item	2722831	et	4	main
tuju	doc_542009824791_item	2722834	et	4	main
samuti	doc_542009824791_item	2722835	et	3	main
tutvuda	doc_542009824791_item	2722838	et	3	main
eriti	doc_542009824791_item	2722842	et	3	main
keskaegsetel	doc_542009824791_item	2722845	et	4	main
ja	doc_542009824791_item	2722847	et	3	main
jutustus	doc_542009824792_item	2722850	et	4	main
on	doc_542009824792_item	2722854	et	4	main
on	doc_542009824792_item	2722858	et	4	main
ma	doc_542009824792_item	2722860	et	3	main
rahulik	doc_542009824789_item	2722433	et	3	main
teha	doc_542009824789_item	2722437	et	3	main
heal	doc_542009824789_item	2722442	et	3	main
tuttaval	doc_542009824789_item	2722443	et	4	main
sünnipäev	doc_542009824789_item	2722445	et	3	main
siis	doc_542009824789_item	2722446	et	3	main
ma	doc_542009824789_item	2722447	et	3	main
talle	doc_542009824789_item	2722449	et	4	main
hommikul	doc_542009824789_item	2722450	et	3	main
ja	doc_542009824789_item	2722451	et	3	main
soovin	doc_542009824789_item	2722452	et	3	main
õnne	doc_542009824789_item	2722453	et	4	main
kui	doc_542009824789_item	2722454	et	3	main
kutsub	doc_542009824789_item	2722459	et	3	main
kingitusega	doc_542009824789_item	2722466	et	4	main
kui	doc_542009824789_item	2722467	et	3	main
mu	doc_542009824789_item	2722468	et	3	main
sõber	doc_542009824789_item	2722469	et	3	main
palub	doc_542009824789_item	2722470	et	3	main
probleem	doc_542009824789_item	2722477	et	3	main
kas	doc_542009824789_item	2722481	et	3	main
ole	doc_542009824789_item	2722492	et	4	main
kohustasi	doc_542009824789_item	2722494	et	4	main
siis	doc_542009824789_item	2722495	et	3	main
ma	doc_542009824789_item	2722496	et	3	main
magan	doc_542009824789_item	2722497	et	3	main
kauem	doc_542009824789_item	2722498	et	4	main
teen	doc_542009824789_item	2722499	et	3	main
seda	doc_542009824789_item	2722500	et	3	main
mida	doc_542009824789_item	2722501	et	4	main
tahan	doc_542009824789_item	2722502	et	3	main
essee	doc_542009824790_item	2722503	et	4	main
tere	doc_542009824790_item	2722504	et	3	main
saame	doc_542009824790_item	2722505	et	4	main
tuttavaks	doc_542009824790_item	2722506	et	4	main
minu	doc_542009824790_item	2722507	et	3	main
nimi	doc_542009824790_item	2722508	et	3	main
on	doc_542009824790_item	2722509	et	4	main
eesnimi	doc_542009824790_item	2722510	et	3	main
mul	doc_542009824790_item	2722511	et	3	main
on	doc_542009824790_item	2722512	et	4	main
kakskümend	doc_542009824790_item	2722513	et	4	main
kuus	doc_542009824790_item	2722514	et	4	main
aastat	doc_542009824790_item	2722515	et	3	main
vana	doc_542009824790_item	2722516	et	4	main
ma	doc_542009824790_item	2722517	et	3	main
olen	doc_542009824790_item	2722518	et	3	main
sõbralik	doc_542009824790_item	2722519	et	3	main
ja	doc_542009824790_item	2722520	et	3	main
inimene	doc_542009824790_item	2722522	et	3	main
linnas	doc_542009824790_item	2722532	et	4	main
mul	doc_542009824790_item	2722533	et	3	main
meeldib	doc_542009824790_item	2722534	et	3	main
esti	doc_542009824790_item	2722535	et	4	main
kodune	doc_542009824790_item	2722541	et	4	main
palju	doc_542009824790_item	2722562	et	4	main
sünnipäev	doc_542009824789_item	2722457	et	3	main
lähen	doc_542009824789_item	2722463	et	3	main
ma	doc_542009824789_item	2722474	et	3	main
ja	doc_542009824789_item	2722479	et	3	main
aidata	doc_542009824789_item	2722484	et	4	main
jõhvi	doc_542009824790_item	2722531	et	4	main
ja	doc_542009824790_item	2722537	et	3	main
keel	doc_542009824790_item	2722545	et	4	main
aga	doc_542009824790_item	2722546	et	3	main
väga	doc_542009824790_item	2722548	et	3	main
eritit	doc_542009824790_item	2722552	et	4	main
on	doc_542009824790_item	2722554	et	4	main
mulle	doc_542009824790_item	2722555	et	4	main
juurde	doc_542009824790_item	2722560	et	4	main
õppima	doc_542009824790_item	2722561	et	3	main
ole	doc_542009824790_item	2722566	et	4	main
abielus	doc_542009824790_item	2722590	et	4	main
mehed	doc_542009824790_item	2722593	et	3	main
on	doc_542009824790_item	2722595	et	4	main
on	doc_542009824790_item	2722605	et	4	main
meeldib	doc_542009824790_item	2722622	et	3	main
minu	doc_542009824790_item	2722628	et	3	main
sellel	doc_542009824790_item	2722630	et	4	main
asub	doc_542009824790_item	2722646	et	3	main
nimi	doc_542009824791_item	2722659	et	3	main
on	doc_542009824791_item	2722664	et	4	main
olen	doc_542009824791_item	2722667	et	3	main
vana	doc_542009824791_item	2722670	et	4	main
ja	doc_542009824791_item	2722675	et	3	main
on	doc_542009824791_item	2722687	et	4	main
venelane	doc_542009824791_item	2722688	et	3	main
ja	doc_542009824791_item	2722689	et	3	main
kodakondsus	doc_542009824791_item	2722690	et	3	main
töötan	doc_542009824791_item	2722729	et	3	main
erialaks	doc_542009824791_item	2722731	et	3	main
pere	doc_542009824791_item	2722733	et	4	main
on	doc_542009824791_item	2722734	et	4	main
koos	doc_542009824791_item	2722747	et	4	main
nimi	doc_542009824791_item	2722753	et	3	main
on	doc_542009824791_item	2722754	et	4	main
eesnimi	doc_542009824791_item	2722755	et	3	main
ta	doc_542009824791_item	2722764	et	4	main
ajas	doc_542009824791_item	2722772	et	4	main
sõna	doc_542009824791_item	2722784	et	4	main
meeldin	doc_542009824791_item	2722797	et	3	main
aga	doc_542009824791_item	2722799	et	3	main
seltsiv	doc_542009824791_item	2722813	et	4	main
suvel	doc_542009824791_item	2722814	et	3	main
ja	doc_542009824791_item	2722820	et	3	main
mulle	doc_542009824791_item	2722823	et	4	main
vaba	doc_542009824791_item	2722826	et	4	main
oma	doc_542009824791_item	2722828	et	4	main
perekonna	doc_542009824791_item	2722829	et	4	main
tõstab	doc_542009824791_item	2722833	et	3	main
ma	doc_542009824791_item	2722836	et	3	main
kirikutel	doc_542009824791_item	2722846	et	4	main
lossid	doc_542009824791_item	2722848	et	4	main
minu	doc_542009824792_item	2722856	et	3	main
üheksasaja	doc_542009824792_item	2722866	et	4	main
elan	doc_542009824792_item	2722874	et	3	main
rahvusest	doc_542009824792_item	2722876	et	4	main
venelane	doc_542009824792_item	2722879	et	3	main
ma	doc_542009824792_item	2722880	et	3	main
eestis	doc_542009824792_item	2722882	et	3	main
tahtsin	doc_542009824792_item	2722885	et	3	main
ajalugu	doc_542009824792_item	2722931	et	4	main
raskusi	doc_542009824792_item	2722938	et	4	main
kaks	doc_542009824792_item	2722955	et	3	main
iseloomulikult	doc_542009824792_item	2722958	et	4	main
olen	doc_542009824792_item	2722960	et	3	main
töökas	doc_542009824792_item	2722962	et	4	main
kesk	doc_542009824792_item	2722974	et	3	main
sündinud	doc_542009824790_item	2722525	et	4	main
aga	doc_542009824790_item	2722527	et	3	main
praegu	doc_542009824790_item	2722528	et	3	main
minu	doc_542009824790_item	2722540	et	3	main
keel	doc_542009824790_item	2722542	et	4	main
on	doc_542009824790_item	2722543	et	4	main
vene	doc_542009824790_item	2722544	et	4	main
eesti	doc_542009824790_item	2722550	et	4	main
sõna	doc_542009824790_item	2722563	et	4	main
mul	doc_542009824790_item	2722564	et	3	main
ei	doc_542009824790_item	2722565	et	4	main
ida-virumaa	doc_542009824790_item	2722579	et	4	main
kutseharidus	doc_542009824790_item	2722580	et	3	main
eriala	doc_542009824790_item	2722583	et	4	main
protsesside	doc_542009824790_item	2722585	et	3	main
perekonnaseis	doc_542009824790_item	2722588	et	4	main
on	doc_542009824790_item	2722589	et	4	main
on	doc_542009824790_item	2722592	et	4	main
eesnimi	doc_542009824790_item	2722596	et	3	main
viieastane	doc_542009824790_item	2722606	et	4	main
poeg	doc_542009824790_item	2722607	et	3	main
ma	doc_542009824790_item	2722610	et	3	main
arvatan	doc_542009824790_item	2722611	et	4	main
mis	doc_542009824790_item	2722612	et	4	main
minu	doc_542009824790_item	2722613	et	3	main
pere	doc_542009824790_item	2722614	et	4	main
väga	doc_542009824790_item	2722615	et	3	main
sõbralik	doc_542009824790_item	2722616	et	3	main
minu	doc_542009824790_item	2722617	et	3	main
hobi	doc_542009824790_item	2722618	et	4	main
on	doc_542009824790_item	2722619	et	4	main
foto	doc_542009824790_item	2722620	et	4	main
mul	doc_542009824790_item	2722621	et	3	main
ja	doc_542009824790_item	2722627	et	3	main
on	doc_542009824790_item	2722637	et	4	main
on	doc_542009824790_item	2722647	et	4	main
park	doc_542009824790_item	2722648	et	3	main
tihti	doc_542009824790_item	2722651	et	3	main
minu	doc_542009824791_item	2722662	et	3	main
aastat	doc_542009824791_item	2722669	et	3	main
neljandal	doc_542009824791_item	2722680	et	3	main
teisel	doc_542009824791_item	2722683	et	4	main
augustil	doc_542009824791_item	2722684	et	3	main
mu	doc_542009824791_item	2722685	et	3	main
rahvusest	doc_542009824791_item	2722686	et	4	main
kohtla-järve	doc_542009824790_item	2722570	et	4	main
õhtukeskoolis	doc_542009824790_item	2722571	et	4	main
keskuses	doc_542009824790_item	2722581	et	4	main
tehnoloogiliste	doc_542009824790_item	2722584	et	4	main
meil	doc_542009824790_item	2722591	et	4	main
eesnimi	doc_542009824790_item	2722603	et	3	main
ta	doc_542009824790_item	2722604	et	4	main
lasteaias	doc_542009824790_item	2722609	et	4	main
loodust	doc_542009824790_item	2722624	et	4	main
koht	doc_542009824790_item	2722626	et	3	main
väike	doc_542009824790_item	2722639	et	4	main
tal	doc_542009824790_item	2722640	et	3	main
oli	doc_542009824790_item	2722641	et	3	main
üks	doc_542009824790_item	2722642	et	3	main
aastat	doc_542009824790_item	2722643	et	3	main
me	doc_542009824790_item	2722650	et	4	main
sõidame	doc_542009824790_item	2722652	et	3	main
toilas	doc_542009824790_item	2722653	et	4	main
ja	doc_542009824790_item	2722654	et	3	main
mere	doc_542009824790_item	2722655	et	3	main
ääres	doc_542009824790_item	2722656	et	4	main
eesnimi	doc_542009824791_item	2722661	et	3	main
olen	doc_542009824791_item	2722676	et	3	main
aastal	doc_542009824791_item	2722681	et	3	main
ma	doc_542009824791_item	2722693	et	3	main
lõpetasi	doc_542009824791_item	2722694	et	4	main
kooli	doc_542009824791_item	2722695	et	4	main
tuhande	doc_542009824791_item	2722696	et	3	main
üheksasaja	doc_542009824791_item	2722697	et	4	main
üheksakümne	doc_542009824791_item	2722698	et	4	main
kaheksandal	doc_542009824791_item	2722699	et	3	main
aastal	doc_542009824791_item	2722700	et	3	main
pärast	doc_542009824791_item	2722701	et	4	main
kooli	doc_542009824791_item	2722702	et	4	main
ma	doc_542009824791_item	2722703	et	3	main
lõpetasin	doc_542009824791_item	2722704	et	3	main
ida-virumaa	doc_542009824791_item	2722705	et	4	main
kutsehariduskeskus	doc_542009824791_item	2722706	et	3	main
kaks	doc_542009824791_item	2722707	et	3	main
tuhande	doc_542009824791_item	2722708	et	3	main
kuuendal	doc_542009824791_item	2722709	et	3	main
aastal	doc_542009824791_item	2722710	et	3	main
minu	doc_542009824791_item	2722711	et	3	main
eriala	doc_542009824791_item	2722712	et	4	main
on	doc_542009824791_item	2722713	et	4	main
pagar-kondiiter	doc_542009824791_item	2722714	et	3	main
samal	doc_542009824791_item	2722715	et	3	main
aastal	doc_542009824791_item	2722716	et	3	main
ma	doc_542009824791_item	2722717	et	3	main
õppima	doc_542009824791_item	2722719	et	3	main
erialaks	doc_542009824791_item	2722720	et	3	main
jatkan	doc_542009824791_item	2722718	et	4	main
tehnoloogiliste	doc_542009824791_item	2722721	et	4	main
ma	doc_542009824791_item	2722724	et	3	main
sellepärast	doc_542009824791_item	2722727	et	3	main
minu	doc_542009824791_item	2722732	et	3	main
ole	doc_542009824791_item	2722738	et	4	main
vanemad	doc_542009824791_item	2722739	et	4	main
aga	doc_542009824791_item	2722740	et	3	main
mul	doc_542009824791_item	2722741	et	3	main
on	doc_542009824791_item	2722742	et	4	main
üks	doc_542009824791_item	2722743	et	3	main
vend	doc_542009824791_item	2722744	et	3	main
et	doc_542009824791_item	2722726	et	3	main
väike	doc_542009824791_item	2722735	et	4	main
mul	doc_542009824791_item	2722736	et	3	main
ma	doc_542009824791_item	2722745	et	3	main
poega	doc_542009824791_item	2722748	et	4	main
ja	doc_542009824791_item	2722749	et	3	main
abikaasaga	doc_542009824791_item	2722750	et	3	main
mu	doc_542009824791_item	2722751	et	3	main
abikasa	doc_542009824791_item	2722752	et	4	main
selle	doc_542009824791_item	2722730	et	4	main
ei	doc_542009824791_item	2722737	et	4	main
ta	doc_542009824791_item	2722756	et	4	main
töötab	doc_542009824791_item	2722757	et	3	main
on	doc_542009824791_item	2722765	et	4	main
neli	doc_542009824791_item	2722766	et	3	main
aastat	doc_542009824791_item	2722767	et	3	main
buratino	doc_542009824791_item	2722773	et	4	main
vahel	doc_542009824791_item	2722781	et	4	main
minu	doc_542009824791_item	2722787	et	3	main
on	doc_542009824791_item	2722789	et	4	main
lugeda	doc_542009824791_item	2722798	et	3	main
spordi	doc_542009824791_item	2722801	et	4	main
ma	doc_542009824791_item	2722815	et	3	main
töötasin	doc_542009824791_item	2722816	et	3	main
agranomiks	doc_542009824791_item	2722817	et	4	main
koristajaks	doc_542009824791_item	2722819	et	4	main
veel	doc_542009824791_item	2722822	et	4	main
ringis	doc_542009824791_item	2722830	et	4	main
ja	doc_542009824791_item	2722840	et	3	main
essee	doc_542009824792_item	2722849	et	4	main
ennast	doc_542009824792_item	2722851	et	4	main
minu	doc_542009824792_item	2722852	et	3	main
perekonnanimi	doc_542009824792_item	2722859	et	3	main
olen	doc_542009824792_item	2722861	et	3	main
aastal	doc_542009824792_item	2722869	et	3	main
praegu	doc_542009824792_item	2722872	et	3	main
olen	doc_542009824792_item	2722878	et	3	main
sest	doc_542009824792_item	2722883	et	4	main
ma	doc_542009824792_item	2722884	et	3	main
kirjandus	doc_542009824792_item	2722932	et	3	main
ja	doc_542009824792_item	2722933	et	3	main
inglise	doc_542009824792_item	2722934	et	4	main
nädalat	doc_542009824792_item	2722957	et	3	main
olen	doc_542009824792_item	2722973	et	3	main
ma	doc_542009824792_item	2722976	et	3	main
ja	doc_542009824792_item	2722984	et	3	main
ja	doc_542009824794_item	2723120	et	3	main
jaoks	doc_542009824794_item	2723123	et	4	main
teed	doc_542009824794_item	2723140	et	4	main
leida	doc_542009824794_item	2723141	et	3	main
see	doc_542009824794_item	2723142	et	3	main
võib	doc_542009824794_item	2723148	et	3	main
võib	doc_542009824794_item	2723153	et	3	main
palju	doc_542009824794_item	2723155	et	4	main
aita	doc_542009824794_item	2723160	et	4	main
lihtsalt	doc_542009824794_item	2723164	et	4	main
ja	doc_542009824794_item	2723165	et	3	main
mobiiltelefonis	doc_542009824794_item	2723173	et	3	main
väga	doc_542009824794_item	2723176	et	3	main
teenindamine	doc_542009824795_item	2723207	et	4	main
miditsini	doc_542009824795_item	2723213	et	4	main
töötajatest	doc_542009824795_item	2723214	et	4	main
tõttu	doc_542009824795_item	2723233	et	4	main
hea	doc_542009824795_item	2723237	et	4	main
ravi	doc_542009824795_item	2723243	et	4	main
haiget	doc_542009824795_item	2723244	et	3	main
selle	doc_542009824795_item	2723245	et	4	main
pärast	doc_542009824795_item	2723246	et	4	main
kvalitet	doc_542009824795_item	2723259	et	4	main
tõtt	doc_542009824795_item	2723262	et	4	main
öeldes	doc_542009824795_item	2723263	et	3	main
mõni	doc_542009824795_item	2723264	et	3	main
olla	doc_542009824795_item	2723268	et	3	main
ning	doc_542009824796_item	2723308	et	3	main
ei	doc_542009824796_item	2723318	et	4	main
usalda	doc_542009824796_item	2723319	et	4	main
kaevanduses	doc_542009824791_item	2722758	et	4	main
minu	doc_542009824791_item	2722759	et	3	main
vana	doc_542009824791_item	2722768	et	4	main
ta	doc_542009824791_item	2722774	et	4	main
непослушный	doc_542009824791_item	2722786	et	2	main
mulle	doc_542009824791_item	2722796	et	4	main
ma	doc_542009824791_item	2722800	et	3	main
suhtes	doc_542009824791_item	2722802	et	4	main
ükskõikne	doc_542009824791_item	2722803	et	3	main
on	doc_542009824791_item	2722807	et	4	main
tasakaalukus	doc_542009824791_item	2722808	et	4	main
уравновешеный	doc_542009824791_item	2722809	et	2	main
kannatlik	doc_542009824791_item	2722810	et	3	main
терпеливый	doc_542009824791_item	2722811	et	2	main
ja	doc_542009824791_item	2722812	et	3	main
poja	doc_542009824791_item	2722760	et	4	main
nimi	doc_542009824791_item	2722761	et	3	main
ta	doc_542009824791_item	2722769	et	4	main
käib	doc_542009824791_item	2722770	et	3	main
on	doc_542009824791_item	2722775	et	4	main
väga	doc_542009824791_item	2722776	et	3	main
sõbralik	doc_542009824791_item	2722777	et	3	main
ja	doc_542009824791_item	2722778	et	3	main
сердечный	doc_542009824791_item	2722780	et	2	main
on	doc_542009824791_item	2722783	et	4	main
kulmatu	doc_542009824791_item	2722785	et	4	main
hobi	doc_542009824791_item	2722788	et	4	main
õmblema	doc_542009824791_item	2722790	et	3	main
kui	doc_542009824791_item	2722791	et	3	main
mul	doc_542009824791_item	2722792	et	3	main
on	doc_542009824791_item	2722793	et	4	main
равнодушна	doc_542009824791_item	2722804	et	2	main
minu	doc_542009824791_item	2722805	et	3	main
kokas	doc_542009824791_item	2722818	et	3	main
kelneriks	doc_542009824791_item	2722821	et	3	main
meeldida	doc_542009824791_item	2722824	et	3	main
aega	doc_542009824791_item	2722827	et	4	main
armastan	doc_542009824791_item	2722837	et	3	main
muuseumiga	doc_542009824791_item	2722841	et	3	main
mulle	doc_542009824791_item	2722843	et	4	main
eesnimi	doc_542009824792_item	2722855	et	3	main
perekonnanimi	doc_542009824792_item	2722857	et	3	main
linnas	doc_542009824792_item	2722864	et	4	main
tuhande	doc_542009824792_item	2722865	et	3	main
ma	doc_542009824792_item	2722873	et	3	main
üheksasaja	doc_542009824792_item	2722923	et	4	main
kaheksakümne	doc_542009824792_item	2722924	et	4	main
viiendal	doc_542009824792_item	2722925	et	3	main
koolis	doc_542009824792_item	2722927	et	4	main
minu	doc_542009824792_item	2722928	et	3	main
lemmikõppeained	doc_542009824792_item	2722929	et	3	main
oli	doc_542009824792_item	2722930	et	3	main
matemaatika	doc_542009824792_item	2722942	et	4	main
mulle	doc_542009824792_item	2722943	et	4	main
meeldin	doc_542009824792_item	2722944	et	3	main
tegeleda	doc_542009824792_item	2722945	et	3	main
spordiga	doc_542009824792_item	2722946	et	3	main
kasvatada	doc_542009824792_item	2722947	et	3	main
lilled	doc_542009824792_item	2722948	et	3	main
kududa	doc_542009824792_item	2722949	et	3	main
erinevaid	doc_542009824792_item	2722950	et	4	main
asjad	doc_542009824792_item	2722951	et	3	main
ma	doc_542009824792_item	2722952	et	3	main
lähen	doc_542009824792_item	2722953	et	3	main
ma	doc_542009824792_item	2722959	et	3	main
rahulik	doc_542009824792_item	2722961	et	3	main
kaastundlik	doc_542009824792_item	2722963	et	3	main
lõbus	doc_542009824792_item	2722964	et	4	main
välimuselt	doc_542009824792_item	2722967	et	3	main
ma	doc_542009824792_item	2722968	et	3	main
olen	doc_542009824792_item	2722969	et	3	main
ilus	doc_542009824792_item	2722970	et	4	main
naine	doc_542009824792_item	2722971	et	3	main
kasvu	doc_542009824792_item	2722975	et	4	main
tumedad	doc_542009824792_item	2722981	et	3	main
juuksed	doc_542009824792_item	2722983	et	3	main
armastavad	doc_542009824794_item	2723111	et	4	main
sõidavad	doc_542009824794_item	2723121	et	3	main
valismaal	doc_542009824794_item	2723126	et	4	main
tundmatus	doc_542009824794_item	2723133	et	4	main
isegi	doc_542009824794_item	2723135	et	4	main
veedan	doc_542009824791_item	2722825	et	3	main
see	doc_542009824791_item	2722832	et	3	main
vaatamisväärsustega	doc_542009824791_item	2722839	et	4	main
meeldin	doc_542009824791_item	2722844	et	3	main
eesnimi	doc_542009824792_item	2722853	et	3	main
sündinud	doc_542009824792_item	2722862	et	4	main
tartu	doc_542009824792_item	2722863	et	4	main
kuuekümne	doc_542009824792_item	2722867	et	4	main
kaheksandal	doc_542009824792_item	2722868	et	3	main
saada	doc_542009824792_item	2722886	et	4	main
eesti	doc_542009824792_item	2722887	et	4	main
kodakondsus	doc_542009824792_item	2722888	et	3	main
ma	doc_542009824792_item	2722889	et	3	main
andsin	doc_542009824792_item	2722890	et	3	main
eksam	doc_542009824792_item	2722891	et	3	main
ja	doc_542009824792_item	2722892	et	3	main
praegu	doc_542009824792_item	2722893	et	3	main
mul	doc_542009824792_item	2722894	et	3	main
on	doc_542009824792_item	2722895	et	4	main
eesti	doc_542009824792_item	2722896	et	4	main
mina	doc_542009824792_item	2722898	et	4	main
olen	doc_542009824792_item	2722899	et	3	main
kolm	doc_542009824792_item	2722900	et	3	main
kümmend	doc_542009824792_item	2722901	et	4	main
seitse	doc_542009824792_item	2722902	et	3	main
kodakondsus	doc_542009824792_item	2722897	et	3	main
aastat	doc_542009824792_item	2722903	et	3	main
vana	doc_542009824792_item	2722904	et	4	main
ma	doc_542009824792_item	2722905	et	3	main
olen	doc_542009824792_item	2722906	et	3	main
abielus	doc_542009824792_item	2722907	et	4	main
mul	doc_542009824792_item	2722908	et	3	main
on	doc_542009824792_item	2722909	et	4	main
kaks	doc_542009824792_item	2722910	et	3	main
last	doc_542009824792_item	2722911	et	4	main
tütar	doc_542009824792_item	2722912	et	3	main
ja	doc_542009824792_item	2722913	et	3	main
poeg	doc_542009824792_item	2722914	et	3	main
ma	doc_542009824792_item	2722915	et	3	main
õppisin	doc_542009824792_item	2722916	et	3	main
keskkoolis	doc_542009824792_item	2722918	et	4	main
neljateistkümnendas	doc_542009824792_item	2722917	et	4	main
ma	doc_542009824792_item	2722919	et	3	main
lõpetasin	doc_542009824792_item	2722920	et	3	main
viieteistkümnendal	doc_542009824792_item	2722870	et	4	main
novembril	doc_542009824792_item	2722871	et	3	main
kohtla-järvel	doc_542009824792_item	2722875	et	4	main
ma	doc_542009824792_item	2722877	et	3	main
elan	doc_542009824792_item	2722881	et	3	main
kooli	doc_542009824792_item	2722921	et	4	main
keel	doc_542009824792_item	2722935	et	4	main
on	doc_542009824792_item	2722939	et	4	main
füüsika	doc_542009824792_item	2722940	et	4	main
ja	doc_542009824792_item	2722941	et	3	main
ma	doc_542009824792_item	2722972	et	3	main
olen	doc_542009824792_item	2722977	et	3	main
on	doc_542009824792_item	2722980	et	4	main
pikkad	doc_542009824792_item	2722982	et	4	main
sinised	doc_542009824792_item	2722985	et	4	main
silmad	doc_542009824792_item	2722986	et	4	main
oma	doc_542009824794_item	2723112	et	4	main
istuda	doc_542009824794_item	2723115	et	3	main
selle	doc_542009824794_item	2723122	et	4	main
valismaale	doc_542009824794_item	2723124	et	4	main
ebatavaline	doc_542009824794_item	2723128	et	4	main
huvitav	doc_542009824794_item	2723131	et	4	main
on	doc_542009824794_item	2723143	et	4	main
ja	doc_542009824794_item	2723147	et	3	main
pöörama	doc_542009824794_item	2723151	et	3	main
tähendama	doc_542009824794_item	2723154	et	3	main
mitte	doc_542009824794_item	2723161	et	3	main
teed	doc_542009824794_item	2723168	et	4	main
kaart	doc_542009824794_item	2723172	et	4	main
sest	doc_542009824794_item	2723178	et	4	main
ligi	doc_542009824794_item	2723179	et	3	main
paljudes	doc_542009824794_item	2723180	et	3	main
on	doc_542009824795_item	2723221	et	4	main
usaldavad	doc_542009824795_item	2723228	et	4	main
oma	doc_542009824795_item	2723229	et	4	main
tervis	doc_542009824795_item	2723230	et	3	main
inimesed	doc_542009824795_item	2723231	et	3	main
selle	doc_542009824795_item	2723232	et	4	main
ka	doc_542009824795_item	2723239	et	3	main
mõjub	doc_542009824795_item	2723241	et	3	main
kvaliteedil	doc_542009824795_item	2723242	et	3	main
kui	doc_542009824795_item	2723253	et	3	main
ka	doc_542009824795_item	2723258	et	3	main
kord	doc_542009824795_item	2723265	et	4	main
essee	doc_542009824796_item	2723272	et	4	main
sest	doc_542009824796_item	2723302	et	4	main
ravi	doc_542009824796_item	2723304	et	4	main
spetsiaalse	doc_542009824796_item	2723306	et	3	main
siin	doc_542009824796_item	2723309	et	4	main
mõningad	doc_542009824796_item	2723316	et	3	main
arsti	doc_542009824796_item	2723320	et	4	main
tegelda	doc_542009824796_item	2723323	et	4	main
olla	doc_542009824796_item	2723328	et	3	main
milline	doc_542009824796_item	2723334	et	3	main
haige	doc_542009824796_item	2723338	et	4	main
see	doc_542009824796_item	2723340	et	3	main
ainult	doc_542009824797_item	2723351	et	4	main
arvan	doc_542009824797_item	2723361	et	3	main
ja	doc_542009824797_item	2723391	et	3	main
ta	doc_542009824797_item	2723394	et	4	main
tuhande	doc_542009824792_item	2722922	et	3	main
aastal	doc_542009824792_item	2722926	et	3	main
mulle	doc_542009824792_item	2722936	et	4	main
valmistasin	doc_542009824792_item	2722937	et	3	main
spordikeskuses	doc_542009824792_item	2722954	et	4	main
korda	doc_542009824792_item	2722956	et	4	main
ja	doc_542009824792_item	2722965	et	3	main
täpne	doc_542009824792_item	2722966	et	3	main
sale	doc_542009824792_item	2722978	et	3	main
mul	doc_542009824792_item	2722979	et	3	main
kodus	doc_542009824794_item	2723114	et	4	main
teised	doc_542009824794_item	2723116	et	4	main
armastavad	doc_542009824794_item	2723117	et	4	main
puhkusereis	doc_542009824794_item	2723125	et	4	main
aga	doc_542009824794_item	2723132	et	3	main
kohtades	doc_542009824794_item	2723134	et	3	main
kaardistikuga	doc_542009824794_item	2723136	et	3	main
väga	doc_542009824794_item	2723144	et	3	main
lisakilomeetrid	doc_542009824794_item	2723156	et	4	main
tehnoloogia	doc_542009824794_item	2723158	et	4	main
ja	doc_542009824794_item	2723163	et	3	main
õiget	doc_542009824794_item	2723167	et	3	main
see	doc_542009824794_item	2723170	et	3	main
oma	doc_542009824795_item	2723215	et	4	main
elukutse	doc_542009824795_item	2723216	et	4	main
minu	doc_542009824795_item	2723217	et	3	main
arvates	doc_542009824795_item	2723218	et	4	main
et	doc_542009824795_item	2723219	et	3	main
arst	doc_542009824795_item	2723220	et	3	main
essee	doc_542009824794_item	2723108	et	4	main
mõned	doc_542009824794_item	2723109	et	3	main
inimesed	doc_542009824794_item	2723110	et	3	main
puhkuses	doc_542009824794_item	2723113	et	4	main
lülitamised	doc_542009824794_item	2723118	et	4	main
otsima	doc_542009824794_item	2723119	et	4	main
on	doc_542009824794_item	2723127	et	4	main
ja	doc_542009824794_item	2723129	et	3	main
väga	doc_542009824794_item	2723130	et	3	main
on	doc_542009824794_item	2723137	et	4	main
raskelt	doc_542009824794_item	2723138	et	4	main
õiget	doc_542009824794_item	2723139	et	3	main
keeruline	doc_542009824794_item	2723145	et	4	main
kohas	doc_542009824794_item	2723150	et	4	main
võib	doc_542009824794_item	2723159	et	3	main
eksita	doc_542009824794_item	2723162	et	4	main
kiiresti	doc_542009824794_item	2723166	et	3	main
see	doc_542009824794_item	2723174	et	3	main
on	doc_542009824794_item	2723175	et	4	main
mugav	doc_542009824794_item	2723177	et	3	main
mobiiltelefon	doc_542009824794_item	2723181	et	3	main
on	doc_542009824794_item	2723182	et	4	main
kaasas	doc_542009824794_item	2723183	et	4	main
ka	doc_542009824794_item	2723184	et	3	main
osta	doc_542009824794_item	2723185	et	4	main
mobiiltelefon	doc_542009824794_item	2723186	et	3	main
navigatsioonitarkvaraga	doc_542009824794_item	2723187	et	3	main
on	doc_542009824794_item	2723188	et	4	main
odavam	doc_542009824794_item	2723189	et	4	main
kui	doc_542009824794_item	2723190	et	3	main
navigatsioonsüüstem	doc_542009824794_item	2723191	et	4	main
pihuarvutiga	doc_542009824794_item	2723192	et	4	main
essee	doc_542009824795_item	2723193	et	4	main
kas	doc_542009824795_item	2723194	et	3	main
tasuline	doc_542009824795_item	2723195	et	4	main
arstiabi	doc_542009824795_item	2723196	et	4	main
on	doc_542009824795_item	2723197	et	4	main
kvalitetsem	doc_542009824795_item	2723198	et	4	main
tasulisest	doc_542009824795_item	2723199	et	4	main
arstiabist	doc_542009824795_item	2723200	et	3	main
on	doc_542009824795_item	2723201	et	4	main
positiivsed	doc_542009824795_item	2723202	et	3	main
negativsed	doc_542009824795_item	2723204	et	4	main
poolad	doc_542009824795_item	2723205	et	4	main
ja	doc_542009824795_item	2723203	et	3	main
kvalitetne	doc_542009824795_item	2723206	et	4	main
inimesi	doc_542009824795_item	2723208	et	4	main
orienteeruma	doc_542009824794_item	2723146	et	3	main
vales	doc_542009824794_item	2723149	et	3	main
see	doc_542009824794_item	2723152	et	3	main
uus	doc_542009824794_item	2723157	et	3	main
leida	doc_542009824794_item	2723169	et	3	main
on	doc_542009824794_item	2723171	et	4	main
rahandumistest	doc_542009824795_item	2723210	et	4	main
ja	doc_542009824795_item	2723211	et	3	main
selle	doc_542009824795_item	2723225	et	4	main
pärast	doc_542009824795_item	2723226	et	4	main
tal	doc_542009824795_item	2723227	et	3	main
ta	doc_542009824795_item	2723234	et	4	main
peaks	doc_542009824795_item	2723235	et	4	main
palka	doc_542009824795_item	2723238	et	4	main
rahaldumine	doc_542009824795_item	2723240	et	4	main
siis	doc_542009824795_item	2723257	et	3	main
halb	doc_542009824795_item	2723269	et	3	main
spetsialist	doc_542009824795_item	2723271	et	3	main
kuidas	doc_542009824796_item	2723273	et	3	main
looduselt	doc_542009824796_item	2723301	et	4	main
eest	doc_542009824796_item	2723314	et	4	main
arsti	doc_542009824796_item	2723315	et	4	main
ja	doc_542009824796_item	2723321	et	3	main
see	doc_542009824796_item	2723326	et	3	main
on	doc_542009824796_item	2723336	et	4	main
aga	doc_542009824796_item	2723343	et	3	main
mõjub	doc_542009824796_item	2723345	et	3	main
ei	doc_542009824797_item	2723349	et	4	main
ma	doc_542009824797_item	2723360	et	3	main
erineb	doc_542009824797_item	2723364	et	3	main
loomast	doc_542009824797_item	2723366	et	4	main
saavad	doc_542009824797_item	2723376	et	4	main
reisida	doc_542009824797_item	2723379	et	3	main
kultuuriga	doc_542009824797_item	2723380	et	4	main
ja	doc_542009824797_item	2723382	et	3	main
keeli	doc_542009824797_item	2723383	et	4	main
õppida	doc_542009824797_item	2723384	et	3	main
kirjandust	doc_542009824797_item	2723385	et	3	main
lugeda	doc_542009824797_item	2723386	et	3	main
sellest	doc_542009824797_item	2723397	et	4	main
inimese	doc_542009824797_item	2723398	et	4	main
rahuldus	doc_542009824797_item	2723421	et	4	main
arvates	doc_542009824797_item	2723423	et	4	main
tõttu	doc_542009824797_item	2723430	et	4	main
samuti	doc_542009824797_item	2723431	et	3	main
inimene	doc_542009824797_item	2723432	et	3	main
suhelda	doc_542009824797_item	2723435	et	4	main
külas	doc_542009824797_item	2723438	et	3	main
kütsuda	doc_542009824797_item	2723440	et	4	main
sest	doc_542009824797_item	2723442	et	4	main
et	doc_542009824797_item	2723443	et	3	main
inimene	doc_542009824797_item	2723444	et	3	main
ei	doc_542009824797_item	2723445	et	4	main
täiesti	doc_542009824797_item	2723448	et	3	main
sest	doc_542009824797_item	2723450	et	4	main
talle	doc_542009824797_item	2723452	et	4	main
naiteks	doc_542009824797_item	2723460	et	4	main
kalapüügile	doc_542009824797_item	2723462	et	3	main
ning	doc_542009824797_item	2723465	et	3	main
see	doc_542009824797_item	2723467	et	3	main
rohkem	doc_542009824797_item	2723469	et	4	main
on	doc_542009824797_item	2723484	et	4	main
olla	doc_542009824797_item	2723495	et	3	main
aega	doc_542009824797_item	2723498	et	4	main
talvel	doc_542009824797_item	2723502	et	4	main
kiri	doc_542009824798_item	2723521	et	3	main
1500	doc_542009824798_item	2723534	et	2	main
krooni	doc_542009824798_item	2723535	et	4	main
ruum	doc_542009824798_item	2723547	et	3	main
aga	doc_542009824798_item	2723563	et	3	main
kohta	doc_542009824798_item	2723577	et	4	main
päevavalgust	doc_542009824798_item	2723581	et	4	main
silmad	doc_542009824798_item	2723592	et	4	main
rääkisin	doc_542009824798_item	2723597	et	3	main
ja	doc_542009824798_item	2723599	et	3	main
palusin	doc_542009824798_item	2723600	et	3	main
prooblemi	doc_542009824798_item	2723601	et	4	main
lahendada	doc_542009824798_item	2723602	et	3	main
aga	doc_542009824798_item	2723603	et	3	main
ta	doc_542009824798_item	2723604	et	4	main
ütles	doc_542009824798_item	2723605	et	3	main
et	doc_542009824798_item	2723606	et	3	main
sõltub	doc_542009824795_item	2723209	et	3	main
suhtumistest	doc_542009824795_item	2723212	et	4	main
vastutus	doc_542009824795_item	2723222	et	4	main
rikas	doc_542009824795_item	2723223	et	4	main
elukutse	doc_542009824795_item	2723224	et	4	main
rahandumine	doc_542009824795_item	2723254	et	4	main
on	doc_542009824795_item	2723255	et	4	main
võib	doc_542009824795_item	2723267	et	3	main
meditsini	doc_542009824795_item	2723270	et	3	main
suhtute	doc_542009824796_item	2723274	et	4	main
lõinud	doc_542009824796_item	2723300	et	4	main
abi	doc_542009824796_item	2723313	et	4	main
enese	doc_542009824796_item	2723324	et	4	main
ainult	doc_542009824796_item	2723330	et	4	main
spetsiialisti	doc_542009824796_item	2723331	et	4	main
võib	doc_542009824796_item	2723332	et	3	main
teada	doc_542009824796_item	2723333	et	3	main
on	doc_542009824797_item	2723354	et	4	main
vaja	doc_542009824797_item	2723355	et	4	main
inimesele	doc_542009824797_item	2723356	et	3	main
vaimu	doc_542009824797_item	2723357	et	4	main
jaoks	doc_542009824797_item	2723358	et	4	main
palju	doc_542009824797_item	2723373	et	4	main
võimalusi	doc_542009824797_item	2723374	et	3	main
erinavades	doc_542009824797_item	2723377	et	4	main
riigides	doc_542009824797_item	2723378	et	4	main
teatrides	doc_542009824797_item	2723387	et	4	main
kinot	doc_542009824797_item	2723392	et	4	main
külastada	doc_542009824797_item	2723393	et	3	main
muutub	doc_542009824797_item	2723395	et	3	main
õnnuks	doc_542009824797_item	2723396	et	4	main
asi	doc_542009824797_item	2723425	et	4	main
siski	doc_542009824797_item	2723426	et	3	main
ei	doc_542009824797_item	2723427	et	4	main
käia	doc_542009824797_item	2723437	et	4	main
külalised	doc_542009824797_item	2723441	et	4	main
üksi	doc_542009824797_item	2723449	et	4	main
et	doc_542009824797_item	2723451	et	3	main
on	doc_542009824797_item	2723453	et	4	main
vaja	doc_542009824797_item	2723454	et	4	main
käivad	doc_542009824797_item	2723461	et	4	main
küttimisele	doc_542009824797_item	2723464	et	4	main
kõige	doc_542009824797_item	2723468	et	4	main
laulamine	doc_542009824797_item	2723479	et	4	main
linnad	doc_542009824797_item	2723480	et	3	main
laine	doc_542009824797_item	2723481	et	4	main
kohin	doc_542009824797_item	2723482	et	3	main
sest	doc_542009824797_item	2723492	et	4	main
inimesed	doc_542009824797_item	2723493	et	3	main
oma	doc_542009824797_item	2723496	et	4	main
saama	doc_542009824795_item	2723236	et	4	main
on	doc_542009824795_item	2723247	et	4	main
vaja	doc_542009824795_item	2723248	et	4	main
ostma	doc_542009824795_item	2723249	et	3	main
uue	doc_542009824795_item	2723250	et	3	main
meditsini	doc_542009824795_item	2723251	et	3	main
seadmestikud	doc_542009824795_item	2723252	et	3	main
hea	doc_542009824795_item	2723256	et	4	main
on	doc_542009824795_item	2723260	et	4	main
hea	doc_542009824795_item	2723261	et	4	main
vel	doc_542009824795_item	2723266	et	4	main
ravimite	doc_542009824796_item	2723275	et	3	main
reklaamimise	doc_542009824796_item	2723276	et	4	main
televisionis	doc_542009824796_item	2723277	et	4	main
ja	doc_542009824796_item	2723278	et	3	main
radios	doc_542009824796_item	2723279	et	4	main
tõtt	doc_542009824796_item	2723280	et	4	main
öeldes	doc_542009824796_item	2723281	et	3	main
minu	doc_542009824796_item	2723282	et	3	main
suhe	doc_542009824796_item	2723283	et	3	main
ravimite	doc_542009824796_item	2723284	et	3	main
reklaamimise	doc_542009824796_item	2723285	et	4	main
on	doc_542009824796_item	2723286	et	4	main
negativne	doc_542009824796_item	2723287	et	4	main
selle	doc_542009824796_item	2723288	et	4	main
pärast	doc_542009824796_item	2723289	et	4	main
et	doc_542009824796_item	2723290	et	3	main
ravimitel	doc_542009824796_item	2723292	et	3	main
on	doc_542009824796_item	2723293	et	4	main
kõrvaltoimeid	doc_542009824796_item	2723294	et	3	main
kui	doc_542009824796_item	2723295	et	3	main
paljuteid	doc_542009824796_item	2723291	et	3	main
nad	doc_542009824796_item	2723296	et	3	main
toodas	doc_542009824796_item	2723297	et	4	main
aga	doc_542009824796_item	2723298	et	3	main
ei	doc_542009824796_item	2723299	et	4	main
et	doc_542009824796_item	2723303	et	3	main
on	doc_542009824796_item	2723305	et	4	main
toode	doc_542009824796_item	2723307	et	3	main
on	doc_542009824796_item	2723310	et	4	main
vaja	doc_542009824796_item	2723311	et	4	main
pöörama	doc_542009824796_item	2723312	et	3	main
inimesed	doc_542009824796_item	2723317	et	3	main
võib	doc_542009824796_item	2723322	et	3	main
ohtlikult	doc_542009824796_item	2723329	et	4	main
individualselt	doc_542009824796_item	2723342	et	4	main
halvasti	doc_542009824796_item	2723346	et	3	main
inimene	doc_542009824797_item	2723348	et	3	main
ela	doc_542009824797_item	2723350	et	4	main
leivast	doc_542009824797_item	2723352	et	4	main
tõenäoliselt	doc_542009824797_item	2723353	et	4	main
et	doc_542009824797_item	2723362	et	3	main
inimesed	doc_542009824797_item	2723375	et	3	main
käia	doc_542009824797_item	2723388	et	4	main
ka	doc_542009824797_item	2723389	et	3	main
ole	doc_542009824797_item	2723428	et	4	main
vaja	doc_542009824797_item	2723434	et	4	main
ja	doc_542009824797_item	2723439	et	3	main
saa	doc_542009824797_item	2723446	et	4	main
suhtlemine	doc_542009824797_item	2723455	et	4	main
inimestel	doc_542009824797_item	2723457	et	3	main
hobbi	doc_542009824797_item	2723459	et	4	main
või	doc_542009824797_item	2723463	et	4	main
vaimu	doc_542009824797_item	2723470	et	4	main
tõttu	doc_542009824797_item	2723471	et	4	main
kuulata	doc_542009824797_item	2723478	et	4	main
inimene	doc_542009824797_item	2723483	et	3	main
loodust	doc_542009824797_item	2723486	et	4	main
linnas	doc_542009824797_item	2723487	et	4	main
püüavad	doc_542009824797_item	2723494	et	3	main
nad	doc_542009824797_item	2723501	et	3	main
aga	doc_542009824797_item	2723504	et	3	main
suvel	doc_542009824797_item	2723505	et	3	main
mina	doc_542009824798_item	2723530	et	4	main
maksin	doc_542009824798_item	2723531	et	3	main
kursuste	doc_542009824798_item	2723532	et	3	main
te	doc_542009824798_item	2723541	et	4	main
võtsite	doc_542009824798_item	2723542	et	3	main
25	doc_542009824798_item	2723543	et	2	main
inimest	doc_542009824798_item	2723544	et	3	main
aga	doc_542009824798_item	2723545	et	3	main
ei	doc_542009824798_item	2723565	et	4	main
ole	doc_542009824798_item	2723566	et	4	main
kitsas	doc_542009824798_item	2723571	et	4	main
on	doc_542009824798_item	2723579	et	4	main
vähe	doc_542009824798_item	2723580	et	3	main
on	doc_542009824798_item	2723593	et	4	main
ja	doc_542009824798_item	2723611	et	3	main
ravi	doc_542009824796_item	2723325	et	4	main
võib	doc_542009824796_item	2723327	et	3	main
ravi	doc_542009824796_item	2723335	et	4	main
vaja	doc_542009824796_item	2723337	et	4	main
jaoks	doc_542009824796_item	2723339	et	4	main
on	doc_542009824796_item	2723341	et	4	main
massireklaami	doc_542009824796_item	2723344	et	4	main
essee	doc_542009824797_item	2723347	et	4	main
palju	doc_542009824797_item	2723359	et	4	main
ta	doc_542009824797_item	2723363	et	4	main
sellega	doc_542009824797_item	2723365	et	3	main
täna	doc_542009824797_item	2723367	et	4	main
päeval	doc_542009824797_item	2723368	et	3	main
on	doc_542009824797_item	2723369	et	4	main
kaasaaegse	doc_542009824797_item	2723370	et	3	main
maailmas	doc_542009824797_item	2723371	et	3	main
väga	doc_542009824797_item	2723372	et	3	main
tutvuda	doc_542009824797_item	2723381	et	3	main
kontserte	doc_542009824797_item	2723390	et	3	main
elu	doc_542009824797_item	2723399	et	4	main
saab	doc_542009824797_item	2723400	et	3	main
sellest	doc_542009824797_item	2723401	et	4	main
huvitavamalt	doc_542009824797_item	2723402	et	4	main
ta	doc_542009824797_item	2723403	et	4	main
muutub	doc_542009824797_item	2723404	et	3	main
õnnelikuks	doc_542009824797_item	2723405	et	3	main
inimene	doc_542009824797_item	2723406	et	3	main
kui	doc_542009824797_item	2723407	et	3	main
töötab	doc_542009824797_item	2723408	et	3	main
ka	doc_542009824797_item	2723409	et	3	main
teeb	doc_542009824797_item	2723410	et	3	main
vaimuga	doc_542009824797_item	2723412	et	3	main
töö	doc_542009824797_item	2723411	et	4	main
kui	doc_542009824797_item	2723413	et	3	main
ta	doc_542009824797_item	2723414	et	4	main
armastab	doc_542009824797_item	2723415	et	3	main
selle	doc_542009824797_item	2723416	et	4	main
töö	doc_542009824797_item	2723417	et	4	main
ta	doc_542009824797_item	2723418	et	4	main
saab	doc_542009824797_item	2723419	et	3	main
sellest	doc_542009824797_item	2723420	et	4	main
minu	doc_542009824797_item	2723422	et	3	main
et	doc_542009824797_item	2723424	et	3	main
on	doc_542009824797_item	2723433	et	4	main
elada	doc_542009824797_item	2723447	et	3	main
selleks	doc_542009824797_item	2723472	et	4	main
et	doc_542009824797_item	2723473	et	3	main
laps	doc_542009824797_item	2723485	et	4	main
ta	doc_542009824797_item	2723488	et	4	main
hingab	doc_542009824797_item	2723489	et	3	main
suurem	doc_542009824797_item	2723499	et	4	main
direktor	doc_542009824798_item	2723523	et	3	main
teie	doc_542009824798_item	2723525	et	4	main
hiina	doc_542009824798_item	2723527	et	3	main
teie	doc_542009824798_item	2723536	et	4	main
sekretär	doc_542009824798_item	2723537	et	3	main
teatis	doc_542009824798_item	2723538	et	3	main
kus	doc_542009824798_item	2723548	et	3	main
õpime	doc_542009824798_item	2723550	et	3	main
liiga	doc_542009824798_item	2723552	et	4	main
valgustuste	doc_542009824798_item	2723576	et	4	main
ruumis	doc_542009824798_item	2723585	et	4	main
on	doc_542009824798_item	2723586	et	4	main
väga	doc_542009824798_item	2723587	et	3	main
rahu	doc_542009824797_item	2723429	et	4	main
sõbradega	doc_542009824797_item	2723436	et	4	main
ka	doc_542009824797_item	2723456	et	3	main
on	doc_542009824797_item	2723458	et	4	main
teevad	doc_542009824797_item	2723466	et	3	main
suhelda	doc_542009824797_item	2723474	et	4	main
loodusega	doc_542009824797_item	2723475	et	4	main
puhata	doc_542009824797_item	2723476	et	4	main
tsivilisatsioonist	doc_542009824797_item	2723477	et	3	main
määrduliku	doc_542009824797_item	2723490	et	4	main
õhu	doc_542009824797_item	2723491	et	3	main
vaba	doc_542009824797_item	2723497	et	4	main
loodusele	doc_542009824797_item	2723500	et	4	main
püüavad	doc_542009824797_item	2723506	et	3	main
vaja	doc_542009824797_item	2723507	et	4	main
suusatavad	doc_542009824797_item	2723503	et	4	main
sõida	doc_542009824797_item	2723508	et	4	main
maal	doc_542009824797_item	2723509	et	4	main
või	doc_542009824797_item	2723510	et	4	main
suvilas	doc_542009824797_item	2723511	et	3	main
minu	doc_542009824797_item	2723512	et	3	main
arvates	doc_542009824797_item	2723513	et	4	main
et	doc_542009824797_item	2723514	et	3	main
inimesel	doc_542009824797_item	2723515	et	3	main
on	doc_542009824797_item	2723516	et	4	main
esimesel	doc_542009824797_item	2723517	et	3	main
kohal	doc_542009824797_item	2723518	et	4	main
vaim	doc_542009824797_item	2723519	et	3	main
ametlik	doc_542009824798_item	2723520	et	3	main
lugupeetud	doc_542009824798_item	2723522	et	4	main
kooli	doc_542009824798_item	2723526	et	4	main
keele	doc_542009824798_item	2723528	et	4	main
kursustele	doc_542009824798_item	2723529	et	3	main
mulle	doc_542009824798_item	2723539	et	4	main
et	doc_542009824798_item	2723540	et	3	main
me	doc_542009824798_item	2723549	et	4	main
väga	doc_542009824798_item	2723570	et	3	main
samuti	doc_542009824798_item	2723572	et	3	main
on	doc_542009824798_item	2723573	et	4	main
mul	doc_542009824798_item	2723574	et	3	main
pretensioon	doc_542009824798_item	2723575	et	3	main
elektrivalgust	doc_542009824798_item	2723583	et	4	main
väsinud	doc_542009824798_item	2723595	et	4	main
ma	doc_542009824798_item	2723612	et	3	main
teie	doc_542009824798_item	2723615	et	4	main
registreerusin	doc_542009824798_item	2723524	et	3	main
eest	doc_542009824798_item	2723533	et	4	main
see	doc_542009824798_item	2723546	et	3	main
on	doc_542009824798_item	2723551	et	4	main
väike	doc_542009824798_item	2723553	et	4	main
sellise	doc_542009824798_item	2723554	et	4	main
koguse	doc_542009824798_item	2723555	et	4	main
jaoks	doc_542009824798_item	2723556	et	4	main
ja	doc_542009824798_item	2723557	et	3	main
tuleb	doc_542009824798_item	2723558	et	3	main
istuda	doc_542009824798_item	2723559	et	3	main
kolmekesi	doc_542009824798_item	2723560	et	3	main
laua	doc_542009824798_item	2723561	et	3	main
taga	doc_542009824798_item	2723562	et	4	main
see	doc_542009824798_item	2723564	et	3	main
mugav	doc_542009824798_item	2723567	et	3	main
ja	doc_542009824798_item	2723568	et	3	main
on	doc_542009824798_item	2723569	et	4	main
ruumis	doc_542009824798_item	2723578	et	4	main
ja	doc_542009824798_item	2723582	et	3	main
õhtul	doc_542009824798_item	2723584	et	3	main
lõpuks	doc_542009824798_item	2723591	et	4	main
pöördun	doc_542009824798_item	2723613	et	3	main
prooblem	doc_542009824798_item	2723621	et	4	main
tume	doc_542009824798_item	2723588	et	3	main
ja	doc_542009824798_item	2723589	et	3	main
tunni	doc_542009824798_item	2723590	et	3	main
väga	doc_542009824798_item	2723594	et	3	main
ma	doc_542009824798_item	2723596	et	3	main
õpetajaga	doc_542009824798_item	2723598	et	4	main
poole	doc_542009824798_item	2723616	et	4	main
ja	doc_542009824798_item	2723617	et	3	main
palun	doc_542009824798_item	2723618	et	3	main
lahendada	doc_542009824798_item	2723619	et	3	main
see	doc_542009824798_item	2723620	et	3	main
ma	doc_542009824798_item	2723607	et	3	main
pean	doc_542009824798_item	2723608	et	4	main
rääkima	doc_542009824798_item	2723609	et	3	main
direktoriga	doc_542009824798_item	2723610	et	3	main
nüüd	doc_542009824798_item	2723614	et	4	main
sellistes	doc_542009824798_item	2723622	et	4	main
elukordades	doc_542009824798_item	2723623	et	3	main
ei	doc_542009824798_item	2723624	et	4	main
ole	doc_542009824798_item	2723625	et	4	main
võimalik	doc_542009824798_item	2723626	et	3	main
õppida	doc_542009824798_item	2723627	et	3	main
edasi	doc_542009824798_item	2723628	et	3	main
ametlik	doc_542009824802_item	2723970	et	3	main
tamme	doc_542009824802_item	2723974	et	4	main
kohtla-järve	doc_542009824802_item	2723977	et	4	main
mina	doc_542009824802_item	2723978	et	4	main
ostsin	doc_542009824802_item	2723979	et	3	main
teie	doc_542009824802_item	2723980	et	4	main
krooni	doc_542009824802_item	2723987	et	4	main
probleem	doc_542009824802_item	2723990	et	3	main
poest	doc_542009824802_item	2723981	et	4	main
15092004	doc_542009824802_item	2723982	et	2	main
kohvimasina	doc_542009824802_item	2723983	et	3	main
kohvimasin	doc_542009824802_item	2723984	et	3	main
tekkis	doc_542009824802_item	2723988	et	3	main
vastu	doc_542009824802_item	2724021	et	3	main
eesnimi	doc_542009824802_item	2724025	et	3	main
98	doc_542009824802_item	2724029	et	2	main
56	doc_542009824802_item	2724036	et	2	main
lemmikõpetaja	doc_542009824803_item	2724040	et	4	main
matemaatikat	doc_542009824803_item	2724042	et	3	main
ja	doc_542009824803_item	2724055	et	3	main
lahendasin	doc_542009824803_item	2724056	et	3	main
pärast	doc_542009824803_item	2724062	et	4	main
eksamile	doc_542009824803_item	2724076	et	3	main
lemmik	doc_542009824804_item	2724079	et	3	main
minu	doc_542009824804_item	2724081	et	3	main
viiekümne	doc_542009824804_item	2724089	et	4	main
tundides	doc_542009824804_item	2724097	et	3	main
kirjutasime	doc_542009824804_item	2724101	et	3	main
õpisime	doc_542009824804_item	2724103	et	4	main
arutasime	doc_542009824804_item	2724105	et	3	main
kooli	doc_542009824804_item	2724129	et	4	main
koos	doc_542009824804_item	2724131	et	4	main
on	doc_542009824804_item	2724150	et	4	main
meil	doc_542009824804_item	2724151	et	4	main
oli	doc_542009824805_item	2724160	et	3	main
muusika	doc_542009824805_item	2724161	et	4	main
klassi	doc_542009824805_item	2724167	et	4	main
üht	doc_542009824805_item	2724217	et	3	main
päeva	doc_542009824805_item	2724223	et	4	main
kiri	doc_542009824802_item	2723971	et	3	main
maksis	doc_542009824802_item	2723985	et	4	main
selline	doc_542009824802_item	2723989	et	4	main
tel	doc_542009824802_item	2724032	et	4	main
94	doc_542009824802_item	2724035	et	2	main
minu	doc_542009824803_item	2724039	et	3	main
ta	doc_542009824803_item	2724043	et	4	main
oli	doc_542009824803_item	2724044	et	3	main
umbes	doc_542009824803_item	2724045	et	4	main
me	doc_542009824803_item	2724052	et	4	main
tegime	doc_542009824803_item	2724053	et	3	main
jäin	doc_542009824803_item	2724061	et	3	main
seal	doc_542009824803_item	2724064	et	4	main
tegelesime	doc_542009824803_item	2724075	et	3	main
käis	doc_542009824804_item	2724092	et	4	main
rangelt	doc_542009824804_item	2724094	et	4	main
ning	doc_542009824804_item	2724095	et	3	main
maitsekalt	doc_542009824804_item	2724096	et	4	main
me	doc_542009824804_item	2724098	et	4	main
ülesandeid	doc_542009824804_item	2724100	et	3	main
ekskursioonidele	doc_542009824804_item	2724123	et	3	main
mina	doc_542009824804_item	2724130	et	4	main
teiste	doc_542009824804_item	2724132	et	4	main
ja	doc_542009824804_item	2724139	et	3	main
torti	doc_542009824804_item	2724141	et	4	main
ja	doc_542009824804_item	2724142	et	3	main
suhtlesime	doc_542009824804_item	2724143	et	3	main
jutustasime	doc_542009824804_item	2724144	et	3	main
ja	doc_542009824804_item	2724153	et	3	main
plaanid	doc_542009824804_item	2724154	et	4	main
praegu	doc_542009824804_item	2724155	et	3	main
tali	doc_542009824805_item	2724165	et	4	main
oli	doc_542009824805_item	2724179	et	3	main
kunagi	doc_542009824805_item	2724210	et	3	main
vilde	doc_542009824802_item	2723973	et	4	main
8	doc_542009824802_item	2723975	et	2	main
350	doc_542009824802_item	2723986	et	2	main
tagastatakse	doc_542009824802_item	2724023	et	3	main
perekonnanimi	doc_542009824802_item	2724026	et	3	main
männiku	doc_542009824802_item	2724027	et	3	main
56	doc_542009824802_item	2724033	et	2	main
ta	doc_542009824803_item	2724047	et	4	main
mina	doc_542009824803_item	2724058	et	4	main
klassikastlastega	doc_542009824803_item	2724059	et	3	main
meil	doc_542009824803_item	2724070	et	4	main
oli	doc_542009824803_item	2724071	et	3	main
essee	doc_542009824804_item	2724077	et	4	main
õpetaja	doc_542009824804_item	2724080	et	4	main
matemaatikat	doc_542009824804_item	2724085	et	3	main
aastane	doc_542009824804_item	2724090	et	4	main
lahendasime	doc_542009824804_item	2724099	et	3	main
nägin	doc_542009824804_item	2724125	et	3	main
pärast	doc_542009824804_item	2724128	et	4	main
olime	doc_542009824804_item	2724134	et	3	main
jõime	doc_542009824804_item	2724137	et	3	main
millised	doc_542009824804_item	2724149	et	3	main
minu	doc_542009824805_item	2724157	et	3	main
lemmik	doc_542009824805_item	2724158	et	3	main
õpetaja	doc_542009824805_item	2724159	et	4	main
hommik	doc_542009824805_item	2724164	et	3	main
ta	doc_542009824805_item	2724174	et	4	main
oli	doc_542009824805_item	2724175	et	3	main
väga	doc_542009824805_item	2724176	et	3	main
kaunis	doc_542009824805_item	2724177	et	4	main
juuksed	doc_542009824805_item	2724178	et	3	main
ei	doc_542009824805_item	2724211	et	4	main
koduseid	doc_542009824805_item	2724213	et	4	main
töid	doc_542009824805_item	2724214	et	3	main
tunnilõpus	doc_542009824805_item	2724215	et	4	main
laulsime	doc_542009824805_item	2724216	et	3	main
laulu	doc_542009824805_item	2724218	et	4	main
kus	doc_542009824805_item	2724219	et	3	main
üksteisele	doc_542009824805_item	2724221	et	3	main
kauplus	doc_542009824802_item	2723972	et	3	main
56656	doc_542009824802_item	2723976	et	2	main
et	doc_542009824802_item	2723991	et	3	main
põles	doc_542009824802_item	2723992	et	4	main
läbi	doc_542009824802_item	2723993	et	4	main
soojendus	doc_542009824802_item	2723994	et	4	main
element	doc_542009824802_item	2723995	et	3	main
probleem	doc_542009824802_item	2723996	et	3	main
tekkis	doc_542009824802_item	2723997	et	3	main
kuu	doc_542009824802_item	2723999	et	4	main
möödumisel	doc_542009824802_item	2724000	et	4	main
kahe	doc_542009824802_item	2723998	et	3	main
ostupäevast	doc_542009824802_item	2724001	et	4	main
probleemi	doc_542009824802_item	2724002	et	4	main
lahendamiseks	doc_542009824802_item	2724003	et	4	main
tagastasin	doc_542009824802_item	2724004	et	3	main
toote	doc_542009824802_item	2724005	et	4	main
kauplusesse	doc_542009824802_item	2724006	et	4	main
kauplus	doc_542009824802_item	2724007	et	3	main
võttis	doc_542009824802_item	2724008	et	3	main
kohvimasina	doc_542009824802_item	2724009	et	3	main
vastu	doc_542009824802_item	2724010	et	3	main
et	doc_542009824802_item	2724011	et	3	main
saata	doc_542009824802_item	2724012	et	3	main
see	doc_542009824802_item	2724013	et	3	main
tootjafirmale	doc_542009824802_item	2724014	et	3	main
remontimiseks	doc_542009824802_item	2724015	et	4	main
soovin	doc_542009824802_item	2724016	et	3	main
et	doc_542009824802_item	2724017	et	3	main
kaup	doc_542009824802_item	2724018	et	3	main
vahetatakse	doc_542009824802_item	2724019	et	3	main
uue	doc_542009824802_item	2724020	et	3	main
raha	doc_542009824802_item	2724024	et	4	main
22-23	doc_542009824802_item	2724028	et	2	main
või	doc_542009824802_item	2724022	et	4	main
kohtla-järve	doc_542009824802_item	2724031	et	4	main
031104	doc_542009824802_item	2724037	et	2	main
60-aastane	doc_542009824803_item	2724046	et	4	main
harjutusi	doc_542009824803_item	2724054	et	4	main
ülesandeid	doc_542009824803_item	2724057	et	3	main
lisatunnid	doc_542009824803_item	2724072	et	3	main
kus	doc_542009824803_item	2724073	et	3	main
me	doc_542009824803_item	2724074	et	4	main
õpetas	doc_542009824804_item	2724084	et	3	main
ta	doc_542009824804_item	2724091	et	4	main
riides	doc_542009824804_item	2724093	et	4	main
kontrolltöid	doc_542009824804_item	2724102	et	3	main
reegleid	doc_542009824804_item	2724104	et	3	main
õpetaja	doc_542009824804_item	2724107	et	4	main
tegeles	doc_542009824804_item	2724108	et	3	main
õpilastega	doc_542009824804_item	2724109	et	4	main
tunnivälisel	doc_542009824804_item	2724110	et	4	main
ajal	doc_542009824804_item	2724111	et	4	main
me	doc_542009824804_item	2724112	et	4	main
tema	doc_542009824804_item	2724114	et	4	main
käisime	doc_542009824804_item	2724113	et	3	main
pool	doc_542009824804_item	2724115	et	4	main
koduses	doc_542009824804_item	2724116	et	4	main
jalutasime	doc_542009824804_item	2724117	et	3	main
pargis	doc_542009824804_item	2724118	et	3	main
käisime	doc_542009824804_item	2724119	et	3	main
kontserditel	doc_542009824804_item	2724120	et	4	main
teatrites	doc_542009824804_item	2724121	et	3	main
seda	doc_542009824804_item	2724126	et	3	main
tal	doc_542009824804_item	2724135	et	3	main
külas	doc_542009824804_item	2724136	et	3	main
teed	doc_542009824804_item	2724138	et	4	main
sõime	doc_542009824804_item	2724140	et	4	main
millega	doc_542009824804_item	2724145	et	3	main
me	doc_542009824804_item	2724146	et	4	main
unistused	doc_542009824804_item	2724152	et	4	main
õpetaja	doc_542009824805_item	2724162	et	4	main
tuju	doc_542009824805_item	2724173	et	4	main
soengus	doc_542009824805_item	2724180	et	3	main
soovisime	doc_542009824805_item	2724220	et	3	main
000	doc_542009824802_item	2724030	et	2	main
88	doc_542009824802_item	2724034	et	2	main
essee	doc_542009824803_item	2724038	et	4	main
õpetas	doc_542009824803_item	2724041	et	3	main
käis	doc_542009824803_item	2724048	et	4	main
riides	doc_542009824803_item	2724049	et	4	main
hästi	doc_542009824803_item	2724050	et	3	main
tundides	doc_542009824803_item	2724051	et	3	main
tihti	doc_542009824803_item	2724060	et	3	main
tunde	doc_542009824803_item	2724063	et	4	main
me	doc_542009824803_item	2724065	et	4	main
tegelesime	doc_542009824803_item	2724066	et	3	main
matemaatika	doc_542009824803_item	2724067	et	4	main
olümpiaadile	doc_542009824803_item	2724068	et	3	main
ka	doc_542009824803_item	2724069	et	3	main
minu	doc_542009824804_item	2724078	et	3	main
lemmik	doc_542009824804_item	2724082	et	3	main
õpetaja	doc_542009824804_item	2724083	et	4	main
ta	doc_542009824804_item	2724086	et	4	main
oli	doc_542009824804_item	2724087	et	3	main
ümbes	doc_542009824804_item	2724088	et	4	main
teooriat	doc_542009824804_item	2724106	et	3	main
sõitsime	doc_542009824804_item	2724122	et	3	main
ma	doc_542009824804_item	2724124	et	3	main
õpetajat	doc_542009824804_item	2724127	et	4	main
õpilastega	doc_542009824804_item	2724133	et	4	main
nüüd	doc_542009824804_item	2724147	et	4	main
tegeleme	doc_542009824804_item	2724148	et	3	main
essee	doc_542009824805_item	2724156	et	4	main
iga	doc_542009824805_item	2724163	et	4	main
ta	doc_542009824805_item	2724166	et	4	main
naeratusega	doc_542009824805_item	2724168	et	4	main
ja	doc_542009824805_item	2724169	et	3	main
see	doc_542009824805_item	2724170	et	3	main
annab	doc_542009824805_item	2724171	et	3	main
hea	doc_542009824805_item	2724172	et	4	main
kostüümid	doc_542009824805_item	2724181	et	3	main
olid	doc_542009824805_item	2724182	et	4	main
puhtat	doc_542009824805_item	2724183	et	4	main
ta	doc_542009824805_item	2724184	et	4	main
armastas	doc_542009824805_item	2724185	et	3	main
pikki	doc_542009824805_item	2724186	et	4	main
seelikuid	doc_542009824805_item	2724187	et	3	main
ta	doc_542009824805_item	2724188	et	4	main
kandis	doc_542009824805_item	2724189	et	4	main
naljakat	doc_542009824805_item	2724190	et	3	main
kingi	doc_542009824805_item	2724191	et	4	main
tal	doc_542009824805_item	2724192	et	3	main
oli	doc_542009824805_item	2724193	et	3	main
alati	doc_542009824805_item	2724194	et	4	main
kaasas	doc_542009824805_item	2724195	et	4	main
suur	doc_542009824805_item	2724196	et	3	main
nahk	doc_542009824805_item	2724197	et	3	main
kott	doc_542009824805_item	2724198	et	3	main
tema	doc_542009824805_item	2724199	et	4	main
tunnis	doc_542009824805_item	2724200	et	3	main
oli	doc_542009824805_item	2724201	et	3	main
alati	doc_542009824805_item	2724202	et	4	main
huvitav	doc_542009824805_item	2724203	et	4	main
me	doc_542009824805_item	2724204	et	4	main
laulsime	doc_542009824805_item	2724205	et	3	main
tantsime	doc_542009824805_item	2724206	et	3	main
seal	doc_542009824805_item	2724207	et	4	main
tunnis	doc_542009824805_item	2724208	et	3	main
tema	doc_542009824805_item	2724209	et	4	main
andnud	doc_542009824805_item	2724212	et	4	main
heat	doc_542009824805_item	2724222	et	4	main
dokument	doc_542009824808_item	2724392	et	3	main
võib	doc_542009824808_item	2724394	et	3	main
viivitamatult	doc_542009824808_item	2724395	et	4	main
helistada	doc_542009824808_item	2724396	et	3	main
kui	doc_542009824808_item	2724397	et	3	main
rolitaga	doc_542009824808_item	2724423	et	4	main
3	doc_542009824808_item	2724435	et	2	main
ei	doc_542009824808_item	2724436	et	4	main
ole	doc_542009824808_item	2724437	et	4	main
ole	doc_542009824808_item	2724444	et	4	main
on	doc_542009824808_item	2724452	et	4	main
mahakukuda	doc_542009824808_item	2724461	et	4	main
1	doc_542009824809_item	2724463	et	2	main
valjä	doc_542009824809_item	2724498	et	4	main
jne	doc_542009824809_item	2724503	et	4	main
lasta	doc_542009824809_item	2724510	et	4	main
ei	doc_542009824809_item	2724513	et	4	main
võtta	doc_542009824809_item	2724519	et	3	main
kendi	doc_542009824808_item	2724422	et	4	main
lületatud	doc_542009824808_item	2724429	et	4	main
telefoni	doc_542009824808_item	2724446	et	4	main
5	doc_542009824808_item	2724450	et	2	main
kohas	doc_542009824808_item	2724456	et	4	main
viivitamatult	doc_542009824809_item	2724465	et	4	main
helistada	doc_542009824809_item	2724466	et	3	main
kui	doc_542009824809_item	2724467	et	3	main
mobiltelefon	doc_542009824809_item	2724495	et	4	main
lületatud	doc_542009824809_item	2724499	et	4	main
loengu	doc_542009824809_item	2724501	et	3	main
ei	doc_542009824809_item	2724506	et	4	main
4	doc_542009824809_item	2724512	et	2	main
telefon	doc_542009824809_item	2724524	et	3	main
oleks	doc_542009824809_item	2724525	et	3	main
ei	doc_542009824809_item	2724529	et	4	main
on	doc_542009824808_item	2724398	et	4	main
vaja	doc_542009824808_item	2724399	et	4	main
2	doc_542009824808_item	2724400	et	2	main
võib	doc_542009824808_item	2724401	et	3	main
saata	doc_542009824808_item	2724402	et	3	main
sõnumeid	doc_542009824808_item	2724403	et	3	main
3	doc_542009824808_item	2724404	et	2	main
saab	doc_542009824808_item	2724405	et	3	main
sajlitada	doc_542009824808_item	2724406	et	4	main
vajalikke	doc_542009824808_item	2724407	et	3	main
numbreid	doc_542009824808_item	2724408	et	3	main
4	doc_542009824808_item	2724409	et	2	main
voib	doc_542009824808_item	2724410	et	4	main
kasutada	doc_542009824808_item	2724411	et	3	main
5	doc_542009824808_item	2724413	et	2	main
saab	doc_542009824808_item	2724414	et	3	main
kasutada	doc_542009824808_item	2724415	et	3	main
iseteenindust	doc_542009824808_item	2724416	et	3	main
infomenüüd	doc_542009824808_item	2724412	et	4	main
internetis	doc_542009824808_item	2724417	et	4	main
1	doc_542009824808_item	2724418	et	2	main
ei	doc_542009824808_item	2724419	et	4	main
tohi	doc_542009824808_item	2724420	et	4	main
valjä	doc_542009824808_item	2724428	et	4	main
koolitunni	doc_542009824808_item	2724430	et	3	main
loengu	doc_542009824808_item	2724431	et	3	main
jne	doc_542009824808_item	2724433	et	4	main
võtta	doc_542009824808_item	2724449	et	3	main
sovitas	doc_542009824808_item	2724451	et	4	main
oleks	doc_542009824808_item	2724455	et	3	main
ta	doc_542009824808_item	2724458	et	4	main
ei	doc_542009824808_item	2724459	et	4	main
olema	doc_542009824809_item	2724497	et	4	main
ajal	doc_542009824809_item	2724504	et	4	main
ole	doc_542009824809_item	2724507	et	4	main
soovitav	doc_542009824809_item	2724508	et	4	main
vette	doc_542009824809_item	2724511	et	3	main
ole	doc_542009824809_item	2724514	et	4	main
saa	doc_542009824809_item	2724530	et	4	main
mahakukuda	doc_542009824809_item	2724531	et	4	main
uus	doc_542009824808_item	2724391	et	3	main
1	doc_542009824808_item	2724393	et	2	main
kasutada	doc_542009824808_item	2724421	et	3	main
2	doc_542009824808_item	2724424	et	2	main
mobiltelefon	doc_542009824808_item	2724425	et	4	main
peab	doc_542009824808_item	2724426	et	4	main
olema	doc_542009824808_item	2724427	et	4	main
koosoleku	doc_542009824808_item	2724432	et	3	main
ajal	doc_542009824808_item	2724434	et	4	main
soovitav	doc_542009824808_item	2724438	et	4	main
telefoni	doc_542009824808_item	2724439	et	4	main
lasta	doc_542009824808_item	2724440	et	4	main
vette	doc_542009824808_item	2724441	et	3	main
4	doc_542009824808_item	2724442	et	2	main
ei	doc_542009824808_item	2724443	et	4	main
iseseisvalt	doc_542009824808_item	2724447	et	4	main
saa	doc_542009824808_item	2724460	et	4	main
rolitaga	doc_542009824809_item	2724493	et	4	main
2	doc_542009824809_item	2724494	et	2	main
koolitunni	doc_542009824809_item	2724500	et	3	main
3	doc_542009824809_item	2724505	et	2	main
telefoni	doc_542009824809_item	2724509	et	4	main
iseseisvalt	doc_542009824809_item	2724517	et	4	main
lahti	doc_542009824809_item	2724518	et	4	main
5	doc_542009824809_item	2724520	et	2	main
kust	doc_542009824809_item	2724527	et	4	main
heaks	doc_542009824811_item	2724683	et	4	main
saada	doc_542009824811_item	2724685	et	4	main
head	doc_542009824811_item	2724687	et	4	main
lapsed	doc_542009824811_item	2724688	et	3	main
kasvatada	doc_542009824811_item	2724689	et	3	main
harjutus	doc_542009824812_item	2724690	et	4	main
kui	doc_542009824812_item	2724691	et	3	main
ma	doc_542009824812_item	2724692	et	3	main
kui	doc_542009824812_item	2724693	et	3	main
mina	doc_542009824812_item	2724694	et	4	main
olin	doc_542009824812_item	2724695	et	3	main
kui	doc_542009824813_item	2724717	et	3	main
kui	doc_542009824813_item	2724719	et	3	main
olin	doc_542009824813_item	2724721	et	3	main
unistasin	doc_542009824813_item	2724725	et	3	main
kuninganaks	doc_542009824813_item	2724729	et	3	main
maailma	doc_542009824813_item	2724742	et	4	main
teisi	doc_542009824813_item	2724745	et	4	main
kommetega	doc_542009824813_item	2724756	et	4	main
soovitav	doc_542009824808_item	2724445	et	4	main
lahti	doc_542009824808_item	2724448	et	4	main
et	doc_542009824808_item	2724453	et	3	main
telefon	doc_542009824808_item	2724454	et	3	main
kust	doc_542009824808_item	2724457	et	4	main
juhend	doc_542009824809_item	2724462	et	3	main
võib	doc_542009824809_item	2724464	et	3	main
on	doc_542009824809_item	2724468	et	4	main
vaja	doc_542009824809_item	2724469	et	4	main
2	doc_542009824809_item	2724470	et	2	main
võib	doc_542009824809_item	2724471	et	3	main
saata	doc_542009824809_item	2724472	et	3	main
sõnumeid	doc_542009824809_item	2724473	et	3	main
3	doc_542009824809_item	2724474	et	2	main
saab	doc_542009824809_item	2724475	et	3	main
sajlitada	doc_542009824809_item	2724476	et	4	main
vajalikke	doc_542009824809_item	2724477	et	3	main
numbreid	doc_542009824809_item	2724478	et	3	main
4	doc_542009824809_item	2724479	et	2	main
voib	doc_542009824809_item	2724480	et	4	main
kasutada	doc_542009824809_item	2724481	et	3	main
infomenüüd	doc_542009824809_item	2724482	et	4	main
5	doc_542009824809_item	2724483	et	2	main
saab	doc_542009824809_item	2724484	et	3	main
kasutada	doc_542009824809_item	2724485	et	3	main
iseteenindust	doc_542009824809_item	2724486	et	3	main
internetis	doc_542009824809_item	2724487	et	4	main
1	doc_542009824809_item	2724488	et	2	main
ei	doc_542009824809_item	2724489	et	4	main
tohi	doc_542009824809_item	2724490	et	4	main
kasutada	doc_542009824809_item	2724491	et	3	main
kendi	doc_542009824809_item	2724492	et	4	main
peab	doc_542009824809_item	2724496	et	4	main
koosoleku	doc_542009824809_item	2724502	et	3	main
soovitav	doc_542009824809_item	2724515	et	4	main
telefoni	doc_542009824809_item	2724516	et	4	main
sovitas	doc_542009824809_item	2724521	et	4	main
väike	doc_542009824812_item	2724696	et	4	main
saaks	doc_542009824812_item	2724699	et	3	main
kui	doc_542009824812_item	2724701	et	3	main
mina	doc_542009824812_item	2724702	et	4	main
olin	doc_542009824812_item	2724703	et	3	main
väike	doc_542009824812_item	2724704	et	4	main
ma	doc_542009824813_item	2724738	et	3	main
unistan	doc_542009824813_item	2724739	et	3	main
reisida	doc_542009824813_item	2724740	et	3	main
ümber	doc_542009824813_item	2724741	et	3	main
nende	doc_542009824813_item	2724753	et	4	main
traditsiooni	doc_542009824813_item	2724754	et	4	main
ja	doc_542009824813_item	2724755	et	3	main
ja	doc_542009824815_item	2724821	et	3	main
on	doc_542009824809_item	2724522	et	4	main
et	doc_542009824809_item	2724523	et	3	main
kohas	doc_542009824809_item	2724526	et	4	main
ta	doc_542009824809_item	2724528	et	4	main
harjutus	doc_542009824811_item	2724667	et	4	main
kui	doc_542009824811_item	2724668	et	3	main
ma	doc_542009824811_item	2724669	et	3	main
olin	doc_542009824811_item	2724670	et	3	main
väike	doc_542009824811_item	2724671	et	4	main
siis	doc_542009824811_item	2724672	et	3	main
ma	doc_542009824811_item	2724673	et	3	main
unistasin	doc_542009824811_item	2724674	et	3	main
arstiks	doc_542009824811_item	2724675	et	4	main
ja	doc_542009824811_item	2724677	et	3	main
saada	doc_542009824811_item	2724676	et	4	main
inimesi	doc_542009824811_item	2724678	et	4	main
tervida	doc_542009824811_item	2724679	et	4	main
nüüd	doc_542009824811_item	2724680	et	4	main
ma	doc_542009824811_item	2724681	et	3	main
unistan	doc_542009824811_item	2724682	et	3	main
spetsialiistiks	doc_542009824811_item	2724684	et	4	main
unistan	doc_542009824811_item	2724686	et	3	main
ma	doc_542009824812_item	2724697	et	3	main
näitlejaks	doc_542009824812_item	2724700	et	4	main
ma	doc_542009824812_item	2724709	et	3	main
unistasin	doc_542009824812_item	2724710	et	3	main
harjutus	doc_542009824813_item	2724716	et	4	main
ma	doc_542009824813_item	2724718	et	3	main
ma	doc_542009824813_item	2724720	et	3	main
siis	doc_542009824813_item	2724723	et	3	main
ja	doc_542009824813_item	2724726	et	3	main
ja	doc_542009824813_item	2724734	et	3	main
teiste	doc_542009824813_item	2724749	et	4	main
rahvustega	doc_542009824813_item	2724750	et	3	main
ja	doc_542009824813_item	2724751	et	3	main
tutvuda	doc_542009824813_item	2724752	et	3	main
selle	doc_542009824815_item	2724835	et	4	main
ma	doc_542009824815_item	2724836	et	3	main
kiri	doc_542576733648_item	2724840	et	3	main
pikkus	doc_542576733648_item	2724871	et	4	main
augustil	doc_542576733648_item	2724878	et	3	main
lagodas	doc_542576733648_item	2724892	et	4	main
umbes	doc_542576733648_item	2724904	et	4	main
me	doc_542576733648_item	2724912	et	4	main
vane	doc_542576733648_item	2724922	et	4	main
te	doc_542576733648_item	2724926	et	4	main
maksab	doc_542576733648_item	2724930	et	3	main
võtame	doc_542576733648_item	2724934	et	3	main
sa	doc_542576733648_item	2724939	et	3	main
helistage	doc_542576733648_item	2724943	et	3	main
nägemist	doc_542576733648_item	2724945	et	4	main
millal	doc_542576733649_item	2724959	et	3	main
te	doc_542576733649_item	2724962	et	4	main
millega	doc_542576733649_item	2724965	et	3	main
kui	doc_542576733649_item	2724969	et	3	main
sinu	doc_542576733649_item	2724990	et	3	main
sõidan	doc_542576733649_item	2725005	et	3	main
koos	doc_542576733649_item	2725006	et	4	main
abikaasaga	doc_542576733649_item	2725007	et	3	main
ja	doc_542576733649_item	2725008	et	3	main
me	doc_542576733649_item	2725010	et	4	main
maksab	doc_542576733649_item	2725022	et	3	main
ei	doc_542576733649_item	2725031	et	4	main
sõita	doc_542576733649_item	2725032	et	3	main
rongiga	doc_542576733649_item	2725033	et	4	main
elab	doc_542576733649_item	2725038	et	3	main
ta	doc_542576733649_item	2725040	et	4	main
korteris	doc_542576733649_item	2725047	et	3	main
koos	doc_542576733649_item	2725048	et	4	main
tahavad	doc_542576733649_item	2725051	et	3	main
meie	doc_542576733649_item	2725055	et	4	main
aed	doc_542576733649_item	2725064	et	3	main
teised	doc_542576733649_item	2725068	et	4	main
ma	doc_542576733649_item	2725070	et	3	main
kirjutan	doc_542576733649_item	2725071	et	3	main
palun	doc_542576733649_item	2725078	et	3	main
umbes	doc_542576733650_item	2725122	et	4	main
hästi	doc_542576733650_item	2725146	et	3	main
tööl	doc_542576733650_item	2725148	et	3	main
mul	doc_542576733650_item	2725150	et	3	main
hea	doc_542576733650_item	2725153	et	4	main
ma	doc_542576733650_item	2725154	et	3	main
sõidsime	doc_542576733650_item	2725155	et	4	main
peterburgi	doc_542576733650_item	2725176	et	4	main
palju	doc_542576733650_item	2725217	et	4	main
ma	doc_542009824812_item	2724705	et	3	main
unistasin	doc_542009824812_item	2724706	et	3	main
stalonest	doc_542009824812_item	2724707	et	4	main
ministrinaiseks	doc_542009824812_item	2724715	et	3	main
väike	doc_542009824813_item	2724722	et	4	main
ma	doc_542009824813_item	2724724	et	3	main
saada	doc_542009824813_item	2724728	et	4	main
ja	doc_542009824813_item	2724730	et	3	main
ilusas	doc_542009824813_item	2724732	et	3	main
ja	doc_542009824813_item	2724743	et	3	main
kühvlist	doc_542009824815_item	2724823	et	4	main
nüüd	doc_542009824815_item	2724829	et	4	main
unistan	doc_542009824815_item	2724831	et	3	main
te	doc_542576733648_item	2724841	et	4	main
reisi	doc_542576733648_item	2724843	et	4	main
kirjutage	doc_542576733648_item	2724845	et	3	main
ööbite	doc_542576733648_item	2724861	et	3	main
see	doc_542576733648_item	2724864	et	3	main
millistes	doc_542576733648_item	2724866	et	3	main
umbes	doc_542576733648_item	2724872	et	4	main
80	doc_542576733648_item	2724873	et	2	main
vana	doc_542576733648_item	2724891	et	4	main
iga	doc_542576733648_item	2724910	et	4	main
kreml	doc_542576733648_item	2724923	et	3	main
museumid	doc_542576733648_item	2724925	et	4	main
tuhad	doc_542576733648_item	2724936	et	3	main
meiega	doc_542576733648_item	2724942	et	4	main
kiri	doc_542576733649_item	2724947	et	3	main
reisi	doc_542576733649_item	2724950	et	4	main
kiri	doc_542576733649_item	2724954	et	3	main
kirjutage	doc_542576733649_item	2724958	et	3	main
ööbite	doc_542576733649_item	2724968	et	3	main
tahan	doc_542576733649_item	2724992	et	3	main
plaanid	doc_542576733649_item	2724996	et	4	main
suvel	doc_542576733649_item	2724998	et	3	main
ma	doc_542576733649_item	2724999	et	3	main
ostsime	doc_542576733649_item	2725011	et	3	main
üks	doc_542576733649_item	2725015	et	3	main
520	doc_542576733649_item	2725018	et	2	main
lapse	doc_542576733649_item	2725020	et	4	main
veel	doc_542576733649_item	2725030	et	4	main
vanem	doc_542576733649_item	2725036	et	4	main
kolmetoalises	doc_542576733649_item	2725046	et	4	main
tütre	doc_542576733649_item	2725056	et	3	main
botaaniline	doc_542576733649_item	2725063	et	3	main
ja	doc_542576733649_item	2725067	et	3	main
arno	doc_542576733649_item	2725069	et	4	main
sulle	doc_542576733649_item	2725072	et	3	main
pärast	doc_542576733649_item	2725073	et	4	main
jutustan	doc_542576733649_item	2725076	et	3	main
kirjuta	doc_542576733649_item	2725079	et	4	main
mulle	doc_542576733649_item	2725080	et	4	main
ka	doc_542576733649_item	2725081	et	3	main
pikkus	doc_542576733650_item	2725121	et	4	main
sõna	doc_542576733650_item	2725124	et	4	main
tere	doc_542576733650_item	2725125	et	3	main
kallis	doc_542576733650_item	2725126	et	4	main
nüüd	doc_542576733650_item	2725134	et	4	main
lõpuks	doc_542576733650_item	2725135	et	4	main
otsustasin	doc_542576733650_item	2725136	et	3	main
et	doc_542576733650_item	2725137	et	3	main
käib	doc_542576733650_item	2725143	et	3	main
peterburgi	doc_542576733650_item	2725157	et	4	main
ma	doc_542576733650_item	2725158	et	3	main
elasime	doc_542576733650_item	2725159	et	3	main
hotellis	doc_542576733650_item	2725160	et	3	main
ma	doc_542576733650_item	2725162	et	3	main
ilus	doc_542576733650_item	2725174	et	4	main
väga	doc_542576733650_item	2725214	et	3	main
asstorijal	doc_542576733650_item	2725216	et	4	main
elasime	doc_542576733650_item	2725220	et	3	main
hea	doc_542576733650_item	2725224	et	4	main
küll	doc_542576733650_item	2725225	et	4	main
sellega	doc_542576733650_item	2725226	et	3	main
tahtsin	doc_542009824812_item	2724698	et	3	main
nüüd	doc_542009824812_item	2724708	et	4	main
swartsnegerist	doc_542009824812_item	2724711	et	4	main
ma	doc_542009824812_item	2724712	et	3	main
tahan	doc_542009824812_item	2724713	et	3	main
saaks	doc_542009824812_item	2724714	et	3	main
tahtsin	doc_542009824813_item	2724727	et	3	main
elada	doc_542009824813_item	2724731	et	3	main
lossis	doc_542009824813_item	2724733	et	4	main
kõiki	doc_542009824813_item	2724735	et	4	main
käsutada	doc_542009824813_item	2724736	et	3	main
nüüd	doc_542009824813_item	2724737	et	4	main
vaadata	doc_542009824813_item	2724744	et	4	main
maid	doc_542009824813_item	2724746	et	4	main
ning	doc_542009824813_item	2724747	et	3	main
suhel	doc_542009824813_item	2724748	et	4	main
harjutus	doc_542009824815_item	2724809	et	4	main
kui	doc_542009824815_item	2724810	et	3	main
ma	doc_542009824815_item	2724811	et	3	main
kui	doc_542009824815_item	2724812	et	3	main
ma	doc_542009824815_item	2724813	et	3	main
olin	doc_542009824815_item	2724814	et	3	main
väike	doc_542009824815_item	2724815	et	4	main
siis	doc_542009824815_item	2724816	et	3	main
ma	doc_542009824815_item	2724817	et	3	main
unistasin	doc_542009824815_item	2724818	et	3	main
triibulist	doc_542009824815_item	2724819	et	4	main
pallist	doc_542009824815_item	2724820	et	4	main
ja	doc_542009824815_item	2724824	et	3	main
ma	doc_542009824815_item	2724826	et	3	main
saan	doc_542009824815_item	2724837	et	4	main
kus	doc_542576733648_item	2724860	et	3	main
kirja	doc_542576733648_item	2724869	et	4	main
nõutav	doc_542576733648_item	2724870	et	4	main
aime	doc_542576733648_item	2724877	et	4	main
me	doc_542576733648_item	2724879	et	4	main
planime	doc_542576733648_item	2724880	et	4	main
venemaale	doc_542576733648_item	2724882	et	4	main
abikaasaga	doc_542576733648_item	2724883	et	3	main
sõidame	doc_542576733648_item	2724885	et	3	main
tahame	doc_542576733648_item	2724888	et	3	main
vaatamisväärsusede	doc_542576733648_item	2724909	et	4	main
sugulasete	doc_542576733648_item	2724914	et	3	main
hotellis	doc_542576733648_item	2724917	et	3	main
tahksi	doc_542576733648_item	2724919	et	4	main
ma	doc_542576733648_item	2724920	et	3	main
neid	doc_542009824815_item	2724827	et	4	main
must	doc_542009824815_item	2724832	et	4	main
hummerist	doc_542009824815_item	2724833	et	4	main
ja	doc_542009824815_item	2724834	et	3	main
ka	doc_542009824815_item	2724838	et	3	main
venemaale	doc_542576733648_item	2724844	et	4	main
millal	doc_542576733648_item	2724852	et	3	main
ja	doc_542576733648_item	2724853	et	3	main
kuhu	doc_542576733648_item	2724854	et	3	main
te	doc_542576733648_item	2724855	et	4	main
sõita	doc_542576733648_item	2724856	et	3	main
soovite	doc_542576733648_item	2724857	et	3	main
millega	doc_542576733648_item	2724858	et	3	main
punasest	doc_542009824815_item	2724822	et	4	main
siis	doc_542009824815_item	2724825	et	3	main
sain	doc_542009824815_item	2724828	et	3	main
ma	doc_542009824815_item	2724830	et	3	main
kunagi	doc_542009824815_item	2724839	et	3	main
plaanite	doc_542576733648_item	2724842	et	3	main
sellest	doc_542576733648_item	2724846	et	4	main
kiri	doc_542576733648_item	2724847	et	3	main
oma	doc_542576733648_item	2724848	et	4	main
eestlasest	doc_542576733648_item	2724849	et	3	main
sõbrale	doc_542576733648_item	2724850	et	3	main
kirjutage	doc_542576733648_item	2724851	et	3	main
kui	doc_542576733648_item	2724862	et	3	main
maksab	doc_542576733648_item	2724865	et	3	main
peatute	doc_542576733648_item	2724868	et	4	main
reisi	doc_542576733648_item	2724881	et	4	main
me	doc_542576733648_item	2724884	et	4	main
ja	doc_542576733648_item	2724887	et	3	main
on	doc_542576733648_item	2724889	et	4	main
peterburis	doc_542576733648_item	2724890	et	4	main
moskvas	doc_542576733648_item	2724895	et	4	main
me	doc_542576733648_item	2724896	et	4	main
mõtleme	doc_542576733648_item	2724897	et	3	main
et	doc_542576733648_item	2724898	et	3	main
on	doc_542576733648_item	2724900	et	4	main
jätkub	doc_542576733648_item	2724903	et	3	main
3	doc_542576733648_item	2724905	et	2	main
nädalat	doc_542576733648_item	2724906	et	3	main
me	doc_542576733648_item	2724907	et	4	main
vaatame	doc_542576733648_item	2724908	et	3	main
oobime	doc_542576733648_item	2724913	et	4	main
väikes	doc_542576733648_item	2724916	et	4	main
novgorodis	doc_542576733648_item	2724918	et	4	main
reisite	doc_542576733648_item	2724859	et	3	main
palju	doc_542576733648_item	2724863	et	4	main
kohtades	doc_542576733648_item	2724867	et	3	main
sõna	doc_542576733648_item	2724874	et	4	main
tere	doc_542576733648_item	2724875	et	3	main
kallis	doc_542576733648_item	2724876	et	4	main
autoga	doc_542576733648_item	2724886	et	3	main
novgorodis	doc_542576733648_item	2724893	et	4	main
ja	doc_542576733648_item	2724894	et	3	main
reis	doc_542576733648_item	2724899	et	4	main
huvitav	doc_542576733648_item	2724901	et	4	main
ja	doc_542576733648_item	2724902	et	3	main
linna	doc_542576733648_item	2724911	et	4	main
või	doc_542576733648_item	2724915	et	4	main
küsite	doc_542576733648_item	2724927	et	3	main
palju	doc_542576733648_item	2724929	et	4	main
10	doc_542576733648_item	2724935	et	2	main
kas	doc_542576733648_item	2724938	et	3	main
sõitta	doc_542576733648_item	2724941	et	4	main
eesnimi	doc_542576733648_item	2724946	et	3	main
kirjutage	doc_542576733649_item	2724952	et	3	main
eestlasest	doc_542576733649_item	2724956	et	3	main
ja	doc_542576733649_item	2724960	et	3	main
reisite	doc_542576733649_item	2724966	et	3	main
sulle	doc_542576733649_item	2724994	et	3	main
esimesel	doc_542576733649_item	2725013	et	3	main
juulil	doc_542576733649_item	2725014	et	3	main
krooni	doc_542576733649_item	2725024	et	4	main
sõidame	doc_542576733649_item	2725026	et	3	main
vend	doc_542576733649_item	2725037	et	3	main
meid	doc_542576733649_item	2725042	et	4	main
meid	doc_542576733649_item	2725052	et	4	main
eriti	doc_542576733649_item	2725054	et	3	main
loomaaed	doc_542576733649_item	2725065	et	3	main
oma	doc_542576733649_item	2725082	et	4	main
anja	doc_542576733650_item	2725127	et	4	main
pole	doc_542576733650_item	2725128	et	3	main
ammu	doc_542576733650_item	2725131	et	4	main
kuidas	doc_542576733650_item	2725139	et	3	main
elad	doc_542576733650_item	2725145	et	3	main
sooviksin	doc_542576733650_item	2725163	et	3	main
me	doc_542576733650_item	2725179	et	4	main
jalutasime	doc_542576733650_item	2725180	et	3	main
korrusel	doc_542576733650_item	2725218	et	3	main
suudlen	doc_542576733650_item	2725231	et	3	main
me	doc_542576733650_item	2725235	et	4	main
juutustan	doc_542576733650_item	2725238	et	4	main
kiri	doc_542576733651_item	2725241	et	3	main
sõbrale	doc_542576733651_item	2725251	et	3	main
sõita	doc_542576733651_item	2725257	et	3	main
millega	doc_542576733651_item	2725259	et	3	main
pikkus	doc_542576733651_item	2725272	et	4	main
olen	doc_542576733651_item	2725284	et	3	main
käinud	doc_542576733651_item	2725285	et	4	main
bussiga	doc_542576733651_item	2725289	et	3	main
krooni	doc_542576733651_item	2725293	et	4	main
tädi	doc_542576733651_item	2725297	et	4	main
onu	doc_542576733651_item	2725299	et	4	main
elan	doc_542576733651_item	2725302	et	3	main
ja	doc_542576733651_item	2725322	et	3	main
kõige	doc_542576733651_item	2725337	et	4	main
kõik	doc_542576733651_item	2725348	et	4	main
varsti	doc_542576733651_item	2725351	et	3	main
te	doc_542576733652_item	2725371	et	4	main
sõita	doc_542576733652_item	2725372	et	3	main
soovite	doc_542576733652_item	2725373	et	3	main
millega	doc_542576733652_item	2725374	et	3	main
reisite	doc_542576733652_item	2725375	et	3	main
kus	doc_542576733652_item	2725376	et	3	main
mael	doc_542576733652_item	2725412	et	4	main
mul	doc_542576733652_item	2725413	et	3	main
oli	doc_542576733652_item	2725414	et	3	main
puhkus	doc_542576733652_item	2725415	et	3	main
ja	doc_542576733652_item	2725416	et	3	main
sõitsime	doc_542576733652_item	2725432	et	3	main
peatusime	doc_542576733652_item	2725435	et	4	main
valmistasime	doc_542576733652_item	2725438	et	3	main
jalutasime	doc_542576733652_item	2725441	et	3	main
elasime	doc_542576733652_item	2725452	et	3	main
kolmekohaline	doc_542576733652_item	2725453	et	4	main
tuppa	doc_542576733652_item	2725454	et	3	main
reisi	doc_542576733653_item	2725478	et	4	main
ja	doc_542576733648_item	2724924	et	3	main
kui	doc_542576733648_item	2724928	et	3	main
reiss	doc_542576733648_item	2724932	et	4	main
krooni	doc_542576733648_item	2724937	et	4	main
soovid	doc_542576733648_item	2724940	et	4	main
kiitesti	doc_542576733648_item	2724944	et	4	main
te	doc_542576733649_item	2724948	et	4	main
venemaale	doc_542576733649_item	2724951	et	4	main
oma	doc_542576733649_item	2724955	et	4	main
kuhu	doc_542576733649_item	2724961	et	3	main
kus	doc_542576733649_item	2724967	et	3	main
palju	doc_542576733649_item	2724970	et	4	main
see	doc_542576733649_item	2724971	et	3	main
maksab	doc_542576733649_item	2724972	et	3	main
millistes	doc_542576733649_item	2724973	et	3	main
kohtades	doc_542576733649_item	2724974	et	3	main
peatute	doc_542576733649_item	2724975	et	4	main
kirja	doc_542576733649_item	2724976	et	4	main
nõutav	doc_542576733649_item	2724977	et	4	main
pikkus	doc_542576733649_item	2724978	et	4	main
umbes	doc_542576733649_item	2724979	et	4	main
80	doc_542576733649_item	2724980	et	2	main
sõna	doc_542576733649_item	2724981	et	4	main
tere	doc_542576733649_item	2724982	et	3	main
kallis	doc_542576733649_item	2724983	et	4	main
arno	doc_542576733649_item	2724984	et	4	main
kuidas	doc_542576733649_item	2724985	et	3	main
sa	doc_542576733649_item	2724986	et	3	main
elad	doc_542576733649_item	2724987	et	3	main
kuidas	doc_542576733649_item	2724988	et	3	main
õppivad	doc_542576733649_item	2724989	et	4	main
näha	doc_542576733648_item	2724921	et	3	main
see	doc_542576733648_item	2724931	et	3	main
me	doc_542576733648_item	2724933	et	4	main
plaanite	doc_542576733649_item	2724949	et	3	main
sellest	doc_542576733649_item	2724953	et	4	main
sõbrale	doc_542576733649_item	2724957	et	3	main
sõita	doc_542576733649_item	2724963	et	3	main
soovite	doc_542576733649_item	2724964	et	3	main
kirjutada	doc_542576733649_item	2724993	et	3	main
oma	doc_542576733649_item	2724995	et	4	main
sellel	doc_542576733649_item	2724997	et	4	main
tahan	doc_542576733649_item	2725000	et	3	main
sõita	doc_542576733649_item	2725001	et	3	main
venemaale	doc_542576733649_item	2725002	et	4	main
tütrega	doc_542576733649_item	2725009	et	3	main
pilet	doc_542576733649_item	2725016	et	3	main
krooni	doc_542576733649_item	2725019	et	4	main
lapsed	doc_542576733649_item	2724991	et	3	main
peterburisse	doc_542576733649_item	2725003	et	4	main
ma	doc_542576733649_item	2725004	et	3	main
piletid	doc_542576733649_item	2725012	et	3	main
maksab	doc_542576733649_item	2725017	et	3	main
pilet	doc_542576733649_item	2725021	et	3	main
rongiga	doc_542576733649_item	2725027	et	4	main
meie	doc_542576733649_item	2725028	et	4	main
tütar	doc_542576733649_item	2725029	et	3	main
endale	doc_542576733649_item	2725043	et	4	main
ta	doc_542576733649_item	2725044	et	4	main
elab	doc_542576733649_item	2725045	et	3	main
näha	doc_542576733649_item	2725053	et	3	main
me	doc_542576733649_item	2725057	et	4	main
kõiged	doc_542576733649_item	2725060	et	4	main
vaatamisvärsusi	doc_542576733649_item	2725061	et	4	main
ja	doc_542576733649_item	2725075	et	3	main
suve	doc_542576733649_item	2725083	et	4	main
plaan	doc_542576733649_item	2725084	et	3	main
head	doc_542576733649_item	2725085	et	4	main
kirja	doc_542576733650_item	2725119	et	4	main
nõutav	doc_542576733650_item	2725120	et	4	main
250	doc_542576733649_item	2725023	et	2	main
me	doc_542576733649_item	2725025	et	4	main
minu	doc_542576733649_item	2725034	et	3	main
abikaasa	doc_542576733649_item	2725035	et	4	main
peterburis	doc_542576733649_item	2725039	et	4	main
kutsub	doc_542576733649_item	2725041	et	3	main
naisega	doc_542576733649_item	2725049	et	3	main
need	doc_542576733649_item	2725050	et	3	main
soovime	doc_542576733649_item	2725058	et	4	main
vaadata	doc_542576733649_item	2725059	et	4	main
näitek	doc_542576733649_item	2725062	et	4	main
petergof	doc_542576733649_item	2725066	et	4	main
reisi	doc_542576733649_item	2725074	et	4	main
kõikidest	doc_542576733649_item	2725077	et	4	main
aega	doc_542576733649_item	2725086	et	4	main
sinu	doc_542576733649_item	2725087	et	3	main
sõber	doc_542576733649_item	2725088	et	3	main
eesnimi	doc_542576733649_item	2725089	et	3	main
kiri	doc_542576733650_item	2725090	et	3	main
te	doc_542576733650_item	2725091	et	4	main
plaanite	doc_542576733650_item	2725092	et	3	main
reisi	doc_542576733650_item	2725093	et	4	main
venemaale	doc_542576733650_item	2725094	et	4	main
kirjutage	doc_542576733650_item	2725095	et	3	main
sellest	doc_542576733650_item	2725096	et	4	main
kiri	doc_542576733650_item	2725097	et	3	main
oma	doc_542576733650_item	2725098	et	4	main
eestlasest	doc_542576733650_item	2725099	et	3	main
sõbrale	doc_542576733650_item	2725100	et	3	main
kirjutage	doc_542576733650_item	2725101	et	3	main
millal	doc_542576733650_item	2725102	et	3	main
ja	doc_542576733650_item	2725103	et	3	main
kuhu	doc_542576733650_item	2725104	et	3	main
te	doc_542576733650_item	2725105	et	4	main
sõita	doc_542576733650_item	2725106	et	3	main
soovite	doc_542576733650_item	2725107	et	3	main
millega	doc_542576733650_item	2725108	et	3	main
reisite	doc_542576733650_item	2725109	et	3	main
kus	doc_542576733650_item	2725110	et	3	main
ööbite	doc_542576733650_item	2725111	et	3	main
kui	doc_542576733650_item	2725112	et	3	main
palju	doc_542576733650_item	2725113	et	4	main
see	doc_542576733650_item	2725114	et	3	main
maksab	doc_542576733650_item	2725115	et	3	main
millistes	doc_542576733650_item	2725116	et	3	main
kohtades	doc_542576733650_item	2725117	et	3	main
peatute	doc_542576733650_item	2725118	et	4	main
80	doc_542576733650_item	2725123	et	2	main
nii	doc_542576733650_item	2725130	et	3	main
kurjutanud	doc_542576733650_item	2725132	et	4	main
ning	doc_542576733650_item	2725133	et	3	main
sul	doc_542576733650_item	2725140	et	3	main
sankt	doc_542576733650_item	2725156	et	4	main
nädal	doc_542576733650_item	2725171	et	3	main
venemaal	doc_542576733650_item	2725172	et	4	main
väga	doc_542576733650_item	2725173	et	3	main
suvel	doc_542576733650_item	2725181	et	3	main
parkis	doc_542576733650_item	2725182	et	3	main
me	doc_542576733650_item	2725183	et	4	main
lapsega	doc_542576733650_item	2725184	et	3	main
käime	doc_542576733650_item	2725185	et	4	main
zoopark	doc_542576733650_item	2725186	et	3	main
ilm	doc_542576733650_item	2725187	et	3	main
oli	doc_542576733650_item	2725188	et	3	main
väga	doc_542576733650_item	2725189	et	3	main
hea	doc_542576733650_item	2725190	et	4	main
ilus	doc_542576733650_item	2725191	et	4	main
taevas	doc_542576733650_item	2725192	et	4	main
on	doc_542576733650_item	2725193	et	4	main
selge	doc_542576733650_item	2725194	et	4	main
pilvitu	doc_542576733650_item	2725195	et	4	main
päike	doc_542576733650_item	2725196	et	3	main
paistab	doc_542576733650_item	2725197	et	3	main
me	doc_542576733650_item	2725198	et	4	main
sõitsime	doc_542576733650_item	2725199	et	3	main
bussiga	doc_542576733650_item	2725200	et	3	main
rongiga	doc_542576733650_item	2725201	et	4	main
ja	doc_542576733650_item	2725202	et	3	main
trammiga	doc_542576733650_item	2725203	et	3	main
me	doc_542576733650_item	2725204	et	4	main
lemmikusse	doc_542576733650_item	2725205	et	4	main
kunst-kamerasse	doc_542576733650_item	2725206	et	4	main
tagasi	doc_542576733650_item	2725207	et	3	main
me	doc_542576733650_item	2725208	et	4	main
sõitsime	doc_542576733650_item	2725209	et	3	main
21	doc_542576733650_item	2725210	et	2	main
juulil	doc_542576733650_item	2725211	et	3	main
hotell	doc_542576733650_item	2725212	et	3	main
asstorija	doc_542576733650_item	2725213	et	4	main
sulle	doc_542576733650_item	2725129	et	3	main
kurjutan	doc_542576733650_item	2725138	et	4	main
ka	doc_542576733650_item	2725141	et	3	main
käsi	doc_542576733650_item	2725142	et	4	main
kas	doc_542576733650_item	2725144	et	3	main
kuidas	doc_542576733650_item	2725147	et	3	main
läheb	doc_542576733650_item	2725149	et	3	main
on	doc_542576733650_item	2725151	et	4	main
väga	doc_542576733650_item	2725152	et	3	main
asstorija	doc_542576733650_item	2725161	et	4	main
ühe	doc_542576733650_item	2725164	et	4	main
toa	doc_542576733650_item	2725165	et	3	main
reserveerida	doc_542576733650_item	2725166	et	3	main
me	doc_542576733650_item	2725167	et	4	main
elasime	doc_542576733650_item	2725168	et	3	main
hotellis	doc_542576733650_item	2725169	et	3	main
üks	doc_542576733650_item	2725170	et	3	main
sankt	doc_542576733650_item	2725175	et	4	main
palju	doc_542576733650_item	2725177	et	4	main
museumis	doc_542576733650_item	2725178	et	4	main
kolmekohaline	doc_542576733650_item	2725221	et	4	main
no	doc_542576733650_item	2725223	et	3	main
ootan	doc_542576733650_item	2725232	et	3	main
kui	doc_542576733650_item	2725234	et	3	main
kirjutage	doc_542576733651_item	2725246	et	3	main
kiri	doc_542576733651_item	2725248	et	3	main
millal	doc_542576733651_item	2725253	et	3	main
kus	doc_542576733651_item	2725261	et	3	main
see	doc_542576733651_item	2725265	et	3	main
kohtades	doc_542576733651_item	2725268	et	3	main
kaliningradis	doc_542576733651_item	2725286	et	4	main
pilet	doc_542576733651_item	2725290	et	3	main
kaliningradis	doc_542576733651_item	2725294	et	4	main
linn	doc_542576733651_item	2725324	et	3	main
mere	doc_542576733651_item	2725342	et	3	main
sõidan	doc_542576733651_item	2725344	et	3	main
nädala	doc_542576733651_item	2725346	et	3	main
palju	doc_542576733651_item	2725353	et	4	main
tervisi	doc_542576733651_item	2725354	et	3	main
eesnimi	doc_542576733651_item	2725355	et	3	main
kiri	doc_542576733652_item	2725356	et	3	main
te	doc_542576733652_item	2725357	et	4	main
venemaale	doc_542576733652_item	2725360	et	4	main
me	doc_542576733652_item	2725417	et	4	main
sõitsime	doc_542576733652_item	2725418	et	3	main
meie	doc_542576733652_item	2725419	et	4	main
perega	doc_542576733652_item	2725420	et	3	main
ilus	doc_542576733650_item	2725215	et	4	main
me	doc_542576733650_item	2725219	et	4	main
tuppa	doc_542576733650_item	2725222	et	3	main
tervitused	doc_542576733650_item	2725230	et	4	main
külla	doc_542576733650_item	2725233	et	4	main
ma	doc_542576733650_item	2725237	et	3	main
sulle	doc_542576733650_item	2725239	et	3	main
venemaale	doc_542576733651_item	2725245	et	4	main
eestlasest	doc_542576733651_item	2725250	et	3	main
nõutav	doc_542576733651_item	2725271	et	4	main
ma	doc_542576733651_item	2725287	et	3	main
sõidan	doc_542576733651_item	2725288	et	3	main
maksab	doc_542576733651_item	2725291	et	3	main
kõige	doc_542576733651_item	2725329	et	4	main
suurem	doc_542576733651_item	2725330	et	4	main
huvitavaid	doc_542576733651_item	2725338	et	4	main
teatrisse	doc_542576733651_item	2725339	et	3	main
kohvikus	doc_542576733651_item	2725340	et	3	main
balti	doc_542576733651_item	2725341	et	3	main
rõõmsad	doc_542576733651_item	2725349	et	3	main
reisi	doc_542576733652_item	2725359	et	4	main
kirjutage	doc_542576733652_item	2725361	et	3	main
kui	doc_542576733652_item	2725378	et	3	main
uudis	doc_542576733652_item	2725411	et	3	main
venemaale	doc_542576733652_item	2725421	et	4	main
sõitsime	doc_542576733652_item	2725423	et	3	main
autoga	doc_542576733652_item	2725424	et	3	main
väga	doc_542576733652_item	2725427	et	3	main
vaatasime	doc_542576733652_item	2725442	et	3	main
moskva	doc_542576733652_item	2725451	et	4	main
külla	doc_542576733652_item	2725471	et	4	main
kohtumiseni	doc_542576733652_item	2725472	et	4	main
130605	doc_542576733652_item	2725474	et	2	main
kiri	doc_542576733653_item	2725475	et	3	main
te	doc_542576733653_item	2725476	et	4	main
venemaale	doc_542576733653_item	2725479	et	4	main
sellest	doc_542576733653_item	2725481	et	4	main
kiri	doc_542576733653_item	2725482	et	3	main
oma	doc_542576733653_item	2725483	et	4	main
eestlasest	doc_542576733653_item	2725484	et	3	main
sõbrale	doc_542576733653_item	2725485	et	3	main
kirja	doc_542576733653_item	2725504	et	4	main
autoga	doc_542576733653_item	2725515	et	3	main
tulin	doc_542576733653_item	2725518	et	3	main
peterburgi	doc_542576733653_item	2725520	et	4	main
kõigile	doc_542576733650_item	2725229	et	4	main
oma	doc_542576733651_item	2725249	et	4	main
kuhu	doc_542576733651_item	2725255	et	3	main
soovite	doc_542576733651_item	2725258	et	3	main
reisite	doc_542576733651_item	2725260	et	3	main
ööbite	doc_542576733651_item	2725262	et	3	main
palju	doc_542576733651_item	2725264	et	4	main
maksab	doc_542576733651_item	2725266	et	3	main
millistes	doc_542576733651_item	2725267	et	3	main
umbes	doc_542576733651_item	2725273	et	4	main
80	doc_542576733651_item	2725274	et	2	main
sõna	doc_542576733651_item	2725275	et	4	main
tere	doc_542576733651_item	2725276	et	3	main
minu	doc_542576733651_item	2725296	et	3	main
ja	doc_542576733651_item	2725298	et	3	main
ma	doc_542576733651_item	2725301	et	3	main
külalis	doc_542576733651_item	2725303	et	4	main
nad	doc_542576733651_item	2725304	et	3	main
elavad	doc_542576733651_item	2725305	et	4	main
üheksakorruselis	doc_542576733651_item	2725306	et	4	main
keskküttega	doc_542576733651_item	2725307	et	3	main
kivimajas	doc_542576733651_item	2725308	et	4	main
viiendal	doc_542576733651_item	2725309	et	3	main
korrusel	doc_542576733651_item	2725310	et	3	main
nad	doc_542576733651_item	2725311	et	3	main
elavad	doc_542576733651_item	2725312	et	4	main
kahetoalises	doc_542576733651_item	2725313	et	4	main
korteris	doc_542576733651_item	2725314	et	3	main
minu	doc_542576733651_item	2725315	et	3	main
tädi	doc_542576733651_item	2725316	et	4	main
on	doc_542576733651_item	2725317	et	4	main
pensionäär	doc_542576733651_item	2725318	et	4	main
kaliningrad	doc_542576733651_item	2725319	et	4	main
on	doc_542576733651_item	2725320	et	4	main
suur	doc_542576733651_item	2725321	et	3	main
ilus	doc_542576733651_item	2725323	et	4	main
see	doc_542576733651_item	2725325	et	3	main
olnud	doc_542576733651_item	2725327	et	4	main
siiani	doc_542576733651_item	2725328	et	4	main
see	doc_542576733651_item	2725335	et	3	main
on	doc_542576733651_item	2725336	et	4	main
puhkas	doc_542576733651_item	2725347	et	3	main
kõigele	doc_542576733651_item	2725352	et	4	main
plaanite	doc_542576733652_item	2725358	et	3	main
sellest	doc_542576733652_item	2725362	et	4	main
kiri	doc_542576733652_item	2725363	et	3	main
oma	doc_542576733652_item	2725364	et	4	main
eestlasest	doc_542576733652_item	2725365	et	3	main
sõbrale	doc_542576733652_item	2725366	et	3	main
kirjutage	doc_542576733652_item	2725367	et	3	main
millal	doc_542576733652_item	2725368	et	3	main
ja	doc_542576733652_item	2725369	et	3	main
kuhu	doc_542576733652_item	2725370	et	3	main
ööbite	doc_542576733652_item	2725377	et	3	main
me	doc_542576733652_item	2725422	et	4	main
ilm	doc_542576733652_item	2725425	et	3	main
soe	doc_542576733652_item	2725428	et	4	main
ja	doc_542576733652_item	2725429	et	3	main
paikepaisteline	doc_542576733652_item	2725430	et	4	main
kämpingus	doc_542576733652_item	2725436	et	3	main
palju	doc_542576733652_item	2725440	et	4	main
vaatamiseväärsused	doc_542576733652_item	2725443	et	4	main
sõitsime	doc_542576733652_item	2725445	et	3	main
ma	doc_542576733650_item	2725227	et	3	main
lõpetan	doc_542576733650_item	2725228	et	3	main
kohtume	doc_542576733650_item	2725236	et	3	main
eesnimi	doc_542576733650_item	2725240	et	3	main
te	doc_542576733651_item	2725242	et	4	main
plaanite	doc_542576733651_item	2725243	et	3	main
reisi	doc_542576733651_item	2725244	et	4	main
sellest	doc_542576733651_item	2725247	et	4	main
kirjutage	doc_542576733651_item	2725252	et	3	main
ja	doc_542576733651_item	2725254	et	3	main
te	doc_542576733651_item	2725256	et	4	main
kui	doc_542576733651_item	2725263	et	3	main
peatute	doc_542576733651_item	2725269	et	4	main
kirja	doc_542576733651_item	2725270	et	4	main
kallis	doc_542576733651_item	2725277	et	4	main
irina	doc_542576733651_item	2725278	et	3	main
juulis	doc_542576733651_item	2725279	et	3	main
ma	doc_542576733651_item	2725280	et	3	main
sõidan	doc_542576733651_item	2725281	et	3	main
venemaale	doc_542576733651_item	2725282	et	4	main
ma	doc_542576733651_item	2725283	et	3	main
300	doc_542576733651_item	2725292	et	2	main
elab	doc_542576733651_item	2725295	et	3	main
poeg	doc_542576733651_item	2725300	et	3	main
on	doc_542576733651_item	2725326	et	4	main
elamus	doc_542576733651_item	2725331	et	4	main
kaliningradis	doc_542576733651_item	2725332	et	4	main
meri	doc_542576733651_item	2725333	et	3	main
linn	doc_542576733651_item	2725334	et	3	main
mina	doc_542576733651_item	2725343	et	4	main
2	doc_542576733651_item	2725345	et	2	main
kohtume	doc_542576733651_item	2725350	et	3	main
palju	doc_542576733652_item	2725379	et	4	main
see	doc_542576733652_item	2725380	et	3	main
maksab	doc_542576733652_item	2725381	et	3	main
millistes	doc_542576733652_item	2725382	et	3	main
kohtades	doc_542576733652_item	2725383	et	3	main
peatute	doc_542576733652_item	2725384	et	4	main
kirja	doc_542576733652_item	2725385	et	4	main
nõutav	doc_542576733652_item	2725386	et	4	main
pikkus	doc_542576733652_item	2725387	et	4	main
umbes	doc_542576733652_item	2725388	et	4	main
80	doc_542576733652_item	2725389	et	2	main
sõna	doc_542576733652_item	2725390	et	4	main
tere	doc_542576733652_item	2725391	et	3	main
kallis	doc_542576733652_item	2725392	et	4	main
sõber	doc_542576733652_item	2725393	et	3	main
tina	doc_542576733652_item	2725394	et	4	main
sain	doc_542576733652_item	2725395	et	3	main
täna	doc_542576733652_item	2725396	et	4	main
sinu	doc_542576733652_item	2725397	et	3	main
kirja	doc_542576733652_item	2725398	et	4	main
suur	doc_542576733652_item	2725399	et	3	main
aitäh	doc_542576733652_item	2725400	et	3	main
kirja	doc_542576733652_item	2725401	et	4	main
tahan	doc_542576733652_item	2725403	et	3	main
sulle	doc_542576733652_item	2725404	et	3	main
kohe	doc_542576733652_item	2725405	et	4	main
eest	doc_542576733652_item	2725402	et	4	main
vastata	doc_542576733652_item	2725406	et	4	main
sest	doc_542576733652_item	2725407	et	4	main
mul	doc_542576733652_item	2725408	et	3	main
on	doc_542576733652_item	2725409	et	4	main
sulle	doc_542576733652_item	2725410	et	3	main
oli	doc_542576733652_item	2725426	et	3	main
me	doc_542576733652_item	2725434	et	4	main
seal	doc_542576733652_item	2725437	et	4	main
me	doc_542576733652_item	2725444	et	4	main
tuba	doc_542576733652_item	2725455	et	4	main
maksab	doc_542576733652_item	2725456	et	3	main
1000	doc_542576733652_item	2725457	et	2	main
rubla	doc_542576733652_item	2725458	et	4	main
öö	doc_542576733652_item	2725459	et	4	main
me	doc_542576733652_item	2725460	et	4	main
vaatasime	doc_542576733652_item	2725461	et	3	main
vaatamisväärsused	doc_542576733652_item	2725462	et	4	main
kui	doc_542576733652_item	2725463	et	3	main
me	doc_542576733652_item	2725464	et	4	main
kohtume	doc_542576733652_item	2725465	et	3	main
ma	doc_542576733652_item	2725466	et	3	main
me	doc_542576733652_item	2725431	et	4	main
moskvasse	doc_542576733652_item	2725433	et	4	main
sööki	doc_542576733652_item	2725439	et	4	main
moskvasse	doc_542576733652_item	2725446	et	4	main
mael	doc_542576733652_item	2725448	et	4	main
peatusime	doc_542576733652_item	2725449	et	4	main
hotellis	doc_542576733652_item	2725450	et	3	main
eesnimi	doc_542576733652_item	2725473	et	3	main
reisite	doc_542576733653_item	2725494	et	3	main
palju	doc_542576733653_item	2725498	et	4	main
nõutav	doc_542576733653_item	2725505	et	4	main
pikkus	doc_542576733653_item	2725506	et	4	main
vannituba	doc_542576733653_item	2725531	et	4	main
ma	doc_542576733653_item	2725532	et	3	main
otsustasin	doc_542576733653_item	2725533	et	3	main
et	doc_542576733653_item	2725534	et	3	main
öeldi	doc_542576733653_item	2725540	et	3	main
hotellis	doc_542576733653_item	2725544	et	3	main
dušš	doc_542576733653_item	2725578	et	2	main
sain	doc_542576733653_item	2725580	et	3	main
olemas	doc_542576733653_item	2725585	et	4	main
venemaale	doc_542576733654_item	2725616	et	4	main
kirjutage	doc_542576733654_item	2725617	et	3	main
oma	doc_542576733654_item	2725620	et	4	main
kirjutage	doc_542576733654_item	2725623	et	3	main
sõita	doc_542576733654_item	2725628	et	3	main
reisite	doc_542576733654_item	2725631	et	3	main
palju	doc_542576733654_item	2725635	et	4	main
kohtades	doc_542576733654_item	2725639	et	3	main
umbes	doc_542576733654_item	2725644	et	4	main
sulle	doc_542576733654_item	2725651	et	3	main
juunil	doc_542576733654_item	2725661	et	3	main
on	doc_542576733654_item	2725663	et	4	main
me	doc_542576733654_item	2725671	et	4	main
tutrega	doc_542576733654_item	2725673	et	4	main
ääres	doc_542576733654_item	2725677	et	4	main
me	doc_542576733654_item	2725680	et	4	main
sõbrale	doc_542576733655_item	2725722	et	3	main
millal	doc_542576733655_item	2725724	et	3	main
sõita	doc_542576733655_item	2725728	et	3	main
kus	doc_542576733655_item	2725732	et	3	main
kui	doc_542576733655_item	2725734	et	3	main
kohtades	doc_542576733655_item	2725739	et	3	main
umbes	doc_542576733655_item	2725744	et	4	main
80	doc_542576733655_item	2725745	et	2	main
sulle	doc_542576733655_item	2725750	et	3	main
reisi	doc_542576733655_item	2725769	et	4	main
kuus	doc_542576733655_item	2725774	et	4	main
28	doc_542576733655_item	2725775	et	2	main
kuupäeval	doc_542576733655_item	2725776	et	3	main
eek	doc_542576733655_item	2725785	et	4	main
150	doc_542576733655_item	2725789	et	2	main
me	doc_542576733655_item	2725796	et	4	main
planeerime	doc_542576733655_item	2725797	et	3	main
peatuda	doc_542576733655_item	2725798	et	3	main
sugulasel	doc_542576733655_item	2725799	et	3	main
21	doc_542576733652_item	2725447	et	2	main
juutustan	doc_542576733652_item	2725467	et	4	main
sulle	doc_542576733652_item	2725468	et	3	main
ootan	doc_542576733652_item	2725469	et	3	main
plaanite	doc_542576733653_item	2725477	et	3	main
ööbite	doc_542576733653_item	2725496	et	3	main
maksab	doc_542576733653_item	2725500	et	3	main
kohtades	doc_542576733653_item	2725502	et	3	main
sõitsime	doc_542576733653_item	2725514	et	3	main
mina	doc_542576733653_item	2725517	et	4	main
jään	doc_542576733653_item	2725535	et	3	main
siia	doc_542576733653_item	2725536	et	4	main
et	doc_542576733653_item	2725541	et	3	main
ka	doc_542576733653_item	2725577	et	3	main
mina	doc_542576733653_item	2725579	et	4	main
et	doc_542576733653_item	2725598	et	3	main
piljard	doc_542576733653_item	2725601	et	3	main
ja	doc_542576733653_item	2725603	et	3	main
need	doc_542576733653_item	2725605	et	3	main
minule	doc_542576733653_item	2725608	et	3	main
sinu	doc_542576733653_item	2725610	et	3	main
eesnimi	doc_542576733653_item	2725611	et	3	main
kiri	doc_542576733654_item	2725612	et	3	main
te	doc_542576733654_item	2725613	et	4	main
kiri	doc_542576733654_item	2725619	et	3	main
kuhu	doc_542576733654_item	2725626	et	3	main
ööbite	doc_542576733654_item	2725633	et	3	main
pikkus	doc_542576733654_item	2725643	et	4	main
hea	doc_542576733654_item	2725656	et	4	main
siin	doc_542576733654_item	2725662	et	4	main
palju	doc_542576733654_item	2725665	et	4	main
ilusad	doc_542576733654_item	2725676	et	3	main
palju	doc_542576733654_item	2725678	et	4	main
museumis	doc_542576733654_item	2725679	et	4	main
otsustasime	doc_542576733654_item	2725687	et	3	main
eestlasest	doc_542576733655_item	2725721	et	3	main
kirjutage	doc_542576733655_item	2725723	et	3	main
kuhu	doc_542576733655_item	2725726	et	3	main
millega	doc_542576733655_item	2725730	et	3	main
see	doc_542576733655_item	2725736	et	3	main
kirja	doc_542576733655_item	2725741	et	4	main
sinu	doc_542576733655_item	2725751	et	3	main
sõbranna	doc_542576733655_item	2725752	et	4	main
k	doc_542576733655_item	2725754	et	4	main
venemaale	doc_542576733655_item	2725770	et	4	main
ma	doc_542576733655_item	2725771	et	3	main
sõidan	doc_542576733655_item	2725772	et	3	main
sellel	doc_542576733655_item	2725773	et	4	main
ma	doc_542576733655_item	2725777	et	3	main
lapse	doc_542576733655_item	2725786	et	4	main
eek	doc_542576733655_item	2725790	et	4	main
otsime	doc_542576733655_item	2725792	et	4	main
piletid	doc_542576733655_item	2725793	et	3	main
juba	doc_542576733655_item	2725794	et	3	main
kevadel	doc_542576733655_item	2725795	et	4	main
seal	doc_542576733655_item	2725801	et	4	main
elavad	doc_542576733655_item	2725802	et	4	main
ja	doc_542576733655_item	2725805	et	3	main
külla	doc_542576733655_item	2725809	et	4	main
peterburgi	doc_542576733655_item	2725810	et	4	main
suured	doc_542576733655_item	2725818	et	3	main
eritti	doc_542576733655_item	2725820	et	4	main
me	doc_542576733655_item	2725821	et	4	main
külla	doc_542576733655_item	2725823	et	4	main
sind	doc_542576733655_item	2725836	et	4	main
kiri	doc_542576733656_item	2725840	et	3	main
kirjutage	doc_542576733656_item	2725845	et	3	main
eestlasest	doc_542576733656_item	2725849	et	3	main
te	doc_542576733656_item	2725855	et	4	main
sõita	doc_542576733656_item	2725856	et	3	main
soovite	doc_542576733656_item	2725857	et	3	main
millega	doc_542576733656_item	2725858	et	3	main
reisite	doc_542576733656_item	2725859	et	3	main
kus	doc_542576733656_item	2725860	et	3	main
kohtades	doc_542576733656_item	2725867	et	3	main
sõna	doc_542576733656_item	2725874	et	4	main
tere	doc_542576733656_item	2725875	et	3	main
regina	doc_542576733656_item	2725876	et	4	main
kirjutab	doc_542576733656_item	2725877	et	3	main
sulle	doc_542576733656_item	2725878	et	3	main
eesnimi	doc_542576733656_item	2725879	et	3	main
venemaale	doc_542576733656_item	2725886	et	4	main
sind	doc_542576733652_item	2725470	et	4	main
kirjutage	doc_542576733653_item	2725486	et	3	main
millal	doc_542576733653_item	2725487	et	3	main
ja	doc_542576733653_item	2725488	et	3	main
kuhu	doc_542576733653_item	2725489	et	3	main
te	doc_542576733653_item	2725490	et	4	main
sõita	doc_542576733653_item	2725491	et	3	main
soovite	doc_542576733653_item	2725492	et	3	main
millega	doc_542576733653_item	2725493	et	3	main
kus	doc_542576733653_item	2725495	et	3	main
see	doc_542576733653_item	2725499	et	3	main
millistes	doc_542576733653_item	2725501	et	3	main
peatute	doc_542576733653_item	2725503	et	4	main
venemaale	doc_542576733653_item	2725516	et	4	main
puhata	doc_542576733653_item	2725519	et	4	main
sain	doc_542576733653_item	2725522	et	3	main
ühest	doc_542576733653_item	2725524	et	4	main
ka	doc_542576733653_item	2725529	et	3	main
eraldi	doc_542576733653_item	2725530	et	4	main
päevaks	doc_542576733653_item	2725538	et	3	main
maksab	doc_542576733653_item	2725545	et	3	main
kuussada	doc_542576733653_item	2725546	et	4	main
mina	doc_542576733653_item	2725548	et	4	main
sain	doc_542576733653_item	2725549	et	3	main
administraatorilt	doc_542576733653_item	2725550	et	3	main
et	doc_542576733653_item	2725582	et	3	main
hotellis	doc_542576733653_item	2725599	et	3	main
olid	doc_542576733653_item	2725607	et	4	main
unustamatud	doc_542576733653_item	2725609	et	4	main
plaanite	doc_542576733654_item	2725614	et	3	main
reisi	doc_542576733654_item	2725615	et	4	main
te	doc_542576733654_item	2725627	et	4	main
maksab	doc_542576733654_item	2725637	et	3	main
peatute	doc_542576733654_item	2725640	et	4	main
sõna	doc_542576733654_item	2725646	et	4	main
niina	doc_542576733654_item	2725649	et	4	main
petseri	doc_542576733654_item	2725652	et	4	main
mul	doc_542576733654_item	2725653	et	3	main
on	doc_542576733654_item	2725654	et	4	main
väga	doc_542576733654_item	2725655	et	3	main
kohti	doc_542576733654_item	2725667	et	4	main
metsa	doc_542576733654_item	2725668	et	4	main
ja	doc_542576733654_item	2725669	et	3	main
siis	doc_542576733654_item	2725674	et	3	main
suvel	doc_542576733654_item	2725682	et	3	main
me	doc_542576733654_item	2725686	et	4	main
kirjutage	doc_542576733653_item	2725480	et	3	main
kui	doc_542576733653_item	2725497	et	3	main
umbes	doc_542576733653_item	2725507	et	4	main
80	doc_542576733653_item	2725508	et	2	main
sõna	doc_542576733653_item	2725509	et	4	main
tere	doc_542576733653_item	2725510	et	3	main
kallis	doc_542576733653_item	2725511	et	4	main
anna	doc_542576733653_item	2725512	et	4	main
mina	doc_542576733653_item	2725513	et	4	main
ja	doc_542576733653_item	2725521	et	3	main
endale	doc_542576733653_item	2725523	et	4	main
toa	doc_542576733653_item	2725525	et	3	main
minu	doc_542576733653_item	2725526	et	3	main
toas	doc_542576733653_item	2725527	et	3	main
oli	doc_542576733653_item	2725528	et	3	main
kolmeks	doc_542576733653_item	2725537	et	4	main
öö	doc_542576733653_item	2725543	et	4	main
rubla	doc_542576733653_item	2725547	et	4	main
võtme	doc_542576733653_item	2725551	et	3	main
võtsin	doc_542576733653_item	2725552	et	3	main
kohvrid	doc_542576733653_item	2725553	et	3	main
ja	doc_542576733653_item	2725554	et	3	main
astusin	doc_542576733653_item	2725555	et	3	main
lifti	doc_542576733653_item	2725556	et	4	main
minu	doc_542576733653_item	2725557	et	3	main
all	doc_542576733653_item	2725583	et	3	main
on	doc_542576733653_item	2725600	et	4	main
ilusalong	doc_542576733653_item	2725602	et	3	main
solarium	doc_542576733653_item	2725604	et	4	main
päevad	doc_542576733653_item	2725606	et	3	main
sellest	doc_542576733654_item	2725618	et	4	main
eestlasest	doc_542576733654_item	2725621	et	3	main
millal	doc_542576733654_item	2725624	et	3	main
ja	doc_542576733654_item	2725625	et	3	main
soovite	doc_542576733654_item	2725629	et	3	main
kui	doc_542576733654_item	2725634	et	3	main
millistes	doc_542576733654_item	2725638	et	3	main
80	doc_542576733654_item	2725645	et	2	main
kallis	doc_542576733654_item	2725648	et	4	main
kirjutan	doc_542576733654_item	2725650	et	3	main
sõitsime	doc_542576733654_item	2725659	et	3	main
pangi	doc_542576733654_item	2725670	et	4	main
jalutasime	doc_542576733654_item	2725681	et	3	main
järgmisel	doc_542576733654_item	2725684	et	3	main
nõutav	doc_542576733655_item	2725742	et	4	main
sõbranna	doc_542576733655_item	2725748	et	4	main
sellepärast	doc_542576733655_item	2725766	et	3	main
maksab	doc_542576733655_item	2725788	et	3	main
me	doc_542576733655_item	2725791	et	4	main
onu	doc_542576733655_item	2725806	et	4	main
teatridesse	doc_542576733655_item	2725814	et	4	main
diskosse	doc_542576733655_item	2725816	et	4	main
kauplusse	doc_542576733655_item	2725819	et	3	main
muuseumid	doc_542576733655_item	2725824	et	3	main
lõpetan	doc_542576733655_item	2725826	et	3	main
selle	doc_542576733655_item	2725827	et	4	main
kirja	doc_542576733655_item	2725828	et	4	main
reisi	doc_542576733656_item	2725843	et	4	main
kui	doc_542576733656_item	2725862	et	3	main
millistes	doc_542576733656_item	2725866	et	3	main
sõita	doc_542576733656_item	2725882	et	3	main
kuhu	doc_542576733656_item	2725887	et	3	main
ei	doc_542576733656_item	2725889	et	4	main
aga	doc_542576733656_item	2725891	et	3	main
on	doc_542576733656_item	2725897	et	4	main
sõidu	doc_542576733656_item	2725898	et	3	main
elmisel	doc_542576733656_item	2725906	et	4	main
suvel	doc_542576733656_item	2725908	et	3	main
mulle	doc_542576733656_item	2725916	et	4	main
väga	doc_542576733656_item	2725917	et	3	main
mulle	doc_542576733653_item	2725539	et	4	main
üks	doc_542576733653_item	2725542	et	3	main
tuba	doc_542576733653_item	2725558	et	4	main
asus	doc_542576733653_item	2725559	et	4	main
kuuendal	doc_542576733653_item	2725560	et	3	main
korrusel	doc_542576733653_item	2725561	et	3	main
ma	doc_542576733653_item	2725562	et	3	main
keerasin	doc_542576733653_item	2725563	et	3	main
ukse	doc_542576733653_item	2725564	et	3	main
lahti	doc_542576733653_item	2725565	et	4	main
ja	doc_542576733653_item	2725566	et	3	main
panin	doc_542576733653_item	2725567	et	3	main
tule	doc_542576733653_item	2725568	et	4	main
põlema	doc_542576733653_item	2725569	et	4	main
mulle	doc_542576733653_item	2725570	et	4	main
väga	doc_542576733653_item	2725571	et	3	main
meeldis	doc_542576733653_item	2725572	et	3	main
minu	doc_542576733653_item	2725573	et	3	main
tuba	doc_542576733653_item	2725574	et	4	main
vannitoas	doc_542576733653_item	2725575	et	3	main
oli	doc_542576733653_item	2725576	et	3	main
teada	doc_542576733653_item	2725581	et	3	main
on	doc_542576733653_item	2725584	et	4	main
söökla	doc_542576733653_item	2725586	et	4	main
ja	doc_542576733653_item	2725587	et	3	main
restoran	doc_542576733653_item	2725588	et	3	main
õhtuti	doc_542576733653_item	2725589	et	3	main
töötas	doc_542576733653_item	2725590	et	3	main
ka	doc_542576733653_item	2725591	et	3	main
baar	doc_542576733653_item	2725592	et	3	main
hiljem	doc_542576733653_item	2725593	et	3	main
ma	doc_542576733653_item	2725594	et	3	main
sain	doc_542576733653_item	2725595	et	3	main
teada	doc_542576733653_item	2725596	et	3	main
veel	doc_542576733653_item	2725597	et	4	main
sõbrale	doc_542576733654_item	2725622	et	3	main
millega	doc_542576733654_item	2725630	et	3	main
kus	doc_542576733654_item	2725632	et	3	main
see	doc_542576733654_item	2725636	et	3	main
kirja	doc_542576733654_item	2725641	et	4	main
nõutav	doc_542576733654_item	2725642	et	4	main
tere	doc_542576733654_item	2725647	et	3	main
meel	doc_542576733654_item	2725657	et	4	main
ma	doc_542576733654_item	2725658	et	3	main
bussiga	doc_542576733654_item	2725660	et	3	main
nii	doc_542576733654_item	2725664	et	3	main
ilusaid	doc_542576733654_item	2725666	et	3	main
soidsime	doc_542576733654_item	2725672	et	4	main
on	doc_542576733654_item	2725675	et	4	main
metsa	doc_542576733654_item	2725683	et	4	main
päeval	doc_542576733654_item	2725685	et	3	main
minna	doc_542576733654_item	2725688	et	3	main
museumis	doc_542576733654_item	2725689	et	4	main
oli	doc_542576733654_item	2725690	et	3	main
väga	doc_542576733654_item	2725691	et	3	main
huvitav	doc_542576733654_item	2725692	et	4	main
pillet	doc_542576733654_item	2725693	et	4	main
maksab	doc_542576733654_item	2725694	et	3	main
kuus	doc_542576733654_item	2725695	et	4	main
rubla	doc_542576733654_item	2725696	et	4	main
mina	doc_542576733654_item	2725697	et	4	main
arvan	doc_542576733654_item	2725698	et	3	main
et	doc_542576733654_item	2725699	et	3	main
tulen	doc_542576733654_item	2725700	et	3	main
koju	doc_542576733654_item	2725701	et	3	main
järgmisel	doc_542576733654_item	2725702	et	3	main
päeval	doc_542576733654_item	2725703	et	3	main
soovitan	doc_542576733654_item	2725704	et	3	main
sulle	doc_542576733654_item	2725705	et	3	main
külastada	doc_542576733654_item	2725706	et	3	main
see	doc_542576733654_item	2725707	et	3	main
koht	doc_542576733654_item	2725708	et	3	main
kindlasti	doc_542576733654_item	2725709	et	3	main
sinu	doc_542576733654_item	2725710	et	3	main
eesnimi	doc_542576733654_item	2725711	et	3	main
kiri	doc_542576733655_item	2725712	et	3	main
te	doc_542576733655_item	2725713	et	4	main
plaanite	doc_542576733655_item	2725714	et	3	main
reisi	doc_542576733655_item	2725715	et	4	main
kirjutage	doc_542576733655_item	2725717	et	3	main
venemaale	doc_542576733655_item	2725716	et	4	main
sellest	doc_542576733655_item	2725718	et	4	main
kiri	doc_542576733655_item	2725719	et	3	main
oma	doc_542576733655_item	2725720	et	4	main
te	doc_542576733655_item	2725727	et	4	main
reisite	doc_542576733655_item	2725731	et	3	main
ööbite	doc_542576733655_item	2725733	et	3	main
palju	doc_542576733655_item	2725735	et	4	main
maksab	doc_542576733655_item	2725737	et	3	main
millistes	doc_542576733655_item	2725738	et	3	main
peatute	doc_542576733655_item	2725740	et	4	main
sõna	doc_542576733655_item	2725746	et	4	main
tere	doc_542576733655_item	2725747	et	3	main
sa	doc_542576733655_item	2725757	et	3	main
elad	doc_542576733655_item	2725758	et	3	main
mida	doc_542576733655_item	2725759	et	4	main
uut	doc_542576733655_item	2725760	et	3	main
on	doc_542576733655_item	2725761	et	4	main
tallinnas	doc_542576733655_item	2725762	et	4	main
kirjutan	doc_542576733655_item	2725763	et	3	main
selle	doc_542576733655_item	2725764	et	4	main
kirja	doc_542576733655_item	2725765	et	4	main
ja	doc_542576733655_item	2725725	et	3	main
soovite	doc_542576733655_item	2725729	et	3	main
pikkus	doc_542576733655_item	2725743	et	4	main
kirjutab	doc_542576733655_item	2725749	et	3	main
eesnimi	doc_542576733655_item	2725753	et	3	main
järvelt	doc_542576733655_item	2725755	et	4	main
kuidas	doc_542576733655_item	2725756	et	3	main
bussiga	doc_542576733655_item	2725779	et	3	main
perega	doc_542576733655_item	2725781	et	3	main
maksab	doc_542576733655_item	2725783	et	3	main
pilet	doc_542576733655_item	2725787	et	3	main
peterburgisse	doc_542576733655_item	2725800	et	4	main
tädi	doc_542576733655_item	2725804	et	4	main
me	doc_542576733655_item	2725807	et	4	main
loomaaeda	doc_542576733655_item	2725811	et	4	main
erinivad	doc_542576733655_item	2725812	et	4	main
vaatamisväärsusi	doc_542576733655_item	2725813	et	4	main
milla	doc_542576733655_item	2725829	et	4	main
2	doc_542576733655_item	2725837	et	2	main
plaanite	doc_542576733656_item	2725842	et	3	main
kirjutage	doc_542576733656_item	2725851	et	3	main
kuhu	doc_542576733656_item	2725854	et	3	main
ööbite	doc_542576733656_item	2725861	et	3	main
peatute	doc_542576733656_item	2725868	et	4	main
nõutav	doc_542576733656_item	2725870	et	4	main
pikkus	doc_542576733656_item	2725871	et	4	main
soovin	doc_542576733656_item	2725881	et	3	main
koos	doc_542576733656_item	2725883	et	4	main
perega	doc_542576733656_item	2725885	et	3	main
me	doc_542576733656_item	2725888	et	4	main
tea	doc_542576733656_item	2725890	et	4	main
mulle	doc_542576733656_item	2725892	et	4	main
meeldib	doc_542576733656_item	2725893	et	3	main
auto	doc_542576733656_item	2725899	et	4	main
äärde	doc_542576733656_item	2725905	et	4	main
ma	doc_542576733656_item	2725909	et	3	main
ja	doc_542576733656_item	2725912	et	3	main
puhkus	doc_542576733656_item	2725927	et	3	main
on	doc_542576733656_item	2725932	et	4	main
ka	doc_542576733656_item	2725933	et	3	main
puhkus	doc_542576733656_item	2725934	et	3	main
ja	doc_542576733656_item	2725935	et	3	main
lapsed	doc_542576733656_item	2725936	et	3	main
hotell	doc_542576733656_item	2725941	et	3	main
sotšis	doc_542576733656_item	2725944	et	2	main
see	doc_542576733656_item	2725947	et	3	main
ja	doc_542576733656_item	2725951	et	3	main
seal	doc_542576733656_item	2725960	et	4	main
umbes	doc_542576733656_item	2725961	et	4	main
kaks	doc_542576733656_item	2725962	et	3	main
nädalt	doc_542576733656_item	2725963	et	4	main
ma	doc_542576733656_item	2725965	et	3	main
lõpetan	doc_542576733656_item	2725966	et	3	main
plaanite	doc_542576733657_item	2725975	et	3	main
kiri	doc_542576733657_item	2725980	et	3	main
millal	doc_542576733657_item	2725985	et	3	main
kuhu	doc_542576733657_item	2725987	et	3	main
kus	doc_542576733657_item	2725993	et	3	main
kui	doc_542576733657_item	2725995	et	3	main
see	doc_542576733657_item	2725997	et	3	main
kohtades	doc_542576733657_item	2726000	et	3	main
kirja	doc_542576733657_item	2726002	et	4	main
sõna	doc_542576733657_item	2726007	et	4	main
ma	doc_542576733655_item	2725767	et	3	main
plaanerin	doc_542576733655_item	2725768	et	4	main
sõidan	doc_542576733655_item	2725778	et	3	main
oma	doc_542576733655_item	2725780	et	4	main
pilet	doc_542576733655_item	2725782	et	3	main
300	doc_542576733655_item	2725784	et	2	main
mehe	doc_542576733655_item	2725803	et	3	main
tahame	doc_542576733655_item	2725808	et	3	main
kinnosse	doc_542576733655_item	2725815	et	4	main
kohvikusse	doc_542576733655_item	2725817	et	4	main
tahame	doc_542576733655_item	2725822	et	3	main
ma	doc_542576733655_item	2725825	et	3	main
juurde	doc_542576733655_item	2725833	et	4	main
ma	doc_542576733655_item	2725834	et	3	main
ootan	doc_542576733655_item	2725835	et	3	main
juuni	doc_542576733655_item	2725838	et	4	main
te	doc_542576733656_item	2725841	et	4	main
sõbrale	doc_542576733656_item	2725850	et	3	main
millal	doc_542576733656_item	2725852	et	3	main
ja	doc_542576733656_item	2725853	et	3	main
palju	doc_542576733656_item	2725863	et	4	main
kirja	doc_542576733656_item	2725869	et	4	main
ma	doc_542576733656_item	2725880	et	3	main
oma	doc_542576733656_item	2725884	et	4	main
meil	doc_542576733656_item	2725896	et	4	main
tahame	doc_542576733656_item	2725902	et	3	main
sõita	doc_542576733656_item	2725903	et	3	main
sõitsin	doc_542576733656_item	2725910	et	3	main
sõita	doc_542576733656_item	2725922	et	3	main
kord	doc_542576733656_item	2725924	et	4	main
on	doc_542576733656_item	2725928	et	4	main
keskel	doc_542576733656_item	2725930	et	3	main
õppinud	doc_542576733656_item	2725940	et	4	main
ääres	doc_542576733656_item	2725946	et	4	main
me	doc_542576733656_item	2725957	et	4	main
planeerime	doc_542576733656_item	2725958	et	3	main
peatuda	doc_542576733656_item	2725959	et	3	main
oma	doc_542576733656_item	2725967	et	4	main
sõbranna	doc_542576733656_item	2725971	et	4	main
eesnimi	doc_542576733656_item	2725972	et	3	main
kiri	doc_542576733657_item	2725973	et	3	main
reisi	doc_542576733657_item	2725976	et	4	main
oma	doc_542576733657_item	2725981	et	4	main
sõbrale	doc_542576733657_item	2725983	et	3	main
ja	doc_542576733657_item	2725986	et	3	main
pikkus	doc_542576733657_item	2726004	et	4	main
kallis	doc_542576733657_item	2726008	et	4	main
sõber	doc_542576733657_item	2726009	et	3	main
juunil	doc_542576733657_item	2726011	et	3	main
ma	doc_542576733657_item	2726012	et	3	main
peterburis	doc_542576733657_item	2726026	et	4	main
ma	doc_542576733657_item	2726029	et	3	main
bussiga	doc_542576733657_item	2726031	et	3	main
ööbin	doc_542576733657_item	2726033	et	3	main
krooni	doc_542576733657_item	2726040	et	4	main
mis	doc_542576733657_item	2726043	et	4	main
peterburi	doc_542576733657_item	2726047	et	4	main
ülikool	doc_542576733657_item	2726057	et	4	main
peatuda	doc_542576733657_item	2726062	et	3	main
lossid	doc_542576733657_item	2726071	et	4	main
vene	doc_542576733657_item	2726074	et	4	main
väga	doc_542576733657_item	2726085	et	3	main
linn	doc_542576733657_item	2726087	et	3	main
aga	doc_542576733657_item	2726100	et	3	main
peterburi	doc_542576733657_item	2726107	et	4	main
ilusad	doc_542576733657_item	2726109	et	3	main
hooned	doc_542576733657_item	2726110	et	4	main
ja	doc_542576733657_item	2726116	et	3	main
sillad	doc_542576733657_item	2726117	et	3	main
sa	doc_542576733655_item	2725830	et	3	main
tuled	doc_542576733655_item	2725831	et	4	main
minu	doc_542576733655_item	2725832	et	3	main
allkiri	doc_542576733655_item	2725839	et	3	main
venemaale	doc_542576733656_item	2725844	et	4	main
sellest	doc_542576733656_item	2725846	et	4	main
kiri	doc_542576733656_item	2725847	et	3	main
oma	doc_542576733656_item	2725848	et	4	main
see	doc_542576733656_item	2725864	et	3	main
maksab	doc_542576733656_item	2725865	et	3	main
umbes	doc_542576733656_item	2725872	et	4	main
80	doc_542576733656_item	2725873	et	2	main
lõuna	doc_542576733656_item	2725894	et	4	main
opel	doc_542576733656_item	2725900	et	4	main
me	doc_542576733656_item	2725901	et	4	main
mere	doc_542576733656_item	2725904	et	3	main
aastal	doc_542576733656_item	2725907	et	3	main
svetlana	doc_542576733656_item	2725915	et	4	main
võib	doc_542576733656_item	2725919	et	3	main
minu	doc_542576733656_item	2725926	et	3	main
abukaasal	doc_542576733656_item	2725931	et	4	main
on	doc_542576733656_item	2725948	et	4	main
me	doc_542576733656_item	2725952	et	4	main
kõik	doc_542576733656_item	2725954	et	4	main
te	doc_542576733657_item	2725974	et	4	main
sellest	doc_542576733657_item	2725979	et	4	main
eestlasest	doc_542576733657_item	2725982	et	3	main
sõita	doc_542576733657_item	2725989	et	3	main
millistes	doc_542576733657_item	2725999	et	3	main
peatute	doc_542576733657_item	2726001	et	4	main
nõutav	doc_542576733657_item	2726003	et	4	main
ma	doc_542576733657_item	2726022	et	3	main
sõita	doc_542576733657_item	2726024	et	3	main
reis	doc_542576733657_item	2726035	et	4	main
viisaga	doc_542576733657_item	2726037	et	4	main
nelisada	doc_542576733657_item	2726038	et	4	main
isaaki	doc_542576733657_item	2726051	et	4	main
katedraal	doc_542576733657_item	2726052	et	3	main
peterburi	doc_542576733657_item	2726056	et	4	main
marsovipõld	doc_542576733657_item	2726058	et	4	main
ma	doc_542576733657_item	2726060	et	3	main
kingisseppis	doc_542576733657_item	2726063	et	4	main
ja	doc_542576733657_item	2726064	et	3	main
purskkaevud	doc_542576733657_item	2726069	et	3	main
tsaarid	doc_542576733657_item	2726075	et	3	main
i	doc_542576733657_item	2726078	et	4	main
ja	doc_542576733657_item	2726079	et	3	main
ekatiriina	doc_542576733657_item	2726080	et	4	main
peterburg	doc_542576733657_item	2726083	et	4	main
vaga	doc_542576733657_item	2726089	et	4	main
sõita	doc_542576733657_item	2726098	et	3	main
meeldib	doc_542576733657_item	2726104	et	3	main
sankt	doc_542576733657_item	2726106	et	4	main
barokko	doc_542576733657_item	2726111	et	4	main
stiilis	doc_542576733657_item	2726112	et	4	main
tahaks	doc_542576733657_item	2726119	et	3	main
minuga	doc_542576733657_item	2726123	et	3	main
sinu	doc_542576733657_item	2726125	et	3	main
eesnimi	doc_542576733657_item	2726127	et	3	main
eksamitöö	doc_553383122816_item	2726128	et	4	main
anna	doc_553383122816_item	2726130	et	4	main
ülevaade	doc_553383122816_item	2726131	et	3	main
rahvusteaduste	doc_553383122816_item	2726132	et	3	main
arengust	doc_553383122816_item	2726133	et	3	main
eesti	doc_553383122816_item	2726134	et	4	main
1905	doc_553383122816_item	2726138	et	2	main
tähtsust	doc_553383122816_item	2726141	et	4	main
nähtu	doc_553383122816_item	2726153	et	4	main
põhjal	doc_553383122816_item	2726154	et	4	main
1905	doc_553383122816_item	2726156	et	2	main
aastal	doc_553383122816_item	2726157	et	3	main
toimus	doc_553383122816_item	2726158	et	3	main
revolutsioon	doc_553383122816_item	2726159	et	3	main
eesti	doc_553383122816_item	2726160	et	4	main
oma	doc_553383122816_item	2726180	et	4	main
mõisade	doc_553383122816_item	2726191	et	4	main
ja	doc_553383122816_item	2726209	et	3	main
aru	doc_553383122816_item	2726213	et	4	main
et	doc_553383122816_item	2726214	et	3	main
see	doc_553383122816_item	2726215	et	3	main
paiba	doc_553383122816_item	2726240	et	4	main
korraldaja	doc_553383122816_item	2726245	et	4	main
tapmist	doc_553383122816_item	2726252	et	4	main
1912	doc_553383122816_item	2726256	et	2	main
novelli	doc_553383122816_item	2726258	et	4	main
võimu	doc_553383122816_item	2726318	et	4	main
vastu	doc_553383122816_item	2726319	et	3	main
võitlus	doc_553383122816_item	2726320	et	3	main
venemaal	doc_542576733656_item	2725895	et	4	main
sotšis	doc_542576733656_item	2725911	et	2	main
puhkasin	doc_542576733656_item	2725913	et	3	main
hotellis	doc_542576733656_item	2725914	et	3	main
meeldib	doc_542576733656_item	2725918	et	3	main
olla	doc_542576733656_item	2725920	et	3	main
me	doc_542576733656_item	2725921	et	4	main
veel	doc_542576733656_item	2725923	et	4	main
sotšis	doc_542576733656_item	2725925	et	2	main
juulis	doc_542576733656_item	2725929	et	3	main
mere	doc_542576733656_item	2725945	et	3	main
kallis	doc_542576733656_item	2725949	et	4	main
nägemiseni	doc_542576733656_item	2725969	et	4	main
venemaale	doc_542576733657_item	2725977	et	4	main
soovite	doc_542576733657_item	2725990	et	3	main
millega	doc_542576733657_item	2725991	et	3	main
ööbite	doc_542576733657_item	2725994	et	3	main
palju	doc_542576733657_item	2725996	et	4	main
umbes	doc_542576733657_item	2726005	et	4	main
80	doc_542576733657_item	2726006	et	2	main
viieteistkümnendal	doc_542576733657_item	2726010	et	4	main
sõita	doc_542576733657_item	2726014	et	3	main
sankt	doc_542576733657_item	2726025	et	4	main
mis	doc_542576733657_item	2726028	et	4	main
aga	doc_542576733657_item	2726032	et	3	main
näen	doc_542576733657_item	2726045	et	3	main
petergofis	doc_542576733657_item	2726066	et	4	main
on	doc_542576733657_item	2726084	et	4	main
mis	doc_542576733657_item	2726096	et	4	main
ma	doc_542576733657_item	2726097	et	3	main
palju	doc_542576733657_item	2726113	et	4	main
sõigad	doc_542576733657_item	2726122	et	4	main
sõber	doc_542576733657_item	2726126	et	3	main
wabariigis	doc_553383122816_item	2726135	et	4	main
sündmuste	doc_553383122816_item	2726140	et	3	main
realismi	doc_553383122816_item	2726147	et	4	main
kui	doc_553383122816_item	2726148	et	3	main
loomismeetodit	doc_553383122816_item	2726149	et	3	main
filmi	doc_553383122816_item	2726150	et	4	main
valgus	doc_553383122816_item	2726151	et	4	main
vabadust	doc_553383122816_item	2726166	et	4	main
nad	doc_553383122816_item	2726167	et	3	main
ja	doc_553383122816_item	2726171	et	3	main
tõstmist	doc_553383122816_item	2726173	et	4	main
riigid	doc_553383122816_item	2726175	et	3	main
14	doc_553383122816_item	2726184	et	2	main
tema	doc_553383122816_item	2726199	et	4	main
karistussalk	doc_553383122816_item	2726200	et	3	main
talupojad	doc_553383122816_item	2726208	et	4	main
aastal	doc_553383122816_item	2726223	et	3	main
ajal	doc_553383122816_item	2726231	et	4	main
lasti	doc_553383122816_item	2726232	et	4	main
talu	doc_553383122816_item	2726241	et	4	main
muusikaseltsi	doc_553383122816_item	2726246	et	4	main
juht	doc_553383122816_item	2726247	et	3	main
kirjutas	doc_553383122816_item	2726255	et	3	main
sai	doc_553383122816_item	2726304	et	4	main
valida	doc_553383122816_item	2726305	et	3	main
millesse	doc_553383122816_item	2726306	et	3	main
kirikusse	doc_553383122816_item	2726307	et	4	main
74	doc_553383122816_item	2726325	et	2	main
usuõpetajatest	doc_553383122816_item	2726326	et	4	main
olid	doc_553383122816_item	2726327	et	4	main
baltisakslased	doc_553383122816_item	2726328	et	3	main
1920	doc_553383122816_item	2726333	et	2	main
rahvas	doc_553383122816_item	2726340	et	4	main
ja	doc_553383122816_item	2726344	et	3	main
tuntud	doc_553383122816_item	2726347	et	4	main
neurokirurg	doc_553383122816_item	2726348	et	3	main
esimesena	doc_553383122816_item	2726349	et	3	main
maailmas	doc_553383122816_item	2726350	et	3	main
ajuoperatsioone	doc_553383122816_item	2726353	et	3	main
asutakse	doc_553383122816_item	2726357	et	4	main
liite	doc_553383122816_item	2726359	et	4	main
nt	doc_553383122816_item	2726360	et	4	main
jaavik	doc_553383122816_item	2726365	et	4	main
kultuurielu	doc_553383122816_item	2726368	et	4	main
teadus	doc_553383122816_item	2726369	et	4	main
esimene	doc_553383122816_item	2726370	et	3	main
ooper	doc_553383122816_item	2726372	et	3	main
tekkivad	doc_553383122816_item	2726375	et	4	main
on	doc_542576733656_item	2725937	et	4	main
ka	doc_542576733656_item	2725938	et	3	main
ei	doc_542576733656_item	2725939	et	4	main
svetlana	doc_542576733656_item	2725942	et	4	main
asub	doc_542576733656_item	2725943	et	3	main
hotell	doc_542576733656_item	2725950	et	3	main
võtame	doc_542576733656_item	2725953	et	3	main
oma	doc_542576733656_item	2725955	et	4	main
raha	doc_542576733656_item	2725956	et	4	main
sellega	doc_542576733656_item	2725964	et	3	main
kirja	doc_542576733656_item	2725968	et	4	main
sinu	doc_542576733656_item	2725970	et	3	main
kirjutage	doc_542576733657_item	2725978	et	3	main
kirjutage	doc_542576733657_item	2725984	et	3	main
te	doc_542576733657_item	2725988	et	4	main
reisite	doc_542576733657_item	2725992	et	3	main
maksab	doc_542576733657_item	2725998	et	3	main
tahan	doc_542576733657_item	2726013	et	3	main
venemaale	doc_542576733657_item	2726015	et	4	main
selle	doc_542576733657_item	2726016	et	4	main
pärast	doc_542576733657_item	2726017	et	4	main
ma	doc_542576733657_item	2726018	et	3	main
kirjutan	doc_542576733657_item	2726019	et	3	main
teile	doc_542576733657_item	2726020	et	4	main
konkreetne	doc_542576733657_item	2726021	et	3	main
soovin	doc_542576733657_item	2726023	et	3	main
seitsekümmend	doc_542576733657_item	2726039	et	4	main
loodaks	doc_542576733657_item	2726042	et	4	main
ma	doc_542576733657_item	2726044	et	3	main
kasanski	doc_542576733657_item	2726053	et	4	main
katedraal	doc_542576733657_item	2726054	et	3	main
sankt	doc_542576733657_item	2726055	et	4	main
petergofis	doc_542576733657_item	2726065	et	4	main
väga	doc_542576733657_item	2726067	et	3	main
ilusad	doc_542576733657_item	2726068	et	3	main
seal	doc_542576733657_item	2726072	et	4	main
puhkavad	doc_542576733657_item	2726073	et	4	main
peter	doc_542576733657_item	2726077	et	4	main
ii	doc_542576733657_item	2726081	et	4	main
sankt	doc_542576733657_item	2726082	et	4	main
suur	doc_542576733657_item	2726086	et	3	main
seal	doc_542576733657_item	2726088	et	4	main
ühes	doc_542576733657_item	2726092	et	4	main
osas	doc_542576733657_item	2726093	et	4	main
teise	doc_542576733657_item	2726094	et	4	main
mõtlen	doc_542576733657_item	2726095	et	3	main
jalutan	doc_542576733657_item	2726101	et	3	main
mulle	doc_542576733657_item	2726103	et	4	main
tänaval	doc_542576733657_item	2726108	et	4	main
väga	doc_542576733657_item	2726118	et	3	main
sa	doc_542576733657_item	2726121	et	3	main
hinda	doc_553383122816_item	2726137	et	4	main
aasta	doc_553383122816_item	2726139	et	4	main
eesti	doc_553383122816_item	2726142	et	4	main
ajaloos	doc_553383122816_item	2726143	et	4	main
3	doc_553383122816_item	2726144	et	2	main
nõutis	doc_553383122816_item	2726162	et	4	main
sotsialistliku	doc_553383122816_item	2726163	et	3	main
ja	doc_553383122816_item	2726164	et	3	main
rahvuse	doc_553383122816_item	2726165	et	3	main
lühenemist	doc_553383122816_item	2726170	et	4	main
protesti	doc_553383122816_item	2726181	et	4	main
tuli	doc_553383122816_item	2726188	et	4	main
põletamine	doc_553383122816_item	2726192	et	4	main
relvi	doc_553383122816_item	2726201	et	4	main
abiga	doc_553383122816_item	2726202	et	3	main
nad	doc_553383122816_item	2726203	et	3	main
karistada	doc_553383122816_item	2726210	et	3	main
nõudma	doc_553383122816_item	2726221	et	3	main
bezobrazov	doc_553383122816_item	2726224	et	4	main
bernhard	doc_553383122816_item	2726236	et	4	main
laipmann	doc_553383122816_item	2726237	et	3	main
vigala	doc_553383122816_item	2726243	et	4	main
valis	doc_553383122816_item	2726249	et	3	main
peksmise	doc_553383122816_item	2726250	et	4	main
1992	doc_553383122816_item	2726262	et	2	main
mõtlen	doc_542576733657_item	2726027	et	3	main
sõidan	doc_542576733657_item	2726030	et	3	main
hotellis	doc_542576733657_item	2726034	et	3	main
maksab	doc_542576733657_item	2726036	et	3	main
väga	doc_542576733657_item	2726041	et	3	main
sankt	doc_542576733657_item	2726046	et	4	main
vaatamisväärsused	doc_542576733657_item	2726048	et	4	main
nagu	doc_542576733657_item	2726049	et	3	main
admiralihoone	doc_542576733657_item	2726050	et	4	main
reisil	doc_542576733657_item	2726059	et	3	main
planeerin	doc_542576733657_item	2726061	et	3	main
ja	doc_542576733657_item	2726070	et	3	main
nagu	doc_542576733657_item	2726076	et	3	main
raske	doc_542576733657_item	2726090	et	4	main
jõuda	doc_542576733657_item	2726091	et	3	main
taksoga	doc_542576733657_item	2726099	et	3	main
jalgsi	doc_542576733657_item	2726102	et	3	main
jalutan	doc_542576733657_item	2726105	et	3	main
lossid	doc_542576733657_item	2726114	et	4	main
kirikud	doc_542576733657_item	2726115	et	3	main
mis	doc_542576733657_item	2726120	et	4	main
nägemist	doc_542576733657_item	2726124	et	4	main
2	doc_553383122816_item	2726136	et	2	main
rahvas	doc_553383122816_item	2726161	et	4	main
väiksed	doc_553383122816_item	2726174	et	4	main
töökatkestamisega	doc_553383122816_item	2726182	et	3	main
narvas	doc_553383122816_item	2726183	et	4	main
17	doc_553383122816_item	2726185	et	2	main
detsember	doc_553383122816_item	2726186	et	3	main
maale	doc_553383122816_item	2726189	et	4	main
100	doc_553383122816_item	2726193	et	2	main
jõudis	doc_553383122816_item	2726195	et	3	main
kindral	doc_553383122816_item	2726196	et	4	main
püüdsid	doc_553383122816_item	2726204	et	4	main
kuulma	doc_553383122816_item	2726205	et	3	main
panna	doc_553383122816_item	2726206	et	4	main
1909	doc_553383122816_item	2726222	et	2	main
koos	doc_553383122816_item	2726225	et	4	main
oma	doc_553383122816_item	2726226	et	4	main
karistussalgiga	doc_553383122816_item	2726227	et	3	main
tegi	doc_553383122816_item	2726228	et	4	main
veresaun	doc_553383122816_item	2726229	et	3	main
tol	doc_553383122816_item	2726230	et	3	main
kes	doc_553383122816_item	2726238	et	4	main
oli	doc_553383122816_item	2726239	et	3	main
seltsielu	doc_553383122816_item	2726244	et	4	main
asemele	doc_553383122816_item	2726251	et	4	main
kallas	doc_553383122816_item	2726254	et	4	main
eesti	doc_553383122816_item	2726266	et	4	main
draamateatris	doc_553383122816_item	2726267	et	3	main
seega	doc_553383122816_item	2726268	et	4	main
lühenes	doc_553383122816_item	2726269	et	3	main
tööpäev	doc_553383122816_item	2726270	et	3	main
keelseid	doc_553383122816_item	2726296	et	3	main
1905	doc_553383122816_item	2726298	et	2	main
aastal	doc_553383122816_item	2726299	et	3	main
eitati	doc_553383122816_item	2726310	et	4	main
võidelta	doc_553383122816_item	2726314	et	4	main
kiriku	doc_553383122816_item	2726315	et	3	main
ja	doc_553383122816_item	2726316	et	3	main
religiose	doc_553383122816_item	2726317	et	4	main
usuõpetamise	doc_553383122816_item	2726321	et	3	main
1939	doc_553383122816_item	2726334	et	2	main
agraarriik	doc_553383122816_item	2726341	et	3	main
puusepp	doc_553383122816_item	2726346	et	3	main
eestis	doc_553383122816_item	2726354	et	3	main
usi	doc_553383122816_item	2726358	et	4	main
juht	doc_553383122816_item	2726364	et	3	main
areneb	doc_553383122816_item	2726366	et	3	main
6-klassiline	doc_553383122816_item	2726380	et	4	main
5-klassiline	doc_553383122816_item	2726388	et	4	main
avatakse	doc_553383122816_item	2726403	et	4	main
1934	doc_553383122816_item	2726407	et	2	main
baltisakslaste	doc_553383122816_item	2726421	et	4	main
eestlaste	doc_553383122816_item	2726423	et	4	main
1920	doc_553383122816_item	2726425	et	2	main
aastal	doc_553383122816_item	2726426	et	3	main
esimene	doc_553383122816_item	2726427	et	3	main
1937	doc_553383122816_item	2726429	et	2	main
uuendati	doc_553383122816_item	2726430	et	3	main
1924	doc_553383122816_item	2726442	et	2	main
1	doc_553383122816_item	2726129	et	2	main
kirjelda	doc_553383122816_item	2726145	et	4	main
sotsialistlikku	doc_553383122816_item	2726146	et	4	main
koordis	doc_553383122816_item	2726152	et	4	main
2	doc_553383122816_item	2726155	et	2	main
nõutsid	doc_553383122816_item	2726168	et	4	main
tööpäeva	doc_553383122816_item	2726169	et	4	main
palga	doc_553383122816_item	2726172	et	3	main
nõutsid	doc_553383122816_item	2726176	et	4	main
autonoomiat	doc_553383122816_item	2726177	et	3	main
rahvas	doc_553383122816_item	2726178	et	4	main
näitas	doc_553383122816_item	2726179	et	3	main
mässamine	doc_553383122816_item	2726187	et	4	main
algas	doc_553383122816_item	2726190	et	3	main
eestisse	doc_553383122816_item	2726194	et	4	main
bezobrazov	doc_553383122816_item	2726197	et	4	main
ja	doc_553383122816_item	2726198	et	3	main
rahvas	doc_553383122816_item	2726207	et	4	main
talupojad	doc_553383122816_item	2726211	et	4	main
said	doc_553383122816_item	2726212	et	4	main
ei	doc_553383122816_item	2726216	et	4	main
ole	doc_553383122816_item	2726217	et	4	main
õige	doc_553383122816_item	2726218	et	4	main
tee	doc_553383122816_item	2726219	et	4	main
õigusi	doc_553383122816_item	2726220	et	4	main
ma	doc_553383122816_item	2726233	et	3	main
eesti	doc_553383122816_item	2726234	et	4	main
kangelane	doc_553383122816_item	2726235	et	3	main
peremees	doc_553383122816_item	2726242	et	4	main
ta	doc_553383122816_item	2726248	et	4	main
aino	doc_553383122816_item	2726253	et	4	main
aastal	doc_553383122816_item	2726257	et	3	main
bernhard	doc_553383122816_item	2726259	et	4	main
riives	doc_553383122816_item	2726260	et	4	main
ja	doc_553383122816_item	2726261	et	3	main
umbes	doc_553383122816_item	2726271	et	4	main
tundi	doc_553383122816_item	2726273	et	4	main
eesti	doc_553383122816_item	2726274	et	4	main
sai	doc_553383122816_item	2726276	et	4	main
keel	doc_553383122816_item	2726275	et	4	main
rohkem	doc_553383122816_item	2726277	et	4	main
õigusi	doc_553383122816_item	2726278	et	4	main
koolis	doc_553383122816_item	2726279	et	4	main
avati	doc_553383122816_item	2726280	et	3	main
kutsekoolid	doc_553383122816_item	2726281	et	3	main
kohustuslik	doc_553383122816_item	2726282	et	3	main
algklassiline	doc_553383122816_item	2726283	et	4	main
haridus	doc_553383122816_item	2726284	et	3	main
ka	doc_553383122816_item	2726285	et	3	main
eestlastele	doc_553383122816_item	2726286	et	4	main
eesti	doc_553383122816_item	2726287	et	4	main
soost	doc_553383122816_item	2726288	et	4	main
tüdrukud	doc_553383122816_item	2726289	et	3	main
said	doc_553383122816_item	2726290	et	4	main
õppida	doc_553383122816_item	2726291	et	3	main
kõrgkoolides	doc_553383122816_item	2726292	et	3	main
võimalus	doc_553383122816_item	2726293	et	3	main
avada	doc_553383122816_item	2726294	et	3	main
aastal	doc_553383122816_item	2726263	et	3	main
oli	doc_553383122816_item	2726264	et	3	main
br	doc_553383122816_item	2726265	et	4	main
10	doc_553383122816_item	2726272	et	2	main
tsaari	doc_553383122816_item	2726300	et	4	main
ukaasiga	doc_553383122816_item	2726301	et	3	main
usuvabadusest	doc_553383122816_item	2726302	et	4	main
inimene	doc_553383122816_item	2726303	et	3	main
ateism	doc_553383122816_item	2726309	et	3	main
sotsid	doc_553383122816_item	2726312	et	3	main
sest	doc_553383122816_item	2726324	et	4	main
wabariigi	doc_553383122816_item	2726331	et	4	main
eesti	doc_553383122816_item	2726335	et	4	main
monoetniline	doc_553383122816_item	2726337	et	3	main
domineerib	doc_553383122816_item	2726338	et	3	main
arstiteadus	doc_553383122816_item	2726343	et	4	main
põllumajandus	doc_553383122816_item	2726345	et	3	main
haritlaskond	doc_553383122816_item	2726356	et	3	main
eesti	doc_553383122816_item	2726361	et	4	main
lauljate	doc_553383122816_item	2726362	et	4	main
liit	doc_553383122816_item	2726363	et	3	main
eesti	doc_553383122816_item	2726371	et	4	main
vikerlased	doc_553383122816_item	2726373	et	3	main
aav	doc_553383122816_item	2726374	et	4	main
põhikool	doc_553383122816_item	2726381	et	4	main
tasuta	doc_553383122816_item	2726382	et	4	main
võib	doc_553383122816_item	2726383	et	3	main
õppida	doc_553383122816_item	2726384	et	3	main
ka	doc_553383122816_item	2726385	et	3	main
eesti	doc_553383122816_item	2726386	et	4	main
ülikool	doc_553383122816_item	2726392	et	4	main
tasuline	doc_553383122816_item	2726393	et	4	main
humanitaar-	doc_553383122816_item	2726397	et	4	main
realharu	doc_553383122816_item	2726399	et	4	main
1934	doc_553383122816_item	2726400	et	2	main
aastal	doc_553383122816_item	2726401	et	3	main
koolireform	doc_553383122816_item	2726402	et	3	main
1919	doc_553383122816_item	2726432	et	2	main
mõistnikude	doc_553383122816_item	2726436	et	4	main
1	doc_553383122816_item	2726443	et	2	main
olulisemaid	doc_553383122816_item	2726449	et	4	main
nt	doc_553383122816_item	2726451	et	4	main
27	doc_553383122816_item	2726453	et	2	main
1922	doc_553383122816_item	2726455	et	2	main
aastal	doc_553383122816_item	2726462	et	3	main
kirikud	doc_553383122816_item	2726478	et	3	main
vaikivperiood	doc_553383122816_item	2726488	et	4	main
kontroll	doc_553383122816_item	2726490	et	3	main
eesti	doc_553383122816_item	2726295	et	4	main
erakoole	doc_553383122816_item	2726297	et	4	main
kuuluda	doc_553383122816_item	2726308	et	4	main
jumalat	doc_553383122816_item	2726311	et	3	main
tahtsid	doc_553383122816_item	2726313	et	4	main
aeg	doc_553383122816_item	2726332	et	3	main
on	doc_553383122816_item	2726336	et	4	main
üks	doc_553383122816_item	2726339	et	3	main
kasvab	doc_553383122816_item	2726355	et	3	main
haridus	doc_553383122816_item	2726367	et	3	main
gümnaasium	doc_553383122816_item	2726389	et	3	main
koolides	doc_553383122816_item	2726323	et	3	main
vastu	doc_553383122816_item	2726322	et	3	main
1	doc_553383122816_item	2726329	et	2	main
eesti	doc_553383122816_item	2726330	et	4	main
põllumajanduslik	doc_553383122816_item	2726342	et	3	main
hakkas	doc_553383122816_item	2726351	et	3	main
tegema	doc_553383122816_item	2726352	et	3	main
3-astmeliseks	doc_553383122816_item	2726379	et	4	main
keeles	doc_553383122816_item	2726387	et	4	main
tasuline	doc_553383122816_item	2726391	et	4	main
harud	doc_553383122816_item	2726396	et	3	main
ja	doc_553383122816_item	2726398	et	3	main
kutsekoolid	doc_553383122816_item	2726404	et	3	main
süstemaatiline	doc_553383122816_item	2726405	et	3	main
kunstiõpetus	doc_553383122816_item	2726406	et	3	main
aastal	doc_553383122816_item	2726408	et	3	main
ahtammsaare	doc_553383122816_item	2726409	et	4	main
sai	doc_553383122816_item	2726410	et	4	main
riigivanema	doc_553383122816_item	2726411	et	4	main
kpätsi	doc_553383122816_item	2726412	et	4	main
kirjanduspreemiat	doc_553383122816_item	2726413	et	3	main
tõde	doc_553383122816_item	2726414	et	4	main
ja	doc_553383122816_item	2726415	et	3	main
õigus	doc_553383122816_item	2726416	et	4	main
2	doc_553383122816_item	2726417	et	2	main
viimase	doc_553383122816_item	2726418	et	3	main
köide	doc_553383122816_item	2726419	et	4	main
eest	doc_553383122816_item	2726420	et	4	main
põhiseadus	doc_553383122816_item	2726431	et	4	main
vahel	doc_553383122816_item	2726441	et	4	main
võetakse	doc_553383122816_item	2726458	et	3	main
antakse	doc_553383122816_item	2726463	et	3	main
saavad	doc_553383122816_item	2726471	et	4	main
õppida	doc_553383122816_item	2726472	et	3	main
trükkisõna	doc_553383122816_item	2726476	et	4	main
kroon	doc_553383122816_item	2726482	et	3	main
seotud	doc_553383122816_item	2726485	et	4	main
1934	doc_553383122816_item	2726486	et	2	main
tsentsuur	doc_553383122816_item	2726489	et	4	main
süzheedid	doc_553383122816_item	2726533	et	4	main
hea	doc_553383122816_item	2726542	et	4	main
ühtlaskoolid	doc_553383122816_item	2726376	et	4	main
koolisüsteem	doc_553383122816_item	2726377	et	3	main
muutub	doc_553383122816_item	2726378	et	3	main
osaliselt	doc_553383122816_item	2726390	et	4	main
gümnaasiumis	doc_553383122816_item	2726394	et	3	main
kaks	doc_553383122816_item	2726395	et	3	main
põhiseadus	doc_553383122816_item	2726428	et	4	main
maareform	doc_553383122816_item	2726434	et	3	main
kirikumaad	doc_553383122816_item	2726435	et	4	main
baltisaksa	doc_553383122816_item	2726437	et	4	main
maad	doc_553383122816_item	2726438	et	4	main
jagatakse	doc_553383122816_item	2726439	et	3	main
talupoegade	doc_553383122816_item	2726440	et	3	main
püüti	doc_553383122816_item	2726447	et	3	main
objekte	doc_553383122816_item	2726450	et	3	main
raudteejaamad	doc_553383122816_item	2726452	et	3	main
juuni	doc_553383122816_item	2726454	et	4	main
ametlikuks	doc_553383122816_item	2726459	et	3	main
eesti	doc_553383122816_item	2726466	et	4	main
ema	doc_553383122816_item	2726473	et	4	main
keeles	doc_553383122816_item	2726474	et	4	main
emakeelne	doc_553383122816_item	2726475	et	3	main
eesti	doc_553383122816_item	2726481	et	4	main
saksa	doc_553383122816_item	2726483	et	4	main
markaga	doc_553383122816_item	2726484	et	4	main
hea	doc_553383122816_item	2726521	et	4	main
on	doc_553383122816_item	2726523	et	4	main
kolhoosides	doc_553383122816_item	2726524	et	3	main
tegijad	doc_553383122816_item	2726531	et	4	main
oli	doc_553383122816_item	2726538	et	3	main
vaja	doc_553383122816_item	2726539	et	4	main
ja	doc_553383122816_item	2726422	et	3	main
suhted	doc_553383122816_item	2726424	et	3	main
aastal	doc_553383122816_item	2726433	et	3	main
vallutada	doc_553383122816_item	2726448	et	3	main
sini-must-valge	doc_553383122816_item	2726456	et	4	main
1925	doc_553383122816_item	2726461	et	2	main
kõigidele	doc_553383122816_item	2726465	et	4	main
piirides	doc_553383122816_item	2726467	et	3	main
1928	doc_553383122816_item	2726479	et	2	main
aastal	doc_553383122816_item	2726480	et	3	main
3	doc_553383122816_item	2726491	et	2	main
sotsialistlik	doc_553383122816_item	2726492	et	3	main
realism	doc_553383122816_item	2726493	et	3	main
elamisviisi	doc_553383122816_item	2726494	et	4	main
meetod	doc_553383122816_item	2726495	et	3	main
kirjanduslik	doc_553383122816_item	2726496	et	3	main
meetod	doc_553383122816_item	2726497	et	3	main
vene	doc_553383122816_item	2726498	et	4	main
ajal	doc_553383122816_item	2726499	et	4	main
kus	doc_553383122816_item	2726500	et	3	main
näitakse	doc_553383122816_item	2726501	et	4	main
nagu	doc_553383122816_item	2726502	et	3	main
esitatud	doc_553383122816_item	2726503	et	4	main
filmis	doc_553383122816_item	2726504	et	4	main
valgus	doc_553383122816_item	2726505	et	4	main
koordis	doc_553383122816_item	2726506	et	4	main
kui	doc_553383122816_item	2726507	et	3	main
hea	doc_553383122816_item	2726508	et	4	main
kui	doc_553383122816_item	2726509	et	3	main
maa	doc_553383122816_item	2726510	et	4	main
on	doc_553383122816_item	2726511	et	4	main
kõikide	doc_553383122816_item	2726512	et	4	main
oma	doc_553383122816_item	2726513	et	4	main
kui	doc_553383122816_item	2726514	et	3	main
hea	doc_553383122816_item	2726515	et	4	main
harida	doc_553383122816_item	2726516	et	3	main
seda	doc_553383122816_item	2726517	et	3	main
kõik	doc_553383122816_item	2726518	et	4	main
koos	doc_553383122816_item	2726519	et	4	main
kui	doc_553383122816_item	2726520	et	3	main
kirjutasid	doc_553383122816_item	2726528	et	4	main
sellest	doc_553383122816_item	2726529	et	4	main
sellele	doc_553383122816_item	2726534	et	4	main
teemal	doc_553383122816_item	2726535	et	3	main
igal	doc_553383122816_item	2726536	et	3	main
pool	doc_553383122816_item	2726537	et	4	main
dets	doc_553383122816_item	2726444	et	4	main
riigi	doc_553383122816_item	2726445	et	3	main
pördekatse	doc_553383122816_item	2726446	et	4	main
trikoloor	doc_553383122816_item	2726457	et	3	main
lipuks	doc_553383122816_item	2726460	et	3	main
kultuurautonoomiat	doc_553383122816_item	2726464	et	3	main
elavatele	doc_553383122816_item	2726468	et	4	main
vähemusrahvastele	doc_553383122816_item	2726469	et	4	main
nad	doc_553383122816_item	2726470	et	3	main
enda	doc_553383122816_item	2726477	et	4	main
aastal	doc_553383122816_item	2726487	et	3	main
filmi	doc_553383122816_item	2726530	et	4	main
on	doc_553383122816_item	2726543	et	4	main
sotsialism	doc_553383122816_item	2726544	et	3	main
elu	doc_553383122816_item	2726522	et	4	main
ja	doc_553383122816_item	2726525	et	3	main
sofhoosides	doc_553383122816_item	2726526	et	4	main
kirjanikud	doc_553383122816_item	2726527	et	3	main
tegid	doc_553383122816_item	2726532	et	4	main
näidata	doc_553383122816_item	2726540	et	4	main
kui	doc_553383122816_item	2726541	et	3	main
teile	doc_560938275462_item	2732732	et	4	main
seminaritöö	doc_560938275462_item	2732734	et	4	main
selle	doc_560938275462_item	2732740	et	4	main
välja	doc_560938275462_item	2732741	et	4	main
pean	doc_560938275462_item	2732745	et	4	main
vaadata	doc_560938275462_item	2732752	et	4	main
mulle	doc_560938275462_item	2732756	et	4	main
andsite	doc_560938275462_item	2732757	et	3	main
videomakk	doc_560938275462_item	2732758	et	3	main
kirjutan	doc_560938275462_item	2732721	et	3	main
seminaritööd	doc_560938275462_item	2732723	et	4	main
vaadata	doc_560938275462_item	2732727	et	4	main
tõlkeid	doc_560938275462_item	2732729	et	3	main
saadan	doc_560938275462_item	2732731	et	4	main
et	doc_560938275462_item	2732736	et	3	main
saan	doc_560938275462_item	2732738	et	4	main
kolmapäeval	doc_560938275462_item	2732744	et	3	main
selle	doc_560938275462_item	2732747	et	4	main
kassetti	doc_560938275462_item	2732753	et	4	main
te	doc_560938275462_item	2732755	et	4	main
ensv	doc_568696801174_item	2733049	et	4	main
ühiskonnakorralduses	doc_568696801174_item	2733050	et	3	main
ja	doc_568696801174_item	2733051	et	3	main
majanduses	doc_568696801174_item	2733052	et	4	main
sulast	doc_568696801174_item	2733062	et	4	main
1	doc_568696801174_item	2733063	et	2	main
25081940	doc_568696801174_item	2733064	et	2	main
nimetati	doc_568696801174_item	2733067	et	4	main
ülemkogu	doc_568696801174_item	2733070	et	4	main
poliitiline	doc_568696801174_item	2733076	et	3	main
liider	doc_568696801174_item	2733077	et	3	main
ensv-l	doc_568696801174_item	2733084	et	3	main
oma	doc_568696801174_item	2733086	et	4	main
sõjavägi	doc_568696801174_item	2733089	et	3	main
stalinismi	doc_568696801174_item	2733109	et	4	main
ensv	doc_568696801174_item	2733119	et	4	main
tugevnesid	doc_568696801174_item	2733122	et	4	main
võimu	doc_568696801174_item	2733124	et	4	main
haridussüsteemi	doc_568696801174_item	2733135	et	4	main
ja	doc_568696801174_item	2733136	et	3	main
kuulutati	doc_568696801174_item	2733145	et	4	main
vastlapäevast	doc_560938275462_item	2732722	et	4	main
palun	doc_560938275462_item	2732724	et	3	main
minu	doc_560938275462_item	2732728	et	3	main
kogu	doc_560938275462_item	2732733	et	4	main
kuna	doc_560938275462_item	2732743	et	3	main
saanud	doc_560938275462_item	2732751	et	4	main
mille	doc_560938275462_item	2732754	et	3	main
tänan	doc_560938275462_item	2732761	et	3	main
ametlik	doc_560938275462_item	2732715	et	3	main
kiri	doc_560938275462_item	2732716	et	3	main
lg	doc_560938275462_item	2732717	et	4	main
m	doc_560938275462_item	2732718	et	4	main
k	doc_560938275462_item	2732719	et	4	main
ma	doc_560938275462_item	2732720	et	3	main
läbi	doc_560938275462_item	2732726	et	4	main
esmaspäeval	doc_560938275462_item	2732730	et	3	main
printida	doc_560938275462_item	2732742	et	3	main
viima	doc_560938275462_item	2732746	et	3	main
rikkis	doc_560938275462_item	2732760	et	3	main
teid	doc_560938275462_item	2732725	et	4	main
loodan	doc_560938275462_item	2732735	et	3	main
teisipäeval	doc_560938275462_item	2732737	et	3	main
juba	doc_560938275462_item	2732739	et	3	main
õppetooli	doc_560938275462_item	2732748	et	4	main
kahjuks	doc_560938275462_item	2732749	et	4	main
ei	doc_560938275462_item	2732750	et	4	main
on	doc_560938275462_item	2732759	et	4	main
kui	doc_568696801174_item	2733056	et	3	main
ümber	doc_568696801174_item	2733068	et	3	main
oli	doc_568696801174_item	2733078	et	3	main
lubati	doc_568696801174_item	2733091	et	3	main
rõhutatud	doc_568696801174_item	2733094	et	4	main
kolhoseerimise	doc_568696801174_item	2733095	et	4	main
a	doc_568696801174_item	2733104	et	4	main
suunas	doc_568696801174_item	2733110	et	4	main
osalt	doc_568696801174_item	2733111	et	4	main
on	doc_568696801174_item	2733112	et	4	main
see	doc_568696801174_item	2733113	et	3	main
algaski	doc_568696801174_item	2733129	et	4	main
pealetungiga	doc_568696801174_item	2733130	et	4	main
poolt	doc_568696801174_item	2733139	et	4	main
akadeemia	doc_568696801174_item	2733152	et	4	main
süvenes	doc_568696801174_item	2733158	et	3	main
stalinlik	doc_568696801174_item	2733206	et	4	main
võte	doc_568696801174_item	2733207	et	3	main
1950	doc_568696801174_item	2733208	et	2	main
siberisse	doc_568696801174_item	2733225	et	4	main
ülejaanud	doc_568696801174_item	2733227	et	4	main
hirmuga	doc_568696801174_item	2733228	et	3	main
kolhoosidesse	doc_568696801174_item	2733229	et	3	main
hävitatud	doc_568696801174_item	2733240	et	4	main
ja	doc_568696801174_item	2733241	et	3	main
raskemaid	doc_568696801174_item	2733251	et	4	main
aegu	doc_568696801174_item	2733252	et	4	main
senises	doc_568696801174_item	2733254	et	3	main
rahva	doc_568696801174_item	2733256	et	3	main
juhtimissüsteemide	doc_568696801174_item	2733261	et	3	main
eestis	doc_568696801174_item	2733263	et	3	main
jätkus	doc_568696801174_item	2733264	et	4	main
nii	doc_568696801174_item	2733268	et	3	main
ensv	doc_568696801174_item	2733270	et	4	main
partei	doc_568696801174_item	2733272	et	4	main
pidasid	doc_568696801174_item	2733278	et	4	main
põhiliselt	doc_568696801174_item	2733287	et	4	main
927049	doc_568696801174_item	2733292	et	2	main
242022	doc_568696801174_item	2733296	et	2	main
ha	doc_568696801174_item	2733297	et	4	main
ev	doc_568696801174_item	2733047	et	4	main
ja	doc_568696801174_item	2733048	et	3	main
mõeldakse	doc_568696801174_item	2733055	et	3	main
nn	doc_568696801174_item	2733060	et	4	main
hrustshovi	doc_568696801174_item	2733061	et	4	main
vares-barbarus	doc_568696801174_item	2733075	et	4	main
lauristin	doc_568696801174_item	2733080	et	4	main
muudeti	doc_568696801174_item	2733082	et	3	main
oli	doc_568696801174_item	2733085	et	3	main
välisministeerium	doc_568696801174_item	2733087	et	3	main
amnestiat	doc_568696801174_item	2733092	et	3	main
ei	doc_568696801174_item	2733093	et	4	main
sundust	doc_568696801174_item	2733096	et	4	main
traditsioone	doc_568696801174_item	2733102	et	3	main
toimus	doc_568696801174_item	2733105	et	3	main
märgatav	doc_568696801174_item	2733107	et	4	main
murrang	doc_568696801174_item	2733108	et	3	main
tugevneva	doc_568696801174_item	2733117	et	4	main
stalinismiga	doc_568696801174_item	2733118	et	4	main
koostatud	doc_568696801174_item	2733140	et	4	main
õpikud	doc_568696801174_item	2733141	et	3	main
üha	doc_568696801174_item	2733142	et	3	main
eesti	doc_568696801174_item	2733150	et	4	main
poliitiline	doc_568696801174_item	2733165	et	3	main
majanduslik	doc_568696801174_item	2733166	et	3	main
sotsiaalne	doc_568696801174_item	2733167	et	3	main
ülejaanud	doc_568696801174_item	2733171	et	4	main
liiduga	doc_568696801174_item	2733173	et	3	main
ensv	doc_568696801174_item	2733203	et	4	main
eesti	doc_568696801174_item	2733212	et	4	main
paljusid	doc_568696801174_item	2733214	et	3	main
vapustusi	doc_568696801174_item	2733215	et	4	main
enam-vähem	doc_568696801174_item	2733216	et	3	main
samal	doc_568696801174_item	2733217	et	3	main
tasemel	doc_568696801174_item	2733218	et	3	main
kui	doc_568696801174_item	2733219	et	3	main
ensv	doc_568696801174_item	2733220	et	4	main
1	doc_568696801174_item	2733042	et	2	main
välja	doc_568696801174_item	2733044	et	4	main
peamised	doc_568696801174_item	2733045	et	3	main
erinevused	doc_568696801174_item	2733046	et	4	main
mida	doc_568696801174_item	2733054	et	4	main
kutluuriajaloos	doc_568696801174_item	2733058	et	4	main
a	doc_568696801174_item	2733065	et	4	main
j	doc_568696801174_item	2733074	et	4	main
j	doc_568696801174_item	2733079	et	4	main
mensavendadele	doc_568696801174_item	2733090	et	4	main
1947-1948	doc_568696801174_item	2733103	et	2	main
eesti	doc_568696801174_item	2733106	et	4	main
murrang	doc_568696801174_item	2733114	et	3	main
seotud	doc_568696801174_item	2733115	et	4	main
üha	doc_568696801174_item	2733116	et	3	main
liidus	doc_568696801174_item	2733120	et	4	main
kontrolltöö	doc_568696801174_item	2733041	et	4	main
tooge	doc_568696801174_item	2733043	et	3	main
2	doc_568696801174_item	2733053	et	2	main
ensv	doc_568696801174_item	2733057	et	4	main
kõneldakse	doc_568696801174_item	2733059	et	3	main
riigikogu	doc_568696801174_item	2733066	et	4	main
ensv	doc_568696801174_item	2733069	et	4	main
presiidiumi	doc_568696801174_item	2733071	et	4	main
esimees	doc_568696801174_item	2733072	et	4	main
oli	doc_568696801174_item	2733073	et	3	main
omavalitsused	doc_568696801174_item	2733081	et	3	main
täitevkomiteediteks	doc_568696801174_item	2733083	et	4	main
ja	doc_568696801174_item	2733088	et	3	main
üldine	doc_568696801174_item	2733097	et	4	main
kultuuripoliitika	doc_568696801174_item	2733098	et	4	main
järgis	doc_568696801174_item	2733099	et	4	main
eesti	doc_568696801174_item	2733100	et	4	main
vabariigi	doc_568696801174_item	2733101	et	3	main
teisalt	doc_568696801174_item	2733121	et	4	main
eesti	doc_568696801174_item	2733131	et	4	main
kultuurielule	doc_568696801174_item	2733132	et	3	main
kritiseeriti	doc_568696801174_item	2733133	et	3	main
senist	doc_568696801174_item	2733134	et	3	main
enam	doc_568696801174_item	2733143	et	4	main
raamatuid	doc_568696801174_item	2733144	et	3	main
teaduse	doc_568696801174_item	2733151	et	3	main
ensv	doc_568696801174_item	2733154	et	4	main
ta-le	doc_568696801174_item	2733156	et	3	main
sotsialistikud	doc_568696801174_item	2733159	et	4	main
ümberkorraldused	doc_568696801174_item	2733160	et	3	main
stalinistide	doc_568696801174_item	2733161	et	4	main
eesmärgiks	doc_568696801174_item	2733162	et	3	main
oli	doc_568696801174_item	2733163	et	3	main
tasalülitamine	doc_568696801174_item	2733170	et	3	main
1950	doc_568696801174_item	2733174	et	2	main
a	doc_568696801174_item	2733175	et	4	main
oli	doc_568696801174_item	2733201	et	3	main
juba	doc_568696801174_item	2733202	et	3	main
a	doc_568696801174_item	2733209	et	4	main
liit	doc_568696801174_item	2733221	et	3	main
laostunud	doc_568696801174_item	2733233	et	4	main
metsavahendus	doc_568696801174_item	2733234	et	3	main
eesti	doc_568696801174_item	2733243	et	4	main
kahtlemata	doc_568696801174_item	2733250	et	4	main
kogu	doc_568696801174_item	2733253	et	4	main
eesti	doc_568696801174_item	2733255	et	4	main
ajaloos	doc_568696801174_item	2733257	et	4	main
industrialiseerimine	doc_568696801174_item	2733265	et	4	main
ja	doc_568696801174_item	2733274	et	3	main
õigeks	doc_568696801174_item	2733277	et	3	main
kasutamine	doc_568696801174_item	2733283	et	4	main
aga	doc_568696801174_item	2733285	et	3	main
moskvas	doc_568696801174_item	2733288	et	4	main
kõneldakse	doc_568696801174_item	2733304	et	3	main
mõeldakse	doc_568696801174_item	2733309	et	3	main
hakkas	doc_568696801174_item	2733312	et	3	main
paremini	doc_568696801174_item	2733314	et	4	main
parteisse	doc_568696801174_item	2733321	et	3	main
ungaris	doc_568696801174_item	2733325	et	4	main
siis	doc_568696801174_item	2733326	et	3	main
eestlaste	doc_568696801174_item	2733329	et	4	main
et	doc_568696801174_item	2733335	et	3	main
mida	doc_568696801175_item	2733354	et	4	main
kui	doc_568696801175_item	2733356	et	3	main
2	doc_568696801175_item	2733363	et	2	main
näiteks	doc_568696801175_item	2733368	et	4	main
kirin	doc_568696801175_item	2733395	et	3	main
vabamaj	doc_568696801175_item	2733403	et	4	main
vajadustele	doc_568696801175_item	2733406	et	4	main
eraomand	doc_568696801175_item	2733407	et	3	main
ja	doc_568696801175_item	2733413	et	3	main
jäi	doc_568696801175_item	2733419	et	3	main
võõrtööjõudu	doc_568696801175_item	2733422	et	4	main
väga	doc_568696801175_item	2733424	et	3	main
spetsiifilistel	doc_568696801175_item	2733425	et	3	main
välislektorid	doc_568696801175_item	2733428	et	3	main
lihtsalt	doc_568696801175_item	2733433	et	4	main
ei	doc_568696801175_item	2733434	et	4	main
vahel	doc_568696801175_item	2733440	et	4	main
juhte	doc_568696801175_item	2733444	et	4	main
nõukogude	doc_568696801174_item	2733123	et	3	main
positsioonid	doc_568696801174_item	2733125	et	3	main
eestis	doc_568696801174_item	2733126	et	3	main
stalinistide	doc_568696801174_item	2733127	et	4	main
rünnak	doc_568696801174_item	2733128	et	3	main
eesti	doc_568696801174_item	2733137	et	4	main
autorite	doc_568696801174_item	2733138	et	3	main
allutati	doc_568696801174_item	2733153	et	3	main
liidu	doc_568696801174_item	2733155	et	3	main
majanduses	doc_568696801174_item	2733157	et	4	main
ja	doc_568696801174_item	2733168	et	3	main
algul	doc_568696801174_item	2733176	et	4	main
teravnesid	doc_568696801174_item	2733177	et	4	main
inimestevahelised	doc_568696801174_item	2733178	et	4	main
suhted	doc_568696801174_item	2733179	et	3	main
levis	doc_568696801174_item	2733180	et	4	main
hirm	doc_568696801174_item	2733181	et	3	main
süvenes	doc_568696801174_item	2733182	et	3	main
kahlustamine	doc_568696801174_item	2733183	et	4	main
sagenes	doc_568696801174_item	2733184	et	3	main
pealekabamine	doc_568696801174_item	2733185	et	3	main
klaariti	doc_568696801174_item	2733186	et	3	main
vanu	doc_568696801174_item	2733187	et	4	main
arveid	doc_568696801174_item	2733188	et	3	main
riigivõimu	doc_568696801174_item	2733189	et	4	main
teadmisel	doc_568696801174_item	2733190	et	4	main
ja	doc_568696801174_item	2733191	et	3	main
koguni	doc_568696801174_item	2733192	et	4	main
soosimisel	doc_568696801174_item	2733193	et	4	main
ässitati	doc_568696801174_item	2733194	et	3	main
inimeste	doc_568696801174_item	2733196	et	3	main
terveid	doc_568696801174_item	2733195	et	4	main
gruppe	doc_568696801174_item	2733197	et	3	main
üksteise	doc_568696801174_item	2733198	et	4	main
vastu	doc_568696801174_item	2733199	et	3	main
seegi	doc_568696801174_item	2733200	et	4	main
kõlbmatuks	doc_568696801174_item	2733146	et	3	main
ja	doc_568696801174_item	2733147	et	3	main
kõrvaldati	doc_568696801174_item	2733148	et	3	main
käibet	doc_568696801174_item	2733149	et	4	main
eesti	doc_568696801174_item	2733164	et	4	main
kultuuriline	doc_568696801174_item	2733169	et	4	main
ensv	doc_568696801174_item	2733172	et	4	main
liidus	doc_568696801174_item	2733204	et	4	main
oli	doc_568696801174_item	2733211	et	3	main
astunud	doc_568696801174_item	2733230	et	4	main
ja	doc_568696801174_item	2733231	et	3	main
need	doc_568696801174_item	2733232	et	3	main
sisuselt	doc_568696801174_item	2733236	et	4	main
oli	doc_568696801174_item	2733237	et	3	main
eesti	doc_568696801174_item	2733238	et	4	main
tsiviilühiskond	doc_568696801174_item	2733239	et	3	main
ensv	doc_568696801174_item	2733258	et	4	main
liidu	doc_568696801174_item	2733259	et	3	main
tsentraliseeritud	doc_568696801174_item	2733260	et	4	main
nagu	doc_568696801174_item	2733269	et	3	main
liidu	doc_568696801174_item	2733271	et	3	main
ümberjaotumine	doc_568696801174_item	2733284	et	3	main
1944-1947	doc_568696801174_item	2733290	et	2	main
ha	doc_568696801174_item	2733293	et	4	main
milles	doc_568696801174_item	2733295	et	3	main
kultuuriajaloost	doc_568696801174_item	2733303	et	4	main
nn	doc_568696801174_item	2733305	et	4	main
hrustshovi	doc_568696801174_item	2733306	et	4	main
kommun	doc_568696801174_item	2733320	et	4	main
äraproovitud	doc_568696801174_item	2733205	et	4	main
alguseks	doc_568696801174_item	2733210	et	4	main
pärast	doc_568696801174_item	2733213	et	4	main
iseseisvad	doc_568696801174_item	2733222	et	3	main
põllumehed	doc_568696801174_item	2733223	et	3	main
küüditatud	doc_568696801174_item	2733226	et	4	main
nõrgenes	doc_568696801174_item	2733235	et	3	main
katastroofi	doc_568696801174_item	2733244	et	4	main
oon	doc_568696801174_item	2733249	et	4	main
sõjajärgsel	doc_568696801174_item	2733266	et	3	main
majanduslikud	doc_568696801174_item	2733275	et	3	main
keskorganid	doc_568696801174_item	2733276	et	3	main
loodud	doc_568696801174_item	2733281	et	4	main
väärtuste	doc_568696801174_item	2733282	et	4	main
ensv-s	doc_568696801174_item	2733291	et	3	main
maad	doc_568696801174_item	2733294	et	4	main
põldu	doc_568696801174_item	2733299	et	4	main
2	doc_568696801174_item	2733300	et	2	main
kui	doc_568696801174_item	2733301	et	3	main
et	doc_568696801174_item	2733310	et	3	main
kõik	doc_568696801174_item	2733311	et	4	main
minema	doc_568696801174_item	2733313	et	3	main
ja	doc_568696801174_item	2733315	et	3	main
kergemini	doc_568696801174_item	2733316	et	4	main
inimesed	doc_568696801174_item	2733317	et	3	main
astusid	doc_568696801174_item	2733318	et	4	main
omatahtel	doc_568696801174_item	2733319	et	3	main
1956	doc_568696801174_item	2733322	et	2	main
eestlased	doc_568696801174_item	2733332	et	3	main
said	doc_568696801174_item	2733333	et	4	main
saa	doc_568696801174_item	2733340	et	4	main
välja	doc_568696801175_item	2733344	et	4	main
peamised	doc_568696801175_item	2733345	et	3	main
2	doc_568696801175_item	2733353	et	2	main
sulast	doc_568696801175_item	2733362	et	4	main
vabamaks	doc_568696801175_item	2733367	et	4	main
rehalibiteeriti	doc_568696801175_item	2733369	et	4	main
stalini	doc_568696801175_item	2733370	et	4	main
ajal	doc_568696801175_item	2733371	et	4	main
liitudest	doc_568696801175_item	2733372	et	3	main
sattus	doc_568696801175_item	2733396	et	3	main
eesti	doc_568696801175_item	2733401	et	4	main
oma	doc_568696801175_item	2733415	et	4	main
kui	doc_568696801175_item	2733417	et	3	main
olid	doc_568696801174_item	2733224	et	4	main
terve	doc_568696801174_item	2733242	et	4	main
äärel	doc_568696801174_item	2733245	et	3	main
1940-1950	doc_568696801174_item	2733246	et	2	main
a	doc_568696801174_item	2733247	et	4	main
vahetus	doc_568696801174_item	2733248	et	4	main
allutatud	doc_568696801174_item	2733262	et	4	main
perioodil	doc_568696801174_item	2733267	et	3	main
ladvik	doc_568696801174_item	2733273	et	3	main
sel	doc_568696801174_item	2733279	et	3	main
teel	doc_568696801174_item	2733280	et	4	main
otsustati	doc_568696801174_item	2733286	et	3	main
aastal	doc_568696801174_item	2733289	et	3	main
ensv	doc_568696801174_item	2733302	et	4	main
sulast	doc_568696801174_item	2733307	et	4	main
süsteemist	doc_568696801174_item	2733331	et	4	main
ev	doc_568696801174_item	2733336	et	4	main
hiljem	doc_568696801174_item	2733338	et	3	main
ev	doc_568696801175_item	2733347	et	4	main
ja	doc_568696801175_item	2733348	et	3	main
ensv	doc_568696801175_item	2733349	et	4	main
ühiskonnakorralduses	doc_568696801175_item	2733350	et	3	main
ja	doc_568696801175_item	2733351	et	3	main
mõeldakse	doc_568696801175_item	2733355	et	3	main
ensv	doc_568696801175_item	2733357	et	4	main
muutus	doc_568696801175_item	2733365	et	4	main
suits	doc_568696801175_item	2733394	et	3	main
mees	doc_568696801175_item	2733409	et	4	main
haris	doc_568696801175_item	2733410	et	3	main
mille	doc_568696801175_item	2733430	et	3	main
võitlus	doc_568696801175_item	2733437	et	3	main
oma	doc_568696801175_item	2733443	et	4	main
ise	doc_568696801175_item	2733445	et	4	main
valida	doc_568696801175_item	2733446	et	3	main
ja	doc_568696801175_item	2733451	et	3	main
kes	doc_568696801175_item	2733479	et	4	main
kommunismi	doc_568696801175_item	2733481	et	4	main
poole	doc_568696801175_item	2733482	et	4	main
muutusid	doc_568696801175_item	2733488	et	4	main
maakond	doc_568696801175_item	2733489	et	3	main
rajoon	doc_568696801175_item	2733490	et	3	main
kuressaare	doc_568696801175_item	2733491	et	4	main
kingissepa	doc_568696801175_item	2733492	et	3	main
viktor	doc_568696801175_item	2733493	et	4	main
kingissepa	doc_568696801175_item	2733494	et	3	main
auks	doc_568696801175_item	2733495	et	3	main
tootma	doc_568696801175_item	2733518	et	3	main
hea	doc_568696801175_item	2733519	et	4	main
ettenähtud	doc_568696801175_item	2733522	et	4	main
üle	doc_568696801175_item	2733524	et	3	main
tootmine	doc_568696801175_item	2733525	et	4	main
riigiomand	doc_568696801175_item	2733526	et	3	main
natsionaliseeriti	doc_568696801175_item	2733527	et	3	main
sohvooside	doc_568696801175_item	2733538	et	4	main
kõik	doc_568696801175_item	2733546	et	4	main
tuleb	doc_568696801175_item	2733547	et	3	main
anda	doc_568696801175_item	2733548	et	3	main
ühisomandisse	doc_568696801175_item	2733549	et	3	main
sisse	doc_568696801175_item	2733561	et	4	main
lihtrahva	doc_568696801175_item	2733577	et	3	main
oli	doc_568696801174_item	2733298	et	3	main
sis	doc_568696801174_item	2733308	et	3	main
sündmused	doc_568696801174_item	2733324	et	3	main
võib	doc_568696801174_item	2733327	et	3	main
teada	doc_568696801174_item	2733334	et	3	main
erinevused	doc_568696801175_item	2733346	et	4	main
hrustshovi	doc_568696801175_item	2733361	et	4	main
veidi	doc_568696801175_item	2733366	et	3	main
alla	doc_568696801175_item	2733398	et	3	main
1	doc_568696801175_item	2733399	et	2	main
kroon	doc_568696801175_item	2733402	et	3	main
vastavalt	doc_568696801175_item	2733405	et	4	main
iga	doc_568696801175_item	2733408	et	4	main
kasvatas	doc_568696801175_item	2733414	et	3	main
üle	doc_568696801175_item	2733418	et	3	main
siis	doc_568696801175_item	2733420	et	3	main
müüs	doc_568696801175_item	2733421	et	4	main
kasutati	doc_568696801175_item	2733423	et	4	main
erialadel	doc_568696801175_item	2733426	et	3	main
näit	doc_568696801175_item	2733427	et	3	main
demokraatia	doc_568696801175_item	2733436	et	4	main
parteid	doc_568696801175_item	2733447	et	4	main
tegelevad	doc_568696801175_item	2733448	et	4	main
poliitikaga	doc_568696801175_item	2733452	et	3	main
võimalused	doc_568696801175_item	2733454	et	3	main
loeb	doc_568696801175_item	2733457	et	3	main
viisnurk	doc_568696801175_item	2733476	et	3	main
kogu	doc_568696801175_item	2733506	et	4	main
nsvl-s	doc_568696801175_item	2733507	et	3	main
kehtinud	doc_568696801175_item	2733508	et	4	main
palju	doc_568696801175_item	2733516	et	4	main
tehaseid	doc_568696801175_item	2733530	et	3	main
olev	doc_568696801175_item	2733540	et	4	main
majand	doc_568696801175_item	2733541	et	3	main
loomine	doc_568696801175_item	2733542	et	4	main
inimesed	doc_568696801175_item	2733543	et	3	main
muudeti	doc_568696801175_item	2733544	et	3	main
kaasa	doc_568696801175_item	2733553	et	4	main
nii	doc_568696801175_item	2733554	et	3	main
võõrtööjõu	doc_568696801175_item	2733560	et	3	main
seoses	doc_568696801175_item	2733565	et	4	main
energeetika	doc_568696801175_item	2733566	et	4	main
rasketööstuse	doc_568696801175_item	2733567	et	3	main
arenguga	doc_568696801175_item	2733568	et	3	main
eestis	doc_568696801175_item	2733569	et	3	main
ümberasustamine	doc_568696801175_item	2733570	et	3	main
haritlased	doc_568696801175_item	2733571	et	3	main
küüditati	doc_568696801175_item	2733572	et	3	main
siberisse	doc_568696801175_item	2733573	et	4	main
rahva	doc_568696801175_item	2733574	et	3	main
arv	doc_568696801175_item	2733575	et	3	main
väheneb	doc_568696801175_item	2733576	et	3	main
praktiliselt	doc_568696801175_item	2733603	et	4	main
kõigega	doc_568696801175_item	2733604	et	3	main
inimeste	doc_568696801175_item	2733605	et	3	main
isikliku	doc_568696801175_item	2733606	et	3	main
eluga	doc_568696801175_item	2733607	et	3	main
majandusega	doc_568696801175_item	2733608	et	4	main
tohtinud	doc_568696801175_item	2733613	et	4	main
teha	doc_568696801175_item	2733614	et	3	main
eelised	doc_568696801175_item	2733618	et	4	main
partei	doc_568696801175_item	2733619	et	4	main
liikmetele	doc_568696801175_item	2733620	et	3	main
minevaga	doc_568696801175_item	2733631	et	4	main
loeb	doc_568696801175_item	2733632	et	3	main
rasketööstuse	doc_568696801175_item	2733636	et	3	main
energeetika	doc_568696801175_item	2733641	et	4	main
malevad	doc_568696801175_item	2733650	et	3	main
kontrolltöö	doc_568696801176_item	2733653	et	4	main
tooge	doc_568696801176_item	2733655	et	3	main
ühiskonnakorralduses	doc_568696801176_item	2733662	et	3	main
kutluuriajaloos	doc_568696801176_item	2733670	et	4	main
ev	doc_568696801176_item	2733676	et	4	main
planeerimine	doc_568696801176_item	2733688	et	4	main
asutused	doc_568696801176_item	2733705	et	4	main
pidid	doc_568696801176_item	2733706	et	4	main
jätkunud	doc_568696801176_item	2733717	et	4	main
kõik	doc_568696801176_item	2733718	et	4	main
kõik	doc_568696801176_item	2733728	et	4	main
pangad	doc_568696801176_item	2733729	et	3	main
a	doc_568696801174_item	2733323	et	4	main
rääkida	doc_568696801174_item	2733328	et	3	main
kohanemise	doc_568696801174_item	2733330	et	4	main
taastada	doc_568696801174_item	2733337	et	3	main
ei	doc_568696801174_item	2733339	et	4	main
kontrolltöö	doc_568696801175_item	2733341	et	4	main
1	doc_568696801175_item	2733342	et	2	main
tooge	doc_568696801175_item	2733343	et	3	main
majanduses	doc_568696801175_item	2733352	et	4	main
kutluuriajaloos	doc_568696801175_item	2733358	et	4	main
kõneldakse	doc_568696801175_item	2733359	et	3	main
nn	doc_568696801175_item	2733360	et	4	main
kord	doc_568696801175_item	2733364	et	4	main
eu	doc_568696801175_item	2733373	et	4	main
välja	doc_568696801175_item	2733374	et	4	main
heidetud	doc_568696801175_item	2733375	et	4	main
kirjanikke	doc_568696801175_item	2733376	et	3	main
ja	doc_568696801175_item	2733377	et	3	main
muid	doc_568696801175_item	2733378	et	4	main
kunstiinimesi	doc_568696801175_item	2733379	et	4	main
said	doc_568696801175_item	2733380	et	4	main
oma	doc_568696801175_item	2733381	et	4	main
staatuse	doc_568696801175_item	2733382	et	3	main
tagasi	doc_568696801175_item	2733383	et	3	main
mõningaid	doc_568696801175_item	2733384	et	3	main
stalini	doc_568696801175_item	2733385	et	4	main
ajal	doc_568696801175_item	2733386	et	4	main
keelatud	doc_568696801175_item	2733387	et	4	main
raamatuid	doc_568696801175_item	2733388	et	3	main
tohtis	doc_568696801175_item	2733389	et	3	main
jälle	doc_568696801175_item	2733390	et	3	main
lugeda	doc_568696801175_item	2733391	et	3	main
under	doc_568696801175_item	2733392	et	4	main
ja	doc_568696801175_item	2733393	et	3	main
löögi	doc_568696801175_item	2733397	et	4	main
ev	doc_568696801175_item	2733400	et	4	main
toodetakse	doc_568696801175_item	2733404	et	3	main
oma	doc_568696801175_item	2733411	et	4	main
põldu	doc_568696801175_item	2733412	et	4	main
loomi	doc_568696801175_item	2733416	et	4	main
erialadel	doc_568696801175_item	2733429	et	3	main
eesti	doc_568696801175_item	2733432	et	4	main
olnud	doc_568696801175_item	2733435	et	4	main
rahvas	doc_568696801175_item	2733441	et	4	main
saab	doc_568696801175_item	2733442	et	3	main
riigiasjade	doc_568696801175_item	2733450	et	3	main
kodanikele	doc_568696801175_item	2733456	et	3	main
tööliste	doc_568696801175_item	2733471	et	4	main
verd	doc_568696801175_item	2733472	et	3	main
ja	doc_568696801175_item	2733473	et	3	main
sinna	doc_568696801175_item	2733474	et	3	main
tekkis	doc_568696801175_item	2733475	et	3	main
läbi	doc_568696801175_item	2733484	et	4	main
haldusreform	doc_568696801175_item	2733485	et	3	main
vald	doc_568696801175_item	2733496	et	3	main
noorkotkad	doc_568696801175_item	2733502	et	3	main
leerimine	doc_568696801175_item	2733504	et	4	main
ensv	doc_568696801175_item	2733505	et	4	main
spetsialiste	doc_568696801175_item	2733431	et	3	main
mitme	doc_568696801175_item	2733438	et	4	main
partei	doc_568696801175_item	2733439	et	4	main
ainult	doc_568696801175_item	2733449	et	4	main
ühesugund	doc_568696801175_item	2733453	et	4	main
kõigile	doc_568696801175_item	2733455	et	4	main
raha	doc_568696801175_item	2733458	et	4	main
101-liikmeline	doc_568696801175_item	2733459	et	4	main
riigikogu	doc_568696801175_item	2733460	et	4	main
riigi	doc_568696801175_item	2733461	et	3	main
sümboolika	doc_568696801175_item	2733462	et	4	main
muutus	doc_568696801175_item	2733463	et	4	main
lipu	doc_568696801175_item	2733464	et	3	main
tausta	doc_568696801175_item	2733465	et	4	main
värviks	doc_568696801175_item	2733466	et	4	main
sai	doc_568696801175_item	2733467	et	4	main
punane	doc_568696801175_item	2733468	et	4	main
mis	doc_568696801175_item	2733469	et	4	main
sümboliseeris	doc_568696801175_item	2733470	et	4	main
maailmajaod	doc_568696801175_item	2733478	et	3	main
eesti	doc_568696801175_item	2733486	et	4	main
piirid	doc_568696801175_item	2733487	et	3	main
külanõukogu	doc_568696801175_item	2733497	et	4	main
ümbernimetamine	doc_568696801175_item	2733499	et	3	main
skaudid	doc_568696801175_item	2733501	et	3	main
peab	doc_568696801175_item	2733517	et	4	main
on	doc_568696801175_item	2733521	et	4	main
vabrikuid	doc_568696801175_item	2733529	et	3	main
riigitoetusel	doc_568696801175_item	2733539	et	4	main
mis	doc_568696801175_item	2733550	et	4	main
tegelikkuses	doc_568696801175_item	2733551	et	4	main
tõi	doc_568696801175_item	2733552	et	3	main
massiline	doc_568696801175_item	2733559	et	4	main
jne	doc_568696801175_item	2733609	et	4	main
ilma	doc_568696801175_item	2733615	et	4	main
tuusikud	doc_568696801175_item	2733622	et	3	main
sots	doc_568696801175_item	2733623	et	3	main
positsioon	doc_568696801175_item	2733633	et	3	main
põlevkivitööstuse	doc_568696801175_item	2733639	et	3	main
venemaale	doc_568696801175_item	2733646	et	4	main
ev	doc_568696801176_item	2733659	et	4	main
ja	doc_568696801176_item	2733660	et	3	main
nn	doc_568696801176_item	2733672	et	4	main
sulast	doc_568696801176_item	2733674	et	4	main
eesti	doc_568696801176_item	2733680	et	4	main
nõukogude	doc_568696801176_item	2733681	et	3	main
majanduses	doc_568696801176_item	2733687	et	4	main
rangelt	doc_568696801176_item	2733691	et	4	main
planeeritud	doc_568696801176_item	2733692	et	4	main
maht	doc_568696801176_item	2733694	et	3	main
tehased	doc_568696801176_item	2733710	et	3	main
kinni	doc_568696801176_item	2733712	et	3	main
sest	doc_568696801176_item	2733714	et	4	main
töölisi	doc_568696801176_item	2733715	et	3	main
ei	doc_568696801176_item	2733716	et	4	main
olid	doc_568696801176_item	2733720	et	4	main
riigistanud	doc_568696801176_item	2733721	et	4	main
natsionaliseeritud	doc_568696801176_item	2733723	et	4	main
olid	doc_568696801176_item	2733732	et	4	main
forseerima	doc_568696801176_item	2733738	et	4	main
rasketööstust	doc_568696801176_item	2733739	et	4	main
ja	doc_568696801176_item	2733740	et	3	main
toetas	doc_568696801176_item	2733741	et	3	main
kosmonautikat	doc_568696801176_item	2733742	et	4	main
paljud	doc_568696801176_item	2733743	et	3	main
teadusharud	doc_568696801176_item	2733744	et	3	main
geneetika	doc_568696801176_item	2733749	et	4	main
jõukamad	doc_568696801176_item	2733758	et	4	main
allusid	doc_568696801176_item	2733774	et	4	main
kõik	doc_568696801176_item	2733775	et	4	main
olid	doc_568696801176_item	2733779	et	4	main
vastu	doc_568696801176_item	2733781	et	3	main
seda	doc_568696801176_item	2733791	et	3	main
olid	doc_568696801176_item	2733805	et	4	main
ka	doc_568696801176_item	2733806	et	3	main
varustama	doc_568696801176_item	2733810	et	3	main
sellepärast	doc_568696801176_item	2733814	et	3	main
nk	doc_568696801176_item	2733821	et	4	main
süsteemile	doc_568696801176_item	2733822	et	3	main
ensv	doc_568696801176_item	2733830	et	4	main
ülemnõukoguks	doc_568696801176_item	2733831	et	3	main
varem	doc_568696801176_item	2733832	et	4	main
komitee	doc_568696801176_item	2733841	et	4	main
peaparteiks	doc_568696801176_item	2733842	et	3	main
majandust	doc_568696801176_item	2733856	et	4	main
süsteemi	doc_568696801176_item	2733858	et	4	main
määras	doc_568696801176_item	2733860	et	4	main
maakond	doc_568696801176_item	2733879	et	3	main
muutus	doc_568696801176_item	2733880	et	4	main
piiratud	doc_568696801176_item	2733919	et	4	main
keelatud	doc_568696801176_item	2733931	et	4	main
kui	doc_568696801176_item	2733932	et	3	main
nad	doc_568696801176_item	2733933	et	3	main
ei	doc_568696801176_item	2733934	et	4	main
eesti	doc_568696801176_item	2733942	et	4	main
kokku	doc_568696801176_item	2733947	et	3	main
töölised	doc_568696801176_item	2733952	et	3	main
berio	doc_568696801176_item	2733964	et	4	main
ideede	doc_568696801176_item	2733965	et	3	main
kõik	doc_568696801175_item	2733477	et	4	main
püüdlevad	doc_568696801175_item	2733480	et	4	main
viidi	doc_568696801175_item	2733483	et	4	main
tänavanimede	doc_568696801175_item	2733498	et	3	main
gaidid	doc_568696801175_item	2733500	et	3	main
kodutütred	doc_568696801175_item	2733503	et	3	main
rubla	doc_568696801175_item	2733509	et	4	main
plaanimaj	doc_568696801175_item	2733510	et	4	main
riik	doc_568696801175_item	2733511	et	3	main
annab	doc_568696801175_item	2733512	et	3	main
ette	doc_568696801175_item	2733513	et	4	main
plaani	doc_568696801175_item	2733514	et	4	main
kui	doc_568696801175_item	2733515	et	3	main
näitaja	doc_568696801175_item	2733520	et	4	main
kõike	doc_568696801175_item	2733528	et	4	main
maad	doc_568696801175_item	2733531	et	4	main
nälgimise	doc_568696801175_item	2733558	et	4	main
21000	doc_568696801175_item	2733563	et	2	main
ei	doc_568696801175_item	2733612	et	4	main
partei	doc_568696801175_item	2733616	et	4	main
nõusolekuta	doc_568696801175_item	2733617	et	3	main
ostuload	doc_568696801175_item	2733621	et	4	main
riikidesse	doc_568696801175_item	2733624	et	3	main
lihtrahvas	doc_568696801175_item	2733626	et	4	main
ensv	doc_568696801175_item	2733634	et	4	main
teke	doc_568696801175_item	2733638	et	3	main
suvepäevad	doc_568696801175_item	2733652	et	3	main
1	doc_568696801176_item	2733654	et	2	main
ensv	doc_568696801176_item	2733661	et	4	main
ja	doc_568696801176_item	2733663	et	3	main
2	doc_568696801176_item	2733665	et	2	main
hrustshovi	doc_568696801176_item	2733673	et	4	main
1	doc_568696801176_item	2733675	et	2	main
eesti	doc_568696801176_item	2733677	et	4	main
vabariik	doc_568696801176_item	2733678	et	3	main
ensv	doc_568696801176_item	2733679	et	4	main
tööpäev	doc_568696801176_item	2733689	et	3	main
tootmise	doc_568696801176_item	2733693	et	4	main
igal	doc_568696801176_item	2733695	et	3	main
päeval	doc_568696801176_item	2733696	et	3	main
oli	doc_568696801176_item	2733697	et	3	main
riigi	doc_568696801176_item	2733698	et	3	main
seda	doc_568696801176_item	2733707	et	3	main
kogusest	doc_568696801175_item	2733523	et	4	main
loomi	doc_568696801175_item	2733532	et	4	main
jne	doc_568696801175_item	2733533	et	4	main
kolhooside	doc_568696801175_item	2733534	et	3	main
iseseisev	doc_568696801175_item	2733535	et	3	main
majand	doc_568696801175_item	2733536	et	3	main
ja	doc_568696801175_item	2733537	et	3	main
varatuteks	doc_568696801175_item	2733545	et	4	main
loomade	doc_568696801175_item	2733555	et	4	main
kui	doc_568696801175_item	2733556	et	3	main
inimeste	doc_568696801175_item	2733557	et	3	main
toomine	doc_568696801175_item	2733562	et	4	main
in	doc_568696801175_item	2733564	et	4	main
ja	doc_568696801175_item	2733578	et	3	main
venemaalt	doc_568696801175_item	2733579	et	3	main
tagasipöördunud	doc_568696801175_item	2733580	et	4	main
eestlaste	doc_568696801175_item	2733581	et	4	main
valitakse	doc_568696801175_item	2733583	et	3	main
uued	doc_568696801175_item	2733584	et	3	main
seast	doc_568696801175_item	2733582	et	4	main
juhid	doc_568696801175_item	2733585	et	4	main
tööjõu	doc_568696801175_item	2733586	et	3	main
puudus	doc_568696801175_item	2733587	et	4	main
tuuakse	doc_568696801175_item	2733588	et	3	main
sisse	doc_568696801175_item	2733589	et	4	main
võõrtööjõud	doc_568696801175_item	2733590	et	4	main
üks	doc_568696801175_item	2733591	et	3	main
partei	doc_568696801175_item	2733592	et	4	main
sinna	doc_568696801175_item	2733594	et	3	main
kas	doc_568696801175_item	2733595	et	3	main
kuuluti	doc_568696801175_item	2733596	et	4	main
ekp	doc_568696801175_item	2733593	et	4	main
või	doc_568696801175_item	2733597	et	4	main
mitte	doc_568696801175_item	2733598	et	3	main
valimised	doc_568696801175_item	2733599	et	4	main
demonstratiivsed	doc_568696801175_item	2733600	et	3	main
partei	doc_568696801175_item	2733601	et	4	main
tegeleb	doc_568696801175_item	2733602	et	3	main
ühtegi	doc_568696801175_item	2733610	et	4	main
liigutust	doc_568696801175_item	2733611	et	4	main
korterid	doc_568696801175_item	2733625	et	3	main
pidi	doc_568696801175_item	2733627	et	4	main
rahulduma	doc_568696801175_item	2733628	et	3	main
eluks	doc_568696801175_item	2733629	et	3	main
vaja	doc_568696801175_item	2733630	et	4	main
elektroonikatööstuse	doc_568696801175_item	2733637	et	3	main
oktoobrilapsed	doc_568696801175_item	2733648	et	3	main
pioneerid	doc_568696801175_item	2733649	et	3	main
noorte	doc_568696801175_item	2733651	et	3	main
kõneldakse	doc_568696801176_item	2733671	et	3	main
sotsialistlik	doc_568696801176_item	2733682	et	3	main
ensv	doc_568696801176_item	2733684	et	4	main
valitses	doc_568696801176_item	2733686	et	3	main
poolt	doc_568696801176_item	2733699	et	4	main
planeeritud	doc_568696801176_item	2733700	et	4	main
ka	doc_568696801176_item	2733701	et	3	main
tehased	doc_568696801176_item	2733702	et	3	main
ja	doc_568696801176_item	2733703	et	3	main
täitma	doc_568696801176_item	2733708	et	3	main
olid	doc_568696801176_item	2733711	et	4	main
asutused	doc_568696801176_item	2733719	et	4	main
võetud	doc_568696801176_item	2733735	et	4	main
riik	doc_568696801176_item	2733736	et	3	main
vaenlasteadusteks	doc_568696801176_item	2733746	et	4	main
sohvoosid	doc_568696801176_item	2733754	et	4	main
sinna	doc_568696801176_item	2733755	et	3	main
kasvatad	doc_568696801176_item	2733772	et	3	main
sellele	doc_568696801176_item	2733773	et	4	main
rikkusid	doc_568696801176_item	2733786	et	4	main
eesti	doc_568696801176_item	2733808	et	4	main
len	doc_568696801176_item	2733811	et	4	main
ev	doc_568696801176_item	2733824	et	4	main
ajal	doc_568696801176_item	2733825	et	4	main
oli	doc_568696801176_item	2733826	et	3	main
presiidiumi	doc_568696801176_item	2733833	et	4	main
esimeheks	doc_568696801176_item	2733834	et	3	main
oli	doc_568696801176_item	2733835	et	3	main
sai	doc_568696801176_item	2733843	et	4	main
ekвp	doc_568696801176_item	2733844	et	2	main
mis	doc_568696801176_item	2733852	et	4	main
poliitilist	doc_568696801176_item	2733857	et	3	main
valis	doc_568696801176_item	2733864	et	3	main
privileege	doc_568696801176_item	2733872	et	3	main
oli	doc_568696801176_item	2733873	et	3	main
rajooniks	doc_568696801176_item	2733881	et	4	main
vald	doc_568696801176_item	2733882	et	3	main
ülemanõukogu	doc_568696801175_item	2733635	et	4	main
ja	doc_568696801175_item	2733640	et	3	main
laienemine	doc_568696801175_item	2733642	et	4	main
seoses	doc_568696801175_item	2733643	et	4	main
elektri	doc_568696801175_item	2733644	et	3	main
tootmisega	doc_568696801175_item	2733645	et	4	main
tasuta	doc_568696801175_item	2733647	et	4	main
välja	doc_568696801176_item	2733656	et	4	main
peamised	doc_568696801176_item	2733657	et	3	main
erinevused	doc_568696801176_item	2733658	et	4	main
majanduses	doc_568696801176_item	2733664	et	4	main
mida	doc_568696801176_item	2733666	et	4	main
mõeldakse	doc_568696801176_item	2733667	et	3	main
kui	doc_568696801176_item	2733668	et	3	main
ensv	doc_568696801176_item	2733669	et	4	main
vabariik	doc_568696801176_item	2733683	et	3	main
ajal	doc_568696801176_item	2733685	et	4	main
oli	doc_568696801176_item	2733690	et	3	main
muud	doc_568696801176_item	2733704	et	4	main
paljud	doc_568696801176_item	2733709	et	3	main
pandud	doc_568696801176_item	2733713	et	4	main
eraomandust	doc_568696801176_item	2733724	et	3	main
ei	doc_568696801176_item	2733725	et	4	main
omanikutelt	doc_568696801176_item	2733733	et	4	main
küberneetika	doc_568696801176_item	2733748	et	4	main
peamiselt	doc_568696801176_item	2733757	et	4	main
inimesed	doc_568696801176_item	2733778	et	3	main
ja	doc_568696801176_item	2733782	et	3	main
riik	doc_568696801176_item	2733790	et	3	main
muutusid	doc_568696801176_item	2733795	et	4	main
riigistatud	doc_568696801176_item	2733807	et	4	main
kaevandati	doc_568696801176_item	2733815	et	3	main
põlevkivi	doc_568696801176_item	2733817	et	4	main
eesti	doc_568696801176_item	2733818	et	4	main
riigisüsteem	doc_568696801176_item	2733819	et	3	main
muutus	doc_568696801176_item	2733829	et	4	main
vares-barbarus	doc_568696801176_item	2733837	et	4	main
linnades	doc_568696801176_item	2733838	et	3	main
hakkas	doc_568696801176_item	2733854	et	3	main
ühiskondkiku	doc_568696801176_item	2733861	et	4	main
arengu	doc_568696801176_item	2733862	et	3	main
suunda	doc_568696801176_item	2733863	et	4	main
kaade	doc_568696801176_item	2733867	et	4	main
võim	doc_568696801176_item	2733869	et	3	main
majanduslikke	doc_568696801176_item	2733871	et	3	main
külanõukoguks	doc_568696801176_item	2733883	et	3	main
2	doc_568696801176_item	2733887	et	2	main
trükivabadus	doc_568696801176_item	2733917	et	4	main
oli	doc_568696801176_item	2733918	et	3	main
eesti	doc_568696801176_item	2733921	et	4	main
hävitatakse	doc_568696801176_item	2733923	et	3	main
julgeoleku	doc_568696801176_item	2733924	et	3	main
komitee	doc_568696801176_item	2733925	et	4	main
nkgb	doc_568696801176_item	2733927	et	4	main
algüksus	doc_568696801176_item	2733928	et	3	main
ajalehed	doc_568696801176_item	2733929	et	3	main
avatakse	doc_568696801176_item	2733938	et	4	main
pühapäevakoolid	doc_568696801176_item	2733939	et	3	main
kus	doc_568696801176_item	2733944	et	3	main
tulevad	doc_568696801176_item	2733951	et	4	main
muudest	doc_568696801176_item	2733953	et	4	main
püüdis	doc_568696801176_item	2733968	et	3	main
stalini	doc_568696801176_item	2733986	et	4	main
muuseumi	doc_56989259334_item	2734009	et	4	main
näha	doc_56989259334_item	2734010	et	3	main
väga	doc_56989259334_item	2734020	et	3	main
pean	doc_56989259334_item	2734030	et	4	main
ma	doc_56989259334_item	2734033	et	3	main
suvel	doc_56989259334_item	2734047	et	3	main
töötanud	doc_56989259334_item	2734061	et	4	main
aastat	doc_56989259334_item	2734067	et	3	main
minu	doc_56989259334_item	2734071	et	3	main
algul	doc_56989259334_item	2734075	et	4	main
raske	doc_56989259334_item	2734078	et	4	main
töötama	doc_56989259334_item	2734079	et	3	main
ma	doc_56989259334_item	2734080	et	3	main
mida	doc_56989259334_item	2734083	et	4	main
nendega	doc_56989259334_item	2734085	et	4	main
ja	doc_56989259334_item	2734086	et	3	main
kuidas	doc_56989259334_item	2734087	et	3	main
korvpalli	doc_56989259334_item	2734130	et	4	main
jalgpalli	doc_56989259334_item	2734131	et	4	main
sulgpalli	doc_56989259334_item	2734132	et	4	main
mängu	doc_56989259334_item	2734137	et	4	main
aga	doc_56989259334_item	2734138	et	3	main
kui	doc_56989259334_item	2734139	et	3	main
september	doc_56989259334_item	2734141	et	3	main
ülikooli	doc_56989259334_item	2734145	et	4	main
väga	doc_56989259334_item	2734161	et	3	main
tähendab	doc_568696801176_item	2733722	et	3	main
tohtinud	doc_568696801176_item	2733726	et	4	main
olla	doc_568696801176_item	2733727	et	3	main
ära	doc_568696801176_item	2733734	et	4	main
olid	doc_568696801176_item	2733745	et	4	main
hakkasid	doc_568696801176_item	2733750	et	4	main
tekkima	doc_568696801176_item	2733751	et	3	main
kolhoosid	doc_568696801176_item	2733752	et	3	main
ja	doc_568696801176_item	2733753	et	3	main
inimesed	doc_568696801176_item	2733759	et	3	main
sest	doc_568696801176_item	2733760	et	4	main
nad	doc_568696801176_item	2733761	et	3	main
kartsid	doc_568696801176_item	2733762	et	4	main
oma	doc_568696801176_item	2733763	et	4	main
varandust	doc_568696801176_item	2733764	et	3	main
kaotada	doc_568696801176_item	2733765	et	3	main
kommunistlik	doc_568696801176_item	2733766	et	3	main
partei	doc_568696801176_item	2733767	et	4	main
käskis	doc_568696801176_item	2733768	et	4	main
mida	doc_568696801176_item	2733769	et	4	main
tehased	doc_568696801176_item	2733730	et	3	main
tööstusasutused	doc_568696801176_item	2733731	et	4	main
hakkas	doc_568696801176_item	2733737	et	3	main
tunnistatud	doc_568696801176_item	2733747	et	4	main
astusid	doc_568696801176_item	2733756	et	4	main
harud	doc_568696801176_item	2733777	et	3	main
selle	doc_568696801176_item	2733780	et	4	main
tapsid	doc_568696801176_item	2733783	et	4	main
loomi	doc_568696801176_item	2733784	et	4	main
ja	doc_568696801176_item	2733785	et	3	main
talud	doc_568696801176_item	2733794	et	4	main
sest	doc_568696801176_item	2733797	et	4	main
energiaga	doc_568696801176_item	2733813	et	3	main
muutus	doc_568696801176_item	2733820	et	4	main
ja	doc_568696801176_item	2733770	et	3	main
kuidas	doc_568696801176_item	2733771	et	3	main
pm	doc_568696801176_item	2733776	et	4	main
oma	doc_568696801176_item	2733787	et	4	main
varandust	doc_568696801176_item	2733788	et	3	main
et	doc_568696801176_item	2733789	et	3	main
ei	doc_568696801176_item	2733792	et	4	main
saaks	doc_568696801176_item	2733793	et	3	main
eluvõimalitteks	doc_568696801176_item	2733796	et	4	main
nad	doc_568696801176_item	2733798	et	3	main
pidid	doc_568696801176_item	2733799	et	4	main
maksma	doc_568696801176_item	2733800	et	3	main
riigile	doc_568696801176_item	2733801	et	3	main
suuri	doc_568696801176_item	2733802	et	3	main
makse	doc_568696801176_item	2733803	et	4	main
need	doc_568696801176_item	2733804	et	3	main
pidi	doc_568696801176_item	2733809	et	4	main
oblastit	doc_568696801176_item	2733812	et	3	main
intensiivselt	doc_568696801176_item	2733816	et	4	main
volikogu	doc_568696801176_item	2733827	et	4	main
see	doc_568696801176_item	2733828	et	3	main
j	doc_568696801176_item	2733836	et	4	main
sellele	doc_568696801176_item	2733845	et	4	main
kohe	doc_568696801176_item	2733853	et	4	main
ja	doc_568696801176_item	2733866	et	3	main
olid	doc_568696801176_item	2733885	et	4	main
hruštšovi	doc_568696801176_item	2733888	et	2	main
tsensuur	doc_568696801176_item	2733920	et	3	main
olid	doc_568696801176_item	2733930	et	4	main
lastele	doc_568696801176_item	2733940	et	4	main
eestlased	doc_568696801176_item	2733945	et	3	main
ja	doc_568696801176_item	2733948	et	3	main
viimine	doc_568696801176_item	2733967	et	4	main
sead	doc_568696801176_item	2733982	et	4	main
tunnistatud	doc_568696801176_item	2733984	et	4	main
võivad	doc_56989259334_item	2734005	et	4	main
palju	doc_56989259334_item	2734006	et	4	main
ja	doc_56989259334_item	2734022	et	3	main
ja	doc_56989259334_item	2734024	et	3	main
kirjutama	doc_56989259334_item	2734031	et	3	main
tirjutada	doc_56989259334_item	2734035	et	4	main
ttu-s	doc_56989259334_item	2734044	et	3	main
oli	doc_56989259334_item	2734064	et	3	main
kümme	doc_56989259334_item	2734065	et	3	main
ei	doc_56989259334_item	2734081	et	4	main
teha	doc_56989259334_item	2734084	et	3	main
öömatkamas	doc_56989259334_item	2734127	et	4	main
mängisime	doc_56989259334_item	2734129	et	3	main
mängisimi	doc_56989259334_item	2734133	et	4	main
ma	doc_56989259334_item	2734143	et	3	main
koduneülesannet	doc_56989259334_item	2734155	et	4	main
minu	doc_56989259334_item	2734156	et	3	main
jaoks	doc_56989259334_item	2734157	et	4	main
aga	doc_56989259334_item	2734164	et	3	main
arvan	doc_56989259334_item	2734166	et	3	main
on	doc_572002200596_item	2734203	et	4	main
näe	doc_572002200596_item	2734212	et	4	main
kaup	doc_572002200596_item	2734222	et	3	main
tarbija	doc_572002200596_item	2734226	et	4	main
seda	doc_572002200596_item	2734227	et	3	main
kätte	doc_572002200596_item	2734228	et	4	main
saab	doc_572002200596_item	2734229	et	3	main
mis	doc_572002200596_item	2734230	et	4	main
kui	doc_572002200596_item	2734244	et	3	main
tekkivad	doc_572002200596_item	2734246	et	4	main
mille	doc_572002200596_item	2734248	et	3	main
on	doc_572002200596_item	2734256	et	4	main
sellest	doc_572002200596_item	2734260	et	4	main
sõltub	doc_572002200596_item	2734261	et	3	main
teha	doc_572002200596_item	2734274	et	3	main
ei	doc_572002200596_item	2734289	et	4	main
ja	doc_572002200596_item	2734298	et	3	main
pea	doc_572002200597_item	2734326	et	4	main
kõikidel	doc_572002200597_item	2734329	et	4	main
kodus	doc_572002200597_item	2734345	et	4	main
on	doc_572002200597_item	2734353	et	4	main
ei	doc_572002200597_item	2734359	et	4	main
jooksul	doc_572002200597_item	2734368	et	4	main
ei	doc_572002200597_item	2734378	et	4	main
olema	doc_572002200597_item	2734383	et	4	main
kirjutatud	doc_572002200597_item	2734391	et	4	main
nimi	doc_572002200597_item	2734394	et	3	main
ja	doc_572002200597_item	2734397	et	3	main
vastavaks	doc_568696801176_item	2733823	et	4	main
oli	doc_568696801176_item	2733839	et	3	main
täitev	doc_568696801176_item	2733840	et	4	main
allusid	doc_568696801176_item	2733846	et	4	main
kõik	doc_568696801176_item	2733847	et	4	main
eluharud	doc_568696801176_item	2733848	et	3	main
riigikorraks	doc_568696801176_item	2733849	et	3	main
muutus	doc_568696801176_item	2733850	et	4	main
sotsialism	doc_568696801176_item	2733851	et	3	main
ümberkorraldama	doc_568696801176_item	2733855	et	4	main
see	doc_568696801176_item	2733859	et	3	main
vahendeid	doc_568696801176_item	2733865	et	3	main
poliitiline	doc_568696801176_item	2733868	et	3	main
omandab	doc_568696801176_item	2733870	et	3	main
läbi	doc_568696801176_item	2733874	et	4	main
viidud	doc_568696801176_item	2733875	et	4	main
haldusreform	doc_568696801176_item	2733876	et	3	main
3	doc_568696801176_item	2733877	et	2	main
oblastit	doc_568696801176_item	2733878	et	3	main
tänavad	doc_568696801176_item	2733884	et	4	main
ümbernimetatud	doc_568696801176_item	2733886	et	4	main
sula	doc_568696801176_item	2733889	et	4	main
1957-1968	doc_568696801176_item	2733890	et	2	main
aa	doc_568696801176_item	2733891	et	3	main
sotsialistlik	doc_568696801176_item	2733892	et	3	main
realism	doc_568696801176_item	2733893	et	3	main
põhivool	doc_568696801176_item	2733894	et	4	main
suunatud	doc_568696801176_item	2733895	et	4	main
parema	doc_568696801176_item	2733896	et	4	main
poole	doc_568696801176_item	2733897	et	4	main
euroopa	doc_568696801176_item	2733898	et	4	main
stiile	doc_568696801176_item	2733899	et	3	main
ja	doc_568696801176_item	2733900	et	3	main
voole	doc_568696801176_item	2733901	et	4	main
keelati	doc_568696801176_item	2733902	et	4	main
seltsitegevus	doc_568696801176_item	2733903	et	4	main
keelatud	doc_568696801176_item	2733904	et	4	main
harrastusi	doc_568696801176_item	2733905	et	4	main
ja	doc_568696801176_item	2733906	et	3	main
eriseltse	doc_568696801176_item	2733907	et	3	main
ei	doc_568696801176_item	2733908	et	4	main
tohtinud	doc_568696801176_item	2733909	et	4	main
olla	doc_568696801176_item	2733910	et	3	main
kunstnikke	doc_568696801176_item	2733911	et	3	main
ja	doc_568696801176_item	2733912	et	3	main
kirjanikke	doc_568696801176_item	2733913	et	3	main
represseeriti	doc_568696801176_item	2733914	et	3	main
või	doc_568696801176_item	2733915	et	4	main
vangistati	doc_568696801176_item	2733916	et	4	main
eestis	doc_568696801176_item	2733926	et	3	main
vastanud	doc_568696801176_item	2733935	et	4	main
ekвp	doc_568696801176_item	2733936	et	2	main
eesmärkidele	doc_568696801176_item	2733937	et	3	main
majad	doc_568696801176_item	2733943	et	3	main
suhtlesid	doc_568696801176_item	2733949	et	4	main
maadest	doc_568696801176_item	2733954	et	4	main
peamiselt	doc_568696801176_item	2733955	et	4	main
ida-virumaale	doc_568696801176_item	2733956	et	4	main
seal	doc_568696801176_item	2733957	et	4	main
on	doc_568696801176_item	2733958	et	4	main
majanduslikud	doc_568696801176_item	2733959	et	3	main
ja	doc_568696801176_item	2733961	et	3	main
isoleeritud	doc_568696801176_item	2733962	et	4	main
rajoonid	doc_568696801176_item	2733960	et	4	main
tsoonid	doc_568696801176_item	2733963	et	3	main
kirjasõna	doc_568696801176_item	2733922	et	4	main
avatakse	doc_568696801176_item	2733941	et	4	main
said	doc_568696801176_item	2733946	et	4	main
194719505	doc_568696801176_item	2733950	et	2	main
metsavendade	doc_568696801176_item	2733969	et	3	main
tiigi	doc_568696801176_item	2733972	et	3	main
hakkavad	doc_568696801176_item	2733974	et	4	main
eestisse	doc_568696801176_item	2733975	et	4	main
tagasi	doc_568696801176_item	2733976	et	3	main
tegelased	doc_568696801176_item	2733977	et	3	main
represseeritu	doc_568696801176_item	2733980	et	4	main
kultus	doc_568696801176_item	2733987	et	3	main
meil	doc_56989259334_item	2733998	et	4	main
mälestusmärke	doc_56989259334_item	2734007	et	4	main
ja	doc_56989259334_item	2734008	et	3	main
ja	doc_56989259334_item	2734015	et	3	main
näinud	doc_56989259334_item	2734018	et	4	main
suur	doc_56989259334_item	2734021	et	3	main
aga	doc_56989259334_item	2734032	et	3	main
tahan	doc_56989259334_item	2734034	et	3	main
suve	doc_56989259334_item	2734040	et	4	main
aastal	doc_56989259334_item	2734046	et	3	main
ja	doc_56989259334_item	2734051	et	3	main
kuum	doc_56989259334_item	2734053	et	3	main
rühmajuhatajaks	doc_56989259334_item	2734056	et	3	main
kurtna	doc_56989259334_item	2734058	et	4	main
ma	doc_56989259334_item	2734059	et	3	main
lastega	doc_56989259334_item	2734062	et	3	main
esimene	doc_56989259334_item	2734072	et	3	main
ma	doc_56989259334_item	2734088	et	3	main
vajan	doc_56989259334_item	2734089	et	3	main
läbi	doc_568696801176_item	2733966	et	4	main
tegevust	doc_568696801176_item	2733970	et	4	main
olid	doc_568696801176_item	2733979	et	4	main
oli	doc_568696801176_item	2733983	et	3	main
essee	doc_56989259334_item	2733988	et	4	main
kus	doc_56989259334_item	2733989	et	3	main
käinud	doc_56989259334_item	2733991	et	4	main
palju	doc_56989259334_item	2733999	et	4	main
võimalusi	doc_56989259334_item	2734000	et	3	main
reisida	doc_56989259334_item	2734001	et	3	main
maailma	doc_56989259334_item	2734002	et	4	main
üle	doc_56989259334_item	2734003	et	3	main
mida	doc_56989259334_item	2734016	et	4	main
olen	doc_56989259334_item	2734017	et	3	main
on	doc_56989259334_item	2734019	et	4	main
ma	doc_56989259334_item	2734025	et	3	main
tea	doc_56989259334_item	2734027	et	4	main
öelda	doc_56989259334_item	2734036	et	4	main
ja	doc_56989259334_item	2734037	et	3	main
kirjelda	doc_56989259334_item	2734038	et	4	main
veedamist	doc_56989259334_item	2734041	et	4	main
koolielust	doc_56989259334_item	2734043	et	3	main
hea	doc_56989259334_item	2734049	et	4	main
ma	doc_56989259334_item	2734054	et	3	main
kellel	doc_56989259334_item	2734063	et	4	main
ujumas	doc_56989259334_item	2734128	et	3	main
muud	doc_56989259334_item	2734136	et	4	main
algal	doc_56989259334_item	2734140	et	4	main
läksin	doc_56989259334_item	2734144	et	3	main
mul	doc_56989259334_item	2734147	et	3	main
olnud	doc_56989259334_item	2734149	et	4	main
on	doc_56989259334_item	2734160	et	4	main
ma	doc_56989259334_item	2734165	et	3	main
on	doc_56989259334_item	2734169	et	4	main
kui	doc_56989259334_item	2734171	et	3	main
ma	doc_56989259334_item	2734172	et	3	main
kataloogi	doc_572002200596_item	2734204	et	4	main
kaudu	doc_572002200596_item	2734205	et	3	main
kataloogist	doc_572002200596_item	2734208	et	3	main
ostmisel	doc_572002200596_item	2734209	et	4	main
ning	doc_572002200596_item	2734214	et	3	main
seda	doc_572002200596_item	2734217	et	3	main
juhtub	doc_572002200596_item	2734219	et	3	main
tarbija	doc_572002200596_item	2734234	et	4	main
saab	doc_572002200596_item	2734235	et	3	main
kaubakirja	doc_572002200596_item	2734236	et	4	main
kirjutada	doc_572002200596_item	2734237	et	3	main
ümber	doc_572002200596_item	2734241	et	3	main
vahetada	doc_572002200596_item	2734242	et	3	main
koolis	doc_572002200596_item	2734253	et	4	main
õppimisest	doc_572002200596_item	2734254	et	4	main
raskem	doc_572002200596_item	2734257	et	4	main
erialat	doc_572002200596_item	2734267	et	4	main
ja	doc_572002200596_item	2734268	et	3	main
heaks	doc_572002200596_item	2734287	et	4	main
inimene	doc_572002200596_item	2734288	et	3	main
tarbitada	doc_572002200596_item	2734293	et	4	main
peame	doc_572002200596_item	2734295	et	4	main
suundada	doc_568696801176_item	2733971	et	4	main
kasuks	doc_568696801176_item	2733973	et	4	main
kes	doc_568696801176_item	2733978	et	4	main
enne	doc_568696801176_item	2733981	et	4	main
nn	doc_568696801176_item	2733985	et	4	main
olen	doc_56989259334_item	2733990	et	3	main
ja	doc_56989259334_item	2733992	et	3	main
mida	doc_56989259334_item	2733993	et	4	main
olen	doc_56989259334_item	2733994	et	3	main
teinud	doc_56989259334_item	2733995	et	4	main
tänapäeval	doc_56989259334_item	2733996	et	3	main
on	doc_56989259334_item	2733997	et	4	main
inimesed	doc_56989259334_item	2734004	et	3	main
teema	doc_56989259334_item	2734011	et	4	main
kus	doc_56989259334_item	2734012	et	3	main
olen	doc_56989259334_item	2734013	et	3	main
käinud	doc_56989259334_item	2734014	et	4	main
üldine	doc_56989259334_item	2734023	et	4	main
ei	doc_56989259334_item	2734026	et	4	main
mida	doc_56989259334_item	2734028	et	4	main
ma	doc_56989259334_item	2734029	et	3	main
oma	doc_56989259334_item	2734039	et	4	main
ja	doc_56989259334_item	2734042	et	3	main
sellel	doc_56989259334_item	2734045	et	4	main
oli	doc_56989259334_item	2734048	et	3	main
ilm	doc_56989259334_item	2734050	et	3	main
oli	doc_56989259334_item	2734052	et	3	main
töötasin	doc_56989259334_item	2734055	et	3	main
noortelaagris	doc_56989259334_item	2734057	et	3	main
olen	doc_56989259334_item	2734060	et	3	main
kaksteist	doc_56989259334_item	2734066	et	4	main
vana	doc_56989259334_item	2734068	et	4	main
see	doc_56989259334_item	2734069	et	3	main
oli	doc_56989259334_item	2734070	et	3	main
kogemus	doc_56989259334_item	2734073	et	3	main
ja	doc_56989259334_item	2734074	et	3	main
oli	doc_56989259334_item	2734076	et	3	main
väga	doc_56989259334_item	2734077	et	3	main
teinud	doc_56989259334_item	2734082	et	4	main
nende	doc_56989259334_item	2734090	et	4	main
vabaaega	doc_56989259334_item	2734091	et	4	main
huvitama	doc_56989259334_item	2734092	et	3	main
mõne	doc_56989259334_item	2734093	et	3	main
perioodi	doc_56989259334_item	2734094	et	4	main
pärast	doc_56989259334_item	2734095	et	4	main
mul	doc_56989259334_item	2734096	et	3	main
meeldis	doc_56989259334_item	2734097	et	3	main
seda	doc_56989259334_item	2734098	et	3	main
töö	doc_56989259334_item	2734099	et	4	main
ja	doc_56989259334_item	2734100	et	3	main
minu	doc_56989259334_item	2734101	et	3	main
lapsed	doc_56989259334_item	2734102	et	3	main
nad	doc_56989259334_item	2734103	et	3	main
olid	doc_56989259334_item	2734104	et	4	main
rõõmusad	doc_56989259334_item	2734105	et	4	main
aktiivsed	doc_56989259334_item	2734106	et	3	main
ja	doc_56989259334_item	2734107	et	3	main
liikuvad	doc_56989259334_item	2734108	et	4	main
ma	doc_56989259334_item	2734109	et	3	main
olen	doc_56989259334_item	2734110	et	3	main
ise	doc_56989259334_item	2734111	et	4	main
sportlane	doc_56989259334_item	2734112	et	3	main
ja	doc_56989259334_item	2734113	et	3	main
mulle	doc_56989259334_item	2734114	et	4	main
meeldivad	doc_56989259334_item	2734115	et	4	main
need	doc_56989259334_item	2734116	et	3	main
inimesed	doc_56989259334_item	2734117	et	3	main
nendel	doc_56989259334_item	2734118	et	4	main
inimestel	doc_56989259334_item	2734119	et	3	main
on	doc_56989259334_item	2734120	et	4	main
palju	doc_56989259334_item	2734121	et	4	main
me	doc_56989259334_item	2734123	et	4	main
eneergiat	doc_56989259334_item	2734122	et	4	main
päevamatkamas	doc_56989259334_item	2734125	et	4	main
ja	doc_56989259334_item	2734126	et	3	main
ja	doc_56989259334_item	2734135	et	3	main
õppima	doc_56989259334_item	2734158	et	3	main
ülikoolis	doc_56989259334_item	2734159	et	4	main
suur	doc_56989259334_item	2734162	et	3	main
see	doc_56989259334_item	2734168	et	3	main
harjutan	doc_56989259334_item	2734173	et	3	main
siis	doc_56989259334_item	2734175	et	3	main
ma	doc_56989259334_item	2734176	et	3	main
vaatan	doc_56989259334_item	2734177	et	3	main
tallin	doc_56989259334_item	2734178	et	4	main
ja	doc_56989259334_item	2734179	et	3	main
vaatan	doc_56989259334_item	2734180	et	3	main
kõike	doc_56989259334_item	2734181	et	4	main
mälestusväärsust	doc_56989259334_item	2734182	et	4	main
kontrolltöö	doc_572002200596_item	2734183	et	4	main
milliseid	doc_572002200596_item	2734184	et	3	main
soovitusi	doc_572002200596_item	2734185	et	4	main
annaksid	doc_572002200596_item	2734186	et	4	main
tööotsijale	doc_572002200596_item	2734187	et	3	main
olge	doc_572002200596_item	2734188	et	3	main
julge	doc_572002200596_item	2734189	et	4	main
tööandja	doc_572002200596_item	2734190	et	4	main
vestlemisel	doc_572002200596_item	2734191	et	4	main
vaadake	doc_572002200596_item	2734192	et	3	main
läbi	doc_572002200596_item	2734193	et	4	main
kõik	doc_572002200596_item	2734194	et	4	main
töövõimalused	doc_572002200596_item	2734195	et	3	main
olge	doc_572002200596_item	2734196	et	3	main
enesekindel	doc_572002200596_item	2734197	et	3	main
ja	doc_572002200596_item	2734198	et	3	main
mõelge	doc_572002200596_item	2734199	et	3	main
oma	doc_572002200596_item	2734200	et	4	main
cv-st	doc_572002200596_item	2734201	et	3	main
käisime	doc_56989259334_item	2734124	et	3	main
lauamänge	doc_56989259334_item	2734134	et	3	main
ja	doc_56989259334_item	2734142	et	3	main
siis	doc_56989259334_item	2734146	et	3	main
pole	doc_56989259334_item	2734148	et	3	main
vabaaega	doc_56989259334_item	2734150	et	4	main
ja	doc_56989259334_item	2734151	et	3	main
ma	doc_56989259334_item	2734152	et	3	main
ainult	doc_56989259334_item	2734153	et	4	main
teen	doc_56989259334_item	2734154	et	3	main
koormus	doc_56989259334_item	2734163	et	4	main
ajutiselt	doc_56989259334_item	2734170	et	4	main
sellega	doc_56989259334_item	2734174	et	3	main
tarbija	doc_572002200596_item	2734210	et	4	main
et	doc_572002200596_item	2734221	et	3	main
soobi	doc_572002200596_item	2734224	et	3	main
tarbija	doc_572002200596_item	2734232	et	4	main
tarbija	doc_572002200596_item	2734238	et	4	main
juhul	doc_572002200596_item	2734243	et	3	main
õppimine	doc_572002200596_item	2734252	et	4	main
kogu	doc_572002200596_item	2734262	et	4	main
mida	doc_572002200596_item	2734270	et	4	main
saab	doc_572002200596_item	2734271	et	3	main
inimene	doc_572002200596_item	2734272	et	3	main
tervislik	doc_572002200596_item	2734279	et	3	main
saa	doc_572002200596_item	2734290	et	4	main
suitsetada	doc_572002200596_item	2734291	et	3	main
meie	doc_572002200596_item	2734294	et	4	main
peab	doc_572002200597_item	2734331	et	4	main
olema	doc_572002200597_item	2734332	et	4	main
üks	doc_572002200597_item	2734333	et	3	main
mis	doc_572002200597_item	2734336	et	4	main
kataloogi	doc_572002200597_item	2734338	et	4	main
mis	doc_572002200597_item	2734351	et	4	main
sulle	doc_572002200597_item	2734355	et	3	main
meeldi	doc_572002200597_item	2734360	et	4	main
sa	doc_572002200597_item	2734362	et	3	main
ostsid	doc_572002200597_item	2734363	et	4	main
sa	doc_572002200597_item	2734364	et	3	main
sa	doc_572002200597_item	2734372	et	3	main
võid	doc_572002200597_item	2734373	et	4	main
leida	doc_572002200597_item	2734374	et	3	main
riideid	doc_572002200597_item	2734375	et	3	main
mis	doc_572002200597_item	2734381	et	4	main
olema	doc_572002200597_item	2734390	et	4	main
mida	doc_572002200597_item	2734408	et	4	main
üldiselt	doc_572002200597_item	2734412	et	4	main
lõunavaheaeg	doc_572002200597_item	2734426	et	3	main
koolis	doc_572002200597_item	2734429	et	4	main
15	doc_572002200597_item	2734438	et	2	main
lapsed	doc_572002200597_item	2734441	et	3	main
korrektselt	doc_572002200597_item	2734445	et	4	main
arvan	doc_572002200597_item	2734448	et	3	main
isegi	doc_572002200597_item	2734452	et	4	main
minutid	doc_572002200597_item	2734454	et	3	main
sõltub	doc_572002200597_item	2734466	et	3	main
glenfild	doc_572002200598_item	2734491	et	4	main
perekonnanimi	doc_572002200598_item	2734495	et	3	main
sel	doc_572002200598_item	2734521	et	3	main
iargmisel	doc_572002200598_item	2734531	et	4	main
päeval	doc_572002200598_item	2734532	et	3	main
teie	doc_572002200598_item	2734538	et	4	main
lihtsal	doc_572002200598_item	2734540	et	3	main
minu	doc_572002200598_item	2734550	et	3	main
mulle	doc_572002200598_item	2734557	et	4	main
et	doc_572002200598_item	2734559	et	3	main
oli	doc_572002200598_item	2734561	et	3	main
ma	doc_572002200598_item	2734563	et	3	main
xxx	doc_572002200599_item	2734588	et	4	main
teavitada	doc_572002200599_item	2734591	et	4	main
et	doc_572002200599_item	2734593	et	3	main
ma	doc_572002200599_item	2734594	et	3	main
detsembril	doc_572002200599_item	2734604	et	3	main
nädala	doc_572002200599_item	2734610	et	3	main
see	doc_572002200599_item	2734612	et	3	main
on	doc_572002200599_item	2734614	et	4	main
näitab	doc_572002200599_item	2734625	et	3	main
et	doc_572002200599_item	2734626	et	3	main
vahetasime	doc_572002200599_item	2734632	et	3	main
selle	doc_572002200599_item	2734633	et	4	main
keeldusid	doc_572002200599_item	2734637	et	4	main
töötamast	doc_572002200599_item	2734638	et	4	main
et	doc_56989259334_item	2734167	et	3	main
mis	doc_572002200596_item	2734202	et	4	main
ostmise	doc_572002200596_item	2734206	et	4	main
kaupa	doc_572002200596_item	2734213	et	4	main
saa	doc_572002200596_item	2734216	et	4	main
nii	doc_572002200596_item	2734220	et	3	main
ei	doc_572002200596_item	2734223	et	4	main
kui	doc_572002200596_item	2734225	et	3	main
põhiõigused	doc_572002200596_item	2734233	et	4	main
saab	doc_572002200596_item	2734239	et	3	main
sellega	doc_572002200596_item	2734245	et	3	main
poolest	doc_572002200596_item	2734249	et	4	main
erineb	doc_572002200596_item	2734250	et	3	main
kõrgkoolis	doc_572002200596_item	2734251	et	4	main
elu	doc_572002200596_item	2734263	et	4	main
ise	doc_572002200596_item	2734273	et	4	main
heaks	doc_572002200596_item	2734277	et	4	main
eluviis	doc_572002200596_item	2734280	et	3	main
alkohooli	doc_572002200596_item	2734292	et	3	main
panna	doc_572002200597_item	2734322	et	4	main
mõtlema	doc_572002200597_item	2734327	et	3	main
et	doc_572002200597_item	2734328	et	3	main
küsimustel	doc_572002200597_item	2734330	et	4	main
vastus	doc_572002200597_item	2734335	et	3	main
kaudu	doc_572002200597_item	2734339	et	3	main
ostmise	doc_572002200597_item	2734340	et	4	main
plussid	doc_572002200597_item	2734341	et	3	main
sa	doc_572002200597_item	2734342	et	3	main
kataloogis	doc_572002200597_item	2734352	et	4	main
ei	doc_572002200597_item	2734356	et	4	main
mida	doc_572002200597_item	2734361	et	4	main
saa	doc_572002200597_item	2734379	et	4	main
kirjutatud	doc_572002200597_item	2734384	et	4	main
korrektsele	doc_572002200597_item	2734385	et	3	main
ostutšekile	doc_572002200597_item	2734386	et	2	main
korrektsele	doc_572002200597_item	2734387	et	3	main
1	doc_572002200597_item	2734392	et	2	main
2	doc_572002200597_item	2734395	et	2	main
seda	doc_572002200597_item	2734401	et	3	main
kaupa	doc_572002200597_item	2734402	et	4	main
4	doc_572002200597_item	2734406	et	2	main
koolis	doc_572002200597_item	2734410	et	4	main
tunne	doc_572002200597_item	2734421	et	4	main
tahaksin	doc_572002200597_item	2734424	et	3	main
ainult	doc_572002200597_item	2734437	et	4	main
minutid	doc_572002200597_item	2734439	et	3	main
lihtsalt	doc_572002200597_item	2734442	et	4	main
ei	doc_572002200597_item	2734443	et	4	main
süüja	doc_572002200597_item	2734446	et	4	main
ja	doc_572002200597_item	2734451	et	3	main
ei	doc_572002200597_item	2734455	et	4	main
ole	doc_572002200597_item	2734456	et	4	main
millest	doc_572002200597_item	2734465	et	3	main
1	doc_572002200597_item	2734470	et	2	main
2	doc_572002200597_item	2734472	et	2	main
keskkonnast	doc_572002200597_item	2734475	et	4	main
poliitika	doc_572002200597_item	2734477	et	4	main
vene	doc_572002200598_item	2734489	et	4	main
as	doc_572002200598_item	2734492	et	4	main
mul	doc_572002200598_item	2734496	et	3	main
ma	doc_572002200598_item	2734524	et	3	main
kondsad	doc_572002200598_item	2734528	et	4	main
läksid	doc_572002200598_item	2734529	et	4	main
tuli	doc_572002200598_item	2734534	et	4	main
juurde	doc_572002200598_item	2734536	et	4	main
aga	doc_572002200598_item	2734537	et	3	main
mind	doc_572002200598_item	2734543	et	4	main
kuulata	doc_572002200598_item	2734544	et	4	main
nad	doc_572002200598_item	2734545	et	3	main
uskuda	doc_572002200598_item	2734556	et	3	main
praakkaub	doc_572002200598_item	2734562	et	4	main
olen	doc_572002200598_item	2734564	et	3	main
sünnitud	doc_572002200598_item	2734565	et	4	main
mina	doc_572002200599_item	2734587	et	4	main
katkise	doc_572002200599_item	2734598	et	4	main
03	doc_572002200599_item	2734603	et	2	main
töötanud	doc_572002200599_item	2734620	et	4	main
pirn	doc_572002200599_item	2734623	et	3	main
meie	doc_572002200599_item	2734631	et	4	main
ma	doc_572002200599_item	2734641	et	3	main
ei	doc_572002200599_item	2734651	et	4	main
ei	doc_572002200599_item	2734653	et	4	main
miinused	doc_572002200596_item	2734207	et	3	main
ei	doc_572002200596_item	2734211	et	4	main
ei	doc_572002200596_item	2734215	et	4	main
proovida	doc_572002200596_item	2734218	et	3	main
on	doc_572002200596_item	2734231	et	4	main
kaupa	doc_572002200596_item	2734240	et	4	main
proobleemid	doc_572002200596_item	2734247	et	4	main
kõrgkoolis	doc_572002200596_item	2734255	et	4	main
õppida	doc_572002200596_item	2734258	et	3	main
sest	doc_572002200596_item	2734259	et	4	main
kõrgkoolis	doc_572002200596_item	2734264	et	4	main
õpilane	doc_572002200596_item	2734265	et	3	main
saab	doc_572002200596_item	2734266	et	3	main
praktikat	doc_572002200596_item	2734269	et	3	main
oma	doc_572002200596_item	2734275	et	4	main
tervise	doc_572002200596_item	2734276	et	3	main
esiteks	doc_572002200596_item	2734278	et	3	main
on	doc_572002200596_item	2734281	et	4	main
vajalik	doc_572002200596_item	2734282	et	3	main
et	doc_572002200596_item	2734283	et	3	main
teha	doc_572002200596_item	2734284	et	3	main
oma	doc_572002200596_item	2734285	et	4	main
tervise	doc_572002200596_item	2734286	et	3	main
sporti	doc_572002200596_item	2734296	et	4	main
teha	doc_572002200596_item	2734297	et	3	main
tarbitada	doc_572002200596_item	2734299	et	4	main
värsket	doc_572002200596_item	2734300	et	4	main
vett	doc_572002200596_item	2734301	et	3	main
kontrolltöö	doc_572002200597_item	2734302	et	4	main
mida	doc_572002200597_item	2734303	et	4	main
ei	doc_572002200597_item	2734304	et	4	main
ole	doc_572002200597_item	2734305	et	4	main
soovitatav	doc_572002200597_item	2734306	et	4	main
tööintervjuul	doc_572002200597_item	2734307	et	3	main
teha	doc_572002200597_item	2734308	et	3	main
tööintervjuul	doc_572002200597_item	2734309	et	3	main
ei	doc_572002200597_item	2734310	et	4	main
ole	doc_572002200597_item	2734311	et	4	main
soovitab	doc_572002200597_item	2734312	et	3	main
palju	doc_572002200597_item	2734313	et	4	main
lobiseda	doc_572002200597_item	2734314	et	3	main
tööintervjuul	doc_572002200597_item	2734315	et	3	main
ei	doc_572002200597_item	2734316	et	4	main
ole	doc_572002200597_item	2734317	et	4	main
soovitab	doc_572002200597_item	2734318	et	3	main
ekstravaganseid	doc_572002200597_item	2734319	et	4	main
riideid	doc_572002200597_item	2734320	et	3	main
selga	doc_572002200597_item	2734321	et	4	main
sa	doc_572002200597_item	2734324	et	3	main
on	doc_572002200597_item	2734337	et	4	main
võid	doc_572002200597_item	2734343	et	4	main
istuda	doc_572002200597_item	2734344	et	3	main
vaadata	doc_572002200597_item	2734350	et	4	main
kui	doc_572002200597_item	2734354	et	3	main
või	doc_572002200597_item	2734358	et	4	main
võid	doc_572002200597_item	2734365	et	4	main
2	doc_572002200597_item	2734366	et	2	main
nädala	doc_572002200597_item	2734367	et	3	main
mis	doc_572002200597_item	2734376	et	4	main
kaupluses	doc_572002200597_item	2734377	et	3	main
peab	doc_572002200597_item	2734382	et	4	main
peab	doc_572002200597_item	2734389	et	4	main
kaupluse	doc_572002200597_item	2734393	et	3	main
ka	doc_572002200597_item	2734323	et	3	main
ei	doc_572002200597_item	2734325	et	4	main
õige	doc_572002200597_item	2734334	et	4	main
diivani	doc_572002200597_item	2734346	et	4	main
peale	doc_572002200597_item	2734347	et	4	main
ja	doc_572002200597_item	2734348	et	3	main
rahulikult	doc_572002200597_item	2734349	et	4	main
sobi	doc_572002200597_item	2734357	et	4	main
kaupa	doc_572002200597_item	2734369	et	4	main
tagastada	doc_572002200597_item	2734370	et	3	main
kataloogis	doc_572002200597_item	2734371	et	4	main
osta	doc_572002200597_item	2734380	et	4	main
ostutšekile	doc_572002200597_item	2734388	et	2	main
3	doc_572002200597_item	2734403	et	2	main
kaupade	doc_572002200597_item	2734404	et	3	main
nimi	doc_572002200597_item	2734405	et	3	main
sooviksite	doc_572002200597_item	2734409	et	3	main
et	doc_572002200597_item	2734425	et	3	main
siis	doc_572002200597_item	2734440	et	3	main
mina	doc_572002200597_item	2734447	et	4	main
et	doc_572002200597_item	2734449	et	3	main
20	doc_572002200597_item	2734453	et	2	main
minutid	doc_572002200597_item	2734464	et	3	main
eluiga	doc_572002200597_item	2734468	et	4	main
4	doc_572002200597_item	2734476	et	2	main
5	doc_572002200597_item	2734479	et	2	main
eesnimi	doc_572002200598_item	2734494	et	3	main
need	doc_572002200598_item	2734525	et	3	main
raske	doc_572002200598_item	2734555	et	4	main
sooviksin	doc_572002200599_item	2734590	et	3	main
teid	doc_572002200599_item	2734592	et	4	main
ostsin	doc_572002200599_item	2734595	et	3	main
teie	doc_572002200599_item	2734596	et	4	main
selle	doc_572002200599_item	2734602	et	4	main
kohe	doc_572002200599_item	2734605	et	4	main
ei	doc_572002200599_item	2734619	et	4	main
millal	doc_572002200597_item	2734396	et	3	main
kus	doc_572002200597_item	2734398	et	3	main
ostsid	doc_572002200597_item	2734400	et	4	main
summa	doc_572002200597_item	2734407	et	4	main
ei	doc_572002200597_item	2734420	et	4	main
sa	doc_572002200597_item	2734399	et	3	main
muuta	doc_572002200597_item	2734411	et	4	main
mulle	doc_572002200597_item	2734413	et	4	main
meeldib	doc_572002200597_item	2734414	et	3	main
kuidas	doc_572002200597_item	2734415	et	3	main
koolisüsteem	doc_572002200597_item	2734416	et	3	main
töötab	doc_572002200597_item	2734417	et	3	main
ülekoormust	doc_572002200597_item	2734418	et	4	main
ma	doc_572002200597_item	2734419	et	3	main
aga	doc_572002200597_item	2734422	et	3	main
ma	doc_572002200597_item	2734423	et	3	main
oleks	doc_572002200597_item	2734427	et	3	main
pikem	doc_572002200597_item	2734428	et	4	main
on	doc_572002200597_item	2734430	et	4	main
palju	doc_572002200597_item	2734431	et	4	main
õpilasi	doc_572002200597_item	2734432	et	3	main
ja	doc_572002200597_item	2734433	et	3	main
kui	doc_572002200597_item	2734434	et	3	main
vaheaeg	doc_572002200597_item	2734435	et	3	main
jõua	doc_572002200597_item	2734444	et	4	main
15	doc_572002200597_item	2734450	et	2	main
näiteks	doc_572002200597_item	2734462	et	4	main
45-60	doc_572002200597_item	2734463	et	2	main
3	doc_572002200597_item	2734474	et	2	main
seisukorrast	doc_572002200597_item	2734478	et	4	main
pärilisust	doc_572002200597_item	2734480	et	4	main
ja	doc_572002200597_item	2734481	et	3	main
paljudest	doc_572002200597_item	2734482	et	3	main
faktoridest	doc_572002200597_item	2734483	et	4	main
kaebus	doc_572002200598_item	2734484	et	3	main
eesnimi	doc_572002200598_item	2734485	et	3	main
perekonnanimi	doc_572002200598_item	2734486	et	3	main
kauplus	doc_572002200598_item	2734487	et	3	main
21	doc_572002200598_item	2734490	et	2	main
lp	doc_572002200598_item	2734493	et	4	main
on	doc_572002200597_item	2734436	et	4	main
piisav	doc_572002200597_item	2734457	et	4	main
tahaksin	doc_572002200597_item	2734458	et	3	main
et	doc_572002200597_item	2734459	et	3	main
lõunavaheaeg	doc_572002200597_item	2734460	et	3	main
oleks	doc_572002200597_item	2734461	et	3	main
eluiga	doc_572002200597_item	2734467	et	4	main
sõltub	doc_572002200597_item	2734469	et	3	main
meditsiiniarengust	doc_572002200597_item	2734471	et	3	main
jõudukust	doc_572002200597_item	2734473	et	3	main
juhataja	doc_572002200598_item	2734488	et	4	main
mina	doc_572002200598_item	2734497	et	4	main
eesnimi	doc_572002200598_item	2734498	et	3	main
perekonnanimi	doc_572002200598_item	2734499	et	3	main
ostsin	doc_572002200598_item	2734500	et	3	main
teie	doc_572002200598_item	2734501	et	4	main
kaupluses	doc_572002200598_item	2734502	et	3	main
kingad	doc_572002200598_item	2734504	et	3	main
kõrgkondsaga	doc_572002200598_item	2734503	et	4	main
see	doc_572002200598_item	2734505	et	3	main
oli	doc_572002200598_item	2734506	et	3	main
04	doc_572002200598_item	2734507	et	2	main
12	doc_572002200598_item	2734508	et	2	main
03	doc_572002200598_item	2734509	et	2	main
mul	doc_572002200598_item	2734510	et	3	main
tekkis	doc_572002200598_item	2734511	et	3	main
üks	doc_572002200598_item	2734512	et	3	main
väike	doc_572002200598_item	2734513	et	4	main
probleem	doc_572002200598_item	2734514	et	3	main
kui	doc_572002200598_item	2734515	et	3	main
ma	doc_572002200598_item	2734516	et	3	main
ostsin	doc_572002200598_item	2734517	et	3	main
need	doc_572002200598_item	2734518	et	3	main
kingad	doc_572002200598_item	2734519	et	3	main
siis	doc_572002200598_item	2734520	et	3	main
panin	doc_572002200598_item	2734523	et	3	main
jalga	doc_572002200598_item	2734526	et	4	main
ma	doc_572002200598_item	2734533	et	3	main
teie	doc_572002200598_item	2734535	et	4	main
ei	doc_572002200598_item	2734541	et	4	main
tahtnud	doc_572002200598_item	2734542	et	4	main
süü	doc_572002200598_item	2734551	et	4	main
aga	doc_572002200598_item	2734552	et	3	main
seda	doc_572002200598_item	2734553	et	3	main
on	doc_572002200598_item	2734554	et	4	main
tundub	doc_572002200598_item	2734558	et	3	main
see	doc_572002200598_item	2734560	et	3	main
yyy	doc_572002200599_item	2734589	et	4	main
televiisori	doc_572002200599_item	2734599	et	4	main
ma	doc_572002200599_item	2734600	et	3	main
ostsin	doc_572002200599_item	2734601	et	3	main
palgapäeva	doc_572002200599_item	2734607	et	4	main
kahe	doc_572002200599_item	2734609	et	3	main
pärast	doc_572002200599_item	2734611	et	4	main
tv	doc_572002200599_item	2734613	et	4	main
juba	doc_572002200599_item	2734615	et	3	main
see	doc_572002200599_item	2734621	et	3	main
lülitatud	doc_572002200599_item	2734630	et	4	main
puldinupud	doc_572002200599_item	2734636	et	4	main
õhtul	doc_572002200598_item	2734522	et	3	main
ja	doc_572002200598_item	2734527	et	3	main
katki	doc_572002200598_item	2734530	et	4	main
müüjad	doc_572002200598_item	2734539	et	4	main
ütlesid	doc_572002200598_item	2734546	et	4	main
et	doc_572002200598_item	2734547	et	3	main
see	doc_572002200598_item	2734548	et	3	main
oli	doc_572002200598_item	2734549	et	3	main
tarbijakaitsemaetisse	doc_572002200598_item	2734566	et	4	main
pöörduda	doc_572002200598_item	2734567	et	3	main
võib	doc_572002200598_item	2734568	et	3	main
olla	doc_572002200598_item	2734569	et	3	main
nad	doc_572002200598_item	2734570	et	3	main
aitavad	doc_572002200598_item	2734571	et	4	main
seda	doc_572002200598_item	2734572	et	3	main
probleemi	doc_572002200598_item	2734573	et	4	main
lahendama	doc_572002200598_item	2734574	et	3	main
perekonnanimi	doc_572002200598_item	2734575	et	3	main
eesnimi	doc_572002200598_item	2734576	et	3	main
p	doc_572002200598_item	2734577	et	4	main
kaebus	doc_572002200599_item	2734578	et	3	main
damaged	doc_572002200599_item	2734579	et	4	main
goods	doc_572002200599_item	2734580	et	4	main
kaupluse	doc_572002200599_item	2734581	et	3	main
juhatajale	doc_572002200599_item	2734582	et	4	main
xxx	doc_572002200599_item	2734583	et	4	main
yyy	doc_572002200599_item	2734584	et	4	main
p	doc_572002200599_item	2734585	et	4	main
kaebus	doc_572002200599_item	2734586	et	3	main
kauplusest	doc_572002200599_item	2734597	et	4	main
peale	doc_572002200599_item	2734606	et	4	main
ja	doc_572002200599_item	2734608	et	3	main
katki	doc_572002200599_item	2734616	et	4	main
läinud	doc_572002200599_item	2734617	et	4	main
alguses	doc_572002200599_item	2734618	et	4	main
sisse	doc_572002200599_item	2734629	et	4	main
see	doc_572002200599_item	2734649	et	3	main
sisse	doc_572002200599_item	2734657	et	4	main
palun	doc_572002200599_item	2734661	et	3	main
ära	doc_572002200599_item	2734665	et	4	main
või	doc_572002200599_item	2734666	et	4	main
3200	doc_572002200599_item	2734670	et	2	main
kolm	doc_572002200599_item	2734671	et	3	main
saata	doc_572002200600_item	2734717	et	3	main
selles	doc_572002200600_item	2734722	et	4	main
kas	doc_572002200600_item	2734735	et	3	main
väärt	doc_572002200600_item	2734739	et	4	main
tööintervjuul	doc_572002200600_item	2734740	et	3	main
tuleb	doc_572002200600_item	2734741	et	3	main
tuleb	doc_572002200600_item	2734748	et	3	main
rääkida	doc_572002200600_item	2734749	et	3	main
ainult	doc_572002200600_item	2734750	et	4	main
kalleid	doc_572002200600_item	2734764	et	3	main
sõltub	doc_572002200600_item	2734767	et	3	main
tahad	doc_572002200600_item	2734772	et	3	main
tahad	doc_572002200600_item	2734774	et	3	main
ametit	doc_572002200600_item	2734776	et	3	main
siis	doc_572002200600_item	2734778	et	3	main
prismasse	doc_572002200600_item	2734783	et	3	main
passiivne	doc_572002200601_item	2734821	et	3	main
ostmise	doc_572002200601_item	2734826	et	4	main
plussid	doc_572002200601_item	2734827	et	3	main
sa	doc_572002200601_item	2734828	et	3	main
vaadata	doc_572002200601_item	2734833	et	4	main
ja	doc_572002200601_item	2734834	et	3	main
valida	doc_572002200601_item	2734835	et	3	main
ja	doc_572002200601_item	2734844	et	3	main
kaupa	doc_572002200601_item	2734854	et	4	main
millist	doc_572002200601_item	2734855	et	3	main
peab	doc_572002200601_item	2734862	et	4	main
olema	doc_572002200601_item	2734863	et	4	main
ostutšekile	doc_572002200601_item	2734868	et	2	main
olema	doc_572002200601_item	2734870	et	4	main
koolis	doc_572002200601_item	2734903	et	4	main
muuta	doc_572002200601_item	2734904	et	4	main
ma	doc_572002200601_item	2734905	et	3	main
koolis	doc_572002200601_item	2734910	et	4	main
muuta	doc_572002200601_item	2734911	et	4	main
võib	doc_572002200601_item	2734912	et	3	main
olla	doc_572002200601_item	2734913	et	3	main
ei	doc_572002200601_item	2734919	et	4	main
hindeid	doc_572002200601_item	2734921	et	3	main
oleks	doc_572002200601_item	2734923	et	3	main
endale	doc_572002200601_item	2734930	et	4	main
koolitunnistuse	doc_572002200601_item	2734932	et	3	main
või	doc_572002200601_item	2734933	et	4	main
ma	doc_572002200601_item	2734938	et	3	main
arvan	doc_572002200601_item	2734939	et	3	main
et	doc_572002200601_item	2734940	et	3	main
hindeid	doc_572002200601_item	2734941	et	3	main
eriti	doc_572002200601_item	2734942	et	3	main
ei	doc_572002200601_item	2734943	et	4	main
eluiga	doc_572002200601_item	2734949	et	4	main
elustiilist	doc_572002200601_item	2734954	et	4	main
ei	doc_572002200601_item	2734959	et	4	main
eluiga	doc_572002200601_item	2734967	et	4	main
raha	doc_572002200601_item	2734995	et	4	main
inimeste	doc_572002200601_item	2734996	et	3	main
toetamiseks	doc_572002200601_item	2734997	et	4	main
kontrolltöö	doc_572002200602_item	2734999	et	4	main
olema	doc_572002200602_item	2735002	et	4	main
tõsi	doc_572002200602_item	2735008	et	4	main
sa	doc_572002200602_item	2735009	et	3	main
õppinud	doc_572002200602_item	2735020	et	4	main
ära	doc_572002200602_item	2735047	et	4	main
tugev	doc_572002200602_item	2735050	et	4	main
pead	doc_572002200602_item	2735059	et	4	main
rääkima	doc_572002200602_item	2735060	et	3	main
ja	doc_572002200602_item	2735066	et	3	main
kaudu	doc_572002200602_item	2735072	et	3	main
pean	doc_572002200602_item	2735076	et	4	main
väike	doc_572002200599_item	2734622	et	4	main
mis	doc_572002200599_item	2734624	et	4	main
tv	doc_572002200599_item	2734627	et	4	main
on	doc_572002200599_item	2734628	et	4	main
ära	doc_572002200599_item	2734634	et	4	main
siis	doc_572002200599_item	2734635	et	3	main
ja	doc_572002200599_item	2734639	et	3	main
panna	doc_572002200599_item	2734648	et	4	main
reageeri	doc_572002200599_item	2734652	et	4	main
tagastada	doc_572002200599_item	2734667	et	3	main
eek	doc_572002200599_item	2734674	et	4	main
p	doc_572002200599_item	2734675	et	4	main
xxx	doc_572002200599_item	2734676	et	4	main
yyy	doc_572002200599_item	2734677	et	4	main
kontaktandmedbr	doc_572002200599_item	2734678	et	4	main
tel	doc_572002200599_item	2734679	et	4	main
056	doc_572002200599_item	2734680	et	2	main
1223456	doc_572002200599_item	2734681	et	2	main
e-mail	doc_572002200599_item	2734682	et	4	main
xyyspan	doc_572002200599_item	2734683	et	4	main
kontrolltöö	doc_572002200600_item	2734684	et	4	main
tööintervjuuks	doc_572002200600_item	2734685	et	3	main
ei	doc_572002200600_item	2734686	et	4	main
pea	doc_572002200600_item	2734687	et	4	main
valmistuma	doc_572002200600_item	2734688	et	3	main
ma	doc_572002200600_item	2734689	et	3	main
usun	doc_572002200600_item	2734690	et	3	main
et	doc_572002200600_item	2734691	et	3	main
ikkagi	doc_572002200600_item	2734692	et	4	main
peab	doc_572002200600_item	2734693	et	4	main
tööintervjuuks	doc_572002200600_item	2734694	et	3	main
valmistuma	doc_572002200600_item	2734695	et	3	main
vähemalt	doc_572002200600_item	2734696	et	4	main
peab	doc_572002200600_item	2734697	et	4	main
ennast	doc_572002200600_item	2734698	et	4	main
nüüd	doc_572002200599_item	2734640	et	4	main
ei	doc_572002200599_item	2734643	et	4	main
selle	doc_572002200599_item	2734645	et	4	main
kuidagimoodi	doc_572002200599_item	2734646	et	3	main
käima	doc_572002200599_item	2734647	et	4	main
käsitsi	doc_572002200599_item	2734656	et	3	main
käesolevaga	doc_572002200599_item	2734659	et	3	main
teid	doc_572002200599_item	2734662	et	4	main
vahetada	doc_572002200599_item	2734663	et	3	main
tuhat	doc_572002200599_item	2734672	et	4	main
ja	doc_572002200600_item	2734701	et	3	main
rahulik	doc_572002200600_item	2734703	et	3	main
väljanägemine	doc_572002200600_item	2734705	et	3	main
ja	doc_572002200600_item	2734706	et	3	main
p	doc_572002200600_item	2734712	et	4	main
tugevatest	doc_572002200600_item	2734745	et	4	main
sinu	doc_572002200600_item	2734753	et	3	main
muidugi	doc_572002200600_item	2734757	et	4	main
tööotsija	doc_572002200600_item	2734761	et	4	main
peab	doc_572002200600_item	2734762	et	4	main
see	doc_572002200600_item	2734766	et	3	main
kellena	doc_572002200600_item	2734769	et	3	main
töötada	doc_572002200600_item	2734771	et	3	main
kõrget	doc_572002200600_item	2734775	et	4	main
aga	doc_572002200600_item	2734780	et	3	main
lähed	doc_572002200600_item	2734782	et	3	main
müüjana	doc_572002200600_item	2734784	et	4	main
võib	doc_572002200600_item	2734788	et	3	main
üldse	doc_572002200599_item	2734642	et	3	main
saa	doc_572002200599_item	2734644	et	4	main
televiisor	doc_572002200599_item	2734650	et	3	main
ega	doc_572002200599_item	2734655	et	3	main
selle	doc_572002200599_item	2734664	et	4	main
raha	doc_572002200599_item	2734668	et	4	main
kakssada	doc_572002200599_item	2734673	et	4	main
korda	doc_572002200600_item	2734699	et	4	main
rahulolu	doc_572002200600_item	2734707	et	4	main
on	doc_572002200600_item	2734708	et	4	main
töökonkursile	doc_572002200600_item	2734713	et	3	main
ka	doc_572002200600_item	2734718	et	3	main
puldist	doc_572002200599_item	2734654	et	3	main
lülitamisele	doc_572002200599_item	2734658	et	4	main
ma	doc_572002200599_item	2734660	et	3	main
summas	doc_572002200599_item	2734669	et	4	main
olema	doc_572002200600_item	2734702	et	4	main
hea	doc_572002200600_item	2734704	et	4	main
tähtsad	doc_572002200600_item	2734710	et	3	main
küll	doc_572002200600_item	2734721	et	4	main
mõttes	doc_572002200600_item	2734723	et	3	main
et	doc_572002200600_item	2734724	et	3	main
avaldus	doc_572002200600_item	2734725	et	4	main
ainult	doc_572002200600_item	2734743	et	4	main
oma	doc_572002200600_item	2734744	et	4	main
mitte	doc_572002200600_item	2734758	et	3	main
riideid	doc_572002200600_item	2734765	et	3	main
kui	doc_572002200600_item	2734773	et	3	main
küll	doc_572002200600_item	2734779	et	4	main
kui	doc_572002200600_item	2734781	et	3	main
siis	doc_572002200600_item	2734786	et	3	main
puuduseks	doc_572002200600_item	2734790	et	4	main
selle	doc_572002200601_item	2734849	et	4	main
kätte	doc_572002200601_item	2734850	et	4	main
inimene	doc_572002200601_item	2734851	et	3	main
võib	doc_572002200601_item	2734852	et	3	main
tagastada	doc_572002200601_item	2734853	et	3	main
mis	doc_572002200601_item	2734861	et	4	main
ostutšekile	doc_572002200601_item	2734866	et	2	main
peab	doc_572002200601_item	2734869	et	4	main
kirjutatud	doc_572002200601_item	2734871	et	4	main
andmed	doc_572002200601_item	2734872	et	3	main
millal	doc_572002200601_item	2734873	et	3	main
teagi	doc_572002200601_item	2734907	et	4	main
muudaksin	doc_572002200601_item	2734914	et	3	main
et	doc_572002200601_item	2734925	et	3	main
või	doc_572002200601_item	2734927	et	4	main
saaks	doc_572002200601_item	2734929	et	3	main
inimese	doc_572002200601_item	2734945	et	4	main
toitumisest	doc_572002200601_item	2734953	et	4	main
meie	doc_572002200601_item	2734970	et	4	main
peab	doc_572002200602_item	2735001	et	4	main
lühike	doc_572002200602_item	2735003	et	4	main
ja	doc_572002200602_item	2735004	et	3	main
lakooniline	doc_572002200602_item	2735005	et	3	main
see	doc_572002200602_item	2735006	et	3	main
pole	doc_572002200602_item	2735007	et	3	main
pead	doc_572002200602_item	2735010	et	4	main
kirjutada	doc_572002200602_item	2735011	et	3	main
kõik	doc_572002200602_item	2735012	et	4	main
ja	doc_572002200602_item	2735021	et	3	main
peaks	doc_572002200602_item	2735026	et	4	main
ei	doc_572002200602_item	2735057	et	4	main
küsivad	doc_572002200602_item	2735065	et	4	main
rohkem	doc_572002200602_item	2735068	et	4	main
miinused	doc_572002200602_item	2735074	et	3	main
ma	doc_572002200602_item	2735084	et	3	main
kvaliteet	doc_572002200602_item	2735087	et	3	main
pildil	doc_572002200602_item	2735090	et	3	main
panema	doc_572002200600_item	2734700	et	3	main
kõige	doc_572002200600_item	2734709	et	4	main
asjad	doc_572002200600_item	2734711	et	3	main
tuleb	doc_572002200600_item	2734714	et	3	main
koos	doc_572002200600_item	2734715	et	4	main
cv-ga	doc_572002200600_item	2734716	et	3	main
avaldus	doc_572002200600_item	2734719	et	4	main
tuleb	doc_572002200600_item	2734720	et	3	main
oled	doc_572002200600_item	2734737	et	3	main
külgedest	doc_572002200600_item	2734746	et	4	main
tööintervjuul	doc_572002200600_item	2734747	et	3	main
küsitakse	doc_572002200600_item	2734752	et	4	main
käest	doc_572002200600_item	2734754	et	4	main
ja	doc_572002200600_item	2734756	et	3	main
jne	doc_572002200600_item	2734760	et	4	main
kandma	doc_572002200600_item	2734763	et	3	main
töötama	doc_572002200600_item	2734785	et	3	main
juba	doc_572002200600_item	2734789	et	3	main
võid	doc_572002200601_item	2734829	et	4	main
rahulikult	doc_572002200601_item	2734830	et	4	main
kodus	doc_572002200601_item	2734831	et	4	main
sobiva	doc_572002200601_item	2734837	et	4	main
tuuakse	doc_572002200601_item	2734840	et	3	main
tellimusi	doc_572002200601_item	2734843	et	3	main
või	doc_572002200601_item	2734859	et	4	main
kirjutatud	doc_572002200601_item	2734864	et	4	main
olema	doc_572002200601_item	2734899	et	4	main
mida	doc_572002200601_item	2734901	et	4	main
mida	doc_572002200601_item	2734908	et	4	main
sooviksin	doc_572002200601_item	2734909	et	3	main
pannaks	doc_572002200601_item	2734920	et	4	main
annab	doc_572002200600_item	2734726	et	3	main
teada	doc_572002200600_item	2734727	et	3	main
mida	doc_572002200600_item	2734728	et	4	main
sa	doc_572002200600_item	2734729	et	3	main
tahad	doc_572002200600_item	2734730	et	3	main
ja	doc_572002200600_item	2734731	et	3	main
cv	doc_572002200600_item	2734732	et	4	main
annab	doc_572002200600_item	2734733	et	3	main
teada	doc_572002200600_item	2734734	et	3	main
sa	doc_572002200600_item	2734736	et	3	main
seda	doc_572002200600_item	2734738	et	3	main
rääkida	doc_572002200600_item	2734742	et	3	main
kui	doc_572002200600_item	2734751	et	3	main
midagi	doc_572002200600_item	2734755	et	4	main
pereprobleemidest	doc_572002200600_item	2734759	et	3	main
sellest	doc_572002200600_item	2734768	et	4	main
sa	doc_572002200600_item	2734770	et	3	main
saada	doc_572002200600_item	2734777	et	4	main
see	doc_572002200600_item	2734787	et	3	main
olla	doc_572002200600_item	2734791	et	3	main
kontrolltöö	doc_572002200601_item	2734792	et	4	main
mida	doc_572002200601_item	2734793	et	4	main
ei	doc_572002200601_item	2734794	et	4	main
ole	doc_572002200601_item	2734795	et	4	main
soovitatav	doc_572002200601_item	2734796	et	4	main
tööintervjuul	doc_572002200601_item	2734797	et	3	main
teha	doc_572002200601_item	2734798	et	3	main
tööintervjuul	doc_572002200601_item	2734799	et	3	main
ei	doc_572002200601_item	2734800	et	4	main
soovitatav	doc_572002200601_item	2734802	et	4	main
ole	doc_572002200601_item	2734801	et	4	main
palju	doc_572002200601_item	2734803	et	4	main
rääkida	doc_572002200601_item	2734804	et	3	main
e	doc_572002200601_item	2734805	et	4	main
lobiseda	doc_572002200601_item	2734806	et	3	main
tööintervjuule	doc_572002200601_item	2734807	et	3	main
ei	doc_572002200601_item	2734808	et	4	main
tohi	doc_572002200601_item	2734809	et	4	main
hiljaks	doc_572002200601_item	2734810	et	3	main
jääda	doc_572002200601_item	2734811	et	4	main
tööinterjuule	doc_572002200601_item	2734812	et	4	main
ei	doc_572002200601_item	2734813	et	4	main
tohi	doc_572002200601_item	2734814	et	4	main
korratu	doc_572002200601_item	2734815	et	4	main
tulla	doc_572002200601_item	2734816	et	3	main
tööintervjuul	doc_572002200601_item	2734817	et	3	main
ei	doc_572002200601_item	2734818	et	4	main
soovitatav	doc_572002200601_item	2734819	et	4	main
olla	doc_572002200601_item	2734820	et	3	main
on	doc_572002200601_item	2734823	et	4	main
kataloogi	doc_572002200601_item	2734824	et	4	main
mis	doc_572002200601_item	2734822	et	4	main
endale	doc_572002200601_item	2734836	et	4	main
rõiva	doc_572002200601_item	2734838	et	3	main
sulle	doc_572002200601_item	2734839	et	3	main
koju	doc_572002200601_item	2734841	et	3	main
sina	doc_572002200601_item	2734845	et	4	main
väljumata	doc_572002200601_item	2734847	et	4	main
ei	doc_572002200601_item	2734857	et	4	main
meeldinud	doc_572002200601_item	2734858	et	4	main
sobinud	doc_572002200601_item	2734860	et	4	main
korrektsele	doc_572002200601_item	2734865	et	3	main
seda	doc_572002200601_item	2734874	et	3	main
kaupa	doc_572002200601_item	2734875	et	4	main
osteti	doc_572002200601_item	2734876	et	3	main
peab	doc_572002200601_item	2734877	et	4	main
olema	doc_572002200601_item	2734878	et	4	main
kirjas	doc_572002200601_item	2734879	et	4	main
kauba	doc_572002200601_item	2734880	et	3	main
nimetus	doc_572002200601_item	2734881	et	4	main
ja	doc_572002200601_item	2734882	et	3	main
hind	doc_572002200601_item	2734883	et	3	main
peal	doc_572002200601_item	2734884	et	4	main
peavad	doc_572002200601_item	2734885	et	4	main
olema	doc_572002200601_item	2734886	et	4	main
kaupluse	doc_572002200601_item	2734887	et	3	main
andmed	doc_572002200601_item	2734888	et	3	main
selliseid	doc_572002200601_item	2734889	et	4	main
nagu	doc_572002200601_item	2734890	et	3	main
registri	doc_572002200601_item	2734891	et	3	main
kood	doc_572002200601_item	2734892	et	4	main
asutuse	doc_572002200601_item	2734893	et	4	main
firma	doc_572002200601_item	2734894	et	4	main
nimetus	doc_572002200601_item	2734895	et	4	main
kindlasti	doc_572002200601_item	2734897	et	3	main
ja	doc_572002200601_item	2734896	et	3	main
kaudu	doc_572002200601_item	2734825	et	3	main
istudes	doc_572002200601_item	2734832	et	4	main
sinu	doc_572002200601_item	2734842	et	3	main
kodunt	doc_572002200601_item	2734846	et	3	main
saad	doc_572002200601_item	2734848	et	4	main
talle	doc_572002200601_item	2734856	et	4	main
korrektsele	doc_572002200601_item	2734867	et	3	main
peab	doc_572002200601_item	2734898	et	4	main
tempel	doc_572002200601_item	2734900	et	3	main
sooviksite	doc_572002200601_item	2734902	et	3	main
ainult	doc_572002200601_item	2734915	et	4	main
asja	doc_572002200601_item	2734917	et	4	main
mina	doc_572002200601_item	2734918	et	4	main
kätte	doc_572002200601_item	2734935	et	4	main
ilma	doc_572002200601_item	2734936	et	4	main
teadmist	doc_572002200601_item	2734946	et	4	main
millest	doc_572002200601_item	2734947	et	3	main
sõltub	doc_572002200601_item	2734948	et	3	main
eluiga	doc_572002200601_item	2734956	et	4	main
ka	doc_572002200601_item	2734969	et	3	main
p	doc_572002200601_item	2734998	et	4	main
sa	doc_572002200602_item	2735018	et	3	main
enne	doc_572002200602_item	2735023	et	4	main
tööintervjuule	doc_572002200602_item	2735024	et	3	main
mul	doc_572002200602_item	2735039	et	3	main
on	doc_572002200602_item	2735040	et	4	main
kallist	doc_572002200602_item	2735044	et	4	main
lõhnaõli	doc_572002200602_item	2735045	et	4	main
ei	doc_572002200602_item	2735046	et	4	main
väga	doc_572002200602_item	2735049	et	3	main
tööotsija	doc_572002200602_item	2735052	et	4	main
mis	doc_572002200602_item	2735069	et	4	main
ostmise	doc_572002200602_item	2735073	et	4	main
kaua	doc_572002200602_item	2735077	et	3	main
mis	doc_572002200602_item	2735083	et	4	main
tellin	doc_572002200602_item	2735085	et	3	main
tihti	doc_572002200602_item	2735088	et	3	main
parem	doc_572002200602_item	2735092	et	4	main
aga	doc_572002200602_item	2735093	et	3	main
kui	doc_572002200602_item	2735094	et	3	main
ei	doc_572002200601_item	2734906	et	4	main
üht	doc_572002200601_item	2734916	et	3	main
diploomi	doc_572002200601_item	2734934	et	4	main
näita	doc_572002200601_item	2734944	et	4	main
pärilikkusest	doc_572002200601_item	2734952	et	4	main
et	doc_572002200601_item	2734955	et	3	main
pikkem	doc_572002200601_item	2734958	et	4	main
tohi	doc_572002200601_item	2734960	et	4	main
suitsetada	doc_572002200601_item	2734961	et	3	main
alkoholi	doc_572002200601_item	2734962	et	4	main
juua	doc_572002200601_item	2734963	et	3	main
ja	doc_572002200601_item	2734964	et	3	main
narkootikume	doc_572002200601_item	2734965	et	3	main
sõltub	doc_572002200601_item	2734968	et	3	main
oled	doc_572002200602_item	2735019	et	3	main
ma	doc_572002200602_item	2735034	et	3	main
pean	doc_572002200602_item	2735035	et	4	main
teada	doc_572002200602_item	2735036	et	3	main
mis	doc_572002200602_item	2735037	et	4	main
palk	doc_572002200602_item	2735038	et	3	main
peaks	doc_572002200602_item	2735042	et	4	main
kasutama	doc_572002200602_item	2735043	et	3	main
parfüümi	doc_572002200602_item	2735051	et	4	main
peaks	doc_572002200602_item	2735053	et	4	main
intervjuul	doc_572002200602_item	2735054	et	3	main
palju	doc_572002200602_item	2735055	et	4	main
rääkima	doc_572002200602_item	2735056	et	3	main
mida	doc_572002200602_item	2735063	et	4	main
ma	doc_572002200602_item	2735075	et	3	main
võib-olla	doc_572002200602_item	2735081	et	3	main
kehv	doc_572002200602_item	2735086	et	3	main
kaup	doc_572002200602_item	2735089	et	3	main
kaalep	doc_573958253416_item	2735241	et	4	main
kirjutab	doc_573958253416_item	2735242	et	3	main
lugenud	doc_573958253416_item	2735248	et	4	main
tänapäeval	doc_573958253416_item	2735258	et	3	main
ole	doc_573958253416_item	2735260	et	4	main
abituriendid	doc_573958253416_item	2735261	et	3	main
te	doc_573958253416_item	2735264	et	4	main
kirjutate	doc_573958253416_item	2735265	et	3	main
ühiskond	doc_573958253416_item	2735267	et	3	main
verd	doc_573958253416_item	2735273	et	3	main
selliseid	doc_573958253416_item	2735284	et	4	main
meditsiinisüsteemi	doc_573958253416_item	2735290	et	4	main
mis	doc_573958253416_item	2735292	et	4	main
ja	doc_573958253416_item	2735296	et	3	main
sellega	doc_573958253416_item	2735305	et	3	main
tänavu	doc_573958253416_item	2735309	et	3	main
abiturientide	doc_573958253416_item	2735311	et	3	main
passiivsed	doc_573958253416_item	2735321	et	3	main
muuta	doc_573958253416_item	2735325	et	4	main
lepivad	doc_573958253416_item	2735329	et	3	main
kokku	doc_573958253416_item	2735333	et	3	main
paremuse	doc_573958253416_item	2735336	et	4	main
et	doc_572002200601_item	2734922	et	3	main
niimoodi	doc_572002200601_item	2734924	et	3	main
õpilane	doc_572002200601_item	2734926	et	3	main
üliõpilane	doc_572002200601_item	2734928	et	3	main
oma	doc_572002200601_item	2734931	et	4	main
hinnetelehe	doc_572002200601_item	2734937	et	4	main
eluiga	doc_572002200601_item	2734950	et	4	main
sõltub	doc_572002200601_item	2734951	et	3	main
oleks	doc_572002200601_item	2734957	et	3	main
tarbitada	doc_572002200601_item	2734966	et	4	main
keskkkonnast	doc_572002200601_item	2734971	et	4	main
ja	doc_572002200601_item	2734972	et	3	main
riigi	doc_572002200601_item	2734973	et	3	main
tasandist	doc_572002200601_item	2734974	et	3	main
muidugi	doc_572002200601_item	2734975	et	4	main
on	doc_572002200601_item	2734976	et	4	main
eluiga	doc_572002200601_item	2734977	et	4	main
pikkem	doc_572002200601_item	2734978	et	4	main
seal	doc_572002200601_item	2734979	et	4	main
kus	doc_572002200601_item	2734980	et	3	main
on	doc_572002200601_item	2734981	et	4	main
hea	doc_572002200601_item	2734982	et	4	main
kliimat	doc_572002200601_item	2734983	et	3	main
mis	doc_572002200601_item	2734984	et	4	main
sobib	doc_572002200601_item	2734985	et	3	main
inimeste	doc_572002200601_item	2734987	et	3	main
paremine	doc_572002200601_item	2734986	et	4	main
jaoks	doc_572002200601_item	2734988	et	4	main
ja	doc_572002200601_item	2734989	et	3	main
on	doc_572002200601_item	2734990	et	4	main
rikkas	doc_572002200601_item	2734991	et	4	main
riik	doc_572002200601_item	2734992	et	3	main
et	doc_572002200601_item	2734993	et	3	main
jätkub	doc_572002200601_item	2734994	et	3	main
cv	doc_572002200602_item	2735000	et	4	main
mida	doc_572002200602_item	2735013	et	4	main
sa	doc_572002200602_item	2735014	et	3	main
oskad	doc_572002200602_item	2735015	et	3	main
ja	doc_572002200602_item	2735016	et	3	main
kus	doc_572002200602_item	2735017	et	3	main
töötanud	doc_572002200602_item	2735022	et	4	main
minekut	doc_572002200602_item	2735025	et	3	main
tutvuma	doc_572002200602_item	2735027	et	3	main
firmaga	doc_572002200602_item	2735028	et	3	main
kuhu	doc_572002200602_item	2735029	et	3	main
soovite	doc_572002200602_item	2735030	et	3	main
tööle	doc_572002200602_item	2735031	et	3	main
saada	doc_572002200602_item	2735032	et	4	main
ja	doc_572002200602_item	2735033	et	3	main
tööotsija	doc_572002200602_item	2735041	et	4	main
kasuta	doc_572002200602_item	2735048	et	4	main
sa	doc_572002200602_item	2735058	et	3	main
ainult	doc_572002200602_item	2735061	et	4	main
see	doc_572002200602_item	2735062	et	3	main
nad	doc_572002200602_item	2735064	et	3	main
mitte	doc_572002200602_item	2735067	et	3	main
on	doc_572002200602_item	2735070	et	4	main
kataloogi	doc_572002200602_item	2735071	et	4	main
tellimus	doc_572002200602_item	2735080	et	3	main
sa	doc_572002200602_item	2735095	et	3	main
saatis	doc_572002200602_item	2735096	et	3	main
kauba	doc_572002200602_item	2735097	et	3	main
sis	doc_572002200602_item	2735098	et	3	main
ta	doc_572002200602_item	2735099	et	4	main
ei	doc_572002200602_item	2735100	et	4	main
ole	doc_572002200602_item	2735101	et	4	main
nii	doc_572002200602_item	2735102	et	3	main
hea	doc_572002200602_item	2735103	et	4	main
oodata	doc_572002200602_item	2735078	et	4	main
oma	doc_572002200602_item	2735079	et	4	main
kaup	doc_572002200602_item	2735082	et	3	main
on	doc_572002200602_item	2735091	et	4	main
olen	doc_573958253416_item	2735247	et	3	main
artikli	doc_573958253416_item	2735250	et	3	main
selles	doc_573958253416_item	2735253	et	4	main
ambitsioonikad	doc_573958253416_item	2735263	et	4	main
vajab	doc_573958253416_item	2735268	et	3	main
särtsu	doc_573958253416_item	2735271	et	4	main
kes	doc_573958253416_item	2735275	et	4	main
ja	doc_573958253416_item	2735277	et	3	main
inimesi	doc_573958253416_item	2735285	et	4	main
muuta	doc_573958253416_item	2735299	et	4	main
seas	doc_573958253416_item	2735312	et	4	main
selliseid	doc_573958253416_item	2735315	et	4	main
keda	doc_573958253416_item	2735316	et	4	main
ühiskond	doc_573958253416_item	2735317	et	3	main
taha	doc_573958253416_item	2735323	et	4	main
palgaga	doc_573958253416_item	2735331	et	3	main
ega	doc_573958253416_item	2735334	et	3	main
jaoks	doc_573958253416_item	2735342	et	4	main
ise	doc_573958253416_item	2735347	et	4	main
sellepärast	doc_573958253416_item	2735349	et	3	main
avaldada	doc_573958253416_item	2735354	et	3	main
öelda	doc_573958253416_item	2735357	et	4	main
et	doc_573958253416_item	2735358	et	3	main
ma	doc_573958253416_item	2735359	et	3	main
ei	doc_573958253416_item	2735360	et	4	main
nõus	doc_573958253416_item	2735364	et	4	main
kellest	doc_573958253416_item	2735382	et	4	main
kirjutasite	doc_573958253416_item	2735384	et	3	main
hakka	doc_573958253416_item	2735428	et	4	main
kindlasti	doc_573958253416_item	2735429	et	3	main
avaliku	doc_573958253416_item	2735430	et	3	main
sektori	doc_573958253416_item	2735431	et	3	main
võtmepositsiione	doc_573958253416_item	2735433	et	4	main
võtma	doc_573958253416_item	2735434	et	3	main
neil	doc_573958253416_item	2735435	et	4	main
nõuab	doc_573958253416_item	2735441	et	3	main
kaasa	doc_573958253416_item	2735445	et	4	main
on	doc_573958253416_item	2735449	et	4	main
kindlasti	doc_573958253416_item	2735450	et	3	main
valmis	doc_573958253416_item	2735456	et	4	main
need	doc_573958253416_item	2735457	et	3	main
inimesed	doc_573958253416_item	2735493	et	3	main
eestist	doc_573958253416_item	2735524	et	3	main
selle	doc_573958253416_item	2735532	et	4	main
eest	doc_573958253416_item	2735533	et	4	main
makstakse	doc_573958253416_item	2735534	et	3	main
rohkem	doc_573958253416_item	2735535	et	4	main
siis	doc_573958253416_item	2735536	et	3	main
tekibki	doc_573958253416_item	2735537	et	3	main
jää	doc_573958253416_item	2735544	et	4	main
riik	doc_573958253416_item	2735554	et	3	main
teiste	doc_573958253416_item	2735556	et	4	main
piisavalt	doc_573958253416_item	2735566	et	4	main
olemas	doc_573958253416_item	2735580	et	4	main
selliseid	doc_573958253416_item	2735581	et	4	main
kes	doc_573958253416_item	2735582	et	4	main
ei	doc_573958253416_item	2735583	et	4	main
nad	doc_573958253416_item	2735588	et	3	main
seevastu	doc_573958253416_item	2735590	et	3	main
otsivad	doc_573958253416_item	2735607	et	4	main
valdkonnas	doc_573958253416_item	2735611	et	4	main
võib	doc_573958253416_item	2735613	et	3	main
kiri	doc_573958253416_item	2735238	et	3	main
lugupeetud	doc_573958253416_item	2735239	et	4	main
teile	doc_573958253416_item	2735243	et	4	main
vähenõudlike	doc_573958253416_item	2735251	et	3	main
ja	doc_573958253416_item	2735270	et	3	main
tahavad	doc_573958253416_item	2735276	et	3	main
saavadki	doc_573958253416_item	2735278	et	4	main
ja	doc_573958253416_item	2735280	et	3	main
on	doc_573958253416_item	2735282	et	4	main
vaja	doc_573958253416_item	2735283	et	4	main
kes	doc_573958253416_item	2735286	et	4	main
mittetoimiva	doc_573958253416_item	2735289	et	3	main
vead	doc_573958253416_item	2735293	et	4	main
hariduses	doc_573958253416_item	2735295	et	3	main
seda	doc_573958253416_item	2735298	et	3	main
võtaksid	doc_573958253416_item	2735300	et	4	main
avalikus	doc_573958253416_item	2735301	et	4	main
teie	doc_573958253416_item	2735306	et	4	main
et	doc_573958253416_item	2735308	et	3	main
aasta	doc_573958253416_item	2735310	et	4	main
keskmise	doc_573958253416_item	2735330	et	3	main
töökohtadega	doc_573958253416_item	2735332	et	3	main
olen	doc_573958253416_item	2735346	et	3	main
ole	doc_573958253416_item	2735361	et	4	main
sellega	doc_573958253416_item	2735362	et	3	main
seas	doc_573958253416_item	2735366	et	4	main
passiivseid	doc_573958253416_item	2735370	et	3	main
kui	doc_573958253416_item	2735371	et	3	main
ka	doc_573958253416_item	2735372	et	3	main
väga	doc_573958253416_item	2735373	et	3	main
aktiivseid	doc_573958253416_item	2735374	et	3	main
inimesi	doc_573958253416_item	2735375	et	4	main
need	doc_573958253416_item	2735381	et	3	main
mitmesuguseid	doc_573958253416_item	2735432	et	3	main
vaja	doc_573958253416_item	2735439	et	4	main
see	doc_573958253416_item	2735440	et	3	main
suuremaid	doc_573958253416_item	2735446	et	4	main
on	doc_573958253416_item	2735454	et	4	main
selleks	doc_573958253416_item	2735455	et	4	main
või	doc_573958253416_item	2735468	et	4	main
meditsiinisüsteem	doc_573958253416_item	2735469	et	3	main
või	doc_573958253416_item	2735470	et	4	main
hoopis	doc_573958253416_item	2735471	et	3	main
tootearendus	doc_573958253416_item	2735472	et	3	main
inimesed	doc_573958253416_item	2735478	et	3	main
need	doc_573958253416_item	2735492	et	3	main
tiina	doc_573958253416_item	2735240	et	4	main
põlvkond	doc_573958253416_item	2735252	et	3	main
väidate	doc_573958253416_item	2735256	et	3	main
uut	doc_573958253416_item	2735272	et	3	main
neid	doc_573958253416_item	2735274	et	4	main
ümber	doc_573958253416_item	2735288	et	3	main
suudaksid	doc_573958253416_item	2735297	et	4	main
sektoris	doc_573958253416_item	2735302	et	3	main
jõuga	doc_573958253416_item	2735303	et	3	main
võtmepositsioone	doc_573958253416_item	2735304	et	3	main
ei	doc_573958253416_item	2735313	et	4	main
ole	doc_573958253416_item	2735314	et	4	main
midagi	doc_573958253416_item	2735324	et	4	main
riigis	doc_573958253416_item	2735327	et	3	main
püüdle	doc_573958253416_item	2735335	et	4	main
poole	doc_573958253416_item	2735337	et	4	main
on	doc_573958253416_item	2735340	et	4	main
minu	doc_573958253416_item	2735341	et	3	main
aktuaalne	doc_573958253416_item	2735344	et	3	main
abiturient	doc_573958253416_item	2735348	et	3	main
om	doc_573958253416_item	2735351	et	4	main
ka	doc_573958253416_item	2735353	et	3	main
täielikult	doc_573958253416_item	2735363	et	4	main
passiivsete	doc_573958253416_item	2735377	et	3	main
hulka	doc_573958253416_item	2735378	et	4	main
kuuluvad	doc_573958253416_item	2735379	et	4	main
korter	doc_573958253416_item	2735421	et	3	main
riided	doc_573958253416_item	2735423	et	3	main
jne	doc_573958253416_item	2735424	et	4	main
ja	doc_573958253416_item	2735443	et	3	main
kes	doc_573958253416_item	2735453	et	4	main
midagi	doc_573958253416_item	2735461	et	4	main
ümber	doc_573958253416_item	2735462	et	3	main
särtsakad	doc_573958253416_item	2735475	et	3	main
vaprad	doc_573958253416_item	2735477	et	3	main
kes	doc_573958253416_item	2735479	et	4	main
aina	doc_573958253416_item	2735481	et	4	main
poole	doc_573958253416_item	2735483	et	4	main
juhid	doc_573958253416_item	2735491	et	4	main
teistele	doc_573958253416_item	2735529	et	4	main
riikidele	doc_573958253416_item	2735530	et	3	main
uudishimulisi	doc_573958253416_item	2735547	et	4	main
aktiivseid	doc_573958253416_item	2735549	et	3	main
on	doc_573958253416_item	2735552	et	4	main
ja	doc_573958253416_item	2735559	et	3	main
riikidega	doc_573958253416_item	2735561	et	3	main
püütakse	doc_573958253416_item	2735570	et	3	main
tahaks	doc_573958253416_item	2735573	et	3	main
et	doc_573958253416_item	2735575	et	3	main
milleks	doc_573958253416_item	2735587	et	4	main
ja	doc_573958253416_item	2735594	et	3	main
aktiivseid	doc_573958253416_item	2735595	et	3	main
ei	doc_573958253416_item	2735598	et	4	main
arenguvõimalusi	doc_573958253416_item	2735609	et	3	main
siin	doc_573958253416_item	2735612	et	4	main
selle	doc_573958253416_item	2735244	et	4	main
aasta	doc_573958253416_item	2735245	et	4	main
abiturient	doc_573958253416_item	2735246	et	3	main
teie	doc_573958253416_item	2735249	et	4	main
artiklis	doc_573958253416_item	2735254	et	3	main
teie	doc_573958253416_item	2735255	et	4	main
et	doc_573958253416_item	2735257	et	3	main
ei	doc_573958253416_item	2735259	et	4	main
sugugi	doc_573958253416_item	2735262	et	4	main
et	doc_573958253416_item	2735266	et	3	main
värskust	doc_573958253416_item	2735269	et	3	main
ministriks	doc_573958253416_item	2735279	et	3	main
peaministriks	doc_573958253416_item	2735281	et	3	main
teeksid	doc_573958253416_item	2735287	et	4	main
teaksid	doc_573958253416_item	2735291	et	4	main
on	doc_573958253416_item	2735294	et	4	main
ütlete	doc_573958253416_item	2735307	et	3	main
vajab	doc_573958253416_item	2735318	et	3	main
need	doc_573958253416_item	2735319	et	3	main
on	doc_573958253416_item	2735320	et	4	main
ei	doc_573958253416_item	2735322	et	4	main
meie	doc_573958253416_item	2735326	et	4	main
need	doc_573958253416_item	2735328	et	3	main
kuna	doc_573958253416_item	2735345	et	3	main
abiturientide	doc_573958253416_item	2735365	et	3	main
on	doc_573958253416_item	2735367	et	4	main
alati	doc_573958253416_item	2735368	et	4	main
nii	doc_573958253416_item	2735369	et	3	main
kindlasti	doc_573958253416_item	2735380	et	3	main
teie	doc_573958253416_item	2735383	et	4	main
oma	doc_573958253416_item	2735385	et	4	main
artiklis	doc_573958253416_item	2735386	et	3	main
need	doc_573958253416_item	2735387	et	3	main
kes	doc_573958253416_item	2735388	et	4	main
ei	doc_573958253416_item	2735389	et	4	main
tea	doc_573958253416_item	2735390	et	4	main
täpselt	doc_573958253416_item	2735391	et	4	main
mida	doc_573958253416_item	2735392	et	4	main
nad	doc_573958253416_item	2735393	et	3	main
tahavad	doc_573958253416_item	2735394	et	3	main
elus	doc_573958253416_item	2735395	et	4	main
saavutada	doc_573958253416_item	2735396	et	3	main
ning	doc_573958253416_item	2735397	et	3	main
kõrgharidus	doc_573958253416_item	2735398	et	3	main
on	doc_573958253416_item	2735399	et	4	main
nende	doc_573958253416_item	2735400	et	4	main
jaoks	doc_573958253416_item	2735401	et	4	main
vaid	doc_573958253416_item	2735402	et	3	main
võimalus	doc_573958253416_item	2735403	et	3	main
leida	doc_573958253416_item	2735404	et	3	main
hea	doc_573958253416_item	2735405	et	4	main
töökoha	doc_573958253416_item	2735406	et	4	main
kus	doc_573958253416_item	2735407	et	3	main
saab	doc_573958253416_item	2735408	et	3	main
teenida	doc_573958253416_item	2735409	et	3	main
piisavalt	doc_573958253416_item	2735410	et	4	main
raha	doc_573958253416_item	2735411	et	4	main
selleks	doc_573958253416_item	2735412	et	4	main
et	doc_573958253416_item	2735413	et	3	main
peret	doc_573958253416_item	2735414	et	3	main
pidada	doc_573958253416_item	2735415	et	4	main
ning	doc_573958253416_item	2735416	et	3	main
osta	doc_573958253416_item	2735417	et	4	main
kõike	doc_573958253416_item	2735418	et	4	main
vajalikku	doc_573958253416_item	2735419	et	4	main
nagu	doc_573958253416_item	2735420	et	3	main
see	doc_573958253416_item	2735338	et	3	main
probleem	doc_573958253416_item	2735339	et	3	main
väga	doc_573958253416_item	2735343	et	3	main
tahaks	doc_573958253416_item	2735350	et	3	main
arvamust	doc_573958253416_item	2735352	et	3	main
kõigepealt	doc_573958253416_item	2735355	et	3	main
tahaks	doc_573958253416_item	2735356	et	3	main
olemas	doc_573958253416_item	2735376	et	4	main
toob	doc_573958253416_item	2735444	et	3	main
muuta	doc_573958253416_item	2735463	et	4	main
olgu	doc_573958253416_item	2735464	et	3	main
see	doc_573958253416_item	2735465	et	3	main
haridus-	doc_573958253416_item	2735466	et	3	main
panga-	doc_573958253416_item	2735467	et	3	main
on	doc_573958253416_item	2735474	et	4	main
tormavad	doc_573958253416_item	2735480	et	4	main
ette	doc_573958253416_item	2735482	et	4	main
ning	doc_573958253416_item	2735484	et	3	main
nendest	doc_573958253416_item	2735485	et	4	main
saavad	doc_573958253416_item	2735486	et	4	main
ministrid	doc_573958253416_item	2735487	et	3	main
direktorid	doc_573958253416_item	2735488	et	3	main
mõtlevad	doc_573958253416_item	2735494	et	4	main
pidevalt	doc_573958253416_item	2735495	et	4	main
midagi	doc_573958253416_item	2735496	et	4	main
uut	doc_573958253416_item	2735497	et	3	main
juurde	doc_573958253416_item	2735498	et	4	main
igas	doc_573958253416_item	2735499	et	3	main
valdkonnas	doc_573958253416_item	2735500	et	4	main
selleseid	doc_573958253416_item	2735501	et	4	main
inimesi	doc_573958253416_item	2735502	et	4	main
on	doc_573958253416_item	2735503	et	4	main
kindalsti	doc_573958253416_item	2735504	et	4	main
palju	doc_573958253416_item	2735505	et	4	main
abiturientide	doc_573958253416_item	2735506	et	3	main
seas	doc_573958253416_item	2735507	et	4	main
kuna	doc_573958253416_item	2735508	et	3	main
noorus	doc_573958253416_item	2735509	et	4	main
teebki	doc_573958253416_item	2735510	et	3	main
neid	doc_573958253416_item	2735511	et	4	main
nii	doc_573958253416_item	2735512	et	3	main
julgeteks	doc_573958253416_item	2735513	et	3	main
teisest	doc_573958253416_item	2735514	et	4	main
küljest	doc_573958253416_item	2735515	et	4	main
on	doc_573958253416_item	2735516	et	4	main
olemas	doc_573958253416_item	2735517	et	4	main
selline	doc_573958253416_item	2735518	et	4	main
probleem	doc_573958253416_item	2735519	et	3	main
et	doc_573958253416_item	2735520	et	3	main
targad	doc_573958253416_item	2735521	et	3	main
müüvad	doc_573958253416_item	2735526	et	4	main
ideed	doc_573958253416_item	2735528	et	4	main
selline	doc_573958253416_item	2735538	et	4	main
olukord	doc_573958253416_item	2735539	et	3	main
et	doc_573958253416_item	2735540	et	3	main
piisavalt	doc_573958253416_item	2735545	et	4	main
tarku	doc_573958253416_item	2735546	et	3	main
euroopa	doc_573958253416_item	2735557	et	4	main
ei	doc_573958253416_item	2735563	et	4	main
kuigi	doc_573958253416_item	2735568	et	3	main
kokkuvõtteks	doc_573958253416_item	2735572	et	3	main
on	doc_573958253416_item	2735579	et	4	main
tea	doc_573958253416_item	2735584	et	4	main
auto	doc_573958253416_item	2735422	et	4	main
sellised	doc_573958253416_item	2735425	et	4	main
üliõpilased	doc_573958253416_item	2735426	et	3	main
ei	doc_573958253416_item	2735427	et	4	main
ei	doc_573958253416_item	2735436	et	4	main
ole	doc_573958253416_item	2735437	et	4	main
seda	doc_573958253416_item	2735438	et	3	main
julgust	doc_573958253416_item	2735442	et	4	main
riske	doc_573958253416_item	2735447	et	3	main
siiski	doc_573958253416_item	2735448	et	4	main
selliseid	doc_573958253416_item	2735451	et	4	main
üliõpilasi	doc_573958253416_item	2735452	et	3	main
soovivad	doc_573958253416_item	2735458	et	4	main
ja	doc_573958253416_item	2735459	et	3	main
suudavad	doc_573958253416_item	2735460	et	3	main
need	doc_573958253416_item	2735473	et	3	main
ja	doc_573958253416_item	2735476	et	3	main
mitmesuguste	doc_573958253416_item	2735489	et	3	main
organisatsioonide	doc_573958253416_item	2735490	et	3	main
lahkuvad	doc_573958253416_item	2735523	et	4	main
kus	doc_573958253416_item	2735531	et	3	main
meie	doc_573958253416_item	2735541	et	4	main
riiki	doc_573958253416_item	2735542	et	4	main
ja	doc_573958253416_item	2735548	et	3	main
võrreldes	doc_573958253416_item	2735555	et	3	main
seetõttu	doc_573958253416_item	2735562	et	3	main
ole	doc_573958253416_item	2735564	et	4	main
siin	doc_573958253416_item	2735565	et	4	main
sellega	doc_573958253416_item	2735569	et	3	main
abituriente	doc_573958253416_item	2735576	et	3	main
mida	doc_573958253416_item	2735585	et	4	main
palju	doc_573958253416_item	2735592	et	4	main
tuudengeid	doc_573958253416_item	2735596	et	4	main
igas	doc_573958253416_item	2735610	et	3	main
tuudengite	doc_573958253416_item	2735617	et	4	main
organisatsioone	doc_573958253416_item	2735618	et	3	main
lugupidamisega	doc_573958253416_item	2735619	et	3	main
abituriendid	doc_573958253416_item	2735522	et	3	main
ning	doc_573958253416_item	2735525	et	3	main
omad	doc_573958253416_item	2735527	et	4	main
ei	doc_573958253416_item	2735543	et	4	main
tuudengeid	doc_573958253416_item	2735550	et	4	main
eesti	doc_573958253416_item	2735551	et	4	main
väike	doc_573958253416_item	2735553	et	4	main
liidu	doc_573958253416_item	2735558	et	3	main
ameerika	doc_573958253416_item	2735560	et	3	main
arenguvõimalusi	doc_573958253416_item	2735567	et	3	main
võidelda	doc_573958253416_item	2735571	et	4	main
öelda	doc_573958253416_item	2735574	et	4	main
on	doc_573958253416_item	2735577	et	4	main
erinevaid	doc_573958253416_item	2735578	et	4	main
ja	doc_573958253416_item	2735586	et	3	main
õpivad	doc_573958253416_item	2735589	et	3	main
töökaid	doc_573958253416_item	2735593	et	4	main
mitmesuguseid	doc_573958253416_item	2735608	et	3	main
erinevaid	doc_573958253416_item	2735616	et	4	main
x	doc_573958253416_item	2735620	et	4	main
on	doc_573958253416_item	2735591	et	4	main
kes	doc_573958253416_item	2735597	et	4	main
lepi	doc_573958253416_item	2735599	et	4	main
keskmise	doc_573958253416_item	2735600	et	3	main
palga	doc_573958253416_item	2735601	et	3	main
ja	doc_573958253416_item	2735602	et	3	main
mittetoimiva	doc_573958253416_item	2735603	et	3	main
meditsiinisüsteemiga	doc_573958253416_item	2735604	et	3	main
kokku	doc_573958253416_item	2735605	et	3	main
ning	doc_573958253416_item	2735606	et	3	main
kaalep	doc_573958253418_item	2735876	et	4	main
pea	doc_573958253418_item	2735939	et	4	main
kindlustust	doc_573958253418_item	2735945	et	4	main
sotsiaaltagatiseid	doc_573958253418_item	2735946	et	4	main
meie	doc_573958253418_item	2735950	et	4	main
põlvkond	doc_573958253418_item	2735961	et	3	main
et	doc_573958253418_item	2735964	et	3	main
midagi	doc_573958253418_item	2735967	et	4	main
töökohtadile	doc_573958253418_item	2736000	et	4	main
naudi	doc_573958253418_item	2736002	et	4	main
keegi	doc_573958253418_item	2736028	et	4	main
ei	doc_573958253418_item	2736029	et	4	main
reklaamideta	doc_574559240055_item	2736055	et	3	main
stressi	doc_574559240055_item	2736060	et	4	main
midagi	doc_574559240055_item	2736065	et	4	main
teha	doc_574559240055_item	2736066	et	3	main
ilma	doc_574559240055_item	2736093	et	4	main
meeldivad	doc_574559240055_item	2736102	et	4	main
arvamus	doc_574559240056_item	2736103	et	3	main
peaaegu	doc_574559240056_item	2736104	et	3	main
iga	doc_574559240056_item	2736105	et	4	main
päev	doc_574559240056_item	2736106	et	3	main
saan	doc_574559240056_item	2736109	et	4	main
selliste	doc_574559240056_item	2736111	et	4	main
reklaamide	doc_574559240056_item	2736112	et	3	main
näiteks	doc_573958253416_item	2735614	et	4	main
tuua	doc_573958253416_item	2735615	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_573958253416_item	2735621	et	4	main
mina	doc_573958253418_item	2735877	et	4	main
lugesin	doc_573958253418_item	2735878	et	3	main
teie	doc_573958253418_item	2735879	et	4	main
artiklit	doc_573958253418_item	2735880	et	3	main
vähenõudlike	doc_573958253418_item	2735881	et	3	main
teistest	doc_573958253418_item	2735921	et	4	main
nagu	doc_573958253418_item	2735923	et	3	main
kirjutasite	doc_573958253418_item	2735925	et	3	main
aeg	doc_573958253418_item	2735927	et	3	main
on	doc_573958253418_item	2735928	et	4	main
täiesti	doc_573958253418_item	2735929	et	3	main
väärtus	doc_573958253418_item	2735930	et	3	main
ja	doc_573958253418_item	2735931	et	3	main
palju	doc_573958253418_item	2735941	et	4	main
tahaks	doc_573958253418_item	2735943	et	3	main
materiaalse	doc_573958253418_item	2735944	et	3	main
elada	doc_573958253418_item	2735955	et	3	main
neljakümnesed	doc_573958253418_item	2735957	et	3	main
on	doc_573958253418_item	2735959	et	4	main
meie	doc_573958253418_item	2735960	et	4	main
ma	doc_573958253418_item	2735962	et	3	main
on	doc_573958253418_item	2735966	et	4	main
vale	doc_573958253418_item	2735968	et	4	main
riigieksamitega	doc_573958253418_item	2735969	et	3	main
kas	doc_573958253418_item	2735970	et	3	main
veedab	doc_573958253418_item	2735971	et	3	main
või	doc_573958253418_item	2735972	et	4	main
mitte	doc_573958253418_item	2735973	et	3	main
juhtub	doc_573958253418_item	2735974	et	3	main
ka	doc_573958253418_item	2735975	et	3	main
nii	doc_573958253418_item	2735976	et	3	main
et	doc_573958253418_item	2735977	et	3	main
need	doc_573958253418_item	2735978	et	3	main
palki	doc_573958253418_item	2735984	et	4	main
kohas	doc_573958253418_item	2735989	et	4	main
nad	doc_573958253418_item	2735997	et	3	main
ütle	doc_573958253418_item	2736030	et	4	main
hoolitsen	doc_573958253418_item	2735920	et	3	main
te	doc_573958253418_item	2735924	et	4	main
tuleviku	doc_573958253418_item	2735935	et	4	main
kus	doc_573958253418_item	2735936	et	3	main
ma	doc_573958253418_item	2735937	et	3	main
jne	doc_573958253418_item	2735947	et	4	main
see	doc_573958253418_item	2735948	et	3	main
on	doc_573958253418_item	2735949	et	4	main
probleem	doc_573958253418_item	2735952	et	3	main
nagu	doc_573958253418_item	2735956	et	3	main
selline	doc_573958253418_item	2735958	et	4	main
saavad	doc_573958253418_item	2735981	et	4	main
väga	doc_573958253418_item	2735982	et	3	main
sellest	doc_573958253418_item	2735985	et	4	main
sõltub	doc_573958253418_item	2735987	et	3	main
lõpetamist	doc_573958253418_item	2735996	et	4	main
suvalistele	doc_573958253418_item	2735999	et	4	main
mida	doc_573958253418_item	2736024	et	4	main
eest	doc_573958253418_item	2736040	et	4	main
see	doc_573958253418_item	2736041	et	3	main
oli	doc_573958253418_item	2736042	et	3	main
väga	doc_573958253418_item	2736043	et	3	main
teaduslik	doc_573958253418_item	2736044	et	3	main
lugupidamisega	doc_573958253418_item	2736045	et	3	main
x	doc_573958253418_item	2736046	et	4	main
ilma	doc_574559240055_item	2736054	et	4	main
heata	doc_574559240055_item	2736094	et	3	main
naerma	doc_574559240056_item	2736115	et	3	main
on	doc_574559240056_item	2736124	et	4	main
hästi	doc_574559240056_item	2736125	et	3	main
tehtud	doc_574559240056_item	2736126	et	4	main
või	doc_574559240056_item	2736144	et	4	main
mitmetähenduslik	doc_574559240056_item	2736146	et	3	main
võivad	doc_574559240056_item	2736157	et	4	main
muud	doc_574559240056_item	2736161	et	4	main
tavaliselt	doc_574559240056_item	2736163	et	4	main
palju	doc_574559240056_item	2736174	et	4	main
reklaamid	doc_574559240057_item	2736176	et	4	main
emotsioonidega	doc_574559240057_item	2736178	et	3	main
uus	doc_573958253418_item	2735872	et	3	main
dokument	doc_573958253418_item	2735873	et	3	main
põlvkond	doc_573958253418_item	2735882	et	3	main
mina	doc_573958253418_item	2735932	et	4	main
valeks	doc_573958253418_item	2735933	et	3	main
endale	doc_573958253418_item	2735934	et	4	main
tööle	doc_573958253418_item	2735940	et	3	main
suur	doc_573958253418_item	2735951	et	3	main
arvan	doc_573958253418_item	2735963	et	3	main
kindlasti	doc_573958253418_item	2735965	et	3	main
nende	doc_573958253418_item	2735993	et	4	main
tulevik	doc_573958253418_item	2735994	et	3	main
pärast	doc_573958253418_item	2735995	et	4	main
ei	doc_573958253418_item	2736001	et	4	main
ja	doc_573958253418_item	2736023	et	3	main
lugupeetud	doc_573958253418_item	2735874	et	4	main
tiina	doc_573958253418_item	2735875	et	4	main
ja	doc_573958253418_item	2735883	et	3	main
tahan	doc_573958253418_item	2735884	et	3	main
kirjutada	doc_573958253418_item	2735885	et	3	main
teile	doc_573958253418_item	2735886	et	4	main
oma	doc_573958253418_item	2735887	et	4	main
arvamusest	doc_573958253418_item	2735888	et	4	main
olen	doc_573958253418_item	2735889	et	3	main
teiega	doc_573958253418_item	2735890	et	3	main
absoluutselt	doc_573958253418_item	2735891	et	4	main
nõus	doc_573958253418_item	2735892	et	4	main
et	doc_573958253418_item	2735893	et	3	main
kõik	doc_573958253418_item	2735894	et	4	main
tahavad	doc_573958253418_item	2735895	et	3	main
palju	doc_573958253418_item	2735896	et	4	main
pappi	doc_573958253418_item	2735897	et	4	main
ja	doc_573958253418_item	2735898	et	3	main
kohe	doc_573958253418_item	2735899	et	4	main
keegi	doc_573958253418_item	2735900	et	4	main
eriti	doc_573958253418_item	2735901	et	3	main
ei	doc_573958253418_item	2735902	et	4	main
hooli	doc_573958253418_item	2735903	et	4	main
keskkonnast	doc_573958253418_item	2735904	et	4	main
teistest	doc_573958253418_item	2735905	et	4	main
inimestest	doc_573958253418_item	2735906	et	3	main
kajuks	doc_573958253418_item	2735907	et	4	main
olen	doc_573958253418_item	2735908	et	3	main
ma	doc_573958253418_item	2735909	et	3	main
võib	doc_573958253418_item	2735910	et	3	main
olla	doc_573958253418_item	2735911	et	3	main
ka	doc_573958253418_item	2735912	et	3	main
selline	doc_573958253418_item	2735913	et	4	main
aga	doc_573958253418_item	2735914	et	3	main
tahaks	doc_573958253418_item	2735915	et	3	main
märkida	doc_573958253418_item	2735916	et	4	main
et	doc_573958253418_item	2735917	et	3	main
ma	doc_573958253418_item	2735918	et	3	main
ikkagi	doc_573958253418_item	2735919	et	4	main
inimestest	doc_573958253418_item	2735922	et	3	main
vaba	doc_573958253418_item	2735926	et	4	main
ei	doc_573958253418_item	2735938	et	4	main
käima	doc_573958253418_item	2735942	et	4	main
et	doc_573958253418_item	2735953	et	3	main
tahame	doc_573958253418_item	2735954	et	3	main
kes	doc_573958253418_item	2735979	et	4	main
teavad	doc_573958253418_item	2735980	et	3	main
vähe	doc_573958253418_item	2735983	et	3	main
ju	doc_573958253418_item	2735986	et	3	main
kus	doc_573958253418_item	2735988	et	3	main
nad	doc_573958253418_item	2735990	et	3	main
hakkavad	doc_573958253418_item	2735991	et	4	main
õppima	doc_573958253418_item	2735992	et	3	main
kandideerivad	doc_573958253418_item	2735998	et	4	main
oma	doc_573958253418_item	2736003	et	4	main
ametist	doc_573958253418_item	2736004	et	3	main
ma	doc_573958253418_item	2736006	et	3	main
ütlen	doc_573958253418_item	2736007	et	3	main
et	doc_573958253418_item	2736008	et	3	main
lõpuks	doc_573958253418_item	2736005	et	4	main
on	doc_573958253418_item	2736009	et	4	main
vaja	doc_573958253418_item	2736010	et	4	main
rääkida	doc_573958253418_item	2736011	et	3	main
tulevikust	doc_573958253418_item	2736012	et	4	main
juba	doc_573958253418_item	2736013	et	3	main
koolis	doc_573958253418_item	2736014	et	4	main
nii	doc_573958253418_item	2736015	et	3	main
et	doc_573958253418_item	2736016	et	3	main
kõik	doc_573958253418_item	2736017	et	4	main
teaksid	doc_573958253418_item	2736018	et	4	main
kus	doc_573958253418_item	2736019	et	3	main
nad	doc_573958253418_item	2736020	et	3	main
tahavad	doc_573958253418_item	2736021	et	3	main
tahavad	doc_573958253418_item	2736025	et	3	main
teha	doc_573958253418_item	2736026	et	3	main
ja	doc_573958253418_item	2736027	et	3	main
igav	doc_574559240055_item	2736056	et	3	main
ikka	doc_574559240055_item	2736067	et	4	main
võib	doc_574559240055_item	2736068	et	3	main
oma	doc_574559240055_item	2736069	et	4	main
postkasti	doc_574559240055_item	2736070	et	4	main
peale	doc_574559240055_item	2736071	et	4	main
kinnitada	doc_574559240055_item	2736072	et	3	main
ikka	doc_574559240055_item	2736095	et	4	main
inimesi	doc_574559240055_item	2736097	et	4	main
reklaamid	doc_574559240055_item	2736099	et	4	main
lihtsalt	doc_574559240055_item	2736100	et	4	main
väga	doc_574559240055_item	2736101	et	3	main
jalutades	doc_574559240056_item	2736108	et	3	main
mis	doc_574559240056_item	2736114	et	4	main
mis	doc_574559240056_item	2736123	et	4	main
mõeldud	doc_574559240056_item	2736128	et	4	main
on	doc_574559240056_item	2736131	et	4	main
näha	doc_574559240056_item	2736132	et	3	main
et	doc_574559240056_item	2736133	et	3	main
nende	doc_574559240056_item	2736134	et	4	main
jaoks	doc_574559240056_item	2736135	et	4	main
muu	doc_574559240056_item	2736145	et	4	main
taval	doc_574559240056_item	2736153	et	3	main
selliseid	doc_574559240056_item	2736158	et	4	main
tegemine	doc_574559240056_item	2736169	et	4	main
ja	doc_574559240056_item	2736170	et	3	main
väljaandmine	doc_574559240056_item	2736171	et	3	main
õpida	doc_573958253418_item	2736022	et	4	main
põlvkond	doc_573958253418_item	2736034	et	3	main
suur	doc_573958253418_item	2736035	et	3	main
täna	doc_573958253418_item	2736036	et	4	main
teile	doc_573958253418_item	2736037	et	4	main
ilusa	doc_573958253418_item	2736038	et	3	main
artikli	doc_573958253418_item	2736039	et	3	main
elu	doc_574559240055_item	2736053	et	4	main
või	doc_574559240055_item	2736057	et	4	main
vähem	doc_574559240055_item	2736059	et	4	main
tekitav	doc_574559240055_item	2736061	et	4	main
reklaamide	doc_574559240055_item	2736062	et	3	main
vastu	doc_574559240055_item	2736063	et	3	main
pole	doc_574559240055_item	2736064	et	3	main
palun	doc_574559240055_item	2736073	et	3	main
ei	doc_574559240055_item	2736074	et	4	main
reklaame	doc_574559240055_item	2736075	et	3	main
sildi	doc_574559240055_item	2736076	et	4	main
ja	doc_574559240055_item	2736077	et	3	main
mitte	doc_574559240055_item	2736078	et	3	main
omast	doc_574559240055_item	2736079	et	4	main
toast	doc_574559240055_item	2736080	et	3	main
välja	doc_574559240055_item	2736081	et	4	main
astuda	doc_574559240055_item	2736082	et	3	main
ilma	doc_574559240055_item	2736083	et	4	main
suuri	doc_574559240055_item	2736084	et	3	main
musti	doc_574559240055_item	2736085	et	4	main
päikeseprille	doc_574559240055_item	2736086	et	3	main
mis	doc_574559240055_item	2736087	et	4	main
filtreerivad	doc_574559240055_item	2736088	et	4	main
inetud	doc_574559240055_item	2736089	et	4	main
pole	doc_574559240055_item	2736091	et	3	main
reklaamid	doc_574559240055_item	2736090	et	4	main
halba	doc_574559240055_item	2736092	et	4	main
et	doc_573958253418_item	2736031	et	3	main
oleme	doc_573958253418_item	2736032	et	3	main
vähenõudlik	doc_573958253418_item	2736033	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_573958253418_item	2736047	et	4	main
arvamus	doc_574559240055_item	2736048	et	3	main
milline	doc_574559240055_item	2736049	et	3	main
oleks	doc_574559240055_item	2736050	et	3	main
täna	doc_574559240055_item	2736051	et	4	main
päeva	doc_574559240055_item	2736052	et	4	main
ainult	doc_574559240055_item	2736058	et	4	main
on	doc_574559240055_item	2736096	et	4	main
tänavatel	doc_574559240056_item	2736107	et	4	main
rõõmu	doc_574559240056_item	2736110	et	4	main
millest	doc_574559240056_item	2736130	et	3	main
aega	doc_574559240056_item	2736138	et	4	main
võib-olla	doc_574559240056_item	2736139	et	3	main
neis	doc_574559240056_item	2736140	et	4	main
on	doc_574559240056_item	2736141	et	4	main
mingisugune	doc_574559240056_item	2736142	et	3	main
muul	doc_574559240056_item	2736152	et	4	main
aga	doc_574559240056_item	2736160	et	3	main
mängivad	doc_574559240057_item	2736177	et	4	main
ja	doc_574559240057_item	2736179	et	3	main
ei	doc_574559240057_item	2736181	et	4	main
kunagi	doc_574559240057_item	2736183	et	3	main
kättesaadav	doc_574559240057_item	2736201	et	4	main
kellele	doc_574559240055_item	2736098	et	4	main
panevad	doc_574559240056_item	2736116	et	4	main
nad	doc_574559240056_item	2736117	et	3	main
on	doc_574559240056_item	2736118	et	4	main
geniaalseid	doc_574559240056_item	2736119	et	3	main
ja	doc_574559240056_item	2736120	et	3	main
lõbusaid	doc_574559240056_item	2736121	et	3	main
ja	doc_574559240056_item	2736129	et	3	main
kulutatud	doc_574559240056_item	2736137	et	4	main
nali	doc_574559240056_item	2736143	et	3	main
sõna	doc_574559240056_item	2736147	et	4	main
huvitav	doc_574559240056_item	2736154	et	4	main
asi	doc_574559240056_item	2736155	et	4	main
riidereklaamid	doc_574559240056_item	2736156	et	3	main
olla	doc_574559240056_item	2736159	et	3	main
nendest	doc_574559240056_item	2736164	et	4	main
on	doc_574559240056_item	2736165	et	4	main
näha	doc_574559240056_item	2736166	et	3	main
et	doc_574559240056_item	2736167	et	3	main
nende	doc_574559240056_item	2736168	et	4	main
väga	doc_574559240056_item	2736173	et	3	main
kes	doc_574559240057_item	2736180	et	4	main
pugeta	doc_574559240057_item	2736184	et	4	main
kellelegi	doc_574559240057_item	2736185	et	4	main
kaissu	doc_574559240057_item	2736186	et	4	main
ja	doc_574559240057_item	2736187	et	3	main
hellust	doc_574559240057_item	2736189	et	4	main
ettevõttede	doc_574559240057_item	2736221	et	4	main
umbes	doc_574559240057_item	2736224	et	4	main
462	doc_574559240057_item	2736225	et	2	main
reklaam	doc_574559240057_item	2736235	et	3	main
sellesse	doc_574559240057_item	2736241	et	4	main
tahame	doc_574559240057_item	2736243	et	3	main
anna	doc_576966344269_item	2736521	et	4	main
sündmste	doc_576966344269_item	2736531	et	4	main
tähtsust	doc_576966344269_item	2736532	et	4	main
realismi	doc_576966344269_item	2736538	et	4	main
valgus	doc_576966344269_item	2736542	et	4	main
koordis	doc_576966344269_item	2736543	et	4	main
aga	doc_576966344269_item	2736556	et	3	main
neist	doc_576966344269_item	2736559	et	4	main
rakendust	doc_576966344269_item	2736561	et	4	main
1906	doc_576966344269_item	2736569	et	2	main
aastal	doc_576966344269_item	2736570	et	3	main
estonia	doc_576966344269_item	2736573	et	4	main
vanemuine	doc_576966344269_item	2736575	et	4	main
hiljem	doc_576966344269_item	2736577	et	3	main
endla	doc_576966344269_item	2736580	et	4	main
ja	doc_576966344269_item	2736622	et	3	main
tõttu	doc_574559240056_item	2736113	et	4	main
reklaame	doc_574559240056_item	2736122	et	3	main
pikale	doc_574559240056_item	2736127	et	4	main
on	doc_574559240056_item	2736136	et	4	main
lause	doc_574559240056_item	2736148	et	4	main
või	doc_574559240056_item	2736149	et	4	main
pilt	doc_574559240056_item	2736150	et	3	main
või	doc_574559240056_item	2736151	et	4	main
ka	doc_574559240056_item	2736162	et	3	main
maksab	doc_574559240056_item	2736172	et	3	main
arvamus	doc_574559240057_item	2736175	et	3	main
tahaks	doc_574559240057_item	2736182	et	3	main
või	doc_574559240057_item	2736190	et	4	main
maailmanaisena	doc_574559240057_item	2736192	et	3	main
jetsettide	doc_574559240057_item	2736193	et	4	main
see	doc_574559240057_item	2736196	et	3	main
lihtne	doc_574559240057_item	2736199	et	3	main
reklaam	doc_574559240057_item	2736203	et	3	main
ei	doc_574559240057_item	2736204	et	4	main
ole	doc_574559240057_item	2736205	et	4	main
tühi	doc_574559240057_item	2736206	et	3	main
asi	doc_574559240057_item	2736207	et	4	main
sest	doc_574559240057_item	2736208	et	4	main
selles	doc_574559240057_item	2736209	et	4	main
liigub	doc_574559240057_item	2736210	et	3	main
suured	doc_574559240057_item	2736211	et	3	main
rahad	doc_574559240057_item	2736212	et	4	main
näiteks	doc_574559240057_item	2736213	et	4	main
soomes	doc_574559240057_item	2736214	et	4	main
eelmisel	doc_574559240057_item	2736215	et	3	main
aastal	doc_574559240057_item	2736216	et	3	main
tehtud	doc_574559240057_item	2736217	et	4	main
küsitluse	doc_574559240057_item	2736218	et	4	main
järgi	doc_574559240057_item	2736219	et	4	main
400	doc_574559240057_item	2736220	et	2	main
miljoonid	doc_574559240057_item	2736226	et	4	main
palju	doc_574559240057_item	2736232	et	4	main
tasuks	doc_574559240057_item	2736237	et	4	main
saada	doc_574559240057_item	2736188	et	4	main
kui	doc_574559240057_item	2736195	et	3	main
ja	doc_574559240057_item	2736200	et	3	main
raisaksid	doc_574559240057_item	2736230	et	4	main
nii	doc_574559240057_item	2736231	et	3	main
raha	doc_574559240057_item	2736233	et	4	main
ei	doc_574559240057_item	2736236	et	4	main
me	doc_574559240057_item	2736238	et	4	main
kõig	doc_574559240057_item	2736239	et	4	main
tarbimispeosse	doc_574559240057_item	2736242	et	4	main
särata	doc_574559240057_item	2736191	et	4	main
seltskonnas	doc_574559240057_item	2736194	et	3	main
olekski	doc_574559240057_item	2736197	et	3	main
nii	doc_574559240057_item	2736198	et	3	main
poest	doc_574559240057_item	2736202	et	4	main
reklaamieelarve	doc_574559240057_item	2736222	et	4	main
on	doc_574559240057_item	2736223	et	4	main
vaevalt	doc_574559240057_item	2736228	et	4	main
ettevõtted	doc_574559240057_item	2736229	et	3	main
kui	doc_574559240057_item	2736234	et	3	main
osaleme	doc_574559240057_item	2736240	et	3	main
või	doc_574559240057_item	2736244	et	4	main
mitte	doc_574559240057_item	2736245	et	3	main
aasta	doc_576966344269_item	2736530	et	4	main
kirjelda	doc_576966344269_item	2736536	et	4	main
loomismeetodit	doc_576966344269_item	2736540	et	3	main
nähtu	doc_576966344269_item	2736544	et	4	main
põhjal	doc_576966344269_item	2736545	et	4	main
br	doc_576966344269_item	2736546	et	4	main
1	doc_576966344269_item	2736547	et	2	main
arstid	doc_576966344269_item	2736553	et	4	main
kodumaal	doc_576966344269_item	2736562	et	4	main
kasvas	doc_576966344269_item	2736563	et	3	main
tartus	doc_576966344269_item	2736576	et	3	main
rakendati	doc_576966344269_item	2736586	et	3	main
esimene	doc_576966344269_item	2736621	et	3	main
ajaloos	doc_576966344269_item	2736630	et	4	main
tõde	doc_576966344269_item	2736646	et	4	main
ja	doc_576966344269_item	2736654	et	3	main
ilmuvad	doc_576966344269_item	2736669	et	4	main
nende	doc_576966344269_item	2736728	et	4	main
täidetud	doc_576966344269_item	2736731	et	4	main
tööpäev	doc_576966344269_item	2736732	et	3	main
10-tunniks	doc_576966344269_item	2736734	et	3	main
piirati	doc_576966344269_item	2736736	et	4	main
oma	doc_576966344269_item	2736740	et	4	main
tahtsid	doc_576966344269_item	2736742	et	4	main
kõik	doc_576966344269_item	2736743	et	4	main
paremaks	doc_576966344269_item	2736746	et	4	main
säilitada	doc_576966344269_item	2736749	et	3	main
ajalugu	doc_576966344269_item	2736752	et	4	main
eurot	doc_574559240057_item	2736227	et	3	main
eesti	doc_576966344269_item	2736517	et	4	main
kultuuriloo	doc_576966344269_item	2736518	et	4	main
kontrolltöö	doc_576966344269_item	2736519	et	4	main
1	doc_576966344269_item	2736520	et	2	main
rahvusteaduste	doc_576966344269_item	2736523	et	3	main
eesti	doc_576966344269_item	2736525	et	4	main
arengust	doc_576966344269_item	2736524	et	3	main
wabariigis	doc_576966344269_item	2736526	et	4	main
2	doc_576966344269_item	2736527	et	2	main
eesti	doc_576966344269_item	2736533	et	4	main
ajaloosbr	doc_576966344269_item	2736534	et	4	main
3	doc_576966344269_item	2736535	et	2	main
kui	doc_576966344269_item	2736539	et	3	main
perioodil	doc_576966344269_item	2736549	et	3	main
eestlaste	doc_576966344269_item	2736551	et	4	main
filoloogid	doc_576966344269_item	2736554	et	3	main
arvbr	doc_576966344269_item	2736565	et	4	main
eestis	doc_576966344269_item	2736566	et	3	main
hakkasid	doc_576966344269_item	2736567	et	4	main
toimima	doc_576966344269_item	2736568	et	3	main
kutse	doc_576966344269_item	2736571	et	4	main
teatrid	doc_576966344269_item	2736572	et	3	main
viljandis	doc_576966344269_item	2736579	et	4	main
pärnus	doc_576966344269_item	2736581	et	3	main
sai	doc_576966344269_item	2736583	et	4	main
ülevaade	doc_576966344269_item	2736522	et	3	main
sotsialistlikku	doc_576966344269_item	2736537	et	4	main
filmi	doc_576966344269_item	2736541	et	4	main
ew	doc_576966344269_item	2736548	et	4	main
kasvas	doc_576966344269_item	2736550	et	3	main
haritlaskond	doc_576966344269_item	2736552	et	3	main
insenerid	doc_576966344269_item	2736555	et	3	main
raamatutelugejate	doc_576966344269_item	2736564	et	4	main
tallinnas	doc_576966344269_item	2736574	et	4	main
loodusteadust	doc_576966344269_item	2736587	et	4	main
neuroloogia	doc_576966344269_item	2736588	et	4	main
tehti	doc_576966344269_item	2736589	et	3	main
ajuoperatsioonebr	doc_576966344269_item	2736590	et	4	main
toimis	doc_576966344269_item	2736591	et	4	main
kirjandusrühmitus	doc_576966344269_item	2736592	et	4	main
noor-eesti	doc_576966344269_item	2736593	et	4	main
jäägem	doc_576966344269_item	2736594	et	3	main
eestlasteks	doc_576966344269_item	2736595	et	4	main
kuid	doc_576966344269_item	2736596	et	4	main
saagem	doc_576966344269_item	2736597	et	3	main
ka	doc_576966344269_item	2736598	et	3	main
eurooplasteks	doc_576966344269_item	2736599	et	3	main
rühmituse	doc_576966344269_item	2736600	et	4	main
liikmeteks	doc_576966344269_item	2736601	et	3	main
olid	doc_576966344269_item	2736602	et	4	main
ftuglas	doc_576966344269_item	2736603	et	4	main
jaavik	doc_576966344269_item	2736604	et	4	main
gsuits	doc_576966344269_item	2736605	et	4	main
kitzberg	doc_576966344269_item	2736606	et	4	main
ftuglas	doc_576966344269_item	2736607	et	4	main
maapäeval	doc_576966344269_item	2736608	et	3	main
esimest	doc_576966344269_item	2736609	et	4	main
korda	doc_576966344269_item	2736610	et	4	main
sõnastas	doc_576966344269_item	2736612	et	3	main
avalikult	doc_576966344269_item	2736611	et	4	main
tahtmist	doc_576966344269_item	2736613	et	4	main
saada	doc_576966344269_item	2736614	et	4	main
eesti	doc_576966344269_item	2736616	et	4	main
autonoomiat	doc_576966344269_item	2736615	et	3	main
keel	doc_576966344269_item	2736617	et	4	main
sai	doc_576966344269_item	2736618	et	4	main
rohkem	doc_576966344269_item	2736619	et	4	main
vabadusi	doc_576966344269_item	2736620	et	4	main
emakeeles	doc_576966344269_item	2736628	et	4	main
edaspidises	doc_576966344269_item	2736629	et	3	main
muutusid	doc_576966344269_item	2736632	et	4	main
ahtammsare	doc_576966344269_item	2736645	et	4	main
ja	doc_576966344269_item	2736647	et	3	main
hinda	doc_576966344269_item	2736528	et	4	main
1905	doc_576966344269_item	2736529	et	2	main
mitte	doc_576966344269_item	2736557	et	3	main
kõik	doc_576966344269_item	2736558	et	4	main
said	doc_576966344269_item	2736560	et	4	main
koit	doc_576966344269_item	2736578	et	3	main
tartu	doc_576966344269_item	2736582	et	4	main
teadustearengu	doc_576966344269_item	2736584	et	4	main
pealinnaks	doc_576966344269_item	2736585	et	4	main
õpilased	doc_576966344269_item	2736625	et	3	main
õppida	doc_576966344269_item	2736627	et	3	main
tartu	doc_576966344269_item	2736638	et	4	main
ülikool	doc_576966344269_item	2736639	et	4	main
see	doc_576966344269_item	2736640	et	3	main
mõjutas	doc_576966344269_item	2736641	et	3	main
õigus	doc_576966344269_item	2736648	et	4	main
teised	doc_576966344269_item	2736652	et	4	main
demokraatiat	doc_576966344269_item	2736699	et	3	main
trahvimise	doc_576966344269_item	2736704	et	4	main
töötingimuste	doc_576966344269_item	2736706	et	3	main
kaotasid	doc_576966344269_item	2736712	et	4	main
ühes	doc_576966344269_item	2736718	et	4	main
koolid	doc_576966344269_item	2736721	et	3	main
töötajad	doc_576966344269_item	2736724	et	4	main
nõudmised	doc_576966344269_item	2736729	et	4	main
olid	doc_576966344269_item	2736730	et	4	main
oma	doc_576966344269_item	2736744	et	4	main
teha	doc_576966344269_item	2736747	et	3	main
nõudsid	doc_576966344269_item	2736766	et	4	main
meie	doc_576966344269_item	2736774	et	4	main
realism	doc_576966344269_item	2736815	et	3	main
vene	doc_576966344269_item	2736817	et	4	main
võimu	doc_576966344269_item	2736818	et	4	main
nagu	doc_576966344269_item	2736819	et	3	main
teine	doc_576966344269_item	2736623	et	3	main
koolid	doc_576966344269_item	2736631	et	3	main
eesti	doc_576966344269_item	2736635	et	4	main
sai	doc_576966344269_item	2736637	et	4	main
kasvamisele	doc_576966344269_item	2736644	et	4	main
sees	doc_576966344269_item	2736651	et	4	main
kirjanikurühmitus	doc_576966344269_item	2736660	et	4	main
siurubr	doc_576966344269_item	2736661	et	4	main
religioon	doc_576966344269_item	2736662	et	3	main
koolist	doc_576966344269_item	2736667	et	4	main
keelesbr	doc_576966344269_item	2736672	et	4	main
kasvab	doc_576966344269_item	2736673	et	3	main
kutsekoolide	doc_576966344269_item	2736674	et	3	main
ja	doc_576966344269_item	2736675	et	3	main
gümnaasiumite	doc_576966344269_item	2736676	et	3	main
arv	doc_576966344269_item	2736677	et	3	main
humanitaar	doc_576966344269_item	2736678	et	4	main
ja	doc_576966344269_item	2736679	et	3	main
reaal	doc_576966344269_item	2736680	et	3	main
gümn	doc_576966344269_item	2736681	et	4	main
br	doc_576966344269_item	2736682	et	4	main
2	doc_576966344269_item	2736683	et	2	main
1905	doc_576966344269_item	2736684	et	2	main
aasta	doc_576966344269_item	2736685	et	4	main
sündmused	doc_576966344269_item	2736686	et	3	main
olid	doc_576966344269_item	2736687	et	4	main
väga	doc_576966344269_item	2736688	et	3	main
tähtsad	doc_576966344269_item	2736689	et	3	main
eesti	doc_576966344269_item	2736690	et	4	main
ajaloos	doc_576966344269_item	2736691	et	4	main
eesti	doc_576966344269_item	2736692	et	4	main
rahvas	doc_576966344269_item	2736693	et	4	main
klassi	doc_576966344269_item	2736624	et	4	main
võid	doc_576966344269_item	2736626	et	4	main
eesti	doc_576966344269_item	2736633	et	4	main
keelseteks	doc_576966344269_item	2736634	et	4	main
keelseks	doc_576966344269_item	2736636	et	4	main
eesti	doc_576966344269_item	2736642	et	4	main
haritlaskonna	doc_576966344269_item	2736643	et	4	main
rahva	doc_576966344269_item	2736650	et	3	main
oma	doc_576966344269_item	2736657	et	4	main
tööd	doc_576966344269_item	2736658	et	4	main
toimib	doc_576966344269_item	2736659	et	3	main
raamatud	doc_576966344269_item	2736670	et	4	main
eesti	doc_576966344269_item	2736671	et	4	main
jõu	doc_576966344269_item	2736696	et	3	main
nõudsid	doc_576966344269_item	2736701	et	4	main
parandamist	doc_576966344269_item	2736707	et	4	main
eestlased	doc_576966344269_item	2736708	et	3	main
tahtsid	doc_576966344269_item	2736709	et	4	main
et	doc_576966344269_item	2736710	et	3	main
baltisakslased	doc_576966344269_item	2736711	et	3	main
privillegid	doc_576966344269_item	2736714	et	4	main
rahvas	doc_576966344269_item	2736716	et	4	main
ühines	doc_576966344269_item	2736717	et	3	main
levib	doc_576966344269_item	2736649	et	3	main
kirjanikud	doc_576966344269_item	2736653	et	3	main
luuletajad	doc_576966344269_item	2736655	et	4	main
avaldavad	doc_576966344269_item	2736656	et	4	main
on	doc_576966344269_item	2736663	et	4	main
riigist	doc_576966344269_item	2736664	et	3	main
lahutatud	doc_576966344269_item	2736665	et	4	main
ja	doc_576966344269_item	2736666	et	3	main
ka	doc_576966344269_item	2736668	et	3	main
tundis	doc_576966344269_item	2736694	et	3	main
oma	doc_576966344269_item	2736695	et	4	main
ja	doc_576966344269_item	2736697	et	3	main
terve	doc_576966344269_item	2736715	et	4	main
streigisid	doc_576966344269_item	2736720	et	4	main
töölised	doc_576966344269_item	2736726	et	3	main
trahvimist	doc_576966344269_item	2736735	et	4	main
eesti	doc_576966344269_item	2736737	et	4	main
rahvas	doc_576966344269_item	2736738	et	4	main
tundis	doc_576966344269_item	2736739	et	3	main
eriparasust	doc_576966344269_item	2736751	et	3	main
põletati	doc_576966344269_item	2736755	et	3	main
mõisahooneid	doc_576966344269_item	2736756	et	4	main
need	doc_576966344269_item	2736757	et	3	main
tingimuste	doc_576966344269_item	2736768	et	3	main
kes	doc_576966344269_item	2736772	et	4	main
kirjeldab	doc_576966344269_item	2736816	et	3	main
kõikide	doc_576966344269_item	2736828	et	4	main
üle	doc_576966344269_item	2736829	et	3	main
on	doc_576966344269_item	2736832	et	4	main
ja	doc_576966344269_item	2736839	et	3	main
hea	doc_576966344269_item	2736850	et	4	main
oli	doc_576966344269_item	2736862	et	3	main
kiita	doc_576966344269_item	2736891	et	4	main
partei	doc_576966344269_item	2736894	et	4	main
elualades	doc_576966344269_item	2736903	et	3	main
plaanimajandus	doc_576966344269_item	2736905	et	3	main
üks	doc_576966344269_item	2736907	et	3	main
oli	doc_576966344269_item	2736921	et	3	main
tõi	doc_576966344269_item	2736925	et	3	main
tõeliselt	doc_576966344269_item	2736926	et	4	main
see	doc_576966344269_item	2736927	et	3	main
ilmub	doc_576966344269_item	2736934	et	3	main
ei	doc_576966344269_item	2736944	et	4	main
kui	doc_576966344269_item	2736948	et	3	main
ariteeritud	doc_576966344269_item	2736957	et	4	main
tapetudbr	doc_576966344269_item	2736959	et	4	main
nõudis	doc_576966344269_item	2736698	et	3	main
töölised	doc_576966344269_item	2736700	et	3	main
tööpäeva	doc_576966344269_item	2736702	et	4	main
lühinemist	doc_576966344269_item	2736703	et	4	main
piiratamist	doc_576966344269_item	2736705	et	4	main
oma	doc_576966344269_item	2736713	et	4	main
streigilaines	doc_576966344269_item	2736719	et	3	main
telegrafi	doc_576966344269_item	2736723	et	4	main
vabrikute	doc_576966344269_item	2736725	et	3	main
osaliselt	doc_576966344269_item	2736727	et	4	main
ja	doc_576966344269_item	2736748	et	3	main
mõisanikke	doc_576966344269_item	2736758	et	4	main
rendi	doc_576966344269_item	2736767	et	4	main
nõustuma	doc_576966344269_item	2736809	et	3	main
see	doc_576966344269_item	2736820	et	3	main
juhtiv	doc_576966344269_item	2736837	et	4	main
roll	doc_576966344269_item	2736838	et	3	main
see	doc_576966344269_item	2736840	et	3	main
ideoloogia	doc_576966344269_item	2736841	et	4	main
on	doc_576966344269_item	2736842	et	4	main
ja	doc_576966344269_item	2736851	et	3	main
on	doc_576966344269_item	2736853	et	4	main
kes	doc_576966344269_item	2736856	et	4	main
toimis	doc_576966344269_item	2736857	et	4	main
nagu	doc_576966344269_item	2736858	et	3	main
levitanud	doc_576966344269_item	2736886	et	4	main
sotsialistliku	doc_576966344269_item	2736896	et	3	main
sotsialistlikus	doc_576966344269_item	2736898	et	4	main
tsensuur	doc_576966344269_item	2736906	et	3	main
mis	doc_576966344269_item	2736909	et	4	main
tulebelada	doc_576966344269_item	2736912	et	4	main
peavad	doc_576966344269_item	2736916	et	4	main
tõtt	doc_576966344269_item	2736923	et	4	main
mis	doc_576966344269_item	2736924	et	4	main
keelatud	doc_576966344269_item	2736931	et	4	main
kirjandust	doc_576966344269_item	2736936	et	3	main
mis	doc_576966344269_item	2736937	et	4	main
ajal	doc_576966344269_item	2736939	et	4	main
oli	doc_576966344269_item	2736940	et	3	main
märtsi	doc_576966344269_item	2736952	et	4	main
massiline	doc_576966344269_item	2736954	et	4	main
mõned	doc_576966344269_item	2736955	et	3	main
raudteelased	doc_576966344269_item	2736722	et	3	main
lühines	doc_576966344269_item	2736733	et	4	main
ühinemistküll	doc_576966344269_item	2736741	et	4	main
elu	doc_576966344269_item	2736745	et	4	main
oma	doc_576966344269_item	2736750	et	4	main
keelt	doc_576966344269_item	2736753	et	4	main
kultuuri	doc_576966344269_item	2736754	et	4	main
või	doc_576966344269_item	2736769	et	4	main
kuid	doc_576966344269_item	2736776	et	4	main
1905a	doc_576966344269_item	2736779	et	4	main
oli	doc_576966344269_item	2736780	et	3	main
terve	doc_576966344269_item	2736781	et	4	main
rahvavaimu	doc_576966344269_item	2736782	et	4	main
tõus	doc_576966344269_item	2736783	et	4	main
nad	doc_576966344269_item	2736784	et	3	main
mõtlesid	doc_576966344269_item	2736785	et	4	main
et	doc_576966344269_item	2736786	et	3	main
venelased	doc_576966344269_item	2736787	et	3	main
võivad	doc_576966344269_item	2736788	et	4	main
nõudmisi	doc_576966344269_item	2736789	et	4	main
avalikult	doc_576966344269_item	2736790	et	4	main
esitada	doc_576966344269_item	2736791	et	3	main
ja	doc_576966344269_item	2736792	et	3	main
nad	doc_576966344269_item	2736793	et	3	main
võivad	doc_576966344269_item	2736794	et	4	main
ka	doc_576966344269_item	2736795	et	3	main
seda	doc_576966344269_item	2736796	et	3	main
teha	doc_576966344269_item	2736797	et	3	main
br	doc_576966344269_item	2736798	et	4	main
3	doc_576966344269_item	2736799	et	2	main
loomismeetod	doc_576966344269_item	2736800	et	3	main
sotsialistlik	doc_576966344269_item	2736801	et	3	main
realism	doc_576966344269_item	2736802	et	3	main
tuli	doc_576966344269_item	2736803	et	4	main
nõukogude	doc_576966344269_item	2736804	et	3	main
ajal	doc_576966344269_item	2736805	et	4	main
mõned	doc_576966344269_item	2736806	et	3	main
kirjanikud	doc_576966344269_item	2736807	et	3	main
proovisid	doc_576966344269_item	2736808	et	4	main
kes	doc_576966344269_item	2736759	et	4	main
ei	doc_576966344269_item	2736760	et	4	main
jõudnud	doc_576966344269_item	2736761	et	4	main
põgeneda	doc_576966344269_item	2736762	et	3	main
tapeti	doc_576966344269_item	2736763	et	3	main
ära	doc_576966344269_item	2736764	et	4	main
talunikud	doc_576966344269_item	2736765	et	3	main
maksmise	doc_576966344269_item	2736770	et	4	main
kergendamistbr	doc_576966344269_item	2736771	et	4	main
parandab	doc_576966344269_item	2736773	et	3	main
elu	doc_576966344269_item	2736775	et	4	main
meie	doc_576966344269_item	2736777	et	4	main
ise	doc_576966344269_item	2736778	et	4	main
korraga	doc_576966344269_item	2736811	et	4	main
mõned	doc_576966344269_item	2736812	et	3	main
mitte	doc_576966344269_item	2736813	et	3	main
sotsialistlik	doc_576966344269_item	2736814	et	3	main
on	doc_576966344269_item	2736821	et	4	main
ja	doc_576966344269_item	2736823	et	3	main
ainuke	doc_576966344269_item	2736824	et	4	main
ja	doc_576966344269_item	2736830	et	3	main
on	doc_576966344269_item	2736836	et	4	main
tõde	doc_576966344269_item	2736845	et	4	main
ja	doc_576966344269_item	2736846	et	3	main
mis	doc_576966344269_item	2736852	et	4	main
neid	doc_576966344269_item	2736855	et	4	main
hea	doc_576966344269_item	2736863	et	4	main
kes	doc_576966344269_item	2736864	et	4	main
oli	doc_576966344269_item	2736865	et	3	main
sotsialistliku	doc_576966344269_item	2736866	et	3	main
korra	doc_576966344269_item	2736867	et	4	main
ja	doc_576966344269_item	2736895	et	3	main
kõikides	doc_576966344269_item	2736902	et	4	main
oli	doc_576966344269_item	2736904	et	3	main
olema	doc_576966344269_item	2736917	et	4	main
kord	doc_576966344269_item	2736928	et	4	main
inimestele	doc_576966344269_item	2736929	et	3	main
olid	doc_576966344269_item	2736930	et	4	main
palju	doc_576966344269_item	2736935	et	4	main
tol	doc_576966344269_item	2736938	et	3	main
keelatud	doc_576966344269_item	2736941	et	4	main
saanud	doc_576966344269_item	2736945	et	4	main
olla	doc_576966344269_item	2736946	et	3	main
toimus	doc_576966344269_item	2736949	et	3	main
25	doc_576966344269_item	2736951	et	2	main
kõige	doc_576966344269_item	2736953	et	4	main
olid	doc_576966344269_item	2736956	et	4	main
või	doc_576966344269_item	2736958	et	4	main
selle	doc_576966344269_item	2736810	et	4	main
üks	doc_576966344269_item	2736822	et	3	main
võim	doc_576966344269_item	2736825	et	3	main
mis	doc_576966344269_item	2736826	et	4	main
on	doc_576966344269_item	2736827	et	4	main
venelastel	doc_576966344269_item	2736835	et	4	main
õige	doc_576966344269_item	2736843	et	4	main
otsiti	doc_576966344269_item	2736844	et	3	main
on	doc_576966344269_item	2736849	et	4	main
halb	doc_576966344269_item	2736854	et	3	main
vastu	doc_576966344269_item	2736868	et	3	main
nõukogude	doc_576966344269_item	2736892	et	3	main
korda	doc_576966344269_item	2736897	et	4	main
korras	doc_576966344269_item	2736899	et	4	main
poliitika	doc_576966344269_item	2736900	et	4	main
domineeris	doc_576966344269_item	2736901	et	3	main
partei	doc_576966344269_item	2736908	et	4	main
otsustas	doc_576966344269_item	2736910	et	3	main
kuidas	doc_576966344269_item	2736911	et	3	main
ja	doc_576966344269_item	2736913	et	3	main
millised	doc_576966344269_item	2736914	et	3	main
eesmärgid	doc_576966344269_item	2736915	et	3	main
see	doc_576966344269_item	2736831	et	3	main
õige	doc_576966344269_item	2736833	et	4	main
kord	doc_576966344269_item	2736834	et	4	main
õiglust	doc_576966344269_item	2736847	et	4	main
mis	doc_576966344269_item	2736848	et	4	main
tõeline	doc_576966344269_item	2736859	et	4	main
nõukogu	doc_576966344269_item	2736860	et	4	main
inimene	doc_576966344269_item	2736861	et	3	main
oli	doc_576966344269_item	2736869	et	3	main
aga	doc_576966344269_item	2736870	et	3	main
halb	doc_576966344269_item	2736871	et	3	main
nõukogude	doc_576966344269_item	2736872	et	3	main
ajal	doc_576966344269_item	2736873	et	4	main
ei	doc_576966344269_item	2736874	et	4	main
tohtinud	doc_576966344269_item	2736875	et	4	main
oma	doc_576966344269_item	2736876	et	4	main
mõtteid	doc_576966344269_item	2736877	et	3	main
avaldada	doc_576966344269_item	2736878	et	3	main
sind	doc_576966344269_item	2736879	et	4	main
võid	doc_576966344269_item	2736880	et	4	main
otse	doc_576966344269_item	2736881	et	4	main
siberisse	doc_576966344269_item	2736882	et	4	main
saata	doc_576966344269_item	2736883	et	3	main
pealekaebamine	doc_576966344269_item	2736884	et	3	main
oli	doc_576966344269_item	2736885	et	3	main
kirjanikud	doc_576966344269_item	2736887	et	3	main
võisid	doc_576966344269_item	2736888	et	4	main
kirjutada	doc_576966344269_item	2736889	et	3	main
ja	doc_576966344269_item	2736890	et	3	main
liitu	doc_576966344269_item	2736893	et	4	main
need	doc_576966344269_item	2736918	et	3	main
raamatud	doc_576966344269_item	2736919	et	4	main
kus	doc_576966344269_item	2736920	et	3	main
kirjutatud	doc_576966344269_item	2736922	et	4	main
eesti	doc_576966344269_item	2736942	et	4	main
inimene	doc_576966344269_item	2736943	et	3	main
ükskõikne	doc_576966344269_item	2736947	et	3	main
massiküüditamine	doc_576966344269_item	2736950	et	3	main
eesti	doc_57773893368_item	2737260	et	4	main
1	doc_57773893368_item	2737262	et	2	main
mõjud	doc_57773893368_item	2737264	et	4	main
eesti	doc_57773893368_item	2737265	et	4	main
ühiskonnakorraldusele	doc_57773893368_item	2737266	et	3	main
1316	doc_57773893368_item	2737267	et	2	main
sajandil	doc_57773893368_item	2737268	et	3	main
2	doc_57773893368_item	2737269	et	2	main
tekkis	doc_57773893368_item	2737277	et	3	main
ja	doc_57773893368_item	2737279	et	3	main
taani	doc_57773893368_item	2737280	et	4	main
rüütlitel	doc_57773893368_item	2737281	et	3	main
ja	doc_57773893368_item	2737282	et	3	main
kasutanud	doc_57773893368_item	2737291	et	4	main
pärast	doc_57773893368_item	2737294	et	4	main
eesti	doc_57773893368_item	2737299	et	4	main
juba	doc_57773893368_item	2737310	et	3	main
pärisorjus	doc_57773893368_item	2737312	et	3	main
killustunud	doc_57773893368_item	2737331	et	4	main
isegi	doc_576966344269_item	2736932	et	4	main
praegu	doc_576966344269_item	2736933	et	3	main
kontrolltöö	doc_57773893368_item	2737259	et	4	main
ristiusustamist	doc_57773893368_item	2737276	et	3	main
uurijatel	doc_57773893368_item	2737284	et	4	main
juba	doc_57773893368_item	2737285	et	3	main
rahumeelne	doc_57773893368_item	2737295	et	3	main
hõimud	doc_57773893368_item	2737300	et	4	main
võitlesid	doc_57773893368_item	2737301	et	4	main
vabaduse	doc_57773893368_item	2737303	et	4	main
euroopa	doc_57773893368_item	2737317	et	4	main
ja	doc_57773893368_item	2737321	et	3	main
areng	doc_57773893368_item	2737323	et	3	main
tööd	doc_57773893368_item	2737335	et	4	main
linn	doc_57773893368_item	2737346	et	3	main
raat	doc_57773893368_item	2737350	et	3	main
talupoegadele	doc_57773893368_item	2737353	et	3	main
raske	doc_57773893368_item	2737357	et	4	main
juures	doc_57773893368_item	2737371	et	4	main
kirjatarkus	doc_57773893368_item	2737377	et	4	main
reformatsioon	doc_57773893368_item	2737379	et	3	main
1517	doc_57773893368_item	2737383	et	2	main
keeles	doc_57773893368_item	2737423	et	4	main
tuli	doc_57773893368_item	2737425	et	4	main
tegelikult	doc_57773893368_item	2737435	et	4	main
talupoegadele	doc_57773893368_item	2737436	et	3	main
oli	doc_57773893368_item	2737437	et	3	main
peaaegu	doc_57773893368_item	2737438	et	3	main
ükskõik	doc_57773893368_item	2737439	et	3	main
kas	doc_57773893368_item	2737440	et	3	main
preister	doc_57773893368_item	2737441	et	4	main
on	doc_57773893368_item	2737442	et	4	main
aastaks	doc_57773893368_item	2737448	et	4	main
eesti	doc_57773893368_item	2737449	et	4	main
oli	doc_57773893368_item	2737450	et	3	main
lutherlik	doc_57773893368_item	2737451	et	4	main
missugune	doc_57773893369_item	2737457	et	3	main
tema	doc_57773893369_item	2737498	et	4	main
asuvad	doc_57773893369_item	2737500	et	4	main
vürtsiriigid	doc_57773893369_item	2737502	et	3	main
kujuneb	doc_57773893369_item	2737503	et	3	main
ühtne	doc_57773893369_item	2737504	et	3	main
riik	doc_57773893369_item	2737505	et	3	main
kehtis	doc_57773893369_item	2737517	et	3	main
linnaõigus	doc_57773893369_item	2737519	et	4	main
mida	doc_57773893368_item	2737270	et	4	main
tähendab	doc_57773893368_item	2737271	et	3	main
reformatsioon	doc_57773893368_item	2737272	et	3	main
1	doc_57773893368_item	2737273	et	2	main
ei	doc_57773893368_item	2737290	et	4	main
asendus	doc_57773893368_item	2737297	et	4	main
oli	doc_57773893368_item	2737309	et	3	main
tekkinud	doc_57773893368_item	2737311	et	4	main
sattusid	doc_57773893368_item	2737314	et	4	main
viikingiajast	doc_57773893368_item	2737316	et	4	main
mõte	doc_57773893368_item	2737274	et	3	main
x	doc_57773893368_item	2737286	et	4	main
algul	doc_57773893368_item	2737288	et	4	main
misjonäärid	doc_57773893368_item	2737289	et	4	main
kuid	doc_57773893368_item	2737293	et	4	main
sõjaretkega	doc_57773893368_item	2737298	et	3	main
oma	doc_57773893368_item	2737302	et	4	main
eest	doc_57773893368_item	2737304	et	4	main
aga	doc_57773893368_item	2737305	et	3	main
tsivilisatsiooni	doc_57773893368_item	2737318	et	4	main
kultuuri	doc_57773893368_item	2737320	et	4	main
majanduse	doc_57773893368_item	2737322	et	4	main
põlisrahvas	doc_57773893368_item	2737324	et	4	main
jäi	doc_57773893368_item	2737325	et	3	main
pidid	doc_57773893368_item	2737333	et	4	main
tegema	doc_57773893368_item	2737334	et	3	main
mõisale	doc_57773893368_item	2737339	et	3	main
saamine	doc_57773893368_item	2737355	et	4	main
oli	doc_57773893368_item	2737356	et	3	main
asusid	doc_57773893368_item	2737372	et	4	main
koolid	doc_57773893368_item	2737373	et	3	main
nii	doc_57773893368_item	2737374	et	3	main
2	doc_57773893368_item	2737378	et	2	main
kiriku	doc_57773893368_item	2737380	et	3	main
reformatsioon	doc_57773893368_item	2737381	et	3	main
kirikukommete	doc_57773893368_item	2737415	et	4	main
raamatute	doc_57773893368_item	2737432	et	3	main
väljaandlusele	doc_57773893368_item	2737433	et	3	main
kuid	doc_57773893368_item	2737434	et	4	main
kultuuriloost	doc_57773893369_item	2737455	et	4	main
oli	doc_57773893369_item	2737458	et	3	main
miks	doc_57773893369_item	2737462	et	4	main
jõudu	doc_57773893369_item	2737506	et	4	main
tuleb	doc_57773893369_item	2737507	et	3	main
juurde	doc_57773893369_item	2737508	et	4	main
1	doc_57773893369_item	2737509	et	2	main
linnad	doc_57773893369_item	2737510	et	3	main
juhtis	doc_57773893369_item	2737521	et	3	main
pidada	doc_57773893369_item	2737535	et	4	main
linnas	doc_57773893369_item	2737536	et	4	main
moodustusid	doc_57773893369_item	2737555	et	4	main
linnades	doc_57773893369_item	2737560	et	3	main
eestlasi	doc_57773893369_item	2737563	et	3	main
elu	doc_57773893369_item	2737580	et	4	main
oluline	doc_57773893369_item	2737598	et	4	main
transiitsadam	doc_57773893369_item	2737599	et	3	main
läbima	doc_57773893369_item	2737608	et	4	main
eesti	doc_57773893369_item	2737609	et	4	main
sadamad	doc_57773893369_item	2737610	et	3	main
kauplemine	doc_57773893369_item	2737611	et	4	main
oli	doc_57773893369_item	2737612	et	3	main
sakslaste	doc_57773893369_item	2737613	et	3	main
ehte-	doc_57773893369_item	2737622	et	3	main
relvameistrid	doc_57773893369_item	2737624	et	3	main
peamine	doc_57773893369_item	2737626	et	3	main
tema	doc_57773893369_item	2737633	et	4	main
kvaliteedi	doc_57773893369_item	2737635	et	3	main
eesti	doc_57773893369_item	2737639	et	4	main
vilja	doc_57773893369_item	2737640	et	4	main
sellepärast	doc_57773893369_item	2737641	et	3	main
et	doc_57773893369_item	2737642	et	3	main
siin	doc_57773893369_item	2737643	et	4	main
oli	doc_57773893369_item	2737644	et	3	main
kuivatamine	doc_57773893369_item	2737647	et	4	main
sisse	doc_57773893369_item	2737656	et	4	main
heeringat	doc_57773893369_item	2737662	et	3	main
rauda	doc_57773893369_item	2737663	et	4	main
kala	doc_57773893369_item	2737670	et	4	main
tulekahjude	doc_57773893369_item	2737681	et	4	main
body	doc_582053207518_item	2737721	et	4	main
dokument	doc_582053207519_item	2737723	et	3	main
kiri	doc_582053207520_item	2737724	et	3	main
vaadata	doc_582053207520_item	2737732	et	4	main
seminaritöö	doc_582053207520_item	2737739	et	4	main
kontrolltöö	doc_57773893368_item	2737258	et	4	main
kultuuriloost	doc_57773893368_item	2737261	et	4	main
ristiusustamise	doc_57773893368_item	2737263	et	3	main
baltimaade	doc_57773893368_item	2737275	et	3	main
saksa	doc_57773893368_item	2737278	et	4	main
rooma	doc_57773893368_item	2737283	et	4	main
s	doc_57773893368_item	2737287	et	4	main
jõudu	doc_57773893368_item	2737292	et	4	main
misjonitöö	doc_57773893368_item	2737296	et	4	main
xvi	doc_57773893368_item	2737306	et	4	main
sajandini	doc_57773893368_item	2737307	et	3	main
eestis	doc_57773893368_item	2737308	et	3	main
nii	doc_57773893368_item	2737313	et	3	main
eestlased	doc_57773893368_item	2737315	et	3	main
algas	doc_57773893368_item	2737319	et	3	main
ja	doc_57773893368_item	2737337	et	3	main
maksu	doc_57773893368_item	2737340	et	4	main
ja	doc_57773893368_item	2737342	et	3	main
võimu	doc_57773893368_item	2737343	et	4	main
tsunft	doc_57773893368_item	2737360	et	3	main
kirikute	doc_57773893368_item	2737370	et	4	main
inimene	doc_57773893368_item	2737410	et	3	main
vaene	doc_57773893368_item	2737411	et	4	main
inimene	doc_57773893368_item	2737412	et	3	main
ta	doc_57773893368_item	2737413	et	4	main
nõudis	doc_57773893368_item	2737414	et	3	main
enamikus	doc_57773893368_item	2737326	et	3	main
talupoegadeks	doc_57773893368_item	2737327	et	3	main
eesti	doc_57773893368_item	2737328	et	4	main
oli	doc_57773893368_item	2737329	et	3	main
feodaalselt	doc_57773893368_item	2737330	et	4	main
mõisas	doc_57773893368_item	2737336	et	3	main
poliitika	doc_57773893368_item	2737341	et	4	main
keskuseks	doc_57773893368_item	2737344	et	4	main
oli	doc_57773893368_item	2737345	et	3	main
kõrgeim	doc_57773893368_item	2737348	et	4	main
koosnes	doc_57773893368_item	2737351	et	3	main
linnakodanikuks	doc_57773893368_item	2737354	et	4	main
gild	doc_57773893368_item	2737359	et	3	main
ristiusustamise	doc_57773893368_item	2737361	et	3	main
eesti	doc_57773893368_item	2737363	et	4	main
kasutusele	doc_57773893368_item	2737365	et	4	main
ühiskondlikusüsteemi	doc_57773893368_item	2737367	et	4	main
kloostrite	doc_57773893368_item	2737368	et	3	main
ja	doc_57773893368_item	2737369	et	3	main
levima	doc_57773893368_item	2737376	et	3	main
algas	doc_57773893368_item	2737382	et	3	main
a	doc_57773893368_item	2737384	et	4	main
saksamaal	doc_57773893368_item	2737385	et	4	main
algataja	doc_57773893368_item	2737386	et	4	main
martin	doc_57773893368_item	2737387	et	4	main
luther	doc_57773893368_item	2737388	et	4	main
selles	doc_57773893368_item	2737389	et	4	main
ajaks	doc_57773893368_item	2737390	et	4	main
katoliku	doc_57773893368_item	2737391	et	3	main
kirikust	doc_57773893368_item	2737392	et	4	main
sai	doc_57773893368_item	2737393	et	4	main
iseseisev	doc_57773893368_item	2737394	et	3	main
feodaalne	doc_57773893368_item	2737395	et	3	main
organisatsioon	doc_57773893368_item	2737396	et	3	main
millel	doc_57773893368_item	2737397	et	3	main
oli	doc_57773893368_item	2737398	et	3	main
materiaalne	doc_57773893368_item	2737399	et	3	main
eesmärk	doc_57773893368_item	2737400	et	3	main
ning	doc_57773893368_item	2737401	et	3	main
m	doc_57773893368_item	2737402	et	4	main
luther	doc_57773893368_item	2737403	et	4	main
tahtis	doc_57773893368_item	2737404	et	3	main
seda	doc_57773893368_item	2737405	et	3	main
muuta	doc_57773893368_item	2737406	et	4	main
tema	doc_57773893368_item	2737407	et	4	main
arvates	doc_57773893368_item	2737408	et	4	main
vaimne	doc_57773893368_item	2737409	et	3	main
talupojad	doc_57773893368_item	2737332	et	4	main
maksma	doc_57773893368_item	2737338	et	3	main
linna	doc_57773893368_item	2737347	et	4	main
võimuorgan	doc_57773893368_item	2737349	et	3	main
linnakodanikest	doc_57773893368_item	2737352	et	3	main
vennaskond	doc_57773893368_item	2737358	et	3	main
abil	doc_57773893368_item	2737362	et	4	main
võttis	doc_57773893368_item	2737364	et	3	main
euroopaliku	doc_57773893368_item	2737366	et	3	main
hakkas	doc_57773893368_item	2737375	et	3	main
lihtsustamise	doc_57773893368_item	2737416	et	4	main
maakabelite	doc_57773893368_item	2737417	et	3	main
hävitamist	doc_57773893368_item	2737418	et	4	main
jumalateenused	doc_57773893368_item	2737419	et	3	main
pidid	doc_57773893368_item	2737420	et	4	main
toimuma	doc_57773893368_item	2737421	et	3	main
juba	doc_57773893368_item	2737446	et	3	main
linnakultuur	doc_57773893369_item	2737460	et	3	main
vene-liivi	doc_57773893369_item	2737465	et	4	main
2	doc_57773893369_item	2737467	et	2	main
moskva	doc_57773893369_item	2737495	et	4	main
väikesed	doc_57773893369_item	2737501	et	4	main
linnal	doc_57773893369_item	2737516	et	3	main
maahärra	doc_57773893369_item	2737531	et	4	main
rae	doc_57773893369_item	2737532	et	3	main
ülesanne	doc_57773893369_item	2737533	et	4	main
oli	doc_57773893369_item	2737534	et	3	main
gildid	doc_57773893369_item	2737556	et	3	main
elasid	doc_57773893369_item	2737570	et	4	main
linnades	doc_57773893369_item	2737571	et	3	main
säilis	doc_57773893369_item	2737572	et	4	main
raskem	doc_57773893369_item	2737583	et	4	main
sest	doc_57773893369_item	2737586	et	4	main
kes	doc_57773893369_item	2737602	et	4	main
kaubelda	doc_57773893369_item	2737604	et	4	main
olid	doc_57773893369_item	2737619	et	4	main
saksamaalt	doc_57773893369_item	2737621	et	3	main
oli	doc_57773893369_item	2737628	et	3	main
tunti	doc_57773893369_item	2737631	et	3	main
erilise	doc_57773893369_item	2737654	et	4	main
veini	doc_57773893369_item	2737660	et	4	main
kive	doc_57773893369_item	2737676	et	3	main
uus	doc_582053207519_item	2737722	et	3	main
ma	doc_582053207520_item	2737725	et	3	main
teid	doc_582053207520_item	2737730	et	4	main
teisipäeval	doc_582053207520_item	2737742	et	3	main
saan	doc_582053207520_item	2737743	et	4	main
selle	doc_582053207520_item	2737745	et	4	main
kolmapäeval	doc_582053207520_item	2737749	et	3	main
viima	doc_582053207520_item	2737751	et	3	main
te	doc_582053207520_item	2737760	et	4	main
ja	doc_582053207521_item	2737773	et	3	main
ja	doc_582053207521_item	2737776	et	3	main
sellel	doc_582053207522_item	2737793	et	4	main
ei	doc_582053207522_item	2737796	et	4	main
ole	doc_582053207522_item	2737797	et	4	main
kindlat	doc_582053207522_item	2737798	et	3	main
kuulub	doc_582053207522_item	2737801	et	3	main
sekka	doc_582053207522_item	2737804	et	3	main
paastu	doc_582053207522_item	2737819	et	4	main
toitudest	doc_582053207522_item	2737826	et	3	main
veel	doc_582053207522_item	2737846	et	4	main
küpsetatakse	doc_582053207522_item	2737849	et	3	main
või-pannkooke	doc_582053207522_item	2737850	et	4	main
võinädalaks	doc_582053207522_item	2737854	et	3	main
rahvapüha	doc_582053207522_item	2737863	et	4	main
päevadel	doc_582053207522_item	2737866	et	3	main
iga	doc_582053207522_item	2737868	et	4	main
kohus	doc_582053207522_item	2737870	et	4	main
mõeldud	doc_582053207522_item	2737881	et	4	main
mida	doc_582053207522_item	2737891	et	4	main
kõrgemale	doc_582053207522_item	2737892	et	4	main
seda	doc_582053207522_item	2737921	et	3	main
pannkooke	doc_582053207522_item	2737932	et	4	main
kolmapäeval	doc_582053207522_item	2737933	et	3	main
perenaised	doc_582053207522_item	2737934	et	3	main
piduliku	doc_582053207522_item	2737936	et	3	main
et	doc_582053207522_item	2737947	et	3	main
talle	doc_582053207522_item	2737959	et	4	main
juures	doc_582053207522_item	2737964	et	4	main
1	doc_582053207523_item	2738005	et	2	main
mõjutavad	doc_582053207523_item	2738012	et	4	main
tegurid	doc_582053207523_item	2738013	et	3	main
eestikeelsete	doc_57773893368_item	2737431	et	4	main
katolik	doc_57773893368_item	2737443	et	4	main
või	doc_57773893368_item	2737444	et	4	main
kontrolltöö	doc_57773893369_item	2737452	et	4	main
1	doc_57773893369_item	2737456	et	2	main
2	doc_57773893369_item	2737461	et	2	main
huvitus	doc_57773893369_item	2737469	et	4	main
pääs	doc_57773893369_item	2737470	et	3	main
merele	doc_57773893369_item	2737471	et	3	main
venelaste	doc_57773893369_item	2737472	et	4	main
arvates	doc_57773893369_item	2737473	et	4	main
kiusati	doc_57773893369_item	2737474	et	4	main
eestis	doc_57773893369_item	2737475	et	3	main
taga	doc_57773893369_item	2737476	et	4	main
õigeusklikku	doc_57773893369_item	2737477	et	4	main
takistati	doc_57773893369_item	2737478	et	3	main
kauplemist	doc_57773893369_item	2737479	et	4	main
euroopaga	doc_57773893369_item	2737480	et	3	main
pealegi	doc_57773893369_item	2737481	et	4	main
pidavat	doc_57773893369_item	2737482	et	4	main
eesti	doc_57773893369_item	2737483	et	4	main
nagunii	doc_57773893369_item	2737484	et	3	main
ajalooliselt	doc_57773893369_item	2737485	et	4	main
venemaale	doc_57773893369_item	2737486	et	4	main
kuuluma	doc_57773893369_item	2737487	et	3	main
venemaal	doc_57773893369_item	2737488	et	4	main
oli	doc_57773893369_item	2737489	et	3	main
troonil	doc_57773893369_item	2737490	et	3	main
ivan	doc_57773893369_item	2737491	et	4	main
iv	doc_57773893369_item	2737492	et	4	main
ivan	doc_57773893369_item	2737493	et	4	main
julm	doc_57773893369_item	2737494	et	3	main
kohalikes	doc_57773893368_item	2737422	et	3	main
palved	doc_57773893368_item	2737424	et	3	main
õppida	doc_57773893368_item	2737426	et	3	main
pähe	doc_57773893368_item	2737427	et	4	main
see	doc_57773893368_item	2737428	et	3	main
aitas	doc_57773893368_item	2737429	et	3	main
kaasa	doc_57773893368_item	2737430	et	4	main
lutherlik	doc_57773893368_item	2737445	et	4	main
1526	doc_57773893368_item	2737447	et	2	main
kontrolltöö	doc_57773893369_item	2737453	et	4	main
eesti	doc_57773893369_item	2737454	et	4	main
keskaegne	doc_57773893369_item	2737459	et	3	main
sa	doc_57773893369_item	2737463	et	3	main
võimalikuks	doc_57773893369_item	2737464	et	3	main
sõda	doc_57773893369_item	2737466	et	4	main
venemaad	doc_57773893369_item	2737468	et	4	main
kokku	doc_57773893369_item	2737497	et	3	main
ümber	doc_57773893369_item	2737499	et	3	main
keskajal	doc_57773893369_item	2737512	et	3	main
omavalitsuslikud	doc_57773893369_item	2737513	et	3	main
üksused	doc_57773893369_item	2737514	et	3	main
oma	doc_57773893369_item	2737518	et	4	main
linna	doc_57773893369_item	2737520	et	4	main
elanikeks	doc_57773893369_item	2737523	et	3	main
pidada	doc_57773893369_item	2737540	et	4	main
kohut	doc_57773893369_item	2737541	et	3	main
võtta	doc_57773893369_item	2737550	et	3	main
kodanikuks	doc_57773893369_item	2737552	et	4	main
keda	doc_57773893369_item	2737553	et	4	main
mitte	doc_57773893369_item	2737554	et	3	main
käsitöölised	doc_57773893369_item	2737559	et	3	main
tegelesid	doc_57773893369_item	2737565	et	4	main
side	doc_57773893369_item	2737573	et	4	main
linnas	doc_57773893369_item	2737581	et	4	main
tiheda	doc_57773893369_item	2737587	et	3	main
asustuse	doc_57773893369_item	2737588	et	4	main
euroopa	doc_57773893369_item	2737600	et	4	main
ja	doc_57773893369_item	2737623	et	3	main
vili	doc_57773893369_item	2737629	et	3	main
poolest	doc_57773893369_item	2737636	et	4	main
hinnaliseks	doc_57773893369_item	2737637	et	4	main
vilja	doc_57773893369_item	2737646	et	4	main
maitse	doc_57773893369_item	2737655	et	4	main
kangasid	doc_57773893369_item	2737661	et	4	main
tina	doc_57773893369_item	2737665	et	4	main
lina	doc_57773893369_item	2737672	et	4	main
tõttu	doc_57773893369_item	2737682	et	4	main
eddasi	doc_582053207518_item	2737720	et	4	main
seminaritööd	doc_582053207520_item	2737728	et	4	main
kogu	doc_582053207520_item	2737738	et	4	main
välja	doc_582053207520_item	2737746	et	4	main
mulle	doc_582053207520_item	2737761	et	4	main
andsite	doc_582053207520_item	2737762	et	3	main
videomakk	doc_582053207520_item	2737763	et	3	main
kombed	doc_582053207521_item	2737774	et	3	main
kultuuriruumisvastlapäev	doc_582053207521_item	2737778	et	4	main
ma	doc_582053207521_item	2737779	et	3	main
tõlkisin	doc_582053207521_item	2737780	et	3	main
vene	doc_582053207521_item	2737781	et	4	main
referaat	doc_582053207522_item	2737787	et	3	main
rahva-	doc_582053207522_item	2737790	et	3	main
iidsel	doc_582053207522_item	2737794	et	3	main
rahvapühal	doc_582053207522_item	2737795	et	3	main
vastlapäev	doc_582053207522_item	2737800	et	3	main
seda	doc_582053207522_item	2737805	et	3	main
7	doc_582053207522_item	2737807	et	2	main
nädalal	doc_582053207522_item	2737811	et	3	main
mis	doc_582053207522_item	2737812	et	4	main
seitse	doc_582053207522_item	2737814	et	3	main
nädalat	doc_582053207522_item	2737815	et	3	main
usklikel	doc_582053207522_item	2737823	et	3	main
lõbustustest	doc_582053207522_item	2737827	et	4	main
vastlapäeva	doc_582053207522_item	2737830	et	4	main
sellel	doc_582053207522_item	2737834	et	4	main
nädalal	doc_582053207522_item	2737835	et	3	main
õigeuskliku	doc_582053207522_item	2737836	et	3	main
kombe	doc_582053207522_item	2737837	et	4	main
aga	doc_582053207522_item	2737843	et	3	main
piimatooteid	doc_582053207522_item	2737844	et	4	main
tohib	doc_582053207522_item	2737845	et	3	main
sellepärast	doc_582053207522_item	2737848	et	3	main
on	doc_582053207522_item	2737858	et	4	main
kõige	doc_582053207522_item	2737859	et	4	main
kogus	doc_57773893369_item	2737496	et	4	main
olid	doc_57773893369_item	2737511	et	4	main
igal	doc_57773893369_item	2737515	et	3	main
raad	doc_57773893369_item	2737522	et	4	main
peamiselt	doc_57773893369_item	2737524	et	4	main
võõramaalased	doc_57773893369_item	2737525	et	3	main
linna	doc_57773893369_item	2737526	et	4	main
ümbritsevate	doc_57773893369_item	2737527	et	4	main
maade	doc_57773893369_item	2737528	et	3	main
omanikke	doc_57773893369_item	2737529	et	3	main
esindas	doc_57773893369_item	2737530	et	3	main
korda	doc_57773893369_item	2737537	et	4	main
maksustada	doc_57773893369_item	2737538	et	3	main
elanikke	doc_57773893369_item	2737539	et	3	main
kaupmehed	doc_57773893369_item	2737557	et	3	main
elas	doc_57773893369_item	2737561	et	3	main
nad	doc_57773893369_item	2737564	et	3	main
kes	doc_57773893369_item	2737569	et	4	main
linna	doc_57773893369_item	2737578	et	4	main
põlde	doc_57773893369_item	2737579	et	3	main
kui	doc_57773893369_item	2737584	et	3	main
levisid	doc_57773893369_item	2737590	et	4	main
haigused	doc_57773893369_item	2737591	et	4	main
mille	doc_57773893369_item	2737592	et	3	main
tõttu	doc_57773893369_item	2737593	et	4	main
paljud	doc_57773893369_item	2737594	et	3	main
surid	doc_57773893369_item	2737595	et	4	main
kaupmehed	doc_57773893369_item	2737601	et	3	main
tahtsid	doc_57773893369_item	2737603	et	4	main
turul	doc_57773893369_item	2737606	et	3	main
pidid	doc_57773893369_item	2737607	et	4	main
tulnud	doc_57773893369_item	2737620	et	4	main
seda	doc_57773893369_item	2737630	et	3	main
euroopas	doc_57773893369_item	2737632	et	3	main
hea	doc_57773893369_item	2737634	et	4	main
peeti	doc_57773893369_item	2737638	et	4	main
säilinud	doc_57773893369_item	2737645	et	4	main
taludes	doc_57773893369_item	2737648	et	4	main
suits	doc_57773893369_item	2737649	et	3	main
andis	doc_57773893369_item	2737650	et	3	main
viljast	doc_57773893369_item	2737651	et	4	main
toodi	doc_57773893369_item	2737657	et	4	main
humalat	doc_57773893369_item	2737666	et	3	main
viidi	doc_57773893369_item	2737668	et	4	main
hülgerasva	doc_57773893369_item	2737671	et	4	main
valmistatud	doc_57773893369_item	2737674	et	4	main
linnas	doc_57773893369_item	2737677	et	4	main
hukkus	doc_57773893369_item	2737678	et	3	main
inimesi	doc_57773893369_item	2737679	et	4	main
ka	doc_57773893369_item	2737680	et	3	main
dokumenti	doc_582053207518_item	2737719	et	4	main
ja	doc_57773893369_item	2737542	et	3	main
müntida	doc_57773893369_item	2737543	et	3	main
raha	doc_57773893369_item	2737544	et	4	main
igal	doc_57773893369_item	2737545	et	3	main
linnal	doc_57773893369_item	2737546	et	3	main
oma	doc_57773893369_item	2737547	et	4	main
otsustada	doc_57773893369_item	2737548	et	3	main
keda	doc_57773893369_item	2737549	et	4	main
linna	doc_57773893369_item	2737551	et	4	main
tsunftid	doc_57773893369_item	2737558	et	3	main
ka	doc_57773893369_item	2737562	et	3	main
lihtsama	doc_57773893369_item	2737566	et	4	main
käsitööga	doc_57773893369_item	2737567	et	3	main
eestlastel	doc_57773893369_item	2737568	et	4	main
maaga	doc_57773893369_item	2737574	et	3	main
nad	doc_57773893369_item	2737575	et	3	main
omasid	doc_57773893369_item	2737576	et	4	main
väljaspool	doc_57773893369_item	2737577	et	3	main
oli	doc_57773893369_item	2737582	et	3	main
maal	doc_57773893369_item	2737585	et	4	main
tõttu	doc_57773893369_item	2737589	et	4	main
tallinn	doc_57773893369_item	2737596	et	4	main
oli	doc_57773893369_item	2737597	et	3	main
novgorodi	doc_57773893369_item	2737605	et	4	main
käes	doc_57773893369_item	2737614	et	4	main
ka	doc_57773893369_item	2737615	et	3	main
peenemate	doc_57773893369_item	2737616	et	4	main
alade	doc_57773893369_item	2737617	et	3	main
käsitöölise	doc_57773893369_item	2737618	et	3	main
eesti	doc_57773893369_item	2737625	et	4	main
eksportkaup	doc_57773893369_item	2737627	et	3	main
valmistatud	doc_57773893369_item	2737652	et	4	main
leivale	doc_57773893369_item	2737653	et	3	main
soola	doc_57773893369_item	2737658	et	4	main
vürtse	doc_57773893369_item	2737659	et	3	main
vaske	doc_57773893369_item	2737664	et	4	main
välja	doc_57773893369_item	2737667	et	4	main
ka	doc_57773893369_item	2737669	et	3	main
kanepist	doc_57773893369_item	2737673	et	4	main
köit	doc_57773893369_item	2737675	et	3	main
sest	doc_57773893369_item	2737683	et	4	main
tol	doc_57773893369_item	2737684	et	3	main
ajal	doc_57773893369_item	2737685	et	4	main
kasutati	doc_57773893369_item	2737686	et	4	main
ehitamiseks	doc_57773893369_item	2737687	et	4	main
peamiselt	doc_57773893369_item	2737688	et	4	main
puitu	doc_57773893369_item	2737689	et	4	main
ja	doc_57773893369_item	2737690	et	3	main
kuna	doc_57773893369_item	2737691	et	3	main
majad	doc_57773893369_item	2737692	et	3	main
asusid	doc_57773893369_item	2737693	et	4	main
tihedalt	doc_57773893369_item	2737694	et	4	main
üksteise	doc_57773893369_item	2737695	et	4	main
kõrval	doc_57773893369_item	2737696	et	4	main
siis	doc_57773893369_item	2737697	et	3	main
tuleb	doc_57773893369_item	2737698	et	3	main
tule	doc_57773893369_item	2737699	et	4	main
peatamiseks	doc_57773893369_item	2737700	et	4	main
teinekord	doc_57773893369_item	2737701	et	3	main
maju	doc_57773893369_item	2737702	et	3	main
isegi	doc_57773893369_item	2737703	et	4	main
lammutada	doc_57773893369_item	2737704	et	3	main
hiljem	doc_57773893369_item	2737705	et	3	main
rootsiajal	doc_57773893369_item	2737706	et	3	main
sai	doc_57773893369_item	2737707	et	4	main
peamiseks	doc_57773893369_item	2737708	et	3	main
ehitusmaterjaliks	doc_57773893369_item	2737709	et	3	main
kivi	doc_57773893369_item	2737710	et	4	main
just	doc_57773893369_item	2737711	et	3	main
oma	doc_57773893369_item	2737712	et	4	main
omaduse	doc_57773893369_item	2737713	et	4	main
tõttu	doc_57773893369_item	2737714	et	4	main
mitte	doc_57773893369_item	2737715	et	3	main
põleda	doc_57773893369_item	2737716	et	3	main
test	doc_582053207518_item	2737717	et	3	main
testime	doc_582053207518_item	2737718	et	4	main
kirjutan	doc_582053207520_item	2737726	et	3	main
teile	doc_582053207520_item	2737737	et	4	main
et	doc_582053207520_item	2737741	et	3	main
printida	doc_582053207520_item	2737747	et	3	main
pean	doc_582053207520_item	2737750	et	4	main
selle	doc_582053207520_item	2737752	et	4	main
õppetooli	doc_582053207520_item	2737753	et	4	main
kahjuks	doc_582053207520_item	2737754	et	4	main
ei	doc_582053207520_item	2737755	et	4	main
saanud	doc_582053207520_item	2737756	et	4	main
vaadata	doc_582053207520_item	2737757	et	4	main
kassetti	doc_582053207520_item	2737758	et	4	main
mille	doc_582053207520_item	2737759	et	3	main
vastlapäevast	doc_582053207520_item	2737727	et	4	main
palun	doc_582053207520_item	2737729	et	3	main
läbi	doc_582053207520_item	2737731	et	4	main
minu	doc_582053207520_item	2737733	et	3	main
tõlkeid	doc_582053207520_item	2737734	et	3	main
esmaspäeval	doc_582053207520_item	2737735	et	3	main
saadan	doc_582053207520_item	2737736	et	4	main
loodan	doc_582053207520_item	2737740	et	3	main
kuna	doc_582053207520_item	2737748	et	3	main
kirjutan	doc_582053207521_item	2737769	et	3	main
pühad	doc_582053207521_item	2737772	et	3	main
teil	doc_582053207521_item	2737785	et	4	main
ja	doc_582053207522_item	2737791	et	3	main
kalendripäeva	doc_582053207522_item	2737799	et	4	main
liikuvate	doc_582053207522_item	2737802	et	4	main
pühade	doc_582053207522_item	2737803	et	3	main
tähistatakse	doc_582053207522_item	2737806	et	3	main
päeva	doc_582053207522_item	2737808	et	4	main
paastu	doc_582053207522_item	2737809	et	4	main
viimasel	doc_582053207522_item	2737810	et	3	main
kestis	doc_582053207522_item	2737813	et	4	main
lõppes	doc_582053207522_item	2737817	et	4	main
lihavõttetega	doc_582053207522_item	2737818	et	4	main
hoiduda	doc_582053207522_item	2737824	et	3	main
meelelahutustest	doc_582053207522_item	2737829	et	4	main
tekkis	doc_582053207522_item	2737832	et	3	main
kuna	doc_582053207522_item	2737833	et	3	main
sööda	doc_582053207522_item	2737842	et	4	main
lõbusam	doc_582053207522_item	2737860	et	4	main
ära	doc_582053207522_item	2737873	et	4	main
ja	doc_582053207522_item	2737875	et	3	main
selleks	doc_582053207522_item	2737878	et	4	main
olid	doc_582053207522_item	2737879	et	4	main
kelgud	doc_582053207522_item	2737893	et	3	main
algasid	doc_582053207522_item	2737924	et	4	main
lõbusad	doc_582053207522_item	2737925	et	3	main
naljade	doc_582053207522_item	2737927	et	3	main
ja	doc_582053207522_item	2737928	et	3	main
lõbustuste	doc_582053207522_item	2737929	et	4	main
eest	doc_582053207522_item	2737930	et	4	main
katsid	doc_582053207522_item	2737935	et	4	main
pannkoogid	doc_582053207522_item	2737941	et	3	main
korraldati	doc_582053207522_item	2737943	et	3	main
järgi	doc_582053207522_item	2737946	et	4	main
reedel	doc_582053207522_item	2737953	et	3	main
väimees	doc_582053207522_item	2737954	et	4	main
pannkooke	doc_582053207522_item	2737960	et	4	main
pakkutakse	doc_582053207522_item	2737967	et	4	main
palutakse	doc_582053207522_item	2737970	et	4	main
keele	doc_582053207523_item	2738029	et	4	main
kooliõppekava	doc_582053207523_item	2738030	et	4	main
21	doc_582053207523_item	2738036	et	2	main
testianalüüs	doc_582053207523_item	2738045	et	3	main
huvi	doc_582053207523_item	2738074	et	4	main
kavatsen	doc_582053207523_item	2738077	et	3	main
kuna	doc_582053207523_item	2738084	et	3	main
on	doc_582053207523_item	2738087	et	4	main
õpetada	doc_582053207523_item	2738098	et	3	main
palju	doc_582053207523_item	2738122	et	4	main
on	doc_582053207523_item	2738130	et	4	main
sellega	doc_582053207523_item	2738131	et	3	main
neid	doc_582053207523_item	2738136	et	4	main
ja	doc_582053207523_item	2738138	et	3	main
need	doc_582053207523_item	2738140	et	3	main
tekivad	doc_582053207523_item	2738142	et	3	main
tähelepanu	doc_582053207523_item	2738153	et	4	main
kultuuri	doc_582053207523_item	2738155	et	4	main
õppimiseks	doc_582053207523_item	2738156	et	4	main
minu	doc_582053207523_item	2738157	et	3	main
tööeesmärgiks	doc_582053207523_item	2738158	et	3	main
mida	doc_582053207523_item	2738162	et	4	main
teavad	doc_582053207523_item	2738164	et	3	main
neil	doc_582053207523_item	2738173	et	4	main
selleks	doc_582053207523_item	2738175	et	4	main
et	doc_582053207523_item	2738176	et	3	main
nende	doc_582053207523_item	2738217	et	4	main
arusaamiseks	doc_582053207523_item	2738227	et	4	main
ma	doc_582053207523_item	2738235	et	3	main
mõjutavad	doc_582053207523_item	2738247	et	4	main
tegurid	doc_582053207523_item	2738248	et	3	main
eesti	doc_582053207523_item	2738249	et	4	main
juba	doc_582053207520_item	2737744	et	3	main
on	doc_582053207520_item	2737764	et	4	main
rikkis	doc_582053207520_item	2737765	et	3	main
tänan	doc_582053207520_item	2737766	et	3	main
kiri	doc_582053207521_item	2737767	et	3	main
ma	doc_582053207521_item	2737768	et	3	main
keelest	doc_582053207521_item	2737782	et	4	main
ja	doc_582053207521_item	2737783	et	3	main
paluksin	doc_582053207521_item	2737784	et	3	main
21	doc_582053207522_item	2737788	et	2	main
vastlapäev	doc_582053207522_item	2737789	et	3	main
ja	doc_582053207522_item	2737816	et	3	main
mõnedest	doc_582053207522_item	2737825	et	3	main
ja	doc_582053207522_item	2737828	et	3	main
nimetus	doc_582053207522_item	2737831	et	4	main
ei	doc_582053207522_item	2737841	et	4	main
ja	doc_582053207522_item	2737851	et	3	main
vastlapäeva	doc_582053207522_item	2737853	et	4	main
vastlapäev	doc_582053207522_item	2737857	et	3	main
venemaal	doc_582053207522_item	2737864	et	4	main
oli	doc_582053207522_item	2737867	et	3	main
inimese	doc_582053207522_item	2737869	et	4	main
välja	doc_582053207522_item	2737880	et	4	main
liumägesi	doc_582053207522_item	2737890	et	4	main
seminaritööd	doc_582053207521_item	2737770	et	4	main
kaasaaegsed	doc_582053207521_item	2737771	et	3	main
eestlaste	doc_582053207521_item	2737775	et	4	main
mitte-eestlaste	doc_582053207521_item	2737777	et	4	main
korrekteeridatänan	doc_582053207521_item	2737786	et	4	main
kirikukalendris	doc_582053207522_item	2737792	et	3	main
ajal	doc_582053207522_item	2737820	et	4	main
kohustab	doc_582053207522_item	2737822	et	3	main
kirik	doc_582053207522_item	2737821	et	3	main
järgi	doc_582053207522_item	2737838	et	4	main
liha	doc_582053207522_item	2737839	et	4	main
juba	doc_582053207522_item	2737840	et	3	main
tarvitada	doc_582053207522_item	2737847	et	3	main
nimetatakse	doc_582053207522_item	2737852	et	3	main
23	doc_582053207522_item	2737855	et	2	main
vastlakombed	doc_582053207522_item	2737856	et	3	main
nendel	doc_582053207522_item	2737865	et	4	main
talv	doc_582053207522_item	2737872	et	3	main
loodust	doc_582053207522_item	2737876	et	4	main
sõidavad	doc_582053207522_item	2737894	et	3	main
mida	doc_582053207522_item	2737895	et	4	main
valjem	doc_582053207522_item	2737896	et	4	main
lärm	doc_582053207522_item	2737897	et	3	main
ja	doc_582053207522_item	2737898	et	3	main
naer	doc_582053207522_item	2737899	et	3	main
ümber	doc_582053207522_item	2737901	et	3	main
mäe	doc_582053207522_item	2737900	et	3	main
seda	doc_582053207522_item	2737902	et	3	main
rikkalikum	doc_582053207522_item	2737903	et	4	main
saak	doc_582053207522_item	2737904	et	3	main
ja	doc_582053207522_item	2737905	et	3	main
pikem	doc_582053207522_item	2737906	et	4	main
lina	doc_582053207522_item	2737907	et	4	main
aga	doc_582053207522_item	2737908	et	3	main
selleks	doc_582053207522_item	2737909	et	4	main
et	doc_582053207522_item	2737910	et	3	main
paremini	doc_582053207522_item	2737911	et	4	main
kasvaksid	doc_582053207522_item	2737912	et	4	main
taimed	doc_582053207522_item	2737913	et	3	main
oli	doc_582053207522_item	2737914	et	3	main
vaja	doc_582053207522_item	2737915	et	4	main
kiikedel	doc_582053207522_item	2737916	et	4	main
kiikuda	doc_582053207522_item	2737917	et	3	main
ja	doc_582053207522_item	2737918	et	3	main
mida	doc_582053207522_item	2737919	et	4	main
kõrgemale	doc_582053207522_item	2737920	et	4	main
parem	doc_582053207522_item	2737922	et	4	main
teisipäeval	doc_582053207522_item	2737923	et	3	main
kus	doc_582053207522_item	2737938	et	3	main
olid	doc_582053207522_item	2737940	et	4	main
pakkub	doc_582053207522_item	2737958	et	4	main
käiakse	doc_582053207522_item	2737962	et	3	main
ja	doc_582053207522_item	2737965	et	3	main
pühapäeval	doc_582053207522_item	2737969	et	3	main
sugulastel	doc_582053207522_item	2737971	et	4	main
ja	doc_582053207522_item	2737972	et	3	main
tuttavatel	doc_582053207522_item	2737973	et	3	main
lk4	doc_582053207523_item	2738007	et	4	main
11eesti	doc_582053207523_item	2738008	et	4	main
rahvuspärimus	doc_582053207523_item	2738009	et	3	main
ja	doc_582053207523_item	2738010	et	3	main
teda	doc_582053207523_item	2738011	et	4	main
12	doc_582053207523_item	2738015	et	2	main
ja	doc_582053207522_item	2737861	et	3	main
lärmakam	doc_582053207522_item	2737862	et	4	main
aidata	doc_582053207522_item	2737871	et	4	main
saata	doc_582053207522_item	2737874	et	3	main
äratada	doc_582053207522_item	2737877	et	3	main
kõik	doc_582053207522_item	2737882	et	4	main
need	doc_582053207522_item	2737883	et	3	main
traditsioonid	doc_582053207522_item	2737884	et	3	main
esmaspäeval	doc_582053207522_item	2737885	et	3	main
tuli	doc_582053207522_item	2737886	et	4	main
korraldada	doc_582053207522_item	2737887	et	3	main
ja	doc_582053207522_item	2737888	et	3	main
teha	doc_582053207522_item	2737889	et	3	main
pakkuti	doc_582053207522_item	2737931	et	4	main
laua	doc_582053207522_item	2737937	et	3	main
pearoaks	doc_582053207522_item	2737939	et	4	main
päikese	doc_582053207522_item	2737945	et	4	main
päikesel	doc_582053207522_item	2737948	et	4	main
ära	doc_582053207522_item	2737951	et	4	main
sõidab	doc_582053207522_item	2737955	et	3	main
tema	doc_582053207522_item	2737956	et	4	main
aga	doc_582053207522_item	2737957	et	3	main
laupäeval	doc_582053207522_item	2737961	et	3	main
jälle	doc_582053207522_item	2737966	et	3	main
andestust	doc_582053207522_item	2737974	et	4	main
eest	doc_582053207522_item	2737976	et	4	main
lk6	doc_582053207523_item	2738014	et	4	main
keele	doc_582053207523_item	2738017	et	4	main
riigiõppekava	doc_582053207523_item	2738018	et	4	main
lk15	doc_582053207523_item	2738033	et	4	main
11	doc_582053207523_item	2738043	et	2	main
oma	doc_582053207523_item	2738053	et	4	main
seminaritööteemaks	doc_582053207523_item	2738054	et	4	main
ma	doc_582053207523_item	2738055	et	3	main
olen	doc_582053207523_item	2738056	et	3	main
venekeelses	doc_582053207523_item	2738063	et	3	main
olen	doc_582053207523_item	2738065	et	3	main
selle	doc_582053207523_item	2738067	et	4	main
teema	doc_582053207523_item	2738068	et	4	main
sellepärast	doc_582053207523_item	2738069	et	3	main
et	doc_582053207523_item	2738070	et	3	main
ja	doc_582053207523_item	2738075	et	3	main
ülikooli	doc_582053207523_item	2738079	et	4	main
kooliõpetajaks	doc_582053207523_item	2738082	et	3	main
õppekavas	doc_582053207523_item	2738086	et	3	main
olnud	doc_582053207523_item	2738090	et	4	main
saaks	doc_582053207523_item	2738135	et	3	main
probleemid	doc_582053207523_item	2738141	et	3	main
on	doc_582053207523_item	2738159	et	4	main
lapsed	doc_582053207523_item	2738163	et	3	main
eesti	doc_582053207523_item	2738165	et	4	main
mida	doc_582053207523_item	2738167	et	4	main
lapsed	doc_582053207523_item	2738168	et	3	main
raskusi	doc_582053207523_item	2738174	et	4	main
oma	doc_582053207523_item	2738177	et	4	main
ja	doc_582053207523_item	2738215	et	3	main
avaldan	doc_582053207523_item	2738216	et	3	main
ja	doc_582053207523_item	2738220	et	3	main
oma	doc_582053207523_item	2738228	et	4	main
kasutan	doc_582053207523_item	2738231	et	3	main
kasutan	doc_582053207523_item	2738236	et	3	main
interneti-	doc_582053207523_item	2738238	et	4	main
on	doc_582053207523_item	2738250	et	4	main
pii	doc_582053207523_item	2738260	et	4	main
asend	doc_582053207523_item	2738263	et	3	main
näo	doc_582053207523_item	2738267	et	3	main
tervikpilti	doc_582053207523_item	2738269	et	4	main
iseloomustavad	doc_582053207523_item	2738270	et	4	main
juba	doc_582053207523_item	2738271	et	3	main
kaugest	doc_582053207523_item	2738272	et	3	main
minevikust	doc_582053207523_item	2738273	et	3	main
et	doc_582053207523_item	2738282	et	3	main
on	doc_582053207523_item	2738284	et	4	main
ühe	doc_582053207523_item	2738285	et	4	main
alamast	doc_582053207523_item	2738289	et	4	main
mitmekihiline	doc_582053207523_item	2738295	et	4	main
olemise	doc_582053207523_item	2738296	et	4	main
lõuna-eestiks	doc_582053207523_item	2738326	et	4	main
mis	doc_582053207523_item	2738333	et	4	main
viitab	doc_582053207523_item	2738334	et	3	main
sellele	doc_582053207523_item	2738335	et	4	main
mängud	doc_582053207522_item	2737926	et	3	main
neljapäeval	doc_582053207522_item	2737942	et	3	main
ratsutamist	doc_582053207522_item	2737944	et	4	main
aidata	doc_582053207522_item	2737949	et	4	main
talv	doc_582053207522_item	2737950	et	3	main
saata	doc_582053207522_item	2737952	et	3	main
sugulaste	doc_582053207522_item	2737963	et	4	main
pannkooke	doc_582053207522_item	2737968	et	4	main
solvangute	doc_582053207522_item	2737975	et	3	main
ja	doc_582053207522_item	2737977	et	3	main
pärast	doc_582053207522_item	2737978	et	4	main
hinge	doc_582053207522_item	2737979	et	4	main
kergendamist	doc_582053207522_item	2737980	et	4	main
lõbusalt	doc_582053207522_item	2737981	et	4	main
lauldakse	doc_582053207522_item	2737982	et	3	main
tantsitakse	doc_582053207522_item	2737983	et	3	main
ja	doc_582053207522_item	2737984	et	3	main
saadetakse	doc_582053207522_item	2737985	et	3	main
vastlapäev	doc_582053207522_item	2737986	et	3	main
minema	doc_582053207522_item	2737987	et	3	main
seminaritöö	doc_582053207523_item	2737988	et	4	main
eesti	doc_582053207523_item	2737989	et	4	main
rahvuspärimuse	doc_582053207523_item	2737990	et	3	main
õpetamine	doc_582053207523_item	2737991	et	4	main
ja	doc_582053207523_item	2737992	et	3	main
õppimine	doc_582053207523_item	2737993	et	4	main
venekeelses	doc_582053207523_item	2737994	et	3	main
koolis	doc_582053207523_item	2737995	et	4	main
seminaritöö	doc_582053207523_item	2737996	et	4	main
tallinn	doc_582053207523_item	2737997	et	4	main
2005	doc_582053207523_item	2737998	et	2	main
sisukord	doc_582053207523_item	2737999	et	3	main
lk2	doc_582053207523_item	2738000	et	4	main
sisukord	doc_582053207523_item	2738001	et	3	main
lk3	doc_582053207523_item	2738002	et	4	main
sissejuhatus	doc_582053207523_item	2738003	et	4	main
lk4	doc_582053207523_item	2738004	et	4	main
õpetamine	doc_582053207523_item	2738006	et	4	main
lk6	doc_582053207523_item	2738019	et	4	main
121	doc_582053207523_item	2738020	et	2	main
eesti	doc_582053207523_item	2738016	et	4	main
13	doc_582053207523_item	2738023	et	2	main
tallinna	doc_582053207523_item	2738024	et	4	main
õismäe	doc_582053207523_item	2738025	et	3	main
eesti	doc_582053207523_item	2738028	et	4	main
lk15	doc_582053207523_item	2738031	et	4	main
2õppimine	doc_582053207523_item	2738032	et	4	main
klassi	doc_582053207523_item	2738044	et	4	main
kokkuvõte	doc_582053207523_item	2738047	et	3	main
kasutatud	doc_582053207523_item	2738049	et	4	main
kirjandus	doc_582053207523_item	2738050	et	3	main
lisad	doc_582053207523_item	2738051	et	4	main
valinud	doc_582053207523_item	2738057	et	4	main
eesti	doc_582053207523_item	2738058	et	4	main
rahvuspärimuse	doc_582053207523_item	2738059	et	3	main
mulle	doc_582053207523_item	2738073	et	4	main
minu	doc_582053207523_item	2738085	et	3	main
kultuuriõpe	doc_582053207523_item	2738089	et	3	main
samas	doc_582053207523_item	2738092	et	4	main
mul	doc_582053207523_item	2738093	et	3	main
kultuuri	doc_582053207523_item	2738097	et	4	main
kuidas	doc_582053207523_item	2738134	et	3	main
kuidas	doc_582053207523_item	2738139	et	3	main
on	doc_582053207523_item	2738145	et	4	main
näidata	doc_582053207523_item	2738146	et	4	main
et	doc_582053207523_item	2738148	et	3	main
riigiõppekavas	doc_582053207523_item	2738149	et	3	main
on	doc_582053207523_item	2738150	et	4	main
väga	doc_582053207523_item	2738151	et	3	main
vähe	doc_582053207523_item	2738152	et	3	main
selgitada	doc_582053207523_item	2738161	et	3	main
tööhüpoteesi	doc_582053207523_item	2738178	et	4	main
õppekavast	doc_582053207523_item	2738219	et	4	main
nende	doc_582053207523_item	2738221	et	4	main
kultuuri	doc_582053207523_item	2738223	et	4	main
paremaks	doc_582053207523_item	2738224	et	4	main
ma	doc_582053207523_item	2738230	et	3	main
meetodid	doc_582053207523_item	2738233	et	3	main
mõnda	doc_582053207523_item	2738237	et	4	main
ja	doc_582053207523_item	2738239	et	3	main
kirjanduseallikad	doc_582053207523_item	2738240	et	3	main
pikki	doc_582053207523_item	2738252	et	4	main
aastatuhandeid	doc_582053207523_item	2738255	et	4	main
euroopas	doc_582053207523_item	2738256	et	3	main
lääne	doc_582053207523_item	2738257	et	4	main
see	doc_582053207523_item	2738262	et	3	main
pärinevad	doc_582053207523_item	2738274	et	4	main
kohalikud	doc_582053207523_item	2738275	et	3	main
erijooned	doc_582053207523_item	2738276	et	3	main
eesti	doc_582053207523_item	2738277	et	4	main
rahvapärimuse	doc_582053207523_item	2738278	et	3	main
rahva	doc_582053207523_item	2738291	et	3	main
erakordselt	doc_582053207523_item	2738292	et	4	main
ja	doc_582053207523_item	2738294	et	3	main
oli	doc_582053207523_item	2738299	et	3	main
murde	doc_582053207523_item	2738331	et	4	main
madal-eesti	doc_582053207523_item	2738346	et	4	main
on	doc_582053207523_item	2738348	et	4	main
lai	doc_582053207523_item	2738349	et	3	main
kultuuriline	doc_582053207523_item	2738350	et	4	main
eestimaale	doc_582053207523_item	2738386	et	4	main
põhja-eesti	doc_582053207523_item	2738392	et	4	main
lk8	doc_582053207523_item	2738022	et	4	main
vene	doc_582053207523_item	2738026	et	4	main
lk20	doc_582053207523_item	2738046	et	4	main
lk21	doc_582053207523_item	2738048	et	4	main
õppimine	doc_582053207523_item	2738062	et	4	main
valinud	doc_582053207523_item	2738066	et	4	main
pakub	doc_582053207523_item	2738072	et	3	main
peale	doc_582053207523_item	2738078	et	4	main
lõpetamist	doc_582053207523_item	2738080	et	4	main
hakkama	doc_582053207523_item	2738081	et	3	main
ka	doc_582053207523_item	2738088	et	3	main
ja	doc_582053207523_item	2738091	et	3	main
on	doc_582053207523_item	2738094	et	4	main
vaja	doc_582053207523_item	2738095	et	4	main
on	doc_582053207523_item	2738099	et	4	main
mu	doc_582053207523_item	2738100	et	3	main
jaoks	doc_582053207523_item	2738101	et	4	main
väga	doc_582053207523_item	2738102	et	3	main
oluline	doc_582053207523_item	2738103	et	4	main
teada	doc_582053207523_item	2738104	et	3	main
mis	doc_582053207523_item	2738105	et	4	main
toimub	doc_582053207523_item	2738106	et	3	main
kultuuriõppimisega	doc_582053207523_item	2738107	et	3	main
milline	doc_582053207523_item	2738108	et	3	main
on	doc_582053207523_item	2738109	et	4	main
olukord	doc_582053207523_item	2738110	et	3	main
selles	doc_582053207523_item	2738111	et	4	main
valdkonnassee	doc_582053207523_item	2738112	et	4	main
teema	doc_582053207523_item	2738113	et	4	main
tundub	doc_582053207523_item	2738114	et	3	main
mulle	doc_582053207523_item	2738115	et	4	main
olevat	doc_582053207523_item	2738116	et	4	main
väga	doc_582053207523_item	2738117	et	3	main
aktuaalne	doc_582053207523_item	2738118	et	3	main
kuna	doc_582053207523_item	2738119	et	3	main
tänapäeval	doc_582053207523_item	2738120	et	3	main
räägitakse	doc_582053207523_item	2738121	et	3	main
integratsioonist	doc_582053207523_item	2738123	et	3	main
kuidas	doc_582053207523_item	2738125	et	3	main
protsess	doc_582053207523_item	2738127	et	3	main
lahendada	doc_582053207523_item	2738137	et	3	main
tööhüpoteesiks	doc_582053207523_item	2738144	et	4	main
see	doc_582053207523_item	2738147	et	3	main
pööratud	doc_582053207523_item	2738154	et	4	main
sooviksid	doc_582053207523_item	2738169	et	4	main
õppida	doc_582053207523_item	2738170	et	3	main
millega	doc_582053207523_item	2738171	et	3	main
on	doc_582053207523_item	2738172	et	4	main
mis	doc_582053207523_item	2738183	et	4	main
arvamust	doc_582053207523_item	2738218	et	3	main
meetodid	doc_582053207523_item	2738222	et	3	main
õppimiseks	doc_582053207523_item	2738225	et	4	main
ja	doc_582053207523_item	2738226	et	3	main
samas	doc_582053207523_item	2738234	et	4	main
1	doc_582053207523_item	2738241	et	2	main
õpetamine	doc_582053207523_item	2738242	et	4	main
11eesti	doc_582053207523_item	2738243	et	4	main
rahvapärimus	doc_582053207523_item	2738244	et	3	main
ja	doc_582053207523_item	2738245	et	3	main
sissejuhatus	doc_582053207523_item	2738021	et	4	main
lütseumi	doc_582053207523_item	2738027	et	4	main
sissejuhatus	doc_582053207523_item	2738034	et	4	main
lk15	doc_582053207523_item	2738035	et	4	main
7	doc_582053207523_item	2738037	et	2	main
klassi	doc_582053207523_item	2738038	et	4	main
testianalüüs	doc_582053207523_item	2738039	et	3	main
lk	doc_582053207523_item	2738040	et	4	main
17	doc_582053207523_item	2738041	et	2	main
22	doc_582053207523_item	2738042	et	2	main
sissejuhatus	doc_582053207523_item	2738052	et	4	main
õpetamine	doc_582053207523_item	2738060	et	4	main
ja	doc_582053207523_item	2738061	et	3	main
koolisma	doc_582053207523_item	2738064	et	4	main
ta	doc_582053207523_item	2738071	et	4	main
ma	doc_582053207523_item	2738076	et	3	main
ning	doc_582053207523_item	2738083	et	3	main
koolis	doc_582053207523_item	2738096	et	4	main
sellest	doc_582053207523_item	2738124	et	4	main
see	doc_582053207523_item	2738126	et	3	main
toimub	doc_582053207523_item	2738128	et	3	main
millised	doc_582053207523_item	2738129	et	3	main
seonduvad	doc_582053207523_item	2738132	et	4	main
probleemid	doc_582053207523_item	2738133	et	3	main
minu	doc_582053207523_item	2738143	et	3	main
välja	doc_582053207523_item	2738160	et	4	main
kultuurist	doc_582053207523_item	2738166	et	3	main
kaitsta	doc_582053207523_item	2738179	et	4	main
ma	doc_582053207523_item	2738180	et	3	main
korraldan	doc_582053207523_item	2738181	et	3	main
teste	doc_582053207523_item	2738182	et	3	main
näitavad	doc_582053207523_item	2738184	et	4	main
õpilaste	doc_582053207523_item	2738185	et	4	main
õppeedukust	doc_582053207523_item	2738186	et	4	main
samas	doc_582053207523_item	2738187	et	4	main
ma	doc_582053207523_item	2738188	et	3	main
toon	doc_582053207523_item	2738189	et	4	main
esile	doc_582053207523_item	2738190	et	3	main
riigiõppekava	doc_582053207523_item	2738191	et	4	main
selleks	doc_582053207523_item	2738192	et	4	main
et	doc_582053207523_item	2738193	et	3	main
tõestada	doc_582053207523_item	2738194	et	3	main
mu	doc_582053207523_item	2738195	et	3	main
hüpoteesi	doc_582053207523_item	2738196	et	4	main
esile	doc_582053207523_item	2738198	et	3	main
tallinna	doc_582053207523_item	2738199	et	4	main
õismäe	doc_582053207523_item	2738200	et	3	main
toon	doc_582053207523_item	2738197	et	4	main
vene	doc_582053207523_item	2738201	et	4	main
lütseumi	doc_582053207523_item	2738202	et	4	main
eesti	doc_582053207523_item	2738203	et	4	main
keele	doc_582053207523_item	2738204	et	4	main
kooliõppekava	doc_582053207523_item	2738205	et	4	main
aga	doc_582053207523_item	2738206	et	3	main
ainult	doc_582053207523_item	2738207	et	4	main
seda	doc_582053207523_item	2738208	et	3	main
mis	doc_582053207523_item	2738209	et	4	main
puudutab	doc_582053207523_item	2738210	et	3	main
kultuuriloo	doc_582053207523_item	2738211	et	4	main
õpetamist	doc_582053207523_item	2738212	et	4	main
vestlen	doc_582053207523_item	2738213	et	3	main
õpetajatega	doc_582053207523_item	2738214	et	4	main
uuringus	doc_582053207523_item	2738229	et	3	main
kvalitatiivsed	doc_582053207523_item	2738232	et	3	main
teda	doc_582053207523_item	2738246	et	4	main
ja	doc_582053207523_item	2738258	et	3	main
tulebki	doc_582053207523_item	2738280	et	3	main
tõdeda	doc_582053207523_item	2738281	et	3	main
seisusest	doc_582053207523_item	2738290	et	4	main
keeruline	doc_582053207523_item	2738293	et	4	main
vastuoluline	doc_582053207523_item	2738298	et	4	main
eestlase	doc_582053207523_item	2738301	et	3	main
vaimuilm	doc_582053207523_item	2738302	et	3	main
kus	doc_582053207523_item	2738303	et	3	main
eksisteerisid	doc_582053207523_item	2738304	et	4	main
koos	doc_582053207523_item	2738305	et	4	main
nii	doc_582053207523_item	2738306	et	3	main
kristlikud	doc_582053207523_item	2738307	et	3	main
kui	doc_582053207523_item	2738308	et	3	main
paganlikud	doc_582053207523_item	2738309	et	3	main
tegelased	doc_582053207523_item	2738310	et	3	main
ja	doc_582053207523_item	2738311	et	3	main
mõlematega	doc_582053207523_item	2738312	et	3	main
tuli	doc_582053207523_item	2738313	et	4	main
hästi	doc_582053207523_item	2738314	et	3	main
läbi	doc_582053207523_item	2738315	et	4	main
saada	doc_582053207523_item	2738316	et	4	main
rahvapärimuse	doc_582053207523_item	2738317	et	3	main
seisukohalt	doc_582053207523_item	2738318	et	4	main
jaguneb	doc_582053207523_item	2738319	et	3	main
kõrg-eesti	doc_582053207523_item	2738320	et	4	main
ala	doc_582053207523_item	2738332	et	4	main
on	doc_582053207523_item	2738339	et	4	main
pärit	doc_582053207523_item	2738340	et	3	main
juba	doc_582053207523_item	2738341	et	3	main
ja	doc_582053207523_item	2738345	et	3	main
ulatub	doc_582053207523_item	2738353	et	3	main
tallinnast	doc_582053207523_item	2738354	et	3	main
pärnuni	doc_582053207523_item	2738355	et	4	main
geograafiliselt	doc_582053207523_item	2738356	et	4	main
kattub	doc_582053207523_item	2738357	et	3	main
see	doc_582053207523_item	2738358	et	3	main
samasuunaliste	doc_582053207523_item	2738359	et	4	main
metsade	doc_582053207523_item	2738360	et	3	main
ja	doc_582053207523_item	2738361	et	3	main
sünni	doc_582053207523_item	2738365	et	4	main
on	doc_582053207523_item	2738367	et	4	main
rannikuala	doc_582053207523_item	2738377	et	4	main
olid	doc_582053207523_item	2738378	et	4	main
omamoodi	doc_582053207523_item	2738379	et	3	main
ei	doc_582053207523_item	2738387	et	4	main
olnud	doc_582053207523_item	2738393	et	4	main
ka	doc_582053207523_item	2738415	et	3	main
linna	doc_582053207523_item	2738424	et	4	main
suhtes	doc_582053207523_item	2738425	et	4	main
teisekeelseks	doc_582053207523_item	2738429	et	4	main
hoolimata	doc_582053207523_item	2738434	et	4	main
oli	doc_582053207523_item	2738435	et	3	main
maa	doc_582053207523_item	2738441	et	4	main
kõige	doc_582053207523_item	2738448	et	4	main
regivärsilist	doc_582053207523_item	2738453	et	4	main
rahvalaulu	doc_582053207523_item	2738454	et	4	main
hapendatud	doc_582053207523_item	2738461	et	4	main
ühine	doc_582053207523_item	2738463	et	4	main
seisnud	doc_582053207523_item	2738251	et	4	main
isegi	doc_582053207523_item	2738254	et	4	main
ril	doc_582053207523_item	2738261	et	4	main
määranud	doc_582053207523_item	2738265	et	4	main
mille	doc_582053207523_item	2738268	et	3	main
mõistmiseks	doc_582053207523_item	2738279	et	4	main
see	doc_582053207523_item	2738283	et	3	main
maal	doc_582053207523_item	2738288	et	4	main
viis	doc_582053207523_item	2738297	et	4	main
koos	doc_582053207523_item	2738321	et	4	main
lähialadega	doc_582053207523_item	2738323	et	3	main
põhja-	doc_582053207523_item	2738324	et	4	main
ja	doc_582053207523_item	2738325	et	3	main
tuumikuks	doc_582053207523_item	2738328	et	4	main
esiajaloolisest	doc_582053207523_item	2738342	et	4	main
üleminekuala	doc_582053207523_item	2738351	et	4	main
soode	doc_582053207523_item	2738362	et	3	main
olulisemad	doc_582053207523_item	2738371	et	4	main
kontaktid	doc_582053207523_item	2738372	et	3	main
naabritega	doc_582053207523_item	2738373	et	3	main
eesti	doc_582053207523_item	2738374	et	4	main
saared	doc_582053207523_item	2738375	et	3	main
ja	doc_582053207523_item	2738376	et	3	main
skandinaavia	doc_582053207523_item	2738382	et	4	main
mis	doc_582053207523_item	2738384	et	4	main
kaugemale	doc_582053207523_item	2738385	et	4	main
on	doc_582053207523_item	2738391	et	4	main
kubermangu	doc_582053207523_item	2738428	et	4	main
piirkondlikest	doc_582053207523_item	2738432	et	3	main
üle	doc_582053207523_item	2738439	et	3	main
pidada	doc_582053207523_item	2738452	et	4	main
kui	doc_582053207523_item	2738456	et	3	main
osa	doc_582053207523_item	2738467	et	4	main
saksa	doc_582053207523_item	2738489	et	4	main
kaasa	doc_582053207523_item	2738503	et	4	main
reformatsioon	doc_582053207523_item	2738504	et	3	main
eestikeelne	doc_582053207523_item	2738505	et	3	main
jumalateenistus	doc_582053207523_item	2738506	et	3	main
lõi	doc_582053207523_item	2738507	et	4	main
tingimused	doc_582053207523_item	2738508	et	3	main
eestikeelse	doc_582053207523_item	2738509	et	3	main
aluse	doc_582053207523_item	2738517	et	4	main
sajandeid	doc_582053207523_item	2738253	et	3	main
ida	doc_582053207523_item	2738259	et	4	main
on	doc_582053207523_item	2738264	et	4	main
rahvapärimuse	doc_582053207523_item	2738266	et	3	main
väikese	doc_582053207523_item	2738286	et	4	main
omal	doc_582053207523_item	2738287	et	3	main
ka	doc_582053207523_item	2738300	et	3	main
oma	doc_582053207523_item	2738322	et	4	main
lõuna-eesti	doc_582053207523_item	2738327	et	4	main
on	doc_582053207523_item	2738329	et	4	main
lõuna-eesti	doc_582053207523_item	2738330	et	4	main
kultuuriline	doc_582053207523_item	2738337	et	4	main
erinevus	doc_582053207523_item	2738338	et	4	main
kõrg-	doc_582053207523_item	2738344	et	4	main
vahel	doc_582053207523_item	2738347	et	4	main
kultuurivaldkondade	doc_582053207523_item	2738364	et	3	main
puhul	doc_582053207523_item	2738366	et	4	main
looduslikest	doc_582053207523_item	2738368	et	3	main
eeldustest	doc_582053207523_item	2738369	et	4	main
siiski	doc_582053207523_item	2738370	et	4	main
rajajooneks	doc_582053207523_item	2738380	et	3	main
mõjutustele	doc_582053207523_item	2738383	et	4	main
aega	doc_582053207523_item	2738395	et	4	main
uuendustele	doc_582053207523_item	2738396	et	4	main
tunduvalt	doc_582053207523_item	2738397	et	4	main
enam	doc_582053207523_item	2738398	et	4	main
avatud	doc_582053207523_item	2738399	et	4	main
kui	doc_582053207523_item	2738400	et	3	main
lõuna-eesti	doc_582053207523_item	2738401	et	4	main
põhja-eesti	doc_582053207523_item	2738402	et	4	main
keskendus	doc_582053207523_item	2738403	et	4	main
tallinna	doc_582053207523_item	2738404	et	4	main
kui	doc_582053207523_item	2738405	et	3	main
tähtsa	doc_582053207523_item	2738406	et	3	main
kaubanduskeskuse	doc_582053207523_item	2738407	et	3	main
ümber	doc_582053207523_item	2738408	et	3	main
ja	doc_582053207523_item	2738409	et	3	main
alates	doc_582053207523_item	2738410	et	3	main
18	doc_582053207523_item	2738411	et	2	main
sajandist	doc_582053207523_item	2738412	et	3	main
andis	doc_582053207523_item	2738413	et	3	main
tunda	doc_582053207523_item	2738414	et	3	main
kiiresti	doc_582053207523_item	2738416	et	3	main
areneva	doc_582053207523_item	2738417	et	4	main
peterburi	doc_582053207523_item	2738418	et	4	main
lähedus	doc_582053207523_item	2738419	et	4	main
lõuna-eesti	doc_582053207523_item	2738420	et	4	main
seevastu	doc_582053207523_item	2738421	et	3	main
ääremaaks	doc_582053207523_item	2738430	et	3	main
talupojakultuuril	doc_582053207523_item	2738438	et	3	main
tervikuks	doc_582053207523_item	2738446	et	4	main
liitsid	doc_582053207523_item	2738447	et	4	main
tüüpilist	doc_582053207523_item	2738457	et	3	main
oli	doc_582053207523_item	2738464	et	3	main
suur	doc_582053207523_item	2738466	et	3	main
pulma-	doc_582053207523_item	2738468	et	4	main
ja	doc_582053207523_item	2738469	et	3	main
jõulukombestikust	doc_582053207523_item	2738470	et	4	main
külvinädalate	doc_582053207523_item	2738471	et	3	main
on	doc_582053207523_item	2738477	et	4	main
neist	doc_582053207523_item	2738484	et	4	main
algas	doc_582053207523_item	2738485	et	3	main
et	doc_582053207523_item	2738336	et	3	main
ajast	doc_582053207523_item	2738343	et	4	main
mis	doc_582053207523_item	2738352	et	4	main
vööndiga	doc_582053207523_item	2738363	et	3	main
mitmetele	doc_582053207523_item	2738381	et	4	main
ulatunud	doc_582053207523_item	2738388	et	4	main
rahvapärimuse	doc_582053207523_item	2738389	et	3	main
seisukohalt	doc_582053207523_item	2738390	et	4	main
pikka	doc_582053207523_item	2738394	et	4	main
liivimaa	doc_582053207523_item	2738427	et	4	main
kõikidest	doc_582053207523_item	2738431	et	4	main
vanal	doc_582053207523_item	2738436	et	3	main
kogu	doc_582053207523_item	2738440	et	4	main
tuntud	doc_582053207523_item	2738442	et	4	main
ühisjooni	doc_582053207523_item	2738443	et	3	main
mis	doc_582053207523_item	2738444	et	4	main
tunnuslikumaks	doc_582053207523_item	2738449	et	4	main
elamut	doc_582053207523_item	2738458	et	3	main
pehmet	doc_582053207523_item	2738460	et	3	main
rukkileiba	doc_582053207523_item	2738462	et	4	main
lugemine	doc_582053207523_item	2738472	et	4	main
ja	doc_582053207523_item	2738473	et	3	main
hingedeaeg	doc_582053207523_item	2738474	et	3	main
rahvakultuuris	doc_582053207523_item	2738478	et	3	main
kolm	doc_582053207523_item	2738481	et	3	main
ühiskonna	doc_582053207523_item	2738497	et	4	main
teise	doc_582053207523_item	2738500	et	4	main
murrangu	doc_582053207523_item	2738501	et	3	main
kooliõpetuse	doc_582053207523_item	2738512	et	3	main
tekkeks	doc_582053207523_item	2738513	et	3	main
rahva	doc_582053207523_item	2738518	et	3	main
kokku	doc_582053207523_item	2738522	et	3	main
suulise	doc_582053207523_item	2738527	et	4	main
hakkasid	doc_582053207523_item	2738543	et	4	main
leidis	doc_582053207523_item	2738554	et	4	main
mõjutusi	doc_582053207523_item	2738578	et	4	main
ja	doc_582053207523_item	2738584	et	3	main
ka	doc_582053207523_item	2738587	et	3	main
saabunud	doc_582053207523_item	2738611	et	4	main
peab	doc_582053207523_item	2738621	et	4	main
teadma	doc_582053207523_item	2738622	et	3	main
enda	doc_582053207523_item	2738625	et	4	main
maa	doc_582053207523_item	2738626	et	4	main
maa	doc_582053207523_item	2738635	et	4	main
oluliseks	doc_582053207523_item	2738642	et	4	main
rahvapärimuse	doc_582053207523_item	2738643	et	3	main
ja	doc_582053207523_item	2738644	et	3	main
aega	doc_582053207523_item	2738651	et	4	main
keelt	doc_582053207523_item	2738664	et	4	main
midagi	doc_582053207523_item	2738670	et	4	main
vene	doc_582053207523_item	2738692	et	4	main
midagi	doc_582053207523_item	2738696	et	4	main
muuta	doc_582053207523_item	2738698	et	4	main
see	doc_582053207523_item	2738699	et	3	main
initsiatiiv	doc_582053207523_item	2738700	et	3	main
peab	doc_582053207523_item	2738701	et	4	main
õppekava	doc_582053207523_item	2738708	et	4	main
arvan	doc_582053207523_item	2738712	et	3	main
seda	doc_582053207523_item	2738715	et	3	main
oluliseks	doc_582053207523_item	2738720	et	4	main
punktiks	doc_582053207523_item	2738721	et	4	main
rahva	doc_582053207523_item	2738730	et	3	main
kultuuriga	doc_582053207523_item	2738731	et	4	main
ei	doc_582053207523_item	2738735	et	4	main
on	doc_582053207523_item	2738741	et	4	main
eesti	doc_582053207523_item	2738742	et	4	main
keele	doc_582053207523_item	2738743	et	4	main
õppekavas	doc_582053207523_item	2738744	et	3	main
ja	doc_582053207523_item	2738745	et	3	main
mis	doc_582053207523_item	2738753	et	4	main
puudutavad	doc_582053207523_item	2738754	et	4	main
kultuuriloo	doc_582053207523_item	2738755	et	4	main
ja	doc_582053207523_item	2738758	et	3	main
õppekava	doc_582053207523_item	2738761	et	4	main
riiklik	doc_582053207523_item	2738763	et	3	main
õppekava	doc_582053207523_item	2738777	et	4	main
omandatavad	doc_582053207523_item	2738779	et	4	main
pädevused	doc_582053207523_item	2738780	et	4	main
õppekorralduse	doc_582053207523_item	2738781	et	3	main
nõuded	doc_582053207523_item	2738787	et	3	main
omandab	doc_582053207523_item	2738808	et	3	main
jäi	doc_582053207523_item	2738422	et	3	main
riia	doc_582053207523_item	2738423	et	4	main
siiski	doc_582053207523_item	2738426	et	4	main
erinevustest	doc_582053207523_item	2738433	et	4	main
eesti	doc_582053207523_item	2738437	et	4	main
selle	doc_582053207523_item	2738445	et	4	main
neist	doc_582053207523_item	2738450	et	4	main
võib	doc_582053207523_item	2738451	et	3	main
rehielamut	doc_582053207523_item	2738455	et	4	main
ja	doc_582053207523_item	2738459	et	3	main
ka	doc_582053207523_item	2738465	et	3	main
vaatevinklist	doc_582053207523_item	2738476	et	4	main
eristatavad	doc_582053207523_item	2738480	et	4	main
murranguperioodi	doc_582053207523_item	2738482	et	4	main
esimene	doc_582053207523_item	2738483	et	3	main
13	doc_582053207523_item	2738486	et	2	main
sajandil	doc_582053207523_item	2738487	et	3	main
seoses	doc_582053207523_item	2738488	et	4	main
seisusliku	doc_582053207523_item	2738496	et	3	main
linnakultuuri	doc_582053207523_item	2738499	et	4	main
tõi	doc_582053207523_item	2738502	et	3	main
omakorda	doc_582053207523_item	2738515	et	3	main
kirjaoskusele	doc_582053207523_item	2738519	et	3	main
kõik	doc_582053207523_item	2738520	et	4	main
see	doc_582053207523_item	2738521	et	3	main
vana	doc_582053207523_item	2738526	et	4	main
pärimuse	doc_582053207523_item	2738530	et	4	main
hoogu	doc_582053207523_item	2738544	et	4	main
võtma	doc_582053207523_item	2738545	et	3	main
18	doc_582053207523_item	2738547	et	2	main
sajandi	doc_582053207523_item	2738548	et	3	main
lõpul	doc_582053207523_item	2738549	et	3	main
tõeliselt	doc_582053207523_item	2738550	et	4	main
suur	doc_582053207523_item	2738551	et	3	main
19	doc_582053207523_item	2738556	et	2	main
poolel	doc_582053207523_item	2738559	et	4	main
ajaloos	doc_582053207523_item	2738570	et	4	main
tuleb	doc_582053207523_item	2738571	et	3	main
ja	doc_582053207523_item	2738575	et	3	main
vastastikuseid	doc_582053207523_item	2738577	et	4	main
nii	doc_582053207523_item	2738582	et	3	main
kirik	doc_582053207523_item	2738583	et	3	main
ja	doc_582053207523_item	2738589	et	3	main
eestlastel	doc_582053207523_item	2738591	et	4	main
ürgne	doc_582053207523_item	2738609	et	3	main
uus	doc_582053207523_item	2738612	et	3	main
iga	doc_582053207523_item	2738618	et	4	main
haritud	doc_582053207523_item	2738619	et	4	main
inimene	doc_582053207523_item	2738620	et	3	main
õpetatava	doc_582053207523_item	2738630	et	4	main
rahvapärimust	doc_582053207523_item	2738636	et	4	main
kultuuri	doc_582053207523_item	2738645	et	4	main
oluliseks	doc_582053207523_item	2738652	et	4	main
keele	doc_582053207523_item	2738655	et	4	main
valdav	doc_582053207523_item	2738666	et	4	main
inimene	doc_582053207523_item	2738667	et	3	main
ei	doc_582053207523_item	2738694	et	4	main
sisu	doc_582053207523_item	2738709	et	4	main
praegu	doc_582053207523_item	2738714	et	3	main
ajaloolisest	doc_582053207523_item	2738475	et	4	main
selgesti	doc_582053207523_item	2738479	et	3	main
vallutustega	doc_582053207523_item	2738490	et	4	main
ja	doc_582053207523_item	2738491	et	3	main
tõi	doc_582053207523_item	2738492	et	3	main
maale	doc_582053207523_item	2738493	et	4	main
katoliku	doc_582053207523_item	2738494	et	3	main
usu	doc_582053207523_item	2738495	et	4	main
trükisõna	doc_582053207523_item	2738510	et	4	main
ja	doc_582053207523_item	2738511	et	3	main
pani	doc_582053207523_item	2738516	et	4	main
etendas	doc_582053207523_item	2738523	et	3	main
kujunemises	doc_582053207523_item	2738535	et	4	main
pööre	doc_582053207523_item	2738552	et	4	main
rahvakultuuris	doc_582053207523_item	2738553	et	3	main
kõrg-	doc_582053207523_item	2738574	et	4	main
rahvakultuuri	doc_582053207523_item	2738576	et	4	main
vahendajateks	doc_582053207523_item	2738579	et	4	main
kui	doc_582053207523_item	2738586	et	3	main
mõis	doc_582053207523_item	2738588	et	3	main
linn	doc_582053207523_item	2738590	et	3	main
teravaid	doc_582053207523_item	2738595	et	3	main
oma	doc_582053207523_item	2738598	et	4	main
materiaalses	doc_582053207523_item	2738601	et	3	main
kultuuris	doc_582053207523_item	2738602	et	3	main
ning	doc_582053207523_item	2738603	et	3	main
sulatada	doc_582053207523_item	2738604	et	3	main
ühte	doc_582053207523_item	2738605	et	4	main
enda	doc_582053207523_item	2738606	et	4	main
vana	doc_582053207523_item	2738607	et	4	main
ja	doc_582053207523_item	2738608	et	3	main
ja	doc_582053207523_item	2738498	et	3	main
mis	doc_582053207523_item	2738514	et	4	main
osa	doc_582053207523_item	2738525	et	4	main
siiski	doc_582053207523_item	2738536	et	4	main
oli	doc_582053207523_item	2738537	et	3	main
see	doc_582053207523_item	2738538	et	3	main
aeganõudev	doc_582053207523_item	2738539	et	3	main
protsess	doc_582053207523_item	2738540	et	3	main
ja	doc_582053207523_item	2738541	et	3	main
muudatused	doc_582053207523_item	2738542	et	3	main
sajandi	doc_582053207523_item	2738557	et	3	main
ka	doc_582053207523_item	2738573	et	3	main
õnnestus	doc_582053207523_item	2738592	et	4	main
nii	doc_582053207523_item	2738597	et	3	main
vaimses	doc_582053207523_item	2738599	et	3	main
ning	doc_582053207523_item	2738610	et	3	main
ja	doc_582053207523_item	2738613	et	3	main
võõras	doc_582053207523_item	2738614	et	4	main
httpwwwestonicaorgestluguhtmlmenyyid175kateg5alam19leht1	doc_582053207523_item	2738615	et	4	main
rahvapärimust	doc_582053207523_item	2738627	et	4	main
keele	doc_582053207523_item	2738631	et	4	main
pea	doc_582053207523_item	2738640	et	4	main
seda	doc_582053207523_item	2738641	et	3	main
andnud	doc_582053207523_item	2738648	et	4	main
väga	doc_582053207523_item	2738649	et	3	main
vähe	doc_582053207523_item	2738650	et	3	main
eesti	doc_582053207523_item	2738654	et	4	main
vabalt	doc_582053207523_item	2738665	et	4	main
saa	doc_582053207523_item	2738695	et	4	main
õppekavas	doc_582053207523_item	2738697	et	3	main
ise	doc_582053207523_item	2738706	et	4	main
muutma	doc_582053207523_item	2738707	et	3	main
et	doc_582053207523_item	2738713	et	3	main
keele	doc_582053207523_item	2738729	et	4	main
osad	doc_582053207523_item	2738752	et	3	main
põhikooli	doc_582053207523_item	2738757	et	4	main
eesmärgid	doc_582053207523_item	2738775	et	3	main
tunnijaotusplaani	doc_582053207523_item	2738786	et	4	main
ja	doc_582053207523_item	2738789	et	3	main
lõpetamiseks	doc_582053207523_item	2738791	et	4	main
ning	doc_582053207523_item	2738792	et	3	main
põhimõtted	doc_582053207523_item	2738797	et	3	main
õpilane	doc_582053207523_item	2738807	et	3	main
ja	doc_582053207523_item	2738813	et	3	main
jõulud	doc_582053207523_item	2738824	et	3	main
kooliastmel	doc_582053207523_item	2738833	et	3	main
oma	doc_582053207523_item	2738836	et	4	main
eripära	doc_582053207523_item	2738838	et	4	main
teadmised	doc_582053207523_item	2738845	et	4	main
ja	doc_582053207523_item	2738850	et	3	main
kultuur	doc_582053207523_item	2738851	et	3	main
vaatamisväärsused	doc_582053207523_item	2738853	et	4	main
luuletusi	doc_582053207523_item	2738857	et	4	main
lastekirjandusestnäited	doc_582053207523_item	2738859	et	4	main
vanasõnadest	doc_582053207523_item	2738860	et	3	main
mõistatusest	doc_582053207523_item	2738861	et	4	main
kõnekäändusest	doc_582053207523_item	2738862	et	3	main
riigipühad	doc_582053207523_item	2738863	et	3	main
ja	doc_582053207523_item	2738864	et	3	main
eesti	doc_582053207523_item	2738871	et	4	main
sümboleid	doc_582053207523_item	2738872	et	3	main
ainekava	doc_582053207523_item	2738875	et	4	main
sel	doc_582053207523_item	2738879	et	3	main
eesti	doc_582053207523_item	2738891	et	4	main
olulist	doc_582053207523_item	2738524	et	4	main
ja	doc_582053207523_item	2738528	et	3	main
muusikalise	doc_582053207523_item	2738529	et	4	main
murenemises	doc_582053207523_item	2738531	et	4	main
ja	doc_582053207523_item	2738532	et	3	main
uute	doc_582053207523_item	2738533	et	3	main
arusaamade	doc_582053207523_item	2738534	et	3	main
alles	doc_582053207523_item	2738546	et	3	main
aset	doc_582053207523_item	2738555	et	3	main
teisel	doc_582053207523_item	2738558	et	4	main
selle	doc_582053207523_item	2738560	et	4	main
ajendiks	doc_582053207523_item	2738561	et	3	main
oli	doc_582053207523_item	2738562	et	3	main
1860	doc_582053207523_item	2738563	et	2	main
aastatel	doc_582053207523_item	2738564	et	4	main
alanud	doc_582053207523_item	2738565	et	4	main
talude	doc_582053207523_item	2738566	et	3	main
päriseksostmine	doc_582053207523_item	2738567	et	3	main
eesti	doc_582053207523_item	2738568	et	4	main
rahvakultuuri	doc_582053207523_item	2738569	et	4	main
rõhutada	doc_582053207523_item	2738572	et	3	main
olid	doc_582053207523_item	2738580	et	4	main
siin	doc_582053207523_item	2738581	et	4	main
klooster	doc_582053207523_item	2738585	et	3	main
siiski	doc_582053207523_item	2738593	et	4	main
vältida	doc_582053207523_item	2738594	et	3	main
vastuolusid	doc_582053207523_item	2738596	et	3	main
kui	doc_582053207523_item	2738600	et	3	main
12riigiõppekava	doc_582053207523_item	2738616	et	4	main
sissejuhatus	doc_582053207523_item	2738617	et	4	main
nii	doc_582053207523_item	2738624	et	3	main
kuid	doc_582053207523_item	2738628	et	4	main
või	doc_582053207523_item	2738632	et	4	main
valitud	doc_582053207523_item	2738633	et	4	main
elamiseks	doc_582053207523_item	2738634	et	4	main
ei	doc_582053207523_item	2738639	et	4	main
on	doc_582053207523_item	2738647	et	4	main
aga	doc_582053207523_item	2738659	et	3	main
on	doc_582053207523_item	2738660	et	4	main
kuidagi	doc_582053207523_item	2738661	et	3	main
kummaline	doc_582053207523_item	2738662	et	3	main
kui	doc_582053207523_item	2738663	et	3	main
oska	doc_582053207523_item	2738669	et	4	main
haridusministeeriumilt	doc_582053207523_item	2738703	et	3	main
aga	doc_582053207523_item	2738710	et	3	main
ei	doc_582053207523_item	2738716	et	4	main
lootagi	doc_582053207523_item	2738718	et	4	main
sest	doc_582053207523_item	2738719	et	4	main
õpetatava	doc_582053207523_item	2738728	et	4	main
jaoks	doc_582053207523_item	2738734	et	4	main
õppekava	doc_582053207523_item	2738739	et	4	main
see	doc_582053207523_item	2738740	et	3	main
õppekavast	doc_582053207523_item	2738747	et	4	main
ma	doc_582053207523_item	2738748	et	3	main
valisin	doc_582053207523_item	2738749	et	3	main
õppimist	doc_582053207523_item	2738756	et	4	main
kool	doc_582053207523_item	2738771	et	4	main
ja	doc_582053207523_item	2738785	et	3	main
kooliastmete	doc_582053207523_item	2738788	et	3	main
kooli	doc_582053207523_item	2738790	et	4	main
ja	doc_582053207523_item	2738795	et	3	main
olenemata	doc_582053207523_item	2738798	et	4	main
ainekava	doc_582053207523_item	2738804	et	4	main
13	doc_582053207523_item	2738805	et	2	main
klassile	doc_582053207523_item	2738806	et	3	main
esmased	doc_582053207523_item	2738809	et	3	main
eestist	doc_582053207523_item	2738811	et	3	main
rahvakalendri	doc_582053207523_item	2738814	et	3	main
ja	doc_582053207523_item	2738817	et	3	main
kadri-	doc_582053207523_item	2738821	et	4	main
46	doc_582053207523_item	2738830	et	2	main
klassile	doc_582053207523_item	2738831	et	3	main
õpilase	doc_582053207523_item	2738844	et	3	main
mina	doc_582053207523_item	2738849	et	4	main
paikkonna	doc_582053207523_item	2738852	et	3	main
eesti	doc_582053207523_item	2738873	et	4	main
9	doc_582053207523_item	2738877	et	2	main
koliastmel	doc_582053207523_item	2738880	et	3	main
eestikeelseid	doc_582053207523_item	2738894	et	3	main
lõpetaja	doc_582053207523_item	2738922	et	4	main
eesti	doc_582053207523_item	2738936	et	4	main
ja	doc_582053207523_item	2738941	et	3	main
ning	doc_582053207523_item	2738948	et	3	main
kursuseks	doc_582053207523_item	2738961	et	3	main
kursuse	doc_582053207523_item	2738963	et	3	main
2	doc_582053207523_item	2738978	et	2	main
seda	doc_582053207523_item	2738981	et	3	main
35-tunnise	doc_582053207523_item	2738985	et	4	main
kutselise	doc_582053207523_item	2738995	et	4	main
i	doc_582053207523_item	2739003	et	4	main
kirjandusest	doc_582053207523_item	2739007	et	4	main
kunstist	doc_582053207523_item	2739009	et	4	main
muusikast	doc_582053207523_item	2739010	et	4	main
poole	doc_582053207523_item	2739015	et	4	main
ja	doc_582053207523_item	2739026	et	3	main
kunstniku	doc_582053207523_item	2739027	et	3	main
teised	doc_582053207523_item	2739037	et	4	main
keeled	doc_582053207523_item	2739038	et	3	main
struktuurilised	doc_582053207523_item	2739044	et	4	main
tutvustus	doc_582053207523_item	2739056	et	4	main
seosed	doc_582053207523_item	2739064	et	3	main
rahvapärimust	doc_582053207523_item	2738623	et	4	main
ka	doc_582053207523_item	2738629	et	3	main
praegune	doc_582053207523_item	2738637	et	3	main
õppekava	doc_582053207523_item	2738638	et	4	main
õppimiseks	doc_582053207523_item	2738646	et	4	main
peetakse	doc_582053207523_item	2738653	et	3	main
õppimine	doc_582053207523_item	2738656	et	4	main
ja	doc_582053207523_item	2738657	et	3	main
valdamine	doc_582053207523_item	2738658	et	4	main
ei	doc_582053207523_item	2738668	et	4	main
öelda	doc_582053207523_item	2738671	et	4	main
selle	doc_582053207523_item	2738672	et	4	main
rahvapärimusest	doc_582053207523_item	2738673	et	4	main
selliste	doc_582053207523_item	2738674	et	4	main
tundide	doc_582053207523_item	2738675	et	3	main
jooksul	doc_582053207523_item	2738676	et	4	main
mis	doc_582053207523_item	2738677	et	4	main
on	doc_582053207523_item	2738678	et	4	main
määratletud	doc_582053207523_item	2738679	et	4	main
rahvapärimuse	doc_582053207523_item	2738680	et	3	main
õppimiseks	doc_582053207523_item	2738681	et	4	main
saab	doc_582053207523_item	2738682	et	3	main
anda	doc_582053207523_item	2738683	et	3	main
vaid	doc_582053207523_item	2738684	et	3	main
lühiülevaade	doc_582053207523_item	2738685	et	3	main
kuigi	doc_582053207523_item	2738686	et	3	main
loomulikult	doc_582053207523_item	2738687	et	4	main
see	doc_582053207523_item	2738688	et	3	main
pole	doc_582053207523_item	2738689	et	3	main
piisav	doc_582053207523_item	2738690	et	4	main
samas	doc_582053207523_item	2738691	et	4	main
koolid	doc_582053207523_item	2738693	et	3	main
tulema	doc_582053207523_item	2738702	et	4	main
kes	doc_582053207523_item	2738704	et	4	main
peaks	doc_582053207523_item	2738705	et	4	main
ma	doc_582053207523_item	2738711	et	3	main
maksa	doc_582053207523_item	2738717	et	4	main
peetakse	doc_582053207523_item	2738722	et	3	main
valdamine	doc_582053207523_item	2738726	et	4	main
mitte	doc_582053207523_item	2738727	et	3	main
kultuuriloo	doc_582053207523_item	2738733	et	4	main
koostatud	doc_582053207523_item	2738738	et	4	main
sellest	doc_582053207523_item	2738746	et	4	main
riiklik	doc_582053207523_item	2738760	et	3	main
õppekava	doc_582053207523_item	2738764	et	4	main
määrab	doc_582053207523_item	2738765	et	3	main
kindlaks	doc_582053207523_item	2738766	et	3	main
põhikooli	doc_582053207523_item	2738767	et	4	main
ja	doc_582053207523_item	2738768	et	3	main
gümnaasiumi	doc_582053207523_item	2738769	et	4	main
edaspidi	doc_582053207523_item	2738770	et	3	main
riikliku	doc_582053207523_item	2738776	et	3	main
põhimõtted	doc_582053207523_item	2738778	et	3	main
kooliõppekava	doc_582053207523_item	2738793	et	4	main
ülesehituse	doc_582053207523_item	2738794	et	3	main
keele	doc_582053207523_item	2738803	et	4	main
tähtpäevadest	doc_582053207523_item	2738815	et	3	main
kultuur	doc_582053207523_item	2738818	et	3	main
üldandmedrahvussümbolikarahvuslindlillpuu	doc_582053207523_item	2738820	et	4	main
mardipäev	doc_582053207523_item	2738823	et	3	main
sel	doc_582053207523_item	2738832	et	3	main
laienevad	doc_582053207523_item	2738848	et	4	main
ja	doc_582053207523_item	2738854	et	3	main
kultuuritegelasedraamatukogujutte	doc_582053207523_item	2738855	et	4	main
lippvapphümneesti	doc_582053207523_item	2738866	et	4	main
president	doc_582053207523_item	2738867	et	3	main
6klassi	doc_582053207523_item	2738868	et	4	main
lõpetaja	doc_582053207523_item	2738869	et	4	main
teab	doc_582053207523_item	2738870	et	3	main
keele	doc_582053207523_item	2738874	et	4	main
7	doc_582053207523_item	2738876	et	2	main
klassile	doc_582053207523_item	2738878	et	3	main
keskendutakse	doc_582053207523_item	2738881	et	3	main
eripäraleloodus	doc_582053207523_item	2738883	et	4	main
kliima	doc_582053207523_item	2738884	et	4	main
kultuurilugusenisest	doc_582053207523_item	2738885	et	3	main
kultuurielust	doc_582053207523_item	2738892	et	3	main
2-3	doc_582053207523_item	2738924	et	2	main
objekte	doc_582053207523_item	2738939	et	3	main
huviväärsustest	doc_582053207523_item	2738949	et	4	main
ainekava	doc_582053207523_item	2738952	et	4	main
9	doc_582053207523_item	2738959	et	2	main
on	doc_582053207523_item	2738965	et	4	main
on	doc_582053207523_item	2738976	et	4	main
kuid	doc_582053207523_item	2738980	et	4	main
ka	doc_582053207523_item	2738984	et	3	main
kursusena	doc_582053207523_item	2738986	et	3	main
ja	doc_582053207523_item	2738992	et	3	main
kunsti	doc_582053207523_item	2738993	et	4	main
teadusest	doc_582053207523_item	2739011	et	4	main
20	doc_582053207523_item	2739012	et	2	main
sajandi	doc_582053207523_item	2739013	et	3	main
ii	doc_582053207523_item	2739014	et	4	main
keel	doc_582053207523_item	2739035	et	4	main
ja	doc_582053207523_item	2739036	et	3	main
keel	doc_582053207523_item	2739043	et	4	main
eesti	doc_582053207523_item	2739046	et	4	main
keeles	doc_582053207523_item	2739049	et	4	main
kirjakeele	doc_582053207523_item	2739051	et	4	main
kujunemine	doc_582053207523_item	2739052	et	4	main
23	doc_582053207523_item	2739053	et	2	main
keeleteadlase	doc_582053207523_item	2739054	et	3	main
ja	doc_582053207523_item	2739060	et	3	main
kasutamine	doc_582053207523_item	2739061	et	4	main
kultuuride	doc_582053207523_item	2739062	et	3	main
ja	doc_582053207523_item	2739087	et	3	main
rahvakalendri	doc_582053207523_item	2739088	et	3	main
tähtpäevadestjõulud	doc_582053207523_item	2739089	et	4	main
sõbrapäev	doc_582053207523_item	2739090	et	3	main
emadepäev	doc_582053207523_item	2739091	et	3	main
õpetaja	doc_582053207523_item	2739092	et	4	main
keele	doc_582053207523_item	2738723	et	4	main
õppimine	doc_582053207523_item	2738724	et	4	main
ja	doc_582053207523_item	2738725	et	3	main
tutvustamine	doc_582053207523_item	2738732	et	4	main
ole	doc_582053207523_item	2738736	et	4	main
eraldi	doc_582053207523_item	2738737	et	4	main
ainult	doc_582053207523_item	2738750	et	4	main
need	doc_582053207523_item	2738751	et	3	main
gümnaasiumi	doc_582053207523_item	2738759	et	4	main
edaspidi	doc_582053207523_item	2738762	et	3	main
õppe-	doc_582053207523_item	2738772	et	4	main
ja	doc_582053207523_item	2738773	et	3	main
kasvatustegevuse	doc_582053207523_item	2738774	et	4	main
alused	doc_582053207523_item	2738782	et	4	main
kohustuslikud	doc_582053207523_item	2738783	et	3	main
õppeained	doc_582053207523_item	2738784	et	3	main
koostamise	doc_582053207523_item	2738796	et	4	main
kooli	doc_582053207523_item	2738799	et	4	main
õiguslikust	doc_582053207523_item	2738800	et	4	main
seisundist	doc_582053207523_item	2738801	et	3	main
eesti	doc_582053207523_item	2738802	et	4	main
sõbrapäev	doc_582053207523_item	2738825	et	3	main
emadepäev	doc_582053207523_item	2738826	et	3	main
keele	doc_582053207523_item	2738828	et	4	main
ainekava	doc_582053207523_item	2738829	et	4	main
õpilane	doc_582053207523_item	2738835	et	3	main
kodukoha	doc_582053207523_item	2738837	et	4	main
õpib	doc_582053207523_item	2738839	et	3	main
sellest	doc_582053207523_item	2738840	et	4	main
eesti	doc_582053207523_item	2738846	et	4	main
kultuurist	doc_582053207523_item	2738847	et	3	main
tähtpäevadeesti	doc_582053207523_item	2738865	et	4	main
enam	doc_582053207523_item	2738886	et	4	main
pakutakse	doc_582053207523_item	2738887	et	3	main
õpilasele	doc_582053207523_item	2738888	et	3	main
aktiivset	doc_582053207523_item	2738889	et	3	main
korraldatakse	doc_582053207523_item	2738893	et	3	main
klassiväliseid	doc_582053207523_item	2738895	et	4	main
põhikooli	doc_582053207523_item	2738921	et	4	main
noorsookirjanikku	doc_582053207523_item	2738925	et	4	main
eesti	doc_582053207523_item	2738927	et	4	main
keeles	doc_582053207523_item	2738928	et	4	main
kultuuriloo	doc_582053207523_item	2738937	et	4	main
sündmusi	doc_582053207523_item	2738940	et	3	main
kultuuritegelastjutustab	doc_582053207523_item	2738943	et	4	main
ja	doc_582053207523_item	2738945	et	3	main
eesti	doc_582053207523_item	2738946	et	4	main
eluolust	doc_582053207523_item	2738947	et	3	main
keele	doc_582053207523_item	2738956	et	4	main
ainekava	doc_582053207523_item	2738957	et	4	main
liigendub	doc_582053207523_item	2738958	et	3	main
ühe	doc_582053207523_item	2738962	et	4	main
õpetamiseks	doc_582053207523_item	2738975	et	4	main
kursust	doc_582053207523_item	2738979	et	3	main
võib	doc_582053207523_item	2738982	et	3	main
näiteid	doc_582053207523_item	2739006	et	3	main
teadmised	doc_582053207523_item	2738810	et	4	main
rahvussümbolikast	doc_582053207523_item	2738812	et	3	main
mina	doc_582053207523_item	2738816	et	4	main
eesti	doc_582053207523_item	2738819	et	4	main
ja	doc_582053207523_item	2738822	et	3	main
eesti	doc_582053207523_item	2738827	et	4	main
teadvustab	doc_582053207523_item	2738834	et	3	main
eesti	doc_582053207523_item	2738841	et	4	main
keeles	doc_582053207523_item	2738842	et	4	main
jutustama	doc_582053207523_item	2738843	et	3	main
ja	doc_582053207523_item	2738856	et	3	main
eesti	doc_582053207523_item	2738858	et	4	main
eesti	doc_582053207523_item	2738882	et	4	main
osavõttu	doc_582053207523_item	2738890	et	4	main
üritusi	doc_582053207523_item	2738896	et	4	main
käiakse	doc_582053207523_item	2738897	et	3	main
tetris	doc_582053207523_item	2738898	et	4	main
kontserditel	doc_582053207523_item	2738899	et	4	main
muuseumides	doc_582053207523_item	2738900	et	3	main
jm	doc_582053207523_item	2738901	et	4	main
mina	doc_582053207523_item	2738902	et	4	main
ja	doc_582053207523_item	2738903	et	3	main
kultuurpaikkonna	doc_582053207523_item	2738904	et	3	main
kultuurielu	doc_582053207523_item	2738905	et	4	main
eesti	doc_582053207523_item	2738906	et	4	main
kultuuriloo	doc_582053207523_item	2738907	et	4	main
objektid	doc_582053207523_item	2738909	et	3	main
tähtsamad	doc_582053207523_item	2738908	et	4	main
sündmused	doc_582053207523_item	2738910	et	3	main
ja	doc_582053207523_item	2738911	et	3	main
olulised	doc_582053207523_item	2738912	et	4	main
kultuuritegelased	doc_582053207523_item	2738913	et	3	main
katked	doc_582053207523_item	2738914	et	4	main
noorsookirjandusest	doc_582053207523_item	2738915	et	4	main
näiteid	doc_582053207523_item	2738916	et	3	main
muinasjuttudest	doc_582053207523_item	2738917	et	3	main
muistenditest	doc_582053207523_item	2738918	et	3	main
naljanditest	doc_582053207523_item	2738919	et	3	main
legendidest	doc_582053207523_item	2738920	et	3	main
lugenud	doc_582053207523_item	2738929	et	4	main
2-3	doc_582053207523_item	2738930	et	2	main
eakohast	doc_582053207523_item	2738931	et	4	main
ja	doc_582053207523_item	2738932	et	3	main
keeleliselt	doc_582053207523_item	2738933	et	4	main
jõukohast	doc_582053207523_item	2738934	et	4	main
proosateksti	doc_582053207523_item	2738935	et	4	main
eesti	doc_582053207523_item	2738950	et	4	main
keele	doc_582053207523_item	2738951	et	4	main
gümnaasiumile	doc_582053207523_item	2738953	et	3	main
gümnaasiumi	doc_582053207523_item	2738954	et	4	main
järjestus	doc_582053207523_item	2738969	et	4	main
ja	doc_582053207523_item	2738970	et	3	main
maht	doc_582053207523_item	2738971	et	3	main
fikseeritakse	doc_582053207523_item	2738972	et	3	main
kooliõppekavas	doc_582053207523_item	2738973	et	3	main
kultuuriloo	doc_582053207523_item	2738974	et	4	main
kavandatud	doc_582053207523_item	2738977	et	4	main
õpetada	doc_582053207523_item	2738983	et	3	main
kultuurilugu	doc_582053207523_item	2738987	et	4	main
teab	doc_582053207523_item	2738923	et	3	main
on	doc_582053207523_item	2738926	et	4	main
tähtsamaid	doc_582053207523_item	2738938	et	4	main
2-3	doc_582053207523_item	2738942	et	2	main
paikkonna	doc_582053207523_item	2738944	et	3	main
eesti	doc_582053207523_item	2738955	et	4	main
kohustusliks	doc_582053207523_item	2738960	et	4	main
maht	doc_582053207523_item	2738964	et	3	main
35	doc_582053207523_item	2738966	et	2	main
õppetundi	doc_582053207523_item	2738967	et	4	main
kursuste	doc_582053207523_item	2738968	et	3	main
sünd	doc_582053207523_item	2738994	et	3	main
ja	doc_582053207523_item	2738997	et	3	main
traditsiooni	doc_582053207523_item	2738999	et	4	main
algus	doc_582053207523_item	2739000	et	4	main
20	doc_582053207523_item	2739001	et	2	main
sajandi	doc_582053207523_item	2739002	et	3	main
poole	doc_582053207523_item	2739004	et	4	main
kultuurielu	doc_582053207523_item	2739016	et	4	main
näiteid	doc_582053207523_item	2739017	et	3	main
proosast	doc_582053207523_item	2739018	et	4	main
ja	doc_582053207523_item	2739019	et	3	main
luulest	doc_582053207523_item	2739020	et	4	main
muusikategelase	doc_582053207523_item	2739025	et	3	main
teatrietenduse	doc_582053207523_item	2739032	et	3	main
keel	doc_582053207523_item	2739040	et	4	main
kui	doc_582053207523_item	2739041	et	3	main
soomeugri	doc_582053207523_item	2739042	et	4	main
vene	doc_582053207523_item	2739048	et	4	main
õigekeelsussõnaraamatu	doc_582053207523_item	2739057	et	4	main
koostamise	doc_582053207523_item	2739058	et	4	main
printsiibid	doc_582053207523_item	2739059	et	3	main
tõlkekirjandus	doc_582053207523_item	2739065	et	3	main
eesti	doc_582053207523_item	2739071	et	4	main
keele	doc_582053207523_item	2739072	et	4	main
jm	doc_582053207523_item	2739081	et	4	main
rahvussümboolikastlindlillpuu	doc_582053207523_item	2739086	et	4	main
tähendust	doc_582053207523_item	2739101	et	4	main
keele	doc_582053207523_item	2739103	et	4	main
ja	doc_582053207523_item	2739104	et	3	main
koduloo	doc_582053207523_item	2739105	et	4	main
tunnis	doc_582053207523_item	2739106	et	3	main
ja	doc_582053207523_item	2739118	et	3	main
ja	doc_582053207523_item	2739125	et	3	main
eesti	doc_582053207523_item	2739141	et	4	main
sel	doc_582053207523_item	2739143	et	3	main
kasutatakse	doc_582053207523_item	2739145	et	3	main
ja	doc_582053207523_item	2739150	et	3	main
lihtsamaid	doc_582053207523_item	2739166	et	4	main
tähtpäevakaarte	doc_582053207523_item	2739168	et	4	main
tähistamine	doc_582053207523_item	2739203	et	4	main
klassidevaheline	doc_582053207523_item	2739207	et	4	main
emadepäeva	doc_582053207523_item	2739210	et	4	main
mõista	doc_582053207523_item	2739220	et	4	main
nende	doc_582053207523_item	2739237	et	4	main
kuid	doc_582053207523_item	2739255	et	4	main
mis	doc_582053207523_item	2739256	et	4	main
roll	doc_582053207523_item	2739257	et	3	main
ei	doc_582053207523_item	2739268	et	4	main
ainuke	doc_582053207523_item	2739296	et	4	main
emadepäev	doc_582053207523_item	2739306	et	3	main
klass	doc_582053207523_item	2739308	et	3	main
kultuuriruumigata	doc_582053207523_item	2739317	et	4	main
rahvussümboolikast	doc_582053207523_item	2739322	et	4	main
oskab	doc_582053207523_item	2739327	et	3	main
üldandmetest	doc_582053207523_item	2739329	et	4	main
mardipäev	doc_582053207523_item	2739336	et	3	main
emadepäev	doc_582053207523_item	2739339	et	3	main
mardipäeva	doc_582053207523_item	2739347	et	4	main
tähistamine	doc_582053207523_item	2739348	et	4	main
tähistamine	doc_582053207523_item	2739354	et	4	main
tähistatakse	doc_582053207523_item	2739381	et	3	main
mardisanti	doc_582053207523_item	2739392	et	4	main
ja	doc_582053207523_item	2739393	et	3	main
võrrelda	doc_582053207523_item	2739396	et	4	main
ja	doc_582053207523_item	2739398	et	3	main
ärkamisaegne	doc_582053207523_item	2738988	et	3	main
kultuurielu	doc_582053207523_item	2738989	et	4	main
rahvusliku	doc_582053207523_item	2738990	et	3	main
kirjanduse	doc_582053207523_item	2738991	et	3	main
teatri	doc_582053207523_item	2738996	et	3	main
laulupidude	doc_582053207523_item	2738998	et	4	main
kultuurielu	doc_582053207523_item	2739005	et	4	main
ajakirjandusest	doc_582053207523_item	2739008	et	4	main
eesti	doc_582053207523_item	2739021	et	4	main
filmilinal	doc_582053207523_item	2739023	et	3	main
loomingu	doc_582053207523_item	2739028	et	3	main
eestikeelse	doc_582053207523_item	2739030	et	3	main
kultuurisaate	doc_582053207523_item	2739031	et	3	main
arutelu	doc_582053207523_item	2739033	et	4	main
eesti	doc_582053207523_item	2739034	et	4	main
erinevused	doc_582053207523_item	2739045	et	4	main
tegevuse	doc_582053207523_item	2739055	et	4	main
lütseumi	doc_582053207523_item	2739070	et	4	main
1klass	doc_582053207523_item	2739074	et	3	main
õpilane	doc_582053207523_item	2739075	et	3	main
kirjutab	doc_582053207523_item	2739076	et	3	main
lihtsamaid	doc_582053207523_item	2739077	et	4	main
esmased	doc_582053207523_item	2739083	et	3	main
teadmised	doc_582053207523_item	2739084	et	4	main
rahvussümboolikat	doc_582053207523_item	2739098	et	3	main
jõulutraditsioone	doc_582053207523_item	2739109	et	3	main
kuidas	doc_582053207523_item	2739110	et	3	main
eesti	doc_582053207523_item	2739117	et	4	main
kirjandus	doc_582053207523_item	2739022	et	3	main
23	doc_582053207523_item	2739024	et	2	main
tutvustus	doc_582053207523_item	2739029	et	4	main
eesti	doc_582053207523_item	2739039	et	4	main
ja	doc_582053207523_item	2739047	et	3	main
eesti	doc_582053207523_item	2739050	et	4	main
vahelised	doc_582053207523_item	2739063	et	4	main
13tallinna	doc_582053207523_item	2739067	et	4	main
õismäe	doc_582053207523_item	2739068	et	3	main
vene	doc_582053207523_item	2739069	et	4	main
kooliõppekava	doc_582053207523_item	2739073	et	4	main
omandab	doc_582053207523_item	2739082	et	3	main
eestist	doc_582053207523_item	2739085	et	3	main
nende	doc_582053207523_item	2739100	et	4	main
eesti	doc_582053207523_item	2739102	et	4	main
ja	doc_582053207523_item	2739111	et	3	main
vene	doc_582053207523_item	2739119	et	4	main
ei	doc_582053207523_item	2739122	et	4	main
on	doc_582053207523_item	2739127	et	4	main
mõistetavamad	doc_582053207523_item	2739129	et	4	main
nad	doc_582053207523_item	2739130	et	3	main
oskavad	doc_582053207523_item	2739131	et	4	main
2	doc_582053207523_item	2739136	et	2	main
kultuuriruumiga	doc_582053207523_item	2739142	et	4	main
kooliastmel	doc_582053207523_item	2739144	et	3	main
keeleõppes	doc_582053207523_item	2739146	et	3	main
praktilist	doc_582053207523_item	2739148	et	3	main
tegevust	doc_582053207523_item	2739149	et	4	main
ja	doc_582053207523_item	2739196	et	3	main
julupühade	doc_582053207523_item	2739208	et	4	main
tähistamine	doc_582053207523_item	2739211	et	4	main
laste	doc_582053207523_item	2739212	et	4	main
arenguks	doc_582053207523_item	2739213	et	3	main
kasutatakse	doc_582053207523_item	2739214	et	3	main
mõistatusi	doc_582053207523_item	2739223	et	4	main
tiritamm	doc_582053207523_item	2739225	et	3	main
1992laulukogumikkeeesti	doc_582053207523_item	2739226	et	4	main
muinasjutte	doc_582053207523_item	2739227	et	3	main
seotud	doc_582053207523_item	2739239	et	4	main
tavasid	doc_582053207523_item	2739240	et	3	main
et	doc_582053207523_item	2739243	et	3	main
ja	doc_582053207523_item	2739245	et	3	main
kadrisandid	doc_582053207523_item	2739246	et	4	main
neile	doc_582053207523_item	2739265	et	4	main
seda	doc_582053207523_item	2739291	et	3	main
nad	doc_582053207523_item	2739292	et	3	main
jällegi	doc_582053207523_item	2739293	et	4	main
mõistetav	doc_582053207523_item	2739304	et	4	main
õppeeesmärgideks	doc_582053207523_item	2739309	et	3	main
et	doc_582053207523_item	2739312	et	3	main
kontakt	doc_582053207523_item	2739315	et	3	main
ja	doc_582053207523_item	2739323	et	3	main
rahvussümboolikast	doc_582053207523_item	2739330	et	4	main
rahvuslind	doc_582053207523_item	2739331	et	3	main
lill	doc_582053207523_item	2739332	et	3	main
puu	doc_582053207523_item	2739333	et	4	main
neid	doc_582053207523_item	2739341	et	4	main
praktikal	doc_582053207523_item	2739343	et	3	main
korraldatakse	doc_582053207523_item	2739345	et	3	main
tähistamine	doc_582053207523_item	2739351	et	4	main
klassidevaheline	doc_582053207523_item	2739352	et	4	main
jõulupühade	doc_582053207523_item	2739353	et	3	main
seotud	doc_582053207523_item	2739374	et	4	main
üritused	doc_582053207523_item	2739375	et	4	main
seda	doc_582053207523_item	2739378	et	3	main
teavad	doc_582053207523_item	2739402	et	3	main
tähtpäevast	doc_582053207523_item	2739415	et	4	main
õpilased	doc_582053207523_item	2739419	et	3	main
httpswwwriigiteatajaeeertactjspid802290	doc_582053207523_item	2739066	et	4	main
tekste	doc_582053207523_item	2739078	et	3	main
tähtpäevakaarte	doc_582053207523_item	2739079	et	4	main
sünnipäevakutseid	doc_582053207523_item	2739080	et	3	main
eesti	doc_582053207523_item	2739097	et	4	main
ja	doc_582053207523_item	2739099	et	3	main
eesti	doc_582053207523_item	2739108	et	4	main
millal	doc_582053207523_item	2739112	et	3	main
tähistavad	doc_582053207523_item	2739113	et	4	main
eestlased	doc_582053207523_item	2739114	et	3	main
jõule	doc_582053207523_item	2739115	et	4	main
jõulud	doc_582053207523_item	2739120	et	3	main
sõbrapäev	doc_582053207523_item	2739124	et	3	main
emadepäev	doc_582053207523_item	2739126	et	3	main
õpilastele	doc_582053207523_item	2739128	et	4	main
kontakt	doc_582053207523_item	2739140	et	3	main
palju	doc_582053207523_item	2739147	et	4	main
häälega	doc_582053207523_item	2739155	et	3	main
lugemine	doc_582053207523_item	2739156	et	4	main
ja	doc_582053207523_item	2739157	et	3	main
loetu	doc_582053207523_item	2739158	et	4	main
vestlemine	doc_582053207523_item	2739162	et	4	main
jutustamine	doc_582053207523_item	2739163	et	4	main
õpilane	doc_582053207523_item	2739164	et	3	main
jm	doc_582053207523_item	2739170	et	4	main
mardipäeva	doc_582053207523_item	2739202	et	4	main
peale	doc_582053207523_item	2739215	et	4	main
õppekavajärgseid	doc_582053207523_item	2739216	et	3	main
raamatuid	doc_582053207523_item	2739217	et	3	main
ka	doc_582053207523_item	2739218	et	3	main
mõista	doc_582053207523_item	2739219	et	4	main
kommentaar	doc_582053207523_item	2739093	et	3	main
õpilane	doc_582053207523_item	2739094	et	3	main
õpib	doc_582053207523_item	2739095	et	3	main
tundma	doc_582053207523_item	2739096	et	3	main
õpitakse	doc_582053207523_item	2739107	et	4	main
miks	doc_582053207523_item	2739116	et	4	main
lange	doc_582053207523_item	2739123	et	4	main
mõista	doc_582053207523_item	2739132	et	4	main
nende	doc_582053207523_item	2739133	et	4	main
tähtpäevade	doc_582053207523_item	2739134	et	3	main
tähendusi	doc_582053207523_item	2739135	et	4	main
klass	doc_582053207523_item	2739137	et	3	main
õpilasel	doc_582053207523_item	2739138	et	3	main
tekib	doc_582053207523_item	2739139	et	3	main
on	doc_582053207523_item	2739154	et	4	main
vastamine	doc_582053207523_item	2739161	et	4	main
tekste	doc_582053207523_item	2739167	et	3	main
sünnipäevakutseid	doc_582053207523_item	2739169	et	3	main
täiendab	doc_582053207523_item	2739171	et	3	main
pikaajalised	doc_582053207523_item	2739197	et	4	main
koolidevahelised	doc_582053207523_item	2739198	et	4	main
projektid	doc_582053207523_item	2739199	et	3	main
nt	doc_582053207523_item	2739200	et	4	main
kadripäeva	doc_582053207523_item	2739205	et	4	main
tähistamine	doc_582053207523_item	2739206	et	4	main
eesti	doc_582053207523_item	2739221	et	4	main
tallinn	doc_582053207523_item	2739224	et	4	main
kadripäeva	doc_582053207523_item	2739232	et	4	main
ja	doc_582053207523_item	2739233	et	3	main
mardipäeva	doc_582053207523_item	2739234	et	4	main
on	doc_582053207523_item	2739258	et	4	main
tea	doc_582053207523_item	2739269	et	4	main
päev	doc_582053207523_item	2739297	et	3	main
neil	doc_582053207523_item	2739299	et	4	main
on	doc_582053207523_item	2739305	et	4	main
3	doc_582053207523_item	2739307	et	2	main
on	doc_582053207523_item	2739310	et	4	main
see	doc_582053207523_item	2739311	et	3	main
õpilasel	doc_582053207523_item	2739313	et	3	main
eesti	doc_582053207523_item	2739316	et	4	main
oma	doc_582053207523_item	2739319	et	4	main
kokku	doc_582053207523_item	2739121	et	3	main
mängu	doc_582053207523_item	2739151	et	4	main
tähelepanu	doc_582053207523_item	2739152	et	4	main
keskmes	doc_582053207523_item	2739153	et	3	main
põhjal	doc_582053207523_item	2739159	et	4	main
küsimustele	doc_582053207523_item	2739160	et	4	main
kirjutab	doc_582053207523_item	2739165	et	3	main
oma	doc_582053207523_item	2739172	et	4	main
teadmisi	doc_582053207523_item	2739173	et	4	main
eestistüldandmed	doc_582053207523_item	2739174	et	4	main
rahvussümboolikast	doc_582053207523_item	2739175	et	4	main
rahvuslind	doc_582053207523_item	2739176	et	3	main
lill	doc_582053207523_item	2739177	et	3	main
puu	doc_582053207523_item	2739178	et	4	main
ja	doc_582053207523_item	2739179	et	3	main
rahvakalendri	doc_582053207523_item	2739180	et	3	main
tähtpäevadest	doc_582053207523_item	2739181	et	3	main
kadri-	doc_582053207523_item	2739182	et	4	main
ja	doc_582053207523_item	2739183	et	3	main
mardipäev	doc_582053207523_item	2739184	et	3	main
jõulud	doc_582053207523_item	2739185	et	3	main
sõbrapäev	doc_582053207523_item	2739186	et	3	main
emadepäev	doc_582053207523_item	2739187	et	3	main
jaanipäev	doc_582053207523_item	2739188	et	3	main
samas	doc_582053207523_item	2739189	et	4	main
on	doc_582053207523_item	2739190	et	4	main
käivel	doc_582053207523_item	2739191	et	4	main
mitmesugused	doc_582053207523_item	2739192	et	3	main
ainetevahelised	doc_582053207523_item	2739193	et	4	main
klassidevahelised	doc_582053207523_item	2739194	et	4	main
ülekoolilised	doc_582053207523_item	2739195	et	4	main
klassidevaheline	doc_582053207523_item	2739201	et	4	main
klassidevaheline	doc_582053207523_item	2739204	et	4	main
tähistamine	doc_582053207523_item	2739209	et	4	main
rahva	doc_582053207523_item	2739222	et	3	main
tähendust	doc_582053207523_item	2739235	et	4	main
teavad	doc_582053207523_item	2739236	et	3	main
teavad	doc_582053207523_item	2739242	et	3	main
mardisandid	doc_582053207523_item	2739244	et	4	main
peavad	doc_582053207523_item	2739247	et	4	main
laulma	doc_582053207523_item	2739248	et	3	main
ja	doc_582053207523_item	2739249	et	3	main
tantsima	doc_582053207523_item	2739250	et	3	main
ning	doc_582053207523_item	2739251	et	3	main
neile	doc_582053207523_item	2739252	et	4	main
antakse	doc_582053207523_item	2739253	et	3	main
tegelikult	doc_582053207523_item	2739259	et	4	main
mardisantidel	doc_582053207523_item	2739260	et	3	main
ja	doc_582053207523_item	2739261	et	3	main
kadrisantidel	doc_582053207523_item	2739262	et	3	main
see	doc_582053207523_item	2739263	et	3	main
jääb	doc_582053207523_item	2739264	et	3	main
ei	doc_582053207523_item	2739294	et	4	main
mis	doc_582053207523_item	2739298	et	4	main
on	doc_582053207523_item	2739300	et	4	main
selge	doc_582053207523_item	2739301	et	4	main
ja	doc_582053207523_item	2739302	et	3	main
täiesti	doc_582053207523_item	2739303	et	3	main
tekib	doc_582053207523_item	2739314	et	3	main
täiendab	doc_582053207523_item	2739318	et	3	main
teadmisi	doc_582053207523_item	2739320	et	4	main
tähtpäevadest	doc_582053207523_item	2739325	et	3	main
rääkidaeesti	doc_582053207523_item	2739328	et	4	main
teadmisi	doc_582053207523_item	2739342	et	4	main
kadripäeva	doc_582053207523_item	2739350	et	4	main
tähistamine	doc_582053207523_item	2739356	et	4	main
kus	doc_582053207523_item	2739357	et	3	main
selle	doc_582053207523_item	2739372	et	4	main
kuidas	doc_582053207523_item	2739380	et	3	main
päeva	doc_582053207523_item	2739383	et	4	main
ning	doc_582053207523_item	2739384	et	3	main
miks	doc_582053207523_item	2739385	et	4	main
otsitakse	doc_582053207523_item	2739386	et	3	main
sõnajalaõit	doc_582053207523_item	2739387	et	3	main
õpilased	doc_582053207523_item	2739388	et	3	main
jooksevad	doc_582053207523_item	2739389	et	4	main
juba	doc_582053207523_item	2739390	et	3	main
oskavad	doc_582053207523_item	2739395	et	4	main
vene	doc_582053207523_item	2739399	et	4	main
samuti	doc_582053207523_item	2739401	et	3	main
mardipäev	doc_582053207523_item	2739416	et	3	main
kadripäev	doc_582053207523_item	2739418	et	3	main
üritustel	doc_582053207523_item	2739422	et	4	main
või	doc_582053207523_item	2739428	et	4	main
tallinna	doc_582053207523_item	2739437	et	4	main
õismäe	doc_582053207523_item	2739438	et	3	main
vene	doc_582053207523_item	2739439	et	4	main
lütseumis	doc_582053207523_item	2739440	et	3	main
selle	doc_582053207523_item	2739451	et	4	main
rohkem	doc_582053207523_item	2739471	et	4	main
teadmisi	doc_582053207523_item	2739488	et	4	main
tähtpäevadesteesti	doc_582053207523_item	2739491	et	4	main
eesti	doc_582053207523_item	2739493	et	4	main
lipp	doc_582053207523_item	2739494	et	3	main
vapp	doc_582053207523_item	2739495	et	3	main
praktikal	doc_582053207523_item	2739499	et	3	main
rakendada	doc_582053207523_item	2739500	et	3	main
siin	doc_582053207523_item	2739529	et	4	main
õpetajad	doc_582053207523_item	2739536	et	4	main
on	doc_582053207523_item	2739559	et	4	main
eakohast	doc_582053207523_item	2739564	et	4	main
ja	doc_582053207523_item	2739565	et	3	main
lasteraamatut	doc_582053207523_item	2739568	et	3	main
oskab	doc_582053207523_item	2739570	et	3	main
ilusa	doc_582053207523_item	2739614	et	3	main
kahjuks	doc_582053207523_item	2739626	et	4	main
tunnijaotusplaani	doc_582053207523_item	2739629	et	4	main
enda	doc_582053207523_item	2739634	et	4	main
initsiatiivil	doc_582053207523_item	2739635	et	3	main
räägivad	doc_582053207523_item	2739643	et	3	main
huvi	doc_582053207523_item	2739651	et	4	main
õpetajate	doc_582053207523_item	2739228	et	4	main
kommentaarid	doc_582053207523_item	2739229	et	3	main
õpilased	doc_582053207523_item	2739230	et	3	main
mõistavad	doc_582053207523_item	2739231	et	3	main
päevadega	doc_582053207523_item	2739238	et	3	main
nad	doc_582053207523_item	2739241	et	3	main
ande	doc_582053207523_item	2739254	et	4	main
mõistatuseks	doc_582053207523_item	2739266	et	4	main
õpilased	doc_582053207523_item	2739267	et	3	main
et	doc_582053207523_item	2739270	et	3	main
nad	doc_582053207523_item	2739271	et	3	main
toovad	doc_582053207523_item	2739272	et	4	main
vilja-ja	doc_582053207523_item	2739273	et	3	main
karjaõnne	doc_582053207523_item	2739274	et	4	main
rahvuslind	doc_582053207523_item	2739275	et	3	main
lill	doc_582053207523_item	2739276	et	3	main
ja	doc_582053207523_item	2739277	et	3	main
puu	doc_582053207523_item	2739278	et	4	main
on	doc_582053207523_item	2739279	et	4	main
enamus	doc_582053207523_item	2739280	et	4	main
õpilastel	doc_582053207523_item	2739281	et	4	main
selge	doc_582053207523_item	2739282	et	4	main
kuid	doc_582053207523_item	2739283	et	4	main
kuuluvad	doc_582053207523_item	2739285	et	4	main
just	doc_582053207523_item	2739286	et	3	main
nemad	doc_582053207523_item	2739287	et	3	main
miks	doc_582053207523_item	2739284	et	4	main
eesti	doc_582053207523_item	2739288	et	4	main
rahvussümboolika	doc_582053207523_item	2739289	et	4	main
hulka	doc_582053207523_item	2739290	et	4	main
tea	doc_582053207523_item	2739295	et	4	main
eestist	doc_582053207523_item	2739321	et	3	main
rahvuskalendritähtpäevadestkadri-	doc_582053207523_item	2739334	et	4	main
ja	doc_582053207523_item	2739335	et	3	main
sõbrapäev	doc_582053207523_item	2739338	et	3	main
klassidevaheline	doc_582053207523_item	2739349	et	4	main
emadepäeva	doc_582053207523_item	2739355	et	4	main
miks	doc_582053207523_item	2739376	et	4	main
päeva	doc_582053207523_item	2739379	et	4	main
seda	doc_582053207523_item	2739382	et	3	main
kadrisanti	doc_582053207523_item	2739394	et	4	main
eesti	doc_582053207523_item	2739397	et	4	main
kolmanda	doc_582053207523_item	2739405	et	3	main
klassi	doc_582053207523_item	2739406	et	4	main
tunneb	doc_582053207523_item	2739408	et	3	main
mõnedest	doc_582053207523_item	2739413	et	3	main
osalevad	doc_582053207523_item	2739420	et	4	main
koolisisestel	doc_582053207523_item	2739421	et	3	main
mis	doc_582053207523_item	2739435	et	4	main
keeles	doc_582053207523_item	2739442	et	4	main
4	doc_582053207523_item	2739443	et	2	main
klass	doc_582053207523_item	2739444	et	3	main
õppeeeasmärgiks	doc_582053207523_item	2739445	et	4	main
vastu	doc_582053207523_item	2739453	et	3	main
kelle	doc_582053207523_item	2739454	et	4	main
elatakse	doc_582053207523_item	2739456	et	3	main
selle	doc_582053207523_item	2739458	et	4	main
vaatamisväärsusi	doc_582053207523_item	2739467	et	4	main
ja	doc_582053207523_item	2739468	et	3	main
lastekirjandusest	doc_582053207523_item	2739481	et	4	main
näiteid	doc_582053207523_item	2739482	et	3	main
vanasõnadest	doc_582053207523_item	2739483	et	3	main
mõistatustest	doc_582053207523_item	2739484	et	4	main
kõnekäändudest	doc_582053207523_item	2739485	et	3	main
riigipühadest	doc_582053207523_item	2739489	et	3	main
rahvussümbolitest	doc_582053207523_item	2739492	et	4	main
presidentselleks	doc_582053207523_item	2739497	et	4	main
teadmisi	doc_582053207523_item	2739501	et	4	main
korraldatakse	doc_582053207523_item	2739502	et	3	main
lapsed	doc_582053207523_item	2739530	et	3	main
saavad	doc_582053207523_item	2739531	et	4	main
oma	doc_582053207523_item	2739532	et	4	main
saavad	doc_582053207523_item	2739537	et	4	main
on	doc_582053207523_item	2739546	et	4	main
klassi	doc_582053207523_item	2739553	et	4	main
eesti	doc_582053207523_item	2739556	et	4	main
keeles	doc_582053207523_item	2739561	et	4	main
jõukohast	doc_582053207523_item	2739567	et	4	main
ta	doc_582053207523_item	2739569	et	4	main
nimetada	doc_582053207523_item	2739571	et	3	main
eesti	doc_582053207523_item	2739572	et	4	main
riigi	doc_582053207523_item	2739573	et	3	main
sümboleid	doc_582053207523_item	2739574	et	3	main
selleks	doc_582053207523_item	2739610	et	4	main
saaks	doc_582053207523_item	2739613	et	3	main
ülevaate	doc_582053207523_item	2739615	et	4	main
eraldi	doc_582053207523_item	2739621	et	4	main
eesti	doc_582053207523_item	2739623	et	4	main
mis	doc_582053207523_item	2739625	et	4	main
kooli	doc_582053207523_item	2739628	et	4	main
vastu	doc_582053207523_item	2739653	et	3	main
huvi	doc_582053207523_item	2739671	et	4	main
armastus	doc_582053207523_item	2739673	et	4	main
selle	doc_582053207523_item	2739674	et	4	main
rahva	doc_582053207523_item	2739675	et	3	main
elatakse	doc_582053207523_item	2739685	et	3	main
saada	doc_582053207523_item	2739696	et	4	main
kultuurist	doc_582053207523_item	2739697	et	3	main
kõnekäändudest	doc_582053207523_item	2739707	et	3	main
riigipühadest	doc_582053207523_item	2739711	et	3	main
ja	doc_582053207523_item	2739712	et	3	main
tähtpäevadest	doc_582053207523_item	2739713	et	3	main
eesti	doc_582053207523_item	2739714	et	4	main
rahvakalendri	doc_582053207523_item	2739324	et	3	main
õpilane	doc_582053207523_item	2739326	et	3	main
jõulud	doc_582053207523_item	2739337	et	3	main
jaanipäevet	doc_582053207523_item	2739340	et	4	main
rakendada	doc_582053207523_item	2739344	et	3	main
klassidevaheline	doc_582053207523_item	2739346	et	4	main
lapsed	doc_582053207523_item	2739358	et	3	main
saavad	doc_582053207523_item	2739359	et	4	main
reaalselt	doc_582053207523_item	2739360	et	4	main
näha	doc_582053207523_item	2739361	et	3	main
mis	doc_582053207523_item	2739362	et	4	main
need	doc_582053207523_item	2739363	et	3	main
päevad	doc_582053207523_item	2739364	et	3	main
endast	doc_582053207523_item	2739365	et	4	main
kujutlevad	doc_582053207523_item	2739366	et	4	main
õpetajate	doc_582053207523_item	2739367	et	4	main
kommentaarid	doc_582053207523_item	2739368	et	3	main
juurde	doc_582053207523_item	2739369	et	4	main
lisandub	doc_582053207523_item	2739370	et	3	main
jaanipäev	doc_582053207523_item	2739371	et	3	main
päevaga	doc_582053207523_item	2739373	et	3	main
tähistatakse	doc_582053207523_item	2739377	et	3	main
ise	doc_582053207523_item	2739391	et	4	main
jõulukombeid	doc_582053207523_item	2739400	et	4	main
rahvussümboolikat	doc_582053207523_item	2739404	et	3	main
eesti	doc_582053207523_item	2739409	et	4	main
sümboolikat	doc_582053207523_item	2739410	et	3	main
oskab	doc_582053207523_item	2739411	et	3	main
rahvakalendri	doc_582053207523_item	2739414	et	3	main
mis	doc_582053207523_item	2739423	et	4	main
on	doc_582053207523_item	2739436	et	4	main
armastus	doc_582053207523_item	2739450	et	4	main
et	doc_582053207523_item	2739470	et	3	main
saada	doc_582053207523_item	2739473	et	4	main
lapsed	doc_582053207523_item	2739475	et	3	main
loevad	doc_582053207523_item	2739476	et	3	main
jutte	doc_582053207523_item	2739477	et	3	main
ja	doc_582053207523_item	2739478	et	3	main
arendatakse	doc_582053207523_item	2739487	et	3	main
klassidevahelised	doc_582053207523_item	2739503	et	4	main
peod	doc_582053207523_item	2739504	et	4	main
jne	doc_582053207523_item	2739509	et	4	main
võistlused	doc_582053207523_item	2739511	et	3	main
sa	doc_582053207523_item	2739515	et	3	main
tunned	doc_582053207523_item	2739521	et	3	main
kuidas	doc_582053207523_item	2739539	et	3	main
on	doc_582053207523_item	2739541	et	4	main
materjali	doc_582053207523_item	2739543	et	4	main
koolidevahelised	doc_582053207523_item	2739548	et	4	main
projektid	doc_582053207523_item	2739549	et	3	main
lõpetaja	doc_582053207523_item	2739554	et	4	main
lastekirjanikke	doc_582053207523_item	2739557	et	3	main
lugenud	doc_582053207523_item	2739562	et	4	main
keeleliselt	doc_582053207523_item	2739566	et	4	main
kommentaar	doc_582053207523_item	2739576	et	3	main
lastekirjanduse	doc_582053207523_item	2739617	et	3	main
peaks	doc_582053207523_item	2739619	et	4	main
olema	doc_582053207523_item	2739620	et	4	main
eesti	doc_582053207523_item	2739403	et	4	main
õpilane	doc_582053207523_item	2739407	et	3	main
rääkida	doc_582053207523_item	2739412	et	3	main
ja	doc_582053207523_item	2739417	et	3	main
seotud	doc_582053207523_item	2739425	et	4	main
sümboolikaga	doc_582053207523_item	2739427	et	3	main
tähtpäevadega	doc_582053207523_item	2739429	et	3	main
seda	doc_582053207523_item	2739430	et	3	main
teemat	doc_582053207523_item	2739431	et	3	main
toetavad	doc_582053207523_item	2739432	et	4	main
on	doc_582053207523_item	2739446	et	4	main
äratada	doc_582053207523_item	2739447	et	3	main
huvi	doc_582053207523_item	2739448	et	4	main
ja	doc_582053207523_item	2739449	et	3	main
keskel	doc_582053207523_item	2739455	et	3	main
kultuuritegelasiselleks	doc_582053207523_item	2739469	et	4	main
aru	doc_582053207523_item	2739472	et	4	main
kultuurist	doc_582053207523_item	2739474	et	3	main
luuletusi	doc_582053207523_item	2739479	et	4	main
eesti	doc_582053207523_item	2739480	et	4	main
ja	doc_582053207523_item	2739490	et	3	main
hümneesti	doc_582053207523_item	2739496	et	4	main
et	doc_582053207523_item	2739498	et	3	main
vastlad	doc_582053207523_item	2739508	et	3	main
viktoriinid	doc_582053207523_item	2739513	et	3	main
on	doc_582053207523_item	2739424	et	4	main
eesti	doc_582053207523_item	2739426	et	4	main
koduloo	doc_582053207523_item	2739433	et	4	main
tunnid	doc_582053207523_item	2739434	et	3	main
eesti	doc_582053207523_item	2739441	et	4	main
rahva	doc_582053207523_item	2739452	et	3	main
ja	doc_582053207523_item	2739457	et	3	main
maa	doc_582053207523_item	2739459	et	4	main
vastu	doc_582053207523_item	2739460	et	3	main
kus	doc_582053207523_item	2739461	et	3	main
elatakse	doc_582053207523_item	2739462	et	3	main
lapsed	doc_582053207523_item	2739463	et	3	main
õpivad	doc_582053207523_item	2739464	et	3	main
tundma	doc_582053207523_item	2739465	et	3	main
paikkonna	doc_582053207523_item	2739466	et	3	main
samas	doc_582053207523_item	2739486	et	4	main
nt	doc_582053207523_item	2739505	et	4	main
kadripäev	doc_582053207523_item	2739506	et	3	main
mardipäev	doc_582053207523_item	2739507	et	3	main
klassidevahelised	doc_582053207523_item	2739510	et	4	main
ja	doc_582053207523_item	2739512	et	3	main
kas	doc_582053207523_item	2739514	et	3	main
oskad	doc_582053207523_item	2739516	et	3	main
eesti	doc_582053207523_item	2739517	et	4	main
keelt	doc_582053207523_item	2739518	et	4	main
kas	doc_582053207523_item	2739519	et	3	main
sa	doc_582053207523_item	2739520	et	3	main
jne	doc_582053207523_item	2739523	et	4	main
peod	doc_582053207523_item	2739525	et	4	main
viktoriinid	doc_582053207523_item	2739526	et	3	main
ja	doc_582053207523_item	2739527	et	3	main
olümpiaadid	doc_582053207523_item	2739528	et	3	main
ülevaade	doc_582053207523_item	2739538	et	3	main
lapsed	doc_582053207523_item	2739540	et	3	main
uue	doc_582053207523_item	2739542	et	3	main
omandanud	doc_582053207523_item	2739544	et	4	main
samas	doc_582053207523_item	2739545	et	4	main
plaani	doc_582053207523_item	2739550	et	4	main
järgi	doc_582053207523_item	2739551	et	4	main
4	doc_582053207523_item	2739552	et	2	main
eesti	doc_582053207523_item	2739560	et	4	main
õpetaja	doc_582053207523_item	2739575	et	4	main
ning	doc_582053207523_item	2739605	et	3	main
muidugi	doc_582053207523_item	2739606	et	4	main
on	doc_582053207523_item	2739607	et	4	main
seda	doc_582053207523_item	2739608	et	3	main
et	doc_582053207523_item	2739611	et	3	main
vene	doc_582053207523_item	2739627	et	4	main
ei	doc_582053207523_item	2739630	et	4	main
ainult	doc_582053207523_item	2739632	et	4	main
õpilastes	doc_582053207523_item	2739650	et	4	main
tallinna	doc_582053207523_item	2739654	et	4	main
õismäe	doc_582053207523_item	2739655	et	3	main
on	doc_582053207523_item	2739669	et	4	main
äratada	doc_582053207523_item	2739670	et	3	main
lapsed	doc_582053207523_item	2739686	et	3	main
aru	doc_582053207523_item	2739695	et	4	main
eesti	doc_582053207523_item	2739703	et	4	main
mõistatustest	doc_582053207523_item	2739706	et	4	main
klassidevahelised	doc_582053207523_item	2739722	et	4	main
peod	doc_582053207523_item	2739723	et	4	main
oskad	doc_582053207523_item	2739734	et	3	main
keelt	doc_582053207523_item	2739736	et	4	main
sa	doc_582053207523_item	2739738	et	3	main
eestimaad	doc_582053207523_item	2739740	et	4	main
jneekskursioonidüldkoolilised	doc_582053207523_item	2739741	et	4	main
5	doc_582053207523_item	2739750	et	2	main
eesti	doc_582053207523_item	2739754	et	4	main
on	doc_582053207523_item	2739756	et	4	main
keeles	doc_582053207523_item	2739758	et	4	main
lugenud	doc_582053207523_item	2739759	et	4	main
2-3	doc_582053207523_item	2739760	et	2	main
eesti	doc_582053207523_item	2739766	et	4	main
riigi	doc_582053207523_item	2739767	et	3	main
sümboleid	doc_582053207523_item	2739768	et	3	main
siin	doc_582053207523_item	2739769	et	4	main
tv-	doc_582053207523_item	2739772	et	4	main
eestimaad	doc_582053207523_item	2739522	et	4	main
üldkoolilised	doc_582053207523_item	2739524	et	4	main
teadmisi	doc_582053207523_item	2739533	et	4	main
täiendada	doc_582053207523_item	2739534	et	3	main
ja	doc_582053207523_item	2739535	et	3	main
käivel	doc_582053207523_item	2739547	et	4	main
teab	doc_582053207523_item	2739555	et	3	main
ta	doc_582053207523_item	2739558	et	4	main
2-3	doc_582053207523_item	2739563	et	2	main
neljanda	doc_582053207523_item	2739577	et	3	main
klassi	doc_582053207523_item	2739578	et	4	main
õpilased	doc_582053207523_item	2739579	et	3	main
tutvuvad	doc_582053207523_item	2739580	et	4	main
jõukohaste	doc_582053207523_item	2739581	et	4	main
lasteraamatutega	doc_582053207523_item	2739582	et	3	main
külastavad	doc_582053207523_item	2739583	et	4	main
nukuteatrit	doc_582053207523_item	2739584	et	3	main
ning	doc_582053207523_item	2739585	et	3	main
vaatavad	doc_582053207523_item	2739586	et	4	main
telesaateid	doc_582053207523_item	2739587	et	3	main
see	doc_582053207523_item	2739588	et	3	main
on	doc_582053207523_item	2739589	et	4	main
esimene	doc_582053207523_item	2739590	et	3	main
selline	doc_582053207523_item	2739591	et	4	main
tutvus	doc_582053207523_item	2739592	et	4	main
eesti	doc_582053207523_item	2739593	et	4	main
lastekirjanikega	doc_582053207523_item	2739594	et	3	main
kuid	doc_582053207523_item	2739595	et	4	main
kahjuks	doc_582053207523_item	2739596	et	4	main
saab	doc_582053207523_item	2739597	et	3	main
tundides	doc_582053207523_item	2739598	et	3	main
ainult	doc_582053207523_item	2739600	et	4	main
põgusa	doc_582053207523_item	2739601	et	3	main
anda	doc_582053207523_item	2739599	et	3	main
ülevaate	doc_582053207523_item	2739602	et	4	main
nendest	doc_582053207523_item	2739603	et	4	main
kirjanikest	doc_582053207523_item	2739604	et	3	main
vähe	doc_582053207523_item	2739609	et	3	main
õpilane	doc_582053207523_item	2739612	et	3	main
eesti	doc_582053207523_item	2739616	et	4	main
kohta	doc_582053207523_item	2739618	et	4	main
tund	doc_582053207523_item	2739622	et	3	main
lastekirjandusest	doc_582053207523_item	2739624	et	4	main
kooli	doc_582053207523_item	2739633	et	4	main
kes	doc_582053207523_item	2739642	et	4	main
loomingust	doc_582053207523_item	2739645	et	3	main
lähemalt	doc_582053207523_item	2739646	et	4	main
oskavad	doc_582053207523_item	2739648	et	4	main
tekitada	doc_582053207523_item	2739649	et	3	main
külastanud	doc_582053207523_item	2739659	et	4	main
leelo	doc_582053207523_item	2739660	et	4	main
vastu	doc_582053207523_item	2739676	et	3	main
kelle	doc_582053207523_item	2739677	et	4	main
keskel	doc_582053207523_item	2739678	et	3	main
elatakse	doc_582053207523_item	2739679	et	3	main
ja	doc_582053207523_item	2739680	et	3	main
õpivad	doc_582053207523_item	2739687	et	3	main
vaatamisväärsusi	doc_582053207523_item	2739690	et	4	main
kultuuritegelasiselleks	doc_582053207523_item	2739692	et	4	main
et	doc_582053207523_item	2739693	et	3	main
rohkem	doc_582053207523_item	2739694	et	4	main
jutte	doc_582053207523_item	2739700	et	3	main
luuletusi	doc_582053207523_item	2739702	et	4	main
lastekirjandusestnäiteid	doc_582053207523_item	2739704	et	4	main
rahvussümbolitest	doc_582053207523_item	2739715	et	4	main
presidentsamas	doc_582053207523_item	2739720	et	4	main
sa	doc_582053207523_item	2739733	et	3	main
kas	doc_582053207523_item	2739737	et	3	main
peod	doc_582053207523_item	2739742	et	4	main
viktoriinid	doc_582053207523_item	2739743	et	3	main
ja	doc_582053207523_item	2739744	et	3	main
olümpiaadid	doc_582053207523_item	2739745	et	3	main
lõpetaja	doc_582053207523_item	2739752	et	4	main
eakohast	doc_582053207523_item	2739761	et	4	main
keeleliselt	doc_582053207523_item	2739763	et	4	main
on	doc_582053207523_item	2739771	et	4	main
ja	doc_582053207523_item	2739773	et	3	main
videofilmid	doc_582053207523_item	2739776	et	3	main
lastekirjanikke	doc_582053207523_item	2739797	et	3	main
pealiskaudne	doc_582053207523_item	2739807	et	3	main
ja	doc_582053207523_item	2739808	et	3	main
ning	doc_582053207523_item	2739822	et	3	main
mahu	doc_582053207523_item	2739631	et	4	main
on	doc_582053207523_item	2739636	et	4	main
võimalik	doc_582053207523_item	2739637	et	3	main
kutsuda	doc_582053207523_item	2739638	et	3	main
kooli	doc_582053207523_item	2739639	et	4	main
eesti	doc_582053207523_item	2739640	et	4	main
lastekirjanike	doc_582053207523_item	2739641	et	3	main
oma	doc_582053207523_item	2739644	et	4	main
ja	doc_582053207523_item	2739647	et	3	main
raamatute	doc_582053207523_item	2739652	et	3	main
vene	doc_582053207523_item	2739656	et	4	main
lütseumi	doc_582053207523_item	2739657	et	4	main
on	doc_582053207523_item	2739658	et	4	main
tungal	doc_582053207523_item	2739661	et	4	main
jaan	doc_582053207523_item	2739662	et	3	main
rannap	doc_582053207523_item	2739663	et	4	main
henno	doc_582053207523_item	2739664	et	4	main
käo	doc_582053207523_item	2739665	et	3	main
jne	doc_582053207523_item	2739666	et	4	main
5klass	doc_582053207523_item	2739667	et	3	main
esmärgiks	doc_582053207523_item	2739668	et	4	main
ja	doc_582053207523_item	2739672	et	3	main
maa	doc_582053207523_item	2739682	et	4	main
vastu	doc_582053207523_item	2739683	et	3	main
kus	doc_582053207523_item	2739684	et	3	main
paikkonna	doc_582053207523_item	2739689	et	3	main
ja	doc_582053207523_item	2739691	et	3	main
lapsed	doc_582053207523_item	2739698	et	3	main
vanasõnadest	doc_582053207523_item	2739705	et	3	main
samas	doc_582053207523_item	2739708	et	4	main
arendatakse	doc_582053207523_item	2739709	et	3	main
teadmisi	doc_582053207523_item	2739710	et	4	main
hümneesti	doc_582053207523_item	2739719	et	4	main
toimuvad	doc_582053207523_item	2739721	et	4	main
kadripäev	doc_582053207523_item	2739724	et	3	main
mardipäev	doc_582053207523_item	2739725	et	3	main
vastlad	doc_582053207523_item	2739726	et	3	main
jne	doc_582053207523_item	2739727	et	4	main
eesti	doc_582053207523_item	2739735	et	4	main
tunned	doc_582053207523_item	2739739	et	3	main
klassi	doc_582053207523_item	2739751	et	4	main
abiks	doc_582053207523_item	2739770	et	3	main
raadiosaated	doc_582053207523_item	2739774	et	3	main
on	doc_582053207523_item	2739781	et	4	main
muidugi	doc_582053207523_item	2739793	et	4	main
raua	doc_582053207523_item	2739801	et	3	main
kuid	doc_582053207523_item	2739803	et	4	main
ka	doc_582053207523_item	2739830	et	3	main
tunnis	doc_582053207523_item	2739832	et	3	main
viiendas	doc_582053207523_item	2739846	et	3	main
eesti	doc_582053207523_item	2739849	et	4	main
kursus	doc_582053207523_item	2739851	et	3	main
traditsioonid	doc_582053207523_item	2739871	et	3	main
tulemusi	doc_582053207523_item	2739887	et	4	main
klass	doc_582053207523_item	2739889	et	3	main
6	doc_582053207523_item	2739893	et	2	main
klass	doc_582053207523_item	2739894	et	3	main
sel	doc_582053207523_item	2739895	et	3	main
kooliastmel	doc_582053207523_item	2739896	et	3	main
teadvustab	doc_582053207523_item	2739897	et	3	main
sellest	doc_582053207523_item	2739903	et	4	main
jutustama	doc_582053207523_item	2739906	et	3	main
õpilase	doc_582053207523_item	2739907	et	3	main
vaatamisväärsusi	doc_582053207523_item	2739915	et	4	main
ja	doc_582053207523_item	2739916	et	3	main
eestimaad	doc_582053207523_item	2739962	et	4	main
lugenud	doc_582053207523_item	2739971	et	4	main
4-5	doc_582053207523_item	2739972	et	2	main
meedia	doc_582053207523_item	2739989	et	4	main
ajakirjad	doc_582053207523_item	2739990	et	3	main
ja	doc_582053207523_item	2739991	et	3	main
ajalehed	doc_582053207523_item	2739992	et	3	main
sõnastikud	doc_582053207523_item	2739993	et	3	main
ja	doc_582053207523_item	2739994	et	3	main
teatmeteosed	doc_582053207523_item	2739995	et	3	main
on	doc_582053207523_item	2740020	et	4	main
eesti	doc_582053207523_item	2740023	et	4	main
peale	doc_582053207523_item	2740027	et	4	main
pole	doc_582053207523_item	2740028	et	3	main
mõtet	doc_582053207523_item	2740029	et	3	main
ei	doc_582053207523_item	2740044	et	4	main
teema	doc_582053207523_item	2740049	et	4	main
selles	doc_582053207523_item	2740071	et	4	main
õpetus	doc_582053207523_item	2740082	et	4	main
taotleb	doc_582053207523_item	2740083	et	3	main
et	doc_582053207523_item	2740084	et	3	main
õpilane	doc_582053207523_item	2740085	et	3	main
kultuuri	doc_582053207523_item	2740092	et	4	main
kultuurielust	doc_582053207523_item	2740104	et	3	main
kaudu	doc_582053207523_item	2740107	et	3	main
ja	doc_582053207523_item	2740111	et	3	main
keskendutakse	doc_582053207523_item	2740113	et	3	main
eesti	doc_582053207523_item	2740114	et	4	main
eripärale	doc_582053207523_item	2740115	et	3	main
aktiivset	doc_582053207523_item	2740123	et	3	main
kultuurielust	doc_582053207523_item	2740126	et	3	main
paikkonna	doc_582053207523_item	2740138	et	3	main
tähtsamatest	doc_582053207523_item	2740142	et	4	main
on	doc_582053207523_item	2740163	et	4	main
minu	doc_582053207523_item	2740164	et	3	main
tähistamine	doc_582053207523_item	2740170	et	4	main
ja	doc_582053207523_item	2740176	et	3	main
selle	doc_582053207523_item	2739681	et	4	main
tundma	doc_582053207523_item	2739688	et	3	main
loevad	doc_582053207523_item	2739699	et	3	main
ja	doc_582053207523_item	2739701	et	3	main
eesti	doc_582053207523_item	2739716	et	4	main
lipp	doc_582053207523_item	2739717	et	3	main
vapp	doc_582053207523_item	2739718	et	3	main
klassidevahelised	doc_582053207523_item	2739728	et	4	main
kas	doc_582053207523_item	2739732	et	3	main
õpetaja	doc_582053207523_item	2739777	et	4	main
klassis	doc_582053207523_item	2739780	et	3	main
tundi	doc_582053207523_item	2739783	et	4	main
keele	doc_582053207523_item	2739790	et	4	main
õpitakse	doc_582053207523_item	2739794	et	4	main
kõik	doc_582053207523_item	2739806	et	4	main
tutvutakse	doc_582053207523_item	2739829	et	3	main
ning	doc_582053207523_item	2739833	et	3	main
on	doc_582053207523_item	2739835	et	4	main
loetakse	doc_582053207523_item	2739838	et	3	main
selle	doc_582053207523_item	2739852	et	4	main
tunni	doc_582053207523_item	2739853	et	3	main
ning	doc_582053207523_item	2739862	et	3	main
on	doc_582053207523_item	2739876	et	4	main
5	doc_582053207523_item	2739877	et	2	main
saaksid	doc_582053207523_item	2739885	et	4	main
2	doc_582053207523_item	2739890	et	2	main
jagatud	doc_582053207523_item	2739892	et	4	main
oma	doc_582053207523_item	2739899	et	4	main
kodukoha	doc_582053207523_item	2739900	et	4	main
eesti	doc_582053207523_item	2739904	et	4	main
rohkem	doc_582053207523_item	2739920	et	4	main
luuletusi	doc_582053207523_item	2739927	et	4	main
kõnekäändudest	doc_582053207523_item	2739933	et	3	main
eesti	doc_582053207523_item	2739941	et	4	main
lipp	doc_582053207523_item	2739942	et	3	main
toimub	doc_582053207523_item	2739946	et	3	main
tähistamine	doc_582053207523_item	2739952	et	4	main
emakeelepäeva	doc_582053207523_item	2739953	et	4	main
klassi	doc_582053207523_item	2739964	et	4	main
teabeesti	doc_582053207523_item	2739966	et	4	main
lastekirjanikke	doc_582053207523_item	2739967	et	3	main
eakohast	doc_582053207523_item	2739973	et	4	main
ja	doc_582053207523_item	2739974	et	3	main
meetmed	doc_582053207523_item	2739982	et	3	main
arvutiprogrammid	doc_582053207523_item	2739984	et	3	main
jne	doc_582053207523_item	2739988	et	4	main
võistlused	doc_582053207523_item	2739729	et	3	main
ja	doc_582053207523_item	2739730	et	3	main
viktoriinid	doc_582053207523_item	2739731	et	3	main
koolidevahelised	doc_582053207523_item	2739746	et	4	main
projektid	doc_582053207523_item	2739747	et	3	main
plaani	doc_582053207523_item	2739748	et	4	main
järgi	doc_582053207523_item	2739749	et	4	main
teab	doc_582053207523_item	2739753	et	3	main
lastekirjanikke	doc_582053207523_item	2739755	et	3	main
eesti	doc_582053207523_item	2739757	et	4	main
ja	doc_582053207523_item	2739762	et	3	main
jõukohast	doc_582053207523_item	2739764	et	4	main
lasteraamatut	doc_582053207523_item	2739765	et	3	main
kommentaar	doc_582053207523_item	2739778	et	3	main
enamus	doc_582053207523_item	2739786	et	4	main
aur	doc_582053207523_item	2739787	et	3	main
läheb	doc_582053207523_item	2739788	et	3	main
eesti	doc_582053207523_item	2739789	et	4	main
tundma	doc_582053207523_item	2739795	et	3	main
näiteks	doc_582053207523_item	2739799	et	4	main
naksitrallid	doc_582053207523_item	2739802	et	3	main
see	doc_582053207523_item	2739804	et	3	main
on	doc_582053207523_item	2739805	et	4	main
süsteemitu	doc_582053207523_item	2739809	et	4	main
õnn	doc_582053207523_item	2739810	et	3	main
on	doc_582053207523_item	2739811	et	4	main
kui	doc_582053207523_item	2739812	et	3	main
eesti	doc_582053207523_item	2739813	et	4	main
keele	doc_582053207523_item	2739814	et	4	main
ja	doc_582053207523_item	2739815	et	3	main
vene	doc_582053207523_item	2739816	et	4	main
keele	doc_582053207523_item	2739817	et	4	main
õpetajad	doc_582053207523_item	2739818	et	4	main
suudavad	doc_582053207523_item	2739819	et	3	main
teha	doc_582053207523_item	2739820	et	3	main
tegelastega	doc_582053207523_item	2739828	et	3	main
kui	doc_582053207523_item	2739834	et	3	main
võimalus	doc_582053207523_item	2739836	et	3	main
siis	doc_582053207523_item	2739837	et	3	main
klassis	doc_582053207523_item	2739847	et	3	main
ajaloo	doc_582053207523_item	2739850	et	4	main
raames	doc_582053207523_item	2739854	et	4	main
paljud	doc_582053207523_item	2739870	et	3	main
klassi	doc_582053207523_item	2739878	et	4	main
ajalootunnid	doc_582053207523_item	2739879	et	3	main
eesti	doc_582053207523_item	2739880	et	4	main
paremaid	doc_582053207523_item	2739886	et	4	main
omapära	doc_582053207523_item	2739901	et	4	main
õpib	doc_582053207523_item	2739902	et	3	main
keeles	doc_582053207523_item	2739905	et	4	main
saada	doc_582053207523_item	2739922	et	4	main
ja	doc_582053207523_item	2739926	et	3	main
näiteid	doc_582053207523_item	2739930	et	3	main
mõistatustest	doc_582053207523_item	2739932	et	4	main
vapp	doc_582053207523_item	2739943	et	3	main
tähistamineülekoolilised	doc_582053207523_item	2739954	et	4	main
üritused	doc_582053207523_item	2739955	et	4	main
olümpiaadid	doc_582053207523_item	2739956	et	3	main
konkurssid	doc_582053207523_item	2739957	et	4	main
6	doc_582053207523_item	2739963	et	2	main
on	doc_582053207523_item	2739968	et	4	main
eesti	doc_582053207523_item	2739969	et	4	main
keeleliselt	doc_582053207523_item	2739975	et	4	main
jõukohast	doc_582053207523_item	2739976	et	4	main
nii	doc_582053207523_item	2740030	et	3	main
selle	doc_582053207523_item	2740048	et	4	main
on	doc_582053207523_item	2740070	et	4	main
koolis	doc_582053207523_item	2740072	et	4	main
klassis	doc_582053207523_item	2740074	et	3	main
ajakirjad	doc_582053207523_item	2739775	et	3	main
viiendas	doc_582053207523_item	2739779	et	3	main
4	doc_582053207523_item	2739782	et	2	main
eesti	doc_582053207523_item	2739784	et	4	main
keelt	doc_582053207523_item	2739785	et	4	main
grammatika	doc_582053207523_item	2739791	et	4	main
õppimisele	doc_582053207523_item	2739792	et	4	main
ka	doc_582053207523_item	2739796	et	3	main
loomingut	doc_582053207523_item	2739798	et	3	main
e	doc_582053207523_item	2739800	et	4	main
eesti	doc_582053207523_item	2739823	et	4	main
tutvutud	doc_582053207523_item	2739826	et	4	main
raamatute	doc_582053207523_item	2739827	et	3	main
emakeele	doc_582053207523_item	2739831	et	4	main
vene	doc_582053207523_item	2739839	et	4	main
keele	doc_582053207523_item	2739840	et	4	main
tunnis	doc_582053207523_item	2739841	et	3	main
ka	doc_582053207523_item	2739842	et	3	main
on	doc_582053207523_item	2739848	et	4	main
saavad	doc_582053207523_item	2739855	et	4	main
õpilased	doc_582053207523_item	2739856	et	3	main
tallinna	doc_582053207523_item	2739872	et	4	main
õismäe	doc_582053207523_item	2739873	et	3	main
vene	doc_582053207523_item	2739874	et	4	main
lütseumis	doc_582053207523_item	2739875	et	3	main
keeles	doc_582053207523_item	2739881	et	4	main
ja	doc_582053207523_item	2739882	et	3	main
et	doc_582053207523_item	2739883	et	3	main
on	doc_582053207523_item	2739888	et	4	main
rühmaks	doc_582053207523_item	2739891	et	4	main
õpilane	doc_582053207523_item	2739898	et	3	main
teadmised	doc_582053207523_item	2739908	et	4	main
eestist	doc_582053207523_item	2739909	et	3	main
laienevad	doc_582053207523_item	2739910	et	4	main
lapsed	doc_582053207523_item	2739911	et	3	main
õpivad	doc_582053207523_item	2739912	et	3	main
tundma	doc_582053207523_item	2739913	et	3	main
paikkonna	doc_582053207523_item	2739914	et	3	main
aru	doc_582053207523_item	2739921	et	4	main
lapsed	doc_582053207523_item	2739923	et	3	main
loevad	doc_582053207523_item	2739924	et	3	main
eesti	doc_582053207523_item	2739928	et	4	main
lastekirjandusest	doc_582053207523_item	2739929	et	4	main
vanasõnadest	doc_582053207523_item	2739931	et	3	main
samas	doc_582053207523_item	2739934	et	4	main
arendatakse	doc_582053207523_item	2739935	et	3	main
teadmisi	doc_582053207523_item	2739936	et	4	main
riigipühadest	doc_582053207523_item	2739937	et	3	main
ja	doc_582053207523_item	2739938	et	3	main
hümneesti	doc_582053207523_item	2739944	et	4	main
rahvakalendri	doc_582053207523_item	2739947	et	3	main
klassidevaheline	doc_582053207523_item	2739949	et	4	main
ülekooliline	doc_582053207523_item	2739951	et	4	main
klassidevaheline	doc_582053207523_item	2739958	et	4	main
viktoriin	doc_582053207523_item	2739959	et	3	main
kas	doc_582053207523_item	2739960	et	3	main
tunned	doc_582053207523_item	2739961	et	3	main
lõpetaja	doc_582053207523_item	2739965	et	4	main
kasutatavad	doc_582053207523_item	2739981	et	4	main
juhised	doc_582053207523_item	2739986	et	3	main
arvamusel	doc_582053207523_item	2740021	et	3	main
sümboolika	doc_582053207523_item	2740024	et	4	main
ja	doc_582053207523_item	2740025	et	3	main
rahvuskultuuri	doc_582053207523_item	2740026	et	4	main
raisata	doc_582053207523_item	2740033	et	4	main
neid	doc_582053207523_item	2740034	et	4	main
teagi	doc_582053207523_item	2740045	et	4	main
peaaegu	doc_582053207523_item	2740046	et	3	main
midagi	doc_582053207523_item	2740047	et	4	main
kohta	doc_582053207523_item	2740050	et	4	main
lütseumis	doc_582053207523_item	2740054	et	3	main
valikainena	doc_582053207523_item	2740069	et	3	main
eesti	doc_582053207523_item	2740080	et	4	main
keele	doc_582053207523_item	2740081	et	4	main
ja	doc_582053207523_item	2740089	et	3	main
rikastab	doc_582053207523_item	2740105	et	3	main
oma	doc_582053207523_item	2740108	et	4	main
teadmisi	doc_582053207523_item	2740109	et	4	main
mõtte-	doc_582053207523_item	2740110	et	3	main
kultuurilugu	doc_582053207523_item	2740118	et	4	main
koostööd	doc_582053207523_item	2739821	et	4	main
keele	doc_582053207523_item	2739824	et	4	main
tunnis	doc_582053207523_item	2739825	et	3	main
eesti	doc_582053207523_item	2739843	et	4	main
autorite	doc_582053207523_item	2739844	et	3	main
kirjandust	doc_582053207523_item	2739845	et	3	main
teada	doc_582053207523_item	2739857	et	3	main
kuidas	doc_582053207523_item	2739858	et	3	main
elasid	doc_582053207523_item	2739859	et	4	main
muistsed	doc_582053207523_item	2739860	et	3	main
eestlased	doc_582053207523_item	2739861	et	3	main
millega	doc_582053207523_item	2739863	et	3	main
nad	doc_582053207523_item	2739864	et	3	main
tegelesid	doc_582053207523_item	2739865	et	4	main
kust	doc_582053207523_item	2739866	et	4	main
on	doc_582053207523_item	2739867	et	4	main
alguse	doc_582053207523_item	2739868	et	3	main
saanud	doc_582053207523_item	2739869	et	4	main
õpilased	doc_582053207523_item	2739884	et	3	main
kultuuritegelasiselleks	doc_582053207523_item	2739917	et	4	main
et	doc_582053207523_item	2739918	et	3	main
kultuurist	doc_582053207523_item	2739919	et	3	main
jutte	doc_582053207523_item	2739925	et	3	main
tähtpäevadesteesti	doc_582053207523_item	2739939	et	4	main
rahvussümbolitest	doc_582053207523_item	2739940	et	4	main
presidentsamas	doc_582053207523_item	2739945	et	4	main
tähtpäevade	doc_582053207523_item	2739948	et	3	main
ja	doc_582053207523_item	2739950	et	3	main
keeles	doc_582053207523_item	2739970	et	4	main
lasteraamatut	doc_582053207523_item	2739977	et	3	main
eesti	doc_582053207523_item	2739978	et	4	main
riigi	doc_582053207523_item	2739979	et	3	main
sümboleid	doc_582053207523_item	2739980	et	3	main
on	doc_582053207523_item	2739983	et	4	main
töölehed	doc_582053207523_item	2739985	et	3	main
ristsõnad	doc_582053207523_item	2739987	et	3	main
õpetaja	doc_582053207523_item	2739996	et	4	main
kommentaar	doc_582053207523_item	2739997	et	3	main
õpilased	doc_582053207523_item	2739998	et	3	main
õpivad	doc_582053207523_item	2739999	et	3	main
tundma	doc_582053207523_item	2740000	et	3	main
vanasõnu	doc_582053207523_item	2740001	et	3	main
mõistatusi	doc_582053207523_item	2740002	et	4	main
kõnekäände	doc_582053207523_item	2740003	et	4	main
kuid	doc_582053207523_item	2740004	et	4	main
ikkagi	doc_582053207523_item	2740005	et	4	main
on	doc_582053207523_item	2740006	et	4	main
suurem	doc_582053207523_item	2740007	et	4	main
rõhk	doc_582053207523_item	2740008	et	3	main
pandud	doc_582053207523_item	2740009	et	4	main
grammatikale	doc_582053207523_item	2740010	et	3	main
ja	doc_582053207523_item	2740011	et	3	main
läbivatele	doc_582053207523_item	2740012	et	4	main
teemadele	doc_582053207523_item	2740013	et	3	main
tihti	doc_582053207523_item	2740014	et	3	main
nii	doc_582053207523_item	2740015	et	3	main
õpilased	doc_582053207523_item	2740016	et	3	main
kui	doc_582053207523_item	2740017	et	3	main
ka	doc_582053207523_item	2740018	et	3	main
õpetajad	doc_582053207523_item	2740019	et	4	main
et	doc_582053207523_item	2740022	et	3	main
palju	doc_582053207523_item	2740031	et	4	main
teemasid	doc_582053207523_item	2740035	et	3	main
õpitakse	doc_582053207523_item	2740036	et	4	main
kahjuks	doc_582053207523_item	2740037	et	4	main
nagu	doc_582053207523_item	2740038	et	3	main
mööda	doc_582053207523_item	2740039	et	4	main
minnes	doc_582053207523_item	2740040	et	3	main
ning	doc_582053207523_item	2740041	et	3	main
seetõttu	doc_582053207523_item	2740042	et	3	main
õpilased	doc_582053207523_item	2740043	et	3	main
õismäe	doc_582053207523_item	2740052	et	3	main
õpitakse	doc_582053207523_item	2740055	et	4	main
mõistma	doc_582053207523_item	2740088	et	3	main
ühiskondlikust	doc_582053207523_item	2740102	et	4	main
ja	doc_582053207523_item	2740103	et	3	main
tundemaailma	doc_582053207523_item	2740112	et	4	main
enam	doc_582053207523_item	2740120	et	4	main
aega	doc_582053207523_item	2740032	et	4	main
tallinna	doc_582053207523_item	2740051	et	4	main
vene	doc_582053207523_item	2740053	et	4	main
loodusõpetust	doc_582053207523_item	2740056	et	3	main
mis	doc_582053207523_item	2740057	et	4	main
on	doc_582053207523_item	2740058	et	4	main
seotud	doc_582053207523_item	2740059	et	4	main
eestiga	doc_582053207523_item	2740060	et	4	main
eesti	doc_582053207523_item	2740061	et	4	main
keeles	doc_582053207523_item	2740062	et	4	main
kuid	doc_582053207523_item	2740063	et	4	main
ka	doc_582053207523_item	2740064	et	3	main
sellest	doc_582053207523_item	2740065	et	4	main
on	doc_582053207523_item	2740066	et	4	main
vähe	doc_582053207523_item	2740067	et	3	main
ning	doc_582053207523_item	2740068	et	3	main
6	doc_582053207523_item	2740073	et	2	main
eesti	doc_582053207523_item	2740075	et	4	main
kirjandus	doc_582053207523_item	2740076	et	3	main
õpib	doc_582053207523_item	2740086	et	3	main
eesti	doc_582053207523_item	2740091	et	4	main
püsiväärtusi	doc_582053207523_item	2740093	et	3	main
olulisemaid	doc_582053207523_item	2740094	et	4	main
ajaloofakte	doc_582053207523_item	2740095	et	3	main
rahva	doc_582053207523_item	2740096	et	3	main
tavasid	doc_582053207523_item	2740097	et	3	main
ja	doc_582053207523_item	2740098	et	3	main
kombeid	doc_582053207523_item	2740099	et	4	main
huvitub	doc_582053207523_item	2740100	et	3	main
kaasaegsest	doc_582053207523_item	2740101	et	3	main
selle	doc_582053207523_item	2740106	et	4	main
loodus	doc_582053207523_item	2740116	et	4	main
kliima	doc_582053207523_item	2740117	et	4	main
korraldatakse	doc_582053207523_item	2740127	et	3	main
klassiväliseid	doc_582053207523_item	2740129	et	4	main
käiakse	doc_582053207523_item	2740131	et	3	main
teatrites	doc_582053207523_item	2740132	et	3	main
kontserditel	doc_582053207523_item	2740133	et	4	main
kultuurielust	doc_582053207523_item	2740139	et	3	main
noorsookirjandusest	doc_582053207523_item	2740151	et	4	main
klassidevaheline	doc_582053207523_item	2740160	et	4	main
viktoriin	doc_582053207523_item	2740161	et	3	main
lõpetaja	doc_582053207523_item	2740172	et	4	main
eesti	doc_582053207523_item	2740177	et	4	main
peale	doc_582053207523_item	2740181	et	4	main
on	doc_582053207523_item	2740185	et	4	main
videofilmid	doc_582053207523_item	2740190	et	3	main
7	doc_582053207523_item	2740193	et	2	main
eesti	doc_582053207523_item	2740198	et	4	main
kõik	doc_582053207523_item	2740222	et	4	main
ei	doc_582053207523_item	2740223	et	4	main
tea	doc_582053207523_item	2740224	et	4	main
nad	doc_582053207523_item	2740225	et	3	main
tunne	doc_582053207523_item	2740229	et	4	main
ei	doc_582053207523_item	2740232	et	4	main
muuseume	doc_582053207523_item	2740234	et	3	main
ei	doc_582053207523_item	2740245	et	4	main
neid	doc_582053207523_item	2740252	et	4	main
8	doc_582053207523_item	2740255	et	2	main
õpilane	doc_582053207523_item	2740264	et	3	main
ja	doc_582053207523_item	2740277	et	3	main
huvitub	doc_582053207523_item	2740280	et	3	main
kaasaegsest	doc_582053207523_item	2740281	et	3	main
ühiskondlikust	doc_582053207523_item	2740282	et	4	main
kultuurielust	doc_582053207523_item	2740284	et	3	main
selle	doc_582053207523_item	2740286	et	4	main
kaudu	doc_582053207523_item	2740287	et	3	main
oma	doc_582053207523_item	2740288	et	4	main
tähtsamatest	doc_582053207523_item	2740322	et	4	main
kultuuritegelastestõpilane	doc_582053207523_item	2740327	et	3	main
klassidevaheline	doc_582053207523_item	2740343	et	4	main
viktoriin	doc_582053207523_item	2740344	et	3	main
tähistamine	doc_582053207523_item	2740355	et	4	main
seal	doc_582053207523_item	2740399	et	4	main
rõhku	doc_582053207523_item	2740405	et	4	main
pane	doc_582053207523_item	2740407	et	4	main
9	doc_582053207523_item	2740408	et	2	main
klass	doc_582053207523_item	2740409	et	3	main
õpib	doc_582053207523_item	2740417	et	3	main
mõistma	doc_582053207523_item	2740419	et	3	main
7	doc_582053207523_item	2740077	et	2	main
klass	doc_582053207523_item	2740078	et	3	main
7klassi	doc_582053207523_item	2740079	et	4	main
tundma	doc_582053207523_item	2740087	et	3	main
hindama	doc_582053207523_item	2740090	et	3	main
pakutakse	doc_582053207523_item	2740121	et	3	main
eestikeelseid	doc_582053207523_item	2740128	et	3	main
üritusi	doc_582053207523_item	2740130	et	4	main
muuseumidesõpilane	doc_582053207523_item	2740134	et	4	main
saab	doc_582053207523_item	2740135	et	3	main
uued	doc_582053207523_item	2740136	et	3	main
ta	doc_582053207523_item	2740148	et	4	main
loeb	doc_582053207523_item	2740149	et	3	main
katkendeid	doc_582053207523_item	2740150	et	3	main
legendidesttoimub	doc_582053207523_item	2740159	et	4	main
pühendatud	doc_582053207523_item	2740166	et	4	main
vabariigi	doc_582053207523_item	2740167	et	3	main
aastapäevale	doc_582053207523_item	2740168	et	4	main
oskab	doc_582053207523_item	2740173	et	3	main
jutustada	doc_582053207523_item	2740174	et	3	main
eluolust	doc_582053207523_item	2740178	et	3	main
õpikuid	doc_582053207523_item	2740182	et	4	main
õppematerjalid	doc_582053207523_item	2740184	et	3	main
kommentaar	doc_582053207523_item	2740192	et	3	main
peaksid	doc_582053207523_item	2740196	et	4	main
hümni	doc_582053207523_item	2740199	et	4	main
absoluutselt	doc_582053207523_item	2740221	et	4	main
ei	doc_582053207523_item	2740228	et	4	main
kurb	doc_582053207523_item	2740237	et	3	main
on	doc_582053207523_item	2740238	et	4	main
keele	doc_582053207523_item	2740260	et	4	main
tundma	doc_582053207523_item	2740266	et	3	main
ja	doc_582053207523_item	2740268	et	3	main
eesti	doc_582053207523_item	2740270	et	4	main
kombeid	doc_582053207523_item	2740278	et	4	main
rikastab	doc_582053207523_item	2740285	et	3	main
senisest	doc_582053207523_item	2740119	et	3	main
õpilasele	doc_582053207523_item	2740122	et	3	main
osavõttu	doc_582053207523_item	2740124	et	4	main
teadmised	doc_582053207523_item	2740137	et	4	main
kultuuriloo	doc_582053207523_item	2740141	et	4	main
sündmustest	doc_582053207523_item	2740144	et	4	main
ta	doc_582053207523_item	2740152	et	4	main
rakendab	doc_582053207523_item	2740153	et	3	main
eesti	doc_582053207523_item	2740162	et	4	main
emakeelepäeva	doc_582053207523_item	2740169	et	4	main
paikonna	doc_582053207523_item	2740175	et	4	main
raadiosaated	doc_582053207523_item	2740188	et	3	main
eesti	doc_582053207523_item	2740125	et	4	main
eesti	doc_582053207523_item	2740140	et	4	main
objektidest	doc_582053207523_item	2740143	et	3	main
ja	doc_582053207523_item	2740145	et	3	main
olulisematest	doc_582053207523_item	2740146	et	4	main
kultuuritegelastest	doc_582053207523_item	2740147	et	4	main
oma	doc_582053207523_item	2740154	et	4	main
teadmisi	doc_582053207523_item	2740155	et	4	main
muinasjuttudest	doc_582053207523_item	2740156	et	3	main
muistenditest	doc_582053207523_item	2740157	et	3	main
naljanditest	doc_582053207523_item	2740158	et	3	main
kodu	doc_582053207523_item	2740165	et	4	main
7klassi	doc_582053207523_item	2740171	et	4	main
ning	doc_582053207523_item	2740179	et	3	main
tv-	doc_582053207523_item	2740186	et	4	main
ajakirjandus	doc_582053207523_item	2740189	et	3	main
tundma	doc_582053207523_item	2740200	et	3	main
eestlaste	doc_582053207523_item	2740201	et	4	main
tavasid	doc_582053207523_item	2740202	et	3	main
ning	doc_582053207523_item	2740203	et	3	main
kombeid	doc_582053207523_item	2740204	et	4	main
kuid	doc_582053207523_item	2740205	et	4	main
praktika	doc_582053207523_item	2740206	et	4	main
näitab	doc_582053207523_item	2740207	et	3	main
et	doc_582053207523_item	2740208	et	3	main
nad	doc_582053207523_item	2740209	et	3	main
hakkavad	doc_582053207523_item	2740210	et	4	main
unustama	doc_582053207523_item	2740211	et	3	main
isegi	doc_582053207523_item	2740212	et	4	main
seda	doc_582053207523_item	2740213	et	3	main
mida	doc_582053207523_item	2740214	et	4	main
algklassides	doc_582053207523_item	2740215	et	3	main
õppisid	doc_582053207523_item	2740216	et	4	main
ja	doc_582053207523_item	2740217	et	3	main
teadsid	doc_582053207523_item	2740218	et	4	main
raskusi	doc_582053207523_item	2740219	et	4	main
valmistab	doc_582053207523_item	2740220	et	3	main
nad	doc_582053207523_item	2740230	et	3	main
vene	doc_582053207523_item	2740240	et	4	main
koolide	doc_582053207523_item	2740241	et	3	main
õpetus	doc_582053207523_item	2740261	et	4	main
taotleb	doc_582053207523_item	2740262	et	3	main
et	doc_582053207523_item	2740263	et	3	main
rahva	doc_582053207523_item	2740275	et	3	main
teadmisi	doc_582053207523_item	2740289	et	4	main
sündmustest	doc_582053207523_item	2740324	et	4	main
loeb	doc_582053207523_item	2740328	et	3	main
muinasjuttud	doc_582053207523_item	2740330	et	4	main
legendid	doc_582053207523_item	2740333	et	3	main
paikonna	doc_582053207523_item	2740336	et	4	main
ja	doc_582053207523_item	2740337	et	3	main
eesti	doc_582053207523_item	2740338	et	4	main
eluolust	doc_582053207523_item	2740339	et	3	main
ning	doc_582053207523_item	2740340	et	3	main
kodu	doc_582053207523_item	2740348	et	4	main
emadepäeva	doc_582053207523_item	2740354	et	4	main
8	doc_582053207523_item	2740358	et	2	main
o	doc_582053207523_item	2740361	et	4	main
mõtlema	doc_582053207523_item	2740387	et	3	main
kuidas	doc_582053207523_item	2740389	et	3	main
ette	doc_582053207523_item	2740392	et	4	main
huviväärsustest	doc_582053207523_item	2740180	et	4	main
kasutavad	doc_582053207523_item	2740183	et	4	main
ja	doc_582053207523_item	2740187	et	3	main
õpetaja	doc_582053207523_item	2740191	et	4	main
klassi	doc_582053207523_item	2740194	et	4	main
õpilased	doc_582053207523_item	2740195	et	3	main
teadma	doc_582053207523_item	2740197	et	3	main
eesti	doc_582053207523_item	2740226	et	4	main
kultuuritegelasi	doc_582053207523_item	2740227	et	3	main
külasta	doc_582053207523_item	2740233	et	4	main
näitusi	doc_582053207523_item	2740236	et	3	main
vene	doc_582053207523_item	2740246	et	4	main
ega	doc_582053207523_item	2740247	et	3	main
ka	doc_582053207523_item	2740248	et	3	main
eesti	doc_582053207523_item	2740249	et	4	main
kultuuri	doc_582053207523_item	2740250	et	4	main
peavad	doc_582053207523_item	2740251	et	4	main
üleliigseteks	doc_582053207523_item	2740254	et	4	main
klass	doc_582053207523_item	2740256	et	3	main
klassi	doc_582053207523_item	2740258	et	4	main
eesti	doc_582053207523_item	2740259	et	4	main
mõistma	doc_582053207523_item	2740267	et	3	main
ja	doc_582053207523_item	2740283	et	3	main
ja	doc_582053207523_item	2740325	et	3	main
olulisematest	doc_582053207523_item	2740326	et	4	main
naljandid	doc_582053207523_item	2740332	et	3	main
oskab	doc_582053207523_item	2740334	et	3	main
eesti	doc_582053207523_item	2740345	et	4	main
on	doc_582053207523_item	2740346	et	4	main
minu	doc_582053207523_item	2740347	et	3	main
tähistamine	doc_582053207523_item	2740353	et	4	main
kommentaar	doc_582053207523_item	2740357	et	3	main
õpitakse	doc_582053207523_item	2740360	et	4	main
lutsu	doc_582053207523_item	2740362	et	4	main
ja	doc_582053207523_item	2740363	et	3	main
ah	doc_582053207523_item	2740364	et	3	main
õpetajad	doc_582053207523_item	2740386	et	4	main
valmistada	doc_582053207523_item	2740390	et	3	main
teadmisi	doc_582053207523_item	2740398	et	4	main
õpetajad	doc_582053207523_item	2740403	et	4	main
ei	doc_582053207523_item	2740406	et	4	main
9klassi	doc_582053207523_item	2740410	et	4	main
tundma	doc_582053207523_item	2740418	et	3	main
püsiväärtusi	doc_582053207523_item	2740424	et	3	main
eesti	doc_582053207523_item	2740443	et	4	main
kultuurielust	doc_582053207523_item	2740444	et	3	main
eestikeelseid	doc_582053207523_item	2740446	et	3	main
üritusi	doc_582053207523_item	2740448	et	4	main
käiakse	doc_582053207523_item	2740449	et	3	main
teatrites	doc_582053207523_item	2740450	et	3	main
kontserditel	doc_582053207523_item	2740451	et	4	main
eesti	doc_582053207523_item	2740458	et	4	main
kultuuriloo	doc_582053207523_item	2740459	et	4	main
ja	doc_582053207523_item	2740463	et	3	main
jutustada	doc_582053207523_item	2740467	et	3	main
noorsookirjandust	doc_582053207523_item	2740470	et	3	main
tuua	doc_582053207523_item	2740473	et	3	main
naljanditest	doc_582053207523_item	2740477	et	3	main
jutustada	doc_582053207523_item	2740480	et	3	main
klassidevaheline	doc_582053207523_item	2740488	et	4	main
viktoriin	doc_582053207523_item	2740489	et	3	main
vabariigi	doc_582053207523_item	2740495	et	3	main
eesti	doc_582053207523_item	2740507	et	4	main
eluolust	doc_582053207523_item	2740508	et	3	main
ning	doc_582053207523_item	2740509	et	3	main
huviväärsustest	doc_582053207523_item	2740510	et	4	main
kasutavad	doc_582053207523_item	2740511	et	4	main
ning	doc_582053207523_item	2740524	et	3	main
kultuuriga	doc_582053207523_item	2740531	et	4	main
enda	doc_582053207523_item	2740536	et	4	main
kanda	doc_582053207523_item	2740537	et	4	main
kas	doc_582053207523_item	2740538	et	3	main
saladus	doc_582053207523_item	2740547	et	3	main
õpetajal	doc_582053207523_item	2740551	et	4	main
tunde	doc_582053207523_item	2740552	et	4	main
puudu	doc_582053207523_item	2740553	et	4	main
ning	doc_582053207523_item	2740554	et	3	main
kogu	doc_582053207523_item	2740555	et	4	main
igapäeva	doc_582053207523_item	2740561	et	4	main
ja	doc_582053207523_item	2740595	et	3	main
teatreid	doc_582053207523_item	2740231	et	3	main
ega	doc_582053207523_item	2740235	et	3	main
et	doc_582053207523_item	2740239	et	3	main
õpilased	doc_582053207523_item	2740242	et	3	main
ei	doc_582053207523_item	2740243	et	4	main
tunne	doc_582053207523_item	2740244	et	4	main
teadmisi	doc_582053207523_item	2740253	et	4	main
8	doc_582053207523_item	2740257	et	2	main
õpib	doc_582053207523_item	2740265	et	3	main
hindama	doc_582053207523_item	2740269	et	3	main
kultuuri	doc_582053207523_item	2740271	et	4	main
püsiväärtusi	doc_582053207523_item	2740272	et	3	main
olulisemaid	doc_582053207523_item	2740273	et	4	main
ajaloofakte	doc_582053207523_item	2740274	et	3	main
tavasid	doc_582053207523_item	2740276	et	3	main
ta	doc_582053207523_item	2740279	et	4	main
mõtte-	doc_582053207523_item	2740290	et	3	main
ja	doc_582053207523_item	2740291	et	3	main
tundemaailma	doc_582053207523_item	2740292	et	4	main
keskendutakse	doc_582053207523_item	2740293	et	3	main
eesti	doc_582053207523_item	2740294	et	4	main
eripärale	doc_582053207523_item	2740295	et	3	main
loodus	doc_582053207523_item	2740296	et	4	main
kliima	doc_582053207523_item	2740297	et	4	main
kultuurilugu	doc_582053207523_item	2740298	et	4	main
senisest	doc_582053207523_item	2740299	et	3	main
enam	doc_582053207523_item	2740300	et	4	main
pakutakse	doc_582053207523_item	2740301	et	3	main
õpilasele	doc_582053207523_item	2740302	et	3	main
aktiivset	doc_582053207523_item	2740303	et	3	main
osavõttu	doc_582053207523_item	2740304	et	4	main
eesti	doc_582053207523_item	2740305	et	4	main
kultuurielust	doc_582053207523_item	2740306	et	3	main
korraldatakse	doc_582053207523_item	2740307	et	3	main
eestikeelseid	doc_582053207523_item	2740308	et	3	main
klassiväliseid	doc_582053207523_item	2740309	et	4	main
üritusi	doc_582053207523_item	2740310	et	4	main
käiakse	doc_582053207523_item	2740311	et	3	main
teatrites	doc_582053207523_item	2740312	et	3	main
kontserditel	doc_582053207523_item	2740313	et	4	main
muuseumides	doc_582053207523_item	2740314	et	3	main
jmõpilane	doc_582053207523_item	2740315	et	4	main
laiendab	doc_582053207523_item	2740316	et	3	main
teadmisi	doc_582053207523_item	2740317	et	4	main
paikkonna	doc_582053207523_item	2740318	et	3	main
kultuurielust	doc_582053207523_item	2740319	et	3	main
eesti	doc_582053207523_item	2740320	et	4	main
kultuuriloo	doc_582053207523_item	2740321	et	4	main
objektidest	doc_582053207523_item	2740323	et	3	main
noorsookirjandust	doc_582053207523_item	2740329	et	3	main
muistendid	doc_582053207523_item	2740331	et	3	main
jutustada	doc_582053207523_item	2740335	et	3	main
emakeelepäeva	doc_582053207523_item	2740352	et	4	main
õpetaja	doc_582053207523_item	2740356	et	4	main
tammsaare	doc_582053207523_item	2740365	et	3	main
loomingut	doc_582053207523_item	2740366	et	3	main
kuid	doc_582053207523_item	2740367	et	4	main
nendest	doc_582053207523_item	2740368	et	4	main
tundidest	doc_582053207523_item	2740369	et	3	main
on	doc_582053207523_item	2740370	et	4	main
ikkagi	doc_582053207523_item	2740371	et	4	main
vähe	doc_582053207523_item	2740372	et	3	main
sest	doc_582053207523_item	2740373	et	4	main
loetakse	doc_582053207523_item	2740374	et	3	main
ainult	doc_582053207523_item	2740375	et	4	main
katkendeid	doc_582053207523_item	2740376	et	3	main
ja	doc_582053207523_item	2740377	et	3	main
needki	doc_582053207523_item	2740378	et	3	main
ei	doc_582053207523_item	2740379	et	4	main
ole	doc_582053207523_item	2740380	et	4	main
kõik	doc_582053207523_item	2740381	et	4	main
originaaltekstid	doc_582053207523_item	2740382	et	3	main
8	doc_582053207523_item	2740383	et	2	main
huviväärsustest	doc_582053207523_item	2740341	et	4	main
toimub	doc_582053207523_item	2740342	et	3	main
pühendatud	doc_582053207523_item	2740349	et	4	main
vabariigi	doc_582053207523_item	2740350	et	3	main
aastapäevale	doc_582053207523_item	2740351	et	4	main
klassis	doc_582053207523_item	2740359	et	3	main
klassis	doc_582053207523_item	2740384	et	3	main
selle	doc_582053207523_item	2740396	et	4	main
kontrollita	doc_582053207523_item	2740401	et	4	main
ning	doc_582053207523_item	2740402	et	3	main
keele	doc_582053207523_item	2740412	et	4	main
eesti	doc_582053207523_item	2740422	et	4	main
rahva	doc_582053207523_item	2740427	et	3	main
ja	doc_582053207523_item	2740429	et	3	main
keskendutakse	doc_582053207523_item	2740431	et	3	main
kliima	doc_582053207523_item	2740435	et	4	main
muuseumides	doc_582053207523_item	2740452	et	3	main
jm	doc_582053207523_item	2740453	et	4	main
õpilane	doc_582053207523_item	2740454	et	3	main
tähtsamad	doc_582053207523_item	2740460	et	4	main
olulisemad	doc_582053207523_item	2740464	et	4	main
oskab	doc_582053207523_item	2740466	et	3	main
paikkonna	doc_582053207523_item	2740468	et	3	main
esile	doc_582053207523_item	2740472	et	3	main
muinasjuttudest	doc_582053207523_item	2740475	et	3	main
legendidest	doc_582053207523_item	2740478	et	3	main
minu	doc_582053207523_item	2740492	et	3	main
tähistamine	doc_582053207523_item	2740498	et	4	main
9klassi	doc_582053207523_item	2740501	et	4	main
paikonna	doc_582053207523_item	2740505	et	4	main
ja	doc_582053207523_item	2740506	et	3	main
kõik	doc_582053207523_item	2740530	et	4	main
õpetaja	doc_582053207523_item	2740535	et	4	main
et	doc_582053207523_item	2740548	et	3	main
jääb	doc_582053207523_item	2740550	et	3	main
grammtikale	doc_582053207523_item	2740559	et	4	main
ja	doc_582053207523_item	2740560	et	3	main
sotsiaalsfääris	doc_582053207523_item	2740585	et	3	main
võimeline	doc_582053207523_item	2740588	et	4	main
sündmused	doc_582053207523_item	2740594	et	3	main
olulisemad	doc_582053207523_item	2740596	et	4	main
kultuuritegelasi	doc_582053207523_item	2740597	et	3	main
oskab	doc_582053207523_item	2740598	et	3	main
jutustada	doc_582053207523_item	2740599	et	3	main
paikkonna	doc_582053207523_item	2740600	et	3	main
kultuurielust	doc_582053207523_item	2740601	et	3	main
on	doc_582053207523_item	2740602	et	4	main
kultuuritegelasi	doc_582053207523_item	2740619	et	3	main
on	doc_582053207523_item	2740620	et	4	main
hakkavad	doc_582053207523_item	2740385	et	4	main
sellele	doc_582053207523_item	2740388	et	4	main
õpilasi	doc_582053207523_item	2740391	et	3	main
alaseid	doc_582053207523_item	2740397	et	4	main
eesti	doc_582053207523_item	2740411	et	4	main
hindama	doc_582053207523_item	2740421	et	3	main
kultuuri	doc_582053207523_item	2740423	et	4	main
eesti	doc_582053207523_item	2740432	et	4	main
eripärale	doc_582053207523_item	2740433	et	3	main
loodus	doc_582053207523_item	2740434	et	4	main
korraldatakse	doc_582053207523_item	2740445	et	3	main
klassiväliseid	doc_582053207523_item	2740447	et	4	main
ja	doc_582053207523_item	2740482	et	3	main
eluolust	doc_582053207523_item	2740484	et	3	main
toimuvad	doc_582053207523_item	2740487	et	4	main
kodu	doc_582053207523_item	2740493	et	4	main
pühendatud	doc_582053207523_item	2740494	et	4	main
emadepäeva	doc_582053207523_item	2740499	et	4	main
algtaseme	doc_582053207523_item	2740522	et	3	main
eksami	doc_582053207523_item	2740523	et	3	main
kultuuriga	doc_582053207523_item	2740526	et	4	main
seotud	doc_582053207523_item	2740532	et	4	main
küsimused	doc_582053207523_item	2740533	et	4	main
ja	doc_582053207523_item	2740539	et	3	main
seda	doc_582053207523_item	2740542	et	3	main
alati	doc_582053207523_item	2740549	et	4	main
jõud	doc_582053207523_item	2740556	et	4	main
eesti	doc_582053207523_item	2740582	et	4	main
on	doc_582053207523_item	2740587	et	4	main
eesti	doc_582053207523_item	2740590	et	4	main
kultuuriloo	doc_582053207523_item	2740591	et	4	main
tähtsamad	doc_582053207523_item	2740592	et	4	main
objektid	doc_582053207523_item	2740593	et	3	main
eesti	doc_582053207523_item	2740604	et	4	main
luulet	doc_582053207523_item	2740605	et	3	main
11	doc_582053207523_item	2740609	et	2	main
õpilane	doc_582053207523_item	2740611	et	3	main
ühiskonnale	doc_582053207523_item	2740629	et	4	main
kultuuriloo	doc_582053207523_item	2740635	et	4	main
11	doc_582053207523_item	2740639	et	2	main
gümnaasiumi	doc_582053207523_item	2740644	et	4	main
eesti	doc_582053207523_item	2740645	et	4	main
kirjanduse	doc_582053207523_item	2740660	et	3	main
rikkusena	doc_582053207523_item	2740671	et	3	main
keele	doc_582053207523_item	2740675	et	4	main
lugejakultuuri	doc_582053207523_item	2740702	et	4	main
eesti	doc_582053207523_item	2740708	et	4	main
arenemise	doc_582053207523_item	2740714	et	4	main
2	doc_582053207523_item	2740716	et	2	main
õppetegevus	doc_582053207523_item	2740717	et	4	main
sel	doc_582053207523_item	2740718	et	3	main
kooliastmel	doc_582053207523_item	2740719	et	3	main
süveneb	doc_582053207523_item	2740720	et	3	main
põhikooli	doc_582053207523_item	2740393	et	4	main
eksamiks	doc_582053207523_item	2740394	et	3	main
kahjuks	doc_582053207523_item	2740395	et	4	main
ei	doc_582053207523_item	2740400	et	4	main
sellele	doc_582053207523_item	2740404	et	4	main
õpetus	doc_582053207523_item	2740413	et	4	main
taotleb	doc_582053207523_item	2740414	et	3	main
et	doc_582053207523_item	2740415	et	3	main
õpilane	doc_582053207523_item	2740416	et	3	main
ja	doc_582053207523_item	2740420	et	3	main
ajaloofakte	doc_582053207523_item	2740426	et	3	main
kultuurilugu	doc_582053207523_item	2740436	et	4	main
senisest	doc_582053207523_item	2740437	et	3	main
aktiivset	doc_582053207523_item	2740441	et	3	main
võimeline	doc_582053207523_item	2740456	et	4	main
nimetada	doc_582053207523_item	2740457	et	3	main
sündmused	doc_582053207523_item	2740462	et	3	main
paikonna	doc_582053207523_item	2740481	et	4	main
aastapäevale	doc_582053207523_item	2740496	et	4	main
sooritab	doc_582053207523_item	2740521	et	3	main
seal	doc_582053207523_item	2740525	et	4	main
seotud	doc_582053207523_item	2740527	et	4	main
küsimusi	doc_582053207523_item	2740528	et	4	main
pole	doc_582053207523_item	2740529	et	3	main
jäävad	doc_582053207523_item	2740534	et	4	main
kui	doc_582053207523_item	2740540	et	3	main
õpilastele	doc_582053207523_item	2740543	et	4	main
anda	doc_582053207523_item	2740544	et	3	main
kuid	doc_582053207523_item	2740545	et	4	main
pole	doc_582053207523_item	2740546	et	3	main
pannakse	doc_582053207523_item	2740557	et	3	main
ikkagi	doc_582053207523_item	2740558	et	4	main
ja	doc_582053207523_item	2740584	et	3	main
3-4	doc_582053207523_item	2740607	et	2	main
eesti	doc_582053207523_item	2740613	et	4	main
iseloomulikke	doc_582053207523_item	2740630	et	3	main
käitumis-	doc_582053207523_item	2740631	et	4	main
ja	doc_582053207523_item	2740632	et	3	main
suhtlemisnorme	doc_582053207523_item	2740633	et	3	main
kultuuriloo	doc_582053207523_item	2740646	et	4	main
ja	doc_582053207523_item	2740647	et	3	main
kirjanduse	doc_582053207523_item	2740648	et	3	main
õpetus	doc_582053207523_item	2740649	et	4	main
lugupidavalt	doc_582053207523_item	2740658	et	4	main
tunnustades	doc_582053207523_item	2740659	et	3	main
suhtluse	doc_582053207523_item	2740672	et	3	main
ja	doc_582053207523_item	2740676	et	3	main
kirjanduse	doc_582053207523_item	2740677	et	3	main
õpetuse	doc_582053207523_item	2740679	et	4	main
kaudu	doc_582053207523_item	2740680	et	3	main
oma	doc_582053207523_item	2740681	et	4	main
vaimsete	doc_582053207523_item	2740695	et	4	main
ja	doc_582053207523_item	2740710	et	3	main
ning	doc_582053207523_item	2740712	et	3	main
ja	doc_582053207523_item	2740722	et	3	main
andmetega	doc_582053207523_item	2740732	et	3	main
eelistatakse	doc_582053207523_item	2740744	et	3	main
meetodeid	doc_582053207523_item	2740746	et	3	main
mis	doc_582053207523_item	2740748	et	4	main
vastu	doc_582053207523_item	2740756	et	3	main
õppesisu	doc_582053207523_item	2740758	et	4	main
ja	doc_582053207523_item	2740764	et	3	main
kunsti	doc_582053207523_item	2740765	et	4	main
kutselise	doc_582053207523_item	2740767	et	4	main
teatri	doc_582053207523_item	2740768	et	3	main
ja	doc_582053207523_item	2740769	et	3	main
laulupidude	doc_582053207523_item	2740770	et	4	main
kreutzwald	doc_582053207523_item	2740776	et	4	main
anna	doc_582053207523_item	2740781	et	4	main
2	doc_582053207523_item	2740783	et	2	main
sajandi	doc_582053207523_item	2740785	et	3	main
kultuurielu	doc_582053207523_item	2740788	et	4	main
ajakirjandusest	doc_582053207523_item	2740791	et	4	main
kunstist	doc_582053207523_item	2740792	et	4	main
sajandi	doc_582053207523_item	2740806	et	3	main
proosa	doc_582053207523_item	2740810	et	4	main
tutvustus	doc_582053207523_item	2740821	et	4	main
kultuurisaate	doc_582053207523_item	2740823	et	3	main
arutelu	doc_582053207523_item	2740825	et	4	main
juhan	doc_582053207523_item	2740835	et	3	main
eesti	doc_582053207523_item	2740838	et	4	main
olulisemaid	doc_582053207523_item	2740425	et	4	main
tavasid	doc_582053207523_item	2740428	et	3	main
kombeid	doc_582053207523_item	2740430	et	4	main
enam	doc_582053207523_item	2740438	et	4	main
pakutakse	doc_582053207523_item	2740439	et	3	main
õpilasele	doc_582053207523_item	2740440	et	3	main
osavõttu	doc_582053207523_item	2740442	et	4	main
on	doc_582053207523_item	2740455	et	4	main
objektid	doc_582053207523_item	2740461	et	3	main
kultuuritegelasi	doc_582053207523_item	2740465	et	3	main
kultuurielustloeb	doc_582053207523_item	2740469	et	4	main
saab	doc_582053207523_item	2740471	et	3	main
näiteid	doc_582053207523_item	2740474	et	3	main
muistenditest	doc_582053207523_item	2740476	et	3	main
oskab	doc_582053207523_item	2740479	et	3	main
eesti	doc_582053207523_item	2740483	et	4	main
ning	doc_582053207523_item	2740485	et	3	main
huviväärsustest	doc_582053207523_item	2740486	et	4	main
eesti	doc_582053207523_item	2740490	et	4	main
on	doc_582053207523_item	2740491	et	4	main
emakeelepäeva	doc_582053207523_item	2740497	et	4	main
tähistamine	doc_582053207523_item	2740500	et	4	main
lõpetaja	doc_582053207523_item	2740502	et	4	main
oskab	doc_582053207523_item	2740503	et	3	main
jutustada	doc_582053207523_item	2740504	et	3	main
õpetamismeetodid	doc_582053207523_item	2740512	et	4	main
ajalehed	doc_582053207523_item	2740513	et	3	main
ajakirjad	doc_582053207523_item	2740514	et	3	main
video-	doc_582053207523_item	2740515	et	4	main
ja	doc_582053207523_item	2740516	et	3	main
audeerimismaterjalid	doc_582053207523_item	2740517	et	4	main
õpetaja	doc_582053207523_item	2740518	et	4	main
kommentaar	doc_582053207523_item	2740519	et	3	main
põhikoolilõpetaja	doc_582053207523_item	2740520	et	4	main
palju	doc_582053207523_item	2740541	et	4	main
elu	doc_582053207523_item	2740562	et	4	main
puudutavatele	doc_582053207523_item	2740563	et	4	main
küsimustele	doc_582053207523_item	2740564	et	4	main
10	doc_582053207523_item	2740565	et	2	main
klass	doc_582053207523_item	2740566	et	3	main
gümnaasiumiastmel	doc_582053207523_item	2740567	et	3	main
on	doc_582053207523_item	2740568	et	4	main
kultuuriõppimisele	doc_582053207523_item	2740569	et	3	main
pööratud	doc_582053207523_item	2740570	et	4	main
väga	doc_582053207523_item	2740571	et	3	main
vähe	doc_582053207523_item	2740572	et	3	main
tähelepanu	doc_582053207523_item	2740573	et	4	main
10klassi	doc_582053207523_item	2740574	et	4	main
eesti	doc_582053207523_item	2740575	et	4	main
keele	doc_582053207523_item	2740576	et	4	main
õpetusega	doc_582053207523_item	2740577	et	4	main
taotletakse	doc_582053207523_item	2740578	et	3	main
et	doc_582053207523_item	2740579	et	3	main
õpilane	doc_582053207523_item	2740580	et	3	main
orienteerub	doc_582053207523_item	2740581	et	3	main
kultuuris	doc_582053207523_item	2740583	et	3	main
õpilane	doc_582053207523_item	2740586	et	3	main
nimetada	doc_582053207523_item	2740589	et	3	main
lugenud	doc_582053207523_item	2740603	et	4	main
proosateost	doc_582053207523_item	2740608	et	4	main
lugenud	doc_582053207523_item	2740621	et	4	main
ja	doc_582053207523_item	2740636	et	3	main
ainekava	doc_582053207523_item	2740638	et	4	main
35	doc_582053207523_item	2740641	et	2	main
1õppe-eesmärgid	doc_582053207523_item	2740643	et	3	main
et	doc_582053207523_item	2740651	et	3	main
kirjandusse	doc_582053207523_item	2740657	et	3	main
osa	doc_582053207523_item	2740661	et	4	main
selles	doc_582053207523_item	2740662	et	4	main
rahva	doc_582053207523_item	2740663	et	3	main
vaimse	doc_582053207523_item	2740664	et	3	main
täiustab	doc_582053207523_item	2740674	et	3	main
ajastu	doc_582053207523_item	2740690	et	4	main
vahekorrast	doc_582053207523_item	2740691	et	4	main
kirjanduse	doc_582053207523_item	2740692	et	3	main
ja	doc_582053207523_item	2740693	et	3	main
inimese	doc_582053207523_item	2740694	et	4	main
võimeid	doc_582053207523_item	2740704	et	3	main
loeb	doc_582053207523_item	2740705	et	3	main
õpib	doc_582053207523_item	2740706	et	3	main
keele	doc_582053207523_item	2740709	et	4	main
kultuuriruumi	doc_582053207523_item	2740723	et	4	main
õpetamine	doc_582053207523_item	2740726	et	4	main
piirdu	doc_582053207523_item	2740728	et	4	main
saavad	doc_582053207523_item	2740734	et	4	main
stilistikast	doc_582053207523_item	2740737	et	4	main
õppeprotsessis	doc_582053207523_item	2740743	et	3	main
rahvusliku	doc_582053207523_item	2740762	et	3	main
sünd	doc_582053207523_item	2740766	et	3	main
traditsiooni	doc_582053207523_item	2740771	et	4	main
lydia	doc_582053207523_item	2740777	et	4	main
bornhöhe	doc_582053207523_item	2740780	et	4	main
haava	doc_582053207523_item	2740782	et	4	main
poole	doc_582053207523_item	2740787	et	4	main
näiteid	doc_582053207523_item	2740790	et	3	main
eduard	doc_582053207523_item	2740796	et	4	main
vilde	doc_582053207523_item	2740797	et	4	main
20	doc_582053207523_item	2740805	et	2	main
hando	doc_582053207523_item	2740831	et	4	main
unt	doc_582053207523_item	2740834	et	4	main
keel	doc_582053207523_item	2740844	et	4	main
eesti	doc_582053207523_item	2740850	et	4	main
eesti	doc_582053207523_item	2740858	et	4	main
seosed	doc_582053207523_item	2740872	et	3	main
4	doc_582053207523_item	2740874	et	2	main
kirjanduslugu	doc_582053207523_item	2740882	et	4	main
koolibri	doc_582053207523_item	2740883	et	4	main
virgela	doc_582053207523_item	2740885	et	4	main
koolikirjandus	doc_582053207523_item	2740886	et	3	main
väike	doc_582053207523_item	2740887	et	4	main
lias	doc_582053207523_item	2740893	et	4	main
eesti	doc_582053207523_item	2740894	et	4	main
kirjandus	doc_582053207523_item	2740895	et	3	main
klassile	doc_582053207523_item	2740897	et	3	main
1996	doc_582053207523_item	2740899	et	2	main
a	doc_582053207523_item	2740900	et	4	main
õim	doc_582053207523_item	2740901	et	4	main
h	doc_582053207523_item	2740907	et	4	main
joonuks	doc_582053207523_item	2740908	et	4	main
kirjanduslikke	doc_582053207523_item	2740909	et	3	main
1999	doc_582053207523_item	2740913	et	2	main
riigieksamile	doc_582053207523_item	2740921	et	3	main
kultuuri	doc_582053207523_item	2740923	et	4	main
õppimiseks	doc_582053207523_item	2740924	et	4	main
eesti	doc_582053207523_item	2740934	et	4	main
sotsiaalsfääris	doc_582053207523_item	2740937	et	3	main
2-3	doc_582053207523_item	2740947	et	2	main
eesti	doc_582053207523_item	2740950	et	4	main
õpetaja	doc_582053207523_item	2740956	et	4	main
õpilane	doc_582053207523_item	2740962	et	3	main
valib	doc_582053207523_item	2740976	et	3	main
saab	doc_582053207523_item	2740981	et	3	main
ulatuses	doc_582053207523_item	2740986	et	4	main
peaks	doc_582053207523_item	2741036	et	4	main
üks	doc_582053207523_item	2741040	et	3	main
eesti	doc_582053207523_item	2741043	et	4	main
ja	doc_582053207523_item	2740606	et	3	main
klass	doc_582053207523_item	2740610	et	3	main
orienteerub	doc_582053207523_item	2740612	et	3	main
kultuuris	doc_582053207523_item	2740614	et	3	main
ja	doc_582053207523_item	2740615	et	3	main
sotsiallsfääris	doc_582053207523_item	2740616	et	4	main
teab	doc_582053207523_item	2740617	et	3	main
eesti	doc_582053207523_item	2740618	et	4	main
eesti	doc_582053207523_item	2740622	et	4	main
luulet	doc_582053207523_item	2740623	et	3	main
3-4	doc_582053207523_item	2740625	et	2	main
teab	doc_582053207523_item	2740627	et	3	main
eesti	doc_582053207523_item	2740628	et	4	main
kirjanduse	doc_582053207523_item	2740637	et	3	main
allika	doc_582053207523_item	2740666	et	3	main
ja	doc_582053207523_item	2740667	et	3	main
tähtsaima	doc_582053207523_item	2740668	et	4	main
osana	doc_582053207523_item	2740669	et	3	main
rahvusliku	doc_582053207523_item	2740670	et	3	main
erivormina	doc_582053207523_item	2740673	et	3	main
integreeritud	doc_582053207523_item	2740678	et	4	main
loomingulisi	doc_582053207523_item	2740703	et	4	main
tundma	doc_582053207523_item	2740707	et	3	main
kirjanduse	doc_582053207523_item	2740725	et	3	main
ei	doc_582053207523_item	2740727	et	4	main
biograafiliste	doc_582053207523_item	2740729	et	4	main
ja	doc_582053207523_item	2740730	et	3	main
teadmisi	doc_582053207523_item	2740735	et	4	main
ja	doc_582053207523_item	2740738	et	3	main
semiootikast	doc_582053207523_item	2740739	et	4	main
kirjandusteoreetilisi	doc_582053207523_item	2740741	et	3	main
teadmisi	doc_582053207523_item	2740742	et	4	main
kirjanduse	doc_582053207523_item	2740763	et	3	main
reinhold	doc_582053207523_item	2740775	et	4	main
eduard	doc_582053207523_item	2740779	et	4	main
20	doc_582053207523_item	2740784	et	2	main
teadusest	doc_582053207523_item	2740794	et	4	main
kirjanikud	doc_582053207523_item	2740795	et	3	main
tuglas	doc_582053207523_item	2740803	et	4	main
ii	doc_582053207523_item	2740807	et	4	main
teatrietenduse	doc_582053207523_item	2740824	et	3	main
jaan	doc_582053207523_item	2740827	et	3	main
kross	doc_582053207523_item	2740828	et	3	main
paul-eerik	doc_582053207523_item	2740829	et	4	main
rummo	doc_582053207523_item	2740830	et	4	main
eesti	doc_582053207523_item	2740843	et	4	main
erinevused	doc_582053207523_item	2740849	et	4	main
kasutatav	doc_582053207523_item	2740875	et	4	main
hennoste	doc_582053207523_item	2740879	et	4	main
eesti	doc_582053207523_item	2740881	et	4	main
eesti	doc_582053207523_item	2740888	et	4	main
kirjanike	doc_582053207523_item	2740889	et	3	main
leksikon	doc_582053207523_item	2740890	et	3	main
1998	doc_582053207523_item	2740891	et	2	main
fraseoloogia	doc_582053207523_item	2740902	et	4	main
sõnaraamat	doc_582053207523_item	2740903	et	3	main
eta	doc_582053207523_item	2740904	et	4	main
eestis	doc_582053207523_item	2740911	et	3	main
klass	doc_582053207523_item	2740915	et	3	main
jääb	doc_582053207523_item	2740925	et	3	main
aega	doc_582053207523_item	2740928	et	4	main
klassi	doc_582053207523_item	2740930	et	4	main
õpilane	doc_582053207523_item	2740931	et	3	main
ühiskonnale	doc_582053207523_item	2740951	et	4	main
suhtlemisnorme	doc_582053207523_item	2740955	et	3	main
klassi	doc_582053207523_item	2740959	et	4	main
35	doc_582053207523_item	2740964	et	2	main
asi	doc_582053207523_item	2740972	et	4	main
piirdubki	doc_582053207523_item	2740973	et	3	main
kirjanduse	doc_582053207523_item	2740979	et	3	main
kohta	doc_582053207523_item	2740990	et	4	main
ning	doc_582053207523_item	2740991	et	3	main
ajaloost	doc_582053207523_item	2741021	et	4	main
teata	doc_582053207523_item	2741023	et	4	main
ka	doc_582053207523_item	2741024	et	3	main
lõpetaja	doc_582053207523_item	2741030	et	4	main
rahvapärimust	doc_582053207523_item	2741035	et	4	main
ajalooga	doc_582053207523_item	2741050	et	4	main
kirjandusega	doc_582053207523_item	2741051	et	3	main
tea	doc_582053207523_item	2741067	et	4	main
ja	doc_582053207523_item	2740624	et	3	main
proosateost	doc_582053207523_item	2740626	et	4	main
eesti	doc_582053207523_item	2740634	et	4	main
klass	doc_582053207523_item	2740640	et	3	main
tundi	doc_582053207523_item	2740642	et	4	main
taotleb	doc_582053207523_item	2740650	et	3	main
õpilane	doc_582053207523_item	2740652	et	3	main
suhtub	doc_582053207523_item	2740653	et	3	main
eesti	doc_582053207523_item	2740654	et	4	main
kultuurilukku	doc_582053207523_item	2740655	et	4	main
ja	doc_582053207523_item	2740656	et	3	main
kultuuri	doc_582053207523_item	2740665	et	4	main
kommunikatiivseid	doc_582053207523_item	2740682	et	3	main
oskusi	doc_582053207523_item	2740683	et	3	main
omandab	doc_582053207523_item	2740684	et	3	main
küllaldase	doc_582053207523_item	2740685	et	3	main
arusaama	doc_582053207523_item	2740686	et	4	main
kultuuriprotsessidest	doc_582053207523_item	2740687	et	3	main
kirjanduse	doc_582053207523_item	2740688	et	3	main
ja	doc_582053207523_item	2740689	et	3	main
otsingute	doc_582053207523_item	2740696	et	3	main
seostest	doc_582053207523_item	2740697	et	3	main
arendab	doc_582053207523_item	2740698	et	3	main
oma	doc_582053207523_item	2740699	et	4	main
esteetilist	doc_582053207523_item	2740700	et	3	main
maitset	doc_582053207523_item	2740701	et	3	main
kirjanduse	doc_582053207523_item	2740711	et	3	main
kultuuri	doc_582053207523_item	2740713	et	4	main
protsesse	doc_582053207523_item	2740715	et	3	main
kirjanduse	doc_582053207523_item	2740721	et	3	main
ajaloolis-kultuuriliste	doc_582053207523_item	2740731	et	4	main
õpilased	doc_582053207523_item	2740733	et	3	main
ilukirjandusteksti	doc_582053207523_item	2740736	et	4	main
vorme	doc_582053207523_item	2740745	et	3	main
võtteid	doc_582053207523_item	2740747	et	3	main
3	doc_582053207523_item	2740757	et	2	main
1	doc_582053207523_item	2740759	et	2	main
ärkamisaegne	doc_582053207523_item	2740760	et	3	main
algus	doc_582053207523_item	2740772	et	4	main
kirjanikud	doc_582053207523_item	2740773	et	3	main
friedrich	doc_582053207523_item	2740774	et	4	main
i	doc_582053207523_item	2740786	et	4	main
kirjandus	doc_582053207523_item	2740789	et	3	main
3	doc_582053207523_item	2740804	et	2	main
luule	doc_582053207523_item	2740812	et	4	main
eesti	doc_582053207523_item	2740813	et	4	main
kirjandus	doc_582053207523_item	2740814	et	3	main
filmilinal	doc_582053207523_item	2740815	et	3	main
2-3	doc_582053207523_item	2740816	et	2	main
muusikategelase	doc_582053207523_item	2740817	et	3	main
ja	doc_582053207523_item	2740818	et	3	main
kunstniku	doc_582053207523_item	2740819	et	3	main
loomingu	doc_582053207523_item	2740820	et	3	main
tunnetamine	doc_582053207523_item	2740724	et	4	main
üldistatakse	doc_582053207523_item	2740740	et	3	main
soodustavad	doc_582053207523_item	2740749	et	4	main
initsiatiivi	doc_582053207523_item	2740750	et	4	main
arengut	doc_582053207523_item	2740751	et	3	main
huvi	doc_582053207523_item	2740752	et	4	main
kunsti	doc_582053207523_item	2740753	et	4	main
ja	doc_582053207523_item	2740754	et	3	main
raamatu	doc_582053207523_item	2740755	et	4	main
kultuurielu	doc_582053207523_item	2740761	et	4	main
koidula	doc_582053207523_item	2740778	et	4	main
muusikast	doc_582053207523_item	2740793	et	4	main
juhan	doc_582053207523_item	2740798	et	3	main
liiv	doc_582053207523_item	2740799	et	3	main
gustav	doc_582053207523_item	2740800	et	4	main
suits	doc_582053207523_item	2740801	et	3	main
friedebert	doc_582053207523_item	2740802	et	4	main
poole	doc_582053207523_item	2740808	et	4	main
kultuurielu	doc_582053207523_item	2740809	et	4	main
ja	doc_582053207523_item	2740811	et	3	main
eestikeelse	doc_582053207523_item	2740822	et	3	main
kirjanikud	doc_582053207523_item	2740826	et	3	main
mati	doc_582053207523_item	2740833	et	4	main
4	doc_582053207523_item	2740837	et	2	main
keel	doc_582053207523_item	2740839	et	4	main
ja	doc_582053207523_item	2740840	et	3	main
teised	doc_582053207523_item	2740841	et	4	main
keeled	doc_582053207523_item	2740842	et	3	main
keel	doc_582053207523_item	2740847	et	4	main
struktuurilised	doc_582053207523_item	2740848	et	4	main
vene	doc_582053207523_item	2740852	et	4	main
kirjanikud	doc_582053207523_item	2740854	et	3	main
vahelised	doc_582053207523_item	2740871	et	4	main
õppevahendid	doc_582053207523_item	2740877	et	3	main
m	doc_582053207523_item	2740878	et	4	main
väike	doc_582053207523_item	2740880	et	4	main
1997	doc_582053207523_item	2740884	et	2	main
12	doc_582053207523_item	2740914	et	2	main
tähelepanu	doc_582053207523_item	2740918	et	4	main
seega	doc_582053207523_item	2740922	et	4	main
12	doc_582053207523_item	2740929	et	2	main
oskab	doc_582053207523_item	2740932	et	3	main
eesti	doc_582053207523_item	2740944	et	4	main
luulet	doc_582053207523_item	2740945	et	3	main
ja	doc_582053207523_item	2740946	et	3	main
proosateost	doc_582053207523_item	2740948	et	4	main
iseloomulikke	doc_582053207523_item	2740952	et	3	main
ja	doc_582053207523_item	2740954	et	3	main
kommentaar	doc_582053207523_item	2740957	et	3	main
õppekavast	doc_582053207523_item	2740960	et	4	main
õpilane	doc_582053207523_item	2740975	et	3	main
valikainena	doc_582053207523_item	2740977	et	3	main
ta	doc_582053207523_item	2740982	et	4	main
35	doc_582053207523_item	2740984	et	2	main
teadmisi	doc_582053207523_item	2740987	et	4	main
eesti	doc_582053207523_item	2740988	et	4	main
kirjanduse	doc_582053207523_item	2740989	et	3	main
runnel	doc_582053207523_item	2740832	et	4	main
viiding	doc_582053207523_item	2740836	et	4	main
kui	doc_582053207523_item	2740845	et	3	main
soomeugri	doc_582053207523_item	2740846	et	4	main
ja	doc_582053207523_item	2740851	et	3	main
andrus	doc_582053207523_item	2740855	et	3	main
5	doc_582053207523_item	2740857	et	2	main
kirjakeele	doc_582053207523_item	2740859	et	4	main
kujunemine	doc_582053207523_item	2740860	et	4	main
2-3	doc_582053207523_item	2740861	et	2	main
keeleteadlase	doc_582053207523_item	2740862	et	3	main
tegevuse	doc_582053207523_item	2740863	et	4	main
tutvustus	doc_582053207523_item	2740864	et	4	main
õigekeelsussõnaraamatu	doc_582053207523_item	2740865	et	4	main
koostamise	doc_582053207523_item	2740866	et	4	main
printsiibid	doc_582053207523_item	2740867	et	3	main
ja	doc_582053207523_item	2740868	et	3	main
kasutamine	doc_582053207523_item	2740869	et	4	main
keeles	doc_582053207523_item	2740853	et	4	main
kivirähk	doc_582053207523_item	2740856	et	3	main
õppekirjandus	doc_582053207523_item	2740876	et	3	main
p	doc_582053207523_item	2740892	et	4	main
koolibri	doc_582053207523_item	2740898	et	4	main
kki	doc_582053207523_item	2740905	et	4	main
1993	doc_582053207523_item	2740906	et	2	main
koolibri	doc_582053207523_item	2740912	et	4	main
kõige	doc_582053207523_item	2740916	et	4	main
on	doc_582053207523_item	2740919	et	4	main
kultuuride	doc_582053207523_item	2740870	et	3	main
tõlkekirjandus	doc_582053207523_item	2740873	et	3	main
12	doc_582053207523_item	2740896	et	2	main
paiku	doc_582053207523_item	2740910	et	4	main
rohkem	doc_582053207523_item	2740917	et	4	main
pööratud	doc_582053207523_item	2740920	et	4	main
vähe	doc_582053207523_item	2740927	et	3	main
kultuuris	doc_582053207523_item	2740935	et	3	main
ta	doc_582053207523_item	2740938	et	4	main
eesti	doc_582053207523_item	2740940	et	4	main
kultuuritegelasi	doc_582053207523_item	2740941	et	3	main
on	doc_582053207523_item	2740942	et	4	main
teab	doc_582053207523_item	2740949	et	3	main
käitumis-	doc_582053207523_item	2740953	et	4	main
gümnaasiumi	doc_582053207523_item	2740961	et	4	main
tunnise	doc_582053207523_item	2740965	et	4	main
eesti	doc_582053207523_item	2740967	et	4	main
kui	doc_582053207523_item	2740974	et	3	main
eesti	doc_582053207523_item	2740978	et	4	main
tunni	doc_582053207523_item	2740985	et	3	main
selleks	doc_582053207523_item	2741026	et	4	main
et	doc_582053207523_item	2741027	et	3	main
eesti	doc_582053207523_item	2741034	et	4	main
olema	doc_582053207523_item	2741039	et	4	main
tund	doc_582053207523_item	2741041	et	3	main
kiita	doc_582053207523_item	2741069	et	4	main
ja	doc_582053207523_item	2741074	et	3	main
nn	doc_582053207523_item	2741082	et	4	main
kiiksuga	doc_582053207523_item	2741083	et	4	main
tema	doc_582053207523_item	2741087	et	4	main
kultuurilugu	doc_582053207523_item	2741089	et	4	main
kui	doc_582053207523_item	2741091	et	3	main
pole	doc_582053207523_item	2741093	et	3	main
ei	doc_582053207523_item	2741095	et	4	main
rohkem	doc_582053207523_item	2741109	et	4	main
ruumi	doc_582053207523_item	2741110	et	4	main
ka	doc_582053207523_item	2741111	et	3	main
2õppimine	doc_582053207523_item	2741115	et	4	main
testidtest	doc_582053207523_item	2741123	et	4	main
anonüümne	doc_582053207523_item	2741125	et	3	main
mida	doc_582053207523_item	2741131	et	4	main
ning	doc_582053207523_item	2741134	et	3	main
ei	doc_582053207523_item	2741136	et	4	main
võiksid	doc_582053207523_item	2741140	et	4	main
vabalt	doc_582053207523_item	2741141	et	4	main
ole	doc_582053207523_item	2741149	et	4	main
hindeline	doc_582053207523_item	2741150	et	4	main
pingutada	doc_582053207523_item	2741156	et	3	main
ning	doc_582053207523_item	2741157	et	3	main
maha	doc_582053207523_item	2741158	et	4	main
kirjutada	doc_582053207523_item	2741159	et	3	main
2	doc_582053207523_item	2741168	et	2	main
esimene	doc_582053207523_item	2741170	et	3	main
oli	doc_582053207523_item	2741171	et	3	main
klassi	doc_582053207523_item	2741173	et	4	main
ja	doc_582053207523_item	2741175	et	3	main
18	doc_582053207523_item	2741177	et	2	main
väga	doc_582053207523_item	2740926	et	3	main
orienteeruda	doc_582053207523_item	2740933	et	3	main
ja	doc_582053207523_item	2740936	et	3	main
teab	doc_582053207523_item	2740939	et	3	main
lugenud	doc_582053207523_item	2740943	et	4	main
1012	doc_582053207523_item	2740958	et	2	main
läbib	doc_582053207523_item	2740963	et	3	main
kursuse	doc_582053207523_item	2740966	et	3	main
rahvuskultuuri	doc_582053207523_item	2740968	et	4	main
kohta	doc_582053207523_item	2740969	et	4	main
ja	doc_582053207523_item	2740970	et	3	main
sellega	doc_582053207523_item	2740971	et	3	main
siis	doc_582053207523_item	2740980	et	3	main
veel	doc_582053207523_item	2740983	et	4	main
ongi	doc_582053207523_item	2740992	et	4	main
kõik	doc_582053207523_item	2740993	et	4	main
kahjuks	doc_582053207523_item	2740994	et	4	main
ei	doc_582053207523_item	2740995	et	4	main
suuda	doc_582053207523_item	2740996	et	4	main
gümnaasiumi	doc_582053207523_item	2740997	et	4	main
õpilane	doc_582053207523_item	2740998	et	3	main
nimetada	doc_582053207523_item	2740999	et	3	main
eesti	doc_582053207523_item	2741000	et	4	main
kultuuritegelasi	doc_582053207523_item	2741001	et	3	main
rahatähtedel	doc_582053207523_item	2741002	et	4	main
samuti	doc_582053207523_item	2741003	et	3	main
on	doc_582053207523_item	2741004	et	4	main
ununenud	doc_582053207523_item	2741005	et	4	main
eesti	doc_582053207523_item	2741006	et	4	main
hümn	doc_582053207523_item	2741007	et	3	main
teatakse	doc_582053207523_item	2741008	et	3	main
küll	doc_582053207523_item	2741009	et	4	main
eesti	doc_582053207523_item	2741010	et	4	main
lipuvärve	doc_582053207523_item	2741011	et	3	main
kuid	doc_582053207523_item	2741012	et	4	main
nende	doc_582053207523_item	2741013	et	4	main
tähendus	doc_582053207523_item	2741014	et	4	main
on	doc_582053207523_item	2741015	et	4	main
juba	doc_582053207523_item	2741016	et	3	main
ammu	doc_582053207523_item	2741017	et	4	main
ununenud	doc_582053207523_item	2741018	et	4	main
ning	doc_582053207523_item	2741019	et	3	main
lipu	doc_582053207523_item	2741020	et	3	main
ei	doc_582053207523_item	2741022	et	4	main
midagi	doc_582053207523_item	2741025	et	4	main
tunneks	doc_582053207523_item	2741031	et	4	main
ja	doc_582053207523_item	2741032	et	3	main
teaks	doc_582053207523_item	2741033	et	3	main
klassis	doc_582053207523_item	2741038	et	3	main
kultuurilugu	doc_582053207523_item	2741044	et	4	main
kus	doc_582053207523_item	2741045	et	3	main
tutvutakse	doc_582053207523_item	2741046	et	3	main
vene	doc_582053207523_item	2741028	et	4	main
kooli	doc_582053207523_item	2741029	et	4	main
igas	doc_582053207523_item	2741037	et	3	main
nädalas	doc_582053207523_item	2741042	et	3	main
geograafia	doc_582053207523_item	2741052	et	4	main
jne	doc_582053207523_item	2741053	et	4	main
kahjuks	doc_582053207523_item	2741054	et	4	main
on	doc_582053207523_item	2741055	et	4	main
täna	doc_582053207523_item	2741056	et	4	main
muukeelses	doc_582053207523_item	2741057	et	4	main
koolis	doc_582053207523_item	2741058	et	4	main
seis	doc_582053207523_item	2741059	et	4	main
üpris	doc_582053207523_item	2741060	et	3	main
kurb	doc_582053207523_item	2741061	et	3	main
ega	doc_582053207523_item	2741062	et	3	main
rahvakalendri	doc_582053207523_item	2741047	et	3	main
koolis	doc_582053207523_item	2741065	et	4	main
see	doc_582053207523_item	2741066	et	3	main
kõik	doc_582053207523_item	2741071	et	4	main
sõltub	doc_582053207523_item	2741072	et	3	main
paremaks	doc_582053207523_item	2741100	et	4	main
muutub	doc_582053207523_item	2741101	et	3	main
jääb	doc_582053207523_item	2741102	et	3	main
loota	doc_582053207523_item	2741103	et	4	main
et	doc_582053207523_item	2741104	et	3	main
uues	doc_582053207523_item	2741105	et	3	main
riiklikus	doc_582053207523_item	2741106	et	4	main
õppekavas	doc_582053207523_item	2741107	et	3	main
jääb	doc_582053207523_item	2741108	et	3	main
testid	doc_582053207523_item	2741116	et	4	main
tööhüpoteesi	doc_582053207523_item	2741119	et	4	main
kirjutada	doc_582053207523_item	2741130	et	3	main
teavad	doc_582053207523_item	2741133	et	3	main
ei	doc_582053207523_item	2741148	et	4	main
ole	doc_582053207523_item	2741154	et	4	main
vaja	doc_582053207523_item	2741155	et	4	main
tehtud	doc_582053207523_item	2741167	et	4	main
7	doc_582053207523_item	2741172	et	2	main
jaoks	doc_582053207523_item	2741174	et	4	main
koosnes	doc_582053207523_item	2741176	et	3	main
küsimustest	doc_582053207523_item	2741178	et	4	main
ja	doc_582053207523_item	2741179	et	3	main
teine	doc_582053207523_item	2741180	et	3	main
oli	doc_582053207523_item	2741181	et	3	main
11	doc_582053207523_item	2741182	et	2	main
ülejäänud	doc_582053207523_item	2741227	et	4	main
kirjutama	doc_582053207523_item	2741229	et	3	main
hümni	doc_582053207523_item	2741244	et	4	main
sõnade	doc_582053207523_item	2741245	et	3	main
jakobson	doc_582053207523_item	2741252	et	4	main
voldemarperekonnanimi	doc_582053207523_item	2741254	et	4	main
oli	doc_582053207523_item	2741255	et	3	main
oli	doc_582053207523_item	2741260	et	3	main
inimest	doc_582053207523_item	2741265	et	3	main
inimest	doc_582053207523_item	2741274	et	3	main
johan	doc_582053207523_item	2741276	et	4	main
voldemar	doc_582053207523_item	2741277	et	4	main
sõnade	doc_582053207523_item	2741283	et	3	main
võib	doc_582053207523_item	2741297	et	3	main
põhjustatud	doc_582053207523_item	2741299	et	4	main
sellega	doc_582053207523_item	2741300	et	3	main
arvati	doc_582053207523_item	2741311	et	4	main
mis	doc_582053207523_item	2741319	et	4	main
suutnud	doc_582053207523_item	2741333	et	4	main
rahvuspuu	doc_582053207523_item	2741337	et	4	main
suur	doc_582053207523_item	2741339	et	3	main
vastuseid	doc_582053207523_item	2741342	et	3	main
iga	doc_582053207523_item	2741354	et	4	main
õiged	doc_582053207523_item	2741374	et	3	main
vastused	doc_582053207523_item	2741375	et	3	main
ma	doc_582053207523_item	2741378	et	3	main
ole	doc_582053207523_item	2741391	et	4	main
laulupidu	doc_582053207523_item	2741398	et	4	main
mitte	doc_582053207523_item	2741403	et	3	main
oli	doc_582053207523_item	2741410	et	3	main
inimesed	doc_582053207523_item	2741415	et	3	main
peal	doc_582053207523_item	2741418	et	4	main
oli	doc_582053207523_item	2741419	et	3	main
kus	doc_582053207523_item	2741424	et	3	main
tähtpäevadega	doc_582053207523_item	2741048	et	3	main
eesti	doc_582053207523_item	2741049	et	4	main
selles	doc_582053207523_item	2741075	et	4	main
töötavatest	doc_582053207523_item	2741077	et	4	main
siis	doc_582053207523_item	2741084	et	3	main
ole	doc_582053207523_item	2741096	et	4	main
et	doc_582053207523_item	2741098	et	3	main
jaoks	doc_582053207523_item	2741114	et	4	main
korraldasin	doc_582053207523_item	2741122	et	3	main
ausalt	doc_582053207523_item	2741129	et	4	main
tühja	doc_582053207523_item	2741142	et	4	main
jätta	doc_582053207523_item	2741144	et	3	main
kuna	doc_582053207523_item	2741145	et	3	main
see	doc_582053207523_item	2741146	et	3	main
töö	doc_582053207523_item	2741147	et	4	main
selleks	doc_582053207523_item	2741160	et	4	main
et	doc_582053207523_item	2741161	et	3	main
saavutada	doc_582053207523_item	2741162	et	3	main
häid	doc_582053207523_item	2741163	et	3	main
tulemusi	doc_582053207523_item	2741164	et	4	main
mul	doc_582053207523_item	2741165	et	3	main
oli	doc_582053207523_item	2741166	et	3	main
testivarianti	doc_582053207523_item	2741169	et	4	main
28	doc_582053207523_item	2741187	et	2	main
küsimutest	doc_582053207523_item	2741188	et	3	main
ei	doc_582053207523_item	2741222	et	4	main
rahvuslindlillkivi	doc_582053207523_item	2741232	et	4	main
kes	doc_582053207523_item	2741241	et	4	main
jakob	doc_582053207523_item	2741250	et	4	main
puudu	doc_582053207523_item	2741259	et	4	main
frederik	doc_582053207523_item	2741262	et	4	main
32st	doc_582053207523_item	2741266	et	3	main
ei	doc_582053207523_item	2741267	et	4	main
mitte	doc_582053207523_item	2741269	et	3	main
arvasidet	doc_582053207523_item	2741281	et	4	main
frederik	doc_582053207523_item	2741286	et	4	main
pacius	doc_582053207523_item	2741287	et	4	main
õiget	doc_582053207523_item	2741289	et	3	main
olla	doc_582053207523_item	2741298	et	3	main
et	doc_582053207523_item	2741301	et	3	main
helilooja	doc_582053207523_item	2741304	et	4	main
et	doc_582053207523_item	2741312	et	3	main
töötas	doc_582053207523_item	2741314	et	3	main
puudutasid	doc_582053207523_item	2741320	et	4	main
kirjutada	doc_582053207523_item	2741334	et	3	main
kõik	doc_582053207523_item	2741372	et	4	main
midagi	doc_582053207523_item	2741383	et	4	main
muudküsimus	doc_582053207523_item	2741384	et	3	main
ei	doc_582053207523_item	2741390	et	4	main
esimene	doc_582053207523_item	2741397	et	3	main
keegi	doc_582053207523_item	2741404	et	4	main
vastuseidseal	doc_582053207523_item	2741414	et	4	main
seda	doc_582053207523_item	2741432	et	3	main
ja	doc_582053207523_item	2741434	et	3	main
inimest	doc_582053207523_item	2741436	et	3	main
harva	doc_582053207523_item	2741451	et	4	main
sellest	doc_582053207523_item	2741464	et	4	main
lähimalt	doc_582053207523_item	2741465	et	4	main
mis	doc_582053207523_item	2741469	et	4	main
andsid	doc_582053207523_item	2741473	et	4	main
26	doc_582053207523_item	2741476	et	2	main
4	doc_582053207523_item	2741478	et	2	main
ei	doc_582053207523_item	2741479	et	4	main
andsid	doc_582053207523_item	2741485	et	4	main
ja	doc_582053207523_item	2741489	et	3	main
sellisedseda	doc_582053207523_item	2741494	et	4	main
arvata	doc_582053207523_item	2741498	et	4	main
küsimus	doc_582053207523_item	2741500	et	4	main
ei	doc_582053207523_item	2741517	et	4	main
5klassis	doc_582053207523_item	2741522	et	3	main
palju	doc_582053207523_item	2741525	et	4	main
vastuse	doc_582053207523_item	2741533	et	3	main
rahvuslaule	doc_582053207523_item	2741545	et	4	main
kirjutasid	doc_582053207523_item	2741559	et	4	main
segamini	doc_582053207523_item	2741609	et	4	main
rahvamõistatusi	doc_582053207523_item	2741610	et	3	main
seega	doc_582053207523_item	2741613	et	4	main
õpilane	doc_582053207523_item	2741620	et	3	main
kommenteerida	doc_582053207523_item	2741636	et	3	main
kas	doc_582053207523_item	2741652	et	3	main
tund	doc_582053207523_item	2741655	et	3	main
ka	doc_582053207523_item	2741063	et	3	main
eesti	doc_582053207523_item	2741064	et	4	main
ole	doc_582053207523_item	2741070	et	4	main
on	doc_582053207523_item	2741081	et	4	main
ka	doc_582053207523_item	2741086	et	3	main
õpilased	doc_582053207523_item	2741088	et	3	main
tundma	doc_582053207523_item	2741090	et	3	main
siis	doc_582053207523_item	2741094	et	3	main
lootustki	doc_582053207523_item	2741097	et	4	main
midagi	doc_582053207523_item	2741099	et	4	main
kultuuriloo	doc_582053207523_item	2741112	et	4	main
sissejuhatus	doc_582053207523_item	2741117	et	4	main
oma	doc_582053207523_item	2741118	et	4	main
tõestamiseks	doc_582053207523_item	2741120	et	4	main
mis	doc_582053207523_item	2741068	et	4	main
koolist	doc_582053207523_item	2741073	et	4	main
koolis	doc_582053207523_item	2741076	et	4	main
õpetajatest	doc_582053207523_item	2741078	et	4	main
kui	doc_582053207523_item	2741079	et	3	main
õpetaja	doc_582053207523_item	2741080	et	4	main
õpivad	doc_582053207523_item	2741085	et	3	main
aga	doc_582053207523_item	2741092	et	3	main
tundide	doc_582053207523_item	2741113	et	3	main
ma	doc_582053207523_item	2741121	et	3	main
seega	doc_582053207523_item	2741126	et	4	main
õpilased	doc_582053207523_item	2741127	et	3	main
said	doc_582053207523_item	2741128	et	4	main
nad	doc_582053207523_item	2741132	et	3	main
jaoks	doc_582053207523_item	2741184	et	4	main
ja	doc_582053207523_item	2741185	et	3	main
koosnes	doc_582053207523_item	2741186	et	3	main
teadnud	doc_582053207523_item	2741223	et	4	main
üldse	doc_582053207523_item	2741224	et	3	main
ja	doc_582053207523_item	2741226	et	3	main
eraldi	doc_582053207523_item	2741237	et	4	main
küsimusedteiseks	doc_582053207523_item	2741238	et	4	main
küsimuseks	doc_582053207523_item	2741239	et	4	main
oli	doc_582053207523_item	2741240	et	3	main
vastusteks	doc_582053207523_item	2741247	et	4	main
hurt	doc_582053207523_item	2741251	et	3	main
johan	doc_582053207523_item	2741253	et	4	main
paljudel	doc_582053207523_item	2741256	et	3	main
lihtsalt	doc_582053207523_item	2741258	et	4	main
ning	doc_582053207523_item	2741263	et	3	main
kirjutanud	doc_582053207523_item	2741268	et	4	main
midagi	doc_582053207523_item	2741270	et	4	main
jansen	doc_582053207523_item	2741278	et	4	main
9	doc_582053207523_item	2741279	et	2	main
autor	doc_582053207523_item	2741284	et	3	main
vastust-lydia	doc_582053207523_item	2741290	et	4	main
koidula	doc_582053207523_item	2741291	et	4	main
kirjutas	doc_582053207523_item	2741292	et	3	main
on	doc_582053207523_item	2741303	et	4	main
ja	doc_582053207523_item	2741305	et	3	main
koidulat	doc_582053207523_item	2741306	et	4	main
ei	doc_582053207523_item	2741307	et	4	main
jannseni	doc_582053207523_item	2741315	et	4	main
juhendamise	doc_582053207523_item	2741316	et	4	main
all	doc_582053207523_item	2741317	et	3	main
oli	doc_582053207523_item	2741124	et	3	main
mida	doc_582053207523_item	2741135	et	4	main
olnud	doc_582053207523_item	2741137	et	4	main
teadnud	doc_582053207523_item	2741138	et	4	main
siis	doc_582053207523_item	2741139	et	3	main
kohta	doc_582053207523_item	2741143	et	4	main
harjutus	doc_582053207523_item	2741151	et	4	main
siis	doc_582053207523_item	2741152	et	3	main
ei	doc_582053207523_item	2741153	et	4	main
klassi	doc_582053207523_item	2741183	et	4	main
21	doc_582053207523_item	2741189	et	2	main
7klassi	doc_582053207523_item	2741190	et	4	main
testianalüüs	doc_582053207523_item	2741191	et	3	main
kokku	doc_582053207523_item	2741192	et	3	main
oli	doc_582053207523_item	2741193	et	3	main
läbi	doc_582053207523_item	2741194	et	4	main
küsitud	doc_582053207523_item	2741195	et	4	main
32	doc_582053207523_item	2741196	et	2	main
õpilast	doc_582053207523_item	2741197	et	4	main
esimeseks	doc_582053207523_item	2741198	et	3	main
küsimiseks	doc_582053207523_item	2741199	et	4	main
oli	doc_582053207523_item	2741200	et	3	main
millised	doc_582053207523_item	2741201	et	3	main
on	doc_582053207523_item	2741202	et	4	main
eesti	doc_582053207523_item	2741203	et	4	main
riigisümbolid	doc_582053207523_item	2741204	et	3	main
ning	doc_582053207523_item	2741205	et	3	main
vastusteks	doc_582053207523_item	2741206	et	4	main
ma	doc_582053207523_item	2741207	et	3	main
ootasin	doc_582053207523_item	2741208	et	3	main
lippuhümni	doc_582053207523_item	2741210	et	4	main
ja	doc_582053207523_item	2741211	et	3	main
eesti	doc_582053207523_item	2741209	et	4	main
vapi	doc_582053207523_item	2741212	et	3	main
ja	doc_582053207523_item	2741213	et	3	main
selliseid	doc_582053207523_item	2741214	et	4	main
vastuseid	doc_582053207523_item	2741215	et	3	main
kirjutasid	doc_582053207523_item	2741216	et	4	main
ainult	doc_582053207523_item	2741217	et	4	main
5	doc_582053207523_item	2741218	et	2	main
inimest	doc_582053207523_item	2741219	et	3	main
32st	doc_582053207523_item	2741220	et	3	main
6	doc_582053207523_item	2741221	et	2	main
vastust	doc_582053207523_item	2741225	et	4	main
hakkkasid	doc_582053207523_item	2741228	et	4	main
kes	doc_582053207523_item	2741230	et	4	main
on	doc_582053207523_item	2741231	et	4	main
eesti	doc_582053207523_item	2741243	et	4	main
mainitud	doc_582053207523_item	2741249	et	4	main
ka	doc_582053207523_item	2741261	et	3	main
aga	doc_582053207523_item	2741233	et	3	main
selleks	doc_582053207523_item	2741234	et	4	main
oli	doc_582053207523_item	2741235	et	3	main
mul	doc_582053207523_item	2741236	et	3	main
on	doc_582053207523_item	2741242	et	4	main
kirjutaja	doc_582053207523_item	2741246	et	4	main
olid	doc_582053207523_item	2741248	et	4	main
inimestel	doc_582053207523_item	2741257	et	3	main
vastuseks	doc_582053207523_item	2741271	et	4	main
ning	doc_582053207523_item	2741272	et	3	main
11	doc_582053207523_item	2741273	et	2	main
õpilast	doc_582053207523_item	2741280	et	4	main
oli	doc_582053207523_item	2741285	et	3	main
ja	doc_582053207523_item	2741288	et	3	main
ainult	doc_582053207523_item	2741293	et	4	main
üks	doc_582053207523_item	2741294	et	3	main
pacius	doc_582053207523_item	2741302	et	4	main
ta	doc_582053207523_item	2741313	et	4	main
olid	doc_582053207523_item	2741325	et	4	main
kõikidel	doc_582053207523_item	2741326	et	4	main
õiged	doc_582053207523_item	2741327	et	3	main
vastused	doc_582053207523_item	2741328	et	3	main
2	doc_582053207523_item	2741330	et	2	main
õpilast	doc_582053207523_item	2741331	et	4	main
ei	doc_582053207523_item	2741332	et	4	main
ja	doc_582053207523_item	2741353	et	3	main
aasta	doc_582053207523_item	2741355	et	4	main
samas	doc_582053207523_item	2741357	et	4	main
presidendist	doc_582053207523_item	2741370	et	4	main
ning	doc_582053207523_item	2741371	et	3	main
öeldes	doc_582053207523_item	2741377	et	3	main
ei	doc_582053207523_item	2741379	et	4	main
millal	doc_582053207523_item	2741393	et	3	main
tihti	doc_582053207523_item	2741400	et	3	main
peetakse	doc_582053207523_item	2741402	et	3	main
vastust	doc_582053207523_item	2741409	et	4	main
palju	doc_582053207523_item	2741412	et	4	main
absurdseid	doc_582053207523_item	2741413	et	3	main
laulavad	doc_582053207523_item	2741416	et	4	main
jannsenpaljud	doc_582053207523_item	2741422	et	4	main
laulupidu10	doc_582053207523_item	2741427	et	4	main
oli	doc_582053207523_item	2741440	et	3	main
selle	doc_582053207523_item	2741442	et	4	main
põhjuseks	doc_582053207523_item	2741443	et	3	main
suvevaheajal	doc_582053207523_item	2741454	et	3	main
perioodil	doc_582053207523_item	2741457	et	3	main
rääkidantminna	doc_582053207523_item	2741466	et	4	main
puudutab	doc_582053207523_item	2741470	et	3	main
kirjutanud	doc_582053207523_item	2741482	et	4	main
ja	doc_582053207523_item	2741483	et	3	main
vastust16	doc_582053207523_item	2741487	et	4	main
detsembermiks	doc_582053207523_item	2741491	et	4	main
järgmine	doc_582053207523_item	2741499	et	3	main
eesti	doc_582053207523_item	2741502	et	4	main
ka	doc_582053207523_item	2741510	et	3	main
pakutud	doc_582053207523_item	2741512	et	4	main
kalev	doc_582053207523_item	2741513	et	3	main
ning	doc_582053207523_item	2741514	et	3	main
igapäeva	doc_582053207523_item	2741528	et	4	main
põhjustas	doc_582053207523_item	2741532	et	3	main
on	doc_582053207523_item	2741535	et	4	main
selgitadasamas	doc_582053207523_item	2741538	et	4	main
ma	doc_582053207523_item	2741539	et	3	main
raskeid	doc_582053207523_item	2741541	et	3	main
13	doc_582053207523_item	2741546	et	2	main
küsitlenust	doc_582053207523_item	2741547	et	4	main
ülejäänud	doc_582053207523_item	2741560	et	4	main
muutuda	doc_582053207523_item	2741569	et	3	main
oli	doc_582053207523_item	2741603	et	3	main
ajasid	doc_582053207523_item	2741608	et	4	main
ja	doc_582053207523_item	2741611	et	3	main
vanasõnu	doc_582053207523_item	2741612	et	3	main
tulemus	doc_582053207523_item	2741614	et	3	main
oli	doc_582053207523_item	2741615	et	3	main
selline	doc_582053207523_item	2741616	et	4	main
et	doc_582053207523_item	2741617	et	3	main
mitte	doc_582053207523_item	2741618	et	3	main
ükski	doc_582053207523_item	2741619	et	4	main
8	doc_582053207523_item	2741264	et	2	main
kirjutasid	doc_582053207523_item	2741275	et	4	main
hümni	doc_582053207523_item	2741282	et	4	main
õpilaneselline	doc_582053207523_item	2741295	et	4	main
tulemus	doc_582053207523_item	2741296	et	3	main
mainitud	doc_582053207523_item	2741308	et	4	main
sellepärast	doc_582053207523_item	2741309	et	3	main
et	doc_582053207523_item	2741310	et	3	main
küsimused	doc_582053207523_item	2741318	et	4	main
rahvuslidu	doc_582053207523_item	2741322	et	4	main
lilli	doc_582053207523_item	2741323	et	4	main
puu	doc_582053207523_item	2741324	et	4	main
on	doc_582053207523_item	2741336	et	4	main
selline	doc_582053207523_item	2741338	et	4	main
õigeid	doc_582053207523_item	2741341	et	3	main
põhjustatud	doc_582053207523_item	2741344	et	4	main
sellega	doc_582053207523_item	2741345	et	3	main
et	doc_582053207523_item	2741346	et	3	main
et	doc_582053207523_item	2741347	et	3	main
rahvussümbolid	doc_582053207523_item	2741348	et	3	main
hakatakse	doc_582053207523_item	2741349	et	3	main
õppima	doc_582053207523_item	2741350	et	3	main
alates	doc_582053207523_item	2741351	et	3	main
eesti	doc_582053207523_item	2741369	et	4	main
andsid	doc_582053207523_item	2741373	et	4	main
ausalt	doc_582053207523_item	2741376	et	4	main
laulupeost	doc_582053207523_item	2741385	et	4	main
tekitas	doc_582053207523_item	2741386	et	3	main
päris	doc_582053207523_item	2741387	et	4	main
palju	doc_582053207523_item	2741388	et	4	main
ja	doc_582053207523_item	2741394	et	3	main
oli	doc_582053207523_item	2741396	et	3	main
kui	doc_582053207523_item	2741399	et	3	main
seda	doc_582053207523_item	2741401	et	3	main
ei	doc_582053207523_item	2741405	et	4	main
osanud	doc_582053207523_item	2741406	et	4	main
anda	doc_582053207523_item	2741407	et	3	main
täpset	doc_582053207523_item	2741408	et	3	main
pakutud	doc_582053207523_item	2741411	et	4	main
rahvuslaulelaua	doc_582053207523_item	2741417	et	4	main
esimeneoli	doc_582053207523_item	2741420	et	4	main
voldemar	doc_582053207523_item	2741421	et	4	main
teadsid	doc_582053207523_item	2741423	et	4	main
oli	doc_582053207523_item	2741425	et	3	main
esimene	doc_582053207523_item	2741426	et	3	main
maininud	doc_582053207523_item	2741438	et	4	main
esimene	doc_582053207523_item	2741441	et	3	main
võib	doc_582053207523_item	2741444	et	3	main
olla	doc_582053207523_item	2741445	et	3	main
see	doc_582053207523_item	2741446	et	3	main
et	doc_582053207523_item	2741447	et	3	main
laulupidu	doc_582053207523_item	2741448	et	4	main
korraldatakse	doc_582053207523_item	2741449	et	3	main
väga	doc_582053207523_item	2741450	et	3	main
ja	doc_582053207523_item	2741455	et	3	main
saa	doc_582053207523_item	2741459	et	4	main
koos	doc_582053207523_item	2741467	et	4	main
iseseisvuspäeva	doc_582053207523_item	2741471	et	4	main
vastustseega	doc_582053207523_item	2741475	et	4	main
õpilast	doc_582053207523_item	2741477	et	4	main
2	doc_582053207523_item	2741484	et	2	main
raske	doc_582053207523_item	2741497	et	4	main
puudutas	doc_582053207523_item	2741501	et	3	main
rahvuseepose	doc_582053207523_item	2741503	et	3	main
nimet	doc_582053207523_item	2741504	et	4	main
väga	doc_582053207523_item	2741505	et	3	main
paljud	doc_582053207523_item	2741506	et	3	main
teadsid	doc_582053207523_item	2741507	et	4	main
õiget	doc_582053207523_item	2741508	et	3	main
vastuseks	doc_582053207523_item	2741511	et	4	main
6	doc_582053207523_item	2741515	et	2	main
õpilast	doc_582053207523_item	2741516	et	4	main
räägitakse	doc_582053207523_item	2741524	et	3	main
koolis	doc_582053207523_item	2741526	et	4	main
ja	doc_582053207523_item	2741527	et	3	main
mis	doc_582053207523_item	2741531	et	4	main
puudumist	doc_582053207523_item	2741534	et	4	main
raske	doc_582053207523_item	2741536	et	4	main
välja	doc_582053207523_item	2741537	et	4	main
küsisin	doc_582053207523_item	2741540	et	3	main
küsimisepalusin	doc_582053207523_item	2741542	et	4	main
eesti	doc_582053207523_item	2741321	et	4	main
ainult	doc_582053207523_item	2741329	et	4	main
mis	doc_582053207523_item	2741335	et	4	main
arv	doc_582053207523_item	2741340	et	3	main
oli	doc_582053207523_item	2741343	et	3	main
1klassist	doc_582053207523_item	2741352	et	3	main
korratakse	doc_582053207523_item	2741356	et	4	main
need	doc_582053207523_item	2741358	et	3	main
sümbolid	doc_582053207523_item	2741359	et	3	main
on	doc_582053207523_item	2741360	et	4	main
kirjas	doc_582053207523_item	2741361	et	4	main
paljude	doc_582053207523_item	2741362	et	3	main
eesti	doc_582053207523_item	2741363	et	4	main
keele	doc_582053207523_item	2741364	et	4	main
õpikute	doc_582053207523_item	2741365	et	3	main
esikaaneteloli	doc_582053207523_item	2741366	et	4	main
ka	doc_582053207523_item	2741367	et	3	main
küsimus	doc_582053207523_item	2741368	et	4	main
ole	doc_582053207523_item	2741380	et	4	main
oodanud	doc_582053207523_item	2741381	et	4	main
mitte	doc_582053207523_item	2741382	et	3	main
probleemeõpilastel	doc_582053207523_item	2741389	et	4	main
selge	doc_582053207523_item	2741392	et	4	main
kus	doc_582053207523_item	2741395	et	3	main
õpilast	doc_582053207523_item	2741428	et	4	main
teavad	doc_582053207523_item	2741429	et	3	main
kui	doc_582053207523_item	2741430	et	3	main
tihti	doc_582053207523_item	2741431	et	3	main
on	doc_582053207523_item	2741437	et	4	main
millal	doc_582053207523_item	2741439	et	3	main
see	doc_582053207523_item	2741452	et	3	main
sel	doc_582053207523_item	2741456	et	3	main
ei	doc_582053207523_item	2741458	et	4	main
midagi	doc_582053207523_item	2741460	et	4	main
korraldada	doc_582053207523_item	2741461	et	3	main
et	doc_582053207523_item	2741462	et	3	main
õpilastele	doc_582053207523_item	2741463	et	4	main
laulupeolesee	doc_582053207523_item	2741468	et	4	main
paljud	doc_582053207523_item	2741472	et	3	main
õiget	doc_582053207523_item	2741474	et	3	main
midagi	doc_582053207523_item	2741481	et	4	main
on	doc_582053207523_item	2741495	et	4	main
väga	doc_582053207523_item	2741496	et	3	main
vastustoli	doc_582053207523_item	2741509	et	4	main
vastatakalevipoja	doc_582053207523_item	2741519	et	4	main
peetakse	doc_582053207523_item	2741433	et	3	main
2	doc_582053207523_item	2741435	et	2	main
toimub	doc_582053207523_item	2741453	et	3	main
olnud	doc_582053207523_item	2741480	et	4	main
kummalist	doc_582053207523_item	2741486	et	3	main
veebruar	doc_582053207523_item	2741488	et	3	main
24	doc_582053207523_item	2741490	et	2	main
vastused	doc_582053207523_item	2741492	et	3	main
olid	doc_582053207523_item	2741493	et	4	main
osanud	doc_582053207523_item	2741518	et	4	main
eepost	doc_582053207523_item	2741520	et	3	main
õpitakse	doc_582053207523_item	2741521	et	4	main
sellest	doc_582053207523_item	2741523	et	4	main
ning	doc_582053207523_item	2741530	et	3	main
ei	doc_582053207523_item	2741548	et	4	main
kirjutanud	doc_582053207523_item	2741549	et	4	main
mitte	doc_582053207523_item	2741550	et	3	main
niigi	doc_582053207523_item	2741558	et	4	main
tuleb	doc_582053207523_item	2741567	et	3	main
õppekava	doc_582053207523_item	2741570	et	4	main
lisada	doc_582053207523_item	2741571	et	3	main
sinna	doc_582053207523_item	2741572	et	3	main
audiomaterjale	doc_582053207523_item	2741573	et	3	main
sellekset	doc_582053207523_item	2741574	et	4	main
eesti	doc_582053207523_item	2741604	et	4	main
mõned	doc_582053207523_item	2741606	et	3	main
ei	doc_582053207523_item	2741621	et	4	main
sellele	doc_582053207523_item	2741623	et	4	main
küsimusele	doc_582053207523_item	2741624	et	4	main
aga	doc_582053207523_item	2741625	et	3	main
vanasõnu	doc_582053207523_item	2741626	et	3	main
tihti	doc_582053207523_item	2741627	et	3	main
läheb	doc_582053207523_item	2741628	et	3	main
vaja	doc_582053207523_item	2741634	et	4	main
et	doc_582053207523_item	2741648	et	3	main
õppekavas	doc_582053207523_item	2741649	et	3	main
saaks	doc_582053207523_item	2741650	et	3	main
pühendada	doc_582053207523_item	2741651	et	3	main
sellekset	doc_582053207523_item	2741658	et	4	main
teksti	doc_582053207523_item	2741670	et	4	main
kui	doc_582053207523_item	2741685	et	3	main
vastatarahvatarkuste	doc_582053207523_item	2741693	et	4	main
väga	doc_582053207523_item	2741709	et	3	main
kirjutada	doc_582053207523_item	2741721	et	3	main
rahvuspidusid	doc_582053207523_item	2741737	et	4	main
õpilased	doc_582053207523_item	2741738	et	3	main
vastlad	doc_582053207523_item	2741743	et	3	main
on	doc_582053207523_item	2741753	et	4	main
et	doc_582053207523_item	2741757	et	3	main
koolis	doc_582053207523_item	2741759	et	4	main
järgmises	doc_582053207523_item	2741769	et	3	main
oli	doc_582053207523_item	2741771	et	3	main
smuul	doc_582053207523_item	2741805	et	4	main
aga	doc_582053207523_item	2741806	et	3	main
lingren	doc_582053207523_item	2741816	et	4	main
ja	doc_582053207523_item	2741817	et	3	main
ainult	doc_582053207523_item	2741824	et	4	main
olutsu	doc_582053207523_item	2741828	et	4	main
teosed	doc_582053207523_item	2741831	et	3	main
õpetatakse	doc_582053207523_item	2741832	et	3	main
koolis	doc_582053207523_item	2741833	et	4	main
kes	doc_582053207523_item	2741850	et	4	main
eesti	doc_582053207523_item	2741858	et	4	main
elus	doc_582053207523_item	2741529	et	4	main
rahvuslauluks	doc_582053207523_item	2741556	et	4	main
ja	doc_582053207523_item	2741557	et	3	main
vastuseidselle	doc_582053207523_item	2741564	et	4	main
tulemuse	doc_582053207523_item	2741565	et	3	main
alusel	doc_582053207523_item	2741566	et	4	main
kindlasti	doc_582053207523_item	2741568	et	3	main
õpilased	doc_582053207523_item	2741575	et	3	main
saaksid	doc_582053207523_item	2741576	et	4	main
endale	doc_582053207523_item	2741577	et	4	main
ette	doc_582053207523_item	2741578	et	4	main
kujutleda	doc_582053207523_item	2741579	et	3	main
mis	doc_582053207523_item	2741580	et	4	main
see	doc_582053207523_item	2741581	et	3	main
rahvuslaul	doc_582053207523_item	2741582	et	4	main
üldse	doc_582053207523_item	2741583	et	3	main
on	doc_582053207523_item	2741584	et	4	main
samas	doc_582053207523_item	2741585	et	4	main
lapsi	doc_582053207523_item	2741586	et	4	main
ei	doc_582053207523_item	2741587	et	4	main
huvita	doc_582053207523_item	2741588	et	4	main
rahvuslaulud	doc_582053207523_item	2741589	et	3	main
ka	doc_582053207523_item	2741590	et	3	main
et	doc_582053207523_item	2741592	et	3	main
sellepärast	doc_582053207523_item	2741591	et	3	main
seal	doc_582053207523_item	2741593	et	4	main
on	doc_582053207523_item	2741594	et	4	main
kasutatud	doc_582053207523_item	2741595	et	4	main
vana	doc_582053207523_item	2741596	et	4	main
sõnavara	doc_582053207523_item	2741597	et	4	main
millest	doc_582053207523_item	2741598	et	3	main
õpilased	doc_582053207523_item	2741599	et	3	main
aru	doc_582053207523_item	2741600	et	4	main
ei	doc_582053207523_item	2741601	et	4	main
saasama	doc_582053207523_item	2741602	et	4	main
nimetada	doc_582053207523_item	2741543	et	3	main
eesti	doc_582053207523_item	2741544	et	4	main
midagi	doc_582053207523_item	2741551	et	4	main
13	doc_582053207523_item	2741552	et	2	main
pidas	doc_582053207523_item	2741553	et	3	main
eesti	doc_582053207523_item	2741554	et	4	main
hümni	doc_582053207523_item	2741555	et	4	main
pakusid	doc_582053207523_item	2741561	et	4	main
mitmesuguseid	doc_582053207523_item	2741562	et	3	main
õigeid	doc_582053207523_item	2741563	et	3	main
vanasõnadega	doc_582053207523_item	2741605	et	3	main
õpilased	doc_582053207523_item	2741607	et	3	main
vaja	doc_582053207523_item	2741629	et	4	main
igapäevases	doc_582053207523_item	2741630	et	4	main
elus	doc_582053207523_item	2741631	et	4	main
või	doc_582053207523_item	2741637	et	4	main
õpetada	doc_582053207523_item	2741638	et	3	main
abil	doc_582053207523_item	2741641	et	4	main
mis	doc_582053207523_item	2741668	et	4	main
küsimuseks	doc_582053207523_item	2741676	et	4	main
ei	doc_582053207523_item	2741691	et	4	main
väga	doc_582053207523_item	2741696	et	3	main
küsisin	doc_582053207523_item	2741700	et	3	main
vastanud	doc_582053207523_item	2741622	et	4	main
kui	doc_582053207523_item	2741632	et	3	main
on	doc_582053207523_item	2741633	et	4	main
vanasõna	doc_582053207523_item	2741639	et	4	main
samas	doc_582053207523_item	2741642	et	4	main
see	doc_582053207523_item	2741643	et	3	main
aitab	doc_582053207523_item	2741644	et	3	main
rikastada	doc_582053207523_item	2741645	et	3	main
kõnema	doc_582053207523_item	2741646	et	4	main
arvan	doc_582053207523_item	2741647	et	3	main
või	doc_582053207523_item	2741653	et	4	main
üks	doc_582053207523_item	2741654	et	3	main
samas	doc_582053207523_item	2741662	et	4	main
sisuga	doc_582053207523_item	2741671	et	3	main
hästi	doc_582053207523_item	2741672	et	3	main
omavahel	doc_582053207523_item	2741673	et	3	main
vastata	doc_582053207523_item	2741678	et	4	main
peaaegu	doc_582053207523_item	2741683	et	3	main
küsimusega	doc_582053207523_item	2741687	et	4	main
teadmine	doc_582053207523_item	2741694	et	4	main
on	doc_582053207523_item	2741695	et	4	main
ka	doc_582053207523_item	2741701	et	3	main
muisete	doc_582053207523_item	2741703	et	4	main
erinevaid	doc_582053207523_item	2741710	et	4	main
mõned	doc_582053207523_item	2741711	et	3	main
olid	doc_582053207523_item	2741712	et	4	main
väga	doc_582053207523_item	2741713	et	3	main
naljakad	doc_582053207523_item	2741714	et	3	main
näiteks	doc_582053207523_item	2741715	et	4	main
küsimused	doc_582053207523_item	2741717	et	4	main
kalevipoegjeesuslydiajärgmised	doc_582053207523_item	2741716	et	4	main
olid	doc_582053207523_item	2741718	et	4	main
rahvakalendristnimelt	doc_582053207523_item	2741719	et	4	main
palusin	doc_582053207523_item	2741720	et	3	main
nad	doc_582053207523_item	2741724	et	3	main
jaanipäev	doc_582053207523_item	2741744	et	3	main
palju	doc_582053207523_item	2741749	et	4	main
pühasid	doc_582053207523_item	2741750	et	3	main
pühadest	doc_582053207523_item	2741752	et	3	main
nimetada	doc_582053207523_item	2741773	et	3	main
tammsaarevilde	doc_582053207523_item	2741804	et	4	main
ka	doc_582053207523_item	2741820	et	3	main
et	doc_582053207523_item	2741823	et	3	main
nimetas	doc_582053207523_item	2741827	et	3	main
tema	doc_582053207523_item	2741830	et	4	main
kirjutatakse	doc_582053207523_item	2741834	et	3	main
sellest	doc_582053207523_item	2741835	et	4	main
selle	doc_582053207523_item	2741839	et	4	main
küsimusele	doc_582053207523_item	2741840	et	4	main
vastajaid	doc_582053207523_item	2741841	et	4	main
olnud	doc_582053207523_item	2741852	et	4	main
vastanud	doc_582053207523_item	2741853	et	4	main
midagieelviimaseks	doc_582053207523_item	2741854	et	3	main
lavastusedpaljud	doc_582053207523_item	2741862	et	4	main
nimetasid	doc_582053207523_item	2741864	et	4	main
olevaid	doc_582053207523_item	2741867	et	4	main
teatreid	doc_582053207523_item	2741868	et	3	main
ja	doc_582053207523_item	2741869	et	3	main
ainult	doc_582053207523_item	2741870	et	4	main
1	doc_582053207523_item	2741899	et	2	main
laste	doc_582053207523_item	2741913	et	4	main
teadmised	doc_582053207523_item	2741914	et	4	main
et	doc_582053207523_item	2741928	et	3	main
on	doc_582053207523_item	2741930	et	4	main
vähe	doc_582053207523_item	2741932	et	3	main
jäätnud	doc_582053207523_item	2741934	et	4	main
tulemus	doc_582053207523_item	2741943	et	3	main
kirjutanud	doc_582053207523_item	2741952	et	4	main
lydia	doc_582053207523_item	2741963	et	4	main
olin	doc_582053207523_item	2741973	et	3	main
õppekavas	doc_582053207523_item	2741993	et	3	main
midagi	doc_582053207523_item	2741635	et	4	main
kasutamise	doc_582053207523_item	2741640	et	4	main
jooksul	doc_582053207523_item	2741657	et	4	main
olukorda	doc_582053207523_item	2741660	et	4	main
selle	doc_582053207523_item	2741669	et	4	main
oli	doc_582053207523_item	2741677	et	3	main
ja	doc_582053207523_item	2741680	et	3	main
oli	doc_582053207523_item	2741682	et	3	main
eelneva	doc_582053207523_item	2741686	et	4	main
seega	doc_582053207523_item	2741688	et	4	main
mitte	doc_582053207523_item	2741689	et	3	main
keegi	doc_582053207523_item	2741690	et	4	main
tasemeltestis	doc_582053207523_item	2741698	et	4	main
rahvakalendripäevi	doc_582053207523_item	2741723	et	4	main
rohkem	doc_582053207523_item	2741726	et	4	main
jaanipäeva	doc_582053207523_item	2741729	et	4	main
suurt	doc_582053207523_item	2741730	et	3	main
reedet	doc_582053207523_item	2741731	et	3	main
vastlapäevajärgnev	doc_582053207523_item	2741732	et	3	main
vastused	doc_582053207523_item	2741741	et	3	main
mardi-ja	doc_582053207523_item	2741745	et	3	main
üpris	doc_582053207523_item	2741748	et	3	main
ka	doc_582053207523_item	2741755	et	3	main
lydia	doc_582053207523_item	2741802	et	4	main
koidulat	doc_582053207523_item	2741803	et	4	main
tobiasoli	doc_582053207523_item	2741819	et	4	main
õppeaasta	doc_582053207523_item	2741656	et	4	main
sellist	doc_582053207523_item	2741659	et	4	main
parandada	doc_582053207523_item	2741661	et	3	main
tuleb	doc_582053207523_item	2741663	et	3	main
enne	doc_582053207523_item	2741664	et	4	main
õppeteksti	doc_582053207523_item	2741665	et	4	main
lisada	doc_582053207523_item	2741666	et	3	main
vanasõnu	doc_582053207523_item	2741667	et	3	main
sobiksid	doc_582053207523_item	2741674	et	4	main
järgmiseks	doc_582053207523_item	2741675	et	3	main
mõistatustele	doc_582053207523_item	2741679	et	4	main
tulemus	doc_582053207523_item	2741681	et	3	main
sama	doc_582053207523_item	2741684	et	4	main
osanud	doc_582053207523_item	2741692	et	4	main
nõrgal	doc_582053207523_item	2741697	et	3	main
ma	doc_582053207523_item	2741699	et	3	main
eesti	doc_582053207523_item	2741702	et	4	main
jumalate	doc_582053207523_item	2741704	et	3	main
nimesid	doc_582053207523_item	2741705	et	3	main
ja	doc_582053207523_item	2741706	et	3	main
vastuseid	doc_582053207523_item	2741707	et	3	main
sain	doc_582053207523_item	2741708	et	3	main
missuguseid	doc_582053207523_item	2741722	et	3	main
teati	doc_582053207523_item	2741727	et	3	main
tähistavad	doc_582053207523_item	2741739	et	4	main
peamised	doc_582053207523_item	2741740	et	3	main
tähistatkse	doc_582053207523_item	2741747	et	4	main
teadmised	doc_582053207523_item	2741751	et	4	main
sellepärast	doc_582053207523_item	2741756	et	3	main
nendest	doc_582053207523_item	2741758	et	4	main
räägitakse	doc_582053207523_item	2741760	et	3	main
palju	doc_582053207523_item	2741761	et	4	main
korraldatakse	doc_582053207523_item	2741762	et	3	main
nende	doc_582053207523_item	2741763	et	4	main
peode	doc_582053207523_item	2741764	et	3	main
vaja	doc_582053207523_item	2741772	et	4	main
kirjanikkevastuseid	doc_582053207523_item	2741775	et	4	main
oli	doc_582053207523_item	2741776	et	3	main
palju	doc_582053207523_item	2741777	et	4	main
mainisid	doc_582053207523_item	2741801	et	4	main
mingil	doc_582053207523_item	2741807	et	4	main
põhjusel	doc_582053207523_item	2741808	et	3	main
eesti	doc_582053207523_item	2741809	et	4	main
kirjanikke	doc_582053207523_item	2741810	et	3	main
hulka	doc_582053207523_item	2741811	et	4	main
oli	doc_582053207523_item	2741812	et	3	main
sattunud	doc_582053207523_item	2741813	et	4	main
ka	doc_582053207523_item	2741814	et	3	main
astrid	doc_582053207523_item	2741815	et	3	main
kummaline	doc_582053207523_item	2741821	et	3	main
õpilane	doc_582053207523_item	2741826	et	3	main
kuigi	doc_582053207523_item	2741829	et	3	main
küsimustega	doc_582053207523_item	2741838	et	4	main
üpris	doc_582053207523_item	2741843	et	3	main
siiski	doc_582053207523_item	2741846	et	4	main
2	doc_582053207523_item	2741848	et	2	main
teatrid	doc_582053207523_item	2741860	et	3	main
ainult	doc_582053207523_item	2741865	et	4	main
tallinnas	doc_582053207523_item	2741866	et	4	main
ole	doc_582053207523_item	2741904	et	4	main
mitte	doc_582053207523_item	2741905	et	3	main
keegi	doc_582053207523_item	2741906	et	4	main
kirjutanudneed	doc_582053207523_item	2741907	et	4	main
eesti	doc_582053207523_item	2741915	et	4	main
see	doc_582053207523_item	2741921	et	3	main
kultuuri	doc_582053207523_item	2741923	et	4	main
õppekavas	doc_582053207523_item	2741929	et	3	main
rahakupüüridel	doc_582053207523_item	2741942	et	3	main
selline	doc_582053207523_item	2741945	et	4	main
andsid	doc_582053207523_item	2741956	et	4	main
ja	doc_582053207523_item	2741959	et	3	main
küsimust	doc_582053207523_item	2741970	et	4	main
küsides	doc_582053207523_item	2741971	et	3	main
teadmised	doc_582053207523_item	2741987	et	4	main
kultuurist	doc_582053207523_item	2741988	et	3	main
on	doc_582053207523_item	2741989	et	4	main
madalal	doc_582053207523_item	2741990	et	4	main
laulupidu	doc_582053207523_item	2741999	et	4	main
uue	doc_582053207523_item	2742014	et	3	main
õppekava	doc_582053207523_item	2742015	et	4	main
teavadkõige	doc_582053207523_item	2741725	et	4	main
jõulud	doc_582053207523_item	2741728	et	3	main
küsimus	doc_582053207523_item	2741733	et	4	main
kõlas	doc_582053207523_item	2741734	et	4	main
nii	doc_582053207523_item	2741735	et	3	main
milliseid	doc_582053207523_item	2741736	et	3	main
olidjõulud	doc_582053207523_item	2741742	et	4	main
kadripäevperedes	doc_582053207523_item	2741746	et	3	main
põhjalikud	doc_582053207523_item	2741754	et	3	main
tähistamine	doc_582053207523_item	2741765	et	4	main
ja	doc_582053207523_item	2741766	et	3	main
näidatakse	doc_582053207523_item	2741767	et	3	main
traditsioonid	doc_582053207523_item	2741768	et	3	main
küsimuses	doc_582053207523_item	2741770	et	4	main
eesti	doc_582053207523_item	2741774	et	4	main
ja	doc_582053207523_item	2741778	et	3	main
kõige	doc_582053207523_item	2741779	et	4	main
rohkem	doc_582053207523_item	2741780	et	4	main
nimetati	doc_582053207523_item	2741781	et	4	main
eno	doc_582053207523_item	2741782	et	4	main
rauda	doc_582053207523_item	2741783	et	4	main
see	doc_582053207523_item	2741784	et	3	main
oli	doc_582053207523_item	2741785	et	3	main
kuidagi	doc_582053207523_item	2741786	et	3	main
imelik	doc_582053207523_item	2741787	et	3	main
kuna	doc_582053207523_item	2741788	et	3	main
see	doc_582053207523_item	2741789	et	3	main
kirjanik	doc_582053207523_item	2741790	et	3	main
kirjutas	doc_582053207523_item	2741791	et	3	main
peamiselt	doc_582053207523_item	2741792	et	4	main
väikestele	doc_582053207523_item	2741793	et	4	main
lasteleoli	doc_582053207523_item	2741794	et	4	main
ka	doc_582053207523_item	2741796	et	3	main
mainitud	doc_582053207523_item	2741795	et	4	main
ellen	doc_582053207523_item	2741797	et	4	main
niit	doc_582053207523_item	2741798	et	4	main
paar	doc_582053207523_item	2741799	et	3	main
inimest	doc_582053207523_item	2741800	et	3	main
rudolph	doc_582053207523_item	2741818	et	4	main
üks	doc_582053207523_item	2741825	et	3	main
teiste	doc_582053207523_item	2741837	et	4	main
oli	doc_582053207523_item	2741842	et	3	main
ei	doc_582053207523_item	2741851	et	4	main
tuntumad	doc_582053207523_item	2741859	et	4	main
õpilased99	doc_582053207523_item	2741863	et	3	main
ainult	doc_582053207523_item	2741898	et	4	main
õpilane	doc_582053207523_item	2741900	et	3	main
näitlejaid	doc_582053207523_item	2741902	et	4	main
ei	doc_582053207523_item	2741903	et	4	main
näitavad	doc_582053207523_item	2741909	et	4	main
kui	doc_582053207523_item	2741910	et	3	main
viletsad	doc_582053207523_item	2741911	et	3	main
on	doc_582053207523_item	2741912	et	4	main
kuna	doc_582053207523_item	2741920	et	3	main
on	doc_582053207523_item	2741922	et	4	main
tõestab	doc_582053207523_item	2741927	et	3	main
eesti	doc_582053207523_item	2741941	et	4	main
oli	doc_582053207523_item	2741944	et	3	main
õpilast	doc_582053207523_item	2741948	et	4	main
ole	doc_582053207523_item	2741950	et	4	main
midagi	doc_582053207523_item	2741951	et	4	main
15	doc_582053207523_item	2741955	et	2	main
täieliku	doc_582053207523_item	2741957	et	3	main
vastuskalevipoegsellist	doc_582053207523_item	2741969	et	4	main
et	doc_582053207523_item	2741975	et	3	main
teksti	doc_582053207523_item	2741979	et	4	main
analüüsides	doc_582053207523_item	2741980	et	4	main
ma	doc_582053207523_item	2741981	et	3	main
sain	doc_582053207523_item	2741982	et	3	main
teada	doc_582053207523_item	2741983	et	3	main
et	doc_582053207523_item	2741984	et	3	main
et	doc_582053207523_item	2741985	et	3	main
õpilaste	doc_582053207523_item	2741986	et	4	main
tasemelnõrgad	doc_582053207523_item	2741991	et	4	main
lavastused	doc_582053207523_item	2741995	et	4	main
näitlejad	doc_582053207523_item	2741996	et	4	main
vanasõnad	doc_582053207523_item	2742005	et	3	main
muistendid	doc_582053207523_item	2742006	et	3	main
tarkused	doc_582053207523_item	2742007	et	4	main
tuleb	doc_582053207523_item	2742010	et	3	main
vesteldes	doc_582053207523_item	2742017	et	3	main
rohkem	doc_582053207523_item	2742022	et	4	main
just	doc_582053207523_item	2742028	et	3	main
mis	doc_582053207523_item	2742031	et	4	main
pakkunud	doc_582053207523_item	2742033	et	4	main
sealolev	doc_582053207523_item	2742039	et	3	main
mainisid	doc_582053207523_item	2742047	et	4	main
rohkem	doc_582053207523_item	2742057	et	4	main
11	doc_582053207523_item	2742061	et	2	main
anonüümnetestis	doc_582053207523_item	2742070	et	4	main
osalesid	doc_582053207523_item	2742071	et	4	main
vastupiditestisse	doc_582053207523_item	2742101	et	3	main
ma	doc_582053207523_item	2742102	et	3	main
lisasin	doc_582053207523_item	2742103	et	3	main
oli	doc_582053207523_item	2742109	et	3	main
rahvuslindulilli-kivekokku	doc_582053207523_item	2742117	et	4	main
kirjutasid	doc_582053207523_item	2742122	et	4	main
on	doc_582053207523_item	2742130	et	4	main
sümbolid	doc_582053207523_item	2742136	et	3	main
oli	doc_582053207523_item	2742139	et	3	main
suurenenudteine	doc_582053207523_item	2742142	et	4	main
2	doc_582053207523_item	2742152	et	2	main
võrreldes	doc_582053207523_item	2742154	et	3	main
oskajate	doc_582053207523_item	2742158	et	4	main
arv	doc_582053207523_item	2742159	et	3	main
suurendas	doc_582053207523_item	2742160	et	3	main
olid	doc_582053207523_item	2742176	et	4	main
eesti	doc_582053207523_item	2742177	et	4	main
need	doc_582053207523_item	2742211	et	3	main
teadmised	doc_582053207523_item	2742219	et	4	main
on	doc_582053207523_item	2742220	et	4	main
30st	doc_582053207523_item	2742224	et	3	main
tartus	doc_582053207523_item	2742245	et	3	main
vastanute	doc_582053207523_item	2742250	et	4	main
eesti	doc_582053207523_item	2742260	et	4	main
raskusi	doc_582053207523_item	2742276	et	4	main
nimetatud	doc_582053207523_item	2742283	et	4	main
ja	doc_582053207523_item	2742287	et	3	main
16	doc_582053207523_item	2742290	et	2	main
see	doc_582053207523_item	2741822	et	3	main
kirjandeidvõrreldes	doc_582053207523_item	2741836	et	4	main
palju	doc_582053207523_item	2741844	et	4	main
aga	doc_582053207523_item	2741845	et	3	main
leidus	doc_582053207523_item	2741847	et	4	main
õpilast	doc_582053207523_item	2741849	et	4	main
küsimuseks	doc_582053207523_item	2741855	et	4	main
oli	doc_582053207523_item	2741856	et	3	main
nimetada	doc_582053207523_item	2741857	et	3	main
näitlejad	doc_582053207523_item	2741861	et	4	main
tuntumaidteater	doc_582053207523_item	2741871	et	4	main
estonia	doc_582053207523_item	2741872	et	4	main
ja	doc_582053207523_item	2741873	et	3	main
vene	doc_582053207523_item	2741874	et	4	main
teater	doc_582053207523_item	2741875	et	3	main
näiteks	doc_582053207523_item	2741876	et	4	main
vanalinnastuudiost	doc_582053207523_item	2741877	et	3	main
ei	doc_582053207523_item	2741878	et	4	main
ole	doc_582053207523_item	2741879	et	4	main
juttugi	doc_582053207523_item	2741880	et	4	main
ainult	doc_582053207523_item	2741881	et	4	main
üks	doc_582053207523_item	2741882	et	3	main
õpilane	doc_582053207523_item	2741883	et	3	main
nimetas	doc_582053207523_item	2741884	et	3	main
vanemuineteatri	doc_582053207523_item	2741885	et	4	main
hulka	doc_582053207523_item	2741886	et	4	main
ka	doc_582053207523_item	2741887	et	3	main
õpilaste	doc_582053207523_item	2741888	et	4	main
arvates	doc_582053207523_item	2741889	et	4	main
kuulusid	doc_582053207523_item	2741890	et	4	main
coca-cola	doc_582053207523_item	2741891	et	4	main
plaza	doc_582053207523_item	2741892	et	4	main
kino	doc_582053207523_item	2741893	et	4	main
kosmos	doc_582053207523_item	2741894	et	3	main
ja	doc_582053207523_item	2741895	et	3	main
sõpruslavastusi	doc_582053207523_item	2741896	et	3	main
teadis	doc_582053207523_item	2741897	et	4	main
32st	doc_582053207523_item	2741901	et	3	main
tulemused	doc_582053207523_item	2741908	et	3	main
teatrielust	doc_582053207523_item	2741916	et	3	main
seega	doc_582053207523_item	2741917	et	4	main
ka	doc_582053207523_item	2741918	et	3	main
kultuurist	doc_582053207523_item	2741919	et	3	main
lahendamata	doc_582053207523_item	2741924	et	4	main
osasee	doc_582053207523_item	2741925	et	4	main
kultuuriõppimiseksviimane	doc_582053207523_item	2741935	et	3	main
kõlas	doc_582053207523_item	2741937	et	4	main
on	doc_582053207523_item	2741940	et	4	main
et	doc_582053207523_item	2741946	et	3	main
pool	doc_582053207523_item	2741953	et	4	main
4	doc_582053207523_item	2741960	et	2	main
ainult	doc_582053207523_item	2741962	et	4	main
ma	doc_582053207523_item	2741972	et	3	main
saan	doc_582053207523_item	2741976	et	4	main
vastused	doc_582053207523_item	2741978	et	3	main
kirjanduseesti	doc_582053207523_item	2741997	et	4	main
kirjanikud	doc_582053207523_item	2741998	et	3	main
rahvuslaulud-sellele	doc_582053207523_item	2742008	et	4	main
rohkem	doc_582053207523_item	2742011	et	4	main
tahaksid	doc_582053207523_item	2742021	et	4	main
teada	doc_582053207523_item	2742023	et	3	main
tetritest	doc_582053207523_item	2742024	et	4	main
muuseumidest	doc_582053207523_item	2742025	et	3	main
kirjanikest	doc_582053207523_item	2742026	et	3	main
rahvapärimuse	doc_582053207523_item	2742051	et	3	main
õpetamisele	doc_582053207523_item	2742052	et	4	main
tähelepanu	doc_582053207523_item	2742056	et	4	main
test	doc_582053207523_item	2742067	et	3	main
30	doc_582053207523_item	2742073	et	2	main
arenenud	doc_582053207523_item	2742098	et	4	main
või	doc_582053207523_item	2742099	et	4	main
hoopiski	doc_582053207523_item	2742100	et	3	main
küsimust	doc_582053207523_item	2742106	et	4	main
eesti	doc_582053207523_item	2742116	et	4	main
eesti	doc_582053207523_item	2742123	et	4	main
hümniõpilastel	doc_582053207523_item	2742126	et	4	main
ei	doc_582053207523_item	2742127	et	4	main
ole	doc_582053207523_item	2742128	et	4	main
on	doc_582053207523_item	2742134	et	4	main
7klassiga	doc_582053207523_item	2742138	et	3	main
õigesti	doc_582053207523_item	2742149	et	3	main
seega	doc_582053207523_item	2742153	et	4	main
7klassiga	doc_582053207523_item	2742155	et	3	main
ühe	doc_582053207523_item	2742162	et	4	main
inimese	doc_582053207523_item	2742163	et	4	main
võrra	doc_582053207523_item	2742164	et	3	main
aga	doc_582053207523_item	2742168	et	3	main
sõnadeautor	doc_582053207523_item	2742170	et	3	main
johann	doc_582053207523_item	2742172	et	4	main
voldemar	doc_582053207523_item	2742173	et	4	main
rahvuslillest	doc_582053207523_item	2742180	et	4	main
sellele	doc_582053207523_item	2742181	et	4	main
peavad	doc_582053207523_item	2742207	et	4	main
kõik	doc_582053207523_item	2742209	et	4	main
on	doc_582053207523_item	2742212	et	4	main
baasteadmised	doc_582053207523_item	2742213	et	3	main
kultuuristseitsmes	doc_582053207523_item	2742214	et	4	main
veelkord	doc_582053207523_item	2741926	et	3	main
väga	doc_582053207523_item	2741931	et	3	main
aega	doc_582053207523_item	2741933	et	4	main
küsimus	doc_582053207523_item	2741936	et	4	main
niimillised	doc_582053207523_item	2741938	et	4	main
kultuuritegelased	doc_582053207523_item	2741939	et	3	main
15	doc_582053207523_item	2741947	et	2	main
ei	doc_582053207523_item	2741949	et	4	main
küsitletust	doc_582053207523_item	2741954	et	4	main
ülevaade	doc_582053207523_item	2741958	et	3	main
mainisid	doc_582053207523_item	2741961	et	4	main
koidulat	doc_582053207523_item	2741964	et	4	main
oli	doc_582053207523_item	2741965	et	3	main
ka	doc_582053207523_item	2741966	et	3	main
üks	doc_582053207523_item	2741967	et	3	main
originaalne	doc_582053207523_item	2741968	et	3	main
kindel	doc_582053207523_item	2741974	et	3	main
konkreetsed	doc_582053207523_item	2741977	et	3	main
kohad	doc_582053207523_item	2741992	et	4	main
traditsioonid	doc_582053207523_item	2742003	et	3	main
eesti	doc_582053207523_item	2742004	et	4	main
koostamiselõpilastega	doc_582053207523_item	2742016	et	4	main
selgus	doc_582053207523_item	2742018	et	4	main
et	doc_582053207523_item	2742019	et	3	main
nad	doc_582053207523_item	2742020	et	3	main
onteater	doc_582053207523_item	2741994	et	4	main
ja	doc_582053207523_item	2742000	et	3	main
sellega	doc_582053207523_item	2742001	et	3	main
seonduvad	doc_582053207523_item	2742002	et	4	main
kõigile	doc_582053207523_item	2742009	et	4	main
tähelepanu	doc_582053207523_item	2742012	et	4	main
pöörata	doc_582053207523_item	2742013	et	4	main
20	doc_582053207523_item	2742029	et	2	main
raskelt	doc_582053207523_item	2742043	et	4	main
arusaadav	doc_582053207523_item	2742044	et	4	main
et	doc_582053207523_item	2742048	et	3	main
tegeldakse	doc_582053207523_item	2742058	et	3	main
keelestruktuuridega	doc_582053207523_item	2742059	et	3	main
klassi	doc_582053207523_item	2742062	et	4	main
testianalüüs	doc_582053207523_item	2742063	et	3	main
selles	doc_582053207523_item	2742064	et	4	main
klassis	doc_582053207523_item	2742065	et	3	main
korraldatav	doc_582053207523_item	2742066	et	4	main
10	doc_582053207523_item	2742105	et	2	main
küsimuseks	doc_582053207523_item	2742108	et	4	main
nimetada	doc_582053207523_item	2742110	et	3	main
selgemis	doc_582053207523_item	2742129	et	4	main
riigi	doc_582053207523_item	2742135	et	3	main
vastajate	doc_582053207523_item	2742140	et	4	main
hümni	doc_582053207523_item	2742146	et	4	main
sõnadeautori	doc_582053207523_item	2742147	et	3	main
ja	doc_582053207523_item	2742148	et	3	main
ainult	doc_582053207523_item	2742161	et	4	main
olid	doc_582053207523_item	2742167	et	4	main
jannsenjärgmised	doc_582053207523_item	2742174	et	4	main
küsimused	doc_582053207523_item	2742175	et	4	main
teadma	doc_582053207523_item	2742208	et	3	main
kuna	doc_582053207523_item	2742210	et	3	main
võrreldes	doc_582053207523_item	2742218	et	3	main
paranenud	doc_582053207523_item	2742222	et	4	main
vastasid	doc_582053207523_item	2742240	et	4	main
et	doc_582053207523_item	2742241	et	3	main
õigesti	doc_582053207523_item	2742249	et	3	main
et	doc_582053207523_item	2742255	et	3	main
on	doc_582053207523_item	2742257	et	4	main
35-tunniline	doc_582053207523_item	2742258	et	4	main
kursus	doc_582053207523_item	2742259	et	3	main
kõik	doc_582053207523_item	2742272	et	4	main
olukord	doc_582053207523_item	2742278	et	3	main
on	doc_582053207523_item	2742281	et	4	main
õigesti	doc_582053207523_item	2742288	et	3	main
õpilast14	doc_582053207523_item	2742291	et	4	main
olnud	doc_582053207523_item	2742293	et	4	main
laulme	doc_582053207523_item	2742304	et	4	main
et	doc_582053207523_item	2742311	et	3	main
piir	doc_582053207523_item	2742315	et	3	main
ei	doc_582053207523_item	2742324	et	4	main
oli	doc_582053207523_item	2742330	et	3	main
eesti	doc_582053207523_item	2742333	et	4	main
muistsete	doc_582053207523_item	2742334	et	3	main
jumalate	doc_582053207523_item	2742335	et	3	main
klassst16	doc_582053207523_item	2742342	et	4	main
varianteaga	doc_582053207523_item	2742351	et	4	main
küsimuse	doc_582053207523_item	2742355	et	4	main
nimetada	doc_582053207523_item	2742358	et	3	main
vanasõnu	doc_582053207523_item	2742360	et	3	main
ole	doc_582053207523_item	2742369	et	4	main
palju	doc_582053207523_item	2742376	et	4	main
ei	doc_582053207523_item	2742032	et	4	main
keel	doc_582053207523_item	2742040	et	4	main
on	doc_582053207523_item	2742041	et	4	main
väga	doc_582053207523_item	2742042	et	3	main
nad	doc_582053207523_item	2742046	et	3	main
nende	doc_582053207523_item	2742049	et	4	main
on	doc_582053207523_item	2742053	et	4	main
pööratud	doc_582053207523_item	2742054	et	4	main
vähe	doc_582053207523_item	2742055	et	3	main
samuti	doc_582053207523_item	2742069	et	3	main
oli	doc_582053207523_item	2742075	et	3	main
28	doc_582053207523_item	2742076	et	2	main
esimesed	doc_582053207523_item	2742077	et	3	main
18	doc_582053207523_item	2742078	et	2	main
olid	doc_582053207523_item	2742079	et	4	main
õpilastküsimusi	doc_582053207523_item	2742074	et	4	main
samas	doc_582053207523_item	2742080	et	4	main
nagu	doc_582053207523_item	2742081	et	3	main
7klassi	doc_582053207523_item	2742082	et	4	main
testis	doc_582053207523_item	2742083	et	4	main
niimodi	doc_582053207523_item	2742084	et	4	main
ma	doc_582053207523_item	2742085	et	3	main
tegin	doc_582053207523_item	2742086	et	3	main
sellepärast	doc_582053207523_item	2742087	et	3	main
et	doc_582053207523_item	2742088	et	3	main
tahtsin	doc_582053207523_item	2742089	et	3	main
kontrollida	doc_582053207523_item	2742090	et	4	main
ja	doc_582053207523_item	2742091	et	3	main
võrrelda	doc_582053207523_item	2742092	et	4	main
kuivõrd	doc_582053207523_item	2742094	et	3	main
nad	doc_582053207523_item	2742095	et	3	main
teadmisi	doc_582053207523_item	2742093	et	4	main
on	doc_582053207523_item	2742096	et	4	main
paranenud	doc_582053207523_item	2742097	et	4	main
kirjandusest	doc_582053207523_item	2742027	et	4	main
sajandisee	doc_582053207523_item	2742030	et	4	main
huvi	doc_582053207523_item	2742034	et	4	main
neile	doc_582053207523_item	2742035	et	4	main
olid	doc_582053207523_item	2742036	et	4	main
rahvuslaulud	doc_582053207523_item	2742037	et	3	main
kuna	doc_582053207523_item	2742038	et	3	main
samas	doc_582053207523_item	2742045	et	4	main
arvates	doc_582053207523_item	2742050	et	4	main
22	doc_582053207523_item	2742060	et	2	main
oli	doc_582053207523_item	2742068	et	3	main
kokku	doc_582053207523_item	2742072	et	3	main
juurde	doc_582053207523_item	2742104	et	4	main
esimeseks	doc_582053207523_item	2742107	et	3	main
eesti	doc_582053207523_item	2742111	et	4	main
riigisümboleid	doc_582053207523_item	2742112	et	3	main
palju	doc_582053207523_item	2742113	et	4	main
õpilased	doc_582053207523_item	2742114	et	3	main
nimetasid	doc_582053207523_item	2742115	et	4	main
vastasid	doc_582053207523_item	2742120	et	4	main
16ainult	doc_582053207523_item	2742118	et	4	main
14	doc_582053207523_item	2742119	et	2	main
vapulippu	doc_582053207523_item	2742124	et	4	main
võrreldes	doc_582053207523_item	2742137	et	3	main
vastajaid	doc_582053207523_item	2742150	et	4	main
rahvuslinnust	doc_582053207523_item	2742178	et	4	main
vastuseid	doc_582053207523_item	2742206	et	3	main
laulupeost7klassiga	doc_582053207523_item	2742217	et	4	main
õpilast	doc_582053207523_item	2742225	et	4	main
aasta	doc_582053207523_item	2742228	et	4	main
kirjutasid	doc_582053207523_item	2742230	et	4	main
õigesti	doc_582053207523_item	2742231	et	3	main
et	doc_582053207523_item	2742232	et	3	main
see	doc_582053207523_item	2742233	et	3	main
toimub	doc_582053207523_item	2742234	et	3	main
5	doc_582053207523_item	2742236	et	2	main
aastat	doc_582053207523_item	2742237	et	3	main
ja	doc_582053207523_item	2742238	et	3	main
laulupidu	doc_582053207523_item	2742243	et	4	main
ma	doc_582053207523_item	2742246	et	3	main
et	doc_582053207523_item	2742248	et	3	main
suurenes	doc_582053207523_item	2742252	et	4	main
sellepärast	doc_582053207523_item	2742254	et	3	main
kultuuristjärgmisele	doc_582053207523_item	2742261	et	4	main
küsimusele	doc_582053207523_item	2742262	et	4	main
iseseisvuspäevast	doc_582053207523_item	2742263	et	4	main
õigestirahvuslauludega	doc_582053207523_item	2742273	et	4	main
võrreldes	doc_582053207523_item	2742279	et	3	main
palju	doc_582053207523_item	2742284	et	4	main
variante	doc_582053207523_item	2742286	et	3	main
ei	doc_582053207523_item	2742306	et	4	main
õpilastel	doc_582053207523_item	2742312	et	4	main
selge	doc_582053207523_item	2742314	et	4	main
ja	doc_582053207523_item	2742317	et	3	main
hümni	doc_582053207523_item	2742319	et	4	main
nimelt	doc_582053207523_item	2742321	et	4	main
ole	doc_582053207523_item	2742325	et	4	main
vastanuid	doc_582053207523_item	2742337	et	4	main
oli	doc_582053207523_item	2742338	et	3	main
rohkem	doc_582053207523_item	2742339	et	4	main
kui	doc_582053207523_item	2742340	et	3	main
pakusid	doc_582053207523_item	2742349	et	4	main
ülesanne	doc_582053207523_item	2742356	et	4	main
eesti	doc_582053207523_item	2742359	et	4	main
selle	doc_582053207523_item	2742361	et	4	main
kirjutanud	doc_582053207523_item	2742371	et	4	main
võrreldes	doc_582053207523_item	2742372	et	3	main
7klassiga	doc_582053207523_item	2742373	et	3	main
juurde	doc_582053207523_item	2742377	et	4	main
13	doc_582053207523_item	2742412	et	2	main
ei	doc_582053207523_item	2742413	et	4	main
11klassi	doc_582053207523_item	2742420	et	4	main
kui	doc_582053207523_item	2742425	et	3	main
seitsmendal	doc_582053207523_item	2742426	et	3	main
küsimuse	doc_582053207523_item	2742428	et	4	main
rahvakalendri	doc_582053207523_item	2742429	et	3	main
erinevaid	doc_582053207523_item	2742436	et	4	main
olid	doc_582053207523_item	2742453	et	4	main
kohal	doc_582053207523_item	2742460	et	4	main
kirjanikkeainult	doc_582053207523_item	2742468	et	4	main
ei	doc_582053207523_item	2742471	et	4	main
midagi	doc_582053207523_item	2742473	et	4	main
vastusevariante	doc_582053207523_item	2742479	et	4	main
ka	doc_582053207523_item	2742481	et	3	main
on	doc_582053207523_item	2742494	et	4	main
võime	doc_582053207523_item	2742500	et	4	main
näha	doc_582053207523_item	2742501	et	3	main
et	doc_582053207523_item	2742502	et	3	main
tulemused	doc_582053207523_item	2742503	et	3	main
on	doc_582053207523_item	2742504	et	4	main
väga	doc_582053207523_item	2742505	et	3	main
headjärgmises	doc_582053207523_item	2742506	et	3	main
küsimuses	doc_582053207523_item	2742507	et	4	main
oli	doc_582053207523_item	2742508	et	3	main
lavastusioli	doc_582053207523_item	2742515	et	4	main
tallinnas	doc_582053207523_item	2742521	et	4	main
ainult	doc_582053207523_item	2742525	et	4	main
ole	doc_582053207523_item	2742536	et	4	main
eesti	doc_582053207523_item	2742545	et	4	main
aga	doc_582053207523_item	2742552	et	3	main
õigestiseega	doc_582053207523_item	2742121	et	4	main
ja	doc_582053207523_item	2742125	et	3	main
rahvasümbolid	doc_582053207523_item	2742131	et	3	main
ja	doc_582053207523_item	2742132	et	3	main
mis	doc_582053207523_item	2742133	et	4	main
arv	doc_582053207523_item	2742141	et	3	main
küsimus	doc_582053207523_item	2742143	et	4	main
puudutas	doc_582053207523_item	2742144	et	3	main
eesti	doc_582053207523_item	2742145	et	4	main
oli	doc_582053207523_item	2742151	et	3	main
selle	doc_582053207523_item	2742156	et	4	main
küsimuse	doc_582053207523_item	2742157	et	4	main
23	doc_582053207523_item	2742165	et	2	main
õpilast	doc_582053207523_item	2742166	et	4	main
kindladet	doc_582053207523_item	2742169	et	4	main
on	doc_582053207523_item	2742171	et	4	main
ja	doc_582053207523_item	2742179	et	3	main
küsimusele	doc_582053207523_item	2742182	et	4	main
vastasid	doc_582053207523_item	2742183	et	4	main
õigesti	doc_582053207523_item	2742184	et	3	main
peaaegu	doc_582053207523_item	2742185	et	3	main
kõik	doc_582053207523_item	2742186	et	4	main
õpilased	doc_582053207523_item	2742187	et	3	main
2	doc_582053207523_item	2742188	et	2	main
aga	doc_582053207523_item	2742189	et	3	main
pakkusid	doc_582053207523_item	2742190	et	4	main
sinililleeesti	doc_582053207523_item	2742192	et	4	main
rahuslilleks	doc_582053207523_item	2742191	et	4	main
presidenti	doc_582053207523_item	2742193	et	4	main
nimetasid	doc_582053207523_item	2742194	et	4	main
õigesti	doc_582053207523_item	2742195	et	3	main
kõik	doc_582053207523_item	2742196	et	4	main
õpilased	doc_582053207523_item	2742197	et	3	main
samas	doc_582053207523_item	2742198	et	4	main
kõik	doc_582053207523_item	2742199	et	4	main
nimetasid	doc_582053207523_item	2742200	et	4	main
õigesti	doc_582053207523_item	2742201	et	3	main
eesti	doc_582053207523_item	2742202	et	4	main
rahvuspuudaga	doc_582053207523_item	2742203	et	3	main
nendele	doc_582053207523_item	2742204	et	4	main
küsimustele	doc_582053207523_item	2742205	et	4	main
küsimus	doc_582053207523_item	2742215	et	4	main
oli	doc_582053207523_item	2742216	et	3	main
märgatavalt	doc_582053207523_item	2742221	et	4	main
kirjutasid	doc_582053207523_item	2742226	et	4	main
18	doc_582053207523_item	2742229	et	2	main
iga	doc_582053207523_item	2742235	et	4	main
kõik	doc_582053207523_item	2742239	et	4	main
toimus	doc_582053207523_item	2742244	et	3	main
arvan	doc_582053207523_item	2742247	et	3	main
vastasid	doc_582053207523_item	2742264	et	4	main
esinesid	doc_582053207523_item	2742274	et	4	main
ka	doc_582053207523_item	2742275	et	3	main
7klassiga	doc_582053207523_item	2742280	et	3	main
paranenudoli	doc_582053207523_item	2742282	et	4	main
õigeid	doc_582053207523_item	2742285	et	3	main
vastasid	doc_582053207523_item	2742289	et	4	main
nteesti	doc_582053207523_item	2742300	et	4	main
saa	doc_582053207523_item	2742307	et	4	main
mitte	doc_582053207523_item	2742322	et	3	main
hümnijärgmises	doc_582053207523_item	2742328	et	3	main
vaja	doc_582053207523_item	2742331	et	4	main
nimetada	doc_582053207523_item	2742332	et	3	main
nimesidvalesti	doc_582053207523_item	2742336	et	4	main
inimest	doc_582053207523_item	2742343	et	3	main
ning	doc_582053207523_item	2742344	et	3	main
õigesti	doc_582053207523_item	2742345	et	3	main
vastasid	doc_582053207523_item	2742346	et	4	main
14	doc_582053207523_item	2742347	et	2	main
enamus	doc_582053207523_item	2742352	et	4	main
oli	doc_582053207523_item	2742357	et	3	main
ülesannega	doc_582053207523_item	2742362	et	4	main
õpilast60	doc_582053207523_item	2742365	et	4	main
levinum	doc_582053207523_item	2742379	et	4	main
vastanud	doc_582053207523_item	2742415	et	4	main
mitte	doc_582053207523_item	2742416	et	3	main
ühtele	doc_582053207523_item	2742417	et	3	main
küsimusele	doc_582053207523_item	2742418	et	4	main
kõrgem	doc_582053207523_item	2742424	et	4	main
nimetatud	doc_582053207523_item	2742433	et	4	main
populaarsemad	doc_582053207523_item	2742439	et	4	main
ka	doc_582053207523_item	2742444	et	3	main
milliseid	doc_582053207523_item	2742448	et	3	main
jaanipäevsiis	doc_582053207523_item	2742456	et	4	main
jõulud	doc_582053207523_item	2742457	et	3	main
ning	doc_582053207523_item	2742458	et	3	main
kolmandal	doc_582053207523_item	2742459	et	3	main
kadripäevviieteistkümnendal	doc_582053207523_item	2742462	et	4	main
2	doc_582053207523_item	2742469	et	2	main
ülejäänud	doc_582053207523_item	2742475	et	4	main
pakkusid	doc_582053207523_item	2742477	et	4	main
oli	doc_582053207523_item	2742480	et	3	main
et	doc_582053207523_item	2742483	et	3	main
kirjanikke	doc_582053207523_item	2742487	et	3	main
kui	doc_582053207523_item	2742488	et	3	main
ka	doc_582053207523_item	2742489	et	3	main
kaasaegseid	doc_582053207523_item	2742490	et	3	main
kirjanikkekuna	doc_582053207523_item	2742491	et	4	main
selline	doc_582053207523_item	2742492	et	4	main
klassi	doc_582053207523_item	2742496	et	4	main
vaja	doc_582053207523_item	2742509	et	4	main
nimetada	doc_582053207523_item	2742510	et	3	main
tuntumad	doc_582053207523_item	2742511	et	4	main
palju	doc_582053207523_item	2742517	et	4	main
teatreid	doc_582053207523_item	2742518	et	3	main
25	doc_582053207523_item	2742223	et	2	main
õigesti	doc_582053207523_item	2742227	et	3	main
esimene	doc_582053207523_item	2742242	et	3	main
arv	doc_582053207523_item	2742251	et	3	main
ka	doc_582053207523_item	2742253	et	3	main
11klassis	doc_582053207523_item	2742256	et	3	main
kõik	doc_582053207523_item	2742265	et	4	main
õpilased	doc_582053207523_item	2742266	et	3	main
õigesti	doc_582053207523_item	2742267	et	3	main
rahvuseepose	doc_582053207523_item	2742268	et	3	main
nimi	doc_582053207523_item	2742269	et	3	main
kirjutasid	doc_582053207523_item	2742270	et	4	main
ka	doc_582053207523_item	2742271	et	3	main
aga	doc_582053207523_item	2742277	et	3	main
midagi	doc_582053207523_item	2742294	et	4	main
oli	doc_582053207523_item	2742296	et	3	main
ka	doc_582053207523_item	2742297	et	3	main
naljakaid	doc_582053207523_item	2742298	et	4	main
pappi	doc_582053207523_item	2742305	et	4	main
on	doc_582053207523_item	2742313	et	4	main
rahvuslaulude	doc_582053207523_item	2742316	et	3	main
eesti	doc_582053207523_item	2742318	et	4	main
vahel	doc_582053207523_item	2742320	et	4	main
ei	doc_582053207523_item	2742292	et	4	main
kirjutanud	doc_582053207523_item	2742295	et	4	main
vastuseid	doc_582053207523_item	2742299	et	3	main
rahvuslauluks	doc_582053207523_item	2742301	et	4	main
osutus	doc_582053207523_item	2742302	et	4	main
räpp	doc_582053207523_item	2742303	et	3	main
samas	doc_582053207523_item	2742308	et	4	main
tahaks	doc_582053207523_item	2742309	et	3	main
mainida	doc_582053207523_item	2742310	et	3	main
kirjutanud	doc_582053207523_item	2742326	et	4	main
küsimuses	doc_582053207523_item	2742329	et	4	main
pool	doc_582053207523_item	2742341	et	4	main
mitu	doc_582053207523_item	2742350	et	4	main
vanaisajärgmise	doc_582053207523_item	2742354	et	3	main
midagi	doc_582053207523_item	2742370	et	4	main
õppinudkõike	doc_582053207523_item	2742378	et	4	main
vastuse	doc_582053207523_item	2742410	et	3	main
ja	doc_582053207523_item	2742411	et	3	main
seega	doc_582053207523_item	2742419	et	4	main
päeva	doc_582053207523_item	2742430	et	4	main
tundmisest	doc_582053207523_item	2742431	et	4	main
oli	doc_582053207523_item	2742432	et	3	main
jõuludemadepäevmind	doc_582053207523_item	2742442	et	4	main
asi	doc_582053207523_item	2742446	et	4	main
on	doc_582053207523_item	2742455	et	4	main
ole	doc_582053207523_item	2742472	et	4	main
näitlejaid	doc_582053207523_item	2742514	et	4	main
mainisid	doc_582053207523_item	2742524	et	4	main
inimest	doc_582053207523_item	2742527	et	3	main
paranenudveel	doc_582053207523_item	2742538	et	4	main
oli	doc_582053207523_item	2742539	et	3	main
vaja	doc_582053207523_item	2742540	et	4	main
nimetada	doc_582053207523_item	2742541	et	3	main
olid	doc_582053207523_item	2742547	et	4	main
vastuseid	doc_582053207523_item	2742551	et	3	main
nimetasid	doc_582053207523_item	2742568	et	4	main
vähem	doc_582053207523_item	2742575	et	4	main
27	doc_582053207523_item	2742576	et	2	main
esimest	doc_582053207523_item	2742583	et	4	main
mainisid	doc_582053207523_item	2742587	et	4	main
küsinutest15	doc_582053207523_item	2742598	et	4	main
inimest	doc_582053207523_item	2742599	et	3	main
eesti	doc_582053207523_item	2742600	et	4	main
aabitsast	doc_582053207523_item	2742601	et	4	main
ja	doc_582053207523_item	2742602	et	3	main
ei	doc_582053207523_item	2742607	et	4	main
teada	doc_582053207523_item	2742612	et	3	main
eesti	doc_582053207523_item	2742616	et	4	main
midagi	doc_582053207523_item	2742630	et	4	main
raske	doc_582053207523_item	2742635	et	4	main
oli	doc_582053207523_item	2742637	et	3	main
vaja	doc_582053207523_item	2742638	et	4	main
kirjutada	doc_582053207523_item	2742639	et	3	main
oma	doc_582053207523_item	2742640	et	4	main
teadmisi	doc_582053207523_item	2742641	et	4	main
kasettpõlvkonnast	doc_582053207523_item	2742642	et	4	main
vastuseid	doc_582053207523_item	2742643	et	3	main
oli	doc_582053207523_item	2742644	et	3	main
absurdseid	doc_582053207523_item	2742645	et	3	main
aga	doc_582053207523_item	2742646	et	3	main
mitte	doc_582053207523_item	2742647	et	3	main
õpilaste	doc_582053207523_item	2742655	et	4	main
teadmised	doc_582053207523_item	2742698	et	4	main
keskmisest	doc_582053207523_item	2742702	et	3	main
on	doc_582053207523_item	2742709	et	4	main
ning	doc_582053207523_item	2742723	et	3	main
kohad	doc_582053207523_item	2742734	et	4	main
on	doc_582053207523_item	2742735	et	4	main
aga	doc_582053207523_item	2742736	et	3	main
peale	doc_582053207523_item	2742747	et	4	main
testide	doc_582053207523_item	2742748	et	3	main
tulin	doc_582053207523_item	2742754	et	3	main
et	doc_582053207523_item	2742756	et	3	main
eesti	doc_582053207523_item	2742758	et	4	main
õppimiseks	doc_582053207523_item	2742760	et	4	main
määratud	doc_582053207523_item	2742761	et	4	main
aeg	doc_582053207523_item	2742762	et	3	main
on	doc_582053207523_item	2742763	et	4	main
väga	doc_582053207523_item	2742764	et	3	main
piisa	doc_582053207523_item	2742769	et	4	main
õppekavas	doc_582053207523_item	2742770	et	3	main
keegi	doc_582053207523_item	2742323	et	4	main
eesti	doc_582053207523_item	2742327	et	4	main
õpilastnad	doc_582053207523_item	2742348	et	4	main
vastas	doc_582053207523_item	2742353	et	4	main
said	doc_582053207523_item	2742363	et	4	main
hakkama18	doc_582053207523_item	2742364	et	3	main
ning	doc_582053207523_item	2742366	et	3	main
12	doc_582053207523_item	2742367	et	2	main
ei	doc_582053207523_item	2742368	et	4	main
on	doc_582053207523_item	2742374	et	4	main
õpilased	doc_582053207523_item	2742375	et	3	main
vastus	doc_582053207523_item	2742380	et	3	main
oli	doc_582053207523_item	2742381	et	3	main
kes	doc_582053207523_item	2742382	et	4	main
eessee	doc_582053207523_item	2742383	et	4	main
meeskolmeteiskümnendas	doc_582053207523_item	2742384	et	4	main
küsimuses	doc_582053207523_item	2742385	et	4	main
oli	doc_582053207523_item	2742386	et	3	main
vaja	doc_582053207523_item	2742387	et	4	main
antud	doc_582053207523_item	2742388	et	4	main
mõistatusele	doc_582053207523_item	2742389	et	4	main
kirjutada	doc_582053207523_item	2742390	et	3	main
õigeid	doc_582053207523_item	2742391	et	3	main
vastuseidoli	doc_582053207523_item	2742392	et	4	main
kokku	doc_582053207523_item	2742393	et	3	main
3	doc_582053207523_item	2742394	et	2	main
mõistatustoli	doc_582053207523_item	2742395	et	4	main
2	doc_582053207523_item	2742396	et	2	main
õpilastkes	doc_582053207523_item	2742397	et	4	main
on	doc_582053207523_item	2742398	et	4	main
vastanud	doc_582053207523_item	2742399	et	4	main
kõigidele	doc_582053207523_item	2742400	et	4	main
küsimustele	doc_582053207523_item	2742401	et	4	main
8	doc_582053207523_item	2742402	et	2	main
õpilast	doc_582053207523_item	2742403	et	4	main
vastasid	doc_582053207523_item	2742404	et	4	main
kahele	doc_582053207523_item	2742405	et	4	main
mõistatusele	doc_582053207523_item	2742406	et	4	main
7	doc_582053207523_item	2742407	et	2	main
kirjutasid	doc_582053207523_item	2742408	et	4	main
ühe	doc_582053207523_item	2742409	et	4	main
ole	doc_582053207523_item	2742414	et	4	main
teadmisteskaal	doc_582053207523_item	2742421	et	4	main
palju	doc_582053207523_item	2742423	et	4	main
klassiljärgmise	doc_582053207523_item	2742427	et	4	main
päevi	doc_582053207523_item	2742437	et	4	main
kõige	doc_582053207523_item	2742438	et	4	main
huvitas	doc_582053207523_item	2742443	et	3	main
sellisedesimene	doc_582053207523_item	2742454	et	4	main
mardi-ja	doc_582053207523_item	2742461	et	3	main
küsimusel	doc_582053207523_item	2742463	et	4	main
oli	doc_582053207523_item	2742464	et	3	main
vaja	doc_582053207523_item	2742465	et	4	main
vastanus	doc_582053207523_item	2742474	et	4	main
erinevaid	doc_582053207523_item	2742478	et	4	main
teema	doc_582053207523_item	2742493	et	4	main
spetsiaalses	doc_582053207523_item	2742497	et	3	main
me	doc_582053207523_item	2742499	et	4	main
eesti	doc_582053207523_item	2742512	et	4	main
teatreid	doc_582053207523_item	2742513	et	3	main
kirjutasid	doc_582053207523_item	2742530	et	4	main
eriti	doc_582053207523_item	2742537	et	3	main
rahakupüüridel	doc_582053207523_item	2742546	et	3	main
konkreetsed	doc_582053207523_item	2742550	et	3	main
kirjutanudjärgnevas	doc_582053207523_item	2742557	et	4	main
küsimuses	doc_582053207523_item	2742558	et	4	main
tema	doc_582053207523_item	2742569	et	4	main
eluaastaidlydia	doc_582053207523_item	2742570	et	4	main
koidulast	doc_582053207523_item	2742571	et	4	main
strahvatansu	doc_582053207523_item	2742578	et	4	main
teadsid	doc_582053207523_item	2742579	et	4	main
18	doc_582053207523_item	2742580	et	2	main
eesti	doc_582053207523_item	2742584	et	4	main
õpilast	doc_582053207523_item	2742589	et	4	main
eesti	doc_582053207523_item	2742591	et	4	main
pool	doc_582053207523_item	2742597	et	4	main
koostajast	doc_582053207523_item	2742604	et	4	main
ole	doc_582053207523_item	2742608	et	4	main
ma	doc_582053207523_item	2742610	et	3	main
tahtsin	doc_582053207523_item	2742611	et	3	main
et	doc_582053207523_item	2742613	et	3	main
õpilased	doc_582053207523_item	2742618	et	3	main
on	doc_582053207523_item	2742422	et	4	main
hästi	doc_582053207523_item	2742434	et	3	main
palju	doc_582053207523_item	2742435	et	4	main
olid	doc_582053207523_item	2742440	et	4	main
jaanipäev	doc_582053207523_item	2742441	et	3	main
selline	doc_582053207523_item	2742445	et	4	main
et	doc_582053207523_item	2742447	et	3	main
päevi	doc_582053207523_item	2742449	et	4	main
õpilased	doc_582053207523_item	2742450	et	3	main
tähistavad	doc_582053207523_item	2742451	et	4	main
vastused	doc_582053207523_item	2742452	et	3	main
nimetada	doc_582053207523_item	2742466	et	3	main
eesti	doc_582053207523_item	2742467	et	4	main
õpilast	doc_582053207523_item	2742470	et	4	main
28	doc_582053207523_item	2742476	et	2	main
mõnus	doc_582053207523_item	2742482	et	4	main
nimetati	doc_582053207523_item	2742484	et	4	main
nii	doc_582053207523_item	2742485	et	3	main
19sajandi	doc_582053207523_item	2742486	et	3	main
11	doc_582053207523_item	2742495	et	2	main
kultuuriprogrammis	doc_582053207523_item	2742498	et	3	main
mainitud	doc_582053207523_item	2742516	et	4	main
aga	doc_582053207523_item	2742519	et	3	main
peamiselt	doc_582053207523_item	2742520	et	4	main
näitlejäid	doc_582053207523_item	2742523	et	4	main
ning	doc_582053207523_item	2742528	et	3	main
6	doc_582053207523_item	2742531	et	2	main
inimest	doc_582053207523_item	2742532	et	3	main
seega	doc_582053207523_item	2742533	et	4	main
kes	doc_582053207523_item	2742543	et	4	main
on	doc_582053207523_item	2742544	et	4	main
palju	doc_582053207523_item	2742549	et	4	main
õpilast	doc_582053207523_item	2742554	et	4	main
kohta	doc_582053207523_item	2742560	et	4	main
olid	doc_582053207523_item	2742561	et	4	main
kõik	doc_582053207523_item	2742562	et	4	main
õiged	doc_582053207523_item	2742563	et	3	main
vastused	doc_582053207523_item	2742564	et	3	main
mõned	doc_582053207523_item	2742565	et	3	main
aga	doc_582053207523_item	2742566	et	3	main
isegi	doc_582053207523_item	2742567	et	4	main
30	doc_582053207523_item	2742577	et	2	main
nimetasid	doc_582053207523_item	2742594	et	4	main
õigesti	doc_582053207523_item	2742595	et	3	main
vaid	doc_582053207523_item	2742596	et	3	main
selle	doc_582053207523_item	2742603	et	4	main
küsimus	doc_582053207523_item	2742632	et	4	main
nimelt	doc_582053207523_item	2742636	et	4	main
ei	doc_582053207523_item	2742650	et	4	main
eesti	doc_582053207523_item	2742657	et	4	main
filmidest	doc_582053207523_item	2742658	et	3	main
teadmisi	doc_582053207523_item	2742678	et	4	main
tollast	doc_582053207523_item	2742679	et	3	main
ajast	doc_582053207523_item	2742680	et	4	main
tulemused	doc_582053207523_item	2742681	et	3	main
kirjutanud16	doc_582053207523_item	2742687	et	4	main
kuupäeva	doc_582053207523_item	2742690	et	4	main
ja	doc_582053207523_item	2742691	et	3	main
ainult	doc_582053207523_item	2742692	et	4	main
üldiselt	doc_582053207523_item	2742696	et	4	main
kultuuriloost	doc_582053207523_item	2742699	et	4	main
st	doc_582053207523_item	2742712	et	3	main
keeleõppimisele	doc_582053207523_item	2742713	et	3	main
on	doc_582053207523_item	2742717	et	4	main
aabits	doc_582053207523_item	2742722	et	3	main
eesti	doc_582053207523_item	2742732	et	4	main
kirjanduskasettpõlvkondtugevad	doc_582053207523_item	2742733	et	4	main
eesti	doc_582053207523_item	2742744	et	4	main
tantsust	doc_582053207523_item	2742745	et	3	main
kokkuvõte	doc_582053207523_item	2742746	et	3	main
ma	doc_582053207523_item	2742753	et	3	main
lühike	doc_582053207523_item	2742765	et	4	main
tunde	doc_582053207523_item	2742771	et	4	main
videomaterjali	doc_582053207523_item	2742782	et	4	main
õpilastele	doc_582053207523_item	2742789	et	4	main
mitmesugusid	doc_582053207523_item	2742821	et	3	main
aru	doc_582053207523_item	2742831	et	4	main
riigiõppekava	doc_582053207523_item	2742838	et	4	main
aega	doc_582053207523_item	2742841	et	4	main
asuvaid	doc_582053207523_item	2742522	et	4	main
6	doc_582053207523_item	2742526	et	2	main
lavastusi	doc_582053207523_item	2742529	et	4	main
teatriteadmised	doc_582053207523_item	2742534	et	3	main
ei	doc_582053207523_item	2742535	et	4	main
kultuuritegelasi	doc_582053207523_item	2742542	et	3	main
päris	doc_582053207523_item	2742548	et	4	main
7	doc_582053207523_item	2742553	et	2	main
pole	doc_582053207523_item	2742555	et	3	main
vastajaid	doc_582053207523_item	2742574	et	4	main
ajalehe	doc_582053207523_item	2742585	et	3	main
nime	doc_582053207523_item	2742586	et	4	main
24	doc_582053207523_item	2742588	et	2	main
rahvusärkamisaega	doc_582053207523_item	2742592	et	4	main
algust	doc_582053207523_item	2742593	et	4	main
mitte	doc_582053207523_item	2742605	et	3	main
oskavad	doc_582053207523_item	2742619	et	4	main
nimetada	doc_582053207523_item	2742620	et	3	main
erinevaid	doc_582053207523_item	2742623	et	4	main
16	doc_582053207523_item	2742625	et	2	main
ei	doc_582053207523_item	2742627	et	4	main
ole	doc_582053207523_item	2742628	et	4	main
mitte	doc_582053207523_item	2742629	et	3	main
23	doc_582053207523_item	2742659	et	2	main
õpilast76	doc_582053207523_item	2742660	et	4	main
oma	doc_582053207523_item	2742677	et	4	main
olid	doc_582053207523_item	2742682	et	4	main
järgmised13	doc_582053207523_item	2742683	et	3	main
kirjutasid	doc_582053207523_item	2742688	et	4	main
4	doc_582053207523_item	2742693	et	2	main
tähelepanu	doc_582053207523_item	2742708	et	4	main
kohad	doc_582053207523_item	2742715	et	4	main
esimene	doc_582053207523_item	2742721	et	3	main
eesti	doc_582053207523_item	2742737	et	4	main
vastamineteadmised	doc_582053207523_item	2742740	et	4	main
arvates	doc_582053207523_item	2742767	et	4	main
ei	doc_582053207523_item	2742768	et	4	main
et	doc_582053207523_item	2742773	et	3	main
ei	doc_582053207523_item	2742777	et	4	main
ole	doc_582053207523_item	2742778	et	4	main
näidata	doc_582053207523_item	2742785	et	4	main
ja	doc_582053207523_item	2742786	et	3	main
selleks	doc_582053207523_item	2742826	et	4	main
et	doc_582053207523_item	2742827	et	3	main
järgi	doc_582053207523_item	2742839	et	4	main
pole	doc_582053207523_item	2742840	et	3	main
õppimiseks	doc_582053207523_item	2742845	et	4	main
me	doc_582053207523_item	2742847	et	4	main
saame	doc_582053207523_item	2742848	et	4	main
klassis	doc_582053207523_item	2742877	et	3	main
klassi	doc_582053207523_item	2742889	et	4	main
ajalootunnid	doc_582053207523_item	2742890	et	3	main
süstemmatiliselt	doc_582053207523_item	2742907	et	4	main
omandasid	doc_582053207523_item	2742914	et	4	main
midagi	doc_582053207523_item	2742556	et	4	main
kreutzwaldi	doc_582053207523_item	2742559	et	4	main
olid	doc_582053207523_item	2742572	et	4	main
õigesti	doc_582053207523_item	2742573	et	3	main
õpilast	doc_582053207523_item	2742581	et	4	main
60	doc_582053207523_item	2742582	et	2	main
ning	doc_582053207523_item	2742590	et	3	main
keegi	doc_582053207523_item	2742606	et	4	main
nimetanudsamas	doc_582053207523_item	2742609	et	4	main
milliseid	doc_582053207523_item	2742614	et	3	main
kaasaegseid	doc_582053207523_item	2742615	et	3	main
kirjanikke	doc_582053207523_item	2742617	et	3	main
pakkusid	doc_582053207523_item	2742622	et	4	main
suhteliselt	doc_582053207523_item	2742634	et	4	main
ole	doc_582053207523_item	2742651	et	4	main
olnudveel	doc_582053207523_item	2742652	et	4	main
ma	doc_582053207523_item	2742653	et	3	main
küsisin	doc_582053207523_item	2742654	et	3	main
palusin	doc_582053207523_item	2742675	et	3	main
ei	doc_582053207523_item	2742684	et	4	main
ainult	doc_582053207523_item	2742689	et	4	main
lisaandmed	doc_582053207523_item	2742695	et	3	main
on	doc_582053207523_item	2742697	et	4	main
madalamal	doc_582053207523_item	2742703	et	4	main
tasandilkuna	doc_582053207523_item	2742704	et	4	main
sel	doc_582053207523_item	2742705	et	3	main
õppeastmel	doc_582053207523_item	2742706	et	3	main
kõik	doc_582053207523_item	2742707	et	4	main
suunatud	doc_582053207523_item	2742710	et	4	main
nõrgad	doc_582053207523_item	2742714	et	3	main
mis	doc_582053207523_item	2742725	et	4	main
viisid	doc_582053207523_item	2742726	et	4	main
eesti	doc_582053207523_item	2742727	et	4	main
iseseisvuselebalti	doc_582053207523_item	2742728	et	4	main
vanasõnade	doc_582053207523_item	2742738	et	3	main
analüüsimist	doc_582053207523_item	2742749	et	4	main
ja	doc_582053207523_item	2742750	et	3	main
õpetajatega	doc_582053207523_item	2742751	et	4	main
järeldusele	doc_582053207523_item	2742755	et	4	main
õppekavas	doc_582053207523_item	2742757	et	3	main
kultuurile	doc_582053207523_item	2742759	et	3	main
õpetada	doc_582053207523_item	2742774	et	3	main
piisavalt	doc_582053207523_item	2742779	et	4	main
audio	doc_582053207523_item	2742780	et	4	main
ja	doc_582053207523_item	2742781	et	3	main
mis	doc_582053207523_item	2742787	et	4	main
pakub	doc_582053207523_item	2742788	et	3	main
14	doc_582053207523_item	2742621	et	2	main
variante	doc_582053207523_item	2742624	et	3	main
aga	doc_582053207523_item	2742626	et	3	main
kirjutanudjärgmine	doc_582053207523_item	2742631	et	4	main
oli	doc_582053207523_item	2742633	et	3	main
ühtki	doc_582053207523_item	2742648	et	4	main
õiget	doc_582053207523_item	2742649	et	3	main
teadmisest	doc_582053207523_item	2742656	et	4	main
nimetasid	doc_582053207523_item	2742661	et	4	main
mitmesuguseid	doc_582053207523_item	2742662	et	3	main
filme	doc_582053207523_item	2742663	et	3	main
ülejäänud	doc_582053207523_item	2742664	et	4	main
7	doc_582053207523_item	2742665	et	2	main
aga	doc_582053207523_item	2742666	et	3	main
ei	doc_582053207523_item	2742667	et	4	main
vastanudviimane	doc_582053207523_item	2742668	et	4	main
küsimus	doc_582053207523_item	2742669	et	4	main
oli	doc_582053207523_item	2742670	et	3	main
balti	doc_582053207523_item	2742671	et	3	main
ketist	doc_582053207523_item	2742672	et	3	main
ja	doc_582053207523_item	2742673	et	3	main
ma	doc_582053207523_item	2742674	et	3	main
kirjutada	doc_582053207523_item	2742676	et	3	main
ole	doc_582053207523_item	2742685	et	4	main
midagi	doc_582053207523_item	2742686	et	4	main
kirjutasid	doc_582053207523_item	2742694	et	4	main
11klassi	doc_582053207523_item	2742700	et	4	main
jaoks	doc_582053207523_item	2742701	et	4	main
riigieksamile	doc_582053207523_item	2742711	et	3	main
kultuuriteadmises	doc_582053207523_item	2742716	et	3	main
eesti	doc_582053207523_item	2742718	et	4	main
teater	doc_582053207523_item	2742719	et	3	main
eesti	doc_582053207523_item	2742720	et	4	main
sündmused	doc_582053207523_item	2742724	et	3	main
kett	doc_582053207523_item	2742729	et	4	main
ning	doc_582053207523_item	2742730	et	3	main
kaasaaegne	doc_582053207523_item	2742731	et	3	main
teadminemõistatustele	doc_582053207523_item	2742739	et	4	main
kultuuritegelastestkoidulakreutzwaldeesti	doc_582053207523_item	2742741	et	4	main
ajalehest	doc_582053207523_item	2742742	et	4	main
ja	doc_582053207523_item	2742743	et	3	main
vestlemist	doc_582053207523_item	2742752	et	4	main
õpetajate	doc_582053207523_item	2742766	et	4	main
selleks	doc_582053207523_item	2742772	et	4	main
põhjalikult	doc_582053207523_item	2742775	et	4	main
rohkem	doc_582053207523_item	2742790	et	4	main
huvi	doc_582053207523_item	2742791	et	4	main
kui	doc_582053207523_item	2742792	et	3	main
õpikud	doc_582053207523_item	2742793	et	3	main
nagu	doc_582053207523_item	2742794	et	3	main
öeldakse	doc_582053207523_item	2742795	et	3	main
et	doc_582053207523_item	2742796	et	3	main
oma	doc_582053207523_item	2742797	et	4	main
silm	doc_582053207523_item	2742798	et	3	main
on	doc_582053207523_item	2742799	et	4	main
kuningassamas	doc_582053207523_item	2742800	et	4	main
õpetajad	doc_582053207523_item	2742801	et	4	main
arvavad	doc_582053207523_item	2742802	et	4	main
et	doc_582053207523_item	2742803	et	3	main
õppekavas	doc_582053207523_item	2742804	et	3	main
on	doc_582053207523_item	2742805	et	4	main
väga	doc_582053207523_item	2742806	et	3	main
vähe	doc_582053207523_item	2742807	et	3	main
aega	doc_582053207523_item	2742808	et	4	main
jäetud	doc_582053207523_item	2742809	et	4	main
selleks	doc_582053207523_item	2742810	et	4	main
et	doc_582053207523_item	2742811	et	3	main
praktikal	doc_582053207523_item	2742812	et	3	main
rakendada	doc_582053207523_item	2742813	et	3	main
oma	doc_582053207523_item	2742814	et	4	main
teadmisi	doc_582053207523_item	2742815	et	4	main
ning	doc_582053207523_item	2742816	et	3	main
koolid	doc_582053207523_item	2742817	et	3	main
peavad	doc_582053207523_item	2742818	et	4	main
ise	doc_582053207523_item	2742819	et	4	main
korraldama	doc_582053207523_item	2742820	et	3	main
pidustusi	doc_582053207523_item	2742822	et	3	main
mõtlema	doc_582053207523_item	2742825	et	3	main
lastel	doc_582053207523_item	2742828	et	4	main
oleks	doc_582053207523_item	2742829	et	3	main
kergem	doc_582053207523_item	2742830	et	4	main
näiteks	doc_582053207523_item	2742836	et	4	main
selliseid	doc_582053207523_item	2742849	et	4	main
kultuuri	doc_582053207523_item	2742776	et	4	main
mida	doc_582053207523_item	2742783	et	4	main
võiks	doc_582053207523_item	2742784	et	4	main
ja	doc_582053207523_item	2742823	et	3	main
eesti	doc_582053207523_item	2742833	et	4	main
rahva	doc_582053207523_item	2742834	et	3	main
kultuurist	doc_582053207523_item	2742835	et	3	main
jäetud	doc_582053207523_item	2742842	et	4	main
seega	doc_582053207523_item	2742846	et	4	main
välja	doc_582053207523_item	2742866	et	4	main
mõtlema	doc_582053207523_item	2742867	et	3	main
on	doc_582053207523_item	2742887	et	4	main
5	doc_582053207523_item	2742888	et	2	main
saaksid	doc_582053207523_item	2742896	et	4	main
ole	doc_582053207523_item	2742906	et	4	main
unustavad	doc_582053207523_item	2742911	et	4	main
seda	doc_582053207523_item	2742912	et	3	main
algklassides	doc_582053207523_item	2742916	et	3	main
on	doc_582053207523_item	2742926	et	4	main
ja	doc_582053207523_item	2742931	et	3	main
väga	doc_582053207523_item	2742942	et	3	main
koostööd	doc_582053207523_item	2742952	et	4	main
keele	doc_582053207523_item	2742955	et	4	main
ainuld	doc_582053207523_item	2742964	et	4	main
katkendeid	doc_582053207523_item	2742965	et	3	main
raamatutest	doc_582053207523_item	2742966	et	4	main
ning	doc_582053207523_item	2742967	et	3	main
on	doc_582053207523_item	2742971	et	4	main
keeleõppimisele	doc_582053207523_item	2742973	et	3	main
õpetajad	doc_582053207523_item	2742984	et	4	main
olukorda	doc_582053207523_item	2742995	et	4	main
kuna	doc_582053207523_item	2743006	et	3	main
kutsuvad	doc_582053207523_item	2743017	et	4	main
kooli	doc_582053207523_item	2743018	et	4	main
näitustel	doc_582053207523_item	2743024	et	4	main
teatritesüldiselt	doc_582053207523_item	2743025	et	4	main
rohkem	doc_582053207523_item	2743039	et	4	main
õpilaste	doc_582053207523_item	2743044	et	4	main
on	doc_582053207523_item	2743046	et	4	main
samuti	doc_582053207523_item	2743047	et	3	main
kuna	doc_582053207523_item	2743057	et	3	main
teadmised	doc_582053207523_item	2743061	et	4	main
kultuuris	doc_582053207523_item	2743062	et	3	main
ei	doc_582053207523_item	2743063	et	4	main
nende	doc_582053207523_item	2743093	et	4	main
arvates	doc_582053207523_item	2743094	et	4	main
õppitakse	doc_582053207523_item	2743114	et	4	main
kuid	doc_582053207523_item	2743115	et	4	main
mingit	doc_582053207523_item	2743119	et	3	main
välja	doc_582053207523_item	2742824	et	4	main
saada	doc_582053207523_item	2742832	et	4	main
5klassi	doc_582053207523_item	2742837	et	4	main
tulemusi	doc_582053207523_item	2742850	et	4	main
et	doc_582053207523_item	2742851	et	3	main
õpilased	doc_582053207523_item	2742852	et	3	main
millal	doc_582053207523_item	2742855	et	3	main
see	doc_582053207523_item	2742856	et	3	main
laulupidu	doc_582053207523_item	2742857	et	4	main
oli	doc_582053207523_item	2742858	et	3	main
ja	doc_582053207523_item	2742859	et	3	main
kui	doc_582053207523_item	2742860	et	3	main
tihti	doc_582053207523_item	2742861	et	3	main
peetaksekoolid	doc_582053207523_item	2742862	et	4	main
aga	doc_582053207523_item	2742863	et	3	main
ise	doc_582053207523_item	2742865	et	4	main
eesti	doc_582053207523_item	2742843	et	4	main
ajaloo	doc_582053207523_item	2742844	et	4	main
ei	doc_582053207523_item	2742853	et	4	main
tea	doc_582053207523_item	2742854	et	4	main
midagi	doc_582053207523_item	2742868	et	4	main
et	doc_582053207523_item	2742869	et	3	main
koolilõpetajad	doc_582053207523_item	2742870	et	3	main
keeles	doc_582053207523_item	2742892	et	4	main
ja	doc_582053207523_item	2742893	et	3	main
et	doc_582053207523_item	2742894	et	3	main
õpilased	doc_582053207523_item	2742895	et	3	main
teadmisi	doc_582053207523_item	2742898	et	4	main
2	doc_582053207523_item	2742901	et	2	main
jagatud	doc_582053207523_item	2742903	et	4	main
kuna	doc_582053207523_item	2742904	et	3	main
õpilased	doc_582053207523_item	2742909	et	3	main
õpilased	doc_582053207523_item	2742918	et	3	main
vanasõnu	doc_582053207523_item	2742921	et	3	main
kõnekäände	doc_582053207523_item	2742923	et	4	main
ikkagi	doc_582053207523_item	2742925	et	4	main
grammatikale	doc_582053207523_item	2742930	et	3	main
rahvapärimust	doc_582053207523_item	2742935	et	4	main
peavad	doc_582053207523_item	2742950	et	4	main
parimaid	doc_582053207523_item	2742987	et	4	main
peaks	doc_582053207523_item	2742996	et	4	main
parandama	doc_582053207523_item	2742997	et	3	main
sel	doc_582053207523_item	2743007	et	3	main
vanasamas	doc_582053207523_item	2743015	et	4	main
ei	doc_582053207523_item	2743027	et	4	main
neile	doc_582053207523_item	2743038	et	4	main
ole	doc_582053207523_item	2743064	et	4	main
eesti	doc_582053207523_item	2743083	et	4	main
keelt	doc_582053207523_item	2743084	et	4	main
oska	doc_582053207523_item	2743087	et	4	main
kultuuriteadmine	doc_582053207523_item	2743095	et	3	main
on	doc_582053207523_item	2743096	et	4	main
kui	doc_582053207523_item	2743100	et	3	main
ebapiisavad	doc_582053207523_item	2743106	et	3	main
saab	doc_582053207523_item	2743107	et	3	main
sellega	doc_582053207523_item	2743110	et	3	main
ei	doc_582053207523_item	2743117	et	4	main
saa	doc_582053207523_item	2743118	et	4	main
vesteldes	doc_582053207523_item	2743122	et	3	main
nende	doc_582053207523_item	2743134	et	4	main
looming	doc_582053207523_item	2743135	et	3	main
eesti	doc_582053207523_item	2743136	et	4	main
igas	doc_582053207523_item	2743145	et	3	main
ma	doc_582053207523_item	2743162	et	3	main
sellest	doc_582053207523_item	2743164	et	4	main
muutused	doc_582053207523_item	2743174	et	4	main
termin	doc_582053207523_item	2743179	et	3	main
tõestasin	doc_582053207523_item	2743189	et	3	main
töös	doc_582053207523_item	2743191	et	3	main
pandnud	doc_582053207523_item	2743192	et	4	main
õpetamiseks	doc_582053207523_item	2743198	et	4	main
2	doc_582053207523_item	2743208	et	2	main
httpwwwermeelangestnode201	doc_582053207523_item	2743209	et	4	main
3	doc_582053207523_item	2743210	et	2	main
2001	doc_582053207523_item	2743222	et	2	main
7	doc_582053207523_item	2743248	et	2	main
referaat	doc_582053207524_item	2743251	et	3	main
neid	doc_582053207524_item	2743270	et	4	main
vältida	doc_582053207524_item	2743271	et	3	main
hulka	doc_582053207524_item	2743277	et	4	main
ja	doc_582053207524_item	2743278	et	3	main
neid	doc_582053207524_item	2743279	et	4	main
teeb	doc_582053207524_item	2743280	et	3	main
enamik	doc_582053207524_item	2743281	et	3	main
eesti	doc_582053207524_item	2743282	et	4	main
rõhutada	doc_582053207524_item	2743289	et	3	main
t	doc_582053207524_item	2743307	et	4	main
infinitiivi	doc_582053207524_item	2743312	et	4	main
peavad	doc_582053207523_item	2742864	et	4	main
haritud	doc_582053207523_item	2742873	et	4	main
inimesed	doc_582053207523_item	2742874	et	3	main
seega	doc_582053207523_item	2742875	et	4	main
viiendas	doc_582053207523_item	2742876	et	3	main
eesti	doc_582053207523_item	2742879	et	4	main
eesti	doc_582053207523_item	2742891	et	4	main
paremaid	doc_582053207523_item	2742897	et	4	main
on	doc_582053207523_item	2742899	et	4	main
klass	doc_582053207523_item	2742900	et	3	main
rühmaks	doc_582053207523_item	2742902	et	4	main
kultuuriõppimist	doc_582053207523_item	2742908	et	3	main
6klassis	doc_582053207523_item	2742917	et	3	main
tundma	doc_582053207523_item	2742920	et	3	main
mõistatusi	doc_582053207523_item	2742922	et	4	main
kuid	doc_582053207523_item	2742924	et	4	main
suurem	doc_582053207523_item	2742927	et	4	main
ning	doc_582053207523_item	2742934	et	3	main
mööda	doc_582053207523_item	2742937	et	4	main
kirjanikke	doc_582053207523_item	2742939	et	3	main
kaudselt	doc_582053207523_item	2742943	et	4	main
kuna	doc_582053207523_item	2742944	et	3	main
eesti	doc_582053207523_item	2742954	et	4	main
tunnis	doc_582053207523_item	2742956	et	3	main
tutvutakse	doc_582053207523_item	2742960	et	3	main
ka	doc_582053207523_item	2742961	et	3	main
tunnisloetakse	doc_582053207523_item	2742963	et	4	main
õppeaeg	doc_582053207523_item	2742970	et	3	main
kuna	doc_582053207523_item	2742974	et	3	main
peavad	doc_582053207523_item	2742985	et	4	main
näitama	doc_582053207523_item	2742986	et	3	main
kõik	doc_582053207523_item	2742990	et	4	main
on	doc_582053207523_item	2742992	et	4	main
pööratud	doc_582053207523_item	2742993	et	4	main
riigieksamile	doc_582053207523_item	2742994	et	3	main
eesti	doc_582053207523_item	2743000	et	4	main
tuleb	doc_582053207523_item	2743009	et	3	main
uut	doc_582053207523_item	2743011	et	3	main
käiakse	doc_582053207523_item	2743022	et	3	main
ole	doc_582053207523_item	2743028	et	4	main
ainult	doc_582053207523_item	2743042	et	4	main
tahaksid	doc_582053207523_item	2743053	et	4	main
nende	doc_582053207523_item	2743058	et	4	main
ei	doc_582053207523_item	2743086	et	4	main
midagi	doc_582053207523_item	2743089	et	4	main
öelda	doc_582053207523_item	2743090	et	4	main
kultuurist	doc_582053207523_item	2743091	et	3	main
samuti	doc_582053207523_item	2743092	et	3	main
kui	doc_582053207523_item	2743102	et	3	main
on	doc_582053207523_item	2743105	et	4	main
keelt	doc_582053207523_item	2743112	et	4	main
kultuuriteadmistepuudulikkusele	doc_582053207523_item	2743116	et	4	main
leidaõpilastega	doc_582053207523_item	2743121	et	4	main
rohkem	doc_582053207523_item	2743128	et	4	main
neid	doc_582053207523_item	2743129	et	4	main
huvitavad	doc_582053207523_item	2743130	et	4	main
kaasaaegsed	doc_582053207523_item	2743131	et	3	main
filmid	doc_582053207523_item	2743137	et	4	main
oma	doc_582053207523_item	2743149	et	4	main
kõne	doc_582053207523_item	2743150	et	4	main
öeldes	doc_582053207523_item	2743161	et	3	main
sain	doc_582053207523_item	2743163	et	3	main
ning	doc_582053207523_item	2743175	et	3	main
testideanalüüsidega	doc_582053207523_item	2743185	et	4	main
jäetud	doc_582053207523_item	2743201	et	4	main
vähe	doc_582053207523_item	2743202	et	3	main
httpswwwriigiteatajaeeertactjspid802290	doc_582053207523_item	2743211	et	4	main
valdmaa	doc_582053207523_item	2743216	et	4	main
oleksid	doc_582053207523_item	2742871	et	4	main
ikka	doc_582053207523_item	2742872	et	4	main
on	doc_582053207523_item	2742878	et	4	main
ajaloo	doc_582053207523_item	2742880	et	4	main
kursus	doc_582053207523_item	2742881	et	3	main
ning	doc_582053207523_item	2742882	et	3	main
tallinna	doc_582053207523_item	2742883	et	4	main
õismäe	doc_582053207523_item	2742884	et	3	main
vene	doc_582053207523_item	2742885	et	4	main
lütseumis	doc_582053207523_item	2742886	et	3	main
ei	doc_582053207523_item	2742905	et	4	main
sageli	doc_582053207523_item	2742910	et	3	main
mis	doc_582053207523_item	2742913	et	4	main
juba	doc_582053207523_item	2742915	et	3	main
õpivad	doc_582053207523_item	2742919	et	3	main
rõhk	doc_582053207523_item	2742928	et	3	main
teemadele	doc_582053207523_item	2742933	et	3	main
õpetatakse	doc_582053207523_item	2742936	et	3	main
õpetatakse	doc_582053207523_item	2742941	et	3	main
sellele	doc_582053207523_item	2742945	et	4	main
väga	doc_582053207523_item	2742947	et	3	main
vähe	doc_582053207523_item	2742948	et	3	main
aegaõpetajad	doc_582053207523_item	2742949	et	3	main
ning	doc_582053207523_item	2742953	et	3	main
tutvutud	doc_582053207523_item	2742957	et	4	main
tegelastega	doc_582053207523_item	2742959	et	3	main
rahvapärimuseteadmisi	doc_582053207523_item	2742982	et	4	main
ning	doc_582053207523_item	2742983	et	3	main
samuti	doc_582053207523_item	2742989	et	3	main
kursusel	doc_582053207523_item	2743008	et	3	main
peale	doc_582053207523_item	2743010	et	4	main
materjali	doc_582053207523_item	2743012	et	4	main
korrata	doc_582053207523_item	2743013	et	4	main
ka	doc_582053207523_item	2743014	et	3	main
eesti	doc_582053207523_item	2743019	et	4	main
kirjanikke	doc_582053207523_item	2743020	et	3	main
pandud	doc_582053207523_item	2742929	et	4	main
läbivatele	doc_582053207523_item	2742932	et	4	main
minnes	doc_582053207523_item	2742938	et	3	main
loomingust	doc_582053207523_item	2742940	et	3	main
on	doc_582053207523_item	2742946	et	4	main
tegema	doc_582053207523_item	2742951	et	3	main
raamatute	doc_582053207523_item	2742958	et	3	main
emakeele	doc_582053207523_item	2742962	et	4	main
terve	doc_582053207523_item	2742968	et	4	main
9klassi	doc_582053207523_item	2742969	et	4	main
suunatud	doc_582053207523_item	2742972	et	4	main
ees	doc_582053207523_item	2742975	et	4	main
on	doc_582053207523_item	2742976	et	4	main
põhikoolieksam	doc_582053207523_item	2742977	et	3	main
kus	doc_582053207523_item	2742978	et	3	main
kontrollitakse	doc_582053207523_item	2742979	et	4	main
grammatikat	doc_582053207523_item	2742980	et	3	main
mitte	doc_582053207523_item	2742981	et	3	main
tulemusigümnaasiumiastmes	doc_582053207523_item	2742988	et	3	main
tähelepanu	doc_582053207523_item	2742991	et	4	main
35-tunniline	doc_582053207523_item	2742998	et	4	main
kurss	doc_582053207523_item	2742999	et	3	main
kultuurist	doc_582053207523_item	2743001	et	3	main
aga	doc_582053207523_item	2743002	et	3	main
seda	doc_582053207523_item	2743003	et	3	main
on	doc_582053207523_item	2743004	et	4	main
vähe	doc_582053207523_item	2743005	et	3	main
õpetajad	doc_582053207523_item	2743016	et	4	main
näitlejaid	doc_582053207523_item	2743021	et	4	main
ekskursioonidel	doc_582053207523_item	2743023	et	3	main
õpetajad	doc_582053207523_item	2743026	et	4	main
õppekava	doc_582053207523_item	2743036	et	4	main
annab	doc_582053207523_item	2743037	et	3	main
mitte	doc_582053207523_item	2743041	et	3	main
keeleõppimiseks	doc_582053207523_item	2743043	et	3	main
arvates	doc_582053207523_item	2743045	et	4	main
kultuuriõppimine	doc_582053207523_item	2743048	et	3	main
pole	doc_582053207523_item	2743049	et	3	main
piisav	doc_582053207523_item	2743050	et	4	main
paljud	doc_582053207523_item	2743051	et	3	main
õpilased	doc_582053207523_item	2743052	et	3	main
arvates	doc_582053207523_item	2743059	et	4	main
nende	doc_582053207523_item	2743060	et	4	main
kõrgel	doc_582053207523_item	2743065	et	4	main
samas	doc_582053207523_item	2743080	et	4	main
oskavad	doc_582053207523_item	2743082	et	4	main
teadmised	doc_582053207523_item	2743104	et	4	main
seda	doc_582053207523_item	2743108	et	3	main
põhjendada	doc_582053207523_item	2743109	et	3	main
et	doc_582053207523_item	2743111	et	3	main
ma	doc_582053207523_item	2743123	et	3	main
eesti	doc_582053207523_item	2743132	et	4	main
kirjanikud	doc_582053207523_item	2743133	et	3	main
mida	doc_582053207523_item	2743142	et	4	main
saab	doc_582053207523_item	2743143	et	3	main
kasutada	doc_582053207523_item	2743144	et	3	main
situatsioonis	doc_582053207523_item	2743146	et	3	main
ja	doc_582053207523_item	2743147	et	3	main
rikastada	doc_582053207523_item	2743148	et	3	main
terminist	doc_582053207523_item	2743165	et	3	main
ainult	doc_582053207523_item	2743167	et	4	main
ülikoolis	doc_582053207523_item	2743168	et	4	main
aga	doc_582053207523_item	2743169	et	3	main
lastele	doc_582053207523_item	2743176	et	4	main
arusaadavaks	doc_582053207523_item	2743180	et	4	main
koolis	doc_582053207523_item	2743182	et	4	main
selliste	doc_582053207523_item	2743183	et	4	main
arvamustega	doc_582053207523_item	2743187	et	3	main
on	doc_582053207523_item	2743199	et	4	main
riigiõõpekavas	doc_582053207523_item	2743200	et	4	main
aega	doc_582053207523_item	2743203	et	4	main
valikuliselt	doc_582053207523_item	2743212	et	4	main
4	doc_582053207523_item	2743213	et	2	main
ajalugu	doc_582053207523_item	2743218	et	4	main
lk	doc_582053207523_item	2743223	et	4	main
lk	doc_582053207523_item	2743225	et	4	main
академия	doc_582053207523_item	2743228	et	2	main
эстонской	doc_582053207523_item	2743230	et	2	main
институт	doc_582053207523_item	2743232	et	2	main
и	doc_582053207523_item	2743234	et	2	main
эстонский	doc_582053207523_item	2743236	et	2	main
раамат	doc_582053207523_item	2743239	et	2	main
httpwwwtovltlneduee	doc_582053207523_item	2743247	et	4	main
kuna	doc_582053207524_item	2743253	et	3	main
infinitiivi	doc_582053207524_item	2743254	et	4	main
rahul	doc_582053207523_item	2743029	et	4	main
praeguse	doc_582053207523_item	2743030	et	3	main
õppekavaga	doc_582053207523_item	2743031	et	3	main
ja	doc_582053207523_item	2743032	et	3	main
loodavad	doc_582053207523_item	2743033	et	4	main
et	doc_582053207523_item	2743034	et	3	main
uus	doc_582053207523_item	2743035	et	3	main
võimalusi	doc_582053207523_item	2743040	et	3	main
rohkem	doc_582053207523_item	2743054	et	4	main
õppida	doc_582053207523_item	2743055	et	3	main
kultuuri	doc_582053207523_item	2743056	et	4	main
tasemel	doc_582053207523_item	2743066	et	3	main
ja	doc_582053207523_item	2743067	et	3	main
nad	doc_582053207523_item	2743068	et	3	main
kardavad	doc_582053207523_item	2743069	et	4	main
et	doc_582053207523_item	2743070	et	3	main
tekib	doc_582053207523_item	2743071	et	3	main
selline	doc_582053207523_item	2743072	et	4	main
situatsioon	doc_582053207523_item	2743073	et	3	main
et	doc_582053207523_item	2743074	et	3	main
tuleb	doc_582053207523_item	2743076	et	3	main
neil	doc_582053207523_item	2743075	et	4	main
vestelda	doc_582053207523_item	2743077	et	4	main
eesti	doc_582053207523_item	2743078	et	4	main
kultuurist	doc_582053207523_item	2743079	et	3	main
nad	doc_582053207523_item	2743081	et	3	main
aga	doc_582053207523_item	2743085	et	3	main
mitte	doc_582053207523_item	2743088	et	3	main
samal	doc_582053207523_item	2743097	et	3	main
tähtsal	doc_582053207523_item	2743098	et	3	main
tasemel	doc_582053207523_item	2743099	et	3	main
keeleõppimine	doc_582053207523_item	2743101	et	3	main
keele	doc_582053207523_item	2743103	et	4	main
alles	doc_582053207523_item	2743113	et	3	main
vabandust	doc_582053207523_item	2743120	et	4	main
teada	doc_582053207523_item	2743125	et	3	main
et	doc_582053207523_item	2743126	et	3	main
eesti	doc_582053207523_item	2743138	et	4	main
vanasõnad	doc_582053207523_item	2743139	et	3	main
ja	doc_582053207523_item	2743140	et	3	main
sams	doc_582053207523_item	2743151	et	4	main
teada	doc_582053207523_item	2743166	et	3	main
loodameet	doc_582053207523_item	2743170	et	4	main
järgmises	doc_582053207523_item	2743171	et	3	main
õppekavas	doc_582053207523_item	2743172	et	3	main
saab	doc_582053207523_item	2743177	et	3	main
juba	doc_582053207523_item	2743181	et	3	main
õpetajate	doc_582053207523_item	2743186	et	4	main
kasutatud	doc_582053207523_item	2743204	et	4	main
kirjandus	doc_582053207523_item	2743205	et	3	main
1	doc_582053207523_item	2743206	et	2	main
andres	doc_582053207523_item	2743214	et	4	main
eesti	doc_582053207523_item	2743217	et	4	main
tallinn	doc_582053207523_item	2743220	et	4	main
307-323	doc_582053207523_item	2743245	et	2	main
valikuliselt	doc_582053207523_item	2743250	et	4	main
vead	doc_582053207524_item	2743255	et	4	main
võimalikku	doc_582053207524_item	2743268	et	4	main
et	doc_582053207524_item	2743269	et	3	main
universaalsete	doc_582053207524_item	2743275	et	4	main
vigade	doc_582053207524_item	2743276	et	3	main
õppijaid	doc_582053207524_item	2743284	et	4	main
kokkuvõtteks	doc_582053207524_item	2743285	et	3	main
tahaksime	doc_582053207524_item	2743286	et	3	main
infinitiivi	doc_582053207524_item	2743292	et	4	main
seotud	doc_582053207524_item	2743294	et	4	main
ähtsamaks	doc_582053207524_item	2743308	et	4	main
olemas	doc_582053207524_item	2743332	et	4	main
kasutamine	doc_582053207524_item	2743336	et	4	main
eriti	doc_582053207524_item	2743338	et	3	main
keele	doc_582053207524_item	2743341	et	4	main
e	doc_582053207524_item	2743346	et	4	main
nõuab	doc_582053207524_item	2743360	et	3	main
erilist	doc_582053207524_item	2743361	et	4	main
keeletundmist	doc_582053207524_item	2743362	et	3	main
ja	doc_582053207524_item	2743363	et	3	main
tähelepanu	doc_582053207524_item	2743364	et	4	main
seotud	doc_582053207524_item	2743369	et	4	main
antud	doc_582053207524_item	2743376	et	4	main
autoril	doc_582053207524_item	2743378	et	3	main
eesmärki	doc_582053207524_item	2743381	et	4	main
teooria	doc_582053207524_item	2743382	et	4	main
osas	doc_582053207524_item	2743383	et	4	main
eesti	doc_582053207524_item	2743387	et	4	main
et	doc_582053207524_item	2743392	et	3	main
mis	doc_582053207524_item	2743400	et	4	main
vigade	doc_582053207524_item	2743410	et	3	main
millega	doc_582053207524_item	2743421	et	3	main
õpetajatel	doc_582053207524_item	2743428	et	4	main
määrata	doc_582053207524_item	2743429	et	4	main
verbe	doc_582053207524_item	2743430	et	3	main
millele	doc_582053207524_item	2743431	et	3	main
tuleb	doc_582053207524_item	2743432	et	3	main
õpilaste	doc_582053207524_item	2743433	et	4	main
pöörata	doc_582053207524_item	2743436	et	4	main
eesti	doc_582053207524_item	2743441	et	4	main
vigade	doc_582053207524_item	2743444	et	3	main
analüüsida	doc_582053207524_item	2743447	et	3	main
näidet	doc_582053207524_item	2743449	et	3	main
160	doc_582053207524_item	2743452	et	2	main
kõik	doc_582053207524_item	2743453	et	4	main
need	doc_582053207524_item	2743454	et	3	main
välja	doc_582053207524_item	2743465	et	4	main
ma-infinitiivi	doc_582053207524_item	2743478	et	4	main
ühend	doc_582053207524_item	2743480	et	3	main
et	doc_582053207524_item	2743493	et	3	main
vigade	doc_582053207524_item	2743499	et	3	main
da-infinitiiv	doc_582053207524_item	2743501	et	3	main
sain	doc_582053207523_item	2743124	et	3	main
kõige	doc_582053207523_item	2743127	et	4	main
mõistatused	doc_582053207523_item	2743141	et	4	main
neid	doc_582053207523_item	2743152	et	4	main
huvitas	doc_582053207523_item	2743153	et	3	main
selline	doc_582053207523_item	2743154	et	4	main
terminkasettpõlvkond	doc_582053207523_item	2743155	et	4	main
mida	doc_582053207523_item	2743156	et	4	main
päris	doc_582053207523_item	2743157	et	4	main
tihti	doc_582053207523_item	2743158	et	3	main
kasutatakse	doc_582053207523_item	2743159	et	3	main
ausalt	doc_582053207523_item	2743160	et	4	main
tulevad	doc_582053207523_item	2743173	et	4	main
see	doc_582053207523_item	2743178	et	3	main
järeldustega	doc_582053207523_item	2743184	et	4	main
ma	doc_582053207523_item	2743188	et	3	main
oma	doc_582053207523_item	2743190	et	4	main
hüpoteesi	doc_582053207523_item	2743193	et	4	main
et	doc_582053207523_item	2743194	et	3	main
rahvuspärimuse	doc_582053207523_item	2743195	et	3	main
õppimiseks	doc_582053207523_item	2743196	et	4	main
ja	doc_582053207523_item	2743197	et	3	main
mytele2eeoldjyrimarijyrivalikuliselt	doc_582053207523_item	2743207	et	4	main
adamsonsulev	doc_582053207523_item	2743215	et	4	main
gümnaasiumile	doc_582053207523_item	2743219	et	3	main
koolibri	doc_582053207523_item	2743221	et	4	main
119-124	doc_582053207523_item	2743224	et	2	main
249	doc_582053207523_item	2743226	et	2	main
1	doc_582053207523_item	2743227	et	2	main
наук	doc_582053207523_item	2743229	et	2	main
сср	doc_582053207523_item	2743231	et	2	main
языка	doc_582053207523_item	2743233	et	2	main
литературы	doc_582053207523_item	2743235	et	2	main
фольклорталлин	doc_582053207523_item	2743237	et	2	main
ээсти	doc_582053207523_item	2743238	et	2	main
1980	doc_582053207523_item	2743240	et	2	main
lk	doc_582053207523_item	2743241	et	4	main
54-122	doc_582053207523_item	2743242	et	2	main
278	doc_582053207523_item	2743243	et	2	main
283	doc_582053207523_item	2743244	et	2	main
httpwwwestonicaorgestluguhtmlmenyyid175kateg5alam19leht1	doc_582053207523_item	2743249	et	4	main
emakeele	doc_582053207524_item	2743261	et	4	main
rääkivate	doc_582053207524_item	2743262	et	4	main
inimeste	doc_582053207524_item	2743263	et	3	main
infinitiivi	doc_582053207524_item	2743272	et	4	main
veel	doc_582053207524_item	2743287	et	4	main
eesti	doc_582053207524_item	2743291	et	4	main
tingitud	doc_582053207524_item	2743299	et	4	main
kahe	doc_582053207524_item	2743300	et	3	main
keele	doc_582053207524_item	2743301	et	4	main
infinitiivide	doc_582053207524_item	2743302	et	3	main
erinevustest	doc_582053207524_item	2743303	et	4	main
saab	doc_582053207524_item	2743304	et	3	main
on	doc_582053207524_item	2743310	et	4	main
sellest	doc_582053207524_item	2743321	et	4	main
tingitud	doc_582053207524_item	2743323	et	4	main
suurem	doc_582053207524_item	2743324	et	4	main
makorda	doc_582053207524_item	2743331	et	4	main
esti	doc_582053207524_item	2743347	et	4	main
infinitiivide	doc_582053207524_item	2743348	et	3	main
väljendata	doc_582053207524_item	2743351	et	3	main
õige	doc_582053207524_item	2743358	et	4	main
äändevormide	doc_582053207524_item	2743366	et	4	main
analüsis	doc_582053207524_item	2743373	et	4	main
umbes	doc_582053207524_item	2743374	et	4	main
7	doc_582053207524_item	2743375	et	2	main
kaks	doc_582053207524_item	2743380	et	3	main
omavahel	doc_582053207524_item	2743386	et	3	main
infinitiive	doc_582053207524_item	2743390	et	3	main
välja	doc_582053207524_item	2743393	et	4	main
nende	doc_582053207524_item	2743398	et	4	main
jaoks	doc_582053207524_item	2743404	et	4	main
seejärel	doc_582053207524_item	2743405	et	3	main
oli	doc_582053207524_item	2743406	et	3	main
infinitiivide	doc_582053207524_item	2743442	et	3	main
näiteid	doc_582053207524_item	2743445	et	3	main
on	doc_582053207524_item	2743450	et	4	main
kokku	doc_582053207524_item	2743451	et	3	main
alatest	doc_582053207524_item	2743463	et	3	main
kõrgtasemeni	doc_582053207524_item	2743464	et	3	main
asemel	doc_582053207524_item	2743479	et	4	main
kolmes	doc_582053207524_item	2743481	et	4	main
verbist	doc_582053207524_item	2743482	et	3	main
viga	doc_582053207524_item	2743490	et	4	main
selgub	doc_582053207524_item	2743492	et	3	main
asemel	doc_582053207524_item	2743496	et	4	main
võtab	doc_582053207524_item	2743497	et	3	main
vahe	doc_582053207524_item	2743507	et	4	main
kahe	doc_582053207524_item	2743508	et	3	main
näitajate	doc_582053207524_item	2743509	et	4	main
suur	doc_582053207524_item	2743513	et	3	main
üldistama	doc_582053207524_item	2743519	et	3	main
2	doc_582053207523_item	2743246	et	2	main
kokkuvõte	doc_582053207524_item	2743252	et	3	main
kõnes	doc_582053207524_item	2743264	et	3	main
tuleks	doc_582053207524_item	2743265	et	4	main
teha	doc_582053207524_item	2743266	et	3	main
kõike	doc_582053207524_item	2743267	et	4	main
kuuluvad	doc_582053207524_item	2743274	et	4	main
keele	doc_582053207524_item	2743283	et	4	main
et	doc_582053207524_item	2743290	et	3	main
valikuga	doc_582053207524_item	2743293	et	3	main
vead	doc_582053207524_item	2743295	et	4	main
venelaste	doc_582053207524_item	2743296	et	4	main
kõnes	doc_582053207524_item	2743297	et	3	main
et	doc_582053207524_item	2743306	et	3	main
olemasolu	doc_582053207524_item	2743313	et	4	main
eesti	doc_582053207524_item	2743314	et	4	main
keeles	doc_582053207524_item	2743315	et	4	main
ja	doc_582053207524_item	2743316	et	3	main
ühe	doc_582053207524_item	2743317	et	4	main
vene	doc_582053207524_item	2743318	et	4	main
keeles	doc_582053207524_item	2743319	et	4	main
just	doc_582053207524_item	2743320	et	3	main
osa	doc_582053207524_item	2743325	et	4	main
vigu	doc_582053207524_item	2743326	et	3	main
eesti	doc_582053207524_item	2743327	et	4	main
infinitiividel	doc_582053207524_item	2743328	et	3	main
käändevormid	doc_582053207524_item	2743334	et	4	main
on	doc_582053207524_item	2743337	et	4	main
emakeelena	doc_582053207524_item	2743342	et	3	main
käändevormide	doc_582053207524_item	2743349	et	4	main
kase	doc_582053207524_item	2743352	et	3	main
vene	doc_582053207524_item	2743353	et	4	main
leksikaalselt	doc_582053207524_item	2743355	et	4	main
nende	doc_582053207524_item	2743357	et	4	main
k	doc_582053207524_item	2743365	et	4	main
tuli	doc_582053207524_item	2743384	et	4	main
selleks	doc_582053207524_item	2743391	et	4	main
vahel	doc_582053207524_item	2743399	et	4	main
vaja	doc_582053207524_item	2743407	et	4	main
esinevad	doc_582053207524_item	2743256	et	4	main
väga	doc_582053207524_item	2743257	et	3	main
tihti	doc_582053207524_item	2743258	et	3	main
vene	doc_582053207524_item	2743259	et	4	main
kui	doc_582053207524_item	2743260	et	3	main
vead	doc_582053207524_item	2743273	et	4	main
kord	doc_582053207524_item	2743288	et	4	main
on	doc_582053207524_item	2743298	et	4	main
väita	doc_582053207524_item	2743305	et	4	main
erinevuseks	doc_582053207524_item	2743309	et	4	main
kahe	doc_582053207524_item	2743311	et	3	main
on	doc_582053207524_item	2743322	et	4	main
ka	doc_582053207524_item	2743333	et	3	main
mille	doc_582053207524_item	2743335	et	3	main
vene	doc_582053207524_item	2743340	et	4	main
kõnelevatele	doc_582053207524_item	2743343	et	4	main
inimestele	doc_582053207524_item	2743344	et	3	main
sest	doc_582053207524_item	2743345	et	4	main
mõisteid	doc_582053207524_item	2743350	et	3	main
keeles	doc_582053207524_item	2743354	et	4	main
ning	doc_582053207524_item	2743356	et	3	main
kasutamisega	doc_582053207524_item	2743368	et	4	main
viga	doc_582053207524_item	2743370	et	4	main
töö	doc_582053207524_item	2743377	et	4	main
oli	doc_582053207524_item	2743379	et	3	main
kõrvutada	doc_582053207524_item	2743385	et	3	main
vene	doc_582053207524_item	2743389	et	4	main
sarnasusi	doc_582053207524_item	2743395	et	4	main
välja	doc_582053207524_item	2743408	et	4	main
selgitada	doc_582053207524_item	2743409	et	3	main
kõige	doc_582053207524_item	2743423	et	4	main
erilist	doc_582053207524_item	2743434	et	4	main
praktiline	doc_582053207524_item	2743437	et	3	main
koguda	doc_582053207524_item	2743440	et	3	main
ja	doc_582053207524_item	2743446	et	3	main
neid	doc_582053207524_item	2743448	et	4	main
asemel	doc_582053207524_item	2743476	et	4	main
õige	doc_582053207524_item	2743483	et	4	main
vale	doc_582053207524_item	2743485	et	4	main
ühes	doc_582053207524_item	2743486	et	4	main
lauses	doc_582053207524_item	2743487	et	3	main
ja	doc_582053207524_item	2743488	et	3	main
da-infinitiivi	doc_582053207524_item	2743495	et	4	main
4863	doc_582053207524_item	2743498	et	2	main
põhiarvust	doc_582053207524_item	2743500	et	4	main
on	doc_582053207524_item	2743511	et	4	main
kiputakse	doc_582053207524_item	2743518	et	3	main
on	doc_582053207524_item	2743329	et	4	main
o	doc_582053207524_item	2743330	et	4	main
keeruline	doc_582053207524_item	2743339	et	4	main
kasutamine	doc_582053207524_item	2743359	et	4	main
väärase	doc_582053207524_item	2743367	et	4	main
on	doc_582053207524_item	2743371	et	4	main
antud	doc_582053207524_item	2743372	et	4	main
ja	doc_582053207524_item	2743388	et	3	main
selgitada	doc_582053207524_item	2743394	et	3	main
ja	doc_582053207524_item	2743396	et	3	main
erinevusi	doc_582053207524_item	2743397	et	4	main
on	doc_582053207524_item	2743401	et	4	main
vajalikud	doc_582053207524_item	2743402	et	3	main
analüüsi	doc_582053207524_item	2743403	et	4	main
põhjusi	doc_582053207524_item	2743411	et	3	main
ja	doc_582053207524_item	2743412	et	3	main
seletada	doc_582053207524_item	2743413	et	3	main
neid	doc_582053207524_item	2743414	et	4	main
eesti	doc_582053207524_item	2743415	et	4	main
grammatika	doc_582053207524_item	2743416	et	4	main
lähtekohast	doc_582053207524_item	2743417	et	4	main
ning	doc_582053207524_item	2743418	et	3	main
määrata	doc_582053207524_item	2743419	et	4	main
verbe	doc_582053207524_item	2743420	et	3	main
sagedamini	doc_582053207524_item	2743424	et	4	main
peaks	doc_582053207524_item	2743426	et	4	main
ülesande	doc_582053207524_item	2743438	et	4	main
da-infinitiiv	doc_582053207524_item	2743477	et	3	main
käändevormide	doc_582053207524_item	2743489	et	4	main
ma-infinitiivi	doc_582053207524_item	2743502	et	4	main
asemel	doc_582053207524_item	2743503	et	4	main
vahel	doc_582053207524_item	2743510	et	4	main
järeldada	doc_582053207524_item	2743515	et	3	main
ma-infinitiivi	doc_582053207524_item	2743517	et	4	main
ja	doc_582053207524_item	2743520	et	3	main
kasutama	doc_582053207524_item	2743521	et	3	main
õpitakse	doc_582053207524_item	2743536	et	4	main
lisaks	doc_582053207524_item	2743542	et	4	main
mis	doc_582053207524_item	2743567	et	4	main
see	doc_582053207524_item	2743572	et	3	main
tähendus	doc_582053207524_item	2743573	et	4	main
määrab	doc_582053207524_item	2743574	et	3	main
ma	doc_582053207524_item	2743575	et	3	main
da	doc_582053207524_item	2743577	et	4	main
saab	doc_582053207524_item	2743580	et	3	main
da-infinitiiviga	doc_582053207524_item	2743583	et	3	main
perfektiivsust	doc_582053207524_item	2743592	et	4	main
see	doc_582053207524_item	2743600	et	3	main
antud	doc_582053207524_item	2743611	et	4	main
valik	doc_582053207524_item	2743618	et	3	main
sellest	doc_582053207524_item	2743621	et	4	main
kõigist	doc_582053207524_item	2743642	et	4	main
modaalverbidega	doc_582053207524_item	2743647	et	4	main
võib	doc_582053207524_item	2743649	et	3	main
nõuavad	doc_582053207524_item	2743654	et	4	main
kui	doc_582053207524_item	2743660	et	3	main
neutraalseks	doc_582053207524_item	2743665	et	3	main
mis	doc_582053207524_item	2743673	et	4	main
esolevas	doc_582053207524_item	2743683	et	4	main
viga	doc_582053207524_item	2743688	et	4	main
strateegia	doc_582053207524_item	2743721	et	4	main
ja	doc_582053207524_item	2743724	et	3	main
see	doc_582053207524_item	2743725	et	3	main
põhjustab	doc_582053207524_item	2743726	et	3	main
vigu	doc_582053207524_item	2743727	et	3	main
kategooria	doc_582053207524_item	2743735	et	4	main
see	doc_582053207524_item	2743736	et	3	main
et	doc_582053207524_item	2743738	et	3	main
valik	doc_582053207524_item	2743742	et	3	main
tegevus	doc_582053207524_item	2743751	et	4	main
juhul	doc_582053207524_item	2743761	et	3	main
eksitakse	doc_582053207524_item	2743422	et	4	main
see	doc_582053207524_item	2743425	et	3	main
aitama	doc_582053207524_item	2743427	et	3	main
tähelepanu	doc_582053207524_item	2743435	et	4	main
oli	doc_582053207524_item	2743439	et	3	main
kasutuse	doc_582053207524_item	2743443	et	4	main
pärinevad	doc_582053207524_item	2743455	et	4	main
kirjalikest	doc_582053207524_item	2743456	et	3	main
töödest	doc_582053207524_item	2743457	et	3	main
õppijate	doc_582053207524_item	2743458	et	4	main
keeletasemed	doc_582053207524_item	2743459	et	3	main
olid	doc_582053207524_item	2743460	et	4	main
erinevad	doc_582053207524_item	2743461	et	4	main
algtasemest	doc_582053207524_item	2743462	et	3	main
analüüsi	doc_582053207524_item	2743466	et	4	main
käigus	doc_582053207524_item	2743467	et	4	main
kujunes	doc_582053207524_item	2743468	et	3	main
välja	doc_582053207524_item	2743469	et	4	main
5	doc_582053207524_item	2743470	et	2	main
vigade	doc_582053207524_item	2743471	et	3	main
tüüpi	doc_582053207524_item	2743472	et	4	main
ma	doc_582053207524_item	2743473	et	3	main
infinitiiv	doc_582053207524_item	2743474	et	3	main
da-infinitiivi	doc_582053207524_item	2743475	et	4	main
ja	doc_582053207524_item	2743484	et	3	main
tööst	doc_582053207524_item	2743491	et	3	main
ma-infinitiiv	doc_582053207524_item	2743494	et	3	main
saab	doc_582053207524_item	2743514	et	3	main
et	doc_582053207524_item	2743516	et	3	main
asemel	doc_582053207524_item	2743523	et	4	main
ma-infinitiiv	doc_582053207524_item	2743530	et	3	main
õppijatele	doc_582053207524_item	2743541	et	4	main
selles	doc_582053207524_item	2743549	et	4	main
tegevuse	doc_582053207524_item	2743569	et	4	main
aspektuaalset	doc_582053207524_item	2743570	et	4	main
et	doc_582053207524_item	2743582	et	3	main
tavaliselt	doc_582053207524_item	2743585	et	4	main
olla	doc_582053207524_item	2743599	et	3	main
valib	doc_582053207524_item	2743603	et	3	main
väljendab	doc_582053207524_item	2743610	et	3	main
verb	doc_582053207524_item	2743612	et	3	main
sõltu	doc_582053207524_item	2743620	et	4	main
hoopis	doc_582053207524_item	2743627	et	3	main
leidus	doc_582053207524_item	2743632	et	4	main
67	doc_582053207524_item	2743641	et	2	main
tehtud	doc_582053207524_item	2743645	et	4	main
et	doc_582053207524_item	2743652	et	3	main
keele	doc_582053207524_item	2743659	et	4	main
ma-infinitiivi	doc_582053207524_item	2743664	et	4	main
kasutavad	doc_582053207524_item	2743667	et	4	main
infinitiivvormi	doc_582053207524_item	2743674	et	4	main
eksitakse	doc_582053207524_item	2743677	et	4	main
väljendavate	doc_582053207524_item	2743679	et	4	main
sellist	doc_582053207524_item	2743687	et	4	main
üle	doc_582053207524_item	2743722	et	3	main
kanda	doc_582053207524_item	2743723	et	4	main
eesti	doc_582053207524_item	2743728	et	4	main
infinitiivi	doc_582053207524_item	2743729	et	4	main
valikut	doc_582053207524_item	2743730	et	3	main
mõjutab	doc_582053207524_item	2743731	et	3	main
aktiivsuse	doc_582053207524_item	2743732	et	4	main
ja	doc_582053207524_item	2743733	et	3	main
passiivsuse	doc_582053207524_item	2743734	et	4	main
ja	doc_582053207524_item	2743740	et	3	main
kas	doc_582053207524_item	2743745	et	3	main
asi	doc_582053207524_item	2743748	et	4	main
millele	doc_582053207524_item	2743749	et	3	main
aktiivne	doc_582053207524_item	2743754	et	3	main
või	doc_582053207524_item	2743755	et	4	main
verbi	doc_582053207524_item	2743763	et	4	main
kasutusreeglid	doc_582053207524_item	2743766	et	3	main
kui	doc_582053207524_item	2743772	et	3	main
sõna	doc_582053207524_item	2743777	et	4	main
ei	doc_582053207524_item	2743781	et	4	main
ole	doc_582053207524_item	2743782	et	4	main
kinnistunud	doc_582053207524_item	2743783	et	4	main
kipuvad	doc_582053207524_item	2743784	et	3	main
venelased	doc_582053207524_item	2743785	et	3	main
keeles	doc_582053207524_item	2743794	et	4	main
mis	doc_582053207524_item	2743798	et	4	main
nõuavad	doc_582053207524_item	2743799	et	4	main
minna	doc_582053207524_item	2743843	et	3	main
see	doc_582053207524_item	2743851	et	3	main
mõista	doc_582053207524_item	2743865	et	4	main
mis	doc_582053207524_item	2743866	et	4	main
verb	doc_582053207524_item	2743867	et	3	main
dikteerib	doc_582053207524_item	2743868	et	3	main
teise	doc_582053207524_item	2743869	et	4	main
sellisel	doc_582053207524_item	2743872	et	4	main
juhul	doc_582053207524_item	2743873	et	3	main
üks	doc_582053207524_item	2743874	et	3	main
infinitiiv	doc_582053207524_item	2743875	et	3	main
valitud	doc_582053207524_item	2743878	et	4	main
teine	doc_582053207524_item	2743880	et	3	main
valesti	doc_582053207524_item	2743882	et	3	main
ainult	doc_582053207524_item	2743504	et	4	main
3114	doc_582053207524_item	2743505	et	2	main
kuna	doc_582053207524_item	2743506	et	3	main
üsna	doc_582053207524_item	2743512	et	3	main
da-infinitiivi	doc_582053207524_item	2743522	et	4	main
on	doc_582053207524_item	2743526	et	4	main
see	doc_582053207524_item	2743528	et	3	main
on	doc_582053207524_item	2743531	et	4	main
esimene	doc_582053207524_item	2743532	et	3	main
verbi	doc_582053207524_item	2743533	et	4	main
vorm	doc_582053207524_item	2743534	et	3	main
mida	doc_582053207524_item	2743535	et	4	main
algtaseme	doc_582053207524_item	2743540	et	3	main
ma-infinitiivi	doc_582053207524_item	2743544	et	4	main
põhivormiks	doc_582053207524_item	2743546	et	4	main
sest	doc_582053207524_item	2743547	et	4	main
just	doc_582053207524_item	2743548	et	3	main
tegevuse	doc_582053207524_item	2743586	et	4	main
imperfektiivset	doc_582053207524_item	2743587	et	3	main
akpekti	doc_582053207524_item	2743588	et	4	main
ma-infinitiiviga	doc_582053207524_item	2743589	et	3	main
aga	doc_582053207524_item	2743590	et	3	main
tekitavaks	doc_582053207524_item	2743595	et	4	main
põhjuseks	doc_582053207524_item	2743597	et	3	main
infinitiivi	doc_582053207524_item	2743605	et	4	main
sõltudes	doc_582053207524_item	2743606	et	3	main
sellest	doc_582053207524_item	2743607	et	4	main
infinitiivi	doc_582053207524_item	2743617	et	4	main
vigu	doc_582053207524_item	2743631	et	3	main
käesolevas	doc_582053207524_item	2743633	et	3	main
20	doc_582053207524_item	2743636	et	2	main
et	doc_582053207524_item	2743639	et	3	main
on	doc_582053207524_item	2743644	et	4	main
nimetada	doc_582053207524_item	2743650	et	3	main
ja	doc_582053207524_item	2743666	et	3	main
seda	doc_582053207524_item	2743668	et	3	main
valida	doc_582053207524_item	2743675	et	3	main
k	doc_582053207524_item	2743681	et	4	main
ä	doc_582053207524_item	2743682	et	4	main
tähendab	doc_582053207524_item	2743737	et	3	main
sellest	doc_582053207524_item	2743744	et	4	main
isik	doc_582053207524_item	2743746	et	3	main
on	doc_582053207524_item	2743753	et	4	main
vead	doc_582053207524_item	2743758	et	4	main
kui	doc_582053207524_item	2743762	et	3	main
ja	doc_582053207524_item	2743765	et	3	main
ning	doc_582053207524_item	2743778	et	3	main
kasutusreeglid	doc_582053207524_item	2743780	et	3	main
da-infinitiivi	doc_582053207524_item	2743805	et	4	main
vigu	doc_582053207524_item	2743806	et	3	main
esinevad	doc_582053207524_item	2743821	et	4	main
kolmest	doc_582053207524_item	2743823	et	4	main
kaks	doc_582053207524_item	2743826	et	3	main
ja	doc_582053207524_item	2743830	et	3	main
üks	doc_582053207524_item	2743831	et	3	main
neist	doc_582053207524_item	2743832	et	4	main
dikteerib	doc_582053207524_item	2743833	et	3	main
inimesel	doc_582053207524_item	2743840	et	3	main
ja	doc_582053207524_item	2743845	et	3	main
et	doc_582053207524_item	2743852	et	3	main
ja	doc_582053207524_item	2743862	et	3	main
verbi	doc_582053207524_item	2743870	et	4	main
infinitiivvormide	doc_582053207524_item	2743887	et	4	main
moodustamise	doc_582053207524_item	2743888	et	4	main
ja	doc_582053207524_item	2743889	et	3	main
tingitud	doc_582053207524_item	2743894	et	4	main
ei	doc_582053207524_item	2743898	et	4	main
ole	doc_582053207524_item	2743899	et	4	main
vajalikus	doc_582053207524_item	2743900	et	4	main
antud	doc_582053207524_item	2743906	et	4	main
keerulised	doc_582053207524_item	2743923	et	4	main
teadmisi	doc_582053207524_item	2743940	et	4	main
vältida	doc_582053207524_item	2743948	et	3	main
neid	doc_582053207524_item	2743951	et	4	main
verbe	doc_582053207524_item	2743952	et	3	main
pähe	doc_582053207524_item	2743953	et	4	main
raames	doc_582053207524_item	2743961	et	4	main
on	doc_582053207524_item	2743962	et	4	main
vale	doc_582053207524_item	2743972	et	4	main
ininitiiv	doc_582053207524_item	2743973	et	4	main
8	doc_582053207524_item	2743977	et	2	main
arvatavasti	doc_582053207524_item	2743981	et	3	main
põhjuseks	doc_582053207524_item	2743525	et	3	main
või	doc_582053207524_item	2743539	et	4	main
vormis	doc_582053207524_item	2743550	et	4	main
järjestatakse	doc_582053207524_item	2743551	et	3	main
ööst	doc_582053207524_item	2743555	et	3	main
tuli	doc_582053207524_item	2743556	et	4	main
välja	doc_582053207524_item	2743557	et	4	main
eesti	doc_582053207524_item	2743559	et	4	main
et	doc_582053207524_item	2743558	et	3	main
keeles	doc_582053207524_item	2743560	et	4	main
ühildub	doc_582053207524_item	2743561	et	3	main
ma	doc_582053207524_item	2743562	et	3	main
ja	doc_582053207524_item	2743563	et	3	main
da	doc_582053207524_item	2743564	et	4	main
infinitiiv	doc_582053207524_item	2743565	et	3	main
üheks	doc_582053207524_item	2743524	et	3	main
arvatavasti	doc_582053207524_item	2743527	et	3	main
et	doc_582053207524_item	2743529	et	3	main
lastele	doc_582053207524_item	2743537	et	4	main
koolis	doc_582053207524_item	2743538	et	4	main
peetakse	doc_582053207524_item	2743543	et	3	main
verbi	doc_582053207524_item	2743545	et	4	main
verbid	doc_582053207524_item	2743552	et	3	main
sõnastikes	doc_582053207524_item	2743553	et	3	main
t	doc_582053207524_item	2743554	et	4	main
tähendust	doc_582053207524_item	2743571	et	4	main
tegevuse	doc_582053207524_item	2743591	et	4	main
võib	doc_582053207524_item	2743598	et	3	main
mis	doc_582053207524_item	2743608	et	4	main
verbidega	doc_582053207524_item	2743566	et	3	main
näitavad	doc_582053207524_item	2743568	et	4	main
ja	doc_582053207524_item	2743576	et	3	main
infinitiivi	doc_582053207524_item	2743578	et	4	main
valikut	doc_582053207524_item	2743579	et	3	main
väita	doc_582053207524_item	2743581	et	4	main
väljendatakse	doc_582053207524_item	2743584	et	3	main
üheks	doc_582053207524_item	2743593	et	3	main
vigade	doc_582053207524_item	2743594	et	3	main
tekkimise	doc_582053207524_item	2743596	et	4	main
et	doc_582053207524_item	2743601	et	3	main
kõneleja	doc_582053207524_item	2743602	et	4	main
eesti	doc_582053207524_item	2743604	et	4	main
aspekti	doc_582053207524_item	2743609	et	4	main
tema	doc_582053207524_item	2743613	et	4	main
emakeeles	doc_582053207524_item	2743614	et	4	main
kuigi	doc_582053207524_item	2743615	et	3	main
tihti	doc_582053207524_item	2743616	et	3	main
ei	doc_582053207524_item	2743619	et	4	main
ja	doc_582053207524_item	2743622	et	3	main
kehtib	doc_582053207524_item	2743623	et	3	main
teine	doc_582053207524_item	2743624	et	3	main
rektsioon	doc_582053207524_item	2743628	et	3	main
selle	doc_582053207524_item	2743629	et	4	main
tüübi	doc_582053207524_item	2743630	et	3	main
analüüsis	doc_582053207524_item	2743634	et	4	main
umbes	doc_582053207524_item	2743635	et	4	main
analüüs	doc_582053207524_item	2743637	et	3	main
näitas	doc_582053207524_item	2743638	et	3	main
vigadest	doc_582053207524_item	2743643	et	3	main
seda	doc_582053207524_item	2743651	et	3	main
vene	doc_582053207524_item	2743658	et	4	main
emakeele	doc_582053207524_item	2743661	et	4	main
kõnelejad	doc_582053207524_item	2743662	et	4	main
iga	doc_582053207524_item	2743669	et	4	main
kord	doc_582053207524_item	2743670	et	4	main
kui	doc_582053207524_item	2743671	et	3	main
kahtlevad	doc_582053207524_item	2743672	et	4	main
samuti	doc_582053207524_item	2743676	et	3	main
liikumist	doc_582053207524_item	2743678	et	4	main
verbidega	doc_582053207524_item	2743680	et	3	main
analüüsis	doc_582053207524_item	2743684	et	4	main
da-infinitiivi	doc_582053207524_item	2743741	et	4	main
sõltub	doc_582053207524_item	2743743	et	3	main
või	doc_582053207524_item	2743747	et	4	main
on	doc_582053207524_item	2743750	et	4	main
passiivne	doc_582053207524_item	2743756	et	3	main
ka	doc_582053207524_item	2743760	et	3	main
kahes	doc_582053207524_item	2743769	et	4	main
väärase	doc_582053207524_item	2743791	et	4	main
infinitiivi	doc_582053207524_item	2743792	et	4	main
eesti	doc_582053207524_item	2743793	et	4	main
hulk	doc_582053207524_item	2743796	et	3	main
reeglite	doc_582053207524_item	2743800	et	3	main
järgi	doc_582053207524_item	2743801	et	4	main
kas	doc_582053207524_item	2743802	et	3	main
ma-	doc_582053207524_item	2743803	et	3	main
või	doc_582053207524_item	2743804	et	4	main
reegel	doc_582053207524_item	2743625	et	3	main
või	doc_582053207524_item	2743626	et	4	main
umbes	doc_582053207524_item	2743640	et	4	main
konstruktsioonides	doc_582053207524_item	2743646	et	3	main
põhjuseks	doc_582053207524_item	2743648	et	3	main
modaalverbid	doc_582053207524_item	2743653	et	4	main
enamasti	doc_582053207524_item	2743655	et	4	main
da-infinitiivi	doc_582053207524_item	2743656	et	4	main
aga	doc_582053207524_item	2743657	et	3	main
pidavad	doc_582053207524_item	2743663	et	4	main
leidus	doc_582053207524_item	2743685	et	4	main
15	doc_582053207524_item	2743686	et	2	main
need	doc_582053207524_item	2743689	et	3	main
verbid	doc_582053207524_item	2743690	et	3	main
nõuavad	doc_582053207524_item	2743691	et	4	main
tavaliselt	doc_582053207524_item	2743692	et	4	main
ma-infinitiivi	doc_582053207524_item	2743693	et	4	main
kuigi	doc_582053207524_item	2743694	et	3	main
venelased	doc_582053207524_item	2743695	et	3	main
kipuvad	doc_582053207524_item	2743696	et	3	main
kasutama	doc_582053207524_item	2743697	et	3	main
nende	doc_582053207524_item	2743698	et	4	main
da-infinitiivi	doc_582053207524_item	2743700	et	4	main
vene	doc_582053207524_item	2743701	et	4	main
verbidega	doc_582053207524_item	2743699	et	3	main
keeles	doc_582053207524_item	2743702	et	4	main
nõuavad	doc_582053207524_item	2743703	et	4	main
liikumist	doc_582053207524_item	2743704	et	4	main
väljendavad	doc_582053207524_item	2743705	et	4	main
verbid	doc_582053207524_item	2743706	et	3	main
imperfektiivset	doc_582053207524_item	2743707	et	3	main
aspekti	doc_582053207524_item	2743708	et	4	main
aga	doc_582053207524_item	2743709	et	3	main
eesti	doc_582053207524_item	2743710	et	4	main
keeles	doc_582053207524_item	2743711	et	4	main
väljendab	doc_582053207524_item	2743712	et	3	main
imperfektiivset	doc_582053207524_item	2743713	et	3	main
aspekti	doc_582053207524_item	2743714	et	4	main
da-infinitiiv	doc_582053207524_item	2743715	et	3	main
arvatavasti	doc_582053207524_item	2743716	et	3	main
püüab	doc_582053207524_item	2743717	et	3	main
kõneleja	doc_582053207524_item	2743718	et	4	main
sihtkeelede	doc_582053207524_item	2743719	et	4	main
emakeele	doc_582053207524_item	2743720	et	4	main
ma-	doc_582053207524_item	2743739	et	3	main
suunatud	doc_582053207524_item	2743752	et	4	main
tegija	doc_582053207524_item	2743757	et	4	main
tekivad	doc_582053207524_item	2743759	et	3	main
tähendused	doc_582053207524_item	2743764	et	4	main
ei	doc_582053207524_item	2743767	et	4	main
lange	doc_582053207524_item	2743768	et	4	main
kokku	doc_582053207524_item	2743771	et	3	main
ühte	doc_582053207524_item	2743773	et	4	main
neid	doc_582053207524_item	2743786	et	4	main
verbe	doc_582053207524_item	2743787	et	3	main
üldistama	doc_582053207524_item	2743788	et	3	main
valides	doc_582053207524_item	2743789	et	3	main
tihtipeale	doc_582053207524_item	2743790	et	3	main
on	doc_582053207524_item	2743795	et	4	main
tehakse	doc_582053207524_item	2743807	et	3	main
kõige	doc_582053207524_item	2743808	et	4	main
sagedamini	doc_582053207524_item	2743809	et	4	main
juhul	doc_582053207524_item	2743810	et	3	main
kui	doc_582053207524_item	2743811	et	3	main
need	doc_582053207524_item	2743812	et	3	main
reeglid	doc_582053207524_item	2743813	et	3	main
jäävad	doc_582053207524_item	2743814	et	4	main
omandamata	doc_582053207524_item	2743815	et	4	main
vigu	doc_582053207524_item	2743817	et	3	main
on	doc_582053207524_item	2743818	et	4	main
35	doc_582053207524_item	2743819	et	2	main
vead	doc_582053207524_item	2743820	et	4	main
milles	doc_582053207524_item	2743825	et	3	main
teise	doc_582053207524_item	2743834	et	4	main
vormi	doc_582053207524_item	2743835	et	4	main
võivad	doc_582053207524_item	2743841	et	4	main
põhisõnad	doc_582053207524_item	2743844	et	3	main
laiendid	doc_582053207524_item	2743847	et	3	main
arvatavasti	doc_582053207524_item	2743850	et	3	main
konstruktsioonides	doc_582053207524_item	2743854	et	3	main
on	doc_582053207524_item	2743855	et	4	main
kõneleja	doc_582053207524_item	2743863	et	4	main
on	doc_582053207524_item	2743876	et	4	main
õpilaste	doc_582053207524_item	2743883	et	4	main
töödes	doc_582053207524_item	2743885	et	3	main
et	doc_582053207524_item	2743896	et	3	main
õppijad	doc_582053207524_item	2743897	et	4	main
anal	doc_582053207524_item	2743907	et	4	main
umbes	doc_582053207524_item	2743913	et	4	main
vene	doc_582053207524_item	2743924	et	4	main
kui	doc_582053207524_item	2743926	et	3	main
vene	doc_582053207524_item	2743935	et	4	main
keeletundmist	doc_582053207524_item	2743942	et	3	main
on	doc_582053207524_item	2743949	et	4	main
juhtumeid	doc_582053207524_item	2743957	et	3	main
kus	doc_582053207524_item	2743958	et	3	main
õige	doc_582053207524_item	2743969	et	4	main
kui	doc_582053207524_item	2743970	et	3	main
on	doc_582053207524_item	2743976	et	4	main
tulevad	doc_582053207524_item	2743980	et	4	main
üks	doc_582053207524_item	2743989	et	3	main
teist	doc_582053207524_item	2743995	et	4	main
kasutusreeglid	doc_582053207524_item	2744021	et	3	main
verbide	doc_582053207524_item	2744027	et	3	main
õppimata	doc_582053207524_item	2744030	et	4	main
vahetevahel	doc_582053207524_item	2744031	et	3	main
tulenevad	doc_582053207524_item	2744032	et	4	main
juhul	doc_582053207524_item	2744038	et	3	main
on	doc_582053207524_item	2744042	et	4	main
üksik	doc_582053207524_item	2744047	et	3	main
infinitiivi	doc_582053207524_item	2744051	et	4	main
asub	doc_582053207524_item	2744053	et	3	main
lõpus	doc_582053207524_item	2744055	et	4	main
keeles	doc_582053207524_item	2743770	et	4	main
tähendust	doc_582053207524_item	2743774	et	4	main
väljendab	doc_582053207524_item	2743775	et	3	main
mitu	doc_582053207524_item	2743776	et	4	main
nende	doc_582053207524_item	2743779	et	4	main
verbe	doc_582053207524_item	2743797	et	3	main
neid	doc_582053207524_item	2743816	et	4	main
ühendis	doc_582053207524_item	2743822	et	3	main
kui	doc_582053207524_item	2743836	et	3	main
fraas	doc_582053207524_item	2743837	et	3	main
on	doc_582053207524_item	2743838	et	4	main
nende	doc_582053207524_item	2743846	et	4	main
põhjuseks	doc_582053207524_item	2743848	et	3	main
sõnajärjestus	doc_582053207524_item	2743857	et	3	main
see	doc_582053207524_item	2743858	et	3	main
kõnelejat	doc_582053207524_item	2743860	et	4	main
tavaliselt	doc_582053207524_item	2743877	et	4	main
aga	doc_582053207524_item	2743881	et	3	main
kasutamise	doc_582053207524_item	2743890	et	4	main
infinitiivi	doc_582053207524_item	2743904	et	4	main
kasutamisreegleid	doc_582053207524_item	2743905	et	3	main
on	doc_582053207524_item	2743911	et	4	main
13	doc_582053207524_item	2743912	et	2	main
kogu	doc_582053207524_item	2743915	et	4	main
arvust	doc_582053207524_item	2743917	et	4	main
emakeele	doc_582053207524_item	2743927	et	4	main
kõnelejate	doc_582053207524_item	2743928	et	4	main
eesti	doc_582053207524_item	2743933	et	4	main
keelest	doc_582053207524_item	2743934	et	4	main
ja	doc_582053207524_item	2743941	et	3	main
võimaluseks	doc_582053207524_item	2743945	et	3	main
õppida	doc_582053207524_item	2743950	et	3	main
ühe	doc_582053207524_item	2743959	et	4	main
kasutatud	doc_582053207524_item	2743963	et	4	main
ühe	doc_582053207524_item	2743964	et	4	main
sellist	doc_582053207524_item	2743974	et	4	main
ja	doc_582053207524_item	2743978	et	3	main
lohakast	doc_582053207524_item	2743984	et	3	main
õppija	doc_582053207524_item	2743988	et	4	main
kasutas	doc_582053207524_item	2743991	et	3	main
õige	doc_582053207524_item	2743992	et	4	main
infinitiivi	doc_582053207524_item	2743993	et	4	main
aga	doc_582053207524_item	2743994	et	3	main
verbist	doc_582053207524_item	2743824	et	3	main
on	doc_582053207524_item	2743827	et	4	main
infinitiivi	doc_582053207524_item	2743828	et	4	main
vormis	doc_582053207524_item	2743829	et	4	main
pikk	doc_582053207524_item	2743839	et	4	main
segamini	doc_582053207524_item	2743842	et	4	main
on	doc_582053207524_item	2743849	et	4	main
sellistes	doc_582053207524_item	2743853	et	4	main
eksitav	doc_582053207524_item	2743856	et	4	main
ajab	doc_582053207524_item	2743859	et	3	main
segadusse	doc_582053207524_item	2743861	et	3	main
ei	doc_582053207524_item	2743864	et	4	main
vormi	doc_582053207524_item	2743871	et	4	main
õigesti	doc_582053207524_item	2743879	et	3	main
esinevad	doc_582053207524_item	2743886	et	4	main
on	doc_582053207524_item	2743892	et	4	main
tihti	doc_582053207524_item	2743893	et	3	main
ulatuses	doc_582053207524_item	2743901	et	4	main
omandanud	doc_582053207524_item	2743902	et	4	main
üü	doc_582053207524_item	2743908	et	4	main
71	doc_582053207524_item	2743914	et	2	main
vigade	doc_582053207524_item	2743916	et	3	main
infinitiivide	doc_582053207524_item	2743918	et	3	main
käändelised	doc_582053207524_item	2743919	et	4	main
vormid	doc_582053207524_item	2743920	et	4	main
eriti	doc_582053207524_item	2743922	et	3	main
keel	doc_582053207524_item	2743925	et	4	main
jaoks	doc_582053207524_item	2743929	et	4	main
kuna	doc_582053207524_item	2743930	et	3	main
keelde	doc_582053207524_item	2743936	et	4	main
nõuab	doc_582053207524_item	2743937	et	3	main
väga	doc_582053207524_item	2743938	et	3	main
ja	doc_582053207524_item	2743943	et	3	main
neid	doc_582053207524_item	2743946	et	4	main
vigu	doc_582053207524_item	2743947	et	3	main
on	doc_582053207524_item	2743956	et	4	main
ja	doc_582053207524_item	2743965	et	3	main
sama	doc_582053207524_item	2743966	et	4	main
verbiga	doc_582053207524_item	2743967	et	3	main
nii	doc_582053207524_item	2743968	et	3	main
viga	doc_582053207524_item	2743975	et	4	main
need	doc_582053207524_item	2743979	et	3	main
tähelepanematusest	doc_582053207524_item	2743983	et	3	main
keelde	doc_582053207524_item	2743986	et	4	main
kui	doc_582053207524_item	2744025	et	3	main
vead	doc_582053207524_item	2744033	et	4	main
kui	doc_582053207524_item	2744044	et	3	main
või	doc_582053207524_item	2744046	et	4	main
verb	doc_582053207524_item	2744048	et	3	main
eksitakse	doc_582053207524_item	2744068	et	4	main
hakkama	doc_582053207524_item	2744072	et	3	main
see	doc_582053207524_item	2744075	et	3	main
tingitud	doc_582053207524_item	2744078	et	4	main
tõttu	doc_582053207524_item	2744088	et	4	main
verbiga	doc_582053207524_item	2744096	et	3	main
teisi	doc_582053207524_item	2744099	et	4	main
pidama	doc_582053207524_item	2744101	et	4	main
on	doc_582053207524_item	2744102	et	4	main
nende	doc_582053207524_item	2744114	et	4	main
milleta	doc_582053207525_item	2744118	et	3	main
ei	doc_582053207525_item	2744119	et	4	main
elada	doc_582053207525_item	2744122	et	3	main
ei	doc_582053207525_item	2744124	et	4	main
ei	doc_582053207525_item	2744129	et	4	main
saa	doc_582053207525_item	2744130	et	4	main
elada	doc_582053207525_item	2744131	et	3	main
on	doc_582053207525_item	2744139	et	4	main
tema	doc_582053207525_item	2744143	et	4	main
hoolitsevad	doc_582053207525_item	2744145	et	4	main
ja	doc_582053207525_item	2744146	et	3	main
teda	doc_582053207525_item	2744147	et	4	main
hirmus	doc_582053207525_item	2744155	et	4	main
areneda	doc_582053207525_item	2744159	et	3	main
ta	doc_582053207525_item	2744162	et	4	main
väga	doc_582053207525_item	2744173	et	3	main
kui	doc_582053207525_item	2744176	et	3	main
saanud	doc_582053207525_item	2744179	et	4	main
kirjalikes	doc_582053207524_item	2743884	et	3	main
vead	doc_582053207524_item	2743891	et	4	main
sellest	doc_582053207524_item	2743895	et	4	main
vastava	doc_582053207524_item	2743903	et	4	main
sis	doc_582053207524_item	2743909	et	3	main
neid	doc_582053207524_item	2743910	et	4	main
on	doc_582053207524_item	2743921	et	4	main
nende	doc_582053207524_item	2743931	et	4	main
tõlge	doc_582053207524_item	2743932	et	3	main
sügavaid	doc_582053207524_item	2743939	et	4	main
ainukeseks	doc_582053207524_item	2743944	et	4	main
umbes	doc_582053207524_item	2743954	et	4	main
5	doc_582053207524_item	2743955	et	2	main
lause	doc_582053207524_item	2743960	et	4	main
ka	doc_582053207524_item	2743971	et	3	main
kõneleja	doc_582053207524_item	2743982	et	4	main
suhtumisest	doc_582053207524_item	2743985	et	4	main
korda	doc_582053207524_item	2743996	et	4	main
tegi	doc_582053207524_item	2743997	et	4	main
sama	doc_582053207524_item	2743998	et	4	main
verbiga	doc_582053207524_item	2743999	et	3	main
vea	doc_582053207524_item	2744000	et	4	main
saab	doc_582053207524_item	2744001	et	3	main
järeldada	doc_582053207524_item	2744002	et	3	main
et	doc_582053207524_item	2744003	et	3	main
ta	doc_582053207524_item	2744004	et	4	main
tegi	doc_582053207524_item	2744005	et	4	main
seda	doc_582053207524_item	2744006	et	3	main
kogemata	doc_582053207524_item	2744007	et	4	main
tähelepanematusest	doc_582053207524_item	2744008	et	3	main
mõnikord	doc_582053207524_item	2744009	et	3	main
vead	doc_582053207524_item	2744010	et	4	main
tekivad	doc_582053207524_item	2744011	et	3	main
ka	doc_582053207524_item	2744012	et	3	main
juhul	doc_582053207524_item	2744013	et	3	main
kui	doc_582053207524_item	2744014	et	3	main
kõneleja	doc_582053207524_item	2744015	et	4	main
võõrkeelt	doc_582053207524_item	2744016	et	4	main
õppides	doc_582053207524_item	2744017	et	4	main
sai	doc_582053207524_item	2744018	et	4	main
mõnede	doc_582053207524_item	2744019	et	3	main
verbide	doc_582053207524_item	2744020	et	3	main
ajal	doc_582053207524_item	2744024	et	4	main
põhifraasi	doc_582053207524_item	2744034	et	4	main
positsioonist	doc_582053207524_item	2744035	et	3	main
sõltub	doc_582053207524_item	2744050	et	3	main
valik	doc_582053207524_item	2744052	et	3	main
kõneleja	doc_582053207524_item	2744058	et	4	main
pidama	doc_582053207524_item	2744071	et	4	main
olla	doc_582053207524_item	2744077	et	3	main
sellest	doc_582053207524_item	2744079	et	4	main
põhisõnavara	doc_582053207524_item	2744084	et	4	main
asendatakse	doc_582053207524_item	2744098	et	3	main
sõnu	doc_582053207524_item	2744100	et	4	main
kasutatav	doc_582053207524_item	2744105	et	4	main
verb	doc_582053207524_item	2744106	et	3	main
on	doc_582053207524_item	2744116	et	4	main
suurem	doc_582053207524_item	2744117	et	4	main
kindlasti	doc_582053207525_item	2744140	et	3	main
ilma	doc_582053207525_item	2744150	et	4	main
armastuseta	doc_582053207525_item	2744151	et	4	main
problemeid	doc_582053207525_item	2744169	et	4	main
või	doc_582053207525_item	2744175	et	4	main
kui	doc_582053207524_item	2743987	et	3	main
kord	doc_582053207524_item	2743990	et	4	main
samal	doc_582053207524_item	2744023	et	3	main
reeglid	doc_582053207524_item	2744028	et	3	main
lauses	doc_582053207524_item	2744036	et	3	main
kõneleja	doc_582053207524_item	2744040	et	4	main
oska	doc_582053207524_item	2744057	et	4	main
tihedamini	doc_582053207524_item	2744070	et	4	main
võib	doc_582053207524_item	2744076	et	3	main
sageli	doc_582053207524_item	2744095	et	3	main
sagedamini	doc_582053207524_item	2744104	et	4	main
mis	doc_582053207524_item	2744107	et	4	main
väljendab	doc_582053207524_item	2744108	et	3	main
kohustust	doc_582053207524_item	2744109	et	4	main
järelikult	doc_582053207524_item	2744110	et	3	main
võimalus	doc_582053207524_item	2744111	et	3	main
teha	doc_582053207524_item	2744112	et	3	main
kasutamisel	doc_582053207524_item	2744115	et	4	main
saa	doc_582053207525_item	2744120	et	4	main
selgeks	doc_582053207524_item	2744022	et	3	main
teiste	doc_582053207524_item	2744026	et	4	main
jäid	doc_582053207524_item	2744029	et	4	main
eriti	doc_582053207524_item	2744037	et	3	main
kui	doc_582053207524_item	2744039	et	3	main
keeletase	doc_582053207524_item	2744041	et	3	main
madal	doc_582053207524_item	2744043	et	3	main
konstruktsioon	doc_582053207524_item	2744045	et	3	main
millest	doc_582053207524_item	2744049	et	3	main
lause	doc_582053207524_item	2744054	et	4	main
reeglit	doc_582053207524_item	2744059	et	3	main
järgida	doc_582053207524_item	2744060	et	3	main
uurimuse	doc_582053207524_item	2744061	et	3	main
põhjal	doc_582053207524_item	2744062	et	4	main
saab	doc_582053207524_item	2744063	et	3	main
teha	doc_582053207524_item	2744064	et	3	main
järelduse	doc_582053207524_item	2744065	et	4	main
et	doc_582053207524_item	2744066	et	3	main
verbidest	doc_582053207524_item	2744067	et	3	main
ei	doc_582053207524_item	2744056	et	4	main
kõige	doc_582053207524_item	2744069	et	4	main
tahtma	doc_582053207524_item	2744073	et	3	main
sisse	doc_582053207524_item	2744085	et	4	main
ja	doc_582053207524_item	2744086	et	3	main
selle	doc_582053207524_item	2744087	et	4	main
hakkama	doc_582053207524_item	2744097	et	3	main
kõige	doc_582053207524_item	2744103	et	4	main
viga	doc_582053207524_item	2744113	et	4	main
milleta	doc_582053207525_item	2744123	et	3	main
inimene	doc_582053207525_item	2744128	et	3	main
lapsel	doc_582053207525_item	2744138	et	4	main
et	doc_582053207525_item	2744142	et	3	main
eest	doc_582053207525_item	2744144	et	4	main
ta	doc_582053207525_item	2744152	et	4	main
tunneb	doc_582053207525_item	2744153	et	3	main
ebakindlustus	doc_582053207525_item	2744154	et	3	main
täisväärtusliku	doc_582053207525_item	2744158	et	3	main
kui	doc_582053207525_item	2744161	et	3	main
natukene	doc_582053207525_item	2744163	et	4	main
kasvab	doc_582053207525_item	2744164	et	3	main
siis	doc_582053207525_item	2744165	et	3	main
juhtuvad	doc_582053207525_item	2744166	et	4	main
ei	doc_582053207525_item	2744178	et	4	main
armastus	doc_582053207525_item	2744180	et	4	main
siis	doc_582053207525_item	2744181	et	3	main
kui	doc_582053207525_item	2744182	et	3	main
ta	doc_582053207525_item	2744183	et	4	main
vene	doc_582053207526_item	2744233	et	4	main
kool	doc_582053207526_item	2744234	et	4	main
valik	doc_582053207526_item	2744247	et	3	main
kus	doc_582053207526_item	2744248	et	3	main
ja	doc_582053207526_item	2744249	et	3	main
kuidas	doc_582053207526_item	2744250	et	3	main
ja	doc_582053207526_item	2744258	et	3	main
keelt	doc_582053207526_item	2744277	et	4	main
ja	doc_582053207526_item	2744278	et	3	main
näiteks	doc_582053207526_item	2744281	et	4	main
lihtsalt	doc_582053207526_item	2744288	et	4	main
sellepärast	doc_582053207526_item	2744289	et	3	main
et	doc_582053207526_item	2744290	et	3	main
on	doc_582053207526_item	2744298	et	4	main
eestlased	doc_582053207526_item	2744299	et	3	main
koolides	doc_582053207526_item	2744329	et	3	main
eesti	doc_582053207526_item	2744331	et	4	main
aga	doc_582053207526_item	2744333	et	3	main
tahan	doc_582053207526_item	2744338	et	3	main
meie	doc_582053207526_item	2744340	et	4	main
olema	doc_582053207526_item	2744349	et	4	main
valik	doc_582053207526_item	2744350	et	3	main
kus	doc_582053207526_item	2744351	et	3	main
kellena	doc_582053207526_item	2744352	et	3	main
ta	doc_582053207526_item	2744355	et	4	main
tahab	doc_582053207526_item	2744356	et	3	main
õppida	doc_582053207526_item	2744357	et	3	main
muidugi	doc_582053207526_item	2744358	et	4	main
ise	doc_582053207526_item	2744361	et	4	main
keel	doc_582053207526_item	2744363	et	4	main
mis	doc_582053207526_item	2744364	et	4	main
kättesaadav	doc_582053207526_item	2744371	et	4	main
ja	doc_582053207526_item	2744372	et	3	main
ema	doc_582053207526_item	2744373	et	4	main
elada	doc_582053207527_item	2744409	et	3	main
maailmas	doc_582053207527_item	2744410	et	3	main
vajalikud	doc_582053207527_item	2744421	et	3	main
vesi	doc_582053207527_item	2744432	et	4	main
toit	doc_582053207527_item	2744433	et	3	main
nii	doc_582053207527_item	2744436	et	3	main
teises	doc_582053207527_item	2744438	et	4	main
on	doc_582053207527_item	2744440	et	4	main
sotsiaalset	doc_582053207527_item	2744441	et	3	main
asjad	doc_582053207527_item	2744442	et	3	main
nii	doc_582053207527_item	2744443	et	3	main
vised	doc_582053207527_item	2744444	et	4	main
kolmas	doc_582053207527_item	2744451	et	3	main
on	doc_582053207527_item	2744453	et	4	main
asjad	doc_582053207527_item	2744455	et	3	main
saab	doc_582053207527_item	2744458	et	3	main
raha	doc_582053207527_item	2744460	et	4	main
eest	doc_582053207527_item	2744461	et	4	main
autod	doc_582053207527_item	2744462	et	3	main
kinno	doc_582053207527_item	2744471	et	3	main
verbidega	doc_582053207524_item	2744074	et	3	main
et	doc_582053207524_item	2744080	et	3	main
need	doc_582053207524_item	2744081	et	3	main
verbid	doc_582053207524_item	2744082	et	3	main
kuuluvad	doc_582053207524_item	2744083	et	4	main
neid	doc_582053207524_item	2744089	et	4	main
kasutatakse	doc_582053207524_item	2744090	et	3	main
kõnes	doc_582053207524_item	2744091	et	3	main
ja	doc_582053207524_item	2744092	et	3	main
kirjas	doc_582053207524_item	2744093	et	4	main
eriti	doc_582053207524_item	2744094	et	3	main
inimene	doc_582053207525_item	2744121	et	3	main
ilma	doc_582053207525_item	2744132	et	4	main
armastuseta	doc_582053207525_item	2744133	et	4	main
ükskõik	doc_582053207525_item	2744134	et	3	main
millises	doc_582053207525_item	2744135	et	3	main
eas	doc_582053207525_item	2744136	et	3	main
väikesel	doc_582053207525_item	2744137	et	4	main
vaja	doc_582053207525_item	2744141	et	4	main
saa	doc_582053207525_item	2744157	et	4	main
pärast	doc_582053207525_item	2744160	et	4	main
ta	doc_582053207525_item	2744170	et	4	main
saab	doc_582053207525_item	2744171	et	3	main
olla	doc_582053207525_item	2744172	et	3	main
agresiivne	doc_582053207525_item	2744174	et	4	main
laps	doc_582053207525_item	2744177	et	4	main
narkomaneid	doc_582053207525_item	2744222	et	4	main
et	doc_582053207525_item	2744224	et	3	main
taha	doc_582053207525_item	2744230	et	4	main
armastama	doc_582053207525_item	2744231	et	3	main
teineteist	doc_582053207525_item	2744232	et	4	main
vene	doc_582053207526_item	2744237	et	4	main
olema	doc_582053207526_item	2744246	et	4	main
ta	doc_582053207526_item	2744251	et	4	main
tahab	doc_582053207526_item	2744252	et	3	main
õppida	doc_582053207526_item	2744253	et	3	main
eesti	doc_582053207526_item	2744254	et	4	main
riigis	doc_582053207526_item	2744255	et	3	main
kes	doc_582053207526_item	2744273	et	4	main
tahavad	doc_582053207526_item	2744274	et	3	main
osata	doc_582053207526_item	2744275	et	4	main
vene	doc_582053207526_item	2744279	et	4	main
keelt	doc_582053207526_item	2744280	et	4	main
eesti	doc_582053207526_item	2744286	et	4	main
koolis	doc_582053207526_item	2744287	et	4	main
vene	doc_582053207526_item	2744303	et	4	main
keeles	doc_582053207526_item	2744321	et	4	main
paraleellselt	doc_582053207526_item	2744323	et	4	main
eesti	doc_582053207526_item	2744325	et	4	main
keel	doc_582053207526_item	2744326	et	4	main
lõpuks	doc_582053207526_item	2744337	et	4	main
peab	doc_582053207526_item	2744348	et	4	main
ta	doc_582053207526_item	2744359	et	4	main
valida	doc_582053207526_item	2744362	et	3	main
kõigile	doc_582053207526_item	2744370	et	4	main
inimene	doc_582053207527_item	2744408	et	3	main
on	doc_582053207527_item	2744411	et	4	main
nii	doc_582053207527_item	2744412	et	3	main
palju	doc_582053207527_item	2744413	et	4	main
ei	doc_582053207527_item	2744417	et	4	main
elada	doc_582053207527_item	2744419	et	3	main
jagab	doc_582053207527_item	2744423	et	3	main
riided	doc_582053207527_item	2744434	et	3	main
pere	doc_582053207527_item	2744445	et	4	main
sõbrad	doc_582053207527_item	2744447	et	3	main
edasi	doc_582053207527_item	2744450	et	3	main
need	doc_582053207527_item	2744456	et	3	main
osta	doc_582053207527_item	2744459	et	4	main
gruppis	doc_582053207527_item	2744466	et	4	main
teater	doc_582053207527_item	2744472	et	3	main
väga	doc_582053207527_item	2744500	et	3	main
ei	doc_582053207527_item	2744504	et	4	main
elada	doc_582053207527_item	2744506	et	3	main
mis	doc_582053207527_item	2744508	et	4	main
ole	doc_582053207527_item	2744510	et	4	main
temale	doc_582053207527_item	2744511	et	3	main
väga	doc_582053207527_item	2744512	et	3	main
on	doc_582053207527_item	2744523	et	4	main
materiaalsed	doc_582053207527_item	2744526	et	3	main
ei	doc_582053207528_item	2744530	et	4	main
saa	doc_582053207528_item	2744531	et	4	main
inimene	doc_582053207528_item	2744532	et	3	main
saa	doc_582053207525_item	2744125	et	4	main
inimene	doc_582053207525_item	2744126	et	3	main
elada	doc_582053207525_item	2744127	et	3	main
armastavad	doc_582053207525_item	2744148	et	4	main
siis	doc_582053207525_item	2744149	et	3	main
ei	doc_582053207525_item	2744156	et	4	main
koolis	doc_582053207525_item	2744167	et	4	main
igasuguseid	doc_582053207525_item	2744168	et	3	main
kasvab	doc_582053207525_item	2744184	et	3	main
suurem	doc_582053207525_item	2744185	et	4	main
hakkab	doc_582053207525_item	2744186	et	3	main
otsima	doc_582053207525_item	2744187	et	4	main
seda	doc_582053207525_item	2744188	et	3	main
ise	doc_582053207525_item	2744189	et	4	main
sõprade	doc_582053207525_item	2744190	et	3	main
hulkas	doc_582053207525_item	2744191	et	4	main
ka	doc_582053207525_item	2744192	et	3	main
kindlasti	doc_582053207525_item	2744193	et	3	main
vanainimesed	doc_582053207525_item	2744194	et	3	main
tahavad	doc_582053207525_item	2744195	et	3	main
et	doc_582053207525_item	2744196	et	3	main
neid	doc_582053207525_item	2744197	et	4	main
armastavad	doc_582053207525_item	2744198	et	4	main
ilma	doc_582053207525_item	2744199	et	4	main
armatuseta	doc_582053207525_item	2744200	et	4	main
inemene	doc_582053207525_item	2744201	et	4	main
tunneb	doc_582053207525_item	2744202	et	3	main
üksivus	doc_582053207525_item	2744203	et	4	main
õnnetu	doc_582053207525_item	2744204	et	4	main
ja	doc_582053207525_item	2744205	et	3	main
elus	doc_582053207525_item	2744206	et	4	main
on	doc_582053207525_item	2744207	et	4	main
rohkem	doc_582053207525_item	2744208	et	4	main
musta	doc_582053207525_item	2744209	et	4	main
värvi	doc_582053207525_item	2744210	et	4	main
kui	doc_582053207525_item	2744211	et	3	main
valge	doc_582053207525_item	2744212	et	4	main
praegu	doc_582053207525_item	2744213	et	3	main
maailmas	doc_582053207525_item	2744214	et	3	main
on	doc_582053207525_item	2744215	et	4	main
selline	doc_582053207525_item	2744216	et	4	main
olukord	doc_582053207525_item	2744217	et	3	main
kus	doc_582053207525_item	2744218	et	3	main
on	doc_582053207525_item	2744219	et	4	main
palju	doc_582053207525_item	2744220	et	4	main
enesetappe	doc_582053207525_item	2744223	et	4	main
inimesed	doc_582053207525_item	2744225	et	3	main
keeles	doc_582053207526_item	2744236	et	4	main
peab	doc_582053207526_item	2744245	et	4	main
elavad	doc_582053207526_item	2744256	et	4	main
eestlased	doc_582053207526_item	2744259	et	3	main
õppida	doc_582053207526_item	2744262	et	3	main
eesti	doc_582053207526_item	2744276	et	4	main
õpiks	doc_582053207526_item	2744285	et	4	main
osata	doc_582053207526_item	2744293	et	4	main
osata	doc_582053207526_item	2744302	et	4	main
kus	doc_582053207526_item	2744311	et	3	main
eesti	doc_582053207526_item	2744312	et	4	main
keele	doc_582053207526_item	2744313	et	4	main
süvaõpega	doc_582053207526_item	2744314	et	4	main
näiteks	doc_582053207526_item	2744315	et	4	main
venelane	doc_582053207526_item	2744316	et	3	main
saab	doc_582053207526_item	2744317	et	3	main
õpida	doc_582053207526_item	2744318	et	4	main
koolis	doc_582053207526_item	2744319	et	4	main
ema	doc_582053207526_item	2744320	et	4	main
kõigides	doc_582053207526_item	2744327	et	4	main
õppitakse	doc_582053207526_item	2744330	et	4	main
keel	doc_582053207526_item	2744332	et	4	main
pole	doc_582053207526_item	2744334	et	3	main
elus	doc_582053207526_item	2744341	et	4	main
on	doc_582053207526_item	2744344	et	4	main
ja	doc_582053207526_item	2744353	et	3	main
tahab	doc_582053207526_item	2744365	et	3	main
osata	doc_582053207526_item	2744366	et	4	main
haridus	doc_582053207526_item	2744367	et	3	main
asju	doc_582053207527_item	2744414	et	3	main
saa	doc_582053207527_item	2744418	et	4	main
asjad	doc_582053207527_item	2744422	et	3	main
gruppiks	doc_582053207527_item	2744425	et	4	main
ja	doc_582053207527_item	2744435	et	3	main
armsat	doc_582053207527_item	2744446	et	3	main
ja	doc_582053207527_item	2744448	et	3	main
gruppis	doc_582053207527_item	2744452	et	4	main
materiaalsed	doc_582053207527_item	2744454	et	3	main
maja	doc_582053207527_item	2744463	et	4	main
asjad	doc_582053207527_item	2744469	et	3	main
on	doc_582053207527_item	2744497	et	4	main
ta	doc_582053207527_item	2744503	et	4	main
on	doc_582053207527_item	2744516	et	4	main
väga	doc_582053207527_item	2744517	et	3	main
tähtis	doc_582053207527_item	2744518	et	4	main
väga	doc_582053207527_item	2744524	et	3	main
asjad	doc_582053207527_item	2744527	et	3	main
tänapäeval	doc_582053207528_item	2744533	et	3	main
elada	doc_582053207528_item	2744534	et	3	main
sa	doc_582053207528_item	2744535	et	3	main
küsisid	doc_582053207528_item	2744536	et	4	main
elada	doc_582053207528_item	2744543	et	3	main
meil	doc_582053207528_item	2744548	et	4	main
on	doc_582053207528_item	2744549	et	4	main
sellest	doc_582053207528_item	2744557	et	4	main
mobiiltelefoniga	doc_582053207528_item	2744559	et	4	main
autoga	doc_582053207528_item	2744560	et	3	main
elektriga	doc_582053207528_item	2744561	et	3	main
kütega	doc_582053207528_item	2744562	et	4	main
ja	doc_582053207528_item	2744563	et	3	main
loomulikult	doc_582053207528_item	2744564	et	4	main
rahaga	doc_582053207528_item	2744565	et	4	main
see	doc_582053207528_item	2744573	et	3	main
tähendab	doc_582053207528_item	2744574	et	3	main
inimene	doc_582053207528_item	2744576	et	3	main
elada	doc_582053207528_item	2744585	et	3	main
töötadaveel	doc_582053207528_item	2744588	et	4	main
saa	doc_582053207528_item	2744591	et	4	main
ilma	doc_582053207528_item	2744593	et	4	main
armastus	doc_582053207528_item	2744596	et	4	main
sest	doc_582053207529_item	2744629	et	4	main
sõjaid	doc_582053207525_item	2744221	et	4	main
ei	doc_582053207525_item	2744226	et	4	main
või	doc_582053207525_item	2744228	et	4	main
ei	doc_582053207525_item	2744229	et	4	main
eesti	doc_582053207526_item	2744235	et	4	main
keeles	doc_582053207526_item	2744240	et	4	main
ma	doc_582053207526_item	2744241	et	3	main
arvan	doc_582053207526_item	2744242	et	3	main
et	doc_582053207526_item	2744243	et	3	main
inimesel	doc_582053207526_item	2744244	et	3	main
tahavad	doc_582053207526_item	2744261	et	3	main
muidugi	doc_582053207526_item	2744263	et	4	main
on	doc_582053207526_item	2744267	et	4	main
inimesed	doc_582053207526_item	2744268	et	3	main
kui	doc_582053207526_item	2744269	et	3	main
venelased	doc_582053207526_item	2744270	et	3	main
nii	doc_582053207526_item	2744271	et	3	main
eestlased	doc_582053207526_item	2744272	et	3	main
vene	doc_582053207526_item	2744282	et	4	main
inimene	doc_582053207526_item	2744283	et	3	main
heameelega	doc_582053207526_item	2744284	et	3	main
ta	doc_582053207526_item	2744291	et	4	main
tahab	doc_582053207526_item	2744292	et	3	main
kes	doc_582053207526_item	2744300	et	4	main
tahavad	doc_582053207526_item	2744301	et	3	main
olema	doc_582053207526_item	2744309	et	4	main
koolid	doc_582053207526_item	2744310	et	3	main
oska	doc_582053207525_item	2744227	et	4	main
kool	doc_582053207526_item	2744238	et	4	main
eesti	doc_582053207526_item	2744239	et	4	main
venelased	doc_582053207526_item	2744257	et	3	main
nad	doc_582053207526_item	2744260	et	3	main
ema	doc_582053207526_item	2744264	et	4	main
keeles	doc_582053207526_item	2744265	et	4	main
aga	doc_582053207526_item	2744266	et	3	main
eesti	doc_582053207526_item	2744294	et	4	main
keelt	doc_582053207526_item	2744295	et	4	main
samuti	doc_582053207526_item	2744296	et	3	main
tagurpidi	doc_582053207526_item	2744297	et	3	main
keelt	doc_582053207526_item	2744304	et	4	main
mõtlen	doc_582053207526_item	2744305	et	3	main
et	doc_582053207526_item	2744306	et	3	main
samuti	doc_582053207526_item	2744307	et	3	main
peavad	doc_582053207526_item	2744308	et	4	main
ja	doc_582053207526_item	2744322	et	3	main
õppida	doc_582053207526_item	2744324	et	3	main
vene	doc_582053207526_item	2744328	et	4	main
kõigides	doc_582053207526_item	2744335	et	4	main
süvaõppega	doc_582053207526_item	2744336	et	3	main
öelda	doc_582053207526_item	2744339	et	4	main
meie	doc_582053207526_item	2744342	et	4	main
ajas	doc_582053207526_item	2744343	et	4	main
millal	doc_582053207526_item	2744354	et	3	main
peab	doc_582053207526_item	2744360	et	4	main
olema	doc_582053207526_item	2744369	et	4	main
inimesed	doc_582053207527_item	2744416	et	3	main
kõik	doc_582053207527_item	2744420	et	4	main
oluline	doc_582053207526_item	2744345	et	4	main
valik	doc_582053207526_item	2744346	et	3	main
inimesel	doc_582053207526_item	2744347	et	3	main
peab	doc_582053207526_item	2744368	et	4	main
keeles	doc_582053207526_item	2744374	et	4	main
olen	doc_582053207526_item	2744375	et	3	main
nõus	doc_582053207526_item	2744376	et	4	main
et	doc_582053207526_item	2744377	et	3	main
kui	doc_582053207526_item	2744378	et	3	main
inimene	doc_582053207526_item	2744379	et	3	main
elab	doc_582053207526_item	2744380	et	3	main
ühes	doc_582053207526_item	2744381	et	4	main
riigis	doc_582053207526_item	2744382	et	3	main
siis	doc_582053207526_item	2744383	et	3	main
peab	doc_582053207526_item	2744384	et	4	main
osata	doc_582053207526_item	2744385	et	4	main
riigikeel	doc_582053207526_item	2744386	et	4	main
aga	doc_582053207526_item	2744387	et	3	main
õppida	doc_582053207526_item	2744388	et	3	main
ja	doc_582053207526_item	2744389	et	3	main
võib	doc_582053207526_item	2744390	et	3	main
saada	doc_582053207526_item	2744391	et	4	main
hariduse	doc_582053207526_item	2744392	et	3	main
ema	doc_582053207526_item	2744393	et	4	main
keeles	doc_582053207526_item	2744394	et	4	main
või	doc_582053207526_item	2744395	et	4	main
keeles	doc_582053207526_item	2744396	et	4	main
mis	doc_582053207526_item	2744397	et	4	main
soovib	doc_582053207526_item	2744398	et	3	main
p	doc_582053207526_item	2744399	et	4	main
milleta	doc_582053207527_item	2744400	et	3	main
ei	doc_582053207527_item	2744401	et	4	main
saa	doc_582053207527_item	2744402	et	4	main
inimene	doc_582053207527_item	2744403	et	3	main
elada	doc_582053207527_item	2744404	et	3	main
milleta	doc_582053207527_item	2744405	et	3	main
ei	doc_582053207527_item	2744406	et	4	main
saa	doc_582053207527_item	2744407	et	4	main
milleta	doc_582053207527_item	2744415	et	3	main
neljaks	doc_582053207527_item	2744424	et	4	main
gruppi	doc_582053207527_item	2744427	et	4	main
gruppis	doc_582053207527_item	2744439	et	4	main
tvja	doc_582053207527_item	2744464	et	4	main
on	doc_582053207527_item	2744467	et	4	main
muusika	doc_582053207527_item	2744470	et	4	main
saa	doc_582053207527_item	2744505	et	4	main
ja	doc_582053207527_item	2744507	et	3	main
ei	doc_582053207527_item	2744509	et	4	main
vaimse	doc_582053207527_item	2744519	et	3	main
kellegile	doc_582053207527_item	2744522	et	4	main
ilma	doc_582053207528_item	2744537	et	4	main
milleta	doc_582053207528_item	2744538	et	3	main
ei	doc_582053207528_item	2744539	et	4	main
progress	doc_582053207528_item	2744551	et	3	main
elada	doc_582053207528_item	2744555	et	3	main
raha	doc_582053207528_item	2744566	et	4	main
see	doc_582053207528_item	2744567	et	3	main
on	doc_582053207528_item	2744568	et	4	main
töö	doc_582053207528_item	2744569	et	4	main
palju	doc_582053207528_item	2744587	et	4	main
elada	doc_582053207528_item	2744592	et	3	main
sulle	doc_582053207529_item	2744621	et	3	main
saada	doc_582053207529_item	2744626	et	4	main
sõpradetta	doc_582053207529_item	2744628	et	4	main
raha	doc_582053207529_item	2744637	et	4	main
vaja	doc_582053207529_item	2744652	et	4	main
lõppetan	doc_582053207529_item	2744661	et	4	main
sulle	doc_582053207529_item	2744664	et	3	main
ilma	doc_582053207530_item	2744667	et	4	main
talle	doc_582053207530_item	2744681	et	4	main
mitte	doc_582053207530_item	2744688	et	3	main
ei	doc_582053207530_item	2744721	et	4	main
olen	doc_582053207530_item	2744728	et	3	main
siis	doc_582053207530_item	2744730	et	3	main
loodus	doc_582053207530_item	2744745	et	4	main
annab	doc_582053207530_item	2744746	et	3	main
sõbradeta	doc_582053207530_item	2744759	et	4	main
minu	doc_582053207530_item	2744760	et	3	main
pereta	doc_582053207530_item	2744761	et	3	main
ja	doc_582053207530_item	2744762	et	3	main
muusikata	doc_582053207530_item	2744763	et	3	main
nädal	doc_582053207531_item	2744785	et	3	main
vastata	doc_582053207531_item	2744789	et	4	main
inemene	doc_582053207531_item	2744797	et	4	main
tänapäeval	doc_582053207531_item	2744798	et	3	main
elada	doc_582053207531_item	2744799	et	3	main
raha	doc_582053207531_item	2744809	et	4	main
teine	doc_582053207531_item	2744810	et	3	main
see	doc_582053207531_item	2744811	et	3	main
on	doc_582053207531_item	2744812	et	4	main
elu	doc_582053207531_item	2744813	et	4	main
kolmas	doc_582053207531_item	2744814	et	3	main
see	doc_582053207531_item	2744815	et	3	main
esimese	doc_582053207527_item	2744426	et	3	main
sisenevad	doc_582053207527_item	2744428	et	4	main
väga	doc_582053207527_item	2744429	et	3	main
vajalikud	doc_582053207527_item	2744430	et	3	main
asjad	doc_582053207527_item	2744431	et	3	main
edasi	doc_582053207527_item	2744437	et	3	main
nii	doc_582053207527_item	2744449	et	3	main
mis	doc_582053207527_item	2744457	et	4	main
neljandas	doc_582053207527_item	2744465	et	3	main
vaimsed	doc_582053207527_item	2744468	et	3	main
ma	doc_582053207527_item	2744473	et	3	main
mõtlen	doc_582053207527_item	2744474	et	3	main
et	doc_582053207527_item	2744475	et	3	main
kõik	doc_582053207527_item	2744476	et	4	main
gruppid	doc_582053207527_item	2744478	et	4	main
on	doc_582053207527_item	2744479	et	4	main
minu	doc_582053207527_item	2744480	et	3	main
need	doc_582053207527_item	2744477	et	3	main
jaoks	doc_582053207527_item	2744481	et	4	main
väga	doc_582053207527_item	2744482	et	3	main
tähtsad	doc_582053207527_item	2744483	et	3	main
seest	doc_582053207527_item	2744484	et	3	main
nendega	doc_582053207527_item	2744485	et	4	main
on	doc_582053207527_item	2744486	et	4	main
rõmsam	doc_582053207527_item	2744487	et	4	main
ja	doc_582053207527_item	2744488	et	3	main
huvitam	doc_582053207527_item	2744489	et	4	main
elada	doc_582053207527_item	2744490	et	3	main
iga	doc_582053207527_item	2744491	et	4	main
inemene	doc_582053207527_item	2744492	et	4	main
saab	doc_582053207527_item	2744493	et	3	main
ise	doc_582053207527_item	2744494	et	4	main
valida	doc_582053207527_item	2744495	et	3	main
mis	doc_582053207527_item	2744496	et	4	main
tema	doc_582053207527_item	2744498	et	4	main
jaoks	doc_582053207527_item	2744499	et	4	main
milleta	doc_582053207527_item	2744502	et	3	main
elu	doc_582053207527_item	2744520	et	4	main
aga	doc_582053207527_item	2744521	et	3	main
ilma	doc_582053207528_item	2744528	et	4	main
tehniline	doc_582053207528_item	2744550	et	3	main
ilma	doc_582053207528_item	2744556	et	4	main
pead	doc_582053207528_item	2744571	et	4	main
ei	doc_582053207528_item	2744577	et	4	main
elada	doc_582053207528_item	2744579	et	3	main
tööga	doc_582053207528_item	2744581	et	3	main
kui	doc_582053207528_item	2744582	et	3	main
tahad	doc_582053207528_item	2744583	et	3	main
ästi	doc_582053207528_item	2744584	et	4	main
armastus	doc_582053207528_item	2744594	et	4	main
on	doc_582053207528_item	2744595	et	4	main
esiteks	doc_582053207529_item	2744622	et	3	main
pole	doc_582053207529_item	2744623	et	3	main
on	doc_582053207529_item	2744631	et	4	main
raskel	doc_582053207529_item	2744634	et	3	main
perekonda	doc_582053207529_item	2744644	et	4	main
võimaldata	doc_582053207529_item	2744645	et	3	main
lastele	doc_582053207529_item	2744646	et	4	main
hea	doc_582053207529_item	2744647	et	4	main
haridus	doc_582053207529_item	2744648	et	3	main
töökohta	doc_582053207529_item	2744654	et	4	main
et	doc_582053207529_item	2744655	et	3	main
oleks	doc_582053207529_item	2744656	et	3	main
võimali	doc_582053207529_item	2744657	et	4	main
teostada	doc_582053207529_item	2744658	et	3	main
milleta	doc_582053207530_item	2744668	et	3	main
inimene	doc_582053207530_item	2744671	et	3	main
iga	doc_582053207530_item	2744673	et	4	main
inimene	doc_582053207530_item	2744674	et	3	main
teab	doc_582053207530_item	2744675	et	3	main
mida	doc_582053207530_item	2744676	et	4	main
tarvis	doc_582053207530_item	2744683	et	3	main
täna	doc_582053207530_item	2744684	et	4	main
inimesed	doc_582053207530_item	2744685	et	3	main
tähtsis	doc_582053207527_item	2744501	et	4	main
vaja	doc_582053207527_item	2744513	et	4	main
ühele	doc_582053207527_item	2744514	et	3	main
inimesele	doc_582053207527_item	2744515	et	3	main
vaja	doc_582053207527_item	2744525	et	4	main
milleta	doc_582053207528_item	2744529	et	3	main
saa	doc_582053207528_item	2744540	et	4	main
inimene	doc_582053207528_item	2744541	et	3	main
ma	doc_582053207528_item	2744544	et	3	main
praegu	doc_582053207528_item	2744547	et	3	main
ei	doc_582053207528_item	2744553	et	4	main
ilma	doc_582053207528_item	2744558	et	4	main
töötama	doc_582053207528_item	2744572	et	3	main
et	doc_582053207528_item	2744575	et	3	main
saa	doc_582053207528_item	2744578	et	4	main
ilma	doc_582053207528_item	2744580	et	4	main
inimene	doc_582053207528_item	2744589	et	3	main
tuju	doc_582053207528_item	2744599	et	4	main
ilma	doc_582053207529_item	2744600	et	4	main
milleta	doc_582053207529_item	2744601	et	3	main
ei	doc_582053207529_item	2744602	et	4	main
saa	doc_582053207529_item	2744603	et	4	main
inimene	doc_582053207529_item	2744604	et	3	main
tänapäeval	doc_582053207529_item	2744605	et	3	main
elada	doc_582053207529_item	2744606	et	3	main
tere	doc_582053207529_item	2744607	et	3	main
minu	doc_582053207529_item	2744608	et	3	main
sõber	doc_582053207529_item	2744609	et	3	main
meelis	doc_582053207529_item	2744610	et	3	main
sa	doc_582053207529_item	2744611	et	3	main
küsid	doc_582053207529_item	2744612	et	3	main
ilma	doc_582053207529_item	2744613	et	4	main
milleta	doc_582053207529_item	2744614	et	3	main
ei	doc_582053207529_item	2744615	et	4	main
saa	doc_582053207529_item	2744616	et	4	main
inimene	doc_582053207529_item	2744617	et	3	main
elada	doc_582053207529_item	2744618	et	3	main
tänapäeval	doc_582053207529_item	2744619	et	3	main
vastan	doc_582053207529_item	2744620	et	3	main
hakkama	doc_582053207529_item	2744625	et	3	main
ilma	doc_582053207529_item	2744627	et	4	main
head	doc_582053207529_item	2744653	et	4	main
oma	doc_582053207529_item	2744662	et	4	main
kallis	doc_582053207529_item	2744665	et	4	main
saa	doc_582053207530_item	2744670	et	4	main
on	doc_582053207530_item	2744682	et	4	main
kui	doc_582053207530_item	2744689	et	3	main
aastat	doc_582053207530_item	2744691	et	3	main
saa	doc_582053207530_item	2744722	et	4	main
minu	doc_582053207530_item	2744725	et	3	main
ma	doc_582053207530_item	2744727	et	3	main
kõik	doc_582053207530_item	2744734	et	4	main
ta	doc_582053207530_item	2744738	et	4	main
tarve	doc_582053207530_item	2744741	et	3	main
vaimustust	doc_582053207530_item	2744748	et	4	main
ja	doc_582053207530_item	2744749	et	3	main
rõõmu	doc_582053207530_item	2744750	et	4	main
saa	doc_582053207530_item	2744755	et	4	main
saanud	doc_582053207531_item	2744788	et	4	main
töötasin	doc_582053207531_item	2744790	et	3	main
sa	doc_582053207531_item	2744791	et	3	main
ilma	doc_582053207531_item	2744793	et	4	main
milleta	doc_582053207531_item	2744794	et	3	main
ei	doc_582053207531_item	2744795	et	4	main
küsimus	doc_582053207531_item	2744804	et	4	main
tänapäeval	doc_582053207528_item	2744542	et	3	main
ütlen	doc_582053207528_item	2744545	et	3	main
sulle	doc_582053207528_item	2744546	et	3	main
inimene	doc_582053207528_item	2744552	et	3	main
saa	doc_582053207528_item	2744554	et	4	main
inimene	doc_582053207528_item	2744570	et	3	main
peab	doc_582053207528_item	2744586	et	4	main
ei	doc_582053207528_item	2744590	et	4	main
on	doc_582053207528_item	2744597	et	4	main
hea	doc_582053207528_item	2744598	et	4	main
võimalik	doc_582053207529_item	2744624	et	3	main
allati	doc_582053207529_item	2744632	et	3	main
toeks	doc_582053207529_item	2744633	et	3	main
teiseks	doc_582053207529_item	2744636	et	4	main
rahaga	doc_582053207529_item	2744639	et	4	main
selleks	doc_582053207529_item	2744649	et	4	main
sõber	doc_582053207529_item	2744666	et	3	main
ei	doc_582053207530_item	2744669	et	4	main
elada	doc_582053207530_item	2744672	et	3	main
ta	doc_582053207530_item	2744677	et	4	main
tahab	doc_582053207530_item	2744678	et	3	main
ja	doc_582053207530_item	2744679	et	3	main
elavad	doc_582053207530_item	2744686	et	4	main
sada	doc_582053207530_item	2744690	et	4	main
tagasi	doc_582053207530_item	2744692	et	3	main
inimisel	doc_582053207530_item	2744693	et	4	main
on	doc_582053207530_item	2744694	et	4	main
teehnika	doc_582053207530_item	2744695	et	4	main
mis	doc_582053207530_item	2744696	et	4	main
abistab	doc_582053207530_item	2744697	et	3	main
talle	doc_582053207530_item	2744698	et	4	main
kaupluses	doc_582053207530_item	2744699	et	3	main
on	doc_582053207530_item	2744700	et	4	main
kõik	doc_582053207530_item	2744701	et	4	main
mis	doc_582053207530_item	2744702	et	4	main
on	doc_582053207530_item	2744703	et	4	main
tarvis	doc_582053207530_item	2744704	et	3	main
inimesele	doc_582053207530_item	2744705	et	3	main
arvuti	doc_582053207530_item	2744706	et	4	main
ja	doc_582053207530_item	2744707	et	3	main
teleriit	doc_582053207530_item	2744708	et	3	main
asendavad	doc_582053207530_item	2744709	et	4	main
inimese	doc_582053207530_item	2744710	et	4	main
suhtlemine	doc_582053207530_item	2744711	et	4	main
siiski	doc_582053207530_item	2744712	et	4	main
inimene	doc_582053207530_item	2744713	et	3	main
ei	doc_582053207530_item	2744714	et	4	main
saa	doc_582053207530_item	2744715	et	4	main
elama	doc_582053207530_item	2744716	et	3	main
ilma	doc_582053207530_item	2744717	et	4	main
teist	doc_582053207530_item	2744718	et	4	main
inimedeta	doc_582053207530_item	2744719	et	3	main
ma	doc_582053207530_item	2744720	et	3	main
ilma	doc_582053207530_item	2744724	et	4	main
koras	doc_582053207530_item	2744735	et	4	main
ja	doc_582053207530_item	2744737	et	3	main
mule	doc_582053207530_item	2744747	et	4	main
veel	doc_582053207530_item	2744752	et	4	main
ei	doc_582053207530_item	2744754	et	4	main
elama	doc_582053207530_item	2744756	et	3	main
ilma	doc_582053207530_item	2744757	et	4	main
minu	doc_582053207530_item	2744758	et	3	main
kohe	doc_582053207531_item	2744786	et	4	main
saa	doc_582053207531_item	2744796	et	4	main
sõbrad	doc_582053207529_item	2744630	et	3	main
hetkel	doc_582053207529_item	2744635	et	4	main
sest	doc_582053207529_item	2744638	et	4	main
on	doc_582053207529_item	2744640	et	4	main
võimalik	doc_582053207529_item	2744641	et	3	main
ülal	doc_582053207529_item	2744642	et	3	main
pidata	doc_582053207529_item	2744643	et	4	main
on	doc_582053207529_item	2744650	et	4	main
ka	doc_582053207529_item	2744651	et	3	main
oelpoolmainitutt	doc_582053207529_item	2744659	et	4	main
sellega	doc_582053207529_item	2744660	et	3	main
kirja	doc_582053207529_item	2744663	et	4	main
mis	doc_582053207530_item	2744680	et	4	main
teistmoodi	doc_582053207530_item	2744687	et	3	main
õnnelik	doc_582053207530_item	2744729	et	3	main
kui	doc_582053207530_item	2744731	et	3	main
pojal	doc_582053207530_item	2744733	et	4	main
elus	doc_582053207530_item	2744736	et	4	main
on	doc_582053207530_item	2744739	et	4	main
või	doc_582053207530_item	2744743	et	4	main
suvil	doc_582053207530_item	2744744	et	4	main
tuju	doc_582053207530_item	2744751	et	4	main
see	doc_582053207531_item	2744800	et	3	main
väga	doc_582053207531_item	2744802	et	3	main
raske	doc_582053207531_item	2744803	et	4	main
sellest	doc_582053207531_item	2744819	et	4	main
sugulaste	doc_582053207531_item	2744833	et	4	main
elu	doc_582053207531_item	2744862	et	4	main
meile	doc_582053207531_item	2744866	et	4	main
pakkutakse	doc_582053207531_item	2744867	et	4	main
uusi	doc_582053207531_item	2744868	et	3	main
programme	doc_582053207531_item	2744869	et	3	main
mis	doc_582053207531_item	2744870	et	4	main
tavalises	doc_582053207531_item	2744873	et	4	main
teema	doc_582053207531_item	2744877	et	4	main
mul	doc_582053207531_item	2744879	et	3	main
kirjasbr	doc_582053207531_item	2744887	et	4	main
kirjuta	doc_582053207531_item	2744888	et	4	main
saa	doc_582053207532_item	2744904	et	4	main
inimene	doc_582053207532_item	2744905	et	3	main
tänapäeval	doc_582053207532_item	2744906	et	3	main
elada	doc_582053207532_item	2744907	et	3	main
tere	doc_582053207532_item	2744908	et	3	main
nädalal	doc_582053207532_item	2744915	et	3	main
ei	doc_582053207532_item	2744918	et	4	main
sa	doc_582053207532_item	2744922	et	3	main
milleta	doc_582053207532_item	2744925	et	3	main
ei	doc_582053207532_item	2744926	et	4	main
raske	doc_582053207532_item	2744933	et	4	main
mina	doc_582053207532_item	2744935	et	4	main
kaua	doc_582053207532_item	2744936	et	3	main
praegu	doc_582053207532_item	2744939	et	3	main
saa	doc_582053207532_item	2744951	et	4	main
tütra	doc_582053207532_item	2744959	et	4	main
tahaksin	doc_582053207532_item	2744961	et	3	main
saa	doc_582053207532_item	2744971	et	4	main
ja	doc_582053207532_item	2744979	et	3	main
inimesi	doc_582053207532_item	2744981	et	4	main
elus	doc_582053207532_item	2744982	et	4	main
arusaamine	doc_582053207532_item	2744987	et	4	main
elama	doc_582053207530_item	2744723	et	3	main
pojata	doc_582053207530_item	2744726	et	4	main
minu	doc_582053207530_item	2744732	et	3	main
õnnelik	doc_582053207530_item	2744740	et	3	main
kevadel	doc_582053207530_item	2744742	et	4	main
ma	doc_582053207530_item	2744753	et	3	main
kõik	doc_582053207530_item	2744764	et	4	main
see	doc_582053207530_item	2744765	et	3	main
on	doc_582053207530_item	2744766	et	4	main
kallis	doc_582053207530_item	2744767	et	4	main
mulle	doc_582053207530_item	2744768	et	4	main
ilma	doc_582053207531_item	2744769	et	4	main
milleta	doc_582053207531_item	2744770	et	3	main
ei	doc_582053207531_item	2744771	et	4	main
saa	doc_582053207531_item	2744772	et	4	main
inimene	doc_582053207531_item	2744773	et	3	main
tänapäeval	doc_582053207531_item	2744774	et	3	main
elada	doc_582053207531_item	2744775	et	3	main
tere	doc_582053207531_item	2744776	et	3	main
kallis	doc_582053207531_item	2744777	et	4	main
kati	doc_582053207531_item	2744778	et	3	main
aitäh	doc_582053207531_item	2744779	et	3	main
kirja	doc_582053207531_item	2744780	et	4	main
eest	doc_582053207531_item	2744781	et	4	main
sain	doc_582053207531_item	2744782	et	3	main
selle	doc_582053207531_item	2744783	et	4	main
eelmisel	doc_582053207531_item	2744784	et	3	main
ei	doc_582053207531_item	2744787	et	4	main
küsisid	doc_582053207531_item	2744792	et	4	main
on	doc_582053207531_item	2744801	et	4	main
igal	doc_582053207531_item	2744820	et	3	main
mõtte	doc_582053207531_item	2744824	et	3	main
peale	doc_582053207531_item	2744826	et	4	main
minu	doc_582053207531_item	2744828	et	3	main
olemas	doc_582053207531_item	2744841	et	4	main
lemmik	doc_582053207531_item	2744842	et	3	main
raha	doc_582053207531_item	2744844	et	4	main
ja	doc_582053207531_item	2744845	et	3	main
armastusbr	doc_582053207531_item	2744846	et	4	main
võib	doc_582053207531_item	2744847	et	3	main
elada	doc_582053207531_item	2744855	et	3	main
sobivat	doc_582053207531_item	2744871	et	4	main
elus	doc_582053207531_item	2744874	et	4	main
mõtteid	doc_582053207531_item	2744882	et	3	main
neid	doc_582053207531_item	2744883	et	4	main
järgmises	doc_582053207531_item	2744886	et	3	main
ootan	doc_582053207531_item	2744892	et	3	main
p	doc_582053207531_item	2744898	et	4	main
typemoz	doc_582053207531_item	2744900	et	4	main
ilma	doc_582053207532_item	2744901	et	4	main
milleta	doc_582053207532_item	2744902	et	3	main
ei	doc_582053207532_item	2744903	et	4	main
möödunud	doc_582053207532_item	2744914	et	4	main
see	doc_582053207532_item	2744930	et	3	main
väga	doc_582053207532_item	2744932	et	3	main
saan	doc_582053207532_item	2744940	et	4	main
ma	doc_582053207532_item	2744943	et	3	main
elada	doc_582053207532_item	2744952	et	3	main
terved	doc_582053207532_item	2744965	et	4	main
veel	doc_582053207532_item	2744968	et	4	main
nendega	doc_582053207532_item	2744975	et	4	main
kõik	doc_582053207532_item	2744976	et	4	main
läheb	doc_582053207532_item	2744977	et	3	main
kiiresti	doc_582053207532_item	2744978	et	3	main
armastus	doc_582053207532_item	2744986	et	4	main
talle	doc_582053207532_item	2744993	et	4	main
praegu	doc_582053207533_item	2745023	et	3	main
väga	doc_582053207533_item	2745026	et	3	main
raske	doc_582053207533_item	2745027	et	4	main
tööd	doc_582053207533_item	2745033	et	4	main
kõik	doc_582053207533_item	2745052	et	4	main
on	doc_582053207533_item	2745053	et	4	main
et	doc_582053207533_item	2745068	et	3	main
inimesed	doc_582053207533_item	2745070	et	3	main
haridus	doc_582053207533_item	2745077	et	3	main
nendel	doc_582053207533_item	2745080	et	4	main
ilma	doc_582053207534_item	2745097	et	4	main
saa	doc_582053207534_item	2745100	et	4	main
inimene	doc_582053207534_item	2745101	et	3	main
tänapäeval	doc_582053207534_item	2745102	et	3	main
elada	doc_582053207534_item	2745103	et	3	main
mida	doc_582053207534_item	2745104	et	4	main
raha	doc_582053207534_item	2745113	et	4	main
armastus	doc_582053207534_item	2745114	et	4	main
karjäär	doc_582053207534_item	2745115	et	3	main
ning	doc_582053207534_item	2745116	et	3	main
olla	doc_582053207534_item	2745127	et	3	main
haridus	doc_582053207534_item	2745133	et	3	main
võõrkeeli	doc_582053207534_item	2745136	et	3	main
täna	doc_582053207534_item	2745147	et	4	main
sa	doc_582053207534_item	2745155	et	3	main
elada	doc_582053207534_item	2745157	et	3	main
armastus	doc_582053207534_item	2745166	et	4	main
perekonnas	doc_582053207534_item	2745167	et	4	main
suhtleid	doc_582053207534_item	2745170	et	4	main
arvan	doc_582053207534_item	2745172	et	3	main
sinul	doc_582053207534_item	2745183	et	3	main
ka	doc_582053207535_item	2745229	et	3	main
siis	doc_582053207535_item	2745239	et	3	main
rohkem	doc_582053207535_item	2745242	et	4	main
ning	doc_582053207535_item	2745245	et	3	main
ka	doc_582053207535_item	2745248	et	3	main
ilma	doc_582053207536_item	2745254	et	4	main
milleta	doc_582053207536_item	2745255	et	3	main
ei	doc_582053207536_item	2745256	et	4	main
saa	doc_582053207536_item	2745264	et	4	main
inimene	doc_582053207536_item	2745265	et	3	main
väga	doc_582053207536_item	2745274	et	3	main
raske	doc_582053207536_item	2745275	et	4	main
esimene	doc_582053207531_item	2744805	et	3	main
ütleb	doc_582053207531_item	2744806	et	3	main
see	doc_582053207531_item	2744807	et	3	main
on	doc_582053207531_item	2744816	et	4	main
oma	doc_582053207531_item	2744823	et	4	main
terve	doc_582053207531_item	2744834	et	4	main
on	doc_582053207531_item	2744836	et	4	main
terve	doc_582053207531_item	2744837	et	4	main
kõik	doc_582053207531_item	2744840	et	4	main
töö	doc_582053207531_item	2744843	et	4	main
ilma	doc_582053207531_item	2744856	et	4	main
sest	doc_582053207531_item	2744858	et	4	main
need	doc_582053207531_item	2744859	et	3	main
teevad	doc_582053207531_item	2744860	et	3	main
meie	doc_582053207531_item	2744861	et	4	main
palju	doc_582053207531_item	2744881	et	4	main
ma	doc_582053207531_item	2744891	et	3	main
p	doc_582053207531_item	2744894	et	4	main
kirja	doc_582053207532_item	2744913	et	4	main
kohe	doc_582053207532_item	2744917	et	4	main
vastata	doc_582053207532_item	2744921	et	4	main
küsisid	doc_582053207532_item	2744923	et	4	main
ilma	doc_582053207532_item	2744924	et	4	main
ja	doc_582053207532_item	2744938	et	3	main
täpselt	doc_582053207532_item	2744942	et	4	main
arvan	doc_582053207532_item	2744944	et	3	main
kõige	doc_582053207532_item	2744946	et	4	main
tähtsem	doc_582053207532_item	2744947	et	4	main
pere	doc_582053207532_item	2744954	et	4	main
koos	doc_582053207532_item	2744974	et	4	main
on	doc_582053207532_item	2744983	et	4	main
sõprus	doc_582053207532_item	2744988	et	3	main
mida	doc_582053207532_item	2744992	et	4	main
elada	doc_582053207533_item	2745022	et	3	main
meil	doc_582053207533_item	2745024	et	4	main
ei	doc_582053207533_item	2745031	et	4	main
ei	doc_582053207533_item	2745035	et	4	main
ole	doc_582053207533_item	2745036	et	4	main
oma	doc_582053207533_item	2745037	et	4	main
korterit	doc_582053207533_item	2745038	et	3	main
lapsed	doc_582053207533_item	2745039	et	3	main
aga	doc_582053207533_item	2745048	et	3	main
kus	doc_582053207533_item	2745051	et	3	main
lapsed	doc_582053207533_item	2745055	et	3	main
õppivad	doc_582053207533_item	2745056	et	4	main
huvitavat	doc_582053207533_item	2745061	et	4	main
head	doc_582053207533_item	2745064	et	4	main
ma	doc_582053207533_item	2745066	et	3	main
hea	doc_582053207533_item	2745076	et	4	main
ja	doc_582053207533_item	2745088	et	3	main
ei	doc_582053207534_item	2745092	et	4	main
tõeliselt	doc_582053207534_item	2745107	et	4	main
vaja	doc_582053207534_item	2745112	et	4	main
peab	doc_582053207534_item	2745126	et	4	main
valdab	doc_582053207534_item	2745135	et	3	main
ilma	doc_582053207534_item	2745148	et	4	main
armastuseta	doc_582053207534_item	2745153	et	4	main
ma	doc_582053207534_item	2745171	et	3	main
et	doc_582053207534_item	2745173	et	3	main
suprudeta	doc_582053207534_item	2745176	et	4	main
sõber	doc_582053207534_item	2745182	et	3	main
elada	doc_582053207534_item	2745185	et	3	main
on	doc_582053207535_item	2745222	et	4	main
valdab	doc_582053207535_item	2745237	et	3	main
leida	doc_582053207535_item	2745243	et	3	main
ilma	doc_582053207535_item	2745252	et	4	main
tööta	doc_582053207535_item	2745253	et	4	main
tänapäeval	doc_582053207536_item	2745266	et	3	main
elada	doc_582053207536_item	2745267	et	3	main
mina	doc_582053207536_item	2745268	et	4	main
arvan	doc_582053207536_item	2745269	et	3	main
see	doc_582053207536_item	2745271	et	3	main
on	doc_582053207536_item	2745278	et	4	main
hea	doc_582053207536_item	2745279	et	4	main
ilma	doc_582053207536_item	2745290	et	4	main
ilma	doc_582053207536_item	2745308	et	4	main
ilma	doc_582053207536_item	2745316	et	4	main
on	doc_582053207531_item	2744808	et	4	main
armastus	doc_582053207531_item	2744817	et	4	main
alustan	doc_582053207531_item	2744818	et	3	main
ühel	doc_582053207531_item	2744821	et	3	main
selle	doc_582053207531_item	2744825	et	4	main
aga	doc_582053207531_item	2744827	et	3	main
jaoks	doc_582053207531_item	2744829	et	4	main
on	doc_582053207531_item	2744830	et	4	main
see	doc_582053207531_item	2744831	et	3	main
minu	doc_582053207531_item	2744832	et	3	main
siis	doc_582053207531_item	2744838	et	3	main
arvutist	doc_582053207531_item	2744857	et	4	main
meile	doc_582053207531_item	2744872	et	4	main
selle	doc_582053207531_item	2744876	et	4	main
peale	doc_582053207531_item	2744878	et	4	main
on	doc_582053207531_item	2744880	et	4	main
mulle	doc_582053207531_item	2744889	et	4	main
vastus	doc_582053207531_item	2744890	et	3	main
kirja	doc_582053207531_item	2744893	et	4	main
p	doc_582053207531_item	2744895	et	4	main
p	doc_582053207531_item	2744896	et	4	main
br	doc_582053207531_item	2744899	et	4	main
kallis	doc_582053207532_item	2744909	et	4	main
eva	doc_582053207532_item	2744910	et	4	main
sain	doc_582053207532_item	2744911	et	3	main
sinu	doc_582053207532_item	2744912	et	3	main
saa	doc_582053207532_item	2744927	et	4	main
tänapäeval	doc_582053207532_item	2744928	et	3	main
elada	doc_582053207532_item	2744929	et	3	main
öelda	doc_582053207532_item	2744941	et	4	main
et	doc_582053207532_item	2744945	et	3	main
ilma	doc_582053207532_item	2744948	et	4	main
milleta	doc_582053207532_item	2744949	et	3	main
on	doc_582053207532_item	2744953	et	4	main
armastan	doc_582053207532_item	2744956	et	3	main
vanemad	doc_582053207532_item	2744958	et	4	main
meest	doc_582053207532_item	2744960	et	4	main
et	doc_582053207532_item	2744962	et	3	main
nad	doc_582053207532_item	2744963	et	3	main
on	doc_582053207532_item	2744964	et	4	main
elada	doc_582053207532_item	2744972	et	3	main
sõbradeta	doc_582053207532_item	2744973	et	4	main
hästi	doc_582053207532_item	2744980	et	3	main
iga	doc_582053207532_item	2744989	et	4	main
tänapäeval	doc_582053207533_item	2745021	et	3	main
on	doc_582053207533_item	2745025	et	4	main
inimestel	doc_582053207533_item	2745030	et	3	main
kedagil	doc_582053207533_item	2745034	et	4	main
ei	doc_582053207533_item	2745045	et	4	main
on	doc_582053207533_item	2745049	et	4	main
koolis	doc_582053207533_item	2745057	et	4	main
tööd	doc_582053207533_item	2745062	et	4	main
töötasu	doc_582053207533_item	2745065	et	4	main
võõrkeeliga	doc_582053207533_item	2745072	et	4	main
ja	doc_582053207533_item	2745073	et	3	main
milleta	doc_582053207534_item	2745091	et	3	main
tänapäeval	doc_582053207534_item	2745095	et	3	main
on	doc_582053207534_item	2745105	et	4	main
elus	doc_582053207534_item	2745106	et	4	main
on	doc_582053207534_item	2745111	et	4	main
sõbrad	doc_582053207534_item	2745118	et	3	main
alguses	doc_582053207534_item	2745119	et	4	main
kes	doc_582053207534_item	2745122	et	4	main
tahab	doc_582053207534_item	2745123	et	3	main
kõrg	doc_582053207534_item	2745128	et	4	main
sinul	doc_582053207534_item	2745131	et	3	main
temal	doc_582053207534_item	2745137	et	3	main
rohkem	doc_582053207534_item	2745139	et	4	main
leida	doc_582053207534_item	2745141	et	3	main
rahata	doc_582053207534_item	2745149	et	4	main
ka	doc_582053207534_item	2745156	et	3	main
oma	doc_582053207534_item	2745165	et	4	main
elada	doc_582053207534_item	2745178	et	3	main
ilma	doc_582053207535_item	2745186	et	4	main
saa	doc_582053207535_item	2745189	et	4	main
elada	doc_582053207535_item	2745192	et	3	main
ilma	doc_582053207535_item	2745193	et	4	main
milleta	doc_582053207535_item	2745194	et	3	main
võõrkeeli	doc_582053207535_item	2745238	et	3	main
on	doc_582053207535_item	2745241	et	4	main
ilma	doc_582053207536_item	2745261	et	4	main
milleta	doc_582053207536_item	2745262	et	3	main
on	doc_582053207531_item	2744822	et	4	main
kui	doc_582053207531_item	2744835	et	3	main
on	doc_582053207531_item	2744839	et	4	main
õlda	doc_582053207531_item	2744848	et	4	main
veel	doc_582053207531_item	2744849	et	4	main
et	doc_582053207531_item	2744850	et	3	main
täna	doc_582053207531_item	2744851	et	4	main
inemene	doc_582053207531_item	2744852	et	4	main
ei	doc_582053207531_item	2744853	et	4	main
saa	doc_582053207531_item	2744854	et	4	main
kergem	doc_582053207531_item	2744863	et	4	main
igal	doc_582053207531_item	2744864	et	3	main
aastal	doc_582053207531_item	2744865	et	3	main
kati	doc_582053207531_item	2744875	et	3	main
ma	doc_582053207531_item	2744884	et	3	main
kirjutan	doc_582053207531_item	2744885	et	3	main
p	doc_582053207531_item	2744897	et	4	main
aga	doc_582053207532_item	2744916	et	3	main
olnud	doc_582053207532_item	2744919	et	4	main
aega	doc_582053207532_item	2744920	et	4	main
on	doc_582053207532_item	2744931	et	4	main
küsimus	doc_582053207532_item	2744934	et	4	main
mõtlesin	doc_582053207532_item	2744937	et	3	main
ei	doc_582053207532_item	2744950	et	4	main
ma	doc_582053207532_item	2744955	et	3	main
minu	doc_582053207532_item	2744957	et	3	main
lõbusad	doc_582053207532_item	2744966	et	3	main
aktiivsed	doc_582053207532_item	2744967	et	3	main
ma	doc_582053207532_item	2744969	et	3	main
ei	doc_582053207532_item	2744970	et	4	main
palju	doc_582053207532_item	2744984	et	4	main
asju	doc_582053207532_item	2744985	et	3	main
ise	doc_582053207532_item	2744990	et	4	main
valib	doc_582053207532_item	2744991	et	3	main
on	doc_582053207532_item	2744994	et	4	main
vaja	doc_582053207532_item	2744995	et	4	main
br	doc_582053207532_item	2744996	et	4	main
kirjuta	doc_582053207532_item	2744997	et	4	main
mulle	doc_582053207532_item	2744998	et	4	main
ilma	doc_582053207532_item	2744999	et	4	main
milleta	doc_582053207532_item	2745000	et	3	main
sina	doc_582053207532_item	2745001	et	4	main
ei	doc_582053207532_item	2745002	et	4	main
saa	doc_582053207532_item	2745003	et	4	main
elada	doc_582053207532_item	2745004	et	3	main
ootan	doc_582053207532_item	2745005	et	3	main
sinu	doc_582053207532_item	2745006	et	3	main
kirja	doc_582053207532_item	2745007	et	4	main
inna	doc_582053207532_item	2745008	et	3	main
ilma	doc_582053207533_item	2745009	et	4	main
milleta	doc_582053207533_item	2745010	et	3	main
ei	doc_582053207533_item	2745011	et	4	main
saa	doc_582053207533_item	2745012	et	4	main
inimene	doc_582053207533_item	2745013	et	3	main
tänapäeval	doc_582053207533_item	2745014	et	3	main
elada	doc_582053207533_item	2745015	et	3	main
ilma	doc_582053207533_item	2745016	et	4	main
milleta	doc_582053207533_item	2745017	et	3	main
ei	doc_582053207533_item	2745018	et	4	main
saa	doc_582053207533_item	2745019	et	4	main
inimene	doc_582053207533_item	2745020	et	3	main
aeg	doc_582053207533_item	2745028	et	3	main
ole	doc_582053207533_item	2745032	et	4	main
koolis	doc_582053207533_item	2745042	et	4	main
nad	doc_582053207533_item	2745044	et	3	main
pered	doc_582053207533_item	2745050	et	3	main
korras	doc_582053207533_item	2745054	et	4	main
on	doc_582053207533_item	2745060	et	4	main
kui	doc_582053207533_item	2745069	et	3	main
valdavad	doc_582053207533_item	2745071	et	4	main
nendel	doc_582053207533_item	2745074	et	4	main
on	doc_582053207533_item	2745075	et	4	main
ja	doc_582053207533_item	2745078	et	3	main
paremini	doc_582053207533_item	2745087	et	4	main
kindlemini	doc_582053207533_item	2745089	et	4	main
ilma	doc_582053207534_item	2745090	et	4	main
paljudel	doc_582053207533_item	2745029	et	3	main
mõnikord	doc_582053207533_item	2745040	et	3	main
käivad	doc_582053207533_item	2745041	et	4	main
narkoga	doc_582053207533_item	2745043	et	4	main
taha	doc_582053207533_item	2745046	et	4	main
õppida	doc_582053207533_item	2745047	et	3	main
ülekoolis	doc_582053207533_item	2745058	et	4	main
vanemadel	doc_582053207533_item	2745059	et	4	main
ja	doc_582053207533_item	2745063	et	3	main
arvan	doc_582053207533_item	2745067	et	3	main
eriala	doc_582053207533_item	2745079	et	4	main
ei	doc_582053207533_item	2745081	et	4	main
ole	doc_582053207533_item	2745082	et	4	main
probleeme	doc_582053207533_item	2745083	et	3	main
nad	doc_582053207533_item	2745084	et	3	main
tunnevad	doc_582053207533_item	2745085	et	3	main
end	doc_582053207533_item	2745086	et	4	main
saa	doc_582053207534_item	2745093	et	4	main
jaoks	doc_582053207534_item	2745110	et	4	main
head	doc_582053207534_item	2745117	et	4	main
inimene	doc_582053207534_item	2745121	et	3	main
elada	doc_582053207534_item	2745124	et	3	main
kui	doc_582053207534_item	2745130	et	3	main
head	doc_582053207534_item	2745132	et	4	main
ning	doc_582053207534_item	2745134	et	3	main
on	doc_582053207534_item	2745138	et	4	main
võimalusi	doc_582053207534_item	2745140	et	3	main
head	doc_582053207534_item	2745142	et	4	main
tööd	doc_582053207534_item	2745143	et	4	main
ning	doc_582053207534_item	2745144	et	3	main
suur	doc_582053207534_item	2745145	et	3	main
ei	doc_582053207534_item	2745150	et	4	main
ei	doc_582053207534_item	2745154	et	4	main
sinul	doc_582053207534_item	2745158	et	3	main
olema	doc_582053207534_item	2745160	et	4	main
kellele	doc_582053207534_item	2745162	et	4	main
sa	doc_582053207534_item	2745163	et	3	main
annad	doc_582053207534_item	2745164	et	4	main
soed	doc_582053207534_item	2745169	et	4	main
raske	doc_582053207534_item	2745177	et	4	main
kui	doc_582053207534_item	2745179	et	3	main
heas	doc_582053207534_item	2745181	et	3	main
milleta	doc_582053207535_item	2745187	et	3	main
ei	doc_582053207535_item	2745195	et	4	main
abil	doc_582053207535_item	2745221	et	4	main
huvitavat	doc_582053207535_item	2745244	et	4	main
tasuvat	doc_582053207535_item	2745246	et	4	main
tööd	doc_582053207535_item	2745247	et	4	main
on	doc_582053207536_item	2745273	et	4	main
ma	doc_582053207536_item	2745282	et	3	main
saa	doc_582053207536_item	2745288	et	4	main
lapse	doc_582053207536_item	2745297	et	4	main
hobbi	doc_582053207536_item	2745305	et	4	main
sõprad	doc_582053207536_item	2745306	et	4	main
suhtlema	doc_582053207536_item	2745307	et	3	main
oma	doc_582053207536_item	2745314	et	4	main
majas	doc_582053207536_item	2745315	et	3	main
oma	doc_582053207536_item	2745319	et	4	main
ja	doc_582053207536_item	2745321	et	3	main
tahan	doc_582053207536_item	2745329	et	3	main
elada	doc_582053207536_item	2745330	et	3	main
rahul	doc_582053207536_item	2745331	et	4	main
milleta	doc_582053207537_item	2745346	et	3	main
ei	doc_582053207537_item	2745347	et	4	main
väitele	doc_582053207537_item	2745353	et	3	main
vastata	doc_582053207537_item	2745355	et	4	main
aga	doc_582053207537_item	2745356	et	3	main
veel	doc_582053207537_item	2745357	et	4	main
on	doc_582053207537_item	2745363	et	4	main
ilma	doc_582053207537_item	2745366	et	4	main
milleta	doc_582053207537_item	2745367	et	3	main
ei	doc_582053207537_item	2745373	et	4	main
elada	doc_582053207537_item	2745375	et	3	main
ilma	doc_582053207537_item	2745376	et	4	main
sõbrata	doc_582053207537_item	2745381	et	3	main
inimesele	doc_582053207537_item	2745383	et	3	main
vaja	doc_582053207537_item	2745385	et	4	main
palju	doc_582053207537_item	2745389	et	4	main
õhu	doc_582053207537_item	2745390	et	3	main
ja	doc_582053207537_item	2745391	et	3	main
vesi	doc_582053207537_item	2745392	et	4	main
katus	doc_582053207537_item	2745402	et	4	main
ilma	doc_582053207537_item	2745403	et	4	main
selleta	doc_582053207537_item	2745404	et	3	main
inimene	doc_582053207534_item	2745094	et	3	main
elada	doc_582053207534_item	2745096	et	3	main
milleta	doc_582053207534_item	2745098	et	3	main
ei	doc_582053207534_item	2745099	et	4	main
vaja	doc_582053207534_item	2745108	et	4	main
elu	doc_582053207534_item	2745109	et	4	main
iga	doc_582053207534_item	2745120	et	4	main
hästi	doc_582053207534_item	2745125	et	3	main
haridus	doc_582053207534_item	2745129	et	3	main
palka	doc_582053207534_item	2745146	et	4	main
saa	doc_582053207534_item	2745151	et	4	main
elada	doc_582053207534_item	2745152	et	3	main
peab	doc_582053207534_item	2745159	et	4	main
lapsed	doc_582053207534_item	2745161	et	3	main
on	doc_582053207534_item	2745168	et	4	main
ilma	doc_582053207534_item	2745174	et	4	main
head	doc_582053207534_item	2745175	et	4	main
sinul	doc_582053207534_item	2745180	et	3	main
kergem	doc_582053207534_item	2745184	et	4	main
ei	doc_582053207535_item	2745188	et	4	main
inimene	doc_582053207535_item	2745190	et	3	main
tänapäeval	doc_582053207535_item	2745191	et	3	main
saa	doc_582053207535_item	2745196	et	4	main
inimene	doc_582053207535_item	2745197	et	3	main
tänapäeval	doc_582053207535_item	2745198	et	3	main
elada	doc_582053207535_item	2745199	et	3	main
tänapäeval	doc_582053207535_item	2745200	et	3	main
ei	doc_582053207535_item	2745201	et	4	main
saa	doc_582053207535_item	2745202	et	4	main
elada	doc_582053207535_item	2745203	et	3	main
arvuti	doc_582053207535_item	2745204	et	4	main
oskuseta	doc_582053207535_item	2745205	et	3	main
arvuti	doc_582053207535_item	2745206	et	4	main
on	doc_582053207535_item	2745207	et	4	main
täna	doc_582053207535_item	2745208	et	4	main
mitte	doc_582053207535_item	2745209	et	3	main
ainult	doc_582053207535_item	2745210	et	4	main
väga	doc_582053207535_item	2745211	et	3	main
vajalik	doc_582053207535_item	2745212	et	3	main
töövahend	doc_582053207535_item	2745213	et	3	main
ta	doc_582053207535_item	2745214	et	4	main
võimaldab	doc_582053207535_item	2745215	et	3	main
sada	doc_582053207535_item	2745217	et	4	main
internetist	doc_582053207535_item	2745216	et	4	main
infot	doc_582053207535_item	2745219	et	3	main
kasulikku	doc_582053207535_item	2745218	et	4	main
arvuti	doc_582053207535_item	2745220	et	4	main
täna	doc_582053207535_item	2745223	et	4	main
võimalik	doc_582053207535_item	2745224	et	3	main
ka	doc_582053207535_item	2745225	et	3	main
suhelda	doc_582053207535_item	2745226	et	4	main
tänapäeval	doc_582053207535_item	2745227	et	3	main
inimene	doc_582053207535_item	2745228	et	3	main
ei	doc_582053207535_item	2745230	et	4	main
saa	doc_582053207535_item	2745231	et	4	main
elada	doc_582053207535_item	2745232	et	3	main
võõrkeeli	doc_582053207535_item	2745233	et	3	main
oskamata	doc_582053207535_item	2745234	et	4	main
kui	doc_582053207535_item	2745235	et	3	main
inimene	doc_582053207535_item	2745236	et	3	main
temal	doc_582053207535_item	2745240	et	3	main
ei	doc_582053207535_item	2745249	et	4	main
saa	doc_582053207535_item	2745250	et	4	main
elada	doc_582053207535_item	2745251	et	3	main
saa	doc_582053207536_item	2745257	et	4	main
inimene	doc_582053207536_item	2745258	et	3	main
tänapäeval	doc_582053207536_item	2745259	et	3	main
elada	doc_582053207536_item	2745260	et	3	main
et	doc_582053207536_item	2745270	et	3	main
aga	doc_582053207536_item	2745281	et	3	main
et	doc_582053207536_item	2745284	et	3	main
ei	doc_582053207536_item	2745287	et	4	main
tööta	doc_582053207536_item	2745291	et	4	main
rahaga	doc_582053207536_item	2745293	et	4	main
oma	doc_582053207536_item	2745295	et	4	main
saa	doc_582053207536_item	2745300	et	4	main
spordi	doc_582053207536_item	2745309	et	4	main
naabrid	doc_582053207536_item	2745317	et	3	main
lapsega	doc_582053207536_item	2745320	et	3	main
tutvuga	doc_582053207536_item	2745322	et	4	main
koeraga	doc_582053207536_item	2745324	et	3	main
aga	doc_582053207536_item	2745325	et	3	main
ilma	doc_582053207536_item	2745326	et	4	main
ma	doc_582053207536_item	2745328	et	3	main
ilma	doc_582053207536_item	2745333	et	4	main
ilma	doc_582053207537_item	2745338	et	4	main
tänapäeval	doc_582053207537_item	2745350	et	3	main
raske	doc_582053207537_item	2745354	et	4	main
inimesel	doc_582053207537_item	2745362	et	3	main
oma	doc_582053207537_item	2745364	et	4	main
saa	doc_582053207537_item	2745369	et	4	main
elada	doc_582053207537_item	2745371	et	3	main
saa	doc_582053207537_item	2745374	et	4	main
veel	doc_582053207537_item	2745393	et	4	main
oleks	doc_582053207537_item	2745394	et	3	main
väga	doc_582053207537_item	2745395	et	3	main
hea	doc_582053207537_item	2745396	et	4	main
et	doc_582053207537_item	2745397	et	3	main
inimesel	doc_582053207537_item	2745398	et	3	main
saa	doc_582053207537_item	2745407	et	4	main
räägitakse	doc_582053207537_item	2745425	et	3	main
supp	doc_582053207537_item	2745427	et	3	main
teisel	doc_582053207537_item	2745430	et	4	main
minu	doc_582053207537_item	2745436	et	3	main
väljend	doc_582053207537_item	2745439	et	3	main
ei	doc_582053207537_item	2745443	et	4	main
üleval	doc_582053207537_item	2745451	et	4	main
tahaksin	doc_582053207537_item	2745452	et	3	main
veel	doc_582053207537_item	2745453	et	4	main
tähtsam	doc_582053207537_item	2745469	et	4	main
kui	doc_582053207537_item	2745470	et	3	main
naiste	doc_582053207537_item	2745471	et	3	main
minu	doc_582053207537_item	2745474	et	3	main
ma	doc_582053207537_item	2745492	et	3	main
pean	doc_582053207537_item	2745493	et	4	main
minu	doc_582053207537_item	2745497	et	3	main
ei	doc_582053207537_item	2745505	et	4	main
elada	doc_582053207537_item	2745530	et	3	main
internetita	doc_582053207537_item	2745533	et	4	main
ei	doc_582053207537_item	2745545	et	4	main
teid	doc_582053207537_item	2745549	et	4	main
ilma	doc_582053207538_item	2745552	et	4	main
tänapäeval	doc_582053207538_item	2745557	et	3	main
saa	doc_582053207538_item	2745562	et	4	main
p	doc_582053207538_item	2745566	et	4	main
1	doc_582053207538_item	2745567	et	2	main
enam	doc_582053207538_item	2745576	et	4	main
et	doc_582053207538_item	2745577	et	3	main
heast	doc_582053207538_item	2745591	et	3	main
ilma	doc_582053207538_item	2745594	et	4	main
inimene	doc_582053207538_item	2745596	et	3	main
ei	doc_582053207536_item	2745263	et	4	main
küsimus	doc_582053207536_item	2745272	et	4	main
praegu	doc_582053207536_item	2745276	et	3	main
elu	doc_582053207536_item	2745280	et	4	main
tänapäeval	doc_582053207536_item	2745285	et	3	main
perekonna	doc_582053207536_item	2745296	et	4	main
ei	doc_582053207536_item	2745299	et	4	main
elada	doc_582053207536_item	2745301	et	3	main
ka	doc_582053207536_item	2745303	et	3	main
aga	doc_582053207536_item	2745318	et	3	main
oma	doc_582053207536_item	2745323	et	4	main
ei	doc_582053207537_item	2745340	et	4	main
saa	doc_582053207537_item	2745341	et	4	main
inimene	doc_582053207537_item	2745342	et	3	main
tänapäeval	doc_582053207537_item	2745343	et	3	main
elada	doc_582053207537_item	2745344	et	3	main
elada	doc_582053207537_item	2745351	et	3	main
sellele	doc_582053207537_item	2745352	et	4	main
rahata	doc_582053207537_item	2745377	et	4	main
üldse	doc_582053207537_item	2745405	et	3	main
inimene	doc_582053207537_item	2745408	et	3	main
on	doc_582053207537_item	2745421	et	4	main
on	doc_582053207537_item	2745428	et	4	main
ilma	doc_582053207537_item	2745440	et	4	main
saaks	doc_582053207537_item	2745444	et	3	main
palk	doc_582053207537_item	2745458	et	3	main
olen	doc_582053207537_item	2745462	et	3	main
on	doc_582053207537_item	2745466	et	4	main
jaoks	doc_582053207537_item	2745475	et	4	main
tähtsalt	doc_582053207537_item	2745491	et	4	main
et	doc_582053207537_item	2745496	et	3	main
laste	doc_582053207537_item	2745498	et	4	main
on	doc_582053207537_item	2745500	et	4	main
kogu	doc_582053207537_item	2745521	et	4	main
eriti	doc_582053207537_item	2745526	et	3	main
ilma	doc_582053207537_item	2745531	et	4	main
ma	doc_582053207537_item	2745536	et	3	main
ole	doc_582053207537_item	2745546	et	4	main
saa	doc_582053207538_item	2745555	et	4	main
elu	doc_582053207538_item	2745578	et	4	main
peab	doc_582053207538_item	2745581	et	4	main
õppima	doc_582053207538_item	2745582	et	3	main
kogu	doc_582053207538_item	2745583	et	4	main
elu	doc_582053207538_item	2745584	et	4	main
niisiis	doc_582053207538_item	2745585	et	3	main
hea	doc_582053207538_item	2745586	et	4	main
siiski	doc_582053207538_item	2745589	et	4	main
ilma	doc_582053207538_item	2745609	et	4	main
eesti	doc_582053207538_item	2745615	et	4	main
peab	doc_582053207538_item	2745618	et	4	main
peab	doc_582053207538_item	2745627	et	4	main
niisiis	doc_582053207538_item	2745630	et	3	main
milleta	doc_582053207539_item	2745637	et	3	main
korterita	doc_582053207539_item	2745662	et	3	main
sõprata	doc_582053207539_item	2745664	et	4	main
õhkuta	doc_582053207539_item	2745666	et	3	main
see	doc_582053207539_item	2745671	et	3	main
meie	doc_582053207539_item	2745674	et	4	main
ja	doc_582053207539_item	2745680	et	3	main
saa	doc_582053207540_item	2745685	et	4	main
inimene	doc_582053207540_item	2745686	et	3	main
tänapäeval	doc_582053207540_item	2745687	et	3	main
elada	doc_582053207540_item	2745695	et	3	main
elus	doc_582053207540_item	2745697	et	4	main
väga	doc_582053207540_item	2745704	et	3	main
jne	doc_582053207540_item	2745716	et	4	main
on	doc_582053207540_item	2745724	et	4	main
hea	doc_582053207540_item	2745725	et	4	main
mina	doc_582053207540_item	2745740	et	4	main
oli	doc_582053207540_item	2745744	et	3	main
ilus	doc_582053207540_item	2745748	et	4	main
hea	doc_582053207540_item	2745751	et	4	main
töökoht	doc_582053207540_item	2745752	et	3	main
suurepärane	doc_582053207540_item	2745753	et	4	main
iga	doc_582053207540_item	2745758	et	4	main
päev	doc_582053207540_item	2745759	et	3	main
ma	doc_582053207540_item	2745760	et	3	main
ainult	doc_582053207540_item	2745769	et	4	main
üks	doc_582053207540_item	2745770	et	3	main
mida	doc_582053207540_item	2745781	et	4	main
kogu	doc_582053207540_item	2745787	et	4	main
aeg	doc_582053207540_item	2745788	et	3	main
praegu	doc_582053207540_item	2745789	et	3	main
mul	doc_582053207536_item	2745277	et	3	main
arvan	doc_582053207536_item	2745283	et	3	main
elada	doc_582053207536_item	2745286	et	3	main
inimene	doc_582053207536_item	2745289	et	3	main
ilma	doc_582053207536_item	2745292	et	4	main
ilma	doc_582053207536_item	2745294	et	4	main
armastus	doc_582053207536_item	2745298	et	4	main
tänapäeval	doc_582053207536_item	2745302	et	3	main
ilma	doc_582053207536_item	2745304	et	4	main
tantsi	doc_582053207536_item	2745310	et	4	main
ma	doc_582053207536_item	2745311	et	3	main
tahan	doc_582053207536_item	2745312	et	3	main
elada	doc_582053207536_item	2745313	et	3	main
ja	doc_582053207536_item	2745335	et	3	main
tood	doc_582053207536_item	2745337	et	3	main
milleta	doc_582053207537_item	2745339	et	3	main
saa	doc_582053207537_item	2745348	et	4	main
inimene	doc_582053207537_item	2745349	et	3	main
raskem	doc_582053207537_item	2745358	et	4	main
kirjutada	doc_582053207537_item	2745359	et	3	main
kirjand	doc_582053207537_item	2745360	et	3	main
igal	doc_582053207537_item	2745361	et	3	main
ei	doc_582053207537_item	2745368	et	4	main
võimatu	doc_582053207537_item	2745379	et	4	main
ilma	doc_582053207537_item	2745380	et	4	main
igale	doc_582053207537_item	2745382	et	3	main
on	doc_582053207537_item	2745384	et	4	main
jaoks	doc_582053207537_item	2745387	et	4	main
oleksid	doc_582053207537_item	2745399	et	4	main
toit	doc_582053207537_item	2745400	et	3	main
ei	doc_582053207537_item	2745406	et	4	main
erinevad	doc_582053207537_item	2745422	et	4	main
mis	doc_582053207537_item	2745434	et	4	main
tähendab	doc_582053207537_item	2745435	et	3	main
milleta	doc_582053207537_item	2745441	et	3	main
miinimumi	doc_582053207537_item	2745446	et	4	main
juurde	doc_582053207537_item	2745447	et	4	main
mis	doc_582053207537_item	2745448	et	4	main
ma	doc_582053207537_item	2745449	et	3	main
nimetasin	doc_582053207537_item	2745450	et	3	main
töökollektiiv	doc_582053207537_item	2745460	et	3	main
et	doc_582053207537_item	2745464	et	3	main
on	doc_582053207537_item	2745476	et	4	main
minu	doc_582053207537_item	2745478	et	3	main
ja	doc_582053207537_item	2745480	et	3	main
tervis	doc_582053207537_item	2745499	et	3	main
korras	doc_582053207537_item	2745501	et	4	main
p	doc_582053207537_item	2745502	et	4	main
tänapäeval	doc_582053207537_item	2745503	et	3	main
inimesed	doc_582053207537_item	2745504	et	3	main
raske	doc_582053207537_item	2745529	et	4	main
auto	doc_582053207537_item	2745532	et	4	main
jne	doc_582053207537_item	2745534	et	4	main
kahjuks	doc_582053207537_item	2745535	et	4	main
tea	doc_582053207537_item	2745538	et	4	main
suur	doc_582053207537_item	2745547	et	3	main
ei	doc_582053207538_item	2745554	et	4	main
hariduseta	doc_582053207538_item	2745569	et	3	main
peab	doc_582053207538_item	2745571	et	4	main
õppima	doc_582053207538_item	2745572	et	3	main
kogu	doc_582053207538_item	2745573	et	4	main
muutuda	doc_582053207538_item	2745579	et	3	main
töökoha	doc_582053207538_item	2745587	et	4	main
kõrge	doc_582053207538_item	2745599	et	4	main
palgaga	doc_582053207538_item	2745600	et	3	main
kuna	doc_582053207538_item	2745602	et	3	main
3	doc_582053207538_item	2745608	et	2	main
keeli	doc_582053207538_item	2745611	et	4	main
keel	doc_582053207538_item	2745616	et	4	main
õppima	doc_582053207538_item	2745628	et	3	main
ilma	doc_582053207539_item	2745636	et	4	main
elada	doc_582053207539_item	2745649	et	3	main
uudisteta	doc_582053207539_item	2745667	et	3	main
emakeele	doc_582053207539_item	2745669	et	4	main
on	doc_582053207539_item	2745673	et	4	main
oluline	doc_582053207539_item	2745676	et	4	main
elada	doc_582053207539_item	2745681	et	3	main
milleta	doc_582053207540_item	2745683	et	3	main
saa	doc_582053207540_item	2745692	et	4	main
tänapäeval	doc_582053207540_item	2745694	et	3	main
on	doc_582053207540_item	2745698	et	4	main
vajalik	doc_582053207540_item	2745705	et	3	main
kassid	doc_582053207536_item	2745327	et	3	main
aga	doc_582053207536_item	2745332	et	3	main
sõja	doc_582053207536_item	2745334	et	3	main
raske	doc_582053207536_item	2745336	et	4	main
ilma	doc_582053207537_item	2745345	et	4	main
arvamus	doc_582053207537_item	2745365	et	3	main
tänapäeval	doc_582053207537_item	2745370	et	3	main
ühel	doc_582053207537_item	2745372	et	3	main
teisel	doc_582053207537_item	2745378	et	4	main
elu	doc_582053207537_item	2745386	et	4	main
mitte	doc_582053207537_item	2745388	et	3	main
ja	doc_582053207537_item	2745401	et	3	main
eksisteerida	doc_582053207537_item	2745409	et	3	main
teised	doc_582053207537_item	2745410	et	4	main
asjad	doc_582053207537_item	2745411	et	3	main
sõltuvad	doc_582053207537_item	2745412	et	4	main
sellest	doc_582053207537_item	2745413	et	4	main
kui	doc_582053207537_item	2745414	et	3	main
suur	doc_582053207537_item	2745415	et	3	main
isu	doc_582053207537_item	2745416	et	4	main
on	doc_582053207537_item	2745417	et	4	main
inimesel	doc_582053207537_item	2745418	et	3	main
erinevatel	doc_582053207537_item	2745419	et	4	main
inimestel	doc_582053207537_item	2745420	et	3	main
nagu	doc_582053207537_item	2745424	et	3	main
väike	doc_582053207537_item	2745432	et	4	main
briljant	doc_582053207537_item	2745433	et	3	main
jaoks	doc_582053207537_item	2745437	et	4	main
see	doc_582053207537_item	2745438	et	3	main
lisada	doc_582053207537_item	2745454	et	3	main
lemmik	doc_582053207537_item	2745455	et	3	main
töö	doc_582053207537_item	2745456	et	4	main
stabiilne	doc_582053207537_item	2745457	et	3	main
veendunud	doc_582053207537_item	2745463	et	4	main
meeste	doc_582053207537_item	2745467	et	4	main
jaoks	doc_582053207537_item	2745468	et	4	main
tähtsam	doc_582053207537_item	2745477	et	4	main
pere	doc_582053207537_item	2745479	et	4	main
isegi	doc_582053207537_item	2745481	et	4	main
ma	doc_582053207537_item	2745482	et	3	main
olen	doc_582053207537_item	2745483	et	3	main
kindel	doc_582053207537_item	2745484	et	3	main
et	doc_582053207537_item	2745485	et	3	main
see	doc_582053207537_item	2745486	et	3	main
teiste	doc_582053207537_item	2745487	et	4	main
inimeste	doc_582053207537_item	2745488	et	3	main
jaoks	doc_582053207537_item	2745489	et	4	main
ka	doc_582053207537_item	2745490	et	3	main
kindel	doc_582053207537_item	2745495	et	3	main
probleemid	doc_582053207537_item	2745423	et	3	main
ühel	doc_582053207537_item	2745426	et	3	main
lahja	doc_582053207537_item	2745429	et	4	main
on	doc_582053207537_item	2745431	et	4	main
ma	doc_582053207537_item	2745442	et	3	main
elada	doc_582053207537_item	2745445	et	3	main
hea	doc_582053207537_item	2745459	et	4	main
ma	doc_582053207537_item	2745461	et	3	main
töökoht	doc_582053207537_item	2745465	et	3	main
jaoks	doc_582053207537_item	2745472	et	4	main
samuti	doc_582053207537_item	2745473	et	3	main
olema	doc_582053207537_item	2745494	et	4	main
saa	doc_582053207537_item	2745506	et	4	main
ette	doc_582053207537_item	2745507	et	4	main
kujutada	doc_582053207537_item	2745508	et	3	main
endale	doc_582053207537_item	2745509	et	4	main
ilma	doc_582053207537_item	2745510	et	4	main
kodu	doc_582053207537_item	2745511	et	4	main
mugavuseta	doc_582053207537_item	2745512	et	4	main
ma	doc_582053207537_item	2745513	et	3	main
ei	doc_582053207537_item	2745514	et	4	main
tahtnud	doc_582053207537_item	2745515	et	4	main
elada	doc_582053207537_item	2745516	et	3	main
selles	doc_582053207537_item	2745517	et	4	main
kohas	doc_582053207537_item	2745518	et	4	main
kus	doc_582053207537_item	2745519	et	3	main
tualett	doc_582053207537_item	2745520	et	3	main
kui	doc_582053207537_item	2745523	et	3	main
suvel	doc_582053207537_item	2745524	et	3	main
nii	doc_582053207537_item	2745525	et	3	main
rohkem	doc_582053207537_item	2745543	et	4	main
mõtteid	doc_582053207537_item	2745544	et	3	main
tähelepanu	doc_582053207537_item	2745550	et	4	main
milleta	doc_582053207538_item	2745553	et	3	main
inimene	doc_582053207538_item	2745556	et	3	main
ilma	doc_582053207538_item	2745559	et	4	main
ilma	doc_582053207538_item	2745568	et	4	main
inimene	doc_582053207538_item	2745570	et	3	main
inimene	doc_582053207538_item	2745580	et	3	main
sõltub	doc_582053207538_item	2745590	et	3	main
haridusest	doc_582053207538_item	2745592	et	4	main
tööd	doc_582053207538_item	2745601	et	4	main
kallis	doc_582053207538_item	2745607	et	4	main
ajal	doc_582053207537_item	2745522	et	4	main
talvel	doc_582053207537_item	2745527	et	4	main
praegu	doc_582053207537_item	2745528	et	3	main
ei	doc_582053207537_item	2745537	et	4	main
mis	doc_582053207537_item	2745539	et	4	main
veel	doc_582053207537_item	2745540	et	4	main
võib	doc_582053207537_item	2745541	et	3	main
kirjutada	doc_582053207537_item	2745542	et	3	main
tänan	doc_582053207537_item	2745548	et	3	main
eest	doc_582053207537_item	2745551	et	4	main
elada	doc_582053207538_item	2745558	et	3	main
milleta	doc_582053207538_item	2745560	et	3	main
ei	doc_582053207538_item	2745561	et	4	main
inimene	doc_582053207538_item	2745563	et	3	main
tänapäeval	doc_582053207538_item	2745564	et	3	main
elada	doc_582053207538_item	2745565	et	3	main
elu	doc_582053207538_item	2745574	et	4	main
seda	doc_582053207538_item	2745575	et	3	main
leidmine	doc_582053207538_item	2745588	et	4	main
2	doc_582053207538_item	2745593	et	2	main
tööta	doc_582053207538_item	2745595	et	4	main
peab	doc_582053207538_item	2745597	et	4	main
töötama	doc_582053207538_item	2745598	et	3	main
raske	doc_582053207538_item	2745605	et	4	main
ja	doc_582053207538_item	2745606	et	3	main
eesti	doc_582053207538_item	2745610	et	4	main
lauteda	doc_582053207538_item	2745612	et	4	main
riigikeel	doc_582053207538_item	2745613	et	4	main
on	doc_582053207538_item	2745614	et	4	main
inimene	doc_582053207538_item	2745617	et	3	main
eesti	doc_582053207538_item	2745620	et	4	main
4	doc_582053207538_item	2745622	et	2	main
eesti	doc_582053207538_item	2745631	et	4	main
teel	doc_582053207538_item	2745633	et	4	main
õppilase	doc_582053207538_item	2745634	et	4	main
saa	doc_582053207539_item	2745646	et	4	main
inimene	doc_582053207539_item	2745647	et	3	main
meie	doc_582053207539_item	2745650	et	4	main
ei	doc_582053207539_item	2745651	et	4	main
töövõimaluseta	doc_582053207539_item	2745657	et	3	main
sideta	doc_582053207539_item	2745659	et	4	main
perekonnata	doc_582053207539_item	2745660	et	4	main
päikeseta	doc_582053207539_item	2745668	et	4	main
oskuseta	doc_582053207539_item	2745670	et	3	main
töötada	doc_582053207539_item	2745679	et	3	main
ei	doc_582053207540_item	2745684	et	4	main
elada	doc_582053207540_item	2745688	et	3	main
ilma	doc_582053207540_item	2745689	et	4	main
milleta	doc_582053207540_item	2745690	et	3	main
palju	doc_582053207540_item	2745700	et	4	main
mis	doc_582053207540_item	2745703	et	4	main
inimsele	doc_582053207540_item	2745706	et	4	main
sünnitamist	doc_582053207540_item	2745730	et	4	main
olin	doc_582053207540_item	2745732	et	3	main
haige	doc_582053207540_item	2745734	et	4	main
loodus	doc_582053207540_item	2745735	et	4	main
oli	doc_582053207540_item	2745736	et	3	main
edasi	doc_582053207540_item	2745742	et	3	main
kõige	doc_582053207540_item	2745745	et	4	main
on	doc_582053207540_item	2745765	et	4	main
väga	doc_582053207540_item	2745766	et	3	main
raske	doc_582053207540_item	2745767	et	4	main
kirjutada	doc_582053207540_item	2745768	et	3	main
minu	doc_582053207540_item	2745776	et	3	main
ta	doc_582053207540_item	2745778	et	4	main
ta	doc_582053207540_item	2745784	et	4	main
elu	doc_582053207538_item	2745603	et	4	main
on	doc_582053207538_item	2745604	et	4	main
õppima	doc_582053207538_item	2745619	et	3	main
keel	doc_582053207538_item	2745621	et	4	main
võrkeeli	doc_582053207538_item	2745624	et	4	main
on	doc_582053207538_item	2745632	et	4	main
ei	doc_582053207539_item	2745638	et	4	main
saa	doc_582053207539_item	2745639	et	4	main
inimene	doc_582053207539_item	2745640	et	3	main
tänapäeval	doc_582053207539_item	2745641	et	3	main
elada	doc_582053207539_item	2745642	et	3	main
ilma	doc_582053207539_item	2745643	et	4	main
milleta	doc_582053207539_item	2745644	et	3	main
tänapäeval	doc_582053207539_item	2745648	et	3	main
keeleoskuseta	doc_582053207539_item	2745656	et	3	main
vaja	doc_582053207539_item	2745678	et	4	main
ilma	doc_582053207540_item	2745682	et	4	main
inimene	doc_582053207540_item	2745693	et	3	main
erinevaid	doc_582053207540_item	2745701	et	4	main
asju	doc_582053207540_item	2745702	et	3	main
vanemad	doc_582053207540_item	2745712	et	4	main
sõbrad	doc_582053207540_item	2745713	et	3	main
töö	doc_582053207540_item	2745714	et	4	main
raha	doc_582053207540_item	2745715	et	4	main
tervist	doc_582053207540_item	2745726	et	4	main
lapse	doc_582053207540_item	2745729	et	4	main
mina	doc_582053207540_item	2745731	et	4	main
hea	doc_582053207540_item	2745746	et	4	main
korter	doc_582053207540_item	2745750	et	3	main
isegi	doc_582053207540_item	2745762	et	4	main
praegu	doc_582053207540_item	2745763	et	3	main
minusse	doc_582053207540_item	2745774	et	3	main
soovitasid	doc_582053207540_item	2745782	et	4	main
aastane	doc_582053207540_item	2745794	et	4	main
muidugi	doc_582053207540_item	2745825	et	4	main
praegu	doc_582053207540_item	2745826	et	3	main
tulevad	doc_582053207540_item	2745842	et	4	main
milleta	doc_582053207541_item	2745851	et	3	main
ei	doc_582053207541_item	2745852	et	4	main
kui	doc_582053207541_item	2745857	et	3	main
või	doc_582053207541_item	2745859	et	4	main
inimese	doc_582053207541_item	2745861	et	4	main
ilma	doc_582053207541_item	2745865	et	4	main
õhuta	doc_582053207541_item	2745866	et	4	main
ei	doc_582053207541_item	2745872	et	4	main
välja	doc_582053207541_item	2745874	et	4	main
füüsilisest	doc_582053207541_item	2745884	et	3	main
ei	doc_582053207541_item	2745886	et	4	main
inimesi	doc_582053207541_item	2745892	et	4	main
kes	doc_582053207541_item	2745893	et	4	main
elasid	doc_582053207541_item	2745894	et	4	main
meie	doc_582053207541_item	2745900	et	4	main
põlvkonna	doc_582053207541_item	2745901	et	4	main
probleemid	doc_582053207541_item	2745902	et	3	main
säästmine	doc_582053207541_item	2745908	et	4	main
efekt	doc_582053207541_item	2745914	et	3	main
ainult	doc_582053207541_item	2745929	et	4	main
vähem	doc_582053207541_item	2745936	et	4	main
siis	doc_582053207541_item	2745939	et	3	main
ei	doc_582053207541_item	2745944	et	4	main
saamisel	doc_582053207541_item	2745950	et	4	main
miks	doc_582053207541_item	2745955	et	4	main
nii	doc_582053207541_item	2745956	et	3	main
juhtub	doc_582053207541_item	2745957	et	3	main
ja	doc_582053207541_item	2745958	et	3	main
kuidas	doc_582053207541_item	2745959	et	3	main
ära	doc_582053207541_item	2745960	et	4	main
hoiduda	doc_582053207541_item	2745961	et	3	main
jubedate	doc_582053207541_item	2745962	et	3	main
sündmuste	doc_582053207541_item	2745963	et	3	main
elavad	doc_582053207541_item	2746015	et	4	main
samad	doc_582053207541_item	2746017	et	3	main
ei	doc_582053207541_item	2746028	et	4	main
tänapäeva	doc_582053207541_item	2746030	et	4	main
eluga	doc_582053207541_item	2746031	et	3	main
hakkama	doc_582053207541_item	2746032	et	3	main
perekonnata	doc_582053207541_item	2746039	et	4	main
eelistavad	doc_582053207541_item	2746052	et	4	main
üksindust	doc_582053207541_item	2746053	et	3	main
minu	doc_582053207541_item	2746056	et	3	main
tohi	doc_582053207541_item	2746060	et	4	main
edasi	doc_582053207541_item	2746061	et	3	main
ilma	doc_582053207538_item	2745623	et	4	main
lauteda	doc_582053207538_item	2745625	et	4	main
inimene	doc_582053207538_item	2745626	et	3	main
võrkeeli	doc_582053207538_item	2745629	et	4	main
ühiskonda	doc_582053207538_item	2745635	et	4	main
ei	doc_582053207539_item	2745645	et	4	main
saa	doc_582053207539_item	2745652	et	4	main
elada	doc_582053207539_item	2745653	et	3	main
ilma	doc_582053207539_item	2745654	et	4	main
hariduseta	doc_582053207539_item	2745655	et	3	main
arvutita	doc_582053207539_item	2745658	et	4	main
tööta	doc_582053207539_item	2745661	et	4	main
rahata	doc_582053207539_item	2745663	et	4	main
telefonideta	doc_582053207539_item	2745665	et	3	main
kõik	doc_582053207539_item	2745672	et	4	main
tänapäeval	doc_582053207539_item	2745675	et	3	main
et	doc_582053207539_item	2745677	et	3	main
ei	doc_582053207540_item	2745691	et	4	main
meie	doc_582053207540_item	2745696	et	4	main
väga	doc_582053207540_item	2745699	et	3	main
kõige	doc_582053207540_item	2745721	et	4	main
inimesele	doc_582053207540_item	2745723	et	3	main
esimese	doc_582053207540_item	2745728	et	3	main
nii	doc_582053207540_item	2745737	et	3	main
perekond	doc_582053207540_item	2745747	et	3	main
mugavustega	doc_582053207540_item	2745749	et	4	main
väike	doc_582053207540_item	2745755	et	4	main
ilus	doc_582053207540_item	2745756	et	4	main
laps	doc_582053207540_item	2745757	et	4	main
mul	doc_582053207540_item	2745764	et	3	main
oli	doc_582053207540_item	2745775	et	3	main
arstid	doc_582053207540_item	2745783	et	4	main
mina	doc_582053207540_item	2745790	et	4	main
viie	doc_582053207540_item	2745793	et	3	main
armastuseta	doc_582053207540_item	2745821	et	4	main
hobbid	doc_582053207540_item	2745841	et	4	main
ilma	doc_582053207541_item	2745850	et	4	main
elada	doc_582053207541_item	2745856	et	3	main
füüsilisest	doc_582053207541_item	2745862	et	3	main
elust	doc_582053207541_item	2745863	et	3	main
siis	doc_582053207541_item	2745864	et	3	main
inimene	doc_582053207541_item	2745870	et	3	main
elada	doc_582053207541_item	2745875	et	3	main
kuid	doc_582053207541_item	2745876	et	4	main
küsitakse	doc_582053207541_item	2745878	et	4	main
tänapäevasest	doc_582053207541_item	2745879	et	4	main
räägita	doc_582053207541_item	2745887	et	4	main
sest	doc_582053207541_item	2745888	et	4	main
need	doc_582053207541_item	2745889	et	3	main
mured	doc_582053207541_item	2745890	et	3	main
aastaid	doc_582053207541_item	2745898	et	4	main
katastroofid	doc_582053207541_item	2745910	et	3	main
muutmine	doc_582053207541_item	2745912	et	4	main
mille	doc_582053207541_item	2745920	et	3	main
abil	doc_582053207541_item	2745932	et	4	main
tean	doc_582053207541_item	2745938	et	3	main
rahulikum	doc_582053207541_item	2745940	et	4	main
vaid	doc_582053207541_item	2745942	et	3	main
hakkab	doc_582053207541_item	2745952	et	3	main
sellele	doc_582053207541_item	2745954	et	4	main
ja	doc_582053207541_item	2745964	et	3	main
tekkimisest	doc_582053207541_item	2745967	et	4	main
ei	doc_582053207541_item	2745973	et	4	main
saa	doc_582053207541_item	2745974	et	4	main
inimene	doc_582053207541_item	2745975	et	3	main
armastab	doc_582053207541_item	2745976	et	3	main
reisima	doc_582053207541_item	2745977	et	3	main
inimesed	doc_582053207541_item	2746009	et	3	main
ametikohtadel	doc_582053207541_item	2746013	et	3	main
suurepäraselt	doc_582053207541_item	2746016	et	4	main
sõnad	doc_582053207541_item	2746018	et	4	main
võib	doc_582053207541_item	2746019	et	3	main
tihti	doc_582053207541_item	2746022	et	3	main
haritatud	doc_582053207541_item	2746026	et	4	main
saa	doc_582053207541_item	2746029	et	4	main
saama	doc_582053207541_item	2746033	et	4	main
ja	doc_582053207541_item	2746034	et	3	main
jääb	doc_582053207541_item	2746035	et	3	main
prügimäele	doc_582053207541_item	2746036	et	3	main
võivad	doc_582053207541_item	2746048	et	4	main
vaidelda	doc_582053207541_item	2746049	et	4	main
et	doc_582053207541_item	2746050	et	3	main
nad	doc_582053207541_item	2746051	et	3	main
sõltumatust	doc_582053207541_item	2746055	et	4	main
arvates	doc_582053207541_item	2746057	et	4	main
maakera	doc_582053207541_item	2746064	et	4	main
floora	doc_582053207541_item	2746065	et	4	main
hea	doc_582053207540_item	2745707	et	4	main
haridust	doc_582053207540_item	2745708	et	4	main
targad	doc_582053207540_item	2745709	et	3	main
ja	doc_582053207540_item	2745710	et	3	main
lahked	doc_582053207540_item	2745711	et	3	main
aga	doc_582053207540_item	2745717	et	3	main
mina	doc_582053207540_item	2745718	et	4	main
arvan	doc_582053207540_item	2745719	et	3	main
et	doc_582053207540_item	2745720	et	3	main
vajalikum	doc_582053207540_item	2745722	et	4	main
pärast	doc_582053207540_item	2745727	et	4	main
väga	doc_582053207540_item	2745733	et	3	main
väike	doc_582053207540_item	2745738	et	4	main
et	doc_582053207540_item	2745739	et	3	main
elan	doc_582053207540_item	2745741	et	3	main
mul	doc_582053207540_item	2745743	et	3	main
mees	doc_582053207540_item	2745754	et	4	main
nutsin	doc_582053207540_item	2745761	et	4	main
inimene	doc_582053207540_item	2745771	et	3	main
kes	doc_582053207540_item	2745772	et	4	main
usus	doc_582053207540_item	2745773	et	3	main
mees	doc_582053207540_item	2745777	et	4	main
tegi	doc_582053207540_item	2745779	et	4	main
kõike	doc_582053207540_item	2745780	et	4	main
aitas	doc_582053207540_item	2745785	et	3	main
mind	doc_582053207540_item	2745786	et	4	main
olen	doc_582053207540_item	2745791	et	3	main
naine	doc_582053207540_item	2745795	et	3	main
nii	doc_582053207540_item	2745796	et	3	main
kaua	doc_582053207540_item	2745797	et	3	main
ma	doc_582053207540_item	2745798	et	3	main
elan	doc_582053207540_item	2745799	et	3	main
kui	doc_582053207540_item	2745800	et	3	main
prognoosid	doc_582053207540_item	2745801	et	4	main
olid	doc_582053207540_item	2745802	et	4	main
väga	doc_582053207540_item	2745803	et	3	main
halvad	doc_582053207540_item	2745804	et	4	main
mina	doc_582053207540_item	2745805	et	4	main
olen	doc_582053207540_item	2745806	et	3	main
rõõmsameelne	doc_582053207540_item	2745807	et	3	main
inimene	doc_582053207540_item	2745808	et	3	main
ja	doc_582053207540_item	2745809	et	3	main
ma	doc_582053207540_item	2745810	et	3	main
tean	doc_582053207540_item	2745811	et	3	main
igale	doc_582053207540_item	2745812	et	3	main
inimesele	doc_582053207540_item	2745813	et	3	main
annab	doc_582053207540_item	2745814	et	3	main
palju	doc_582053207540_item	2745815	et	4	main
jõudu	doc_582053207540_item	2745816	et	4	main
armastust	doc_582053207540_item	2745817	et	4	main
laies	doc_582053207540_item	2745818	et	4	main
mõttes	doc_582053207540_item	2745819	et	3	main
ilma	doc_582053207540_item	2745820	et	4	main
p	doc_582053207540_item	2745824	et	4	main
et	doc_582053207540_item	2745834	et	3	main
näha	doc_582053207540_item	2745835	et	3	main
ilma	doc_582053207541_item	2745843	et	4	main
milleta	doc_582053207541_item	2745844	et	3	main
saa	doc_582053207541_item	2745853	et	4	main
saa	doc_582053207541_item	2745873	et	4	main
puudutasid	doc_582053207541_item	2745891	et	4	main
tagasi	doc_582053207541_item	2745899	et	3	main
ilmumine	doc_582053207541_item	2745917	et	4	main
on	doc_582053207541_item	2745922	et	4	main
kogu	doc_582053207541_item	2745924	et	4	main
viiekümne	doc_582053207540_item	2745792	et	4	main
raske	doc_582053207540_item	2745822	et	4	main
on	doc_582053207540_item	2745827	et	4	main
huvitav	doc_582053207540_item	2745829	et	4	main
elada	doc_582053207540_item	2745830	et	3	main
tahaks	doc_582053207540_item	2745831	et	3	main
elada	doc_582053207540_item	2745832	et	3	main
kaua	doc_582053207540_item	2745833	et	3	main
kuidas	doc_582053207540_item	2745836	et	3	main
ei	doc_582053207541_item	2745845	et	4	main
inimene	doc_582053207541_item	2745854	et	3	main
rääkida	doc_582053207541_item	2745858	et	3	main
kirjutada	doc_582053207541_item	2745860	et	3	main
üldse	doc_582053207541_item	2745871	et	3	main
lihtsalt	doc_582053207541_item	2745883	et	4	main
elust	doc_582053207541_item	2745885	et	3	main
palju	doc_582053207541_item	2745897	et	4	main
teised	doc_582053207541_item	2745904	et	4	main
need	doc_582053207541_item	2745905	et	3	main
on	doc_582053207541_item	2745906	et	4	main
ümbruskeskkonna	doc_582053207541_item	2745907	et	3	main
uute	doc_582053207541_item	2745915	et	3	main
haiguste	doc_582053207541_item	2745916	et	4	main
terroristide	doc_582053207541_item	2745918	et	3	main
tegevus	doc_582053207541_item	2745919	et	4	main
elada	doc_582053207540_item	2745823	et	3	main
väga	doc_582053207540_item	2745828	et	3	main
arenevad	doc_582053207540_item	2745837	et	4	main
inimesed	doc_582053207540_item	2745838	et	3	main
tehnika	doc_582053207540_item	2745839	et	4	main
missugused	doc_582053207540_item	2745840	et	3	main
saa	doc_582053207541_item	2745846	et	4	main
inimene	doc_582053207541_item	2745847	et	3	main
tänapäeval	doc_582053207541_item	2745848	et	3	main
elada	doc_582053207541_item	2745849	et	3	main
tänapäeval	doc_582053207541_item	2745855	et	3	main
veeta	doc_582053207541_item	2745867	et	4	main
ja	doc_582053207541_item	2745868	et	3	main
söögita	doc_582053207541_item	2745869	et	3	main
väljendis	doc_582053207541_item	2745877	et	3	main
inimese	doc_582053207541_item	2745880	et	4	main
elust	doc_582053207541_item	2745881	et	3	main
siis	doc_582053207541_item	2745882	et	3	main
koobades	doc_582053207541_item	2745895	et	4	main
ja	doc_582053207541_item	2745896	et	3	main
on	doc_582053207541_item	2745903	et	4	main
looduslikud	doc_582053207541_item	2745909	et	3	main
kliima	doc_582053207541_item	2745911	et	4	main
kasvuhoone	doc_582053207541_item	2745913	et	4	main
tulemuseks	doc_582053207541_item	2745921	et	3	main
arenenud	doc_582053207541_item	2745930	et	4	main
ma	doc_582053207541_item	2745937	et	3	main
õige	doc_582053207541_item	2745947	et	4	main
niisuguse	doc_582053207541_item	2745948	et	3	main
mõtlema	doc_582053207541_item	2745953	et	3	main
nende	doc_582053207541_item	2745965	et	4	main
see	doc_582053207541_item	2745968	et	3	main
tähendab	doc_582053207541_item	2745969	et	3	main
ilma	doc_582053207541_item	2745970	et	4	main
infotehnoloogiata	doc_582053207541_item	2745971	et	3	main
teenivad	doc_582053207541_item	2746010	et	4	main
kasvatatud	doc_582053207541_item	2746024	et	4	main
et	doc_582053207541_item	2746038	et	3	main
lähedasteta	doc_582053207541_item	2746041	et	3	main
elada	doc_582053207541_item	2746044	et	3	main
edukad	doc_582053207541_item	2746046	et	3	main
inimesed	doc_582053207541_item	2746047	et	3	main
on	doc_582053207541_item	2746073	et	4	main
milleta	doc_582053207542_item	2746078	et	3	main
tänapäeval	doc_582053207542_item	2746082	et	3	main
esimene	doc_582053207542_item	2746098	et	3	main
väike	doc_582053207542_item	2746124	et	4	main
läheb	doc_582053207542_item	2746126	et	3	main
lapsele	doc_582053207542_item	2746135	et	4	main
esimesed	doc_582053207542_item	2746136	et	3	main
laiad	doc_582053207542_item	2746137	et	4	main
hariduseta	doc_582053207542_item	2746166	et	3	main
omandatud	doc_582053207542_item	2746168	et	4	main
inimesele	doc_582053207542_item	2746171	et	3	main
võimalust	doc_582053207542_item	2746172	et	3	main
edasi	doc_582053207542_item	2746173	et	3	main
areneda	doc_582053207542_item	2746174	et	3	main
ja	doc_582053207542_item	2746175	et	3	main
ennast	doc_582053207542_item	2746176	et	4	main
väljendada	doc_582053207542_item	2746177	et	3	main
ka	doc_582053207542_item	2746192	et	3	main
inimohvred	doc_582053207541_item	2745923	et	4	main
informatsioon	doc_582053207541_item	2745926	et	3	main
jõuab	doc_582053207541_item	2745927	et	3	main
meieni	doc_582053207541_item	2745928	et	4	main
infosüsteemi	doc_582053207541_item	2745931	et	4	main
võiks	doc_582053207541_item	2745933	et	4	main
öelda	doc_582053207541_item	2745934	et	4	main
kui	doc_582053207541_item	2745935	et	3	main
informatsiooni	doc_582053207541_item	2745949	et	4	main
elada	doc_582053207541_item	2745972	et	3	main
aga	doc_582053207541_item	2745978	et	3	main
kuidas	doc_582053207541_item	2745979	et	3	main
saada	doc_582053207541_item	2745980	et	4	main
austraaliasse	doc_582053207541_item	2745981	et	4	main
või	doc_582053207541_item	2745982	et	4	main
pariisi	doc_582053207541_item	2745983	et	4	main
ilma	doc_582053207541_item	2745984	et	4	main
lennukita	doc_582053207541_item	2745985	et	3	main
või	doc_582053207541_item	2745986	et	4	main
autota	doc_582053207541_item	2745987	et	3	main
ei	doc_582053207541_item	2745988	et	4	main
saa	doc_582053207541_item	2745989	et	4	main
põhimõtteliselt	doc_582053207541_item	2745990	et	4	main
saab	doc_582053207541_item	2745991	et	3	main
kuid	doc_582053207541_item	2745992	et	4	main
väga	doc_582053207541_item	2745993	et	3	main
igav	doc_582053207541_item	2745994	et	3	main
võiks	doc_582053207541_item	2745995	et	4	main
küll	doc_582053207541_item	2745996	et	4	main
öelda	doc_582053207541_item	2745997	et	4	main
et	doc_582053207541_item	2745998	et	3	main
ilma	doc_582053207541_item	2745999	et	4	main
hariduseta	doc_582053207541_item	2746000	et	3	main
hästi	doc_582053207541_item	2746001	et	3	main
elada	doc_582053207541_item	2746002	et	3	main
ei	doc_582053207541_item	2746003	et	4	main
saa	doc_582053207541_item	2746004	et	4	main
kuid	doc_582053207541_item	2746005	et	4	main
ilma	doc_582053207541_item	2746006	et	4	main
see	doc_582053207541_item	2745925	et	3	main
elan	doc_582053207541_item	2745941	et	3	main
see	doc_582053207541_item	2745943	et	3	main
ole	doc_582053207541_item	2745945	et	4	main
täielikult	doc_582053207541_item	2745946	et	4	main
inimene	doc_582053207541_item	2745951	et	3	main
tagajärgede	doc_582053207541_item	2745966	et	3	main
selleta	doc_582053207541_item	2746007	et	3	main
paljud	doc_582053207541_item	2746008	et	3	main
headel	doc_582053207541_item	2746012	et	3	main
kasvatusest	doc_582053207541_item	2746021	et	4	main
hästi	doc_582053207541_item	2746023	et	3	main
ja	doc_582053207541_item	2746025	et	3	main
ütlen	doc_582053207541_item	2746037	et	3	main
ei	doc_582053207541_item	2746042	et	4	main
tohi	doc_582053207541_item	2746043	et	4	main
siis	doc_582053207541_item	2746045	et	3	main
ilma	doc_582053207541_item	2746063	et	4	main
säilitamise	doc_582053207541_item	2746070	et	4	main
ei	doc_582053207542_item	2746079	et	4	main
ilma	doc_582053207542_item	2746084	et	4	main
peab	doc_582053207542_item	2746095	et	4	main
sündima	doc_582053207542_item	2746096	et	3	main
järelikult	doc_582053207542_item	2746097	et	3	main
isa	doc_582053207542_item	2746122	et	4	main
lasteaia	doc_582053207542_item	2746127	et	4	main
kooli	doc_582053207542_item	2746130	et	4	main
lasteaed	doc_582053207542_item	2746131	et	3	main
ja	doc_582053207542_item	2746132	et	3	main
kool	doc_582053207542_item	2746133	et	4	main
elust	doc_582053207542_item	2746139	et	3	main
maailmast	doc_582053207542_item	2746140	et	4	main
ja	doc_582053207542_item	2746141	et	3	main
ei	doc_582053207542_item	2746162	et	4	main
meie	doc_582053207542_item	2746178	et	4	main
kui	doc_582053207542_item	2746181	et	3	main
ta	doc_582053207542_item	2746186	et	4	main
töö	doc_582053207542_item	2746189	et	4	main
väga	doc_582053207542_item	2746193	et	3	main
kasvavad	doc_582053207542_item	2746230	et	4	main
ja	doc_582053207542_item	2746231	et	3	main
igal	doc_582053207542_item	2746235	et	3	main
huvid	doc_582053207542_item	2746242	et	3	main
ta	doc_582053207542_item	2746245	et	4	main
ei	doc_582053207542_item	2746250	et	4	main
ainult	doc_582053207542_item	2746269	et	4	main
tema	doc_582053207542_item	2746270	et	4	main
kõrval	doc_582053207542_item	2746271	et	4	main
need	doc_582053207542_item	2746272	et	3	main
inimesed	doc_582053207542_item	2746273	et	3	main
mis	doc_582053207542_item	2746280	et	4	main
saa	doc_582053207543_item	2746288	et	4	main
inimene	doc_582053207543_item	2746289	et	3	main
ilma	doc_582053207543_item	2746292	et	4	main
milleta	doc_582053207543_item	2746293	et	3	main
ei	doc_582053207543_item	2746294	et	4	main
saa	doc_582053207543_item	2746302	et	4	main
arvates	doc_582053207543_item	2746305	et	4	main
ilma	doc_582053207543_item	2746306	et	4	main
areneb	doc_582053207543_item	2746312	et	3	main
kõike	doc_582053207543_item	2746317	et	4	main
jälgida	doc_582053207543_item	2746318	et	3	main
kõige	doc_582053207543_item	2746319	et	4	main
kaudu	doc_582053207543_item	2746328	et	3	main
ja	doc_582053207543_item	2746334	et	3	main
saa	doc_582053207543_item	2746346	et	4	main
ilma	doc_582053207543_item	2746349	et	4	main
on	doc_582053207543_item	2746355	et	4	main
vanasti	doc_582053207543_item	2746364	et	3	main
teenimine	doc_582053207543_item	2746389	et	4	main
võtavad	doc_582053207543_item	2746390	et	3	main
meie	doc_582053207543_item	2746395	et	4	main
meilt	doc_582053207543_item	2746399	et	3	main
p	doc_582053207543_item	2746401	et	4	main
ilma	doc_582053207544_item	2746402	et	4	main
milleta	doc_582053207544_item	2746403	et	3	main
ja	doc_582053207544_item	2746418	et	3	main
jaoks	doc_582053207544_item	2746423	et	4	main
toob	doc_582053207544_item	2746427	et	3	main
inimene	doc_582053207544_item	2746443	et	3	main
võib	doc_582053207544_item	2746454	et	3	main
väike	doc_582053207544_item	2746456	et	4	main
põllul	doc_582053207544_item	2746458	et	3	main
raha	doc_582053207541_item	2746011	et	4	main
ja	doc_582053207541_item	2746014	et	3	main
öelda	doc_582053207541_item	2746020	et	4	main
inimene	doc_582053207541_item	2746027	et	3	main
ja	doc_582053207541_item	2746040	et	3	main
ja	doc_582053207541_item	2746054	et	3	main
täna	doc_582053207541_item	2746058	et	4	main
ei	doc_582053207541_item	2746059	et	4	main
kavata	doc_582053207541_item	2746071	et	3	main
inimkonna	doc_582053207541_item	2746075	et	4	main
elada	doc_582053207542_item	2746083	et	3	main
ei	doc_582053207542_item	2746086	et	4	main
inimene	doc_582053207542_item	2746088	et	3	main
tänapäeval	doc_582053207542_item	2746089	et	3	main
elada	doc_582053207542_item	2746090	et	3	main
et	doc_582053207542_item	2746091	et	3	main
üldse	doc_582053207542_item	2746092	et	3	main
inimene	doc_582053207542_item	2746094	et	3	main
milleta	doc_582053207542_item	2746101	et	3	main
ilma	doc_582053207542_item	2746100	et	4	main
ei	doc_582053207542_item	2746102	et	4	main
saa	doc_582053207542_item	2746103	et	4	main
inimene	doc_582053207542_item	2746104	et	3	main
elada	doc_582053207542_item	2746105	et	3	main
see	doc_582053207542_item	2746106	et	3	main
on	doc_582053207542_item	2746107	et	4	main
ema	doc_582053207542_item	2746108	et	4	main
ja	doc_582053207542_item	2746109	et	3	main
isa	doc_582053207542_item	2746110	et	4	main
siis	doc_582053207542_item	2746111	et	3	main
järgmine	doc_582053207542_item	2746112	et	3	main
etapp	doc_582053207542_item	2746113	et	3	main
lapse	doc_582053207542_item	2746115	et	4	main
on	doc_582053207542_item	2746114	et	4	main
kasvatamine	doc_582053207542_item	2746116	et	4	main
alguses	doc_582053207542_item	2746117	et	4	main
kasvatavad	doc_582053207542_item	2746118	et	4	main
last	doc_582053207542_item	2746119	et	4	main
ema	doc_582053207542_item	2746120	et	4	main
ja	doc_582053207542_item	2746121	et	3	main
ja	doc_582053207542_item	2746128	et	3	main
teadmised	doc_582053207542_item	2746138	et	4	main
lõpetamist	doc_582053207542_item	2746145	et	4	main
lähevad	doc_582053207542_item	2746152	et	3	main
kohe	doc_582053207542_item	2746154	et	4	main
saa	doc_582053207542_item	2746163	et	4	main
siis	doc_582053207542_item	2746180	et	3	main
asub	doc_582053207542_item	2746187	et	3	main
tööle	doc_582053207542_item	2746188	et	3	main
see	doc_582053207542_item	2746190	et	3	main
tähtis	doc_582053207542_item	2746194	et	4	main
on	doc_582053207542_item	2746237	et	4	main
asjad	doc_582053207542_item	2746240	et	3	main
ilma	doc_582053207542_item	2746256	et	4	main
mõnedel	doc_582053207542_item	2746260	et	3	main
oleks	doc_582053207542_item	2746268	et	3	main
on	doc_582053207542_item	2746277	et	4	main
tänapäeval	doc_582053207543_item	2746290	et	3	main
inimene	doc_582053207543_item	2746296	et	3	main
elada	doc_582053207543_item	2746298	et	3	main
ei	doc_582053207543_item	2746301	et	4	main
elada	doc_582053207543_item	2746303	et	3	main
minu	doc_582053207543_item	2746304	et	3	main
elu	doc_582053207543_item	2746309	et	4	main
nii	doc_582053207543_item	2746310	et	3	main
elada	doc_582053207541_item	2746062	et	3	main
kaitsmise	doc_582053207541_item	2746068	et	4	main
ja	doc_582053207541_item	2746069	et	3	main
ilma	doc_582053207542_item	2746077	et	4	main
milleta	doc_582053207542_item	2746085	et	3	main
saa	doc_582053207542_item	2746087	et	4	main
elada	doc_582053207542_item	2746093	et	3	main
ja	doc_582053207541_item	2746066	et	3	main
fauna	doc_582053207541_item	2746067	et	4	main
see	doc_582053207541_item	2746072	et	3	main
kogu	doc_582053207541_item	2746074	et	4	main
mure	doc_582053207541_item	2746076	et	4	main
saa	doc_582053207542_item	2746080	et	4	main
inimene	doc_582053207542_item	2746081	et	3	main
asi	doc_582053207542_item	2746099	et	4	main
siis	doc_582053207542_item	2746123	et	3	main
pärast	doc_582053207542_item	2746129	et	4	main
pärast	doc_582053207542_item	2746143	et	4	main
keskkooli	doc_582053207542_item	2746144	et	4	main
teistmeelised	doc_582053207542_item	2746147	et	4	main
või	doc_582053207542_item	2746149	et	4	main
mõned	doc_582053207542_item	2746151	et	3	main
sest	doc_582053207542_item	2746167	et	4	main
haridus	doc_582053207542_item	2746169	et	3	main
annab	doc_582053207542_item	2746170	et	3	main
hariduse	doc_582053207542_item	2746185	et	3	main
läheb	doc_582053207542_item	2746222	et	3	main
hästi	doc_582053207542_item	2746224	et	3	main
alustavad	doc_582053207542_item	2746232	et	4	main
vajadused	doc_582053207542_item	2746239	et	3	main
ja	doc_582053207542_item	2746241	et	3	main
ilma	doc_582053207542_item	2746243	et	4	main
saa	doc_582053207542_item	2746251	et	4	main
ilma	doc_582053207542_item	2746253	et	4	main
koduta	doc_582053207542_item	2746257	et	3	main
teda	doc_582053207542_item	2746266	et	4	main
armastaks	doc_582053207542_item	2746267	et	3	main
armastus	doc_582053207542_item	2746276	et	4	main
paneb	doc_582053207542_item	2746281	et	3	main
tegutsema	doc_582053207542_item	2746283	et	3	main
elada	doc_582053207543_item	2746291	et	3	main
tänapäeval	doc_582053207543_item	2746297	et	3	main
tänapäeval	doc_582053207543_item	2746299	et	3	main
arvutiteta	doc_582053207543_item	2746307	et	4	main
tähtsamat	doc_582053207543_item	2746320	et	4	main
laps	doc_582053207542_item	2746125	et	4	main
annavab	doc_582053207542_item	2746134	et	4	main
teadustest	doc_582053207542_item	2746142	et	4	main
lähevad	doc_582053207542_item	2746146	et	3	main
gümnaasiumisse	doc_582053207542_item	2746148	et	3	main
tehnikumisse	doc_582053207542_item	2746150	et	4	main
aga	doc_582053207542_item	2746153	et	3	main
tööle	doc_582053207542_item	2746155	et	3	main
sellest	doc_582053207542_item	2746156	et	4	main
võib	doc_582053207542_item	2746157	et	3	main
järeldada	doc_582053207542_item	2746158	et	3	main
et	doc_582053207542_item	2746159	et	3	main
tänapäeval	doc_582053207542_item	2746160	et	3	main
inimene	doc_582053207542_item	2746161	et	3	main
elada	doc_582053207542_item	2746164	et	3	main
ilma	doc_582053207542_item	2746165	et	4	main
seltskonnas	doc_582053207542_item	2746179	et	3	main
inimene	doc_582053207542_item	2746182	et	3	main
on	doc_582053207542_item	2746183	et	4	main
omandanud	doc_582053207542_item	2746184	et	4	main
on	doc_582053207542_item	2746191	et	4	main
meie	doc_582053207542_item	2746195	et	4	main
tänapäevases	doc_582053207542_item	2746196	et	4	main
elus	doc_582053207542_item	2746197	et	4	main
inimene	doc_582053207542_item	2746198	et	3	main
ei	doc_582053207542_item	2746199	et	4	main
elada	doc_582053207542_item	2746201	et	3	main
ka	doc_582053207542_item	2746202	et	3	main
ilma	doc_582053207542_item	2746203	et	4	main
saa	doc_582053207542_item	2746200	et	4	main
armastuseta	doc_582053207542_item	2746204	et	4	main
inimene	doc_582053207542_item	2746205	et	3	main
püüab	doc_582053207542_item	2746206	et	3	main
oma	doc_582053207542_item	2746207	et	4	main
elu	doc_582053207542_item	2746208	et	4	main
jooksul	doc_582053207542_item	2746209	et	4	main
leida	doc_582053207542_item	2746210	et	3	main
endale	doc_582053207542_item	2746211	et	4	main
sobiva	doc_582053207542_item	2746212	et	4	main
partneri	doc_582053207542_item	2746213	et	3	main
et	doc_582053207542_item	2746214	et	3	main
pärast	doc_582053207542_item	2746215	et	4	main
temaga	doc_582053207542_item	2746216	et	3	main
luua	doc_582053207542_item	2746217	et	4	main
uue	doc_582053207542_item	2746218	et	3	main
perekonda	doc_582053207542_item	2746219	et	4	main
kui	doc_582053207542_item	2746220	et	3	main
noorpaaril	doc_582053207542_item	2746221	et	4	main
oma	doc_582053207542_item	2746233	et	4	main
omad	doc_582053207542_item	2746238	et	4	main
milleta	doc_582053207542_item	2746244	et	3	main
ei	doc_582053207542_item	2746246	et	4	main
saa	doc_582053207542_item	2746247	et	4	main
elada	doc_582053207542_item	2746248	et	3	main
tööta	doc_582053207542_item	2746254	et	4	main
kes	doc_582053207542_item	2746255	et	4	main
jne	doc_582053207542_item	2746258	et	4	main
kõik	doc_582053207542_item	2746223	et	4	main
sünnivad	doc_582053207542_item	2746225	et	3	main
neil	doc_582053207542_item	2746226	et	4	main
varsti	doc_582053207542_item	2746227	et	3	main
lapsed	doc_582053207542_item	2746228	et	3	main
lapsed	doc_582053207542_item	2746229	et	3	main
elubr	doc_582053207542_item	2746234	et	4	main
inimesel	doc_582053207542_item	2746236	et	3	main
kes	doc_582053207542_item	2746249	et	4	main
elada	doc_582053207542_item	2746252	et	3	main
aga	doc_582053207542_item	2746259	et	3	main
on	doc_582053207542_item	2746261	et	4	main
kes	doc_582053207542_item	2746265	et	4	main
arvavad	doc_582053207542_item	2746274	et	4	main
et	doc_582053207542_item	2746275	et	3	main
jõud	doc_582053207542_item	2746279	et	4	main
ilma	doc_582053207543_item	2746285	et	4	main
et	doc_582053207543_item	2746313	et	3	main
võimalust	doc_582053207543_item	2746316	et	3	main
kiiresti	doc_582053207543_item	2746324	et	3	main
leida	doc_582053207543_item	2746326	et	3	main
vajadust	doc_582053207543_item	2746330	et	4	main
näitus	doc_582053207543_item	2746332	et	3	main
raisata	doc_582053207543_item	2746341	et	4	main
oma	doc_582053207543_item	2746342	et	4	main
jooksul	doc_582053207543_item	2746353	et	4	main
mõnikord	doc_582053207543_item	2746354	et	3	main
kui	doc_582053207543_item	2746363	et	3	main
töö	doc_582053207543_item	2746386	et	4	main
ja	doc_582053207543_item	2746387	et	3	main
raha	doc_582053207543_item	2746388	et	4	main
inimene	doc_582053207544_item	2746406	et	3	main
ilma	doc_582053207544_item	2746409	et	4	main
milleta	doc_582053207544_item	2746410	et	3	main
ei	doc_582053207544_item	2746411	et	4	main
tänapäeval	doc_582053207544_item	2746414	et	3	main
tähtsem	doc_582053207544_item	2746421	et	4	main
on	doc_582053207544_item	2746436	et	4	main
kõige	doc_582053207544_item	2746437	et	4	main
armastuseta	doc_582053207544_item	2746446	et	4	main
mis	doc_582053207544_item	2746469	et	4	main
päeval	doc_582053207544_item	2746470	et	3	main
energiat	doc_582053207544_item	2746473	et	3	main
ja	doc_582053207544_item	2746475	et	3	main
aitab	doc_582053207544_item	2746477	et	3	main
me	doc_582053207544_item	2746514	et	4	main
oleme	doc_582053207544_item	2746515	et	3	main
iga	doc_582053207544_item	2746516	et	4	main
päev	doc_582053207544_item	2746517	et	3	main
ja	doc_582053207544_item	2746518	et	3	main
mõni	doc_582053207544_item	2746519	et	3	main
kord	doc_582053207544_item	2746520	et	4	main
vaja	doc_582053207542_item	2746262	et	4	main
et	doc_582053207542_item	2746263	et	3	main
keegi	doc_582053207542_item	2746264	et	4	main
see	doc_582053207542_item	2746278	et	3	main
inimest	doc_582053207542_item	2746282	et	3	main
p	doc_582053207542_item	2746284	et	4	main
milelta	doc_582053207543_item	2746286	et	4	main
ei	doc_582053207543_item	2746287	et	4	main
saa	doc_582053207543_item	2746295	et	4	main
inimene	doc_582053207543_item	2746300	et	3	main
meie	doc_582053207543_item	2746308	et	4	main
ei	doc_582053207543_item	2746314	et	4	main
ole	doc_582053207543_item	2746315	et	4	main
väga	doc_582053207543_item	2746323	et	3	main
mingit	doc_582053207543_item	2746336	et	3	main
või	doc_582053207543_item	2746338	et	4	main
ajakirju	doc_582053207543_item	2746339	et	4	main
ning	doc_582053207543_item	2746340	et	3	main
elada	doc_582053207543_item	2746348	et	3	main
autota	doc_582053207543_item	2746350	et	3	main
vaja	doc_582053207543_item	2746356	et	4	main
olla	doc_582053207543_item	2746357	et	3	main
mitmendates	doc_582053207543_item	2746358	et	3	main
kohtades	doc_582053207543_item	2746359	et	3	main
liiga	doc_582053207543_item	2746391	et	4	main
ei	doc_582053207544_item	2746404	et	4	main
saa	doc_582053207544_item	2746412	et	4	main
oli	doc_582053207544_item	2746424	et	3	main
haigused	doc_582053207544_item	2746430	et	4	main
rasked	doc_582053207544_item	2746431	et	3	main
üleelamised	doc_582053207544_item	2746432	et	4	main
minu	doc_582053207544_item	2746433	et	3	main
meeles	doc_582053207544_item	2746434	et	3	main
see	doc_582053207544_item	2746435	et	3	main
asi	doc_582053207544_item	2746439	et	4	main
ei	doc_582053207544_item	2746441	et	4	main
või	doc_582053207544_item	2746450	et	4	main
mille	doc_582053207544_item	2746451	et	3	main
vastu	doc_582053207544_item	2746452	et	3	main
olla	doc_582053207544_item	2746455	et	3	main
lill	doc_582053207544_item	2746457	et	3	main
oma	doc_582053207544_item	2746463	et	4	main
läheduses	doc_582053207544_item	2746467	et	4	main
on	doc_582053207544_item	2746481	et	4	main
peaks	doc_582053207544_item	2746527	et	4	main
on	doc_582053207544_item	2746530	et	4	main
meie	doc_582053207544_item	2746531	et	4	main
jaoks	doc_582053207544_item	2746534	et	4	main
kõik	doc_582053207544_item	2746537	et	4	main
misukused	doc_582053207544_item	2746538	et	4	main
me	doc_582053207544_item	2746539	et	4	main
ikka	doc_582053207544_item	2746542	et	4	main
armastavad	doc_582053207544_item	2746544	et	4	main
ainult	doc_582053207544_item	2746546	et	4	main
kellega	doc_582053207544_item	2746567	et	3	main
mittu	doc_582053207544_item	2746568	et	4	main
nende	doc_582053207544_item	2746575	et	4	main
ilma	doc_582053207545_item	2746577	et	4	main
milleta	doc_582053207545_item	2746578	et	3	main
ei	doc_582053207545_item	2746579	et	4	main
tänapäeval	doc_582053207545_item	2746589	et	3	main
elada	doc_582053207545_item	2746592	et	3	main
töökoht	doc_582053207545_item	2746604	et	3	main
ainult	doc_582053207545_item	2746605	et	4	main
hea	doc_582053207545_item	2746606	et	4	main
hea	doc_582053207545_item	2746611	et	4	main
põhipalk	doc_582053207545_item	2746613	et	3	main
oleneb	doc_582053207545_item	2746614	et	3	main
haridusest	doc_582053207545_item	2746616	et	4	main
ja	doc_582053207545_item	2746617	et	3	main
töökogemusest	doc_582053207545_item	2746618	et	4	main
eest	doc_582053207545_item	2746623	et	4	main
eest	doc_582053207545_item	2746626	et	4	main
tööandja	doc_582053207545_item	2746629	et	4	main
mobiiltelefoni	doc_582053207545_item	2746633	et	4	main
kulude	doc_582053207545_item	2746637	et	3	main
elada	doc_582053207545_item	2746642	et	3	main
head	doc_582053207545_item	2746648	et	4	main
kui	doc_582053207545_item	2746650	et	3	main
oma	doc_582053207545_item	2746654	et	4	main
jalutab	doc_582053207545_item	2746659	et	3	main
ta	doc_582053207545_item	2746664	et	4	main
kiiresti	doc_582053207543_item	2746311	et	3	main
infot	doc_582053207543_item	2746321	et	3	main
pole	doc_582053207543_item	2746329	et	3	main
minna	doc_582053207543_item	2746331	et	3	main
raamatukokku	doc_582053207543_item	2746333	et	4	main
otsida	doc_582053207543_item	2746335	et	4	main
aega	doc_582053207543_item	2746343	et	4	main
samuti	doc_582053207543_item	2746344	et	3	main
ei	doc_582053207543_item	2746345	et	4	main
korraga	doc_582053207543_item	2746360	et	4	main
aga	doc_582053207543_item	2746361	et	3	main
siiski	doc_582053207543_item	2746362	et	4	main
ning	doc_582053207543_item	2746384	et	3	main
palju	doc_582053207543_item	2746392	et	4	main
lähimad	doc_582053207543_item	2746396	et	4	main
lähevad	doc_582053207543_item	2746398	et	3	main
saa	doc_582053207544_item	2746405	et	4	main
elada	doc_582053207544_item	2746408	et	3	main
kõikidel	doc_582053207544_item	2746416	et	4	main
riigidel	doc_582053207544_item	2746419	et	4	main
kõige	doc_582053207544_item	2746420	et	4	main
ja	doc_582053207543_item	2746322	et	3	main
võib	doc_582053207543_item	2746325	et	3	main
interneti	doc_582053207543_item	2746327	et	4	main
raamatut	doc_582053207543_item	2746337	et	3	main
praktiliselt	doc_582053207543_item	2746347	et	4	main
sest	doc_582053207543_item	2746351	et	4	main
päeva	doc_582053207543_item	2746352	et	4	main
tänapäeval	doc_582053207543_item	2746365	et	3	main
inimene	doc_582053207543_item	2746366	et	3	main
ei	doc_582053207543_item	2746367	et	4	main
saa	doc_582053207543_item	2746368	et	4	main
elada	doc_582053207543_item	2746369	et	3	main
ilma	doc_582053207543_item	2746370	et	4	main
armastuseta	doc_582053207543_item	2746371	et	4	main
aeg	doc_582053207543_item	2746372	et	3	main
nii	doc_582053207543_item	2746373	et	3	main
kiiresti	doc_582053207543_item	2746374	et	3	main
lendab	doc_582053207543_item	2746375	et	3	main
et	doc_582053207543_item	2746376	et	3	main
me	doc_582053207543_item	2746377	et	4	main
ei	doc_582053207543_item	2746378	et	4	main
jõua	doc_582053207543_item	2746379	et	4	main
tihemini	doc_582053207543_item	2746380	et	4	main
kohtuma	doc_582053207543_item	2746381	et	3	main
oma	doc_582053207543_item	2746382	et	4	main
vanematega	doc_582053207543_item	2746383	et	4	main
tuttavatega	doc_582053207543_item	2746385	et	3	main
aega	doc_582053207543_item	2746393	et	4	main
ning	doc_582053207543_item	2746394	et	3	main
inimesed	doc_582053207543_item	2746397	et	3	main
ära	doc_582053207543_item	2746400	et	4	main
tänapäeval	doc_582053207544_item	2746407	et	3	main
inimene	doc_582053207544_item	2746413	et	3	main
elada	doc_582053207544_item	2746415	et	3	main
ajadel	doc_582053207544_item	2746417	et	4	main
inimeste	doc_582053207544_item	2746422	et	3	main
sõda	doc_582053207544_item	2746426	et	4	main
inimestele	doc_582053207544_item	2746428	et	3	main
tähtsam	doc_582053207544_item	2746438	et	4	main
elada	doc_582053207544_item	2746444	et	3	main
kõik	doc_582053207544_item	2746448	et	4	main
see	doc_582053207544_item	2746453	et	3	main
mis	doc_582053207544_item	2746461	et	4	main
voolab	doc_582053207544_item	2746462	et	3	main
vett	doc_582053207544_item	2746464	et	3	main
maja	doc_582053207544_item	2746466	et	4	main
muusika	doc_582053207544_item	2746468	et	4	main
lõdvestuda	doc_582053207544_item	2746479	et	4	main
ole	doc_582053207544_item	2746522	et	4	main
olema	doc_582053207544_item	2746528	et	4	main
selle	doc_582053207544_item	2746547	et	4	main
õppime	doc_582053207544_item	2746570	et	4	main
saa	doc_582053207545_item	2746580	et	4	main
tänapäeval	doc_582053207545_item	2746581	et	3	main
elada	doc_582053207545_item	2746582	et	3	main
elada	doc_582053207545_item	2746588	et	3	main
ei	doc_582053207545_item	2746594	et	4	main
ole	doc_582053207545_item	2746595	et	4	main
lomulikult	doc_582053207545_item	2746597	et	4	main
leida	doc_582053207545_item	2746610	et	3	main
tööandja	doc_582053207545_item	2746620	et	4	main
maksab	doc_582053207545_item	2746621	et	3	main
võib	doc_582053207545_item	2746630	et	3	main
eest	doc_582053207545_item	2746638	et	4	main
ei	doc_582053207545_item	2746640	et	4	main
ole	doc_582053207545_item	2746645	et	4	main
inimine	doc_582053207545_item	2746651	et	4	main
tegeleb	doc_582053207545_item	2746656	et	3	main
siis	doc_582053207545_item	2746663	et	3	main
parem	doc_582053207545_item	2746665	et	4	main
last	doc_582053207545_item	2746675	et	4	main
inimene	doc_582053207546_item	2746710	et	3	main
see	doc_582053207546_item	2746718	et	3	main
armastus	doc_582053207546_item	2746722	et	4	main
ja	doc_582053207546_item	2746726	et	3	main
kodu	doc_582053207546_item	2746728	et	4	main
on	doc_582053207546_item	2746731	et	4	main
jagame	doc_582053207546_item	2746739	et	3	main
ja	doc_582053207546_item	2746742	et	3	main
keda	doc_582053207546_item	2746747	et	4	main
ilma	doc_582053207546_item	2746757	et	4	main
olla	doc_582053207546_item	2746765	et	3	main
olla	doc_582053207546_item	2746770	et	3	main
saa	doc_582053207546_item	2746776	et	4	main
elada	doc_582053207546_item	2746777	et	3	main
ilma	doc_582053207546_item	2746778	et	4	main
päev	doc_582053207546_item	2746785	et	3	main
baaris	doc_582053207546_item	2746788	et	3	main
riietuda	doc_582053207546_item	2746793	et	3	main
selle	doc_582053207546_item	2746795	et	4	main
jaoks	doc_582053207546_item	2746796	et	4	main
palju	doc_582053207546_item	2746832	et	4	main
raha	doc_582053207546_item	2746843	et	4	main
aitavad	doc_582053207546_item	2746844	et	4	main
endast	doc_582053207546_item	2746854	et	4	main
rahu	doc_582053207544_item	2746425	et	4	main
kaotused	doc_582053207544_item	2746429	et	4	main
elus	doc_582053207544_item	2746440	et	4	main
saa	doc_582053207544_item	2746442	et	4	main
ilma	doc_582053207544_item	2746445	et	4	main
üks	doc_582053207544_item	2746447	et	3	main
kelle	doc_582053207544_item	2746449	et	4	main
või	doc_582053207544_item	2746459	et	4	main
sinu	doc_582053207544_item	2746465	et	3	main
sulle	doc_582053207544_item	2746472	et	3	main
tööks	doc_582053207544_item	2746474	et	3	main
see	doc_582053207544_item	2746480	et	3	main
päike	doc_582053207544_item	2746482	et	3	main
mida	doc_582053207544_item	2746483	et	4	main
meie	doc_582053207544_item	2746484	et	4	main
viimasel	doc_582053207544_item	2746485	et	3	main
ajal	doc_582053207544_item	2746486	et	4	main
nii	doc_582053207544_item	2746487	et	3	main
harva	doc_582053207544_item	2746488	et	4	main
näeme	doc_582053207544_item	2746489	et	3	main
inimesed	doc_582053207544_item	2746490	et	3	main
kellega	doc_582053207544_item	2746491	et	3	main
meil	doc_582053207544_item	2746492	et	4	main
on	doc_582053207544_item	2746493	et	4	main
hea	doc_582053207544_item	2746494	et	4	main
olla	doc_582053207544_item	2746495	et	3	main
kellega	doc_582053207544_item	2746496	et	3	main
võib	doc_582053207544_item	2746497	et	3	main
rääkida	doc_582053207544_item	2746498	et	3	main
kõikidest	doc_582053207544_item	2746499	et	4	main
asjadest	doc_582053207544_item	2746500	et	3	main
ja	doc_582053207544_item	2746501	et	3	main
kui	doc_582053207544_item	2746502	et	3	main
sull	doc_582053207544_item	2746503	et	4	main
on	doc_582053207544_item	2746504	et	4	main
raske	doc_582053207544_item	2746505	et	4	main
toetavad	doc_582053207544_item	2746506	et	4	main
sind	doc_582053207544_item	2746507	et	4	main
see	doc_582053207544_item	2746508	et	3	main
on	doc_582053207544_item	2746509	et	4	main
pere	doc_582053207544_item	2746510	et	4	main
liikmed	doc_582053207544_item	2746511	et	3	main
kellega	doc_582053207544_item	2746512	et	3	main
koos	doc_582053207544_item	2746513	et	4	main
jõgi	doc_582053207544_item	2746460	et	3	main
annab	doc_582053207544_item	2746471	et	3	main
õhtul	doc_582053207544_item	2746476	et	3	main
sulle	doc_582053207544_item	2746478	et	3	main
ei	doc_582053207544_item	2746521	et	4	main
tähelepanelikud	doc_582053207544_item	2746523	et	4	main
nende	doc_582053207544_item	2746524	et	4	main
vastu	doc_582053207544_item	2746525	et	3	main
kui	doc_582053207544_item	2746526	et	3	main
oleme	doc_582053207544_item	2746540	et	3	main
pärast	doc_582053207544_item	2746548	et	4	main
et	doc_582053207544_item	2746549	et	3	main
me	doc_582053207544_item	2746550	et	4	main
oleme	doc_582053207544_item	2746551	et	3	main
nende	doc_582053207544_item	2746552	et	4	main
lapsed	doc_582053207544_item	2746553	et	3	main
see	doc_582053207544_item	2746554	et	3	main
on	doc_582053207544_item	2746555	et	4	main
proovime	doc_582053207544_item	2746573	et	3	main
probleemed	doc_582053207544_item	2746576	et	4	main
ei	doc_582053207545_item	2746585	et	4	main
saa	doc_582053207545_item	2746586	et	4	main
ei	doc_582053207545_item	2746590	et	4	main
on	doc_582053207545_item	2746602	et	4	main
hea	doc_582053207545_item	2746603	et	4	main
annab	doc_582053207545_item	2746608	et	3	main
see	doc_582053207544_item	2746529	et	3	main
kelle	doc_582053207544_item	2746533	et	4	main
täiesti	doc_582053207544_item	2746535	et	3	main
aga	doc_582053207544_item	2746541	et	3	main
nad	doc_582053207544_item	2746543	et	3	main
meid	doc_582053207544_item	2746545	et	4	main
meie	doc_582053207544_item	2746556	et	4	main
lapsed	doc_582053207544_item	2746557	et	3	main
ja	doc_582053207544_item	2746558	et	3	main
lapse	doc_582053207544_item	2746559	et	4	main
lapsed	doc_582053207544_item	2746560	et	3	main
kellega	doc_582053207544_item	2746561	et	3	main
me	doc_582053207544_item	2746562	et	4	main
elame	doc_582053207544_item	2746563	et	3	main
uuesti	doc_582053207544_item	2746564	et	3	main
oma	doc_582053207544_item	2746565	et	4	main
nooruse	doc_582053207544_item	2746566	et	4	main
vanemad	doc_582053207544_item	2746532	et	4	main
üks	doc_582053207544_item	2746536	et	3	main
korda	doc_582053207544_item	2746569	et	4	main
lahenda	doc_582053207544_item	2746574	et	4	main
tänapäeval	doc_582053207545_item	2746587	et	3	main
kui	doc_582053207545_item	2746593	et	3	main
raha	doc_582053207545_item	2746596	et	4	main
raha	doc_582053207545_item	2746598	et	4	main
saab	doc_582053207545_item	2746599	et	3	main
teenida	doc_582053207545_item	2746600	et	3	main
kui	doc_582053207545_item	2746601	et	3	main
haridus	doc_582053207545_item	2746607	et	3	main
tööd	doc_582053207545_item	2746612	et	4	main
lisatasu	doc_582053207545_item	2746619	et	4	main
liisaks	doc_582053207545_item	2746627	et	4	main
auto	doc_582053207545_item	2746632	et	4	main
kaardi	doc_582053207545_item	2746635	et	4	main
saa	doc_582053207545_item	2746641	et	4	main
kui	doc_582053207545_item	2746643	et	3	main
pere	doc_582053207545_item	2746647	et	4	main
sõprad	doc_582053207545_item	2746649	et	4	main
hoolitseb	doc_582053207545_item	2746653	et	3	main
terviga	doc_582053207545_item	2746655	et	4	main
õhkub	doc_582053207545_item	2746660	et	3	main
õhkuga	doc_582053207545_item	2746662	et	4	main
ja	doc_582053207545_item	2746667	et	3	main
kus	doc_582053207545_item	2746671	et	3	main
kaks	doc_582053207545_item	2746673	et	3	main
arvan	doc_582053207546_item	2746707	et	3	main
paljude	doc_582053207546_item	2746715	et	3	main
kodus	doc_582053207546_item	2746736	et	4	main
ma	doc_582053207546_item	2746748	et	3	main
on	doc_582053207546_item	2746752	et	4	main
meie	doc_582053207546_item	2746754	et	4	main
tohi	doc_582053207546_item	2746760	et	4	main
elada	doc_582053207546_item	2746761	et	3	main
armastus	doc_582053207546_item	2746767	et	4	main
veel	doc_582053207546_item	2746772	et	4	main
iga	doc_582053207546_item	2746784	et	4	main
käivad	doc_582053207546_item	2746787	et	4	main
diskos	doc_582053207546_item	2746789	et	4	main
ebaõnnestumisi	doc_582053207546_item	2746833	et	3	main
üle	doc_582053207546_item	2746834	et	3	main
elada	doc_582053207546_item	2746835	et	3	main
inimene	doc_582053207546_item	2746857	et	3	main
olla	doc_582053207546_item	2746859	et	3	main
koolis	doc_582053207544_item	2746571	et	4	main
ja	doc_582053207544_item	2746572	et	3	main
ilma	doc_582053207545_item	2746583	et	4	main
milleta	doc_582053207545_item	2746584	et	3	main
sa	doc_582053207545_item	2746591	et	3	main
võimalust	doc_582053207545_item	2746609	et	3	main
kvalifikatsioonist	doc_582053207545_item	2746615	et	3	main
edukatöö	doc_582053207545_item	2746622	et	4	main
liisakormuse	doc_582053207545_item	2746625	et	4	main
palgale	doc_582053207545_item	2746628	et	3	main
ei	doc_582053207545_item	2746644	et	4	main
ise	doc_582053207545_item	2746652	et	4	main
spordiga	doc_582053207545_item	2746657	et	3	main
värske	doc_582053207545_item	2746661	et	4	main
töötada	doc_582053207545_item	2746666	et	3	main
pere	doc_582053207545_item	2746670	et	4	main
naine	doc_582053207545_item	2746676	et	3	main
ei	doc_582053207546_item	2746711	et	4	main
on	doc_582053207546_item	2746719	et	4	main
pere	doc_582053207546_item	2746720	et	4	main
teiseks	doc_582053207546_item	2746723	et	4	main
töökohata	doc_582053207546_item	2746727	et	4	main
ja	doc_582053207546_item	2746729	et	3	main
oluline	doc_582053207546_item	2746733	et	4	main
elus	doc_582053207546_item	2746735	et	4	main
oma	doc_582053207546_item	2746740	et	4	main
probleemidega	doc_582053207546_item	2746743	et	3	main
võin	doc_582053207546_item	2746749	et	3	main
armastatu	doc_582053207546_item	2746766	et	4	main
rahata	doc_582053207546_item	2746779	et	4	main
nad	doc_582053207546_item	2746786	et	3	main
peab	doc_582053207546_item	2746798	et	4	main
suurt	doc_582053207546_item	2746821	et	3	main
inimeste	doc_582053207546_item	2746823	et	3	main
kodus	doc_582053207546_item	2746836	et	4	main
on	doc_582053207546_item	2746837	et	4	main
lähedased	doc_582053207546_item	2746838	et	3	main
inimesed	doc_582053207546_item	2746839	et	3	main
hea	doc_582053207546_item	2746846	et	4	main
elada	doc_582053207546_item	2746847	et	3	main
aga	doc_582053207546_item	2746848	et	3	main
ma	doc_582053207546_item	2746849	et	3	main
mõtlen	doc_582053207546_item	2746850	et	3	main
et	doc_582053207546_item	2746851	et	3	main
kui	doc_582053207546_item	2746856	et	3	main
õnnelik	doc_582053207546_item	2746860	et	3	main
armastust	doc_582053207546_item	2746866	et	4	main
haridust	doc_582053207546_item	2746868	et	4	main
või	doc_582053207545_item	2746624	et	4	main
pakkuda	doc_582053207545_item	2746631	et	3	main
bensini	doc_582053207545_item	2746634	et	4	main
firmade	doc_582053207545_item	2746636	et	3	main
veel	doc_582053207545_item	2746639	et	4	main
tervis	doc_582053207545_item	2746646	et	3	main
palju	doc_582053207545_item	2746658	et	4	main
elada	doc_582053207545_item	2746668	et	3	main
on	doc_582053207545_item	2746672	et	4	main
kes	doc_582053207545_item	2746677	et	4	main
ei	doc_582053207545_item	2746678	et	4	main
tööta	doc_582053207545_item	2746679	et	4	main
mees	doc_582053207545_item	2746680	et	4	main
kes	doc_582053207545_item	2746681	et	4	main
töötab	doc_582053207545_item	2746682	et	3	main
ja	doc_582053207545_item	2746683	et	3	main
annab	doc_582053207545_item	2746684	et	3	main
oma	doc_582053207545_item	2746685	et	4	main
perele	doc_582053207545_item	2746686	et	3	main
pisavalt	doc_582053207545_item	2746687	et	4	main
kõva	doc_582053207545_item	2746688	et	4	main
pere	doc_582053207545_item	2746689	et	4	main
on	doc_582053207545_item	2746690	et	4	main
sõltub	doc_582053207545_item	2746691	et	3	main
milleta	doc_582053207546_item	2746693	et	3	main
ilma	doc_582053207546_item	2746692	et	4	main
ei	doc_582053207546_item	2746694	et	4	main
saa	doc_582053207546_item	2746695	et	4	main
inimene	doc_582053207546_item	2746696	et	3	main
tänapäeval	doc_582053207546_item	2746697	et	3	main
elada	doc_582053207546_item	2746698	et	3	main
ilma	doc_582053207546_item	2746699	et	4	main
milleta	doc_582053207546_item	2746700	et	3	main
ei	doc_582053207546_item	2746701	et	4	main
saa	doc_582053207546_item	2746702	et	4	main
inimene	doc_582053207546_item	2746703	et	3	main
tänapäeval	doc_582053207546_item	2746704	et	3	main
elada	doc_582053207546_item	2746705	et	3	main
ma	doc_582053207546_item	2746706	et	3	main
kõva	doc_582053207545_item	2746669	et	4	main
kolm	doc_582053207545_item	2746674	et	3	main
tänapäeval	doc_582053207546_item	2746709	et	3	main
saa	doc_582053207546_item	2746712	et	4	main
ilma	doc_582053207546_item	2746714	et	4	main
esiteks	doc_582053207546_item	2746717	et	3	main
ilma	doc_582053207546_item	2746724	et	4	main
pere	doc_582053207546_item	2746730	et	4	main
meie	doc_582053207546_item	2746734	et	4	main
me	doc_582053207546_item	2746737	et	4	main
kasvame	doc_582053207546_item	2746738	et	3	main
edudega	doc_582053207546_item	2746741	et	3	main
on	doc_582053207546_item	2746745	et	4	main
usaldada	doc_582053207546_item	2746750	et	3	main
elus	doc_582053207546_item	2746755	et	4	main
ka	doc_582053207546_item	2746756	et	3	main
armastuseta	doc_582053207546_item	2746758	et	4	main
ei	doc_582053207546_item	2746759	et	4	main
tahab	doc_582053207546_item	2746764	et	3	main
ei	doc_582053207546_item	2746775	et	4	main
ja	doc_582053207546_item	2746790	et	3	main
tahavad	doc_582053207546_item	2746791	et	3	main
ilusti	doc_582053207546_item	2746792	et	3	main
aga	doc_582053207546_item	2746794	et	3	main
olema	doc_582053207546_item	2746799	et	4	main
et	doc_582053207546_item	2746708	et	3	main
elada	doc_582053207546_item	2746713	et	3	main
asjadeta	doc_582053207546_item	2746716	et	3	main
ja	doc_582053207546_item	2746721	et	3	main
rahata	doc_582053207546_item	2746725	et	4	main
väga	doc_582053207546_item	2746732	et	3	main
peres	doc_582053207546_item	2746744	et	3	main
inimesed	doc_582053207546_item	2746746	et	3	main
armastus	doc_582053207546_item	2746751	et	4	main
oluline	doc_582053207546_item	2746753	et	4	main
iga	doc_582053207546_item	2746762	et	4	main
inimene	doc_582053207546_item	2746763	et	3	main
aitab	doc_582053207546_item	2746768	et	3	main
meil	doc_582053207546_item	2746769	et	4	main
õnnelik	doc_582053207546_item	2746771	et	3	main
palju	doc_582053207546_item	2746773	et	4	main
inimesi	doc_582053207546_item	2746774	et	4	main
sest	doc_582053207546_item	2746780	et	4	main
nad	doc_582053207546_item	2746781	et	3	main
tahavad	doc_582053207546_item	2746782	et	3	main
lõbutseda	doc_582053207546_item	2746783	et	3	main
nendel	doc_582053207546_item	2746797	et	4	main
kõrgemalt	doc_582053207546_item	2746800	et	4	main
tasustavat	doc_582053207546_item	2746801	et	4	main
töö	doc_582053207546_item	2746802	et	4	main
ja	doc_582053207546_item	2746803	et	3	main
kui	doc_582053207546_item	2746804	et	3	main
inimesel	doc_582053207546_item	2746805	et	3	main
ei	doc_582053207546_item	2746806	et	4	main
ole	doc_582053207546_item	2746807	et	4	main
haridust	doc_582053207546_item	2746808	et	4	main
siis	doc_582053207546_item	2746809	et	3	main
ta	doc_582053207546_item	2746810	et	4	main
ei	doc_582053207546_item	2746811	et	4	main
või	doc_582053207546_item	2746812	et	4	main
leida	doc_582053207546_item	2746813	et	3	main
töökohta	doc_582053207546_item	2746814	et	4	main
ja	doc_582053207546_item	2746815	et	3	main
me	doc_582053207546_item	2746816	et	4	main
näeme	doc_582053207546_item	2746817	et	3	main
et	doc_582053207546_item	2746818	et	3	main
haridus	doc_582053207546_item	2746819	et	3	main
mängib	doc_582053207546_item	2746820	et	3	main
rolli	doc_582053207546_item	2746822	et	4	main
kabr	doc_582053207546_item	2746825	et	4	main
kodu	doc_582053207546_item	2746830	et	4	main
aitab	doc_582053207546_item	2746831	et	3	main
me	doc_582053207546_item	2746841	et	4	main
armastame	doc_582053207546_item	2746842	et	3	main
kõik	doc_582053207546_item	2746852	et	4	main
sõltub	doc_582053207546_item	2746853	et	3	main
tahab	doc_582053207546_item	2746858	et	3	main
ta	doc_582053207546_item	2746862	et	4	main
kalliks	doc_582053207546_item	2746864	et	3	main
kodu	doc_582053207546_item	2746865	et	4	main
p	doc_582053207546_item	2746869	et	4	main
elus	doc_582053207546_item	2746824	et	4	main
inimene	doc_582053207546_item	2746826	et	3	main
sõltub	doc_582053207546_item	2746827	et	3	main
paljudest	doc_582053207546_item	2746828	et	3	main
asjadest	doc_582053207546_item	2746829	et	3	main
keda	doc_582053207546_item	2746840	et	4	main
meil	doc_582053207546_item	2746845	et	4	main
inimesest	doc_582053207546_item	2746855	et	3	main
siis	doc_582053207546_item	2746861	et	3	main
peab	doc_582053207546_item	2746863	et	4	main
ja	doc_582053207546_item	2746867	et	3	main
kiri	doc_584615399807_item	2750026	et	3	main
te	doc_584615399807_item	2750027	et	4	main
plaanite	doc_584615399807_item	2750028	et	3	main
kus	doc_584615399807_item	2750046	et	3	main
palju	doc_584615399807_item	2750049	et	4	main
maksab	doc_584615399807_item	2750051	et	3	main
sõna	doc_584615399807_item	2750060	et	4	main
tere	doc_584615399807_item	2750061	et	3	main
mulle	doc_584615399807_item	2750068	et	4	main
ja	doc_584615399807_item	2750081	et	3	main
moskva	doc_584615399807_item	2750089	et	4	main
seal	doc_584615399807_item	2750090	et	4	main
eestlasest	doc_584615399807_item	2750035	et	3	main
kirjutage	doc_584615399807_item	2750037	et	3	main
ja	doc_584615399807_item	2750039	et	3	main
te	doc_584615399807_item	2750041	et	4	main
reisite	doc_584615399807_item	2750045	et	3	main
ööbite	doc_584615399807_item	2750047	et	3	main
umbes	doc_584615399807_item	2750058	et	4	main
80	doc_584615399807_item	2750059	et	2	main
ma	doc_584615399807_item	2750072	et	3	main
puhkus	doc_584615399807_item	2750080	et	3	main
venemaale	doc_584615399807_item	2750084	et	4	main
leningradi	doc_584615399807_item	2750087	et	4	main
hakkan	doc_584615399807_item	2750105	et	3	main
sulle	doc_584615399807_item	2750122	et	3	main
kiri	doc_584615399808_item	2750127	et	3	main
vastake	doc_584615399808_item	2750132	et	3	main
kirjas	doc_584615399808_item	2750134	et	4	main
perekonnaseis	doc_584615399808_item	2750142	et	4	main
arvutioskus	doc_584615399808_item	2750146	et	3	main
millist	doc_584615399808_item	2750153	et	3	main
kui	doc_584615399808_item	2750156	et	3	main
soovite	doc_584615399808_item	2750159	et	3	main
töögraafik	doc_584615399808_item	2750161	et	3	main
toidukauplus	doc_584615399808_item	2750168	et	3	main
ja	doc_584615399808_item	2750179	et	3	main
sobivat	doc_584615399808_item	2750193	et	4	main
töögraafikut	doc_584615399808_item	2750194	et	3	main
kakuke	doc_584615399808_item	2750199	et	4	main
as	doc_584615399808_item	2750203	et	4	main
personalijuht	doc_584615399808_item	2750209	et	3	main
kiri	doc_584615399807_item	2750033	et	3	main
soovite	doc_584615399807_item	2750043	et	3	main
millega	doc_584615399807_item	2750044	et	3	main
kui	doc_584615399807_item	2750048	et	3	main
see	doc_584615399807_item	2750050	et	3	main
peatute	doc_584615399807_item	2750054	et	4	main
praegu	doc_584615399807_item	2750071	et	3	main
eesti	doc_584615399807_item	2750074	et	4	main
aga	doc_584615399807_item	2750076	et	3	main
on	doc_584615399807_item	2750079	et	4	main
tahaksin	doc_584615399807_item	2750085	et	3	main
ja	doc_584615399807_item	2750088	et	3	main
kirjutan	doc_584615399807_item	2750121	et	3	main
ametlik	doc_584615399808_item	2750126	et	3	main
lugege	doc_584615399808_item	2750128	et	3	main
kuulutus	doc_584615399808_item	2750130	et	4	main
autojuhiload	doc_584615399808_item	2750147	et	4	main
oma	doc_584615399808_item	2750151	et	4	main
suurt	doc_584615399808_item	2750157	et	3	main
töötasu	doc_584615399808_item	2750158	et	4	main
sobib	doc_584615399808_item	2750162	et	3	main
kahe	doc_584615399808_item	2750163	et	3	main
vene	doc_584615399808_item	2750180	et	4	main
head	doc_584615399808_item	2750183	et	4	main
suhtlemisoskust	doc_584615399808_item	2750184	et	3	main
kindlat	doc_584615399808_item	2750195	et	3	main
palka	doc_584615399808_item	2750196	et	4	main
lisainfo	doc_584615399808_item	2750197	et	4	main
mnt3	doc_584615399808_item	2750201	et	4	main
tallinn	doc_584615399808_item	2750202	et	4	main
kakuke	doc_584615399808_item	2750204	et	4	main
räägitakse	doc_584615399808_item	2750231	et	3	main
et	doc_584615399808_item	2750232	et	3	main
kauplusesse	doc_584615399808_item	2750240	et	4	main
koristajaid	doc_584615399808_item	2750245	et	4	main
venemaale	doc_584615399807_item	2750030	et	4	main
kirjutage	doc_584615399807_item	2750031	et	3	main
sellest	doc_584615399807_item	2750032	et	4	main
millal	doc_584615399807_item	2750038	et	3	main
kohtades	doc_584615399807_item	2750053	et	3	main
miks	doc_584615399807_item	2750066	et	4	main
sa	doc_584615399807_item	2750067	et	3	main
kirjuta	doc_584615399807_item	2750070	et	4	main
õpin	doc_584615399807_item	2750073	et	3	main
varsti	doc_584615399807_item	2750077	et	3	main
sõidan	doc_584615399807_item	2750083	et	3	main
külla	doc_584615399807_item	2750086	et	4	main
elavad	doc_584615399807_item	2750091	et	4	main
minu	doc_584615399807_item	2750092	et	3	main
sugulased	doc_584615399807_item	2750093	et	3	main
ja	doc_584615399807_item	2750094	et	3	main
sõbrad	doc_584615399807_item	2750095	et	3	main
ma	doc_584615399807_item	2750096	et	3	main
tahan	doc_584615399807_item	2750097	et	3	main
sõitma	doc_584615399807_item	2750098	et	3	main
20	doc_584615399807_item	2750099	et	2	main
ööbima	doc_584615399807_item	2750104	et	3	main
lõpetan	doc_584615399807_item	2750124	et	3	main
läbi	doc_584615399808_item	2750129	et	4	main
sellele	doc_584615399808_item	2750133	et	4	main
peab	doc_584615399808_item	2750135	et	4	main
olema	doc_584615399808_item	2750136	et	4	main
haridus	doc_584615399808_item	2750143	et	3	main
töökogemused	doc_584615399808_item	2750144	et	3	main
keelteoskus	doc_584615399808_item	2750145	et	3	main
ja	doc_584615399808_item	2750149	et	3	main
tööd	doc_584615399808_item	2750154	et	4	main
milline	doc_584615399808_item	2750160	et	3	main
kuu	doc_584615399808_item	2750164	et	4	main
pärast	doc_584615399808_item	2750165	et	4	main
kauplusesse	doc_584615399808_item	2750169	et	4	main
vajatakse	doc_584615399808_item	2750170	et	4	main
keele	doc_584615399808_item	2750181	et	4	main
oskust	doc_584615399808_item	2750182	et	3	main
tartu	doc_584615399808_item	2750200	et	4	main
kuulutust	doc_584615399808_item	2750229	et	4	main
kus	doc_584615399808_item	2750230	et	3	main
kuu	doc_584615399808_item	2750234	et	4	main
vajatakse	doc_584615399808_item	2750241	et	4	main
sellel	doc_584615399808_item	2750255	et	4	main
kuid	doc_584615399808_item	2750260	et	4	main
ma	doc_584615399808_item	2750263	et	3	main
lõppesin	doc_584615399808_item	2750284	et	3	main
ma	doc_584615399808_item	2750288	et	3	main
oskan	doc_584615399808_item	2750291	et	3	main
arvutit	doc_584615399808_item	2750293	et	3	main
ja	doc_584615399808_item	2750297	et	3	main
kohtuda	doc_584615399808_item	2750300	et	3	main
inimestega	doc_584615399808_item	2750302	et	3	main
tõsine	doc_584615399808_item	2750305	et	4	main
siiras	doc_584615399808_item	2750309	et	4	main
soovin	doc_584615399808_item	2750315	et	3	main
kahekümneni	doc_584615399808_item	2750323	et	4	main
väga	doc_584615399808_item	2750326	et	3	main
lugupidamisega	doc_584615399808_item	2750335	et	3	main
eesnimi	doc_584615399808_item	2750336	et	3	main
perekonnanimi	doc_584615399808_item	2750337	et	3	main
essee	doc_584615399809_item	2750338	et	4	main
on	doc_584615399809_item	2750343	et	4	main
valdamine	doc_584615399809_item	2750357	et	4	main
ja	doc_584615399809_item	2750369	et	3	main
eneseusku	doc_584615399809_item	2750390	et	4	main
ja	doc_584615399809_item	2750391	et	3	main
reisi	doc_584615399807_item	2750029	et	4	main
oma	doc_584615399807_item	2750034	et	4	main
sõbrale	doc_584615399807_item	2750036	et	3	main
kuhu	doc_584615399807_item	2750040	et	3	main
sõita	doc_584615399807_item	2750042	et	3	main
millistes	doc_584615399807_item	2750052	et	3	main
kirja	doc_584615399807_item	2750055	et	4	main
nõutav	doc_584615399807_item	2750056	et	4	main
pikkus	doc_584615399807_item	2750057	et	4	main
laine	doc_584615399807_item	2750062	et	4	main
kuidas	doc_584615399807_item	2750063	et	3	main
käsi	doc_584615399807_item	2750064	et	4	main
käib	doc_584615399807_item	2750065	et	3	main
ei	doc_584615399807_item	2750069	et	4	main
keelt	doc_584615399807_item	2750075	et	4	main
mul	doc_584615399807_item	2750078	et	3	main
ma	doc_584615399807_item	2750082	et	3	main
juunil	doc_584615399807_item	2750100	et	3	main
ostsin	doc_584615399807_item	2750101	et	3	main
juba	doc_584615399807_item	2750102	et	3	main
rongipiletit	doc_584615399807_item	2750103	et	3	main
sugulaste	doc_584615399807_item	2750106	et	4	main
sellega	doc_584615399807_item	2750108	et	3	main
hoian	doc_584615399807_item	2750109	et	3	main
juurs	doc_584615399807_item	2750107	et	4	main
raha	doc_584615399807_item	2750110	et	4	main
kokku	doc_584615399807_item	2750111	et	3	main
tahan	doc_584615399807_item	2750112	et	3	main
külastada	doc_584615399807_item	2750113	et	3	main
palju	doc_584615399807_item	2750114	et	4	main
huvitavaid	doc_584615399807_item	2750115	et	4	main
paika	doc_584615399807_item	2750116	et	4	main
kui	doc_584615399807_item	2750117	et	3	main
tulen	doc_584615399807_item	2750118	et	3	main
tagasi	doc_584615399807_item	2750119	et	3	main
siis	doc_584615399807_item	2750120	et	3	main
sellega	doc_584615399807_item	2750123	et	3	main
ja	doc_584615399808_item	2750131	et	3	main
kirjutage	doc_584615399808_item	2750150	et	3	main
avatakse	doc_584615399808_item	2750166	et	4	main
eesti	doc_584615399808_item	2750178	et	4	main
soovitav	doc_584615399808_item	2750185	et	4	main
teile	doc_584615399808_item	2750192	et	4	main
tartu	doc_584615399808_item	2750205	et	4	main
40233	doc_584615399808_item	2750217	et	2	main
345	doc_584615399808_item	2750222	et	2	main
lugesin	doc_584615399808_item	2750224	et	3	main
eesti	doc_584615399808_item	2750226	et	4	main
päevaleht	doc_584615399808_item	2750227	et	3	main
teie	doc_584615399808_item	2750228	et	4	main
kassapidajaid	doc_584615399808_item	2750243	et	3	main
töötada	doc_584615399808_item	2750249	et	3	main
aastal	doc_584615399808_item	2750256	et	3	main
ma	doc_584615399808_item	2750257	et	3	main
töötasin	doc_584615399808_item	2750264	et	3	main
ma	doc_584615399808_item	2750266	et	3	main
vene	doc_584615399808_item	2750269	et	4	main
ja	doc_584615399808_item	2750270	et	3	main
englise	doc_584615399808_item	2750271	et	4	main
keelt	doc_584615399808_item	2750272	et	4	main
oskan	doc_584615399808_item	2750273	et	3	main
kõnes	doc_584615399808_item	2750274	et	3	main
ja	doc_584615399808_item	2750275	et	3	main
eelmisel	doc_584615399808_item	2750281	et	3	main
seoses	doc_584615399808_item	2750286	et	4	main
armastan	doc_584615399808_item	2750295	et	3	main
eesnimi	doc_584615399807_item	2750125	et	3	main
umbes	doc_584615399808_item	2750137	et	4	main
60	doc_584615399808_item	2750138	et	2	main
sõna	doc_584615399808_item	2750139	et	4	main
tutvustage	doc_584615399808_item	2750140	et	3	main
ennast	doc_584615399808_item	2750141	et	4	main
hobid	doc_584615399808_item	2750148	et	3	main
soovidest	doc_584615399808_item	2750152	et	3	main
soovite	doc_584615399808_item	2750155	et	3	main
uus	doc_584615399808_item	2750167	et	3	main
müüjat	doc_584615399808_item	2750171	et	4	main
kassapidajaid	doc_584615399808_item	2750172	et	3	main
turvamehi	doc_584615399808_item	2750173	et	3	main
koristajaid	doc_584615399808_item	2750174	et	4	main
pakkijaid	doc_584615399808_item	2750175	et	4	main
kandidaatidelt	doc_584615399808_item	2750176	et	3	main
ootame	doc_584615399808_item	2750177	et	3	main
on	doc_584615399808_item	2750186	et	4	main
ka	doc_584615399808_item	2750187	et	3	main
arvutikasutamisoskus	doc_584615399808_item	2750188	et	3	main
pakume	doc_584615399808_item	2750189	et	3	main
mugavaid	doc_584615399808_item	2750190	et	3	main
töötingimusi	doc_584615399808_item	2750191	et	3	main
as	doc_584615399808_item	2750198	et	4	main
mnt	doc_584615399808_item	2750206	et	4	main
3	doc_584615399808_item	2750207	et	2	main
tallinn	doc_584615399808_item	2750208	et	4	main
härra	doc_584615399808_item	2750210	et	4	main
omand	doc_584615399808_item	2750211	et	3	main
eesnimi	doc_584615399808_item	2750212	et	3	main
perekonnanimi	doc_584615399808_item	2750213	et	3	main
kooli	doc_584615399808_item	2750214	et	4	main
5	doc_584615399808_item	2750215	et	2	main
11	doc_584615399808_item	2750216	et	2	main
tallinn	doc_584615399808_item	2750218	et	4	main
56	doc_584615399808_item	2750220	et	2	main
t	doc_584615399808_item	2750219	et	4	main
785	doc_584615399808_item	2750221	et	2	main
ajalehest	doc_584615399808_item	2750225	et	4	main
kahe	doc_584615399808_item	2750233	et	3	main
pärast	doc_584615399808_item	2750235	et	4	main
avatakse	doc_584615399808_item	2750236	et	4	main
uus	doc_584615399808_item	2750237	et	3	main
toidukauplus	doc_584615399808_item	2750238	et	3	main
ja	doc_584615399808_item	2750239	et	3	main
ma	doc_584615399808_item	2750247	et	3	main
müüjana	doc_584615399808_item	2750250	et	4	main
ei	doc_584615399808_item	2750252	et	4	main
abielus	doc_584615399808_item	2750254	et	4	main
suvel	doc_584615399808_item	2750262	et	3	main
kirjas	doc_584615399808_item	2750276	et	4	main
eesti	doc_584615399808_item	2750277	et	4	main
ja	doc_584615399808_item	2750278	et	3	main
vene	doc_584615399808_item	2750279	et	4	main
ma	doc_584615399808_item	2750283	et	3	main
arvutikursused	doc_584615399808_item	2750285	et	3	main
kasutada	doc_584615399808_item	2750292	et	3	main
inimest	doc_584615399808_item	2750296	et	3	main
olen	doc_584615399808_item	2750304	et	3	main
umbes	doc_584615399808_item	2750329	et	4	main
5	doc_584615399808_item	2750330	et	2	main
äide	doc_584615399809_item	2750340	et	4	main
tänapäeva	doc_584615399809_item	2750341	et	4	main
vaid	doc_584615399809_item	2750345	et	3	main
väitega	doc_584615399809_item	2750351	et	3	main
ma	doc_584615399809_item	2750353	et	3	main
edukas	doc_584615399809_item	2750360	et	4	main
avardunud	doc_584615399809_item	2750366	et	4	main
reisimis-	doc_584615399809_item	2750367	et	3	main
töötamis-	doc_584615399809_item	2750368	et	3	main
tõttu	doc_584615399809_item	2750371	et	4	main
vaja	doc_584615399809_item	2750375	et	4	main
ja	doc_584615399809_item	2750376	et	3	main
võimalik	doc_584615399809_item	2750377	et	3	main
ühiskonnas	doc_584615399809_item	2750381	et	4	main
keelte	doc_584615399809_item	2750383	et	3	main
tugevdab	doc_584615399809_item	2750388	et	3	main
inimese	doc_584615399809_item	2750395	et	4	main
avaldus	doc_584615399808_item	2750223	et	4	main
müüjat	doc_584615399808_item	2750242	et	4	main
turvamehi	doc_584615399808_item	2750244	et	3	main
pakkijaid	doc_584615399808_item	2750246	et	4	main
ma	doc_584615399808_item	2750251	et	3	main
ole	doc_584615399808_item	2750253	et	4	main
lõppesin	doc_584615399808_item	2750258	et	3	main
toidukaupluses	doc_584615399808_item	2750265	et	3	main
oskan	doc_584615399808_item	2750267	et	3	main
keelt	doc_584615399808_item	2750280	et	4	main
sellega	doc_584615399808_item	2750287	et	3	main
hästi	doc_584615399808_item	2750290	et	3	main
mulle	doc_584615399808_item	2750298	et	4	main
tugev	doc_584615399808_item	2750307	et	4	main
ametikohal	doc_584615399808_item	2750317	et	4	main
töötada	doc_584615399808_item	2750318	et	3	main
igas	doc_584615399808_item	2750319	et	3	main
päevas	doc_584615399808_item	2750320	et	3	main
kaheksast	doc_584615399808_item	2750321	et	4	main
ma	doc_584615399808_item	2750324	et	3	main
hea	doc_584615399808_item	2750327	et	4	main
töötasu	doc_584615399808_item	2750328	et	4	main
v	doc_584615399809_item	2750339	et	4	main
kes	doc_584615399809_item	2750347	et	4	main
võõrkeeli	doc_584615399809_item	2750349	et	3	main
olen	doc_584615399809_item	2750352	et	3	main
ei	doc_584615399809_item	2750358	et	4	main
kuid	doc_584615399809_item	2750361	et	4	main
hulga	doc_584615399809_item	2750364	et	4	main
suhtlemisvõimaluste	doc_584615399809_item	2750370	et	3	main
on	doc_584615399809_item	2750372	et	4	main
kõigil	doc_584615399809_item	2750373	et	4	main
inimestel	doc_584615399809_item	2750374	et	3	main
tänapäeva	doc_584615399809_item	2750380	et	4	main
valdamine	doc_584615399809_item	2750384	et	4	main
loob	doc_584615399809_item	2750385	et	3	main
tingimused	doc_584615399809_item	2750386	et	3	main
koostööks	doc_584615399809_item	2750387	et	3	main
inimese	doc_584615399809_item	2750389	et	4	main
internet	doc_584615399809_item	2750423	et	4	main
see	doc_584615399809_item	2750430	et	3	main
auto	doc_584615399809_item	2750443	et	4	main
millega	doc_584615399809_item	2750444	et	3	main
uhkustada	doc_584615399809_item	2750445	et	3	main
teine	doc_584615399809_item	2750446	et	3	main
edukas	doc_584615399809_item	2750467	et	4	main
inimene	doc_584615399809_item	2750468	et	3	main
teab	doc_584615399809_item	2750469	et	3	main
mida	doc_584615399809_item	2750470	et	4	main
tahab	doc_584615399809_item	2750471	et	3	main
ja	doc_584615399809_item	2750472	et	3	main
kuidas	doc_584615399809_item	2750473	et	3	main
seda	doc_584615399809_item	2750474	et	3	main
saavutada	doc_584615399809_item	2750475	et	3	main
minemata	doc_584615399809_item	2750476	et	4	main
võtta	doc_584615399809_item	2750487	et	3	main
õppetundi	doc_584615399809_item	2750489	et	4	main
mina	doc_584615399809_item	2750497	et	4	main
omandamine	doc_584615399809_item	2750501	et	4	main
tohiks	doc_584615399809_item	2750503	et	3	main
soovin	doc_584615399808_item	2750248	et	3	main
keskkooli	doc_584615399808_item	2750259	et	4	main
igal	doc_584615399808_item	2750261	et	3	main
eesti	doc_584615399808_item	2750268	et	4	main
aastal	doc_584615399808_item	2750282	et	3	main
väga	doc_584615399808_item	2750289	et	3	main
ma	doc_584615399808_item	2750294	et	3	main
erinevate	doc_584615399808_item	2750301	et	4	main
ma	doc_584615399808_item	2750303	et	3	main
ja	doc_584615399808_item	2750306	et	3	main
ja	doc_584615399808_item	2750310	et	3	main
inimene	doc_584615399808_item	2750312	et	3	main
ma	doc_584615399808_item	2750313	et	3	main
väga	doc_584615399808_item	2750314	et	3	main
kuni	doc_584615399808_item	2750322	et	3	main
soovin	doc_584615399808_item	2750325	et	3	main
ette	doc_584615399808_item	2750333	et	4	main
tänades	doc_584615399808_item	2750334	et	3	main
ühiskonnas	doc_584615399809_item	2750342	et	4	main
see	doc_584615399809_item	2750346	et	3	main
selle	doc_584615399809_item	2750350	et	4	main
osaliselt	doc_584615399809_item	2750354	et	4	main
nõus	doc_584615399809_item	2750355	et	4	main
keelte	doc_584615399809_item	2750356	et	3	main
tee	doc_584615399809_item	2750359	et	4	main
loob	doc_584615399809_item	2750362	et	3	main
selleks	doc_584615399809_item	2750363	et	4	main
kasutada	doc_584615399809_item	2750378	et	3	main
erinevate	doc_584615399809_item	2750382	et	4	main
võimaldab	doc_584615399809_item	2750394	et	3	main
kirjandus	doc_584615399809_item	2750422	et	3	main
teisest	doc_584615399809_item	2750424	et	4	main
inimene	doc_584615399809_item	2750429	et	3	main
sõltub	doc_584615399809_item	2750431	et	3	main
on	doc_584615399809_item	2750438	et	4	main
endale	doc_584615399809_item	2750448	et	4	main
korralikku	doc_584615399809_item	2750450	et	4	main
kodu	doc_584615399809_item	2750451	et	4	main
edukas	doc_584615399809_item	2750455	et	4	main
läbi	doc_584615399809_item	2750466	et	4	main
vastuollu	doc_584615399809_item	2750477	et	4	main
ja	doc_584615399809_item	2750485	et	3	main
ebaõnnestumise	doc_584615399809_item	2750493	et	3	main
arvan	doc_584615399809_item	2750498	et	3	main
s	doc_584615399811_item	2750703	et	4	main
on	doc_584615399811_item	2750705	et	4	main
sisseastumise	doc_584615399811_item	2750708	et	3	main
kuidas	doc_584615399811_item	2750711	et	3	main
varem	doc_584615399811_item	2750713	et	4	main
varem	doc_584615399811_item	2750715	et	4	main
ma	doc_584615399811_item	2750716	et	3	main
õppisin	doc_584615399811_item	2750717	et	3	main
mitte	doc_584615399811_item	2750718	et	3	main
nagu	doc_584615399811_item	2750721	et	3	main
sest	doc_584615399811_item	2750723	et	4	main
ei	doc_584615399811_item	2750725	et	4	main
meeldib	doc_584615399808_item	2750299	et	3	main
isiksus	doc_584615399808_item	2750308	et	3	main
lõbus	doc_584615399808_item	2750311	et	4	main
sellel	doc_584615399808_item	2750316	et	4	main
000	doc_584615399808_item	2750331	et	2	main
kr	doc_584615399808_item	2750332	et	4	main
edukas	doc_584615399809_item	2750344	et	4	main
valdab	doc_584615399809_item	2750348	et	3	main
eeldusi	doc_584615399809_item	2750365	et	4	main
võõrkeeli	doc_584615399809_item	2750379	et	3	main
keelekeskkonnas	doc_584615399809_item	2750397	et	3	main
iseseisvalt	doc_584615399809_item	2750398	et	4	main
toimida	doc_584615399809_item	2750399	et	3	main
võõrkeelte	doc_584615399809_item	2750400	et	3	main
abil	doc_584615399809_item	2750401	et	4	main
on	doc_584615399809_item	2750402	et	4	main
võimalik	doc_584615399809_item	2750403	et	3	main
hankida	doc_584615399809_item	2750404	et	3	main
informatsioone	doc_584615399809_item	2750405	et	3	main
mis	doc_584615399809_item	2750406	et	4	main
pole	doc_584615399809_item	2750407	et	3	main
emakeeles	doc_584615399809_item	2750408	et	4	main
kättesaadav	doc_584615399809_item	2750409	et	4	main
võõrkeele	doc_584615399809_item	2750410	et	4	main
omandamisega	doc_584615399809_item	2750411	et	4	main
saab	doc_584615399809_item	2750412	et	3	main
inimene	doc_584615399809_item	2750413	et	3	main
täiendava	doc_584615399809_item	2750414	et	4	main
juurdepääsu	doc_584615399809_item	2750415	et	4	main
erinevatele	doc_584615399809_item	2750416	et	4	main
teadmiste	doc_584615399809_item	2750417	et	4	main
allikatele	doc_584615399809_item	2750418	et	4	main
näiteks	doc_584615399809_item	2750419	et	4	main
teatmeteosed	doc_584615399809_item	2750420	et	3	main
võõrkeelne	doc_584615399809_item	2750421	et	3	main
on	doc_584615399809_item	2750427	et	4	main
edukas	doc_584615399809_item	2750428	et	4	main
sellest	doc_584615399809_item	2750432	et	4	main
millised	doc_584615399809_item	2750433	et	3	main
on	doc_584615399809_item	2750434	et	4	main
suur	doc_584615399809_item	2750440	et	3	main
ja	doc_584615399809_item	2750441	et	3	main
tahab	doc_584615399809_item	2750447	et	3	main
ilusat	doc_584615399809_item	2750449	et	3	main
minu	doc_584615399809_item	2750452	et	3	main
rahul	doc_584615399809_item	2750460	et	4	main
ja	doc_584615399809_item	2750461	et	3	main
tunneb	doc_584615399809_item	2750462	et	3	main
et	doc_584615399809_item	2750463	et	3	main
lööb	doc_584615399809_item	2750464	et	3	main
oma	doc_584615399809_item	2750483	et	4	main
vigu	doc_584615399809_item	2750484	et	3	main
lähe	doc_584615399809_item	2750491	et	4	main
et	doc_584615399809_item	2750499	et	3	main
kindlustunnet	doc_584615399809_item	2750392	et	3	main
võõrkeeleoskus	doc_584615399809_item	2750393	et	3	main
teises	doc_584615399809_item	2750396	et	4	main
küljest	doc_584615399809_item	2750425	et	4	main
kes	doc_584615399809_item	2750426	et	4	main
inimene	doc_584615399809_item	2750435	et	3	main
eluväärtused	doc_584615399809_item	2750436	et	3	main
uhke	doc_584615399809_item	2750442	et	4	main
on	doc_584615399809_item	2750454	et	4	main
see	doc_584615399809_item	2750456	et	3	main
elus	doc_584615399809_item	2750465	et	4	main
iseenda	doc_584615399809_item	2750478	et	3	main
ja	doc_584615399809_item	2750479	et	3	main
äpardusi	doc_584615399809_item	2750486	et	4	main
kui	doc_584615399809_item	2750488	et	3	main
ega	doc_584615399809_item	2750490	et	3	main
iga	doc_584615399809_item	2750492	et	4	main
endast	doc_584615399809_item	2750495	et	4	main
välja	doc_584615399809_item	2750496	et	4	main
ühel	doc_584615399809_item	2750437	et	3	main
eesmärgiks	doc_584615399809_item	2750439	et	3	main
arvates	doc_584615399809_item	2750453	et	4	main
kes	doc_584615399809_item	2750457	et	4	main
on	doc_584615399809_item	2750458	et	4	main
endaga	doc_584615399809_item	2750459	et	4	main
teistega	doc_584615399809_item	2750480	et	4	main
ta	doc_584615399809_item	2750481	et	4	main
oskab	doc_584615399809_item	2750482	et	3	main
pärast	doc_584615399809_item	2750494	et	4	main
võõrkeelte	doc_584615399809_item	2750500	et	3	main
ei	doc_584615399809_item	2750502	et	4	main
muutuda	doc_584615399809_item	2750504	et	3	main
eesmärgiks	doc_584615399809_item	2750505	et	3	main
vaid	doc_584615399809_item	2750506	et	3	main
jääma	doc_584615399809_item	2750507	et	4	main
abivahendiks	doc_584615399809_item	2750508	et	3	main
elueesmärgi	doc_584615399809_item	2750509	et	4	main
saavutamisel	doc_584615399809_item	2750510	et	4	main
õpid	doc_584615399811_item	2750692	et	4	main
nendes	doc_584615399811_item	2750700	et	4	main
mis	doc_584615399811_item	2750704	et	4	main
vajalikud	doc_584615399811_item	2750706	et	3	main
3	doc_584615399811_item	2750710	et	2	main
1	doc_584615399811_item	2750668	et	2	main
miks	doc_584615399811_item	2750669	et	4	main
ma	doc_584615399811_item	2750670	et	3	main
tahan	doc_584615399811_item	2750671	et	3	main
õppida	doc_584615399811_item	2750672	et	3	main
ma	doc_584615399811_item	2750673	et	3	main
tahan	doc_584615399811_item	2750674	et	3	main
õppida	doc_584615399811_item	2750675	et	3	main
et	doc_584615399811_item	2750676	et	3	main
saada	doc_584615399811_item	2750677	et	4	main
edukaks	doc_584615399811_item	2750678	et	3	main
ja	doc_584615399811_item	2750679	et	3	main
isesesvuslikuks	doc_584615399811_item	2750680	et	4	main
inimeseks	doc_584615399811_item	2750681	et	3	main
saada	doc_584615399811_item	2750682	et	4	main
head	doc_584615399811_item	2750683	et	4	main
tööd	doc_584615399811_item	2750684	et	4	main
ja	doc_584615399811_item	2750685	et	3	main
suhelda	doc_584615399811_item	2750686	et	4	main
huvitavate	doc_584615399811_item	2750687	et	4	main
inimestega	doc_584615399811_item	2750688	et	3	main
2	doc_584615399811_item	2750689	et	2	main
kuidas	doc_584615399811_item	2750690	et	3	main
sa	doc_584615399811_item	2750691	et	3	main
vastus	doc_584615399811_item	2750666	et	3	main
praegu	doc_584615399811_item	2750693	et	3	main
ma	doc_584615399811_item	2750695	et	3	main
üsna	doc_584615399811_item	2750697	et	3	main
eriti	doc_584615399811_item	2750699	et	3	main
õppeala	doc_584615399811_item	2750701	et	4	main
de	doc_584615399811_item	2750702	et	4	main
sa	doc_584615399811_item	2750712	et	3	main
ma	doc_584615399811_item	2750724	et	3	main
õppimine	doc_584615399811_item	2750730	et	4	main
jaoks	doc_584615399811_item	2750738	et	4	main
õppetöös	doc_584615399811_item	2750745	et	3	main
arvates	doc_584615399811_item	2750747	et	4	main
õppe-	doc_584615399811_item	2750764	et	4	main
vajalikut	doc_584615399811_item	2750769	et	4	main
tööd	doc_584615399811_item	2750770	et	4	main
ja	doc_584615399811_item	2750771	et	3	main
materiaali	doc_584615399811_item	2750777	et	4	main
missugused	doc_584615399811_item	2750789	et	3	main
jaoks	doc_584615399811_item	2750793	et	4	main
kooli	doc_584615399811_item	2750801	et	4	main
saada	doc_584615399811_item	2750802	et	4	main
kõrged	doc_584615399811_item	2750803	et	3	main
ise	doc_584615399811_item	2750813	et	4	main
on	doc_584615399811_item	2750827	et	4	main
minu	doc_584615399811_item	2750831	et	3	main
see	doc_584615399811_item	2750841	et	3	main
8	doc_584615399811_item	2750844	et	2	main
näed	doc_584615399811_item	2750847	et	3	main
tulevikus	doc_584615399811_item	2750854	et	4	main
ei	doc_584615399811_item	2750864	et	4	main
ma	doc_596017998605_item	2750871	et	3	main
õpinsest	doc_596017998605_item	2750872	et	4	main
keskhariduse	doc_596017998605_item	2750874	et	3	main
ülikooli	doc_596017998605_item	2750878	et	4	main
lõpetamist	doc_596017998605_item	2750882	et	4	main
siin	doc_596017998605_item	2750921	et	4	main
parem	doc_596017998605_item	2750923	et	4	main
rahulikult	doc_596017998605_item	2750928	et	4	main
edasi	doc_596017998605_item	2750934	et	3	main
ainult	doc_596017998605_item	2750940	et	4	main
missuguses	doc_596017998605_item	2750941	et	3	main
missuguses	doc_596017998605_item	2750944	et	3	main
aidata	doc_596017998605_item	2750959	et	4	main
6kas	doc_596017998605_item	2750962	et	3	main
istuvad	doc_596017998605_item	2750975	et	4	main
taga	doc_596017998605_item	2750977	et	4	main
ja	doc_596017998605_item	2750978	et	3	main
neid	doc_596017998605_item	2750979	et	4	main
baarides	doc_596017998605_item	2750984	et	3	main
ja	doc_596017998605_item	2750987	et	3	main
ei	doc_596017998605_item	2750989	et	4	main
ma	doc_596017998606_item	2750996	et	3	main
1	doc_596017998606_item	2750999	et	2	main
ilma	doc_596017998606_item	2751002	et	4	main
ei	doc_596017998606_item	2751004	et	4	main
praegu	doc_596017998606_item	2751016	et	3	main
minu	doc_596017998606_item	2751022	et	3	main
märksalt	doc_596017998606_item	2751025	et	4	main
mina	doc_596017998606_item	2751029	et	4	main
pärssis	doc_596017998606_item	2751041	et	3	main
sa	doc_596017998606_item	2751046	et	3	main
3	doc_596017998606_item	2751049	et	2	main
hinded	doc_596017998606_item	2751059	et	3	main
olid	doc_596017998606_item	2751061	et	4	main
ei	doc_596017998606_item	2751079	et	4	main
ole	doc_596017998606_item	2751080	et	4	main
asi	doc_596017998606_item	2751084	et	4	main
on	doc_596017998606_item	2751085	et	4	main
ja	doc_596017998606_item	2751087	et	3	main
õppida	doc_596017998606_item	2751089	et	3	main
kohendada	doc_596017998606_item	2751094	et	3	main
küsimusele	doc_584615399811_item	2750667	et	4	main
minu	doc_584615399811_item	2750707	et	3	main
jaoks	doc_584615399811_item	2750709	et	4	main
hästi	doc_584615399811_item	2750720	et	3	main
on	doc_584615399811_item	2750731	et	4	main
4	doc_584615399811_item	2750739	et	2	main
on	doc_584615399811_item	2750748	et	4	main
veel	doc_584615399811_item	2750772	et	4	main
saada	doc_584615399811_item	2750776	et	4	main
saada	doc_584615399811_item	2750779	et	4	main
teada	doc_584615399811_item	2750780	et	3	main
kui	doc_584615399811_item	2750781	et	3	main
edukaks	doc_584615399811_item	2750787	et	3	main
püstitasin	doc_584615399811_item	2750796	et	3	main
enda	doc_584615399811_item	2750797	et	4	main
hästi	doc_584615399811_item	2750799	et	3	main
lõpetada	doc_584615399811_item	2750800	et	3	main
kuhu	doc_584615399811_item	2750811	et	3	main
õppetööd	doc_584615399811_item	2750821	et	4	main
püüdlikus	doc_584615399811_item	2750825	et	4	main
see	doc_584615399811_item	2750826	et	3	main
mulle	doc_584615399811_item	2750837	et	4	main
mõnikord	doc_584615399811_item	2750838	et	3	main
oma	doc_584615399811_item	2750848	et	4	main
et	doc_584615399811_item	2750853	et	3	main
õpin	doc_584615399811_item	2750856	et	3	main
mis	doc_584615399811_item	2750859	et	4	main
juhtub	doc_584615399811_item	2750860	et	3	main
pärast	doc_584615399811_item	2750861	et	4	main
küsimusele	doc_596017998605_item	2750867	et	4	main
1miks	doc_596017998605_item	2750868	et	4	main
pärast	doc_596017998605_item	2750877	et	4	main
lõpetadaaga	doc_596017998605_item	2750879	et	4	main
pärast	doc_596017998605_item	2750880	et	4	main
see	doc_596017998605_item	2750916	et	3	main
minu	doc_596017998605_item	2750918	et	3	main
praegu	doc_584615399811_item	2750694	et	3	main
õpin	doc_584615399811_item	2750696	et	3	main
hästi	doc_584615399811_item	2750698	et	3	main
õppisid	doc_584615399811_item	2750714	et	4	main
eriti	doc_584615399811_item	2750719	et	3	main
praegu	doc_584615399811_item	2750722	et	3	main
on	doc_584615399811_item	2750741	et	4	main
sinu	doc_584615399811_item	2750743	et	3	main
õppetöös	doc_584615399811_item	2750750	et	3	main
ja	doc_584615399811_item	2750752	et	3	main
usk	doc_584615399811_item	2750753	et	3	main
alati	doc_584615399811_item	2750767	et	4	main
saada	doc_584615399811_item	2750786	et	4	main
enda	doc_584615399811_item	2750792	et	4	main
ma	doc_584615399811_item	2750795	et	3	main
jaoks	doc_584615399811_item	2750798	et	4	main
ja	doc_584615399811_item	2750806	et	3	main
sisse	doc_584615399811_item	2750807	et	4	main
astuda	doc_584615399811_item	2750808	et	3	main
see	doc_584615399811_item	2750809	et	3	main
ma	doc_584615399811_item	2750812	et	3	main
7	doc_584615399811_item	2750815	et	2	main
mõjutab	doc_584615399811_item	2750817	et	3	main
õppetööd	doc_584615399811_item	2750819	et	4	main
minu	doc_584615399811_item	2750820	et	3	main
positiivne	doc_584615399811_item	2750828	et	3	main
aga	doc_584615399811_item	2750829	et	3	main
ka	doc_584615399811_item	2750830	et	3	main
koduneülesandeid	doc_584615399811_item	2750839	et	4	main
teha	doc_584615399811_item	2750840	et	3	main
ma	doc_584615399811_item	2750851	et	3	main
ma	doc_584615399811_item	2750862	et	3	main
nüüd	doc_584615399811_item	2750863	et	4	main
ma	doc_596017998605_item	2750869	et	3	main
saada	doc_596017998605_item	2750875	et	4	main
ülikooli	doc_596017998605_item	2750881	et	4	main
on	doc_596017998605_item	2750927	et	4	main
kui	doc_596017998605_item	2750930	et	3	main
4kus	doc_596017998605_item	2750932	et	3	main
omandada	doc_596017998605_item	2750952	et	3	main
head	doc_596017998605_item	2750955	et	4	main
eestil	doc_596017998605_item	2750960	et	3	main
areneda	doc_596017998605_item	2750961	et	3	main
midagikäivad	doc_596017998605_item	2750983	et	3	main
diskool	doc_596017998605_item	2750986	et	4	main
nad	doc_596017998605_item	2750988	et	3	main
saa	doc_596017998605_item	2750990	et	4	main
vastus	doc_596017998606_item	2750992	et	3	main
miks	doc_596017998606_item	2750995	et	4	main
et	doc_596017998606_item	2751001	et	3	main
oskagi	doc_596017998606_item	2751005	et	4	main
elada	doc_596017998606_item	2751006	et	3	main
nii	doc_596017998606_item	2751007	et	3	main
nagu	doc_596017998606_item	2751008	et	3	main
tahan	doc_596017998606_item	2751009	et	3	main
ja	doc_596017998606_item	2751010	et	3	main
õpid	doc_596017998606_item	2751015	et	4	main
hakkasin	doc_596017998606_item	2751028	et	3	main
rohkem	doc_596017998606_item	2751031	et	4	main
või	doc_596017998606_item	2751042	et	4	main
õppisid	doc_596017998606_item	2751048	et	4	main
noormatselt	doc_596017998606_item	2751050	et	4	main
aga	doc_596017998606_item	2751051	et	3	main
silmaring	doc_596017998606_item	2751052	et	3	main
ei	doc_596017998606_item	2751053	et	4	main
täna	doc_596017998606_item	2751058	et	4	main
eruditsiooni	doc_596017998606_item	2751075	et	4	main
laiendamine	doc_596017998606_item	2751076	et	4	main
tulemused	doc_596017998606_item	2751077	et	3	main
aga	doc_596017998606_item	2751078	et	3	main
peamine	doc_596017998606_item	2751083	et	3	main
midagi	doc_596017998606_item	2751092	et	4	main
5	doc_596017998606_item	2751095	et	2	main
mitte	doc_596017998606_item	2751121	et	3	main
teiseks	doc_596017998606_item	2751134	et	4	main
kolmandaks	doc_596017998606_item	2751138	et	4	main
8	doc_596017998606_item	2751165	et	2	main
sõltub	doc_596017998606_item	2751167	et	3	main
sooritamisest	doc_596017998606_item	2751170	et	4	main
p	doc_596182270457_item	2751201	et	4	main
robinsons	doc_596182270457_item	2751204	et	4	main
2	doc_596182270457_item	2751207	et	2	main
aru	doc_584615399811_item	2750728	et	4	main
et	doc_584615399811_item	2750729	et	3	main
õpetajate	doc_584615399811_item	2750737	et	4	main
peamine	doc_584615399811_item	2750742	et	3	main
jaoks	doc_584615399811_item	2750744	et	4	main
võimalikusse	doc_584615399811_item	2750755	et	4	main
5	doc_584615399811_item	2750756	et	2	main
missugused	doc_584615399811_item	2750757	et	3	main
oma	doc_584615399811_item	2750754	et	4	main
on	doc_584615399811_item	2750758	et	4	main
sinu	doc_584615399811_item	2750759	et	3	main
peamised	doc_584615399811_item	2750760	et	3	main
õppe-eesmärgid	doc_584615399811_item	2750761	et	3	main
minu	doc_584615399811_item	2750762	et	3	main
peamised	doc_584615399811_item	2750763	et	3	main
saanud	doc_584615399811_item	2750726	et	4	main
häasti	doc_584615399811_item	2750727	et	4	main
vaja	doc_584615399811_item	2750732	et	4	main
minu	doc_584615399811_item	2750733	et	3	main
jaoks	doc_584615399811_item	2750734	et	4	main
aga	doc_584615399811_item	2750735	et	3	main
mitte	doc_584615399811_item	2750736	et	3	main
mis	doc_584615399811_item	2750740	et	4	main
minu	doc_584615399811_item	2750746	et	3	main
peamine	doc_584615399811_item	2750749	et	3	main
püüdlikus	doc_584615399811_item	2750751	et	4	main
eesmärgid	doc_584615399811_item	2750765	et	3	main
rohkem	doc_584615399811_item	2750773	et	4	main
et	doc_584615399811_item	2750774	et	3	main
rohkem	doc_584615399811_item	2750784	et	4	main
et	doc_584615399811_item	2750785	et	3	main
ülesanded	doc_584615399811_item	2750790	et	3	main
püstisasid	doc_584615399811_item	2750794	et	4	main
tahan	doc_584615399811_item	2750814	et	3	main
sinu	doc_584615399811_item	2750818	et	3	main
on	doc_584615399811_item	2750766	et	4	main
teha	doc_584615399811_item	2750768	et	3	main
aru	doc_584615399811_item	2750775	et	4	main
paremini	doc_584615399811_item	2750778	et	4	main
on	doc_584615399811_item	2750782	et	4	main
võimalik	doc_584615399811_item	2750783	et	3	main
6	doc_584615399811_item	2750788	et	2	main
sa	doc_584615399811_item	2750791	et	3	main
hinned	doc_584615399811_item	2750804	et	4	main
eksamidel	doc_584615399811_item	2750805	et	4	main
kõrgkooli	doc_584615399811_item	2750810	et	4	main
mis	doc_584615399811_item	2750816	et	4	main
mõjutavad	doc_584615399811_item	2750822	et	4	main
minu	doc_584615399811_item	2750823	et	3	main
vanemate	doc_584615399811_item	2750832	et	4	main
suhted	doc_584615399811_item	2750833	et	3	main
sest	doc_584615399811_item	2750834	et	4	main
nad	doc_584615399811_item	2750835	et	3	main
segavad	doc_584615399811_item	2750836	et	4	main
sa	doc_584615399811_item	2750846	et	3	main
tulevikus	doc_584615399811_item	2750850	et	4	main
kõrgkoolis	doc_584615399811_item	2750857	et	4	main
õpin	doc_596017998605_item	2750870	et	3	main
ja	doc_596017998605_item	2750876	et	3	main
töötadasest	doc_596017998605_item	2750915	et	4	main
on	doc_596017998605_item	2750917	et	4	main
tean	doc_596017998605_item	2750924	et	3	main
õppidaei	doc_596017998605_item	2750938	et	4	main
veel	doc_596017998605_item	2750948	et	4	main
soovid	doc_596017998605_item	2750950	et	4	main
sellepärastet	doc_596017998605_item	2750953	et	4	main
ja	doc_596017998605_item	2750958	et	3	main
arvuti	doc_596017998605_item	2750976	et	4	main
pole	doc_596017998605_item	2750982	et	3	main
ja	doc_596017998605_item	2750985	et	3	main
õppida	doc_596017998605_item	2750991	et	3	main
küsimusele	doc_596017998606_item	2750993	et	4	main
õppida	doc_596017998606_item	2750998	et	3	main
pean	doc_596017998606_item	2751011	et	4	main
sa	doc_596017998606_item	2751014	et	3	main
2	doc_596017998606_item	2751017	et	2	main
oma	doc_584615399811_item	2750824	et	4	main
on	doc_584615399811_item	2750842	et	4	main
negatiivne	doc_584615399811_item	2750843	et	3	main
kuidas	doc_584615399811_item	2750845	et	3	main
õpenguid	doc_584615399811_item	2750849	et	4	main
loodan	doc_584615399811_item	2750852	et	3	main
ma	doc_584615399811_item	2750855	et	3	main
aga	doc_584615399811_item	2750858	et	3	main
tea	doc_584615399811_item	2750865	et	4	main
vastus	doc_596017998605_item	2750866	et	3	main
tahan	doc_596017998605_item	2750873	et	3	main
tahan	doc_596017998605_item	2750883	et	3	main
head	doc_596017998605_item	2750884	et	4	main
tööd	doc_596017998605_item	2750885	et	4	main
leida	doc_596017998605_item	2750886	et	3	main
2missugused	doc_596017998605_item	2750887	et	3	main
raskused	doc_596017998605_item	2750888	et	4	main
õppetöös	doc_596017998605_item	2750889	et	3	main
minu	doc_596017998605_item	2750890	et	3	main
ei	doc_596017998605_item	2750892	et	4	main
õppetöös	doc_596017998605_item	2750891	et	3	main
ole	doc_596017998605_item	2750893	et	4	main
materjali	doc_596017998605_item	2750894	et	4	main
aru	doc_596017998605_item	2750895	et	4	main
saamisega	doc_596017998605_item	2750896	et	4	main
probleemidainult	doc_596017998605_item	2750897	et	4	main
suur	doc_596017998605_item	2750899	et	3	main
on	doc_596017998605_item	2750898	et	4	main
õppekoormuspalju	doc_596017998605_item	2750900	et	4	main
kodutööd	doc_596017998605_item	2750901	et	4	main
ja	doc_596017998605_item	2750902	et	3	main
väsin	doc_596017998605_item	2750904	et	3	main
tihti	doc_596017998605_item	2750903	et	3	main
3kus	doc_596017998605_item	2750905	et	3	main
on	doc_596017998605_item	2750906	et	4	main
parem	doc_596017998605_item	2750907	et	4	main
õppidaeestis	doc_596017998605_item	2750908	et	4	main
või	doc_596017998605_item	2750909	et	4	main
välismaal	doc_596017998605_item	2750910	et	4	main
arvanet	doc_596017998605_item	2750911	et	4	main
eestis	doc_596017998605_item	2750912	et	3	main
on	doc_596017998605_item	2750913	et	4	main
parem	doc_596017998605_item	2750914	et	4	main
kodumaa	doc_596017998605_item	2750919	et	4	main
ja	doc_596017998605_item	2750920	et	3	main
välismaal	doc_596017998605_item	2750931	et	4	main
sooviksid	doc_596017998605_item	2750933	et	4	main
sooviksin	doc_596017998605_item	2750936	et	3	main
tea	doc_596017998605_item	2750939	et	4	main
linnas	doc_596017998605_item	2750942	et	4	main
ja	doc_596017998605_item	2750943	et	3	main
ole	doc_596017998605_item	2750946	et	4	main
5miks	doc_596017998605_item	2750949	et	4	main
tööd	doc_596017998605_item	2750956	et	4	main
ei	doc_596017998605_item	2750980	et	4	main
huvita	doc_596017998605_item	2750981	et	4	main
1	doc_596017998606_item	2750994	et	2	main
hariduseta	doc_596017998606_item	2751003	et	3	main
kuidas	doc_596017998606_item	2751013	et	3	main
arvan	doc_596017998606_item	2751018	et	3	main
halvasti	doc_596017998606_item	2751020	et	3	main
kuna	doc_596017998606_item	2751021	et	3	main
eesmäkite	doc_596017998606_item	2751023	et	4	main
vähenenult	doc_596017998606_item	2751026	et	4	main
pöörama	doc_596017998606_item	2751030	et	3	main
kuidas	doc_596017998606_item	2751045	et	3	main
olnud	doc_596017998606_item	2751054	et	4	main
nii	doc_596017998606_item	2751055	et	3	main
lai	doc_596017998606_item	2751056	et	3	main
ja	doc_596017998606_item	2751090	et	3	main
ja	doc_596017998606_item	2751105	et	3	main
6	doc_596017998606_item	2751109	et	2	main
sa	doc_596017998606_item	2751112	et	3	main
lihtsalt	doc_596017998606_item	2751117	et	4	main
ma	doc_596017998605_item	2750922	et	3	main
kõiktean	doc_596017998605_item	2750925	et	4	main
seaduseidinimesikodumaal	doc_596017998605_item	2750926	et	4	main
töötada	doc_596017998605_item	2750929	et	3	main
õppida	doc_596017998605_item	2750935	et	3	main
ülikoolis	doc_596017998605_item	2750937	et	4	main
ülikoolisei	doc_596017998605_item	2750945	et	4	main
valinud	doc_596017998605_item	2750947	et	4	main
kõrgharidust	doc_596017998605_item	2750951	et	4	main
tahan	doc_596017998605_item	2750954	et	3	main
leida	doc_596017998605_item	2750957	et	3	main
tänapäeva	doc_596017998605_item	2750963	et	4	main
noored	doc_596017998605_item	2750964	et	3	main
värtustavad	doc_596017998605_item	2750965	et	4	main
haridus	doc_596017998605_item	2750966	et	3	main
arvanet	doc_596017998605_item	2750967	et	4	main
tänapäeva	doc_596017998605_item	2750968	et	4	main
noored	doc_596017998605_item	2750969	et	3	main
ei	doc_596017998605_item	2750970	et	4	main
värtusta	doc_596017998605_item	2750971	et	4	main
haridussest	doc_596017998605_item	2750972	et	4	main
noored	doc_596017998605_item	2750973	et	3	main
alati	doc_596017998605_item	2750974	et	4	main
tahan	doc_596017998606_item	2750997	et	3	main
tean	doc_596017998606_item	2751000	et	3	main
2	doc_596017998606_item	2751012	et	2	main
et	doc_596017998606_item	2751019	et	3	main
hulk	doc_596017998606_item	2751024	et	3	main
õpiimine	doc_596017998606_item	2751039	et	4	main
protsess	doc_596017998606_item	2751040	et	3	main
soiskus	doc_596017998606_item	2751043	et	4	main
nagu	doc_596017998606_item	2751057	et	3	main
aga	doc_596017998606_item	2751060	et	3	main
nii	doc_596017998606_item	2751081	et	3	main
uut	doc_596017998606_item	2751093	et	3	main
on	doc_596017998606_item	2751097	et	4	main
sinu	doc_596017998606_item	2751098	et	3	main
5	doc_596017998606_item	2751102	et	2	main
olla	doc_596017998606_item	2751103	et	3	main
erudeeritud	doc_596017998606_item	2751104	et	3	main
poisina	doc_596017998606_item	2751108	et	3	main
missugused	doc_596017998606_item	2751110	et	3	main
enda	doc_596017998606_item	2751113	et	4	main
püstitasid	doc_596017998606_item	2751115	et	4	main
6	doc_596017998606_item	2751116	et	2	main
jaoks	doc_596017998606_item	2751120	et	4	main
saamise	doc_596017998606_item	2751124	et	4	main
puhul	doc_596017998606_item	2751125	et	4	main
valdkonnas	doc_596017998606_item	2751143	et	4	main
kuna	doc_596017998606_item	2751144	et	3	main
tahan	doc_596017998606_item	2751145	et	3	main
raevust	doc_596017998606_item	2751148	et	4	main
tulevikus	doc_596017998606_item	2751164	et	4	main
etv	doc_596182270457_item	2751202	et	4	main
seriaal	doc_596182270457_item	2751203	et	3	main
ja	doc_596182270457_item	2751205	et	3	main
las	doc_596182270457_item	2751209	et	4	main
meelest	doc_596182270457_item	2751212	et	4	main
hea	doc_596182270457_item	2751215	et	4	main
kanal	doc_596182270457_item	2751220	et	4	main
2s	doc_596182270457_item	2751221	et	4	main
lugema	doc_596182270457_item	2751224	et	4	main
ja	doc_596182270457_item	2751225	et	3	main
ka	doc_596182270457_item	2751226	et	3	main
sisu	doc_596182270457_item	2751233	et	4	main
siis	doc_596182270457_item	2751240	et	3	main
kui	doc_596182270457_item	2751241	et	3	main
kõneleja	doc_596182270457_item	2751242	et	4	main
lahti	doc_596182270457_item	2751244	et	4	main
liiga	doc_596182270457_item	2751252	et	4	main
2	doc_596182270457_item	2751257	et	2	main
mind	doc_596182270457_item	2751258	et	4	main
2	doc_596182270457_item	2751269	et	2	main
etvs	doc_596182270457_item	2751271	et	4	main
subtiiter	doc_596182270457_item	2751286	et	4	main
kaherealine	doc_596182270457_item	2751288	et	4	main
all	doc_596182270457_item	2751290	et	3	main
vasakul	doc_596182270457_item	2751291	et	4	main
serval	doc_596182270457_item	2751292	et	3	main
oli	doc_596182270457_item	2751295	et	3	main
olnud	doc_596182270457_item	2751323	et	4	main
subtiitri	doc_596182270457_item	2751324	et	4	main
poolitamine	doc_596182270457_item	2751325	et	4	main
oli	doc_596182270457_item	2751326	et	3	main
loogiline	doc_596182270457_item	2751331	et	4	main
nii	doc_596182270457_item	2751332	et	3	main
et	doc_596182270457_item	2751341	et	3	main
punktiga	doc_596182270457_item	2751346	et	4	main
kasutuses	doc_596182270457_item	2751350	et	4	main
kanal	doc_596182270457_item	2751355	et	4	main
2	doc_596182270457_item	2751356	et	2	main
oli	doc_596182270457_item	2751357	et	3	main
siis	doc_596182270457_item	2751363	et	3	main
filmis	doc_596182270457_item	2751365	et	4	main
subtiitril	doc_596182270457_item	2751370	et	4	main
oli	doc_596182270457_item	2751371	et	3	main
ära	doc_596182270457_item	2751396	et	4	main
samamoodi	doc_596182270457_item	2751397	et	3	main
nagu	doc_596182270457_item	2751398	et	3	main
etvs	doc_596182270457_item	2751399	et	4	main
oli	doc_596182270457_item	2751400	et	3	main
kõne	doc_596182270457_item	2751411	et	4	main
kui	doc_596182270457_item	2751427	et	3	main
ei	doc_596182270457_item	2751429	et	4	main
vajalik	doc_596182270457_item	2751431	et	3	main
ja	doc_596017998606_item	2751027	et	3	main
tähelepanu	doc_596017998606_item	2751032	et	4	main
konkreetstele	doc_596017998606_item	2751033	et	4	main
asjadele	doc_596017998606_item	2751034	et	3	main
ja	doc_596017998606_item	2751035	et	3	main
valdkondadele	doc_596017998606_item	2751036	et	3	main
seepaärast	doc_596017998606_item	2751037	et	4	main
minu	doc_596017998606_item	2751038	et	3	main
3	doc_596017998606_item	2751044	et	2	main
varem	doc_596017998606_item	2751047	et	4	main
lausa	doc_596017998606_item	2751062	et	4	main
rahuldavad	doc_596017998606_item	2751063	et	4	main
4	doc_596017998606_item	2751064	et	2	main
mis	doc_596017998606_item	2751065	et	4	main
on	doc_596017998606_item	2751066	et	4	main
peamine	doc_596017998606_item	2751067	et	3	main
sinu	doc_596017998606_item	2751068	et	3	main
jaoks	doc_596017998606_item	2751069	et	4	main
õppetöös	doc_596017998606_item	2751070	et	3	main
4	doc_596017998606_item	2751071	et	2	main
vestlemine	doc_596017998606_item	2751072	et	4	main
silmaringi	doc_596017998606_item	2751073	et	4	main
ja	doc_596017998606_item	2751074	et	3	main
vajalikud	doc_596017998606_item	2751082	et	3	main
teamised	doc_596017998606_item	2751086	et	4	main
oskus	doc_596017998606_item	2751088	et	3	main
omistada	doc_596017998606_item	2751091	et	3	main
peamised	doc_596017998606_item	2751099	et	3	main
õppe	doc_596017998606_item	2751100	et	4	main
eesmärgid	doc_596017998606_item	2751101	et	3	main
õppida	doc_596017998606_item	2751118	et	3	main
hinnete	doc_596017998606_item	2751123	et	3	main
tahe	doc_596017998606_item	2751135	et	4	main
nähes	doc_596017998606_item	2751146	et	4	main
ja	doc_596017998606_item	2751149	et	3	main
minu	doc_596017998606_item	2751168	et	3	main
kuuldav	doc_596182270457_item	2751229	et	4	main
sünkroonis	doc_596182270457_item	2751235	et	4	main
hilja	doc_596182270457_item	2751253	et	3	main
minu	doc_596182270457_item	2751254	et	3	main
arvates	doc_596182270457_item	2751255	et	4	main
teise	doc_596182270457_item	2751261	et	4	main
tiiter	doc_596182270457_item	2751264	et	3	main
seda	doc_596182270457_item	2751266	et	3	main
taustaks	doc_596182270457_item	2751274	et	3	main
tähed	doc_596182270457_item	2751277	et	3	main
suurim	doc_596182270457_item	2751280	et	3	main
arv	doc_596182270457_item	2751282	et	3	main
oli	doc_596182270457_item	2751284	et	3	main
ekraani	doc_596182270457_item	2751289	et	4	main
alumine	doc_596182270457_item	2751293	et	3	main
pikem	doc_596182270457_item	2751297	et	4	main
tehtud	doc_596182270457_item	2751327	et	4	main
kohas	doc_596182270457_item	2751328	et	4	main
süntaktiliselt	doc_596182270457_item	2751336	et	4	main
subtiiter	doc_596182270457_item	2751342	et	4	main
samasuguselt	doc_596182270457_item	2751358	et	4	main
asjad	doc_596182270457_item	2751362	et	3	main
keeles	doc_596182270457_item	2751369	et	4	main
keele	doc_596182270457_item	2751380	et	4	main
suurem	doc_596182270457_item	2751383	et	4	main
inglisekeelse	doc_596182270457_item	2751388	et	3	main
teksi	doc_596182270457_item	2751389	et	4	main
must	doc_596182270457_item	2751393	et	4	main
kast	doc_596182270457_item	2751394	et	3	main
kaos	doc_596182270457_item	2751395	et	4	main
lõpes	doc_596182270457_item	2751407	et	3	main
oli	doc_596182270457_item	2751412	et	3	main
oli	doc_596182270457_item	2751414	et	3	main
ka	doc_596182270457_item	2751416	et	3	main
et	doc_596182270457_item	2751418	et	3	main
sõna	doc_596182270457_item	2751420	et	4	main
siis	doc_596182270457_item	2751426	et	3	main
tiia-mai	doc_596182270457_item	2751435	et	4	main
2	doc_596182270457_item	2751439	et	2	main
oli	doc_596182270457_item	2751441	et	3	main
dokumentaalsari	doc_596182270457_item	2751446	et	4	main
ja	doc_596182270457_item	2751448	et	3	main
2	doc_596182270457_item	2751450	et	2	main
dokumentaalsari	doc_596182270457_item	2751451	et	4	main
samamoodi	doc_596182270457_item	2751458	et	3	main
s	doc_596182270457_item	2751487	et	4	main
nii	doc_596182270457_item	2751488	et	3	main
seriaalis	doc_596182270457_item	2751489	et	3	main
alaosas	doc_596182270457_item	2751497	et	3	main
eelmine	doc_596182270457_item	2751508	et	3	main
järgmisesse	doc_596182270457_item	2751511	et	3	main
toppama	doc_596182270457_item	2751513	et	3	main
arv	doc_596182270457_item	2751516	et	3	main
34	doc_596182270457_item	2751518	et	2	main
rita	doc_596182270457_item	2751520	et	4	main
talson	doc_596182270457_item	2751521	et	4	main
pärni	doc_596182270457_item	2751523	et	4	main
subtiitrite	doc_596182270457_item	2751524	et	4	main
kanal	doc_596182270457_item	2751528	et	4	main
seriaali	doc_596182270457_item	2751542	et	4	main
korda	doc_596182270457_item	2751547	et	4	main
lõppus	doc_596182270457_item	2751550	et	4	main
punkti	doc_596182270457_item	2751552	et	4	main
suurem	doc_596182270457_item	2751553	et	4	main
tähemärkide	doc_596182270457_item	2751554	et	3	main
veaks	doc_596182270457_item	2751564	et	4	main
et	doc_596182270457_item	2751567	et	3	main
alguses	doc_596182270457_item	2751570	et	4	main
missugused	doc_596017998606_item	2751096	et	3	main
palju	doc_596017998606_item	2751106	et	4	main
lugetud	doc_596017998606_item	2751107	et	4	main
ülesanded	doc_596017998606_item	2751111	et	3	main
jaoks	doc_596017998606_item	2751114	et	4	main
enda	doc_596017998606_item	2751119	et	4	main
heade	doc_596017998606_item	2751122	et	3	main
7	doc_596017998606_item	2751126	et	2	main
mis	doc_596017998606_item	2751127	et	4	main
õppetööd	doc_596017998606_item	2751130	et	4	main
7	doc_596017998606_item	2751131	et	2	main
esiteks	doc_596017998606_item	2751132	et	3	main
suhtumine	doc_596017998606_item	2751133	et	4	main
soov	doc_596017998606_item	2751137	et	3	main
õpetajate	doc_596017998606_item	2751140	et	4	main
huvitatus	doc_596017998606_item	2751141	et	4	main
oma	doc_596017998606_item	2751142	et	4	main
nende	doc_596017998606_item	2751147	et	4	main
oma	doc_596017998606_item	2751150	et	4	main
tunnist	doc_596017998606_item	2751151	et	4	main
tahan	doc_596017998606_item	2751154	et	3	main
ka	doc_596017998606_item	2751155	et	3	main
õppida	doc_596017998606_item	2751156	et	3	main
seda	doc_596017998606_item	2751157	et	3	main
8	doc_596017998606_item	2751158	et	2	main
kuidas	doc_596017998606_item	2751159	et	3	main
sa	doc_596017998606_item	2751160	et	3	main
näed	doc_596017998606_item	2751161	et	3	main
oma	doc_596017998606_item	2751162	et	4	main
õpinguid	doc_596017998606_item	2751163	et	3	main
kõik	doc_596017998606_item	2751166	et	4	main
lõppeksamite	doc_596017998606_item	2751169	et	3	main
ja	doc_596017998606_item	2751171	et	3	main
ja	doc_596182270457_item	2751199	et	3	main
lugemiskiirus	doc_596182270457_item	2751213	et	4	main
nii	doc_596182270457_item	2751216	et	3	main
kui	doc_596182270457_item	2751218	et	3	main
jõudsin	doc_596182270457_item	2751222	et	3	main
pilti	doc_596182270457_item	2751227	et	4	main
vaatama	doc_596182270457_item	2751228	et	3	main
olid	doc_596182270457_item	2751234	et	4	main
paar	doc_596182270457_item	2751246	et	3	main
löödud	doc_596182270457_item	2751250	et	4	main
subtiiter	doc_596182270457_item	2751251	et	4	main
kanal	doc_596182270457_item	2751256	et	4	main
häiris	doc_596182270457_item	2751259	et	3	main
jooksev	doc_596182270457_item	2751263	et	4	main
aga	doc_596182270457_item	2751265	et	3	main
korda	doc_596182270457_item	2751270	et	4	main
oli	doc_596182270457_item	2751275	et	3	main
paksud	doc_596182270457_item	2751279	et	3	main
tähemärkide	doc_596182270457_item	2751281	et	3	main
oli	doc_596182270457_item	2751287	et	3	main
tavaliselt	doc_596182270457_item	2751296	et	4	main
ka	doc_596182270457_item	2751321	et	3	main
mis	doc_596182270457_item	2751329	et	4	main
oli	doc_596182270457_item	2751330	et	3	main
viga	doc_596182270457_item	2751338	et	4	main
oli	doc_596182270457_item	2751339	et	3	main
see	doc_596182270457_item	2751340	et	3	main
lause	doc_596182270457_item	2751351	et	4	main
lõpus	doc_596182270457_item	2751352	et	4	main
teisiti	doc_596182270457_item	2751359	et	3	main
inglise	doc_596182270457_item	2751368	et	4	main
inglise	doc_596182270457_item	2751379	et	4	main
seletuse	doc_596182270457_item	2751381	et	4	main
tähemärkide	doc_596182270457_item	2751384	et	3	main
33	doc_596182270457_item	2751386	et	2	main
ei	doc_596182270457_item	2751391	et	4	main
veaks	doc_596182270457_item	2751401	et	4	main
see	doc_596182270457_item	2751402	et	3	main
paar	doc_596182270457_item	2751404	et	3	main
telefooni	doc_596182270457_item	2751410	et	4	main
oli	doc_596182270457_item	2751421	et	3	main
korda	doc_596182270457_item	2751424	et	4	main
olnud	doc_596182270457_item	2751430	et	4	main
ja	doc_596182270457_item	2751437	et	3	main
laanejärv	doc_596182270457_item	2751443	et	3	main
teeliiklusest	doc_596182270457_item	2751447	et	4	main
etv	doc_596182270457_item	2751453	et	4	main
kõik	doc_596182270457_item	2751456	et	4	main
ainult	doc_596182270457_item	2751463	et	4	main
mõjutab	doc_596017998606_item	2751128	et	3	main
sinu	doc_596017998606_item	2751129	et	3	main
ja	doc_596017998606_item	2751136	et	3	main
kindlasti	doc_596017998606_item	2751139	et	3	main
lihtsalt	doc_596017998606_item	2751152	et	4	main
meeletust	doc_596017998606_item	2751153	et	4	main
kukru	doc_596017998606_item	2751172	et	3	main
paksust	doc_596017998606_item	2751173	et	4	main
analüüs	doc_596182270457_item	2751174	et	3	main
subtiitrite	doc_596182270457_item	2751175	et	4	main
anal	doc_596182270457_item	2751176	et	4	main
üüs	doc_596182270457_item	2751177	et	4	main
lindistasin	doc_596182270457_item	2751178	et	3	main
ja	doc_596182270457_item	2751179	et	3	main
vaatasin	doc_596182270457_item	2751180	et	3	main
läbi	doc_596182270457_item	2751181	et	4	main
kahe	doc_596182270457_item	2751182	et	3	main
žanriga	doc_596182270457_item	2751184	et	2	main
erineva	doc_596182270457_item	2751183	et	4	main
saateid	doc_596182270457_item	2751185	et	3	main
kahelt	doc_596182270457_item	2751186	et	4	main
erinevalt	doc_596182270457_item	2751187	et	4	main
telekanalilt	doc_596182270457_item	2751188	et	3	main
need	doc_596182270457_item	2751189	et	3	main
olid	doc_596182270457_item	2751190	et	4	main
etv	doc_596182270457_item	2751191	et	4	main
ja	doc_596182270457_item	2751192	et	3	main
kanal	doc_596182270457_item	2751193	et	4	main
2	doc_596182270457_item	2751194	et	2	main
ning	doc_596182270457_item	2751195	et	3	main
žanriks	doc_596182270457_item	2751196	et	2	main
olid	doc_596182270457_item	2751197	et	4	main
seriaalid	doc_596182270457_item	2751198	et	3	main
tõsielusarjad	doc_596182270457_item	2751200	et	3	main
kanal	doc_596182270457_item	2751206	et	4	main
seriaal	doc_596182270457_item	2751208	et	3	main
etvs	doc_596182270457_item	2751217	et	4	main
ka	doc_596182270457_item	2751219	et	3	main
vegas	doc_596182270457_item	2751210	et	4	main
minu	doc_596182270457_item	2751211	et	3	main
oli	doc_596182270457_item	2751214	et	3	main
subtiitreid	doc_596182270457_item	2751223	et	4	main
ja	doc_596182270457_item	2751231	et	3	main
subtiitri	doc_596182270457_item	2751232	et	4	main
ilmusid	doc_596182270457_item	2751237	et	4	main
mõlemal	doc_596182270457_item	2751238	et	3	main
kanalil	doc_596182270457_item	2751239	et	3	main
tegi	doc_596182270457_item	2751245	et	4	main
korda	doc_596182270457_item	2751247	et	4	main
oli	doc_596182270457_item	2751249	et	3	main
kaadrisse	doc_596182270457_item	2751262	et	3	main
ainult	doc_596182270457_item	2751268	et	4	main
teksti	doc_596182270457_item	2751273	et	4	main
34	doc_596182270457_item	2751285	et	2	main
rida	doc_596182270457_item	2751294	et	4	main
selge	doc_596182270457_item	2751337	et	4	main
tihti	doc_596182270457_item	2751343	et	3	main
olid	doc_596182270457_item	2751353	et	4	main
oli	doc_596182270457_item	2751360	et	3	main
kui	doc_596182270457_item	2751364	et	3	main
olid	doc_596182270457_item	2751366	et	4	main
seletused	doc_596182270457_item	2751367	et	4	main
lihtsalt	doc_596182270457_item	2751372	et	4	main
must	doc_596182270457_item	2751373	et	4	main
kast	doc_596182270457_item	2751374	et	3	main
ja	doc_596182270457_item	2751375	et	3	main
eestikeelne	doc_596182270457_item	2751376	et	3	main
subtiiter	doc_596182270457_item	2751377	et	4	main
enam	doc_596182270457_item	2751390	et	4	main
olnud	doc_596182270457_item	2751392	et	4	main
korda	doc_596182270457_item	2751405	et	4	main
kolme	doc_596182270457_item	2751408	et	4	main
üks	doc_596182270457_item	2751419	et	3	main
heli	doc_596182270457_item	2751230	et	4	main
subtiitrid	doc_596182270457_item	2751236	et	4	main
suu	doc_596182270457_item	2751243	et	4	main
etvs	doc_596182270457_item	2751248	et	4	main
aga	doc_596182270457_item	2751260	et	3	main
nägin	doc_596182270457_item	2751267	et	3	main
valge	doc_596182270457_item	2751272	et	4	main
telepilt	doc_596182270457_item	2751276	et	3	main
olid	doc_596182270457_item	2751278	et	4	main
reas	doc_596182270457_item	2751283	et	3	main
kui	doc_596182270457_item	2751298	et	3	main
ülemine	doc_596182270457_item	2751299	et	4	main
kui	doc_596182270457_item	2751300	et	3	main
tõlgiti	doc_596182270457_item	2751301	et	3	main
tekst	doc_596182270457_item	2751302	et	3	main
internetist	doc_596182270457_item	2751303	et	4	main
oli	doc_596182270457_item	2751304	et	3	main
see	doc_596182270457_item	2751305	et	3	main
tsentreeritud	doc_596182270457_item	2751306	et	4	main
aga	doc_596182270457_item	2751307	et	3	main
kursiivis	doc_596182270457_item	2751308	et	3	main
ei	doc_596182270457_item	2751309	et	4	main
olnud	doc_596182270457_item	2751310	et	4	main
osa	doc_596182270457_item	2751311	et	4	main
raamatust	doc_596182270457_item	2751312	et	4	main
mida	doc_596182270457_item	2751313	et	4	main
isa	doc_596182270457_item	2751314	et	4	main
luges	doc_596182270457_item	2751315	et	3	main
pojale	doc_596182270457_item	2751316	et	4	main
oli	doc_596182270457_item	2751317	et	3	main
jutumärkides	doc_596182270457_item	2751318	et	3	main
aga	doc_596182270457_item	2751319	et	3	main
kursiivis	doc_596182270457_item	2751320	et	3	main
ei	doc_596182270457_item	2751322	et	4	main
semantiliselt	doc_596182270457_item	2751333	et	4	main
kui	doc_596182270457_item	2751334	et	3	main
ka	doc_596182270457_item	2751335	et	3	main
lõpes	doc_596182270457_item	2751344	et	3	main
kolme	doc_596182270457_item	2751345	et	4	main
semikoolon	doc_596182270457_item	2751347	et	4	main
oli	doc_596182270457_item	2751348	et	3	main
ka	doc_596182270457_item	2751349	et	3	main
punktid	doc_596182270457_item	2751354	et	4	main
järgmised	doc_596182270457_item	2751361	et	3	main
oli	doc_596182270457_item	2751378	et	3	main
peal	doc_596182270457_item	2751382	et	4	main
arv	doc_596182270457_item	2751385	et	3	main
kui	doc_596182270457_item	2751387	et	3	main
et	doc_596182270457_item	2751403	et	3	main
subtiiter	doc_596182270457_item	2751406	et	4	main
punktiga	doc_596182270457_item	2751409	et	4	main
kursiivis	doc_596182270457_item	2751413	et	3	main
veaks	doc_596182270457_item	2751415	et	4	main
see	doc_596182270457_item	2751417	et	3	main
kirjutatud	doc_596182270457_item	2751422	et	4	main
mitu	doc_596182270457_item	2751423	et	4	main
kanal	doc_596182270457_item	2751438	et	4	main
etv	doc_596182270457_item	2751445	et	4	main
kanal	doc_596182270457_item	2751449	et	4	main
oli	doc_596182270457_item	2751457	et	3	main
nadu	doc_596182270457_item	2751459	et	4	main
seriaali	doc_596182270457_item	2751464	et	4	main
puhul	doc_596182270457_item	2751465	et	4	main
keelekasutus	doc_596182270457_item	2751466	et	4	main
oli	doc_596182270457_item	2751467	et	3	main
sest	doc_596182270457_item	2751484	et	4	main
kanal	doc_596182270457_item	2751485	et	4	main
2	doc_596182270457_item	2751486	et	2	main
dokumentaalsaades	doc_596182270457_item	2751492	et	4	main
tiiter	doc_596182270457_item	2751493	et	3	main
samaaegselt	doc_596182270457_item	2751495	et	4	main
olid	doc_596182270457_item	2751505	et	4	main
piisavad	doc_596182270457_item	2751506	et	4	main
mõnikord	doc_596182270457_item	2751507	et	3	main
jüri	doc_596182270457_item	2751522	et	4	main
2	doc_596182270457_item	2751529	et	2	main
samamoodi	doc_596182270457_item	2751535	et	3	main
nagu	doc_596182270457_item	2751536	et	3	main
ma	doc_596182270457_item	2751537	et	3	main
vegas	doc_596182270457_item	2751544	et	4	main
kohta	doc_596182270457_item	2751545	et	4	main
lause	doc_596182270457_item	2751549	et	4	main
kolm	doc_596182270457_item	2751551	et	3	main
ku	doc_596182270457_item	2751562	et	4	main
alumine	doc_596182270457_item	2751563	et	3	main
olid	doc_596182270457_item	2751573	et	4	main
normaaltekstis	doc_596182270457_item	2751574	et	3	main
hiljem	doc_596182270457_item	2751575	et	3	main
äkki	doc_596182270457_item	2751576	et	3	main
oli	doc_596182270457_item	2751580	et	3	main
ka	doc_596182270457_item	2751581	et	3	main
olid	doc_596182270457_item	2751584	et	4	main
keerukaid	doc_596182270457_item	2751586	et	3	main
jooksvaid	doc_596182270457_item	2751590	et	4	main
tiina	doc_596182270457_item	2751593	et	4	main
järjest	doc_596182270457_item	2751425	et	4	main
see	doc_596182270457_item	2751428	et	3	main
etv	doc_596182270457_item	2751432	et	4	main
tõlkija	doc_596182270457_item	2751433	et	4	main
oli	doc_596182270457_item	2751434	et	3	main
tõlkija	doc_596182270457_item	2751440	et	4	main
p	doc_596182270457_item	2751444	et	4	main
dokumentaalsarjas	doc_596182270457_item	2751454	et	3	main
peaaegu	doc_596182270457_item	2751455	et	3	main
etv	doc_596182270457_item	2751460	et	4	main
seriaalis	doc_596182270457_item	2751461	et	3	main
robinsons	doc_596182270457_item	2751462	et	4	main
vabam	doc_596182270457_item	2751468	et	4	main
isegi	doc_596182270457_item	2751469	et	4	main
lohakam	doc_596182270457_item	2751470	et	4	main
kui	doc_596182270457_item	2751471	et	3	main
dokumentaalsarjas	doc_596182270457_item	2751472	et	3	main
kui	doc_596182270457_item	2751473	et	3	main
näidati	doc_596182270457_item	2751474	et	3	main
kõneleva	doc_596182270457_item	2751475	et	4	main
inimese	doc_596182270457_item	2751476	et	4	main
nimi	doc_596182270457_item	2751477	et	3	main
subtiiter	doc_596182270457_item	2751478	et	4	main
asetati	doc_596182270457_item	2751479	et	4	main
ekraani	doc_596182270457_item	2751480	et	4	main
ülaossa	doc_596182270457_item	2751481	et	3	main
see	doc_596182270457_item	2751482	et	3	main
oli	doc_596182270457_item	2751483	et	3	main
nõmmik	doc_596182270457_item	2751436	et	3	main
tiina	doc_596182270457_item	2751442	et	4	main
lastetaltsutaja	doc_596182270457_item	2751452	et	4	main
kui	doc_596182270457_item	2751490	et	3	main
subtiitriga	doc_596182270457_item	2751499	et	4	main
kasutus	doc_596182270457_item	2751501	et	4	main
oli	doc_596182270457_item	2751502	et	3	main
jäi	doc_596182270457_item	2751510	et	3	main
tõlkijad	doc_596182270457_item	2751519	et	4	main
dokumentaalsarjas	doc_596182270457_item	2751530	et	3	main
lastetaltsutaja	doc_596182270457_item	2751531	et	4	main
peaaegu	doc_596182270457_item	2751533	et	3	main
kirjutasin	doc_596182270457_item	2751538	et	3	main
kanal	doc_596182270457_item	2751540	et	4	main
2	doc_596182270457_item	2751541	et	2	main
palju	doc_596182270457_item	2751546	et	4	main
34	doc_596182270457_item	2751556	et	2	main
oli	doc_596182270457_item	2751565	et	3	main
see	doc_596182270457_item	2751566	et	3	main
olid	doc_596182270457_item	2751577	et	4	main
kasutatud	doc_596182270457_item	2751585	et	4	main
laanejärv	doc_596182270457_item	2751594	et	3	main
lugupeetud	doc_59711134399_item	2751771	et	4	main
tiina	doc_59711134399_item	2751772	et	4	main
isegi	doc_59711134399_item	2751813	et	4	main
kaine	doc_59711134399_item	2751825	et	4	main
kuhu	doc_59711134399_item	2751827	et	3	main
nende	doc_59711134399_item	2751828	et	4	main
punktidega	doc_59711134399_item	2751829	et	3	main
üldse	doc_59711134399_item	2751830	et	3	main
saab	doc_59711134399_item	2751831	et	3	main
minna	doc_59711134399_item	2751832	et	3	main
ja	doc_59711134399_item	2751846	et	3	main
et	doc_59711134399_item	2751850	et	3	main
rühm	doc_59711134399_item	2751852	et	3	main
suur	doc_59711134399_item	2751854	et	3	main
kahju	doc_59711134399_item	2751865	et	4	main
oma	doc_59711134399_item	2751895	et	4	main
töid	doc_59711134399_item	2751896	et	3	main
halvem	doc_59711134399_item	2751897	et	4	main
kui	doc_59711134399_item	2751898	et	3	main
huvitatud	doc_59711134399_item	2751899	et	4	main
inimene	doc_59711134399_item	2751900	et	3	main
oleksid	doc_59711134399_item	2751910	et	4	main
ka	doc_596182270457_item	2751491	et	3	main
ilmus	doc_596182270457_item	2751494	et	4	main
ekraani	doc_596182270457_item	2751496	et	4	main
oleva	doc_596182270457_item	2751498	et	4	main
sõnade	doc_596182270457_item	2751500	et	3	main
sobiv	doc_596182270457_item	2751503	et	4	main
pausid	doc_596182270457_item	2751504	et	3	main
tähemärkide	doc_596182270457_item	2751515	et	3	main
toimetaja	doc_596182270457_item	2751525	et	4	main
marju	doc_596182270457_item	2751526	et	3	main
las	doc_596182270457_item	2751543	et	4	main
oli	doc_596182270457_item	2751548	et	3	main
pikem	doc_596182270457_item	2751561	et	4	main
selle	doc_596182270457_item	2751568	et	4	main
et	doc_596182270457_item	2751583	et	3	main
subtiiter	doc_596182270457_item	2751509	et	4	main
kaadrisse	doc_596182270457_item	2751512	et	3	main
suurim	doc_596182270457_item	2751514	et	3	main
jälle	doc_596182270457_item	2751517	et	3	main
makki	doc_596182270457_item	2751527	et	4	main
oli	doc_596182270457_item	2751532	et	3	main
kõik	doc_596182270457_item	2751534	et	4	main
enne	doc_596182270457_item	2751539	et	4	main
arv	doc_596182270457_item	2751555	et	3	main
mõnikord	doc_596182270457_item	2751557	et	3	main
ülemine	doc_596182270457_item	2751558	et	4	main
rida	doc_596182270457_item	2751559	et	4	main
oli	doc_596182270457_item	2751560	et	3	main
saade	doc_596182270457_item	2751569	et	4	main
lapsehoidja	doc_596182270457_item	2751571	et	4	main
kursiivis	doc_596182270457_item	2751578	et	3	main
kolme	doc_596182270457_item	2751588	et	4	main
seletused	doc_596182270457_item	2751572	et	4	main
halb	doc_596182270457_item	2751579	et	3	main
see	doc_596182270457_item	2751582	et	3	main
läbi	doc_596182270457_item	2751587	et	4	main
subtiitri	doc_596182270457_item	2751589	et	4	main
lauseid	doc_596182270457_item	2751591	et	3	main
tõlkis	doc_596182270457_item	2751592	et	3	main
aega	doc_59711134399_item	2751808	et	4	main
nad	doc_59711134399_item	2751810	et	3	main
tea	doc_59711134399_item	2751812	et	4	main
uus	doc_59711134399_item	2751818	et	3	main
on	doc_59711134399_item	2751817	et	4	main
tulnud	doc_59711134399_item	2751820	et	4	main
koos	doc_59711134399_item	2751821	et	4	main
loteriiga	doc_59711134399_item	2751823	et	3	main
sisetunde	doc_59711134399_item	2751837	et	4	main
rajada	doc_59711134399_item	2751845	et	3	main
aga	doc_59711134399_item	2751862	et	3	main
on	doc_59711134399_item	2751903	et	4	main
nortele	doc_59711134399_item	2751906	et	4	main
on	doc_59711134399_item	2751920	et	4	main
palka	doc_59711134399_item	2751931	et	4	main
vanemate	doc_59711134399_item	2751942	et	4	main
18-aastased	doc_59711134399_item	2751950	et	4	main
väga	doc_59711134399_item	2751968	et	3	main
kodus	doc_59711134399_item	2751970	et	4	main
kodune	doc_59711134399_item	2751972	et	4	main
idüll	doc_59711134399_item	2751973	et	3	main
mida	doc_59711134399_item	2751974	et	4	main
lastena	doc_59711134399_item	2751975	et	3	main
silmis	doc_59711134399_item	2751980	et	4	main
ihaldusväärne	doc_59711134399_item	2751981	et	3	main
ja	doc_59711134399_item	2751982	et	3	main
suurt	doc_59711134399_item	2751983	et	3	main
võitlust	doc_59711134399_item	2751984	et	3	main
tavaliselt	doc_59711134399_item	2751998	et	4	main
ma	doc_59711134399_item	2751999	et	3	main
töötasid	doc_59711134399_item	2752006	et	4	main
on	doc_59711134399_item	2752022	et	4	main
tahaksin	doc_59711134399_item	2752025	et	3	main
ka	doc_59711134399_item	2752027	et	3	main
huvitavad	doc_59711134399_item	2752040	et	4	main
veel	doc_59711134399_item	2752044	et	4	main
noored	doc_59711134399_item	2752047	et	3	main
oma	doc_59711134399_item	2752049	et	4	main
tulekust	doc_59711134399_item	2752050	et	4	main
juba	doc_59711134399_item	2752051	et	3	main
palju	doc_59711134399_item	2752055	et	4	main
avatud	doc_59711134399_item	2752067	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_59711134399_item	2752068	et	4	main
kaalep	doc_59711134399_item	2751773	et	4	main
ma	doc_59711134399_item	2751774	et	3	main
olen	doc_59711134399_item	2751775	et	3	main
teie	doc_59711134399_item	2751776	et	4	main
austaja	doc_59711134399_item	2751777	et	4	main
lugesin	doc_59711134399_item	2751778	et	3	main
teie	doc_59711134399_item	2751779	et	4	main
artikli	doc_59711134399_item	2751780	et	3	main
ja	doc_59711134399_item	2751781	et	3	main
leidsin	doc_59711134399_item	2751782	et	3	main
palju	doc_59711134399_item	2751783	et	4	main
huvatavat	doc_59711134399_item	2751784	et	4	main
mõniga	doc_59711134399_item	2751785	et	4	main
väitega	doc_59711134399_item	2751786	et	3	main
ma	doc_59711134399_item	2751787	et	3	main
olen	doc_59711134399_item	2751788	et	3	main
nõus	doc_59711134399_item	2751789	et	4	main
teie	doc_59711134399_item	2751790	et	4	main
artiklis	doc_59711134399_item	2751791	et	3	main
on	doc_59711134399_item	2751792	et	4	main
kirjeldatud	doc_59711134399_item	2751793	et	4	main
üks	doc_59711134399_item	2751794	et	3	main
rühm	doc_59711134399_item	2751795	et	3	main
kes	doc_59711134399_item	2751796	et	4	main
ei	doc_59711134399_item	2751797	et	4	main
tea	doc_59711134399_item	2751798	et	4	main
mis	doc_59711134399_item	2751799	et	4	main
neist	doc_59711134399_item	2751800	et	4	main
saab	doc_59711134399_item	2751801	et	3	main
vaid	doc_59711134399_item	2751802	et	3	main
mõni	doc_59711134399_item	2751803	et	3	main
nädal	doc_59711134399_item	2751804	et	3	main
on	doc_59711134399_item	2751805	et	4	main
ülikoolidesse	doc_59711134399_item	2751806	et	3	main
astumiseni	doc_59711134399_item	2751807	et	4	main
kiri	doc_59711134399_item	2751770	et	3	main
ei	doc_59711134399_item	2751811	et	4	main
mitte	doc_59711134399_item	2751815	et	3	main
asi	doc_59711134399_item	2751819	et	4	main
riigieksamite	doc_59711134399_item	2751822	et	3	main
see	doc_59711134399_item	2751824	et	3	main
arvestus	doc_59711134399_item	2751826	et	4	main
peale	doc_59711134399_item	2751836	et	4	main
te	doc_59711134399_item	2751847	et	4	main
märkasite	doc_59711134399_item	2751849	et	3	main
see	doc_59711134399_item	2751851	et	3	main
on	doc_59711134399_item	2751853	et	4	main
elu	doc_59711134399_item	2751855	et	4	main
näitab	doc_59711134399_item	2751856	et	3	main
et	doc_59711134399_item	2751857	et	3	main
see	doc_59711134399_item	2751858	et	3	main
on	doc_59711134399_item	2751859	et	4	main
just	doc_59711134399_item	2751860	et	3	main
nii	doc_59711134399_item	2751861	et	3	main
pärast	doc_59711134399_item	2751902	et	4	main
liisida	doc_59711134399_item	2751932	et	4	main
olid	doc_59711134399_item	2751951	et	4	main
olid	doc_59711134399_item	2751955	et	4	main
tühjad	doc_59711134399_item	2751956	et	3	main
vaesed	doc_59711134399_item	2751959	et	4	main
vaevalt	doc_59711134399_item	2751960	et	4	main
et	doc_59711134399_item	2751961	et	3	main
ei	doc_59711134399_item	2751976	et	4	main
kogetud	doc_59711134399_item	2751977	et	4	main
oma	doc_59711134399_item	2751985	et	4	main
olen	doc_59711134399_item	2751989	et	3	main
iga	doc_59711134399_item	2751991	et	4	main
aega	doc_59711134399_item	2751997	et	4	main
vanemad	doc_59711134399_item	2752005	et	4	main
ome	doc_59711134399_item	2752033	et	4	main
et	doc_59711134399_item	2752046	et	3	main
mõtleksid	doc_59711134399_item	2752048	et	4	main
eestis	doc_59711134399_item	2752057	et	3	main
võib	doc_59711134399_item	2752059	et	3	main
leida	doc_59711134399_item	2752061	et	3	main
tallinnas	doc_59711134399_item	2752063	et	4	main
aga	doc_59711134399_item	2751809	et	3	main
umbkaudu	doc_59711134399_item	2751814	et	3	main
see	doc_59711134399_item	2751816	et	3	main
neil	doc_59711134399_item	2751833	et	4	main
abiturientidel	doc_59711134399_item	2751834	et	3	main
pole	doc_59711134399_item	2751835	et	3	main
kuidas	doc_59711134399_item	2751838	et	3	main
läksid	doc_59711134399_item	2751840	et	4	main
midagi	doc_59711134399_item	2751842	et	4	main
millele	doc_59711134399_item	2751843	et	3	main
tulevikuplaane	doc_59711134399_item	2751844	et	3	main
õigesti	doc_59711134399_item	2751848	et	3	main
on	doc_59711134399_item	2751863	et	4	main
väga	doc_59711134399_item	2751864	et	3	main
anda	doc_59711134399_item	2751905	et	3	main
huvi	doc_59711134399_item	2751907	et	4	main
et	doc_59711134399_item	2751908	et	3	main
nad	doc_59711134399_item	2751909	et	3	main
huvitatud	doc_59711134399_item	2751911	et	4	main
juba	doc_59711134399_item	2751912	et	3	main
siis	doc_59711134399_item	2751913	et	3	main
kui	doc_59711134399_item	2751914	et	3	main
nad	doc_59711134399_item	2751915	et	3	main
õpivad	doc_59711134399_item	2751916	et	3	main
saada	doc_59711134399_item	2751928	et	4	main
täiesti	doc_59711134399_item	2751929	et	3	main
normaalselt	doc_59711134399_item	2751930	et	4	main
auto	doc_59711134399_item	2751933	et	4	main
näinud	doc_59711134399_item	2751940	et	4	main
põnnid	doc_59711134399_item	2751952	et	3	main
poed	doc_59711134399_item	2751954	et	4	main
ja	doc_59711134399_item	2751957	et	3	main
kodud	doc_59711134399_item	2751958	et	3	main
tegid	doc_59711134399_item	2751965	et	4	main
teistkümnetunniseid	doc_59711134399_item	2751966	et	4	main
palju	doc_59711134399_item	2751969	et	4	main
kodus	doc_59711134399_item	2752001	et	4	main
üksi	doc_59711134399_item	2752002	et	4	main
väga	doc_59711134399_item	2752007	et	3	main
loodan	doc_59711134399_item	2752035	et	3	main
teil	doc_59711134399_item	2752037	et	4	main
niisugused	doc_59711134399_item	2752039	et	3	main
artiklid	doc_59711134399_item	2752043	et	3	main
kõik	doc_59711134399_item	2752064	et	4	main
teed	doc_59711134399_item	2752065	et	4	main
eksamid	doc_59711134399_item	2751839	et	3	main
tegelikult	doc_59711134399_item	2751841	et	4	main
praegu	doc_59711134399_item	2751866	et	3	main
noortel	doc_59711134399_item	2751867	et	3	main
ei	doc_59711134399_item	2751868	et	4	main
ole	doc_59711134399_item	2751869	et	4	main
huvialasid	doc_59711134399_item	2751870	et	4	main
ja	doc_59711134399_item	2751871	et	3	main
hobisid	doc_59711134399_item	2751872	et	3	main
nad	doc_59711134399_item	2751873	et	3	main
ei	doc_59711134399_item	2751874	et	4	main
teavad	doc_59711134399_item	2751875	et	3	main
mis	doc_59711134399_item	2751876	et	4	main
nendele	doc_59711134399_item	2751877	et	4	main
meeldib	doc_59711134399_item	2751878	et	3	main
kogu	doc_59711134399_item	2751879	et	4	main
vabaaega	doc_59711134399_item	2751880	et	4	main
nad	doc_59711134399_item	2751881	et	3	main
mängivad	doc_59711134399_item	2751882	et	4	main
arvutimängu	doc_59711134399_item	2751883	et	4	main
või	doc_59711134399_item	2751884	et	4	main
kõndivad	doc_59711134399_item	2751885	et	4	main
sihitult	doc_59711134399_item	2751886	et	4	main
mööda	doc_59711134399_item	2751887	et	4	main
linna	doc_59711134399_item	2751888	et	4	main
kui	doc_59711134399_item	2751889	et	3	main
ei	doc_59711134399_item	2751890	et	4	main
ole	doc_59711134399_item	2751891	et	4	main
eesmärgi	doc_59711134399_item	2751892	et	4	main
inimene	doc_59711134399_item	2751893	et	3	main
teeb	doc_59711134399_item	2751894	et	3	main
selle	doc_59711134399_item	2751901	et	4	main
vaja	doc_59711134399_item	2751904	et	4	main
algkoolis	doc_59711134399_item	2751917	et	4	main
teine	doc_59711134399_item	2751918	et	3	main
rühm	doc_59711134399_item	2751919	et	3	main
inemesed	doc_59711134399_item	2751921	et	4	main
rahulikult	doc_59711134399_item	2751925	et	4	main
rabelemata	doc_59711134399_item	2751926	et	4	main
ja	doc_59711134399_item	2751927	et	3	main
väike	doc_59711134399_item	2751935	et	4	main
oma	doc_59711134399_item	2751941	et	4	main
rapsimisi	doc_59711134399_item	2751943	et	4	main
90-ndatel	doc_59711134399_item	2751944	et	4	main
ega	doc_59711134399_item	2751945	et	3	main
vanemad	doc_59711134399_item	2751962	et	4	main
tööpäevi	doc_59711134399_item	2751967	et	4	main
ei	doc_59711134399_item	2751987	et	4	main
olin	doc_59711134399_item	2752000	et	3	main
kes	doc_59711134399_item	2751922	et	4	main
tahaks	doc_59711134399_item	2751923	et	3	main
töötada	doc_59711134399_item	2751924	et	3	main
soetada	doc_59711134399_item	2751934	et	3	main
kodu	doc_59711134399_item	2751936	et	4	main
need	doc_59711134399_item	2751937	et	3	main
noored	doc_59711134399_item	2751938	et	3	main
on	doc_59711134399_item	2751939	et	4	main
taha	doc_59711134399_item	2751946	et	4	main
seda	doc_59711134399_item	2751947	et	3	main
korrata	doc_59711134399_item	2751948	et	4	main
tänased	doc_59711134399_item	2751949	et	3	main
kui	doc_59711134399_item	2751953	et	3	main
kes	doc_59711134399_item	2751963	et	4	main
sageli	doc_59711134399_item	2751964	et	3	main
olid	doc_59711134399_item	2751971	et	4	main
on	doc_59711134399_item	2751978	et	4	main
laste	doc_59711134399_item	2751979	et	4	main
ellu	doc_59711134399_item	2751986	et	4	main
taheta	doc_59711134399_item	2751988	et	3	main
nõus	doc_59711134399_item	2751990	et	4	main
sõnaga	doc_59711134399_item	2751992	et	3	main
sest	doc_59711134399_item	2751993	et	4	main
ma	doc_59711134399_item	2751994	et	3	main
mäletan	doc_59711134399_item	2751995	et	3	main
seda	doc_59711134399_item	2751996	et	3	main
sest	doc_59711134399_item	2752003	et	4	main
et	doc_59711134399_item	2752004	et	3	main
palju	doc_59711134399_item	2752008	et	4	main
ma	doc_59711134399_item	2752009	et	3	main
võin	doc_59711134399_item	2752010	et	3	main
öelda	doc_59711134399_item	2752011	et	4	main
et	doc_59711134399_item	2752012	et	3	main
kuulun	doc_59711134399_item	2752013	et	3	main
sellele	doc_59711134399_item	2752014	et	4	main
rühmale	doc_59711134399_item	2752015	et	3	main
mulle	doc_59711134399_item	2752016	et	4	main
meeldib	doc_59711134399_item	2752017	et	3	main
stabiilne	doc_59711134399_item	2752018	et	3	main
elu	doc_59711134399_item	2752019	et	4	main
sest	doc_59711134399_item	2752020	et	4	main
stabiilsus	doc_59711134399_item	2752021	et	4	main
hüvang	doc_59711134399_item	2752023	et	3	main
just	doc_59711134399_item	2752026	et	3	main
perega	doc_59711134399_item	2752034	et	3	main
on	doc_59711134399_item	2752038	et	4	main
tunnetuslikud	doc_59711134399_item	2752042	et	3	main
tahaksin	doc_59711134399_item	2752045	et	3	main
on	doc_59711134399_item	2752054	et	4	main
on	doc_59711134399_item	2752066	et	4	main
ma	doc_59711134399_item	2752024	et	3	main
oma	doc_59711134399_item	2752028	et	4	main
erimaja	doc_59711134399_item	2752029	et	4	main
kus	doc_59711134399_item	2752030	et	3	main
ma	doc_59711134399_item	2752031	et	3	main
elaksin	doc_59711134399_item	2752032	et	3	main
et	doc_59711134399_item	2752036	et	3	main
ja	doc_59711134399_item	2752041	et	3	main
algkoolist	doc_59711134399_item	2752052	et	4	main
praegu	doc_59711134399_item	2752053	et	3	main
võimalusi	doc_59711134399_item	2752056	et	3	main
kust	doc_59711134399_item	2752058	et	4	main
tööst	doc_59711134399_item	2752060	et	3	main
eriti	doc_59711134399_item	2752062	et	3	main
artikli	doc_59711134402_item	2752524	et	3	main
vähenõudlike	doc_59711134402_item	2752525	et	3	main
põlvkond	doc_59711134402_item	2752526	et	3	main
toob	doc_59711134402_item	2752544	et	3	main
suur	doc_59711134402_item	2752545	et	3	main
kasu	doc_59711134402_item	2752546	et	4	main
ma	doc_59711134402_item	2752557	et	3	main
tulevikus	doc_59711134402_item	2752575	et	4	main
ülikoolis	doc_59711134402_item	2752579	et	4	main
oma	doc_59711134402_item	2752581	et	4	main
õpingut	doc_59711134402_item	2752582	et	3	main
meie	doc_59711134402_item	2752584	et	4	main
elukutset	doc_59711134402_item	2752590	et	3	main
mis	doc_59711134402_item	2752591	et	4	main
piisavalt	doc_59711134402_item	2752594	et	4	main
et	doc_59711134402_item	2752596	et	3	main
ja	doc_59711134402_item	2752598	et	3	main
ja	doc_59711134402_item	2752600	et	3	main
et	doc_59711134402_item	2752606	et	3	main
see	doc_59711134402_item	2752607	et	3	main
huvita	doc_59711134402_item	2752614	et	4	main
neid	doc_59711134402_item	2752615	et	4	main
meil	doc_59711134402_item	2752617	et	4	main
ei	doc_59711134402_item	2752618	et	4	main
kirjutada	doc_59711134402_item	2752529	et	3	main
seisukoht	doc_59711134402_item	2752532	et	3	main
on	doc_59711134402_item	2752533	et	4	main
selline	doc_59711134402_item	2752534	et	4	main
et	doc_59711134402_item	2752535	et	3	main
see	doc_59711134402_item	2752536	et	3	main
aega	doc_59711134402_item	2752554	et	4	main
saan	doc_59711134402_item	2752558	et	4	main
saa	doc_59711134402_item	2752564	et	4	main
hiljuti	doc_59711134402_item	2752567	et	4	main
ma	doc_59711134402_item	2752568	et	3	main
seisin	doc_59711134402_item	2752569	et	3	main
valiku	doc_59711134402_item	2752570	et	3	main
ees	doc_59711134402_item	2752571	et	4	main
saada	doc_59711134402_item	2752576	et	4	main
missuguses	doc_59711134402_item	2752578	et	3	main
annaks	doc_59711134402_item	2752593	et	4	main
väike	doc_59711134402_item	2752601	et	4	main
maja	doc_59711134402_item	2752602	et	4	main
validakse	doc_59711134402_item	2752603	et	4	main
eriala	doc_59711134402_item	2752608	et	4	main
ei	doc_59711134402_item	2752610	et	4	main
õigust	doc_59711134402_item	2752620	et	4	main
tahaksid	doc_59711134402_item	2752626	et	4	main
heaolus	doc_59711134402_item	2752629	et	3	main
arvan	doc_59711134402_item	2752631	et	3	main
olla	doc_59711134402_item	2752638	et	3	main
päevas	doc_59711134402_item	2752640	et	3	main
nad	doc_59711134402_item	2752644	et	3	main
toitumine	doc_59711134402_item	2752651	et	4	main
noored	doc_59711134402_item	2752659	et	3	main
pappi	doc_59711134402_item	2752662	et	4	main
soov	doc_59711134402_item	2752681	et	3	main
ma	doc_59711134402_item	2752527	et	3	main
otsustasin	doc_59711134402_item	2752528	et	3	main
huvitav	doc_59711134402_item	2752541	et	4	main
artikkel	doc_59711134402_item	2752542	et	3	main
millega	doc_59711134402_item	2752556	et	3	main
ja	doc_59711134402_item	2752561	et	3	main
kelleks	doc_59711134402_item	2752572	et	4	main
ma	doc_59711134402_item	2752573	et	3	main
tahan	doc_59711134402_item	2752574	et	3	main
ja	doc_59711134402_item	2752577	et	3	main
ajal	doc_59711134402_item	2752585	et	4	main
enamus	doc_59711134402_item	2752586	et	4	main
oleks	doc_59711134402_item	2752597	et	3	main
auto	doc_59711134402_item	2752599	et	4	main
sellele	doc_59711134402_item	2752605	et	4	main
neile	doc_59711134402_item	2752609	et	4	main
sobi	doc_59711134402_item	2752611	et	4	main
või	doc_59711134402_item	2752612	et	4	main
üldse	doc_59711134402_item	2752616	et	3	main
inimesi	doc_59711134402_item	2752621	et	4	main
parem	doc_59711134402_item	2752628	et	4	main
igal	doc_59711134402_item	2752633	et	3	main
kindel	doc_59711134402_item	2752637	et	3	main
terveslik	doc_59711134402_item	2752650	et	4	main
selles	doc_59711134402_item	2752657	et	4	main
et	doc_59711134402_item	2752658	et	3	main
head	doc_59711134402_item	2752670	et	4	main
ja	doc_59711134402_item	2752684	et	3	main
olen	doc_59711134402_item	2752687	et	3	main
päri	doc_59711134402_item	2752691	et	4	main
on	doc_59711134402_item	2752705	et	4	main
inimesed	doc_59711134402_item	2752715	et	3	main
esmakursuslane	doc_59711134402_item	2752521	et	3	main
teie	doc_59711134402_item	2752523	et	4	main
teile	doc_59711134402_item	2752530	et	4	main
minu	doc_59711134402_item	2752531	et	3	main
mis	doc_59711134402_item	2752543	et	4	main
teiega	doc_59711134402_item	2752559	et	3	main
nõustuma	doc_59711134402_item	2752560	et	3	main
millega	doc_59711134402_item	2752562	et	3	main
täiesti	doc_59711134402_item	2752566	et	3	main
jätkuda	doc_59711134402_item	2752580	et	3	main
noordest	doc_59711134402_item	2752587	et	4	main
valib	doc_59711134402_item	2752588	et	3	main
raha	doc_59711134402_item	2752595	et	4	main
vaatamata	doc_59711134402_item	2752604	et	4	main
ei	doc_59711134402_item	2752613	et	4	main
südistama	doc_59711134402_item	2752622	et	4	main
selles	doc_59711134402_item	2752623	et	4	main
et	doc_59711134402_item	2752624	et	3	main
nad	doc_59711134402_item	2752625	et	3	main
ja	doc_59711134402_item	2752641	et	3	main
et	doc_59711134402_item	2752643	et	3	main
anda	doc_59711134402_item	2752646	et	3	main
lastele	doc_59711134402_item	2752648	et	4	main
kõik	doc_59711134402_item	2752649	et	4	main
ülikoolis	doc_59711134402_item	2752656	et	4	main
maja	doc_59711134402_item	2752665	et	4	main
kahekümneaastased	doc_59711134402_item	2752675	et	4	main
tahavad	doc_59711134402_item	2752676	et	3	main
elada	doc_59711134402_item	2752677	et	3	main
neljakümnesed	doc_59711134402_item	2752679	et	3	main
jõukalt	doc_59711134402_item	2752683	et	4	main
ma	doc_59711134402_item	2752686	et	3	main
niisuguste	doc_59711134402_item	2752688	et	3	main
täiesti	doc_59711134402_item	2752690	et	3	main
kui	doc_59711134402_item	2752692	et	3	main
need	doc_59711134402_item	2752693	et	3	main
ei	doc_59711134402_item	2752694	et	4	main
kriminaaliga	doc_59711134402_item	2752697	et	4	main
nõus	doc_59711134402_item	2752700	et	4	main
kiri	doc_59711134402_item	2752509	et	3	main
lugupeetud	doc_59711134402_item	2752510	et	4	main
tiina	doc_59711134402_item	2752511	et	4	main
kaalep	doc_59711134402_item	2752512	et	4	main
minu	doc_59711134402_item	2752513	et	3	main
nimi	doc_59711134402_item	2752514	et	3	main
on	doc_59711134402_item	2752515	et	4	main
x	doc_59711134402_item	2752516	et	4	main
ja	doc_59711134402_item	2752517	et	3	main
ma	doc_59711134402_item	2752518	et	3	main
olen	doc_59711134402_item	2752519	et	3	main
ttü	doc_59711134402_item	2752520	et	4	main
lugedes	doc_59711134402_item	2752522	et	3	main
on	doc_59711134402_item	2752537	et	4	main
väga	doc_59711134402_item	2752538	et	3	main
tunnetuslik	doc_59711134402_item	2752539	et	3	main
ja	doc_59711134402_item	2752540	et	3	main
tulevastele	doc_59711134402_item	2752547	et	4	main
üliõpilastele	doc_59711134402_item	2752548	et	4	main
pärast	doc_59711134402_item	2752549	et	4	main
lugemist	doc_59711134402_item	2752550	et	4	main
ma	doc_59711134402_item	2752551	et	3	main
mõtlesin	doc_59711134402_item	2752552	et	3	main
palju	doc_59711134402_item	2752553	et	4	main
sellest	doc_59711134402_item	2752555	et	4	main
ei	doc_59711134402_item	2752563	et	4	main
kuna	doc_59711134402_item	2752565	et	3	main
muidugi	doc_59711134402_item	2752583	et	4	main
niisugust	doc_59711134402_item	2752589	et	3	main
tulevikus	doc_59711134402_item	2752592	et	4	main
ole	doc_59711134402_item	2752619	et	4	main
elada	doc_59711134402_item	2752627	et	3	main
ma	doc_59711134402_item	2752630	et	3	main
et	doc_59711134402_item	2752632	et	3	main
soov	doc_59711134402_item	2752636	et	3	main
homses	doc_59711134402_item	2752639	et	3	main
selles	doc_59711134402_item	2752642	et	4	main
õppimine	doc_59711134402_item	2752652	et	4	main
heas	doc_59711134402_item	2752653	et	3	main
koolis	doc_59711134402_item	2752654	et	4	main
ja	doc_59711134402_item	2752655	et	3	main
soovivad	doc_59711134402_item	2752660	et	4	main
ja	doc_59711134402_item	2752664	et	3	main
liisida	doc_59711134402_item	2752666	et	4	main
ma	doc_59711134402_item	2752667	et	3	main
näen	doc_59711134402_item	2752668	et	3	main
ainult	doc_59711134402_item	2752669	et	4	main
näen	doc_59711134402_item	2752680	et	3	main
ole	doc_59711134402_item	2752695	et	4	main
ma	doc_59711134402_item	2752698	et	3	main
teie	doc_59711134402_item	2752702	et	4	main
saavad	doc_59711134402_item	2752712	et	4	main
seisukohta	doc_59711134402_item	2752727	et	4	main
ja	doc_59711134402_item	2752728	et	3	main
valivad	doc_59711134402_item	2752729	et	4	main
tulevikut	doc_59711134402_item	2752730	et	4	main
sõpru	doc_59711134402_item	2752735	et	3	main
need	doc_59711134402_item	2752739	et	3	main
nõrgad	doc_59711134402_item	2752741	et	3	main
inimesed	doc_59711134402_item	2752742	et	3	main
kellel	doc_59711134402_item	2752743	et	4	main
on	doc_59711134402_item	2752744	et	4	main
väga	doc_59711134402_item	2752745	et	3	main
jagan	doc_59711134402_item	2752749	et	3	main
noorel	doc_59711134402_item	2752755	et	3	main
paremaks	doc_59711134402_item	2752768	et	4	main
kiri	doc_59711134403_item	2752781	et	3	main
kaalep	doc_59711134403_item	2752785	et	4	main
kirjutan	doc_59711134403_item	2752787	et	3	main
kuna	doc_59711134403_item	2752789	et	3	main
lugenud	doc_59711134403_item	2752791	et	4	main
teie	doc_59711134403_item	2752792	et	4	main
artikli	doc_59711134403_item	2752793	et	3	main
ja	doc_59711134403_item	2752794	et	3	main
see	doc_59711134403_item	2752795	et	3	main
artikkel	doc_59711134403_item	2752796	et	3	main
mulle	doc_59711134403_item	2752797	et	4	main
meeldis	doc_59711134403_item	2752798	et	3	main
üliõpilane	doc_59711134403_item	2752807	et	3	main
tean	doc_59711134403_item	2752811	et	3	main
raha	doc_59711134403_item	2752832	et	4	main
ja	doc_59711134403_item	2752833	et	3	main
mitte	doc_59711134403_item	2752834	et	3	main
ja	doc_59711134403_item	2752836	et	3	main
nad	doc_59711134403_item	2752837	et	3	main
saada	doc_59711134403_item	2752840	et	4	main
palju	doc_59711134403_item	2752841	et	4	main
on	doc_59711134403_item	2752848	et	4	main
küll	doc_59711134403_item	2752849	et	4	main
et	doc_59711134403_item	2752850	et	3	main
abiturientide	doc_59711134403_item	2752851	et	3	main
tulevik	doc_59711134403_item	2752852	et	3	main
sõltub	doc_59711134403_item	2752853	et	3	main
eksami	doc_59711134403_item	2752854	et	3	main
tulemusest	doc_59711134403_item	2752855	et	4	main
kui	doc_59711134403_item	2752867	et	3	main
tulemused	doc_59711134403_item	2752871	et	3	main
selgeks	doc_59711134403_item	2752873	et	3	main
ei	doc_59711134403_item	2752878	et	4	main
on	doc_59711134403_item	2752916	et	4	main
küll	doc_59711134403_item	2752917	et	4	main
inimesel	doc_59711134402_item	2752634	et	3	main
on	doc_59711134402_item	2752635	et	4	main
saavad	doc_59711134402_item	2752645	et	4	main
oma	doc_59711134402_item	2752647	et	4	main
palju	doc_59711134402_item	2752661	et	4	main
reisida	doc_59711134402_item	2752663	et	3	main
tõttamist	doc_59711134402_item	2752671	et	4	main
aga	doc_59711134402_item	2752672	et	3	main
selles	doc_59711134402_item	2752673	et	4	main
et	doc_59711134402_item	2752674	et	3	main
nagu	doc_59711134402_item	2752678	et	3	main
elada	doc_59711134402_item	2752682	et	3	main
inimesi	doc_59711134402_item	2752707	et	4	main
ei	doc_59711134402_item	2752717	et	4	main
tea	doc_59711134402_item	2752718	et	4	main
mis	doc_59711134402_item	2752719	et	4	main
neil	doc_59711134402_item	2752720	et	4	main
on	doc_59711134402_item	2752721	et	4	main
üldse	doc_59711134402_item	2752723	et	3	main
kellel	doc_59711134402_item	2752724	et	4	main
pole	doc_59711134402_item	2752725	et	3	main
oma	doc_59711134402_item	2752726	et	4	main
mul	doc_59711134402_item	2752736	et	3	main
ka	doc_59711134402_item	2752750	et	3	main
et	doc_59711134402_item	2752753	et	3	main
vajalik	doc_59711134402_item	2752758	et	3	main
tahaksin	doc_59711134402_item	2752771	et	3	main
tänada	doc_59711134402_item	2752772	et	3	main
teid	doc_59711134402_item	2752773	et	4	main
olen	doc_59711134403_item	2752790	et	3	main
tänapäevane	doc_59711134403_item	2752802	et	4	main
praegu	doc_59711134403_item	2752804	et	3	main
hästi	doc_59711134403_item	2752810	et	3	main
nad	doc_59711134403_item	2752822	et	3	main
töötada	doc_59711134403_item	2752835	et	3	main
unustavad	doc_59711134403_item	2752838	et	4	main
näiteks	doc_59711134403_item	2752856	et	4	main
kui	doc_59711134403_item	2752857	et	3	main
oli	doc_59711134403_item	2752858	et	3	main
ma	doc_59711134403_item	2752860	et	3	main
ülikooli	doc_59711134403_item	2752863	et	4	main
ühe	doc_59711134403_item	2752864	et	4	main
erialale	doc_59711134403_item	2752865	et	3	main
minna	doc_59711134403_item	2752920	et	3	main
nad	doc_59711134403_item	2752923	et	3	main
kohtadele	doc_59711134403_item	2752929	et	3	main
ei	doc_59711134403_item	2752948	et	4	main
otsivad	doc_59711134403_item	2752952	et	4	main
parianti	doc_59711134403_item	2752955	et	4	main
ja	doc_59711134403_item	2752965	et	3	main
oma	doc_59711134403_item	2752967	et	4	main
ostavad	doc_59711134403_item	2752975	et	3	main
ja	doc_59711134403_item	2752978	et	3	main
aga	doc_59711134403_item	2752980	et	3	main
on	doc_59711134403_item	2752981	et	4	main
ka	doc_59711134403_item	2752982	et	3	main
lubada	doc_59711134403_item	2752989	et	3	main
aga	doc_59711134403_item	2752990	et	3	main
nad	doc_59711134403_item	2752995	et	3	main
hästi	doc_59711134403_item	2752997	et	3	main
on	doc_59711134403_item	2753000	et	4	main
vaga	doc_59711134403_item	2753004	et	4	main
kuna	doc_59711134403_item	2753006	et	3	main
ei	doc_59711134403_item	2753014	et	4	main
tööd	doc_59711134403_item	2753023	et	4	main
meestele	doc_59711134403_item	2753027	et	4	main
tööd	doc_59711134403_item	2753039	et	4	main
endale	doc_59711134403_item	2753040	et	4	main
suvi	doc_59711134403_item	2753041	et	3	main
jooksul	doc_59711134403_item	2753042	et	4	main
aga	doc_59711134403_item	2753043	et	3	main
leida	doc_59711134403_item	2753048	et	3	main
pakkuti	doc_59711134403_item	2753052	et	4	main
õmblejana	doc_59711134403_item	2753054	et	4	main
juba	doc_59711134403_item	2753057	et	3	main
see	doc_59711134403_item	2753060	et	3	main
arstid	doc_59711134403_item	2753088	et	4	main
ehitajana	doc_59711134403_item	2753108	et	4	main
olema	doc_59711134403_item	2753111	et	4	main
kuna	doc_59711134403_item	2753115	et	3	main
sõltub	doc_59711134403_item	2753117	et	3	main
elu	doc_59711134403_item	2753119	et	4	main
ja	doc_59711134403_item	2753120	et	3	main
muretult	doc_59711134402_item	2752685	et	4	main
eesmärkidega	doc_59711134402_item	2752689	et	3	main
seotud	doc_59711134402_item	2752696	et	4	main
olen	doc_59711134402_item	2752699	et	3	main
sajaprotsendiliselt	doc_59711134402_item	2752701	et	4	main
et	doc_59711134402_item	2752704	et	3	main
palju	doc_59711134402_item	2752706	et	4	main
kes	doc_59711134402_item	2752708	et	4	main
lähevad	doc_59711134402_item	2752709	et	3	main
kuhu	doc_59711134402_item	2752710	et	3	main
sisse	doc_59711134402_item	2752711	et	4	main
kes	doc_59711134402_item	2752716	et	4	main
ja	doc_59711134402_item	2752734	et	3	main
et	doc_59711134402_item	2752738	et	3	main
on	doc_59711134402_item	2752740	et	4	main
raske	doc_59711134402_item	2752746	et	4	main
arvamust	doc_59711134402_item	2752752	et	3	main
teaksid	doc_59711134402_item	2752761	et	4	main
mida	doc_59711134402_item	2752762	et	4	main
kui	doc_59711134402_item	2752764	et	3	main
teha	doc_59711134402_item	2752765	et	3	main
huvitava	doc_59711134402_item	2752774	et	4	main
artikli	doc_59711134402_item	2752775	et	3	main
soovitega	doc_59711134402_item	2752778	et	4	main
tiina	doc_59711134403_item	2752784	et	4	main
sest	doc_59711134403_item	2752799	et	4	main
ja	doc_59711134403_item	2752808	et	3	main
arvamusega	doc_59711134402_item	2752703	et	3	main
on	doc_59711134402_item	2752713	et	4	main
ka	doc_59711134402_item	2752714	et	3	main
vaja	doc_59711134402_item	2752722	et	4	main
erialat	doc_59711134402_item	2752731	et	4	main
kuulades	doc_59711134402_item	2752732	et	3	main
ma	doc_59711134402_item	2752748	et	3	main
on	doc_59711134402_item	2752757	et	4	main
kes	doc_59711134402_item	2752760	et	4	main
lõpuks	doc_59711134402_item	2752769	et	4	main
ma	doc_59711134402_item	2752770	et	3	main
parimate	doc_59711134402_item	2752777	et	4	main
x	doc_59711134402_item	2752779	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_59711134402_item	2752780	et	4	main
tere	doc_59711134403_item	2752782	et	3	main
lugupeetud	doc_59711134403_item	2752783	et	4	main
ma	doc_59711134403_item	2752786	et	3	main
teile	doc_59711134403_item	2752788	et	4	main
see	doc_59711134403_item	2752800	et	3	main
elu	doc_59711134403_item	2752803	et	4	main
ma	doc_59711134403_item	2752805	et	3	main
väga	doc_59711134403_item	2752809	et	3	main
muidugi	doc_59711134403_item	2752821	et	4	main
tahavad	doc_59711134403_item	2752823	et	3	main
paju	doc_59711134403_item	2752825	et	4	main
paljud	doc_59711134403_item	2752828	et	3	main
et	doc_59711134403_item	2752839	et	3	main
hästi	doc_59711134403_item	2752846	et	3	main
tahaksin	doc_59711134403_item	2752861	et	3	main
ma	doc_59711134403_item	2752868	et	3	main
jäi	doc_59711134403_item	2752872	et	3	main
et	doc_59711134403_item	2752874	et	3	main
erialale	doc_59711134403_item	2752876	et	3	main
aga	doc_59711134403_item	2752922	et	3	main
saa	doc_59711134403_item	2752926	et	4	main
kutsekooli	doc_59711134403_item	2752938	et	4	main
või	doc_59711134403_item	2752939	et	4	main
nad	doc_59711134403_item	2752951	et	3	main
majas	doc_59711134403_item	2752964	et	3	main
autoga	doc_59711134403_item	2752968	et	3	main
aitavad	doc_59711134403_item	2752973	et	4	main
saa	doc_59711134403_item	2752986	et	4	main
väike	doc_59711134403_item	2753001	et	4	main
vanemaid	doc_59711134402_item	2752733	et	4	main
tundub	doc_59711134402_item	2752737	et	3	main
elus	doc_59711134402_item	2752747	et	4	main
teie	doc_59711134402_item	2752751	et	4	main
meie	doc_59711134402_item	2752754	et	4	main
riigil	doc_59711134402_item	2752756	et	3	main
inimesed	doc_59711134402_item	2752759	et	3	main
ja	doc_59711134402_item	2752763	et	3	main
meie	doc_59711134402_item	2752766	et	4	main
riik	doc_59711134402_item	2752767	et	3	main
eest	doc_59711134402_item	2752776	et	4	main
on	doc_59711134403_item	2752801	et	4	main
olen	doc_59711134403_item	2752806	et	3	main
mida	doc_59711134403_item	2752812	et	4	main
tahavad	doc_59711134403_item	2752813	et	3	main
paljud	doc_59711134403_item	2752814	et	3	main
abituriendid	doc_59711134403_item	2752815	et	3	main
kui	doc_59711134403_item	2752816	et	3	main
te	doc_59711134403_item	2752817	et	4	main
juba	doc_59711134403_item	2752818	et	3	main
olete	doc_59711134403_item	2752819	et	3	main
rääginud	doc_59711134403_item	2752820	et	4	main
raha	doc_59711134403_item	2752826	et	4	main
ja	doc_59711134403_item	2752827	et	3	main
neis	doc_59711134403_item	2752829	et	4	main
tahavad	doc_59711134403_item	2752830	et	3	main
teenida	doc_59711134403_item	2752831	et	3	main
raha	doc_59711134403_item	2752842	et	4	main
aga	doc_59711134403_item	2752866	et	3	main
see	doc_59711134403_item	2752875	et	3	main
ma	doc_59711134403_item	2752877	et	3	main
saa	doc_59711134403_item	2752879	et	4	main
tahaksid	doc_59711134403_item	2752919	et	4	main
ei	doc_59711134403_item	2752925	et	4	main
kuna	doc_59711134403_item	2752927	et	3	main
ja	doc_59711134403_item	2752950	et	3	main
nad	doc_59711134403_item	2752991	et	3	main
tahavad	doc_59711134403_item	2752993	et	3	main
aga	doc_59711134403_item	2752998	et	3	main
siis	doc_59711134403_item	2753002	et	3	main
saavad	doc_59711134403_item	2753010	et	4	main
raha	doc_59711134403_item	2753012	et	4	main
ma	doc_59711134403_item	2753025	et	3	main
pakkuvad	doc_59711134403_item	2753028	et	4	main
rohkem	doc_59711134403_item	2753029	et	4	main
töid	doc_59711134403_item	2753030	et	3	main
kui	doc_59711134403_item	2753031	et	3	main
neiule	doc_59711134403_item	2753032	et	4	main
oli	doc_59711134403_item	2753046	et	3	main
mulle	doc_59711134403_item	2753051	et	4	main
ma	doc_59711134403_item	2753056	et	3	main
on	doc_59711134403_item	2753061	et	4	main
töö	doc_59711134403_item	2753063	et	4	main
koormust	doc_59711134403_item	2753086	et	4	main
ja	doc_59711134403_item	2753091	et	3	main
ühendab	doc_59711134403_item	2753094	et	3	main
see	doc_59711134403_item	2753095	et	3	main
jne	doc_59711134403_item	2753109	et	4	main
muidugi	doc_59711134403_item	2753121	et	4	main
töö	doc_59711134403_item	2753134	et	4	main
ma	doc_59711134403_item	2753135	et	3	main
valitsuses	doc_59711134403_item	2753138	et	4	main
nägid	doc_59711134403_item	2753139	et	4	main
ja	doc_59711134403_item	2753140	et	3	main
osa	doc_59711134403_item	2753146	et	4	main
parandamiseks	doc_59711134403_item	2753148	et	4	main
hästi	doc_59711134403_item	2753157	et	3	main
tiina	doc_59711134404_item	2753177	et	4	main
tehnika	doc_59711134404_item	2753181	et	4	main
soojustehnika	doc_59711134404_item	2753183	et	4	main
kursuse	doc_59711134404_item	2753186	et	3	main
vastuste	doc_59711134404_item	2753196	et	4	main
aspektidega	doc_59711134404_item	2753197	et	3	main
kes	doc_59711134404_item	2753204	et	4	main
palka	doc_59711134404_item	2753211	et	4	main
oma	doc_59711134404_item	2753213	et	4	main
perekonnale	doc_59711134404_item	2753217	et	4	main
teenida	doc_59711134403_item	2752824	et	3	main
on	doc_59711134403_item	2752843	et	4	main
ka	doc_59711134403_item	2752844	et	3	main
vaja	doc_59711134403_item	2752845	et	4	main
töötada	doc_59711134403_item	2752847	et	3	main
minul	doc_59711134403_item	2752859	et	3	main
minna	doc_59711134403_item	2752862	et	3	main
nägin	doc_59711134403_item	2752869	et	3	main
oma	doc_59711134403_item	2752870	et	4	main
minna	doc_59711134403_item	2752880	et	3	main
ja	doc_59711134403_item	2752881	et	3	main
otsisin	doc_59711134403_item	2752882	et	3	main
teise	doc_59711134403_item	2752883	et	4	main
ja	doc_59711134403_item	2752884	et	3	main
leidsin	doc_59711134403_item	2752885	et	3	main
kus	doc_59711134403_item	2752886	et	3	main
ma	doc_59711134403_item	2752887	et	3	main
praegu	doc_59711134403_item	2752888	et	3	main
õpin	doc_59711134403_item	2752889	et	3	main
ma	doc_59711134403_item	2752890	et	3	main
arvan	doc_59711134403_item	2752891	et	3	main
et	doc_59711134403_item	2752892	et	3	main
mulle	doc_59711134403_item	2752893	et	4	main
väga	doc_59711134403_item	2752894	et	3	main
vedas	doc_59711134403_item	2752895	et	4	main
aga	doc_59711134403_item	2752896	et	3	main
mis	doc_59711134403_item	2752897	et	4	main
hakkavad	doc_59711134403_item	2752898	et	4	main
teha	doc_59711134403_item	2752899	et	3	main
need	doc_59711134403_item	2752900	et	3	main
kes	doc_59711134403_item	2752901	et	4	main
ei	doc_59711134403_item	2752902	et	4	main
saa	doc_59711134403_item	2752903	et	4	main
tunnistust	doc_59711134403_item	2752904	et	4	main
ja	doc_59711134403_item	2752905	et	3	main
ootavad	doc_59711134403_item	2752906	et	4	main
järgmist	doc_59711134403_item	2752907	et	3	main
aastat	doc_59711134403_item	2752908	et	3	main
või	doc_59711134403_item	2752909	et	4	main
need	doc_59711134403_item	2752910	et	3	main
kes	doc_59711134403_item	2752911	et	4	main
sai	doc_59711134403_item	2752912	et	4	main
halva	doc_59711134403_item	2752913	et	4	main
tulemust	doc_59711134403_item	2752914	et	4	main
aga	doc_59711134403_item	2752915	et	3	main
nad	doc_59711134403_item	2752918	et	3	main
ülikooli	doc_59711134403_item	2752921	et	4	main
näiteks	doc_59711134403_item	2752937	et	4	main
on	doc_59711134403_item	2752943	et	4	main
selge	doc_59711134403_item	2752944	et	4	main
et	doc_59711134403_item	2752945	et	3	main
see	doc_59711134403_item	2752946	et	3	main
nendele	doc_59711134403_item	2752947	et	4	main
endale	doc_59711134403_item	2752953	et	4	main
parimat	doc_59711134403_item	2752954	et	4	main
on	doc_59711134403_item	2752956	et	4	main
selge	doc_59711134403_item	2752957	et	4	main
et	doc_59711134403_item	2752958	et	3	main
abituriendid	doc_59711134403_item	2752959	et	3	main
tahavad	doc_59711134403_item	2752960	et	3	main
ka	doc_59711134403_item	2752961	et	3	main
elada	doc_59711134403_item	2752962	et	3	main
sõita	doc_59711134403_item	2752966	et	3	main
on	doc_59711134403_item	2752969	et	4	main
tore	doc_59711134403_item	2752970	et	3	main
kui	doc_59711134403_item	2752971	et	3	main
vanemad	doc_59711134403_item	2752972	et	4	main
autot	doc_59711134403_item	2752976	et	3	main
endale	doc_59711134403_item	2752987	et	4	main
seda	doc_59711134403_item	2752988	et	3	main
väga	doc_59711134403_item	2752992	et	3	main
töötavad	doc_59711134403_item	2752996	et	4	main
palk	doc_59711134403_item	2752999	et	3	main
on	doc_59711134403_item	2753003	et	4	main
kahetsetav	doc_59711134403_item	2753005	et	4	main
mõnedainult	doc_59711134403_item	2753007	et	4	main
rohkem	doc_59711134403_item	2753011	et	4	main
ma	doc_59711134403_item	2753013	et	3	main
saa	doc_59711134403_item	2753015	et	4	main
ole	doc_59711134403_item	2753022	et	4	main
tean	doc_59711134403_item	2753026	et	3	main
otsin	doc_59711134403_item	2753038	et	3	main
väga	doc_59711134403_item	2753047	et	3	main
töö	doc_59711134403_item	2753053	et	4	main
aga	doc_59711134403_item	2753055	et	3	main
raske	doc_59711134403_item	2753062	et	4	main
suurt	doc_59711134403_item	2753085	et	3	main
näiteks	doc_59711134403_item	2753087	et	4	main
lendurid	doc_59711134403_item	2753090	et	3	main
head	doc_59711134403_item	2753113	et	4	main
lugesid	doc_59711134403_item	2753141	et	4	main
teie	doc_59711134403_item	2753142	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_59711134403_item	2753174	et	4	main
mina	doc_59711134404_item	2753179	et	4	main
valdkonna	doc_59711134404_item	2753184	et	4	main
esimese	doc_59711134404_item	2753185	et	3	main
tudeng	doc_59711134404_item	2753187	et	3	main
läbi	doc_59711134404_item	2753189	et	4	main
olen	doc_59711134404_item	2753192	et	3	main
nõus	doc_59711134404_item	2753193	et	4	main
paljude	doc_59711134404_item	2753194	et	3	main
minul	doc_59711134404_item	2753199	et	3	main
soovivad	doc_59711134404_item	2753205	et	4	main
saada	doc_59711134404_item	2753209	et	4	main
praegu	doc_59711134403_item	2752924	et	3	main
tasulistele	doc_59711134403_item	2752928	et	4	main
on	doc_59711134403_item	2752930	et	4	main
ka	doc_59711134403_item	2752931	et	3	main
praegu	doc_59711134403_item	2752932	et	3	main
järjekord	doc_59711134403_item	2752933	et	3	main
siis	doc_59711134403_item	2752934	et	3	main
nad	doc_59711134403_item	2752935	et	3	main
tulevad	doc_59711134403_item	2752936	et	4	main
avatude	doc_59711134403_item	2752940	et	4	main
ülikooli	doc_59711134403_item	2752941	et	4	main
aga	doc_59711134403_item	2752942	et	3	main
meeldi	doc_59711134403_item	2752949	et	4	main
oma	doc_59711134403_item	2752963	et	4	main
neile	doc_59711134403_item	2752974	et	4	main
korterid	doc_59711134403_item	2752977	et	3	main
muud	doc_59711134403_item	2752979	et	4	main
need	doc_59711134403_item	2752983	et	3	main
kes	doc_59711134403_item	2752984	et	4	main
ei	doc_59711134403_item	2752985	et	4	main
ja	doc_59711134403_item	2752994	et	3	main
istuvad	doc_59711134403_item	2753008	et	4	main
ja	doc_59711134403_item	2753009	et	3	main
aru	doc_59711134403_item	2753016	et	4	main
miks	doc_59711134403_item	2753017	et	4	main
noormehed	doc_59711134403_item	2753018	et	3	main
et	doc_59711134403_item	2753020	et	3	main
nuttavad	doc_59711134403_item	2753019	et	4	main
ei	doc_59711134403_item	2753021	et	4	main
meie	doc_59711134403_item	2753044	et	4	main
tööd	doc_59711134403_item	2753049	et	4	main
muidugi	doc_59711134403_item	2753050	et	4	main
et	doc_59711134403_item	2753059	et	3	main
tesied	doc_59711134403_item	2753092	et	4	main
neid	doc_59711134403_item	2753093	et	4	main
üks	doc_59711134403_item	2753096	et	3	main
nende	doc_59711134403_item	2753098	et	4	main
erialas	doc_59711134403_item	2753099	et	3	main
ja	doc_59711134403_item	2753100	et	3	main
teine	doc_59711134403_item	2753101	et	3	main
peavad	doc_59711134403_item	2753110	et	4	main
ainult	doc_59711134403_item	2753112	et	4	main
nendest	doc_59711134403_item	2753116	et	4	main
inimese	doc_59711134403_item	2753118	et	4	main
kui	doc_59711134403_item	2753024	et	3	main
ise	doc_59711134403_item	2753033	et	4	main
olen	doc_59711134403_item	2753034	et	3	main
niisamas	doc_59711134403_item	2753035	et	4	main
situatsioonis	doc_59711134403_item	2753036	et	3	main
kuna	doc_59711134403_item	2753037	et	3	main
linnas	doc_59711134403_item	2753045	et	4	main
tean	doc_59711134403_item	2753058	et	3	main
istuda	doc_59711134403_item	2753064	et	3	main
ühes	doc_59711134403_item	2753065	et	4	main
kohas	doc_59711134403_item	2753066	et	4	main
ja	doc_59711134403_item	2753067	et	3	main
ainult	doc_59711134403_item	2753068	et	4	main
õmblema	doc_59711134403_item	2753069	et	3	main
aga	doc_59711134403_item	2753070	et	3	main
palk	doc_59711134403_item	2753071	et	3	main
ei	doc_59711134403_item	2753072	et	4	main
ole	doc_59711134403_item	2753073	et	4	main
suur	doc_59711134403_item	2753074	et	3	main
muidugi	doc_59711134403_item	2753075	et	4	main
meie	doc_59711134403_item	2753076	et	4	main
riigis	doc_59711134403_item	2753077	et	3	main
on	doc_59711134403_item	2753078	et	4	main
erialad	doc_59711134403_item	2753079	et	3	main
mis	doc_59711134403_item	2753080	et	4	main
vajavad	doc_59711134403_item	2753081	et	4	main
ettevaatlikut	doc_59711134403_item	2753082	et	4	main
ja	doc_59711134403_item	2753083	et	3	main
võtavad	doc_59711134403_item	2753084	et	3	main
ehitajad	doc_59711134403_item	2753089	et	4	main
viga	doc_59711134403_item	2753097	et	4	main
inimene	doc_59711134403_item	2753102	et	3	main
võib	doc_59711134403_item	2753103	et	3	main
surra	doc_59711134403_item	2753104	et	3	main
minu	doc_59711134403_item	2753105	et	3	main
arvates	doc_59711134403_item	2753106	et	4	main
arstina	doc_59711134403_item	2753107	et	3	main
spetsialistid	doc_59711134403_item	2753114	et	3	main
neil	doc_59711134403_item	2753123	et	4	main
peab	doc_59711134403_item	2753124	et	4	main
nad	doc_59711134403_item	2753130	et	3	main
teevad	doc_59711134403_item	2753131	et	3	main
suur	doc_59711134403_item	2753133	et	3	main
et	doc_59711134403_item	2753137	et	3	main
artiklit	doc_59711134403_item	2753143	et	3	main
elu	doc_59711134403_item	2753147	et	4	main
üliõpilastele	doc_59711134403_item	2753149	et	4	main
ja	doc_59711134403_item	2753150	et	3	main
muidugi	doc_59711134403_item	2753151	et	4	main
inimestele	doc_59711134403_item	2753152	et	3	main
kuna	doc_59711134403_item	2753153	et	3	main
12012007	doc_59711134403_item	2753173	et	2	main
lugupeetud	doc_59711134404_item	2753176	et	4	main
küsitluse	doc_59711134404_item	2753195	et	4	main
tööd	doc_59711134404_item	2753208	et	4	main
aega	doc_59711134404_item	2753214	et	4	main
kodule	doc_59711134404_item	2753215	et	3	main
väga	doc_59711134404_item	2753223	et	3	main
ainult	doc_59711134404_item	2753226	et	4	main
ja	doc_59711134404_item	2753228	et	3	main
tööd	doc_59711134404_item	2753235	et	4	main
ja	doc_59711134404_item	2753236	et	3	main
liisida	doc_59711134404_item	2753237	et	4	main
väikest	doc_59711134404_item	2753241	et	4	main
tudengid	doc_59711134404_item	2753254	et	3	main
saa	doc_59711134404_item	2753256	et	4	main
kogu	doc_59711134404_item	2753263	et	4	main
korraliku	doc_59711134404_item	2753277	et	3	main
endale	doc_59711134404_item	2753282	et	4	main
materiaalselt	doc_59711134404_item	2753284	et	4	main
seega	doc_59711134404_item	2753287	et	4	main
läksin	doc_59711134404_item	2753288	et	3	main
tehnika	doc_59711134404_item	2753289	et	4	main
see	doc_59711134404_item	2753293	et	3	main
mahaanikuna	doc_59711134404_item	2753306	et	4	main
leian	doc_59711134404_item	2753307	et	3	main
ma	doc_59711134404_item	2753308	et	3	main
tööturul	doc_59711134404_item	2753309	et	3	main
kodu	doc_59711134404_item	2753315	et	4	main
nendest	doc_59711134404_item	2753322	et	4	main
kes	doc_59711134404_item	2753324	et	4	main
üldse	doc_59711134404_item	2753325	et	3	main
kuhu	doc_59711134404_item	2753332	et	3	main
minna	doc_59711134404_item	2753334	et	3	main
tööd	doc_59711134404_item	2753337	et	4	main
on	doc_59711134404_item	2753349	et	4	main
talle	doc_59711134404_item	2753358	et	4	main
meeldiks	doc_59711134404_item	2753359	et	3	main
ja	doc_59711134404_item	2753360	et	3	main
pärast	doc_59711134404_item	2753361	et	4	main
tulemused	doc_59711134404_item	2753371	et	3	main
tähenda	doc_59711134404_item	2753373	et	4	main
saab	doc_59711134404_item	2753381	et	3	main
endale	doc_59711134404_item	2753383	et	4	main
seega	doc_59711134404_item	2753385	et	4	main
tuleb	doc_59711134404_item	2753386	et	3	main
ebastabiilsus	doc_59711134404_item	2753387	et	4	main
ja	doc_59711134404_item	2753388	et	3	main
niisugune	doc_59711134404_item	2753389	et	3	main
positsioon	doc_59711134404_item	2753390	et	3	main
mis	doc_59711134404_item	2753395	et	4	main
palk	doc_59711134403_item	2753122	et	3	main
olema	doc_59711134403_item	2753125	et	4	main
loodan	doc_59711134403_item	2753136	et	3	main
ning	doc_59711134403_item	2753144	et	3	main
kõik	doc_59711134403_item	2753154	et	4	main
tahavad	doc_59711134403_item	2753155	et	3	main
elada	doc_59711134403_item	2753156	et	3	main
ja	doc_59711134403_item	2753158	et	3	main
keegi	doc_59711134403_item	2753159	et	4	main
ei	doc_59711134403_item	2753160	et	4	main
taha	doc_59711134403_item	2753161	et	4	main
olla	doc_59711134403_item	2753162	et	3	main
vaeseks	doc_59711134403_item	2753163	et	4	main
suur	doc_59711134403_item	2753164	et	3	main
aitäh	doc_59711134403_item	2753165	et	3	main
teile	doc_59711134403_item	2753166	et	4	main
et	doc_59711134403_item	2753167	et	3	main
puudutasite	doc_59711134403_item	2753168	et	3	main
seda	doc_59711134403_item	2753169	et	3	main
probleemi	doc_59711134403_item	2753170	et	4	main
lugupidamisega	doc_59711134403_item	2753171	et	3	main
x	doc_59711134403_item	2753172	et	4	main
suurem	doc_59711134403_item	2753126	et	4	main
kui	doc_59711134403_item	2753127	et	3	main
praegu	doc_59711134403_item	2753128	et	3	main
sest	doc_59711134403_item	2753129	et	4	main
väga	doc_59711134403_item	2753132	et	3	main
võttavad	doc_59711134403_item	2753145	et	4	main
kiri	doc_59711134404_item	2753175	et	3	main
kaalep	doc_59711134404_item	2753178	et	4	main
on	doc_59711134404_item	2753200	et	4	main
palju	doc_59711134404_item	2753202	et	4	main
tuttavaid	doc_59711134404_item	2753203	et	3	main
meeldivat	doc_59711134404_item	2753207	et	4	main
pühendada	doc_59711134404_item	2753212	et	3	main
ja	doc_59711134404_item	2753216	et	3	main
unistus	doc_59711134404_item	2753222	et	4	main
sooviks	doc_59711134404_item	2753227	et	4	main
ei	doc_59711134404_item	2753229	et	4	main
realiseeru	doc_59711134404_item	2753230	et	4	main
auto	doc_59711134404_item	2753238	et	4	main
ei	doc_59711134404_item	2753255	et	4	main
endale	doc_59711134404_item	2753257	et	4	main
lubada	doc_59711134404_item	2753258	et	3	main
näidisena	doc_59711134404_item	2753259	et	3	main
võin	doc_59711134404_item	2753260	et	3	main
oma	doc_59711134404_item	2753264	et	4	main
elu	doc_59711134404_item	2753265	et	4	main
tahtsin	doc_59711134404_item	2753266	et	3	main
audenteses	doc_59711134404_item	2753267	et	4	main
ülikooli	doc_59711134404_item	2753290	et	4	main
seda	doc_59711134404_item	2753298	et	3	main
kohta	doc_59711134404_item	2753310	et	4	main
et	doc_59711134404_item	2753311	et	3	main
saada	doc_59711134404_item	2753312	et	4	main
normaalset	doc_59711134404_item	2753313	et	3	main
palka	doc_59711134404_item	2753314	et	4	main
teie	doc_59711134404_item	2753319	et	4	main
noorinimestest	doc_59711134404_item	2753323	et	3	main
eluga	doc_59711134404_item	2753330	et	3	main
teha	doc_59711134404_item	2753331	et	3	main
ja	doc_59711134404_item	2753335	et	3	main
olen	doc_59711134404_item	2753339	et	3	main
palju	doc_59711134404_item	2753343	et	4	main
sõltub	doc_59711134404_item	2753344	et	3	main
eksamitulemustest	doc_59711134404_item	2753345	et	4	main
kui	doc_59711134404_item	2753346	et	3	main
ka	doc_59711134404_item	2753362	et	3	main
palgast	doc_59711134404_item	2753366	et	4	main
teiselt	doc_59711134404_item	2753368	et	4	main
külelt	doc_59711134404_item	2753369	et	4	main
ei	doc_59711134404_item	2753372	et	4	main
saamine	doc_59711134404_item	2753376	et	4	main
on	doc_59711134404_item	2753377	et	4	main
seda	doc_59711134404_item	2753382	et	3	main
lubada	doc_59711134404_item	2753384	et	3	main
et	doc_59711134404_item	2753391	et	3	main
las	doc_59711134404_item	2753392	et	4	main
homme	doc_59711134404_item	2753396	et	3	main
minu	doc_59711134404_item	2753422	et	3	main
rohkem	doc_59711134404_item	2753433	et	4	main
kompeteensemaid	doc_59711134404_item	2753434	et	4	main
elu	doc_59711134404_item	2753442	et	4	main
eestis	doc_59711134404_item	2753443	et	3	main
parimate	doc_59711134404_item	2753446	et	4	main
olen	doc_59711134404_item	2753180	et	3	main
ülikooli	doc_59711134404_item	2753182	et	4	main
lugesin	doc_59711134404_item	2753188	et	3	main
teie	doc_59711134404_item	2753190	et	4	main
artikli	doc_59711134404_item	2753191	et	3	main
esiteks	doc_59711134404_item	2753198	et	3	main
hästi	doc_59711134404_item	2753201	et	3	main
leida	doc_59711134404_item	2753206	et	3	main
normaalset	doc_59711134404_item	2753210	et	3	main
kahjuks	doc_59711134404_item	2753219	et	4	main
soov	doc_59711134404_item	2753220	et	3	main
jäävad	doc_59711134404_item	2753225	et	4	main
kodu	doc_59711134404_item	2753242	et	4	main
tuua	doc_59711134404_item	2753261	et	3	main
tööd	doc_59711134404_item	2753275	et	4	main
saanud	doc_59711134404_item	2753281	et	4	main
mehaanika	doc_59711134404_item	2753291	et	4	main
osakonda	doc_59711134404_item	2753292	et	4	main
oli	doc_59711134404_item	2753294	et	3	main
vanemad	doc_59711134404_item	2753300	et	4	main
said	doc_59711134404_item	2753301	et	4	main
endale	doc_59711134404_item	2753302	et	4	main
lubada	doc_59711134404_item	2753303	et	3	main
vaevalt	doc_59711134404_item	2753304	et	4	main
et	doc_59711134404_item	2753305	et	3	main
oma	doc_59711134404_item	2753317	et	4	main
samuti	doc_59711134404_item	2753320	et	3	main
ei	doc_59711134404_item	2753326	et	4	main
tea	doc_59711134404_item	2753327	et	4	main
teiega	doc_59711134404_item	2753340	et	3	main
et	doc_59711134404_item	2753342	et	3	main
sooritatud	doc_59711134404_item	2753351	et	4	main
siis	doc_59711134404_item	2753352	et	3	main
võib	doc_59711134404_item	2753353	et	3	main
inimene	doc_59711134404_item	2753354	et	3	main
unistada	doc_59711134404_item	2753355	et	3	main
erialast	doc_59711134404_item	2753356	et	4	main
tööst	doc_59711134404_item	2753363	et	3	main
kuid	doc_59711134404_item	2753367	et	4	main
tasuta	doc_59711134404_item	2753378	et	4	main
elu	doc_59711134404_item	2753393	et	4	main
näitab	doc_59711134404_item	2753394	et	3	main
oli	doc_59711134404_item	2753421	et	3	main
poliitika	doc_59711134404_item	2753439	et	4	main
lihtsam	doc_59711134404_item	2753445	et	4	main
kuid	doc_59711134404_item	2753218	et	4	main
ja	doc_59711134404_item	2753221	et	3	main
sest	doc_59711134404_item	2753231	et	4	main
korraliku	doc_59711134404_item	2753234	et	3	main
või	doc_59711134404_item	2753239	et	4	main
selleks	doc_59711134404_item	2753243	et	4	main
tuleb	doc_59711134404_item	2753244	et	3	main
omandada	doc_59711134404_item	2753245	et	3	main
kõrgharidust	doc_59711134404_item	2753246	et	4	main
et	doc_59711134404_item	2753262	et	3	main
suhteid	doc_59711134404_item	2753269	et	3	main
õppida	doc_59711134404_item	2753270	et	3	main
et	doc_59711134404_item	2753271	et	3	main
ja	doc_59711134404_item	2753276	et	3	main
palgaga	doc_59711134404_item	2753278	et	3	main
ei	doc_59711134404_item	2753280	et	4	main
seda	doc_59711134404_item	2753283	et	3	main
lubada	doc_59711134404_item	2753285	et	3	main
minu	doc_59711134404_item	2753299	et	3	main
liisimiseks	doc_59711134404_item	2753316	et	4	main
artiklis	doc_59711134404_item	2753318	et	3	main
kirjutate	doc_59711134404_item	2753321	et	3	main
oma	doc_59711134404_item	2753329	et	4	main
õppima	doc_59711134404_item	2753333	et	3	main
millist	doc_59711134404_item	2753336	et	3	main
korralikult	doc_59711134404_item	2753350	et	4	main
heast	doc_59711134404_item	2753365	et	3	main
et	doc_59711134404_item	2753374	et	3	main
kõrghariduse	doc_59711134404_item	2753375	et	3	main
inimene	doc_59711134404_item	2753380	et	3	main
jaoks	doc_59711134404_item	2753423	et	4	main
nõustan	doc_59711134404_item	2753426	et	3	main
teiega	doc_59711134404_item	2753427	et	3	main
et	doc_59711134404_item	2753428	et	3	main
kuid	doc_59711134404_item	2753429	et	4	main
meditsiini	doc_59711134404_item	2753436	et	4	main
hariduse	doc_59711134404_item	2753437	et	3	main
ja	doc_59711134404_item	2753438	et	3	main
siis	doc_59711134404_item	2753441	et	3	main
x	doc_59711134404_item	2753448	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_59711134404_item	2753449	et	4	main
sageli	doc_59711134404_item	2753224	et	3	main
et	doc_59711134404_item	2753232	et	3	main
leida	doc_59711134404_item	2753233	et	3	main
isegi	doc_59711134404_item	2753240	et	4	main
kuid	doc_59711134404_item	2753247	et	4	main
kõrghariduse	doc_59711134404_item	2753248	et	3	main
saamine	doc_59711134404_item	2753249	et	4	main
nõuab	doc_59711134404_item	2753250	et	3	main
raha	doc_59711134404_item	2753251	et	4	main
mida	doc_59711134404_item	2753252	et	4	main
paljud	doc_59711134404_item	2753253	et	3	main
rahvusvahelisi	doc_59711134404_item	2753268	et	4	main
pärast	doc_59711134404_item	2753272	et	4	main
leida	doc_59711134404_item	2753273	et	3	main
korraliku	doc_59711134404_item	2753274	et	3	main
kuid	doc_59711134404_item	2753279	et	4	main
ja	doc_59711134404_item	2753286	et	3	main
palju	doc_59711134404_item	2753295	et	4	main
odavam	doc_59711134404_item	2753296	et	4	main
ja	doc_59711134404_item	2753297	et	3	main
mida	doc_59711134404_item	2753328	et	4	main
saada	doc_59711134404_item	2753338	et	4	main
nõus	doc_59711134404_item	2753341	et	4	main
kõik	doc_59711134404_item	2753347	et	4	main
eksamid	doc_59711134404_item	2753348	et	3	main
mis	doc_59711134404_item	2753357	et	4	main
ja	doc_59711134404_item	2753364	et	3	main
head	doc_59711134404_item	2753370	et	4	main
ja	doc_59711134404_item	2753379	et	3	main
saab	doc_59711134404_item	2753397	et	3	main
ja	doc_59711134404_item	2753398	et	3	main
siis	doc_59711134404_item	2753399	et	3	main
teen	doc_59711134404_item	2753400	et	3	main
oma	doc_59711134404_item	2753401	et	4	main
valiku	doc_59711134404_item	2753402	et	3	main
lõpuks	doc_59711134404_item	2753403	et	4	main
mainite	doc_59711134404_item	2753405	et	3	main
teie	doc_59711134404_item	2753404	et	4	main
kolamanda	doc_59711134404_item	2753406	et	4	main
rühma	doc_59711134404_item	2753407	et	4	main
küsitlejatest	doc_59711134404_item	2753408	et	4	main
kes	doc_59711134404_item	2753409	et	4	main
soovivad	doc_59711134404_item	2753410	et	4	main
leida	doc_59711134404_item	2753411	et	3	main
tööd	doc_59711134404_item	2753412	et	4	main
sotsiaaltöötajana	doc_59711134404_item	2753413	et	3	main
või	doc_59711134404_item	2753414	et	4	main
keskonnakaitsejana	doc_59711134404_item	2753415	et	4	main
ütlen	doc_59711134404_item	2753416	et	3	main
ausalt	doc_59711134404_item	2753417	et	4	main
et	doc_59711134404_item	2753418	et	3	main
niisugune	doc_59711134404_item	2753419	et	3	main
vastus	doc_59711134404_item	2753420	et	3	main
meie	doc_59711134404_item	2753430	et	4	main
riigis	doc_59711134404_item	2753431	et	3	main
oleks	doc_59711134404_item	2753432	et	3	main
oleks	doc_59711134404_item	2753444	et	3	main
üllatuseks	doc_59711134404_item	2753424	et	4	main
kuid	doc_59711134404_item	2753425	et	4	main
töötajaid	doc_59711134404_item	2753435	et	4	main
valdkonnas	doc_59711134404_item	2753440	et	4	main
soovidega	doc_59711134404_item	2753447	et	3	main
hollandiga	doc_59711134410_item	2754461	et	4	main
ma	doc_59711134410_item	2754462	et	3	main
osalesin	doc_59711134410_item	2754463	et	3	main
tulid	doc_59711134410_item	2754467	et	4	main
olid	doc_59711134410_item	2754471	et	4	main
meie	doc_59711134410_item	2754472	et	4	main
pidime	doc_59711134410_item	2754478	et	3	main
külas	doc_59711134410_item	2754485	et	3	main
sõbrannal	doc_59711134410_item	2754487	et	3	main
talvel	doc_59711134410_item	2754490	et	4	main
iga	doc_59711134410_item	2754493	et	4	main
jaoks	doc_59711134410_item	2754496	et	4	main
näiteks	doc_59711134410_item	2754501	et	4	main
esimesel	doc_59711134410_item	2754502	et	3	main
päeval	doc_59711134410_item	2754503	et	3	main
koolis	doc_59711134410_item	2754507	et	4	main
k	doc_59711134410_item	2754442	et	4	main
olen	doc_59711134410_item	2754446	et	3	main
aastat	doc_59711134410_item	2754449	et	3	main
siis	doc_59711134410_item	2754451	et	3	main
ma	doc_59711134410_item	2754453	et	3	main
kümnendas	doc_59711134410_item	2754455	et	3	main
koolis	doc_59711134410_item	2754458	et	4	main
toimus	doc_59711134410_item	2754459	et	3	main
õpilastevahetus	doc_59711134410_item	2754460	et	4	main
juures	doc_59711134410_item	2754473	et	4	main
nädala	doc_59711134410_item	2754474	et	3	main
olin	doc_59711134410_item	2754484	et	3	main
olid	doc_59711134410_item	2754497	et	4	main
me	doc_59711134410_item	2754504	et	4	main
olime	doc_59711134410_item	2754505	et	3	main
õppeainet	doc_59711134410_item	2754523	et	3	main
keel	doc_59711134410_item	2754525	et	4	main
gochi	doc_59711134410_item	2754543	et	4	main
keeles	doc_59711134410_item	2754548	et	4	main
see	doc_59711134410_item	2754568	et	3	main
et	doc_59711134410_item	2754570	et	3	main
pere	doc_59711134410_item	2754572	et	4	main
pidi	doc_59711134410_item	2754573	et	4	main
näitama	doc_59711134410_item	2754574	et	3	main
rohkem	doc_59711134410_item	2754579	et	4	main
väga	doc_59711134410_item	2754590	et	3	main
veekanaleid	doc_59711134410_item	2754604	et	4	main
sõime	doc_59711134410_item	2754618	et	4	main
oli	doc_59711134410_item	2754624	et	3	main
tegin	doc_59711134410_item	2754630	et	3	main
tihti	doc_59711134410_item	2754633	et	3	main
mulle	doc_59711134410_item	2754638	et	4	main
meeldib	doc_59711134410_item	2754639	et	3	main
seda	doc_59711134410_item	2754642	et	3	main
kiiresti	doc_59711134410_item	2754649	et	3	main
mööda	doc_59711134410_item	2754650	et	4	main
oli	doc_59711134410_item	2754651	et	3	main
ja	doc_59711134410_item	2754663	et	3	main
tutvustusena	doc_59711134410_item	2754664	et	4	main
unustamatu	doc_59711134410_item	2754672	et	4	main
et	doc_59711134410_item	2754676	et	3	main
olen	doc_59711134410_item	2754441	et	3	main
klassis	doc_59711134410_item	2754456	et	3	main
selles	doc_59711134410_item	2754464	et	4	main
aega	doc_59711134410_item	2754475	et	4	main
aprillis	doc_59711134410_item	2754476	et	3	main
me	doc_59711134410_item	2754477	et	4	main
lendama	doc_59711134410_item	2754479	et	3	main
oma	doc_59711134410_item	2754486	et	4	main
kes	doc_59711134410_item	2754488	et	4	main
oli	doc_59711134410_item	2754521	et	3	main
hollandi	doc_59711134410_item	2754524	et	4	main
muusika	doc_59711134410_item	2754526	et	4	main
joonistamine	doc_59711134410_item	2754527	et	4	main
ja	doc_59711134410_item	2754528	et	3	main
pillede	doc_59711134410_item	2754539	et	4	main
natukene	doc_59711134410_item	2754545	et	4	main
rääkisime	doc_59711134410_item	2754546	et	3	main
teisel	doc_59711134410_item	2754549	et	4	main
sõitsime	doc_59711134410_item	2754552	et	3	main
ja	doc_59711134410_item	2754563	et	3	main
päevad	doc_59711134410_item	2754565	et	3	main
tähendab	doc_59711134410_item	2754569	et	3	main
seal	doc_59711134410_item	2754588	et	4	main
veel	doc_59711134410_item	2754592	et	4	main
utrehti	doc_59711134410_item	2754594	et	4	main
sõitsime	doc_59711134410_item	2754598	et	3	main
seal	doc_59711134410_item	2754605	et	4	main
lossis	doc_59711134410_item	2754612	et	4	main
me	doc_59711134410_item	2754614	et	4	main
bouwlingut	doc_59711134410_item	2754616	et	4	main
ja	doc_59711134410_item	2754617	et	3	main
pankooke	doc_59711134410_item	2754621	et	4	main
päeval	doc_59711134410_item	2754623	et	3	main
ma	doc_59711134410_item	2754629	et	3	main
läbi	doc_59711134410_item	2754637	et	4	main
meelde	doc_59711134410_item	2754640	et	3	main
tuletada	doc_59711134410_item	2754641	et	3	main
arä	doc_59711134410_item	2754654	et	4	main
huvitav	doc_59711134410_item	2754670	et	4	main
ja	doc_59711134410_item	2754671	et	3	main
essee	doc_59711134410_item	2754439	et	4	main
näinud	doc_59711134410_item	2754447	et	4	main
hollandlased	doc_59711134410_item	2754466	et	3	main
jaanuaris	doc_59711134410_item	2754469	et	3	main
nad	doc_59711134410_item	2754470	et	3	main
hollandisse	doc_59711134410_item	2754480	et	4	main
ka	doc_59711134410_item	2754481	et	3	main
nädalaks	doc_59711134410_item	2754482	et	3	main
mina	doc_59711134410_item	2754483	et	4	main
oli	doc_59711134410_item	2754489	et	3	main
juures	doc_59711134410_item	2754492	et	4	main
päev	doc_59711134410_item	2754494	et	3	main
meie	doc_59711134410_item	2754495	et	4	main
meelelahutused	doc_59711134410_item	2754500	et	4	main
keemia	doc_59711134410_item	2754529	et	4	main
väga	doc_59711134410_item	2754532	et	3	main
tegime	doc_59711134410_item	2754534	et	3	main
palju	doc_59711134410_item	2754535	et	4	main
eksperimente	doc_59711134410_item	2754536	et	3	main
mängisime	doc_59711134410_item	2754537	et	3	main
erinevate	doc_59711134410_item	2754538	et	4	main
maale	doc_59711134410_item	2754544	et	4	main
me	doc_59711134410_item	2754551	et	4	main
kohtus	doc_59711134410_item	2754561	et	4	main
kolmas	doc_59711134410_item	2754562	et	3	main
neljas	doc_59711134410_item	2754564	et	4	main
kõige	doc_59711134410_item	2754578	et	4	main
see	doc_59711134410_item	2754583	et	3	main
nagu	doc_59711134410_item	2754585	et	3	main
üks	doc_59711134410_item	2754610	et	3	main
lossis	doc_59711134410_item	2754613	et	4	main
mängisime	doc_59711134410_item	2754615	et	3	main
disco-pidu	doc_59711134410_item	2754627	et	4	main
palju	doc_59711134410_item	2754631	et	4	main
reisi	doc_59711134410_item	2754643	et	4	main
seitse	doc_59711134410_item	2754645	et	3	main
minna	doc_59711134410_item	2754655	et	3	main
see	doc_59711134410_item	2754656	et	3	main
vahetus	doc_59711134410_item	2754657	et	4	main
oli	doc_59711134410_item	2754658	et	3	main
keeles	doc_59711134410_item	2754662	et	4	main
teise	doc_59711134410_item	2754665	et	4	main
kus	doc_59711134410_item	2754440	et	3	main
äinud	doc_59711134410_item	2754443	et	4	main
ja	doc_59711134410_item	2754444	et	3	main
mida	doc_59711134410_item	2754445	et	4	main
kolm	doc_59711134410_item	2754448	et	3	main
tagasi	doc_59711134410_item	2754450	et	3	main
kui	doc_59711134410_item	2754452	et	3	main
käisin	doc_59711134410_item	2754454	et	3	main
meie	doc_59711134410_item	2754457	et	4	main
ka	doc_59711134410_item	2754465	et	3	main
eestisse	doc_59711134410_item	2754468	et	4	main
minu	doc_59711134410_item	2754491	et	3	main
plaanitud	doc_59711134410_item	2754498	et	4	main
erinevad	doc_59711134410_item	2754499	et	4	main
nendes	doc_59711134410_item	2754506	et	4	main
ja	doc_59711134410_item	2754508	et	3	main
tutvusime	doc_59711134410_item	2754509	et	4	main
neide	doc_59711134410_item	2754510	et	3	main
kultuuriga	doc_59711134410_item	2754511	et	4	main
sellel	doc_59711134410_item	2754512	et	4	main
päeval	doc_59711134410_item	2754513	et	3	main
meil	doc_59711134410_item	2754514	et	4	main
oli	doc_59711134410_item	2754515	et	3	main
tunnid	doc_59711134410_item	2754516	et	3	main
ja	doc_59711134410_item	2754517	et	3	main
me	doc_59711134410_item	2754518	et	4	main
õppisime	doc_59711134410_item	2754519	et	3	main
tunniplaanis	doc_59711134410_item	2754520	et	3	main
oli	doc_59711134410_item	2754531	et	3	main
joonistasime	doc_59711134410_item	2754541	et	3	main
hollandi	doc_59711134410_item	2754547	et	4	main
seal	doc_59711134410_item	2754554	et	4	main
palju	doc_59711134410_item	2754555	et	4	main
olid	doc_59711134410_item	2754566	et	4	main
hollandi	doc_59711134410_item	2754571	et	4	main
ise	doc_59711134410_item	2754575	et	4	main
mulle	doc_59711134410_item	2754580	et	4	main
meeldis	doc_59711134410_item	2754581	et	3	main
on	doc_59711134410_item	2754584	et	4	main
ilus	doc_59711134410_item	2754591	et	4	main
viiendal	doc_59711134410_item	2754596	et	3	main
amsterdaammi	doc_59711134410_item	2754599	et	4	main
seal	doc_59711134410_item	2754600	et	4	main
sõitsime	doc_59711134410_item	2754601	et	3	main
paadiga	doc_59711134410_item	2754602	et	3	main
mööda	doc_59711134410_item	2754603	et	4	main
oli	doc_59711134410_item	2754611	et	3	main
seal	doc_59711134410_item	2754619	et	4	main
neli	doc_59711134410_item	2754522	et	3	main
päev	doc_59711134410_item	2754530	et	3	main
huvitav	doc_59711134410_item	2754533	et	4	main
pael	doc_59711134410_item	2754540	et	4	main
van	doc_59711134410_item	2754542	et	4	main
päeval	doc_59711134410_item	2754550	et	3	main
haagasse	doc_59711134410_item	2754553	et	4	main
jalutasime	doc_59711134410_item	2754556	et	3	main
ja	doc_59711134410_item	2754557	et	3	main
kõigepealt	doc_59711134410_item	2754558	et	3	main
olime	doc_59711134410_item	2754559	et	3	main
rahvusvahelinses	doc_59711134410_item	2754560	et	4	main
perepäevad	doc_59711134410_item	2754567	et	3	main
midagi	doc_59711134410_item	2754576	et	4	main
huvitavat	doc_59711134410_item	2754577	et	4	main
keukenhof	doc_59711134410_item	2754582	et	4	main
lille	doc_59711134410_item	2754586	et	4	main
park	doc_59711134410_item	2754587	et	3	main
on	doc_59711134410_item	2754589	et	4	main
olin	doc_59711134410_item	2754593	et	3	main
kirikus	doc_59711134410_item	2754595	et	3	main
päeval	doc_59711134410_item	2754597	et	3	main
oli	doc_59711134410_item	2754606	et	3	main
palju	doc_59711134410_item	2754607	et	4	main
ekskursioone	doc_59711134410_item	2754608	et	3	main
ja	doc_59711134410_item	2754609	et	3	main
suuri	doc_59711134410_item	2754620	et	3	main
seal	doc_59711134410_item	2754628	et	4	main
neid	doc_59711134410_item	2754635	et	4	main
kahju	doc_59711134410_item	2754652	et	4	main
mõeldud	doc_59711134410_item	2754659	et	4	main
praaktikana	doc_59711134410_item	2754660	et	3	main
kogemus	doc_59711134410_item	2754673	et	3	main
õnnelik	doc_59711134410_item	2754675	et	3	main
sellise	doc_59711134410_item	2754678	et	4	main
viimasel	doc_59711134410_item	2754622	et	3	main
meie	doc_59711134410_item	2754625	et	4	main
puhul	doc_59711134410_item	2754626	et	4	main
pilte	doc_59711134410_item	2754632	et	3	main
vaatan	doc_59711134410_item	2754634	et	3	main
uuesti	doc_59711134410_item	2754636	et	3	main
need	doc_59711134410_item	2754644	et	3	main
päeva	doc_59711134410_item	2754646	et	4	main
läksid	doc_59711134410_item	2754647	et	4	main
väga	doc_59711134410_item	2754648	et	3	main
hollandist	doc_59711134410_item	2754653	et	4	main
inglise	doc_59711134410_item	2754661	et	4	main
olen	doc_59711134410_item	2754674	et	3	main
kultuuriga	doc_59711134410_item	2754666	et	4	main
see	doc_59711134410_item	2754667	et	3	main
oli	doc_59711134410_item	2754668	et	3	main
väga	doc_59711134410_item	2754669	et	3	main
sain	doc_59711134410_item	2754677	et	3	main
võimaluse	doc_59711134410_item	2754679	et	3	main
kiri	doc_59711134415_item	2755346	et	3	main
ei	doc_59711134415_item	2755353	et	4	main
j	doc_59711134415_item	2755359	et	4	main
komplekteerijana	doc_59711134415_item	2755383	et	4	main
varakult	doc_59711134415_item	2755388	et	4	main
tööle	doc_59711134415_item	2755389	et	3	main
seetõttu	doc_59711134415_item	2755392	et	3	main
ei	doc_59711134415_item	2755393	et	4	main
jõudnud	doc_59711134415_item	2755394	et	4	main
ma	doc_59711134415_item	2755395	et	3	main
paluma	doc_59711134415_item	2755403	et	3	main
töö	doc_59711134415_item	2755406	et	4	main
kindel	doc_59711134415_item	2755418	et	3	main
olnud	doc_59711134415_item	2755354	et	4	main
ärgi	doc_59711134415_item	2755360	et	4	main
kahjuks	doc_59711134415_item	2755384	et	4	main
mõnikord	doc_59711134415_item	2755385	et	3	main
keele	doc_59711134415_item	2755397	et	4	main
ei	doc_59711134415_item	2755407	et	4	main
kui	doc_59711134415_item	2755412	et	3	main
päevaplaani	doc_59711134415_item	2755431	et	4	main
sain	doc_59711134415_item	2755432	et	3	main
ma	doc_59711134415_item	2755433	et	3	main
lõpuks	doc_59711134415_item	2755434	et	4	main
pean	doc_59711134415_item	2755437	et	4	main
töötan	doc_59711134415_item	2755445	et	3	main
sellepärast	doc_59711134415_item	2755458	et	3	main
pidin	doc_59711134415_item	2755461	et	3	main
tööd	doc_59711134415_item	2755476	et	4	main
ja	doc_59711134415_item	2755479	et	3	main
töölepingut	doc_59711134415_item	2755496	et	3	main
katkestama	doc_59711134415_item	2755497	et	3	main
oktoobris	doc_59711134415_item	2755498	et	3	main
oli	doc_59711134415_item	2755499	et	3	main
ka	doc_59711134415_item	2755500	et	3	main
teine	doc_59711134415_item	2755501	et	3	main
ei	doc_59711134415_item	2755505	et	4	main
eesti	doc_59711134415_item	2755507	et	4	main
keele	doc_59711134415_item	2755508	et	4	main
tunnis	doc_59711134415_item	2755509	et	3	main
suurepärane	doc_59711134415_item	2755521	et	4	main
mis	doc_59711134415_item	2755535	et	4	main
mäest	doc_59711134415_item	2755546	et	3	main
ma	doc_59711134415_item	2755551	et	3	main
puudumise	doc_59711134415_item	2755566	et	4	main
ja	doc_59711134415_item	2755568	et	3	main
loodan	doc_59711134415_item	2755569	et	3	main
selgitused	doc_59711134415_item	2755572	et	4	main
teie	doc_59711134415_item	2755583	et	4	main
ma	doc_59711134415_item	2755348	et	3	main
olen	doc_59711134415_item	2755349	et	3	main
teinud	doc_59711134415_item	2755350	et	4	main
keele	doc_59711134415_item	2755356	et	4	main
tunnis	doc_59711134415_item	2755357	et	3	main
eesti	doc_59711134415_item	2755396	et	4	main
pärast	doc_59711134415_item	2755401	et	4	main
tean	doc_59711134415_item	2755404	et	3	main
või	doc_59711134415_item	2755408	et	4	main
käia	doc_59711134415_item	2755423	et	4	main
pärast	doc_59711134415_item	2755427	et	4	main
aru	doc_59711134415_item	2755435	et	4	main
et	doc_59711134415_item	2755436	et	3	main
et	doc_59711134415_item	2755443	et	3	main
et	doc_59711134415_item	2755459	et	3	main
ületunnitööd	doc_59711134415_item	2755462	et	4	main
tegema	doc_59711134415_item	2755463	et	3	main
minu	doc_59711134415_item	2755464	et	3	main
sõber	doc_59711134415_item	2755465	et	3	main
ütles	doc_59711134415_item	2755466	et	3	main
et	doc_59711134415_item	2755467	et	3	main
kui	doc_59711134415_item	2755468	et	3	main
tegelikult	doc_59711134415_item	2755483	et	4	main
põhjus	doc_59711134415_item	2755502	et	4	main
käinud	doc_59711134415_item	2755506	et	4	main
me	doc_59711134415_item	2755513	et	4	main
sõpradega	doc_59711134415_item	2755514	et	3	main
kuid	doc_59711134415_item	2755522	et	4	main
bobisõidu	doc_59711134415_item	2755537	et	4	main
alla	doc_59711134415_item	2755547	et	3	main
veel	doc_59711134415_item	2755562	et	4	main
vabandust	doc_59711134415_item	2755564	et	4	main
minu	doc_59711134415_item	2755571	et	3	main
mõnikord	doc_59711134415_item	2755581	et	3	main
mida	doc_59711134415_item	2755347	et	4	main
eesti	doc_59711134415_item	2755355	et	4	main
olid	doc_59711134415_item	2755361	et	4	main
puudumise	doc_59711134415_item	2755400	et	4	main
õppimast	doc_59711134415_item	2755409	et	3	main
kuid	doc_59711134415_item	2755411	et	4	main
ma	doc_59711134415_item	2755413	et	3	main
alla	doc_59711134415_item	2755415	et	3	main
olin	doc_59711134415_item	2755417	et	3	main
et	doc_59711134415_item	2755419	et	3	main
kui	doc_59711134415_item	2755351	et	3	main
mind	doc_59711134415_item	2755352	et	4	main
tunniplaani	doc_59711134415_item	2755358	et	4	main
meil	doc_59711134415_item	2755362	et	4	main
eesti	doc_59711134415_item	2755363	et	4	main
keele	doc_59711134415_item	2755364	et	4	main
tunnid	doc_59711134415_item	2755365	et	3	main
teisipäevati	doc_59711134415_item	2755366	et	3	main
kell	doc_59711134415_item	2755367	et	3	main
1400	doc_59711134415_item	2755368	et	2	main
septembris	doc_59711134415_item	2755369	et	3	main
käisin	doc_59711134415_item	2755370	et	3	main
ma	doc_59711134415_item	2755371	et	3	main
igas	doc_59711134415_item	2755372	et	3	main
tunnis	doc_59711134415_item	2755373	et	3	main
kuid	doc_59711134415_item	2755374	et	4	main
alates	doc_59711134415_item	2755375	et	3	main
oktobrikuust	doc_59711134415_item	2755376	et	4	main
alustasin	doc_59711134415_item	2755377	et	3	main
ma	doc_59711134415_item	2755378	et	3	main
tööd	doc_59711134415_item	2755379	et	4	main
ühes	doc_59711134415_item	2755380	et	4	main
farmaatsiaettevõtes	doc_59711134415_item	2755381	et	3	main
ravimite	doc_59711134415_item	2755382	et	3	main
pidin	doc_59711134415_item	2755386	et	3	main
ma	doc_59711134415_item	2755387	et	3	main
minema	doc_59711134415_item	2755390	et	3	main
ja	doc_59711134415_item	2755391	et	3	main
tundi	doc_59711134415_item	2755398	et	4	main
tahan	doc_59711134415_item	2755399	et	3	main
vabandust	doc_59711134415_item	2755402	et	4	main
et	doc_59711134415_item	2755405	et	3	main
segada	doc_59711134415_item	2755410	et	3	main
töölepingule	doc_59711134415_item	2755414	et	4	main
kirjutasin	doc_59711134415_item	2755416	et	3	main
jõuan	doc_59711134415_item	2755420	et	3	main
nii	doc_59711134415_item	2755421	et	3	main
ka	doc_59711134415_item	2755425	et	3	main
ma	doc_59711134415_item	2755444	et	3	main
vaatamata	doc_59711134415_item	2755448	et	4	main
selline	doc_59711134415_item	2755455	et	4	main
vastuargumente	doc_59711134415_item	2755472	et	3	main
arvestama	doc_59711134415_item	2755473	et	3	main
pean	doc_59711134415_item	2755474	et	4	main
järele	doc_59711134415_item	2755477	et	4	main
õppimist	doc_59711134415_item	2755480	et	4	main
käsile	doc_59711134415_item	2755481	et	4	main
võtma	doc_59711134415_item	2755482	et	3	main
veenis	doc_59711134415_item	2755485	et	4	main
mind	doc_59711134415_item	2755486	et	4	main
oma	doc_59711134415_item	2755487	et	4	main
miks	doc_59711134415_item	2755503	et	4	main
teisel	doc_59711134415_item	2755523	et	4	main
me	doc_59711134415_item	2755527	et	4	main
oli	doc_59711134415_item	2755536	et	3	main
proovinud	doc_59711134415_item	2755544	et	4	main
toost	doc_59711134415_item	2755545	et	3	main
panevad	doc_59711134415_item	2755573	et	4	main
teid	doc_59711134415_item	2755574	et	4	main
uskuma	doc_59711134415_item	2755575	et	3	main
et	doc_59711134415_item	2755576	et	3	main
mul	doc_59711134415_item	2755577	et	3	main
tõesti	doc_59711134415_item	2755578	et	3	main
tööl	doc_59711134415_item	2755422	et	3	main
kaks	doc_59711134415_item	2755428	et	3	main
tunne	doc_59711134415_item	2755442	et	4	main
tunne	doc_59711134415_item	2755456	et	4	main
tekkis	doc_59711134415_item	2755457	et	3	main
mõnikord	doc_59711134415_item	2755460	et	3	main
ma	doc_59711134415_item	2755475	et	3	main
jätma	doc_59711134415_item	2755478	et	3	main
ta	doc_59711134415_item	2755484	et	4	main
oktoobrikuu	doc_59711134415_item	2755510	et	4	main
riigasse	doc_59711134415_item	2755515	et	4	main
puhkama	doc_59711134415_item	2755516	et	3	main
esimesel	doc_59711134415_item	2755517	et	3	main
päeval	doc_59711134415_item	2755518	et	3	main
oli	doc_59711134415_item	2755519	et	3	main
kõik	doc_59711134415_item	2755520	et	4	main
kui	doc_59711134415_item	2755424	et	3	main
õppida	doc_59711134415_item	2755426	et	3	main
kuud	doc_59711134415_item	2755429	et	4	main
pingelist	doc_59711134415_item	2755430	et	4	main
tööd	doc_59711134415_item	2755438	et	4	main
katkestama	doc_59711134415_item	2755439	et	3	main
mul	doc_59711134415_item	2755440	et	3	main
oli	doc_59711134415_item	2755441	et	3	main
kahes	doc_59711134415_item	2755446	et	4	main
vahetuses	doc_59711134415_item	2755447	et	4	main
sellele	doc_59711134415_item	2755449	et	4	main
et	doc_59711134415_item	2755450	et	3	main
töötasin	doc_59711134415_item	2755451	et	3	main
osakoormusega	doc_59711134415_item	2755452	et	3	main
arvan	doc_59711134415_item	2755453	et	3	main
et	doc_59711134415_item	2755454	et	3	main
kõiki	doc_59711134415_item	2755469	et	4	main
poolt-	doc_59711134415_item	2755470	et	4	main
ja	doc_59711134415_item	2755471	et	3	main
õigsuses	doc_59711134415_item	2755488	et	3	main
ja	doc_59711134415_item	2755489	et	3	main
juba	doc_59711134415_item	2755490	et	3	main
järgmisel	doc_59711134415_item	2755491	et	3	main
päeval	doc_59711134415_item	2755492	et	3	main
läksin	doc_59711134415_item	2755493	et	3	main
mina	doc_59711134415_item	2755494	et	4	main
kontorisse	doc_59711134415_item	2755495	et	3	main
ma	doc_59711134415_item	2755504	et	3	main
alguses	doc_59711134415_item	2755511	et	4	main
läksime	doc_59711134415_item	2755512	et	3	main
juhtus	doc_59711134415_item	2755525	et	3	main
õnnetus	doc_59711134415_item	2755526	et	4	main
läksime	doc_59711134415_item	2755528	et	3	main
moodi	doc_59711134415_item	2755538	et	4	main
parem	doc_59711134415_item	2755539	et	4	main
oleks	doc_59711134415_item	2755540	et	3	main
kui	doc_59711134415_item	2755541	et	3	main
ma	doc_59711134415_item	2755542	et	3	main
laskuda	doc_59711134415_item	2755548	et	3	main
lõpuks	doc_59711134415_item	2755550	et	4	main
venitasin	doc_59711134415_item	2755552	et	3	main
jalalihase	doc_59711134415_item	2755553	et	4	main
ära	doc_59711134415_item	2755554	et	4	main
ja	doc_59711134415_item	2755555	et	3	main
pidin	doc_59711134415_item	2755556	et	3	main
kord	doc_59711134415_item	2755563	et	4	main
minu	doc_59711134415_item	2755565	et	3	main
pärast	doc_59711134415_item	2755567	et	4	main
et	doc_59711134415_item	2755570	et	3	main
olnud	doc_59711134415_item	2755580	et	4	main
võimalust	doc_59711134415_item	2755582	et	3	main
päeval	doc_59711134415_item	2755524	et	3	main
lõbustusparki	doc_59711134415_item	2755529	et	4	main
kus	doc_59711134415_item	2755530	et	3	main
mulle	doc_59711134415_item	2755531	et	4	main
meeldis	doc_59711134415_item	2755532	et	3	main
üks	doc_59711134415_item	2755533	et	3	main
atraktsioon	doc_59711134415_item	2755534	et	3	main
ei	doc_59711134415_item	2755543	et	4	main
kuna	doc_59711134415_item	2755549	et	3	main
kaks	doc_59711134415_item	2755557	et	3	main
nädalat	doc_59711134415_item	2755558	et	3	main
voodis	doc_59711134415_item	2755559	et	3	main
lamama	doc_59711134415_item	2755560	et	4	main
palun	doc_59711134415_item	2755561	et	3	main
ei	doc_59711134415_item	2755579	et	4	main
tundides	doc_59711134415_item	2755584	et	3	main
käia	doc_59711134415_item	2755585	et	4	main
ma	doc_59711134418_item	2756021	et	3	main
saada	doc_59711134418_item	2756023	et	4	main
meie	doc_59711134418_item	2756025	et	4	main
see	doc_59711134418_item	2756032	et	3	main
teil	doc_59711134418_item	2756042	et	4	main
töökohta	doc_59711134418_item	2756049	et	4	main
et	doc_59711134418_item	2756053	et	3	main
on	doc_59711134418_item	2756057	et	4	main
väga	doc_59711134418_item	2756058	et	3	main
käesolev	doc_59711134418_item	2756059	et	3	main
annab	doc_59711134418_item	2756107	et	3	main
endale	doc_59711134418_item	2756121	et	4	main
teha	doc_59711134418_item	2756123	et	3	main
et	doc_59711134418_item	2756124	et	3	main
essee	doc_59711134418_item	2755996	et	4	main
mina	doc_59711134418_item	2755997	et	4	main
ja	doc_59711134418_item	2755998	et	3	main
kooli	doc_59711134418_item	2756006	et	4	main
sest	doc_59711134418_item	2756031	et	4	main
väga	doc_59711134418_item	2756034	et	3	main
tänapäeval	doc_59711134418_item	2756036	et	3	main
veel	doc_59711134418_item	2756050	et	4	main
keele	doc_59711134418_item	2756055	et	4	main
riigikeel	doc_59711134418_item	2756063	et	4	main
ma	doc_59711134418_item	2756086	et	3	main
materiaalse	doc_59711134418_item	2756096	et	3	main
perele	doc_59711134418_item	2756099	et	3	main
tulevikus	doc_59711134418_item	2756101	et	4	main
vanemust	doc_59711134418_item	2756103	et	4	main
ülikooli	doc_59711134418_item	2756104	et	4	main
plaane	doc_59711134418_item	2756117	et	3	main
elus	doc_59711134418_item	2756118	et	4	main
tuleb	doc_59711134418_item	2756120	et	3	main
õppimine	doc_59711134418_item	2756125	et	4	main
ülikoolis	doc_59711134418_item	2756126	et	4	main
ja	doc_59711134418_item	2756127	et	3	main
gümnaasiumis	doc_59711134418_item	2756128	et	3	main
ole	doc_59711134418_item	2756140	et	4	main
on	doc_59711134418_item	2756155	et	4	main
ülikooli	doc_59711134418_item	2756163	et	4	main
tunniplaani	doc_59711134418_item	2756170	et	4	main
väga	doc_59711134418_item	2756177	et	3	main
sobiv	doc_59711134418_item	2756178	et	4	main
paljud	doc_59711134418_item	2756180	et	3	main
tudengid	doc_59711134418_item	2756181	et	3	main
käivad	doc_59711134418_item	2756182	et	4	main
mina	doc_59711134418_item	2756000	et	4	main
olen	doc_59711134418_item	2756001	et	3	main
koolis	doc_59711134418_item	2756008	et	4	main
ma	doc_59711134418_item	2756009	et	3	main
õpisin	doc_59711134418_item	2756010	et	4	main
12	doc_59711134418_item	2756011	et	2	main
aastat	doc_59711134418_item	2756012	et	3	main
nüüd	doc_59711134418_item	2756013	et	4	main
ma	doc_59711134418_item	2756014	et	3	main
astusin	doc_59711134418_item	2756015	et	3	main
tehnikaülikooli	doc_59711134418_item	2756017	et	4	main
mehaanika	doc_59711134418_item	2756018	et	4	main
tallinna	doc_59711134418_item	2756016	et	4	main
teaduskonda	doc_59711134418_item	2756019	et	4	main
tulevikus	doc_59711134418_item	2756020	et	4	main
ülikool	doc_59711134418_item	2755999	et	4	main
selles	doc_59711134418_item	2756007	et	4	main
tahan	doc_59711134418_item	2756022	et	3	main
kõrgharidus	doc_59711134418_item	2756030	et	3	main
kui	doc_59711134418_item	2756037	et	3	main
ei	doc_59711134418_item	2756043	et	4	main
ole	doc_59711134418_item	2756044	et	4	main
palju	doc_59711134418_item	2756045	et	4	main
võimalusi	doc_59711134418_item	2756046	et	3	main
valida	doc_59711134418_item	2756047	et	3	main
ma	doc_59711134418_item	2756051	et	3	main
on	doc_59711134418_item	2756062	et	4	main
endale	doc_59711134418_item	2756089	et	4	main
heaolu	doc_59711134418_item	2756097	et	4	main
aga	doc_59711134418_item	2756100	et	3	main
vaesusemata	doc_59711134418_item	2756102	et	3	main
inimesele	doc_59711134418_item	2756108	et	3	main
oma	doc_59711134418_item	2756116	et	4	main
ei	doc_59711134418_item	2756139	et	4	main
kes	doc_59711134418_item	2756142	et	4	main
sulle	doc_59711134418_item	2756144	et	3	main
ja	doc_59711134418_item	2756146	et	3	main
vaja	doc_59711134418_item	2756156	et	4	main
elus	doc_59711134418_item	2756164	et	4	main
sa	doc_59711134418_item	2756165	et	3	main
saad	doc_59711134418_item	2756166	et	4	main
teha	doc_59711134418_item	2756167	et	3	main
vajalik	doc_59711134418_item	2756173	et	3	main
parim	doc_59711134418_item	2756228	et	4	main
aga	doc_59711134418_item	2756229	et	3	main
ma	doc_59711134418_item	2756230	et	3	main
tahtsin	doc_59711134418_item	2756246	et	3	main
ainult	doc_59711134418_item	2756248	et	4	main
kaupluse	doc_598824800290_item	2756274	et	3	main
2	doc_598824800290_item	2756277	et	2	main
span	doc_598824800290_item	2756279	et	4	main
19	doc_598824800290_item	2756280	et	2	main
12	doc_598824800290_item	2756281	et	2	main
03	doc_598824800290_item	2756282	et	2	main
üks	doc_598824800290_item	2756283	et	3	main
nädalat	doc_598824800290_item	2756284	et	3	main
tagasi	doc_598824800290_item	2756285	et	3	main
ma	doc_598824800290_item	2756286	et	3	main
ostsin	doc_598824800290_item	2756287	et	3	main
pleier	doc_598824800290_item	2756290	et	3	main
päeva	doc_598824800290_item	2756294	et	4	main
stopp-nupp	doc_598824800290_item	2756301	et	3	main
täna	doc_598824800291_item	2756336	et	4	main
on	doc_598824800291_item	2756337	et	4	main
kooli	doc_598824800291_item	2756351	et	4	main
kujunenud	doc_598824800291_item	2756354	et	4	main
tahaksin	doc_598824800291_item	2756358	et	3	main
teie	doc_598824800291_item	2756371	et	4	main
suhtumist	doc_598824800291_item	2756374	et	4	main
3	doc_598824800291_item	2756380	et	2	main
tundi	doc_598824800291_item	2756381	et	4	main
et	doc_598824800291_item	2756383	et	3	main
teha	doc_598824800291_item	2756421	et	3	main
kodus	doc_598824800291_item	2756429	et	4	main
alustavad	doc_598824800291_item	2756445	et	4	main
jooksul	doc_598824800291_item	2756451	et	4	main
mängida	doc_598824800291_item	2756460	et	3	main
suureb	doc_598824800291_item	2756480	et	4	main
p	doc_598824800291_item	2756491	et	4	main
te	doc_600365859531_item	2756495	et	4	main
palju	doc_600365859531_item	2756507	et	4	main
seotud	doc_600365859531_item	2756514	et	4	main
käitumisega	doc_600365859531_item	2756516	et	4	main
rahvastel	doc_600365859531_item	2756520	et	4	main
oma	doc_600365859531_item	2756522	et	4	main
tekkimisest	doc_600365859531_item	2756529	et	4	main
2	doc_600365859531_item	2756532	et	2	main
eesti	doc_600365859531_item	2756533	et	4	main
kultuur	doc_600365859531_item	2756534	et	3	main
ise	doc_600365859531_item	2756550	et	4	main
tegelikult	doc_600365859531_item	2756565	et	4	main
x	doc_59711134418_item	2756002	et	4	main
ma	doc_59711134418_item	2756003	et	3	main
lõpetasin	doc_59711134418_item	2756004	et	3	main
narva	doc_59711134418_item	2756005	et	4	main
tähtis	doc_59711134418_item	2756029	et	4	main
on	doc_59711134418_item	2756033	et	4	main
tähtis	doc_59711134418_item	2756035	et	4	main
teil	doc_59711134418_item	2756038	et	4	main
ei	doc_59711134418_item	2756039	et	4	main
pärast	doc_59711134418_item	2756080	et	4	main
ülikooli	doc_59711134418_item	2756081	et	4	main
oskan	doc_59711134418_item	2756087	et	3	main
sisse	doc_59711134418_item	2756105	et	4	main
realiseerida	doc_59711134418_item	2756115	et	3	main
aga	doc_59711134418_item	2756119	et	3	main
mehaanikainseneriks	doc_59711134418_item	2756024	et	3	main
elus	doc_59711134418_item	2756026	et	4	main
on	doc_59711134418_item	2756027	et	4	main
väga	doc_59711134418_item	2756028	et	3	main
ole	doc_59711134418_item	2756040	et	4	main
kõrgharidus	doc_59711134418_item	2756041	et	3	main
oma	doc_59711134418_item	2756048	et	4	main
arvan	doc_59711134418_item	2756052	et	3	main
eesti	doc_59711134418_item	2756054	et	4	main
oskus	doc_59711134418_item	2756056	et	3	main
eesti	doc_59711134418_item	2756060	et	4	main
keel	doc_59711134418_item	2756061	et	4	main
rigikeelte	doc_59711134418_item	2756064	et	4	main
oskus	doc_59711134418_item	2756065	et	3	main
ja	doc_59711134418_item	2756066	et	3	main
kõrgharidus	doc_59711134418_item	2756067	et	3	main
avaldab	doc_59711134418_item	2756068	et	3	main
palju	doc_59711134418_item	2756069	et	4	main
võimalusi	doc_59711134418_item	2756070	et	3	main
inimeste	doc_59711134418_item	2756071	et	3	main
jaoks	doc_59711134418_item	2756072	et	4	main
näiteks	doc_59711134418_item	2756073	et	4	main
inimene	doc_59711134418_item	2756074	et	3	main
võib	doc_59711134418_item	2756075	et	3	main
töötada	doc_59711134418_item	2756076	et	3	main
kus	doc_59711134418_item	2756077	et	3	main
ta	doc_59711134418_item	2756078	et	4	main
tahab	doc_59711134418_item	2756079	et	3	main
lõpitamist	doc_59711134418_item	2756082	et	4	main
ma	doc_59711134418_item	2756083	et	3	main
loodan	doc_59711134418_item	2756084	et	3	main
et	doc_59711134418_item	2756085	et	3	main
otsida	doc_59711134418_item	2756088	et	4	main
hea	doc_59711134418_item	2756090	et	4	main
töökohta	doc_59711134418_item	2756091	et	4	main
ja	doc_59711134418_item	2756092	et	3	main
saan	doc_59711134418_item	2756093	et	4	main
tagastada	doc_59711134418_item	2756094	et	3	main
stabiilse	doc_59711134418_item	2756095	et	3	main
oma	doc_59711134418_item	2756098	et	4	main
astumine	doc_59711134418_item	2756106	et	4	main
palju	doc_59711134418_item	2756109	et	4	main
uusi	doc_59711134418_item	2756110	et	3	main
võimalusi	doc_59711134418_item	2756111	et	3	main
inimesel	doc_59711134418_item	2756112	et	3	main
on	doc_59711134418_item	2756113	et	4	main
kerge	doc_59711134418_item	2756114	et	4	main
erinev	doc_59711134418_item	2756130	et	4	main
seda	doc_59711134418_item	2756131	et	3	main
hakkad	doc_59711134418_item	2756132	et	3	main
sul	doc_59711134418_item	2756138	et	3	main
aitama	doc_59711134418_item	2756145	et	3	main
panema	doc_59711134418_item	2756147	et	3	main
õigele	doc_59711134418_item	2756149	et	3	main
elad	doc_59711134418_item	2756152	et	3	main
iseseisvuna	doc_59711134418_item	2756158	et	4	main
on	doc_59711134418_item	2756159	et	4	main
aga	doc_59711134418_item	2756160	et	3	main
ise	doc_59711134418_item	2756168	et	4	main
on	doc_59711134418_item	2756174	et	4	main
sest	doc_59711134418_item	2756179	et	4	main
astuda	doc_59711134418_item	2756221	et	3	main
sest	doc_59711134418_item	2756223	et	4	main
hingele	doc_59711134418_item	2756227	et	4	main
õppima	doc_59711134418_item	2756238	et	3	main
ju	doc_59711134418_item	2756245	et	3	main
õppida	doc_59711134418_item	2756247	et	3	main
tallinna	doc_59711134418_item	2756249	et	4	main
tehnikaülikoolis	doc_59711134418_item	2756250	et	4	main
ametlik	doc_59711134419_item	2756251	et	3	main
vaja	doc_59711134419_item	2756264	et	4	main
juhatajale	doc_598824800290_item	2756275	et	4	main
ma	doc_598824800290_item	2756304	et	3	main
seal	doc_598824800290_item	2756309	et	4	main
et	doc_598824800290_item	2756312	et	3	main
ei	doc_598824800290_item	2756314	et	4	main
saa	doc_598824800290_item	2756315	et	4	main
teha	doc_598824800290_item	2756316	et	3	main
perekonnanimi	doc_598824800290_item	2756324	et	3	main
p	doc_598824800290_item	2756325	et	4	main
kontakst	doc_598824800290_item	2756326	et	4	main
kõne	doc_598824800291_item	2756331	et	4	main
kogunud	doc_598824800291_item	2756339	et	4	main
kõik	doc_598824800291_item	2756340	et	4	main
päev	doc_598824800291_item	2756346	et	3	main
väga	doc_598824800291_item	2756348	et	3	main
tähtis	doc_598824800291_item	2756349	et	4	main
meie	doc_598824800291_item	2756350	et	4	main
on	doc_598824800291_item	2756353	et	4	main
olukord	doc_598824800291_item	2756355	et	3	main
kus	doc_598824800291_item	2756356	et	3	main
koolipäevaplaani	doc_598824800291_item	2756360	et	4	main
esimiset	doc_598824800291_item	2756363	et	4	main
ettepanek	doc_598824800291_item	2756365	et	3	main
teie	doc_598824800291_item	2756373	et	4	main
selline	doc_598824800291_item	2756377	et	4	main
ja	doc_598824800291_item	2756423	et	3	main
laste	doc_598824800291_item	2756425	et	4	main
mõned	doc_598824800291_item	2756427	et	3	main
see	doc_598824800291_item	2756433	et	3	main
on	doc_598824800291_item	2756434	et	4	main
keel	doc_598824800291_item	2756440	et	4	main
3-4	doc_598824800291_item	2756446	et	2	main
aga	doc_598824800291_item	2756449	et	3	main
koduülesandid	doc_598824800291_item	2756455	et	4	main
teha	doc_598824800291_item	2756456	et	3	main
jalutada	doc_598824800291_item	2756457	et	3	main
sõpradega	doc_598824800291_item	2756459	et	3	main
et	doc_598824800291_item	2756477	et	3	main
poolteist	doc_598824800291_item	2756481	et	4	main
ja	doc_598824800291_item	2756486	et	3	main
vastus	doc_600365859531_item	2756492	et	3	main
selgeks	doc_59711134418_item	2756122	et	3	main
on	doc_59711134418_item	2756129	et	4	main
päevast	doc_59711134418_item	2756136	et	4	main
klassijuhatajat	doc_59711134418_item	2756141	et	3	main
teele	doc_59711134418_item	2756150	et	3	main
oma	doc_59711134418_item	2756153	et	4	main
elu	doc_59711134418_item	2756154	et	4	main
oma	doc_59711134418_item	2756161	et	4	main
plussid	doc_59711134418_item	2756162	et	3	main
indale	doc_59711134418_item	2756169	et	4	main
see	doc_59711134418_item	2756175	et	3	main
võimalusi	doc_59711134418_item	2756187	et	3	main
töö	doc_59711134418_item	2756188	et	4	main
jaoks	doc_59711134418_item	2756189	et	4	main
samuti	doc_59711134418_item	2756190	et	3	main
ülikoolis	doc_59711134418_item	2756191	et	4	main
on	doc_59711134418_item	2756192	et	4	main
olemas	doc_59711134418_item	2756193	et	4	main
valikained	doc_59711134418_item	2756194	et	3	main
ja	doc_59711134418_item	2756195	et	3	main
valik	doc_59711134418_item	2756196	et	3	main
väga	doc_59711134418_item	2756198	et	3	main
suur	doc_59711134418_item	2756199	et	3	main
nii	doc_59711134418_item	2756200	et	3	main
on	doc_59711134418_item	2756197	et	4	main
et	doc_59711134418_item	2756201	et	3	main
iga	doc_59711134418_item	2756202	et	4	main
inimene	doc_59711134418_item	2756203	et	3	main
saab	doc_59711134418_item	2756204	et	3	main
leida	doc_59711134418_item	2756205	et	3	main
endale	doc_59711134418_item	2756206	et	4	main
midagi	doc_59711134418_item	2756207	et	4	main
oma	doc_59711134418_item	2756208	et	4	main
huvist	doc_59711134418_item	2756209	et	3	main
miks	doc_59711134418_item	2756210	et	4	main
ma	doc_59711134418_item	2756211	et	3	main
valisin	doc_59711134418_item	2756212	et	3	main
just	doc_59711134418_item	2756213	et	3	main
selle	doc_59711134418_item	2756214	et	4	main
ametit	doc_59711134418_item	2756215	et	3	main
kui	doc_59711134418_item	2756216	et	3	main
ausalt	doc_59711134418_item	2756217	et	4	main
öelda	doc_59711134418_item	2756218	et	4	main
ma	doc_59711134418_item	2756219	et	3	main
tahtsin	doc_59711134418_item	2756220	et	3	main
see	doc_59711134418_item	2756224	et	3	main
on	doc_59711134418_item	2756225	et	4	main
minule	doc_59711134418_item	2756226	et	3	main
konkursi	doc_59711134418_item	2756233	et	3	main
aga	doc_59711134418_item	2756234	et	3	main
mehaanikat	doc_59711134418_item	2756235	et	3	main
ma	doc_59711134418_item	2756236	et	3	main
aru	doc_59711134418_item	2756133	et	4	main
saama	doc_59711134418_item	2756134	et	4	main
esimesest	doc_59711134418_item	2756135	et	3	main
ülikoolis	doc_59711134418_item	2756137	et	4	main
hakkab	doc_59711134418_item	2756143	et	3	main
sind	doc_59711134418_item	2756148	et	4	main
sa	doc_59711134418_item	2756151	et	3	main
olla	doc_59711134418_item	2756157	et	3	main
mis	doc_59711134418_item	2756171	et	4	main
sul	doc_59711134418_item	2756172	et	3	main
on	doc_59711134418_item	2756176	et	4	main
tööl	doc_59711134418_item	2756183	et	3	main
see	doc_59711134418_item	2756184	et	3	main
annab	doc_59711134418_item	2756185	et	3	main
rohkem	doc_59711134418_item	2756186	et	4	main
ehitusteaduskonda	doc_59711134418_item	2756222	et	4	main
ei	doc_59711134418_item	2756231	et	4	main
läbinud	doc_59711134418_item	2756232	et	4	main
läksin	doc_59711134418_item	2756237	et	3	main
päevast	doc_59711134419_item	2756254	et	4	main
sekretäär	doc_59711134419_item	2756255	et	4	main
te	doc_59711134419_item	2756258	et	4	main
talle	doc_59711134419_item	2756260	et	4	main
on	doc_59711134419_item	2756263	et	4	main
muutuda	doc_59711134419_item	2756265	et	3	main
minu	doc_59711134419_item	2756266	et	3	main
hinne	doc_59711134419_item	2756267	et	3	main
kaebus	doc_598824800290_item	2756272	et	3	main
ta	doc_598824800290_item	2756291	et	4	main
tema	doc_598824800290_item	2756300	et	4	main
ei	doc_598824800290_item	2756302	et	4	main
töötas	doc_598824800290_item	2756303	et	3	main
plaier	doc_598824800290_item	2756306	et	4	main
koolidirektori	doc_598824800291_item	2756330	et	3	main
täna	doc_598824800291_item	2756345	et	4	main
jaoks	doc_598824800291_item	2756352	et	4	main
et	doc_598824800291_item	2756362	et	3	main
ei	doc_598824800291_item	2756366	et	4	main
meeldinud	doc_598824800291_item	2756367	et	4	main
muudate	doc_598824800291_item	2756372	et	3	main
ettepanek	doc_598824800291_item	2756375	et	3	main
kestab	doc_598824800291_item	2756379	et	4	main
rohkem	doc_59711134418_item	2756240	et	4	main
valikut	doc_59711134418_item	2756241	et	3	main
ei	doc_59711134418_item	2756242	et	4	main
sest	doc_59711134418_item	2756239	et	4	main
olnud	doc_59711134418_item	2756243	et	4	main
kiri	doc_59711134419_item	2756252	et	3	main
saatsite	doc_59711134419_item	2756259	et	3	main
et	doc_59711134419_item	2756262	et	3	main
õppekaartis	doc_59711134419_item	2756268	et	4	main
lugupidamisega	doc_59711134419_item	2756269	et	3	main
eesnimi	doc_59711134419_item	2756270	et	3	main
perekonnanimi	doc_59711134419_item	2756271	et	3	main
teie	doc_598824800290_item	2756288	et	4	main
neli	doc_598824800290_item	2756293	et	3	main
pärast	doc_598824800290_item	2756296	et	4	main
ta	doc_598824800290_item	2756297	et	4	main
läks	doc_598824800290_item	2756298	et	3	main
katki	doc_598824800290_item	2756299	et	4	main
andndsin	doc_598824800290_item	2756305	et	4	main
aga	doc_598824800290_item	2756308	et	3	main
öeldi	doc_598824800290_item	2756311	et	3	main
plaier	doc_598824800290_item	2756321	et	4	main
eesnimi	doc_598824800290_item	2756323	et	3	main
direktori	doc_598824800291_item	2756332	et	3	main
kolleegid	doc_598824800291_item	2756335	et	3	main
meie	doc_598824800291_item	2756341	et	4	main
õpetajad	doc_598824800291_item	2756342	et	4	main
arvan	doc_598824800291_item	2756343	et	3	main
et	doc_598824800291_item	2756344	et	3	main
on	doc_598824800291_item	2756347	et	4	main
ma	doc_598824800291_item	2756357	et	3	main
muudata	doc_598824800291_item	2756359	et	4	main
arvan	doc_598824800291_item	2756361	et	3	main
teile	doc_598824800291_item	2756368	et	4	main
vaid	doc_598824800291_item	2756369	et	3	main
pärast	doc_598824800291_item	2756370	et	4	main
teile	doc_598824800291_item	2756384	et	4	main
pärast	doc_598824800291_item	2756437	et	4	main
3	doc_598824800291_item	2756438	et	2	main
tundi	doc_598824800291_item	2756439	et	4	main
tundi	doc_598824800291_item	2756447	et	4	main
lastel	doc_598824800291_item	2756452	et	4	main
on	doc_598824800291_item	2756453	et	4	main
võimalus	doc_598824800291_item	2756454	et	3	main
vastutavaks	doc_598824800291_item	2756475	et	4	main
määran	doc_598824800291_item	2756476	et	3	main
palk	doc_598824800291_item	2756479	et	3	main
korda	doc_598824800291_item	2756482	et	4	main
tänan	doc_598824800291_item	2756483	et	3	main
tähelepanu	doc_598824800291_item	2756484	et	4	main
teha	doc_598824800291_item	2756488	et	3	main
valimust	doc_598824800291_item	2756490	et	4	main
küsimusele	doc_600365859531_item	2756493	et	4	main
rääkida	doc_600365859531_item	2756508	et	3	main
arenemisega	doc_600365859531_item	2756517	et	4	main
ma	doc_59711134418_item	2756244	et	3	main
tere	doc_59711134419_item	2756253	et	3	main
palus	doc_59711134419_item	2756256	et	4	main
et	doc_59711134419_item	2756257	et	3	main
kiri	doc_59711134419_item	2756261	et	3	main
kaebus	doc_598824800290_item	2756273	et	3	main
sikupilli	doc_598824800290_item	2756276	et	4	main
span	doc_598824800290_item	2756278	et	4	main
kauplusest	doc_598824800290_item	2756289	et	4	main
töötas	doc_598824800290_item	2756292	et	3	main
ja	doc_598824800290_item	2756295	et	3	main
remondiks	doc_598824800290_item	2756307	et	4	main
mulle	doc_598824800290_item	2756310	et	4	main
see	doc_598824800290_item	2756313	et	3	main
ma	doc_598824800290_item	2756317	et	3	main
tahan	doc_598824800290_item	2756318	et	3	main
vahetada	doc_598824800290_item	2756319	et	3	main
selle	doc_598824800290_item	2756320	et	4	main
uueks	doc_598824800290_item	2756322	et	3	main
tel	doc_598824800290_item	2756327	et	4	main
6	doc_598824800290_item	2756328	et	2	main
333-444	doc_598824800290_item	2756329	et	2	main
kõne	doc_598824800291_item	2756333	et	4	main
austatud	doc_598824800291_item	2756334	et	4	main
siia	doc_598824800291_item	2756338	et	4	main
minu	doc_598824800291_item	2756364	et	3	main
on	doc_598824800291_item	2756376	et	4	main
lõunavaheaeg	doc_598824800291_item	2756378	et	3	main
näen	doc_598824800291_item	2756382	et	3	main
seda	doc_598824800291_item	2756385	et	3	main
ei	doc_598824800291_item	2756386	et	4	main
meeldi	doc_598824800291_item	2756387	et	4	main
vaid	doc_598824800291_item	2756388	et	3	main
kohe	doc_598824800291_item	2756389	et	4	main
seletan	doc_598824800291_item	2756390	et	3	main
õppepäev	doc_598824800291_item	2756391	et	3	main
alustab	doc_598824800291_item	2756392	et	3	main
keel	doc_598824800291_item	2756393	et	4	main
kaheksa	doc_598824800291_item	2756394	et	4	main
ja	doc_598824800291_item	2756395	et	3	main
lähevad	doc_598824800291_item	2756396	et	3	main
4	doc_598824800291_item	2756397	et	2	main
tundi	doc_598824800291_item	2756398	et	4	main
nad	doc_598824800291_item	2756399	et	3	main
lõpetavad	doc_598824800291_item	2756400	et	4	main
keel	doc_598824800291_item	2756401	et	4	main
pool	doc_598824800291_item	2756402	et	4	main
12	doc_598824800291_item	2756403	et	2	main
siis	doc_598824800291_item	2756404	et	3	main
meie	doc_598824800291_item	2756405	et	4	main
on	doc_598824800291_item	2756406	et	4	main
3-me	doc_598824800291_item	2756407	et	4	main
tundiline	doc_598824800291_item	2756408	et	4	main
vaheaeg	doc_598824800291_item	2756409	et	3	main
selle	doc_598824800291_item	2756410	et	4	main
aja	doc_598824800291_item	2756411	et	4	main
jooksul	doc_598824800291_item	2756412	et	4	main
koolis	doc_598824800291_item	2756413	et	4	main
on	doc_598824800291_item	2756414	et	4	main
avatud	doc_598824800291_item	2756415	et	4	main
mõned	doc_598824800291_item	2756416	et	3	main
klassid	doc_598824800291_item	2756417	et	3	main
kui	doc_598824800291_item	2756418	et	3	main
õpetajad	doc_598824800291_item	2756419	et	4	main
aitavad	doc_598824800291_item	2756420	et	4	main
käia	doc_598824800291_item	2756430	et	4	main
või	doc_598824800291_item	2756431	et	4	main
kaupluses	doc_598824800291_item	2756432	et	3	main
pool	doc_598824800291_item	2756441	et	4	main
kolm	doc_598824800291_item	2756442	et	3	main
tunnid	doc_598824800291_item	2756443	et	3	main
muutuse	doc_598824800291_item	2756473	et	4	main
õpetaja	doc_598824800291_item	2756478	et	4	main
eest	doc_598824800291_item	2756485	et	4	main
soovin	doc_598824800291_item	2756487	et	3	main
õige	doc_598824800291_item	2756489	et	4	main
eesti	doc_600365859531_item	2756501	et	4	main
kultuur	doc_600365859531_item	2756502	et	3	main
1	doc_600365859531_item	2756503	et	2	main
kultuuridest	doc_600365859531_item	2756504	et	3	main
võib	doc_600365859531_item	2756505	et	3	main
väga	doc_600365859531_item	2756506	et	3	main
arvates	doc_600365859531_item	2756511	et	4	main
on	doc_600365859531_item	2756513	et	4	main
inimese	doc_600365859531_item	2756515	et	4	main
on	doc_600365859531_item	2756521	et	4	main
kultuur	doc_600365859531_item	2756523	et	3	main
väga	doc_600365859531_item	2756536	et	3	main
teistest	doc_600365859531_item	2756537	et	4	main
tahan	doc_600365859531_item	2756542	et	3	main
väga	doc_600365859531_item	2756562	et	3	main
aga	doc_600365859531_item	2756564	et	3	main
saan	doc_600365859531_item	2756568	et	4	main
selles	doc_600365859531_item	2756576	et	4	main
mõttes	doc_600365859531_item	2756577	et	3	main
et	doc_600365859531_item	2756578	et	3	main
on	doc_600365859531_item	2756580	et	4	main
väga	doc_600365859531_item	2756581	et	3	main
meie	doc_600365859531_item	2756597	et	4	main
huvitamaks	doc_600365859531_item	2756599	et	3	main
eestlasest	doc_600559928975_item	2756603	et	3	main
et	doc_600559928975_item	2756605	et	3	main
kursustel	doc_600559928975_item	2756608	et	3	main
kirjuta	doc_600559928975_item	2756609	et	4	main
mida	doc_600559928975_item	2756610	et	4	main
sa	doc_600559928975_item	2756611	et	3	main
kursustel	doc_600559928975_item	2756612	et	3	main
kirjuta	doc_600559928975_item	2756619	et	4	main
praktikale	doc_600559928975_item	2756622	et	3	main
firma	doc_600559928975_item	2756625	et	4	main
hakkad	doc_600559928975_item	2756632	et	3	main
eesti	doc_600559928975_item	2756635	et	4	main
priit	doc_600559928975_item	2756637	et	3	main
mina	doc_600559928975_item	2756638	et	4	main
lähen	doc_600559928975_item	2756639	et	3	main
kursusel	doc_600559928975_item	2756640	et	3	main
ja	doc_600559928975_item	2756641	et	3	main
et	doc_600559928975_item	2756642	et	3	main
varsti	doc_600559928975_item	2756643	et	3	main
ordi	doc_600559928975_item	2756651	et	4	main
pladid	doc_600559928975_item	2756663	et	4	main
ma	doc_600559928975_item	2756668	et	3	main
töö	doc_600559928975_item	2756671	et	4	main
kirjuta	doc_600559928976_item	2756684	et	4	main
sõbrale	doc_600559928976_item	2756687	et	3	main
arvutiõppimine	doc_600559928976_item	2756747	et	3	main
ja	doc_600559928976_item	2756751	et	3	main
praegu	doc_600559928976_item	2756754	et	3	main
õpin	doc_600559928976_item	2756756	et	3	main
keelt	doc_600559928976_item	2756758	et	4	main
eksami	doc_600559928976_item	2756761	et	3	main
esimest	doc_600559928976_item	2756764	et	4	main
või	doc_600559928976_item	2756805	et	4	main
erinevaid	doc_600559928976_item	2756810	et	4	main
ajalehti	doc_600559928976_item	2756811	et	4	main
kirjapaberit	doc_600559928976_item	2756815	et	3	main
ja	doc_600559928976_item	2756816	et	3	main
et	doc_600559928976_item	2756822	et	3	main
on	doc_600559928976_item	2756835	et	4	main
kui	doc_600559928976_item	2756837	et	3	main
on	doc_600559928976_item	2756847	et	4	main
arvuti	doc_600559928976_item	2756849	et	4	main
ma	doc_600559928976_item	2756850	et	3	main
oskan	doc_600559928976_item	2756851	et	3	main
töötada	doc_600559928976_item	2756861	et	3	main
post	doc_600559928976_item	2756862	et	3	main
kooliülesandeid	doc_598824800291_item	2756422	et	3	main
vastavad	doc_598824800291_item	2756424	et	4	main
küsimustele	doc_598824800291_item	2756426	et	4	main
saavad	doc_598824800291_item	2756428	et	4	main
teie	doc_598824800291_item	2756435	et	4	main
valik	doc_598824800291_item	2756436	et	3	main
jälle	doc_598824800291_item	2756444	et	3	main
veel	doc_598824800291_item	2756448	et	4	main
vaheaja	doc_598824800291_item	2756450	et	3	main
süüa	doc_598824800291_item	2756458	et	3	main
jne	doc_598824800291_item	2756461	et	4	main
arvan	doc_598824800291_item	2756462	et	3	main
et	doc_598824800291_item	2756463	et	3	main
selle	doc_598824800291_item	2756464	et	4	main
tulemusel	doc_598824800291_item	2756465	et	3	main
lastel	doc_598824800291_item	2756466	et	4	main
on	doc_598824800291_item	2756467	et	4	main
õhtul	doc_598824800291_item	2756468	et	3	main
rohkem	doc_598824800291_item	2756469	et	4	main
vabaaja	doc_598824800291_item	2756470	et	3	main
kodusbr	doc_598824800291_item	2756471	et	4	main
selle	doc_598824800291_item	2756472	et	4	main
eest	doc_598824800291_item	2756474	et	4	main
mida	doc_600365859531_item	2756494	et	4	main
mõtlete	doc_600365859531_item	2756496	et	3	main
kuulete	doc_600365859531_item	2756498	et	4	main
sõna	doc_600365859531_item	2756499	et	4	main
kultuur	doc_600365859531_item	2756500	et	3	main
aga	doc_600365859531_item	2756509	et	3	main
iga	doc_600365859531_item	2756519	et	4	main
meile	doc_600365859531_item	2756526	et	4	main
linna	doc_600365859531_item	2756528	et	4	main
ja	doc_600365859531_item	2756530	et	3	main
kombedest	doc_600365859531_item	2756531	et	4	main
kultuuridest	doc_600365859531_item	2756538	et	3	main
erinev	doc_600365859531_item	2756539	et	4	main
sellega	doc_600365859531_item	2756540	et	3	main
ma	doc_600365859531_item	2756541	et	3	main
eestlastel	doc_600365859531_item	2756545	et	4	main
rohkem	doc_600365859531_item	2756549	et	4	main
kultuur	doc_600365859531_item	2756560	et	3	main
ainult	doc_600365859531_item	2756569	et	4	main
raske	doc_600365859531_item	2756582	et	4	main
mõnte	doc_600365859531_item	2756583	et	4	main
saada	doc_600365859531_item	2756586	et	4	main
aga	doc_600365859531_item	2756589	et	3	main
kuultur	doc_600365859531_item	2756594	et	4	main
kirjuta	doc_600559928975_item	2756601	et	4	main
oma	doc_600559928975_item	2756602	et	4	main
käid	doc_600559928975_item	2756606	et	3	main
lähed	doc_600559928975_item	2756623	et	3	main
tere	doc_600559928975_item	2756633	et	3	main
sõber	doc_600559928975_item	2756636	et	3	main
ma	doc_600559928975_item	2756652	et	3	main
müü	doc_600559928975_item	2756654	et	4	main
müü	doc_600559928975_item	2756666	et	4	main
sõber	doc_600559928975_item	2756682	et	3	main
käid	doc_600559928976_item	2756689	et	3	main
elad	doc_600559928976_item	2756721	et	3	main
on	doc_600559928976_item	2756723	et	4	main
ma	doc_600559928976_item	2756728	et	3	main
ma	doc_600559928976_item	2756740	et	3	main
õpin	doc_600559928976_item	2756741	et	3	main
palju	doc_600559928976_item	2756742	et	4	main
aineid	doc_600559928976_item	2756743	et	3	main
see	doc_600559928976_item	2756744	et	3	main
tarbijakaitse	doc_600559928976_item	2756748	et	4	main
tööõigus	doc_600559928976_item	2756750	et	4	main
detsembrist	doc_600559928976_item	2756765	et	3	main
kaivad	doc_600559928976_item	2756799	et	4	main
osta	doc_600559928976_item	2756802	et	4	main
midagi	doc_600559928976_item	2756807	et	4	main
posti	doc_600559928976_item	2756825	et	4	main
tule	doc_600559928976_item	2756840	et	4	main
hakkan	doc_600559928976_item	2756843	et	3	main
arvan	doc_600559928976_item	2756855	et	3	main
lähedal	doc_600559928976_item	2756867	et	4	main
me	doc_600559928976_item	2756880	et	4	main
varsti	doc_600559928976_item	2756882	et	3	main
ja	doc_600559928976_item	2756884	et	3	main
räägime	doc_600559928976_item	2756886	et	3	main
kiri	doc_600559928977_item	2756889	et	3	main
käid	doc_600559928977_item	2756895	et	3	main
hakkad	doc_600559928977_item	2756921	et	3	main
arvuti	doc_600559928977_item	2756943	et	4	main
ma	doc_600559928977_item	2756944	et	3	main
ma	doc_600559928977_item	2756949	et	3	main
hakkan	doc_600559928977_item	2756951	et	3	main
kirjuta	doc_600559928977_item	2756959	et	4	main
mulle	doc_600559928977_item	2756960	et	4	main
kui	doc_600365859531_item	2756497	et	3	main
minu	doc_600365859531_item	2756510	et	3	main
kultuur	doc_600365859531_item	2756512	et	3	main
traditsioonidega	doc_600365859531_item	2756518	et	3	main
mis	doc_600365859531_item	2756524	et	4	main
on	doc_600365859531_item	2756535	et	4	main
öelda	doc_600365859531_item	2756543	et	4	main
nende	doc_600365859531_item	2756546	et	4	main
kultuur	doc_600365859531_item	2756547	et	3	main
on	doc_600365859531_item	2756548	et	4	main
lugeda	doc_600365859531_item	2756570	et	3	main
õppida	doc_600365859531_item	2756571	et	3	main
aga	doc_600365859531_item	2756572	et	3	main
mitet	doc_600365859531_item	2756573	et	4	main
mulle	doc_600365859531_item	2756579	et	4	main
see	doc_600365859531_item	2756591	et	3	main
mis	doc_600365859531_item	2756595	et	4	main
kiri	doc_600559928975_item	2756600	et	3	main
sõbrale	doc_600559928975_item	2756604	et	3	main
praegu	doc_600559928975_item	2756607	et	3	main
praktikale	doc_600559928975_item	2756618	et	3	main
sa	doc_600559928975_item	2756621	et	3	main
on	doc_600559928975_item	2756627	et	4	main
seal	doc_600559928975_item	2756630	et	4	main
as	doc_600559928975_item	2756650	et	4	main
tahan	doc_600559928975_item	2756653	et	3	main
firma	doc_600559928975_item	2756657	et	4	main
müü	doc_600559928975_item	2756658	et	4	main
minule	doc_600559928975_item	2756664	et	3	main
kiri	doc_600559928976_item	2756683	et	3	main
et	doc_600559928976_item	2756688	et	3	main
annab	doc_600365859531_item	2756525	et	3	main
informatsioone	doc_600365859531_item	2756527	et	3	main
et	doc_600365859531_item	2756544	et	3	main
tehtud	doc_600365859531_item	2756551	et	4	main
mitte	doc_600365859531_item	2756552	et	3	main
võetud	doc_600365859531_item	2756553	et	4	main
või	doc_600365859531_item	2756554	et	4	main
kopeeritud	doc_600365859531_item	2756555	et	4	main
mingi	doc_600365859531_item	2756556	et	4	main
teiste	doc_600365859531_item	2756557	et	4	main
rahvastega	doc_600365859531_item	2756558	et	4	main
eesti	doc_600365859531_item	2756559	et	4	main
on	doc_600365859531_item	2756561	et	4	main
huvitav	doc_600365859531_item	2756563	et	4	main
aru	doc_600365859531_item	2756574	et	4	main
asju	doc_600365859531_item	2756584	et	3	main
näiteks	doc_600365859531_item	2756587	et	4	main
anekdoote	doc_600365859531_item	2756588	et	3	main
ongi	doc_600365859531_item	2756592	et	4	main
see	doc_600365859531_item	2756593	et	3	main
teeb	doc_600365859531_item	2756596	et	3	main
elu	doc_600365859531_item	2756598	et	4	main
lähete	doc_600559928975_item	2756617	et	4	main
mina	doc_600365859531_item	2756566	et	4	main
venelane	doc_600365859531_item	2756567	et	3	main
saada	doc_600365859531_item	2756575	et	4	main
ara	doc_600365859531_item	2756585	et	3	main
see	doc_600365859531_item	2756590	et	3	main
õpid	doc_600559928975_item	2756613	et	4	main
ja	doc_600559928975_item	2756614	et	3	main
et	doc_600559928975_item	2756615	et	3	main
varsti	doc_600559928975_item	2756616	et	3	main
kuhu	doc_600559928975_item	2756620	et	3	main
tegema	doc_600559928975_item	2756631	et	3	main
lahete	doc_600559928975_item	2756644	et	4	main
praktikale	doc_600559928975_item	2756645	et	3	main
ma	doc_600559928975_item	2756646	et	3	main
läksin	doc_600559928975_item	2756647	et	3	main
praktikale	doc_600559928975_item	2756648	et	3	main
firmas	doc_600559928975_item	2756649	et	3	main
komputriga	doc_600559928975_item	2756655	et	4	main
see	doc_600559928975_item	2756656	et	3	main
koputriga	doc_600559928975_item	2756659	et	4	main
cd	doc_600559928975_item	2756660	et	4	main
ja	doc_600559928975_item	2756661	et	3	main
armastan	doc_600559928975_item	2756665	et	3	main
komputriga	doc_600559928975_item	2756667	et	4	main
ja	doc_600559928975_item	2756672	et	3	main
ma	doc_600559928975_item	2756673	et	3	main
tahan	doc_600559928975_item	2756674	et	3	main
osta	doc_600559928975_item	2756675	et	4	main
autoga	doc_600559928975_item	2756676	et	3	main
ja	doc_600559928975_item	2756677	et	3	main
ma	doc_600559928975_item	2756678	et	3	main
sõidan	doc_600559928975_item	2756679	et	3	main
sulle	doc_600559928975_item	2756680	et	3	main
tervitades	doc_600559928975_item	2756681	et	3	main
eestlasest	doc_600559928976_item	2756686	et	3	main
kursustel	doc_600559928976_item	2756691	et	3	main
kõik	doc_600559928976_item	2756724	et	4	main
väga	doc_600559928976_item	2756725	et	3	main
hästi	doc_600559928976_item	2756726	et	3	main
ei	doc_600559928976_item	2756729	et	4	main
tööta	doc_600559928976_item	2756730	et	4	main
aga	doc_600559928976_item	2756731	et	3	main
ma	doc_600559928976_item	2756732	et	3	main
käin	doc_600559928976_item	2756733	et	3	main
kursustele	doc_600559928976_item	2756734	et	3	main
kursuste	doc_600559928976_item	2756735	et	3	main
nimi	doc_600559928976_item	2756736	et	3	main
on	doc_600559928976_item	2756745	et	4	main
asjaajamine	doc_600559928976_item	2756746	et	4	main
ma	doc_600559928976_item	2756755	et	3	main
eesti	doc_600559928976_item	2756757	et	4	main
ma	doc_600559928976_item	2756759	et	3	main
kodakondsusele	doc_600559928976_item	2756762	et	3	main
sooritama	doc_600559928976_item	2756763	et	3	main
praktika	doc_600559928976_item	2756767	et	4	main
lõpeb	doc_600559928976_item	2756769	et	4	main
postisse	doc_600559928976_item	2756800	et	3	main
müüakse	doc_600559928976_item	2756809	et	3	main
ajakirju	doc_600559928976_item	2756812	et	4	main
marke	doc_600559928976_item	2756813	et	3	main
ümbrikuid	doc_600559928976_item	2756814	et	3	main
nii	doc_600559928976_item	2756817	et	3	main
edasi	doc_600559928976_item	2756818	et	3	main
tuleb	doc_600559928976_item	2756820	et	3	main
postkontorisse	doc_600559928976_item	2756821	et	3	main
oma	doc_600559928976_item	2756831	et	4	main
postkast	doc_600559928976_item	2756832	et	3	main
see	doc_600559928976_item	2756833	et	3	main
teenus	doc_600559928976_item	2756834	et	3	main
tasuline	doc_600559928976_item	2756836	et	4	main
keegi	doc_600559928976_item	2756838	et	4	main
ei	doc_600559928976_item	2756839	et	4	main
ka	doc_600559928976_item	2756848	et	3	main
ma	doc_600559928976_item	2756854	et	3	main
et	doc_600559928976_item	2756856	et	3	main
on	doc_600559928976_item	2756858	et	4	main
huvitav	doc_600559928976_item	2756860	et	4	main
sest	doc_600559928976_item	2756868	et	4	main
uudised	doc_600559928976_item	2756876	et	3	main
arvan	doc_600559928976_item	2756878	et	3	main
sõbrale	doc_600559928977_item	2756893	et	3	main
kursustel	doc_600559928977_item	2756897	et	3	main
mis	doc_600559928975_item	2756624	et	4	main
see	doc_600559928975_item	2756626	et	3	main
mida	doc_600559928975_item	2756628	et	4	main
sa	doc_600559928975_item	2756629	et	3	main
minu	doc_600559928975_item	2756634	et	3	main
palju	doc_600559928975_item	2756662	et	4	main
tahan	doc_600559928975_item	2756669	et	3	main
seda	doc_600559928975_item	2756670	et	3	main
oma	doc_600559928976_item	2756685	et	4	main
praegu	doc_600559928976_item	2756690	et	3	main
kirjuta	doc_600559928976_item	2756692	et	4	main
mida	doc_600559928976_item	2756693	et	4	main
sa	doc_600559928976_item	2756694	et	3	main
kursustel	doc_600559928976_item	2756695	et	3	main
õpid	doc_600559928976_item	2756696	et	4	main
ja	doc_600559928976_item	2756697	et	3	main
et	doc_600559928976_item	2756698	et	3	main
varsti	doc_600559928976_item	2756699	et	3	main
lähete	doc_600559928976_item	2756700	et	4	main
praktikale	doc_600559928976_item	2756701	et	3	main
kirjuta	doc_600559928976_item	2756702	et	4	main
kuhu	doc_600559928976_item	2756703	et	3	main
sa	doc_600559928976_item	2756704	et	3	main
praktikale	doc_600559928976_item	2756705	et	3	main
lähed	doc_600559928976_item	2756706	et	3	main
mis	doc_600559928976_item	2756707	et	4	main
firma	doc_600559928976_item	2756708	et	4	main
see	doc_600559928976_item	2756709	et	3	main
on	doc_600559928976_item	2756710	et	4	main
mida	doc_600559928976_item	2756711	et	4	main
sa	doc_600559928976_item	2756712	et	3	main
seal	doc_600559928976_item	2756713	et	4	main
tegema	doc_600559928976_item	2756714	et	3	main
hakkad	doc_600559928976_item	2756715	et	3	main
tere	doc_600559928976_item	2756716	et	3	main
kallis	doc_600559928976_item	2756717	et	4	main
valja	doc_600559928976_item	2756718	et	3	main
kuidas	doc_600559928976_item	2756719	et	3	main
sa	doc_600559928976_item	2756720	et	3	main
on	doc_600559928976_item	2756737	et	4	main
klienditenindaja	doc_600559928976_item	2756738	et	4	main
marketing	doc_600559928976_item	2756749	et	4	main
nii	doc_600559928976_item	2756752	et	3	main
aga	doc_600559928976_item	2756768	et	3	main
viieteistkümnendal	doc_600559928976_item	2756770	et	4	main
jaanuaril	doc_600559928976_item	2756771	et	3	main
et	doc_600559928976_item	2756801	et	3	main
ajalehti	doc_600559928976_item	2756803	et	4	main
ajakirju	doc_600559928976_item	2756804	et	4	main
postis	doc_600559928976_item	2756808	et	3	main
võtma	doc_600559928976_item	2756823	et	3	main
selle	doc_600559928976_item	2756826	et	4	main
tal	doc_600559928976_item	2756828	et	3	main
mul	doc_600559928976_item	2756722	et	3	main
praegu	doc_600559928976_item	2756727	et	3	main
siin	doc_600559928976_item	2756739	et	4	main
edasi	doc_600559928976_item	2756753	et	3	main
hakkan	doc_600559928976_item	2756760	et	3	main
algab	doc_600559928976_item	2756766	et	3	main
ma	doc_600559928976_item	2756772	et	3	main
leidsin	doc_600559928976_item	2756773	et	3	main
praktikat	doc_600559928976_item	2756774	et	3	main
aseris	doc_600559928976_item	2756775	et	4	main
ma	doc_600559928976_item	2756776	et	3	main
hakkan	doc_600559928976_item	2756777	et	3	main
töötama	doc_600559928976_item	2756778	et	3	main
meie	doc_600559928976_item	2756779	et	4	main
postkontoris	doc_600559928976_item	2756780	et	3	main
ma	doc_600559928976_item	2756781	et	3	main
arvan	doc_600559928976_item	2756782	et	3	main
et	doc_600559928976_item	2756783	et	3	main
on	doc_600559928976_item	2756785	et	4	main
palju	doc_600559928976_item	2756786	et	4	main
seal	doc_600559928976_item	2756784	et	4	main
erinevat	doc_600559928976_item	2756787	et	4	main
töod	doc_600559928976_item	2756788	et	4	main
postis	doc_600559928976_item	2756789	et	3	main
käib	doc_600559928976_item	2756790	et	3	main
palju	doc_600559928976_item	2756791	et	4	main
inimesi	doc_600559928976_item	2756792	et	4	main
nad	doc_600559928976_item	2756793	et	3	main
maksavad	doc_600559928976_item	2756794	et	3	main
oma	doc_600559928976_item	2756795	et	4	main
arveid	doc_600559928976_item	2756796	et	3	main
paljud	doc_600559928976_item	2756797	et	3	main
inimesed	doc_600559928976_item	2756798	et	3	main
veel	doc_600559928976_item	2756806	et	4	main
keegi	doc_600559928976_item	2756819	et	4	main
oma	doc_600559928976_item	2756824	et	4	main
jaoks	doc_600559928976_item	2756827	et	4	main
peab	doc_600559928976_item	2756829	et	4	main
olema	doc_600559928976_item	2756830	et	4	main
sorteerima	doc_600559928976_item	2756844	et	3	main
posti	doc_600559928976_item	2756845	et	4	main
seal	doc_600559928976_item	2756846	et	4	main
töötama	doc_600559928976_item	2756853	et	3	main
väga	doc_600559928976_item	2756859	et	3	main
ma	doc_600559928976_item	2756869	et	3	main
see	doc_600559928976_item	2756873	et	3	main
ma	doc_600559928976_item	2756877	et	3	main
eestlasest	doc_600559928977_item	2756892	et	3	main
kirjuta	doc_600559928977_item	2756898	et	4	main
sa	doc_600559928977_item	2756900	et	3	main
kursustel	doc_600559928977_item	2756901	et	3	main
õpid	doc_600559928977_item	2756902	et	4	main
ja	doc_600559928977_item	2756903	et	3	main
et	doc_600559928977_item	2756904	et	3	main
varsti	doc_600559928977_item	2756905	et	3	main
lähete	doc_600559928977_item	2756906	et	4	main
praktikale	doc_600559928977_item	2756907	et	3	main
kirjuta	doc_600559928977_item	2756908	et	4	main
kuhu	doc_600559928977_item	2756909	et	3	main
sa	doc_600559928977_item	2756910	et	3	main
praktikale	doc_600559928977_item	2756911	et	3	main
lähed	doc_600559928977_item	2756912	et	3	main
mis	doc_600559928977_item	2756913	et	4	main
firma	doc_600559928977_item	2756914	et	4	main
see	doc_600559928977_item	2756915	et	3	main
on	doc_600559928977_item	2756916	et	4	main
mida	doc_600559928977_item	2756917	et	4	main
sa	doc_600559928977_item	2756918	et	3	main
seal	doc_600559928977_item	2756919	et	4	main
tegema	doc_600559928977_item	2756920	et	3	main
peeter	doc_600559928977_item	2756923	et	3	main
sulle	doc_600559928977_item	2756927	et	3	main
kirjutanud	doc_600559928977_item	2756929	et	4	main
on	doc_600559928977_item	2756931	et	4	main
väga	doc_600559928977_item	2756932	et	3	main
kursustel	doc_600559928977_item	2756938	et	3	main
eesti	doc_600559928977_item	2756941	et	4	main
keel	doc_600559928977_item	2756942	et	4	main
firma	doc_600559928977_item	2756948	et	4	main
elektrik	doc_600559928977_item	2756952	et	3	main
kus	doc_600559928977_item	2756956	et	3	main
tööitad	doc_600559928977_item	2756958	et	4	main
siis	doc_600559928976_item	2756841	et	3	main
ma	doc_600559928976_item	2756842	et	3	main
arvutiga	doc_600559928976_item	2756852	et	4	main
postis	doc_600559928976_item	2756857	et	3	main
postisse	doc_600559928976_item	2756871	et	3	main
jalgsi	doc_600559928976_item	2756872	et	3	main
on	doc_600559928976_item	2756874	et	4	main
kohtume	doc_600559928976_item	2756881	et	3	main
sinuga	doc_600559928976_item	2756883	et	3	main
kohtumiseni	doc_600559928976_item	2756887	et	4	main
kirjuta	doc_600559928977_item	2756890	et	4	main
oma	doc_600559928977_item	2756891	et	4	main
praegu	doc_600559928977_item	2756896	et	3	main
mida	doc_600559928977_item	2756899	et	4	main
tere	doc_600559928977_item	2756922	et	3	main
ei	doc_600559928977_item	2756925	et	4	main
rõõmus	doc_600559928977_item	2756933	et	4	main
uudis	doc_600559928977_item	2756934	et	3	main
ma	doc_600559928977_item	2756935	et	3	main
käid	doc_600559928977_item	2756936	et	3	main
praegu	doc_600559928977_item	2756937	et	3	main
õpin	doc_600559928977_item	2756940	et	3	main
seal	doc_600559928977_item	2756950	et	4	main
kuidas	doc_600559928977_item	2756953	et	3	main
asub	doc_600559928976_item	2756863	et	3	main
minu	doc_600559928976_item	2756864	et	3	main
oma	doc_600559928976_item	2756865	et	4	main
maja	doc_600559928976_item	2756866	et	4	main
käin	doc_600559928976_item	2756870	et	3	main
kõik	doc_600559928976_item	2756875	et	4	main
et	doc_600559928976_item	2756879	et	3	main
siis	doc_600559928976_item	2756885	et	3	main
eesnimi	doc_600559928976_item	2756888	et	3	main
et	doc_600559928977_item	2756894	et	3	main
ammu	doc_600559928977_item	2756928	et	4	main
mul	doc_600559928977_item	2756930	et	3	main
lahen	doc_600559928977_item	2756945	et	4	main
praktikale	doc_600559928977_item	2756946	et	3	main
elad	doc_600559928977_item	2756955	et	3	main
sa	doc_600559928977_item	2756957	et	3	main
ma	doc_600559928977_item	2756924	et	3	main
ole	doc_600559928977_item	2756926	et	4	main
ma	doc_600559928977_item	2756939	et	3	main
ehituse	doc_600559928977_item	2756947	et	4	main
sa	doc_600559928977_item	2756954	et	3	main
nägemisine	doc_600559928977_item	2756961	et	4	main
sinu	doc_600559928977_item	2756962	et	3	main
sõber	doc_600559928977_item	2756963	et	3	main
eesnimi	doc_600559928977_item	2756964	et	3	main
sõbrale	doc_600559928981_item	2757354	et	3	main
praegu	doc_600559928981_item	2757357	et	3	main
kirjuta	doc_600559928981_item	2757359	et	4	main
kursustel	doc_600559928981_item	2757362	et	3	main
ja	doc_600559928981_item	2757364	et	3	main
et	doc_600559928981_item	2757365	et	3	main
varsti	doc_600559928981_item	2757366	et	3	main
lähete	doc_600559928981_item	2757367	et	4	main
praktikale	doc_600559928981_item	2757368	et	3	main
tiina	doc_600559928981_item	2757384	et	4	main
sinult	doc_600559928981_item	2757386	et	3	main
ei	doc_600559928981_item	2757394	et	4	main
veel	doc_600559928981_item	2757423	et	4	main
müüjad	doc_600559928981_item	2757426	et	4	main
müüjad	doc_600559928981_item	2757428	et	4	main
mulle	doc_600559928981_item	2757429	et	4	main
meldib	doc_600559928981_item	2757430	et	4	main
kaaluma	doc_600559928981_item	2757431	et	3	main
produkt	doc_600559928981_item	2757432	et	3	main
töötad	doc_600559928981_item	2757440	et	3	main
ma	doc_600559928981_item	2757446	et	3	main
kiri	doc_600559928982_item	2757451	et	3	main
et	doc_600559928982_item	2757456	et	3	main
kursustel	doc_600559928982_item	2757459	et	3	main
varsti	doc_600559928982_item	2757467	et	3	main
praktikale	doc_600559928982_item	2757469	et	3	main
seal	doc_600559928982_item	2757481	et	4	main
hakkad	doc_600559928982_item	2757483	et	3	main
õppimenud	doc_600559928982_item	2757519	et	4	main
eesti	doc_600559928982_item	2757521	et	4	main
keskkoolis	doc_600559928982_item	2757527	et	4	main
eesnimi	doc_600559928982_item	2757529	et	3	main
eestlasest	doc_600559928981_item	2757353	et	3	main
et	doc_600559928981_item	2757355	et	3	main
kirjuta	doc_600559928981_item	2757369	et	4	main
kuhu	doc_600559928981_item	2757370	et	3	main
mis	doc_600559928981_item	2757374	et	4	main
see	doc_600559928981_item	2757376	et	3	main
olnud	doc_600559928981_item	2757395	et	4	main
aega	doc_600559928981_item	2757396	et	4	main
mul	doc_600559928981_item	2757397	et	3	main
on	doc_600559928981_item	2757398	et	4	main
uus	doc_600559928981_item	2757399	et	3	main
uudis	doc_600559928981_item	2757400	et	3	main
praegu	doc_600559928981_item	2757401	et	3	main
pildistama	doc_600559928981_item	2757421	et	3	main
fotoatelje	doc_600559928981_item	2757434	et	4	main
samuti	doc_600559928981_item	2757435	et	3	main
kus	doc_600559928981_item	2757438	et	3	main
sa	doc_600559928981_item	2757439	et	3	main
mulle	doc_600559928981_item	2757442	et	4	main
või	doc_600559928981_item	2757443	et	4	main
vastus	doc_600559928981_item	2757448	et	3	main
õpid	doc_600559928982_item	2757464	et	4	main
kuhu	doc_600559928982_item	2757471	et	3	main
praktikale	doc_600559928982_item	2757473	et	3	main
tegema	doc_600559928982_item	2757482	et	3	main
mul	doc_600559928982_item	2757515	et	3	main
ma	doc_600559928982_item	2757524	et	3	main
töötab	doc_600559928982_item	2757526	et	3	main
nagemis	doc_600559928982_item	2757528	et	4	main
kiri	doc_600559928981_item	2757350	et	3	main
kirjuta	doc_600559928981_item	2757351	et	4	main
sa	doc_600559928981_item	2757371	et	3	main
mida	doc_600559928981_item	2757378	et	4	main
tegema	doc_600559928981_item	2757381	et	3	main
hakkad	doc_600559928981_item	2757382	et	3	main
tere	doc_600559928981_item	2757383	et	3	main
hiljuti	doc_600559928981_item	2757387	et	4	main
ei	doc_600559928981_item	2757391	et	4	main
vastunud	doc_600559928981_item	2757392	et	4	main
mul	doc_600559928981_item	2757393	et	3	main
oma	doc_600559928981_item	2757352	et	4	main
käid	doc_600559928981_item	2757356	et	3	main
kursustel	doc_600559928981_item	2757358	et	3	main
praktikale	doc_600559928981_item	2757372	et	3	main
sa	doc_600559928981_item	2757379	et	3	main
seal	doc_600559928981_item	2757380	et	4	main
kirja	doc_600559928981_item	2757388	et	4	main
kohe	doc_600559928981_item	2757390	et	4	main
ma	doc_600559928981_item	2757402	et	3	main
käin	doc_600559928981_item	2757403	et	3	main
kursustel	doc_600559928981_item	2757404	et	3	main
kursustel	doc_600559928981_item	2757405	et	3	main
ma	doc_600559928981_item	2757406	et	3	main
õpin	doc_600559928981_item	2757407	et	3	main
eestikeel	doc_600559928981_item	2757408	et	4	main
arvuti	doc_600559928981_item	2757409	et	4	main
varsti	doc_600559928981_item	2757410	et	3	main
lähen	doc_600559928981_item	2757411	et	3	main
praktikale	doc_600559928981_item	2757412	et	3	main
ma	doc_600559928981_item	2757413	et	3	main
lähen	doc_600559928981_item	2757414	et	3	main
praktikale	doc_600559928981_item	2757415	et	3	main
fotoatelje	doc_600559928981_item	2757416	et	4	main
firmas	doc_600559928981_item	2757417	et	3	main
seal	doc_600559928981_item	2757418	et	4	main
ma	doc_600559928981_item	2757419	et	3	main
hakkan	doc_600559928981_item	2757420	et	3	main
ma	doc_600559928981_item	2757424	et	3	main
anne	doc_600559928981_item	2757444	et	4	main
teatmine	doc_600559928981_item	2757445	et	4	main
ja	doc_600559928982_item	2757465	et	3	main
sa	doc_600559928982_item	2757472	et	3	main
mis	doc_600559928982_item	2757475	et	4	main
tere	doc_600559928982_item	2757484	et	3	main
on	doc_600559928982_item	2757516	et	4	main
me	doc_600559928982_item	2757518	et	4	main
kursusel	doc_600559928982_item	2757520	et	3	main
hakkan	doc_600559928982_item	2757525	et	3	main
mida	doc_600559928981_item	2757360	et	4	main
sa	doc_600559928981_item	2757361	et	3	main
õpid	doc_600559928981_item	2757363	et	4	main
lähed	doc_600559928981_item	2757373	et	3	main
firma	doc_600559928981_item	2757375	et	4	main
on	doc_600559928981_item	2757377	et	4	main
sain	doc_600559928981_item	2757385	et	3	main
aga	doc_600559928981_item	2757389	et	3	main
inimesed	doc_600559928981_item	2757422	et	3	main
lihad	doc_600559928981_item	2757427	et	3	main
nagemist	doc_600559928981_item	2757449	et	4	main
eesnimi	doc_600559928981_item	2757450	et	3	main
kirjuta	doc_600559928982_item	2757452	et	4	main
sõbrale	doc_600559928982_item	2757455	et	3	main
praegu	doc_600559928982_item	2757458	et	3	main
et	doc_600559928982_item	2757466	et	3	main
kirjuta	doc_600559928982_item	2757470	et	4	main
lähed	doc_600559928982_item	2757474	et	3	main
firma	doc_600559928982_item	2757476	et	4	main
see	doc_600559928982_item	2757477	et	3	main
on	doc_600559928982_item	2757478	et	4	main
keel	doc_600559928982_item	2757522	et	4	main
hakkan	doc_600559928981_item	2757425	et	3	main
firma	doc_600559928981_item	2757433	et	4	main
hea	doc_600559928981_item	2757436	et	4	main
aga	doc_600559928981_item	2757437	et	3	main
kirjutad	doc_600559928981_item	2757441	et	3	main
ootan	doc_600559928981_item	2757447	et	3	main
oma	doc_600559928982_item	2757453	et	4	main
eestlasest	doc_600559928982_item	2757454	et	3	main
käid	doc_600559928982_item	2757457	et	3	main
kirjuta	doc_600559928982_item	2757460	et	4	main
mida	doc_600559928982_item	2757461	et	4	main
sa	doc_600559928982_item	2757462	et	3	main
kursustel	doc_600559928982_item	2757463	et	3	main
lähete	doc_600559928982_item	2757468	et	4	main
mida	doc_600559928982_item	2757479	et	4	main
sa	doc_600559928982_item	2757480	et	3	main
tina	doc_600559928982_item	2757485	et	4	main
kuidas	doc_600559928982_item	2757486	et	3	main
on	doc_600559928982_item	2757487	et	4	main
sinu	doc_600559928982_item	2757488	et	3	main
tervis	doc_600559928982_item	2757489	et	3	main
mul	doc_600559928982_item	2757490	et	3	main
on	doc_600559928982_item	2757491	et	4	main
hea	doc_600559928982_item	2757492	et	4	main
tuju	doc_600559928982_item	2757493	et	4	main
ma	doc_600559928982_item	2757494	et	3	main
ostsin	doc_600559928982_item	2757495	et	3	main
korteri	doc_600559928982_item	2757496	et	3	main
möödunud	doc_600559928982_item	2757497	et	4	main
nädalal	doc_600559928982_item	2757498	et	3	main
see	doc_600559928982_item	2757499	et	3	main
on	doc_600559928982_item	2757500	et	4	main
viiekorruselise	doc_600559928982_item	2757501	et	4	main
majas	doc_600559928982_item	2757502	et	3	main
minu	doc_600559928982_item	2757503	et	3	main
korter	doc_600559928982_item	2757504	et	3	main
on	doc_600559928982_item	2757505	et	4	main
neljandal	doc_600559928982_item	2757506	et	3	main
korrusel	doc_600559928982_item	2757507	et	3	main
mulle	doc_600559928982_item	2757508	et	4	main
meeldib	doc_600559928982_item	2757509	et	3	main
korterväga	doc_600559928982_item	2757510	et	4	main
ma	doc_600559928982_item	2757511	et	3	main
käisin	doc_600559928982_item	2757512	et	3	main
kursusse	doc_600559928982_item	2757513	et	3	main
klienditenindaja	doc_600559928982_item	2757514	et	4	main
meldib	doc_600559928982_item	2757517	et	4	main
psuhholoogija	doc_600559928982_item	2757523	et	4	main
sõbrale	doc_600559928990_item	2758557	et	3	main
praegu	doc_600559928990_item	2758560	et	3	main
firma	doc_600559928990_item	2758578	et	4	main
see	doc_600559928990_item	2758579	et	3	main
seal	doc_600559928990_item	2758583	et	4	main
hakkad	doc_600559928990_item	2758585	et	3	main
on	doc_600559928990_item	2758589	et	4	main
aega	doc_600559928990_item	2758590	et	4	main
et	doc_600559928990_item	2758558	et	3	main
kursustel	doc_600559928990_item	2758561	et	3	main
sa	doc_600559928990_item	2758564	et	3	main
õpid	doc_600559928990_item	2758566	et	4	main
varsti	doc_600559928990_item	2758569	et	3	main
on	doc_600559928990_item	2758580	et	4	main
tegema	doc_600559928990_item	2758584	et	3	main
pärast	doc_600559928990_item	2758631	et	4	main
huvitav	doc_600559928990_item	2758642	et	4	main
õppesime	doc_600559928990_item	2758644	et	4	main
meil	doc_600559928990_item	2758647	et	4	main
oli	doc_600559928990_item	2758648	et	3	main
psühholoogiat	doc_600559928990_item	2758649	et	3	main
arvutit	doc_600559928990_item	2758650	et	3	main
me	doc_600559928990_item	2758657	et	4	main
lõpetame	doc_600559928990_item	2758658	et	3	main
varsti	doc_600559928990_item	2758661	et	3	main
läheme	doc_600559928990_item	2758663	et	3	main
aga	doc_600559928990_item	2758671	et	3	main
lilled	doc_600559928990_item	2758679	et	3	main
kirja	doc_600559928990_item	2758688	et	4	main
ära	doc_600559928990_item	2758689	et	4	main
mind	doc_600559928990_item	2758691	et	4	main
kirjuta	doc_600559928990_item	2758554	et	4	main
ei	doc_600559928990_item	2758625	et	4	main
hästi	doc_600559928990_item	2758633	et	3	main
kursustel	doc_600559928990_item	2758637	et	3	main
on	doc_600559928990_item	2758640	et	4	main
asjaajaminst	doc_600559928990_item	2758651	et	4	main
esmaabi	doc_600559928990_item	2758652	et	4	main
ma	doc_600559928990_item	2758665	et	3	main
ma	doc_600559928990_item	2758669	et	3	main
lähen	doc_600559928990_item	2758674	et	3	main
kiri	doc_600559928990_item	2758553	et	3	main
kirjuta	doc_600559928990_item	2758562	et	4	main
et	doc_600559928990_item	2758568	et	3	main
sa	doc_600559928990_item	2758582	et	3	main
tere	doc_600559928990_item	2758586	et	3	main
mul	doc_600559928990_item	2758588	et	3	main
ja	doc_600559928990_item	2758591	et	3	main
ma	doc_600559928990_item	2758592	et	3	main
kirjutan	doc_600559928990_item	2758593	et	3	main
sulle	doc_600559928990_item	2758594	et	3	main
kirja	doc_600559928990_item	2758595	et	4	main
kuidas	doc_600559928990_item	2758596	et	3	main
sa	doc_600559928990_item	2758597	et	3	main
elad	doc_600559928990_item	2758598	et	3	main
kuidas	doc_600559928990_item	2758599	et	3	main
elavad	doc_600559928990_item	2758600	et	4	main
sinu	doc_600559928990_item	2758601	et	3	main
õed	doc_600559928990_item	2758602	et	3	main
virgi	doc_600559928990_item	2758603	et	4	main
ja	doc_600559928990_item	2758604	et	3	main
kristi	doc_600559928990_item	2758605	et	4	main
ma	doc_600559928990_item	2758606	et	3	main
kuulsin	doc_600559928990_item	2758607	et	3	main
et	doc_600559928990_item	2758608	et	3	main
virgi	doc_600559928990_item	2758609	et	4	main
abiellus	doc_600559928990_item	2758610	et	3	main
õnnetlen	doc_600559928990_item	2758611	et	4	main
teda	doc_600559928990_item	2758612	et	4	main
mul	doc_600559928990_item	2758613	et	3	main
on	doc_600559928990_item	2758614	et	4	main
kõik	doc_600559928990_item	2758615	et	4	main
hästi	doc_600559928990_item	2758616	et	3	main
minu	doc_600559928990_item	2758617	et	3	main
tütar	doc_600559928990_item	2758618	et	3	main
žlata	doc_600559928990_item	2758619	et	2	main
käib	doc_600559928990_item	2758620	et	3	main
lasteaias	doc_600559928990_item	2758621	et	4	main
nädal	doc_600559928990_item	2758623	et	3	main
praegu	doc_600559928990_item	2758634	et	3	main
käin	doc_600559928990_item	2758636	et	3	main
klienditeenindaja	doc_600559928990_item	2758638	et	4	main
eesti	doc_600559928990_item	2758659	et	4	main
praktikale	doc_600559928990_item	2758664	et	3	main
arvan	doc_600559928990_item	2758672	et	3	main
oma	doc_600559928990_item	2758555	et	4	main
eestlasest	doc_600559928990_item	2758556	et	3	main
käid	doc_600559928990_item	2758559	et	3	main
mida	doc_600559928990_item	2758563	et	4	main
kursustel	doc_600559928990_item	2758565	et	3	main
ja	doc_600559928990_item	2758567	et	3	main
lähete	doc_600559928990_item	2758570	et	4	main
praktikale	doc_600559928990_item	2758571	et	3	main
kirjuta	doc_600559928990_item	2758572	et	4	main
kuhu	doc_600559928990_item	2758573	et	3	main
sa	doc_600559928990_item	2758574	et	3	main
praktikale	doc_600559928990_item	2758575	et	3	main
lähed	doc_600559928990_item	2758576	et	3	main
mis	doc_600559928990_item	2758577	et	4	main
mida	doc_600559928990_item	2758581	et	4	main
tiina	doc_600559928990_item	2758587	et	4	main
esimesel	doc_600559928990_item	2758622	et	3	main
läks	doc_600559928990_item	2758632	et	3	main
väga	doc_600559928990_item	2758641	et	3	main
me	doc_600559928990_item	2758643	et	4	main
palju	doc_600559928990_item	2758645	et	4	main
õppeainet	doc_600559928990_item	2758646	et	3	main
tööturgu	doc_600559928990_item	2758653	et	4	main
ja	doc_600559928990_item	2758654	et	3	main
teised	doc_600559928990_item	2758655	et	4	main
praegu	doc_600559928990_item	2758656	et	3	main
keel	doc_600559928990_item	2758660	et	4	main
tea	doc_600559928990_item	2758667	et	4	main
kuhu	doc_600559928990_item	2758668	et	3	main
et	doc_600559928990_item	2758673	et	3	main
lillekauplusse	doc_600559928990_item	2758675	et	3	main
tahan	doc_600559928990_item	2758677	et	3	main
ja	doc_600559928990_item	2758680	et	3	main
sinu	doc_600559928990_item	2758692	et	3	main
eesnimi	doc_600559928990_item	2758694	et	3	main
ta	doc_600559928990_item	2758624	et	4	main
tahtnud	doc_600559928990_item	2758626	et	4	main
minna	doc_600559928990_item	2758627	et	3	main
ja	doc_600559928990_item	2758628	et	3	main
nuttis	doc_600559928990_item	2758629	et	3	main
aga	doc_600559928990_item	2758630	et	3	main
ma	doc_600559928990_item	2758635	et	3	main
see	doc_600559928990_item	2758639	et	3	main
me	doc_600559928990_item	2758662	et	4	main
ei	doc_600559928990_item	2758666	et	4	main
lähen	doc_600559928990_item	2758670	et	3	main
seal	doc_600559928990_item	2758676	et	4	main
müüa	doc_600559928990_item	2758678	et	3	main
suhtleda	doc_600559928990_item	2758681	et	4	main
kliediga	doc_600559928990_item	2758682	et	4	main
ma	doc_600559928990_item	2758683	et	3	main
lõpetan	doc_600559928990_item	2758684	et	3	main
kirja	doc_600559928990_item	2758685	et	4	main
ootan	doc_600559928990_item	2758686	et	3	main
sinu	doc_600559928990_item	2758687	et	3	main
unusta	doc_600559928990_item	2758690	et	4	main
sõbranna	doc_600559928990_item	2758693	et	4	main
kiri	doc_600559928995_item	2759178	et	3	main
oma	doc_600559928995_item	2759179	et	4	main
eestlasest	doc_600559928995_item	2759180	et	3	main
sõbrale	doc_600559928995_item	2759181	et	3	main
kirjutage	doc_600559928995_item	2759182	et	3	main
millal	doc_600559928995_item	2759183	et	3	main
reisite	doc_600559928995_item	2759190	et	3	main
ööbite	doc_600559928995_item	2759192	et	3	main
millistes	doc_600559928995_item	2759197	et	3	main
kirja	doc_600559928995_item	2759200	et	4	main
pikkus	doc_600559928995_item	2759202	et	4	main
reisi	doc_600559928995_item	2759210	et	4	main
ma	doc_600559928995_item	2759222	et	3	main
ema	doc_600559928995_item	2759229	et	4	main
ja	doc_600559928995_item	2759230	et	3	main
isa	doc_600559928995_item	2759231	et	4	main
reisi	doc_600559928996_item	2759250	et	4	main
te	doc_600559928996_item	2759262	et	4	main
kui	doc_600559928996_item	2759269	et	3	main
sõita	doc_600559928996_item	2759291	et	3	main
1februaril	doc_600559928996_item	2759292	et	4	main
samarasse	doc_600559928996_item	2759293	et	3	main
ma	doc_600559928996_item	2759294	et	3	main
sõidan	doc_600559928996_item	2759295	et	3	main
lennukiga	doc_600559928996_item	2759296	et	3	main
see	doc_600559928996_item	2759297	et	3	main
pilet	doc_600559928996_item	2759298	et	3	main
maksab	doc_600559928996_item	2759299	et	3	main
ma	doc_600559928996_item	2759305	et	3	main
ma	doc_600559928996_item	2759309	et	3	main
temaga	doc_600559928996_item	2759312	et	3	main
sõbrad	doc_600559928996_item	2759314	et	3	main
samarasse	doc_600559928996_item	2759316	et	3	main
armastan	doc_600559928996_item	2759321	et	3	main
te	doc_600559928997_item	2759326	et	4	main
soovite	doc_600559928997_item	2759342	et	3	main
kui	doc_600559928997_item	2759347	et	3	main
pikkus	doc_600559928997_item	2759356	et	4	main
te	doc_600559928995_item	2759172	et	4	main
reisi	doc_600559928995_item	2759174	et	4	main
venemaale	doc_600559928995_item	2759175	et	4	main
kirjutage	doc_600559928995_item	2759176	et	3	main
sellest	doc_600559928995_item	2759177	et	4	main
te	doc_600559928995_item	2759186	et	4	main
sõita	doc_600559928995_item	2759187	et	3	main
millega	doc_600559928995_item	2759189	et	3	main
kus	doc_600559928995_item	2759191	et	3	main
kohtades	doc_600559928995_item	2759198	et	3	main
sõna	doc_600559928995_item	2759205	et	4	main
lugupetud	doc_600559928995_item	2759206	et	3	main
anna	doc_600559928995_item	2759207	et	4	main
ma	doc_600559928995_item	2759208	et	3	main
palju	doc_600559928995_item	2759194	et	4	main
maksab	doc_600559928995_item	2759196	et	3	main
peatute	doc_600559928995_item	2759199	et	4	main
nõutav	doc_600559928995_item	2759201	et	4	main
venemaale	doc_600559928995_item	2759211	et	4	main
elavad	doc_600559928995_item	2759215	et	4	main
ööbin	doc_600559928995_item	2759223	et	3	main
isa	doc_600559928995_item	2759227	et	4	main
ma	doc_600559928995_item	2759235	et	3	main
venemaale	doc_600559928996_item	2759251	et	4	main
oma	doc_600559928996_item	2759255	et	4	main
sõbrale	doc_600559928996_item	2759257	et	3	main
ja	doc_600559928996_item	2759260	et	3	main
reisite	doc_600559928996_item	2759266	et	3	main
ööbite	doc_600559928996_item	2759268	et	3	main
ma	doc_600559928996_item	2759302	et	3	main
elavad	doc_600559928996_item	2759315	et	4	main
ma	doc_600559928996_item	2759317	et	3	main
puhkata	doc_600559928996_item	2759319	et	4	main
nägemist	doc_600559928996_item	2759323	et	4	main
reisi	doc_600559928997_item	2759328	et	4	main
millega	doc_600559928997_item	2759343	et	3	main
millistes	doc_600559928997_item	2759351	et	3	main
umbes	doc_600559928997_item	2759357	et	4	main
küsisid	doc_600559928997_item	2759367	et	4	main
ma	doc_600559928997_item	2759371	et	3	main
näiteks	doc_600559928997_item	2759406	et	4	main
seal	doc_600559928997_item	2759407	et	4	main
etendus	doc_600559928997_item	2759411	et	4	main
ma	doc_600559928997_item	2759437	et	3	main
lähen	doc_600559928997_item	2759440	et	3	main
see	doc_600559928997_item	2759444	et	3	main
on	doc_600559928997_item	2759445	et	4	main
kogu	doc_600559928997_item	2759453	et	4	main
reisi	doc_600559928997_item	2759454	et	4	main
umbes	doc_600559928997_item	2759457	et	4	main
tuhat	doc_600559928997_item	2759458	et	4	main
veel	doc_600559928997_item	2759461	et	4	main
vaja	doc_600559928997_item	2759465	et	4	main
10	doc_600559928997_item	2759468	et	2	main
tore	doc_600559928997_item	2759476	et	3	main
on	doc_600559928997_item	2759483	et	4	main
head	doc_600559928997_item	2759492	et	4	main
eesnimi	doc_600559928997_item	2759493	et	3	main
plaanite	doc_600559928995_item	2759173	et	3	main
kuhu	doc_600559928995_item	2759185	et	3	main
soovite	doc_600559928995_item	2759188	et	3	main
plaanin	doc_600559928995_item	2759209	et	3	main
kaliningradis	doc_600559928995_item	2759212	et	4	main
minu	doc_600559928995_item	2759213	et	3	main
vanemad	doc_600559928995_item	2759214	et	4	main
ma	doc_600559928995_item	2759218	et	3	main
sõitan	doc_600559928995_item	2759219	et	4	main
bussiga	doc_600559928995_item	2759220	et	3	main
kaliningradis	doc_600559928995_item	2759224	et	4	main
kooli	doc_600559928995_item	2759240	et	4	main
kus	doc_600559928995_item	2759241	et	3	main
ma	doc_600559928995_item	2759242	et	3	main
oppisin	doc_600559928995_item	2759243	et	4	main
eesnimi	doc_600559928995_item	2759245	et	3	main
kiri	doc_600559928996_item	2759254	et	3	main
kirjutage	doc_600559928996_item	2759258	et	3	main
kuhu	doc_600559928996_item	2759261	et	3	main
soovite	doc_600559928996_item	2759264	et	3	main
ma	doc_600559928996_item	2759289	et	3	main
1600	doc_600559928996_item	2759300	et	2	main
eek	doc_600559928996_item	2759301	et	4	main
tallinnas	doc_600559928996_item	2759304	et	4	main
abikaasaga	doc_600559928996_item	2759307	et	3	main
soovin	doc_600559928996_item	2759310	et	3	main
minu	doc_600559928996_item	2759313	et	3	main
ma	doc_600559928996_item	2759320	et	3	main
reisida	doc_600559928996_item	2759322	et	3	main
te	doc_600559928997_item	2759340	et	4	main
sõita	doc_600559928997_item	2759341	et	3	main
maksab	doc_600559928997_item	2759350	et	3	main
80	doc_600559928997_item	2759358	et	2	main
sõna	doc_600559928997_item	2759359	et	4	main
tere	doc_600559928997_item	2759360	et	3	main
mare	doc_600559928997_item	2759361	et	4	main
sain	doc_600559928997_item	2759362	et	3	main
sinult	doc_600559928997_item	2759363	et	3	main
kirja	doc_600559928997_item	2759364	et	4	main
plaanidest	doc_600559928997_item	2759369	et	3	main
saaksin	doc_600559928997_item	2759401	et	3	main
mingi	doc_600559928997_item	2759402	et	4	main
palju	doc_600559928997_item	2759426	et	4	main
ilusamaid	doc_600559928997_item	2759427	et	4	main
kohti	doc_600559928997_item	2759428	et	4	main
ja	doc_600559928997_item	2759429	et	3	main
praegu	doc_600559928997_item	2759430	et	3	main
ma	doc_600559928997_item	2759431	et	3	main
ei	doc_600559928997_item	2759432	et	4	main
öelda	doc_600559928997_item	2759435	et	4	main
seal	doc_600559928997_item	2759438	et	4	main
natuke	doc_600559928997_item	2759449	et	4	main
odavam	doc_600559928997_item	2759450	et	4	main
arvan	doc_600559928997_item	2759451	et	3	main
et	doc_600559928997_item	2759452	et	3	main
seda	doc_600559928997_item	2759473	et	3	main
oleks	doc_600559928997_item	2759475	et	3	main
tahaks	doc_600559928997_item	2759486	et	3	main
sinult	doc_600559928997_item	2759489	et	3	main
kiri	doc_600559928995_item	2759171	et	3	main
ja	doc_600559928995_item	2759184	et	3	main
kui	doc_600559928995_item	2759193	et	3	main
see	doc_600559928995_item	2759195	et	3	main
umbes	doc_600559928995_item	2759203	et	4	main
80	doc_600559928995_item	2759204	et	2	main
kaliningradis	doc_600559928995_item	2759216	et	4	main
suvel	doc_600559928995_item	2759217	et	3	main
venemaale	doc_600559928995_item	2759221	et	4	main
ja	doc_600559928995_item	2759226	et	3	main
jurde	doc_600559928995_item	2759228	et	4	main
plaanin	doc_600559928995_item	2759236	et	3	main
13062005	doc_600559928995_item	2759244	et	2	main
kiri	doc_600559928996_item	2759247	et	3	main
plaanite	doc_600559928996_item	2759249	et	3	main
sellest	doc_600559928996_item	2759253	et	4	main
millal	doc_600559928996_item	2759259	et	3	main
sõita	doc_600559928996_item	2759263	et	3	main
millega	doc_600559928996_item	2759265	et	3	main
ööbin	doc_600559928996_item	2759303	et	3	main
sõidan	doc_600559928996_item	2759306	et	3	main
reisida	doc_600559928996_item	2759311	et	3	main
tahan	doc_600559928996_item	2759318	et	3	main
ema	doc_600559928995_item	2759225	et	4	main
elavad	doc_600559928995_item	2759232	et	4	main
eramajas	doc_600559928995_item	2759233	et	3	main
kesklinnas	doc_600559928995_item	2759234	et	4	main
peatu	doc_600559928995_item	2759237	et	4	main
museumid	doc_600559928995_item	2759238	et	4	main
zoo	doc_600559928995_item	2759239	et	4	main
perekonnanimi	doc_600559928995_item	2759246	et	3	main
te	doc_600559928996_item	2759248	et	4	main
kirjutage	doc_600559928996_item	2759252	et	3	main
eestlasest	doc_600559928996_item	2759256	et	3	main
kus	doc_600559928996_item	2759267	et	3	main
palju	doc_600559928996_item	2759270	et	4	main
see	doc_600559928996_item	2759271	et	3	main
maksab	doc_600559928996_item	2759272	et	3	main
millistes	doc_600559928996_item	2759273	et	3	main
kohtades	doc_600559928996_item	2759274	et	3	main
peatute	doc_600559928996_item	2759275	et	4	main
kirja	doc_600559928996_item	2759276	et	4	main
pikkus	doc_600559928996_item	2759278	et	4	main
nõutav	doc_600559928996_item	2759277	et	4	main
umbes	doc_600559928996_item	2759279	et	4	main
80	doc_600559928996_item	2759280	et	2	main
sõna	doc_600559928996_item	2759281	et	4	main
01012005	doc_600559928996_item	2759282	et	2	main
tere	doc_600559928996_item	2759283	et	3	main
tiina	doc_600559928996_item	2759284	et	4	main
ma	doc_600559928996_item	2759285	et	3	main
plaanin	doc_600559928996_item	2759286	et	3	main
reisi	doc_600559928996_item	2759287	et	4	main
venemaale	doc_600559928996_item	2759288	et	4	main
soovin	doc_600559928996_item	2759290	et	3	main
aga	doc_600559928996_item	2759308	et	3	main
eesnimi	doc_600559928996_item	2759324	et	3	main
plaanite	doc_600559928997_item	2759327	et	3	main
kirjutage	doc_600559928997_item	2759330	et	3	main
kiri	doc_600559928997_item	2759332	et	3	main
reisite	doc_600559928997_item	2759344	et	3	main
see	doc_600559928997_item	2759349	et	3	main
kohtades	doc_600559928997_item	2759352	et	3	main
kirja	doc_600559928997_item	2759354	et	4	main
nõutav	doc_600559928997_item	2759355	et	4	main
praegu	doc_600559928997_item	2759370	et	3	main
puhkus	doc_600559928997_item	2759375	et	3	main
kui	doc_600559928997_item	2759400	et	3	main
etendusele	doc_600559928997_item	2759404	et	4	main
minna	doc_600559928997_item	2759405	et	3	main
ei	doc_600559928997_item	2759413	et	4	main
tea	doc_600559928997_item	2759414	et	4	main
kui	doc_600559928997_item	2759416	et	3	main
mis	doc_600559928997_item	2759421	et	4	main
etendub	doc_600559928997_item	2759423	et	3	main
peterburis	doc_600559928997_item	2759424	et	4	main
on	doc_600559928997_item	2759425	et	4	main
saa	doc_600559928997_item	2759433	et	4	main
millega	doc_600559928997_item	2759436	et	3	main
sinna	doc_600559928997_item	2759441	et	3	main
sest	doc_600559928997_item	2759443	et	4	main
ja	doc_600559928997_item	2759447	et	3	main
isegi	doc_600559928997_item	2759448	et	4	main
viisa	doc_600559928997_item	2759464	et	4	main
juunil	doc_600559928997_item	2759469	et	3	main
palvetan	doc_600559928997_item	2759471	et	3	main
et	doc_600559928997_item	2759474	et	3	main
päikesepaisteline	doc_600559928997_item	2759477	et	4	main
ilm	doc_600559928997_item	2759478	et	3	main
aga	doc_600559928997_item	2759479	et	3	main
mis	doc_600559928997_item	2759480	et	4	main
sul	doc_600559928997_item	2759481	et	3	main
sa	doc_600559928997_item	2759485	et	3	main
ootan	doc_600559928997_item	2759488	et	3	main
kiri	doc_600559928997_item	2759325	et	3	main
venemaale	doc_600559928997_item	2759329	et	4	main
sellest	doc_600559928997_item	2759331	et	4	main
oma	doc_600559928997_item	2759333	et	4	main
eestlasest	doc_600559928997_item	2759334	et	3	main
sõbrale	doc_600559928997_item	2759335	et	3	main
kirjutage	doc_600559928997_item	2759336	et	3	main
millal	doc_600559928997_item	2759337	et	3	main
ja	doc_600559928997_item	2759338	et	3	main
kuhu	doc_600559928997_item	2759339	et	3	main
kus	doc_600559928997_item	2759345	et	3	main
ööbite	doc_600559928997_item	2759346	et	3	main
palju	doc_600559928997_item	2759348	et	4	main
peatute	doc_600559928997_item	2759353	et	4	main
mu	doc_600559928997_item	2759368	et	3	main
sõita	doc_600559928997_item	2759373	et	3	main
lühike	doc_600559928997_item	2759377	et	4	main
ja	doc_600559928997_item	2759378	et	3	main
sellepärast	doc_600559928997_item	2759379	et	3	main
sõidan	doc_600559928997_item	2759380	et	3	main
peterburii	doc_600559928997_item	2759381	et	4	main
kolmaks	doc_600559928997_item	2759382	et	4	main
päevaks	doc_600559928997_item	2759383	et	3	main
seal	doc_600559928997_item	2759384	et	4	main
elavad	doc_600559928997_item	2759385	et	4	main
mu	doc_600559928997_item	2759386	et	3	main
sõbrad	doc_600559928997_item	2759387	et	3	main
ja	doc_600559928997_item	2759388	et	3	main
ma	doc_600559928997_item	2759389	et	3	main
saan	doc_600559928997_item	2759390	et	4	main
nendel	doc_600559928997_item	2759391	et	4	main
ööbida	doc_600559928997_item	2759392	et	3	main
suur	doc_600559928997_item	2759393	et	3	main
soov	doc_600559928997_item	2759394	et	3	main
lihtsalt	doc_600559928997_item	2759395	et	4	main
jalutada	doc_600559928997_item	2759396	et	3	main
aga	doc_600559928997_item	2759397	et	3	main
oleks	doc_600559928997_item	2759398	et	3	main
kus	doc_600559928997_item	2759365	et	3	main
sa	doc_600559928997_item	2759366	et	3	main
tahan	doc_600559928997_item	2759372	et	3	main
venemaale	doc_600559928997_item	2759374	et	4	main
on	doc_600559928997_item	2759376	et	4	main
teatri	doc_600559928997_item	2759403	et	3	main
komöödia	doc_600559928997_item	2759410	et	4	main
bussiga	doc_600559928997_item	2759442	et	3	main
mugavam	doc_600559928997_item	2759446	et	4	main
krooni	doc_600559928997_item	2759459	et	4	main
lähen	doc_600559928997_item	2759466	et	3	main
sinna	doc_600559928997_item	2759467	et	3	main
praegu	doc_600559928997_item	2759470	et	3	main
ainult	doc_600559928997_item	2759472	et	4	main
kuhu	doc_600559928997_item	2759484	et	3	main
vastust	doc_600559928997_item	2759490	et	4	main
08062005	doc_600559928997_item	2759494	et	2	main
te	doc_600559929001_item	2759885	et	4	main
millega	doc_600559929001_item	2759888	et	3	main
ööbite	doc_600559929001_item	2759891	et	3	main
palju	doc_600559929001_item	2759893	et	4	main
on	doc_600559929001_item	2759913	et	4	main
sõidan	doc_600559929001_item	2759916	et	3	main
ma	doc_600559929001_item	2759918	et	3	main
sõidan	doc_600559929001_item	2759919	et	3	main
rongiga	doc_600559929001_item	2759920	et	4	main
tore	doc_600559928997_item	2759399	et	3	main
on	doc_600559928997_item	2759408	et	4	main
hea	doc_600559928997_item	2759409	et	4	main
aga	doc_600559928997_item	2759412	et	3	main
veel	doc_600559928997_item	2759415	et	4	main
palju	doc_600559928997_item	2759417	et	4	main
pilet	doc_600559928997_item	2759418	et	3	main
maksab	doc_600559928997_item	2759419	et	3	main
ja	doc_600559928997_item	2759420	et	3	main
seal	doc_600559928997_item	2759422	et	4	main
veel	doc_600559928997_item	2759434	et	4	main
tegelen	doc_600559928997_item	2759439	et	3	main
eest	doc_600559928997_item	2759455	et	4	main
maksan	doc_600559928997_item	2759456	et	3	main
sest	doc_600559928997_item	2759460	et	4	main
mul	doc_600559928997_item	2759462	et	3	main
on	doc_600559928997_item	2759463	et	4	main
plaanis	doc_600559928997_item	2759482	et	4	main
sõita	doc_600559928997_item	2759487	et	3	main
kõike	doc_600559928997_item	2759491	et	4	main
plaanite	doc_600559929001_item	2759872	et	3	main
soovite	doc_600559929001_item	2759887	et	3	main
millistes	doc_600559929001_item	2759896	et	3	main
umbes	doc_600559929001_item	2759902	et	4	main
sõna	doc_600559929001_item	2759904	et	4	main
tere	doc_600559929001_item	2759905	et	3	main
sõber	doc_600559929001_item	2759906	et	3	main
on	doc_600559929001_item	2759909	et	4	main
eesnimi	doc_600559929001_item	2759910	et	3	main
mina	doc_600559929001_item	2759911	et	4	main
elan	doc_600559929001_item	2759921	et	3	main
tutvon	doc_600559929001_item	2759935	et	4	main
kohtumisumi	doc_600559929001_item	2759946	et	4	main
te	doc_600559929001_item	2759871	et	4	main
sõita	doc_600559929001_item	2759886	et	3	main
see	doc_600559929001_item	2759894	et	3	main
kohtades	doc_600559929001_item	2759897	et	3	main
kirja	doc_600559929001_item	2759899	et	4	main
nõutav	doc_600559929001_item	2759900	et	4	main
80	doc_600559929001_item	2759903	et	2	main
signe	doc_600559929001_item	2759907	et	4	main
kirjate	doc_600559929001_item	2759908	et	3	main
peterburgi	doc_600559929001_item	2759917	et	4	main
uute	doc_600559929001_item	2759936	et	3	main
kestab	doc_600559929001_item	2759939	et	4	main
nedalat	doc_600559929001_item	2759941	et	4	main
sõidan	doc_600559929001_item	2759943	et	3	main
te	doc_600559929002_item	2759950	et	4	main
sellest	doc_600559929002_item	2759955	et	4	main
eestlasest	doc_600559929002_item	2759958	et	3	main
kirjutage	doc_600559929002_item	2759960	et	3	main
kuhu	doc_600559929002_item	2759963	et	3	main
sõita	doc_600559929002_item	2759965	et	3	main
millega	doc_600559929002_item	2759967	et	3	main
ööbite	doc_600559929002_item	2759970	et	3	main
umbes	doc_600559929002_item	2759981	et	4	main
80	doc_600559929002_item	2759982	et	2	main
sellel	doc_600559929002_item	2759989	et	4	main
juunil	doc_600559929002_item	2759990	et	3	main
ma	doc_600559929002_item	2759991	et	3	main
me	doc_600559929002_item	2760007	et	4	main
reisi	doc_600559929001_item	2759873	et	4	main
kirjutage	doc_600559929001_item	2759875	et	3	main
reisite	doc_600559929001_item	2759889	et	3	main
maksab	doc_600559929001_item	2759895	et	3	main
peatute	doc_600559929001_item	2759898	et	4	main
pikkus	doc_600559929001_item	2759901	et	4	main
juures	doc_600559929001_item	2759923	et	4	main
kroon	doc_600559929001_item	2759927	et	3	main
lähen	doc_600559929001_item	2759929	et	3	main
teatrisse	doc_600559929001_item	2759931	et	3	main
õhtul	doc_600559929001_item	2759932	et	3	main
inimestega	doc_600559929001_item	2759937	et	3	main
siina	doc_600559929001_item	2759944	et	4	main
juuli	doc_600559929001_item	2759945	et	4	main
reisi	doc_600559929002_item	2759952	et	4	main
kirjutage	doc_600559929002_item	2759954	et	3	main
kiri	doc_600559929002_item	2759956	et	3	main
sõbrale	doc_600559929002_item	2759959	et	3	main
kohtades	doc_600559929002_item	2759976	et	3	main
sõna	doc_600559929002_item	2759983	et	4	main
sompa	doc_600559929002_item	2759984	et	4	main
050505	doc_600559929002_item	2759985	et	2	main
kallis	doc_600559929002_item	2759986	et	4	main
sõita	doc_600559929002_item	2759994	et	3	main
peterburi	doc_600559929002_item	2760010	et	4	main
kirikutesses	doc_600559929002_item	2760033	et	4	main
võtma	doc_600559929002_item	2760038	et	3	main
peterburis	doc_600559929002_item	2760042	et	4	main
natalia	doc_600559929002_item	2760050	et	4	main
suvorovski	doc_600559929002_item	2760052	et	4	main
2	doc_600559929002_item	2760056	et	2	main
tal	doc_600559929002_item	2760058	et	3	main
külalisel	doc_600559929002_item	2760059	et	4	main
see	doc_600559929002_item	2760066	et	3	main
tuba	doc_600559929002_item	2760069	et	4	main
komunaalkorteris	doc_600559929002_item	2760070	et	4	main
tal	doc_600559929002_item	2760071	et	3	main
on	doc_600559929002_item	2760072	et	4	main
intelligeentne	doc_600559929002_item	2760076	et	4	main
on	doc_600559929002_item	2760079	et	4	main
sõbralik	doc_600559929002_item	2760081	et	3	main
sinu	doc_600559929002_item	2760083	et	3	main
eesnimi	doc_600559929002_item	2760085	et	3	main
kiri	doc_600559929001_item	2759870	et	3	main
venemaale	doc_600559929001_item	2759874	et	4	main
sellest	doc_600559929001_item	2759876	et	4	main
kiri	doc_600559929001_item	2759877	et	3	main
oma	doc_600559929001_item	2759878	et	4	main
eestlasest	doc_600559929001_item	2759879	et	3	main
sõbrale	doc_600559929001_item	2759880	et	3	main
kirjutage	doc_600559929001_item	2759881	et	3	main
millal	doc_600559929001_item	2759882	et	3	main
ja	doc_600559929001_item	2759883	et	3	main
kuhu	doc_600559929001_item	2759884	et	3	main
kus	doc_600559929001_item	2759890	et	3	main
kui	doc_600559929001_item	2759892	et	3	main
puhkus	doc_600559929001_item	2759912	et	3	main
venemaa	doc_600559929001_item	2759914	et	4	main
ma	doc_600559929001_item	2759915	et	3	main
sõbran	doc_600559929001_item	2759922	et	4	main
maksad	doc_600559929001_item	2759925	et	4	main
ma	doc_600559929001_item	2759928	et	3	main
muuseumi	doc_600559929001_item	2759930	et	4	main
jalutan	doc_600559929001_item	2759933	et	3	main
kaks	doc_600559929001_item	2759940	et	3	main
ma	doc_600559929001_item	2759942	et	3	main
venemaale	doc_600559929002_item	2759953	et	4	main
oma	doc_600559929002_item	2759957	et	4	main
millal	doc_600559929002_item	2759961	et	3	main
te	doc_600559929002_item	2759964	et	4	main
reisite	doc_600559929002_item	2759968	et	3	main
kui	doc_600559929002_item	2759971	et	3	main
maksab	doc_600559929002_item	2759974	et	3	main
kirja	doc_600559929002_item	2759978	et	4	main
venemaale	doc_600559929002_item	2759993	et	4	main
mitu	doc_600559929002_item	2759997	et	4	main
ja	doc_600559929002_item	2759999	et	3	main
minu	doc_600559929002_item	2760004	et	3	main
sõbrannaga	doc_600559929002_item	2760005	et	3	main
me	doc_600559929002_item	2760026	et	4	main
peatume	doc_600559929002_item	2760027	et	4	main
mitmes	doc_600559929002_item	2760028	et	4	main
kohtades	doc_600559929002_item	2760029	et	3	main
peame	doc_600559929002_item	2760036	et	4	main
meil	doc_600559929002_item	2760039	et	4	main
olin	doc_600559929002_item	2760055	et	3	main
vanad	doc_600559929002_item	2760075	et	3	main
sellest	doc_600559929005_item	2760311	et	4	main
millal	doc_600559929005_item	2760317	et	3	main
millega	doc_600559929005_item	2760323	et	3	main
pilet	doc_600559929001_item	2759924	et	3	main
200	doc_600559929001_item	2759926	et	2	main
linnas	doc_600559929001_item	2759934	et	4	main
reis	doc_600559929001_item	2759938	et	4	main
plaanite	doc_600559929002_item	2759951	et	3	main
ja	doc_600559929002_item	2759962	et	3	main
soovite	doc_600559929002_item	2759966	et	3	main
kus	doc_600559929002_item	2759969	et	3	main
palju	doc_600559929002_item	2759972	et	4	main
see	doc_600559929002_item	2759973	et	3	main
peatute	doc_600559929002_item	2759977	et	4	main
nõutav	doc_600559929002_item	2759979	et	4	main
pikkus	doc_600559929002_item	2759980	et	4	main
helena	doc_600559929002_item	2759987	et	4	main
tere	doc_600559929002_item	2759988	et	3	main
ma	doc_600559929002_item	2759995	et	3	main
soovin	doc_600559929002_item	2759996	et	3	main
ja	doc_600559929002_item	2760011	et	3	main
ööbime	doc_600559929002_item	2760012	et	3	main
ka	doc_600559929002_item	2760013	et	3	main
bussis	doc_600559929002_item	2760014	et	3	main
see	doc_600559929002_item	2760015	et	3	main
maksab	doc_600559929002_item	2760016	et	3	main
7	doc_600559929002_item	2760017	et	2	main
sada	doc_600559929002_item	2760018	et	4	main
viisa	doc_600559929002_item	2760020	et	4	main
krooni	doc_600559929002_item	2760019	et	4	main
on	doc_600559929002_item	2760021	et	4	main
100	doc_600559929002_item	2760024	et	2	main
näiteks	doc_600559929002_item	2760030	et	4	main
kaasa	doc_600559929002_item	2760037	et	4	main
on	doc_600559929002_item	2760040	et	4	main
tütar	doc_600559929002_item	2760049	et	3	main
väga	doc_600559929002_item	2760062	et	3	main
tema	doc_600559929002_item	2760063	et	4	main
korter	doc_600559929002_item	2760064	et	3	main
on	doc_600559929002_item	2760067	et	4	main
ainult	doc_600559929002_item	2760068	et	4	main
eesnimi	doc_600559929001_item	2759947	et	3	main
080605	doc_600559929001_item	2759948	et	2	main
kiri	doc_600559929002_item	2759949	et	3	main
millistes	doc_600559929002_item	2759975	et	3	main
plaanin	doc_600559929002_item	2759992	et	3	main
linne	doc_600559929002_item	2759998	et	3	main
kohti	doc_600559929002_item	2760000	et	4	main
külastada	doc_600559929002_item	2760001	et	3	main
ma	doc_600559929002_item	2760002	et	3	main
tahan	doc_600559929002_item	2760003	et	3	main
reisima	doc_600559929002_item	2760006	et	3	main
sõidame	doc_600559929002_item	2760008	et	3	main
bussiga	doc_600559929002_item	2760009	et	3	main
odavam	doc_600559929002_item	2760022	et	4	main
ainult	doc_600559929002_item	2760023	et	4	main
krooni	doc_600559929002_item	2760025	et	4	main
lossides	doc_600559929002_item	2760031	et	4	main
ja	doc_600559929002_item	2760032	et	3	main
sugulased	doc_600559929002_item	2760041	et	3	main
on	doc_600559929002_item	2760043	et	4	main
võimalik	doc_600559929002_item	2760044	et	3	main
seal	doc_600559929002_item	2760045	et	4	main
ööbima	doc_600559929002_item	2760046	et	3	main
minu	doc_600559929002_item	2760047	et	3	main
elab	doc_600559929002_item	2760051	et	3	main
pujesteel	doc_600559929002_item	2760053	et	4	main
korda	doc_600559929002_item	2760057	et	4	main
mulle	doc_600559929002_item	2760060	et	4	main
meeldis	doc_600559929002_item	2760061	et	3	main
väga	doc_600559929002_item	2760080	et	3	main
tervitage	doc_600559929002_item	2760082	et	3	main
abikaasa	doc_600559929002_item	2760084	et	4	main
te	doc_600559929005_item	2760306	et	4	main
plaanite	doc_600559929005_item	2760307	et	3	main
venemaale	doc_600559929005_item	2760309	et	4	main
eestlasest	doc_600559929005_item	2760314	et	3	main
soovite	doc_600559929005_item	2760322	et	3	main
reisite	doc_600559929005_item	2760324	et	3	main
kirja	doc_600559929005_item	2760334	et	4	main
pikkus	doc_600559929005_item	2760336	et	4	main
sõna	doc_600559929005_item	2760339	et	4	main
süüa	doc_600559929002_item	2760034	et	3	main
me	doc_600559929002_item	2760035	et	4	main
abikaasa	doc_600559929002_item	2760048	et	4	main
ma	doc_600559929002_item	2760054	et	3	main
täpsemalt	doc_600559929002_item	2760065	et	4	main
head	doc_600559929002_item	2760073	et	4	main
naabrid	doc_600559929002_item	2760074	et	3	main
naised	doc_600559929002_item	2760077	et	3	main
nad	doc_600559929002_item	2760078	et	3	main
uus	doc_600559929005_item	2760304	et	3	main
dokument	doc_600559929005_item	2760305	et	3	main
reisi	doc_600559929005_item	2760308	et	4	main
kirjutage	doc_600559929005_item	2760310	et	3	main
sõbrale	doc_600559929005_item	2760315	et	3	main
ja	doc_600559929005_item	2760318	et	3	main
sõita	doc_600559929005_item	2760321	et	3	main
kui	doc_600559929005_item	2760327	et	3	main
see	doc_600559929005_item	2760329	et	3	main
millistes	doc_600559929005_item	2760331	et	3	main
080605	doc_600559929005_item	2760340	et	2	main
sinul	doc_600559929005_item	2760352	et	3	main
viis	doc_600559929005_item	2760356	et	4	main
mis	doc_600559929005_item	2760358	et	4	main
juhtus	doc_600559929005_item	2760359	et	3	main
kõik	doc_600559929005_item	2760365	et	4	main
on	doc_600559929005_item	2760368	et	4	main
kõik	doc_600559929005_item	2760369	et	4	main
puhkus	doc_600559929005_item	2760378	et	3	main
ja	doc_600559929005_item	2760380	et	3	main
kolleegid	doc_600559929005_item	2760381	et	3	main
rõmus	doc_600559929005_item	2760391	et	4	main
oma	doc_600559929005_item	2760313	et	4	main
kirjutage	doc_600559929005_item	2760316	et	3	main
te	doc_600559929005_item	2760320	et	4	main
kuhu	doc_600559929005_item	2760319	et	3	main
ööbite	doc_600559929005_item	2760326	et	3	main
maksab	doc_600559929005_item	2760330	et	3	main
peatute	doc_600559929005_item	2760333	et	4	main
riina	doc_600559929005_item	2760346	et	4	main
ma	doc_600559929005_item	2760347	et	3	main
sain	doc_600559929005_item	2760348	et	3	main
paar	doc_600559929005_item	2760349	et	3	main
päeva	doc_600559929005_item	2760350	et	4	main
tagasi	doc_600559929005_item	2760351	et	3	main
kus	doc_600559929005_item	2760354	et	3	main
et	doc_600559929005_item	2760362	et	3	main
on	doc_600559929005_item	2760364	et	4	main
normaalne	doc_600559929005_item	2760366	et	3	main
meil	doc_600559929005_item	2760376	et	4	main
mina	doc_600559929005_item	2760379	et	4	main
me	doc_600559929005_item	2760392	et	4	main
läheme	doc_600559929005_item	2760393	et	3	main
moskvasse	doc_600559929005_item	2760394	et	4	main
rongiga	doc_600559929005_item	2760395	et	4	main
ja	doc_600559929005_item	2760396	et	3	main
läheme	doc_600559929005_item	2760421	et	3	main
tegen	doc_600559929005_item	2760426	et	4	main
kirsipuud	doc_600559929005_item	2760436	et	4	main
kaks	doc_600559929005_item	2760437	et	3	main
päeva	doc_600559929005_item	2760438	et	4	main
linnas	doc_600559929005_item	2760444	et	4	main
ilus	doc_600559929005_item	2760450	et	4	main
päeva	doc_600559929005_item	2760453	et	4	main
me	doc_600559929005_item	2760455	et	4	main
tulime	doc_600559929005_item	2760456	et	3	main
tagasi	doc_600559929005_item	2760457	et	3	main
oma	doc_600559929005_item	2760478	et	4	main
ja	doc_600559929005_item	2760480	et	3	main
lapsi	doc_600559929005_item	2760481	et	4	main
eesnimi	doc_600559929005_item	2760485	et	3	main
kiri	doc_600559929005_item	2760312	et	3	main
tervituti	doc_600559929005_item	2760341	et	4	main
järvelt	doc_600559929005_item	2760343	et	4	main
tere	doc_600559929005_item	2760344	et	3	main
kallis	doc_600559929005_item	2760345	et	4	main
loodan	doc_600559929005_item	2760361	et	3	main
häste	doc_600559929005_item	2760370	et	4	main
mul	doc_600559929005_item	2760371	et	3	main
on	doc_600559929005_item	2760372	et	4	main
varsti	doc_600559929005_item	2760375	et	3	main
sõidame	doc_600559929005_item	2760382	et	3	main
huvitav	doc_600559929005_item	2760386	et	4	main
ta	doc_600559929005_item	2760388	et	4	main
nõmetakse	doc_600559929005_item	2760389	et	3	main
kuld	doc_600559929005_item	2760390	et	3	main
elame	doc_600559929005_item	2760397	et	3	main
pealinnas	doc_600559929005_item	2760398	et	4	main
päeva	doc_600559929005_item	2760400	et	4	main
siin	doc_600559929005_item	2760401	et	4	main
vaatame	doc_600559929005_item	2760402	et	3	main
näetus	doc_600559929005_item	2760403	et	4	main
köisime	doc_600559929005_item	2760404	et	4	main
teatris	doc_600559929005_item	2760405	et	3	main
ja	doc_600559929005_item	2760406	et	3	main
loomaajas	doc_600559929005_item	2760407	et	4	main
kolm	doc_600559929005_item	2760408	et	3	main
päeva	doc_600559929005_item	2760409	et	4	main
sõidame	doc_600559929005_item	2760411	et	3	main
bussiga	doc_600559929005_item	2760412	et	3	main
vladimiri	doc_600559929005_item	2760413	et	4	main
pärast	doc_600559929005_item	2760410	et	4	main
linnas	doc_600559929005_item	2760414	et	4	main
see	doc_600559929005_item	2760415	et	3	main
on	doc_600559929005_item	2760416	et	4	main
minu	doc_600559929005_item	2760417	et	3	main
kodune	doc_600559929005_item	2760418	et	4	main
linn	doc_600559929005_item	2760419	et	3	main
kolleegid	doc_600559929005_item	2760420	et	3	main
minule	doc_600559929005_item	2760422	et	3	main
kasvavad	doc_600559929005_item	2760432	et	4	main
pärast	doc_600559929005_item	2760439	et	4	main
me	doc_600559929005_item	2760440	et	4	main
läheme	doc_600559929005_item	2760441	et	3	main
on	doc_600559929005_item	2760446	et	4	main
näitus	doc_600559929005_item	2760447	et	3	main
teatrid	doc_600559929005_item	2760448	et	3	main
ja	doc_600559929005_item	2760449	et	3	main
aega	doc_600559929005_item	2760476	et	4	main
kõik	doc_600559929005_item	2760482	et	4	main
kus	doc_600559929005_item	2760325	et	3	main
palju	doc_600559929005_item	2760328	et	4	main
kohtades	doc_600559929005_item	2760332	et	3	main
nõutav	doc_600559929005_item	2760335	et	4	main
umbes	doc_600559929005_item	2760337	et	4	main
80	doc_600559929005_item	2760338	et	2	main
kirja	doc_600559929005_item	2760353	et	4	main
ma	doc_600559929005_item	2760360	et	3	main
see	doc_600559929005_item	2760384	et	3	main
on	doc_600559929005_item	2760385	et	4	main
reis	doc_600559929005_item	2760387	et	4	main
kolm	doc_600559929005_item	2760399	et	3	main
külas	doc_600559929005_item	2760424	et	3	main
palju	doc_600559929005_item	2760433	et	4	main
siin	doc_600559929005_item	2760445	et	4	main
viis	doc_600559929005_item	2760452	et	4	main
mul	doc_600559929005_item	2760473	et	3	main
kohtla	doc_600559929005_item	2760342	et	4	main
oli	doc_600559929005_item	2760355	et	3	main
riida	doc_600559929005_item	2760357	et	3	main
sul	doc_600559929005_item	2760363	et	3	main
mul	doc_600559929005_item	2760367	et	3	main
üks	doc_600559929005_item	2760373	et	3	main
uudis	doc_600559929005_item	2760374	et	3	main
on	doc_600559929005_item	2760377	et	4	main
venemaale	doc_600559929005_item	2760383	et	4	main
sugulasele	doc_600559929005_item	2760423	et	3	main
ma	doc_600559929005_item	2760425	et	3	main
ekskursioni	doc_600559929005_item	2760427	et	4	main
ja	doc_600559929005_item	2760428	et	3	main
jalutame	doc_600559929005_item	2760429	et	3	main
linnas	doc_600559929005_item	2760430	et	4	main
lilli	doc_600559929005_item	2760434	et	4	main
rongiga	doc_600559929005_item	2760442	et	4	main
pärast	doc_600559929005_item	2760454	et	4	main
ei	doc_600559929005_item	2760474	et	4	main
ole	doc_600559929005_item	2760475	et	4	main
abikaasale	doc_600559929005_item	2760479	et	4	main
nägimiseni	doc_600559929005_item	2760484	et	4	main
siin	doc_600559929005_item	2760431	et	4	main
ja	doc_600559929005_item	2760435	et	3	main
vjasniki	doc_600559929005_item	2760443	et	4	main
loodus	doc_600559929005_item	2760451	et	4	main
reis	doc_600559929005_item	2760458	et	4	main
maksab	doc_600559929005_item	2760459	et	3	main
700	doc_600559929005_item	2760460	et	2	main
krooni	doc_600559929005_item	2760461	et	4	main
kahjuks	doc_600559929005_item	2760462	et	4	main
et	doc_600559929005_item	2760463	et	3	main
sina	doc_600559929005_item	2760464	et	4	main
ei	doc_600559929005_item	2760465	et	4	main
või	doc_600559929005_item	2760466	et	4	main
sõida	doc_600559929005_item	2760467	et	4	main
öösel	doc_600559929005_item	2760468	et	4	main
me	doc_600559929005_item	2760469	et	4	main
asume	doc_600559929005_item	2760470	et	3	main
hotellis	doc_600559929005_item	2760471	et	3	main
praegu	doc_600559929005_item	2760472	et	3	main
tervita	doc_600559929005_item	2760477	et	4	main
head	doc_600559929005_item	2760483	et	4	main
arvamus	doc_609075653171_item	2760747	et	3	main
oleksin	doc_609075653171_item	2760750	et	3	main
liige	doc_609075653171_item	2760752	et	4	main
siis	doc_609075653171_item	2760753	et	3	main
kõigepealt	doc_609075653171_item	2760754	et	3	main
puhastamine	doc_609075653171_item	2760757	et	4	main
elada	doc_609075653171_item	2760761	et	3	main
on	doc_609075653171_item	2760771	et	4	main
ja	doc_609075653171_item	2760775	et	3	main
soiseks	doc_609075653171_item	2760781	et	4	main
ja	doc_609075653171_item	2760783	et	3	main
on	doc_609075653171_item	2760786	et	4	main
veel	doc_609075653171_item	2760795	et	4	main
ma	doc_609075653171_item	2760796	et	3	main
paigaldaksin	doc_609075653171_item	2760797	et	3	main
oleks	doc_609075653171_item	2760802	et	3	main
aga	doc_609075653171_item	2760804	et	3	main
effektiivseltne	doc_609075653171_item	2760807	et	4	main
siis	doc_609075653171_item	2760809	et	3	main
kui	doc_609075653171_item	2760810	et	3	main
inimesed	doc_609075653171_item	2760811	et	3	main
prügi	doc_609075653171_item	2760815	et	4	main
meie	doc_609075653171_item	2760818	et	4	main
tänavatel	doc_609075653171_item	2760819	et	4	main
kui	doc_609075653171_item	2760748	et	3	main
volikogu	doc_609075653171_item	2760751	et	4	main
rahastaksin	doc_609075653171_item	2760755	et	4	main
ei	doc_609075653171_item	2760759	et	4	main
ilma	doc_609075653171_item	2760762	et	4	main
veeta	doc_609075653171_item	2760763	et	4	main
aga	doc_609075653171_item	2760764	et	3	main
praegune	doc_609075653171_item	2760765	et	3	main
veekogude	doc_609075653171_item	2760766	et	3	main
seisund	doc_609075653171_item	2760767	et	3	main
ainetega	doc_609075653171_item	2760774	et	3	main
veeloomad	doc_609075653171_item	2760782	et	3	main
loodust	doc_609075653171_item	2760792	et	4	main
ja	doc_609075653171_item	2760793	et	3	main
see	doc_609075653171_item	2760805	et	3	main
viska	doc_609075653171_item	2760814	et	4	main
palju	doc_609075653171_item	2760821	et	4	main
ja	doc_609075653171_item	2760824	et	3	main
pärast	doc_609075653171_item	2760827	et	4	main
ma	doc_609075653171_item	2760828	et	3	main
finantseeriksin	doc_609075653171_item	2760829	et	3	main
renoveerimise	doc_609075653171_item	2760831	et	4	main
lapsed	doc_609075653171_item	2760835	et	3	main
ohutu	doc_609075653171_item	2760849	et	4	main
rjaksin	doc_609075653171_item	2760853	et	4	main
elavad	doc_609075653171_item	2760859	et	4	main
heas	doc_609075653171_item	2760860	et	3	main
peame	doc_609075653171_item	2760870	et	4	main
kaitsma	doc_609075653171_item	2760871	et	3	main
loomi	doc_609075653171_item	2760875	et	4	main
põlvedele	doc_609075653171_item	2760882	et	4	main
ürituse	doc_609075653171_item	2760886	et	4	main
propageerida	doc_609075653171_item	2760894	et	3	main
looduse	doc_609075653171_item	2760895	et	4	main
hoolitseksid	doc_609075653171_item	2760904	et	4	main
esemesel	doc_609075653172_item	2760912	et	4	main
ja	doc_609075653172_item	2760923	et	3	main
puhkas	doc_609075653172_item	2760926	et	3	main
taevas	doc_609075653172_item	2760927	et	4	main
piltil	doc_609075653172_item	2760928	et	4	main
suur	doc_609075653172_item	2760933	et	3	main
on	doc_609075653172_item	2760953	et	4	main
on	doc_609075653172_item	2760956	et	4	main
tähendab	doc_609075653172_item	2760961	et	3	main
osalen	doc_609075653173_item	2760991	et	3	main
oma	doc_609075653173_item	2760992	et	4	main
koolis	doc_609075653173_item	2761000	et	4	main
klassides	doc_609075653173_item	2761018	et	3	main
olla	doc_609075653173_item	2761020	et	3	main
peab	doc_609075653173_item	2761028	et	4	main
olla	doc_609075653173_item	2761029	et	3	main
koolivoimla	doc_609075653173_item	2761031	et	4	main
arvuti	doc_609075653173_item	2761040	et	4	main
on	doc_609075653171_item	2760768	et	4	main
reostatud	doc_609075653171_item	2760772	et	4	main
vesi	doc_609075653171_item	2760777	et	4	main
ja	doc_609075653171_item	2760779	et	3	main
hukuvad	doc_609075653171_item	2760785	et	3	main
vaja	doc_609075653171_item	2760787	et	4	main
veekogusid	doc_609075653171_item	2760789	et	4	main
et	doc_609075653171_item	2760790	et	3	main
prügikastid	doc_609075653171_item	2760798	et	3	main
maha	doc_609075653171_item	2760816	et	4	main
praegu	doc_609075653171_item	2760817	et	3	main
muuid	doc_609075653171_item	2760825	et	4	main
prügisid	doc_609075653171_item	2760826	et	3	main
teavad	doc_609075653171_item	2760833	et	3	main
on	doc_609075653171_item	2760836	et	4	main
meie	doc_609075653171_item	2760837	et	4	main
tulevik	doc_609075653171_item	2760838	et	3	main
tähtis	doc_609075653171_item	2760856	et	4	main
et	doc_609075653171_item	2760857	et	3	main
inimesed	doc_609075653171_item	2760858	et	3	main
sõltub	doc_609075653171_item	2760865	et	3	main
sellesteest	doc_609075653171_item	2760866	et	4	main
muidugi	doc_609075653171_item	2760868	et	4	main
hirmus	doc_609075653171_item	2760769	et	4	main
veetaimed	doc_609075653171_item	2760784	et	3	main
end	doc_609075653171_item	2760794	et	4	main
meie	doc_609075653171_item	2760800	et	4	main
on	doc_609075653171_item	2760806	et	4	main
ainult	doc_609075653171_item	2760808	et	4	main
ise	doc_609075653171_item	2760812	et	4	main
ei	doc_609075653171_item	2760813	et	4	main
on	doc_609075653171_item	2760820	et	4	main
lastemänguväljakute	doc_609075653171_item	2760830	et	3	main
peab	doc_609075653171_item	2760840	et	4	main
nende	doc_609075653171_item	2760863	et	4	main
loodust	doc_609075653171_item	2760874	et	4	main
ja	doc_609075653171_item	2760876	et	3	main
trükiksin	doc_609075653171_item	2760890	et	3	main
on	doc_609075653171_item	2760892	et	4	main
vaja	doc_609075653171_item	2760893	et	4	main
inimesed	doc_609075653171_item	2760898	et	3	main
mõtleksid	doc_609075653171_item	2760900	et	4	main
loodusest	doc_609075653171_item	2760902	et	4	main
ja	doc_609075653171_item	2760903	et	3	main
on	doc_609075653172_item	2760909	et	4	main
ma	doc_609075653171_item	2760749	et	3	main
veekogude	doc_609075653171_item	2760756	et	3	main
inimene	doc_609075653171_item	2760758	et	3	main
sa	doc_609075653171_item	2760760	et	3	main
veekogud	doc_609075653171_item	2760770	et	3	main
ohtlikute	doc_609075653171_item	2760773	et	4	main
sellepärast	doc_609075653171_item	2760776	et	3	main
õitseb	doc_609075653171_item	2760778	et	4	main
muutub	doc_609075653171_item	2760780	et	3	main
puhastada	doc_609075653171_item	2760788	et	3	main
aidata	doc_609075653171_item	2760791	et	4	main
et	doc_609075653171_item	2760799	et	3	main
linn	doc_609075653171_item	2760801	et	3	main
puhtam	doc_609075653171_item	2760803	et	4	main
et	doc_609075653171_item	2760834	et	3	main
lastel	doc_609075653171_item	2760839	et	4	main
ja	doc_609075653171_item	2760848	et	3	main
seda	doc_609075653171_item	2760851	et	3	main
keskkonnas	doc_609075653171_item	2760861	et	3	main
sest	doc_609075653171_item	2760862	et	4	main
ja	doc_609075653171_item	2760867	et	3	main
ta	doc_609075653171_item	2760879	et	4	main
säiliks	doc_609075653171_item	2760880	et	3	main
reklaami	doc_609075653171_item	2760891	et	4	main
et	doc_609075653171_item	2760897	et	3	main
tehtud	doc_609075653172_item	2760910	et	4	main
sügisel	doc_609075653172_item	2760911	et	3	main
õpilane	doc_609075653172_item	2760938	et	3	main
aastal	doc_609075653172_item	2760940	et	3	main
aga	doc_609075653172_item	2760945	et	3	main
pois	doc_609075653172_item	2760946	et	3	main
abiturient	doc_609075653172_item	2760947	et	3	main
kes	doc_609075653172_item	2760948	et	4	main
kooli	doc_609075653172_item	2760951	et	4	main
pühariides	doc_609075653172_item	2760954	et	3	main
tüdrukul	doc_609075653172_item	2760955	et	3	main
kell	doc_609075653172_item	2760957	et	3	main
see	doc_609075653172_item	2760960	et	3	main
koolihoone	doc_609075653172_item	2760981	et	4	main
on	doc_609075653172_item	2760983	et	4	main
meeleolu	doc_609075653172_item	2760987	et	4	main
peab	doc_609075653173_item	2761001	et	4	main
õpetajale	doc_609075653173_item	2761011	et	4	main
meeldib	doc_609075653173_item	2761012	et	3	main
hea	doc_609075653173_item	2761023	et	4	main
tehnika	doc_609075653173_item	2761025	et	4	main
teiseks	doc_609075653173_item	2761026	et	4	main
uus	doc_609075653173_item	2761030	et	3	main
aula	doc_609075653173_item	2761032	et	4	main
aktus	doc_609075653173_item	2761033	et	3	main
tähtsusjarjekorras	doc_609075653173_item	2761034	et	4	main
sanitaarremont	doc_609075653173_item	2761035	et	3	main
koolivõimla	doc_609075653173_item	2761042	et	4	main
kvaliteeti	doc_609075653173_item	2761061	et	4	main
kodulinnas	doc_609075653174_item	2761071	et	4	main
on	doc_609075653174_item	2761072	et	4	main
väga	doc_609075653174_item	2761073	et	3	main
restoranis	doc_609075653174_item	2761085	et	3	main
abikaasaga	doc_609075653174_item	2761101	et	3	main
käin	doc_609075653174_item	2761104	et	3	main
käin	doc_609075653174_item	2761113	et	3	main
väljas	doc_609075653174_item	2761114	et	4	main
sõbrannaga	doc_609075653174_item	2761115	et	3	main
siis	doc_609075653174_item	2761116	et	3	main
maksab	doc_609075653174_item	2761117	et	3	main
leo	doc_609075653174_item	2761123	et	4	main
menüüst	doc_609075653174_item	2761125	et	3	main
salatid	doc_609075653174_item	2761127	et	3	main
supid	doc_609075653174_item	2761131	et	3	main
seljanka	doc_609075653174_item	2761132	et	4	main
jogurti-	doc_609075653174_item	2761150	et	3	main
koogid	doc_609075653174_item	2761154	et	4	main
joogid	doc_609075653174_item	2761156	et	4	main
kuumad	doc_609075653174_item	2761157	et	4	main
joogid	doc_609075653174_item	2761162	et	4	main
viski	doc_609075653174_item	2761171	et	4	main
viinad	doc_609075653174_item	2761172	et	3	main
koktelid	doc_609075653174_item	2761173	et	4	main
pingeline	doc_609075653175_item	2761203	et	4	main
siis	doc_609075653175_item	2761205	et	3	main
räägin	doc_609075653175_item	2761207	et	3	main
suitsuotsi	doc_609075653171_item	2760822	et	4	main
paberlipakaseid	doc_609075653171_item	2760823	et	3	main
kõik	doc_609075653171_item	2760832	et	4	main
olema	doc_609075653171_item	2760841	et	4	main
oma	doc_609075653171_item	2760842	et	4	main
koht	doc_609075653171_item	2760843	et	3	main
mängudeks	doc_609075653171_item	2760844	et	3	main
mis	doc_609075653171_item	2760845	et	4	main
oleks	doc_609075653171_item	2760846	et	3	main
mugav	doc_609075653171_item	2760847	et	3	main
pärast	doc_609075653171_item	2760850	et	4	main
ma	doc_609075653171_item	2760852	et	3	main
looduskaitseala	doc_609075653171_item	2760854	et	4	main
on	doc_609075653171_item	2760855	et	4	main
tervis	doc_609075653171_item	2760864	et	3	main
oma	doc_609075653171_item	2760872	et	4	main
kaunist	doc_609075653171_item	2760873	et	4	main
taimi	doc_609075653171_item	2760877	et	4	main
looduse	doc_609075653171_item	2760887	et	4	main
sõbrad	doc_609075653171_item	2760888	et	3	main
ja	doc_609075653171_item	2760889	et	3	main
rohkem	doc_609075653171_item	2760899	et	4	main
meie	doc_609075653171_item	2760901	et	4	main
eest	doc_609075653171_item	2760906	et	4	main
kirjeldus	doc_609075653172_item	2760907	et	4	main
pilt	doc_609075653172_item	2760908	et	3	main
septembril	doc_609075653172_item	2760913	et	3	main
selle	doc_609075653172_item	2760914	et	4	main
eest	doc_609075653172_item	2760915	et	4	main
et	doc_609075653172_item	2760916	et	3	main
piltil	doc_609075653172_item	2760917	et	4	main
on	doc_609075653172_item	2760918	et	4	main
teadmisipäev	doc_609075653172_item	2760919	et	4	main
esimene	doc_609075653172_item	2760920	et	3	main
õppepäev	doc_609075653172_item	2760921	et	3	main
on	doc_609075653172_item	2760929	et	4	main
väke	doc_609075653172_item	2760930	et	4	main
tüdruk	doc_609075653172_item	2760931	et	3	main
tüdruk	doc_609075653172_item	2760935	et	3	main
lõpetas	doc_609075653172_item	2760950	et	3	main
nad	doc_609075653172_item	2760952	et	3	main
nad	doc_609075653172_item	2760971	et	3	main
kelllel	doc_609075653172_item	2760982	et	4	main
pidulik	doc_609075653172_item	2760984	et	3	main
ja	doc_609075653172_item	2760985	et	3	main
rõõmus	doc_609075653172_item	2760986	et	4	main
koolielu	doc_609075653173_item	2760989	et	4	main
olla	doc_609075653173_item	2761002	et	3	main
remont	doc_609075653173_item	2761004	et	3	main
eest	doc_609075653173_item	2761006	et	4	main
et	doc_609075653173_item	2761007	et	3	main
ilusas	doc_609075653173_item	2761008	et	3	main
uues	doc_609075653173_item	2761009	et	3	main
koolis	doc_609075653173_item	2761010	et	4	main
ja	doc_609075653173_item	2761015	et	3	main
õppida	doc_609075653173_item	2761017	et	3	main
me	doc_609075653171_item	2760869	et	4	main
ja	doc_609075653171_item	2760878	et	3	main
tulevastele	doc_609075653171_item	2760881	et	4	main
lõpuks	doc_609075653171_item	2760883	et	4	main
ma	doc_609075653171_item	2760884	et	3	main
viiksin	doc_609075653171_item	2760885	et	3	main
kaitsmist	doc_609075653171_item	2760896	et	4	main
tema	doc_609075653171_item	2760905	et	4	main
soe	doc_609075653172_item	2760922	et	4	main
päikesepaisteline	doc_609075653172_item	2760924	et	4	main
ilm	doc_609075653172_item	2760925	et	3	main
ja	doc_609075653172_item	2760932	et	3	main
esimese	doc_609075653172_item	2760936	et	3	main
sel	doc_609075653172_item	2760939	et	3	main
juba	doc_609075653172_item	2760949	et	3	main
ta	doc_609075653172_item	2760958	et	4	main
kellab	doc_609075653172_item	2760959	et	3	main
arvamus	doc_609075653173_item	2760988	et	3	main
ma	doc_609075653173_item	2760990	et	3	main
kooli	doc_609075653173_item	2760993	et	4	main
puudutavas	doc_609075653173_item	2760994	et	4	main
hea	doc_609075653173_item	2761003	et	4	main
selle	doc_609075653173_item	2761005	et	4	main
töötada	doc_609075653173_item	2761014	et	3	main
peab	doc_609075653173_item	2761019	et	4	main
koolis	doc_609075653173_item	2761027	et	4	main
puhkeruumi	doc_609075653173_item	2761036	et	4	main
remont	doc_609075653173_item	2761037	et	3	main
õppevahendite	doc_609075653173_item	2761038	et	3	main
eluks	doc_609075653173_item	2761043	et	3	main
kool	doc_609075653173_item	2761048	et	4	main
on	doc_609075653173_item	2761049	et	4	main
siis	doc_609075653173_item	2761053	et	3	main
kirjeldus	doc_609075653174_item	2761064	et	4	main
vähe	doc_609075653174_item	2761074	et	3	main
haid	doc_609075653174_item	2761075	et	4	main
restorane	doc_609075653174_item	2761076	et	3	main
ma	doc_609075653174_item	2761077	et	3	main
leo	doc_609075653174_item	2761080	et	4	main
kohvikus	doc_609075653174_item	2761088	et	3	main
läheksin	doc_609075653174_item	2761090	et	3	main
hea	doc_609075653174_item	2761093	et	4	main
sõbraga	doc_609075653174_item	2761094	et	3	main
ma	doc_609075653174_item	2761095	et	3	main
läheks	doc_609075653174_item	2761097	et	3	main
sinna	doc_609075653174_item	2761098	et	3	main
ma	doc_609075653174_item	2761103	et	3	main
siis	doc_609075653174_item	2761107	et	3	main
iseenda	doc_609075653174_item	2761119	et	3	main
kirjutan	doc_609075653174_item	2761122	et	3	main
liha	doc_609075653174_item	2761135	et	4	main
kartul	doc_609075653174_item	2761145	et	3	main
riis	doc_609075653174_item	2761146	et	3	main
5	doc_609075653174_item	2761147	et	2	main
magustoidu	doc_609075653174_item	2761148	et	3	main
jäätis	doc_609075653174_item	2761149	et	3	main
joogid	doc_609075653174_item	2761158	et	4	main
kohv	doc_609075653174_item	2761159	et	3	main
mineraal	doc_609075653174_item	2761164	et	3	main
limonaadid	doc_609075653174_item	2761166	et	3	main
alkohoolsed	doc_609075653174_item	2761168	et	3	main
konjak	doc_609075653174_item	2761170	et	3	main
olukord	doc_609075653175_item	2761204	et	3	main
ma	doc_609075653175_item	2761206	et	3	main
mulle	doc_609075653175_item	2761209	et	4	main
aitan	doc_609075653175_item	2761210	et	3	main
4	doc_609075653175_item	2761212	et	2	main
kui	doc_609075653175_item	2761213	et	3	main
mu	doc_609075653175_item	2761214	et	3	main
heal	doc_609075653175_item	2761215	et	3	main
tuttaval	doc_609075653175_item	2761216	et	4	main
pois	doc_609075653172_item	2760934	et	3	main
klasisi	doc_609075653172_item	2760937	et	4	main
ta	doc_609075653172_item	2760941	et	4	main
algab	doc_609075653172_item	2760942	et	3	main
koolis	doc_609075653172_item	2760943	et	4	main
õppima	doc_609075653172_item	2760944	et	3	main
et	doc_609075653172_item	2760962	et	3	main
algus	doc_609075653172_item	2760964	et	4	main
kooliaasta	doc_609075653172_item	2760963	et	4	main
tagaplaanil	doc_609075653172_item	2760965	et	4	main
on	doc_609075653172_item	2760966	et	4	main
inimesed	doc_609075653172_item	2760967	et	3	main
õpetajad	doc_609075653172_item	2760968	et	4	main
õpilased	doc_609075653172_item	2760969	et	3	main
vanemad	doc_609075653172_item	2760970	et	4	main
vesllevad	doc_609075653172_item	2760972	et	4	main
tagaplaanil	doc_609075653172_item	2760973	et	4	main
on	doc_609075653172_item	2760974	et	4	main
muusikaapparatuur	doc_609075653172_item	2760975	et	4	main
peole	doc_609075653172_item	2760976	et	4	main
tagaplaanil	doc_609075653172_item	2760977	et	4	main
on	doc_609075653172_item	2760978	et	4	main
ka	doc_609075653172_item	2760979	et	3	main
kool	doc_609075653172_item	2760980	et	4	main
küsitluses	doc_609075653173_item	2760995	et	4	main
kõigepealt	doc_609075653173_item	2760996	et	3	main
ma	doc_609075653173_item	2760997	et	3	main
arvan	doc_609075653173_item	2760998	et	3	main
et	doc_609075653173_item	2760999	et	3	main
rohkem	doc_609075653173_item	2761013	et	4	main
õpilastele	doc_609075653173_item	2761016	et	4	main
uus	doc_609075653173_item	2761021	et	3	main
õppevehend	doc_609075653173_item	2761024	et	4	main
uute	doc_609075653173_item	2761044	et	3	main
valgustite	doc_609075653173_item	2761045	et	4	main
uus	doc_609075653173_item	2761051	et	3	main
rohkem	doc_609075653173_item	2761054	et	4	main
õppida	doc_609075653173_item	2761056	et	3	main
ja	doc_609075653173_item	2761062	et	3	main
õppimiseks	doc_609075653173_item	2761063	et	4	main
ma	doc_609075653174_item	2761065	et	3	main
käin	doc_609075653174_item	2761066	et	3	main
restoranis	doc_609075653174_item	2761067	et	3	main
väga	doc_609075653174_item	2761068	et	3	main
harva	doc_609075653174_item	2761069	et	4	main
olen	doc_609075653174_item	2761078	et	3	main
privaadis	doc_609075653174_item	2761082	et	4	main
pubis	doc_609075653174_item	2761083	et	4	main
kalevi	doc_609075653174_item	2761087	et	3	main
oma	doc_609075653174_item	2761092	et	4	main
kui	doc_609075653174_item	2761102	et	3	main
väljas	doc_609075653174_item	2761105	et	4	main
ja	doc_609075653173_item	2761022	et	3	main
ostmine	doc_609075653173_item	2761039	et	4	main
ostmine	doc_609075653173_item	2761041	et	4	main
ilus	doc_609075653173_item	2761050	et	4	main
meeldib	doc_609075653173_item	2761055	et	3	main
ja	doc_609075653173_item	2761057	et	3	main
parandab	doc_609075653173_item	2761059	et	3	main
käinud	doc_609075653174_item	2761079	et	4	main
baaris	doc_609075653174_item	2761081	et	3	main
ja	doc_609075653174_item	2761086	et	3	main
eks	doc_609075653174_item	2761100	et	3	main
igaüks	doc_609075653174_item	2761118	et	3	main
ma	doc_609075653174_item	2761121	et	3	main
baari	doc_609075653174_item	2761124	et	4	main
kartulisalat	doc_609075653174_item	2761128	et	3	main
3	doc_609075653174_item	2761133	et	2	main
praend	doc_609075653174_item	2761134	et	4	main
shnitsel	doc_609075653174_item	2761138	et	4	main
lõhe	doc_609075653174_item	2761140	et	4	main
lisandid	doc_609075653174_item	2761142	et	3	main
puvilja	doc_609075653174_item	2761152	et	4	main
6	doc_609075653174_item	2761155	et	2	main
mahl	doc_609075653174_item	2761163	et	3	main
vesi	doc_609075653174_item	2761165	et	4	main
joogid	doc_609075653174_item	2761169	et	4	main
on	doc_609075653175_item	2761217	et	4	main
sünnipäev	doc_609075653175_item	2761218	et	3	main
külla	doc_609075653175_item	2761225	et	4	main
on	doc_609075653175_item	2761230	et	4	main
selliseid	doc_609075653175_item	2761233	et	4	main
juhtub	doc_609075653175_item	2761235	et	3	main
mu	doc_609075653175_item	2761241	et	3	main
palub	doc_609075653175_item	2761243	et	3	main
ma	doc_609075653175_item	2761247	et	3	main
aidata	doc_609075653175_item	2761253	et	4	main
ole	doc_609075653175_item	2761277	et	4	main
tihti	doc_609075653175_item	2761278	et	3	main
praegu	doc_609075653175_item	2761279	et	3	main
kirjeldus	doc_609075653176_item	2761282	et	4	main
wwwsunee	doc_609075653176_item	2761283	et	4	main
rahva	doc_609075653176_item	2761284	et	3	main
suurematest	doc_609075653176_item	2761289	et	4	main
eesti	doc_609075653176_item	2761291	et	4	main
internetis	doc_609075653176_item	2761292	et	4	main
iga	doc_609075653176_item	2761309	et	4	main
kasutajatele	doc_609075653176_item	2761327	et	4	main
postikast	doc_609075653176_item	2761328	et	3	main
tõlkjaga	doc_609075653176_item	2761335	et	3	main
me	doc_609075653176_item	2761339	et	4	main
on	doc_609075653176_item	2761351	et	4	main
võimalus	doc_609075653176_item	2761355	et	3	main
alati	doc_609075653177_item	2761369	et	4	main
väga	doc_609075653177_item	2761370	et	3	main
inimene	doc_609075653177_item	2761372	et	3	main
meldib	doc_609075653177_item	2761374	et	4	main
see	doc_609075653177_item	2761403	et	3	main
3	doc_609075653177_item	2761406	et	2	main
mul	doc_609075653177_item	2761408	et	3	main
ma	doc_609075653177_item	2761413	et	3	main
neid	doc_609075653177_item	2761415	et	4	main
sõpradega	doc_609075653177_item	2761416	et	3	main
me	doc_609075653177_item	2761418	et	4	main
selgitame	doc_609075653177_item	2761419	et	3	main
vahel	doc_609075653177_item	2761421	et	4	main
iga	doc_609075653177_item	2761423	et	4	main
sõbralt	doc_609075653177_item	2761430	et	3	main
heal	doc_609075653177_item	2761434	et	3	main
sünnipäev	doc_609075653177_item	2761437	et	3	main
siis	doc_609075653177_item	2761438	et	3	main
talle	doc_609075653177_item	2761441	et	4	main
kingitus	doc_609075653177_item	2761442	et	4	main
ma	doc_609075653177_item	2761449	et	3	main
ma	doc_609075653177_item	2761453	et	3	main
appi	doc_609075653177_item	2761483	et	4	main
kui	doc_609075653177_item	2761485	et	3	main
ole	doc_609075653177_item	2761495	et	4	main
ma	doc_609075653177_item	2761499	et	3	main
koos	doc_609075653177_item	2761502	et	4	main
see	doc_609075653177_item	2761504	et	3	main
kuidas	doc_609075653177_item	2761509	et	3	main
tahan	doc_609075653177_item	2761511	et	3	main
ühe	doc_609075653178_item	2761513	et	4	main
muretsemine	doc_609075653173_item	2761046	et	4	main
kui	doc_609075653173_item	2761047	et	3	main
kaasaegne	doc_609075653173_item	2761052	et	3	main
see	doc_609075653173_item	2761058	et	3	main
õptamise	doc_609075653173_item	2761060	et	4	main
oma	doc_609075653174_item	2761070	et	4	main
fregati	doc_609075653174_item	2761084	et	3	main
ma	doc_609075653174_item	2761089	et	3	main
sinna	doc_609075653174_item	2761091	et	3	main
ei	doc_609075653174_item	2761096	et	4	main
oma	doc_609075653174_item	2761099	et	4	main
mehega	doc_609075653174_item	2761106	et	3	main
tavaliselt	doc_609075653174_item	2761108	et	4	main
maksab	doc_609075653174_item	2761109	et	3	main
meesterahvas	doc_609075653174_item	2761110	et	4	main
kui	doc_609075653174_item	2761111	et	3	main
ma	doc_609075653174_item	2761112	et	3	main
eest	doc_609075653174_item	2761120	et	4	main
1	doc_609075653174_item	2761126	et	2	main
krabisalat	doc_609075653174_item	2761129	et	3	main
2	doc_609075653174_item	2761130	et	2	main
moodi	doc_609075653174_item	2761137	et	4	main
4	doc_609075653174_item	2761141	et	2	main
ja	doc_609075653174_item	2761151	et	3	main
tee	doc_609075653174_item	2761160	et	4	main
kakao	doc_609075653174_item	2761161	et	4	main
sõbrale	doc_609075653175_item	2761208	et	3	main
nõuanne	doc_609075653175_item	2761211	et	4	main
ma	doc_609075653175_item	2761220	et	3	main
talle	doc_609075653175_item	2761222	et	4	main
toredad	doc_609075653175_item	2761232	et	3	main
kui	doc_609075653175_item	2761240	et	3	main
ära	doc_609075653175_item	2761250	et	4	main
püüan	doc_609075653175_item	2761252	et	3	main
sellepärast	doc_609075653175_item	2761254	et	3	main
kui	doc_609075653175_item	2761263	et	3	main
kohustusi	doc_609075653175_item	2761268	et	4	main
siis	doc_609075653175_item	2761269	et	3	main
õpin	doc_609075653175_item	2761281	et	3	main
sunee	doc_609075653176_item	2761295	et	4	main
kõige	doc_609075653176_item	2761302	et	4	main
interneti-võimalus	doc_609075653176_item	2761305	et	3	main
25	doc_609075653176_item	2761313	et	2	main
viirustest	doc_609075653176_item	2761334	et	4	main
aadressiraamat	doc_609075653176_item	2761345	et	4	main
samuti	doc_609075653176_item	2761348	et	3	main
kontrolltöö	doc_609075653177_item	2761365	et	4	main
1	doc_609075653177_item	2761366	et	2	main
mulle	doc_609075653177_item	2761373	et	4	main
toniseerib	doc_609075653177_item	2761404	et	3	main
on	doc_609075653177_item	2761409	et	4	main
olukord	doc_609075653177_item	2761411	et	3	main
oma	doc_609075653177_item	2761420	et	4	main
ja	doc_609075653177_item	2761428	et	3	main
4	doc_609075653177_item	2761431	et	2	main
mulle	doc_609075653177_item	2761443	et	4	main
meeldivad	doc_609075653177_item	2761444	et	4	main
sünnipäevad	doc_609075653177_item	2761445	et	3	main
suure	doc_609075653177_item	2761446	et	3	main
sõbrat	doc_609075653177_item	2761478	et	4	main
tihti	doc_609075653177_item	2761479	et	3	main
küsib	doc_609075653177_item	2761480	et	3	main
minu	doc_609075653177_item	2761481	et	3	main
käest	doc_609075653177_item	2761482	et	4	main
mingeid	doc_609075653177_item	2761496	et	3	main
vedan	doc_609075653177_item	2761500	et	4	main
nii	doc_609075653177_item	2761507	et	3	main
tehtud	doc_609075653178_item	2761521	et	4	main
on	doc_609075653178_item	2761528	et	4	main
roheliste	doc_609075653178_item	2761539	et	4	main
veel	doc_609075653178_item	2761542	et	4	main
medali	doc_609075653178_item	2761555	et	3	main
oma	doc_609075653178_item	2761556	et	4	main
õele	doc_609075653178_item	2761557	et	3	main
medal	doc_609075653178_item	2761559	et	3	main
medal	doc_609075653178_item	2761562	et	3	main
puust	doc_609075653178_item	2761569	et	4	main
aga	doc_609075653178_item	2761572	et	3	main
tagasi	doc_609075653178_item	2761581	et	3	main
medal	doc_609075653178_item	2761583	et	3	main
oma	doc_609075653179_item	2761591	et	4	main
kodus	doc_609075653179_item	2761593	et	4	main
prantsuse	doc_609075653174_item	2761136	et	3	main
kodukotled	doc_609075653174_item	2761139	et	4	main
frikartul	doc_609075653174_item	2761143	et	4	main
keedu	doc_609075653174_item	2761144	et	4	main
salat	doc_609075653174_item	2761153	et	3	main
7	doc_609075653174_item	2761167	et	2	main
õlu	doc_609075653174_item	2761174	et	3	main
kontrolltöö	doc_609075653175_item	2761175	et	4	main
1	doc_609075653175_item	2761176	et	2	main
ma	doc_609075653175_item	2761177	et	3	main
olen	doc_609075653175_item	2761178	et	3	main
alati	doc_609075653175_item	2761179	et	4	main
sõbralik	doc_609075653175_item	2761180	et	3	main
inimene	doc_609075653175_item	2761181	et	3	main
see	doc_609075653175_item	2761182	et	3	main
tähendab	doc_609075653175_item	2761183	et	3	main
et	doc_609075653175_item	2761184	et	3	main
ma	doc_609075653175_item	2761185	et	3	main
oma	doc_609075653175_item	2761186	et	4	main
sõpra	doc_609075653175_item	2761187	et	4	main
armastan	doc_609075653175_item	2761188	et	3	main
2	doc_609075653175_item	2761189	et	2	main
mulle	doc_609075653175_item	2761190	et	4	main
õpida	doc_609075653175_item	2761191	et	4	main
meeldib	doc_609075653175_item	2761192	et	3	main
ma	doc_609075653175_item	2761193	et	3	main
parandama	doc_609075653175_item	2761194	et	3	main
mis	doc_609075653175_item	2761195	et	4	main
tahan	doc_609075653175_item	2761196	et	3	main
asja	doc_609075653175_item	2761197	et	4	main
õpin	doc_609075653175_item	2761198	et	3	main
3	doc_609075653175_item	2761199	et	2	main
kui	doc_609075653175_item	2761200	et	3	main
mul	doc_609075653175_item	2761201	et	3	main
on	doc_609075653175_item	2761202	et	4	main
siis	doc_609075653175_item	2761219	et	3	main
mulle	doc_609075653175_item	2761226	et	4	main
need	doc_609075653175_item	2761229	et	3	main
ei	doc_609075653175_item	2761236	et	4	main
ole	doc_609075653175_item	2761237	et	4	main
tihti	doc_609075653175_item	2761238	et	3	main
appi	doc_609075653175_item	2761245	et	4	main
kuulan	doc_609075653175_item	2761248	et	3	main
me	doc_609075653175_item	2761256	et	4	main
mul	doc_609075653175_item	2761264	et	3	main
ole	doc_609075653175_item	2761266	et	4	main
välja	doc_609075653175_item	2761272	et	4	main
selliseid	doc_609075653175_item	2761274	et	4	main
hetki	doc_609075653175_item	2761275	et	4	main
ei	doc_609075653175_item	2761276	et	4	main
wwwsunee	doc_609075653176_item	2761286	et	4	main
üks	doc_609075653176_item	2761287	et	3	main
rohkem	doc_609075653176_item	2761296	et	4	main
3	doc_609075653176_item	2761298	et	2	main
miljoni	doc_609075653176_item	2761299	et	3	main
sunee	doc_609075653176_item	2761301	et	4	main
eesti	doc_609075653176_item	2761304	et	4	main
rohkem	doc_609075653176_item	2761311	et	4	main
tasuliste	doc_609075653176_item	2761321	et	4	main
piiritu	doc_609075653176_item	2761329	et	4	main
suuruse	doc_609075653176_item	2761330	et	4	main
kaitsega	doc_609075653176_item	2761331	et	3	main
ja	doc_609075653176_item	2761336	et	3	main
veel	doc_609075653176_item	2761338	et	4	main
pakkume	doc_609075653176_item	2761340	et	4	main
häälposti	doc_609075653176_item	2761341	et	4	main
kalender	doc_609075653176_item	2761342	et	3	main
koduleht	doc_609075653176_item	2761343	et	3	main
foorumid	doc_609075653176_item	2761344	et	3	main
wwwsunee	doc_609075653176_item	2761359	et	4	main
see	doc_609075653176_item	2761360	et	3	main
on	doc_609075653176_item	2761361	et	4	main
päike	doc_609075653176_item	2761362	et	3	main
sinus	doc_609075653176_item	2761363	et	3	main
majas	doc_609075653176_item	2761364	et	3	main
meeldib	doc_609075653175_item	2761227	et	3	main
sünnipäevad	doc_609075653175_item	2761228	et	3	main
5	doc_609075653175_item	2761239	et	2	main
ja	doc_609075653175_item	2761251	et	3	main
6	doc_609075653175_item	2761262	et	2	main
ei	doc_609075653175_item	2761265	et	4	main
mingeid	doc_609075653175_item	2761267	et	3	main
ma	doc_609075653175_item	2761270	et	3	main
ma	doc_609075653175_item	2761280	et	3	main
kõige	doc_609075653176_item	2761288	et	4	main
igapäevane	doc_609075653176_item	2761293	et	4	main
auditoorium	doc_609075653176_item	2761294	et	3	main
päev	doc_609075653176_item	2761310	et	3	main
miljoni	doc_609075653176_item	2761314	et	3	main
kirjad	doc_609075653176_item	2761315	et	4	main
sunee	doc_609075653176_item	2761316	et	4	main
laeneb	doc_609075653176_item	2761317	et	4	main
juhtiv	doc_609075653176_item	2761318	et	4	main
positsiooni	doc_609075653176_item	2761319	et	4	main
mitte	doc_609075653176_item	2761320	et	3	main
lähen	doc_609075653175_item	2761221	et	3	main
pärast	doc_609075653175_item	2761223	et	4	main
tööd	doc_609075653175_item	2761224	et	4	main
väga	doc_609075653175_item	2761231	et	3	main
olukordi	doc_609075653175_item	2761234	et	4	main
sõber	doc_609075653175_item	2761242	et	3	main
mind	doc_609075653175_item	2761244	et	4	main
siis	doc_609075653175_item	2761246	et	3	main
ta	doc_609075653175_item	2761249	et	4	main
et	doc_609075653175_item	2761255	et	3	main
sõbrame	doc_609075653175_item	2761257	et	4	main
selliseid	doc_609075653175_item	2761258	et	4	main
juhtub	doc_609075653175_item	2761259	et	3	main
mitte	doc_609075653175_item	2761260	et	3	main
tihti	doc_609075653175_item	2761261	et	3	main
lähen	doc_609075653175_item	2761271	et	3	main
jalutama	doc_609075653175_item	2761273	et	3	main
postiteenistus	doc_609075653176_item	2761285	et	3	main
portaalidest	doc_609075653176_item	2761290	et	3	main
kui	doc_609075653176_item	2761297	et	3	main
kasutajaid	doc_609075653176_item	2761300	et	4	main
kiirem	doc_609075653176_item	2761303	et	4	main
postkasti	doc_609075653176_item	2761306	et	4	main
käib	doc_609075653176_item	2761307	et	3	main
läbi	doc_609075653176_item	2761308	et	4	main
kui	doc_609075653176_item	2761312	et	3	main
posti	doc_609075653176_item	2761322	et	4	main
teeninduste	doc_609075653176_item	2761323	et	4	main
seas	doc_609075653176_item	2761324	et	4	main
võimaldame	doc_609075653176_item	2761325	et	3	main
rämpspostist	doc_609075653176_item	2761332	et	4	main
ja	doc_609075653176_item	2761333	et	3	main
otsingu	doc_609075653176_item	2761346	et	3	main
võimalus	doc_609075653176_item	2761347	et	3	main
sunifon	doc_609075653176_item	2761349	et	4	main
ja	doc_609075653176_item	2761353	et	3	main
helistada	doc_609075653176_item	2761356	et	3	main
olen	doc_609075653177_item	2761368	et	3	main
organismi	doc_609075653177_item	2761405	et	4	main
abi	doc_609075653177_item	2761427	et	4	main
nõu	doc_609075653177_item	2761429	et	4	main
on	doc_609075653177_item	2761436	et	4	main
ma	doc_609075653177_item	2761439	et	3	main
sünnipäeval	doc_609075653177_item	2761452	et	3	main
ei	doc_609075653177_item	2761454	et	4	main
lähe	doc_609075653177_item	2761455	et	4	main
nii	doc_609075653177_item	2761456	et	3	main
tihti	doc_609075653177_item	2761457	et	3	main
kuidas	doc_609075653177_item	2761458	et	3	main
mina	doc_609075653177_item	2761459	et	4	main
tahan	doc_609075653177_item	2761460	et	3	main
5	doc_609075653177_item	2761461	et	2	main
kui	doc_609075653177_item	2761462	et	3	main
ma	doc_609075653177_item	2761488	et	3	main
kui	doc_609075653177_item	2761492	et	3	main
siis	doc_609075653177_item	2761498	et	3	main
ei	doc_609075653177_item	2761505	et	4	main
ole	doc_609075653177_item	2761506	et	4	main
on	doc_609075653178_item	2761517	et	4	main
medal	doc_609075653178_item	2761519	et	3	main
peizhaasis	doc_609075653178_item	2761527	et	4	main
helesinine	doc_609075653178_item	2761530	et	4	main
suur	doc_609075653178_item	2761536	et	3	main
seal	doc_609075653178_item	2761543	et	4	main
on	doc_609075653178_item	2761544	et	4	main
joonistus	doc_609075653178_item	2761548	et	4	main
joonistas	doc_609075653178_item	2761549	et	3	main
üks	doc_609075653178_item	2761550	et	3	main
tüdruk	doc_609075653178_item	2761551	et	3	main
medali	doc_609075653178_item	2761571	et	3	main
mõned	doc_609075653179_item	2761588	et	3	main
inimesed	doc_609075653179_item	2761589	et	3	main
väga	doc_609075653179_item	2761623	et	3	main
ja	doc_609075653179_item	2761626	et	3	main
võib	doc_609075653179_item	2761627	et	3	main
aita	doc_609075653179_item	2761639	et	4	main
mitte	doc_609075653179_item	2761640	et	3	main
eksita	doc_609075653179_item	2761641	et	4	main
õiget	doc_609075653179_item	2761646	et	3	main
on	doc_609075653179_item	2761650	et	4	main
pihuarvutiga	doc_609075653179_item	2761671	et	4	main
vastus	doc_609075653180_item	2761672	et	3	main
oma	doc_609075653176_item	2761326	et	4	main
ne	doc_609075653176_item	2761337	et	4	main
see	doc_609075653176_item	2761350	et	3	main
moodne	doc_609075653176_item	2761352	et	3	main
tasuta	doc_609075653176_item	2761354	et	4	main
interneti	doc_609075653176_item	2761357	et	4	main
kaudu	doc_609075653176_item	2761358	et	3	main
mina	doc_609075653177_item	2761367	et	4	main
aktiivne	doc_609075653177_item	2761371	et	3	main
vestelda	doc_609075653177_item	2761375	et	4	main
inimestega	doc_609075653177_item	2761376	et	3	main
ma	doc_609075653177_item	2761377	et	3	main
armastan	doc_609075653177_item	2761378	et	3	main
kulata	doc_609075653177_item	2761379	et	3	main
inimestega	doc_609075653177_item	2761380	et	3	main
ja	doc_609075653177_item	2761381	et	3	main
kui	doc_609075653177_item	2761382	et	3	main
ma	doc_609075653177_item	2761383	et	3	main
saan	doc_609075653177_item	2761384	et	4	main
aidata	doc_609075653177_item	2761385	et	4	main
siis	doc_609075653177_item	2761386	et	3	main
ma	doc_609075653177_item	2761387	et	3	main
loomulikul	doc_609075653177_item	2761388	et	3	main
aitan	doc_609075653177_item	2761389	et	3	main
2	doc_609075653177_item	2761390	et	2	main
mulle	doc_609075653177_item	2761391	et	4	main
meeldib	doc_609075653177_item	2761392	et	3	main
jälutada	doc_609075653177_item	2761393	et	4	main
pargis	doc_609075653177_item	2761394	et	3	main
koos	doc_609075653177_item	2761395	et	4	main
sõbradega	doc_609075653177_item	2761396	et	4	main
sest	doc_609075653177_item	2761397	et	4	main
on	doc_609075653177_item	2761398	et	4	main
võimalus	doc_609075653177_item	2761399	et	3	main
hingata	doc_609075653177_item	2761400	et	4	main
värsket	doc_609075653177_item	2761401	et	4	main
õhku	doc_609075653177_item	2761402	et	4	main
kui	doc_609075653177_item	2761407	et	3	main
pingiline	doc_609075653177_item	2761410	et	4	main
siis	doc_609075653177_item	2761412	et	3	main
lahendan	doc_609075653177_item	2761414	et	3	main
mõnikord	doc_609075653177_item	2761417	et	3	main
mu	doc_609075653177_item	2761433	et	3	main
läks	doc_609075653177_item	2761450	et	3	main
ma	doc_609075653177_item	2761486	et	3	main
temale	doc_609075653177_item	2761490	et	3	main
ei	doc_609075653177_item	2761494	et	4	main
kohustusi	doc_609075653177_item	2761497	et	4	main
tihti	doc_609075653177_item	2761508	et	3	main
kirjeldus	doc_609075653178_item	2761512	et	4	main
eseme	doc_609075653178_item	2761514	et	3	main
on	doc_609075653178_item	2761520	et	4	main
puust	doc_609075653178_item	2761522	et	4	main
medalil	doc_609075653178_item	2761523	et	3	main
ilus	doc_609075653178_item	2761529	et	4	main
taevas	doc_609075653178_item	2761531	et	4	main
krooni	doc_609075653178_item	2761540	et	4	main
lehtega	doc_609075653178_item	2761541	et	4	main
ta	doc_609075653178_item	2761552	et	4	main
tegin	doc_609075653178_item	2761553	et	3	main
seda	doc_609075653178_item	2761554	et	3	main
on	doc_609075653178_item	2761563	et	4	main
tehtuma	doc_609075653178_item	2761570	et	3	main
noorem	doc_609075653178_item	2761573	et	4	main
õde	doc_609075653178_item	2761574	et	4	main
joonistas	doc_609075653178_item	2761575	et	3	main
see	doc_609075653178_item	2761576	et	3	main
oli	doc_609075653178_item	2761578	et	3	main
on	doc_609075653179_item	2761622	et	4	main
lihtsalt	doc_609075653179_item	2761643	et	4	main
leida	doc_609075653179_item	2761648	et	3	main
kaart	doc_609075653179_item	2761651	et	4	main
mobiiltelefonis	doc_609075653179_item	2761652	et	3	main
ee	doc_609075653179_item	2761653	et	3	main
on	doc_609075653179_item	2761654	et	4	main
väga	doc_609075653179_item	2761655	et	3	main
mugav	doc_609075653179_item	2761656	et	3	main
kaasas	doc_609075653179_item	2761662	et	4	main
küsimusele	doc_609075653180_item	2761673	et	4	main
õppida	doc_609075653180_item	2761680	et	3	main
sest	doc_609075653180_item	2761681	et	4	main
kooli	doc_609075653180_item	2761683	et	4	main
tahan	doc_609075653180_item	2761684	et	3	main
õppida	doc_609075653180_item	2761685	et	3	main
ülikoolis	doc_609075653180_item	2761686	et	4	main
ja	doc_609075653180_item	2761687	et	3	main
hea	doc_609075653180_item	2761694	et	4	main
on	doc_609075653180_item	2761697	et	4	main
elus	doc_609075653180_item	2761705	et	4	main
kuidas	doc_609075653180_item	2761710	et	3	main
praegu	doc_609075653180_item	2761713	et	3	main
soovi	doc_609075653180_item	2761726	et	4	main
väsin	doc_609075653180_item	2761730	et	3	main
ja	doc_609075653180_item	2761732	et	3	main
ei	doc_609075653180_item	2761734	et	4	main
saa	doc_609075653180_item	2761735	et	4	main
teha	doc_609075653180_item	2761736	et	3	main
sõltub	doc_609075653180_item	2761756	et	3	main
et	doc_609075653180_item	2761766	et	3	main
ma	doc_609075653180_item	2761772	et	3	main
läksin	doc_609075653180_item	2761800	et	3	main
klasisse	doc_609075653180_item	2761802	et	4	main
aru	doc_609075653180_item	2761805	et	4	main
et	doc_609075653180_item	2761806	et	3	main
on	doc_609075653180_item	2761808	et	4	main
mul	doc_609075653180_item	2761811	et	3	main
ma	doc_609075653180_item	2761819	et	3	main
sinu	doc_609075653180_item	2761828	et	3	main
õppetöös	doc_609075653180_item	2761830	et	3	main
et	doc_609075653180_item	2761833	et	3	main
õppetöös	doc_609075653180_item	2761838	et	3	main
on	doc_609075653180_item	2761841	et	4	main
sihekindel	doc_609075653180_item	2761842	et	4	main
peamised	doc_609075653180_item	2761862	et	3	main
arvan	doc_609075653180_item	2761865	et	3	main
kooli	doc_609075653180_item	2761893	et	4	main
eksamid	doc_609075653180_item	2761894	et	3	main
hästi	doc_609075653180_item	2761895	et	3	main
vahekorda	doc_609075653177_item	2761422	et	4	main
kord	doc_609075653177_item	2761424	et	4	main
ma	doc_609075653177_item	2761425	et	3	main
ootan	doc_609075653177_item	2761426	et	3	main
kui	doc_609075653177_item	2761432	et	3	main
tuttaval	doc_609075653177_item	2761435	et	4	main
ostan	doc_609075653177_item	2761440	et	3	main
hea	doc_609075653177_item	2761447	et	4	main
meelega	doc_609075653177_item	2761448	et	4	main
sünnipäevasse	doc_609075653177_item	2761451	et	4	main
mu	doc_609075653177_item	2761463	et	3	main
sõber	doc_609075653177_item	2761464	et	3	main
palub	doc_609075653177_item	2761465	et	3	main
mind	doc_609075653177_item	2761466	et	4	main
appi	doc_609075653177_item	2761467	et	4	main
siis	doc_609075653177_item	2761468	et	3	main
ma	doc_609075653177_item	2761469	et	3	main
loomulikult	doc_609075653177_item	2761470	et	4	main
aitan	doc_609075653177_item	2761471	et	3	main
teda	doc_609075653177_item	2761472	et	4	main
ma	doc_609075653177_item	2761473	et	3	main
olen	doc_609075653177_item	2761474	et	3	main
inimene	doc_609075653177_item	2761476	et	3	main
abivalmis	doc_609075653177_item	2761475	et	3	main
minu	doc_609075653177_item	2761477	et	3	main
ja	doc_609075653177_item	2761484	et	3	main
saan	doc_609075653177_item	2761487	et	4	main
aitan	doc_609075653177_item	2761489	et	3	main
6	doc_609075653177_item	2761491	et	2	main
mul	doc_609075653177_item	2761493	et	3	main
vaheaed	doc_609075653177_item	2761501	et	3	main
sõpradega	doc_609075653177_item	2761503	et	3	main
mina	doc_609075653177_item	2761510	et	4	main
see	doc_609075653178_item	2761516	et	3	main
luge	doc_609075653178_item	2761515	et	3	main
medal	doc_609075653178_item	2761518	et	3	main
peizhaas	doc_609075653178_item	2761526	et	4	main
mere	doc_609075653178_item	2761533	et	3	main
on	doc_609075653178_item	2761535	et	4	main
mururoheline	doc_609075653178_item	2761545	et	4	main
sõprust	doc_609075653178_item	2761561	et	3	main
kodust	doc_609075653178_item	2761565	et	4	main
isa	doc_609075653178_item	2761567	et	4	main
aitab	doc_609075653178_item	2761568	et	3	main
loo	doc_609075653178_item	2761577	et	4	main
ühel	doc_609075653178_item	2761579	et	3	main
tehtud	doc_609075653178_item	2761585	et	4	main
kirjeldus	doc_609075653179_item	2761587	et	4	main
armastavad	doc_609075653179_item	2761590	et	4	main
puhkuses	doc_609075653179_item	2761592	et	4	main
see	doc_609075653179_item	2761621	et	3	main
keeruline	doc_609075653179_item	2761624	et	4	main
kohas	doc_609075653179_item	2761629	et	4	main
pöörama	doc_609075653179_item	2761630	et	3	main
see	doc_609075653179_item	2761631	et	3	main
võib	doc_609075653179_item	2761632	et	3	main
ja	doc_609075653179_item	2761642	et	3	main
mobiiltelefon	doc_609075653179_item	2761660	et	3	main
osta	doc_609075653179_item	2761664	et	4	main
miks	doc_609075653180_item	2761674	et	4	main
ma	doc_609075653180_item	2761675	et	3	main
tahan	doc_609075653180_item	2761676	et	3	main
õppida	doc_609075653180_item	2761677	et	3	main
töötada	doc_609075653180_item	2761689	et	3	main
jaoks	doc_609075653180_item	2761693	et	4	main
mängivad	doc_609075653180_item	2761707	et	4	main
suurt	doc_609075653180_item	2761708	et	3	main
ole	doc_609075653180_item	2761723	et	4	main
ja	doc_609075653180_item	2761725	et	3	main
ma	doc_609075653180_item	2761728	et	3	main
koolis	doc_609075653180_item	2761731	et	4	main
kodus	doc_609075653180_item	2761733	et	4	main
klass	doc_609075653180_item	2761749	et	3	main
oluline	doc_609075653180_item	2761752	et	4	main
minu	doc_609075653180_item	2761757	et	3	main
elu	doc_609075653180_item	2761759	et	4	main
varem	doc_609075653180_item	2761762	et	4	main
õppisid	doc_609075653180_item	2761763	et	4	main
ma	doc_609075653180_item	2761764	et	3	main
õppisin	doc_609075653180_item	2761769	et	3	main
raske	doc_609075653180_item	2761809	et	4	main
ole	doc_609075653180_item	2761813	et	4	main
soovi	doc_609075653180_item	2761814	et	4	main
õppida	doc_609075653180_item	2761815	et	3	main
edasi	doc_609075653180_item	2761816	et	3	main
on	doc_609075653178_item	2761524	et	4	main
joonistatud	doc_609075653178_item	2761525	et	4	main
tumesinine	doc_609075653178_item	2761532	et	4	main
keskel	doc_609075653178_item	2761534	et	3	main
puu	doc_609075653178_item	2761537	et	4	main
kirjulise	doc_609075653178_item	2761538	et	4	main
padi	doc_609075653178_item	2761546	et	3	main
selle	doc_609075653178_item	2761547	et	4	main
see	doc_609075653178_item	2761558	et	3	main
tähendab	doc_609075653178_item	2761560	et	3	main
toodud	doc_609075653178_item	2761564	et	4	main
tüdrukutele	doc_609075653178_item	2761566	et	4	main
kuud	doc_609075653178_item	2761580	et	4	main
see	doc_609075653178_item	2761582	et	3	main
oli	doc_609075653178_item	2761584	et	3	main
armastust	doc_609075653178_item	2761586	et	4	main
teised	doc_609075653179_item	2761595	et	4	main
armastavad	doc_609075653179_item	2761596	et	4	main
lülitamised	doc_609075653179_item	2761597	et	4	main
otsima	doc_609075653179_item	2761598	et	4	main
ja	doc_609075653179_item	2761599	et	3	main
sõidavad	doc_609075653179_item	2761600	et	3	main
selle	doc_609075653179_item	2761601	et	4	main
jaoks	doc_609075653179_item	2761602	et	4	main
välismaale	doc_609075653179_item	2761603	et	4	main
puhkusereis	doc_609075653179_item	2761604	et	4	main
välismaal	doc_609075653179_item	2761605	et	4	main
on	doc_609075653179_item	2761606	et	4	main
ebatavaline	doc_609075653179_item	2761607	et	4	main
ja	doc_609075653179_item	2761608	et	3	main
väga	doc_609075653179_item	2761609	et	3	main
huvitav	doc_609075653179_item	2761610	et	4	main
aga	doc_609075653179_item	2761611	et	3	main
tundmatus	doc_609075653179_item	2761612	et	4	main
kohtades	doc_609075653179_item	2761613	et	3	main
isegi	doc_609075653179_item	2761614	et	4	main
kaardistikuga	doc_609075653179_item	2761615	et	3	main
on	doc_609075653179_item	2761616	et	4	main
raskelt	doc_609075653179_item	2761617	et	4	main
õiget	doc_609075653179_item	2761618	et	3	main
teed	doc_609075653179_item	2761619	et	4	main
leida	doc_609075653179_item	2761620	et	3	main
istuda	doc_609075653179_item	2761594	et	3	main
lisakilomeetrid	doc_609075653179_item	2761635	et	4	main
uus	doc_609075653179_item	2761636	et	3	main
tehnoloogia	doc_609075653179_item	2761637	et	4	main
võib	doc_609075653179_item	2761638	et	3	main
ja	doc_609075653179_item	2761644	et	3	main
teed	doc_609075653179_item	2761647	et	4	main
see	doc_609075653179_item	2761649	et	3	main
ligi	doc_609075653179_item	2761658	et	3	main
on	doc_609075653179_item	2761661	et	4	main
mobiiltelefon	doc_609075653179_item	2761665	et	3	main
on	doc_609075653179_item	2761667	et	4	main
tulevikus	doc_609075653180_item	2761688	et	4	main
tööl	doc_609075653180_item	2761691	et	3	main
rahad	doc_609075653180_item	2761703	et	4	main
mul	doc_609075653180_item	2761721	et	3	main
aega	doc_609075653180_item	2761724	et	4	main
koduseülesandeid	doc_609075653180_item	2761737	et	4	main
ma	doc_609075653180_item	2761740	et	3	main
tulemustest	doc_609075653180_item	2761755	et	4	main
tulevik	doc_609075653180_item	2761758	et	3	main
kuidas	doc_609075653180_item	2761760	et	3	main
ma	doc_609075653180_item	2761768	et	3	main
sain	doc_609075653180_item	2761804	et	3	main
see	doc_609075653180_item	2761807	et	3	main
ja	doc_609075653180_item	2761810	et	3	main
praegu	doc_609075653180_item	2761818	et	3	main
on	doc_609075653180_item	2761826	et	4	main
jaoks	doc_609075653180_item	2761829	et	4	main
arvan	doc_609075653180_item	2761832	et	3	main
jaoks	doc_609075653180_item	2761846	et	4	main
õppida	doc_609075653180_item	2761857	et	3	main
sinu	doc_609075653180_item	2761861	et	3	main
tunnistus	doc_609075653180_item	2761868	et	4	main
ja	doc_609075653180_item	2761869	et	3	main
riigieksami	doc_609075653180_item	2761870	et	3	main
tulemused	doc_609075653180_item	2761871	et	3	main
sellest	doc_609075653180_item	2761876	et	4	main
sõltub	doc_609075653180_item	2761877	et	3	main
edaspidine	doc_609075653180_item	2761878	et	3	main
enda	doc_609075653180_item	2761885	et	4	main
jaoks	doc_609075653180_item	2761886	et	4	main
saada	doc_609075653180_item	2761897	et	4	main
mis	doc_609075653180_item	2761900	et	4	main
õppimine	doc_609075653180_item	2761927	et	4	main
kuidas	doc_609075653180_item	2761935	et	3	main
oma	doc_609075653180_item	2761938	et	4	main
tulevikus	doc_609075653180_item	2761940	et	4	main
oma	doc_609075653180_item	2761943	et	4	main
õpinguid	doc_609075653180_item	2761944	et	3	main
tahan	doc_609075653181_item	2761969	et	3	main
tulevikku	doc_609075653181_item	2761971	et	4	main
teadmiseid	doc_609075653181_item	2761974	et	4	main
õppid	doc_609075653181_item	2761978	et	4	main
peremini	doc_609075653181_item	2761994	et	4	main
kui	doc_609075653181_item	2761995	et	3	main
praegu	doc_609075653181_item	2761996	et	3	main
3	doc_609075653181_item	2761997	et	2	main
kuidas	doc_609075653181_item	2761998	et	3	main
sa	doc_609075653181_item	2761999	et	3	main
mis	doc_609075653181_item	2762009	et	4	main
õppida	doc_609075653181_item	2762021	et	3	main
näiteks	doc_609075653181_item	2762025	et	4	main
vastupidavus	doc_609075653181_item	2762027	et	4	main
on	doc_609075653181_item	2762031	et	4	main
head	doc_609075653181_item	2762042	et	4	main
jaoks	doc_609075653181_item	2762056	et	4	main
püstitasid	doc_609075653181_item	2762057	et	4	main
ma	doc_609075653181_item	2762058	et	3	main
püstitasin	doc_609075653181_item	2762059	et	3	main
erinevad	doc_609075653181_item	2762062	et	4	main
ülekoolis	doc_609075653181_item	2762070	et	4	main
juurde	doc_609075653181_item	2762071	et	4	main
sinu	doc_609075653181_item	2762075	et	3	main
õppetööd	doc_609075653181_item	2762078	et	4	main
tulevikus	doc_609075653181_item	2762093	et	4	main
praegu	doc_609075653182_item	2762152	et	3	main
tulemuste	doc_609075653182_item	2762157	et	4	main
jaoks	doc_609075653182_item	2762158	et	4	main
õpetajate	doc_609075653182_item	2762173	et	4	main
vahel	doc_609075653182_item	2762174	et	4	main
orienteeruma	doc_609075653179_item	2761625	et	3	main
vales	doc_609075653179_item	2761628	et	3	main
tähendama	doc_609075653179_item	2761633	et	3	main
palju	doc_609075653179_item	2761634	et	4	main
kiiresti	doc_609075653179_item	2761645	et	3	main
sest	doc_609075653179_item	2761657	et	4	main
paljudes	doc_609075653179_item	2761659	et	3	main
ka	doc_609075653179_item	2761663	et	3	main
navigatsioonitarkvaraga	doc_609075653179_item	2761666	et	3	main
odavam	doc_609075653179_item	2761668	et	4	main
kui	doc_609075653179_item	2761669	et	3	main
navigatsioonsüsteemi	doc_609075653179_item	2761670	et	4	main
ma	doc_609075653180_item	2761678	et	3	main
heal	doc_609075653180_item	2761690	et	3	main
minu	doc_609075653180_item	2761692	et	3	main
töö	doc_609075653180_item	2761695	et	4	main
meie	doc_609075653180_item	2761704	et	4	main
rolli	doc_609075653180_item	2761709	et	4	main
õpid	doc_609075653180_item	2761712	et	4	main
praegu	doc_609075653180_item	2761714	et	3	main
õpin	doc_609075653180_item	2761716	et	3	main
kesmisel	doc_609075653180_item	2761717	et	4	main
tasel	doc_609075653180_item	2761718	et	4	main
sest	doc_609075653180_item	2761719	et	4	main
samuti	doc_609075653180_item	2761720	et	3	main
tahan	doc_609075653180_item	2761679	et	3	main
pärast	doc_609075653180_item	2761682	et	4	main
see	doc_609075653180_item	2761696	et	3	main
töö	doc_609075653180_item	2761698	et	4	main
kus	doc_609075653180_item	2761699	et	3	main
ma	doc_609075653180_item	2761700	et	3	main
teeniksin	doc_609075653180_item	2761701	et	3	main
head	doc_609075653180_item	2761702	et	4	main
rahad	doc_609075653180_item	2761706	et	4	main
sa	doc_609075653180_item	2761711	et	3	main
ma	doc_609075653180_item	2761715	et	3	main
ei	doc_609075653180_item	2761722	et	4	main
õppida	doc_609075653180_item	2761727	et	3	main
aga	doc_609075653180_item	2761738	et	3	main
püüan	doc_609075653180_item	2761741	et	3	main
hästi	doc_609075653180_item	2761743	et	3	main
saan	doc_609075653180_item	2761745	et	4	main
aru	doc_609075653180_item	2761746	et	4	main
et	doc_609075653180_item	2761747	et	3	main
12	doc_609075653180_item	2761748	et	2	main
ja	doc_609075653180_item	2761753	et	3	main
sa	doc_609075653180_item	2761761	et	3	main
varem	doc_609075653180_item	2761767	et	4	main
halvem	doc_609075653180_item	2761770	et	4	main
ma	doc_609075653180_item	2761799	et	3	main
10	doc_609075653180_item	2761801	et	2	main
ma	doc_609075653180_item	2761803	et	3	main
ei	doc_609075653180_item	2761812	et	4	main
tahaksin	doc_609075653180_item	2761820	et	3	main
kooli	doc_609075653180_item	2761822	et	4	main
mis	doc_609075653180_item	2761825	et	4	main
ma	doc_609075653180_item	2761831	et	3	main
minu	doc_609075653180_item	2761834	et	3	main
peamine	doc_609075653180_item	2761837	et	3	main
mul	doc_609075653180_item	2761840	et	3	main
kui	doc_609075653180_item	2761848	et	3	main
inimestel	doc_609075653180_item	2761849	et	3	main
ei	doc_609075653180_item	2761850	et	4	main
missugused	doc_609075653180_item	2761859	et	3	main
õppe-eesmärgid	doc_609075653180_item	2761863	et	3	main
hea	doc_609075653180_item	2761867	et	4	main
ja	doc_609075653180_item	2761880	et	3	main
sa	doc_609075653180_item	2761884	et	3	main
tunnistus	doc_609075653180_item	2761899	et	4	main
avab	doc_609075653180_item	2761901	et	3	main
mõjutab	doc_609075653180_item	2761911	et	3	main
elukeskond	doc_609075653180_item	2761912	et	4	main
vanemaid	doc_609075653180_item	2761917	et	4	main
nad	doc_609075653180_item	2761919	et	3	main
tihti	doc_609075653180_item	2761729	et	3	main
praegu	doc_609075653180_item	2761739	et	3	main
õppida	doc_609075653180_item	2761742	et	3	main
sest	doc_609075653180_item	2761744	et	4	main
on	doc_609075653180_item	2761750	et	4	main
väga	doc_609075653180_item	2761751	et	3	main
sellest	doc_609075653180_item	2761754	et	4	main
arvan	doc_609075653180_item	2761765	et	3	main
sest	doc_609075653180_item	2761771	et	4	main
teadsin	doc_609075653180_item	2761773	et	3	main
et	doc_609075653180_item	2761774	et	3	main
ja	doc_609075653180_item	2761776	et	3	main
algharidus	doc_609075653180_item	2761775	et	3	main
põhiharidus	doc_609075653180_item	2761777	et	3	main
nii	doc_609075653180_item	2761780	et	3	main
ole	doc_609075653180_item	2761779	et	4	main
ei	doc_609075653180_item	2761778	et	4	main
olulised	doc_609075653180_item	2761781	et	4	main
kui	doc_609075653180_item	2761782	et	3	main
keskharidus	doc_609075653180_item	2761783	et	3	main
aga	doc_609075653180_item	2761784	et	3	main
ma	doc_609075653180_item	2761785	et	3	main
püüan	doc_609075653180_item	2761786	et	3	main
õppida	doc_609075653180_item	2761787	et	3	main
hästi	doc_609075653180_item	2761788	et	3	main
ka	doc_609075653180_item	2761789	et	3	main
üheksandas	doc_609075653180_item	2761790	et	3	main
klassis	doc_609075653180_item	2761791	et	3	main
ma	doc_609075653180_item	2761792	et	3	main
püüüan	doc_609075653180_item	2761793	et	4	main
ja	doc_609075653180_item	2761794	et	3	main
saan	doc_609075653180_item	2761795	et	4	main
lõppetada	doc_609075653180_item	2761796	et	4	main
kooli	doc_609075653180_item	2761797	et	4	main
kolmatakui	doc_609075653180_item	2761798	et	4	main
aga	doc_609075653180_item	2761817	et	3	main
ja	doc_609075653180_item	2761843	et	3	main
soov	doc_609075653180_item	2761844	et	3	main
õppimise	doc_609075653180_item	2761845	et	4	main
ole	doc_609075653180_item	2761851	et	4	main
ma	doc_609075653180_item	2761864	et	3	main
et	doc_609075653180_item	2761866	et	3	main
on	doc_609075653180_item	2761872	et	4	main
tähtis	doc_609075653180_item	2761873	et	4	main
haridus	doc_609075653180_item	2761879	et	3	main
ülesanded	doc_609075653180_item	2761883	et	3	main
püstitasid	doc_609075653180_item	2761887	et	4	main
ma	doc_609075653180_item	2761888	et	3	main
tahan	doc_609075653180_item	2761889	et	3	main
kirjutada	doc_609075653180_item	2761890	et	3	main
riigi	doc_609075653180_item	2761891	et	3	main
ja	doc_609075653180_item	2761892	et	3	main
hea	doc_609075653180_item	2761898	et	4	main
mulle	doc_609075653180_item	2761902	et	4	main
hea	doc_609075653180_item	2761903	et	4	main
tulevik	doc_609075653180_item	2761904	et	3	main
õpetajad	doc_609075653180_item	2761913	et	4	main
minu	doc_609075653180_item	2761914	et	3	main
sõbrad	doc_609075653180_item	2761915	et	3	main
sõbradega	doc_609075653180_item	2761928	et	4	main
samuti	doc_609075653180_item	2761929	et	3	main
mõjutab	doc_609075653180_item	2761930	et	3	main
minu	doc_609075653180_item	2761931	et	3	main
näed	doc_609075653180_item	2761937	et	3	main
ja	doc_609075653180_item	2761951	et	3	main
saan	doc_609075653180_item	2761952	et	4	main
sa	doc_609075653181_item	2761977	et	3	main
praegu	doc_609075653181_item	2761979	et	3	main
ma	doc_609075653181_item	2761981	et	3	main
järgmisel	doc_609075653181_item	2761985	et	3	main
aastal	doc_609075653181_item	2761986	et	3	main
aga	doc_609075653181_item	2761987	et	3	main
algkoolis	doc_609075653181_item	2761990	et	4	main
ja	doc_609075653181_item	2761991	et	3	main
põhikoolis	doc_609075653181_item	2761992	et	4	main
õppisid	doc_609075653181_item	2762001	et	4	main
varem	doc_609075653181_item	2762002	et	4	main
ma	doc_609075653181_item	2762003	et	3	main
õppisin	doc_609075653181_item	2762004	et	3	main
on	doc_609075653181_item	2762010	et	4	main
õppetöös	doc_609075653181_item	2762014	et	3	main
jaoks	doc_609075653181_item	2762016	et	4	main
peamine	doc_609075653181_item	2762017	et	3	main
on	doc_609075653181_item	2762018	et	4	main
õppilase	doc_609075653181_item	2762019	et	4	main
omadused	doc_609075653181_item	2762024	et	4	main
5	doc_609075653181_item	2762029	et	2	main
sinu	doc_609075653181_item	2762032	et	3	main
on	doc_609075653181_item	2762038	et	4	main
suhted	doc_609075653181_item	2762043	et	3	main
õpitajatega	doc_609075653181_item	2762045	et	4	main
riigieksamide	doc_609075653181_item	2762067	et	4	main
ja	doc_609075653181_item	2762068	et	3	main
õppimise	doc_609075653181_item	2762069	et	4	main
mõjutab	doc_609075653181_item	2762074	et	3	main
õppetööd	doc_609075653181_item	2762076	et	4	main
näiteks	doc_609075653181_item	2762082	et	4	main
kollektiivis	doc_609075653181_item	2762084	et	3	main
ja	doc_609075653181_item	2762085	et	3	main
kodus	doc_609075653181_item	2762086	et	4	main
8	doc_609075653181_item	2762087	et	2	main
kuidas	doc_609075653181_item	2762088	et	3	main
2	doc_609075653182_item	2762122	et	2	main
õpid	doc_609075653182_item	2762125	et	4	main
praegu	doc_609075653182_item	2762127	et	3	main
õpin	doc_609075653182_item	2762129	et	3	main
kui	doc_609075653182_item	2762131	et	3	main
sest	doc_609075653182_item	2762133	et	4	main
täna	doc_609075653182_item	2762134	et	4	main
ma	doc_609075653182_item	2762135	et	3	main
varem	doc_609075653182_item	2762145	et	4	main
ma	doc_609075653182_item	2762146	et	3	main
õppisin	doc_609075653182_item	2762147	et	3	main
oma	doc_609075653182_item	2762148	et	4	main
ma	doc_609075653182_item	2762153	et	3	main
enda	doc_609075653182_item	2762155	et	4	main
lõppetada	doc_609075653180_item	2761821	et	4	main
kolmata	doc_609075653180_item	2761823	et	4	main
ka	doc_609075653180_item	2761824	et	3	main
peamine	doc_609075653180_item	2761827	et	3	main
jaoks	doc_609075653180_item	2761835	et	4	main
on	doc_609075653180_item	2761836	et	4	main
et	doc_609075653180_item	2761839	et	3	main
sest	doc_609075653180_item	2761847	et	4	main
neid	doc_609075653180_item	2761852	et	4	main
omadusi	doc_609075653180_item	2761853	et	4	main
nad	doc_609075653180_item	2761854	et	3	main
ei	doc_609075653180_item	2761855	et	4	main
saavad	doc_609075653180_item	2761856	et	4	main
normaalne	doc_609075653180_item	2761858	et	3	main
on	doc_609075653180_item	2761860	et	4	main
õppimises	doc_609075653180_item	2761874	et	4	main
sest	doc_609075653180_item	2761875	et	4	main
töö	doc_609075653180_item	2761881	et	4	main
missugused	doc_609075653180_item	2761882	et	3	main
mis	doc_609075653180_item	2761905	et	4	main
mõjutab	doc_609075653180_item	2761906	et	3	main
sinu	doc_609075653180_item	2761907	et	3	main
ja	doc_609075653180_item	2761916	et	3	main
sest	doc_609075653180_item	2761918	et	4	main
mille	doc_609075653180_item	2761921	et	3	main
on	doc_609075653180_item	2761923	et	4	main
me	doc_609075653180_item	2761925	et	4	main
arutleme	doc_609075653180_item	2761926	et	3	main
tuju	doc_609075653180_item	2761934	et	4	main
õpinguid	doc_609075653180_item	2761939	et	3	main
ma	doc_609075653180_item	2761941	et	3	main
näen	doc_609075653180_item	2761942	et	3	main
tulevikus	doc_609075653180_item	2761945	et	4	main
et	doc_609075653180_item	2761946	et	3	main
ma	doc_609075653180_item	2761947	et	3	main
hästi	doc_609075653180_item	2761948	et	3	main
hea	doc_609075653180_item	2761953	et	4	main
ma	doc_609075653181_item	2761964	et	3	main
tahan	doc_609075653181_item	2761965	et	3	main
õppida	doc_609075653181_item	2761966	et	3	main
sest	doc_609075653181_item	2761967	et	4	main
hea	doc_609075653181_item	2761970	et	4	main
olid	doc_609075653181_item	2761993	et	4	main
paremini	doc_609075653181_item	2762005	et	4	main
kui	doc_609075653181_item	2762006	et	3	main
gümnaasiumis	doc_609075653181_item	2762007	et	3	main
4	doc_609075653181_item	2762008	et	2	main
tahtmine	doc_609075653181_item	2762020	et	4	main
tähelepanu	doc_609075653181_item	2762028	et	4	main
õppe-eesmärgid	doc_609075653181_item	2762034	et	3	main
õppe-eesmärgid	doc_609075653181_item	2762037	et	3	main
enda	doc_609075653181_item	2762055	et	4	main
jaoks	doc_609075653181_item	2762061	et	4	main
ülesanded	doc_609075653181_item	2762063	et	3	main
ette	doc_609075653181_item	2762065	et	4	main
7	doc_609075653181_item	2762072	et	2	main
mõjub	doc_609075653181_item	2762079	et	3	main
ja	doc_609075653180_item	2761896	et	3	main
õppetööd	doc_609075653180_item	2761908	et	4	main
minu	doc_609075653180_item	2761909	et	3	main
õppetööd	doc_609075653180_item	2761910	et	4	main
soovivad	doc_609075653180_item	2761920	et	4	main
perem	doc_609075653180_item	2761924	et	4	main
sa	doc_609075653180_item	2761936	et	3	main
palju	doc_609075653181_item	2761973	et	4	main
2	doc_609075653181_item	2761975	et	2	main
praegu	doc_609075653181_item	2761980	et	3	main
õpin	doc_609075653181_item	2761982	et	3	main
kui	doc_609075653181_item	2761984	et	3	main
minu	doc_609075653181_item	2761988	et	3	main
tulemused	doc_609075653181_item	2761989	et	3	main
peamine	doc_609075653181_item	2762011	et	3	main
jaoks	doc_609075653181_item	2762013	et	4	main
minu	doc_609075653181_item	2762015	et	3	main
tema	doc_609075653181_item	2762023	et	4	main
missugused	doc_609075653181_item	2762030	et	3	main
peamised	doc_609075653181_item	2762033	et	3	main
minu	doc_609075653181_item	2762035	et	3	main
teadmised	doc_609075653181_item	2762050	et	4	main
6	doc_609075653181_item	2762051	et	2	main
missugused	doc_609075653181_item	2762052	et	3	main
ülesanded	doc_609075653181_item	2762053	et	3	main
sa	doc_609075653181_item	2762054	et	3	main
näiteks	doc_609075653181_item	2762064	et	4	main
valmistada	doc_609075653181_item	2762066	et	3	main
minu	doc_609075653181_item	2762077	et	3	main
tükke	doc_609075653181_item	2762081	et	3	main
suhtlemine	doc_609075653181_item	2762083	et	4	main
sa	doc_609075653181_item	2762089	et	3	main
näed	doc_609075653181_item	2762090	et	3	main
oma	doc_609075653181_item	2762091	et	4	main
paremini	doc_609075653182_item	2762121	et	4	main
ma	doc_609075653182_item	2762128	et	3	main
varem	doc_609075653182_item	2762132	et	4	main
õppisid	doc_609075653182_item	2762144	et	4	main
jaoks	doc_609075653182_item	2762150	et	4	main
õpin	doc_609075653182_item	2762154	et	3	main
ja	doc_609075653182_item	2762156	et	3	main
erinevad	doc_609075653182_item	2762181	et	4	main
probleemid	doc_609075653182_item	2762182	et	3	main
seejäärel	doc_609075653182_item	2762183	et	3	main
peab	doc_609075653182_item	2762184	et	4	main
kuidas	doc_609075653182_item	2762189	et	3	main
midagi	doc_609075653182_item	2762200	et	4	main
peamiset	doc_609075653182_item	2762220	et	4	main
praegu	doc_609075653182_item	2762222	et	3	main
mis	doc_609075653180_item	2761922	et	4	main
õppetööd	doc_609075653180_item	2761932	et	4	main
minu	doc_609075653180_item	2761933	et	3	main
lõppetan	doc_609075653180_item	2761949	et	4	main
ülikooli	doc_609075653180_item	2761950	et	4	main
tööd	doc_609075653180_item	2761954	et	4	main
mis	doc_609075653180_item	2761955	et	4	main
on	doc_609075653180_item	2761956	et	4	main
sidunud	doc_609075653180_item	2761957	et	4	main
inglise	doc_609075653180_item	2761958	et	4	main
füloloogia	doc_609075653180_item	2761959	et	4	main
vastus	doc_609075653181_item	2761960	et	3	main
küsimusele	doc_609075653181_item	2761961	et	4	main
1	doc_609075653181_item	2761962	et	2	main
miks	doc_609075653181_item	2761963	et	4	main
ma	doc_609075653181_item	2761968	et	3	main
ja	doc_609075653181_item	2761972	et	3	main
kuidas	doc_609075653181_item	2761976	et	3	main
paremini	doc_609075653181_item	2761983	et	4	main
varem	doc_609075653181_item	2762000	et	4	main
sinu	doc_609075653181_item	2762012	et	3	main
ja	doc_609075653181_item	2762022	et	3	main
kannatus	doc_609075653181_item	2762026	et	4	main
peamised	doc_609075653181_item	2762036	et	3	main
materjali	doc_609075653181_item	2762039	et	4	main
aru	doc_609075653181_item	2762040	et	4	main
saamine	doc_609075653181_item	2762041	et	4	main
koos	doc_609075653181_item	2762044	et	4	main
ja	doc_609075653181_item	2762046	et	3	main
klassikaaslastega	doc_609075653181_item	2762047	et	4	main
ja	doc_609075653181_item	2762048	et	3	main
tähtsad	doc_609075653181_item	2762049	et	3	main
enda	doc_609075653181_item	2762060	et	4	main
mis	doc_609075653181_item	2762073	et	4	main
palju	doc_609075653181_item	2762080	et	4	main
õpenguid	doc_609075653181_item	2762092	et	4	main
ma	doc_609075653181_item	2762094	et	3	main
näen	doc_609075653181_item	2762095	et	3	main
oma	doc_609075653181_item	2762096	et	4	main
õpenguid	doc_609075653181_item	2762097	et	4	main
tulevikus	doc_609075653181_item	2762098	et	4	main
ülekoolis	doc_609075653181_item	2762099	et	4	main
vastus	doc_609075653182_item	2762100	et	3	main
küsimusele	doc_609075653182_item	2762101	et	4	main
1	doc_609075653182_item	2762102	et	2	main
miks	doc_609075653182_item	2762103	et	4	main
ma	doc_609075653182_item	2762104	et	3	main
tahan	doc_609075653182_item	2762105	et	3	main
õppida	doc_609075653182_item	2762106	et	3	main
ma	doc_609075653182_item	2762107	et	3	main
tahan	doc_609075653182_item	2762108	et	3	main
õpida	doc_609075653182_item	2762109	et	4	main
sest	doc_609075653182_item	2762110	et	4	main
kui	doc_609075653182_item	2762111	et	3	main
inimene	doc_609075653182_item	2762112	et	3	main
on	doc_609075653182_item	2762113	et	4	main
haritud	doc_609075653182_item	2762114	et	4	main
siis	doc_609075653182_item	2762115	et	3	main
tal	doc_609075653182_item	2762116	et	3	main
on	doc_609075653182_item	2762117	et	4	main
palju	doc_609075653182_item	2762118	et	4	main
võimalusi	doc_609075653182_item	2762119	et	3	main
elada	doc_609075653182_item	2762120	et	3	main
sa	doc_609075653182_item	2762124	et	3	main
praegu	doc_609075653182_item	2762126	et	3	main
juba	doc_609075653182_item	2762136	et	3	main
oma	doc_609075653182_item	2762138	et	4	main
3	doc_609075653182_item	2762140	et	2	main
kuidas	doc_609075653182_item	2762141	et	3	main
sa	doc_609075653182_item	2762142	et	3	main
varem	doc_609075653182_item	2762143	et	4	main
sest	doc_609075653182_item	2762188	et	4	main
on	doc_609075653182_item	2762191	et	4	main
väike	doc_609075653182_item	2762192	et	4	main
siis	doc_609075653182_item	2762193	et	3	main
ma	doc_609075653182_item	2762194	et	3	main
peab	doc_609075653182_item	2762204	et	4	main
õpida	doc_609075653182_item	2762234	et	4	main
kuidas	doc_609075653182_item	2762123	et	3	main
paremini	doc_609075653182_item	2762130	et	4	main
mõtlen	doc_609075653182_item	2762137	et	3	main
tulevikust	doc_609075653182_item	2762139	et	4	main
vanemate	doc_609075653182_item	2762149	et	4	main
aga	doc_609075653182_item	2762151	et	3	main
4	doc_609075653182_item	2762159	et	2	main
mis	doc_609075653182_item	2762160	et	4	main
on	doc_609075653182_item	2762161	et	4	main
peamine	doc_609075653182_item	2762162	et	3	main
sinu	doc_609075653182_item	2762163	et	3	main
jaoks	doc_609075653182_item	2762164	et	4	main
õppetöös	doc_609075653182_item	2762165	et	3	main
kõigepealt	doc_609075653182_item	2762166	et	3	main
peab	doc_609075653182_item	2762167	et	4	main
olema	doc_609075653182_item	2762168	et	4	main
head	doc_609075653182_item	2762169	et	4	main
suhted	doc_609075653182_item	2762170	et	3	main
minu	doc_609075653182_item	2762171	et	3	main
ja	doc_609075653182_item	2762172	et	3	main
kuna	doc_609075653182_item	2762175	et	3	main
kui	doc_609075653182_item	2762176	et	3	main
halvad	doc_609075653182_item	2762177	et	4	main
suhted	doc_609075653182_item	2762178	et	3	main
siis	doc_609075653182_item	2762179	et	3	main
tekkivad	doc_609075653182_item	2762180	et	4	main
kormus	doc_609075653182_item	2762187	et	4	main
kormus	doc_609075653182_item	2762190	et	4	main
pärast	doc_609075653182_item	2762201	et	4	main
seda	doc_609075653182_item	2762202	et	3	main
mul	doc_609075653182_item	2762203	et	3	main
näiteks	doc_609075653182_item	2762210	et	4	main
mugav	doc_609075653182_item	2762211	et	3	main
töökoht	doc_609075653182_item	2762212	et	3	main
ja	doc_609075653182_item	2762213	et	3	main
soobiv	doc_609075653182_item	2762214	et	4	main
atmosfäär	doc_609075653182_item	2762215	et	3	main
5	doc_609075653182_item	2762216	et	2	main
missugused	doc_609075653182_item	2762217	et	3	main
on	doc_609075653182_item	2762218	et	4	main
sinu	doc_609075653182_item	2762219	et	3	main
tahan	doc_609075653182_item	2762224	et	3	main
püstitasid	doc_609075653182_item	2762242	et	4	main
ma	doc_609075653182_item	2762243	et	3	main
tahan	doc_609075653182_item	2762244	et	3	main
sooritada	doc_609075653182_item	2762245	et	3	main
eksamit	doc_609075653182_item	2762246	et	3	main
ja	doc_609075653182_item	2762247	et	3	main
saada	doc_609075653182_item	2762248	et	4	main
kõrgharidust	doc_609075653182_item	2762249	et	4	main
7	doc_609075653182_item	2762250	et	2	main
mis	doc_609075653182_item	2762251	et	4	main
mõjutab	doc_609075653182_item	2762252	et	3	main
sinu	doc_609075653182_item	2762253	et	3	main
kuidas	doc_609075653182_item	2762264	et	3	main
on	doc_609075653182_item	2762267	et	4	main
ta	doc_609075653182_item	2762271	et	4	main
saab	doc_609075653182_item	2762277	et	3	main
rääkida	doc_609075653182_item	2762278	et	3	main
8	doc_609075653182_item	2762280	et	2	main
kuidas	doc_609075653182_item	2762281	et	3	main
sa	doc_609075653182_item	2762282	et	3	main
näed	doc_609075653182_item	2762283	et	3	main
oma	doc_609075653182_item	2762284	et	4	main
õpinguid	doc_609075653182_item	2762285	et	3	main
tulevikus	doc_609075653182_item	2762286	et	4	main
olema	doc_609075653182_item	2762185	et	4	main
piisav	doc_609075653182_item	2762186	et	4	main
taha	doc_609075653182_item	2762196	et	4	main
teha	doc_609075653182_item	2762197	et	3	main
üldse	doc_609075653182_item	2762198	et	3	main
mitte	doc_609075653182_item	2762199	et	3	main
õppimise	doc_609075653182_item	2762208	et	4	main
jaoks	doc_609075653182_item	2762209	et	4	main
õppe-eesmärgid	doc_609075653182_item	2762221	et	3	main
kooli	doc_609075653182_item	2762226	et	4	main
saab	doc_609075653182_item	2762239	et	3	main
enda	doc_609075653182_item	2762240	et	4	main
õppetööd	doc_609075653182_item	2762262	et	4	main
enda	doc_609075653182_item	2762273	et	4	main
ja	doc_609075653182_item	2762276	et	3	main
vabalt	doc_609075653182_item	2762279	et	4	main
tallinna	doc_609075653182_item	2762291	et	4	main
ülikoolis	doc_609075653182_item	2762292	et	4	main
ei	doc_609075653182_item	2762195	et	4	main
olema	doc_609075653182_item	2762205	et	4	main
toredad	doc_609075653182_item	2762206	et	3	main
tingimused	doc_609075653182_item	2762207	et	3	main
ma	doc_609075653182_item	2762223	et	3	main
lõpetada	doc_609075653182_item	2762225	et	3	main
ja	doc_609075653182_item	2762229	et	3	main
ülesanned	doc_609075653182_item	2762238	et	4	main
inimese	doc_609075653182_item	2762265	et	4	main
õppida	doc_609075653184_item	2762453	et	3	main
et	doc_609075653184_item	2762455	et	3	main
jaoks	doc_609075653184_item	2762479	et	4	main
2	doc_609075653184_item	2762480	et	2	main
kuidas	doc_609075653184_item	2762481	et	3	main
sa	doc_609075653184_item	2762482	et	3	main
õpetajatega	doc_609075653184_item	2762500	et	4	main
3	doc_609075653184_item	2762501	et	2	main
kuidas	doc_609075653184_item	2762502	et	3	main
sa	doc_609075653184_item	2762503	et	3	main
hästi	doc_609075653184_item	2762509	et	3	main
mul	doc_609075653184_item	2762512	et	3	main
on	doc_609075653184_item	2762521	et	4	main
eesmärk	doc_609075653184_item	2762527	et	3	main
soovitus	doc_609075653184_item	2762529	et	4	main
ja	doc_609075653184_item	2762530	et	3	main
positiivsed	doc_609075653184_item	2762531	et	3	main
emotsioonid	doc_609075653184_item	2762532	et	3	main
5	doc_609075653184_item	2762533	et	2	main
missugused	doc_609075653184_item	2762534	et	3	main
on	doc_609075653184_item	2762535	et	4	main
head	doc_609075653184_item	2762539	et	4	main
klassikaslaste	doc_609075653184_item	2762548	et	4	main
õppimises	doc_609075653184_item	2762559	et	4	main
ja	doc_609075653184_item	2762560	et	3	main
ülikooli	doc_609075653184_item	2762567	et	4	main
7	doc_609075653184_item	2762568	et	2	main
õppetööd	doc_609075653184_item	2762572	et	4	main
tallinna	doc_609075653184_item	2762611	et	4	main
ja	doc_609075653184_item	2762615	et	3	main
otsustada	doc_609075653184_item	2762623	et	3	main
saada	doc_609075653184_item	2762627	et	4	main
missugune	doc_609075653184_item	2762629	et	3	main
minu	doc_609075653184_item	2762637	et	3	main
heate	doc_609075653182_item	2762227	et	4	main
tulemustega	doc_609075653182_item	2762228	et	3	main
sõita	doc_609075653182_item	2762230	et	3	main
tallinna	doc_609075653182_item	2762231	et	4	main
ja	doc_609075653182_item	2762232	et	3	main
seal	doc_609075653182_item	2762233	et	4	main
jaoks	doc_609075653182_item	2762241	et	4	main
õppetööd	doc_609075653182_item	2762254	et	4	main
ma	doc_609075653182_item	2762255	et	3	main
arvan	doc_609075653182_item	2762256	et	3	main
et	doc_609075653182_item	2762257	et	3	main
sõbralik	doc_609075653182_item	2762258	et	3	main
atmosfäär	doc_609075653182_item	2762259	et	3	main
mõjutab	doc_609075653182_item	2762260	et	3	main
minu	doc_609075653182_item	2762261	et	3	main
ülikoolis	doc_609075653182_item	2762235	et	4	main
6	doc_609075653182_item	2762236	et	2	main
missugused	doc_609075653182_item	2762237	et	3	main
kuna	doc_609075653182_item	2762263	et	3	main
ümbruses	doc_609075653182_item	2762266	et	3	main
ainult	doc_609075653182_item	2762268	et	4	main
sõbrad	doc_609075653182_item	2762269	et	3	main
siis	doc_609075653182_item	2762270	et	3	main
hästi	doc_609075653182_item	2762274	et	3	main
mugavalt	doc_609075653182_item	2762275	et	4	main
tahan	doc_609075653184_item	2762452	et	3	main
õppimine	doc_609075653184_item	2762470	et	4	main
läheb	doc_609075653184_item	2762475	et	3	main
ülikooli	doc_609075653184_item	2762477	et	4	main
õppimise	doc_609075653184_item	2762478	et	4	main
hästi	doc_609075653184_item	2762491	et	3	main
varem	doc_609075653184_item	2762504	et	4	main
ka	doc_609075653184_item	2762510	et	3	main
eesmärk	doc_609075653184_item	2762514	et	3	main
edukalt	doc_609075653184_item	2762516	et	4	main
peamine	doc_609075653184_item	2762522	et	3	main
sinu	doc_609075653184_item	2762536	et	3	main
6	doc_609075653184_item	2762551	et	2	main
sa	doc_609075653184_item	2762554	et	3	main
jaoks	doc_609075653184_item	2762556	et	4	main
edu	doc_609075653184_item	2762558	et	4	main
sisse	doc_609075653184_item	2762566	et	4	main
sinu	doc_609075653184_item	2762571	et	3	main
tuju	doc_609075653184_item	2762573	et	4	main
ma	doc_609075653184_item	2762625	et	3	main
tahan	doc_609075653184_item	2762626	et	3	main
elu	doc_609075653184_item	2762630	et	4	main
on	doc_609075653184_item	2762631	et	4	main
edasi	doc_609075653184_item	2762632	et	3	main
see	doc_609075653184_item	2762633	et	3	main
on	doc_609075653184_item	2762634	et	4	main
mul	doc_609075653184_item	2762642	et	3	main
kindel	doc_609075653184_item	2762644	et	3	main
tuneb	doc_609075653182_item	2762272	et	4	main
tulevikus	doc_609075653182_item	2762287	et	4	main
ma	doc_609075653182_item	2762288	et	3	main
planeerin	doc_609075653182_item	2762289	et	3	main
õpida	doc_609075653182_item	2762290	et	4	main
vastus	doc_609075653184_item	2762444	et	3	main
küsimusele	doc_609075653184_item	2762445	et	4	main
sellepärast	doc_609075653184_item	2762454	et	3	main
lahendab	doc_609075653184_item	2762471	et	3	main
vaja	doc_609075653184_item	2762476	et	4	main
praegu	doc_609075653184_item	2762484	et	3	main
et	doc_609075653184_item	2762487	et	3	main
praegu	doc_609075653184_item	2762490	et	3	main
mul	doc_609075653184_item	2762493	et	3	main
head	doc_609075653184_item	2762495	et	4	main
hinded	doc_609075653184_item	2762496	et	3	main
ja	doc_609075653184_item	2762497	et	3	main
head	doc_609075653184_item	2762498	et	4	main
suhted	doc_609075653184_item	2762499	et	3	main
varem	doc_609075653184_item	2762508	et	4	main
oli	doc_609075653184_item	2762513	et	3	main
õppida	doc_609075653184_item	2762515	et	3	main
kooliaasta	doc_609075653184_item	2762517	et	4	main
jooksul	doc_609075653184_item	2762518	et	4	main
4	doc_609075653184_item	2762519	et	2	main
sinu	doc_609075653184_item	2762523	et	3	main
õppetöös	doc_609075653184_item	2762525	et	3	main
koolimaterjali	doc_609075653184_item	2762541	et	4	main
saamine	doc_609075653184_item	2762543	et	4	main
edu	doc_609075653184_item	2762544	et	4	main
õppetöös	doc_609075653184_item	2762545	et	3	main
lahked	doc_609075653184_item	2762546	et	3	main
suhted	doc_609075653184_item	2762547	et	3	main
isikud	doc_609075653184_item	2762575	et	3	main
nii	doc_609075653184_item	2762616	et	3	main
minu	doc_609075653184_item	2762618	et	3	main
püstitab	doc_609075653184_item	2762620	et	3	main
ülesande	doc_609075653184_item	2762622	et	4	main
olla	doc_609075653184_item	2762643	et	3	main
järgmises	doc_609075653184_item	2762645	et	3	main
miks	doc_609075653184_item	2762447	et	4	main
ma	doc_609075653184_item	2762448	et	3	main
tahan	doc_609075653184_item	2762449	et	3	main
õppida	doc_609075653184_item	2762450	et	3	main
minu	doc_609075653184_item	2762472	et	3	main
ja	doc_609075653184_item	2762474	et	3	main
õpid	doc_609075653184_item	2762483	et	4	main
arvan	doc_609075653184_item	2762486	et	3	main
ma	doc_609075653184_item	2762488	et	3	main
sest	doc_609075653184_item	2762492	et	4	main
on	doc_609075653184_item	2762494	et	4	main
mis	doc_609075653184_item	2762520	et	4	main
1	doc_609075653184_item	2762446	et	2	main
ma	doc_609075653184_item	2762451	et	3	main
ma	doc_609075653184_item	2762456	et	3	main
tahan	doc_609075653184_item	2762457	et	3	main
olla	doc_609075653184_item	2762458	et	3	main
haritud	doc_609075653184_item	2762459	et	4	main
et	doc_609075653184_item	2762460	et	3	main
minu	doc_609075653184_item	2762461	et	3	main
sõprad	doc_609075653184_item	2762462	et	4	main
ja	doc_609075653184_item	2762463	et	3	main
tuttavad	doc_609075653184_item	2762464	et	4	main
näevad	doc_609075653184_item	2762465	et	3	main
minus	doc_609075653184_item	2762466	et	3	main
kultuurset	doc_609075653184_item	2762467	et	3	main
inimest	doc_609075653184_item	2762468	et	3	main
ning	doc_609075653184_item	2762469	et	3	main
silmaringi	doc_609075653184_item	2762473	et	4	main
ma	doc_609075653184_item	2762485	et	3	main
õpin	doc_609075653184_item	2762489	et	3	main
õppisid	doc_609075653184_item	2762505	et	4	main
ma	doc_609075653184_item	2762506	et	3	main
õppisin	doc_609075653184_item	2762507	et	3	main
sest	doc_609075653184_item	2762511	et	4	main
õppe-eesmärgid	doc_609075653184_item	2762538	et	3	main
hinded	doc_609075653184_item	2762540	et	3	main
aru	doc_609075653184_item	2762542	et	4	main
ja	doc_609075653184_item	2762549	et	3	main
õpetajatega	doc_609075653184_item	2762550	et	4	main
missugused	doc_609075653184_item	2762552	et	3	main
enda	doc_609075653184_item	2762555	et	4	main
püstitasid	doc_609075653184_item	2762557	et	4	main
riigieksamide	doc_609075653184_item	2762561	et	4	main
mis	doc_609075653184_item	2762569	et	4	main
asjud	doc_609075653184_item	2762576	et	4	main
ja	doc_609075653184_item	2762578	et	3	main
mõjutab	doc_609075653184_item	2762580	et	3	main
kool	doc_609075653184_item	2762614	et	4	main
ees	doc_609075653184_item	2762619	et	4	main
jaoks	doc_609075653184_item	2762524	et	4	main
täpne	doc_609075653184_item	2762526	et	3	main
kanatlikus	doc_609075653184_item	2762528	et	4	main
peamised	doc_609075653184_item	2762537	et	3	main
ülesanded	doc_609075653184_item	2762553	et	3	main
sooritamine	doc_609075653184_item	2762562	et	4	main
et	doc_609075653184_item	2762563	et	3	main
edukalt	doc_609075653184_item	2762564	et	4	main
astuda	doc_609075653184_item	2762565	et	3	main
mõjutab	doc_609075653184_item	2762570	et	3	main
minu	doc_609075653184_item	2762574	et	3	main
tervis	doc_609075653184_item	2762577	et	3	main
keskkond	doc_609075653184_item	2762579	et	3	main
minu	doc_609075653184_item	2762581	et	3	main
õppetööd	doc_609075653184_item	2762582	et	4	main
kuidas	doc_609075653184_item	2762584	et	3	main
sa	doc_609075653184_item	2762585	et	3	main
näed	doc_609075653184_item	2762586	et	3	main
oma	doc_609075653184_item	2762587	et	4	main
8	doc_609075653184_item	2762583	et	2	main
õpinguid	doc_609075653184_item	2762588	et	3	main
tulevikus	doc_609075653184_item	2762589	et	4	main
ma	doc_609075653184_item	2762590	et	3	main
tahaksin	doc_609075653184_item	2762591	et	3	main
astuda	doc_609075653184_item	2762592	et	3	main
sisse	doc_609075653184_item	2762593	et	4	main
järgmisel	doc_609075653184_item	2762595	et	3	main
aastal	doc_609075653184_item	2762596	et	3	main
aga	doc_609075653184_item	2762597	et	3	main
praegu	doc_609075653184_item	2762598	et	3	main
ma	doc_609075653184_item	2762599	et	3	main
ülikooli	doc_609075653184_item	2762594	et	4	main
täpselt	doc_609075653184_item	2762600	et	4	main
ei	doc_609075653184_item	2762601	et	4	main
otsusta	doc_609075653184_item	2762602	et	4	main
kuhu	doc_609075653184_item	2762603	et	3	main
ma	doc_609075653184_item	2762604	et	3	main
tahan	doc_609075653184_item	2762605	et	3	main
minna	doc_609075653184_item	2762606	et	3	main
mul	doc_609075653184_item	2762607	et	3	main
on	doc_609075653184_item	2762608	et	4	main
erinevad	doc_609075653184_item	2762609	et	4	main
variaantid	doc_609075653184_item	2762610	et	4	main
ülikool	doc_609075653184_item	2762612	et	4	main
mainori	doc_609075653184_item	2762613	et	4	main
edasi	doc_609075653184_item	2762617	et	3	main
rasket	doc_609075653184_item	2762621	et	3	main
ja	doc_609075653184_item	2762628	et	3	main
aitab	doc_609075653184_item	2762641	et	3	main
päevas	doc_609075653184_item	2762646	et	3	main
kelleks	doc_609075653184_item	2762624	et	4	main
raske	doc_609075653184_item	2762635	et	4	main
valik	doc_609075653184_item	2762636	et	3	main
arvates	doc_609075653184_item	2762638	et	4	main
minu	doc_609075653184_item	2762639	et	3	main
õping	doc_609075653184_item	2762640	et	3	main
vastus	doc_609075653187_item	2762991	et	3	main
küsimusele	doc_609075653187_item	2762992	et	4	main
inimesed	doc_609075653187_item	2763005	et	3	main
raha	doc_609075653187_item	2763011	et	4	main
kuidas	doc_609075653187_item	2763013	et	3	main
ma	doc_609075653187_item	2763018	et	3	main
hästi	doc_609075653187_item	2763020	et	3	main
õppisin	doc_609075653187_item	2763023	et	3	main
kuidas	doc_609075653187_item	2763026	et	3	main
õppisid	doc_609075653187_item	2763029	et	4	main
õppisin	doc_609075653187_item	2763031	et	3	main
väga	doc_609075653187_item	2763032	et	3	main
olin	doc_609075653187_item	2763034	et	3	main
mis	doc_609075653187_item	2763039	et	4	main
jaoks	doc_609075653187_item	2763043	et	4	main
arvan	doc_609075653187_item	2763050	et	3	main
vaja	doc_609075653187_item	2763053	et	4	main
oleme	doc_609075653187_item	2763069	et	3	main
5	doc_609075653187_item	2763071	et	2	main
muidugi	doc_609075653187_item	2763077	et	4	main
ma	doc_609075653187_item	2763078	et	3	main
oleksid	doc_609075653187_item	2763082	et	4	main
head	doc_609075653187_item	2763083	et	4	main
laendada	doc_609075653187_item	2763086	et	4	main
suhted	doc_609075653187_item	2763121	et	3	main
õppetöödkui	doc_609075653187_item	2763125	et	4	main
edukas	doc_609075653187_item	2763133	et	4	main
8	doc_609075653187_item	2763134	et	2	main
kuidas	doc_609075653187_item	2763135	et	3	main
näed	doc_609075653187_item	2763137	et	3	main
arvan	doc_609075653187_item	2763146	et	3	main
õppida	doc_609075653187_item	2763156	et	3	main
ma	doc_609075653187_item	2763158	et	3	main
et	doc_609075653187_item	2763160	et	3	main
minu	doc_609075653187_item	2763174	et	3	main
tulevikus	doc_609075653187_item	2763176	et	4	main
mitte	doc_609075653187_item	2763178	et	3	main
1	doc_609075653187_item	2762993	et	2	main
miks	doc_609075653187_item	2762994	et	4	main
ma	doc_609075653187_item	2762995	et	3	main
tahan	doc_609075653187_item	2762996	et	3	main
õppida	doc_609075653187_item	2762997	et	3	main
ma	doc_609075653187_item	2762998	et	3	main
tahan	doc_609075653187_item	2762999	et	3	main
õppida	doc_609075653187_item	2763000	et	3	main
palju	doc_609075653187_item	2763010	et	4	main
sa	doc_609075653187_item	2763014	et	3	main
praegu	doc_609075653187_item	2763016	et	3	main
aga	doc_609075653187_item	2763021	et	3	main
varem	doc_609075653187_item	2763028	et	4	main
hästialgklassides	doc_609075653187_item	2763033	et	3	main
sinu	doc_609075653187_item	2763042	et	3	main
õppetöös	doc_609075653187_item	2763044	et	3	main
jaoks	doc_609075653187_item	2763046	et	4	main
püüdlikus	doc_609075653187_item	2763047	et	4	main
kui	doc_609075653187_item	2763057	et	3	main
see	doc_609075653187_item	2763061	et	3	main
et	doc_609075653187_item	2763080	et	3	main
tahan	doc_609075653187_item	2763085	et	3	main
mõjuvad	doc_609075653187_item	2763123	et	4	main
korras	doc_609075653187_item	2763128	et	4	main
siis	doc_609075653187_item	2763129	et	3	main
minu	doc_609075653187_item	2763130	et	3	main
õppetöö	doc_609075653187_item	2763131	et	4	main
oma	doc_609075653187_item	2763138	et	4	main
et	doc_609075653187_item	2763147	et	3	main
õdukalt	doc_609075653187_item	2763157	et	4	main
meeldib	doc_609075653187_item	2763173	et	3	main
töö	doc_609075653187_item	2763175	et	4	main
uut	doc_609075653188_item	2763200	et	3	main
2missugused	doc_609075653188_item	2763202	et	3	main
on	doc_609075653188_item	2763204	et	4	main
õppetöös	doc_609075653188_item	2763205	et	3	main
sest	doc_609075653187_item	2763001	et	4	main
tahan	doc_609075653187_item	2763002	et	3	main
töötavad	doc_609075653187_item	2763006	et	4	main
heas	doc_609075653187_item	2763007	et	3	main
kohas	doc_609075653187_item	2763008	et	4	main
2	doc_609075653187_item	2763012	et	2	main
õppid	doc_609075653187_item	2763015	et	4	main
praegu	doc_609075653187_item	2763017	et	3	main
õppin	doc_609075653187_item	2763019	et	4	main
sa	doc_609075653187_item	2763027	et	3	main
ma	doc_609075653187_item	2763030	et	3	main
on	doc_609075653187_item	2763040	et	4	main
minu	doc_609075653187_item	2763045	et	3	main
et	doc_609075653187_item	2763051	et	3	main
palju	doc_609075653187_item	2763055	et	4	main
töötada	doc_609075653187_item	2763056	et	3	main
õppida	doc_609075653187_item	2763059	et	3	main
on	doc_609075653187_item	2763062	et	4	main
väga	doc_609075653187_item	2763063	et	3	main
raske	doc_609075653187_item	2763064	et	4	main
me	doc_609075653187_item	2763068	et	4	main
mul	doc_609075653187_item	2763126	et	3	main
sa	doc_609075653187_item	2763136	et	3	main
ülikoolis	doc_609075653187_item	2763144	et	4	main
on	doc_609075653187_item	2763149	et	4	main
rohkem	doc_609075653187_item	2763150	et	4	main
võimalusi	doc_609075653187_item	2763151	et	3	main
noorte	doc_609075653187_item	2763152	et	3	main
inimeste	doc_609075653187_item	2763153	et	3	main
püüjan	doc_609075653187_item	2763159	et	4	main
minu	doc_609075653187_item	2763161	et	3	main
minu	doc_609075653187_item	2763163	et	3	main
sest	doc_609075653187_item	2763165	et	4	main
see	doc_609075653187_item	2763166	et	3	main
on	doc_609075653187_item	2763167	et	4	main
väga	doc_609075653187_item	2763168	et	3	main
sellest	doc_609075653187_item	2763170	et	4	main
kas	doc_609075653187_item	2763172	et	3	main
1	doc_609075653188_item	2763181	et	2	main
ma	doc_609075653188_item	2763183	et	3	main
raskus	doc_609075653188_item	2763208	et	4	main
sellega	doc_609075653188_item	2763209	et	3	main
keele	doc_609075653188_item	2763222	et	4	main
tunnis	doc_609075653188_item	2763223	et	3	main
pärast	doc_609075653188_item	2763257	et	4	main
ja	doc_609075653188_item	2763266	et	3	main
unistus	doc_609075653188_item	2763270	et	4	main
sa	doc_609075653188_item	2763271	et	3	main
õppida	doc_609075653188_item	2763273	et	3	main
miks	doc_609075653188_item	2763283	et	4	main
minu	doc_609075653188_item	2763287	et	3	main
õpetajaks	doc_609075653188_item	2763293	et	4	main
olla	doc_609075653188_item	2763303	et	3	main
on	doc_609075653188_item	2763306	et	4	main
5	doc_609075653188_item	2763308	et	2	main
ei	doc_609075653188_item	2763339	et	4	main
väärtusta	doc_609075653188_item	2763340	et	4	main
haridust	doc_609075653188_item	2763341	et	4	main
tasuta	doc_609075653188_item	2763346	et	4	main
aga	doc_609075653188_item	2763348	et	3	main
haridus	doc_609075653188_item	2763350	et	3	main
ja	doc_609075653188_item	2763353	et	3	main
kultuuriloost	doc_617668397741_item	2763360	et	4	main
hariduselu	doc_617668397741_item	2763363	et	4	main
rahvakoolid	doc_617668397741_item	2763364	et	3	main
asutatud	doc_617668397741_item	2763394	et	4	main
1620	doc_617668397741_item	2763397	et	2	main
veel	doc_617668397741_item	2763406	et	4	main
alates	doc_617668397741_item	2763412	et	3	main
lapsed	doc_617668397741_item	2763415	et	3	main
käima	doc_617668397741_item	2763417	et	4	main
talurahvakooli	doc_617668397741_item	2763421	et	4	main
forselisus	doc_617668397741_item	2763424	et	4	main
palju	doc_617668397741_item	2763428	et	4	main
head	doc_617668397741_item	2763429	et	4	main
hariduselule	doc_617668397741_item	2763430	et	3	main
aabitsad	doc_617668397741_item	2763433	et	3	main
tartu	doc_617668397741_item	2763436	et	4	main
usuteaduskond	doc_617668397741_item	2763441	et	3	main
lätlastele	doc_617668397741_item	2763446	et	3	main
oli	doc_617668397741_item	2763448	et	3	main
tähtis	doc_617668397741_item	2763450	et	4	main
rootsi	doc_617668397741_item	2763451	et	4	main
alistatud	doc_617668397741_item	2763465	et	4	main
usuteaduseprofessorid	doc_617668397741_item	2763467	et	3	main
arendada	doc_617668397741_item	2763478	et	3	main
kui	doc_617668397741_item	2763501	et	3	main
vene	doc_617668397741_item	2763503	et	4	main
tekkisid	doc_617668397741_item	2763506	et	4	main
olla	doc_609075653187_item	2763003	et	3	main
haritudharitud	doc_609075653187_item	2763004	et	4	main
teenivad	doc_609075653187_item	2763009	et	4	main
varem	doc_609075653187_item	2763022	et	4	main
paremini	doc_609075653187_item	2763024	et	4	main
õppilastest	doc_609075653187_item	2763037	et	4	main
peaminema	doc_609075653187_item	2763049	et	4	main
on	doc_609075653187_item	2763052	et	4	main
väga	doc_609075653187_item	2763054	et	3	main
tahad	doc_609075653187_item	2763058	et	3	main
hästi	doc_609075653187_item	2763060	et	3	main
kõik	doc_609075653187_item	2763067	et	4	main
laiskvorstid	doc_609075653187_item	2763070	et	3	main
missugused	doc_609075653187_item	2763072	et	3	main
sinu	doc_609075653187_item	2763074	et	3	main
peamised	doc_609075653187_item	2763075	et	3	main
õppe-eesmärgid	doc_609075653187_item	2763076	et	3	main
tahaksin	doc_609075653187_item	2763079	et	3	main
mul	doc_609075653187_item	2763081	et	3	main
minu	doc_609075653187_item	2763124	et	3	main
kõik	doc_609075653187_item	2763127	et	4	main
on	doc_609075653187_item	2763132	et	4	main
ma	doc_609075653187_item	2763141	et	3	main
tahan	doc_609075653187_item	2763142	et	3	main
tallinasma	doc_609075653187_item	2763145	et	4	main
pealinnas	doc_609075653187_item	2763148	et	4	main
jaoksma	doc_609075653187_item	2763154	et	4	main
tahan	doc_609075653187_item	2763155	et	3	main
tähtis	doc_609075653187_item	2763169	et	4	main
sõltub	doc_609075653187_item	2763171	et	3	main
küsimusele	doc_609075653188_item	2763180	et	4	main
ma	doc_609075653188_item	2763185	et	3	main
õppida	doc_609075653188_item	2763192	et	3	main
saada	doc_609075653188_item	2763199	et	4	main
raskused	doc_609075653188_item	2763203	et	4	main
mul	doc_609075653188_item	2763206	et	3	main
on	doc_609075653188_item	2763207	et	4	main
et	doc_609075653188_item	2763228	et	3	main
ja	doc_609075653188_item	2763233	et	3	main
see	doc_609075653188_item	2763234	et	3	main
on	doc_609075653188_item	2763235	et	4	main
raske	doc_609075653188_item	2763236	et	4	main
ma	doc_609075653188_item	2763247	et	3	main
on	doc_609075653188_item	2763259	et	4	main
missugune	doc_609075653188_item	2763267	et	3	main
sooviksid	doc_609075653188_item	2763280	et	4	main
ma	doc_609075653188_item	2763289	et	3	main
armastan	doc_609075653188_item	2763298	et	3	main
et	doc_609075653188_item	2763302	et	3	main
et	doc_609075653188_item	2763321	et	3	main
tööd	doc_609075653188_item	2763324	et	4	main
haridust	doc_609075653188_item	2763333	et	4	main
ma	doc_609075653188_item	2763334	et	3	main
selle	doc_609075653188_item	2763342	et	4	main
on	doc_609075653188_item	2763351	et	4	main
üliõpilased	doc_609075653188_item	2763354	et	3	main
haridust	doc_609075653188_item	2763356	et	4	main
ülikool	doc_617668397741_item	2763366	et	4	main
gümnaasiumid	doc_617668397741_item	2763395	et	3	main
alates	doc_617668397741_item	2763396	et	3	main
aastast	doc_617668397741_item	2763398	et	4	main
oli	doc_617668397741_item	2763399	et	3	main
ka	doc_617668397741_item	2763400	et	3	main
rootsi	doc_617668397741_item	2763401	et	4	main
ülikoolid	doc_617668397741_item	2763402	et	3	main
upsala	doc_617668397741_item	2763403	et	4	main
turu	doc_617668397741_item	2763404	et	3	main
ja	doc_617668397741_item	2763405	et	3	main
seadus	doc_617668397741_item	2763411	et	4	main
töötas	doc_617668397741_item	2763423	et	3	main
3	doc_609075653187_item	2763025	et	2	main
ühena	doc_609075653187_item	2763035	et	3	main
parematest	doc_609075653187_item	2763036	et	4	main
4	doc_609075653187_item	2763038	et	2	main
peamine	doc_609075653187_item	2763041	et	3	main
on	doc_609075653187_item	2763048	et	4	main
sest	doc_609075653187_item	2763065	et	4	main
tihti	doc_609075653187_item	2763066	et	3	main
on	doc_609075653187_item	2763073	et	4	main
hindedma	doc_609075653187_item	2763084	et	4	main
silmaringi	doc_609075653187_item	2763087	et	4	main
et	doc_609075653187_item	2763088	et	3	main
saaks	doc_609075653187_item	2763089	et	3	main
suhelda	doc_609075653187_item	2763090	et	4	main
huvitavate	doc_609075653187_item	2763091	et	4	main
inimestega	doc_609075653187_item	2763092	et	3	main
6	doc_609075653187_item	2763093	et	2	main
missugused	doc_609075653187_item	2763094	et	3	main
ülesanded	doc_609075653187_item	2763095	et	3	main
sa	doc_609075653187_item	2763096	et	3	main
enda	doc_609075653187_item	2763097	et	4	main
jaoks	doc_609075653187_item	2763098	et	4	main
püstitasid	doc_609075653187_item	2763099	et	4	main
ma	doc_609075653187_item	2763100	et	3	main
tahan	doc_609075653187_item	2763101	et	3	main
asutada	doc_609075653187_item	2763102	et	3	main
sisse	doc_609075653187_item	2763103	et	4	main
ülikooli	doc_609075653187_item	2763104	et	4	main
mudugi	doc_609075653187_item	2763105	et	4	main
ma	doc_609075653187_item	2763106	et	3	main
tahan	doc_609075653187_item	2763107	et	3	main
pärast	doc_609075653187_item	2763108	et	4	main
ülikooli	doc_609075653187_item	2763109	et	4	main
leida	doc_609075653187_item	2763110	et	3	main
huvitavat	doc_609075653187_item	2763111	et	4	main
tööd	doc_609075653187_item	2763112	et	4	main
7	doc_609075653187_item	2763113	et	2	main
mis	doc_609075653187_item	2763114	et	4	main
mõjutab	doc_609075653187_item	2763115	et	3	main
sinu	doc_609075653187_item	2763116	et	3	main
õppetööd	doc_609075653187_item	2763117	et	4	main
minu	doc_609075653187_item	2763118	et	3	main
pere	doc_609075653187_item	2763119	et	4	main
sõbrad	doc_609075653187_item	2763120	et	3	main
inimestega	doc_609075653187_item	2763122	et	3	main
õpenguid	doc_609075653187_item	2763139	et	4	main
tilevikus	doc_609075653187_item	2763140	et	4	main
õppida	doc_609075653187_item	2763143	et	3	main
meeldib	doc_609075653187_item	2763162	et	3	main
õpengud	doc_609075653187_item	2763164	et	4	main
või	doc_609075653187_item	2763177	et	4	main
miks	doc_609075653188_item	2763182	et	4	main
õpin	doc_609075653188_item	2763184	et	3	main
selle	doc_609075653188_item	2763187	et	4	main
et	doc_609075653188_item	2763189	et	3	main
ma	doc_609075653188_item	2763190	et	3	main
ülikoolis	doc_609075653188_item	2763194	et	4	main
infot	doc_609075653188_item	2763201	et	3	main
et	doc_609075653188_item	2763210	et	3	main
ma	doc_609075653188_item	2763211	et	3	main
ei	doc_609075653188_item	2763212	et	4	main
saa	doc_609075653188_item	2763213	et	4	main
aru	doc_609075653188_item	2763214	et	4	main
seda	doc_609075653188_item	2763215	et	3	main
et	doc_609075653188_item	2763216	et	3	main
teised	doc_609075653188_item	2763217	et	4	main
räägivad	doc_609075653188_item	2763218	et	3	main
inglise	doc_609075653188_item	2763219	et	4	main
ja	doc_609075653188_item	2763220	et	3	main
on	doc_609075653188_item	2763230	et	4	main
palju	doc_609075653188_item	2763231	et	4	main
et	doc_609075653188_item	2763249	et	3	main
on	doc_609075653188_item	2763251	et	4	main
parem	doc_609075653188_item	2763252	et	4	main
õppida	doc_609075653188_item	2763253	et	3	main
kui	doc_609075653188_item	2763254	et	3	main
eestis	doc_609075653188_item	2763255	et	3	main
selle	doc_609075653188_item	2763256	et	4	main
võimalusi	doc_609075653188_item	2763261	et	3	main
kus	doc_609075653188_item	2763262	et	3	main
sa	doc_609075653188_item	2763263	et	3	main
tahad	doc_609075653188_item	2763264	et	3	main
on	doc_609075653188_item	2763268	et	4	main
edasi	doc_609075653188_item	2763281	et	3	main
õppida	doc_609075653188_item	2763282	et	3	main
ma	doc_609075653188_item	2763284	et	3	main
selle	doc_609075653188_item	2763294	et	4	main
heat	doc_609075653188_item	2763323	et	4	main
ja	doc_609075653188_item	2763325	et	3	main
meeldiv	doc_609075653188_item	2763326	et	4	main
arvan	doc_609075653188_item	2763335	et	3	main
et	doc_609075653188_item	2763336	et	3	main
tänapäeva	doc_609075653188_item	2763337	et	4	main
noored	doc_609075653188_item	2763338	et	3	main
on	doc_609075653188_item	2763345	et	4	main
kontrolltöö	doc_617668397741_item	2763357	et	4	main
kontrolltöö	doc_617668397741_item	2763358	et	4	main
gümnaasiumid	doc_617668397741_item	2763365	et	3	main
pidid	doc_617668397741_item	2763416	et	4	main
koolis	doc_617668397741_item	2763418	et	4	main
ilmusid	doc_617668397741_item	2763419	et	4	main
tegeles	doc_617668397741_item	2763434	et	3	main
olid	doc_617668397741_item	2763442	et	4	main
eestlastele	doc_617668397741_item	2763444	et	4	main
teadus	doc_617668397741_item	2763447	et	4	main
väga	doc_617668397741_item	2763449	et	3	main
palka	doc_617668397741_item	2763458	et	4	main
oli	doc_617668397741_item	2763464	et	3	main
teisi	doc_617668397741_item	2763469	et	4	main
teaduskondi	doc_617668397741_item	2763470	et	4	main
rootsiaegses	doc_617668397741_item	2763471	et	3	main
mis	doc_617668397741_item	2763476	et	4	main
forseliuse	doc_617668397741_item	2763480	et	4	main
kõrgel	doc_617668397741_item	2763529	et	4	main
tasemel	doc_617668397741_item	2763530	et	3	main
vastus	doc_609075653188_item	2763179	et	3	main
õpin	doc_609075653188_item	2763186	et	3	main
pärast	doc_609075653188_item	2763188	et	4	main
tahan	doc_609075653188_item	2763191	et	3	main
edasi	doc_609075653188_item	2763193	et	3	main
selle	doc_609075653188_item	2763195	et	4	main
pärast	doc_609075653188_item	2763196	et	4	main
et	doc_609075653188_item	2763197	et	3	main
tahan	doc_609075653188_item	2763198	et	3	main
eesti	doc_609075653188_item	2763221	et	4	main
raskus	doc_609075653188_item	2763225	et	4	main
on	doc_609075653188_item	2763226	et	4	main
see	doc_609075653188_item	2763227	et	3	main
parem	doc_609075653188_item	2763242	et	4	main
õppida	doc_609075653188_item	2763243	et	3	main
eestis	doc_609075653188_item	2763244	et	3	main
või	doc_609075653188_item	2763245	et	4	main
välismaal	doc_609075653188_item	2763246	et	4	main
välismaal	doc_609075653188_item	2763250	et	4	main
palju	doc_609075653188_item	2763260	et	4	main
õppida	doc_609075653188_item	2763265	et	3	main
sinu	doc_609075653188_item	2763269	et	3	main
võid	doc_609075653188_item	2763272	et	4	main
soovid	doc_609075653188_item	2763277	et	4	main
4	doc_609075653188_item	2763278	et	2	main
kus	doc_609075653188_item	2763279	et	3	main
õppida	doc_609075653188_item	2763286	et	3	main
õppiksin	doc_609075653188_item	2763290	et	4	main
edasi	doc_609075653188_item	2763291	et	3	main
lasteaia	doc_609075653188_item	2763292	et	4	main
õpetajana	doc_609075653188_item	2763304	et	4	main
see	doc_609075653188_item	2763305	et	3	main
minu	doc_609075653188_item	2763307	et	3	main
miks	doc_609075653188_item	2763309	et	4	main
ja	doc_609075653188_item	2763224	et	3	main
koolis	doc_609075653188_item	2763229	et	4	main
infot	doc_609075653188_item	2763232	et	3	main
jätta	doc_609075653188_item	2763237	et	3	main
meelde	doc_609075653188_item	2763238	et	3	main
3	doc_609075653188_item	2763239	et	2	main
kus	doc_609075653188_item	2763240	et	3	main
on	doc_609075653188_item	2763241	et	4	main
arvan	doc_609075653188_item	2763248	et	3	main
seal	doc_609075653188_item	2763258	et	4	main
seal	doc_609075653188_item	2763274	et	4	main
kus	doc_609075653188_item	2763275	et	3	main
sa	doc_609075653188_item	2763276	et	3	main
sooviksin	doc_609075653188_item	2763285	et	3	main
kodumaal	doc_609075653188_item	2763288	et	4	main
pärast	doc_609075653188_item	2763295	et	4	main
et	doc_609075653188_item	2763296	et	3	main
ma	doc_609075653188_item	2763297	et	3	main
last	doc_609075653188_item	2763299	et	4	main
ma	doc_609075653188_item	2763300	et	3	main
tunnen	doc_609075653188_item	2763301	et	3	main
soovid	doc_609075653188_item	2763310	et	4	main
kõrgharidus	doc_609075653188_item	2763311	et	3	main
omandada	doc_609075653188_item	2763312	et	3	main
ma	doc_609075653188_item	2763313	et	3	main
arvan	doc_609075653188_item	2763314	et	3	main
et	doc_609075653188_item	2763315	et	3	main
kõrgharidus	doc_609075653188_item	2763316	et	3	main
on	doc_609075653188_item	2763317	et	4	main
vaja	doc_609075653188_item	2763318	et	4	main
selle	doc_609075653188_item	2763319	et	4	main
jaoks	doc_609075653188_item	2763320	et	4	main
palka	doc_609075653188_item	2763327	et	4	main
6	doc_609075653188_item	2763328	et	2	main
tänapäeva	doc_609075653188_item	2763330	et	4	main
noored	doc_609075653188_item	2763331	et	3	main
väärtustavad	doc_609075653188_item	2763332	et	4	main
haridus	doc_609075653188_item	2763344	et	3	main
koolis	doc_609075653188_item	2763347	et	4	main
ülikoolis	doc_609075653188_item	2763349	et	4	main
eesti	doc_617668397741_item	2763359	et	4	main
rootsiaegne	doc_617668397741_item	2763388	et	3	main
elu	doc_617668397741_item	2763389	et	4	main
oli	doc_617668397741_item	2763390	et	3	main
seotud	doc_617668397741_item	2763391	et	4	main
haridusega	doc_617668397741_item	2763392	et	3	main
6	doc_617668397741_item	2763413	et	2	main
talurahvakoolid	doc_617668397741_item	2763420	et	3	main
õpetajana	doc_617668397741_item	2763422	et	4	main
tegi	doc_617668397741_item	2763432	et	4	main
kirjaviisiga	doc_617668397741_item	2763435	et	4	main
ülikool	doc_617668397741_item	2763437	et	4	main
töötas	doc_617668397741_item	2763438	et	3	main
ja	doc_617668397741_item	2763439	et	3	main
oli	doc_617668397741_item	2763440	et	3	main
pastorid	doc_617668397741_item	2763443	et	3	main
suurem	doc_617668397741_item	2763457	et	4	main
teadus	doc_617668397741_item	2763463	et	4	main
usule	doc_617668397741_item	2763466	et	3	main
tähtis	doc_617668397741_item	2763474	et	4	main
sündmus	doc_617668397741_item	2763475	et	3	main
seminaar	doc_617668397741_item	2763481	et	4	main
ta	doc_617668397741_item	2763484	et	4	main
160	doc_617668397741_item	2763486	et	2	main
ajal	doc_617668397741_item	2763490	et	4	main
suur	doc_617668397741_item	2763493	et	3	main
arv	doc_617668397741_item	2763494	et	3	main
eriõigustega	doc_617668397741_item	2763507	et	4	main
autonoomsed	doc_617668397741_item	2763508	et	3	main
alad	doc_617668397741_item	2763509	et	3	main
kuskil	doc_617668397741_item	2763510	et	3	main
saada	doc_609075653188_item	2763322	et	4	main
kas	doc_609075653188_item	2763329	et	3	main
pärast	doc_609075653188_item	2763343	et	4	main
tasuline	doc_609075653188_item	2763352	et	4	main
väärtustavad	doc_609075653188_item	2763355	et	4	main
1	doc_617668397741_item	2763361	et	2	main
rootsiaegne	doc_617668397741_item	2763362	et	3	main
balti	doc_617668397741_item	2763368	et	3	main
2	doc_617668397741_item	2763367	et	2	main
erikorra	doc_617668397741_item	2763369	et	3	main
positiivsed	doc_617668397741_item	2763370	et	3	main
tagajärjed	doc_617668397741_item	2763371	et	3	main
eestlaste	doc_617668397741_item	2763372	et	4	main
kultuuri-	doc_617668397741_item	2763373	et	4	main
ja	doc_617668397741_item	2763374	et	3	main
majanduselule	doc_617668397741_item	2763375	et	3	main
3	doc_617668397741_item	2763376	et	2	main
c	doc_617668397741_item	2763377	et	4	main
r	doc_617668397741_item	2763378	et	4	main
jakobson	doc_617668397741_item	2763379	et	4	main
ja	doc_617668397741_item	2763380	et	3	main
j	doc_617668397741_item	2763381	et	4	main
hurt	doc_617668397741_item	2763382	et	3	main
rahvusliku	doc_617668397741_item	2763383	et	3	main
liikumise	doc_617668397741_item	2763384	et	4	main
tähtsamad	doc_617668397741_item	2763385	et	4	main
tegelased	doc_617668397741_item	2763386	et	3	main
1	doc_617668397741_item	2763387	et	2	main
olid	doc_617668397741_item	2763393	et	4	main
teised	doc_617668397741_item	2763407	et	4	main
oli	doc_617668397741_item	2763408	et	3	main
ka	doc_617668397741_item	2763409	et	3	main
koolikorralduse	doc_617668397741_item	2763410	et	3	main
aastast	doc_617668397741_item	2763414	et	4	main
see	doc_617668397741_item	2763425	et	3	main
tõi	doc_617668397741_item	2763427	et	3	main
ajal	doc_617668397741_item	2763452	et	4	main
ja	doc_617668397741_item	2763453	et	3	main
seepärast	doc_617668397741_item	2763454	et	3	main
professorid	doc_617668397741_item	2763455	et	3	main
saaksid	doc_617668397741_item	2763456	et	4	main
tähtis	doc_617668397741_item	2763461	et	4	main
ja	doc_617668397741_item	2763462	et	3	main
kontrollisid	doc_617668397741_item	2763468	et	4	main
haridust	doc_617668397741_item	2763479	et	4	main
1686	doc_617668397741_item	2763483	et	2	main
omavalitsev	doc_617668397741_item	2763499	et	3	main
eestlaste	doc_617668397741_item	2763522	et	4	main
kultuuri-	doc_617668397741_item	2763523	et	4	main
ja	doc_617668397741_item	2763524	et	3	main
majanduselule	doc_617668397741_item	2763525	et	3	main
koolitus	doc_617668397741_item	2763527	et	4	main
oli	doc_617668397741_item	2763528	et	3	main
kahju	doc_617668397741_item	2763536	et	4	main
aga	doc_617668397741_item	2763537	et	3	main
rahvuspäringuga	doc_617668397741_item	2763547	et	3	main
tooded	doc_617668397741_item	2763558	et	4	main
tekkisid	doc_617668397741_item	2763561	et	4	main
balti	doc_617668397741_item	2763563	et	3	main
ja	doc_617668397741_item	2763576	et	3	main
see	doc_617668397741_item	2763579	et	3	main
mis	doc_617668397741_item	2763591	et	4	main
manufakturid	doc_617668397741_item	2763596	et	4	main
talupojaid	doc_617668397741_item	2763602	et	4	main
3	doc_617668397741_item	2763628	et	2	main
palju	doc_617668397741_item	2763640	et	4	main
oma	doc_617668397741_item	2763644	et	4	main
nende	doc_617668397741_item	2763646	et	4	main
elutöö	doc_617668397741_item	2763647	et	4	main
nad	doc_617668397741_item	2763651	et	3	main
rahvapärimust	doc_617668397741_item	2763656	et	4	main
nende	doc_617668397741_item	2763657	et	4	main
inimeste	doc_617668397741_item	2763682	et	3	main
jakobson	doc_617668397741_item	2763720	et	4	main
inimene	doc_617668397741_item	2763426	et	3	main
ta	doc_617668397741_item	2763431	et	4	main
ja	doc_617668397741_item	2763445	et	3	main
usuteadus	doc_617668397741_item	2763459	et	4	main
oli	doc_617668397741_item	2763460	et	3	main
hariduselus	doc_617668397741_item	2763472	et	4	main
oli	doc_617668397741_item	2763473	et	3	main
aitas	doc_617668397741_item	2763477	et	3	main
1646	doc_617668397741_item	2763482	et	2	main
õppis	doc_617668397741_item	2763485	et	3	main
eestalst	doc_617668397741_item	2763487	et	4	main
ja	doc_617668397741_item	2763488	et	3	main
tol	doc_617668397741_item	2763489	et	3	main
see	doc_617668397741_item	2763491	et	3	main
oli	doc_617668397741_item	2763492	et	3	main
2	doc_617668397741_item	2763495	et	2	main
balti	doc_617668397741_item	2763496	et	3	main
erikord	doc_617668397741_item	2763497	et	3	main
on	doc_617668397741_item	2763498	et	4	main
autonoomia	doc_617668397741_item	2763500	et	4	main
tuli	doc_617668397741_item	2763502	et	4	main
aeg	doc_617668397741_item	2763504	et	3	main
siis	doc_617668397741_item	2763505	et	3	main
seda	doc_617668397741_item	2763512	et	3	main
ei	doc_617668397741_item	2763513	et	4	main
olnud	doc_617668397741_item	2763514	et	4	main
balti	doc_617668397741_item	2763515	et	3	main
erikord	doc_617668397741_item	2763516	et	3	main
on	doc_617668397741_item	2763517	et	4	main
toonud	doc_617668397741_item	2763518	et	4	main
palju	doc_617668397741_item	2763519	et	4	main
positiivseid	doc_617668397741_item	2763520	et	3	main
tagajärjeid	doc_617668397741_item	2763521	et	4	main
haridus	doc_617668397741_item	2763526	et	3	main
poole	doc_617668397741_item	2763535	et	4	main
see	doc_617668397741_item	2763539	et	3	main
hävitati	doc_617668397741_item	2763548	et	3	main
oli	doc_617668397741_item	2763551	et	3	main
olid	doc_617668397741_item	2763559	et	4	main
keeles	doc_617668397741_item	2763574	et	4	main
tähtis	doc_617668397741_item	2763581	et	4	main
on	doc_617668397741_item	2763594	et	4	main
balti	doc_617668397741_item	2763624	et	3	main
tõepoolest	doc_617668397741_item	2763633	et	3	main
liikumise	doc_617668397741_item	2763635	et	4	main
et	doc_617668397741_item	2763642	et	3	main
on	doc_617668397741_item	2763648	et	4	main
seotud	doc_617668397741_item	2763649	et	4	main
edenesid	doc_617668397741_item	2763652	et	4	main
haridust	doc_617668397741_item	2763653	et	4	main
on	doc_617668397741_item	2763659	et	4	main
tekkisid	doc_617668397741_item	2763668	et	4	main
passid	doc_617668397741_item	2763670	et	4	main
talupoegadele	doc_617668397741_item	2763671	et	3	main
muutusi	doc_617668397741_item	2763681	et	4	main
identeet	doc_617668397741_item	2763727	et	4	main
väike	doc_617668397741_item	2763743	et	4	main
oma	doc_617668397741_item	2763749	et	4	main
jakobson	doc_617668397741_item	2763752	et	4	main
tahtsid	doc_617668397741_item	2763755	et	4	main
linnakultuuri	doc_617668397742_item	2763787	et	4	main
eestimaal	doc_617668397742_item	2763789	et	4	main
mesoliitikumist	doc_617668397742_item	2763802	et	4	main
tol	doc_617668397742_item	2763805	et	3	main
muutuseid	doc_617668397742_item	2763823	et	4	main
ka	doc_617668397742_item	2763833	et	3	main
inimesed	doc_617668397742_item	2763836	et	3	main
ilmusid	doc_617668397742_item	2763841	et	4	main
uued	doc_617668397742_item	2763842	et	3	main
kuidas	doc_617668397742_item	2763844	et	3	main
töötada	doc_617668397742_item	2763845	et	3	main
põllul	doc_617668397742_item	2763846	et	3	main
tarberiistad	doc_617668397742_item	2763847	et	3	main
muujal	doc_617668397741_item	2763511	et	4	main
et	doc_617668397741_item	2763540	et	3	main
kõik	doc_617668397741_item	2763543	et	4	main
mis	doc_617668397741_item	2763544	et	4	main
oli	doc_617668397741_item	2763545	et	3	main
seotud	doc_617668397741_item	2763546	et	4	main
aeg	doc_617668397741_item	2763553	et	3	main
laadakaubandus	doc_617668397741_item	2763556	et	3	main
kõik	doc_617668397741_item	2763557	et	4	main
kaupmehed	doc_617668397741_item	2763562	et	3	main
eestikeelne	doc_617668397741_item	2763577	et	3	main
oli	doc_617668397741_item	2763580	et	3	main
elus	doc_617668397741_item	2763584	et	4	main
ministriteks	doc_617668397741_item	2763621	et	3	main
kindralkubernerideks	doc_617668397741_item	2763623	et	3	main
olid	doc_617668397741_item	2763626	et	4	main
ja	doc_617668397741_item	2763630	et	3	main
on	doc_617668397741_item	2763632	et	4	main
rahvusliku	doc_617668397741_item	2763634	et	3	main
rakendasid	doc_617668397741_item	2763654	et	4	main
mis	doc_617668397741_item	2763662	et	4	main
oli	doc_617668397741_item	2763663	et	3	main
1918	doc_617668397741_item	2763665	et	2	main
vabalt	doc_617668397741_item	2763675	et	4	main
liikuda	doc_617668397741_item	2763676	et	3	main
sel	doc_617668397741_item	2763677	et	3	main
ajal	doc_617668397741_item	2763678	et	4	main
oli	doc_617668397741_item	2763679	et	3	main
tekkinud	doc_617668397741_item	2763685	et	4	main
uus	doc_617668397741_item	2763686	et	3	main
oli	doc_617668397741_item	2763712	et	3	main
rahvaluulekogumisega	doc_617668397741_item	2763716	et	4	main
nad	doc_617668397741_item	2763717	et	3	main
hurt	doc_617668397741_item	2763718	et	3	main
ja	doc_617668397741_item	2763719	et	3	main
riiklik	doc_617668397741_item	2763729	et	3	main
tahtsid	doc_617668397741_item	2763732	et	4	main
et	doc_617668397741_item	2763733	et	3	main
oleks	doc_617668397741_item	2763734	et	3	main
emakeelne	doc_617668397741_item	2763735	et	3	main
haridus	doc_617668397741_item	2763736	et	3	main
siiski	doc_617668397741_item	2763745	et	4	main
nad	doc_617668397741_item	2763746	et	3	main
ja	doc_617668397741_item	2763753	et	3	main
toimusid	doc_617668397742_item	2763781	et	4	main
üleminekul	doc_617668397742_item	2763782	et	3	main
miks	doc_617668397742_item	2763791	et	4	main
n	doc_617668397742_item	2763797	et	4	main
ajal	doc_617668397742_item	2763806	et	4	main
toimusid	doc_617668397742_item	2763827	et	4	main
hakkasid	doc_617668397742_item	2763837	et	4	main
muutuma	doc_617668397742_item	2763851	et	4	main
parem	doc_617668397742_item	2763856	et	4	main
kujunema	doc_617668397742_item	2763859	et	3	main
vaimne	doc_617668397742_item	2763861	et	3	main
rauast	doc_617668397742_item	2763869	et	4	main
mõjutasid	doc_617668397742_item	2763871	et	4	main
inimeste	doc_617668397742_item	2763872	et	3	main
ma	doc_617668397742_item	2763911	et	3	main
öelda	doc_617668397742_item	2763913	et	4	main
igas	doc_617668397742_item	2763916	et	3	main
pärnu	doc_617668397742_item	2763939	et	4	main
rakvere	doc_617668397742_item	2763944	et	4	main
elati	doc_617668397742_item	2763947	et	3	main
elamine	doc_617668397742_item	2763949	et	4	main
põld	doc_617668397742_item	2763959	et	3	main
kus	doc_617668397742_item	2763960	et	3	main
võiks	doc_617668397742_item	2763961	et	4	main
tegelda	doc_617668397742_item	2763967	et	4	main
linnas	doc_617668397742_item	2763969	et	4	main
seda	doc_617668397742_item	2763970	et	3	main
raske	doc_617668397742_item	2763974	et	4	main
kivimajad	doc_617668397742_item	2763976	et	4	main
ja	doc_617668397742_item	2763977	et	3	main
puumajad	doc_617668397742_item	2763978	et	3	main
inimesed	doc_617668397742_item	2763979	et	3	main
elasid	doc_617668397742_item	2763980	et	4	main
lõppes	doc_617668397742_item	2764022	et	4	main
hea	doc_617668397742_item	2764027	et	4	main
ja	doc_617668397742_item	2764034	et	3	main
et	doc_617668397742_item	2764042	et	3	main
ja	doc_617668397742_item	2764047	et	3	main
inimesed	doc_617668397741_item	2763532	et	3	main
püüdlesid	doc_617668397741_item	2763533	et	4	main
teadmiste	doc_617668397741_item	2763534	et	4	main
on	doc_617668397741_item	2763538	et	4	main
rahvariideid	doc_617668397741_item	2763541	et	3	main
kui	doc_617668397741_item	2763550	et	3	main
vene	doc_617668397741_item	2763552	et	4	main
arenes	doc_617668397741_item	2763555	et	3	main
vene	doc_617668397741_item	2763560	et	4	main
erikkorras	doc_617668397741_item	2763564	et	4	main
on	doc_617668397741_item	2763565	et	4	main
posiivne	doc_617668397741_item	2763566	et	4	main
tulemus	doc_617668397741_item	2763567	et	3	main
ka	doc_617668397741_item	2763568	et	3	main
see	doc_617668397741_item	2763569	et	3	main
et	doc_617668397741_item	2763570	et	3	main
enamikus	doc_617668397741_item	2763575	et	3	main
ajakiri	doc_617668397741_item	2763578	et	3	main
tolles	doc_617668397741_item	2763583	et	4	main
arenes	doc_617668397741_item	2763586	et	3	main
turul	doc_617668397741_item	2763587	et	3	main
ilmusid	doc_617668397741_item	2763588	et	4	main
balti	doc_617668397741_item	2763589	et	3	main
kilud	doc_617668397741_item	2763590	et	3	main
majandusellu	doc_617668397741_item	2763593	et	3	main
jm	doc_617668397741_item	2763598	et	4	main
pärisorjusest	doc_617668397741_item	2763603	et	4	main
ja	doc_617668397741_item	2763604	et	3	main
nad	doc_617668397741_item	2763605	et	3	main
saaksid	doc_617668397741_item	2763606	et	4	main
elada	doc_617668397741_item	2763607	et	3	main
veidi	doc_617668397741_item	2763608	et	3	main
paremini	doc_617668397741_item	2763609	et	4	main
arenesid	doc_617668397741_item	2763610	et	4	main
humanitaarteadvused	doc_617668397741_item	2763611	et	4	main
oli	doc_617668397741_item	2763613	et	3	main
ka	doc_617668397741_item	2763614	et	3	main
heal	doc_617668397741_item	2763615	et	3	main
tasemel	doc_617668397741_item	2763616	et	3	main
esinemisoskus	doc_617668397741_item	2763612	et	3	main
baltisaksa	doc_617668397741_item	2763617	et	4	main
aadlikud	doc_617668397741_item	2763618	et	3	main
tõusid	doc_617668397741_item	2763619	et	4	main
venemaa	doc_617668397741_item	2763620	et	4	main
jakobson	doc_617668397741_item	2763629	et	4	main
head	doc_617668397741_item	2763641	et	4	main
rahvaga	doc_617668397741_item	2763650	et	3	main
millal	doc_617668397741_item	2763667	et	3	main
palju	doc_617668397741_item	2763680	et	4	main
on	doc_617668397741_item	2763684	et	4	main
arvasid	doc_617668397741_item	2763721	et	4	main
tähtsam	doc_617668397741_item	2763724	et	4	main
nad	doc_617668397741_item	2763731	et	3	main
arvasid	doc_617668397741_item	2763738	et	4	main
et	doc_617668397741_item	2763739	et	3	main
kui	doc_617668397741_item	2763740	et	3	main
eestlased	doc_617668397741_item	2763741	et	3	main
on	doc_617668397741_item	2763742	et	4	main
säilitama	doc_617668397741_item	2763748	et	4	main
hurt	doc_617668397741_item	2763754	et	3	main
et	doc_617668397741_item	2763756	et	3	main
kontrolltöö	doc_617668397742_item	2763770	et	4	main
eesti	doc_617668397742_item	2763772	et	4	main
1	doc_617668397742_item	2763774	et	2	main
ja	doc_617668397741_item	2763531	et	3	main
ja	doc_617668397741_item	2763542	et	3	main
ära	doc_617668397741_item	2763549	et	4	main
siis	doc_617668397741_item	2763554	et	3	main
ilmusid	doc_617668397741_item	2763571	et	4	main
ajalehed	doc_617668397741_item	2763572	et	3	main
saksa	doc_617668397741_item	2763573	et	4	main
sündmus	doc_617668397741_item	2763582	et	3	main
majanduselu	doc_617668397741_item	2763585	et	4	main
mõjutas	doc_617668397741_item	2763592	et	3	main
tekkinud	doc_617668397741_item	2763595	et	4	main
tehased	doc_617668397741_item	2763597	et	3	main
aleksander	doc_617668397741_item	2763599	et	4	main
i	doc_617668397741_item	2763600	et	4	main
vabastas	doc_617668397741_item	2763601	et	3	main
ja	doc_617668397741_item	2763622	et	3	main
erikorras	doc_617668397741_item	2763625	et	3	main
rüütelkonnad	doc_617668397741_item	2763627	et	3	main
hurt	doc_617668397741_item	2763631	et	3	main
tähtsamad	doc_617668397741_item	2763636	et	4	main
tegurid	doc_617668397741_item	2763637	et	3	main
nad	doc_617668397741_item	2763638	et	3	main
tegid	doc_617668397741_item	2763639	et	4	main
arendada	doc_617668397741_item	2763643	et	3	main
kultuuri	doc_617668397741_item	2763645	et	4	main
trükkisõna	doc_617668397741_item	2763655	et	4	main
tegud	doc_617668397741_item	2763658	et	4	main
seotud	doc_617668397741_item	2763660	et	4	main
ärkamisajaga	doc_617668397741_item	2763661	et	3	main
1850	doc_617668397741_item	2763664	et	2	main
aastani	doc_617668397741_item	2763666	et	3	main
esimesed	doc_617668397741_item	2763669	et	3	main
ja	doc_617668397741_item	2763672	et	3	main
nad	doc_617668397741_item	2763673	et	3	main
saaksid	doc_617668397741_item	2763674	et	4	main
elus	doc_617668397741_item	2763683	et	4	main
teadvus	doc_617668397741_item	2763687	et	4	main
ja	doc_617668397741_item	2763688	et	3	main
need	doc_617668397741_item	2763689	et	3	main
kes	doc_617668397741_item	2763690	et	4	main
aitasid	doc_617668397741_item	2763691	et	4	main
selle	doc_617668397741_item	2763692	et	4	main
teadvuse	doc_617668397741_item	2763693	et	4	main
mõjutada	doc_617668397741_item	2763694	et	3	main
rahvast	doc_617668397741_item	2763695	et	4	main
on	doc_617668397741_item	2763696	et	4	main
just	doc_617668397741_item	2763697	et	3	main
hurt	doc_617668397741_item	2763698	et	3	main
ja	doc_617668397741_item	2763699	et	3	main
jakobson	doc_617668397741_item	2763700	et	4	main
nad	doc_617668397741_item	2763701	et	3	main
tegid	doc_617668397741_item	2763702	et	4	main
seda	doc_617668397741_item	2763703	et	3	main
mida	doc_617668397741_item	2763704	et	4	main
mõtlesid	doc_617668397741_item	2763705	et	4	main
ja	doc_617668397741_item	2763706	et	3	main
rääkisid	doc_617668397741_item	2763707	et	4	main
nii	doc_617668397741_item	2763708	et	3	main
nagu	doc_617668397741_item	2763709	et	3	main
tahtsid	doc_617668397741_item	2763710	et	4	main
hurt	doc_617668397741_item	2763711	et	3	main
kogu	doc_617668397741_item	2763713	et	4	main
elu	doc_617668397741_item	2763714	et	4	main
tegelnud	doc_617668397741_item	2763715	et	4	main
et	doc_617668397741_item	2763722	et	3	main
mitte	doc_617668397741_item	2763728	et	3	main
kuuluvus	doc_617668397741_item	2763730	et	4	main
rahvas	doc_617668397741_item	2763744	et	4	main
kultuuri	doc_617668397741_item	2763750	et	4	main
eestlastel	doc_617668397741_item	2763757	et	4	main
olid	doc_617668397741_item	2763758	et	4	main
võrdsed	doc_617668397741_item	2763759	et	3	main
õigused	doc_617668397741_item	2763760	et	4	main
sakslastega	doc_617668397741_item	2763761	et	3	main
eriti	doc_617668397741_item	2763762	et	3	main
poliitikas	doc_617668397741_item	2763763	et	3	main
tahtsid	doc_617668397741_item	2763764	et	4	main
et	doc_617668397741_item	2763765	et	3	main
eestlased	doc_617668397741_item	2763766	et	3	main
esinesid	doc_617668397741_item	2763767	et	4	main
kõige	doc_617668397741_item	2763723	et	4	main
on	doc_617668397741_item	2763725	et	4	main
rahvuslik	doc_617668397741_item	2763726	et	3	main
ja	doc_617668397741_item	2763737	et	3	main
peavad	doc_617668397741_item	2763747	et	4	main
rahvapärimust	doc_617668397741_item	2763751	et	4	main
kubermangudes	doc_617668397741_item	2763769	et	3	main
kiviajast	doc_617668397742_item	2763783	et	4	main
rauaaega	doc_617668397742_item	2763784	et	4	main
2	doc_617668397742_item	2763785	et	2	main
keskaegsel	doc_617668397742_item	2763788	et	3	main
lõppes	doc_617668397742_item	2763794	et	4	main
kaotusega	doc_617668397742_item	2763796	et	4	main
koosneb	doc_617668397742_item	2763800	et	3	main
ja	doc_617668397742_item	2763803	et	3	main
enamus	doc_617668397742_item	2763807	et	4	main
oli	doc_617668397742_item	2763809	et	3	main
seepärast	doc_617668397742_item	2763814	et	3	main
avastamine	doc_617668397742_item	2763816	et	4	main
ja	doc_617668397742_item	2763817	et	3	main
kasutamine	doc_617668397742_item	2763818	et	4	main
töid	doc_617668397742_item	2763819	et	3	main
inimeste	doc_617668397742_item	2763820	et	3	main
maapäevadel	doc_617668397741_item	2763768	et	3	main
kontrolltöö	doc_617668397742_item	2763771	et	4	main
kultuuriloost	doc_617668397742_item	2763773	et	4	main
muutused	doc_617668397742_item	2763776	et	4	main
materiaalses	doc_617668397742_item	2763777	et	3	main
ja	doc_617668397742_item	2763778	et	3	main
vaimses	doc_617668397742_item	2763779	et	3	main
kultuuris	doc_617668397742_item	2763780	et	3	main
kirjelda	doc_617668397742_item	2763786	et	4	main
muistne	doc_617668397742_item	2763792	et	3	main
1	doc_617668397742_item	2763798	et	2	main
luust	doc_617668397742_item	2763810	et	4	main
kivist	doc_617668397742_item	2763812	et	4	main
just	doc_617668397742_item	2763813	et	3	main
elusse	doc_617668397742_item	2763821	et	3	main
vaimses	doc_617668397742_item	2763834	et	3	main
nägemiselt	doc_617668397742_item	2763850	et	4	main
esemed	doc_617668397742_item	2763868	et	3	main
muutus	doc_617668397742_item	2763875	et	4	main
siis	doc_617668397742_item	2763910	et	3	main
et	doc_617668397742_item	2763914	et	3	main
vähe	doc_617668397742_item	2763919	et	3	main
tegelikult	doc_617668397742_item	2763921	et	4	main
teiste	doc_617668397742_item	2763923	et	4	main
tol	doc_617668397742_item	2763925	et	3	main
viljandi	doc_617668397742_item	2763937	et	4	main
narva	doc_617668397742_item	2763943	et	4	main
maal	doc_617668397742_item	2763956	et	4	main
oli	doc_617668397742_item	2763957	et	3	main
palju	doc_617668397742_item	2763958	et	4	main
oli	doc_617668397742_item	2763972	et	3	main
maal	doc_617668397742_item	2763988	et	4	main
vabadusvõistlus	doc_617668397742_item	2764021	et	3	main
see	doc_617668397742_item	2764025	et	3	main
rahvas	doc_617668397742_item	2764036	et	4	main
ei	doc_617668397742_item	2764038	et	4	main
inimesed	doc_617668397742_item	2764044	et	3	main
palju	doc_617668397742_item	2764087	et	4	main
oli	doc_617668397742_item	2764098	et	3	main
kontrolltöö	doc_617668397743_item	2764111	et	4	main
kultuuriloost	doc_617668397743_item	2764113	et	4	main
välja	doc_617668397743_item	2764116	et	4	main
2	doc_617668397743_item	2764123	et	2	main
hiliskeskaegset	doc_617668397743_item	2764125	et	3	main
3	doc_617668397743_item	2764127	et	2	main
missugune	doc_617668397743_item	2764128	et	3	main
oli	doc_617668397743_item	2764129	et	3	main
muistse	doc_617668397743_item	2764130	et	3	main
osa	doc_617668397743_item	2764138	et	4	main
endale	doc_617668397743_item	2764144	et	4	main
selle	doc_617668397743_item	2764147	et	4	main
muu	doc_617668397743_item	2764160	et	4	main
nad	doc_617668397743_item	2764184	et	3	main
kaitsma	doc_617668397743_item	2764186	et	3	main
oma	doc_617668397743_item	2764187	et	4	main
maad	doc_617668397743_item	2764188	et	4	main
ja	doc_617668397743_item	2764189	et	3	main
pered	doc_617668397743_item	2764190	et	3	main
näitasid	doc_617668397743_item	2764194	et	4	main
seista	doc_617668397743_item	2764203	et	4	main
juba	doc_617668397743_item	2764211	et	3	main
teisiti	doc_617668397743_item	2764212	et	3	main
2	doc_617668397743_item	2764216	et	2	main
taludes	doc_617668397743_item	2764221	et	4	main
millised	doc_617668397742_item	2763775	et	3	main
3	doc_617668397742_item	2763790	et	2	main
vabadusvõitlus	doc_617668397742_item	2763793	et	3	main
eestlastele	doc_617668397742_item	2763795	et	4	main
kiviaeg	doc_617668397742_item	2763799	et	3	main
paleoliitikumist	doc_617668397742_item	2763801	et	4	main
neoliitikumist	doc_617668397742_item	2763804	et	4	main
tarbeesemetest	doc_617668397742_item	2763808	et	3	main
ja	doc_617668397742_item	2763811	et	3	main
raua	doc_617668397742_item	2763815	et	3	main
suured	doc_617668397742_item	2763828	et	3	main
muutused	doc_617668397742_item	2763829	et	4	main
nii	doc_617668397742_item	2763830	et	3	main
materiaalses	doc_617668397742_item	2763831	et	3	main
kui	doc_617668397742_item	2763832	et	3	main
kultuuris	doc_617668397742_item	2763835	et	3	main
tööristad	doc_617668397742_item	2763840	et	4	main
sest	doc_617668397742_item	2763852	et	4	main
töötada	doc_617668397742_item	2763857	et	3	main
olid	doc_617668397742_item	2763867	et	4	main
rauaaeg	doc_617668397742_item	2763876	et	3	main
mõjutas	doc_617668397742_item	2763877	et	3	main
inimeste	doc_617668397742_item	2763878	et	3	main
ajal	doc_617668397742_item	2763907	et	4	main
võin	doc_617668397742_item	2763912	et	3	main
elanikke	doc_617668397742_item	2763915	et	3	main
ajal	doc_617668397742_item	2763926	et	4	main
siis	doc_617668397742_item	2763927	et	3	main
linnaelanike	doc_617668397742_item	2763928	et	3	main
arv	doc_617668397742_item	2763929	et	3	main
oli	doc_617668397742_item	2763930	et	3	main
piisav	doc_617668397742_item	2763931	et	4	main
vana	doc_617668397742_item	2763938	et	4	main
maal	doc_617668397742_item	2763954	et	4	main
külas	doc_617668397742_item	2763955	et	3	main
kariloomadega	doc_617668397742_item	2763962	et	3	main
maakorraldusega	doc_617668397742_item	2763964	et	3	main
peredega	doc_617668397742_item	2763981	et	3	main
tol	doc_617668397742_item	2763984	et	3	main
palju	doc_617668397742_item	2763822	et	4	main
üleminekul	doc_617668397742_item	2763824	et	3	main
kiviajast	doc_617668397742_item	2763825	et	4	main
rauaaega	doc_617668397742_item	2763826	et	4	main
kasutama	doc_617668397742_item	2763838	et	3	main
uued	doc_617668397742_item	2763839	et	3	main
ideeid	doc_617668397742_item	2763843	et	4	main
hakkati	doc_617668397742_item	2763848	et	3	main
välja	doc_617668397742_item	2763849	et	4	main
nendega	doc_617668397742_item	2763854	et	4	main
oli	doc_617668397742_item	2763855	et	3	main
olid	doc_617668397742_item	2763864	et	4	main
meelekindus	doc_617668397742_item	2763874	et	4	main
kombe	doc_617668397742_item	2763879	et	4	main
ja	doc_617668397742_item	2763880	et	3	main
suhteid	doc_617668397742_item	2763881	et	3	main
elu	doc_617668397742_item	2763882	et	4	main
rauaajal	doc_617668397742_item	2763883	et	3	main
oli	doc_617668397742_item	2763884	et	3	main
lihtsam	doc_617668397742_item	2763885	et	4	main
kui	doc_617668397742_item	2763886	et	3	main
kiviajal	doc_617668397742_item	2763887	et	3	main
rauaaeg	doc_617668397742_item	2763888	et	3	main
koosneb	doc_617668397742_item	2763889	et	3	main
pronksiajast	doc_617668397742_item	2763890	et	4	main
noorest	doc_617668397742_item	2763891	et	3	main
vanemast	doc_617668397742_item	2763892	et	4	main
ja	doc_617668397742_item	2763893	et	3	main
keskmisest	doc_617668397742_item	2763894	et	3	main
rauaajast	doc_617668397742_item	2763895	et	4	main
n	doc_617668397742_item	2763896	et	4	main
2	doc_617668397742_item	2763897	et	2	main
keskaegsel	doc_617668397742_item	2763898	et	3	main
estimal	doc_617668397742_item	2763899	et	4	main
kujunes	doc_617668397742_item	2763900	et	3	main
linnakultuur	doc_617668397742_item	2763901	et	3	main
kui	doc_617668397742_item	2763902	et	3	main
võrrelda	doc_617668397742_item	2763903	et	4	main
elanike	doc_617668397742_item	2763904	et	3	main
arv	doc_617668397742_item	2763905	et	3	main
tol	doc_617668397742_item	2763906	et	3	main
rauast	doc_617668397742_item	2763853	et	4	main
hakkas	doc_617668397742_item	2763858	et	3	main
uus	doc_617668397742_item	2763860	et	3	main
kultuur	doc_617668397742_item	2763862	et	3	main
hauad	doc_617668397742_item	2763863	et	3	main
juba	doc_617668397742_item	2763865	et	3	main
tugevnenud	doc_617668397742_item	2763866	et	4	main
mis	doc_617668397742_item	2763870	et	4	main
vaimujõudu	doc_617668397742_item	2763873	et	4	main
meie	doc_617668397742_item	2763908	et	4	main
aegadega	doc_617668397742_item	2763909	et	3	main
oli	doc_617668397742_item	2763918	et	3	main
linnas	doc_617668397742_item	2763917	et	4	main
aga	doc_617668397742_item	2763920	et	3	main
võrreldes	doc_617668397742_item	2763922	et	3	main
riikidega	doc_617668397742_item	2763924	et	3	main
olid	doc_617668397742_item	2763936	et	4	main
tartu	doc_617668397742_item	2763942	et	4	main
tallinn	doc_617668397742_item	2763945	et	4	main
ja	doc_617668397742_item	2763963	et	3	main
künnimaaga	doc_617668397742_item	2763966	et	3	main
loomulikult	doc_617668397742_item	2763968	et	4	main
teha	doc_617668397742_item	2763971	et	3	main
tsiviliseeritum	doc_617668397742_item	2763986	et	4	main
kui	doc_617668397742_item	2763987	et	3	main
maakonnad	doc_617668397742_item	2763989	et	4	main
eestlastele	doc_617668397742_item	2764023	et	4	main
olid	doc_617668397742_item	2764030	et	4	main
eestlased	doc_617668397742_item	2764031	et	3	main
rahulik	doc_617668397742_item	2764032	et	3	main
lepne	doc_617668397742_item	2764033	et	3	main
vaikne	doc_617668397742_item	2764035	et	3	main
tulevad	doc_617668397742_item	2764043	et	4	main
head	doc_617668397742_item	2764053	et	4	main
sõja	doc_617668397742_item	2764054	et	3	main
asjades	doc_617668397742_item	2764055	et	3	main
teadnud	doc_617668397742_item	2764058	et	4	main
oleks	doc_617668397742_item	2764063	et	3	main
oli	doc_617668397742_item	2764079	et	3	main
väiksem	doc_617668397742_item	2764080	et	4	main
kui	doc_617668397742_item	2764081	et	3	main
vastuseisjal	doc_617668397742_item	2764082	et	3	main
inimesi	doc_617668397742_item	2764089	et	4	main
tol	doc_617668397742_item	2764092	et	3	main
ja	doc_617668397742_item	2764094	et	3	main
kahjuks	doc_617668397742_item	2764096	et	4	main
vastuseisjatelt	doc_617668397742_item	2764097	et	3	main
eestastelt	doc_617668397742_item	2764109	et	4	main
muinaseestlaste	doc_617668397743_item	2764117	et	4	main
usundi	doc_617668397743_item	2764118	et	3	main
ja	doc_617668397743_item	2764119	et	3	main
ristiusu	doc_617668397743_item	2764120	et	3	main
suuremad	doc_617668397742_item	2763932	et	4	main
linnad	doc_617668397742_item	2763933	et	3	main
keskaegsel	doc_617668397742_item	2763934	et	3	main
eestimaal	doc_617668397742_item	2763935	et	4	main
uus	doc_617668397742_item	2763940	et	3	main
pärnu	doc_617668397742_item	2763941	et	4	main
linnas	doc_617668397742_item	2763946	et	4	main
teistmoodi	doc_617668397742_item	2763948	et	3	main
ei	doc_617668397742_item	2763950	et	4	main
olnud	doc_617668397742_item	2763951	et	4	main
samasugune	doc_617668397742_item	2763952	et	3	main
kui	doc_617668397742_item	2763953	et	3	main
ning	doc_617668397742_item	2763965	et	3	main
väga	doc_617668397742_item	2763973	et	3	main
ilmusid	doc_617668397742_item	2763975	et	4	main
linnaelu	doc_617668397742_item	2763982	et	4	main
oli	doc_617668397742_item	2763983	et	3	main
ajal	doc_617668397742_item	2763985	et	4	main
koosnesid	doc_617668397742_item	2763990	et	4	main
kihelkonnadest	doc_617668397742_item	2763991	et	4	main
kihelkonnad	doc_617668397742_item	2763992	et	3	main
küladest	doc_617668397742_item	2763993	et	3	main
linnas	doc_617668397742_item	2763994	et	4	main
elasid	doc_617668397742_item	2763995	et	4	main
enam	doc_617668397742_item	2763996	et	4	main
rikkad	doc_617668397742_item	2763997	et	4	main
inimesed	doc_617668397742_item	2763998	et	3	main
kellel	doc_617668397742_item	2763999	et	4	main
olid	doc_617668397742_item	2764000	et	4	main
et	doc_617668397742_item	2764002	et	3	main
orjad	doc_617668397742_item	2764001	et	4	main
teha	doc_617668397742_item	2764003	et	3	main
tööd	doc_617668397742_item	2764004	et	4	main
maal	doc_617668397742_item	2764005	et	4	main
või	doc_617668397742_item	2764006	et	4	main
veel	doc_617668397742_item	2764007	et	4	main
kuskil	doc_617668397742_item	2764008	et	3	main
tarberiistad	doc_617668397742_item	2764009	et	3	main
olid	doc_617668397742_item	2764010	et	4	main
keraamilised	doc_617668397742_item	2764011	et	3	main
ja	doc_617668397742_item	2764012	et	3	main
isegi	doc_617668397742_item	2764013	et	4	main
rauast	doc_617668397742_item	2764014	et	4	main
ja	doc_617668397742_item	2764015	et	3	main
savist	doc_617668397742_item	2764016	et	4	main
n	doc_617668397742_item	2764017	et	4	main
3	doc_617668397742_item	2764018	et	2	main
miks	doc_617668397742_item	2764019	et	4	main
muistne	doc_617668397742_item	2764020	et	3	main
on	doc_617668397742_item	2764026	et	4	main
küsimus	doc_617668397742_item	2764028	et	4	main
ajalooliselt	doc_617668397742_item	2764029	et	4	main
kaotusega	doc_617668397742_item	2764024	et	4	main
nad	doc_617668397742_item	2764037	et	3	main
osanud	doc_617668397742_item	2764039	et	4	main
kujutada	doc_617668397742_item	2764040	et	3	main
ette	doc_617668397742_item	2764041	et	4	main
hõivama	doc_617668397742_item	2764045	et	3	main
vallatuma	doc_617668397742_item	2764048	et	4	main
kuidas	doc_617668397742_item	2764059	et	3	main
nii	doc_617668397742_item	2764061	et	3	main
rahu	doc_617668397742_item	2764064	et	4	main
neid	doc_617668397742_item	2764065	et	4	main
ei	doc_617668397742_item	2764066	et	4	main
olnud	doc_617668397742_item	2764067	et	4	main
hästi	doc_617668397742_item	2764068	et	3	main
välja	doc_617668397742_item	2764069	et	4	main
õpetatuid	doc_617668397742_item	2764070	et	4	main
sõdureid	doc_617668397742_item	2764071	et	3	main
see	doc_617668397742_item	2764072	et	3	main
kõik	doc_617668397742_item	2764073	et	4	main
mõjutas	doc_617668397742_item	2764074	et	3	main
vabadusvõistluse	doc_617668397742_item	2764075	et	3	main
lahinguid	doc_617668397742_item	2764076	et	4	main
eesti	doc_617668397742_item	2764077	et	4	main
sõjavägi	doc_617668397742_item	2764078	et	3	main
neid	doc_617668397742_item	2764046	et	4	main
eestlased	doc_617668397742_item	2764050	et	3	main
nad	doc_617668397742_item	2764056	et	3	main
et	doc_617668397742_item	2764062	et	3	main
juba	doc_617668397742_item	2764085	et	3	main
haaranud	doc_617668397742_item	2764086	et	4	main
kes	doc_617668397742_item	2764090	et	4	main
leedus	doc_617668397742_item	2764093	et	4	main
lätis	doc_617668397742_item	2764095	et	4	main
oli	doc_617668397742_item	2764104	et	3	main
ka	doc_617668397742_item	2764105	et	3	main
eesti	doc_617668397743_item	2764112	et	4	main
peamised	doc_617668397743_item	2764121	et	3	main
taust	doc_617668397743_item	2764133	et	4	main
kes	doc_617668397743_item	2764141	et	4	main
tahtsid	doc_617668397743_item	2764142	et	4	main
eestimaad	doc_617668397743_item	2764146	et	4	main
1227	doc_617668397743_item	2764151	et	2	main
kaotasid	doc_617668397743_item	2764156	et	4	main
lasid	doc_617668397743_item	2764157	et	4	main
sakslasi	doc_617668397743_item	2764158	et	3	main
ning	doc_617668397743_item	2764159	et	3	main
tähendas	doc_617668397743_item	2764179	et	3	main
eesti	doc_617668397743_item	2764180	et	4	main
rahvale	doc_617668397743_item	2764181	et	3	main
palju	doc_617668397743_item	2764182	et	4	main
pidid	doc_617668397743_item	2764185	et	4	main
kaudu	doc_617668397743_item	2764193	et	3	main
et	doc_617668397743_item	2764195	et	3	main
ei	doc_617668397743_item	2764197	et	4	main
rumal	doc_617668397743_item	2764199	et	3	main
rahvas	doc_617668397743_item	2764200	et	4	main
aga	doc_617668397743_item	2764201	et	3	main
sellest	doc_617668397743_item	2764208	et	4	main
majanduselu	doc_617668397743_item	2764217	et	4	main
tasapisi	doc_617668397743_item	2764219	et	3	main
ja	doc_617668397743_item	2764224	et	3	main
joodi	doc_617668397743_item	2764225	et	4	main
pidasid	doc_617668397743_item	2764229	et	4	main
ning	doc_617668397743_item	2764233	et	3	main
kaunistused	doc_617668397743_item	2764234	et	4	main
vahetus	doc_617668397743_item	2764242	et	4	main
müük	doc_617668397743_item	2764243	et	3	main
see	doc_617668397743_item	2764244	et	3	main
tähendab	doc_617668397743_item	2764245	et	3	main
kellelgil	doc_617668397743_item	2764248	et	4	main
oleks	doc_617668397743_item	2764249	et	3	main
vaja	doc_617668397743_item	2764250	et	4	main
mingit	doc_617668397743_item	2764251	et	3	main
olnud	doc_617668397743_item	2764265	et	4	main
palju	doc_617668397743_item	2764278	et	4	main
olid	doc_617668397743_item	2764281	et	4	main
1	doc_617668397743_item	2764294	et	2	main
ususid	doc_617668397743_item	2764297	et	4	main
et	doc_617668397743_item	2764298	et	3	main
maailmas	doc_617668397743_item	2764299	et	3	main
näiteks	doc_617668397743_item	2764309	et	4	main
vihmajumal	doc_617668397743_item	2764310	et	3	main
jumalat	doc_617668397743_item	2764317	et	3	main
eestlastel	doc_617668397743_item	2764319	et	4	main
jutud	doc_617668397743_item	2764323	et	3	main
või	doc_617668397743_item	2764334	et	4	main
ta	doc_617668397743_item	2764344	et	4	main
tegi	doc_617668397743_item	2764346	et	4	main
eestlastel	doc_617668397743_item	2764349	et	4	main
asju	doc_617668397743_item	2764351	et	3	main
ei	doc_617668397743_item	2764352	et	4	main
kultuuriloost	doc_617668397744_item	2764357	et	4	main
1	doc_617668397744_item	2764358	et	2	main
esimese	doc_617668397744_item	2764362	et	3	main
tegelased	doc_617668397744_item	2764365	et	3	main
panus	doc_617668397744_item	2764372	et	4	main
eesti	doc_617668397744_item	2764409	et	4	main
kultuuri	doc_617668397744_item	2764410	et	4	main
esimene	doc_617668397744_item	2764415	et	3	main
see	doc_617668397744_item	2764423	et	3	main
sel	doc_617668397744_item	2764433	et	3	main
midagi	doc_617668397744_item	2764447	et	4	main
nimelt	doc_617668397744_item	2764450	et	4	main
ilmuma	doc_617668397744_item	2764452	et	3	main
ajaleht	doc_617668397744_item	2764455	et	3	main
vahetas	doc_617668397744_item	2764474	et	3	main
muistsed	doc_617668397742_item	2764049	et	3	main
ei	doc_617668397742_item	2764051	et	4	main
olnud	doc_617668397742_item	2764052	et	4	main
ei	doc_617668397742_item	2764057	et	4	main
teha	doc_617668397742_item	2764060	et	3	main
teisi	doc_617668397742_item	2764088	et	4	main
elasid	doc_617668397742_item	2764091	et	4	main
rohkem	doc_617668397742_item	2764106	et	4	main
kui	doc_617668397742_item	2764107	et	3	main
muistselt	doc_617668397742_item	2764108	et	4	main
1	doc_617668397743_item	2764114	et	2	main
too	doc_617668397743_item	2764115	et	4	main
erinevused	doc_617668397743_item	2764122	et	4	main
majanduselu	doc_617668397743_item	2764126	et	4	main
vabadusvõitluse	doc_617668397743_item	2764131	et	3	main
rahvusvaheline	doc_617668397743_item	2764132	et	4	main
peamiselt	doc_617668397743_item	2764139	et	4	main
sakslased	doc_617668397743_item	2764140	et	3	main
maad	doc_617668397743_item	2764145	et	4	main
1208	doc_617668397743_item	2764150	et	2	main
rahvusi	doc_617668397743_item	2764161	et	3	main
eestlased	doc_617668397743_item	2764191	et	3	main
nad	doc_617668397743_item	2764196	et	3	main
ole	doc_617668397743_item	2764198	et	4	main
eest	doc_617668397743_item	2764205	et	4	main
ning	doc_617668397743_item	2764206	et	3	main
võitlema	doc_617668397743_item	2764207	et	3	main
eesti	doc_617668397743_item	2764214	et	4	main
peamiselt	doc_617668397743_item	2764222	et	4	main
söödi	doc_617668397743_item	2764223	et	4	main
koduloomi	doc_617668397743_item	2764231	et	4	main
tööristu	doc_617668397743_item	2764252	et	4	main
siis	doc_617668397743_item	2764253	et	3	main
selle	doc_617668397743_item	2764254	et	4	main
raha	doc_617668397743_item	2764261	et	4	main
tol	doc_617668397743_item	2764262	et	3	main
paremini	doc_617668397743_item	2764279	et	4	main
maad	doc_617668397743_item	2764284	et	4	main
need	doc_617668397743_item	2764286	et	3	main
elasid	doc_617668397743_item	2764288	et	4	main
mitu	doc_617668397743_item	2764301	et	4	main
jumalat	doc_617668397743_item	2764302	et	3	main
kes	doc_617668397743_item	2764303	et	4	main
kõik	doc_617668397743_item	2764320	et	4	main
palved	doc_617668397743_item	2764321	et	3	main
olid	doc_617668397743_item	2764324	et	4	main
летописи	doc_617668397743_item	2764335	et	2	main
ristiusu	doc_617668397743_item	2764336	et	3	main
propagandevust	doc_617668397743_item	2764337	et	4	main
olnud	doc_617668397743_item	2764353	et	4	main
kes	doc_617668397744_item	2764359	et	4	main
rahvusliku	doc_617668397744_item	2764363	et	3	main
meelest	doc_617668397744_item	2764367	et	4	main
liikumise	doc_617668397744_item	2764371	et	4	main
hariduselu	doc_617668397744_item	2764374	et	4	main
edendamisse	doc_617668397744_item	2764375	et	4	main
karl	doc_617668397744_item	2764411	et	4	main
oli	doc_617668397744_item	2764414	et	3	main
just	doc_617668397744_item	2764432	et	3	main
peol	doc_617668397744_item	2764434	et	4	main
tunda	doc_617668397744_item	2764436	et	3	main
end	doc_617668397744_item	2764437	et	4	main
vabana	doc_617668397744_item	2764438	et	3	main
ja	doc_617668397744_item	2764439	et	3	main
unustada	doc_617668397744_item	2764440	et	3	main
ärgipäeva	doc_617668397744_item	2764441	et	4	main
probleeme	doc_617668397744_item	2764442	et	3	main
samuti	doc_617668397744_item	2764443	et	3	main
ka	doc_617668397744_item	2764444	et	3	main
erilist	doc_617668397744_item	2764448	et	4	main
perno	doc_617668397744_item	2764453	et	4	main
andis	doc_617668397744_item	2764459	et	3	main
ja	doc_617668397744_item	2764462	et	3	main
kindlasti	doc_617668397744_item	2764464	et	3	main
mainima	doc_617668397744_item	2764466	et	3	main
jannsen	doc_617668397744_item	2764468	et	4	main
õpetaja	doc_617668397744_item	2764471	et	4	main
hiljem	doc_617668397744_item	2764472	et	3	main
ajaleht	doc_617668397744_item	2764473	et	3	main
me	doc_617668397744_item	2764484	et	4	main
tänapäevani	doc_617668397744_item	2764485	et	3	main
kes	doc_617668397742_item	2764083	et	4	main
olid	doc_617668397742_item	2764084	et	4	main
rohkem	doc_617668397742_item	2764099	et	4	main
organiseeritud	doc_617668397742_item	2764100	et	4	main
sõjataktika	doc_617668397742_item	2764101	et	4	main
ja	doc_617668397742_item	2764102	et	3	main
sõjakogemust	doc_617668397742_item	2764103	et	3	main
kontrolltöö	doc_617668397743_item	2764110	et	4	main
iseloomusta	doc_617668397743_item	2764124	et	4	main
võtsid	doc_617668397743_item	2764137	et	4	main
saada	doc_617668397743_item	2764143	et	4	main
aja	doc_617668397743_item	2764148	et	4	main
eestlased	doc_617668397743_item	2764152	et	3	main
võita	doc_617668397743_item	2764154	et	4	main
sest	doc_617668397743_item	2764183	et	4	main
võidu	doc_617668397743_item	2764192	et	4	main
enda	doc_617668397743_item	2764204	et	4	main
rahvasesse	doc_617668397743_item	2764215	et	4	main
arenes	doc_617668397743_item	2764220	et	3	main
kasvatud	doc_617668397743_item	2764227	et	4	main
toitu	doc_617668397743_item	2764228	et	4	main
kasutusel	doc_617668397743_item	2764239	et	4	main
omavahel	doc_617668397743_item	2764240	et	3	main
käis	doc_617668397743_item	2764241	et	4	main
ja	doc_617668397743_item	2764266	et	3	main
asemel	doc_617668397743_item	2764268	et	4	main
loomulikult	doc_617668397743_item	2764276	et	4	main
neil	doc_617668397743_item	2764280	et	4	main
kes	doc_617668397743_item	2764287	et	4	main
nende	doc_617668397743_item	2764289	et	4	main
maal	doc_617668397743_item	2764290	et	4	main
on	doc_617668397743_item	2764300	et	4	main
asja	doc_617668397743_item	2764307	et	4	main
eest	doc_617668397743_item	2764308	et	4	main
üht	doc_617668397743_item	2764316	et	3	main
ja	doc_617668397743_item	2764322	et	3	main
antud	doc_617668397743_item	2764326	et	4	main
ristiisa	doc_617668397743_item	2764338	et	4	main
ning	doc_617668397743_item	2764339	et	3	main
kohad	doc_617668397743_item	2764342	et	4	main
kontrolltöö	doc_617668397744_item	2764354	et	4	main
kontrolltöö	doc_617668397744_item	2764355	et	4	main
tähtsamad	doc_617668397744_item	2764361	et	4	main
ärkamisaja	doc_617668397744_item	2764364	et	3	main
sinu	doc_617668397744_item	2764366	et	3	main
miks	doc_617668397744_item	2764368	et	4	main
vennastekoguduse	doc_617668397744_item	2764370	et	3	main
eestlaste	doc_617668397744_item	2764373	et	4	main
paljud	doc_617668397744_item	2764404	et	3	main
kes	doc_617668397744_item	2764406	et	4	main
robert	doc_617668397744_item	2764412	et	4	main
kes	doc_617668397744_item	2764416	et	4	main
ja	doc_617668397744_item	2764418	et	3	main
viis	doc_617668397744_item	2764420	et	4	main
sest	doc_617668397744_item	2764431	et	4	main
tõi	doc_617668397744_item	2764446	et	3	main
tavaelusse	doc_617668397744_item	2764449	et	3	main
mis	doc_617668397744_item	2764456	et	4	main
elu	doc_617668397744_item	2764458	et	4	main
lihtsalt	doc_617668397744_item	2764479	et	4	main
ka	doc_617668397744_item	2764488	et	3	main
koidula	doc_617668397744_item	2764495	et	4	main
oli	doc_617668397744_item	2764496	et	3	main
oli	doc_617668397744_item	2764521	et	3	main
kirjutas	doc_617668397744_item	2764531	et	3	main
ja	doc_617668397744_item	2764548	et	3	main
õpetas	doc_617668397744_item	2764549	et	3	main
kunsti	doc_617668397744_item	2764551	et	4	main
selle	doc_617668397744_item	2764561	et	4	main
seda	doc_617668397744_item	2764575	et	3	main
oli	doc_617668397744_item	2764578	et	3	main
võiksid	doc_617668397744_item	2764586	et	4	main
talupojadega	doc_617668397744_item	2764592	et	3	main
oluliseks	doc_617668397744_item	2764594	et	4	main
kultuuri	doc_617668397744_item	2764628	et	4	main
ja	doc_617668397744_item	2764629	et	3	main
seltsides	doc_617668397744_item	2764637	et	4	main
võiks	doc_617668397744_item	2764644	et	4	main
parandada	doc_617668397744_item	2764645	et	3	main
ja	doc_617668397744_item	2764646	et	3	main
3	doc_617668397743_item	2764134	et	2	main
muistsest	doc_617668397743_item	2764135	et	3	main
vabadusvõitlusest	doc_617668397743_item	2764136	et	4	main
jooksul	doc_617668397743_item	2764149	et	4	main
püüdsid	doc_617668397743_item	2764153	et	4	main
nad	doc_617668397743_item	2764155	et	3	main
enda	doc_617668397743_item	2764162	et	4	main
territooriumile	doc_617668397743_item	2764163	et	3	main
aga	doc_617668397743_item	2764164	et	3	main
lõpude	doc_617668397743_item	2764165	et	4	main
lõpuks	doc_617668397743_item	2764166	et	4	main
ikkagi	doc_617668397743_item	2764167	et	4	main
võitsid	doc_617668397743_item	2764168	et	4	main
eesti	doc_617668397743_item	2764169	et	4	main
maad	doc_617668397743_item	2764170	et	4	main
tahtsid	doc_617668397743_item	2764171	et	4	main
saada	doc_617668397743_item	2764172	et	4	main
endale	doc_617668397743_item	2764173	et	4	main
ka	doc_617668397743_item	2764174	et	3	main
muud	doc_617668397743_item	2764175	et	4	main
maad	doc_617668397743_item	2764176	et	4	main
rahvad	doc_617668397743_item	2764177	et	3	main
vabadusvõitlus	doc_617668397743_item	2764178	et	3	main
oskavad	doc_617668397743_item	2764202	et	4	main
ajast	doc_617668397743_item	2764209	et	4	main
hakati	doc_617668397743_item	2764210	et	3	main
suhtlema	doc_617668397743_item	2764213	et	3	main
hiliskeskajal	doc_617668397743_item	2764218	et	3	main
mõned	doc_617668397743_item	2764230	et	3	main
tööristad	doc_617668397743_item	2764232	et	4	main
ja	doc_617668397743_item	2764235	et	3	main
potid	doc_617668397743_item	2764236	et	4	main
olid	doc_617668397743_item	2764237	et	4	main
juba	doc_617668397743_item	2764238	et	3	main
eest	doc_617668397743_item	2764255	et	4	main
oli	doc_617668397743_item	2764256	et	3	main
ajal	doc_617668397743_item	2764263	et	4	main
väärtuslikut	doc_617668397743_item	2764273	et	4	main
rikkamad	doc_617668397743_item	2764274	et	4	main
inimesed	doc_617668397743_item	2764275	et	3	main
suur	doc_617668397743_item	2764283	et	3	main
ning	doc_617668397743_item	2764285	et	3	main
ka	doc_617668397743_item	2764292	et	3	main
maksma	doc_617668397743_item	2764293	et	3	main
muistsed	doc_617668397743_item	2764295	et	3	main
olulise	doc_617668397743_item	2764306	et	4	main
eeldab	doc_617668397743_item	2764314	et	3	main
ainult	doc_617668397743_item	2764315	et	4	main
muistsetel	doc_617668397743_item	2764318	et	3	main
oma	doc_617668397743_item	2764226	et	4	main
et	doc_617668397743_item	2764246	et	3	main
kui	doc_617668397743_item	2764247	et	3	main
vaja	doc_617668397743_item	2764257	et	4	main
ka	doc_617668397743_item	2764258	et	3	main
maksta	doc_617668397743_item	2764259	et	4	main
aga	doc_617668397743_item	2764260	et	3	main
ei	doc_617668397743_item	2764264	et	4	main
selle	doc_617668397743_item	2764267	et	4	main
võiks	doc_617668397743_item	2764269	et	4	main
anda	doc_617668397743_item	2764270	et	3	main
ükskõik	doc_617668397743_item	2764271	et	3	main
mida	doc_617668397743_item	2764272	et	4	main
elasid	doc_617668397743_item	2764277	et	4	main
orjad	doc_617668397743_item	2764282	et	4	main
pidid	doc_617668397743_item	2764291	et	4	main
eestlased	doc_617668397743_item	2764296	et	3	main
vastavad	doc_617668397743_item	2764304	et	4	main
iga	doc_617668397743_item	2764305	et	4	main
või	doc_617668397743_item	2764311	et	4	main
päikejumal	doc_617668397743_item	2764312	et	4	main
ristiusu	doc_617668397743_item	2764313	et	3	main
biiblist	doc_617668397743_item	2764332	et	4	main
библия	doc_617668397743_item	2764333	et	2	main
teatud	doc_617668397743_item	2764341	et	4	main
nt	doc_617668397743_item	2764348	et	4	main
selliseid	doc_617668397743_item	2764350	et	4	main
eesti	doc_617668397744_item	2764356	et	4	main
2	doc_617668397744_item	2764369	et	2	main
koidula	doc_617668397744_item	2764402	et	4	main
ja	doc_617668397744_item	2764403	et	3	main
teised	doc_617668397744_item	2764405	et	4	main
mõjutasid	doc_617668397744_item	2764407	et	4	main
positiivselt	doc_617668397744_item	2764408	et	4	main
esimese	doc_617668397744_item	2764421	et	3	main
tõesti	doc_617668397744_item	2764425	et	3	main
eesti	doc_617668397744_item	2764428	et	4	main
rahva	doc_617668397744_item	2764429	et	3	main
tavaelus	doc_617668397744_item	2764430	et	4	main
jannsen	doc_617668397744_item	2764445	et	4	main
postimees	doc_617668397744_item	2764454	et	4	main
kirjeldas	doc_617668397744_item	2764457	et	3	main
nõu	doc_617668397744_item	2764461	et	4	main
informeeris	doc_617668397744_item	2764463	et	3	main
nime	doc_617668397744_item	2764476	et	4	main
ja	doc_617668397744_item	2764477	et	3	main
jäi	doc_617668397744_item	2764478	et	3	main
oli	doc_617668397744_item	2764487	et	3	main
kes	doc_617668397744_item	2764530	et	4	main
oli	doc_617668397744_item	2764537	et	3	main
ka	doc_617668397744_item	2764538	et	3	main
hea	doc_617668397744_item	2764539	et	4	main
arst	doc_617668397744_item	2764540	et	3	main
peamine	doc_617668397744_item	2764541	et	3	main
kunsti	doc_617668397744_item	2764542	et	4	main
õpis	doc_617668397744_item	2764547	et	3	main
peterburi	doc_617668397744_item	2764550	et	4	main
kahjuks	doc_617668397744_item	2764552	et	4	main
võtis	doc_617668397744_item	2764553	et	3	main
ta	doc_617668397744_item	2764554	et	4	main
pärast	doc_617668397744_item	2764562	et	4	main
et	doc_617668397744_item	2764563	et	3	main
elas	doc_617668397744_item	2764564	et	3	main
negatiivseteks	doc_617668397744_item	2764567	et	3	main
võiks	doc_617668397744_item	2764569	et	4	main
ajal	doc_617668397744_item	2764573	et	4	main
et	doc_617668397744_item	2764576	et	3	main
piiramatu	doc_617668397744_item	2764579	et	4	main
mõisnikud	doc_617668397744_item	2764585	et	3	main
mida	doc_617668397744_item	2764590	et	4	main
edasi	doc_617668397743_item	2764325	et	3	main
suuliselt	doc_617668397743_item	2764327	et	4	main
aga	doc_617668397743_item	2764328	et	3	main
ristiusust	doc_617668397743_item	2764329	et	3	main
võiks	doc_617668397743_item	2764330	et	4	main
lugeda	doc_617668397743_item	2764331	et	3	main
olid	doc_617668397743_item	2764340	et	4	main
kus	doc_617668397743_item	2764343	et	3	main
seda	doc_617668397743_item	2764345	et	3	main
kirik	doc_617668397743_item	2764347	et	3	main
olid	doc_617668397744_item	2764360	et	4	main
3	doc_617668397744_item	2764376	et	2	main
balti	doc_617668397744_item	2764377	et	3	main
erikorra	doc_617668397744_item	2764378	et	3	main
negatiivsed	doc_617668397744_item	2764379	et	3	main
tagajärjed	doc_617668397744_item	2764380	et	3	main
eestlaste	doc_617668397744_item	2764381	et	4	main
kultuuri-	doc_617668397744_item	2764382	et	4	main
ja	doc_617668397744_item	2764383	et	3	main
majanduselule	doc_617668397744_item	2764384	et	3	main
1	doc_617668397744_item	2764385	et	2	main
minu	doc_617668397744_item	2764386	et	3	main
arvates	doc_617668397744_item	2764387	et	4	main
tähtsamad	doc_617668397744_item	2764388	et	4	main
tegelased	doc_617668397744_item	2764389	et	3	main
esimese	doc_617668397744_item	2764390	et	3	main
rahvusliku	doc_617668397744_item	2764391	et	3	main
ärkamisaja	doc_617668397744_item	2764392	et	3	main
tegelased	doc_617668397744_item	2764393	et	3	main
olid	doc_617668397744_item	2764394	et	4	main
johan	doc_617668397744_item	2764395	et	4	main
voldemar	doc_617668397744_item	2764396	et	4	main
jannsen	doc_617668397744_item	2764397	et	4	main
karl	doc_617668397744_item	2764398	et	4	main
robert	doc_617668397744_item	2764399	et	4	main
jakobson	doc_617668397744_item	2764400	et	4	main
lydia	doc_617668397744_item	2764401	et	4	main
jakobson	doc_617668397744_item	2764413	et	4	main
organiseeris	doc_617668397744_item	2764417	et	3	main
läbi	doc_617668397744_item	2764419	et	4	main
laulupeo	doc_617668397744_item	2764422	et	4	main
oli	doc_617668397744_item	2764424	et	3	main
tähtis	doc_617668397744_item	2764426	et	4	main
moment	doc_617668397744_item	2764427	et	3	main
võiks	doc_617668397744_item	2764435	et	4	main
hakkas	doc_617668397744_item	2764451	et	3	main
häid	doc_617668397744_item	2764460	et	3	main
peaks	doc_617668397744_item	2764465	et	4	main
et	doc_617668397744_item	2764467	et	3	main
oli	doc_617668397744_item	2764469	et	3	main
ka	doc_617668397744_item	2764470	et	3	main
postimees	doc_617668397744_item	2764480	et	4	main
seda	doc_617668397744_item	2764481	et	3	main
ajalehe	doc_617668397744_item	2764482	et	3	main
loeme	doc_617668397744_item	2764483	et	3	main
see	doc_617668397744_item	2764489	et	3	main
asutas	doc_617668397744_item	2764491	et	3	main
ja	doc_617668397744_item	2764499	et	3	main
juba	doc_617668397744_item	2764500	et	3	main
selle	doc_617668397744_item	2764501	et	4	main
pärast	doc_617668397744_item	2764502	et	4	main
osales	doc_617668397744_item	2764503	et	3	main
aktiivselt	doc_617668397744_item	2764504	et	4	main
eesti	doc_617668397744_item	2764505	et	4	main
kultuuri	doc_617668397744_item	2764506	et	4	main
elus	doc_617668397744_item	2764507	et	4	main
asutas	doc_617668397744_item	2764508	et	3	main
teatri	doc_617668397744_item	2764509	et	3	main
seltsi	doc_617668397744_item	2764510	et	4	main
ning	doc_617668397744_item	2764511	et	3	main
korraldas	doc_617668397744_item	2764512	et	3	main
teatri	doc_617668397744_item	2764513	et	3	main
etendusi	doc_617668397744_item	2764514	et	4	main
ei	doc_617668397744_item	2764515	et	4	main
tohi	doc_617668397744_item	2764516	et	4	main
ka	doc_617668397744_item	2764517	et	3	main
unustada	doc_617668397744_item	2764518	et	3	main
et	doc_617668397744_item	2764519	et	3	main
ta	doc_617668397744_item	2764520	et	4	main
ka	doc_617668397744_item	2764522	et	3	main
luuletaja	doc_617668397744_item	2764524	et	4	main
tegelane	doc_617668397744_item	2764526	et	3	main
oli	doc_617668397744_item	2764527	et	3	main
eesti	doc_617668397744_item	2764533	et	4	main
mees	doc_617668397744_item	2764543	et	4	main
oli	doc_617668397744_item	2764544	et	3	main
köler	doc_617668397744_item	2764545	et	4	main
osa	doc_617668397744_item	2764556	et	4	main
eesti	doc_617668397744_item	2764557	et	4	main
kultuuri	doc_617668397744_item	2764558	et	4	main
loomisest	doc_617668397744_item	2764559	et	4	main
kaugel	doc_617668397744_item	2764565	et	4	main
tagajärjeteks	doc_617668397744_item	2764568	et	4	main
pidada	doc_617668397744_item	2764570	et	4	main
balti	doc_617668397744_item	2764571	et	3	main
erakorra	doc_617668397744_item	2764572	et	3	main
see	doc_617668397744_item	2764581	et	3	main
seda	doc_617668397744_item	2764583	et	3	main
kõik	doc_617668397744_item	2764589	et	4	main
küljeks	doc_617668397744_item	2764596	et	3	main
oma	doc_617668397744_item	2764475	et	4	main
jannsen	doc_617668397744_item	2764486	et	4	main
kes	doc_617668397744_item	2764490	et	4	main
talupoja	doc_617668397744_item	2764492	et	4	main
selts	doc_617668397744_item	2764493	et	3	main
lydia	doc_617668397744_item	2764494	et	4	main
jakobsoni	doc_617668397744_item	2764497	et	4	main
tütar	doc_617668397744_item	2764498	et	3	main
peamine	doc_617668397744_item	2764525	et	3	main
ka	doc_617668397744_item	2764528	et	3	main
kes	doc_617668397744_item	2764546	et	4	main
väikest	doc_617668397744_item	2764555	et	4	main
näiteks	doc_617668397744_item	2764574	et	4	main
võim	doc_617668397744_item	2764580	et	3	main
tähendas	doc_617668397744_item	2764582	et	3	main
et	doc_617668397744_item	2764584	et	3	main
teha	doc_617668397744_item	2764587	et	3	main
negatiivseks	doc_617668397744_item	2764595	et	3	main
usku	doc_617668397744_item	2764622	et	4	main
nt	doc_617668397744_item	2764638	et	4	main
suurepärane	doc_617668397744_item	2764523	et	4	main
kreuzwald	doc_617668397744_item	2764529	et	4	main
tuntuma	doc_617668397744_item	2764532	et	4	main
eepose	doc_617668397744_item	2764534	et	3	main
kalevipoeg	doc_617668397744_item	2764535	et	3	main
samas	doc_617668397744_item	2764536	et	4	main
ainult	doc_617668397744_item	2764560	et	4	main
3	doc_617668397744_item	2764566	et	2	main
mõisnikel	doc_617668397744_item	2764577	et	3	main
üks	doc_617668397744_item	2764588	et	3	main
oma	doc_617668397744_item	2764591	et	4	main
samuti	doc_617668397744_item	2764593	et	3	main
võiks	doc_617668397744_item	2764597	et	4	main
ka	doc_617668397744_item	2764599	et	3	main
seda	doc_617668397744_item	2764600	et	3	main
nimetada	doc_617668397744_item	2764598	et	3	main
et	doc_617668397744_item	2764601	et	3	main
hävitati	doc_617668397744_item	2764602	et	3	main
eesti	doc_617668397744_item	2764603	et	4	main
kultuuri	doc_617668397744_item	2764604	et	4	main
riided	doc_617668397744_item	2764605	et	3	main
luule	doc_617668397744_item	2764606	et	4	main
rahvapärimust	doc_617668397744_item	2764607	et	4	main
balti	doc_617668397744_item	2764608	et	3	main
erakord	doc_617668397744_item	2764609	et	3	main
tähendas	doc_617668397744_item	2764610	et	3	main
eesti	doc_617668397744_item	2764611	et	4	main
rahvale	doc_617668397744_item	2764612	et	3	main
õigusliku	doc_617668397744_item	2764613	et	3	main
ja	doc_617668397744_item	2764614	et	3	main
sotsiaalse	doc_617668397744_item	2764615	et	3	main
olukorra	doc_617668397744_item	2764616	et	3	main
halvenemist	doc_617668397744_item	2764617	et	4	main
samuti	doc_617668397744_item	2764618	et	3	main
oli	doc_617668397744_item	2764619	et	3	main
vastu	doc_617668397744_item	2764620	et	3	main
eesti	doc_617668397744_item	2764621	et	4	main
hariduselu	doc_617668397744_item	2764630	et	4	main
edendamisse	doc_617668397744_item	2764631	et	4	main
oli	doc_617668397744_item	2764632	et	3	main
seltside	doc_617668397744_item	2764633	et	3	main
õpetajate	doc_617668397744_item	2764639	et	4	main
paremaks	doc_617668397744_item	2764647	et	4	main
õpimist	doc_617668397744_item	2764651	et	4	main
2	doc_617668397744_item	2764623	et	2	main
vennastekoguduse	doc_617668397744_item	2764624	et	3	main
liikumise	doc_617668397744_item	2764625	et	4	main
panuseks	doc_617668397744_item	2764626	et	4	main
organiseerimine	doc_617668397744_item	2764634	et	4	main
ning	doc_617668397744_item	2764635	et	3	main
seltsis	doc_617668397744_item	2764640	et	4	main
mõeldi	doc_617668397744_item	2764641	et	3	main
õpetamist	doc_617668397744_item	2764649	et	4	main
eestlaste	doc_617668397744_item	2764627	et	4	main
nendes	doc_617668397744_item	2764636	et	4	main
välja	doc_617668397744_item	2764642	et	4	main
kuidas	doc_617668397744_item	2764643	et	3	main
muuta	doc_617668397744_item	2764648	et	4	main
ja	doc_617668397744_item	2764650	et	3	main
elus	doc_617668397747_item	2765278	et	4	main
2	doc_617668397747_item	2765282	et	2	main
kirjasõna	doc_617668397747_item	2765287	et	4	main
vene	doc_617668397747_item	2765333	et	4	main
võimud	doc_617668397747_item	2765334	et	3	main
otsustati	doc_617668397747_item	2765335	et	3	main
võtta	doc_617668397747_item	2765342	et	3	main
renti	doc_617668397747_item	2765345	et	4	main
eest	doc_617668397747_item	2765346	et	4	main
mõnedel	doc_617668397747_item	2765347	et	3	main
talupojadel	doc_617668397747_item	2765348	et	3	main
oli	doc_617668397747_item	2765349	et	3	main
majapidamisega	doc_617668397747_item	2765357	et	3	main
pärast	doc_617668397747_item	2765378	et	4	main
pärsiorjusest	doc_617668397747_item	2765379	et	4	main
kirjutada	doc_617668397747_item	2765389	et	3	main
ja	doc_617668397747_item	2765390	et	3	main
lugeda	doc_617668397747_item	2765391	et	3	main
1525	doc_617668397747_item	2765412	et	2	main
ilmus	doc_617668397747_item	2765414	et	4	main
katehisis	doc_617668397747_item	2765416	et	4	main
mis	doc_617668397747_item	2765417	et	4	main
nägi	doc_617668397747_item	2765418	et	3	main
õpik	doc_617668397747_item	2765422	et	3	main
võiksid	doc_617668397747_item	2765432	et	4	main
oma	doc_617668397747_item	2765433	et	4	main
sai	doc_617668397747_item	2765444	et	4	main
kuuest	doc_617668397747_item	2765445	et	4	main
olid	doc_617668397747_item	2765463	et	4	main
neli	doc_617668397747_item	2765464	et	3	main
teaduskonda	doc_617668397747_item	2765465	et	4	main
aastal	doc_617668397747_item	2765472	et	3	main
sai	doc_617668397747_item	2765486	et	4	main
aktiivselt	doc_617668397747_item	2765495	et	4	main
avalikust	doc_617668397747_item	2765496	et	4	main
elust	doc_617668397747_item	2765497	et	3	main
kirjutas	doc_617668397747_item	2765522	et	3	main
patriootilisi	doc_617668397747_item	2765523	et	3	main
eesti	doc_617668397747_item	2765265	et	4	main
kultuuriloost	doc_617668397747_item	2765266	et	4	main
pärisorjusest	doc_617668397747_item	2765269	et	4	main
vabastamise	doc_617668397747_item	2765270	et	4	main
kultuurpoliitilised	doc_617668397747_item	2765271	et	3	main
ja	doc_617668397747_item	2765272	et	3	main
majanduslikud	doc_617668397747_item	2765273	et	3	main
põhjused	doc_617668397747_item	2765274	et	3	main
pärast	doc_617668397747_item	2765279	et	4	main
nende	doc_617668397747_item	2765280	et	4	main
rootsiaegne	doc_617668397747_item	2765283	et	3	main
keelealased	doc_617668397747_item	2765288	et	4	main
3	doc_617668397747_item	2765290	et	2	main
rahvuslikus	doc_617668397747_item	2765296	et	4	main
algab	doc_617668397747_item	2765321	et	3	main
nendele	doc_617668397747_item	2765327	et	4	main
pärast	doc_617668397747_item	2765330	et	4	main
seda	doc_617668397747_item	2765331	et	3	main
rahvaseadustega	doc_617668397747_item	2765332	et	3	main
talupojadele	doc_617668397747_item	2765341	et	3	main
tegelesid	doc_617668397747_item	2765354	et	4	main
liikuda	doc_617668397747_item	2765377	et	3	main
seega	doc_617668397747_item	2765387	et	4	main
õppida	doc_617668397747_item	2765388	et	3	main
2	doc_617668397747_item	2765392	et	2	main
rootsiajal	doc_617668397747_item	2765393	et	3	main
kontrolltöö	doc_617668397747_item	2765263	et	4	main
muutus	doc_617668397747_item	2765276	et	4	main
vabastamist	doc_617668397747_item	2765281	et	4	main
õpikud	doc_617668397747_item	2765285	et	3	main
nende	doc_617668397747_item	2765294	et	4	main
roll	doc_617668397747_item	2765295	et	3	main
1	doc_617668397747_item	2765267	et	2	main
talupoegade	doc_617668397747_item	2765268	et	3	main
talupoegade	doc_617668397747_item	2765277	et	3	main
hariduselu	doc_617668397747_item	2765284	et	4	main
rahvavalgustuslik	doc_617668397747_item	2765286	et	3	main
et	doc_617668397747_item	2765323	et	3	main
mõistnikute	doc_617668397747_item	2765337	et	4	main
mõisad	doc_617668397747_item	2765338	et	3	main
maad	doc_617668397747_item	2765344	et	4	main
põllumajandusega	doc_617668397747_item	2765355	et	3	main
niimoodi	doc_617668397747_item	2765359	et	3	main
endale	doc_617668397747_item	2765361	et	4	main
saada	doc_617668397747_item	2765386	et	4	main
hakkas	doc_617668397747_item	2765406	et	3	main
moodustama	doc_617668397747_item	2765407	et	3	main
nagu	doc_617668397747_item	2765420	et	3	main
kiriku	doc_617668397747_item	2765421	et	3	main
keeles	doc_617668397747_item	2765434	et	4	main
jumalaga	doc_617668397747_item	2765435	et	4	main
selles	doc_617668397747_item	2765440	et	4	main
keeles	doc_617668397747_item	2765441	et	4	main
linnades	doc_617668397747_item	2765443	et	3	main
haridus	doc_617668397747_item	2765448	et	3	main
kohustuslikuks	doc_617668397747_item	2765449	et	3	main
tartu	doc_617668397747_item	2765460	et	4	main
meditsiini	doc_617668397747_item	2765467	et	4	main
jannsen	doc_617668397747_item	2765473	et	4	main
välja	doc_617668397747_item	2765476	et	4	main
eestikeelse	doc_617668397747_item	2765478	et	3	main
perno	doc_617668397747_item	2765480	et	4	main
nimelt	doc_617668397747_item	2765483	et	4	main
see	doc_617668397747_item	2765484	et	3	main
osa	doc_617668397747_item	2765498	et	4	main
luuletusi	doc_617668397747_item	2765524	et	4	main
koos	doc_617668397747_item	2765534	et	4	main
kultuurikeskustena	doc_617668397748_item	2765553	et	4	main
missugused	doc_617668397748_item	2765555	et	3	main
kultuurid	doc_617668397748_item	2765559	et	3	main
muinaseestlasteelu	doc_617668397748_item	2765561	et	4	main
oli	doc_617668397748_item	2765562	et	3	main
argikultuur	doc_617668397748_item	2765563	et	3	main
neid	doc_617668397748_item	2765572	et	4	main
õpetati	doc_617668397748_item	2765573	et	3	main
jne	doc_617668397748_item	2765577	et	4	main
pärast	doc_617668397748_item	2765585	et	4	main
argikultuur	doc_617668397748_item	2765621	et	3	main
ja	doc_617668397748_item	2765623	et	3	main
kõikide	doc_617668397748_item	2765627	et	4	main
juba	doc_617668397748_item	2765633	et	3	main
seda	doc_617668397748_item	2765634	et	3	main
edasi	doc_617668397748_item	2765635	et	3	main
anda	doc_617668397748_item	2765636	et	3	main
aga	doc_617668397748_item	2765637	et	3	main
muinaseestlaste	doc_617668397748_item	2765638	et	4	main
argikultuur	doc_617668397748_item	2765639	et	3	main
tempoga	doc_617668397748_item	2765644	et	3	main
muld	doc_617668397748_item	2765647	et	3	main
ole	doc_617668397748_item	2765649	et	4	main
olnud	doc_617668397748_item	2765651	et	4	main
väga	doc_617668397748_item	2765669	et	3	main
tüüpilisest	doc_617668397748_item	2765671	et	3	main
haridusest	doc_617668397748_item	2765673	et	4	main
vaesete	doc_617668397748_item	2765674	et	4	main
inimeste	doc_617668397748_item	2765675	et	3	main
kontrolltöö	doc_617668397747_item	2765264	et	4	main
mis	doc_617668397747_item	2765275	et	4	main
väljaanded	doc_617668397747_item	2765289	et	3	main
jannsen	doc_617668397747_item	2765291	et	4	main
ja	doc_617668397747_item	2765292	et	3	main
koidula	doc_617668397747_item	2765293	et	4	main
liikumises	doc_617668397747_item	2765297	et	4	main
1	doc_617668397747_item	2765298	et	2	main
1802	doc_617668397747_item	2765299	et	2	main
aastal	doc_617668397747_item	2765300	et	3	main
hakkas	doc_617668397747_item	2765301	et	3	main
õigus	doc_617668397747_item	2765303	et	4	main
pärsiorjuse	doc_617668397747_item	2765302	et	3	main
pehmenema	doc_617668397747_item	2765304	et	3	main
selle	doc_617668397747_item	2765305	et	4	main
peamised	doc_617668397747_item	2765306	et	3	main
põhjused	doc_617668397747_item	2765307	et	3	main
olid	doc_617668397747_item	2765308	et	4	main
valgustusliku	doc_617668397747_item	2765309	et	3	main
ja	doc_617668397747_item	2765310	et	3	main
humaniistliku	doc_617668397747_item	2765311	et	4	main
ideoloogiat	doc_617668397747_item	2765312	et	3	main
levendamine	doc_617668397747_item	2765313	et	4	main
ja	doc_617668397747_item	2765314	et	3	main
majandusliku	doc_617668397747_item	2765315	et	3	main
olukorra	doc_617668397747_item	2765316	et	3	main
halvenemine	doc_617668397747_item	2765317	et	4	main
talupoegade	doc_617668397747_item	2765318	et	3	main
pärisorjusest	doc_617668397747_item	2765319	et	4	main
vabastamine	doc_617668397747_item	2765320	et	4	main
sellest	doc_617668397747_item	2765322	et	4	main
vabastati	doc_617668397747_item	2765324	et	3	main
maata	doc_617668397747_item	2765326	et	3	main
anti	doc_617668397747_item	2765328	et	3	main
perekonnanimesid	doc_617668397747_item	2765329	et	3	main
lubada	doc_617668397747_item	2765340	et	3	main
mõisade	doc_617668397747_item	2765343	et	4	main
nad	doc_617668397747_item	2765353	et	3	main
ja	doc_617668397747_item	2765356	et	3	main
hakkasid	doc_617668397747_item	2765360	et	4	main
haridust	doc_617668397747_item	2765385	et	4	main
ideed	doc_617668397747_item	2765397	et	4	main
mille	doc_617668397747_item	2765398	et	3	main
sõnum	doc_617668397747_item	2765399	et	3	main
oli	doc_617668397747_item	2765400	et	3	main
vabadus	doc_617668397747_item	2765401	et	4	main
võrdlus	doc_617668397747_item	2765402	et	3	main
vendlus	doc_617668397747_item	2765403	et	3	main
samal	doc_617668397747_item	2765404	et	3	main
ilma	doc_617668397747_item	2765325	et	4	main
jagada	doc_617668397747_item	2765336	et	3	main
ja	doc_617668397747_item	2765339	et	3	main
oma	doc_617668397747_item	2765350	et	4	main
maatükk	doc_617668397747_item	2765351	et	3	main
kus	doc_617668397747_item	2765352	et	3	main
ning	doc_617668397747_item	2765358	et	3	main
raha	doc_617668397747_item	2765362	et	4	main
teenida	doc_617668397747_item	2765363	et	3	main
talupojadele	doc_617668397747_item	2765364	et	3	main
anti	doc_617668397747_item	2765365	et	3	main
esimese	doc_617668397747_item	2765366	et	3	main
isiku	doc_617668397747_item	2765367	et	3	main
tõendava	doc_617668397747_item	2765368	et	4	main
dokumenti	doc_617668397747_item	2765369	et	4	main
mis	doc_617668397747_item	2765370	et	4	main
andis	doc_617668397747_item	2765371	et	3	main
nendele	doc_617668397747_item	2765372	et	4	main
võimalust	doc_617668397747_item	2765373	et	3	main
vabalt	doc_617668397747_item	2765374	et	4	main
riigi	doc_617668397747_item	2765375	et	3	main
raames	doc_617668397747_item	2765376	et	4	main
vabastamist	doc_617668397747_item	2765380	et	4	main
talupojadel	doc_617668397747_item	2765381	et	3	main
tekkis	doc_617668397747_item	2765382	et	3	main
võimalus	doc_617668397747_item	2765383	et	3	main
normaalset	doc_617668397747_item	2765384	et	3	main
valgustlikud	doc_617668397747_item	2765396	et	4	main
ajal	doc_617668397747_item	2765405	et	4	main
niisugune	doc_617668397747_item	2765408	et	3	main
nagu	doc_617668397747_item	2765410	et	3	main
reformatsioon	doc_617668397747_item	2765411	et	3	main
välja	doc_617668397747_item	2765419	et	4	main
lood	doc_617668397747_item	2765426	et	4	main
vormis	doc_617668397747_item	2765428	et	4	main
selleks	doc_617668397747_item	2765429	et	4	main
et	doc_617668397747_item	2765430	et	3	main
inimesed	doc_617668397747_item	2765431	et	3	main
suhelda	doc_617668397747_item	2765436	et	4	main
vaja	doc_617668397747_item	2765439	et	4	main
haridus	doc_617668397747_item	2765451	et	3	main
toimus	doc_617668397747_item	2765452	et	3	main
ülikool	doc_617668397747_item	2765461	et	4	main
kus	doc_617668397747_item	2765462	et	3	main
teoloogia	doc_617668397747_item	2765468	et	4	main
asutas	doc_617668397747_item	2765474	et	3	main
ajalehe	doc_617668397747_item	2765479	et	3	main
postimees	doc_617668397747_item	2765481	et	4	main
just	doc_617668397747_item	2765482	et	3	main
rahvusliku	doc_617668397747_item	2765487	et	3	main
üheks	doc_617668397747_item	2765490	et	3	main
öelda	doc_617668397747_item	2765529	et	4	main
juures	doc_617668397747_item	2765539	et	4	main
2	doc_617668397748_item	2765548	et	2	main
kloostrid	doc_617668397748_item	2765549	et	3	main
keskaegse	doc_617668397748_item	2765550	et	3	main
hariduselu	doc_617668397748_item	2765551	et	4	main
ja	doc_617668397748_item	2765552	et	3	main
arheoloogilised	doc_617668397748_item	2765558	et	4	main
1	doc_617668397748_item	2765560	et	2	main
kasvatada	doc_617668397748_item	2765575	et	3	main
algusel	doc_617668397748_item	2765578	et	4	main
kasvatasid	doc_617668397748_item	2765580	et	4	main
puuvilju	doc_617668397748_item	2765582	et	3	main
teravilju	doc_617668397748_item	2765583	et	3	main
siis	doc_617668397748_item	2765584	et	3	main
saaki	doc_617668397748_item	2765587	et	4	main
kiiresti	doc_617668397747_item	2765394	et	3	main
levitasid	doc_617668397747_item	2765395	et	4	main
nn	doc_617668397747_item	2765415	et	4	main
ning	doc_617668397747_item	2765423	et	3	main
näht	doc_617668397747_item	2765409	et	3	main
aastal	doc_617668397747_item	2765413	et	3	main
jutustas	doc_617668397747_item	2765424	et	3	main
neid	doc_617668397747_item	2765437	et	4	main
saadik	doc_617668397747_item	2765447	et	4	main
ning	doc_617668397747_item	2765450	et	3	main
eesti	doc_617668397747_item	2765454	et	4	main
õigus	doc_617668397747_item	2765469	et	4	main
3	doc_617668397747_item	2765470	et	2	main
1857	doc_617668397747_item	2765471	et	2	main
ajaleht	doc_617668397747_item	2765485	et	3	main
tekkimise	doc_617668397747_item	2765489	et	4	main
see	doc_617668397747_item	2765492	et	3	main
inimesi	doc_617668397747_item	2765494	et	4	main
piibli	doc_617668397747_item	2765425	et	3	main
dialoogi	doc_617668397747_item	2765427	et	4	main
oli	doc_617668397747_item	2765438	et	3	main
õpetada	doc_617668397747_item	2765442	et	3	main
aastast	doc_617668397747_item	2765446	et	4	main
peamiselt	doc_617668397747_item	2765453	et	4	main
keeles	doc_617668397747_item	2765455	et	4	main
1632	doc_617668397747_item	2765456	et	2	main
aastal	doc_617668397747_item	2765457	et	3	main
oli	doc_617668397747_item	2765458	et	3	main
asutanud	doc_617668397747_item	2765459	et	4	main
filosoofia	doc_617668397747_item	2765466	et	4	main
andis	doc_617668397747_item	2765475	et	3	main
esimese	doc_617668397747_item	2765477	et	3	main
liikumise	doc_617668397747_item	2765488	et	4	main
põhjuseks	doc_617668397747_item	2765491	et	3	main
manitses	doc_617668397747_item	2765493	et	3	main
võtta	doc_617668397747_item	2765499	et	3	main
nimelt	doc_617668397747_item	2765500	et	4	main
sellises	doc_617668397747_item	2765501	et	4	main
ajalehes	doc_617668397747_item	2765502	et	3	main
oli	doc_617668397747_item	2765503	et	3	main
trükitud	doc_617668397747_item	2765504	et	4	main
esimeseks	doc_617668397747_item	2765505	et	3	main
väljend	doc_617668397747_item	2765506	et	3	main
eestlased	doc_617668397747_item	2765507	et	3	main
lidia	doc_617668397747_item	2765508	et	4	main
koidula	doc_617668397747_item	2765509	et	4	main
oli	doc_617668397747_item	2765510	et	3	main
jannseni	doc_617668397747_item	2765511	et	4	main
tütarlaps	doc_617668397747_item	2765512	et	4	main
tema	doc_617668397747_item	2765513	et	4	main
osales	doc_617668397747_item	2765514	et	3	main
aktiivselt	doc_617668397747_item	2765515	et	4	main
ajalehe	doc_617668397747_item	2765516	et	3	main
väljaandmisest	doc_617668397747_item	2765517	et	3	main
ja	doc_617668397747_item	2765518	et	3	main
kultuuri	doc_617668397747_item	2765519	et	4	main
elust	doc_617668397747_item	2765520	et	3	main
tema	doc_617668397747_item	2765521	et	4	main
isegi	doc_617668397747_item	2765530	et	4	main
nii	doc_617668397747_item	2765531	et	3	main
et	doc_617668397747_item	2765532	et	3	main
jannsen	doc_617668397747_item	2765533	et	4	main
kontrolltöö	doc_617668397748_item	2765541	et	4	main
1	doc_617668397748_item	2765544	et	2	main
argikultuuri	doc_617668397748_item	2765547	et	4	main
kultuurid	doc_617668397748_item	2765556	et	3	main
elumõiste	doc_617668397748_item	2765567	et	4	main
kuidas	doc_617668397748_item	2765574	et	3	main
areneb	doc_617668397748_item	2765622	et	3	main
vahel	doc_617668397748_item	2765629	et	4	main
oskavad	doc_617668397748_item	2765632	et	4	main
kiire	doc_617668397748_item	2765643	et	4	main
kunagi	doc_617668397748_item	2765650	et	3	main
väga	doc_617668397748_item	2765652	et	3	main
polnud	doc_617668397748_item	2765679	et	3	main
oli	doc_617668397748_item	2765680	et	3	main
laulda	doc_617668397748_item	2765691	et	4	main
kontrolltöö	doc_617668397748_item	2765540	et	4	main
kultuuriloost	doc_617668397748_item	2765543	et	4	main
muinaseestlaste	doc_617668397748_item	2765546	et	4	main
on	doc_617668397748_item	2765557	et	4	main
see	doc_617668397748_item	2765564	et	3	main
oli	doc_617668397748_item	2765565	et	3	main
nende	doc_617668397748_item	2765566	et	4	main
nad	doc_617668397748_item	2765579	et	3	main
nisu	doc_617668397748_item	2765581	et	4	main
nad	doc_617668397748_item	2765588	et	3	main
ei	doc_617668397748_item	2765589	et	4	main
osanud	doc_617668397748_item	2765590	et	4	main
veel	doc_617668397748_item	2765591	et	4	main
loomade	doc_617668397748_item	2765592	et	4	main
eest	doc_617668397748_item	2765593	et	4	main
hoolitseda	doc_617668397748_item	2765594	et	3	main
ja	doc_617668397748_item	2765595	et	3	main
pidid	doc_617668397748_item	2765596	et	4	main
ise	doc_617668397748_item	2765597	et	4	main
hakkama	doc_617668397748_item	2765598	et	3	main
saama	doc_617668397748_item	2765599	et	4	main
need	doc_617668397748_item	2765600	et	3	main
olid	doc_617668397748_item	2765601	et	4	main
rasked	doc_617668397748_item	2765602	et	3	main
ajad	doc_617668397748_item	2765603	et	4	main
siis	doc_617668397748_item	2765604	et	3	main
tuleb	doc_617668397748_item	2765605	et	3	main
kogemus	doc_617668397748_item	2765606	et	3	main
uued	doc_617668397748_item	2765609	et	3	main
tulevad	doc_617668397748_item	2765607	et	4	main
ka	doc_617668397748_item	2765608	et	3	main
argivahendid	doc_617668397748_item	2765610	et	3	main
uued	doc_617668397748_item	2765611	et	3	main
töövahendid	doc_617668397748_item	2765612	et	3	main
inimene	doc_617668397748_item	2765613	et	3	main
oskab	doc_617668397748_item	2765614	et	3	main
juba	doc_617668397748_item	2765615	et	3	main
loomi	doc_617668397748_item	2765616	et	4	main
pidada	doc_617668397748_item	2765617	et	4	main
hobused	doc_617668397748_item	2765618	et	4	main
lambad	doc_617668397748_item	2765619	et	3	main
tähendab	doc_617668397748_item	2765620	et	3	main
levinevad	doc_617668397748_item	2765626	et	4	main
arenenud	doc_617668397748_item	2765641	et	4	main
väga	doc_617668397748_item	2765642	et	3	main
pärast	doc_617668397748_item	2765655	et	4	main
nemad	doc_617668397748_item	2765656	et	3	main
jaoks	doc_617668397748_item	2765676	et	4	main
muud	doc_617668397748_item	2765696	et	4	main
mis	doc_617668397747_item	2765525	et	4	main
trükkiti	doc_617668397747_item	2765526	et	4	main
ajalehe	doc_617668397747_item	2765527	et	3	main
võib	doc_617668397747_item	2765528	et	3	main
koidulaga	doc_617668397747_item	2765535	et	4	main
seisisid	doc_617668397747_item	2765536	et	3	main
ärkamisaja	doc_617668397747_item	2765537	et	3	main
allika	doc_617668397747_item	2765538	et	3	main
eesti	doc_617668397748_item	2765542	et	4	main
iseloomusta	doc_617668397748_item	2765545	et	4	main
3	doc_617668397748_item	2765554	et	2	main
ja	doc_617668397748_item	2765568	et	3	main
mõte	doc_617668397748_item	2765569	et	3	main
vara	doc_617668397748_item	2765570	et	4	main
lapsepõlvest	doc_617668397748_item	2765571	et	4	main
hoolitseda	doc_617668397748_item	2765576	et	3	main
koristasid	doc_617668397748_item	2765586	et	4	main
kõik	doc_617668397748_item	2765624	et	4	main
eestlaste	doc_617668397748_item	2765628	et	4	main
et	doc_617668397748_item	2765630	et	3	main
nemad	doc_617668397748_item	2765631	et	3	main
ei	doc_617668397748_item	2765648	et	4	main
haridus	doc_617668397748_item	2765668	et	3	main
kirikus	doc_617668397748_item	2765685	et	3	main
kus	doc_617668397748_item	2765686	et	3	main
poisse	doc_617668397748_item	2765687	et	4	main
õpetati	doc_617668397748_item	2765688	et	3	main
kuidas	doc_617668397748_item	2765689	et	3	main
lugeda	doc_617668397748_item	2765690	et	3	main
ja	doc_617668397748_item	2765693	et	3	main
haridus	doc_617668397748_item	2765697	et	3	main
üldse	doc_617668397748_item	2765706	et	3	main
teenima	doc_617668397748_item	2765717	et	3	main
perekondade	doc_617668397748_item	2765718	et	3	main
kes	doc_617668397748_item	2765726	et	4	main
endale	doc_617668397748_item	2765729	et	4	main
lubada	doc_617668397748_item	2765730	et	3	main
ajalugu	doc_617668397748_item	2765737	et	4	main
keelte	doc_617668397748_item	2765738	et	3	main
õppimine	doc_617668397748_item	2765745	et	4	main
siin	doc_617668397748_item	2765759	et	4	main
kauplesid	doc_617668397748_item	2765770	et	4	main
3	doc_617668397748_item	2765774	et	2	main
need	doc_617668397748_item	2765777	et	3	main
alusel	doc_617668397748_item	2765780	et	4	main
faktid	doc_617668397748_item	2765782	et	3	main
milliseid	doc_617668397748_item	2765783	et	3	main
võib	doc_617668397748_item	2765784	et	3	main
tõestada	doc_617668397748_item	2765785	et	3	main
mitte	doc_617668397748_item	2765786	et	3	main
ka	doc_617668397748_item	2765790	et	3	main
sest	doc_617668397748_item	2765822	et	4	main
läba	doc_617668397748_item	2765826	et	4	main
jälgida	doc_617668397748_item	2765827	et	3	main
kuidas	doc_617668397748_item	2765828	et	3	main
elu	doc_617668397748_item	2765829	et	4	main
läheb	doc_617668397748_item	2765830	et	3	main
kuidas	doc_617668397748_item	2765831	et	3	main
kontrolltöö	doc_617668397749_item	2765836	et	4	main
eestlaste	doc_617668397749_item	2765850	et	4	main
kultuuri-	doc_617668397749_item	2765851	et	4	main
ja	doc_617668397749_item	2765852	et	3	main
j	doc_617668397749_item	2765859	et	4	main
tehti	doc_617668397749_item	2765871	et	3	main
kohaselt	doc_617668397749_item	2765878	et	4	main
kirjutati	doc_617668397749_item	2765907	et	3	main
rahvakalendreid	doc_617668397749_item	2765910	et	3	main
jutte	doc_617668397749_item	2765914	et	3	main
kirjutati	doc_617668397749_item	2765915	et	3	main
koraale	doc_617668397749_item	2765918	et	3	main
palju	doc_617668397749_item	2765919	et	4	main
tegi	doc_617668397749_item	2765920	et	4	main
avas	doc_617668397749_item	2765927	et	4	main
või	doc_617668397749_item	2765952	et	4	main
vähemalt	doc_617668397749_item	2765959	et	4	main
kolm	doc_617668397749_item	2765960	et	3	main
aastat	doc_617668397749_item	2765961	et	3	main
võimatu	doc_617668397749_item	2765966	et	4	main
mõnel	doc_617668397749_item	2765968	et	3	main
soost	doc_617668397749_item	2765970	et	4	main
tähtis	doc_617668397749_item	2765982	et	4	main
oskused	doc_617668397748_item	2765625	et	3	main
ei	doc_617668397748_item	2765640	et	4	main
kuna	doc_617668397748_item	2765645	et	3	main
eesti	doc_617668397748_item	2765646	et	4	main
viljakas	doc_617668397748_item	2765653	et	4	main
selle	doc_617668397748_item	2765654	et	4	main
pidid	doc_617668397748_item	2765657	et	4	main
palju	doc_617668397748_item	2765658	et	4	main
töötama	doc_617668397748_item	2765659	et	3	main
ja	doc_617668397748_item	2765660	et	3	main
pingutama	doc_617668397748_item	2765661	et	3	main
selleks	doc_617668397748_item	2765662	et	4	main
et	doc_617668397748_item	2765663	et	3	main
midagi	doc_617668397748_item	2765664	et	4	main
saavutada	doc_617668397748_item	2765665	et	3	main
2	doc_617668397748_item	2765666	et	2	main
keskaegne	doc_617668397748_item	2765667	et	3	main
erineb	doc_617668397748_item	2765670	et	3	main
ettekujutusest	doc_617668397748_item	2765672	et	4	main
haridust	doc_617668397748_item	2765678	et	4	main
maximum	doc_617668397748_item	2765682	et	4	main
koha	doc_617668397748_item	2765684	et	4	main
kirikulaule	doc_617668397748_item	2765692	et	4	main
olnud	doc_617668397748_item	2765705	et	4	main
jaoks	doc_617668397748_item	2765709	et	4	main
pidid	doc_617668397748_item	2765712	et	4	main
palju	doc_617668397748_item	2765713	et	4	main
töötama	doc_617668397748_item	2765714	et	3	main
ja	doc_617668397748_item	2765715	et	3	main
hariduse	doc_617668397748_item	2765721	et	3	main
siin	doc_617668397748_item	2765731	et	4	main
algas	doc_617668397748_item	2765732	et	3	main
õppimine	doc_617668397748_item	2765739	et	4	main
jne	doc_617668397748_item	2765746	et	4	main
haridus	doc_617668397748_item	2765747	et	3	main
muutub	doc_617668397748_item	2765748	et	3	main
jaoks	doc_617668397748_item	2765757	et	4	main
mainitakse	doc_617668397748_item	2765761	et	3	main
käisid	doc_617668397748_item	2765771	et	4	main
peaagu	doc_617668397748_item	2765677	et	4	main
3	doc_617668397748_item	2765681	et	2	main
aasta	doc_617668397748_item	2765683	et	4	main
midagi	doc_617668397748_item	2765695	et	4	main
tähendanud	doc_617668397748_item	2765701	et	4	main
see	doc_617668397748_item	2765703	et	3	main
oluline	doc_617668397748_item	2765707	et	4	main
nende	doc_617668397748_item	2765708	et	4	main
kuna	doc_617668397748_item	2765710	et	3	main
nad	doc_617668397748_item	2765711	et	3	main
huvi	doc_617668397748_item	2765720	et	4	main
kõik	doc_617668397748_item	2765694	et	4	main
nende	doc_617668397748_item	2765698	et	4	main
ei	doc_617668397748_item	2765700	et	4	main
ei	doc_617668397748_item	2765704	et	4	main
raha	doc_617668397748_item	2765716	et	4	main
jaoks	doc_617668397748_item	2765719	et	4	main
vastu	doc_617668397748_item	2765722	et	3	main
nendel	doc_617668397748_item	2765724	et	4	main
tõeline	doc_617668397748_item	2765733	et	4	main
peamiselt	doc_617668397748_item	2765740	et	4	main
see	doc_617668397748_item	2765741	et	3	main
oli	doc_617668397748_item	2765742	et	3	main
ladina	doc_617668397748_item	2765743	et	4	main
keele	doc_617668397748_item	2765744	et	4	main
on	doc_617668397748_item	2765752	et	4	main
väga	doc_617668397748_item	2765753	et	3	main
oluline	doc_617668397748_item	2765754	et	4	main
ajalooperiood	doc_617668397748_item	2765755	et	3	main
teadlaste	doc_617668397748_item	2765756	et	3	main
esmasti	doc_617668397748_item	2765760	et	4	main
elust	doc_617668397748_item	2765763	et	3	main
nad	doc_617668397748_item	2765765	et	3	main
arheoloogilised	doc_617668397748_item	2765775	et	4	main
jaoks	doc_617668397748_item	2765821	et	4	main
siit	doc_617668397748_item	2765823	et	3	main
toimuvad	doc_617668397748_item	2765834	et	4	main
hariduselu	doc_617668397749_item	2765841	et	4	main
rahvakoolid	doc_617668397749_item	2765842	et	3	main
gümnaasiumid	doc_617668397749_item	2765843	et	3	main
3	doc_617668397749_item	2765854	et	2	main
hurt	doc_617668397749_item	2765860	et	3	main
ajal	doc_617668397749_item	2765870	et	4	main
heaks	doc_617668397749_item	2765924	et	4	main
hariduse	doc_617668397749_item	2765933	et	3	main
eesti	doc_617668397749_item	2765936	et	4	main
soost	doc_617668397749_item	2765937	et	4	main
inimest	doc_617668397749_item	2765938	et	3	main
ka	doc_617668397749_item	2765946	et	3	main
gümnaasiume	doc_617668397749_item	2765947	et	3	main
rootsi	doc_617668397749_item	2765951	et	4	main
olid	doc_617668397749_item	2765957	et	4	main
ometi	doc_617668397749_item	2765964	et	3	main
eesti	doc_617668397749_item	2765969	et	4	main
poisil	doc_617668397749_item	2765971	et	3	main
näiteks	doc_617668397749_item	2765975	et	4	main
mõisas	doc_617668397749_item	2765976	et	3	main
või	doc_617668397749_item	2765977	et	4	main
kirikus	doc_617668397749_item	2765978	et	3	main
oli	doc_617668397749_item	2765986	et	3	main
rootsi	doc_617668397749_item	2766027	et	4	main
mil	doc_617668397749_item	2766029	et	4	main
siinne	doc_617668397749_item	2766030	et	3	main
balti	doc_617668397749_item	2766031	et	3	main
aadlil	doc_617668397749_item	2766032	et	3	main
oli	doc_617668397749_item	2766033	et	3	main
kõik	doc_617668397749_item	2766039	et	4	main
samad	doc_617668397749_item	2766040	et	3	main
seadused	doc_617668397749_item	2766041	et	3	main
erikord	doc_617668397749_item	2766046	et	3	main
eestisse	doc_617668397749_item	2766048	et	4	main
ii	doc_617668397749_item	2766056	et	4	main
tahtis	doc_617668397749_item	2766057	et	3	main
et	doc_617668397749_item	2766058	et	3	main
sama	doc_617668397749_item	2766063	et	4	main
kord	doc_617668397749_item	2766064	et	4	main
siiski	doc_617668397749_item	2766072	et	4	main
erinevaks	doc_617668397749_item	2766073	et	4	main
muutus	doc_617668397749_item	2766074	et	4	main
asehalduskord	doc_617668397749_item	2766075	et	3	main
domineerima	doc_617668397749_item	2766085	et	3	main
luteri	doc_617668397749_item	2766086	et	3	main
ka	doc_617668397749_item	2766089	et	3	main
õppekeelt	doc_617668397749_item	2766095	et	4	main
püsimisele	doc_617668397749_item	2766122	et	4	main
toimunud	doc_617668397749_item	2766124	et	4	main
eesti	doc_617668397749_item	2766125	et	4	main
rahva	doc_617668397749_item	2766126	et	3	main
säilis	doc_617668397749_item	2766134	et	4	main
ülikooli	doc_617668397749_item	2766151	et	4	main
teisi	doc_617668397749_item	2766171	et	4	main
haritlasi	doc_617668397749_item	2766172	et	3	main
jaoks	doc_617668397748_item	2765699	et	4	main
tegelikult	doc_617668397748_item	2765702	et	4	main
tekkis	doc_617668397748_item	2765723	et	3	main
haridus	doc_617668397748_item	2765734	et	3	main
õpetamine	doc_617668397748_item	2765735	et	4	main
huvitavamaks	doc_617668397748_item	2765749	et	4	main
kuna	doc_617668397748_item	2765758	et	3	main
perekonade	doc_617668397748_item	2765767	et	4	main
suhtest	doc_617668397748_item	2765768	et	4	main
kuidas	doc_617668397748_item	2765769	et	3	main
tööl	doc_617668397748_item	2765773	et	3	main
kultuurid	doc_617668397748_item	2765776	et	3	main
kultuurid	doc_617668397748_item	2765778	et	3	main
eesti	doc_617668397749_item	2765837	et	4	main
tagajärjed	doc_617668397749_item	2765849	et	3	main
r	doc_617668397749_item	2765856	et	4	main
tegelased	doc_617668397749_item	2765864	et	3	main
võib	doc_617668397749_item	2765866	et	3	main
öelda	doc_617668397749_item	2765867	et	4	main
et	doc_617668397749_item	2765868	et	3	main
eesti	doc_617668397749_item	2765874	et	4	main
kroonikaid	doc_617668397749_item	2765908	et	4	main
ja	doc_617668397749_item	2765912	et	3	main
ka	doc_617668397749_item	2765916	et	3	main
siinse	doc_617668397749_item	2765921	et	3	main
tartus	doc_617668397749_item	2765928	et	3	main
seminari	doc_617668397749_item	2765930	et	4	main
u	doc_617668397749_item	2765934	et	4	main
poisid	doc_617668397749_item	2765955	et	4	main
kooliharidust	doc_617668397749_item	2765962	et	4	main
varem	doc_617668397749_item	2765973	et	4	main
olnud	doc_617668397749_item	2765974	et	4	main
saada	doc_617668397749_item	2765981	et	4	main
hariduselus	doc_617668397749_item	2765985	et	4	main
hakkas	doc_617668397749_item	2766024	et	3	main
talle	doc_617668397749_item	2766036	et	4	main
ei	doc_617668397749_item	2766037	et	4	main
rootsi	doc_617668397749_item	2766043	et	4	main
katariina	doc_617668397749_item	2766055	et	4	main
kehtiks	doc_617668397749_item	2766062	et	3	main
siinsetel	doc_617668397749_item	2766083	et	4	main
saksa	doc_617668397749_item	2766092	et	4	main
muudetud	doc_617668397749_item	2766099	et	4	main
siinset	doc_617668397749_item	2766100	et	3	main
omavalitsust	doc_617668397749_item	2766101	et	3	main
inimestel	doc_617668397748_item	2765725	et	3	main
võisid	doc_617668397748_item	2765727	et	4	main
seda	doc_617668397748_item	2765728	et	3	main
jumalast	doc_617668397748_item	2765736	et	4	main
keskaegne	doc_617668397748_item	2765750	et	3	main
kultuur	doc_617668397748_item	2765751	et	3	main
eestlaste	doc_617668397748_item	2765762	et	4	main
kuidas	doc_617668397748_item	2765764	et	3	main
elasid	doc_617668397748_item	2765766	et	4	main
koolis	doc_617668397748_item	2765772	et	4	main
mille	doc_617668397748_item	2765779	et	3	main
on	doc_617668397748_item	2765781	et	4	main
suuliselt	doc_617668397748_item	2765787	et	4	main
vaid	doc_617668397748_item	2765788	et	3	main
tuua	doc_617668397748_item	2765789	et	3	main
reaalsed	doc_617668397748_item	2765791	et	3	main
tõendid	doc_617668397748_item	2765792	et	3	main
leidud	doc_617668397748_item	2765793	et	3	main
mingid	doc_617668397748_item	2765794	et	4	main
mainitused	doc_617668397748_item	2765795	et	4	main
kroonikadest	doc_617668397748_item	2765796	et	4	main
esimesed	doc_617668397748_item	2765797	et	3	main
märkmed	doc_617668397748_item	2765798	et	3	main
eestist	doc_617668397748_item	2765799	et	3	main
ilmusid	doc_617668397748_item	2765800	et	4	main
hilisrauaajas	doc_617668397748_item	2765801	et	3	main
umbes	doc_617668397748_item	2765802	et	4	main
1400	doc_617668397748_item	2765803	et	2	main
aastat	doc_617668397748_item	2765804	et	3	main
tagasi	doc_617668397748_item	2765805	et	3	main
algab	doc_617668397748_item	2765807	et	3	main
siin	doc_617668397748_item	2765806	et	4	main
eesti	doc_617668397748_item	2765808	et	4	main
arheoloogiline	doc_617668397748_item	2765809	et	4	main
kultuur	doc_617668397748_item	2765810	et	3	main
sellest	doc_617668397748_item	2765811	et	4	main
momendist	doc_617668397748_item	2765812	et	3	main
algab	doc_617668397748_item	2765813	et	3	main
selline	doc_617668397748_item	2765814	et	4	main
periood	doc_617668397748_item	2765815	et	3	main
mis	doc_617668397748_item	2765816	et	4	main
on	doc_617668397748_item	2765817	et	4	main
väga	doc_617668397748_item	2765818	et	3	main
tähtis	doc_617668397748_item	2765819	et	4	main
ajaloolaste	doc_617668397748_item	2765820	et	4	main
erinevad	doc_617668397748_item	2765832	et	4	main
protsessid	doc_617668397748_item	2765833	et	4	main
kultuuriloost	doc_617668397749_item	2765838	et	4	main
1	doc_617668397749_item	2765839	et	2	main
rootsiaegne	doc_617668397749_item	2765840	et	3	main
majanduselule	doc_617668397749_item	2765853	et	3	main
võib	doc_617668397748_item	2765824	et	3	main
juba	doc_617668397748_item	2765825	et	3	main
kontrolltöö	doc_617668397749_item	2765835	et	4	main
ülikool	doc_617668397749_item	2765844	et	4	main
2	doc_617668397749_item	2765845	et	2	main
balti	doc_617668397749_item	2765846	et	3	main
erikorra	doc_617668397749_item	2765847	et	3	main
positiivsed	doc_617668397749_item	2765848	et	3	main
c	doc_617668397749_item	2765855	et	4	main
ja	doc_617668397749_item	2765858	et	3	main
rahvusliku	doc_617668397749_item	2765861	et	3	main
tähtsamad	doc_617668397749_item	2765863	et	4	main
esimesed	doc_617668397749_item	2765872	et	3	main
harimiseks	doc_617668397749_item	2765876	et	4	main
iga	doc_617668397749_item	2765880	et	4	main
linnalaps	doc_617668397749_item	2765881	et	4	main
alates	doc_617668397749_item	2765882	et	3	main
6	doc_617668397749_item	2765883	et	2	main
eluaastast	doc_617668397749_item	2765884	et	4	main
koolis	doc_617668397749_item	2765885	et	4	main
käima	doc_617668397749_item	2765886	et	4	main
koole	doc_617668397749_item	2765887	et	4	main
rajati	doc_617668397749_item	2765888	et	3	main
ka	doc_617668397749_item	2765889	et	3	main
kihelkondadesse	doc_617668397749_item	2765890	et	3	main
koos	doc_617668397749_item	2765891	et	4	main
trükitehnika	doc_617668397749_item	2765892	et	4	main
arenemisega	doc_617668397749_item	2765893	et	4	main
suurenes	doc_617668397749_item	2765894	et	4	main
tollel	doc_617668397749_item	2765895	et	4	main
ajal	doc_617668397749_item	2765896	et	4	main
ka	doc_617668397749_item	2765897	et	3	main
eestikeelsete	doc_617668397749_item	2765898	et	4	main
kirjutiste	doc_617668397749_item	2765899	et	3	main
hulk	doc_617668397749_item	2765900	et	3	main
huvituti	doc_617668397749_item	2765901	et	4	main
eesti	doc_617668397749_item	2765902	et	4	main
ajaloost	doc_617668397749_item	2765903	et	4	main
ja	doc_617668397749_item	2765904	et	3	main
eesti	doc_617668397749_item	2765905	et	4	main
jakobson	doc_617668397749_item	2765857	et	4	main
liikumise	doc_617668397749_item	2765862	et	4	main
1	doc_617668397749_item	2765865	et	2	main
rootsi	doc_617668397749_item	2765869	et	4	main
sammud	doc_617668397749_item	2765873	et	4	main
talurahva	doc_617668397749_item	2765875	et	3	main
seaduse	doc_617668397749_item	2765877	et	3	main
pidi	doc_617668397749_item	2765879	et	4	main
keelde	doc_617668397749_item	2765906	et	4	main
samuti	doc_617668397749_item	2765909	et	3	main
rahvaluulet	doc_617668397749_item	2765911	et	3	main
lühikesi	doc_617668397749_item	2765913	et	4	main
eestikeelseid	doc_617668397749_item	2765917	et	3	main
harimiseks	doc_617668397749_item	2765923	et	4	main
forselius	doc_617668397749_item	2765926	et	4	main
õpetajate	doc_617668397749_item	2765929	et	4	main
õpetasid	doc_617668397749_item	2765943	et	4	main
linnadesse	doc_617668397749_item	2765944	et	3	main
loodi	doc_617668397749_item	2765945	et	4	main
kus	doc_617668397749_item	2765948	et	3	main
põhiliselt	doc_617668397749_item	2765949	et	4	main
kes	doc_617668397749_item	2765956	et	4	main
saanud	doc_617668397749_item	2765963	et	4	main
kirjutajaks	doc_617668397749_item	2765979	et	4	main
rootsiaegses	doc_617668397749_item	2765984	et	3	main
skytte	doc_617668397749_item	2765988	et	4	main
ta	doc_617668397749_item	2765989	et	4	main
asutas	doc_617668397749_item	2765990	et	3	main
2	doc_617668397749_item	2766021	et	2	main
ajal	doc_617668397749_item	2766028	et	4	main
eriseisus	doc_617668397749_item	2766034	et	4	main
ja	doc_617668397749_item	2766035	et	3	main
mis	doc_617668397749_item	2766042	et	4	main
jäi	doc_617668397749_item	2766047	et	3	main
peale	doc_617668397749_item	2766050	et	4	main
põhjasõda	doc_617668397749_item	2766051	et	4	main
kuigi	doc_617668397749_item	2766052	et	3	main
jäid	doc_617668397749_item	2766069	et	4	main
siinsed	doc_617668397749_item	2766070	et	3	main
alad	doc_617668397749_item	2766071	et	3	main
mõisate	doc_617668397749_item	2766077	et	3	main
jäi	doc_617668397749_item	2766082	et	3	main
ja	doc_617668397749_item	2766088	et	3	main
keel	doc_617668397749_item	2766093	et	4	main
ega	doc_617668397749_item	2766096	et	3	main
ei	doc_617668397749_item	2766098	et	4	main
ei	doc_617668397749_item	2766123	et	4	main
püsisid	doc_617668397749_item	2766130	et	4	main
intensiivsemad	doc_617668397749_item	2766131	et	4	main
sidemed	doc_617668397749_item	2766132	et	3	main
ja	doc_617668397749_item	2766133	et	3	main
ja	doc_617668397749_item	2766141	et	3	main
võsud	doc_617668397749_item	2766143	et	4	main
omandama	doc_617668397749_item	2766146	et	3	main
halle	doc_617668397749_item	2766150	et	4	main
tulles	doc_617668397749_item	2766153	et	4	main
nad	doc_617668397749_item	2766155	et	3	main
valgustusideid	doc_617668397749_item	2766156	et	3	main
kes	doc_617668397749_item	2766175	et	4	main
tihti	doc_617668397749_item	2766176	et	3	main
siinsest	doc_617668397749_item	2766177	et	3	main
kultuurist	doc_617668397749_item	2766178	et	3	main
merkel	doc_617668397749_item	2766184	et	4	main
ja	doc_617668397749_item	2766185	et	3	main
vastastena	doc_617668397749_item	2766195	et	4	main
kiirendasid	doc_617668397749_item	2766196	et	4	main
nad	doc_617668397749_item	2766197	et	3	main
ka	doc_617668397749_item	2766198	et	3	main
vabastamist	doc_617668397749_item	2766200	et	4	main
ja	doc_617668397749_item	2766204	et	3	main
harimises	doc_617668397749_item	2766212	et	4	main
valgustamises	doc_617668397749_item	2766214	et	4	main
vaimu	doc_617668397749_item	2766216	et	4	main
kahel	doc_617668397749_item	2766219	et	4	main
mehel	doc_617668397749_item	2766220	et	3	main
talurahva	doc_617668397749_item	2765922	et	3	main
forselius	doc_617668397749_item	2765925	et	4	main
kus	doc_617668397749_item	2765931	et	3	main
said	doc_617668397749_item	2765932	et	4	main
160	doc_617668397749_item	2765935	et	2	main
kes	doc_617668397749_item	2765939	et	4	main
hiljem	doc_617668397749_item	2765940	et	3	main
ka	doc_617668397749_item	2765941	et	3	main
talupojakoolis	doc_617668397749_item	2765942	et	4	main
õppisid	doc_617668397749_item	2765950	et	4	main
saksa	doc_617668397749_item	2765953	et	4	main
soost	doc_617668397749_item	2765954	et	4	main
enne	doc_617668397749_item	2765958	et	4	main
polnud	doc_617668397749_item	2765965	et	3	main
ka	doc_617668397749_item	2765967	et	3	main
kes	doc_617668397749_item	2765972	et	4	main
gümnaasiumiharidust	doc_617668397749_item	2765980	et	4	main
nimi	doc_617668397749_item	2765983	et	3	main
ka	doc_617668397749_item	2765987	et	3	main
1630	doc_617668397749_item	2765991	et	2	main
aastal	doc_617668397749_item	2765992	et	3	main
tartus	doc_617668397749_item	2765993	et	3	main
hariduse	doc_617668397749_item	2765994	et	3	main
akadeemia	doc_617668397749_item	2765995	et	4	main
ja	doc_617668397749_item	2765996	et	3	main
tema	doc_617668397749_item	2765997	et	4	main
soovitustel	doc_617668397749_item	2765998	et	4	main
lasi	doc_617668397749_item	2765999	et	4	main
aastal	doc_617668397749_item	2766001	et	3	main
1632	doc_617668397749_item	2766000	et	2	main
gustav	doc_617668397749_item	2766002	et	4	main
adolf	doc_617668397749_item	2766003	et	4	main
ii	doc_617668397749_item	2766004	et	4	main
asutada	doc_617668397749_item	2766005	et	3	main
tartusse	doc_617668397749_item	2766006	et	3	main
ülikooli	doc_617668397749_item	2766007	et	4	main
rootsi	doc_617668397749_item	2766008	et	4	main
ajal	doc_617668397749_item	2766009	et	4	main
arenes	doc_617668397749_item	2766010	et	3	main
ka	doc_617668397749_item	2766011	et	3	main
eesti	doc_617668397749_item	2766012	et	4	main
keele	doc_617668397749_item	2766013	et	4	main
grammatika	doc_617668397749_item	2766014	et	4	main
mille	doc_617668397749_item	2766015	et	3	main
kohta	doc_617668397749_item	2766016	et	4	main
avaldas	doc_617668397749_item	2766017	et	3	main
raamatu	doc_617668397749_item	2766018	et	4	main
anthon	doc_617668397749_item	2766019	et	4	main
thorttelle	doc_617668397749_item	2766020	et	4	main
balti	doc_617668397749_item	2766022	et	3	main
tekkima	doc_617668397749_item	2766025	et	3	main
riigis	doc_617668397749_item	2766044	et	3	main
erikord	doc_617668397749_item	2766023	et	3	main
juba	doc_617668397749_item	2766026	et	3	main
kehtinud	doc_617668397749_item	2766038	et	4	main
balti	doc_617668397749_item	2766045	et	3	main
kõikides	doc_617668397749_item	2766059	et	4	main
vene	doc_617668397749_item	2766060	et	4	main
kubermangudes	doc_617668397749_item	2766061	et	3	main
riigistamine	doc_617668397749_item	2766078	et	4	main
balti	doc_617668397749_item	2766080	et	3	main
aladel	doc_617668397749_item	2766084	et	3	main
usk	doc_617668397749_item	2766087	et	3	main
asjaajamiskeeleks	doc_617668397749_item	2766090	et	4	main
jäi	doc_617668397749_item	2766091	et	3	main
teostas	doc_617668397749_item	2766102	et	3	main
ikka	doc_617668397749_item	2766103	et	4	main
balti	doc_617668397749_item	2766104	et	3	main
aadel	doc_617668397749_item	2766105	et	3	main
ja	doc_617668397749_item	2766106	et	3	main
tänu	doc_617668397749_item	2766107	et	4	main
balti	doc_617668397749_item	2766108	et	3	main
aadlitele	doc_617668397749_item	2766109	et	3	main
oli	doc_617668397749_item	2766110	et	3	main
ka	doc_617668397749_item	2766111	et	3	main
kaubavahetust	doc_617668397749_item	2766112	et	4	main
läänega	doc_617668397749_item	2766113	et	3	main
teostada	doc_617668397749_item	2766115	et	3	main
võib	doc_617668397749_item	2766116	et	3	main
öelda	doc_617668397749_item	2766117	et	4	main
kergem	doc_617668397749_item	2766114	et	4	main
et	doc_617668397749_item	2766118	et	3	main
tänu	doc_617668397749_item	2766119	et	4	main
balti	doc_617668397749_item	2766120	et	3	main
erikorra	doc_617668397749_item	2766121	et	3	main
eripärane	doc_617668397749_item	2766136	et	4	main
kultuur	doc_617668397749_item	2766137	et	3	main
paljud	doc_617668397749_item	2766138	et	3	main
balti	doc_617668397749_item	2766139	et	3	main
aadlite	doc_617668397749_item	2766140	et	3	main
mõisnike	doc_617668397749_item	2766142	et	3	main
saadeti	doc_617668397749_item	2766144	et	3	main
huvituma	doc_617668397749_item	2766181	et	4	main
nii	doc_617668397749_item	2766186	et	3	main
talupoegade	doc_617668397749_item	2766199	et	3	main
pärisorjusest	doc_617668397749_item	2766201	et	4	main
hurt	doc_617668397749_item	2766203	et	3	main
ja	doc_617668397749_item	2766213	et	3	main
poliitik	doc_617668397749_item	2766234	et	3	main
tänu	doc_617668397749_item	2766235	et	4	main
temale	doc_617668397749_item	2766236	et	3	main
algas	doc_617668397749_item	2766237	et	3	main
eestis	doc_617668397749_item	2766238	et	3	main
ulatuslik	doc_617668397749_item	2766239	et	3	main
pea	doc_617668397749_item	2766248	et	4	main
arvult	doc_617668397749_item	2766251	et	3	main
me	doc_617668397749_item	2766253	et	4	main
levis	doc_617668397749_item	2766267	et	4	main
ka	doc_617668397749_item	2766273	et	3	main
sest	doc_617668397749_item	2766289	et	4	main
monarhia	doc_617668397749_item	2766293	et	4	main
läbi	doc_617668397749_item	2766295	et	4	main
omariikluse	doc_617668397749_item	2766296	et	4	main
oli	doc_617668397749_item	2766322	et	3	main
ka	doc_617668397749_item	2766049	et	3	main
valgustatud	doc_617668397749_item	2766053	et	4	main
monarh	doc_617668397749_item	2766054	et	3	main
mis	doc_617668397749_item	2766065	et	4	main
vene	doc_617668397749_item	2766066	et	4	main
riigis	doc_617668397749_item	2766067	et	3	main
siis	doc_617668397749_item	2766068	et	3	main
lõpetati	doc_617668397749_item	2766076	et	3	main
tänu	doc_617668397749_item	2766079	et	4	main
erikorrale	doc_617668397749_item	2766081	et	3	main
koolide	doc_617668397749_item	2766094	et	3	main
religiooniõpetust	doc_617668397749_item	2766097	et	3	main
venestumist	doc_617668397749_item	2766127	et	4	main
sinne	doc_617668397749_item	2766135	et	4	main
kaugemale	doc_617668397749_item	2766147	et	4	main
näiteks	doc_617668397749_item	2766149	et	4	main
tagasi	doc_617668397749_item	2766152	et	3	main
levitasid	doc_617668397749_item	2766154	et	4	main
eksida	doc_617668397749_item	2766169	et	4	main
lääne	doc_617668397749_item	2766173	et	4	main
euroopast	doc_617668397749_item	2766174	et	3	main
luce	doc_617668397749_item	2766183	et	4	main
estofiilidena	doc_617668397749_item	2766187	et	3	main
eestlastesse	doc_617668397749_item	2766188	et	4	main
uhkust	doc_617668397749_item	2766190	et	4	main
ja	doc_617668397749_item	2766191	et	3	main
vabadusmõtet	doc_617668397749_item	2766192	et	3	main
süstisid	doc_617668397749_item	2766193	et	4	main
pärisorjuse	doc_617668397749_item	2766194	et	3	main
iseteadvusetõusus	doc_617668397749_item	2766210	et	4	main
rahva	doc_617668397749_item	2766211	et	3	main
teadusemees	doc_617668397749_item	2766232	et	4	main
kui	doc_617668397749_item	2766233	et	3	main
ka	doc_617668397749_item	2766244	et	3	main
suureks	doc_617668397749_item	2766249	et	4	main
aga	doc_617668397749_item	2766252	et	3	main
võime	doc_617668397749_item	2766254	et	4	main
suureks	doc_617668397749_item	2766255	et	4	main
võib	doc_617668397749_item	2766259	et	3	main
1880	doc_617668397749_item	2766270	et	2	main
kus	doc_617668397749_item	2766276	et	3	main
oma	doc_617668397749_item	2766281	et	4	main
esindajaks	doc_617668397749_item	2766288	et	4	main
oli	doc_617668397749_item	2766292	et	3	main
kukutamise	doc_617668397749_item	2766294	et	4	main
arvas	doc_617668397749_item	2766299	et	3	main
seda	doc_617668397749_item	2766308	et	3	main
pealt	doc_617668397749_item	2766332	et	4	main
oli	doc_617668397749_item	2766333	et	3	main
jakobson	doc_617668397749_item	2766334	et	4	main
lihtne	doc_617668397749_item	2766335	et	3	main
talu	doc_617668397749_item	2766347	et	4	main
peab	doc_617668397749_item	2766348	et	4	main
kontrolltöö	doc_617668397750_item	2766351	et	4	main
kultuuriloost	doc_617668397750_item	2766353	et	4	main
2	doc_617668397750_item	2766357	et	2	main
eestlaste	doc_617668397750_item	2766371	et	4	main
eesti	doc_617668397750_item	2766381	et	4	main
viljamajandusele	doc_617668397750_item	2766422	et	3	main
nüüd	doc_617668397750_item	2766423	et	4	main
ja	doc_617668397750_item	2766428	et	3	main
peeres	doc_617668397750_item	2766434	et	4	main
isa	doc_617668397750_item	2766438	et	4	main
viis	doc_617668397750_item	2766443	et	4	main
toimusid	doc_617668397750_item	2766462	et	4	main
ohverdamised	doc_617668397750_item	2766465	et	4	main
asutused	doc_617668397750_item	2766470	et	4	main
viljamajandus	doc_617668397750_item	2766477	et	3	main
selle	doc_617668397750_item	2766492	et	4	main
ja	doc_617668397750_item	2766495	et	3	main
metalli	doc_617668397750_item	2766498	et	4	main
ehteid	doc_617668397750_item	2766499	et	3	main
loomiseks	doc_617668397750_item	2766500	et	4	main
õpikud	doc_617668397751_item	2766523	et	3	main
jannsen	doc_617668397751_item	2766529	et	4	main
ja	doc_617668397751_item	2766530	et	3	main
koidula	doc_617668397751_item	2766531	et	4	main
nende	doc_617668397751_item	2766532	et	4	main
roll	doc_617668397751_item	2766533	et	3	main
oli	doc_617668397751_item	2766541	et	3	main
vabastamine	doc_617668397751_item	2766547	et	4	main
lääne	doc_617668397749_item	2766128	et	4	main
euroopaga	doc_617668397749_item	2766129	et	3	main
haridust	doc_617668397749_item	2766145	et	4	main
euroopasse	doc_617668397749_item	2766148	et	3	main
ja	doc_617668397749_item	2766157	et	3	main
läänelikku	doc_617668397749_item	2766158	et	4	main
kultuuri	doc_617668397749_item	2766159	et	4	main
eestis	doc_617668397749_item	2766161	et	3	main
tänu	doc_617668397749_item	2766162	et	4	main
ka	doc_617668397749_item	2766160	et	3	main
saksa	doc_617668397749_item	2766163	et	4	main
keelele	doc_617668397749_item	2766164	et	4	main
said	doc_617668397749_item	2766165	et	4	main
siinsete	doc_617668397749_item	2766166	et	4	main
mõisatesse	doc_617668397749_item	2766167	et	3	main
kooliõpetajatena	doc_617668397749_item	2766168	et	3	main
ka	doc_617668397749_item	2766170	et	3	main
ja	doc_617668397749_item	2766179	et	3	main
keelest	doc_617668397749_item	2766180	et	4	main
rahvuslikku	doc_617668397749_item	2766189	et	4	main
3	doc_617668397749_item	2766202	et	2	main
jakobson	doc_617668397749_item	2766205	et	4	main
mängisid	doc_617668397749_item	2766206	et	4	main
tähtsat	doc_617668397749_item	2766207	et	3	main
siiski	doc_617668397749_item	2766221	et	4	main
eesmärgid	doc_617668397749_item	2766223	et	3	main
hurt	doc_617668397749_item	2766224	et	3	main
ja	doc_617668397749_item	2766227	et	3	main
targu	doc_617668397749_item	2766228	et	3	main
kogumine	doc_617668397749_item	2766241	et	4	main
temale	doc_617668397749_item	2766242	et	3	main
kuuluvad	doc_617668397749_item	2766243	et	4	main
me	doc_617668397749_item	2766246	et	4	main
saada	doc_617668397749_item	2766256	et	4	main
mõõduka	doc_617668397749_item	2766263	et	3	main
suuna	doc_617668397749_item	2766264	et	4	main
esindajaks	doc_617668397749_item	2766265	et	4	main
pidas	doc_617668397749_item	2766272	et	3	main
isamaakõnet	doc_617668397749_item	2766275	et	3	main
rahvast	doc_617668397749_item	2766278	et	4	main
hoidma	doc_617668397749_item	2766280	et	3	main
kultuuri	doc_617668397749_item	2766282	et	4	main
jakobsoni	doc_617668397749_item	2766283	et	4	main
peetakse	doc_617668397749_item	2766284	et	3	main
ärkamisaja	doc_617668397749_item	2766285	et	3	main
radikaalse	doc_617668397749_item	2766286	et	3	main
tema	doc_617668397749_item	2766290	et	4	main
õigemaks	doc_617668397749_item	2766300	et	4	main
teha	doc_617668397749_item	2766301	et	3	main
koostööd	doc_617668397749_item	2766302	et	4	main
vene	doc_617668397749_item	2766303	et	4	main
võimudega	doc_617668397749_item	2766304	et	3	main
ei	doc_617668397749_item	2766309	et	4	main
ka	doc_617668397749_item	2766311	et	3	main
pidas	doc_617668397749_item	2766313	et	3	main
jakobson	doc_617668397749_item	2766321	et	4	main
ka	doc_617668397749_item	2766323	et	3	main
esimese	doc_617668397749_item	2766325	et	3	main
taluperemees	doc_617668397749_item	2766336	et	4	main
ja	doc_617668397749_item	2766337	et	3	main
olema	doc_617668397749_item	2766349	et	4	main
eesti	doc_617668397750_item	2766352	et	4	main
1	doc_617668397750_item	2766354	et	2	main
rauaaeg	doc_617668397750_item	2766355	et	3	main
eestis	doc_617668397750_item	2766356	et	3	main
keskaegset	doc_617668397750_item	2766359	et	3	main
3	doc_617668397750_item	2766361	et	2	main
millal	doc_617668397750_item	2766362	et	3	main
jüriöö	doc_617668397750_item	2766364	et	4	main
ülestõus	doc_617668397750_item	2766365	et	4	main
missugune	doc_617668397750_item	2766366	et	3	main
tähtsus	doc_617668397750_item	2766367	et	4	main
ajast	doc_617668397750_item	2766379	et	4	main
kui	doc_617668397750_item	2766380	et	3	main
toimus	doc_617668397750_item	2766418	et	3	main
üleminek	doc_617668397750_item	2766419	et	3	main
anastavalt	doc_617668397750_item	2766420	et	4	main
loomakasvatusega	doc_617668397750_item	2766429	et	3	main
ka	doc_617668397750_item	2766432	et	3	main
pered	doc_617668397750_item	2766435	et	3	main
ja	doc_617668397750_item	2766457	et	3	main
nii	doc_617668397750_item	2766458	et	3	main
edasi	doc_617668397750_item	2766459	et	3	main
relve	doc_617668397750_item	2766464	et	3	main
ilmusid	doc_617668397750_item	2766467	et	4	main
uut	doc_617668397750_item	2766468	et	3	main
ehitusviisi	doc_617668397750_item	2766469	et	4	main
elamu	doc_617668397750_item	2766475	et	4	main
mis	doc_617668397750_item	2766480	et	4	main
lõppus	doc_617668397750_item	2766485	et	4	main
kasutati	doc_617668397750_item	2766493	et	4	main
rahvavalgustuslik	doc_617668397751_item	2766524	et	3	main
3	doc_617668397751_item	2766528	et	2	main
1	doc_617668397751_item	2766536	et	2	main
talupoegade	doc_617668397751_item	2766537	et	3	main
pärisorjusest	doc_617668397751_item	2766538	et	4	main
vabastamine	doc_617668397751_item	2766539	et	4	main
eestis	doc_617668397751_item	2766540	et	3	main
hakkasid	doc_617668397749_item	2766182	et	4	main
rolli	doc_617668397749_item	2766208	et	4	main
eestlase	doc_617668397749_item	2766209	et	3	main
sama	doc_617668397749_item	2766215	et	4	main
kandes	doc_617668397749_item	2766217	et	4	main
oli	doc_617668397749_item	2766218	et	3	main
erinevad	doc_617668397749_item	2766222	et	4	main
tegutses	doc_617668397749_item	2766225	et	3	main
tasa	doc_617668397749_item	2766226	et	3	main
ta	doc_617668397749_item	2766229	et	4	main
oli	doc_617668397749_item	2766230	et	3	main
rohkem	doc_617668397749_item	2766231	et	4	main
ei	doc_617668397749_item	2766247	et	4	main
teda	doc_617668397749_item	2766258	et	4	main
pidada	doc_617668397749_item	2766260	et	4	main
rahvusliku	doc_617668397749_item	2766261	et	3	main
ärkamisaja	doc_617668397749_item	2766262	et	3	main
aastatel	doc_617668397749_item	2766268	et	4	main
1860	doc_617668397749_item	2766269	et	2	main
kutsus	doc_617668397749_item	2766277	et	4	main
üles	doc_617668397749_item	2766279	et	3	main
saavutamine	doc_617668397749_item	2766297	et	4	main
samas	doc_617668397749_item	2766305	et	4	main
kui	doc_617668397749_item	2766306	et	3	main
pooldanud	doc_617668397749_item	2766310	et	4	main
kontrolltöö	doc_617668397750_item	2766350	et	4	main
kirjelda	doc_617668397750_item	2766358	et	4	main
talupojakultuuri	doc_617668397750_item	2766360	et	4	main
ülestõusul	doc_617668397750_item	2766370	et	3	main
1	doc_617668397750_item	2766375	et	2	main
rauaeg	doc_617668397750_item	2766376	et	4	main
eestis	doc_617668397750_item	2766377	et	3	main
muutus	doc_617668397750_item	2766412	et	4	main
ja	doc_617668397750_item	2766414	et	3	main
majandusest	doc_617668397750_item	2766421	et	4	main
inimesed	doc_617668397750_item	2766424	et	3	main
hakati	doc_617668397750_item	2766425	et	3	main
telegema	doc_617668397750_item	2766426	et	4	main
põllumajanduse	doc_617668397750_item	2766427	et	3	main
toimus	doc_617668397750_item	2766431	et	3	main
matti	doc_617668397750_item	2766447	et	4	main
ning	doc_617668397750_item	2766449	et	3	main
relveid	doc_617668397750_item	2766456	et	4	main
eesti	doc_617668397750_item	2766460	et	4	main
territooriumil	doc_617668397750_item	2766461	et	3	main
nüüd	doc_617668397750_item	2766471	et	4	main
hakati	doc_617668397750_item	2766472	et	3	main
kindlustama	doc_617668397750_item	2766473	et	3	main
omanduse	doc_617668397750_item	2766479	et	4	main
kasutada	doc_617668397750_item	2766488	et	3	main
väärtuslikke	doc_617668397750_item	2766497	et	3	main
rootsiaegne	doc_617668397751_item	2766521	et	3	main
rahvuslikus	doc_617668397751_item	2766534	et	4	main
vene	doc_617668397751_item	2766545	et	4	main
ärkamisajal	doc_617668397751_item	2766550	et	3	main
oli	doc_617668397751_item	2766557	et	3	main
aktuaalne	doc_617668397751_item	2766561	et	3	main
vaja	doc_617668397751_item	2766565	et	4	main
rahvuslik	doc_617668397751_item	2766621	et	3	main
hea	doc_617668397751_item	2766626	et	4	main
rootsiajaks	doc_617668397751_item	2766627	et	3	main
selle	doc_617668397751_item	2766628	et	4	main
tõus	doc_617668397751_item	2766654	et	4	main
ja	doc_617668397751_item	2766657	et	3	main
rolli	doc_617668397751_item	2766661	et	4	main
koidula	doc_617668397751_item	2766665	et	4	main
on	doc_617668397751_item	2766666	et	4	main
esimene	doc_617668397751_item	2766667	et	3	main
naise	doc_617668397751_item	2766668	et	3	main
isa	doc_617668397751_item	2766672	et	4	main
ajalehte	doc_617668397751_item	2766675	et	4	main
postimees	doc_617668397751_item	2766676	et	4	main
kus	doc_617668397751_item	2766677	et	3	main
nad	doc_617668397751_item	2766678	et	3	main
liidia	doc_617668397751_item	2766684	et	4	main
rahvas	doc_617668397751_item	2766691	et	4	main
rahvaluule	doc_617668397749_item	2766240	et	4	main
sõnad	doc_617668397749_item	2766245	et	4	main
saama	doc_617668397749_item	2766250	et	4	main
vaimult	doc_617668397749_item	2766257	et	4	main
mis	doc_617668397749_item	2766266	et	4	main
ta	doc_617668397749_item	2766271	et	4	main
mitu	doc_617668397749_item	2766274	et	4	main
suuna	doc_617668397749_item	2766287	et	4	main
eesmärgiks	doc_617668397749_item	2766291	et	3	main
ta	doc_617668397749_item	2766298	et	4	main
hurt	doc_617668397749_item	2766307	et	3	main
jakobson	doc_617668397749_item	2766312	et	4	main
mitu	doc_617668397749_item	2766314	et	4	main
kirgliku	doc_617668397749_item	2766315	et	3	main
isamaakõnet	doc_617668397749_item	2766316	et	3	main
ja	doc_617668397749_item	2766317	et	3	main
võitis	doc_617668397749_item	2766318	et	3	main
palju	doc_617668397749_item	2766319	et	4	main
poolehoidjaid	doc_617668397749_item	2766320	et	3	main
ajalehe	doc_617668397749_item	2766327	et	3	main
teise	doc_617668397749_item	2766330	et	4	main
külje	doc_617668397749_item	2766331	et	3	main
näidistalu	doc_617668397749_item	2766340	et	4	main
et	doc_617668397749_item	2766341	et	3	main
eestlasele	doc_617668397749_item	2766342	et	3	main
õpetada	doc_617668397749_item	2766343	et	3	main
milline	doc_617668397749_item	2766344	et	3	main
üks	doc_617668397749_item	2766345	et	3	main
korralik	doc_617668397749_item	2766346	et	3	main
toimus	doc_617668397750_item	2766363	et	3	main
ja	doc_617668397750_item	2766373	et	3	main
territooriumil	doc_617668397750_item	2766382	et	3	main
hakati	doc_617668397750_item	2766383	et	3	main
kasutama	doc_617668397750_item	2766384	et	3	main
rauaesemeid	doc_617668397750_item	2766385	et	3	main
tööriistu	doc_617668397750_item	2766386	et	3	main
relveid	doc_617668397750_item	2766387	et	4	main
jt	doc_617668397750_item	2766388	et	4	main
esiteks	doc_617668397750_item	2766389	et	3	main
rauast	doc_617668397750_item	2766390	et	4	main
tehtud	doc_617668397750_item	2766391	et	4	main
esemeid	doc_617668397750_item	2766392	et	3	main
toodi	doc_617668397750_item	2766393	et	4	main
teistest	doc_617668397750_item	2766394	et	4	main
riikidest	doc_617668397750_item	2766395	et	3	main
enamasti	doc_617668397750_item	2766396	et	4	main
venemaalt	doc_617668397750_item	2766397	et	3	main
pärast	doc_617668397750_item	2766398	et	4	main
seda	doc_617668397750_item	2766399	et	3	main
hakati	doc_617668397750_item	2766400	et	3	main
tooma	doc_617668397750_item	2766401	et	3	main
rauda	doc_617668397750_item	2766402	et	4	main
vahel	doc_617668397750_item	2766403	et	4	main
ja	doc_617668397750_item	2766404	et	3	main
ise	doc_617668397750_item	2766405	et	4	main
sulatama	doc_617668397750_item	2766406	et	4	main
niimoodi	doc_617668397750_item	2766407	et	3	main
täiendasid	doc_617668397750_item	2766408	et	4	main
tööriistad	doc_617668397750_item	2766409	et	3	main
ning	doc_617668397750_item	2766410	et	3	main
toimus	doc_617668397750_item	2766411	et	3	main
eesti	doc_617668397749_item	2766324	et	4	main
poliitilise	doc_617668397749_item	2766326	et	3	main
sakala	doc_617668397749_item	2766328	et	4	main
väljaandjaks	doc_617668397749_item	2766329	et	3	main
tegi	doc_617668397749_item	2766338	et	4	main
ka	doc_617668397749_item	2766339	et	3	main
on	doc_617668397750_item	2766368	et	4	main
sellel	doc_617668397750_item	2766369	et	4	main
aja-	doc_617668397750_item	2766372	et	4	main
kultuuriloos	doc_617668397750_item	2766374	et	4	main
sellest	doc_617668397750_item	2766378	et	4	main
majanduses	doc_617668397750_item	2766413	et	4	main
koju	doc_617668397750_item	2766415	et	3	main
pidamises	doc_617668397750_item	2766416	et	4	main
nimelt	doc_617668397750_item	2766417	et	4	main
rauaajal	doc_617668397750_item	2766430	et	3	main
muutis	doc_617668397750_item	2766440	et	3	main
ka	doc_617668397750_item	2766441	et	3	main
inimesi	doc_617668397750_item	2766446	et	4	main
ka	doc_617668397750_item	2766463	et	3	main
rauaajal	doc_617668397750_item	2766466	et	3	main
kuna	doc_617668397750_item	2766476	et	3	main
kaitsta	doc_617668397750_item	2766483	et	4	main
inimesed	doc_617668397750_item	2766486	et	3	main
hõbet	doc_617668397750_item	2766489	et	4	main
maksmisvahendina	doc_617668397750_item	2766490	et	3	main
peale	doc_617668397750_item	2766491	et	4	main
hõbet	doc_617668397750_item	2766494	et	4	main
muutus	doc_617668397750_item	2766433	et	4	main
jäid	doc_617668397750_item	2766436	et	4	main
patriorhaalsteks	doc_617668397750_item	2766437	et	4	main
järgi	doc_617668397750_item	2766439	et	4	main
matmise	doc_617668397750_item	2766442	et	4	main
sel	doc_617668397750_item	2766444	et	3	main
ajal	doc_617668397750_item	2766445	et	4	main
kivikirstides	doc_617668397750_item	2766448	et	3	main
panti	doc_617668397750_item	2766450	et	4	main
kirstidesse	doc_617668397750_item	2766451	et	3	main
omaniku	doc_617668397750_item	2766452	et	3	main
erinevaid	doc_617668397750_item	2766453	et	4	main
esemeid	doc_617668397750_item	2766454	et	3	main
tööriistu	doc_617668397750_item	2766455	et	3	main
oma	doc_617668397750_item	2766474	et	4	main
tekkitas	doc_617668397750_item	2766478	et	4	main
oli	doc_617668397750_item	2766481	et	3	main
vaja	doc_617668397750_item	2766482	et	4	main
rauaaja	doc_617668397750_item	2766484	et	3	main
õppisid	doc_617668397750_item	2766487	et	4	main
teisi	doc_617668397750_item	2766496	et	4	main
kontrolltöö	doc_617668397751_item	2766501	et	4	main
kontrolltöö	doc_617668397751_item	2766502	et	4	main
eesti	doc_617668397751_item	2766503	et	4	main
kultuuriloost	doc_617668397751_item	2766504	et	4	main
1	doc_617668397751_item	2766505	et	2	main
talupoegade	doc_617668397751_item	2766506	et	3	main
pärisorjusest	doc_617668397751_item	2766507	et	4	main
vabastamise	doc_617668397751_item	2766508	et	4	main
kultuurpoliitilised	doc_617668397751_item	2766509	et	3	main
ja	doc_617668397751_item	2766510	et	3	main
majanduslikud	doc_617668397751_item	2766511	et	3	main
põhjused	doc_617668397751_item	2766512	et	3	main
mis	doc_617668397751_item	2766513	et	4	main
muutus	doc_617668397751_item	2766514	et	4	main
talupoegade	doc_617668397751_item	2766515	et	3	main
elus	doc_617668397751_item	2766516	et	4	main
pärast	doc_617668397751_item	2766517	et	4	main
nende	doc_617668397751_item	2766518	et	4	main
vabastamist	doc_617668397751_item	2766519	et	4	main
2	doc_617668397751_item	2766520	et	2	main
hariduselu	doc_617668397751_item	2766522	et	4	main
keelealased	doc_617668397751_item	2766526	et	4	main
liikumises	doc_617668397751_item	2766535	et	4	main
varem	doc_617668397751_item	2766542	et	4	main
talupoegade	doc_617668397751_item	2766546	et	3	main
toimus	doc_617668397751_item	2766549	et	3	main
riigis	doc_617668397751_item	2766552	et	3	main
see	doc_617668397751_item	2766559	et	3	main
ja	doc_617668397751_item	2766562	et	3	main
vabalt	doc_617668397751_item	2766573	et	4	main
mineviku	doc_617668397751_item	2766599	et	3	main
vastu	doc_617668397751_item	2766602	et	3	main
kinnitas	doc_617668397751_item	2766604	et	3	main
mitte	doc_617668397751_item	2766612	et	3	main
on	doc_617668397751_item	2766615	et	4	main
riiklik	doc_617668397751_item	2766618	et	3	main
kuuluvus	doc_617668397751_item	2766619	et	4	main
vaid	doc_617668397751_item	2766620	et	3	main
kirjasõna	doc_617668397751_item	2766525	et	4	main
väljaanded	doc_617668397751_item	2766527	et	3	main
kui	doc_617668397751_item	2766543	et	3	main
pärisorjusest	doc_617668397751_item	2766548	et	4	main
1861	doc_617668397751_item	2766551	et	2	main
oli	doc_617668397751_item	2766553	et	3	main
ka	doc_617668397751_item	2766556	et	3	main
midagi	doc_617668397751_item	2766563	et	4	main
pärast	doc_617668397751_item	2766567	et	4	main
vabastamist	doc_617668397751_item	2766569	et	4	main
liikuda	doc_617668397751_item	2766574	et	3	main
liikumisvabadus	doc_617668397751_item	2766575	et	4	main
toimus	doc_617668397751_item	2766576	et	3	main
passikorraldus	doc_617668397751_item	2766577	et	3	main
ka	doc_617668397751_item	2766578	et	3	main
ärkamisajal	doc_617668397751_item	2766579	et	3	main
mis	doc_617668397751_item	2766580	et	4	main
andis	doc_617668397751_item	2766581	et	3	main
talupoegade	doc_617668397751_item	2766582	et	3	main
esimese	doc_617668397751_item	2766583	et	3	main
isikut	doc_617668397751_item	2766584	et	3	main
kodumendi	doc_617668397751_item	2766586	et	4	main
tõendava	doc_617668397751_item	2766585	et	4	main
vasttärganud	doc_617668397751_item	2766587	et	3	main
rahvuslus	doc_617668397751_item	2766588	et	4	main
tekkis	doc_617668397751_item	2766589	et	3	main
mõiste	doc_617668397751_item	2766590	et	4	main
üle	doc_617668397751_item	2766591	et	3	main
ehitada	doc_617668397751_item	2766592	et	3	main
oma	doc_617668397751_item	2766593	et	4	main
rahvast	doc_617668397751_item	2766594	et	4	main
hakkasid	doc_617668397751_item	2766595	et	4	main
huvi	doc_617668397751_item	2766596	et	4	main
tundma	doc_617668397751_item	2766597	et	3	main
venemaal	doc_617668397751_item	2766544	et	4	main
majanduskriis	doc_617668397751_item	2766554	et	3	main
kriis	doc_617668397751_item	2766558	et	3	main
polnud	doc_617668397751_item	2766560	et	3	main
vahetada	doc_617668397751_item	2766566	et	3	main
et	doc_617668397751_item	2766605	et	3	main
missioon	doc_617668397751_item	2766609	et	3	main
poliitiline	doc_617668397751_item	2766613	et	3	main
ja	doc_617668397751_item	2766614	et	3	main
tähtis	doc_617668397751_item	2766616	et	4	main
mitte	doc_617668397751_item	2766617	et	3	main
2	doc_617668397751_item	2766623	et	2	main
eesti	doc_617668397751_item	2766639	et	4	main
kiriklikud	doc_617668397751_item	2766642	et	4	main
keelne	doc_617668397751_item	2766647	et	3	main
grammatika	doc_617668397751_item	2766648	et	4	main
algkooliõpikud	doc_617668397751_item	2766649	et	3	main
jannsen	doc_617668397751_item	2766656	et	4	main
koidula	doc_617668397751_item	2766658	et	4	main
mängisid	doc_617668397751_item	2766659	et	4	main
suurt	doc_617668397751_item	2766660	et	3	main
liidia	doc_617668397751_item	2766671	et	4	main
rajas	doc_617668397751_item	2766674	et	4	main
poole	doc_617668397751_item	2766687	et	4	main
ta	doc_617668397751_item	2766688	et	4	main
äratab	doc_617668397751_item	2766689	et	3	main
tema	doc_617668397751_item	2766694	et	4	main
teoseid	doc_617668397751_item	2766695	et	3	main
postimees	doc_617668397751_item	2766697	et	4	main
nad	doc_617668397751_item	2766703	et	3	main
ii	doc_617668397753_item	2766916	et	4	main
pärisorjusesüsteemis	doc_617668397751_item	2766555	et	3	main
oli	doc_617668397751_item	2766564	et	3	main
talupoegade	doc_617668397751_item	2766568	et	3	main
nendel	doc_617668397751_item	2766570	et	4	main
oli	doc_617668397751_item	2766571	et	3	main
õigus	doc_617668397751_item	2766572	et	4	main
rahva	doc_617668397751_item	2766598	et	3	main
kultuuripärandi	doc_617668397751_item	2766601	et	3	main
jhurt	doc_617668397751_item	2766603	et	4	main
eestlaste	doc_617668397751_item	2766606	et	4	main
kui	doc_617668397751_item	2766607	et	3	main
väikerahva	doc_617668397751_item	2766608	et	3	main
on	doc_617668397751_item	2766610	et	4	main
pärast	doc_617668397751_item	2766629	et	4	main
sõjad	doc_617668397751_item	2766632	et	3	main
ei	doc_617668397751_item	2766636	et	4	main
puuduta	doc_617668397751_item	2766637	et	4	main
kirjavara	doc_617668397751_item	2766641	et	4	main
rootsi	doc_617668397751_item	2766650	et	4	main
rahvahariduse	doc_617668397751_item	2766653	et	3	main
3	doc_617668397751_item	2766655	et	2	main
luuletaja	doc_617668397751_item	2766669	et	4	main
koos	doc_617668397751_item	2766679	et	4	main
oma	doc_617668397751_item	2766685	et	4	main
rahva	doc_617668397751_item	2766686	et	3	main
rahvuslikku	doc_617668397751_item	2766692	et	4	main
ajalehes	doc_617668397751_item	2766698	et	3	main
oma	doc_617668397751_item	2766701	et	4	main
eesti	doc_617668397753_item	2766904	et	4	main
1	doc_617668397753_item	2766906	et	2	main
aasta	doc_617668397753_item	2766908	et	4	main
revolutsioon	doc_617668397753_item	2766909	et	3	main
keel	doc_617668397753_item	2766919	et	4	main
arengut	doc_617668397753_item	2766934	et	3	main
palju	doc_617668397753_item	2766944	et	4	main
kuna	doc_617668397753_item	2766945	et	3	main
algas	doc_617668397753_item	2766946	et	3	main
eestis	doc_617668397753_item	2766947	et	3	main
niisugune	doc_617668397753_item	2766948	et	3	main
orjusest	doc_617668397753_item	2766953	et	4	main
ilmusid	doc_617668397753_item	2766954	et	4	main
palju	doc_617668397753_item	2766959	et	4	main
eepose	doc_617668397753_item	2766971	et	3	main
eesti	doc_617668397753_item	2766975	et	4	main
ja	doc_617668397753_item	2766977	et	3	main
ühiskonnateadlane	doc_617668397753_item	2766978	et	3	main
ja	doc_617668397751_item	2766600	et	3	main
kultuuriline	doc_617668397751_item	2766611	et	4	main
rootsiaeg	doc_617668397751_item	2766624	et	3	main
et	doc_617668397751_item	2766630	et	3	main
35	doc_617668397751_item	2766633	et	2	main
aastat	doc_617668397751_item	2766635	et	3	main
eestit	doc_617668397751_item	2766638	et	3	main
käsiraamatud	doc_617668397751_item	2766643	et	4	main
ja	doc_617668397751_item	2766644	et	3	main
tarbeteosed	doc_617668397751_item	2766645	et	3	main
eesti	doc_617668397751_item	2766646	et	4	main
oli	doc_617668397751_item	2766652	et	3	main
rahvuslikus	doc_617668397751_item	2766662	et	4	main
liikumises	doc_617668397751_item	2766663	et	4	main
jannsen	doc_617668397751_item	2766670	et	4	main
esimesene	doc_617668397751_item	2766673	et	4	main
oma	doc_617668397751_item	2766681	et	4	main
luuletustes	doc_617668397751_item	2766682	et	4	main
pöördub	doc_617668397751_item	2766683	et	3	main
eestlaste	doc_617668397751_item	2766690	et	4	main
trükitati	doc_617668397751_item	2766696	et	3	main
koos	doc_617668397751_item	2766700	et	4	main
kontrolltöö	doc_617668397753_item	2766903	et	4	main
kultuuriloost	doc_617668397753_item	2766905	et	4	main
kultuurielu	doc_617668397753_item	2766918	et	4	main
jne	doc_617668397753_item	2766923	et	4	main
lühiülevaade	doc_617668397753_item	2766924	et	3	main
kuidas	doc_617668397753_item	2766926	et	3	main
vabastamine	doc_617668397753_item	2766930	et	4	main
2	doc_617668397753_item	2766935	et	2	main
poole	doc_617668397753_item	2766939	et	4	main
vabastati	doc_617668397753_item	2766952	et	3	main
eludesse	doc_617668397753_item	2766965	et	3	main
nagu	doc_617668397753_item	2766966	et	3	main
kalevipoeg	doc_617668397753_item	2766972	et	3	main
kirjanik	doc_617668397753_item	2766987	et	3	main
parnu	doc_617668397753_item	2766989	et	4	main
postimees	doc_617668397753_item	2766990	et	4	main
erinevaid	doc_617668397753_item	2766994	et	4	main
esimene	doc_617668397753_item	2766998	et	3	main
kus	doc_617668397753_item	2767002	et	3	main
täpselt	doc_617668397753_item	2767004	et	4	main
tallinnas	doc_617668397753_item	2767006	et	4	main
toimus	doc_617668397753_item	2767007	et	3	main
identiteet	doc_617668397751_item	2766622	et	4	main
nimetatakse	doc_617668397751_item	2766625	et	3	main
euroopa	doc_617668397751_item	2766631	et	4	main
36	doc_617668397751_item	2766634	et	2	main
keelne	doc_617668397751_item	2766640	et	3	main
ajal	doc_617668397751_item	2766651	et	4	main
liidia	doc_617668397751_item	2766664	et	4	main
töötasid	doc_617668397751_item	2766680	et	4	main
identiteeti	doc_617668397751_item	2766693	et	4	main
kus	doc_617668397751_item	2766699	et	3	main
isaga	doc_617668397751_item	2766702	et	3	main
avaldasid	doc_617668397751_item	2766704	et	4	main
eestimeelse	doc_617668397751_item	2766705	et	3	main
intelligentsi	doc_617668397751_item	2766706	et	4	main
seisukoha	doc_617668397751_item	2766707	et	4	main
kontrolltöö	doc_617668397753_item	2766902	et	4	main
1905	doc_617668397753_item	2766907	et	2	main
põhjus	doc_617668397753_item	2766910	et	4	main
ja	doc_617668397753_item	2766911	et	3	main
tagajärjed	doc_617668397753_item	2766912	et	3	main
2	doc_617668397753_item	2766913	et	2	main
19	doc_617668397753_item	2766914	et	2	main
sajandi	doc_617668397753_item	2766915	et	3	main
kirjandus	doc_617668397753_item	2766920	et	3	main
teater	doc_617668397753_item	2766922	et	3	main
mõjutas	doc_617668397753_item	2766927	et	3	main
ja	doc_617668397753_item	2766932	et	3	main
sajandi	doc_617668397753_item	2766937	et	3	main
poole	doc_617668397753_item	2766917	et	4	main
muusika	doc_617668397753_item	2766921	et	4	main
3	doc_617668397753_item	2766925	et	2	main
talupoegade	doc_617668397753_item	2766928	et	3	main
pärsiorjusest	doc_617668397753_item	2766929	et	4	main
tööstuse	doc_617668397753_item	2766933	et	3	main
19	doc_617668397753_item	2766936	et	2	main
uusi	doc_617668397753_item	2766960	et	3	main
sündmusi	doc_617668397753_item	2766961	et	3	main
ja	doc_617668397753_item	2766962	et	3	main
arendamisi	doc_617668397753_item	2766963	et	4	main
kirjutas	doc_617668397753_item	2766969	et	3	main
vanemuise	doc_617668397753_item	2766981	et	4	main
sakala	doc_617668397753_item	2766984	et	4	main
jannsen	doc_617668397753_item	2766988	et	4	main
spordiselts	doc_617668397753_item	2766997	et	3	main
ei	doc_617668397753_item	2767000	et	4	main
palju	doc_617668397753_item	2767029	et	4	main
eestlasi	doc_617668397753_item	2767030	et	3	main
sibirisse	doc_617668397753_item	2767031	et	4	main
balti	doc_617668397753_item	2767032	et	3	main
saksa	doc_617668397753_item	2767033	et	4	main
revolutsiooni	doc_617668397753_item	2767037	et	4	main
avati	doc_617668397753_item	2767039	et	3	main
ilmus	doc_617668397753_item	2767043	et	4	main
ajalehti	doc_617668397753_item	2767045	et	4	main
ja	doc_617668397753_item	2767046	et	3	main
algusel	doc_617668397753_item	2767055	et	4	main
kõigil	doc_617668397753_item	2767056	et	4	main
3	doc_617668397753_item	2767060	et	2	main
talupoegade	doc_617668397753_item	2767064	et	3	main
aga	doc_617668397753_item	2767072	et	3	main
ja	doc_617668397753_item	2767087	et	3	main
ne	doc_617668397753_item	2767088	et	4	main
ja	doc_617668397753_item	2767092	et	3	main
ehitamine	doc_617668397753_item	2767102	et	4	main
erinevad	doc_617668397753_item	2767106	et	4	main
metalli	doc_617668397753_item	2767108	et	4	main
riie	doc_617668397753_item	2767111	et	3	main
linnastumist	doc_617668397753_item	2766931	et	4	main
ii	doc_617668397753_item	2766938	et	4	main
on	doc_617668397753_item	2766941	et	4	main
võimalik	doc_617668397753_item	2766942	et	3	main
öelda	doc_617668397753_item	2766943	et	4	main
talupogade	doc_617668397753_item	2766951	et	4	main
eesti	doc_617668397753_item	2766964	et	4	main
kuulsa	doc_617668397753_item	2766970	et	3	main
jakob	doc_617668397753_item	2766973	et	4	main
rajaja	doc_617668397753_item	2766982	et	4	main
pedagoog	doc_617668397753_item	2766986	et	3	main
teataja	doc_617668397753_item	2766991	et	4	main
oli	doc_617668397753_item	2766992	et	3	main
selts	doc_617668397753_item	2766995	et	3	main
laulupidu	doc_617668397753_item	2766999	et	4	main
lkoidula	doc_617668397753_item	2767008	et	4	main
mu	doc_617668397753_item	2767009	et	3	main
isamaa	doc_617668397753_item	2767010	et	4	main
on	doc_617668397753_item	2767011	et	4	main
minu	doc_617668397753_item	2767012	et	3	main
arm	doc_617668397753_item	2767013	et	3	main
1	doc_617668397753_item	2767014	et	2	main
revolutsiooni	doc_617668397753_item	2767015	et	4	main
põhjus	doc_617668397753_item	2767016	et	4	main
sotsiaal-demok	doc_617668397753_item	2767017	et	4	main
ideed	doc_617668397753_item	2767018	et	4	main
eestlastele	doc_617668397753_item	2767019	et	4	main
ei	doc_617668397753_item	2767020	et	4	main
et	doc_617668397753_item	2767022	et	3	main
oli	doc_617668397753_item	2767024	et	3	main
tulid	doc_617668397753_item	2767025	et	4	main
reziim	doc_617668397753_item	2767034	et	4	main
1905	doc_617668397753_item	2767035	et	2	main
ajakirju	doc_617668397753_item	2767047	et	4	main
vaatamata	doc_617668397753_item	2767048	et	4	main
sajandi	doc_617668397753_item	2767054	et	3	main
eluandel	doc_617668397753_item	2767057	et	3	main
1816	doc_617668397753_item	2767061	et	2	main
pärast	doc_617668397753_item	2767071	et	4	main
nad	doc_617668397753_item	2767073	et	3	main
seda	doc_617668397753_item	2767075	et	3	main
ilmus	doc_617668397753_item	2767081	et	4	main
dokument	doc_617668397753_item	2767099	et	3	main
tehased	doc_617668397753_item	2767107	et	3	main
algas	doc_617668397753_item	2767121	et	3	main
mitte	doc_617668397753_item	2767131	et	3	main
vene	doc_617668397753_item	2767132	et	4	main
osa	doc_617668397753_item	2767135	et	4	main
arendama	doc_617668397753_item	2767138	et	3	main
tõeline	doc_617668397753_item	2767140	et	4	main
linn	doc_617668397753_item	2767142	et	3	main
eesti	doc_617668397754_item	2767147	et	4	main
kultuuriloost	doc_617668397754_item	2767148	et	4	main
1	doc_617668397754_item	2767149	et	2	main
2	doc_617668397754_item	2767153	et	2	main
missugused	doc_617668397754_item	2767160	et	3	main
mojutasid	doc_617668397754_item	2767174	et	4	main
tahtsid	doc_617668397754_item	2767186	et	4	main
sest	doc_617668397754_item	2767198	et	4	main
huvi	doc_617668397754_item	2767206	et	4	main
teda	doc_617668397754_item	2767207	et	4	main
vastu	doc_617668397754_item	2767208	et	3	main
oma	doc_617668397754_item	2767215	et	4	main
kultuuri	doc_617668397754_item	2767216	et	4	main
ja	doc_617668397754_item	2767217	et	3	main
tänapäevani	doc_617668397754_item	2767220	et	3	main
on	doc_617668397754_item	2767222	et	4	main
et	doc_617668397754_item	2767229	et	3	main
ei	doc_617668397754_item	2767242	et	4	main
kultuurielust	doc_617668397753_item	2766940	et	3	main
kultuuri	doc_617668397753_item	2766949	et	4	main
tõustmine	doc_617668397753_item	2766950	et	4	main
kuulsad	doc_617668397753_item	2766955	et	3	main
inimesed	doc_617668397753_item	2766956	et	3	main
kes	doc_617668397753_item	2766957	et	4	main
tõi	doc_617668397753_item	2766958	et	3	main
kreutswald	doc_617668397753_item	2766967	et	4	main
kes	doc_617668397753_item	2766968	et	4	main
hurt	doc_617668397753_item	2766974	et	3	main
rahvaluule	doc_617668397753_item	2766976	et	4	main
teataja	doc_617668397753_item	2766985	et	4	main
palju	doc_617668397753_item	2766993	et	4	main
lauluselts	doc_617668397753_item	2766996	et	3	main
aga	doc_617668397753_item	2767003	et	3	main
mitte	doc_617668397753_item	2767005	et	3	main
nendel	doc_617668397753_item	2767023	et	4	main
järel	doc_617668397753_item	2767038	et	4	main
emakeelseid	doc_617668397753_item	2767041	et	3	main
xx	doc_617668397753_item	2767053	et	4	main
aastal	doc_617668397753_item	2767062	et	3	main
pärisorjusest	doc_617668397753_item	2767065	et	4	main
alguses	doc_617668397753_item	2767068	et	4	main
osta	doc_617668397753_item	2767077	et	4	main
aktiivne	doc_617668397753_item	2767079	et	3	main
talupojad	doc_617668397753_item	2767089	et	4	main
said	doc_617668397753_item	2767090	et	4	main
passikorraldus	doc_617668397753_item	2767094	et	3	main
tõendav	doc_617668397753_item	2767098	et	4	main
hakkas	doc_617668397753_item	2767100	et	3	main
raudteede	doc_617668397753_item	2767101	et	3	main
tallinn	doc_617668397753_item	2767104	et	4	main
paldiski	doc_617668397753_item	2767105	et	4	main
tekstiilitööstus	doc_617668397753_item	2767110	et	3	main
eesti	doc_617668397753_item	2767122	et	4	main
rahva	doc_617668397753_item	2767123	et	3	main
või	doc_617668397753_item	2767133	et	4	main
muinaseestlaste	doc_617668397754_item	2767151	et	4	main
eestimaa	doc_617668397754_item	2767166	et	4	main
selline	doc_617668397754_item	2767169	et	4	main
idast	doc_617668397754_item	2767183	et	4	main
venelased	doc_617668397754_item	2767184	et	3	main
kõik	doc_617668397754_item	2767185	et	4	main
ja	doc_617668397754_item	2767190	et	3	main
eestimaa	doc_617668397754_item	2767192	et	4	main
eestis	doc_617668397754_item	2767221	et	3	main
12	doc_617668397754_item	2767224	et	2	main
mis	doc_617668397754_item	2767227	et	4	main
ole	doc_617668397754_item	2767243	et	4	main
kammikultuur	doc_617668397754_item	2767253	et	4	main
ja	doc_617668397754_item	2767254	et	3	main
leidsid	doc_617668397754_item	2767259	et	4	main
on	doc_617668397754_item	2767261	et	4	main
võimalik	doc_617668397754_item	2767262	et	3	main
näha	doc_617668397754_item	2767263	et	3	main
ka	doc_617668397754_item	2767264	et	3	main
tänapäeval	doc_617668397754_item	2767265	et	3	main
esed	doc_617668397754_item	2767294	et	4	main
keskaegne	doc_617668397754_item	2767296	et	3	main
oli	doc_617668397754_item	2767298	et	3	main
mitte	doc_617668397754_item	2767299	et	3	main
sest	doc_617668397754_item	2767302	et	4	main
õppimine	doc_617668397754_item	2767313	et	4	main
ikkagi	doc_617668397754_item	2767314	et	4	main
töötasid	doc_617668397754_item	2767329	et	4	main
seal	doc_617668397754_item	2767333	et	4	main
ainult	doc_617668397754_item	2767336	et	4	main
ka	doc_617668397754_item	2767342	et	3	main
seda	doc_617668397754_item	2767345	et	3	main
kaua	doc_617668397754_item	2767348	et	3	main
olid	doc_617668397754_item	2767357	et	4	main
valmis	doc_617668397754_item	2767358	et	4	main
riiki	doc_617668397754_item	2767363	et	4	main
muinaseestlaste	doc_617668397754_item	2767365	et	4	main
ei	doc_617668397754_item	2767378	et	4	main
rukist	doc_617668397754_item	2767387	et	3	main
inimesed	doc_617668397754_item	2767424	et	3	main
запрягать	doc_617668397754_item	2767426	et	2	main
loomi	doc_617668397754_item	2767427	et	4	main
et	doc_617668397754_item	2767428	et	3	main
nad	doc_617668397754_item	2767429	et	3	main
keeleteadlane	doc_617668397753_item	2766979	et	3	main
jakobson	doc_617668397753_item	2766980	et	4	main
ja	doc_617668397753_item	2766983	et	3	main
mäleta	doc_617668397753_item	2767001	et	4	main
meeldinud	doc_617668397753_item	2767021	et	4	main
venelased	doc_617668397753_item	2767026	et	3	main
ja	doc_617668397753_item	2767027	et	3	main
saadati	doc_617668397753_item	2767028	et	4	main
palju	doc_617668397753_item	2767044	et	4	main
arenes	doc_617668397753_item	2767051	et	3	main
eesti	doc_617668397753_item	2767052	et	4	main
edasi	doc_617668397753_item	2767059	et	3	main
vabastamine	doc_617668397753_item	2767066	et	4	main
eestimaal	doc_617668397753_item	2767067	et	4	main
said	doc_617668397753_item	2767074	et	4	main
algas	doc_617668397753_item	2767093	et	3	main
ilmus	doc_617668397753_item	2767095	et	4	main
esiku	doc_617668397753_item	2767097	et	3	main
rahvas	doc_617668397753_item	2767130	et	4	main
eesti	doc_617668397753_item	2767136	et	4	main
nagu	doc_617668397753_item	2767139	et	3	main
euroopa	doc_617668397753_item	2767141	et	4	main
euroopa	doc_617668397753_item	2767143	et	4	main
3	doc_617668397754_item	2767159	et	2	main
asukoht	doc_617668397754_item	2767167	et	3	main
poolt	doc_617668397754_item	2767172	et	4	main
teda	doc_617668397754_item	2767173	et	4	main
taanlased	doc_617668397754_item	2767178	et	3	main
juurduma	doc_617668397754_item	2767187	et	3	main
kombe	doc_617668397754_item	2767189	et	4	main
iseseisev	doc_617668397754_item	2767196	et	3	main
rahvad	doc_617668397754_item	2767200	et	3	main
tundsid	doc_617668397754_item	2767205	et	4	main
säilitada	doc_617668397754_item	2767218	et	3	main
aasta	doc_617668397753_item	2767036	et	4	main
taas	doc_617668397753_item	2767040	et	3	main
koole	doc_617668397753_item	2767042	et	4	main
venestuse	doc_617668397753_item	2767049	et	4	main
survele	doc_617668397753_item	2767050	et	3	main
jõudsalt	doc_617668397753_item	2767058	et	4	main
toimus	doc_617668397753_item	2767063	et	3	main
ilma	doc_617668397753_item	2767069	et	4	main
maata	doc_617668397753_item	2767070	et	3	main
välja	doc_617668397753_item	2767076	et	4	main
algas	doc_617668397753_item	2767078	et	3	main
linnastumine	doc_617668397753_item	2767080	et	4	main
uus	doc_617668397753_item	2767082	et	3	main
eliit	doc_617668397753_item	2767083	et	3	main
aritöötajad	doc_617668397753_item	2767084	et	4	main
vaimulikud	doc_617668397753_item	2767085	et	3	main
kauptöötajad	doc_617668397753_item	2767086	et	3	main
perekonnanime	doc_617668397753_item	2767091	et	4	main
i	doc_617668397753_item	2767096	et	4	main
peterburi	doc_617668397753_item	2767103	et	4	main
piima	doc_617668397753_item	2767109	et	4	main
ja	doc_617668397753_item	2767112	et	3	main
ne	doc_617668397753_item	2767113	et	4	main
riigiteenistajad	doc_617668397753_item	2767114	et	4	main
19	doc_617668397753_item	2767115	et	2	main
s	doc_617668397753_item	2767116	et	4	main
linnapea	doc_617668397753_item	2767117	et	4	main
staatus	doc_617668397753_item	2767118	et	3	main
volikoogu	doc_617668397753_item	2767119	et	3	main
linnavalitsus	doc_617668397753_item	2767120	et	3	main
hakkas	doc_617668397753_item	2767137	et	3	main
kontrolltöö	doc_617668397754_item	2767145	et	4	main
kontrolltöö	doc_617668397754_item	2767146	et	4	main
argikultuuri	doc_617668397754_item	2767152	et	4	main
kultuurid	doc_617668397754_item	2767161	et	3	main
on	doc_617668397754_item	2767162	et	4	main
arheoloogilised	doc_617668397754_item	2767163	et	4	main
kultuurid	doc_617668397754_item	2767164	et	3	main
3	doc_617668397754_item	2767165	et	2	main
erinevad	doc_617668397754_item	2767175	et	4	main
põhjast	doc_617668397754_item	2767177	et	4	main
idast	doc_617668397754_item	2767180	et	4	main
laatlased	doc_617668397754_item	2767181	et	4	main
sakslased	doc_617668397754_item	2767182	et	3	main
oma	doc_617668397754_item	2767188	et	4	main
kultuuri	doc_617668397754_item	2767191	et	4	main
riik	doc_617668397754_item	2767197	et	3	main
teda	doc_617668397754_item	2767202	et	4	main
valitsema	doc_617668397754_item	2767203	et	3	main
ja	doc_617668397754_item	2767204	et	3	main
ikkagi	doc_617668397754_item	2767212	et	4	main
kujundada	doc_617668397754_item	2767213	et	3	main
välja	doc_617668397754_item	2767214	et	4	main
säilinud	doc_617668397754_item	2767223	et	4	main
arheoloogilised	doc_617668397754_item	2767225	et	4	main
eset	doc_617668397754_item	2767226	et	3	main
oli	doc_617668397754_item	2767231	et	3	main
kultuur	doc_617668397754_item	2767233	et	3	main
elu	doc_617668397754_item	2767236	et	4	main
aga	doc_617668397754_item	2767237	et	3	main
loomulikult	doc_617668397754_item	2767238	et	4	main
need	doc_617668397754_item	2767239	et	3	main
12	doc_617668397754_item	2767240	et	2	main
eset	doc_617668397754_item	2767241	et	3	main
on	doc_617668397754_item	2767248	et	4	main
eset	doc_617668397754_item	2767257	et	3	main
2	doc_617668397754_item	2767295	et	2	main
töötasid	doc_617668397754_item	2767308	et	4	main
aga	doc_617668397754_item	2767312	et	3	main
käis	doc_617668397754_item	2767315	et	4	main
õppimine	doc_617668397754_item	2767316	et	4	main
ja	doc_617668397754_item	2767317	et	3	main
arvamine	doc_617668397753_item	2767124	et	4	main
nad	doc_617668397753_item	2767125	et	3	main
tundsid	doc_617668397753_item	2767126	et	4	main
ennast	doc_617668397753_item	2767127	et	4	main
nagu	doc_617668397753_item	2767128	et	3	main
iseseisev	doc_617668397753_item	2767129	et	3	main
saksa	doc_617668397753_item	2767134	et	4	main
suunas	doc_617668397753_item	2767144	et	4	main
iseloomusta	doc_617668397754_item	2767150	et	4	main
kloostrid	doc_617668397754_item	2767154	et	3	main
keskaegse	doc_617668397754_item	2767155	et	3	main
hariduselu	doc_617668397754_item	2767156	et	4	main
ja	doc_617668397754_item	2767157	et	3	main
kultuurikeskustena	doc_617668397754_item	2767158	et	4	main
on	doc_617668397754_item	2767168	et	4	main
et	doc_617668397754_item	2767170	et	3	main
igal	doc_617668397754_item	2767171	et	3	main
rahvad	doc_617668397754_item	2767176	et	3	main
soomlased	doc_617668397754_item	2767179	et	3	main
ei	doc_617668397754_item	2767193	et	4	main
kujunenud	doc_617668397754_item	2767194	et	4	main
nagu	doc_617668397754_item	2767195	et	3	main
erinevad	doc_617668397754_item	2767199	et	4	main
tahtsid	doc_617668397754_item	2767201	et	4	main
aga	doc_617668397754_item	2767209	et	3	main
eestlased	doc_617668397754_item	2767210	et	3	main
said	doc_617668397754_item	2767211	et	4	main
seda	doc_617668397754_item	2767219	et	3	main
eestimaal	doc_617668397754_item	2767230	et	4	main
keskaegne	doc_617668397754_item	2767235	et	3	main
ainult	doc_617668397754_item	2767244	et	4	main
nõõrsokultuur	doc_617668397754_item	2767255	et	4	main
on	doc_617668397754_item	2767266	et	4	main
mitu	doc_617668397754_item	2767267	et	4	main
loomulikult	doc_617668397754_item	2767290	et	4	main
oma	doc_617668397754_item	2767291	et	4	main
hing	doc_617668397754_item	2767292	et	3	main
väga	doc_617668397754_item	2767300	et	3	main
põlludel	doc_617668397754_item	2767309	et	4	main
kirikutedes	doc_617668397754_item	2767321	et	4	main
õpetajad	doc_617668397754_item	2767323	et	4	main
olid	doc_617668397754_item	2767324	et	4	main
munkid	doc_617668397754_item	2767325	et	4	main
ja	doc_617668397754_item	2767326	et	3	main
nunnid	doc_617668397754_item	2767327	et	3	main
õpilased	doc_617668397754_item	2767328	et	3	main
palvetasid	doc_617668397754_item	2767330	et	4	main
õppisid	doc_617668397754_item	2767332	et	4	main
esialgul	doc_617668397754_item	2767334	et	3	main
võimalust	doc_617668397754_item	2767340	et	3	main
said	doc_617668397754_item	2767341	et	4	main
aga	doc_617668397754_item	2767344	et	3	main
juba	doc_617668397754_item	2767347	et	3	main
pärast	doc_617668397754_item	2767350	et	4	main
ja	doc_617668397754_item	2767360	et	3	main
oma	doc_617668397754_item	2767362	et	4	main
keeruline	doc_617668397754_item	2767371	et	4	main
pidid	doc_617668397754_item	2767373	et	4	main
töötama	doc_617668397754_item	2767374	et	3	main
põlludel	doc_617668397754_item	2767375	et	4	main
aga	doc_617668397754_item	2767376	et	3	main
see	doc_617668397754_item	2767377	et	3	main
kariloomadega	doc_617668397754_item	2767383	et	3	main
oru	doc_617668397754_item	2767389	et	3	main
tegid	doc_617668397754_item	2767391	et	4	main
loomulikult	doc_617668397754_item	2767421	et	4	main
pärast	doc_617668397754_item	2767423	et	4	main
ja	doc_617668397754_item	2767439	et	3	main
kultuuriloost	doc_617668397755_item	2767444	et	4	main
1905	doc_617668397755_item	2767446	et	2	main
aasta	doc_617668397755_item	2767447	et	4	main
revolutsioon	doc_617668397755_item	2767448	et	3	main
põhjus	doc_617668397755_item	2767449	et	4	main
3	doc_617668397755_item	2767464	et	2	main
kelle	doc_617668397755_item	2767513	et	4	main
ametit	doc_617668397755_item	2767514	et	3	main
võtsidki	doc_617668397755_item	2767515	et	4	main
tekkima	doc_617668397755_item	2767524	et	3	main
vaja	doc_617668397755_item	2767533	et	4	main
töölisi	doc_617668397755_item	2767534	et	3	main
samuti	doc_617668397755_item	2767543	et	3	main
et	doc_617668397755_item	2767547	et	3	main
ja	doc_617668397755_item	2767549	et	3	main
jäänud	doc_617668397755_item	2767554	et	4	main
algatajateks	doc_617668397755_item	2767587	et	4	main
olid	doc_617668397755_item	2767588	et	4	main
hurt	doc_617668397755_item	2767589	et	3	main
aktiivselt	doc_617668397755_item	2767593	et	4	main
eesti	doc_617668397755_item	2767598	et	4	main
kogunesid	doc_617668397755_item	2767625	et	4	main
lõid	doc_617668397755_item	2767637	et	4	main
ev	doc_617668397755_item	2767644	et	4	main
hümniks	doc_617668397755_item	2767645	et	3	main
samal	doc_617668397755_item	2767646	et	3	main
olid	doc_617668397755_item	2767658	et	4	main
kinnitavad	doc_617668397754_item	2767228	et	4	main
oma	doc_617668397754_item	2767232	et	4	main
ja	doc_617668397754_item	2767234	et	3	main
ühed	doc_617668397754_item	2767245	et	3	main
asjad	doc_617668397754_item	2767246	et	3	main
mis	doc_617668397754_item	2767247	et	4	main
need	doc_617668397754_item	2767256	et	3	main
mida	doc_617668397754_item	2767258	et	4	main
arheoologid	doc_617668397754_item	2767260	et	4	main
muusiumid	doc_617668397754_item	2767268	et	4	main
kus	doc_617668397754_item	2767269	et	3	main
need	doc_617668397754_item	2767270	et	3	main
on	doc_617668397754_item	2767271	et	4	main
esinenud	doc_617668397754_item	2767272	et	4	main
on	doc_617668397754_item	2767274	et	4	main
see	doc_617668397754_item	2767273	et	3	main
tööristad	doc_617668397754_item	2767275	et	4	main
sõõgiriistad	doc_617668397754_item	2767276	et	4	main
mingi	doc_617668397754_item	2767277	et	4	main
riietus	doc_617668397754_item	2767278	et	4	main
ja	doc_617668397754_item	2767279	et	3	main
ne	doc_617668397754_item	2767280	et	4	main
nendel	doc_617668397754_item	2767281	et	4	main
asjadel	doc_617668397754_item	2767282	et	3	main
on	doc_617668397754_item	2767283	et	4	main
oma	doc_617668397754_item	2767284	et	4	main
vanus	doc_617668397754_item	2767285	et	4	main
oma	doc_617668397754_item	2767286	et	4	main
ebakorduv	doc_617668397754_item	2767287	et	3	main
säilinud	doc_617668397754_item	2767249	et	4	main
oli	doc_617668397754_item	2767250	et	3	main
populaarne	doc_617668397754_item	2767251	et	3	main
гребенчастая	doc_617668397754_item	2767252	et	2	main
välimus	doc_617668397754_item	2767288	et	3	main
ja	doc_617668397754_item	2767289	et	3	main
oma	doc_617668397754_item	2767305	et	4	main
elust	doc_617668397754_item	2767306	et	3	main
inimesed	doc_617668397754_item	2767307	et	3	main
loomi	doc_617668397754_item	2767311	et	4	main
õppisid	doc_617668397754_item	2767335	et	4	main
tüdrukud	doc_617668397754_item	2767343	et	3	main
juhtis	doc_617668397754_item	2767346	et	3	main
aega	doc_617668397754_item	2767349	et	4	main
alati	doc_617668397754_item	2767356	et	4	main
kaitsta	doc_617668397754_item	2767361	et	4	main
1	doc_617668397754_item	2767364	et	2	main
aeg	doc_617668397754_item	2767366	et	3	main
oli	doc_617668397754_item	2767367	et	3	main
üsna	doc_617668397754_item	2767368	et	3	main
raske	doc_617668397754_item	2767369	et	4	main
ja	doc_617668397754_item	2767370	et	3	main
ole	doc_617668397754_item	2767379	et	4	main
lihtne	doc_617668397754_item	2767380	et	3	main
kalapüükidega	doc_617668397754_item	2767384	et	3	main
tööristad	doc_617668397754_item	2767396	et	4	main
olid	doc_617668397754_item	2767397	et	4	main
sõltub	doc_617668397754_item	2767399	et	3	main
savi	doc_617668397754_item	2767293	et	4	main
hariduselu	doc_617668397754_item	2767297	et	4	main
populaarne	doc_617668397754_item	2767301	et	3	main
suur	doc_617668397754_item	2767303	et	3	main
osa	doc_617668397754_item	2767304	et	4	main
kasvatasid	doc_617668397754_item	2767310	et	4	main
ja	doc_617668397754_item	2767331	et	3	main
poisid	doc_617668397754_item	2767337	et	4	main
relvastust	doc_617668397754_item	2767353	et	4	main
et	doc_617668397754_item	2767354	et	3	main
nad	doc_617668397754_item	2767355	et	3	main
sõjaks	doc_617668397754_item	2767359	et	3	main
tegevus	doc_617668397754_item	2767381	et	4	main
kasvatasid	doc_617668397754_item	2767385	et	4	main
nisu	doc_617668397754_item	2767388	et	4	main
kanepit	doc_617668397754_item	2767390	et	3	main
endale	doc_617668397754_item	2767392	et	4	main
iseseisvalt	doc_617668397754_item	2767393	et	4	main
erinevad	doc_617668397754_item	2767398	et	4	main
aidasid	doc_617668397754_item	2767430	et	4	main
kündma	doc_617668397754_item	2767431	et	3	main
põllu	doc_617668397754_item	2767432	et	3	main
kõik	doc_617668397754_item	2767433	et	4	main
need	doc_617668397754_item	2767434	et	3	main
aspektid	doc_617668397754_item	2767435	et	3	main
tegid	doc_617668397754_item	2767436	et	4	main
kontrolltöö	doc_617668397755_item	2767441	et	4	main
eesti	doc_617668397755_item	2767443	et	4	main
19	doc_617668397755_item	2767453	et	2	main
sajandi	doc_617668397755_item	2767454	et	3	main
poole	doc_617668397755_item	2767456	et	4	main
keel	doc_617668397755_item	2767458	et	4	main
kirjandus	doc_617668397755_item	2767459	et	3	main
lühiülevaade	doc_617668397755_item	2767463	et	3	main
kuidas	doc_617668397755_item	2767465	et	3	main
rohkem	doc_617668397755_item	2767502	et	4	main
hakkasid	doc_617668397755_item	2767522	et	4	main
linnastumine	doc_617668397755_item	2767536	et	4	main
võttis	doc_617668397755_item	2767537	et	3	main
tol	doc_617668397755_item	2767538	et	3	main
ajal	doc_617668397755_item	2767539	et	4	main
suure	doc_617668397755_item	2767540	et	3	main
mõisad	doc_617668397755_item	2767550	et	3	main
alguses	doc_617668397755_item	2767561	et	4	main
väga	doc_617668397755_item	2767569	et	3	main
kultuurielus	doc_617668397755_item	2767579	et	4	main
eelkõige	doc_617668397755_item	2767580	et	3	main
eestlaste	doc_617668397755_item	2767581	et	4	main
köler	doc_617668397755_item	2767590	et	4	main
kirjutati	doc_617668397755_item	2767597	et	3	main
nii	doc_617668397755_item	2767622	et	3	main
noored	doc_617668397755_item	2767626	et	3	main
üheskoos	doc_617668397755_item	2767630	et	3	main
ja	doc_617668397755_item	2767632	et	3	main
ühe	doc_617668397755_item	2767638	et	4	main
levima	doc_617668397755_item	2767649	et	3	main
esialgu	doc_617668397755_item	2767651	et	3	main
olid	doc_617668397755_item	2767653	et	4	main
et	doc_617668397755_item	2767665	et	3	main
aeg	doc_617668397755_item	2767667	et	3	main
nime	doc_617668397755_item	2767670	et	4	main
kultuuri	doc_617668397755_item	2767680	et	4	main
eestis	doc_617668397755_item	2767687	et	3	main
oli	doc_617668397755_item	2767688	et	3	main
mässumeelseid	doc_617668397755_item	2767727	et	3	main
karistati	doc_617668397755_item	2767728	et	3	main
massiliselt	doc_617668397755_item	2767730	et	4	main
kohas	doc_617668397755_item	2767733	et	4	main
karistas	doc_617668397755_item	2767739	et	3	main
sõjavägi	doc_617668397755_item	2767742	et	3	main
keelasid	doc_617668397755_item	2767744	et	4	main
igasuguse	doc_617668397755_item	2767745	et	3	main
parempartei	doc_617668397755_item	2767746	et	4	main
siis	doc_617668397755_item	2767753	et	3	main
euroopa	doc_617668397755_item	2767768	et	4	main
pilguga	doc_617668397755_item	2767771	et	3	main
eesti	doc_617668397756_item	2767780	et	4	main
kultuuris	doc_617668397756_item	2767788	et	3	main
üleminekul	doc_617668397756_item	2767790	et	3	main
rauaaega	doc_617668397756_item	2767792	et	4	main
3	doc_617668397756_item	2767798	et	2	main
esimesed	doc_617668397754_item	2767318	et	3	main
koolid	doc_617668397754_item	2767319	et	3	main
veetsid	doc_617668397754_item	2767320	et	4	main
kus	doc_617668397754_item	2767322	et	3	main
pärast	doc_617668397754_item	2767338	et	4	main
seda	doc_617668397754_item	2767339	et	3	main
poisid	doc_617668397754_item	2767351	et	4	main
õppisid	doc_617668397754_item	2767352	et	4	main
inimesed	doc_617668397754_item	2767372	et	3	main
tegelesid	doc_617668397754_item	2767382	et	4	main
üles	doc_617668397754_item	2767386	et	3	main
tööriste	doc_617668397754_item	2767394	et	4	main
need	doc_617668397754_item	2767395	et	3	main
sellest	doc_617668397754_item	2767400	et	4	main
missugune	doc_617668397754_item	2767401	et	3	main
aeg	doc_617668397754_item	2767402	et	3	main
see	doc_617668397754_item	2767403	et	3	main
oli	doc_617668397754_item	2767404	et	3	main
kui	doc_617668397754_item	2767405	et	3	main
see	doc_617668397754_item	2767406	et	3	main
oli	doc_617668397754_item	2767407	et	3	main
kiviaeg	doc_617668397754_item	2767408	et	3	main
siis	doc_617668397754_item	2767409	et	3	main
proovisid	doc_617668397754_item	2767410	et	4	main
teha	doc_617668397754_item	2767411	et	3	main
kivist	doc_617668397754_item	2767412	et	4	main
aga	doc_617668397754_item	2767413	et	3	main
50	doc_617668397754_item	2767414	et	2	main
oma	doc_617668397754_item	2767415	et	4	main
tööst	doc_617668397754_item	2767416	et	3	main
või	doc_617668397754_item	2767417	et	4	main
rohkem	doc_617668397754_item	2767418	et	4	main
tegid	doc_617668397754_item	2767419	et	4	main
nad	doc_617668397754_item	2767420	et	3	main
käega	doc_617668397754_item	2767422	et	3	main
alustasid	doc_617668397754_item	2767425	et	4	main
kergemaks	doc_617668397754_item	2767440	et	4	main
1	doc_617668397755_item	2767445	et	2	main
tagajärjed	doc_617668397755_item	2767451	et	3	main
ii	doc_617668397755_item	2767455	et	4	main
kultuurielu	doc_617668397755_item	2767457	et	4	main
jne	doc_617668397755_item	2767462	et	4	main
mõjutas	doc_617668397755_item	2767466	et	3	main
pärsiorjusest	doc_617668397755_item	2767468	et	4	main
linnastumist	doc_617668397755_item	2767470	et	4	main
ja	doc_617668397755_item	2767471	et	3	main
vabastatud	doc_617668397755_item	2767516	et	4	main
pärisorjad	doc_617668397755_item	2767517	et	3	main
endale	doc_617668397755_item	2767518	et	4	main
19	doc_617668397755_item	2767519	et	2	main
sajandi	doc_617668397755_item	2767520	et	3	main
lõpus	doc_617668397755_item	2767521	et	4	main
suurehulgaliselt	doc_617668397755_item	2767523	et	4	main
hoogu	doc_617668397755_item	2767541	et	4	main
kuid	doc_617668397755_item	2767542	et	4	main
oleks	doc_617668397755_item	2767551	et	3	main
tühjaks	doc_617668397755_item	2767553	et	3	main
2	doc_617668397755_item	2767555	et	2	main
19	doc_617668397755_item	2767556	et	2	main
sajandi	doc_617668397755_item	2767557	et	3	main
ii	doc_617668397755_item	2767558	et	4	main
poole	doc_617668397755_item	2767559	et	4	main
et	doc_617668397755_item	2767565	et	3	main
see	doc_617668397755_item	2767566	et	3	main
töötamine	doc_617668397754_item	2767437	et	4	main
kontrolltöö	doc_617668397755_item	2767442	et	4	main
ja	doc_617668397755_item	2767450	et	3	main
teater	doc_617668397755_item	2767461	et	3	main
vabastamine	doc_617668397755_item	2767469	et	4	main
tööstuse	doc_617668397755_item	2767472	et	3	main
arengut	doc_617668397755_item	2767473	et	3	main
3	doc_617668397755_item	2767474	et	2	main
talupoegade	doc_617668397755_item	2767475	et	3	main
pärisorjusest	doc_617668397755_item	2767476	et	4	main
vabastamine	doc_617668397755_item	2767477	et	4	main
tunduvalt	doc_617668397755_item	2767478	et	4	main
mõjutas	doc_617668397755_item	2767479	et	3	main
nii	doc_617668397755_item	2767480	et	3	main
linnastumist	doc_617668397755_item	2767481	et	4	main
kui	doc_617668397755_item	2767482	et	3	main
ka	doc_617668397755_item	2767483	et	3	main
tööstuse	doc_617668397755_item	2767484	et	3	main
arengut	doc_617668397755_item	2767485	et	3	main
paljud	doc_617668397755_item	2767486	et	3	main
endised	doc_617668397755_item	2767487	et	3	main
pärisorjad	doc_617668397755_item	2767488	et	3	main
ei	doc_617668397755_item	2767489	et	4	main
soovinud	doc_617668397755_item	2767490	et	4	main
oma	doc_617668397755_item	2767491	et	4	main
elu	doc_617668397755_item	2767492	et	4	main
ja	doc_617668397755_item	2767493	et	3	main
tegevust	doc_617668397755_item	2767494	et	4	main
maal	doc_617668397755_item	2767495	et	4	main
jätkata	doc_617668397755_item	2767496	et	4	main
ja	doc_617668397755_item	2767497	et	3	main
siirdusid	doc_617668397755_item	2767498	et	4	main
linnadesse	doc_617668397755_item	2767499	et	3	main
kus	doc_617668397755_item	2767500	et	3	main
lihtsamaks	doc_617668397754_item	2767438	et	4	main
2	doc_617668397755_item	2767452	et	2	main
muusika	doc_617668397755_item	2767460	et	4	main
talupoegade	doc_617668397755_item	2767467	et	3	main
oli	doc_617668397755_item	2767501	et	3	main
võimalusi	doc_617668397755_item	2767503	et	3	main
ennast	doc_617668397755_item	2767504	et	4	main
rakendada	doc_617668397755_item	2767505	et	3	main
linnades	doc_617668397755_item	2767506	et	3	main
oli	doc_617668397755_item	2767507	et	3	main
suur	doc_617668397755_item	2767508	et	3	main
nõudlus	doc_617668397755_item	2767509	et	3	main
erinevate	doc_617668397755_item	2767510	et	4	main
seppade	doc_617668397755_item	2767511	et	3	main
manufaktuurid	doc_617668397755_item	2767525	et	3	main
tallinnas	doc_617668397755_item	2767526	et	4	main
jne	doc_617668397755_item	2767529	et	4	main
kus	doc_617668397755_item	2767530	et	3	main
samuti	doc_617668397755_item	2767531	et	3	main
oli	doc_617668397755_item	2767532	et	3	main
ei	doc_617668397755_item	2767544	et	4	main
talud	doc_617668397755_item	2767548	et	4	main
päris	doc_617668397755_item	2767552	et	4	main
peab	doc_617668397755_item	2767562	et	4	main
kohe	doc_617668397755_item	2767563	et	4	main
ütlema	doc_617668397755_item	2767564	et	3	main
aeg	doc_617668397755_item	2767567	et	3	main
eesti	doc_617668397755_item	2767571	et	4	main
rahva	doc_617668397755_item	2767572	et	3	main
jaoks	doc_617668397755_item	2767573	et	4	main
toimus	doc_617668397755_item	2767574	et	3	main
rahvusärkamine	doc_617668397755_item	2767575	et	3	main
mis	doc_617668397755_item	2767576	et	4	main
väljendus	doc_617668397755_item	2767577	et	4	main
aktiivses	doc_617668397755_item	2767578	et	3	main
ja	doc_617668397755_item	2767583	et	3	main
keeles	doc_617668397755_item	2767585	et	4	main
jt	doc_617668397755_item	2767592	et	4	main
hakkas	doc_617668397755_item	2767594	et	3	main
arenema	doc_617668397755_item	2767595	et	3	main
kirjandus	doc_617668397755_item	2767596	et	3	main
nagu	doc_617668397755_item	2767623	et	3	main
ja	doc_617668397755_item	2767627	et	3	main
ning	doc_617668397755_item	2767629	et	3	main
laulsid	doc_617668397755_item	2767631	et	4	main
jakobson	doc_617668397755_item	2767636	et	4	main
kokkuvõtteks	doc_617668397755_item	2767662	et	3	main
rahvusärkamise	doc_617668397755_item	2767666	et	3	main
tuntav	doc_617668397755_item	2767683	et	4	main
1	doc_617668397755_item	2767685	et	2	main
isevalitsuse	doc_617668397755_item	2767691	et	3	main
ja	doc_617668397755_item	2767693	et	3	main
revolutsionäärid	doc_617668397755_item	2767697	et	3	main
samuti	doc_617668397755_item	2767721	et	3	main
eesti	doc_617668397755_item	2767723	et	4	main
omavalitsust	doc_617668397755_item	2767726	et	3	main
olid	doc_617668397755_item	2767735	et	4	main
loodud	doc_617668397755_item	2767736	et	4	main
spetsiaalsed	doc_617668397755_item	2767737	et	3	main
kartsid	doc_617668397755_item	2767751	et	4	main
poole	doc_617668397755_item	2767776	et	4	main
vaatama	doc_617668397755_item	2767777	et	3	main
muutused	doc_617668397756_item	2767784	et	4	main
materiaalses	doc_617668397756_item	2767785	et	3	main
toimusid	doc_617668397756_item	2767789	et	4	main
kiviajast	doc_617668397756_item	2767791	et	4	main
2	doc_617668397756_item	2767793	et	2	main
kirjelda	doc_617668397756_item	2767794	et	4	main
muistne	doc_617668397756_item	2767800	et	3	main
et	doc_617668397756_item	2767807	et	3	main
lõppes	doc_617668397756_item	2767810	et	4	main
eestlastel	doc_617668397756_item	2767826	et	4	main
ühist	doc_617668397756_item	2767827	et	3	main
riiki	doc_617668397756_item	2767828	et	4	main
nad	doc_617668397756_item	2767829	et	3	main
tegutseda	doc_617668397756_item	2767848	et	3	main
näiteks	doc_617668397756_item	2767863	et	4	main
sakslastega	doc_617668397756_item	2767864	et	3	main
siis	doc_617668397756_item	2767865	et	3	main
et	doc_617668397756_item	2767868	et	3	main
tõepoolest	doc_617668397756_item	2767871	et	3	main
järgi	doc_617668397755_item	2767512	et	4	main
narvas	doc_617668397755_item	2767527	et	4	main
viljandis	doc_617668397755_item	2767528	et	4	main
üldse	doc_617668397755_item	2767535	et	3	main
saa	doc_617668397755_item	2767545	et	4	main
öelda	doc_617668397755_item	2767546	et	4	main
kultuurielu	doc_617668397755_item	2767560	et	4	main
oli	doc_617668397755_item	2767568	et	3	main
eesti	doc_617668397755_item	2767584	et	4	main
rahvusliikumise	doc_617668397755_item	2767586	et	3	main
nii	doc_617668397755_item	2767600	et	3	main
luulet	doc_617668397755_item	2767601	et	3	main
kui	doc_617668397755_item	2767602	et	3	main
proosat	doc_617668397755_item	2767603	et	3	main
märkimisväärseks	doc_617668397755_item	2767604	et	4	main
luuletajaks	doc_617668397755_item	2767605	et	4	main
oli	doc_617668397755_item	2767606	et	3	main
lkoidula	doc_617668397755_item	2767607	et	4	main
tallinnas	doc_617668397755_item	2767608	et	4	main
ja	doc_617668397755_item	2767609	et	3	main
pärnus	doc_617668397755_item	2767610	et	3	main
hakkasid	doc_617668397755_item	2767611	et	4	main
ilmuma	doc_617668397755_item	2767612	et	3	main
eestikeelsed	doc_617668397755_item	2767613	et	3	main
ajalehed	doc_617668397755_item	2767614	et	3	main
1	doc_617668397755_item	2767615	et	2	main
tuntumaid	doc_617668397755_item	2767616	et	4	main
oli	doc_617668397755_item	2767617	et	3	main
tol	doc_617668397755_item	2767618	et	3	main
ajal	doc_617668397755_item	2767619	et	4	main
perno	doc_617668397755_item	2767620	et	4	main
postimees	doc_617668397755_item	2767621	et	4	main
laulu	doc_617668397755_item	2767639	et	4	main
ajal	doc_617668397755_item	2767647	et	4	main
teatrietendused	doc_617668397755_item	2767650	et	3	main
laval	doc_617668397755_item	2767652	et	3	main
küll	doc_617668397755_item	2767654	et	4	main
ainult	doc_617668397755_item	2767655	et	4	main
mehed	doc_617668397755_item	2767656	et	3	main
näitlejad	doc_617668397755_item	2767657	et	4	main
asjaarmastajad	doc_617668397755_item	2767661	et	3	main
võib	doc_617668397755_item	2767663	et	3	main
oma	doc_617668397755_item	2767669	et	4	main
rahvas	doc_617668397755_item	2767672	et	4	main
hakkas	doc_617668397755_item	2767673	et	3	main
hindama	doc_617668397755_item	2767674	et	3	main
end	doc_617668397755_item	2767675	et	4	main
ja	doc_617668397755_item	2767676	et	3	main
valdkonnas	doc_617668397755_item	2767681	et	4	main
toimus	doc_617668397755_item	2767682	et	3	main
ja	doc_617668397755_item	2767725	et	3	main
lihtrahvast	doc_617668397755_item	2767729	et	4	main
tsaari	doc_617668397755_item	2767741	et	4	main
repressioone	doc_617668397755_item	2767752	et	3	main
osa	doc_617668397755_item	2767755	et	4	main
põgenes	doc_617668397755_item	2767757	et	3	main
välismaale	doc_617668397755_item	2767758	et	4	main
üldiselt	doc_617668397755_item	2767759	et	4	main
mahasurumine	doc_617668397755_item	2767766	et	3	main
pani	doc_617668397755_item	2767767	et	4	main
pani	doc_617668397755_item	2767769	et	4	main
eestlaste	doc_617668397755_item	2767772	et	4	main
tähtis	doc_617668397755_item	2767570	et	4	main
vahel	doc_617668397755_item	2767582	et	4	main
jannsen	doc_617668397755_item	2767591	et	4	main
keeles	doc_617668397755_item	2767599	et	4	main
praegugi	doc_617668397755_item	2767624	et	3	main
vanad	doc_617668397755_item	2767628	et	3	main
tantsisid	doc_617668397755_item	2767633	et	4	main
pacius	doc_617668397755_item	2767634	et	4	main
ja	doc_617668397755_item	2767635	et	3	main
eestist	doc_617668397755_item	2767640	et	3	main
mis	doc_617668397755_item	2767641	et	4	main
hiljem	doc_617668397755_item	2767642	et	3	main
sai	doc_617668397755_item	2767643	et	4	main
hakkasid	doc_617668397755_item	2767648	et	4	main
eesti	doc_617668397755_item	2767671	et	4	main
mitmes	doc_617668397755_item	2767679	et	4	main
revolutsioon	doc_617668397755_item	2767686	et	3	main
revolutsioon	doc_617668397755_item	2767689	et	3	main
ülemkihtide	doc_617668397755_item	2767695	et	3	main
vastu	doc_617668397755_item	2767696	et	3	main
võitlesid	doc_617668397755_item	2767698	et	4	main
maapuuduse	doc_617668397755_item	2767699	et	3	main
vastu	doc_617668397755_item	2767700	et	3	main
feodaalkorra	doc_617668397755_item	2767701	et	4	main
jäänuste	doc_617668397755_item	2767702	et	3	main
vastu	doc_617668397755_item	2767703	et	3	main
kõrgemate	doc_617668397755_item	2767704	et	4	main
kihtide	doc_617668397755_item	2767705	et	3	main
privileegide	doc_617668397755_item	2767706	et	3	main
vastu	doc_617668397755_item	2767707	et	3	main
poliitiliselt	doc_617668397755_item	2767708	et	4	main
eestlased	doc_617668397755_item	2767710	et	3	main
organiseerisid	doc_617668397755_item	2767711	et	4	main
meeleavalduse	doc_617668397755_item	2767712	et	3	main
haritud	doc_617668397755_item	2767709	et	4	main
demonstratsioone	doc_617668397755_item	2767713	et	3	main
toimusid	doc_617668397755_item	2767714	et	4	main
tööliste	doc_617668397755_item	2767715	et	4	main
üldstreigid	doc_617668397755_item	2767716	et	3	main
taotleti	doc_617668397755_item	2767717	et	3	main
demokraatiat	doc_617668397755_item	2767718	et	3	main
ja	doc_617668397755_item	2767719	et	3	main
kodanikuõigusi	doc_617668397755_item	2767720	et	4	main
huvilised	doc_617668397755_item	2767659	et	4	main
ja	doc_617668397755_item	2767660	et	3	main
öelda	doc_617668397755_item	2767664	et	4	main
õigustas	doc_617668397755_item	2767668	et	3	main
oma	doc_617668397755_item	2767677	et	4	main
kultuuri	doc_617668397755_item	2767678	et	4	main
areng	doc_617668397755_item	2767684	et	3	main
suunatud	doc_617668397755_item	2767690	et	4	main
vastu	doc_617668397755_item	2767692	et	3	main
baltisaksa	doc_617668397755_item	2767694	et	4	main
taheti	doc_617668397755_item	2767722	et	3	main
autonoomiat	doc_617668397755_item	2767724	et	3	main
tulistati	doc_617668397755_item	2767731	et	3	main
karistusrühmad	doc_617668397755_item	2767738	et	3	main
tegevuse	doc_617668397755_item	2767747	et	4	main
ametiühinguid	doc_617668397755_item	2767748	et	3	main
kuna	doc_617668397755_item	2767749	et	3	main
riigijuhid	doc_617668397755_item	2767750	et	3	main
suur	doc_617668397755_item	2767754	et	3	main
baltimaades	doc_617668397755_item	2767760	et	4	main
toimunud	doc_617668397755_item	2767761	et	4	main
ja	doc_617668397755_item	2767763	et	3	main
selle	doc_617668397755_item	2767764	et	4	main
tugev	doc_617668397755_item	2767765	et	4	main
uue	doc_617668397755_item	2767770	et	3	main
ja	doc_617668397756_item	2767786	et	3	main
eestimaal	doc_617668397756_item	2767797	et	4	main
miks	doc_617668397756_item	2767799	et	4	main
lõppes	doc_617668397756_item	2767802	et	4	main
eestlastele	doc_617668397756_item	2767803	et	4	main
muistne	doc_617668397756_item	2767808	et	3	main
mõjuvat	doc_617668397756_item	2767821	et	4	main
olnud	doc_617668397756_item	2767825	et	4	main
järelikult	doc_617668397756_item	2767833	et	3	main
ja	doc_617668397756_item	2767842	et	3	main
ei	doc_617668397756_item	2767845	et	4	main
võimaldanud	doc_617668397756_item	2767846	et	4	main
taktika	doc_617668397756_item	2767850	et	4	main
ja	doc_617668397756_item	2767852	et	3	main
vastast	doc_617668397756_item	2767854	et	4	main
on	doc_617668397756_item	2767870	et	4	main
vastav	doc_617668397756_item	2767876	et	4	main
oli	doc_617668397756_item	2767916	et	3	main
tähtis	doc_617668397756_item	2767925	et	4	main
see	doc_617668397756_item	2767927	et	3	main
soola	doc_617668397756_item	2767936	et	4	main
kallis	doc_617668397756_item	2767939	et	4	main
nõutud	doc_617668397756_item	2767941	et	4	main
toimus	doc_617668397756_item	2767960	et	3	main
kaubavahetus	doc_617668397756_item	2767961	et	4	main
ja	doc_617668397756_item	2767963	et	3	main
müük	doc_617668397756_item	2767964	et	3	main
linnas	doc_617668397756_item	2767965	et	4	main
ka	doc_617668397756_item	2767967	et	3	main
keset	doc_617668397756_item	2767976	et	4	main
ka	doc_617668397756_item	2767979	et	3	main
väga	doc_617668397756_item	2767988	et	3	main
tähtsaks	doc_617668397756_item	2767989	et	4	main
samuti	doc_617668397756_item	2767990	et	3	main
peab	doc_617668397756_item	2767991	et	4	main
ja	doc_617668397756_item	2767996	et	3	main
linna	doc_617668397756_item	2768022	et	4	main
turg	doc_617668397756_item	2768026	et	3	main
ja	doc_617668397756_item	2768031	et	3	main
kaubaga	doc_617668397756_item	2768033	et	3	main
toodi	doc_617668397756_item	2768036	et	4	main
rauaaega	doc_617668397756_item	2768040	et	4	main
kvaliteetsem	doc_617668397756_item	2768063	et	4	main
mindi	doc_617668397756_item	2768064	et	3	main
üle	doc_617668397756_item	2768065	et	3	main
mitme	doc_617668397756_item	2768066	et	4	main
põllu	doc_617668397756_item	2768067	et	3	main
maha	doc_617668397756_item	2768079	et	4	main
töötlemiseks	doc_617668397756_item	2768085	et	4	main
ahju	doc_617668397756_item	2768087	et	4	main
rauaajast	doc_617668397756_item	2768088	et	4	main
mille	doc_617668397756_item	2768106	et	3	main
tõttu	doc_617668397756_item	2768107	et	4	main
korjamine	doc_617668397756_item	2768113	et	4	main
põllundusega	doc_617668397756_item	2768115	et	3	main
c	doc_617668397757_item	2768136	et	4	main
ka	doc_617668397755_item	2767740	et	3	main
avalikus	doc_617668397755_item	2767732	et	4	main
selleks	doc_617668397755_item	2767734	et	4	main
keskvõimud	doc_617668397755_item	2767743	et	3	main
neist	doc_617668397755_item	2767756	et	4	main
revolutsioon	doc_617668397755_item	2767762	et	3	main
kontrolltöö	doc_617668397756_item	2767778	et	4	main
kontrolltöö	doc_617668397756_item	2767779	et	4	main
vaimses	doc_617668397756_item	2767787	et	3	main
3	doc_617668397756_item	2767805	et	2	main
olnud	doc_617668397756_item	2767814	et	4	main
selleks	doc_617668397756_item	2767818	et	4	main
oli	doc_617668397756_item	2767819	et	3	main
mitu	doc_617668397756_item	2767820	et	4	main
ja	doc_617668397755_item	2767773	et	3	main
nende	doc_617668397755_item	2767774	et	4	main
probleeme	doc_617668397755_item	2767775	et	3	main
kultuuriloost	doc_617668397756_item	2767781	et	4	main
1	doc_617668397756_item	2767782	et	2	main
millised	doc_617668397756_item	2767783	et	3	main
linnakultuuri	doc_617668397756_item	2767795	et	4	main
keskaegsel	doc_617668397756_item	2767796	et	3	main
kaotusega	doc_617668397756_item	2767804	et	4	main
vabadusvõitlus	doc_617668397756_item	2767809	et	3	main
minu	doc_617668397756_item	2767815	et	3	main
juhuslik	doc_617668397756_item	2767817	et	3	main
põhjust	doc_617668397756_item	2767822	et	4	main
esiteks	doc_617668397756_item	2767823	et	3	main
osaks	doc_617668397756_item	2767832	et	3	main
olnud	doc_617668397756_item	2767835	et	4	main
juht	doc_617668397756_item	2767841	et	3	main
see	doc_617668397756_item	2767844	et	3	main
me	doc_617668397756_item	2767861	et	4	main
võrdleme	doc_617668397756_item	2767862	et	3	main
puudus	doc_617668397756_item	2767875	et	4	main
ning	doc_617668397756_item	2767884	et	3	main
keskuseks	doc_617668397756_item	2767919	et	4	main
kaubandus	doc_617668397756_item	2767923	et	3	main
eriti	doc_617668397756_item	2767924	et	3	main
oli	doc_617668397756_item	2767926	et	3	main
aktiivne	doc_617668397756_item	2767931	et	3	main
kaubavahetus	doc_617668397756_item	2767932	et	4	main
toodi	doc_617668397756_item	2767933	et	4	main
oli	doc_617668397756_item	2767938	et	3	main
ja	doc_617668397756_item	2767940	et	3	main
ja	doc_617668397756_item	2767946	et	3	main
peamiselt	doc_617668397756_item	2767951	et	4	main
mille	doc_617668397756_item	2767957	et	3	main
tegutsesid	doc_617668397756_item	2767966	et	4	main
erinevad	doc_617668397756_item	2767968	et	4	main
sepad	doc_617668397756_item	2767969	et	3	main
ja	doc_617668397756_item	2767970	et	3	main
meistrid	doc_617668397756_item	2767971	et	3	main
nii	doc_617668397756_item	2767972	et	3	main
nagu	doc_617668397756_item	2767973	et	3	main
küla	doc_617668397756_item	2767977	et	4	main
seoses	doc_617668397756_item	2767983	et	4	main
peeti	doc_617668397756_item	2767985	et	4	main
kirikus	doc_617668397756_item	2767986	et	3	main
eestlaste	doc_617668397756_item	2767995	et	4	main
mida	doc_617668397756_item	2768034	et	4	main
üleminemisel	doc_617668397756_item	2768038	et	3	main
kasutuselevõtmisega	doc_617668397756_item	2768051	et	3	main
eestlase	doc_617668397756_item	2768053	et	3	main
lihtsamaks	doc_617668397756_item	2768055	et	4	main
kasutatavad	doc_617668397756_item	2768057	et	4	main
esemed	doc_617668397756_item	2768058	et	3	main
olid	doc_617668397756_item	2768059	et	4	main
mis	doc_617668397756_item	2768069	et	4	main
häid	doc_617668397756_item	2768071	et	3	main
hakkasid	doc_617668397756_item	2768074	et	4	main
tekkima	doc_617668397756_item	2768075	et	3	main
ülejäägid	doc_617668397756_item	2768076	et	3	main
välja	doc_617668397756_item	2768082	et	4	main
vahetada	doc_617668397756_item	2768083	et	3	main
kasutati	doc_617668397756_item	2768086	et	4	main
on	doc_617668397756_item	2768089	et	4	main
mis	doc_617668397756_item	2768094	et	4	main
vihjab	doc_617668397756_item	2768095	et	3	main
sellele	doc_617668397756_item	2768096	et	4	main
et	doc_617668397756_item	2768097	et	3	main
eestlane	doc_617668397756_item	2768098	et	3	main
oli	doc_617668397756_item	2768099	et	3	main
peale	doc_617668397756_item	2768101	et	4	main
põllundust	doc_617668397756_item	2768102	et	3	main
tegeleti	doc_617668397756_item	2768103	et	3	main
loomapidamisega	doc_617668397756_item	2768104	et	3	main
ka	doc_617668397756_item	2768112	et	3	main
kontrolltöö	doc_617668397757_item	2768116	et	4	main
rootsiaegne	doc_617668397757_item	2768121	et	3	main
rahvakoolid	doc_617668397757_item	2768123	et	3	main
gümnaasiumid	doc_617668397757_item	2768124	et	3	main
2	doc_617668397757_item	2768126	et	2	main
balti	doc_617668397757_item	2768127	et	3	main
erikorra	doc_617668397757_item	2768128	et	3	main
vabadusvõitlus	doc_617668397756_item	2767801	et	3	main
see	doc_617668397756_item	2767806	et	3	main
eestlaste	doc_617668397756_item	2767811	et	4	main
kaotusega	doc_617668397756_item	2767812	et	4	main
ei	doc_617668397756_item	2767813	et	4	main
arust	doc_617668397756_item	2767816	et	4	main
mitmeks	doc_617668397756_item	2767831	et	4	main
neil	doc_617668397756_item	2767847	et	4	main
järgi	doc_617668397756_item	2767851	et	4	main
eestlastel	doc_617668397756_item	2767857	et	4	main
igasugune	doc_617668397756_item	2767858	et	3	main
väljaõpe	doc_617668397756_item	2767859	et	3	main
kui	doc_617668397756_item	2767860	et	3	main
nad	doc_617668397756_item	2767869	et	3	main
professionaalsem	doc_617668397756_item	2767872	et	4	main
eestlastel	doc_617668397756_item	2767874	et	4	main
mõõgad	doc_617668397756_item	2767881	et	3	main
ja	doc_617668397756_item	2767882	et	3	main
nooled	doc_617668397756_item	2767883	et	3	main
linn	doc_617668397756_item	2767915	et	3	main
toimus	doc_617668397756_item	2767922	et	3	main
peamiselt	doc_617668397756_item	2767935	et	4	main
välja	doc_617668397756_item	2767943	et	4	main
aga	doc_617668397756_item	2767944	et	3	main
oli	doc_617668397756_item	2767950	et	3	main
kasvatatav	doc_617668397756_item	2767953	et	4	main
tunti	doc_617668397756_item	2767954	et	3	main
raha	doc_617668397756_item	2767956	et	4	main
oli	doc_617668397756_item	2767974	et	3	main
oli	doc_617668397756_item	2767978	et	3	main
käimist	doc_617668397756_item	2767987	et	4	main
märkima	doc_617668397756_item	2767993	et	4	main
kes	doc_617668397756_item	2767998	et	4	main
olla	doc_617668397756_item	2768025	et	3	main
kus	doc_617668397756_item	2768027	et	3	main
selle	doc_617668397756_item	2768032	et	4	main
nüüd	doc_617668397756_item	2768060	et	4	main
parem	doc_617668397756_item	2768061	et	4	main
võis	doc_617668397756_item	2768078	et	4	main
raua	doc_617668397756_item	2768084	et	3	main
erinevaid	doc_617668397756_item	2768091	et	4	main
leiutisi	doc_617668397756_item	2768092	et	3	main
osaliselt	doc_617668397756_item	2768105	et	4	main
kontrolltöö	doc_617668397757_item	2768117	et	4	main
1	doc_617668397757_item	2768120	et	2	main
hariduselu	doc_617668397757_item	2768122	et	4	main
r	doc_617668397757_item	2768137	et	4	main
1	doc_617668397757_item	2768146	et	2	main
kuna	doc_617668397757_item	2768147	et	3	main
laastava	doc_617668397757_item	2768148	et	4	main
talupoegi	doc_617668397757_item	2768165	et	4	main
õpetati	doc_617668397757_item	2768166	et	3	main
niivõrd	doc_617668397757_item	2768167	et	3	main
kuivõrd	doc_617668397757_item	2768168	et	3	main
kodus	doc_617668397757_item	2768169	et	4	main
ja	doc_617668397757_item	2768170	et	3	main
ka	doc_617668397757_item	2768171	et	3	main
asutas	doc_617668397757_item	2768178	et	3	main
seminari	doc_617668397757_item	2768181	et	4	main
uusi	doc_617668397757_item	2768183	et	3	main
õpetajaid	doc_617668397757_item	2768184	et	4	main
maakoolidesse	doc_617668397757_item	2768185	et	3	main
ülikoolis	doc_617668397757_item	2768219	et	4	main
õppida	doc_617668397757_item	2768220	et	3	main
ei	doc_617668397756_item	2767824	et	4	main
jagunesid	doc_617668397756_item	2767830	et	4	main
ei	doc_617668397756_item	2767834	et	4	main
ka	doc_617668397756_item	2767836	et	3	main
ühist	doc_617668397756_item	2767837	et	3	main
sõjaväge	doc_617668397756_item	2767838	et	3	main
kus	doc_617668397756_item	2767839	et	3	main
oleks	doc_617668397756_item	2767840	et	3	main
sõdurid	doc_617668397756_item	2767843	et	3	main
ühise	doc_617668397756_item	2767849	et	3	main
võita	doc_617668397756_item	2767853	et	4	main
teiseks	doc_617668397756_item	2767855	et	4	main
puudus	doc_617668397756_item	2767856	et	4	main
on	doc_617668397756_item	2767866	et	4	main
näha	doc_617668397756_item	2767867	et	3	main
kui	doc_617668397756_item	2767878	et	3	main
vastasel	doc_617668397756_item	2767879	et	3	main
olid	doc_617668397756_item	2767880	et	4	main
nad	doc_617668397756_item	2767886	et	3	main
hobuseid	doc_617668397756_item	2767887	et	4	main
kasutades	doc_617668397756_item	2767888	et	3	main
siis	doc_617668397756_item	2767889	et	3	main
eestlane	doc_617668397756_item	2767890	et	3	main
oli	doc_617668397756_item	2767891	et	3	main
jala	doc_617668397756_item	2767892	et	4	main
ja	doc_617668397756_item	2767893	et	3	main
leppima	doc_617668397756_item	2767895	et	3	main
pidi	doc_617668397756_item	2767894	et	4	main
rehaga	doc_617668397756_item	2767896	et	3	main
ja	doc_617668397756_item	2767897	et	3	main
muude	doc_617668397756_item	2767898	et	4	main
põllundusest	doc_617668397756_item	2767899	et	4	main
laenatud	doc_617668397756_item	2767900	et	4	main
esemetega	doc_617668397756_item	2767901	et	3	main
need	doc_617668397756_item	2767902	et	3	main
3	doc_617668397756_item	2767903	et	2	main
ülaltoodud	doc_617668397756_item	2767904	et	3	main
põhjust	doc_617668397756_item	2767905	et	4	main
olid	doc_617668397756_item	2767906	et	4	main
minu	doc_617668397756_item	2767907	et	3	main
arvates	doc_617668397756_item	2767908	et	4	main
kõige	doc_617668397756_item	2767909	et	4	main
mõjuvamad	doc_617668397756_item	2767910	et	4	main
2	doc_617668397756_item	2767911	et	2	main
linnakultuur	doc_617668397756_item	2767912	et	3	main
keskaegsel	doc_617668397756_item	2767913	et	3	main
eestimaal	doc_617668397756_item	2767914	et	4	main
kolmandaks	doc_617668397756_item	2767873	et	4	main
relvastus	doc_617668397756_item	2767877	et	4	main
liikusid	doc_617668397756_item	2767885	et	4	main
elu	doc_617668397756_item	2767918	et	4	main
keskajal	doc_617668397756_item	2767917	et	3	main
paljudes	doc_617668397756_item	2767920	et	3	main
sadamalinnades	doc_617668397756_item	2767928	et	3	main
kus	doc_617668397756_item	2767929	et	3	main
toimus	doc_617668397756_item	2767930	et	3	main
see	doc_617668397756_item	2767937	et	3	main
vilja	doc_617668397756_item	2767945	et	4	main
palju	doc_617668397756_item	2767947	et	4	main
muud	doc_617668397756_item	2767948	et	4	main
mis	doc_617668397756_item	2767949	et	4	main
siinmaal	doc_617668397756_item	2767952	et	4	main
ka	doc_617668397756_item	2767955	et	3	main
tihti	doc_617668397756_item	2767959	et	3	main
keset	doc_617668397756_item	2767981	et	4	main
ära	doc_617668397756_item	2767992	et	4	main
meistrite	doc_617668397756_item	2768029	et	3	main
merelt	doc_617668397756_item	2768035	et	3	main
toimusid	doc_617668397756_item	2768041	et	4	main
muutused	doc_617668397756_item	2768043	et	4	main
muutus	doc_617668397756_item	2768052	et	4	main
elu	doc_617668397756_item	2768054	et	4	main
põllunduses	doc_617668397756_item	2768056	et	3	main
mugavam	doc_617668397756_item	2768062	et	4	main
tulemusi	doc_617668397756_item	2768072	et	4	main
müüa	doc_617668397756_item	2768080	et	3	main
või	doc_617668397756_item	2768081	et	4	main
leitud	doc_617668397756_item	2768090	et	4	main
leidlik	doc_617668397756_item	2768100	et	3	main
küttimine	doc_617668397756_item	2768109	et	4	main
ebavajalikuks	doc_617668397756_item	2768110	et	3	main
nagu	doc_617668397756_item	2768111	et	3	main
asendus	doc_617668397756_item	2768114	et	4	main
kultuuriloost	doc_617668397757_item	2768119	et	4	main
polnud	doc_617668397757_item	2768152	et	3	main
õpetajaid	doc_617668397757_item	2768158	et	4	main
siis	doc_617668397757_item	2768161	et	3	main
hariduselu	doc_617668397757_item	2768163	et	4	main
alguses	doc_617668397757_item	2768177	et	4	main
oli	doc_617668397757_item	2768221	et	3	main
talupoegadel	doc_617668397757_item	2768223	et	3	main
õppisid	doc_617668397757_item	2768231	et	4	main
14	doc_617668397757_item	2768235	et	2	main
gümnaasiumides	doc_617668397757_item	2768248	et	3	main
jõukamate	doc_617668397757_item	2768250	et	4	main
kohati	doc_617668397757_item	2768254	et	4	main
lõpetamist	doc_617668397757_item	2768262	et	4	main
2	doc_617668397757_item	2768273	et	2	main
küll	doc_617668397757_item	2768277	et	4	main
eestlastele	doc_617668397757_item	2768278	et	4	main
sellel	doc_617668397757_item	2768283	et	4	main
keel	doc_617668397757_item	2768295	et	4	main
ja	doc_617668397757_item	2768296	et	3	main
kohalik	doc_617668397757_item	2768297	et	3	main
kultuur	doc_617668397757_item	2768298	et	3	main
eesti	doc_617668397757_item	2768299	et	4	main
tänu	doc_617668397757_item	2768304	et	4	main
sai	doc_617668397757_item	2768306	et	4	main
ja	doc_617668397757_item	2768309	et	3	main
kultuuriline	doc_617668397757_item	2768310	et	4	main
kontakt	doc_617668397757_item	2768311	et	3	main
välismaailmaga	doc_617668397757_item	2768312	et	3	main
eesti	doc_617668397757_item	2768313	et	4	main
sadamaid	doc_617668397757_item	2768314	et	3	main
ning	doc_617668397757_item	2768318	et	3	main
eestis	doc_617668397757_item	2768321	et	3	main
võimaldas	doc_617668397757_item	2768327	et	3	main
kohaliku	doc_617668397757_item	2768328	et	3	main
rikastumist	doc_617668397757_item	2768330	et	4	main
aadlikud	doc_617668397757_item	2768331	et	3	main
ennekõike	doc_617668397757_item	2768332	et	3	main
erinevalt	doc_617668397757_item	2768333	et	4	main
luterlik	doc_617668397757_item	2768339	et	4	main
omakorda	doc_617668397757_item	2768342	et	3	main
propageeris	doc_617668397757_item	2768345	et	3	main
koolides	doc_617668397757_item	2768349	et	3	main
saksa	doc_617668397757_item	2768354	et	4	main
üldlaulupidu	doc_617668397757_item	2768362	et	4	main
kehtestati	doc_617668397757_item	2768368	et	3	main
määrused	doc_617668397757_item	2768370	et	3	main
tegelased	doc_617668397757_item	2768402	et	3	main
kõiges	doc_617668397757_item	2768408	et	4	main
linnades	doc_617668397756_item	2767921	et	3	main
sisse	doc_617668397756_item	2767934	et	4	main
müüdi	doc_617668397756_item	2767942	et	4	main
abiga	doc_617668397756_item	2767958	et	3	main
ost	doc_617668397756_item	2767962	et	3	main
kirik	doc_617668397756_item	2767975	et	3	main
kirik	doc_617668397756_item	2767980	et	3	main
linna	doc_617668397756_item	2767982	et	4	main
ristiusuga	doc_617668397756_item	2767984	et	3	main
et	doc_617668397756_item	2767994	et	3	main
muulaste	doc_617668397756_item	2767997	et	4	main
parajasti	doc_617668397756_item	2767999	et	3	main
riigivõimu	doc_617668397756_item	2768000	et	4	main
juures	doc_617668397756_item	2768001	et	4	main
oli	doc_617668397756_item	2768002	et	3	main
vahel	doc_617668397756_item	2768003	et	4	main
oli	doc_617668397756_item	2768004	et	3	main
nn	doc_617668397756_item	2768005	et	4	main
kultuurkihtide	doc_617668397756_item	2768006	et	3	main
erinevus	doc_617668397756_item	2768007	et	4	main
väga	doc_617668397756_item	2768008	et	3	main
harva	doc_617668397756_item	2768009	et	4	main
olid	doc_617668397756_item	2768010	et	4	main
nad	doc_617668397756_item	2768011	et	3	main
eestlased	doc_617668397756_item	2768012	et	3	main
mingisugusel	doc_617668397756_item	2768013	et	3	main
tähtsal	doc_617668397756_item	2768014	et	3	main
ametil	doc_617668397756_item	2768015	et	3	main
pigem	doc_617668397756_item	2768016	et	3	main
jäid	doc_617668397756_item	2768017	et	4	main
nad	doc_617668397756_item	2768018	et	3	main
meistriteks	doc_617668397756_item	2768019	et	3	main
ja	doc_617668397756_item	2768020	et	3	main
talupoegadeks	doc_617668397756_item	2768021	et	3	main
keskplatsil	doc_617668397756_item	2768023	et	3	main
võis	doc_617668397756_item	2768024	et	4	main
kaubeldi	doc_617668397756_item	2768028	et	3	main
toodetega	doc_617668397756_item	2768030	et	3	main
1	doc_617668397756_item	2768037	et	2	main
kiviajast	doc_617668397756_item	2768039	et	4	main
mõningad	doc_617668397756_item	2768042	et	3	main
eestlaste	doc_617668397756_item	2768044	et	4	main
materiaalses	doc_617668397756_item	2768045	et	3	main
ja	doc_617668397756_item	2768046	et	3	main
vaimses	doc_617668397756_item	2768047	et	3	main
kultuuris	doc_617668397756_item	2768048	et	3	main
seoses	doc_617668397756_item	2768049	et	4	main
raua	doc_617668397756_item	2768050	et	3	main
süsteemile	doc_617668397756_item	2768068	et	3	main
tõi	doc_617668397756_item	2768070	et	3	main
varsti	doc_617668397756_item	2768073	et	3	main
mida	doc_617668397756_item	2768077	et	4	main
rauast	doc_617668397756_item	2768093	et	4	main
muutus	doc_617668397756_item	2768108	et	4	main
eesti	doc_617668397757_item	2768118	et	4	main
ülikool	doc_617668397757_item	2768125	et	4	main
positiivsed	doc_617668397757_item	2768129	et	3	main
tagajärjed	doc_617668397757_item	2768130	et	3	main
eestlaste	doc_617668397757_item	2768131	et	4	main
kultuuri-	doc_617668397757_item	2768132	et	4	main
ja	doc_617668397757_item	2768133	et	3	main
majanduselule	doc_617668397757_item	2768134	et	3	main
3	doc_617668397757_item	2768135	et	2	main
liikumise	doc_617668397757_item	2768143	et	4	main
sõja	doc_617668397757_item	2768150	et	3	main
oli	doc_617668397757_item	2768159	et	3	main
käis	doc_617668397757_item	2768162	et	4	main
alla	doc_617668397757_item	2768164	et	3	main
saj	doc_617668397757_item	2768176	et	4	main
ta	doc_617668397757_item	2768186	et	4	main
sai	doc_617668397757_item	2768187	et	4	main
rootsi	doc_617668397757_item	2768188	et	4	main
kuningalt	doc_617668397757_item	2768189	et	4	main
loa	doc_617668397757_item	2768190	et	4	main
asutada	doc_617668397757_item	2768191	et	3	main
koole	doc_617668397757_item	2768192	et	4	main
just	doc_617668397757_item	2768193	et	3	main
sinna	doc_617668397757_item	2768194	et	3	main
kus	doc_617668397757_item	2768195	et	3	main
seda	doc_617668397757_item	2768196	et	3	main
vaja	doc_617668397757_item	2768197	et	4	main
hakkas	doc_617668397757_item	2768199	et	3	main
hariduselu	doc_617668397757_item	2768198	et	4	main
toibuma	doc_617668397757_item	2768200	et	3	main
asutati	doc_617668397757_item	2768201	et	4	main
rahvakoole	doc_617668397757_item	2768202	et	4	main
ja	doc_617668397757_item	2768203	et	3	main
suurematesse	doc_617668397757_item	2768204	et	4	main
linnadesse	doc_617668397757_item	2768205	et	3	main
isegi	doc_617668397757_item	2768206	et	4	main
esimesed	doc_617668397757_item	2768207	et	3	main
gümnaasiumid	doc_617668397757_item	2768208	et	3	main
avati	doc_617668397757_item	2768209	et	3	main
tartu	doc_617668397757_item	2768210	et	4	main
ülikool	doc_617668397757_item	2768211	et	4	main
mis	doc_617668397757_item	2768212	et	4	main
on	doc_617668397757_item	2768213	et	4	main
siis	doc_617668397757_item	2768214	et	3	main
eesti	doc_617668397757_item	2768215	et	4	main
vanim	doc_617668397757_item	2768216	et	3	main
ülikool	doc_617668397757_item	2768217	et	4	main
võimalus	doc_617668397757_item	2768218	et	3	main
jakobson	doc_617668397757_item	2768138	et	4	main
ja	doc_617668397757_item	2768139	et	3	main
j	doc_617668397757_item	2768140	et	4	main
hurt	doc_617668397757_item	2768141	et	3	main
rahvusliku	doc_617668397757_item	2768142	et	3	main
liivi	doc_617668397757_item	2768149	et	4	main
säilinud	doc_617668397757_item	2768153	et	4	main
koole	doc_617668397757_item	2768155	et	4	main
ja	doc_617668397757_item	2768156	et	3	main
kõstri	doc_617668397757_item	2768173	et	4	main
abiga	doc_617668397757_item	2768174	et	3	main
17	doc_617668397757_item	2768175	et	2	main
forselius	doc_617668397757_item	2768179	et	4	main
neid	doc_617668397757_item	2768225	et	4	main
7	doc_617668397757_item	2768234	et	2	main
lõppes	doc_617668397757_item	2768247	et	4	main
peale	doc_617668397757_item	2768260	et	4	main
rahvakooli	doc_617668397757_item	2768261	et	4	main
käisid	doc_617668397757_item	2768264	et	4	main
baltisakslased	doc_617668397757_item	2768266	et	3	main
erikord	doc_617668397757_item	2768275	et	3	main
oli	doc_617668397757_item	2768276	et	3	main
positiivsed	doc_617668397757_item	2768285	et	3	main
sellele	doc_617668397757_item	2768288	et	4	main
eesti	doc_617668397757_item	2768294	et	4	main
läänemaailmale	doc_617668397757_item	2768302	et	4	main
majanduslik	doc_617668397757_item	2768308	et	3	main
tähtsamad	doc_617668397757_item	2768144	et	4	main
tegelased	doc_617668397757_item	2768145	et	3	main
tulemusena	doc_617668397757_item	2768151	et	3	main
enam	doc_617668397757_item	2768154	et	4	main
ka	doc_617668397757_item	2768157	et	3	main
vähe	doc_617668397757_item	2768160	et	3	main
küla	doc_617668397757_item	2768172	et	4	main
õpetajate	doc_617668397757_item	2768180	et	4	main
ettevalmistamaks	doc_617668397757_item	2768182	et	4	main
ka	doc_617668397757_item	2768222	et	3	main
kuigi	doc_617668397757_item	2768224	et	3	main
palju	doc_617668397757_item	2768226	et	4	main
sinna	doc_617668397757_item	2768227	et	3	main
ei	doc_617668397757_item	2768228	et	4	main
jõudnud	doc_617668397757_item	2768229	et	4	main
aastased	doc_617668397757_item	2768236	et	4	main
ja	doc_617668397757_item	2768238	et	3	main
toimus	doc_617668397757_item	2768240	et	3	main
talviti	doc_617668397757_item	2768241	et	3	main
enamasti	doc_617668397757_item	2768242	et	4	main
sellega	doc_617668397757_item	2768243	et	3	main
ka	doc_617668397757_item	2768244	et	3	main
talupoegade	doc_617668397757_item	2768245	et	3	main
hariduselu	doc_617668397757_item	2768246	et	4	main
käisid	doc_617668397757_item	2768249	et	4	main
linnakodanike	doc_617668397757_item	2768251	et	3	main
ning	doc_617668397757_item	2768253	et	3	main
ka	doc_617668397757_item	2768255	et	3	main
targemad	doc_617668397757_item	2768256	et	4	main
tartu	doc_617668397757_item	2768267	et	4	main
ka	doc_617668397757_item	2768270	et	3	main
palju	doc_617668397757_item	2768271	et	4	main
välisüliõpilasi	doc_617668397757_item	2768272	et	3	main
olid	doc_617668397757_item	2768282	et	4	main
tänu	doc_617668397757_item	2768287	et	4	main
venestamist	doc_617668397757_item	2768291	et	4	main
ja	doc_617668397757_item	2768292	et	3	main
jäi	doc_617668397757_item	2768300	et	3	main
avatuks	doc_617668397757_item	2768301	et	4	main
kasutati	doc_617668397757_item	2768315	et	4	main
maksusüsteem	doc_617668397757_item	2768325	et	3	main
rahva	doc_617668397757_item	2768329	et	3	main
ning	doc_617668397757_item	2768347	et	3	main
ja	doc_617668397757_item	2768353	et	3	main
tänu	doc_617668397757_item	2768356	et	4	main
esimene	doc_617668397757_item	2768361	et	3	main
positiivsed	doc_617668397757_item	2768369	et	3	main
vabastati	doc_617668397757_item	2768372	et	3	main
aga	doc_617668397757_item	2768403	et	3	main
olnud	doc_617668397757_item	2768406	et	4	main
c	doc_617668397757_item	2768411	et	4	main
oli	doc_617668397757_item	2768414	et	3	main
kes	doc_617668397757_item	2768420	et	4	main
paistis	doc_617668397757_item	2768421	et	3	main
oma	doc_617668397757_item	2768423	et	4	main
kõnede	doc_617668397757_item	2768424	et	3	main
ajalehega	doc_617668397757_item	2768426	et	3	main
lootis	doc_617668397757_item	2768433	et	3	main
oli	doc_617668397757_item	2768438	et	3	main
iseseisvust	doc_617668397757_item	2768446	et	4	main
oli	doc_617668397757_item	2768452	et	3	main
saksa	doc_617668397757_item	2768453	et	4	main
et	doc_617668397757_item	2768459	et	3	main
pidades	doc_617668397757_item	2768465	et	3	main
suur	doc_617668397757_item	2768467	et	3	main
selle	doc_617668397757_item	2768471	et	4	main
ülestõus	doc_617668397758_item	2768498	et	4	main
tähtsus	doc_617668397758_item	2768500	et	4	main
rooma	doc_617668397758_item	2768513	et	4	main
rauaajaks	doc_617668397758_item	2768514	et	3	main
rauaajaks	doc_617668397758_item	2768516	et	3	main
rauaaeg	doc_617668397758_item	2768525	et	3	main
pronksiajast	doc_617668397758_item	2768542	et	4	main
eel	doc_617668397758_item	2768543	et	4	main
rauda	doc_617668397758_item	2768552	et	4	main
osatud	doc_617668397758_item	2768554	et	4	main
sellest	doc_617668397758_item	2768563	et	4	main
esemeid	doc_617668397758_item	2768564	et	3	main
valmistama	doc_617668397758_item	2768565	et	3	main
oli	doc_617668397758_item	2768566	et	3	main
tehtud	doc_617668397758_item	2768579	et	4	main
tavaliselt	doc_617668397757_item	2768232	et	4	main
lapsed	doc_617668397757_item	2768252	et	3	main
enamasti	doc_617668397757_item	2768265	et	4	main
balti	doc_617668397757_item	2768274	et	3	main
rõhuv	doc_617668397757_item	2768279	et	4	main
teatud	doc_617668397757_item	2768284	et	4	main
säilis	doc_617668397757_item	2768293	et	4	main
sellele	doc_617668397757_item	2768305	et	4	main
toimuda	doc_617668397757_item	2768307	et	3	main
impordiks	doc_617668397757_item	2768317	et	4	main
ka	doc_617668397757_item	2768319	et	3	main
ekspordiks	doc_617668397757_item	2768320	et	4	main
oli	doc_617668397757_item	2768322	et	3	main
oma	doc_617668397757_item	2768323	et	4	main
eestis	doc_617668397757_item	2768337	et	3	main
lubatud	doc_617668397757_item	2768338	et	4	main
mis	doc_617668397757_item	2768341	et	4	main
eesti	doc_617668397757_item	2768352	et	4	main
erikorrale	doc_617668397757_item	2768358	et	3	main
sai	doc_617668397757_item	2768359	et	4	main
eesti	doc_617668397757_item	2768364	et	4	main
kirjasõna	doc_617668397757_item	2768366	et	4	main
18161819	doc_617668397757_item	2768371	et	2	main
tähtsaimad	doc_617668397757_item	2768401	et	4	main
ometigi	doc_617668397757_item	2768404	et	4	main
arvamusel	doc_617668397757_item	2768410	et	3	main
rahvusliku	doc_617668397757_item	2768415	et	3	main
rahvakoolis	doc_617668397757_item	2768230	et	4	main
kuskil	doc_617668397757_item	2768233	et	3	main
lapsed	doc_617668397757_item	2768237	et	3	main
õppetöö	doc_617668397757_item	2768239	et	4	main
talupojad	doc_617668397757_item	2768257	et	4	main
gümnaasiumisse	doc_617668397757_item	2768258	et	3	main
mindi	doc_617668397757_item	2768259	et	3	main
ülikoolis	doc_617668397757_item	2768263	et	4	main
ülikoolis	doc_617668397757_item	2768268	et	4	main
käis	doc_617668397757_item	2768269	et	4	main
aga	doc_617668397757_item	2768280	et	3	main
siiski	doc_617668397757_item	2768281	et	4	main
omadused	doc_617668397757_item	2768286	et	4	main
ei	doc_617668397757_item	2768289	et	4	main
toimunud	doc_617668397757_item	2768290	et	4	main
ja	doc_617668397757_item	2768303	et	3	main
kauba	doc_617668397757_item	2768316	et	3	main
kohalik	doc_617668397757_item	2768324	et	3	main
mis	doc_617668397757_item	2768326	et	4	main
soosis	doc_617668397757_item	2768343	et	4	main
lugemisoskust	doc_617668397757_item	2768348	et	3	main
toimus	doc_617668397757_item	2768350	et	3	main
keeles	doc_617668397757_item	2768355	et	4	main
levis	doc_617668397757_item	2768363	et	4	main
keelne	doc_617668397757_item	2768365	et	3	main
pärisorjusest	doc_617668397757_item	2768374	et	4	main
nad	doc_617668397757_item	2768407	et	3	main
jakobson	doc_617668397757_item	2768413	et	4	main
esindaja	doc_617668397757_item	2768419	et	4	main
silma	doc_617668397757_item	2768422	et	4	main
oli	doc_617668397757_item	2768427	et	3	main
suuna	doc_617668397757_item	2768429	et	4	main
st	doc_617668397757_item	2768431	et	3	main
jhurt	doc_617668397757_item	2768437	et	4	main
ja	doc_617668397757_item	2768440	et	3	main
taotles	doc_617668397757_item	2768442	et	3	main
toetaja	doc_617668397757_item	2768455	et	4	main
leidis	doc_617668397757_item	2768458	et	4	main
tuleks	doc_617668397757_item	2768461	et	4	main
saavutada	doc_617668397757_item	2768462	et	3	main
mõisnikega	doc_617668397757_item	2768463	et	3	main
oli	doc_617668397757_item	2768466	et	3	main
on	doc_617668397758_item	2768501	et	4	main
üks	doc_617668397758_item	2768520	et	3	main
sai	doc_617668397758_item	2768526	et	4	main
kuskil	doc_617668397758_item	2768528	et	3	main
ja	doc_617668397758_item	2768532	et	3	main
12	doc_617668397758_item	2768535	et	2	main
rauast	doc_617668397758_item	2768547	et	4	main
esemeid	doc_617668397758_item	2768548	et	3	main
kasutusel	doc_617668397758_item	2768549	et	4	main
rauda	doc_617668397758_item	2768560	et	4	main
ühiskonnas	doc_617668397758_item	2768569	et	4	main
tööriistad	doc_617668397758_item	2768572	et	3	main
sai	doc_617668397758_item	2768578	et	4	main
oli	doc_617668397758_item	2768618	et	3	main
2	doc_617668397758_item	2768620	et	2	main
oli	doc_617668397758_item	2768630	et	3	main
võeti	doc_617668397758_item	2768637	et	3	main
talivili	doc_617668397758_item	2768639	et	3	main
välja	doc_617668397758_item	2768641	et	4	main
maeti	doc_617668397758_item	2768657	et	3	main
kaasa	doc_617668397758_item	2768666	et	4	main
ringikujulistesse	doc_617668397758_item	2768672	et	4	main
liivakääbastesse	doc_617668397758_item	2768675	et	3	main
suurenes	doc_617668397758_item	2768681	et	4	main
ja	doc_617668397758_item	2768692	et	3	main
saare	doc_617668397758_item	2768723	et	3	main
maal	doc_617668397758_item	2768727	et	4	main
erinev	doc_617668397758_item	2768731	et	4	main
veel	doc_617668397758_item	2768743	et	4	main
siiski	doc_617668397758_item	2768744	et	4	main
isiklikult	doc_617668397758_item	2768745	et	4	main
osa	doc_617668397758_item	2768760	et	4	main
hiljem	doc_617668397758_item	2768764	et	3	main
pühul	doc_617668397758_item	2768808	et	4	main
teataval	doc_617668397758_item	2768811	et	4	main
ristiusu	doc_617668397758_item	2768820	et	3	main
jüriöö	doc_617668397758_item	2768823	et	4	main
1543	doc_617668397758_item	2768826	et	2	main
olid	doc_617668397758_item	2768836	et	4	main
tsaari	doc_617668397757_item	2768334	et	4	main
venemaast	doc_617668397757_item	2768335	et	3	main
oli	doc_617668397757_item	2768336	et	3	main
kirik	doc_617668397757_item	2768340	et	3	main
ja	doc_617668397757_item	2768344	et	3	main
haridust	doc_617668397757_item	2768346	et	4	main
õpe	doc_617668397757_item	2768351	et	3	main
balti	doc_617668397757_item	2768357	et	3	main
toimuda	doc_617668397757_item	2768360	et	3	main
talupoegadele	doc_617668397757_item	2768367	et	3	main
nad	doc_617668397757_item	2768373	et	3	main
ja	doc_617668397757_item	2768375	et	3	main
18491856	doc_617668397757_item	2768376	et	2	main
said	doc_617668397757_item	2768377	et	4	main
õiguse	doc_617668397757_item	2768378	et	4	main
talu	doc_617668397757_item	2768379	et	4	main
päriseks	doc_617668397757_item	2768380	et	4	main
osta	doc_617668397757_item	2768381	et	4	main
ja	doc_617668397757_item	2768382	et	3	main
seda	doc_617668397757_item	2768383	et	3	main
pärandada	doc_617668397757_item	2768384	et	3	main
talude	doc_617668397757_item	2768385	et	3	main
päriseksostmisega	doc_617668397757_item	2768386	et	3	main
ja	doc_617668397757_item	2768387	et	3	main
raharendile	doc_617668397757_item	2768388	et	3	main
üleminekuga	doc_617668397757_item	2768389	et	3	main
tõusis	doc_617668397757_item	2768390	et	4	main
talupoegade	doc_617668397757_item	2768391	et	3	main
jõukus	doc_617668397757_item	2768392	et	4	main
jacobson	doc_617668397757_item	2768394	et	4	main
ja	doc_617668397757_item	2768395	et	3	main
r	doc_617668397757_item	2768393	et	4	main
j	doc_617668397757_item	2768396	et	4	main
hurt	doc_617668397757_item	2768397	et	3	main
on	doc_617668397757_item	2768398	et	4	main
liikumise	doc_617668397757_item	2768400	et	4	main
rahvusliku	doc_617668397757_item	2768399	et	3	main
ei	doc_617668397757_item	2768405	et	4	main
samal	doc_617668397757_item	2768409	et	3	main
liikumise	doc_617668397757_item	2768416	et	4	main
vene	doc_617668397757_item	2768428	et	4	main
toetaja	doc_617668397757_item	2768430	et	4	main
vene	doc_617668397757_item	2768435	et	4	main
rohkem	doc_617668397757_item	2768443	et	4	main
kultuurilist	doc_617668397757_item	2768445	et	4	main
ja	doc_617668397757_item	2768447	et	3	main
arengut	doc_617668397757_item	2768448	et	3	main
kui	doc_617668397757_item	2768449	et	3	main
poliitilist	doc_617668397757_item	2768450	et	3	main
iseseisvust	doc_617668397757_item	2768451	et	4	main
koguja	doc_617668397757_item	2768469	et	4	main
jaguneb	doc_617668397758_item	2768511	et	3	main
eel	doc_617668397758_item	2768512	et	4	main
rooma	doc_617668397758_item	2768515	et	4	main
ja	doc_617668397758_item	2768517	et	3	main
hilisrauaaja	doc_617668397758_item	2768519	et	3	main
osa	doc_617668397758_item	2768521	et	4	main
veel	doc_617668397758_item	2768523	et	4	main
viikingiaeg	doc_617668397758_item	2768524	et	3	main
esimesel	doc_617668397758_item	2768529	et	3	main
umbes	doc_617668397758_item	2768534	et	4	main
13	doc_617668397758_item	2768536	et	2	main
sajandil	doc_617668397758_item	2768537	et	3	main
pkr	doc_617668397758_item	2768538	et	4	main
rauaaeg	doc_617668397758_item	2768539	et	3	main
kasvas	doc_617668397758_item	2768540	et	3	main
välja	doc_617668397758_item	2768541	et	4	main
ei	doc_617668397758_item	2768553	et	4	main
sulatama	doc_617668397758_item	2768561	et	4	main
ning	doc_617668397758_item	2768562	et	3	main
see	doc_617668397758_item	2768567	et	3	main
murranguks	doc_617668397758_item	2768568	et	3	main
eriti	doc_617668397758_item	2768571	et	3	main
olid	doc_617668397758_item	2768573	et	4	main
vastupidavamad	doc_617668397758_item	2768576	et	4	main
välja	doc_617668397758_item	2768621	et	4	main
st	doc_617668397758_item	2768623	et	3	main
et	doc_617668397758_item	2768624	et	3	main
ajal	doc_617668397758_item	2768626	et	4	main
üks	doc_617668397758_item	2768628	et	3	main
teine	doc_617668397758_item	2768633	et	3	main
inimesed	doc_617668397758_item	2768645	et	3	main
rikkamaks	doc_617668397758_item	2768647	et	4	main
sest	doc_617668397758_item	2768648	et	4	main
talle	doc_617668397758_item	2768665	et	4	main
pandud	doc_617668397758_item	2768667	et	4	main
asjadega	doc_617668397758_item	2768668	et	3	main
maeti	doc_617668397758_item	2768670	et	3	main
ning	doc_617668397758_item	2768674	et	3	main
ja	doc_617668397758_item	2768678	et	3	main
hulk	doc_617668397758_item	2768684	et	3	main
ka	doc_617668397758_item	2768686	et	3	main
levis	doc_617668397758_item	2768689	et	4	main
kudumise	doc_617668397758_item	2768691	et	4	main
moodustati	doc_617668397758_item	2768722	et	3	main
piiskopkond	doc_617668397758_item	2768725	et	3	main
võim	doc_617668397758_item	2768729	et	3	main
oli	doc_617668397758_item	2768730	et	3	main
mõneti	doc_617668397758_item	2768736	et	3	main
vallutamist	doc_617668397758_item	2768740	et	4	main
jäi	doc_617668397758_item	2768741	et	3	main
talupoeg	doc_617668397758_item	2768742	et	3	main
maksma	doc_617668397758_item	2768753	et	3	main
sellele	doc_617668397758_item	2768766	et	4	main
raha	doc_617668397758_item	2768768	et	4	main
vöörvõimu	doc_617668397758_item	2768770	et	4	main
ajal	doc_617668397758_item	2768771	et	4	main
seoses	doc_617668397758_item	2768814	et	4	main
tulekuga	doc_617668397758_item	2768816	et	3	main
hakata	doc_617668397758_item	2768818	et	4	main
kombeid	doc_617668397758_item	2768821	et	4	main
ülestõus	doc_617668397758_item	2768824	et	4	main
toimus	doc_617668397758_item	2768825	et	3	main
1545	doc_617668397758_item	2768827	et	2	main
aastatel	doc_617668397758_item	2768828	et	4	main
liiga	doc_617668397758_item	2768837	et	4	main
rängad	doc_617668397758_item	2768838	et	3	main
koormised	doc_617668397758_item	2768839	et	3	main
r	doc_617668397757_item	2768412	et	4	main
radikaalsema	doc_617668397757_item	2768417	et	4	main
suuna	doc_617668397757_item	2768418	et	4	main
ja	doc_617668397757_item	2768425	et	3	main
rahva	doc_617668397757_item	2768444	et	3	main
st	doc_617668397757_item	2768456	et	3	main
et	doc_617668397757_item	2768457	et	3	main
edu	doc_617668397757_item	2768460	et	4	main
rahvaluule	doc_617668397757_item	2768468	et	4	main
ja	doc_617668397757_item	2768470	et	3	main
kogumise	doc_617668397757_item	2768472	et	4	main
missugune	doc_617668397758_item	2768499	et	3	main
sellel	doc_617668397758_item	2768502	et	4	main
eestlaste	doc_617668397758_item	2768504	et	4	main
aja-	doc_617668397758_item	2768505	et	4	main
ja	doc_617668397758_item	2768506	et	3	main
kultuuriloos	doc_617668397758_item	2768507	et	4	main
1	doc_617668397758_item	2768508	et	2	main
rauaaeg	doc_617668397758_item	2768509	et	3	main
eestis	doc_617668397758_item	2768510	et	3	main
et	doc_617668397757_item	2768432	et	3	main
abi	doc_617668397757_item	2768434	et	4	main
tsaarilt	doc_617668397757_item	2768436	et	3	main
tagasihoidlikum	doc_617668397757_item	2768439	et	4	main
tasakaalukam	doc_617668397757_item	2768441	et	4	main
suuna	doc_617668397757_item	2768454	et	4	main
läbirääkimisi	doc_617668397757_item	2768464	et	3	main
organiseerija	doc_617668397757_item	2768473	et	4	main
c	doc_617668397757_item	2768474	et	4	main
r	doc_617668397757_item	2768475	et	4	main
jakobson	doc_617668397757_item	2768476	et	4	main
tõi	doc_617668397757_item	2768477	et	3	main
ärkamisaja	doc_617668397757_item	2768478	et	3	main
kohta	doc_617668397757_item	2768479	et	4	main
kasutusele	doc_617668397757_item	2768480	et	4	main
mõiste	doc_617668397757_item	2768481	et	4	main
koiduaeg	doc_617668397757_item	2768482	et	3	main
kontrolltöö	doc_617668397758_item	2768483	et	4	main
kontrolltöö	doc_617668397758_item	2768484	et	4	main
eesti	doc_617668397758_item	2768485	et	4	main
1	doc_617668397758_item	2768487	et	2	main
rauaaeg	doc_617668397758_item	2768488	et	3	main
eestis	doc_617668397758_item	2768489	et	3	main
2	doc_617668397758_item	2768490	et	2	main
kultuuriloost	doc_617668397758_item	2768486	et	4	main
kirjelda	doc_617668397758_item	2768491	et	4	main
keskaegset	doc_617668397758_item	2768492	et	3	main
talupojakultuuri	doc_617668397758_item	2768493	et	4	main
3	doc_617668397758_item	2768494	et	2	main
millal	doc_617668397758_item	2768495	et	3	main
toimus	doc_617668397758_item	2768496	et	3	main
jüriöö	doc_617668397758_item	2768497	et	4	main
ülestõusul	doc_617668397758_item	2768503	et	3	main
hilisrauaajaks	doc_617668397758_item	2768518	et	3	main
alguse	doc_617668397758_item	2768527	et	3	main
ekr	doc_617668397758_item	2768531	et	4	main
vähe	doc_617668397758_item	2768550	et	3	main
veel	doc_617668397758_item	2768555	et	4	main
ise	doc_617668397758_item	2768556	et	4	main
sulatada	doc_617668397758_item	2768557	et	3	main
kui	doc_617668397758_item	2768558	et	3	main
õpiti	doc_617668397758_item	2768559	et	3	main
raudesemed	doc_617668397758_item	2768570	et	3	main
efektiivsemad	doc_617668397758_item	2768574	et	4	main
töö	doc_617668397758_item	2768577	et	4	main
kasutusel	doc_617668397758_item	2768631	et	4	main
kasutusele	doc_617668397758_item	2768638	et	4	main
arenes	doc_617668397758_item	2768640	et	3	main
3	doc_617668397758_item	2768642	et	2	main
süsteem	doc_617668397758_item	2768644	et	3	main
muutusid	doc_617668397758_item	2768646	et	4	main
2	doc_617668397758_item	2768651	et	2	main
ja	doc_617668397758_item	2768654	et	3	main
rauaaja	doc_617668397758_item	2768658	et	3	main
enamasti	doc_617668397758_item	2768661	et	4	main
surnu	doc_617668397758_item	2768663	et	4	main
koos	doc_617668397758_item	2768664	et	4	main
viikingiajal	doc_617668397758_item	2768669	et	3	main
tekkis	doc_617668397758_item	2768676	et	3	main
ehete	doc_617668397758_item	2768683	et	3	main
osakaal	doc_617668397758_item	2768688	et	3	main
ketramise	doc_617668397758_item	2768690	et	4	main
riide	doc_617668397758_item	2768693	et	4	main
on	doc_617668397758_item	2768522	et	4	main
aastasajal	doc_617668397758_item	2768530	et	4	main
lõppes	doc_617668397758_item	2768533	et	4	main
rooma	doc_617668397758_item	2768544	et	4	main
rauaajal	doc_617668397758_item	2768545	et	3	main
oli	doc_617668397758_item	2768546	et	3	main
sest	doc_617668397758_item	2768551	et	4	main
ning	doc_617668397758_item	2768575	et	3	main
vaevaga	doc_617668397758_item	2768583	et	4	main
mis	doc_617668397758_item	2768584	et	4	main
kõige	doc_617668397758_item	2768585	et	4	main
tätsam	doc_617668397758_item	2768586	et	4	main
rauamaaki	doc_617668397758_item	2768587	et	4	main
leidus	doc_617668397758_item	2768588	et	4	main
ka	doc_617668397758_item	2768589	et	3	main
eestialadel	doc_617668397758_item	2768590	et	3	main
tekkisid	doc_617668397758_item	2768591	et	4	main
kindlustatud	doc_617668397758_item	2768592	et	4	main
asulad	doc_617668397758_item	2768593	et	3	main
kus	doc_617668397758_item	2768594	et	3	main
raua	doc_617668397758_item	2768596	et	3	main
sulatamine	doc_617668397758_item	2768597	et	4	main
enamasti	doc_617668397758_item	2768595	et	4	main
toimuski	doc_617668397758_item	2768598	et	3	main
see	doc_617668397758_item	2768599	et	3	main
omakorda	doc_617668397758_item	2768600	et	3	main
viis	doc_617668397758_item	2768601	et	4	main
tööjõujaotumiseni	doc_617668397758_item	2768602	et	3	main
raudesemeid	doc_617668397758_item	2768603	et	3	main
vahetati	doc_617668397758_item	2768604	et	4	main
tavaliselt	doc_617668397758_item	2768605	et	4	main
vilja	doc_617668397758_item	2768606	et	4	main
eest	doc_617668397758_item	2768607	et	4	main
inimesed	doc_617668397758_item	2768608	et	3	main
elasid	doc_617668397758_item	2768609	et	4	main
suhteliselt	doc_617668397758_item	2768610	et	4	main
hajali	doc_617668397758_item	2768611	et	3	main
20	doc_617668397758_item	2768612	et	2	main
30	doc_617668397758_item	2768613	et	2	main
inimese	doc_617668397758_item	2768614	et	4	main
rauaaja	doc_617668397758_item	2768616	et	3	main
alguses	doc_617668397758_item	2768617	et	4	main
kaupa	doc_617668397758_item	2768615	et	4	main
kiiremini	doc_617668397758_item	2768580	et	4	main
ning	doc_617668397758_item	2768581	et	3	main
väiksema	doc_617668397758_item	2768582	et	4	main
levinud	doc_617668397758_item	2768619	et	4	main
sel	doc_617668397758_item	2768625	et	3	main
kui	doc_617668397758_item	2768627	et	3	main
söötis	doc_617668397758_item	2768634	et	4	main
viikingiajal	doc_617668397758_item	2768636	et	3	main
aastas	doc_617668397758_item	2768649	et	3	main
viljasaaki	doc_617668397758_item	2768652	et	4	main
suvivili	doc_617668397758_item	2768655	et	3	main
surnud	doc_617668397758_item	2768656	et	4	main
tarandkalmetesse	doc_617668397758_item	2768660	et	4	main
põletati	doc_617668397758_item	2768662	et	3	main
surnud	doc_617668397758_item	2768671	et	4	main
kalmetesse	doc_617668397758_item	2768673	et	3	main
ühikkond	doc_617668397758_item	2768677	et	4	main
killustatus	doc_617668397758_item	2768680	et	4	main
kantavate	doc_617668397758_item	2768682	et	4	main
suurenes	doc_617668397758_item	2768685	et	4	main
osavus	doc_617668397758_item	2768695	et	4	main
võeti	doc_617668397758_item	2768698	et	3	main
künniloomana	doc_617668397758_item	2768699	et	4	main
kasutusele	doc_617668397758_item	2768700	et	4	main
hobune	doc_617668397758_item	2768701	et	4	main
2	doc_617668397758_item	2768702	et	2	main
keskaeg	doc_617668397758_item	2768703	et	3	main
sai	doc_617668397758_item	2768704	et	4	main
eestis	doc_617668397758_item	2768705	et	3	main
alguse	doc_617668397758_item	2768706	et	3	main
maa	doc_617668397758_item	2768707	et	4	main
vallutamisega	doc_617668397758_item	2768708	et	4	main
muistses	doc_617668397758_item	2768709	et	3	main
vabadusvõitluses	doc_617668397758_item	2768710	et	3	main
põhja	doc_617668397758_item	2768711	et	4	main
eesti	doc_617668397758_item	2768712	et	4	main
sai	doc_617668397758_item	2768713	et	4	main
taani	doc_617668397758_item	2768714	et	4	main
lõuna	doc_617668397758_item	2768715	et	4	main
estist	doc_617668397758_item	2768716	et	4	main
saksa	doc_617668397758_item	2768717	et	4	main
ordu	doc_617668397758_item	2768718	et	4	main
ning	doc_617668397758_item	2768719	et	3	main
lääne	doc_617668397758_item	2768720	et	4	main
kuna	doc_617668397758_item	2768726	et	3	main
ka	doc_617668397758_item	2768733	et	3	main
erinevalt	doc_617668397758_item	2768737	et	4	main
küll	doc_617668397758_item	2768747	et	4	main
pidi	doc_617668397758_item	2768749	et	4	main
algul	doc_617668397758_item	2768755	et	4	main
saagist	doc_617668397758_item	2768762	et	4	main
aga	doc_617668397758_item	2768763	et	3	main
välja	doc_617668397758_item	2768798	et	4	main
oli	doc_617668397758_item	2768799	et	3	main
pulmade	doc_617668397758_item	2768803	et	3	main
lapse	doc_617668397758_item	2768806	et	4	main
sünni	doc_617668397758_item	2768807	et	4	main
muutus	doc_617668397758_item	2768813	et	4	main
ristiusu	doc_617668397758_item	2768815	et	3	main
tuli	doc_617668397758_item	2768817	et	4	main
3	doc_617668397758_item	2768822	et	2	main
lõppes	doc_617668397758_item	2768833	et	4	main
süsteem	doc_617668397758_item	2768622	et	3	main
põld	doc_617668397758_item	2768629	et	3	main
oli	doc_617668397758_item	2768632	et	3	main
kui	doc_617668397758_item	2768635	et	3	main
välja	doc_617668397758_item	2768643	et	4	main
sai	doc_617668397758_item	2768650	et	4	main
talivili	doc_617668397758_item	2768653	et	3	main
alguses	doc_617668397758_item	2768659	et	4	main
majanduslik	doc_617668397758_item	2768679	et	3	main
kaubanduse	doc_617668397758_item	2768687	et	3	main
tegemise	doc_617668397758_item	2768694	et	4	main
härja	doc_617668397758_item	2768696	et	3	main
asemel	doc_617668397758_item	2768697	et	4	main
eestis	doc_617668397758_item	2768721	et	3	main
lääne	doc_617668397758_item	2768724	et	4	main
valitsev	doc_617668397758_item	2768728	et	4	main
talupojakultuur	doc_617668397758_item	2768734	et	3	main
peale	doc_617668397758_item	2768738	et	4	main
maa	doc_617668397758_item	2768739	et	4	main
vabaks	doc_617668397758_item	2768746	et	3	main
kümnis	doc_617668397758_item	2768754	et	3	main
oli	doc_617668397758_item	2768756	et	3	main
ainult	doc_617668397758_item	2768758	et	4	main
lisandus	doc_617668397758_item	2768765	et	4	main
ka	doc_617668397758_item	2768767	et	3	main
kogu	doc_617668397758_item	2768769	et	4	main
kummardamas	doc_617668397758_item	2768795	et	3	main
jumalaid	doc_617668397758_item	2768797	et	3	main
oma	doc_617668397758_item	2768801	et	4	main
matuste	doc_617668397758_item	2768804	et	3	main
mis	doc_617668397758_item	2768809	et	4	main
määral	doc_617668397758_item	2768812	et	3	main
sai	doc_617668397758_item	2768732	et	4	main
erineda	doc_617668397758_item	2768735	et	3	main
aga	doc_617668397758_item	2768748	et	3	main
ta	doc_617668397758_item	2768750	et	4	main
mõisnikele	doc_617668397758_item	2768751	et	3	main
andamit	doc_617668397758_item	2768752	et	3	main
andamiks	doc_617668397758_item	2768757	et	3	main
teatav	doc_617668397758_item	2768759	et	4	main
talu	doc_617668397758_item	2768761	et	4	main
suutsid	doc_617668397758_item	2768772	et	4	main
eestlased	doc_617668397758_item	2768773	et	3	main
siiski	doc_617668397758_item	2768774	et	4	main
säilitada	doc_617668397758_item	2768775	et	3	main
oma	doc_617668397758_item	2768776	et	4	main
keele	doc_617668397758_item	2768777	et	4	main
rahvakultuuris	doc_617668397758_item	2768778	et	3	main
hakkasid	doc_617668397758_item	2768779	et	4	main
levima	doc_617668397758_item	2768780	et	3	main
rahvalaulud	doc_617668397758_item	2768781	et	3	main
ja	doc_617668397758_item	2768782	et	3	main
jutud	doc_617668397758_item	2768783	et	3	main
rahvas	doc_617668397758_item	2768784	et	4	main
oli	doc_617668397758_item	2768785	et	3	main
küll	doc_617668397758_item	2768787	et	4	main
sunnitud	doc_617668397758_item	2768786	et	4	main
ristiusu	doc_617668397758_item	2768788	et	3	main
vastu	doc_617668397758_item	2768789	et	3	main
võtma	doc_617668397758_item	2768790	et	3	main
aga	doc_617668397758_item	2768791	et	3	main
kohati	doc_617668397758_item	2768792	et	4	main
käidi	doc_617668397758_item	2768793	et	3	main
ikka	doc_617668397758_item	2768794	et	4	main
maausu	doc_617668397758_item	2768796	et	3	main
arenenud	doc_617668397758_item	2768800	et	4	main
kombestik	doc_617668397758_item	2768802	et	3	main
ja	doc_617668397758_item	2768805	et	3	main
aga	doc_617668397758_item	2768810	et	3	main
järgima	doc_617668397758_item	2768819	et	3	main
sai	doc_617668397758_item	2768829	et	4	main
alguse	doc_617668397758_item	2768830	et	3	main
ja	doc_617668397758_item	2768832	et	3	main
oli	doc_617668397758_item	2768851	et	3	main
katse	doc_617668397758_item	2768853	et	4	main
ka	doc_617668397758_item	2768860	et	3	main
ja	doc_617668397758_item	2768862	et	3	main
muutusid	doc_617668397758_item	2768863	et	4	main
pärisorjadeks	doc_617668397758_item	2768864	et	3	main
haridusele	doc_617668397758_item	2768903	et	3	main
talupoegadel	doc_617668397758_item	2768907	et	3	main
ka	doc_617668397758_item	2768909	et	3	main
vabadus	doc_617668397758_item	2768910	et	4	main
kuuluvat	doc_617668397758_item	2768915	et	4	main
olnud	doc_617668397758_item	2768919	et	4	main
alade	doc_617668397758_item	2768924	et	3	main
millised	doc_617668397760_item	2769251	et	3	main
materiaalses	doc_617668397760_item	2769253	et	3	main
linnakultuuri	doc_617668397760_item	2769263	et	4	main
miks	doc_617668397760_item	2769267	et	4	main
vabadusvõitlus	doc_617668397760_item	2769269	et	3	main
eestlastele	doc_617668397760_item	2769271	et	4	main
kaotusega	doc_617668397760_item	2769272	et	4	main
need	doc_617668397760_item	2769286	et	3	main
minu	doc_617668397760_item	2769288	et	3	main
tahtsamad	doc_617668397760_item	2769292	et	4	main
küttimisest	doc_617668397760_item	2769301	et	4	main
tekkis	doc_617668397760_item	2769308	et	3	main
juba	doc_617668397760_item	2769309	et	3	main
ka	doc_617668397760_item	2769314	et	3	main
muutused	doc_617668397760_item	2769316	et	4	main
harjumaalt	doc_617668397758_item	2768831	et	3	main
üldine	doc_617668397758_item	2768841	et	4	main
peetakse	doc_617668397758_item	2768845	et	3	main
talupojad	doc_617668397758_item	2768859	et	4	main
keda	doc_617668397758_item	2768870	et	4	main
võidi	doc_617668397758_item	2768871	et	4	main
osta	doc_617668397758_item	2768872	et	4	main
müüa	doc_617668397758_item	2768873	et	3	main
ja	doc_617668397758_item	2768874	et	3	main
vahetada	doc_617668397758_item	2768875	et	3	main
kultuuriliselt	doc_617668397758_item	2768876	et	4	main
oli	doc_617668397758_item	2768877	et	3	main
see	doc_617668397758_item	2768878	et	3	main
raske	doc_617668397758_item	2768879	et	4	main
aeg	doc_617668397758_item	2768880	et	3	main
sest	doc_617668397758_item	2768881	et	4	main
juuriti	doc_617668397758_item	2768882	et	3	main
välja	doc_617668397758_item	2768883	et	4	main
muistne	doc_617668397758_item	2768884	et	3	main
usund	doc_617668397758_item	2768885	et	3	main
kristlikust	doc_617668397758_item	2768886	et	4	main
õpetusest	doc_617668397758_item	2768887	et	4	main
aga	doc_617668397758_item	2768888	et	3	main
suurt	doc_617668397758_item	2768889	et	3	main
aru	doc_617668397758_item	2768890	et	4	main
ei	doc_617668397758_item	2768891	et	4	main
saadud	doc_617668397758_item	2768892	et	4	main
sest	doc_617668397758_item	2768893	et	4	main
jutlused	doc_617668397758_item	2768894	et	3	main
olid	doc_617668397758_item	2768895	et	4	main
kõik	doc_617668397758_item	2768896	et	4	main
saaremaal	doc_617668397758_item	2768834	et	4	main
põhjuseks	doc_617668397758_item	2768835	et	3	main
jüriöö	doc_617668397758_item	2768843	et	4	main
muistse	doc_617668397758_item	2768847	et	3	main
kaotasid	doc_617668397758_item	2768858	et	4	main
isikuvabaduse	doc_617668397758_item	2768861	et	4	main
ja	doc_617668397758_item	2768869	et	3	main
ja	doc_617668397758_item	2768840	et	3	main
ülestõusu	doc_617668397758_item	2768844	et	4	main
jätkuks	doc_617668397758_item	2768849	et	4	main
peale	doc_617668397758_item	2768856	et	4	main
seda	doc_617668397758_item	2768857	et	3	main
õigused	doc_617668397758_item	2768868	et	4	main
ladina	doc_617668397758_item	2768897	et	4	main
õigust	doc_617668397758_item	2768902	et	4	main
õpetusele	doc_617668397758_item	2768905	et	4	main
mõisnikule	doc_617668397758_item	2768914	et	3	main
kontakt	doc_617668397758_item	2768922	et	3	main
rahulolematus	doc_617668397758_item	2768842	et	4	main
ka	doc_617668397758_item	2768846	et	3	main
vabadusvõitluse	doc_617668397758_item	2768848	et	3	main
see	doc_617668397758_item	2768850	et	3	main
viimane	doc_617668397758_item	2768852	et	3	main
vabaneda	doc_617668397758_item	2768854	et	3	main
võõrvõimust	doc_617668397758_item	2768855	et	4	main
kellel	doc_617668397758_item	2768865	et	4	main
puudusid	doc_617668397758_item	2768866	et	4	main
igasugused	doc_617668397758_item	2768867	et	3	main
ning	doc_617668397758_item	2768899	et	3	main
polnud	doc_617668397758_item	2768901	et	3	main
ega	doc_617668397758_item	2768904	et	3	main
kuna	doc_617668397758_item	2768906	et	3	main
puudus	doc_617668397758_item	2768908	et	4	main
ringi	doc_617668397758_item	2768911	et	4	main
liikuda	doc_617668397758_item	2768912	et	3	main
väljaspool	doc_617668397758_item	2768913	et	3	main
siis	doc_617668397758_item	2768917	et	3	main
keeles	doc_617668397758_item	2768898	et	4	main
orjadel	doc_617668397758_item	2768900	et	3	main
ala	doc_617668397758_item	2768916	et	4	main
ei	doc_617668397758_item	2768918	et	4	main
võimalik	doc_617668397758_item	2768920	et	3	main
ka	doc_617668397758_item	2768921	et	3	main
kontrolltöö	doc_617668397760_item	2769247	et	4	main
kultuuriloost	doc_617668397760_item	2769249	et	4	main
muutused	doc_617668397760_item	2769252	et	4	main
ja	doc_617668397760_item	2769254	et	3	main
eestimaal	doc_617668397760_item	2769265	et	4	main
ja	doc_617668397760_item	2769275	et	3	main
ja	doc_617668397760_item	2769285	et	3	main
ajaloos	doc_617668397760_item	2769295	et	4	main
korilusest	doc_617668397760_item	2769302	et	4	main
siis	doc_617668397760_item	2769305	et	3	main
kaasnesid	doc_617668397760_item	2769313	et	4	main
tarbe-	doc_617668397760_item	2769343	et	3	main
kiviajal	doc_617668397760_item	2769346	et	3	main
talirukist	doc_617668397760_item	2769359	et	3	main
nn	doc_617668397760_item	2769362	et	4	main
kolmeviljasüsteem	doc_617668397760_item	2769363	et	3	main
oli	doc_617668397760_item	2769364	et	3	main
maalappi	doc_617668397760_item	2769367	et	4	main
ajal	doc_617668397760_item	2769369	et	4	main
inimesed	doc_617668397760_item	2769376	et	3	main
kodukohta	doc_617668397760_item	2769379	et	4	main
nn	doc_617668397760_item	2769389	et	4	main
kividest	doc_617668397760_item	2769392	et	3	main
teiste	doc_617668397758_item	2768923	et	4	main
inimestega	doc_617668397758_item	2768925	et	3	main
kontrolltöö	doc_617668397760_item	2769246	et	4	main
1	doc_617668397760_item	2769273	et	2	main
rauaaega	doc_617668397760_item	2769281	et	4	main
palju	doc_617668397760_item	2769283	et	4	main
muutusi	doc_617668397760_item	2769284	et	4	main
kui	doc_617668397760_item	2769296	et	3	main
ja	doc_617668397760_item	2769303	et	3	main
varasel	doc_617668397760_item	2769306	et	4	main
ja	doc_617668397760_item	2769311	et	3	main
suurenes	doc_617668397760_item	2769321	et	4	main
ka	doc_617668397760_item	2769322	et	3	main
arv	doc_617668397760_item	2769324	et	3	main
kui	doc_617668397760_item	2769325	et	3	main
oli	doc_617668397760_item	2769327	et	3	main
kõplapõllundus	doc_617668397760_item	2769329	et	4	main
siis	doc_617668397760_item	2769330	et	3	main
varasel	doc_617668397760_item	2769331	et	4	main
metalliajal	doc_617668397760_item	2769332	et	3	main
rauaajal	doc_617668397760_item	2769351	et	3	main
kuid	doc_617668397760_item	2769357	et	4	main
kolmandat	doc_617668397760_item	2769366	et	3	main
oli	doc_617668397760_item	2769372	et	3	main
ühel	doc_617668397760_item	2769373	et	3	main
kiviajal	doc_617668397760_item	2769374	et	3	main
peamiselt	doc_617668397760_item	2769377	et	4	main
oma	doc_617668397760_item	2769378	et	4	main
asula	doc_617668397760_item	2769380	et	4	main
juude	doc_617668397760_item	2769381	et	4	main
eemale	doc_617668397760_item	2769384	et	3	main
rajama	doc_617668397760_item	2769388	et	3	main
selle	doc_617668397760_item	2769395	et	4	main
oli	doc_617668397760_item	2769397	et	3	main
kivikirst	doc_617668397760_item	2769398	et	3	main
surnu	doc_617668397760_item	2769400	et	4	main
kuid	doc_617668397760_item	2769422	et	4	main
suurenes	doc_617668397760_item	2769424	et	4	main
enne	doc_617668397760_item	2769452	et	4	main
tööriistu	doc_617668397760_item	2769456	et	3	main
olid	doc_617668397760_item	2769464	et	4	main
need	doc_617668397760_item	2769465	et	3	main
rauast	doc_617668397760_item	2769466	et	4	main
vastupidavamad	doc_617668397760_item	2769467	et	4	main
ja	doc_617668397760_item	2769468	et	3	main
1	doc_617668397760_item	2769250	et	2	main
keskaegsel	doc_617668397760_item	2769264	et	3	main
materiaalses	doc_617668397760_item	2769274	et	3	main
kultuuris	doc_617668397760_item	2769277	et	3	main
üleminekul	doc_617668397760_item	2769279	et	3	main
on	doc_617668397760_item	2769287	et	4	main
arvates	doc_617668397760_item	2769289	et	4	main
ka	doc_617668397760_item	2769290	et	3	main
kõige	doc_617668397760_item	2769291	et	4	main
näiteks	doc_617668397760_item	2769297	et	4	main
kiviajal	doc_617668397760_item	2769298	et	3	main
elati	doc_617668397760_item	2769299	et	3	main
peamiselt	doc_617668397760_item	2769300	et	4	main
eesti	doc_617668397760_item	2769248	et	4	main
vaimses	doc_617668397760_item	2769255	et	3	main
kultuuris	doc_617668397760_item	2769256	et	3	main
üleminekul	doc_617668397760_item	2769258	et	3	main
kiviajast	doc_617668397760_item	2769259	et	4	main
toimusid	doc_617668397760_item	2769257	et	4	main
rauaaega	doc_617668397760_item	2769260	et	4	main
2	doc_617668397760_item	2769261	et	2	main
kirjelda	doc_617668397760_item	2769262	et	4	main
3	doc_617668397760_item	2769266	et	2	main
muistne	doc_617668397760_item	2769268	et	3	main
lõppes	doc_617668397760_item	2769270	et	4	main
vaimses	doc_617668397760_item	2769276	et	3	main
toimus	doc_617668397760_item	2769278	et	3	main
kiviajast	doc_617668397760_item	2769280	et	4	main
väga	doc_617668397760_item	2769282	et	3	main
muutused	doc_617668397760_item	2769293	et	4	main
muinasaja	doc_617668397760_item	2769294	et	3	main
rauaajal	doc_617668397760_item	2769307	et	3	main
põllumajandus	doc_617668397760_item	2769317	et	3	main
kivist	doc_617668397760_item	2769334	et	4	main
kõplad	doc_617668397760_item	2769335	et	4	main
juba	doc_617668397760_item	2769336	et	3	main
raudtööriistadeks	doc_617668397760_item	2769337	et	3	main
kuid	doc_617668397760_item	2769338	et	4	main
kasutati	doc_617668397760_item	2769340	et	4	main
toimis	doc_617668397760_item	2769347	et	4	main
üheväljasüsteem	doc_617668397760_item	2769349	et	3	main
see	doc_617668397760_item	2769353	et	3	main
kasvatati	doc_617668397760_item	2769355	et	3	main
hiljem	doc_617668397760_item	2769358	et	3	main
kui	doc_617668397760_item	2769360	et	3	main
tekkis	doc_617668397760_item	2769361	et	3	main
metalliajal	doc_617668397760_item	2769385	et	3	main
juba	doc_617668397760_item	2769387	et	3	main
kogus	doc_617668397760_item	2769429	et	4	main
relvi	doc_617668397760_item	2769430	et	4	main
nt	doc_617668397760_item	2769433	et	4	main
lahingut	doc_617668397760_item	2769435	et	3	main
kasutuselevõtt	doc_617668397760_item	2769450	et	3	main
ning	doc_617668397760_item	2769470	et	3	main
ja	doc_617668397760_item	2769476	et	3	main
maksma	doc_617668397760_item	2769486	et	3	main
tekkisid	doc_617668397760_item	2769492	et	4	main
juhid	doc_617668397760_item	2769495	et	4	main
usundisel	doc_617668397760_item	2769521	et	4	main
kui	doc_617668397760_item	2769523	et	3	main
siis	doc_617668397760_item	2769527	et	3	main
nüüd	doc_617668397760_item	2769528	et	4	main
läbi	doc_617668397760_item	2769531	et	4	main
kui	doc_617668397760_item	2769533	et	3	main
rajati	doc_617668397760_item	2769535	et	3	main
ära	doc_617668397760_item	2769538	et	4	main
kasvab	doc_617668397760_item	2769541	et	3	main
ja	doc_617668397760_item	2769542	et	3	main
seega	doc_617668397760_item	2769543	et	4	main
arvestati	doc_617668397760_item	2769544	et	3	main
ka	doc_617668397760_item	2769545	et	3	main
kaasusaamisel	doc_617668397760_item	2769547	et	4	main
arenes	doc_617668397760_item	2769548	et	3	main
kvaliteetsematele	doc_617668397760_item	2769552	et	4	main
ja	doc_617668397760_item	2769555	et	3	main
seotud	doc_617668397760_item	2769561	et	4	main
inimesed	doc_617668397760_item	2769566	et	3	main
kaitstud	doc_617668397760_item	2769578	et	4	main
kardeti	doc_617668397760_item	2769587	et	3	main
niisama	doc_617668397760_item	2769593	et	3	main
kahekümne	doc_617668397760_item	2769623	et	4	main
aasta	doc_617668397760_item	2769624	et	4	main
palju	doc_617668397760_item	2769633	et	4	main
saksa	doc_617668397760_item	2769643	et	4	main
ordu	doc_617668397760_item	2769644	et	4	main
oli	doc_617668397760_item	2769645	et	3	main
peamine	doc_617668397760_item	2769646	et	3	main
baltimaad	doc_617668397760_item	2769654	et	4	main
olid	doc_617668397760_item	2769655	et	4	main
ristimata	doc_617668397760_item	2769657	et	4	main
ka	doc_617668397760_item	2769658	et	3	main
ning	doc_617668397760_item	2769664	et	3	main
lätlasi	doc_617668397760_item	2769668	et	3	main
muid	doc_617668397760_item	2769670	et	4	main
suur	doc_617668397760_item	2769672	et	3	main
eestlastele	doc_617668397760_item	2769675	et	4	main
mõõgavendade	doc_617668397760_item	2769680	et	3	main
need	doc_617668397760_item	2769682	et	3	main
vaimulikud	doc_617668397760_item	2769684	et	3	main
ettekäändeks	doc_617668397760_item	2769701	et	3	main
taheti	doc_617668397760_item	2769703	et	3	main
teda	doc_617668397760_item	2769728	et	4	main
20	doc_617668397760_item	2769730	et	2	main
kalastamisest	doc_617668397760_item	2769304	et	4	main
viljelusmajandus	doc_617668397760_item	2769310	et	3	main
sellega	doc_617668397760_item	2769312	et	3	main
suured	doc_617668397760_item	2769315	et	3	main
arenes	doc_617668397760_item	2769318	et	3	main
ja	doc_617668397760_item	2769319	et	3	main
sellega	doc_617668397760_item	2769320	et	3	main
asendusid	doc_617668397760_item	2769333	et	4	main
endiselt	doc_617668397760_item	2769339	et	4	main
kivist	doc_617668397760_item	2769342	et	4	main
ja	doc_617668397760_item	2769344	et	3	main
arenes	doc_617668397760_item	2769352	et	3	main
kaheväljasüsteemiks	doc_617668397760_item	2769354	et	3	main
vaja	doc_617668397760_item	2769365	et	4	main
harva	doc_617668397760_item	2769382	et	4	main
kujukesi	doc_617668397760_item	2769421	et	4	main
metalliajal	doc_617668397760_item	2769423	et	3	main
relvade	doc_617668397760_item	2769425	et	3	main
tähtsus	doc_617668397760_item	2769426	et	4	main
hauas	doc_617668397760_item	2769427	et	3	main
suur	doc_617668397760_item	2769428	et	3	main
näidata	doc_617668397760_item	2769432	et	4	main
muutus	doc_617668397760_item	2769446	et	4	main
oli	doc_617668397760_item	2769447	et	3	main
muidugi	doc_617668397760_item	2769448	et	4	main
raua	doc_617668397760_item	2769449	et	3	main
tarbe-	doc_617668397760_item	2769454	et	3	main
ja	doc_617668397760_item	2769455	et	3	main
nüüd	doc_617668397760_item	2769463	et	4	main
kaasnes	doc_617668397760_item	2769472	et	3	main
inimarvu	doc_617668397760_item	2769477	et	4	main
suurenemine	doc_617668397760_item	2769478	et	4	main
ei	doc_617668397760_item	2769480	et	4	main
pidanud	doc_617668397760_item	2769481	et	4	main
raua	doc_617668397760_item	2769482	et	3	main
vaid	doc_617668397760_item	2769487	et	3	main
varasel	doc_617668397760_item	2769503	et	4	main
edaspidisel	doc_617668397760_item	2769546	et	3	main
materiaalne	doc_617668397760_item	2769554	et	3	main
omavahel	doc_617668397760_item	2769559	et	3	main
kliima	doc_617668397760_item	2769562	et	4	main
paremini	doc_617668397760_item	2769577	et	4	main
edasi	doc_617668397760_item	2769585	et	3	main
loomade	doc_617668397760_item	2769589	et	4	main
ka	doc_617668397760_item	2769592	et	3	main
rünnakuid	doc_617668397760_item	2769621	et	3	main
vaenlasi	doc_617668397760_item	2769634	et	3	main
euroopas	doc_617668397760_item	2769638	et	3	main
saj	doc_617668397760_item	2769641	et	4	main
kes	doc_617668397760_item	2769647	et	4	main
tahtis	doc_617668397760_item	2769648	et	3	main
sest	doc_617668397760_item	2769653	et	4	main
veel	doc_617668397760_item	2769656	et	4	main
lõõk	doc_617668397760_item	2769673	et	4	main
oli	doc_617668397760_item	2769674	et	3	main
see	doc_617668397760_item	2769676	et	3	main
nn	doc_617668397760_item	2769679	et	4	main
olid	doc_617668397760_item	2769683	et	4	main
vägisi	doc_617668397760_item	2769692	et	3	main
ja	doc_617668397760_item	2769695	et	3	main
rootsile	doc_617668397760_item	2769696	et	3	main
ristiusu	doc_617668397760_item	2769698	et	3	main
laiendada	doc_617668397760_item	2769706	et	3	main
selles	doc_617668397760_item	2769712	et	4	main
võitluses	doc_617668397760_item	2769713	et	3	main
taheti	doc_617668397760_item	2769714	et	3	main
need	doc_617668397760_item	2769715	et	3	main
nn	doc_617668397760_item	2769716	et	4	main
ei	doc_617668397760_item	2769721	et	4	main
vastuhakkamist	doc_617668397760_item	2769736	et	3	main
sõjatehnika	doc_617668397760_item	2769742	et	4	main
puudus	doc_617668397760_item	2769747	et	4	main
ka	doc_617668397760_item	2769748	et	3	main
poolele	doc_617668397760_item	2769756	et	4	main
liivlased	doc_617668397760_item	2769758	et	3	main
alistusid	doc_617668397760_item	2769762	et	4	main
küll	doc_617668397760_item	2769766	et	4	main
ajaks	doc_617668397760_item	2769769	et	4	main
jüriöö	doc_617668397760_item	2769770	et	4	main
valmistusid	doc_617668397760_item	2769777	et	4	main
vastaseid	doc_617668397760_item	2769783	et	3	main
rahvastiku	doc_617668397760_item	2769323	et	3	main
kiviajal	doc_617668397760_item	2769326	et	3	main
peamiselt	doc_617668397760_item	2769328	et	4	main
ka	doc_617668397760_item	2769341	et	3	main
tööriistu	doc_617668397760_item	2769345	et	3	main
nn	doc_617668397760_item	2769348	et	4	main
kuid	doc_617668397760_item	2769350	et	4	main
suvirukist	doc_617668397760_item	2769356	et	3	main
sel	doc_617668397760_item	2769368	et	3	main
kui	doc_617668397760_item	2769370	et	3	main
talirukis	doc_617668397760_item	2769371	et	3	main
maeti	doc_617668397760_item	2769375	et	3	main
asulast	doc_617668397760_item	2769383	et	4	main
hakati	doc_617668397760_item	2769386	et	3	main
kivikirstkalmeid	doc_617668397760_item	2769390	et	4	main
ümmargused	doc_617668397760_item	2769391	et	3	main
laotud	doc_617668397760_item	2769393	et	4	main
kalmed	doc_617668397760_item	2769394	et	3	main
keskel	doc_617668397760_item	2769396	et	3	main
kuhu	doc_617668397760_item	2769399	et	3	main
pandi	doc_617668397760_item	2769401	et	4	main
kiviajal	doc_617668397760_item	2769402	et	3	main
maeti	doc_617668397760_item	2769403	et	3	main
inimesed	doc_617668397760_item	2769404	et	3	main
ka	doc_617668397760_item	2769405	et	3	main
lihtsalt	doc_617668397760_item	2769406	et	4	main
kivihunnikutesse	doc_617668397760_item	2769407	et	3	main
kiviajal	doc_617668397760_item	2769408	et	3	main
pandi	doc_617668397760_item	2769409	et	4	main
surnutele	doc_617668397760_item	2769410	et	4	main
hauda	doc_617668397760_item	2769411	et	4	main
kaasa	doc_617668397760_item	2769412	et	4	main
luust	doc_617668397760_item	2769413	et	4	main
sarvest	doc_617668397760_item	2769414	et	4	main
ja	doc_617668397760_item	2769415	et	3	main
kivist	doc_617668397760_item	2769416	et	4	main
ehteid	doc_617668397760_item	2769417	et	3	main
looma-	doc_617668397760_item	2769418	et	4	main
ja	doc_617668397760_item	2769419	et	3	main
inimese	doc_617668397760_item	2769420	et	4	main
ja	doc_617668397760_item	2769443	et	3	main
eriline	doc_617668397760_item	2769444	et	4	main
kui	doc_617668397760_item	2769451	et	3	main
luust	doc_617668397760_item	2769458	et	4	main
sellega	doc_617668397760_item	2769471	et	3	main
eest	doc_617668397760_item	2769483	et	4	main
kallist	doc_617668397760_item	2769484	et	4	main
saadi	doc_617668397760_item	2769489	et	4	main
maal	doc_617668397760_item	2769491	et	4	main
nn	doc_617668397760_item	2769493	et	4	main
asulate	doc_617668397760_item	2769494	et	3	main
olid	doc_617668397760_item	2769497	et	4	main
ka	doc_617668397760_item	2769498	et	3	main
natuke	doc_617668397760_item	2769499	et	4	main
teistsugused	doc_617668397760_item	2769500	et	3	main
matmiskombed	doc_617668397760_item	2769501	et	3	main
kui	doc_617668397760_item	2769502	et	3	main
arusaamal	doc_617668397760_item	2769522	et	3	main
enne	doc_617668397760_item	2769524	et	4	main
oli	doc_617668397760_item	2769525	et	3	main
hoolikalt	doc_617668397760_item	2769530	et	4	main
enne	doc_617668397760_item	2769532	et	4	main
sõjaline	doc_617668397760_item	2769549	et	4	main
olukord	doc_617668397760_item	2769550	et	3	main
tänu	doc_617668397760_item	2769551	et	4	main
tööriistadele	doc_617668397760_item	2769553	et	3	main
olid	doc_617668397760_item	2769558	et	4	main
võis	doc_617668397760_item	2769431	et	4	main
võidukat	doc_617668397760_item	2769434	et	3	main
või	doc_617668397760_item	2769436	et	4	main
seda	doc_617668397760_item	2769437	et	3	main
et	doc_617668397760_item	2769438	et	3	main
see	doc_617668397760_item	2769439	et	3	main
inimene	doc_617668397760_item	2769440	et	3	main
oli	doc_617668397760_item	2769441	et	3	main
võimas	doc_617668397760_item	2769442	et	4	main
tähtsaim	doc_617668397760_item	2769445	et	4	main
tehti	doc_617668397760_item	2769453	et	3	main
peamiselt	doc_617668397760_item	2769457	et	4	main
sarvest	doc_617668397760_item	2769459	et	4	main
ja	doc_617668397760_item	2769460	et	3	main
kivist	doc_617668397760_item	2769461	et	4	main
siis	doc_617668397760_item	2769462	et	3	main
kvaliteetsemad	doc_617668397760_item	2769469	et	4	main
põllumajanduse	doc_617668397760_item	2769474	et	3	main
seda	doc_617668397760_item	2769488	et	3	main
kiviajal	doc_617668397760_item	2769504	et	3	main
jahiti	doc_617668397760_item	2769505	et	3	main
peamiselt	doc_617668397760_item	2769506	et	4	main
hülgeid	doc_617668397760_item	2769507	et	3	main
ja	doc_617668397760_item	2769508	et	3	main
põtru	doc_617668397760_item	2769509	et	3	main
siis	doc_617668397760_item	2769510	et	3	main
üleminekul	doc_617668397760_item	2769511	et	3	main
rauaaega	doc_617668397760_item	2769512	et	4	main
olid	doc_617668397760_item	2769513	et	4	main
juba	doc_617668397760_item	2769514	et	3	main
tähtsal	doc_617668397760_item	2769515	et	3	main
kohal	doc_617668397760_item	2769516	et	4	main
koduloomad	doc_617668397760_item	2769517	et	3	main
suur	doc_617668397760_item	2769518	et	3	main
osa	doc_617668397760_item	2769519	et	4	main
oli	doc_617668397760_item	2769520	et	3	main
põllud	doc_617668397760_item	2769534	et	3	main
jagati	doc_617668397760_item	2769536	et	3	main
vaimne	doc_617668397760_item	2769556	et	3	main
ei	doc_617668397760_item	2769567	et	4	main
ääres	doc_617668397760_item	2769571	et	4	main
vaid	doc_617668397760_item	2769572	et	3	main
ka	doc_617668397760_item	2769573	et	3	main
sisemaal	doc_617668397760_item	2769574	et	4	main
asulad	doc_617668397760_item	2769575	et	3	main
olid	doc_617668397760_item	2769576	et	4	main
loomakasvatus	doc_617668397760_item	2769586	et	4	main
rünnakuid	doc_617668397760_item	2769595	et	3	main
ka	doc_617668397760_item	2769473	et	3	main
areng	doc_617668397760_item	2769475	et	3	main
enam	doc_617668397760_item	2769479	et	4	main
hinda	doc_617668397760_item	2769485	et	4	main
enda	doc_617668397760_item	2769490	et	4	main
neil	doc_617668397760_item	2769496	et	4	main
allpõllundus	doc_617668397760_item	2769526	et	3	main
mõeldi	doc_617668397760_item	2769529	et	3	main
täpselt	doc_617668397760_item	2769537	et	4	main
mis	doc_617668397760_item	2769539	et	4	main
kus	doc_617668397760_item	2769540	et	3	main
kultuurid	doc_617668397760_item	2769557	et	3	main
elanud	doc_617668397760_item	2769568	et	4	main
vee	doc_617668397760_item	2769570	et	3	main
nii	doc_617668397760_item	2769588	et	3	main
kui	doc_617668397760_item	2769591	et	3	main
tekkisid	doc_617668397760_item	2769596	et	4	main
sepad	doc_617668397760_item	2769597	et	3	main
need	doc_617668397760_item	2769598	et	3	main
olid	doc_617668397760_item	2769599	et	4	main
peamiselt	doc_617668397760_item	2769600	et	4	main
kindlustatud	doc_617668397760_item	2769601	et	4	main
asulates	doc_617668397760_item	2769602	et	4	main
kindlustatud	doc_617668397760_item	2769603	et	4	main
asulaid	doc_617668397760_item	2769604	et	4	main
ehitati	doc_617668397760_item	2769605	et	3	main
peamiselt	doc_617668397760_item	2769606	et	4	main
nt	doc_617668397760_item	2769607	et	4	main
järvesaartele	doc_617668397760_item	2769608	et	3	main
kõrgematesse	doc_617668397760_item	2769609	et	4	main
kohtadesse	doc_617668397760_item	2769610	et	3	main
3	doc_617668397760_item	2769611	et	2	main
peamine	doc_617668397760_item	2769612	et	3	main
põhjus	doc_617668397760_item	2769613	et	4	main
oli	doc_617668397760_item	2769614	et	3	main
see	doc_617668397760_item	2769615	et	3	main
et	doc_617668397760_item	2769616	et	3	main
liiga	doc_617668397760_item	2769617	et	4	main
palju	doc_617668397760_item	2769618	et	4	main
rüüstamisi	doc_617668397760_item	2769619	et	4	main
ja	doc_617668397760_item	2769620	et	3	main
kuid	doc_617668397760_item	2769631	et	4	main
väga	doc_617668397760_item	2769632	et	3	main
kogu	doc_617668397760_item	2769637	et	4	main
baltimaid	doc_617668397760_item	2769649	et	4	main
alistada	doc_617668397760_item	2769650	et	3	main
ja	doc_617668397760_item	2769651	et	3	main
ajal	doc_617668397760_item	2769662	et	4	main
ründas	doc_617668397760_item	2769666	et	3	main
baltirahvaid	doc_617668397760_item	2769671	et	3	main
ordu	doc_617668397760_item	2769681	et	4	main
rüütlid	doc_617668397760_item	2769685	et	3	main
kes	doc_617668397760_item	2769686	et	4	main
surusid	doc_617668397760_item	2769687	et	4	main
ristiusku	doc_617668397760_item	2769688	et	4	main
ja	doc_617668397760_item	2769689	et	3	main
peale	doc_617668397760_item	2769693	et	4	main
pigem	doc_617668397760_item	2769700	et	3	main
pigem	doc_617668397760_item	2769702	et	3	main
oma	doc_617668397760_item	2769704	et	4	main
kaubandusteed	doc_617668397760_item	2769707	et	4	main
tähtsad	doc_617668397760_item	2769711	et	3	main
puhtaks	doc_617668397760_item	2769718	et	3	main
väga	doc_617668397760_item	2769560	et	3	main
muutus	doc_617668397760_item	2769563	et	4	main
väga	doc_617668397760_item	2769564	et	3	main
palju	doc_617668397760_item	2769565	et	4	main
enam	doc_617668397760_item	2769569	et	4	main
sest	doc_617668397760_item	2769579	et	4	main
rundajaid	doc_617668397760_item	2769580	et	4	main
oli	doc_617668397760_item	2769581	et	3	main
rohkem	doc_617668397760_item	2769582	et	4	main
kuna	doc_617668397760_item	2769583	et	3	main
arenes	doc_617668397760_item	2769584	et	3	main
pärast	doc_617668397760_item	2769590	et	4	main
vaenlaste	doc_617668397760_item	2769594	et	3	main
kestis	doc_617668397760_item	2769636	et	4	main
11	doc_617668397760_item	2769639	et	2	main
ja	doc_617668397760_item	2769642	et	3	main
venemaa	doc_617668397760_item	2769659	et	4	main
oli	doc_617668397760_item	2769660	et	3	main
sel	doc_617668397760_item	2769661	et	3	main
ka	doc_617668397760_item	2769665	et	3	main
liivlasi	doc_617668397760_item	2769667	et	3	main
kui	doc_617668397760_item	2769677	et	3	main
taanile	doc_617668397760_item	2769694	et	4	main
võimu	doc_617668397760_item	2769705	et	4	main
paganatest	doc_617668397760_item	2769717	et	4	main
maid	doc_617668397760_item	2769727	et	4	main
ründab	doc_617668397760_item	2769729	et	3	main
parem	doc_617668397760_item	2769741	et	4	main
mis	doc_617668397760_item	2769745	et	4	main
see	doc_617668397760_item	2769749	et	3	main
et	doc_617668397760_item	2769750	et	3	main
liivlased	doc_617668397760_item	2769751	et	3	main
ja	doc_617668397760_item	2769752	et	3	main
lätlased	doc_617668397760_item	2769753	et	3	main
asusid	doc_617668397760_item	2769754	et	4	main
vastupanuta	doc_617668397760_item	2769764	et	3	main
mõneks	doc_617668397760_item	2769768	et	3	main
edukas	doc_617668397760_item	2769774	et	4	main
sest	doc_617668397760_item	2769775	et	4	main
nad	doc_617668397760_item	2769776	et	3	main
ründasid	doc_617668397760_item	2769782	et	4	main
linnakultuur	doc_617668397760_item	2769791	et	3	main
enam	doc_617668397760_item	2769795	et	4	main
ei	doc_617668397760_item	2769796	et	4	main
vaid	doc_617668397760_item	2769800	et	3	main
väga	doc_617668397760_item	2769821	et	3	main
sellest	doc_617668397760_item	2769824	et	4	main
väed	doc_617668397761_item	2769847	et	3	main
eesti	doc_617668397761_item	2769869	et	4	main
ja	doc_617668397761_item	2769877	et	3	main
selle	doc_617668397761_item	2769881	et	4	main
keerisesse	doc_617668397761_item	2769886	et	4	main
temast	doc_617668397761_item	2769888	et	3	main
kummalised	doc_617668397761_item	2769901	et	3	main
sisemine	doc_617668397761_item	2769910	et	3	main
eestlasliku	doc_617668397761_item	2769914	et	4	main
ja	doc_617668397761_item	2769916	et	3	main
terve	doc_617668397761_item	2769921	et	4	main
koomilisi	doc_617668397761_item	2769923	et	3	main
vaadates	doc_617668397761_item	2769925	et	3	main
filmi	doc_617668397761_item	2769926	et	4	main
vastuseid	doc_617668397761_item	2769930	et	3	main
paljudele	doc_617668397761_item	2769931	et	3	main
ajalugu	doc_617668397761_item	2769937	et	4	main
eestlased	doc_617668397761_item	2769941	et	3	main
vaba	doc_617668397761_item	2769948	et	4	main
riiki	doc_617668397761_item	2769950	et	4	main
eestimaa	doc_617668397761_item	2769956	et	4	main
väga	doc_617668397761_item	2770015	et	3	main
kui	doc_617668397761_item	2770017	et	3	main
eestlaste	doc_617668397761_item	2770029	et	4	main
seda	doc_617668397761_item	2770033	et	3	main
malev	doc_617668397761_item	2770035	et	3	main
sakslane	doc_617668397761_item	2770047	et	3	main
rääkida	doc_617668397761_item	2770053	et	3	main
tegid	doc_617668397761_item	2770068	et	4	main
tuleb	doc_617668397761_item	2770078	et	3	main
et	doc_617668397761_item	2770080	et	3	main
täpselt	doc_617668397761_item	2770097	et	4	main
oli	doc_617668397761_item	2770098	et	3	main
ei	doc_617668397761_item	2770099	et	4	main
keegi	doc_617668397761_item	2770106	et	4	main
u	doc_617668397760_item	2769622	et	4	main
jooksul	doc_617668397760_item	2769625	et	4	main
eestil	doc_617668397760_item	2769626	et	3	main
oli	doc_617668397760_item	2769627	et	3	main
väga	doc_617668397760_item	2769628	et	3	main
vähe	doc_617668397760_item	2769629	et	3	main
liitlasi	doc_617668397760_item	2769630	et	3	main
ristisõda	doc_617668397760_item	2769635	et	4	main
13	doc_617668397760_item	2769640	et	2	main
ristida	doc_617668397760_item	2769652	et	4	main
võimas	doc_617668397760_item	2769663	et	4	main
ja	doc_617668397760_item	2769669	et	3	main
tekkis	doc_617668397760_item	2769678	et	3	main
oma	doc_617668397760_item	2769690	et	4	main
võimu	doc_617668397760_item	2769691	et	4	main
oli	doc_617668397760_item	2769697	et	3	main
pealesurumine	doc_617668397760_item	2769699	et	3	main
olid	doc_617668397760_item	2769708	et	4	main
ka	doc_617668397760_item	2769709	et	3	main
väga	doc_617668397760_item	2769710	et	3	main
teha	doc_617668397760_item	2769719	et	3	main
eesti	doc_617668397760_item	2769720	et	4	main
palju	doc_617668397760_item	2769726	et	4	main
olid	doc_617668397760_item	2769738	et	4	main
ja	doc_617668397760_item	2769760	et	3	main
lätlased	doc_617668397760_item	2769761	et	3	main
peaaegu	doc_617668397760_item	2769763	et	3	main
õnnestus	doc_617668397760_item	2769767	et	4	main
ootamatult	doc_617668397760_item	2769784	et	4	main
sõna	doc_617668397760_item	2769788	et	4	main
ütleb	doc_617668397760_item	2769790	et	3	main
tekkisid	doc_617668397760_item	2769792	et	4	main
linnused	doc_617668397760_item	2769793	et	3	main
linnad	doc_617668397760_item	2769794	et	3	main
nüüd	doc_617668397760_item	2769801	et	4	main
äraelamine	doc_617668397760_item	2769827	et	3	main
essee	doc_617668397761_item	2769828	et	4	main
film	doc_617668397761_item	2769829	et	3	main
malev	doc_617668397761_item	2769830	et	3	main
liivimaal	doc_617668397761_item	2769843	et	4	main
rahvaid	doc_617668397761_item	2769850	et	3	main
sündmuste	doc_617668397761_item	2769885	et	3	main
kus	doc_617668397761_item	2769887	et	3	main
sünnimaa	doc_617668397761_item	2769890	et	4	main
ja	doc_617668397761_item	2769893	et	3	main
mis	doc_617668397761_item	2769895	et	4	main
on	doc_617668397761_item	2769899	et	4	main
veidrad	doc_617668397761_item	2769900	et	3	main
kaine	doc_617668397761_item	2769906	et	4	main
mõistusega	doc_617668397761_item	2769907	et	3	main
mis	doc_617668397761_item	2769933	et	4	main
näiteks	doc_617668397761_item	2769939	et	4	main
sajandil	doc_617668397761_item	2769953	et	3	main
kulges	doc_617668397761_item	2769955	et	3	main
anastamine	doc_617668397761_item	2769957	et	4	main
tegelikult	doc_617668397761_item	2769958	et	4	main
arvan	doc_617668397761_item	2769959	et	3	main
et	doc_617668397761_item	2769960	et	3	main
malevit	doc_617668397761_item	2769961	et	3	main
tasub	doc_617668397761_item	2769962	et	3	main
see	doc_617668397761_item	2769965	et	3	main
lauludega	doc_617668397761_item	2769994	et	3	main
tantsitega	doc_617668397761_item	2769996	et	4	main
eestlased	doc_617668397761_item	2769999	et	3	main
lauluv	doc_617668397761_item	2770001	et	4	main
rahvas	doc_617668397761_item	2770002	et	4	main
tekkib	doc_617668397761_item	2770008	et	3	main
aga	doc_617668397761_item	2770013	et	3	main
on	doc_617668397761_item	2770014	et	4	main
minu	doc_617668397761_item	2770021	et	3	main
raske	doc_617668397761_item	2770027	et	4	main
ainult	doc_617668397761_item	2770031	et	4	main
üks	doc_617668397761_item	2770037	et	3	main
eesti	doc_617668397761_item	2770039	et	4	main
üldse	doc_617668397761_item	2770044	et	3	main
aru	doc_617668397761_item	2770045	et	4	main
prantslane	doc_617668397761_item	2770049	et	3	main
soomlane	doc_617668397761_item	2770051	et	3	main
kui	doc_617668397761_item	2770065	et	3	main
mõistlikult	doc_617668397761_item	2770066	et	4	main
eest	doc_617668397761_item	2770072	et	4	main
osanud	doc_617668397760_item	2769722	et	4	main
arvata	doc_617668397760_item	2769723	et	4	main
et	doc_617668397760_item	2769724	et	3	main
nii	doc_617668397760_item	2769725	et	3	main
a	doc_617668397760_item	2769731	et	4	main
sakslased	doc_617668397760_item	2769737	et	3	main
tugevamad	doc_617668397760_item	2769740	et	4	main
kooskõlastatus	doc_617668397760_item	2769744	et	4	main
eestil	doc_617668397760_item	2769746	et	3	main
sest	doc_617668397760_item	2769757	et	4	main
kaotasid	doc_617668397760_item	2769759	et	4	main
ülestõus	doc_617668397760_item	2769771	et	4	main
oli	doc_617668397760_item	2769772	et	3	main
selleks	doc_617668397760_item	2769778	et	4	main
hästi	doc_617668397760_item	2769779	et	3	main
juba	doc_617668397760_item	2769803	et	3	main
igaüks	doc_617668397760_item	2769804	et	3	main
kuidas	doc_617668397760_item	2769805	et	3	main
oma	doc_617668397760_item	2769806	et	4	main
3-e	doc_617668397760_item	2769807	et	3	main
liikmelist	doc_617668397760_item	2769808	et	4	main
peret	doc_617668397760_item	2769809	et	3	main
ära	doc_617668397760_item	2769810	et	4	main
toita	doc_617668397760_item	2769811	et	4	main
viljakasvatus	doc_617668397760_item	2769812	et	4	main
oli	doc_617668397760_item	2769813	et	3	main
tähtis	doc_617668397760_item	2769814	et	4	main
leib	doc_617668397760_item	2769815	et	3	main
oli	doc_617668397760_item	2769816	et	3	main
tähtsal	doc_617668397760_item	2769817	et	3	main
kohal	doc_617668397760_item	2769818	et	4	main
maaviljelus	doc_617668397760_item	2769819	et	3	main
oli	doc_617668397760_item	2769820	et	3	main
jooksul	doc_617668397760_item	2769732	et	4	main
mitusada	doc_617668397760_item	2769733	et	4	main
võitlust	doc_617668397760_item	2769734	et	3	main
ja	doc_617668397760_item	2769735	et	3	main
palju	doc_617668397760_item	2769739	et	4	main
ettevalmistus	doc_617668397760_item	2769743	et	3	main
sama	doc_617668397760_item	2769755	et	4	main
eestil	doc_617668397760_item	2769765	et	3	main
eestlastele	doc_617668397760_item	2769773	et	4	main
ette	doc_617668397760_item	2769780	et	4	main
ja	doc_617668397760_item	2769781	et	3	main
2	doc_617668397760_item	2769785	et	2	main
see	doc_617668397760_item	2769787	et	3	main
juba	doc_617668397760_item	2769789	et	3	main
nn	doc_617668397760_item	2769798	et	4	main
suurperedena	doc_617668397760_item	2769799	et	3	main
kogu	doc_617668397760_item	2769826	et	4	main
mõnes	doc_617668397761_item	2769832	et	3	main
ajalooline	doc_617668397761_item	2769834	et	4	main
kus	doc_617668397761_item	2769844	et	3	main
saksa	doc_617668397761_item	2769845	et	4	main
üritavad	doc_617668397761_item	2769848	et	4	main
võtsid	doc_617668397761_item	2769862	et	4	main
on	doc_617668397761_item	2769866	et	4	main
haritud	doc_617668397761_item	2769868	et	4	main
noormees	doc_617668397761_item	2769870	et	4	main
ning	doc_617668397761_item	2769871	et	3	main
peab	doc_617668397761_item	2769872	et	4	main
leidma	doc_617668397761_item	2769873	et	3	main
saamise	doc_617668397761_item	2769879	et	4	main
sattub	doc_617668397761_item	2769883	et	3	main
ta	doc_617668397761_item	2769884	et	4	main
sõltub	doc_617668397761_item	2769889	et	3	main
ees	doc_617668397761_item	2769897	et	4	main
ootavad	doc_617668397761_item	2769898	et	4	main
võitlus	doc_617668397761_item	2769911	et	3	main
euroopaliku	doc_617668397761_item	2769912	et	3	main
olukordi	doc_617668397761_item	2769924	et	4	main
kui	doc_617668397761_item	2769935	et	3	main
uurid	doc_617668397761_item	2769936	et	4	main
kas	doc_617668397761_item	2769940	et	3	main
vabaduseks	doc_617668397761_item	2769943	et	4	main
sündinud	doc_617668397761_item	2769947	et	4	main
13	doc_617668397761_item	2769952	et	2	main
kuidas	doc_617668397761_item	2769954	et	3	main
huvitav	doc_617668397761_item	2769967	et	4	main
film	doc_617668397761_item	2769970	et	3	main
ja	doc_617668397761_item	2769995	et	3	main
just	doc_617668397761_item	2769997	et	3	main
sellepärast	doc_617668397761_item	2769998	et	3	main
on	doc_617668397761_item	2770000	et	4	main
ja	doc_617668397761_item	2770010	et	3	main
vahel	doc_617668397761_item	2770012	et	4	main
kurb	doc_617668397761_item	2770016	et	3	main
lõppus	doc_617668397761_item	2770018	et	4	main
uro	doc_617668397761_item	2770019	et	4	main
sureb	doc_617668397761_item	2770020	et	3	main
nagu	doc_617668397760_item	2769786	et	3	main
elatud	doc_617668397760_item	2769797	et	4	main
mõtles	doc_617668397760_item	2769802	et	3	main
tahtsal	doc_617668397760_item	2769822	et	4	main
mõttes	doc_617668397761_item	2769833	et	3	main
absurdiseikluskomöödia	doc_617668397761_item	2769835	et	4	main
tegevus	doc_617668397761_item	2769836	et	4	main
toimub	doc_617668397761_item	2769837	et	3	main
13	doc_617668397761_item	2769838	et	2	main
sajandi	doc_617668397761_item	2769839	et	3	main
algusel	doc_617668397761_item	2769840	et	4	main
eestis	doc_617668397761_item	2769841	et	3	main
ja	doc_617668397761_item	2769842	et	3	main
teda	doc_617668397761_item	2769861	et	4	main
sõjavangi	doc_617668397761_item	2769864	et	4	main
esimene	doc_617668397761_item	2769867	et	3	main
jäämise	doc_617668397761_item	2769876	et	4	main
käigus	doc_617668397761_item	2769882	et	4	main
seigad	doc_617668397761_item	2769892	et	3	main
takistused	doc_617668397761_item	2769894	et	4	main
teda	doc_617668397761_item	2769896	et	4	main
ja	doc_617668397761_item	2769902	et	3	main
kentsakad	doc_617668397761_item	2769903	et	3	main
on	doc_617668397761_item	2769905	et	4	main
inimene	doc_617668397761_item	2769908	et	3	main
vahel	doc_617668397761_item	2769915	et	4	main
suhestumine	doc_617668397761_item	2769917	et	4	main
eestlastega	doc_617668397761_item	2769918	et	4	main
tekitab	doc_617668397761_item	2769919	et	3	main
temaga	doc_617668397761_item	2769920	et	3	main
kohal	doc_617668397760_item	2769823	et	4	main
sõltus	doc_617668397760_item	2769825	et	4	main
on	doc_617668397761_item	2769831	et	4	main
ordu	doc_617668397761_item	2769846	et	4	main
siinseid	doc_617668397761_item	2769849	et	3	main
allutada	doc_617668397761_item	2769851	et	3	main
ja	doc_617668397761_item	2769852	et	3	main
noor	doc_617668397761_item	2769854	et	3	main
eesti	doc_617668397761_item	2769855	et	4	main
ristida	doc_617668397761_item	2769853	et	4	main
poiss	doc_617668397761_item	2769856	et	3	main
uru	doc_617668397761_item	2769857	et	3	main
sattub	doc_617668397761_item	2769858	et	3	main
euroopasse	doc_617668397761_item	2769859	et	3	main
sest	doc_617668397761_item	2769860	et	4	main
saaklased	doc_617668397761_item	2769863	et	4	main
ta	doc_617668397761_item	2769865	et	4	main
tasakaalu	doc_617668397761_item	2769874	et	4	main
eestlaseks	doc_617668397761_item	2769875	et	3	main
eurooplaseks	doc_617668397761_item	2769878	et	3	main
vahel	doc_617668397761_item	2769880	et	4	main
tulevik	doc_617668397761_item	2769891	et	3	main
ta	doc_617668397761_item	2769904	et	4	main
aga	doc_617668397761_item	2769909	et	3	main
ja	doc_617668397761_item	2769913	et	3	main
tekkivad	doc_617668397761_item	2769934	et	4	main
on	doc_617668397761_item	2769942	et	4	main
valmis	doc_617668397761_item	2769944	et	4	main
miks	doc_617668397761_item	2769945	et	4	main
vaadata	doc_617668397761_item	2769963	et	4	main
on	doc_617668397761_item	2769966	et	4	main
ja	doc_617668397761_item	2769968	et	3	main
põnev	doc_617668397761_item	2769969	et	3	main
filmis	doc_617668397761_item	2770003	et	4	main
on	doc_617668397761_item	2770004	et	4	main
ka	doc_617668397761_item	2770005	et	3	main
armastus	doc_617668397761_item	2770006	et	4	main
mis	doc_617668397761_item	2770007	et	4	main
mitteeestikeelsele	doc_617668397761_item	2770023	et	3	main
ajalugu	doc_617668397761_item	2770030	et	4	main
filmi	doc_617668397761_item	2770034	et	4	main
ei	doc_617668397761_item	2770042	et	4	main
saa	doc_617668397761_item	2770043	et	4	main
kui	doc_617668397761_item	2770052	et	3	main
siis	doc_617668397761_item	2770056	et	3	main
autorid	doc_617668397761_item	2770069	et	3	main
nende	doc_617668397761_item	2770070	et	4	main
mineviku	doc_617668397761_item	2770071	et	3	main
tõdeda	doc_617668397761_item	2770079	et	3	main
asi	doc_617668397761_item	2770083	et	4	main
on	doc_617668397761_item	2770085	et	4	main
olnud	doc_617668397761_item	2770086	et	4	main
malev	doc_617668397761_item	2770087	et	3	main
tea	doc_617668397761_item	2770100	et	4	main
ei	doc_617668397761_item	2770107	et	4	main
muud	doc_617668397761_item	2770118	et	4	main
vaatamist	doc_617668397761_item	2770129	et	4	main
on	doc_617668397761_item	2770130	et	4	main
hea	doc_617668397761_item	2770131	et	4	main
ja	doc_617668397761_item	2770132	et	3	main
rea	doc_617668397761_item	2769922	et	3	main
malev	doc_617668397761_item	2769927	et	3	main
saab	doc_617668397761_item	2769928	et	3	main
leida	doc_617668397761_item	2769929	et	3	main
küsimustele	doc_617668397761_item	2769932	et	4	main
läbi	doc_617668397761_item	2769938	et	4	main
ei	doc_617668397761_item	2769946	et	4	main
eesti	doc_617668397761_item	2769949	et	4	main
juba	doc_617668397761_item	2769951	et	3	main
sest	doc_617668397761_item	2769964	et	4	main
sealt	doc_617668397761_item	2769971	et	4	main
saab	doc_617668397761_item	2769972	et	3	main
näha	doc_617668397761_item	2769973	et	3	main
eestlaste	doc_617668397761_item	2769974	et	4	main
mineviku	doc_617668397761_item	2769975	et	3	main
ja	doc_617668397761_item	2769976	et	3	main
kultuuri	doc_617668397761_item	2769977	et	4	main
vaadates	doc_617668397761_item	2769978	et	3	main
filmi	doc_617668397761_item	2769979	et	4	main
saad	doc_617668397761_item	2769980	et	4	main
aru	doc_617668397761_item	2769981	et	4	main
miks	doc_617668397761_item	2769982	et	4	main
eestlased	doc_617668397761_item	2769983	et	3	main
on	doc_617668397761_item	2769984	et	4	main
rahumeelsed	doc_617668397761_item	2769985	et	3	main
inimesed	doc_617668397761_item	2769986	et	3	main
ükskõik	doc_617668397761_item	2769987	et	3	main
mis	doc_617668397761_item	2769988	et	4	main
nendega	doc_617668397761_item	2769989	et	4	main
juhtub	doc_617668397761_item	2769990	et	3	main
nad	doc_617668397761_item	2769991	et	3	main
võtavad	doc_617668397761_item	2769992	et	3	main
vastu	doc_617668397761_item	2769993	et	3	main
uro	doc_617668397761_item	2770009	et	4	main
ilge	doc_617668397761_item	2770011	et	4	main
on	doc_617668397761_item	2770025	et	4	main
on	doc_617668397761_item	2770036	et	4	main
ehe	doc_617668397761_item	2770038	et	4	main
asi	doc_617668397761_item	2770040	et	4	main
ega	doc_617668397761_item	2770050	et	3	main
on	doc_617668397761_item	2770058	et	4	main
kergem	doc_617668397761_item	2770059	et	4	main
sest	doc_617668397761_item	2770060	et	4	main
nad	doc_617668397761_item	2770061	et	3	main
nalja	doc_617668397761_item	2770067	et	4	main
ajalugu	doc_617668397761_item	2770081	et	4	main
mis	doc_617668397761_item	2770084	et	4	main
filmis	doc_617668397761_item	2770105	et	4	main
moodi	doc_617668397761_item	2770119	et	4	main
saanud	doc_617668397761_item	2770121	et	4	main
meeldiv	doc_617668397761_item	2770123	et	4	main
on	doc_617668397761_item	2770124	et	4	main
ka	doc_617668397761_item	2770125	et	3	main
et	doc_617668397761_item	2770127	et	3	main
pärast	doc_617668397761_item	2770128	et	4	main
meeleolu	doc_617668397761_item	2770134	et	4	main
hiljuti	doc_617668397763_item	2770373	et	4	main
on	doc_617668397763_item	2770389	et	4	main
sündmustest	doc_617668397763_item	2770407	et	4	main
täpselt	doc_617668397763_item	2770412	et	4	main
puuduvad	doc_617668397763_item	2770418	et	4	main
on	doc_617668397763_item	2770420	et	4	main
õige	doc_617668397763_item	2770425	et	4	main
mis	doc_617668397763_item	2770426	et	4	main
on	doc_617668397763_item	2770427	et	4	main
tea	doc_617668397763_item	2770431	et	4	main
täpsemalt	doc_617668397763_item	2770432	et	4	main
kuidas	doc_617668397763_item	2770433	et	3	main
tõeliselt	doc_617668397763_item	2770435	et	4	main
see	doc_617668397763_item	2770436	et	3	main
võis	doc_617668397763_item	2770437	et	4	main
olla	doc_617668397763_item	2770438	et	3	main
nii	doc_617668397763_item	2770439	et	3	main
aru	doc_617668397763_item	2770455	et	4	main
hästi	doc_617668397763_item	2770456	et	3	main
eesti	doc_617668397763_item	2770457	et	4	main
ajaloofaktide	doc_617668397763_item	2770460	et	3	main
ei	doc_617668397763_item	2770468	et	4	main
olnud	doc_617668397763_item	2770478	et	4	main
vabaduseks	doc_617668397763_item	2770480	et	4	main
arvates	doc_617668397761_item	2770022	et	4	main
publikule	doc_617668397761_item	2770024	et	3	main
veidi	doc_617668397761_item	2770026	et	3	main
mõista	doc_617668397761_item	2770028	et	4	main
vaadates	doc_617668397761_item	2770032	et	3	main
sellest	doc_617668397761_item	2770041	et	4	main
ei	doc_617668397761_item	2770046	et	4	main
venelane	doc_617668397761_item	2770048	et	3	main
eestikeelsest	doc_617668397761_item	2770054	et	3	main
publikust	doc_617668397761_item	2770055	et	3	main
nendele	doc_617668397761_item	2770057	et	4	main
paremini	doc_617668397761_item	2770062	et	4	main
saavad	doc_617668397761_item	2770063	et	4	main
aru	doc_617668397761_item	2770064	et	4	main
otsad	doc_617668397761_item	2770075	et	4	main
siis	doc_617668397761_item	2770077	et	3	main
on	doc_617668397761_item	2770088	et	4	main
lugu	doc_617668397761_item	2770089	et	4	main
eestlaste	doc_617668397761_item	2770090	et	4	main
muistsest	doc_617668397761_item	2770091	et	3	main
vabadusvõitlusest	doc_617668397761_item	2770092	et	4	main
keegi	doc_617668397761_item	2770101	et	4	main
püüdnud	doc_617668397761_item	2770108	et	4	main
ei	doc_617668397761_item	2770120	et	4	main
see	doc_617668397761_item	2770126	et	3	main
lõbus	doc_617668397761_item	2770133	et	4	main
kujutatud	doc_617668397763_item	2770390	et	4	main
tõestisündinud	doc_617668397763_item	2770392	et	3	main
fakte	doc_617668397763_item	2770393	et	3	main
lavastatust	doc_617668397763_item	2770398	et	4	main
kõigil	doc_617668397763_item	2770401	et	4	main
teatakse	doc_617668397763_item	2770413	et	3	main
kui	doc_617668397761_item	2770073	et	3	main
võtta	doc_617668397761_item	2770074	et	3	main
kokku	doc_617668397761_item	2770076	et	3	main
on	doc_617668397761_item	2770082	et	4	main
aga	doc_617668397761_item	2770093	et	3	main
kuidas	doc_617668397761_item	2770094	et	3	main
see	doc_617668397761_item	2770095	et	3	main
päris	doc_617668397761_item	2770096	et	4	main
on	doc_617668397761_item	2770102	et	4	main
tore	doc_617668397761_item	2770103	et	3	main
et	doc_617668397761_item	2770104	et	3	main
pähe	doc_617668397761_item	2770109	et	4	main
suruda	doc_617668397761_item	2770110	et	3	main
mõtte	doc_617668397761_item	2770111	et	3	main
et	doc_617668397761_item	2770112	et	3	main
nii	doc_617668397761_item	2770113	et	3	main
see	doc_617668397761_item	2770114	et	3	main
oli	doc_617668397761_item	2770115	et	3	main
ei	doc_617668397761_item	2770116	et	4	main
kuidagi	doc_617668397761_item	2770117	et	3	main
olla	doc_617668397761_item	2770122	et	3	main
on	doc_617668397763_item	2770396	et	4	main
kauges	doc_617668397763_item	2770404	et	3	main
minevikus	doc_617668397763_item	2770405	et	3	main
toimunud	doc_617668397763_item	2770406	et	4	main
aga	doc_617668397763_item	2770411	et	3	main
kuna	doc_617668397763_item	2770415	et	3	main
sellepärast	doc_617668397763_item	2770419	et	3	main
raske	doc_617668397763_item	2770421	et	4	main
mis	doc_617668397763_item	2770423	et	4	main
on	doc_617668397763_item	2770424	et	4	main
me	doc_617668397763_item	2770429	et	4	main
oli	doc_617668397763_item	2770434	et	3	main
olla	doc_617668397763_item	2770442	et	3	main
vastab	doc_617668397763_item	2770465	et	3	main
rahvusriik	doc_617668397763_item	2770471	et	3	main
juba	doc_617668397763_item	2770472	et	3	main
miks	doc_617668397763_item	2770475	et	4	main
ja	doc_617668397763_item	2770488	et	3	main
ja	doc_617668397763_item	2770501	et	3	main
ähvardaval	doc_617668397763_item	2770504	et	4	main
karupee	doc_617668397763_item	2770507	et	4	main
külakeses	doc_617668397763_item	2770508	et	4	main
poiss	doc_617668397763_item	2770509	et	3	main
nimega	doc_617668397763_item	2770510	et	3	main
uru	doc_617668397763_item	2770511	et	3	main
üks	doc_617668397763_item	2770512	et	3	main
püüab	doc_617668397763_item	2770514	et	3	main
kinni	doc_617668397763_item	2770516	et	3	main
viib	doc_617668397763_item	2770518	et	3	main
karmid	doc_617668397763_item	2770524	et	4	main
mungad	doc_617668397763_item	2770525	et	3	main
õnneliku	doc_617668397763_item	2770531	et	3	main
tõttu	doc_617668397763_item	2770533	et	4	main
pääseb	doc_617668397763_item	2770534	et	3	main
muutununa	doc_617668397763_item	2770540	et	4	main
oma	doc_617668397763_item	2770555	et	4	main
eestlaste	doc_617668397763_item	2770566	et	4	main
oma	doc_617668397763_item	2770574	et	4	main
ei	doc_617668397763_item	2770578	et	4	main
kannatada	doc_617668397763_item	2770580	et	3	main
sakslane	doc_617668397763_item	2770584	et	3	main
eelistasid	doc_617668397763_item	2770598	et	4	main
ei	doc_617668397763_item	2770610	et	4	main
huvitanud	doc_617668397763_item	2770611	et	4	main
maades	doc_617668397763_item	2770615	et	4	main
rahvastega	doc_617668397763_item	2770620	et	4	main
palju	doc_617668397763_item	2770391	et	4	main
kuid	doc_617668397763_item	2770394	et	4	main
palju	doc_617668397763_item	2770395	et	4	main
ning	doc_617668397763_item	2770399	et	3	main
olemas	doc_617668397763_item	2770408	et	4	main
oma	doc_617668397763_item	2770409	et	4	main
arvamus	doc_617668397763_item	2770410	et	3	main
peaaegu	doc_617668397763_item	2770417	et	3	main
ütelda	doc_617668397763_item	2770422	et	4	main
vale	doc_617668397763_item	2770428	et	4	main
võis	doc_617668397763_item	2770441	et	4	main
värvikalt	doc_617668397763_item	2770449	et	4	main
eesti	doc_617668397763_item	2770450	et	4	main
rahvast	doc_617668397763_item	2770451	et	4	main
põhjustest	doc_617668397763_item	2770461	et	3	main
see	doc_617668397763_item	2770463	et	3	main
küsimustele	doc_617668397763_item	2770466	et	4	main
miks	doc_617668397763_item	2770467	et	4	main
tegevus	doc_617668397763_item	2770482	et	4	main
toimub	doc_617668397763_item	2770483	et	3	main
13	doc_617668397763_item	2770484	et	2	main
sajandi	doc_617668397763_item	2770485	et	3	main
ja	doc_617668397763_item	2770494	et	3	main
loodusrahvaid	doc_617668397763_item	2770499	et	3	main
ristirüütel	doc_617668397763_item	2770513	et	3	main
uru	doc_617668397763_item	2770515	et	3	main
essee	doc_617668397763_item	2770372	et	4	main
vaatasin	doc_617668397763_item	2770374	et	3	main
eesti	doc_617668397763_item	2770375	et	4	main
filmi	doc_617668397763_item	2770376	et	4	main
malev	doc_617668397763_item	2770377	et	3	main
mille	doc_617668397763_item	2770378	et	3	main
rezissööriks	doc_617668397763_item	2770379	et	4	main
on	doc_617668397763_item	2770380	et	4	main
kaaren	doc_617668397763_item	2770381	et	3	main
kaer	doc_617668397763_item	2770382	et	3	main
filmi	doc_617668397763_item	2770383	et	4	main
zanriks	doc_617668397763_item	2770384	et	4	main
on	doc_617668397763_item	2770385	et	4	main
ajalooline	doc_617668397763_item	2770386	et	4	main
komöödia	doc_617668397763_item	2770387	et	4	main
seal	doc_617668397763_item	2770388	et	4	main
ka	doc_617668397763_item	2770397	et	3	main
fantaasiat	doc_617668397763_item	2770400	et	3	main
on	doc_617668397763_item	2770402	et	4	main
küll	doc_617668397763_item	2770403	et	4	main
vähe	doc_617668397763_item	2770414	et	3	main
ajalooallikad	doc_617668397763_item	2770416	et	3	main
aga	doc_617668397763_item	2770440	et	3	main
teistmoodi	doc_617668397763_item	2770443	et	3	main
kujutatud	doc_617668397763_item	2770447	et	4	main
väga	doc_617668397763_item	2770448	et	3	main
saame	doc_617668397763_item	2770454	et	4	main
selle	doc_617668397763_item	2770459	et	4	main
näiteks	doc_617668397763_item	2770462	et	4	main
film	doc_617668397763_item	2770464	et	3	main
eestlaste	doc_617668397763_item	2770470	et	4	main
13	doc_617668397763_item	2770473	et	2	main
sajandil	doc_617668397763_item	2770474	et	3	main
eestlased	doc_617668397763_item	2770476	et	3	main
alguses	doc_617668397763_item	2770486	et	4	main
liivimaal	doc_617668397763_item	2770489	et	4	main
kus	doc_617668397763_item	2770490	et	3	main
saksa	doc_617668397763_item	2770491	et	4	main
väed	doc_617668397763_item	2770496	et	3	main
allutada	doc_617668397763_item	2770500	et	3	main
sünnib	doc_617668397763_item	2770506	et	3	main
saksamaale	doc_617668397763_item	2770520	et	4	main
kloostrisse	doc_617668397763_item	2770521	et	3	main
esimese	doc_617668397763_item	2770527	et	3	main
naaseb	doc_617668397763_item	2770538	et	3	main
endas	doc_617668397763_item	2770544	et	4	main
eestlaseks	doc_617668397763_item	2770546	et	3	main
kodumaad	doc_617668397763_item	2770556	et	4	main
ja	doc_617668397763_item	2770557	et	3	main
jääb	doc_617668397763_item	2770558	et	3	main
rahvuslaseks	doc_617668397763_item	2770559	et	3	main
see	doc_617668397763_item	2770560	et	3	main
kes	doc_617668397763_item	2770572	et	4	main
väärtusi	doc_617668397763_item	2770576	et	3	main
saanud	doc_617668397763_item	2770579	et	4	main
taluda	doc_617668397763_item	2770582	et	3	main
kuidas	doc_617668397763_item	2770583	et	3	main
ei	doc_617668397763_item	2770593	et	4	main
teineteist	doc_617668397763_item	2770603	et	4	main
laulda	doc_617668397763_item	2770606	et	4	main
mis	doc_617668397763_item	2770617	et	4	main
teiste	doc_617668397763_item	2770619	et	4	main
ei	doc_617668397763_item	2770430	et	4	main
selles	doc_617668397763_item	2770444	et	4	main
filmis	doc_617668397763_item	2770445	et	4	main
on	doc_617668397763_item	2770446	et	4	main
ja	doc_617668397763_item	2770452	et	3	main
me	doc_617668397763_item	2770453	et	4	main
ajaloost	doc_617668397763_item	2770458	et	4	main
tekkinud	doc_617668397763_item	2770469	et	4	main
ei	doc_617668397763_item	2770477	et	4	main
valmis	doc_617668397763_item	2770479	et	4	main
filmi	doc_617668397763_item	2770481	et	4	main
ordu	doc_617668397763_item	2770492	et	4	main
võimsad	doc_617668397763_item	2770493	et	3	main
üritavad	doc_617668397763_item	2770497	et	4	main
sel	doc_617668397763_item	2770503	et	3	main
tunnil	doc_617668397763_item	2770505	et	3	main
ja	doc_617668397763_item	2770517	et	3	main
annavad	doc_617668397763_item	2770523	et	3	main
urule	doc_617668397763_item	2770526	et	3	main
euroopaliku	doc_617668397763_item	2770529	et	3	main
juhuse	doc_617668397763_item	2770532	et	3	main
leidma	doc_617668397763_item	2770543	et	3	main
pani	doc_617668397763_item	2770562	et	4	main
mind	doc_617668397763_item	2770563	et	4	main
austavad	doc_617668397763_item	2770573	et	4	main
nad	doc_617668397763_item	2770577	et	3	main
valmis	doc_617668397763_item	2770596	et	4	main
nad	doc_617668397763_item	2770597	et	3	main
armastasid	doc_617668397763_item	2770602	et	4	main
armastasid	doc_617668397763_item	2770605	et	4	main
ja	doc_617668397763_item	2770607	et	3	main
tantsida	doc_617668397763_item	2770608	et	3	main
eestlasi	doc_617668397763_item	2770609	et	3	main
teistes	doc_617668397763_item	2770614	et	4	main
ning	doc_617668397763_item	2770616	et	3	main
juhtus	doc_617668397763_item	2770618	et	3	main
elasid	doc_617668397763_item	2770622	et	4	main
valmis	doc_617668397763_item	2770633	et	4	main
midagi	doc_617668397763_item	2770644	et	4	main
sõjapidajatena	doc_617668397763_item	2770650	et	3	main
lisaks	doc_617668397763_item	2770652	et	4	main
oli	doc_617668397763_item	2770653	et	3	main
eest	doc_617668397763_item	2770670	et	4	main
rahva	doc_617668397763_item	2770682	et	3	main
psühholoogilistest	doc_617668397763_item	2770683	et	4	main
kaotamiseni	doc_617668397763_item	2770688	et	4	main
keskmises	doc_617668397764_item	2770694	et	3	main
kasvanud	doc_617668397764_item	2770698	et	4	main
teab	doc_617668397764_item	2770700	et	3	main
tema	doc_617668397764_item	2770702	et	4	main
ja	doc_617668397764_item	2770711	et	3	main
heroilistest	doc_617668397764_item	2770719	et	3	main
eelkäijaest	doc_617668397764_item	2770720	et	4	main
eestlased	doc_617668397764_item	2770723	et	3	main
sellepärast	doc_617668397764_item	2770729	et	3	main
et	doc_617668397764_item	2770731	et	3	main
kasulik	doc_617668397764_item	2770734	et	3	main
lihtsalt	doc_617668397764_item	2770737	et	4	main
väiksele	doc_617668397764_item	2770741	et	4	main
kui	doc_617668397764_item	2770743	et	3	main
käigus	doc_617668397764_item	2770755	et	4	main
lübeckis	doc_617668397764_item	2770760	et	4	main
euroopa	doc_617668397764_item	2770764	et	4	main
ristiusku	doc_617668397764_item	2770767	et	4	main
ning	doc_617668397764_item	2770780	et	3	main
mõlema	doc_617668397764_item	2770781	et	3	main
huviorbiiti	doc_617668397764_item	2770782	et	4	main
eesti	doc_617668397764_item	2770785	et	4	main
olles	doc_617668397764_item	2770787	et	3	main
eestis	doc_617668397763_item	2770487	et	3	main
verehimulised	doc_617668397763_item	2770495	et	4	main
siinseid	doc_617668397763_item	2770498	et	3	main
ristida	doc_617668397763_item	2770502	et	4	main
ta	doc_617668397763_item	2770519	et	4	main
seal	doc_617668397763_item	2770522	et	4	main
eestlasena	doc_617668397763_item	2770528	et	3	main
kasvatuse	doc_617668397763_item	2770530	et	4	main
uru	doc_617668397763_item	2770535	et	3	main
vangistusest	doc_617668397763_item	2770536	et	4	main
ning	doc_617668397763_item	2770537	et	3	main
kodumaale	doc_617668397763_item	2770539	et	4	main
peab	doc_617668397763_item	2770541	et	4	main
ta	doc_617668397763_item	2770553	et	4	main
armastab	doc_617668397763_item	2770554	et	3	main
mõtlema	doc_617668397763_item	2770564	et	3	main
et	doc_617668397763_item	2770565	et	3	main
on	doc_617668397763_item	2770568	et	4	main
madisepäeva	doc_617668397763_item	2770589	et	4	main
lahing	doc_617668397763_item	2770590	et	3	main
kuid	doc_617668397763_item	2770591	et	4	main
olnud	doc_617668397763_item	2770594	et	4	main
vabaduseks	doc_617668397763_item	2770595	et	4	main
nad	doc_617668397763_item	2770604	et	3	main
mis	doc_617668397763_item	2770612	et	4	main
olnud	doc_617668397763_item	2770632	et	4	main
ei	doc_617668397763_item	2770641	et	4	main
oma	doc_617668397763_item	2770667	et	4	main
perekonna	doc_617668397763_item	2770668	et	4	main
eripäradest	doc_617668397763_item	2770684	et	3	main
mis	doc_617668397763_item	2770685	et	4	main
vabaduse	doc_617668397763_item	2770687	et	4	main
üles	doc_617668397764_item	2770697	et	3	main
oma	doc_617668397764_item	2770708	et	4	main
säilitamiseks	doc_617668397764_item	2770713	et	4	main
see	doc_617668397764_item	2770714	et	3	main
kollektiivsesse	doc_617668397764_item	2770715	et	4	main
mällu	doc_617668397764_item	2770716	et	3	main
tänapäeva	doc_617668397764_item	2770722	et	4	main
võib-olla	doc_617668397764_item	2770725	et	3	main
meelelahutulik	doc_617668397764_item	2770738	et	4	main
filmikogemus	doc_617668397764_item	2770739	et	3	main
koolijütsile	doc_617668397764_item	2770742	et	3	main
näinud	doc_617668397764_item	2770746	et	4	main
poiss	doc_617668397764_item	2770758	et	3	main
urule	doc_617668397764_item	2770762	et	3	main
kombeid	doc_617668397764_item	2770765	et	4	main
prantslased	doc_617668397764_item	2770786	et	3	main
huvitatud	doc_617668397764_item	2770788	et	4	main
karata	doc_617668397764_item	2770829	et	4	main
ja	doc_617668397764_item	2770836	et	3	main
näe	doc_617668397764_item	2770846	et	4	main
ja	doc_617668397764_item	2770847	et	3	main
teine	doc_617668397764_item	2770848	et	3	main
ei	doc_617668397764_item	2770849	et	4	main
kuule	doc_617668397764_item	2770850	et	4	main
midagi	doc_617668397764_item	2770855	et	4	main
enne	doc_617668397764_item	2770856	et	4	main
juba	doc_617668397764_item	2770859	et	3	main
kentsakas	doc_617668397764_item	2770871	et	4	main
oimetuks	doc_617668397764_item	2770879	et	4	main
laulda	doc_617668397764_item	2770880	et	4	main
jalge	doc_617668397764_item	2770885	et	4	main
tõmmata	doc_617668397764_item	2770887	et	4	main
arvab	doc_617668397764_item	2770889	et	3	main
lahendus	doc_617668397764_item	2770905	et	4	main
sõrmekooku	doc_617668397764_item	2770908	et	4	main
peab	doc_617668397764_item	2770910	et	4	main
vanematele	doc_617668397764_item	2770911	et	4	main
uru	doc_617668397764_item	2770915	et	3	main
enam	doc_617668397764_item	2770921	et	4	main
on	doc_617668397764_item	2770927	et	4	main
ristitud	doc_617668397764_item	2770928	et	4	main
pole	doc_617668397764_item	2770929	et	3	main
mõtet	doc_617668397764_item	2770930	et	3	main
arutleda	doc_617668397764_item	2770931	et	3	main
kui	doc_617668397764_item	2770932	et	3	main
tõepärane	doc_617668397764_item	2770933	et	4	main
filmi	doc_617668397764_item	2770938	et	4	main
ei	doc_617668397764_item	2770941	et	4	main
oluline	doc_617668397764_item	2770947	et	4	main
uru	doc_617668397763_item	2770542	et	3	main
jäämise	doc_617668397763_item	2770547	et	4	main
tasakaalu	doc_617668397763_item	2770545	et	4	main
ja	doc_617668397763_item	2770548	et	3	main
eurooplaseks	doc_617668397763_item	2770549	et	3	main
saamise	doc_617668397763_item	2770550	et	4	main
vahel	doc_617668397763_item	2770551	et	4	main
kuid	doc_617668397763_item	2770552	et	4	main
film	doc_617668397763_item	2770561	et	3	main
hulgas	doc_617668397763_item	2770567	et	4	main
tõelisi	doc_617668397763_item	2770569	et	4	main
kodumaa	doc_617668397763_item	2770570	et	4	main
patrioote	doc_617668397763_item	2770571	et	3	main
põliseid	doc_617668397763_item	2770575	et	4	main
ega	doc_617668397763_item	2770581	et	3	main
tallas	doc_617668397763_item	2770585	et	4	main
rukililli	doc_617668397763_item	2770586	et	4	main
nõnda	doc_617668397763_item	2770587	et	3	main
algas	doc_617668397763_item	2770588	et	3	main
eestlased	doc_617668397763_item	2770592	et	3	main
rahulikku	doc_617668397763_item	2770599	et	4	main
elu	doc_617668397763_item	2770600	et	4	main
nad	doc_617668397763_item	2770601	et	3	main
toimus	doc_617668397763_item	2770613	et	3	main
nad	doc_617668397763_item	2770621	et	3	main
ja	doc_617668397763_item	2770624	et	3	main
nende	doc_617668397763_item	2770625	et	4	main
piiratud	doc_617668397763_item	2770629	et	4	main
eestlased	doc_617668397763_item	2770630	et	3	main
ei	doc_617668397763_item	2770631	et	4	main
kaitsma	doc_617668397763_item	2770639	et	3	main
maakonnavanemad	doc_617668397763_item	2770640	et	4	main
samuti	doc_617668397763_item	2770643	et	3	main
tarka	doc_617668397763_item	2770645	et	4	main
nad	doc_617668397763_item	2770648	et	3	main
tapmise	doc_617668397763_item	2770669	et	4	main
tõlgenduse	doc_617668397763_item	2770676	et	4	main
kuidas	doc_617668397763_item	2770677	et	3	main
eestlased	doc_617668397763_item	2770678	et	3	main
orjastati	doc_617668397763_item	2770679	et	3	main
räägib	doc_617668397763_item	2770680	et	3	main
viisid	doc_617668397763_item	2770686	et	4	main
malev	doc_617668397764_item	2770690	et	3	main
eesti	doc_617668397764_item	2770695	et	4	main
et	doc_617668397764_item	2770701	et	3	main
esivanemad	doc_617668397764_item	2770703	et	4	main
on	doc_617668397764_item	2770704	et	4	main
usu	doc_617668397764_item	2770709	et	4	main
just	doc_617668397764_item	2770728	et	3	main
arvan	doc_617668397764_item	2770730	et	3	main
malev	doc_617668397764_item	2770732	et	3	main
ja	doc_617668397764_item	2770735	et	3	main
film	doc_617668397764_item	2770748	et	3	main
räägib	doc_617668397764_item	2770749	et	3	main
sajandi	doc_617668397764_item	2770751	et	3	main
kust	doc_617668397764_item	2770753	et	4	main
varastatakse	doc_617668397764_item	2770756	et	3	main
väike	doc_617668397764_item	2770757	et	4	main
uru	doc_617668397764_item	2770759	et	3	main
peksuga	doc_617668397764_item	2770763	et	3	main
ordu	doc_617668397764_item	2770776	et	4	main
vaheline	doc_617668397764_item	2770777	et	4	main
maade	doc_617668397764_item	2770778	et	3	main
ümberjagamine	doc_617668397764_item	2770779	et	3	main
nii	doc_617668397764_item	2770830	et	3	main
käib	doc_617668397764_item	2770831	et	3	main
uru	doc_617668397764_item	2770832	et	3	main
mööda	doc_617668397764_item	2770833	et	4	main
maad	doc_617668397764_item	2770834	et	4	main
midagi	doc_617668397764_item	2770840	et	4	main
peale	doc_617668397764_item	2770841	et	4	main
tehta	doc_617668397764_item	2770854	et	3	main
kuklasse	doc_617668397764_item	2770860	et	4	main
hingab	doc_617668397764_item	2770861	et	3	main
stseen	doc_617668397764_item	2770862	et	3	main
kus	doc_617668397764_item	2770863	et	3	main
vanemad	doc_617668397764_item	2770864	et	4	main
koosolekul	doc_617668397764_item	2770865	et	3	main
sakslaste	doc_617668397764_item	2770866	et	3	main
alistamist	doc_617668397764_item	2770867	et	4	main
vägagi	doc_617668397764_item	2770870	et	3	main
vanem	doc_617668397764_item	2770873	et	4	main
vaenlane	doc_617668397764_item	2770878	et	3	main
peaks	doc_617668397764_item	2770892	et	4	main
jootma	doc_617668397764_item	2770894	et	3	main
ning	doc_617668397764_item	2770901	et	3	main
neljas	doc_617668397764_item	2770902	et	4	main
et	doc_617668397764_item	2770903	et	3	main
aru	doc_617668397764_item	2770912	et	4	main
kes	doc_617668397764_item	2770916	et	4	main
vallutajatega	doc_617668397763_item	2770634	et	4	main
suutnud	doc_617668397763_item	2770642	et	4	main
välja	doc_617668397763_item	2770646	et	4	main
olid	doc_617668397763_item	2770649	et	4	main
saamatud	doc_617668397763_item	2770651	et	4	main
raskendatud	doc_617668397763_item	2770654	et	4	main
arusaamine	doc_617668397763_item	2770656	et	4	main
kuna	doc_617668397763_item	2770657	et	3	main
kõik	doc_617668397763_item	2770658	et	4	main
rääkisid	doc_617668397763_item	2770659	et	4	main
erinevaid	doc_617668397763_item	2770660	et	4	main
murdeid	doc_617668397763_item	2770661	et	3	main
filmi	doc_617668397763_item	2770662	et	4	main
lõpus	doc_617668397763_item	2770663	et	4	main
tasub	doc_617668397763_item	2770664	et	3	main
uru	doc_617668397763_item	2770665	et	3	main
omaette	doc_617668397763_item	2770623	et	3	main
maailmapilt	doc_617668397763_item	2770626	et	3	main
oli	doc_617668397763_item	2770627	et	3	main
väga	doc_617668397763_item	2770628	et	3	main
võitlema	doc_617668397763_item	2770635	et	3	main
ega	doc_617668397763_item	2770636	et	3	main
ennast	doc_617668397763_item	2770637	et	4	main
relvaga	doc_617668397763_item	2770638	et	3	main
mõelda	doc_617668397763_item	2770647	et	4	main
teineteisest	doc_617668397763_item	2770655	et	4	main
veriselt	doc_617668397763_item	2770671	et	4	main
ühe	doc_617668397763_item	2770681	et	4	main
essee	doc_617668397764_item	2770689	et	4	main
mõte	doc_617668397764_item	2770692	et	3	main
peres	doc_617668397764_item	2770696	et	3	main
eestlane	doc_617668397764_item	2770699	et	3	main
võitlusi	doc_617668397764_item	2770707	et	3	main
kultuuri	doc_617668397764_item	2770710	et	4	main
iseseisvuse	doc_617668397764_item	2770712	et	4	main
teeb	doc_617668397764_item	2770721	et	3	main
nii	doc_617668397764_item	2770740	et	3	main
ilma	doc_617668397764_item	2770745	et	4	main
saksa	doc_617668397764_item	2770773	et	4	main
ja	doc_617668397764_item	2770774	et	3	main
prantsuse	doc_617668397764_item	2770775	et	3	main
ka	doc_617668397764_item	2770784	et	3	main
rohkem	doc_617668397764_item	2770822	et	4	main
ja	doc_617668397764_item	2770824	et	3	main
otsib	doc_617668397764_item	2770837	et	3	main
kes	doc_617668397764_item	2770839	et	4	main
saarlaste	doc_617668397764_item	2770881	et	4	main
maa	doc_617668397764_item	2770884	et	4	main
et	doc_617668397764_item	2770890	et	3	main
ja	doc_617668397764_item	2770895	et	3	main
kirpe	doc_617668397764_item	2770898	et	3	main
täis	doc_617668397764_item	2770899	et	4	main
toppima	doc_617668397764_item	2770900	et	3	main
on	doc_617668397764_item	2770906	et	4	main
pähe	doc_617668397764_item	2770913	et	4	main
eestlaste	doc_617668397764_item	2770917	et	4	main
kohaselt	doc_617668397764_item	2770919	et	4	main
situdagi	doc_617668397764_item	2770922	et	4	main
on	doc_617668397764_item	2770937	et	4	main
olegi	doc_617668397764_item	2770942	et	4	main
eesmärk	doc_617668397764_item	2770944	et	3	main
on	doc_617668397764_item	2770946	et	4	main
täheldada	doc_617668397764_item	2770948	et	3	main
mida	doc_617668397764_item	2770957	et	4	main
lahingus	doc_617668397763_item	2770666	et	3	main
kätte	doc_617668397763_item	2770672	et	4	main
film	doc_617668397763_item	2770673	et	3	main
pakub	doc_617668397763_item	2770674	et	3	main
ühe	doc_617668397763_item	2770675	et	4	main
vaba	doc_617668397764_item	2770691	et	4	main
igas	doc_617668397764_item	2770693	et	3	main
pidanud	doc_617668397764_item	2770705	et	4	main
raskeid	doc_617668397764_item	2770706	et	3	main
sissesööbinud	doc_617668397764_item	2770717	et	4	main
tõdemus	doc_617668397764_item	2770718	et	3	main
uhkeks	doc_617668397764_item	2770724	et	4	main
ülemäära	doc_617668397764_item	2770726	et	3	main
uhkekski	doc_617668397764_item	2770727	et	4	main
on	doc_617668397764_item	2770733	et	4	main
ka	doc_617668397764_item	2770736	et	3	main
ka	doc_617668397764_item	2770744	et	3	main
professorile	doc_617668397764_item	2770747	et	3	main
13	doc_617668397764_item	2770750	et	2	main
eestist	doc_617668397764_item	2770752	et	3	main
röövretke	doc_617668397764_item	2770754	et	4	main
õpetatakse	doc_617668397764_item	2770761	et	3	main
ja	doc_617668397764_item	2770766	et	3	main
euroopa	doc_617668397764_item	2770768	et	4	main
kaardil	doc_617668397764_item	2770769	et	3	main
käib	doc_617668397764_item	2770770	et	3	main
aga	doc_617668397764_item	2770771	et	3	main
parasjagu	doc_617668397764_item	2770772	et	3	main
kuulub	doc_617668397764_item	2770783	et	3	main
eestimaa	doc_617668397764_item	2770789	et	4	main
konnavarudest	doc_617668397764_item	2770790	et	3	main
võtavad	doc_617668397764_item	2770791	et	3	main
uru	doc_617668397764_item	2770792	et	3	main
oma	doc_617668397764_item	2770793	et	4	main
kaitse	doc_617668397764_item	2770794	et	4	main
alla	doc_617668397764_item	2770795	et	3	main
ja	doc_617668397764_item	2770796	et	3	main
saadavad	doc_617668397764_item	2770797	et	4	main
viimase	doc_617668397764_item	2770798	et	3	main
eestisse	doc_617668397764_item	2770799	et	4	main
sõna	doc_617668397764_item	2770800	et	4	main
viima	doc_617668397764_item	2770801	et	3	main
et	doc_617668397764_item	2770802	et	3	main
sakslasest	doc_617668397764_item	2770803	et	3	main
vallutaja	doc_617668397764_item	2770804	et	4	main
on	doc_617668397764_item	2770805	et	4	main
tulekul	doc_617668397764_item	2770806	et	3	main
selle	doc_617668397764_item	2770807	et	4	main
asemel	doc_617668397764_item	2770808	et	4	main
aga	doc_617668397764_item	2770809	et	3	main
et	doc_617668397764_item	2770810	et	3	main
nutikas	doc_617668397764_item	2770811	et	4	main
lembitu	doc_617668397764_item	2770812	et	4	main
hakkaks	doc_617668397764_item	2770813	et	3	main
sõnumit	doc_617668397764_item	2770814	et	3	main
kuuldes	doc_617668397764_item	2770815	et	4	main
malevat	doc_617668397764_item	2770816	et	3	main
kokku	doc_617668397764_item	2770817	et	3	main
ajama	doc_617668397764_item	2770818	et	4	main
on	doc_617668397764_item	2770819	et	4	main
viimane	doc_617668397764_item	2770820	et	3	main
huvitatud	doc_617668397764_item	2770821	et	4	main
laulumängudest	doc_617668397764_item	2770823	et	3	main
esimese	doc_617668397764_item	2770825	et	3	main
öö	doc_617668397764_item	2770826	et	4	main
ringi	doc_617668397764_item	2770835	et	4	main
vanemat	doc_617668397764_item	2770838	et	4	main
hakkaks	doc_617668397764_item	2770842	et	3	main
kuid	doc_617668397764_item	2770843	et	4	main
üks	doc_617668397764_item	2770844	et	3	main
ning	doc_617668397764_item	2770851	et	3	main
nii	doc_617668397764_item	2770852	et	3	main
plaanivad	doc_617668397764_item	2770868	et	4	main
hiiumaa	doc_617668397764_item	2770872	et	4	main
veste	doc_617668397764_item	2770874	et	4	main
paneb	doc_617668397764_item	2770875	et	3	main
vanem	doc_617668397764_item	2770882	et	4	main
parim	doc_617668397764_item	2770904	et	4	main
tõmmata	doc_617668397764_item	2770907	et	4	main
nii	doc_617668397764_item	2770909	et	3	main
panema	doc_617668397764_item	2770914	et	3	main
uskumuse	doc_617668397764_item	2770918	et	3	main
ammu	doc_617668397764_item	2770920	et	4	main
õigusest	doc_617668397764_item	2770827	et	4	main
naisi	doc_617668397764_item	2770828	et	3	main
ei	doc_617668397764_item	2770845	et	4	main
ei	doc_617668397764_item	2770853	et	4	main
kui	doc_617668397764_item	2770857	et	3	main
oht	doc_617668397764_item	2770858	et	3	main
on	doc_617668397764_item	2770869	et	4	main
näiteks	doc_617668397764_item	2770876	et	4	main
ette	doc_617668397764_item	2770877	et	4	main
vaenlaselt	doc_617668397764_item	2770883	et	3	main
alt	doc_617668397764_item	2770886	et	4	main
kolmas	doc_617668397764_item	2770888	et	3	main
sakslased	doc_617668397764_item	2770891	et	3	main
täis	doc_617668397764_item	2770893	et	4	main
siis	doc_617668397764_item	2770896	et	3	main
püksid	doc_617668397764_item	2770897	et	3	main
saama	doc_617668397764_item	2770925	et	4	main
või	doc_617668397764_item	2770934	et	4	main
ülesehitus	doc_617668397764_item	2770939	et	4	main
ajakohaseid	doc_617668397764_item	2770952	et	4	main
elemente	doc_617668397764_item	2770953	et	3	main
irooniat	doc_617668397764_item	2770956	et	3	main
jätkub	doc_617668397764_item	2770958	et	3	main
eestlaste	doc_617668397764_item	2770960	et	4	main
pihta	doc_617668397764_item	2770965	et	4	main
interpretatsiooni	doc_617668397764_item	2770981	et	4	main
malev	doc_617668397766_item	2771245	et	3	main
on	doc_617668397766_item	2771249	et	4	main
tolle	doc_617668397766_item	2771263	et	4	main
väike	doc_617668397766_item	2771265	et	4	main
mainima	doc_617668397766_item	2771277	et	3	main
et	doc_617668397766_item	2771278	et	3	main
vabaduse	doc_617668397766_item	2771279	et	4	main
filmi	doc_617668397766_item	2771283	et	4	main
pööramine	doc_617668397766_item	2771296	et	4	main
see	doc_617668397766_item	2771297	et	3	main
kerge	doc_617668397766_item	2771300	et	4	main
abiga	doc_617668397766_item	2771329	et	3	main
varsti	doc_617668397766_item	2771330	et	3	main
kodumaale	doc_617668397766_item	2771331	et	4	main
ordu	doc_617668397766_item	2771338	et	4	main
sest	doc_617668397766_item	2771352	et	4	main
ei	doc_617668397764_item	2770923	et	4	main
peaks	doc_617668397764_item	2770924	et	4	main
ja	doc_617668397764_item	2770954	et	3	main
sakslaste	doc_617668397764_item	2770961	et	3	main
niikuinii	doc_617668397764_item	2770967	et	4	main
teada	doc_617668397764_item	2770969	et	3	main
eestlaste	doc_617668397764_item	2770971	et	4	main
teemal	doc_617668397764_item	2770982	et	3	main
mis	doc_617668397764_item	2770983	et	4	main
muidu	doc_617668397764_item	2770984	et	3	main
tundub	doc_617668397764_item	2770985	et	3	main
nii	doc_617668397764_item	2770986	et	3	main
püha	doc_617668397764_item	2770987	et	4	main
ja	doc_617668397764_item	2770988	et	3	main
muutmatu	doc_617668397764_item	2770989	et	4	main
sest	doc_617668397764_item	2770926	et	4	main
ajalooliselt	doc_617668397764_item	2770935	et	4	main
korrektne	doc_617668397764_item	2770936	et	3	main
see	doc_617668397764_item	2770940	et	3	main
maleva	doc_617668397764_item	2770943	et	3	main
pigem	doc_617668397764_item	2770945	et	3	main
ennekõike	doc_617668397764_item	2770955	et	3	main
nii	doc_617668397764_item	2770959	et	3	main
kui	doc_617668397764_item	2770962	et	3	main
ka	doc_617668397764_item	2770963	et	3	main
prantslaste	doc_617668397764_item	2770964	et	3	main
tegelikult	doc_617668397764_item	2770974	et	4	main
kulges	doc_617668397764_item	2770975	et	3	main
siis	doc_617668397764_item	2770976	et	3	main
miks	doc_617668397764_item	2770977	et	4	main
mitte	doc_617668397764_item	2770978	et	3	main
lubada	doc_617668397764_item	2770979	et	3	main
vaba	doc_617668397764_item	2770980	et	4	main
väikeseid	doc_617668397764_item	2770949	et	4	main
tabavaid	doc_617668397764_item	2770950	et	4	main
ütlusi	doc_617668397764_item	2770951	et	3	main
kui	doc_617668397764_item	2770966	et	3	main
pole	doc_617668397764_item	2770968	et	3	main
kuidas	doc_617668397764_item	2770970	et	3	main
muistne	doc_617668397764_item	2770972	et	3	main
vabadusvõitlus	doc_617668397764_item	2770973	et	3	main
filmi	doc_617668397766_item	2771247	et	4	main
mille	doc_617668397766_item	2771252	et	3	main
13	doc_617668397766_item	2771255	et	2	main
sajaldil	doc_617668397766_item	2771256	et	4	main
eestis	doc_617668397766_item	2771257	et	3	main
ja	doc_617668397766_item	2771258	et	3	main
liivimaal	doc_617668397766_item	2771259	et	4	main
see	doc_617668397766_item	2771260	et	3	main
oleks	doc_617668397766_item	2771261	et	3	main
juskui	doc_617668397766_item	2771262	et	4	main
mitte	doc_617668397766_item	2771267	et	3	main
kogu	doc_617668397766_item	2771282	et	4	main
sajandi	doc_617668397766_item	2771286	et	3	main
eesti	doc_617668397766_item	2771290	et	4	main
ja	doc_617668397766_item	2771291	et	3	main
läti	doc_617668397766_item	2771292	et	4	main
maaalade	doc_617668397766_item	2771293	et	3	main
rahva	doc_617668397766_item	2771294	et	3	main
ristiusku	doc_617668397766_item	2771295	et	4	main
sunniviisiliselt	doc_617668397766_item	2771321	et	4	main
tagasiteel	doc_617668397766_item	2771333	et	3	main
ta	doc_617668397766_item	2771350	et	4	main
hõivatud	doc_617668397766_item	2771355	et	4	main
mitmed	doc_617668397766_item	2771365	et	4	main
naljakad	doc_617668397766_item	2771366	et	3	main
olukorrad	doc_617668397766_item	2771367	et	3	main
naeratust	doc_617668397766_item	2771370	et	4	main
eesti	doc_617668397766_item	2771371	et	4	main
nii	doc_617668397766_item	2771375	et	3	main
tööd	doc_617668397766_item	2771409	et	4	main
seda	doc_617668397766_item	2771414	et	3	main
ole	doc_617668397766_item	2771416	et	4	main
et	doc_617668397766_item	2771422	et	3	main
võib	doc_617668397766_item	2771429	et	3	main
jääda	doc_617668397766_item	2771431	et	4	main
mõstavad	doc_617668397766_item	2771440	et	4	main
eestlased	doc_617668397766_item	2771442	et	3	main
omast	doc_617668397766_item	2771464	et	4	main
essee	doc_617668397766_item	2771243	et	4	main
tutvustus	doc_617668397766_item	2771246	et	4	main
malev	doc_617668397766_item	2771248	et	3	main
ehtne	doc_617668397766_item	2771250	et	3	main
tegevus	doc_617668397766_item	2771253	et	4	main
ja	doc_617668397766_item	2771266	et	3	main
detailsem	doc_617668397766_item	2771269	et	4	main
muistsete	doc_617668397766_item	2771273	et	3	main
eestlaste	doc_617668397766_item	2771274	et	4	main
13	doc_617668397766_item	2771285	et	2	main
euroopasse	doc_617668397766_item	2771322	et	3	main
saadetud	doc_617668397766_item	2771323	et	4	main
haridust	doc_617668397766_item	2771324	et	4	main
omandama	doc_617668397766_item	2771325	et	3	main
põgeneb	doc_617668397766_item	2771326	et	3	main
prantslasest	doc_617668397766_item	2771327	et	3	main
munga	doc_617668397766_item	2771328	et	3	main
saab	doc_617668397766_item	2771334	et	3	main
kodu	doc_617668397766_item	2771344	et	4	main
poole	doc_617668397766_item	2771345	et	4	main
toetust	doc_617668397766_item	2771351	et	4	main
oma	doc_617668397766_item	2771356	et	4	main
võivad	doc_617668397766_item	2771368	et	4	main
on	doc_617668397766_item	2771410	et	4	main
paraku	doc_617668397766_item	2771411	et	3	main
peaaegu	doc_617668397766_item	2771421	et	3	main
kes	doc_617668397766_item	2771425	et	4	main
siiski	doc_617668397766_item	2771434	et	4	main
passiivne	doc_617668397766_item	2771435	et	3	main
roll	doc_617668397766_item	2771436	et	3	main
mida	doc_617668397766_item	2771439	et	4	main
kultuuriga	doc_617668397766_item	2771448	et	4	main
tuttavad	doc_617668397766_item	2771450	et	4	main
tunda	doc_617668397766_item	2771460	et	3	main
eestlastele	doc_617668397766_item	2771462	et	4	main
teos	doc_617668397766_item	2771467	et	4	main
mulle	doc_617668397766_item	2771470	et	4	main
ka	doc_617668397766_item	2771474	et	3	main
soovitaks	doc_617668397766_item	2771477	et	4	main
siiski	doc_617668397766_item	2771479	et	4	main
vaadata	doc_617668397766_item	2771480	et	4	main
eriti	doc_617668397766_item	2771481	et	3	main
huvituvad	doc_617668397766_item	2771484	et	4	main
tagamaid	doc_617668397766_item	2771494	et	4	main
malev	doc_617668397766_item	2771495	et	3	main
annab	doc_617668397766_item	2771496	et	3	main
vastuseid	doc_617668397766_item	2771497	et	3	main
mõningatele	doc_617668397766_item	2771498	et	3	main
kultuuri	doc_617668397766_item	2771500	et	4	main
malev	doc_617668397767_item	2771509	et	3	main
ehtne	doc_617668397767_item	2771514	et	3	main
film	doc_617668397767_item	2771522	et	3	main
muistsest	doc_617668397767_item	2771523	et	3	main
eesti-	doc_617668397767_item	2771529	et	4	main
ja	doc_617668397767_item	2771530	et	3	main
liivimaal	doc_617668397767_item	2771531	et	4	main
kus	doc_617668397767_item	2771532	et	3	main
lisaks	doc_617668397767_item	2771533	et	4	main
küll	doc_617668397767_item	2771545	et	4	main
käigus	doc_617668397767_item	2771565	et	4	main
kaasa	doc_617668397767_item	2771568	et	4	main
lübecki	doc_617668397767_item	2771571	et	4	main
ja	doc_617668397767_item	2771589	et	3	main
õhutada	doc_617668397767_item	2771591	et	3	main
lembituga	doc_617668397767_item	2771595	et	4	main
varitsevast	doc_617668397767_item	2771600	et	4	main
ohust	doc_617668397767_item	2771601	et	3	main
kui	doc_617668397767_item	2771604	et	3	main
aga	doc_617668397767_item	2771606	et	3	main
on	doc_617668397767_item	2771610	et	4	main
idee	doc_617668397767_item	2771632	et	4	main
eestlaste	doc_617668397767_item	2771635	et	4	main
filmi	doc_617668397766_item	2771244	et	4	main
absurdkomöödia	doc_617668397766_item	2771251	et	4	main
toimub	doc_617668397766_item	2771254	et	3	main
aja	doc_617668397766_item	2771264	et	4	main
kõige	doc_617668397766_item	2771268	et	4	main
kroonika	doc_617668397766_item	2771270	et	4	main
film	doc_617668397766_item	2771271	et	3	main
räägib	doc_617668397766_item	2771272	et	3	main
teema	doc_617668397766_item	2771280	et	4	main
läbib	doc_617668397766_item	2771281	et	3	main
süžeed	doc_617668397766_item	2771284	et	2	main
alguses	doc_617668397766_item	2771287	et	4	main
toimus	doc_617668397766_item	2771288	et	3	main
teatavasti	doc_617668397766_item	2771289	et	3	main
ei	doc_617668397766_item	2771298	et	4	main
aeg	doc_617668397766_item	2771301	et	3	main
eestlaste	doc_617668397766_item	2771302	et	4	main
jaoks	doc_617668397766_item	2771303	et	4	main
seetõttu	doc_617668397766_item	2771304	et	3	main
vabadusvõistlusest	doc_617668397766_item	2771275	et	4	main
peab	doc_617668397766_item	2771276	et	4	main
olnud	doc_617668397766_item	2771299	et	4	main
soovisid	doc_617668397766_item	2771305	et	4	main
filmi	doc_617668397766_item	2771306	et	4	main
tegijad	doc_617668397766_item	2771307	et	4	main
näidata	doc_617668397766_item	2771308	et	4	main
oma	doc_617668397766_item	2771309	et	4	main
visiooni	doc_617668397766_item	2771310	et	4	main
ja	doc_617668397766_item	2771311	et	3	main
edastada	doc_617668397766_item	2771312	et	3	main
seda	doc_617668397766_item	2771313	et	3	main
tänapäevase	doc_617668397766_item	2771314	et	4	main
vaatajani	doc_617668397766_item	2771315	et	4	main
loo	doc_617668397766_item	2771316	et	4	main
peategelane	doc_617668397766_item	2771317	et	3	main
uru	doc_617668397766_item	2771318	et	3	main
oli	doc_617668397766_item	2771320	et	3	main
kes	doc_617668397766_item	2771319	et	4	main
ta	doc_617668397766_item	2771335	et	4	main
teada	doc_617668397766_item	2771336	et	3	main
veelgi	doc_617668397766_item	2771342	et	4	main
enam	doc_617668397766_item	2771343	et	4	main
tuua	doc_617668397766_item	2771369	et	3	main
kultuuriga	doc_617668397766_item	2771372	et	4	main
tutvunud	doc_617668397766_item	2771373	et	4	main
jäetakse	doc_617668397766_item	2771376	et	3	main
üksi	doc_617668397766_item	2771378	et	4	main
vaba	doc_617668397766_item	2771406	et	4	main
hinnata	doc_617668397766_item	2771412	et	4	main
ei	doc_617668397766_item	2771415	et	4	main
praktiliselt	doc_617668397766_item	2771417	et	4	main
näha	doc_617668397766_item	2771418	et	3	main
uru	doc_617668397766_item	2771419	et	3	main
on	doc_617668397766_item	2771420	et	4	main
eestisse	doc_617668397766_item	2771332	et	4	main
saksa	doc_617668397766_item	2771337	et	4	main
plaanidest	doc_617668397766_item	2771339	et	3	main
ning	doc_617668397766_item	2771340	et	3	main
kiirustab	doc_617668397766_item	2771341	et	3	main
seal	doc_617668397766_item	2771346	et	4	main
aga	doc_617668397766_item	2771347	et	3	main
ei	doc_617668397766_item	2771348	et	4	main
leia	doc_617668397766_item	2771349	et	4	main
kõik	doc_617668397766_item	2771353	et	4	main
on	doc_617668397766_item	2771354	et	4	main
eluga	doc_617668397766_item	2771358	et	3	main
vaatajale	doc_617668397766_item	2771374	et	4	main
teda	doc_617668397766_item	2771377	et	4	main
mõtisklema	doc_617668397766_item	2771379	et	3	main
paratamatu	doc_617668397766_item	2771380	et	4	main
olukorra	doc_617668397766_item	2771381	et	3	main
üle	doc_617668397766_item	2771382	et	3	main
saades	doc_617668397766_item	2771383	et	3	main
lõpuks	doc_617668397766_item	2771384	et	4	main
hulga	doc_617668397766_item	2771385	et	4	main
rahvast	doc_617668397766_item	2771386	et	4	main
kokku	doc_617668397766_item	2771387	et	3	main
võitleb	doc_617668397766_item	2771388	et	3	main
ta	doc_617668397766_item	2771389	et	4	main
raskes	doc_617668397766_item	2771390	et	3	main
lahingus	doc_617668397766_item	2771391	et	3	main
oma	doc_617668397766_item	2771392	et	4	main
maa	doc_617668397766_item	2771393	et	4	main
vabaduse	doc_617668397766_item	2771394	et	4	main
eest	doc_617668397766_item	2771395	et	4	main
loo	doc_617668397766_item	2771396	et	4	main
lõpp	doc_617668397766_item	2771397	et	3	main
on	doc_617668397766_item	2771398	et	4	main
traditsiooniline	doc_617668397766_item	2771399	et	4	main
peategelane	doc_617668397766_item	2771400	et	3	main
sureb	doc_617668397766_item	2771401	et	3	main
võideldes	doc_617668397766_item	2771402	et	3	main
jätab	doc_617668397766_item	2771403	et	3	main
oma	doc_617668397766_item	2771404	et	4	main
rahvale	doc_617668397766_item	2771405	et	3	main
igapäevase	doc_617668397766_item	2771357	et	4	main
mida	doc_617668397766_item	2771359	et	4	main
humoorikalt	doc_617668397766_item	2771360	et	4	main
näitas	doc_617668397766_item	2771361	et	3	main
režissöör	doc_617668397766_item	2771362	et	2	main
kaaren	doc_617668397766_item	2771363	et	3	main
kaer	doc_617668397766_item	2771364	et	3	main
maad	doc_617668397766_item	2771407	et	4	main
on	doc_617668397766_item	2771433	et	4	main
rohkem	doc_617668397766_item	2771449	et	4	main
on	doc_617668397766_item	2771451	et	4	main
filmis	doc_617668397766_item	2771458	et	4	main
palju	doc_617668397766_item	2771461	et	4	main
mitte	doc_617668397766_item	2771463	et	3	main
ei	doc_617668397766_item	2771471	et	4	main
positiivset	doc_617668397766_item	2771475	et	3	main
eestlase	doc_617668397766_item	2771487	et	3	main
ja	doc_617668397766_item	2771489	et	3	main
teada	doc_617668397766_item	2771491	et	3	main
tänapäevaste	doc_617668397766_item	2771492	et	4	main
kultuuritraditsioonide	doc_617668397766_item	2771493	et	3	main
malev	doc_617668397767_item	2771508	et	3	main
on	doc_617668397767_item	2771544	et	4	main
piltilus	doc_617668397767_item	2771553	et	4	main
ühe	doc_617668397767_item	2771561	et	4	main
ordu	doc_617668397767_item	2771563	et	4	main
aladelt	doc_617668397767_item	2771567	et	3	main
ain	doc_617668397767_item	2771596	et	3	main
kuuldagi	doc_617668397767_item	2771603	et	4	main
pöörde	doc_617668397767_item	2771608	et	3	main
kanad	doc_617668397767_item	2771614	et	3	main
kärajad	doc_617668397767_item	2771617	et	4	main
ei	doc_617668397767_item	2771621	et	4	main
sellegi	doc_617668397767_item	2771623	et	4	main
kelle	doc_617668397767_item	2771631	et	4	main
vaadata	doc_617668397767_item	2771646	et	4	main
mõningased	doc_617668397767_item	2771650	et	3	main
paroodia	doc_617668397767_item	2771658	et	4	main
vaatajale	doc_617668397767_item	2771659	et	4	main
lihtsalt	doc_617668397767_item	2771660	et	4	main
arusaamatuks	doc_617668397767_item	2771661	et	4	main
keda	doc_617668397767_item	2771671	et	4	main
küll	doc_617668397767_item	2771672	et	4	main
kohtlastena	doc_617668397767_item	2771675	et	4	main
aga	doc_617668397767_item	2771676	et	3	main
eks	doc_617668397767_item	2771677	et	3	main
kõigele	doc_617668397767_item	2771716	et	4	main
teadvaid	doc_617668397767_item	2771718	et	4	main
rügavaid	doc_617668397767_item	2771727	et	4	main
filmis	doc_617668397767_item	2771729	et	4	main
uusberg	doc_617668397767_item	2771731	et	4	main
ainult	doc_617668397767_item	2771733	et	4	main
ringi	doc_617668397767_item	2771735	et	4	main
vaadata	doc_617668397767_item	2771736	et	4	main
vaid	doc_617668397767_item	2771751	et	3	main
komöödiaga	doc_617668397767_item	2771753	et	4	main
mis	doc_617668397767_item	2771760	et	4	main
tegelikult	doc_617668397767_item	2771761	et	4	main
ajal	doc_617668397767_item	2771771	et	4	main
ainult	doc_617668397767_item	2771778	et	4	main
oletada	doc_617668397767_item	2771779	et	3	main
teil	doc_617668397767_item	2771782	et	4	main
on	doc_617668397767_item	2771783	et	4	main
ordu	doc_617668397768_item	2771818	et	4	main
võimsad	doc_617668397768_item	2771819	et	3	main
väed	doc_617668397768_item	2771820	et	3	main
näitlejate	doc_617668397766_item	2771408	et	4	main
raske	doc_617668397766_item	2771413	et	4	main
ainuke	doc_617668397766_item	2771423	et	4	main
tegelane	doc_617668397766_item	2771424	et	3	main
mõne	doc_617668397766_item	2771426	et	3	main
aja	doc_617668397766_item	2771427	et	4	main
möödudes	doc_617668397766_item	2771428	et	3	main
meelde	doc_617668397766_item	2771430	et	3	main
paljud	doc_617668397766_item	2771437	et	3	main
praegused	doc_617668397766_item	2771441	et	3	main
ja	doc_617668397766_item	2771443	et	3	main
kes	doc_617668397766_item	2771445	et	4	main
on	doc_617668397766_item	2771459	et	4	main
jätnud	doc_617668397766_item	2771469	et	4	main
muljet	doc_617668397766_item	2771476	et	3	main
filmi	doc_617668397766_item	2771478	et	4	main
kultuurist	doc_617668397766_item	2771486	et	3	main
mõttemaailmast	doc_617668397766_item	2771488	et	4	main
soovivad	doc_617668397766_item	2771490	et	4	main
puudutavatele	doc_617668397766_item	2771501	et	4	main
mis	doc_617668397766_item	2771503	et	4	main
tekivad	doc_617668397766_item	2771504	et	3	main
erinevatel	doc_617668397766_item	2771505	et	4	main
rahvustel	doc_617668397766_item	2771506	et	3	main
2005	doc_617668397767_item	2771511	et	2	main
ja	doc_617668397767_item	2771515	et	3	main
eestimaine	doc_617668397767_item	2771516	et	4	main
109	doc_617668397767_item	2771518	et	2	main
minutit	doc_617668397767_item	2771519	et	3	main
kestev	doc_617668397767_item	2771520	et	4	main
enamusel	doc_617668397766_item	2771432	et	4	main
naljad	doc_617668397766_item	2771438	et	3	main
need	doc_617668397766_item	2771444	et	3	main
on	doc_617668397766_item	2771446	et	4	main
eesti	doc_617668397766_item	2771447	et	4	main
kahtlemata	doc_617668397766_item	2771452	et	4	main
arusaamatud	doc_617668397766_item	2771453	et	4	main
ameeriklastele	doc_617668397766_item	2771454	et	3	main
venelastele	doc_617668397766_item	2771455	et	4	main
sakslastele	doc_617668397766_item	2771456	et	3	main
soomlastele	doc_617668397766_item	2771457	et	3	main
eneseirooniat	doc_617668397766_item	2771465	et	3	main
see	doc_617668397766_item	2771466	et	3	main
negatiivset	doc_617668397766_item	2771472	et	3	main
neile	doc_617668397766_item	2771482	et	4	main
kes	doc_617668397766_item	2771483	et	4	main
essee	doc_617668397767_item	2771507	et	4	main
on	doc_617668397767_item	2771510	et	4	main
valminud	doc_617668397767_item	2771513	et	4	main
13saj	doc_617668397767_item	2771528	et	4	main
ordu	doc_617668397767_item	2771535	et	4	main
ristirüütlitele	doc_617668397767_item	2771536	et	3	main
figureerib	doc_617668397767_item	2771537	et	3	main
veel	doc_617668397767_item	2771538	et	4	main
on	doc_617668397767_item	2771552	et	4	main
eesti	doc_617668397767_item	2771566	et	4	main
haaratakse	doc_617668397767_item	2771569	et	3	main
ning	doc_617668397767_item	2771570	et	3	main
vastupanu	doc_617668397767_item	2771590	et	4	main
rahvas	doc_617668397767_item	2771592	et	4	main
eesotsas	doc_617668397767_item	2771593	et	4	main
ei	doc_617668397767_item	2771598	et	4	main
esialgu	doc_617668397767_item	2771602	et	3	main
tõsisema	doc_617668397767_item	2771607	et	4	main
peata	doc_617668397767_item	2771613	et	4	main
ei	doc_617668397766_item	2771468	et	4	main
ega	doc_617668397766_item	2771473	et	3	main
eesti	doc_617668397766_item	2771485	et	4	main
eesti	doc_617668397766_item	2771499	et	4	main
küsimustele	doc_617668397766_item	2771502	et	4	main
aastal	doc_617668397767_item	2771512	et	3	main
tervelt	doc_617668397767_item	2771517	et	4	main
humoorikas	doc_617668397767_item	2771521	et	4	main
filmi	doc_617668397767_item	2771525	et	4	main
prantslaste	doc_617668397767_item	2771539	et	3	main
templiordu	doc_617668397767_item	2771540	et	4	main
kelle	doc_617668397767_item	2771541	et	4	main
eesmärgiks	doc_617668397767_item	2771542	et	3	main
oma	doc_617668397767_item	2771547	et	4	main
täiendamine	doc_617668397767_item	2771549	et	4	main
filmi	doc_617668397767_item	2771550	et	4	main
kangelane	doc_617668397767_item	2771551	et	3	main
saksa	doc_617668397767_item	2771562	et	4	main
vanem	doc_617668397767_item	2771594	et	4	main
mäeots	doc_617668397767_item	2771597	et	3	main
taha	doc_617668397767_item	2771599	et	4	main
sündmused	doc_617668397767_item	2771605	et	3	main
võtavad	doc_617668397767_item	2771609	et	3	main
vanemad	doc_617668397767_item	2771611	et	4	main
nagu	doc_617668397767_item	2771612	et	3	main
kutsutakse	doc_617668397767_item	2771615	et	3	main
küll	doc_617668397767_item	2771616	et	4	main
kokku	doc_617668397767_item	2771618	et	3	main
aga	doc_617668397767_item	2771619	et	3	main
ettevõetavas	doc_617668397767_item	2771620	et	3	main
appi	doc_617668397767_item	2771628	et	4	main
tuleb	doc_617668397767_item	2771629	et	3	main
uru	doc_617668397767_item	2771630	et	3	main
kõigi	doc_617668397767_item	2771638	et	4	main
lõõgastav	doc_617668397767_item	2771645	et	4	main
tulevad	doc_617668397767_item	2771648	et	4	main
näme	doc_617668397767_item	2771664	et	4	main
endid	doc_617668397767_item	2771666	et	4	main
veidi	doc_617668397767_item	2771674	et	3	main
vastust	doc_617668397767_item	2771717	et	4	main
kobin	doc_617668397767_item	2771722	et	4	main
tuimalt	doc_617668397767_item	2771725	et	4	main
tugiseid	doc_617668397767_item	2771728	et	4	main
filmi	doc_617668397767_item	2771737	et	4	main
vaadates	doc_617668397767_item	2771738	et	3	main
detailsetele	doc_617668397767_item	2771747	et	4	main
dokumentaalfilmiga	doc_617668397767_item	2771750	et	3	main
fantaasiarikka	doc_617668397767_item	2771752	et	4	main
filmis	doc_617668397767_item	2771754	et	4	main
autorite	doc_617668397767_item	2771757	et	3	main
sellest	doc_617668397767_item	2771759	et	4	main
seepärast	doc_617668397767_item	2771766	et	3	main
tõde	doc_617668397767_item	2771769	et	4	main
tol	doc_617668397767_item	2771770	et	3	main
me	doc_617668397767_item	2771773	et	4	main
kui	doc_617668397767_item	2771781	et	3	main
rahvast	doc_617668397768_item	2771823	et	4	main
on	doc_617668397768_item	2771838	et	4	main
lübecki	doc_617668397768_item	2771848	et	4	main
rääkides	doc_617668397768_item	2771863	et	4	main
kuid	doc_617668397768_item	2771866	et	4	main
vabadus	doc_617668397768_item	2771875	et	4	main
ja	doc_617668397768_item	2771876	et	3	main
õpetada	doc_617668397768_item	2771884	et	3	main
paremini	doc_617668397768_item	2771886	et	4	main
esialgu	doc_617668397768_item	2771888	et	3	main
ole	doc_617668397768_item	2771896	et	4	main
sama	doc_617668397768_item	2771903	et	4	main
ja	doc_617668397768_item	2771921	et	3	main
kogemuse	doc_617668397768_item	2771923	et	3	main
kes	doc_617668397768_item	2771934	et	4	main
eestlaste	doc_617668397768_item	2771943	et	4	main
ikkagi	doc_617668397768_item	2771947	et	4	main
suurt	doc_617668397768_item	2771948	et	3	main
võitu	doc_617668397768_item	2771949	et	4	main
neil	doc_617668397768_item	2771955	et	4	main
pole	doc_617668397768_item	2771983	et	3	main
näiteks	doc_617668397768_item	2771984	et	4	main
madisepäeva	doc_617668397768_item	2771985	et	4	main
saada	doc_617668397768_item	2771996	et	4	main
palju	doc_617668397768_item	2772003	et	4	main
vabadusvõitlusest	doc_617668397767_item	2771524	et	4	main
tegevus	doc_617668397767_item	2771526	et	4	main
toimub	doc_617668397767_item	2771527	et	3	main
saksa	doc_617668397767_item	2771534	et	4	main
filmis	doc_617668397767_item	2771543	et	4	main
ainult	doc_617668397767_item	2771546	et	4	main
konnavarude	doc_617668397767_item	2771548	et	3	main
noormees	doc_617668397767_item	2771554	et	4	main
uru	doc_617668397767_item	2771555	et	3	main
ott	doc_617668397767_item	2771556	et	3	main
sepp	doc_617668397767_item	2771557	et	3	main
kes	doc_617668397767_item	2771558	et	4	main
noore	doc_617668397767_item	2771559	et	3	main
poisina	doc_617668397767_item	2771560	et	3	main
röövretke	doc_617668397767_item	2771564	et	4	main
kloostrisse	doc_617668397767_item	2771572	et	3	main
harimisele	doc_617668397767_item	2771573	et	4	main
saadetakse	doc_617668397767_item	2771574	et	3	main
haritud	doc_617668397767_item	2771575	et	4	main
mehena	doc_617668397767_item	2771576	et	3	main
ning	doc_617668397767_item	2771577	et	3	main
templiordu	doc_617668397767_item	2771578	et	4	main
õhutusel	doc_617668397767_item	2771579	et	4	main
naaseb	doc_617668397767_item	2771580	et	3	main
uru	doc_617668397767_item	2771581	et	3	main
kodumaale	doc_617668397767_item	2771582	et	4	main
et	doc_617668397767_item	2771583	et	3	main
siinset	doc_617668397767_item	2771584	et	3	main
rahvast	doc_617668397767_item	2771585	et	4	main
sakslaste	doc_617668397767_item	2771586	et	3	main
eest	doc_617668397767_item	2771587	et	4	main
hoiatada	doc_617668397767_item	2771588	et	3	main
filmi	doc_617668397767_item	2771641	et	4	main
kasuks	doc_617668397767_item	2771647	et	4	main
eesti	doc_617668397767_item	2771652	et	4	main
ajaloost	doc_617668397767_item	2771654	et	4	main
vastasel	doc_617668397767_item	2771655	et	3	main
juhul	doc_617668397767_item	2771656	et	3	main
jääb	doc_617668397767_item	2771657	et	3	main
filmi	doc_617668397767_item	2771662	et	4	main
vaadates	doc_617668397767_item	2771663	et	3	main
eestlasi	doc_617668397767_item	2771667	et	3	main
kujutatakse	doc_617668397767_item	2771673	et	3	main
ole	doc_617668397767_item	2771679	et	4	main
oma	doc_617668397767_item	2771680	et	4	main
tõetera	doc_617668397767_item	2771681	et	4	main
sees	doc_617668397767_item	2771682	et	4	main
tegelaste	doc_617668397767_item	2771683	et	3	main
üle	doc_617668397767_item	2771684	et	3	main
naerdes	doc_617668397767_item	2771685	et	3	main
naerame	doc_617668397767_item	2771686	et	3	main
endi	doc_617668397767_item	2771687	et	4	main
üle	doc_617668397767_item	2771688	et	3	main
sest	doc_617668397767_item	2771689	et	4	main
ka	doc_617668397767_item	2771690	et	3	main
meie	doc_617668397767_item	2771691	et	4	main
tänapäeva	doc_617668397767_item	2771692	et	4	main
eestlased	doc_617668397767_item	2771693	et	3	main
oleme	doc_617668397767_item	2771694	et	3	main
vähemal	doc_617668397767_item	2771695	et	4	main
või	doc_617668397767_item	2771696	et	4	main
rohkemal	doc_617668397767_item	2771697	et	4	main
määral	doc_617668397767_item	2771698	et	3	main
samade	doc_617668397767_item	2771699	et	3	main
tunnusjoontega	doc_617668397767_item	2771700	et	3	main
meie	doc_617668397767_item	2771701	et	4	main
seas	doc_617668397767_item	2771702	et	4	main
leidub	doc_617668397767_item	2771703	et	3	main
nii	doc_617668397767_item	2771704	et	3	main
ainult	doc_617668397767_item	2771705	et	4	main
hööveldamisest	doc_617668397767_item	2771706	et	4	main
ja	doc_617668397767_item	2771707	et	3	main
suudeta	doc_617668397767_item	2771622	et	4	main
poolest	doc_617668397767_item	2771624	et	4	main
kuidagi	doc_617668397767_item	2771625	et	3	main
kokkuleppele	doc_617668397767_item	2771626	et	3	main
jõuda	doc_617668397767_item	2771627	et	3	main
kohaselt	doc_617668397767_item	2771633	et	4	main
on	doc_617668397767_item	2771634	et	4	main
ainukeseks	doc_617668397767_item	2771636	et	4	main
lootuseks	doc_617668397767_item	2771637	et	4	main
ühismalev	doc_617668397767_item	2771640	et	3	main
on	doc_617668397767_item	2771642	et	4	main
kerge	doc_617668397767_item	2771643	et	4	main
ning	doc_617668397767_item	2771644	et	3	main
sealgi	doc_617668397767_item	2771678	et	4	main
lembituid	doc_617668397767_item	2771712	et	4	main
rõõmsameelseid	doc_617668397767_item	2771714	et	3	main
manivaldesid	doc_617668397767_item	2771719	et	4	main
filmis	doc_617668397767_item	2771720	et	4	main
eestlaste	doc_617668397767_item	2771639	et	4	main
ehk	doc_617668397767_item	2771649	et	3	main
teadmised	doc_617668397767_item	2771651	et	4	main
varasest	doc_617668397767_item	2771653	et	4	main
me	doc_617668397767_item	2771665	et	4	main
töö-	doc_617668397767_item	2771668	et	4	main
ja	doc_617668397767_item	2771669	et	3	main
laulurahvast	doc_617668397767_item	2771670	et	4	main
esimese	doc_617668397767_item	2771708	et	3	main
öö	doc_617668397767_item	2771709	et	4	main
õigusest	doc_617668397767_item	2771710	et	4	main
alati	doc_617668397767_item	2771713	et	4	main
ja	doc_617668397767_item	2771715	et	3	main
anti	doc_617668397767_item	2771721	et	3	main
sõna-sõnalt	doc_617668397767_item	2771743	et	3	main
ei	doc_617668397767_item	2771745	et	4	main
faktidele	doc_617668397767_item	2771748	et	3	main
esitatud	doc_617668397767_item	2771756	et	4	main
nägemus	doc_617668397767_item	2771758	et	3	main
et	doc_617668397767_item	2771767	et	3	main
kindlat	doc_617668397767_item	2771768	et	3	main
võime	doc_617668397767_item	2771777	et	4	main
eesti	doc_617668397768_item	2771822	et	4	main
ristida	doc_617668397768_item	2771826	et	4	main
toimus	doc_617668397768_item	2771829	et	3	main
13sajandi	doc_617668397768_item	2771830	et	3	main
alguses	doc_617668397768_item	2771831	et	4	main
eestis	doc_617668397768_item	2771832	et	3	main
ja	doc_617668397768_item	2771833	et	3	main
eesti	doc_617668397768_item	2771839	et	4	main
kloostrisse	doc_617668397768_item	2771849	et	3	main
esimene	doc_617668397768_item	2771853	et	3	main
eurooplane	doc_617668397768_item	2771855	et	3	main
tahavad	doc_617668397768_item	2771857	et	3	main
ise	doc_617668397768_item	2771867	et	4	main
tulevik	doc_617668397768_item	2771877	et	3	main
ta	doc_617668397768_item	2771878	et	4	main
see	doc_617668397768_item	2771890	et	3	main
sest	doc_617668397768_item	2771892	et	4	main
jaoks	doc_617668397768_item	2771894	et	4	main
lahingus	doc_617668397768_item	2771906	et	3	main
kajastub	doc_617668397768_item	2771910	et	3	main
lahingut	doc_617668397768_item	2771916	et	3	main
huvituvaid	doc_617668397767_item	2771711	et	4	main
ka	doc_617668397767_item	2771724	et	3	main
veidike	doc_617668397767_item	2771734	et	4	main
ei	doc_617668397767_item	2771739	et	4	main
kõike	doc_617668397767_item	2771742	et	4	main
on	doc_617668397767_item	2771755	et	4	main
tegelikult	doc_617668397767_item	2771764	et	4	main
just	doc_617668397767_item	2771765	et	3	main
juhtunust	doc_617668397767_item	2771772	et	4	main
ei	doc_617668397767_item	2771774	et	4	main
tea	doc_617668397767_item	2771775	et	4	main
niisiis	doc_617668397767_item	2771780	et	3	main
kuidas	doc_617668397768_item	2771816	et	3	main
ja	doc_617668397768_item	2771825	et	3	main
liivimaal	doc_617668397768_item	2771834	et	4	main
ning	doc_617668397768_item	2771835	et	3	main
kelle	doc_617668397768_item	2771842	et	4	main
temast	doc_617668397768_item	2771851	et	3	main
tehakse	doc_617668397768_item	2771852	et	3	main
eestlasest	doc_617668397768_item	2771854	et	3	main
muidugi	doc_617668397768_item	2771858	et	4	main
kavalusega	doc_617668397768_item	2771859	et	4	main
eestlaste	doc_617668397768_item	2771864	et	4	main
ihkavad	doc_617668397768_item	2771868	et	4	main
eesti	doc_617668397768_item	2771869	et	4	main
konnavarusid	doc_617668397768_item	2771870	et	3	main
üritab	doc_617668397768_item	2771879	et	3	main
eestlasi	doc_617668397768_item	2771880	et	3	main
euroopalikult	doc_617668397768_item	2771881	et	4	main
lahingus	doc_617668397768_item	2771885	et	3	main
tal	doc_617668397768_item	2771889	et	3	main
peale	doc_617668397768_item	2771897	et	4	main
oluline	doc_617668397768_item	2771904	et	4	main
esimeses	doc_617668397768_item	2771905	et	3	main
lembitu	doc_617668397768_item	2771908	et	4	main
tegelikus	doc_617668397768_item	2771912	et	4	main
esimest	doc_617668397768_item	2771915	et	4	main
musta	doc_617668397768_item	2771932	et	4	main
rüütliga	doc_617668397768_item	2771933	et	3	main
vanemad	doc_617668397768_item	2771938	et	4	main
ning	doc_617668397768_item	2771939	et	3	main
ta	doc_617668397768_item	2771940	et	4	main
sureb	doc_617668397768_item	2771941	et	3	main
huvitavam	doc_617668397768_item	2771953	et	4	main
naljade	doc_617668397768_item	2771978	et	3	main
need	doc_617668397768_item	2771981	et	3	main
kuulnud	doc_617668397768_item	2771988	et	4	main
aru	doc_617668397768_item	2771995	et	4	main
öelda	doc_617668397768_item	2772000	et	4	main
võin	doc_617668397768_item	2772008	et	3	main
silmis	doc_617668397768_item	2772014	et	4	main
ja	doc_617668397768_item	2772015	et	3	main
paljud	doc_617668397768_item	2772017	et	3	main
filmi	doc_617668397768_item	2772019	et	4	main
mõistavad	doc_617668397768_item	2772022	et	3	main
kindlasti	doc_617668397768_item	2772024	et	3	main
ju	doc_617668397768_item	2772029	et	3	main
täpselt	doc_617668397768_item	2772032	et	4	main
kuidas	doc_617668397768_item	2772033	et	3	main
madisepäeva	doc_617668397768_item	2772034	et	4	main
lahing	doc_617668397768_item	2772035	et	3	main
päriselt	doc_617668397768_item	2772036	et	3	main
toimus	doc_617668397768_item	2772037	et	3	main
ja	doc_617668397768_item	2772038	et	3	main
mis	doc_617668397768_item	2772039	et	4	main
filmis	doc_617668397768_item	2772046	et	4	main
saab	doc_617668397768_item	2772047	et	3	main
poliitika	doc_617668397768_item	2772053	et	4	main
olukordade	doc_617668397768_item	2772058	et	3	main
küljest	doc_617668397768_item	2772066	et	4	main
määral	doc_617668397768_item	2772068	et	3	main
osanud	doc_617668397768_item	2772080	et	4	main
ei	doc_617668397768_item	2772082	et	4	main
olnud	doc_617668397768_item	2772083	et	4	main
neil	doc_617668397768_item	2772086	et	4	main
tänu	doc_617668397768_item	2772122	et	4	main
kogemusi	doc_617668397768_item	2772130	et	3	main
kuid	doc_617668397768_item	2772132	et	4	main
alles	doc_617668397768_item	2772133	et	3	main
pärast	doc_617668397768_item	2772134	et	4	main
esimeses	doc_617668397768_item	2772135	et	3	main
kui	doc_617668397767_item	2771723	et	3	main
tööd	doc_617668397767_item	2771726	et	4	main
uku	doc_617668397767_item	2771730	et	4	main
tuleb	doc_617668397767_item	2771732	et	3	main
tasu	doc_617668397767_item	2771740	et	4	main
võtta	doc_617668397767_item	2771741	et	3	main
tegu	doc_617668397767_item	2771744	et	4	main
ole	doc_617668397767_item	2771746	et	4	main
toetuva	doc_617668397767_item	2771749	et	4	main
võis	doc_617668397767_item	2771762	et	4	main
juhtuda	doc_617668397767_item	2771763	et	3	main
me	doc_617668397767_item	2771776	et	4	main
109	doc_617668397767_item	2771784	et	2	main
minutit	doc_617668397767_item	2771785	et	3	main
vaba	doc_617668397767_item	2771786	et	4	main
aega	doc_617668397767_item	2771787	et	4	main
huumorimeelt	doc_617668397767_item	2771788	et	4	main
veidike	doc_617668397767_item	2771789	et	4	main
teadmisi	doc_617668397767_item	2771790	et	4	main
eesti	doc_617668397767_item	2771791	et	4	main
ajaloost	doc_617668397767_item	2771792	et	4	main
ja	doc_617668397767_item	2771793	et	3	main
olete	doc_617668397767_item	2771794	et	3	main
avatud	doc_617668397767_item	2771795	et	4	main
uutele	doc_617668397767_item	2771796	et	3	main
vaatenurkadele	doc_617668397767_item	2771797	et	3	main
siis	doc_617668397767_item	2771798	et	3	main
on	doc_617668397767_item	2771799	et	4	main
teile	doc_617668397767_item	2771800	et	4	main
filmielamus	doc_617668397767_item	2771801	et	4	main
garanteeritud	doc_617668397767_item	2771802	et	4	main
essee	doc_617668397768_item	2771803	et	4	main
eesti	doc_617668397768_item	2771804	et	4	main
filmi	doc_617668397768_item	2771805	et	4	main
malev	doc_617668397768_item	2771806	et	3	main
võib	doc_617668397768_item	2771807	et	3	main
minu	doc_617668397768_item	2771808	et	3	main
arvates	doc_617668397768_item	2771809	et	4	main
nimetada	doc_617668397768_item	2771810	et	3	main
ajalooliseks	doc_617668397768_item	2771811	et	4	main
komöödiaks	doc_617668397768_item	2771812	et	4	main
film	doc_617668397768_item	2771813	et	3	main
räägib	doc_617668397768_item	2771814	et	3	main
sellest	doc_617668397768_item	2771815	et	4	main
saksa	doc_617668397768_item	2771817	et	4	main
allutada	doc_617668397768_item	2771824	et	3	main
filmi	doc_617668397768_item	2771827	et	4	main
tegevus	doc_617668397768_item	2771828	et	4	main
peategelaseks	doc_617668397768_item	2771837	et	3	main
poiss	doc_617668397768_item	2771840	et	3	main
vanemad	doc_617668397768_item	2771843	et	4	main
tapsid	doc_617668397768_item	2771844	et	4	main
sakslased	doc_617668397768_item	2771845	et	3	main
uru	doc_617668397768_item	2771846	et	3	main
viiakse	doc_617668397768_item	2771847	et	3	main
vabadusest	doc_617668397768_item	2771865	et	4	main
eestimaa	doc_617668397768_item	2771874	et	4	main
ja	doc_617668397768_item	2771883	et	3	main
ebaõnnestub	doc_617668397768_item	2771891	et	3	main
laulmise	doc_617668397768_item	2771898	et	4	main
tantsimise	doc_617668397768_item	2771899	et	4	main
ja	doc_617668397768_item	2771900	et	3	main
töörabamise	doc_617668397768_item	2771901	et	3	main
mis	doc_617668397768_item	2771909	et	4	main
ka	doc_617668397768_item	2771911	et	3	main
ajaloos	doc_617668397768_item	2771913	et	4	main
pärast	doc_617668397768_item	2771914	et	4	main
on	doc_617668397768_item	2771917	et	4	main
eestlased	doc_617668397768_item	2771918	et	3	main
juba	doc_617668397768_item	2771919	et	3	main
suure	doc_617668397768_item	2771920	et	3	main
targemad	doc_617668397768_item	2771925	et	4	main
isiklikult	doc_617668397768_item	2771935	et	4	main
tappis	doc_617668397768_item	2771936	et	4	main
kuid	doc_617668397768_item	2771942	et	4	main
see	doc_617668397768_item	2771946	et	3	main
vaadata	doc_617668397768_item	2771954	et	4	main
teiste	doc_617668397768_item	2771977	et	4	main
üle	doc_617668397768_item	2771979	et	3	main
kes	doc_617668397768_item	2771982	et	4	main
kindlasti	doc_617668397768_item	2771989	et	3	main
oleks	doc_617668397768_item	2771990	et	3	main
eesti	doc_617668397768_item	2771991	et	4	main
rahvusest	doc_617668397768_item	2771992	et	4	main
inimestel	doc_617668397768_item	2771993	et	3	main
selle	doc_617668397768_item	2771998	et	4	main
kuna	doc_617668397768_item	2772002	et	3	main
samas	doc_617668397768_item	2772007	et	4	main
ilu	doc_617668397768_item	2772011	et	4	main
on	doc_617668397768_item	2772012	et	4	main
naerda	doc_617668397768_item	2772048	et	4	main
ja	doc_617668397768_item	2772056	et	3	main
näitab	doc_617668397768_item	2772061	et	3	main
humoorikast	doc_617668397768_item	2772065	et	3	main
film	doc_617668397768_item	2772071	et	3	main
on	doc_617668397768_item	2772076	et	4	main
nad	doc_617668397768_item	2772078	et	3	main
ei	doc_617668397768_item	2772079	et	4	main
valmis	doc_617668397768_item	2772084	et	4	main
tapma	doc_617668397768_item	2772085	et	3	main
juurde	doc_617668397768_item	2772131	et	4	main
arvates	doc_617668397768_item	2772146	et	4	main
soovi	doc_617668397768_item	2772152	et	4	main
jääks	doc_617668397768_item	2772154	et	4	main
poole	doc_617668397768_item	2772155	et	4	main
pealt	doc_617668397768_item	2772156	et	4	main
olen	doc_634572338199_item	2772171	et	3	main
eesnimi	doc_634572338199_item	2772172	et	3	main
narva	doc_634572338199_item	2772175	et	4	main
kooli	doc_634572338199_item	2772176	et	4	main
mehaanika	doc_634572338199_item	2772188	et	4	main
meie	doc_634572338199_item	2772195	et	4	main
ei	doc_634572338199_item	2772213	et	4	main
veel	doc_634572338199_item	2772220	et	4	main
üritavad	doc_617668397768_item	2771821	et	4	main
selle	doc_617668397768_item	2771836	et	4	main
uru	doc_617668397768_item	2771841	et	3	main
kus	doc_617668397768_item	2771850	et	3	main
prantslased	doc_617668397768_item	2771856	et	3	main
oma	doc_617668397768_item	2771860	et	4	main
eesmärki	doc_617668397768_item	2771861	et	4	main
saavutada	doc_617668397768_item	2771862	et	3	main
nüüd	doc_617668397768_item	2771871	et	4	main
sõltub	doc_617668397768_item	2771872	et	3	main
urust	doc_617668397768_item	2771873	et	3	main
meelestada	doc_617668397768_item	2771882	et	3	main
võistlema	doc_617668397768_item	2771887	et	3	main
eestlaste	doc_617668397768_item	2771893	et	4	main
ei	doc_617668397768_item	2771895	et	4	main
miski	doc_617668397768_item	2771902	et	4	main
langebki	doc_617668397768_item	2771907	et	3	main
tõttu	doc_617668397768_item	2771924	et	4	main
ning	doc_617668397768_item	2771926	et	3	main
valmistuvad	doc_617668397768_item	2771927	et	4	main
teiseks	doc_617668397768_item	2771928	et	4	main
katsumuseks	doc_617668397768_item	2771929	et	3	main
uru	doc_617668397768_item	2771930	et	3	main
võitleb	doc_617668397768_item	2771931	et	3	main
tema	doc_617668397768_item	2771937	et	4	main
jaoks	doc_617668397768_item	2771944	et	4	main
tähendab	doc_617668397768_item	2771945	et	3	main
filmi	doc_617668397768_item	2771950	et	4	main
kes	doc_617668397768_item	2771956	et	4	main
kui	doc_617668397768_item	2771980	et	3	main
midagi	doc_617668397768_item	2771987	et	4	main
filmiga	doc_617668397768_item	2771999	et	3	main
et	doc_617668397768_item	2772010	et	3	main
väga	doc_617668397768_item	2772016	et	3	main
inimesed	doc_617668397768_item	2772021	et	3	main
selle	doc_617668397768_item	2772023	et	4	main
hukka	doc_617668397768_item	2772025	et	4	main
tegelikult	doc_617668397768_item	2772026	et	4	main
ei	doc_617668397768_item	2772027	et	4	main
selles	doc_617668397768_item	2772045	et	4	main
üle	doc_617668397768_item	2772059	et	3	main
euroopa	doc_617668397768_item	2772063	et	4	main
mingil	doc_617668397768_item	2772067	et	4	main
ei	doc_617668397768_item	2772087	et	4	main
olnud	doc_617668397768_item	2772088	et	4	main
valusa	doc_617668397768_item	2771922	et	3	main
on	doc_617668397768_item	2771951	et	4	main
kindlasti	doc_617668397768_item	2771952	et	3	main
mingil	doc_617668397768_item	2771957	et	4	main
määral	doc_617668397768_item	2771958	et	3	main
tunnevad	doc_617668397768_item	2771959	et	3	main
eesti	doc_617668397768_item	2771960	et	4	main
ajalugu	doc_617668397768_item	2771961	et	4	main
ja	doc_617668397768_item	2771962	et	3	main
teavad	doc_617668397768_item	2771963	et	3	main
13sajandil	doc_617668397768_item	2771964	et	3	main
toimunut	doc_617668397768_item	2771965	et	4	main
need	doc_617668397768_item	2771966	et	3	main
inimesed	doc_617668397768_item	2771967	et	3	main
näevad	doc_617668397768_item	2771968	et	3	main
filmi	doc_617668397768_item	2771970	et	4	main
sündmusi	doc_617668397768_item	2771971	et	3	main
selle	doc_617668397768_item	2771969	et	4	main
hoopis	doc_617668397768_item	2771972	et	3	main
teise	doc_617668397768_item	2771973	et	4	main
pilguga	doc_617668397768_item	2771974	et	3	main
naeravad	doc_617668397768_item	2771975	et	3	main
hoopis	doc_617668397768_item	2771976	et	3	main
lahingust	doc_617668397768_item	2771986	et	4	main
lihtsam	doc_617668397768_item	2771994	et	4	main
mida	doc_617668397768_item	2771997	et	4	main
taheti	doc_617668397768_item	2772001	et	3	main
on	doc_617668397768_item	2772004	et	4	main
eestipäraseid	doc_617668397768_item	2772005	et	4	main
seda	doc_617668397768_item	2772018	et	3	main
nalju	doc_617668397768_item	2772006	et	3	main
öelda	doc_617668397768_item	2772009	et	4	main
vaataja	doc_617668397768_item	2772013	et	4	main
näinud	doc_617668397768_item	2772020	et	4	main
tea	doc_617668397768_item	2772028	et	4	main
keegi	doc_617668397768_item	2772031	et	4	main
tänapäeva	doc_617668397768_item	2772049	et	4	main
erinevate	doc_617668397768_item	2772054	et	4	main
film	doc_617668397768_item	2772060	et	3	main
poliitikas	doc_617668397768_item	2772064	et	3	main
see	doc_617668397768_item	2772070	et	3	main
kui	doc_617668397768_item	2772073	et	3	main
sõdida	doc_617668397768_item	2772081	et	3	main
samas	doc_617668397768_item	2772092	et	4	main
palju	doc_617668397768_item	2772128	et	4	main
suuri	doc_617668397768_item	2772129	et	3	main
meeste	doc_617668397768_item	2772140	et	4	main
lihtne	doc_617668397768_item	2772147	et	3	main
ei	doc_617668397768_item	2772149	et	4	main
selles	doc_634572338199_item	2772177	et	4	main
õpisin	doc_634572338199_item	2772180	et	4	main
teaduskonda	doc_634572338199_item	2772189	et	4	main
on	doc_634572338199_item	2772203	et	4	main
väga	doc_634572338199_item	2772204	et	3	main
teil	doc_634572338199_item	2772212	et	4	main
töökohta	doc_634572338199_item	2772219	et	4	main
ma	doc_634572338199_item	2772221	et	3	main
et	doc_634572338199_item	2772223	et	3	main
eesti	doc_634572338199_item	2772224	et	4	main
oskus	doc_634572338199_item	2772226	et	3	main
eesti	doc_634572338199_item	2772230	et	4	main
tahab	doc_634572338199_item	2772249	et	3	main
ma	doc_634572338199_item	2772256	et	3	main
aga	doc_634572338199_item	2772270	et	3	main
vanemust	doc_634572338199_item	2772273	et	4	main
inimesele	doc_634572338199_item	2772278	et	3	main
palju	doc_634572338199_item	2772279	et	4	main
inimesel	doc_634572338199_item	2772282	et	3	main
on	doc_634572338199_item	2772283	et	4	main
elus	doc_634572338199_item	2772288	et	4	main
tuleb	doc_634572338199_item	2772290	et	3	main
selgeks	doc_634572338199_item	2772292	et	3	main
päevast	doc_634572338199_item	2772306	et	4	main
ei	doc_634572338199_item	2772309	et	4	main
ole	doc_634572338199_item	2772310	et	4	main
elad	doc_634572338199_item	2772322	et	3	main
elu	doc_634572338199_item	2772324	et	4	main
vaja	doc_634572338199_item	2772326	et	4	main
olla	doc_634572338199_item	2772327	et	3	main
elus	doc_634572338199_item	2772334	et	4	main
sa	doc_634572338199_item	2772335	et	3	main
sobiv	doc_634572338199_item	2772348	et	4	main
võimalusi	doc_634572338199_item	2772357	et	3	main
jaoks	doc_634572338199_item	2772359	et	4	main
iga	doc_634572338199_item	2772372	et	4	main
leida	doc_634572338199_item	2772375	et	3	main
oma	doc_634572338199_item	2772378	et	4	main
miks	doc_634572338199_item	2772380	et	4	main
valisin	doc_634572338199_item	2772382	et	3	main
hingele	doc_634572338199_item	2772397	et	4	main
ei	doc_634572338199_item	2772401	et	4	main
aga	doc_634572338199_item	2772404	et	3	main
õppima	doc_634572338199_item	2772408	et	3	main
rohkem	doc_634572338199_item	2772410	et	4	main
x	doc_634572338200_item	2772428	et	4	main
ma	doc_634572338200_item	2772434	et	3	main
seda	doc_634572338200_item	2772436	et	3	main
üksendal	doc_634572338200_item	2772439	et	4	main
ma	doc_634572338200_item	2772447	et	3	main
sellest	doc_634572338200_item	2772451	et	4	main
eesti	doc_634572338200_item	2772470	et	4	main
kuna	doc_634572338200_item	2772474	et	3	main
vene	doc_634572338200_item	2772484	et	4	main
gruppi	doc_634572338200_item	2772485	et	4	main
ärindust	doc_634572338200_item	2772486	et	3	main
ülikoolis	doc_634572338200_item	2772530	et	4	main
ei	doc_634572338200_item	2772535	et	4	main
ole	doc_634572338200_item	2772536	et	4	main
igapäevast	doc_634572338200_item	2772537	et	4	main
tudeng	doc_634572338200_item	2772543	et	3	main
oska	doc_634572338200_item	2772551	et	4	main
kus	doc_634572338200_item	2772553	et	3	main
mitte	doc_617668397768_item	2772030	et	3	main
seal	doc_617668397768_item	2772040	et	4	main
täpselt	doc_617668397768_item	2772041	et	4	main
juhtus	doc_617668397768_item	2772042	et	3	main
minu	doc_617668397768_item	2772043	et	3	main
arvates	doc_617668397768_item	2772044	et	4	main
eesti	doc_617668397768_item	2772050	et	4	main
ja	doc_617668397768_item	2772051	et	3	main
euroopa	doc_617668397768_item	2772052	et	4	main
inimtüüpide	doc_617668397768_item	2772055	et	3	main
igapäevaste	doc_617668397768_item	2772057	et	4	main
eestlasi	doc_617668397768_item	2772062	et	3	main
tahab	doc_617668397768_item	2772069	et	3	main
näidata	doc_617668397768_item	2772072	et	4	main
saamatud	doc_617668397768_item	2772074	et	4	main
eestlased	doc_617668397768_item	2772075	et	3	main
et	doc_617668397768_item	2772077	et	3	main
sõdimiseks	doc_617668397768_item	2772089	et	4	main
vajalikke	doc_617668397768_item	2772090	et	3	main
tapariistu	doc_617668397768_item	2772091	et	3	main
kui	doc_617668397768_item	2772093	et	3	main
sakslased	doc_617668397768_item	2772094	et	3	main
olid	doc_617668397768_item	2772095	et	4	main
kujutatud	doc_617668397768_item	2772096	et	4	main
väga	doc_617668397768_item	2772097	et	3	main
võimsate	doc_617668397768_item	2772098	et	3	main
ja	doc_617668397768_item	2772099	et	3	main
vägevatena	doc_617668397768_item	2772100	et	3	main
kasvõi	doc_617668397768_item	2772101	et	3	main
selle	doc_617668397768_item	2772102	et	4	main
poolest	doc_617668397768_item	2772103	et	4	main
et	doc_617668397768_item	2772104	et	3	main
neil	doc_617668397768_item	2772105	et	4	main
olid	doc_617668397768_item	2772106	et	4	main
olemas	doc_617668397768_item	2772107	et	4	main
sõjahobused	doc_617668397768_item	2772108	et	4	main
eestlased	doc_617668397768_item	2772109	et	3	main
aga	doc_617668397768_item	2772110	et	3	main
arvasid	doc_617668397768_item	2772111	et	4	main
et	doc_617668397768_item	2772112	et	3	main
lauldes	doc_617668397768_item	2772113	et	3	main
saab	doc_617668397768_item	2772114	et	3	main
igast	doc_617668397768_item	2772115	et	3	main
murest	doc_617668397768_item	2772116	et	4	main
lahti	doc_617668397768_item	2772117	et	4	main
filmi	doc_617668397768_item	2772118	et	4	main
said	doc_617668397768_item	2772120	et	4	main
lõpus	doc_617668397768_item	2772119	et	4	main
eestlased	doc_617668397768_item	2772121	et	3	main
euroopalikele	doc_617668397768_item	2772123	et	3	main
õpetustele	doc_617668397768_item	2772124	et	4	main
ikkagi	doc_617668397768_item	2772125	et	4	main
targemaks	doc_617668397768_item	2772126	et	4	main
kaotamist	doc_617668397768_item	2772141	et	4	main
seda	doc_617668397768_item	2772142	et	3	main
filmi	doc_617668397768_item	2772143	et	4	main
oli	doc_617668397768_item	2772144	et	3	main
magama	doc_617668397768_item	2772157	et	3	main
kuna	doc_617668397768_item	2772158	et	3	main
uudishimu	doc_617668397768_item	2772159	et	4	main
oli	doc_617668397768_item	2772160	et	3	main
suur	doc_617668397768_item	2772161	et	3	main
mis	doc_617668397768_item	2772162	et	4	main
edasi	doc_617668397768_item	2772163	et	3	main
toimuma	doc_617668397768_item	2772164	et	3	main
hakkab	doc_617668397768_item	2772165	et	3	main
essee	doc_634572338199_item	2772166	et	4	main
mina	doc_634572338199_item	2772167	et	4	main
ja	doc_634572338199_item	2772168	et	3	main
ülikool	doc_634572338199_item	2772169	et	4	main
mina	doc_634572338199_item	2772170	et	4	main
ja	doc_617668397768_item	2772127	et	3	main
lahingus	doc_617668397768_item	2772136	et	3	main
lüüasaamist	doc_617668397768_item	2772137	et	4	main
ja	doc_617668397768_item	2772138	et	3	main
paljude	doc_617668397768_item	2772139	et	3	main
minu	doc_617668397768_item	2772145	et	3	main
vaadata	doc_617668397768_item	2772148	et	4	main
tekkinud	doc_617668397768_item	2772150	et	4	main
sellist	doc_617668397768_item	2772151	et	4	main
ma	doc_634572338199_item	2772173	et	3	main
koolis	doc_634572338199_item	2772178	et	4	main
12	doc_634572338199_item	2772181	et	2	main
aastat	doc_634572338199_item	2772182	et	3	main
nüüd	doc_634572338199_item	2772183	et	4	main
ma	doc_634572338199_item	2772184	et	3	main
astusin	doc_634572338199_item	2772185	et	3	main
tulevikus	doc_634572338199_item	2772190	et	4	main
ma	doc_634572338199_item	2772191	et	3	main
tahan	doc_634572338199_item	2772192	et	3	main
saada	doc_634572338199_item	2772193	et	4	main
mehaanikainseneriks	doc_634572338199_item	2772194	et	3	main
on	doc_634572338199_item	2772197	et	4	main
tähtis	doc_634572338199_item	2772199	et	4	main
ei	doc_634572338199_item	2772209	et	4	main
ole	doc_634572338199_item	2772210	et	4	main
kõrgharidus	doc_634572338199_item	2772211	et	3	main
oma	doc_634572338199_item	2772218	et	4	main
arvan	doc_634572338199_item	2772222	et	3	main
on	doc_634572338199_item	2772232	et	4	main
riigikeel	doc_634572338199_item	2772233	et	4	main
näiteks	doc_634572338199_item	2772243	et	4	main
inimene	doc_634572338199_item	2772244	et	3	main
võib	doc_634572338199_item	2772245	et	3	main
töötada	doc_634572338199_item	2772246	et	3	main
kus	doc_634572338199_item	2772247	et	3	main
ta	doc_634572338199_item	2772248	et	4	main
ma	doc_634572338199_item	2772253	et	3	main
et	doc_634572338199_item	2772255	et	3	main
saan	doc_634572338199_item	2772263	et	4	main
tagastada	doc_634572338199_item	2772264	et	3	main
stabiilse	doc_634572338199_item	2772265	et	3	main
perele	doc_634572338199_item	2772269	et	3	main
vaesusemata	doc_634572338199_item	2772272	et	3	main
uusi	doc_634572338199_item	2772280	et	3	main
on	doc_634572338199_item	2772299	et	4	main
esimesest	doc_634572338199_item	2772305	et	3	main
ülikoolis	doc_634572338199_item	2772307	et	4	main
oma	doc_634572338199_item	2772323	et	4	main
on	doc_634572338199_item	2772325	et	4	main
indale	doc_634572338199_item	2772339	et	4	main
on	doc_634572338199_item	2772344	et	4	main
see	doc_634572338199_item	2772345	et	3	main
on	doc_634572338199_item	2772346	et	4	main
väga	doc_634572338199_item	2772347	et	3	main
rohkem	doc_634572338199_item	2772356	et	4	main
et	doc_634572338199_item	2772371	et	3	main
inimene	doc_634572338199_item	2772373	et	3	main
midagi	doc_634572338199_item	2772377	et	4	main
huvist	doc_634572338199_item	2772379	et	3	main
ma	doc_634572338199_item	2772381	et	3	main
kui	doc_634572338199_item	2772386	et	3	main
astuda	doc_634572338199_item	2772391	et	3	main
sest	doc_634572338199_item	2772393	et	4	main
see	doc_634572338199_item	2772394	et	3	main
on	doc_634572338199_item	2772395	et	4	main
minule	doc_634572338199_item	2772396	et	3	main
ma	doc_634572338199_item	2772400	et	3	main
sest	doc_634572338199_item	2772409	et	4	main
ei	doc_634572338199_item	2772412	et	4	main
essee	doc_634572338200_item	2772421	et	4	main
ja	doc_634572338200_item	2772423	et	3	main
ülikool	doc_634572338200_item	2772424	et	4	main
minu	doc_634572338200_item	2772425	et	3	main
nimi	doc_634572338200_item	2772426	et	3	main
valisin	doc_634572338200_item	2772435	et	3	main
huvi	doc_634572338200_item	2772444	et	4	main
sellepärast	doc_634572338200_item	2772445	et	3	main
olen	doc_634572338200_item	2772448	et	3	main
minu	doc_634572338200_item	2772453	et	3	main
ema	doc_634572338200_item	2772454	et	4	main
raamatupidaja	doc_634572338200_item	2772456	et	4	main
ja	doc_634572338200_item	2772457	et	3	main
et	doc_617668397768_item	2772153	et	3	main
ma	doc_634572338199_item	2772179	et	3	main
tallinna	doc_634572338199_item	2772186	et	4	main
elus	doc_634572338199_item	2772196	et	4	main
väga	doc_634572338199_item	2772198	et	3	main
kõrgharidus	doc_634572338199_item	2772200	et	3	main
sest	doc_634572338199_item	2772201	et	4	main
see	doc_634572338199_item	2772202	et	3	main
palju	doc_634572338199_item	2772215	et	4	main
võimalusi	doc_634572338199_item	2772216	et	3	main
valida	doc_634572338199_item	2772217	et	3	main
keele	doc_634572338199_item	2772225	et	4	main
lõpitamist	doc_634572338199_item	2772252	et	4	main
loodan	doc_634572338199_item	2772254	et	3	main
oskan	doc_634572338199_item	2772257	et	3	main
materiaalse	doc_634572338199_item	2772266	et	3	main
astumine	doc_634572338199_item	2772276	et	4	main
annab	doc_634572338199_item	2772277	et	3	main
oma	doc_634572338199_item	2772286	et	4	main
aga	doc_634572338199_item	2772289	et	3	main
endale	doc_634572338199_item	2772291	et	4	main
et	doc_634572338199_item	2772294	et	3	main
teha	doc_634572338199_item	2772337	et	3	main
sest	doc_634572338199_item	2772349	et	4	main
paljud	doc_634572338199_item	2772350	et	3	main
tudengid	doc_634572338199_item	2772351	et	3	main
käivad	doc_634572338199_item	2772352	et	4	main
tööl	doc_634572338199_item	2772353	et	3	main
see	doc_634572338199_item	2772354	et	3	main
annab	doc_634572338199_item	2772355	et	3	main
endale	doc_634572338199_item	2772376	et	4	main
ausalt	doc_634572338199_item	2772387	et	4	main
ma	doc_634572338199_item	2772389	et	3	main
parim	doc_634572338199_item	2772398	et	4	main
läbinud	doc_634572338199_item	2772402	et	4	main
mehaanikat	doc_634572338199_item	2772405	et	3	main
läksin	doc_634572338199_item	2772407	et	3	main
valikut	doc_634572338199_item	2772411	et	3	main
tallinna	doc_634572338199_item	2772419	et	4	main
ja	doc_634572338200_item	2772429	et	3	main
ma	doc_634572338200_item	2772430	et	3	main
olen	doc_634572338200_item	2772431	et	3	main
juba	doc_634572338200_item	2772438	et	3	main
klassil	doc_634572338200_item	2772440	et	3	main
kuulnud	doc_634572338200_item	2772450	et	4	main
on	doc_634572338200_item	2772455	et	4	main
õppima	doc_634572338200_item	2772466	et	3	main
eesti	doc_634572338200_item	2772480	et	4	main
keeles	doc_634572338200_item	2772481	et	4	main
pidin	doc_634572338200_item	2772482	et	3	main
minema	doc_634572338200_item	2772483	et	3	main
praegu	doc_634572338200_item	2772489	et	3	main
kahetse	doc_634572338200_item	2772492	et	4	main
sest	doc_634572338200_item	2772493	et	4	main
ülikoolis	doc_634572338200_item	2772522	et	4	main
mitte	doc_634572338200_item	2772524	et	3	main
õpid	doc_634572338200_item	2772527	et	4	main
oma	doc_634572338200_item	2772528	et	4	main
vabaaega	doc_634572338200_item	2772533	et	4	main
kodutööd	doc_634572338200_item	2772538	et	4	main
saab	doc_634572338200_item	2772544	et	3	main
ütelda	doc_634572338200_item	2772552	et	4	main
mulle	doc_634572338200_item	2772554	et	4	main
meeldib	doc_634572338200_item	2772556	et	3	main
õppida	doc_634572338200_item	2772557	et	3	main
ülikoolis	doc_634572338200_item	2772564	et	4	main
hea	doc_634572338200_item	2772569	et	4	main
koos	doc_634572338200_item	2772595	et	4	main
ja	doc_634572338200_item	2772596	et	3	main
sõpradeks	doc_634572338200_item	2772601	et	3	main
harjuma	doc_634572338200_item	2772608	et	3	main
teisega	doc_634572338200_item	2772610	et	4	main
lõpetasin	doc_634572338199_item	2772174	et	3	main
tehnikaülikooli	doc_634572338199_item	2772187	et	4	main
tähtis	doc_634572338199_item	2772205	et	4	main
tänapäeval	doc_634572338199_item	2772206	et	3	main
kui	doc_634572338199_item	2772207	et	3	main
teil	doc_634572338199_item	2772208	et	4	main
ole	doc_634572338199_item	2772214	et	4	main
keel	doc_634572338199_item	2772231	et	4	main
jaoks	doc_634572338199_item	2772242	et	4	main
ülikooli	doc_634572338199_item	2772251	et	4	main
endale	doc_634572338199_item	2772259	et	4	main
heaolu	doc_634572338199_item	2772267	et	4	main
tulevikus	doc_634572338199_item	2772271	et	4	main
ülikooli	doc_634572338199_item	2772274	et	4	main
sisse	doc_634572338199_item	2772275	et	4	main
võimalusi	doc_634572338199_item	2772281	et	3	main
plaane	doc_634572338199_item	2772287	et	3	main
teha	doc_634572338199_item	2772293	et	3	main
õppimine	doc_634572338199_item	2772295	et	4	main
ülikoolis	doc_634572338199_item	2772296	et	4	main
ja	doc_634572338199_item	2772297	et	3	main
gümnaasiumis	doc_634572338199_item	2772298	et	3	main
saama	doc_634572338199_item	2772304	et	4	main
sul	doc_634572338199_item	2772308	et	3	main
sa	doc_634572338199_item	2772321	et	3	main
saad	doc_634572338199_item	2772336	et	4	main
tunniplaani	doc_634572338199_item	2772340	et	4	main
sul	doc_634572338199_item	2772342	et	3	main
just	doc_634572338199_item	2772383	et	3	main
ametit	doc_634572338199_item	2772385	et	3	main
olnud	doc_634572338199_item	2772413	et	4	main
ma	doc_634572338199_item	2772414	et	3	main
ju	doc_634572338199_item	2772415	et	3	main
tahtsin	doc_634572338199_item	2772416	et	3	main
õppida	doc_634572338199_item	2772417	et	3	main
tehnikaülikoolis	doc_634572338199_item	2772420	et	4	main
on	doc_634572338200_item	2772427	et	4	main
tipikas	doc_634572338200_item	2772433	et	4	main
erialat	doc_634572338200_item	2772437	et	4	main
majandus	doc_634572338200_item	2772441	et	4	main
pakus	doc_634572338200_item	2772442	et	3	main
mulle	doc_634572338200_item	2772443	et	4	main
emalt	doc_634572338200_item	2772452	et	3	main
tahtsin	doc_634572338200_item	2772464	et	3	main
rahvamajandust	doc_634572338200_item	2772467	et	3	main
keele	doc_634572338200_item	2772471	et	4	main
halvasti	doc_634572338200_item	2772473	et	3	main
rahvamajandust	doc_634572338200_item	2772475	et	3	main
võimalik	doc_634572338200_item	2772477	et	3	main
ma	doc_634572338200_item	2772490	et	3	main
õppida	doc_634572338200_item	2772521	et	3	main
aga	doc_634572338200_item	2772523	et	3	main
siin	doc_634572338200_item	2772525	et	4	main
sa	doc_634572338200_item	2772526	et	3	main
on	doc_634572338200_item	2772531	et	4	main
rohkem	doc_634572338200_item	2772532	et	4	main
vähe	doc_634572338200_item	2772542	et	3	main
oma	doc_634572338200_item	2772547	et	4	main
oma	doc_634572338200_item	2772561	et	4	main
moodi	doc_634572338200_item	2772562	et	4	main
moodi	doc_634572338200_item	2772568	et	4	main
ülikoolis	doc_634572338200_item	2772580	et	4	main
on	doc_634572338200_item	2772581	et	4	main
iga	doc_634572338200_item	2772582	et	4	main
semester	doc_634572338200_item	2772583	et	3	main
uued	doc_634572338200_item	2772584	et	3	main
on	doc_634572338200_item	2772587	et	4	main
meie	doc_634572338200_item	2772590	et	4	main
klass	doc_634572338200_item	2772591	et	3	main
õpis	doc_634572338200_item	2772592	et	3	main
kaksteist	doc_634572338200_item	2772593	et	4	main
aastat	doc_634572338200_item	2772594	et	3	main
suurteks	doc_634572338200_item	2772600	et	3	main
peale	doc_634572338200_item	2772606	et	4	main
väga	doc_634572338200_item	2772623	et	3	main
ja	doc_634572338200_item	2772627	et	3	main
klassikaaslasi	doc_634572338200_item	2772628	et	3	main
tähtsam	doc_634572338200_item	2772637	et	4	main
minu	doc_634572338200_item	2772638	et	3	main
session	doc_634572338200_item	2772642	et	4	main
on	doc_634572338199_item	2772227	et	4	main
väga	doc_634572338199_item	2772228	et	3	main
käesolev	doc_634572338199_item	2772229	et	3	main
rigikeelte	doc_634572338199_item	2772234	et	4	main
oskus	doc_634572338199_item	2772235	et	3	main
ja	doc_634572338199_item	2772236	et	3	main
kõrgharidus	doc_634572338199_item	2772237	et	3	main
avaldab	doc_634572338199_item	2772238	et	3	main
palju	doc_634572338199_item	2772239	et	4	main
võimalusi	doc_634572338199_item	2772240	et	3	main
inimeste	doc_634572338199_item	2772241	et	3	main
pärast	doc_634572338199_item	2772250	et	4	main
otsida	doc_634572338199_item	2772258	et	4	main
hea	doc_634572338199_item	2772260	et	4	main
töökohta	doc_634572338199_item	2772261	et	4	main
ja	doc_634572338199_item	2772262	et	3	main
oma	doc_634572338199_item	2772268	et	4	main
kerge	doc_634572338199_item	2772284	et	4	main
realiseerida	doc_634572338199_item	2772285	et	3	main
erinev	doc_634572338199_item	2772300	et	4	main
seda	doc_634572338199_item	2772301	et	3	main
hakkad	doc_634572338199_item	2772302	et	3	main
aru	doc_634572338199_item	2772303	et	4	main
klassijuhatajat	doc_634572338199_item	2772311	et	3	main
kes	doc_634572338199_item	2772312	et	4	main
hakkab	doc_634572338199_item	2772313	et	3	main
sulle	doc_634572338199_item	2772314	et	3	main
aitama	doc_634572338199_item	2772315	et	3	main
ja	doc_634572338199_item	2772316	et	3	main
panema	doc_634572338199_item	2772317	et	3	main
sind	doc_634572338199_item	2772318	et	4	main
õigele	doc_634572338199_item	2772319	et	3	main
teele	doc_634572338199_item	2772320	et	3	main
iseseisvuna	doc_634572338199_item	2772328	et	4	main
on	doc_634572338199_item	2772329	et	4	main
aga	doc_634572338199_item	2772330	et	3	main
oma	doc_634572338199_item	2772331	et	4	main
plussid	doc_634572338199_item	2772332	et	3	main
ülikooli	doc_634572338199_item	2772333	et	4	main
ise	doc_634572338199_item	2772338	et	4	main
mis	doc_634572338199_item	2772341	et	4	main
vajalik	doc_634572338199_item	2772343	et	3	main
töö	doc_634572338199_item	2772358	et	4	main
samuti	doc_634572338199_item	2772360	et	3	main
ülikoolis	doc_634572338199_item	2772361	et	4	main
on	doc_634572338199_item	2772362	et	4	main
olemas	doc_634572338199_item	2772363	et	4	main
valikained	doc_634572338199_item	2772364	et	3	main
ja	doc_634572338199_item	2772365	et	3	main
valik	doc_634572338199_item	2772366	et	3	main
on	doc_634572338199_item	2772367	et	4	main
väga	doc_634572338199_item	2772368	et	3	main
suur	doc_634572338199_item	2772369	et	3	main
nii	doc_634572338199_item	2772370	et	3	main
saab	doc_634572338199_item	2772374	et	3	main
selle	doc_634572338199_item	2772384	et	4	main
öelda	doc_634572338199_item	2772388	et	4	main
tahtsin	doc_634572338199_item	2772390	et	3	main
ehitusteaduskonda	doc_634572338199_item	2772392	et	4	main
aga	doc_634572338199_item	2772399	et	3	main
konkursi	doc_634572338199_item	2772403	et	3	main
ma	doc_634572338199_item	2772406	et	3	main
ainult	doc_634572338199_item	2772418	et	4	main
mina	doc_634572338200_item	2772422	et	4	main
majandusteaduskonna	doc_634572338200_item	2772432	et	4	main
et	doc_634572338200_item	2772446	et	3	main
palju	doc_634572338200_item	2772449	et	4	main
erialat	doc_634572338200_item	2772461	et	4	main
esialgu	doc_634572338200_item	2772462	et	3	main
ma	doc_634572338200_item	2772463	et	3	main
minna	doc_634572338200_item	2772465	et	3	main
kuid	doc_634572338200_item	2772468	et	4	main
on	doc_634572338200_item	2772476	et	4	main
ainult	doc_634572338200_item	2772479	et	4	main
aga	doc_634572338200_item	2772488	et	3	main
ei	doc_634572338200_item	2772491	et	4	main
rahvamajanduses	doc_634572338200_item	2772494	et	3	main
on	doc_634572338200_item	2772495	et	4	main
raskem	doc_634572338200_item	2772496	et	4	main
tean	doc_634572338200_item	2772498	et	3	main
sellest	doc_634572338200_item	2772499	et	4	main
õppida	doc_634572338200_item	2772497	et	3	main
oma	doc_634572338200_item	2772500	et	4	main
sõbrannalt	doc_634572338200_item	2772501	et	3	main
kuigi	doc_634572338200_item	2772502	et	3	main
ta	doc_634572338200_item	2772503	et	4	main
õpis	doc_634572338200_item	2772504	et	3	main
eesti	doc_634572338200_item	2772505	et	4	main
koolis	doc_634572338200_item	2772506	et	4	main
tal	doc_634572338200_item	2772507	et	3	main
on	doc_634572338200_item	2772508	et	4	main
ikkagi	doc_634572338200_item	2772509	et	4	main
raske	doc_634572338200_item	2772510	et	4	main
õppimine	doc_634572338200_item	2772511	et	4	main
ülikoolis	doc_634572338200_item	2772512	et	4	main
väga	doc_634572338200_item	2772513	et	3	main
erineb	doc_634572338200_item	2772514	et	3	main
õppimisest	doc_634572338200_item	2772515	et	4	main
koolis	doc_634572338200_item	2772516	et	4	main
koolis	doc_634572338200_item	2772517	et	4	main
õpetajad	doc_634572338200_item	2772518	et	4	main
sundivad	doc_634572338200_item	2772519	et	4	main
sind	doc_634572338200_item	2772520	et	4	main
ta	doc_634572338200_item	2772458	et	4	main
õpis	doc_634572338200_item	2772459	et	3	main
seda	doc_634572338200_item	2772460	et	3	main
sooritasin	doc_634572338200_item	2772469	et	3	main
eksami	doc_634572338200_item	2772472	et	3	main
õppida	doc_634572338200_item	2772478	et	3	main
õppima	doc_634572338200_item	2772487	et	3	main
jaoks	doc_634572338200_item	2772529	et	4	main
on	doc_634572338200_item	2772540	et	4	main
seda	doc_634572338200_item	2772541	et	3	main
ei	doc_634572338200_item	2772550	et	4	main
oma	doc_634572338200_item	2772567	et	4	main
nüüd	doc_634572338200_item	2772570	et	4	main
millised	doc_634572338200_item	2772573	et	3	main
mulle	doc_634572338200_item	2772575	et	4	main
huvitav	doc_634572338200_item	2772588	et	4	main
ajaga	doc_634572338200_item	2772598	et	3	main
hakab	doc_634572338200_item	2772603	et	4	main
otsast	doc_634572338200_item	2772605	et	4	main
teine	doc_634572338200_item	2772609	et	3	main
koolis	doc_634572338200_item	2772621	et	4	main
oma	doc_634572338200_item	2772625	et	4	main
mulle	doc_634572338200_item	2772630	et	4	main
meeldib	doc_634572338200_item	2772631	et	3	main
ülikoolis	doc_634572338200_item	2772633	et	4	main
praegu	doc_634572338200_item	2772634	et	3	main
et	doc_634572338200_item	2772640	et	3	main
ei	doc_634572338202_item	2772841	et	4	main
eesti	doc_634572338202_item	2772843	et	4	main
tunnis	doc_634572338202_item	2772845	et	3	main
ma	doc_634572338202_item	2772859	et	3	main
eesti	doc_634572338202_item	2772884	et	4	main
keele	doc_634572338202_item	2772885	et	4	main
või	doc_634572338202_item	2772896	et	4	main
alla	doc_634572338202_item	2772903	et	3	main
olin	doc_634572338202_item	2772905	et	3	main
käia	doc_634572338202_item	2772911	et	4	main
kui	doc_634572338202_item	2772912	et	3	main
ka	doc_634572338202_item	2772913	et	3	main
õppida	doc_634572338202_item	2772914	et	3	main
pärast	doc_634572338202_item	2772915	et	4	main
kaks	doc_634572338202_item	2772916	et	3	main
aru	doc_634572338202_item	2772923	et	4	main
kahes	doc_634572338202_item	2772934	et	4	main
vahetuses	doc_634572338202_item	2772935	et	4	main
tunne	doc_634572338202_item	2772944	et	4	main
et	doc_634572338202_item	2772947	et	3	main
ületunnitööd	doc_634572338202_item	2772950	et	4	main
tegema	doc_634572338202_item	2772951	et	3	main
minu	doc_634572338202_item	2772952	et	3	main
sest	doc_634572338200_item	2772534	et	4	main
või	doc_634572338200_item	2772539	et	4	main
ise	doc_634572338200_item	2772545	et	4	main
jagada	doc_634572338200_item	2772546	et	3	main
aega	doc_634572338200_item	2772548	et	4	main
ma	doc_634572338200_item	2772549	et	3	main
rohkem	doc_634572338200_item	2772555	et	4	main
sest	doc_634572338200_item	2772558	et	4	main
koolis	doc_634572338200_item	2772559	et	4	main
oli	doc_634572338200_item	2772560	et	3	main
on	doc_634572338200_item	2772565	et	4	main
aga	doc_634572338200_item	2772566	et	3	main
ja	doc_634572338200_item	2772578	et	3	main
ülikoolis	doc_634572338200_item	2772579	et	4	main
see	doc_634572338200_item	2772586	et	3	main
koolis	doc_634572338200_item	2772589	et	4	main
saime	doc_634572338200_item	2772599	et	3	main
ülikoolois	doc_634572338200_item	2772602	et	4	main
kõik	doc_634572338200_item	2772604	et	4	main
peab	doc_634572338200_item	2772607	et	4	main
algusel	doc_634572338200_item	2772611	et	4	main
mul	doc_634572338200_item	2772612	et	3	main
oli	doc_634572338200_item	2772613	et	3	main
raske	doc_634572338200_item	2772614	et	4	main
uskuda	doc_634572338200_item	2772615	et	3	main
et	doc_634572338200_item	2772616	et	3	main
ma	doc_634572338200_item	2772617	et	3	main
rohkem	doc_634572338200_item	2772618	et	4	main
ei	doc_634572338200_item	2772619	et	4	main
õpi	doc_634572338200_item	2772620	et	4	main
ma	doc_634572338200_item	2772622	et	3	main
oleks	doc_634572338200_item	2772643	et	3	main
edukas	doc_634572338200_item	2772644	et	4	main
ida	doc_634572338202_item	2772835	et	4	main
ma	doc_634572338202_item	2772836	et	3	main
olen	doc_634572338202_item	2772837	et	3	main
olnud	doc_634572338202_item	2772842	et	4	main
tunniplaani	doc_634572338202_item	2772846	et	4	main
j	doc_634572338202_item	2772847	et	4	main
eesti	doc_634572338202_item	2772851	et	4	main
hea	doc_634572338200_item	2772563	et	4	main
tahan	doc_634572338200_item	2772571	et	3	main
rääkida	doc_634572338200_item	2772572	et	3	main
asjad	doc_634572338200_item	2772574	et	3	main
meeldivad	doc_634572338200_item	2772576	et	4	main
koolis	doc_634572338200_item	2772577	et	4	main
õppeained	doc_634572338200_item	2772585	et	3	main
selle	doc_634572338200_item	2772597	et	4	main
on	doc_634572338200_item	2772635	et	4	main
kõige	doc_634572338200_item	2772636	et	4	main
esimene	doc_634572338200_item	2772641	et	3	main
igatsesin	doc_634572338200_item	2772624	et	3	main
klassijuhatajat	doc_634572338200_item	2772626	et	3	main
aga	doc_634572338200_item	2772629	et	3	main
õppida	doc_634572338200_item	2772632	et	3	main
jaoks	doc_634572338200_item	2772639	et	4	main
vastus	doc_634572338202_item	2772832	et	3	main
küsimusele	doc_634572338202_item	2772833	et	4	main
m	doc_634572338202_item	2772834	et	4	main
mind	doc_634572338202_item	2772840	et	4	main
meil	doc_634572338202_item	2772850	et	4	main
septembris	doc_634572338202_item	2772857	et	3	main
igas	doc_634572338202_item	2772860	et	3	main
kuid	doc_634572338202_item	2772862	et	4	main
kuid	doc_634572338202_item	2772899	et	4	main
kuud	doc_634572338202_item	2772917	et	4	main
lõpuks	doc_634572338202_item	2772922	et	4	main
et	doc_634572338202_item	2772924	et	3	main
pean	doc_634572338202_item	2772925	et	4	main
vaatamata	doc_634572338202_item	2772936	et	4	main
sellepärast	doc_634572338202_item	2772946	et	3	main
pidin	doc_634572338202_item	2772949	et	3	main
kui	doc_634572338202_item	2772956	et	3	main
arvestama	doc_634572338202_item	2772961	et	3	main
juba	doc_634572338202_item	2772978	et	3	main
päeval	doc_634572338202_item	2772980	et	3	main
kontorisse	doc_634572338202_item	2772983	et	3	main
katkestama	doc_634572338202_item	2772985	et	3	main
miks	doc_634572338202_item	2772991	et	4	main
käinud	doc_634572338202_item	2772994	et	4	main
teinud	doc_634572338202_item	2772838	et	4	main
ärgi	doc_634572338202_item	2772848	et	4	main
1400	doc_634572338202_item	2772856	et	2	main
tunnis	doc_634572338202_item	2772861	et	3	main
alates	doc_634572338202_item	2772863	et	3	main
tundi	doc_634572338202_item	2772886	et	4	main
tahan	doc_634572338202_item	2772887	et	3	main
puudumise	doc_634572338202_item	2772888	et	4	main
kui	doc_634572338202_item	2772900	et	3	main
töölepingule	doc_634572338202_item	2772902	et	4	main
kui	doc_634572338202_item	2772839	et	3	main
keele	doc_634572338202_item	2772844	et	4	main
olid	doc_634572338202_item	2772849	et	4	main
käisin	doc_634572338202_item	2772858	et	3	main
oktobrikuust	doc_634572338202_item	2772864	et	4	main
alustasin	doc_634572338202_item	2772865	et	3	main
ma	doc_634572338202_item	2772866	et	3	main
tööd	doc_634572338202_item	2772867	et	4	main
ühes	doc_634572338202_item	2772868	et	4	main
farmaatsiaettevõtes	doc_634572338202_item	2772869	et	3	main
ravimite	doc_634572338202_item	2772870	et	3	main
komplekteerijana	doc_634572338202_item	2772871	et	4	main
kahjuks	doc_634572338202_item	2772872	et	4	main
mõnikord	doc_634572338202_item	2772873	et	3	main
pidin	doc_634572338202_item	2772874	et	3	main
ma	doc_634572338202_item	2772875	et	3	main
varakult	doc_634572338202_item	2772876	et	4	main
tööle	doc_634572338202_item	2772877	et	3	main
minema	doc_634572338202_item	2772878	et	3	main
ja	doc_634572338202_item	2772879	et	3	main
seetõttu	doc_634572338202_item	2772880	et	3	main
ei	doc_634572338202_item	2772881	et	4	main
jõudnud	doc_634572338202_item	2772882	et	4	main
keele	doc_634572338202_item	2772852	et	4	main
tunnid	doc_634572338202_item	2772853	et	3	main
teisipäevati	doc_634572338202_item	2772854	et	3	main
kell	doc_634572338202_item	2772855	et	3	main
ma	doc_634572338202_item	2772883	et	3	main
pärast	doc_634572338202_item	2772889	et	4	main
vabandust	doc_634572338202_item	2772890	et	4	main
paluma	doc_634572338202_item	2772891	et	3	main
tean	doc_634572338202_item	2772892	et	3	main
et	doc_634572338202_item	2772893	et	3	main
töö	doc_634572338202_item	2772894	et	4	main
segada	doc_634572338202_item	2772898	et	3	main
kindel	doc_634572338202_item	2772906	et	3	main
jõuan	doc_634572338202_item	2772908	et	3	main
nii	doc_634572338202_item	2772909	et	3	main
pingelist	doc_634572338202_item	2772918	et	4	main
sain	doc_634572338202_item	2772920	et	3	main
ma	doc_634572338202_item	2772921	et	3	main
tööd	doc_634572338202_item	2772926	et	4	main
katkestama	doc_634572338202_item	2772927	et	3	main
mul	doc_634572338202_item	2772928	et	3	main
oli	doc_634572338202_item	2772929	et	3	main
sellele	doc_634572338202_item	2772937	et	4	main
et	doc_634572338202_item	2772938	et	3	main
töötasin	doc_634572338202_item	2772939	et	3	main
osakoormusega	doc_634572338202_item	2772940	et	3	main
arvan	doc_634572338202_item	2772941	et	3	main
et	doc_634572338202_item	2772942	et	3	main
selline	doc_634572338202_item	2772943	et	4	main
kõiki	doc_634572338202_item	2772957	et	4	main
pean	doc_634572338202_item	2772962	et	4	main
tööd	doc_634572338202_item	2772964	et	4	main
ja	doc_634572338202_item	2772977	et	3	main
järgmisel	doc_634572338202_item	2772979	et	3	main
läksin	doc_634572338202_item	2772981	et	3	main
teine	doc_634572338202_item	2772989	et	3	main
atraktsioon	doc_634572338202_item	2773022	et	3	main
kui	doc_634572338202_item	2773029	et	3	main
kord	doc_634572338202_item	2773051	et	4	main
pärast	doc_634572338202_item	2773055	et	4	main
minu	doc_634572338202_item	2773059	et	3	main
me	doc_634572338203_item	2773076	et	4	main
teadma	doc_634572338203_item	2773087	et	3	main
peaaegu	doc_634572338203_item	2773089	et	3	main
võimatu	doc_634572338203_item	2773090	et	4	main
tea	doc_634572338203_item	2773095	et	4	main
keelt	doc_634572338203_item	2773097	et	4	main
muidugi	doc_634572338203_item	2773098	et	4	main
teisi	doc_634572338203_item	2773103	et	4	main
on	doc_634572338203_item	2773115	et	4	main
esimesel	doc_634572338203_item	2773116	et	3	main
kahjuks	doc_634572338203_item	2773127	et	4	main
käinud	doc_634572338203_item	2773145	et	4	main
eesti	doc_634572338203_item	2773146	et	4	main
töö	doc_634572338203_item	2773156	et	4	main
aga	doc_634572338203_item	2773158	et	3	main
palju	doc_634572338203_item	2773162	et	4	main
leida	doc_634572338203_item	2773167	et	3	main
mõnda	doc_634572338203_item	2773169	et	4	main
teist	doc_634572338203_item	2773170	et	4	main
katsuvad	doc_634572338203_item	2773184	et	4	main
oma	doc_634572338203_item	2773186	et	4	main
ja	doc_634572338203_item	2773188	et	3	main
õpimist	doc_634572338203_item	2773189	et	4	main
raske	doc_634572338203_item	2773194	et	4	main
aga	doc_634572338203_item	2773195	et	3	main
teiseti	doc_634572338203_item	2773196	et	4	main
kui	doc_634572338203_item	2773197	et	3	main
mitte	doc_634572338203_item	2773198	et	3	main
töötada	doc_634572338203_item	2773199	et	3	main
on	doc_634572338203_item	2773200	et	4	main
keegi	doc_634572338203_item	2773203	et	4	main
segavad	doc_634572338204_item	2773229	et	4	main
tada	doc_634572338204_item	2773234	et	4	main
õppida	doc_634572338204_item	2773235	et	3	main
ja	doc_634572338204_item	2773236	et	3	main
erinevaid	doc_634572338204_item	2773237	et	4	main
edusid	doc_634572338204_item	2773238	et	3	main
saavutada	doc_634572338204_item	2773239	et	3	main
mitte	doc_634572338204_item	2773240	et	3	main
alati	doc_634572338204_item	2773241	et	4	main
ka	doc_634572338204_item	2773249	et	3	main
ei	doc_634572338202_item	2772895	et	4	main
õppimast	doc_634572338202_item	2772897	et	3	main
ma	doc_634572338202_item	2772901	et	3	main
tööl	doc_634572338202_item	2772910	et	3	main
päevaplaani	doc_634572338202_item	2772919	et	4	main
kirjutasin	doc_634572338202_item	2772904	et	3	main
et	doc_634572338202_item	2772907	et	3	main
tunne	doc_634572338202_item	2772930	et	4	main
et	doc_634572338202_item	2772931	et	3	main
ma	doc_634572338202_item	2772932	et	3	main
poolt-	doc_634572338202_item	2772958	et	4	main
vastuargumente	doc_634572338202_item	2772960	et	3	main
ma	doc_634572338202_item	2772963	et	3	main
järele	doc_634572338202_item	2772965	et	4	main
jätma	doc_634572338202_item	2772966	et	3	main
ja	doc_634572338202_item	2772967	et	3	main
õppimist	doc_634572338202_item	2772968	et	4	main
õigsuses	doc_634572338202_item	2772976	et	3	main
oktoobris	doc_634572338202_item	2772986	et	3	main
ka	doc_634572338202_item	2772988	et	3	main
ei	doc_634572338202_item	2772993	et	4	main
üks	doc_634572338202_item	2773021	et	3	main
moodi	doc_634572338202_item	2773026	et	4	main
parem	doc_634572338202_item	2773027	et	4	main
oleks	doc_634572338202_item	2773028	et	3	main
toost	doc_634572338202_item	2773033	et	3	main
alla	doc_634572338202_item	2773035	et	3	main
minu	doc_634572338202_item	2773053	et	3	main
et	doc_634572338202_item	2773058	et	3	main
teie	doc_634572338202_item	2773071	et	4	main
tundides	doc_634572338202_item	2773072	et	3	main
käia	doc_634572338202_item	2773073	et	4	main
elame	doc_634572338203_item	2773078	et	3	main
kus	doc_634572338203_item	2773080	et	3	main
keel	doc_634572338203_item	2773082	et	4	main
on	doc_634572338203_item	2773083	et	4	main
ei	doc_634572338203_item	2773094	et	4	main
ka	doc_634572338203_item	2773102	et	3	main
inglise	doc_634572338203_item	2773106	et	4	main
keel	doc_634572338203_item	2773107	et	4	main
ja	doc_634572338203_item	2773108	et	3	main
ülikoolis	doc_634572338203_item	2773123	et	4	main
kohal	doc_634572338203_item	2773125	et	4	main
üks	doc_634572338203_item	2773129	et	3	main
midagi	doc_634572338203_item	2773154	et	4	main
liiga	doc_634572338203_item	2773161	et	4	main
mis	doc_634572338203_item	2773172	et	4	main
aega	doc_634572338203_item	2773177	et	4	main
ühendada	doc_634572338203_item	2773185	et	3	main
päris	doc_634572338203_item	2773193	et	4	main
veelgi	doc_634572338203_item	2773201	et	4	main
loengutest	doc_634572338204_item	2773222	et	4	main
meist	doc_634572338204_item	2773224	et	3	main
tekivad	doc_634572338204_item	2773226	et	3	main
probleemid	doc_634572338204_item	2773227	et	3	main
t	doc_634572338204_item	2773232	et	4	main
voib	doc_634572338204_item	2773242	et	4	main
õppimisel	doc_634572338204_item	2773259	et	4	main
õppesta	doc_634572338204_item	2773261	et	4	main
raskelt	doc_634572338204_item	2773267	et	4	main
suur	doc_634572338204_item	2773268	et	3	main
raske	doc_634572338204_item	2773276	et	4	main
oppimiseta	doc_634572338204_item	2773280	et	4	main
pärast	doc_634572338204_item	2773282	et	4	main
endale	doc_634572338204_item	2773293	et	4	main
veendunud	doc_634572338204_item	2773303	et	4	main
et	doc_634572338204_item	2773304	et	3	main
ise	doc_634572338204_item	2773307	et	4	main
katseks	doc_634572338204_item	2773318	et	4	main
lugupidamisega	doc_634572338204_item	2773319	et	3	main
x	doc_634572338204_item	2773320	et	4	main
töötan	doc_634572338202_item	2772933	et	3	main
tekkis	doc_634572338202_item	2772945	et	3	main
mõnikord	doc_634572338202_item	2772948	et	3	main
ja	doc_634572338202_item	2772959	et	3	main
käsile	doc_634572338202_item	2772969	et	4	main
võtma	doc_634572338202_item	2772970	et	3	main
tegelikult	doc_634572338202_item	2772971	et	4	main
oma	doc_634572338202_item	2772975	et	4	main
mina	doc_634572338202_item	2772982	et	4	main
töölepingut	doc_634572338202_item	2772984	et	3	main
oli	doc_634572338202_item	2772987	et	3	main
põhjus	doc_634572338202_item	2772990	et	4	main
ma	doc_634572338202_item	2772992	et	3	main
eesti	doc_634572338202_item	2772995	et	4	main
keele	doc_634572338202_item	2772996	et	4	main
oktoobrikuu	doc_634572338202_item	2772998	et	4	main
alguses	doc_634572338202_item	2772999	et	4	main
läksime	doc_634572338202_item	2773000	et	3	main
me	doc_634572338202_item	2773001	et	4	main
sõpradega	doc_634572338202_item	2773002	et	3	main
riigasse	doc_634572338202_item	2773003	et	4	main
puhkama	doc_634572338202_item	2773004	et	3	main
esimesel	doc_634572338202_item	2773005	et	3	main
päeval	doc_634572338202_item	2773006	et	3	main
oli	doc_634572338202_item	2773007	et	3	main
kõik	doc_634572338202_item	2773008	et	4	main
suurepärane	doc_634572338202_item	2773009	et	4	main
kuid	doc_634572338202_item	2773010	et	4	main
teisel	doc_634572338202_item	2773011	et	4	main
päeval	doc_634572338202_item	2773012	et	3	main
juhtus	doc_634572338202_item	2773013	et	3	main
õnnetus	doc_634572338202_item	2773014	et	4	main
me	doc_634572338202_item	2773015	et	4	main
läksime	doc_634572338202_item	2773016	et	3	main
lõbustusparki	doc_634572338202_item	2773017	et	4	main
kus	doc_634572338202_item	2773018	et	3	main
mulle	doc_634572338202_item	2773019	et	4	main
meeldis	doc_634572338202_item	2773020	et	3	main
oli	doc_634572338202_item	2773024	et	3	main
proovinud	doc_634572338202_item	2773032	et	4	main
laskuda	doc_634572338202_item	2773036	et	3	main
ma	doc_634572338202_item	2773039	et	3	main
veel	doc_634572338202_item	2773050	et	4	main
olnud	doc_634572338202_item	2773068	et	4	main
mõnikord	doc_634572338202_item	2773069	et	3	main
võimalust	doc_634572338202_item	2773070	et	3	main
kõik	doc_634572338203_item	2773077	et	4	main
peame	doc_634572338203_item	2773085	et	4	main
on	doc_634572338203_item	2773088	et	4	main
on	doc_634572338203_item	2773099	et	4	main
vene	doc_634572338203_item	2773109	et	4	main
keel	doc_634572338203_item	2773114	et	4	main
sõber	doc_634572338202_item	2772953	et	3	main
ütles	doc_634572338202_item	2772954	et	3	main
et	doc_634572338202_item	2772955	et	3	main
ta	doc_634572338202_item	2772972	et	4	main
veenis	doc_634572338202_item	2772973	et	4	main
mind	doc_634572338202_item	2772974	et	4	main
tunnis	doc_634572338202_item	2772997	et	3	main
mis	doc_634572338202_item	2773023	et	4	main
bobisõidu	doc_634572338202_item	2773025	et	4	main
ei	doc_634572338202_item	2773031	et	4	main
jalalihase	doc_634572338202_item	2773041	et	4	main
ja	doc_634572338202_item	2773043	et	3	main
pidin	doc_634572338202_item	2773044	et	3	main
kaks	doc_634572338202_item	2773045	et	3	main
puudumise	doc_634572338202_item	2773054	et	4	main
ja	doc_634572338202_item	2773056	et	3	main
selgitused	doc_634572338202_item	2773060	et	4	main
uskuma	doc_634572338202_item	2773063	et	3	main
essee	doc_634572338203_item	2773074	et	4	main
riigikeel	doc_634572338203_item	2773084	et	4	main
leida	doc_634572338203_item	2773091	et	3	main
kui	doc_634572338203_item	2773093	et	3	main
eesti	doc_634572338203_item	2773096	et	4	main
keele	doc_634572338203_item	2773104	et	4	main
näiteks	doc_634572338203_item	2773105	et	4	main
tallinna	doc_634572338203_item	2773121	et	4	main
tasulisel	doc_634572338203_item	2773124	et	4	main
kallimatest	doc_634572338203_item	2773131	et	4	main
keele	doc_634572338203_item	2773147	et	4	main
ja	doc_634572338203_item	2773148	et	3	main
mõnedes	doc_634572338203_item	2773149	et	3	main
oma	doc_634572338203_item	2773155	et	4	main
see	doc_634572338203_item	2773159	et	3	main
aega	doc_634572338203_item	2773163	et	4	main
ma	doc_634572338203_item	2773165	et	3	main
ei	doc_634572338203_item	2773173	et	4	main
võta	doc_634572338203_item	2773174	et	4	main
nii	doc_634572338203_item	2773175	et	3	main
palju	doc_634572338203_item	2773176	et	4	main
tean	doc_634572338203_item	2773183	et	3	main
tööt	doc_634572338203_item	2773187	et	4	main
muidugi	doc_634572338203_item	2773190	et	4	main
see	doc_634572338203_item	2773191	et	3	main
meid	doc_634572338204_item	2773230	et	4	main
mis	doc_634572338204_item	2773245	et	4	main
minusse	doc_634572338204_item	2773246	et	3	main
puutub	doc_634572338204_item	2773247	et	3	main
ka	doc_634572338204_item	2773258	et	3	main
materjalimaht	doc_634572338204_item	2773269	et	3	main
järsult	doc_634572338204_item	2773270	et	4	main
ilmunud	doc_634572338204_item	2773271	et	4	main
koormus	doc_634572338204_item	2773272	et	4	main
kahe	doc_634572338204_item	2773278	et	3	main
ei	doc_634572338204_item	2773290	et	4	main
leia	doc_634572338204_item	2773291	et	4	main
keele	doc_634572338204_item	2773298	et	4	main
puudunud	doc_634572338204_item	2773300	et	4	main
sest	doc_634572338204_item	2773301	et	4	main
olen	doc_634572338204_item	2773302	et	3	main
oma	doc_634572338204_item	2773308	et	4	main
vastama	doc_634572338204_item	2773311	et	3	main
mitte	doc_634572338204_item	2773313	et	3	main
ma	doc_634572338202_item	2773030	et	3	main
mäest	doc_634572338202_item	2773034	et	3	main
kuna	doc_634572338202_item	2773037	et	3	main
lõpuks	doc_634572338202_item	2773038	et	4	main
venitasin	doc_634572338202_item	2773040	et	3	main
ära	doc_634572338202_item	2773042	et	4	main
nädalat	doc_634572338202_item	2773046	et	3	main
voodis	doc_634572338202_item	2773047	et	3	main
lamama	doc_634572338202_item	2773048	et	4	main
palun	doc_634572338202_item	2773049	et	3	main
vabandust	doc_634572338202_item	2773052	et	4	main
loodan	doc_634572338202_item	2773057	et	3	main
panevad	doc_634572338202_item	2773061	et	4	main
teid	doc_634572338202_item	2773062	et	4	main
et	doc_634572338202_item	2773064	et	3	main
mul	doc_634572338202_item	2773065	et	3	main
tõesti	doc_634572338202_item	2773066	et	3	main
ei	doc_634572338202_item	2773067	et	4	main
kuna	doc_634572338203_item	2773075	et	3	main
riigis	doc_634572338203_item	2773079	et	3	main
eesti	doc_634572338203_item	2773081	et	4	main
seda	doc_634572338203_item	2773086	et	3	main
tööd	doc_634572338203_item	2773092	et	4	main
vaja	doc_634572338203_item	2773100	et	4	main
teada	doc_634572338203_item	2773101	et	3	main
keel	doc_634572338203_item	2773110	et	4	main
kuid	doc_634572338203_item	2773111	et	4	main
ikkagi	doc_634572338203_item	2773112	et	4	main
eesti	doc_634572338203_item	2773113	et	4	main
kohal	doc_634572338203_item	2773117	et	4	main
ma	doc_634572338203_item	2773118	et	3	main
ise	doc_634572338203_item	2773119	et	4	main
õpin	doc_634572338203_item	2773120	et	3	main
tehnika	doc_634572338203_item	2773122	et	4	main
majandusteaduskond	doc_634572338203_item	2773126	et	3	main
ei	doc_634572338203_item	2773144	et	4	main
mul	doc_634572338203_item	2773152	et	3	main
pole	doc_634572338203_item	2773153	et	3	main
võtab	doc_634572338203_item	2773160	et	3	main
ja	doc_634572338203_item	2773164	et	3	main
tahaks	doc_634572338203_item	2773166	et	3	main
endale	doc_634572338203_item	2773168	et	4	main
peaaegu	doc_634572338203_item	2773178	et	3	main
keda	doc_634572338203_item	2773181	et	4	main
on	doc_634572338203_item	2773192	et	4	main
raskem	doc_634572338203_item	2773202	et	4	main
ei	doc_634572338203_item	2773204	et	4	main
soovi	doc_634572338203_item	2773205	et	4	main
ülalpeetav	doc_634572338203_item	2773206	et	3	main
on	doc_634572338203_item	2773128	et	4	main
kõige	doc_634572338203_item	2773130	et	4	main
teaduskondadest	doc_634572338203_item	2773132	et	3	main
seepärast	doc_634572338203_item	2773133	et	3	main
ma	doc_634572338203_item	2773134	et	3	main
pean	doc_634572338203_item	2773135	et	4	main
töötama	doc_634572338203_item	2773136	et	3	main
töötan	doc_634572338203_item	2773137	et	3	main
praegu	doc_634572338203_item	2773138	et	3	main
iga	doc_634572338203_item	2773139	et	4	main
päev	doc_634572338203_item	2773140	et	3	main
ja	doc_634572338203_item	2773141	et	3	main
just	doc_634572338203_item	2773142	et	3	main
sellepärast	doc_634572338203_item	2773143	et	3	main
teistes	doc_634572338203_item	2773150	et	4	main
tundides	doc_634572338203_item	2773151	et	3	main
vastu	doc_634572338203_item	2773157	et	3	main
tööt	doc_634572338203_item	2773171	et	4	main
kõik	doc_634572338203_item	2773179	et	4	main
tudengid	doc_634572338203_item	2773180	et	3	main
ma	doc_634572338203_item	2773182	et	3	main
olema	doc_634572338203_item	2773207	et	4	main
ja	doc_634572338203_item	2773208	et	3	main
nii	doc_634572338203_item	2773209	et	3	main
kõvasti	doc_634572338203_item	2773210	et	3	main
sõltuma	doc_634572338203_item	2773211	et	3	main
oma	doc_634572338203_item	2773212	et	4	main
vanematest	doc_634572338203_item	2773213	et	4	main
seletuskiri	doc_634572338204_item	2773214	et	3	main
mida	doc_634572338204_item	2773215	et	4	main
mina	doc_634572338204_item	2773216	et	4	main
tegin	doc_634572338204_item	2773217	et	3	main
kui	doc_634572338204_item	2773218	et	3	main
puudusin	doc_634572338204_item	2773219	et	3	main
eesti	doc_634572338204_item	2773220	et	4	main
keele	doc_634572338204_item	2773221	et	4	main
aeg-ajalt	doc_634572338204_item	2773225	et	4	main
mis	doc_634572338204_item	2773228	et	4	main
öö	doc_634572338204_item	2773233	et	4	main
neid	doc_634572338204_item	2773243	et	4	main
ületada	doc_634572338204_item	2773244	et	3	main
omandatud	doc_634572338204_item	2773277	et	4	main
aastate	doc_634572338204_item	2773281	et	3	main
väike	doc_634572338204_item	2773283	et	4	main
vastupidavus	doc_634572338204_item	2773284	et	4	main
ma	doc_634572338204_item	2773289	et	3	main
mitu	doc_634572338204_item	2773296	et	4	main
loengutest	doc_634572338204_item	2773299	et	4	main
vigade	doc_634572338204_item	2773309	et	3	main
paluksin	doc_634572338204_item	2773312	et	3	main
igal	doc_634572338204_item	2773223	et	3	main
normaalselt	doc_634572338204_item	2773231	et	4	main
minul	doc_634572338204_item	2773248	et	3	main
ei	doc_634572338204_item	2773250	et	4	main
klappi	doc_634572338204_item	2773251	et	4	main
pidevalt	doc_634572338204_item	2773252	et	4	main
oma	doc_634572338204_item	2773253	et	4	main
plaani	doc_634572338204_item	2773254	et	4	main
elusse	doc_634572338204_item	2773255	et	3	main
viia	doc_634572338204_item	2773256	et	3	main
kahjuks	doc_634572338204_item	2773257	et	4	main
see	doc_634572338204_item	2773260	et	3	main
pisavalt	doc_634572338204_item	2773266	et	4	main
mis	doc_634572338204_item	2773273	et	4	main
oli	doc_634572338204_item	2773274	et	3	main
väga	doc_634572338204_item	2773275	et	3	main
peaaegu	doc_634572338204_item	2773279	et	3	main
haiguse	doc_634572338204_item	2773287	et	4	main
tõttu	doc_634572338204_item	2773288	et	4	main
et	doc_634572338204_item	2773294	et	3	main
olin	doc_634572338204_item	2773295	et	3	main
iga	doc_634572338204_item	2773305	et	4	main
eest	doc_634572338204_item	2773310	et	4	main
arvada	doc_634572338204_item	2773314	et	4	main
osalesin	doc_634572338206_item	2773478	et	3	main
sellel	doc_634572338206_item	2773527	et	4	main
päeval	doc_634572338206_item	2773528	et	3	main
meil	doc_634572338206_item	2773529	et	4	main
me	doc_634572338206_item	2773533	et	4	main
õppisime	doc_634572338206_item	2773534	et	3	main
tunniplaanis	doc_634572338206_item	2773535	et	3	main
oli	doc_634572338206_item	2773536	et	3	main
neli	doc_634572338206_item	2773537	et	3	main
õppeainet	doc_634572338206_item	2773538	et	3	main
oli	doc_634572338206_item	2773546	et	3	main
erinevate	doc_634572338206_item	2773553	et	4	main
natukene	doc_634572338206_item	2773560	et	4	main
rääkisime	doc_634572338206_item	2773561	et	3	main
keukenhof	doc_634572338206_item	2773597	et	4	main
on	doc_634572338206_item	2773604	et	4	main
utrehti	doc_634572338206_item	2773609	et	4	main
päeval	doc_634572338206_item	2773612	et	3	main
seal	doc_634572338206_item	2773620	et	4	main
üks	doc_634572338206_item	2773625	et	3	main
sõime	doc_634572338206_item	2773633	et	4	main
seal	doc_634572338206_item	2773634	et	4	main
seal	doc_634572338206_item	2773643	et	4	main
ma	doc_634572338206_item	2773644	et	3	main
tegin	doc_634572338206_item	2773645	et	3	main
meelde	doc_634572338206_item	2773655	et	3	main
need	doc_634572338206_item	2773659	et	3	main
kiiresti	doc_634572338206_item	2773664	et	3	main
oli	doc_634572338206_item	2773666	et	3	main
arä	doc_634572338206_item	2773669	et	4	main
minna	doc_634572338206_item	2773670	et	3	main
on	doc_634572338204_item	2773262	et	4	main
alanud	doc_634572338204_item	2773263	et	4	main
minu	doc_634572338204_item	2773264	et	3	main
jaoks	doc_634572338204_item	2773265	et	4	main
mis	doc_634572338204_item	2773285	et	4	main
tekis	doc_634572338204_item	2773286	et	3	main
õigustuse	doc_634572338204_item	2773292	et	4	main
eesti	doc_634572338204_item	2773297	et	4	main
peab	doc_634572338204_item	2773306	et	4	main
selle	doc_634572338204_item	2773315	et	4	main
essee	doc_634572338204_item	2773316	et	4	main
õigustamise	doc_634572338204_item	2773317	et	4	main
essee	doc_634572338206_item	2773454	et	4	main
kus	doc_634572338206_item	2773455	et	3	main
olen	doc_634572338206_item	2773456	et	3	main
olen	doc_634572338206_item	2773461	et	3	main
kolm	doc_634572338206_item	2773463	et	3	main
aastat	doc_634572338206_item	2773464	et	3	main
siis	doc_634572338206_item	2773466	et	3	main
ma	doc_634572338206_item	2773468	et	3	main
kümnendas	doc_634572338206_item	2773470	et	3	main
meie	doc_634572338206_item	2773472	et	4	main
õpilastevahetus	doc_634572338206_item	2773475	et	4	main
ka	doc_634572338206_item	2773480	et	3	main
tulid	doc_634572338206_item	2773482	et	4	main
jaanuaris	doc_634572338206_item	2773484	et	3	main
lendama	doc_634572338206_item	2773494	et	3	main
hollandisse	doc_634572338206_item	2773495	et	4	main
ka	doc_634572338206_item	2773496	et	3	main
nädalaks	doc_634572338206_item	2773497	et	3	main
koolis	doc_634572338206_item	2773522	et	4	main
oli	doc_634572338206_item	2773530	et	3	main
tunnid	doc_634572338206_item	2773531	et	3	main
ja	doc_634572338206_item	2773532	et	3	main
hollandi	doc_634572338206_item	2773539	et	4	main
keel	doc_634572338206_item	2773540	et	4	main
väga	doc_634572338206_item	2773547	et	3	main
maale	doc_634572338206_item	2773559	et	4	main
pidi	doc_634572338206_item	2773588	et	4	main
näitama	doc_634572338206_item	2773589	et	3	main
ise	doc_634572338206_item	2773590	et	4	main
mulle	doc_634572338206_item	2773595	et	4	main
meeldis	doc_634572338206_item	2773596	et	3	main
park	doc_634572338206_item	2773602	et	3	main
veel	doc_634572338206_item	2773607	et	4	main
viiendal	doc_634572338206_item	2773611	et	3	main
mida	doc_634572338206_item	2773460	et	4	main
näinud	doc_634572338206_item	2773462	et	4	main
klassis	doc_634572338206_item	2773471	et	3	main
koolis	doc_634572338206_item	2773473	et	4	main
toimus	doc_634572338206_item	2773474	et	3	main
selles	doc_634572338206_item	2773479	et	4	main
nad	doc_634572338206_item	2773485	et	3	main
olid	doc_634572338206_item	2773486	et	4	main
juures	doc_634572338206_item	2773488	et	4	main
aega	doc_634572338206_item	2773490	et	4	main
aprillis	doc_634572338206_item	2773491	et	3	main
me	doc_634572338206_item	2773492	et	4	main
pidime	doc_634572338206_item	2773493	et	3	main
külas	doc_634572338206_item	2773500	et	3	main
sõbrannal	doc_634572338206_item	2773502	et	3	main
k	doc_634572338206_item	2773457	et	4	main
hollandiga	doc_634572338206_item	2773476	et	4	main
ma	doc_634572338206_item	2773477	et	3	main
meie	doc_634572338206_item	2773487	et	4	main
mina	doc_634572338206_item	2773498	et	4	main
kes	doc_634572338206_item	2773503	et	4	main
oli	doc_634572338206_item	2773504	et	3	main
talvel	doc_634572338206_item	2773505	et	4	main
minu	doc_634572338206_item	2773506	et	3	main
juures	doc_634572338206_item	2773507	et	4	main
iga	doc_634572338206_item	2773508	et	4	main
päev	doc_634572338206_item	2773509	et	3	main
meie	doc_634572338206_item	2773510	et	4	main
jaoks	doc_634572338206_item	2773511	et	4	main
olid	doc_634572338206_item	2773512	et	4	main
plaanitud	doc_634572338206_item	2773513	et	4	main
erinevad	doc_634572338206_item	2773514	et	4	main
meelelahutused	doc_634572338206_item	2773515	et	4	main
näiteks	doc_634572338206_item	2773516	et	4	main
esimesel	doc_634572338206_item	2773517	et	3	main
päeval	doc_634572338206_item	2773518	et	3	main
me	doc_634572338206_item	2773519	et	4	main
olime	doc_634572338206_item	2773520	et	3	main
nendes	doc_634572338206_item	2773521	et	4	main
ja	doc_634572338206_item	2773523	et	3	main
tutvusime	doc_634572338206_item	2773524	et	4	main
neide	doc_634572338206_item	2773525	et	3	main
kultuuriga	doc_634572338206_item	2773526	et	4	main
keemia	doc_634572338206_item	2773544	et	4	main
päev	doc_634572338206_item	2773545	et	3	main
huvitav	doc_634572338206_item	2773548	et	4	main
tegime	doc_634572338206_item	2773549	et	3	main
palju	doc_634572338206_item	2773550	et	4	main
eksperimente	doc_634572338206_item	2773551	et	3	main
pillede	doc_634572338206_item	2773554	et	4	main
van	doc_634572338206_item	2773557	et	4	main
gochi	doc_634572338206_item	2773558	et	4	main
pere	doc_634572338206_item	2773587	et	4	main
rohkem	doc_634572338206_item	2773594	et	4	main
nagu	doc_634572338206_item	2773600	et	3	main
väga	doc_634572338206_item	2773605	et	3	main
kirikus	doc_634572338206_item	2773610	et	3	main
seal	doc_634572338206_item	2773615	et	4	main
veekanaleid	doc_634572338206_item	2773619	et	4	main
palju	doc_634572338206_item	2773622	et	4	main
ja	doc_634572338206_item	2773624	et	3	main
lossis	doc_634572338206_item	2773627	et	4	main
suuri	doc_634572338206_item	2773635	et	3	main
pankooke	doc_634572338206_item	2773636	et	4	main
viimasel	doc_634572338206_item	2773637	et	3	main
päeval	doc_634572338206_item	2773638	et	3	main
oli	doc_634572338206_item	2773639	et	3	main
palju	doc_634572338206_item	2773646	et	4	main
pilte	doc_634572338206_item	2773647	et	3	main
tihti	doc_634572338206_item	2773648	et	3	main
vaatan	doc_634572338206_item	2773649	et	3	main
neid	doc_634572338206_item	2773650	et	4	main
uuesti	doc_634572338206_item	2773651	et	3	main
läksid	doc_634572338206_item	2773662	et	4	main
praaktikana	doc_634572338206_item	2773675	et	3	main
tutvustusena	doc_634572338206_item	2773679	et	4	main
õnnelik	doc_634572338206_item	2773690	et	3	main
äinud	doc_634572338206_item	2773458	et	4	main
ja	doc_634572338206_item	2773459	et	3	main
tagasi	doc_634572338206_item	2773465	et	3	main
kui	doc_634572338206_item	2773467	et	3	main
käisin	doc_634572338206_item	2773469	et	3	main
hollandlased	doc_634572338206_item	2773481	et	3	main
eestisse	doc_634572338206_item	2773483	et	4	main
nädala	doc_634572338206_item	2773489	et	3	main
olin	doc_634572338206_item	2773499	et	3	main
oma	doc_634572338206_item	2773501	et	4	main
muusika	doc_634572338206_item	2773541	et	4	main
mängisime	doc_634572338206_item	2773552	et	3	main
pael	doc_634572338206_item	2773555	et	4	main
joonistasime	doc_634572338206_item	2773556	et	3	main
hollandi	doc_634572338206_item	2773562	et	4	main
midagi	doc_634572338206_item	2773591	et	4	main
huvitavat	doc_634572338206_item	2773592	et	4	main
kõige	doc_634572338206_item	2773593	et	4	main
on	doc_634572338206_item	2773599	et	4	main
seal	doc_634572338206_item	2773603	et	4	main
ilus	doc_634572338206_item	2773606	et	4	main
sõitsime	doc_634572338206_item	2773613	et	3	main
oli	doc_634572338206_item	2773621	et	3	main
ekskursioone	doc_634572338206_item	2773623	et	3	main
puhul	doc_634572338206_item	2773641	et	4	main
disco-pidu	doc_634572338206_item	2773642	et	4	main
meeldib	doc_634572338206_item	2773654	et	3	main
väga	doc_634572338206_item	2773663	et	3	main
mõeldud	doc_634572338206_item	2773674	et	4	main
olen	doc_634572338206_item	2773689	et	3	main
sellise	doc_634572338206_item	2773693	et	4	main
teile	doc_634572338208_item	2773925	et	4	main
sellepärast	doc_634572338208_item	2773926	et	3	main
see	doc_634572338208_item	2773931	et	3	main
artikkel	doc_634572338208_item	2773932	et	3	main
tahan	doc_634572338208_item	2773933	et	3	main
kirjutada	doc_634572338208_item	2773934	et	3	main
minu	doc_634572338208_item	2773935	et	3	main
arvamust	doc_634572338208_item	2773936	et	3	main
joonistamine	doc_634572338206_item	2773542	et	4	main
ja	doc_634572338206_item	2773543	et	3	main
keeles	doc_634572338206_item	2773563	et	4	main
teisel	doc_634572338206_item	2773564	et	4	main
päeval	doc_634572338206_item	2773565	et	3	main
me	doc_634572338206_item	2773566	et	4	main
sõitsime	doc_634572338206_item	2773567	et	3	main
haagasse	doc_634572338206_item	2773568	et	4	main
seal	doc_634572338206_item	2773569	et	4	main
palju	doc_634572338206_item	2773570	et	4	main
jalutasime	doc_634572338206_item	2773571	et	3	main
ja	doc_634572338206_item	2773572	et	3	main
kõigepealt	doc_634572338206_item	2773573	et	3	main
olime	doc_634572338206_item	2773574	et	3	main
rahvusvahelinses	doc_634572338206_item	2773575	et	4	main
kolmas	doc_634572338206_item	2773577	et	3	main
ja	doc_634572338206_item	2773578	et	3	main
neljas	doc_634572338206_item	2773579	et	4	main
päevad	doc_634572338206_item	2773580	et	3	main
kohtus	doc_634572338206_item	2773576	et	4	main
olid	doc_634572338206_item	2773581	et	4	main
perepäevad	doc_634572338206_item	2773582	et	3	main
see	doc_634572338206_item	2773583	et	3	main
tähendab	doc_634572338206_item	2773584	et	3	main
et	doc_634572338206_item	2773585	et	3	main
hollandi	doc_634572338206_item	2773586	et	4	main
see	doc_634572338206_item	2773598	et	3	main
lille	doc_634572338206_item	2773601	et	4	main
olin	doc_634572338206_item	2773608	et	3	main
amsterdaammi	doc_634572338206_item	2773614	et	4	main
sõitsime	doc_634572338206_item	2773616	et	3	main
paadiga	doc_634572338206_item	2773617	et	3	main
mööda	doc_634572338206_item	2773618	et	4	main
bouwlingut	doc_634572338206_item	2773631	et	4	main
ja	doc_634572338206_item	2773632	et	3	main
läbi	doc_634572338206_item	2773652	et	4	main
seda	doc_634572338206_item	2773657	et	3	main
seitse	doc_634572338206_item	2773660	et	3	main
vahetus	doc_634572338206_item	2773672	et	4	main
oli	doc_634572338206_item	2773673	et	3	main
huvitav	doc_634572338206_item	2773685	et	4	main
ja	doc_634572338206_item	2773686	et	3	main
jagasite	doc_634572338208_item	2773939	et	3	main
noor	doc_634572338208_item	2773940	et	3	main
need	doc_634572338208_item	2773947	et	3	main
töötada	doc_634572338208_item	2773964	et	3	main
normaalset	doc_634572338208_item	2773966	et	3	main
minu	doc_634572338208_item	2773974	et	3	main
ei	doc_634572338208_item	2773977	et	4	main
huvita	doc_634572338208_item	2773978	et	4	main
mis	doc_634572338208_item	2774007	et	4	main
hooli	doc_634572338208_item	2774028	et	4	main
ja	doc_634572338208_item	2774038	et	3	main
see	doc_634572338208_item	2774044	et	3	main
teiega	doc_634572338208_item	2774050	et	3	main
sotsiaaltöötaja	doc_634572338208_item	2774066	et	4	main
ja	doc_634572338208_item	2774067	et	3	main
ei	doc_634572338208_item	2774086	et	4	main
hakkavad	doc_634572338208_item	2774123	et	4	main
välismaal	doc_634572338208_item	2774125	et	4	main
kus	doc_634572338208_item	2774126	et	3	main
palk	doc_634572338208_item	2774127	et	3	main
on	doc_634572338208_item	2774139	et	4	main
et	doc_634572338208_item	2774145	et	3	main
rühm	doc_634572338208_item	2774147	et	3	main
tiina	doc_634572338209_item	2774158	et	4	main
lugupeetud	doc_634572338209_item	2774164	et	4	main
olen	doc_634572338209_item	2774168	et	3	main
teie	doc_634572338209_item	2774172	et	4	main
leidsin	doc_634572338209_item	2774175	et	3	main
tea	doc_634572338209_item	2774205	et	4	main
koos	doc_634572338209_item	2774214	et	4	main
riigieksamite	doc_634572338209_item	2774215	et	3	main
loteriiga	doc_634572338209_item	2774216	et	3	main
see	doc_634572338209_item	2774217	et	3	main
punktidega	doc_634572338209_item	2774222	et	3	main
neil	doc_634572338209_item	2774226	et	4	main
oli	doc_634572338206_item	2773626	et	3	main
lossis	doc_634572338206_item	2773628	et	4	main
me	doc_634572338206_item	2773629	et	4	main
mängisime	doc_634572338206_item	2773630	et	3	main
meie	doc_634572338206_item	2773640	et	4	main
mulle	doc_634572338206_item	2773653	et	4	main
tuletada	doc_634572338206_item	2773656	et	3	main
reisi	doc_634572338206_item	2773658	et	4	main
päeva	doc_634572338206_item	2773661	et	4	main
mööda	doc_634572338206_item	2773665	et	4	main
kahju	doc_634572338206_item	2773667	et	4	main
hollandist	doc_634572338206_item	2773668	et	4	main
keeles	doc_634572338206_item	2773677	et	4	main
ja	doc_634572338206_item	2773678	et	3	main
teise	doc_634572338206_item	2773680	et	4	main
kultuuriga	doc_634572338206_item	2773681	et	4	main
see	doc_634572338206_item	2773682	et	3	main
oli	doc_634572338206_item	2773683	et	3	main
väga	doc_634572338206_item	2773684	et	3	main
sain	doc_634572338206_item	2773692	et	3	main
võimaluse	doc_634572338206_item	2773694	et	3	main
põlvkond	doc_634572338208_item	2773921	et	3	main
see	doc_634572338206_item	2773671	et	3	main
inglise	doc_634572338206_item	2773676	et	4	main
unustamatu	doc_634572338206_item	2773687	et	4	main
kogemus	doc_634572338206_item	2773688	et	3	main
et	doc_634572338206_item	2773691	et	3	main
eesti	doc_634572338208_item	2773922	et	4	main
kirjutan	doc_634572338208_item	2773924	et	3	main
põlvkonna	doc_634572338208_item	2773941	et	4	main
kolmeks	doc_634572338208_item	2773942	et	4	main
elada	doc_634572338208_item	2773951	et	3	main
rohkem	doc_634572338208_item	2773956	et	4	main
olen	doc_634572338208_item	2773957	et	3	main
teiega	doc_634572338208_item	2773958	et	3	main
nõus	doc_634572338208_item	2773959	et	4	main
arvamus	doc_634572338208_item	2773891	et	3	main
arvamuse	doc_634572338208_item	2773892	et	3	main
eesti	doc_634572338208_item	2773893	et	4	main
ekspressi	doc_634572338208_item	2773894	et	4	main
toimetaja	doc_634572338208_item	2773895	et	4	main
tiina	doc_634572338208_item	2773896	et	4	main
kaalepi	doc_634572338208_item	2773897	et	4	main
artikli	doc_634572338208_item	2773898	et	3	main
kohtaarikkel	doc_634572338208_item	2773899	et	4	main
vt	doc_634572338208_item	2773900	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338208_item	2773901	et	4	main
lp	doc_634572338208_item	2773902	et	4	main
tiina	doc_634572338208_item	2773903	et	4	main
kaalepp	doc_634572338208_item	2773904	et	4	main
minu	doc_634572338208_item	2773905	et	3	main
nimi	doc_634572338208_item	2773906	et	3	main
on	doc_634572338208_item	2773907	et	4	main
x	doc_634572338208_item	2773908	et	4	main
ma	doc_634572338208_item	2773909	et	3	main
õppin	doc_634572338208_item	2773910	et	4	main
tallinna	doc_634572338208_item	2773911	et	4	main
tehnika	doc_634572338208_item	2773912	et	4	main
ülikoolis	doc_634572338208_item	2773913	et	4	main
paar	doc_634572338208_item	2773914	et	3	main
nädalat	doc_634572338208_item	2773915	et	3	main
tagasi	doc_634572338208_item	2773916	et	3	main
lugesin	doc_634572338208_item	2773917	et	3	main
teie	doc_634572338208_item	2773918	et	4	main
artiklit	doc_634572338208_item	2773919	et	3	main
vähenõudlike	doc_634572338208_item	2773920	et	3	main
ekspressis	doc_634572338208_item	2773923	et	4	main
et	doc_634572338208_item	2773927	et	3	main
minule	doc_634572338208_item	2773928	et	3	main
väga	doc_634572338208_item	2773929	et	3	main
meeldis	doc_634572338208_item	2773930	et	3	main
rühmaks	doc_634572338208_item	2773943	et	4	main
kes	doc_634572338208_item	2773948	et	4	main
inimesi	doc_634572338208_item	2773953	et	4	main
on	doc_634572338208_item	2773954	et	4	main
tahavad	doc_634572338208_item	2773962	et	3	main
saada	doc_634572338208_item	2773965	et	4	main
meelest	doc_634572338208_item	2773975	et	4	main
neid	doc_634572338208_item	2773976	et	4	main
tähtsam	doc_634572338208_item	2773982	et	4	main
on	doc_634572338208_item	2773983	et	4	main
stabiilsus	doc_634572338208_item	2773984	et	4	main
just	doc_634572338208_item	2773993	et	3	main
garanteerivad	doc_634572338208_item	2773996	et	4	main
neist	doc_634572338208_item	2774008	et	4	main
saab	doc_634572338208_item	2774009	et	3	main
see	doc_634572338208_item	2774010	et	3	main
juhtub	doc_634572338208_item	2774011	et	3	main
riigieksamite	doc_634572338208_item	2774012	et	3	main
tõttu	doc_634572338208_item	2774013	et	4	main
see	doc_634572338208_item	2774014	et	3	main
nagu	doc_634572338208_item	2774016	et	3	main
on	doc_634572338208_item	2774015	et	4	main
loterii	doc_634572338208_item	2774017	et	4	main
noortele	doc_634572338208_item	2774018	et	3	main
tihti	doc_634572338208_item	2774019	et	3	main
nendest	doc_634572338208_item	2774020	et	4	main
ei	doc_634572338208_item	2774021	et	4	main
sest	doc_634572338208_item	2774025	et	4	main
nad	doc_634572338208_item	2774026	et	3	main
sellest	doc_634572338208_item	2774032	et	4	main
et	doc_634572338208_item	2774033	et	3	main
oleks	doc_634572338208_item	2774034	et	3	main
koht	doc_634572338208_item	2774035	et	3	main
loodan	doc_634572338208_item	2774042	et	3	main
ei	doc_634572338208_item	2774055	et	4	main
midagi	doc_634572338208_item	2774058	et	4	main
eriti	doc_634572338208_item	2774059	et	3	main
head	doc_634572338208_item	2774060	et	4	main
kolmas	doc_634572338208_item	2774061	et	3	main
rühm	doc_634572338208_item	2774062	et	3	main
need	doc_634572338208_item	2774063	et	3	main
et	doc_634572338208_item	2774079	et	3	main
see	doc_634572338208_item	2774080	et	3	main
toimu	doc_634572338208_item	2774082	et	4	main
sest	doc_634572338208_item	2774083	et	4	main
need	doc_634572338208_item	2774084	et	3	main
erialad	doc_634572338208_item	2774085	et	3	main
liiga	doc_634572338208_item	2774092	et	4	main
sellega	doc_634572338208_item	2774096	et	3	main
et	doc_634572338208_item	2774097	et	3	main
artid	doc_634572338208_item	2774098	et	4	main
parimate	doc_634572338208_item	2774150	et	4	main
arvamuse	doc_634572338209_item	2774154	et	3	main
artikli	doc_634572338209_item	2774160	et	3	main
kohtaarikkel	doc_634572338209_item	2774161	et	4	main
ja	doc_634572338209_item	2774174	et	3	main
ülikoolidesse	doc_634572338209_item	2774199	et	3	main
isegi	doc_634572338209_item	2774206	et	4	main
umbkaudu	doc_634572338209_item	2774207	et	3	main
mitte	doc_634572338209_item	2774208	et	3	main
see	doc_634572338209_item	2774209	et	3	main
kaine	doc_634572338209_item	2774218	et	4	main
saab	doc_634572338209_item	2774224	et	3	main
minna	doc_634572338209_item	2774225	et	3	main
sellest	doc_634572338208_item	2773937	et	4	main
esimene	doc_634572338208_item	2773944	et	3	main
teie	doc_634572338208_item	2773945	et	4	main
tahavad	doc_634572338208_item	2773949	et	3	main
rahulikult	doc_634572338208_item	2773963	et	4	main
liisida	doc_634572338208_item	2773968	et	4	main
auto	doc_634572338208_item	2773969	et	4	main
ja	doc_634572338208_item	2773970	et	3	main
soetada	doc_634572338208_item	2773971	et	3	main
risk	doc_634572338208_item	2773979	et	3	main
ja	doc_634572338208_item	2773980	et	3	main
kõige	doc_634572338208_item	2773981	et	4	main
rahu	doc_634572338208_item	2773985	et	4	main
arvan	doc_634572338208_item	2773986	et	3	main
et	doc_634572338208_item	2773987	et	3	main
see	doc_634572338208_item	2773988	et	3	main
rühm	doc_634572338208_item	2773989	et	3	main
on	doc_634572338208_item	2773990	et	4	main
sellised	doc_634572338208_item	2773994	et	4	main
neid	doc_634572338208_item	2774003	et	4	main
kes	doc_634572338208_item	2774004	et	4	main
ei	doc_634572338208_item	2774005	et	4	main
tule	doc_634572338208_item	2774022	et	4	main
head	doc_634572338208_item	2774023	et	4	main
spetsialistid	doc_634572338208_item	2774024	et	3	main
alast	doc_634572338208_item	2774029	et	4	main
vaid	doc_634572338208_item	2774030	et	3	main
ainult	doc_634572338208_item	2774031	et	4	main
käia	doc_634572338208_item	2774037	et	4	main
et	doc_634572338208_item	2774043	et	3	main
rühm	doc_634572338208_item	2774045	et	3	main
väheneb	doc_634572338208_item	2774047	et	3	main
olen	doc_634572338208_item	2774049	et	3	main
kujuta	doc_634572338208_item	2774056	et	4	main
keskonnakaitsja	doc_634572338208_item	2774068	et	4	main
oleks	doc_634572338208_item	2774074	et	3	main
kindel	doc_634572338208_item	2774078	et	3	main
palk	doc_634572338208_item	2774090	et	3	main
olen	doc_634572338208_item	2774094	et	3	main
nõus	doc_634572338208_item	2774095	et	4	main
paljud	doc_634572338208_item	2774121	et	3	main
teie	doc_634572338208_item	2774135	et	4	main
arvamusega	doc_634572338208_item	2774136	et	3	main
nõus	doc_634572338208_item	2774137	et	4	main
mul	doc_634572338208_item	2774138	et	3	main
kuidas	doc_634572338208_item	2774142	et	3	main
soovidega	doc_634572338208_item	2774151	et	3	main
arvamus	doc_634572338209_item	2774153	et	3	main
eesti	doc_634572338209_item	2774155	et	4	main
tiina	doc_634572338209_item	2774165	et	4	main
teie	doc_634572338209_item	2774169	et	4	main
on	doc_634572338209_item	2774210	et	4	main
uus	doc_634572338209_item	2774211	et	3	main
arvestus	doc_634572338209_item	2774219	et	4	main
kuhu	doc_634572338209_item	2774220	et	3	main
just	doc_634572338209_item	2774253	et	3	main
kahju	doc_634572338209_item	2774258	et	4	main
ei	doc_634572338209_item	2774261	et	4	main
ole	doc_634572338209_item	2774262	et	4	main
või	doc_634572338209_item	2774277	et	4	main
ei	doc_634572338209_item	2774283	et	4	main
teie	doc_634572338208_item	2773938	et	4	main
arvates	doc_634572338208_item	2773946	et	4	main
rahulikult	doc_634572338208_item	2773950	et	4	main
selliseid	doc_634572338208_item	2773952	et	4	main
kõige	doc_634572338208_item	2773955	et	4	main
need	doc_634572338208_item	2773960	et	3	main
väike	doc_634572338208_item	2773972	et	4	main
tulevik	doc_634572338208_item	2773992	et	3	main
inimesed	doc_634572338208_item	2773995	et	3	main
rahu	doc_634572338208_item	2773997	et	4	main
meie	doc_634572338208_item	2773998	et	4	main
maailmas	doc_634572338208_item	2773999	et	3	main
teine	doc_634572338208_item	2774000	et	3	main
rühm	doc_634572338208_item	2774001	et	3	main
on	doc_634572338208_item	2774002	et	4	main
tea	doc_634572338208_item	2774006	et	4	main
ei	doc_634572338208_item	2774027	et	4	main
kus	doc_634572338208_item	2774036	et	3	main
palk	doc_634572338208_item	2774040	et	3	main
kes	doc_634572338208_item	2774064	et	4	main
räägivad	doc_634572338208_item	2774065	et	3	main
neid	doc_634572338208_item	2774073	et	4	main
ma	doc_634572338208_item	2774076	et	3	main
olen	doc_634572338208_item	2774077	et	3	main
ole	doc_634572338208_item	2774087	et	4	main
populaarsed	doc_634572338208_item	2774088	et	3	main
on	doc_634572338208_item	2774091	et	4	main
noored	doc_634572338208_item	2773961	et	3	main
palka	doc_634572338208_item	2773967	et	4	main
kodu	doc_634572338208_item	2773973	et	4	main
meie	doc_634572338208_item	2773991	et	4	main
mingi	doc_634572338208_item	2774039	et	4	main
saata	doc_634572338208_item	2774041	et	3	main
tulevikus	doc_634572338208_item	2774046	et	4	main
tulevikus	doc_634572338208_item	2774048	et	4	main
nõus	doc_634572338208_item	2774051	et	4	main
et	doc_634572338208_item	2774052	et	3	main
see	doc_634572338208_item	2774053	et	3	main
valdkond	doc_634572338208_item	2774054	et	3	main
endast	doc_634572338208_item	2774057	et	4	main
ametist	doc_634572338208_item	2774069	et	3	main
teie	doc_634572338208_item	2774070	et	4	main
tahate	doc_634572338208_item	2774071	et	3	main
et	doc_634572338208_item	2774072	et	3	main
rohkem	doc_634572338208_item	2774075	et	4	main
ei	doc_634572338208_item	2774081	et	4	main
ja	doc_634572338208_item	2774089	et	3	main
väike	doc_634572338208_item	2774093	et	4	main
peavad	doc_634572338208_item	2774099	et	4	main
oma	doc_634572338208_item	2774100	et	4	main
töö	doc_634572338208_item	2774101	et	4	main
eest	doc_634572338208_item	2774102	et	4	main
saama	doc_634572338208_item	2774103	et	4	main
palju	doc_634572338208_item	2774104	et	4	main
rohkem	doc_634572338208_item	2774105	et	4	main
raha	doc_634572338208_item	2774106	et	4	main
kui	doc_634572338208_item	2774107	et	3	main
täna	doc_634572338208_item	2774108	et	4	main
tänapäevas	doc_634572338208_item	2774109	et	3	main
see	doc_634572338208_item	2774110	et	3	main
on	doc_634572338208_item	2774111	et	4	main
suur	doc_634572338208_item	2774112	et	3	main
probleem	doc_634572338208_item	2774113	et	3	main
meie	doc_634572338208_item	2774114	et	4	main
riigis	doc_634572338208_item	2774115	et	3	main
varsti	doc_634572338208_item	2774116	et	3	main
võib	doc_634572338208_item	2774117	et	3	main
juhtuda	doc_634572338208_item	2774118	et	3	main
nii	doc_634572338208_item	2774119	et	3	main
et	doc_634572338208_item	2774120	et	3	main
lõpuks	doc_634572338208_item	2774130	et	4	main
tahan	doc_634572338208_item	2774131	et	3	main
kirjutada	doc_634572338208_item	2774132	et	3	main
et	doc_634572338208_item	2774133	et	3	main
olen	doc_634572338208_item	2774134	et	3	main
küsimus	doc_634572338208_item	2774141	et	4	main
teha	doc_634572338208_item	2774143	et	3	main
teine	doc_634572338208_item	2774146	et	3	main
hakkaks	doc_634572338208_item	2774148	et	3	main
kaalepi	doc_634572338209_item	2774159	et	4	main
kaalep	doc_634572338209_item	2774166	et	4	main
austaja	doc_634572338209_item	2774170	et	4	main
artikli	doc_634572338209_item	2774173	et	3	main
astumiseni	doc_634572338209_item	2774200	et	4	main
aega	doc_634572338209_item	2774201	et	4	main
aga	doc_634572338209_item	2774202	et	3	main
nad	doc_634572338209_item	2774203	et	3	main
ei	doc_634572338209_item	2774204	et	4	main
tulnud	doc_634572338209_item	2774213	et	4	main
nende	doc_634572338209_item	2774221	et	4	main
üldse	doc_634572338209_item	2774223	et	3	main
arstid	doc_634572338208_item	2774122	et	4	main
töötama	doc_634572338208_item	2774124	et	3	main
on	doc_634572338208_item	2774128	et	4	main
normaalne	doc_634572338208_item	2774129	et	3	main
üks	doc_634572338208_item	2774140	et	3	main
nii	doc_634572338208_item	2774144	et	3	main
vähenema	doc_634572338208_item	2774149	et	3	main
x	doc_634572338208_item	2774152	et	4	main
ekspressi	doc_634572338209_item	2774156	et	4	main
toimetaja	doc_634572338209_item	2774157	et	4	main
vt	doc_634572338209_item	2774162	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338209_item	2774163	et	4	main
ma	doc_634572338209_item	2774167	et	3	main
lugesin	doc_634572338209_item	2774171	et	3	main
palju	doc_634572338209_item	2774176	et	4	main
huvatavat	doc_634572338209_item	2774177	et	4	main
mõniga	doc_634572338209_item	2774178	et	4	main
väitega	doc_634572338209_item	2774179	et	3	main
ma	doc_634572338209_item	2774180	et	3	main
olen	doc_634572338209_item	2774181	et	3	main
nõus	doc_634572338209_item	2774182	et	4	main
teie	doc_634572338209_item	2774183	et	4	main
artiklis	doc_634572338209_item	2774184	et	3	main
on	doc_634572338209_item	2774185	et	4	main
kirjeldatud	doc_634572338209_item	2774186	et	4	main
üks	doc_634572338209_item	2774187	et	3	main
rühm	doc_634572338209_item	2774188	et	3	main
kes	doc_634572338209_item	2774189	et	4	main
ei	doc_634572338209_item	2774190	et	4	main
mis	doc_634572338209_item	2774192	et	4	main
neist	doc_634572338209_item	2774193	et	4	main
saab	doc_634572338209_item	2774194	et	3	main
vaid	doc_634572338209_item	2774195	et	3	main
mõni	doc_634572338209_item	2774196	et	3	main
tea	doc_634572338209_item	2774191	et	4	main
nädal	doc_634572338209_item	2774197	et	3	main
on	doc_634572338209_item	2774198	et	4	main
asi	doc_634572338209_item	2774212	et	4	main
läksid	doc_634572338209_item	2774233	et	4	main
millele	doc_634572338209_item	2774236	et	3	main
rajada	doc_634572338209_item	2774238	et	3	main
on	doc_634572338209_item	2774252	et	4	main
on	doc_634572338209_item	2774256	et	4	main
praegu	doc_634572338209_item	2774259	et	3	main
ei	doc_634572338209_item	2774267	et	4	main
kogu	doc_634572338209_item	2774272	et	4	main
nad	doc_634572338209_item	2774274	et	3	main
mängivad	doc_634572338209_item	2774275	et	4	main
sihitult	doc_634572338209_item	2774279	et	4	main
eesmärgi	doc_634572338209_item	2774285	et	4	main
inimene	doc_634572338209_item	2774286	et	3	main
teeb	doc_634572338209_item	2774287	et	3	main
oma	doc_634572338209_item	2774288	et	4	main
vaja	doc_634572338209_item	2774297	et	4	main
anda	doc_634572338209_item	2774298	et	3	main
nortele	doc_634572338209_item	2774299	et	4	main
nad	doc_634572338209_item	2774302	et	3	main
oleksid	doc_634572338209_item	2774303	et	4	main
huvitatud	doc_634572338209_item	2774304	et	4	main
juba	doc_634572338209_item	2774305	et	3	main
siis	doc_634572338209_item	2774306	et	3	main
kui	doc_634572338209_item	2774307	et	3	main
nad	doc_634572338209_item	2774308	et	3	main
õpivad	doc_634572338209_item	2774309	et	3	main
algkoolis	doc_634572338209_item	2774310	et	4	main
teine	doc_634572338209_item	2774311	et	3	main
rühm	doc_634572338209_item	2774312	et	3	main
on	doc_634572338209_item	2774313	et	4	main
inemesed	doc_634572338209_item	2774314	et	4	main
kes	doc_634572338209_item	2774315	et	4	main
tahaks	doc_634572338209_item	2774316	et	3	main
töötada	doc_634572338209_item	2774317	et	3	main
rahulikult	doc_634572338209_item	2774318	et	4	main
rabelemata	doc_634572338209_item	2774319	et	4	main
ja	doc_634572338209_item	2774320	et	3	main
normaalselt	doc_634572338209_item	2774323	et	4	main
vanemate	doc_634572338209_item	2774335	et	4	main
rapsimisi	doc_634572338209_item	2774336	et	4	main
korrata	doc_634572338209_item	2774341	et	4	main
poed	doc_634572338209_item	2774347	et	4	main
tühjad	doc_634572338209_item	2774349	et	3	main
ja	doc_634572338209_item	2774350	et	3	main
kodud	doc_634572338209_item	2774351	et	3	main
vaesed	doc_634572338209_item	2774352	et	4	main
väga	doc_634572338209_item	2774361	et	3	main
palju	doc_634572338209_item	2774362	et	4	main
on	doc_634572338209_item	2774371	et	4	main
laste	doc_634572338209_item	2774372	et	4	main
iga	doc_634572338209_item	2774384	et	4	main
sõnaga	doc_634572338209_item	2774385	et	3	main
sest	doc_634572338209_item	2774386	et	4	main
ma	doc_634572338209_item	2774387	et	3	main
mäletan	doc_634572338209_item	2774388	et	3	main
tavaliselt	doc_634572338209_item	2774391	et	4	main
rühmale	doc_634572338209_item	2774408	et	3	main
sest	doc_634572338209_item	2774413	et	4	main
stabiilsus	doc_634572338209_item	2774414	et	4	main
huvitavad	doc_634572338209_item	2774433	et	4	main
ja	doc_634572338209_item	2774434	et	3	main
tunnetuslikud	doc_634572338209_item	2774435	et	3	main
artiklid	doc_634572338209_item	2774436	et	3	main
abiturientidel	doc_634572338209_item	2774227	et	3	main
pole	doc_634572338209_item	2774228	et	3	main
midagi	doc_634572338209_item	2774235	et	4	main
märkasite	doc_634572338209_item	2774242	et	3	main
on	doc_634572338209_item	2774246	et	4	main
elu	doc_634572338209_item	2774248	et	4	main
näitab	doc_634572338209_item	2774249	et	3	main
et	doc_634572338209_item	2774250	et	3	main
aga	doc_634572338209_item	2774255	et	3	main
meeldib	doc_634572338209_item	2774271	et	3	main
arvutimängu	doc_634572338209_item	2774276	et	4	main
linna	doc_634572338209_item	2774281	et	4	main
kui	doc_634572338209_item	2774282	et	3	main
töid	doc_634572338209_item	2774289	et	3	main
huvitatud	doc_634572338209_item	2774292	et	4	main
huvi	doc_634572338209_item	2774300	et	4	main
et	doc_634572338209_item	2774301	et	3	main
palka	doc_634572338209_item	2774324	et	4	main
soetada	doc_634572338209_item	2774327	et	3	main
noored	doc_634572338209_item	2774331	et	3	main
18-aastased	doc_634572338209_item	2774343	et	4	main
vanemad	doc_634572338209_item	2774355	et	4	main
kes	doc_634572338209_item	2774356	et	4	main
sageli	doc_634572338209_item	2774357	et	3	main
kodune	doc_634572338209_item	2774365	et	4	main
idüll	doc_634572338209_item	2774366	et	3	main
ellu	doc_634572338209_item	2774379	et	4	main
ei	doc_634572338209_item	2774380	et	4	main
taheta	doc_634572338209_item	2774381	et	3	main
olen	doc_634572338209_item	2774382	et	3	main
sest	doc_634572338209_item	2774396	et	4	main
et	doc_634572338209_item	2774397	et	3	main
mulle	doc_634572338209_item	2774409	et	4	main
meeldib	doc_634572338209_item	2774410	et	3	main
elu	doc_634572338209_item	2774412	et	4	main
oma	doc_634572338209_item	2774421	et	4	main
kus	doc_634572338209_item	2774423	et	3	main
ma	doc_634572338209_item	2774424	et	3	main
ome	doc_634572338209_item	2774426	et	4	main
perega	doc_634572338209_item	2774427	et	3	main
loodan	doc_634572338209_item	2774428	et	3	main
et	doc_634572338209_item	2774429	et	3	main
et	doc_634572338209_item	2774439	et	3	main
palju	doc_634572338209_item	2774448	et	4	main
võimalusi	doc_634572338209_item	2774449	et	3	main
eestis	doc_634572338209_item	2774450	et	3	main
leida	doc_634572338209_item	2774454	et	3	main
peale	doc_634572338209_item	2774229	et	4	main
sisetunde	doc_634572338209_item	2774230	et	4	main
kuidas	doc_634572338209_item	2774231	et	3	main
eksamid	doc_634572338209_item	2774232	et	3	main
tulevikuplaane	doc_634572338209_item	2774237	et	3	main
te	doc_634572338209_item	2774240	et	4	main
see	doc_634572338209_item	2774244	et	3	main
suur	doc_634572338209_item	2774247	et	3	main
see	doc_634572338209_item	2774251	et	3	main
huvialasid	doc_634572338209_item	2774263	et	4	main
ja	doc_634572338209_item	2774264	et	3	main
hobisid	doc_634572338209_item	2774265	et	3	main
nad	doc_634572338209_item	2774266	et	3	main
mis	doc_634572338209_item	2774269	et	4	main
kõndivad	doc_634572338209_item	2774278	et	4	main
ole	doc_634572338209_item	2774284	et	4	main
halvem	doc_634572338209_item	2774290	et	4	main
kui	doc_634572338209_item	2774291	et	3	main
selle	doc_634572338209_item	2774294	et	4	main
täiesti	doc_634572338209_item	2774322	et	3	main
liisida	doc_634572338209_item	2774325	et	4	main
oma	doc_634572338209_item	2774334	et	4	main
seda	doc_634572338209_item	2774340	et	3	main
kui	doc_634572338209_item	2774346	et	3	main
teistkümnetunniseid	doc_634572338209_item	2774359	et	4	main
kodus	doc_634572338209_item	2774363	et	4	main
silmis	doc_634572338209_item	2774373	et	4	main
ihaldusväärne	doc_634572338209_item	2774374	et	3	main
ja	doc_634572338209_item	2774375	et	3	main
suurt	doc_634572338209_item	2774376	et	3	main
võitlust	doc_634572338209_item	2774377	et	3	main
oma	doc_634572338209_item	2774378	et	4	main
nõus	doc_634572338209_item	2774383	et	4	main
aega	doc_634572338209_item	2774390	et	4	main
töötasid	doc_634572338209_item	2774399	et	4	main
väga	doc_634572338209_item	2774400	et	3	main
palju	doc_634572338209_item	2774401	et	4	main
on	doc_634572338209_item	2774415	et	4	main
hüvang	doc_634572338209_item	2774416	et	3	main
ma	doc_634572338209_item	2774417	et	3	main
tahaksin	doc_634572338209_item	2774418	et	3	main
just	doc_634572338209_item	2774419	et	3	main
ka	doc_634572338209_item	2774420	et	3	main
tegelikult	doc_634572338209_item	2774234	et	4	main
ja	doc_634572338209_item	2774239	et	3	main
õigesti	doc_634572338209_item	2774241	et	3	main
et	doc_634572338209_item	2774243	et	3	main
rühm	doc_634572338209_item	2774245	et	3	main
nii	doc_634572338209_item	2774254	et	3	main
väga	doc_634572338209_item	2774257	et	3	main
noortel	doc_634572338209_item	2774260	et	3	main
teavad	doc_634572338209_item	2774268	et	3	main
nendele	doc_634572338209_item	2774270	et	4	main
vabaaega	doc_634572338209_item	2774273	et	4	main
mööda	doc_634572338209_item	2774280	et	4	main
inimene	doc_634572338209_item	2774293	et	3	main
pärast	doc_634572338209_item	2774295	et	4	main
on	doc_634572338209_item	2774296	et	4	main
saada	doc_634572338209_item	2774321	et	4	main
kodu	doc_634572338209_item	2774329	et	4	main
90-ndatel	doc_634572338209_item	2774337	et	4	main
ega	doc_634572338209_item	2774338	et	3	main
tänased	doc_634572338209_item	2774342	et	3	main
tegid	doc_634572338209_item	2774358	et	4	main
tööpäevi	doc_634572338209_item	2774360	et	4	main
mida	doc_634572338209_item	2774367	et	4	main
lastena	doc_634572338209_item	2774368	et	3	main
ei	doc_634572338209_item	2774369	et	4	main
seda	doc_634572338209_item	2774389	et	3	main
ma	doc_634572338209_item	2774392	et	3	main
olin	doc_634572338209_item	2774393	et	3	main
kodus	doc_634572338209_item	2774394	et	4	main
üksi	doc_634572338209_item	2774395	et	4	main
ma	doc_634572338209_item	2774402	et	3	main
võin	doc_634572338209_item	2774403	et	3	main
öelda	doc_634572338209_item	2774404	et	4	main
et	doc_634572338209_item	2774405	et	3	main
kuulun	doc_634572338209_item	2774406	et	3	main
on	doc_634572338209_item	2774431	et	4	main
niisugused	doc_634572338209_item	2774432	et	3	main
on	doc_634572338209_item	2774447	et	4	main
auto	doc_634572338209_item	2774326	et	4	main
väike	doc_634572338209_item	2774328	et	4	main
need	doc_634572338209_item	2774330	et	3	main
on	doc_634572338209_item	2774332	et	4	main
näinud	doc_634572338209_item	2774333	et	4	main
taha	doc_634572338209_item	2774339	et	4	main
olid	doc_634572338209_item	2774344	et	4	main
põnnid	doc_634572338209_item	2774345	et	3	main
olid	doc_634572338209_item	2774348	et	4	main
vaevalt	doc_634572338209_item	2774353	et	4	main
et	doc_634572338209_item	2774354	et	3	main
olid	doc_634572338209_item	2774364	et	4	main
kogetud	doc_634572338209_item	2774370	et	4	main
vanemad	doc_634572338209_item	2774398	et	4	main
sellele	doc_634572338209_item	2774407	et	4	main
stabiilne	doc_634572338209_item	2774411	et	3	main
noored	doc_634572338209_item	2774440	et	3	main
on	doc_634572338209_item	2774459	et	4	main
erimaja	doc_634572338209_item	2774422	et	4	main
elaksin	doc_634572338209_item	2774425	et	3	main
teil	doc_634572338209_item	2774430	et	4	main
tahaksin	doc_634572338209_item	2774438	et	3	main
oma	doc_634572338209_item	2774442	et	4	main
tulekust	doc_634572338209_item	2774443	et	4	main
juba	doc_634572338209_item	2774444	et	3	main
algkoolist	doc_634572338209_item	2774445	et	4	main
praegu	doc_634572338209_item	2774446	et	3	main
eriti	doc_634572338209_item	2774455	et	3	main
kõik	doc_634572338209_item	2774457	et	4	main
teed	doc_634572338209_item	2774458	et	4	main
avatud	doc_634572338209_item	2774460	et	4	main
veel	doc_634572338209_item	2774437	et	4	main
mõtleksid	doc_634572338209_item	2774441	et	4	main
kust	doc_634572338209_item	2774451	et	4	main
võib	doc_634572338209_item	2774452	et	3	main
tööst	doc_634572338209_item	2774453	et	3	main
tallinnas	doc_634572338209_item	2774456	et	4	main
arvamus	doc_634572338212_item	2774895	et	3	main
tiina	doc_634572338212_item	2774900	et	4	main
ei	doc_634572338212_item	2774926	et	4	main
verd	doc_634572338212_item	2774940	et	3	main
kes	doc_634572338212_item	2774953	et	4	main
ja	doc_634572338212_item	2774963	et	3	main
aasta	doc_634572338212_item	2774977	et	4	main
seas	doc_634572338212_item	2774979	et	4	main
vajab	doc_634572338212_item	2774985	et	3	main
muuta	doc_634572338212_item	2774992	et	4	main
paremuse	doc_634572338212_item	2775003	et	4	main
on	doc_634572338212_item	2775007	et	4	main
ise	doc_634572338212_item	2775014	et	4	main
om	doc_634572338212_item	2775018	et	4	main
seas	doc_634572338212_item	2775033	et	4	main
on	doc_634572338212_item	2775034	et	4	main
oma	doc_634572338212_item	2775052	et	4	main
artiklis	doc_634572338212_item	2775053	et	3	main
lugupeetud	doc_634572338212_item	2774906	et	4	main
selle	doc_634572338212_item	2774911	et	4	main
abiturient	doc_634572338212_item	2774913	et	3	main
lugenud	doc_634572338212_item	2774915	et	4	main
teie	doc_634572338212_item	2774916	et	4	main
teie	doc_634572338212_item	2774922	et	4	main
tänapäeval	doc_634572338212_item	2774925	et	3	main
uut	doc_634572338212_item	2774939	et	3	main
vaja	doc_634572338212_item	2774950	et	4	main
selliseid	doc_634572338212_item	2774951	et	4	main
teaksid	doc_634572338212_item	2774958	et	4	main
midagi	doc_634572338212_item	2774991	et	4	main
poole	doc_634572338212_item	2775004	et	4	main
probleem	doc_634572338212_item	2775006	et	3	main
minu	doc_634572338212_item	2775008	et	3	main
jaoks	doc_634572338212_item	2775009	et	4	main
aktuaalne	doc_634572338212_item	2775011	et	3	main
ka	doc_634572338212_item	2775020	et	3	main
nõus	doc_634572338212_item	2775031	et	4	main
abiturientide	doc_634572338212_item	2775032	et	3	main
olemas	doc_634572338212_item	2775043	et	4	main
passiivsete	doc_634572338212_item	2775044	et	3	main
mida	doc_634572338212_item	2775059	et	4	main
nende	doc_634572338212_item	2775067	et	4	main
leida	doc_634572338212_item	2775071	et	3	main
töökoha	doc_634572338212_item	2775073	et	4	main
teenida	doc_634572338212_item	2775076	et	3	main
raha	doc_634572338212_item	2775078	et	4	main
auto	doc_634572338212_item	2775089	et	4	main
riided	doc_634572338212_item	2775090	et	3	main
jne	doc_634572338212_item	2775091	et	4	main
selleks	doc_634572338212_item	2775122	et	4	main
valmis	doc_634572338212_item	2775123	et	4	main
tormavad	doc_634572338212_item	2775147	et	4	main
nendest	doc_634572338212_item	2775152	et	4	main
organisatsioonide	doc_634572338212_item	2775157	et	3	main
pidevalt	doc_634572338212_item	2775162	et	4	main
midagi	doc_634572338212_item	2775163	et	4	main
uut	doc_634572338212_item	2775164	et	3	main
on	doc_634572338212_item	2775170	et	4	main
seas	doc_634572338212_item	2775174	et	4	main
noorus	doc_634572338212_item	2775176	et	4	main
teebki	doc_634572338212_item	2775177	et	3	main
neid	doc_634572338212_item	2775178	et	4	main
on	doc_634572338212_item	2775219	et	4	main
võrreldes	doc_634572338212_item	2775222	et	3	main
seetõttu	doc_634572338212_item	2775229	et	3	main
arvamuse	doc_634572338212_item	2774896	et	3	main
eesti	doc_634572338212_item	2774897	et	4	main
vt	doc_634572338212_item	2774904	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338212_item	2774905	et	4	main
artikli	doc_634572338212_item	2774917	et	3	main
vähenõudlike	doc_634572338212_item	2774918	et	3	main
põlvkond	doc_634572338212_item	2774919	et	3	main
selles	doc_634572338212_item	2774920	et	4	main
teile	doc_634572338212_item	2774910	et	4	main
olen	doc_634572338212_item	2774914	et	3	main
väidate	doc_634572338212_item	2774923	et	3	main
ole	doc_634572338212_item	2774927	et	4	main
sugugi	doc_634572338212_item	2774929	et	4	main
kes	doc_634572338212_item	2774942	et	4	main
tahavad	doc_634572338212_item	2774943	et	3	main
ja	doc_634572338212_item	2774944	et	3	main
saavadki	doc_634572338212_item	2774945	et	4	main
ministriks	doc_634572338212_item	2774946	et	3	main
ja	doc_634572338212_item	2774947	et	3	main
peaministriks	doc_634572338212_item	2774948	et	3	main
inimesi	doc_634572338212_item	2774952	et	4	main
mittetoimiva	doc_634572338212_item	2774956	et	3	main
mis	doc_634572338212_item	2774959	et	4	main
vead	doc_634572338212_item	2774960	et	4	main
tänavu	doc_634572338212_item	2774976	et	3	main
abiturientide	doc_634572338212_item	2774978	et	3	main
ei	doc_634572338212_item	2774980	et	4	main
ekspressi	doc_634572338212_item	2774898	et	4	main
toimetaja	doc_634572338212_item	2774899	et	4	main
kaalepi	doc_634572338212_item	2774901	et	4	main
artikli	doc_634572338212_item	2774902	et	3	main
kohtaarikkel	doc_634572338212_item	2774903	et	4	main
tiina	doc_634572338212_item	2774907	et	4	main
kaalep	doc_634572338212_item	2774908	et	4	main
kirjutab	doc_634572338212_item	2774909	et	3	main
aasta	doc_634572338212_item	2774912	et	4	main
artiklis	doc_634572338212_item	2774921	et	3	main
särtsu	doc_634572338212_item	2774938	et	4	main
neid	doc_634572338212_item	2774941	et	4	main
ümber	doc_634572338212_item	2774955	et	3	main
meditsiinisüsteemi	doc_634572338212_item	2774957	et	4	main
on	doc_634572338212_item	2774961	et	4	main
hariduses	doc_634572338212_item	2774962	et	3	main
selliseid	doc_634572338212_item	2774982	et	4	main
keda	doc_634572338212_item	2774983	et	4	main
ühiskond	doc_634572338212_item	2774984	et	3	main
on	doc_634572338212_item	2774987	et	4	main
passiivsed	doc_634572338212_item	2774988	et	3	main
ei	doc_634572338212_item	2774989	et	4	main
meie	doc_634572338212_item	2774993	et	4	main
lepivad	doc_634572338212_item	2774996	et	3	main
töökohtadega	doc_634572338212_item	2774999	et	3	main
ega	doc_634572338212_item	2775001	et	3	main
väga	doc_634572338212_item	2775010	et	3	main
kuna	doc_634572338212_item	2775012	et	3	main
sellepärast	doc_634572338212_item	2775016	et	3	main
kõigepealt	doc_634572338212_item	2775022	et	3	main
öelda	doc_634572338212_item	2775024	et	4	main
ma	doc_634572338212_item	2775026	et	3	main
hulka	doc_634572338212_item	2775045	et	4	main
kuuluvad	doc_634572338212_item	2775046	et	4	main
kindlasti	doc_634572338212_item	2775047	et	3	main
need	doc_634572338212_item	2775048	et	3	main
ei	doc_634572338212_item	2775056	et	4	main
saab	doc_634572338212_item	2775075	et	3	main
selleks	doc_634572338212_item	2775079	et	4	main
et	doc_634572338212_item	2775080	et	3	main
peret	doc_634572338212_item	2775081	et	3	main
pidada	doc_634572338212_item	2775082	et	4	main
ei	doc_634572338212_item	2775094	et	4	main
on	doc_634572338212_item	2775121	et	4	main
need	doc_634572338212_item	2775124	et	3	main
muuta	doc_634572338212_item	2775130	et	4	main
haridus-	doc_634572338212_item	2775133	et	3	main
või	doc_634572338212_item	2775137	et	4	main
on	doc_634572338212_item	2775141	et	4	main
inimesed	doc_634572338212_item	2775145	et	3	main
ministrid	doc_634572338212_item	2775154	et	3	main
inimesed	doc_634572338212_item	2775160	et	3	main
valdkonnas	doc_634572338212_item	2775167	et	4	main
kindalsti	doc_634572338212_item	2775171	et	4	main
abiturientide	doc_634572338212_item	2775173	et	3	main
kuna	doc_634572338212_item	2775175	et	3	main
ei	doc_634572338212_item	2775210	et	4	main
piisavalt	doc_634572338212_item	2775212	et	4	main
tarku	doc_634572338212_item	2775213	et	3	main
väike	doc_634572338212_item	2775220	et	4	main
et	doc_634572338212_item	2774924	et	3	main
abituriendid	doc_634572338212_item	2774928	et	3	main
ambitsioonikad	doc_634572338212_item	2774930	et	4	main
te	doc_634572338212_item	2774931	et	4	main
kirjutate	doc_634572338212_item	2774932	et	3	main
et	doc_634572338212_item	2774933	et	3	main
ühiskond	doc_634572338212_item	2774934	et	3	main
vajab	doc_634572338212_item	2774935	et	3	main
värskust	doc_634572338212_item	2774936	et	3	main
ja	doc_634572338212_item	2774937	et	3	main
on	doc_634572338212_item	2774949	et	4	main
teeksid	doc_634572338212_item	2774954	et	4	main
suudaksid	doc_634572338212_item	2774964	et	4	main
seda	doc_634572338212_item	2774965	et	3	main
muuta	doc_634572338212_item	2774966	et	4	main
võtaksid	doc_634572338212_item	2774967	et	4	main
avalikus	doc_634572338212_item	2774968	et	4	main
sektoris	doc_634572338212_item	2774969	et	3	main
jõuga	doc_634572338212_item	2774970	et	3	main
võtmepositsioone	doc_634572338212_item	2774971	et	3	main
sellega	doc_634572338212_item	2774972	et	3	main
teie	doc_634572338212_item	2774973	et	4	main
ütlete	doc_634572338212_item	2774974	et	3	main
et	doc_634572338212_item	2774975	et	3	main
ole	doc_634572338212_item	2774981	et	4	main
taha	doc_634572338212_item	2774990	et	4	main
keskmise	doc_634572338212_item	2774997	et	3	main
kokku	doc_634572338212_item	2775000	et	3	main
olen	doc_634572338212_item	2775013	et	3	main
abiturient	doc_634572338212_item	2775015	et	3	main
tahaks	doc_634572338212_item	2775017	et	3	main
arvamust	doc_634572338212_item	2775019	et	3	main
need	doc_634572338212_item	2774986	et	3	main
riigis	doc_634572338212_item	2774994	et	3	main
need	doc_634572338212_item	2774995	et	3	main
palgaga	doc_634572338212_item	2774998	et	3	main
püüdle	doc_634572338212_item	2775002	et	4	main
see	doc_634572338212_item	2775005	et	3	main
avaldada	doc_634572338212_item	2775021	et	3	main
tahaks	doc_634572338212_item	2775023	et	3	main
ei	doc_634572338212_item	2775027	et	4	main
ole	doc_634572338212_item	2775028	et	4	main
sellega	doc_634572338212_item	2775029	et	3	main
alati	doc_634572338212_item	2775035	et	4	main
nii	doc_634572338212_item	2775036	et	3	main
passiivseid	doc_634572338212_item	2775037	et	3	main
kellest	doc_634572338212_item	2775049	et	4	main
teie	doc_634572338212_item	2775050	et	4	main
kirjutasite	doc_634572338212_item	2775051	et	3	main
täpselt	doc_634572338212_item	2775058	et	4	main
jaoks	doc_634572338212_item	2775068	et	4	main
võimalus	doc_634572338212_item	2775070	et	3	main
piisavalt	doc_634572338212_item	2775077	et	4	main
vajalikku	doc_634572338212_item	2775086	et	4	main
nagu	doc_634572338212_item	2775087	et	3	main
korter	doc_634572338212_item	2775088	et	3	main
et	doc_634572338212_item	2775025	et	3	main
täielikult	doc_634572338212_item	2775030	et	4	main
kui	doc_634572338212_item	2775038	et	3	main
ka	doc_634572338212_item	2775039	et	3	main
väga	doc_634572338212_item	2775040	et	3	main
aktiivseid	doc_634572338212_item	2775041	et	3	main
inimesi	doc_634572338212_item	2775042	et	4	main
tea	doc_634572338212_item	2775057	et	4	main
on	doc_634572338212_item	2775066	et	4	main
vaid	doc_634572338212_item	2775069	et	3	main
ning	doc_634572338212_item	2775083	et	3	main
osta	doc_634572338212_item	2775084	et	4	main
sellised	doc_634572338212_item	2775092	et	4	main
hakka	doc_634572338212_item	2775095	et	4	main
kindlasti	doc_634572338212_item	2775096	et	3	main
avaliku	doc_634572338212_item	2775097	et	3	main
sektori	doc_634572338212_item	2775098	et	3	main
mitmesuguseid	doc_634572338212_item	2775099	et	3	main
võtmepositsiione	doc_634572338212_item	2775100	et	4	main
võtma	doc_634572338212_item	2775101	et	3	main
neil	doc_634572338212_item	2775102	et	4	main
ei	doc_634572338212_item	2775103	et	4	main
ole	doc_634572338212_item	2775104	et	4	main
seda	doc_634572338212_item	2775105	et	3	main
vaja	doc_634572338212_item	2775106	et	4	main
see	doc_634572338212_item	2775107	et	3	main
nõuab	doc_634572338212_item	2775108	et	3	main
julgust	doc_634572338212_item	2775109	et	4	main
ja	doc_634572338212_item	2775110	et	3	main
toob	doc_634572338212_item	2775111	et	3	main
kaasa	doc_634572338212_item	2775112	et	4	main
suuremaid	doc_634572338212_item	2775113	et	4	main
riske	doc_634572338212_item	2775114	et	3	main
siiski	doc_634572338212_item	2775115	et	4	main
on	doc_634572338212_item	2775116	et	4	main
kindlasti	doc_634572338212_item	2775117	et	3	main
selliseid	doc_634572338212_item	2775118	et	4	main
üliõpilasi	doc_634572338212_item	2775119	et	3	main
kes	doc_634572338212_item	2775120	et	4	main
suudavad	doc_634572338212_item	2775127	et	3	main
hoopis	doc_634572338212_item	2775138	et	3	main
need	doc_634572338212_item	2775140	et	3	main
särtsakad	doc_634572338212_item	2775142	et	3	main
vaprad	doc_634572338212_item	2775144	et	3	main
poole	doc_634572338212_item	2775150	et	4	main
ning	doc_634572338212_item	2775151	et	3	main
juhid	doc_634572338212_item	2775158	et	4	main
mõtlevad	doc_634572338212_item	2775161	et	4	main
selleseid	doc_634572338212_item	2775168	et	4	main
inimesi	doc_634572338212_item	2775169	et	4	main
palju	doc_634572338212_item	2775172	et	4	main
tuudengeid	doc_634572338212_item	2775217	et	4	main
ja	doc_634572338212_item	2775226	et	3	main
riikidega	doc_634572338212_item	2775228	et	3	main
ole	doc_634572338212_item	2775231	et	4	main
need	doc_634572338212_item	2775054	et	3	main
kes	doc_634572338212_item	2775055	et	4	main
nad	doc_634572338212_item	2775060	et	3	main
tahavad	doc_634572338212_item	2775061	et	3	main
elus	doc_634572338212_item	2775062	et	4	main
saavutada	doc_634572338212_item	2775063	et	3	main
ning	doc_634572338212_item	2775064	et	3	main
kõrgharidus	doc_634572338212_item	2775065	et	3	main
hea	doc_634572338212_item	2775072	et	4	main
kus	doc_634572338212_item	2775074	et	3	main
kõike	doc_634572338212_item	2775085	et	4	main
üliõpilased	doc_634572338212_item	2775093	et	3	main
soovivad	doc_634572338212_item	2775125	et	4	main
midagi	doc_634572338212_item	2775128	et	4	main
olgu	doc_634572338212_item	2775131	et	3	main
panga-	doc_634572338212_item	2775134	et	3	main
meditsiinisüsteem	doc_634572338212_item	2775136	et	3	main
tootearendus	doc_634572338212_item	2775139	et	3	main
ja	doc_634572338212_item	2775143	et	3	main
kes	doc_634572338212_item	2775146	et	4	main
aina	doc_634572338212_item	2775148	et	4	main
direktorid	doc_634572338212_item	2775155	et	3	main
mitmesuguste	doc_634572338212_item	2775156	et	3	main
need	doc_634572338212_item	2775159	et	3	main
eesti	doc_634572338212_item	2775218	et	4	main
teiste	doc_634572338212_item	2775223	et	4	main
võidelda	doc_634572338212_item	2775238	et	4	main
kokkuvõtteks	doc_634572338212_item	2775239	et	3	main
milleks	doc_634572338212_item	2775254	et	4	main
nad	doc_634572338212_item	2775255	et	3	main
õpivad	doc_634572338212_item	2775256	et	3	main
kes	doc_634572338212_item	2775264	et	4	main
palga	doc_634572338212_item	2775268	et	3	main
meditsiinisüsteemiga	doc_634572338212_item	2775271	et	3	main
siin	doc_634572338212_item	2775279	et	4	main
kohtaarikkel	doc_634572338213_item	2775296	et	4	main
kaalep	doc_634572338213_item	2775301	et	4	main
kirjutab	doc_634572338213_item	2775302	et	3	main
lugesin	doc_634572338213_item	2775306	et	3	main
kirjutate	doc_634572338213_item	2775316	et	3	main
taha	doc_634572338213_item	2775322	et	4	main
palju	doc_634572338213_item	2775333	et	4	main
töötama	doc_634572338213_item	2775334	et	3	main
ja	doc_634572338213_item	2775335	et	3	main
see	doc_634572338213_item	2775336	et	3	main
stimuleerib	doc_634572338213_item	2775337	et	3	main
noored	doc_634572338213_item	2775338	et	3	main
või	doc_634572338213_item	2775349	et	4	main
huvid	doc_634572338213_item	2775369	et	3	main
ta	doc_634572338213_item	2775371	et	4	main
ei	doc_634572338213_item	2775372	et	4	main
tohi	doc_634572338213_item	2775373	et	4	main
ajal	doc_634572338213_item	2775405	et	4	main
ragite	doc_634572338213_item	2775414	et	4	main
et	doc_634572338213_item	2775415	et	3	main
ja	doc_634572338212_item	2775126	et	3	main
ümber	doc_634572338212_item	2775129	et	3	main
see	doc_634572338212_item	2775132	et	3	main
või	doc_634572338212_item	2775135	et	4	main
ette	doc_634572338212_item	2775149	et	4	main
saavad	doc_634572338212_item	2775153	et	4	main
juurde	doc_634572338212_item	2775165	et	4	main
igas	doc_634572338212_item	2775166	et	3	main
nii	doc_634572338212_item	2775179	et	3	main
julgeteks	doc_634572338212_item	2775180	et	3	main
teisest	doc_634572338212_item	2775181	et	4	main
küljest	doc_634572338212_item	2775182	et	4	main
on	doc_634572338212_item	2775183	et	4	main
olemas	doc_634572338212_item	2775184	et	4	main
selline	doc_634572338212_item	2775185	et	4	main
probleem	doc_634572338212_item	2775186	et	3	main
et	doc_634572338212_item	2775187	et	3	main
targad	doc_634572338212_item	2775188	et	3	main
abituriendid	doc_634572338212_item	2775189	et	3	main
lahkuvad	doc_634572338212_item	2775190	et	4	main
eestist	doc_634572338212_item	2775191	et	3	main
ning	doc_634572338212_item	2775192	et	3	main
müüvad	doc_634572338212_item	2775193	et	4	main
omad	doc_634572338212_item	2775194	et	4	main
ideed	doc_634572338212_item	2775195	et	4	main
teistele	doc_634572338212_item	2775196	et	4	main
riikidele	doc_634572338212_item	2775197	et	3	main
kus	doc_634572338212_item	2775198	et	3	main
selle	doc_634572338212_item	2775199	et	4	main
eest	doc_634572338212_item	2775200	et	4	main
makstakse	doc_634572338212_item	2775201	et	3	main
rohkem	doc_634572338212_item	2775202	et	4	main
siis	doc_634572338212_item	2775203	et	3	main
tekibki	doc_634572338212_item	2775204	et	3	main
selline	doc_634572338212_item	2775205	et	4	main
olukord	doc_634572338212_item	2775206	et	3	main
et	doc_634572338212_item	2775207	et	3	main
meie	doc_634572338212_item	2775208	et	4	main
riiki	doc_634572338212_item	2775209	et	4	main
jää	doc_634572338212_item	2775211	et	4	main
uudishimulisi	doc_634572338212_item	2775214	et	4	main
ja	doc_634572338212_item	2775215	et	3	main
aktiivseid	doc_634572338212_item	2775216	et	3	main
riik	doc_634572338212_item	2775221	et	3	main
euroopa	doc_634572338212_item	2775224	et	4	main
ameerika	doc_634572338212_item	2775227	et	3	main
ei	doc_634572338212_item	2775230	et	4	main
siin	doc_634572338212_item	2775232	et	4	main
piisavalt	doc_634572338212_item	2775233	et	4	main
arenguvõimalusi	doc_634572338212_item	2775234	et	3	main
kuigi	doc_634572338212_item	2775235	et	3	main
sellega	doc_634572338212_item	2775236	et	3	main
püütakse	doc_634572338212_item	2775237	et	3	main
on	doc_634572338212_item	2775246	et	4	main
ei	doc_634572338212_item	2775265	et	4	main
ning	doc_634572338212_item	2775273	et	3	main
lugupidamisega	doc_634572338212_item	2775286	et	3	main
arvamuse	doc_634572338213_item	2775289	et	3	main
lugupeetud	doc_634572338213_item	2775299	et	4	main
ei	doc_634572338213_item	2775310	et	4	main
teiega	doc_634572338213_item	2775313	et	3	main
te	doc_634572338213_item	2775315	et	4	main
ma	doc_634572338213_item	2775328	et	3	main
otsivad	doc_634572338213_item	2775340	et	4	main
mis	doc_634572338213_item	2775343	et	4	main
edasi	doc_634572338213_item	2775344	et	3	main
perspektiivne	doc_634572338213_item	2775346	et	3	main
et	doc_634572338213_item	2775351	et	3	main
tulevast	doc_634572338213_item	2775358	et	4	main
palgast	doc_634572338213_item	2775359	et	4	main
nagu	doc_634572338213_item	2775360	et	3	main
omad	doc_634572338213_item	2775368	et	4	main
printsiibid	doc_634572338213_item	2775370	et	3	main
tänapäevased	doc_634572338213_item	2775376	et	4	main
te	doc_634572338213_item	2775413	et	4	main
takkistab	doc_634572338213_item	2775418	et	4	main
see	doc_634572338213_item	2775427	et	3	main
tulimuse	doc_634572338213_item	2775444	et	4	main
mis	doc_634572338213_item	2775447	et	4	main
tahab	doc_634572338213_item	2775454	et	3	main
oppidasee	doc_634572338213_item	2775472	et	4	main
teema	doc_634572338213_item	2775481	et	4	main
liidu	doc_634572338212_item	2775225	et	3	main
tahaks	doc_634572338212_item	2775240	et	3	main
on	doc_634572338212_item	2775244	et	4	main
erinevaid	doc_634572338212_item	2775245	et	4	main
selliseid	doc_634572338212_item	2775248	et	4	main
seevastu	doc_634572338212_item	2775257	et	3	main
on	doc_634572338212_item	2775258	et	4	main
ja	doc_634572338212_item	2775269	et	3	main
mitmesuguseid	doc_634572338212_item	2775275	et	3	main
võib	doc_634572338212_item	2775280	et	3	main
arvamus	doc_634572338213_item	2775288	et	3	main
vt	doc_634572338213_item	2775297	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338213_item	2775298	et	4	main
lugeja	doc_634572338213_item	2775304	et	4	main
teie	doc_634572338213_item	2775307	et	4	main
artikli	doc_634572338213_item	2775308	et	3	main
praegu	doc_634572338213_item	2775318	et	3	main
opilased	doc_634572338213_item	2775320	et	4	main
et	doc_634572338213_item	2775330	et	3	main
teised	doc_634572338213_item	2775341	et	4	main
enamus	doc_634572338213_item	2775352	et	4	main
eriala	doc_634572338213_item	2775355	et	4	main
mõtlevad	doc_634572338213_item	2775356	et	4	main
motlevad	doc_634572338213_item	2775367	et	4	main
raakida	doc_634572338213_item	2775374	et	4	main
et	doc_634572338213_item	2775375	et	3	main
on	doc_634572338213_item	2775406	et	4	main
noorte	doc_634572338213_item	2775416	et	3	main
et	doc_634572338213_item	2775420	et	3	main
nad	doc_634572338213_item	2775421	et	3	main
eksamite	doc_634572338213_item	2775425	et	3	main
õpilased	doc_634572338213_item	2775429	et	3	main
selle	doc_634572338213_item	2775439	et	4	main
need	doc_634572338213_item	2775440	et	3	main
samas	doc_634572338213_item	2775456	et	4	main
olen	doc_634572338213_item	2775458	et	3	main
sellega	doc_634572338213_item	2775460	et	3	main
infot	doc_634572338213_item	2775465	et	3	main
kohadkus	doc_634572338213_item	2775469	et	4	main
nad	doc_634572338213_item	2775470	et	3	main
mulle	doc_634572338213_item	2775476	et	4	main
meeldib	doc_634572338213_item	2775477	et	3	main
teile	doc_634572338213_item	2775478	et	4	main
öelda	doc_634572338212_item	2775241	et	4	main
et	doc_634572338212_item	2775242	et	3	main
olemas	doc_634572338212_item	2775247	et	4	main
tea	doc_634572338212_item	2775251	et	4	main
palju	doc_634572338212_item	2775259	et	4	main
töökaid	doc_634572338212_item	2775260	et	4	main
ja	doc_634572338212_item	2775261	et	3	main
aktiivseid	doc_634572338212_item	2775262	et	3	main
lepi	doc_634572338212_item	2775266	et	4	main
igas	doc_634572338212_item	2775277	et	3	main
tuua	doc_634572338212_item	2775282	et	3	main
tuudengite	doc_634572338212_item	2775284	et	4	main
organisatsioone	doc_634572338212_item	2775285	et	3	main
eesti	doc_634572338213_item	2775290	et	4	main
toimetaja	doc_634572338213_item	2775292	et	4	main
teile	doc_634572338213_item	2775303	et	4	main
ole	doc_634572338213_item	2775311	et	4	main
ulikooli	doc_634572338213_item	2775319	et	4	main
ei	doc_634572338213_item	2775321	et	4	main
tootada	doc_634572338213_item	2775323	et	4	main
ja	doc_634572338213_item	2775324	et	3	main
soovivad	doc_634572338213_item	2775325	et	4	main
elada	doc_634572338213_item	2775326	et	3	main
inimesed	doc_634572338213_item	2775339	et	3	main
tegevust	doc_634572338213_item	2775342	et	4	main
samas	doc_634572338213_item	2775347	et	4	main
ei	doc_634572338213_item	2775348	et	4	main
abiturientidest	doc_634572338213_item	2775353	et	3	main
valides	doc_634572338213_item	2775354	et	3	main
sqbrad	doc_634572338213_item	2775366	et	4	main
noored	doc_634572338213_item	2775377	et	3	main
valikut	doc_634572338213_item	2775417	et	3	main
see	doc_634572338213_item	2775419	et	3	main
tea	doc_634572338213_item	2775423	et	4	main
need	doc_634572338213_item	2775428	et	3	main
kellel	doc_634572338213_item	2775430	et	4	main
siht	doc_634572338213_item	2775432	et	3	main
saavutasid	doc_634572338213_item	2775438	et	4	main
kes	doc_634572338213_item	2775441	et	4	main
motleb	doc_634572338213_item	2775442	et	4	main
omade	doc_634572338213_item	2775443	et	3	main
ta	doc_634572338213_item	2775453	et	4	main
ma	doc_634572338213_item	2775457	et	3	main
vahe	doc_634572338213_item	2775464	et	4	main
on	doc_634572338213_item	2775473	et	4	main
suur	doc_634572338213_item	2775474	et	3	main
abituriente	doc_634572338212_item	2775243	et	3	main
kes	doc_634572338212_item	2775249	et	4	main
ei	doc_634572338212_item	2775250	et	4	main
mida	doc_634572338212_item	2775252	et	4	main
ja	doc_634572338212_item	2775253	et	3	main
tuudengeid	doc_634572338212_item	2775263	et	4	main
keskmise	doc_634572338212_item	2775267	et	3	main
mittetoimiva	doc_634572338212_item	2775270	et	3	main
kokku	doc_634572338212_item	2775272	et	3	main
otsivad	doc_634572338212_item	2775274	et	4	main
arenguvõimalusi	doc_634572338212_item	2775276	et	3	main
valdkonnas	doc_634572338212_item	2775278	et	4	main
näiteks	doc_634572338212_item	2775281	et	4	main
erinevaid	doc_634572338212_item	2775283	et	4	main
x	doc_634572338212_item	2775287	et	4	main
ekspressi	doc_634572338213_item	2775291	et	4	main
tiina	doc_634572338213_item	2775293	et	4	main
kaalepi	doc_634572338213_item	2775294	et	4	main
artikli	doc_634572338213_item	2775295	et	3	main
tiina	doc_634572338213_item	2775300	et	4	main
x	doc_634572338213_item	2775305	et	4	main
ja	doc_634572338213_item	2775309	et	3	main
nous	doc_634572338213_item	2775312	et	4	main
esimene	doc_634572338213_item	2775314	et	3	main
et	doc_634572338213_item	2775317	et	3	main
hasti	doc_634572338213_item	2775327	et	4	main
arvan	doc_634572338213_item	2775329	et	3	main
nende	doc_634572338213_item	2775331	et	4	main
vanemad	doc_634572338213_item	2775332	et	4	main
oleks	doc_634572338213_item	2775345	et	3	main
öelda	doc_634572338213_item	2775350	et	4	main
ainult	doc_634572338213_item	2775357	et	4	main
mina	doc_634572338213_item	2775361	et	4	main
tean	doc_634572338213_item	2775362	et	3	main
et	doc_634572338213_item	2775363	et	3	main
koik	doc_634572338213_item	2775364	et	4	main
minu	doc_634572338213_item	2775365	et	3	main
kuidagi	doc_634572338213_item	2775378	et	3	main
erinevad	doc_634572338213_item	2775379	et	4	main
huviallad	doc_634572338213_item	2775381	et	4	main
paljud	doc_634572338213_item	2775382	et	3	main
teistest	doc_634572338213_item	2775380	et	4	main
inimesed	doc_634572338213_item	2775383	et	3	main
rääkisid	doc_634572338213_item	2775384	et	4	main
sellest	doc_634572338213_item	2775385	et	4	main
et	doc_634572338213_item	2775386	et	3	main
inimesed	doc_634572338213_item	2775387	et	3	main
ei	doc_634572338213_item	2775388	et	4	main
muutu	doc_634572338213_item	2775389	et	4	main
tähendab	doc_634572338213_item	2775390	et	3	main
et	doc_634572338213_item	2775391	et	3	main
tänapäevased	doc_634572338213_item	2775392	et	4	main
noored	doc_634572338213_item	2775393	et	3	main
on	doc_634572338213_item	2775394	et	4	main
maksimalistid	doc_634572338213_item	2775395	et	3	main
nagu	doc_634572338213_item	2775396	et	3	main
nende	doc_634572338213_item	2775397	et	4	main
vanemad	doc_634572338213_item	2775398	et	4	main
olid	doc_634572338213_item	2775399	et	4	main
see	doc_634572338213_item	2775400	et	3	main
on	doc_634572338213_item	2775401	et	4	main
muidugisest	doc_634572338213_item	2775402	et	4	main
et	doc_634572338213_item	2775403	et	3	main
igal	doc_634572338213_item	2775404	et	3	main
omad	doc_634572338213_item	2775407	et	4	main
probleemid	doc_634572338213_item	2775408	et	3	main
ja	doc_634572338213_item	2775409	et	3	main
teine	doc_634572338213_item	2775410	et	3	main
teie	doc_634572338213_item	2775411	et	4	main
artiklis	doc_634572338213_item	2775412	et	3	main
ei	doc_634572338213_item	2775422	et	4	main
omade	doc_634572338213_item	2775424	et	3	main
oli	doc_634572338213_item	2775431	et	3	main
kuhu	doc_634572338213_item	2775433	et	3	main
näiteks	doc_634572338213_item	2775435	et	4	main
meditsiini	doc_634572338213_item	2775436	et	4	main
õppima	doc_634572338213_item	2775437	et	3	main
teab	doc_634572338213_item	2775446	et	3	main
et	doc_634572338213_item	2775461	et	3	main
uliqpilased	doc_634572338213_item	2775462	et	4	main
teavad	doc_634572338213_item	2775463	et	3	main
ulikoolised	doc_634572338213_item	2775466	et	4	main
teised	doc_634572338213_item	2775468	et	4	main
probleem	doc_634572338213_item	2775475	et	3	main
on	doc_634572338213_item	2775482	et	4	main
rohkem	doc_634572338213_item	2775484	et	4	main
lugupidamisega	doc_634572338213_item	2775485	et	3	main
x	doc_634572338213_item	2775486	et	4	main
tulemusi	doc_634572338213_item	2775426	et	4	main
saada	doc_634572338213_item	2775434	et	4	main
ta	doc_634572338213_item	2775445	et	4	main
eriala	doc_634572338213_item	2775448	et	4	main
ta	doc_634572338213_item	2775449	et	4	main
tahab	doc_634572338213_item	2775450	et	3	main
oppidaja	doc_634572338213_item	2775451	et	4	main
kus	doc_634572338213_item	2775452	et	3	main
oppida	doc_634572338213_item	2775455	et	4	main
nõus	doc_634572338213_item	2775459	et	4	main
ja	doc_634572338213_item	2775467	et	3	main
voiksid	doc_634572338213_item	2775471	et	4	main
artikel	doc_634572338213_item	2775479	et	4	main
see	doc_634572338213_item	2775480	et	3	main
vaga	doc_634572338213_item	2775483	et	4	main
kaalepi	doc_634572338218_item	2776331	et	4	main
artikli	doc_634572338218_item	2776332	et	3	main
kohtaarikkel	doc_634572338218_item	2776333	et	4	main
tiina	doc_634572338218_item	2776337	et	4	main
kaalep	doc_634572338218_item	2776338	et	4	main
valdkonna	doc_634572338218_item	2776344	et	4	main
esimese	doc_634572338218_item	2776345	et	3	main
kursuse	doc_634572338218_item	2776346	et	3	main
tudeng	doc_634572338218_item	2776347	et	3	main
lugesin	doc_634572338218_item	2776348	et	3	main
nõus	doc_634572338218_item	2776353	et	4	main
vastuste	doc_634572338218_item	2776356	et	4	main
tuttavaid	doc_634572338218_item	2776363	et	3	main
kes	doc_634572338218_item	2776364	et	4	main
leida	doc_634572338218_item	2776366	et	3	main
liisida	doc_634572338218_item	2776397	et	4	main
nõuab	doc_634572338218_item	2776410	et	3	main
arvamus	doc_634572338218_item	2776325	et	3	main
arvamuse	doc_634572338218_item	2776326	et	3	main
eesti	doc_634572338218_item	2776327	et	4	main
soojustehnika	doc_634572338218_item	2776343	et	4	main
küsitluse	doc_634572338218_item	2776355	et	4	main
esiteks	doc_634572338218_item	2776358	et	3	main
isegi	doc_634572338218_item	2776400	et	4	main
saamine	doc_634572338218_item	2776409	et	4	main
mida	doc_634572338218_item	2776412	et	4	main
saa	doc_634572338218_item	2776416	et	4	main
et	doc_634572338218_item	2776422	et	3	main
oma	doc_634572338218_item	2776424	et	4	main
elu	doc_634572338218_item	2776425	et	4	main
korraliku	doc_634572338218_item	2776434	et	3	main
ja	doc_634572338218_item	2776436	et	3	main
korraliku	doc_634572338218_item	2776437	et	3	main
palgaga	doc_634572338218_item	2776438	et	3	main
kuid	doc_634572338218_item	2776439	et	4	main
ja	doc_634572338218_item	2776446	et	3	main
seega	doc_634572338218_item	2776447	et	4	main
läksin	doc_634572338218_item	2776448	et	3	main
oli	doc_634572338218_item	2776454	et	3	main
seda	doc_634572338218_item	2776458	et	3	main
lubada	doc_634572338218_item	2776463	et	3	main
liisimiseks	doc_634572338218_item	2776476	et	4	main
kes	doc_634572338218_item	2776484	et	4	main
ei	doc_634572338218_item	2776486	et	4	main
olen	doc_634572338218_item	2776499	et	3	main
teiega	doc_634572338218_item	2776500	et	3	main
nõus	doc_634572338218_item	2776501	et	4	main
ja	doc_634572338218_item	2776524	et	3	main
kuid	doc_634572338218_item	2776527	et	4	main
saamine	doc_634572338218_item	2776536	et	4	main
on	doc_634572338218_item	2776537	et	4	main
ebastabiilsus	doc_634572338218_item	2776547	et	4	main
ja	doc_634572338218_item	2776548	et	3	main
niisugune	doc_634572338218_item	2776549	et	3	main
positsioon	doc_634572338218_item	2776550	et	3	main
et	doc_634572338218_item	2776551	et	3	main
las	doc_634572338218_item	2776552	et	4	main
homme	doc_634572338218_item	2776556	et	3	main
ja	doc_634572338218_item	2776558	et	3	main
vt	doc_634572338218_item	2776334	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338218_item	2776335	et	4	main
tehnika	doc_634572338218_item	2776341	et	4	main
teie	doc_634572338218_item	2776350	et	4	main
artikli	doc_634572338218_item	2776351	et	3	main
on	doc_634572338218_item	2776360	et	4	main
tööd	doc_634572338218_item	2776395	et	4	main
väikest	doc_634572338218_item	2776401	et	4	main
kuid	doc_634572338218_item	2776407	et	4	main
raha	doc_634572338218_item	2776411	et	4	main
paljud	doc_634572338218_item	2776413	et	3	main
tudengid	doc_634572338218_item	2776414	et	3	main
ei	doc_634572338218_item	2776415	et	4	main
suhteid	doc_634572338218_item	2776429	et	3	main
pärast	doc_634572338218_item	2776432	et	4	main
leida	doc_634572338218_item	2776433	et	3	main
endale	doc_634572338218_item	2776442	et	4	main
seda	doc_634572338218_item	2776443	et	3	main
mehaanika	doc_634572338218_item	2776451	et	4	main
ja	doc_634572338218_item	2776457	et	3	main
minu	doc_634572338218_item	2776459	et	3	main
said	doc_634572338218_item	2776461	et	4	main
et	doc_634572338218_item	2776465	et	3	main
leian	doc_634572338218_item	2776467	et	3	main
samuti	doc_634572338218_item	2776480	et	3	main
tea	doc_634572338218_item	2776487	et	4	main
mida	doc_634572338218_item	2776488	et	4	main
oma	doc_634572338218_item	2776489	et	4	main
eluga	doc_634572338218_item	2776490	et	3	main
teha	doc_634572338218_item	2776491	et	3	main
kuhu	doc_634572338218_item	2776492	et	3	main
õppima	doc_634572338218_item	2776493	et	3	main
minna	doc_634572338218_item	2776494	et	3	main
ja	doc_634572338218_item	2776495	et	3	main
millist	doc_634572338218_item	2776496	et	3	main
toimetaja	doc_634572338218_item	2776329	et	4	main
tiina	doc_634572338218_item	2776330	et	4	main
lugupeetud	doc_634572338218_item	2776336	et	4	main
ülikooli	doc_634572338218_item	2776342	et	4	main
olen	doc_634572338218_item	2776352	et	3	main
aspektidega	doc_634572338218_item	2776357	et	3	main
palju	doc_634572338218_item	2776362	et	4	main
soovivad	doc_634572338218_item	2776365	et	4	main
meeldivat	doc_634572338218_item	2776367	et	4	main
sest	doc_634572338218_item	2776391	et	4	main
et	doc_634572338218_item	2776392	et	3	main
leida	doc_634572338218_item	2776393	et	3	main
korraliku	doc_634572338218_item	2776394	et	3	main
ja	doc_634572338218_item	2776396	et	3	main
kodu	doc_634572338218_item	2776402	et	4	main
selleks	doc_634572338218_item	2776403	et	4	main
tuleb	doc_634572338218_item	2776404	et	3	main
omandada	doc_634572338218_item	2776405	et	3	main
kõrgharidust	doc_634572338218_item	2776406	et	4	main
endale	doc_634572338218_item	2776417	et	4	main
tahtsin	doc_634572338218_item	2776426	et	3	main
audenteses	doc_634572338218_item	2776427	et	4	main
materiaalselt	doc_634572338218_item	2776444	et	4	main
lubada	doc_634572338218_item	2776445	et	3	main
osakonda	doc_634572338218_item	2776452	et	4	main
see	doc_634572338218_item	2776453	et	3	main
vanemad	doc_634572338218_item	2776460	et	4	main
vaevalt	doc_634572338218_item	2776464	et	4	main
mahaanikuna	doc_634572338218_item	2776466	et	4	main
kohta	doc_634572338218_item	2776470	et	4	main
palka	doc_634572338218_item	2776474	et	4	main
kodu	doc_634572338218_item	2776475	et	4	main
teie	doc_634572338218_item	2776479	et	4	main
kirjutate	doc_634572338218_item	2776481	et	3	main
et	doc_634572338218_item	2776502	et	3	main
pärast	doc_634572338218_item	2776521	et	4	main
head	doc_634572338218_item	2776530	et	4	main
tulemused	doc_634572338218_item	2776531	et	3	main
tasuta	doc_634572338218_item	2776538	et	4	main
ja	doc_634572338218_item	2776539	et	3	main
inimene	doc_634572338218_item	2776540	et	3	main
saab	doc_634572338218_item	2776541	et	3	main
endale	doc_634572338218_item	2776543	et	4	main
näitab	doc_634572338218_item	2776554	et	3	main
siis	doc_634572338218_item	2776559	et	3	main
valiku	doc_634572338218_item	2776562	et	3	main
soovivad	doc_634572338218_item	2776570	et	4	main
leida	doc_634572338218_item	2776571	et	3	main
oli	doc_634572338218_item	2776581	et	3	main
jaoks	doc_634572338218_item	2776583	et	4	main
töötajaid	doc_634572338218_item	2776595	et	4	main
valdkonnas	doc_634572338218_item	2776600	et	4	main
elu	doc_634572338218_item	2776602	et	4	main
oleks	doc_634572338218_item	2776604	et	3	main
toimetaja	doc_634572338219_item	2776613	et	4	main
tiina	doc_634572338219_item	2776614	et	4	main
vt	doc_634572338219_item	2776618	et	4	main
ekspressi	doc_634572338218_item	2776328	et	4	main
mina	doc_634572338218_item	2776339	et	4	main
olen	doc_634572338218_item	2776340	et	3	main
läbi	doc_634572338218_item	2776349	et	4	main
paljude	doc_634572338218_item	2776354	et	3	main
minul	doc_634572338218_item	2776359	et	3	main
hästi	doc_634572338218_item	2776361	et	3	main
tööd	doc_634572338218_item	2776368	et	4	main
saada	doc_634572338218_item	2776369	et	4	main
normaalset	doc_634572338218_item	2776370	et	3	main
palka	doc_634572338218_item	2776371	et	4	main
pühendada	doc_634572338218_item	2776372	et	3	main
oma	doc_634572338218_item	2776373	et	4	main
aega	doc_634572338218_item	2776374	et	4	main
kodule	doc_634572338218_item	2776375	et	3	main
ja	doc_634572338218_item	2776376	et	3	main
perekonnale	doc_634572338218_item	2776377	et	4	main
kahjuks	doc_634572338218_item	2776379	et	4	main
soov	doc_634572338218_item	2776380	et	3	main
kuid	doc_634572338218_item	2776378	et	4	main
ja	doc_634572338218_item	2776381	et	3	main
unistus	doc_634572338218_item	2776382	et	4	main
väga	doc_634572338218_item	2776383	et	3	main
sageli	doc_634572338218_item	2776384	et	3	main
jäävad	doc_634572338218_item	2776385	et	4	main
ainult	doc_634572338218_item	2776386	et	4	main
sooviks	doc_634572338218_item	2776387	et	4	main
ja	doc_634572338218_item	2776388	et	3	main
ei	doc_634572338218_item	2776389	et	4	main
realiseeru	doc_634572338218_item	2776390	et	4	main
auto	doc_634572338218_item	2776398	et	4	main
või	doc_634572338218_item	2776399	et	4	main
kõrghariduse	doc_634572338218_item	2776408	et	3	main
lubada	doc_634572338218_item	2776418	et	3	main
näidisena	doc_634572338218_item	2776419	et	3	main
võin	doc_634572338218_item	2776420	et	3	main
tuua	doc_634572338218_item	2776421	et	3	main
kogu	doc_634572338218_item	2776423	et	4	main
et	doc_634572338218_item	2776431	et	3	main
tööd	doc_634572338218_item	2776435	et	4	main
ei	doc_634572338218_item	2776440	et	4	main
tehnika	doc_634572338218_item	2776449	et	4	main
odavam	doc_634572338218_item	2776456	et	4	main
tööturul	doc_634572338218_item	2776469	et	3	main
et	doc_634572338218_item	2776471	et	3	main
normaalset	doc_634572338218_item	2776473	et	3	main
üldse	doc_634572338218_item	2776485	et	3	main
tööd	doc_634572338218_item	2776497	et	4	main
heast	doc_634572338218_item	2776525	et	3	main
ei	doc_634572338218_item	2776532	et	4	main
et	doc_634572338218_item	2776534	et	3	main
seda	doc_634572338218_item	2776542	et	3	main
lubada	doc_634572338218_item	2776544	et	3	main
saab	doc_634572338218_item	2776557	et	3	main
kes	doc_634572338218_item	2776569	et	4	main
sotsiaaltöötajana	doc_634572338218_item	2776573	et	3	main
ütlen	doc_634572338218_item	2776576	et	3	main
ausalt	doc_634572338218_item	2776577	et	4	main
et	doc_634572338218_item	2776578	et	3	main
minu	doc_634572338218_item	2776582	et	3	main
kuid	doc_634572338218_item	2776585	et	4	main
kuid	doc_634572338218_item	2776589	et	4	main
riigis	doc_634572338218_item	2776591	et	3	main
ja	doc_634572338218_item	2776598	et	3	main
eesti	doc_634572338219_item	2776611	et	4	main
tiina	doc_634572338219_item	2776621	et	4	main
tere	doc_634572338219_item	2776623	et	3	main
tiina	doc_634572338219_item	2776625	et	4	main
teile	doc_634572338219_item	2776629	et	4	main
meeldis	doc_634572338219_item	2776639	et	3	main
paljud	doc_634572338219_item	2776655	et	3	main
juba	doc_634572338219_item	2776659	et	3	main
rääginud	doc_634572338219_item	2776661	et	4	main
nad	doc_634572338219_item	2776663	et	3	main
tahavad	doc_634572338219_item	2776664	et	3	main
teenida	doc_634572338219_item	2776665	et	3	main
paju	doc_634572338219_item	2776666	et	4	main
ja	doc_634572338219_item	2776674	et	3	main
nad	doc_634572338219_item	2776678	et	3	main
töötada	doc_634572338219_item	2776688	et	3	main
eksami	doc_634572338219_item	2776695	et	3	main
näiteks	doc_634572338219_item	2776697	et	4	main
minul	doc_634572338219_item	2776700	et	3	main
minna	doc_634572338219_item	2776703	et	3	main
ülikooli	doc_634572338219_item	2776704	et	4	main
tulemused	doc_634572338219_item	2776712	et	3	main
selgeks	doc_634572338219_item	2776714	et	3	main
erialale	doc_634572338219_item	2776717	et	3	main
ja	doc_634572338219_item	2776725	et	3	main
kus	doc_634572338219_item	2776727	et	3	main
õpin	doc_634572338219_item	2776730	et	3	main
ma	doc_634572338219_item	2776731	et	3	main
et	doc_634572338219_item	2776733	et	3	main
minna	doc_634572338219_item	2776761	et	3	main
nendele	doc_634572338219_item	2776788	et	4	main
ei	doc_634572338219_item	2776789	et	4	main
endale	doc_634572338219_item	2776794	et	4	main
vanemad	doc_634572338219_item	2776813	et	4	main
autot	doc_634572338219_item	2776817	et	3	main
endale	doc_634572338219_item	2776828	et	4	main
seda	doc_634572338219_item	2776829	et	3	main
lubada	doc_634572338219_item	2776830	et	3	main
aga	doc_634572338219_item	2776831	et	3	main
nad	doc_634572338219_item	2776832	et	3	main
ja	doc_634572338219_item	2776835	et	3	main
on	doc_634572338219_item	2776841	et	4	main
muidugi	doc_634572338219_item	2776891	et	4	main
see	doc_634572338219_item	2776901	et	3	main
ainult	doc_634572338219_item	2776909	et	4	main
õmblema	doc_634572338219_item	2776910	et	3	main
palk	doc_634572338219_item	2776912	et	3	main
vajavad	doc_634572338219_item	2776922	et	4	main
rahvusvahelisi	doc_634572338218_item	2776428	et	4	main
õppida	doc_634572338218_item	2776430	et	3	main
saanud	doc_634572338218_item	2776441	et	4	main
ülikooli	doc_634572338218_item	2776450	et	4	main
palju	doc_634572338218_item	2776455	et	4	main
endale	doc_634572338218_item	2776462	et	4	main
ma	doc_634572338218_item	2776468	et	3	main
saada	doc_634572338218_item	2776472	et	4	main
oma	doc_634572338218_item	2776477	et	4	main
artiklis	doc_634572338218_item	2776478	et	3	main
nendest	doc_634572338218_item	2776482	et	4	main
noorinimestest	doc_634572338218_item	2776483	et	3	main
saada	doc_634572338218_item	2776498	et	4	main
palju	doc_634572338218_item	2776503	et	4	main
sõltub	doc_634572338218_item	2776504	et	3	main
eksamitulemustest	doc_634572338218_item	2776505	et	4	main
kui	doc_634572338218_item	2776506	et	3	main
kõik	doc_634572338218_item	2776507	et	4	main
eksamid	doc_634572338218_item	2776508	et	3	main
on	doc_634572338218_item	2776509	et	4	main
korralikult	doc_634572338218_item	2776510	et	4	main
sooritatud	doc_634572338218_item	2776511	et	4	main
siis	doc_634572338218_item	2776512	et	3	main
võib	doc_634572338218_item	2776513	et	3	main
inimene	doc_634572338218_item	2776514	et	3	main
unistada	doc_634572338218_item	2776515	et	3	main
erialast	doc_634572338218_item	2776516	et	4	main
talle	doc_634572338218_item	2776518	et	4	main
meeldiks	doc_634572338218_item	2776519	et	3	main
mis	doc_634572338218_item	2776517	et	4	main
ja	doc_634572338218_item	2776520	et	3	main
tööst	doc_634572338218_item	2776523	et	3	main
teiselt	doc_634572338218_item	2776528	et	4	main
külelt	doc_634572338218_item	2776529	et	4	main
tähenda	doc_634572338218_item	2776533	et	4	main
kõrghariduse	doc_634572338218_item	2776535	et	3	main
elu	doc_634572338218_item	2776553	et	4	main
teen	doc_634572338218_item	2776560	et	3	main
rühma	doc_634572338218_item	2776567	et	4	main
küsitlejatest	doc_634572338218_item	2776568	et	4	main
tööd	doc_634572338218_item	2776572	et	4	main
keskonnakaitsejana	doc_634572338218_item	2776575	et	4	main
üllatuseks	doc_634572338218_item	2776584	et	4	main
nõustan	doc_634572338218_item	2776586	et	3	main
meie	doc_634572338218_item	2776590	et	4	main
kompeteensemaid	doc_634572338218_item	2776594	et	4	main
lihtsam	doc_634572338218_item	2776605	et	4	main
parimate	doc_634572338218_item	2776606	et	4	main
soovidega	doc_634572338218_item	2776607	et	3	main
kaalepile	doc_634572338219_item	2776622	et	4	main
ma	doc_634572338219_item	2776627	et	3	main
mulle	doc_634572338219_item	2776638	et	4	main
sest	doc_634572338219_item	2776640	et	4	main
on	doc_634572338219_item	2776642	et	4	main
tänapäevane	doc_634572338219_item	2776643	et	4	main
praegu	doc_634572338219_item	2776645	et	3	main
ma	doc_634572338219_item	2776646	et	3	main
olen	doc_634572338219_item	2776647	et	3	main
üliõpilane	doc_634572338219_item	2776648	et	3	main
ja	doc_634572338219_item	2776649	et	3	main
väga	doc_634572338219_item	2776650	et	3	main
hästi	doc_634572338219_item	2776651	et	3	main
tean	doc_634572338219_item	2776652	et	3	main
ka	doc_634572338218_item	2776522	et	3	main
palgast	doc_634572338218_item	2776526	et	4	main
seega	doc_634572338218_item	2776545	et	4	main
tuleb	doc_634572338218_item	2776546	et	3	main
mis	doc_634572338218_item	2776555	et	4	main
oma	doc_634572338218_item	2776561	et	4	main
lõpuks	doc_634572338218_item	2776563	et	4	main
teie	doc_634572338218_item	2776564	et	4	main
mainite	doc_634572338218_item	2776565	et	3	main
kolamanda	doc_634572338218_item	2776566	et	4	main
või	doc_634572338218_item	2776574	et	4	main
vastus	doc_634572338218_item	2776580	et	3	main
et	doc_634572338218_item	2776588	et	3	main
meditsiini	doc_634572338218_item	2776596	et	4	main
hariduse	doc_634572338218_item	2776597	et	3	main
siis	doc_634572338218_item	2776601	et	3	main
eestis	doc_634572338218_item	2776603	et	3	main
ekspressi	doc_634572338219_item	2776612	et	4	main
kohtaarikkel	doc_634572338219_item	2776617	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338219_item	2776619	et	4	main
kiri	doc_634572338219_item	2776620	et	3	main
kirjutan	doc_634572338219_item	2776628	et	3	main
olen	doc_634572338219_item	2776631	et	3	main
ja	doc_634572338219_item	2776635	et	3	main
see	doc_634572338219_item	2776636	et	3	main
mida	doc_634572338219_item	2776653	et	4	main
tahavad	doc_634572338219_item	2776654	et	3	main
te	doc_634572338219_item	2776658	et	4	main
töötada	doc_634572338219_item	2776676	et	3	main
on	doc_634572338219_item	2776684	et	4	main
tulevik	doc_634572338219_item	2776693	et	3	main
oli	doc_634572338219_item	2776699	et	3	main
ma	doc_634572338219_item	2776701	et	3	main
ühe	doc_634572338219_item	2776705	et	4	main
erialale	doc_634572338219_item	2776706	et	3	main
aga	doc_634572338219_item	2776707	et	3	main
kui	doc_634572338219_item	2776708	et	3	main
ma	doc_634572338219_item	2776709	et	3	main
see	doc_634572338219_item	2776716	et	3	main
ei	doc_634572338219_item	2776719	et	4	main
niisugune	doc_634572338218_item	2776579	et	3	main
teiega	doc_634572338218_item	2776587	et	3	main
oleks	doc_634572338218_item	2776592	et	3	main
rohkem	doc_634572338218_item	2776593	et	4	main
poliitika	doc_634572338218_item	2776599	et	4	main
x	doc_634572338218_item	2776608	et	4	main
arvamus	doc_634572338219_item	2776609	et	3	main
arvamuse	doc_634572338219_item	2776610	et	3	main
kaalepi	doc_634572338219_item	2776615	et	4	main
artikli	doc_634572338219_item	2776616	et	3	main
kaalep	doc_634572338219_item	2776626	et	4	main
teie	doc_634572338219_item	2776633	et	4	main
artikkel	doc_634572338219_item	2776637	et	3	main
see	doc_634572338219_item	2776641	et	3	main
abituriendid	doc_634572338219_item	2776656	et	3	main
olete	doc_634572338219_item	2776660	et	3	main
muidugi	doc_634572338219_item	2776662	et	4	main
raha	doc_634572338219_item	2776673	et	4	main
et	doc_634572338219_item	2776680	et	3	main
palju	doc_634572338219_item	2776682	et	4	main
raha	doc_634572338219_item	2776683	et	4	main
küll	doc_634572338219_item	2776690	et	4	main
et	doc_634572338219_item	2776691	et	3	main
jäi	doc_634572338219_item	2776713	et	3	main
ma	doc_634572338219_item	2776718	et	3	main
minna	doc_634572338219_item	2776721	et	3	main
ei	doc_634572338219_item	2776743	et	4	main
need	doc_634572338219_item	2776751	et	3	main
halva	doc_634572338219_item	2776754	et	4	main
küll	doc_634572338219_item	2776758	et	4	main
avatude	doc_634572338219_item	2776781	et	4	main
et	doc_634572338219_item	2776786	et	3	main
see	doc_634572338219_item	2776787	et	3	main
korterid	doc_634572338219_item	2776818	et	3	main
ka	doc_634572338219_item	2776823	et	3	main
väga	doc_634572338219_item	2776833	et	3	main
nad	doc_634572338219_item	2776836	et	3	main
palk	doc_634572338219_item	2776840	et	3	main
väike	doc_634572338219_item	2776842	et	4	main
saavad	doc_634572338219_item	2776851	et	4	main
rohkem	doc_634572338219_item	2776852	et	4	main
raha	doc_634572338219_item	2776853	et	4	main
ma	doc_634572338219_item	2776854	et	3	main
ei	doc_634572338219_item	2776855	et	4	main
et	doc_634572338219_item	2776861	et	3	main
tean	doc_634572338219_item	2776899	et	3	main
ei	doc_634572338219_item	2776913	et	4	main
ole	doc_634572338219_item	2776914	et	4	main
suur	doc_634572338219_item	2776915	et	3	main
on	doc_634572338219_item	2776919	et	4	main
üks	doc_634572338219_item	2776937	et	3	main
teine	doc_634572338219_item	2776942	et	3	main
surra	doc_634572338219_item	2776945	et	3	main
arvates	doc_634572338219_item	2776947	et	4	main
peavad	doc_634572338219_item	2776951	et	4	main
olema	doc_634572338219_item	2776966	et	4	main
sest	doc_634572338219_item	2776970	et	4	main
suur	doc_634572338219_item	2776974	et	3	main
nägid	doc_634572338219_item	2776980	et	4	main
teie	doc_634572338219_item	2776983	et	4	main
artiklit	doc_634572338219_item	2776984	et	3	main
ning	doc_634572338219_item	2776985	et	3	main
üliõpilastele	doc_634572338219_item	2776990	et	4	main
ja	doc_634572338219_item	2776991	et	3	main
kõik	doc_634572338219_item	2776995	et	4	main
elada	doc_634572338219_item	2776997	et	3	main
ja	doc_634572338219_item	2776999	et	3	main
ei	doc_634572338219_item	2777001	et	4	main
taha	doc_634572338219_item	2777002	et	4	main
lugupidamisega	doc_634572338219_item	2777012	et	3	main
eesti	doc_634572338220_item	2777017	et	4	main
kaalepi	doc_634572338220_item	2777021	et	4	main
lugupeetud	doc_634572338220_item	2777026	et	4	main
kaalep	doc_634572338220_item	2777028	et	4	main
on	doc_634572338220_item	2777031	et	4	main
otsustasin	doc_634572338220_item	2777044	et	3	main
on	doc_634572338220_item	2777053	et	4	main
väga	doc_634572338220_item	2777054	et	3	main
tunnetuslik	doc_634572338220_item	2777055	et	3	main
ja	doc_634572338220_item	2777056	et	3	main
üliõpilastele	doc_634572338220_item	2777064	et	4	main
sellest	doc_634572338220_item	2777071	et	4	main
lugupeetud	doc_634572338219_item	2776624	et	4	main
kuna	doc_634572338219_item	2776630	et	3	main
lugenud	doc_634572338219_item	2776632	et	4	main
artikli	doc_634572338219_item	2776634	et	3	main
elu	doc_634572338219_item	2776644	et	4	main
kui	doc_634572338219_item	2776657	et	3	main
neis	doc_634572338219_item	2776670	et	4	main
tahavad	doc_634572338219_item	2776671	et	3	main
teenida	doc_634572338219_item	2776672	et	3	main
unustavad	doc_634572338219_item	2776679	et	4	main
saada	doc_634572338219_item	2776681	et	4	main
hästi	doc_634572338219_item	2776687	et	3	main
sõltub	doc_634572338219_item	2776694	et	3	main
tulemusest	doc_634572338219_item	2776696	et	4	main
kui	doc_634572338219_item	2776698	et	3	main
tahaksin	doc_634572338219_item	2776702	et	3	main
oma	doc_634572338219_item	2776711	et	4	main
et	doc_634572338219_item	2776715	et	3	main
saa	doc_634572338219_item	2776720	et	4	main
otsisin	doc_634572338219_item	2776723	et	3	main
praegu	doc_634572338219_item	2776729	et	3	main
väga	doc_634572338219_item	2776735	et	3	main
mis	doc_634572338219_item	2776738	et	4	main
hakkavad	doc_634572338219_item	2776739	et	4	main
ootavad	doc_634572338219_item	2776747	et	4	main
järgmist	doc_634572338219_item	2776748	et	3	main
aastat	doc_634572338219_item	2776749	et	3	main
või	doc_634572338219_item	2776750	et	4	main
sai	doc_634572338219_item	2776753	et	4	main
tulemust	doc_634572338219_item	2776755	et	4	main
aga	doc_634572338219_item	2776756	et	3	main
tahaksid	doc_634572338219_item	2776760	et	4	main
ülikooli	doc_634572338219_item	2776782	et	4	main
aga	doc_634572338219_item	2776783	et	3	main
meeldi	doc_634572338219_item	2776790	et	4	main
ja	doc_634572338219_item	2776791	et	3	main
nad	doc_634572338219_item	2776792	et	3	main
on	doc_634572338219_item	2776797	et	4	main
ka	doc_634572338219_item	2776802	et	3	main
ostavad	doc_634572338219_item	2776816	et	3	main
ja	doc_634572338219_item	2776819	et	3	main
kes	doc_634572338219_item	2776825	et	4	main
hästi	doc_634572338219_item	2776838	et	3	main
siis	doc_634572338219_item	2776843	et	3	main
vaga	doc_634572338219_item	2776845	et	4	main
miks	doc_634572338219_item	2776858	et	4	main
noormehed	doc_634572338219_item	2776859	et	3	main
oli	doc_634572338219_item	2776887	et	3	main
väga	doc_634572338219_item	2776888	et	3	main
leida	doc_634572338219_item	2776889	et	3	main
mulle	doc_634572338219_item	2776892	et	4	main
pakkuti	doc_634572338219_item	2776893	et	4	main
töö	doc_634572338219_item	2776894	et	4	main
kohas	doc_634572338219_item	2776907	et	4	main
ja	doc_634572338219_item	2776908	et	3	main
meie	doc_634572338219_item	2776917	et	4	main
raha	doc_634572338219_item	2776667	et	4	main
ja	doc_634572338219_item	2776668	et	3	main
paljud	doc_634572338219_item	2776669	et	3	main
mitte	doc_634572338219_item	2776675	et	3	main
ja	doc_634572338219_item	2776677	et	3	main
ka	doc_634572338219_item	2776685	et	3	main
vaja	doc_634572338219_item	2776686	et	4	main
on	doc_634572338219_item	2776689	et	4	main
abiturientide	doc_634572338219_item	2776692	et	3	main
nägin	doc_634572338219_item	2776710	et	3	main
ja	doc_634572338219_item	2776722	et	3	main
arvan	doc_634572338219_item	2776732	et	3	main
mulle	doc_634572338219_item	2776734	et	4	main
aga	doc_634572338219_item	2776737	et	3	main
teha	doc_634572338219_item	2776740	et	3	main
need	doc_634572338219_item	2776741	et	3	main
kes	doc_634572338219_item	2776742	et	4	main
on	doc_634572338219_item	2776757	et	4	main
nad	doc_634572338219_item	2776759	et	3	main
ülikooli	doc_634572338219_item	2776762	et	4	main
on	doc_634572338219_item	2776784	et	4	main
selge	doc_634572338219_item	2776785	et	4	main
otsivad	doc_634572338219_item	2776793	et	4	main
parimat	doc_634572338219_item	2776795	et	4	main
selge	doc_634572338219_item	2776798	et	4	main
tahavad	doc_634572338219_item	2776801	et	3	main
oma	doc_634572338219_item	2776804	et	4	main
majas	doc_634572338219_item	2776805	et	3	main
ja	doc_634572338219_item	2776806	et	3	main
sõita	doc_634572338219_item	2776807	et	3	main
oma	doc_634572338219_item	2776808	et	4	main
autoga	doc_634572338219_item	2776809	et	3	main
on	doc_634572338219_item	2776810	et	4	main
tore	doc_634572338219_item	2776811	et	3	main
kui	doc_634572338219_item	2776812	et	3	main
neile	doc_634572338219_item	2776815	et	4	main
teise	doc_634572338219_item	2776724	et	4	main
leidsin	doc_634572338219_item	2776726	et	3	main
ma	doc_634572338219_item	2776728	et	3	main
vedas	doc_634572338219_item	2776736	et	4	main
saa	doc_634572338219_item	2776744	et	4	main
tunnistust	doc_634572338219_item	2776745	et	4	main
ja	doc_634572338219_item	2776746	et	3	main
kes	doc_634572338219_item	2776752	et	4	main
aga	doc_634572338219_item	2776763	et	3	main
nad	doc_634572338219_item	2776764	et	3	main
praegu	doc_634572338219_item	2776765	et	3	main
ei	doc_634572338219_item	2776766	et	4	main
saa	doc_634572338219_item	2776767	et	4	main
kuna	doc_634572338219_item	2776768	et	3	main
tasulistele	doc_634572338219_item	2776769	et	4	main
kohtadele	doc_634572338219_item	2776770	et	3	main
on	doc_634572338219_item	2776771	et	4	main
ka	doc_634572338219_item	2776772	et	3	main
praegu	doc_634572338219_item	2776773	et	3	main
järjekord	doc_634572338219_item	2776774	et	3	main
siis	doc_634572338219_item	2776775	et	3	main
nad	doc_634572338219_item	2776776	et	3	main
tulevad	doc_634572338219_item	2776777	et	4	main
näiteks	doc_634572338219_item	2776778	et	4	main
või	doc_634572338219_item	2776780	et	4	main
kutsekooli	doc_634572338219_item	2776779	et	4	main
parianti	doc_634572338219_item	2776796	et	4	main
et	doc_634572338219_item	2776799	et	3	main
abituriendid	doc_634572338219_item	2776800	et	3	main
elada	doc_634572338219_item	2776803	et	3	main
aitavad	doc_634572338219_item	2776814	et	4	main
muud	doc_634572338219_item	2776820	et	4	main
aga	doc_634572338219_item	2776821	et	3	main
ei	doc_634572338219_item	2776826	et	4	main
saa	doc_634572338219_item	2776827	et	4	main
töötavad	doc_634572338219_item	2776837	et	4	main
aga	doc_634572338219_item	2776839	et	3	main
on	doc_634572338219_item	2776844	et	4	main
kahetsetav	doc_634572338219_item	2776846	et	4	main
kuna	doc_634572338219_item	2776847	et	3	main
mõnedainult	doc_634572338219_item	2776848	et	4	main
nuttavad	doc_634572338219_item	2776860	et	4	main
ole	doc_634572338219_item	2776863	et	4	main
tean	doc_634572338219_item	2776867	et	3	main
õmblejana	doc_634572338219_item	2776895	et	4	main
aga	doc_634572338219_item	2776896	et	3	main
ma	doc_634572338219_item	2776897	et	3	main
juba	doc_634572338219_item	2776898	et	3	main
on	doc_634572338219_item	2776902	et	4	main
töö	doc_634572338219_item	2776904	et	4	main
istuda	doc_634572338219_item	2776905	et	3	main
ühes	doc_634572338219_item	2776906	et	4	main
muidugi	doc_634572338219_item	2776916	et	4	main
erialad	doc_634572338219_item	2776920	et	3	main
näiteks	doc_634572338219_item	2776928	et	4	main
arstid	doc_634572338219_item	2776929	et	4	main
neid	doc_634572338219_item	2776934	et	4	main
erialas	doc_634572338219_item	2776940	et	3	main
ehitajana	doc_634572338219_item	2776949	et	4	main
jne	doc_634572338219_item	2776950	et	4	main
palk	doc_634572338219_item	2776963	et	3	main
neil	doc_634572338219_item	2776964	et	4	main
praegu	doc_634572338219_item	2776969	et	3	main
ma	doc_634572338219_item	2776976	et	3	main
valitsuses	doc_634572338219_item	2776979	et	4	main
ja	doc_634572338219_item	2776981	et	3	main
lugesid	doc_634572338219_item	2776982	et	4	main
parandamiseks	doc_634572338219_item	2776989	et	4	main
tahavad	doc_634572338219_item	2776996	et	3	main
puudutasite	doc_634572338219_item	2777009	et	3	main
12012007	doc_634572338219_item	2777014	et	2	main
tiina	doc_634572338220_item	2777020	et	4	main
kohtaarikkel	doc_634572338220_item	2777023	et	4	main
tiina	doc_634572338220_item	2777027	et	4	main
nimi	doc_634572338220_item	2777030	et	3	main
x	doc_634572338220_item	2777032	et	4	main
ja	doc_634572338220_item	2777033	et	3	main
ma	doc_634572338220_item	2777034	et	3	main
olen	doc_634572338220_item	2777035	et	3	main
ttü	doc_634572338220_item	2777036	et	4	main
esmakursuslane	doc_634572338220_item	2777037	et	3	main
lugedes	doc_634572338220_item	2777038	et	3	main
kirjutada	doc_634572338220_item	2777045	et	3	main
minu	doc_634572338220_item	2777047	et	3	main
on	doc_634572338220_item	2777049	et	4	main
selline	doc_634572338220_item	2777050	et	4	main
et	doc_634572338220_item	2777051	et	3	main
see	doc_634572338220_item	2777052	et	3	main
tulevastele	doc_634572338220_item	2777063	et	4	main
nõustuma	doc_634572338220_item	2777076	et	3	main
ei	doc_634572338220_item	2777079	et	4	main
ees	doc_634572338220_item	2777087	et	4	main
see	doc_634572338220_item	2777123	et	3	main
õigust	doc_634572338220_item	2777136	et	4	main
homses	doc_634572338220_item	2777155	et	3	main
nad	doc_634572338220_item	2777160	et	3	main
soovivad	doc_634572338220_item	2777176	et	4	main
pappi	doc_634572338220_item	2777178	et	4	main
reisida	doc_634572338220_item	2777179	et	3	main
ja	doc_634572338220_item	2777180	et	3	main
tõttamist	doc_634572338220_item	2777187	et	4	main
aga	doc_634572338220_item	2777188	et	3	main
selles	doc_634572338220_item	2777189	et	4	main
et	doc_634572338220_item	2777190	et	3	main
neljakümnesed	doc_634572338220_item	2777195	et	3	main
elada	doc_634572338220_item	2777198	et	3	main
niisuguste	doc_634572338220_item	2777204	et	3	main
on	doc_634572338219_item	2776822	et	4	main
need	doc_634572338219_item	2776824	et	3	main
tahavad	doc_634572338219_item	2776834	et	3	main
istuvad	doc_634572338219_item	2776849	et	4	main
ja	doc_634572338219_item	2776850	et	3	main
saa	doc_634572338219_item	2776856	et	4	main
aru	doc_634572338219_item	2776857	et	4	main
ei	doc_634572338219_item	2776862	et	4	main
tööd	doc_634572338219_item	2776864	et	4	main
kui	doc_634572338219_item	2776865	et	3	main
ma	doc_634572338219_item	2776866	et	3	main
meestele	doc_634572338219_item	2776868	et	4	main
pakkuvad	doc_634572338219_item	2776869	et	4	main
rohkem	doc_634572338219_item	2776870	et	4	main
töid	doc_634572338219_item	2776871	et	3	main
kui	doc_634572338219_item	2776872	et	3	main
neiule	doc_634572338219_item	2776873	et	4	main
ise	doc_634572338219_item	2776874	et	4	main
olen	doc_634572338219_item	2776875	et	3	main
niisamas	doc_634572338219_item	2776876	et	4	main
situatsioonis	doc_634572338219_item	2776877	et	3	main
kuna	doc_634572338219_item	2776878	et	3	main
otsin	doc_634572338219_item	2776879	et	3	main
tööd	doc_634572338219_item	2776880	et	4	main
endale	doc_634572338219_item	2776881	et	4	main
suvi	doc_634572338219_item	2776882	et	3	main
jooksul	doc_634572338219_item	2776883	et	4	main
aga	doc_634572338219_item	2776884	et	3	main
meie	doc_634572338219_item	2776885	et	4	main
linnas	doc_634572338219_item	2776886	et	4	main
tööd	doc_634572338219_item	2776890	et	4	main
et	doc_634572338219_item	2776900	et	3	main
raske	doc_634572338219_item	2776903	et	4	main
aga	doc_634572338219_item	2776911	et	3	main
riigis	doc_634572338219_item	2776918	et	3	main
mis	doc_634572338219_item	2776921	et	4	main
ettevaatlikut	doc_634572338219_item	2776923	et	4	main
ja	doc_634572338219_item	2776924	et	3	main
võtavad	doc_634572338219_item	2776925	et	3	main
koormust	doc_634572338219_item	2776927	et	4	main
tesied	doc_634572338219_item	2776933	et	4	main
nende	doc_634572338219_item	2776939	et	4	main
võib	doc_634572338219_item	2776944	et	3	main
minu	doc_634572338219_item	2776946	et	3	main
ja	doc_634572338219_item	2776961	et	3	main
muidugi	doc_634572338219_item	2776962	et	4	main
kui	doc_634572338219_item	2776968	et	3	main
väga	doc_634572338219_item	2776973	et	3	main
loodan	doc_634572338219_item	2776977	et	3	main
võttavad	doc_634572338219_item	2776986	et	4	main
muidugi	doc_634572338219_item	2776992	et	4	main
et	doc_634572338219_item	2777008	et	3	main
probleemi	doc_634572338219_item	2777011	et	4	main
ekspressi	doc_634572338220_item	2777018	et	4	main
toimetaja	doc_634572338220_item	2777019	et	4	main
artikli	doc_634572338220_item	2777022	et	3	main
vt	doc_634572338220_item	2777024	et	4	main
teie	doc_634572338220_item	2777039	et	4	main
artikli	doc_634572338220_item	2777040	et	3	main
vähenõudlike	doc_634572338220_item	2777041	et	3	main
artikkel	doc_634572338220_item	2777058	et	3	main
mis	doc_634572338220_item	2777059	et	4	main
toob	doc_634572338220_item	2777060	et	3	main
suur	doc_634572338220_item	2777061	et	3	main
kasu	doc_634572338220_item	2777062	et	4	main
millega	doc_634572338220_item	2777078	et	3	main
ma	doc_634572338220_item	2777084	et	3	main
valiku	doc_634572338220_item	2777086	et	3	main
kelleks	doc_634572338220_item	2777088	et	4	main
ma	doc_634572338220_item	2777089	et	3	main
ehitajad	doc_634572338219_item	2776930	et	4	main
lendurid	doc_634572338219_item	2776931	et	3	main
ja	doc_634572338219_item	2776932	et	3	main
see	doc_634572338219_item	2776936	et	3	main
olema	doc_634572338219_item	2776952	et	4	main
ainult	doc_634572338219_item	2776953	et	4	main
head	doc_634572338219_item	2776954	et	4	main
spetsialistid	doc_634572338219_item	2776955	et	3	main
kuna	doc_634572338219_item	2776956	et	3	main
nendest	doc_634572338219_item	2776957	et	4	main
sõltub	doc_634572338219_item	2776958	et	3	main
inimese	doc_634572338219_item	2776959	et	4	main
elu	doc_634572338219_item	2776960	et	4	main
suurt	doc_634572338219_item	2776926	et	3	main
ühendab	doc_634572338219_item	2776935	et	3	main
viga	doc_634572338219_item	2776938	et	4	main
ja	doc_634572338219_item	2776941	et	3	main
inimene	doc_634572338219_item	2776943	et	3	main
arstina	doc_634572338219_item	2776948	et	3	main
peab	doc_634572338219_item	2776965	et	4	main
nad	doc_634572338219_item	2776971	et	3	main
töö	doc_634572338219_item	2776975	et	4	main
inimestele	doc_634572338219_item	2776993	et	3	main
hästi	doc_634572338219_item	2776998	et	3	main
teile	doc_634572338219_item	2777007	et	4	main
seda	doc_634572338219_item	2777010	et	3	main
arvamus	doc_634572338220_item	2777015	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338220_item	2777025	et	4	main
põlvkond	doc_634572338220_item	2777042	et	3	main
huvitav	doc_634572338220_item	2777057	et	4	main
pärast	doc_634572338220_item	2777065	et	4	main
kuna	doc_634572338220_item	2777081	et	3	main
hiljuti	doc_634572338220_item	2777083	et	4	main
seisin	doc_634572338220_item	2777085	et	3	main
sellele	doc_634572338220_item	2777121	et	4	main
või	doc_634572338220_item	2777128	et	4	main
parem	doc_634572338220_item	2777144	et	4	main
selles	doc_634572338220_item	2777158	et	4	main
head	doc_634572338220_item	2777186	et	4	main
nagu	doc_634572338220_item	2777194	et	3	main
jõukalt	doc_634572338220_item	2777199	et	4	main
ma	doc_634572338220_item	2777214	et	3	main
olen	doc_634572338220_item	2777215	et	3	main
sajaprotsendiliselt	doc_634572338220_item	2777217	et	4	main
teie	doc_634572338220_item	2777218	et	4	main
arvamusega	doc_634572338220_item	2777219	et	3	main
et	doc_634572338220_item	2777220	et	3	main
suurem	doc_634572338219_item	2776967	et	4	main
teevad	doc_634572338219_item	2776972	et	3	main
et	doc_634572338219_item	2776978	et	3	main
osa	doc_634572338219_item	2776987	et	4	main
elu	doc_634572338219_item	2776988	et	4	main
kuna	doc_634572338219_item	2776994	et	3	main
keegi	doc_634572338219_item	2777000	et	4	main
olla	doc_634572338219_item	2777003	et	3	main
vaeseks	doc_634572338219_item	2777004	et	4	main
suur	doc_634572338219_item	2777005	et	3	main
aitäh	doc_634572338219_item	2777006	et	3	main
x	doc_634572338219_item	2777013	et	4	main
arvamuse	doc_634572338220_item	2777016	et	3	main
minu	doc_634572338220_item	2777029	et	3	main
ma	doc_634572338220_item	2777043	et	3	main
teile	doc_634572338220_item	2777046	et	4	main
seisukoht	doc_634572338220_item	2777048	et	3	main
lugemist	doc_634572338220_item	2777066	et	4	main
ma	doc_634572338220_item	2777067	et	3	main
mõtlesin	doc_634572338220_item	2777068	et	3	main
palju	doc_634572338220_item	2777069	et	4	main
aega	doc_634572338220_item	2777070	et	4	main
saa	doc_634572338220_item	2777080	et	4	main
täiesti	doc_634572338220_item	2777082	et	3	main
tahan	doc_634572338220_item	2777090	et	3	main
tulevikus	doc_634572338220_item	2777091	et	4	main
saada	doc_634572338220_item	2777092	et	4	main
ja	doc_634572338220_item	2777093	et	3	main
missuguses	doc_634572338220_item	2777094	et	3	main
ülikoolis	doc_634572338220_item	2777095	et	4	main
jätkuda	doc_634572338220_item	2777096	et	3	main
oma	doc_634572338220_item	2777097	et	4	main
õpingut	doc_634572338220_item	2777098	et	3	main
muidugi	doc_634572338220_item	2777099	et	4	main
meie	doc_634572338220_item	2777100	et	4	main
ajal	doc_634572338220_item	2777101	et	4	main
enamus	doc_634572338220_item	2777102	et	4	main
noordest	doc_634572338220_item	2777103	et	4	main
valib	doc_634572338220_item	2777104	et	3	main
niisugust	doc_634572338220_item	2777105	et	3	main
elukutset	doc_634572338220_item	2777106	et	3	main
mis	doc_634572338220_item	2777107	et	4	main
tulevikus	doc_634572338220_item	2777108	et	4	main
annaks	doc_634572338220_item	2777109	et	4	main
piisavalt	doc_634572338220_item	2777110	et	4	main
raha	doc_634572338220_item	2777111	et	4	main
et	doc_634572338220_item	2777112	et	3	main
oleks	doc_634572338220_item	2777113	et	3	main
ja	doc_634572338220_item	2777114	et	3	main
auto	doc_634572338220_item	2777115	et	4	main
ja	doc_634572338220_item	2777116	et	3	main
väike	doc_634572338220_item	2777117	et	4	main
maja	doc_634572338220_item	2777118	et	4	main
validakse	doc_634572338220_item	2777119	et	4	main
vaatamata	doc_634572338220_item	2777120	et	4	main
sobi	doc_634572338220_item	2777127	et	4	main
huvita	doc_634572338220_item	2777130	et	4	main
inimesi	doc_634572338220_item	2777137	et	4	main
päevas	doc_634572338220_item	2777156	et	3	main
saavad	doc_634572338220_item	2777161	et	4	main
et	doc_634572338220_item	2777174	et	3	main
ainult	doc_634572338220_item	2777185	et	4	main
tahavad	doc_634572338220_item	2777192	et	3	main
soov	doc_634572338220_item	2777197	et	3	main
millega	doc_634572338220_item	2777072	et	3	main
ma	doc_634572338220_item	2777073	et	3	main
saan	doc_634572338220_item	2777074	et	4	main
teiega	doc_634572338220_item	2777075	et	3	main
ja	doc_634572338220_item	2777077	et	3	main
et	doc_634572338220_item	2777122	et	3	main
eriala	doc_634572338220_item	2777124	et	4	main
neile	doc_634572338220_item	2777125	et	4	main
ei	doc_634572338220_item	2777129	et	4	main
üldse	doc_634572338220_item	2777132	et	3	main
ei	doc_634572338220_item	2777134	et	4	main
ole	doc_634572338220_item	2777135	et	4	main
südistama	doc_634572338220_item	2777138	et	4	main
selles	doc_634572338220_item	2777139	et	4	main
et	doc_634572338220_item	2777140	et	3	main
nad	doc_634572338220_item	2777141	et	3	main
tahaksid	doc_634572338220_item	2777142	et	4	main
elada	doc_634572338220_item	2777143	et	3	main
ja	doc_634572338220_item	2777157	et	3	main
et	doc_634572338220_item	2777159	et	3	main
anda	doc_634572338220_item	2777162	et	3	main
elada	doc_634572338220_item	2777193	et	3	main
muretult	doc_634572338220_item	2777201	et	4	main
ma	doc_634572338220_item	2777202	et	3	main
olen	doc_634572338220_item	2777203	et	3	main
eesmärkidega	doc_634572338220_item	2777205	et	3	main
päri	doc_634572338220_item	2777207	et	4	main
kui	doc_634572338220_item	2777208	et	3	main
need	doc_634572338220_item	2777209	et	3	main
mis	doc_634572338220_item	2777235	et	4	main
vaja	doc_634572338220_item	2777238	et	4	main
tundub	doc_634572338220_item	2777253	et	3	main
teie	doc_634572338220_item	2777267	et	4	main
ma	doc_634572338220_item	2777286	et	3	main
tahaksin	doc_634572338220_item	2777287	et	3	main
tänada	doc_634572338220_item	2777288	et	3	main
teid	doc_634572338220_item	2777289	et	4	main
nõus	doc_634572338222_item	2777442	et	4	main
väidetega	doc_634572338222_item	2777443	et	3	main
hoolikalt	doc_634572338222_item	2777449	et	4	main
2	doc_634572338222_item	2777450	et	2	main
kasutage	doc_634572338222_item	2777451	et	3	main
3	doc_634572338222_item	2777455	et	2	main
toiduained	doc_634572338222_item	2777457	et	3	main
toitu	doc_634572338222_item	2777468	et	4	main
põhjalikult	doc_634572338222_item	2777469	et	4	main
sailitage	doc_634572338222_item	2777471	et	4	main
toitu	doc_634572338222_item	2777473	et	4	main
arvates	doc_634572338222_item	2777477	et	4	main
saab	doc_634572338222_item	2777488	et	3	main
kahjustada	doc_634572338222_item	2777489	et	3	main
meie	doc_634572338222_item	2777498	et	4	main
maailmas	doc_634572338222_item	2777499	et	3	main
parem	doc_634572338222_item	2777512	et	4	main
ei	doc_634572338220_item	2777126	et	4	main
neid	doc_634572338220_item	2777131	et	4	main
meil	doc_634572338220_item	2777133	et	4	main
heaolus	doc_634572338220_item	2777145	et	3	main
ma	doc_634572338220_item	2777146	et	3	main
arvan	doc_634572338220_item	2777147	et	3	main
et	doc_634572338220_item	2777148	et	3	main
igal	doc_634572338220_item	2777149	et	3	main
inimesel	doc_634572338220_item	2777150	et	3	main
on	doc_634572338220_item	2777151	et	4	main
soov	doc_634572338220_item	2777152	et	3	main
kindel	doc_634572338220_item	2777153	et	3	main
olla	doc_634572338220_item	2777154	et	3	main
oma	doc_634572338220_item	2777163	et	4	main
lastele	doc_634572338220_item	2777164	et	4	main
kõik	doc_634572338220_item	2777165	et	4	main
terveslik	doc_634572338220_item	2777166	et	4	main
toitumine	doc_634572338220_item	2777167	et	4	main
õppimine	doc_634572338220_item	2777168	et	4	main
heas	doc_634572338220_item	2777169	et	3	main
koolis	doc_634572338220_item	2777170	et	4	main
ja	doc_634572338220_item	2777171	et	3	main
ülikoolis	doc_634572338220_item	2777172	et	4	main
selles	doc_634572338220_item	2777173	et	4	main
noored	doc_634572338220_item	2777175	et	3	main
palju	doc_634572338220_item	2777177	et	4	main
maja	doc_634572338220_item	2777181	et	4	main
liisida	doc_634572338220_item	2777182	et	4	main
ma	doc_634572338220_item	2777183	et	3	main
näen	doc_634572338220_item	2777184	et	3	main
kahekümneaastased	doc_634572338220_item	2777191	et	4	main
näen	doc_634572338220_item	2777196	et	3	main
ole	doc_634572338220_item	2777211	et	4	main
palju	doc_634572338220_item	2777222	et	4	main
inimesed	doc_634572338220_item	2777231	et	3	main
kes	doc_634572338220_item	2777232	et	4	main
üldse	doc_634572338220_item	2777239	et	3	main
pole	doc_634572338220_item	2777241	et	3	main
seisukohta	doc_634572338220_item	2777243	et	4	main
need	doc_634572338220_item	2777255	et	3	main
on	doc_634572338220_item	2777256	et	4	main
elus	doc_634572338220_item	2777263	et	4	main
ma	doc_634572338220_item	2777264	et	3	main
jagan	doc_634572338220_item	2777265	et	3	main
eest	doc_634572338220_item	2777292	et	4	main
soovitega	doc_634572338220_item	2777294	et	4	main
x	doc_634572338220_item	2777295	et	4	main
1	doc_634572338222_item	2777444	et	2	main
käsi	doc_634572338222_item	2777446	et	4	main
ja	doc_634572338222_item	2777448	et	3	main
puhast	doc_634572338222_item	2777453	et	3	main
oma	doc_634572338222_item	2777459	et	4	main
olemuselt	doc_634572338222_item	2777460	et	3	main
4	doc_634572338222_item	2777466	et	2	main
valmistage	doc_634572338222_item	2777467	et	3	main
1	doc_634572338222_item	2777475	et	2	main
palju	doc_634572338222_item	2777485	et	4	main
oluline	doc_634572338222_item	2777496	et	4	main
inimesed	doc_634572338222_item	2777502	et	3	main
vett	doc_634572338222_item	2777504	et	3	main
kui	doc_634572338222_item	2777506	et	3	main
kasutab	doc_634572338222_item	2777508	et	3	main
veet	doc_634572338222_item	2777510	et	4	main
valida	doc_634572338222_item	2777529	et	3	main
vaja	doc_634572338222_item	2777542	et	4	main
on	doc_634572338222_item	2777560	et	4	main
oma	doc_634572338222_item	2777570	et	4	main
aega	doc_634572338222_item	2777582	et	4	main
peab	doc_634572338222_item	2777583	et	4	main
tõlgi	doc_634572338223_item	2777590	et	4	main
джек	doc_634572338223_item	2777591	et	2	main
килби	doc_634572338223_item	2777592	et	2	main
родился	doc_634572338223_item	2777593	et	2	main
интегральные	doc_634572338223_item	2777623	et	2	main
или	doc_634572338223_item	2777628	et	2	main
развиваться	doc_634572338223_item	2777635	et	2	main
лежит	doc_634572338223_item	2777641	et	2	main
всей	doc_634572338223_item	2777644	et	2	main
можно	doc_634572338223_item	2777650	et	2	main
они	doc_634572338223_item	2777656	et	2	main
ja	doc_634572338220_item	2777200	et	3	main
täiesti	doc_634572338220_item	2777206	et	3	main
ei	doc_634572338220_item	2777210	et	4	main
kriminaaliga	doc_634572338220_item	2777213	et	4	main
saavad	doc_634572338220_item	2777228	et	4	main
on	doc_634572338220_item	2777229	et	4	main
ka	doc_634572338220_item	2777230	et	3	main
neil	doc_634572338220_item	2777236	et	4	main
tulevikut	doc_634572338220_item	2777246	et	4	main
erialat	doc_634572338220_item	2777247	et	4	main
et	doc_634572338220_item	2777254	et	3	main
nõrgad	doc_634572338220_item	2777257	et	3	main
inimesed	doc_634572338220_item	2777258	et	3	main
on	doc_634572338220_item	2777260	et	4	main
väga	doc_634572338220_item	2777261	et	3	main
huvitava	doc_634572338220_item	2777290	et	4	main
parimate	doc_634572338220_item	2777293	et	4	main
harjutus	doc_634572338222_item	2777439	et	4	main
kas	doc_634572338222_item	2777440	et	3	main
ainult	doc_634572338222_item	2777452	et	4	main
valige	doc_634572338222_item	2777456	et	3	main
mis	doc_634572338222_item	2777458	et	4	main
vajalikult	doc_634572338222_item	2777464	et	4	main
töödeldud	doc_634572338222_item	2777465	et	4	main
see	doc_634572338222_item	2777478	et	3	main
tahtis	doc_634572338222_item	2777481	et	3	main
seal	doc_634572338222_item	2777483	et	4	main
kogunevad	doc_634572338222_item	2777484	et	4	main
iga	doc_634572338222_item	2777500	et	4	main
kasutavad	doc_634572338222_item	2777503	et	4	main
nõus	doc_634572338222_item	2777519	et	4	main
vaga	doc_634572338222_item	2777524	et	4	main
inimene	doc_634572338222_item	2777527	et	3	main
puhas	doc_634572338222_item	2777531	et	3	main
suur	doc_634572338222_item	2777545	et	3	main
temperatuur	doc_634572338222_item	2777546	et	3	main
mikroobi	doc_634572338222_item	2777549	et	4	main
kui	doc_634572338222_item	2777551	et	3	main
aega	doc_634572338222_item	2777555	et	4	main
inimesele	doc_634572338222_item	2777565	et	3	main
kui	doc_634572338222_item	2777573	et	3	main
ei	doc_634572338222_item	2777575	et	4	main
taha	doc_634572338222_item	2777576	et	4	main
hoolikalt	doc_634572338222_item	2777585	et	4	main
säilitada	doc_634572338222_item	2777586	et	3	main
oma	doc_634572338222_item	2777587	et	4	main
toitu	doc_634572338222_item	2777588	et	4	main
tõlge	doc_634572338223_item	2777589	et	3	main
микросхемы	doc_634572338223_item	2777627	et	2	main
этому	doc_634572338223_item	2777631	et	2	main
стала	doc_634572338223_item	2777633	et	2	main
в	doc_634572338223_item	2777638	et	2	main
основе	doc_634572338223_item	2777643	et	2	main
техники	doc_634572338223_item	2777646	et	2	main
назвать	doc_634572338223_item	2777651	et	2	main
и	doc_634572338223_item	2777654	et	2	main
механизмов	doc_634572338223_item	2777664	et	2	main
автомобиля	doc_634572338223_item	2777669	et	2	main
спутников	doc_634572338223_item	2777672	et	2	main
томографа	doc_634572338223_item	2777679	et	2	main
ядерного	doc_634572338223_item	2777684	et	2	main
жизнь	doc_634572338223_item	2777690	et	2	main
seotud	doc_634572338220_item	2777212	et	4	main
nõus	doc_634572338220_item	2777216	et	4	main
sisse	doc_634572338220_item	2777227	et	4	main
tea	doc_634572338220_item	2777234	et	4	main
kellel	doc_634572338220_item	2777240	et	4	main
oma	doc_634572338220_item	2777242	et	4	main
ja	doc_634572338220_item	2777244	et	3	main
kuulades	doc_634572338220_item	2777248	et	3	main
mul	doc_634572338220_item	2777252	et	3	main
kellel	doc_634572338220_item	2777259	et	4	main
raske	doc_634572338220_item	2777262	et	4	main
artikli	doc_634572338220_item	2777291	et	3	main
peske	doc_634572338222_item	2777445	et	3	main
korduvalt	doc_634572338222_item	2777447	et	4	main
on	doc_634572338222_item	2777461	et	4	main
ohutumad	doc_634572338222_item	2777462	et	4	main
valmistatud	doc_634572338222_item	2777472	et	4	main
hoolikalt	doc_634572338222_item	2777474	et	4	main
minu	doc_634572338222_item	2777476	et	3	main
aegaga	doc_634572338222_item	2777482	et	4	main
asi	doc_634572338222_item	2777497	et	4	main
väitega	doc_634572338222_item	2777521	et	3	main
sõltub	doc_634572338222_item	2777523	et	3	main
kasulik	doc_634572338222_item	2777533	et	3	main
mina	doc_634572338222_item	2777536	et	4	main
valmistada	doc_634572338222_item	2777543	et	3	main
põhjalikult	doc_634572338222_item	2777544	et	4	main
tapab	doc_634572338222_item	2777547	et	3	main
aga	doc_634572338222_item	2777550	et	3	main
toit	doc_634572338222_item	2777552	et	3	main
vähem	doc_634572338222_item	2777561	et	4	main
võimalusi	doc_634572338222_item	2777562	et	3	main
mikroobidel	doc_634572338222_item	2777563	et	3	main
kahjustada	doc_634572338222_item	2777564	et	3	main
5	doc_634572338222_item	2777566	et	2	main
toituainedel	doc_634572338222_item	2777568	et	4	main
kehtivuse	doc_634572338222_item	2777571	et	4	main
inimene	doc_634572338222_item	2777574	et	3	main
ta	doc_634572338222_item	2777584	et	4	main
1923	doc_634572338223_item	2777595	et	2	main
развил	doc_634572338223_item	2777622	et	2	main
благодаря	doc_634572338223_item	2777630	et	2	main
которая	doc_634572338223_item	2777637	et	2	main
время	doc_634572338223_item	2777640	et	2	main
качестве	doc_634572338223_item	2777648	et	2	main
компьютеры	doc_634572338223_item	2777653	et	2	main
работу	doc_634572338223_item	2777662	et	2	main
и	doc_634572338223_item	2777668	et	2	main
медицинского	doc_634572338223_item	2777674	et	2	main
компьютерного	doc_634572338223_item	2777678	et	2	main
на	doc_634572338223_item	2777682	et	2	main
резонанса	doc_634572338223_item	2777686	et	2	main
небольшой	doc_634572338223_item	2777691	et	2	main
от	doc_634572338223_item	2777696	et	2	main
и	doc_634572338223_item	2777699	et	2	main
калькуляторов	doc_634572338223_item	2777703	et	2	main
kodanik	doc_634572338223_item	2777719	et	3	main
am	doc_634572338223_item	2777729	et	4	main
professor	doc_634572338223_item	2777730	et	3	main
djek	doc_634572338223_item	2777731	et	4	main
avastas	doc_634572338223_item	2777733	et	3	main
ja	doc_634572338223_item	2777734	et	3	main
arendas	doc_634572338223_item	2777735	et	3	main
on	doc_634572338220_item	2777221	et	4	main
inimesi	doc_634572338220_item	2777223	et	4	main
kes	doc_634572338220_item	2777224	et	4	main
lähevad	doc_634572338220_item	2777225	et	3	main
kuhu	doc_634572338220_item	2777226	et	3	main
ei	doc_634572338220_item	2777233	et	4	main
on	doc_634572338220_item	2777237	et	4	main
valivad	doc_634572338220_item	2777245	et	4	main
vanemaid	doc_634572338220_item	2777249	et	4	main
ja	doc_634572338220_item	2777250	et	3	main
sõpru	doc_634572338220_item	2777251	et	3	main
ka	doc_634572338220_item	2777266	et	3	main
arvamust	doc_634572338220_item	2777268	et	3	main
et	doc_634572338220_item	2777269	et	3	main
meie	doc_634572338220_item	2777270	et	4	main
noorel	doc_634572338220_item	2777271	et	3	main
riigil	doc_634572338220_item	2777272	et	3	main
on	doc_634572338220_item	2777273	et	4	main
vajalik	doc_634572338220_item	2777274	et	3	main
inimesed	doc_634572338220_item	2777275	et	3	main
kes	doc_634572338220_item	2777276	et	4	main
teaksid	doc_634572338220_item	2777277	et	4	main
mida	doc_634572338220_item	2777278	et	4	main
ja	doc_634572338220_item	2777279	et	3	main
kui	doc_634572338220_item	2777280	et	3	main
teha	doc_634572338220_item	2777281	et	3	main
meie	doc_634572338220_item	2777282	et	4	main
riik	doc_634572338220_item	2777283	et	3	main
paremaks	doc_634572338220_item	2777284	et	4	main
lõpuks	doc_634572338220_item	2777285	et	4	main
olete	doc_634572338222_item	2777441	et	3	main
vett	doc_634572338222_item	2777454	et	3	main
või	doc_634572338222_item	2777463	et	4	main
5	doc_634572338222_item	2777470	et	2	main
on	doc_634572338222_item	2777479	et	4	main
väga	doc_634572338222_item	2777480	et	3	main
mikroobi	doc_634572338222_item	2777486	et	4	main
mis	doc_634572338222_item	2777487	et	4	main
tervist	doc_634572338222_item	2777490	et	4	main
2	doc_634572338222_item	2777491	et	2	main
vett	doc_634572338222_item	2777492	et	3	main
see	doc_634572338222_item	2777493	et	3	main
on	doc_634572338222_item	2777494	et	4	main
väga	doc_634572338222_item	2777495	et	3	main
päev	doc_634572338222_item	2777501	et	3	main
sellepärast	doc_634572338222_item	2777505	et	3	main
inimene	doc_634572338222_item	2777507	et	3	main
puhas	doc_634572338222_item	2777509	et	3	main
siis	doc_634572338222_item	2777511	et	3	main
selle	doc_634572338222_item	2777520	et	4	main
toitudest	doc_634572338222_item	2777522	et	3	main
sellepärast	doc_634572338222_item	2777526	et	3	main
ainult	doc_634572338222_item	2777530	et	4	main
toit	doc_634572338222_item	2777534	et	3	main
olen	doc_634572338222_item	2777537	et	3	main
on	doc_634572338222_item	2777541	et	4	main
palju	doc_634572338222_item	2777548	et	4	main
valmistatakse	doc_634572338222_item	2777553	et	3	main
palju	doc_634572338222_item	2777554	et	4	main
ja	doc_634572338222_item	2777556	et	3	main
suure	doc_634572338222_item	2777557	et	3	main
temperaturiga	doc_634572338222_item	2777558	et	4	main
siis	doc_634572338222_item	2777559	et	3	main
aeg	doc_634572338222_item	2777572	et	3	main
varem	doc_634572338222_item	2777580	et	4	main
в	doc_634572338223_item	2777594	et	2	main
и	doc_634572338223_item	2777621	et	2	main
tema	doc_634572338222_item	2777513	et	4	main
tervis	doc_634572338222_item	2777514	et	3	main
3	doc_634572338222_item	2777515	et	2	main
ma	doc_634572338222_item	2777516	et	3	main
olen	doc_634572338222_item	2777517	et	3	main
täiesti	doc_634572338222_item	2777518	et	3	main
palju	doc_634572338222_item	2777525	et	4	main
peab	doc_634572338222_item	2777528	et	4	main
ja	doc_634572338222_item	2777532	et	3	main
4	doc_634572338222_item	2777535	et	2	main
nõus	doc_634572338222_item	2777538	et	4	main
et	doc_634572338222_item	2777539	et	3	main
toitu	doc_634572338222_item	2777540	et	4	main
kõikidel	doc_634572338222_item	2777567	et	4	main
on	doc_634572338222_item	2777569	et	4	main
et	doc_634572338222_item	2777577	et	3	main
toit	doc_634572338222_item	2777578	et	3	main
rikkub	doc_634572338222_item	2777579	et	4	main
kehtivuse	doc_634572338222_item	2777581	et	4	main
году	doc_634572338223_item	2777596	et	2	main
в	doc_634572338223_item	2777597	et	2	main
джефферсон-сити	doc_634572338223_item	2777598	et	2	main
миссури	doc_634572338223_item	2777599	et	2	main
сша	doc_634572338223_item	2777600	et	2	main
гражданин	doc_634572338223_item	2777601	et	2	main
соединённых	doc_634572338223_item	2777602	et	2	main
штатов	doc_634572338223_item	2777603	et	2	main
1958	doc_634572338223_item	2777605	et	2	main
с	doc_634572338223_item	2777604	et	2	main
года	doc_634572338223_item	2777606	et	2	main
работал	doc_634572338223_item	2777607	et	2	main
в	doc_634572338223_item	2777608	et	2	main
texas	doc_634572338223_item	2777609	et	4	main
instruments	doc_634572338223_item	2777610	et	4	main
техасского	doc_634572338223_item	2777612	et	2	main
профессор	doc_634572338223_item	2777611	et	2	main
университета	doc_634572338223_item	2777613	et	2	main
am	doc_634572338223_item	2777614	et	4	main
в	doc_634572338223_item	2777615	et	2	main
1978-85	doc_634572338223_item	2777616	et	2	main
джек	doc_634572338223_item	2777618	et	2	main
килби	doc_634572338223_item	2777619	et	2	main
открыл	doc_634572338223_item	2777620	et	2	main
годах	doc_634572338223_item	2777617	et	2	main
схемы	doc_634572338223_item	2777624	et	2	main
название	doc_634572338223_item	2777626	et	2	main
открытию	doc_634572338223_item	2777632	et	2	main
микроэлектроника	doc_634572338223_item	2777636	et	2	main
в	doc_634572338223_item	2777642	et	2	main
в	doc_634572338223_item	2777647	et	2	main
мощные	doc_634572338223_item	2777652	et	2	main
всех	doc_634572338223_item	2777663	et	2	main
машины	doc_634572338223_item	2777667	et	2	main
диагностического	doc_634572338223_item	2777675	et	2	main
и	doc_634572338223_item	2777680	et	2	main
магнитного	doc_634572338223_item	2777685	et	2	main
нашу	doc_634572338223_item	2777689	et	2	main
аппаратурой	doc_634572338223_item	2777695	et	2	main
игр	doc_634572338223_item	2777701	et	2	main
домашних	doc_634572338223_item	2777705	et	2	main
получившие	doc_634572338223_item	2777625	et	2	main
чипа	doc_634572338223_item	2777629	et	2	main
быстро	doc_634572338223_item	2777634	et	2	main
настоящее	doc_634572338223_item	2777639	et	2	main
современной	doc_634572338223_item	2777645	et	2	main
примера	doc_634572338223_item	2777649	et	2	main
процессоры	doc_634572338223_item	2777655	et	2	main
собирают	doc_634572338223_item	2777657	et	2	main
и	doc_634572338223_item	2777658	et	2	main
обрабатывают	doc_634572338223_item	2777659	et	2	main
контролируют	doc_634572338223_item	2777661	et	2	main
информацию	doc_634572338223_item	2777660	et	2	main
от	doc_634572338223_item	2777665	et	2	main
стиральной	doc_634572338223_item	2777666	et	2	main
космических	doc_634572338223_item	2777671	et	2	main
например	doc_634572338223_item	2777677	et	2	main
основе	doc_634572338223_item	2777683	et	2	main
микросхемы	doc_634572338223_item	2777687	et	2	main
по	doc_634572338223_item	2777692	et	2	main
часов	doc_634572338223_item	2777698	et	2	main
и	doc_634572338223_item	2777704	et	2	main
1923	doc_634572338223_item	2777710	et	2	main
riikide	doc_634572338223_item	2777718	et	3	main
töötas	doc_634572338223_item	2777722	et	3	main
instruments	doc_634572338223_item	2777724	et	4	main
1978-85	doc_634572338223_item	2777726	et	2	main
texase	doc_634572338223_item	2777727	et	4	main
integraalskeemid	doc_634572338223_item	2777736	et	4	main
kiibid	doc_634572338223_item	2777742	et	3	main
tänu	doc_634572338223_item	2777743	et	4	main
mis	doc_634572338223_item	2777749	et	4	main
kogu	doc_634572338223_item	2777751	et	4	main
aegse	doc_634572338223_item	2777753	et	3	main
tehnika	doc_634572338223_item	2777754	et	4	main
võimsad	doc_634572338223_item	2777759	et	3	main
protsessorid	doc_634572338223_item	2777762	et	3	main
töötlevad	doc_634572338223_item	2777766	et	4	main
mehanismeid	doc_634572338223_item	2777771	et	4	main
ja	doc_634572338223_item	2777774	et	3	main
kosmosi	doc_634572338223_item	2777777	et	3	main
ja	doc_634572338223_item	2777779	et	3	main
diagnostika	doc_634572338223_item	2777781	et	4	main
arvutitomograafia	doc_634572338223_item	2777784	et	4	main
tuuma	doc_634572338223_item	2777785	et	4	main
elektronkellad	doc_634572338223_item	2777794	et	3	main
alouseks	doc_634572338224_item	2777821	et	4	main
vaja	doc_634572338224_item	2777823	et	4	main
teha	doc_634572338224_item	2777824	et	3	main
seda	doc_634572338224_item	2777831	et	3	main
teha	doc_634572338224_item	2777835	et	3	main
teeme	doc_634572338224_item	2777839	et	3	main
külmkapp	doc_634572338224_item	2777847	et	3	main
muutuseta	doc_634572338224_item	2777856	et	4	main
sina	doc_634572338224_item	2777857	et	4	main
on	doc_634572338224_item	2777866	et	4	main
teha	doc_634572338224_item	2777868	et	3	main
2	doc_634572338224_item	2777872	et	2	main
pinka	doc_634572338224_item	2777873	et	3	main
põrand	doc_634572338224_item	2777875	et	3	main
pust	doc_634572338224_item	2777878	et	4	main
riulit	doc_634572338224_item	2777881	et	4	main
on	doc_634572338224_item	2777883	et	4	main
2	doc_634572338224_item	2777885	et	2	main
essee	doc_634572338225_item	2777895	et	4	main
kodu	doc_634572338225_item	2777899	et	4	main
vanituba	doc_634572338225_item	2777907	et	4	main
ma	doc_634572338225_item	2777911	et	3	main
teen	doc_634572338225_item	2777912	et	3	main
ja	doc_634572338225_item	2777922	et	3	main
pahteldan	doc_634572338225_item	2777931	et	3	main
värvin	doc_634572338225_item	2777936	et	3	main
ainult	doc_634572338225_item	2777946	et	4	main
krohvimist	doc_634572338225_item	2777953	et	4	main
ma	doc_634572338225_item	2777954	et	3	main
teen	doc_634572338225_item	2777955	et	3	main
ventilatsion	doc_634572338225_item	2777959	et	4	main
pärast	doc_634572338225_item	2777965	et	4	main
keldris	doc_634572338225_item	2777966	et	3	main
võib	doc_634572338225_item	2777967	et	3	main
mööblit	doc_634572338225_item	2777968	et	3	main
paigaldama	doc_634572338225_item	2777969	et	3	main
köögis	doc_634572338225_item	2777970	et	3	main
voodi	doc_634572338225_item	2777998	et	4	main
koos	doc_634572338225_item	2778000	et	4	main
kapp	doc_634572338225_item	2778003	et	3	main
koristamisega	doc_634572338225_item	2778008	et	4	main
до	doc_634572338223_item	2777670	et	2	main
и	doc_634572338223_item	2777673	et	2	main
оборудования	doc_634572338223_item	2777676	et	2	main
приборов	doc_634572338223_item	2777681	et	2	main
наводнили	doc_634572338223_item	2777688	et	2	main
объёму	doc_634572338223_item	2777693	et	2	main
электронных	doc_634572338223_item	2777697	et	2	main
до	doc_634572338223_item	2777702	et	2	main
djek	doc_634572338223_item	2777707	et	4	main
aastal	doc_634572338223_item	2777711	et	3	main
usa	doc_634572338223_item	2777712	et	4	main
osarigis	doc_634572338223_item	2777714	et	4	main
aastast	doc_634572338223_item	2777720	et	4	main
1958	doc_634572338223_item	2777721	et	2	main
nimetuse	doc_634572338223_item	2777739	et	4	main
mikroskeemid	doc_634572338223_item	2777740	et	3	main
arenema	doc_634572338223_item	2777747	et	3	main
on	doc_634572338223_item	2777750	et	4	main
näiteks	doc_634572338223_item	2777756	et	4	main
tuua	doc_634572338223_item	2777758	et	3	main
arvutid	doc_634572338223_item	2777760	et	4	main
nad	doc_634572338223_item	2777763	et	3	main
ümber	doc_634572338223_item	2777767	et	3	main
kõikide	doc_634572338223_item	2777770	et	4	main
autotest	doc_634572338223_item	2777775	et	3	main
näiteks	doc_634572338223_item	2777783	et	4	main
magneetilise	doc_634572338223_item	2777786	et	4	main
täidsid	doc_634572338223_item	2777789	et	4	main
eluväikese	doc_634572338223_item	2777791	et	4	main
telemängud-	doc_634572338223_item	2777796	et	3	main
vaheseinu	doc_634572338224_item	2777836	et	3	main
laadus	doc_634572338224_item	2777841	et	4	main
laadu	doc_634572338224_item	2777845	et	4	main
ka	doc_634572338224_item	2777854	et	3	main
puust	doc_634572338224_item	2777859	et	4	main
riulid	doc_634572338224_item	2777860	et	4	main
olema	doc_634572338224_item	2777863	et	4	main
seinale	doc_634572338224_item	2777876	et	3	main
klaaslaud	doc_634572338224_item	2777891	et	4	main
elektrisaun	doc_634572338224_item	2777894	et	3	main
minu	doc_634572338225_item	2777896	et	3	main
ehitamisest	doc_634572338225_item	2777917	et	4	main
panin	doc_634572338225_item	2777923	et	3	main
ma	doc_634572338225_item	2777935	et	3	main
seinu	doc_634572338225_item	2777938	et	3	main
vannitoas	doc_634572338225_item	2777947	et	3	main
niiskustõke	doc_634572338225_item	2777957	et	3	main
lõpetan	doc_634572338225_item	2778007	et	3	main
электронной	doc_634572338223_item	2777694	et	2	main
телевизионных	doc_634572338223_item	2777700	et	2	main
компьютеров	doc_634572338223_item	2777706	et	2	main
kilbi	doc_634572338223_item	2777708	et	3	main
citys	doc_634572338223_item	2777716	et	4	main
ühend	doc_634572338223_item	2777717	et	3	main
texas	doc_634572338223_item	2777723	et	4	main
aastatel	doc_634572338223_item	2777725	et	4	main
kilbi	doc_634572338223_item	2777732	et	3	main
või	doc_634572338223_item	2777741	et	4	main
mikroelektronika	doc_634572338223_item	2777748	et	4	main
aluseks	doc_634572338223_item	2777755	et	4	main
ja	doc_634572338223_item	2777765	et	3	main
informatsiooni	doc_634572338223_item	2777768	et	4	main
kontrollivad	doc_634572338223_item	2777769	et	4	main
kuni	doc_634572338223_item	2777776	et	3	main
meditsiinilise	doc_634572338223_item	2777780	et	4	main
seadmeteni	doc_634572338223_item	2777782	et	3	main
elektronilise	doc_634572338223_item	2777792	et	4	main
aparatuuriga-	doc_634572338223_item	2777793	et	3	main
kalkulatori	doc_634572338223_item	2777798	et	4	main
sest	doc_634572338224_item	2777826	et	4	main
seinad	doc_634572338224_item	2777829	et	3	main
pärast	doc_634572338224_item	2777832	et	4	main
seda	doc_634572338224_item	2777833	et	3	main
võib	doc_634572338224_item	2777834	et	3	main
sisukujundust	doc_634572338224_item	2777840	et	3	main
jagutakse	doc_634572338224_item	2777842	et	4	main
ja	doc_634572338224_item	2777846	et	3	main
külmkappis	doc_634572338224_item	2777861	et	4	main
10c	doc_634572338224_item	2777864	et	4	main
plaaditud	doc_634572338224_item	2777874	et	4	main
panen	doc_634572338224_item	2777877	et	3	main
puupõrand	doc_634572338224_item	2777884	et	3	main
teine	doc_634572338224_item	2777887	et	3	main
ja	doc_634572338224_item	2777890	et	3	main
on	doc_634572338224_item	2777893	et	4	main
ja	doc_634572338225_item	2777908	et	3	main
esimesena	doc_634572338225_item	2777910	et	3	main
vaheseinu	doc_634572338225_item	2777913	et	3	main
põrand	doc_634572338225_item	2777920	et	3	main
uuesti	doc_634572338225_item	2777921	et	3	main
ma	doc_634572338225_item	2777926	et	3	main
neid	doc_634572338225_item	2777932	et	4	main
seda	doc_634572338225_item	2777934	et	3	main
parketti	doc_634572338225_item	2777945	et	4	main
koridooris	doc_634572338225_item	2777949	et	4	main
plaatin	doc_634572338225_item	2777950	et	4	main
korralik	doc_634572338225_item	2777956	et	3	main
ja	doc_634572338225_item	2777958	et	3	main
džakuzi	doc_634572338225_item	2777992	et	2	main
ja	doc_634572338225_item	2778004	et	3	main
sündis	doc_634572338223_item	2777709	et	3	main
missuri	doc_634572338223_item	2777713	et	4	main
jeferson	doc_634572338223_item	2777715	et	4	main
ülikooli	doc_634572338223_item	2777728	et	4	main
said	doc_634572338223_item	2777738	et	4	main
avastuselehakkas	doc_634572338223_item	2777745	et	4	main
kiiresti	doc_634572338223_item	2777746	et	3	main
võib	doc_634572338223_item	2777757	et	3	main
ja	doc_634572338223_item	2777761	et	3	main
koguvad	doc_634572338223_item	2777764	et	4	main
tööd	doc_634572338223_item	2777772	et	4	main
mikroskeemi	doc_634572338223_item	2777788	et	4	main
ja	doc_634572338223_item	2777795	et	3	main
kuni	doc_634572338223_item	2777797	et	3	main
ja	doc_634572338223_item	2777799	et	3	main
essee	doc_634572338224_item	2777801	et	4	main
keldris	doc_634572338224_item	2777802	et	3	main
koduarvutid	doc_634572338223_item	2777800	et	4	main
keldris	doc_634572338224_item	2777803	et	3	main
teen	doc_634572338224_item	2777804	et	3	main
3	doc_634572338224_item	2777805	et	2	main
ruumi	doc_634572338224_item	2777806	et	4	main
sauna	doc_634572338224_item	2777807	et	4	main
pesumisruum	doc_634572338224_item	2777808	et	3	main
ja	doc_634572338224_item	2777809	et	3	main
ladu	doc_634572338224_item	2777810	et	4	main
väljapääs	doc_634572338224_item	2777811	et	3	main
asub	doc_634572338224_item	2777812	et	3	main
pesumisruumis	doc_634572338224_item	2777813	et	3	main
selle	doc_634572338224_item	2777814	et	4	main
mööda	doc_634572338224_item	2777815	et	4	main
võib	doc_634572338224_item	2777816	et	3	main
minna	doc_634572338224_item	2777817	et	3	main
laadusse	doc_634572338224_item	2777818	et	3	main
ja	doc_634572338224_item	2777819	et	3	main
sauna	doc_634572338224_item	2777820	et	4	main
mis	doc_634572338223_item	2777737	et	4	main
sellele	doc_634572338223_item	2777744	et	4	main
kaasa	doc_634572338223_item	2777752	et	4	main
pesumasinadest	doc_634572338223_item	2777773	et	4	main
laevade	doc_634572338223_item	2777778	et	3	main
rezonanse	doc_634572338223_item	2777787	et	4	main
meie	doc_634572338223_item	2777790	et	4	main
põrand	doc_634572338224_item	2777827	et	3	main
ja	doc_634572338224_item	2777828	et	3	main
vajavad	doc_634572338224_item	2777830	et	4	main
peale	doc_634572338224_item	2777837	et	4	main
kaheks	doc_634572338224_item	2777843	et	4	main
ise	doc_634572338224_item	2777844	et	4	main
peab	doc_634572338224_item	2777862	et	4	main
selleks	doc_634572338224_item	2777865	et	4	main
vaja	doc_634572338224_item	2777867	et	4	main
külmetussüstemi	doc_634572338224_item	2777869	et	4	main
pesumisruumis	doc_634572338224_item	2777870	et	3	main
panen	doc_634572338224_item	2777871	et	3	main
pinka	doc_634572338224_item	2777886	et	3	main
see	doc_634572338224_item	2777892	et	3	main
minu	doc_634572338225_item	2777898	et	3	main
minu	doc_634572338225_item	2777900	et	3	main
neli	doc_634572338225_item	2777903	et	3	main
magamistuba	doc_634572338225_item	2777905	et	4	main
köök	doc_634572338225_item	2777906	et	3	main
külalistetuba	doc_634572338225_item	2777909	et	4	main
tellisest	doc_634572338225_item	2777914	et	3	main
pärast	doc_634572338225_item	2777915	et	4	main
vaheseinu	doc_634572338225_item	2777916	et	3	main
betoneerin	doc_634572338225_item	2777919	et	3	main
on	doc_634572338224_item	2777822	et	4	main
remonti	doc_634572338224_item	2777825	et	4	main
seda	doc_634572338224_item	2777838	et	3	main
nendes	doc_634572338224_item	2777848	et	4	main
ruumides	doc_634572338224_item	2777849	et	4	main
on	doc_634572338224_item	2777850	et	4	main
betoneeritud	doc_634572338224_item	2777851	et	4	main
põrand	doc_634572338224_item	2777852	et	3	main
seinad	doc_634572338224_item	2777853	et	3	main
jaavad	doc_634572338224_item	2777855	et	4	main
panen	doc_634572338224_item	2777858	et	3	main
kate	doc_634572338224_item	2777879	et	3	main
mitu	doc_634572338224_item	2777880	et	4	main
saunas	doc_634572338224_item	2777882	et	3	main
teise	doc_634572338224_item	2777888	et	4	main
vastu	doc_634572338224_item	2777889	et	3	main
kelder	doc_634572338225_item	2777897	et	3	main
kelderis	doc_634572338225_item	2777901	et	3	main
on	doc_634572338225_item	2777902	et	4	main
ruumi	doc_634572338225_item	2777904	et	4	main
ma	doc_634572338225_item	2777918	et	3	main
põrandaküte	doc_634572338225_item	2777924	et	3	main
pärast	doc_634572338225_item	2777925	et	4	main
krohvin	doc_634572338225_item	2777927	et	3	main
ja	doc_634572338225_item	2777930	et	3	main
kõik	doc_634572338225_item	2777937	et	4	main
vannitoas	doc_634572338225_item	2777939	et	3	main
plaatitud	doc_634572338225_item	2777941	et	4	main
ja	doc_634572338225_item	2777948	et	3	main
plaatiga	doc_634572338225_item	2777951	et	4	main
enne	doc_634572338225_item	2777952	et	4	main
dušš	doc_634572338225_item	2777991	et	2	main
mul	doc_634572338225_item	2777996	et	3	main
kapike	doc_634572338225_item	2778005	et	4	main
kõik	doc_634572338225_item	2777928	et	4	main
seinu	doc_634572338225_item	2777929	et	3	main
pärast	doc_634572338225_item	2777933	et	4	main
seinad	doc_634572338225_item	2777940	et	3	main
kõikides	doc_634572338225_item	2777942	et	4	main
ruumis	doc_634572338225_item	2777943	et	4	main
panin	doc_634572338225_item	2777944	et	3	main
pean	doc_634572338225_item	2777960	et	4	main
ka	doc_634572338225_item	2777961	et	3	main
soojendama	doc_634572338225_item	2777962	et	3	main
seinu	doc_634572338225_item	2777963	et	3	main
selle	doc_634572338225_item	2777964	et	4	main
mul	doc_634572338225_item	2777971	et	3	main
on	doc_634572338225_item	2777972	et	4	main
söögilaud	doc_634572338225_item	2777973	et	4	main
köögiplitt	doc_634572338225_item	2777975	et	4	main
ja	doc_634572338225_item	2777976	et	3	main
külmakapp	doc_634572338225_item	2777974	et	3	main
kaks	doc_634572338225_item	2777977	et	3	main
kapike	doc_634572338225_item	2777978	et	4	main
külalistetoas	doc_634572338225_item	2777979	et	3	main
mul	doc_634572338225_item	2777980	et	3	main
on	doc_634572338225_item	2777981	et	4	main
piljardilaud	doc_634572338225_item	2777982	et	4	main
suur	doc_634572338225_item	2777983	et	3	main
diivan	doc_634572338225_item	2777984	et	3	main
ja	doc_634572338225_item	2777985	et	3	main
stereosüstem	doc_634572338225_item	2777986	et	4	main
vannitoas	doc_634572338225_item	2777987	et	3	main
ma	doc_634572338225_item	2777988	et	3	main
paigaldan	doc_634572338225_item	2777989	et	3	main
sanitaartehnika	doc_634572338225_item	2777990	et	4	main
ja	doc_634572338225_item	2777993	et	3	main
wc-pott	doc_634572338225_item	2777994	et	3	main
magamistoas	doc_634572338225_item	2777995	et	3	main
on	doc_634572338225_item	2777997	et	4	main
arvutilaud	doc_634572338225_item	2777999	et	4	main
arvutiga	doc_634572338225_item	2778001	et	4	main
teler	doc_634572338225_item	2778002	et	3	main
remont	doc_634572338225_item	2778006	et	3	main
on	doc_634572338227_item	2778225	et	4	main
samuti	doc_634572338227_item	2778237	et	3	main
põhjalikult	doc_634572338227_item	2778247	et	4	main
valmistada	doc_634572338227_item	2778252	et	3	main
halvasti	doc_634572338227_item	2778254	et	3	main
toit	doc_634572338227_item	2778256	et	3	main
inimesele	doc_634572338227_item	2778258	et	3	main
on	doc_634572338227_item	2778274	et	4	main
kasulikum	doc_634572338227_item	2778278	et	4	main
peske	doc_634572338227_item	2778279	et	3	main
käsi	doc_634572338227_item	2778280	et	4	main
on	doc_634572338227_item	2778285	et	4	main
vaja	doc_634572338227_item	2778286	et	4	main
pesta	doc_634572338227_item	2778290	et	4	main
on	doc_634572338227_item	2778307	et	4	main
läbi	doc_634572338227_item	2778310	et	4	main
tappa	doc_634572338227_item	2778313	et	4	main
mikroobe	doc_634572338227_item	2778314	et	3	main
käsi	doc_634572338228_item	2778322	et	4	main
2	doc_634572338228_item	2778326	et	2	main
3	doc_634572338228_item	2778331	et	2	main
puhast	doc_634572338227_item	2778221	et	3	main
puhast	doc_634572338227_item	2778223	et	3	main
sest	doc_634572338227_item	2778228	et	4	main
puhtas	doc_634572338227_item	2778240	et	3	main
sisaldab	doc_634572338227_item	2778242	et	3	main
valmistage	doc_634572338227_item	2778245	et	3	main
sest	doc_634572338227_item	2778253	et	4	main
kohe	doc_634572338227_item	2778262	et	4	main
pärast	doc_634572338227_item	2778263	et	4	main
valmistamist	doc_634572338227_item	2778271	et	4	main
toit	doc_634572338227_item	2778275	et	3	main
ja	doc_634572338227_item	2778277	et	3	main
valmistatud	doc_634572338227_item	2778300	et	4	main
korralikult	doc_634572338227_item	2778302	et	4	main
läbi	doc_634572338227_item	2778303	et	4	main
korduvalt	doc_634572338228_item	2778323	et	4	main
hoolikalt	doc_634572338228_item	2778325	et	4	main
vett	doc_634572338228_item	2778330	et	3	main
toiduained	doc_634572338228_item	2778333	et	3	main
harjutus	doc_634572338227_item	2778214	et	4	main
kas	doc_634572338227_item	2778215	et	3	main
olete	doc_634572338227_item	2778216	et	3	main
nõus	doc_634572338227_item	2778217	et	4	main
väidetega	doc_634572338227_item	2778218	et	3	main
kasutage	doc_634572338227_item	2778219	et	3	main
ainult	doc_634572338227_item	2778220	et	4	main
vett	doc_634572338227_item	2778222	et	3	main
on	doc_634572338227_item	2778236	et	4	main
vaja	doc_634572338227_item	2778250	et	4	main
põhjalikult	doc_634572338227_item	2778251	et	4	main
on	doc_634572338227_item	2778257	et	4	main
sööge	doc_634572338227_item	2778260	et	3	main
toitu	doc_634572338227_item	2778265	et	4	main
on	doc_634572338227_item	2778266	et	4	main
sest	doc_634572338227_item	2778272	et	4	main
hoolikalt	doc_634572338227_item	2778289	et	4	main
toit	doc_634572338227_item	2778301	et	3	main
vaja	doc_634572338227_item	2778308	et	4	main
peske	doc_634572338228_item	2778321	et	3	main
puhast	doc_634572338228_item	2778329	et	3	main
oma	doc_634572338228_item	2778335	et	4	main
vajalikult	doc_634572338228_item	2778340	et	4	main
4	doc_634572338228_item	2778342	et	2	main
valmistage	doc_634572338228_item	2778343	et	3	main
toitu	doc_634572338228_item	2778344	et	4	main
5	doc_634572338228_item	2778346	et	2	main
sälitada	doc_634572338228_item	2778359	et	4	main
kasulik	doc_634572338228_item	2778366	et	3	main
kontrolltöö	doc_634572338229_item	2778404	et	4	main
pesumasinaga	doc_634572338229_item	2778410	et	3	main
kohvi	doc_634572338229_item	2778433	et	4	main
külmkapp	doc_634572338229_item	2778443	et	3	main
предпринимать	doc_634572338229_item	2778446	et	2	main
ara	doc_634572338229_item	2778449	et	3	main
блестеть	doc_634572338229_item	2778459	et	2	main
ilusa	doc_634572338230_item	2778469	et	3	main
sauna	doc_634572338230_item	2778470	et	4	main
jaoks	doc_634572338230_item	2778475	et	4	main
remonditöid	doc_634572338230_item	2778478	et	3	main
vaja	doc_634572338230_item	2778489	et	4	main
vaja	doc_634572338230_item	2778535	et	4	main
juba	doc_634572338230_item	2778540	et	3	main
tahan	doc_634572338230_item	2778543	et	3	main
sauna	doc_634572338230_item	2778551	et	4	main
keldrisse	doc_634572338231_item	2778559	et	3	main
ja	doc_634572338231_item	2778561	et	3	main
duširuumi	doc_634572338231_item	2778608	et	2	main
teha	doc_634572338231_item	2778612	et	3	main
tuleks	doc_634572338231_item	2778629	et	4	main
kuulata	doc_634572338231_item	2778639	et	4	main
tuleks	doc_634572338231_item	2778641	et	4	main
ja	doc_634572338231_item	2778651	et	3	main
kõigi	doc_634572338231_item	2778656	et	4	main
lähitulevikus	doc_634572338231_item	2778665	et	4	main
olen	doc_634572338231_item	2778674	et	3	main
essee	doc_634572338232_item	2778685	et	4	main
majas	doc_634572338232_item	2778688	et	3	main
ma	doc_634572338232_item	2778691	et	3	main
vett	doc_634572338227_item	2778224	et	3	main
kasutada	doc_634572338227_item	2778227	et	3	main
puhas	doc_634572338227_item	2778229	et	3	main
vesi	doc_634572338227_item	2778235	et	4	main
вкусная	doc_634572338227_item	2778239	et	2	main
toit	doc_634572338227_item	2778246	et	3	main
toitu	doc_634572338227_item	2778248	et	4	main
on	doc_634572338227_item	2778249	et	4	main
valmistatud	doc_634572338227_item	2778255	et	4	main
kahjulik	doc_634572338227_item	2778259	et	3	main
toitu	doc_634572338227_item	2778261	et	4	main
vaja	doc_634572338227_item	2778267	et	4	main
süüa	doc_634572338227_item	2778268	et	3	main
kohe	doc_634572338227_item	2778269	et	4	main
siis	doc_634572338227_item	2778273	et	3	main
värskem	doc_634572338227_item	2778276	et	4	main
hoolikalt	doc_634572338227_item	2778283	et	4	main
käsi	doc_634572338227_item	2778284	et	4	main
kätel	doc_634572338227_item	2778293	et	3	main
mitu	doc_634572338227_item	2778295	et	4	main
miljardit	doc_634572338227_item	2778296	et	3	main
harjutus	doc_634572338228_item	2778315	et	4	main
kas	doc_634572338228_item	2778316	et	3	main
olete	doc_634572338228_item	2778317	et	3	main
nõus	doc_634572338228_item	2778318	et	4	main
väidetega	doc_634572338228_item	2778319	et	3	main
1	doc_634572338228_item	2778320	et	2	main
vaja	doc_634572338227_item	2778226	et	4	main
vesi	doc_634572338227_item	2778230	et	4	main
on	doc_634572338227_item	2778231	et	4	main
kasulik	doc_634572338227_item	2778232	et	3	main
полезная	doc_634572338227_item	2778233	et	2	main
puhas	doc_634572338227_item	2778234	et	3	main
maitsev	doc_634572338227_item	2778238	et	4	main
vesi	doc_634572338227_item	2778241	et	4	main
vähe	doc_634572338227_item	2778243	et	3	main
mikroobe	doc_634572338227_item	2778244	et	3	main
valmistamist	doc_634572338227_item	2778264	et	4	main
pärast	doc_634572338227_item	2778270	et	4	main
korduvalt	doc_634572338227_item	2778281	et	4	main
ja	doc_634572338227_item	2778282	et	3	main
korduvalt	doc_634572338227_item	2778287	et	4	main
ja	doc_634572338227_item	2778288	et	3	main
sest	doc_634572338227_item	2778291	et	4	main
meie	doc_634572338227_item	2778292	et	4	main
on	doc_634572338227_item	2778294	et	4	main
mikroobe	doc_634572338227_item	2778297	et	3	main
kuumutage	doc_634572338227_item	2778298	et	3	main
varem	doc_634572338227_item	2778299	et	4	main
varem	doc_634572338227_item	2778304	et	4	main
valmistatud	doc_634572338227_item	2778305	et	4	main
toit	doc_634572338227_item	2778306	et	3	main
korralikult	doc_634572338227_item	2778309	et	4	main
kuumutada	doc_634572338227_item	2778311	et	3	main
et	doc_634572338227_item	2778312	et	3	main
ja	doc_634572338228_item	2778324	et	3	main
ainult	doc_634572338228_item	2778328	et	4	main
või	doc_634572338228_item	2778339	et	4	main
põhjalikult	doc_634572338228_item	2778345	et	4	main
hoolikalt	doc_634572338228_item	2778350	et	4	main
on	doc_634572338228_item	2778353	et	4	main
2	doc_634572338228_item	2778362	et	2	main
puhast	doc_634572338228_item	2778363	et	3	main
vett	doc_634572338228_item	2778364	et	3	main
on	doc_634572338228_item	2778365	et	4	main
ta	doc_634572338228_item	2778401	et	4	main
kontrolltöö	doc_634572338229_item	2778403	et	4	main
1	doc_634572338229_item	2778405	et	2	main
mida	doc_634572338229_item	2778406	et	4	main
tehakse	doc_634572338229_item	2778407	et	3	main
pestakse	doc_634572338229_item	2778411	et	3	main
külmkapp	doc_634572338229_item	2778414	et	3	main
2	doc_634572338229_item	2778437	et	2	main
электросеть	doc_634572338229_item	2778440	et	2	main
заряжать	doc_634572338229_item	2778442	et	2	main
põrandahari	doc_634572338229_item	2778447	et	3	main
keldri	doc_634572338230_item	2778462	et	3	main
keldrisse	doc_634572338230_item	2778468	et	3	main
duširuumiga	doc_634572338230_item	2778472	et	2	main
selle	doc_634572338230_item	2778474	et	4	main
tööd	doc_634572338230_item	2778480	et	4	main
seinade	doc_634572338230_item	2778481	et	3	main
ruumis	doc_634572338230_item	2778484	et	4	main
on	doc_634572338230_item	2778488	et	4	main
ventilatsioon	doc_634572338230_item	2778491	et	3	main
ahi	doc_634572338230_item	2778524	et	4	main
ning	doc_634572338230_item	2778527	et	3	main
jaoks	doc_634572338230_item	2778533	et	4	main
läheb	doc_634572338230_item	2778534	et	3	main
tahan	doc_634572338230_item	2778548	et	3	main
tahan	doc_634572338231_item	2778556	et	3	main
sauna	doc_634572338231_item	2778560	et	4	main
piljardisaali	doc_634572338231_item	2778562	et	4	main
tööd	doc_634572338231_item	2778570	et	4	main
et	doc_634572338231_item	2778571	et	3	main
ehitada	doc_634572338231_item	2778572	et	3	main
ehitada	doc_634572338231_item	2778607	et	3	main
leiliruumi	doc_634572338231_item	2778617	et	4	main
teha	doc_634572338231_item	2778621	et	3	main
piljardisaali	doc_634572338231_item	2778632	et	4	main
teha	doc_634572338231_item	2778636	et	3	main
elektritoid	doc_634572338231_item	2778637	et	4	main
et	doc_634572338231_item	2778638	et	3	main
kus	doc_634572338231_item	2778647	et	3	main
aeg	doc_634572338231_item	2778653	et	3	main
tuleb	doc_634572338231_item	2778658	et	3	main
teha	doc_634572338231_item	2778660	et	3	main
tööd	doc_634572338231_item	2778662	et	4	main
kasutage	doc_634572338228_item	2778327	et	3	main
valige	doc_634572338228_item	2778332	et	3	main
säilitage	doc_634572338228_item	2778347	et	3	main
3	doc_634572338228_item	2778368	et	2	main
olen	doc_634572338228_item	2778370	et	3	main
nõus	doc_634572338228_item	2778371	et	4	main
et	doc_634572338228_item	2778372	et	3	main
inimene	doc_634572338228_item	2778374	et	3	main
peab	doc_634572338228_item	2778375	et	4	main
valima	doc_634572338228_item	2778376	et	3	main
iga	doc_634572338228_item	2778373	et	4	main
toit	doc_634572338228_item	2778377	et	3	main
enda	doc_634572338228_item	2778378	et	4	main
jargi	doc_634572338228_item	2778379	et	4	main
kui	doc_634572338228_item	2778381	et	3	main
4	doc_634572338228_item	2778380	et	2	main
toit	doc_634572338228_item	2778382	et	3	main
valmistage	doc_634572338228_item	2778383	et	3	main
paha	doc_634572338228_item	2778384	et	4	main
seal	doc_634572338228_item	2778385	et	4	main
võib	doc_634572338228_item	2778386	et	3	main
olla	doc_634572338228_item	2778387	et	3	main
palju	doc_634572338228_item	2778388	et	4	main
mikroobid	doc_634572338228_item	2778389	et	3	main
5	doc_634572338228_item	2778390	et	2	main
toit	doc_634572338228_item	2778391	et	3	main
võib	doc_634572338228_item	2778392	et	3	main
rikkuma	doc_634572338228_item	2778393	et	3	main
ja	doc_634572338228_item	2778394	et	3	main
kui	doc_634572338228_item	2778395	et	3	main
inimene	doc_634572338228_item	2778396	et	3	main
sööb	doc_634572338228_item	2778397	et	3	main
mis	doc_634572338228_item	2778334	et	4	main
on	doc_634572338228_item	2778337	et	4	main
ohutumad	doc_634572338228_item	2778338	et	4	main
valmistatud	doc_634572338228_item	2778348	et	4	main
1	doc_634572338228_item	2778351	et	2	main
tähtis	doc_634572338228_item	2778355	et	4	main
kai	doc_634572338228_item	2778356	et	4	main
inimene	doc_634572338228_item	2778357	et	3	main
tahab	doc_634572338228_item	2778358	et	3	main
see	doc_634572338228_item	2778398	et	3	main
siis	doc_634572338228_item	2778400	et	3	main
haigestab	doc_634572338228_item	2778402	et	3	main
arvutiga	doc_634572338229_item	2778421	et	4	main
videomagnetofon	doc_634572338229_item	2778423	et	3	main
printeriga	doc_634572338229_item	2778424	et	3	main
prinditakse	doc_634572338229_item	2778425	et	3	main
dokumente	doc_634572338229_item	2778426	et	3	main
kohvimasinaga	doc_634572338229_item	2778431	et	3	main
valmistatakse	doc_634572338229_item	2778432	et	3	main
vahustatakse	doc_634572338229_item	2778435	et	3	main
laadima	doc_634572338229_item	2778441	et	3	main
üritama	doc_634572338229_item	2778445	et	3	main
швабра	doc_634572338229_item	2778448	et	2	main
не	doc_634572338229_item	2778451	et	2	main
kihutama	doc_634572338229_item	2778454	et	3	main
taimer	doc_634572338229_item	2778456	et	3	main
oma	doc_634572338230_item	2778461	et	4	main
ma	doc_634572338230_item	2778464	et	3	main
oma	doc_634572338230_item	2778467	et	4	main
tuleb	doc_634572338230_item	2778476	et	3	main
olemuselt	doc_634572338228_item	2778336	et	3	main
töödeldud	doc_634572338228_item	2778341	et	4	main
toitu	doc_634572338228_item	2778349	et	4	main
see	doc_634572338228_item	2778352	et	3	main
väga	doc_634572338228_item	2778354	et	3	main
oma	doc_634572338228_item	2778360	et	4	main
tervist	doc_634572338228_item	2778361	et	4	main
tervist	doc_634572338228_item	2778367	et	4	main
ma	doc_634572338228_item	2778369	et	3	main
kohvimasin	doc_634572338229_item	2778413	et	3	main
is	doc_634572338229_item	2778415	et	4	main
mangitakse	doc_634572338229_item	2778422	et	4	main
pliit	doc_634572338229_item	2778427	et	3	main
raadiost	doc_634572338229_item	2778428	et	3	main
tõlgi	doc_634572338229_item	2778438	et	4	main
elektrivõrk	doc_634572338229_item	2778439	et	3	main
бери	doc_634572338229_item	2778452	et	2	main
läikima	doc_634572338229_item	2778458	et	4	main
plaan	doc_634572338230_item	2778463	et	3	main
ehitada	doc_634572338230_item	2778466	et	3	main
koos	doc_634572338230_item	2778471	et	4	main
kuid	doc_634572338230_item	2778473	et	4	main
teha	doc_634572338230_item	2778490	et	3	main
on	doc_634572338230_item	2778521	et	4	main
teha	doc_634572338230_item	2778525	et	3	main
laudadest	doc_634572338230_item	2778530	et	3	main
palju	doc_634572338230_item	2778536	et	4	main
homme	doc_634572338230_item	2778541	et	3	main
alustada	doc_634572338230_item	2778544	et	3	main
sest	doc_634572338230_item	2778546	et	4	main
ma	doc_634572338230_item	2778547	et	3	main
kelder	doc_634572338231_item	2778554	et	3	main
ehitada	doc_634572338231_item	2778557	et	3	main
selle	doc_634572338231_item	2778563	et	4	main
jaoks	doc_634572338231_item	2778564	et	4	main
läheb	doc_634572338231_item	2778565	et	3	main
mul	doc_634572338231_item	2778566	et	3	main
käija	doc_634572338231_item	2778598	et	4	main
jaoks	doc_634572338231_item	2778610	et	4	main
plaadimistoid	doc_634572338231_item	2778613	et	4	main
ning	doc_634572338231_item	2778614	et	3	main
santehnika	doc_634572338231_item	2778615	et	4	main
pinke	doc_634572338231_item	2778622	et	4	main
soojustada	doc_634572338231_item	2778630	et	3	main
saaks	doc_634572338231_item	2778648	et	3	main
jaoks	doc_634572338231_item	2778657	et	4	main
palju	doc_634572338231_item	2778661	et	4	main
keldrisse	doc_634572338231_item	2778668	et	3	main
ruume	doc_634572338231_item	2778671	et	3	main
ma	doc_634572338231_item	2778673	et	3	main
kirjeldanud	doc_634572338231_item	2778675	et	4	main
oma	doc_634572338231_item	2778676	et	4	main
kirjandis	doc_634572338231_item	2778677	et	3	main
sest	doc_634572338231_item	2778678	et	4	main
siis	doc_634572338231_item	2778679	et	3	main
saab	doc_634572338231_item	2778680	et	3	main
panna	doc_634572338231_item	2778684	et	4	main
minu	doc_634572338232_item	2778687	et	3	main
tahtsin	doc_634572338232_item	2778692	et	3	main
küte	doc_634572338232_item	2778721	et	3	main
talvel	doc_634572338232_item	2778723	et	4	main
soojus	doc_634572338232_item	2778726	et	4	main
keldris	doc_634572338232_item	2778727	et	3	main
umbes	doc_634572338232_item	2778728	et	4	main
ühe	doc_634572338232_item	2778729	et	4	main
müüre	doc_634572338232_item	2778730	et	3	main
piljardi	doc_634572338232_item	2778733	et	3	main
nurgisse	doc_634572338232_item	2778736	et	4	main
aga	doc_634572338232_item	2778746	et	3	main
toad	doc_634572338232_item	2778749	et	3	main
hea	doc_634572338232_item	2778752	et	4	main
mahutuse	doc_634572338232_item	2778754	et	4	main
kui	doc_634572338232_item	2778762	et	3	main
oleke	doc_634572338232_item	2778764	et	4	main
ma	doc_634572338232_item	2778767	et	3	main
toit	doc_634572338228_item	2778399	et	3	main
olmetehnika	doc_634572338229_item	2778408	et	4	main
kodutehnika	doc_634572338229_item	2778409	et	4	main
riideid	doc_634572338229_item	2778412	et	3	main
sailitatakse	doc_634572338229_item	2778416	et	4	main
toiduaineid	doc_634572338229_item	2778417	et	3	main
telerist	doc_634572338229_item	2778418	et	4	main
vaadatakse	doc_634572338229_item	2778419	et	3	main
erinevaid	doc_634572338229_item	2778420	et	4	main
kuulatakse	doc_634572338229_item	2778429	et	3	main
muusikat	doc_634572338229_item	2778430	et	3	main
mikser	doc_634572338229_item	2778434	et	3	main
kokteili	doc_634572338229_item	2778436	et	4	main
холодильник	doc_634572338229_item	2778444	et	2	main
korjama	doc_634572338229_item	2778450	et	3	main
robottolmuimeja	doc_634572338229_item	2778453	et	4	main
мчаться	doc_634572338229_item	2778455	et	2	main
таимеr	doc_634572338229_item	2778457	et	2	main
essee	doc_634572338230_item	2778460	et	4	main
tahan	doc_634572338230_item	2778465	et	3	main
teha	doc_634572338230_item	2778477	et	3	main
alustaksin	doc_634572338230_item	2778479	et	3	main
soojustamisega	doc_634572338230_item	2778482	et	4	main
et	doc_634572338230_item	2778483	et	3	main
oleks	doc_634572338230_item	2778485	et	3	main
soe	doc_634572338230_item	2778486	et	4	main
siis	doc_634572338230_item	2778487	et	3	main
ja	doc_634572338230_item	2778492	et	3	main
niiskustõke	doc_634572338230_item	2778493	et	3	main
see	doc_634572338230_item	2778494	et	3	main
on	doc_634572338230_item	2778495	et	4	main
kõige	doc_634572338230_item	2778496	et	4	main
olulisem	doc_634572338230_item	2778497	et	4	main
sauna	doc_634572338230_item	2778498	et	4	main
tegemiseks	doc_634572338230_item	2778499	et	4	main
põrandaküte	doc_634572338230_item	2778500	et	3	main
on	doc_634572338230_item	2778501	et	4	main
ka	doc_634572338230_item	2778502	et	3	main
vajalik	doc_634572338230_item	2778503	et	3	main
et	doc_634572338230_item	2778504	et	3	main
oleks	doc_634572338230_item	2778505	et	3	main
mugav	doc_634572338230_item	2778506	et	3	main
käia	doc_634572338230_item	2778507	et	4	main
ka	doc_634572338230_item	2778508	et	3	main
paljujalu	doc_634572338230_item	2778509	et	4	main
duširuumi	doc_634572338230_item	2778510	et	2	main
tegemiseks	doc_634572338230_item	2778511	et	4	main
läheb	doc_634572338230_item	2778512	et	3	main
vaja	doc_634572338230_item	2778513	et	4	main
santehnikatöid	doc_634572338230_item	2778514	et	4	main
paigaldada	doc_634572338230_item	2778515	et	3	main
elektrit	doc_634572338230_item	2778516	et	3	main
ning	doc_634572338230_item	2778517	et	3	main
teha	doc_634572338230_item	2778518	et	3	main
plaadimistöid	doc_634572338230_item	2778519	et	3	main
leiliruumi	doc_634572338230_item	2778520	et	4	main
maja	doc_634572338230_item	2778522	et	4	main
pinke	doc_634572338230_item	2778526	et	4	main
teha	doc_634572338230_item	2778529	et	3	main
selle	doc_634572338230_item	2778531	et	4	main
kõigi	doc_634572338230_item	2778532	et	4	main
paigaldada	doc_634572338230_item	2778523	et	3	main
seinu	doc_634572338230_item	2778528	et	3	main
raha	doc_634572338230_item	2778537	et	4	main
ning	doc_634572338230_item	2778538	et	3	main
ehitamisega	doc_634572338230_item	2778545	et	4	main
endale	doc_634572338230_item	2778549	et	4	main
oma	doc_634572338230_item	2778550	et	4	main
mina	doc_634572338231_item	2778555	et	4	main
oma	doc_634572338231_item	2778558	et	4	main
palju	doc_634572338231_item	2778569	et	4	main
saun	doc_634572338231_item	2778573	et	3	main
tuleb	doc_634572338231_item	2778574	et	3	main
teha	doc_634572338231_item	2778575	et	3	main
hea	doc_634572338231_item	2778576	et	4	main
ventilatsioon	doc_634572338231_item	2778577	et	3	main
hea	doc_634572338231_item	2778578	et	4	main
niiskustõke	doc_634572338231_item	2778579	et	3	main
selle	doc_634572338231_item	2778580	et	4	main
jaoks	doc_634572338231_item	2778581	et	4	main
tuleb	doc_634572338231_item	2778582	et	3	main
teha	doc_634572338231_item	2778583	et	3	main
vahesein	doc_634572338231_item	2778584	et	3	main
et	doc_634572338231_item	2778585	et	3	main
saun	doc_634572338231_item	2778586	et	3	main
ja	doc_634572338231_item	2778587	et	3	main
piljardisaal	doc_634572338231_item	2778588	et	3	main
oleks	doc_634572338231_item	2778589	et	3	main
eraldi	doc_634572338231_item	2778590	et	4	main
laheb	doc_634572338231_item	2778591	et	4	main
vaja	doc_634572338231_item	2778592	et	4	main
uud	doc_634572338231_item	2778593	et	4	main
põrandakutet	doc_634572338231_item	2778594	et	4	main
et	doc_634572338231_item	2778595	et	3	main
oleks	doc_634572338231_item	2778596	et	3	main
tööd	doc_634572338230_item	2778539	et	4	main
ma	doc_634572338230_item	2778542	et	3	main
essee	doc_634572338231_item	2778552	et	4	main
minu	doc_634572338231_item	2778553	et	3	main
vaja	doc_634572338231_item	2778567	et	4	main
teha	doc_634572338231_item	2778568	et	3	main
mugav	doc_634572338231_item	2778597	et	3	main
ja	doc_634572338231_item	2778599	et	3	main
soe	doc_634572338231_item	2778602	et	4	main
ming	doc_634572338231_item	2778603	et	4	main
toid	doc_634572338231_item	2778616	et	4	main
teha	doc_634572338231_item	2778623	et	3	main
et	doc_634572338231_item	2778625	et	3	main
oleks	doc_634572338231_item	2778626	et	3	main
ruumides	doc_634572338231_item	2778627	et	4	main
soem	doc_634572338231_item	2778628	et	4	main
sinu	doc_634572338231_item	2778631	et	3	main
muusikat	doc_634572338231_item	2778640	et	3	main
teha	doc_634572338231_item	2778645	et	3	main
pinke	doc_634572338231_item	2778646	et	4	main
vaba	doc_634572338231_item	2778652	et	4	main
aga	doc_634572338231_item	2778659	et	3	main
selliseid	doc_634572338231_item	2778670	et	4	main
kui	doc_634572338232_item	2778686	et	3	main
et	doc_634572338232_item	2778722	et	3	main
peal	doc_634572338232_item	2778741	et	4	main
jaoks	doc_634572338232_item	2778751	et	4	main
niisugune	doc_634572338232_item	2778765	et	3	main
veetaksin	doc_634572338232_item	2778768	et	4	main
jalgadel	doc_634572338231_item	2778600	et	3	main
oleks	doc_634572338231_item	2778601	et	3	main
veel	doc_634572338231_item	2778604	et	4	main
ma	doc_634572338231_item	2778605	et	3	main
tahan	doc_634572338231_item	2778606	et	3	main
selle	doc_634572338231_item	2778609	et	4	main
tuleb	doc_634572338231_item	2778611	et	3	main
tuleks	doc_634572338231_item	2778618	et	4	main
paigaldada	doc_634572338231_item	2778619	et	3	main
ahi	doc_634572338231_item	2778620	et	4	main
elektritoid	doc_634572338231_item	2778624	et	4	main
tegemiseks	doc_634572338231_item	2778633	et	4	main
tuleks	doc_634572338231_item	2778634	et	4	main
ka	doc_634572338231_item	2778635	et	3	main
soojustada	doc_634572338231_item	2778642	et	3	main
sinu	doc_634572338231_item	2778643	et	3	main
põrandat	doc_634572338231_item	2778644	et	3	main
sõpradega	doc_634572338231_item	2778649	et	3	main
istuda	doc_634572338231_item	2778650	et	3	main
veeta	doc_634572338231_item	2778654	et	4	main
selle	doc_634572338231_item	2778655	et	4	main
ehitada	doc_634572338231_item	2778666	et	3	main
just	doc_634572338231_item	2778669	et	3	main
seal	doc_634572338231_item	2778681	et	4	main
sõpradega	doc_634572338231_item	2778682	et	3	main
on	doc_634572338232_item	2778689	et	4	main
seal	doc_634572338232_item	2778693	et	4	main
puhkeruumi	doc_634572338232_item	2778694	et	4	main
ja	doc_634572338232_item	2778695	et	3	main
meelelahutused	doc_634572338232_item	2778696	et	4	main
teha	doc_634572338232_item	2778697	et	3	main
aga	doc_634572338232_item	2778698	et	3	main
algul	doc_634572338232_item	2778699	et	4	main
tarvis	doc_634572338232_item	2778700	et	3	main
kontrollida	doc_634572338232_item	2778701	et	4	main
kuidas	doc_634572338232_item	2778702	et	3	main
olek	doc_634572338232_item	2778703	et	3	main
kelder	doc_634572338232_item	2778704	et	3	main
kui	doc_634572338232_item	2778705	et	3	main
tarvis	doc_634572338232_item	2778706	et	3	main
siis	doc_634572338232_item	2778707	et	3	main
ehaksin	doc_634572338232_item	2778709	et	3	main
t	doc_634572338232_item	2778708	et	4	main
remont	doc_634572338232_item	2778710	et	3	main
ja	doc_634572338232_item	2778711	et	3	main
tingimata	doc_634572338232_item	2778712	et	4	main
ma	doc_634572338232_item	2778713	et	3	main
tehaksin	doc_634572338232_item	2778714	et	4	main
müüre	doc_634572338232_item	2778715	et	3	main
ja	doc_634572338232_item	2778716	et	3	main
põrand	doc_634572338232_item	2778717	et	3	main
soem	doc_634572338232_item	2778718	et	4	main
ja	doc_634572338232_item	2778719	et	3	main
teostaksin	doc_634572338232_item	2778720	et	3	main
ma	doc_634572338232_item	2778731	et	3	main
diivan	doc_634572338232_item	2778739	et	3	main
diivani	doc_634572338232_item	2778742	et	4	main
ma	doc_634572338232_item	2778743	et	3	main
paniks	doc_634572338232_item	2778744	et	4	main
nurga	doc_634572338232_item	2778747	et	3	main
valgustuse	doc_634572338232_item	2778753	et	4	main
veel	doc_634572338232_item	2778755	et	4	main
võib	doc_634572338232_item	2778756	et	3	main
panema	doc_634572338232_item	2778757	et	3	main
ma	doc_634572338231_item	2778663	et	3	main
kavatsen	doc_634572338231_item	2778664	et	3	main
oma	doc_634572338231_item	2778667	et	4	main
mida	doc_634572338231_item	2778672	et	4	main
pidu	doc_634572338231_item	2778683	et	4	main
kelder	doc_634572338232_item	2778690	et	3	main
aga	doc_634572338232_item	2778735	et	3	main
vastu	doc_634572338232_item	2778737	et	3	main
vastu	doc_634572338232_item	2778740	et	3	main
telekas	doc_634572338232_item	2778745	et	4	main
lambid	doc_634572338232_item	2778750	et	4	main
oma	doc_634572338232_item	2778770	et	4	main
aeg	doc_634572338232_item	2778772	et	3	main
muusikat	doc_634572338232_item	2778774	et	3	main
ja	doc_634572338232_item	2778775	et	3	main
mängisin	doc_634572338232_item	2778776	et	3	main
oma	doc_634572338232_item	2778779	et	4	main
sõpradega	doc_634572338232_item	2778780	et	3	main
allalas	doc_634572338234_item	2778892	et	3	main
on	doc_634572338234_item	2778894	et	4	main
söön	doc_634572338234_item	2778901	et	3	main
laud	doc_634572338234_item	2778909	et	4	main
pesumasin	doc_634572338234_item	2778910	et	3	main
võib	doc_634572338234_item	2778914	et	3	main
võimlas	doc_634572338234_item	2778916	et	3	main
keldris	doc_634572338232_item	2778724	et	3	main
oli	doc_634572338232_item	2778725	et	3	main
paniks	doc_634572338232_item	2778732	et	4	main
laud	doc_634572338232_item	2778734	et	4	main
peal	doc_634572338232_item	2778738	et	4	main
mööda	doc_634572338232_item	2778748	et	4	main
ole	doc_634572338232_item	2778760	et	4	main
muusikakeskus	doc_634572338232_item	2778761	et	3	main
mul	doc_634572338232_item	2778763	et	3	main
kelder	doc_634572338232_item	2778766	et	3	main
koos	doc_634572338232_item	2778778	et	4	main
ktee	doc_634572338234_item	2778893	et	4	main
on	doc_634572338234_item	2778903	et	4	main
kapid	doc_634572338234_item	2778904	et	4	main
ja	doc_634572338234_item	2778905	et	3	main
laudid	doc_634572338234_item	2778906	et	4	main
toolid	doc_634572338234_item	2778907	et	3	main
ja	doc_634572338234_item	2778908	et	3	main
toa	doc_634572338234_item	2778913	et	3	main
on	doc_634572338234_item	2778921	et	4	main
hantelid	doc_634572338234_item	2778923	et	3	main
puhketoas	doc_634572338234_item	2778925	et	3	main
muusika	doc_634572338234_item	2778932	et	4	main
sambakedega	doc_634572338234_item	2778936	et	4	main
ja	doc_634572338234_item	2778941	et	3	main
tisleritöökoda	doc_634572338234_item	2778946	et	4	main
politseile	doc_634572338235_item	2778956	et	3	main
narvast	doc_634572338235_item	2778975	et	4	main
selle	doc_634572338235_item	2778992	et	4	main
aja	doc_634572338235_item	2778993	et	4	main
ma	doc_634572338235_item	2778994	et	3	main
tulin	doc_634572338235_item	2778995	et	3	main
kaupluses	doc_634572338235_item	2778996	et	3	main
kauplusest	doc_634572338235_item	2778999	et	4	main
väljusin	doc_634572338235_item	2779000	et	3	main
kuritegija	doc_634572338235_item	2779001	et	4	main
oli	doc_634572338235_item	2779002	et	3	main
minu	doc_634572338235_item	2779003	et	3	main
sõbranna	doc_634572338235_item	2779007	et	4	main
autos	doc_634572338235_item	2779010	et	3	main
viskada	doc_634572338235_item	2779017	et	4	main
kuhu	doc_634572338232_item	2778758	et	3	main
ega	doc_634572338232_item	2778759	et	3	main
temas	doc_634572338232_item	2778769	et	3	main
vaba	doc_634572338232_item	2778771	et	4	main
kuulsin	doc_634572338232_item	2778773	et	3	main
piljardisse	doc_634572338232_item	2778777	et	3	main
tooted	doc_634572338234_item	2778899	et	3	main
see	doc_634572338234_item	2778912	et	3	main
läbima	doc_634572338234_item	2778915	et	4	main
ja	doc_634572338234_item	2778917	et	3	main
puhketoa	doc_634572338234_item	2778918	et	3	main
treninguseade	doc_634572338234_item	2778924	et	4	main
mul	doc_634572338234_item	2778926	et	3	main
on	doc_634572338234_item	2778927	et	4	main
teler	doc_634572338234_item	2778928	et	3	main
keskus	doc_634572338234_item	2778933	et	3	main
võib	doc_634572338234_item	2778944	et	3	main
mõõteriistad	doc_634572338234_item	2778950	et	3	main
montöötööristad	doc_634572338234_item	2778951	et	4	main
seletuskiri	doc_634572338235_item	2778955	et	3	main
minu	doc_634572338235_item	2778957	et	3	main
praegu	doc_634572338235_item	2778977	et	3	main
kohtla-järves	doc_634572338235_item	2778979	et	4	main
pikk	doc_634572338235_item	2778980	et	4	main
toimub	doc_634572338235_item	2778984	et	3	main
juhtus	doc_634572338235_item	2778989	et	3	main
ma	doc_634572338235_item	2778998	et	3	main
istus	doc_634572338235_item	2779008	et	4	main
käe	doc_634572338235_item	2779033	et	3	main
kuid	doc_634572338235_item	2779034	et	4	main
nimi	doc_634572338235_item	2779044	et	3	main
madala	doc_634572338235_item	2779052	et	3	main
ja	doc_634572338235_item	2779063	et	3	main
vurrud	doc_634572338235_item	2779067	et	3	main
seljas	doc_634572338235_item	2779069	et	4	main
oli	doc_634572338235_item	2779070	et	3	main
must	doc_634572338235_item	2779071	et	4	main
täpne	doc_634572338235_item	2779078	et	3	main
allkiri	doc_634572338235_item	2779086	et	3	main
essee	doc_634572338234_item	2778884	et	4	main
minu	doc_634572338234_item	2778885	et	3	main
kelder	doc_634572338234_item	2778886	et	3	main
keldris	doc_634572338234_item	2778887	et	3	main
mul	doc_634572338234_item	2778888	et	3	main
on	doc_634572338234_item	2778889	et	4	main
neli	doc_634572338234_item	2778890	et	3	main
toad	doc_634572338234_item	2778891	et	3	main
köök-ladu	doc_634572338234_item	2778895	et	4	main
siin	doc_634572338234_item	2778896	et	4	main
ma	doc_634572338234_item	2778897	et	3	main
võimlas	doc_634572338234_item	2778919	et	3	main
arvuti	doc_634572338234_item	2778930	et	4	main
diivan	doc_634572338234_item	2778931	et	3	main
koos	doc_634572338234_item	2778934	et	4	main
siin	doc_634572338234_item	2778938	et	4	main
ma	doc_634572338234_item	2778939	et	3	main
puhkan	doc_634572338234_item	2778942	et	3	main
toasse	doc_634572338234_item	2778943	et	3	main
elan	doc_634572338235_item	2778978	et	3	main
11	doc_634572338235_item	2778981	et	2	main
seda	doc_634572338235_item	2778982	et	3	main
sündmus	doc_634572338235_item	2778983	et	3	main
12	doc_634572338235_item	2778987	et	2	main
millal	doc_634572338235_item	2778997	et	3	main
minu	doc_634572338235_item	2779006	et	3	main
oma	doc_634572338235_item	2779009	et	4	main
ja	doc_634572338235_item	2779011	et	3	main
otsustas	doc_634572338235_item	2779012	et	3	main
ava	doc_634572338235_item	2779013	et	4	main
aken	doc_634572338235_item	2779014	et	3	main
kinni	doc_634572338235_item	2779025	et	3	main
käest	doc_634572338235_item	2779027	et	4	main
ja	doc_634572338235_item	2779028	et	3	main
eesnimi	doc_634572338235_item	2779046	et	3	main
aga	doc_634572338235_item	2779048	et	3	main
kasvu	doc_634572338235_item	2779053	et	4	main
ja	doc_634572338235_item	2779054	et	3	main
spordi	doc_634572338235_item	2779055	et	4	main
kehaehituse	doc_634572338235_item	2779056	et	3	main
noor	doc_634572338235_item	2779057	et	3	main
mustad	doc_634572338235_item	2779061	et	4	main
veel	doc_634572338235_item	2779064	et	4	main
oli	doc_634572338235_item	2779066	et	3	main
mnt	doc_634572338235_item	2779082	et	4	main
hojan	doc_634572338234_item	2778898	et	4	main
ja	doc_634572338234_item	2778900	et	3	main
siin	doc_634572338234_item	2778902	et	4	main
kaudu	doc_634572338234_item	2778911	et	3	main
mul	doc_634572338234_item	2778920	et	3	main
kand	doc_634572338234_item	2778922	et	3	main
võimsadega	doc_634572338234_item	2778935	et	4	main
raamaturiiulid	doc_634572338234_item	2778937	et	3	main
magan	doc_634572338234_item	2778940	et	3	main
mööda	doc_634572338234_item	2778945	et	4	main
siin	doc_634572338234_item	2778947	et	4	main
on	doc_634572338234_item	2778948	et	4	main
höövelriistad	doc_634572338234_item	2778952	et	3	main
kiri	doc_634572338235_item	2778954	et	3	main
päeval	doc_634572338235_item	2778985	et	3	main
kell	doc_634572338235_item	2778986	et	3	main
see	doc_634572338235_item	2778988	et	3	main
tankmise	doc_634572338235_item	2778990	et	4	main
juures	doc_634572338235_item	2778991	et	4	main
sõbranna	doc_634572338235_item	2779004	et	4	main
et	doc_634572338235_item	2779015	et	3	main
prügi	doc_634572338235_item	2779016	et	4	main
ilmub	doc_634572338235_item	2779022	et	3	main
ja	doc_634572338235_item	2779024	et	3	main
haaras	doc_634572338235_item	2779026	et	4	main
tahaks	doc_634572338235_item	2779029	et	3	main
katki	doc_634572338235_item	2779030	et	4	main
teha	doc_634572338235_item	2779031	et	3	main
on	doc_634572338235_item	2779045	et	4	main
perekonnanimi	doc_634572338235_item	2779047	et	3	main
isikukirjeldus	doc_634572338235_item	2779050	et	3	main
on	doc_634572338235_item	2779051	et	4	main
on	doc_634572338235_item	2779060	et	4	main
püksid	doc_634572338235_item	2779075	et	3	main
sündmuse	doc_634572338235_item	2779077	et	3	main
on	doc_634572338235_item	2779080	et	4	main
tallinna	doc_634572338235_item	2779081	et	4	main
ametlik	doc_634572338238_item	2779360	et	3	main
kiri	doc_634572338238_item	2779361	et	3	main
kirjutuslaud	doc_634572338234_item	2778929	et	4	main
tisleripink	doc_634572338234_item	2778949	et	4	main
ametlik	doc_634572338235_item	2778953	et	3	main
nimi	doc_634572338235_item	2778958	et	3	main
on	doc_634572338235_item	2778959	et	4	main
eesnimi	doc_634572338235_item	2778960	et	3	main
perekonnanimi	doc_634572338235_item	2778961	et	3	main
ma	doc_634572338235_item	2778962	et	3	main
olen	doc_634572338235_item	2778963	et	3	main
ohvri	doc_634572338235_item	2778964	et	3	main
sõbranna	doc_634572338235_item	2778965	et	4	main
ma	doc_634572338235_item	2778966	et	3	main
olen	doc_634572338235_item	2778967	et	3	main
sündinud	doc_634572338235_item	2778968	et	4	main
on	doc_634572338235_item	2778969	et	4	main
12111981	doc_634572338235_item	2778970	et	2	main
a	doc_634572338235_item	2778971	et	4	main
ma	doc_634572338235_item	2778972	et	3	main
olen	doc_634572338235_item	2778973	et	3	main
pärit	doc_634572338235_item	2778974	et	3	main
kui	doc_634572338235_item	2778976	et	3	main
kõrval	doc_634572338235_item	2779005	et	4	main
järsku	doc_634572338235_item	2779019	et	4	main
selja	doc_634572338235_item	2779020	et	3	main
ja	doc_634572338235_item	2779018	et	3	main
tagant	doc_634572338235_item	2779021	et	3	main
kuritegija	doc_634572338235_item	2779023	et	4	main
minu	doc_634572338235_item	2779035	et	3	main
sõbranna	doc_634572338235_item	2779036	et	4	main
rebis	doc_634572338235_item	2779037	et	3	main
ja	doc_634572338235_item	2779038	et	3	main
lüüa	doc_634572338235_item	2779039	et	3	main
rusika	doc_634572338235_item	2779040	et	3	main
nägu	doc_634572338235_item	2779041	et	4	main
minu	doc_634572338235_item	2779042	et	3	main
kuritegija	doc_634572338235_item	2779049	et	4	main
juuksed	doc_634572338235_item	2779062	et	3	main
tal	doc_634572338235_item	2779065	et	3	main
tema	doc_634572338235_item	2779068	et	4	main
11	doc_634572338235_item	2779083	et	2	main
e	doc_634572338235_item	2779084	et	4	main
perekonnanimi	doc_634572338235_item	2779085	et	3	main
olen	doc_634572338238_item	2779376	et	3	main
tema	doc_634572338235_item	2779032	et	4	main
sõbranna	doc_634572338235_item	2779043	et	4	main
mees	doc_634572338235_item	2779058	et	4	main
tal	doc_634572338235_item	2779059	et	3	main
jope	doc_634572338235_item	2779072	et	4	main
ja	doc_634572338235_item	2779073	et	3	main
mustad	doc_634572338235_item	2779074	et	4	main
selle	doc_634572338235_item	2779076	et	4	main
koht	doc_634572338235_item	2779079	et	3	main
olen	doc_634572338238_item	2779369	et	3	main
juunil	doc_634572338238_item	2779372	et	3	main
sellepärast	doc_634572338238_item	2779378	et	3	main
olin	doc_634572338238_item	2779380	et	3	main
restoraanis	doc_634572338238_item	2779381	et	4	main
nägin	doc_634572338238_item	2779383	et	3	main
üks	doc_634572338238_item	2779385	et	3	main
mees	doc_634572338238_item	2779386	et	4	main
tema	doc_634572338239_item	2779446	et	4	main
oli	doc_634572338239_item	2779458	et	3	main
mees	doc_634572338239_item	2779461	et	4	main
tahtis	doc_634572338239_item	2779462	et	3	main
ümbert	doc_634572338239_item	2779471	et	3	main
kinni	doc_634572338239_item	2779472	et	3	main
ei	doc_634572338239_item	2779476	et	4	main
hämmeldanud	doc_634572338239_item	2779477	et	4	main
hakkas	doc_634572338239_item	2779479	et	3	main
mehe	doc_634572338239_item	2779484	et	3	main
midagi	doc_634572338239_item	2779503	et	4	main
ametlik	doc_634572338240_item	2779506	et	3	main
politseile	doc_634572338240_item	2779509	et	3	main
on	doc_634572338240_item	2779512	et	4	main
on	doc_634572338238_item	2779365	et	4	main
eesnimi	doc_634572338238_item	2779366	et	3	main
perekonnanimi	doc_634572338238_item	2779367	et	3	main
sündinud	doc_634572338238_item	2779370	et	4	main
1977	doc_634572338238_item	2779373	et	2	main
ma	doc_634572338238_item	2779375	et	3	main
eile	doc_634572338238_item	2779379	et	3	main
neiu	doc_634572338238_item	2779390	et	4	main
hakkas	doc_634572338238_item	2779391	et	3	main
vastu	doc_634572338238_item	2779392	et	3	main
leena	doc_634572338239_item	2779422	et	3	main
selle	doc_634572338239_item	2779438	et	4	main
pilti	doc_634572338239_item	2779439	et	4	main
leena	doc_634572338239_item	2779440	et	3	main
minu	doc_634572338239_item	2779441	et	3	main
õde	doc_634572338239_item	2779442	et	4	main
mustad	doc_634572338239_item	2779455	et	4	main
prunid	doc_634572338239_item	2779459	et	4	main
noort	doc_634572338239_item	2779473	et	3	main
ja	doc_634572338239_item	2779478	et	3	main
ta	doc_634572338239_item	2779481	et	4	main
pea	doc_634572338239_item	2779485	et	4	main
kuritegija	doc_634572338239_item	2779495	et	4	main
kiiresti	doc_634572338239_item	2779496	et	3	main
rohkem	doc_634572338239_item	2779504	et	4	main
perekonnanimi	doc_634572338240_item	2779514	et	3	main
sündinud	doc_634572338240_item	2779516	et	4	main
elan	doc_634572338240_item	2779518	et	3	main
noormes	doc_634572338240_item	2779536	et	4	main
öelda	doc_634572338240_item	2779544	et	4	main
välja	doc_634572338240_item	2779547	et	4	main
näes	doc_634572338240_item	2779548	et	4	main
hakkama	doc_634572338240_item	2779556	et	3	main
siiski	doc_634572338240_item	2779560	et	4	main
ja	doc_634572338240_item	2779562	et	3	main
jalutas	doc_634572338240_item	2779563	et	3	main
peab	doc_634572338241_item	2779575	et	4	main
et	doc_634572338241_item	2779579	et	3	main
oli	doc_634572338241_item	2779592	et	3	main
see	doc_634572338241_item	2779594	et	3	main
annab	doc_634572338241_item	2779596	et	3	main
mugavad	doc_634572338241_item	2779606	et	3	main
istmepea	doc_634572338241_item	2779609	et	4	main
olema	doc_634572338241_item	2779618	et	4	main
armuke	doc_634572338241_item	2779624	et	4	main
olema	doc_634572338242_item	2779634	et	4	main
ei	doc_634572338242_item	2779640	et	4	main
peab	doc_634572338242_item	2779657	et	4	main
juhimine	doc_634572338242_item	2779669	et	4	main
suur	doc_634572338242_item	2779670	et	3	main
ma	doc_634572338238_item	2779368	et	3	main
tunnistaja	doc_634572338238_item	2779377	et	4	main
et	doc_634572338238_item	2779384	et	3	main
krabis	doc_634572338238_item	2779387	et	3	main
ja	doc_634572338238_item	2779393	et	3	main
räägis	doc_634572338238_item	2779394	et	3	main
talle	doc_634572338238_item	2779395	et	4	main
midagi	doc_634572338238_item	2779396	et	4	main
aga	doc_634572338238_item	2779397	et	3	main
mee	doc_634572338238_item	2779398	et	3	main
tahtnud	doc_634572338238_item	2779399	et	4	main
mitte	doc_634572338238_item	2779400	et	3	main
midagi	doc_634572338238_item	2779401	et	4	main
kuulata	doc_634572338238_item	2779402	et	4	main
siis	doc_634572338238_item	2779403	et	3	main
neiu	doc_634572338238_item	2779404	et	4	main
tõukas	doc_634572338238_item	2779405	et	3	main
teda	doc_634572338238_item	2779406	et	4	main
ja	doc_634572338238_item	2779407	et	3	main
hakkas	doc_634572338238_item	2779408	et	3	main
karjatama	doc_634572338238_item	2779409	et	3	main
ametlik	doc_634572338239_item	2779410	et	3	main
kiri	doc_634572338239_item	2779411	et	3	main
ma	doc_634572338239_item	2779412	et	3	main
olen	doc_634572338239_item	2779413	et	3	main
eesnimi	doc_634572338239_item	2779414	et	3	main
perekonnanimi	doc_634572338239_item	2779415	et	3	main
26	doc_634572338239_item	2779416	et	2	main
aastat	doc_634572338239_item	2779417	et	3	main
vana	doc_634572338239_item	2779418	et	4	main
elan	doc_634572338239_item	2779419	et	3	main
narvas	doc_634572338239_item	2779420	et	4	main
tean	doc_634572338239_item	2779421	et	3	main
seletuskiri	doc_634572338238_item	2779362	et	3	main
minu	doc_634572338238_item	2779363	et	3	main
nimi	doc_634572338238_item	2779364	et	3	main
24	doc_634572338238_item	2779371	et	2	main
aastal	doc_634572338238_item	2779374	et	3	main
aga	doc_634572338239_item	2779423	et	3	main
kuritegijaga	doc_634572338239_item	2779426	et	3	main
tel	doc_634572338239_item	2779428	et	4	main
555555	doc_634572338239_item	2779430	et	2	main
eile	doc_634572338239_item	2779431	et	3	main
õhtul	doc_634572338239_item	2779432	et	3	main
ma	doc_634572338239_item	2779433	et	3	main
olin	doc_634572338239_item	2779434	et	3	main
diskol	doc_634572338239_item	2779435	et	4	main
ja	doc_634572338239_item	2779436	et	3	main
nägin	doc_634572338239_item	2779437	et	3	main
juurde	doc_634572338239_item	2779447	et	4	main
valge	doc_634572338239_item	2779453	et	4	main
särk	doc_634572338239_item	2779454	et	3	main
vuntsid	doc_634572338239_item	2779460	et	4	main
tantsida	doc_634572338239_item	2779463	et	3	main
naisega	doc_634572338239_item	2779464	et	3	main
aga	doc_634572338239_item	2779465	et	3	main
leena	doc_634572338239_item	2779466	et	3	main
keeldus	doc_634572338239_item	2779467	et	3	main
siis	doc_634572338239_item	2779468	et	3	main
mees	doc_634572338239_item	2779469	et	4	main
võttis	doc_634572338239_item	2779470	et	3	main
neiu	doc_634572338239_item	2779474	et	4	main
vastu	doc_634572338239_item	2779480	et	3	main
kinni	doc_634572338239_item	2779482	et	3	main
ja	doc_634572338239_item	2779486	et	3	main
mees	doc_634572338239_item	2779490	et	4	main
langes	doc_634572338239_item	2779491	et	4	main
ja	doc_634572338239_item	2779492	et	3	main
leena	doc_634572338239_item	2779493	et	3	main
vabanes	doc_634572338239_item	2779494	et	3	main
ära	doc_634572338239_item	2779498	et	4	main
tea	doc_634572338239_item	2779501	et	4	main
kiri	doc_634572338240_item	2779507	et	3	main
minu	doc_634572338240_item	2779510	et	3	main
eesnimi	doc_634572338240_item	2779513	et	3	main
on	doc_634572338240_item	2779515	et	4	main
01021988	doc_634572338240_item	2779517	et	2	main
on	doc_634572338240_item	2779522	et	4	main
12	doc_634572338240_item	2779528	et	2	main
aprillil	doc_634572338240_item	2779529	et	3	main
röövida	doc_634572338240_item	2779538	et	4	main
täpselt	doc_634572338240_item	2779541	et	4	main
ei	doc_634572338240_item	2779542	et	4	main
tume	doc_634572338240_item	2779552	et	3	main
proovis	doc_634572338240_item	2779554	et	4	main
aga	doc_634572338240_item	2779557	et	3	main
tugevam	doc_634572338240_item	2779561	et	4	main
mulle	doc_634572338241_item	2779587	et	4	main
tahaksin	doc_634572338241_item	2779588	et	3	main
et	doc_634572338241_item	2779589	et	3	main
minu	doc_634572338241_item	2779590	et	3	main
punast	doc_634572338241_item	2779593	et	4	main
saalon	doc_634572338241_item	2779598	et	4	main
istmed	doc_634572338241_item	2779607	et	3	main
tugiga	doc_634572338241_item	2779610	et	4	main
on	doc_634572338241_item	2779612	et	4	main
vastus	doc_634572338242_item	2779625	et	3	main
minu	doc_634572338242_item	2779627	et	3	main
minu	doc_634572338242_item	2779630	et	3	main
auto	doc_634572338242_item	2779632	et	4	main
ilus	doc_634572338242_item	2779637	et	4	main
sellepärast	doc_634572338242_item	2779638	et	3	main
mulle	doc_634572338242_item	2779639	et	4	main
auto	doc_634572338242_item	2779650	et	4	main
taskukohane	doc_634572338242_item	2779659	et	4	main
et	doc_634572338242_item	2779660	et	3	main
osta	doc_634572338242_item	2779663	et	4	main
taha	doc_634572338242_item	2779665	et	4	main
unistuste	doc_634572338243_item	2779675	et	4	main
auto	doc_634572338243_item	2779678	et	4	main
olema	doc_634572338243_item	2779680	et	4	main
suur	doc_634572338243_item	2779681	et	3	main
ja	doc_634572338243_item	2779682	et	3	main
ja	doc_634572338238_item	2779382	et	3	main
neiu	doc_634572338238_item	2779388	et	4	main
jalga	doc_634572338238_item	2779389	et	4	main
ei	doc_634572338239_item	2779424	et	4	main
minu	doc_634572338239_item	2779427	et	3	main
jooksis	doc_634572338239_item	2779448	et	4	main
mees	doc_634572338239_item	2779449	et	4	main
tal	doc_634572338239_item	2779457	et	3	main
hoidis	doc_634572338239_item	2779483	et	4	main
lõi	doc_634572338239_item	2779487	et	4	main
vastu	doc_634572338239_item	2779489	et	3	main
jooksis	doc_634572338239_item	2779497	et	4	main
seletuskiri	doc_634572338240_item	2779508	et	3	main
nimi	doc_634572338240_item	2779511	et	3	main
5-6	doc_634572338240_item	2779521	et	2	main
tunnistajaks	doc_634572338240_item	2779525	et	4	main
aastal	doc_634572338240_item	2779531	et	3	main
maantel	doc_634572338240_item	2779533	et	4	main
kell	doc_634572338240_item	2779534	et	3	main
üheksa	doc_634572338240_item	2779535	et	4	main
naiste	doc_634572338240_item	2779539	et	3	main
või	doc_634572338240_item	2779543	et	4	main
juba	doc_634572338240_item	2779551	et	3	main
naine	doc_634572338240_item	2779553	et	3	main
vastu	doc_634572338240_item	2779555	et	3	main
küsimusele	doc_634572338241_item	2779568	et	4	main
ma	doc_634572338241_item	2779569	et	3	main
unustan	doc_634572338241_item	2779570	et	3	main
väikest	doc_634572338241_item	2779571	et	4	main
ilust	doc_634572338241_item	2779572	et	3	main
autost	doc_634572338241_item	2779573	et	3	main
olema	doc_634572338241_item	2779576	et	4	main
väga	doc_634572338241_item	2779577	et	3	main
moodne	doc_634572338241_item	2779578	et	3	main
edukast	doc_634572338241_item	2779597	et	4	main
peab	doc_634572338241_item	2779599	et	4	main
on	doc_634572338241_item	2779608	et	4	main
veel	doc_634572338241_item	2779611	et	4	main
klaasitõstuk	doc_634572338241_item	2779614	et	3	main
tuuduvalt	doc_634572338241_item	2779615	et	4	main
veel	doc_634572338241_item	2779616	et	4	main
et	doc_634572338241_item	2779620	et	3	main
unistuste	doc_634572338242_item	2779628	et	4	main
moodsus	doc_634572338242_item	2779635	et	4	main
meeldi	doc_634572338242_item	2779641	et	4	main
ja	doc_634572338242_item	2779644	et	3	main
mugavus	doc_634572338242_item	2779652	et	4	main
ja	doc_634572338242_item	2779653	et	3	main
pehmed	doc_634572338242_item	2779654	et	3	main
istmed	doc_634572338242_item	2779655	et	3	main
auto	doc_634572338242_item	2779656	et	4	main
saaksin	doc_634572338242_item	2779662	et	3	main
kütusekulu	doc_634572338242_item	2779671	et	4	main
vastus	doc_634572338243_item	2779672	et	3	main
küsimusele	doc_634572338243_item	2779673	et	4	main
minu	doc_634572338243_item	2779674	et	3	main
auto	doc_634572338243_item	2779676	et	4	main
peab	doc_634572338243_item	2779679	et	4	main
kallis	doc_634572338243_item	2779720	et	4	main
elektrilised	doc_634572338245_item	2779832	et	4	main
ladima	doc_634572338245_item	2779839	et	4	main
ara	doc_634572338245_item	2779840	et	3	main
tutvusta	doc_634572338239_item	2779425	et	4	main
55	doc_634572338239_item	2779429	et	2	main
tantsis	doc_634572338239_item	2779443	et	4	main
ja	doc_634572338239_item	2779444	et	3	main
äkki	doc_634572338239_item	2779445	et	3	main
ta	doc_634572338239_item	2779450	et	4	main
oli	doc_634572338239_item	2779451	et	3	main
riienud	doc_634572338239_item	2779452	et	4	main
püksid	doc_634572338239_item	2779456	et	3	main
leena	doc_634572338239_item	2779475	et	3	main
silmi	doc_634572338239_item	2779488	et	4	main
ma	doc_634572338239_item	2779499	et	3	main
ei	doc_634572338239_item	2779500	et	4	main
mitte	doc_634572338239_item	2779502	et	3	main
allkiri	doc_634572338239_item	2779505	et	3	main
jõhvis	doc_634572338240_item	2779519	et	3	main
tamme	doc_634572338240_item	2779520	et	4	main
mis	doc_634572338240_item	2779526	et	4	main
2005	doc_634572338240_item	2779530	et	2	main
narva	doc_634572338240_item	2779532	et	4	main
kott	doc_634572338240_item	2779540	et	3	main
sest	doc_634572338240_item	2779549	et	4	main
oli	doc_634572338240_item	2779559	et	3	main
pööravad	doc_634572338241_item	2779584	et	4	main
minu	doc_634572338241_item	2779585	et	3	main
autole	doc_634572338241_item	2779586	et	3	main
olema	doc_634572338241_item	2779600	et	4	main
peab	doc_634572338241_item	2779617	et	4	main
ei	doc_634572338241_item	2779621	et	4	main
mulle	doc_634572338241_item	2779623	et	4	main
auto	doc_634572338242_item	2779629	et	4	main
unistuste	doc_634572338242_item	2779631	et	4	main
peab	doc_634572338242_item	2779633	et	4	main
liiga	doc_634572338242_item	2779645	et	4	main
tahan	doc_634572338242_item	2779647	et	3	main
minu	doc_634572338242_item	2779649	et	3	main
oleks	doc_634572338242_item	2779651	et	3	main
ma	doc_634572338242_item	2779661	et	3	main
ei	doc_634572338242_item	2779664	et	4	main
et	doc_634572338242_item	2779666	et	3	main
oleks	doc_634572338242_item	2779667	et	3	main
raske	doc_634572338242_item	2779668	et	4	main
see	doc_634572338243_item	2779677	et	3	main
autoga	doc_634572338245_item	2779822	et	3	main
ma	doc_634572338245_item	2779825	et	3	main
lülita	doc_634572338245_item	2779833	et	4	main
ära	doc_634572338245_item	2779862	et	4	main
linnast	doc_634572338245_item	2779871	et	4	main
vastus	doc_634572338246_item	2779873	et	3	main
objektidel	doc_634572338246_item	2779882	et	3	main
on	doc_634572338246_item	2779883	et	4	main
seisma	doc_634572338246_item	2779921	et	3	main
tallinn	doc_634572338246_item	2779933	et	4	main
on	doc_634572338246_item	2779937	et	4	main
siis	doc_634572338246_item	2779939	et	3	main
hakkavad	doc_634572338246_item	2779940	et	4	main
töötama	doc_634572338246_item	2779941	et	3	main
avariigeneraatorid	doc_634572338246_item	2779942	et	3	main
aga	doc_634572338246_item	2779943	et	3	main
kui	doc_634572338246_item	2779944	et	3	main
tehke	doc_634572338246_item	2779945	et	4	main
saanud	doc_634572338240_item	2779523	et	4	main
kuriteo	doc_634572338240_item	2779524	et	4	main
juhtus	doc_634572338240_item	2779527	et	3	main
proovis	doc_634572338240_item	2779537	et	4	main
kuidas	doc_634572338240_item	2779545	et	3	main
kurjategija	doc_634572338240_item	2779546	et	4	main
ole	doc_634572338240_item	2779550	et	4	main
noormes	doc_634572338240_item	2779558	et	4	main
kottiga	doc_634572338240_item	2779564	et	4	main
ära	doc_634572338240_item	2779565	et	4	main
allkiri	doc_634572338240_item	2779566	et	3	main
vastus	doc_634572338241_item	2779567	et	3	main
tema	doc_634572338241_item	2779574	et	4	main
sõitak	doc_634572338241_item	2779580	et	4	main
ma	doc_634572338241_item	2779581	et	3	main
ja	doc_634572338241_item	2779582	et	3	main
kõik	doc_634572338241_item	2779583	et	4	main
auto	doc_634572338241_item	2779591	et	4	main
värv	doc_634572338241_item	2779595	et	3	main
valge	doc_634572338241_item	2779601	et	4	main
ja	doc_634572338241_item	2779602	et	3	main
istmed	doc_634572338241_item	2779603	et	3	main
pehmed	doc_634572338241_item	2779604	et	3	main
ja	doc_634572338241_item	2779605	et	3	main
akna	doc_634572338241_item	2779613	et	3	main
signaliisasioon	doc_634572338241_item	2779619	et	4	main
varasta	doc_634572338241_item	2779622	et	4	main
küsimusele	doc_634572338242_item	2779626	et	4	main
kiirus	doc_634572338242_item	2779636	et	4	main
vanad	doc_634572338242_item	2779642	et	3	main
autod	doc_634572338242_item	2779643	et	3	main
väiked	doc_634572338242_item	2779646	et	4	main
et	doc_634572338242_item	2779648	et	3	main
olema	doc_634572338242_item	2779658	et	4	main
ilus	doc_634572338243_item	2779683	et	4	main
ta	doc_634572338243_item	2779684	et	4	main
peab	doc_634572338243_item	2779685	et	4	main
olema	doc_634572338243_item	2779686	et	4	main
suur	doc_634572338243_item	2779687	et	3	main
sellepärast	doc_634572338243_item	2779688	et	3	main
mul	doc_634572338243_item	2779689	et	3	main
on	doc_634572338243_item	2779690	et	4	main
suur	doc_634572338243_item	2779691	et	3	main
pere	doc_634572338243_item	2779692	et	4	main
katusel	doc_634572338243_item	2779693	et	3	main
oleb	doc_634572338243_item	2779694	et	4	main
ka	doc_634572338243_item	2779695	et	3	main
tuseluuk	doc_634572338243_item	2779696	et	4	main
see	doc_634572338243_item	2779697	et	3	main
auto	doc_634572338243_item	2779698	et	4	main
on	doc_634572338243_item	2779699	et	4	main
roheline	doc_634572338243_item	2779700	et	4	main
värvuse	doc_634572338243_item	2779701	et	3	main
moodsuse	doc_634572338243_item	2779702	et	4	main
ja	doc_634572338243_item	2779703	et	3	main
mugavuse	doc_634572338243_item	2779704	et	4	main
tal	doc_634572338243_item	2779705	et	3	main
suur	doc_634572338243_item	2779707	et	3	main
esituled	doc_634572338243_item	2779708	et	3	main
ja	doc_634572338243_item	2779709	et	3	main
mugane	doc_634572338243_item	2779710	et	4	main
lai	doc_634572338243_item	2779711	et	3	main
on	doc_634572338243_item	2779706	et	4	main
kummid	doc_634572338243_item	2779712	et	4	main
aga	doc_634572338243_item	2779713	et	3	main
ta	doc_634572338243_item	2779714	et	4	main
on	doc_634572338243_item	2779715	et	4	main
peab	doc_634572338243_item	2779716	et	4	main
olema	doc_634572338243_item	2779717	et	4	main
ei	doc_634572338243_item	2779718	et	4	main
ole	doc_634572338243_item	2779719	et	4	main
harjutus	doc_634572338245_item	2779817	et	4	main
kasuta	doc_634572338245_item	2779818	et	4	main
käskivat	doc_634572338245_item	2779819	et	4	main
kõneviisi	doc_634572338245_item	2779820	et	4	main
kihutama	doc_634572338245_item	2779821	et	3	main
linnast	doc_634572338245_item	2779823	et	4	main
kihutan	doc_634572338245_item	2779826	et	3	main
linnast	doc_634572338245_item	2779827	et	4	main
välja	doc_634572338245_item	2779828	et	4	main
autoga	doc_634572338245_item	2779829	et	3	main
elektrivirku	doc_634572338245_item	2779830	et	3	main
aku	doc_634572338245_item	2779836	et	4	main
kell	doc_634572338245_item	2779845	et	3	main
panna	doc_634572338245_item	2779847	et	4	main
koristamiseks	doc_634572338245_item	2779857	et	4	main
etta	doc_634572338245_item	2779859	et	4	main
katse	doc_634572338245_item	2779860	et	4	main
õppida	doc_634572338245_item	2779861	et	3	main
jäätist	doc_634572338245_item	2779868	et	3	main
kõikidel	doc_634572338246_item	2779879	et	4	main
kaitseväe	doc_634572338246_item	2779880	et	3	main
aga	doc_634572338246_item	2779922	et	3	main
on	doc_634572338246_item	2779924	et	4	main
kus	doc_634572338246_item	2779925	et	3	main
seal	doc_634572338246_item	2779927	et	4	main
on	doc_634572338246_item	2779928	et	4	main
avariigeneraatorid	doc_634572338246_item	2779929	et	3	main
ja	doc_634572338246_item	2779930	et	3	main
akud	doc_634572338246_item	2779931	et	3	main
kas	doc_634572338246_item	2779932	et	3	main
jookse	doc_634572338246_item	2779951	et	4	main
ja	doc_634572338246_item	2779957	et	3	main
raadio	doc_634572338246_item	2779958	et	4	main
küll	doc_634572338246_item	2779963	et	4	main
aga	doc_634572338246_item	2779964	et	3	main
voolu	doc_634572338246_item	2779970	et	4	main
seal	doc_634572338246_item	2779975	et	4	main
on	doc_634572338246_item	2779976	et	4	main
ja	doc_634572338246_item	2779978	et	3	main
aita	doc_634572338246_item	2779989	et	4	main
kui	doc_634572338246_item	2779990	et	3	main
küsimusele	doc_634572338247_item	2780028	et	4	main
ma	doc_634572338247_item	2780032	et	3	main
lülikatke	doc_634572338245_item	2779831	et	4	main
panna	doc_634572338245_item	2779838	et	4	main
akna	doc_634572338245_item	2779850	et	3	main
laikivad	doc_634572338245_item	2779852	et	3	main
on	doc_634572338245_item	2779854	et	4	main
vaja	doc_634572338245_item	2779855	et	4	main
masinatemihanismid	doc_634572338245_item	2779863	et	4	main
külmkapsis	doc_634572338245_item	2779864	et	3	main
on	doc_634572338245_item	2779865	et	4	main
hea	doc_634572338245_item	2779866	et	4	main
hoida	doc_634572338245_item	2779867	et	3	main
autoga	doc_634572338245_item	2779870	et	3	main
küsimusele	doc_634572338246_item	2779874	et	4	main
kas	doc_634572338246_item	2779875	et	3	main
raadarid	doc_634572338246_item	2779876	et	4	main
olulistel	doc_634572338246_item	2779881	et	4	main
joogiveeta	doc_634572338246_item	2779935	et	3	main
voolukatkestus	doc_634572338246_item	2779938	et	3	main
ei	doc_634572338246_item	2779950	et	4	main
ei	doc_634572338246_item	2779967	et	4	main
võimalik	doc_634572338246_item	2779968	et	3	main
politseinikud	doc_634572338246_item	2779972	et	4	main
akud	doc_634572338246_item	2779979	et	3	main
arvutitele	doc_634572338246_item	2779983	et	4	main
ja	doc_634572338246_item	2779984	et	3	main
sidesüsteemidele	doc_634572338246_item	2779985	et	3	main
nad	doc_634572338246_item	2779987	et	3	main
peab	doc_634572338247_item	2780041	et	4	main
kättesaadav	doc_634572338247_item	2780048	et	4	main
selg	doc_634572338247_item	2780057	et	3	main
peab	doc_634572338247_item	2780063	et	4	main
olema	doc_634572338247_item	2780064	et	4	main
punane	doc_634572338247_item	2780065	et	4	main
olema	doc_634572338247_item	2780071	et	4	main
auto	doc_634572338248_item	2780077	et	4	main
kiirus	doc_634572338248_item	2780080	et	4	main
tahan	doc_634572338248_item	2780087	et	3	main
välja	doc_634572338245_item	2779824	et	4	main
triikraud	doc_634572338245_item	2779834	et	3	main
elektrivõrku	doc_634572338245_item	2779835	et	4	main
tuleb	doc_634572338245_item	2779837	et	3	main
halvakvaliteetiga	doc_634572338245_item	2779842	et	4	main
puhasta	doc_634572338245_item	2779849	et	4	main
jäävad	doc_634572338246_item	2779877	et	4	main
pildita	doc_634572338246_item	2779878	et	3	main
toiteallikas	doc_634572338246_item	2779885	et	4	main
ehk	doc_634572338246_item	2779886	et	3	main
varugenerator	doc_634572338246_item	2779887	et	4	main
kas	doc_634572338246_item	2779888	et	3	main
kaevandused	doc_634572338246_item	2779889	et	4	main
upuvad	doc_634572338246_item	2779890	et	3	main
jah	doc_634572338246_item	2779891	et	3	main
küll	doc_634572338246_item	2779892	et	4	main
seal	doc_634572338246_item	2779893	et	4	main
on	doc_634572338246_item	2779894	et	4	main
aga	doc_634572338246_item	2779895	et	3	main
pumbad	doc_634572338246_item	2779896	et	3	main
ja	doc_634572338246_item	2779897	et	3	main
avariigeneraatorid	doc_634572338246_item	2779898	et	3	main
aga	doc_634572338246_item	2779899	et	3	main
pumbad	doc_634572338246_item	2779900	et	3	main
tarbivad	doc_634572338246_item	2779901	et	4	main
väga	doc_634572338246_item	2779902	et	3	main
palju	doc_634572338246_item	2779903	et	4	main
voolu	doc_634572338246_item	2779904	et	4	main
ja	doc_634572338246_item	2779905	et	3	main
generaatorid	doc_634572338246_item	2779906	et	3	main
ei	doc_634572338246_item	2779907	et	4	main
aita	doc_634572338246_item	2779908	et	4	main
üldse	doc_634572338246_item	2779909	et	3	main
kas	doc_634572338246_item	2779910	et	3	main
liftid	doc_634572338246_item	2779911	et	3	main
jäävad	doc_634572338246_item	2779912	et	4	main
seisma	doc_634572338246_item	2779913	et	3	main
kui	doc_634572338246_item	2779914	et	3	main
maja	doc_634572338246_item	2779915	et	4	main
on	doc_634572338246_item	2779916	et	4	main
suur	doc_634572338246_item	2779917	et	3	main
siis	doc_634572338246_item	2779918	et	3	main
liftid	doc_634572338246_item	2779919	et	3	main
jäävad	doc_634572338246_item	2779920	et	4	main
kui	doc_634572338246_item	2779923	et	3	main
maja	doc_634572338246_item	2779926	et	4	main
võtta	doc_634572338245_item	2779841	et	3	main
kaupa	doc_634572338245_item	2779843	et	4	main
aratus	doc_634572338245_item	2779844	et	4	main
tuleb	doc_634572338245_item	2779846	et	3	main
taimerile	doc_634572338245_item	2779848	et	4	main
klassid	doc_634572338245_item	2779851	et	3	main
põrandaharja	doc_634572338245_item	2779853	et	4	main
rumide	doc_634572338245_item	2779856	et	4	main
võtta	doc_634572338245_item	2779858	et	3	main
kihutada	doc_634572338245_item	2779869	et	3	main
välja	doc_634572338245_item	2779872	et	4	main
autonoomne	doc_634572338246_item	2779884	et	3	main
jääb	doc_634572338246_item	2779934	et	3	main
vesi	doc_634572338246_item	2779949	et	4	main
ta	doc_634572338246_item	2779952	et	4	main
jõua	doc_634572338246_item	2779954	et	4	main
tööta	doc_634572338246_item	2779960	et	4	main
ei	doc_634572338246_item	2779961	et	4	main
anda	doc_634572338246_item	2779969	et	3	main
sideta	doc_634572338246_item	2779974	et	4	main
mis	doc_634572338246_item	2779980	et	4	main
voolu	doc_634572338246_item	2779982	et	4	main
aga	doc_634572338246_item	2779986	et	3	main
katkestus	doc_634572338246_item	2779991	et	4	main
on	doc_634572338246_item	2779992	et	4	main
rohkem	doc_634572338246_item	2779993	et	4	main
48	doc_634572338246_item	2779994	et	2	main
tunnist	doc_634572338246_item	2779995	et	4	main
kas	doc_634572338246_item	2779996	et	3	main
haiglates	doc_634572338246_item	2779997	et	3	main
on	doc_634572338246_item	2779998	et	4	main
varuvõimalus	doc_634572338246_item	2779999	et	3	main
jah	doc_634572338246_item	2780000	et	3	main
seal	doc_634572338246_item	2780001	et	4	main
on	doc_634572338246_item	2780002	et	4	main
varugeneraatorid	doc_634572338246_item	2780003	et	3	main
ja	doc_634572338246_item	2780004	et	3	main
ups	doc_634572338246_item	2780005	et	4	main
patareid	doc_634572338246_item	2780006	et	4	main
need	doc_634572338246_item	2780007	et	3	main
häirivad	doc_634572338246_item	2780008	et	4	main
haigla	doc_634572338246_item	2780009	et	4	main
tööd	doc_634572338246_item	2780010	et	4	main
palju	doc_634572338246_item	2780011	et	4	main
rohkem	doc_634572338246_item	2780012	et	4	main
kas	doc_634572338246_item	2780013	et	3	main
pangakaardid	doc_634572338246_item	2780014	et	3	main
ei	doc_634572338246_item	2780015	et	4	main
tööta	doc_634572338246_item	2780016	et	4	main
ei	doc_634572338246_item	2780017	et	4	main
tööta	doc_634572338246_item	2780018	et	4	main
töötavad	doc_634572338246_item	2780019	et	4	main
ainult	doc_634572338246_item	2780020	et	4	main
liivalaja	doc_634572338246_item	2780021	et	4	main
ja	doc_634572338246_item	2780023	et	3	main
olema	doc_634572338247_item	2780042	et	4	main
elektripakk	doc_634572338247_item	2780043	et	3	main
et	doc_634572338247_item	2780044	et	3	main
autose	doc_634572338247_item	2780049	et	4	main
istmed	doc_634572338247_item	2780050	et	3	main
väsiks	doc_634572338247_item	2780061	et	3	main
või	doc_634572338247_item	2780066	et	4	main
kolane	doc_634572338247_item	2780067	et	4	main
minu	doc_634572338247_item	2780068	et	3	main
kui	doc_634572338246_item	2779936	et	3	main
ei	doc_634572338246_item	2779959	et	4	main
tallinna	doc_634572338246_item	2779965	et	4	main
teletornis	doc_634572338246_item	2779966	et	3	main
kas	doc_634572338246_item	2779971	et	3	main
jäävad	doc_634572338246_item	2779973	et	4	main
avariigeneraatorid	doc_634572338246_item	2779977	et	3	main
annavad	doc_634572338246_item	2779981	et	3	main
lahti	doc_634572338246_item	2779946	et	4	main
kraan	doc_634572338246_item	2779947	et	3	main
siis	doc_634572338246_item	2779948	et	3	main
ei	doc_634572338246_item	2779953	et	4	main
kas	doc_634572338246_item	2779955	et	3	main
tv	doc_634572338246_item	2779956	et	4	main
tööta	doc_634572338246_item	2779962	et	4	main
ei	doc_634572338246_item	2779988	et	4	main
rävala	doc_634572338246_item	2780024	et	4	main
puiestee	doc_634572338246_item	2780025	et	4	main
kontorid	doc_634572338246_item	2780026	et	3	main
vastus	doc_634572338247_item	2780027	et	3	main
unistuse	doc_634572338247_item	2780030	et	4	main
unistan	doc_634572338247_item	2780033	et	3	main
väike	doc_634572338247_item	2780034	et	4	main
mugav	doc_634572338247_item	2780035	et	3	main
moodne	doc_634572338247_item	2780036	et	3	main
ja	doc_634572338247_item	2780037	et	3	main
kõik	doc_634572338247_item	2780045	et	4	main
olema	doc_634572338247_item	2780052	et	4	main
väga	doc_634572338247_item	2780055	et	3	main
on	doc_634572338247_item	2780058	et	4	main
autose	doc_634572338247_item	2780069	et	4	main
vastus	doc_634572338248_item	2780073	et	3	main
unistute	doc_634572338248_item	2780076	et	4	main
mulle	doc_634572338248_item	2780078	et	4	main
meldib	doc_634572338248_item	2780079	et	4	main
volkswagen	doc_634572338248_item	2780084	et	4	main
ma	doc_634572338248_item	2780086	et	3	main
polo	doc_634572338248_item	2780090	et	4	main
14	doc_634572338248_item	2780091	et	2	main
rattad	doc_634572338248_item	2780092	et	3	main
ja	doc_634572338248_item	2780093	et	3	main
värvi	doc_634572338249_item	2780126	et	4	main
tahaks	doc_634572338249_item	2780127	et	3	main
auto	doc_634572338249_item	2780130	et	4	main
firma	doc_634572338249_item	2780146	et	4	main
oleks	doc_634572338249_item	2780147	et	3	main
bmw	doc_634572338249_item	2780148	et	4	main
on	doc_634572338249_item	2780149	et	4	main
salong	doc_634572338249_item	2780165	et	3	main
automatiseeritud	doc_634572338249_item	2780167	et	4	main
oleks	doc_634572338249_item	2780170	et	3	main
1	doc_640286507873_item	2780174	et	2	main
1970ndatel	doc_640286507873_item	2780179	et	4	main
nsvl	doc_640286507873_item	2780185	et	4	main
lähisvälismaana	doc_640286507873_item	2780186	et	3	main
laiuse	doc_640286507873_item	2780189	et	4	main
kas	doc_640286507873_item	2780192	et	3	main
1	doc_640286507873_item	2780199	et	2	main
sellest	doc_640286507873_item	2780200	et	4	main
oli	doc_640286507873_item	2780206	et	3	main
oskasid	doc_640286507873_item	2780210	et	4	main
traditsiooni	doc_640286507873_item	2780216	et	4	main
80ndate	doc_640286507873_item	2780217	et	4	main
hakati	doc_640286507873_item	2780219	et	3	main
folkloori	doc_640286507873_item	2780221	et	4	main
kestis	doc_640286507873_item	2780233	et	4	main
loeng	doc_640286507873_item	2780234	et	3	main
45	doc_640286507873_item	2780235	et	2	main
minutit	doc_640286507873_item	2780236	et	3	main
kui	doc_640286507873_item	2780237	et	3	main
inimene	doc_640286507873_item	2780258	et	3	main
humanitaarteadustes	doc_640286507873_item	2780299	et	3	main
süvenes	doc_640286507873_item	2780301	et	3	main
tendentslikus	doc_640286507873_item	2780303	et	4	main
pidurdus	doc_640286507873_item	2780304	et	4	main
noore	doc_640286507873_item	2780305	et	3	main
kaadri	doc_640286507873_item	2780306	et	3	main
pealekasv	doc_640286507873_item	2780307	et	3	main
ka	doc_640286507873_item	2780308	et	3	main
kasvas	doc_640286507873_item	2780309	et	3	main
entel-tentel	doc_640286507873_item	2780321	et	4	main
mis	doc_640286507873_item	2780337	et	4	main
käib	doc_640286507873_item	2780338	et	3	main
tänase	doc_640286507873_item	2780339	et	3	main
päevani	doc_640286507873_item	2780340	et	3	main
eestisse	doc_640286507873_item	2780344	et	4	main
maakoolid	doc_640286507873_item	2780346	et	3	main
hakkasid	doc_640286507873_item	2780348	et	4	main
enamus	doc_640286507873_item	2780355	et	4	main
tänaval	doc_634572338246_item	2780022	et	4	main
minu	doc_634572338247_item	2780029	et	3	main
auto	doc_634572338247_item	2780031	et	4	main
autose	doc_634572338247_item	2780040	et	4	main
olma	doc_634572338247_item	2780047	et	4	main
peab	doc_634572338247_item	2780051	et	4	main
pehmed	doc_634572338247_item	2780053	et	3	main
ei	doc_634572338247_item	2780059	et	4	main
näiteks	doc_634572338248_item	2780083	et	4	main
punane	doc_634572338248_item	2780095	et	4	main
värvid	doc_634572338248_item	2780096	et	4	main
vastus	doc_634572338249_item	2780097	et	3	main
küsimusele	doc_634572338249_item	2780098	et	4	main
minu	doc_634572338249_item	2780099	et	3	main
unistuste	doc_634572338249_item	2780100	et	4	main
auto	doc_634572338249_item	2780101	et	4	main
ma	doc_634572338249_item	2780102	et	3	main
tahaksin	doc_634572338249_item	2780103	et	3	main
et	doc_634572338249_item	2780104	et	3	main
mul	doc_634572338249_item	2780105	et	3	main
oli	doc_634572338249_item	2780106	et	3	main
moodne	doc_634572338249_item	2780107	et	3	main
mitte	doc_634572338249_item	2780108	et	3	main
eriline	doc_634572338249_item	2780109	et	4	main
auto	doc_634572338249_item	2780110	et	4	main
kauplusest	doc_634572338249_item	2780111	et	4	main
et	doc_634572338249_item	2780112	et	3	main
õues	doc_634572338249_item	2780113	et	4	main
kõik	doc_634572338249_item	2780114	et	4	main
inimesed	doc_634572338249_item	2780115	et	3	main
pöörasid	doc_634572338249_item	2780116	et	4	main
ma	doc_634572338249_item	2780117	et	3	main
tahaksin	doc_634572338249_item	2780118	et	3	main
et	doc_634572338249_item	2780119	et	3	main
auto	doc_634572338249_item	2780120	et	4	main
keskmise	doc_634572338249_item	2780132	et	3	main
et	doc_634572338249_item	2780138	et	3	main
see	doc_634572338249_item	2780153	et	3	main
et	doc_634572338249_item	2780164	et	3	main
ja	doc_634572338249_item	2780168	et	3	main
hele	doc_634572338249_item	2780171	et	3	main
kontrolltöö	doc_640286507873_item	2780173	et	4	main
eesti	doc_640286507873_item	2780181	et	4	main
või	doc_640286507873_item	2780196	et	4	main
pärast	doc_640286507873_item	2780204	et	4	main
inimesi	doc_640286507873_item	2780208	et	4	main
ülikoolis	doc_640286507873_item	2780232	et	4	main
järelmaksuga	doc_640286507873_item	2780250	et	3	main
vaibad	doc_640286507873_item	2780251	et	3	main
külmkapid	doc_640286507873_item	2780252	et	3	main
selleks	doc_640286507873_item	2780253	et	4	main
et	doc_640286507873_item	2780254	et	3	main
andis	doc_640286507873_item	2780295	et	3	main
end	doc_640286507873_item	2780297	et	4	main
tuli	doc_640286507873_item	2780314	et	4	main
rohkem	doc_640286507873_item	2780315	et	4	main
turvalisus	doc_634572338247_item	2780038	et	4	main
autost	doc_634572338247_item	2780039	et	3	main
on	doc_634572338247_item	2780046	et	4	main
ja	doc_634572338247_item	2780054	et	3	main
mugavused	doc_634572338247_item	2780056	et	4	main
ole	doc_634572338247_item	2780060	et	4	main
värvus	doc_634572338247_item	2780062	et	4	main
peab	doc_634572338247_item	2780070	et	4	main
küsimusele	doc_634572338248_item	2780074	et	4	main
mugavus	doc_634572338248_item	2780081	et	4	main
autod	doc_634572338248_item	2780082	et	3	main
must	doc_634572338248_item	2780088	et	4	main
volkswagen	doc_634572338248_item	2780089	et	4	main
kummid	doc_634572338248_item	2780094	et	4	main
oli	doc_634572338249_item	2780122	et	3	main
või	doc_634572338249_item	2780124	et	4	main
ebatavalise	doc_634572338249_item	2780125	et	4	main
minu	doc_634572338249_item	2780129	et	3	main
oli	doc_634572338249_item	2780131	et	3	main
suuruse	doc_634572338249_item	2780133	et	4	main
oleks	doc_634572338249_item	2780135	et	3	main
seal	doc_634572338249_item	2780139	et	4	main
magada	doc_634572338249_item	2780141	et	3	main
vajatusel	doc_634572338249_item	2780142	et	4	main
et	doc_634572338249_item	2780152	et	3	main
põhjust	doc_640286507873_item	2780180	et	4	main
2	doc_640286507873_item	2780187	et	2	main
libahunt	doc_640286507873_item	2780191	et	3	main
miks	doc_640286507873_item	2780198	et	4	main
sõda	doc_640286507873_item	2780205	et	4	main
mängida	doc_640286507873_item	2780212	et	3	main
olnud	doc_640286507873_item	2780214	et	4	main
signalisatsioon	doc_634572338247_item	2780072	et	3	main
minu	doc_634572338248_item	2780075	et	3	main
ja	doc_634572338248_item	2780085	et	3	main
metallik	doc_634572338249_item	2780123	et	4	main
mugav	doc_634572338249_item	2780137	et	3	main
võiks	doc_634572338249_item	2780140	et	4	main
tahaks	doc_634572338249_item	2780143	et	3	main
et	doc_634572338249_item	2780144	et	3	main
tootja	doc_634572338249_item	2780145	et	4	main
vaja	doc_634572338249_item	2780150	et	4	main
ka	doc_634572338249_item	2780151	et	3	main
majanduslikud-kultuurilised	doc_640286507873_item	2780176	et	4	main
nsvi	doc_640286507873_item	2780182	et	4	main
l	doc_640286507873_item	2780188	et	4	main
mängufilm	doc_640286507873_item	2780190	et	3	main
teie	doc_640286507873_item	2780193	et	4	main
arvates	doc_640286507873_item	2780194	et	4	main
ajaloodokument	doc_640286507873_item	2780195	et	3	main
räägitakse	doc_640286507873_item	2780201	et	3	main
suhteliselt	doc_640286507873_item	2780202	et	4	main
vähe	doc_640286507873_item	2780203	et	3	main
pille	doc_640286507873_item	2780211	et	3	main
alguses	doc_640286507873_item	2780218	et	4	main
käima	doc_640286507873_item	2780231	et	4	main
osta	doc_640286507873_item	2780249	et	4	main
nt	doc_640286507873_item	2780256	et	4	main
pidi	doc_640286507873_item	2780259	et	4	main
luba	doc_640286507873_item	2780261	et	4	main
küsima	doc_640286507873_item	2780262	et	3	main
2	doc_640286507873_item	2780263	et	2	main
erisoodustus	doc_640286507873_item	2780264	et	3	main
tugevalt	doc_640286507873_item	2780294	et	4	main
noorte	doc_640286507873_item	2780312	et	3	main
uusi	doc_640286507873_item	2780316	et	3	main
nagu	doc_640286507873_item	2780319	et	3	main
värvus	doc_634572338249_item	2780121	et	4	main
et	doc_634572338249_item	2780128	et	3	main
ja	doc_634572338249_item	2780134	et	3	main
väga	doc_634572338249_item	2780136	et	3	main
auto	doc_634572338249_item	2780154	et	4	main
oleks	doc_634572338249_item	2780155	et	3	main
turvalisus	doc_634572338249_item	2780156	et	4	main
sest	doc_634572338249_item	2780157	et	4	main
meie	doc_634572338249_item	2780158	et	4	main
ajal	doc_634572338249_item	2780159	et	4	main
on	doc_634572338249_item	2780160	et	4	main
palju	doc_634572338249_item	2780161	et	4	main
kuritegijad	doc_634572338249_item	2780162	et	3	main
tahaks	doc_634572338249_item	2780163	et	3	main
oleks	doc_634572338249_item	2780166	et	3	main
salong	doc_634572338249_item	2780169	et	3	main
värvi	doc_634572338249_item	2780172	et	4	main
missugused	doc_640286507873_item	2780175	et	3	main
tegurid	doc_640286507873_item	2780177	et	3	main
andsid	doc_640286507873_item	2780178	et	4	main
tunda	doc_640286507873_item	2780183	et	3	main
end	doc_640286507873_item	2780184	et	4	main
ühiskonnakriitika	doc_640286507873_item	2780197	et	4	main
vähe	doc_640286507873_item	2780207	et	3	main
kes	doc_640286507873_item	2780209	et	4	main
on	doc_640286507873_item	2780213	et	4	main
laulude	doc_640286507873_item	2780215	et	3	main
tegema	doc_640286507873_item	2780220	et	3	main
olid	doc_640286507873_item	2780223	et	4	main
kohalviibimist	doc_640286507873_item	2780227	et	3	main
igas	doc_640286507873_item	2780228	et	3	main
hakati	doc_640286507873_item	2780238	et	3	main
avaldama	doc_640286507873_item	2780239	et	3	main
majanduslikku	doc_640286507873_item	2780240	et	4	main
survet	doc_640286507873_item	2780241	et	3	main
siis	doc_640286507873_item	2780242	et	3	main
hakkas	doc_640286507873_item	2780243	et	3	main
situatsioon	doc_640286507873_item	2780244	et	3	main
paranema	doc_640286507873_item	2780245	et	3	main
1	doc_640286507873_item	2780246	et	2	main
tarbijakaupu	doc_640286507873_item	2780247	et	3	main
võis	doc_640286507873_item	2780248	et	4	main
vaipa	doc_640286507873_item	2780257	et	4	main
enne	doc_640286507873_item	2780260	et	4	main
luksus	doc_640286507873_item	2780265	et	4	main
kaupadele	doc_640286507873_item	2780266	et	3	main
autod	doc_640286507873_item	2780267	et	3	main
telerid	doc_640286507873_item	2780268	et	3	main
vaibad	doc_640286507873_item	2780269	et	3	main
stagnaperiood	doc_640286507873_item	2780296	et	3	main
tunda	doc_640286507873_item	2780298	et	3	main
siis	doc_640286507873_item	2780300	et	3	main
käsitluse	doc_640286507873_item	2780302	et	4	main
seas	doc_640286507873_item	2780313	et	4	main
noorte	doc_640286507873_item	2780317	et	3	main
nt	doc_640286507873_item	2780320	et	4	main
tipp	doc_640286507873_item	2780323	et	3	main
televisiooni	doc_640286507873_item	2780326	et	4	main
välismaalased	doc_640286507873_item	2780342	et	3	main
oli	doc_640286507873_item	2780359	et	3	main
neile	doc_640286507873_item	2780366	et	4	main
arvates	doc_640286507874_item	2780397	et	4	main
miks	doc_640286507874_item	2780401	et	4	main
põhjust	doc_640286507874_item	2780410	et	4	main
lähivälismaana	doc_640286507874_item	2780415	et	3	main
see	doc_640286507874_item	2780417	et	3	main
side	doc_640286507874_item	2780426	et	4	main
läänega	doc_640286507874_item	2780427	et	3	main
see	doc_640286507874_item	2780428	et	3	main
liikumise	doc_640286507874_item	2780431	et	4	main
sest	doc_640286507874_item	2780441	et	4	main
need	doc_640286507874_item	2780442	et	3	main
põhja-eesti	doc_640286507874_item	2780447	et	4	main
kultuuriliseks	doc_640286507874_item	2780465	et	4	main
teguriks	doc_640286507874_item	2780466	et	3	main
minu	doc_640286507874_item	2780467	et	3	main
väga	doc_640286507874_item	2780473	et	3	main
mängud	doc_640286507874_item	2780477	et	3	main
andsid	doc_640286507874_item	2780515	et	4	main
llaiuse	doc_640286507874_item	2780524	et	4	main
suunatud	doc_640286507874_item	2780543	et	4	main
kes	doc_640286507874_item	2780553	et	4	main
oma	doc_640286507874_item	2780559	et	4	main
ning	doc_640286507874_item	2780584	et	3	main
armastus	doc_640286507874_item	2780586	et	4	main
ei	doc_640286507874_item	2780587	et	4	main
üle	doc_640286507874_item	2780590	et	3	main
on	doc_640286507874_item	2780595	et	4	main
väga	doc_640286507874_item	2780596	et	3	main
hea	doc_640286507874_item	2780597	et	4	main
romaan	doc_640286507874_item	2780598	et	3	main
sest	doc_640286507874_item	2780599	et	4	main
see	doc_640286507874_item	2780600	et	3	main
annab	doc_640286507874_item	2780601	et	3	main
inimeste	doc_640286507874_item	2780605	et	3	main
ülikoolides	doc_640286507873_item	2780222	et	3	main
muudatused	doc_640286507873_item	2780224	et	3	main
kontrolliti	doc_640286507873_item	2780225	et	3	main
koolivormi	doc_640286507873_item	2780226	et	4	main
tunnis	doc_640286507873_item	2780229	et	3	main
pidi	doc_640286507873_item	2780230	et	4	main
osta	doc_640286507873_item	2780255	et	4	main
70ndatel	doc_640286507873_item	2780270	et	4	main
hakati	doc_640286507873_item	2780271	et	3	main
tootma	doc_640286507873_item	2780272	et	3	main
norma	doc_640286507873_item	2780273	et	4	main
märgid	doc_640286507873_item	2780274	et	4	main
sportlastel	doc_640286507873_item	2780275	et	4	main
tüdrukutel	doc_640286507873_item	2780276	et	4	main
lubati	doc_640286507873_item	2780277	et	3	main
kanda	doc_640286507873_item	2780278	et	4	main
pikki	doc_640286507873_item	2780279	et	4	main
pükse	doc_640286507873_item	2780280	et	3	main
ülikoolides	doc_640286507873_item	2780281	et	3	main
loengud	doc_640286507873_item	2780282	et	3	main
hakkasid	doc_640286507873_item	2780283	et	4	main
kestma	doc_640286507873_item	2780284	et	3	main
15	doc_640286507873_item	2780285	et	2	main
tundi	doc_640286507873_item	2780286	et	4	main
aktiviseerus	doc_640286507873_item	2780287	et	3	main
kultuuritarbimine	doc_640286507873_item	2780288	et	3	main
etteotsa	doc_640286507873_item	2780289	et	3	main
jõudsid	doc_640286507873_item	2780290	et	4	main
kino-	doc_640286507873_item	2780291	et	4	main
arvud	doc_640286507873_item	2780293	et	3	main
teatrikülastajate	doc_640286507873_item	2780292	et	3	main
televisiooni	doc_640286507873_item	2780310	et	4	main
maht	doc_640286507873_item	2780311	et	3	main
täpp	doc_640286507873_item	2780325	et	3	main
tuli	doc_640286507873_item	2780327	et	4	main
ka	doc_640286507873_item	2780328	et	3	main
uued	doc_640286507873_item	2780329	et	3	main
saated	doc_640286507873_item	2780330	et	3	main
mälumängud	doc_640286507873_item	2780331	et	3	main
ja	doc_640286507873_item	2780332	et	3	main
tõsielusarjad	doc_640286507873_item	2780333	et	3	main
nt	doc_640286507873_item	2780334	et	4	main
käima	doc_640286507873_item	2780351	et	4	main
linna	doc_640286507873_item	2780358	et	4	main
varastasid	doc_640286507873_item	2780363	et	4	main
l	doc_640286507874_item	2780391	et	4	main
laiuse	doc_640286507874_item	2780392	et	4	main
mängufilm	doc_640286507874_item	2780393	et	3	main
libahunt	doc_640286507874_item	2780394	et	3	main
kas	doc_640286507874_item	2780395	et	3	main
tähtsam	doc_640286507874_item	2780406	et	4	main
end	doc_640286507874_item	2780414	et	4	main
et	doc_640286507874_item	2780418	et	3	main
ning	doc_640286507874_item	2780422	et	3	main
sellel	doc_640286507874_item	2780423	et	4	main
alati	doc_640286507874_item	2780424	et	4	main
raske	doc_640286507874_item	2780436	et	4	main
sõita	doc_640286507874_item	2780437	et	3	main
saartele	doc_640286507874_item	2780438	et	3	main
eriti	doc_640286507874_item	2780439	et	3	main
liiga	doc_640286507874_item	2780445	et	4	main
nad	doc_640286507874_item	2780456	et	3	main
arvates	doc_640286507874_item	2780468	et	4	main
oli	doc_640286507874_item	2780469	et	3	main
televiktoriinid	doc_640286507874_item	2780476	et	3	main
teised	doc_640286507874_item	2780511	et	4	main
eestile	doc_640286507874_item	2780516	et	3	main
põhjust	doc_640286507874_item	2780517	et	4	main
tunda	doc_640286507874_item	2780518	et	3	main
end	doc_640286507874_item	2780519	et	4	main
lähisvälismaana	doc_640286507874_item	2780520	et	3	main
saateid	doc_640286507873_item	2780318	et	3	main
ja	doc_640286507873_item	2780322	et	3	main
paljud	doc_640286507873_item	2780341	et	3	main
likvideeriti	doc_640286507873_item	2780345	et	3	main
maalapsed	doc_640286507873_item	2780347	et	3	main
linna	doc_640286507873_item	2780349	et	4	main
koolis	doc_640286507873_item	2780350	et	4	main
kuna	doc_640286507873_item	2780354	et	3	main
lapsed	doc_640286507873_item	2780356	et	3	main
riigivargus	doc_640286507873_item	2780361	et	3	main
töökohtadelt	doc_640286507873_item	2780365	et	3	main
ajaloodokument	doc_640286507874_item	2780398	et	3	main
ühiskonnakriitika	doc_640286507874_item	2780400	et	4	main
arvates	doc_640286507874_item	2780404	et	4	main
kõige	doc_640286507874_item	2780405	et	4	main
andis	doc_640286507874_item	2780409	et	3	main
eesti	doc_640286507874_item	2780411	et	4	main
nsvl	doc_640286507874_item	2780412	et	4	main
tunda	doc_640286507874_item	2780413	et	3	main
on	doc_640286507874_item	2780416	et	4	main
eesti	doc_640286507874_item	2780419	et	4	main
on	doc_640286507874_item	2780420	et	4	main
ja	doc_640286507873_item	2780324	et	3	main
õnne	doc_640286507873_item	2780335	et	4	main
13	doc_640286507873_item	2780336	et	2	main
tulid	doc_640286507873_item	2780343	et	4	main
kolisid	doc_640286507873_item	2780352	et	4	main
linna	doc_640286507873_item	2780353	et	4	main
ka	doc_640286507873_item	2780360	et	3	main
kodule	doc_640286507873_item	2780367	et	3	main
vajalikke	doc_640286507873_item	2780368	et	3	main
asju	doc_640286507873_item	2780369	et	3	main
nagu	doc_640286507873_item	2780370	et	3	main
nt	doc_640286507873_item	2780371	et	4	main
tööriistu	doc_640286507873_item	2780373	et	3	main
ja	doc_640286507873_item	2780374	et	3	main
naelu	doc_640286507873_item	2780372	et	3	main
teisi	doc_640286507873_item	2780375	et	4	main
1	doc_640286507874_item	2780377	et	2	main
kontrolltöö	doc_640286507874_item	2780376	et	4	main
missugused	doc_640286507874_item	2780378	et	3	main
majanduslikud-kultuurilised	doc_640286507874_item	2780379	et	4	main
tegurid	doc_640286507874_item	2780380	et	3	main
andsid	doc_640286507874_item	2780381	et	4	main
1970ndatel	doc_640286507874_item	2780382	et	4	main
põhjust	doc_640286507874_item	2780383	et	4	main
eesti	doc_640286507874_item	2780384	et	4	main
nsvi	doc_640286507874_item	2780385	et	4	main
tunda	doc_640286507874_item	2780386	et	3	main
kolisid	doc_640286507873_item	2780357	et	4	main
inimesed	doc_640286507873_item	2780362	et	3	main
oma	doc_640286507873_item	2780364	et	4	main
end	doc_640286507874_item	2780387	et	4	main
teie	doc_640286507874_item	2780396	et	4	main
tegur	doc_640286507874_item	2780407	et	3	main
mis	doc_640286507874_item	2780408	et	4	main
sadamalinn	doc_640286507874_item	2780421	et	3	main
olid	doc_640286507874_item	2780443	et	4	main
elanikutel	doc_640286507874_item	2780448	et	4	main
oli	doc_640286507874_item	2780449	et	3	main
võimalus	doc_640286507874_item	2780450	et	3	main
ka	doc_640286507874_item	2780451	et	3	main
soome	doc_640286507874_item	2780452	et	3	main
tv	doc_640286507874_item	2780453	et	4	main
said	doc_640286507874_item	2780457	et	4	main
seal	doc_640286507874_item	2780459	et	4	main
elati	doc_640286507874_item	2780460	et	3	main
ja	doc_640286507874_item	2780461	et	3	main
oli	doc_640286507874_item	2780472	et	3	main
jne	doc_640286507874_item	2780478	et	4	main
ka	doc_640286507874_item	2780510	et	3	main
mis	doc_640286507874_item	2780512	et	4	main
tulenevad	doc_640286507874_item	2780513	et	4	main
nendest	doc_640286507874_item	2780514	et	4	main
minu	doc_640286507874_item	2780522	et	3	main
rohkem	doc_640286507874_item	2780528	et	4	main
agressiivsust	doc_640286507874_item	2780540	et	4	main
mis	doc_640286507874_item	2780541	et	4	main
ongi	doc_640286507874_item	2780550	et	4	main
ema	doc_640286507874_item	2780560	et	4	main
mõtlemisviisi	doc_640286507874_item	2780581	et	4	main
vastu	doc_640286507874_item	2780582	et	3	main
saanud	doc_640286507874_item	2780588	et	4	main
suurepärase	doc_640286507874_item	2780602	et	4	main
ja	doc_640286507874_item	2780609	et	3	main
näeb	doc_640286507874_item	2780612	et	3	main
ning	doc_640286507874_item	2780615	et	3	main
oma	doc_640286507874_item	2780617	et	4	main
realism	doc_640286507876_item	2780774	et	3	main
vaid	doc_640286507876_item	2780790	et	3	main
vabanemine	doc_640286507876_item	2780806	et	4	main
kultuur	doc_640286507876_item	2780807	et	3	main
arenes	doc_640286507876_item	2780808	et	3	main
nüüd	doc_640286507876_item	2780809	et	4	main
õnnelikud	doc_640286507876_item	2780824	et	3	main
lõpu	doc_640286507876_item	2780827	et	3	main
ellujäämise	doc_640286507876_item	2780829	et	4	main
kunsti-	doc_640286507876_item	2780837	et	4	main
ja	doc_640286507876_item	2780838	et	3	main
haridusjanus	doc_640286507876_item	2780839	et	3	main
nad	doc_640286507876_item	2780840	et	3	main
ajal	doc_640286507876_item	2780848	et	4	main
ja	doc_640286507876_item	2780856	et	3	main
mis	doc_640286507876_item	2780857	et	4	main
oli	doc_640286507876_item	2780858	et	3	main
katkestatud	doc_640286507876_item	2780859	et	4	main
sõjaga	doc_640286507876_item	2780860	et	3	main
nsvl	doc_640286507874_item	2780388	et	4	main
lähisvälismaana	doc_640286507874_item	2780389	et	3	main
2	doc_640286507874_item	2780390	et	2	main
või	doc_640286507874_item	2780399	et	4	main
1	doc_640286507874_item	2780402	et	2	main
minu	doc_640286507874_item	2780403	et	3	main
piiramist	doc_640286507874_item	2780432	et	4	main
näiteks	doc_640286507874_item	2780433	et	4	main
oli	doc_640286507874_item	2780434	et	3	main
väga	doc_640286507874_item	2780435	et	3	main
riigipiiri	doc_640286507874_item	2780444	et	4	main
kust	doc_640286507874_item	2780455	et	4	main
elu	doc_640286507874_item	2780463	et	4	main
on	doc_640286507874_item	2780464	et	4	main
etv	doc_640286507874_item	2780471	et	4	main
lastesaaded	doc_640286507874_item	2780475	et	4	main
2	doc_640286507874_item	2780521	et	2	main
libahunt	doc_640286507874_item	2780526	et	3	main
nähtuste	doc_640286507874_item	2780535	et	4	main
vastu	doc_640286507874_item	2780536	et	3	main
ja	doc_640286507874_item	2780537	et	3	main
ebaõiglast	doc_640286507874_item	2780539	et	3	main
sellele	doc_640286507874_item	2780544	et	4	main
keda	doc_640286507874_item	2780545	et	4	main
nad	doc_640286507874_item	2780546	et	3	main
see	doc_640286507874_item	2780551	et	3	main
on	doc_640286507874_item	2780555	et	4	main
ta	doc_640286507874_item	2780557	et	4	main
tekkinud	doc_640286507874_item	2780580	et	4	main
arvan	doc_640286507874_item	2780592	et	3	main
võimaluse	doc_640286507874_item	2780603	et	3	main
teisest	doc_640286507874_item	2780607	et	4	main
oli	doc_640286507874_item	2780425	et	3	main
ka	doc_640286507874_item	2780429	et	3	main
põhjustas	doc_640286507874_item	2780430	et	3	main
väikestele	doc_640286507874_item	2780440	et	4	main
lähedal	doc_640286507874_item	2780446	et	4	main
vaadata	doc_640286507874_item	2780454	et	4	main
kuidas	doc_640286507874_item	2780458	et	3	main
missugune	doc_640286507874_item	2780462	et	3	main
etv	doc_640286507874_item	2780470	et	4	main
populaarne	doc_640286507874_item	2780474	et	3	main
see	doc_640286507874_item	2780479	et	3	main
kõik	doc_640286507874_item	2780480	et	4	main
tegi	doc_640286507874_item	2780481	et	4	main
tugeva	doc_640286507874_item	2780482	et	4	main
siide	doc_640286507874_item	2780483	et	3	main
elanikutega	doc_640286507874_item	2780484	et	4	main
eestis	doc_640286507874_item	2780485	et	3	main
asus	doc_640286507874_item	2780486	et	4	main
ka	doc_640286507874_item	2780487	et	3	main
reklammikool	doc_640286507874_item	2780488	et	4	main
niisugust	doc_640286507874_item	2780489	et	3	main
asja	doc_640286507874_item	2780490	et	4	main
nsvl-s	doc_640286507874_item	2780491	et	3	main
kuskil	doc_640286507874_item	2780492	et	3	main
veel	doc_640286507874_item	2780493	et	4	main
ei	doc_640286507874_item	2780494	et	4	main
olnud	doc_640286507874_item	2780495	et	4	main
samuti	doc_640286507874_item	2780496	et	3	main
oli	doc_640286507874_item	2780497	et	3	main
väga	doc_640286507874_item	2780498	et	3	main
tähtis	doc_640286507874_item	2780499	et	4	main
turims	doc_640286507874_item	2780500	et	4	main
just	doc_640286507874_item	2780501	et	3	main
nende	doc_640286507874_item	2780502	et	4	main
jaoks	doc_640286507874_item	2780503	et	4	main
avati	doc_640286507874_item	2780504	et	3	main
valuutakauplused	doc_640286507874_item	2780505	et	3	main
kõik	doc_640286507874_item	2780506	et	4	main
need	doc_640286507874_item	2780507	et	3	main
tegurid	doc_640286507874_item	2780508	et	3	main
ja	doc_640286507874_item	2780509	et	3	main
arvates	doc_640286507874_item	2780523	et	4	main
inimeste	doc_640286507874_item	2780538	et	3	main
süüdlane	doc_640286507874_item	2780552	et	3	main
saatuse	doc_640286507874_item	2780561	et	3	main
pärast	doc_640286507874_item	2780562	et	4	main
inimeste	doc_640286507874_item	2780563	et	3	main
kartuste	doc_640286507874_item	2780564	et	3	main
ja	doc_640286507874_item	2780565	et	3	main
agressiivsuse	doc_640286507874_item	2780566	et	4	main
ohvriks	doc_640286507874_item	2780567	et	3	main
minu	doc_640286507874_item	2780568	et	3	main
arvates	doc_640286507874_item	2780569	et	4	main
see	doc_640286507874_item	2780570	et	3	main
näitab	doc_640286507874_item	2780571	et	3	main
inimeste	doc_640286507874_item	2780572	et	3	main
teadmatust	doc_640286507874_item	2780573	et	4	main
ja	doc_640286507874_item	2780574	et	3	main
nõrgust	doc_640286507874_item	2780575	et	3	main
nad	doc_640286507874_item	2780576	et	3	main
ei	doc_640286507874_item	2780577	et	4	main
saa	doc_640286507874_item	2780578	et	4	main
ammu	doc_640286507874_item	2780579	et	4	main
mängufilm	doc_640286507874_item	2780525	et	3	main
on	doc_640286507874_item	2780527	et	4	main
ühiskonnakriitika	doc_640286507874_item	2780529	et	4	main
see	doc_640286507874_item	2780530	et	3	main
peegeldab	doc_640286507874_item	2780531	et	3	main
inimkonna	doc_640286507874_item	2780532	et	4	main
kartust	doc_640286507874_item	2780533	et	3	main
ebaloomulike	doc_640286507874_item	2780534	et	3	main
on	doc_640286507874_item	2780542	et	4	main
valivad	doc_640286507874_item	2780547	et	4	main
süüdlaseks	doc_640286507874_item	2780548	et	3	main
tiina	doc_640286507874_item	2780549	et	4	main
tegelikuses	doc_640286507874_item	2780554	et	4	main
süütu	doc_640286507874_item	2780556	et	4	main
sai	doc_640286507874_item	2780558	et	4	main
vaadata	doc_640286507874_item	2780604	et	4	main
võib-olla	doc_640286507874_item	2780610	et	3	main
iseenda	doc_640286507874_item	2780614	et	3	main
mõtleb	doc_640286507874_item	2780616	et	3	main
käitumise	doc_640286507874_item	2780618	et	4	main
üle	doc_640286507874_item	2780619	et	3	main
minna	doc_640286507874_item	2780583	et	3	main
isegi	doc_640286507874_item	2780585	et	4	main
selle	doc_640286507874_item	2780589	et	4	main
võita	doc_640286507874_item	2780591	et	4	main
et	doc_640286507874_item	2780593	et	3	main
see	doc_640286507874_item	2780594	et	3	main
küljest	doc_640286507874_item	2780608	et	4	main
keegi	doc_640286507874_item	2780611	et	4	main
ka	doc_640286507874_item	2780613	et	3	main
1	doc_640286507876_item	2780777	et	2	main
ev	doc_640286507876_item	2780779	et	4	main
kui	doc_640286507876_item	2780781	et	3	main
kultuuri	doc_640286507876_item	2780797	et	4	main
enam	doc_640286507876_item	2780815	et	4	main
pärast	doc_640286507876_item	2780821	et	4	main
olid	doc_640286507876_item	2780823	et	4	main
sõja	doc_640286507876_item	2780826	et	3	main
ja	doc_640286507876_item	2780828	et	3	main
üle	doc_640286507876_item	2780830	et	3	main
sest	doc_640286507876_item	2780831	et	4	main
inimesed	doc_640286507876_item	2780832	et	3	main
olid	doc_640286507876_item	2780841	et	4	main
õnnelikud	doc_640286507876_item	2780842	et	3	main
ensv	doc_640286507876_item	2780847	et	4	main
taastamist	doc_640286507876_item	2780867	et	4	main
nt	doc_640286507876_item	2780868	et	4	main
kogemustega	doc_640286507876_item	2780875	et	3	main
hoidsid	doc_640286507876_item	2780882	et	4	main
sai	doc_640286507876_item	2780920	et	4	main
1947	doc_640286507876_item	2780929	et	2	main
iga	doc_640286507876_item	2780937	et	4	main
hakkasid	doc_640286507876_item	2780946	et	4	main
tegutsema	doc_640286507876_item	2780947	et	3	main
ka	doc_640286507876_item	2780948	et	3	main
teised	doc_640286507876_item	2780949	et	4	main
teatrid	doc_640286507876_item	2780950	et	3	main
huvi	doc_640286507876_item	2780955	et	4	main
oma	doc_640286507876_item	2780966	et	4	main
arenemist	doc_640286507876_item	2780971	et	4	main
nõudmised	doc_640286507876_item	2780976	et	4	main
rahvas	doc_640286507876_item	2780984	et	4	main
polnud	doc_640286507876_item	2780985	et	3	main
suur	doc_640286507876_item	2780986	et	3	main
see	doc_640286507876_item	2780988	et	3	main
suureks	doc_640286507876_item	2780990	et	4	main
vaimult	doc_640286507876_item	2780991	et	4	main
ja	doc_640286507876_item	2780992	et	3	main
arendas	doc_640286507876_item	2780993	et	3	main
sotsialistlik	doc_640286507876_item	2781001	et	3	main
kontrolltöö	doc_640286507877_item	2781055	et	4	main
ja	doc_640286507877_item	2781060	et	3	main
kultuurielu	doc_640286507877_item	2781063	et	4	main
sotsialistlik	doc_640286507877_item	2781065	et	3	main
realism	doc_640286507877_item	2781066	et	3	main
kui	doc_640286507877_item	2781067	et	3	main
kirjandusvool	doc_640286507877_item	2781068	et	4	main
24	doc_640286507877_item	2781069	et	2	main
veeb	doc_640286507877_item	2781070	et	3	main
1918	doc_640286507877_item	2781071	et	2	main
28	doc_640286507877_item	2781072	et	2	main
sep	doc_640286507877_item	2781073	et	4	main
1939	doc_640286507877_item	2781074	et	2	main
2	doc_640286507877_item	2781078	et	2	main
1920	doc_640286507877_item	2781080	et	2	main
muutused	doc_640286507877_item	2781088	et	4	main
maa	doc_640286507877_item	2781089	et	4	main
oli	doc_640286507877_item	2781095	et	3	main
tegutsemisele	doc_640286507874_item	2780606	et	4	main
ja	doc_640286507876_item	2780768	et	3	main
kirjandusvool	doc_640286507876_item	2780776	et	4	main
kiiremini	doc_640286507876_item	2780788	et	4	main
arenema	doc_640286507876_item	2780789	et	3	main
olid	doc_640286507876_item	2780793	et	4	main
ja	doc_640286507876_item	2780811	et	3	main
riik	doc_640286507876_item	2780812	et	3	main
ensv	doc_640286507876_item	2780818	et	4	main
sõja	doc_640286507876_item	2780820	et	3	main
olid	doc_640286507876_item	2780833	et	4	main
saada	doc_640286507876_item	2780843	et	4	main
võimalust	doc_640286507876_item	2780844	et	3	main
end	doc_640286507876_item	2780845	et	4	main
ajal	doc_640286507876_item	2780855	et	4	main
teaduse	doc_640286507876_item	2780866	et	3	main
ensv	doc_640286507876_item	2780869	et	4	main
ajal	doc_640286507876_item	2780870	et	4	main
koolides	doc_640286507876_item	2780871	et	3	main
aja	doc_640286507876_item	2780877	et	4	main
õppetöö	doc_640286507876_item	2780883	et	4	main
traditsioon	doc_640286507876_item	2780918	et	3	main
populaarseks	doc_640286507876_item	2780919	et	4	main
rahva	doc_640286507876_item	2780922	et	3	main
tulemuseks	doc_640286507876_item	2780924	et	3	main
ajal	doc_640286507876_item	2780926	et	4	main
sai	doc_640286507876_item	2780927	et	4	main
peeti	doc_640286507876_item	2780936	et	4	main
taasavamine	doc_640286507876_item	2780945	et	4	main
vastu	doc_640286507876_item	2780952	et	3	main
rahvase	doc_640286507876_item	2780956	et	4	main
tööd	doc_640286507876_item	2780967	et	4	main
võimu	doc_640286507876_item	2780974	et	4	main
ideoloogiline	doc_640286507876_item	2780978	et	4	main
arvult	doc_640286507876_item	2780987	et	3	main
võimalik	doc_640286507876_item	2780999	et	3	main
kirjanikud	doc_640286507876_item	2781024	et	3	main
keelatud	doc_640286507876_item	2781031	et	4	main
range	doc_640286507876_item	2781032	et	4	main
tsensuur	doc_640286507876_item	2781033	et	3	main
oli	doc_640286507876_item	2781034	et	3	main
kõikjal	doc_640286507876_item	2781035	et	3	main
romantilised	doc_640286507876_item	2781036	et	3	main
lood	doc_640286507876_item	2781037	et	4	main
polnud	doc_640286507876_item	2781038	et	3	main
väga	doc_640286507876_item	2781039	et	3	main
populaarsed	doc_640286507876_item	2781040	et	3	main
tol	doc_640286507876_item	2781041	et	3	main
mis	doc_640286507876_item	2781050	et	4	main
võrrelge	doc_640286507877_item	2781057	et	3	main
kultuurielu	doc_640286507876_item	2780771	et	4	main
kui	doc_640286507876_item	2780775	et	3	main
nii	doc_640286507876_item	2780778	et	3	main
ajal	doc_640286507876_item	2780780	et	4	main
ensv	doc_640286507876_item	2780783	et	4	main
pärastsõjajärgsel	doc_640286507876_item	2780784	et	3	main
ajal	doc_640286507876_item	2780785	et	4	main
kultuur	doc_640286507876_item	2780786	et	3	main
hakkas	doc_640286507876_item	2780787	et	3	main
selleks	doc_640286507876_item	2780792	et	4	main
arenemise	doc_640286507876_item	2780798	et	4	main
põhjuseks	doc_640286507876_item	2780799	et	3	main
vabalt	doc_640286507876_item	2780810	et	4	main
ei	doc_640286507876_item	2780813	et	4	main
esitanud	doc_640286507876_item	2780814	et	4	main
nõudmisi	doc_640286507876_item	2780817	et	4	main
elanud	doc_640286507876_item	2780834	et	4	main
sõja	doc_640286507876_item	2780835	et	3	main
jätkus	doc_640286507876_item	2780849	et	4	main
arenemine	doc_640286507876_item	2780851	et	4	main
jätkasid	doc_640286507876_item	2780872	et	4	main
vana	doc_640286507876_item	2780878	et	4	main
kaadri	doc_640286507876_item	2780879	et	3	main
samuti	doc_640286507876_item	2780930	et	3	main
viie	doc_640286507876_item	2780938	et	3	main
aasta	doc_640286507876_item	2780939	et	4	main
laulupidu	doc_640286507876_item	2780941	et	4	main
oli	doc_640286507876_item	2780953	et	3	main
ev	doc_640286507876_item	2780959	et	4	main
aja	doc_640286507876_item	2780960	et	4	main
teadlased	doc_640286507876_item	2780961	et	3	main
haritlased	doc_640286507876_item	2780962	et	3	main
ja	doc_640286507876_item	2780963	et	3	main
kirjanikud	doc_640286507876_item	2780964	et	3	main
jätkasid	doc_640286507876_item	2780965	et	4	main
loomuliku	doc_640286507876_item	2780970	et	3	main
katkestasid	doc_640286507876_item	2780972	et	4	main
eesti	doc_640286507876_item	2780983	et	4	main
oma	doc_640286507876_item	2780994	et	4	main
millest	doc_640286507876_item	2781022	et	3	main
tahtsid	doc_640286507876_item	2781023	et	4	main
kes	doc_640286507876_item	2781025	et	4	main
kritiseerisid	doc_640286507876_item	2781026	et	4	main
riigikorda	doc_640286507876_item	2781027	et	4	main
ja	doc_640286507876_item	2781028	et	3	main
seotud	doc_640286507876_item	2781048	et	4	main
poliitikaga	doc_640286507876_item	2781049	et	3	main
elu	doc_640286507876_item	2781054	et	4	main
ensv	doc_640286507877_item	2781061	et	4	main
2	doc_640286507877_item	2781064	et	2	main
ev	doc_640286507877_item	2781077	et	4	main
olid	doc_640286507877_item	2781085	et	4	main
tehtud	doc_640286507877_item	2781086	et	4	main
57	doc_640286507877_item	2781092	et	2	main
antud	doc_640286507877_item	2781096	et	4	main
mis	doc_640286507877_item	2781104	et	4	main
toetust	doc_640286507877_item	2781106	et	4	main
erakapitalist	doc_640286507877_item	2781107	et	4	main
eestis	doc_640286507877_item	2781108	et	3	main
toodeti	doc_640286507877_item	2781109	et	3	main
paberit	doc_640286507877_item	2781110	et	3	main
harimismasinaid	doc_640286507877_item	2781132	et	3	main
muutus	doc_640286507877_item	2781137	et	4	main
75000	doc_640286507877_item	2781140	et	2	main
tuhandeni	doc_640286507877_item	2781142	et	3	main
balanseeritud	doc_640286507877_item	2781152	et	4	main
põllumajandus	doc_640286507877_item	2781161	et	3	main
rõhutanud	doc_640286507877_item	2781170	et	4	main
põllumajandust	doc_640286507877_item	2781171	et	3	main
rasketööstus	doc_640286507877_item	2781172	et	3	main
oli	doc_640286507877_item	2781173	et	3	main
vilets	doc_640286507877_item	2781174	et	3	main
vähem	doc_640286507877_item	2781181	et	4	main
euroopat	doc_640286507877_item	2781183	et	3	main
kontrolltöö	doc_640286507876_item	2780763	et	4	main
1	doc_640286507876_item	2780764	et	2	main
võrrelge	doc_640286507876_item	2780765	et	3	main
ev	doc_640286507876_item	2780766	et	4	main
aegset	doc_640286507876_item	2780767	et	3	main
ensv	doc_640286507876_item	2780769	et	4	main
pärastsõjajärgset	doc_640286507876_item	2780770	et	3	main
2	doc_640286507876_item	2780772	et	2	main
sotsialistlik	doc_640286507876_item	2780773	et	3	main
ka	doc_640286507876_item	2780782	et	3	main
põhjused	doc_640286507876_item	2780791	et	3	main
erinevad	doc_640286507876_item	2780794	et	4	main
ev	doc_640286507876_item	2780795	et	4	main
aegse	doc_640286507876_item	2780796	et	3	main
sai	doc_640286507876_item	2780800	et	4	main
kõigepealt	doc_640286507876_item	2780801	et	3	main
vene	doc_640286507876_item	2780802	et	4	main
ja	doc_640286507876_item	2780803	et	3	main
saksa	doc_640286507876_item	2780804	et	4	main
mõjust	doc_640286507876_item	2780805	et	3	main
ideoloogilisi	doc_640286507876_item	2780816	et	4	main
ajal	doc_640286507876_item	2780819	et	4	main
inimesed	doc_640286507876_item	2780822	et	3	main
kõigepealt	doc_640286507876_item	2780825	et	3	main
ajal	doc_640286507876_item	2780836	et	4	main
väljendada	doc_640286507876_item	2780846	et	3	main
kultuurielu	doc_640286507876_item	2780850	et	4	main
mis	doc_640286507876_item	2780852	et	4	main
algas	doc_640286507876_item	2780853	et	3	main
ev	doc_640286507876_item	2780854	et	4	main
rahvakultuuri	doc_640286507876_item	2780863	et	4	main
hariduse	doc_640286507876_item	2780864	et	3	main
oma	doc_640286507876_item	2780873	et	4	main
tööd	doc_640286507876_item	2780874	et	4	main
ev	doc_640286507876_item	2780876	et	4	main
tasemel	doc_640286507876_item	2780885	et	3	main
kuid	doc_640286507876_item	2780886	et	4	main
probleemid	doc_640286507876_item	2780887	et	3	main
olid	doc_640286507876_item	2780888	et	4	main
erinevad	doc_640286507876_item	2780889	et	4	main
nõukogude	doc_640286507876_item	2780890	et	3	main
võim	doc_640286507876_item	2780891	et	3	main
avaldas	doc_640286507876_item	2780892	et	3	main
oma	doc_640286507876_item	2780893	et	4	main
mõju	doc_640286507876_item	2780894	et	4	main
ja	doc_640286507876_item	2780895	et	3	main
ensv	doc_640286507876_item	2780896	et	4	main
ajal	doc_640286507876_item	2780897	et	4	main
probleemiks	doc_640286507876_item	2780898	et	4	main
koolides	doc_640286507876_item	2780899	et	3	main
sai	doc_640286507876_item	2780900	et	4	main
klassivõitlus	doc_640286507876_item	2780901	et	3	main
sõja	doc_640286507876_item	2780902	et	3	main
pärast	doc_640286507876_item	2780903	et	4	main
taasavasid	doc_640286507876_item	2780904	et	4	main
rahvamajad	doc_640286507876_item	2780905	et	3	main
raamatukogud	doc_640286507876_item	2780906	et	3	main
mis	doc_640286507876_item	2780907	et	4	main
töötasid	doc_640286507876_item	2780908	et	4	main
juba	doc_640286507876_item	2780909	et	3	main
ev	doc_640286507876_item	2780910	et	4	main
ajal	doc_640286507876_item	2780911	et	4	main
jätkas	doc_640286507876_item	2780912	et	3	main
pilli-	doc_640286507876_item	2780913	et	4	main
ja	doc_640286507876_item	2780914	et	3	main
näitemängu	doc_640286507876_item	2780915	et	4	main
ning	doc_640286507876_item	2780916	et	3	main
laulukooride	doc_640286507876_item	2780917	et	3	main
see	doc_640286507876_item	2780861	et	3	main
tähendas	doc_640286507876_item	2780862	et	3	main
ja	doc_640286507876_item	2780865	et	3	main
õpetajad	doc_640286507876_item	2780880	et	4	main
eks	doc_640286507876_item	2780881	et	3	main
kõrgel	doc_640286507876_item	2780884	et	4	main
rahvatants	doc_640286507876_item	2780921	et	3	main
entusiasmi	doc_640286507876_item	2780923	et	4	main
ensv	doc_640286507876_item	2780925	et	4	main
1923	doc_640286507876_item	2780934	et	2	main
aastast	doc_640286507876_item	2780935	et	4	main
kultuuri	doc_640286507876_item	2780969	et	4	main
ideoloogilised	doc_640286507876_item	2780975	et	4	main
vaatamata	doc_640286507876_item	2780980	et	4	main
sellele	doc_640286507876_item	2780981	et	4	main
et	doc_640286507876_item	2780982	et	3	main
kultuuri	doc_640286507876_item	2780995	et	4	main
oli	doc_640286507876_item	2780997	et	3	main
2	doc_640286507876_item	2781000	et	2	main
kirjutada	doc_640286507876_item	2781021	et	3	main
olid	doc_640286507876_item	2781030	et	4	main
puutus	doc_640286507876_item	2781051	et	4	main
tolleaegse	doc_640286507876_item	2781052	et	3	main
inimese	doc_640286507876_item	2781053	et	4	main
ev	doc_640286507877_item	2781058	et	4	main
pärastsõjajärgset	doc_640286507877_item	2781062	et	3	main
veeb	doc_640286507877_item	2781079	et	3	main
rahu	doc_640286507877_item	2781082	et	4	main
olulised	doc_640286507877_item	2781087	et	4	main
käes	doc_640286507877_item	2781094	et	4	main
suurimad	doc_640286507877_item	2781098	et	4	main
keemilisi	doc_640286507877_item	2781112	et	4	main
beekoni	doc_640286507877_item	2781122	et	4	main
ka	doc_640286507877_item	2781124	et	3	main
teri	doc_640286507877_item	2781125	et	3	main
omal	doc_640286507877_item	2781128	et	3	main
pärast	doc_640286507877_item	2781134	et	4	main
rohkem	doc_640286507877_item	2781151	et	4	main
rigatehas	doc_640286507877_item	2781159	et	4	main
tööstus	doc_640286507877_item	2781160	et	3	main
vaevalt	doc_640286507877_item	2781167	et	4	main
oli	doc_640286507877_item	2781169	et	3	main
1929	doc_640286507877_item	2781175	et	2	main
a	doc_640286507877_item	2781176	et	4	main
kriis	doc_640286507877_item	2781177	et	3	main
mõjutas	doc_640286507877_item	2781178	et	3	main
oli	doc_640286507877_item	2781185	et	3	main
xviii-xix	doc_640286507877_item	2781221	et	4	main
pidi	doc_640286507877_item	2781228	et	4	main
majanduspoliitikat	doc_640286507877_item	2781230	et	3	main
toote	doc_640286507877_item	2781233	et	4	main
kvalitee	doc_640286507877_item	2781234	et	4	main
palju	doc_640286507877_item	2781238	et	4	main
kõige	doc_640286507877_item	2781252	et	4	main
oli	doc_640286507877_item	2781255	et	3	main
tõde	doc_640286507877_item	2781257	et	4	main
mis	doc_640286507877_item	2781260	et	4	main
arenemist	doc_640286507877_item	2781267	et	4	main
oma	doc_640286507877_item	2781279	et	4	main
või	doc_640286507877_item	2781317	et	4	main
baltiühing	doc_640286507877_item	2781318	et	3	main
läti	doc_640286507877_item	2781319	et	4	main
leedu	doc_640286507877_item	2781320	et	4	main
üldlaulupidu	doc_640286507876_item	2780928	et	4	main
ev	doc_640286507876_item	2780931	et	4	main
ajal	doc_640286507876_item	2780932	et	4	main
alates	doc_640286507876_item	2780933	et	3	main
tagant	doc_640286507876_item	2780940	et	3	main
1947	doc_640286507876_item	2780942	et	2	main
teatri	doc_640286507876_item	2780943	et	3	main
estonia	doc_640286507876_item	2780944	et	4	main
nende	doc_640286507876_item	2780951	et	4	main
suur	doc_640286507876_item	2780954	et	3	main
seas	doc_640286507876_item	2780957	et	4	main
paljud	doc_640286507876_item	2780958	et	3	main
eesti	doc_640286507876_item	2780968	et	4	main
nõukogude	doc_640286507876_item	2780973	et	3	main
sõda	doc_640286507876_item	2780977	et	4	main
terror	doc_640286507876_item	2780979	et	3	main
sai	doc_640286507876_item	2780989	et	4	main
nagu	doc_640286507876_item	2780996	et	3	main
see	doc_640286507876_item	2780998	et	3	main
riigikord	doc_640286507876_item	2781002	et	3	main
mõjus	doc_640286507876_item	2781003	et	4	main
tunduvalt	doc_640286507876_item	2781004	et	4	main
ka	doc_640286507876_item	2781005	et	3	main
see	doc_640286507876_item	2781007	et	3	main
kunsti	doc_640286507876_item	2781006	et	4	main
ilmus	doc_640286507876_item	2781008	et	4	main
ka	doc_640286507876_item	2781009	et	3	main
kirjanduses	doc_640286507876_item	2781010	et	3	main
paljud	doc_640286507876_item	2781011	et	3	main
poliitilised	doc_640286507876_item	2781012	et	3	main
sündmused	doc_640286507876_item	2781013	et	3	main
peegeldasid	doc_640286507876_item	2781014	et	4	main
ka	doc_640286507876_item	2781015	et	3	main
kirjanduses	doc_640286507876_item	2781016	et	3	main
tolleaegsed	doc_640286507876_item	2781017	et	3	main
kirjanikud	doc_640286507876_item	2781018	et	3	main
ei	doc_640286507876_item	2781019	et	4	main
saanud	doc_640286507876_item	2781020	et	4	main
võimu	doc_640286507876_item	2781029	et	4	main
ajal	doc_640286507876_item	2781042	et	4	main
populaarne	doc_640286507876_item	2781043	et	3	main
oli	doc_640286507876_item	2781044	et	3	main
kõik	doc_640286507876_item	2781045	et	4	main
mis	doc_640286507876_item	2781046	et	4	main
oli	doc_640286507876_item	2781047	et	3	main
1	doc_640286507877_item	2781056	et	2	main
aegset	doc_640286507877_item	2781059	et	3	main
funktsioneeris	doc_640286507877_item	2781076	et	3	main
tartu	doc_640286507877_item	2781081	et	4	main
majandus	doc_640286507877_item	2781083	et	4	main
majanduses	doc_640286507877_item	2781084	et	4	main
väiksemad	doc_640286507877_item	2781103	et	4	main
tekstiili	doc_640286507877_item	2781111	et	4	main
saematerialid	doc_640286507877_item	2781114	et	4	main
põllumajanduses	doc_640286507877_item	2781118	et	3	main
a	doc_640286507877_item	2781075	et	4	main
mis	doc_640286507877_item	2781090	et	4	main
oli	doc_640286507877_item	2781091	et	3	main
mõisnikute	doc_640286507877_item	2781093	et	4	main
pandi	doc_640286507877_item	2781100	et	4	main
kinni	doc_640286507877_item	2781101	et	3	main
tekkisid	doc_640286507877_item	2781102	et	4	main
ja	doc_640286507877_item	2781121	et	3	main
samas	doc_640286507877_item	2781123	et	4	main
täideti	doc_640286507877_item	2781127	et	3	main
keemiatooteid	doc_640286507877_item	2781133	et	4	main
eestis	doc_640286507877_item	2781136	et	3	main
talude	doc_640286507877_item	2781138	et	3	main
12	doc_640286507877_item	2781141	et	2	main
1920-30	doc_640286507877_item	2781143	et	2	main
kui	doc_640286507877_item	2781153	et	3	main
teistes	doc_640286507877_item	2781154	et	4	main
aga	doc_640286507877_item	2781162	et	3	main
riigi	doc_640286507877_item	2781165	et	3	main
eestit	doc_640286507877_item	2781179	et	3	main
kui	doc_640286507877_item	2781182	et	3	main
talupoegadele	doc_640286507877_item	2781097	et	3	main
vabrikud	doc_640286507877_item	2781099	et	3	main
leidsid	doc_640286507877_item	2781105	et	4	main
tooteid	doc_640286507877_item	2781113	et	4	main
tekstiili	doc_640286507877_item	2781115	et	4	main
ja	doc_640286507877_item	2781116	et	3	main
masinaid	doc_640286507877_item	2781117	et	3	main
toodeti	doc_640286507877_item	2781119	et	3	main
võid	doc_640286507877_item	2781120	et	4	main
eestisse	doc_640286507877_item	2781131	et	4	main
kui	doc_640286507877_item	2781144	et	3	main
teiste	doc_640286507877_item	2781146	et	4	main
baltiriikidega	doc_640286507877_item	2781147	et	3	main
eestis	doc_640286507877_item	2781148	et	3	main
oli	doc_640286507877_item	2781149	et	3	main
arenemine	doc_640286507877_item	2781150	et	4	main
jõudis	doc_640286507877_item	2781163	et	3	main
tarbeid	doc_640286507877_item	2781166	et	3	main
leedu	doc_640286507877_item	2781168	et	4	main
kõrgem	doc_640286507877_item	2781189	et	4	main
piimatooteid	doc_640286507877_item	2781224	et	4	main
veena	doc_640286507877_item	2781225	et	4	main
praegu	doc_640286507877_item	2781226	et	3	main
kultuuriruumis	doc_640286507877_item	2781235	et	3	main
kirjeldas	doc_640286507877_item	2781261	et	3	main
ja	doc_640286507877_item	2781266	et	3	main
ja	doc_640286507877_item	2781270	et	3	main
lähenemine	doc_640286507877_item	2781330	et	4	main
ensv-ga	doc_640286507877_item	2781331	et	3	main
ja	doc_640286507877_item	2781339	et	3	main
eesti	doc_640286507877_item	2781340	et	4	main
kokkuleppega	doc_640286507877_item	2781341	et	3	main
vabadus	doc_640286507877_item	2781348	et	4	main
loodud	doc_640286507877_item	2781356	et	4	main
aja	doc_640286507877_item	2781373	et	4	main
1939	doc_640286507877_item	2781377	et	2	main
aug	doc_640286507877_item	2781380	et	4	main
ensv	doc_640286507877_item	2781382	et	4	main
1940	doc_640286507877_item	2781387	et	2	main
ev-inkorporeeritud	doc_640286507877_item	2781388	et	4	main
nõukogude	doc_640286507877_item	2781389	et	3	main
jaotuses	doc_640286507877_item	2781394	et	4	main
oblastid	doc_640286507877_item	2781396	et	3	main
1941	doc_640286507877_item	2781399	et	2	main
keelatud	doc_640286507877_item	2781414	et	4	main
kõik	doc_640286507877_item	2781415	et	4	main
kokkutulekud	doc_640286507877_item	2781416	et	3	main
kp-kokkutulekud	doc_640286507877_item	2781420	et	3	main
sotsiaalpropaganda	doc_640286507877_item	2781430	et	4	main
kirjanduses	doc_640286507877_item	2781431	et	3	main
kunstis	doc_640286507877_item	2781432	et	3	main
kultuurimajad	doc_640286507877_item	2781433	et	4	main
suletakse	doc_640286507877_item	2781434	et	4	main
tööstus	doc_640286507877_item	2781441	et	3	main
nõukogude	doc_640286507877_item	2781444	et	3	main
tarbeid	doc_640286507877_item	2781446	et	3	main
tehas	doc_640286507877_item	2781451	et	3	main
elektrijaam	doc_640286507877_item	2781453	et	3	main
sillamäe	doc_640286507877_item	2781456	et	3	main
linn	doc_640286507877_item	2781458	et	3	main
on	doc_640286507877_item	2781465	et	4	main
narvas	doc_640286507877_item	2781476	et	4	main
negatiivne	doc_640286507877_item	2781483	et	3	main
põllumajanduse	doc_640286507877_item	2781485	et	3	main
tarbeid	doc_640286507877_item	2781126	et	3	main
jõul	doc_640286507877_item	2781129	et	4	main
inporteeriti	doc_640286507877_item	2781130	et	4	main
maareformi	doc_640286507877_item	2781135	et	4	main
arv	doc_640286507877_item	2781139	et	3	main
võrrelda	doc_640286507877_item	2781145	et	4	main
lätis	doc_640286507877_item	2781155	et	4	main
oli	doc_640286507877_item	2781156	et	3	main
kõvasti	doc_640286507877_item	2781157	et	3	main
arenenud	doc_640286507877_item	2781158	et	4	main
täita	doc_640286507877_item	2781164	et	4	main
aga	doc_640286507877_item	2781180	et	3	main
eestis	doc_640286507877_item	2781186	et	3	main
ajal	doc_640286507877_item	2781188	et	4	main
kui	doc_640286507877_item	2781190	et	3	main
euroopas	doc_640286507877_item	2781191	et	3	main
193436	doc_640286507877_item	2781192	et	2	main
eestis	doc_640286507877_item	2781193	et	3	main
märgata	doc_640286507877_item	2781195	et	4	main
kõva	doc_640286507877_item	2781196	et	4	main
on	doc_640286507877_item	2781194	et	4	main
tõusu	doc_640286507877_item	2781197	et	4	main
seletada	doc_640286507877_item	2781198	et	3	main
võib	doc_640286507877_item	2781199	et	3	main
sellega	doc_640286507877_item	2781200	et	3	main
et	doc_640286507877_item	2781201	et	3	main
majandus	doc_640286507877_item	2781202	et	4	main
euroopas	doc_640286507877_item	2781203	et	3	main
enam-vähem	doc_640286507877_item	2781204	et	3	main
stabiliseerus	doc_640286507877_item	2781205	et	3	main
nüüd	doc_640286507877_item	2781206	et	4	main
eesti	doc_640286507877_item	2781207	et	4	main
kaotas	doc_640286507877_item	2781208	et	3	main
venemaal	doc_640286507877_item	2781209	et	4	main
ja	doc_640286507877_item	2781211	et	3	main
pühendas	doc_640286507877_item	2781212	et	3	main
oma	doc_640286507877_item	2781213	et	4	main
tooteturg	doc_640286507877_item	2781210	et	3	main
tähelepanu	doc_640286507877_item	2781214	et	4	main
euroopale	doc_640286507877_item	2781215	et	3	main
tööstustõusu	doc_640286507877_item	2781216	et	4	main
seletab	doc_640286507877_item	2781217	et	3	main
turukaotamine	doc_640286507877_item	2781218	et	3	main
venemaale	doc_640286507877_item	2781219	et	4	main
eksporteeriti	doc_640286507877_item	2781220	et	4	main
eesti	doc_640286507877_item	2781227	et	4	main
oli	doc_640286507877_item	2781236	et	3	main
muudatusi	doc_640286507877_item	2781239	et	3	main
kultuurikapital	doc_640286507877_item	2781243	et	3	main
elutase	doc_640286507877_item	2781184	et	3	main
tol	doc_640286507877_item	2781187	et	3	main
teri	doc_640286507877_item	2781222	et	3	main
muutma	doc_640286507877_item	2781229	et	3	main
ka	doc_640286507877_item	2781237	et	3	main
oli	doc_640286507877_item	2781240	et	3	main
eesti	doc_640286507877_item	2781242	et	4	main
andis	doc_640286507877_item	2781245	et	3	main
preemiaid	doc_640286507877_item	2781247	et	3	main
väljapaistvatele	doc_640286507877_item	2781248	et	3	main
kultuuritegijatele	doc_640286507877_item	2781249	et	3	main
kirjanikud	doc_640286507877_item	2781250	et	3	main
kunstnikud	doc_640286507877_item	2781251	et	3	main
kirjandusnäide	doc_640286507877_item	2781254	et	3	main
inimeste	doc_640286507877_item	2781268	et	3	main
ajamõju	doc_640286507877_item	2781272	et	4	main
inimkäitumisele	doc_640286507877_item	2781273	et	3	main
tuntud	doc_640286507877_item	2781274	et	4	main
oli	doc_640286507877_item	2781275	et	3	main
ka	doc_640286507877_item	2781276	et	3	main
paul	doc_640286507877_item	2781277	et	4	main
keres	doc_640286507877_item	2781278	et	3	main
leedu	doc_640286507877_item	2781313	et	4	main
soome	doc_640286507877_item	2781314	et	3	main
ida	doc_640286507877_item	2781315	et	4	main
ühing	doc_640286507877_item	2781316	et	3	main
leedu	doc_640286507877_item	2781329	et	4	main
lõhkus	doc_640286507877_item	2781332	et	3	main
selle	doc_640286507877_item	2781333	et	4	main
idee	doc_640286507877_item	2781334	et	4	main
inimese	doc_640286507877_item	2781342	et	4	main
olid	doc_640286507877_item	2781349	et	4	main
alghariduse	doc_640286507877_item	2781357	et	3	main
oli	doc_640286507877_item	2781361	et	3	main
jaoks	doc_640286507877_item	2781374	et	4	main
1944	doc_640286507877_item	2781378	et	2	main
1946	doc_640286507877_item	2781391	et	2	main
muudatused	doc_640286507877_item	2781392	et	3	main
uued	doc_640286507877_item	2781395	et	3	main
küüditus	doc_640286507877_item	2781408	et	4	main
20000	doc_640286507877_item	2781409	et	2	main
inimest	doc_640286507877_item	2781410	et	3	main
legaalne	doc_640286507877_item	2781418	et	3	main
ja	doc_640286507877_item	2781424	et	3	main
ja	doc_640286507877_item	2781440	et	3	main
balteks	doc_640286507877_item	2781450	et	4	main
täidab	doc_640286507877_item	2781460	et	3	main
paldiski	doc_640286507877_item	2781464	et	4	main
suur	doc_640286507877_item	2781466	et	3	main
baas	doc_640286507877_item	2781468	et	3	main
toodi	doc_640286507877_item	2781471	et	4	main
tööjõudu	doc_640286507877_item	2781472	et	4	main
kollektiviseerimine	doc_640286507877_item	2781478	et	4	main
see	doc_640286507877_item	2781480	et	3	main
oli	doc_640286507877_item	2781482	et	3	main
olid	doc_640286507877_item	2781523	et	4	main
sõnavabadust	doc_640286507877_item	2781526	et	4	main
usk	doc_640286507877_item	2781528	et	3	main
luuterlik	doc_640286507877_item	2781529	et	4	main
k	doc_640286507877_item	2781530	et	4	main
õigeusu	doc_640286507877_item	2781531	et	3	main
k	doc_640286507877_item	2781532	et	4	main
religioon	doc_640286507877_item	2781533	et	3	main
oopium	doc_640286507877_item	2781534	et	3	main
rahvale	doc_640286507877_item	2781535	et	3	main
rahvus	doc_640286507877_item	2781536	et	3	main
ühine	doc_640286507877_item	2781541	et	4	main
kp	doc_640286507877_item	2781549	et	4	main
kandidaadi	doc_640286507877_item	2781555	et	3	main
oli	doc_640286507877_item	2781559	et	3	main
seisab	doc_640286507877_item	2781578	et	3	main
läbitut	doc_640286507877_item	2781594	et	4	main
tsensuur	doc_640286507877_item	2781598	et	3	main
teaduses	doc_640286507877_item	2781604	et	3	main
olid	doc_640286507877_item	2781605	et	4	main
vahetatud	doc_640286507877_item	2781606	et	4	main
mõned	doc_640286507877_item	2781607	et	3	main
faktid	doc_640286507877_item	2781608	et	3	main
trükkid	doc_640286507877_item	2781617	et	4	main
sotsialismideega	doc_640286507877_item	2781621	et	4	main
kas	doc_640286507877_item	2781623	et	3	main
liha	doc_640286507877_item	2781223	et	4	main
pöördudes	doc_640286507877_item	2781231	et	3	main
tööstusele	doc_640286507877_item	2781232	et	3	main
rajatud	doc_640286507877_item	2781241	et	4	main
mis	doc_640286507877_item	2781244	et	4	main
välja	doc_640286507877_item	2781246	et	4	main
eesti	doc_640286507877_item	2781262	et	4	main
idee	doc_640286507877_item	2781264	et	4	main
selle	doc_640286507877_item	2781271	et	4	main
mallemaailmas	doc_640286507877_item	2781281	et	4	main
olid	doc_640286507877_item	2781282	et	4	main
loodud	doc_640286507877_item	2781283	et	4	main
teatrid	doc_640286507877_item	2781284	et	3	main
tallinnas	doc_640286507877_item	2781285	et	4	main
tartus	doc_640286507877_item	2781286	et	3	main
ja	doc_640286507877_item	2781287	et	3	main
narvas	doc_640286507877_item	2781288	et	4	main
olid	doc_640286507877_item	2781289	et	4	main
levinud	doc_640286507877_item	2781290	et	4	main
igasugused	doc_640286507877_item	2781291	et	3	main
klubid	doc_640286507877_item	2781292	et	3	main
ja	doc_640286507877_item	2781293	et	3	main
ne	doc_640286507877_item	2781294	et	4	main
poliitikas	doc_640286507877_item	2781295	et	3	main
püüdis	doc_640286507877_item	2781297	et	3	main
saavutada	doc_640286507877_item	2781298	et	3	main
baltikumi	doc_640286507877_item	2781299	et	4	main
liitu	doc_640286507877_item	2781300	et	4	main
eesti	doc_640286507877_item	2781296	et	4	main
mis	doc_640286507877_item	2781301	et	4	main
võiks	doc_640286507877_item	2781302	et	4	main
garanteerida	doc_640286507877_item	2781303	et	3	main
rahu	doc_640286507877_item	2781304	et	4	main
aga	doc_640286507877_item	2781305	et	3	main
sellest	doc_640286507877_item	2781306	et	4	main
midagi	doc_640286507877_item	2781307	et	4	main
ei	doc_640286507877_item	2781308	et	4	main
tulnud	doc_640286507877_item	2781309	et	4	main
välja	doc_640286507877_item	2781310	et	4	main
poole	doc_640286507877_item	2781311	et	4	main
läti	doc_640286507877_item	2781312	et	4	main
kuulsam	doc_640286507877_item	2781253	et	4	main
tammsaare	doc_640286507877_item	2781256	et	3	main
ja	doc_640286507877_item	2781258	et	3	main
õigus	doc_640286507877_item	2781259	et	4	main
riigi	doc_640286507877_item	2781263	et	3	main
sündmust	doc_640286507877_item	2781265	et	3	main
eludes	doc_640286507877_item	2781269	et	3	main
saavutustega	doc_640286507877_item	2781280	et	4	main
eesti	doc_640286507877_item	2781321	et	4	main
huvi	doc_640286507877_item	2781323	et	4	main
tundus	doc_640286507877_item	2781324	et	3	main
rootsi	doc_640286507877_item	2781325	et	4	main
ühingu	doc_640286507877_item	2781326	et	3	main
vastu	doc_640286507877_item	2781327	et	3	main
aga	doc_640286507877_item	2781328	et	3	main
lõppes	doc_640286507877_item	2781335	et	4	main
see	doc_640286507877_item	2781336	et	3	main
õiguse	doc_640286507877_item	2781343	et	4	main
suhtes	doc_640286507877_item	2781344	et	4	main
eestis	doc_640286507877_item	2781345	et	3	main
oli	doc_640286507877_item	2781346	et	3	main
natsionaalvähemused	doc_640286507877_item	2781351	et	4	main
venelased	doc_640286507877_item	2781352	et	3	main
17	doc_640286507877_item	2781353	et	2	main
sakslased	doc_640286507877_item	2781354	et	3	main
emakeeles	doc_640286507877_item	2781359	et	4	main
ne	doc_640286507877_item	2781365	et	4	main
põhiseadus	doc_640286507877_item	2781366	et	4	main
eestis	doc_640286507877_item	2781367	et	3	main
1920	doc_640286507877_item	2781368	et	2	main
oli	doc_640286507877_item	2781369	et	3	main
väga	doc_640286507877_item	2781370	et	3	main
demokraatlik	doc_640286507877_item	2781371	et	3	main
28	doc_640286507877_item	2781375	et	2	main
liitu	doc_640286507877_item	2781390	et	4	main
elu	doc_640286507877_item	2781412	et	4	main
sõnavabadus	doc_640286507877_item	2781413	et	4	main
ainult	doc_640286507877_item	2781419	et	4	main
range	doc_640286507877_item	2781421	et	4	main
ajakirjade	doc_640286507877_item	2781423	et	3	main
planeeritud	doc_640286507877_item	2781438	et	4	main
areng	doc_640286507877_item	2781439	et	3	main
elektrijaame	doc_640286507877_item	2781449	et	3	main
eesti	doc_640286507877_item	2781452	et	4	main
balti	doc_640286507877_item	2781454	et	3	main
sõjaväe	doc_640286507877_item	2781462	et	3	main
eestisse	doc_640286507877_item	2781469	et	4	main
1959-67	doc_640286507877_item	2781477	et	2	main
koondati	doc_640286507877_item	2781538	et	4	main
rahvas	doc_640286507877_item	2781543	et	4	main
falsititseeritud	doc_640286507877_item	2781551	et	4	main
99	doc_640286507877_item	2781552	et	2	main
poolt	doc_640286507877_item	2781556	et	4	main
trükitut	doc_640286507877_item	2781566	et	4	main
eesti	doc_640286507877_item	2781567	et	4	main
keele	doc_640286507877_item	2781568	et	4	main
kirjanduses	doc_640286507877_item	2781569	et	3	main
ilukirjanduses	doc_640286507877_item	2781570	et	3	main
oli	doc_640286507877_item	2781571	et	3	main
kõik	doc_640286507877_item	2781572	et	4	main
ideele	doc_640286507877_item	2781576	et	3	main
pärast	doc_640286507877_item	2781586	et	4	main
annab	doc_640286507877_item	2781589	et	3	main
alla	doc_640286507877_item	2781590	et	3	main
ei	doc_640286507877_item	2781599	et	4	main
geneetika	doc_640286507877_item	2781610	et	4	main
oli	doc_640286507877_item	2781611	et	3	main
neid	doc_640286507877_item	2781622	et	4	main
mõned	doc_640286507877_item	2781625	et	3	main
ajutis	doc_640286507877_item	2781322	et	4	main
läti	doc_640286507877_item	2781338	et	4	main
kõik	doc_640286507877_item	2781337	et	4	main
legaliseeritud	doc_640286507877_item	2781350	et	4	main
võimaluse	doc_640286507877_item	2781358	et	3	main
vaba	doc_640286507877_item	2781360	et	4	main
kirjanuds	doc_640286507877_item	2781362	et	4	main
usk	doc_640286507877_item	2781363	et	3	main
ja	doc_640286507877_item	2781364	et	3	main
sep	doc_640286507877_item	2781376	et	4	main
20	doc_640286507877_item	2781379	et	2	main
191	doc_640286507877_item	2781381	et	2	main
aeg	doc_640286507877_item	2781383	et	3	main
muudatusi	doc_640286507877_item	2781384	et	3	main
ensv	doc_640286507877_item	2781393	et	4	main
3	doc_640286507877_item	2781397	et	2	main
kultuuri	doc_640286507877_item	2781411	et	4	main
sulgemine	doc_640286507877_item	2781426	et	4	main
väljapaistvate	doc_640286507877_item	2781427	et	3	main
kultuuritegelaste	doc_640286507877_item	2781428	et	3	main
kultuurimõiste	doc_640286507877_item	2781435	et	4	main
muutub	doc_640286507877_item	2781436	et	3	main
ekonoomika	doc_640286507877_item	2781437	et	4	main
täidab	doc_640286507877_item	2781443	et	3	main
tehaseid	doc_640286507877_item	2781448	et	3	main
elektrijaam	doc_640286507877_item	2781455	et	3	main
kinnine	doc_640286507877_item	2781457	et	3	main
nl	doc_640286507877_item	2781461	et	4	main
tellimusi	doc_640286507877_item	2781463	et	3	main
nl	doc_640286507877_item	2781467	et	4	main
jõukalt	doc_640286507877_item	2781470	et	4	main
eestis	doc_640286507877_item	2781479	et	3	main
muidugi	doc_640286507877_item	2781481	et	4	main
vastutegu	doc_640286507877_item	2781520	et	4	main
õigused	doc_640286507877_item	2781522	et	4	main
vähemused	doc_640286507877_item	2781537	et	4	main
nõukogu	doc_640286507877_item	2781542	et	4	main
valimised	doc_640286507877_item	2781550	et	4	main
kirjandus	doc_640286507877_item	2781558	et	3	main
pühendatud	doc_640286507877_item	2781561	et	4	main
ainult	doc_640286507877_item	2781574	et	4	main
kapitalismi	doc_640286507877_item	2781579	et	4	main
muidugi	doc_640286507877_item	2781581	et	4	main
kõikides	doc_640286507877_item	2781595	et	4	main
nt	doc_640286507877_item	2781609	et	4	main
paljud	doc_640286507877_item	2781616	et	3	main
täislik	doc_640286507877_item	2781347	et	4	main
5	doc_640286507877_item	2781355	et	2	main
selle	doc_640286507877_item	2781372	et	4	main
oli	doc_640286507877_item	2781385	et	3	main
palju	doc_640286507877_item	2781386	et	4	main
tk	doc_640286507877_item	2781398	et	4	main
juuni	doc_640286507877_item	2781400	et	4	main
küüditus	doc_640286507877_item	2781401	et	4	main
10157	doc_640286507877_item	2781402	et	2	main
inimest	doc_640286507877_item	2781403	et	3	main
1949	doc_640286507877_item	2781404	et	2	main
a	doc_640286507877_item	2781405	et	4	main
25	doc_640286507877_item	2781406	et	2	main
märts	doc_640286507877_item	2781407	et	3	main
keelatud	doc_640286507877_item	2781417	et	4	main
tsensuur	doc_640286507877_item	2781422	et	3	main
ajalehtede	doc_640286507877_item	2781425	et	4	main
küüditamine	doc_640286507877_item	2781429	et	4	main
tööstus	doc_640286507877_item	2781442	et	3	main
liidu	doc_640286507877_item	2781445	et	3	main
ehitatakse	doc_640286507877_item	2781447	et	3	main
mis	doc_640286507877_item	2781459	et	4	main
8suurim	doc_640286507877_item	2781473	et	3	main
välisjõu	doc_640286507877_item	2781474	et	3	main
linn	doc_640286507877_item	2781475	et	3	main
joon	doc_640286507877_item	2781484	et	4	main
arenemises	doc_640286507877_item	2781486	et	4	main
inimesel	doc_640286507877_item	2781487	et	3	main
polnud	doc_640286507877_item	2781488	et	3	main
entusiasmi	doc_640286507877_item	2781489	et	4	main
raske	doc_640286507877_item	2781490	et	4	main
tööstus	doc_640286507877_item	2781491	et	3	main
eestis	doc_640286507877_item	2781492	et	3	main
olid	doc_640286507877_item	2781493	et	4	main
rajatud	doc_640286507877_item	2781494	et	4	main
tehased	doc_640286507877_item	2781495	et	3	main
mis	doc_640286507877_item	2781496	et	4	main
olid	doc_640286507877_item	2781497	et	4	main
pühendatud	doc_640286507877_item	2781498	et	4	main
masinaehitusele	doc_640286507877_item	2781499	et	3	main
moderniseeritud	doc_640286507877_item	2781500	et	4	main
volta	doc_640286507877_item	2781501	et	4	main
punane	doc_640286507877_item	2781502	et	4	main
peet	doc_640286507877_item	2781503	et	3	main
kaabel	doc_640286507877_item	2781504	et	4	main
masinaid	doc_640286507877_item	2781505	et	3	main
ekspordeeriti	doc_640286507877_item	2781506	et	4	main
nl	doc_640286507877_item	2781507	et	4	main
arenenud	doc_640286507877_item	2781508	et	4	main
oli	doc_640286507877_item	2781509	et	3	main
põlevkivi	doc_640286507877_item	2781510	et	4	main
tööstus	doc_640286507877_item	2781511	et	3	main
ja	doc_640286507877_item	2781512	et	3	main
sellega	doc_640286507877_item	2781513	et	3	main
seotud	doc_640286507877_item	2781514	et	4	main
keemitööstus	doc_640286507877_item	2781515	et	4	main
fosforiidi	doc_640286507877_item	2781516	et	4	main
kampaania	doc_640286507877_item	2781517	et	4	main
leidis	doc_640286507877_item	2781518	et	4	main
kõva	doc_640286507877_item	2781519	et	4	main
inimese	doc_640286507877_item	2781521	et	4	main
hävitud	doc_640286507877_item	2781525	et	4	main
polnud	doc_640286507877_item	2781527	et	3	main
nüüd	doc_640286507877_item	2781539	et	4	main
ainult	doc_640286507877_item	2781540	et	4	main
ilmunud	doc_640286507877_item	2781553	et	4	main
97hääletasid	doc_640286507877_item	2781554	et	4	main
terved	doc_640286507877_item	2781563	et	4	main
marksism-leninismist	doc_640286507877_item	2781565	et	4	main
pühendatud	doc_640286507877_item	2781573	et	4	main
sotsialism	doc_640286507877_item	2781577	et	3	main
vastu	doc_640286507877_item	2781580	et	3	main
raskustega	doc_640286507877_item	2781582	et	4	main
ja	doc_640286507877_item	2781583	et	3	main
mõne	doc_640286507877_item	2781584	et	3	main
mädanev	doc_640286507877_item	2781587	et	4	main
idee	doc_640286507877_item	2781592	et	4	main
on	doc_640286507877_item	2781593	et	4	main
range	doc_640286507877_item	2781597	et	4	main
läbi	doc_640286507877_item	2781601	et	4	main
teoseid	doc_640286507877_item	2781603	et	3	main
olid	doc_640286507877_item	2781614	et	4	main
hävitatud	doc_640286507877_item	2781615	et	4	main
mis	doc_640286507877_item	2781618	et	4	main
läksid	doc_640286507877_item	2781619	et	4	main
lahku	doc_640286507877_item	2781620	et	4	main
maksimaalselt	doc_640286507877_item	2781524	et	4	main
poliitiline	doc_640286507877_item	2781544	et	3	main
vaikus	doc_640286507877_item	2781545	et	3	main
ainult	doc_640286507877_item	2781546	et	4	main
üks	doc_640286507877_item	2781547	et	3	main
partei	doc_640286507877_item	2781548	et	4	main
2	doc_640286507877_item	2781557	et	2	main
täiuslikult	doc_640286507877_item	2781560	et	4	main
sotsiaalideoloogiale	doc_640286507877_item	2781562	et	3	main
traktaadid	doc_640286507877_item	2781564	et	3	main
ühele	doc_640286507877_item	2781575	et	3	main
aja	doc_640286507877_item	2781585	et	4	main
kapitalism	doc_640286507877_item	2781588	et	3	main
see	doc_640286507877_item	2781591	et	3	main
zanrites	doc_640286507877_item	2781596	et	4	main
lase	doc_640286507877_item	2781600	et	4	main
kirjanikude	doc_640286507877_item	2781602	et	3	main
pidurdatud	doc_640286507877_item	2781612	et	4	main
arengus	doc_640286507877_item	2781613	et	3	main
põletati	doc_640286507877_item	2781624	et	3	main
lõked	doc_640286507877_item	2781626	et	4	main
korrekteeriti	doc_640286507877_item	2781627	et	4	main
lõke	doc_643650824484_item	2781963	et	4	main
küla	doc_643650824484_item	2781966	et	4	main
ühe	doc_643650824484_item	2781968	et	4	main
mida	doc_643650824484_item	2781981	et	4	main
tühjad	doc_643650824484_item	2781988	et	3	main
tavaliselt	doc_643650824484_item	2781999	et	4	main
selleks	doc_643650824484_item	2782006	et	4	main
nad	doc_643650824484_item	2782007	et	3	main
küla	doc_643650824484_item	2782011	et	4	main
läbi	doc_643650824484_item	2782012	et	4	main
tavaliselt	doc_643650824484_item	2782023	et	4	main
kus	doc_643650824484_item	2782029	et	3	main
toimus	doc_643650824484_item	2782031	et	3	main
vastuvõtmine	doc_643650824484_item	2782033	et	3	main
põlema	doc_643650824484_item	2782040	et	4	main
arvati	doc_643650824484_item	2782047	et	4	main
mida	doc_643650824484_item	2782049	et	4	main
erksam	doc_643650824484_item	2782050	et	4	main
see	doc_643650824484_item	2782051	et	3	main
lõke	doc_643650824484_item	2782057	et	4	main
pühapäeva	doc_643650824484_item	2782061	et	4	main
paiku	doc_643650824484_item	2782064	et	4	main
seda	doc_643650824484_item	2782065	et	3	main
tavandit	doc_643650824484_item	2782066	et	3	main
teostati	doc_643650824484_item	2782067	et	3	main
kaldal	doc_643650824484_item	2782074	et	3	main
see	doc_643650824484_item	2782076	et	3	main
püha	doc_643650824484_item	2782078	et	4	main
pärast	doc_643650824484_item	2782080	et	4	main
lõke	doc_643650824484_item	2781961	et	4	main
terve	doc_643650824484_item	2781965	et	4	main
tegi	doc_643650824484_item	2781967	et	4	main
suure	doc_643650824484_item	2781969	et	3	main
lõke	doc_643650824484_item	2781970	et	4	main
kuhu	doc_643650824484_item	2781971	et	3	main
ei	doc_643650824484_item	2781983	et	4	main
kasutata	doc_643650824484_item	2781984	et	3	main
ratad	doc_643650824484_item	2781986	et	4	main
tünnid	doc_643650824484_item	2781989	et	3	main
laste	doc_643650824484_item	2781992	et	4	main
vihad	doc_643650824484_item	2781995	et	4	main
vihk	doc_643650824484_item	2781996	et	3	main
kogu	doc_643650824484_item	2781997	et	4	main
tihti	doc_643650824484_item	2782013	et	3	main
kinnitatud	doc_643650824484_item	2782017	et	4	main
latt	doc_643650824484_item	2782020	et	3	main
otsas	doc_643650824484_item	2782022	et	4	main
esialgu	doc_643650824484_item	2782030	et	3	main
vastlapäeva	doc_643650824484_item	2782032	et	4	main
lõke	doc_643650824484_item	2782034	et	4	main
peab	doc_643650824484_item	2782035	et	4	main
seda	doc_643650824484_item	2782042	et	3	main
hästi	doc_643650824484_item	2782045	et	3	main
süüdati	doc_643650824484_item	2782058	et	3	main
seitsme-kaheksa	doc_643650824484_item	2782063	et	4	main
hoovis	doc_643650824484_item	2782068	et	4	main
põllul	doc_643650824484_item	2782069	et	3	main
jõe	doc_643650824484_item	2782073	et	3	main
vastlapäeva	doc_643650824484_item	2781960	et	4	main
venelastel	doc_643650824484_item	2781964	et	4	main
vanu	doc_643650824484_item	2781979	et	4	main
asju	doc_643650824484_item	2781980	et	3	main
kolu	doc_643650824484_item	2781998	et	4	main
jooksul	doc_643650824484_item	2782005	et	4	main
keset	doc_643650824484_item	2782014	et	4	main
oli	doc_643650824484_item	2782016	et	3	main
pikk	doc_643650824484_item	2782018	et	4	main
ritv	doc_643650824484_item	2782019	et	3	main
rataga	doc_643650824484_item	2782021	et	4	main
kõrge	doc_643650824484_item	2782027	et	4	main
et	doc_643650824484_item	2782041	et	3	main
kaugelt	doc_643650824484_item	2782044	et	4	main
näha	doc_643650824484_item	2782046	et	3	main
rikkam	doc_643650824484_item	2782054	et	4	main
on	doc_643650824484_item	2782055	et	4	main
järve	doc_643650824484_item	2782070	et	4	main
jääl	doc_643650824484_item	2782071	et	3	main
ja	doc_643650824484_item	2782075	et	3	main
lõppu	doc_643650824484_item	2782079	et	4	main
kõik	doc_643650824484_item	2782084	et	4	main
võis	doc_643650824484_item	2782121	et	4	main
kujutatud	doc_643650824484_item	2782123	et	4	main
või	doc_643650824484_item	2782125	et	4	main
inimesena	doc_643650824484_item	2782132	et	3	main
kes	doc_643650824484_item	2782133	et	4	main
tegemisel	doc_643650824484_item	2782141	et	4	main
oli	doc_643650824484_item	2782142	et	3	main
karusnahaga	doc_643650824484_item	2782157	et	3	main
keha	doc_643650824484_item	2782162	et	4	main
jaoks	doc_643650824484_item	2782163	et	4	main
kui	doc_643650824484_item	2782164	et	3	main
ka	doc_643650824484_item	2782165	et	3	main
tingimata	doc_643650824484_item	2782170	et	4	main
muutes	doc_643650824484_item	2782175	et	4	main
paljudes	doc_643650824484_item	2782179	et	3	main
ka	doc_643650824484_item	2782182	et	3	main
hernehirmutisest	doc_643650824484_item	2782189	et	4	main
sellega	doc_643650824484_item	2782190	et	3	main
see	doc_643650824484_item	2782225	et	3	main
iga	doc_643650824484_item	2781972	et	4	main
perekond	doc_643650824484_item	2781973	et	3	main
pidi	doc_643650824484_item	2781974	et	4	main
jooksul	doc_643650824484_item	2781991	et	4	main
vanad	doc_643650824484_item	2781994	et	3	main
väikesed	doc_643650824484_item	2782001	et	4	main
lapsed	doc_643650824484_item	2782002	et	3	main
eelneva	doc_643650824484_item	2782003	et	4	main
nädala	doc_643650824484_item	2782004	et	3	main
kogu	doc_643650824484_item	2782010	et	4	main
lõket	doc_643650824484_item	2782015	et	4	main
lõke	doc_643650824484_item	2782024	et	4	main
valiti	doc_643650824484_item	2782026	et	3	main
ja	doc_643650824484_item	2782038	et	3	main
hästi	doc_643650824484_item	2782039	et	3	main
on	doc_643650824484_item	2782052	et	4	main
seda	doc_643650824484_item	2782053	et	3	main
viimasel	doc_643650824484_item	2782059	et	3	main
õhtul	doc_643650824484_item	2782062	et	3	main
või	doc_643650824484_item	2782072	et	4	main
läksid	doc_643650824484_item	2782085	et	4	main
venemaa	doc_643650824484_item	2782088	et	4	main
olla	doc_643650824484_item	2782122	et	3	main
heinast	doc_643650824484_item	2782124	et	4	main
mängis	doc_643650824484_item	2782134	et	3	main
kõige	doc_643650824484_item	2782137	et	4	main
rõivad	doc_643650824484_item	2782145	et	3	main
olema	doc_643650824484_item	2782147	et	4	main
vanad	doc_643650824484_item	2782148	et	3	main
kulunud	doc_643650824484_item	2782149	et	4	main
pahupidi	doc_643650824484_item	2782155	et	3	main
nii	doc_643650824484_item	2782160	et	3	main
riietus	doc_643650824484_item	2782168	et	4	main
tuli	doc_643650824484_item	2782169	et	4	main
hernrhirmutist	doc_643650824484_item	2782176	et	4	main
sümboliks	doc_643650824484_item	2782178	et	4	main
välimusega	doc_643650824484_item	2782194	et	3	main
joonistati	doc_643650824484_item	2782196	et	4	main
nina	doc_643650824484_item	2782199	et	4	main
riietati	doc_643650824484_item	2782200	et	3	main
erksatesse	doc_643650824484_item	2782201	et	3	main
pidulikkesse	doc_643650824484_item	2782202	et	3	main
kostüümidesse	doc_643650824484_item	2782203	et	3	main
pere	doc_643650824484_item	2782204	et	4	main
nuku	doc_643650824484_item	2782205	et	3	main
varustati	doc_643650824484_item	2782206	et	3	main
vastlapäeva	doc_643650824484_item	2781962	et	4	main
midagi	doc_643650824484_item	2781975	et	4	main
kütmiseks	doc_643650824484_item	2781976	et	4	main
tooma	doc_643650824484_item	2781977	et	3	main
toodi	doc_643650824484_item	2781978	et	4	main
enam	doc_643650824484_item	2781982	et	4	main
vankri	doc_643650824484_item	2781985	et	3	main
rehad	doc_643650824484_item	2781987	et	3	main
aasta	doc_643650824484_item	2781990	et	4	main
korjatud	doc_643650824484_item	2781993	et	4	main
korjasid	doc_643650824484_item	2782000	et	4	main
käisid	doc_643650824484_item	2782008	et	4	main
lauldes	doc_643650824484_item	2782009	et	3	main
koht	doc_643650824484_item	2782028	et	3	main
ehitamiseks	doc_643650824484_item	2782025	et	4	main
olema	doc_643650824484_item	2782036	et	4	main
erk	doc_643650824484_item	2782037	et	3	main
oleks	doc_643650824484_item	2782043	et	3	main
et	doc_643650824484_item	2782048	et	3	main
küla	doc_643650824484_item	2782056	et	4	main
päeval	doc_643650824484_item	2782060	et	3	main
põlemist	doc_643650824484_item	2782083	et	4	main
mõnedes	doc_643650824484_item	2782087	et	3	main
maakondades	doc_643650824484_item	2782089	et	3	main
lõkete	doc_643650824484_item	2782090	et	3	main
asemel	doc_643650824484_item	2782091	et	4	main
olid	doc_643650824484_item	2782092	et	4	main
põlevad	doc_643650824484_item	2782093	et	4	main
õlevihad	doc_643650824484_item	2782094	et	4	main
pikkadel	doc_643650824484_item	2782095	et	4	main
ritvadel	doc_643650824484_item	2782096	et	3	main
selliste	doc_643650824484_item	2782097	et	4	main
tõrvikutega	doc_643650824484_item	2782098	et	3	main
käidi	doc_643650824484_item	2782099	et	3	main
külas	doc_643650824484_item	2782100	et	3	main
ja	doc_643650824484_item	2782101	et	3	main
selle	doc_643650824484_item	2782102	et	4	main
ümber	doc_643650824484_item	2782103	et	3	main
kinnitati	doc_643650824484_item	2782104	et	4	main
neid	doc_643650824484_item	2782105	et	4	main
rohkesti	doc_643650824484_item	2782106	et	3	main
mööda	doc_643650824484_item	2782107	et	4	main
teid	doc_643650824484_item	2782108	et	4	main
noored	doc_643650824484_item	2782109	et	3	main
aga	doc_643650824484_item	2782110	et	3	main
tantsisid	doc_643650824484_item	2782111	et	4	main
ja	doc_643650824484_item	2782112	et	3	main
laulsid	doc_643650824484_item	2782113	et	4	main
p	doc_643650824484_item	2782114	et	4	main
vastlapäeva	doc_643650824484_item	2782115	et	4	main
hernehirmutis	doc_643650824484_item	2782116	et	4	main
venelastel	doc_643650824484_item	2782117	et	4	main
venemaal	doc_643650824484_item	2782118	et	4	main
vastlapäeva	doc_643650824484_item	2782119	et	4	main
hernehirmutis	doc_643650824484_item	2782120	et	4	main
sümboliseeris	doc_643650824484_item	2782077	et	4	main
lõke	doc_643650824484_item	2782081	et	4	main
läbi	doc_643650824484_item	2782082	et	4	main
puust	doc_643650824484_item	2782126	et	4	main
nukku	doc_643650824484_item	2782140	et	4	main
riietumine	doc_643650824484_item	2782144	et	4	main
peavad	doc_643650824484_item	2782146	et	4	main
peale	doc_643650824484_item	2782154	et	4	main
erinevatest	doc_643650824484_item	2782171	et	4	main
kodudest	doc_643650824484_item	2782172	et	3	main
kokku	doc_643650824484_item	2782173	et	3	main
küla	doc_643650824484_item	2782188	et	4	main
et	doc_643650824484_item	2782191	et	3	main
olid	doc_643650824484_item	2782192	et	4	main
pidulikude	doc_643650824484_item	2782208	et	4	main
küpsetaks	doc_643650824484_item	2782222	et	4	main
püha	doc_643650824484_item	2782235	et	4	main
sümboliksoli	doc_643650824484_item	2782236	et	4	main
kubermangudes	doc_643650824484_item	2782240	et	3	main
kelkudega	doc_643650824484_item	2782249	et	3	main
alla	doc_643650824484_item	2782251	et	3	main
venemaa	doc_643650824484_item	2782255	et	4	main
oli	doc_643650824484_item	2782264	et	3	main
välja	doc_643650824484_item	2782266	et	4	main
teda	doc_643650824484_item	2782270	et	4	main
riietati	doc_643650824484_item	2782271	et	3	main
naise	doc_643650824484_item	2782278	et	3	main
või	doc_643650824484_item	2782292	et	4	main
suure	doc_643650824484_item	2782294	et	3	main
teda	doc_643650824484_item	2782296	et	4	main
saatsid	doc_643650824484_item	2782297	et	4	main
ühekülainimesed	doc_643650824484_item	2782298	et	3	main
protsessiooni	doc_643650824484_item	2782308	et	4	main
külla	doc_643650824484_item	2782311	et	4	main
2	doc_662339917498_item	2782321	et	2	main
aasta	doc_662339917498_item	2782324	et	4	main
realismi	doc_662339917498_item	2782331	et	4	main
kui	doc_662339917498_item	2782332	et	3	main
põhjal	doc_662339917498_item	2782338	et	4	main
revolutsioon	doc_662339917498_item	2782352	et	3	main
see	doc_662339917498_item	2782366	et	3	main
võimu	doc_662339917498_item	2782405	et	4	main
sel	doc_662339917498_item	2782407	et	3	main
laulupeod	doc_662339917498_item	2782423	et	4	main
maal	doc_662339917498_item	2782443	et	4	main
aasta	doc_662339917498_item	2782445	et	4	main
mõned	doc_662339917498_item	2782466	et	3	main
vanemuine	doc_662339917498_item	2782470	et	4	main
murrang	doc_662339917498_item	2782474	et	3	main
lõpuks	doc_662339917498_item	2782477	et	4	main
nad	doc_662339917498_item	2782478	et	3	main
vüisid	doc_662339917498_item	2782479	et	4	main
teha	doc_662339917498_item	2782487	et	3	main
muuta	doc_662339917498_item	2782490	et	4	main
paremuse	doc_662339917498_item	2782492	et	4	main
sõda	doc_662339917498_item	2782499	et	4	main
ka	doc_662339917498_item	2782506	et	3	main
bolshevikud	doc_662339917498_item	2782511	et	4	main
võimu	doc_662339917498_item	2782512	et	4	main
neil	doc_662339917498_item	2782517	et	4	main
õnnestuski	doc_662339917498_item	2782518	et	4	main
ja	doc_662339917498_item	2782519	et	3	main
võim	doc_662339917498_item	2782521	et	3	main
kaua	doc_662339917498_item	2782523	et	3	main
ja	doc_662339917498_item	2782531	et	3	main
stagnatsioonaga	doc_662339917498_item	2782539	et	4	main
et	doc_662339917498_item	2782546	et	3	main
liit	doc_662339917498_item	2782548	et	3	main
teha	doc_662339917498_item	2782550	et	3	main
et	doc_662339917498_item	2782552	et	3	main
kõik	doc_662339917498_item	2782553	et	4	main
sisimuselt	doc_662339917498_item	2782564	et	4	main
oli	doc_662339917498_item	2782565	et	3	main
nad	doc_662339917498_item	2782581	et	3	main
ja	doc_662339917498_item	2782588	et	3	main
juhul	doc_662339917498_item	2782593	et	3	main
oli	doc_662339917498_item	2782595	et	3	main
selles	doc_662339917498_item	2782600	et	4	main
filmis	doc_662339917498_item	2782601	et	4	main
oli	doc_662339917498_item	2782602	et	3	main
partei	doc_662339917498_item	2782609	et	4	main
koju	doc_643650824484_item	2782086	et	3	main
või	doc_643650824484_item	2782128	et	4	main
naisena	doc_643650824484_item	2782129	et	3	main
või	doc_643650824484_item	2782130	et	4	main
reaalse	doc_643650824484_item	2782131	et	3	main
rolli	doc_643650824484_item	2782136	et	4	main
tähtsamaks	doc_643650824484_item	2782138	et	4	main
selle	doc_643650824484_item	2782139	et	4	main
tema	doc_643650824484_item	2782143	et	4	main
väljapoole	doc_643650824484_item	2782158	et	3	main
kogu	doc_643650824484_item	2782166	et	4	main
tema	doc_643650824484_item	2782167	et	4	main
küla	doc_643650824484_item	2782177	et	4	main
tehti	doc_643650824484_item	2782181	et	3	main
oma	doc_643650824484_item	2782183	et	4	main
pere	doc_643650824484_item	2782184	et	4	main
nukke	doc_643650824484_item	2782185	et	3	main
nad	doc_643650824484_item	2782186	et	3	main
neile	doc_643650824484_item	2782195	et	4	main
silmad	doc_643650824484_item	2782197	et	4	main
kulmud	doc_643650824484_item	2782198	et	3	main
atribuutidega	doc_643650824484_item	2782209	et	3	main
ta	doc_643650824484_item	2782221	et	4	main
mõnedes	doc_643650824484_item	2782254	et	3	main
piirkondades	doc_643650824484_item	2782256	et	3	main
talunik	doc_643650824484_item	2782262	et	3	main
ja	doc_643650824484_item	2782273	et	3	main
riietatud	doc_643650824484_item	2782287	et	4	main
inimene	doc_643650824484_item	2782288	et	3	main
sõitis	doc_643650824484_item	2782289	et	3	main
välja	doc_643650824484_item	2782300	et	4	main
sõites	doc_643650824484_item	2782301	et	3	main
kogu	doc_643650824484_item	2782307	et	4	main
naases	doc_643650824484_item	2782310	et	4	main
tagasi	doc_643650824484_item	2782312	et	3	main
hinda	doc_662339917498_item	2782322	et	4	main
valgus	doc_662339917498_item	2782335	et	4	main
2	doc_662339917498_item	2782340	et	2	main
tähtis	doc_662339917498_item	2782345	et	4	main
kus	doc_662339917498_item	2782353	et	3	main
tahtsid	doc_662339917498_item	2782355	et	4	main
troonilt	doc_662339917498_item	2782359	et	3	main
võtta	doc_662339917498_item	2782361	et	3	main
kellegi	doc_662339917498_item	2782404	et	4	main
aastal	doc_662339917498_item	2782408	et	3	main
hakkas	doc_662339917498_item	2782409	et	3	main
kultuuriliselt	doc_662339917498_item	2782414	et	4	main
tähtis	doc_662339917498_item	2782419	et	4	main
hakkasid	doc_662339917498_item	2782420	et	4	main
mehena	doc_643650824484_item	2782127	et	3	main
seda	doc_643650824484_item	2782135	et	3	main
rebinud	doc_643650824484_item	2782150	et	4	main
aga	doc_643650824484_item	2782151	et	3	main
mõnikord	doc_643650824484_item	2782152	et	3	main
tõmmati	doc_643650824484_item	2782153	et	3	main
pööratud	doc_643650824484_item	2782156	et	4	main
kasukas	doc_643650824484_item	2782159	et	4	main
heina	doc_643650824484_item	2782161	et	4	main
korjata	doc_643650824484_item	2782174	et	4	main
külades	doc_643650824484_item	2782180	et	3	main
erinesid	doc_643650824484_item	2782187	et	4	main
kena	doc_643650824484_item	2782193	et	4	main
vastavate	doc_643650824484_item	2782207	et	4	main
panniga	doc_643650824484_item	2782210	et	4	main
kulbiga	doc_643650824484_item	2782211	et	3	main
pannkoogidega	doc_643650824484_item	2782212	et	4	main
ja	doc_643650824484_item	2782213	et	3	main
pandi	doc_643650824484_item	2782214	et	4	main
kodus	doc_643650824484_item	2782215	et	4	main
pingile	doc_643650824484_item	2782216	et	3	main
istuma	doc_643650824484_item	2782217	et	3	main
sellises	doc_643650824484_item	2782218	et	4	main
asendis	doc_643650824484_item	2782219	et	3	main
nagu	doc_643650824484_item	2782220	et	3	main
pannkooke	doc_643650824484_item	2782223	et	4	main
kuid	doc_643650824484_item	2782231	et	4	main
mitte	doc_643650824484_item	2782232	et	3	main
peamiseks	doc_643650824484_item	2782234	et	3	main
nukk	doc_643650824484_item	2782238	et	3	main
oli	doc_643650824484_item	2782242	et	3	main
teistes	doc_643650824484_item	2782244	et	4	main
kujutatud	doc_643650824484_item	2782245	et	4	main
lumememmena	doc_643650824484_item	2782246	et	3	main
veeretati	doc_643650824484_item	2782248	et	3	main
mäest	doc_643650824484_item	2782250	et	3	main
jaoks	doc_643650824484_item	2782269	et	4	main
fantastiliselt	doc_643650824484_item	2782286	et	4	main
külast	doc_643650824484_item	2782299	et	4	main
rõivadesse	doc_643650824484_item	2782305	et	4	main
ja	doc_643650824484_item	2782306	et	3	main
osalejatega	doc_643650824484_item	2782309	et	4	main
1905	doc_662339917498_item	2782323	et	2	main
sündmuste	doc_662339917498_item	2782325	et	3	main
tähtsust	doc_662339917498_item	2782326	et	4	main
eesti	doc_662339917498_item	2782327	et	4	main
loomismeetodit	doc_662339917498_item	2782333	et	3	main
filmi	doc_662339917498_item	2782334	et	4	main
vastused	doc_662339917498_item	2782339	et	3	main
väga	doc_662339917498_item	2782344	et	3	main
eesti	doc_662339917498_item	2782346	et	4	main
maha	doc_662339917498_item	2782360	et	4	main
nikolai	doc_662339917498_item	2782362	et	4	main
lõppude	doc_662339917498_item	2782364	et	4	main
eesti	doc_662339917498_item	2782369	et	4	main
oli	doc_662339917498_item	2782371	et	3	main
see	doc_662339917498_item	2782372	et	3	main
aasta	doc_662339917498_item	2782373	et	4	main
pöördepunkt	doc_662339917498_item	2782374	et	3	main
nagu	doc_662339917498_item	2782375	et	3	main
tegutsemaka	doc_662339917498_item	2782410	et	4	main
aasta	doc_662339917498_item	2782416	et	4	main
tegutsema	doc_662339917498_item	2782421	et	3	main
on	doc_662339917498_item	2782433	et	4	main
põllumajandus	doc_662339917498_item	2782434	et	3	main
see	doc_662339917498_item	2782437	et	3	main
seda	doc_662339917498_item	2782447	et	3	main
saavad	doc_662339917498_item	2782450	et	4	main
ka	doc_662339917498_item	2782464	et	3	main
kutselised	doc_662339917498_item	2782467	et	4	main
kuid	doc_643650824484_item	2782224	et	4	main
rituaal	doc_643650824484_item	2782226	et	3	main
tähendanud	doc_643650824484_item	2782228	et	4	main
tõsist	doc_643650824484_item	2782230	et	4	main
õlest	doc_643650824484_item	2782237	et	4	main
hernehirmutis	doc_643650824484_item	2782241	et	4	main
puust	doc_643650824484_item	2782243	et	4	main
xix	doc_643650824484_item	2782252	et	4	main
kes	doc_643650824484_item	2782263	et	4	main
rebitud	doc_643650824484_item	2782274	et	4	main
rõivadesse	doc_643650824484_item	2782276	et	4	main
varustati	doc_643650824484_item	2782279	et	3	main
hobusega	doc_643650824484_item	2782290	et	4	main
metsa	doc_643650824484_item	2782293	et	4	main
riietus	doc_643650824484_item	2782303	et	4	main
tavalistesse	doc_643650824484_item	2782304	et	4	main
kontrolltöö	doc_662339917498_item	2782313	et	4	main
1	doc_662339917498_item	2782314	et	2	main
anna	doc_662339917498_item	2782315	et	4	main
ülevaade	doc_662339917498_item	2782316	et	3	main
rahvusteaduste	doc_662339917498_item	2782317	et	3	main
arengust	doc_662339917498_item	2782318	et	3	main
eesti	doc_662339917498_item	2782319	et	4	main
wabariigis	doc_662339917498_item	2782320	et	4	main
koordis	doc_662339917498_item	2782336	et	4	main
1905	doc_662339917498_item	2782342	et	2	main
oli	doc_662339917498_item	2782343	et	3	main
ajaloos	doc_662339917498_item	2782347	et	4	main
sellepärast	doc_662339917498_item	2782348	et	3	main
et	doc_662339917498_item	2782349	et	3	main
venemaal	doc_662339917498_item	2782350	et	4	main
bolshevikud	doc_662339917498_item	2782354	et	4	main
haarata	doc_662339917498_item	2782356	et	4	main
võimu	doc_662339917498_item	2782357	et	4	main
ja	doc_662339917498_item	2782358	et	3	main
lõpuksneil	doc_662339917498_item	2782365	et	4	main
aga	doc_662339917498_item	2782368	et	3	main
eesti	doc_662339917498_item	2782411	et	4	main
kirjanikke	doc_662339917498_item	2782412	et	3	main
selts	doc_662339917498_item	2782413	et	3	main
see	doc_662339917498_item	2782415	et	3	main
oli	doc_662339917498_item	2782417	et	3	main
ka	doc_662339917498_item	2782418	et	3	main
uuesti	doc_662339917498_item	2782422	et	3	main
erinevad	doc_662339917498_item	2782428	et	4	main
seltsid	doc_662339917498_item	2782429	et	4	main
nagu	doc_662339917498_item	2782430	et	3	main
teada	doc_662339917498_item	2782431	et	3	main
eesti	doc_662339917498_item	2782432	et	4	main
nad	doc_662339917498_item	2782449	et	3	main
oma	doc_662339917498_item	2782451	et	4	main
olukorda	doc_662339917498_item	2782452	et	4	main
parandada	doc_662339917498_item	2782453	et	3	main
hakkasid	doc_662339917498_item	2782463	et	4	main
eestlaste	doc_662339917498_item	2782475	et	4	main
sisimusel	doc_662339917498_item	2782476	et	4	main
eestit	doc_662339917498_item	2782491	et	3	main
3	doc_662339917498_item	2782494	et	2	main
nagu	doc_662339917498_item	2782495	et	3	main
teada	doc_662339917498_item	2782496	et	3	main
ii	doc_662339917498_item	2782497	et	4	main
purustav	doc_662339917498_item	2782503	et	4	main
see	doc_662339917498_item	2782504	et	3	main
ja	doc_662339917498_item	2782508	et	3	main
otsustasid	doc_662339917498_item	2782510	et	4	main
enda	doc_662339917498_item	2782513	et	4	main
nende	doc_662339917498_item	2782520	et	4	main
ei	doc_643650824484_item	2782227	et	4	main
midagi	doc_643650824484_item	2782229	et	4	main
alati	doc_643650824484_item	2782233	et	4	main
mõnedes	doc_643650824484_item	2782239	et	3	main
mida	doc_643650824484_item	2782247	et	4	main
sajandil	doc_643650824484_item	2782253	et	3	main
vastlapäeva	doc_643650824484_item	2782257	et	4	main
hernehirmutise	doc_643650824484_item	2782258	et	3	main
rolli	doc_643650824484_item	2782259	et	4	main
mängis	doc_643650824484_item	2782260	et	3	main
mingisugune	doc_643650824484_item	2782261	et	3	main
spetsiaalselt	doc_643650824484_item	2782265	et	4	main
valitud	doc_643650824484_item	2782267	et	4	main
ühiskonna	doc_643650824484_item	2782268	et	4	main
kulunud	doc_643650824484_item	2782272	et	4	main
mehe	doc_643650824484_item	2782275	et	3	main
mõnikord	doc_643650824484_item	2782277	et	3	main
arvukate	doc_643650824484_item	2782280	et	4	main
tobedate	doc_643650824484_item	2782281	et	3	main
rekvisiitidega	doc_643650824484_item	2782282	et	3	main
ja	doc_643650824484_item	2782283	et	3	main
liikumisvahenditega	doc_643650824484_item	2782284	et	3	main
selline	doc_643650824484_item	2782285	et	4	main
põllule	doc_643650824484_item	2782291	et	3	main
lärmiga	doc_643650824484_item	2782295	et	3	main
hernehirmutis	doc_643650824484_item	2782302	et	4	main
ajaloos	doc_662339917498_item	2782328	et	4	main
3kirjelda	doc_662339917498_item	2782329	et	4	main
sotsialistlikku	doc_662339917498_item	2782330	et	4	main
nähtu	doc_662339917498_item	2782337	et	4	main
aasta	doc_662339917498_item	2782341	et	4	main
juhtus	doc_662339917498_item	2782351	et	3	main
ii-se	doc_662339917498_item	2782363	et	4	main
õnnestus	doc_662339917498_item	2782367	et	4	main
jaoks	doc_662339917498_item	2782370	et	4	main
teada	doc_662339917498_item	2782376	et	3	main
esti	doc_662339917498_item	2782377	et	4	main
on	doc_662339917498_item	2782378	et	4	main
väike	doc_662339917498_item	2782379	et	4	main
riik	doc_662339917498_item	2782380	et	3	main
ja	doc_662339917498_item	2782381	et	3	main
ta	doc_662339917498_item	2782382	et	4	main
tahtis	doc_662339917498_item	2782383	et	3	main
saada	doc_662339917498_item	2782384	et	4	main
iseseisvaks	doc_662339917498_item	2782385	et	3	main
riigiks	doc_662339917498_item	2782386	et	3	main
see	doc_662339917498_item	2782387	et	3	main
oli	doc_662339917498_item	2782388	et	3	main
nende	doc_662339917498_item	2782389	et	4	main
peamine	doc_662339917498_item	2782390	et	3	main
eesmärk	doc_662339917498_item	2782391	et	3	main
eesti	doc_662339917498_item	2782392	et	4	main
tahtis	doc_662339917498_item	2782393	et	3	main
olla	doc_662339917498_item	2782394	et	3	main
tuntav	doc_662339917498_item	2782395	et	4	main
maailmas	doc_662339917498_item	2782396	et	3	main
ta	doc_662339917498_item	2782397	et	4	main
oli	doc_662339917498_item	2782398	et	3	main
juba	doc_662339917498_item	2782399	et	3	main
väsinud	doc_662339917498_item	2782400	et	4	main
sajandite	doc_662339917498_item	2782401	et	3	main
kaupa	doc_662339917498_item	2782402	et	4	main
olles	doc_662339917498_item	2782403	et	3	main
all	doc_662339917498_item	2782406	et	3	main
ajakirjad	doc_662339917498_item	2782425	et	3	main
hakkasid	doc_662339917498_item	2782426	et	4	main
ja	doc_662339917498_item	2782436	et	3	main
inimesed	doc_662339917498_item	2782441	et	3	main
et	doc_662339917498_item	2782448	et	3	main
aadlike	doc_662339917498_item	2782460	et	4	main
käskete	doc_662339917498_item	2782461	et	3	main
all	doc_662339917498_item	2782462	et	3	main
loota	doc_662339917498_item	2782480	et	4	main
et	doc_662339917498_item	2782481	et	3	main
nad	doc_662339917498_item	2782482	et	3	main
et	doc_662339917498_item	2782489	et	3	main
poole	doc_662339917498_item	2782493	et	4	main
jaoks	doc_662339917498_item	2782502	et	4	main
kätte	doc_662339917498_item	2782514	et	4	main
võtta	doc_662339917498_item	2782515	et	3	main
periood	doc_662339917498_item	2782530	et	3	main
nt	doc_662339917498_item	2782534	et	4	main
sügav	doc_662339917498_item	2782538	et	4	main
teiste	doc_662339917498_item	2782557	et	4	main
jaoks	doc_662339917498_item	2782558	et	4	main
aga	doc_662339917498_item	2782559	et	3	main
see	doc_662339917498_item	2782560	et	3	main
oli	doc_662339917498_item	2782561	et	3	main
ainukeseks	doc_662339917498_item	2782569	et	4	main
parteiks	doc_662339917498_item	2782570	et	3	main
sotsialistlik	doc_662339917498_item	2782575	et	3	main
meelde	doc_662339917498_item	2782577	et	3	main
kasulik	doc_662339917498_item	2782587	et	3	main
parteile	doc_662339917498_item	2782590	et	3	main
vastasel	doc_662339917498_item	2782592	et	3	main
mida	doc_662339917498_item	2782598	et	4	main
ilmusid	doc_662339917498_item	2782424	et	4	main
tegutsema	doc_662339917498_item	2782427	et	3	main
riik	doc_662339917498_item	2782435	et	3	main
tähendab	doc_662339917498_item	2782438	et	3	main
et	doc_662339917498_item	2782439	et	3	main
paljud	doc_662339917498_item	2782440	et	3	main
töötasid	doc_662339917498_item	2782442	et	4	main
see	doc_662339917498_item	2782444	et	3	main
tähendas	doc_662339917498_item	2782446	et	3	main
ja	doc_662339917498_item	2782454	et	3	main
töötada	doc_662339917498_item	2782455	et	3	main
maal	doc_662339917498_item	2782456	et	4	main
ise	doc_662339917498_item	2782457	et	4	main
mitte	doc_662339917498_item	2782458	et	3	main
aga	doc_662339917498_item	2782459	et	3	main
tegutsema	doc_662339917498_item	2782465	et	3	main
teatrid	doc_662339917498_item	2782468	et	3	main
saavad	doc_662339917498_item	2782483	et	4	main
kõik	doc_662339917498_item	2782488	et	4	main
oli	doc_662339917498_item	2782500	et	3	main
kõikide	doc_662339917498_item	2782501	et	4	main
eestit	doc_662339917498_item	2782507	et	3	main
siis	doc_662339917498_item	2782509	et	3	main
mis	doc_662339917498_item	2782516	et	4	main
kestis	doc_662339917498_item	2782522	et	4	main
ka	doc_662339917498_item	2782525	et	3	main
hetki	doc_662339917498_item	2782527	et	4	main
halvad	doc_662339917498_item	2782532	et	4	main
ajad	doc_662339917498_item	2782533	et	4	main
tõsine	doc_662339917498_item	2782568	et	4	main
olla	doc_662339917498_item	2782572	et	3	main
vaid	doc_662339917498_item	2782573	et	3	main
olema	doc_662339917498_item	2782586	et	4	main
lojaalne	doc_662339917498_item	2782589	et	3	main
võimalik	doc_662339917498_item	2782596	et	3	main
mis	doc_662339917498_item	2782605	et	4	main
oli	doc_662339917498_item	2782606	et	3	main
räägitud	doc_662339917498_item	2782607	et	4	main
muutus	doc_662339917498_item	2782621	et	4	main
omandiks	doc_662339917498_item	2782623	et	3	main
oli	doc_662339917498_item	2782626	et	3	main
ette	doc_662339917498_item	2782631	et	4	main
siis	doc_662339917498_item	2782633	et	3	main
aga	doc_662339917498_item	2782642	et	3	main
peamine	doc_662339917498_item	2782643	et	3	main
selles	doc_662339917498_item	2782644	et	4	main
oli	doc_662339917498_item	2782645	et	3	main
rajama	doc_662339917498_item	2782649	et	3	main
andma	doc_662339917498_item	2782655	et	3	main
saagist	doc_662339917498_item	2782659	et	4	main
kolhoosile	doc_662339917498_item	2782661	et	3	main
muidu	doc_662339917498_item	2782662	et	3	main
sind	doc_662339917498_item	2782663	et	4	main
süüdistatakse	doc_662339917498_item	2782664	et	3	main
mitte	doc_662339917498_item	2782665	et	3	main
on	doc_662339917498_item	2782693	et	4	main
seotud	doc_662339917498_item	2782715	et	4	main
tehti	doc_662339917498_item	2782716	et	3	main
edaspidi	doc_662339917498_item	2782724	et	3	main
kasuks	doc_662339917498_item	2782727	et	4	main
vaid	doc_662339917498_item	2782729	et	3	main
öeldud	doc_662339917498_item	2782733	et	4	main
oli	doc_662339917498_item	2782740	et	3	main
teisiti	doc_662339917498_item	2782742	et	3	main
kõik	doc_662339917498_item	2782745	et	4	main
kõik	doc_662339917498_item	2782750	et	4	main
isegi	doc_662339917498_item	2782752	et	4	main
huvitanud	doc_662339917498_item	2782761	et	4	main
väga	doc_662339917498_item	2782769	et	3	main
essee	doc_670731433410_item	2782875	et	4	main
ülikool	doc_670731433410_item	2782878	et	4	main
nimi	doc_670731433410_item	2782880	et	3	main
eesnimi	doc_670731433410_item	2782882	et	3	main
ma	doc_670731433410_item	2782883	et	3	main
kaheksateist	doc_670731433410_item	2782885	et	4	main
aastat	doc_670731433410_item	2782886	et	3	main
vana	doc_670731433410_item	2782887	et	4	main
ja	doc_670731433410_item	2782893	et	3	main
on	doc_670731433410_item	2782938	et	4	main
väga	doc_670731433410_item	2782939	et	3	main
hea	doc_670731433410_item	2782940	et	4	main
see	doc_670731433410_item	2782949	et	3	main
on	doc_670731433410_item	2782956	et	4	main
on	doc_670731433410_item	2782963	et	4	main
kergem	doc_670731433410_item	2782964	et	4	main
välja	doc_670731433410_item	2782990	et	4	main
nagu	doc_662339917498_item	2782469	et	3	main
tartus	doc_662339917498_item	2782471	et	3	main
see	doc_662339917498_item	2782472	et	3	main
oli	doc_662339917498_item	2782473	et	3	main
olla	doc_662339917498_item	2782484	et	3	main
vabad	doc_662339917498_item	2782485	et	3	main
ja	doc_662339917498_item	2782486	et	3	main
maailma	doc_662339917498_item	2782498	et	4	main
puudutas	doc_662339917498_item	2782505	et	3	main
oli	doc_662339917498_item	2782524	et	3	main
häid	doc_662339917498_item	2782526	et	3	main
nt	doc_662339917498_item	2782528	et	4	main
sula	doc_662339917498_item	2782529	et	4	main
puudutab	doc_662339917498_item	2782541	et	3	main
realismi	doc_662339917498_item	2782543	et	4	main
nõukogude	doc_662339917498_item	2782547	et	3	main
nii	doc_662339917498_item	2782551	et	3	main
ainult	doc_662339917498_item	2782562	et	4	main
pealiskaudne	doc_662339917498_item	2782563	et	3	main
kõik	doc_662339917498_item	2782603	et	4	main
see	doc_662339917498_item	2782604	et	3	main
tuli	doc_662339917498_item	2782610	et	4	main
oli	doc_662339917498_item	2782630	et	3	main
ära	doc_662339917498_item	2782638	et	4	main
andma	doc_662339917498_item	2782639	et	3	main
niinimetatud	doc_662339917498_item	2782640	et	3	main
natsionaliseerumine	doc_662339917498_item	2782641	et	4	main
hakati	doc_662339917498_item	2782648	et	3	main
iga	doc_662339917498_item	2782651	et	4	main
pidi	doc_662339917498_item	2782653	et	4	main
veel	doc_662339917498_item	2782702	et	4	main
sotsialistlik	doc_662339917498_item	2782704	et	3	main
näidusõite	doc_662339917498_item	2782717	et	4	main
et	doc_662339917498_item	2782718	et	3	main
kasutada	doc_662339917498_item	2782725	et	3	main
mitte	doc_662339917498_item	2782728	et	3	main
pealiskaudne	doc_662339917498_item	2782737	et	3	main
tehti	doc_662339917498_item	2782749	et	3	main
see	doc_662339917498_item	2782759	et	3	main
ta	doc_662339917498_item	2782763	et	4	main
ainulaadne	doc_662339917498_item	2782766	et	3	main
võimu	doc_662339917498_item	2782771	et	4	main
minu	doc_670731433410_item	2782879	et	3	main
on	doc_670731433410_item	2782881	et	4	main
sest	doc_670731433410_item	2782903	et	4	main
ma	doc_670731433410_item	2782904	et	3	main
käisin	doc_670731433410_item	2782905	et	3	main
pärast	doc_670731433410_item	2782924	et	4	main
koolis	doc_670731433410_item	2782926	et	4	main
mul	doc_670731433410_item	2782927	et	3	main
oli	doc_670731433410_item	2782928	et	3	main
mul	doc_670731433410_item	2782932	et	3	main
aeg	doc_670731433410_item	2782934	et	3	main
huvitav	doc_670731433410_item	2782936	et	4	main
on	doc_670731433410_item	2782944	et	4	main
tähtis	doc_670731433410_item	2782952	et	4	main
sõpru	doc_670731433410_item	2782958	et	3	main
see	doc_670731433410_item	2782960	et	3	main
mul	doc_670731433410_item	2782962	et	3	main
ja	doc_670731433410_item	2782969	et	3	main
tuleb	doc_670731433410_item	2782989	et	3	main
brezhnevi	doc_662339917498_item	2782535	et	4	main
periood	doc_662339917498_item	2782536	et	3	main
ja	doc_662339917498_item	2782537	et	3	main
mis	doc_662339917498_item	2782540	et	4	main
sotsialistlikku	doc_662339917498_item	2782542	et	4	main
see	doc_662339917498_item	2782544	et	3	main
tähendab	doc_662339917498_item	2782545	et	3	main
püüdis	doc_662339917498_item	2782549	et	3	main
tunduks	doc_662339917498_item	2782554	et	3	main
väga	doc_662339917498_item	2782555	et	3	main
hea	doc_662339917498_item	2782556	et	4	main
kõik	doc_662339917498_item	2782566	et	4	main
väga	doc_662339917498_item	2782567	et	3	main
sai	doc_662339917498_item	2782571	et	4	main
üks	doc_662339917498_item	2782574	et	3	main
kõik	doc_662339917498_item	2782576	et	4	main
avaldusi	doc_662339917498_item	2782578	et	4	main
kontrolliti	doc_662339917498_item	2782579	et	3	main
et	doc_662339917498_item	2782580	et	3	main
oleksid	doc_662339917498_item	2782582	et	4	main
õiged	doc_662339917498_item	2782583	et	3	main
inimene	doc_662339917498_item	2782584	et	3	main
pidi	doc_662339917498_item	2782585	et	4	main
või	doc_662339917498_item	2782591	et	4	main
temaga	doc_662339917498_item	2782594	et	3	main
teha	doc_662339917498_item	2782597	et	3	main
taheti	doc_662339917498_item	2782599	et	3	main
enne	doc_662339917498_item	2782608	et	4	main
võimule	doc_662339917498_item	2782611	et	3	main
ja	doc_662339917498_item	2782612	et	3	main
tahtis	doc_662339917498_item	2782613	et	3	main
enda	doc_662339917498_item	2782614	et	4	main
alla	doc_662339917498_item	2782615	et	3	main
suruda	doc_662339917498_item	2782616	et	3	main
kõiki	doc_662339917498_item	2782617	et	4	main
ja	doc_662339917498_item	2782618	et	3	main
kõik	doc_662339917498_item	2782619	et	4	main
kõik	doc_662339917498_item	2782620	et	4	main
riigi	doc_662339917498_item	2782622	et	3	main
maad	doc_662339917498_item	2782628	et	4	main
nähtud	doc_662339917498_item	2782632	et	4	main
sa	doc_662339917498_item	2782634	et	3	main
pidid	doc_662339917498_item	2782635	et	4	main
seda	doc_662339917498_item	2782636	et	3	main
see	doc_662339917498_item	2782646	et	3	main
kolhoose	doc_662339917498_item	2782650	et	3	main
osa	doc_662339917498_item	2782657	et	4	main
juhul	doc_662339917498_item	2782669	et	3	main
vaja	doc_662339917498_item	2782694	et	4	main
abi	doc_662339917498_item	2782695	et	4	main
siis	doc_662339917498_item	2782696	et	3	main
sulle	doc_662339917498_item	2782697	et	3	main
tullakse	doc_662339917498_item	2782698	et	3	main
vastu	doc_662339917498_item	2782699	et	3	main
ja	doc_662339917498_item	2782700	et	3	main
see	doc_662339917498_item	2782703	et	3	main
tahtis	doc_662339917498_item	2782706	et	3	main
kui	doc_662339917498_item	2782708	et	3	main
näidata	doc_662339917498_item	2782719	et	4	main
uut	doc_662339917498_item	2782720	et	3	main
võib	doc_662339917498_item	2782723	et	3	main
kõik	doc_662339917498_item	2782734	et	4	main
see	doc_662339917498_item	2782735	et	3	main
aga	doc_662339917498_item	2782738	et	3	main
ja	doc_662339917498_item	2782743	et	3	main
et	doc_662339917498_item	2782744	et	3	main
minevat	doc_662339917498_item	2782748	et	4	main
võimalikku	doc_662339917498_item	2782751	et	4	main
kui	doc_662339917498_item	2782753	et	3	main
oli	doc_662339917498_item	2782754	et	3	main
vaja	doc_662339917498_item	2782755	et	4	main
tuua	doc_662339917498_item	2782756	et	3	main
inimohvreid	doc_662339917498_item	2782757	et	3	main
sul	doc_662339917498_item	2782625	et	3	main
kui	doc_662339917498_item	2782629	et	3	main
maad	doc_662339917498_item	2782637	et	4	main
et	doc_662339917498_item	2782647	et	3	main
talunik	doc_662339917498_item	2782652	et	3	main
mingit	doc_662339917498_item	2782656	et	3	main
oma	doc_662339917498_item	2782658	et	4	main
sellele	doc_662339917498_item	2782660	et	4	main
sind	doc_662339917498_item	2782670	et	4	main
saadetakse	doc_662339917498_item	2782671	et	3	main
laagrisse	doc_662339917498_item	2782672	et	3	main
sund	doc_662339917498_item	2782673	et	3	main
töödele	doc_662339917498_item	2782674	et	3	main
veel	doc_662339917498_item	2782675	et	4	main
öeldi	doc_662339917498_item	2782676	et	3	main
et	doc_662339917498_item	2782677	et	3	main
kolhoos	doc_662339917498_item	2782678	et	3	main
on	doc_662339917498_item	2782679	et	4	main
ju	doc_662339917498_item	2782680	et	3	main
kõige	doc_662339917498_item	2782681	et	4	main
parem	doc_662339917498_item	2782682	et	4	main
asi	doc_662339917498_item	2782683	et	4	main
sest	doc_662339917498_item	2782684	et	4	main
siis	doc_662339917498_item	2782685	et	3	main
saab	doc_662339917498_item	2782686	et	3	main
kõike	doc_662339917498_item	2782687	et	4	main
kontrollda	doc_662339917498_item	2782688	et	4	main
et	doc_662339917498_item	2782689	et	3	main
oleks	doc_662339917498_item	2782690	et	3	main
õige	doc_662339917498_item	2782691	et	4	main
ui	doc_662339917498_item	2782692	et	4	main
kui	doc_662339917498_item	2782624	et	3	main
rohkem	doc_662339917498_item	2782627	et	4	main
ära	doc_662339917498_item	2782654	et	4	main
lojaalsuses	doc_662339917498_item	2782666	et	4	main
ja	doc_662339917498_item	2782667	et	3	main
paremal	doc_662339917498_item	2782668	et	4	main
aidatakse	doc_662339917498_item	2782701	et	4	main
realism	doc_662339917498_item	2782705	et	3	main
näidata	doc_662339917498_item	2782707	et	4	main
areneb	doc_662339917498_item	2782710	et	3	main
hästi	doc_662339917498_item	2782709	et	3	main
teadus	doc_662339917498_item	2782711	et	4	main
ja	doc_662339917498_item	2782712	et	3	main
kõik	doc_662339917498_item	2782713	et	4	main
temaga	doc_662339917498_item	2782714	et	3	main
tehnikat	doc_662339917498_item	2782721	et	3	main
riigi	doc_662339917498_item	2782726	et	3	main
oli	doc_662339917498_item	2782736	et	3	main
sisimuselt	doc_662339917498_item	2782739	et	4	main
tuntuks	doc_662339917498_item	2782746	et	4	main
lõpetasin	doc_670731433410_item	2782889	et	3	main
aastal	doc_670731433410_item	2782891	et	3	main
astusin	doc_670731433410_item	2782895	et	3	main
siia	doc_670731433410_item	2782906	et	4	main
ma	doc_670731433410_item	2782908	et	3	main
ma	doc_670731433410_item	2782921	et	3	main
mida	doc_662339917498_item	2782722	et	4	main
enda	doc_662339917498_item	2782730	et	4	main
jaoks	doc_662339917498_item	2782731	et	4	main
nagu	doc_662339917498_item	2782732	et	3	main
kõik	doc_662339917498_item	2782741	et	4	main
hästi	doc_662339917498_item	2782747	et	3	main
parteid	doc_662339917498_item	2782758	et	4	main
ei	doc_662339917498_item	2782760	et	4	main
olla	doc_662339917498_item	2782765	et	3	main
omada	doc_662339917498_item	2782768	et	3	main
suurt	doc_662339917498_item	2782770	et	3	main
üldse	doc_662339917498_item	2782762	et	3	main
tohtis	doc_662339917498_item	2782764	et	3	main
ja	doc_662339917498_item	2782767	et	3	main
mina	doc_670731433410_item	2782876	et	4	main
ma	doc_670731433410_item	2782888	et	3	main
sisse	doc_670731433410_item	2782894	et	4	main
kursustesse	doc_670731433410_item	2782907	et	3	main
käisin	doc_670731433410_item	2782909	et	3	main
ökonoomika	doc_670731433410_item	2782930	et	4	main
kogu	doc_670731433410_item	2782933	et	4	main
mulje	doc_670731433410_item	2782941	et	4	main
et	doc_670731433410_item	2782948	et	3	main
moraalselt	doc_670731433410_item	2782965	et	4	main
kes	doc_670731433412_item	2783091	et	4	main
hakkab	doc_670731433412_item	2783092	et	3	main
seda	doc_670731433412_item	2783093	et	3	main
lugeda	doc_670731433412_item	2783094	et	3	main
minu	doc_670731433412_item	2783095	et	3	main
nimi	doc_670731433412_item	2783096	et	3	main
tõnismäe	doc_670731433412_item	2783126	et	3	main
sii	doc_670731433412_item	2783140	et	4	main
saa	doc_670731433412_item	2783143	et	4	main
ülikoolist	doc_670731433412_item	2783150	et	4	main
ettevõtlusest	doc_670731433412_item	2783167	et	4	main
ja	doc_670731433412_item	2783180	et	3	main
ootan	doc_670731433412_item	2783223	et	3	main
võimalus	doc_670731433412_item	2783225	et	3	main
ja	doc_670731433410_item	2782877	et	3	main
olen	doc_670731433410_item	2782884	et	3	main
sellel	doc_670731433410_item	2782890	et	4	main
kooli	doc_670731433410_item	2782892	et	4	main
tallinna	doc_670731433410_item	2782896	et	4	main
tehnika	doc_670731433410_item	2782897	et	4	main
ülikooli	doc_670731433410_item	2782898	et	4	main
ma	doc_670731433410_item	2782899	et	3	main
olin	doc_670731433410_item	2782900	et	3	main
väga	doc_670731433410_item	2782901	et	3	main
tore	doc_670731433410_item	2782902	et	3	main
õppida	doc_670731433410_item	2782910	et	3	main
just	doc_670731433410_item	2782911	et	3	main
majandusel	doc_670731433410_item	2782912	et	4	main
selle	doc_670731433410_item	2782913	et	4	main
pärast	doc_670731433410_item	2782914	et	4	main
et	doc_670731433410_item	2782915	et	3	main
mulle	doc_670731433410_item	2782916	et	4	main
see	doc_670731433410_item	2782917	et	3	main
väga	doc_670731433410_item	2782918	et	3	main
huvitav	doc_670731433410_item	2782919	et	4	main
see	doc_670731433410_item	2782920	et	3	main
tean	doc_670731433410_item	2782922	et	3	main
ja	doc_670731433410_item	2782931	et	3	main
minul	doc_670731433410_item	2782937	et	3	main
riigiülikool	doc_670731433410_item	2782945	et	4	main
ma	doc_670731433410_item	2782946	et	3	main
arvan	doc_670731433410_item	2782947	et	3	main
ülikoolis	doc_670731433410_item	2782954	et	4	main
mul	doc_670731433410_item	2782955	et	3	main
ttü	doc_670731433410_item	2782966	et	4	main
väga	doc_670731433410_item	2782967	et	3	main
suur	doc_670731433410_item	2782968	et	3	main
on	doc_670731433412_item	2783097	et	4	main
eesnimi	doc_670731433412_item	2783098	et	3	main
perekonnanimi	doc_670731433412_item	2783099	et	3	main
2005	doc_670731433412_item	2783122	et	2	main
ttü	doc_670731433412_item	2783134	et	4	main
ja	doc_670731433412_item	2783135	et	3	main
miks	doc_670731433412_item	2783136	et	4	main
majandus	doc_670731433412_item	2783137	et	4	main
kui	doc_670731433412_item	2783138	et	3	main
selle	doc_670731433410_item	2782923	et	4	main
et	doc_670731433410_item	2782925	et	3	main
tund	doc_670731433410_item	2782929	et	3	main
oli	doc_670731433410_item	2782935	et	3	main
ttüst	doc_670731433410_item	2782942	et	4	main
ttü	doc_670731433410_item	2782943	et	4	main
on	doc_670731433410_item	2782950	et	4	main
väga	doc_670731433410_item	2782951	et	3	main
sellel	doc_670731433410_item	2782953	et	4	main
palju	doc_670731433410_item	2782957	et	4	main
ja	doc_670731433410_item	2782959	et	3	main
tõttu	doc_670731433410_item	2782961	et	4	main
kasaaegne	doc_670731433410_item	2782970	et	4	main
hoone	doc_670731433410_item	2782971	et	4	main
õppida	doc_670731433410_item	2782972	et	3	main
siin	doc_670731433410_item	2782973	et	4	main
meeldiv	doc_670731433410_item	2782974	et	4	main
ma	doc_670731433410_item	2782975	et	3	main
ootan	doc_670731433410_item	2782976	et	3	main
keele	doc_670731433410_item	2782978	et	4	main
eesti	doc_670731433410_item	2782977	et	4	main
loengutelt	doc_670731433410_item	2782979	et	4	main
õppimise	doc_670731433410_item	2782980	et	4	main
grammatika	doc_670731433410_item	2782981	et	4	main
ja	doc_670731433410_item	2782982	et	3	main
palju	doc_670731433410_item	2782983	et	4	main
suhelda	doc_670731433410_item	2782984	et	4	main
ma	doc_670731433410_item	2782985	et	3	main
loodan	doc_670731433410_item	2782986	et	3	main
et	doc_670731433410_item	2782987	et	3	main
mul	doc_670731433410_item	2782988	et	3	main
mina	doc_670731433412_item	2783086	et	4	main
aastal	doc_670731433412_item	2783123	et	3	main
reaalkooli	doc_670731433412_item	2783127	et	4	main
nüüd	doc_670731433412_item	2783129	et	4	main
õpin	doc_670731433412_item	2783130	et	3	main
ttüs	doc_670731433412_item	2783131	et	4	main
tõesti	doc_670731433412_item	2783139	et	3	main
vastada	doc_670731433412_item	2783145	et	4	main
on	doc_670731433412_item	2783147	et	4	main
ma	doc_670731433412_item	2783154	et	3	main
võib	doc_670731433412_item	2783158	et	3	main
palju	doc_670731433412_item	2783164	et	4	main
on	doc_670731433412_item	2783170	et	4	main
teada	doc_670731433412_item	2783181	et	3	main
ja	doc_670731433412_item	2783206	et	3	main
läheb	doc_670731433412_item	2783211	et	3	main
tore	doc_670731433412_item	2783213	et	3	main
olla	doc_670731433412_item	2783215	et	3	main
ja	doc_670731433412_item	2783216	et	3	main
tunda	doc_670731433412_item	2783217	et	3	main
üliõpilasena	doc_670731433412_item	2783219	et	3	main
loengutest	doc_670731433412_item	2783222	et	4	main
keeles	doc_670731433412_item	2783237	et	4	main
ja	doc_670731433412_item	2783087	et	3	main
ülikool	doc_670731433412_item	2783088	et	4	main
tere	doc_670731433412_item	2783089	et	3	main
kõikidele	doc_670731433412_item	2783090	et	4	main
essee	doc_670731433412_item	2783085	et	4	main
olen	doc_670731433412_item	2783100	et	3	main
sündinud	doc_670731433412_item	2783101	et	4	main
tallinnas	doc_670731433412_item	2783102	et	4	main
paarkümmend	doc_670731433412_item	2783103	et	4	main
aastat	doc_670731433412_item	2783104	et	3	main
tagasi	doc_670731433412_item	2783105	et	3	main
olen	doc_670731433412_item	2783106	et	3	main
väga	doc_670731433412_item	2783107	et	3	main
aktiivne	doc_670731433412_item	2783108	et	3	main
väga	doc_670731433412_item	2783110	et	3	main
inimene	doc_670731433412_item	2783109	et	3	main
armastan	doc_670731433412_item	2783111	et	3	main
igasuguseid	doc_670731433412_item	2783112	et	3	main
spordialad	doc_670731433412_item	2783113	et	3	main
aga	doc_670731433412_item	2783114	et	3	main
kõige	doc_670731433412_item	2783115	et	4	main
rohkem	doc_670731433412_item	2783116	et	4	main
mulle	doc_670731433412_item	2783117	et	4	main
meeldib	doc_670731433412_item	2783118	et	3	main
jalgpall	doc_670731433412_item	2783119	et	3	main
ja	doc_670731433412_item	2783120	et	3	main
korvpall	doc_670731433412_item	2783121	et	3	main
tallinna	doc_670731433412_item	2783125	et	4	main
ja	doc_670731433412_item	2783128	et	3	main
ma	doc_670731433412_item	2783141	et	3	main
ttü	doc_670731433412_item	2783146	et	4	main
üks	doc_670731433412_item	2783148	et	3	main
valisin	doc_670731433412_item	2783155	et	3	main
juba	doc_670731433412_item	2783163	et	3	main
mul	doc_670731433412_item	2783169	et	3	main
arusaadav	doc_670731433412_item	2783179	et	4	main
loodan	doc_670731433412_item	2783207	et	3	main
kõik	doc_670731433412_item	2783210	et	4	main
hästi	doc_670731433412_item	2783212	et	3	main
eesti	doc_670731433412_item	2783236	et	4	main
lõpetasin	doc_670731433412_item	2783124	et	3	main
miks	doc_670731433412_item	2783132	et	4	main
just	doc_670731433412_item	2783133	et	3	main
täpselt	doc_670731433412_item	2783144	et	4	main
parimatest	doc_670731433412_item	2783149	et	4	main
ja	doc_670731433412_item	2783152	et	3	main
majandus	doc_670731433412_item	2783157	et	4	main
olla	doc_670731433412_item	2783159	et	3	main
et	doc_670731433412_item	2783161	et	3	main
olen	doc_670731433412_item	2783162	et	3	main
aega	doc_670731433412_item	2783165	et	4	main
huvitanud	doc_670731433412_item	2783166	et	4	main
mitu	doc_670731433412_item	2783171	et	4	main
millega	doc_670731433412_item	2783173	et	3	main
võiks	doc_670731433412_item	2783174	et	4	main
tegeleda	doc_670731433412_item	2783175	et	3	main
aga	doc_670731433412_item	2783176	et	3	main
et	doc_670731433412_item	2783177	et	3	main
olla	doc_670731433412_item	2783178	et	3	main
kuidas	doc_670731433412_item	2783182	et	3	main
seda	doc_670731433412_item	2783183	et	3	main
savutada	doc_670731433412_item	2783184	et	4	main
pean	doc_670731433412_item	2783185	et	4	main
ju	doc_670731433412_item	2783186	et	3	main
mingit	doc_670731433412_item	2783187	et	3	main
haridust	doc_670731433412_item	2783188	et	4	main
omandama	doc_670731433412_item	2783189	et	3	main
ttü	doc_670731433412_item	2783190	et	4	main
jätis	doc_670731433412_item	2783191	et	4	main
mul	doc_670731433412_item	2783192	et	3	main
päris	doc_670731433412_item	2783193	et	4	main
hea	doc_670731433412_item	2783194	et	4	main
mulje	doc_670731433412_item	2783195	et	4	main
siin	doc_670731433412_item	2783196	et	4	main
on	doc_670731433412_item	2783197	et	4	main
huvitavad	doc_670731433412_item	2783198	et	4	main
inimesed	doc_670731433412_item	2783199	et	3	main
siis	doc_670731433412_item	2783200	et	3	main
on	doc_670731433412_item	2783201	et	4	main
päris	doc_670731433412_item	2783202	et	4	main
head	doc_670731433412_item	2783203	et	4	main
võimalused	doc_670731433412_item	2783204	et	3	main
õpitamiseks	doc_670731433412_item	2783205	et	4	main
ei	doc_670731433412_item	2783142	et	4	main
eestis	doc_670731433412_item	2783151	et	3	main
sellepärast	doc_670731433412_item	2783153	et	3	main
seda	doc_670731433412_item	2783156	et	3	main
sellepärast	doc_670731433412_item	2783160	et	3	main
ja	doc_670731433412_item	2783168	et	3	main
ideed	doc_670731433412_item	2783172	et	4	main
mul	doc_670731433412_item	2783209	et	3	main
siin	doc_670731433412_item	2783214	et	4	main
ennast	doc_670731433412_item	2783218	et	4	main
eesti	doc_670731433412_item	2783220	et	4	main
et	doc_670731433412_item	2783208	et	3	main
keele	doc_670731433412_item	2783221	et	4	main
oma	doc_670731433412_item	2783227	et	4	main
suhtelda	doc_670731433412_item	2783238	et	4	main
hea	doc_670731433412_item	2783224	et	4	main
areneda	doc_670731433412_item	2783226	et	3	main
eesti	doc_670731433412_item	2783228	et	4	main
keele	doc_670731433412_item	2783229	et	4	main
oskusi	doc_670731433412_item	2783230	et	3	main
ja	doc_670731433412_item	2783231	et	3	main
loodan	doc_670731433412_item	2783232	et	3	main
et	doc_670731433412_item	2783233	et	3	main
saaks	doc_670731433412_item	2783234	et	3	main
hästi	doc_670731433412_item	2783235	et	3	main
gümnaasium	doc_670731433416_item	2783617	et	3	main
oli	doc_670731433416_item	2783620	et	3	main
väga	doc_670731433416_item	2783621	et	3	main
viimased	doc_670731433416_item	2783624	et	3	main
ma	doc_670731433416_item	2783626	et	3	main
videot	doc_670731433416_item	2783628	et	3	main
need	doc_670731433416_item	2783630	et	3	main
kõik	doc_670731433416_item	2783633	et	4	main
kes	doc_670731433416_item	2783634	et	4	main
aktusel	doc_670731433416_item	2783637	et	3	main
lõpetasin	doc_670731433416_item	2783639	et	3	main
selles	doc_670731433416_item	2783647	et	4	main
üks	doc_670731433416_item	2783649	et	3	main
ma	doc_670731433416_item	2783652	et	3	main
ajal	doc_670731433416_item	2783662	et	4	main
3d-graafikat	doc_670731433416_item	2783665	et	3	main
et	doc_670731433416_item	2783694	et	3	main
arvutid	doc_670731433416_item	2783697	et	4	main
ja	doc_670731433416_item	2783698	et	3	main
ja	doc_670731433416_item	2783708	et	3	main
seal	doc_670731433416_item	2783718	et	4	main
mida	doc_670731433416_item	2783721	et	4	main
elan	doc_670731433416_item	2783727	et	3	main
natuke	doc_670731433416_item	2783736	et	4	main
ei	doc_670731433416_item	2783737	et	4	main
on	doc_670731433416_item	2783747	et	4	main
kirjutada	doc_670731433416_item	2783752	et	3	main
annelinna	doc_670731433416_item	2783616	et	4	main
tartu	doc_670731433416_item	2783615	et	4	main
palju	doc_670731433416_item	2783622	et	4	main
sündmuseid	doc_670731433416_item	2783623	et	3	main
kõikidel	doc_670731433416_item	2783636	et	4	main
pärast	doc_670731433416_item	2783644	et	4	main
ma	doc_670731433416_item	2783645	et	3	main
töötasin	doc_670731433416_item	2783646	et	3	main
aasta	doc_670731433416_item	2783650	et	4	main
organizerin	doc_670731433416_item	2783653	et	4	main
kõik	doc_670731433416_item	2783654	et	4	main
aktused	doc_670731433416_item	2783655	et	3	main
ja	doc_670731433416_item	2783656	et	3	main
videot	doc_670731433416_item	2783658	et	3	main
ja	doc_670731433416_item	2783659	et	3	main
muusikat	doc_670731433416_item	2783660	et	3	main
mis	doc_670731433416_item	2783700	et	4	main
saab	doc_670731433416_item	2783701	et	3	main
teha	doc_670731433416_item	2783702	et	3	main
temaga	doc_670731433416_item	2783703	et	3	main
veel	doc_670731433416_item	2783704	et	4	main
ma	doc_670731433416_item	2783705	et	3	main
parandan	doc_670731433416_item	2783706	et	3	main
windowsi	doc_670731433416_item	2783707	et	4	main
palju	doc_670731433416_item	2783710	et	4	main
on	doc_670731433416_item	2783719	et	4	main
kõik	doc_670731433416_item	2783720	et	4	main
koolis	doc_670731433416_item	2783619	et	4	main
aastat	doc_670731433416_item	2783625	et	3	main
tegin	doc_670731433416_item	2783627	et	3	main
ja	doc_670731433416_item	2783629	et	3	main
videot	doc_670731433416_item	2783631	et	3	main
vaatasid	doc_670731433416_item	2783632	et	4	main
ma	doc_670731433416_item	2783638	et	3	main
2005	doc_670731433416_item	2783640	et	2	main
ja	doc_670731433416_item	2783666	et	3	main
ttu-s	doc_670731433416_item	2783691	et	3	main
mulle	doc_670731433416_item	2783695	et	4	main
meeldib	doc_670731433416_item	2783696	et	3	main
tallinna	doc_670731433416_item	2783712	et	4	main
on	doc_670731433416_item	2783722	et	4	main
mulle	doc_670731433416_item	2783735	et	4	main
ei	doc_670731433416_item	2783742	et	4	main
kõik	doc_670731433416_item	2783748	et	4	main
tahan	doc_670731433416_item	2783751	et	3	main
pärast	doc_670731433418_item	2783887	et	4	main
minu	doc_670731433418_item	2783895	et	3	main
mina	doc_670731433418_item	2783898	et	4	main
ttü-s	doc_670731433418_item	2783907	et	3	main
tasuta	doc_670731433418_item	2783908	et	4	main
meeldib	doc_670731433418_item	2783909	et	3	main
töötada	doc_670731433418_item	2783910	et	3	main
essee	doc_670731433416_item	2783599	et	4	main
mina	doc_670731433416_item	2783600	et	4	main
ja	doc_670731433416_item	2783601	et	3	main
ülikool	doc_670731433416_item	2783602	et	4	main
mina	doc_670731433416_item	2783603	et	4	main
olen	doc_670731433416_item	2783604	et	3	main
19	doc_670731433416_item	2783605	et	2	main
aastane	doc_670731433416_item	2783606	et	4	main
kõik	doc_670731433416_item	2783607	et	4	main
minu	doc_670731433416_item	2783608	et	3	main
elu	doc_670731433416_item	2783609	et	4	main
läks	doc_670731433416_item	2783610	et	3	main
tartus	doc_670731433416_item	2783611	et	3	main
ja	doc_670731433416_item	2783612	et	3	main
ma	doc_670731433416_item	2783613	et	3	main
lõpetasin	doc_670731433416_item	2783614	et	3	main
sel	doc_670731433416_item	2783618	et	3	main
oli	doc_670731433416_item	2783635	et	3	main
aastasel	doc_670731433416_item	2783641	et	4	main
selle	doc_670731433416_item	2783642	et	4	main
kooli	doc_670731433416_item	2783643	et	4	main
ma	doc_670731433416_item	2783663	et	3	main
informaatikas	doc_670731433416_item	2783690	et	3	main
pärast	doc_670731433416_item	2783693	et	4	main
kõik	doc_670731433416_item	2783699	et	4	main
tean	doc_670731433416_item	2783709	et	3	main
programme	doc_670731433416_item	2783711	et	3	main
tehnika	doc_670731433416_item	2783713	et	4	main
ülikool	doc_670731433416_item	2783714	et	4	main
praegu	doc_670731433416_item	2783728	et	3	main
remondi	doc_670731433416_item	2783744	et	4	main
mul	doc_670731433416_item	2783746	et	3	main
lõpetamist	doc_670731433418_item	2783889	et	4	main
tahaksin	doc_670731433418_item	2783890	et	3	main
astuda	doc_670731433418_item	2783891	et	3	main
ülikooli	doc_670731433418_item	2783892	et	4	main
tehnika	doc_670731433418_item	2783903	et	4	main
praegu	doc_670731433418_item	2783904	et	3	main
õpin	doc_670731433418_item	2783905	et	3	main
pärast	doc_670731433418_item	2783913	et	4	main
valiksin	doc_670731433418_item	2783914	et	3	main
just	doc_670731433418_item	2783915	et	3	main
ttü	doc_670731433418_item	2783923	et	4	main
sõpru	doc_670731433418_item	2783932	et	3	main
võimalused	doc_670731433418_item	2783944	et	3	main
seotud	doc_670731433418_item	2783954	et	4	main
kaasaegsede	doc_670731433418_item	2783955	et	4	main
loengudest	doc_670731433418_item	2783959	et	4	main
võimalust	doc_670731433418_item	2783961	et	3	main
ei	doc_670731433418_item	2783968	et	4	main
siin	doc_670731433418_item	2783979	et	4	main
ma	doc_670731433418_item	2783980	et	3	main
loodan	doc_670731433418_item	2783981	et	3	main
võimalusi	doc_670731433418_item	2783985	et	3	main
kasutada	doc_670731433418_item	2783986	et	3	main
sellepärast	doc_670731433418_item	2783991	et	3	main
võivad	doc_670731433418_item	2783994	et	4	main
essee	doc_670731433419_item	2783997	et	4	main
mina	doc_670731433419_item	2783998	et	4	main
ja	doc_670731433419_item	2783999	et	3	main
üheksateist	doc_670731433419_item	2784008	et	4	main
aastat	doc_670731433419_item	2784009	et	3	main
tagasi	doc_670731433419_item	2784010	et	3	main
tammiku	doc_670731433419_item	2784014	et	3	main
nende	doc_670731433419_item	2784023	et	4	main
ja	doc_670731433419_item	2784028	et	3	main
kohti	doc_670731433419_item	2784047	et	4	main
kus	doc_670731433419_item	2784048	et	3	main
võib	doc_670731433419_item	2784049	et	3	main
koolis	doc_670731433416_item	2783648	et	4	main
seal	doc_670731433416_item	2783651	et	4	main
tegin	doc_670731433416_item	2783657	et	3	main
vabal	doc_670731433416_item	2783661	et	3	main
tegelen	doc_670731433416_item	2783664	et	3	main
kõik	doc_670731433416_item	2783667	et	4	main
oma	doc_670731433416_item	2783668	et	4	main
on	doc_670731433416_item	2783670	et	4	main
töö	doc_670731433416_item	2783669	et	4	main
internetis	doc_670731433416_item	2783671	et	4	main
eelmisel	doc_670731433416_item	2783672	et	3	main
aastal	doc_670731433416_item	2783673	et	3	main
ma	doc_670731433416_item	2783674	et	3	main
õpisin	doc_670731433416_item	2783675	et	4	main
tartu	doc_670731433416_item	2783676	et	4	main
ülikoolis	doc_670731433416_item	2783677	et	4	main
aga	doc_670731433416_item	2783678	et	3	main
minu	doc_670731433416_item	2783679	et	3	main
eesti	doc_670731433416_item	2783680	et	4	main
keel	doc_670731433416_item	2783681	et	4	main
on	doc_670731433416_item	2783682	et	4	main
halb	doc_670731433416_item	2783683	et	3	main
ja	doc_670731433416_item	2783684	et	3	main
ma	doc_670731433416_item	2783685	et	3	main
läksin	doc_670731433416_item	2783686	et	3	main
ära	doc_670731433416_item	2783687	et	4	main
ma	doc_670731433416_item	2783688	et	3	main
valisin	doc_670731433416_item	2783689	et	3	main
selle	doc_670731433416_item	2783692	et	4	main
mulle	doc_670731433416_item	2783715	et	4	main
meeldib	doc_670731433416_item	2783716	et	3	main
et	doc_670731433416_item	2783717	et	3	main
vaja	doc_670731433416_item	2783723	et	4	main
aga	doc_670731433416_item	2783725	et	3	main
akadeemia	doc_670731433416_item	2783730	et	4	main
7	doc_670731433416_item	2783732	et	2	main
ja	doc_670731433416_item	2783733	et	3	main
seal	doc_670731433416_item	2783734	et	4	main
et	doc_670731433416_item	2783740	et	3	main
seal	doc_670731433416_item	2783741	et	4	main
praegu	doc_670731433416_item	2783745	et	3	main
mida	doc_670731433416_item	2783749	et	4	main
ma	doc_670731433416_item	2783750	et	3	main
essee	doc_670731433418_item	2783862	et	4	main
sain	doc_670731433418_item	2783885	et	3	main
valik	doc_670731433418_item	2783896	et	3	main
siin	doc_670731433418_item	2783906	et	4	main
arvuti	doc_670731433418_item	2783916	et	4	main
ja	doc_670731433418_item	2783917	et	3	main
võib	doc_670731433418_item	2783920	et	3	main
sest	doc_670731433418_item	2783927	et	4	main
see	doc_670731433418_item	2783933	et	3	main
on	doc_670731433418_item	2783935	et	4	main
suur	doc_670731433418_item	2783936	et	3	main
ja	doc_670731433418_item	2783937	et	3	main
tehniliselt	doc_670731433418_item	2783938	et	4	main
kasutada	doc_670731433418_item	2783945	et	3	main
suurt	doc_670731433418_item	2783947	et	3	main
ja	doc_670731433418_item	2783949	et	3	main
võimalusi	doc_670731433418_item	2783951	et	3	main
mida	doc_670731433418_item	2783952	et	4	main
keele	doc_670731433418_item	2783958	et	4	main
ootan	doc_670731433418_item	2783960	et	3	main
eesti	doc_670731433418_item	2783963	et	4	main
olnud	doc_670731433418_item	2783969	et	4	main
ainult	doc_670731433418_item	2783974	et	4	main
koolis	doc_670731433418_item	2783978	et	4	main
mul	doc_670731433418_item	2783982	et	3	main
olla	doc_670731433418_item	2783984	et	3	main
ja	doc_670731433418_item	2783990	et	3	main
muutuda	doc_670731433418_item	2783995	et	3	main
nimi	doc_670731433419_item	2784002	et	3	main
selles	doc_670731433419_item	2784011	et	4	main
gümnasiumit	doc_670731433419_item	2784015	et	4	main
üliõpilasele	doc_670731433416_item	2783724	et	3	main
ma	doc_670731433416_item	2783726	et	3	main
ühiselamus	doc_670731433416_item	2783729	et	4	main
tee	doc_670731433416_item	2783731	et	4	main
meldi	doc_670731433416_item	2783738	et	4	main
elada	doc_670731433416_item	2783739	et	3	main
ole	doc_670731433416_item	2783743	et	4	main
lõputunnistuse	doc_670731433418_item	2783886	et	3	main
kooli	doc_670731433418_item	2783888	et	4	main
valiksin	doc_670731433418_item	2783899	et	3	main
arvitidega	doc_670731433418_item	2783911	et	4	main
selle	doc_670731433418_item	2783912	et	4	main
süsteemitehnika	doc_670731433418_item	2783918	et	4	main
öelda	doc_670731433418_item	2783921	et	4	main
meeldib	doc_670731433418_item	2783924	et	3	main
mulle	doc_670731433418_item	2783925	et	4	main
seal	doc_670731433418_item	2783928	et	4	main
leidsin	doc_670731433418_item	2783930	et	3	main
tudengitel	doc_670731433418_item	2783942	et	3	main
arvuteid	doc_670731433418_item	2783946	et	4	main
raamatukogu	doc_670731433418_item	2783948	et	4	main
teisi	doc_670731433418_item	2783950	et	4	main
tehnoloogiatega	doc_670731433418_item	2783956	et	3	main
sest	doc_670731433418_item	2783966	et	4	main
eesti	doc_670731433418_item	2783975	et	4	main
tunnis	doc_670731433418_item	2783977	et	3	main
tihti	doc_670731433418_item	2783989	et	3	main
paremaks	doc_670731433418_item	2783996	et	4	main
aastas	doc_670731433419_item	2784012	et	3	main
palk	doc_670731433419_item	2784024	et	3	main
see	doc_670731433419_item	2784029	et	3	main
eriala	doc_670731433419_item	2784030	et	4	main
mitte	doc_670731433419_item	2784032	et	3	main
minu	doc_670731433419_item	2784035	et	3	main
huvi	doc_670731433419_item	2784036	et	4	main
saada	doc_670731433419_item	2784053	et	4	main
see	doc_670731433419_item	2784054	et	3	main
ttü	doc_670731433419_item	2784064	et	4	main
põhjus	doc_670731433419_item	2784076	et	4	main
ttü-s	doc_670731433419_item	2784079	et	3	main
leida	doc_670731433419_item	2784091	et	3	main
tööt	doc_670731433419_item	2784092	et	4	main
aga	doc_670731433419_item	2784093	et	3	main
see	doc_670731433419_item	2784094	et	3	main
ja	doc_670731433419_item	2784099	et	3	main
olla	doc_670731433419_item	2784101	et	3	main
ainult	doc_670731433419_item	2784109	et	4	main
mina	doc_670731433418_item	2783863	et	4	main
ja	doc_670731433418_item	2783864	et	3	main
ülikool	doc_670731433418_item	2783865	et	4	main
olen	doc_670731433418_item	2783866	et	3	main
päärit	doc_670731433418_item	2783867	et	4	main
naarvast	doc_670731433418_item	2783868	et	4	main
ja	doc_670731433418_item	2783869	et	3	main
lõpetasin	doc_670731433418_item	2783870	et	3	main
pähklimäe	doc_670731433418_item	2783872	et	3	main
gümnaasiumi	doc_670731433418_item	2783873	et	4	main
kus	doc_670731433418_item	2783874	et	3	main
õppisin	doc_670731433418_item	2783875	et	3	main
narva	doc_670731433418_item	2783871	et	4	main
kaksteist	doc_670731433418_item	2783876	et	4	main
aastat	doc_670731433418_item	2783877	et	3	main
võib	doc_670731433418_item	2783878	et	3	main
öelda	doc_670731433418_item	2783879	et	4	main
et	doc_670731433418_item	2783880	et	3	main
seal	doc_670731433418_item	2783881	et	4	main
õppisin	doc_670731433418_item	2783882	et	3	main
hästi	doc_670731433418_item	2783883	et	3	main
ja	doc_670731433418_item	2783884	et	3	main
ttü	doc_670731433418_item	2783893	et	4	main
oli	doc_670731433418_item	2783894	et	3	main
kus	doc_670731433418_item	2783897	et	3	main
arvuti	doc_670731433418_item	2783900	et	4	main
ja	doc_670731433418_item	2783901	et	3	main
süsteemi	doc_670731433418_item	2783902	et	4	main
eriala	doc_670731433418_item	2783919	et	4	main
uut	doc_670731433418_item	2783931	et	3	main
õppeasutus	doc_670731433418_item	2783934	et	4	main
arenenud	doc_670731433418_item	2783939	et	4	main
kus	doc_670731433418_item	2783940	et	3	main
on	doc_670731433418_item	2783953	et	4	main
eesti	doc_670731433418_item	2783957	et	4	main
õppida	doc_670731433418_item	2783962	et	3	main
ida-virumaal	doc_670731433418_item	2783967	et	4	main
keeles	doc_670731433418_item	2783973	et	4	main
keele	doc_670731433418_item	2783976	et	4	main
keelt	doc_670731433418_item	2783988	et	4	main
oskused	doc_670731433418_item	2783993	et	3	main
on	doc_670731433419_item	2784003	et	4	main
eesnimi	doc_670731433419_item	2784004	et	3	main
olen	doc_670731433419_item	2784005	et	3	main
sündinud	doc_670731433419_item	2784006	et	4	main
kohtla-järvel	doc_670731433419_item	2784007	et	4	main
lõpetasin	doc_670731433419_item	2784013	et	3	main
väike	doc_670731433419_item	2784027	et	4	main
perspektiivne	doc_670731433419_item	2784033	et	3	main
hea	doc_670731433419_item	2784050	et	4	main
arvuti	doc_670731433419_item	2784051	et	4	main
ülikool	doc_670731433419_item	2784057	et	4	main
õppimine	doc_670731433419_item	2784078	et	4	main
siin	doc_670731433419_item	2784080	et	4	main
pärast	doc_670731433419_item	2784086	et	4	main
on	doc_670731433419_item	2784095	et	4	main
lihtsalt	doc_670731433419_item	2784096	et	4	main
minu	doc_670731433419_item	2784097	et	3	main
mina	doc_670731433419_item	2784107	et	4	main
ja	doc_670731433419_item	2784112	et	3	main
mulje	doc_670731433419_item	2784114	et	4	main
huvitavad	doc_670731433419_item	2784124	et	4	main
nendega	doc_670731433419_item	2784135	et	4	main
hakkan	doc_670731433419_item	2784137	et	3	main
usuma	doc_670731433419_item	2784138	et	4	main
mitte	doc_670731433419_item	2784142	et	3	main
elu	doc_670731433420_item	2784169	et	4	main
lõpetasin	doc_670731433420_item	2784171	et	3	main
perekonnas	doc_670731433420_item	2784176	et	4	main
isa	doc_670731433420_item	2784181	et	4	main
algsin	doc_670731433420_item	2784197	et	4	main
õppida	doc_670731433420_item	2784198	et	3	main
tallinna	doc_670731433420_item	2784199	et	4	main
valisin	doc_670731433420_item	2784202	et	3	main
mulle	doc_670731433420_item	2784212	et	4	main
ja	doc_670731433420_item	2784216	et	3	main
et	doc_670731433418_item	2783922	et	3	main
väga	doc_670731433418_item	2783926	et	3	main
mina	doc_670731433418_item	2783929	et	4	main
meil	doc_670731433418_item	2783941	et	4	main
on	doc_670731433418_item	2783943	et	4	main
keelt	doc_670731433418_item	2783964	et	4	main
paremaks	doc_670731433418_item	2783965	et	4	main
võimalusi	doc_670731433418_item	2783970	et	3	main
suhelda	doc_670731433418_item	2783971	et	4	main
eesti	doc_670731433418_item	2783972	et	4	main
võib	doc_670731433418_item	2783983	et	3	main
eesti	doc_670731433418_item	2783987	et	4	main
minu	doc_670731433418_item	2783992	et	3	main
üikool	doc_670731433419_item	2784000	et	4	main
minu	doc_670731433419_item	2784001	et	3	main
kogu	doc_670731433419_item	2784016	et	4	main
elu	doc_670731433419_item	2784017	et	4	main
unustasin	doc_670731433419_item	2784018	et	3	main
olla	doc_670731433419_item	2784019	et	3	main
politseinikuna	doc_670731433419_item	2784020	et	4	main
aga	doc_670731433419_item	2784021	et	3	main
väga	doc_670731433419_item	2784026	et	3	main
on	doc_670731433419_item	2784031	et	4	main
teine	doc_670731433419_item	2784034	et	3	main
on	doc_670731433419_item	2784037	et	4	main
eestis	doc_670731433419_item	2784044	et	3	main
on	doc_670731433419_item	2784045	et	4	main
kolm	doc_670731433419_item	2784046	et	3	main
on	doc_670731433419_item	2784055	et	4	main
kõige	doc_670731433419_item	2784082	et	4	main
õpetajad	doc_670731433419_item	2784084	et	4	main
võib	doc_670731433419_item	2784100	et	3	main
kõik	doc_670731433419_item	2784102	et	4	main
ülikoolis	doc_670731433419_item	2784106	et	4	main
nädalat	doc_670731433419_item	2784111	et	3	main
esimine	doc_670731433419_item	2784113	et	4	main
on	doc_670731433419_item	2784115	et	4	main
surepärane	doc_670731433419_item	2784116	et	4	main
hooned	doc_670731433419_item	2784121	et	4	main
it	doc_670731433419_item	2784126	et	4	main
töötada	doc_670731433419_item	2784136	et	3	main
semestr	doc_670731433419_item	2784141	et	4	main
eesnimi	doc_670731433419_item	2784144	et	3	main
tallinna	doc_670731433420_item	2784172	et	4	main
mina	doc_670731433420_item	2784180	et	4	main
vend	doc_670731433420_item	2784186	et	3	main
hobbi	doc_670731433420_item	2784188	et	4	main
sport	doc_670731433420_item	2784190	et	3	main
kikpoksi	doc_670731433420_item	2784193	et	4	main
selles	doc_670731433420_item	2784194	et	4	main
aastas	doc_670731433420_item	2784195	et	3	main
ma	doc_670731433420_item	2784196	et	3	main
ja	doc_670731433420_item	2784204	et	3	main
tööta	doc_670731433420_item	2784214	et	4	main
arvutiga	doc_670731433420_item	2784215	et	4	main
minu	doc_670731433420_item	2784217	et	3	main
ma	doc_670731433420_item	2784225	et	3	main
et	doc_670731433420_item	2784235	et	3	main
ttü	doc_670731433420_item	2784236	et	4	main
on	doc_670731433420_item	2784237	et	4	main
väga	doc_670731433420_item	2784238	et	3	main
hea	doc_670731433420_item	2784239	et	4	main
ja	doc_670731433420_item	2784240	et	3	main
on	doc_670731433420_item	2784263	et	4	main
pragu	doc_670731433420_item	2784267	et	4	main
ma	doc_670731433420_item	2784268	et	3	main
keele	doc_670731433420_item	2784271	et	4	main
esse	doc_670731433420_item	2784276	et	3	main
sõna	doc_670731433420_item	2784282	et	4	main
ma	doc_670731433420_item	2784286	et	3	main
et	doc_670731433420_item	2784288	et	3	main
eesti	doc_670731433420_item	2784290	et	4	main
üks	doc_670731433420_item	2784297	et	3	main
eesti	doc_670731433420_item	2784303	et	4	main
õppima	doc_670731433420_item	2784308	et	3	main
hea	doc_670731433420_item	2784314	et	4	main
praegu	doc_670731433419_item	2784022	et	3	main
on	doc_670731433419_item	2784025	et	4	main
arvutid	doc_670731433419_item	2784038	et	4	main
ja	doc_670731433419_item	2784039	et	3	main
kõik	doc_670731433419_item	2784040	et	4	main
mida	doc_670731433419_item	2784041	et	4	main
sellega	doc_670731433419_item	2784042	et	3	main
seotud	doc_670731433419_item	2784043	et	4	main
eriala	doc_670731433419_item	2784052	et	4	main
it	doc_670731433419_item	2784058	et	4	main
koledž	doc_670731433419_item	2784059	et	2	main
ja	doc_670731433419_item	2784060	et	3	main
ttü	doc_670731433419_item	2784061	et	4	main
mina	doc_670731433419_item	2784062	et	4	main
sellepärest	doc_670731433419_item	2784065	et	4	main
selles	doc_670731433419_item	2784067	et	4	main
on	doc_670731433419_item	2784077	et	4	main
ja	doc_670731433419_item	2784085	et	3	main
ttü-st	doc_670731433419_item	2784087	et	3	main
kõige	doc_670731433419_item	2784089	et	4	main
lihtsem	doc_670731433419_item	2784090	et	4	main
mõtted	doc_670731433419_item	2784098	et	3	main
õpin	doc_670731433419_item	2784108	et	3	main
head	doc_670731433419_item	2784117	et	4	main
suured	doc_670731433419_item	2784118	et	3	main
ja	doc_670731433419_item	2784119	et	3	main
mugavad	doc_670731433419_item	2784120	et	3	main
ja	doc_670731433419_item	2784123	et	3	main
on	doc_670731433419_item	2784128	et	4	main
ja	doc_670731433419_item	2784131	et	3	main
mulle	doc_670731433419_item	2784132	et	4	main
väga	doc_670731433419_item	2784133	et	3	main
meeldib	doc_670731433419_item	2784134	et	3	main
üheksatest	doc_670731433420_item	2784156	et	4	main
gümnaasium	doc_670731433420_item	2784174	et	3	main
minu	doc_670731433420_item	2784175	et	3	main
ema	doc_670731433420_item	2784182	et	4	main
ja	doc_670731433420_item	2784183	et	3	main
mino	doc_670731433420_item	2784187	et	4	main
ma	doc_670731433420_item	2784191	et	3	main
sest	doc_670731433420_item	2784211	et	4	main
ka	doc_670731433420_item	2784220	et	3	main
see	doc_670731433420_item	2784222	et	3	main
ja	doc_670731433420_item	2784224	et	3	main
sellest	doc_670731433420_item	2784227	et	4	main
et	doc_670731433420_item	2784251	et	3	main
professorid	doc_670731433420_item	2784261	et	3	main
tõsiline	doc_670731433420_item	2784266	et	4	main
istun	doc_670731433420_item	2784269	et	3	main
see	doc_670731433420_item	2784275	et	3	main
tean	doc_670731433420_item	2784278	et	3	main
teine	doc_670731433420_item	2784281	et	3	main
on	doc_670731433420_item	2784283	et	4	main
kirjutatud	doc_670731433420_item	2784284	et	4	main
parem	doc_670731433420_item	2784294	et	4	main
kaks	doc_670731433420_item	2784310	et	3	main
on	doc_670731433422_item	2784436	et	4	main
eesnimi	doc_670731433422_item	2784437	et	3	main
ma	doc_670731433422_item	2784438	et	3	main
olin	doc_670731433422_item	2784439	et	3	main
astusin	doc_670731433422_item	2784449	et	3	main
ttüs	doc_670731433422_item	2784450	et	4	main
isa	doc_670731433422_item	2784458	et	4	main
institud	doc_670731433422_item	2784462	et	4	main
on	doc_670731433422_item	2784471	et	4	main
tähtsam	doc_670731433422_item	2784479	et	4	main
mite	doc_670731433422_item	2784490	et	4	main
ttü	doc_670731433422_item	2784500	et	4	main
imetlesin	doc_670731433422_item	2784506	et	3	main
me	doc_670731433422_item	2784509	et	4	main
palju	doc_670731433422_item	2784517	et	4	main
ained	doc_670731433422_item	2784519	et	3	main
sest	doc_670731433422_item	2784528	et	4	main
tartu	doc_670731433419_item	2784056	et	4	main
valisin	doc_670731433419_item	2784063	et	3	main
et	doc_670731433419_item	2784066	et	3	main
ülikoolis	doc_670731433419_item	2784068	et	4	main
õpivad	doc_670731433419_item	2784069	et	3	main
minu	doc_670731433419_item	2784070	et	3	main
sõbrad	doc_670731433419_item	2784071	et	3	main
ja	doc_670731433419_item	2784072	et	3	main
tuttavad	doc_670731433419_item	2784073	et	4	main
aga	doc_670731433419_item	2784074	et	3	main
teine	doc_670731433419_item	2784075	et	3	main
töötavad	doc_670731433419_item	2784081	et	4	main
paremad	doc_670731433419_item	2784083	et	4	main
on	doc_670731433419_item	2784088	et	4	main
on	doc_670731433419_item	2784103	et	4	main
teistmoodi	doc_670731433419_item	2784104	et	3	main
selles	doc_670731433419_item	2784105	et	4	main
kaks	doc_670731433419_item	2784110	et	3	main
õpetajad	doc_670731433419_item	2784125	et	4	main
kasaaegsed	doc_670731433419_item	2784129	et	4	main
esimine	doc_670731433419_item	2784140	et	4	main
viimane	doc_670731433419_item	2784143	et	3	main
mina	doc_670731433420_item	2784146	et	4	main
ülikool	doc_670731433420_item	2784148	et	4	main
minu	doc_670731433420_item	2784149	et	3	main
nimi	doc_670731433420_item	2784150	et	3	main
on	doc_670731433420_item	2784151	et	4	main
eesnimi	doc_670731433420_item	2784152	et	3	main
perekonnanimi	doc_670731433420_item	2784153	et	3	main
ma	doc_670731433420_item	2784154	et	3	main
olen	doc_670731433420_item	2784155	et	3	main
ma	doc_670731433420_item	2784170	et	3	main
läänemere	doc_670731433420_item	2784173	et	3	main
minu	doc_670731433420_item	2784184	et	3	main
ma	doc_670731433420_item	2784201	et	3	main
arvutid	doc_670731433420_item	2784203	et	4	main
vend	doc_670731433420_item	2784219	et	3	main
lõpetas	doc_670731433420_item	2784221	et	3	main
arvan	doc_670731433420_item	2784226	et	3	main
saada	doc_670731433420_item	2784252	et	4	main
hea	doc_670731433420_item	2784253	et	4	main
mis	doc_670731433420_item	2784262	et	4	main
ma	doc_670731433420_item	2784277	et	3	main
saadavad	doc_670731433420_item	2784293	et	4	main
ja	doc_670731433420_item	2784309	et	3	main
ap	doc_670731433420_item	2784311	et	4	main
ka	doc_670731433420_item	2784313	et	3	main
targad	doc_670731433419_item	2784122	et	3	main
majas	doc_670731433419_item	2784127	et	3	main
arvutid	doc_670731433419_item	2784130	et	4	main
et	doc_670731433419_item	2784139	et	3	main
essee	doc_670731433420_item	2784145	et	4	main
ja	doc_670731433420_item	2784147	et	3	main
aastat	doc_670731433420_item	2784157	et	3	main
vana	doc_670731433420_item	2784158	et	4	main
ma	doc_670731433420_item	2784159	et	3	main
sündisin	doc_670731433420_item	2784160	et	3	main
eestis	doc_670731433420_item	2784161	et	3	main
ja	doc_670731433420_item	2784163	et	3	main
tallinnas	doc_670731433420_item	2784162	et	4	main
ma	doc_670731433420_item	2784164	et	3	main
elasin	doc_670731433420_item	2784165	et	3	main
eestis	doc_670731433420_item	2784166	et	3	main
minu	doc_670731433420_item	2784167	et	3	main
kogu	doc_670731433420_item	2784168	et	4	main
on	doc_670731433420_item	2784177	et	4	main
neli	doc_670731433420_item	2784178	et	3	main
liikmeid	doc_670731433420_item	2784179	et	3	main
vanem	doc_670731433420_item	2784185	et	4	main
on	doc_670731433420_item	2784189	et	4	main
tegelen	doc_670731433420_item	2784192	et	3	main
tehnikaülikoolis	doc_670731433420_item	2784200	et	4	main
süsteemi	doc_670731433420_item	2784205	et	4	main
tehnika	doc_670731433420_item	2784206	et	4	main
ma	doc_670731433420_item	2784207	et	3	main
valisin	doc_670731433420_item	2784208	et	3	main
see	doc_670731433420_item	2784209	et	3	main
eriala	doc_670731433420_item	2784210	et	4	main
meeldib	doc_670731433420_item	2784213	et	3	main
vanem	doc_670731433420_item	2784218	et	4	main
kurs	doc_670731433420_item	2784223	et	4	main
mind	doc_670731433420_item	2784228	et	4	main
siin	doc_670731433420_item	2784229	et	4	main
võib	doc_670731433420_item	2784230	et	3	main
olla	doc_670731433420_item	2784231	et	3	main
tugev	doc_670731433420_item	2784241	et	4	main
eestis	doc_670731433420_item	2784250	et	3	main
kõrg	doc_670731433420_item	2784254	et	4	main
haridus	doc_670731433420_item	2784255	et	3	main
ka	doc_670731433420_item	2784256	et	3	main
siin	doc_670731433420_item	2784257	et	4	main
on	doc_670731433420_item	2784258	et	4	main
väga	doc_670731433420_item	2784259	et	3	main
ka	doc_670731433420_item	2784264	et	3	main
tunnis	doc_670731433420_item	2784272	et	3	main
ja	doc_670731433420_item	2784273	et	3	main
iga	doc_670731433420_item	2784280	et	4	main
viguga	doc_670731433420_item	2784285	et	4	main
loodan	doc_670731433420_item	2784287	et	3	main
minu	doc_670731433420_item	2784289	et	3	main
võimalused	doc_670731433420_item	2784292	et	3	main
pärast	doc_670731433420_item	2784296	et	4	main
aasta	doc_670731433420_item	2784298	et	4	main
kui	doc_670731433420_item	2784299	et	3	main
ma	doc_670731433420_item	2784300	et	3	main
pean	doc_670731433420_item	2784301	et	4	main
õppida	doc_670731433420_item	2784302	et	3	main
kerge	doc_670731433420_item	2784307	et	4	main
on	doc_670731433420_item	2784312	et	4	main
essee	doc_670731433422_item	2784430	et	4	main
kohtla-jarvelt	doc_670731433422_item	2784440	et	4	main
elektroenergetika	doc_670731433422_item	2784451	et	4	main
elektroenergetik	doc_670731433422_item	2784456	et	4	main
on	doc_670731433422_item	2784459	et	4	main
eriala	doc_670731433422_item	2784470	et	4	main
ja	doc_670731433422_item	2784474	et	3	main
tasustatud	doc_670731433422_item	2784476	et	4	main
algus	doc_670731433422_item	2784487	et	4	main
28	doc_670731433422_item	2784488	et	2	main
augustiks	doc_670731433422_item	2784489	et	3	main
kuigi	doc_670731433422_item	2784493	et	3	main
me	doc_670731433422_item	2784497	et	4	main
tutvusime	doc_670731433422_item	2784498	et	4	main
et	doc_670731433422_item	2784507	et	3	main
ttüs	doc_670731433422_item	2784515	et	4	main
vaba	doc_670731433422_item	2784518	et	4	main
keel	doc_670731433422_item	2784527	et	4	main
eesti	doc_670731433422_item	2784539	et	4	main
suhelda	doc_670731433422_item	2784552	et	4	main
ülikool	doc_670731433423_item	2784556	et	4	main
ainult	doc_670731433423_item	2784576	et	4	main
ainult	doc_670731433423_item	2784614	et	4	main
üks	doc_670731433423_item	2784615	et	3	main
kergem	doc_670731433420_item	2784232	et	4	main
ma	doc_670731433420_item	2784233	et	3	main
arvan	doc_670731433420_item	2784234	et	3	main
ülikool	doc_670731433420_item	2784242	et	4	main
ja	doc_670731433420_item	2784243	et	3	main
et	doc_670731433420_item	2784244	et	3	main
see	doc_670731433420_item	2784245	et	3	main
on	doc_670731433420_item	2784246	et	4	main
kõige	doc_670731433420_item	2784247	et	4	main
parem	doc_670731433420_item	2784248	et	4	main
koht	doc_670731433420_item	2784249	et	3	main
head	doc_670731433420_item	2784260	et	4	main
väga	doc_670731433420_item	2784265	et	3	main
eesti	doc_670731433420_item	2784270	et	4	main
kirjutan	doc_670731433420_item	2784274	et	3	main
et	doc_670731433420_item	2784279	et	3	main
keele	doc_670731433420_item	2784291	et	4	main
ja	doc_670731433420_item	2784295	et	3	main
keeles	doc_670731433420_item	2784304	et	4	main
mul	doc_670731433420_item	2784305	et	3	main
on	doc_670731433420_item	2784306	et	4	main
ja	doc_670731433422_item	2784432	et	3	main
lõppetan	doc_670731433422_item	2784443	et	4	main
gümnaasium	doc_670731433422_item	2784445	et	3	main
kooli	doc_670731433422_item	2784447	et	4	main
lõppetan	doc_670731433422_item	2784463	et	4	main
siis	doc_670731433422_item	2784464	et	3	main
ma	doc_670731433422_item	2784465	et	3	main
astusin	doc_670731433422_item	2784466	et	3	main
ka	doc_670731433422_item	2784467	et	3	main
hästi	doc_670731433422_item	2784475	et	3	main
see	doc_670731433422_item	2784481	et	3	main
mule	doc_670731433422_item	2784483	et	4	main
esimesel	doc_670731433422_item	2784495	et	3	main
ttüst	doc_670731433422_item	2784499	et	4	main
suur	doc_670731433422_item	2784504	et	3	main
oma	doc_670731433422_item	2784512	et	4	main
ained	doc_670731433422_item	2784513	et	3	main
aga	doc_670731433422_item	2784514	et	3	main
eesti	doc_670731433422_item	2784521	et	4	main
ttü	doc_670731433422_item	2784535	et	4	main
parem	doc_670731433422_item	2784551	et	4	main
ja	doc_670731433423_item	2784555	et	3	main
gümnaasiumi	doc_670731433423_item	2784570	et	4	main
minu	doc_670731433423_item	2784571	et	3	main
pere	doc_670731433423_item	2784572	et	4	main
minu	doc_670731433423_item	2784577	et	3	main
erialaga	doc_670731433423_item	2784606	et	3	main
töödata	doc_670731433423_item	2784609	et	4	main
firmas	doc_670731433423_item	2784610	et	3	main
temaga	doc_670731433423_item	2784611	et	3	main
aga	doc_670731433423_item	2784617	et	3	main
meeldib	doc_670731433423_item	2784622	et	3	main
ja	doc_670731433423_item	2784629	et	3	main
kellega	doc_670731433423_item	2784637	et	3	main
mõned	doc_670731433423_item	2784640	et	3	main
parem	doc_670731433423_item	2784652	et	4	main
keel	doc_670731433423_item	2784662	et	4	main
ma	doc_670731433423_item	2784667	et	3	main
öelda	doc_670731433423_item	2784670	et	4	main
pragu	doc_670731433423_item	2784672	et	4	main
ma	doc_670731433423_item	2784673	et	3	main
hästi	doc_670731433423_item	2784679	et	3	main
aga	doc_670731433423_item	2784680	et	3	main
kui	doc_670731433423_item	2784681	et	3	main
mul	doc_670731433423_item	2784700	et	3	main
kõik	doc_670731433425_item	2784833	et	4	main
s	doc_670731433425_item	2784840	et	4	main
seotud	doc_670731433425_item	2784854	et	4	main
arvan	doc_670731433425_item	2784859	et	3	main
seal	doc_670731433422_item	2784441	et	4	main
pärast	doc_670731433422_item	2784446	et	4	main
ma	doc_670731433422_item	2784448	et	3	main
fakultetis	doc_670731433422_item	2784452	et	4	main
minu	doc_670731433422_item	2784453	et	3	main
minu	doc_670731433422_item	2784457	et	3	main
ka	doc_670731433422_item	2784460	et	3	main
elektroenergetika	doc_670731433422_item	2784461	et	4	main
hea	doc_670731433422_item	2784473	et	4	main
1	doc_670731433422_item	2784491	et	2	main
on	doc_670731433422_item	2784502	et	4	main
väga	doc_670731433422_item	2784503	et	3	main
seal	doc_670731433422_item	2784508	et	4	main
peame	doc_670731433422_item	2784510	et	4	main
deklarerida	doc_670731433422_item	2784511	et	4	main
näiteks	doc_670731433422_item	2784520	et	4	main
keel	doc_670731433422_item	2784522	et	4	main
ma	doc_670731433422_item	2784523	et	3	main
tahan	doc_670731433422_item	2784524	et	3	main
deklarerida	doc_670731433422_item	2784525	et	4	main
pean	doc_670731433422_item	2784532	et	4	main
teada	doc_670731433422_item	2784533	et	3	main
kõik	doc_670731433422_item	2784534	et	4	main
praktida	doc_670731433422_item	2784544	et	4	main
eesti	doc_670731433422_item	2784545	et	4	main
keel	doc_670731433422_item	2784546	et	4	main
ma	doc_670731433422_item	2784547	et	3	main
ootan	doc_670731433422_item	2784548	et	3	main
tundidest	doc_670731433422_item	2784549	et	3	main
õpida	doc_670731433422_item	2784550	et	4	main
mina	doc_670731433423_item	2784554	et	4	main
on	doc_670731433423_item	2784559	et	4	main
ma	doc_670731433423_item	2784561	et	3	main
tallinnas	doc_670731433423_item	2784563	et	4	main
mina	doc_670731433423_item	2784613	et	4	main
siin	doc_670731433423_item	2784620	et	4	main
et	doc_670731433423_item	2784623	et	3	main
on	doc_670731433423_item	2784625	et	4	main
väga	doc_670731433423_item	2784626	et	3	main
puhtad	doc_670731433423_item	2784627	et	3	main
parkla	doc_670731433423_item	2784630	et	4	main
olemas	doc_670731433423_item	2784632	et	4	main
siin	doc_670731433423_item	2784633	et	4	main
koolist	doc_670731433423_item	2784643	et	4	main
targad	doc_670731433423_item	2784647	et	3	main
pärast	doc_670731433423_item	2784665	et	4	main
lihtselt	doc_670731433423_item	2784669	et	4	main
eestlasega	doc_670731433423_item	2784671	et	3	main
ei	doc_670731433423_item	2784674	et	4	main
tahan	doc_670731433423_item	2784683	et	3	main
siis	doc_670731433423_item	2784686	et	3	main
mina	doc_670731433422_item	2784431	et	4	main
ülikool	doc_670731433422_item	2784433	et	4	main
minu	doc_670731433422_item	2784434	et	3	main
nime	doc_670731433422_item	2784435	et	4	main
ma	doc_670731433422_item	2784442	et	3	main
slaavi	doc_670731433422_item	2784444	et	3	main
eriala	doc_670731433422_item	2784454	et	4	main
on	doc_670731433422_item	2784455	et	4	main
elektroenergetiks	doc_670731433422_item	2784468	et	4	main
see	doc_670731433422_item	2784469	et	3	main
väga	doc_670731433422_item	2784472	et	3	main
ja	doc_670731433422_item	2784477	et	3	main
kõige	doc_670731433422_item	2784478	et	4	main
et	doc_670731433422_item	2784480	et	3	main
eriala	doc_670731433422_item	2784482	et	4	main
meldib	doc_670731433422_item	2784484	et	4	main
see	doc_670731433422_item	2784485	et	3	main
simester	doc_670731433422_item	2784486	et	4	main
september	doc_670731433422_item	2784492	et	3	main
koolis	doc_670731433422_item	2784494	et	4	main
nägal	doc_670731433422_item	2784496	et	3	main
hoone	doc_670731433422_item	2784501	et	4	main
ma	doc_670731433422_item	2784505	et	3	main
olen	doc_670731433422_item	2784516	et	3	main
eesti	doc_670731433422_item	2784526	et	4	main
sühtlesi	doc_670731433422_item	2784536	et	4	main
eesti	doc_670731433422_item	2784537	et	4	main
keeles	doc_670731433422_item	2784538	et	4	main
essee	doc_670731433423_item	2784553	et	4	main
minu	doc_670731433423_item	2784557	et	3	main
eesnimi	doc_670731433423_item	2784560	et	3	main
tänavas	doc_670731433423_item	2784565	et	4	main
selles	doc_670731433423_item	2784566	et	4	main
aastas	doc_670731433423_item	2784567	et	3	main
lõpetasin	doc_670731433423_item	2784568	et	3	main
lasnamäe	doc_670731433423_item	2784569	et	3	main
ema	doc_670731433423_item	2784578	et	4	main
isa	doc_670731433423_item	2784579	et	4	main
ja	doc_670731433423_item	2784580	et	3	main
mina	doc_670731433423_item	2784581	et	4	main
isa	doc_670731433423_item	2784582	et	4	main
ja	doc_670731433423_item	2784583	et	3	main
ema	doc_670731433423_item	2784584	et	4	main
vanemad	doc_670731433423_item	2784585	et	4	main
ka	doc_670731433423_item	2784586	et	3	main
elavad	doc_670731433423_item	2784587	et	4	main
tallinnas	doc_670731433423_item	2784588	et	4	main
see	doc_670731433423_item	2784589	et	3	main
eriala	doc_670731433423_item	2784590	et	4	main
ma	doc_670731433423_item	2784591	et	3	main
valisin	doc_670731433423_item	2784592	et	3	main
sellepärast	doc_670731433423_item	2784593	et	3	main
et	doc_670731433423_item	2784594	et	3	main
isa	doc_670731433423_item	2784595	et	4	main
ütlesis	doc_670731433423_item	2784596	et	4	main
et	doc_670731433423_item	2784597	et	3	main
arvuti	doc_670731433423_item	2784598	et	4	main
ja	doc_670731433423_item	2784599	et	3	main
süsteemtehnika	doc_670731433423_item	2784600	et	4	main
on	doc_670731433423_item	2784601	et	4	main
väga	doc_670731433423_item	2784602	et	3	main
perspektiivne	doc_670731433423_item	2784603	et	3	main
eriala	doc_670731433423_item	2784604	et	4	main
selle	doc_670731433423_item	2784605	et	4	main
see	doc_670731433422_item	2784529	et	3	main
keel	doc_670731433422_item	2784530	et	4	main
ma	doc_670731433422_item	2784531	et	3	main
keele	doc_670731433422_item	2784540	et	4	main
tundides	doc_670731433422_item	2784541	et	3	main
ma	doc_670731433422_item	2784542	et	3	main
tahan	doc_670731433422_item	2784543	et	3	main
nimi	doc_670731433423_item	2784558	et	3	main
elan	doc_670731433423_item	2784562	et	3	main
paekaare	doc_670731433423_item	2784564	et	3	main
ei	doc_670731433423_item	2784573	et	4	main
ole	doc_670731433423_item	2784574	et	4	main
suur	doc_670731433423_item	2784575	et	3	main
ma	doc_670731433423_item	2784607	et	3	main
võin	doc_670731433423_item	2784608	et	3	main
mulle	doc_670731433423_item	2784621	et	4	main
ruumid	doc_670731433423_item	2784628	et	4	main
on	doc_670731433423_item	2784631	et	4	main
head	doc_670731433423_item	2784635	et	4	main
ma	doc_670731433423_item	2784638	et	3	main
on	doc_670731433423_item	2784641	et	4	main
meie	doc_670731433423_item	2784642	et	4	main
on	doc_670731433423_item	2784645	et	4	main
tehnika	doc_670731433423_item	2784653	et	4	main
siin	doc_670731433423_item	2784663	et	4	main
siis	doc_670731433423_item	2784664	et	3	main
võin	doc_670731433423_item	2784668	et	3	main
töödata	doc_670731433423_item	2784684	et	4	main
pean	doc_670731433423_item	2784688	et	4	main
riigikeelt	doc_670731433423_item	2784690	et	4	main
väga	doc_670731433423_item	2784691	et	3	main
on	doc_670731433423_item	2784701	et	4	main
essee	doc_670731433425_item	2784821	et	4	main
ülikool	doc_670731433425_item	2784824	et	4	main
olen	doc_670731433425_item	2784826	et	3	main
eesnimi	doc_670731433425_item	2784827	et	3	main
sõidsin	doc_670731433425_item	2784830	et	4	main
ma	doc_670731433425_item	2784831	et	3	main
aastat	doc_670731433425_item	2784836	et	3	main
õppisin	doc_670731433425_item	2784838	et	3	main
praegu	doc_670731433425_item	2784844	et	3	main
tallinna	doc_670731433425_item	2784846	et	4	main
tänapäevadel	doc_670731433425_item	2784848	et	3	main
arenevad	doc_670731433425_item	2784850	et	4	main
osad	doc_670731433425_item	2784851	et	3	main
millesed	doc_670731433425_item	2784852	et	4	main
arvutidega	doc_670731433425_item	2784855	et	4	main
et	doc_670731433425_item	2784860	et	3	main
esimesel	doc_670731433425_item	2784880	et	3	main
siin	doc_670731433425_item	2784891	et	4	main
vajalikud	doc_670731433425_item	2784901	et	3	main
seda	doc_670731433425_item	2784909	et	3	main
ülikoolis	doc_670731433425_item	2784925	et	4	main
armasta	doc_670731433425_item	2784939	et	4	main
tunnides	doc_670731433425_item	2784951	et	4	main
ttüs	doc_670731433423_item	2784612	et	4	main
nädal	doc_670731433423_item	2784616	et	3	main
on	doc_670731433423_item	2784634	et	4	main
väga	doc_670731433423_item	2784646	et	3	main
sest	doc_670731433423_item	2784649	et	4	main
ülikool	doc_670731433423_item	2784654	et	4	main
eestis	doc_670731433423_item	2784655	et	3	main
mina	doc_670731433423_item	2784656	et	4	main
arvan	doc_670731433423_item	2784657	et	3	main
kui	doc_670731433423_item	2784658	et	3	main
ma	doc_670731433423_item	2784659	et	3	main
õpin	doc_670731433423_item	2784660	et	3	main
eesti	doc_670731433423_item	2784661	et	4	main
ülikooli	doc_670731433423_item	2784666	et	4	main
eesti	doc_670731433423_item	2784676	et	4	main
keel	doc_670731433423_item	2784677	et	4	main
nii	doc_670731433423_item	2784678	et	3	main
ma	doc_670731433423_item	2784682	et	3	main
eestis	doc_670731433423_item	2784685	et	3	main
ma	doc_670731433423_item	2784687	et	3	main
valdama	doc_670731433423_item	2784689	et	3	main
hästi	doc_670731433423_item	2784692	et	3	main
narvast	doc_670731433425_item	2784832	et	4	main
ma	doc_670731433425_item	2784837	et	3	main
on	doc_670731433425_item	2784853	et	4	main
ma	doc_670731433425_item	2784858	et	3	main
minu	doc_670731433425_item	2784861	et	3	main
elukutse	doc_670731433425_item	2784862	et	4	main
kasulik	doc_670731433425_item	2784864	et	3	main
tulen	doc_670731433425_item	2784877	et	3	main
minu	doc_670731433425_item	2784883	et	3	main
oli	doc_670731433425_item	2784895	et	3	main
peab	doc_670731433425_item	2784904	et	4	main
loeng	doc_670731433425_item	2784906	et	3	main
ka	doc_670731433425_item	2784926	et	3	main
ole	doc_670731433425_item	2784930	et	4	main
asjat	doc_670731433425_item	2784932	et	4	main
et	doc_670731433425_item	2784933	et	3	main
juba	doc_670731433425_item	2784934	et	3	main
loengust	doc_670731433425_item	2784936	et	4	main
muljet	doc_670731433425_item	2784944	et	3	main
on	doc_670731433425_item	2784947	et	4	main
sellel	doc_670731433426_item	2784979	et	4	main
head	doc_670731433426_item	2785009	et	4	main
nõu	doc_670731433426_item	2785014	et	4	main
sul	doc_670731433426_item	2785016	et	3	main
vaja	doc_670731433426_item	2785018	et	4	main
võivad	doc_670731433426_item	2785019	et	4	main
sul	doc_670731433426_item	2785022	et	3	main
on	doc_670731433426_item	2785023	et	4	main
ma	doc_670731433426_item	2785027	et	3	main
tulin	doc_670731433426_item	2785028	et	3	main
õppima	doc_670731433426_item	2785029	et	3	main
arvan	doc_670731433426_item	2785032	et	3	main
see	doc_670731433426_item	2785034	et	3	main
tahasin	doc_670731433426_item	2785044	et	4	main
kes	doc_670731433426_item	2785063	et	4	main
ole	doc_670731433426_item	2785072	et	4	main
väga	doc_670731433426_item	2785073	et	3	main
raske	doc_670731433426_item	2785074	et	4	main
ma	doc_670731433426_item	2785079	et	3	main
väga	doc_670731433426_item	2785087	et	3	main
mulle	doc_670731433423_item	2784618	et	4	main
meeldib	doc_670731433423_item	2784619	et	3	main
siin	doc_670731433423_item	2784624	et	4	main
inimesed	doc_670731433423_item	2784636	et	3	main
õpin	doc_670731433423_item	2784639	et	3	main
siin	doc_670731433423_item	2784644	et	4	main
õpetajad	doc_670731433423_item	2784648	et	4	main
ttü	doc_670731433423_item	2784650	et	4	main
on	doc_670731433423_item	2784651	et	4	main
tea	doc_670731433423_item	2784675	et	4	main
pärast	doc_670731433423_item	2784693	et	4	main
ülikooli	doc_670731433423_item	2784694	et	4	main
ma	doc_670731433423_item	2784695	et	3	main
tahan	doc_670731433423_item	2784696	et	3	main
elada	doc_670731433423_item	2784697	et	3	main
eestis	doc_670731433423_item	2784698	et	3	main
ja	doc_670731433423_item	2784699	et	3	main
vaja	doc_670731433423_item	2784702	et	4	main
eesti	doc_670731433423_item	2784703	et	4	main
keel	doc_670731433423_item	2784704	et	4	main
need	doc_670731433425_item	2784834	et	3	main
sellepärast	doc_670731433425_item	2784857	et	3	main
on	doc_670731433425_item	2784863	et	4	main
ja	doc_670731433425_item	2784865	et	3	main
vajalik	doc_670731433425_item	2784866	et	3	main
ma	doc_670731433425_item	2784868	et	3	main
arvan	doc_670731433425_item	2784869	et	3	main
et	doc_670731433425_item	2784870	et	3	main
õppida	doc_670731433425_item	2784871	et	3	main
siin	doc_670731433425_item	2784872	et	4	main
tallinna	doc_670731433425_item	2784878	et	4	main
eelnädalal	doc_670731433425_item	2784882	et	3	main
midagi	doc_670731433425_item	2784890	et	4	main
teadsin	doc_670731433425_item	2784893	et	3	main
kus	doc_670731433425_item	2784903	et	3	main
praegu	doc_670731433425_item	2784908	et	3	main
mina	doc_670731433425_item	2784822	et	4	main
ja	doc_670731433425_item	2784823	et	3	main
ma	doc_670731433425_item	2784825	et	3	main
perekonnanimi	doc_670731433425_item	2784828	et	3	main
ning	doc_670731433425_item	2784829	et	3	main
12	doc_670731433425_item	2784835	et	2	main
narva	doc_670731433425_item	2784839	et	4	main
oldino	doc_670731433425_item	2784841	et	4	main
gümnaasiumis	doc_670731433425_item	2784842	et	3	main
aga	doc_670731433425_item	2784843	et	3	main
toimisin	doc_670731433425_item	2784845	et	3	main
tehnikaülikooli	doc_670731433425_item	2784847	et	4	main
kiiresti	doc_670731433425_item	2784849	et	3	main
ja	doc_670731433425_item	2784856	et	3	main
on	doc_670731433425_item	2784873	et	4	main
huvitav	doc_670731433425_item	2784874	et	4	main
millal	doc_670731433425_item	2784875	et	3	main
ma	doc_670731433425_item	2784876	et	3	main
mulle	doc_670731433425_item	2784894	et	4	main
arienteeruda	doc_670731433425_item	2784897	et	4	main
ja	doc_670731433425_item	2784899	et	3	main
kohad	doc_670731433425_item	2784902	et	4	main
aga	doc_670731433425_item	2784907	et	3	main
ei	doc_670731433425_item	2784911	et	4	main
mulle	doc_670731433425_item	2784914	et	4	main
kõik	doc_670731433425_item	2784915	et	4	main
rohkem	doc_670731433425_item	2784916	et	4	main
ja	doc_670731433425_item	2784917	et	3	main
rohkem	doc_670731433425_item	2784918	et	4	main
meeldib	doc_670731433425_item	2784919	et	3	main
ttüs	doc_670731433425_item	2784920	et	4	main
mulle	doc_670731433425_item	2784922	et	4	main
nendel	doc_670731433425_item	2784928	et	4	main
niisugust	doc_670731433425_item	2784931	et	3	main
esimesest	doc_670731433425_item	2784935	et	3	main
nad	doc_670731433425_item	2784937	et	3	main
ei	doc_670731433425_item	2784938	et	4	main
et	doc_670731433425_item	2784945	et	3	main
oma	doc_670731433425_item	2784955	et	4	main
eesti	doc_670731433425_item	2784956	et	4	main
keelt	doc_670731433425_item	2784957	et	4	main
oskus	doc_670731433425_item	2784958	et	3	main
teaduseid	doc_670731433425_item	2784964	et	3	main
mina	doc_670731433426_item	2784966	et	4	main
vana	doc_670731433426_item	2784978	et	4	main
hea	doc_670731433426_item	2785004	et	4	main
nad	doc_670731433426_item	2785011	et	3	main
aitada	doc_670731433426_item	2785020	et	4	main
veel	doc_670731433425_item	2784867	et	4	main
tehnikaülikooli	doc_670731433425_item	2784879	et	4	main
õpepäeval	doc_670731433425_item	2784881	et	4	main
jaoks	doc_670731433425_item	2784884	et	4	main
kõik	doc_670731433425_item	2784885	et	4	main
oli	doc_670731433425_item	2784886	et	3	main
uut	doc_670731433425_item	2784887	et	3	main
ma	doc_670731433425_item	2784888	et	3	main
mitte	doc_670731433425_item	2784889	et	3	main
ei	doc_670731433425_item	2784892	et	4	main
raske	doc_670731433425_item	2784896	et	4	main
hoonetes	doc_670731433425_item	2784898	et	4	main
leida	doc_670731433425_item	2784900	et	3	main
toimuma	doc_670731433425_item	2784905	et	3	main
probleemit	doc_670731433425_item	2784910	et	4	main
ole	doc_670731433425_item	2784912	et	4	main
ja	doc_670731433425_item	2784913	et	3	main
õppetajad	doc_670731433425_item	2784927	et	4	main
hästi	doc_670731433425_item	2784948	et	3	main
uut	doc_670731433425_item	2784963	et	3	main
üheksateist	doc_670731433426_item	2784976	et	4	main
aastat	doc_670731433426_item	2784977	et	3	main
nad	doc_670731433426_item	2785006	et	3	main
inimesed	doc_670731433426_item	2785010	et	3	main
probleemid	doc_670731433426_item	2785024	et	3	main
kõige	doc_670731433426_item	2785036	et	4	main
ja	doc_670731433426_item	2785040	et	3	main
siin	doc_670731433426_item	2785046	et	4	main
eriala	doc_670731433426_item	2785058	et	4	main
mul	doc_670731433426_item	2785059	et	3	main
ütlesid	doc_670731433426_item	2785069	et	4	main
et	doc_670731433426_item	2785070	et	3	main
ei	doc_670731433426_item	2785071	et	4	main
leia	doc_670731433426_item	2785077	et	4	main
juba	doc_670731433426_item	2785082	et	3	main
nädal	doc_670731433426_item	2785084	et	3	main
mulle	doc_670731433426_item	2785086	et	4	main
meeldib	doc_670731433426_item	2785088	et	3	main
koolis	doc_670731433426_item	2785095	et	4	main
ma	doc_670731433426_item	2785123	et	3	main
keel	doc_670731433426_item	2785137	et	4	main
peame	doc_670731433426_item	2785144	et	4	main
mina	doc_670731433427_item	2785150	et	4	main
ja	doc_670731433427_item	2785151	et	3	main
ülikool	doc_670731433427_item	2785152	et	4	main
on	doc_670731433427_item	2785155	et	4	main
eesnimi	doc_670731433427_item	2785156	et	3	main
perekonnanimi	doc_670731433427_item	2785157	et	3	main
minu	doc_670731433427_item	2785198	et	3	main
arvuti	doc_670731433427_item	2785200	et	4	main
kord	doc_670731433427_item	2785210	et	4	main
augustil	doc_670731433427_item	2785213	et	3	main
ja	doc_670731433427_item	2785214	et	3	main
juba	doc_670731433427_item	2785215	et	3	main
head	doc_670731433427_item	2785221	et	4	main
õppemine	doc_670731433427_item	2785226	et	4	main
on	doc_670731433427_item	2785227	et	4	main
meeldiv	doc_670731433427_item	2785230	et	4	main
ttü	doc_670731433427_item	2785231	et	4	main
on	doc_670731433427_item	2785233	et	4	main
väga	doc_670731433427_item	2785234	et	3	main
kaasaegne	doc_670731433427_item	2785235	et	3	main
ja	doc_670731433427_item	2785236	et	3	main
suur	doc_670731433427_item	2785237	et	3	main
mis	doc_670731433427_item	2785238	et	4	main
meeldiv	doc_670731433427_item	2785241	et	4	main
keele	doc_670731433427_item	2785243	et	4	main
eesti	doc_670731433427_item	2785246	et	4	main
küll	doc_670731433427_item	2785252	et	4	main
2	doc_670731433427_item	2785253	et	2	main
vajalike	doc_670731433427_item	2785254	et	3	main
essee	doc_670731433428_item	2785256	et	4	main
mina	doc_670731433428_item	2785266	et	4	main
astusin	doc_670731433428_item	2785267	et	3	main
ttü-sse	doc_670731433428_item	2785268	et	3	main
hea	doc_670731433428_item	2785341	et	4	main
ja	doc_670731433428_item	2785343	et	3	main
on	doc_670731433428_item	2785345	et	4	main
hea	doc_670731433428_item	2785360	et	4	main
et	doc_670731433428_item	2785363	et	3	main
võib	doc_670731433428_item	2785365	et	3	main
on	doc_670731433428_item	2785378	et	4	main
olema	doc_670731433425_item	2784921	et	4	main
meeldisid	doc_670731433425_item	2784923	et	4	main
selles	doc_670731433425_item	2784924	et	4	main
ei	doc_670731433425_item	2784929	et	4	main
meid	doc_670731433425_item	2784940	et	4	main
ja	doc_670731433425_item	2784941	et	3	main
minul	doc_670731433425_item	2784942	et	3	main
on	doc_670731433425_item	2784943	et	4	main
kõik	doc_670731433425_item	2784946	et	4	main
eesti	doc_670731433425_item	2784949	et	4	main
keele	doc_670731433425_item	2784950	et	4	main
parem	doc_670731433425_item	2784959	et	4	main
ja	doc_670731433425_item	2784960	et	3	main
nimi	doc_670731433426_item	2784970	et	3	main
on	doc_670731433426_item	2784971	et	4	main
eesnimi	doc_670731433426_item	2784972	et	3	main
perekonnanimi	doc_670731433426_item	2784973	et	3	main
ma	doc_670731433426_item	2784974	et	3	main
olen	doc_670731433426_item	2784975	et	3	main
ma	doc_670731433426_item	2784981	et	3	main
lõpetasin	doc_670731433426_item	2784982	et	3	main
tallinna	doc_670731433426_item	2784983	et	4	main
paekaare	doc_670731433426_item	2784984	et	3	main
gümnaasiumi	doc_670731433426_item	2784985	et	4	main
õppisin	doc_670731433426_item	2784987	et	3	main
ma	doc_670731433426_item	2784986	et	3	main
selles	doc_670731433426_item	2784988	et	4	main
gümnasiumis	doc_670731433426_item	2784989	et	4	main
kaksteist	doc_670731433426_item	2784990	et	4	main
aastat	doc_670731433426_item	2784991	et	3	main
mulle	doc_670731433426_item	2784992	et	4	main
meeldib	doc_670731433426_item	2784993	et	3	main
seda	doc_670731433426_item	2784994	et	3	main
gümnaasimi	doc_670731433426_item	2784995	et	4	main
seal	doc_670731433426_item	2784996	et	4	main
õpetavad	doc_670731433426_item	2784997	et	4	main
head	doc_670731433426_item	2784998	et	4	main
õpetajaid	doc_670731433426_item	2784999	et	4	main
nad	doc_670731433426_item	2785000	et	3	main
ei	doc_670731433426_item	2785001	et	4	main
ole	doc_670731433426_item	2785002	et	4	main
ainult	doc_670731433426_item	2785003	et	4	main
ma	doc_670731433425_item	2784952	et	3	main
tahaksin	doc_670731433425_item	2784953	et	3	main
teha	doc_670731433425_item	2784954	et	3	main
saada	doc_670731433425_item	2784961	et	4	main
mingeid	doc_670731433425_item	2784962	et	3	main
essee	doc_670731433426_item	2784965	et	4	main
ja	doc_670731433426_item	2784967	et	3	main
ülikool	doc_670731433426_item	2784968	et	4	main
minu	doc_670731433426_item	2784969	et	3	main
aastal	doc_670731433426_item	2784980	et	3	main
pedagoogid	doc_670731433426_item	2785005	et	3	main
on	doc_670731433426_item	2785007	et	4	main
võivad	doc_670731433426_item	2785012	et	4	main
sellel	doc_670731433426_item	2785025	et	4	main
ma	doc_670731433426_item	2785031	et	3	main
ülikool	doc_670731433426_item	2785038	et	4	main
tallinnas	doc_670731433426_item	2785039	et	4	main
kõige	doc_670731433426_item	2785041	et	4	main
rohkem	doc_670731433426_item	2785042	et	4	main
ma	doc_670731433426_item	2785043	et	3	main
hea	doc_670731433426_item	2785057	et	4	main
palju	doc_670731433426_item	2785061	et	4	main
õpetamist	doc_670731433426_item	2785076	et	4	main
ttü-s	doc_670731433426_item	2785081	et	3	main
ole	doc_670731433426_item	2785093	et	4	main
nägu	doc_670731433426_item	2785094	et	4	main
väga	doc_670731433426_item	2785098	et	3	main
nad	doc_670731433426_item	2785101	et	3	main
parem	doc_670731433426_item	2785116	et	4	main
saada	doc_670731433426_item	2785118	et	4	main
ja	doc_670731433426_item	2785119	et	3	main
veel	doc_670731433426_item	2785008	et	4	main
anda	doc_670731433426_item	2785013	et	3	main
kui	doc_670731433426_item	2785015	et	3	main
on	doc_670731433426_item	2785017	et	4	main
kui	doc_670731433426_item	2785021	et	3	main
aastal	doc_670731433426_item	2785026	et	3	main
ttü-sse	doc_670731433426_item	2785030	et	3	main
et	doc_670731433426_item	2785033	et	3	main
on	doc_670731433426_item	2785035	et	4	main
õppida	doc_670731433426_item	2785045	et	3	main
ma	doc_670731433426_item	2785047	et	3	main
väga	doc_670731433426_item	2785056	et	3	main
osakonnas	doc_670731433426_item	2785066	et	4	main
ja	doc_670731433426_item	2785067	et	3	main
nad	doc_670731433426_item	2785068	et	3	main
pärast	doc_670731433426_item	2785075	et	4	main
olen	doc_670731433426_item	2785080	et	3	main
on	doc_670731433426_item	2785097	et	4	main
auditooriumid	doc_670731433426_item	2785100	et	3	main
väga	doc_670731433426_item	2785103	et	3	main
eesti	doc_670731433426_item	2785121	et	4	main
see	doc_670731433426_item	2785126	et	3	main
ülikool	doc_670731433426_item	2785131	et	4	main
pärast	doc_670731433426_item	2785139	et	4	main
et	doc_670731433426_item	2785140	et	3	main
keeles	doc_670731433426_item	2785148	et	4	main
essee	doc_670731433427_item	2785149	et	4	main
tallinnas	doc_670731433427_item	2785160	et	4	main
ja	doc_670731433427_item	2785161	et	3	main
siin	doc_670731433427_item	2785163	et	4	main
gümnaasiumi	doc_670731433427_item	2785170	et	4	main
ja	doc_670731433427_item	2785171	et	3	main
ja	doc_670731433427_item	2785197	et	3	main
mulle	doc_670731433427_item	2785218	et	4	main
siin	doc_670731433427_item	2785220	et	4	main
väga	doc_670731433427_item	2785240	et	3	main
eesti	doc_670731433427_item	2785242	et	4	main
loengutelt	doc_670731433427_item	2785244	et	4	main
ootan	doc_670731433427_item	2785245	et	3	main
on	doc_670731433427_item	2785251	et	4	main
tehnikaülikoolis	doc_670731433428_item	2785264	et	4	main
tallinnas	doc_670731433428_item	2785272	et	4	main
aastat	doc_670731433428_item	2785275	et	3	main
saksakeele	doc_670731433428_item	2785305	et	4	main
vabalt	doc_670731433428_item	2785311	et	4	main
aga	doc_670731433428_item	2785312	et	3	main
olid	doc_670731433428_item	2785329	et	4	main
eestis	doc_670731433428_item	2785333	et	3	main
ma	doc_670731433428_item	2785335	et	3	main
et	doc_670731433428_item	2785337	et	3	main
õppejõud	doc_670731433428_item	2785342	et	4	main
tudengid	doc_670731433428_item	2785344	et	3	main
võimalus	doc_670731433428_item	2785346	et	3	main
eesti	doc_670731433428_item	2785348	et	4	main
keeles	doc_670731433428_item	2785349	et	4	main
kui	doc_670731433428_item	2785350	et	3	main
ka	doc_670731433428_item	2785351	et	3	main
aga	doc_670731433428_item	2785361	et	3	main
see	doc_670731433428_item	2785364	et	3	main
olla	doc_670731433428_item	2785367	et	3	main
kolmat	doc_670731433428_item	2785369	et	3	main
õppe	doc_670731433428_item	2785372	et	4	main
keeles	doc_670731433428_item	2785386	et	4	main
ka	doc_670731433428_item	2785398	et	3	main
ülikool	doc_670731433429_item	2785428	et	4	main
elu	doc_670731433429_item	2785443	et	4	main
vanalinna	doc_670731433429_item	2785448	et	4	main
veedan	doc_670731433429_item	2785452	et	3	main
mina	doc_670731433429_item	2785467	et	4	main
peres	doc_670731433429_item	2785469	et	3	main
on	doc_670731433429_item	2785471	et	4	main
ema	doc_670731433429_item	2785473	et	4	main
pere	doc_670731433429_item	2785481	et	4	main
me	doc_670731433429_item	2785482	et	4	main
väga	doc_670731433429_item	2785485	et	3	main
et	doc_670731433429_item	2785498	et	3	main
mina	doc_670731433429_item	2785500	et	4	main
saada	doc_670731433429_item	2785502	et	4	main
politseinikuks	doc_670731433429_item	2785503	et	4	main
juba	doc_670731433429_item	2785504	et	3	main
suvel	doc_670731433429_item	2785505	et	3	main
mul	doc_670731433429_item	2785506	et	3	main
parem	doc_670731433426_item	2785037	et	4	main
valisin	doc_670731433426_item	2785048	et	3	main
elektroenergeetika	doc_670731433426_item	2785049	et	4	main
osakonna	doc_670731433426_item	2785050	et	4	main
ma	doc_670731433426_item	2785051	et	3	main
mõtlen	doc_670731433426_item	2785052	et	3	main
et	doc_670731433426_item	2785053	et	3	main
see	doc_670731433426_item	2785054	et	3	main
on	doc_670731433426_item	2785055	et	4	main
on	doc_670731433426_item	2785060	et	4	main
tutvuseid	doc_670731433426_item	2785062	et	3	main
õpetavad	doc_670731433426_item	2785064	et	4	main
elektroenergeetika	doc_670731433426_item	2785065	et	4	main
töö	doc_670731433426_item	2785078	et	4	main
üks	doc_670731433426_item	2785083	et	3	main
ja	doc_670731433426_item	2785085	et	3	main
asutada	doc_670731433426_item	2785090	et	3	main
siin	doc_670731433426_item	2785091	et	4	main
siin	doc_670731433426_item	2785096	et	4	main
gramaatikat	doc_670731433426_item	2785115	et	4	main
keeles	doc_670731433426_item	2785122	et	4	main
väga	doc_670731433426_item	2785128	et	3	main
tore	doc_670731433426_item	2785129	et	3	main
meile	doc_670731433426_item	2785133	et	4	main
võimalusi	doc_670731433426_item	2785134	et	3	main
õpetama	doc_670731433426_item	2785135	et	3	main
järgmisel	doc_670731433426_item	2785141	et	3	main
õppima	doc_670731433426_item	2785145	et	3	main
eesti	doc_670731433426_item	2785147	et	4	main
minu	doc_670731433427_item	2785153	et	3	main
sellel	doc_670731433427_item	2785166	et	4	main
lõpetanud	doc_670731433427_item	2785168	et	4	main
lasnamäe	doc_670731433427_item	2785169	et	3	main
päeval	doc_670731433427_item	2785217	et	3	main
meeldinud	doc_670731433427_item	2785219	et	4	main
siin	doc_670731433426_item	2785089	et	4	main
ei	doc_670731433426_item	2785092	et	4	main
huvitavad	doc_670731433426_item	2785099	et	4	main
on	doc_670731433426_item	2785102	et	4	main
suured	doc_670731433426_item	2785104	et	3	main
eesti	doc_670731433426_item	2785105	et	4	main
keele	doc_670731433426_item	2785106	et	4	main
tundidelt	doc_670731433426_item	2785107	et	3	main
ma	doc_670731433426_item	2785108	et	3	main
ootan	doc_670731433426_item	2785109	et	3	main
et	doc_670731433426_item	2785110	et	3	main
ma	doc_670731433426_item	2785111	et	3	main
võiksin	doc_670731433426_item	2785112	et	3	main
parem	doc_670731433426_item	2785113	et	4	main
teada	doc_670731433426_item	2785114	et	3	main
aaru	doc_670731433426_item	2785117	et	4	main
rääkida	doc_670731433426_item	2785120	et	3	main
mõtlen	doc_670731433426_item	2785124	et	3	main
selle	doc_670731433426_item	2785138	et	4	main
me	doc_670731433426_item	2785143	et	4	main
ainult	doc_670731433426_item	2785146	et	4	main
sündinud	doc_670731433427_item	2785159	et	4	main
elasin	doc_670731433427_item	2785162	et	3	main
kogu	doc_670731433427_item	2785164	et	4	main
elav	doc_670731433427_item	2785165	et	4	main
kahekümne	doc_670731433427_item	2785211	et	4	main
kaheksandal	doc_670731433427_item	2785212	et	3	main
esimesel	doc_670731433427_item	2785216	et	3	main
hooned	doc_670731433427_item	2785222	et	4	main
menü	doc_670731433427_item	2785224	et	4	main
on	doc_670731433427_item	2785239	et	4	main
sest	doc_670731433428_item	2785269	et	4	main
ma	doc_670731433428_item	2785270	et	3	main
olen	doc_670731433428_item	2785271	et	3	main
midagi	doc_670731433428_item	2785313	et	4	main
saksamaale	doc_670731433428_item	2785320	et	4	main
saata	doc_670731433428_item	2785321	et	3	main
seda	doc_670731433428_item	2785323	et	3	main
otsustasin	doc_670731433428_item	2785325	et	3	main
vanemad	doc_670731433428_item	2785328	et	4	main
rõõmsad	doc_670731433428_item	2785330	et	3	main
ma	doc_670731433428_item	2785332	et	3	main
väga	doc_670731433428_item	2785340	et	3	main
nii	doc_670731433428_item	2785347	et	3	main
eesti	doc_670731433428_item	2785373	et	4	main
keeles	doc_670731433428_item	2785374	et	4	main
minu	doc_670731433428_item	2785375	et	3	main
hea	doc_670731433428_item	2785379	et	4	main
mul	doc_670731433428_item	2785388	et	3	main
palju	doc_670731433428_item	2785390	et	4	main
tutvu	doc_670731433428_item	2785393	et	4	main
ttü-s	doc_670731433428_item	2785394	et	3	main
õppejõuga	doc_670731433428_item	2785395	et	3	main
mul	doc_670731433428_item	2785396	et	3	main
head	doc_670731433428_item	2785399	et	4	main
mina	doc_670731433429_item	2785426	et	4	main
ja	doc_670731433429_item	2785438	et	3	main
elan	doc_670731433429_item	2785439	et	3	main
seal	doc_670731433429_item	2785440	et	4	main
mina	doc_670731433429_item	2785445	et	4	main
lõpetasin	doc_670731433429_item	2785446	et	3	main
kool	doc_670731433429_item	2785449	et	4	main
õde	doc_670731433429_item	2785474	et	4	main
ja	doc_670731433429_item	2785475	et	3	main
oma	doc_670731433429_item	2785480	et	4	main
armastame	doc_670731433429_item	2785484	et	3	main
vaatama	doc_670731433429_item	2785493	et	3	main
veel	doc_670731433429_item	2785494	et	4	main
mina	doc_670731433429_item	2785495	et	4	main
tahaksin	doc_670731433429_item	2785496	et	3	main
enne	doc_670731433429_item	2785499	et	4	main
ttü	doc_670731433429_item	2785515	et	4	main
valeksin	doc_670731433429_item	2785518	et	4	main
sellepärast	doc_670731433429_item	2785520	et	3	main
ttüs	doc_670731433429_item	2785522	et	4	main
huvitav	doc_670731433429_item	2785532	et	4	main
et	doc_670731433429_item	2785541	et	3	main
öelda	doc_670731433429_item	2785549	et	4	main
raske	doc_670731433429_item	2785559	et	4	main
elu	doc_670731433429_item	2785560	et	4	main
on	doc_670731433429_item	2785564	et	4	main
vana	doc_670731433430_item	2785575	et	4	main
et	doc_670731433426_item	2785125	et	3	main
on	doc_670731433426_item	2785127	et	4	main
et	doc_670731433426_item	2785130	et	3	main
annab	doc_670731433426_item	2785132	et	3	main
eesti	doc_670731433426_item	2785136	et	4	main
aastal	doc_670731433426_item	2785142	et	3	main
nimi	doc_670731433427_item	2785154	et	3	main
olen	doc_670731433427_item	2785158	et	3	main
aastal	doc_670731433427_item	2785167	et	3	main
käi	doc_670731433427_item	2785172	et	4	main
õppima	doc_670731433427_item	2785173	et	3	main
tallinna	doc_670731433427_item	2785174	et	4	main
tihnilise	doc_670731433427_item	2785175	et	4	main
ülikooli	doc_670731433427_item	2785176	et	4	main
ttüs	doc_670731433427_item	2785177	et	4	main
ma	doc_670731433427_item	2785178	et	3	main
olen	doc_670731433427_item	2785179	et	3	main
it	doc_670731433427_item	2785180	et	4	main
teaduskonnas	doc_670731433427_item	2785181	et	4	main
arvuti	doc_670731433427_item	2785182	et	4	main
ja	doc_670731433427_item	2785183	et	3	main
süsteemide	doc_670731433427_item	2785184	et	3	main
tehnika	doc_670731433427_item	2785185	et	4	main
erialal	doc_670731433427_item	2785186	et	3	main
valisin	doc_670731433427_item	2785187	et	3	main
see	doc_670731433427_item	2785188	et	3	main
eriala	doc_670731433427_item	2785189	et	4	main
selle	doc_670731433427_item	2785190	et	4	main
pärast	doc_670731433427_item	2785191	et	4	main
et	doc_670731433427_item	2785192	et	3	main
see	doc_670731433427_item	2785193	et	3	main
on	doc_670731433427_item	2785194	et	4	main
perspektiivne	doc_670731433427_item	2785195	et	3	main
eriala	doc_670731433427_item	2785196	et	4	main
arvates	doc_670731433427_item	2785199	et	4	main
teadused	doc_670731433427_item	2785201	et	3	main
on	doc_670731433427_item	2785202	et	4	main
väga	doc_670731433427_item	2785203	et	3	main
kasulik	doc_670731433427_item	2785204	et	3	main
tänapäevas	doc_670731433427_item	2785205	et	3	main
ma	doc_670731433427_item	2785206	et	3	main
olin	doc_670731433427_item	2785207	et	3	main
ttüs	doc_670731433427_item	2785208	et	4	main
esimene	doc_670731433427_item	2785209	et	3	main
kafees	doc_670731433427_item	2785225	et	4	main
väga	doc_670731433427_item	2785229	et	3	main
spordihall	doc_670731433427_item	2785232	et	4	main
mina	doc_670731433428_item	2785257	et	4	main
ja	doc_670731433428_item	2785258	et	3	main
ülikool	doc_670731433428_item	2785259	et	4	main
praegu	doc_670731433428_item	2785260	et	3	main
ma	doc_670731433428_item	2785261	et	3	main
õpin	doc_670731433428_item	2785262	et	3	main
tallinna	doc_670731433428_item	2785263	et	4	main
palju	doc_670731433428_item	2785274	et	4	main
oskused	doc_670731433428_item	2785306	et	3	main
ja	doc_670731433428_item	2785307	et	3	main
ma	doc_670731433428_item	2785308	et	3	main
räägin	doc_670731433428_item	2785309	et	3	main
saksakelt	doc_670731433428_item	2785310	et	3	main
liiga	doc_670731433428_item	2785317	et	4	main
hilja	doc_670731433428_item	2785318	et	3	main
dokumendid	doc_670731433428_item	2785319	et	3	main
pärast	doc_670731433428_item	2785322	et	4	main
mina	doc_670731433428_item	2785324	et	4	main
et	doc_670731433428_item	2785331	et	3	main
jäin	doc_670731433428_item	2785334	et	3	main
arvan	doc_670731433428_item	2785336	et	3	main
ttü-s	doc_670731433428_item	2785338	et	3	main
keeles	doc_670731433428_item	2785353	et	4	main
õppima	doc_670731433428_item	2785354	et	3	main
minu	doc_670731433428_item	2785355	et	3	main
eesti	doc_670731433428_item	2785356	et	4	main
keele	doc_670731433428_item	2785357	et	4	main
oskus	doc_670731433428_item	2785358	et	3	main
pärast	doc_670731433428_item	2785368	et	4	main
algab	doc_670731433428_item	2785371	et	3	main
arvates	doc_670731433428_item	2785376	et	4	main
see	doc_670731433428_item	2785377	et	3	main
sest	doc_670731433428_item	2785380	et	4	main
peab	doc_670731433428_item	2785382	et	4	main
olema	doc_670731433428_item	2785383	et	4	main
on	doc_670731433428_item	2785397	et	4	main
hea	doc_670731433427_item	2785223	et	4	main
ka	doc_670731433427_item	2785228	et	3	main
keele	doc_670731433427_item	2785247	et	4	main
oskusede	doc_670731433427_item	2785248	et	4	main
saada	doc_670731433427_item	2785249	et	4	main
ja	doc_670731433427_item	2785250	et	3	main
ap	doc_670731433427_item	2785255	et	4	main
majandust	doc_670731433428_item	2785265	et	4	main
juba	doc_670731433428_item	2785273	et	3	main
elanud	doc_670731433428_item	2785276	et	4	main
minu	doc_670731433428_item	2785277	et	3	main
vanemad	doc_670731433428_item	2785278	et	4	main
tahavad	doc_670731433428_item	2785279	et	3	main
et	doc_670731433428_item	2785280	et	3	main
ma	doc_670731433428_item	2785281	et	3	main
elasin	doc_670731433428_item	2785282	et	3	main
koos	doc_670731433428_item	2785283	et	4	main
nendega	doc_670731433428_item	2785284	et	4	main
aga	doc_670731433428_item	2785285	et	3	main
varem	doc_670731433428_item	2785286	et	4	main
olid	doc_670731433428_item	2785287	et	4	main
mul	doc_670731433428_item	2785288	et	3	main
teised	doc_670731433428_item	2785289	et	4	main
plaanid	doc_670731433428_item	2785290	et	4	main
pärast	doc_670731433428_item	2785291	et	4	main
kooli	doc_670731433428_item	2785292	et	4	main
lõpetamist	doc_670731433428_item	2785293	et	4	main
ma	doc_670731433428_item	2785294	et	3	main
tahaksin	doc_670731433428_item	2785295	et	3	main
saksamaale	doc_670731433428_item	2785296	et	4	main
sõita	doc_670731433428_item	2785297	et	3	main
ja	doc_670731433428_item	2785298	et	3	main
seal	doc_670731433428_item	2785299	et	4	main
õppima	doc_670731433428_item	2785300	et	3	main
mul	doc_670731433428_item	2785301	et	3	main
on	doc_670731433428_item	2785302	et	4	main
väga	doc_670731433428_item	2785303	et	3	main
head	doc_670731433428_item	2785304	et	4	main
ei	doc_670731433428_item	2785314	et	4	main
klappinud	doc_670731433428_item	2785315	et	4	main
oli	doc_670731433428_item	2785316	et	3	main
ttü-s	doc_670731433428_item	2785326	et	3	main
õppida	doc_670731433428_item	2785327	et	3	main
on	doc_670731433428_item	2785339	et	4	main
vene	doc_670731433428_item	2785352	et	4	main
on	doc_670731433428_item	2785359	et	4	main
arvan	doc_670731433428_item	2785362	et	3	main
parem	doc_670731433428_item	2785366	et	4	main
semestrit	doc_670731433428_item	2785370	et	3	main
haridus	doc_670731433428_item	2785384	et	3	main
eesti	doc_670731433428_item	2785385	et	4	main
sõpru	doc_670731433428_item	2785391	et	3	main
suhted	doc_670731433428_item	2785400	et	3	main
olen	doc_670731433428_item	2785401	et	3	main
kindel	doc_670731433428_item	2785402	et	3	main
et	doc_670731433428_item	2785403	et	3	main
olen	doc_670731433428_item	2785404	et	3	main
õigel	doc_670731433428_item	2785405	et	3	main
haridusteel	doc_670731433428_item	2785406	et	3	main
pärast	doc_670731433428_item	2785407	et	4	main
ülikooli	doc_670731433428_item	2785408	et	4	main
lõpetamist	doc_670731433428_item	2785409	et	4	main
tahan	doc_670731433428_item	2785410	et	3	main
oma	doc_670731433428_item	2785411	et	4	main
firmat	doc_670731433428_item	2785412	et	3	main
avaneda	doc_670731433428_item	2785413	et	3	main
ja	doc_670731433428_item	2785414	et	3	main
palju	doc_670731433428_item	2785415	et	4	main
raha	doc_670731433428_item	2785416	et	4	main
olen	doc_670731433428_item	2785418	et	3	main
kindel	doc_670731433428_item	2785419	et	3	main
et	doc_670731433428_item	2785420	et	3	main
teenida	doc_670731433428_item	2785417	et	3	main
oma	doc_670731433428_item	2785422	et	4	main
realiseerida	doc_670731433428_item	2785424	et	3	main
essee	doc_670731433429_item	2785425	et	4	main
nimi	doc_670731433429_item	2785430	et	3	main
eesnimi	doc_670731433429_item	2785432	et	3	main
kõik	doc_670731433429_item	2785441	et	4	main
sillamäe	doc_670731433429_item	2785447	et	3	main
ujumisega	doc_670731433429_item	2785463	et	4	main
ja	doc_670731433429_item	2785464	et	3	main
mina	doc_670731433429_item	2785477	et	4	main
väga	doc_670731433429_item	2785478	et	3	main
koos	doc_670731433429_item	2785491	et	4	main
tellerit	doc_670731433429_item	2785492	et	3	main
öelda	doc_670731433429_item	2785497	et	4	main
või	doc_670731433429_item	2785514	et	4	main
mina	doc_670731433429_item	2785517	et	4	main
ttü	doc_670731433429_item	2785519	et	4	main
eestimaal	doc_670731433428_item	2785381	et	4	main
praegu	doc_670731433428_item	2785387	et	3	main
on	doc_670731433428_item	2785389	et	4	main
ja	doc_670731433428_item	2785392	et	3	main
saan	doc_670731433428_item	2785421	et	4	main
plaanid	doc_670731433428_item	2785423	et	4	main
minu	doc_670731433429_item	2785429	et	3	main
mina	doc_670731433429_item	2785434	et	4	main
oma	doc_670731433429_item	2785442	et	4	main
aega	doc_670731433429_item	2785451	et	4	main
edasi	doc_670731433429_item	2785466	et	3	main
elan	doc_670731433429_item	2785468	et	3	main
see	doc_670731433429_item	2785470	et	3	main
isa	doc_670731433429_item	2785472	et	4	main
armastan	doc_670731433429_item	2785479	et	3	main
väga	doc_670731433429_item	2785483	et	3	main
pere	doc_670731433429_item	2785486	et	4	main
ringis	doc_670731433429_item	2785487	et	4	main
õhtul	doc_670731433429_item	2785488	et	3	main
tahaksin	doc_670731433429_item	2785501	et	3	main
et	doc_670731433429_item	2785521	et	3	main
energetika	doc_670731433429_item	2785524	et	4	main
palk	doc_670731433429_item	2785536	et	3	main
ja	doc_670731433429_item	2785537	et	3	main
mina	doc_670731433429_item	2785539	et	4	main
elu	doc_670731433429_item	2785543	et	4	main
parem	doc_670731433429_item	2785545	et	4	main
lõpetuteks	doc_670731433429_item	2785547	et	4	main
et	doc_670731433429_item	2785550	et	3	main
tulevikus	doc_670731433429_item	2785552	et	4	main
see	doc_670731433429_item	2785563	et	3	main
tore	doc_670731433429_item	2785565	et	3	main
mina	doc_670731433430_item	2785567	et	4	main
ja	doc_670731433430_item	2785568	et	3	main
ülikool	doc_670731433430_item	2785569	et	4	main
minu	doc_670731433430_item	2785570	et	3	main
nimi	doc_670731433430_item	2785571	et	3	main
eesnimi	doc_670731433430_item	2785572	et	3	main
20	doc_670731433430_item	2785573	et	2	main
kool	doc_670731433430_item	2785578	et	4	main
oli	doc_670731433430_item	2785594	et	3	main
seal	doc_670731433430_item	2785599	et	4	main
jalgpalliga	doc_670731433430_item	2785624	et	3	main
olen	doc_670731433430_item	2785630	et	3	main
oma	doc_670731433430_item	2785641	et	4	main
avaldus	doc_670731433430_item	2785642	et	4	main
ja	doc_670731433430_item	2785643	et	3	main
energeetika	doc_670731433430_item	2785650	et	4	main
elab	doc_670731433430_item	2785655	et	3	main
on	doc_670731433430_item	2785659	et	4	main
saamodi	doc_670731433430_item	2785661	et	4	main
kõrgharidus	doc_670731433430_item	2785662	et	3	main
on	doc_670731433430_item	2785663	et	4	main
väga	doc_670731433430_item	2785664	et	3	main
mida	doc_670731433430_item	2785669	et	4	main
kohta	doc_670731433430_item	2785672	et	4	main
meie	doc_670731433430_item	2785709	et	4	main
riigi	doc_670731433430_item	2785710	et	3	main
parem	doc_670731433430_item	2785719	et	4	main
vaja	doc_670731433430_item	2785720	et	4	main
õppida	doc_670731433430_item	2785721	et	3	main
sellega	doc_670731433430_item	2785724	et	3	main
siin	doc_670731433430_item	2785726	et	4	main
tagasi	doc_670731433431_item	2785735	et	3	main
õppisin	doc_670731433431_item	2785740	et	3	main
kaksteist	doc_670731433431_item	2785743	et	4	main
aastat	doc_670731433431_item	2785744	et	3	main
üks	doc_670731433431_item	2785745	et	3	main
etapp	doc_670731433431_item	2785746	et	3	main
on	doc_670731433431_item	2785747	et	4	main
väga	doc_670731433431_item	2785756	et	3	main
kuhu	doc_670731433431_item	2785774	et	3	main
minna	doc_670731433431_item	2785776	et	3	main
tahavad	doc_670731433431_item	2785778	et	3	main
saada	doc_670731433431_item	2785780	et	4	main
filoologiks	doc_670731433431_item	2785790	et	4	main
ja	doc_670731433431_item	2785792	et	3	main
tallinna	doc_670731433431_item	2785793	et	4	main
õppida	doc_670731433431_item	2785795	et	3	main
aastat	doc_670731433431_item	2785807	et	3	main
tagasi	doc_670731433431_item	2785808	et	3	main
mina	doc_670731433431_item	2785809	et	4	main
tulen	doc_670731433431_item	2785813	et	3	main
ja	doc_670731433429_item	2785427	et	3	main
on	doc_670731433429_item	2785431	et	4	main
perekonnanimi	doc_670731433429_item	2785433	et	3	main
sündin	doc_670731433429_item	2785435	et	4	main
sillamäe	doc_670731433429_item	2785436	et	3	main
linnas	doc_670731433429_item	2785437	et	4	main
seal	doc_670731433429_item	2785444	et	4	main
palju	doc_670731433429_item	2785450	et	4	main
spordi	doc_670731433429_item	2785453	et	4	main
saalis	doc_670731433429_item	2785454	et	4	main
mina	doc_670731433429_item	2785455	et	4	main
tegelesin	doc_670731433429_item	2785456	et	3	main
hea	doc_670731433429_item	2785457	et	4	main
meelega	doc_670731433429_item	2785458	et	4	main
kick	doc_670731433429_item	2785459	et	4	main
boksinguga	doc_670731433429_item	2785460	et	4	main
kergejõustikuga	doc_670731433429_item	2785461	et	3	main
boksiga	doc_670731433429_item	2785462	et	3	main
nii	doc_670731433429_item	2785465	et	3	main
mind	doc_670731433429_item	2785476	et	4	main
räkima	doc_670731433429_item	2785489	et	4	main
naerma	doc_670731433429_item	2785490	et	3	main
siis	doc_670731433429_item	2785516	et	3	main
eriala	doc_670731433429_item	2785523	et	4	main
mulle	doc_670731433429_item	2785525	et	4	main
eriala	doc_670731433429_item	2785531	et	4	main
stabiilne	doc_670731433429_item	2785535	et	3	main
mind	doc_670731433429_item	2785553	et	4	main
ootab	doc_670731433429_item	2785554	et	3	main
väga	doc_670731433429_item	2785555	et	3	main
ja	doc_670731433429_item	2785562	et	3	main
essee	doc_670731433430_item	2785566	et	4	main
olen	doc_670731433430_item	2785576	et	3	main
kooli	doc_670731433430_item	2785589	et	4	main
läks	doc_670731433430_item	2785590	et	3	main
sõpradega	doc_670731433430_item	2785591	et	3	main
sõjaväes	doc_670731433430_item	2785592	et	3	main
teenistus	doc_670731433430_item	2785593	et	3	main
divisionis	doc_670731433430_item	2785598	et	4	main
kuud	doc_670731433430_item	2785602	et	4	main
tuli	doc_670731433430_item	2785605	et	4	main
sõpradega	doc_670731433430_item	2785622	et	3	main
mängin	doc_670731433430_item	2785625	et	3	main
10	doc_670731433430_item	2785627	et	2	main
et	doc_670731433430_item	2785646	et	3	main
on	doc_670731433430_item	2785648	et	4	main
huvitav	doc_670731433430_item	2785649	et	4	main
kui	doc_670731433430_item	2785654	et	3	main
energia	doc_670731433430_item	2785658	et	4	main
kohustuslik	doc_670731433430_item	2785660	et	3	main
ttü	doc_670731433430_item	2785671	et	4	main
meie	doc_670731433430_item	2785675	et	4	main
pealinnas	doc_670731433430_item	2785706	et	4	main
kui	doc_670731433430_item	2785715	et	3	main
siis	doc_670731433430_item	2785717	et	3	main
õppida	doc_670731433430_item	2785723	et	3	main
terve	doc_670731433430_item	2785727	et	4	main
essee	doc_670731433431_item	2785729	et	4	main
mina	doc_670731433431_item	2785730	et	4	main
ja	doc_670731433431_item	2785731	et	3	main
kooli	doc_670731433431_item	2785738	et	4	main
selles	doc_670731433431_item	2785741	et	4	main
lõpetas	doc_670731433431_item	2785752	et	3	main
ka	doc_670731433431_item	2785753	et	3	main
lõpuõhtu	doc_670731433431_item	2785754	et	4	main
saada	doc_670731433431_item	2785772	et	4	main
keelte	doc_670731433431_item	2785789	et	3	main
saada	doc_670731433431_item	2785791	et	4	main
mina	doc_670731433431_item	2785805	et	4	main
kolm	doc_670731433431_item	2785806	et	3	main
õppida	doc_670731433431_item	2785814	et	3	main
et	doc_670731433431_item	2785824	et	3	main
ta	doc_670731433431_item	2785832	et	4	main
jutustas	doc_670731433431_item	2785833	et	3	main
käis	doc_670731433431_item	2785842	et	4	main
seest	doc_670731433431_item	2785848	et	3	main
teadnud	doc_670731433431_item	2785852	et	4	main
olid	doc_670731433431_item	2785857	et	4	main
õppima	doc_670731433431_item	2785861	et	3	main
väga	doc_670731433431_item	2785864	et	3	main
aga	doc_670731433431_item	2785868	et	3	main
on	doc_670731433431_item	2785882	et	4	main
elus	doc_670731433431_item	2785886	et	4	main
midagi	doc_670731433431_item	2785889	et	4	main
ma	doc_670731433431_item	2785891	et	3	main
palju	doc_670731433431_item	2785899	et	4	main
tund	doc_670731433431_item	2785921	et	3	main
uued	doc_670731433431_item	2785933	et	3	main
mulle	doc_670731433431_item	2785936	et	4	main
see	doc_670731433431_item	2785938	et	3	main
sa	doc_670731433431_item	2785942	et	3	main
õppimist	doc_670731433431_item	2785944	et	4	main
mulle	doc_670731433431_item	2785952	et	4	main
meeldib	doc_670731433431_item	2785953	et	3	main
väga	doc_670731433431_item	2785954	et	3	main
on	doc_670731433431_item	2785959	et	4	main
oli	doc_670731433429_item	2785507	et	3	main
niisugune	doc_670731433429_item	2785508	et	3	main
valik	doc_670731433429_item	2785509	et	3	main
kas	doc_670731433429_item	2785510	et	3	main
politsei	doc_670731433429_item	2785511	et	4	main
akademiasse	doc_670731433429_item	2785512	et	4	main
minna	doc_670731433429_item	2785513	et	3	main
töö	doc_670731433429_item	2785533	et	4	main
üldse	doc_670731433429_item	2785538	et	3	main
tudente	doc_670731433429_item	2785542	et	4	main
on	doc_670731433429_item	2785544	et	4	main
tahan	doc_670731433429_item	2785548	et	3	main
astat	doc_670731433430_item	2785574	et	4	main
oli	doc_670731433430_item	2785579	et	3	main
2005	doc_670731433430_item	2785581	et	2	main
see	doc_670731433430_item	2785583	et	3	main
narva	doc_670731433430_item	2785585	et	4	main
pähklimäe	doc_670731433430_item	2785586	et	3	main
gümnaasium	doc_670731433430_item	2785587	et	3	main
pärast	doc_670731433430_item	2785588	et	4	main
suvi	doc_670731433430_item	2785603	et	3	main
dembel	doc_670731433430_item	2785607	et	4	main
kohe	doc_670731433430_item	2785610	et	4	main
läks	doc_670731433430_item	2785611	et	3	main
töötama	doc_670731433430_item	2785612	et	3	main
töötasin	doc_670731433430_item	2785613	et	3	main
oma	doc_670731433430_item	2785614	et	4	main
soobib	doc_670731433429_item	2785526	et	4	main
parem	doc_670731433429_item	2785527	et	4	main
see	doc_670731433429_item	2785528	et	3	main
on	doc_670731433429_item	2785529	et	4	main
huvitav	doc_670731433429_item	2785530	et	4	main
ja	doc_670731433429_item	2785534	et	3	main
arvan	doc_670731433429_item	2785540	et	3	main
ttüs	doc_670731433429_item	2785546	et	4	main
mõtlen	doc_670731433429_item	2785551	et	3	main
huvitav	doc_670731433429_item	2785556	et	4	main
ja	doc_670731433429_item	2785557	et	3	main
muidugi	doc_670731433429_item	2785558	et	4	main
ttüs	doc_670731433429_item	2785561	et	4	main
narvast	doc_670731433430_item	2785577	et	4	main
lõpetanud	doc_670731433430_item	2785580	et	4	main
oli	doc_670731433430_item	2785584	et	3	main
õhutõrje	doc_670731433430_item	2785597	et	4	main
oli	doc_670731433430_item	2785600	et	3	main
alguses	doc_670731433430_item	2785604	et	4	main
reserv	doc_670731433430_item	2785606	et	3	main
seda	doc_670731433430_item	2785609	et	3	main
onuga	doc_670731433430_item	2785615	et	3	main
tegime	doc_670731433430_item	2785616	et	3	main
euroremontid	doc_670731433430_item	2785617	et	4	main
muidugi	doc_670731433430_item	2785618	et	4	main
vabal	doc_670731433430_item	2785619	et	3	main
ajal	doc_670731433430_item	2785620	et	4	main
puhkasin	doc_670731433430_item	2785621	et	3	main
aastat	doc_670731433430_item	2785628	et	3	main
eriala	doc_670731433430_item	2785636	et	4	main
lihtsalt	doc_670731433430_item	2785639	et	4	main
panin	doc_670731433430_item	2785640	et	3	main
siin	doc_670731433430_item	2785647	et	4	main
on	doc_670731433430_item	2785651	et	4	main
tugev	doc_670731433430_item	2785652	et	4	main
asi	doc_670731433430_item	2785653	et	4	main
tähtisam	doc_670731433430_item	2785665	et	4	main
asi	doc_670731433430_item	2785666	et	4	main
suur	doc_670731433430_item	2785673	et	3	main
on	doc_670731433430_item	2785718	et	4	main
a	doc_670731433430_item	2785582	et	4	main
tapa	doc_670731433430_item	2785595	et	4	main
linnas	doc_670731433430_item	2785596	et	4	main
11	doc_670731433430_item	2785601	et	2	main
pärast	doc_670731433430_item	2785608	et	4	main
tegelesime	doc_670731433430_item	2785623	et	3	main
ttüs	doc_670731433430_item	2785632	et	4	main
miks	doc_670731433430_item	2785633	et	4	main
valin	doc_670731433430_item	2785634	et	3	main
see	doc_670731433430_item	2785635	et	3	main
kõik	doc_670731433430_item	2785644	et	4	main
inimene	doc_670731433430_item	2785656	et	3	main
meie	doc_670731433430_item	2785667	et	4	main
elus	doc_670731433430_item	2785668	et	4	main
keel	doc_670731433430_item	2785711	et	4	main
peame	doc_670731433430_item	2785712	et	4	main
oskama	doc_670731433430_item	2785713	et	3	main
suhtlema	doc_670731433430_item	2785714	et	3	main
ülikool	doc_670731433431_item	2785732	et	4	main
neli	doc_670731433431_item	2785733	et	3	main
kuu	doc_670731433431_item	2785734	et	4	main
lõpetasin	doc_670731433431_item	2785737	et	3	main
läinud	doc_670731433431_item	2785748	et	4	main
läbi	doc_670731433431_item	2785749	et	4	main
ja	doc_670731433431_item	2785750	et	3	main
lapsepõlv	doc_670731433431_item	2785751	et	3	main
ja	doc_670731433431_item	2785773	et	3	main
ühed	doc_670731433431_item	2785777	et	3	main
arstiks	doc_670731433431_item	2785779	et	4	main
ja	doc_670731433431_item	2785781	et	3	main
tartu	doc_670731433431_item	2785782	et	4	main
ülikoolis	doc_670731433431_item	2785783	et	4	main
õppida	doc_670731433431_item	2785784	et	3	main
aga	doc_670731433431_item	2785796	et	3	main
tahavad	doc_670731433431_item	2785798	et	3	main
ma	doc_670731433431_item	2785812	et	3	main
tallinna	doc_670731433431_item	2785815	et	4	main
olin	doc_670731433431_item	2785821	et	3	main
minu	doc_670731433431_item	2785825	et	3	main
keele	doc_670731433431_item	2785827	et	4	main
õpetaja	doc_670731433431_item	2785828	et	4	main
lõpetas	doc_670731433431_item	2785829	et	3	main
aga	doc_670731433431_item	2785837	et	3	main
ringi	doc_670731433431_item	2785843	et	4	main
see	doc_670731433431_item	2785844	et	3	main
oli	doc_670731433431_item	2785845	et	3	main
nagu	doc_670731433431_item	2785846	et	3	main
revolutsioon	doc_670731433431_item	2785847	et	3	main
ma	doc_670731433431_item	2785850	et	3	main
mul	doc_670731433431_item	2785856	et	3	main
nagu	doc_670731433431_item	2785859	et	3	main
mul	doc_670731433431_item	2785862	et	3	main
suur	doc_670731433431_item	2785865	et	3	main
õppida	doc_670731433431_item	2785867	et	3	main
läksin	doc_670731433431_item	2785870	et	3	main
elu	doc_670731433431_item	2785873	et	4	main
on	doc_670731433431_item	2785875	et	4	main
kõige	doc_670731433431_item	2785876	et	4	main
huvitavam	doc_670731433431_item	2785877	et	4	main
ja	doc_670731433431_item	2785878	et	3	main
etapp	doc_670731433431_item	2785884	et	3	main
ma	doc_670731433431_item	2785887	et	3	main
otsustasin	doc_670731433431_item	2785894	et	3	main
tahan	doc_670731433431_item	2785896	et	3	main
juba	doc_670731433430_item	2785626	et	3	main
nüüd	doc_670731433430_item	2785629	et	4	main
siin	doc_670731433430_item	2785631	et	4	main
ei	doc_670731433430_item	2785637	et	4	main
tea	doc_670731433430_item	2785638	et	4	main
loodan	doc_670731433430_item	2785645	et	3	main
siis	doc_670731433430_item	2785657	et	3	main
öölda	doc_670731433430_item	2785670	et	4	main
hoon	doc_670731433430_item	2785674	et	3	main
korpus	doc_670731433430_item	2785676	et	4	main
on	doc_670731433430_item	2785677	et	4	main
kõige	doc_670731433430_item	2785678	et	4	main
sest	doc_670731433430_item	2785680	et	4	main
ilusam	doc_670731433430_item	2785679	et	4	main
see	doc_670731433430_item	2785681	et	3	main
on	doc_670731433430_item	2785682	et	4	main
uus	doc_670731433430_item	2785683	et	3	main
hoone	doc_670731433430_item	2785684	et	4	main
päris	doc_670731433430_item	2785685	et	4	main
palju	doc_670731433430_item	2785686	et	4	main
sõbrat	doc_670731433430_item	2785687	et	4	main
siin	doc_670731433430_item	2785688	et	4	main
ilusad	doc_670731433430_item	2785689	et	3	main
naised	doc_670731433430_item	2785690	et	3	main
see	doc_670731433430_item	2785691	et	3	main
on	doc_670731433430_item	2785692	et	4	main
tore	doc_670731433430_item	2785693	et	3	main
meeldib	doc_670731433430_item	2785694	et	3	main
ka	doc_670731433430_item	2785695	et	3	main
seda	doc_670731433430_item	2785696	et	3	main
et	doc_670731433430_item	2785697	et	3	main
ttü	doc_670731433430_item	2785698	et	4	main
asub	doc_670731433430_item	2785699	et	3	main
tallinnas	doc_670731433430_item	2785700	et	4	main
muidugi	doc_670731433430_item	2785701	et	4	main
meeldib	doc_670731433430_item	2785702	et	3	main
olla	doc_670731433430_item	2785703	et	3	main
ja	doc_670731433430_item	2785704	et	3	main
õppida	doc_670731433430_item	2785705	et	3	main
eesti	doc_670731433430_item	2785707	et	4	main
keel	doc_670731433430_item	2785708	et	4	main
parem	doc_670731433430_item	2785716	et	4	main
tund	doc_670731433430_item	2785728	et	3	main
ma	doc_670731433431_item	2785736	et	3	main
koolis	doc_670731433431_item	2785742	et	4	main
oli	doc_670731433431_item	2785755	et	3	main
ülikoolis	doc_670731433431_item	2785794	et	4	main
mõned	doc_670731433431_item	2785797	et	3	main
tallinna	doc_670731433431_item	2785799	et	4	main
majandusteaduskonnas	doc_670731433431_item	2785801	et	4	main
õppida	doc_670731433431_item	2785802	et	3	main
see	doc_670731433431_item	2785803	et	3	main
on	doc_670731433431_item	2785804	et	4	main
planeerisin	doc_670731433431_item	2785810	et	3	main
et	doc_670731433431_item	2785811	et	3	main
tehnikaülikoolisse	doc_670731433431_item	2785816	et	4	main
sellepärast	doc_670731433431_item	2785823	et	3	main
inglise	doc_670731433431_item	2785826	et	4	main
oma	doc_670731433431_item	2785835	et	4	main
pärast	doc_670731433431_item	2785838	et	4	main
kooli	doc_670731433431_item	2785839	et	4	main
minu	doc_670731433431_item	2785840	et	3	main
et	doc_670731433431_item	2785849	et	3	main
ma	doc_670731433431_item	2785854	et	3	main
minu	doc_670731433431_item	2785885	et	3	main
mõtlesin	doc_670731433431_item	2785892	et	3	main
õppida	doc_670731433431_item	2785898	et	3	main
sõpru	doc_670731433431_item	2785900	et	3	main
ja	doc_670731433431_item	2785922	et	3	main
ja	doc_670731433431_item	2785925	et	3	main
kirjutan	doc_670731433431_item	2785926	et	3	main
palju	doc_670731433431_item	2785928	et	4	main
uusi	doc_670731433431_item	2785929	et	3	main
inimesi	doc_670731433431_item	2785930	et	4	main
ja	doc_670731433431_item	2785931	et	3	main
mis	doc_670731433431_item	2785935	et	4	main
meeldivad	doc_670731433431_item	2785937	et	4	main
õpin	doc_670731433431_item	2785957	et	3	main
veel	doc_670731433431_item	2785968	et	4	main
kord	doc_670731433431_item	2785990	et	4	main
õppima	doc_670731433431_item	2785991	et	3	main
ülikool	doc_670731433432_item	2785995	et	4	main
olen	doc_670731433432_item	2785997	et	3	main
sellisel	doc_670731433432_item	2786001	et	4	main
lõppesin	doc_670731433432_item	2786004	et	3	main
paekaare	doc_670731433432_item	2786007	et	3	main
see	doc_670731433432_item	2786009	et	3	main
me	doc_670731433432_item	2786014	et	4	main
hästi	doc_670731433432_item	2786023	et	3	main
ülikooli	doc_670731433432_item	2786029	et	4	main
õppima	doc_670731433432_item	2786030	et	3	main
loodan	doc_670731433432_item	2786031	et	3	main
et	doc_670731433432_item	2786032	et	3	main
ülikoolis	doc_670731433432_item	2786033	et	4	main
oleks	doc_670731433432_item	2786034	et	3	main
parem	doc_670731433432_item	2786035	et	4	main
kui	doc_670731433432_item	2786036	et	3	main
ma	doc_670731433432_item	2786044	et	3	main
koht	doc_670731433432_item	2786047	et	3	main
hästi	doc_670731433432_item	2786051	et	3	main
seda	doc_670731433432_item	2786055	et	3	main
mul	doc_670731433432_item	2786057	et	3	main
onu	doc_670731433432_item	2786085	et	4	main
lõpetas	doc_670731433432_item	2786086	et	3	main
elektropriikooli	doc_670731433432_item	2786087	et	4	main
nad	doc_670731433432_item	2786088	et	3	main
aega	doc_670731433432_item	2786093	et	4	main
oli	doc_670731433432_item	2786096	et	3	main
esimine	doc_670731433432_item	2786104	et	4	main
ruumi	doc_670731433432_item	2786118	et	4	main
ja	doc_670731433432_item	2786119	et	3	main
mul	doc_670731433432_item	2786124	et	3	main
pea	doc_670731433432_item	2786127	et	4	main
päeval	doc_670731433432_item	2786129	et	3	main
väga	doc_670731433432_item	2786136	et	3	main
et	doc_670731433432_item	2786142	et	3	main
kõik	doc_670731433432_item	2786152	et	4	main
minu	doc_670731433432_item	2786166	et	3	main
elu	doc_670731433432_item	2786167	et	4	main
ma	doc_670731433432_item	2786168	et	3	main
ja	doc_670731433430_item	2785722	et	3	main
tegeleme	doc_670731433430_item	2785725	et	3	main
ma	doc_670731433431_item	2785739	et	3	main
oluline	doc_670731433431_item	2785757	et	4	main
sündmus	doc_670731433431_item	2785758	et	3	main
siis	doc_670731433431_item	2785759	et	3	main
pärast	doc_670731433431_item	2785760	et	4	main
kooli	doc_670731433431_item	2785761	et	4	main
paljud	doc_670731433431_item	2785762	et	3	main
abituriendid	doc_670731433431_item	2785763	et	3	main
teavad	doc_670731433431_item	2785764	et	3	main
aga	doc_670731433431_item	2785765	et	3	main
mõned	doc_670731433431_item	2785766	et	3	main
mõtlevad	doc_670731433431_item	2785767	et	4	main
veel	doc_670731433431_item	2785768	et	4	main
kelleks	doc_670731433431_item	2785769	et	4	main
nad	doc_670731433431_item	2785770	et	3	main
tahaksid	doc_670731433431_item	2785771	et	4	main
õppima	doc_670731433431_item	2785775	et	3	main
teised	doc_670731433431_item	2785785	et	4	main
tahavad	doc_670731433431_item	2785786	et	3	main
õpetajaks	doc_670731433431_item	2785787	et	4	main
või	doc_670731433431_item	2785788	et	4	main
tehnikaülikoolis	doc_670731433431_item	2785800	et	4	main
huvitunud	doc_670731433431_item	2785822	et	4	main
ja	doc_670731433431_item	2785831	et	3	main
palju	doc_670731433431_item	2785834	et	4	main
õppimisest	doc_670731433431_item	2785836	et	4	main
mida	doc_670731433431_item	2785853	et	4	main
sassi	doc_670731433431_item	2785871	et	3	main
tudengi	doc_670731433431_item	2785872	et	3	main
rõõmsam	doc_670731433431_item	2785879	et	4	main
aeg	doc_670731433431_item	2785880	et	3	main
ja	doc_670731433431_item	2785893	et	3	main
et	doc_670731433431_item	2785895	et	3	main
siin	doc_670731433431_item	2785897	et	4	main
kolmkümmend	doc_670731433431_item	2785923	et	4	main
palju	doc_670731433431_item	2785927	et	4	main
õppeained	doc_670731433431_item	2785934	et	3	main
tähtis	doc_670731433431_item	2785940	et	4	main
kui	doc_670731433431_item	2785941	et	3	main
huvitavaid	doc_670731433431_item	2785949	et	4	main
asju	doc_670731433431_item	2785950	et	3	main
praegu	doc_670731433431_item	2785951	et	3	main
see	doc_670731433431_item	2785958	et	3	main
uued	doc_670731433431_item	2785961	et	3	main
mikroökonoomika	doc_670731433431_item	2785964	et	4	main
majandusmatemaatika	doc_670731433431_item	2785965	et	4	main
tunne	doc_670731433431_item	2785970	et	4	main
läbi	doc_670731433431_item	2785971	et	4	main
võib	doc_670731433431_item	2785975	et	3	main
ma	doc_670731433431_item	2785977	et	3	main
aru	doc_670731433431_item	2785979	et	4	main
kui	doc_670731433431_item	2785980	et	3	main
mul	doc_670731433431_item	2785981	et	3	main
on	doc_670731433431_item	2785982	et	4	main
sessioon	doc_670731433431_item	2785983	et	3	main
aga	doc_670731433431_item	2785984	et	3	main
praegu	doc_670731433431_item	2785985	et	3	main
õppima	doc_670731433431_item	2785986	et	3	main
õppima	doc_670731433431_item	2785987	et	3	main
aastat	doc_670731433432_item	2785999	et	3	main
loobutasime	doc_670731433432_item	2786018	et	4	main
ma	doc_670731433431_item	2785817	et	3	main
tahtsin	doc_670731433431_item	2785818	et	3	main
väga	doc_670731433431_item	2785819	et	3	main
ja	doc_670731433431_item	2785820	et	3	main
ttü-i	doc_670731433431_item	2785830	et	4	main
pea	doc_670731433431_item	2785841	et	4	main
ei	doc_670731433431_item	2785851	et	4	main
tahtsin	doc_670731433431_item	2785855	et	3	main
mõted	doc_670731433431_item	2785858	et	4	main
välismaal	doc_670731433431_item	2785860	et	4	main
oli	doc_670731433431_item	2785863	et	3	main
soov	doc_670731433431_item	2785866	et	3	main
ma	doc_670731433431_item	2785869	et	3	main
see	doc_670731433431_item	2785874	et	3	main
see	doc_670731433431_item	2785881	et	3	main
uus	doc_670731433431_item	2785883	et	3	main
pidasin	doc_670731433431_item	2785888	et	3	main
otsustama	doc_670731433431_item	2785890	et	3	main
õpivad	doc_670731433431_item	2785901	et	3	main
siin	doc_670731433431_item	2785902	et	4	main
tallinnas	doc_670731433431_item	2785903	et	4	main
ja	doc_670731433431_item	2785904	et	3	main
ttü-is	doc_670731433431_item	2785905	et	3	main
ma	doc_670731433431_item	2785906	et	3	main
olin	doc_670731433431_item	2785907	et	3	main
rõõmus	doc_670731433431_item	2785908	et	4	main
inimene	doc_670731433431_item	2785909	et	3	main
kui	doc_670731433431_item	2785910	et	3	main
ma	doc_670731433431_item	2785911	et	3	main
astun	doc_670731433431_item	2785912	et	3	main
ülikooli	doc_670731433431_item	2785913	et	4	main
ma	doc_670731433431_item	2785914	et	3	main
ootasin	doc_670731433431_item	2785915	et	3	main
väga	doc_670731433431_item	2785916	et	3	main
kuidas	doc_670731433431_item	2785917	et	3	main
ma	doc_670731433431_item	2785918	et	3	main
istun	doc_670731433431_item	2785919	et	3	main
loengus	doc_670731433431_item	2785920	et	3	main
minutit	doc_670731433431_item	2785924	et	3	main
õpetajaid	doc_670731433431_item	2785932	et	4	main
palju	doc_670731433431_item	2785948	et	4	main
ma	doc_670731433431_item	2785956	et	3	main
õppeained	doc_670731433431_item	2785962	et	3	main
ei	doc_670731433431_item	2785969	et	4	main
elu	doc_670731433431_item	2785974	et	4	main
ja	doc_670731433431_item	2785988	et	3	main
veel	doc_670731433431_item	2785989	et	4	main
mina	doc_670731433432_item	2785993	et	4	main
tallinna	doc_670731433432_item	2786005	et	4	main
gümnaasium	doc_670731433432_item	2786008	et	3	main
oli	doc_670731433432_item	2786010	et	3	main
aeg	doc_670731433432_item	2786012	et	3	main
millal	doc_670731433432_item	2786013	et	3	main
magasime	doc_670731433432_item	2786015	et	3	main
ära	doc_670731433432_item	2786016	et	4	main
tunnid	doc_670731433432_item	2786017	et	3	main
väga	doc_670731433432_item	2786022	et	3	main
koolis	doc_670731433432_item	2786037	et	4	main
õppima	doc_670731433432_item	2786038	et	3	main
ma	doc_670731433432_item	2786039	et	3	main
valin	doc_670731433432_item	2786040	et	3	main
elektroenergeetikat	doc_670731433432_item	2786041	et	3	main
sest	doc_670731433432_item	2786042	et	4	main
kui	doc_670731433432_item	2786049	et	3	main
ja	doc_670731433432_item	2786053	et	3	main
lõpetan	doc_670731433432_item	2786054	et	3	main
on	doc_670731433431_item	2785939	et	4	main
naudid	doc_670731433431_item	2785943	et	4	main
ma	doc_670731433431_item	2785945	et	3	main
ootan	doc_670731433431_item	2785946	et	3	main
ülikoolist	doc_670731433431_item	2785947	et	4	main
mis	doc_670731433431_item	2785955	et	4	main
sotsioloogia	doc_670731433431_item	2785966	et	4	main
aga	doc_670731433431_item	2785967	et	3	main
tõelist	doc_670731433431_item	2785972	et	4	main
olla	doc_670731433431_item	2785976	et	3	main
ja	doc_670731433432_item	2785994	et	3	main
kaheksateist	doc_670731433432_item	2785998	et	4	main
ma	doc_670731433432_item	2786003	et	3	main
vene	doc_670731433432_item	2786006	et	4	main
tore	doc_670731433432_item	2786011	et	3	main
praegu	doc_670731433432_item	2786026	et	3	main
lähen	doc_670731433432_item	2786028	et	3	main
tasuline	doc_670731433432_item	2786046	et	4	main
õppin	doc_670731433432_item	2786052	et	4	main
ja	doc_670731433432_item	2786075	et	3	main
ttü	doc_670731433432_item	2786080	et	4	main
ttü	doc_670731433432_item	2786090	et	4	main
väga	doc_670731433432_item	2786091	et	3	main
taga	doc_670731433432_item	2786094	et	4	main
teine	doc_670731433432_item	2786097	et	3	main
mäleta	doc_670731433432_item	2786103	et	4	main
ttü	doc_670731433432_item	2786112	et	4	main
on	doc_670731433432_item	2786115	et	4	main
nii	doc_670731433432_item	2786116	et	3	main
palju	doc_670731433432_item	2786117	et	4	main
sest	doc_670731433432_item	2786123	et	4	main
tore	doc_670731433432_item	2786133	et	3	main
klass	doc_670731433432_item	2786139	et	3	main
lapsepõlvest	doc_670731433432_item	2786160	et	4	main
et	doc_670731433432_item	2786161	et	3	main
ma	doc_670731433432_item	2786162	et	3	main
õppima	doc_670731433432_item	2786170	et	3	main
keele	doc_670731433432_item	2786179	et	4	main
tundidelt	doc_670731433432_item	2786180	et	3	main
et	doc_670731433432_item	2786181	et	3	main
ma	doc_670731433432_item	2786182	et	3	main
hästi	doc_670731433432_item	2786183	et	3	main
rääkida	doc_670731433432_item	2786189	et	3	main
õppida	doc_670731433432_item	2786193	et	3	main
kas	doc_670731433433_item	2786223	et	3	main
ma	doc_670731433433_item	2786230	et	3	main
selle	doc_670731433433_item	2786233	et	4	main
et	doc_670731433433_item	2786235	et	3	main
palju	doc_670731433433_item	2786256	et	4	main
sõpru	doc_670731433433_item	2786257	et	3	main
kes	doc_670731433433_item	2786258	et	4	main
mu	doc_670731433433_item	2786262	et	3	main
astuda	doc_670731433433_item	2786265	et	3	main
tartu	doc_670731433433_item	2786266	et	4	main
tahan	doc_670731433433_item	2786279	et	3	main
töötada	doc_670731433433_item	2786284	et	3	main
pärast	doc_670731433433_item	2786328	et	4	main
ja	doc_670731433433_item	2786336	et	3	main
9	doc_670731433433_item	2786342	et	2	main
see	doc_670731433433_item	2786344	et	3	main
väga	doc_670731433433_item	2786346	et	3	main
asjav	doc_670731433433_item	2786350	et	4	main
muutuma	doc_670731433433_item	2786352	et	4	main
esimesed	doc_670731433433_item	2786363	et	3	main
saada	doc_670731433433_item	2786370	et	4	main
õpimine	doc_670731433433_item	2786373	et	4	main
lõpetanud	doc_670731433433_item	2786396	et	4	main
siis	doc_670731433433_item	2786397	et	3	main
ma	doc_670731433433_item	2786398	et	3	main
huvitava	doc_670731433433_item	2786402	et	4	main
mida	doc_670731433433_item	2786404	et	4	main
tean	doc_670731433433_item	2786405	et	3	main
lõpetasin	doc_670731433434_item	2786414	et	3	main
tallinna	doc_670731433434_item	2786415	et	4	main
mustamäe	doc_670731433434_item	2786416	et	3	main
reaalgümnaasiumi	doc_670731433434_item	2786417	et	4	main
juba	doc_670731433434_item	2786418	et	3	main
unistasin	doc_670731433434_item	2786421	et	3	main
lähen	doc_670731433434_item	2786424	et	3	main
oma	doc_670731433434_item	2786442	et	4	main
elektroenergeetika	doc_670731433434_item	2786448	et	4	main
meie	doc_670731433434_item	2786451	et	4	main
majandus	doc_670731433431_item	2785960	et	4	main
nagu	doc_670731433431_item	2785963	et	3	main
tudengi	doc_670731433431_item	2785973	et	3	main
saan	doc_670731433431_item	2785978	et	4	main
essee	doc_670731433432_item	2785992	et	4	main
ma	doc_670731433432_item	2785996	et	3	main
vana	doc_670731433432_item	2786000	et	4	main
aastal	doc_670731433432_item	2786002	et	3	main
koolis	doc_670731433432_item	2786019	et	4	main
näeratasime	doc_670731433432_item	2786020	et	4	main
veetasime	doc_670731433432_item	2786021	et	4	main
aega	doc_670731433432_item	2786025	et	4	main
ma	doc_670731433432_item	2786027	et	3	main
sain	doc_670731433432_item	2786045	et	3	main
ja	doc_670731433432_item	2786048	et	3	main
onu	doc_670731433432_item	2786074	et	4	main
minu	doc_670731433432_item	2786076	et	3	main
lõpetasid	doc_670731433432_item	2786079	et	4	main
on	doc_670731433432_item	2786082	et	4	main
insenäär	doc_670731433432_item	2786083	et	4	main
aga	doc_670731433432_item	2786084	et	3	main
palju	doc_670731433432_item	2786092	et	4	main
ei	doc_670731433432_item	2786102	et	4	main
hooned	doc_670731433432_item	2786113	et	4	main
siin	doc_670731433432_item	2786114	et	4	main
ja	doc_670731433432_item	2786121	et	3	main
esimisel	doc_670731433432_item	2786128	et	4	main
siin	doc_670731433432_item	2786131	et	4	main
mulle	doc_670731433432_item	2786135	et	4	main
meeldib	doc_670731433432_item	2786137	et	3	main
ma	doc_670731433432_item	2786140	et	3	main
kui	doc_670731433432_item	2786143	et	3	main
lähevad	doc_670731433432_item	2786153	et	3	main
kursusel	doc_670731433432_item	2786155	et	3	main
minu	doc_670731433432_item	2786156	et	3	main
ütles	doc_670731433432_item	2786158	et	3	main
mulle	doc_670731433432_item	2786159	et	4	main
pean	doc_670731433432_item	2786169	et	4	main
eesti	doc_670731433432_item	2786185	et	4	main
keelt	doc_670731433432_item	2786186	et	4	main
pean	doc_670731433432_item	2786191	et	4	main
minna	doc_670731433433_item	2786222	et	3	main
või	doc_670731433433_item	2786225	et	4	main
arvuti	doc_670731433433_item	2786226	et	4	main
süsteemitehnikasse	doc_670731433433_item	2786228	et	4	main
aga	doc_670731433433_item	2786229	et	3	main
informaatikasse	doc_670731433433_item	2786232	et	4	main
päras	doc_670731433433_item	2786234	et	3	main
tõnismäe	doc_670731433433_item	2786245	et	3	main
seal	doc_670731433433_item	2786247	et	4	main
ma	doc_670731433433_item	2786248	et	3	main
12	doc_670731433433_item	2786250	et	2	main
veel	doc_670731433433_item	2786259	et	4	main
tugev	doc_670731433433_item	2786272	et	4	main
konkurs	doc_670731433433_item	2786273	et	4	main
ja	doc_670731433433_item	2786274	et	3	main
mina	doc_670731433433_item	2786275	et	4	main
arvuti	doc_670731433433_item	2786281	et	4	main
selle	doc_670731433433_item	2786286	et	4	main
kahjuks	doc_670731433433_item	2786289	et	4	main
eestis	doc_670731433433_item	2786290	et	3	main
on	doc_670731433433_item	2786291	et	4	main
vähe	doc_670731433433_item	2786292	et	3	main
võimalusi	doc_670731433433_item	2786293	et	3	main
et	doc_670731433433_item	2786294	et	3	main
suur	doc_670731433433_item	2786295	et	3	main
oma	doc_670731433432_item	2786024	et	4	main
siia	doc_670731433432_item	2786043	et	4	main
ma	doc_670731433432_item	2786050	et	3	main
ülikooli	doc_670731433432_item	2786056	et	4	main
oleks	doc_670731433432_item	2786058	et	3	main
palju	doc_670731433432_item	2786059	et	4	main
teadet	doc_670731433432_item	2786060	et	4	main
ja	doc_670731433432_item	2786061	et	3	main
väga	doc_670731433432_item	2786062	et	3	main
hea	doc_670731433432_item	2786063	et	4	main
palk	doc_670731433432_item	2786064	et	3	main
veel	doc_670731433432_item	2786065	et	4	main
miks	doc_670731433432_item	2786066	et	4	main
sest	doc_670731433432_item	2786067	et	4	main
mulle	doc_670731433432_item	2786068	et	4	main
meeldib	doc_670731433432_item	2786069	et	3	main
füüsikat	doc_670731433432_item	2786070	et	3	main
ja	doc_670731433432_item	2786071	et	3	main
matemaatikat	doc_670731433432_item	2786072	et	3	main
minu	doc_670731433432_item	2786073	et	3	main
isa	doc_670731433432_item	2786077	et	4	main
ka	doc_670731433432_item	2786078	et	3	main
isa	doc_670731433432_item	2786081	et	4	main
lõpetasid	doc_670731433432_item	2786089	et	4	main
täpselt	doc_670731433432_item	2786101	et	4	main
olin	doc_670731433432_item	2786107	et	3	main
väga	doc_670731433432_item	2786108	et	3	main
imetlen	doc_670731433432_item	2786109	et	3	main
kui	doc_670731433432_item	2786110	et	3	main
ülikoolil	doc_670731433432_item	2786095	et	4	main
nimetus	doc_670731433432_item	2786098	et	4	main
tpü	doc_670731433432_item	2786099	et	4	main
ma	doc_670731433432_item	2786100	et	3	main
kord	doc_670731433432_item	2786105	et	4	main
ma	doc_670731433432_item	2786106	et	3	main
nägin	doc_670731433432_item	2786111	et	3	main
lektori	doc_670731433432_item	2786120	et	3	main
õpilasi	doc_670731433432_item	2786122	et	3	main
õppida	doc_670731433432_item	2786134	et	3	main
minu	doc_670731433432_item	2786138	et	3	main
arvan	doc_670731433432_item	2786141	et	3	main
me	doc_670731433432_item	2786144	et	4	main
kõik	doc_670731433432_item	2786145	et	4	main
oleme	doc_670731433432_item	2786146	et	3	main
koos	doc_670731433432_item	2786147	et	4	main
ja	doc_670731433432_item	2786148	et	3	main
kogu	doc_670731433432_item	2786163	et	4	main
aeg	doc_670731433432_item	2786164	et	3	main
ja	doc_670731433432_item	2786171	et	3	main
nendega	doc_670731433432_item	2786174	et	4	main
ootan	doc_670731433432_item	2786177	et	3	main
eesti	doc_670731433432_item	2786178	et	4	main
ma	doc_670731433432_item	2786190	et	3	main
seda	doc_670731433432_item	2786192	et	3	main
sest	doc_670731433432_item	2786194	et	4	main
informatikasse	doc_670731433433_item	2786224	et	4	main
lõpetanud	doc_670731433433_item	2786243	et	4	main
reaalkool	doc_670731433433_item	2786246	et	4	main
õpisin	doc_670731433433_item	2786249	et	4	main
aastat	doc_670731433433_item	2786251	et	3	main
ja	doc_670731433433_item	2786252	et	3	main
seal	doc_670731433433_item	2786253	et	4	main
mul	doc_670731433433_item	2786254	et	3	main
õpivad	doc_670731433433_item	2786260	et	3	main
oli	doc_670731433433_item	2786264	et	3	main
ülikooli	doc_670731433433_item	2786267	et	4	main
aga	doc_670731433433_item	2786268	et	3	main
seal	doc_670731433433_item	2786269	et	4	main
oli	doc_670731433433_item	2786270	et	3	main
väga	doc_670731433433_item	2786271	et	3	main
võtnud	doc_670731433433_item	2786277	et	4	main
spetsialistiks	doc_670731433433_item	2786282	et	3	main
palka	doc_670731433433_item	2786296	et	4	main
saada	doc_670731433433_item	2786297	et	4	main
ja	doc_670731433433_item	2786348	et	3	main
võivad	doc_670731433433_item	2786351	et	4	main
praegu	doc_670731433433_item	2786353	et	3	main
ma	doc_670731433433_item	2786354	et	3	main
veel	doc_670731433433_item	2786355	et	4	main
eksamid	doc_670731433433_item	2786364	et	3	main
doktoriks	doc_670731433433_item	2786369	et	3	main
ei	doc_670731433433_item	2786375	et	4	main
ma	doc_670731433433_item	2786384	et	3	main
saan	doc_670731433433_item	2786399	et	4	main
teada	doc_670731433433_item	2786400	et	3	main
asju	doc_670731433433_item	2786403	et	3	main
praegu	doc_670731433433_item	2786406	et	3	main
et	doc_670731433434_item	2786413	et	3	main
väga	doc_670731433432_item	2786125	et	3	main
valutas	doc_670731433432_item	2786126	et	3	main
aga	doc_670731433432_item	2786130	et	3	main
on	doc_670731433432_item	2786132	et	4	main
aitame	doc_670731433432_item	2786149	et	3	main
teine	doc_670731433432_item	2786150	et	3	main
teisele	doc_670731433432_item	2786151	et	4	main
teisel	doc_670731433432_item	2786154	et	4	main
ema	doc_670731433432_item	2786157	et	4	main
kõik	doc_670731433432_item	2786165	et	4	main
ma	doc_670731433432_item	2786172	et	3	main
õppin	doc_670731433432_item	2786184	et	4	main
ma	doc_670731433432_item	2786195	et	3	main
elan	doc_670731433432_item	2786196	et	3	main
eestis	doc_670731433432_item	2786197	et	3	main
aga	doc_670731433432_item	2786198	et	3	main
riigikeel	doc_670731433432_item	2786199	et	4	main
on	doc_670731433432_item	2786200	et	4	main
eesti	doc_670731433432_item	2786201	et	4	main
keel	doc_670731433432_item	2786202	et	4	main
essee	doc_670731433433_item	2786203	et	4	main
mina	doc_670731433433_item	2786204	et	4	main
ja	doc_670731433433_item	2786205	et	3	main
ülikool	doc_670731433433_item	2786206	et	4	main
eksamid	doc_670731433433_item	2786207	et	3	main
on	doc_670731433433_item	2786208	et	4	main
juba	doc_670731433433_item	2786209	et	3	main
sooritud	doc_670731433433_item	2786210	et	4	main
ma	doc_670731433433_item	2786211	et	3	main
juba	doc_670731433433_item	2786212	et	3	main
astusin	doc_670731433433_item	2786213	et	3	main
tallinna	doc_670731433433_item	2786214	et	4	main
tehnika	doc_670731433433_item	2786215	et	4	main
ülikooli	doc_670731433433_item	2786216	et	4	main
siis	doc_670731433433_item	2786217	et	3	main
mul	doc_670731433433_item	2786218	et	3	main
oli	doc_670731433433_item	2786219	et	3	main
võimalus	doc_670731433433_item	2786220	et	3	main
kus	doc_670731433433_item	2786221	et	3	main
tarkvara	doc_670731433433_item	2786240	et	4	main
ma	doc_670731433433_item	2786241	et	3	main
olen	doc_670731433433_item	2786242	et	3	main
on	doc_670731433433_item	2786255	et	4	main
ei	doc_670731433433_item	2786276	et	4	main
saada	doc_670731433433_item	2786280	et	4	main
ja	doc_670731433433_item	2786283	et	3	main
pärast	doc_670731433433_item	2786287	et	4	main
mul	doc_670731433433_item	2786322	et	3	main
on	doc_670731433433_item	2786323	et	4	main
pärast	doc_670731433433_item	2786329	et	4	main
doktoriks	doc_670731433433_item	2786338	et	3	main
vähem	doc_670731433433_item	2786339	et	4	main
võtab	doc_670731433433_item	2786341	et	3	main
on	doc_670731433433_item	2786345	et	4	main
ei	doc_670731433433_item	2786356	et	4	main
kas	doc_670731433433_item	2786366	et	3	main
võin	doc_670731433433_item	2786368	et	3	main
olen	doc_670731433432_item	2786173	et	3	main
nõus	doc_670731433432_item	2786175	et	4	main
ma	doc_670731433432_item	2786176	et	3	main
ja	doc_670731433432_item	2786187	et	3	main
vaba	doc_670731433432_item	2786188	et	4	main
ja	doc_670731433433_item	2786227	et	3	main
läksin	doc_670731433433_item	2786231	et	3	main
mind	doc_670731433433_item	2786236	et	4	main
huvitab	doc_670731433433_item	2786237	et	3	main
programeerimine	doc_670731433433_item	2786238	et	4	main
ja	doc_670731433433_item	2786239	et	3	main
tallinna	doc_670731433433_item	2786244	et	4	main
seal	doc_670731433433_item	2786261	et	4	main
unistus	doc_670731433433_item	2786263	et	4	main
ma	doc_670731433433_item	2786278	et	3	main
välismaal	doc_670731433433_item	2786285	et	4	main
et	doc_670731433433_item	2786288	et	3	main
praegu	doc_670731433433_item	2786298	et	3	main
ma	doc_670731433433_item	2786299	et	3	main
ei	doc_670731433433_item	2786300	et	4	main
ole	doc_670731433433_item	2786301	et	4	main
kindel	doc_670731433433_item	2786302	et	3	main
kuhu	doc_670731433433_item	2786303	et	3	main
ma	doc_670731433433_item	2786304	et	3	main
lähen	doc_670731433433_item	2786305	et	3	main
ja	doc_670731433433_item	2786306	et	3	main
millal	doc_670731433433_item	2786307	et	3	main
võib	doc_670731433433_item	2786308	et	3	main
olla	doc_670731433433_item	2786309	et	3	main
et	doc_670731433433_item	2786310	et	3	main
jään	doc_670731433433_item	2786311	et	3	main
siin	doc_670731433433_item	2786312	et	4	main
see	doc_670731433433_item	2786313	et	3	main
sõltub	doc_670731433433_item	2786314	et	3	main
sellest	doc_670731433433_item	2786315	et	4	main
mida	doc_670731433433_item	2786316	et	4	main
ma	doc_670731433433_item	2786317	et	3	main
tahan	doc_670731433433_item	2786318	et	3	main
ja	doc_670731433433_item	2786319	et	3	main
mis	doc_670731433433_item	2786320	et	4	main
töö	doc_670731433433_item	2786321	et	4	main
kolme	doc_670731433433_item	2786324	et	4	main
või	doc_670731433433_item	2786325	et	4	main
bakalauri	doc_670731433433_item	2786330	et	4	main
õpe	doc_670731433433_item	2786331	et	3	main
ma	doc_670731433433_item	2786332	et	3	main
tahan	doc_670731433433_item	2786333	et	3	main
minna	doc_670731433433_item	2786334	et	3	main
aastat	doc_670731433433_item	2786343	et	3	main
palju	doc_670731433433_item	2786347	et	4	main
ma	doc_670731433433_item	2786367	et	3	main
asju	doc_670731433433_item	2786383	et	3	main
essee	doc_670731433434_item	2786407	et	4	main
mina	doc_670731433434_item	2786408	et	4	main
ja	doc_670731433434_item	2786409	et	3	main
ülikool	doc_670731433434_item	2786410	et	4	main
alustan	doc_670731433434_item	2786411	et	3	main
koolis	doc_670731433434_item	2786419	et	4	main
tulevikus	doc_670731433434_item	2786423	et	4	main
ttü-sse	doc_670731433434_item	2786425	et	3	main
olla	doc_670731433434_item	2786428	et	3	main
küsite	doc_670731433434_item	2786429	et	3	main
õppima	doc_670731433434_item	2786444	et	3	main
ajal	doc_670731433434_item	2786452	et	4	main
täpselt	doc_670731433434_item	2786456	et	4	main
nelja	doc_670731433433_item	2786326	et	4	main
aasta	doc_670731433433_item	2786327	et	4	main
magistriks	doc_670731433433_item	2786335	et	3	main
siis	doc_670731433433_item	2786337	et	3	main
see	doc_670731433433_item	2786340	et	3	main
mõned	doc_670731433433_item	2786349	et	3	main
ole	doc_670731433433_item	2786357	et	4	main
tudeng	doc_670731433433_item	2786358	et	3	main
ma	doc_670731433433_item	2786359	et	3	main
olen	doc_670731433433_item	2786360	et	3	main
rebane	doc_670731433433_item	2786361	et	4	main
ja	doc_670731433433_item	2786362	et	3	main
näevad	doc_670731433433_item	2786365	et	3	main
ttüs	doc_670731433433_item	2786374	et	4	main
palju	doc_670731433433_item	2786382	et	4	main
ei	doc_670731433433_item	2786386	et	4	main
aga	doc_670731433433_item	2786388	et	3	main
ma	doc_670731433433_item	2786389	et	3	main
arvan	doc_670731433433_item	2786390	et	3	main
et	doc_670731433433_item	2786391	et	3	main
kui	doc_670731433433_item	2786392	et	3	main
esimene	doc_670731433433_item	2786393	et	3	main
semester	doc_670731433433_item	2786394	et	3	main
on	doc_670731433433_item	2786395	et	4	main
ma	doc_670731433434_item	2786420	et	3	main
võib	doc_670731433434_item	2786427	et	3	main
miks	doc_670731433434_item	2786430	et	4	main
arvan	doc_670731433434_item	2786434	et	3	main
on	doc_670731433434_item	2786436	et	4	main
eriala	doc_670731433434_item	2786443	et	4	main
väga	doc_670731433434_item	2786449	et	3	main
meie	doc_670731433434_item	2786454	et	4	main
on	doc_670731433434_item	2786465	et	4	main
ise	doc_670731433434_item	2786479	et	4	main
ma	doc_670731433434_item	2786488	et	3	main
praegu	doc_670731433434_item	2786491	et	3	main
ütelda	doc_670731433434_item	2786493	et	4	main
on	doc_670731433434_item	2786497	et	4	main
palju	doc_670731433434_item	2786499	et	4	main
see	doc_670731433434_item	2786502	et	3	main
minu	doc_670731433434_item	2786515	et	3	main
õpin	doc_670731433434_item	2786517	et	3	main
vene	doc_670731433434_item	2786518	et	4	main
ikka	doc_670731433434_item	2786521	et	4	main
oluline	doc_670731433434_item	2786528	et	4	main
eesti	doc_670731433434_item	2786536	et	4	main
meelega	doc_670731433434_item	2786544	et	4	main
see	doc_670731433434_item	2786545	et	3	main
on	doc_670731433434_item	2786546	et	4	main
väga	doc_670731433434_item	2786547	et	3	main
mida	doc_670731433434_item	2786552	et	4	main
tundidelt	doc_670731433434_item	2786557	et	3	main
eesti	doc_670731433434_item	2786567	et	4	main
nb	doc_670731433434_item	2786573	et	4	main
oli	doc_670731433434_item	2786574	et	3	main
mina	doc_670731433435_item	2786580	et	4	main
koolis	doc_670731433435_item	2786589	et	4	main
ma	doc_670731433435_item	2786590	et	3	main
kui	doc_670731433435_item	2786626	et	3	main
õppima	doc_670731433435_item	2786628	et	3	main
oma	doc_670731433435_item	2786629	et	4	main
uue	doc_670731433435_item	2786633	et	3	main
ka	doc_670731433435_item	2786637	et	3	main
ma	doc_670731433435_item	2786642	et	3	main
imetlenud	doc_670731433435_item	2786672	et	4	main
tunnid	doc_670731433435_item	2786707	et	3	main
sain	doc_670731433435_item	2786712	et	3	main
eesti	doc_670731433435_item	2786714	et	4	main
ma	doc_670731433435_item	2786716	et	3	main
tean	doc_670731433435_item	2786717	et	3	main
et	doc_670731433435_item	2786718	et	3	main
meil	doc_670731433435_item	2786719	et	4	main
mina	doc_670731433436_item	2786725	et	4	main
ülikool	doc_670731433436_item	2786727	et	4	main
lihtsalt	doc_670731433436_item	2786745	et	4	main
ei	doc_670731433436_item	2786746	et	4	main
just	doc_670731433436_item	2786765	et	3	main
eriala	doc_670731433436_item	2786767	et	4	main
tunnen	doc_670731433436_item	2786770	et	3	main
selle	doc_670731433436_item	2786771	et	4	main
vastu	doc_670731433436_item	2786772	et	3	main
pakkusid	doc_670731433436_item	2786788	et	4	main
või	doc_670731433433_item	2786371	et	4	main
mite	doc_670731433433_item	2786372	et	4	main
ole	doc_670731433433_item	2786376	et	4	main
nii	doc_670731433433_item	2786377	et	3	main
kerge	doc_670731433433_item	2786378	et	4	main
kui	doc_670731433433_item	2786379	et	3	main
ma	doc_670731433433_item	2786380	et	3	main
mõtlesin	doc_670731433433_item	2786381	et	3	main
veel	doc_670731433433_item	2786385	et	4	main
tea	doc_670731433433_item	2786387	et	4	main
rohkem	doc_670731433433_item	2786401	et	4	main
sellest	doc_670731433434_item	2786412	et	4	main
et	doc_670731433434_item	2786422	et	3	main
õppima	doc_670731433434_item	2786426	et	3	main
ausalt	doc_670731433434_item	2786432	et	4	main
sest	doc_670731433434_item	2786445	et	4	main
minu	doc_670731433434_item	2786446	et	3	main
arvates	doc_670731433434_item	2786447	et	4	main
perspektiivne	doc_670731433434_item	2786450	et	3	main
tean	doc_670731433434_item	2786457	et	3	main
lähen	doc_670731433434_item	2786459	et	3	main
pärast	doc_670731433434_item	2786461	et	4	main
on	doc_670731433434_item	2786468	et	4	main
seotud	doc_670731433434_item	2786469	et	4	main
energeetikaga	doc_670731433434_item	2786470	et	3	main
ja	doc_670731433434_item	2786471	et	3	main
loodan	doc_670731433434_item	2786472	et	3	main
et	doc_670731433434_item	2786473	et	3	main
nad	doc_670731433434_item	2786474	et	3	main
ikka	doc_670731433434_item	2786483	et	4	main
muljedest	doc_670731433434_item	2786495	et	4	main
vabalt	doc_670731433434_item	2786514	et	4	main
erialast	doc_670731433434_item	2786516	et	4	main
et	doc_670731433434_item	2786523	et	3	main
keel	doc_670731433434_item	2786525	et	4	main
keelt	doc_670731433434_item	2786537	et	4	main
keele	doc_670731433434_item	2786556	et	4	main
need	doc_670731433434_item	2786560	et	3	main
keeles	doc_670731433434_item	2786568	et	4	main
palju	doc_670731433434_item	2786569	et	4	main
väga	doc_670731433434_item	2786575	et	3	main
meeldiv	doc_670731433434_item	2786576	et	4	main
teiega	doc_670731433434_item	2786577	et	3	main
tutvuga	doc_670731433434_item	2786578	et	4	main
mina	doc_670731433435_item	2786583	et	4	main
kohtla-järve	doc_670731433435_item	2786585	et	4	main
gümnaasiumi	doc_670731433435_item	2786588	et	4	main
füüsika	doc_670731433435_item	2786593	et	4	main
ka	doc_670731433435_item	2786622	et	3	main
kavatsesid	doc_670731433435_item	2786623	et	4	main
ttü-s	doc_670731433435_item	2786625	et	3	main
lahed	doc_670731433435_item	2786638	et	3	main
perspektiivne	doc_670731433435_item	2786655	et	3	main
on	doc_670731433435_item	2786664	et	4	main
väga	doc_670731433435_item	2786665	et	3	main
suur	doc_670731433435_item	2786666	et	3	main
hoone	doc_670731433435_item	2786667	et	4	main
ja	doc_670731433435_item	2786668	et	3	main
kaasaegne	doc_670731433435_item	2786669	et	3	main
seda	doc_670731433435_item	2786670	et	3	main
ja	doc_670731433435_item	2786710	et	3	main
on	doc_670731433435_item	2786720	et	4	main
vastan	doc_670731433434_item	2786431	et	3	main
et	doc_670731433434_item	2786433	et	3	main
ttü	doc_670731433434_item	2786435	et	4	main
parim	doc_670731433434_item	2786437	et	4	main
ülikool	doc_670731433434_item	2786438	et	4	main
eestis	doc_670731433434_item	2786439	et	3	main
tulin	doc_670731433434_item	2786440	et	3	main
just	doc_670731433434_item	2786441	et	3	main
töötama	doc_670731433434_item	2786460	et	3	main
ülikooli	doc_670731433434_item	2786462	et	4	main
lõpetamist	doc_670731433434_item	2786463	et	4	main
mul	doc_670731433434_item	2786464	et	3	main
kõike	doc_670731433434_item	2786480	et	4	main
õppima	doc_670731433434_item	2786481	et	3	main
ja	doc_670731433434_item	2786482	et	3	main
seletasin	doc_670731433434_item	2786486	et	3	main
tulin	doc_670731433434_item	2786489	et	3	main
siin	doc_670731433434_item	2786496	et	4	main
hästi	doc_670731433434_item	2786498	et	3	main
palju	doc_670731433434_item	2786507	et	4	main
uusi	doc_670731433434_item	2786508	et	3	main
sõpru	doc_670731433434_item	2786509	et	3	main
ja	doc_670731433434_item	2786510	et	3	main
tunnen	doc_670731433434_item	2786511	et	3	main
end	doc_670731433434_item	2786512	et	4	main
eesti	doc_670731433434_item	2786524	et	4	main
on	doc_670731433434_item	2786526	et	4	main
väga	doc_670731433434_item	2786527	et	3	main
tundi	doc_670731433434_item	2786535	et	4	main
lähen	doc_670731433434_item	2786542	et	3	main
hea	doc_670731433434_item	2786543	et	4	main
ootan	doc_670731433434_item	2786554	et	3	main
et	doc_670731433434_item	2786559	et	3	main
rohkem	doc_670731433434_item	2786570	et	4	main
ja	doc_670731433434_item	2786571	et	3	main
ja	doc_670731433435_item	2786581	et	3	main
lõpetasin	doc_670731433435_item	2786584	et	3	main
järve	doc_670731433435_item	2786586	et	4	main
vene	doc_670731433435_item	2786587	et	4	main
saada	doc_670731433435_item	2786592	et	4	main
klassikaaslased	doc_670731433435_item	2786621	et	3	main
tulla	doc_670731433435_item	2786624	et	3	main
eriala	doc_670731433435_item	2786630	et	4	main
ma	doc_670731433435_item	2786631	et	3	main
tutvusin	doc_670731433435_item	2786632	et	3	main
inimestega	doc_670731433435_item	2786634	et	3	main
kes	doc_670731433435_item	2786635	et	4	main
ja	doc_670731433435_item	2786640	et	3	main
ma	doc_670731433435_item	2786648	et	3	main
seda	doc_670731433435_item	2786651	et	3	main
sest	doc_670731433435_item	2786674	et	4	main
et	doc_670731433435_item	2786675	et	3	main
ma	doc_670731433435_item	2786676	et	3	main
aitavad	doc_670731433435_item	2786708	et	4	main
mind	doc_670731433435_item	2786709	et	4	main
essee	doc_670731433436_item	2786724	et	4	main
sest	doc_670731433436_item	2786733	et	4	main
kunagi	doc_670731433436_item	2786734	et	3	main
ei	doc_670731433436_item	2786735	et	4	main
tea	doc_670731433436_item	2786736	et	4	main
millest	doc_670731433436_item	2786737	et	3	main
alustada	doc_670731433436_item	2786738	et	3	main
minu	doc_670731433436_item	2786739	et	3	main
huviring	doc_670731433436_item	2786740	et	3	main
jõu	doc_670731433436_item	2786747	et	3	main
tallinna	doc_670731433436_item	2786758	et	4	main
valisin	doc_670731433436_item	2786764	et	3	main
aastat	doc_670731433436_item	2786775	et	3	main
õpetajad	doc_670731433436_item	2786787	et	4	main
meile	doc_670731433436_item	2786789	et	4	main
huvitavaid	doc_670731433436_item	2786791	et	4	main
ärimänge	doc_670731433436_item	2786792	et	3	main
minu	doc_670731433436_item	2786793	et	3	main
lemmikmänguks	doc_670731433436_item	2786794	et	3	main
sai	doc_670731433436_item	2786795	et	4	main
mäng	doc_670731433436_item	2786796	et	3	main
kus	doc_670731433436_item	2786797	et	3	main
börsil	doc_670731433436_item	2786803	et	3	main
olen	doc_670731433436_item	2786810	et	3	main
ma	doc_670731433436_item	2786814	et	3	main
rohkem	doc_670731433436_item	2786837	et	4	main
oma	doc_670731433436_item	2786838	et	4	main
ma	doc_670731433436_item	2786847	et	3	main
ei	doc_670731433436_item	2786848	et	4	main
ja	doc_670731433436_item	2786851	et	3	main
ausalt	doc_670731433436_item	2786856	et	4	main
oli	doc_670731433436_item	2786859	et	3	main
ja	doc_670731433434_item	2786453	et	3	main
riigis	doc_670731433434_item	2786455	et	3	main
tuttavad	doc_670731433434_item	2786466	et	4	main
kes	doc_670731433434_item	2786467	et	4	main
aitavad	doc_670731433434_item	2786475	et	4	main
hakkan	doc_670731433434_item	2786484	et	3	main
miks	doc_670731433434_item	2786487	et	4	main
on	doc_670731433434_item	2786506	et	4	main
keeles	doc_670731433434_item	2786519	et	4	main
kuhu	doc_670731433434_item	2786458	et	3	main
mind	doc_670731433434_item	2786476	et	4	main
loomulikult	doc_670731433434_item	2786477	et	4	main
pean	doc_670731433434_item	2786478	et	4	main
juba	doc_670731433434_item	2786485	et	3	main
ttü-sse	doc_670731433434_item	2786490	et	3	main
tahaks	doc_670731433434_item	2786492	et	3	main
minu	doc_670731433434_item	2786494	et	3	main
rahvast	doc_670731433434_item	2786500	et	4	main
ja	doc_670731433434_item	2786501	et	3	main
on	doc_670731433434_item	2786503	et	4	main
tore	doc_670731433434_item	2786504	et	3	main
mul	doc_670731433434_item	2786505	et	3	main
siin	doc_670731433434_item	2786513	et	4	main
aga	doc_670731433434_item	2786520	et	3	main
ja	doc_670731433434_item	2786538	et	3	main
iga	doc_670731433434_item	2786539	et	4	main
huvitav	doc_670731433434_item	2786548	et	4	main
ma	doc_670731433434_item	2786553	et	3	main
ootan	doc_670731433434_item	2786558	et	3	main
tundid	doc_670731433434_item	2786561	et	4	main
mind	doc_670731433434_item	2786563	et	4	main
saan	doc_670731433434_item	2786565	et	4	main
rääkida	doc_670731433434_item	2786566	et	3	main
parem	doc_670731433434_item	2786572	et	4	main
essee	doc_670731433435_item	2786579	et	4	main
unistasin	doc_670731433435_item	2786591	et	3	main
arvan	doc_670731433434_item	2786522	et	3	main
meie	doc_670731433434_item	2786529	et	4	main
elus	doc_670731433434_item	2786530	et	4	main
koolis	doc_670731433434_item	2786531	et	4	main
mul	doc_670731433434_item	2786532	et	3	main
oli	doc_670731433434_item	2786533	et	3	main
5	doc_670731433434_item	2786534	et	2	main
kord	doc_670731433434_item	2786540	et	4	main
ma	doc_670731433434_item	2786541	et	3	main
teise	doc_670731433434_item	2786549	et	4	main
keeli	doc_670731433434_item	2786550	et	4	main
õppida	doc_670731433434_item	2786551	et	3	main
eesti	doc_670731433434_item	2786555	et	4	main
avanevad	doc_670731433434_item	2786562	et	4	main
ja	doc_670731433434_item	2786564	et	3	main
ülikool	doc_670731433435_item	2786582	et	4	main
õpetajaks	doc_670731433435_item	2786594	et	4	main
aga	doc_670731433435_item	2786595	et	3	main
kui	doc_670731433435_item	2786596	et	3	main
ma	doc_670731433435_item	2786597	et	3	main
mõtlesin	doc_670731433435_item	2786598	et	3	main
ära	doc_670731433435_item	2786599	et	4	main
siis	doc_670731433435_item	2786600	et	3	main
sain	doc_670731433435_item	2786602	et	3	main
aru	doc_670731433435_item	2786603	et	4	main
ma	doc_670731433435_item	2786601	et	3	main
et	doc_670731433435_item	2786604	et	3	main
seda	doc_670731433435_item	2786605	et	3	main
on	doc_670731433435_item	2786606	et	4	main
siis	doc_670731433435_item	2786608	et	3	main
ma	doc_670731433435_item	2786609	et	3	main
raske	doc_670731433435_item	2786607	et	4	main
mõtlesin	doc_670731433435_item	2786610	et	3	main
tulla	doc_670731433435_item	2786611	et	3	main
ttü-s	doc_670731433435_item	2786612	et	3	main
sellepärast	doc_670731433435_item	2786613	et	3	main
et	doc_670731433435_item	2786614	et	3	main
seal	doc_670731433435_item	2786615	et	4	main
on	doc_670731433435_item	2786616	et	4	main
palju	doc_670731433435_item	2786617	et	4	main
sõpru	doc_670731433435_item	2786618	et	3	main
ja	doc_670731433435_item	2786619	et	3	main
minu	doc_670731433435_item	2786620	et	3	main
tulin	doc_670731433435_item	2786627	et	3	main
on	doc_670731433435_item	2786636	et	4	main
õppima	doc_670731433435_item	2786645	et	3	main
erialale	doc_670731433435_item	2786647	et	3	main
mõtlen	doc_670731433435_item	2786649	et	3	main
et	doc_670731433435_item	2786650	et	3	main
on	doc_670731433435_item	2786653	et	4	main
sellel	doc_670731433435_item	2786656	et	4	main
erialal	doc_670731433435_item	2786657	et	3	main
ma	doc_670731433435_item	2786658	et	3	main
jaba	doc_670731433435_item	2786659	et	4	main
leidsin	doc_670731433435_item	2786660	et	3	main
uusi	doc_670731433435_item	2786661	et	3	main
sõbralikud	doc_670731433435_item	2786639	et	3	main
seltsivad	doc_670731433435_item	2786641	et	4	main
lähen	doc_670731433435_item	2786643	et	3	main
ttü-sse	doc_670731433435_item	2786644	et	3	main
oma	doc_670731433435_item	2786646	et	4	main
elektroenergeetika	doc_670731433435_item	2786652	et	4	main
väga	doc_670731433435_item	2786654	et	3	main
on	doc_670731433435_item	2786671	et	4	main
ei	doc_670731433435_item	2786677	et	4	main
õppinud	doc_670731433435_item	2786678	et	4	main
mitte	doc_670731433435_item	2786679	et	3	main
kunagi	doc_670731433435_item	2786680	et	3	main
suures	doc_670731433435_item	2786681	et	3	main
hoones	doc_670731433435_item	2786682	et	4	main
selles	doc_670731433435_item	2786683	et	4	main
ülikukoolis	doc_670731433435_item	2786684	et	4	main
kõik	doc_670731433435_item	2786685	et	4	main
inimesed	doc_670731433435_item	2786686	et	3	main
on	doc_670731433435_item	2786687	et	4	main
sõbralikud	doc_670731433435_item	2786688	et	3	main
aga	doc_670731433435_item	2786689	et	3	main
ma	doc_670731433435_item	2786690	et	3	main
ei	doc_670731433435_item	2786691	et	4	main
oodanut	doc_670731433435_item	2786692	et	4	main
et	doc_670731433435_item	2786693	et	3	main
seal	doc_670731433435_item	2786694	et	4	main
on	doc_670731433435_item	2786695	et	4	main
raske	doc_670731433435_item	2786696	et	4	main
õppida	doc_670731433435_item	2786697	et	3	main
mida	doc_670731433435_item	2786698	et	4	main
ma	doc_670731433435_item	2786699	et	3	main
ootan	doc_670731433435_item	2786700	et	3	main
eesti	doc_670731433435_item	2786701	et	4	main
keele	doc_670731433435_item	2786702	et	4	main
ootan	doc_670731433435_item	2786704	et	3	main
tundidelt	doc_670731433435_item	2786703	et	3	main
et	doc_670731433435_item	2786705	et	3	main
seda	doc_670731433435_item	2786706	et	3	main
sõpru	doc_670731433435_item	2786662	et	3	main
ttü	doc_670731433435_item	2786663	et	4	main
mind	doc_670731433435_item	2786673	et	4	main
rääkida	doc_670731433435_item	2786713	et	3	main
keelt	doc_670731433435_item	2786715	et	4	main
väga	doc_670731433435_item	2786721	et	3	main
ja	doc_670731433436_item	2786726	et	3	main
on	doc_670731433436_item	2786729	et	4	main
üsna	doc_670731433436_item	2786742	et	3	main
lai	doc_670731433436_item	2786743	et	3	main
jutustada	doc_670731433436_item	2786748	et	3	main
tallinna	doc_670731433436_item	2786752	et	4	main
humanitaargümnaasiumi	doc_670731433436_item	2786754	et	4	main
ja	doc_670731433436_item	2786756	et	3	main
huvi	doc_670731433436_item	2786773	et	4	main
kaks	doc_670731433436_item	2786774	et	3	main
laste	doc_670731433436_item	2786778	et	4	main
kus	doc_670731433436_item	2786780	et	3	main
millisesse	doc_670731433436_item	2786806	et	4	main
vaid	doc_670731433436_item	2786820	et	3	main
rahaga	doc_670731433436_item	2786821	et	4	main
ma	doc_670731433436_item	2786823	et	3	main
ärimees	doc_670731433436_item	2786832	et	4	main
ärinaine	doc_670731433436_item	2786834	et	3	main
firma	doc_670731433436_item	2786839	et	4	main
vähem	doc_670731433436_item	2786845	et	4	main
karda	doc_670731433436_item	2786849	et	4	main
raskusi	doc_670731433436_item	2786850	et	4	main
seepärast	doc_670731433436_item	2786852	et	3	main
mulle	doc_670731433436_item	2786853	et	4	main
öeldes	doc_670731433436_item	2786857	et	3	main
õppima	doc_670731433436_item	2786868	et	3	main
mulle	doc_670731433436_item	2786883	et	4	main
rohkem	doc_670731433436_item	2786917	et	4	main
ma	doc_670731433435_item	2786711	et	3	main
õpetaja	doc_670731433435_item	2786723	et	4	main
mul	doc_670731433436_item	2786728	et	3	main
raske	doc_670731433436_item	2786730	et	4	main
endast	doc_670731433436_item	2786731	et	4	main
rääkida	doc_670731433436_item	2786732	et	3	main
kõigest	doc_670731433436_item	2786744	et	4	main
aastal	doc_670731433436_item	2786750	et	3	main
kuldmedaliga	doc_670731433436_item	2786755	et	3	main
tehnika	doc_670731433436_item	2786759	et	4	main
ülikooli	doc_670731433436_item	2786760	et	4	main
ärindust	doc_670731433436_item	2786761	et	3	main
õppima	doc_670731433436_item	2786762	et	3	main
ma	doc_670731433436_item	2786763	et	3	main
ma	doc_670731433436_item	2786776	et	3	main
ärikoolis	doc_670731433436_item	2786779	et	4	main
sain	doc_670731433436_item	2786781	et	3	main
ärikorraldus	doc_670731433436_item	2786784	et	3	main
üldse	doc_670731433436_item	2786785	et	3	main
me	doc_670731433436_item	2786798	et	4	main
pidime	doc_670731433436_item	2786799	et	3	main
otsustama	doc_670731433436_item	2786805	et	3	main
investeerime	doc_670731433436_item	2786808	et	3	main
kindel	doc_670731433436_item	2786811	et	3	main
et	doc_670731433436_item	2786812	et	3	main
saan	doc_670731433436_item	2786815	et	4	main
niimoodi	doc_670731433436_item	2786816	et	3	main
teha	doc_670731433436_item	2786817	et	3	main
mitte	doc_670731433436_item	2786818	et	3	main
kunstrahaga	doc_670731433436_item	2786819	et	4	main
või	doc_670731433436_item	2786833	et	4	main
samal	doc_670731433436_item	2786842	et	3	main
ajal	doc_670731433436_item	2786843	et	4	main
kulutama	doc_670731433436_item	2786846	et	4	main
meeldib	doc_670731433436_item	2786854	et	3	main
raske	doc_670731433436_item	2786860	et	4	main
ülikoolis	doc_670731433436_item	2786867	et	4	main
kuid	doc_670731433436_item	2786876	et	4	main
isa	doc_670731433436_item	2786877	et	4	main
ütles	doc_670731433436_item	2786878	et	3	main
et	doc_670731433436_item	2786879	et	3	main
logistikat	doc_670731433436_item	2786880	et	3	main
õpetab	doc_670731433436_item	2786882	et	3	main
valemite	doc_670731433436_item	2786924	et	3	main
miinuseks	doc_670731433436_item	2786926	et	3	main
et	doc_670731433436_item	2786930	et	3	main
teaduskonna	doc_670731433436_item	2786932	et	4	main
hoone	doc_670731433436_item	2786933	et	4	main
asub	doc_670731433436_item	2786934	et	3	main
koplis	doc_670731433436_item	2786935	et	3	main
minu	doc_670731433436_item	2786936	et	3	main
üliõpilaste	doc_670731433436_item	2786942	et	4	main
ees	doc_670731433436_item	2786944	et	4	main
veel	doc_670731433436_item	2786946	et	4	main
kaks	doc_670731433436_item	2786947	et	3	main
ja	doc_670731433436_item	2786948	et	3	main
väga	doc_670731433436_item	2786957	et	3	main
palju	doc_670731433436_item	2786958	et	4	main
soovin	doc_670731433436_item	2786959	et	3	main
oskusi	doc_670731433436_item	2786989	et	3	main
aeg	doc_670731433436_item	2786990	et	3	main
näitab	doc_670731433436_item	2786991	et	3	main
kas	doc_670731433436_item	2786992	et	3	main
minu	doc_670731433436_item	2786993	et	3	main
valik	doc_670731433436_item	2786994	et	3	main
tehnika	doc_670731433436_item	2787007	et	4	main
mina	doc_670731433437_item	2787010	et	4	main
ülikool	doc_670731433437_item	2787012	et	4	main
olen	doc_670731433437_item	2787013	et	3	main
korteris	doc_670731433437_item	2787024	et	3	main
koos	doc_670731433437_item	2787025	et	4	main
ülikooli	doc_670731433437_item	2787027	et	4	main
taga	doc_670731433437_item	2787036	et	4	main
nagu	doc_670731433437_item	2787037	et	3	main
ka	doc_670731433437_item	2787042	et	3	main
informaatika	doc_670731433437_item	2787054	et	4	main
mulle	doc_670731433437_item	2787061	et	4	main
ainult	doc_670731433437_item	2787067	et	4	main
tea	doc_670731433437_item	2787074	et	4	main
ole	doc_670731433437_item	2787082	et	4	main
hea	doc_670731433435_item	2786722	et	4	main
on	doc_670731433436_item	2786741	et	4	main
sellel	doc_670731433436_item	2786749	et	4	main
lõpetasin	doc_670731433436_item	2786751	et	3	main
xxx	doc_670731433436_item	2786753	et	4	main
astusin	doc_670731433436_item	2786757	et	3	main
selle	doc_670731433436_item	2786766	et	4	main
sest	doc_670731433436_item	2786768	et	4	main
et	doc_670731433436_item	2786769	et	3	main
õppisin	doc_670731433436_item	2786777	et	3	main
teada	doc_670731433436_item	2786782	et	3	main
mis	doc_670731433436_item	2786783	et	4	main
tähendab	doc_670731433436_item	2786786	et	3	main
jälgima	doc_670731433436_item	2786800	et	4	main
mis	doc_670731433436_item	2786801	et	4	main
toimub	doc_670731433436_item	2786802	et	3	main
erinevaid	doc_670731433436_item	2786790	et	4	main
ja	doc_670731433436_item	2786804	et	3	main
firmasse	doc_670731433436_item	2786807	et	3	main
raha	doc_670731433436_item	2786809	et	4	main
varsti	doc_670731433436_item	2786813	et	3	main
mis	doc_670731433436_item	2786822	et	4	main
peab	doc_670731433436_item	2786835	et	4	main
võimalikult	doc_670731433436_item	2786836	et	4	main
tulusid	doc_670731433436_item	2786840	et	4	main
suurendama	doc_670731433436_item	2786841	et	3	main
riskida	doc_670731433436_item	2786855	et	3	main
mul	doc_670731433436_item	2786858	et	3	main
ma	doc_670731433436_item	2786863	et	3	main
mida	doc_670731433436_item	2786865	et	4	main
ta	doc_670731433436_item	2786881	et	4	main
töötab	doc_670731433436_item	2786886	et	3	main
sellel	doc_670731433436_item	2786887	et	4	main
huvi	doc_670731433436_item	2786918	et	4	main
faktide	doc_670731433436_item	2786922	et	3	main
pool	doc_670731433436_item	2786949	et	4	main
aastat	doc_670731433436_item	2786950	et	3	main
intensiivset	doc_670731433436_item	2786951	et	3	main
tuttavaks	doc_670731433436_item	2786962	et	4	main
diplomit	doc_670731433436_item	2786964	et	3	main
kirjutada	doc_670731433436_item	2786965	et	3	main
ja	doc_670731433436_item	2786966	et	3	main
või	doc_670731433436_item	2786997	et	4	main
vale	doc_670731433436_item	2786998	et	4	main
ülikoolis	doc_670731433436_item	2787008	et	4	main
noormees	doc_670731433437_item	2787017	et	4	main
sündisin	doc_670731433437_item	2787018	et	3	main
elan	doc_670731433437_item	2787022	et	3	main
vanematega	doc_670731433437_item	2787026	et	4	main
natukene	doc_670731433437_item	2787033	et	4	main
suhtlen	doc_670731433437_item	2787043	et	3	main
sõbradega	doc_670731433437_item	2787045	et	4	main
erialatest	doc_670731433437_item	2787053	et	3	main
ja	doc_670731433437_item	2787055	et	3	main
ei	doc_670731433437_item	2787062	et	4	main
ttüs	doc_670731433437_item	2787066	et	4	main
ei	doc_670731433437_item	2787073	et	4	main
ei	doc_670731433437_item	2787081	et	4	main
suur	doc_670731433437_item	2787118	et	3	main
loodan	doc_670731433437_item	2787122	et	3	main
olla	doc_670731433437_item	2787128	et	3	main
ja	doc_670731433437_item	2787138	et	3	main
oskust	doc_670731433437_item	2787140	et	3	main
ja	doc_670731433438_item	2787153	et	3	main
väike	doc_670731433438_item	2787154	et	4	main
linn	doc_670731433438_item	2787155	et	3	main
vaned	doc_670731433438_item	2787170	et	4	main
elab	doc_670731433438_item	2787171	et	3	main
lasnamäes	doc_670731433438_item	2787172	et	3	main
ma	doc_670731433438_item	2787173	et	3	main
valisin	doc_670731433438_item	2787188	et	3	main
ärinduse	doc_670731433438_item	2787189	et	3	main
eriala	doc_670731433438_item	2787190	et	4	main
sellepärast	doc_670731433438_item	2787191	et	3	main
et	doc_670731433438_item	2787192	et	3	main
mu	doc_670731433438_item	2787197	et	3	main
astusin	doc_670731433438_item	2787223	et	3	main
see	doc_670731433438_item	2787229	et	3	main
hoone	doc_670731433438_item	2787231	et	4	main
koplis	doc_670731433438_item	2787247	et	3	main
suur	doc_670731433438_item	2787256	et	3	main
ja	doc_670731433438_item	2787257	et	3	main
hoone	doc_670731433438_item	2787259	et	4	main
aga	doc_670731433438_item	2787260	et	3	main
mulle	doc_670731433438_item	2787261	et	4	main
teisest	doc_670731433438_item	2787266	et	4	main
it-maja	doc_670731433438_item	2787273	et	4	main
ja	doc_670731433438_item	2787274	et	3	main
mul	doc_670731433438_item	2787276	et	3	main
väga	doc_670731433438_item	2787278	et	3	main
tunnis	doc_670731433438_item	2787323	et	3	main
tahan	doc_670731433438_item	2787327	et	3	main
tekste	doc_670731433438_item	2787329	et	3	main
keele	doc_670731433439_item	2787339	et	4	main
no	doc_670731433439_item	2787346	et	3	main
kõigipealt	doc_670731433439_item	2787357	et	4	main
paar	doc_670731433439_item	2787363	et	3	main
tavaliselt	doc_670731433439_item	2787383	et	4	main
ise	doc_670731433436_item	2786824	et	4	main
oma	doc_670731433436_item	2786825	et	4	main
peaga	doc_670731433436_item	2786826	et	3	main
teenin	doc_670731433436_item	2786827	et	3	main
ärindus	doc_670731433436_item	2786828	et	3	main
tähendab	doc_670731433436_item	2786829	et	3	main
seda	doc_670731433436_item	2786830	et	3	main
et	doc_670731433436_item	2786831	et	3	main
võimalikult	doc_670731433436_item	2786844	et	4	main
valik	doc_670731433436_item	2786861	et	3	main
kui	doc_670731433436_item	2786862	et	3	main
otsustasin	doc_670731433436_item	2786864	et	3	main
hakkan	doc_670731433436_item	2786866	et	3	main
tahtsin	doc_670731433436_item	2786869	et	3	main
nii	doc_670731433436_item	2786870	et	3	main
logistikat	doc_670731433436_item	2786871	et	3	main
kui	doc_670731433436_item	2786872	et	3	main
ka	doc_670731433436_item	2786873	et	3	main
ärindust	doc_670731433436_item	2786874	et	3	main
õppida	doc_670731433436_item	2786875	et	3	main
ise	doc_670731433436_item	2786884	et	4	main
niimoodi	doc_670731433436_item	2786889	et	3	main
ma	doc_670731433436_item	2786890	et	3	main
astusin	doc_670731433436_item	2786891	et	3	main
majandusteaduskonda	doc_670731433436_item	2786892	et	4	main
olen	doc_670731433436_item	2786893	et	3	main
oma	doc_670731433436_item	2786894	et	4	main
valikuga	doc_670731433436_item	2786895	et	3	main
täiesti	doc_670731433436_item	2786896	et	3	main
rahul	doc_670731433436_item	2786897	et	4	main
mulle	doc_670731433436_item	2786898	et	4	main
meeldib	doc_670731433436_item	2786899	et	3	main
kõik	doc_670731433436_item	2786900	et	4	main
rühm	doc_670731433436_item	2786901	et	3	main
õppejõud	doc_670731433436_item	2786902	et	4	main
õppeained	doc_670731433436_item	2786903	et	3	main
praegu	doc_670731433436_item	2786904	et	3	main
kõige	doc_670731433436_item	2786905	et	4	main
huvitavam	doc_670731433436_item	2786906	et	4	main
aine	doc_670731433436_item	2786907	et	4	main
on	doc_670731433436_item	2786908	et	4	main
mikroökonoomika	doc_670731433436_item	2786909	et	4	main
natuke	doc_670731433436_item	2786910	et	4	main
igav	doc_670731433436_item	2786911	et	3	main
on	doc_670731433436_item	2786912	et	4	main
sotsioloogia	doc_670731433436_item	2786913	et	4	main
sest	doc_670731433436_item	2786914	et	4	main
et	doc_670731433436_item	2786915	et	3	main
tunnen	doc_670731433436_item	2786916	et	3	main
sest	doc_670731433436_item	2786885	et	4	main
erialal	doc_670731433436_item	2786888	et	3	main
mitte	doc_670731433436_item	2786919	et	3	main
ja	doc_670731433436_item	2786923	et	3	main
vastu	doc_670731433436_item	2786925	et	3	main
ka	doc_670731433436_item	2786928	et	3	main
jaoks	doc_670731433436_item	2786943	et	4	main
on	doc_670731433436_item	2786945	et	4	main
oli	doc_670731433436_item	2786995	et	3	main
tänulik	doc_670731433436_item	2787002	et	3	main
vana	doc_670731433437_item	2787016	et	4	main
lähedal	doc_670731433437_item	2787028	et	4	main
vabal	doc_670731433437_item	2787031	et	3	main
tänapäeval	doc_670731433437_item	2787040	et	3	main
koos	doc_670731433437_item	2787044	et	4	main
interneti	doc_670731433437_item	2787046	et	4	main
abil	doc_670731433437_item	2787047	et	4	main
mul	doc_670731433437_item	2787048	et	3	main
oli	doc_670731433437_item	2787049	et	3	main
võimalus	doc_670731433437_item	2787050	et	3	main
valida	doc_670731433437_item	2787051	et	3	main
süsteemtehnika	doc_670731433437_item	2787056	et	4	main
meeldi	doc_670731433437_item	2787063	et	4	main
programerida	doc_670731433437_item	2787064	et	4	main
nädala	doc_670731433437_item	2787069	et	3	main
ja	doc_670731433437_item	2787070	et	3	main
surepärased	doc_670731433437_item	2787113	et	4	main
kohvikud	doc_670731433437_item	2787114	et	3	main
ja	doc_670731433437_item	2787115	et	3	main
valik	doc_670731433437_item	2787119	et	3	main
loengutest	doc_670731433437_item	2787125	et	4	main
välja	doc_670731433437_item	2787136	et	4	main
grammatikat	doc_670731433437_item	2787137	et	3	main
see	doc_670731433438_item	2787149	et	3	main
on	doc_670731433438_item	2787150	et	4	main
väga	doc_670731433438_item	2787151	et	3	main
perekond	doc_670731433438_item	2787160	et	3	main
ma	doc_670731433438_item	2787164	et	3	main
mu	doc_670731433438_item	2787166	et	3	main
pole	doc_670731433438_item	2787178	et	3	main
mulle	doc_670731433438_item	2787180	et	4	main
diskole	doc_670731433438_item	2787183	et	4	main
käia	doc_670731433438_item	2787184	et	4	main
ja	doc_670731433438_item	2787185	et	3	main
tantsida	doc_670731433438_item	2787186	et	3	main
ma	doc_670731433438_item	2787187	et	3	main
ekonoomika	doc_670731433438_item	2787196	et	4	main
on	doc_670731433438_item	2787199	et	4	main
ja	doc_670731433438_item	2787201	et	3	main
mulle	doc_670731433438_item	2787202	et	4	main
ja	doc_670731433438_item	2787203	et	3	main
meeldib	doc_670731433438_item	2787204	et	3	main
suvel	doc_670731433438_item	2787221	et	3	main
praegu	doc_670731433438_item	2787233	et	3	main
üks	doc_670731433438_item	2787239	et	3	main
ja	doc_670731433438_item	2787248	et	3	main
ei	doc_670731433438_item	2787252	et	4	main
meeldi	doc_670731433438_item	2787253	et	4	main
rajoon	doc_670731433438_item	2787265	et	3	main
õppehoones	doc_670731433438_item	2787268	et	4	main
väga	doc_670731433438_item	2787270	et	3	main
spordihoone	doc_670731433438_item	2787275	et	4	main
tuttavaid	doc_670731433438_item	2787280	et	3	main
siis	doc_670731433438_item	2787282	et	3	main
õppida	doc_670731433438_item	2787288	et	3	main
tutvuda	doc_670731433438_item	2787324	et	3	main
õppetajaga	doc_670731433438_item	2787326	et	4	main
mittu	doc_670731433439_item	2787335	et	4	main
korda	doc_670731433439_item	2787336	et	4	main
minu	doc_670731433439_item	2787344	et	3	main
kui	doc_670731433439_item	2787352	et	3	main
on	doc_670731433439_item	2787358	et	4	main
korda	doc_670731433439_item	2787364	et	4	main
ilusalongis	doc_670731433439_item	2787382	et	3	main
aga	doc_670731433439_item	2787386	et	3	main
mind	doc_670731433439_item	2787387	et	4	main
palusid	doc_670731433439_item	2787388	et	4	main
vahetada	doc_670731433439_item	2787389	et	3	main
inimest	doc_670731433439_item	2787390	et	3	main
ja	doc_670731433439_item	2787391	et	3	main
tavaliselt	doc_670731433439_item	2787403	et	4	main
istuda	doc_670731433439_item	2787406	et	3	main
üldväljendite	doc_670731433436_item	2786920	et	3	main
vaid	doc_670731433436_item	2786921	et	3	main
on	doc_670731433436_item	2786927	et	4	main
see	doc_670731433436_item	2786929	et	3	main
meie	doc_670731433436_item	2786931	et	4	main
paljude	doc_670731433436_item	2786941	et	3	main
uutega	doc_670731433436_item	2786960	et	3	main
saada	doc_670731433436_item	2786963	et	4	main
kaitsta	doc_670731433436_item	2786967	et	4	main
selle	doc_670731433436_item	2786968	et	4	main
õige	doc_670731433436_item	2786996	et	4	main
igal	doc_670731433436_item	2786999	et	3	main
juhul	doc_670731433436_item	2787000	et	3	main
et	doc_670731433436_item	2787004	et	3	main
õpin	doc_670731433436_item	2787005	et	3	main
tallinna	doc_670731433436_item	2787006	et	4	main
essee	doc_670731433437_item	2787009	et	4	main
ja	doc_670731433437_item	2787011	et	3	main
tallinnas	doc_670731433437_item	2787019	et	4	main
ja	doc_670731433437_item	2787020	et	3	main
arust	doc_670731433436_item	2786937	et	4	main
see	doc_670731433436_item	2786938	et	3	main
on	doc_670731433436_item	2786939	et	4	main
ebamugav	doc_670731433436_item	2786940	et	3	main
ajutööd	doc_670731433436_item	2786952	et	4	main
sellest	doc_670731433436_item	2786953	et	4	main
ajavahemikust	doc_670731433436_item	2786954	et	4	main
ma	doc_670731433436_item	2786955	et	3	main
ootan	doc_670731433436_item	2786956	et	3	main
inimestega	doc_670731433436_item	2786961	et	3	main
ning	doc_670731433436_item	2786969	et	3	main
praktikal	doc_670731433436_item	2786970	et	3	main
veenduda	doc_670731433436_item	2786971	et	3	main
selles	doc_670731433436_item	2786972	et	4	main
et	doc_670731433436_item	2786973	et	3	main
valisin	doc_670731433436_item	2786974	et	3	main
just	doc_670731433436_item	2786975	et	3	main
seda	doc_670731433436_item	2786976	et	3	main
millega	doc_670731433436_item	2786977	et	3	main
tegelen	doc_670731433436_item	2786978	et	3	main
terve	doc_670731433436_item	2786979	et	4	main
ja	doc_670731433436_item	2786981	et	3	main
elu	doc_670731433436_item	2786980	et	4	main
mis	doc_670731433436_item	2786982	et	4	main
arendab	doc_670731433436_item	2786983	et	3	main
mind	doc_670731433436_item	2786984	et	4	main
ja	doc_670731433436_item	2786985	et	3	main
minu	doc_670731433436_item	2786986	et	3	main
teadmisi	doc_670731433436_item	2786987	et	4	main
ning	doc_670731433436_item	2786988	et	3	main
olen	doc_670731433436_item	2787001	et	3	main
sellele	doc_670731433436_item	2787003	et	4	main
üheksateist	doc_670731433437_item	2787014	et	4	main
aastat	doc_670731433437_item	2787015	et	3	main
praegu	doc_670731433437_item	2787021	et	3	main
kolmetoalises	doc_670731433437_item	2787023	et	4	main
ajal	doc_670731433437_item	2787032	et	4	main
istun	doc_670731433437_item	2787034	et	3	main
arvuti	doc_670731433437_item	2787035	et	4	main
mina	doc_670731433437_item	2787041	et	4	main
teist	doc_670731433437_item	2787058	et	4	main
eriala	doc_670731433437_item	2787059	et	4	main
sest	doc_670731433437_item	2787060	et	4	main
õppin	doc_670731433437_item	2787065	et	4	main
sellest	doc_670731433437_item	2787075	et	4	main
söökla	doc_670731433437_item	2787116	et	4	main
mida	doc_670731433437_item	2787121	et	4	main
rääkimist	doc_670731433437_item	2787139	et	4	main
ilus	doc_670731433438_item	2787152	et	4	main
koosneb	doc_670731433438_item	2787161	et	3	main
elan	doc_670731433438_item	2787174	et	3	main
korteris	doc_670731433438_item	2787175	et	3	main
ja	doc_670731433438_item	2787176	et	3	main
mulle	doc_670731433438_item	2787193	et	4	main
väga	doc_670731433438_item	2787194	et	3	main
ema	doc_670731433438_item	2787198	et	4	main
raamatupidaja	doc_670731433438_item	2787200	et	4	main
kui	doc_670731433438_item	2787234	et	3	main
on	doc_670731433438_item	2787242	et	4	main
majanduse	doc_670731433438_item	2787244	et	4	main
teaduskond	doc_670731433438_item	2787245	et	3	main
on	doc_670731433438_item	2787255	et	4	main
meeldi	doc_670731433438_item	2787263	et	4	main
see	doc_670731433438_item	2787264	et	3	main
palju	doc_670731433438_item	2787279	et	4	main
mulle	doc_670731433438_item	2787284	et	4	main
kui	doc_670731433438_item	2787291	et	3	main
tegelen	doc_670731433437_item	2787029	et	3	main
jalgpalliga	doc_670731433437_item	2787030	et	3	main
teised	doc_670731433437_item	2787038	et	4	main
noormehed	doc_670731433437_item	2787039	et	3	main
kahtest	doc_670731433437_item	2787052	et	4	main
valisin	doc_670731433437_item	2787057	et	3	main
teise	doc_670731433437_item	2787068	et	4	main
veel	doc_670731433437_item	2787071	et	4	main
palju	doc_670731433437_item	2787072	et	4	main
ülikoolist	doc_670731433437_item	2787076	et	4	main
meeldib	doc_670731433437_item	2787077	et	3	main
see	doc_670731433437_item	2787078	et	3	main
asi	doc_670731433437_item	2787079	et	4	main
et	doc_670731433437_item	2787080	et	3	main
vaja	doc_670731433437_item	2787083	et	4	main
vara	doc_670731433437_item	2787084	et	4	main
hommikul	doc_670731433437_item	2787085	et	3	main
tõusta	doc_670731433437_item	2787086	et	4	main
ja	doc_670731433437_item	2787087	et	3	main
kuhugi	doc_670731433437_item	2787088	et	4	main
minna	doc_670731433437_item	2787089	et	3	main
teeb	doc_670731433437_item	2787090	et	3	main
rõõmsaks	doc_670731433437_item	2787091	et	3	main
ka	doc_670731433437_item	2787092	et	3	main
see	doc_670731433437_item	2787093	et	3	main
aspekt	doc_670731433437_item	2787094	et	3	main
et	doc_670731433437_item	2787095	et	3	main
õppivad	doc_670731433437_item	2787097	et	4	main
siin	doc_670731433437_item	2787096	et	4	main
ka	doc_670731433437_item	2787098	et	3	main
venelased	doc_670731433437_item	2787099	et	3	main
kelle	doc_670731433437_item	2787100	et	4	main
eest	doc_670731433437_item	2787101	et	4	main
võib	doc_670731433437_item	2787102	et	3	main
küsida	doc_670731433437_item	2787103	et	3	main
midagi	doc_670731433437_item	2787104	et	4	main
kui	doc_670731433437_item	2787105	et	3	main
on	doc_670731433437_item	2787106	et	4	main
raskused	doc_670731433437_item	2787107	et	4	main
eesti	doc_670731433437_item	2787108	et	4	main
keelega	doc_670731433437_item	2787109	et	3	main
siin	doc_670731433437_item	2787110	et	4	main
asuvad	doc_670731433437_item	2787111	et	4	main
ka	doc_670731433437_item	2787112	et	3	main
päris	doc_670731433437_item	2787117	et	4	main
toidust	doc_670731433437_item	2787120	et	4	main
eesti	doc_670731433437_item	2787123	et	4	main
saada	doc_670731433437_item	2787126	et	4	main
mina	doc_670731433438_item	2787142	et	4	main
ülikool	doc_670731433438_item	2787144	et	4	main
maardus	doc_670731433438_item	2787148	et	4	main
minu	doc_670731433438_item	2787159	et	3	main
liikmest	doc_670731433438_item	2787163	et	4	main
mul	doc_670731433438_item	2787177	et	3	main
väga	doc_670731433438_item	2787181	et	3	main
keele	doc_670731433437_item	2787124	et	4	main
võib	doc_670731433437_item	2787127	et	3	main
rohkem	doc_670731433437_item	2787129	et	4	main
teada	doc_670731433437_item	2787130	et	3	main
eesti	doc_670731433437_item	2787131	et	4	main
kultuurist	doc_670731433437_item	2787132	et	3	main
ja	doc_670731433437_item	2787133	et	3	main
muidugi	doc_670731433437_item	2787134	et	4	main
õppida	doc_670731433437_item	2787135	et	3	main
essee	doc_670731433438_item	2787141	et	4	main
ja	doc_670731433438_item	2787143	et	3	main
lapsepõlvest	doc_670731433438_item	2787145	et	4	main
ma	doc_670731433438_item	2787146	et	3	main
elan	doc_670731433438_item	2787147	et	3	main
ta	doc_670731433438_item	2787156	et	4	main
asub	doc_670731433438_item	2787157	et	3	main
tallinnast	doc_670731433438_item	2787158	et	3	main
neljast	doc_670731433438_item	2787162	et	4	main
elan	doc_670731433438_item	2787165	et	3	main
vanematega	doc_670731433438_item	2787167	et	4	main
aga	doc_670731433438_item	2787168	et	3	main
vanem	doc_670731433438_item	2787169	et	4	main
koduloomi	doc_670731433438_item	2787179	et	4	main
meeldib	doc_670731433438_item	2787182	et	3	main
meeldib	doc_670731433438_item	2787195	et	3	main
see	doc_670731433438_item	2787205	et	3	main
elukutse	doc_670731433438_item	2787206	et	4	main
sellel	doc_670731433438_item	2787207	et	4	main
suvel	doc_670731433438_item	2787208	et	3	main
ma	doc_670731433438_item	2787209	et	3	main
töötasin	doc_670731433438_item	2787210	et	3	main
kaupuses	doc_670731433438_item	2787211	et	3	main
ja	doc_670731433438_item	2787212	et	3	main
praegu	doc_670731433438_item	2787213	et	3	main
ka	doc_670731433438_item	2787214	et	3	main
tahan	doc_670731433438_item	2787215	et	3	main
töötada	doc_670731433438_item	2787216	et	3	main
oma	doc_670731433438_item	2787218	et	4	main
et	doc_670731433438_item	2787217	et	3	main
raha	doc_670731433438_item	2787219	et	4	main
kulutama	doc_670731433438_item	2787220	et	4	main
kui	doc_670731433438_item	2787222	et	3	main
ttüsse	doc_670731433438_item	2787224	et	4	main
siis	doc_670731433438_item	2787225	et	3	main
väga	doc_670731433438_item	2787227	et	3	main
ma	doc_670731433438_item	2787235	et	3	main
õpin	doc_670731433438_item	2787237	et	3	main
see	doc_670731433438_item	2787241	et	3	main
see	doc_670731433438_item	2787249	et	3	main
mulle	doc_670731433438_item	2787250	et	4	main
ilus	doc_670731433438_item	2787258	et	4	main
küljest	doc_670731433438_item	2787267	et	4	main
on	doc_670731433438_item	2787269	et	4	main
ka	doc_670731433438_item	2787283	et	3	main
väga	doc_670731433438_item	2787285	et	3	main
meeldib	doc_670731433438_item	2787286	et	3	main
ka	doc_670731433438_item	2787287	et	3	main
oma	doc_670731433438_item	2787325	et	4	main
ja	doc_670731433438_item	2787330	et	3	main
seletuskiri	doc_670731433439_item	2787334	et	3	main
puudusin	doc_670731433439_item	2787337	et	3	main
eesti	doc_670731433439_item	2787338	et	4	main
elutempo	doc_670731433439_item	2787345	et	4	main
väga	doc_670731433439_item	2787347	et	3	main
kord	doc_670731433439_item	2787394	et	4	main
ma	doc_670731433439_item	2787395	et	3	main
mulle	doc_670731433438_item	2787226	et	4	main
meeldis	doc_670731433438_item	2787228	et	3	main
suur	doc_670731433438_item	2787230	et	3	main
aga	doc_670731433438_item	2787232	et	3	main
juba	doc_670731433438_item	2787236	et	3	main
siis	doc_670731433438_item	2787238	et	3	main
kuu	doc_670731433438_item	2787240	et	4	main
ebamugav	doc_670731433438_item	2787243	et	3	main
asub	doc_670731433438_item	2787246	et	3	main
ka	doc_670731433438_item	2787251	et	3	main
seal	doc_670731433438_item	2787254	et	4	main
ei	doc_670731433438_item	2787262	et	4	main
hea	doc_670731433438_item	2787271	et	4	main
söökla	doc_670731433438_item	2787272	et	4	main
on	doc_670731433438_item	2787277	et	4	main
õppivad	doc_670731433438_item	2787281	et	4	main
teised	doc_670731433438_item	2787289	et	4	main
keeled	doc_670731433438_item	2787290	et	3	main
ma	doc_670731433438_item	2787292	et	3	main
elan	doc_670731433438_item	2787293	et	3	main
eestis	doc_670731433438_item	2787294	et	3	main
siis	doc_670731433438_item	2787295	et	3	main
ma	doc_670731433438_item	2787296	et	3	main
pean	doc_670731433438_item	2787297	et	4	main
teada	doc_670731433438_item	2787298	et	3	main
riigikeel	doc_670731433438_item	2787299	et	4	main
koolis	doc_670731433438_item	2787300	et	4	main
mulle	doc_670731433438_item	2787301	et	4	main
väga	doc_670731433438_item	2787302	et	3	main
meeldis	doc_670731433438_item	2787303	et	3	main
teda	doc_670731433438_item	2787304	et	4	main
õppida	doc_670731433438_item	2787305	et	3	main
sest	doc_670731433438_item	2787306	et	4	main
mul	doc_670731433438_item	2787307	et	3	main
oli	doc_670731433438_item	2787308	et	3	main
väga	doc_670731433438_item	2787309	et	3	main
hea	doc_670731433438_item	2787310	et	4	main
õppetaja	doc_670731433438_item	2787311	et	4	main
ta	doc_670731433438_item	2787312	et	4	main
elab	doc_670731433438_item	2787313	et	3	main
praegu	doc_670731433438_item	2787314	et	3	main
samas	doc_670731433438_item	2787315	et	4	main
majas	doc_670731433438_item	2787316	et	3	main
kui	doc_670731433438_item	2787317	et	3	main
mina	doc_670731433438_item	2787318	et	4	main
ma	doc_670731433438_item	2787319	et	3	main
tahan	doc_670731433438_item	2787320	et	3	main
eesti	doc_670731433438_item	2787321	et	4	main
tõlkida	doc_670731433438_item	2787328	et	3	main
suhelda	doc_670731433438_item	2787331	et	4	main
sõpradega	doc_670731433438_item	2787333	et	3	main
kiire	doc_670731433439_item	2787348	et	4	main
magan	doc_670731433439_item	2787349	et	3	main
ma	doc_670731433439_item	2787350	et	3	main
vähem	doc_670731433439_item	2787351	et	4	main
keele	doc_670731433438_item	2787322	et	4	main
oma	doc_670731433438_item	2787332	et	4	main
tundi	doc_670731433439_item	2787340	et	4	main
tahaksin	doc_670731433439_item	2787341	et	3	main
öelda	doc_670731433439_item	2787342	et	4	main
et	doc_670731433439_item	2787343	et	3	main
on	doc_670731433439_item	2787353	et	4	main
vaja	doc_670731433439_item	2787354	et	4	main
sellepärast	doc_670731433439_item	2787355	et	3	main
et	doc_670731433439_item	2787356	et	3	main
kodutööd	doc_670731433439_item	2787362	et	4	main
ajal	doc_670731433439_item	2787366	et	4	main
olin	doc_670731433439_item	2787368	et	3	main
ma	doc_670731433439_item	2787367	et	3	main
kodus	doc_670731433439_item	2787369	et	4	main
magasin	doc_670731433439_item	2787370	et	4	main
ja	doc_670731433439_item	2787371	et	3	main
veel	doc_670731433439_item	2787372	et	4	main
paar	doc_670731433439_item	2787373	et	3	main
korda	doc_670731433439_item	2787374	et	4	main
olin	doc_670731433439_item	2787375	et	3	main
eesti	doc_670731433439_item	2787376	et	4	main
keele	doc_670731433439_item	2787377	et	4	main
ajal	doc_670731433439_item	2787378	et	4	main
tööl	doc_670731433439_item	2787379	et	3	main
ma	doc_670731433439_item	2787380	et	3	main
töötan	doc_670731433439_item	2787381	et	3	main
vaja	doc_670731433439_item	2787359	et	4	main
teha	doc_670731433439_item	2787360	et	3	main
palju	doc_670731433439_item	2787361	et	4	main
sel	doc_670731433439_item	2787365	et	3	main
sellepärast	doc_670731433439_item	2787397	et	3	main
haige	doc_670731433439_item	2787400	et	4	main
arvan	doc_670731433439_item	2787401	et	3	main
et	doc_670731433439_item	2787402	et	3	main
natukene	doc_670731433439_item	2787405	et	4	main
numbrid	doc_670731433440_item	2787416	et	3	main
on	doc_670731433440_item	2787433	et	4	main
pärit	doc_670731433440_item	2787434	et	3	main
eesti	doc_670731433440_item	2787435	et	4	main
eestist	doc_670731433440_item	2787436	et	3	main
praegu	doc_670731433440_item	2787439	et	3	main
london	doc_670731433440_item	2787441	et	4	main
londonis	doc_670731433440_item	2787443	et	4	main
saja	doc_670731433440_item	2787461	et	4	main
erenivates	doc_670731433440_item	2787471	et	4	main
armastama	doc_670731433440_item	2787474	et	3	main
neid	doc_670731433440_item	2787476	et	4	main
väga	doc_670731433440_item	2787477	et	3	main
karmid	doc_670731433440_item	2787480	et	4	main
suhtuma	doc_670731433440_item	2787482	et	3	main
ainult	doc_670731433440_item	2787492	et	4	main
jalaluu	doc_670731433440_item	2787521	et	4	main
pidn	doc_670731433440_item	2787524	et	4	main
mõnda	doc_670731433440_item	2787525	et	4	main
ainult	doc_670731433440_item	2787538	et	4	main
teineteisega	doc_670731433440_item	2787539	et	3	main
paaris	doc_670731433440_item	2787540	et	4	main
kuigi	doc_670731433440_item	2787541	et	3	main
nemad	doc_670731433440_item	2787542	et	3	main
nemadel	doc_670731433440_item	2787543	et	4	main
tehtud	doc_670731433440_item	2787545	et	4	main
elavad	doc_670731433440_item	2787553	et	4	main
planeeritud	doc_670731433440_item	2787563	et	4	main
toomas	doc_670731433440_item	2787566	et	3	main
ja	doc_670731433440_item	2787569	et	3	main
parem	doc_670731433440_item	2787571	et	4	main
paremine	doc_670731433440_item	2787572	et	4	main
tantsida	doc_670731433440_item	2787573	et	3	main
märtsis	doc_670731433440_item	2787574	et	3	main
seejärel	doc_670731433440_item	2787581	et	3	main
lõuna-aafrika	doc_670731433440_item	2787583	et	4	main
klassiruum	doc_670731433440_item	2787625	et	3	main
saada	doc_670731433440_item	2787629	et	4	main
mis	doc_670731433440_item	2787646	et	4	main
annab	doc_670731433440_item	2787647	et	3	main
sulle	doc_670731433440_item	2787648	et	3	main
3	doc_670731433440_item	2787649	et	2	main
vastavalt	doc_670731433440_item	2787657	et	4	main
individuaalsele	doc_670731433440_item	2787658	et	3	main
4	doc_670731433440_item	2787659	et	2	main
tasemele	doc_670731433440_item	2787660	et	3	main
aeg	doc_670731433440_item	2787661	et	3	main
vaja	doc_670731433440_item	2787671	et	4	main
ka	doc_670731433440_item	2787672	et	3	main
pisut	doc_670731433440_item	2787673	et	3	main
tarkust	doc_670731433440_item	2787674	et	4	main
kui	doc_670731433440_item	2787675	et	3	main
oled	doc_670731433440_item	2787676	et	3	main
kursusele	doc_670731433440_item	2787677	et	3	main
tasud	doc_670731433440_item	2787697	et	4	main
kättesaamisel	doc_670731433440_item	2787699	et	4	main
täidetud	doc_670731433440_item	2787701	et	4	main
meile	doc_670731433440_item	2787703	et	4	main
ainult	doc_670731433439_item	2787384	et	4	main
laupäeval	doc_670731433439_item	2787385	et	3	main
üks	doc_670731433439_item	2787393	et	3	main
puudusin	doc_670731433439_item	2787396	et	3	main
oli	doc_670731433439_item	2787399	et	3	main
kõik	doc_670731433439_item	2787412	et	4	main
sulud	doc_670731433440_item	2787415	et	3	main
õige	doc_670731433440_item	2787420	et	4	main
annab	doc_670731433440_item	2787422	et	3	main
elavad	doc_670731433440_item	2787438	et	4	main
vana	doc_670731433440_item	2787456	et	4	main
vabakutseline	doc_670731433440_item	2787465	et	4	main
inglismaal	doc_670731433440_item	2787473	et	4	main
armastatakse	doc_670731433440_item	2787475	et	3	main
nendesse	doc_670731433440_item	2787484	et	4	main
ülivõrdes	doc_670731433440_item	2787493	et	3	main
kuid	doc_670731433440_item	2787494	et	4	main
veel	doc_670731433439_item	2787392	et	4	main
on	doc_670731433439_item	2787411	et	4	main
avage	doc_670731433440_item	2787414	et	3	main
sõnadega	doc_670731433440_item	2787418	et	3	main
et	doc_670731433439_item	2787398	et	3	main
parem	doc_670731433439_item	2787404	et	4	main
kodus	doc_670731433439_item	2787407	et	4	main
ja	doc_670731433439_item	2787408	et	3	main
kirjutage	doc_670731433440_item	2787417	et	3	main
iga	doc_670731433440_item	2787419	et	4	main
vastus	doc_670731433440_item	2787421	et	3	main
ühe	doc_670731433440_item	2787423	et	4	main
maailmakuulsad	doc_670731433440_item	2787425	et	3	main
balletitantsijad	doc_670731433440_item	2787426	et	3	main
age	doc_670731433440_item	2787444	et	4	main
30	doc_670731433440_item	2787446	et	2	main
tuhande	doc_670731433440_item	2787459	et	3	main
vabakutselised	doc_670731433440_item	2787466	et	4	main
ja	doc_670731433440_item	2787467	et	3	main
esinevad	doc_670731433440_item	2787468	et	4	main
isegi	doc_670731433440_item	2787479	et	4	main
kriitikud	doc_670731433440_item	2787481	et	3	main
tantsimisest	doc_670731433440_item	2787527	et	4	main
age	doc_670731433440_item	2787531	et	4	main
toomas	doc_670731433440_item	2787533	et	3	main
on	doc_670731433440_item	2787534	et	4	main
on	doc_670731433440_item	2787544	et	4	main
pakkumisi	doc_670731433440_item	2787546	et	4	main
suurele	doc_670731433440_item	2787551	et	4	main
edule	doc_670731433440_item	2787552	et	3	main
tagasihoidlikult	doc_670731433440_item	2787556	et	4	main
on	doc_670731433440_item	2787560	et	4	main
sõidavad	doc_670731433440_item	2787582	et	3	main
ühe	doc_670731433440_item	2787617	et	4	main
punkti	doc_670731433440_item	2787618	et	4	main
õpi	doc_670731433440_item	2787619	et	4	main
millal	doc_670731433440_item	2787620	et	3	main
1	doc_670731433440_item	2787621	et	2	main
seda	doc_670731433440_item	2787638	et	3	main
et	doc_670731433440_item	2787664	et	3	main
5	doc_670731433440_item	2787666	et	2	main
postiasutusest	doc_670731433440_item	2787684	et	4	main
kuul	doc_670731433440_item	2787686	et	4	main
õppematerjalid	doc_670731433440_item	2787688	et	3	main
saada	doc_670731433440_item	2787700	et	4	main
kodutöö	doc_670731433440_item	2787702	et	4	main
tagasi	doc_670731433440_item	2787704	et	3	main
õpetaja	doc_670731433440_item	2787705	et	4	main
vaatab	doc_670731433440_item	2787706	et	3	main
tulge	doc_670731433440_item	2787725	et	3	main
vabanduse	doc_670731433440_item	2787753	et	4	main
tasemele	doc_670731433440_item	2787762	et	3	main
tasakesi	doc_670731433440_item	2787764	et	3	main
a	doc_670731433440_item	2787768	et	4	main
kokku	doc_670731433440_item	2787769	et	3	main
saada	doc_670731433440_item	2787770	et	4	main
c	doc_670731433440_item	2787785	et	4	main
a	doc_670731433440_item	2787799	et	4	main
kirjutab	doc_670731433440_item	2787800	et	3	main
c	doc_670731433440_item	2787803	et	4	main
d	doc_670731433440_item	2787805	et	4	main
muudab	doc_670731433440_item	2787806	et	3	main
a	doc_670731433440_item	2787808	et	4	main
liigne	doc_670731433440_item	2787809	et	3	main
b	doc_670731433440_item	2787810	et	4	main
c	doc_670731433440_item	2787821	et	4	main
d	doc_670731433440_item	2787823	et	4	main
harjutus	doc_670731433441_item	2787825	et	4	main
sulud	doc_670731433441_item	2787827	et	3	main
numbrid	doc_670731433441_item	2787828	et	3	main
kirjutage	doc_670731433441_item	2787829	et	3	main
sõnadega	doc_670731433441_item	2787830	et	3	main
on	doc_670731433441_item	2787845	et	4	main
london	doc_670731433441_item	2787853	et	4	main
aastane	doc_670731433441_item	2787860	et	4	main
vabakutseline	doc_670731433441_item	2787879	et	4	main
esinevad	doc_670731433441_item	2787881	et	4	main
väga	doc_670731433441_item	2787890	et	3	main
ainult	doc_670731433441_item	2787905	et	4	main
kergelt	doc_670731433441_item	2787913	et	4	main
murdma	doc_670731433441_item	2787926	et	3	main
noor	doc_670731433441_item	2787928	et	3	main
järve	doc_670731433441_item	2787931	et	4	main
pidama	doc_670731433441_item	2787936	et	4	main
mõnda	doc_670731433441_item	2787938	et	4	main
ja	doc_670731433441_item	2787945	et	3	main
iseravida	doc_670731433439_item	2787409	et	4	main
sellega	doc_670731433439_item	2787410	et	3	main
harjutus	doc_670731433440_item	2787413	et	4	main
punkti	doc_670731433440_item	2787424	et	4	main
abielupaar	doc_670731433440_item	2787427	et	4	main
age	doc_670731433440_item	2787428	et	4	main
oks	doc_670731433440_item	2787429	et	3	main
ja	doc_670731433440_item	2787430	et	3	main
toomas	doc_670731433440_item	2787431	et	3	main
kolmkümend	doc_670731433440_item	2787453	et	4	main
kaks	doc_670731433440_item	2787454	et	3	main
aastat	doc_670731433440_item	2787455	et	3	main
alates	doc_670731433440_item	2787457	et	3	main
teatrides	doc_670731433440_item	2787472	et	4	main
ning	doc_670731433440_item	2787478	et	3	main
suhtuvad	doc_670731433440_item	2787483	et	4	main
üldiselt	doc_670731433440_item	2787485	et	4	main
hästi	doc_670731433440_item	2787486	et	3	main
viimased	doc_670731433440_item	2787487	et	3	main
artiklid	doc_670731433440_item	2787488	et	3	main
räägivad	doc_670731433440_item	2787489	et	3	main
noored	doc_670731433440_item	2787490	et	3	main
kõik	doc_670731433440_item	2787495	et	4	main
aega	doc_670731433440_item	2787526	et	4	main
olema	doc_670731433440_item	2787529	et	4	main
eraldi	doc_670731433440_item	2787548	et	4	main
nende	doc_670731433440_item	2787557	et	4	main
esinemised	doc_670731433440_item	2787559	et	4	main
tulevad	doc_670731433440_item	2787575	et	4	main
nad	doc_670731433440_item	2787576	et	3	main
esinema	doc_670731433440_item	2787577	et	3	main
tallinnasse	doc_670731433440_item	2787579	et	3	main
lõuna-aafrikasse	doc_670731433440_item	2787584	et	4	main
unusta	doc_670731433440_item	2787623	et	4	main
umbne	doc_670731433440_item	2787624	et	3	main
koduõppesüsteem	doc_670731433440_item	2787626	et	3	main
võimaldab	doc_670731433440_item	2787627	et	3	main
sul	doc_670731433440_item	2787628	et	3	main
parasjagu	doc_670731433440_item	2787639	et	3	main
vabaduse	doc_670731433440_item	2787650	et	4	main
on	doc_670731433440_item	2787662	et	4	main
või	doc_670731433440_item	2787682	et	4	main
ees	doc_670731433440_item	2787696	et	4	main
sobid	doc_670731433440_item	2787733	et	4	main
b	doc_670731433440_item	2787734	et	4	main
c	doc_670731433440_item	2787736	et	4	main
2	doc_670731433440_item	2787740	et	2	main
a	doc_670731433440_item	2787741	et	4	main
just	doc_670731433440_item	2787742	et	3	main
b	doc_670731433440_item	2787743	et	4	main
b	doc_670731433440_item	2787752	et	4	main
a	doc_670731433440_item	2787759	et	4	main
tasakaalule	doc_670731433440_item	2787766	et	3	main
kokku	doc_670731433440_item	2787775	et	3	main
panna	doc_670731433440_item	2787779	et	4	main
b	doc_670731433440_item	2787783	et	4	main
vaid	doc_670731433440_item	2787784	et	3	main
et	doc_670731433440_item	2787788	et	3	main
taga	doc_670731433440_item	2787791	et	4	main
d	doc_670731433440_item	2787814	et	4	main
lihtne	doc_670731433440_item	2787815	et	3	main
külastage	doc_670731433440_item	2787822	et	3	main
õige	doc_670731433441_item	2787832	et	4	main
edur	doc_670731433441_item	2787844	et	4	main
eesti	doc_670731433441_item	2787847	et	4	main
inglismaa	doc_670731433441_item	2787852	et	4	main
32	doc_670731433441_item	2787864	et	2	main
kolmküne	doc_670731433441_item	2787865	et	4	main
aastat	doc_670731433441_item	2787867	et	3	main
seitsmiselt	doc_670731433441_item	2787874	et	4	main
on	doc_670731433441_item	2787876	et	4	main
vabakutseline	doc_670731433441_item	2787878	et	4	main
ja	doc_670731433441_item	2787880	et	3	main
teatride	doc_670731433441_item	2787885	et	4	main
armastas	doc_670731433441_item	2787888	et	3	main
karmid	doc_670731433441_item	2787893	et	4	main
suhtuma	doc_670731433441_item	2787895	et	3	main
ülivõrdes	doc_670731433441_item	2787906	et	3	main
kuid	doc_670731433441_item	2787907	et	4	main
kõik	doc_670731433441_item	2787908	et	4	main
pole	doc_670731433441_item	2787909	et	3	main
edur	doc_670731433440_item	2787432	et	4	main
aga	doc_670731433440_item	2787437	et	3	main
inglismaa	doc_670731433440_item	2787440	et	4	main
inglismaal	doc_670731433440_item	2787442	et	4	main
on	doc_670731433440_item	2787445	et	4	main
kolmkümend	doc_670731433440_item	2787447	et	4	main
aastane	doc_670731433440_item	2787448	et	4	main
ja	doc_670731433440_item	2787449	et	3	main
toomas	doc_670731433440_item	2787450	et	3	main
on	doc_670731433440_item	2787451	et	4	main
32	doc_670731433440_item	2787452	et	2	main
1997a	doc_670731433440_item	2787458	et	4	main
üheksa	doc_670731433440_item	2787460	et	4	main
üheksaseitsmes	doc_670731433440_item	2787462	et	4	main
on	doc_670731433440_item	2787463	et	4	main
nad	doc_670731433440_item	2787464	et	3	main
erinevad	doc_670731433440_item	2787469	et	4	main
teatrid	doc_670731433440_item	2787470	et	3	main
noortest	doc_670731433440_item	2787491	et	4	main
pole	doc_670731433440_item	2787496	et	3	main
sugugi	doc_670731433440_item	2787497	et	4	main
alati	doc_670731433440_item	2787498	et	4	main
nii	doc_670731433440_item	2787499	et	3	main
kergelt	doc_670731433440_item	2787500	et	4	main
läinud	doc_670731433440_item	2787501	et	4	main
mõlemal	doc_670731433440_item	2787502	et	3	main
ja	doc_670731433440_item	2787503	et	3	main
eriti	doc_670731433440_item	2787504	et	3	main
agel	doc_670731433440_item	2787505	et	4	main
on	doc_670731433440_item	2787506	et	4	main
olnud	doc_670731433440_item	2787507	et	4	main
probleeme	doc_670731433440_item	2787508	et	3	main
tervis	doc_670731433440_item	2787509	et	3	main
tervisega	doc_670731433440_item	2787510	et	3	main
1990	doc_670731433440_item	2787511	et	2	main
aastal	doc_670731433440_item	2787512	et	3	main
murdma	doc_670731433440_item	2787513	et	3	main
murdis	doc_670731433440_item	2787514	et	3	main
noor	doc_670731433440_item	2787515	et	3	main
naine	doc_670731433440_item	2787516	et	3	main
luikede	doc_670731433440_item	2787517	et	3	main
järve	doc_670731433440_item	2787518	et	4	main
etendus	doc_670731433440_item	2787519	et	4	main
etenduse	doc_670731433440_item	2787520	et	4	main
ja	doc_670731433440_item	2787522	et	3	main
pidama	doc_670731433440_item	2787523	et	4	main
eemal	doc_670731433440_item	2787528	et	3	main
tagasihoidlik	doc_670731433440_item	2787555	et	3	main
lähiaja	doc_670731433440_item	2787558	et	3	main
planeerima	doc_670731433440_item	2787562	et	3	main
age	doc_670731433440_item	2787564	et	4	main
tahavad	doc_670731433440_item	2787567	et	3	main
ja	doc_670731433440_item	2787580	et	3	main
olema	doc_670731433440_item	2787530	et	4	main
ja	doc_670731433440_item	2787532	et	3	main
otsustanud	doc_670731433440_item	2787535	et	4	main
tantsima	doc_670731433440_item	2787536	et	3	main
tantsida	doc_670731433440_item	2787537	et	3	main
ka	doc_670731433440_item	2787547	et	3	main
tantsimiseks	doc_670731433440_item	2787549	et	4	main
vaatamata	doc_670731433440_item	2787550	et	4	main
tantsijad	doc_670731433440_item	2787554	et	4	main
täpselt	doc_670731433440_item	2787561	et	4	main
ja	doc_670731433440_item	2787565	et	3	main
areneda	doc_670731433440_item	2787568	et	3	main
veelgi	doc_670731433440_item	2787570	et	4	main
tallinn	doc_670731433440_item	2787578	et	4	main
kui	doc_670731433440_item	2787585	et	3	main
kaua	doc_670731433440_item	2787586	et	3	main
oks	doc_670731433440_item	2787587	et	3	main
ja	doc_670731433440_item	2787588	et	3	main
edur	doc_670731433440_item	2787589	et	4	main
veel	doc_670731433440_item	2787590	et	4	main
tipus	doc_670731433440_item	2787591	et	3	main
suudavad	doc_670731433440_item	2787592	et	3	main
püsida	doc_670731433440_item	2787593	et	3	main
ei	doc_670731433440_item	2787594	et	4	main
oska	doc_670731433440_item	2787595	et	4	main
nad	doc_670731433440_item	2787596	et	3	main
ütleda	doc_670731433440_item	2787598	et	4	main
nad	doc_670731433440_item	2787599	et	3	main
ütlema	doc_670731433440_item	2787597	et	3	main
eelistavad	doc_670731433440_item	2787600	et	4	main
elada	doc_670731433440_item	2787601	et	3	main
üks	doc_670731433440_item	2787602	et	3	main
päev	doc_670731433440_item	2787603	et	3	main
ühe	doc_670731433440_item	2787604	et	4	main
päeva	doc_670731433440_item	2787605	et	4	main
kaupa	doc_670731433440_item	2787606	et	4	main
kirjutage	doc_670731433440_item	2787607	et	3	main
lünka	doc_670731433440_item	2787608	et	4	main
sobiv	doc_670731433440_item	2787609	et	4	main
sõna	doc_670731433440_item	2787610	et	4	main
teksti	doc_670731433440_item	2787611	et	4	main
alt	doc_670731433440_item	2787612	et	4	main
iga	doc_670731433440_item	2787613	et	4	main
õige	doc_670731433440_item	2787614	et	4	main
vastus	doc_670731433440_item	2787615	et	3	main
annab	doc_670731433440_item	2787616	et	3	main
soovid	doc_670731433440_item	2787622	et	4	main
targemaks	doc_670731433440_item	2787630	et	4	main
2	doc_670731433440_item	2787631	et	2	main
just	doc_670731433440_item	2787632	et	3	main
soovid	doc_670731433440_item	2787640	et	4	main
on	doc_670731433440_item	2787642	et	4	main
planeerida	doc_670731433440_item	2787651	et	3	main
aega	doc_670731433440_item	2787652	et	4	main
eelise	doc_670731433440_item	2787654	et	4	main
omandada	doc_670731433440_item	2787655	et	3	main
teadmisi	doc_670731433440_item	2787656	et	4	main
seda	doc_670731433440_item	2787665	et	3	main
kokku	doc_670731433440_item	2787667	et	3	main
registreerunud	doc_670731433440_item	2787678	et	4	main
saad	doc_670731433440_item	2787679	et	4	main
meie	doc_670731433440_item	2787680	et	4	main
igal	doc_670731433440_item	2787685	et	3	main
kätte	doc_670731433440_item	2787687	et	4	main
ja	doc_670731433440_item	2787690	et	3	main
helikasseti	doc_670731433440_item	2787691	et	4	main
6	doc_670731433440_item	2787692	et	2	main
selle	doc_670731433440_item	2787698	et	4	main
8	doc_670731433440_item	2787709	et	2	main
parandab	doc_670731433440_item	2787710	et	3	main
vead	doc_670731433440_item	2787711	et	4	main
ning	doc_670731433440_item	2787712	et	3	main
vastab	doc_670731433440_item	2787713	et	3	main
vajaduse	doc_670731433440_item	2787714	et	3	main
korral	doc_670731433440_item	2787715	et	4	main
ka	doc_670731433440_item	2787716	et	3	main
tekkinud	doc_670731433440_item	2787717	et	4	main
lisaküsimustele	doc_670731433440_item	2787718	et	4	main
kõik	doc_670731433440_item	2787719	et	4	main
geniaalne	doc_670731433440_item	2787720	et	3	main
on	doc_670731433440_item	2787721	et	4	main
10	doc_670731433440_item	2787724	et	2	main
soovid	doc_670731433440_item	2787735	et	4	main
d	doc_670731433440_item	2787738	et	4	main
c	doc_670731433440_item	2787745	et	4	main
kuigi	doc_670731433440_item	2787746	et	3	main
c	doc_670731433440_item	2787754	et	4	main
varanduse	doc_670731433440_item	2787755	et	3	main
d	doc_670731433440_item	2787756	et	4	main
d	doc_670731433440_item	2787765	et	4	main
5	doc_670731433440_item	2787767	et	2	main
c	doc_670731433440_item	2787774	et	4	main
hoida	doc_670731433440_item	2787776	et	3	main
d	doc_670731433440_item	2787787	et	4	main
c	doc_670731433440_item	2787794	et	4	main
eest	doc_670731433440_item	2787795	et	4	main
palub	doc_670731433440_item	2787802	et	3	main
parandab	doc_670731433440_item	2787804	et	3	main
9	doc_670731433440_item	2787807	et	2	main
10	doc_670731433440_item	2787816	et	2	main
a	doc_670731433440_item	2787817	et	4	main
seal	doc_670731433440_item	2787633	et	4	main
kus	doc_670731433440_item	2787634	et	3	main
ja	doc_670731433440_item	2787635	et	3	main
millal	doc_670731433440_item	2787636	et	3	main
sa	doc_670731433440_item	2787637	et	3	main
käes	doc_670731433440_item	2787641	et	4	main
interaktiivse	doc_670731433440_item	2787643	et	3	main
õppe	doc_670731433440_item	2787644	et	4	main
ajastu	doc_670731433440_item	2787645	et	4	main
ning	doc_670731433440_item	2787653	et	3	main
raha	doc_670731433440_item	2787663	et	4	main
panna	doc_670731433440_item	2787668	et	4	main
ning	doc_670731433440_item	2787669	et	3	main
on	doc_670731433440_item	2787670	et	4	main
kontorist	doc_670731433440_item	2787681	et	4	main
lähimast	doc_670731433440_item	2787683	et	4	main
raamatu	doc_670731433440_item	2787689	et	4	main
kodutöö	doc_670731433440_item	2787693	et	4	main
kursuse	doc_670731433440_item	2787694	et	3	main
7	doc_670731433440_item	2787695	et	2	main
selle	doc_670731433440_item	2787707	et	4	main
üle	doc_670731433440_item	2787708	et	3	main
9	doc_670731433440_item	2787722	et	2	main
meie	doc_670731433440_item	2787726	et	4	main
virtuaalkodu	doc_670731433440_item	2787727	et	4	main
või	doc_670731433440_item	2787728	et	4	main
postitage	doc_670731433440_item	2787729	et	3	main
kupong	doc_670731433440_item	2787730	et	3	main
1	doc_670731433440_item	2787731	et	2	main
soovitad	doc_670731433440_item	2787737	et	3	main
solvud	doc_670731433440_item	2787739	et	3	main
seega	doc_670731433440_item	2787744	et	4	main
d	doc_670731433440_item	2787747	et	4	main
siiski	doc_670731433440_item	2787748	et	4	main
3	doc_670731433440_item	2787749	et	2	main
tasule	doc_670731433440_item	2787760	et	3	main
c	doc_670731433440_item	2787763	et	4	main
kokku	doc_670731433440_item	2787778	et	3	main
6	doc_670731433440_item	2787780	et	2	main
ning	doc_670731433440_item	2787782	et	3	main
7	doc_670731433440_item	2787789	et	2	main
b	doc_670731433440_item	2787801	et	4	main
liikuv	doc_670731433440_item	2787813	et	4	main
minge	doc_670731433440_item	2787824	et	3	main
avage	doc_670731433441_item	2787826	et	3	main
vastus	doc_670731433441_item	2787833	et	3	main
ühe	doc_670731433441_item	2787835	et	4	main
maailmakuulsad	doc_670731433441_item	2787837	et	3	main
eestist	doc_670731433441_item	2787848	et	3	main
inglismaal	doc_670731433441_item	2787854	et	4	main
londonis	doc_670731433441_item	2787855	et	4	main
on	doc_670731433441_item	2787857	et	4	main
30	doc_670731433441_item	2787858	et	2	main
ja	doc_670731433441_item	2787861	et	3	main
kaks	doc_670731433441_item	2787866	et	3	main
alates	doc_670731433441_item	2787869	et	3	main
üheksakümne	doc_670731433441_item	2787873	et	4	main
inglismaal	doc_670731433441_item	2787886	et	4	main
neid	doc_670731433441_item	2787889	et	4	main
kriitikud	doc_670731433441_item	2787894	et	3	main
nendesse	doc_670731433441_item	2787897	et	4	main
üldiselt	doc_670731433441_item	2787898	et	4	main
hästi	doc_670731433441_item	2787899	et	3	main
viimased	doc_670731433441_item	2787900	et	3	main
artiklid	doc_670731433441_item	2787901	et	3	main
räägivad	doc_670731433441_item	2787902	et	3	main
noored	doc_670731433441_item	2787903	et	3	main
noordega	doc_670731433441_item	2787904	et	4	main
alati	doc_670731433441_item	2787911	et	4	main
nii	doc_670731433441_item	2787912	et	3	main
probleeme	doc_670731433441_item	2787921	et	3	main
tervist	doc_670731433441_item	2787923	et	4	main
otsustanud	doc_670731433441_item	2787948	et	4	main
on	doc_670731433441_item	2787957	et	4	main
vaatamata	doc_670731433441_item	2787963	et	4	main
tagasihoidlik	doc_670731433441_item	2787968	et	3	main
nende	doc_670731433441_item	2787970	et	4	main
parem	doc_670731433441_item	2787984	et	4	main
märtsis	doc_670731433441_item	2787987	et	3	main
lihtne	doc_670731433440_item	2787723	et	3	main
a	doc_670731433440_item	2787732	et	4	main
a	doc_670731433440_item	2787750	et	4	main
vajaduse	doc_670731433440_item	2787751	et	3	main
vabaduse	doc_670731433440_item	2787757	et	4	main
4	doc_670731433440_item	2787758	et	2	main
b	doc_670731433440_item	2787761	et	4	main
b	doc_670731433440_item	2787771	et	4	main
kokku	doc_670731433440_item	2787772	et	3	main
liita	doc_670731433440_item	2787773	et	4	main
d	doc_670731433440_item	2787777	et	4	main
a	doc_670731433440_item	2787781	et	4	main
kuid	doc_670731433440_item	2787786	et	4	main
a	doc_670731433440_item	2787790	et	4	main
b	doc_670731433440_item	2787792	et	4	main
ette	doc_670731433440_item	2787793	et	4	main
d	doc_670731433440_item	2787796	et	4	main
ees	doc_670731433440_item	2787797	et	4	main
8	doc_670731433440_item	2787798	et	2	main
libe	doc_670731433440_item	2787811	et	3	main
c	doc_670731433440_item	2787812	et	4	main
tulge	doc_670731433440_item	2787818	et	3	main
b	doc_670731433440_item	2787819	et	4	main
käige	doc_670731433440_item	2787820	et	3	main
iga	doc_670731433441_item	2787831	et	4	main
punkti	doc_670731433441_item	2787836	et	4	main
balletitantsijad	doc_670731433441_item	2787838	et	3	main
pärit	doc_670731433441_item	2787846	et	3	main
elavad	doc_670731433441_item	2787850	et	4	main
age	doc_670731433441_item	2787856	et	4	main
kolmkümmend	doc_670731433441_item	2787859	et	4	main
on	doc_670731433441_item	2787863	et	4	main
tuhande	doc_670731433441_item	2787871	et	3	main
üheksasaja	doc_670731433441_item	2787872	et	4	main
erinevad	doc_670731433441_item	2787882	et	4	main
erinevade	doc_670731433441_item	2787884	et	4	main
ning	doc_670731433441_item	2787891	et	3	main
läinud	doc_670731433441_item	2787914	et	4	main
aastal	doc_670731433441_item	2787925	et	3	main
murdas	doc_670731433441_item	2787927	et	4	main
naine	doc_670731433441_item	2787929	et	3	main
etendusel	doc_670731433441_item	2787933	et	4	main
pidas	doc_670731433441_item	2787937	et	3	main
aega	doc_670731433441_item	2787939	et	4	main
tantsimisest	doc_670731433441_item	2787940	et	4	main
eemal	doc_670731433441_item	2787941	et	3	main
on	doc_670731433441_item	2787947	et	4	main
tantsima	doc_670731433441_item	2787949	et	3	main
suurele	doc_670731433441_item	2787964	et	4	main
edule	doc_670731433441_item	2787965	et	3	main
täpselt	doc_670731433441_item	2787974	et	4	main
planeeritud	doc_670731433441_item	2787976	et	4	main
age	doc_670731433441_item	2787977	et	4	main
ja	doc_670731433441_item	2787978	et	3	main
toomas	doc_670731433441_item	2787979	et	3	main
tahavad	doc_670731433441_item	2787980	et	3	main
areneda	doc_670731433441_item	2787981	et	3	main
ja	doc_670731433441_item	2787982	et	3	main
paremal	doc_670731433441_item	2787985	et	4	main
tulevad	doc_670731433441_item	2787988	et	4	main
nad	doc_670731433441_item	2787989	et	3	main
esinema	doc_670731433441_item	2787990	et	3	main
tallinn	doc_670731433441_item	2787991	et	4	main
oks	doc_670731433441_item	2788000	et	3	main
sobiv	doc_670731433441_item	2788022	et	4	main
sõna	doc_670731433441_item	2788023	et	4	main
teksti	doc_670731433441_item	2788024	et	4	main
punkti	doc_670731433441_item	2788031	et	4	main
saada	doc_670731433441_item	2788042	et	4	main
aega	doc_670731433441_item	2788065	et	4	main
4	doc_670731433441_item	2788072	et	2	main
raha	doc_670731433441_item	2788076	et	4	main
seda	doc_670731433441_item	2788078	et	3	main
kokku	doc_670731433441_item	2788080	et	3	main
lähimast	doc_670731433441_item	2788095	et	4	main
ja	doc_670731433441_item	2788102	et	3	main
vead	doc_670731433441_item	2788124	et	4	main
kõik	doc_670731433441_item	2788132	et	4	main
geniaalne	doc_670731433441_item	2788133	et	3	main
1	doc_670731433441_item	2788144	et	2	main
annab	doc_670731433441_item	2787834	et	3	main
abielupaar	doc_670731433441_item	2787839	et	4	main
age	doc_670731433441_item	2787840	et	4	main
oks	doc_670731433441_item	2787841	et	3	main
ja	doc_670731433441_item	2787842	et	3	main
toomas	doc_670731433441_item	2787843	et	3	main
aga	doc_670731433441_item	2787849	et	3	main
praegu	doc_670731433441_item	2787851	et	3	main
toomas	doc_670731433441_item	2787862	et	3	main
vana	doc_670731433441_item	2787868	et	4	main
1997a	doc_670731433441_item	2787870	et	4	main
aastalt	doc_670731433441_item	2787875	et	3	main
nad	doc_670731433441_item	2787877	et	3	main
teatrid	doc_670731433441_item	2787883	et	3	main
armastama	doc_670731433441_item	2787887	et	3	main
isegi	doc_670731433441_item	2787892	et	4	main
suhtuma	doc_670731433441_item	2787896	et	3	main
sugugi	doc_670731433441_item	2787910	et	4	main
ja	doc_670731433441_item	2787916	et	3	main
eriti	doc_670731433441_item	2787917	et	3	main
agel	doc_670731433441_item	2787918	et	4	main
on	doc_670731433441_item	2787919	et	4	main
olnud	doc_670731433441_item	2787920	et	4	main
tervis	doc_670731433441_item	2787922	et	3	main
1990	doc_670731433441_item	2787924	et	2	main
luikede	doc_670731433441_item	2787930	et	3	main
jalaluu	doc_670731433441_item	2787934	et	4	main
olema	doc_670731433441_item	2787942	et	4	main
olema	doc_670731433441_item	2787943	et	4	main
age	doc_670731433441_item	2787944	et	4	main
ainult	doc_670731433441_item	2787951	et	4	main
tehtud	doc_670731433441_item	2787958	et	4	main
pakkumisi	doc_670731433441_item	2787959	et	4	main
tagasihoidlikus	doc_670731433441_item	2787969	et	4	main
lähiaja	doc_670731433441_item	2787971	et	3	main
lõuna-aafrika	doc_670731433441_item	2787996	et	4	main
lünka	doc_670731433441_item	2788021	et	4	main
õige	doc_670731433441_item	2788027	et	4	main
vastus	doc_670731433441_item	2788028	et	3	main
annab	doc_670731433441_item	2788029	et	3	main
ühe	doc_670731433441_item	2788030	et	4	main
koduõppesüsteem	doc_670731433441_item	2788039	et	3	main
sul	doc_670731433441_item	2788041	et	3	main
targemaks	doc_670731433441_item	2788043	et	4	main
siiski	doc_670731433441_item	2788045	et	4	main
käes	doc_670731433441_item	2788054	et	4	main
õppe	doc_670731433441_item	2788057	et	4	main
ajastu	doc_670731433441_item	2788058	et	4	main
mis	doc_670731433441_item	2788059	et	4	main
annab	doc_670731433441_item	2788060	et	3	main
sulle	doc_670731433441_item	2788061	et	3	main
3	doc_670731433441_item	2788062	et	2	main
vastavalt	doc_670731433441_item	2788070	et	4	main
on	doc_670731433441_item	2788075	et	4	main
vaja	doc_670731433441_item	2788083	et	4	main
ka	doc_670731433441_item	2788084	et	3	main
oled	doc_670731433441_item	2788088	et	3	main
postiasutusest	doc_670731433441_item	2788096	et	4	main
helikasseti	doc_670731433441_item	2788103	et	4	main
8	doc_670731433441_item	2788122	et	2	main
on	doc_670731433441_item	2788134	et	4	main
9	doc_670731433441_item	2788135	et	2	main
lihtne	doc_670731433441_item	2788136	et	3	main
meie	doc_670731433441_item	2788139	et	4	main
b	doc_670731433441_item	2788147	et	4	main
c	doc_670731433441_item	2788158	et	4	main
siiski	doc_670731433441_item	2788161	et	4	main
d	doc_670731433441_item	2788169	et	4	main
taga	doc_670731433441_item	2788204	et	4	main
d	doc_670731433441_item	2788218	et	4	main
muudab	doc_670731433441_item	2788219	et	3	main
mõlemal	doc_670731433441_item	2787915	et	3	main
etendus	doc_670731433441_item	2787932	et	4	main
ja	doc_670731433441_item	2787935	et	3	main
tansida	doc_670731433441_item	2787950	et	4	main
teineteisega	doc_670731433441_item	2787952	et	3	main
ka	doc_670731433441_item	2787960	et	3	main
eraldi	doc_670731433441_item	2787961	et	4	main
elavad	doc_670731433441_item	2787966	et	4	main
planeerima	doc_670731433441_item	2787975	et	3	main
tallinn	doc_670731433441_item	2787992	et	4	main
ja	doc_670731433441_item	2787993	et	3	main
seejärel	doc_670731433441_item	2787994	et	3	main
sõidavad	doc_670731433441_item	2787995	et	3	main
ja	doc_670731433441_item	2788001	et	3	main
edur	doc_670731433441_item	2788002	et	4	main
veel	doc_670731433441_item	2788003	et	4	main
tipus	doc_670731433441_item	2788004	et	3	main
suudavad	doc_670731433441_item	2788005	et	3	main
püsida	doc_670731433441_item	2788006	et	3	main
ei	doc_670731433441_item	2788007	et	4	main
oska	doc_670731433441_item	2788008	et	4	main
nad	doc_670731433441_item	2788009	et	3	main
ütlema	doc_670731433441_item	2788010	et	3	main
ütelda	doc_670731433441_item	2788011	et	4	main
nad	doc_670731433441_item	2788012	et	3	main
eelistavad	doc_670731433441_item	2788013	et	4	main
elada	doc_670731433441_item	2788014	et	3	main
üks	doc_670731433441_item	2788015	et	3	main
päev	doc_670731433441_item	2788016	et	3	main
üksi	doc_670731433441_item	2788017	et	4	main
päeva	doc_670731433441_item	2788018	et	4	main
kaupa	doc_670731433441_item	2788019	et	4	main
kirjutage	doc_670731433441_item	2788020	et	3	main
alt	doc_670731433441_item	2788025	et	4	main
iga	doc_670731433441_item	2788026	et	4	main
1	doc_670731433441_item	2788034	et	2	main
unusta	doc_670731433441_item	2788036	et	4	main
2	doc_670731433441_item	2788044	et	2	main
seal	doc_670731433441_item	2788046	et	4	main
kus	doc_670731433441_item	2788047	et	3	main
ja	doc_670731433441_item	2788048	et	3	main
millal	doc_670731433441_item	2788049	et	3	main
sa	doc_670731433441_item	2788050	et	3	main
seda	doc_670731433441_item	2788051	et	3	main
parasjagu	doc_670731433441_item	2788052	et	3	main
on	doc_670731433441_item	2788055	et	4	main
individuaalsele	doc_670731433441_item	2788071	et	3	main
pisut	doc_670731433441_item	2788085	et	3	main
saad	doc_670731433441_item	2788091	et	4	main
igal	doc_670731433441_item	2788097	et	3	main
kuul	doc_670731433441_item	2788098	et	4	main
6	doc_670731433441_item	2788104	et	2	main
ning	doc_670731433441_item	2788125	et	3	main
vajaduse	doc_670731433441_item	2788127	et	3	main
10	doc_670731433441_item	2788137	et	2	main
sobid	doc_670731433441_item	2788146	et	4	main
c	doc_670731433441_item	2788149	et	4	main
solvud	doc_670731433441_item	2788152	et	3	main
just	doc_670731433441_item	2788155	et	3	main
kuigi	doc_670731433441_item	2788159	et	3	main
vabanduse	doc_670731433441_item	2788166	et	4	main
c	doc_670731433441_item	2788167	et	4	main
varanduse	doc_670731433441_item	2788168	et	3	main
toomas	doc_670731433441_item	2787946	et	3	main
paaris	doc_670731433441_item	2787953	et	4	main
kuigi	doc_670731433441_item	2787954	et	3	main
nemad	doc_670731433441_item	2787955	et	3	main
nendel	doc_670731433441_item	2787956	et	4	main
tantsimiseks	doc_670731433441_item	2787962	et	4	main
tantsijad	doc_670731433441_item	2787967	et	4	main
esinemised	doc_670731433441_item	2787972	et	4	main
on	doc_670731433441_item	2787973	et	4	main
veelgi	doc_670731433441_item	2787983	et	4	main
tantsida	doc_670731433441_item	2787986	et	3	main
lõuna-aafrikas	doc_670731433441_item	2787997	et	4	main
kui	doc_670731433441_item	2787998	et	3	main
kaua	doc_670731433441_item	2787999	et	3	main
soovid	doc_670731433441_item	2788035	et	4	main
klassiruum	doc_670731433441_item	2788038	et	3	main
võimaldab	doc_670731433441_item	2788040	et	3	main
soovid	doc_670731433441_item	2788053	et	4	main
interaktiivse	doc_670731433441_item	2788056	et	3	main
ning	doc_670731433441_item	2788066	et	3	main
aeg	doc_670731433441_item	2788074	et	3	main
saada	doc_670731433441_item	2788081	et	4	main
on	doc_670731433441_item	2788082	et	4	main
kui	doc_670731433441_item	2788087	et	3	main
registreerunud	doc_670731433441_item	2788090	et	4	main
kontorist	doc_670731433441_item	2788093	et	4	main
või	doc_670731433441_item	2788094	et	4	main
ning	doc_670731433441_item	2788105	et	3	main
õpi	doc_670731433441_item	2788032	et	4	main
millal	doc_670731433441_item	2788033	et	3	main
umbne	doc_670731433441_item	2788037	et	3	main
vabaduse	doc_670731433441_item	2788063	et	4	main
planeerida	doc_670731433441_item	2788064	et	3	main
eelise	doc_670731433441_item	2788067	et	4	main
omandada	doc_670731433441_item	2788068	et	3	main
teadmisi	doc_670731433441_item	2788069	et	4	main
tasakesi	doc_670731433441_item	2788073	et	3	main
et	doc_670731433441_item	2788077	et	3	main
5	doc_670731433441_item	2788079	et	2	main
tarkust	doc_670731433441_item	2788086	et	4	main
kursusele	doc_670731433441_item	2788089	et	3	main
meie	doc_670731433441_item	2788092	et	4	main
kätte	doc_670731433441_item	2788099	et	4	main
õppematerjalid	doc_670731433441_item	2788100	et	3	main
raamatu	doc_670731433441_item	2788101	et	4	main
kodutöö	doc_670731433441_item	2788106	et	4	main
kursuse	doc_670731433441_item	2788107	et	3	main
7	doc_670731433441_item	2788108	et	2	main
eest	doc_670731433441_item	2788109	et	4	main
selle	doc_670731433441_item	2788111	et	4	main
tasud	doc_670731433441_item	2788110	et	4	main
kättesaamisel	doc_670731433441_item	2788112	et	4	main
saada	doc_670731433441_item	2788113	et	4	main
täidetud	doc_670731433441_item	2788114	et	4	main
kodutöö	doc_670731433441_item	2788115	et	4	main
meile	doc_670731433441_item	2788116	et	4	main
tagasi	doc_670731433441_item	2788117	et	3	main
õpetaja	doc_670731433441_item	2788118	et	4	main
vaatab	doc_670731433441_item	2788119	et	3	main
selle	doc_670731433441_item	2788120	et	4	main
üle	doc_670731433441_item	2788121	et	3	main
ka	doc_670731433441_item	2788129	et	3	main
lisaküsimustele	doc_670731433441_item	2788131	et	4	main
virtuaalkodu	doc_670731433441_item	2788140	et	4	main
või	doc_670731433441_item	2788141	et	4	main
postitage	doc_670731433441_item	2788142	et	3	main
kupong	doc_670731433441_item	2788143	et	3	main
soovid	doc_670731433441_item	2788148	et	4	main
2	doc_670731433441_item	2788153	et	2	main
seega	doc_670731433441_item	2788157	et	4	main
d	doc_670731433441_item	2788160	et	4	main
3	doc_670731433441_item	2788162	et	2	main
a	doc_670731433441_item	2788163	et	4	main
a	doc_670731433441_item	2788172	et	4	main
b	doc_670731433441_item	2788174	et	4	main
b	doc_670731433441_item	2788205	et	4	main
eest	doc_670731433441_item	2788208	et	4	main
8	doc_670731433441_item	2788211	et	2	main
d	doc_670731433441_item	2788227	et	4	main
lihtne	doc_670731433441_item	2788228	et	3	main
d	doc_670731433441_item	2788236	et	4	main
numbrid	doc_670731433442_item	2788241	et	3	main
punkti	doc_670731433442_item	2788249	et	4	main
maailmakuulsad	doc_670731433442_item	2788250	et	3	main
balletitantsijad	doc_670731433442_item	2788251	et	3	main
inglismaa	doc_670731433442_item	2788265	et	4	main
aastane	doc_670731433442_item	2788273	et	4	main
ja	doc_670731433442_item	2788274	et	3	main
toomas	doc_670731433442_item	2788275	et	3	main
on	doc_670731433442_item	2788276	et	4	main
ja	doc_670731433442_item	2788293	et	3	main
teatride	doc_670731433442_item	2788298	et	4	main
inglismaal	doc_670731433442_item	2788299	et	4	main
armastas	doc_670731433442_item	2788301	et	3	main
kirjutab	doc_670731433441_item	2788123	et	3	main
vastab	doc_670731433441_item	2788126	et	3	main
korral	doc_670731433441_item	2788128	et	4	main
tekkinud	doc_670731433441_item	2788130	et	4	main
tulge	doc_670731433441_item	2788138	et	3	main
soovitad	doc_670731433441_item	2788150	et	3	main
a	doc_670731433441_item	2788154	et	4	main
b	doc_670731433441_item	2788156	et	4	main
4	doc_670731433441_item	2788171	et	2	main
tasemele	doc_670731433441_item	2788175	et	3	main
c	doc_670731433441_item	2788176	et	4	main
tasakesi	doc_670731433441_item	2788177	et	3	main
d	doc_670731433441_item	2788178	et	4	main
tasakaalule	doc_670731433441_item	2788179	et	3	main
5	doc_670731433441_item	2788180	et	2	main
a	doc_670731433441_item	2788181	et	4	main
kokku	doc_670731433441_item	2788182	et	3	main
saada	doc_670731433441_item	2788183	et	4	main
b	doc_670731433441_item	2788184	et	4	main
kokku	doc_670731433441_item	2788185	et	3	main
liita	doc_670731433441_item	2788186	et	4	main
c	doc_670731433441_item	2788187	et	4	main
kokku	doc_670731433441_item	2788188	et	3	main
hoida	doc_670731433441_item	2788189	et	3	main
d	doc_670731433441_item	2788190	et	4	main
kokku	doc_670731433441_item	2788191	et	3	main
panna	doc_670731433441_item	2788192	et	4	main
6	doc_670731433441_item	2788193	et	2	main
a	doc_670731433441_item	2788194	et	4	main
ning	doc_670731433441_item	2788195	et	3	main
b	doc_670731433441_item	2788196	et	4	main
vaid	doc_670731433441_item	2788197	et	3	main
c	doc_670731433441_item	2788198	et	4	main
kuid	doc_670731433441_item	2788199	et	4	main
d	doc_670731433441_item	2788200	et	4	main
et	doc_670731433441_item	2788201	et	3	main
7	doc_670731433441_item	2788202	et	2	main
a	doc_670731433441_item	2788145	et	4	main
d	doc_670731433441_item	2788151	et	4	main
vajaduse	doc_670731433441_item	2788164	et	3	main
b	doc_670731433441_item	2788165	et	4	main
vabaduse	doc_670731433441_item	2788170	et	4	main
tasule	doc_670731433441_item	2788173	et	3	main
a	doc_670731433441_item	2788203	et	4	main
c	doc_670731433441_item	2788207	et	4	main
ees	doc_670731433441_item	2788210	et	4	main
a	doc_670731433441_item	2788212	et	4	main
kirjutab	doc_670731433441_item	2788213	et	3	main
b	doc_670731433441_item	2788214	et	4	main
palub	doc_670731433441_item	2788215	et	3	main
c	doc_670731433441_item	2788225	et	4	main
liikuv	doc_670731433441_item	2788226	et	4	main
c	doc_670731433441_item	2788234	et	4	main
harjutus	doc_670731433442_item	2788238	et	4	main
sõnadega	doc_670731433442_item	2788243	et	3	main
õige	doc_670731433442_item	2788245	et	4	main
age	doc_670731433442_item	2788253	et	4	main
oks	doc_670731433442_item	2788254	et	3	main
edur	doc_670731433442_item	2788257	et	4	main
london	doc_670731433442_item	2788266	et	4	main
londonis	doc_670731433442_item	2788268	et	4	main
age	doc_670731433442_item	2788269	et	4	main
32	doc_670731433442_item	2788277	et	2	main
kolmküne	doc_670731433442_item	2788278	et	4	main
kaks	doc_670731433442_item	2788279	et	3	main
aastat	doc_670731433442_item	2788280	et	3	main
üheksasaja	doc_670731433442_item	2788285	et	4	main
seitsmiselt	doc_670731433442_item	2788287	et	4	main
aastalt	doc_670731433442_item	2788288	et	3	main
on	doc_670731433442_item	2788289	et	4	main
nad	doc_670731433442_item	2788290	et	3	main
erinevad	doc_670731433442_item	2788295	et	4	main
erinevade	doc_670731433442_item	2788297	et	4	main
armastama	doc_670731433442_item	2788300	et	3	main
kriitikud	doc_670731433442_item	2788307	et	3	main
alati	doc_670731433442_item	2788324	et	4	main
kergelt	doc_670731433442_item	2788326	et	4	main
luikede	doc_670731433442_item	2788343	et	3	main
mõnda	doc_670731433442_item	2788351	et	4	main
nende	doc_670731433442_item	2788383	et	4	main
lähiaja	doc_670731433442_item	2788384	et	3	main
täpselt	doc_670731433442_item	2788387	et	4	main
tantsida	doc_670731433442_item	2788399	et	3	main
veel	doc_670731433442_item	2788416	et	4	main
tipus	doc_670731433442_item	2788417	et	3	main
suudavad	doc_670731433442_item	2788418	et	3	main
püsida	doc_670731433442_item	2788419	et	3	main
ütelda	doc_670731433442_item	2788424	et	4	main
üks	doc_670731433442_item	2788428	et	3	main
üksi	doc_670731433442_item	2788430	et	4	main
päeva	doc_670731433442_item	2788431	et	4	main
teksti	doc_670731433442_item	2788437	et	4	main
klassiruum	doc_670731433442_item	2788451	et	3	main
sul	doc_670731433442_item	2788454	et	3	main
soovid	doc_670731433442_item	2788466	et	4	main
käes	doc_670731433442_item	2788467	et	4	main
annab	doc_670731433442_item	2788473	et	3	main
sulle	doc_670731433442_item	2788474	et	3	main
helikasseti	doc_670731433442_item	2788516	et	4	main
saada	doc_670731433442_item	2788526	et	4	main
tagasi	doc_670731433442_item	2788530	et	3	main
õpetaja	doc_670731433442_item	2788531	et	4	main
virtuaalkodu	doc_670731433442_item	2788553	et	4	main
a	doc_670731433442_item	2788585	et	4	main
b	doc_670731433442_item	2788587	et	4	main
tasemele	doc_670731433442_item	2788588	et	3	main
c	doc_670731433442_item	2788589	et	4	main
tasakesi	doc_670731433442_item	2788590	et	3	main
d	doc_670731433442_item	2788591	et	4	main
tasakaalule	doc_670731433442_item	2788592	et	3	main
5	doc_670731433442_item	2788593	et	2	main
kokku	doc_670731433442_item	2788595	et	3	main
taga	doc_670731433442_item	2788617	et	4	main
a	doc_670731433442_item	2788625	et	4	main
palub	doc_670731433442_item	2788628	et	3	main
liikuv	doc_670731433442_item	2788639	et	4	main
c	doc_670731433442_item	2788647	et	4	main
numbrid	doc_670731433443_item	2788654	et	3	main
sõnadega	doc_670731433443_item	2788656	et	3	main
ette	doc_670731433441_item	2788206	et	4	main
d	doc_670731433441_item	2788209	et	4	main
9	doc_670731433441_item	2788220	et	2	main
10	doc_670731433441_item	2788229	et	2	main
a	doc_670731433441_item	2788230	et	4	main
tulge	doc_670731433441_item	2788231	et	3	main
b	doc_670731433441_item	2788232	et	4	main
käige	doc_670731433441_item	2788233	et	3	main
külastage	doc_670731433441_item	2788235	et	3	main
avage	doc_670731433442_item	2788239	et	3	main
iga	doc_670731433442_item	2788244	et	4	main
vastus	doc_670731433442_item	2788246	et	3	main
annab	doc_670731433442_item	2788247	et	3	main
ühe	doc_670731433442_item	2788248	et	4	main
toomas	doc_670731433442_item	2788256	et	3	main
on	doc_670731433442_item	2788270	et	4	main
30	doc_670731433442_item	2788271	et	2	main
alates	doc_670731433442_item	2788282	et	3	main
1997a	doc_670731433442_item	2788283	et	4	main
üheksakümne	doc_670731433442_item	2788286	et	4	main
vabakutseline	doc_670731433442_item	2788292	et	4	main
isegi	doc_670731433442_item	2788305	et	4	main
suhtuma	doc_670731433442_item	2788308	et	3	main
sugugi	doc_670731433442_item	2788323	et	4	main
nii	doc_670731433442_item	2788325	et	3	main
läinud	doc_670731433442_item	2788327	et	4	main
mõlemal	doc_670731433442_item	2788328	et	3	main
ja	doc_670731433442_item	2788329	et	3	main
eriti	doc_670731433442_item	2788330	et	3	main
agel	doc_670731433442_item	2788331	et	4	main
murdma	doc_670731433442_item	2788339	et	3	main
naine	doc_670731433442_item	2788342	et	3	main
aega	doc_670731433442_item	2788352	et	4	main
tantsimisest	doc_670731433442_item	2788353	et	4	main
eemal	doc_670731433442_item	2788354	et	3	main
toomas	doc_670731433442_item	2788359	et	3	main
otsustanud	doc_670731433442_item	2788361	et	4	main
esinemised	doc_670731433442_item	2788385	et	4	main
planeeritud	doc_670731433442_item	2788389	et	4	main
age	doc_670731433442_item	2788390	et	4	main
toomas	doc_670731433442_item	2788392	et	3	main
tahavad	doc_670731433442_item	2788393	et	3	main
areneda	doc_670731433442_item	2788394	et	3	main
ja	doc_670731433442_item	2788395	et	3	main
veelgi	doc_670731433442_item	2788396	et	4	main
parem	doc_670731433442_item	2788397	et	4	main
tallinn	doc_670731433442_item	2788404	et	4	main
ja	doc_670731433442_item	2788406	et	3	main
sõidavad	doc_670731433442_item	2788408	et	3	main
oska	doc_670731433442_item	2788421	et	4	main
lünka	doc_670731433442_item	2788434	et	4	main
umbne	doc_670731433442_item	2788450	et	3	main
võimaldab	doc_670731433442_item	2788453	et	3	main
2	doc_670731433442_item	2788457	et	2	main
õppe	doc_670731433442_item	2788470	et	4	main
kodutöö	doc_670731433442_item	2788519	et	4	main
eest	doc_670731433442_item	2788522	et	4	main
selle	doc_670731433442_item	2788524	et	4	main
kättesaamisel	doc_670731433442_item	2788525	et	4	main
kõik	doc_670731433442_item	2788545	et	4	main
geniaalne	doc_670731433442_item	2788546	et	3	main
on	doc_670731433442_item	2788547	et	4	main
9	doc_670731433442_item	2788548	et	2	main
lihtne	doc_670731433442_item	2788549	et	3	main
b	doc_670731433442_item	2788560	et	4	main
kuigi	doc_670731433442_item	2788572	et	3	main
a	doc_670731433442_item	2788576	et	4	main
tasule	doc_670731433442_item	2788586	et	3	main
saada	doc_670731433442_item	2788596	et	4	main
panna	doc_670731433442_item	2788605	et	4	main
d	doc_670731433442_item	2788613	et	4	main
et	doc_670731433442_item	2788614	et	3	main
c	doc_670731433442_item	2788620	et	4	main
c	doc_670731433441_item	2788216	et	4	main
parandab	doc_670731433441_item	2788217	et	3	main
a	doc_670731433441_item	2788221	et	4	main
b	doc_670731433441_item	2788223	et	4	main
sulud	doc_670731433442_item	2788240	et	3	main
kirjutage	doc_670731433442_item	2788242	et	3	main
pärit	doc_670731433442_item	2788259	et	3	main
kolmkümmend	doc_670731433442_item	2788272	et	4	main
vana	doc_670731433442_item	2788281	et	4	main
vabakutseline	doc_670731433442_item	2788291	et	4	main
teatrid	doc_670731433442_item	2788296	et	3	main
ning	doc_670731433442_item	2788304	et	3	main
1990	doc_670731433442_item	2788337	et	2	main
aastal	doc_670731433442_item	2788338	et	3	main
pidama	doc_670731433442_item	2788349	et	4	main
pidas	doc_670731433442_item	2788350	et	3	main
olema	doc_670731433442_item	2788356	et	4	main
on	doc_670731433442_item	2788360	et	4	main
tantsima	doc_670731433442_item	2788362	et	3	main
esinema	doc_670731433442_item	2788403	et	3	main
ei	doc_670731433442_item	2788420	et	4	main
liigne	doc_670731433441_item	2788222	et	3	main
libe	doc_670731433441_item	2788224	et	3	main
minge	doc_670731433441_item	2788237	et	3	main
abielupaar	doc_670731433442_item	2788252	et	4	main
ja	doc_670731433442_item	2788255	et	3	main
on	doc_670731433442_item	2788258	et	4	main
eesti	doc_670731433442_item	2788260	et	4	main
eestist	doc_670731433442_item	2788261	et	3	main
aga	doc_670731433442_item	2788262	et	3	main
elavad	doc_670731433442_item	2788263	et	4	main
praegu	doc_670731433442_item	2788264	et	3	main
inglismaal	doc_670731433442_item	2788267	et	4	main
tuhande	doc_670731433442_item	2788284	et	3	main
esinevad	doc_670731433442_item	2788294	et	4	main
karmid	doc_670731433442_item	2788306	et	4	main
suhtuma	doc_670731433442_item	2788309	et	3	main
nendesse	doc_670731433442_item	2788310	et	4	main
üldiselt	doc_670731433442_item	2788311	et	4	main
hästi	doc_670731433442_item	2788312	et	3	main
viimased	doc_670731433442_item	2788313	et	3	main
artiklid	doc_670731433442_item	2788314	et	3	main
räägivad	doc_670731433442_item	2788315	et	3	main
noored	doc_670731433442_item	2788316	et	3	main
noordega	doc_670731433442_item	2788317	et	4	main
ainult	doc_670731433442_item	2788318	et	4	main
ülivõrdes	doc_670731433442_item	2788319	et	3	main
kuid	doc_670731433442_item	2788320	et	4	main
pole	doc_670731433442_item	2788322	et	3	main
neid	doc_670731433442_item	2788302	et	4	main
väga	doc_670731433442_item	2788303	et	3	main
kõik	doc_670731433442_item	2788321	et	4	main
olnud	doc_670731433442_item	2788333	et	4	main
probleeme	doc_670731433442_item	2788334	et	3	main
tervis	doc_670731433442_item	2788335	et	3	main
tervist	doc_670731433442_item	2788336	et	4	main
murdas	doc_670731433442_item	2788340	et	4	main
järve	doc_670731433442_item	2788344	et	4	main
etendusel	doc_670731433442_item	2788346	et	4	main
jalaluu	doc_670731433442_item	2788347	et	4	main
ja	doc_670731433442_item	2788348	et	3	main
olema	doc_670731433442_item	2788355	et	4	main
ja	doc_670731433442_item	2788358	et	3	main
on	doc_670731433442_item	2788386	et	4	main
planeerima	doc_670731433442_item	2788388	et	3	main
paremal	doc_670731433442_item	2788398	et	4	main
märtsis	doc_670731433442_item	2788400	et	3	main
tulevad	doc_670731433442_item	2788401	et	4	main
nad	doc_670731433442_item	2788402	et	3	main
lõuna-aafrika	doc_670731433442_item	2788409	et	4	main
kui	doc_670731433442_item	2788411	et	3	main
kaua	doc_670731433442_item	2788412	et	3	main
oks	doc_670731433442_item	2788413	et	3	main
ja	doc_670731433442_item	2788414	et	3	main
edur	doc_670731433442_item	2788415	et	4	main
ütlema	doc_670731433442_item	2788423	et	3	main
eelistavad	doc_670731433442_item	2788426	et	4	main
sõna	doc_670731433442_item	2788436	et	4	main
soovid	doc_670731433442_item	2788448	et	4	main
targemaks	doc_670731433442_item	2788456	et	4	main
siiski	doc_670731433442_item	2788458	et	4	main
seal	doc_670731433442_item	2788459	et	4	main
kus	doc_670731433442_item	2788460	et	3	main
ja	doc_670731433442_item	2788461	et	3	main
millal	doc_670731433442_item	2788462	et	3	main
sa	doc_670731433442_item	2788463	et	3	main
seda	doc_670731433442_item	2788464	et	3	main
parasjagu	doc_670731433442_item	2788465	et	3	main
ajastu	doc_670731433442_item	2788471	et	4	main
raamatu	doc_670731433442_item	2788514	et	4	main
ja	doc_670731433442_item	2788515	et	3	main
on	doc_670731433442_item	2788332	et	4	main
noor	doc_670731433442_item	2788341	et	3	main
etendus	doc_670731433442_item	2788345	et	4	main
age	doc_670731433442_item	2788357	et	4	main
tansida	doc_670731433442_item	2788363	et	4	main
ainult	doc_670731433442_item	2788364	et	4	main
teineteisega	doc_670731433442_item	2788365	et	3	main
paaris	doc_670731433442_item	2788366	et	4	main
kuigi	doc_670731433442_item	2788367	et	3	main
nemad	doc_670731433442_item	2788368	et	3	main
nendel	doc_670731433442_item	2788369	et	4	main
on	doc_670731433442_item	2788370	et	4	main
tehtud	doc_670731433442_item	2788371	et	4	main
pakkumisi	doc_670731433442_item	2788372	et	4	main
ka	doc_670731433442_item	2788373	et	3	main
eraldi	doc_670731433442_item	2788374	et	4	main
tantsimiseks	doc_670731433442_item	2788375	et	4	main
vaatamata	doc_670731433442_item	2788376	et	4	main
suurele	doc_670731433442_item	2788377	et	4	main
edule	doc_670731433442_item	2788378	et	3	main
elavad	doc_670731433442_item	2788379	et	4	main
tantsijad	doc_670731433442_item	2788380	et	4	main
tagasihoidlik	doc_670731433442_item	2788381	et	3	main
tagasihoidlikus	doc_670731433442_item	2788382	et	4	main
ja	doc_670731433442_item	2788391	et	3	main
tallinn	doc_670731433442_item	2788405	et	4	main
seejärel	doc_670731433442_item	2788407	et	3	main
lõuna-aafrikas	doc_670731433442_item	2788410	et	4	main
nad	doc_670731433442_item	2788422	et	3	main
elada	doc_670731433442_item	2788427	et	3	main
päev	doc_670731433442_item	2788429	et	3	main
kaupa	doc_670731433442_item	2788432	et	4	main
kirjutage	doc_670731433442_item	2788433	et	3	main
alt	doc_670731433442_item	2788438	et	4	main
õpi	doc_670731433442_item	2788445	et	4	main
millal	doc_670731433442_item	2788446	et	3	main
1	doc_670731433442_item	2788447	et	2	main
mis	doc_670731433442_item	2788472	et	4	main
3	doc_670731433442_item	2788475	et	2	main
vabaduse	doc_670731433442_item	2788476	et	4	main
planeerida	doc_670731433442_item	2788477	et	3	main
aega	doc_670731433442_item	2788478	et	4	main
ning	doc_670731433442_item	2788479	et	3	main
eelise	doc_670731433442_item	2788480	et	4	main
omandada	doc_670731433442_item	2788481	et	3	main
6	doc_670731433442_item	2788517	et	2	main
ning	doc_670731433442_item	2788518	et	3	main
meile	doc_670731433442_item	2788529	et	4	main
selle	doc_670731433442_item	2788533	et	4	main
üle	doc_670731433442_item	2788534	et	3	main
8	doc_670731433442_item	2788535	et	2	main
kirjutab	doc_670731433442_item	2788536	et	3	main
vead	doc_670731433442_item	2788537	et	4	main
a	doc_670731433442_item	2788558	et	4	main
vajaduse	doc_670731433442_item	2788577	et	3	main
b	doc_670731433442_item	2788578	et	4	main
c	doc_670731433442_item	2788580	et	4	main
a	doc_670731433442_item	2788594	et	4	main
liita	doc_670731433442_item	2788599	et	4	main
b	doc_670731433442_item	2788609	et	4	main
vaid	doc_670731433442_item	2788610	et	3	main
b	doc_670731433442_item	2788618	et	4	main
ette	doc_670731433442_item	2788619	et	4	main
d	doc_670731433442_item	2788622	et	4	main
b	doc_670731433442_item	2788627	et	4	main
9	doc_670731433442_item	2788633	et	2	main
a	doc_670731433442_item	2788634	et	4	main
liigne	doc_670731433442_item	2788635	et	3	main
a	doc_670731433442_item	2788643	et	4	main
tulge	doc_670731433442_item	2788644	et	3	main
minge	doc_670731433442_item	2788650	et	3	main
sulud	doc_670731433443_item	2788653	et	3	main
õige	doc_670731433443_item	2788658	et	4	main
vastus	doc_670731433443_item	2788659	et	3	main
annab	doc_670731433443_item	2788660	et	3	main
ühe	doc_670731433443_item	2788661	et	4	main
eesti	doc_670731433443_item	2788673	et	4	main
eestist	doc_670731433443_item	2788674	et	3	main
aga	doc_670731433443_item	2788675	et	3	main
elavad	doc_670731433443_item	2788676	et	4	main
praegu	doc_670731433443_item	2788677	et	3	main
age	doc_670731433443_item	2788682	et	4	main
on	doc_670731433443_item	2788689	et	4	main
kaks	doc_670731433443_item	2788692	et	3	main
vana	doc_670731433443_item	2788694	et	4	main
1997a	doc_670731433443_item	2788696	et	4	main
seitsmest	doc_670731433443_item	2788700	et	4	main
teatrid	doc_670731433443_item	2788709	et	3	main
nendesse	doc_670731433443_item	2788722	et	4	main
üldiselt	doc_670731433443_item	2788723	et	4	main
hästi	doc_670731433443_item	2788724	et	3	main
noortelt	doc_670731433443_item	2788729	et	3	main
pole	doc_670731433443_item	2788734	et	3	main
kergelt	doc_670731433443_item	2788738	et	4	main
agel	doc_670731433443_item	2788743	et	4	main
pidama	doc_670731433443_item	2788761	et	4	main
ka	doc_670731433443_item	2788783	et	3	main
eraldi	doc_670731433443_item	2788784	et	4	main
esinemised	doc_670731433443_item	2788795	et	4	main
paremini	doc_670731433443_item	2788808	et	4	main
lõuna-aafrikal	doc_670731433443_item	2788820	et	4	main
nad	doc_670731433442_item	2788425	et	3	main
sobiv	doc_670731433442_item	2788435	et	4	main
iga	doc_670731433442_item	2788439	et	4	main
õige	doc_670731433442_item	2788440	et	4	main
vastus	doc_670731433442_item	2788441	et	3	main
annab	doc_670731433442_item	2788442	et	3	main
ühe	doc_670731433442_item	2788443	et	4	main
punkti	doc_670731433442_item	2788444	et	4	main
unusta	doc_670731433442_item	2788449	et	4	main
koduõppesüsteem	doc_670731433442_item	2788452	et	3	main
saada	doc_670731433442_item	2788455	et	4	main
on	doc_670731433442_item	2788468	et	4	main
interaktiivse	doc_670731433442_item	2788469	et	3	main
teadmisi	doc_670731433442_item	2788482	et	4	main
vastavalt	doc_670731433442_item	2788483	et	4	main
individuaalsele	doc_670731433442_item	2788484	et	3	main
4	doc_670731433442_item	2788485	et	2	main
tasakesi	doc_670731433442_item	2788486	et	3	main
aeg	doc_670731433442_item	2788487	et	3	main
on	doc_670731433442_item	2788488	et	4	main
raha	doc_670731433442_item	2788489	et	4	main
seda	doc_670731433442_item	2788491	et	3	main
et	doc_670731433442_item	2788490	et	3	main
5	doc_670731433442_item	2788492	et	2	main
kokku	doc_670731433442_item	2788493	et	3	main
saada	doc_670731433442_item	2788494	et	4	main
on	doc_670731433442_item	2788495	et	4	main
vaja	doc_670731433442_item	2788496	et	4	main
ka	doc_670731433442_item	2788497	et	3	main
pisut	doc_670731433442_item	2788498	et	3	main
tarkust	doc_670731433442_item	2788499	et	4	main
kui	doc_670731433442_item	2788500	et	3	main
oled	doc_670731433442_item	2788501	et	3	main
kursusele	doc_670731433442_item	2788502	et	3	main
registreerunud	doc_670731433442_item	2788503	et	4	main
saad	doc_670731433442_item	2788504	et	4	main
meie	doc_670731433442_item	2788505	et	4	main
kontorist	doc_670731433442_item	2788506	et	4	main
või	doc_670731433442_item	2788507	et	4	main
postiasutusest	doc_670731433442_item	2788509	et	4	main
lähimast	doc_670731433442_item	2788508	et	4	main
igal	doc_670731433442_item	2788510	et	3	main
kuul	doc_670731433442_item	2788511	et	4	main
kätte	doc_670731433442_item	2788512	et	4	main
õppematerjalid	doc_670731433442_item	2788513	et	3	main
kursuse	doc_670731433442_item	2788520	et	3	main
7	doc_670731433442_item	2788521	et	2	main
täidetud	doc_670731433442_item	2788527	et	4	main
tekkinud	doc_670731433442_item	2788543	et	4	main
lisaküsimustele	doc_670731433442_item	2788544	et	4	main
või	doc_670731433442_item	2788554	et	4	main
postitage	doc_670731433442_item	2788555	et	3	main
kupong	doc_670731433442_item	2788556	et	3	main
1	doc_670731433442_item	2788557	et	2	main
d	doc_670731433442_item	2788573	et	4	main
siiski	doc_670731433442_item	2788574	et	4	main
vabaduse	doc_670731433442_item	2788583	et	4	main
4	doc_670731433442_item	2788584	et	2	main
kokku	doc_670731433442_item	2788598	et	3	main
kokku	doc_670731433442_item	2788601	et	3	main
hoida	doc_670731433442_item	2788602	et	3	main
kokku	doc_670731433442_item	2788604	et	3	main
6	doc_670731433442_item	2788606	et	2	main
a	doc_670731433442_item	2788607	et	4	main
ning	doc_670731433442_item	2788608	et	3	main
7	doc_670731433442_item	2788615	et	2	main
a	doc_670731433442_item	2788616	et	4	main
ees	doc_670731433442_item	2788623	et	4	main
b	doc_670731433442_item	2788636	et	4	main
b	doc_670731433442_item	2788645	et	4	main
d	doc_670731433442_item	2788649	et	4	main
avage	doc_670731433443_item	2788652	et	3	main
abielupaar	doc_670731433443_item	2788665	et	4	main
toomas	doc_670731433443_item	2788669	et	3	main
on	doc_670731433443_item	2788671	et	4	main
london	doc_670731433443_item	2788679	et	4	main
inglismaal	doc_670731433443_item	2788680	et	4	main
londonis	doc_670731433443_item	2788681	et	4	main
kolmekümne	doc_670731433443_item	2788685	et	4	main
ja	doc_670731433443_item	2788687	et	3	main
tuhande	doc_670731433443_item	2788697	et	3	main
aastast	doc_670731433443_item	2788701	et	4	main
suhtunud	doc_670731433443_item	2788721	et	4	main
viimased	doc_670731433443_item	2788725	et	3	main
artiklid	doc_670731433443_item	2788726	et	3	main
räägivad	doc_670731433443_item	2788727	et	3	main
noored	doc_670731433443_item	2788728	et	3	main
ainult	doc_670731433443_item	2788730	et	4	main
ülivõrdes	doc_670731433443_item	2788731	et	3	main
kuid	doc_670731433443_item	2788732	et	4	main
alati	doc_670731433443_item	2788736	et	4	main
jalaluu	doc_670731433443_item	2788759	et	4	main
ja	doc_670731433443_item	2788760	et	3	main
tantsimiseks	doc_670731433443_item	2788785	et	4	main
elavad	doc_670731433443_item	2788789	et	4	main
tagasihoidlik	doc_670731433443_item	2788791	et	3	main
täpselt	doc_670731433443_item	2788797	et	4	main
planeerima	doc_670731433443_item	2788798	et	3	main
planeeritud	doc_670731433443_item	2788799	et	4	main
kui	doc_670731433443_item	2788821	et	3	main
oks	doc_670731433443_item	2788823	et	3	main
eelistavad	doc_670731433443_item	2788836	et	4	main
ühe	doc_670731433443_item	2788840	et	4	main
iga	doc_670731433443_item	2788849	et	4	main
õige	doc_670731433443_item	2788850	et	4	main
annab	doc_670731433443_item	2788852	et	3	main
ühe	doc_670731433443_item	2788853	et	4	main
klassiruum	doc_670731433443_item	2788861	et	3	main
koduõppesüsteem	doc_670731433443_item	2788862	et	3	main
seda	doc_670731433443_item	2788874	et	3	main
mis	doc_670731433443_item	2788882	et	4	main
annab	doc_670731433443_item	2788883	et	3	main
sulle	doc_670731433443_item	2788884	et	3	main
vabaduse	doc_670731433443_item	2788886	et	4	main
tasud	doc_670731433442_item	2788523	et	4	main
kodutöö	doc_670731433442_item	2788528	et	4	main
vaatab	doc_670731433442_item	2788532	et	3	main
ning	doc_670731433442_item	2788538	et	3	main
vastab	doc_670731433442_item	2788539	et	3	main
vajaduse	doc_670731433442_item	2788540	et	3	main
korral	doc_670731433442_item	2788541	et	4	main
ka	doc_670731433442_item	2788542	et	3	main
10	doc_670731433442_item	2788550	et	2	main
tulge	doc_670731433442_item	2788551	et	3	main
meie	doc_670731433442_item	2788552	et	4	main
sobid	doc_670731433442_item	2788559	et	4	main
soovid	doc_670731433442_item	2788561	et	4	main
c	doc_670731433442_item	2788562	et	4	main
soovitad	doc_670731433442_item	2788563	et	3	main
d	doc_670731433442_item	2788564	et	4	main
solvud	doc_670731433442_item	2788565	et	3	main
2	doc_670731433442_item	2788566	et	2	main
a	doc_670731433442_item	2788567	et	4	main
just	doc_670731433442_item	2788568	et	3	main
b	doc_670731433442_item	2788569	et	4	main
seega	doc_670731433442_item	2788570	et	4	main
c	doc_670731433442_item	2788571	et	4	main
3	doc_670731433442_item	2788575	et	2	main
vabanduse	doc_670731433442_item	2788579	et	4	main
varanduse	doc_670731433442_item	2788581	et	3	main
d	doc_670731433442_item	2788582	et	4	main
b	doc_670731433442_item	2788597	et	4	main
c	doc_670731433442_item	2788600	et	4	main
d	doc_670731433442_item	2788603	et	4	main
c	doc_670731433442_item	2788611	et	4	main
kuid	doc_670731433442_item	2788612	et	4	main
eest	doc_670731433442_item	2788621	et	4	main
kirjutab	doc_670731433442_item	2788626	et	3	main
libe	doc_670731433442_item	2788637	et	3	main
c	doc_670731433442_item	2788638	et	4	main
käige	doc_670731433442_item	2788646	et	3	main
punkti	doc_670731433443_item	2788662	et	4	main
maailmakuulsad	doc_670731433443_item	2788663	et	3	main
balletitantsijad	doc_670731433443_item	2788664	et	3	main
32	doc_670731433443_item	2788690	et	2	main
aastat	doc_670731433443_item	2788693	et	3	main
vabakutselised	doc_670731433443_item	2788705	et	4	main
ja	doc_670731433443_item	2788706	et	3	main
erinevaid	doc_670731433443_item	2788710	et	4	main
läinud	doc_670731433443_item	2788739	et	4	main
mõlemal	doc_670731433443_item	2788740	et	3	main
ja	doc_670731433443_item	2788741	et	3	main
eriti	doc_670731433443_item	2788742	et	3	main
murdis	doc_670731433443_item	2788752	et	3	main
järve	doc_670731433443_item	2788756	et	4	main
pakkumisi	doc_670731433443_item	2788782	et	4	main
edule	doc_670731433443_item	2788788	et	3	main
tagasihoidlikult	doc_670731433443_item	2788792	et	4	main
nende	doc_670731433443_item	2788793	et	4	main
lähiaja	doc_670731433443_item	2788794	et	3	main
age	doc_670731433443_item	2788800	et	4	main
ja	doc_670731433443_item	2788801	et	3	main
toomas	doc_670731433443_item	2788802	et	3	main
tahavad	doc_670731433443_item	2788803	et	3	main
areneda	doc_670731433443_item	2788804	et	3	main
ja	doc_670731433443_item	2788805	et	3	main
veelgi	doc_670731433443_item	2788806	et	4	main
esinema	doc_670731433443_item	2788813	et	3	main
tallinn	doc_670731433443_item	2788814	et	4	main
ütelda	doc_670731433443_item	2788834	et	4	main
nad	doc_670731433443_item	2788835	et	3	main
kirjutage	doc_670731433443_item	2788843	et	3	main
alt	doc_670731433443_item	2788848	et	4	main
punkti	doc_670731433443_item	2788854	et	4	main
õpi	doc_670731433443_item	2788855	et	4	main
millal	doc_670731433443_item	2788856	et	3	main
1	doc_670731433443_item	2788857	et	2	main
sa	doc_670731433443_item	2788873	et	3	main
ajastu	doc_670731433443_item	2788881	et	4	main
3	doc_670731433443_item	2788885	et	2	main
aega	doc_670731433443_item	2788888	et	4	main
ning	doc_670731433443_item	2788889	et	3	main
eelise	doc_670731433443_item	2788890	et	4	main
vastavalt	doc_670731433443_item	2788893	et	4	main
4	doc_670731433443_item	2788895	et	2	main
kätte	doc_670731433443_item	2788922	et	4	main
helikasseti	doc_670731433443_item	2788926	et	4	main
kodutöö	doc_670731433443_item	2788929	et	4	main
8	doc_670731433443_item	2788945	et	2	main
vastab	doc_670731433443_item	2788949	et	3	main
meie	doc_670731433443_item	2788962	et	4	main
virtuaalkodu	doc_670731433443_item	2788963	et	4	main
või	doc_670731433443_item	2788964	et	4	main
postitage	doc_670731433443_item	2788965	et	3	main
kupong	doc_670731433443_item	2788966	et	3	main
1	doc_670731433443_item	2788967	et	2	main
d	doc_670731433443_item	2788983	et	4	main
b	doc_670731433443_item	2788988	et	4	main
c	doc_670731433443_item	2788990	et	4	main
varanduse	doc_670731433443_item	2788991	et	3	main
c	doc_670731433443_item	2788999	et	4	main
saada	doc_670731433443_item	2789006	et	4	main
kuid	doc_670731433443_item	2789022	et	4	main
taga	doc_670731433443_item	2789027	et	4	main
ette	doc_670731433443_item	2789029	et	4	main
8	doc_670731433443_item	2789034	et	2	main
a	doc_670731433443_item	2789035	et	4	main
kirjutab	doc_670731433443_item	2789036	et	3	main
b	doc_670731433443_item	2789046	et	4	main
8	doc_670731433442_item	2788624	et	2	main
c	doc_670731433442_item	2788629	et	4	main
parandab	doc_670731433442_item	2788630	et	3	main
d	doc_670731433442_item	2788631	et	4	main
muudab	doc_670731433442_item	2788632	et	3	main
d	doc_670731433442_item	2788640	et	4	main
lihtne	doc_670731433442_item	2788641	et	3	main
10	doc_670731433442_item	2788642	et	2	main
külastage	doc_670731433442_item	2788648	et	3	main
harjutus	doc_670731433443_item	2788651	et	4	main
kirjutage	doc_670731433443_item	2788655	et	3	main
iga	doc_670731433443_item	2788657	et	4	main
age	doc_670731433443_item	2788666	et	4	main
inglismaa	doc_670731433443_item	2788678	et	4	main
on	doc_670731433443_item	2788683	et	4	main
aastane	doc_670731433443_item	2788686	et	4	main
kolmkümmend	doc_670731433443_item	2788691	et	4	main
üheksakumne	doc_670731433443_item	2788699	et	4	main
on	doc_670731433443_item	2788702	et	4	main
nad	doc_670731433443_item	2788703	et	3	main
vabakutseline	doc_670731433443_item	2788704	et	4	main
inglismaal	doc_670731433443_item	2788712	et	4	main
armastama	doc_670731433443_item	2788713	et	3	main
neid	doc_670731433443_item	2788714	et	4	main
väga	doc_670731433443_item	2788715	et	3	main
ning	doc_670731433443_item	2788716	et	3	main
isegi	doc_670731433443_item	2788717	et	4	main
karmid	doc_670731433443_item	2788718	et	4	main
kriitikud	doc_670731433443_item	2788719	et	3	main
suhtuma	doc_670731433443_item	2788720	et	3	main
oks	doc_670731433443_item	2788667	et	3	main
ja	doc_670731433443_item	2788668	et	3	main
edur	doc_670731433443_item	2788670	et	4	main
pärit	doc_670731433443_item	2788672	et	3	main
30	doc_670731433443_item	2788684	et	2	main
toomas	doc_670731433443_item	2788688	et	3	main
alates	doc_670731433443_item	2788695	et	3	main
üheksasaia	doc_670731433443_item	2788698	et	4	main
esinevad	doc_670731433443_item	2788707	et	4	main
erinevad	doc_670731433443_item	2788708	et	4	main
teatre	doc_670731433443_item	2788711	et	4	main
sugugi	doc_670731433443_item	2788735	et	4	main
on	doc_670731433443_item	2788744	et	4	main
olnud	doc_670731433443_item	2788745	et	4	main
tervis	doc_670731433443_item	2788747	et	3	main
tervisega	doc_670731433443_item	2788748	et	3	main
noor	doc_670731433443_item	2788753	et	3	main
luikede	doc_670731433443_item	2788755	et	3	main
etendus	doc_670731433443_item	2788757	et	4	main
etendusele	doc_670731433443_item	2788758	et	4	main
kuigi	doc_670731433443_item	2788778	et	3	main
nemad	doc_670731433443_item	2788779	et	3	main
on	doc_670731433443_item	2788780	et	4	main
vaatamata	doc_670731433443_item	2788786	et	4	main
on	doc_670731433443_item	2788796	et	4	main
tantsida	doc_670731433443_item	2788809	et	3	main
tulevad	doc_670731433443_item	2788811	et	4	main
kaua	doc_670731433443_item	2788822	et	3	main
veel	doc_670731433443_item	2788826	et	4	main
tipus	doc_670731433443_item	2788827	et	3	main
püsida	doc_670731433443_item	2788829	et	3	main
ei	doc_670731433443_item	2788830	et	4	main
oska	doc_670731433443_item	2788831	et	4	main
nad	doc_670731433443_item	2788832	et	3	main
ütlema	doc_670731433443_item	2788833	et	3	main
päev	doc_670731433443_item	2788839	et	3	main
lünka	doc_670731433443_item	2788844	et	4	main
sobiv	doc_670731433443_item	2788845	et	4	main
vastus	doc_670731433443_item	2788851	et	3	main
unusta	doc_670731433443_item	2788859	et	4	main
umbne	doc_670731433443_item	2788860	et	3	main
võimaldab	doc_670731433443_item	2788863	et	3	main
saada	doc_670731433443_item	2788865	et	4	main
2	doc_670731433443_item	2788867	et	2	main
just	doc_670731433443_item	2788868	et	3	main
seal	doc_670731433443_item	2788869	et	4	main
kus	doc_670731433443_item	2788870	et	3	main
ja	doc_670731433443_item	2788871	et	3	main
omandada	doc_670731433443_item	2788891	et	3	main
individuaalsele	doc_670731433443_item	2788894	et	3	main
tasemele	doc_670731433443_item	2788896	et	3	main
on	doc_670731433443_item	2788898	et	4	main
raha	doc_670731433443_item	2788899	et	4	main
et	doc_670731433443_item	2788900	et	3	main
seda	doc_670731433443_item	2788901	et	3	main
5	doc_670731433443_item	2788902	et	2	main
kokku	doc_670731433443_item	2788903	et	3	main
saada	doc_670731433443_item	2788904	et	4	main
kuul	doc_670731433443_item	2788921	et	4	main
raamatu	doc_670731433443_item	2788924	et	4	main
kuid	doc_670731433443_item	2788928	et	4	main
kursuse	doc_670731433443_item	2788930	et	3	main
tasud	doc_670731433443_item	2788933	et	4	main
meile	doc_670731433443_item	2788939	et	4	main
ka	doc_670731433443_item	2788952	et	3	main
tekkinud	doc_670731433443_item	2788953	et	4	main
kõik	doc_670731433443_item	2788955	et	4	main
geniaalne	doc_670731433443_item	2788956	et	3	main
on	doc_670731433443_item	2788957	et	4	main
9	doc_670731433443_item	2788958	et	2	main
lihtne	doc_670731433443_item	2788959	et	3	main
10	doc_670731433443_item	2788960	et	2	main
külastage	doc_670731433443_item	2788961	et	3	main
c	doc_670731433443_item	2788972	et	4	main
soovitad	doc_670731433443_item	2788973	et	3	main
c	doc_670731433443_item	2788981	et	4	main
kuigi	doc_670731433443_item	2788982	et	3	main
d	doc_670731433443_item	2788992	et	4	main
vabaduse	doc_670731433443_item	2788993	et	4	main
4	doc_670731433443_item	2788994	et	2	main
tasakaalule	doc_670731433443_item	2789002	et	3	main
c	doc_670731433443_item	2789021	et	4	main
kõik	doc_670731433443_item	2788733	et	4	main
nii	doc_670731433443_item	2788737	et	3	main
probleeme	doc_670731433443_item	2788746	et	3	main
1990	doc_670731433443_item	2788749	et	2	main
aastal	doc_670731433443_item	2788750	et	3	main
murdma	doc_670731433443_item	2788751	et	3	main
naine	doc_670731433443_item	2788754	et	3	main
mõnda	doc_670731433443_item	2788762	et	4	main
aega	doc_670731433443_item	2788763	et	4	main
tantsimisest	doc_670731433443_item	2788764	et	4	main
eemal	doc_670731433443_item	2788765	et	3	main
olema	doc_670731433443_item	2788766	et	4	main
olla	doc_670731433443_item	2788767	et	3	main
age	doc_670731433443_item	2788768	et	4	main
ja	doc_670731433443_item	2788769	et	3	main
toomas	doc_670731433443_item	2788770	et	3	main
on	doc_670731433443_item	2788771	et	4	main
otsustanud	doc_670731433443_item	2788772	et	4	main
tantsima	doc_670731433443_item	2788773	et	3	main
tantsida	doc_670731433443_item	2788774	et	3	main
ainult	doc_670731433443_item	2788775	et	4	main
teineteisega	doc_670731433443_item	2788776	et	3	main
paaris	doc_670731433443_item	2788777	et	4	main
tehtud	doc_670731433443_item	2788781	et	4	main
suurele	doc_670731433443_item	2788787	et	4	main
tantsijad	doc_670731433443_item	2788790	et	4	main
parem	doc_670731433443_item	2788807	et	4	main
märtsis	doc_670731433443_item	2788810	et	3	main
nad	doc_670731433443_item	2788812	et	3	main
tallinna	doc_670731433443_item	2788815	et	4	main
ja	doc_670731433443_item	2788816	et	3	main
seejärel	doc_670731433443_item	2788817	et	3	main
sõidavad	doc_670731433443_item	2788818	et	3	main
lõuna-aafrika	doc_670731433443_item	2788819	et	4	main
ja	doc_670731433443_item	2788824	et	3	main
suudavad	doc_670731433443_item	2788828	et	3	main
üks	doc_670731433443_item	2788838	et	3	main
kaupa	doc_670731433443_item	2788842	et	4	main
sõna	doc_670731433443_item	2788846	et	4	main
teksti	doc_670731433443_item	2788847	et	4	main
sul	doc_670731433443_item	2788864	et	3	main
targemaks	doc_670731433443_item	2788866	et	4	main
parasjagu	doc_670731433443_item	2788875	et	3	main
käes	doc_670731433443_item	2788877	et	4	main
teadmisi	doc_670731433443_item	2788892	et	4	main
aeg	doc_670731433443_item	2788897	et	3	main
vaja	doc_670731433443_item	2788906	et	4	main
6	doc_670731433443_item	2788927	et	2	main
täidetud	doc_670731433443_item	2788937	et	4	main
kodutöö	doc_670731433443_item	2788938	et	4	main
palub	doc_670731433443_item	2788946	et	3	main
korral	doc_670731433443_item	2788951	et	4	main
a	doc_670731433443_item	2788968	et	4	main
just	doc_670731433443_item	2788978	et	3	main
b	doc_670731433443_item	2788979	et	4	main
a	doc_670731433443_item	2788986	et	4	main
vabanduse	doc_670731433443_item	2788989	et	4	main
tasakesi	doc_670731433443_item	2789000	et	3	main
d	doc_670731433443_item	2789001	et	4	main
5	doc_670731433443_item	2789003	et	2	main
a	doc_670731433443_item	2789004	et	4	main
b	doc_670731433443_item	2789007	et	4	main
liita	doc_670731433443_item	2789009	et	4	main
c	doc_670731433443_item	2789010	et	4	main
kokku	doc_670731433443_item	2789011	et	3	main
hoida	doc_670731433443_item	2789012	et	3	main
7	doc_670731433443_item	2789025	et	2	main
parandab	doc_670731433443_item	2789040	et	3	main
9	doc_670731433443_item	2789043	et	2	main
sulud	doc_670731433444_item	2789063	et	3	main
õige	doc_670731433444_item	2789068	et	4	main
annab	doc_670731433444_item	2789070	et	3	main
30	doc_670731433444_item	2789094	et	2	main
kolmekümene	doc_670731433444_item	2789095	et	4	main
aastane	doc_670731433444_item	2789096	et	4	main
ja	doc_670731433444_item	2789097	et	3	main
toomas	doc_670731433444_item	2789098	et	3	main
kolmkümne	doc_670731433444_item	2789101	et	4	main
kümne	doc_670731433444_item	2789110	et	4	main
inglismaal	doc_670731433444_item	2789122	et	4	main
neid	doc_670731433444_item	2789125	et	4	main
väga	doc_670731433444_item	2789126	et	3	main
isegi	doc_670731433444_item	2789128	et	4	main
kuid	doc_670731433444_item	2789143	et	4	main
alati	doc_670731433444_item	2789147	et	4	main
nii	doc_670731433444_item	2789148	et	3	main
kergelt	doc_670731433444_item	2789149	et	4	main
probleeme	doc_670731433444_item	2789157	et	3	main
aastal	doc_670731433444_item	2789161	et	3	main
noor	doc_670731433444_item	2789164	et	3	main
järve	doc_670731433444_item	2789167	et	4	main
eemal	doc_670731433444_item	2789177	et	3	main
ja	doc_670731433444_item	2789181	et	3	main
on	doc_670731433444_item	2789183	et	4	main
tantsida	doc_670731433444_item	2789222	et	3	main
esinema	doc_670731433444_item	2789226	et	3	main
tallinnas	doc_670731433444_item	2789228	et	4	main
sõidavad	doc_670731433444_item	2789231	et	3	main
kui	doc_670731433444_item	2789234	et	3	main
oska	doc_670731433444_item	2789244	et	4	main
eelistavad	doc_670731433444_item	2789249	et	4	main
üks	doc_670731433444_item	2789251	et	3	main
päeva	doc_670731433444_item	2789254	et	4	main
kaupa	doc_670731433444_item	2789255	et	4	main
kirjutage	doc_670731433444_item	2789256	et	3	main
edur	doc_670731433443_item	2788825	et	4	main
elada	doc_670731433443_item	2788837	et	3	main
päeva	doc_670731433443_item	2788841	et	4	main
soovid	doc_670731433443_item	2788858	et	4	main
millal	doc_670731433443_item	2788872	et	3	main
soovid	doc_670731433443_item	2788876	et	4	main
on	doc_670731433443_item	2788878	et	4	main
interaktiivse	doc_670731433443_item	2788879	et	3	main
õppe	doc_670731433443_item	2788880	et	4	main
planeerida	doc_670731433443_item	2788887	et	3	main
on	doc_670731433443_item	2788905	et	4	main
ka	doc_670731433443_item	2788907	et	3	main
pisut	doc_670731433443_item	2788908	et	3	main
tarkust	doc_670731433443_item	2788909	et	4	main
kui	doc_670731433443_item	2788910	et	3	main
oled	doc_670731433443_item	2788911	et	3	main
registreerunud	doc_670731433443_item	2788913	et	4	main
kursusele	doc_670731433443_item	2788912	et	3	main
saad	doc_670731433443_item	2788914	et	4	main
meie	doc_670731433443_item	2788915	et	4	main
või	doc_670731433443_item	2788917	et	4	main
kontorist	doc_670731433443_item	2788916	et	4	main
lähimast	doc_670731433443_item	2788918	et	4	main
postiasutusest	doc_670731433443_item	2788919	et	4	main
igal	doc_670731433443_item	2788920	et	3	main
õppematerjalid	doc_670731433443_item	2788923	et	3	main
ja	doc_670731433443_item	2788925	et	3	main
saada	doc_670731433443_item	2788936	et	4	main
selle	doc_670731433443_item	2788943	et	4	main
üle	doc_670731433443_item	2788944	et	3	main
d	doc_670731433443_item	2788974	et	4	main
solvud	doc_670731433443_item	2788975	et	3	main
2	doc_670731433443_item	2788976	et	2	main
a	doc_670731433443_item	2788977	et	4	main
siiski	doc_670731433443_item	2788984	et	4	main
3	doc_670731433443_item	2788985	et	2	main
a	doc_670731433443_item	2788995	et	4	main
tasule	doc_670731433443_item	2788996	et	3	main
kokku	doc_670731433443_item	2789005	et	3	main
kokku	doc_670731433443_item	2789008	et	3	main
7	doc_670731433443_item	2788931	et	2	main
eest	doc_670731433443_item	2788932	et	4	main
selle	doc_670731433443_item	2788934	et	4	main
kättesaamisel	doc_670731433443_item	2788935	et	4	main
tagasi	doc_670731433443_item	2788940	et	3	main
õpetaja	doc_670731433443_item	2788941	et	4	main
vaatab	doc_670731433443_item	2788942	et	3	main
vead	doc_670731433443_item	2788947	et	4	main
ning	doc_670731433443_item	2788948	et	3	main
vajaduse	doc_670731433443_item	2788950	et	3	main
lisaküsimustele	doc_670731433443_item	2788954	et	4	main
sobid	doc_670731433443_item	2788969	et	4	main
b	doc_670731433443_item	2788970	et	4	main
soovid	doc_670731433443_item	2788971	et	4	main
seega	doc_670731433443_item	2788980	et	4	main
vajaduse	doc_670731433443_item	2788987	et	3	main
b	doc_670731433443_item	2788997	et	4	main
tasemele	doc_670731433443_item	2788998	et	3	main
d	doc_670731433443_item	2789013	et	4	main
kokku	doc_670731433443_item	2789014	et	3	main
panna	doc_670731433443_item	2789015	et	4	main
6	doc_670731433443_item	2789016	et	2	main
a	doc_670731433443_item	2789017	et	4	main
ning	doc_670731433443_item	2789018	et	3	main
b	doc_670731433443_item	2789019	et	4	main
vaid	doc_670731433443_item	2789020	et	3	main
et	doc_670731433443_item	2789024	et	3	main
eest	doc_670731433443_item	2789031	et	4	main
d	doc_670731433443_item	2789032	et	4	main
ees	doc_670731433443_item	2789033	et	4	main
d	doc_670731433443_item	2789041	et	4	main
muudab	doc_670731433443_item	2789042	et	3	main
c	doc_670731433443_item	2789048	et	4	main
a	doc_670731433443_item	2789053	et	4	main
tulge	doc_670731433443_item	2789054	et	3	main
harjutus	doc_670731433444_item	2789061	et	4	main
eestis	doc_670731433444_item	2789084	et	3	main
aga	doc_670731433444_item	2789085	et	3	main
age	doc_670731433444_item	2789092	et	4	main
32	doc_670731433444_item	2789100	et	2	main
vana	doc_670731433444_item	2789104	et	4	main
erinevad	doc_670731433444_item	2789120	et	4	main
karmid	doc_670731433444_item	2789129	et	4	main
viimased	doc_670731433444_item	2789136	et	3	main
noored	doc_670731433444_item	2789139	et	3	main
läinud	doc_670731433444_item	2789150	et	4	main
mõlemal	doc_670731433444_item	2789151	et	3	main
ja	doc_670731433444_item	2789152	et	3	main
eriti	doc_670731433444_item	2789153	et	3	main
tervis	doc_670731433444_item	2789158	et	3	main
jalaluu	doc_670731433444_item	2789170	et	4	main
ja	doc_670731433444_item	2789171	et	3	main
aega	doc_670731433444_item	2789175	et	4	main
olema	doc_670731433444_item	2789178	et	4	main
parem	doc_670731433444_item	2789220	et	4	main
parevad	doc_670731433444_item	2789221	et	4	main
nad	doc_670731433444_item	2789225	et	3	main
tallinn	doc_670731433444_item	2789227	et	4	main
seejärel	doc_670731433444_item	2789230	et	3	main
lõunas-aafrikas	doc_670731433444_item	2789233	et	4	main
ja	doc_670731433444_item	2789237	et	3	main
edur	doc_670731433444_item	2789238	et	4	main
veel	doc_670731433444_item	2789239	et	4	main
tipus	doc_670731433444_item	2789240	et	3	main
suudavad	doc_670731433444_item	2789241	et	3	main
püsida	doc_670731433444_item	2789242	et	3	main
ütlema	doc_670731433444_item	2789246	et	3	main
sobiv	doc_670731433444_item	2789258	et	4	main
õige	doc_670731433444_item	2789263	et	4	main
vastus	doc_670731433444_item	2789264	et	3	main
ühe	doc_670731433444_item	2789266	et	4	main
punkti	doc_670731433444_item	2789267	et	4	main
võimaldab	doc_670731433444_item	2789276	et	3	main
seega	doc_670731433444_item	2789281	et	4	main
d	doc_670731433443_item	2789023	et	4	main
a	doc_670731433443_item	2789026	et	4	main
b	doc_670731433443_item	2789028	et	4	main
palub	doc_670731433443_item	2789038	et	3	main
c	doc_670731433443_item	2789039	et	4	main
liigne	doc_670731433443_item	2789045	et	3	main
d	doc_670731433443_item	2789050	et	4	main
liikuv	doc_670731433443_item	2789049	et	4	main
lihtne	doc_670731433443_item	2789051	et	3	main
10	doc_670731433443_item	2789052	et	2	main
c	doc_670731433443_item	2789030	et	4	main
b	doc_670731433443_item	2789037	et	4	main
a	doc_670731433443_item	2789044	et	4	main
numbrid	doc_670731433444_item	2789064	et	3	main
sõnadega	doc_670731433444_item	2789066	et	3	main
edur	doc_670731433444_item	2789080	et	4	main
on	doc_670731433444_item	2789081	et	4	main
london	doc_670731433444_item	2789089	et	4	main
inglismaal	doc_670731433444_item	2789090	et	4	main
aastat	doc_670731433444_item	2789103	et	3	main
alates	doc_670731433444_item	2789105	et	3	main
tuhate	doc_670731433444_item	2789107	et	4	main
üheksasada	doc_670731433444_item	2789108	et	4	main
nad	doc_670731433444_item	2789113	et	3	main
vabakutseline	doc_670731433444_item	2789114	et	4	main
ja	doc_670731433444_item	2789116	et	3	main
teatrid	doc_670731433444_item	2789121	et	3	main
armastavad	doc_670731433444_item	2789124	et	4	main
suhtuma	doc_670731433444_item	2789131	et	3	main
nendesse	doc_670731433444_item	2789133	et	4	main
hästi	doc_670731433444_item	2789135	et	3	main
artiklid	doc_670731433444_item	2789137	et	3	main
noored	doc_670731433444_item	2789140	et	3	main
kõik	doc_670731433444_item	2789144	et	4	main
tervis	doc_670731433444_item	2789159	et	3	main
murdma	doc_670731433444_item	2789162	et	3	main
veelgi	doc_670731433444_item	2789219	et	4	main
märtsis	doc_670731433444_item	2789223	et	3	main
ei	doc_670731433444_item	2789243	et	4	main
lünka	doc_670731433444_item	2789257	et	4	main
iga	doc_670731433444_item	2789262	et	4	main
soovid	doc_670731433444_item	2789271	et	4	main
seal	doc_670731433444_item	2789282	et	4	main
ja	doc_670731433444_item	2789284	et	3	main
parasjagu	doc_670731433444_item	2789288	et	3	main
interaktiivse	doc_670731433444_item	2789292	et	3	main
õppe	doc_670731433444_item	2789293	et	4	main
vabaduse	doc_670731433444_item	2789299	et	4	main
kuul	doc_670731433444_item	2789334	et	4	main
et	doc_670731433444_item	2789341	et	3	main
kursuse	doc_670731433444_item	2789343	et	3	main
täidetud	doc_670731433444_item	2789350	et	4	main
kodutöö	doc_670731433444_item	2789351	et	4	main
ning	doc_670731433444_item	2789361	et	3	main
vajaduse	doc_670731433444_item	2789363	et	3	main
ka	doc_670731433444_item	2789365	et	3	main
9	doc_670731433444_item	2789371	et	2	main
liigne	doc_670731433444_item	2789372	et	3	main
minge	doc_670731433444_item	2789374	et	3	main
b	doc_670731433444_item	2789383	et	4	main
soovid	doc_670731433444_item	2789384	et	4	main
just	doc_670731433444_item	2789391	et	3	main
b	doc_670731433444_item	2789392	et	4	main
c	doc_670731433444_item	2789394	et	4	main
kuigi	doc_670731433444_item	2789395	et	3	main
d	doc_670731433444_item	2789396	et	4	main
vabanduse	doc_670731433444_item	2789402	et	4	main
d	doc_670731433444_item	2789405	et	4	main
a	doc_670731433444_item	2789408	et	4	main
tasule	doc_670731433444_item	2789409	et	3	main
b	doc_670731433444_item	2789410	et	4	main
tasemele	doc_670731433444_item	2789411	et	3	main
kokku	doc_670731433444_item	2789424	et	3	main
d	doc_670731433444_item	2789426	et	4	main
c	doc_670731433444_item	2789434	et	4	main
eest	doc_670731433444_item	2789444	et	4	main
ees	doc_670731433444_item	2789446	et	4	main
a	doc_670731433444_item	2789448	et	4	main
c	doc_670731433444_item	2789461	et	4	main
b	doc_670731433444_item	2789468	et	4	main
kolmkümmend	doc_670731433445_item	2789508	et	4	main
aastane	doc_670731433445_item	2789509	et	4	main
alates	doc_670731433445_item	2789518	et	3	main
libe	doc_670731433443_item	2789047	et	3	main
avage	doc_670731433444_item	2789062	et	3	main
kirjutage	doc_670731433444_item	2789065	et	3	main
vastus	doc_670731433444_item	2789069	et	3	main
ühe	doc_670731433444_item	2789071	et	4	main
maailmakuulsad	doc_670731433444_item	2789073	et	3	main
balletitantsijad	doc_670731433444_item	2789074	et	3	main
age	doc_670731433444_item	2789076	et	4	main
oks	doc_670731433444_item	2789077	et	3	main
ja	doc_670731433444_item	2789078	et	3	main
toomas	doc_670731433444_item	2789079	et	3	main
eesti	doc_670731433444_item	2789083	et	4	main
elavad	doc_670731433444_item	2789086	et	4	main
praegu	doc_670731433444_item	2789087	et	3	main
inglismaa	doc_670731433444_item	2789088	et	4	main
on	doc_670731433444_item	2789093	et	4	main
üheksa	doc_670731433444_item	2789109	et	4	main
vabakutselivad	doc_670731433444_item	2789115	et	4	main
esinevad	doc_670731433444_item	2789117	et	4	main
ning	doc_670731433444_item	2789127	et	3	main
suhtuvad	doc_670731433444_item	2789132	et	4	main
üldiselt	doc_670731433444_item	2789134	et	4	main
räägivad	doc_670731433444_item	2789138	et	3	main
ainult	doc_670731433444_item	2789141	et	4	main
ülivõrdes	doc_670731433444_item	2789142	et	3	main
agel	doc_670731433444_item	2789154	et	4	main
on	doc_670731433444_item	2789155	et	4	main
1990	doc_670731433444_item	2789160	et	2	main
naine	doc_670731433444_item	2789165	et	3	main
pidama	doc_670731433444_item	2789172	et	4	main
pidab	doc_670731433444_item	2789173	et	4	main
tantsimisest	doc_670731433444_item	2789176	et	4	main
oleb	doc_670731433444_item	2789179	et	4	main
toomas	doc_670731433444_item	2789182	et	3	main
otsustanud	doc_670731433444_item	2789184	et	4	main
ja	doc_670731433444_item	2789229	et	3	main
ütlevad	doc_670731433444_item	2789247	et	4	main
elada	doc_670731433444_item	2789250	et	3	main
üks	doc_670731433444_item	2789253	et	3	main
sõna	doc_670731433444_item	2789259	et	4	main
teksti	doc_670731433444_item	2789260	et	4	main
unusta	doc_670731433444_item	2789272	et	4	main
umbne	doc_670731433444_item	2789273	et	3	main
koduõppesüsteem	doc_670731433444_item	2789275	et	3	main
saada	doc_670731433444_item	2789278	et	4	main
targemaks	doc_670731433444_item	2789279	et	4	main
mis	doc_670731433444_item	2789295	et	4	main
3	doc_670731433444_item	2789298	et	2	main
ning	doc_670731433444_item	2789302	et	3	main
b	doc_670731433443_item	2789055	et	4	main
käige	doc_670731433443_item	2789056	et	3	main
c	doc_670731433443_item	2789057	et	4	main
külastage	doc_670731433443_item	2789058	et	3	main
d	doc_670731433443_item	2789059	et	4	main
minge	doc_670731433443_item	2789060	et	3	main
iga	doc_670731433444_item	2789067	et	4	main
punkti	doc_670731433444_item	2789072	et	4	main
abielupaar	doc_670731433444_item	2789075	et	4	main
pärit	doc_670731433444_item	2789082	et	3	main
londonas	doc_670731433444_item	2789091	et	4	main
on	doc_670731433444_item	2789099	et	4	main
kaks	doc_670731433444_item	2789102	et	3	main
1997a	doc_670731433444_item	2789106	et	4	main
seitse	doc_670731433444_item	2789111	et	3	main
on	doc_670731433444_item	2789112	et	4	main
erinevad	doc_670731433444_item	2789118	et	4	main
teatrid	doc_670731433444_item	2789119	et	3	main
armastama	doc_670731433444_item	2789123	et	3	main
kriitikud	doc_670731433444_item	2789130	et	3	main
pole	doc_670731433444_item	2789145	et	3	main
sugugi	doc_670731433444_item	2789146	et	4	main
olnud	doc_670731433444_item	2789156	et	4	main
murdab	doc_670731433444_item	2789163	et	4	main
luikede	doc_670731433444_item	2789166	et	3	main
etendus	doc_670731433444_item	2789168	et	4	main
etenduse	doc_670731433444_item	2789169	et	4	main
mõnda	doc_670731433444_item	2789174	et	4	main
age	doc_670731433444_item	2789180	et	4	main
tantsima	doc_670731433444_item	2789185	et	3	main
tantsivad	doc_670731433444_item	2789186	et	4	main
ainult	doc_670731433444_item	2789187	et	4	main
teineteisega	doc_670731433444_item	2789188	et	3	main
paaris	doc_670731433444_item	2789189	et	4	main
kuigi	doc_670731433444_item	2789190	et	3	main
nemad	doc_670731433444_item	2789191	et	3	main
nemad	doc_670731433444_item	2789192	et	3	main
on	doc_670731433444_item	2789193	et	4	main
tehtud	doc_670731433444_item	2789194	et	4	main
pakkumisi	doc_670731433444_item	2789195	et	4	main
ka	doc_670731433444_item	2789196	et	3	main
eraldi	doc_670731433444_item	2789197	et	4	main
tantsimiseks	doc_670731433444_item	2789198	et	4	main
vaatamata	doc_670731433444_item	2789199	et	4	main
suurele	doc_670731433444_item	2789200	et	4	main
edule	doc_670731433444_item	2789201	et	3	main
elavad	doc_670731433444_item	2789202	et	4	main
tantsijad	doc_670731433444_item	2789203	et	4	main
tagasihoidlik	doc_670731433444_item	2789204	et	3	main
tagasihoidlikud	doc_670731433444_item	2789205	et	3	main
nende	doc_670731433444_item	2789206	et	4	main
lähiaja	doc_670731433444_item	2789207	et	3	main
esinemised	doc_670731433444_item	2789208	et	4	main
on	doc_670731433444_item	2789209	et	4	main
täpselt	doc_670731433444_item	2789210	et	4	main
planeerima	doc_670731433444_item	2789211	et	3	main
planeerivad	doc_670731433444_item	2789212	et	4	main
age	doc_670731433444_item	2789213	et	4	main
ja	doc_670731433444_item	2789214	et	3	main
toomas	doc_670731433444_item	2789215	et	3	main
tahavad	doc_670731433444_item	2789216	et	3	main
areneda	doc_670731433444_item	2789217	et	3	main
ja	doc_670731433444_item	2789218	et	3	main
tulevad	doc_670731433444_item	2789224	et	4	main
lõuna-aafrika	doc_670731433444_item	2789232	et	4	main
kaua	doc_670731433444_item	2789235	et	3	main
oks	doc_670731433444_item	2789236	et	3	main
nad	doc_670731433444_item	2789245	et	3	main
nad	doc_670731433444_item	2789248	et	3	main
päev	doc_670731433444_item	2789252	et	3	main
annab	doc_670731433444_item	2789265	et	3	main
klassiruum	doc_670731433444_item	2789274	et	3	main
sul	doc_670731433444_item	2789277	et	3	main
kus	doc_670731433444_item	2789283	et	3	main
sa	doc_670731433444_item	2789286	et	3	main
ajastu	doc_670731433444_item	2789294	et	4	main
planeerida	doc_670731433444_item	2789300	et	3	main
eelise	doc_670731433444_item	2789303	et	4	main
omandada	doc_670731433444_item	2789304	et	3	main
teadmisi	doc_670731433444_item	2789305	et	4	main
vastavalt	doc_670731433444_item	2789306	et	4	main
individuaalsele	doc_670731433444_item	2789307	et	3	main
4	doc_670731433444_item	2789308	et	2	main
tasakaalule	doc_670731433444_item	2789309	et	3	main
aeg	doc_670731433444_item	2789310	et	3	main
on	doc_670731433444_item	2789311	et	4	main
raha	doc_670731433444_item	2789312	et	4	main
et	doc_670731433444_item	2789313	et	3	main
seda	doc_670731433444_item	2789314	et	3	main
5	doc_670731433444_item	2789315	et	2	main
kokku	doc_670731433444_item	2789316	et	3	main
hoida	doc_670731433444_item	2789317	et	3	main
on	doc_670731433444_item	2789318	et	4	main
vaja	doc_670731433444_item	2789319	et	4	main
ka	doc_670731433444_item	2789320	et	3	main
saad	doc_670731433444_item	2789327	et	4	main
või	doc_670731433444_item	2789330	et	4	main
raamatu	doc_670731433444_item	2789337	et	4	main
kodutöö	doc_670731433444_item	2789342	et	4	main
saada	doc_670731433444_item	2789349	et	4	main
vead	doc_670731433444_item	2789360	et	4	main
vastab	doc_670731433444_item	2789362	et	3	main
korral	doc_670731433444_item	2789364	et	4	main
10	doc_670731433444_item	2789373	et	2	main
meie	doc_670731433444_item	2789375	et	4	main
1	doc_670731433444_item	2789380	et	2	main
sobid	doc_670731433444_item	2789382	et	4	main
solvud	doc_670731433444_item	2789388	et	3	main
seega	doc_670731433444_item	2789393	et	4	main
varanduse	doc_670731433444_item	2789404	et	3	main
tasakesi	doc_670731433444_item	2789413	et	3	main
5	doc_670731433444_item	2789416	et	2	main
a	doc_670731433444_item	2789417	et	4	main
c	doc_670731433444_item	2789423	et	4	main
panna	doc_670731433444_item	2789428	et	4	main
b	doc_670731433444_item	2789441	et	4	main
d	doc_670731433444_item	2789445	et	4	main
liikuv	doc_670731433444_item	2789462	et	4	main
käige	doc_670731433444_item	2789469	et	3	main
külastage	doc_670731433444_item	2789471	et	3	main
minge	doc_670731433444_item	2789473	et	3	main
harjutus	doc_670731433445_item	2789474	et	4	main
numbrid	doc_670731433445_item	2789477	et	3	main
kirjutage	doc_670731433445_item	2789478	et	3	main
sõnadega	doc_670731433445_item	2789479	et	3	main
kolmkummend	doc_670731433445_item	2789514	et	4	main
kaks	doc_670731433445_item	2789515	et	3	main
alt	doc_670731433444_item	2789261	et	4	main
õpi	doc_670731433444_item	2789268	et	4	main
millal	doc_670731433444_item	2789269	et	3	main
1	doc_670731433444_item	2789270	et	2	main
2	doc_670731433444_item	2789280	et	2	main
seda	doc_670731433444_item	2789287	et	3	main
soovid	doc_670731433444_item	2789289	et	4	main
annab	doc_670731433444_item	2789296	et	3	main
sulle	doc_670731433444_item	2789297	et	3	main
aega	doc_670731433444_item	2789301	et	4	main
pisut	doc_670731433444_item	2789321	et	3	main
oled	doc_670731433444_item	2789324	et	3	main
kontorist	doc_670731433444_item	2789329	et	4	main
ja	doc_670731433444_item	2789338	et	3	main
helikasseti	doc_670731433444_item	2789339	et	4	main
ette	doc_670731433444_item	2789345	et	4	main
selle	doc_670731433444_item	2789347	et	4	main
meile	doc_670731433444_item	2789352	et	4	main
on	doc_670731433444_item	2789370	et	4	main
või	doc_670731433444_item	2789377	et	4	main
2	doc_670731433444_item	2789389	et	2	main
b	doc_670731433444_item	2789401	et	4	main
c	doc_670731433444_item	2789412	et	4	main
d	doc_670731433444_item	2789414	et	4	main
tasakaalule	doc_670731433444_item	2789415	et	3	main
kokku	doc_670731433444_item	2789421	et	3	main
kuid	doc_670731433444_item	2789435	et	4	main
d	doc_670731433444_item	2789436	et	4	main
et	doc_670731433444_item	2789437	et	3	main
ette	doc_670731433444_item	2789442	et	4	main
b	doc_670731433444_item	2789450	et	4	main
d	doc_670731433444_item	2789454	et	4	main
muudab	doc_670731433444_item	2789455	et	3	main
a	doc_670731433444_item	2789457	et	4	main
liigne	doc_670731433444_item	2789458	et	3	main
a	doc_670731433444_item	2789466	et	4	main
tulge	doc_670731433444_item	2789467	et	3	main
c	doc_670731433444_item	2789470	et	4	main
d	doc_670731433444_item	2789472	et	4	main
õige	doc_670731433445_item	2789481	et	4	main
ja	doc_670731433445_item	2789510	et	3	main
toomas	doc_670731433445_item	2789511	et	3	main
on	doc_670731433445_item	2789512	et	4	main
32	doc_670731433445_item	2789513	et	2	main
vabakutselised	doc_670731433445_item	2789527	et	4	main
ja	doc_670731433445_item	2789528	et	3	main
karmid	doc_670731433445_item	2789541	et	4	main
kriitikud	doc_670731433445_item	2789542	et	3	main
suhtuma	doc_670731433445_item	2789543	et	3	main
noored	doc_670731433445_item	2789552	et	3	main
kõik	doc_670731433445_item	2789556	et	4	main
sugugi	doc_670731433445_item	2789558	et	4	main
eriti	doc_670731433445_item	2789565	et	3	main
naine	doc_670731433445_item	2789577	et	3	main
etendus	doc_670731433445_item	2789580	et	4	main
tantsimisest	doc_670731433445_item	2789587	et	4	main
eemal	doc_670731433445_item	2789588	et	3	main
tansida	doc_670731433445_item	2789597	et	4	main
ainult	doc_670731433445_item	2789598	et	4	main
paaris	doc_670731433445_item	2789600	et	4	main
nemad	doc_670731433445_item	2789602	et	3	main
nende	doc_670731433445_item	2789603	et	4	main
on	doc_670731433445_item	2789604	et	4	main
vaatamata	doc_670731433445_item	2789610	et	4	main
toomas	doc_670731433445_item	2789626	et	3	main
veelgi	doc_670731433445_item	2789630	et	4	main
parem	doc_670731433445_item	2789631	et	4	main
sõna	doc_670731433445_item	2789670	et	4	main
teksti	doc_670731433445_item	2789671	et	4	main
punkti	doc_670731433445_item	2789678	et	4	main
sobid	doc_670731433445_item	2789682	et	4	main
umbne	doc_670731433445_item	2789684	et	3	main
klassiruum	doc_670731433445_item	2789685	et	3	main
koduõppesüsteem	doc_670731433445_item	2789686	et	3	main
võimaldab	doc_670731433445_item	2789687	et	3	main
sul	doc_670731433445_item	2789688	et	3	main
saada	doc_670731433445_item	2789689	et	4	main
siiski	doc_670731433445_item	2789692	et	4	main
kus	doc_670731433445_item	2789694	et	3	main
sa	doc_670731433445_item	2789697	et	3	main
soovid	doc_670731433445_item	2789700	et	4	main
käes	doc_670731433445_item	2789701	et	4	main
millal	doc_670731433444_item	2789285	et	3	main
käes	doc_670731433444_item	2789290	et	4	main
on	doc_670731433444_item	2789291	et	4	main
tarkust	doc_670731433444_item	2789322	et	4	main
kui	doc_670731433444_item	2789323	et	3	main
kursusele	doc_670731433444_item	2789325	et	3	main
registreerunud	doc_670731433444_item	2789326	et	4	main
kätte	doc_670731433444_item	2789335	et	4	main
õppematerjalid	doc_670731433444_item	2789336	et	3	main
kättesaamisel	doc_670731433444_item	2789348	et	4	main
kõik	doc_670731433444_item	2789368	et	4	main
geniaalne	doc_670731433444_item	2789369	et	3	main
virtuaalkodu	doc_670731433444_item	2789376	et	4	main
a	doc_670731433444_item	2789381	et	4	main
c	doc_670731433444_item	2789385	et	4	main
a	doc_670731433444_item	2789390	et	4	main
3	doc_670731433444_item	2789398	et	2	main
a	doc_670731433444_item	2789399	et	4	main
vajaduse	doc_670731433444_item	2789400	et	3	main
c	doc_670731433444_item	2789403	et	4	main
vabaduse	doc_670731433444_item	2789406	et	4	main
4	doc_670731433444_item	2789407	et	2	main
meie	doc_670731433444_item	2789328	et	4	main
lähimast	doc_670731433444_item	2789331	et	4	main
postiasutusest	doc_670731433444_item	2789332	et	4	main
igal	doc_670731433444_item	2789333	et	3	main
6	doc_670731433444_item	2789340	et	2	main
7	doc_670731433444_item	2789344	et	2	main
tasud	doc_670731433444_item	2789346	et	4	main
tagasi	doc_670731433444_item	2789353	et	3	main
õpetaja	doc_670731433444_item	2789354	et	4	main
vaatab	doc_670731433444_item	2789355	et	3	main
selle	doc_670731433444_item	2789356	et	4	main
üle	doc_670731433444_item	2789357	et	3	main
8	doc_670731433444_item	2789358	et	2	main
kirjutab	doc_670731433444_item	2789359	et	3	main
tekkinud	doc_670731433444_item	2789366	et	4	main
lisaküsimustele	doc_670731433444_item	2789367	et	4	main
postitage	doc_670731433444_item	2789378	et	3	main
kupong	doc_670731433444_item	2789379	et	3	main
soovitad	doc_670731433444_item	2789386	et	3	main
d	doc_670731433444_item	2789387	et	4	main
siiski	doc_670731433444_item	2789397	et	4	main
kokku	doc_670731433444_item	2789418	et	3	main
saada	doc_670731433444_item	2789419	et	4	main
b	doc_670731433444_item	2789420	et	4	main
hoida	doc_670731433444_item	2789425	et	3	main
7	doc_670731433444_item	2789438	et	2	main
a	doc_670731433444_item	2789439	et	4	main
taga	doc_670731433444_item	2789440	et	4	main
b	doc_670731433444_item	2789459	et	4	main
libe	doc_670731433444_item	2789460	et	3	main
avage	doc_670731433445_item	2789475	et	3	main
sulud	doc_670731433445_item	2789476	et	3	main
30	doc_670731433445_item	2789507	et	2	main
vana	doc_670731433445_item	2789517	et	4	main
esinevad	doc_670731433445_item	2789529	et	4	main
erinevad	doc_670731433445_item	2789530	et	4	main
teatrid	doc_670731433445_item	2789531	et	3	main
armastama	doc_670731433445_item	2789535	et	3	main
neid	doc_670731433445_item	2789537	et	4	main
ainult	doc_670731433445_item	2789553	et	4	main
alati	doc_670731433445_item	2789559	et	4	main
mõlemal	doc_670731433445_item	2789563	et	3	main
murdma	doc_670731433445_item	2789574	et	3	main
pidama	doc_670731433445_item	2789584	et	4	main
mõnda	doc_670731433445_item	2789585	et	4	main
aega	doc_670731433445_item	2789586	et	4	main
toomas	doc_670731433445_item	2789593	et	3	main
tehtud	doc_670731433445_item	2789605	et	4	main
age	doc_670731433445_item	2789624	et	4	main
tahavad	doc_670731433445_item	2789627	et	3	main
lõuna-aafrikale	doc_670731433445_item	2789644	et	4	main
kaua	doc_670731433445_item	2789646	et	3	main
edur	doc_670731433445_item	2789649	et	4	main
veel	doc_670731433445_item	2789650	et	4	main
tipus	doc_670731433445_item	2789651	et	3	main
suudavad	doc_670731433445_item	2789652	et	3	main
püsida	doc_670731433445_item	2789653	et	3	main
ei	doc_670731433445_item	2789654	et	4	main
eelistavad	doc_670731433445_item	2789660	et	4	main
alt	doc_670731433445_item	2789672	et	4	main
ühe	doc_670731433445_item	2789677	et	4	main
1	doc_670731433445_item	2789681	et	2	main
unusta	doc_670731433445_item	2789683	et	4	main
on	doc_670731433445_item	2789702	et	4	main
interaktiivse	doc_670731433445_item	2789703	et	3	main
sulle	doc_670731433445_item	2789708	et	3	main
vabaduse	doc_670731433445_item	2789710	et	4	main
eelise	doc_670731433445_item	2789714	et	4	main
aeg	doc_670731433445_item	2789721	et	3	main
et	doc_670731433445_item	2789724	et	3	main
saada	doc_670731433445_item	2789728	et	4	main
vaja	doc_670731433445_item	2789730	et	4	main
tarkust	doc_670731433445_item	2789733	et	4	main
registreerunud	doc_670731433445_item	2789737	et	4	main
või	doc_670731433445_item	2789741	et	4	main
postiasutusest	doc_670731433445_item	2789743	et	4	main
igal	doc_670731433445_item	2789744	et	3	main
kuul	doc_670731433445_item	2789745	et	4	main
kodutöö	doc_670731433445_item	2789753	et	4	main
ees	doc_670731433445_item	2789756	et	4	main
tasud	doc_670731433445_item	2789757	et	4	main
kodutöö	doc_670731433445_item	2789762	et	4	main
vaatab	doc_670731433445_item	2789766	et	3	main
parandab	doc_670731433445_item	2789770	et	3	main
ning	doc_670731433445_item	2789772	et	3	main
soovid	doc_670731433445_item	2789795	et	4	main
just	doc_670731433445_item	2789802	et	3	main
c	doc_670731433445_item	2789805	et	4	main
d	doc_670731433445_item	2789807	et	4	main
tasule	doc_670731433445_item	2789820	et	3	main
tasemele	doc_670731433445_item	2789822	et	3	main
kokku	doc_670731433445_item	2789829	et	3	main
hoida	doc_670731433445_item	2789836	et	3	main
a	doc_670731433445_item	2789841	et	4	main
kuid	doc_670731433445_item	2789846	et	4	main
a	doc_670731433445_item	2789850	et	4	main
liita	doc_670731433444_item	2789422	et	4	main
kokku	doc_670731433444_item	2789427	et	3	main
6	doc_670731433444_item	2789429	et	2	main
a	doc_670731433444_item	2789430	et	4	main
ning	doc_670731433444_item	2789431	et	3	main
b	doc_670731433444_item	2789432	et	4	main
vaid	doc_670731433444_item	2789433	et	3	main
c	doc_670731433444_item	2789443	et	4	main
8	doc_670731433444_item	2789447	et	2	main
kirjutab	doc_670731433444_item	2789449	et	3	main
palub	doc_670731433444_item	2789451	et	3	main
c	doc_670731433444_item	2789452	et	4	main
parandab	doc_670731433444_item	2789453	et	3	main
9	doc_670731433444_item	2789456	et	2	main
d	doc_670731433444_item	2789463	et	4	main
lihtne	doc_670731433444_item	2789464	et	3	main
10	doc_670731433444_item	2789465	et	2	main
iga	doc_670731433445_item	2789480	et	4	main
vastus	doc_670731433445_item	2789482	et	3	main
annab	doc_670731433445_item	2789483	et	3	main
ühe	doc_670731433445_item	2789484	et	4	main
punkti	doc_670731433445_item	2789485	et	4	main
maailmakuulsad	doc_670731433445_item	2789486	et	3	main
balletitantsijad	doc_670731433445_item	2789487	et	3	main
abielupaar	doc_670731433445_item	2789488	et	4	main
age	doc_670731433445_item	2789489	et	4	main
oks	doc_670731433445_item	2789490	et	3	main
ja	doc_670731433445_item	2789491	et	3	main
toomas	doc_670731433445_item	2789492	et	3	main
edur	doc_670731433445_item	2789493	et	4	main
on	doc_670731433445_item	2789494	et	4	main
pärit	doc_670731433445_item	2789495	et	3	main
eesti	doc_670731433445_item	2789496	et	4	main
eestis	doc_670731433445_item	2789497	et	3	main
aga	doc_670731433445_item	2789498	et	3	main
elavad	doc_670731433445_item	2789499	et	4	main
praegu	doc_670731433445_item	2789500	et	3	main
inglismaa	doc_670731433445_item	2789501	et	4	main
london	doc_670731433445_item	2789502	et	4	main
inglismaal	doc_670731433445_item	2789503	et	4	main
londonis	doc_670731433445_item	2789504	et	4	main
age	doc_670731433445_item	2789505	et	4	main
on	doc_670731433445_item	2789506	et	4	main
aastat	doc_670731433445_item	2789516	et	3	main
üheksasaja	doc_670731433445_item	2789521	et	4	main
nad	doc_670731433445_item	2789525	et	3	main
vabakutseline	doc_670731433445_item	2789526	et	4	main
teatrides	doc_670731433445_item	2789533	et	4	main
armastavad	doc_670731433445_item	2789536	et	4	main
väga	doc_670731433445_item	2789538	et	3	main
ning	doc_670731433445_item	2789539	et	3	main
isegi	doc_670731433445_item	2789540	et	4	main
noored	doc_670731433445_item	2789551	et	3	main
läinud	doc_670731433445_item	2789562	et	4	main
agel	doc_670731433445_item	2789566	et	4	main
aastal	doc_670731433445_item	2789573	et	3	main
luikede	doc_670731433445_item	2789578	et	3	main
age	doc_670731433445_item	2789591	et	4	main
on	doc_670731433445_item	2789594	et	4	main
pakkumisi	doc_670731433445_item	2789606	et	4	main
ka	doc_670731433445_item	2789607	et	3	main
paremini	doc_670731433445_item	2789632	et	4	main
tantsida	doc_670731433445_item	2789633	et	3	main
oska	doc_670731433445_item	2789655	et	4	main
nad	doc_670731433445_item	2789656	et	3	main
ütlema	doc_670731433445_item	2789657	et	3	main
iga	doc_670731433445_item	2789673	et	4	main
seda	doc_670731433445_item	2789698	et	3	main
ajastu	doc_670731433445_item	2789705	et	4	main
aega	doc_670731433445_item	2789712	et	4	main
omandada	doc_670731433445_item	2789715	et	3	main
vastavalt	doc_670731433445_item	2789717	et	4	main
individuaalsele	doc_670731433445_item	2789718	et	3	main
1997a	doc_670731433445_item	2789519	et	4	main
tuhande	doc_670731433445_item	2789520	et	3	main
üheksakümne	doc_670731433445_item	2789522	et	4	main
seitsmenda	doc_670731433445_item	2789523	et	3	main
inglismaal	doc_670731433445_item	2789534	et	4	main
nendesse	doc_670731433445_item	2789545	et	4	main
üldiselt	doc_670731433445_item	2789546	et	4	main
hästi	doc_670731433445_item	2789547	et	3	main
viimased	doc_670731433445_item	2789548	et	3	main
artiklid	doc_670731433445_item	2789549	et	3	main
räägivad	doc_670731433445_item	2789550	et	3	main
kuid	doc_670731433445_item	2789555	et	4	main
pole	doc_670731433445_item	2789557	et	3	main
kergelt	doc_670731433445_item	2789561	et	4	main
ja	doc_670731433445_item	2789564	et	3	main
1990	doc_670731433445_item	2789572	et	2	main
ja	doc_670731433445_item	2789592	et	3	main
tantsima	doc_670731433445_item	2789596	et	3	main
teineteisega	doc_670731433445_item	2789599	et	3	main
tantsimiseks	doc_670731433445_item	2789609	et	4	main
täpselt	doc_670731433445_item	2789621	et	4	main
märtsis	doc_670731433445_item	2789634	et	3	main
tulevad	doc_670731433445_item	2789635	et	4	main
nad	doc_670731433445_item	2789636	et	3	main
esinema	doc_670731433445_item	2789637	et	3	main
tallinn	doc_670731433445_item	2789638	et	4	main
kui	doc_670731433445_item	2789645	et	3	main
ja	doc_670731433445_item	2789648	et	3	main
sobiv	doc_670731433445_item	2789669	et	4	main
vastus	doc_670731433445_item	2789675	et	3	main
õpi	doc_670731433445_item	2789679	et	4	main
2	doc_670731433445_item	2789691	et	2	main
seal	doc_670731433445_item	2789693	et	4	main
ja	doc_670731433445_item	2789695	et	3	main
millal	doc_670731433445_item	2789696	et	3	main
parasjagu	doc_670731433445_item	2789699	et	3	main
mis	doc_670731433445_item	2789706	et	4	main
kokku	doc_670731433445_item	2789727	et	3	main
on	doc_670731433445_item	2789729	et	4	main
oled	doc_670731433445_item	2789735	et	3	main
saad	doc_670731433445_item	2789738	et	4	main
meie	doc_670731433445_item	2789739	et	4	main
kätte	doc_670731433445_item	2789746	et	4	main
selle	doc_670731433445_item	2789758	et	4	main
meile	doc_670731433445_item	2789763	et	4	main
selle	doc_670731433445_item	2789767	et	4	main
sobid	doc_670731433445_item	2789793	et	4	main
solvud	doc_670731433445_item	2789799	et	3	main
b	doc_670731433445_item	2789803	et	4	main
a	doc_670731433445_item	2789810	et	4	main
d	doc_670731433445_item	2789816	et	4	main
vabaduse	doc_670731433445_item	2789817	et	4	main
b	doc_670731433445_item	2789821	et	4	main
tasakaalule	doc_670731433445_item	2789826	et	3	main
b	doc_670731433445_item	2789831	et	4	main
kokku	doc_670731433445_item	2789838	et	3	main
ning	doc_670731433445_item	2789842	et	3	main
et	doc_670731433445_item	2789848	et	3	main
b	doc_670731433445_item	2789852	et	4	main
c	doc_670731433445_item	2789854	et	4	main
a	doc_670731433445_item	2789859	et	4	main
b	doc_670731433445_item	2789861	et	4	main
d	doc_670731433445_item	2789865	et	4	main
muudab	doc_670731433445_item	2789866	et	3	main
libe	doc_670731433445_item	2789871	et	3	main
liikuv	doc_670731433445_item	2789873	et	4	main
tulge	doc_670731433445_item	2789878	et	3	main
c	doc_670731433445_item	2789881	et	4	main
harjutus	doc_670731433446_item	2789885	et	4	main
kirjutage	doc_670731433446_item	2789889	et	3	main
vastus	doc_670731433446_item	2789893	et	3	main
on	doc_670731433445_item	2789524	et	4	main
erinevaid	doc_670731433445_item	2789532	et	4	main
suhtuvad	doc_670731433445_item	2789544	et	4	main
ülivõrdes	doc_670731433445_item	2789554	et	3	main
nii	doc_670731433445_item	2789560	et	3	main
on	doc_670731433445_item	2789567	et	4	main
olnud	doc_670731433445_item	2789568	et	4	main
probleeme	doc_670731433445_item	2789569	et	3	main
tervis	doc_670731433445_item	2789570	et	3	main
tervisega	doc_670731433445_item	2789571	et	3	main
murdab	doc_670731433445_item	2789575	et	4	main
noor	doc_670731433445_item	2789576	et	3	main
järve	doc_670731433445_item	2789579	et	4	main
etendust	doc_670731433445_item	2789581	et	4	main
jalaluu	doc_670731433445_item	2789582	et	4	main
ja	doc_670731433445_item	2789583	et	3	main
olema	doc_670731433445_item	2789589	et	4	main
olla	doc_670731433445_item	2789590	et	3	main
otsustanud	doc_670731433445_item	2789595	et	4	main
kuigi	doc_670731433445_item	2789601	et	3	main
eraldi	doc_670731433445_item	2789608	et	4	main
suurele	doc_670731433445_item	2789611	et	4	main
edule	doc_670731433445_item	2789612	et	3	main
elavad	doc_670731433445_item	2789613	et	4	main
tantsijad	doc_670731433445_item	2789614	et	4	main
tagasihoidlik	doc_670731433445_item	2789615	et	3	main
tagasihoidliku	doc_670731433445_item	2789616	et	3	main
nende	doc_670731433445_item	2789617	et	4	main
lähiaja	doc_670731433445_item	2789618	et	3	main
esinemised	doc_670731433445_item	2789619	et	4	main
on	doc_670731433445_item	2789620	et	4	main
planeerima	doc_670731433445_item	2789622	et	3	main
planeerida	doc_670731433445_item	2789623	et	3	main
ja	doc_670731433445_item	2789625	et	3	main
areneda	doc_670731433445_item	2789628	et	3	main
ja	doc_670731433445_item	2789629	et	3	main
tallinnas	doc_670731433445_item	2789639	et	4	main
ja	doc_670731433445_item	2789640	et	3	main
seejärel	doc_670731433445_item	2789641	et	3	main
sõidavad	doc_670731433445_item	2789642	et	3	main
lõuna-aafrika	doc_670731433445_item	2789643	et	4	main
oks	doc_670731433445_item	2789647	et	3	main
ütlevad	doc_670731433445_item	2789658	et	4	main
nad	doc_670731433445_item	2789659	et	3	main
elada	doc_670731433445_item	2789661	et	3	main
üks	doc_670731433445_item	2789662	et	3	main
päev	doc_670731433445_item	2789663	et	3	main
üksi	doc_670731433445_item	2789664	et	4	main
päeva	doc_670731433445_item	2789665	et	4	main
kaupa	doc_670731433445_item	2789666	et	4	main
kirjutage	doc_670731433445_item	2789667	et	3	main
lünka	doc_670731433445_item	2789668	et	4	main
õige	doc_670731433445_item	2789674	et	4	main
annab	doc_670731433445_item	2789676	et	3	main
millal	doc_670731433445_item	2789680	et	3	main
targemaks	doc_670731433445_item	2789690	et	4	main
õppe	doc_670731433445_item	2789704	et	4	main
3	doc_670731433445_item	2789709	et	2	main
planeerida	doc_670731433445_item	2789711	et	3	main
5	doc_670731433445_item	2789726	et	2	main
kontorist	doc_670731433445_item	2789740	et	4	main
raamatu	doc_670731433445_item	2789748	et	4	main
ja	doc_670731433445_item	2789749	et	3	main
6	doc_670731433445_item	2789751	et	2	main
kättesaamisel	doc_670731433445_item	2789759	et	4	main
tagasi	doc_670731433445_item	2789764	et	3	main
8	doc_670731433445_item	2789769	et	2	main
a	doc_670731433445_item	2789792	et	4	main
c	doc_670731433445_item	2789796	et	4	main
soovitad	doc_670731433445_item	2789797	et	3	main
d	doc_670731433445_item	2789798	et	4	main
2	doc_670731433445_item	2789800	et	2	main
vajaduse	doc_670731433445_item	2789811	et	3	main
b	doc_670731433445_item	2789812	et	4	main
4	doc_670731433445_item	2789818	et	2	main
a	doc_670731433445_item	2789819	et	4	main
d	doc_670731433445_item	2789825	et	4	main
saada	doc_670731433445_item	2789830	et	4	main
kokku	doc_670731433445_item	2789832	et	3	main
kokku	doc_670731433445_item	2789835	et	3	main
panna	doc_670731433445_item	2789839	et	4	main
c	doc_670731433445_item	2789845	et	4	main
ette	doc_670731433445_item	2789853	et	4	main
8	doc_670731433445_item	2789858	et	2	main
parandab	doc_670731433445_item	2789864	et	3	main
10	doc_670731433445_item	2789876	et	2	main
b	doc_670731433445_item	2789879	et	4	main
külastage	doc_670731433445_item	2789882	et	3	main
numbrid	doc_670731433446_item	2789888	et	3	main
toomas	doc_670731433446_item	2789922	et	3	main
kümmend	doc_670731433446_item	2789926	et	4	main
alates	doc_670731433446_item	2789930	et	3	main
1997a	doc_670731433446_item	2789931	et	4	main
erinevaid	doc_670731433446_item	2789940	et	4	main
karmid	doc_670731433446_item	2789949	et	4	main
kriitikud	doc_670731433446_item	2789950	et	3	main
suhtuma	doc_670731433446_item	2789951	et	3	main
nendesse	doc_670731433446_item	2789953	et	4	main
artiklid	doc_670731433446_item	2789957	et	3	main
ainult	doc_670731433446_item	2789961	et	4	main
kõik	doc_670731433446_item	2789964	et	4	main
pole	doc_670731433446_item	2789965	et	3	main
nii	doc_670731433446_item	2789968	et	3	main
tervis	doc_670731433446_item	2789978	et	3	main
luikede	doc_670731433446_item	2789986	et	3	main
etendus	doc_670731433446_item	2789988	et	4	main
mõnda	doc_670731433446_item	2789994	et	4	main
tantsimisest	doc_670731433446_item	2789996	et	4	main
tantsida	doc_670731433446_item	2790006	et	3	main
kuigi	doc_670731433446_item	2790010	et	3	main
elavad	doc_670731433446_item	2790022	et	4	main
planeeritud	doc_670731433446_item	2790032	et	4	main
esinema	doc_670731433446_item	2790046	et	3	main
tallinnasse	doc_670731433446_item	2790048	et	3	main
sõidavad	doc_670731433446_item	2790051	et	3	main
tipus	doc_670731433446_item	2790060	et	3	main
ei	doc_670731433446_item	2790063	et	4	main
punkti	doc_670731433446_item	2790087	et	4	main
sul	doc_670731433446_item	2790097	et	3	main
just	doc_670731433446_item	2790101	et	3	main
parasjagu	doc_670731433446_item	2790108	et	3	main
planeerida	doc_670731433446_item	2790120	et	3	main
on	doc_670731433446_item	2790131	et	4	main
pisut	doc_670731433446_item	2790141	et	3	main
või	doc_670731433446_item	2790150	et	4	main
kättesaamisel	doc_670731433446_item	2790168	et	4	main
õpetaja	doc_670731433446_item	2790174	et	4	main
vaatab	doc_670731433446_item	2790175	et	3	main
vead	doc_670731433446_item	2790180	et	4	main
vajaduse	doc_670731433446_item	2790183	et	3	main
ka	doc_670731433446_item	2790185	et	3	main
tekkinud	doc_670731433446_item	2790186	et	4	main
lisaküsimustele	doc_670731433446_item	2790187	et	4	main
kõik	doc_670731433446_item	2790188	et	4	main
annab	doc_670731433445_item	2789707	et	3	main
ning	doc_670731433445_item	2789713	et	3	main
teadmisi	doc_670731433445_item	2789716	et	4	main
4	doc_670731433445_item	2789719	et	2	main
tasakesi	doc_670731433445_item	2789720	et	3	main
raha	doc_670731433445_item	2789723	et	4	main
ka	doc_670731433445_item	2789731	et	3	main
kursuse	doc_670731433445_item	2789754	et	3	main
siiski	doc_670731433445_item	2789808	et	4	main
3	doc_670731433445_item	2789809	et	2	main
c	doc_670731433445_item	2789823	et	4	main
5	doc_670731433445_item	2789827	et	2	main
liita	doc_670731433445_item	2789833	et	4	main
vaid	doc_670731433445_item	2789844	et	3	main
d	doc_670731433445_item	2789847	et	4	main
taga	doc_670731433445_item	2789851	et	4	main
d	doc_670731433445_item	2789856	et	4	main
palub	doc_670731433445_item	2789862	et	3	main
a	doc_670731433445_item	2789868	et	4	main
b	doc_670731433445_item	2789870	et	4	main
a	doc_670731433445_item	2789877	et	4	main
d	doc_670731433445_item	2789883	et	4	main
sõnadega	doc_670731433446_item	2789890	et	3	main
annab	doc_670731433446_item	2789894	et	3	main
on	doc_670731433446_item	2789923	et	4	main
aastat	doc_670731433446_item	2789928	et	3	main
vana	doc_670731433446_item	2789929	et	4	main
esinevad	doc_670731433446_item	2789937	et	4	main
suhelda	doc_670731433446_item	2789952	et	4	main
noored	doc_670731433446_item	2789959	et	3	main
sugugi	doc_670731433446_item	2789966	et	4	main
kergelt	doc_670731433446_item	2789969	et	4	main
1990	doc_670731433446_item	2789980	et	2	main
murdis	doc_670731433446_item	2789983	et	3	main
pidis	doc_670731433446_item	2789993	et	4	main
aega	doc_670731433446_item	2789995	et	4	main
eemal	doc_670731433446_item	2789997	et	3	main
tantsima	doc_670731433446_item	2790005	et	3	main
on	doc_670731433445_item	2789722	et	4	main
seda	doc_670731433445_item	2789725	et	3	main
pisut	doc_670731433445_item	2789732	et	3	main
kui	doc_670731433445_item	2789734	et	3	main
kursusele	doc_670731433445_item	2789736	et	3	main
lähimast	doc_670731433445_item	2789742	et	4	main
õppematerjalid	doc_670731433445_item	2789747	et	3	main
helikasseti	doc_670731433445_item	2789750	et	4	main
vaid	doc_670731433445_item	2789752	et	3	main
7	doc_670731433445_item	2789755	et	2	main
saada	doc_670731433445_item	2789760	et	4	main
täidetud	doc_670731433445_item	2789761	et	4	main
õpetaja	doc_670731433445_item	2789765	et	4	main
üle	doc_670731433445_item	2789768	et	3	main
vead	doc_670731433445_item	2789771	et	4	main
vastab	doc_670731433445_item	2789773	et	3	main
vajaduse	doc_670731433445_item	2789774	et	3	main
korral	doc_670731433445_item	2789775	et	4	main
ka	doc_670731433445_item	2789776	et	3	main
tekkinud	doc_670731433445_item	2789777	et	4	main
lisaküsimustele	doc_670731433445_item	2789778	et	4	main
kõik	doc_670731433445_item	2789779	et	4	main
geniaalne	doc_670731433445_item	2789780	et	3	main
on	doc_670731433445_item	2789781	et	4	main
9	doc_670731433445_item	2789782	et	2	main
lihtne	doc_670731433445_item	2789783	et	3	main
10	doc_670731433445_item	2789784	et	2	main
tulge	doc_670731433445_item	2789785	et	3	main
meie	doc_670731433445_item	2789786	et	4	main
virtuaalkodu	doc_670731433445_item	2789787	et	4	main
või	doc_670731433445_item	2789788	et	4	main
postitage	doc_670731433445_item	2789789	et	3	main
kupong	doc_670731433445_item	2789790	et	3	main
1	doc_670731433445_item	2789791	et	2	main
b	doc_670731433445_item	2789794	et	4	main
a	doc_670731433445_item	2789801	et	4	main
seega	doc_670731433445_item	2789804	et	4	main
kuigi	doc_670731433445_item	2789806	et	3	main
vabanduse	doc_670731433445_item	2789813	et	4	main
c	doc_670731433445_item	2789814	et	4	main
varanduse	doc_670731433445_item	2789815	et	3	main
tasakesi	doc_670731433445_item	2789824	et	3	main
a	doc_670731433445_item	2789828	et	4	main
c	doc_670731433445_item	2789834	et	4	main
d	doc_670731433445_item	2789837	et	4	main
6	doc_670731433445_item	2789840	et	2	main
b	doc_670731433445_item	2789843	et	4	main
7	doc_670731433445_item	2789849	et	2	main
ees	doc_670731433445_item	2789857	et	4	main
c	doc_670731433445_item	2789863	et	4	main
liigne	doc_670731433445_item	2789869	et	3	main
c	doc_670731433445_item	2789872	et	4	main
lihtne	doc_670731433445_item	2789875	et	3	main
minge	doc_670731433445_item	2789884	et	3	main
sulud	doc_670731433446_item	2789887	et	3	main
õige	doc_670731433446_item	2789892	et	4	main
punkti	doc_670731433446_item	2789896	et	4	main
maailmakuulsad	doc_670731433446_item	2789897	et	3	main
balletitantsijad	doc_670731433446_item	2789898	et	3	main
abielupaar	doc_670731433446_item	2789899	et	4	main
age	doc_670731433446_item	2789900	et	4	main
oks	doc_670731433446_item	2789901	et	3	main
ja	doc_670731433446_item	2789902	et	3	main
toomas	doc_670731433446_item	2789903	et	3	main
edur	doc_670731433446_item	2789904	et	4	main
on	doc_670731433446_item	2789905	et	4	main
pärit	doc_670731433446_item	2789906	et	3	main
eesti	doc_670731433446_item	2789907	et	4	main
eestist	doc_670731433446_item	2789908	et	3	main
aga	doc_670731433446_item	2789909	et	3	main
elavad	doc_670731433446_item	2789910	et	4	main
praegu	doc_670731433446_item	2789911	et	3	main
inglismaa	doc_670731433446_item	2789912	et	4	main
london	doc_670731433446_item	2789913	et	4	main
inglismaal	doc_670731433446_item	2789914	et	4	main
londonis	doc_670731433446_item	2789915	et	4	main
age	doc_670731433446_item	2789916	et	4	main
on	doc_670731433446_item	2789917	et	4	main
30	doc_670731433446_item	2789918	et	2	main
kolmekümne	doc_670731433446_item	2789919	et	4	main
aastane	doc_670731433446_item	2789920	et	4	main
ja	doc_670731433446_item	2789921	et	3	main
kolm	doc_670731433446_item	2789925	et	3	main
kaks	doc_670731433446_item	2789927	et	3	main
vabakutselised	doc_670731433446_item	2789935	et	4	main
ja	doc_670731433446_item	2789936	et	3	main
teatreid	doc_670731433446_item	2789941	et	3	main
armastama	doc_670731433446_item	2789943	et	3	main
neid	doc_670731433446_item	2789945	et	4	main
väga	doc_670731433446_item	2789946	et	3	main
ning	doc_670731433446_item	2789947	et	3	main
isegi	doc_670731433446_item	2789948	et	4	main
olnud	doc_670731433446_item	2789976	et	4	main
probleeme	doc_670731433446_item	2789977	et	3	main
naine	doc_670731433446_item	2789985	et	3	main
on	doc_670731433446_item	2790003	et	4	main
ainult	doc_670731433446_item	2790007	et	4	main
nendel	doc_670731433446_item	2790012	et	4	main
edule	doc_670731433446_item	2790021	et	3	main
eest	doc_670731433445_item	2789855	et	4	main
kirjutab	doc_670731433445_item	2789860	et	3	main
9	doc_670731433445_item	2789867	et	2	main
d	doc_670731433445_item	2789874	et	4	main
käige	doc_670731433445_item	2789880	et	3	main
avage	doc_670731433446_item	2789886	et	3	main
iga	doc_670731433446_item	2789891	et	4	main
ühe	doc_670731433446_item	2789895	et	4	main
32	doc_670731433446_item	2789924	et	2	main
vabakutseline	doc_670731433446_item	2789934	et	4	main
erinevad	doc_670731433446_item	2789938	et	4	main
inglismaal	doc_670731433446_item	2789942	et	4	main
armastavad	doc_670731433446_item	2789944	et	4	main
räägivad	doc_670731433446_item	2789958	et	3	main
on	doc_670731433446_item	2789975	et	4	main
aastal	doc_670731433446_item	2789981	et	3	main
murdma	doc_670731433446_item	2789982	et	3	main
järve	doc_670731433446_item	2789987	et	4	main
etenduses	doc_670731433446_item	2789989	et	4	main
jalaluu	doc_670731433446_item	2789990	et	4	main
ja	doc_670731433446_item	2789991	et	3	main
olema	doc_670731433446_item	2789998	et	4	main
olla	doc_670731433446_item	2789999	et	3	main
age	doc_670731433446_item	2790000	et	4	main
ja	doc_670731433446_item	2790001	et	3	main
toomas	doc_670731433446_item	2790002	et	3	main
teineteisega	doc_670731433446_item	2790008	et	3	main
paaris	doc_670731433446_item	2790009	et	4	main
nemad	doc_670731433446_item	2790011	et	3	main
tagasihoidlik	doc_670731433446_item	2790024	et	3	main
planeerima	doc_670731433446_item	2790031	et	3	main
ja	doc_670731433446_item	2790038	et	3	main
parem	doc_670731433446_item	2790040	et	4	main
märtsis	doc_670731433446_item	2790043	et	3	main
püsida	doc_670731433446_item	2790062	et	3	main
teksti	doc_670731433446_item	2790080	et	4	main
alt	doc_670731433446_item	2790081	et	4	main
õpi	doc_670731433446_item	2790088	et	4	main
millal	doc_670731433446_item	2790089	et	3	main
on	doc_670731433446_item	2790111	et	4	main
interaktiivse	doc_670731433446_item	2790112	et	3	main
mis	doc_670731433446_item	2790115	et	4	main
3	doc_670731433446_item	2790118	et	2	main
ning	doc_670731433446_item	2790122	et	3	main
teadmisi	doc_670731433446_item	2790125	et	4	main
vastavalt	doc_670731433446_item	2790126	et	4	main
individuaalsele	doc_670731433446_item	2790127	et	3	main
4	doc_670731433446_item	2790128	et	2	main
tasemele	doc_670731433446_item	2790129	et	3	main
aeg	doc_670731433446_item	2790130	et	3	main
vaja	doc_670731433446_item	2790139	et	4	main
ka	doc_670731433446_item	2790140	et	3	main
meie	doc_670731433446_item	2790148	et	4	main
kontorist	doc_670731433446_item	2790149	et	4	main
kätte	doc_670731433446_item	2790155	et	4	main
eest	doc_670731433446_item	2790165	et	4	main
üle	doc_670731433446_item	2790177	et	3	main
9	doc_670731433446_item	2790191	et	2	main
sobid	doc_670731433446_item	2790202	et	4	main
c	doc_670731433446_item	2790205	et	4	main
c	doc_670731433446_item	2790214	et	4	main
kuigi	doc_670731433446_item	2790215	et	3	main
b	doc_670731433446_item	2790221	et	4	main
b	doc_670731433446_item	2790240	et	4	main
liita	doc_670731433446_item	2790242	et	4	main
a	doc_670731433446_item	2790259	et	4	main
abielupaar	doc_670731433447_item	2790308	et	4	main
aga	doc_670731433447_item	2790318	et	3	main
age	doc_670731433447_item	2790325	et	4	main
30	doc_670731433447_item	2790327	et	2	main
aastat	doc_670731433447_item	2790336	et	3	main
räägivad	doc_670731433447_item	2790371	et	3	main
ainult	doc_670731433447_item	2790374	et	4	main
murdma	doc_670731433447_item	2790395	et	3	main
naine	doc_670731433447_item	2790397	et	3	main
olema	doc_670731433447_item	2790410	et	4	main
kuigi	doc_670731433447_item	2790422	et	3	main
nemad	doc_670731433447_item	2790424	et	3	main
eraldi	doc_670731433447_item	2790429	et	4	main
toomas	doc_670731433447_item	2790447	et	3	main
tallinn	doc_670731433447_item	2790459	et	4	main
seejärel	doc_670731433447_item	2790462	et	3	main
on	doc_670731433446_item	2789932	et	4	main
nad	doc_670731433446_item	2789933	et	3	main
teatrid	doc_670731433446_item	2789939	et	3	main
üldiselt	doc_670731433446_item	2789954	et	4	main
hästi	doc_670731433446_item	2789955	et	3	main
viimased	doc_670731433446_item	2789956	et	3	main
noordele	doc_670731433446_item	2789960	et	4	main
ülivõrdes	doc_670731433446_item	2789962	et	3	main
kuid	doc_670731433446_item	2789963	et	4	main
alati	doc_670731433446_item	2789967	et	4	main
läinud	doc_670731433446_item	2789970	et	4	main
mõlemal	doc_670731433446_item	2789971	et	3	main
ja	doc_670731433446_item	2789972	et	3	main
eriti	doc_670731433446_item	2789973	et	3	main
agel	doc_670731433446_item	2789974	et	4	main
tervisega	doc_670731433446_item	2789979	et	3	main
noor	doc_670731433446_item	2789984	et	3	main
pidama	doc_670731433446_item	2789992	et	4	main
otsustanud	doc_670731433446_item	2790004	et	4	main
on	doc_670731433446_item	2790013	et	4	main
tehtud	doc_670731433446_item	2790014	et	4	main
pakkumisi	doc_670731433446_item	2790015	et	4	main
ka	doc_670731433446_item	2790016	et	3	main
eraldi	doc_670731433446_item	2790017	et	4	main
tantsimiseks	doc_670731433446_item	2790018	et	4	main
vaatamata	doc_670731433446_item	2790019	et	4	main
suurele	doc_670731433446_item	2790020	et	4	main
on	doc_670731433446_item	2790029	et	4	main
age	doc_670731433446_item	2790033	et	4	main
tahavad	doc_670731433446_item	2790036	et	3	main
edur	doc_670731433446_item	2790058	et	4	main
iga	doc_670731433446_item	2790082	et	4	main
1	doc_670731433446_item	2790090	et	2	main
soovid	doc_670731433446_item	2790091	et	4	main
saada	doc_670731433446_item	2790098	et	4	main
2	doc_670731433446_item	2790100	et	2	main
õppe	doc_670731433446_item	2790113	et	4	main
sulle	doc_670731433446_item	2790117	et	3	main
vabaduse	doc_670731433446_item	2790119	et	4	main
täpselt	doc_670731433446_item	2790030	et	4	main
ja	doc_670731433446_item	2790034	et	3	main
nad	doc_670731433446_item	2790045	et	3	main
tallinn	doc_670731433446_item	2790047	et	4	main
seejärel	doc_670731433446_item	2790050	et	3	main
lõuna-aafrika	doc_670731433446_item	2790052	et	4	main
lõuna-aafrikasse	doc_670731433446_item	2790053	et	4	main
kui	doc_670731433446_item	2790054	et	3	main
kaua	doc_670731433446_item	2790055	et	3	main
oks	doc_670731433446_item	2790056	et	3	main
ja	doc_670731433446_item	2790057	et	3	main
suudavad	doc_670731433446_item	2790061	et	3	main
nad	doc_670731433446_item	2790065	et	3	main
ütlema	doc_670731433446_item	2790066	et	3	main
ütelda	doc_670731433446_item	2790067	et	4	main
oska	doc_670731433446_item	2790064	et	4	main
nad	doc_670731433446_item	2790068	et	3	main
eelistavad	doc_670731433446_item	2790069	et	4	main
elada	doc_670731433446_item	2790070	et	3	main
üks	doc_670731433446_item	2790071	et	3	main
päev	doc_670731433446_item	2790072	et	3	main
ühe	doc_670731433446_item	2790073	et	4	main
päeva	doc_670731433446_item	2790074	et	4	main
kaupa	doc_670731433446_item	2790075	et	4	main
kirjutage	doc_670731433446_item	2790076	et	3	main
lünka	doc_670731433446_item	2790077	et	4	main
tantsijad	doc_670731433446_item	2790023	et	4	main
tagasihoidliku	doc_670731433446_item	2790025	et	3	main
nende	doc_670731433446_item	2790026	et	4	main
lähiaja	doc_670731433446_item	2790027	et	3	main
esinemised	doc_670731433446_item	2790028	et	4	main
toomas	doc_670731433446_item	2790035	et	3	main
areneda	doc_670731433446_item	2790037	et	3	main
veelgi	doc_670731433446_item	2790039	et	4	main
paremini	doc_670731433446_item	2790041	et	4	main
tantsida	doc_670731433446_item	2790042	et	3	main
tulevad	doc_670731433446_item	2790044	et	4	main
ja	doc_670731433446_item	2790049	et	3	main
veel	doc_670731433446_item	2790059	et	4	main
sõna	doc_670731433446_item	2790079	et	4	main
ühe	doc_670731433446_item	2790086	et	4	main
koduõppesüsteem	doc_670731433446_item	2790095	et	3	main
targemaks	doc_670731433446_item	2790099	et	4	main
seal	doc_670731433446_item	2790102	et	4	main
millal	doc_670731433446_item	2790105	et	3	main
seda	doc_670731433446_item	2790107	et	3	main
soovid	doc_670731433446_item	2790109	et	4	main
käes	doc_670731433446_item	2790110	et	4	main
aega	doc_670731433446_item	2790121	et	4	main
eelise	doc_670731433446_item	2790123	et	4	main
seda	doc_670731433446_item	2790134	et	3	main
saada	doc_670731433446_item	2790137	et	4	main
tarkust	doc_670731433446_item	2790142	et	4	main
lähimast	doc_670731433446_item	2790151	et	4	main
saada	doc_670731433446_item	2790169	et	4	main
selle	doc_670731433446_item	2790176	et	4	main
8	doc_670731433446_item	2790178	et	2	main
vastab	doc_670731433446_item	2790182	et	3	main
korral	doc_670731433446_item	2790184	et	4	main
lihtne	doc_670731433446_item	2790192	et	3	main
meie	doc_670731433446_item	2790195	et	4	main
b	doc_670731433446_item	2790203	et	4	main
soovitad	doc_670731433446_item	2790206	et	3	main
2	doc_670731433446_item	2790209	et	2	main
b	doc_670731433446_item	2790212	et	4	main
vabanduse	doc_670731433446_item	2790222	et	4	main
c	doc_670731433446_item	2790223	et	4	main
d	doc_670731433446_item	2790225	et	4	main
tasakaalule	doc_670731433446_item	2790235	et	3	main
a	doc_670731433446_item	2790250	et	4	main
c	doc_670731433446_item	2790263	et	4	main
külastage	doc_670731433446_item	2790291	et	3	main
d	doc_670731433446_item	2790292	et	4	main
minge	doc_670731433446_item	2790293	et	3	main
harjutus	doc_670731433447_item	2790294	et	4	main
avage	doc_670731433447_item	2790295	et	3	main
sulud	doc_670731433447_item	2790296	et	3	main
numbrid	doc_670731433447_item	2790297	et	3	main
kirjutage	doc_670731433447_item	2790298	et	3	main
õige	doc_670731433447_item	2790301	et	4	main
annab	doc_670731433447_item	2790303	et	3	main
punkti	doc_670731433447_item	2790305	et	4	main
maailmakuulsad	doc_670731433447_item	2790306	et	3	main
balletitantsijad	doc_670731433447_item	2790307	et	3	main
eesti	doc_670731433447_item	2790316	et	4	main
eestist	doc_670731433447_item	2790317	et	3	main
sobiv	doc_670731433446_item	2790078	et	4	main
õige	doc_670731433446_item	2790083	et	4	main
vastus	doc_670731433446_item	2790084	et	3	main
annab	doc_670731433446_item	2790085	et	3	main
unusta	doc_670731433446_item	2790092	et	4	main
umbne	doc_670731433446_item	2790093	et	3	main
klassiruum	doc_670731433446_item	2790094	et	3	main
võimaldab	doc_670731433446_item	2790096	et	3	main
kus	doc_670731433446_item	2790103	et	3	main
ja	doc_670731433446_item	2790104	et	3	main
sa	doc_670731433446_item	2790106	et	3	main
ajastu	doc_670731433446_item	2790114	et	4	main
annab	doc_670731433446_item	2790116	et	3	main
omandada	doc_670731433446_item	2790124	et	3	main
on	doc_670731433446_item	2790138	et	4	main
kui	doc_670731433446_item	2790143	et	3	main
registreerunud	doc_670731433446_item	2790146	et	4	main
postiasutusest	doc_670731433446_item	2790152	et	4	main
7	doc_670731433446_item	2790164	et	2	main
tasud	doc_670731433446_item	2790166	et	4	main
selle	doc_670731433446_item	2790167	et	4	main
meile	doc_670731433446_item	2790172	et	4	main
tagasi	doc_670731433446_item	2790173	et	3	main
on	doc_670731433446_item	2790190	et	4	main
külastage	doc_670731433446_item	2790194	et	3	main
virtuaalkodu	doc_670731433446_item	2790196	et	4	main
või	doc_670731433446_item	2790197	et	4	main
postitage	doc_670731433446_item	2790198	et	3	main
kupong	doc_670731433446_item	2790199	et	3	main
1	doc_670731433446_item	2790200	et	2	main
a	doc_670731433446_item	2790210	et	4	main
just	doc_670731433446_item	2790211	et	3	main
siiski	doc_670731433446_item	2790217	et	4	main
3	doc_670731433446_item	2790218	et	2	main
a	doc_670731433446_item	2790219	et	4	main
vajaduse	doc_670731433446_item	2790220	et	3	main
raha	doc_670731433446_item	2790132	et	4	main
et	doc_670731433446_item	2790133	et	3	main
5	doc_670731433446_item	2790135	et	2	main
kokku	doc_670731433446_item	2790136	et	3	main
oled	doc_670731433446_item	2790144	et	3	main
kursusele	doc_670731433446_item	2790145	et	3	main
saad	doc_670731433446_item	2790147	et	4	main
igal	doc_670731433446_item	2790153	et	3	main
kuul	doc_670731433446_item	2790154	et	4	main
õppematerjalid	doc_670731433446_item	2790156	et	3	main
raamatu	doc_670731433446_item	2790157	et	4	main
ja	doc_670731433446_item	2790158	et	3	main
helikasseti	doc_670731433446_item	2790159	et	4	main
6	doc_670731433446_item	2790160	et	2	main
ning	doc_670731433446_item	2790161	et	3	main
kodutöö	doc_670731433446_item	2790162	et	4	main
kursuse	doc_670731433446_item	2790163	et	3	main
täidetud	doc_670731433446_item	2790170	et	4	main
kodutöö	doc_670731433446_item	2790171	et	4	main
kirjutab	doc_670731433446_item	2790179	et	3	main
ning	doc_670731433446_item	2790181	et	3	main
a	doc_670731433446_item	2790201	et	4	main
soovid	doc_670731433446_item	2790204	et	4	main
d	doc_670731433446_item	2790207	et	4	main
solvud	doc_670731433446_item	2790208	et	3	main
d	doc_670731433446_item	2790216	et	4	main
varanduse	doc_670731433446_item	2790224	et	3	main
vabaduse	doc_670731433446_item	2790226	et	4	main
b	doc_670731433446_item	2790230	et	4	main
tasemele	doc_670731433446_item	2790231	et	3	main
panna	doc_670731433446_item	2790248	et	4	main
6	doc_670731433446_item	2790249	et	2	main
taga	doc_670731433446_item	2790260	et	4	main
b	doc_670731433446_item	2790261	et	4	main
ette	doc_670731433446_item	2790262	et	4	main
liikuv	doc_670731433446_item	2790282	et	4	main
lihtne	doc_670731433446_item	2790284	et	3	main
age	doc_670731433447_item	2790309	et	4	main
oks	doc_670731433447_item	2790310	et	3	main
ja	doc_670731433447_item	2790311	et	3	main
toomas	doc_670731433447_item	2790312	et	3	main
elavad	doc_670731433447_item	2790319	et	4	main
inglismaa	doc_670731433447_item	2790321	et	4	main
inglismaal	doc_670731433447_item	2790323	et	4	main
on	doc_670731433447_item	2790326	et	4	main
kolmkümne	doc_670731433447_item	2790328	et	4	main
aastane	doc_670731433447_item	2790329	et	4	main
ja	doc_670731433447_item	2790330	et	3	main
toomas	doc_670731433447_item	2790331	et	3	main
vana	doc_670731433447_item	2790337	et	4	main
tuhande	doc_670731433447_item	2790340	et	3	main
vabakutselised	doc_670731433447_item	2790348	et	4	main
inglismaal	doc_670731433447_item	2790355	et	4	main
neid	doc_670731433447_item	2790358	et	4	main
isegi	doc_670731433447_item	2790361	et	4	main
karmid	doc_670731433447_item	2790362	et	4	main
kriitikud	doc_670731433447_item	2790363	et	3	main
suhtuma	doc_670731433447_item	2790364	et	3	main
suhtuvad	doc_670731433447_item	2790365	et	4	main
nooredest	doc_670731433447_item	2790373	et	4	main
ülivõrdes	doc_670731433447_item	2790375	et	3	main
pole	doc_670731433447_item	2790378	et	3	main
on	doc_670731433447_item	2790388	et	4	main
tervis	doc_670731433447_item	2790391	et	3	main
1990	doc_670731433447_item	2790393	et	2	main
otsustanud	doc_670731433447_item	2790416	et	4	main
tantsida	doc_670731433447_item	2790418	et	3	main
ainult	doc_670731433447_item	2790419	et	4	main
geniaalne	doc_670731433446_item	2790189	et	3	main
10	doc_670731433446_item	2790193	et	2	main
seega	doc_670731433446_item	2790213	et	4	main
c	doc_670731433446_item	2790232	et	4	main
tasakesi	doc_670731433446_item	2790233	et	3	main
d	doc_670731433446_item	2790234	et	4	main
5	doc_670731433446_item	2790236	et	2	main
a	doc_670731433446_item	2790237	et	4	main
kokku	doc_670731433446_item	2790238	et	3	main
ning	doc_670731433446_item	2790251	et	3	main
b	doc_670731433446_item	2790252	et	4	main
vaid	doc_670731433446_item	2790253	et	3	main
c	doc_670731433446_item	2790254	et	4	main
eest	doc_670731433446_item	2790264	et	4	main
c	doc_670731433446_item	2790290	et	4	main
iga	doc_670731433447_item	2790300	et	4	main
ühe	doc_670731433447_item	2790304	et	4	main
london	doc_670731433447_item	2790322	et	4	main
on	doc_670731433447_item	2790332	et	4	main
32	doc_670731433447_item	2790333	et	2	main
kolmkümme	doc_670731433447_item	2790334	et	4	main
kaks	doc_670731433447_item	2790335	et	3	main
1997a	doc_670731433447_item	2790339	et	4	main
teatride	doc_670731433447_item	2790354	et	4	main
nendesse	doc_670731433447_item	2790366	et	4	main
sugugi	doc_670731433447_item	2790379	et	4	main
eriti	doc_670731433447_item	2790386	et	3	main
probleeme	doc_670731433447_item	2790390	et	3	main
aastal	doc_670731433447_item	2790394	et	3	main
pidama	doc_670731433447_item	2790404	et	4	main
peab	doc_670731433447_item	2790405	et	4	main
mõnda	doc_670731433447_item	2790406	et	4	main
olema	doc_670731433447_item	2790411	et	4	main
ka	doc_670731433447_item	2790428	et	3	main
elavad	doc_670731433447_item	2790434	et	4	main
tantsijad	doc_670731433447_item	2790435	et	4	main
tagasihoidlik	doc_670731433447_item	2790436	et	3	main
tagasihoidliku	doc_670731433447_item	2790437	et	3	main
nende	doc_670731433447_item	2790438	et	4	main
lähiaja	doc_670731433447_item	2790439	et	3	main
ja	doc_670731433447_item	2790446	et	3	main
ja	doc_670731433447_item	2790461	et	3	main
lõuna-aafrika	doc_670731433447_item	2790464	et	4	main
veel	doc_670731433447_item	2790471	et	4	main
püsida	doc_670731433447_item	2790474	et	3	main
üks	doc_670731433447_item	2790483	et	3	main
punkti	doc_670731433447_item	2790499	et	4	main
targemaks	doc_670731433447_item	2790511	et	4	main
2	doc_670731433447_item	2790512	et	2	main
just	doc_670731433447_item	2790513	et	3	main
soovid	doc_670731433447_item	2790521	et	4	main
3	doc_670731433447_item	2790530	et	2	main
vabaduse	doc_670731433447_item	2790531	et	4	main
planeerida	doc_670731433447_item	2790532	et	3	main
aega	doc_670731433447_item	2790533	et	4	main
ning	doc_670731433447_item	2790534	et	3	main
eelise	doc_670731433447_item	2790535	et	4	main
omandada	doc_670731433447_item	2790536	et	3	main
4	doc_670731433447_item	2790540	et	2	main
registreerunud	doc_670731433447_item	2790558	et	4	main
meie	doc_670731433447_item	2790560	et	4	main
tasud	doc_670731433447_item	2790578	et	4	main
kodutöö	doc_670731433447_item	2790583	et	4	main
korral	doc_670731433447_item	2790596	et	4	main
9	doc_670731433447_item	2790603	et	2	main
tulge	doc_670731433447_item	2790606	et	3	main
c	doc_670731433447_item	2790617	et	4	main
d	doc_670731433447_item	2790628	et	4	main
vabanduse	doc_670731433447_item	2790634	et	4	main
b	doc_670731433447_item	2790642	et	4	main
tasemele	doc_670731433447_item	2790643	et	3	main
saada	doc_670731433447_item	2790651	et	4	main
kokku	doc_670731433447_item	2790653	et	3	main
a	doc_670731433447_item	2790662	et	4	main
ning	doc_670731433447_item	2790663	et	3	main
b	doc_670731433447_item	2790664	et	4	main
vaid	doc_670731433447_item	2790665	et	3	main
lihtne	doc_670731433447_item	2790696	et	3	main
b	doc_670731433447_item	2790700	et	4	main
harjutus	doc_670731433448_item	2790706	et	4	main
avage	doc_670731433448_item	2790707	et	3	main
sulud	doc_670731433448_item	2790708	et	3	main
4	doc_670731433446_item	2790227	et	2	main
a	doc_670731433446_item	2790228	et	4	main
tasule	doc_670731433446_item	2790229	et	3	main
saada	doc_670731433446_item	2790239	et	4	main
kokku	doc_670731433446_item	2790241	et	3	main
c	doc_670731433446_item	2790243	et	4	main
kokku	doc_670731433446_item	2790244	et	3	main
hoida	doc_670731433446_item	2790245	et	3	main
d	doc_670731433446_item	2790246	et	4	main
kokku	doc_670731433446_item	2790247	et	3	main
kuid	doc_670731433446_item	2790255	et	4	main
d	doc_670731433446_item	2790256	et	4	main
et	doc_670731433446_item	2790257	et	3	main
7	doc_670731433446_item	2790258	et	2	main
d	doc_670731433446_item	2790265	et	4	main
ees	doc_670731433446_item	2790266	et	4	main
8	doc_670731433446_item	2790267	et	2	main
a	doc_670731433446_item	2790268	et	4	main
kirjutab	doc_670731433446_item	2790269	et	3	main
b	doc_670731433446_item	2790270	et	4	main
palub	doc_670731433446_item	2790271	et	3	main
c	doc_670731433446_item	2790272	et	4	main
parandab	doc_670731433446_item	2790273	et	3	main
d	doc_670731433446_item	2790274	et	4	main
muudab	doc_670731433446_item	2790275	et	3	main
9	doc_670731433446_item	2790276	et	2	main
a	doc_670731433446_item	2790277	et	4	main
liigne	doc_670731433446_item	2790278	et	3	main
b	doc_670731433446_item	2790279	et	4	main
libe	doc_670731433446_item	2790280	et	3	main
c	doc_670731433446_item	2790281	et	4	main
d	doc_670731433446_item	2790283	et	4	main
10	doc_670731433446_item	2790285	et	2	main
a	doc_670731433446_item	2790286	et	4	main
tulge	doc_670731433446_item	2790287	et	3	main
b	doc_670731433446_item	2790288	et	4	main
käige	doc_670731433446_item	2790289	et	3	main
sõnadega	doc_670731433447_item	2790299	et	3	main
vastus	doc_670731433447_item	2790302	et	3	main
edur	doc_670731433447_item	2790313	et	4	main
on	doc_670731433447_item	2790314	et	4	main
pärit	doc_670731433447_item	2790315	et	3	main
praegu	doc_670731433447_item	2790320	et	3	main
londonis	doc_670731433447_item	2790324	et	4	main
alates	doc_670731433447_item	2790338	et	3	main
üheksasaja	doc_670731433447_item	2790341	et	4	main
aastal	doc_670731433447_item	2790344	et	3	main
on	doc_670731433447_item	2790345	et	4	main
nad	doc_670731433447_item	2790346	et	3	main
ja	doc_670731433447_item	2790349	et	3	main
erinevad	doc_670731433447_item	2790351	et	4	main
teatrid	doc_670731433447_item	2790352	et	3	main
erinevaid	doc_670731433447_item	2790353	et	4	main
armastama	doc_670731433447_item	2790356	et	3	main
armastatakse	doc_670731433447_item	2790357	et	3	main
ning	doc_670731433447_item	2790360	et	3	main
noored	doc_670731433447_item	2790372	et	3	main
kuid	doc_670731433447_item	2790376	et	4	main
kõik	doc_670731433447_item	2790377	et	4	main
alati	doc_670731433447_item	2790380	et	4	main
nii	doc_670731433447_item	2790381	et	3	main
agel	doc_670731433447_item	2790387	et	4	main
olnud	doc_670731433447_item	2790389	et	4	main
tervisega	doc_670731433447_item	2790392	et	3	main
järve	doc_670731433447_item	2790399	et	4	main
etenduse	doc_670731433447_item	2790401	et	4	main
jalaluu	doc_670731433447_item	2790402	et	4	main
ja	doc_670731433447_item	2790403	et	3	main
aega	doc_670731433447_item	2790407	et	4	main
tantsimisest	doc_670731433447_item	2790408	et	4	main
eemal	doc_670731433447_item	2790409	et	3	main
age	doc_670731433447_item	2790412	et	4	main
on	doc_670731433447_item	2790415	et	4	main
tantsima	doc_670731433447_item	2790417	et	3	main
pakkumisi	doc_670731433447_item	2790427	et	4	main
esinemised	doc_670731433447_item	2790440	et	4	main
tahavad	doc_670731433447_item	2790448	et	3	main
nad	doc_670731433447_item	2790457	et	3	main
esinema	doc_670731433447_item	2790458	et	3	main
kui	doc_670731433447_item	2790466	et	3	main
ütelda	doc_670731433447_item	2790479	et	4	main
nad	doc_670731433447_item	2790480	et	3	main
elada	doc_670731433447_item	2790482	et	3	main
päeva	doc_670731433447_item	2790486	et	4	main
kirjutage	doc_670731433447_item	2790488	et	3	main
sobiv	doc_670731433447_item	2790490	et	4	main
õige	doc_670731433447_item	2790495	et	4	main
vastus	doc_670731433447_item	2790496	et	3	main
annab	doc_670731433447_item	2790497	et	3	main
ühe	doc_670731433447_item	2790498	et	4	main
üheksakümne	doc_670731433447_item	2790342	et	4	main
seitsel	doc_670731433447_item	2790343	et	4	main
vabakutseline	doc_670731433447_item	2790347	et	4	main
esinevad	doc_670731433447_item	2790350	et	4	main
väga	doc_670731433447_item	2790359	et	3	main
üldiselt	doc_670731433447_item	2790367	et	4	main
hästi	doc_670731433447_item	2790368	et	3	main
viimased	doc_670731433447_item	2790369	et	3	main
artiklid	doc_670731433447_item	2790370	et	3	main
kergelt	doc_670731433447_item	2790382	et	4	main
läinud	doc_670731433447_item	2790383	et	4	main
mõlemal	doc_670731433447_item	2790384	et	3	main
ja	doc_670731433447_item	2790385	et	3	main
noor	doc_670731433447_item	2790396	et	3	main
luikede	doc_670731433447_item	2790398	et	3	main
etendus	doc_670731433447_item	2790400	et	4	main
ja	doc_670731433447_item	2790413	et	3	main
toomas	doc_670731433447_item	2790414	et	3	main
teineteisega	doc_670731433447_item	2790420	et	3	main
paaris	doc_670731433447_item	2790421	et	4	main
nemad	doc_670731433447_item	2790423	et	3	main
tantsimiseks	doc_670731433447_item	2790430	et	4	main
edule	doc_670731433447_item	2790433	et	3	main
on	doc_670731433447_item	2790441	et	4	main
täpselt	doc_670731433447_item	2790442	et	4	main
planeerima	doc_670731433447_item	2790443	et	3	main
planeerida	doc_670731433447_item	2790444	et	3	main
age	doc_670731433447_item	2790445	et	4	main
lõuna-aafrikale	doc_670731433447_item	2790465	et	4	main
ja	doc_670731433447_item	2790469	et	3	main
suudavad	doc_670731433447_item	2790473	et	3	main
eelistavad	doc_670731433447_item	2790481	et	4	main
päev	doc_670731433447_item	2790484	et	3	main
kaupa	doc_670731433447_item	2790487	et	4	main
lünka	doc_670731433447_item	2790489	et	4	main
õpi	doc_670731433447_item	2790500	et	4	main
millal	doc_670731433447_item	2790501	et	3	main
parasjagu	doc_670731433447_item	2790520	et	3	main
käes	doc_670731433447_item	2790522	et	4	main
on	doc_670731433447_item	2790523	et	4	main
interaktiivse	doc_670731433447_item	2790524	et	3	main
õppe	doc_670731433447_item	2790525	et	4	main
individuaalsele	doc_670731433447_item	2790539	et	3	main
vaja	doc_670731433447_item	2790551	et	4	main
ka	doc_670731433447_item	2790552	et	3	main
pisut	doc_670731433447_item	2790553	et	3	main
tarkust	doc_670731433447_item	2790554	et	4	main
kui	doc_670731433447_item	2790555	et	3	main
lähimast	doc_670731433447_item	2790563	et	4	main
raamatu	doc_670731433447_item	2790569	et	4	main
ja	doc_670731433447_item	2790570	et	3	main
eest	doc_670731433447_item	2790577	et	4	main
saada	doc_670731433447_item	2790581	et	4	main
täidetud	doc_670731433447_item	2790582	et	4	main
8	doc_670731433447_item	2790590	et	2	main
kirjutab	doc_670731433447_item	2790591	et	3	main
vead	doc_670731433447_item	2790592	et	4	main
ning	doc_670731433447_item	2790593	et	3	main
vastab	doc_670731433447_item	2790594	et	3	main
vajaduse	doc_670731433447_item	2790595	et	3	main
on	doc_670731433447_item	2790602	et	4	main
lihtne	doc_670731433447_item	2790604	et	3	main
meie	doc_670731433447_item	2790607	et	4	main
või	doc_670731433447_item	2790609	et	4	main
postitage	doc_670731433447_item	2790610	et	3	main
kupong	doc_670731433447_item	2790611	et	3	main
soovid	doc_670731433447_item	2790616	et	4	main
soovitad	doc_670731433447_item	2790618	et	3	main
d	doc_670731433447_item	2790619	et	4	main
a	doc_670731433447_item	2790622	et	4	main
b	doc_670731433447_item	2790624	et	4	main
seega	doc_670731433447_item	2790625	et	4	main
c	doc_670731433447_item	2790626	et	4	main
kuigi	doc_670731433447_item	2790627	et	3	main
vajaduse	doc_670731433447_item	2790632	et	3	main
d	doc_670731433447_item	2790637	et	4	main
vabaduse	doc_670731433447_item	2790638	et	4	main
d	doc_670731433447_item	2790646	et	4	main
tasakaalule	doc_670731433447_item	2790647	et	3	main
panna	doc_670731433447_item	2790660	et	4	main
6	doc_670731433447_item	2790661	et	2	main
d	doc_670731433447_item	2790668	et	4	main
et	doc_670731433447_item	2790669	et	3	main
d	doc_670731433447_item	2790704	et	4	main
on	doc_670731433447_item	2790425	et	4	main
tehtud	doc_670731433447_item	2790426	et	4	main
vaatamata	doc_670731433447_item	2790431	et	4	main
suurele	doc_670731433447_item	2790432	et	4	main
areneda	doc_670731433447_item	2790449	et	3	main
ja	doc_670731433447_item	2790450	et	3	main
parem	doc_670731433447_item	2790452	et	4	main
parim	doc_670731433447_item	2790453	et	4	main
tantsida	doc_670731433447_item	2790454	et	3	main
märtsis	doc_670731433447_item	2790455	et	3	main
veelgi	doc_670731433447_item	2790451	et	4	main
tulevad	doc_670731433447_item	2790456	et	4	main
tallinnasse	doc_670731433447_item	2790460	et	3	main
sõidavad	doc_670731433447_item	2790463	et	3	main
oks	doc_670731433447_item	2790468	et	3	main
edur	doc_670731433447_item	2790470	et	4	main
tipus	doc_670731433447_item	2790472	et	3	main
ei	doc_670731433447_item	2790475	et	4	main
oska	doc_670731433447_item	2790476	et	4	main
nad	doc_670731433447_item	2790477	et	3	main
ütlema	doc_670731433447_item	2790478	et	3	main
sõna	doc_670731433447_item	2790491	et	4	main
unusta	doc_670731433447_item	2790504	et	4	main
umbne	doc_670731433447_item	2790505	et	3	main
klassiruum	doc_670731433447_item	2790506	et	3	main
koduõppesüsteem	doc_670731433447_item	2790507	et	3	main
võimaldab	doc_670731433447_item	2790508	et	3	main
sul	doc_670731433447_item	2790509	et	3	main
saada	doc_670731433447_item	2790510	et	4	main
ajastu	doc_670731433447_item	2790526	et	4	main
teadmisi	doc_670731433447_item	2790537	et	4	main
saada	doc_670731433447_item	2790549	et	4	main
on	doc_670731433447_item	2790550	et	4	main
kätte	doc_670731433447_item	2790567	et	4	main
helikasseti	doc_670731433447_item	2790571	et	4	main
meile	doc_670731433447_item	2790584	et	4	main
ka	doc_670731433447_item	2790597	et	3	main
geniaalne	doc_670731433447_item	2790601	et	3	main
10	doc_670731433447_item	2790605	et	2	main
solvud	doc_670731433447_item	2790620	et	3	main
b	doc_670731433447_item	2790633	et	4	main
varanduse	doc_670731433447_item	2790636	et	3	main
4	doc_670731433447_item	2790639	et	2	main
a	doc_670731433447_item	2790640	et	4	main
tasule	doc_670731433447_item	2790641	et	3	main
kokku	doc_670731433447_item	2790650	et	3	main
liita	doc_670731433447_item	2790654	et	4	main
c	doc_670731433447_item	2790655	et	4	main
d	doc_670731433447_item	2790658	et	4	main
kokku	doc_670731433447_item	2790659	et	3	main
kuid	doc_670731433447_item	2790667	et	4	main
10	doc_670731433447_item	2790697	et	2	main
õige	doc_670731433448_item	2790713	et	4	main
vastus	doc_670731433448_item	2790714	et	3	main
annab	doc_670731433448_item	2790715	et	3	main
kaua	doc_670731433447_item	2790467	et	3	main
ühe	doc_670731433447_item	2790485	et	4	main
teksti	doc_670731433447_item	2790492	et	4	main
alt	doc_670731433447_item	2790493	et	4	main
iga	doc_670731433447_item	2790494	et	4	main
1	doc_670731433447_item	2790502	et	2	main
sobid	doc_670731433447_item	2790503	et	4	main
seal	doc_670731433447_item	2790514	et	4	main
kus	doc_670731433447_item	2790515	et	3	main
ja	doc_670731433447_item	2790516	et	3	main
millal	doc_670731433447_item	2790517	et	3	main
sa	doc_670731433447_item	2790518	et	3	main
seda	doc_670731433447_item	2790519	et	3	main
mis	doc_670731433447_item	2790527	et	4	main
annab	doc_670731433447_item	2790528	et	3	main
sulle	doc_670731433447_item	2790529	et	3	main
tasule	doc_670731433447_item	2790541	et	3	main
aeg	doc_670731433447_item	2790542	et	3	main
seda	doc_670731433447_item	2790546	et	3	main
kokku	doc_670731433447_item	2790548	et	3	main
kursusele	doc_670731433447_item	2790557	et	3	main
saad	doc_670731433447_item	2790559	et	4	main
kontorist	doc_670731433447_item	2790561	et	4	main
või	doc_670731433447_item	2790562	et	4	main
õppematerjalid	doc_670731433447_item	2790568	et	3	main
selle	doc_670731433447_item	2790579	et	4	main
kättesaamisel	doc_670731433447_item	2790580	et	4	main
tagasi	doc_670731433447_item	2790585	et	3	main
õpetaja	doc_670731433447_item	2790586	et	4	main
vaatab	doc_670731433447_item	2790587	et	3	main
lisaküsimustele	doc_670731433447_item	2790599	et	4	main
kõik	doc_670731433447_item	2790600	et	4	main
sobid	doc_670731433447_item	2790614	et	4	main
b	doc_670731433447_item	2790615	et	4	main
vastavalt	doc_670731433447_item	2790538	et	4	main
on	doc_670731433447_item	2790543	et	4	main
raha	doc_670731433447_item	2790544	et	4	main
et	doc_670731433447_item	2790545	et	3	main
5	doc_670731433447_item	2790547	et	2	main
oled	doc_670731433447_item	2790556	et	3	main
postiasutusest	doc_670731433447_item	2790564	et	4	main
igal	doc_670731433447_item	2790565	et	3	main
kuul	doc_670731433447_item	2790566	et	4	main
6	doc_670731433447_item	2790572	et	2	main
vaid	doc_670731433447_item	2790573	et	3	main
kodutöö	doc_670731433447_item	2790574	et	4	main
kursuse	doc_670731433447_item	2790575	et	3	main
7	doc_670731433447_item	2790576	et	2	main
selle	doc_670731433447_item	2790588	et	4	main
üle	doc_670731433447_item	2790589	et	3	main
tekkinud	doc_670731433447_item	2790598	et	4	main
virtuaalkodu	doc_670731433447_item	2790608	et	4	main
1	doc_670731433447_item	2790612	et	2	main
a	doc_670731433447_item	2790613	et	4	main
2	doc_670731433447_item	2790621	et	2	main
siiski	doc_670731433447_item	2790629	et	4	main
3	doc_670731433447_item	2790630	et	2	main
c	doc_670731433447_item	2790644	et	4	main
tasakesi	doc_670731433447_item	2790645	et	3	main
5	doc_670731433447_item	2790648	et	2	main
a	doc_670731433447_item	2790649	et	4	main
b	doc_670731433447_item	2790652	et	4	main
tulge	doc_670731433447_item	2790699	et	3	main
käige	doc_670731433447_item	2790701	et	3	main
c	doc_670731433447_item	2790702	et	4	main
külastage	doc_670731433447_item	2790703	et	3	main
maailmakuulsad	doc_670731433448_item	2790718	et	3	main
balletitantsijad	doc_670731433448_item	2790719	et	3	main
age	doc_670731433448_item	2790721	et	4	main
ja	doc_670731433448_item	2790723	et	3	main
inglismaa	doc_670731433448_item	2790733	et	4	main
london	doc_670731433448_item	2790734	et	4	main
üheksakümmend	doc_670731433448_item	2790754	et	4	main
on	doc_670731433448_item	2790756	et	4	main
nad	doc_670731433448_item	2790757	et	3	main
vabakutseline	doc_670731433448_item	2790758	et	4	main
suhtuvad	doc_670731433448_item	2790776	et	4	main
nendesse	doc_670731433448_item	2790777	et	4	main
kuid	doc_670731433448_item	2790787	et	4	main
alati	doc_670731433448_item	2790791	et	4	main
ja	doc_670731433448_item	2790796	et	3	main
agel	doc_670731433448_item	2790798	et	4	main
olnud	doc_670731433448_item	2790800	et	4	main
probleeme	doc_670731433448_item	2790801	et	3	main
tervis	doc_670731433448_item	2790802	et	3	main
tervisega	doc_670731433448_item	2790803	et	3	main
1990	doc_670731433448_item	2790804	et	2	main
aastal	doc_670731433448_item	2790805	et	3	main
murdma	doc_670731433448_item	2790806	et	3	main
murdis	doc_670731433448_item	2790807	et	3	main
noor	doc_670731433448_item	2790808	et	3	main
naine	doc_670731433448_item	2790809	et	3	main
luikede	doc_670731433448_item	2790810	et	3	main
jalaluu	doc_670731433448_item	2790813	et	4	main
eemal	doc_670731433448_item	2790820	et	3	main
olla	doc_670731433448_item	2790822	et	3	main
toomas	doc_670731433448_item	2790825	et	3	main
tantsima	doc_670731433448_item	2790828	et	3	main
tantsima	doc_670731433448_item	2790829	et	3	main
pakkumisi	doc_670731433448_item	2790838	et	4	main
ka	doc_670731433448_item	2790839	et	3	main
elavad	doc_670731433448_item	2790845	et	4	main
tantsijad	doc_670731433448_item	2790846	et	4	main
tagasihoidlik	doc_670731433448_item	2790847	et	3	main
tagasihoidlikult	doc_670731433448_item	2790848	et	4	main
planeeritud	doc_670731433448_item	2790855	et	4	main
kui	doc_670731433448_item	2790877	et	3	main
kaua	doc_670731433448_item	2790878	et	3	main
oks	doc_670731433448_item	2790879	et	3	main
ja	doc_670731433448_item	2790880	et	3	main
edur	doc_670731433448_item	2790881	et	4	main
just	doc_670731433447_item	2790623	et	3	main
a	doc_670731433447_item	2790631	et	4	main
c	doc_670731433447_item	2790635	et	4	main
kokku	doc_670731433447_item	2790656	et	3	main
hoida	doc_670731433447_item	2790657	et	3	main
c	doc_670731433447_item	2790666	et	4	main
7	doc_670731433447_item	2790670	et	2	main
a	doc_670731433447_item	2790671	et	4	main
taga	doc_670731433447_item	2790672	et	4	main
b	doc_670731433447_item	2790673	et	4	main
ette	doc_670731433447_item	2790674	et	4	main
c	doc_670731433447_item	2790675	et	4	main
eest	doc_670731433447_item	2790676	et	4	main
d	doc_670731433447_item	2790677	et	4	main
ees	doc_670731433447_item	2790678	et	4	main
8	doc_670731433447_item	2790679	et	2	main
a	doc_670731433447_item	2790680	et	4	main
kirjutab	doc_670731433447_item	2790681	et	3	main
b	doc_670731433447_item	2790682	et	4	main
palub	doc_670731433447_item	2790683	et	3	main
c	doc_670731433447_item	2790684	et	4	main
parandab	doc_670731433447_item	2790685	et	3	main
d	doc_670731433447_item	2790686	et	4	main
muudab	doc_670731433447_item	2790687	et	3	main
9	doc_670731433447_item	2790688	et	2	main
a	doc_670731433447_item	2790689	et	4	main
liigne	doc_670731433447_item	2790690	et	3	main
b	doc_670731433447_item	2790691	et	4	main
libe	doc_670731433447_item	2790692	et	3	main
c	doc_670731433447_item	2790693	et	4	main
liikuv	doc_670731433447_item	2790694	et	4	main
d	doc_670731433447_item	2790695	et	4	main
a	doc_670731433447_item	2790698	et	4	main
iga	doc_670731433448_item	2790712	et	4	main
punkti	doc_670731433448_item	2790717	et	4	main
abielupaar	doc_670731433448_item	2790720	et	4	main
edur	doc_670731433448_item	2790725	et	4	main
pärit	doc_670731433448_item	2790727	et	3	main
kolmekümne	doc_670731433448_item	2790740	et	4	main
aastane	doc_670731433448_item	2790741	et	4	main
ja	doc_670731433448_item	2790742	et	3	main
toomas	doc_670731433448_item	2790743	et	3	main
alates	doc_670731433448_item	2790750	et	3	main
1997a	doc_670731433448_item	2790751	et	4	main
tuhande	doc_670731433448_item	2790752	et	3	main
seitsemst	doc_670731433448_item	2790755	et	4	main
viimased	doc_670731433448_item	2790780	et	3	main
sugugi	doc_670731433448_item	2790790	et	4	main
mõlemal	doc_670731433448_item	2790795	et	3	main
ja	doc_670731433448_item	2790814	et	3	main
pidas	doc_670731433448_item	2790816	et	3	main
minge	doc_670731433447_item	2790705	et	3	main
ühe	doc_670731433448_item	2790716	et	4	main
oks	doc_670731433448_item	2790722	et	3	main
toomas	doc_670731433448_item	2790724	et	3	main
on	doc_670731433448_item	2790726	et	4	main
eesti	doc_670731433448_item	2790728	et	4	main
eestis	doc_670731433448_item	2790729	et	3	main
aga	doc_670731433448_item	2790730	et	3	main
inglismaal	doc_670731433448_item	2790735	et	4	main
on	doc_670731433448_item	2790738	et	4	main
kaheksa	doc_670731433448_item	2790747	et	4	main
aastat	doc_670731433448_item	2790748	et	3	main
vana	doc_670731433448_item	2790749	et	4	main
üldiselt	doc_670731433448_item	2790778	et	4	main
hästi	doc_670731433448_item	2790779	et	3	main
noortest	doc_670731433448_item	2790784	et	4	main
pole	doc_670731433448_item	2790789	et	3	main
kergelt	doc_670731433448_item	2790793	et	4	main
on	doc_670731433448_item	2790799	et	4	main
järve	doc_670731433448_item	2790811	et	4	main
pidama	doc_670731433448_item	2790815	et	4	main
mõnda	doc_670731433448_item	2790817	et	4	main
eraldi	doc_670731433448_item	2790840	et	4	main
esinemised	doc_670731433448_item	2790851	et	4	main
ja	doc_670731433448_item	2790857	et	3	main
toomas	doc_670731433448_item	2790858	et	3	main
ja	doc_670731433448_item	2790861	et	3	main
tulevad	doc_670731433448_item	2790867	et	4	main
lõuna-aafrika	doc_670731433448_item	2790875	et	4	main
lõuna-aafrikasse	doc_670731433448_item	2790876	et	4	main
targemaks	doc_670731433448_item	2790922	et	4	main
parasjagu	doc_670731433448_item	2790931	et	3	main
annab	doc_670731433448_item	2790939	et	3	main
aega	doc_670731433448_item	2790944	et	4	main
eelise	doc_670731433448_item	2790946	et	4	main
5	doc_670731433448_item	2790958	et	2	main
meie	doc_670731433448_item	2790971	et	4	main
kuul	doc_670731433448_item	2790977	et	4	main
ning	doc_670731433448_item	2790984	et	3	main
7	doc_670731433448_item	2790987	et	2	main
meile	doc_670731433448_item	2790995	et	4	main
parandab	doc_670731433448_item	2791002	et	3	main
vajaduse	doc_670731433448_item	2791006	et	3	main
numbrid	doc_670731433448_item	2790709	et	3	main
kirjutage	doc_670731433448_item	2790710	et	3	main
sõnadega	doc_670731433448_item	2790711	et	3	main
elavad	doc_670731433448_item	2790731	et	4	main
praegu	doc_670731433448_item	2790732	et	3	main
age	doc_670731433448_item	2790737	et	4	main
kolmekümne	doc_670731433448_item	2790746	et	4	main
vabakutselised	doc_670731433448_item	2790759	et	4	main
artiklid	doc_670731433448_item	2790781	et	3	main
noored	doc_670731433448_item	2790783	et	3	main
ainult	doc_670731433448_item	2790785	et	4	main
ülivõrdes	doc_670731433448_item	2790786	et	3	main
läinud	doc_670731433448_item	2790794	et	4	main
eriti	doc_670731433448_item	2790797	et	3	main
tantsimisest	doc_670731433448_item	2790819	et	4	main
olema	doc_670731433448_item	2790821	et	4	main
age	doc_670731433448_item	2790823	et	4	main
on	doc_670731433448_item	2790836	et	4	main
tehtud	doc_670731433448_item	2790837	et	4	main
suurele	doc_670731433448_item	2790843	et	4	main
edule	doc_670731433448_item	2790844	et	3	main
on	doc_670731433448_item	2790852	et	4	main
täpselt	doc_670731433448_item	2790853	et	4	main
planeerima	doc_670731433448_item	2790854	et	3	main
veelgi	doc_670731433448_item	2790862	et	4	main
tantsida	doc_670731433448_item	2790865	et	3	main
nad	doc_670731433448_item	2790868	et	3	main
veel	doc_670731433448_item	2790882	et	4	main
umbne	doc_670731433448_item	2790916	et	3	main
klassiruum	doc_670731433448_item	2790917	et	3	main
koduõppesüsteem	doc_670731433448_item	2790918	et	3	main
võimaldab	doc_670731433448_item	2790919	et	3	main
saada	doc_670731433448_item	2790921	et	4	main
seda	doc_670731433448_item	2790930	et	3	main
mis	doc_670731433448_item	2790938	et	4	main
raha	doc_670731433448_item	2790955	et	4	main
et	doc_670731433448_item	2790956	et	3	main
seda	doc_670731433448_item	2790957	et	3	main
kokku	doc_670731433448_item	2790959	et	3	main
ka	doc_670731433448_item	2790963	et	3	main
pisut	doc_670731433448_item	2790964	et	3	main
kursusele	doc_670731433448_item	2790968	et	3	main
või	doc_670731433448_item	2790973	et	4	main
lähimast	doc_670731433448_item	2790974	et	4	main
kätte	doc_670731433448_item	2790978	et	4	main
helikasseti	doc_670731433448_item	2790982	et	4	main
saada	doc_670731433448_item	2790992	et	4	main
selle	doc_670731433448_item	2790999	et	4	main
vead	doc_670731433448_item	2791003	et	4	main
vastab	doc_670731433448_item	2791005	et	3	main
korral	doc_670731433448_item	2791007	et	4	main
ka	doc_670731433448_item	2791008	et	3	main
1	doc_670731433448_item	2791023	et	2	main
soovitad	doc_670731433448_item	2791029	et	3	main
2	doc_670731433448_item	2791032	et	2	main
vabanduse	doc_670731433448_item	2791045	et	4	main
b	doc_670731433448_item	2791053	et	4	main
tasemele	doc_670731433448_item	2791054	et	3	main
tasakaalule	doc_670731433448_item	2791058	et	3	main
vaid	doc_670731433448_item	2791076	et	3	main
c	doc_670731433448_item	2791077	et	4	main
d	doc_670731433448_item	2791088	et	4	main
b	doc_670731433448_item	2791093	et	4	main
parandab	doc_670731433448_item	2791096	et	3	main
muudab	doc_670731433448_item	2791098	et	3	main
d	doc_670731433448_item	2791106	et	4	main
lihtne	doc_670731433448_item	2791107	et	3	main
b	doc_670731433448_item	2791111	et	4	main
c	doc_670731433448_item	2791113	et	4	main
d	doc_670731433448_item	2791115	et	4	main
sõnadega	doc_670731433449_item	2791122	et	3	main
eesti	doc_670731433449_item	2791139	et	4	main
eestis	doc_670731433449_item	2791140	et	3	main
aga	doc_670731433449_item	2791141	et	3	main
londonis	doc_670731433449_item	2791147	et	4	main
kolme	doc_670731433449_item	2791151	et	4	main
aastane	doc_670731433449_item	2791153	et	4	main
ja	doc_670731433449_item	2791154	et	3	main
toomas	doc_670731433449_item	2791155	et	3	main
on	doc_670731433449_item	2791156	et	4	main
32	doc_670731433449_item	2791157	et	2	main
kõik	doc_670731433449_item	2791201	et	4	main
londonis	doc_670731433448_item	2790736	et	4	main
30	doc_670731433448_item	2790739	et	2	main
on	doc_670731433448_item	2790744	et	4	main
32	doc_670731433448_item	2790745	et	2	main
üheksasada	doc_670731433448_item	2790753	et	4	main
ja	doc_670731433448_item	2790760	et	3	main
esinevad	doc_670731433448_item	2790761	et	4	main
erinevad	doc_670731433448_item	2790762	et	4	main
teatrid	doc_670731433448_item	2790763	et	3	main
erinevates	doc_670731433448_item	2790764	et	4	main
teatrides	doc_670731433448_item	2790765	et	4	main
inglismaal	doc_670731433448_item	2790766	et	4	main
armastama	doc_670731433448_item	2790767	et	3	main
armastavad	doc_670731433448_item	2790768	et	4	main
neid	doc_670731433448_item	2790769	et	4	main
väga	doc_670731433448_item	2790770	et	3	main
ning	doc_670731433448_item	2790771	et	3	main
isegi	doc_670731433448_item	2790772	et	4	main
karmid	doc_670731433448_item	2790773	et	4	main
kriitikud	doc_670731433448_item	2790774	et	3	main
suhtuma	doc_670731433448_item	2790775	et	3	main
räägivad	doc_670731433448_item	2790782	et	3	main
kõik	doc_670731433448_item	2790788	et	4	main
nii	doc_670731433448_item	2790792	et	3	main
etendus	doc_670731433448_item	2790812	et	4	main
aega	doc_670731433448_item	2790818	et	4	main
ja	doc_670731433448_item	2790824	et	3	main
ainult	doc_670731433448_item	2790830	et	4	main
teineteisega	doc_670731433448_item	2790831	et	3	main
paaris	doc_670731433448_item	2790832	et	4	main
kuigi	doc_670731433448_item	2790833	et	3	main
nemad	doc_670731433448_item	2790834	et	3	main
neid	doc_670731433448_item	2790835	et	4	main
tantsimiseks	doc_670731433448_item	2790841	et	4	main
tahavad	doc_670731433448_item	2790859	et	3	main
parem	doc_670731433448_item	2790863	et	4	main
märtsis	doc_670731433448_item	2790866	et	3	main
esinema	doc_670731433448_item	2790869	et	3	main
tallinnas	doc_670731433448_item	2790871	et	4	main
seejärel	doc_670731433448_item	2790873	et	3	main
kuigi	doc_670731433448_item	2790924	et	3	main
soovid	doc_670731433448_item	2790932	et	4	main
on	doc_670731433448_item	2790934	et	4	main
õppe	doc_670731433448_item	2790936	et	4	main
3	doc_670731433448_item	2790941	et	2	main
on	doc_670731433448_item	2790954	et	4	main
on	doc_670731433448_item	2790961	et	4	main
kontorist	doc_670731433448_item	2790972	et	4	main
raamatu	doc_670731433448_item	2790980	et	4	main
ja	doc_670731433448_item	2790981	et	3	main
6	doc_670731433448_item	2790983	et	2	main
üle	doc_670731433448_item	2791000	et	3	main
tekkinud	doc_670731433448_item	2791009	et	4	main
kõik	doc_670731433448_item	2791011	et	4	main
kupong	doc_670731433448_item	2791022	et	3	main
d	doc_670731433448_item	2791030	et	4	main
solvud	doc_670731433448_item	2791031	et	3	main
b	doc_670731433448_item	2791035	et	4	main
d	doc_670731433448_item	2791039	et	4	main
d	doc_670731433448_item	2791048	et	4	main
c	doc_670731433448_item	2791055	et	4	main
c	doc_670731433448_item	2791086	et	4	main
kirjutab	doc_670731433448_item	2791092	et	3	main
liikuv	doc_670731433448_item	2791105	et	4	main
10	doc_670731433448_item	2791108	et	2	main
käige	doc_670731433448_item	2791112	et	3	main
kirjutage	doc_670731433449_item	2791121	et	3	main
punkti	doc_670731433449_item	2791128	et	4	main
maailmakuulsad	doc_670731433449_item	2791129	et	3	main
abielupaar	doc_670731433449_item	2791131	et	4	main
toomas	doc_670731433449_item	2791135	et	3	main
london	doc_670731433449_item	2791145	et	4	main
kolmkümend	doc_670731433449_item	2791158	et	4	main
kaks	doc_670731433449_item	2791159	et	3	main
aastat	doc_670731433449_item	2791160	et	3	main
on	doc_670731433449_item	2791169	et	4	main
nad	doc_670731433449_item	2791170	et	3	main
ja	doc_670731433449_item	2791173	et	3	main
teatrid	doc_670731433449_item	2791176	et	3	main
teatrid	doc_670731433449_item	2791178	et	3	main
armastama	doc_670731433449_item	2791180	et	3	main
kriitikud	doc_670731433449_item	2791187	et	3	main
üldiselt	doc_670731433449_item	2791191	et	4	main
viimased	doc_670731433449_item	2791193	et	3	main
noored	doc_670731433449_item	2791196	et	3	main
alati	doc_670731433449_item	2791204	et	4	main
murdada	doc_670731433449_item	2791220	et	4	main
on	doc_670731433448_item	2790826	et	4	main
otsustanud	doc_670731433448_item	2790827	et	4	main
vaatamata	doc_670731433448_item	2790842	et	4	main
nende	doc_670731433448_item	2790849	et	4	main
lähiaja	doc_670731433448_item	2790850	et	3	main
age	doc_670731433448_item	2790856	et	4	main
areneda	doc_670731433448_item	2790860	et	3	main
paremini	doc_670731433448_item	2790864	et	4	main
tallinn	doc_670731433448_item	2790870	et	4	main
ja	doc_670731433448_item	2790872	et	3	main
sõidavad	doc_670731433448_item	2790874	et	3	main
tipus	doc_670731433448_item	2790883	et	3	main
suudavad	doc_670731433448_item	2790884	et	3	main
püsida	doc_670731433448_item	2790885	et	3	main
ei	doc_670731433448_item	2790886	et	4	main
oska	doc_670731433448_item	2790887	et	4	main
nad	doc_670731433448_item	2790888	et	3	main
ütlema	doc_670731433448_item	2790889	et	3	main
ütelda	doc_670731433448_item	2790890	et	4	main
nad	doc_670731433448_item	2790891	et	3	main
eelistavad	doc_670731433448_item	2790892	et	4	main
elada	doc_670731433448_item	2790893	et	3	main
üks	doc_670731433448_item	2790894	et	3	main
päev	doc_670731433448_item	2790895	et	3	main
ühe	doc_670731433448_item	2790896	et	4	main
päeva	doc_670731433448_item	2790897	et	4	main
kaupa	doc_670731433448_item	2790898	et	4	main
kirjutage	doc_670731433448_item	2790899	et	3	main
lünka	doc_670731433448_item	2790900	et	4	main
sobiv	doc_670731433448_item	2790901	et	4	main
sõna	doc_670731433448_item	2790902	et	4	main
teksti	doc_670731433448_item	2790903	et	4	main
alt	doc_670731433448_item	2790904	et	4	main
iga	doc_670731433448_item	2790905	et	4	main
õige	doc_670731433448_item	2790906	et	4	main
vastus	doc_670731433448_item	2790907	et	3	main
annab	doc_670731433448_item	2790908	et	3	main
ühe	doc_670731433448_item	2790909	et	4	main
punkti	doc_670731433448_item	2790910	et	4	main
õpi	doc_670731433448_item	2790911	et	4	main
millal	doc_670731433448_item	2790912	et	3	main
1	doc_670731433448_item	2790913	et	2	main
soovid	doc_670731433448_item	2790914	et	4	main
unusta	doc_670731433448_item	2790915	et	4	main
sul	doc_670731433448_item	2790920	et	3	main
seal	doc_670731433448_item	2790925	et	4	main
kus	doc_670731433448_item	2790926	et	3	main
millal	doc_670731433448_item	2790928	et	3	main
ajastu	doc_670731433448_item	2790937	et	4	main
vabaduse	doc_670731433448_item	2790942	et	4	main
hoida	doc_670731433448_item	2790960	et	3	main
vaja	doc_670731433448_item	2790962	et	4	main
tarkust	doc_670731433448_item	2790965	et	4	main
kui	doc_670731433448_item	2790966	et	3	main
oled	doc_670731433448_item	2790967	et	3	main
õppematerjalid	doc_670731433448_item	2790979	et	3	main
kodutöö	doc_670731433448_item	2790985	et	4	main
kursuse	doc_670731433448_item	2790986	et	3	main
ees	doc_670731433448_item	2790988	et	4	main
tasud	doc_670731433448_item	2790989	et	4	main
täidetud	doc_670731433448_item	2790993	et	4	main
kodutöö	doc_670731433448_item	2790994	et	4	main
8	doc_670731433448_item	2791001	et	2	main
ning	doc_670731433448_item	2791004	et	3	main
c	doc_670731433448_item	2791028	et	4	main
just	doc_670731433448_item	2791034	et	3	main
kuigi	doc_670731433448_item	2791038	et	3	main
3	doc_670731433448_item	2791041	et	2	main
vabaduse	doc_670731433448_item	2791049	et	4	main
4	doc_670731433448_item	2791050	et	2	main
tasakesi	doc_670731433448_item	2791056	et	3	main
5	doc_670731433448_item	2791059	et	2	main
kuid	doc_670731433448_item	2791078	et	4	main
ette	doc_670731433448_item	2791085	et	4	main
ees	doc_670731433448_item	2791089	et	4	main
palub	doc_670731433448_item	2791094	et	3	main
d	doc_670731433448_item	2791097	et	4	main
sulud	doc_670731433449_item	2791119	et	3	main
õige	doc_670731433449_item	2791124	et	4	main
ühe	doc_670731433449_item	2791127	et	4	main
elavad	doc_670731433449_item	2791142	et	4	main
praegu	doc_670731433449_item	2791143	et	3	main
30	doc_670731433449_item	2791150	et	2	main
vabakutseline	doc_670731433449_item	2791171	et	4	main
esinevad	doc_670731433449_item	2791174	et	4	main
erinevaid	doc_670731433449_item	2791177	et	4	main
inglismaal	doc_670731433449_item	2791179	et	4	main
armastavad	doc_670731433449_item	2791181	et	4	main
suhtuma	doc_670731433449_item	2791188	et	3	main
artiklid	doc_670731433449_item	2791194	et	3	main
noored	doc_670731433449_item	2791197	et	3	main
ülivõrdes	doc_670731433449_item	2791199	et	3	main
kuid	doc_670731433449_item	2791200	et	4	main
nii	doc_670731433449_item	2791205	et	3	main
ja	doc_670731433449_item	2791209	et	3	main
eriti	doc_670731433449_item	2791210	et	3	main
noor	doc_670731433449_item	2791221	et	3	main
pidama	doc_670731433449_item	2791229	et	4	main
peab	doc_670731433449_item	2791230	et	4	main
mõnda	doc_670731433449_item	2791231	et	4	main
age	doc_670731433449_item	2791237	et	4	main
ja	doc_670731433449_item	2791238	et	3	main
toomas	doc_670731433449_item	2791239	et	3	main
on	doc_670731433449_item	2791240	et	4	main
nemad	doc_670731433449_item	2791248	et	3	main
on	doc_670731433449_item	2791250	et	4	main
tehtud	doc_670731433449_item	2791251	et	4	main
suurele	doc_670731433449_item	2791257	et	4	main
lähiaja	doc_670731433449_item	2791264	et	3	main
on	doc_670731433449_item	2791266	et	4	main
täpselt	doc_670731433449_item	2791267	et	4	main
planeerima	doc_670731433449_item	2791268	et	3	main
paremad	doc_670731433449_item	2791278	et	4	main
lõuna-aafrikast	doc_670731433449_item	2791290	et	4	main
kui	doc_670731433449_item	2791291	et	3	main
ja	doc_670731433449_item	2791294	et	3	main
suudavad	doc_670731433449_item	2791298	et	3	main
püsida	doc_670731433449_item	2791299	et	3	main
päeva	doc_670731433449_item	2791311	et	4	main
sobiv	doc_670731433449_item	2791315	et	4	main
punkti	doc_670731433449_item	2791324	et	4	main
millal	doc_670731433449_item	2791326	et	3	main
unusta	doc_670731433449_item	2791329	et	4	main
umbne	doc_670731433449_item	2791330	et	3	main
klassiruum	doc_670731433449_item	2791331	et	3	main
koduõppesüsteem	doc_670731433449_item	2791332	et	3	main
2	doc_670731433448_item	2790923	et	2	main
ja	doc_670731433448_item	2790927	et	3	main
sa	doc_670731433448_item	2790929	et	3	main
käes	doc_670731433448_item	2790933	et	4	main
interaktiivse	doc_670731433448_item	2790935	et	3	main
sulle	doc_670731433448_item	2790940	et	3	main
planeerida	doc_670731433448_item	2790943	et	3	main
ning	doc_670731433448_item	2790945	et	3	main
omandada	doc_670731433448_item	2790947	et	3	main
teadmisi	doc_670731433448_item	2790948	et	4	main
vastavalt	doc_670731433448_item	2790949	et	4	main
individuaalsele	doc_670731433448_item	2790950	et	3	main
4	doc_670731433448_item	2790951	et	2	main
tasemele	doc_670731433448_item	2790952	et	3	main
aeg	doc_670731433448_item	2790953	et	3	main
registreerunud	doc_670731433448_item	2790969	et	4	main
saad	doc_670731433448_item	2790970	et	4	main
postiasutusest	doc_670731433448_item	2790975	et	4	main
igal	doc_670731433448_item	2790976	et	3	main
selle	doc_670731433448_item	2790990	et	4	main
kättesaamisel	doc_670731433448_item	2790991	et	4	main
tagasi	doc_670731433448_item	2790996	et	3	main
õpetaja	doc_670731433448_item	2790997	et	4	main
vaatab	doc_670731433448_item	2790998	et	3	main
lisaküsimustele	doc_670731433448_item	2791010	et	4	main
geniaalne	doc_670731433448_item	2791012	et	3	main
on	doc_670731433448_item	2791013	et	4	main
9	doc_670731433448_item	2791014	et	2	main
lihtne	doc_670731433448_item	2791015	et	3	main
10	doc_670731433448_item	2791016	et	2	main
külastage	doc_670731433448_item	2791017	et	3	main
meie	doc_670731433448_item	2791018	et	4	main
virtuaalkodu	doc_670731433448_item	2791019	et	4	main
või	doc_670731433448_item	2791020	et	4	main
sobid	doc_670731433448_item	2791025	et	4	main
b	doc_670731433448_item	2791026	et	4	main
soovid	doc_670731433448_item	2791027	et	4	main
a	doc_670731433448_item	2791033	et	4	main
seega	doc_670731433448_item	2791036	et	4	main
siiski	doc_670731433448_item	2791040	et	4	main
a	doc_670731433448_item	2791042	et	4	main
vajaduse	doc_670731433448_item	2791043	et	3	main
b	doc_670731433448_item	2791044	et	4	main
a	doc_670731433448_item	2791051	et	4	main
tasule	doc_670731433448_item	2791052	et	3	main
taga	doc_670731433448_item	2791083	et	4	main
b	doc_670731433448_item	2791084	et	4	main
8	doc_670731433448_item	2791090	et	2	main
a	doc_670731433448_item	2791091	et	4	main
9	doc_670731433448_item	2791099	et	2	main
c	doc_670731433448_item	2791104	et	4	main
tulge	doc_670731433448_item	2791110	et	3	main
harjutus	doc_670731433449_item	2791117	et	4	main
avage	doc_670731433449_item	2791118	et	3	main
postitage	doc_670731433448_item	2791021	et	3	main
a	doc_670731433448_item	2791024	et	4	main
c	doc_670731433448_item	2791037	et	4	main
c	doc_670731433448_item	2791046	et	4	main
varanduse	doc_670731433448_item	2791047	et	3	main
d	doc_670731433448_item	2791057	et	4	main
a	doc_670731433448_item	2791060	et	4	main
kokku	doc_670731433448_item	2791061	et	3	main
saada	doc_670731433448_item	2791062	et	4	main
b	doc_670731433448_item	2791063	et	4	main
liita	doc_670731433448_item	2791065	et	4	main
kokku	doc_670731433448_item	2791064	et	3	main
c	doc_670731433448_item	2791066	et	4	main
kokku	doc_670731433448_item	2791067	et	3	main
hoida	doc_670731433448_item	2791068	et	3	main
d	doc_670731433448_item	2791069	et	4	main
kokku	doc_670731433448_item	2791070	et	3	main
panna	doc_670731433448_item	2791071	et	4	main
6	doc_670731433448_item	2791072	et	2	main
a	doc_670731433448_item	2791073	et	4	main
ning	doc_670731433448_item	2791074	et	3	main
b	doc_670731433448_item	2791075	et	4	main
d	doc_670731433448_item	2791079	et	4	main
et	doc_670731433448_item	2791080	et	3	main
7	doc_670731433448_item	2791081	et	2	main
a	doc_670731433448_item	2791082	et	4	main
eest	doc_670731433448_item	2791087	et	4	main
c	doc_670731433448_item	2791095	et	4	main
a	doc_670731433448_item	2791100	et	4	main
liigne	doc_670731433448_item	2791101	et	3	main
b	doc_670731433448_item	2791102	et	4	main
libe	doc_670731433448_item	2791103	et	3	main
a	doc_670731433448_item	2791109	et	4	main
külastage	doc_670731433448_item	2791114	et	3	main
minge	doc_670731433448_item	2791116	et	3	main
numbrid	doc_670731433449_item	2791120	et	3	main
iga	doc_670731433449_item	2791123	et	4	main
annab	doc_670731433449_item	2791126	et	3	main
balletitantsijad	doc_670731433449_item	2791130	et	3	main
age	doc_670731433449_item	2791132	et	4	main
inglismaa	doc_670731433449_item	2791144	et	4	main
age	doc_670731433449_item	2791148	et	4	main
vana	doc_670731433449_item	2791161	et	4	main
alates	doc_670731433449_item	2791162	et	3	main
1997a	doc_670731433449_item	2791163	et	4	main
tuhande	doc_670731433449_item	2791164	et	3	main
üheksasaja	doc_670731433449_item	2791165	et	4	main
üheksakümene	doc_670731433449_item	2791166	et	4	main
seitsmendal	doc_670731433449_item	2791167	et	3	main
aastal	doc_670731433449_item	2791168	et	3	main
vabakutselised	doc_670731433449_item	2791172	et	4	main
erinevad	doc_670731433449_item	2791175	et	4	main
isegi	doc_670731433449_item	2791185	et	4	main
karmid	doc_670731433449_item	2791186	et	4	main
nendesse	doc_670731433449_item	2791190	et	4	main
hästi	doc_670731433449_item	2791192	et	3	main
räägivad	doc_670731433449_item	2791195	et	3	main
ainult	doc_670731433449_item	2791198	et	4	main
on	doc_670731433449_item	2791212	et	4	main
olema	doc_670731433449_item	2791235	et	4	main
paaris	doc_670731433449_item	2791246	et	4	main
kuigi	doc_670731433449_item	2791247	et	3	main
tantsimiseks	doc_670731433449_item	2791255	et	4	main
elavad	doc_670731433449_item	2791259	et	4	main
nende	doc_670731433449_item	2791263	et	4	main
esinemised	doc_670731433449_item	2791265	et	4	main
areneda	doc_670731433449_item	2791274	et	3	main
tipus	doc_670731433449_item	2791297	et	3	main
ühe	doc_670731433449_item	2791310	et	4	main
vastus	doc_670731433449_item	2791125	et	3	main
oks	doc_670731433449_item	2791133	et	3	main
ja	doc_670731433449_item	2791134	et	3	main
edur	doc_670731433449_item	2791136	et	4	main
on	doc_670731433449_item	2791137	et	4	main
pärit	doc_670731433449_item	2791138	et	3	main
inglismaal	doc_670731433449_item	2791146	et	4	main
on	doc_670731433449_item	2791149	et	4	main
kümne	doc_670731433449_item	2791152	et	4	main
neid	doc_670731433449_item	2791182	et	4	main
väga	doc_670731433449_item	2791183	et	3	main
ning	doc_670731433449_item	2791184	et	3	main
suhtuda	doc_670731433449_item	2791189	et	3	main
sugugi	doc_670731433449_item	2791203	et	4	main
läinud	doc_670731433449_item	2791207	et	4	main
luikede	doc_670731433449_item	2791223	et	3	main
etendus	doc_670731433449_item	2791225	et	4	main
aega	doc_670731433449_item	2791232	et	4	main
otsustanud	doc_670731433449_item	2791241	et	4	main
tantsima	doc_670731433449_item	2791242	et	3	main
pakkumisi	doc_670731433449_item	2791252	et	4	main
ka	doc_670731433449_item	2791253	et	3	main
eraldi	doc_670731433449_item	2791254	et	4	main
tantsijad	doc_670731433449_item	2791260	et	4	main
tahavad	doc_670731433449_item	2791273	et	3	main
veelgi	doc_670731433449_item	2791276	et	4	main
tantsida	doc_670731433449_item	2791279	et	3	main
oks	doc_670731433449_item	2791293	et	3	main
veel	doc_670731433449_item	2791296	et	4	main
kirjutage	doc_670731433449_item	2791313	et	3	main
vastavalt	doc_670731433449_item	2791363	et	4	main
raha	doc_670731433449_item	2791369	et	4	main
et	doc_670731433449_item	2791370	et	3	main
seda	doc_670731433449_item	2791371	et	3	main
kui	doc_670731433449_item	2791380	et	3	main
saad	doc_670731433449_item	2791384	et	4	main
kontorist	doc_670731433449_item	2791386	et	4	main
kätte	doc_670731433449_item	2791392	et	4	main
õppematerjalid	doc_670731433449_item	2791393	et	3	main
6	doc_670731433449_item	2791397	et	2	main
parandab	doc_670731433449_item	2791416	et	3	main
ning	doc_670731433449_item	2791418	et	3	main
korral	doc_670731433449_item	2791421	et	4	main
kupong	doc_670731433449_item	2791436	et	3	main
a	doc_670731433449_item	2791438	et	4	main
b	doc_670731433449_item	2791440	et	4	main
soovid	doc_670731433449_item	2791441	et	4	main
2	doc_670731433449_item	2791446	et	2	main
b	doc_670731433449_item	2791449	et	4	main
c	doc_670731433449_item	2791451	et	4	main
a	doc_670731433449_item	2791474	et	4	main
kokku	doc_670731433449_item	2791475	et	3	main
hoida	doc_670731433449_item	2791482	et	3	main
d	doc_670731433449_item	2791493	et	4	main
et	doc_670731433449_item	2791494	et	3	main
tulge	doc_670731433449_item	2791524	et	3	main
sõnadega	doc_670731433450_item	2791536	et	3	main
annab	doc_670731433450_item	2791540	et	3	main
punkti	doc_670731433450_item	2791542	et	4	main
edur	doc_670731433450_item	2791550	et	4	main
pärit	doc_670731433450_item	2791552	et	3	main
eestis	doc_670731433450_item	2791554	et	3	main
aga	doc_670731433450_item	2791555	et	3	main
londonis	doc_670731433450_item	2791561	et	4	main
inglismaal	doc_670731433450_item	2791589	et	4	main
armastama	doc_670731433450_item	2791590	et	3	main
nendesse	doc_670731433450_item	2791599	et	4	main
ainult	doc_670731433450_item	2791606	et	4	main
sugugi	doc_670731433450_item	2791611	et	4	main
pole	doc_670731433449_item	2791202	et	3	main
kergelt	doc_670731433449_item	2791206	et	4	main
mõlemal	doc_670731433449_item	2791208	et	3	main
agel	doc_670731433449_item	2791211	et	4	main
olnud	doc_670731433449_item	2791213	et	4	main
probleeme	doc_670731433449_item	2791214	et	3	main
tervis	doc_670731433449_item	2791215	et	3	main
tervisega	doc_670731433449_item	2791216	et	3	main
1990	doc_670731433449_item	2791217	et	2	main
aastal	doc_670731433449_item	2791218	et	3	main
murdma	doc_670731433449_item	2791219	et	3	main
etenduses	doc_670731433449_item	2791226	et	4	main
jalaluu	doc_670731433449_item	2791227	et	4	main
ja	doc_670731433449_item	2791228	et	3	main
tantsimisest	doc_670731433449_item	2791233	et	4	main
eemal	doc_670731433449_item	2791234	et	3	main
tantsida	doc_670731433449_item	2791243	et	3	main
ainult	doc_670731433449_item	2791244	et	4	main
teineteisega	doc_670731433449_item	2791245	et	3	main
edule	doc_670731433449_item	2791258	et	3	main
tagasihoidlikul	doc_670731433449_item	2791262	et	3	main
planeerivad	doc_670731433449_item	2791269	et	4	main
age	doc_670731433449_item	2791270	et	4	main
ja	doc_670731433449_item	2791271	et	3	main
toomas	doc_670731433449_item	2791272	et	3	main
ja	doc_670731433449_item	2791275	et	3	main
tulevad	doc_670731433449_item	2791281	et	4	main
tallinnas	doc_670731433449_item	2791285	et	4	main
ja	doc_670731433449_item	2791286	et	3	main
seejärel	doc_670731433449_item	2791287	et	3	main
sõidavad	doc_670731433449_item	2791288	et	3	main
lõuna-aafrika	doc_670731433449_item	2791289	et	4	main
oska	doc_670731433449_item	2791301	et	4	main
nad	doc_670731433449_item	2791302	et	3	main
ütlema	doc_670731433449_item	2791303	et	3	main
lünka	doc_670731433449_item	2791314	et	4	main
vastus	doc_670731433449_item	2791321	et	3	main
ühe	doc_670731433449_item	2791323	et	4	main
soovid	doc_670731433449_item	2791328	et	4	main
ja	doc_670731433449_item	2791341	et	3	main
sa	doc_670731433449_item	2791343	et	3	main
parasjagu	doc_670731433449_item	2791345	et	3	main
käes	doc_670731433449_item	2791347	et	4	main
3	doc_670731433449_item	2791355	et	2	main
4	doc_670731433449_item	2791365	et	2	main
aeg	doc_670731433449_item	2791367	et	3	main
pisut	doc_670731433449_item	2791378	et	3	main
oled	doc_670731433449_item	2791381	et	3	main
registreerunud	doc_670731433449_item	2791383	et	4	main
meie	doc_670731433449_item	2791385	et	4	main
ja	doc_670731433449_item	2791395	et	3	main
7	doc_670731433449_item	2791401	et	2	main
saada	doc_670731433449_item	2791406	et	4	main
täidetud	doc_670731433449_item	2791407	et	4	main
selle	doc_670731433449_item	2791413	et	4	main
vajaduse	doc_670731433449_item	2791420	et	3	main
on	doc_670731433449_item	2791427	et	4	main
9	doc_670731433449_item	2791428	et	2	main
lihtne	doc_670731433449_item	2791429	et	3	main
1	doc_670731433449_item	2791437	et	2	main
a	doc_670731433449_item	2791456	et	4	main
vajaduse	doc_670731433449_item	2791457	et	3	main
vabaduse	doc_670731433449_item	2791463	et	4	main
saada	doc_670731433449_item	2791476	et	4	main
b	doc_670731433449_item	2791477	et	4	main
kokku	doc_670731433449_item	2791478	et	3	main
liita	doc_670731433449_item	2791479	et	4	main
kokku	doc_670731433449_item	2791484	et	3	main
panna	doc_670731433449_item	2791485	et	4	main
b	doc_670731433449_item	2791489	et	4	main
vaid	doc_670731433449_item	2791490	et	3	main
b	doc_670731433449_item	2791525	et	4	main
d	doc_670731433449_item	2791529	et	4	main
iga	doc_670731433450_item	2791537	et	4	main
maailmakuulsad	doc_670731433450_item	2791543	et	3	main
toomas	doc_670731433450_item	2791549	et	3	main
london	doc_670731433450_item	2791559	et	4	main
inglismaal	doc_670731433450_item	2791560	et	4	main
kolme	doc_670731433450_item	2791565	et	4	main
teatris	doc_670731433450_item	2791588	et	3	main
neid	doc_670731433450_item	2791592	et	4	main
väga	doc_670731433450_item	2791593	et	3	main
naine	doc_670731433449_item	2791222	et	3	main
järve	doc_670731433449_item	2791224	et	4	main
olla	doc_670731433449_item	2791236	et	3	main
nad	doc_670731433449_item	2791249	et	3	main
vaatamata	doc_670731433449_item	2791256	et	4	main
tagasihoidlik	doc_670731433449_item	2791261	et	3	main
parem	doc_670731433449_item	2791277	et	4	main
märtsis	doc_670731433449_item	2791280	et	3	main
nad	doc_670731433449_item	2791282	et	3	main
esinema	doc_670731433449_item	2791283	et	3	main
tallinn	doc_670731433449_item	2791284	et	4	main
kaua	doc_670731433449_item	2791292	et	3	main
edur	doc_670731433449_item	2791295	et	4	main
ei	doc_670731433449_item	2791300	et	4	main
ütlevad	doc_670731433449_item	2791304	et	4	main
nad	doc_670731433449_item	2791305	et	3	main
eelistavad	doc_670731433449_item	2791306	et	4	main
elada	doc_670731433449_item	2791307	et	3	main
üks	doc_670731433449_item	2791308	et	3	main
päev	doc_670731433449_item	2791309	et	3	main
kaupa	doc_670731433449_item	2791312	et	4	main
sõna	doc_670731433449_item	2791316	et	4	main
teksti	doc_670731433449_item	2791317	et	4	main
alt	doc_670731433449_item	2791318	et	4	main
iga	doc_670731433449_item	2791319	et	4	main
õige	doc_670731433449_item	2791320	et	4	main
targemaks	doc_670731433449_item	2791336	et	4	main
2	doc_670731433449_item	2791337	et	2	main
seal	doc_670731433449_item	2791339	et	4	main
individuaalsele	doc_670731433449_item	2791364	et	3	main
ka	doc_670731433449_item	2791377	et	3	main
postiasutusest	doc_670731433449_item	2791389	et	4	main
igal	doc_670731433449_item	2791390	et	3	main
kuul	doc_670731433449_item	2791391	et	4	main
helikasseti	doc_670731433449_item	2791396	et	4	main
kodutöö	doc_670731433449_item	2791399	et	4	main
eest	doc_670731433449_item	2791402	et	4	main
tasud	doc_670731433449_item	2791403	et	4	main
selle	doc_670731433449_item	2791404	et	4	main
meile	doc_670731433449_item	2791409	et	4	main
tagasi	doc_670731433449_item	2791410	et	3	main
8	doc_670731433449_item	2791415	et	2	main
ka	doc_670731433449_item	2791422	et	3	main
lisaküsimustele	doc_670731433449_item	2791424	et	4	main
10	doc_670731433449_item	2791430	et	2	main
meie	doc_670731433449_item	2791432	et	4	main
postitage	doc_670731433449_item	2791435	et	3	main
soovitad	doc_670731433449_item	2791443	et	3	main
a	doc_670731433449_item	2791447	et	4	main
b	doc_670731433449_item	2791458	et	4	main
4	doc_670731433449_item	2791464	et	2	main
c	doc_670731433449_item	2791469	et	4	main
tasakesi	doc_670731433449_item	2791470	et	3	main
d	doc_670731433449_item	2791471	et	4	main
tasakaalule	doc_670731433449_item	2791472	et	3	main
5	doc_670731433449_item	2791473	et	2	main
c	doc_670731433449_item	2791480	et	4	main
kokku	doc_670731433449_item	2791481	et	3	main
kuid	doc_670731433449_item	2791492	et	4	main
lihtne	doc_670731433449_item	2791521	et	3	main
harjutus	doc_670731433450_item	2791531	et	4	main
avage	doc_670731433450_item	2791532	et	3	main
sulud	doc_670731433450_item	2791533	et	3	main
numbrid	doc_670731433450_item	2791534	et	3	main
inglismaa	doc_670731433450_item	2791558	et	4	main
on	doc_670731433450_item	2791563	et	4	main
30	doc_670731433450_item	2791564	et	2	main
karmid	doc_670731433450_item	2791596	et	4	main
kriitikud	doc_670731433450_item	2791597	et	3	main
suhtuma	doc_670731433450_item	2791598	et	3	main
artiklid	doc_670731433450_item	2791603	et	3	main
ülivõrdes	doc_670731433450_item	2791607	et	3	main
kõik	doc_670731433450_item	2791609	et	4	main
alati	doc_670731433450_item	2791612	et	4	main
nii	doc_670731433450_item	2791613	et	3	main
kergelt	doc_670731433450_item	2791614	et	4	main
läinud	doc_670731433450_item	2791615	et	4	main
mõlemal	doc_670731433450_item	2791616	et	3	main
annab	doc_670731433449_item	2791322	et	3	main
õpi	doc_670731433449_item	2791325	et	4	main
1	doc_670731433449_item	2791327	et	2	main
kuigi	doc_670731433449_item	2791338	et	3	main
kus	doc_670731433449_item	2791340	et	3	main
õppe	doc_670731433449_item	2791350	et	4	main
ajastu	doc_670731433449_item	2791351	et	4	main
mis	doc_670731433449_item	2791352	et	4	main
annab	doc_670731433449_item	2791353	et	3	main
sulle	doc_670731433449_item	2791354	et	3	main
vabaduse	doc_670731433449_item	2791356	et	4	main
planeerida	doc_670731433449_item	2791357	et	3	main
aega	doc_670731433449_item	2791358	et	4	main
ning	doc_670731433449_item	2791359	et	3	main
eelise	doc_670731433449_item	2791360	et	4	main
omandada	doc_670731433449_item	2791361	et	3	main
teadmisi	doc_670731433449_item	2791362	et	4	main
võimaldab	doc_670731433449_item	2791333	et	3	main
sul	doc_670731433449_item	2791334	et	3	main
saada	doc_670731433449_item	2791335	et	4	main
millal	doc_670731433449_item	2791342	et	3	main
seda	doc_670731433449_item	2791344	et	3	main
soovid	doc_670731433449_item	2791346	et	4	main
on	doc_670731433449_item	2791348	et	4	main
interaktiivse	doc_670731433449_item	2791349	et	3	main
tasemele	doc_670731433449_item	2791366	et	3	main
on	doc_670731433449_item	2791368	et	4	main
5	doc_670731433449_item	2791372	et	2	main
kokku	doc_670731433449_item	2791373	et	3	main
hoida	doc_670731433449_item	2791374	et	3	main
on	doc_670731433449_item	2791375	et	4	main
tarkust	doc_670731433449_item	2791379	et	4	main
kursusele	doc_670731433449_item	2791382	et	3	main
raamatu	doc_670731433449_item	2791394	et	4	main
kättesaamisel	doc_670731433449_item	2791405	et	4	main
õpetaja	doc_670731433449_item	2791411	et	4	main
vaatab	doc_670731433449_item	2791412	et	3	main
tekkinud	doc_670731433449_item	2791423	et	4	main
kõik	doc_670731433449_item	2791425	et	4	main
geniaalne	doc_670731433449_item	2791426	et	3	main
või	doc_670731433449_item	2791434	et	4	main
sobid	doc_670731433449_item	2791439	et	4	main
solvud	doc_670731433449_item	2791445	et	3	main
just	doc_670731433449_item	2791448	et	3	main
vabanduse	doc_670731433449_item	2791459	et	4	main
c	doc_670731433449_item	2791460	et	4	main
varanduse	doc_670731433449_item	2791461	et	3	main
a	doc_670731433449_item	2791465	et	4	main
tasemele	doc_670731433449_item	2791468	et	3	main
d	doc_670731433449_item	2791483	et	4	main
6	doc_670731433449_item	2791486	et	2	main
a	doc_670731433449_item	2791487	et	4	main
ning	doc_670731433449_item	2791488	et	3	main
vaja	doc_670731433449_item	2791376	et	4	main
või	doc_670731433449_item	2791387	et	4	main
lähimast	doc_670731433449_item	2791388	et	4	main
ning	doc_670731433449_item	2791398	et	3	main
kursuse	doc_670731433449_item	2791400	et	3	main
kodutöö	doc_670731433449_item	2791408	et	4	main
üle	doc_670731433449_item	2791414	et	3	main
vead	doc_670731433449_item	2791417	et	4	main
vastab	doc_670731433449_item	2791419	et	3	main
minge	doc_670731433449_item	2791431	et	3	main
virtuaalkodu	doc_670731433449_item	2791433	et	4	main
c	doc_670731433449_item	2791442	et	4	main
d	doc_670731433449_item	2791444	et	4	main
seega	doc_670731433449_item	2791450	et	4	main
kuigi	doc_670731433449_item	2791452	et	3	main
d	doc_670731433449_item	2791453	et	4	main
siiski	doc_670731433449_item	2791454	et	4	main
3	doc_670731433449_item	2791455	et	2	main
d	doc_670731433449_item	2791462	et	4	main
tasule	doc_670731433449_item	2791466	et	3	main
b	doc_670731433449_item	2791467	et	4	main
c	doc_670731433449_item	2791491	et	4	main
7	doc_670731433449_item	2791495	et	2	main
a	doc_670731433449_item	2791496	et	4	main
taga	doc_670731433449_item	2791497	et	4	main
b	doc_670731433449_item	2791498	et	4	main
ette	doc_670731433449_item	2791499	et	4	main
c	doc_670731433449_item	2791500	et	4	main
eest	doc_670731433449_item	2791501	et	4	main
d	doc_670731433449_item	2791502	et	4	main
ees	doc_670731433449_item	2791503	et	4	main
8	doc_670731433449_item	2791504	et	2	main
a	doc_670731433449_item	2791505	et	4	main
kirjutab	doc_670731433449_item	2791506	et	3	main
b	doc_670731433449_item	2791507	et	4	main
palub	doc_670731433449_item	2791508	et	3	main
c	doc_670731433449_item	2791509	et	4	main
parandab	doc_670731433449_item	2791510	et	3	main
d	doc_670731433449_item	2791511	et	4	main
muudab	doc_670731433449_item	2791512	et	3	main
9	doc_670731433449_item	2791513	et	2	main
a	doc_670731433449_item	2791514	et	4	main
liigne	doc_670731433449_item	2791515	et	3	main
b	doc_670731433449_item	2791516	et	4	main
libe	doc_670731433449_item	2791517	et	3	main
c	doc_670731433449_item	2791518	et	4	main
liikuv	doc_670731433449_item	2791519	et	4	main
d	doc_670731433449_item	2791520	et	4	main
a	doc_670731433449_item	2791523	et	4	main
käige	doc_670731433449_item	2791526	et	3	main
külastage	doc_670731433449_item	2791528	et	3	main
minge	doc_670731433449_item	2791530	et	3	main
kirjutage	doc_670731433450_item	2791535	et	3	main
balletitantsijad	doc_670731433450_item	2791544	et	3	main
age	doc_670731433450_item	2791546	et	4	main
ja	doc_670731433450_item	2791548	et	3	main
on	doc_670731433450_item	2791551	et	4	main
eesti	doc_670731433450_item	2791553	et	4	main
elavad	doc_670731433450_item	2791556	et	4	main
praegu	doc_670731433450_item	2791557	et	3	main
age	doc_670731433450_item	2791562	et	4	main
kümnane	doc_670731433450_item	2791566	et	4	main
viimased	doc_670731433450_item	2791602	et	3	main
noored	doc_670731433450_item	2791605	et	3	main
kuid	doc_670731433450_item	2791608	et	4	main
agel	doc_670731433450_item	2791619	et	4	main
10	doc_670731433449_item	2791522	et	2	main
c	doc_670731433449_item	2791527	et	4	main
õige	doc_670731433450_item	2791538	et	4	main
vastus	doc_670731433450_item	2791539	et	3	main
ühe	doc_670731433450_item	2791541	et	4	main
abielupaar	doc_670731433450_item	2791545	et	4	main
oks	doc_670731433450_item	2791547	et	3	main
aastane	doc_670731433450_item	2791567	et	4	main
ja	doc_670731433450_item	2791568	et	3	main
toomas	doc_670731433450_item	2791569	et	3	main
on	doc_670731433450_item	2791570	et	4	main
32	doc_670731433450_item	2791571	et	2	main
kolm	doc_670731433450_item	2791572	et	3	main
kümment	doc_670731433450_item	2791573	et	4	main
kaks	doc_670731433450_item	2791574	et	3	main
aastat	doc_670731433450_item	2791575	et	3	main
vana	doc_670731433450_item	2791576	et	4	main
alates	doc_670731433450_item	2791577	et	3	main
1997a	doc_670731433450_item	2791578	et	4	main
on	doc_670731433450_item	2791579	et	4	main
nad	doc_670731433450_item	2791580	et	3	main
vabakutseline	doc_670731433450_item	2791581	et	4	main
vabakutselinevad	doc_670731433450_item	2791582	et	4	main
ja	doc_670731433450_item	2791583	et	3	main
esinevad	doc_670731433450_item	2791584	et	4	main
erinevad	doc_670731433450_item	2791585	et	4	main
teatrid	doc_670731433450_item	2791586	et	3	main
erinevaid	doc_670731433450_item	2791587	et	4	main
armastada	doc_670731433450_item	2791591	et	3	main
üldiselt	doc_670731433450_item	2791600	et	4	main
räägivad	doc_670731433450_item	2791604	et	3	main
pole	doc_670731433450_item	2791610	et	3	main
on	doc_670731433450_item	2791620	et	4	main
1990	doc_670731433450_item	2791625	et	2	main
naine	doc_670731433450_item	2791629	et	3	main
pidu	doc_670731433450_item	2791636	et	4	main
mõnda	doc_670731433450_item	2791637	et	4	main
toomas	doc_670731433450_item	2791644	et	3	main
tantsimiseks	doc_670731433450_item	2791659	et	4	main
tagasihoidlik	doc_670731433450_item	2791665	et	3	main
parem	doc_670731433450_item	2791681	et	4	main
tulevad	doc_670731433450_item	2791685	et	4	main
esinema	doc_670731433450_item	2791687	et	3	main
tallinnas	doc_670731433450_item	2791689	et	4	main
ja	doc_670731433450_item	2791690	et	3	main
seejärel	doc_670731433450_item	2791691	et	3	main
lõuna-aafrikasse	doc_670731433450_item	2791694	et	4	main
oks	doc_670731433450_item	2791697	et	3	main
ütlevad	doc_670731433450_item	2791708	et	4	main
nad	doc_670731433450_item	2791709	et	3	main
päev	doc_670731433450_item	2791713	et	3	main
teksti	doc_670731433450_item	2791721	et	4	main
iga	doc_670731433450_item	2791723	et	4	main
õige	doc_670731433450_item	2791724	et	4	main
targemaks	doc_670731433450_item	2791740	et	4	main
2	doc_670731433450_item	2791741	et	2	main
just	doc_670731433450_item	2791742	et	3	main
seal	doc_670731433450_item	2791743	et	4	main
soovid	doc_670731433450_item	2791750	et	4	main
on	doc_670731433450_item	2791752	et	4	main
interaktiivse	doc_670731433450_item	2791753	et	3	main
õppe	doc_670731433450_item	2791754	et	4	main
aega	doc_670731433450_item	2791762	et	4	main
eelise	doc_670731433450_item	2791764	et	4	main
omandada	doc_670731433450_item	2791765	et	3	main
seda	doc_670731433450_item	2791775	et	3	main
kõik	doc_670731433450_item	2791829	et	4	main
geniaalne	doc_670731433450_item	2791830	et	3	main
on	doc_670731433450_item	2791831	et	4	main
9	doc_670731433450_item	2791832	et	2	main
lihtne	doc_670731433450_item	2791833	et	3	main
või	doc_670731433450_item	2791838	et	4	main
c	doc_670731433450_item	2791855	et	4	main
kuigi	doc_670731433450_item	2791856	et	3	main
vabanduse	doc_670731433450_item	2791863	et	4	main
d	doc_670731433450_item	2791866	et	4	main
4	doc_670731433450_item	2791868	et	2	main
a	doc_670731433450_item	2791869	et	4	main
tasule	doc_670731433450_item	2791870	et	3	main
kuid	doc_670731433450_item	2791896	et	4	main
7	doc_670731433450_item	2791899	et	2	main
a	doc_670731433450_item	2791900	et	4	main
eest	doc_670731433450_item	2791905	et	4	main
libe	doc_670731433450_item	2791921	et	3	main
külastage	doc_670731433450_item	2791932	et	3	main
kirjutage	doc_670731433451_item	2791939	et	3	main
iga	doc_670731433451_item	2791941	et	4	main
ühe	doc_670731433451_item	2791945	et	4	main
age	doc_670731433451_item	2791950	et	4	main
london	doc_670731433451_item	2791963	et	4	main
inglismaal	doc_670731433451_item	2791964	et	4	main
aastane	doc_670731433451_item	2791970	et	4	main
üheksasaja	doc_670731433451_item	2791982	et	4	main
teatrides	doc_670731433451_item	2791995	et	4	main
armastavad	doc_670731433451_item	2791998	et	4	main
karmid	doc_670731433451_item	2792003	et	4	main
suhtuma	doc_670731433451_item	2792005	et	3	main
üldiselt	doc_670731433451_item	2792008	et	4	main
hästi	doc_670731433451_item	2792009	et	3	main
artiklid	doc_670731433451_item	2792011	et	3	main
räägivad	doc_670731433451_item	2792012	et	3	main
ainult	doc_670731433451_item	2792015	et	4	main
alati	doc_670731433451_item	2792021	et	4	main
on	doc_670731433451_item	2792029	et	4	main
probleeme	doc_670731433451_item	2792031	et	3	main
murdma	doc_670731433451_item	2792036	et	3	main
pidama	doc_670731433451_item	2792047	et	4	main
olema	doc_670731433451_item	2792053	et	4	main
on	doc_670731433451_item	2792057	et	4	main
ning	doc_670731433450_item	2791594	et	3	main
isegi	doc_670731433450_item	2791595	et	4	main
hästi	doc_670731433450_item	2791601	et	3	main
probleeme	doc_670731433450_item	2791622	et	3	main
noor	doc_670731433450_item	2791628	et	3	main
järve	doc_670731433450_item	2791631	et	4	main
jalaluu	doc_670731433450_item	2791633	et	4	main
ja	doc_670731433450_item	2791634	et	3	main
pidama	doc_670731433450_item	2791635	et	4	main
otsustanud	doc_670731433450_item	2791646	et	4	main
tantsima	doc_670731433450_item	2791647	et	3	main
vaatamata	doc_670731433450_item	2791660	et	4	main
suurele	doc_670731433450_item	2791661	et	4	main
edule	doc_670731433450_item	2791662	et	3	main
nende	doc_670731433450_item	2791667	et	4	main
esinemised	doc_670731433450_item	2791669	et	4	main
täpselt	doc_670731433450_item	2791671	et	4	main
planeerima	doc_670731433450_item	2791672	et	3	main
planeerida	doc_670731433450_item	2791673	et	3	main
eelistavad	doc_670731433450_item	2791710	et	4	main
ja	doc_670731433450_item	2791617	et	3	main
eriti	doc_670731433450_item	2791618	et	3	main
aastal	doc_670731433450_item	2791626	et	3	main
etendus	doc_670731433450_item	2791632	et	4	main
aega	doc_670731433450_item	2791638	et	4	main
tantsimisest	doc_670731433450_item	2791639	et	4	main
eemal	doc_670731433450_item	2791640	et	3	main
olema	doc_670731433450_item	2791641	et	4	main
tansida	doc_670731433450_item	2791648	et	4	main
ainult	doc_670731433450_item	2791649	et	4	main
teineteisega	doc_670731433450_item	2791650	et	3	main
elavad	doc_670731433450_item	2791663	et	4	main
lähiaja	doc_670731433450_item	2791668	et	3	main
on	doc_670731433450_item	2791670	et	4	main
age	doc_670731433450_item	2791674	et	4	main
ja	doc_670731433450_item	2791675	et	3	main
toomas	doc_670731433450_item	2791676	et	3	main
tahavad	doc_670731433450_item	2791677	et	3	main
areneda	doc_670731433450_item	2791678	et	3	main
ja	doc_670731433450_item	2791679	et	3	main
tantsida	doc_670731433450_item	2791683	et	3	main
lõuna-aafrika	doc_670731433450_item	2791693	et	4	main
kui	doc_670731433450_item	2791695	et	3	main
ja	doc_670731433450_item	2791698	et	3	main
vastus	doc_670731433450_item	2791725	et	3	main
kus	doc_670731433450_item	2791744	et	3	main
käes	doc_670731433450_item	2791751	et	4	main
individuaalsele	doc_670731433450_item	2791768	et	3	main
tasule	doc_670731433450_item	2791770	et	3	main
aeg	doc_670731433450_item	2791771	et	3	main
on	doc_670731433450_item	2791772	et	4	main
kokku	doc_670731433450_item	2791777	et	3	main
on	doc_670731433450_item	2791779	et	4	main
vajaduse	doc_670731433450_item	2791824	et	3	main
korral	doc_670731433450_item	2791825	et	4	main
10	doc_670731433450_item	2791834	et	2	main
külastage	doc_670731433450_item	2791835	et	3	main
meie	doc_670731433450_item	2791836	et	4	main
1	doc_670731433450_item	2791841	et	2	main
a	doc_670731433450_item	2791842	et	4	main
b	doc_670731433450_item	2791844	et	4	main
soovid	doc_670731433450_item	2791845	et	4	main
d	doc_670731433450_item	2791848	et	4	main
d	doc_670731433450_item	2791897	et	4	main
et	doc_670731433450_item	2791898	et	3	main
c	doc_670731433450_item	2791904	et	4	main
kirjutab	doc_670731433450_item	2791910	et	3	main
palub	doc_670731433450_item	2791912	et	3	main
tervis	doc_670731433450_item	2791623	et	3	main
luikede	doc_670731433450_item	2791630	et	3	main
age	doc_670731433450_item	2791642	et	4	main
on	doc_670731433450_item	2791645	et	4	main
pakkumisi	doc_670731433450_item	2791656	et	4	main
ka	doc_670731433450_item	2791657	et	3	main
eraldi	doc_670731433450_item	2791658	et	4	main
tantsijad	doc_670731433450_item	2791664	et	4	main
parem	doc_670731433450_item	2791682	et	4	main
nad	doc_670731433450_item	2791686	et	3	main
tallinn	doc_670731433450_item	2791688	et	4	main
sõidavad	doc_670731433450_item	2791692	et	3	main
kaua	doc_670731433450_item	2791696	et	3	main
edur	doc_670731433450_item	2791699	et	4	main
veel	doc_670731433450_item	2791700	et	4	main
tipus	doc_670731433450_item	2791701	et	3	main
suudavad	doc_670731433450_item	2791702	et	3	main
püsida	doc_670731433450_item	2791703	et	3	main
ei	doc_670731433450_item	2791704	et	4	main
elada	doc_670731433450_item	2791711	et	3	main
päeva	doc_670731433450_item	2791715	et	4	main
kaupa	doc_670731433450_item	2791716	et	4	main
kirjutage	doc_670731433450_item	2791717	et	3	main
lünka	doc_670731433450_item	2791718	et	4	main
sobiv	doc_670731433450_item	2791719	et	4	main
sõna	doc_670731433450_item	2791720	et	4	main
alt	doc_670731433450_item	2791722	et	4	main
ühe	doc_670731433450_item	2791727	et	4	main
punkti	doc_670731433450_item	2791728	et	4	main
1	doc_670731433450_item	2791731	et	2	main
soovib	doc_670731433450_item	2791732	et	3	main
unusta	doc_670731433450_item	2791733	et	4	main
umbne	doc_670731433450_item	2791734	et	3	main
klassiruum	doc_670731433450_item	2791735	et	3	main
koduõppesüsteem	doc_670731433450_item	2791736	et	3	main
võimaldab	doc_670731433450_item	2791737	et	3	main
sul	doc_670731433450_item	2791738	et	3	main
saada	doc_670731433450_item	2791739	et	4	main
millal	doc_670731433450_item	2791746	et	3	main
seda	doc_670731433450_item	2791748	et	3	main
3	doc_670731433450_item	2791759	et	2	main
vabanduse	doc_670731433450_item	2791760	et	4	main
planeerida	doc_670731433450_item	2791761	et	3	main
raha	doc_670731433450_item	2791773	et	4	main
vead	doc_670731433450_item	2791821	et	4	main
vastab	doc_670731433450_item	2791823	et	3	main
ka	doc_670731433450_item	2791826	et	3	main
postitage	doc_670731433450_item	2791839	et	3	main
c	doc_670731433450_item	2791846	et	4	main
solvud	doc_670731433450_item	2791849	et	3	main
a	doc_670731433450_item	2791851	et	4	main
just	doc_670731433450_item	2791852	et	3	main
b	doc_670731433450_item	2791853	et	4	main
a	doc_670731433450_item	2791860	et	4	main
vajaduse	doc_670731433450_item	2791861	et	3	main
varanduse	doc_670731433450_item	2791865	et	3	main
vabaduse	doc_670731433450_item	2791867	et	4	main
b	doc_670731433450_item	2791902	et	4	main
ees	doc_670731433450_item	2791907	et	4	main
8	doc_670731433450_item	2791908	et	2	main
d	doc_670731433450_item	2791915	et	4	main
muudab	doc_670731433450_item	2791916	et	3	main
liikuv	doc_670731433450_item	2791923	et	4	main
d	doc_670731433450_item	2791924	et	4	main
käige	doc_670731433450_item	2791930	et	3	main
harjutus	doc_670731433451_item	2791935	et	4	main
sulud	doc_670731433451_item	2791937	et	3	main
sõnadega	doc_670731433451_item	2791940	et	3	main
õige	doc_670731433451_item	2791942	et	4	main
vastus	doc_670731433451_item	2791943	et	3	main
annab	doc_670731433451_item	2791944	et	3	main
age	doc_670731433451_item	2791966	et	4	main
1997a	doc_670731433451_item	2791980	et	4	main
tuhande	doc_670731433451_item	2791981	et	3	main
astast	doc_670731433451_item	2791985	et	4	main
ning	doc_670731433451_item	2792001	et	3	main
kergelt	doc_670731433451_item	2792023	et	4	main
olnud	doc_670731433450_item	2791621	et	4	main
tervist	doc_670731433450_item	2791624	et	4	main
murdma	doc_670731433450_item	2791627	et	3	main
ja	doc_670731433450_item	2791643	et	3	main
paaris	doc_670731433450_item	2791651	et	4	main
kuigi	doc_670731433450_item	2791652	et	3	main
nemad	doc_670731433450_item	2791653	et	3	main
on	doc_670731433450_item	2791654	et	4	main
tehtud	doc_670731433450_item	2791655	et	4	main
tagasihoidliku	doc_670731433450_item	2791666	et	3	main
veelgi	doc_670731433450_item	2791680	et	4	main
märtsis	doc_670731433450_item	2791684	et	3	main
oska	doc_670731433450_item	2791705	et	4	main
nad	doc_670731433450_item	2791706	et	3	main
ütlema	doc_670731433450_item	2791707	et	3	main
üks	doc_670731433450_item	2791712	et	3	main
üks	doc_670731433450_item	2791714	et	3	main
annab	doc_670731433450_item	2791726	et	3	main
õpi	doc_670731433450_item	2791729	et	4	main
millal	doc_670731433450_item	2791730	et	3	main
sa	doc_670731433450_item	2791747	et	3	main
ajastu	doc_670731433450_item	2791755	et	4	main
ning	doc_670731433450_item	2791763	et	3	main
teadmisi	doc_670731433450_item	2791766	et	4	main
vastavalt	doc_670731433450_item	2791767	et	4	main
4	doc_670731433450_item	2791769	et	2	main
5	doc_670731433450_item	2791776	et	2	main
panna	doc_670731433450_item	2791778	et	4	main
vaja	doc_670731433450_item	2791780	et	4	main
ka	doc_670731433450_item	2791781	et	3	main
pisut	doc_670731433450_item	2791782	et	3	main
parandab	doc_670731433450_item	2791820	et	3	main
ja	doc_670731433450_item	2791745	et	3	main
parasjagu	doc_670731433450_item	2791749	et	3	main
mis	doc_670731433450_item	2791756	et	4	main
annab	doc_670731433450_item	2791757	et	3	main
sulle	doc_670731433450_item	2791758	et	3	main
et	doc_670731433450_item	2791774	et	3	main
tarkust	doc_670731433450_item	2791783	et	4	main
kui	doc_670731433450_item	2791784	et	3	main
oled	doc_670731433450_item	2791785	et	3	main
kursusele	doc_670731433450_item	2791786	et	3	main
registreerunud	doc_670731433450_item	2791787	et	4	main
saad	doc_670731433450_item	2791788	et	4	main
meie	doc_670731433450_item	2791789	et	4	main
kontorist	doc_670731433450_item	2791790	et	4	main
või	doc_670731433450_item	2791791	et	4	main
lähimast	doc_670731433450_item	2791792	et	4	main
postiasutusest	doc_670731433450_item	2791793	et	4	main
igal	doc_670731433450_item	2791794	et	3	main
kuul	doc_670731433450_item	2791795	et	4	main
kätte	doc_670731433450_item	2791796	et	4	main
õppematerjalid	doc_670731433450_item	2791797	et	3	main
raamatu	doc_670731433450_item	2791798	et	4	main
ja	doc_670731433450_item	2791799	et	3	main
helikasseti	doc_670731433450_item	2791800	et	4	main
6	doc_670731433450_item	2791801	et	2	main
kuid	doc_670731433450_item	2791802	et	4	main
kodutöö	doc_670731433450_item	2791803	et	4	main
kursuse	doc_670731433450_item	2791804	et	3	main
7	doc_670731433450_item	2791805	et	2	main
ette	doc_670731433450_item	2791806	et	4	main
tasud	doc_670731433450_item	2791807	et	4	main
selle	doc_670731433450_item	2791808	et	4	main
kättesaamisel	doc_670731433450_item	2791809	et	4	main
saada	doc_670731433450_item	2791810	et	4	main
täidetud	doc_670731433450_item	2791811	et	4	main
kodutöö	doc_670731433450_item	2791812	et	4	main
meile	doc_670731433450_item	2791813	et	4	main
tagasi	doc_670731433450_item	2791814	et	3	main
õpetaja	doc_670731433450_item	2791815	et	4	main
vaatab	doc_670731433450_item	2791816	et	3	main
selle	doc_670731433450_item	2791817	et	4	main
üle	doc_670731433450_item	2791818	et	3	main
8	doc_670731433450_item	2791819	et	2	main
kupong	doc_670731433450_item	2791840	et	3	main
sobid	doc_670731433450_item	2791843	et	4	main
soovitad	doc_670731433450_item	2791847	et	3	main
2	doc_670731433450_item	2791850	et	2	main
d	doc_670731433450_item	2791857	et	4	main
siiski	doc_670731433450_item	2791858	et	4	main
3	doc_670731433450_item	2791859	et	2	main
c	doc_670731433450_item	2791864	et	4	main
b	doc_670731433450_item	2791871	et	4	main
tasemele	doc_670731433450_item	2791872	et	3	main
c	doc_670731433450_item	2791873	et	4	main
tasakesi	doc_670731433450_item	2791874	et	3	main
d	doc_670731433450_item	2791875	et	4	main
tasakaalule	doc_670731433450_item	2791876	et	3	main
5	doc_670731433450_item	2791877	et	2	main
a	doc_670731433450_item	2791878	et	4	main
kokku	doc_670731433450_item	2791879	et	3	main
saada	doc_670731433450_item	2791880	et	4	main
b	doc_670731433450_item	2791881	et	4	main
kokku	doc_670731433450_item	2791882	et	3	main
liita	doc_670731433450_item	2791883	et	4	main
c	doc_670731433450_item	2791884	et	4	main
kokku	doc_670731433450_item	2791885	et	3	main
hoida	doc_670731433450_item	2791886	et	3	main
d	doc_670731433450_item	2791887	et	4	main
kokku	doc_670731433450_item	2791888	et	3	main
panna	doc_670731433450_item	2791889	et	4	main
6	doc_670731433450_item	2791890	et	2	main
a	doc_670731433450_item	2791891	et	4	main
ning	doc_670731433450_item	2791892	et	3	main
b	doc_670731433450_item	2791893	et	4	main
vaid	doc_670731433450_item	2791894	et	3	main
c	doc_670731433450_item	2791895	et	4	main
ning	doc_670731433450_item	2791822	et	3	main
tekkinud	doc_670731433450_item	2791827	et	4	main
lisaküsimustele	doc_670731433450_item	2791828	et	4	main
virtuaalkodu	doc_670731433450_item	2791837	et	4	main
seega	doc_670731433450_item	2791854	et	4	main
b	doc_670731433450_item	2791862	et	4	main
ette	doc_670731433450_item	2791903	et	4	main
a	doc_670731433450_item	2791909	et	4	main
c	doc_670731433450_item	2791913	et	4	main
parandab	doc_670731433450_item	2791914	et	3	main
9	doc_670731433450_item	2791917	et	2	main
a	doc_670731433450_item	2791918	et	4	main
liigne	doc_670731433450_item	2791919	et	3	main
lihtne	doc_670731433450_item	2791925	et	3	main
punkti	doc_670731433451_item	2791946	et	4	main
maailmakuulsad	doc_670731433451_item	2791947	et	3	main
balletitantsijad	doc_670731433451_item	2791948	et	3	main
on	doc_670731433451_item	2791967	et	4	main
ja	doc_670731433451_item	2791971	et	3	main
on	doc_670731433451_item	2791973	et	4	main
kolmkümmend	doc_670731433451_item	2791975	et	4	main
kaks	doc_670731433451_item	2791976	et	3	main
aastat	doc_670731433451_item	2791977	et	3	main
vana	doc_670731433451_item	2791978	et	4	main
alates	doc_670731433451_item	2791979	et	3	main
üheksakümne	doc_670731433451_item	2791983	et	4	main
nad	doc_670731433451_item	2791987	et	3	main
esinevad	doc_670731433451_item	2791991	et	4	main
armastama	doc_670731433451_item	2791997	et	3	main
neid	doc_670731433451_item	2791999	et	4	main
väga	doc_670731433451_item	2792000	et	3	main
ülivõrdes	doc_670731433451_item	2792016	et	3	main
kõik	doc_670731433451_item	2792018	et	4	main
taga	doc_670731433450_item	2791901	et	4	main
d	doc_670731433450_item	2791906	et	4	main
b	doc_670731433450_item	2791911	et	4	main
b	doc_670731433450_item	2791920	et	4	main
10	doc_670731433450_item	2791926	et	2	main
tulge	doc_670731433450_item	2791928	et	3	main
c	doc_670731433450_item	2791931	et	4	main
d	doc_670731433450_item	2791933	et	4	main
numbrid	doc_670731433451_item	2791938	et	3	main
abielupaar	doc_670731433451_item	2791949	et	4	main
ja	doc_670731433451_item	2791952	et	3	main
edur	doc_670731433451_item	2791954	et	4	main
30	doc_670731433451_item	2791968	et	2	main
32	doc_670731433451_item	2791974	et	2	main
seitsmest	doc_670731433451_item	2791984	et	4	main
on	doc_670731433451_item	2791986	et	4	main
vabakutseline	doc_670731433451_item	2791988	et	4	main
vabakutselised	doc_670731433451_item	2791989	et	4	main
ja	doc_670731433451_item	2791990	et	3	main
inglismaal	doc_670731433451_item	2791996	et	4	main
viimased	doc_670731433451_item	2792010	et	3	main
noored	doc_670731433451_item	2792013	et	3	main
luikede	doc_670731433451_item	2792040	et	3	main
mõnda	doc_670731433451_item	2792048	et	4	main
aega	doc_670731433451_item	2792049	et	4	main
ja	doc_670731433451_item	2792055	et	3	main
tantsida	doc_670731433451_item	2792096	et	3	main
esinema	doc_670731433451_item	2792100	et	3	main
seejärel	doc_670731433451_item	2792104	et	3	main
lõuna-aafrika	doc_670731433451_item	2792106	et	4	main
kui	doc_670731433451_item	2792108	et	3	main
kaua	doc_670731433451_item	2792109	et	3	main
oks	doc_670731433451_item	2792110	et	3	main
tipus	doc_670731433451_item	2792114	et	3	main
suudavad	doc_670731433451_item	2792115	et	3	main
oska	doc_670731433451_item	2792118	et	4	main
ütlema	doc_670731433451_item	2792120	et	3	main
eelistavad	doc_670731433451_item	2792123	et	4	main
päev	doc_670731433451_item	2792128	et	3	main
kirjutage	doc_670731433451_item	2792130	et	3	main
sõna	doc_670731433451_item	2792133	et	4	main
õpi	doc_670731433451_item	2792142	et	4	main
1	doc_670731433451_item	2792144	et	2	main
soovid	doc_670731433451_item	2792145	et	4	main
unusta	doc_670731433451_item	2792146	et	4	main
umbne	doc_670731433451_item	2792147	et	3	main
klassiruum	doc_670731433451_item	2792148	et	3	main
koduõppesüsteem	doc_670731433451_item	2792149	et	3	main
võimaldab	doc_670731433451_item	2792150	et	3	main
sul	doc_670731433451_item	2792151	et	3	main
saada	doc_670731433451_item	2792152	et	4	main
seda	doc_670731433451_item	2792161	et	3	main
soovid	doc_670731433451_item	2792163	et	4	main
on	doc_670731433451_item	2792165	et	4	main
interaktiivse	doc_670731433451_item	2792166	et	3	main
õppe	doc_670731433451_item	2792167	et	4	main
teadmisi	doc_670731433451_item	2792179	et	4	main
vaja	doc_670731433451_item	2792193	et	4	main
ka	doc_670731433451_item	2792194	et	3	main
pisut	doc_670731433451_item	2792195	et	3	main
selle	doc_670731433451_item	2792221	et	4	main
tagasi	doc_670731433451_item	2792227	et	3	main
ning	doc_670731433451_item	2792235	et	3	main
vajaduse	doc_670731433451_item	2792237	et	3	main
ka	doc_670731433451_item	2792239	et	3	main
lihtne	doc_670731433451_item	2792246	et	3	main
virtuaalkodu	doc_670731433451_item	2792250	et	4	main
1	doc_670731433451_item	2792254	et	2	main
a	doc_670731433451_item	2792255	et	4	main
soovitad	doc_670731433451_item	2792260	et	3	main
d	doc_670731433451_item	2792261	et	4	main
solvud	doc_670731433451_item	2792262	et	3	main
2	doc_670731433451_item	2792263	et	2	main
siiski	doc_670731433451_item	2792271	et	4	main
a	doc_670731433451_item	2792273	et	4	main
vajaduse	doc_670731433451_item	2792274	et	3	main
d	doc_670731433451_item	2792279	et	4	main
vabaduse	doc_670731433451_item	2792280	et	4	main
4	doc_670731433451_item	2792281	et	2	main
ette	doc_670731433451_item	2792316	et	4	main
parandab	doc_670731433451_item	2792327	et	3	main
d	doc_670731433451_item	2792328	et	4	main
c	doc_670731433450_item	2791922	et	4	main
a	doc_670731433450_item	2791927	et	4	main
b	doc_670731433450_item	2791929	et	4	main
minge	doc_670731433450_item	2791934	et	3	main
avage	doc_670731433451_item	2791936	et	3	main
oks	doc_670731433451_item	2791951	et	3	main
toomas	doc_670731433451_item	2791953	et	3	main
on	doc_670731433451_item	2791955	et	4	main
pärit	doc_670731433451_item	2791956	et	3	main
eesti	doc_670731433451_item	2791957	et	4	main
eestis	doc_670731433451_item	2791958	et	3	main
aga	doc_670731433451_item	2791959	et	3	main
elavad	doc_670731433451_item	2791960	et	4	main
praegu	doc_670731433451_item	2791961	et	3	main
inglismaa	doc_670731433451_item	2791962	et	4	main
londonis	doc_670731433451_item	2791965	et	4	main
kolmekümne	doc_670731433451_item	2791969	et	4	main
toomas	doc_670731433451_item	2791972	et	3	main
erinevad	doc_670731433451_item	2791992	et	4	main
teatrid	doc_670731433451_item	2791993	et	3	main
erinevades	doc_670731433451_item	2791994	et	4	main
isegi	doc_670731433451_item	2792002	et	4	main
kriitikud	doc_670731433451_item	2792004	et	3	main
suhtumad	doc_670731433451_item	2792006	et	4	main
nendesse	doc_670731433451_item	2792007	et	4	main
noortega	doc_670731433451_item	2792014	et	3	main
kuid	doc_670731433451_item	2792017	et	4	main
pole	doc_670731433451_item	2792019	et	3	main
sugugi	doc_670731433451_item	2792020	et	4	main
nii	doc_670731433451_item	2792022	et	3	main
läinud	doc_670731433451_item	2792024	et	4	main
eriti	doc_670731433451_item	2792027	et	3	main
agel	doc_670731433451_item	2792028	et	4	main
tervis	doc_670731433451_item	2792032	et	3	main
1990	doc_670731433451_item	2792034	et	2	main
murdnud	doc_670731433451_item	2792037	et	4	main
noor	doc_670731433451_item	2792038	et	3	main
naine	doc_670731433451_item	2792039	et	3	main
etendus	doc_670731433451_item	2792042	et	4	main
jalaluu	doc_670731433451_item	2792044	et	4	main
ja	doc_670731433451_item	2792045	et	3	main
pidama	doc_670731433451_item	2792046	et	4	main
toomas	doc_670731433451_item	2792056	et	3	main
tantsima	doc_670731433451_item	2792059	et	3	main
pakkumisi	doc_670731433451_item	2792069	et	4	main
tallinn	doc_670731433451_item	2792101	et	4	main
ja	doc_670731433451_item	2792103	et	3	main
sõidavad	doc_670731433451_item	2792105	et	3	main
lõuna-aafrikas	doc_670731433451_item	2792107	et	4	main
elada	doc_670731433451_item	2792124	et	3	main
üks	doc_670731433451_item	2792127	et	3	main
lünka	doc_670731433451_item	2792131	et	4	main
sobiv	doc_670731433451_item	2792132	et	4	main
sa	doc_670731433451_item	2792160	et	3	main
käes	doc_670731433451_item	2792164	et	4	main
3	doc_670731433451_item	2792172	et	2	main
vabaduse	doc_670731433451_item	2792173	et	4	main
planeerida	doc_670731433451_item	2792174	et	3	main
aega	doc_670731433451_item	2792175	et	4	main
ning	doc_670731433451_item	2792176	et	3	main
eelise	doc_670731433451_item	2792177	et	4	main
4	doc_670731433451_item	2792182	et	2	main
on	doc_670731433451_item	2792185	et	4	main
et	doc_670731433451_item	2792187	et	3	main
panna	doc_670731433451_item	2792191	et	4	main
on	doc_670731433451_item	2792192	et	4	main
kodutöö	doc_670731433451_item	2792225	et	4	main
meile	doc_670731433451_item	2792226	et	4	main
selle	doc_670731433451_item	2792230	et	4	main
vead	doc_670731433451_item	2792234	et	4	main
geniaalne	doc_670731433451_item	2792243	et	3	main
on	doc_670731433451_item	2792244	et	4	main
9	doc_670731433451_item	2792245	et	2	main
b	doc_670731433451_item	2792257	et	4	main
just	doc_670731433451_item	2792265	et	3	main
3	doc_670731433451_item	2792272	et	2	main
c	doc_670731433451_item	2792317	et	4	main
eest	doc_670731433451_item	2792318	et	4	main
8	doc_670731433451_item	2792321	et	2	main
palub	doc_670731433451_item	2792325	et	3	main
liigne	doc_670731433451_item	2792332	et	3	main
b	doc_670731433451_item	2792342	et	4	main
käige	doc_670731433451_item	2792343	et	3	main
punkti	doc_670731433452_item	2792359	et	4	main
maailmakuulsad	doc_670731433452_item	2792360	et	3	main
balletitantsijad	doc_670731433452_item	2792361	et	3	main
inglismaal	doc_670731433452_item	2792377	et	4	main
on	doc_670731433452_item	2792386	et	4	main
seitsmendalt	doc_670731433452_item	2792399	et	3	main
järve	doc_670731433451_item	2792041	et	4	main
age	doc_670731433451_item	2792054	et	4	main
otsustanud	doc_670731433451_item	2792058	et	4	main
tansida	doc_670731433451_item	2792060	et	4	main
ainult	doc_670731433451_item	2792061	et	4	main
teineteisega	doc_670731433451_item	2792062	et	3	main
paaris	doc_670731433451_item	2792063	et	4	main
kuigi	doc_670731433451_item	2792064	et	3	main
nemad	doc_670731433451_item	2792065	et	3	main
ka	doc_670731433451_item	2792070	et	3	main
eraldi	doc_670731433451_item	2792071	et	4	main
tantsimiseks	doc_670731433451_item	2792072	et	4	main
vaatamata	doc_670731433451_item	2792073	et	4	main
suurele	doc_670731433451_item	2792074	et	4	main
edule	doc_670731433451_item	2792075	et	3	main
elavad	doc_670731433451_item	2792076	et	4	main
tantsijad	doc_670731433451_item	2792077	et	4	main
tagasihoidlik	doc_670731433451_item	2792078	et	3	main
tagasihoidlikus	doc_670731433451_item	2792079	et	4	main
nende	doc_670731433451_item	2792080	et	4	main
lähiaja	doc_670731433451_item	2792081	et	3	main
esinemised	doc_670731433451_item	2792082	et	4	main
on	doc_670731433451_item	2792083	et	4	main
täpselt	doc_670731433451_item	2792084	et	4	main
planeerima	doc_670731433451_item	2792085	et	3	main
planeeritud	doc_670731433451_item	2792086	et	4	main
age	doc_670731433451_item	2792087	et	4	main
ja	doc_670731433451_item	2792088	et	3	main
toomas	doc_670731433451_item	2792089	et	3	main
tahavad	doc_670731433451_item	2792090	et	3	main
mõlemal	doc_670731433451_item	2792025	et	3	main
ja	doc_670731433451_item	2792026	et	3	main
olnud	doc_670731433451_item	2792030	et	4	main
tervisega	doc_670731433451_item	2792033	et	3	main
aastal	doc_670731433451_item	2792035	et	3	main
etenduses	doc_670731433451_item	2792043	et	4	main
tantsimisest	doc_670731433451_item	2792050	et	4	main
eemal	doc_670731433451_item	2792051	et	3	main
olema	doc_670731433451_item	2792052	et	4	main
neid	doc_670731433451_item	2792066	et	4	main
on	doc_670731433451_item	2792067	et	4	main
tehtud	doc_670731433451_item	2792068	et	4	main
veelgi	doc_670731433451_item	2792093	et	4	main
parem	doc_670731433451_item	2792095	et	4	main
nad	doc_670731433451_item	2792099	et	3	main
edur	doc_670731433451_item	2792112	et	4	main
üks	doc_670731433451_item	2792125	et	3	main
alt	doc_670731433451_item	2792135	et	4	main
iga	doc_670731433451_item	2792136	et	4	main
õige	doc_670731433451_item	2792137	et	4	main
vastus	doc_670731433451_item	2792138	et	3	main
annab	doc_670731433451_item	2792139	et	3	main
ühe	doc_670731433451_item	2792140	et	4	main
millal	doc_670731433451_item	2792159	et	3	main
individuaalsele	doc_670731433451_item	2792181	et	3	main
vaatab	doc_670731433451_item	2792229	et	3	main
kõik	doc_670731433451_item	2792242	et	4	main
soovid	doc_670731433451_item	2792258	et	4	main
b	doc_670731433451_item	2792266	et	4	main
c	doc_670731433451_item	2792268	et	4	main
kirjutab	doc_670731433451_item	2792323	et	3	main
a	doc_670731433451_item	2792331	et	4	main
harjutus	doc_670731433452_item	2792348	et	4	main
avage	doc_670731433452_item	2792349	et	3	main
numbrid	doc_670731433452_item	2792351	et	3	main
abielupaar	doc_670731433452_item	2792362	et	4	main
age	doc_670731433452_item	2792363	et	4	main
toomas	doc_670731433452_item	2792366	et	3	main
on	doc_670731433452_item	2792368	et	4	main
london	doc_670731433452_item	2792376	et	4	main
londonis	doc_670731433452_item	2792378	et	4	main
age	doc_670731433452_item	2792379	et	4	main
toomas	doc_670731433452_item	2792385	et	3	main
32	doc_670731433452_item	2792387	et	2	main
vana	doc_670731433452_item	2792391	et	4	main
1997a	doc_670731433452_item	2792393	et	4	main
üks	doc_670731433452_item	2792394	et	3	main
tühat	doc_670731433452_item	2792395	et	4	main
üldiselt	doc_670731433452_item	2792422	et	4	main
nii	doc_670731433452_item	2792436	et	3	main
kergelt	doc_670731433452_item	2792437	et	4	main
probleeme	doc_670731433452_item	2792445	et	3	main
tervis	doc_670731433452_item	2792446	et	3	main
tervist	doc_670731433452_item	2792447	et	4	main
1990	doc_670731433452_item	2792448	et	2	main
mõnda	doc_670731433452_item	2792462	et	4	main
pakkumisi	doc_670731433452_item	2792483	et	4	main
ka	doc_670731433452_item	2792484	et	3	main
eraldi	doc_670731433452_item	2792485	et	4	main
vaatamata	doc_670731433452_item	2792487	et	4	main
elavad	doc_670731433452_item	2792490	et	4	main
on	doc_670731433452_item	2792497	et	4	main
areneda	doc_670731433452_item	2792505	et	3	main
lõuna-aafrikasse	doc_670731433452_item	2792521	et	4	main
kaua	doc_670731433452_item	2792523	et	3	main
sõna	doc_670731433452_item	2792547	et	4	main
ajastu	doc_670731433452_item	2792582	et	4	main
mis	doc_670731433452_item	2792583	et	4	main
annab	doc_670731433452_item	2792584	et	3	main
sulle	doc_670731433452_item	2792585	et	3	main
3	doc_670731433452_item	2792586	et	2	main
vastavalt	doc_670731433452_item	2792594	et	4	main
meie	doc_670731433452_item	2792616	et	4	main
kätte	doc_670731433452_item	2792623	et	4	main
kursuse	doc_670731433452_item	2792631	et	3	main
ees	doc_670731433452_item	2792633	et	4	main
kättesaamisel	doc_670731433452_item	2792636	et	4	main
vead	doc_670731433452_item	2792648	et	4	main
korral	doc_670731433452_item	2792652	et	4	main
tekkinud	doc_670731433452_item	2792654	et	4	main
a	doc_670731433452_item	2792669	et	4	main
sobid	doc_670731433452_item	2792670	et	4	main
areneda	doc_670731433451_item	2792091	et	3	main
märtsis	doc_670731433451_item	2792097	et	3	main
ja	doc_670731433451_item	2792111	et	3	main
veel	doc_670731433451_item	2792113	et	4	main
püsida	doc_670731433451_item	2792116	et	3	main
ütelda	doc_670731433451_item	2792121	et	4	main
teksti	doc_670731433451_item	2792134	et	4	main
punkti	doc_670731433451_item	2792141	et	4	main
millal	doc_670731433451_item	2792143	et	3	main
seal	doc_670731433451_item	2792156	et	4	main
kus	doc_670731433451_item	2792157	et	3	main
ja	doc_670731433451_item	2792158	et	3	main
ajastu	doc_670731433451_item	2792168	et	4	main
mis	doc_670731433451_item	2792169	et	4	main
annab	doc_670731433451_item	2792170	et	3	main
sulle	doc_670731433451_item	2792171	et	3	main
vastavalt	doc_670731433451_item	2792180	et	4	main
tasemele	doc_670731433451_item	2792183	et	3	main
raha	doc_670731433451_item	2792186	et	4	main
5	doc_670731433451_item	2792189	et	2	main
kokku	doc_670731433451_item	2792190	et	3	main
ja	doc_670731433451_item	2792092	et	3	main
parem	doc_670731433451_item	2792094	et	4	main
tulevad	doc_670731433451_item	2792098	et	4	main
tallinnas	doc_670731433451_item	2792102	et	4	main
ei	doc_670731433451_item	2792117	et	4	main
nad	doc_670731433451_item	2792119	et	3	main
nad	doc_670731433451_item	2792122	et	3	main
päev	doc_670731433451_item	2792126	et	3	main
kaupa	doc_670731433451_item	2792129	et	4	main
targemaks	doc_670731433451_item	2792153	et	4	main
2	doc_670731433451_item	2792154	et	2	main
just	doc_670731433451_item	2792155	et	3	main
parasjagu	doc_670731433451_item	2792162	et	3	main
omandada	doc_670731433451_item	2792178	et	3	main
aeg	doc_670731433451_item	2792184	et	3	main
seda	doc_670731433451_item	2792188	et	3	main
tarkust	doc_670731433451_item	2792196	et	4	main
kui	doc_670731433451_item	2792197	et	3	main
oled	doc_670731433451_item	2792198	et	3	main
kursusele	doc_670731433451_item	2792199	et	3	main
registreerunud	doc_670731433451_item	2792200	et	4	main
saad	doc_670731433451_item	2792201	et	4	main
meie	doc_670731433451_item	2792202	et	4	main
kontorist	doc_670731433451_item	2792203	et	4	main
või	doc_670731433451_item	2792204	et	4	main
lähimast	doc_670731433451_item	2792205	et	4	main
postiasutusest	doc_670731433451_item	2792206	et	4	main
igal	doc_670731433451_item	2792207	et	3	main
kuul	doc_670731433451_item	2792208	et	4	main
kätte	doc_670731433451_item	2792209	et	4	main
õppematerjalid	doc_670731433451_item	2792210	et	3	main
raamatu	doc_670731433451_item	2792211	et	4	main
ja	doc_670731433451_item	2792212	et	3	main
helikasseti	doc_670731433451_item	2792213	et	4	main
6	doc_670731433451_item	2792214	et	2	main
vaid	doc_670731433451_item	2792215	et	3	main
kodutöö	doc_670731433451_item	2792216	et	4	main
kursuse	doc_670731433451_item	2792217	et	3	main
7	doc_670731433451_item	2792218	et	2	main
eest	doc_670731433451_item	2792219	et	4	main
tasud	doc_670731433451_item	2792220	et	4	main
kättesaamisel	doc_670731433451_item	2792222	et	4	main
saada	doc_670731433451_item	2792223	et	4	main
täidetud	doc_670731433451_item	2792224	et	4	main
õpetaja	doc_670731433451_item	2792228	et	4	main
8	doc_670731433451_item	2792232	et	2	main
korral	doc_670731433451_item	2792238	et	4	main
10	doc_670731433451_item	2792247	et	2	main
meie	doc_670731433451_item	2792249	et	4	main
või	doc_670731433451_item	2792251	et	4	main
postitage	doc_670731433451_item	2792252	et	3	main
kupong	doc_670731433451_item	2792253	et	3	main
c	doc_670731433451_item	2792259	et	4	main
seega	doc_670731433451_item	2792267	et	4	main
kuigi	doc_670731433451_item	2792269	et	3	main
d	doc_670731433451_item	2792270	et	4	main
vabanduse	doc_670731433451_item	2792276	et	4	main
d	doc_670731433451_item	2792319	et	4	main
a	doc_670731433451_item	2792322	et	4	main
c	doc_670731433451_item	2792326	et	4	main
9	doc_670731433451_item	2792330	et	2	main
libe	doc_670731433451_item	2792334	et	3	main
liikuv	doc_670731433451_item	2792336	et	4	main
d	doc_670731433451_item	2792337	et	4	main
üle	doc_670731433451_item	2792231	et	3	main
kirjutab	doc_670731433451_item	2792233	et	3	main
vastab	doc_670731433451_item	2792236	et	3	main
tekkinud	doc_670731433451_item	2792240	et	4	main
lisaküsimustele	doc_670731433451_item	2792241	et	4	main
tulge	doc_670731433451_item	2792248	et	3	main
sobid	doc_670731433451_item	2792256	et	4	main
a	doc_670731433451_item	2792264	et	4	main
b	doc_670731433451_item	2792275	et	4	main
c	doc_670731433451_item	2792277	et	4	main
varanduse	doc_670731433451_item	2792278	et	3	main
a	doc_670731433451_item	2792282	et	4	main
tasule	doc_670731433451_item	2792283	et	3	main
b	doc_670731433451_item	2792284	et	4	main
tasemele	doc_670731433451_item	2792285	et	3	main
c	doc_670731433451_item	2792286	et	4	main
tasakesi	doc_670731433451_item	2792287	et	3	main
d	doc_670731433451_item	2792288	et	4	main
tasakaalule	doc_670731433451_item	2792289	et	3	main
5	doc_670731433451_item	2792290	et	2	main
a	doc_670731433451_item	2792291	et	4	main
kokku	doc_670731433451_item	2792292	et	3	main
saada	doc_670731433451_item	2792293	et	4	main
b	doc_670731433451_item	2792294	et	4	main
kokku	doc_670731433451_item	2792295	et	3	main
liita	doc_670731433451_item	2792296	et	4	main
c	doc_670731433451_item	2792297	et	4	main
kokku	doc_670731433451_item	2792298	et	3	main
hoida	doc_670731433451_item	2792299	et	3	main
d	doc_670731433451_item	2792300	et	4	main
kokku	doc_670731433451_item	2792301	et	3	main
panna	doc_670731433451_item	2792302	et	4	main
6	doc_670731433451_item	2792303	et	2	main
a	doc_670731433451_item	2792304	et	4	main
ning	doc_670731433451_item	2792305	et	3	main
vaid	doc_670731433451_item	2792307	et	3	main
c	doc_670731433451_item	2792308	et	4	main
kuid	doc_670731433451_item	2792309	et	4	main
b	doc_670731433451_item	2792306	et	4	main
d	doc_670731433451_item	2792310	et	4	main
et	doc_670731433451_item	2792311	et	3	main
7	doc_670731433451_item	2792312	et	2	main
a	doc_670731433451_item	2792313	et	4	main
taga	doc_670731433451_item	2792314	et	4	main
b	doc_670731433451_item	2792315	et	4	main
ees	doc_670731433451_item	2792320	et	4	main
b	doc_670731433451_item	2792324	et	4	main
a	doc_670731433451_item	2792340	et	4	main
tulge	doc_670731433451_item	2792341	et	3	main
minge	doc_670731433451_item	2792347	et	3	main
sulud	doc_670731433452_item	2792350	et	3	main
kirjutage	doc_670731433452_item	2792352	et	3	main
iga	doc_670731433452_item	2792354	et	4	main
oks	doc_670731433452_item	2792364	et	3	main
on	doc_670731433452_item	2792380	et	4	main
30	doc_670731433452_item	2792381	et	2	main
üheksa	doc_670731433452_item	2792396	et	4	main
üheksakümne	doc_670731433452_item	2792398	et	4	main
nad	doc_670731433452_item	2792401	et	3	main
vabakutseline	doc_670731433452_item	2792402	et	4	main
vabakutselised	doc_670731433452_item	2792403	et	4	main
ja	doc_670731433452_item	2792404	et	3	main
esinevad	doc_670731433452_item	2792405	et	4	main
erinevad	doc_670731433452_item	2792406	et	4	main
teatrid	doc_670731433452_item	2792407	et	3	main
erinevaid	doc_670731433452_item	2792408	et	4	main
teatrid	doc_670731433452_item	2792409	et	3	main
inglismaal	doc_670731433452_item	2792410	et	4	main
armastama	doc_670731433452_item	2792411	et	3	main
armastavad	doc_670731433452_item	2792412	et	4	main
neid	doc_670731433452_item	2792413	et	4	main
väga	doc_670731433452_item	2792414	et	3	main
ning	doc_670731433452_item	2792415	et	3	main
isegi	doc_670731433452_item	2792416	et	4	main
karmid	doc_670731433452_item	2792417	et	4	main
kriitikud	doc_670731433452_item	2792418	et	3	main
suhtuma	doc_670731433452_item	2792419	et	3	main
suhtuvad	doc_670731433452_item	2792420	et	4	main
viimased	doc_670731433452_item	2792424	et	3	main
kuid	doc_670731433452_item	2792431	et	4	main
kõik	doc_670731433452_item	2792432	et	4	main
pole	doc_670731433452_item	2792433	et	3	main
agel	doc_670731433452_item	2792442	et	4	main
murdma	doc_670731433452_item	2792450	et	3	main
pidama	doc_670731433452_item	2792460	et	4	main
tantsima	doc_670731433452_item	2792473	et	3	main
tantsist	doc_670731433452_item	2792474	et	3	main
tehtud	doc_670731433452_item	2792482	et	4	main
tagasihoidlikku	doc_670731433452_item	2792493	et	4	main
planeerinud	doc_670731433452_item	2792500	et	4	main
oks	doc_670731433452_item	2792524	et	3	main
ja	doc_670731433452_item	2792525	et	3	main
öelda	doc_670731433452_item	2792535	et	4	main
nad	doc_670731433452_item	2792536	et	3	main
eelistavad	doc_670731433452_item	2792537	et	4	main
elada	doc_670731433452_item	2792538	et	3	main
üks	doc_670731433452_item	2792539	et	3	main
teksti	doc_670731433452_item	2792548	et	4	main
alt	doc_670731433452_item	2792549	et	4	main
vabanduse	doc_670731433452_item	2792587	et	4	main
planeerida	doc_670731433452_item	2792588	et	3	main
individuaalsele	doc_670731433452_item	2792595	et	3	main
on	doc_670731433452_item	2792606	et	4	main
tarkust	doc_670731433452_item	2792610	et	4	main
oled	doc_670731433452_item	2792612	et	3	main
või	doc_670731433452_item	2792618	et	4	main
lähimast	doc_670731433452_item	2792619	et	4	main
muudab	doc_670731433451_item	2792329	et	3	main
b	doc_670731433451_item	2792333	et	4	main
c	doc_670731433451_item	2792335	et	4	main
c	doc_670731433451_item	2792344	et	4	main
külastage	doc_670731433451_item	2792345	et	3	main
edur	doc_670731433452_item	2792367	et	4	main
pärit	doc_670731433452_item	2792369	et	3	main
elavad	doc_670731433452_item	2792373	et	4	main
praegu	doc_670731433452_item	2792374	et	3	main
inglismaa	doc_670731433452_item	2792375	et	4	main
aastane	doc_670731433452_item	2792383	et	4	main
ja	doc_670731433452_item	2792384	et	3	main
kahe	doc_670731433452_item	2792389	et	3	main
saja	doc_670731433452_item	2792397	et	4	main
on	doc_670731433452_item	2792400	et	4	main
nendesse	doc_670731433452_item	2792421	et	4	main
noorelt	doc_670731433452_item	2792428	et	4	main
ülivõrdes	doc_670731433452_item	2792430	et	3	main
läinud	doc_670731433452_item	2792438	et	4	main
mõlemal	doc_670731433452_item	2792439	et	3	main
ja	doc_670731433452_item	2792440	et	3	main
eriti	doc_670731433452_item	2792441	et	3	main
aastal	doc_670731433452_item	2792449	et	3	main
etendus	doc_670731433452_item	2792456	et	4	main
jalaluu	doc_670731433452_item	2792458	et	4	main
ja	doc_670731433452_item	2792459	et	3	main
olema	doc_670731433452_item	2792466	et	4	main
tantsijad	doc_670731433452_item	2792491	et	4	main
tagasihoidlik	doc_670731433452_item	2792492	et	3	main
täpselt	doc_670731433452_item	2792498	et	4	main
planeerima	doc_670731433452_item	2792499	et	3	main
ja	doc_670731433452_item	2792506	et	3	main
parem	doc_670731433452_item	2792508	et	4	main
kui	doc_670731433452_item	2792522	et	3	main
edur	doc_670731433452_item	2792526	et	4	main
püsida	doc_670731433452_item	2792530	et	3	main
ei	doc_670731433452_item	2792531	et	4	main
päeva	doc_670731433452_item	2792542	et	4	main
kaupa	doc_670731433452_item	2792543	et	4	main
soovid	doc_670731433452_item	2792577	et	4	main
aega	doc_670731433452_item	2792589	et	4	main
4	doc_670731433452_item	2792596	et	2	main
on	doc_670731433452_item	2792599	et	4	main
vaja	doc_670731433452_item	2792607	et	4	main
registreerunud	doc_670731433452_item	2792614	et	4	main
saad	doc_670731433452_item	2792615	et	4	main
postiasutusest	doc_670731433452_item	2792620	et	4	main
lihtne	doc_670731433451_item	2792338	et	3	main
10	doc_670731433451_item	2792339	et	2	main
d	doc_670731433451_item	2792346	et	4	main
sõnadega	doc_670731433452_item	2792353	et	3	main
õige	doc_670731433452_item	2792355	et	4	main
vastus	doc_670731433452_item	2792356	et	3	main
annab	doc_670731433452_item	2792357	et	3	main
ühe	doc_670731433452_item	2792358	et	4	main
ja	doc_670731433452_item	2792365	et	3	main
eesti	doc_670731433452_item	2792370	et	4	main
eestlased	doc_670731433452_item	2792371	et	3	main
aga	doc_670731433452_item	2792372	et	3	main
kolmekümne	doc_670731433452_item	2792382	et	4	main
kolmekümne	doc_670731433452_item	2792388	et	4	main
aastat	doc_670731433452_item	2792390	et	3	main
alates	doc_670731433452_item	2792392	et	3	main
artiklid	doc_670731433452_item	2792425	et	3	main
noored	doc_670731433452_item	2792427	et	3	main
ainult	doc_670731433452_item	2792429	et	4	main
alati	doc_670731433452_item	2792435	et	4	main
olnud	doc_670731433452_item	2792444	et	4	main
murdnud	doc_670731433452_item	2792451	et	4	main
naine	doc_670731433452_item	2792453	et	3	main
järve	doc_670731433452_item	2792455	et	4	main
etenduses	doc_670731433452_item	2792457	et	4	main
olnud	doc_670731433452_item	2792467	et	4	main
ja	doc_670731433452_item	2792469	et	3	main
toomas	doc_670731433452_item	2792470	et	3	main
neil	doc_670731433452_item	2792480	et	4	main
on	doc_670731433452_item	2792481	et	4	main
tantsimiseks	doc_670731433452_item	2792486	et	4	main
nende	doc_670731433452_item	2792494	et	4	main
lähiaja	doc_670731433452_item	2792495	et	3	main
age	doc_670731433452_item	2792501	et	4	main
ja	doc_670731433452_item	2792502	et	3	main
toomas	doc_670731433452_item	2792503	et	3	main
veelgi	doc_670731433452_item	2792507	et	4	main
paremat	doc_670731433452_item	2792509	et	4	main
oska	doc_670731433452_item	2792532	et	4	main
nad	doc_670731433452_item	2792533	et	3	main
ütlema	doc_670731433452_item	2792534	et	3	main
ühe	doc_670731433452_item	2792541	et	4	main
lünka	doc_670731433452_item	2792545	et	4	main
sobiv	doc_670731433452_item	2792546	et	4	main
iga	doc_670731433452_item	2792550	et	4	main
õige	doc_670731433452_item	2792551	et	4	main
vastus	doc_670731433452_item	2792552	et	3	main
annab	doc_670731433452_item	2792553	et	3	main
ühe	doc_670731433452_item	2792554	et	4	main
siiski	doc_670731433452_item	2792569	et	4	main
käes	doc_670731433452_item	2792578	et	4	main
interaktiivse	doc_670731433452_item	2792580	et	3	main
õppe	doc_670731433452_item	2792581	et	4	main
ning	doc_670731433452_item	2792590	et	3	main
tasemele	doc_670731433452_item	2792597	et	3	main
raha	doc_670731433452_item	2792600	et	4	main
5	doc_670731433452_item	2792603	et	2	main
kokku	doc_670731433452_item	2792604	et	3	main
saada	doc_670731433452_item	2792605	et	4	main
pisut	doc_670731433452_item	2792609	et	3	main
kui	doc_670731433452_item	2792611	et	3	main
kursusele	doc_670731433452_item	2792613	et	3	main
igal	doc_670731433452_item	2792621	et	3	main
õppematerjalid	doc_670731433452_item	2792624	et	3	main
raamatu	doc_670731433452_item	2792625	et	4	main
ja	doc_670731433452_item	2792626	et	3	main
helikasseti	doc_670731433452_item	2792627	et	4	main
6	doc_670731433452_item	2792628	et	2	main
saada	doc_670731433452_item	2792637	et	4	main
täidetud	doc_670731433452_item	2792638	et	4	main
vastab	doc_670731433452_item	2792650	et	3	main
soovitad	doc_670731433452_item	2792674	et	3	main
d	doc_670731433452_item	2792684	et	4	main
siiski	doc_670731433452_item	2792685	et	4	main
varanduse	doc_670731433452_item	2792692	et	3	main
a	doc_670731433452_item	2792696	et	4	main
kokku	doc_670731433452_item	2792706	et	3	main
saada	doc_670731433452_item	2792707	et	4	main
kokku	doc_670731433452_item	2792712	et	3	main
kuid	doc_670731433452_item	2792723	et	4	main
7	doc_670731433452_item	2792726	et	2	main
c	doc_670731433452_item	2792731	et	4	main
hästi	doc_670731433452_item	2792423	et	3	main
räägivad	doc_670731433452_item	2792426	et	3	main
sugugi	doc_670731433452_item	2792434	et	4	main
on	doc_670731433452_item	2792443	et	4	main
noor	doc_670731433452_item	2792452	et	3	main
luikede	doc_670731433452_item	2792454	et	3	main
pidas	doc_670731433452_item	2792461	et	3	main
aega	doc_670731433452_item	2792463	et	4	main
tantsimisest	doc_670731433452_item	2792464	et	4	main
eemal	doc_670731433452_item	2792465	et	3	main
age	doc_670731433452_item	2792468	et	4	main
on	doc_670731433452_item	2792471	et	4	main
otsustanud	doc_670731433452_item	2792472	et	4	main
ainult	doc_670731433452_item	2792475	et	4	main
teineteisega	doc_670731433452_item	2792476	et	3	main
paaris	doc_670731433452_item	2792477	et	4	main
kuigi	doc_670731433452_item	2792478	et	3	main
nemad	doc_670731433452_item	2792479	et	3	main
suurele	doc_670731433452_item	2792488	et	4	main
edule	doc_670731433452_item	2792489	et	3	main
esinemised	doc_670731433452_item	2792496	et	4	main
tahavad	doc_670731433452_item	2792504	et	3	main
tantsida	doc_670731433452_item	2792510	et	3	main
märtsis	doc_670731433452_item	2792511	et	3	main
tulevad	doc_670731433452_item	2792512	et	4	main
nad	doc_670731433452_item	2792513	et	3	main
esinema	doc_670731433452_item	2792514	et	3	main
tallinn	doc_670731433452_item	2792515	et	4	main
tallinnasse	doc_670731433452_item	2792516	et	3	main
ja	doc_670731433452_item	2792517	et	3	main
seejärel	doc_670731433452_item	2792518	et	3	main
sõidavad	doc_670731433452_item	2792519	et	3	main
lõuna-aafrika	doc_670731433452_item	2792520	et	4	main
veel	doc_670731433452_item	2792527	et	4	main
tipus	doc_670731433452_item	2792528	et	3	main
suudavad	doc_670731433452_item	2792529	et	3	main
päev	doc_670731433452_item	2792540	et	3	main
kirjutage	doc_670731433452_item	2792544	et	3	main
punkti	doc_670731433452_item	2792555	et	4	main
õpi	doc_670731433452_item	2792556	et	4	main
millal	doc_670731433452_item	2792557	et	3	main
1	doc_670731433452_item	2792558	et	2	main
solvud	doc_670731433452_item	2792559	et	3	main
unusta	doc_670731433452_item	2792560	et	4	main
umbne	doc_670731433452_item	2792561	et	3	main
klassiruum	doc_670731433452_item	2792562	et	3	main
koduõppesüsteem	doc_670731433452_item	2792563	et	3	main
võimaldab	doc_670731433452_item	2792564	et	3	main
sul	doc_670731433452_item	2792565	et	3	main
saada	doc_670731433452_item	2792566	et	4	main
2	doc_670731433452_item	2792568	et	2	main
seal	doc_670731433452_item	2792570	et	4	main
targemaks	doc_670731433452_item	2792567	et	4	main
kus	doc_670731433452_item	2792571	et	3	main
ja	doc_670731433452_item	2792572	et	3	main
millal	doc_670731433452_item	2792573	et	3	main
sa	doc_670731433452_item	2792574	et	3	main
seda	doc_670731433452_item	2792575	et	3	main
parasjagu	doc_670731433452_item	2792576	et	3	main
on	doc_670731433452_item	2792579	et	4	main
eelise	doc_670731433452_item	2792591	et	4	main
omandada	doc_670731433452_item	2792592	et	3	main
teadmisi	doc_670731433452_item	2792593	et	4	main
aeg	doc_670731433452_item	2792598	et	3	main
et	doc_670731433452_item	2792601	et	3	main
seda	doc_670731433452_item	2792602	et	3	main
ka	doc_670731433452_item	2792608	et	3	main
kontorist	doc_670731433452_item	2792617	et	4	main
ning	doc_670731433452_item	2792629	et	3	main
tasud	doc_670731433452_item	2792634	et	4	main
selle	doc_670731433452_item	2792635	et	4	main
parandab	doc_670731433452_item	2792647	et	3	main
postitage	doc_670731433452_item	2792666	et	3	main
kupong	doc_670731433452_item	2792667	et	3	main
1	doc_670731433452_item	2792668	et	2	main
c	doc_670731433452_item	2792673	et	4	main
2	doc_670731433452_item	2792677	et	2	main
just	doc_670731433452_item	2792679	et	3	main
3	doc_670731433452_item	2792686	et	2	main
a	doc_670731433452_item	2792687	et	4	main
vajaduse	doc_670731433452_item	2792688	et	3	main
b	doc_670731433452_item	2792689	et	4	main
d	doc_670731433452_item	2792693	et	4	main
b	doc_670731433452_item	2792698	et	4	main
c	doc_670731433452_item	2792700	et	4	main
liita	doc_670731433452_item	2792710	et	4	main
d	doc_670731433452_item	2792714	et	4	main
6	doc_670731433452_item	2792717	et	2	main
ning	doc_670731433452_item	2792719	et	3	main
b	doc_670731433452_item	2792720	et	4	main
7	doc_670731433452_item	2792632	et	2	main
kodutöö	doc_670731433452_item	2792639	et	4	main
meile	doc_670731433452_item	2792640	et	4	main
tagasi	doc_670731433452_item	2792641	et	3	main
õpetaja	doc_670731433452_item	2792642	et	4	main
vaatab	doc_670731433452_item	2792643	et	3	main
ning	doc_670731433452_item	2792649	et	3	main
vajaduse	doc_670731433452_item	2792651	et	3	main
kõik	doc_670731433452_item	2792656	et	4	main
geniaalne	doc_670731433452_item	2792657	et	3	main
on	doc_670731433452_item	2792658	et	4	main
9	doc_670731433452_item	2792659	et	2	main
lihtne	doc_670731433452_item	2792660	et	3	main
10	doc_670731433452_item	2792661	et	2	main
tulge	doc_670731433452_item	2792662	et	3	main
meie	doc_670731433452_item	2792663	et	4	main
virtuaalkodu	doc_670731433452_item	2792664	et	4	main
või	doc_670731433452_item	2792665	et	4	main
kuul	doc_670731433452_item	2792622	et	4	main
kodutöö	doc_670731433452_item	2792630	et	4	main
selle	doc_670731433452_item	2792644	et	4	main
üle	doc_670731433452_item	2792645	et	3	main
8	doc_670731433452_item	2792646	et	2	main
ka	doc_670731433452_item	2792653	et	3	main
lisaküsimustele	doc_670731433452_item	2792655	et	4	main
soovid	doc_670731433452_item	2792672	et	4	main
solvud	doc_670731433452_item	2792676	et	3	main
a	doc_670731433452_item	2792678	et	4	main
c	doc_670731433452_item	2792691	et	4	main
a	doc_670731433452_item	2792705	et	4	main
c	doc_670731433452_item	2792711	et	4	main
kokku	doc_670731433452_item	2792715	et	3	main
taga	doc_670731433452_item	2792728	et	4	main
b	doc_670731433452_item	2792729	et	4	main
d	doc_670731433452_item	2792733	et	4	main
kirjutab	doc_670731433452_item	2792737	et	3	main
c	doc_670731433452_item	2792749	et	4	main
liikuv	doc_670731433452_item	2792750	et	4	main
a	doc_670731433452_item	2792754	et	4	main
b	doc_670731433452_item	2792756	et	4	main
sulud	doc_670731433453_item	2792764	et	3	main
praegu	doc_670731433453_item	2792788	et	3	main
london	doc_670731433453_item	2792790	et	4	main
inglismaale	doc_670731433453_item	2792791	et	4	main
kolmekümnane	doc_670731433453_item	2792796	et	4	main
toomas	doc_670731433453_item	2792799	et	3	main
kolmkümend	doc_670731433453_item	2792802	et	4	main
aastat	doc_670731433453_item	2792804	et	3	main
on	doc_670731433453_item	2792812	et	4	main
esinevad	doc_670731433453_item	2792817	et	4	main
teatrid	doc_670731433453_item	2792819	et	3	main
neid	doc_670731433453_item	2792825	et	4	main
nendesse	doc_670731433453_item	2792833	et	4	main
noori	doc_670731433453_item	2792840	et	3	main
ülivõrdes	doc_670731433453_item	2792842	et	3	main
kuid	doc_670731433453_item	2792843	et	4	main
kõik	doc_670731433453_item	2792844	et	4	main
nii	doc_670731433453_item	2792848	et	3	main
aastal	doc_670731433453_item	2792861	et	3	main
järve	doc_670731433453_item	2792867	et	4	main
tantsimisest	doc_670731433453_item	2792876	et	4	main
olema	doc_670731433453_item	2792878	et	4	main
olla	doc_670731433453_item	2792879	et	3	main
on	doc_670731433453_item	2792893	et	4	main
ka	doc_670731433453_item	2792896	et	3	main
hästi	doc_670731433453_item	2792921	et	3	main
märtsis	doc_670731433453_item	2792923	et	3	main
seejärel	doc_670731433453_item	2792930	et	3	main
lõuna-aafrika	doc_670731433453_item	2792932	et	4	main
kui	doc_670731433453_item	2792934	et	3	main
kaua	doc_670731433453_item	2792935	et	3	main
oks	doc_670731433453_item	2792936	et	3	main
ja	doc_670731433453_item	2792937	et	3	main
ütled	doc_670731433453_item	2792947	et	3	main
sobiv	doc_670731433453_item	2792958	et	4	main
punkti	doc_670731433453_item	2792967	et	4	main
õpi	doc_670731433453_item	2792968	et	4	main
millal	doc_670731433453_item	2792969	et	3	main
ajastu	doc_670731433453_item	2792994	et	4	main
aega	doc_670731433453_item	2793001	et	4	main
seda	doc_670731433453_item	2793014	et	3	main
b	doc_670731433452_item	2792671	et	4	main
d	doc_670731433452_item	2792675	et	4	main
b	doc_670731433452_item	2792680	et	4	main
seega	doc_670731433452_item	2792681	et	4	main
vabaduse	doc_670731433452_item	2792694	et	4	main
4	doc_670731433452_item	2792695	et	2	main
tasule	doc_670731433452_item	2792697	et	3	main
tasemele	doc_670731433452_item	2792699	et	3	main
b	doc_670731433452_item	2792708	et	4	main
kokku	doc_670731433452_item	2792709	et	3	main
hoida	doc_670731433452_item	2792713	et	3	main
panna	doc_670731433452_item	2792716	et	4	main
a	doc_670731433452_item	2792718	et	4	main
c	doc_670731433452_item	2792722	et	4	main
d	doc_670731433452_item	2792724	et	4	main
et	doc_670731433452_item	2792725	et	3	main
a	doc_670731433452_item	2792727	et	4	main
eest	doc_670731433452_item	2792732	et	4	main
palub	doc_670731433452_item	2792739	et	3	main
parandab	doc_670731433452_item	2792741	et	3	main
d	doc_670731433452_item	2792742	et	4	main
muudab	doc_670731433452_item	2792743	et	3	main
d	doc_670731433452_item	2792751	et	4	main
c	doc_670731433452_item	2792758	et	4	main
külastage	doc_670731433452_item	2792759	et	3	main
d	doc_670731433452_item	2792760	et	4	main
minge	doc_670731433452_item	2792761	et	3	main
inglismaa	doc_670731433453_item	2792789	et	4	main
aastane	doc_670731433453_item	2792797	et	4	main
ja	doc_670731433453_item	2792798	et	3	main
on	doc_670731433453_item	2792800	et	4	main
kaks	doc_670731433453_item	2792803	et	3	main
vana	doc_670731433453_item	2792805	et	4	main
alates	doc_670731433453_item	2792806	et	3	main
1997a	doc_670731433453_item	2792807	et	4	main
tuhad	doc_670731433453_item	2792808	et	3	main
vabakutseline	doc_670731433453_item	2792814	et	4	main
väga	doc_670731433453_item	2792826	et	3	main
karmid	doc_670731433453_item	2792829	et	4	main
kriitikud	doc_670731433453_item	2792830	et	3	main
sugugi	doc_670731433453_item	2792846	et	4	main
läinud	doc_670731433453_item	2792850	et	4	main
ja	doc_670731433453_item	2792852	et	3	main
agel	doc_670731433453_item	2792854	et	4	main
murdma	doc_670731433453_item	2792862	et	3	main
naine	doc_670731433453_item	2792865	et	3	main
pidama	doc_670731433453_item	2792872	et	4	main
aega	doc_670731433453_item	2792875	et	4	main
otsustanud	doc_670731433453_item	2792884	et	4	main
tantsima	doc_670731433453_item	2792885	et	3	main
tansisid	doc_670731433453_item	2792886	et	4	main
ainult	doc_670731433453_item	2792887	et	4	main
teineteisega	doc_670731433453_item	2792888	et	3	main
nemad	doc_670731433453_item	2792891	et	3	main
nad	doc_670731433453_item	2792925	et	3	main
tallinn	doc_670731433453_item	2792927	et	4	main
ei	doc_670731433453_item	2792943	et	4	main
oska	doc_670731433453_item	2792944	et	4	main
nad	doc_670731433453_item	2792945	et	3	main
nad	doc_670731433453_item	2792948	et	3	main
alt	doc_670731433453_item	2792961	et	4	main
1	doc_670731433453_item	2792970	et	2	main
sobid	doc_670731433453_item	2792971	et	4	main
saada	doc_670731433453_item	2792978	et	4	main
targemaks	doc_670731433453_item	2792979	et	4	main
soovid	doc_670731433453_item	2792989	et	4	main
käes	doc_670731433453_item	2792990	et	4	main
mis	doc_670731433453_item	2792995	et	4	main
vajaduse	doc_670731433453_item	2792999	et	3	main
eelise	doc_670731433453_item	2793003	et	4	main
et	doc_670731433453_item	2793013	et	3	main
tarkust	doc_670731433453_item	2793022	et	4	main
kursusele	doc_670731433453_item	2793025	et	3	main
raamatu	doc_670731433453_item	2793037	et	4	main
ja	doc_670731433453_item	2793038	et	3	main
helikasseti	doc_670731433453_item	2793039	et	4	main
6	doc_670731433453_item	2793040	et	2	main
ning	doc_670731433453_item	2793041	et	3	main
7	doc_670731433453_item	2793044	et	2	main
kodutöö	doc_670731433453_item	2793051	et	4	main
tagasi	doc_670731433453_item	2793053	et	3	main
kõik	doc_670731433453_item	2793068	et	4	main
c	doc_670731433452_item	2792682	et	4	main
kuigi	doc_670731433452_item	2792683	et	3	main
vabanduse	doc_670731433452_item	2792690	et	4	main
tasakesi	doc_670731433452_item	2792701	et	3	main
d	doc_670731433452_item	2792702	et	4	main
tasakaalule	doc_670731433452_item	2792703	et	3	main
5	doc_670731433452_item	2792704	et	2	main
vaid	doc_670731433452_item	2792721	et	3	main
ette	doc_670731433452_item	2792730	et	4	main
a	doc_670731433452_item	2792736	et	4	main
b	doc_670731433452_item	2792738	et	4	main
c	doc_670731433452_item	2792740	et	4	main
9	doc_670731433452_item	2792744	et	2	main
a	doc_670731433452_item	2792745	et	4	main
liigne	doc_670731433452_item	2792746	et	3	main
lihtne	doc_670731433452_item	2792752	et	3	main
tulge	doc_670731433452_item	2792755	et	3	main
käige	doc_670731433452_item	2792757	et	3	main
londonisse	doc_670731433453_item	2792792	et	4	main
age	doc_670731433453_item	2792793	et	4	main
on	doc_670731433453_item	2792794	et	4	main
üheksesaja	doc_670731433453_item	2792809	et	4	main
ühekümne	doc_670731433453_item	2792810	et	4	main
seitse	doc_670731433453_item	2792811	et	3	main
nad	doc_670731433453_item	2792813	et	3	main
teatrised	doc_670731433453_item	2792821	et	4	main
armastama	doc_670731433453_item	2792823	et	3	main
armastavad	doc_670731433453_item	2792824	et	4	main
suhtuma	doc_670731433453_item	2792831	et	3	main
üldiselt	doc_670731433453_item	2792834	et	4	main
hästi	doc_670731433453_item	2792835	et	3	main
artiklid	doc_670731433453_item	2792837	et	3	main
noored	doc_670731433453_item	2792839	et	3	main
ainult	doc_670731433453_item	2792841	et	4	main
kergelt	doc_670731433453_item	2792849	et	4	main
mõlemal	doc_670731433453_item	2792851	et	3	main
noor	doc_670731433453_item	2792864	et	3	main
pidatakse	doc_670731433453_item	2792873	et	4	main
kuigi	doc_670731433453_item	2792890	et	3	main
tallinnas	doc_670731433453_item	2792928	et	4	main
lõuna-aafrikasse	doc_670731433453_item	2792933	et	4	main
edur	doc_670731433453_item	2792938	et	4	main
veel	doc_670731433453_item	2792939	et	4	main
tipus	doc_670731433453_item	2792940	et	3	main
suudavad	doc_670731433453_item	2792941	et	3	main
püsida	doc_670731433453_item	2792942	et	3	main
kaupa	doc_670731433453_item	2792955	et	4	main
kirjutage	doc_670731433453_item	2792956	et	3	main
ühe	doc_670731433453_item	2792966	et	4	main
võimaldab	doc_670731433453_item	2792976	et	3	main
2	doc_670731433453_item	2792980	et	2	main
siski	doc_670731433453_item	2792981	et	3	main
seal	doc_670731433453_item	2792982	et	4	main
kus	doc_670731433453_item	2792983	et	3	main
ja	doc_670731433453_item	2792984	et	3	main
millal	doc_670731433453_item	2792985	et	3	main
sa	doc_670731433453_item	2792986	et	3	main
seda	doc_670731433453_item	2792987	et	3	main
parasjagu	doc_670731433453_item	2792988	et	3	main
3	doc_670731433453_item	2792998	et	2	main
on	doc_670731433453_item	2793011	et	4	main
raha	doc_670731433453_item	2793012	et	4	main
pisut	doc_670731433453_item	2793021	et	3	main
oled	doc_670731433453_item	2793024	et	3	main
registreerunud	doc_670731433453_item	2793026	et	4	main
või	doc_670731433453_item	2793030	et	4	main
kodutöö	doc_670731433453_item	2793042	et	4	main
kursuse	doc_670731433453_item	2793043	et	3	main
tasud	doc_670731433453_item	2793046	et	4	main
vaatab	doc_670731433453_item	2793055	et	3	main
üle	doc_670731433453_item	2793057	et	3	main
vead	doc_670731433453_item	2793060	et	4	main
vastab	doc_670731433453_item	2793062	et	3	main
9	doc_670731433453_item	2793071	et	2	main
meie	doc_670731433453_item	2793075	et	4	main
1	doc_670731433453_item	2793080	et	2	main
a	doc_670731433453_item	2793081	et	4	main
d	doc_670731433453_item	2793087	et	4	main
solvud	doc_670731433453_item	2793088	et	3	main
2	doc_670731433453_item	2793089	et	2	main
b	doc_670731433453_item	2793101	et	4	main
vabanduse	doc_670731433453_item	2793102	et	4	main
8	doc_670731433452_item	2792735	et	2	main
harjutus	doc_670731433453_item	2792762	et	4	main
avage	doc_670731433453_item	2792763	et	3	main
numbrid	doc_670731433453_item	2792765	et	3	main
kirjutage	doc_670731433453_item	2792766	et	3	main
sõnadega	doc_670731433453_item	2792767	et	3	main
iga	doc_670731433453_item	2792768	et	4	main
õige	doc_670731433453_item	2792769	et	4	main
vastus	doc_670731433453_item	2792770	et	3	main
annab	doc_670731433453_item	2792771	et	3	main
ühe	doc_670731433453_item	2792772	et	4	main
punkti	doc_670731433453_item	2792773	et	4	main
maailmakuulsad	doc_670731433453_item	2792774	et	3	main
abielupaar	doc_670731433453_item	2792776	et	4	main
balletitantsijad	doc_670731433453_item	2792775	et	3	main
age	doc_670731433453_item	2792777	et	4	main
oks	doc_670731433453_item	2792778	et	3	main
ja	doc_670731433453_item	2792779	et	3	main
toomas	doc_670731433453_item	2792780	et	3	main
edur	doc_670731433453_item	2792781	et	4	main
pärit	doc_670731433453_item	2792783	et	3	main
on	doc_670731433453_item	2792782	et	4	main
eesti	doc_670731433453_item	2792784	et	4	main
eestis	doc_670731433453_item	2792785	et	3	main
aga	doc_670731433453_item	2792786	et	3	main
elavad	doc_670731433453_item	2792787	et	4	main
ees	doc_670731433452_item	2792734	et	4	main
b	doc_670731433452_item	2792747	et	4	main
libe	doc_670731433452_item	2792748	et	3	main
10	doc_670731433452_item	2792753	et	2	main
32	doc_670731433453_item	2792801	et	2	main
ja	doc_670731433453_item	2792816	et	3	main
30	doc_670731433453_item	2792795	et	2	main
vabakutselise	doc_670731433453_item	2792815	et	4	main
erinevad	doc_670731433453_item	2792818	et	4	main
erined	doc_670731433453_item	2792820	et	3	main
pole	doc_670731433453_item	2792845	et	3	main
tervil	doc_670731433453_item	2792859	et	4	main
1990	doc_670731433453_item	2792860	et	2	main
murdned	doc_670731433453_item	2792863	et	4	main
luikede	doc_670731433453_item	2792866	et	3	main
jalaluu	doc_670731433453_item	2792870	et	4	main
ja	doc_670731433453_item	2792871	et	3	main
paaris	doc_670731433453_item	2792889	et	4	main
tehtud	doc_670731433453_item	2792894	et	4	main
tulevad	doc_670731433453_item	2792924	et	4	main
esinema	doc_670731433453_item	2792926	et	3	main
sõidavad	doc_670731433453_item	2792931	et	3	main
lünka	doc_670731433453_item	2792957	et	4	main
teksti	doc_670731433453_item	2792960	et	4	main
sul	doc_670731433453_item	2792977	et	3	main
on	doc_670731433453_item	2792991	et	4	main
interaktiivse	doc_670731433453_item	2792992	et	3	main
õppe	doc_670731433453_item	2792993	et	4	main
sulle	doc_670731433453_item	2792997	et	3	main
planeerida	doc_670731433453_item	2793000	et	3	main
kui	doc_670731433453_item	2793023	et	3	main
kontorist	doc_670731433453_item	2793029	et	4	main
kätte	doc_670731433453_item	2793035	et	4	main
saada	doc_670731433453_item	2793049	et	4	main
lisaküsimustele	doc_670731433453_item	2793067	et	4	main
tulge	doc_670731433453_item	2793074	et	3	main
virtuaalkodu	doc_670731433453_item	2793076	et	4	main
või	doc_670731433453_item	2793077	et	4	main
postitage	doc_670731433453_item	2793078	et	3	main
kupong	doc_670731433453_item	2793079	et	3	main
c	doc_670731433453_item	2793085	et	4	main
soovitad	doc_670731433453_item	2793086	et	3	main
seega	doc_670731433453_item	2793093	et	4	main
kuigi	doc_670731433453_item	2793095	et	3	main
c	doc_670731433453_item	2793112	et	4	main
d	doc_670731433453_item	2793114	et	4	main
tasakaalule	doc_670731433453_item	2793115	et	3	main
kokku	doc_670731433453_item	2793121	et	3	main
c	doc_670731433453_item	2793123	et	4	main
kokku	doc_670731433453_item	2793124	et	3	main
hoida	doc_670731433453_item	2793125	et	3	main
kokku	doc_670731433453_item	2793127	et	3	main
kuid	doc_670731433453_item	2793135	et	4	main
taga	doc_670731433453_item	2793140	et	4	main
ees	doc_670731433453_item	2793146	et	4	main
b	doc_670731433453_item	2793150	et	4	main
c	doc_670731433453_item	2793152	et	4	main
b	doc_670731433453_item	2793159	et	4	main
õige	doc_670731433454_item	2793181	et	4	main
vastus	doc_670731433454_item	2793182	et	3	main
abielupaar	doc_670731433454_item	2793188	et	4	main
eestist	doc_670731433454_item	2793197	et	3	main
armastavad	doc_670731433454_item	2793236	et	4	main
hästi	doc_670731433454_item	2793247	et	3	main
ülivõrdes	doc_670731433454_item	2793254	et	3	main
kõik	doc_670731433454_item	2793256	et	4	main
pole	doc_670731433454_item	2793257	et	3	main
sugugi	doc_670731433454_item	2793258	et	4	main
ja	doc_670731433454_item	2793264	et	3	main
on	doc_670731433454_item	2793267	et	4	main
tervisega	doc_670731433454_item	2793271	et	3	main
olla	doc_670731433454_item	2793291	et	3	main
age	doc_670731433454_item	2793292	et	4	main
ja	doc_670731433454_item	2793293	et	3	main
nemad	doc_670731433454_item	2793303	et	3	main
tantsimiseks	doc_670731433454_item	2793310	et	4	main
nende	doc_670731433454_item	2793318	et	4	main
tulevad	doc_670731433454_item	2793336	et	4	main
veel	doc_670731433454_item	2793351	et	4	main
tipus	doc_670731433454_item	2793352	et	3	main
suudavad	doc_670731433454_item	2793353	et	3	main
oska	doc_670731433454_item	2793356	et	4	main
ütlema	doc_670731433454_item	2793358	et	3	main
eelistavad	doc_670731433454_item	2793361	et	4	main
elada	doc_670731433454_item	2793362	et	3	main
üks	doc_670731433454_item	2793363	et	3	main
päev	doc_670731433454_item	2793364	et	3	main
ühe	doc_670731433454_item	2793365	et	4	main
inglismaal	doc_670731433453_item	2792822	et	4	main
ning	doc_670731433453_item	2792827	et	3	main
isegi	doc_670731433453_item	2792828	et	4	main
suhtusse	doc_670731433453_item	2792832	et	3	main
viimased	doc_670731433453_item	2792836	et	3	main
räägivad	doc_670731433453_item	2792838	et	3	main
alati	doc_670731433453_item	2792847	et	4	main
eriti	doc_670731433453_item	2792853	et	3	main
on	doc_670731433453_item	2792855	et	4	main
olnud	doc_670731433453_item	2792856	et	4	main
probleeme	doc_670731433453_item	2792857	et	3	main
tervis	doc_670731433453_item	2792858	et	3	main
etendus	doc_670731433453_item	2792868	et	4	main
etendused	doc_670731433453_item	2792869	et	4	main
mõnda	doc_670731433453_item	2792874	et	4	main
eemal	doc_670731433453_item	2792877	et	3	main
age	doc_670731433453_item	2792880	et	4	main
ja	doc_670731433453_item	2792881	et	3	main
toomas	doc_670731433453_item	2792882	et	3	main
on	doc_670731433453_item	2792883	et	4	main
neid	doc_670731433453_item	2792892	et	4	main
pakkumisi	doc_670731433453_item	2792895	et	4	main
eraldi	doc_670731433453_item	2792897	et	4	main
tantsimiseks	doc_670731433453_item	2792898	et	4	main
vaatamata	doc_670731433453_item	2792899	et	4	main
suurele	doc_670731433453_item	2792900	et	4	main
edule	doc_670731433453_item	2792901	et	3	main
elavad	doc_670731433453_item	2792902	et	4	main
tantsijad	doc_670731433453_item	2792903	et	4	main
tagasihoidlik	doc_670731433453_item	2792904	et	3	main
tagasihoidlus	doc_670731433453_item	2792905	et	4	main
nende	doc_670731433453_item	2792906	et	4	main
lähiaja	doc_670731433453_item	2792907	et	3	main
esinemised	doc_670731433453_item	2792908	et	4	main
on	doc_670731433453_item	2792909	et	4	main
täpselt	doc_670731433453_item	2792910	et	4	main
planeerima	doc_670731433453_item	2792911	et	3	main
planeerida	doc_670731433453_item	2792912	et	3	main
age	doc_670731433453_item	2792913	et	4	main
toomas	doc_670731433453_item	2792915	et	3	main
ja	doc_670731433453_item	2792914	et	3	main
tahavad	doc_670731433453_item	2792916	et	3	main
areneda	doc_670731433453_item	2792917	et	3	main
ja	doc_670731433453_item	2792918	et	3	main
veelgi	doc_670731433453_item	2792919	et	4	main
parem	doc_670731433453_item	2792920	et	4	main
tantsida	doc_670731433453_item	2792922	et	3	main
ja	doc_670731433453_item	2792929	et	3	main
ütlema	doc_670731433453_item	2792946	et	3	main
eelistavad	doc_670731433453_item	2792949	et	4	main
elada	doc_670731433453_item	2792950	et	3	main
üks	doc_670731433453_item	2792951	et	3	main
päev	doc_670731433453_item	2792952	et	3	main
esimesel	doc_670731433453_item	2792953	et	3	main
päevasel	doc_670731433453_item	2792954	et	4	main
sõna	doc_670731433453_item	2792959	et	4	main
iga	doc_670731433453_item	2792962	et	4	main
õige	doc_670731433453_item	2792963	et	4	main
vastus	doc_670731433453_item	2792964	et	3	main
annab	doc_670731433453_item	2792965	et	3	main
unusta	doc_670731433453_item	2792972	et	4	main
umbne	doc_670731433453_item	2792973	et	3	main
klassiruum	doc_670731433453_item	2792974	et	3	main
koduõppesüsteem	doc_670731433453_item	2792975	et	3	main
annab	doc_670731433453_item	2792996	et	3	main
ning	doc_670731433453_item	2793002	et	3	main
omandada	doc_670731433453_item	2793004	et	3	main
teadmisi	doc_670731433453_item	2793005	et	4	main
vastavalt	doc_670731433453_item	2793006	et	4	main
individuaalsele	doc_670731433453_item	2793007	et	3	main
4	doc_670731433453_item	2793008	et	2	main
tasemele	doc_670731433453_item	2793009	et	3	main
aeg	doc_670731433453_item	2793010	et	3	main
5	doc_670731433453_item	2793015	et	2	main
kokku	doc_670731433453_item	2793016	et	3	main
saada	doc_670731433453_item	2793017	et	4	main
on	doc_670731433453_item	2793018	et	4	main
vaja	doc_670731433453_item	2793019	et	4	main
ka	doc_670731433453_item	2793020	et	3	main
saad	doc_670731433453_item	2793027	et	4	main
õppematerjalid	doc_670731433453_item	2793036	et	3	main
ees	doc_670731433453_item	2793045	et	4	main
selle	doc_670731433453_item	2793047	et	4	main
kättesaamisel	doc_670731433453_item	2793048	et	4	main
meile	doc_670731433453_item	2793052	et	4	main
selle	doc_670731433453_item	2793056	et	4	main
vajaduse	doc_670731433453_item	2793063	et	3	main
tekkinud	doc_670731433453_item	2793066	et	4	main
10	doc_670731433453_item	2793073	et	2	main
b	doc_670731433453_item	2793083	et	4	main
soovid	doc_670731433453_item	2793084	et	4	main
just	doc_670731433453_item	2793091	et	3	main
c	doc_670731433453_item	2793094	et	4	main
a	doc_670731433453_item	2793108	et	4	main
tasule	doc_670731433453_item	2793109	et	3	main
5	doc_670731433453_item	2793116	et	2	main
a	doc_670731433453_item	2793117	et	4	main
liita	doc_670731433453_item	2793122	et	4	main
vaid	doc_670731433453_item	2793133	et	3	main
c	doc_670731433453_item	2793134	et	4	main
a	doc_670731433453_item	2793139	et	4	main
ette	doc_670731433453_item	2793142	et	4	main
8	doc_670731433453_item	2793147	et	2	main
a	doc_670731433453_item	2793166	et	4	main
tulge	doc_670731433453_item	2793167	et	3	main
kirjutage	doc_670731433454_item	2793178	et	3	main
sõnadega	doc_670731433454_item	2793179	et	3	main
iga	doc_670731433454_item	2793180	et	4	main
on	doc_670731433454_item	2793194	et	4	main
pärit	doc_670731433454_item	2793195	et	3	main
üheksakümme	doc_670731433454_item	2793222	et	4	main
on	doc_670731433454_item	2793224	et	4	main
vabakutseline	doc_670731433454_item	2793226	et	4	main
inglismaal	doc_670731433454_item	2793234	et	4	main
armastama	doc_670731433454_item	2793235	et	3	main
üldiselt	doc_670731433454_item	2793246	et	4	main
artiklid	doc_670731433454_item	2793249	et	3	main
kuid	doc_670731433454_item	2793255	et	4	main
mõlemal	doc_670731433454_item	2793263	et	3	main
etenduse	doc_670731433454_item	2793281	et	4	main
pidama	doc_670731433454_item	2793284	et	4	main
olema	doc_670731433454_item	2793290	et	4	main
meie	doc_670731433453_item	2793028	et	4	main
lähimast	doc_670731433453_item	2793031	et	4	main
postiasutusest	doc_670731433453_item	2793032	et	4	main
igal	doc_670731433453_item	2793033	et	3	main
kuul	doc_670731433453_item	2793034	et	4	main
täidetud	doc_670731433453_item	2793050	et	4	main
õpetaja	doc_670731433453_item	2793054	et	4	main
8	doc_670731433453_item	2793058	et	2	main
parandab	doc_670731433453_item	2793059	et	3	main
ning	doc_670731433453_item	2793061	et	3	main
korral	doc_670731433453_item	2793064	et	4	main
ka	doc_670731433453_item	2793065	et	3	main
on	doc_670731433453_item	2793070	et	4	main
lihtne	doc_670731433453_item	2793072	et	3	main
a	doc_670731433453_item	2793090	et	4	main
d	doc_670731433453_item	2793096	et	4	main
siiski	doc_670731433453_item	2793097	et	4	main
3	doc_670731433453_item	2793098	et	2	main
varanduse	doc_670731433453_item	2793104	et	3	main
d	doc_670731433453_item	2793105	et	4	main
tasemele	doc_670731433453_item	2793111	et	3	main
d	doc_670731433453_item	2793126	et	4	main
panna	doc_670731433453_item	2793128	et	4	main
6	doc_670731433453_item	2793129	et	2	main
d	doc_670731433453_item	2793136	et	4	main
et	doc_670731433453_item	2793137	et	3	main
7	doc_670731433453_item	2793138	et	2	main
b	doc_670731433453_item	2793141	et	4	main
c	doc_670731433453_item	2793143	et	4	main
eest	doc_670731433453_item	2793144	et	4	main
a	doc_670731433453_item	2793148	et	4	main
d	doc_670731433453_item	2793154	et	4	main
muudab	doc_670731433453_item	2793155	et	3	main
libe	doc_670731433453_item	2793160	et	3	main
liikuv	doc_670731433453_item	2793162	et	4	main
d	doc_670731433453_item	2793163	et	4	main
lihtne	doc_670731433453_item	2793164	et	3	main
10	doc_670731433453_item	2793165	et	2	main
annab	doc_670731433454_item	2793183	et	3	main
maailmakuulsad	doc_670731433454_item	2793186	et	3	main
üheksasada	doc_670731433454_item	2793221	et	4	main
seitse	doc_670731433454_item	2793223	et	3	main
nad	doc_670731433454_item	2793225	et	3	main
teatrid	doc_670731433454_item	2793231	et	3	main
erinevaid	doc_670731433454_item	2793232	et	4	main
teatrid	doc_670731433454_item	2793233	et	3	main
viimased	doc_670731433454_item	2793248	et	3	main
alati	doc_670731433454_item	2793259	et	4	main
naine	doc_670731433454_item	2793277	et	3	main
luikede	doc_670731433454_item	2793278	et	3	main
järve	doc_670731433454_item	2793279	et	4	main
jalaluu	doc_670731433454_item	2793282	et	4	main
pidab	doc_670731433454_item	2793285	et	4	main
mõnda	doc_670731433454_item	2793286	et	4	main
aega	doc_670731433454_item	2793287	et	4	main
on	doc_670731433454_item	2793295	et	4	main
otsustanud	doc_670731433454_item	2793296	et	4	main
tantsima	doc_670731433454_item	2793297	et	3	main
tantsida	doc_670731433454_item	2793298	et	3	main
kuigi	doc_670731433454_item	2793302	et	3	main
on	doc_670731433454_item	2793305	et	4	main
pakkumisi	doc_670731433454_item	2793307	et	4	main
eraldi	doc_670731433454_item	2793309	et	4	main
tantsijad	doc_670731433454_item	2793315	et	4	main
tagasihoidlik	doc_670731433454_item	2793316	et	3	main
tagasihoidlikud	doc_670731433454_item	2793317	et	3	main
geniaalne	doc_670731433453_item	2793069	et	3	main
sobid	doc_670731433453_item	2793082	et	4	main
b	doc_670731433453_item	2793092	et	4	main
a	doc_670731433453_item	2793099	et	4	main
vajaduse	doc_670731433453_item	2793100	et	3	main
vabaduse	doc_670731433453_item	2793106	et	4	main
4	doc_670731433453_item	2793107	et	2	main
a	doc_670731433453_item	2793130	et	4	main
ning	doc_670731433453_item	2793131	et	3	main
d	doc_670731433453_item	2793145	et	4	main
kirjutab	doc_670731433453_item	2793149	et	3	main
palub	doc_670731433453_item	2793151	et	3	main
parandab	doc_670731433453_item	2793153	et	3	main
9	doc_670731433453_item	2793156	et	2	main
a	doc_670731433453_item	2793157	et	4	main
b	doc_670731433453_item	2793168	et	4	main
käige	doc_670731433453_item	2793169	et	3	main
c	doc_670731433453_item	2793170	et	4	main
külastage	doc_670731433453_item	2793171	et	3	main
d	doc_670731433453_item	2793172	et	4	main
minge	doc_670731433453_item	2793173	et	3	main
harjutus	doc_670731433454_item	2793174	et	4	main
avage	doc_670731433454_item	2793175	et	3	main
sulud	doc_670731433454_item	2793176	et	3	main
numbrid	doc_670731433454_item	2793177	et	3	main
ühe	doc_670731433454_item	2793184	et	4	main
age	doc_670731433454_item	2793189	et	4	main
oks	doc_670731433454_item	2793190	et	3	main
ja	doc_670731433454_item	2793191	et	3	main
toomas	doc_670731433454_item	2793192	et	3	main
edur	doc_670731433454_item	2793193	et	4	main
vabakutselised	doc_670731433454_item	2793227	et	4	main
ja	doc_670731433454_item	2793228	et	3	main
esinevad	doc_670731433454_item	2793229	et	4	main
neid	doc_670731433454_item	2793237	et	4	main
väga	doc_670731433454_item	2793238	et	3	main
ning	doc_670731433454_item	2793239	et	3	main
nendesse	doc_670731433454_item	2793245	et	4	main
nii	doc_670731433454_item	2793260	et	3	main
eriti	doc_670731433454_item	2793265	et	3	main
etendus	doc_670731433454_item	2793280	et	4	main
tantsimisest	doc_670731433454_item	2793288	et	4	main
eemal	doc_670731433454_item	2793289	et	3	main
ainult	doc_670731433454_item	2793299	et	4	main
lähiaja	doc_670731433454_item	2793319	et	3	main
on	doc_670731433454_item	2793321	et	4	main
veelgi	doc_670731433454_item	2793331	et	4	main
parem	doc_670731433454_item	2793332	et	4	main
parema	doc_670731433454_item	2793333	et	4	main
tantsida	doc_670731433454_item	2793334	et	3	main
ei	doc_670731433454_item	2793355	et	4	main
kirjutage	doc_670731433454_item	2793368	et	3	main
lünka	doc_670731433454_item	2793369	et	4	main
alt	doc_670731433454_item	2793373	et	4	main
õige	doc_670731433454_item	2793375	et	4	main
vastus	doc_670731433454_item	2793376	et	3	main
annab	doc_670731433454_item	2793377	et	3	main
ühe	doc_670731433454_item	2793378	et	4	main
umbne	doc_670731433454_item	2793385	et	3	main
koduõppesüsteem	doc_670731433454_item	2793387	et	3	main
sul	doc_670731433454_item	2793389	et	3	main
2	doc_670731433454_item	2793392	et	2	main
siiski	doc_670731433454_item	2793393	et	4	main
seal	doc_670731433454_item	2793394	et	4	main
kus	doc_670731433454_item	2793395	et	3	main
ja	doc_670731433454_item	2793396	et	3	main
millal	doc_670731433454_item	2793397	et	3	main
sa	doc_670731433454_item	2793398	et	3	main
seda	doc_670731433454_item	2793399	et	3	main
vastavalt	doc_670731433454_item	2793418	et	4	main
ka	doc_670731433454_item	2793432	et	3	main
oled	doc_670731433454_item	2793436	et	3	main
lähimast	doc_670731433454_item	2793443	et	4	main
helikasseti	doc_670731433454_item	2793451	et	4	main
6	doc_670731433454_item	2793452	et	2	main
ning	doc_670731433454_item	2793453	et	3	main
ees	doc_670731433454_item	2793457	et	4	main
vajaduse	doc_670731433454_item	2793475	et	3	main
meie	doc_670731433454_item	2793487	et	4	main
b	doc_670731433454_item	2793522	et	4	main
c	doc_670731433454_item	2793524	et	4	main
5	doc_670731433454_item	2793528	et	2	main
c	doc_670731433453_item	2793103	et	4	main
b	doc_670731433453_item	2793110	et	4	main
tasakesi	doc_670731433453_item	2793113	et	3	main
kokku	doc_670731433453_item	2793118	et	3	main
saada	doc_670731433453_item	2793119	et	4	main
b	doc_670731433453_item	2793120	et	4	main
b	doc_670731433453_item	2793132	et	4	main
liigne	doc_670731433453_item	2793158	et	3	main
c	doc_670731433453_item	2793161	et	4	main
punkti	doc_670731433454_item	2793185	et	4	main
balletitantsijad	doc_670731433454_item	2793187	et	3	main
eesti	doc_670731433454_item	2793196	et	4	main
aga	doc_670731433454_item	2793198	et	3	main
elavad	doc_670731433454_item	2793199	et	4	main
praegu	doc_670731433454_item	2793200	et	3	main
inglismaa	doc_670731433454_item	2793201	et	4	main
london	doc_670731433454_item	2793202	et	4	main
inglismaa	doc_670731433454_item	2793203	et	4	main
londonis	doc_670731433454_item	2793204	et	4	main
age	doc_670731433454_item	2793205	et	4	main
on	doc_670731433454_item	2793206	et	4	main
30	doc_670731433454_item	2793207	et	2	main
kolmekümmne	doc_670731433454_item	2793208	et	4	main
aastane	doc_670731433454_item	2793209	et	4	main
ja	doc_670731433454_item	2793210	et	3	main
toomas	doc_670731433454_item	2793211	et	3	main
32	doc_670731433454_item	2793213	et	2	main
on	doc_670731433454_item	2793212	et	4	main
kolmkümme	doc_670731433454_item	2793214	et	4	main
kaks	doc_670731433454_item	2793215	et	3	main
aastat	doc_670731433454_item	2793216	et	3	main
vana	doc_670731433454_item	2793217	et	4	main
alates	doc_670731433454_item	2793218	et	3	main
1997a	doc_670731433454_item	2793219	et	4	main
tuhad	doc_670731433454_item	2793220	et	3	main
erinevad	doc_670731433454_item	2793230	et	4	main
isegi	doc_670731433454_item	2793240	et	4	main
karmid	doc_670731433454_item	2793241	et	4	main
kriitikud	doc_670731433454_item	2793242	et	3	main
suhtuma	doc_670731433454_item	2793243	et	3	main
suhtuvad	doc_670731433454_item	2793244	et	4	main
räägivad	doc_670731433454_item	2793250	et	3	main
noored	doc_670731433454_item	2793251	et	3	main
noortele	doc_670731433454_item	2793252	et	3	main
ainult	doc_670731433454_item	2793253	et	4	main
kergelt	doc_670731433454_item	2793261	et	4	main
läinud	doc_670731433454_item	2793262	et	4	main
agel	doc_670731433454_item	2793266	et	4	main
olnud	doc_670731433454_item	2793268	et	4	main
probleeme	doc_670731433454_item	2793269	et	3	main
tervis	doc_670731433454_item	2793270	et	3	main
1990	doc_670731433454_item	2793272	et	2	main
aastal	doc_670731433454_item	2793273	et	3	main
murdma	doc_670731433454_item	2793274	et	3	main
murdab	doc_670731433454_item	2793275	et	4	main
noor	doc_670731433454_item	2793276	et	3	main
ja	doc_670731433454_item	2793283	et	3	main
toomas	doc_670731433454_item	2793294	et	3	main
paaris	doc_670731433454_item	2793301	et	4	main
vaatamata	doc_670731433454_item	2793311	et	4	main
täpselt	doc_670731433454_item	2793322	et	4	main
planeerima	doc_670731433454_item	2793323	et	3	main
planeeritud	doc_670731433454_item	2793324	et	4	main
märtsis	doc_670731433454_item	2793335	et	3	main
tallinnas	doc_670731433454_item	2793340	et	4	main
sõidavad	doc_670731433454_item	2793343	et	3	main
lõuna-aafrikasse	doc_670731433454_item	2793345	et	4	main
kui	doc_670731433454_item	2793346	et	3	main
kaua	doc_670731433454_item	2793347	et	3	main
oks	doc_670731433454_item	2793348	et	3	main
ja	doc_670731433454_item	2793349	et	3	main
edur	doc_670731433454_item	2793350	et	4	main
päeva	doc_670731433454_item	2793366	et	4	main
teksti	doc_670731433454_item	2793372	et	4	main
1	doc_670731433454_item	2793382	et	2	main
parasjagu	doc_670731433454_item	2793400	et	3	main
käes	doc_670731433454_item	2793402	et	4	main
eelise	doc_670731433454_item	2793415	et	4	main
omandada	doc_670731433454_item	2793416	et	3	main
teadmisi	doc_670731433454_item	2793417	et	4	main
taseele	doc_670731433454_item	2793421	et	4	main
on	doc_670731433454_item	2793423	et	4	main
5	doc_670731433454_item	2793427	et	2	main
kokku	doc_670731433454_item	2793428	et	3	main
hoida	doc_670731433454_item	2793429	et	3	main
meie	doc_670731433454_item	2793440	et	4	main
kursuse	doc_670731433454_item	2793455	et	3	main
kättesaamisel	doc_670731433454_item	2793460	et	4	main
täidetud	doc_670731433454_item	2793462	et	4	main
8	doc_670731433454_item	2793470	et	2	main
korral	doc_670731433454_item	2793476	et	4	main
ka	doc_670731433454_item	2793477	et	3	main
lisaküsimustele	doc_670731433454_item	2793479	et	4	main
sobid	doc_670731433454_item	2793494	et	4	main
soovid	doc_670731433454_item	2793496	et	4	main
d	doc_670731433454_item	2793526	et	4	main
c	doc_670731433454_item	2793535	et	4	main
kokku	doc_670731433454_item	2793536	et	3	main
6	doc_670731433454_item	2793541	et	2	main
taga	doc_670731433454_item	2793552	et	4	main
eest	doc_670731433454_item	2793556	et	4	main
8	doc_670731433454_item	2793559	et	2	main
a	doc_670731433454_item	2793560	et	4	main
kirjutab	doc_670731433454_item	2793561	et	3	main
liigne	doc_670731433454_item	2793570	et	3	main
liikuv	doc_670731433454_item	2793574	et	4	main
10	doc_670731433454_item	2793577	et	2	main
a	doc_670731433454_item	2793578	et	4	main
tulge	doc_670731433454_item	2793579	et	3	main
d	doc_670731433454_item	2793584	et	4	main
sulud	doc_670731433455_item	2793588	et	3	main
on	doc_670731433455_item	2793606	et	4	main
pärit	doc_670731433455_item	2793607	et	3	main
eesti	doc_670731433455_item	2793608	et	4	main
eestis	doc_670731433455_item	2793609	et	3	main
aga	doc_670731433455_item	2793610	et	3	main
elavad	doc_670731433455_item	2793611	et	4	main
london	doc_670731433455_item	2793614	et	4	main
aastane	doc_670731433455_item	2793621	et	4	main
seitmes	doc_670731433455_item	2793635	et	4	main
ning	doc_670731433455_item	2793651	et	3	main
üldiselt	doc_670731433455_item	2793658	et	4	main
hästi	doc_670731433455_item	2793659	et	3	main
viimased	doc_670731433455_item	2793660	et	3	main
noored	doc_670731433455_item	2793663	et	3	main
alati	doc_670731433455_item	2793671	et	4	main
nii	doc_670731433455_item	2793672	et	3	main
teineteisega	doc_670731433454_item	2793300	et	3	main
nemad	doc_670731433454_item	2793304	et	3	main
tehtud	doc_670731433454_item	2793306	et	4	main
ka	doc_670731433454_item	2793308	et	3	main
suurele	doc_670731433454_item	2793312	et	4	main
edule	doc_670731433454_item	2793313	et	3	main
elavad	doc_670731433454_item	2793314	et	4	main
esinemised	doc_670731433454_item	2793320	et	4	main
nad	doc_670731433454_item	2793337	et	3	main
lõuna-aafrika	doc_670731433454_item	2793344	et	4	main
ütelda	doc_670731433454_item	2793359	et	4	main
kaupa	doc_670731433454_item	2793367	et	4	main
punkti	doc_670731433454_item	2793379	et	4	main
õpi	doc_670731433454_item	2793380	et	4	main
millal	doc_670731433454_item	2793381	et	3	main
võimaldab	doc_670731433454_item	2793388	et	3	main
soovid	doc_670731433454_item	2793401	et	4	main
on	doc_670731433454_item	2793403	et	4	main
interaktiivse	doc_670731433454_item	2793404	et	3	main
õppe	doc_670731433454_item	2793405	et	4	main
tarkust	doc_670731433454_item	2793434	et	4	main
registreerunud	doc_670731433454_item	2793438	et	4	main
või	doc_670731433454_item	2793442	et	4	main
kodutöö	doc_670731433454_item	2793454	et	4	main
tasud	doc_670731433454_item	2793458	et	4	main
1	doc_670731433454_item	2793492	et	2	main
b	doc_670731433454_item	2793495	et	4	main
tasule	doc_670731433454_item	2793521	et	3	main
b	doc_670731433454_item	2793532	et	4	main
kokku	doc_670731433454_item	2793533	et	3	main
liita	doc_670731433454_item	2793534	et	4	main
panna	doc_670731433454_item	2793540	et	4	main
a	doc_670731433454_item	2793551	et	4	main
b	doc_670731433454_item	2793562	et	4	main
palub	doc_670731433454_item	2793563	et	3	main
c	doc_670731433454_item	2793564	et	4	main
parandab	doc_670731433454_item	2793565	et	3	main
b	doc_670731433454_item	2793571	et	4	main
c	doc_670731433454_item	2793582	et	4	main
harjutus	doc_670731433455_item	2793586	et	4	main
iga	doc_670731433455_item	2793592	et	4	main
punkti	doc_670731433455_item	2793597	et	4	main
balletitantsijad	doc_670731433455_item	2793599	et	3	main
abielupaar	doc_670731433455_item	2793600	et	4	main
30	doc_670731433455_item	2793619	et	2	main
toomas	doc_670731433455_item	2793623	et	3	main
32	doc_670731433455_item	2793625	et	2	main
kaks	doc_670731433455_item	2793627	et	3	main
1997a	doc_670731433455_item	2793631	et	4	main
üheksakümne	doc_670731433455_item	2793634	et	4	main
vabakutseline	doc_670731433455_item	2793638	et	4	main
vabakutselised	doc_670731433455_item	2793639	et	4	main
ja	doc_670731433455_item	2793640	et	3	main
esinevad	doc_670731433455_item	2793641	et	4	main
suhtuma	doc_670731433455_item	2793655	et	3	main
nendesse	doc_670731433455_item	2793657	et	4	main
räägivad	doc_670731433455_item	2793662	et	3	main
ainult	doc_670731433455_item	2793665	et	4	main
ülivõrdes	doc_670731433455_item	2793666	et	3	main
kuid	doc_670731433455_item	2793667	et	4	main
kergelt	doc_670731433455_item	2793673	et	4	main
eriti	doc_670731433455_item	2793677	et	3	main
aastal	doc_670731433455_item	2793685	et	3	main
tantsimiseks	doc_670731433455_item	2793722	et	4	main
vaatamata	doc_670731433455_item	2793723	et	4	main
lähiaja	doc_670731433455_item	2793731	et	3	main
ja	doc_670731433455_item	2793742	et	3	main
nad	doc_670731433455_item	2793749	et	3	main
esinema	doc_670731433455_item	2793750	et	3	main
õige	doc_670731433455_item	2793788	et	4	main
vastus	doc_670731433455_item	2793789	et	3	main
annab	doc_670731433455_item	2793790	et	3	main
ühe	doc_670731433455_item	2793791	et	4	main
unusta	doc_670731433455_item	2793797	et	4	main
age	doc_670731433454_item	2793325	et	4	main
ja	doc_670731433454_item	2793326	et	3	main
toomas	doc_670731433454_item	2793327	et	3	main
tahavad	doc_670731433454_item	2793328	et	3	main
areneda	doc_670731433454_item	2793329	et	3	main
ja	doc_670731433454_item	2793330	et	3	main
esinema	doc_670731433454_item	2793338	et	3	main
tallinn	doc_670731433454_item	2793339	et	4	main
ja	doc_670731433454_item	2793341	et	3	main
seejärel	doc_670731433454_item	2793342	et	3	main
püsida	doc_670731433454_item	2793354	et	3	main
nad	doc_670731433454_item	2793357	et	3	main
nad	doc_670731433454_item	2793360	et	3	main
sobiv	doc_670731433454_item	2793370	et	4	main
unusta	doc_670731433454_item	2793384	et	4	main
saada	doc_670731433454_item	2793390	et	4	main
mis	doc_670731433454_item	2793407	et	4	main
annab	doc_670731433454_item	2793408	et	3	main
sulle	doc_670731433454_item	2793409	et	3	main
3	doc_670731433454_item	2793410	et	2	main
vajaduse	doc_670731433454_item	2793411	et	3	main
planeerida	doc_670731433454_item	2793412	et	3	main
aega	doc_670731433454_item	2793413	et	4	main
ning	doc_670731433454_item	2793414	et	3	main
individuaalsele	doc_670731433454_item	2793419	et	3	main
4	doc_670731433454_item	2793420	et	2	main
vaja	doc_670731433454_item	2793431	et	4	main
kui	doc_670731433454_item	2793435	et	3	main
saad	doc_670731433454_item	2793439	et	4	main
kontorist	doc_670731433454_item	2793441	et	4	main
kuul	doc_670731433454_item	2793446	et	4	main
kätte	doc_670731433454_item	2793447	et	4	main
õppematerjalid	doc_670731433454_item	2793448	et	3	main
raamatu	doc_670731433454_item	2793449	et	4	main
ja	doc_670731433454_item	2793450	et	3	main
7	doc_670731433454_item	2793456	et	2	main
meile	doc_670731433454_item	2793464	et	4	main
tagasi	doc_670731433454_item	2793465	et	3	main
õpetaja	doc_670731433454_item	2793466	et	4	main
vaatab	doc_670731433454_item	2793467	et	3	main
selle	doc_670731433454_item	2793468	et	4	main
üle	doc_670731433454_item	2793469	et	3	main
vead	doc_670731433454_item	2793472	et	4	main
vastab	doc_670731433454_item	2793474	et	3	main
tekkinud	doc_670731433454_item	2793478	et	4	main
kõik	doc_670731433454_item	2793480	et	4	main
geniaalne	doc_670731433454_item	2793481	et	3	main
on	doc_670731433454_item	2793482	et	4	main
9	doc_670731433454_item	2793483	et	2	main
liigne	doc_670731433454_item	2793484	et	3	main
10	doc_670731433454_item	2793485	et	2	main
külastage	doc_670731433454_item	2793486	et	3	main
a	doc_670731433454_item	2793493	et	4	main
tasakesi	doc_670731433454_item	2793525	et	3	main
a	doc_670731433454_item	2793529	et	4	main
d	doc_670731433454_item	2793538	et	4	main
ning	doc_670731433454_item	2793543	et	3	main
b	doc_670731433454_item	2793544	et	4	main
kuid	doc_670731433454_item	2793547	et	4	main
d	doc_670731433454_item	2793548	et	4	main
et	doc_670731433454_item	2793549	et	3	main
7	doc_670731433454_item	2793550	et	2	main
c	doc_670731433454_item	2793555	et	4	main
d	doc_670731433454_item	2793566	et	4	main
muudab	doc_670731433454_item	2793567	et	3	main
libe	doc_670731433454_item	2793572	et	3	main
külastage	doc_670731433454_item	2793583	et	3	main
numbrid	doc_670731433455_item	2793589	et	3	main
ühe	doc_670731433455_item	2793596	et	4	main
edur	doc_670731433455_item	2793605	et	4	main
on	doc_670731433455_item	2793618	et	4	main
aastat	doc_670731433455_item	2793628	et	3	main
alates	doc_670731433455_item	2793630	et	3	main
erinevad	doc_670731433455_item	2793642	et	4	main
teatrid	doc_670731433455_item	2793643	et	3	main
erinevaid	doc_670731433455_item	2793644	et	4	main
teatrid	doc_670731433455_item	2793645	et	3	main
inglismaal	doc_670731433455_item	2793646	et	4	main
armastama	doc_670731433455_item	2793647	et	3	main
kriitikud	doc_670731433455_item	2793654	et	3	main
1990	doc_670731433455_item	2793684	et	2	main
sõna	doc_670731433454_item	2793371	et	4	main
iga	doc_670731433454_item	2793374	et	4	main
soovitad	doc_670731433454_item	2793383	et	3	main
klassiruum	doc_670731433454_item	2793386	et	3	main
targemaks	doc_670731433454_item	2793391	et	4	main
ajastu	doc_670731433454_item	2793406	et	4	main
aeg	doc_670731433454_item	2793422	et	3	main
raha	doc_670731433454_item	2793424	et	4	main
et	doc_670731433454_item	2793425	et	3	main
seda	doc_670731433454_item	2793426	et	3	main
on	doc_670731433454_item	2793430	et	4	main
pisut	doc_670731433454_item	2793433	et	3	main
kursusele	doc_670731433454_item	2793437	et	3	main
postiasutusest	doc_670731433454_item	2793444	et	4	main
igal	doc_670731433454_item	2793445	et	3	main
selle	doc_670731433454_item	2793459	et	4	main
saada	doc_670731433454_item	2793461	et	4	main
kodutöö	doc_670731433454_item	2793463	et	4	main
kirjutab	doc_670731433454_item	2793471	et	3	main
ning	doc_670731433454_item	2793473	et	3	main
virtuaalkodu	doc_670731433454_item	2793488	et	4	main
või	doc_670731433454_item	2793489	et	4	main
postitage	doc_670731433454_item	2793490	et	3	main
kupong	doc_670731433454_item	2793491	et	3	main
c	doc_670731433454_item	2793497	et	4	main
soovitad	doc_670731433454_item	2793498	et	3	main
d	doc_670731433454_item	2793499	et	4	main
solvud	doc_670731433454_item	2793500	et	3	main
2	doc_670731433454_item	2793501	et	2	main
a	doc_670731433454_item	2793502	et	4	main
just	doc_670731433454_item	2793503	et	3	main
b	doc_670731433454_item	2793504	et	4	main
seega	doc_670731433454_item	2793505	et	4	main
c	doc_670731433454_item	2793506	et	4	main
kuigi	doc_670731433454_item	2793507	et	3	main
d	doc_670731433454_item	2793508	et	4	main
siiski	doc_670731433454_item	2793509	et	4	main
3	doc_670731433454_item	2793510	et	2	main
a	doc_670731433454_item	2793511	et	4	main
vajaduse	doc_670731433454_item	2793512	et	3	main
b	doc_670731433454_item	2793513	et	4	main
vabanduse	doc_670731433454_item	2793514	et	4	main
c	doc_670731433454_item	2793515	et	4	main
varanduse	doc_670731433454_item	2793516	et	3	main
d	doc_670731433454_item	2793517	et	4	main
vabaduse	doc_670731433454_item	2793518	et	4	main
4	doc_670731433454_item	2793519	et	2	main
a	doc_670731433454_item	2793520	et	4	main
tasemele	doc_670731433454_item	2793523	et	3	main
tasakaalule	doc_670731433454_item	2793527	et	3	main
kokku	doc_670731433454_item	2793530	et	3	main
hoida	doc_670731433454_item	2793537	et	3	main
kokku	doc_670731433454_item	2793539	et	3	main
c	doc_670731433454_item	2793546	et	4	main
b	doc_670731433454_item	2793580	et	4	main
käige	doc_670731433454_item	2793581	et	3	main
minge	doc_670731433454_item	2793585	et	3	main
avage	doc_670731433455_item	2793587	et	3	main
õige	doc_670731433455_item	2793593	et	4	main
annab	doc_670731433455_item	2793595	et	3	main
inglismaa	doc_670731433455_item	2793613	et	4	main
inglismaalt	doc_670731433455_item	2793615	et	3	main
saada	doc_670731433454_item	2793531	et	4	main
a	doc_670731433454_item	2793542	et	4	main
vaid	doc_670731433454_item	2793545	et	3	main
b	doc_670731433454_item	2793553	et	4	main
ette	doc_670731433454_item	2793554	et	4	main
d	doc_670731433454_item	2793557	et	4	main
ees	doc_670731433454_item	2793558	et	4	main
9	doc_670731433454_item	2793568	et	2	main
a	doc_670731433454_item	2793569	et	4	main
c	doc_670731433454_item	2793573	et	4	main
d	doc_670731433454_item	2793575	et	4	main
lihtne	doc_670731433454_item	2793576	et	3	main
kirjutage	doc_670731433455_item	2793590	et	3	main
sõnadega	doc_670731433455_item	2793591	et	3	main
vastus	doc_670731433455_item	2793594	et	3	main
maailmakuulsad	doc_670731433455_item	2793598	et	3	main
age	doc_670731433455_item	2793601	et	4	main
oks	doc_670731433455_item	2793602	et	3	main
ja	doc_670731433455_item	2793603	et	3	main
toomas	doc_670731433455_item	2793604	et	3	main
praegu	doc_670731433455_item	2793612	et	3	main
londonis	doc_670731433455_item	2793616	et	4	main
age	doc_670731433455_item	2793617	et	4	main
kolmekümne	doc_670731433455_item	2793620	et	4	main
ja	doc_670731433455_item	2793622	et	3	main
üheksaaja	doc_670731433455_item	2793633	et	3	main
nad	doc_670731433455_item	2793637	et	3	main
neid	doc_670731433455_item	2793649	et	4	main
väga	doc_670731433455_item	2793650	et	3	main
suhtlevad	doc_670731433455_item	2793656	et	4	main
kõik	doc_670731433455_item	2793668	et	4	main
pole	doc_670731433455_item	2793669	et	3	main
sugugi	doc_670731433455_item	2793670	et	4	main
läinud	doc_670731433455_item	2793674	et	4	main
agel	doc_670731433455_item	2793678	et	4	main
on	doc_670731433455_item	2793679	et	4	main
eraldi	doc_670731433455_item	2793721	et	4	main
nende	doc_670731433455_item	2793730	et	4	main
areneda	doc_670731433455_item	2793741	et	3	main
tantsida	doc_670731433455_item	2793746	et	3	main
tallinnas	doc_670731433455_item	2793752	et	4	main
ja	doc_670731433455_item	2793753	et	3	main
seejärel	doc_670731433455_item	2793754	et	3	main
sõidavad	doc_670731433455_item	2793755	et	3	main
lõuna-aafrika	doc_670731433455_item	2793756	et	4	main
lõuna	doc_670731433455_item	2793757	et	4	main
tipus	doc_670731433455_item	2793765	et	3	main
oska	doc_670731433455_item	2793769	et	4	main
sõna	doc_670731433455_item	2793784	et	4	main
õpi	doc_670731433455_item	2793793	et	4	main
millal	doc_670731433455_item	2793794	et	3	main
ning	doc_670731433455_item	2793827	et	3	main
seda	doc_670731433455_item	2793839	et	3	main
saada	doc_670731433455_item	2793842	et	4	main
saad	doc_670731433455_item	2793852	et	4	main
meie	doc_670731433455_item	2793853	et	4	main
postiasutusest	doc_670731433455_item	2793857	et	4	main
kätte	doc_670731433455_item	2793860	et	4	main
tasud	doc_670731433455_item	2793871	et	4	main
täidetud	doc_670731433455_item	2793875	et	4	main
tekkinud	doc_670731433455_item	2793891	et	4	main
või	doc_670731433455_item	2793902	et	4	main
postitage	doc_670731433455_item	2793903	et	3	main
kupong	doc_670731433455_item	2793904	et	3	main
a	doc_670731433455_item	2793933	et	4	main
tasule	doc_670731433455_item	2793934	et	3	main
c	doc_670731433455_item	2793937	et	4	main
liita	doc_670731433455_item	2793947	et	4	main
d	doc_670731433455_item	2793951	et	4	main
kokku	doc_670731433455_item	2793952	et	3	main
b	doc_670731433455_item	2793957	et	4	main
vaid	doc_670731433455_item	2793958	et	3	main
taga	doc_670731433455_item	2793965	et	4	main
c	doc_670731433455_item	2793968	et	4	main
ees	doc_670731433455_item	2793971	et	4	main
muudab	doc_670731433455_item	2793980	et	3	main
liigne	doc_670731433455_item	2793983	et	3	main
d	doc_670731433455_item	2793988	et	4	main
tulge	doc_670731433455_item	2793992	et	3	main
b	doc_670731433455_item	2793993	et	4	main
numbrid	doc_670731433456_item	2794002	et	3	main
iga	doc_670731433456_item	2794005	et	4	main
on	doc_670731433455_item	2793624	et	4	main
kolmkümnend	doc_670731433455_item	2793626	et	3	main
vana	doc_670731433455_item	2793629	et	4	main
tuhande	doc_670731433455_item	2793632	et	3	main
on	doc_670731433455_item	2793636	et	4	main
armastakse	doc_670731433455_item	2793648	et	4	main
isegi	doc_670731433455_item	2793652	et	4	main
karmid	doc_670731433455_item	2793653	et	4	main
artiklid	doc_670731433455_item	2793661	et	3	main
noortel	doc_670731433455_item	2793664	et	3	main
mõlemal	doc_670731433455_item	2793675	et	3	main
ja	doc_670731433455_item	2793676	et	3	main
murdma	doc_670731433455_item	2793686	et	3	main
noor	doc_670731433455_item	2793688	et	3	main
naine	doc_670731433455_item	2793689	et	3	main
luikede	doc_670731433455_item	2793690	et	3	main
järve	doc_670731433455_item	2793691	et	4	main
etendus	doc_670731433455_item	2793692	et	4	main
etendusi	doc_670731433455_item	2793693	et	4	main
jalaluu	doc_670731433455_item	2793694	et	4	main
ja	doc_670731433455_item	2793695	et	3	main
pidama	doc_670731433455_item	2793696	et	4	main
pidama	doc_670731433455_item	2793697	et	4	main
mõnda	doc_670731433455_item	2793698	et	4	main
aega	doc_670731433455_item	2793699	et	4	main
tantsimisest	doc_670731433455_item	2793700	et	4	main
eemal	doc_670731433455_item	2793701	et	3	main
olema	doc_670731433455_item	2793702	et	4	main
olla	doc_670731433455_item	2793703	et	3	main
age	doc_670731433455_item	2793704	et	4	main
ja	doc_670731433455_item	2793705	et	3	main
toomas	doc_670731433455_item	2793706	et	3	main
on	doc_670731433455_item	2793707	et	4	main
otsustanud	doc_670731433455_item	2793708	et	4	main
tantsima	doc_670731433455_item	2793709	et	3	main
tantsida	doc_670731433455_item	2793710	et	3	main
ainult	doc_670731433455_item	2793711	et	4	main
teineteisega	doc_670731433455_item	2793712	et	3	main
paaris	doc_670731433455_item	2793713	et	4	main
kuigi	doc_670731433455_item	2793714	et	3	main
nemad	doc_670731433455_item	2793715	et	3	main
neid	doc_670731433455_item	2793716	et	4	main
on	doc_670731433455_item	2793717	et	4	main
tehtud	doc_670731433455_item	2793718	et	4	main
pakkumisi	doc_670731433455_item	2793719	et	4	main
ka	doc_670731433455_item	2793720	et	3	main
suurele	doc_670731433455_item	2793724	et	4	main
tantsijad	doc_670731433455_item	2793727	et	4	main
tagasihoidlik	doc_670731433455_item	2793728	et	3	main
olnud	doc_670731433455_item	2793680	et	4	main
probleeme	doc_670731433455_item	2793681	et	3	main
tervis	doc_670731433455_item	2793682	et	3	main
tervisega	doc_670731433455_item	2793683	et	3	main
murdsid	doc_670731433455_item	2793687	et	4	main
age	doc_670731433455_item	2793737	et	4	main
ja	doc_670731433455_item	2793738	et	3	main
toomas	doc_670731433455_item	2793739	et	3	main
tahavad	doc_670731433455_item	2793740	et	3	main
veelgi	doc_670731433455_item	2793743	et	4	main
parem	doc_670731433455_item	2793744	et	4	main
märtsis	doc_670731433455_item	2793747	et	3	main
aafrikas	doc_670731433455_item	2793758	et	4	main
kui	doc_670731433455_item	2793759	et	3	main
kaua	doc_670731433455_item	2793760	et	3	main
oks	doc_670731433455_item	2793761	et	3	main
ja	doc_670731433455_item	2793762	et	3	main
püsida	doc_670731433455_item	2793767	et	3	main
ühe	doc_670731433455_item	2793778	et	4	main
kirjutage	doc_670731433455_item	2793781	et	3	main
teksti	doc_670731433455_item	2793785	et	4	main
1	doc_670731433455_item	2793795	et	2	main
soovid	doc_670731433455_item	2793796	et	4	main
annab	doc_670731433455_item	2793821	et	3	main
aega	doc_670731433455_item	2793826	et	4	main
eelise	doc_670731433455_item	2793828	et	4	main
teadmisi	doc_670731433455_item	2793830	et	4	main
et	doc_670731433455_item	2793838	et	3	main
kuul	doc_670731433455_item	2793859	et	4	main
õppematerjalid	doc_670731433455_item	2793861	et	3	main
helikasseti	doc_670731433455_item	2793864	et	4	main
6	doc_670731433455_item	2793865	et	2	main
ning	doc_670731433455_item	2793866	et	3	main
kättesaamisel	doc_670731433455_item	2793873	et	4	main
kodutöö	doc_670731433455_item	2793876	et	4	main
õpetaja	doc_670731433455_item	2793879	et	4	main
selle	doc_670731433455_item	2793881	et	4	main
üle	doc_670731433455_item	2793882	et	3	main
on	doc_670731433455_item	2793895	et	4	main
sobid	doc_670731433455_item	2793907	et	4	main
d	doc_670731433455_item	2793921	et	4	main
vabanduse	doc_670731433455_item	2793927	et	4	main
varanduse	doc_670731433455_item	2793929	et	3	main
tasemele	doc_670731433455_item	2793936	et	3	main
tasakesi	doc_670731433455_item	2793938	et	3	main
5	doc_670731433455_item	2793941	et	2	main
kokku	doc_670731433455_item	2793949	et	3	main
kuid	doc_670731433455_item	2793960	et	4	main
ette	doc_670731433455_item	2793967	et	4	main
d	doc_670731433455_item	2793970	et	4	main
8	doc_670731433455_item	2793972	et	2	main
a	doc_670731433455_item	2793973	et	4	main
kirjutab	doc_670731433455_item	2793974	et	3	main
b	doc_670731433455_item	2793975	et	4	main
palub	doc_670731433455_item	2793976	et	3	main
liikuv	doc_670731433455_item	2793987	et	4	main
a	doc_670731433455_item	2793991	et	4	main
käige	doc_670731433455_item	2793994	et	3	main
elavad	doc_670731433456_item	2794024	et	4	main
inglismal	doc_670731433456_item	2794028	et	4	main
londonis	doc_670731433456_item	2794029	et	4	main
üheksasaja	doc_670731433456_item	2794046	et	4	main
vabakutseline	doc_670731433456_item	2794052	et	4	main
ja	doc_670731433456_item	2794054	et	3	main
armastatakse	doc_670731433456_item	2794062	et	3	main
ning	doc_670731433456_item	2794065	et	3	main
hästi	doc_670731433456_item	2794073	et	3	main
viimased	doc_670731433456_item	2794074	et	3	main
artiklid	doc_670731433456_item	2794075	et	3	main
räägivad	doc_670731433456_item	2794076	et	3	main
noored	doc_670731433456_item	2794077	et	3	main
noortest	doc_670731433456_item	2794078	et	4	main
sugugi	doc_670731433456_item	2794084	et	4	main
alati	doc_670731433456_item	2794085	et	4	main
on	doc_670731433456_item	2794093	et	4	main
olnud	doc_670731433456_item	2794094	et	4	main
probleeme	doc_670731433456_item	2794095	et	3	main
edule	doc_670731433455_item	2793725	et	3	main
elavad	doc_670731433455_item	2793726	et	4	main
on	doc_670731433455_item	2793733	et	4	main
täpselt	doc_670731433455_item	2793734	et	4	main
tulevad	doc_670731433455_item	2793748	et	4	main
tallinn	doc_670731433455_item	2793751	et	4	main
suudavad	doc_670731433455_item	2793766	et	3	main
ütlema	doc_670731433455_item	2793771	et	3	main
nad	doc_670731433455_item	2793773	et	3	main
päeva	doc_670731433455_item	2793779	et	4	main
punkti	doc_670731433455_item	2793792	et	4	main
umbne	doc_670731433455_item	2793798	et	3	main
klassiruum	doc_670731433455_item	2793799	et	3	main
koduõppesüsteem	doc_670731433455_item	2793800	et	3	main
võimaldab	doc_670731433455_item	2793801	et	3	main
sul	doc_670731433455_item	2793802	et	3	main
saada	doc_670731433455_item	2793803	et	4	main
targemaks	doc_670731433455_item	2793804	et	4	main
2	doc_670731433455_item	2793805	et	2	main
just	doc_670731433455_item	2793806	et	3	main
seal	doc_670731433455_item	2793807	et	4	main
kus	doc_670731433455_item	2793808	et	3	main
ja	doc_670731433455_item	2793809	et	3	main
millal	doc_670731433455_item	2793810	et	3	main
sa	doc_670731433455_item	2793811	et	3	main
seda	doc_670731433455_item	2793812	et	3	main
parasjagu	doc_670731433455_item	2793813	et	3	main
soovid	doc_670731433455_item	2793814	et	4	main
käes	doc_670731433455_item	2793815	et	4	main
on	doc_670731433455_item	2793816	et	4	main
interaktiivse	doc_670731433455_item	2793817	et	3	main
õppe	doc_670731433455_item	2793818	et	4	main
ajastu	doc_670731433455_item	2793819	et	4	main
mis	doc_670731433455_item	2793820	et	4	main
vabaduse	doc_670731433455_item	2793824	et	4	main
omandada	doc_670731433455_item	2793829	et	3	main
4	doc_670731433455_item	2793833	et	2	main
tasemele	doc_670731433455_item	2793834	et	3	main
aeg	doc_670731433455_item	2793835	et	3	main
on	doc_670731433455_item	2793836	et	4	main
kokku	doc_670731433455_item	2793841	et	3	main
on	doc_670731433455_item	2793843	et	4	main
vaja	doc_670731433455_item	2793844	et	4	main
ka	doc_670731433455_item	2793845	et	3	main
pisut	doc_670731433455_item	2793846	et	3	main
tarkust	doc_670731433455_item	2793847	et	4	main
kui	doc_670731433455_item	2793848	et	3	main
oled	doc_670731433455_item	2793849	et	3	main
kursusele	doc_670731433455_item	2793850	et	3	main
või	doc_670731433455_item	2793855	et	4	main
kodutöö	doc_670731433455_item	2793867	et	4	main
kursuse	doc_670731433455_item	2793868	et	3	main
7	doc_670731433455_item	2793869	et	2	main
saada	doc_670731433455_item	2793874	et	4	main
lisaküsimustele	doc_670731433455_item	2793892	et	4	main
9	doc_670731433455_item	2793896	et	2	main
tagasihoidlikuna	doc_670731433455_item	2793729	et	3	main
esinemised	doc_670731433455_item	2793732	et	4	main
planeerima	doc_670731433455_item	2793735	et	3	main
plaaneritud	doc_670731433455_item	2793736	et	4	main
paremeni	doc_670731433455_item	2793745	et	4	main
edur	doc_670731433455_item	2793763	et	4	main
veel	doc_670731433455_item	2793764	et	4	main
ei	doc_670731433455_item	2793768	et	4	main
nad	doc_670731433455_item	2793770	et	3	main
ütelda	doc_670731433455_item	2793772	et	4	main
eelistavad	doc_670731433455_item	2793774	et	4	main
elada	doc_670731433455_item	2793775	et	3	main
üks	doc_670731433455_item	2793776	et	3	main
päev	doc_670731433455_item	2793777	et	3	main
kaupa	doc_670731433455_item	2793780	et	4	main
lünka	doc_670731433455_item	2793782	et	4	main
sobiv	doc_670731433455_item	2793783	et	4	main
alt	doc_670731433455_item	2793786	et	4	main
iga	doc_670731433455_item	2793787	et	4	main
sulle	doc_670731433455_item	2793822	et	3	main
planeerida	doc_670731433455_item	2793825	et	3	main
vastavalt	doc_670731433455_item	2793831	et	4	main
individuaalsele	doc_670731433455_item	2793832	et	3	main
5	doc_670731433455_item	2793840	et	2	main
kontorist	doc_670731433455_item	2793854	et	4	main
igal	doc_670731433455_item	2793858	et	3	main
raamatu	doc_670731433455_item	2793862	et	4	main
ja	doc_670731433455_item	2793863	et	3	main
selle	doc_670731433455_item	2793872	et	4	main
meile	doc_670731433455_item	2793877	et	4	main
tagasi	doc_670731433455_item	2793878	et	3	main
vaatab	doc_670731433455_item	2793880	et	3	main
8	doc_670731433455_item	2793883	et	2	main
parandab	doc_670731433455_item	2793884	et	3	main
vead	doc_670731433455_item	2793885	et	4	main
ning	doc_670731433455_item	2793886	et	3	main
vastab	doc_670731433455_item	2793887	et	3	main
vajaduse	doc_670731433455_item	2793888	et	3	main
kõik	doc_670731433455_item	2793893	et	4	main
lihtne	doc_670731433455_item	2793897	et	3	main
tulge	doc_670731433455_item	2793899	et	3	main
virtuaalkodu	doc_670731433455_item	2793901	et	4	main
1	doc_670731433455_item	2793905	et	2	main
a	doc_670731433455_item	2793906	et	4	main
siiski	doc_670731433455_item	2793922	et	4	main
a	doc_670731433455_item	2793924	et	4	main
vajaduse	doc_670731433455_item	2793925	et	3	main
c	doc_670731433455_item	2793928	et	4	main
d	doc_670731433455_item	2793930	et	4	main
vabaduse	doc_670731433455_item	2793931	et	4	main
4	doc_670731433455_item	2793932	et	2	main
b	doc_670731433455_item	2793945	et	4	main
kokku	doc_670731433455_item	2793946	et	3	main
c	doc_670731433455_item	2793959	et	4	main
b	doc_670731433455_item	2793966	et	4	main
eest	doc_670731433455_item	2793969	et	4	main
d	doc_670731433455_item	2793979	et	4	main
a	doc_670731433455_item	2793982	et	4	main
10	doc_670731433455_item	2793990	et	2	main
harjutus	doc_670731433456_item	2793999	et	4	main
avage	doc_670731433456_item	2794000	et	3	main
kirjutage	doc_670731433456_item	2794003	et	3	main
aga	doc_670731433456_item	2794023	et	3	main
london	doc_670731433456_item	2794027	et	4	main
1997a	doc_670731433456_item	2794044	et	4	main
üheksakümne	doc_670731433456_item	2794047	et	4	main
nad	doc_670731433456_item	2794051	et	3	main
neid	doc_670731433456_item	2794063	et	4	main
isegi	doc_670731433456_item	2794066	et	4	main
karmid	doc_670731433456_item	2794067	et	4	main
kriitikud	doc_670731433456_item	2794068	et	3	main
suhtuma	doc_670731433456_item	2794069	et	3	main
ainult	doc_670731433456_item	2794079	et	4	main
ülivõrdes	doc_670731433456_item	2794080	et	3	main
nii	doc_670731433456_item	2794086	et	3	main
ja	doc_670731433456_item	2794090	et	3	main
tervisega	doc_670731433456_item	2794097	et	3	main
murdma	doc_670731433456_item	2794100	et	3	main
nendel	doc_670731433456_item	2794130	et	4	main
on	doc_670731433456_item	2794131	et	4	main
tantsijad	doc_670731433456_item	2794141	et	4	main
esinemised	doc_670731433456_item	2794146	et	4	main
3	doc_670731433455_item	2793823	et	2	main
raha	doc_670731433455_item	2793837	et	4	main
registreerunud	doc_670731433455_item	2793851	et	4	main
lähimast	doc_670731433455_item	2793856	et	4	main
eest	doc_670731433455_item	2793870	et	4	main
korral	doc_670731433455_item	2793889	et	4	main
ka	doc_670731433455_item	2793890	et	3	main
geniaalne	doc_670731433455_item	2793894	et	3	main
10	doc_670731433455_item	2793898	et	2	main
meie	doc_670731433455_item	2793900	et	4	main
b	doc_670731433455_item	2793908	et	4	main
soovid	doc_670731433455_item	2793909	et	4	main
c	doc_670731433455_item	2793910	et	4	main
soovitad	doc_670731433455_item	2793911	et	3	main
d	doc_670731433455_item	2793912	et	4	main
solvud	doc_670731433455_item	2793913	et	3	main
2	doc_670731433455_item	2793914	et	2	main
a	doc_670731433455_item	2793915	et	4	main
just	doc_670731433455_item	2793916	et	3	main
b	doc_670731433455_item	2793917	et	4	main
c	doc_670731433455_item	2793919	et	4	main
kuigi	doc_670731433455_item	2793920	et	3	main
seega	doc_670731433455_item	2793918	et	4	main
b	doc_670731433455_item	2793926	et	4	main
b	doc_670731433455_item	2793935	et	4	main
c	doc_670731433455_item	2793948	et	4	main
6	doc_670731433455_item	2793954	et	2	main
a	doc_670731433455_item	2793955	et	4	main
ning	doc_670731433455_item	2793956	et	3	main
et	doc_670731433455_item	2793962	et	3	main
c	doc_670731433455_item	2793977	et	4	main
parandab	doc_670731433455_item	2793978	et	3	main
lihtne	doc_670731433455_item	2793989	et	3	main
c	doc_670731433455_item	2793995	et	4	main
külastage	doc_670731433455_item	2793996	et	3	main
d	doc_670731433455_item	2793997	et	4	main
minge	doc_670731433455_item	2793998	et	3	main
õige	doc_670731433456_item	2794006	et	4	main
eesti	doc_670731433456_item	2794021	et	4	main
age	doc_670731433456_item	2794030	et	4	main
on	doc_670731433456_item	2794031	et	4	main
on	doc_670731433456_item	2794037	et	4	main
kolmkümend	doc_670731433456_item	2794039	et	4	main
kaks	doc_670731433456_item	2794040	et	3	main
aastat	doc_670731433456_item	2794041	et	3	main
vana	doc_670731433456_item	2794042	et	4	main
alates	doc_670731433456_item	2794043	et	3	main
on	doc_670731433456_item	2794050	et	4	main
vabakutselised	doc_670731433456_item	2794053	et	4	main
esinevad	doc_670731433456_item	2794055	et	4	main
erinevad	doc_670731433456_item	2794056	et	4	main
teatrid	doc_670731433456_item	2794057	et	3	main
väga	doc_670731433456_item	2794064	et	3	main
üldiselt	doc_670731433456_item	2794072	et	4	main
tervis	doc_670731433456_item	2794096	et	3	main
murdis	doc_670731433456_item	2794101	et	3	main
otsustanud	doc_670731433456_item	2794122	et	4	main
tehtud	doc_670731433456_item	2794132	et	4	main
elavad	doc_670731433456_item	2794140	et	4	main
pleneritud	doc_670731433456_item	2794150	et	4	main
veelgi	doc_670731433456_item	2794157	et	4	main
lõuna-aafrikasse	doc_670731433456_item	2794171	et	4	main
sõna	doc_670731433456_item	2794197	et	4	main
vastus	doc_670731433456_item	2794202	et	3	main
õpi	doc_670731433456_item	2794206	et	4	main
seda	doc_670731433456_item	2794225	et	3	main
3	doc_670731433456_item	2794236	et	2	main
teadmisi	doc_670731433456_item	2794243	et	4	main
4	doc_670731433456_item	2794246	et	2	main
tasule	doc_670731433456_item	2794247	et	3	main
aeg	doc_670731433456_item	2794248	et	3	main
3	doc_670731433455_item	2793923	et	2	main
d	doc_670731433455_item	2793939	et	4	main
tasakaalule	doc_670731433455_item	2793940	et	3	main
a	doc_670731433455_item	2793942	et	4	main
kokku	doc_670731433455_item	2793943	et	3	main
saada	doc_670731433455_item	2793944	et	4	main
hoida	doc_670731433455_item	2793950	et	3	main
panna	doc_670731433455_item	2793953	et	4	main
d	doc_670731433455_item	2793961	et	4	main
7	doc_670731433455_item	2793963	et	2	main
a	doc_670731433455_item	2793964	et	4	main
9	doc_670731433455_item	2793981	et	2	main
b	doc_670731433455_item	2793984	et	4	main
libe	doc_670731433455_item	2793985	et	3	main
c	doc_670731433455_item	2793986	et	4	main
sulud	doc_670731433456_item	2794001	et	3	main
sõnadega	doc_670731433456_item	2794004	et	3	main
vastus	doc_670731433456_item	2794007	et	3	main
annab	doc_670731433456_item	2794008	et	3	main
ühe	doc_670731433456_item	2794009	et	4	main
punkti	doc_670731433456_item	2794010	et	4	main
maailmakuulsad	doc_670731433456_item	2794011	et	3	main
balletitantsijad	doc_670731433456_item	2794012	et	3	main
abielupaar	doc_670731433456_item	2794013	et	4	main
age	doc_670731433456_item	2794014	et	4	main
oks	doc_670731433456_item	2794015	et	3	main
ja	doc_670731433456_item	2794016	et	3	main
toomas	doc_670731433456_item	2794017	et	3	main
edur	doc_670731433456_item	2794018	et	4	main
on	doc_670731433456_item	2794019	et	4	main
pärit	doc_670731433456_item	2794020	et	3	main
eestis	doc_670731433456_item	2794022	et	3	main
inglismaa	doc_670731433456_item	2794026	et	4	main
30	doc_670731433456_item	2794032	et	2	main
ja	doc_670731433456_item	2794035	et	3	main
toomas	doc_670731433456_item	2794036	et	3	main
32	doc_670731433456_item	2794038	et	2	main
erinevaid	doc_670731433456_item	2794058	et	4	main
teatreid	doc_670731433456_item	2794059	et	3	main
suhtuvad	doc_670731433456_item	2794070	et	4	main
kuid	doc_670731433456_item	2794081	et	4	main
läinud	doc_670731433456_item	2794088	et	4	main
eriti	doc_670731433456_item	2794091	et	3	main
aastal	doc_670731433456_item	2794099	et	3	main
tantsimiseks	doc_670731433456_item	2794136	et	4	main
vaatamata	doc_670731433456_item	2794137	et	4	main
toomas	doc_670731433456_item	2794153	et	3	main
ja	doc_670731433456_item	2794156	et	3	main
tulevad	doc_670731433456_item	2794162	et	4	main
nad	doc_670731433456_item	2794163	et	3	main
kaua	doc_670731433456_item	2794173	et	3	main
päev	doc_670731433456_item	2794190	et	3	main
õige	doc_670731433456_item	2794201	et	4	main
annab	doc_670731433456_item	2794203	et	3	main
1	doc_670731433456_item	2794208	et	2	main
unusta	doc_670731433456_item	2794210	et	4	main
sa	doc_670731433456_item	2794224	et	3	main
soovid	doc_670731433456_item	2794227	et	4	main
on	doc_670731433456_item	2794229	et	4	main
interaktiivse	doc_670731433456_item	2794230	et	3	main
sada	doc_670731433456_item	2794255	et	4	main
tarkust	doc_670731433456_item	2794260	et	4	main
või	doc_670731433456_item	2794268	et	4	main
postiasutusest	doc_670731433456_item	2794270	et	4	main
igal	doc_670731433456_item	2794271	et	3	main
kuul	doc_670731433456_item	2794272	et	4	main
6	doc_670731433456_item	2794278	et	2	main
kodutöö	doc_670731433456_item	2794280	et	4	main
praegu	doc_670731433456_item	2794025	et	3	main
kolmekümne	doc_670731433456_item	2794033	et	4	main
aastane	doc_670731433456_item	2794034	et	4	main
tuhande	doc_670731433456_item	2794045	et	3	main
seitsmendast	doc_670731433456_item	2794048	et	3	main
aastast	doc_670731433456_item	2794049	et	4	main
inglismaal	doc_670731433456_item	2794060	et	4	main
armastama	doc_670731433456_item	2794061	et	3	main
nendesse	doc_670731433456_item	2794071	et	4	main
kõik	doc_670731433456_item	2794082	et	4	main
pole	doc_670731433456_item	2794083	et	3	main
kergelt	doc_670731433456_item	2794087	et	4	main
mõlemal	doc_670731433456_item	2794089	et	3	main
agel	doc_670731433456_item	2794092	et	4	main
1990	doc_670731433456_item	2794098	et	2	main
noor	doc_670731433456_item	2794102	et	3	main
naine	doc_670731433456_item	2794103	et	3	main
luikede	doc_670731433456_item	2794104	et	3	main
järve	doc_670731433456_item	2794105	et	4	main
etendus	doc_670731433456_item	2794106	et	4	main
etenduse	doc_670731433456_item	2794107	et	4	main
jalaluu	doc_670731433456_item	2794108	et	4	main
ja	doc_670731433456_item	2794109	et	3	main
pidama	doc_670731433456_item	2794110	et	4	main
pidis	doc_670731433456_item	2794111	et	4	main
mõnda	doc_670731433456_item	2794112	et	4	main
aega	doc_670731433456_item	2794113	et	4	main
tantsimisest	doc_670731433456_item	2794114	et	4	main
eemal	doc_670731433456_item	2794115	et	3	main
olema	doc_670731433456_item	2794116	et	4	main
olla	doc_670731433456_item	2794117	et	3	main
age	doc_670731433456_item	2794118	et	4	main
ja	doc_670731433456_item	2794119	et	3	main
toomas	doc_670731433456_item	2794120	et	3	main
on	doc_670731433456_item	2794121	et	4	main
tantsima	doc_670731433456_item	2794123	et	3	main
tantsida	doc_670731433456_item	2794124	et	3	main
ainult	doc_670731433456_item	2794125	et	4	main
teineteisega	doc_670731433456_item	2794126	et	3	main
pakkumisi	doc_670731433456_item	2794133	et	4	main
ka	doc_670731433456_item	2794134	et	3	main
suurele	doc_670731433456_item	2794138	et	4	main
tagasihoidlik	doc_670731433456_item	2794142	et	3	main
nende	doc_670731433456_item	2794144	et	4	main
age	doc_670731433456_item	2794151	et	4	main
ja	doc_670731433456_item	2794152	et	3	main
areneda	doc_670731433456_item	2794155	et	3	main
parem	doc_670731433456_item	2794158	et	4	main
tantsida	doc_670731433456_item	2794160	et	3	main
kui	doc_670731433456_item	2794172	et	3	main
edur	doc_670731433456_item	2794176	et	4	main
tipus	doc_670731433456_item	2794178	et	3	main
suudavad	doc_670731433456_item	2794179	et	3	main
püsida	doc_670731433456_item	2794180	et	3	main
ei	doc_670731433456_item	2794181	et	4	main
oska	doc_670731433456_item	2794182	et	4	main
nad	doc_670731433456_item	2794183	et	3	main
ütlema	doc_670731433456_item	2794184	et	3	main
ühe	doc_670731433456_item	2794191	et	4	main
kaupa	doc_670731433456_item	2794193	et	4	main
teksti	doc_670731433456_item	2794198	et	4	main
paaris	doc_670731433456_item	2794127	et	4	main
kuigi	doc_670731433456_item	2794128	et	3	main
nemad	doc_670731433456_item	2794129	et	3	main
eraldi	doc_670731433456_item	2794135	et	4	main
edule	doc_670731433456_item	2794139	et	3	main
tagasihoidlikuga	doc_670731433456_item	2794143	et	3	main
lähiaja	doc_670731433456_item	2794145	et	3	main
tahavad	doc_670731433456_item	2794154	et	3	main
oks	doc_670731433456_item	2794174	et	3	main
ütleda	doc_670731433456_item	2794185	et	4	main
nad	doc_670731433456_item	2794186	et	3	main
eelistavad	doc_670731433456_item	2794187	et	4	main
elada	doc_670731433456_item	2794188	et	3	main
üks	doc_670731433456_item	2794189	et	3	main
päeva	doc_670731433456_item	2794192	et	4	main
kirjutage	doc_670731433456_item	2794194	et	3	main
iga	doc_670731433456_item	2794200	et	4	main
ühe	doc_670731433456_item	2794204	et	4	main
millal	doc_670731433456_item	2794207	et	3	main
umbne	doc_670731433456_item	2794211	et	3	main
klassiruum	doc_670731433456_item	2794212	et	3	main
koduõppesüsteem	doc_670731433456_item	2794213	et	3	main
võimaldab	doc_670731433456_item	2794214	et	3	main
soovid	doc_670731433456_item	2794209	et	4	main
sul	doc_670731433456_item	2794215	et	3	main
saada	doc_670731433456_item	2794216	et	4	main
targemaks	doc_670731433456_item	2794217	et	4	main
2	doc_670731433456_item	2794218	et	2	main
just	doc_670731433456_item	2794219	et	3	main
seal	doc_670731433456_item	2794220	et	4	main
kus	doc_670731433456_item	2794221	et	3	main
parasjagu	doc_670731433456_item	2794226	et	3	main
ajastu	doc_670731433456_item	2794232	et	4	main
eelise	doc_670731433456_item	2794241	et	4	main
omandada	doc_670731433456_item	2794242	et	3	main
vastavalt	doc_670731433456_item	2794244	et	4	main
individuaalsele	doc_670731433456_item	2794245	et	3	main
vaja	doc_670731433456_item	2794257	et	4	main
pisut	doc_670731433456_item	2794259	et	3	main
oled	doc_670731433456_item	2794262	et	3	main
kätte	doc_670731433456_item	2794273	et	4	main
helikasseti	doc_670731433456_item	2794277	et	4	main
meile	doc_670731433456_item	2794290	et	4	main
tagasi	doc_670731433456_item	2794291	et	3	main
ning	doc_670731433456_item	2794299	et	3	main
soovitad	doc_670731433456_item	2794324	et	3	main
solvud	doc_670731433456_item	2794326	et	3	main
a	doc_670731433456_item	2794328	et	4	main
seega	doc_670731433456_item	2794331	et	4	main
kuigi	doc_670731433456_item	2794333	et	3	main
vabanduse	doc_670731433456_item	2794340	et	4	main
d	doc_670731433456_item	2794343	et	4	main
vabaduse	doc_670731433456_item	2794344	et	4	main
4	doc_670731433456_item	2794345	et	2	main
kokku	doc_670731433456_item	2794362	et	3	main
kokku	doc_670731433456_item	2794365	et	3	main
d	doc_670731433456_item	2794374	et	4	main
et	doc_670731433456_item	2794375	et	3	main
a	doc_670731433456_item	2794377	et	4	main
taga	doc_670731433456_item	2794378	et	4	main
c	doc_670731433456_item	2794381	et	4	main
eest	doc_670731433456_item	2794382	et	4	main
d	doc_670731433456_item	2794383	et	4	main
annab	doc_670731433457_item	2794421	et	3	main
eestis	doc_670731433457_item	2794435	et	3	main
aga	doc_670731433457_item	2794436	et	3	main
elavad	doc_670731433457_item	2794437	et	4	main
londonil	doc_670731433457_item	2794442	et	4	main
30	doc_670731433457_item	2794445	et	2	main
kümne	doc_670731433457_item	2794454	et	4	main
väga	doc_670731433457_item	2794478	et	3	main
suhtuma	doc_670731433457_item	2794483	et	3	main
on	doc_670731433456_item	2794147	et	4	main
täpselt	doc_670731433456_item	2794148	et	4	main
planeerima	doc_670731433456_item	2794149	et	3	main
parem	doc_670731433456_item	2794159	et	4	main
märtsis	doc_670731433456_item	2794161	et	3	main
esinema	doc_670731433456_item	2794164	et	3	main
tallinn	doc_670731433456_item	2794165	et	4	main
tallinnasse	doc_670731433456_item	2794166	et	3	main
ja	doc_670731433456_item	2794167	et	3	main
seejärel	doc_670731433456_item	2794168	et	3	main
sõidavad	doc_670731433456_item	2794169	et	3	main
lõuna-aafrika	doc_670731433456_item	2794170	et	4	main
ja	doc_670731433456_item	2794175	et	3	main
veel	doc_670731433456_item	2794177	et	4	main
lünka	doc_670731433456_item	2794195	et	4	main
sobiv	doc_670731433456_item	2794196	et	4	main
alt	doc_670731433456_item	2794199	et	4	main
punkti	doc_670731433456_item	2794205	et	4	main
ja	doc_670731433456_item	2794222	et	3	main
mis	doc_670731433456_item	2794233	et	4	main
annab	doc_670731433456_item	2794234	et	3	main
sulle	doc_670731433456_item	2794235	et	3	main
vabaduse	doc_670731433456_item	2794237	et	4	main
planeerida	doc_670731433456_item	2794238	et	3	main
aega	doc_670731433456_item	2794239	et	4	main
ning	doc_670731433456_item	2794240	et	3	main
on	doc_670731433456_item	2794256	et	4	main
kursusele	doc_670731433456_item	2794263	et	3	main
saad	doc_670731433456_item	2794265	et	4	main
meie	doc_670731433456_item	2794266	et	4	main
lähimast	doc_670731433456_item	2794269	et	4	main
ja	doc_670731433456_item	2794276	et	3	main
kättesaamisel	doc_670731433456_item	2794286	et	4	main
õpetaja	doc_670731433456_item	2794292	et	4	main
vastab	doc_670731433456_item	2794300	et	3	main
b	doc_670731433456_item	2794321	et	4	main
d	doc_670731433456_item	2794325	et	4	main
a	doc_670731433456_item	2794346	et	4	main
tasule	doc_670731433456_item	2794347	et	3	main
kokku	doc_670731433456_item	2794356	et	3	main
kokku	doc_670731433456_item	2794359	et	3	main
liita	doc_670731433456_item	2794360	et	4	main
hoida	doc_670731433456_item	2794363	et	3	main
kuid	doc_670731433456_item	2794373	et	4	main
ees	doc_670731433456_item	2794384	et	4	main
8	doc_670731433456_item	2794385	et	2	main
millal	doc_670731433456_item	2794223	et	3	main
käes	doc_670731433456_item	2794228	et	4	main
õppe	doc_670731433456_item	2794231	et	4	main
ka	doc_670731433456_item	2794258	et	3	main
kui	doc_670731433456_item	2794261	et	3	main
registreerunud	doc_670731433456_item	2794264	et	4	main
õppematerjalid	doc_670731433456_item	2794274	et	3	main
kursuse	doc_670731433456_item	2794281	et	3	main
eest	doc_670731433456_item	2794283	et	4	main
parandab	doc_670731433456_item	2794297	et	3	main
lisaküsimustele	doc_670731433456_item	2794305	et	4	main
kõik	doc_670731433456_item	2794306	et	4	main
geniaalne	doc_670731433456_item	2794307	et	3	main
on	doc_670731433456_item	2794308	et	4	main
9	doc_670731433456_item	2794309	et	2	main
lihtne	doc_670731433456_item	2794310	et	3	main
10	doc_670731433456_item	2794311	et	2	main
tulge	doc_670731433456_item	2794312	et	3	main
meie	doc_670731433456_item	2794313	et	4	main
virtuaalkodu	doc_670731433456_item	2794314	et	4	main
või	doc_670731433456_item	2794315	et	4	main
postitage	doc_670731433456_item	2794316	et	3	main
kupong	doc_670731433456_item	2794317	et	3	main
1	doc_670731433456_item	2794318	et	2	main
a	doc_670731433456_item	2794319	et	4	main
sobid	doc_670731433456_item	2794320	et	4	main
c	doc_670731433456_item	2794323	et	4	main
3	doc_670731433456_item	2794336	et	2	main
b	doc_670731433456_item	2794339	et	4	main
c	doc_670731433456_item	2794341	et	4	main
c	doc_670731433456_item	2794350	et	4	main
tasakesi	doc_670731433456_item	2794351	et	3	main
d	doc_670731433456_item	2794352	et	4	main
tasakaalule	doc_670731433456_item	2794353	et	3	main
5	doc_670731433456_item	2794354	et	2	main
a	doc_670731433456_item	2794355	et	4	main
b	doc_670731433456_item	2794358	et	4	main
d	doc_670731433456_item	2794364	et	4	main
panna	doc_670731433456_item	2794366	et	4	main
a	doc_670731433456_item	2794368	et	4	main
ning	doc_670731433456_item	2794369	et	3	main
b	doc_670731433456_item	2794370	et	4	main
vaid	doc_670731433456_item	2794371	et	3	main
a	doc_670731433456_item	2794386	et	4	main
kirjutab	doc_670731433456_item	2794387	et	3	main
ühe	doc_670731433457_item	2794422	et	4	main
abielupaar	doc_670731433457_item	2794426	et	4	main
oks	doc_670731433457_item	2794428	et	3	main
ja	doc_670731433457_item	2794429	et	3	main
edur	doc_670731433457_item	2794431	et	4	main
on	doc_670731433457_item	2794432	et	4	main
pärit	doc_670731433457_item	2794433	et	3	main
inglismaalt	doc_670731433457_item	2794441	et	3	main
toomas	doc_670731433457_item	2794450	et	3	main
32	doc_670731433457_item	2794452	et	2	main
kolme	doc_670731433457_item	2794453	et	4	main
esinevad	doc_670731433457_item	2794469	et	4	main
armastama	doc_670731433457_item	2794475	et	3	main
hästi	doc_670731433457_item	2794487	et	3	main
viimased	doc_670731433457_item	2794488	et	3	main
artiklid	doc_670731433457_item	2794489	et	3	main
räägivad	doc_670731433457_item	2794490	et	3	main
noored	doc_670731433457_item	2794491	et	3	main
kõik	doc_670731433457_item	2794496	et	4	main
alati	doc_670731433457_item	2794499	et	4	main
mõlemal	doc_670731433457_item	2794503	et	3	main
on	doc_670731433456_item	2794249	et	4	main
raha	doc_670731433456_item	2794250	et	4	main
et	doc_670731433456_item	2794251	et	3	main
seda	doc_670731433456_item	2794252	et	3	main
5	doc_670731433456_item	2794253	et	2	main
kokku	doc_670731433456_item	2794254	et	3	main
kontorist	doc_670731433456_item	2794267	et	4	main
raamatu	doc_670731433456_item	2794275	et	4	main
vaid	doc_670731433456_item	2794279	et	3	main
saada	doc_670731433456_item	2794287	et	4	main
vaatab	doc_670731433456_item	2794293	et	3	main
selle	doc_670731433456_item	2794294	et	4	main
üle	doc_670731433456_item	2794295	et	3	main
8	doc_670731433456_item	2794296	et	2	main
vajaduse	doc_670731433456_item	2794301	et	3	main
ka	doc_670731433456_item	2794303	et	3	main
7	doc_670731433456_item	2794282	et	2	main
tasud	doc_670731433456_item	2794284	et	4	main
selle	doc_670731433456_item	2794285	et	4	main
täidetud	doc_670731433456_item	2794288	et	4	main
kodutöö	doc_670731433456_item	2794289	et	4	main
vead	doc_670731433456_item	2794298	et	4	main
korral	doc_670731433456_item	2794302	et	4	main
tekkinud	doc_670731433456_item	2794304	et	4	main
soovid	doc_670731433456_item	2794322	et	4	main
b	doc_670731433456_item	2794330	et	4	main
siiski	doc_670731433456_item	2794335	et	4	main
vajaduse	doc_670731433456_item	2794338	et	3	main
varanduse	doc_670731433456_item	2794342	et	3	main
saada	doc_670731433456_item	2794357	et	4	main
c	doc_670731433456_item	2794372	et	4	main
b	doc_670731433456_item	2794379	et	4	main
balletitantsijad	doc_670731433457_item	2794425	et	3	main
inglismaa	doc_670731433457_item	2794439	et	4	main
age	doc_670731433457_item	2794443	et	4	main
kolm	doc_670731433457_item	2794446	et	3	main
aastane	doc_670731433457_item	2794448	et	4	main
ja	doc_670731433457_item	2794449	et	3	main
teatris	doc_670731433457_item	2794473	et	3	main
armastad	doc_670731433457_item	2794476	et	3	main
karmid	doc_670731433457_item	2794481	et	4	main
suhtuda	doc_670731433457_item	2794484	et	3	main
nendesse	doc_670731433457_item	2794485	et	4	main
nii	doc_670731433457_item	2794500	et	3	main
agel	doc_670731433457_item	2794506	et	4	main
etendus	doc_670731433457_item	2794520	et	4	main
jalaluu	doc_670731433457_item	2794522	et	4	main
ja	doc_670731433457_item	2794523	et	3	main
tantsimisest	doc_670731433457_item	2794528	et	4	main
eemal	doc_670731433457_item	2794529	et	3	main
age	doc_670731433457_item	2794532	et	4	main
toomas	doc_670731433457_item	2794534	et	3	main
nende	doc_670731433457_item	2794558	et	4	main
lähiaja	doc_670731433457_item	2794559	et	3	main
esinemised	doc_670731433457_item	2794560	et	4	main
parem	doc_670731433457_item	2794572	et	4	main
seejärel	doc_670731433457_item	2794582	et	3	main
sõidavad	doc_670731433457_item	2794583	et	3	main
lõuna-aafrika	doc_670731433457_item	2794584	et	4	main
ütlevad	doc_670731433457_item	2794599	et	4	main
millal	doc_670731433457_item	2794621	et	3	main
umbne	doc_670731433457_item	2794625	et	3	main
sa	doc_670731433457_item	2794638	et	3	main
soovid	doc_670731433457_item	2794641	et	4	main
on	doc_670731433457_item	2794643	et	4	main
mis	doc_670731433457_item	2794647	et	4	main
ning	doc_670731433457_item	2794654	et	3	main
eelise	doc_670731433457_item	2794655	et	4	main
omandada	doc_670731433457_item	2794656	et	3	main
teadmisi	doc_670731433457_item	2794657	et	4	main
aeg	doc_670731433457_item	2794662	et	3	main
raha	doc_670731433457_item	2794664	et	4	main
kokku	doc_670731433457_item	2794668	et	3	main
saada	doc_670731433457_item	2794669	et	4	main
et	doc_670731433457_item	2794693	et	3	main
7	doc_670731433457_item	2794696	et	2	main
ees	doc_670731433457_item	2794697	et	4	main
saada	doc_670731433457_item	2794701	et	4	main
kodutöö	doc_670731433457_item	2794703	et	4	main
parandab	doc_670731433457_item	2794711	et	3	main
geniaalne	doc_670731433457_item	2794721	et	3	main
virtuaalkodu	doc_670731433457_item	2794728	et	4	main
a	doc_670731433457_item	2794733	et	4	main
d	doc_670731433457_item	2794739	et	4	main
solvud	doc_670731433457_item	2794740	et	3	main
seega	doc_670731433457_item	2794745	et	4	main
d	doc_670731433457_item	2794748	et	4	main
siiski	doc_670731433457_item	2794749	et	4	main
3	doc_670731433457_item	2794750	et	2	main
b	doc_670731433457_item	2794762	et	4	main
tasemele	doc_670731433457_item	2794763	et	3	main
5	doc_670731433457_item	2794768	et	2	main
kokku	doc_670731433457_item	2794770	et	3	main
b	doc_670731433457_item	2794772	et	4	main
kokku	doc_670731433457_item	2794773	et	3	main
c	doc_670731433457_item	2794786	et	4	main
ette	doc_670731433457_item	2794794	et	4	main
a	doc_670731433457_item	2794800	et	4	main
2	doc_670731433456_item	2794327	et	2	main
just	doc_670731433456_item	2794329	et	3	main
c	doc_670731433456_item	2794332	et	4	main
d	doc_670731433456_item	2794334	et	4	main
a	doc_670731433456_item	2794337	et	4	main
b	doc_670731433456_item	2794348	et	4	main
tasemele	doc_670731433456_item	2794349	et	3	main
c	doc_670731433456_item	2794361	et	4	main
6	doc_670731433456_item	2794367	et	2	main
7	doc_670731433456_item	2794376	et	2	main
ette	doc_670731433456_item	2794380	et	4	main
b	doc_670731433456_item	2794388	et	4	main
palub	doc_670731433456_item	2794389	et	3	main
c	doc_670731433456_item	2794390	et	4	main
parandab	doc_670731433456_item	2794391	et	3	main
d	doc_670731433456_item	2794392	et	4	main
muudab	doc_670731433456_item	2794393	et	3	main
9	doc_670731433456_item	2794394	et	2	main
a	doc_670731433456_item	2794395	et	4	main
liigne	doc_670731433456_item	2794396	et	3	main
b	doc_670731433456_item	2794397	et	4	main
libe	doc_670731433456_item	2794398	et	3	main
c	doc_670731433456_item	2794399	et	4	main
liikuv	doc_670731433456_item	2794400	et	4	main
d	doc_670731433456_item	2794401	et	4	main
lihtne	doc_670731433456_item	2794402	et	3	main
10	doc_670731433456_item	2794403	et	2	main
a	doc_670731433456_item	2794404	et	4	main
tulge	doc_670731433456_item	2794405	et	3	main
b	doc_670731433456_item	2794406	et	4	main
käige	doc_670731433456_item	2794407	et	3	main
c	doc_670731433456_item	2794408	et	4	main
külastage	doc_670731433456_item	2794409	et	3	main
d	doc_670731433456_item	2794410	et	4	main
minge	doc_670731433456_item	2794411	et	3	main
harjutus	doc_670731433457_item	2794412	et	4	main
avage	doc_670731433457_item	2794413	et	3	main
sulud	doc_670731433457_item	2794414	et	3	main
numbrid	doc_670731433457_item	2794415	et	3	main
kirjutage	doc_670731433457_item	2794416	et	3	main
sõnadega	doc_670731433457_item	2794417	et	3	main
iga	doc_670731433457_item	2794418	et	4	main
õige	doc_670731433457_item	2794419	et	4	main
vastus	doc_670731433457_item	2794420	et	3	main
punkti	doc_670731433457_item	2794423	et	4	main
age	doc_670731433457_item	2794427	et	4	main
toomas	doc_670731433457_item	2794430	et	3	main
praegu	doc_670731433457_item	2794438	et	3	main
london	doc_670731433457_item	2794440	et	4	main
on	doc_670731433457_item	2794444	et	4	main
maailmakuulsad	doc_670731433457_item	2794424	et	3	main
eesti	doc_670731433457_item	2794434	et	4	main
kümne	doc_670731433457_item	2794447	et	4	main
on	doc_670731433457_item	2794451	et	4	main
alates	doc_670731433457_item	2794458	et	3	main
vana	doc_670731433457_item	2794457	et	4	main
aastat	doc_670731433457_item	2794456	et	3	main
1997a	doc_670731433457_item	2794459	et	4	main
tuhad	doc_670731433457_item	2794460	et	3	main
üheksasaja	doc_670731433457_item	2794461	et	4	main
üheksakümne	doc_670731433457_item	2794462	et	4	main
seitsmest	doc_670731433457_item	2794463	et	4	main
on	doc_670731433457_item	2794464	et	4	main
nad	doc_670731433457_item	2794465	et	3	main
vabakutseline	doc_670731433457_item	2794466	et	4	main
vabakutseliste	doc_670731433457_item	2794467	et	4	main
ja	doc_670731433457_item	2794468	et	3	main
kaks	doc_670731433457_item	2794455	et	3	main
erinevad	doc_670731433457_item	2794472	et	4	main
ning	doc_670731433457_item	2794479	et	3	main
pole	doc_670731433457_item	2794497	et	3	main
sugugi	doc_670731433457_item	2794498	et	4	main
järve	doc_670731433457_item	2794519	et	4	main
etendust	doc_670731433457_item	2794521	et	4	main
pidama	doc_670731433457_item	2794524	et	4	main
pidada	doc_670731433457_item	2794525	et	4	main
olema	doc_670731433457_item	2794530	et	4	main
ja	doc_670731433457_item	2794533	et	3	main
nemad	doc_670731433457_item	2794543	et	3	main
tehtud	doc_670731433457_item	2794546	et	4	main
edur	doc_670731433457_item	2794590	et	4	main
veel	doc_670731433457_item	2794591	et	4	main
tipus	doc_670731433457_item	2794592	et	3	main
suudavad	doc_670731433457_item	2794593	et	3	main
püsida	doc_670731433457_item	2794594	et	3	main
ei	doc_670731433457_item	2794595	et	4	main
oska	doc_670731433457_item	2794596	et	4	main
soovid	doc_670731433457_item	2794623	et	4	main
ja	doc_670731433457_item	2794636	et	3	main
parasjagu	doc_670731433457_item	2794640	et	3	main
käes	doc_670731433457_item	2794642	et	4	main
interaktiivse	doc_670731433457_item	2794644	et	3	main
3	doc_670731433457_item	2794650	et	2	main
vastavalt	doc_670731433457_item	2794658	et	4	main
on	doc_670731433457_item	2794663	et	4	main
5	doc_670731433457_item	2794667	et	2	main
raamatu	doc_670731433457_item	2794689	et	4	main
helikasseti	doc_670731433457_item	2794691	et	4	main
kodutöö	doc_670731433457_item	2794694	et	4	main
kursuse	doc_670731433457_item	2794695	et	3	main
meile	doc_670731433457_item	2794704	et	4	main
tagasi	doc_670731433457_item	2794705	et	3	main
selle	doc_670731433457_item	2794708	et	4	main
kõik	doc_670731433457_item	2794720	et	4	main
on	doc_670731433457_item	2794722	et	4	main
meie	doc_670731433457_item	2794727	et	4	main
c	doc_670731433457_item	2794737	et	4	main
soovitad	doc_670731433457_item	2794738	et	3	main
a	doc_670731433457_item	2794751	et	4	main
vajaduse	doc_670731433457_item	2794752	et	3	main
c	doc_670731433457_item	2794755	et	4	main
varanduse	doc_670731433457_item	2794756	et	3	main
c	doc_670731433457_item	2794764	et	4	main
tasakesi	doc_670731433457_item	2794765	et	3	main
hoida	doc_670731433457_item	2794777	et	3	main
taga	doc_670731433457_item	2794792	et	4	main
d	doc_670731433457_item	2794797	et	4	main
liikuv	doc_670731433457_item	2794814	et	4	main
d	doc_670731433457_item	2794815	et	4	main
10	doc_670731433457_item	2794817	et	2	main
a	doc_670731433457_item	2794818	et	4	main
minge	doc_670731433457_item	2794825	et	3	main
kirjutage	doc_670731433458_item	2794830	et	3	main
iga	doc_670731433458_item	2794832	et	4	main
vastus	doc_670731433458_item	2794834	et	3	main
annab	doc_670731433458_item	2794835	et	3	main
ühe	doc_670731433458_item	2794836	et	4	main
edur	doc_670731433458_item	2794845	et	4	main
on	doc_670731433458_item	2794846	et	4	main
pärit	doc_670731433458_item	2794847	et	3	main
kolmkümne	doc_670731433458_item	2794860	et	4	main
toomas	doc_670731433458_item	2794863	et	3	main
1997a	doc_670731433458_item	2794872	et	4	main
ainult	doc_670731433458_item	2794908	et	4	main
sugugi	doc_670731433458_item	2794913	et	4	main
alati	doc_670731433458_item	2794914	et	4	main
nii	doc_670731433458_item	2794915	et	3	main
mõlemal	doc_670731433458_item	2794918	et	3	main
agel	doc_670731433458_item	2794921	et	4	main
olnud	doc_670731433458_item	2794923	et	4	main
probleeme	doc_670731433458_item	2794924	et	3	main
tervis	doc_670731433458_item	2794925	et	3	main
murdma	doc_670731433458_item	2794929	et	3	main
murdab	doc_670731433458_item	2794930	et	4	main
noor	doc_670731433458_item	2794931	et	3	main
naine	doc_670731433458_item	2794932	et	3	main
luikede	doc_670731433458_item	2794933	et	3	main
aega	doc_670731433458_item	2794942	et	4	main
otsustanud	doc_670731433458_item	2794951	et	4	main
erinevad	doc_670731433457_item	2794470	et	4	main
teatrid	doc_670731433457_item	2794471	et	3	main
inglismaal	doc_670731433457_item	2794474	et	4	main
neid	doc_670731433457_item	2794477	et	4	main
isegi	doc_670731433457_item	2794480	et	4	main
kriitikud	doc_670731433457_item	2794482	et	3	main
kuid	doc_670731433457_item	2794495	et	4	main
kergelt	doc_670731433457_item	2794501	et	4	main
olnud	doc_670731433457_item	2794508	et	4	main
probleeme	doc_670731433457_item	2794509	et	3	main
tervis	doc_670731433457_item	2794510	et	3	main
tervistele	doc_670731433457_item	2794511	et	3	main
1990	doc_670731433457_item	2794512	et	2	main
aastal	doc_670731433457_item	2794513	et	3	main
murdma	doc_670731433457_item	2794514	et	3	main
muru	doc_670731433457_item	2794515	et	4	main
noor	doc_670731433457_item	2794516	et	3	main
naine	doc_670731433457_item	2794517	et	3	main
luikede	doc_670731433457_item	2794518	et	3	main
neil	doc_670731433457_item	2794544	et	4	main
vaatamata	doc_670731433457_item	2794551	et	4	main
täpselt	doc_670731433457_item	2794562	et	4	main
planeerima	doc_670731433457_item	2794563	et	3	main
planeerida	doc_670731433457_item	2794564	et	3	main
tulevad	doc_670731433457_item	2794576	et	4	main
nad	doc_670731433457_item	2794577	et	3	main
esinema	doc_670731433457_item	2794578	et	3	main
ütlema	doc_670731433457_item	2794598	et	3	main
1	doc_670731433457_item	2794622	et	2	main
unusta	doc_670731433457_item	2794624	et	4	main
võimaldab	doc_670731433457_item	2794628	et	3	main
saada	doc_670731433457_item	2794630	et	4	main
siiski	doc_670731433457_item	2794633	et	4	main
seda	doc_670731433457_item	2794639	et	3	main
sulle	doc_670731433457_item	2794649	et	3	main
planeerida	doc_670731433457_item	2794652	et	3	main
individuaalsele	doc_670731433457_item	2794659	et	3	main
tasud	doc_670731433457_item	2794698	et	4	main
selle	doc_670731433457_item	2794699	et	4	main
õpetaja	doc_670731433457_item	2794706	et	4	main
üle	doc_670731433457_item	2794709	et	3	main
lisaküsimustele	doc_670731433457_item	2794719	et	4	main
lihtne	doc_670731433457_item	2794724	et	3	main
käige	doc_670731433457_item	2794726	et	3	main
postitage	doc_670731433457_item	2794730	et	3	main
1	doc_670731433457_item	2794732	et	2	main
sobid	doc_670731433457_item	2794734	et	4	main
b	doc_670731433457_item	2794735	et	4	main
b	doc_670731433457_item	2794753	et	4	main
d	doc_670731433457_item	2794757	et	4	main
vabaduse	doc_670731433457_item	2794758	et	4	main
4	doc_670731433457_item	2794759	et	2	main
d	doc_670731433457_item	2794766	et	4	main
a	doc_670731433457_item	2794769	et	4	main
saada	doc_670731433457_item	2794771	et	4	main
liita	doc_670731433457_item	2794774	et	4	main
b	doc_670731433457_item	2794793	et	4	main
ees	doc_670731433457_item	2794798	et	4	main
8	doc_670731433457_item	2794799	et	2	main
c	doc_670731433457_item	2794804	et	4	main
muudab	doc_670731433457_item	2794807	et	3	main
a	doc_670731433457_item	2794809	et	4	main
liigne	doc_670731433457_item	2794810	et	3	main
b	doc_670731433457_item	2794811	et	4	main
libe	doc_670731433457_item	2794812	et	3	main
c	doc_670731433457_item	2794813	et	4	main
käige	doc_670731433457_item	2794821	et	3	main
punkti	doc_670731433458_item	2794837	et	4	main
maailmakuulsad	doc_670731433458_item	2794838	et	3	main
eesti	doc_670731433458_item	2794848	et	4	main
eestist	doc_670731433458_item	2794849	et	3	main
elavad	doc_670731433458_item	2794851	et	4	main
praegu	doc_670731433458_item	2794852	et	3	main
age	doc_670731433458_item	2794857	et	4	main
ja	doc_670731433458_item	2794862	et	3	main
32	doc_670731433458_item	2794865	et	2	main
kümmend	doc_670731433458_item	2794867	et	4	main
aastat	doc_670731433458_item	2794869	et	3	main
ülivõrdes	doc_670731433458_item	2794909	et	3	main
pole	doc_670731433458_item	2794912	et	3	main
ja	doc_670731433458_item	2794919	et	3	main
etendus	doc_670731433458_item	2794935	et	4	main
üldiselt	doc_670731433457_item	2794486	et	4	main
noortele	doc_670731433457_item	2794492	et	3	main
ainult	doc_670731433457_item	2794493	et	4	main
ülivõrdes	doc_670731433457_item	2794494	et	3	main
läinud	doc_670731433457_item	2794502	et	4	main
ja	doc_670731433457_item	2794504	et	3	main
mõnda	doc_670731433457_item	2794526	et	4	main
aega	doc_670731433457_item	2794527	et	4	main
on	doc_670731433457_item	2794531	et	4	main
on	doc_670731433457_item	2794535	et	4	main
otsustanud	doc_670731433457_item	2794536	et	4	main
tantsima	doc_670731433457_item	2794537	et	3	main
tantsida	doc_670731433457_item	2794538	et	3	main
ainult	doc_670731433457_item	2794539	et	4	main
teineteisega	doc_670731433457_item	2794540	et	3	main
paaris	doc_670731433457_item	2794541	et	4	main
kuigi	doc_670731433457_item	2794542	et	3	main
on	doc_670731433457_item	2794545	et	4	main
pakkumisi	doc_670731433457_item	2794547	et	4	main
ka	doc_670731433457_item	2794548	et	3	main
eraldi	doc_670731433457_item	2794549	et	4	main
suurele	doc_670731433457_item	2794552	et	4	main
edule	doc_670731433457_item	2794553	et	3	main
on	doc_670731433457_item	2794561	et	4	main
paremale	doc_670731433457_item	2794573	et	4	main
tantsida	doc_670731433457_item	2794574	et	3	main
märtsis	doc_670731433457_item	2794575	et	3	main
lõuna-aafrikale	doc_670731433457_item	2794585	et	4	main
kui	doc_670731433457_item	2794586	et	3	main
kaua	doc_670731433457_item	2794587	et	3	main
oks	doc_670731433457_item	2794588	et	3	main
ja	doc_670731433457_item	2794589	et	3	main
nad	doc_670731433457_item	2794597	et	3	main
eriti	doc_670731433457_item	2794505	et	3	main
on	doc_670731433457_item	2794507	et	4	main
tantsimiseks	doc_670731433457_item	2794550	et	4	main
elavad	doc_670731433457_item	2794554	et	4	main
tantsijad	doc_670731433457_item	2794555	et	4	main
tagasihoidlik	doc_670731433457_item	2794556	et	3	main
tagasihoidliku	doc_670731433457_item	2794557	et	3	main
age	doc_670731433457_item	2794565	et	4	main
ja	doc_670731433457_item	2794566	et	3	main
toomas	doc_670731433457_item	2794567	et	3	main
tahavad	doc_670731433457_item	2794568	et	3	main
areneda	doc_670731433457_item	2794569	et	3	main
ja	doc_670731433457_item	2794570	et	3	main
veelgi	doc_670731433457_item	2794571	et	4	main
tallinn	doc_670731433457_item	2794579	et	4	main
tallinnas	doc_670731433457_item	2794580	et	4	main
ja	doc_670731433457_item	2794581	et	3	main
nad	doc_670731433457_item	2794600	et	3	main
elada	doc_670731433457_item	2794602	et	3	main
eelistavad	doc_670731433457_item	2794601	et	4	main
üks	doc_670731433457_item	2794603	et	3	main
päev	doc_670731433457_item	2794604	et	3	main
ühe	doc_670731433457_item	2794605	et	4	main
päeva	doc_670731433457_item	2794606	et	4	main
kaupa	doc_670731433457_item	2794607	et	4	main
kirjutage	doc_670731433457_item	2794608	et	3	main
lünka	doc_670731433457_item	2794609	et	4	main
sõna	doc_670731433457_item	2794611	et	4	main
sobiv	doc_670731433457_item	2794610	et	4	main
teksti	doc_670731433457_item	2794612	et	4	main
alt	doc_670731433457_item	2794613	et	4	main
iga	doc_670731433457_item	2794614	et	4	main
õige	doc_670731433457_item	2794615	et	4	main
vastus	doc_670731433457_item	2794616	et	3	main
annab	doc_670731433457_item	2794617	et	3	main
ühe	doc_670731433457_item	2794618	et	4	main
punkti	doc_670731433457_item	2794619	et	4	main
õpi	doc_670731433457_item	2794620	et	4	main
klassiruum	doc_670731433457_item	2794626	et	3	main
targemaks	doc_670731433457_item	2794631	et	4	main
seal	doc_670731433457_item	2794634	et	4	main
kus	doc_670731433457_item	2794635	et	3	main
4	doc_670731433457_item	2794660	et	2	main
seda	doc_670731433457_item	2794666	et	3	main
täidetud	doc_670731433457_item	2794702	et	4	main
koduõppesüsteem	doc_670731433457_item	2794627	et	3	main
sul	doc_670731433457_item	2794629	et	3	main
2	doc_670731433457_item	2794632	et	2	main
millal	doc_670731433457_item	2794637	et	3	main
õppe	doc_670731433457_item	2794645	et	4	main
ajastu	doc_670731433457_item	2794646	et	4	main
annab	doc_670731433457_item	2794648	et	3	main
vabaduse	doc_670731433457_item	2794651	et	4	main
aega	doc_670731433457_item	2794653	et	4	main
tasemele	doc_670731433457_item	2794661	et	3	main
et	doc_670731433457_item	2794665	et	3	main
on	doc_670731433457_item	2794670	et	4	main
vaja	doc_670731433457_item	2794671	et	4	main
ka	doc_670731433457_item	2794672	et	3	main
pisut	doc_670731433457_item	2794673	et	3	main
tarkust	doc_670731433457_item	2794674	et	4	main
kui	doc_670731433457_item	2794675	et	3	main
oled	doc_670731433457_item	2794676	et	3	main
kursusele	doc_670731433457_item	2794677	et	3	main
registreerunud	doc_670731433457_item	2794678	et	4	main
saad	doc_670731433457_item	2794679	et	4	main
meie	doc_670731433457_item	2794680	et	4	main
kontorist	doc_670731433457_item	2794681	et	4	main
või	doc_670731433457_item	2794682	et	4	main
lähimast	doc_670731433457_item	2794683	et	4	main
postiasutusest	doc_670731433457_item	2794684	et	4	main
igal	doc_670731433457_item	2794685	et	3	main
kuul	doc_670731433457_item	2794686	et	4	main
kätte	doc_670731433457_item	2794687	et	4	main
õppematerjalid	doc_670731433457_item	2794688	et	3	main
ja	doc_670731433457_item	2794690	et	3	main
6	doc_670731433457_item	2794692	et	2	main
kättesaamisel	doc_670731433457_item	2794700	et	4	main
vaatab	doc_670731433457_item	2794707	et	3	main
8	doc_670731433457_item	2794710	et	2	main
vead	doc_670731433457_item	2794712	et	4	main
ning	doc_670731433457_item	2794713	et	3	main
vastab	doc_670731433457_item	2794714	et	3	main
vajaduse	doc_670731433457_item	2794715	et	3	main
korral	doc_670731433457_item	2794716	et	4	main
ka	doc_670731433457_item	2794717	et	3	main
tekkinud	doc_670731433457_item	2794718	et	4	main
soovid	doc_670731433457_item	2794736	et	4	main
b	doc_670731433457_item	2794744	et	4	main
kuigi	doc_670731433457_item	2794747	et	3	main
vabanduse	doc_670731433457_item	2794754	et	4	main
c	doc_670731433457_item	2794775	et	4	main
d	doc_670731433457_item	2794778	et	4	main
kokku	doc_670731433457_item	2794779	et	3	main
panna	doc_670731433457_item	2794780	et	4	main
6	doc_670731433457_item	2794781	et	2	main
a	doc_670731433457_item	2794782	et	4	main
ning	doc_670731433457_item	2794783	et	3	main
b	doc_670731433457_item	2794784	et	4	main
kuid	doc_670731433457_item	2794787	et	4	main
7	doc_670731433457_item	2794790	et	2	main
a	doc_670731433457_item	2794791	et	4	main
parandab	doc_670731433457_item	2794805	et	3	main
tulge	doc_670731433457_item	2794819	et	3	main
b	doc_670731433457_item	2794820	et	4	main
9	doc_670731433457_item	2794723	et	2	main
10	doc_670731433457_item	2794725	et	2	main
või	doc_670731433457_item	2794729	et	4	main
kupong	doc_670731433457_item	2794731	et	3	main
2	doc_670731433457_item	2794741	et	2	main
a	doc_670731433457_item	2794742	et	4	main
just	doc_670731433457_item	2794743	et	3	main
c	doc_670731433457_item	2794746	et	4	main
a	doc_670731433457_item	2794760	et	4	main
tasule	doc_670731433457_item	2794761	et	3	main
tasakaalule	doc_670731433457_item	2794767	et	3	main
kokku	doc_670731433457_item	2794776	et	3	main
vaid	doc_670731433457_item	2794785	et	3	main
d	doc_670731433457_item	2794788	et	4	main
et	doc_670731433457_item	2794789	et	3	main
c	doc_670731433457_item	2794795	et	4	main
eest	doc_670731433457_item	2794796	et	4	main
palub	doc_670731433457_item	2794803	et	3	main
d	doc_670731433457_item	2794806	et	4	main
9	doc_670731433457_item	2794808	et	2	main
lihtne	doc_670731433457_item	2794816	et	3	main
külastage	doc_670731433457_item	2794823	et	3	main
avage	doc_670731433458_item	2794827	et	3	main
numbrid	doc_670731433458_item	2794829	et	3	main
sõnadega	doc_670731433458_item	2794831	et	3	main
õige	doc_670731433458_item	2794833	et	4	main
age	doc_670731433458_item	2794841	et	4	main
oks	doc_670731433458_item	2794842	et	3	main
ja	doc_670731433458_item	2794843	et	3	main
aga	doc_670731433458_item	2794850	et	3	main
inglismaa	doc_670731433458_item	2794853	et	4	main
london	doc_670731433458_item	2794854	et	4	main
inglismaal	doc_670731433458_item	2794855	et	4	main
on	doc_670731433458_item	2794858	et	4	main
on	doc_670731433458_item	2794864	et	4	main
kolm	doc_670731433458_item	2794866	et	3	main
kaks	doc_670731433458_item	2794868	et	3	main
vana	doc_670731433458_item	2794870	et	4	main
üldiselt	doc_670731433458_item	2794901	et	4	main
hästi	doc_670731433458_item	2794902	et	3	main
viimased	doc_670731433458_item	2794903	et	3	main
artiklid	doc_670731433458_item	2794904	et	3	main
räägivad	doc_670731433458_item	2794905	et	3	main
kergelt	doc_670731433458_item	2794916	et	4	main
kirjutab	doc_670731433457_item	2794801	et	3	main
b	doc_670731433457_item	2794802	et	4	main
d	doc_670731433457_item	2794824	et	4	main
harjutus	doc_670731433458_item	2794826	et	4	main
sulud	doc_670731433458_item	2794828	et	3	main
balletitantsijad	doc_670731433458_item	2794839	et	3	main
londonis	doc_670731433458_item	2794856	et	4	main
alates	doc_670731433458_item	2794871	et	3	main
noored	doc_670731433458_item	2794906	et	3	main
kuid	doc_670731433458_item	2794910	et	4	main
kõik	doc_670731433458_item	2794911	et	4	main
läinud	doc_670731433458_item	2794917	et	4	main
järve	doc_670731433458_item	2794934	et	4	main
jalaluu	doc_670731433458_item	2794937	et	4	main
pidadab	doc_670731433458_item	2794940	et	4	main
mõnda	doc_670731433458_item	2794941	et	4	main
ja	doc_670731433458_item	2794948	et	3	main
toomas	doc_670731433458_item	2794949	et	3	main
on	doc_670731433458_item	2794950	et	4	main
teineteisega	doc_670731433458_item	2794955	et	3	main
nemad	doc_670731433458_item	2794958	et	3	main
nemadele	doc_670731433458_item	2794959	et	4	main
nende	doc_670731433458_item	2794973	et	4	main
lähiaja	doc_670731433458_item	2794974	et	3	main
paremini	doc_670731433458_item	2794988	et	4	main
tantsida	doc_670731433458_item	2794989	et	3	main
märtsis	doc_670731433458_item	2794990	et	3	main
oks	doc_670731433458_item	2795003	et	3	main
päev	doc_670731433458_item	2795019	et	3	main
sobiv	doc_670731433458_item	2795025	et	4	main
teksti	doc_670731433458_item	2795027	et	4	main
alt	doc_670731433458_item	2795028	et	4	main
1	doc_670731433458_item	2795037	et	2	main
soovid	doc_670731433458_item	2795038	et	4	main
parasjagu	doc_670731433458_item	2795055	et	3	main
käes	doc_670731433458_item	2795057	et	4	main
vabaduse	doc_670731433458_item	2795066	et	4	main
on	doc_670731433458_item	2795078	et	4	main
on	doc_670731433458_item	2795085	et	4	main
õpetaja	doc_670731433458_item	2795121	et	4	main
üle	doc_670731433458_item	2795124	et	3	main
vead	doc_670731433458_item	2795127	et	4	main
ning	doc_670731433458_item	2795128	et	3	main
vastab	doc_670731433458_item	2795129	et	3	main
10	doc_670731433458_item	2795140	et	2	main
b	doc_670731433458_item	2795150	et	4	main
soovid	doc_670731433458_item	2795151	et	4	main
just	doc_670731433458_item	2795158	et	3	main
a	doc_670731433458_item	2795166	et	4	main
vajaduse	doc_670731433458_item	2795167	et	3	main
a	doc_670731433458_item	2795175	et	4	main
kuid	doc_670731433458_item	2795202	et	4	main
d	doc_670731433458_item	2795203	et	4	main
et	doc_670731433458_item	2795204	et	3	main
7	doc_670731433458_item	2795205	et	2	main
c	doc_670731433458_item	2795210	et	4	main
b	doc_670731433458_item	2795217	et	4	main
palub	doc_670731433458_item	2795218	et	3	main
muudab	doc_670731433458_item	2795222	et	3	main
a	doc_670731433458_item	2795224	et	4	main
liigne	doc_670731433458_item	2795225	et	3	main
b	doc_670731433458_item	2795226	et	4	main
libe	doc_670731433458_item	2795227	et	3	main
c	doc_670731433458_item	2795228	et	4	main
c	doc_670731433458_item	2795237	et	4	main
külastage	doc_670731433458_item	2795238	et	3	main
annab	doc_670731433459_item	2795250	et	3	main
ühe	doc_670731433459_item	2795251	et	4	main
abielupaar	doc_670731433459_item	2795255	et	4	main
inglismaal	doc_670731433459_item	2795270	et	4	main
age	doc_670731433459_item	2795272	et	4	main
aastat	doc_670731433459_item	2795283	et	3	main
tuhat	doc_670731433459_item	2795287	et	4	main
vabakutselised	doc_670731433459_item	2795294	et	4	main
erinevad	doc_670731433459_item	2795297	et	4	main
väga	doc_670731433459_item	2795305	et	3	main
on	doc_670731433459_item	2795334	et	4	main
järve	doc_670731433459_item	2795345	et	4	main
tantsida	doc_670731433459_item	2795364	et	3	main
nemad	doc_670731433459_item	2795369	et	3	main
tantsimiseks	doc_670731433459_item	2795376	et	4	main
on	doc_670731433459_item	2795387	et	4	main
c	doc_670731433457_item	2794822	et	4	main
abielupaar	doc_670731433458_item	2794840	et	4	main
toomas	doc_670731433458_item	2794844	et	3	main
30	doc_670731433458_item	2794859	et	2	main
aastane	doc_670731433458_item	2794861	et	4	main
tuhande	doc_670731433458_item	2794873	et	3	main
üheksasaja	doc_670731433458_item	2794874	et	4	main
üheksa	doc_670731433458_item	2794875	et	4	main
kümmend	doc_670731433458_item	2794876	et	4	main
seitsmendast	doc_670731433458_item	2794877	et	3	main
aastast	doc_670731433458_item	2794878	et	4	main
on	doc_670731433458_item	2794879	et	4	main
nad	doc_670731433458_item	2794880	et	3	main
vabakutseline	doc_670731433458_item	2794881	et	4	main
vabakutselised	doc_670731433458_item	2794882	et	4	main
ja	doc_670731433458_item	2794883	et	3	main
esinevad	doc_670731433458_item	2794884	et	4	main
erinevad	doc_670731433458_item	2794885	et	4	main
teatrid	doc_670731433458_item	2794886	et	3	main
erinevades	doc_670731433458_item	2794887	et	4	main
teatrides	doc_670731433458_item	2794888	et	4	main
inglismaal	doc_670731433458_item	2794889	et	4	main
armastama	doc_670731433458_item	2794890	et	3	main
armastavad	doc_670731433458_item	2794891	et	4	main
neid	doc_670731433458_item	2794892	et	4	main
väga	doc_670731433458_item	2794893	et	3	main
ning	doc_670731433458_item	2794894	et	3	main
isegi	doc_670731433458_item	2794895	et	4	main
kriitikud	doc_670731433458_item	2794897	et	3	main
suhtuma	doc_670731433458_item	2794898	et	3	main
karmid	doc_670731433458_item	2794896	et	4	main
suhtunud	doc_670731433458_item	2794899	et	4	main
nendesse	doc_670731433458_item	2794900	et	4	main
nooredest	doc_670731433458_item	2794907	et	4	main
eriti	doc_670731433458_item	2794920	et	3	main
etenduses	doc_670731433458_item	2794936	et	4	main
pidama	doc_670731433458_item	2794939	et	4	main
eemal	doc_670731433458_item	2794944	et	3	main
ja	doc_670731433458_item	2794981	et	3	main
areneda	doc_670731433458_item	2794984	et	3	main
veelgi	doc_670731433458_item	2794986	et	4	main
esinema	doc_670731433458_item	2794993	et	3	main
tallinnasse	doc_670731433458_item	2794995	et	3	main
on	doc_670731433458_item	2794922	et	4	main
tervisega	doc_670731433458_item	2794926	et	3	main
1990	doc_670731433458_item	2794927	et	2	main
aastal	doc_670731433458_item	2794928	et	3	main
tantsimisest	doc_670731433458_item	2794943	et	4	main
tantsida	doc_670731433458_item	2794953	et	3	main
paaris	doc_670731433458_item	2794956	et	4	main
on	doc_670731433458_item	2794960	et	4	main
tehtud	doc_670731433458_item	2794961	et	4	main
pakkumisi	doc_670731433458_item	2794962	et	4	main
ka	doc_670731433458_item	2794963	et	3	main
eraldi	doc_670731433458_item	2794964	et	4	main
tantsimiseks	doc_670731433458_item	2794965	et	4	main
vaatamata	doc_670731433458_item	2794966	et	4	main
suurele	doc_670731433458_item	2794967	et	4	main
edule	doc_670731433458_item	2794968	et	3	main
elavad	doc_670731433458_item	2794969	et	4	main
tantsijad	doc_670731433458_item	2794970	et	4	main
tagasihoidlik	doc_670731433458_item	2794971	et	3	main
tagasihoidlik	doc_670731433458_item	2794972	et	3	main
ja	doc_670731433458_item	2794938	et	3	main
olema	doc_670731433458_item	2794945	et	4	main
oli	doc_670731433458_item	2794946	et	3	main
age	doc_670731433458_item	2794947	et	4	main
ainult	doc_670731433458_item	2794954	et	4	main
kuigi	doc_670731433458_item	2794957	et	3	main
on	doc_670731433458_item	2794976	et	4	main
täpselt	doc_670731433458_item	2794977	et	4	main
tahavad	doc_670731433458_item	2794983	et	3	main
ja	doc_670731433458_item	2794985	et	3	main
parem	doc_670731433458_item	2794987	et	4	main
tallinn	doc_670731433458_item	2794994	et	4	main
ja	doc_670731433458_item	2794996	et	3	main
sõidavad	doc_670731433458_item	2794998	et	3	main
ja	doc_670731433458_item	2795004	et	3	main
veel	doc_670731433458_item	2795006	et	4	main
püsida	doc_670731433458_item	2795009	et	3	main
üksi	doc_670731433458_item	2795020	et	4	main
kirjutage	doc_670731433458_item	2795023	et	3	main
sõna	doc_670731433458_item	2795026	et	4	main
õige	doc_670731433458_item	2795030	et	4	main
sul	doc_670731433458_item	2795044	et	3	main
2	doc_670731433458_item	2795047	et	2	main
kuigi	doc_670731433458_item	2795048	et	3	main
ja	doc_670731433458_item	2795051	et	3	main
millal	doc_670731433458_item	2795052	et	3	main
soovid	doc_670731433458_item	2795056	et	4	main
on	doc_670731433458_item	2795058	et	4	main
interaktiivse	doc_670731433458_item	2795059	et	3	main
õppe	doc_670731433458_item	2795060	et	4	main
aega	doc_670731433458_item	2795068	et	4	main
ning	doc_670731433458_item	2795069	et	3	main
eelise	doc_670731433458_item	2795070	et	4	main
omandada	doc_670731433458_item	2795071	et	3	main
tekkinud	doc_670731433458_item	2795133	et	4	main
9	doc_670731433458_item	2795138	et	2	main
a	doc_670731433458_item	2795157	et	4	main
seega	doc_670731433458_item	2795160	et	4	main
c	doc_670731433458_item	2795161	et	4	main
kuigi	doc_670731433458_item	2795162	et	3	main
b	doc_670731433458_item	2795168	et	4	main
vabanduse	doc_670731433458_item	2795169	et	4	main
c	doc_670731433458_item	2795170	et	4	main
varanduse	doc_670731433458_item	2795171	et	3	main
5	doc_670731433458_item	2795183	et	2	main
kokku	doc_670731433458_item	2795188	et	3	main
a	doc_670731433458_item	2795206	et	4	main
eest	doc_670731433458_item	2795211	et	4	main
d	doc_670731433458_item	2795212	et	4	main
liikuv	doc_670731433458_item	2795229	et	4	main
d	doc_670731433458_item	2795230	et	4	main
lihtne	doc_670731433458_item	2795231	et	3	main
10	doc_670731433458_item	2795232	et	2	main
a	doc_670731433458_item	2795233	et	4	main
tulge	doc_670731433458_item	2795234	et	3	main
sulud	doc_670731433459_item	2795243	et	3	main
numbrid	doc_670731433459_item	2795244	et	3	main
kirjutage	doc_670731433459_item	2795245	et	3	main
sõnadega	doc_670731433459_item	2795246	et	3	main
maailmakuulsad	doc_670731433459_item	2795253	et	3	main
inglismaa	doc_670731433459_item	2795268	et	4	main
loondonis	doc_670731433459_item	2795271	et	4	main
32	doc_670731433459_item	2795280	et	2	main
kolmkümend	doc_670731433459_item	2795281	et	4	main
kaks	doc_670731433459_item	2795282	et	3	main
1997a	doc_670731433459_item	2795286	et	4	main
üheksasaja	doc_670731433459_item	2795288	et	4	main
üheksakümmend	doc_670731433459_item	2795289	et	4	main
vabakutseline	doc_670731433459_item	2795293	et	4	main
ja	doc_670731433459_item	2795295	et	3	main
armastama	doc_670731433459_item	2795302	et	3	main
armastatakse	doc_670731433459_item	2795303	et	3	main
ning	doc_670731433459_item	2795306	et	3	main
suhtuvad	doc_670731433459_item	2795311	et	4	main
alati	doc_670731433459_item	2795326	et	4	main
olnud	doc_670731433459_item	2795335	et	4	main
probleeme	doc_670731433459_item	2795336	et	3	main
tervis	doc_670731433459_item	2795337	et	3	main
tervisega	doc_670731433459_item	2795338	et	3	main
noor	doc_670731433459_item	2795342	et	3	main
olema	doc_670731433459_item	2795356	et	4	main
tehtud	doc_670731433459_item	2795372	et	4	main
tantsima	doc_670731433458_item	2794952	et	3	main
planeerima	doc_670731433458_item	2794978	et	3	main
planeeritud	doc_670731433458_item	2794979	et	4	main
toomas	doc_670731433458_item	2794982	et	3	main
nad	doc_670731433458_item	2794992	et	3	main
seejärel	doc_670731433458_item	2794997	et	3	main
lõuna-aafrika	doc_670731433458_item	2794999	et	4	main
kaua	doc_670731433458_item	2795002	et	3	main
eelistavad	doc_670731433458_item	2795016	et	4	main
elada	doc_670731433458_item	2795017	et	3	main
üks	doc_670731433458_item	2795018	et	3	main
päeva	doc_670731433458_item	2795021	et	4	main
vastus	doc_670731433458_item	2795031	et	3	main
punkti	doc_670731433458_item	2795034	et	4	main
millal	doc_670731433458_item	2795036	et	3	main
saada	doc_670731433458_item	2795045	et	4	main
seal	doc_670731433458_item	2795049	et	4	main
kus	doc_670731433458_item	2795050	et	3	main
sa	doc_670731433458_item	2795053	et	3	main
mis	doc_670731433458_item	2795062	et	4	main
annab	doc_670731433458_item	2795063	et	3	main
sulle	doc_670731433458_item	2795064	et	3	main
vastavalt	doc_670731433458_item	2795073	et	4	main
individuaalsele	doc_670731433458_item	2795074	et	3	main
4	doc_670731433458_item	2795075	et	2	main
tasemele	doc_670731433458_item	2795076	et	3	main
liita	doc_670731433458_item	2795084	et	4	main
ka	doc_670731433458_item	2795087	et	3	main
tarkust	doc_670731433458_item	2795089	et	4	main
kui	doc_670731433458_item	2795090	et	3	main
oled	doc_670731433458_item	2795091	et	3	main
kursusele	doc_670731433458_item	2795092	et	3	main
vaatab	doc_670731433458_item	2795122	et	3	main
lisaküsimustele	doc_670731433458_item	2795134	et	4	main
lihtne	doc_670731433458_item	2795139	et	3	main
sobid	doc_670731433458_item	2795149	et	4	main
d	doc_670731433458_item	2795163	et	4	main
tasule	doc_670731433458_item	2795176	et	3	main
d	doc_670731433458_item	2795181	et	4	main
tasakaalule	doc_670731433458_item	2795182	et	3	main
a	doc_670731433458_item	2795184	et	4	main
kokku	doc_670731433458_item	2795185	et	3	main
a	doc_670731433458_item	2795197	et	4	main
ning	doc_670731433458_item	2795198	et	3	main
b	doc_670731433458_item	2795199	et	4	main
vaid	doc_670731433458_item	2795200	et	3	main
taga	doc_670731433458_item	2795207	et	4	main
esinemised	doc_670731433458_item	2794975	et	4	main
age	doc_670731433458_item	2794980	et	4	main
tulevad	doc_670731433458_item	2794991	et	4	main
lõuna-aafrikas	doc_670731433458_item	2795000	et	4	main
kui	doc_670731433458_item	2795001	et	3	main
edur	doc_670731433458_item	2795005	et	4	main
tipus	doc_670731433458_item	2795007	et	3	main
suudavad	doc_670731433458_item	2795008	et	3	main
ei	doc_670731433458_item	2795010	et	4	main
oska	doc_670731433458_item	2795011	et	4	main
nad	doc_670731433458_item	2795012	et	3	main
ütlema	doc_670731433458_item	2795013	et	3	main
öelda	doc_670731433458_item	2795014	et	4	main
nad	doc_670731433458_item	2795015	et	3	main
lünka	doc_670731433458_item	2795024	et	4	main
annab	doc_670731433458_item	2795032	et	3	main
õpi	doc_670731433458_item	2795035	et	4	main
unusta	doc_670731433458_item	2795039	et	4	main
umbne	doc_670731433458_item	2795040	et	3	main
klassiruum	doc_670731433458_item	2795041	et	3	main
koduõppesüsteem	doc_670731433458_item	2795042	et	3	main
võimaldab	doc_670731433458_item	2795043	et	3	main
targemaks	doc_670731433458_item	2795046	et	4	main
ajastu	doc_670731433458_item	2795061	et	4	main
teadmisi	doc_670731433458_item	2795072	et	4	main
et	doc_670731433458_item	2795080	et	3	main
5	doc_670731433458_item	2795082	et	2	main
kokku	doc_670731433458_item	2795083	et	3	main
pisut	doc_670731433458_item	2795088	et	3	main
kirjutab	doc_670731433458_item	2795126	et	3	main
vajaduse	doc_670731433458_item	2795130	et	3	main
korral	doc_670731433458_item	2795131	et	4	main
ka	doc_670731433458_item	2795132	et	3	main
on	doc_670731433458_item	2795137	et	4	main
meie	doc_670731433458_item	2795142	et	4	main
või	doc_670731433458_item	2795144	et	4	main
kupong	doc_670731433458_item	2795146	et	3	main
c	doc_670731433458_item	2795152	et	4	main
soovitad	doc_670731433458_item	2795153	et	3	main
siiski	doc_670731433458_item	2795164	et	4	main
3	doc_670731433458_item	2795165	et	2	main
d	doc_670731433458_item	2795172	et	4	main
b	doc_670731433458_item	2795177	et	4	main
tasakesi	doc_670731433458_item	2795180	et	3	main
b	doc_670731433458_item	2795187	et	4	main
liita	doc_670731433458_item	2795189	et	4	main
kokku	doc_670731433458_item	2795191	et	3	main
hoida	doc_670731433458_item	2795192	et	3	main
c	doc_670731433458_item	2795201	et	4	main
b	doc_670731433458_item	2795208	et	4	main
ees	doc_670731433458_item	2795213	et	4	main
8	doc_670731433458_item	2795214	et	2	main
d	doc_670731433458_item	2795221	et	4	main
b	doc_670731433458_item	2795235	et	4	main
käige	doc_670731433458_item	2795236	et	3	main
iga	doc_670731433459_item	2795247	et	4	main
õige	doc_670731433459_item	2795248	et	4	main
vastus	doc_670731433459_item	2795249	et	3	main
london	doc_670731433459_item	2795269	et	4	main
on	doc_670731433459_item	2795279	et	4	main
alates	doc_670731433459_item	2795285	et	3	main
nad	doc_670731433459_item	2795292	et	3	main
inglismaal	doc_670731433459_item	2795301	et	4	main
ainult	doc_670731433459_item	2795320	et	4	main
kaupa	doc_670731433458_item	2795022	et	4	main
iga	doc_670731433458_item	2795029	et	4	main
ühe	doc_670731433458_item	2795033	et	4	main
seda	doc_670731433458_item	2795054	et	3	main
3	doc_670731433458_item	2795065	et	2	main
planeerida	doc_670731433458_item	2795067	et	3	main
aeg	doc_670731433458_item	2795077	et	3	main
raha	doc_670731433458_item	2795079	et	4	main
seda	doc_670731433458_item	2795081	et	3	main
vaja	doc_670731433458_item	2795086	et	4	main
registreerunud	doc_670731433458_item	2795093	et	4	main
saad	doc_670731433458_item	2795094	et	4	main
meie	doc_670731433458_item	2795095	et	4	main
kontorist	doc_670731433458_item	2795096	et	4	main
või	doc_670731433458_item	2795097	et	4	main
lähimast	doc_670731433458_item	2795098	et	4	main
postiasutusest	doc_670731433458_item	2795099	et	4	main
igal	doc_670731433458_item	2795100	et	3	main
kuul	doc_670731433458_item	2795101	et	4	main
kätte	doc_670731433458_item	2795102	et	4	main
õppematerjalid	doc_670731433458_item	2795103	et	3	main
raamatu	doc_670731433458_item	2795104	et	4	main
ja	doc_670731433458_item	2795105	et	3	main
helikasseti	doc_670731433458_item	2795106	et	4	main
6	doc_670731433458_item	2795107	et	2	main
ning	doc_670731433458_item	2795108	et	3	main
kodutöö	doc_670731433458_item	2795109	et	4	main
kursuse	doc_670731433458_item	2795110	et	3	main
7	doc_670731433458_item	2795111	et	2	main
eest	doc_670731433458_item	2795112	et	4	main
tasud	doc_670731433458_item	2795113	et	4	main
selle	doc_670731433458_item	2795114	et	4	main
kättesaamisel	doc_670731433458_item	2795115	et	4	main
saada	doc_670731433458_item	2795116	et	4	main
täidetud	doc_670731433458_item	2795117	et	4	main
kodutöö	doc_670731433458_item	2795118	et	4	main
meile	doc_670731433458_item	2795119	et	4	main
tagasi	doc_670731433458_item	2795120	et	3	main
selle	doc_670731433458_item	2795123	et	4	main
8	doc_670731433458_item	2795125	et	2	main
kõik	doc_670731433458_item	2795135	et	4	main
geniaalne	doc_670731433458_item	2795136	et	3	main
minge	doc_670731433458_item	2795141	et	3	main
virtuaalkodu	doc_670731433458_item	2795143	et	4	main
postitage	doc_670731433458_item	2795145	et	3	main
1	doc_670731433458_item	2795147	et	2	main
a	doc_670731433458_item	2795148	et	4	main
d	doc_670731433458_item	2795154	et	4	main
solvud	doc_670731433458_item	2795155	et	3	main
2	doc_670731433458_item	2795156	et	2	main
b	doc_670731433458_item	2795159	et	4	main
vabaduse	doc_670731433458_item	2795173	et	4	main
4	doc_670731433458_item	2795174	et	2	main
tasemele	doc_670731433458_item	2795178	et	3	main
c	doc_670731433458_item	2795179	et	4	main
saada	doc_670731433458_item	2795186	et	4	main
c	doc_670731433458_item	2795190	et	4	main
d	doc_670731433458_item	2795193	et	4	main
kokku	doc_670731433458_item	2795194	et	3	main
panna	doc_670731433458_item	2795195	et	4	main
6	doc_670731433458_item	2795196	et	2	main
ette	doc_670731433458_item	2795209	et	4	main
a	doc_670731433458_item	2795215	et	4	main
kirjutab	doc_670731433458_item	2795216	et	3	main
c	doc_670731433458_item	2795219	et	4	main
parandab	doc_670731433458_item	2795220	et	3	main
d	doc_670731433458_item	2795239	et	4	main
minge	doc_670731433458_item	2795240	et	3	main
punkti	doc_670731433459_item	2795252	et	4	main
on	doc_670731433459_item	2795273	et	4	main
kolmekümne	doc_670731433459_item	2795275	et	4	main
seitsmest	doc_670731433459_item	2795290	et	4	main
neid	doc_670731433459_item	2795304	et	4	main
isegi	doc_670731433459_item	2795307	et	4	main
suhtuma	doc_670731433459_item	2795310	et	3	main
üldiselt	doc_670731433459_item	2795313	et	4	main
hästi	doc_670731433459_item	2795314	et	3	main
artiklid	doc_670731433459_item	2795316	et	3	main
räägivad	doc_670731433459_item	2795317	et	3	main
noored	doc_670731433459_item	2795318	et	3	main
noortest	doc_670731433459_item	2795319	et	4	main
kuid	doc_670731433459_item	2795322	et	4	main
pole	doc_670731433459_item	2795324	et	3	main
kergelt	doc_670731433459_item	2795328	et	4	main
läinud	doc_670731433459_item	2795329	et	4	main
mõlemal	doc_670731433459_item	2795330	et	3	main
ja	doc_670731433459_item	2795331	et	3	main
eriti	doc_670731433459_item	2795332	et	3	main
agel	doc_670731433459_item	2795333	et	4	main
luikede	doc_670731433459_item	2795344	et	3	main
etendusel	doc_670731433459_item	2795347	et	4	main
olemas	doc_670731433459_item	2795357	et	4	main
age	doc_670731433459_item	2795358	et	4	main
ja	doc_670731433459_item	2795359	et	3	main
toomas	doc_670731433459_item	2795360	et	3	main
on	doc_670731433459_item	2795361	et	4	main
teineteisega	doc_670731433459_item	2795366	et	3	main
paaris	doc_670731433459_item	2795367	et	4	main
ka	doc_670731433459_item	2795374	et	3	main
eraldi	doc_670731433459_item	2795375	et	4	main
tantsijad	doc_670731433459_item	2795381	et	4	main
nende	doc_670731433459_item	2795384	et	4	main
age	doc_670731433459_item	2795391	et	4	main
ja	doc_670731433459_item	2795392	et	3	main
toomas	doc_670731433459_item	2795393	et	3	main
tahavad	doc_670731433459_item	2795394	et	3	main
areneda	doc_670731433459_item	2795395	et	3	main
esinema	doc_670731433459_item	2795404	et	3	main
tallinn	doc_670731433459_item	2795405	et	4	main
ja	doc_670731433459_item	2795407	et	3	main
seejärel	doc_670731433459_item	2795408	et	3	main
sõidavad	doc_670731433459_item	2795409	et	3	main
lõuna-aafrika	doc_670731433459_item	2795410	et	4	main
oska	doc_670731433459_item	2795422	et	4	main
nad	doc_670731433459_item	2795426	et	3	main
päev	doc_670731433459_item	2795430	et	3	main
teksti	doc_670731433459_item	2795438	et	4	main
annab	doc_670731433459_item	2795443	et	3	main
9	doc_670731433458_item	2795223	et	2	main
harjutus	doc_670731433459_item	2795241	et	4	main
avage	doc_670731433459_item	2795242	et	3	main
balletitantsijad	doc_670731433459_item	2795254	et	3	main
oks	doc_670731433459_item	2795257	et	3	main
age	doc_670731433459_item	2795256	et	4	main
ja	doc_670731433459_item	2795258	et	3	main
toomas	doc_670731433459_item	2795259	et	3	main
edur	doc_670731433459_item	2795260	et	4	main
on	doc_670731433459_item	2795261	et	4	main
pärit	doc_670731433459_item	2795262	et	3	main
eesti	doc_670731433459_item	2795263	et	4	main
eestist	doc_670731433459_item	2795264	et	3	main
aga	doc_670731433459_item	2795265	et	3	main
elavad	doc_670731433459_item	2795266	et	4	main
praegu	doc_670731433459_item	2795267	et	3	main
30	doc_670731433459_item	2795274	et	2	main
aastane	doc_670731433459_item	2795276	et	4	main
ja	doc_670731433459_item	2795277	et	3	main
toomas	doc_670731433459_item	2795278	et	3	main
vana	doc_670731433459_item	2795284	et	4	main
on	doc_670731433459_item	2795291	et	4	main
esinevad	doc_670731433459_item	2795296	et	4	main
teatrid	doc_670731433459_item	2795298	et	3	main
erinevates	doc_670731433459_item	2795299	et	4	main
teatrides	doc_670731433459_item	2795300	et	4	main
karmid	doc_670731433459_item	2795308	et	4	main
kriitikud	doc_670731433459_item	2795309	et	3	main
nendesse	doc_670731433459_item	2795312	et	4	main
viimased	doc_670731433459_item	2795315	et	3	main
ülivõrdes	doc_670731433459_item	2795321	et	3	main
kõik	doc_670731433459_item	2795323	et	4	main
1990	doc_670731433459_item	2795339	et	2	main
aastal	doc_670731433459_item	2795340	et	3	main
murdma	doc_670731433459_item	2795341	et	3	main
ja	doc_670731433459_item	2795349	et	3	main
pidas	doc_670731433459_item	2795351	et	3	main
aega	doc_670731433459_item	2795353	et	4	main
tantsimisest	doc_670731433459_item	2795354	et	4	main
eemal	doc_670731433459_item	2795355	et	3	main
otsustanud	doc_670731433459_item	2795362	et	4	main
tantsima	doc_670731433459_item	2795363	et	3	main
pakkumisi	doc_670731433459_item	2795373	et	4	main
elavad	doc_670731433459_item	2795380	et	4	main
planeeritud	doc_670731433459_item	2795390	et	4	main
märtsis	doc_670731433459_item	2795401	et	3	main
edur	doc_670731433459_item	2795416	et	4	main
ütlema	doc_670731433459_item	2795424	et	3	main
üheks	doc_670731433459_item	2795431	et	3	main
päevaks	doc_670731433459_item	2795432	et	3	main
alt	doc_670731433459_item	2795439	et	4	main
võimaldab	doc_670731433459_item	2795454	et	3	main
targemaks	doc_670731433459_item	2795457	et	4	main
soovid	doc_670731433459_item	2795467	et	4	main
ajastu	doc_670731433459_item	2795472	et	4	main
annab	doc_670731433459_item	2795474	et	3	main
3	doc_670731433459_item	2795476	et	2	main
planeerida	doc_670731433459_item	2795478	et	3	main
ning	doc_670731433459_item	2795480	et	3	main
eelise	doc_670731433459_item	2795481	et	4	main
omandada	doc_670731433459_item	2795482	et	3	main
eest	doc_670731433459_item	2795523	et	4	main
selle	doc_670731433459_item	2795525	et	4	main
vead	doc_670731433459_item	2795537	et	4	main
korral	doc_670731433459_item	2795541	et	4	main
ka	doc_670731433459_item	2795542	et	3	main
geniaalne	doc_670731433459_item	2795546	et	3	main
9	doc_670731433459_item	2795548	et	2	main
lihtne	doc_670731433459_item	2795549	et	3	main
meie	doc_670731433459_item	2795552	et	4	main
virtuaalkodu	doc_670731433459_item	2795553	et	4	main
a	doc_670731433459_item	2795594	et	4	main
kokku	doc_670731433459_item	2795595	et	3	main
saada	doc_670731433459_item	2795596	et	4	main
kokku	doc_670731433459_item	2795601	et	3	main
hoida	doc_670731433459_item	2795602	et	3	main
ning	doc_670731433459_item	2795608	et	3	main
c	doc_670731433459_item	2795611	et	4	main
taga	doc_670731433459_item	2795617	et	4	main
b	doc_670731433459_item	2795618	et	4	main
b	doc_670731433459_item	2795627	et	4	main
palub	doc_670731433459_item	2795628	et	3	main
c	doc_670731433459_item	2795629	et	4	main
parandab	doc_670731433459_item	2795630	et	3	main
d	doc_670731433459_item	2795631	et	4	main
muudab	doc_670731433459_item	2795632	et	3	main
b	doc_670731433459_item	2795636	et	4	main
c	doc_670731433459_item	2795638	et	4	main
õige	doc_670731433460_item	2795658	et	4	main
vastus	doc_670731433460_item	2795659	et	3	main
annab	doc_670731433460_item	2795660	et	3	main
ühe	doc_670731433460_item	2795661	et	4	main
age	doc_670731433460_item	2795666	et	4	main
oks	doc_670731433460_item	2795667	et	3	main
on	doc_670731433460_item	2795671	et	4	main
pärit	doc_670731433460_item	2795672	et	3	main
eesti	doc_670731433460_item	2795673	et	4	main
eestist	doc_670731433460_item	2795674	et	3	main
sugugi	doc_670731433459_item	2795325	et	4	main
nii	doc_670731433459_item	2795327	et	3	main
naine	doc_670731433459_item	2795343	et	3	main
etendus	doc_670731433459_item	2795346	et	4	main
jalaluu	doc_670731433459_item	2795348	et	4	main
pidama	doc_670731433459_item	2795350	et	4	main
mõnda	doc_670731433459_item	2795352	et	4	main
ainult	doc_670731433459_item	2795365	et	4	main
kuigi	doc_670731433459_item	2795368	et	3	main
nendel	doc_670731433459_item	2795370	et	4	main
on	doc_670731433459_item	2795371	et	4	main
vaatamata	doc_670731433459_item	2795377	et	4	main
tagasihoidlik	doc_670731433459_item	2795382	et	3	main
ja	doc_670731433459_item	2795396	et	3	main
tulevad	doc_670731433459_item	2795402	et	4	main
tallinnas	doc_670731433459_item	2795406	et	4	main
tipus	doc_670731433459_item	2795418	et	3	main
püsida	doc_670731433459_item	2795420	et	3	main
ei	doc_670731433459_item	2795421	et	4	main
elada	doc_670731433459_item	2795428	et	3	main
ühe	doc_670731433459_item	2795444	et	4	main
õpi	doc_670731433459_item	2795446	et	4	main
millal	doc_670731433459_item	2795447	et	3	main
unusta	doc_670731433459_item	2795450	et	4	main
koduõppesüsteem	doc_670731433459_item	2795453	et	3	main
2	doc_670731433459_item	2795458	et	2	main
just	doc_670731433459_item	2795459	et	3	main
seal	doc_670731433459_item	2795460	et	4	main
kus	doc_670731433459_item	2795461	et	3	main
ja	doc_670731433459_item	2795462	et	3	main
millal	doc_670731433459_item	2795463	et	3	main
sa	doc_670731433459_item	2795464	et	3	main
seda	doc_670731433459_item	2795465	et	3	main
parasjagu	doc_670731433459_item	2795466	et	3	main
interaktiivse	doc_670731433459_item	2795470	et	3	main
vajaduse	doc_670731433459_item	2795477	et	3	main
suurele	doc_670731433459_item	2795378	et	4	main
edule	doc_670731433459_item	2795379	et	3	main
tagasihoidlikult	doc_670731433459_item	2795383	et	4	main
lähiaja	doc_670731433459_item	2795385	et	3	main
esinemised	doc_670731433459_item	2795386	et	4	main
veelgi	doc_670731433459_item	2795397	et	4	main
parem	doc_670731433459_item	2795398	et	4	main
nad	doc_670731433459_item	2795403	et	3	main
lõuna-aafrikasse	doc_670731433459_item	2795411	et	4	main
kui	doc_670731433459_item	2795412	et	3	main
kaua	doc_670731433459_item	2795413	et	3	main
oks	doc_670731433459_item	2795414	et	3	main
ja	doc_670731433459_item	2795415	et	3	main
täpselt	doc_670731433459_item	2795388	et	4	main
planeerima	doc_670731433459_item	2795389	et	3	main
paremini	doc_670731433459_item	2795399	et	4	main
tantsida	doc_670731433459_item	2795400	et	3	main
veel	doc_670731433459_item	2795417	et	4	main
suudavad	doc_670731433459_item	2795419	et	3	main
ööelda	doc_670731433459_item	2795425	et	4	main
eelistavad	doc_670731433459_item	2795427	et	4	main
kirjutage	doc_670731433459_item	2795434	et	3	main
õige	doc_670731433459_item	2795441	et	4	main
soovid	doc_670731433459_item	2795449	et	4	main
klassiruum	doc_670731433459_item	2795452	et	3	main
käes	doc_670731433459_item	2795468	et	4	main
vastavalt	doc_670731433459_item	2795484	et	4	main
individuaalsele	doc_670731433459_item	2795485	et	3	main
4	doc_670731433459_item	2795486	et	2	main
tasemele	doc_670731433459_item	2795487	et	3	main
aeg	doc_670731433459_item	2795488	et	3	main
on	doc_670731433459_item	2795489	et	4	main
täidetud	doc_670731433459_item	2795528	et	4	main
meile	doc_670731433459_item	2795530	et	4	main
vajaduse	doc_670731433459_item	2795540	et	3	main
on	doc_670731433459_item	2795547	et	4	main
10	doc_670731433459_item	2795550	et	2	main
solvud	doc_670731433459_item	2795565	et	3	main
a	doc_670731433459_item	2795585	et	4	main
tasemele	doc_670731433459_item	2795588	et	3	main
c	doc_670731433459_item	2795589	et	4	main
tasakesi	doc_670731433459_item	2795590	et	3	main
kokku	doc_670731433459_item	2795598	et	3	main
panna	doc_670731433459_item	2795605	et	4	main
c	doc_670731433459_item	2795620	et	4	main
d	doc_670731433459_item	2795622	et	4	main
8	doc_670731433459_item	2795624	et	2	main
9	doc_670731433459_item	2795633	et	2	main
libe	doc_670731433459_item	2795637	et	3	main
liikuv	doc_670731433459_item	2795639	et	4	main
d	doc_670731433459_item	2795640	et	4	main
lihtne	doc_670731433459_item	2795641	et	3	main
10	doc_670731433459_item	2795642	et	2	main
harjutus	doc_670731433460_item	2795651	et	4	main
avage	doc_670731433460_item	2795652	et	3	main
sulud	doc_670731433460_item	2795653	et	3	main
numbrid	doc_670731433460_item	2795654	et	3	main
kirjutage	doc_670731433460_item	2795655	et	3	main
sõnadega	doc_670731433460_item	2795656	et	3	main
toomas	doc_670731433460_item	2795669	et	3	main
london	doc_670731433460_item	2795679	et	4	main
nendesse	doc_670731433460_item	2795721	et	4	main
hästi	doc_670731433460_item	2795723	et	3	main
eriti	doc_670731433460_item	2795741	et	3	main
noor	doc_670731433460_item	2795752	et	3	main
tantsimisest	doc_670731433460_item	2795764	et	4	main
eemal	doc_670731433460_item	2795765	et	3	main
otsustanud	doc_670731433460_item	2795772	et	4	main
tantsima	doc_670731433460_item	2795773	et	3	main
tehtud	doc_670731433460_item	2795782	et	4	main
ka	doc_670731433460_item	2795784	et	3	main
tantsimiseks	doc_670731433460_item	2795786	et	4	main
elavad	doc_670731433460_item	2795790	et	4	main
tantsijad	doc_670731433460_item	2795791	et	4	main
tagasihoidlik	doc_670731433460_item	2795792	et	3	main
tagasihoidlikud	doc_670731433460_item	2795793	et	3	main
nende	doc_670731433460_item	2795794	et	4	main
lähiaja	doc_670731433460_item	2795795	et	3	main
kui	doc_670731433460_item	2795822	et	3	main
ja	doc_670731433460_item	2795825	et	3	main
suudavad	doc_670731433460_item	2795829	et	3	main
nad	doc_670731433460_item	2795833	et	3	main
sobiv	doc_670731433460_item	2795846	et	4	main
ühe	doc_670731433460_item	2795854	et	4	main
millal	doc_670731433460_item	2795857	et	3	main
targemaks	doc_670731433460_item	2795867	et	4	main
on	doc_670731433460_item	2795899	et	4	main
et	doc_670731433460_item	2795901	et	3	main
kokku	doc_670731433460_item	2795904	et	3	main
on	doc_670731433460_item	2795906	et	4	main
ka	doc_670731433460_item	2795908	et	3	main
pisut	doc_670731433460_item	2795909	et	3	main
tarkust	doc_670731433460_item	2795910	et	4	main
kui	doc_670731433460_item	2795911	et	3	main
meie	doc_670731433460_item	2795916	et	4	main
nad	doc_670731433459_item	2795423	et	3	main
üks	doc_670731433459_item	2795429	et	3	main
kaupa	doc_670731433459_item	2795433	et	4	main
lünka	doc_670731433459_item	2795435	et	4	main
sobiv	doc_670731433459_item	2795436	et	4	main
sõna	doc_670731433459_item	2795437	et	4	main
iga	doc_670731433459_item	2795440	et	4	main
vastus	doc_670731433459_item	2795442	et	3	main
punkti	doc_670731433459_item	2795445	et	4	main
1	doc_670731433459_item	2795448	et	2	main
umbne	doc_670731433459_item	2795451	et	3	main
on	doc_670731433459_item	2795469	et	4	main
aega	doc_670731433459_item	2795479	et	4	main
teadmisi	doc_670731433459_item	2795483	et	4	main
raha	doc_670731433459_item	2795490	et	4	main
et	doc_670731433459_item	2795491	et	3	main
seda	doc_670731433459_item	2795492	et	3	main
5	doc_670731433459_item	2795493	et	2	main
kokku	doc_670731433459_item	2795494	et	3	main
hoida	doc_670731433459_item	2795495	et	3	main
on	doc_670731433459_item	2795496	et	4	main
vaja	doc_670731433459_item	2795497	et	4	main
ka	doc_670731433459_item	2795498	et	3	main
pisut	doc_670731433459_item	2795499	et	3	main
tarkust	doc_670731433459_item	2795500	et	4	main
kui	doc_670731433459_item	2795501	et	3	main
oled	doc_670731433459_item	2795502	et	3	main
kursusele	doc_670731433459_item	2795503	et	3	main
registreerunud	doc_670731433459_item	2795504	et	4	main
saad	doc_670731433459_item	2795505	et	4	main
meie	doc_670731433459_item	2795506	et	4	main
kontorist	doc_670731433459_item	2795507	et	4	main
või	doc_670731433459_item	2795508	et	4	main
lähimast	doc_670731433459_item	2795509	et	4	main
postiasutusest	doc_670731433459_item	2795510	et	4	main
igal	doc_670731433459_item	2795511	et	3	main
kuul	doc_670731433459_item	2795512	et	4	main
kätte	doc_670731433459_item	2795513	et	4	main
õppematerjalid	doc_670731433459_item	2795514	et	3	main
raamatu	doc_670731433459_item	2795515	et	4	main
ja	doc_670731433459_item	2795516	et	3	main
helikasseti	doc_670731433459_item	2795517	et	4	main
6	doc_670731433459_item	2795518	et	2	main
ning	doc_670731433459_item	2795519	et	3	main
kodutöö	doc_670731433459_item	2795520	et	4	main
kättesaamisel	doc_670731433459_item	2795526	et	4	main
ning	doc_670731433459_item	2795538	et	3	main
vastab	doc_670731433459_item	2795539	et	3	main
lisaküsimustele	doc_670731433459_item	2795544	et	4	main
kõik	doc_670731433459_item	2795545	et	4	main
1	doc_670731433459_item	2795557	et	2	main
sul	doc_670731433459_item	2795455	et	3	main
saada	doc_670731433459_item	2795456	et	4	main
õppe	doc_670731433459_item	2795471	et	4	main
mis	doc_670731433459_item	2795473	et	4	main
sulle	doc_670731433459_item	2795475	et	3	main
kursuse	doc_670731433459_item	2795521	et	3	main
tasud	doc_670731433459_item	2795524	et	4	main
saada	doc_670731433459_item	2795527	et	4	main
kodutöö	doc_670731433459_item	2795529	et	4	main
tekkinud	doc_670731433459_item	2795543	et	4	main
või	doc_670731433459_item	2795554	et	4	main
postitage	doc_670731433459_item	2795555	et	3	main
kupong	doc_670731433459_item	2795556	et	3	main
soovid	doc_670731433459_item	2795561	et	4	main
5	doc_670731433459_item	2795593	et	2	main
liita	doc_670731433459_item	2795599	et	4	main
a	doc_670731433459_item	2795607	et	4	main
vaid	doc_670731433459_item	2795610	et	3	main
kuid	doc_670731433459_item	2795612	et	4	main
d	doc_670731433459_item	2795613	et	4	main
et	doc_670731433459_item	2795614	et	3	main
7	doc_670731433459_item	2795615	et	2	main
7	doc_670731433459_item	2795522	et	2	main
tagasi	doc_670731433459_item	2795531	et	3	main
õpetaja	doc_670731433459_item	2795532	et	4	main
vaatab	doc_670731433459_item	2795533	et	3	main
selle	doc_670731433459_item	2795534	et	4	main
üle	doc_670731433459_item	2795535	et	3	main
8	doc_670731433459_item	2795536	et	2	main
külastage	doc_670731433459_item	2795551	et	3	main
sobid	doc_670731433459_item	2795559	et	4	main
b	doc_670731433459_item	2795560	et	4	main
2	doc_670731433459_item	2795566	et	2	main
a	doc_670731433459_item	2795567	et	4	main
just	doc_670731433459_item	2795568	et	3	main
b	doc_670731433459_item	2795569	et	4	main
seega	doc_670731433459_item	2795570	et	4	main
c	doc_670731433459_item	2795571	et	4	main
kuigi	doc_670731433459_item	2795572	et	3	main
d	doc_670731433459_item	2795573	et	4	main
siiski	doc_670731433459_item	2795574	et	4	main
3	doc_670731433459_item	2795575	et	2	main
a	doc_670731433459_item	2795576	et	4	main
vajaduse	doc_670731433459_item	2795577	et	3	main
b	doc_670731433459_item	2795578	et	4	main
vabanduse	doc_670731433459_item	2795579	et	4	main
c	doc_670731433459_item	2795580	et	4	main
varanduse	doc_670731433459_item	2795581	et	3	main
d	doc_670731433459_item	2795582	et	4	main
vabaduse	doc_670731433459_item	2795583	et	4	main
a	doc_670731433459_item	2795558	et	4	main
c	doc_670731433459_item	2795562	et	4	main
soovitad	doc_670731433459_item	2795563	et	3	main
d	doc_670731433459_item	2795564	et	4	main
4	doc_670731433459_item	2795584	et	2	main
tasule	doc_670731433459_item	2795586	et	3	main
b	doc_670731433459_item	2795587	et	4	main
b	doc_670731433459_item	2795597	et	4	main
kokku	doc_670731433459_item	2795604	et	3	main
a	doc_670731433459_item	2795616	et	4	main
a	doc_670731433459_item	2795634	et	4	main
käige	doc_670731433459_item	2795646	et	3	main
d	doc_670731433459_item	2795649	et	4	main
minge	doc_670731433459_item	2795650	et	3	main
punkti	doc_670731433460_item	2795662	et	4	main
maailmakuulsad	doc_670731433460_item	2795663	et	3	main
balletitantsijad	doc_670731433460_item	2795664	et	3	main
inglismaa	doc_670731433460_item	2795678	et	4	main
üldiselt	doc_670731433460_item	2795722	et	4	main
viimased	doc_670731433460_item	2795724	et	3	main
ainult	doc_670731433460_item	2795729	et	4	main
kuid	doc_670731433460_item	2795731	et	4	main
kõik	doc_670731433460_item	2795732	et	4	main
pole	doc_670731433460_item	2795733	et	3	main
läinud	doc_670731433460_item	2795738	et	4	main
murdis	doc_670731433460_item	2795751	et	3	main
luikede	doc_670731433460_item	2795754	et	3	main
mõnda	doc_670731433460_item	2795762	et	4	main
aega	doc_670731433460_item	2795763	et	4	main
ainult	doc_670731433460_item	2795775	et	4	main
kuigi	doc_670731433460_item	2795778	et	3	main
nemad	doc_670731433460_item	2795779	et	3	main
nemade	doc_670731433460_item	2795780	et	4	main
lõuna-aafrisse	doc_670731433460_item	2795821	et	4	main
püsida	doc_670731433460_item	2795830	et	3	main
ütlevad	doc_670731433460_item	2795835	et	4	main
eelistavad	doc_670731433460_item	2795837	et	4	main
päev	doc_670731433460_item	2795840	et	3	main
õige	doc_670731433460_item	2795851	et	4	main
vastus	doc_670731433460_item	2795852	et	3	main
annab	doc_670731433460_item	2795853	et	3	main
õpi	doc_670731433460_item	2795856	et	4	main
soovid	doc_670731433460_item	2795859	et	4	main
vastavalt	doc_670731433460_item	2795894	et	4	main
individuaalsele	doc_670731433460_item	2795895	et	3	main
aeg	doc_670731433460_item	2795898	et	3	main
5	doc_670731433460_item	2795903	et	2	main
saad	doc_670731433460_item	2795915	et	4	main
kuul	doc_670731433460_item	2795922	et	4	main
õppematerjalid	doc_670731433460_item	2795924	et	3	main
raamatu	doc_670731433460_item	2795925	et	4	main
ja	doc_670731433460_item	2795926	et	3	main
kodutöö	doc_670731433460_item	2795930	et	4	main
saada	doc_670731433460_item	2795937	et	4	main
selle	doc_670731433460_item	2795944	et	4	main
üle	doc_670731433460_item	2795945	et	3	main
vajaduse	doc_670731433460_item	2795951	et	3	main
meie	doc_670731433460_item	2795963	et	4	main
või	doc_670731433460_item	2795965	et	4	main
a	doc_670731433460_item	2795969	et	4	main
b	doc_670731433460_item	2795971	et	4	main
tasemele	doc_670731433460_item	2795999	et	3	main
c	doc_670731433460_item	2796000	et	4	main
tasakesi	doc_670731433460_item	2796001	et	3	main
liita	doc_670731433460_item	2796010	et	4	main
ning	doc_670731433460_item	2796019	et	3	main
b	doc_670731433460_item	2796020	et	4	main
d	doc_670731433459_item	2795591	et	4	main
tasakaalule	doc_670731433459_item	2795592	et	3	main
c	doc_670731433459_item	2795600	et	4	main
d	doc_670731433459_item	2795603	et	4	main
6	doc_670731433459_item	2795606	et	2	main
b	doc_670731433459_item	2795609	et	4	main
ette	doc_670731433459_item	2795619	et	4	main
eest	doc_670731433459_item	2795621	et	4	main
ees	doc_670731433459_item	2795623	et	4	main
a	doc_670731433459_item	2795625	et	4	main
kirjutab	doc_670731433459_item	2795626	et	3	main
a	doc_670731433459_item	2795643	et	4	main
tulge	doc_670731433459_item	2795644	et	3	main
iga	doc_670731433460_item	2795657	et	4	main
abielupaar	doc_670731433460_item	2795665	et	4	main
ja	doc_670731433460_item	2795668	et	3	main
edur	doc_670731433460_item	2795670	et	4	main
räägivad	doc_670731433460_item	2795726	et	3	main
sugugi	doc_670731433460_item	2795734	et	4	main
mõlemal	doc_670731433460_item	2795739	et	3	main
agel	doc_670731433460_item	2795742	et	4	main
tervis	doc_670731433460_item	2795746	et	3	main
tervisega	doc_670731433460_item	2795747	et	3	main
murdma	doc_670731433460_item	2795750	et	3	main
järve	doc_670731433460_item	2795755	et	4	main
etendu	doc_670731433460_item	2795757	et	4	main
jalaluu	doc_670731433460_item	2795758	et	4	main
olema	doc_670731433460_item	2795766	et	4	main
pakkumisi	doc_670731433460_item	2795783	et	4	main
esinemised	doc_670731433460_item	2795796	et	4	main
on	doc_670731433460_item	2795797	et	4	main
liigne	doc_670731433459_item	2795635	et	3	main
b	doc_670731433459_item	2795645	et	4	main
c	doc_670731433459_item	2795647	et	4	main
külastage	doc_670731433459_item	2795648	et	3	main
inglismaal	doc_670731433460_item	2795680	et	4	main
londonis	doc_670731433460_item	2795681	et	4	main
age	doc_670731433460_item	2795682	et	4	main
on	doc_670731433460_item	2795683	et	4	main
kolmekümne	doc_670731433460_item	2795685	et	4	main
30	doc_670731433460_item	2795684	et	2	main
aastane	doc_670731433460_item	2795686	et	4	main
ja	doc_670731433460_item	2795687	et	3	main
toomas	doc_670731433460_item	2795688	et	3	main
on	doc_670731433460_item	2795689	et	4	main
32	doc_670731433460_item	2795690	et	2	main
kolmekümnekaks	doc_670731433460_item	2795691	et	4	main
aastat	doc_670731433460_item	2795692	et	3	main
vana	doc_670731433460_item	2795693	et	4	main
alates	doc_670731433460_item	2795694	et	3	main
1997a	doc_670731433460_item	2795695	et	4	main
tuhande	doc_670731433460_item	2795696	et	3	main
üheksasaja	doc_670731433460_item	2795697	et	4	main
üheksakümne	doc_670731433460_item	2795698	et	4	main
seitsmendal	doc_670731433460_item	2795699	et	3	main
on	doc_670731433460_item	2795700	et	4	main
nad	doc_670731433460_item	2795701	et	3	main
vabakutseline	doc_670731433460_item	2795702	et	4	main
vabakutselised	doc_670731433460_item	2795703	et	4	main
ja	doc_670731433460_item	2795704	et	3	main
esinevad	doc_670731433460_item	2795705	et	4	main
erinevad	doc_670731433460_item	2795706	et	4	main
teatrid	doc_670731433460_item	2795707	et	3	main
erinevates	doc_670731433460_item	2795708	et	4	main
teatris	doc_670731433460_item	2795709	et	3	main
inglismaal	doc_670731433460_item	2795710	et	4	main
armastama	doc_670731433460_item	2795711	et	3	main
armastavad	doc_670731433460_item	2795712	et	4	main
neid	doc_670731433460_item	2795713	et	4	main
väga	doc_670731433460_item	2795714	et	3	main
ning	doc_670731433460_item	2795715	et	3	main
isegi	doc_670731433460_item	2795716	et	4	main
aga	doc_670731433460_item	2795675	et	3	main
elavad	doc_670731433460_item	2795676	et	4	main
praegu	doc_670731433460_item	2795677	et	3	main
noored	doc_670731433460_item	2795727	et	3	main
noordetest	doc_670731433460_item	2795728	et	4	main
ülivõrdes	doc_670731433460_item	2795730	et	3	main
ja	doc_670731433460_item	2795740	et	3	main
on	doc_670731433460_item	2795743	et	4	main
olnud	doc_670731433460_item	2795744	et	4	main
probleeme	doc_670731433460_item	2795745	et	3	main
1990	doc_670731433460_item	2795748	et	2	main
aastal	doc_670731433460_item	2795749	et	3	main
etendus	doc_670731433460_item	2795756	et	4	main
pidama	doc_670731433460_item	2795760	et	4	main
tantsida	doc_670731433460_item	2795774	et	3	main
paaris	doc_670731433460_item	2795777	et	4	main
eraldi	doc_670731433460_item	2795785	et	4	main
suurele	doc_670731433460_item	2795788	et	4	main
oska	doc_670731433460_item	2795832	et	4	main
ütlema	doc_670731433460_item	2795834	et	3	main
sõna	doc_670731433460_item	2795847	et	4	main
teksti	doc_670731433460_item	2795848	et	4	main
alt	doc_670731433460_item	2795849	et	4	main
1	doc_670731433460_item	2795858	et	2	main
unusta	doc_670731433460_item	2795860	et	4	main
saada	doc_670731433460_item	2795866	et	4	main
just	doc_670731433460_item	2795869	et	3	main
teadmisi	doc_670731433460_item	2795893	et	4	main
oled	doc_670731433460_item	2795912	et	3	main
kontorist	doc_670731433460_item	2795917	et	4	main
postiasutusest	doc_670731433460_item	2795920	et	4	main
karmid	doc_670731433460_item	2795717	et	4	main
kriitikud	doc_670731433460_item	2795718	et	3	main
suhtuma	doc_670731433460_item	2795719	et	3	main
suhtuvad	doc_670731433460_item	2795720	et	4	main
artiklid	doc_670731433460_item	2795725	et	3	main
alati	doc_670731433460_item	2795735	et	4	main
nii	doc_670731433460_item	2795736	et	3	main
kergelt	doc_670731433460_item	2795737	et	4	main
naine	doc_670731433460_item	2795753	et	3	main
ja	doc_670731433460_item	2795759	et	3	main
pidis	doc_670731433460_item	2795761	et	4	main
on	doc_670731433460_item	2795767	et	4	main
age	doc_670731433460_item	2795768	et	4	main
ja	doc_670731433460_item	2795769	et	3	main
toomas	doc_670731433460_item	2795770	et	3	main
on	doc_670731433460_item	2795771	et	4	main
teineteisega	doc_670731433460_item	2795776	et	3	main
on	doc_670731433460_item	2795781	et	4	main
vaatamata	doc_670731433460_item	2795787	et	4	main
edule	doc_670731433460_item	2795789	et	3	main
täpselt	doc_670731433460_item	2795798	et	4	main
planeerima	doc_670731433460_item	2795799	et	3	main
planeerida	doc_670731433460_item	2795800	et	3	main
age	doc_670731433460_item	2795801	et	4	main
ja	doc_670731433460_item	2795802	et	3	main
toomas	doc_670731433460_item	2795803	et	3	main
tahavad	doc_670731433460_item	2795804	et	3	main
areneda	doc_670731433460_item	2795805	et	3	main
ja	doc_670731433460_item	2795806	et	3	main
veelgi	doc_670731433460_item	2795807	et	4	main
parem	doc_670731433460_item	2795808	et	4	main
parem	doc_670731433460_item	2795809	et	4	main
tantsida	doc_670731433460_item	2795810	et	3	main
märtsis	doc_670731433460_item	2795811	et	3	main
tulevad	doc_670731433460_item	2795812	et	4	main
nad	doc_670731433460_item	2795813	et	3	main
esinema	doc_670731433460_item	2795814	et	3	main
tallinn	doc_670731433460_item	2795815	et	4	main
tallinnas	doc_670731433460_item	2795816	et	4	main
ja	doc_670731433460_item	2795817	et	3	main
seejärel	doc_670731433460_item	2795818	et	3	main
sõidavad	doc_670731433460_item	2795819	et	3	main
lõuna-aafrika	doc_670731433460_item	2795820	et	4	main
kaua	doc_670731433460_item	2795823	et	3	main
oks	doc_670731433460_item	2795824	et	3	main
edur	doc_670731433460_item	2795826	et	4	main
veel	doc_670731433460_item	2795827	et	4	main
tipus	doc_670731433460_item	2795828	et	3	main
ei	doc_670731433460_item	2795831	et	4	main
nad	doc_670731433460_item	2795836	et	3	main
umbne	doc_670731433460_item	2795861	et	3	main
koduõppesüsteem	doc_670731433460_item	2795863	et	3	main
sul	doc_670731433460_item	2795865	et	3	main
2	doc_670731433460_item	2795868	et	2	main
seal	doc_670731433460_item	2795870	et	4	main
4	doc_670731433460_item	2795896	et	2	main
tasemele	doc_670731433460_item	2795897	et	3	main
hoida	doc_670731433460_item	2795905	et	3	main
vaja	doc_670731433460_item	2795907	et	4	main
registreerunud	doc_670731433460_item	2795914	et	4	main
või	doc_670731433460_item	2795918	et	4	main
lähimast	doc_670731433460_item	2795919	et	4	main
6	doc_670731433460_item	2795928	et	2	main
elada	doc_670731433460_item	2795838	et	3	main
üks	doc_670731433460_item	2795839	et	3	main
ühe	doc_670731433460_item	2795841	et	4	main
päeva	doc_670731433460_item	2795842	et	4	main
kaupa	doc_670731433460_item	2795843	et	4	main
kirjutage	doc_670731433460_item	2795844	et	3	main
lünka	doc_670731433460_item	2795845	et	4	main
iga	doc_670731433460_item	2795850	et	4	main
punkti	doc_670731433460_item	2795855	et	4	main
klassiruum	doc_670731433460_item	2795862	et	3	main
võimaldab	doc_670731433460_item	2795864	et	3	main
kus	doc_670731433460_item	2795871	et	3	main
ja	doc_670731433460_item	2795872	et	3	main
millal	doc_670731433460_item	2795873	et	3	main
sa	doc_670731433460_item	2795874	et	3	main
seda	doc_670731433460_item	2795875	et	3	main
parasjagu	doc_670731433460_item	2795876	et	3	main
soovid	doc_670731433460_item	2795877	et	4	main
käes	doc_670731433460_item	2795878	et	4	main
on	doc_670731433460_item	2795879	et	4	main
interaktiivse	doc_670731433460_item	2795880	et	3	main
õppe	doc_670731433460_item	2795881	et	4	main
ajastu	doc_670731433460_item	2795882	et	4	main
mis	doc_670731433460_item	2795883	et	4	main
annab	doc_670731433460_item	2795884	et	3	main
sulle	doc_670731433460_item	2795885	et	3	main
3	doc_670731433460_item	2795886	et	2	main
vabaduse	doc_670731433460_item	2795887	et	4	main
planeerida	doc_670731433460_item	2795888	et	3	main
aega	doc_670731433460_item	2795889	et	4	main
ning	doc_670731433460_item	2795890	et	3	main
eelise	doc_670731433460_item	2795891	et	4	main
omandada	doc_670731433460_item	2795892	et	3	main
raha	doc_670731433460_item	2795900	et	4	main
seda	doc_670731433460_item	2795902	et	3	main
kursusele	doc_670731433460_item	2795913	et	3	main
igal	doc_670731433460_item	2795921	et	3	main
ning	doc_670731433460_item	2795929	et	3	main
7	doc_670731433460_item	2795932	et	2	main
täidetud	doc_670731433460_item	2795938	et	4	main
8	doc_670731433460_item	2795946	et	2	main
ning	doc_670731433460_item	2795949	et	3	main
tekkinud	doc_670731433460_item	2795954	et	4	main
lisaküsimustele	doc_670731433460_item	2795955	et	4	main
kõik	doc_670731433460_item	2795956	et	4	main
geniaalne	doc_670731433460_item	2795957	et	3	main
virtuaalkodu	doc_670731433460_item	2795964	et	4	main
postitage	doc_670731433460_item	2795966	et	3	main
sobid	doc_670731433460_item	2795970	et	4	main
b	doc_670731433460_item	2796008	et	4	main
kokku	doc_670731433460_item	2796009	et	3	main
a	doc_670731433460_item	2796018	et	4	main
7	doc_670731433460_item	2796026	et	2	main
8	doc_670731433460_item	2796035	et	2	main
a	doc_670731433460_item	2796036	et	4	main
9	doc_670731433460_item	2796044	et	2	main
libe	doc_670731433460_item	2796048	et	3	main
liikuv	doc_670731433460_item	2796050	et	4	main
d	doc_670731433460_item	2796051	et	4	main
lihtne	doc_670731433460_item	2796052	et	3	main
10	doc_670731433460_item	2796053	et	2	main
avage	doc_670731433461_item	2796063	et	3	main
kirjutage	doc_670731433461_item	2796066	et	3	main
õige	doc_670731433461_item	2796069	et	4	main
on	doc_670731433461_item	2796082	et	4	main
pärit	doc_670731433461_item	2796083	et	3	main
elavad	doc_670731433461_item	2796087	et	4	main
ja	doc_670731433461_item	2796098	et	3	main
kolmkümmend	doc_670731433461_item	2796102	et	4	main
aastat	doc_670731433461_item	2796104	et	3	main
seitsest	doc_670731433461_item	2796112	et	4	main
armastama	doc_670731433461_item	2796125	et	3	main
neid	doc_670731433461_item	2796127	et	4	main
väga	doc_670731433461_item	2796128	et	3	main
üldiselt	doc_670731433461_item	2796136	et	4	main
hästi	doc_670731433461_item	2796137	et	3	main
viimased	doc_670731433461_item	2796138	et	3	main
artiklid	doc_670731433461_item	2796139	et	3	main
räägivad	doc_670731433461_item	2796140	et	3	main
noored	doc_670731433461_item	2796141	et	3	main
nooredest	doc_670731433461_item	2796142	et	4	main
alati	doc_670731433461_item	2796149	et	4	main
läinud	doc_670731433461_item	2796152	et	4	main
on	doc_670731433461_item	2796157	et	4	main
olnud	doc_670731433461_item	2796158	et	4	main
1990	doc_670731433461_item	2796162	et	2	main
aastal	doc_670731433461_item	2796163	et	3	main
luikede	doc_670731433461_item	2796168	et	3	main
kuigi	doc_670731433461_item	2796192	et	3	main
eraldi	doc_670731433461_item	2796199	et	4	main
tantsijad	doc_670731433461_item	2796205	et	4	main
tagasihoidlik	doc_670731433461_item	2796206	et	3	main
esinemised	doc_670731433461_item	2796210	et	4	main
veelgi	doc_670731433461_item	2796221	et	4	main
tantsida	doc_670731433461_item	2796224	et	3	main
tallinn	doc_670731433461_item	2796229	et	4	main
oska	doc_670731433461_item	2796246	et	4	main
nad	doc_670731433461_item	2796247	et	3	main
eelistavad	doc_670731433461_item	2796251	et	4	main
üks	doc_670731433461_item	2796253	et	3	main
sobiv	doc_670731433461_item	2796260	et	4	main
saada	doc_670731433461_item	2796280	et	4	main
on	doc_670731433461_item	2796293	et	4	main
interaktiivse	doc_670731433461_item	2796294	et	3	main
vastavalt	doc_670731433461_item	2796308	et	4	main
on	doc_670731433461_item	2796313	et	4	main
on	doc_670731433461_item	2796320	et	4	main
vaja	doc_670731433461_item	2796321	et	4	main
tarkust	doc_670731433461_item	2796324	et	4	main
registreerunud	doc_670731433461_item	2796328	et	4	main
meie	doc_670731433461_item	2796330	et	4	main
kontorist	doc_670731433461_item	2796331	et	4	main
kätte	doc_670731433461_item	2796337	et	4	main
õppematerjalid	doc_670731433461_item	2796338	et	3	main
kättesaamisel	doc_670731433460_item	2795936	et	4	main
õpetaja	doc_670731433460_item	2795942	et	4	main
vaatab	doc_670731433460_item	2795943	et	3	main
vead	doc_670731433460_item	2795948	et	4	main
korral	doc_670731433460_item	2795952	et	4	main
10	doc_670731433460_item	2795961	et	2	main
külastage	doc_670731433460_item	2795962	et	3	main
soovid	doc_670731433460_item	2795972	et	4	main
c	doc_670731433460_item	2795973	et	4	main
soovitad	doc_670731433460_item	2795974	et	3	main
d	doc_670731433460_item	2795975	et	4	main
solvud	doc_670731433460_item	2795976	et	3	main
2	doc_670731433460_item	2795977	et	2	main
a	doc_670731433460_item	2795978	et	4	main
just	doc_670731433460_item	2795979	et	3	main
b	doc_670731433460_item	2795980	et	4	main
seega	doc_670731433460_item	2795981	et	4	main
c	doc_670731433460_item	2795982	et	4	main
kuigi	doc_670731433460_item	2795983	et	3	main
d	doc_670731433460_item	2795984	et	4	main
siiski	doc_670731433460_item	2795985	et	4	main
3	doc_670731433460_item	2795986	et	2	main
a	doc_670731433460_item	2795987	et	4	main
vajaduse	doc_670731433460_item	2795988	et	3	main
b	doc_670731433460_item	2795989	et	4	main
vabanduse	doc_670731433460_item	2795990	et	4	main
c	doc_670731433460_item	2795991	et	4	main
varanduse	doc_670731433460_item	2795992	et	3	main
d	doc_670731433460_item	2795993	et	4	main
vabaduse	doc_670731433460_item	2795994	et	4	main
4	doc_670731433460_item	2795995	et	2	main
a	doc_670731433460_item	2795996	et	4	main
tasule	doc_670731433460_item	2795997	et	3	main
b	doc_670731433460_item	2795998	et	4	main
kätte	doc_670731433460_item	2795923	et	4	main
helikasseti	doc_670731433460_item	2795927	et	4	main
eest	doc_670731433460_item	2795933	et	4	main
kodutöö	doc_670731433460_item	2795939	et	4	main
meile	doc_670731433460_item	2795940	et	4	main
tagasi	doc_670731433460_item	2795941	et	3	main
ka	doc_670731433460_item	2795953	et	3	main
1	doc_670731433460_item	2795968	et	2	main
saada	doc_670731433460_item	2796007	et	4	main
d	doc_670731433460_item	2796024	et	4	main
b	doc_670731433460_item	2796029	et	4	main
ette	doc_670731433460_item	2796030	et	4	main
eest	doc_670731433460_item	2796032	et	4	main
kirjutab	doc_670731433460_item	2796037	et	3	main
liigne	doc_670731433460_item	2796046	et	3	main
b	doc_670731433460_item	2796047	et	4	main
c	doc_670731433460_item	2796049	et	4	main
d	doc_670731433460_item	2796060	et	4	main
minge	doc_670731433460_item	2796061	et	3	main
iga	doc_670731433461_item	2796068	et	4	main
vastus	doc_670731433461_item	2796070	et	3	main
maailmakuulsad	doc_670731433461_item	2796074	et	3	main
balletitantsijad	doc_670731433461_item	2796075	et	3	main
abielupaar	doc_670731433461_item	2796076	et	4	main
eesti	doc_670731433461_item	2796084	et	4	main
age	doc_670731433461_item	2796093	et	4	main
30	doc_670731433461_item	2796095	et	2	main
üheksasaja	doc_670731433461_item	2796109	et	4	main
on	doc_670731433461_item	2796114	et	4	main
nad	doc_670731433461_item	2796115	et	3	main
vabakutselised	doc_670731433461_item	2796117	et	4	main
teatrid	doc_670731433461_item	2796121	et	3	main
suhtuvad	doc_670731433461_item	2796134	et	4	main
agel	doc_670731433461_item	2796156	et	4	main
naine	doc_670731433461_item	2796167	et	3	main
nemad	doc_670731433461_item	2796193	et	3	main
tehtud	doc_670731433461_item	2796196	et	4	main
pakkumisi	doc_670731433461_item	2796197	et	4	main
ka	doc_670731433461_item	2796198	et	3	main
elavad	doc_670731433461_item	2796204	et	4	main
lähiaja	doc_670731433461_item	2796209	et	3	main
planeeritud	doc_670731433461_item	2796214	et	4	main
ja	doc_670731433461_item	2796216	et	3	main
areneda	doc_670731433461_item	2796219	et	3	main
esinema	doc_670731433461_item	2796228	et	3	main
lõuna-aafrika	doc_670731433461_item	2796234	et	4	main
lünka	doc_670731433461_item	2796259	et	4	main
targemaks	doc_670731433461_item	2796281	et	4	main
2	doc_670731433461_item	2796282	et	2	main
õppe	doc_670731433461_item	2796295	et	4	main
aega	doc_670731433461_item	2796303	et	4	main
omandada	doc_670731433461_item	2796306	et	3	main
tasemele	doc_670731433461_item	2796311	et	3	main
pisut	doc_670731433461_item	2796323	et	3	main
lähimast	doc_670731433461_item	2796333	et	4	main
helikasseti	doc_670731433461_item	2796341	et	4	main
6	doc_670731433461_item	2796342	et	2	main
ning	doc_670731433461_item	2796343	et	3	main
7	doc_670731433461_item	2796346	et	2	main
eest	doc_670731433461_item	2796347	et	4	main
kättesaamisel	doc_670731433461_item	2796350	et	4	main
korral	doc_670731433461_item	2796366	et	4	main
lisaküsimustele	doc_670731433461_item	2796369	et	4	main
9	doc_670731433461_item	2796373	et	2	main
b	doc_670731433461_item	2796385	et	4	main
soovid	doc_670731433461_item	2796386	et	4	main
solvud	doc_670731433461_item	2796390	et	3	main
seega	doc_670731433461_item	2796395	et	4	main
vajaduse	doc_670731433461_item	2796402	et	3	main
b	doc_670731433461_item	2796403	et	4	main
d	doc_670731433461_item	2796407	et	4	main
4	doc_670731433461_item	2796409	et	2	main
tasule	doc_670731433461_item	2796411	et	3	main
b	doc_670731433461_item	2796422	et	4	main
kokku	doc_670731433461_item	2796423	et	3	main
liita	doc_670731433461_item	2796424	et	4	main
b	doc_670731433461_item	2796434	et	4	main
vaid	doc_670731433461_item	2796435	et	3	main
et	doc_670731433461_item	2796439	et	3	main
taga	doc_670731433461_item	2796442	et	4	main
b	doc_670731433461_item	2796461	et	4	main
libe	doc_670731433461_item	2796462	et	3	main
kursuse	doc_670731433460_item	2795931	et	3	main
tasud	doc_670731433460_item	2795934	et	4	main
selle	doc_670731433460_item	2795935	et	4	main
parandab	doc_670731433460_item	2795947	et	3	main
vastab	doc_670731433460_item	2795950	et	3	main
on	doc_670731433460_item	2795958	et	4	main
9	doc_670731433460_item	2795959	et	2	main
lihtne	doc_670731433460_item	2795960	et	3	main
kupong	doc_670731433460_item	2795967	et	3	main
a	doc_670731433460_item	2796005	et	4	main
kokku	doc_670731433460_item	2796006	et	3	main
hoida	doc_670731433460_item	2796013	et	3	main
d	doc_670731433460_item	2796014	et	4	main
kokku	doc_670731433460_item	2796015	et	3	main
panna	doc_670731433460_item	2796016	et	4	main
6	doc_670731433460_item	2796017	et	2	main
kuid	doc_670731433460_item	2796023	et	4	main
a	doc_670731433460_item	2796027	et	4	main
c	doc_670731433460_item	2796031	et	4	main
d	doc_670731433460_item	2796033	et	4	main
a	doc_670731433460_item	2796045	et	4	main
a	doc_670731433460_item	2796054	et	4	main
tulge	doc_670731433460_item	2796055	et	3	main
b	doc_670731433460_item	2796056	et	4	main
käige	doc_670731433460_item	2796057	et	3	main
c	doc_670731433460_item	2796058	et	4	main
külastage	doc_670731433460_item	2796059	et	3	main
numbrid	doc_670731433461_item	2796065	et	3	main
sõnadega	doc_670731433461_item	2796067	et	3	main
annab	doc_670731433461_item	2796071	et	3	main
punkti	doc_670731433461_item	2796073	et	4	main
londonis	doc_670731433461_item	2796092	et	4	main
aastane	doc_670731433461_item	2796097	et	4	main
üheksa	doc_670731433461_item	2796110	et	4	main
d	doc_670731433460_item	2796002	et	4	main
tasakaalule	doc_670731433460_item	2796003	et	3	main
5	doc_670731433460_item	2796004	et	2	main
c	doc_670731433460_item	2796011	et	4	main
kokku	doc_670731433460_item	2796012	et	3	main
vaid	doc_670731433460_item	2796021	et	3	main
et	doc_670731433460_item	2796025	et	3	main
ees	doc_670731433460_item	2796034	et	4	main
muudab	doc_670731433460_item	2796043	et	3	main
harjutus	doc_670731433461_item	2796062	et	4	main
ühe	doc_670731433461_item	2796072	et	4	main
age	doc_670731433461_item	2796077	et	4	main
oks	doc_670731433461_item	2796078	et	3	main
ja	doc_670731433461_item	2796079	et	3	main
toomas	doc_670731433461_item	2796080	et	3	main
edur	doc_670731433461_item	2796081	et	4	main
aga	doc_670731433461_item	2796086	et	3	main
praegu	doc_670731433461_item	2796088	et	3	main
london	doc_670731433461_item	2796090	et	4	main
inglismaal	doc_670731433461_item	2796091	et	4	main
on	doc_670731433461_item	2796094	et	4	main
toomas	doc_670731433461_item	2796099	et	3	main
32	doc_670731433461_item	2796101	et	2	main
kaks	doc_670731433461_item	2796103	et	3	main
kümmand	doc_670731433461_item	2796111	et	4	main
inglismaal	doc_670731433461_item	2796124	et	4	main
nendesse	doc_670731433461_item	2796135	et	4	main
kuid	doc_670731433461_item	2796145	et	4	main
kõik	doc_670731433461_item	2796146	et	4	main
pole	doc_670731433461_item	2796147	et	3	main
kergelt	doc_670731433461_item	2796151	et	4	main
mõlemal	doc_670731433461_item	2796153	et	3	main
murdus	doc_670731433461_item	2796165	et	3	main
ainult	doc_670731433461_item	2796189	et	4	main
suurele	doc_670731433461_item	2796202	et	4	main
edule	doc_670731433461_item	2796203	et	3	main
nende	doc_670731433461_item	2796208	et	4	main
planeerima	doc_670731433461_item	2796213	et	3	main
age	doc_670731433461_item	2796215	et	4	main
c	doc_670731433460_item	2796022	et	4	main
taga	doc_670731433460_item	2796028	et	4	main
b	doc_670731433460_item	2796038	et	4	main
palub	doc_670731433460_item	2796039	et	3	main
c	doc_670731433460_item	2796040	et	4	main
parandab	doc_670731433460_item	2796041	et	3	main
d	doc_670731433460_item	2796042	et	4	main
sulud	doc_670731433461_item	2796064	et	3	main
eestist	doc_670731433461_item	2796085	et	3	main
inglismaa	doc_670731433461_item	2796089	et	4	main
kolmekümne	doc_670731433461_item	2796096	et	4	main
on	doc_670731433461_item	2796100	et	4	main
vana	doc_670731433461_item	2796105	et	4	main
alates	doc_670731433461_item	2796106	et	3	main
1997a	doc_670731433461_item	2796107	et	4	main
tuhande	doc_670731433461_item	2796108	et	3	main
aastast	doc_670731433461_item	2796113	et	4	main
vabakutseline	doc_670731433461_item	2796116	et	4	main
ja	doc_670731433461_item	2796118	et	3	main
erinevad	doc_670731433461_item	2796120	et	4	main
esinevad	doc_670731433461_item	2796119	et	4	main
erinevatedes	doc_670731433461_item	2796122	et	4	main
teatrides	doc_670731433461_item	2796123	et	4	main
armastakse	doc_670731433461_item	2796126	et	4	main
ning	doc_670731433461_item	2796129	et	3	main
isegi	doc_670731433461_item	2796130	et	4	main
sugugi	doc_670731433461_item	2796148	et	4	main
probleeme	doc_670731433461_item	2796159	et	3	main
tervis	doc_670731433461_item	2796160	et	3	main
tervisega	doc_670731433461_item	2796161	et	3	main
murdma	doc_670731433461_item	2796164	et	3	main
paaris	doc_670731433461_item	2796191	et	4	main
nendele	doc_670731433461_item	2796194	et	4	main
tantsimiseks	doc_670731433461_item	2796200	et	4	main
tagasihoidlikuks	doc_670731433461_item	2796207	et	3	main
on	doc_670731433461_item	2796211	et	4	main
tahavad	doc_670731433461_item	2796218	et	3	main
ja	doc_670731433461_item	2796220	et	3	main
märtsis	doc_670731433461_item	2796225	et	3	main
ja	doc_670731433461_item	2796231	et	3	main
ei	doc_670731433461_item	2796245	et	4	main
nad	doc_670731433461_item	2796250	et	3	main
elada	doc_670731433461_item	2796252	et	3	main
ühe	doc_670731433461_item	2796255	et	4	main
kaupa	doc_670731433461_item	2796257	et	4	main
kirjutage	doc_670731433461_item	2796258	et	3	main
alt	doc_670731433461_item	2796263	et	4	main
koduõppesüsteem	doc_670731433461_item	2796277	et	3	main
võimaldab	doc_670731433461_item	2796278	et	3	main
sul	doc_670731433461_item	2796279	et	3	main
käes	doc_670731433461_item	2796292	et	4	main
3	doc_670731433461_item	2796300	et	2	main
vabaduse	doc_670731433461_item	2796301	et	4	main
planeerida	doc_670731433461_item	2796302	et	3	main
eelise	doc_670731433461_item	2796305	et	4	main
4	doc_670731433461_item	2796310	et	2	main
aeg	doc_670731433461_item	2796312	et	3	main
5	doc_670731433461_item	2796317	et	2	main
kokku	doc_670731433461_item	2796318	et	3	main
hoida	doc_670731433461_item	2796319	et	3	main
karmid	doc_670731433461_item	2796131	et	4	main
kriitikud	doc_670731433461_item	2796132	et	3	main
suhtuma	doc_670731433461_item	2796133	et	3	main
ainult	doc_670731433461_item	2796143	et	4	main
ülivõrdes	doc_670731433461_item	2796144	et	3	main
nii	doc_670731433461_item	2796150	et	3	main
ja	doc_670731433461_item	2796154	et	3	main
eriti	doc_670731433461_item	2796155	et	3	main
noor	doc_670731433461_item	2796166	et	3	main
etendus	doc_670731433461_item	2796170	et	4	main
etendusel	doc_670731433461_item	2796171	et	4	main
järve	doc_670731433461_item	2796169	et	4	main
jalaluu	doc_670731433461_item	2796172	et	4	main
ja	doc_670731433461_item	2796173	et	3	main
pidama	doc_670731433461_item	2796174	et	4	main
pidas	doc_670731433461_item	2796175	et	3	main
mõnda	doc_670731433461_item	2796176	et	4	main
aega	doc_670731433461_item	2796177	et	4	main
tantsimisest	doc_670731433461_item	2796178	et	4	main
eemal	doc_670731433461_item	2796179	et	3	main
olema	doc_670731433461_item	2796180	et	4	main
olema	doc_670731433461_item	2796181	et	4	main
age	doc_670731433461_item	2796182	et	4	main
ja	doc_670731433461_item	2796183	et	3	main
toomas	doc_670731433461_item	2796184	et	3	main
on	doc_670731433461_item	2796185	et	4	main
otsustanud	doc_670731433461_item	2796186	et	4	main
tantsima	doc_670731433461_item	2796187	et	3	main
tantsida	doc_670731433461_item	2796188	et	3	main
teineteisega	doc_670731433461_item	2796190	et	3	main
on	doc_670731433461_item	2796195	et	4	main
vaatamata	doc_670731433461_item	2796201	et	4	main
täpselt	doc_670731433461_item	2796212	et	4	main
toomas	doc_670731433461_item	2796217	et	3	main
parem	doc_670731433461_item	2796222	et	4	main
parem	doc_670731433461_item	2796223	et	4	main
nad	doc_670731433461_item	2796227	et	3	main
seejärel	doc_670731433461_item	2796232	et	3	main
kui	doc_670731433461_item	2796236	et	3	main
veel	doc_670731433461_item	2796241	et	4	main
tipus	doc_670731433461_item	2796242	et	3	main
suudavad	doc_670731433461_item	2796243	et	3	main
püsida	doc_670731433461_item	2796244	et	3	main
ütelda	doc_670731433461_item	2796249	et	4	main
sõna	doc_670731433461_item	2796261	et	4	main
ja	doc_670731433461_item	2796286	et	3	main
millal	doc_670731433461_item	2796287	et	3	main
sa	doc_670731433461_item	2796288	et	3	main
seda	doc_670731433461_item	2796289	et	3	main
parasjagu	doc_670731433461_item	2796290	et	3	main
soovid	doc_670731433461_item	2796291	et	4	main
mis	doc_670731433461_item	2796297	et	4	main
annab	doc_670731433461_item	2796298	et	3	main
sulle	doc_670731433461_item	2796299	et	3	main
individuaalsele	doc_670731433461_item	2796309	et	3	main
oled	doc_670731433461_item	2796326	et	3	main
kursusele	doc_670731433461_item	2796327	et	3	main
saad	doc_670731433461_item	2796329	et	4	main
igal	doc_670731433461_item	2796335	et	3	main
kuul	doc_670731433461_item	2796336	et	4	main
kodutöö	doc_670731433461_item	2796344	et	4	main
kursuse	doc_670731433461_item	2796345	et	3	main
saada	doc_670731433461_item	2796351	et	4	main
kodutöö	doc_670731433461_item	2796353	et	4	main
tagasi	doc_670731433461_item	2796355	et	3	main
õpetaja	doc_670731433461_item	2796356	et	4	main
vaatab	doc_670731433461_item	2796357	et	3	main
geniaalne	doc_670731433461_item	2796371	et	3	main
lihtne	doc_670731433461_item	2796374	et	3	main
sobid	doc_670731433461_item	2796384	et	4	main
c	doc_670731433461_item	2796396	et	4	main
kuigi	doc_670731433461_item	2796397	et	3	main
vabanduse	doc_670731433461_item	2796404	et	4	main
saada	doc_670731433461_item	2796421	et	4	main
6	doc_670731433461_item	2796431	et	2	main
a	doc_670731433461_item	2796432	et	4	main
ning	doc_670731433461_item	2796433	et	3	main
d	doc_670731433461_item	2796438	et	4	main
ette	doc_670731433461_item	2796444	et	4	main
eest	doc_670731433461_item	2796446	et	4	main
d	doc_670731433461_item	2796447	et	4	main
a	doc_670731433461_item	2796450	et	4	main
palub	doc_670731433461_item	2796453	et	3	main
parandab	doc_670731433461_item	2796455	et	3	main
d	doc_670731433461_item	2796456	et	4	main
muudab	doc_670731433461_item	2796457	et	3	main
9	doc_670731433461_item	2796458	et	2	main
a	doc_670731433461_item	2796459	et	4	main
liigne	doc_670731433461_item	2796460	et	3	main
10	doc_670731433461_item	2796467	et	2	main
b	doc_670731433461_item	2796470	et	4	main
d	doc_670731433461_item	2796474	et	4	main
harjutus	doc_670731433462_item	2796476	et	4	main
sulud	doc_670731433462_item	2796478	et	3	main
sõnadega	doc_670731433462_item	2796481	et	3	main
vana	doc_670731433462_item	2796519	et	4	main
tulevad	doc_670731433461_item	2796226	et	4	main
tallinnasse	doc_670731433461_item	2796230	et	3	main
sõidavad	doc_670731433461_item	2796233	et	3	main
lõuna-aafrikale	doc_670731433461_item	2796235	et	4	main
kaua	doc_670731433461_item	2796237	et	3	main
oks	doc_670731433461_item	2796238	et	3	main
ja	doc_670731433461_item	2796239	et	3	main
edur	doc_670731433461_item	2796240	et	4	main
ütlema	doc_670731433461_item	2796248	et	3	main
päev	doc_670731433461_item	2796254	et	3	main
päeva	doc_670731433461_item	2796256	et	4	main
teksti	doc_670731433461_item	2796262	et	4	main
iga	doc_670731433461_item	2796264	et	4	main
õige	doc_670731433461_item	2796265	et	4	main
vastus	doc_670731433461_item	2796266	et	3	main
annab	doc_670731433461_item	2796267	et	3	main
ühe	doc_670731433461_item	2796268	et	4	main
punkti	doc_670731433461_item	2796269	et	4	main
õpi	doc_670731433461_item	2796270	et	4	main
millal	doc_670731433461_item	2796271	et	3	main
1	doc_670731433461_item	2796272	et	2	main
soovid	doc_670731433461_item	2796273	et	4	main
unusta	doc_670731433461_item	2796274	et	4	main
umbne	doc_670731433461_item	2796275	et	3	main
klassiruum	doc_670731433461_item	2796276	et	3	main
just	doc_670731433461_item	2796283	et	3	main
seal	doc_670731433461_item	2796284	et	4	main
kus	doc_670731433461_item	2796285	et	3	main
ajastu	doc_670731433461_item	2796296	et	4	main
ning	doc_670731433461_item	2796304	et	3	main
teadmisi	doc_670731433461_item	2796307	et	4	main
raha	doc_670731433461_item	2796314	et	4	main
et	doc_670731433461_item	2796315	et	3	main
seda	doc_670731433461_item	2796316	et	3	main
ka	doc_670731433461_item	2796322	et	3	main
postiasutusest	doc_670731433461_item	2796334	et	4	main
täidetud	doc_670731433461_item	2796352	et	4	main
vead	doc_670731433461_item	2796362	et	4	main
ning	doc_670731433461_item	2796363	et	3	main
vastab	doc_670731433461_item	2796364	et	3	main
kõik	doc_670731433461_item	2796370	et	4	main
külastage	doc_670731433461_item	2796376	et	3	main
või	doc_670731433461_item	2796379	et	4	main
postitage	doc_670731433461_item	2796380	et	3	main
kupong	doc_670731433461_item	2796381	et	3	main
1	doc_670731433461_item	2796382	et	2	main
c	doc_670731433461_item	2796387	et	4	main
a	doc_670731433461_item	2796392	et	4	main
3	doc_670731433461_item	2796400	et	2	main
a	doc_670731433461_item	2796401	et	4	main
varanduse	doc_670731433461_item	2796406	et	3	main
a	doc_670731433461_item	2796419	et	4	main
kokku	doc_670731433461_item	2796420	et	3	main
kuid	doc_670731433461_item	2796437	et	4	main
a	doc_670731433461_item	2796441	et	4	main
8	doc_670731433461_item	2796449	et	2	main
a	doc_670731433461_item	2796468	et	4	main
c	doc_670731433461_item	2796472	et	4	main
numbrid	doc_670731433462_item	2796479	et	3	main
kirjutage	doc_670731433462_item	2796480	et	3	main
aastat	doc_670731433462_item	2796518	et	3	main
1997a	doc_670731433462_item	2796521	et	4	main
nad	doc_670731433462_item	2796528	et	3	main
teatrid	doc_670731433462_item	2796534	et	3	main
armastama	doc_670731433462_item	2796538	et	3	main
ning	doc_670731433462_item	2796542	et	3	main
räägivad	doc_670731433462_item	2796553	et	3	main
ainult	doc_670731433462_item	2796556	et	4	main
olla	doc_670731433462_item	2796594	et	3	main
ja	doc_670731433462_item	2796596	et	3	main
on	doc_670731433462_item	2796598	et	4	main
tehtud	doc_670731433462_item	2796609	et	4	main
planeeritud	doc_670731433462_item	2796627	et	4	main
age	doc_670731433462_item	2796628	et	4	main
parem	doc_670731433462_item	2796635	et	4	main
esinema	doc_670731433462_item	2796641	et	3	main
veel	doc_670731433462_item	2796654	et	4	main
oska	doc_670731433462_item	2796659	et	4	main
üks	doc_670731433462_item	2796666	et	3	main
sobiv	doc_670731433462_item	2796673	et	4	main
sõna	doc_670731433462_item	2796674	et	4	main
alt	doc_670731433462_item	2796676	et	4	main
annab	doc_670731433462_item	2796711	et	3	main
sulle	doc_670731433462_item	2796712	et	3	main
aega	doc_670731433462_item	2796716	et	4	main
individuaalsele	doc_670731433462_item	2796722	et	3	main
on	doc_670731433462_item	2796726	et	4	main
postiasutusest	doc_670731433462_item	2796747	et	4	main
ning	doc_670731433462_item	2796756	et	3	main
eest	doc_670731433462_item	2796760	et	4	main
täidetud	doc_670731433462_item	2796765	et	4	main
lisaküsimustele	doc_670731433462_item	2796782	et	4	main
lihtne	doc_670731433462_item	2796787	et	3	main
b	doc_670731433462_item	2796798	et	4	main
soovid	doc_670731433462_item	2796799	et	4	main
a	doc_670731433462_item	2796814	et	4	main
vajaduse	doc_670731433462_item	2796815	et	3	main
vabaduse	doc_670731433462_item	2796821	et	4	main
tasakesi	doc_670731433462_item	2796828	et	3	main
tasakaalule	doc_670731433462_item	2796830	et	3	main
a	doc_670731433462_item	2796832	et	4	main
kokku	doc_670731433462_item	2796833	et	3	main
saada	doc_670731433462_item	2796834	et	4	main
d	doc_670731433462_item	2796841	et	4	main
kokku	doc_670731433462_item	2796842	et	3	main
panna	doc_670731433462_item	2796843	et	4	main
6	doc_670731433462_item	2796844	et	2	main
kui	doc_670731433461_item	2796325	et	3	main
või	doc_670731433461_item	2796332	et	4	main
raamatu	doc_670731433461_item	2796339	et	4	main
ja	doc_670731433461_item	2796340	et	3	main
selle	doc_670731433461_item	2796349	et	4	main
meile	doc_670731433461_item	2796354	et	4	main
selle	doc_670731433461_item	2796358	et	4	main
üle	doc_670731433461_item	2796359	et	3	main
8	doc_670731433461_item	2796360	et	2	main
parandab	doc_670731433461_item	2796361	et	3	main
tekkinud	doc_670731433461_item	2796368	et	4	main
on	doc_670731433461_item	2796372	et	4	main
10	doc_670731433461_item	2796375	et	2	main
meie	doc_670731433461_item	2796377	et	4	main
virtuaalkodu	doc_670731433461_item	2796378	et	4	main
d	doc_670731433461_item	2796389	et	4	main
2	doc_670731433461_item	2796391	et	2	main
just	doc_670731433461_item	2796393	et	3	main
b	doc_670731433461_item	2796394	et	4	main
siiski	doc_670731433461_item	2796399	et	4	main
vabaduse	doc_670731433461_item	2796408	et	4	main
tasud	doc_670731433461_item	2796348	et	4	main
vajaduse	doc_670731433461_item	2796365	et	3	main
ka	doc_670731433461_item	2796367	et	3	main
a	doc_670731433461_item	2796383	et	4	main
soovitad	doc_670731433461_item	2796388	et	3	main
d	doc_670731433461_item	2796398	et	4	main
c	doc_670731433461_item	2796405	et	4	main
a	doc_670731433461_item	2796410	et	4	main
b	doc_670731433461_item	2796412	et	4	main
tasemele	doc_670731433461_item	2796413	et	3	main
c	doc_670731433461_item	2796414	et	4	main
tasakesi	doc_670731433461_item	2796415	et	3	main
d	doc_670731433461_item	2796416	et	4	main
tasakaalule	doc_670731433461_item	2796417	et	3	main
5	doc_670731433461_item	2796418	et	2	main
d	doc_670731433461_item	2796428	et	4	main
kokku	doc_670731433461_item	2796429	et	3	main
panna	doc_670731433461_item	2796430	et	4	main
b	doc_670731433461_item	2796443	et	4	main
c	doc_670731433461_item	2796445	et	4	main
kirjutab	doc_670731433461_item	2796451	et	3	main
c	doc_670731433461_item	2796463	et	4	main
liikuv	doc_670731433461_item	2796464	et	4	main
tulge	doc_670731433461_item	2796469	et	3	main
käige	doc_670731433461_item	2796471	et	3	main
minge	doc_670731433461_item	2796475	et	3	main
avage	doc_670731433462_item	2796477	et	3	main
iga	doc_670731433462_item	2796482	et	4	main
tuhande	doc_670731433462_item	2796522	et	3	main
üheksakümne	doc_670731433462_item	2796524	et	4	main
seitsmendast	doc_670731433462_item	2796525	et	3	main
aastast	doc_670731433462_item	2796526	et	4	main
ja	doc_670731433462_item	2796531	et	3	main
erinevaid	doc_670731433462_item	2796535	et	4	main
nendesse	doc_670731433462_item	2796548	et	4	main
noortele	doc_670731433462_item	2796555	et	3	main
kuid	doc_670731433462_item	2796558	et	4	main
pole	doc_670731433462_item	2796560	et	3	main
eriti	doc_670731433462_item	2796568	et	3	main
probleeme	doc_670731433462_item	2796572	et	3	main
murdma	doc_670731433462_item	2796577	et	3	main
naine	doc_670731433462_item	2796580	et	3	main
pidab	doc_670731433462_item	2796588	et	4	main
mõnda	doc_670731433462_item	2796589	et	4	main
aega	doc_670731433462_item	2796590	et	4	main
paaris	doc_670731433462_item	2796604	et	4	main
kuigi	doc_670731433462_item	2796605	et	3	main
nemad	doc_670731433462_item	2796606	et	3	main
ka	doc_670731433462_item	2796611	et	3	main
vaatamata	doc_670731433462_item	2796614	et	4	main
esinemised	doc_670731433462_item	2796623	et	4	main
toomas	doc_670731433462_item	2796630	et	3	main
parem	doc_670731433462_item	2796636	et	4	main
nad	doc_670731433462_item	2796640	et	3	main
ja	doc_670731433462_item	2796652	et	3	main
püsida	doc_670731433462_item	2796657	et	3	main
ütlema	doc_670731433462_item	2796661	et	3	main
ütleda	doc_670731433462_item	2796662	et	4	main
nad	doc_670731433462_item	2796663	et	3	main
õige	doc_670731433462_item	2796678	et	4	main
raha	doc_670731433462_item	2796727	et	4	main
saada	doc_670731433462_item	2796732	et	4	main
kontorist	doc_670731433462_item	2796744	et	4	main
kodutöö	doc_670731433462_item	2796757	et	4	main
saada	doc_670731433462_item	2796764	et	4	main
korral	doc_670731433462_item	2796779	et	4	main
ka	doc_670731433462_item	2796780	et	3	main
on	doc_670731433462_item	2796785	et	4	main
meie	doc_670731433462_item	2796790	et	4	main
a	doc_670731433462_item	2796796	et	4	main
d	doc_670731433462_item	2796802	et	4	main
a	doc_670731433462_item	2796805	et	4	main
b	doc_670731433462_item	2796816	et	4	main
tasule	doc_670731433462_item	2796824	et	3	main
c	doc_670731433462_item	2796827	et	4	main
a	doc_670731433462_item	2796845	et	4	main
ning	doc_670731433462_item	2796846	et	3	main
b	doc_670731433462_item	2796847	et	4	main
vaid	doc_670731433462_item	2796848	et	3	main
c	doc_670731433462_item	2796849	et	4	main
kuid	doc_670731433462_item	2796850	et	4	main
a	doc_670731433462_item	2796854	et	4	main
c	doc_670731433461_item	2796425	et	4	main
kokku	doc_670731433461_item	2796426	et	3	main
hoida	doc_670731433461_item	2796427	et	3	main
c	doc_670731433461_item	2796436	et	4	main
7	doc_670731433461_item	2796440	et	2	main
ees	doc_670731433461_item	2796448	et	4	main
b	doc_670731433461_item	2796452	et	4	main
c	doc_670731433461_item	2796454	et	4	main
d	doc_670731433461_item	2796465	et	4	main
lihtne	doc_670731433461_item	2796466	et	3	main
õige	doc_670731433462_item	2796483	et	4	main
vastus	doc_670731433462_item	2796484	et	3	main
annab	doc_670731433462_item	2796485	et	3	main
ühe	doc_670731433462_item	2796486	et	4	main
punkti	doc_670731433462_item	2796487	et	4	main
maailmakuulsad	doc_670731433462_item	2796488	et	3	main
balletitantsijad	doc_670731433462_item	2796489	et	3	main
abielupaar	doc_670731433462_item	2796490	et	4	main
age	doc_670731433462_item	2796491	et	4	main
oks	doc_670731433462_item	2796492	et	3	main
ja	doc_670731433462_item	2796493	et	3	main
toomas	doc_670731433462_item	2796494	et	3	main
edur	doc_670731433462_item	2796495	et	4	main
on	doc_670731433462_item	2796496	et	4	main
pärit	doc_670731433462_item	2796497	et	3	main
eesti	doc_670731433462_item	2796498	et	4	main
eestist	doc_670731433462_item	2796499	et	3	main
aga	doc_670731433462_item	2796500	et	3	main
elavad	doc_670731433462_item	2796501	et	4	main
praegu	doc_670731433462_item	2796502	et	3	main
inglismaa	doc_670731433462_item	2796503	et	4	main
london	doc_670731433462_item	2796504	et	4	main
inglismaal	doc_670731433462_item	2796505	et	4	main
londonis	doc_670731433462_item	2796506	et	4	main
age	doc_670731433462_item	2796507	et	4	main
on	doc_670731433462_item	2796508	et	4	main
30	doc_670731433462_item	2796509	et	2	main
kolmekümne	doc_670731433462_item	2796510	et	4	main
aastane	doc_670731433462_item	2796511	et	4	main
ja	doc_670731433462_item	2796512	et	3	main
toomas	doc_670731433462_item	2796513	et	3	main
on	doc_670731433462_item	2796514	et	4	main
32	doc_670731433462_item	2796515	et	2	main
kaks	doc_670731433462_item	2796517	et	3	main
külastage	doc_670731433461_item	2796473	et	3	main
kolmkümend	doc_670731433462_item	2796516	et	4	main
alates	doc_670731433462_item	2796520	et	3	main
on	doc_670731433462_item	2796527	et	4	main
inglismaal	doc_670731433462_item	2796537	et	4	main
neid	doc_670731433462_item	2796540	et	4	main
artiklid	doc_670731433462_item	2796552	et	3	main
läinud	doc_670731433462_item	2796565	et	4	main
mõlemal	doc_670731433462_item	2796566	et	3	main
ja	doc_670731433462_item	2796567	et	3	main
tervis	doc_670731433462_item	2796573	et	3	main
1990	doc_670731433462_item	2796575	et	2	main
olema	doc_670731433462_item	2796593	et	4	main
toomas	doc_670731433462_item	2796597	et	3	main
on	doc_670731433462_item	2796608	et	4	main
eraldi	doc_670731433462_item	2796612	et	4	main
lähiaja	doc_670731433462_item	2796622	et	3	main
on	doc_670731433462_item	2796624	et	4	main
täpselt	doc_670731433462_item	2796625	et	4	main
planeerima	doc_670731433462_item	2796626	et	3	main
tahavad	doc_670731433462_item	2796631	et	3	main
märtsis	doc_670731433462_item	2796638	et	3	main
tallinnas	doc_670731433462_item	2796643	et	4	main
ja	doc_670731433462_item	2796644	et	3	main
seejärel	doc_670731433462_item	2796645	et	3	main
sõidavad	doc_670731433462_item	2796646	et	3	main
lõuna-aafrika	doc_670731433462_item	2796647	et	4	main
tipus	doc_670731433462_item	2796655	et	3	main
eelistavad	doc_670731433462_item	2796664	et	4	main
päeva	doc_670731433462_item	2796669	et	4	main
lünka	doc_670731433462_item	2796672	et	4	main
iga	doc_670731433462_item	2796677	et	4	main
planeerida	doc_670731433462_item	2796715	et	3	main
ning	doc_670731433462_item	2796717	et	3	main
teadmisi	doc_670731433462_item	2796720	et	4	main
vabakutseline	doc_670731433462_item	2796529	et	4	main
esinevad	doc_670731433462_item	2796532	et	4	main
erinevad	doc_670731433462_item	2796533	et	4	main
üldiselt	doc_670731433462_item	2796549	et	4	main
hästi	doc_670731433462_item	2796550	et	3	main
viimased	doc_670731433462_item	2796551	et	3	main
alati	doc_670731433462_item	2796562	et	4	main
nii	doc_670731433462_item	2796563	et	3	main
kergelt	doc_670731433462_item	2796564	et	4	main
olnud	doc_670731433462_item	2796571	et	4	main
tervisega	doc_670731433462_item	2796574	et	3	main
aastal	doc_670731433462_item	2796576	et	3	main
murdab	doc_670731433462_item	2796578	et	4	main
luikede	doc_670731433462_item	2796581	et	3	main
etendus	doc_670731433462_item	2796583	et	4	main
etenduses	doc_670731433462_item	2796584	et	4	main
jalaluu	doc_670731433462_item	2796585	et	4	main
ja	doc_670731433462_item	2796586	et	3	main
pidama	doc_670731433462_item	2796587	et	4	main
age	doc_670731433462_item	2796595	et	4	main
otsustanud	doc_670731433462_item	2796599	et	4	main
tantsima	doc_670731433462_item	2796600	et	3	main
tantsida	doc_670731433462_item	2796601	et	3	main
ainult	doc_670731433462_item	2796602	et	4	main
teineteisega	doc_670731433462_item	2796603	et	3	main
pakkumisi	doc_670731433462_item	2796610	et	4	main
tantsimiseks	doc_670731433462_item	2796613	et	4	main
suurele	doc_670731433462_item	2796615	et	4	main
edule	doc_670731433462_item	2796616	et	3	main
elavad	doc_670731433462_item	2796617	et	4	main
tantsijad	doc_670731433462_item	2796618	et	4	main
tagasihoidlik	doc_670731433462_item	2796619	et	3	main
tagasihoidlikuks	doc_670731433462_item	2796620	et	3	main
nende	doc_670731433462_item	2796621	et	4	main
ja	doc_670731433462_item	2796629	et	3	main
veelgi	doc_670731433462_item	2796634	et	4	main
tantsida	doc_670731433462_item	2796637	et	3	main
lõuna-aafrikasse	doc_670731433462_item	2796648	et	4	main
kui	doc_670731433462_item	2796649	et	3	main
kaua	doc_670731433462_item	2796650	et	3	main
oks	doc_670731433462_item	2796651	et	3	main
ei	doc_670731433462_item	2796658	et	4	main
nad	doc_670731433462_item	2796660	et	3	main
päev	doc_670731433462_item	2796667	et	3	main
vastus	doc_670731433462_item	2796679	et	3	main
vabaduse	doc_670731433462_item	2796714	et	4	main
eelise	doc_670731433462_item	2796718	et	4	main
seda	doc_670731433462_item	2796729	et	3	main
registreerunud	doc_670731433462_item	2796741	et	4	main
saad	doc_670731433462_item	2796742	et	4	main
igal	doc_670731433462_item	2796748	et	3	main
kätte	doc_670731433462_item	2796750	et	4	main
õppematerjalid	doc_670731433462_item	2796751	et	3	main
kursuse	doc_670731433462_item	2796758	et	3	main
10	doc_670731433462_item	2796788	et	2	main
sobid	doc_670731433462_item	2796797	et	4	main
2	doc_670731433462_item	2796804	et	2	main
just	doc_670731433462_item	2796806	et	3	main
c	doc_670731433462_item	2796809	et	4	main
vabanduse	doc_670731433462_item	2796817	et	4	main
c	doc_670731433462_item	2796818	et	4	main
varanduse	doc_670731433462_item	2796819	et	3	main
b	doc_670731433462_item	2796825	et	4	main
tasemele	doc_670731433462_item	2796826	et	3	main
liita	doc_670731433462_item	2796837	et	4	main
c	doc_670731433462_item	2796838	et	4	main
kokku	doc_670731433462_item	2796839	et	3	main
taga	doc_670731433462_item	2796855	et	4	main
b	doc_670731433462_item	2796865	et	4	main
palub	doc_670731433462_item	2796866	et	3	main
c	doc_670731433462_item	2796867	et	4	main
parandab	doc_670731433462_item	2796868	et	3	main
liikuv	doc_670731433462_item	2796877	et	4	main
lihtne	doc_670731433462_item	2796879	et	3	main
a	doc_670731433462_item	2796881	et	4	main
käige	doc_670731433462_item	2796884	et	3	main
üheksa	doc_670731433463_item	2796936	et	4	main
üheksasaja	doc_670731433462_item	2796523	et	4	main
vabakutselised	doc_670731433462_item	2796530	et	4	main
teatrid	doc_670731433462_item	2796536	et	3	main
armastavad	doc_670731433462_item	2796539	et	4	main
väga	doc_670731433462_item	2796541	et	3	main
isegi	doc_670731433462_item	2796543	et	4	main
karmid	doc_670731433462_item	2796544	et	4	main
kriitikud	doc_670731433462_item	2796545	et	3	main
suhtuma	doc_670731433462_item	2796546	et	3	main
suhtuda	doc_670731433462_item	2796547	et	3	main
noored	doc_670731433462_item	2796554	et	3	main
ülivõrdes	doc_670731433462_item	2796557	et	3	main
kõik	doc_670731433462_item	2796559	et	4	main
sugugi	doc_670731433462_item	2796561	et	4	main
agel	doc_670731433462_item	2796569	et	4	main
on	doc_670731433462_item	2796570	et	4	main
noor	doc_670731433462_item	2796579	et	3	main
järve	doc_670731433462_item	2796582	et	4	main
tantsimisest	doc_670731433462_item	2796591	et	4	main
eemal	doc_670731433462_item	2796592	et	3	main
neil	doc_670731433462_item	2796607	et	4	main
areneda	doc_670731433462_item	2796632	et	3	main
ja	doc_670731433462_item	2796633	et	3	main
tulevad	doc_670731433462_item	2796639	et	4	main
tallinn	doc_670731433462_item	2796642	et	4	main
edur	doc_670731433462_item	2796653	et	4	main
suudavad	doc_670731433462_item	2796656	et	3	main
elada	doc_670731433462_item	2796665	et	3	main
ühe	doc_670731433462_item	2796668	et	4	main
kaupa	doc_670731433462_item	2796670	et	4	main
kirjutage	doc_670731433462_item	2796671	et	3	main
teksti	doc_670731433462_item	2796675	et	4	main
annab	doc_670731433462_item	2796680	et	3	main
ühe	doc_670731433462_item	2796681	et	4	main
punkti	doc_670731433462_item	2796682	et	4	main
õpi	doc_670731433462_item	2796683	et	4	main
millal	doc_670731433462_item	2796684	et	3	main
1	doc_670731433462_item	2796685	et	2	main
soovid	doc_670731433462_item	2796686	et	4	main
unusta	doc_670731433462_item	2796687	et	4	main
umbne	doc_670731433462_item	2796688	et	3	main
klassiruum	doc_670731433462_item	2796689	et	3	main
koduõppesüsteem	doc_670731433462_item	2796690	et	3	main
võimaldab	doc_670731433462_item	2796691	et	3	main
sul	doc_670731433462_item	2796692	et	3	main
saada	doc_670731433462_item	2796693	et	4	main
targemaks	doc_670731433462_item	2796694	et	4	main
2	doc_670731433462_item	2796695	et	2	main
just	doc_670731433462_item	2796696	et	3	main
seal	doc_670731433462_item	2796697	et	4	main
kus	doc_670731433462_item	2796698	et	3	main
ja	doc_670731433462_item	2796699	et	3	main
millal	doc_670731433462_item	2796700	et	3	main
sa	doc_670731433462_item	2796701	et	3	main
seda	doc_670731433462_item	2796702	et	3	main
parasjagu	doc_670731433462_item	2796703	et	3	main
soovid	doc_670731433462_item	2796704	et	4	main
käes	doc_670731433462_item	2796705	et	4	main
on	doc_670731433462_item	2796706	et	4	main
interaktiivse	doc_670731433462_item	2796707	et	3	main
õppe	doc_670731433462_item	2796708	et	4	main
ajastu	doc_670731433462_item	2796709	et	4	main
mis	doc_670731433462_item	2796710	et	4	main
3	doc_670731433462_item	2796713	et	2	main
omandada	doc_670731433462_item	2796719	et	3	main
4	doc_670731433462_item	2796723	et	2	main
aeg	doc_670731433462_item	2796725	et	3	main
5	doc_670731433462_item	2796730	et	2	main
on	doc_670731433462_item	2796733	et	4	main
ka	doc_670731433462_item	2796735	et	3	main
pisut	doc_670731433462_item	2796736	et	3	main
tarkust	doc_670731433462_item	2796737	et	4	main
kui	doc_670731433462_item	2796738	et	3	main
oled	doc_670731433462_item	2796739	et	3	main
kursusele	doc_670731433462_item	2796740	et	3	main
või	doc_670731433462_item	2796745	et	4	main
kättesaamisel	doc_670731433462_item	2796763	et	4	main
tekkinud	doc_670731433462_item	2796781	et	4	main
9	doc_670731433462_item	2796786	et	2	main
tulge	doc_670731433462_item	2796789	et	3	main
solvud	doc_670731433462_item	2796803	et	3	main
seega	doc_670731433462_item	2796808	et	4	main
kuigi	doc_670731433462_item	2796810	et	3	main
4	doc_670731433462_item	2796822	et	2	main
d	doc_670731433462_item	2796829	et	4	main
5	doc_670731433462_item	2796831	et	2	main
hoida	doc_670731433462_item	2796840	et	3	main
7	doc_670731433462_item	2796853	et	2	main
b	doc_670731433462_item	2796856	et	4	main
c	doc_670731433462_item	2796858	et	4	main
muudab	doc_670731433462_item	2796870	et	3	main
a	doc_670731433462_item	2796872	et	4	main
liigne	doc_670731433462_item	2796873	et	3	main
tulge	doc_670731433462_item	2796882	et	3	main
c	doc_670731433462_item	2796885	et	4	main
külastage	doc_670731433462_item	2796886	et	3	main
d	doc_670731433462_item	2796887	et	4	main
minge	doc_670731433462_item	2796888	et	3	main
vastavalt	doc_670731433462_item	2796721	et	4	main
tasemele	doc_670731433462_item	2796724	et	3	main
et	doc_670731433462_item	2796728	et	3	main
kokku	doc_670731433462_item	2796731	et	3	main
vaja	doc_670731433462_item	2796734	et	4	main
meie	doc_670731433462_item	2796743	et	4	main
lähimast	doc_670731433462_item	2796746	et	4	main
kuul	doc_670731433462_item	2796749	et	4	main
raamatu	doc_670731433462_item	2796752	et	4	main
ja	doc_670731433462_item	2796753	et	3	main
helikasseti	doc_670731433462_item	2796754	et	4	main
6	doc_670731433462_item	2796755	et	2	main
7	doc_670731433462_item	2796759	et	2	main
tasud	doc_670731433462_item	2796761	et	4	main
selle	doc_670731433462_item	2796762	et	4	main
kodutöö	doc_670731433462_item	2796766	et	4	main
meile	doc_670731433462_item	2796767	et	4	main
tagasi	doc_670731433462_item	2796768	et	3	main
õpetaja	doc_670731433462_item	2796769	et	4	main
vaatab	doc_670731433462_item	2796770	et	3	main
selle	doc_670731433462_item	2796771	et	4	main
üle	doc_670731433462_item	2796772	et	3	main
8	doc_670731433462_item	2796773	et	2	main
parandab	doc_670731433462_item	2796774	et	3	main
vead	doc_670731433462_item	2796775	et	4	main
ning	doc_670731433462_item	2796776	et	3	main
vastab	doc_670731433462_item	2796777	et	3	main
vajaduse	doc_670731433462_item	2796778	et	3	main
kõik	doc_670731433462_item	2796783	et	4	main
geniaalne	doc_670731433462_item	2796784	et	3	main
virtuaalkodu	doc_670731433462_item	2796791	et	4	main
või	doc_670731433462_item	2796792	et	4	main
postitage	doc_670731433462_item	2796793	et	3	main
kupong	doc_670731433462_item	2796794	et	3	main
1	doc_670731433462_item	2796795	et	2	main
c	doc_670731433462_item	2796800	et	4	main
soovitad	doc_670731433462_item	2796801	et	3	main
b	doc_670731433462_item	2796807	et	4	main
d	doc_670731433462_item	2796811	et	4	main
siiski	doc_670731433462_item	2796812	et	4	main
3	doc_670731433462_item	2796813	et	2	main
d	doc_670731433462_item	2796820	et	4	main
a	doc_670731433462_item	2796823	et	4	main
b	doc_670731433462_item	2796835	et	4	main
kokku	doc_670731433462_item	2796836	et	3	main
et	doc_670731433462_item	2796852	et	3	main
ette	doc_670731433462_item	2796857	et	4	main
d	doc_670731433462_item	2796860	et	4	main
ees	doc_670731433462_item	2796861	et	4	main
8	doc_670731433462_item	2796862	et	2	main
a	doc_670731433462_item	2796863	et	4	main
kirjutab	doc_670731433462_item	2796864	et	3	main
b	doc_670731433462_item	2796874	et	4	main
avage	doc_670731433463_item	2796890	et	3	main
sulud	doc_670731433463_item	2796891	et	3	main
numbrid	doc_670731433463_item	2796892	et	3	main
kirjutage	doc_670731433463_item	2796893	et	3	main
sõnadega	doc_670731433463_item	2796894	et	3	main
iga	doc_670731433463_item	2796895	et	4	main
õige	doc_670731433463_item	2796896	et	4	main
vastus	doc_670731433463_item	2796897	et	3	main
annab	doc_670731433463_item	2796898	et	3	main
ühe	doc_670731433463_item	2796899	et	4	main
punkti	doc_670731433463_item	2796900	et	4	main
balletitantsijad	doc_670731433463_item	2796902	et	3	main
abielupaar	doc_670731433463_item	2796903	et	4	main
maailmakuulsad	doc_670731433463_item	2796901	et	3	main
age	doc_670731433463_item	2796904	et	4	main
oks	doc_670731433463_item	2796905	et	3	main
ja	doc_670731433463_item	2796906	et	3	main
toomas	doc_670731433463_item	2796907	et	3	main
edur	doc_670731433463_item	2796908	et	4	main
on	doc_670731433463_item	2796909	et	4	main
pärit	doc_670731433463_item	2796910	et	3	main
eesti	doc_670731433463_item	2796911	et	4	main
eestis	doc_670731433463_item	2796912	et	3	main
aga	doc_670731433463_item	2796913	et	3	main
elavad	doc_670731433463_item	2796914	et	4	main
praegu	doc_670731433463_item	2796915	et	3	main
inglismaa	doc_670731433463_item	2796916	et	4	main
london	doc_670731433463_item	2796917	et	4	main
inglismaa	doc_670731433463_item	2796918	et	4	main
londonis	doc_670731433463_item	2796919	et	4	main
age	doc_670731433463_item	2796920	et	4	main
on	doc_670731433463_item	2796921	et	4	main
1997a	doc_670731433463_item	2796934	et	4	main
saja	doc_670731433463_item	2796937	et	4	main
nad	doc_670731433463_item	2796942	et	3	main
teatriga	doc_670731433463_item	2796950	et	3	main
neid	doc_670731433463_item	2796954	et	4	main
artiklid	doc_670731433463_item	2796966	et	3	main
noor	doc_670731433463_item	2796993	et	3	main
pidada	doc_670731433463_item	2797002	et	4	main
d	doc_670731433462_item	2796851	et	4	main
eest	doc_670731433462_item	2796859	et	4	main
d	doc_670731433462_item	2796869	et	4	main
9	doc_670731433462_item	2796871	et	2	main
c	doc_670731433462_item	2796876	et	4	main
d	doc_670731433462_item	2796878	et	4	main
10	doc_670731433462_item	2796880	et	2	main
harjutus	doc_670731433463_item	2796889	et	4	main
on	doc_670731433463_item	2796927	et	4	main
tuhande	doc_670731433463_item	2796935	et	3	main
üheksa	doc_670731433463_item	2796938	et	4	main
seitseni	doc_670731433463_item	2796940	et	4	main
vabakutseline	doc_670731433463_item	2796943	et	4	main
vabakutseline	doc_670731433463_item	2796944	et	4	main
ja	doc_670731433463_item	2796945	et	3	main
armastan	doc_670731433463_item	2796953	et	3	main
ning	doc_670731433463_item	2796956	et	3	main
hästi	doc_670731433463_item	2796964	et	3	main
1990	doc_670731433463_item	2796989	et	2	main
etenduse	doc_670731433463_item	2796998	et	4	main
pidama	doc_670731433463_item	2797001	et	4	main
olema	doc_670731433463_item	2797007	et	4	main
olla	doc_670731433463_item	2797008	et	3	main
otsustanud	doc_670731433463_item	2797013	et	4	main
ainult	doc_670731433463_item	2797016	et	4	main
paaris	doc_670731433463_item	2797018	et	4	main
kuigi	doc_670731433463_item	2797019	et	3	main
nemad	doc_670731433463_item	2797020	et	3	main
tantsimiseks	doc_670731433463_item	2797027	et	4	main
vaatamata	doc_670731433463_item	2797028	et	4	main
suurele	doc_670731433463_item	2797029	et	4	main
edule	doc_670731433463_item	2797030	et	3	main
lähiaja	doc_670731433463_item	2797036	et	3	main
planeerima	doc_670731433463_item	2797040	et	3	main
ja	doc_670731433463_item	2797043	et	3	main
toomas	doc_670731433463_item	2797044	et	3	main
ja	doc_670731433463_item	2797047	et	3	main
tallinn	doc_670731433463_item	2797056	et	4	main
ei	doc_670731433463_item	2797072	et	4	main
sõna	doc_670731433463_item	2797088	et	4	main
iga	doc_670731433463_item	2797091	et	4	main
ajastu	doc_670731433463_item	2797123	et	4	main
vastavalt	doc_670731433463_item	2797135	et	4	main
4	doc_670731433463_item	2797137	et	2	main
tasemele	doc_670731433463_item	2797138	et	3	main
aeg	doc_670731433463_item	2797139	et	3	main
on	doc_670731433463_item	2797140	et	4	main
hoida	doc_670731433463_item	2797146	et	3	main
oled	doc_670731433463_item	2797153	et	3	main
registreerunud	doc_670731433463_item	2797155	et	4	main
saad	doc_670731433463_item	2797156	et	4	main
kontorist	doc_670731433463_item	2797158	et	4	main
õppematerjalid	doc_670731433463_item	2797165	et	3	main
ja	doc_670731433463_item	2797167	et	3	main
selle	doc_670731433463_item	2797176	et	4	main
meile	doc_670731433463_item	2797181	et	4	main
tagasi	doc_670731433463_item	2797182	et	3	main
selle	doc_670731433463_item	2797185	et	4	main
vastab	doc_670731433463_item	2797191	et	3	main
on	doc_670731433463_item	2797199	et	4	main
lihtne	doc_670731433463_item	2797201	et	3	main
3	doc_670731433463_item	2797227	et	2	main
vabanduse	doc_670731433463_item	2797231	et	4	main
c	doc_670731433463_item	2797232	et	4	main
kokku	doc_670731433463_item	2797247	et	3	main
kokku	doc_670731433463_item	2797253	et	3	main
b	doc_670731433463_item	2797261	et	4	main
vaid	doc_670731433463_item	2797262	et	3	main
c	doc_670731433463_item	2797290	et	4	main
10	doc_670731433463_item	2797294	et	2	main
tulge	doc_670731433463_item	2797296	et	3	main
minge	doc_670731433463_item	2797302	et	3	main
sulud	doc_670731433464_item	2797305	et	3	main
ühe	doc_670731433464_item	2797313	et	4	main
toomas	doc_670731433464_item	2797321	et	3	main
eesti	doc_670731433464_item	2797325	et	4	main
eestist	doc_670731433464_item	2797326	et	3	main
londonis	doc_670731433464_item	2797333	et	4	main
32	doc_670731433464_item	2797342	et	2	main
vabakutseline	doc_670731433464_item	2797357	et	4	main
teatrides	doc_670731433464_item	2797364	et	4	main
väga	doc_670731433464_item	2797369	et	3	main
libe	doc_670731433462_item	2796875	et	3	main
b	doc_670731433462_item	2796883	et	4	main
30	doc_670731433463_item	2796922	et	2	main
aastane	doc_670731433463_item	2796924	et	4	main
ja	doc_670731433463_item	2796925	et	3	main
toomas	doc_670731433463_item	2796926	et	3	main
32	doc_670731433463_item	2796928	et	2	main
esinevad	doc_670731433463_item	2796946	et	4	main
inglismaal	doc_670731433463_item	2796951	et	4	main
väga	doc_670731433463_item	2796955	et	3	main
viimased	doc_670731433463_item	2796965	et	3	main
tervis	doc_670731433463_item	2796987	et	3	main
aastal	doc_670731433463_item	2796990	et	3	main
järve	doc_670731433463_item	2796996	et	4	main
mõnda	doc_670731433463_item	2797003	et	4	main
aega	doc_670731433463_item	2797004	et	4	main
on	doc_670731433463_item	2797012	et	4	main
eraldi	doc_670731433463_item	2797026	et	4	main
tantsijad	doc_670731433463_item	2797032	et	4	main
tagasihoidlik	doc_670731433463_item	2797033	et	3	main
nende	doc_670731433463_item	2797035	et	4	main
täpselt	doc_670731433463_item	2797039	et	4	main
tulevad	doc_670731433463_item	2797053	et	4	main
nad	doc_670731433463_item	2797054	et	3	main
esinema	doc_670731433463_item	2797055	et	3	main
seejärel	doc_670731433463_item	2797059	et	3	main
ütleda	doc_670731433463_item	2797076	et	4	main
eelistavad	doc_670731433463_item	2797078	et	4	main
üks	doc_670731433463_item	2797080	et	3	main
alt	doc_670731433463_item	2797090	et	4	main
interaktiivse	doc_670731433463_item	2797121	et	3	main
aega	doc_670731433463_item	2797130	et	4	main
ning	doc_670731433463_item	2797131	et	3	main
eelise	doc_670731433463_item	2797132	et	4	main
omandada	doc_670731433463_item	2797133	et	3	main
teadmisi	doc_670731433463_item	2797134	et	4	main
seda	doc_670731433463_item	2797143	et	3	main
pisut	doc_670731433463_item	2797150	et	3	main
tarkust	doc_670731433463_item	2797151	et	4	main
6	doc_670731433463_item	2797169	et	2	main
ning	doc_670731433463_item	2797170	et	3	main
kodutöö	doc_670731433463_item	2797171	et	4	main
kursuse	doc_670731433463_item	2797172	et	3	main
7	doc_670731433463_item	2797173	et	2	main
kättesaamisel	doc_670731433463_item	2797177	et	4	main
saada	doc_670731433463_item	2797178	et	4	main
õpetaja	doc_670731433463_item	2797183	et	4	main
8	doc_670731433463_item	2797187	et	2	main
vead	doc_670731433463_item	2797189	et	4	main
vajaduse	doc_670731433463_item	2797192	et	3	main
9	doc_670731433463_item	2797200	et	2	main
meie	doc_670731433463_item	2797204	et	4	main
b	doc_670731433463_item	2797221	et	4	main
c	doc_670731433463_item	2797223	et	4	main
kuigi	doc_670731433463_item	2797224	et	3	main
a	doc_670731433463_item	2797228	et	4	main
b	doc_670731433463_item	2797230	et	4	main
d	doc_670731433463_item	2797234	et	4	main
a	doc_670731433463_item	2797246	et	4	main
c	doc_670731433463_item	2797252	et	4	main
kuid	doc_670731433463_item	2797264	et	4	main
libe	doc_670731433463_item	2797289	et	3	main
lihtne	doc_670731433463_item	2797293	et	3	main
b	doc_670731433463_item	2797297	et	4	main
käige	doc_670731433463_item	2797298	et	3	main
c	doc_670731433463_item	2797299	et	4	main
külastage	doc_670731433463_item	2797300	et	3	main
avage	doc_670731433464_item	2797304	et	3	main
iga	doc_670731433464_item	2797309	et	4	main
punkti	doc_670731433464_item	2797314	et	4	main
edur	doc_670731433464_item	2797322	et	4	main
pärit	doc_670731433464_item	2797324	et	3	main
aga	doc_670731433464_item	2797327	et	3	main
elavad	doc_670731433464_item	2797328	et	4	main
praegu	doc_670731433464_item	2797329	et	3	main
inglismaal	doc_670731433464_item	2797332	et	4	main
on	doc_670731433464_item	2797335	et	4	main
kolm	doc_670731433464_item	2797343	et	3	main
vana	doc_670731433464_item	2797347	et	4	main
alates	doc_670731433464_item	2797348	et	3	main
1997a	doc_670731433464_item	2797349	et	4	main
vabakutselised	doc_670731433464_item	2797358	et	4	main
kolmkümne	doc_670731433463_item	2796923	et	4	main
kolmkümne	doc_670731433463_item	2796929	et	4	main
kaheksa	doc_670731433463_item	2796930	et	4	main
aastat	doc_670731433463_item	2796931	et	3	main
vana	doc_670731433463_item	2796932	et	4	main
alates	doc_670731433463_item	2796933	et	3	main
erinevad	doc_670731433463_item	2796947	et	4	main
teatrid	doc_670731433463_item	2796948	et	3	main
erinevad	doc_670731433463_item	2796949	et	4	main
üldiselt	doc_670731433463_item	2796963	et	4	main
noored	doc_670731433463_item	2796968	et	3	main
noore	doc_670731433463_item	2796969	et	3	main
ainult	doc_670731433463_item	2796970	et	4	main
ülivõrdes	doc_670731433463_item	2796971	et	3	main
kuid	doc_670731433463_item	2796972	et	4	main
kõik	doc_670731433463_item	2796973	et	4	main
pole	doc_670731433463_item	2796974	et	3	main
sugugi	doc_670731433463_item	2796975	et	4	main
alati	doc_670731433463_item	2796976	et	4	main
nii	doc_670731433463_item	2796977	et	3	main
kergelt	doc_670731433463_item	2796978	et	4	main
läinud	doc_670731433463_item	2796979	et	4	main
mõlemal	doc_670731433463_item	2796980	et	3	main
ja	doc_670731433463_item	2796981	et	3	main
eriti	doc_670731433463_item	2796982	et	3	main
agel	doc_670731433463_item	2796983	et	4	main
on	doc_670731433463_item	2796984	et	4	main
olnud	doc_670731433463_item	2796985	et	4	main
probleeme	doc_670731433463_item	2796986	et	3	main
kümmend	doc_670731433463_item	2796939	et	4	main
on	doc_670731433463_item	2796941	et	4	main
armastama	doc_670731433463_item	2796952	et	3	main
isegi	doc_670731433463_item	2796957	et	4	main
karmid	doc_670731433463_item	2796958	et	4	main
kriitikud	doc_670731433463_item	2796959	et	3	main
suhtuma	doc_670731433463_item	2796960	et	3	main
suhtuda	doc_670731433463_item	2796961	et	3	main
nendesse	doc_670731433463_item	2796962	et	4	main
räägivad	doc_670731433463_item	2796967	et	3	main
tervisiga	doc_670731433463_item	2796988	et	4	main
murdan	doc_670731433463_item	2796992	et	4	main
luikede	doc_670731433463_item	2796995	et	3	main
tantsima	doc_670731433463_item	2797014	et	3	main
nende	doc_670731433463_item	2797021	et	4	main
esinemised	doc_670731433463_item	2797037	et	4	main
planerida	doc_670731433463_item	2797041	et	4	main
age	doc_670731433463_item	2797042	et	4	main
parem	doc_670731433463_item	2797049	et	4	main
perem	doc_670731433463_item	2797050	et	4	main
tantsida	doc_670731433463_item	2797051	et	3	main
märtsis	doc_670731433463_item	2797052	et	3	main
ja	doc_670731433463_item	2797058	et	3	main
lõuna-aafrika	doc_670731433463_item	2797061	et	4	main
kui	doc_670731433463_item	2797063	et	3	main
ja	doc_670731433463_item	2797066	et	3	main
oska	doc_670731433463_item	2797073	et	4	main
päev	doc_670731433463_item	2797081	et	3	main
teksti	doc_670731433463_item	2797089	et	4	main
õige	doc_670731433463_item	2797092	et	4	main
annab	doc_670731433463_item	2797125	et	3	main
3	doc_670731433463_item	2797127	et	2	main
individuaalsele	doc_670731433463_item	2797136	et	3	main
on	doc_670731433463_item	2797147	et	4	main
ka	doc_670731433463_item	2797149	et	3	main
kätte	doc_670731433463_item	2797164	et	4	main
helikasseti	doc_670731433463_item	2797168	et	4	main
üle	doc_670731433463_item	2797186	et	3	main
kõik	doc_670731433463_item	2797197	et	4	main
geniaalne	doc_670731433463_item	2797198	et	3	main
a	doc_670731433463_item	2797210	et	4	main
sobid	doc_670731433463_item	2797211	et	4	main
seega	doc_670731433463_item	2797222	et	4	main
d	doc_670731433463_item	2797225	et	4	main
vajaduse	doc_670731433463_item	2797229	et	3	main
4	doc_670731433463_item	2797236	et	2	main
a	doc_670731433463_item	2797237	et	4	main
b	doc_670731433463_item	2797239	et	4	main
saada	doc_670731433463_item	2797248	et	4	main
b	doc_670731433463_item	2797249	et	4	main
kokku	doc_670731433463_item	2797250	et	3	main
hoida	doc_670731433463_item	2797254	et	3	main
kokku	doc_670731433463_item	2797256	et	3	main
6	doc_670731433463_item	2797258	et	2	main
a	doc_670731433463_item	2797259	et	4	main
ning	doc_670731433463_item	2797260	et	3	main
harjutus	doc_670731433464_item	2797303	et	4	main
maailmakuulsad	doc_670731433464_item	2797315	et	3	main
balletitantsijad	doc_670731433464_item	2797316	et	3	main
abielupaar	doc_670731433464_item	2797317	et	4	main
age	doc_670731433464_item	2797318	et	4	main
oks	doc_670731433464_item	2797319	et	3	main
ja	doc_670731433464_item	2797320	et	3	main
murdma	doc_670731433463_item	2796991	et	3	main
naine	doc_670731433463_item	2796994	et	3	main
etendus	doc_670731433463_item	2796997	et	4	main
jalaluu	doc_670731433463_item	2796999	et	4	main
ja	doc_670731433463_item	2797000	et	3	main
tantsimisest	doc_670731433463_item	2797005	et	4	main
eemal	doc_670731433463_item	2797006	et	3	main
tantsida	doc_670731433463_item	2797015	et	3	main
teineteisega	doc_670731433463_item	2797017	et	3	main
age	doc_670731433463_item	2797009	et	4	main
ja	doc_670731433463_item	2797010	et	3	main
toomas	doc_670731433463_item	2797011	et	3	main
tagasihoidlik	doc_670731433463_item	2797034	et	3	main
on	doc_670731433463_item	2797038	et	4	main
areneda	doc_670731433463_item	2797046	et	3	main
sõidavad	doc_670731433463_item	2797060	et	3	main
kaua	doc_670731433463_item	2797064	et	3	main
nad	doc_670731433463_item	2797074	et	3	main
nad	doc_670731433463_item	2797077	et	3	main
elada	doc_670731433463_item	2797079	et	3	main
ühe	doc_670731433463_item	2797082	et	4	main
kaupa	doc_670731433463_item	2797084	et	4	main
kirjutage	doc_670731433463_item	2797085	et	3	main
lünka	doc_670731433463_item	2797086	et	4	main
sobiv	doc_670731433463_item	2797087	et	4	main
mis	doc_670731433463_item	2797124	et	4	main
sulle	doc_670731433463_item	2797126	et	3	main
planeerida	doc_670731433463_item	2797129	et	3	main
kokku	doc_670731433463_item	2797145	et	3	main
vaja	doc_670731433463_item	2797148	et	4	main
kui	doc_670731433463_item	2797152	et	3	main
kursusele	doc_670731433463_item	2797154	et	3	main
või	doc_670731433463_item	2797159	et	4	main
postiasutusest	doc_670731433463_item	2797161	et	4	main
igal	doc_670731433463_item	2797162	et	3	main
kuul	doc_670731433463_item	2797163	et	4	main
raamatu	doc_670731433463_item	2797166	et	4	main
ette	doc_670731433463_item	2797174	et	4	main
täidetud	doc_670731433463_item	2797179	et	4	main
vaatab	doc_670731433463_item	2797184	et	3	main
kirjutab	doc_670731433463_item	2797188	et	3	main
ning	doc_670731433463_item	2797190	et	3	main
korral	doc_670731433463_item	2797193	et	4	main
ka	doc_670731433463_item	2797194	et	3	main
tekkinud	doc_670731433463_item	2797195	et	4	main
10	doc_670731433463_item	2797202	et	2	main
on	doc_670731433463_item	2797022	et	4	main
tehtud	doc_670731433463_item	2797023	et	4	main
pakkumisi	doc_670731433463_item	2797024	et	4	main
ka	doc_670731433463_item	2797025	et	3	main
elavad	doc_670731433463_item	2797031	et	4	main
tahavad	doc_670731433463_item	2797045	et	3	main
veelgi	doc_670731433463_item	2797048	et	4	main
tallinnas	doc_670731433463_item	2797057	et	4	main
lõuna-aafris	doc_670731433463_item	2797062	et	4	main
oks	doc_670731433463_item	2797065	et	3	main
edur	doc_670731433463_item	2797067	et	4	main
veel	doc_670731433463_item	2797068	et	4	main
tipus	doc_670731433463_item	2797069	et	3	main
suudavad	doc_670731433463_item	2797070	et	3	main
püsida	doc_670731433463_item	2797071	et	3	main
ütlema	doc_670731433463_item	2797075	et	3	main
päeva	doc_670731433463_item	2797083	et	4	main
vastus	doc_670731433463_item	2797093	et	3	main
annab	doc_670731433463_item	2797094	et	3	main
ühe	doc_670731433463_item	2797095	et	4	main
punkti	doc_670731433463_item	2797096	et	4	main
õpi	doc_670731433463_item	2797097	et	4	main
millal	doc_670731433463_item	2797098	et	3	main
1	doc_670731433463_item	2797099	et	2	main
unusta	doc_670731433463_item	2797101	et	4	main
umbne	doc_670731433463_item	2797102	et	3	main
klassiruum	doc_670731433463_item	2797103	et	3	main
koduõppesüsteem	doc_670731433463_item	2797104	et	3	main
soovitad	doc_670731433463_item	2797100	et	3	main
võimaldab	doc_670731433463_item	2797105	et	3	main
sul	doc_670731433463_item	2797106	et	3	main
saada	doc_670731433463_item	2797107	et	4	main
targemaks	doc_670731433463_item	2797108	et	4	main
2	doc_670731433463_item	2797109	et	2	main
just	doc_670731433463_item	2797110	et	3	main
seal	doc_670731433463_item	2797111	et	4	main
kus	doc_670731433463_item	2797112	et	3	main
ja	doc_670731433463_item	2797113	et	3	main
millal	doc_670731433463_item	2797114	et	3	main
sa	doc_670731433463_item	2797115	et	3	main
seda	doc_670731433463_item	2797116	et	3	main
parasjagu	doc_670731433463_item	2797117	et	3	main
soovid	doc_670731433463_item	2797118	et	4	main
käes	doc_670731433463_item	2797119	et	4	main
on	doc_670731433463_item	2797120	et	4	main
õppe	doc_670731433463_item	2797122	et	4	main
vabaduse	doc_670731433463_item	2797128	et	4	main
raha	doc_670731433463_item	2797141	et	4	main
et	doc_670731433463_item	2797142	et	3	main
5	doc_670731433463_item	2797144	et	2	main
meie	doc_670731433463_item	2797157	et	4	main
lähimast	doc_670731433463_item	2797160	et	4	main
tasud	doc_670731433463_item	2797175	et	4	main
kodutöö	doc_670731433463_item	2797180	et	4	main
lisaküsimustele	doc_670731433463_item	2797196	et	4	main
tulge	doc_670731433463_item	2797203	et	3	main
virtuaalkodu	doc_670731433463_item	2797205	et	4	main
või	doc_670731433463_item	2797206	et	4	main
postitage	doc_670731433463_item	2797207	et	3	main
kupong	doc_670731433463_item	2797208	et	3	main
1	doc_670731433463_item	2797209	et	2	main
b	doc_670731433463_item	2797212	et	4	main
soovid	doc_670731433463_item	2797213	et	4	main
c	doc_670731433463_item	2797214	et	4	main
soovitad	doc_670731433463_item	2797215	et	3	main
d	doc_670731433463_item	2797216	et	4	main
solvud	doc_670731433463_item	2797217	et	3	main
2	doc_670731433463_item	2797218	et	2	main
a	doc_670731433463_item	2797219	et	4	main
just	doc_670731433463_item	2797220	et	3	main
siiski	doc_670731433463_item	2797226	et	4	main
vabaduse	doc_670731433463_item	2797235	et	4	main
c	doc_670731433463_item	2797241	et	4	main
tasakesi	doc_670731433463_item	2797242	et	3	main
d	doc_670731433463_item	2797243	et	4	main
tasakaalule	doc_670731433463_item	2797244	et	3	main
5	doc_670731433463_item	2797245	et	2	main
c	doc_670731433463_item	2797263	et	4	main
b	doc_670731433463_item	2797288	et	4	main
d	doc_670731433463_item	2797292	et	4	main
d	doc_670731433463_item	2797301	et	4	main
kirjutage	doc_670731433464_item	2797307	et	3	main
õige	doc_670731433464_item	2797310	et	4	main
inglismaa	doc_670731433464_item	2797330	et	4	main
on	doc_670731433464_item	2797341	et	4	main
kümmend	doc_670731433464_item	2797344	et	4	main
kaks	doc_670731433464_item	2797345	et	3	main
üheksasaja	doc_670731433464_item	2797351	et	4	main
ja	doc_670731433464_item	2797359	et	3	main
inglismaal	doc_670731433464_item	2797365	et	4	main
armastama	doc_670731433464_item	2797366	et	3	main
armastavad	doc_670731433464_item	2797367	et	4	main
isegi	doc_670731433464_item	2797371	et	4	main
suhtuma	doc_670731433464_item	2797374	et	3	main
kõik	doc_670731433464_item	2797387	et	4	main
pole	doc_670731433464_item	2797388	et	3	main
nii	doc_670731433464_item	2797391	et	3	main
aastal	doc_670731433464_item	2797404	et	3	main
murdma	doc_670731433464_item	2797405	et	3	main
murdis	doc_670731433464_item	2797406	et	3	main
age	doc_670731433464_item	2797423	et	4	main
tantsida	doc_670731433464_item	2797429	et	3	main
ainult	doc_670731433464_item	2797430	et	4	main
teineteisega	doc_670731433464_item	2797431	et	3	main
paaris	doc_670731433464_item	2797432	et	4	main
kuigi	doc_670731433464_item	2797433	et	3	main
nemad	doc_670731433464_item	2797434	et	3	main
ka	doc_670731433464_item	2797439	et	3	main
eraldi	doc_670731433464_item	2797440	et	4	main
tantsijad	doc_670731433464_item	2797446	et	4	main
esinemised	doc_670731433464_item	2797451	et	4	main
täpselt	doc_670731433464_item	2797453	et	4	main
sobiv	doc_670731433464_item	2797501	et	4	main
õpi	doc_670731433464_item	2797511	et	4	main
millal	doc_670731433464_item	2797512	et	3	main
1	doc_670731433464_item	2797513	et	2	main
ja	doc_670731433464_item	2797527	et	3	main
seda	doc_670731433464_item	2797530	et	3	main
varanduse	doc_670731433463_item	2797233	et	3	main
tasule	doc_670731433463_item	2797238	et	3	main
tasemele	doc_670731433463_item	2797240	et	3	main
liita	doc_670731433463_item	2797251	et	4	main
d	doc_670731433463_item	2797255	et	4	main
panna	doc_670731433463_item	2797257	et	4	main
d	doc_670731433463_item	2797265	et	4	main
et	doc_670731433463_item	2797266	et	3	main
7	doc_670731433463_item	2797267	et	2	main
a	doc_670731433463_item	2797268	et	4	main
taga	doc_670731433463_item	2797269	et	4	main
b	doc_670731433463_item	2797270	et	4	main
ette	doc_670731433463_item	2797271	et	4	main
c	doc_670731433463_item	2797272	et	4	main
eest	doc_670731433463_item	2797273	et	4	main
d	doc_670731433463_item	2797274	et	4	main
ees	doc_670731433463_item	2797275	et	4	main
8	doc_670731433463_item	2797276	et	2	main
a	doc_670731433463_item	2797277	et	4	main
kirjutab	doc_670731433463_item	2797278	et	3	main
b	doc_670731433463_item	2797279	et	4	main
palub	doc_670731433463_item	2797280	et	3	main
c	doc_670731433463_item	2797281	et	4	main
parandab	doc_670731433463_item	2797282	et	3	main
d	doc_670731433463_item	2797283	et	4	main
muudab	doc_670731433463_item	2797284	et	3	main
9	doc_670731433463_item	2797285	et	2	main
a	doc_670731433463_item	2797286	et	4	main
liigne	doc_670731433463_item	2797287	et	3	main
liikuv	doc_670731433463_item	2797291	et	4	main
a	doc_670731433463_item	2797295	et	4	main
numbrid	doc_670731433464_item	2797306	et	3	main
sõnadega	doc_670731433464_item	2797308	et	3	main
vastus	doc_670731433464_item	2797311	et	3	main
annab	doc_670731433464_item	2797312	et	3	main
on	doc_670731433464_item	2797323	et	4	main
london	doc_670731433464_item	2797331	et	4	main
age	doc_670731433464_item	2797334	et	4	main
30	doc_670731433464_item	2797336	et	2	main
kolmekümne	doc_670731433464_item	2797337	et	4	main
aastat	doc_670731433464_item	2797346	et	3	main
aastast	doc_670731433464_item	2797354	et	4	main
on	doc_670731433464_item	2797355	et	4	main
nad	doc_670731433464_item	2797356	et	3	main
erinevades	doc_670731433464_item	2797363	et	4	main
neid	doc_670731433464_item	2797368	et	4	main
karmid	doc_670731433464_item	2797372	et	4	main
kriitikud	doc_670731433464_item	2797373	et	3	main
viimased	doc_670731433464_item	2797379	et	3	main
artiklid	doc_670731433464_item	2797380	et	3	main
räägivad	doc_670731433464_item	2797381	et	3	main
eriti	doc_670731433464_item	2797396	et	3	main
on	doc_670731433464_item	2797398	et	4	main
järve	doc_670731433464_item	2797410	et	4	main
tantsimisest	doc_670731433464_item	2797419	et	4	main
aastane	doc_670731433464_item	2797338	et	4	main
ja	doc_670731433464_item	2797339	et	3	main
toomas	doc_670731433464_item	2797340	et	3	main
tuhande	doc_670731433464_item	2797350	et	3	main
üheksakümne	doc_670731433464_item	2797352	et	4	main
seitsme	doc_670731433464_item	2797353	et	3	main
esinevad	doc_670731433464_item	2797360	et	4	main
erinevad	doc_670731433464_item	2797361	et	4	main
teatrid	doc_670731433464_item	2797362	et	3	main
kuid	doc_670731433464_item	2797386	et	4	main
alati	doc_670731433464_item	2797390	et	4	main
läinud	doc_670731433464_item	2797393	et	4	main
ja	doc_670731433464_item	2797395	et	3	main
agel	doc_670731433464_item	2797397	et	4	main
luikede	doc_670731433464_item	2797409	et	3	main
aega	doc_670731433464_item	2797418	et	4	main
olla	doc_670731433464_item	2797422	et	3	main
on	doc_670731433464_item	2797426	et	4	main
otsustanud	doc_670731433464_item	2797427	et	4	main
tantsima	doc_670731433464_item	2797428	et	3	main
on	doc_670731433464_item	2797436	et	4	main
tagasihoidlik	doc_670731433464_item	2797447	et	3	main
on	doc_670731433464_item	2797452	et	4	main
planeerima	doc_670731433464_item	2797454	et	3	main
paremini	doc_670731433464_item	2797464	et	4	main
tantsida	doc_670731433464_item	2797465	et	3	main
märtsis	doc_670731433464_item	2797466	et	3	main
tallinn	doc_670731433464_item	2797470	et	4	main
ja	doc_670731433464_item	2797472	et	3	main
sõidavad	doc_670731433464_item	2797474	et	3	main
ühe	doc_670731433464_item	2797496	et	4	main
päeva	doc_670731433464_item	2797497	et	4	main
iga	doc_670731433464_item	2797505	et	4	main
punkti	doc_670731433464_item	2797510	et	4	main
võimaldab	doc_670731433464_item	2797519	et	3	main
ning	doc_670731433464_item	2797370	et	3	main
nendesse	doc_670731433464_item	2797376	et	4	main
hästi	doc_670731433464_item	2797378	et	3	main
noored	doc_670731433464_item	2797382	et	3	main
sugugi	doc_670731433464_item	2797389	et	4	main
kergelt	doc_670731433464_item	2797392	et	4	main
mõlemal	doc_670731433464_item	2797394	et	3	main
noor	doc_670731433464_item	2797407	et	3	main
etendus	doc_670731433464_item	2797411	et	4	main
jalaluu	doc_670731433464_item	2797413	et	4	main
eemal	doc_670731433464_item	2797420	et	3	main
ja	doc_670731433464_item	2797424	et	3	main
nende	doc_670731433464_item	2797449	et	4	main
nad	doc_670731433464_item	2797468	et	3	main
seejärel	doc_670731433464_item	2797473	et	3	main
kaupa	doc_670731433464_item	2797498	et	4	main
kirjutage	doc_670731433464_item	2797499	et	3	main
unusta	doc_670731433464_item	2797515	et	4	main
umbne	doc_670731433464_item	2797516	et	3	main
klassiruum	doc_670731433464_item	2797517	et	3	main
sul	doc_670731433464_item	2797520	et	3	main
saada	doc_670731433464_item	2797521	et	4	main
just	doc_670731433464_item	2797524	et	3	main
seal	doc_670731433464_item	2797525	et	4	main
soovid	doc_670731433464_item	2797532	et	4	main
ajastu	doc_670731433464_item	2797537	et	4	main
annab	doc_670731433464_item	2797539	et	3	main
eelise	doc_670731433464_item	2797546	et	4	main
vastavalt	doc_670731433464_item	2797549	et	4	main
individuaalsele	doc_670731433464_item	2797550	et	3	main
ka	doc_670731433464_item	2797563	et	3	main
kättesaamisel	doc_670731433464_item	2797591	et	4	main
kodutöö	doc_670731433464_item	2797594	et	4	main
parandab	doc_670731433464_item	2797602	et	3	main
ka	doc_670731433464_item	2797608	et	3	main
9	doc_670731433464_item	2797614	et	2	main
lihtne	doc_670731433464_item	2797615	et	3	main
suhtuvad	doc_670731433464_item	2797375	et	4	main
üldiselt	doc_670731433464_item	2797377	et	4	main
nooret	doc_670731433464_item	2797383	et	4	main
ainult	doc_670731433464_item	2797384	et	4	main
ülivõrdes	doc_670731433464_item	2797385	et	3	main
olnud	doc_670731433464_item	2797399	et	4	main
probleeme	doc_670731433464_item	2797400	et	3	main
tervis	doc_670731433464_item	2797401	et	3	main
tervisega	doc_670731433464_item	2797402	et	3	main
1990	doc_670731433464_item	2797403	et	2	main
naine	doc_670731433464_item	2797408	et	3	main
etenduses	doc_670731433464_item	2797412	et	4	main
ja	doc_670731433464_item	2797414	et	3	main
pidama	doc_670731433464_item	2797415	et	4	main
pidas	doc_670731433464_item	2797416	et	3	main
mõnda	doc_670731433464_item	2797417	et	4	main
olema	doc_670731433464_item	2797421	et	4	main
tehtud	doc_670731433464_item	2797437	et	4	main
pakkumisi	doc_670731433464_item	2797438	et	4	main
elavad	doc_670731433464_item	2797445	et	4	main
lähiaja	doc_670731433464_item	2797450	et	3	main
veelgi	doc_670731433464_item	2797462	et	4	main
parem	doc_670731433464_item	2797463	et	4	main
esinema	doc_670731433464_item	2797469	et	3	main
sõna	doc_670731433464_item	2797502	et	4	main
teksti	doc_670731433464_item	2797503	et	4	main
soovid	doc_670731433464_item	2797514	et	4	main
2	doc_670731433464_item	2797523	et	2	main
sa	doc_670731433464_item	2797529	et	3	main
käes	doc_670731433464_item	2797533	et	4	main
on	doc_670731433464_item	2797534	et	4	main
interaktiivse	doc_670731433464_item	2797535	et	3	main
õppe	doc_670731433464_item	2797536	et	4	main
3	doc_670731433464_item	2797541	et	2	main
omandada	doc_670731433464_item	2797547	et	3	main
on	doc_670731433464_item	2797561	et	4	main
tarkust	doc_670731433464_item	2797565	et	4	main
oled	doc_670731433464_item	2797567	et	3	main
ees	doc_670731433464_item	2797588	et	4	main
selle	doc_670731433464_item	2797599	et	4	main
üle	doc_670731433464_item	2797600	et	3	main
kõik	doc_670731433464_item	2797611	et	4	main
geniaalne	doc_670731433464_item	2797612	et	3	main
või	doc_670731433464_item	2797620	et	4	main
seega	doc_670731433464_item	2797636	et	4	main
3	doc_670731433464_item	2797641	et	2	main
b	doc_670731433464_item	2797644	et	4	main
c	doc_670731433464_item	2797646	et	4	main
varanduse	doc_670731433464_item	2797647	et	3	main
c	doc_670731433464_item	2797655	et	4	main
tasakesi	doc_670731433464_item	2797656	et	3	main
kokku	doc_670731433464_item	2797661	et	3	main
liita	doc_670731433464_item	2797665	et	4	main
ees	doc_670731433464_item	2797689	et	4	main
8	doc_670731433464_item	2797690	et	2	main
9	doc_670731433464_item	2797699	et	2	main
a	doc_670731433464_item	2797700	et	4	main
liigne	doc_670731433464_item	2797701	et	3	main
minge	doc_670731433464_item	2797716	et	3	main
sulud	doc_670731433465_item	2797719	et	3	main
kirjutage	doc_670731433465_item	2797721	et	3	main
age	doc_670731433465_item	2797748	et	4	main
kriitikud	doc_670731433465_item	2797785	et	3	main
suhtuma	doc_670731433465_item	2797786	et	3	main
noored	doc_670731433465_item	2797794	et	3	main
on	doc_670731433465_item	2797810	et	4	main
tervis	doc_670731433465_item	2797813	et	3	main
aastal	doc_670731433465_item	2797816	et	3	main
noor	doc_670731433465_item	2797819	et	3	main
jalaluu	doc_670731433465_item	2797825	et	4	main
mõnda	doc_670731433465_item	2797829	et	4	main
aega	doc_670731433465_item	2797830	et	4	main
toomas	doc_670731433465_item	2797837	et	3	main
tansida	doc_670731433465_item	2797841	et	4	main
ainult	doc_670731433465_item	2797842	et	4	main
teineteisega	doc_670731433465_item	2797843	et	3	main
tantsimiseks	doc_670731433465_item	2797853	et	4	main
esinemised	doc_670731433465_item	2797863	et	4	main
on	doc_670731433465_item	2797864	et	4	main
planeeritud	doc_670731433465_item	2797867	et	4	main
edur	doc_670731433465_item	2797893	et	4	main
nad	doc_670731433465_item	2797900	et	3	main
toomas	doc_670731433464_item	2797425	et	3	main
neil	doc_670731433464_item	2797435	et	4	main
tantsimiseks	doc_670731433464_item	2797441	et	4	main
vaatamata	doc_670731433464_item	2797442	et	4	main
suurele	doc_670731433464_item	2797443	et	4	main
edule	doc_670731433464_item	2797444	et	3	main
tagasihoidlikult	doc_670731433464_item	2797448	et	4	main
planeerivad	doc_670731433464_item	2797455	et	4	main
age	doc_670731433464_item	2797456	et	4	main
ja	doc_670731433464_item	2797457	et	3	main
toomas	doc_670731433464_item	2797458	et	3	main
tahavad	doc_670731433464_item	2797459	et	3	main
areneda	doc_670731433464_item	2797460	et	3	main
ja	doc_670731433464_item	2797461	et	3	main
tulevad	doc_670731433464_item	2797467	et	4	main
tallinnas	doc_670731433464_item	2797471	et	4	main
lõuna-aafrika	doc_670731433464_item	2797475	et	4	main
lõuna-aafrikas	doc_670731433464_item	2797476	et	4	main
kui	doc_670731433464_item	2797477	et	3	main
kaua	doc_670731433464_item	2797478	et	3	main
oks	doc_670731433464_item	2797479	et	3	main
ja	doc_670731433464_item	2797480	et	3	main
edur	doc_670731433464_item	2797481	et	4	main
veel	doc_670731433464_item	2797482	et	4	main
tipus	doc_670731433464_item	2797483	et	3	main
suudavad	doc_670731433464_item	2797484	et	3	main
püsida	doc_670731433464_item	2797485	et	3	main
ei	doc_670731433464_item	2797486	et	4	main
oska	doc_670731433464_item	2797487	et	4	main
nad	doc_670731433464_item	2797488	et	3	main
ütlema	doc_670731433464_item	2797489	et	3	main
öelda	doc_670731433464_item	2797490	et	4	main
nad	doc_670731433464_item	2797491	et	3	main
eelistavad	doc_670731433464_item	2797492	et	4	main
elada	doc_670731433464_item	2797493	et	3	main
üks	doc_670731433464_item	2797494	et	3	main
päev	doc_670731433464_item	2797495	et	3	main
lünka	doc_670731433464_item	2797500	et	4	main
alt	doc_670731433464_item	2797504	et	4	main
õige	doc_670731433464_item	2797506	et	4	main
vastus	doc_670731433464_item	2797507	et	3	main
annab	doc_670731433464_item	2797508	et	3	main
ühe	doc_670731433464_item	2797509	et	4	main
koduõppesüsteem	doc_670731433464_item	2797518	et	3	main
millal	doc_670731433464_item	2797528	et	3	main
parasjagu	doc_670731433464_item	2797531	et	3	main
mis	doc_670731433464_item	2797538	et	4	main
sulle	doc_670731433464_item	2797540	et	3	main
vabaduse	doc_670731433464_item	2797542	et	4	main
planeerida	doc_670731433464_item	2797543	et	3	main
ning	doc_670731433464_item	2797545	et	3	main
teadmisi	doc_670731433464_item	2797548	et	4	main
4	doc_670731433464_item	2797551	et	2	main
tasemele	doc_670731433464_item	2797552	et	3	main
aeg	doc_670731433464_item	2797553	et	3	main
on	doc_670731433464_item	2797554	et	4	main
pisut	doc_670731433464_item	2797564	et	3	main
saada	doc_670731433464_item	2797592	et	4	main
täidetud	doc_670731433464_item	2797593	et	4	main
meile	doc_670731433464_item	2797595	et	4	main
tagasi	doc_670731433464_item	2797596	et	3	main
õpetaja	doc_670731433464_item	2797597	et	4	main
vaatab	doc_670731433464_item	2797598	et	3	main
vead	doc_670731433464_item	2797603	et	4	main
vajaduse	doc_670731433464_item	2797606	et	3	main
postitage	doc_670731433464_item	2797621	et	3	main
a	doc_670731433464_item	2797624	et	4	main
sobid	doc_670731433464_item	2797625	et	4	main
soovitad	doc_670731433464_item	2797629	et	3	main
solvud	doc_670731433464_item	2797631	et	3	main
a	doc_670731433464_item	2797633	et	4	main
just	doc_670731433464_item	2797634	et	3	main
b	doc_670731433464_item	2797635	et	4	main
siiski	doc_670731433464_item	2797640	et	4	main
4	doc_670731433464_item	2797650	et	2	main
ette	doc_670731433464_item	2797685	et	4	main
eest	doc_670731433464_item	2797687	et	4	main
d	doc_670731433464_item	2797688	et	4	main
liikuv	doc_670731433464_item	2797705	et	4	main
d	doc_670731433464_item	2797715	et	4	main
targemaks	doc_670731433464_item	2797522	et	4	main
kus	doc_670731433464_item	2797526	et	3	main
raha	doc_670731433464_item	2797555	et	4	main
et	doc_670731433464_item	2797556	et	3	main
seda	doc_670731433464_item	2797557	et	3	main
5	doc_670731433464_item	2797558	et	2	main
kokku	doc_670731433464_item	2797559	et	3	main
hoida	doc_670731433464_item	2797560	et	3	main
kursusele	doc_670731433464_item	2797568	et	3	main
registreerunud	doc_670731433464_item	2797569	et	4	main
saad	doc_670731433464_item	2797570	et	4	main
meie	doc_670731433464_item	2797571	et	4	main
või	doc_670731433464_item	2797573	et	4	main
kontorist	doc_670731433464_item	2797572	et	4	main
lähimast	doc_670731433464_item	2797574	et	4	main
postiasutusest	doc_670731433464_item	2797575	et	4	main
igal	doc_670731433464_item	2797576	et	3	main
kuul	doc_670731433464_item	2797577	et	4	main
kätte	doc_670731433464_item	2797578	et	4	main
õppematerjalid	doc_670731433464_item	2797579	et	3	main
raamatu	doc_670731433464_item	2797580	et	4	main
ja	doc_670731433464_item	2797581	et	3	main
helikasseti	doc_670731433464_item	2797582	et	4	main
6	doc_670731433464_item	2797583	et	2	main
ning	doc_670731433464_item	2797584	et	3	main
kodutöö	doc_670731433464_item	2797585	et	4	main
kursuse	doc_670731433464_item	2797586	et	3	main
7	doc_670731433464_item	2797587	et	2	main
aega	doc_670731433464_item	2797544	et	4	main
vaja	doc_670731433464_item	2797562	et	4	main
kui	doc_670731433464_item	2797566	et	3	main
selle	doc_670731433464_item	2797590	et	4	main
ning	doc_670731433464_item	2797604	et	3	main
on	doc_670731433464_item	2797613	et	4	main
10	doc_670731433464_item	2797616	et	2	main
meie	doc_670731433464_item	2797618	et	4	main
soovid	doc_670731433464_item	2797627	et	4	main
2	doc_670731433464_item	2797632	et	2	main
a	doc_670731433464_item	2797642	et	4	main
vajaduse	doc_670731433464_item	2797643	et	3	main
vabanduse	doc_670731433464_item	2797645	et	4	main
5	doc_670731433464_item	2797659	et	2	main
a	doc_670731433464_item	2797691	et	4	main
kirjutab	doc_670731433464_item	2797692	et	3	main
b	doc_670731433464_item	2797702	et	4	main
libe	doc_670731433464_item	2797703	et	3	main
b	doc_670731433464_item	2797711	et	4	main
käige	doc_670731433464_item	2797712	et	3	main
harjutus	doc_670731433465_item	2797717	et	4	main
numbrid	doc_670731433465_item	2797720	et	3	main
sõnadega	doc_670731433465_item	2797722	et	3	main
ühe	doc_670731433465_item	2797727	et	4	main
age	doc_670731433465_item	2797732	et	4	main
oks	doc_670731433465_item	2797733	et	3	main
ja	doc_670731433465_item	2797734	et	3	main
toomas	doc_670731433465_item	2797735	et	3	main
inglismaa	doc_670731433465_item	2797744	et	4	main
on	doc_670731433465_item	2797749	et	4	main
kolmekümne	doc_670731433465_item	2797751	et	4	main
karmid	doc_670731433465_item	2797784	et	4	main
nooredelt	doc_670731433465_item	2797795	et	3	main
ülivõrdes	doc_670731433465_item	2797797	et	3	main
eriti	doc_670731433465_item	2797808	et	3	main
tasud	doc_670731433464_item	2797589	et	4	main
8	doc_670731433464_item	2797601	et	2	main
vastab	doc_670731433464_item	2797605	et	3	main
korral	doc_670731433464_item	2797607	et	4	main
tekkinud	doc_670731433464_item	2797609	et	4	main
lisaküsimustele	doc_670731433464_item	2797610	et	4	main
külastage	doc_670731433464_item	2797617	et	3	main
virtuaalkodu	doc_670731433464_item	2797619	et	4	main
1	doc_670731433464_item	2797623	et	2	main
b	doc_670731433464_item	2797626	et	4	main
c	doc_670731433464_item	2797637	et	4	main
kuigi	doc_670731433464_item	2797638	et	3	main
d	doc_670731433464_item	2797648	et	4	main
d	doc_670731433464_item	2797657	et	4	main
tasakaalule	doc_670731433464_item	2797658	et	3	main
saada	doc_670731433464_item	2797662	et	4	main
kokku	doc_670731433464_item	2797664	et	3	main
a	doc_670731433464_item	2797682	et	4	main
b	doc_670731433464_item	2797684	et	4	main
b	doc_670731433464_item	2797693	et	4	main
palub	doc_670731433464_item	2797694	et	3	main
c	doc_670731433464_item	2797704	et	4	main
c	doc_670731433464_item	2797713	et	4	main
külastage	doc_670731433464_item	2797714	et	3	main
avage	doc_670731433465_item	2797718	et	3	main
õige	doc_670731433465_item	2797724	et	4	main
edur	doc_670731433465_item	2797736	et	4	main
on	doc_670731433465_item	2797737	et	4	main
pärit	doc_670731433465_item	2797738	et	3	main
eesti	doc_670731433465_item	2797739	et	4	main
eestist	doc_670731433465_item	2797740	et	3	main
aga	doc_670731433465_item	2797741	et	3	main
elavad	doc_670731433465_item	2797742	et	4	main
praegu	doc_670731433465_item	2797743	et	3	main
londonis	doc_670731433465_item	2797747	et	4	main
suhtuvad	doc_670731433465_item	2797787	et	4	main
nendesse	doc_670731433465_item	2797788	et	4	main
ainult	doc_670731433465_item	2797796	et	4	main
kuid	doc_670731433465_item	2797798	et	4	main
kõik	doc_670731433465_item	2797799	et	4	main
alati	doc_670731433465_item	2797802	et	4	main
agel	doc_670731433465_item	2797809	et	4	main
naine	doc_670731433465_item	2797820	et	3	main
järve	doc_670731433465_item	2797822	et	4	main
etendusel	doc_670731433465_item	2797824	et	4	main
paaris	doc_670731433465_item	2797844	et	4	main
kuigi	doc_670731433465_item	2797845	et	3	main
nemad	doc_670731433465_item	2797846	et	3	main
neid	doc_670731433465_item	2797847	et	4	main
eraldi	doc_670731433465_item	2797852	et	4	main
suurele	doc_670731433465_item	2797855	et	4	main
elavad	doc_670731433465_item	2797857	et	4	main
tagasihoidlikult	doc_670731433465_item	2797860	et	4	main
täpselt	doc_670731433465_item	2797865	et	4	main
ja	doc_670731433465_item	2797892	et	3	main
ei	doc_670731433465_item	2797898	et	4	main
ütelda	doc_670731433465_item	2797902	et	4	main
teksti	doc_670731433465_item	2797915	et	4	main
õpi	doc_670731433465_item	2797923	et	4	main
1	doc_670731433465_item	2797925	et	2	main
soovid	doc_670731433465_item	2797926	et	4	main
kus	doc_670731433465_item	2797938	et	3	main
4	doc_670731433465_item	2797963	et	2	main
tasemele	doc_670731433465_item	2797964	et	3	main
aeg	doc_670731433465_item	2797965	et	3	main
oled	doc_670731433465_item	2797979	et	3	main
või	doc_670731433465_item	2797985	et	4	main
raamatu	doc_670731433465_item	2797992	et	4	main
helikasseti	doc_670731433465_item	2797994	et	4	main
ees	doc_670731433465_item	2798000	et	4	main
8	doc_670731433465_item	2798013	et	2	main
vastab	doc_670731433465_item	2798017	et	3	main
korral	doc_670731433465_item	2798019	et	4	main
9	doc_670731433465_item	2798026	et	2	main
külastage	doc_670731433465_item	2798029	et	3	main
või	doc_670731433465_item	2798032	et	4	main
d	doc_670731433465_item	2798042	et	4	main
just	doc_670731433465_item	2798046	et	3	main
d	doc_670731433465_item	2798060	et	4	main
tasemele	doc_670731433465_item	2798066	et	3	main
tasakesi	doc_670731433465_item	2798068	et	3	main
a	doc_670731433465_item	2798072	et	4	main
kupong	doc_670731433464_item	2797622	et	3	main
c	doc_670731433464_item	2797628	et	4	main
d	doc_670731433464_item	2797630	et	4	main
d	doc_670731433464_item	2797639	et	4	main
vabaduse	doc_670731433464_item	2797649	et	4	main
a	doc_670731433464_item	2797651	et	4	main
tasule	doc_670731433464_item	2797652	et	3	main
b	doc_670731433464_item	2797653	et	4	main
tasemele	doc_670731433464_item	2797654	et	3	main
a	doc_670731433464_item	2797660	et	4	main
b	doc_670731433464_item	2797663	et	4	main
c	doc_670731433464_item	2797666	et	4	main
kokku	doc_670731433464_item	2797667	et	3	main
hoida	doc_670731433464_item	2797668	et	3	main
d	doc_670731433464_item	2797669	et	4	main
kokku	doc_670731433464_item	2797670	et	3	main
panna	doc_670731433464_item	2797671	et	4	main
6	doc_670731433464_item	2797672	et	2	main
a	doc_670731433464_item	2797673	et	4	main
ning	doc_670731433464_item	2797674	et	3	main
b	doc_670731433464_item	2797675	et	4	main
vaid	doc_670731433464_item	2797676	et	3	main
c	doc_670731433464_item	2797677	et	4	main
kuid	doc_670731433464_item	2797678	et	4	main
d	doc_670731433464_item	2797679	et	4	main
et	doc_670731433464_item	2797680	et	3	main
7	doc_670731433464_item	2797681	et	2	main
taga	doc_670731433464_item	2797683	et	4	main
c	doc_670731433464_item	2797686	et	4	main
c	doc_670731433464_item	2797695	et	4	main
parandab	doc_670731433464_item	2797696	et	3	main
d	doc_670731433464_item	2797697	et	4	main
muudab	doc_670731433464_item	2797698	et	3	main
d	doc_670731433464_item	2797706	et	4	main
lihtne	doc_670731433464_item	2797707	et	3	main
10	doc_670731433464_item	2797708	et	2	main
a	doc_670731433464_item	2797709	et	4	main
tulge	doc_670731433464_item	2797710	et	3	main
iga	doc_670731433465_item	2797723	et	4	main
annab	doc_670731433465_item	2797726	et	3	main
punkti	doc_670731433465_item	2797728	et	4	main
maailmakuulsad	doc_670731433465_item	2797729	et	3	main
balletitantsijad	doc_670731433465_item	2797730	et	3	main
abielupaar	doc_670731433465_item	2797731	et	4	main
30	doc_670731433465_item	2797750	et	2	main
aastane	doc_670731433465_item	2797752	et	4	main
ja	doc_670731433465_item	2797753	et	3	main
toomas	doc_670731433465_item	2797754	et	3	main
on	doc_670731433465_item	2797755	et	4	main
32	doc_670731433465_item	2797756	et	2	main
kolmkümmend	doc_670731433465_item	2797757	et	4	main
kaks	doc_670731433465_item	2797758	et	3	main
aastat	doc_670731433465_item	2797759	et	3	main
inglismaal	doc_670731433465_item	2797777	et	4	main
armastavad	doc_670731433465_item	2797779	et	4	main
üldiselt	doc_670731433465_item	2797789	et	4	main
räägivad	doc_670731433465_item	2797793	et	3	main
pole	doc_670731433465_item	2797800	et	3	main
läinud	doc_670731433465_item	2797805	et	4	main
mõlemal	doc_670731433465_item	2797806	et	3	main
ja	doc_670731433465_item	2797807	et	3	main
probleeme	doc_670731433465_item	2797812	et	3	main
tervisega	doc_670731433465_item	2797814	et	3	main
murdma	doc_670731433465_item	2797817	et	3	main
etendus	doc_670731433465_item	2797823	et	4	main
pidama	doc_670731433465_item	2797827	et	4	main
pidis	doc_670731433465_item	2797828	et	4	main
olema	doc_670731433465_item	2797833	et	4	main
olema	doc_670731433465_item	2797834	et	4	main
on	doc_670731433465_item	2797838	et	4	main
tantsima	doc_670731433465_item	2797840	et	3	main
edule	doc_670731433465_item	2797856	et	3	main
tantsijad	doc_670731433465_item	2797858	et	4	main
tagasihoidlik	doc_670731433465_item	2797859	et	3	main
veel	doc_670731433465_item	2797894	et	4	main
tipus	doc_670731433465_item	2797895	et	3	main
suudavad	doc_670731433465_item	2797896	et	3	main
päev	doc_670731433465_item	2797907	et	3	main
alt	doc_670731433465_item	2797916	et	4	main
ühe	doc_670731433465_item	2797921	et	4	main
vastus	doc_670731433465_item	2797725	et	3	main
london	doc_670731433465_item	2797745	et	4	main
inglismaal	doc_670731433465_item	2797746	et	4	main
vana	doc_670731433465_item	2797760	et	4	main
alates	doc_670731433465_item	2797761	et	3	main
1997a	doc_670731433465_item	2797762	et	4	main
tuhande	doc_670731433465_item	2797763	et	3	main
üheksasaja	doc_670731433465_item	2797764	et	4	main
üheksakümne	doc_670731433465_item	2797765	et	4	main
seitsmendast	doc_670731433465_item	2797766	et	3	main
on	doc_670731433465_item	2797767	et	4	main
nad	doc_670731433465_item	2797768	et	3	main
vabakutseline	doc_670731433465_item	2797769	et	4	main
vabakutselised	doc_670731433465_item	2797770	et	4	main
ja	doc_670731433465_item	2797771	et	3	main
esinevad	doc_670731433465_item	2797772	et	4	main
erinevad	doc_670731433465_item	2797773	et	4	main
teatrid	doc_670731433465_item	2797774	et	3	main
erinevaid	doc_670731433465_item	2797775	et	4	main
teatre	doc_670731433465_item	2797776	et	4	main
armastama	doc_670731433465_item	2797778	et	3	main
neid	doc_670731433465_item	2797780	et	4	main
väga	doc_670731433465_item	2797781	et	3	main
ning	doc_670731433465_item	2797782	et	3	main
isegi	doc_670731433465_item	2797783	et	4	main
hästi	doc_670731433465_item	2797790	et	3	main
viimased	doc_670731433465_item	2797791	et	3	main
artiklid	doc_670731433465_item	2797792	et	3	main
sugugi	doc_670731433465_item	2797801	et	4	main
nii	doc_670731433465_item	2797803	et	3	main
kergelt	doc_670731433465_item	2797804	et	4	main
olnud	doc_670731433465_item	2797811	et	4	main
1990	doc_670731433465_item	2797815	et	2	main
murdis	doc_670731433465_item	2797818	et	3	main
luikede	doc_670731433465_item	2797821	et	3	main
tantsimisest	doc_670731433465_item	2797831	et	4	main
eemal	doc_670731433465_item	2797832	et	3	main
ja	doc_670731433465_item	2797836	et	3	main
otsustanud	doc_670731433465_item	2797839	et	4	main
on	doc_670731433465_item	2797848	et	4	main
tehtud	doc_670731433465_item	2797849	et	4	main
pakkumisi	doc_670731433465_item	2797850	et	4	main
ka	doc_670731433465_item	2797851	et	3	main
vaatamata	doc_670731433465_item	2797854	et	4	main
oska	doc_670731433465_item	2797899	et	4	main
ütlema	doc_670731433465_item	2797901	et	3	main
nad	doc_670731433465_item	2797903	et	3	main
eelistavad	doc_670731433465_item	2797904	et	4	main
elada	doc_670731433465_item	2797905	et	3	main
sobiv	doc_670731433465_item	2797913	et	4	main
sõna	doc_670731433465_item	2797914	et	4	main
õige	doc_670731433465_item	2797918	et	4	main
annab	doc_670731433465_item	2797920	et	3	main
võimaldab	doc_670731433465_item	2797931	et	3	main
saada	doc_670731433465_item	2797933	et	4	main
targemaks	doc_670731433465_item	2797934	et	4	main
2	doc_670731433465_item	2797935	et	2	main
just	doc_670731433465_item	2797936	et	3	main
seda	doc_670731433465_item	2797942	et	3	main
soovid	doc_670731433465_item	2797944	et	4	main
õppe	doc_670731433465_item	2797948	et	4	main
on	doc_670731433465_item	2797973	et	4	main
kui	doc_670731433465_item	2797978	et	3	main
kättesaamisel	doc_670731433465_item	2798003	et	4	main
õpetaja	doc_670731433465_item	2798009	et	4	main
vaatab	doc_670731433465_item	2798010	et	3	main
selle	doc_670731433465_item	2798011	et	4	main
parandab	doc_670731433465_item	2798014	et	3	main
ja	doc_670731433465_item	2797826	et	3	main
age	doc_670731433465_item	2797835	et	4	main
nende	doc_670731433465_item	2797861	et	4	main
lähiaja	doc_670731433465_item	2797862	et	3	main
planeerima	doc_670731433465_item	2797866	et	3	main
age	doc_670731433465_item	2797868	et	4	main
ja	doc_670731433465_item	2797869	et	3	main
toomas	doc_670731433465_item	2797870	et	3	main
tahavad	doc_670731433465_item	2797871	et	3	main
areneda	doc_670731433465_item	2797872	et	3	main
ja	doc_670731433465_item	2797873	et	3	main
veelgi	doc_670731433465_item	2797874	et	4	main
parem	doc_670731433465_item	2797875	et	4	main
paremeni	doc_670731433465_item	2797876	et	4	main
tantsida	doc_670731433465_item	2797877	et	3	main
märtsis	doc_670731433465_item	2797878	et	3	main
tulevad	doc_670731433465_item	2797879	et	4	main
nad	doc_670731433465_item	2797880	et	3	main
esinema	doc_670731433465_item	2797881	et	3	main
tallinn	doc_670731433465_item	2797882	et	4	main
tallinnas	doc_670731433465_item	2797883	et	4	main
ja	doc_670731433465_item	2797884	et	3	main
seejärel	doc_670731433465_item	2797885	et	3	main
sõidavad	doc_670731433465_item	2797886	et	3	main
lõuna-aafrika	doc_670731433465_item	2797887	et	4	main
lõuna-aafrikasse	doc_670731433465_item	2797888	et	4	main
kui	doc_670731433465_item	2797889	et	3	main
kaua	doc_670731433465_item	2797890	et	3	main
oks	doc_670731433465_item	2797891	et	3	main
püsida	doc_670731433465_item	2797897	et	3	main
kaupa	doc_670731433465_item	2797910	et	4	main
kirjutage	doc_670731433465_item	2797911	et	3	main
lünka	doc_670731433465_item	2797912	et	4	main
iga	doc_670731433465_item	2797917	et	4	main
vastus	doc_670731433465_item	2797919	et	3	main
punkti	doc_670731433465_item	2797922	et	4	main
millal	doc_670731433465_item	2797924	et	3	main
seal	doc_670731433465_item	2797937	et	4	main
ja	doc_670731433465_item	2797939	et	3	main
mis	doc_670731433465_item	2797950	et	4	main
on	doc_670731433465_item	2797966	et	4	main
raha	doc_670731433465_item	2797967	et	4	main
et	doc_670731433465_item	2797968	et	3	main
seda	doc_670731433465_item	2797969	et	3	main
5	doc_670731433465_item	2797970	et	2	main
kokku	doc_670731433465_item	2797971	et	3	main
hoida	doc_670731433465_item	2797972	et	3	main
tarkust	doc_670731433465_item	2797977	et	4	main
kursusele	doc_670731433465_item	2797980	et	3	main
lähimast	doc_670731433465_item	2797986	et	4	main
postiasutusest	doc_670731433465_item	2797987	et	4	main
ja	doc_670731433465_item	2797993	et	3	main
kodutöö	doc_670731433465_item	2797997	et	4	main
saada	doc_670731433465_item	2798004	et	4	main
täidetud	doc_670731433465_item	2798005	et	4	main
kodutöö	doc_670731433465_item	2798006	et	4	main
meile	doc_670731433465_item	2798007	et	4	main
tagasi	doc_670731433465_item	2798008	et	3	main
ning	doc_670731433465_item	2798016	et	3	main
lihtne	doc_670731433465_item	2798027	et	3	main
meie	doc_670731433465_item	2798030	et	4	main
c	doc_670731433465_item	2798040	et	4	main
soovitad	doc_670731433465_item	2798041	et	3	main
a	doc_670731433465_item	2798045	et	4	main
a	doc_670731433465_item	2798054	et	4	main
b	doc_670731433465_item	2798065	et	4	main
tasakaalule	doc_670731433465_item	2798070	et	3	main
c	doc_670731433465_item	2798078	et	4	main
kokku	doc_670731433465_item	2798079	et	3	main
b	doc_670731433465_item	2798087	et	4	main
d	doc_670731433465_item	2798100	et	4	main
ees	doc_670731433465_item	2798101	et	4	main
c	doc_670731433465_item	2798116	et	4	main
külastage	doc_670731433465_item	2798126	et	3	main
vastus	doc_670731433466_item	2798137	et	3	main
balletitantsijad	doc_670731433466_item	2798142	et	3	main
london	doc_670731433466_item	2798157	et	4	main
kolmekümne	doc_670731433466_item	2798163	et	4	main
on	doc_670731433466_item	2798167	et	4	main
kolmkümend	doc_670731433466_item	2798169	et	4	main
kaks	doc_670731433466_item	2798170	et	3	main
aastat	doc_670731433466_item	2798171	et	3	main
vana	doc_670731433466_item	2798172	et	4	main
nad	doc_670731433466_item	2798181	et	3	main
vabakutselised	doc_670731433466_item	2798183	et	4	main
teatrid	doc_670731433466_item	2798187	et	3	main
eriti	doc_670731433466_item	2798221	et	3	main
noor	doc_670731433466_item	2798232	et	3	main
etendus	doc_670731433466_item	2798236	et	4	main
etendusel	doc_670731433466_item	2798237	et	4	main
mõnda	doc_670731433466_item	2798242	et	4	main
tantsima	doc_670731433466_item	2798253	et	3	main
pakkumisi	doc_670731433466_item	2798263	et	4	main
edule	doc_670731433466_item	2798269	et	3	main
ja	doc_670731433466_item	2798305	et	3	main
tipus	doc_670731433466_item	2798308	et	3	main
kaupa	doc_670731433466_item	2798323	et	4	main
teksti	doc_670731433466_item	2798328	et	4	main
unusta	doc_670731433466_item	2798340	et	4	main
umbne	doc_670731433466_item	2798341	et	3	main
klassiruum	doc_670731433466_item	2798342	et	3	main
koduõppesüsteem	doc_670731433466_item	2798343	et	3	main
saada	doc_670731433466_item	2798346	et	4	main
käes	doc_670731433466_item	2798358	et	4	main
aega	doc_670731433466_item	2798369	et	4	main
ning	doc_670731433466_item	2798370	et	3	main
4	doc_670731433466_item	2798376	et	2	main
on	doc_670731433466_item	2798379	et	4	main
vaatab	doc_670731433466_item	2798423	et	3	main
üle	doc_670731433466_item	2798425	et	3	main
ka	doc_670731433466_item	2798433	et	3	main
üks	doc_670731433465_item	2797906	et	3	main
ühe	doc_670731433465_item	2797908	et	4	main
päeva	doc_670731433465_item	2797909	et	4	main
unusta	doc_670731433465_item	2797927	et	4	main
umbne	doc_670731433465_item	2797928	et	3	main
klassiruum	doc_670731433465_item	2797929	et	3	main
koduõppesüsteem	doc_670731433465_item	2797930	et	3	main
sa	doc_670731433465_item	2797941	et	3	main
parasjagu	doc_670731433465_item	2797943	et	3	main
käes	doc_670731433465_item	2797945	et	4	main
on	doc_670731433465_item	2797946	et	4	main
interaktiivse	doc_670731433465_item	2797947	et	3	main
vaja	doc_670731433465_item	2797974	et	4	main
pisut	doc_670731433465_item	2797976	et	3	main
registreerunud	doc_670731433465_item	2797981	et	4	main
meie	doc_670731433465_item	2797983	et	4	main
igal	doc_670731433465_item	2797988	et	3	main
kuul	doc_670731433465_item	2797989	et	4	main
6	doc_670731433465_item	2797995	et	2	main
kursuse	doc_670731433465_item	2797998	et	3	main
vead	doc_670731433465_item	2798015	et	4	main
vajaduse	doc_670731433465_item	2798018	et	3	main
ka	doc_670731433465_item	2798020	et	3	main
on	doc_670731433465_item	2798025	et	4	main
postitage	doc_670731433465_item	2798033	et	3	main
a	doc_670731433465_item	2798036	et	4	main
soovid	doc_670731433465_item	2798039	et	4	main
2	doc_670731433465_item	2798044	et	2	main
siiski	doc_670731433465_item	2798052	et	4	main
3	doc_670731433465_item	2798053	et	2	main
vabaduse	doc_670731433465_item	2798061	et	4	main
c	doc_670731433465_item	2798067	et	4	main
d	doc_670731433465_item	2798081	et	4	main
kokku	doc_670731433465_item	2798082	et	3	main
panna	doc_670731433465_item	2798083	et	4	main
vaid	doc_670731433465_item	2798088	et	3	main
kuid	doc_670731433465_item	2798090	et	4	main
d	doc_670731433465_item	2798091	et	4	main
et	doc_670731433465_item	2798092	et	3	main
7	doc_670731433465_item	2798093	et	2	main
c	doc_670731433465_item	2798098	et	4	main
c	doc_670731433465_item	2798107	et	4	main
d	doc_670731433465_item	2798109	et	4	main
muudab	doc_670731433465_item	2798110	et	3	main
a	doc_670731433465_item	2798112	et	4	main
liigne	doc_670731433465_item	2798113	et	3	main
käige	doc_670731433465_item	2798124	et	3	main
c	doc_670731433465_item	2798125	et	4	main
sulud	doc_670731433466_item	2798131	et	3	main
sõnadega	doc_670731433466_item	2798134	et	3	main
toomas	doc_670731433466_item	2798147	et	3	main
londonis	doc_670731433466_item	2798159	et	4	main
age	doc_670731433466_item	2798160	et	4	main
toomas	doc_670731433466_item	2798166	et	3	main
aastast	doc_670731433466_item	2798179	et	4	main
murdma	doc_670731433466_item	2798230	et	3	main
luikede	doc_670731433466_item	2798234	et	3	main
pidama	doc_670731433466_item	2798240	et	4	main
age	doc_670731433466_item	2798248	et	4	main
ja	doc_670731433466_item	2798249	et	3	main
toomas	doc_670731433466_item	2798250	et	3	main
nemad	doc_670731433466_item	2798259	et	3	main
tehtud	doc_670731433466_item	2798262	et	4	main
suurele	doc_670731433466_item	2798268	et	4	main
elavad	doc_670731433466_item	2798270	et	4	main
tantsijad	doc_670731433466_item	2798271	et	4	main
oska	doc_670731433466_item	2798312	et	4	main
ütlema	doc_670731433466_item	2798314	et	3	main
ütelda	doc_670731433466_item	2798315	et	4	main
nad	doc_670731433466_item	2798316	et	3	main
päeva	doc_670731433466_item	2798322	et	4	main
iga	doc_670731433466_item	2798330	et	4	main
soovid	doc_670731433466_item	2798339	et	4	main
seda	doc_670731433466_item	2798355	et	3	main
individuaalsele	doc_670731433466_item	2798375	et	3	main
aeg	doc_670731433466_item	2798378	et	3	main
raha	doc_670731433466_item	2798380	et	4	main
et	doc_670731433466_item	2798381	et	3	main
seda	doc_670731433466_item	2798382	et	3	main
saada	doc_670731433466_item	2798385	et	4	main
on	doc_670731433466_item	2798386	et	4	main
tagasi	doc_670731433466_item	2798421	et	3	main
sul	doc_670731433465_item	2797932	et	3	main
millal	doc_670731433465_item	2797940	et	3	main
ajastu	doc_670731433465_item	2797949	et	4	main
annab	doc_670731433465_item	2797951	et	3	main
sulle	doc_670731433465_item	2797952	et	3	main
3	doc_670731433465_item	2797953	et	2	main
vajaduse	doc_670731433465_item	2797954	et	3	main
planeerida	doc_670731433465_item	2797955	et	3	main
aega	doc_670731433465_item	2797956	et	4	main
ning	doc_670731433465_item	2797957	et	3	main
eelise	doc_670731433465_item	2797958	et	4	main
omandada	doc_670731433465_item	2797959	et	3	main
teadmisi	doc_670731433465_item	2797960	et	4	main
vastavalt	doc_670731433465_item	2797961	et	4	main
individuaalsele	doc_670731433465_item	2797962	et	3	main
ka	doc_670731433465_item	2797975	et	3	main
saad	doc_670731433465_item	2797982	et	4	main
kontorist	doc_670731433465_item	2797984	et	4	main
kätte	doc_670731433465_item	2797990	et	4	main
õppematerjalid	doc_670731433465_item	2797991	et	3	main
ning	doc_670731433465_item	2797996	et	3	main
7	doc_670731433465_item	2797999	et	2	main
tasud	doc_670731433465_item	2798001	et	4	main
selle	doc_670731433465_item	2798002	et	4	main
üle	doc_670731433465_item	2798012	et	3	main
tekkinud	doc_670731433465_item	2798021	et	4	main
virtuaalkodu	doc_670731433465_item	2798031	et	4	main
1	doc_670731433465_item	2798035	et	2	main
d	doc_670731433465_item	2798051	et	4	main
4	doc_670731433465_item	2798062	et	2	main
a	doc_670731433465_item	2798063	et	4	main
tasule	doc_670731433465_item	2798064	et	3	main
5	doc_670731433465_item	2798071	et	2	main
b	doc_670731433465_item	2798075	et	4	main
liita	doc_670731433465_item	2798077	et	4	main
ning	doc_670731433465_item	2798086	et	3	main
c	doc_670731433465_item	2798089	et	4	main
b	doc_670731433465_item	2798096	et	4	main
ette	doc_670731433465_item	2798097	et	4	main
palub	doc_670731433465_item	2798106	et	3	main
liikuv	doc_670731433465_item	2798117	et	4	main
tulge	doc_670731433465_item	2798122	et	3	main
d	doc_670731433465_item	2798127	et	4	main
minge	doc_670731433465_item	2798128	et	3	main
kirjutage	doc_670731433466_item	2798133	et	3	main
annab	doc_670731433466_item	2798138	et	3	main
punkti	doc_670731433466_item	2798140	et	4	main
abielupaar	doc_670731433466_item	2798143	et	4	main
age	doc_670731433466_item	2798144	et	4	main
oks	doc_670731433466_item	2798145	et	3	main
ja	doc_670731433466_item	2798146	et	3	main
on	doc_670731433466_item	2798149	et	4	main
inglismaal	doc_670731433466_item	2798158	et	4	main
aastane	doc_670731433466_item	2798164	et	4	main
32	doc_670731433466_item	2798168	et	2	main
alates	doc_670731433466_item	2798173	et	3	main
1997a	doc_670731433466_item	2798174	et	4	main
üheksa	doc_670731433466_item	2798177	et	4	main
on	doc_670731433466_item	2798180	et	4	main
erinevad	doc_670731433466_item	2798186	et	4	main
on	doc_670731433466_item	2798223	et	4	main
probleeme	doc_670731433466_item	2798225	et	3	main
tervis	doc_670731433466_item	2798226	et	3	main
on	doc_670731433466_item	2798247	et	4	main
otsustanud	doc_670731433466_item	2798252	et	4	main
tantsida	doc_670731433466_item	2798254	et	3	main
ka	doc_670731433466_item	2798264	et	3	main
eraldi	doc_670731433466_item	2798265	et	4	main
edur	doc_670731433466_item	2798306	et	4	main
kirjutage	doc_670731433466_item	2798324	et	3	main
sobiv	doc_670731433466_item	2798326	et	4	main
alt	doc_670731433466_item	2798329	et	4	main
õpi	doc_670731433466_item	2798336	et	4	main
millal	doc_670731433466_item	2798337	et	3	main
1	doc_670731433466_item	2798338	et	2	main
targemaks	doc_670731433466_item	2798347	et	4	main
2	doc_670731433466_item	2798348	et	2	main
just	doc_670731433466_item	2798349	et	3	main
on	doc_670731433466_item	2798359	et	4	main
interaktiivse	doc_670731433466_item	2798360	et	3	main
ajastu	doc_670731433466_item	2798362	et	4	main
annab	doc_670731433466_item	2798364	et	3	main
3	doc_670731433466_item	2798366	et	2	main
vabaduse	doc_670731433466_item	2798367	et	4	main
planeerida	doc_670731433466_item	2798368	et	3	main
vastavalt	doc_670731433466_item	2798374	et	4	main
vaja	doc_670731433466_item	2798387	et	4	main
ka	doc_670731433466_item	2798388	et	3	main
meie	doc_670731433466_item	2798443	et	4	main
sobid	doc_670731433466_item	2798450	et	4	main
vajaduse	doc_670731433466_item	2798468	et	3	main
varanduse	doc_670731433466_item	2798472	et	3	main
d	doc_670731433466_item	2798473	et	4	main
vabaduse	doc_670731433466_item	2798474	et	4	main
lisaküsimustele	doc_670731433465_item	2798022	et	4	main
kõik	doc_670731433465_item	2798023	et	4	main
geniaalne	doc_670731433465_item	2798024	et	3	main
10	doc_670731433465_item	2798028	et	2	main
kupong	doc_670731433465_item	2798034	et	3	main
sobid	doc_670731433465_item	2798037	et	4	main
b	doc_670731433465_item	2798038	et	4	main
solvud	doc_670731433465_item	2798043	et	3	main
b	doc_670731433465_item	2798047	et	4	main
seega	doc_670731433465_item	2798048	et	4	main
c	doc_670731433465_item	2798049	et	4	main
kuigi	doc_670731433465_item	2798050	et	3	main
vajaduse	doc_670731433465_item	2798055	et	3	main
b	doc_670731433465_item	2798056	et	4	main
vabanduse	doc_670731433465_item	2798057	et	4	main
c	doc_670731433465_item	2798058	et	4	main
varanduse	doc_670731433465_item	2798059	et	3	main
d	doc_670731433465_item	2798069	et	4	main
kokku	doc_670731433465_item	2798073	et	3	main
saada	doc_670731433465_item	2798074	et	4	main
kokku	doc_670731433465_item	2798076	et	3	main
6	doc_670731433465_item	2798084	et	2	main
a	doc_670731433465_item	2798085	et	4	main
taga	doc_670731433465_item	2798095	et	4	main
8	doc_670731433465_item	2798102	et	2	main
a	doc_670731433465_item	2798103	et	4	main
kirjutab	doc_670731433465_item	2798104	et	3	main
d	doc_670731433465_item	2798118	et	4	main
lihtne	doc_670731433465_item	2798119	et	3	main
10	doc_670731433465_item	2798120	et	2	main
hoida	doc_670731433465_item	2798080	et	3	main
a	doc_670731433465_item	2798094	et	4	main
eest	doc_670731433465_item	2798099	et	4	main
b	doc_670731433465_item	2798105	et	4	main
parandab	doc_670731433465_item	2798108	et	3	main
9	doc_670731433465_item	2798111	et	2	main
b	doc_670731433465_item	2798114	et	4	main
libe	doc_670731433465_item	2798115	et	3	main
a	doc_670731433465_item	2798121	et	4	main
b	doc_670731433465_item	2798123	et	4	main
harjutus	doc_670731433466_item	2798129	et	4	main
avage	doc_670731433466_item	2798130	et	3	main
numbrid	doc_670731433466_item	2798132	et	3	main
iga	doc_670731433466_item	2798135	et	4	main
ühe	doc_670731433466_item	2798139	et	4	main
maailmakuulsad	doc_670731433466_item	2798141	et	3	main
edur	doc_670731433466_item	2798148	et	4	main
pärit	doc_670731433466_item	2798150	et	3	main
eesti	doc_670731433466_item	2798151	et	4	main
eestist	doc_670731433466_item	2798152	et	3	main
aga	doc_670731433466_item	2798153	et	3	main
elavad	doc_670731433466_item	2798154	et	4	main
praegu	doc_670731433466_item	2798155	et	3	main
ja	doc_670731433466_item	2798165	et	3	main
üheksasada	doc_670731433466_item	2798176	et	4	main
kümmendseitse	doc_670731433466_item	2798178	et	4	main
esinevad	doc_670731433466_item	2798185	et	4	main
teatrit	doc_670731433466_item	2798189	et	3	main
õige	doc_670731433466_item	2798136	et	4	main
inglismaa	doc_670731433466_item	2798156	et	4	main
on	doc_670731433466_item	2798161	et	4	main
30	doc_670731433466_item	2798162	et	2	main
tuha	doc_670731433466_item	2798175	et	3	main
vabakutseline	doc_670731433466_item	2798182	et	4	main
ja	doc_670731433466_item	2798184	et	3	main
erinevaid	doc_670731433466_item	2798188	et	4	main
inglismaal	doc_670731433466_item	2798190	et	4	main
armastama	doc_670731433466_item	2798191	et	3	main
armastavad	doc_670731433466_item	2798192	et	4	main
neid	doc_670731433466_item	2798193	et	4	main
väga	doc_670731433466_item	2798194	et	3	main
ning	doc_670731433466_item	2798195	et	3	main
isegi	doc_670731433466_item	2798196	et	4	main
karmid	doc_670731433466_item	2798197	et	4	main
kriitikud	doc_670731433466_item	2798198	et	3	main
suhtuma	doc_670731433466_item	2798199	et	3	main
suhtuda	doc_670731433466_item	2798200	et	3	main
nendesse	doc_670731433466_item	2798201	et	4	main
üldiselt	doc_670731433466_item	2798202	et	4	main
hästi	doc_670731433466_item	2798203	et	3	main
viimased	doc_670731433466_item	2798204	et	3	main
artiklid	doc_670731433466_item	2798205	et	3	main
räägivad	doc_670731433466_item	2798206	et	3	main
noored	doc_670731433466_item	2798207	et	3	main
noored	doc_670731433466_item	2798208	et	3	main
ainult	doc_670731433466_item	2798209	et	4	main
ülivõrdes	doc_670731433466_item	2798210	et	3	main
kuid	doc_670731433466_item	2798211	et	4	main
pole	doc_670731433466_item	2798213	et	3	main
kõik	doc_670731433466_item	2798212	et	4	main
sugugi	doc_670731433466_item	2798214	et	4	main
alati	doc_670731433466_item	2798215	et	4	main
nii	doc_670731433466_item	2798216	et	3	main
kergelt	doc_670731433466_item	2798217	et	4	main
läinud	doc_670731433466_item	2798218	et	4	main
mõlemal	doc_670731433466_item	2798219	et	3	main
ja	doc_670731433466_item	2798220	et	3	main
agel	doc_670731433466_item	2798222	et	4	main
olnud	doc_670731433466_item	2798224	et	4	main
tervisega	doc_670731433466_item	2798227	et	3	main
1990	doc_670731433466_item	2798228	et	2	main
aastal	doc_670731433466_item	2798229	et	3	main
naine	doc_670731433466_item	2798233	et	3	main
pidas	doc_670731433466_item	2798241	et	3	main
aega	doc_670731433466_item	2798243	et	4	main
tantsimisest	doc_670731433466_item	2798244	et	4	main
eemal	doc_670731433466_item	2798245	et	3	main
olema	doc_670731433466_item	2798246	et	4	main
murdis	doc_670731433466_item	2798231	et	3	main
järve	doc_670731433466_item	2798235	et	4	main
jalaluu	doc_670731433466_item	2798238	et	4	main
ja	doc_670731433466_item	2798239	et	3	main
on	doc_670731433466_item	2798251	et	4	main
ainult	doc_670731433466_item	2798255	et	4	main
teineteisega	doc_670731433466_item	2798256	et	3	main
nad	doc_670731433466_item	2798260	et	3	main
on	doc_670731433466_item	2798261	et	4	main
tantsimiseks	doc_670731433466_item	2798266	et	4	main
vaatamata	doc_670731433466_item	2798267	et	4	main
nende	doc_670731433466_item	2798274	et	4	main
lähiaja	doc_670731433466_item	2798275	et	3	main
esinemised	doc_670731433466_item	2798276	et	4	main
on	doc_670731433466_item	2798277	et	4	main
täpselt	doc_670731433466_item	2798278	et	4	main
planeerima	doc_670731433466_item	2798279	et	3	main
planeeritud	doc_670731433466_item	2798280	et	4	main
age	doc_670731433466_item	2798281	et	4	main
ja	doc_670731433466_item	2798282	et	3	main
toomas	doc_670731433466_item	2798283	et	3	main
tahavad	doc_670731433466_item	2798284	et	3	main
areneda	doc_670731433466_item	2798285	et	3	main
ja	doc_670731433466_item	2798286	et	3	main
veelgi	doc_670731433466_item	2798287	et	4	main
parem	doc_670731433466_item	2798288	et	4	main
parem	doc_670731433466_item	2798289	et	4	main
tantsida	doc_670731433466_item	2798290	et	3	main
märtsis	doc_670731433466_item	2798291	et	3	main
tulevad	doc_670731433466_item	2798292	et	4	main
nad	doc_670731433466_item	2798293	et	3	main
esinema	doc_670731433466_item	2798294	et	3	main
tallinn	doc_670731433466_item	2798295	et	4	main
tallinnas	doc_670731433466_item	2798296	et	4	main
ja	doc_670731433466_item	2798297	et	3	main
seejärel	doc_670731433466_item	2798298	et	3	main
paaris	doc_670731433466_item	2798257	et	4	main
kuigi	doc_670731433466_item	2798258	et	3	main
tagasihoidlik	doc_670731433466_item	2798272	et	3	main
tagasihoidlikult	doc_670731433466_item	2798273	et	4	main
sõidavad	doc_670731433466_item	2798299	et	3	main
lõuna-aafrika	doc_670731433466_item	2798300	et	4	main
veel	doc_670731433466_item	2798307	et	4	main
suudavad	doc_670731433466_item	2798309	et	3	main
ei	doc_670731433466_item	2798311	et	4	main
nad	doc_670731433466_item	2798313	et	3	main
eelistavad	doc_670731433466_item	2798317	et	4	main
elada	doc_670731433466_item	2798318	et	3	main
üks	doc_670731433466_item	2798319	et	3	main
päev	doc_670731433466_item	2798320	et	3	main
lõuna-aafrikasse	doc_670731433466_item	2798301	et	4	main
kui	doc_670731433466_item	2798302	et	3	main
kaua	doc_670731433466_item	2798303	et	3	main
oks	doc_670731433466_item	2798304	et	3	main
püsida	doc_670731433466_item	2798310	et	3	main
ühe	doc_670731433466_item	2798321	et	4	main
õige	doc_670731433466_item	2798331	et	4	main
vastus	doc_670731433466_item	2798332	et	3	main
annab	doc_670731433466_item	2798333	et	3	main
ühe	doc_670731433466_item	2798334	et	4	main
punkti	doc_670731433466_item	2798335	et	4	main
sul	doc_670731433466_item	2798345	et	3	main
seal	doc_670731433466_item	2798350	et	4	main
kus	doc_670731433466_item	2798351	et	3	main
ja	doc_670731433466_item	2798352	et	3	main
millal	doc_670731433466_item	2798353	et	3	main
sa	doc_670731433466_item	2798354	et	3	main
parasjagu	doc_670731433466_item	2798356	et	3	main
eelise	doc_670731433466_item	2798371	et	4	main
omandada	doc_670731433466_item	2798372	et	3	main
teadmisi	doc_670731433466_item	2798373	et	4	main
5	doc_670731433466_item	2798383	et	2	main
kokku	doc_670731433466_item	2798384	et	3	main
lünka	doc_670731433466_item	2798325	et	4	main
sõna	doc_670731433466_item	2798327	et	4	main
võimaldab	doc_670731433466_item	2798344	et	3	main
soovid	doc_670731433466_item	2798357	et	4	main
õppe	doc_670731433466_item	2798361	et	4	main
mis	doc_670731433466_item	2798363	et	4	main
sulle	doc_670731433466_item	2798365	et	3	main
tasakesi	doc_670731433466_item	2798377	et	3	main
pisut	doc_670731433466_item	2798389	et	3	main
tarkust	doc_670731433466_item	2798390	et	4	main
kui	doc_670731433466_item	2798391	et	3	main
oled	doc_670731433466_item	2798392	et	3	main
kursusele	doc_670731433466_item	2798393	et	3	main
registreerunud	doc_670731433466_item	2798394	et	4	main
saad	doc_670731433466_item	2798395	et	4	main
meie	doc_670731433466_item	2798396	et	4	main
kontorist	doc_670731433466_item	2798397	et	4	main
või	doc_670731433466_item	2798398	et	4	main
lähimast	doc_670731433466_item	2798399	et	4	main
postiasutusest	doc_670731433466_item	2798400	et	4	main
igal	doc_670731433466_item	2798401	et	3	main
kuul	doc_670731433466_item	2798402	et	4	main
kätte	doc_670731433466_item	2798403	et	4	main
õppematerjalid	doc_670731433466_item	2798404	et	3	main
raamatu	doc_670731433466_item	2798405	et	4	main
ja	doc_670731433466_item	2798406	et	3	main
helikasseti	doc_670731433466_item	2798407	et	4	main
6	doc_670731433466_item	2798408	et	2	main
kodutöö	doc_670731433466_item	2798410	et	4	main
ning	doc_670731433466_item	2798409	et	3	main
kursuse	doc_670731433466_item	2798411	et	3	main
7	doc_670731433466_item	2798412	et	2	main
eest	doc_670731433466_item	2798413	et	4	main
tasud	doc_670731433466_item	2798414	et	4	main
selle	doc_670731433466_item	2798415	et	4	main
kättesaamisel	doc_670731433466_item	2798416	et	4	main
saada	doc_670731433466_item	2798417	et	4	main
täidetud	doc_670731433466_item	2798418	et	4	main
kodutöö	doc_670731433466_item	2798419	et	4	main
meile	doc_670731433466_item	2798420	et	4	main
korral	doc_670731433466_item	2798432	et	4	main
kõik	doc_670731433466_item	2798436	et	4	main
on	doc_670731433466_item	2798438	et	4	main
9	doc_670731433466_item	2798439	et	2	main
lihtne	doc_670731433466_item	2798440	et	3	main
10	doc_670731433466_item	2798441	et	2	main
külastage	doc_670731433466_item	2798442	et	3	main
b	doc_670731433466_item	2798460	et	4	main
seega	doc_670731433466_item	2798461	et	4	main
õpetaja	doc_670731433466_item	2798422	et	4	main
vead	doc_670731433466_item	2798428	et	4	main
vajaduse	doc_670731433466_item	2798431	et	3	main
a	doc_670731433466_item	2798458	et	4	main
just	doc_670731433466_item	2798459	et	3	main
siiski	doc_670731433466_item	2798465	et	4	main
3	doc_670731433466_item	2798466	et	2	main
4	doc_670731433466_item	2798475	et	2	main
a	doc_670731433466_item	2798476	et	4	main
tasule	doc_670731433466_item	2798477	et	3	main
c	doc_670731433466_item	2798480	et	4	main
tasakesi	doc_670731433466_item	2798481	et	3	main
d	doc_670731433466_item	2798482	et	4	main
tasakaalule	doc_670731433466_item	2798483	et	3	main
5	doc_670731433466_item	2798484	et	2	main
a	doc_670731433466_item	2798485	et	4	main
kokku	doc_670731433466_item	2798486	et	3	main
saada	doc_670731433466_item	2798487	et	4	main
b	doc_670731433466_item	2798488	et	4	main
kokku	doc_670731433466_item	2798489	et	3	main
liita	doc_670731433466_item	2798490	et	4	main
c	doc_670731433466_item	2798491	et	4	main
kokku	doc_670731433466_item	2798492	et	3	main
hoida	doc_670731433466_item	2798493	et	3	main
d	doc_670731433466_item	2798494	et	4	main
kokku	doc_670731433466_item	2798495	et	3	main
panna	doc_670731433466_item	2798496	et	4	main
6	doc_670731433466_item	2798497	et	2	main
a	doc_670731433466_item	2798498	et	4	main
ning	doc_670731433466_item	2798499	et	3	main
b	doc_670731433466_item	2798500	et	4	main
vaid	doc_670731433466_item	2798501	et	3	main
c	doc_670731433466_item	2798502	et	4	main
kuid	doc_670731433466_item	2798503	et	4	main
d	doc_670731433466_item	2798504	et	4	main
et	doc_670731433466_item	2798505	et	3	main
7	doc_670731433466_item	2798506	et	2	main
a	doc_670731433466_item	2798507	et	4	main
taga	doc_670731433466_item	2798508	et	4	main
b	doc_670731433466_item	2798509	et	4	main
ette	doc_670731433466_item	2798510	et	4	main
c	doc_670731433466_item	2798511	et	4	main
selle	doc_670731433466_item	2798424	et	4	main
8	doc_670731433466_item	2798426	et	2	main
parandab	doc_670731433466_item	2798427	et	3	main
ning	doc_670731433466_item	2798429	et	3	main
vastab	doc_670731433466_item	2798430	et	3	main
tekkinud	doc_670731433466_item	2798434	et	4	main
virtuaalkodu	doc_670731433466_item	2798444	et	4	main
või	doc_670731433466_item	2798445	et	4	main
postitage	doc_670731433466_item	2798446	et	3	main
kupong	doc_670731433466_item	2798447	et	3	main
b	doc_670731433466_item	2798451	et	4	main
c	doc_670731433466_item	2798453	et	4	main
soovitad	doc_670731433466_item	2798454	et	3	main
d	doc_670731433466_item	2798455	et	4	main
solvud	doc_670731433466_item	2798456	et	3	main
2	doc_670731433466_item	2798457	et	2	main
d	doc_670731433466_item	2798464	et	4	main
vabanduse	doc_670731433466_item	2798470	et	4	main
b	doc_670731433466_item	2798518	et	4	main
parandab	doc_670731433466_item	2798521	et	3	main
muudab	doc_670731433466_item	2798523	et	3	main
b	doc_670731433466_item	2798527	et	4	main
c	doc_670731433466_item	2798529	et	4	main
d	doc_670731433466_item	2798540	et	4	main
minge	doc_670731433466_item	2798541	et	3	main
kirjutage	doc_670731433467_item	2798546	et	3	main
sõnadega	doc_670731433467_item	2798547	et	3	main
õige	doc_670731433467_item	2798549	et	4	main
maailmakuulsad	doc_670731433467_item	2798554	et	3	main
praegu	doc_670731433467_item	2798568	et	3	main
london	doc_670731433467_item	2798570	et	4	main
inglismaal	doc_670731433467_item	2798571	et	4	main
aastane	doc_670731433467_item	2798578	et	4	main
ja	doc_670731433467_item	2798579	et	3	main
toomas	doc_670731433467_item	2798580	et	3	main
32	doc_670731433467_item	2798582	et	2	main
kaks	doc_670731433467_item	2798585	et	3	main
üheksa	doc_670731433467_item	2798593	et	4	main
noored	doc_670731433467_item	2798624	et	3	main
alati	doc_670731433467_item	2798632	et	4	main
olnud	doc_670731433467_item	2798641	et	4	main
murdma	doc_670731433467_item	2798647	et	3	main
järve	doc_670731433467_item	2798652	et	4	main
jalaluu	doc_670731433467_item	2798655	et	4	main
mõnda	doc_670731433467_item	2798659	et	4	main
tantsimisest	doc_670731433467_item	2798661	et	4	main
eemal	doc_670731433467_item	2798662	et	3	main
olema	doc_670731433467_item	2798663	et	4	main
otsustanud	doc_670731433467_item	2798669	et	4	main
tantsima	doc_670731433467_item	2798670	et	3	main
tansida	doc_670731433467_item	2798671	et	4	main
nemad	doc_670731433467_item	2798676	et	3	main
lõuna-aafrika	doc_670731433467_item	2798716	et	4	main
päeva	doc_670731433467_item	2798738	et	4	main
kirjutage	doc_670731433467_item	2798740	et	3	main
sobiv	doc_670731433467_item	2798742	et	4	main
sõna	doc_670731433467_item	2798743	et	4	main
õige	doc_670731433467_item	2798747	et	4	main
vastus	doc_670731433467_item	2798748	et	3	main
annab	doc_670731433467_item	2798749	et	3	main
koduõppesüsteem	doc_670731433467_item	2798759	et	3	main
soovid	doc_670731433467_item	2798773	et	4	main
õppe	doc_670731433467_item	2798777	et	4	main
mis	doc_670731433467_item	2798779	et	4	main
3	doc_670731433467_item	2798782	et	2	main
vabaduse	doc_670731433467_item	2798783	et	4	main
planeerida	doc_670731433467_item	2798784	et	3	main
tasule	doc_670731433467_item	2798793	et	3	main
seda	doc_670731433467_item	2798798	et	3	main
kokku	doc_670731433467_item	2798800	et	3	main
lisaküsimustele	doc_670731433466_item	2798435	et	4	main
geniaalne	doc_670731433466_item	2798437	et	3	main
1	doc_670731433466_item	2798448	et	2	main
a	doc_670731433466_item	2798449	et	4	main
soovid	doc_670731433466_item	2798452	et	4	main
a	doc_670731433466_item	2798467	et	4	main
b	doc_670731433466_item	2798478	et	4	main
8	doc_670731433466_item	2798515	et	2	main
a	doc_670731433466_item	2798516	et	4	main
kirjutab	doc_670731433466_item	2798517	et	3	main
d	doc_670731433466_item	2798522	et	4	main
a	doc_670731433466_item	2798534	et	4	main
tulge	doc_670731433466_item	2798535	et	3	main
avage	doc_670731433467_item	2798543	et	3	main
punkti	doc_670731433467_item	2798553	et	4	main
abielupaar	doc_670731433467_item	2798556	et	4	main
oks	doc_670731433467_item	2798558	et	3	main
edur	doc_670731433467_item	2798561	et	4	main
age	doc_670731433467_item	2798573	et	4	main
on	doc_670731433467_item	2798574	et	4	main
30	doc_670731433467_item	2798575	et	2	main
sada	doc_670731433467_item	2798592	et	4	main
c	doc_670731433466_item	2798462	et	4	main
kuigi	doc_670731433466_item	2798463	et	3	main
b	doc_670731433466_item	2798469	et	4	main
c	doc_670731433466_item	2798471	et	4	main
d	doc_670731433466_item	2798513	et	4	main
9	doc_670731433466_item	2798524	et	2	main
libe	doc_670731433466_item	2798528	et	3	main
liikuv	doc_670731433466_item	2798530	et	4	main
d	doc_670731433466_item	2798531	et	4	main
lihtne	doc_670731433466_item	2798532	et	3	main
10	doc_670731433466_item	2798533	et	2	main
harjutus	doc_670731433467_item	2798542	et	4	main
annab	doc_670731433467_item	2798551	et	3	main
on	doc_670731433467_item	2798562	et	4	main
pärit	doc_670731433467_item	2798563	et	3	main
eesti	doc_670731433467_item	2798564	et	4	main
eestist	doc_670731433467_item	2798565	et	3	main
kolm	doc_670731433467_item	2798576	et	3	main
kümnenda	doc_670731433467_item	2798577	et	3	main
kümend	doc_670731433467_item	2798584	et	4	main
aastat	doc_670731433467_item	2798586	et	3	main
alates	doc_670731433467_item	2798588	et	3	main
räägivad	doc_670731433467_item	2798623	et	3	main
ülivõrdes	doc_670731433467_item	2798627	et	3	main
kuid	doc_670731433467_item	2798628	et	4	main
pole	doc_670731433467_item	2798630	et	3	main
eriti	doc_670731433467_item	2798638	et	3	main
agel	doc_670731433467_item	2798639	et	4	main
tervis	doc_670731433467_item	2798643	et	3	main
ja	doc_670731433467_item	2798656	et	3	main
age	doc_670731433467_item	2798665	et	4	main
on	doc_670731433467_item	2798668	et	4	main
on	doc_670731433467_item	2798677	et	4	main
lõuna-aafrikasse	doc_670731433467_item	2798717	et	4	main
oks	doc_670731433467_item	2798720	et	3	main
veel	doc_670731433467_item	2798723	et	4	main
teksti	doc_670731433467_item	2798744	et	4	main
ühe	doc_670731433467_item	2798750	et	4	main
punkti	doc_670731433467_item	2798751	et	4	main
umbne	doc_670731433467_item	2798757	et	3	main
sul	doc_670731433467_item	2798761	et	3	main
2	doc_670731433467_item	2798764	et	2	main
siiski	doc_670731433467_item	2798765	et	4	main
seal	doc_670731433467_item	2798766	et	4	main
kus	doc_670731433467_item	2798767	et	3	main
ja	doc_670731433467_item	2798768	et	3	main
millal	doc_670731433467_item	2798769	et	3	main
sa	doc_670731433467_item	2798770	et	3	main
seda	doc_670731433467_item	2798771	et	3	main
parasjagu	doc_670731433467_item	2798772	et	3	main
on	doc_670731433467_item	2798775	et	4	main
ajastu	doc_670731433467_item	2798778	et	4	main
annab	doc_670731433467_item	2798780	et	3	main
sulle	doc_670731433467_item	2798781	et	3	main
vastavalt	doc_670731433467_item	2798790	et	4	main
individuaalsele	doc_670731433467_item	2798791	et	3	main
4	doc_670731433467_item	2798792	et	2	main
6	doc_670731433467_item	2798824	et	2	main
kodutöö	doc_670731433467_item	2798826	et	4	main
tasud	doc_670731433467_item	2798830	et	4	main
lihtne	doc_670731433467_item	2798856	et	3	main
solvud	doc_670731433467_item	2798872	et	3	main
siiski	doc_670731433467_item	2798881	et	4	main
d	doc_670731433467_item	2798889	et	4	main
tasule	doc_670731433467_item	2798893	et	3	main
kokku	doc_670731433467_item	2798908	et	3	main
kokku	doc_670731433467_item	2798911	et	3	main
a	doc_670731433467_item	2798923	et	4	main
d	doc_670731433467_item	2798929	et	4	main
parandab	doc_670731433467_item	2798937	et	3	main
muudab	doc_670731433467_item	2798939	et	3	main
b	doc_670731433467_item	2798943	et	4	main
a	doc_670731433467_item	2798950	et	4	main
sõnadega	doc_670731433468_item	2798963	et	3	main
iga	doc_670731433468_item	2798964	et	4	main
londonis	doc_670731433468_item	2798988	et	4	main
toomas	doc_670731433468_item	2798995	et	3	main
üheksakümmend	doc_670731433468_item	2799006	et	4	main
seitsmendal	doc_670731433468_item	2799007	et	3	main
nad	doc_670731433468_item	2799009	et	3	main
armastad	doc_670731433468_item	2799020	et	3	main
väga	doc_670731433468_item	2799022	et	3	main
tasemele	doc_670731433466_item	2798479	et	3	main
ees	doc_670731433466_item	2798514	et	4	main
liigne	doc_670731433466_item	2798526	et	3	main
b	doc_670731433466_item	2798536	et	4	main
sulud	doc_670731433467_item	2798544	et	3	main
iga	doc_670731433467_item	2798548	et	4	main
vastus	doc_670731433467_item	2798550	et	3	main
age	doc_670731433467_item	2798557	et	4	main
toomas	doc_670731433467_item	2798560	et	3	main
elavad	doc_670731433467_item	2798567	et	4	main
kolm	doc_670731433467_item	2798583	et	3	main
vana	doc_670731433467_item	2798587	et	4	main
kümend	doc_670731433467_item	2798594	et	4	main
seitsmendal	doc_670731433467_item	2798595	et	3	main
aastal	doc_670731433467_item	2798596	et	3	main
on	doc_670731433467_item	2798597	et	4	main
nad	doc_670731433467_item	2798598	et	3	main
vabakutseline	doc_670731433467_item	2798599	et	4	main
viimased	doc_670731433467_item	2798621	et	3	main
nii	doc_670731433467_item	2798633	et	3	main
kergelt	doc_670731433467_item	2798634	et	4	main
läinud	doc_670731433467_item	2798635	et	4	main
mõlemal	doc_670731433467_item	2798636	et	3	main
ja	doc_670731433467_item	2798637	et	3	main
probleeme	doc_670731433467_item	2798642	et	3	main
murdsib	doc_670731433467_item	2798648	et	4	main
naine	doc_670731433467_item	2798650	et	3	main
luikede	doc_670731433467_item	2798651	et	3	main
etendus	doc_670731433467_item	2798653	et	4	main
olema	doc_670731433467_item	2798664	et	4	main
ainult	doc_670731433467_item	2798672	et	4	main
teineteisega	doc_670731433467_item	2798673	et	3	main
kui	doc_670731433467_item	2798718	et	3	main
edur	doc_670731433467_item	2798722	et	4	main
tipus	doc_670731433467_item	2798724	et	3	main
ei	doc_670731433467_item	2798727	et	4	main
oska	doc_670731433467_item	2798728	et	4	main
nad	doc_670731433467_item	2798729	et	3	main
ütlema	doc_670731433467_item	2798730	et	3	main
kaupa	doc_670731433467_item	2798739	et	4	main
alt	doc_670731433467_item	2798745	et	4	main
iga	doc_670731433467_item	2798746	et	4	main
klassiruum	doc_670731433467_item	2798758	et	3	main
võimaldab	doc_670731433467_item	2798760	et	3	main
interaktiivse	doc_670731433467_item	2798776	et	3	main
eelise	doc_670731433467_item	2798787	et	4	main
raamatu	doc_670731433467_item	2798821	et	4	main
helikasseti	doc_670731433467_item	2798823	et	4	main
ning	doc_670731433467_item	2798825	et	3	main
kursuse	doc_670731433467_item	2798827	et	3	main
7	doc_670731433467_item	2798828	et	2	main
kodutöö	doc_670731433467_item	2798835	et	4	main
vajaduse	doc_670731433467_item	2798847	et	3	main
lisaküsimustele	doc_670731433467_item	2798851	et	4	main
kõik	doc_670731433467_item	2798852	et	4	main
on	doc_670731433467_item	2798854	et	4	main
c	doc_670731433467_item	2798878	et	4	main
kuigi	doc_670731433467_item	2798879	et	3	main
vabanduse	doc_670731433467_item	2798886	et	4	main
vabaduse	doc_670731433467_item	2798890	et	4	main
a	doc_670731433467_item	2798892	et	4	main
d	doc_670731433467_item	2798898	et	4	main
tasakaalule	doc_670731433467_item	2798899	et	3	main
5	doc_670731433467_item	2798900	et	2	main
et	doc_670731433467_item	2798921	et	3	main
taga	doc_670731433467_item	2798924	et	4	main
ees	doc_670731433467_item	2798930	et	4	main
8	doc_670731433467_item	2798931	et	2	main
a	doc_670731433467_item	2798932	et	4	main
kirjutab	doc_670731433467_item	2798933	et	3	main
9	doc_670731433467_item	2798940	et	2	main
10	doc_670731433467_item	2798949	et	2	main
kolmkümmend	doc_670731433468_item	2798992	et	4	main
aastane	doc_670731433468_item	2798993	et	4	main
ja	doc_670731433468_item	2798994	et	3	main
tuhande	doc_670731433468_item	2799004	et	3	main
erinevad	doc_670731433468_item	2799014	et	4	main
neid	doc_670731433468_item	2799021	et	4	main
üldiselt	doc_670731433468_item	2799030	et	4	main
hästi	doc_670731433468_item	2799031	et	3	main
viimased	doc_670731433468_item	2799032	et	3	main
nooreks	doc_670731433468_item	2799036	et	3	main
eest	doc_670731433466_item	2798512	et	4	main
palub	doc_670731433466_item	2798519	et	3	main
c	doc_670731433466_item	2798520	et	4	main
a	doc_670731433466_item	2798525	et	4	main
käige	doc_670731433466_item	2798537	et	3	main
c	doc_670731433466_item	2798538	et	4	main
külastage	doc_670731433466_item	2798539	et	3	main
numbrid	doc_670731433467_item	2798545	et	3	main
ühe	doc_670731433467_item	2798552	et	4	main
balletitantsijad	doc_670731433467_item	2798555	et	3	main
ja	doc_670731433467_item	2798559	et	3	main
aga	doc_670731433467_item	2798566	et	3	main
inglismaa	doc_670731433467_item	2798569	et	4	main
londonis	doc_670731433467_item	2798572	et	4	main
on	doc_670731433467_item	2798581	et	4	main
1997a	doc_670731433467_item	2798589	et	4	main
tuhad	doc_670731433467_item	2798590	et	3	main
üheksa	doc_670731433467_item	2798591	et	4	main
vabakutselised	doc_670731433467_item	2798600	et	4	main
ja	doc_670731433467_item	2798601	et	3	main
esinevad	doc_670731433467_item	2798602	et	4	main
teatrid	doc_670731433467_item	2798604	et	3	main
erinevad	doc_670731433467_item	2798603	et	4	main
erinevas	doc_670731433467_item	2798605	et	4	main
teatris	doc_670731433467_item	2798606	et	3	main
inglismaal	doc_670731433467_item	2798607	et	4	main
armastama	doc_670731433467_item	2798608	et	3	main
armastab	doc_670731433467_item	2798609	et	3	main
neid	doc_670731433467_item	2798610	et	4	main
väga	doc_670731433467_item	2798611	et	3	main
ning	doc_670731433467_item	2798612	et	3	main
isegi	doc_670731433467_item	2798613	et	4	main
karmid	doc_670731433467_item	2798614	et	4	main
kriitikud	doc_670731433467_item	2798615	et	3	main
suhtuma	doc_670731433467_item	2798616	et	3	main
suhtuda	doc_670731433467_item	2798617	et	3	main
nendesse	doc_670731433467_item	2798618	et	4	main
üldiselt	doc_670731433467_item	2798619	et	4	main
hästi	doc_670731433467_item	2798620	et	3	main
noorest	doc_670731433467_item	2798625	et	3	main
kõik	doc_670731433467_item	2798629	et	4	main
sugugi	doc_670731433467_item	2798631	et	4	main
on	doc_670731433467_item	2798640	et	4	main
1990	doc_670731433467_item	2798645	et	2	main
etendusest	doc_670731433467_item	2798654	et	4	main
pidama	doc_670731433467_item	2798657	et	4	main
toomas	doc_670731433467_item	2798667	et	3	main
tehtud	doc_670731433467_item	2798678	et	4	main
ka	doc_670731433467_item	2798680	et	3	main
tallinn	doc_670731433467_item	2798711	et	4	main
tallinasse	doc_670731433467_item	2798712	et	4	main
ja	doc_670731433467_item	2798713	et	3	main
seejärel	doc_670731433467_item	2798714	et	3	main
sõidavad	doc_670731433467_item	2798715	et	3	main
ja	doc_670731433467_item	2798721	et	3	main
suudavad	doc_670731433467_item	2798725	et	3	main
püsida	doc_670731433467_item	2798726	et	3	main
ühe	doc_670731433467_item	2798737	et	4	main
lünka	doc_670731433467_item	2798741	et	4	main
unusta	doc_670731433467_item	2798756	et	4	main
targemaks	doc_670731433467_item	2798763	et	4	main
käes	doc_670731433467_item	2798774	et	4	main
omandada	doc_670731433467_item	2798788	et	3	main
artiklid	doc_670731433467_item	2798622	et	3	main
ainult	doc_670731433467_item	2798626	et	4	main
tervisega	doc_670731433467_item	2798644	et	3	main
aastal	doc_670731433467_item	2798646	et	3	main
noor	doc_670731433467_item	2798649	et	3	main
peab	doc_670731433467_item	2798658	et	4	main
aega	doc_670731433467_item	2798660	et	4	main
ja	doc_670731433467_item	2798666	et	3	main
paaris	doc_670731433467_item	2798674	et	4	main
kuigi	doc_670731433467_item	2798675	et	3	main
pakkumisi	doc_670731433467_item	2798679	et	4	main
eraldi	doc_670731433467_item	2798681	et	4	main
tantsimiseks	doc_670731433467_item	2798682	et	4	main
vaatamata	doc_670731433467_item	2798683	et	4	main
suurele	doc_670731433467_item	2798684	et	4	main
edule	doc_670731433467_item	2798685	et	3	main
elavad	doc_670731433467_item	2798686	et	4	main
tantsijad	doc_670731433467_item	2798687	et	4	main
tagasihoidlik	doc_670731433467_item	2798688	et	3	main
tagasihoidlikus	doc_670731433467_item	2798689	et	4	main
nende	doc_670731433467_item	2798690	et	4	main
lähiaja	doc_670731433467_item	2798691	et	3	main
esinemised	doc_670731433467_item	2798692	et	4	main
on	doc_670731433467_item	2798693	et	4	main
täpselt	doc_670731433467_item	2798694	et	4	main
planeerima	doc_670731433467_item	2798695	et	3	main
planeerivad	doc_670731433467_item	2798696	et	4	main
age	doc_670731433467_item	2798697	et	4	main
ja	doc_670731433467_item	2798698	et	3	main
toomas	doc_670731433467_item	2798699	et	3	main
tahavad	doc_670731433467_item	2798700	et	3	main
areneda	doc_670731433467_item	2798701	et	3	main
ja	doc_670731433467_item	2798702	et	3	main
veelgi	doc_670731433467_item	2798703	et	4	main
parem	doc_670731433467_item	2798704	et	4	main
parem	doc_670731433467_item	2798705	et	4	main
tantsida	doc_670731433467_item	2798706	et	3	main
märtsis	doc_670731433467_item	2798707	et	3	main
tulevad	doc_670731433467_item	2798708	et	4	main
nad	doc_670731433467_item	2798709	et	3	main
esinema	doc_670731433467_item	2798710	et	3	main
kaua	doc_670731433467_item	2798719	et	3	main
ütelda	doc_670731433467_item	2798731	et	4	main
nad	doc_670731433467_item	2798732	et	3	main
eelistavad	doc_670731433467_item	2798733	et	4	main
elada	doc_670731433467_item	2798734	et	3	main
üks	doc_670731433467_item	2798735	et	3	main
päev	doc_670731433467_item	2798736	et	3	main
õpi	doc_670731433467_item	2798752	et	4	main
millal	doc_670731433467_item	2798753	et	3	main
1	doc_670731433467_item	2798754	et	2	main
soovid	doc_670731433467_item	2798755	et	4	main
saada	doc_670731433467_item	2798762	et	4	main
aega	doc_670731433467_item	2798785	et	4	main
ning	doc_670731433467_item	2798786	et	3	main
aeg	doc_670731433467_item	2798794	et	3	main
raha	doc_670731433467_item	2798796	et	4	main
5	doc_670731433467_item	2798799	et	2	main
on	doc_670731433467_item	2798802	et	4	main
vaja	doc_670731433467_item	2798803	et	4	main
ka	doc_670731433467_item	2798804	et	3	main
pisut	doc_670731433467_item	2798805	et	3	main
tarkust	doc_670731433467_item	2798806	et	4	main
kui	doc_670731433467_item	2798807	et	3	main
oled	doc_670731433467_item	2798808	et	3	main
kursusele	doc_670731433467_item	2798809	et	3	main
registreerunud	doc_670731433467_item	2798810	et	4	main
saad	doc_670731433467_item	2798811	et	4	main
meie	doc_670731433467_item	2798812	et	4	main
kontorist	doc_670731433467_item	2798813	et	4	main
või	doc_670731433467_item	2798814	et	4	main
lähimast	doc_670731433467_item	2798815	et	4	main
postiasutusest	doc_670731433467_item	2798816	et	4	main
igal	doc_670731433467_item	2798817	et	3	main
kuul	doc_670731433467_item	2798818	et	4	main
kätte	doc_670731433467_item	2798819	et	4	main
õppematerjalid	doc_670731433467_item	2798820	et	3	main
ette	doc_670731433467_item	2798829	et	4	main
selle	doc_670731433467_item	2798831	et	4	main
kättesaamisel	doc_670731433467_item	2798832	et	4	main
meile	doc_670731433467_item	2798836	et	4	main
tagasi	doc_670731433467_item	2798837	et	3	main
õpetaja	doc_670731433467_item	2798838	et	4	main
vaatab	doc_670731433467_item	2798839	et	3	main
selle	doc_670731433467_item	2798840	et	4	main
üle	doc_670731433467_item	2798841	et	3	main
8	doc_670731433467_item	2798842	et	2	main
ka	doc_670731433467_item	2798849	et	3	main
tekkinud	doc_670731433467_item	2798850	et	4	main
9	doc_670731433467_item	2798855	et	2	main
10	doc_670731433467_item	2798857	et	2	main
meie	doc_670731433467_item	2798859	et	4	main
virtuaalkodu	doc_670731433467_item	2798860	et	4	main
või	doc_670731433467_item	2798861	et	4	main
postitage	doc_670731433467_item	2798862	et	3	main
kupong	doc_670731433467_item	2798863	et	3	main
1	doc_670731433467_item	2798864	et	2	main
c	doc_670731433467_item	2798869	et	4	main
2	doc_670731433467_item	2798873	et	2	main
just	doc_670731433467_item	2798875	et	3	main
3	doc_670731433467_item	2798882	et	2	main
a	doc_670731433467_item	2798883	et	4	main
vajaduse	doc_670731433467_item	2798884	et	3	main
b	doc_670731433467_item	2798885	et	4	main
c	doc_670731433467_item	2798907	et	4	main
teadmisi	doc_670731433467_item	2798789	et	4	main
on	doc_670731433467_item	2798795	et	4	main
et	doc_670731433467_item	2798797	et	3	main
saada	doc_670731433467_item	2798801	et	4	main
saada	doc_670731433467_item	2798833	et	4	main
korral	doc_670731433467_item	2798848	et	4	main
a	doc_670731433467_item	2798865	et	4	main
soovitad	doc_670731433467_item	2798870	et	3	main
a	doc_670731433467_item	2798874	et	4	main
d	doc_670731433467_item	2798880	et	4	main
c	doc_670731433467_item	2798887	et	4	main
varanduse	doc_670731433467_item	2798888	et	3	main
a	doc_670731433467_item	2798901	et	4	main
kokku	doc_670731433467_item	2798902	et	3	main
saada	doc_670731433467_item	2798903	et	4	main
hoida	doc_670731433467_item	2798909	et	3	main
6	doc_670731433467_item	2798913	et	2	main
b	doc_670731433467_item	2798934	et	4	main
palub	doc_670731433467_item	2798935	et	3	main
c	doc_670731433467_item	2798936	et	4	main
d	doc_670731433467_item	2798938	et	4	main
b	doc_670731433467_item	2798952	et	4	main
c	doc_670731433467_item	2798954	et	4	main
õige	doc_670731433468_item	2798965	et	4	main
age	doc_670731433468_item	2798989	et	4	main
on	doc_670731433468_item	2798990	et	4	main
30	doc_670731433468_item	2798991	et	2	main
32	doc_670731433468_item	2798997	et	2	main
üheksasaja	doc_670731433468_item	2799005	et	4	main
on	doc_670731433468_item	2799008	et	4	main
teatrid	doc_670731433468_item	2799015	et	3	main
erinevad	doc_670731433468_item	2799016	et	4	main
teatrid	doc_670731433468_item	2799017	et	3	main
inglismaal	doc_670731433468_item	2799018	et	4	main
armastama	doc_670731433468_item	2799019	et	3	main
ja	doc_670731433467_item	2798822	et	3	main
täidetud	doc_670731433467_item	2798834	et	4	main
parandab	doc_670731433467_item	2798843	et	3	main
vead	doc_670731433467_item	2798844	et	4	main
ning	doc_670731433467_item	2798845	et	3	main
vastab	doc_670731433467_item	2798846	et	3	main
geniaalne	doc_670731433467_item	2798853	et	3	main
tulge	doc_670731433467_item	2798858	et	3	main
sobid	doc_670731433467_item	2798866	et	4	main
b	doc_670731433467_item	2798867	et	4	main
soovid	doc_670731433467_item	2798868	et	4	main
d	doc_670731433467_item	2798871	et	4	main
b	doc_670731433467_item	2798876	et	4	main
seega	doc_670731433467_item	2798877	et	4	main
4	doc_670731433467_item	2798891	et	2	main
b	doc_670731433467_item	2798894	et	4	main
tasemele	doc_670731433467_item	2798895	et	3	main
c	doc_670731433467_item	2798896	et	4	main
tasakesi	doc_670731433467_item	2798897	et	3	main
b	doc_670731433467_item	2798904	et	4	main
kokku	doc_670731433467_item	2798905	et	3	main
liita	doc_670731433467_item	2798906	et	4	main
d	doc_670731433467_item	2798910	et	4	main
panna	doc_670731433467_item	2798912	et	4	main
a	doc_670731433467_item	2798914	et	4	main
ning	doc_670731433467_item	2798915	et	3	main
b	doc_670731433467_item	2798916	et	4	main
vaid	doc_670731433467_item	2798917	et	3	main
c	doc_670731433467_item	2798918	et	4	main
kuid	doc_670731433467_item	2798919	et	4	main
d	doc_670731433467_item	2798920	et	4	main
c	doc_670731433467_item	2798927	et	4	main
eest	doc_670731433467_item	2798928	et	4	main
d	doc_670731433467_item	2798947	et	4	main
lihtne	doc_670731433467_item	2798948	et	3	main
käige	doc_670731433467_item	2798953	et	3	main
külastage	doc_670731433467_item	2798955	et	3	main
vastus	doc_670731433468_item	2798966	et	3	main
annab	doc_670731433468_item	2798967	et	3	main
ühe	doc_670731433468_item	2798968	et	4	main
punkti	doc_670731433468_item	2798969	et	4	main
maailmakuulsad	doc_670731433468_item	2798970	et	3	main
balletitantsijad	doc_670731433468_item	2798971	et	3	main
abielupaar	doc_670731433468_item	2798972	et	4	main
age	doc_670731433468_item	2798973	et	4	main
oks	doc_670731433468_item	2798974	et	3	main
ja	doc_670731433468_item	2798975	et	3	main
toomas	doc_670731433468_item	2798976	et	3	main
edur	doc_670731433468_item	2798977	et	4	main
on	doc_670731433468_item	2798978	et	4	main
pärit	doc_670731433468_item	2798979	et	3	main
eesti	doc_670731433468_item	2798980	et	4	main
eestist	doc_670731433468_item	2798981	et	3	main
aga	doc_670731433468_item	2798982	et	3	main
elavad	doc_670731433468_item	2798983	et	4	main
praegu	doc_670731433468_item	2798984	et	3	main
inglismaa	doc_670731433468_item	2798985	et	4	main
7	doc_670731433467_item	2798922	et	2	main
b	doc_670731433467_item	2798925	et	4	main
ette	doc_670731433467_item	2798926	et	4	main
a	doc_670731433467_item	2798941	et	4	main
liigne	doc_670731433467_item	2798942	et	3	main
libe	doc_670731433467_item	2798944	et	3	main
c	doc_670731433467_item	2798945	et	4	main
liikuv	doc_670731433467_item	2798946	et	4	main
tulge	doc_670731433467_item	2798951	et	3	main
d	doc_670731433467_item	2798956	et	4	main
minge	doc_670731433467_item	2798957	et	3	main
harjutus	doc_670731433468_item	2798958	et	4	main
avage	doc_670731433468_item	2798959	et	3	main
sulud	doc_670731433468_item	2798960	et	3	main
numbrid	doc_670731433468_item	2798961	et	3	main
kirjutage	doc_670731433468_item	2798962	et	3	main
london	doc_670731433468_item	2798986	et	4	main
inglismaa	doc_670731433468_item	2798987	et	4	main
on	doc_670731433468_item	2798996	et	4	main
kolmkümmend	doc_670731433468_item	2798998	et	4	main
kaks	doc_670731433468_item	2798999	et	3	main
aastat	doc_670731433468_item	2799000	et	3	main
vana	doc_670731433468_item	2799001	et	4	main
alates	doc_670731433468_item	2799002	et	3	main
ja	doc_670731433468_item	2799012	et	3	main
esinevad	doc_670731433468_item	2799013	et	4	main
nendesse	doc_670731433468_item	2799029	et	4	main
noored	doc_670731433468_item	2799035	et	3	main
alati	doc_670731433468_item	2799043	et	4	main
kergelt	doc_670731433468_item	2799045	et	4	main
läinud	doc_670731433468_item	2799046	et	4	main
mõlemal	doc_670731433468_item	2799047	et	3	main
probleeme	doc_670731433468_item	2799053	et	3	main
tervis	doc_670731433468_item	2799054	et	3	main
1990	doc_670731433468_item	2799056	et	2	main
järve	doc_670731433468_item	2799063	et	4	main
jalaluu	doc_670731433468_item	2799066	et	4	main
ja	doc_670731433468_item	2799067	et	3	main
nemad	doc_670731433468_item	2799087	et	3	main
neid	doc_670731433468_item	2799088	et	4	main
pakkumisi	doc_670731433468_item	2799091	et	4	main
vaatamata	doc_670731433468_item	2799095	et	4	main
age	doc_670731433468_item	2799109	et	4	main
ja	doc_670731433468_item	2799110	et	3	main
toomas	doc_670731433468_item	2799111	et	3	main
tahavad	doc_670731433468_item	2799112	et	3	main
areneda	doc_670731433468_item	2799113	et	3	main
ja	doc_670731433468_item	2799114	et	3	main
veelgi	doc_670731433468_item	2799115	et	4	main
esinema	doc_670731433468_item	2799122	et	3	main
tallinnasse	doc_670731433468_item	2799124	et	3	main
seejärel	doc_670731433468_item	2799126	et	3	main
lõuna-aafrika	doc_670731433468_item	2799128	et	4	main
kui	doc_670731433468_item	2799130	et	3	main
edur	doc_670731433468_item	2799134	et	4	main
tipus	doc_670731433468_item	2799136	et	3	main
püsida	doc_670731433468_item	2799138	et	3	main
ei	doc_670731433468_item	2799139	et	4	main
oska	doc_670731433468_item	2799140	et	4	main
nad	doc_670731433468_item	2799141	et	3	main
ütlema	doc_670731433468_item	2799142	et	3	main
elada	doc_670731433468_item	2799146	et	3	main
päev	doc_670731433468_item	2799148	et	3	main
päeva	doc_670731433468_item	2799150	et	4	main
kaupa	doc_670731433468_item	2799151	et	4	main
kirjutage	doc_670731433468_item	2799152	et	3	main
sõna	doc_670731433468_item	2799155	et	4	main
iga	doc_670731433468_item	2799158	et	4	main
unusta	doc_670731433468_item	2799168	et	4	main
umbne	doc_670731433468_item	2799169	et	3	main
klassiruum	doc_670731433468_item	2799170	et	3	main
koduõppesüsteem	doc_670731433468_item	2799171	et	3	main
võimaldab	doc_670731433468_item	2799172	et	3	main
sul	doc_670731433468_item	2799173	et	3	main
saada	doc_670731433468_item	2799174	et	4	main
saad	doc_670731433468_item	2799223	et	4	main
1997a	doc_670731433468_item	2799003	et	4	main
vabakutseline	doc_670731433468_item	2799010	et	4	main
vabakutselist	doc_670731433468_item	2799011	et	4	main
ning	doc_670731433468_item	2799023	et	3	main
artiklid	doc_670731433468_item	2799033	et	3	main
nii	doc_670731433468_item	2799044	et	3	main
naine	doc_670731433468_item	2799061	et	3	main
on	doc_670731433468_item	2799089	et	4	main
elavad	doc_670731433468_item	2799098	et	4	main
tantsijad	doc_670731433468_item	2799099	et	4	main
tagasihoidlik	doc_670731433468_item	2799100	et	3	main
esinemised	doc_670731433468_item	2799104	et	4	main
täpselt	doc_670731433468_item	2799106	et	4	main
tantsida	doc_670731433468_item	2799118	et	3	main
isegi	doc_670731433468_item	2799024	et	4	main
ülivõrdes	doc_670731433468_item	2799038	et	3	main
kõik	doc_670731433468_item	2799040	et	4	main
pole	doc_670731433468_item	2799041	et	3	main
sugugi	doc_670731433468_item	2799042	et	4	main
ja	doc_670731433468_item	2799048	et	3	main
on	doc_670731433468_item	2799051	et	4	main
murdma	doc_670731433468_item	2799058	et	3	main
noor	doc_670731433468_item	2799060	et	3	main
pidama	doc_670731433468_item	2799068	et	4	main
pidanud	doc_670731433468_item	2799069	et	4	main
mõnda	doc_670731433468_item	2799070	et	4	main
aega	doc_670731433468_item	2799071	et	4	main
tantsimisest	doc_670731433468_item	2799072	et	4	main
eemal	doc_670731433468_item	2799073	et	3	main
olema	doc_670731433468_item	2799074	et	4	main
on	doc_670731433468_item	2799075	et	4	main
age	doc_670731433468_item	2799076	et	4	main
ja	doc_670731433468_item	2799077	et	3	main
toomas	doc_670731433468_item	2799078	et	3	main
on	doc_670731433468_item	2799079	et	4	main
otsustanud	doc_670731433468_item	2799080	et	4	main
tantsima	doc_670731433468_item	2799081	et	3	main
tansima	doc_670731433468_item	2799082	et	4	main
ainult	doc_670731433468_item	2799083	et	4	main
teineteisega	doc_670731433468_item	2799084	et	3	main
paaris	doc_670731433468_item	2799085	et	4	main
kuigi	doc_670731433468_item	2799086	et	3	main
karmid	doc_670731433468_item	2799025	et	4	main
kriitikud	doc_670731433468_item	2799026	et	3	main
suhtuma	doc_670731433468_item	2799027	et	3	main
suheldud	doc_670731433468_item	2799028	et	4	main
räägivad	doc_670731433468_item	2799034	et	3	main
ainult	doc_670731433468_item	2799037	et	4	main
kuid	doc_670731433468_item	2799039	et	4	main
eriti	doc_670731433468_item	2799049	et	3	main
tehtud	doc_670731433468_item	2799090	et	4	main
tantsimiseks	doc_670731433468_item	2799094	et	4	main
suurele	doc_670731433468_item	2799096	et	4	main
edule	doc_670731433468_item	2799097	et	3	main
lähiaja	doc_670731433468_item	2799103	et	3	main
paremi	doc_670731433468_item	2799117	et	4	main
märtsis	doc_670731433468_item	2799119	et	3	main
ja	doc_670731433468_item	2799133	et	3	main
suudavad	doc_670731433468_item	2799137	et	3	main
alt	doc_670731433468_item	2799157	et	4	main
õige	doc_670731433468_item	2799159	et	4	main
vastus	doc_670731433468_item	2799160	et	3	main
annab	doc_670731433468_item	2799161	et	3	main
ühe	doc_670731433468_item	2799162	et	4	main
siiski	doc_670731433468_item	2799177	et	4	main
ja	doc_670731433468_item	2799180	et	3	main
parasjagu	doc_670731433468_item	2799184	et	3	main
raamatu	doc_670731433468_item	2799233	et	4	main
ja	doc_670731433468_item	2799234	et	3	main
6	doc_670731433468_item	2799236	et	2	main
saada	doc_670731433468_item	2799245	et	4	main
selle	doc_670731433468_item	2799252	et	4	main
üle	doc_670731433468_item	2799253	et	3	main
8	doc_670731433468_item	2799254	et	2	main
parandab	doc_670731433468_item	2799255	et	3	main
kõik	doc_670731433468_item	2799264	et	4	main
geniaalne	doc_670731433468_item	2799265	et	3	main
virtuaalkodu	doc_670731433468_item	2799272	et	4	main
sobid	doc_670731433468_item	2799278	et	4	main
b	doc_670731433468_item	2799288	et	4	main
b	doc_670731433468_item	2799297	et	4	main
a	doc_670731433468_item	2799304	et	4	main
tasemele	doc_670731433468_item	2799307	et	3	main
panna	doc_670731433468_item	2799324	et	4	main
a	doc_670731433468_item	2799326	et	4	main
vaid	doc_670731433468_item	2799329	et	3	main
kuid	doc_670731433468_item	2799331	et	4	main
eest	doc_670731433468_item	2799340	et	4	main
c	doc_670731433468_item	2799348	et	4	main
parandab	doc_670731433468_item	2799349	et	3	main
d	doc_670731433468_item	2799350	et	4	main
libe	doc_670731433468_item	2799356	et	3	main
d	doc_670731433468_item	2799359	et	4	main
a	doc_670731433468_item	2799362	et	4	main
tulge	doc_670731433468_item	2799363	et	3	main
balletitantsijad	doc_670731433469_item	2799383	et	3	main
eesti	doc_670731433469_item	2799392	et	4	main
eestis	doc_670731433469_item	2799393	et	3	main
aga	doc_670731433469_item	2799394	et	3	main
elavad	doc_670731433469_item	2799395	et	4	main
praegu	doc_670731433469_item	2799396	et	3	main
inglismaal	doc_670731433469_item	2799399	et	4	main
age	doc_670731433469_item	2799401	et	4	main
on	doc_670731433469_item	2799402	et	4	main
30	doc_670731433469_item	2799403	et	2	main
on	doc_670731433469_item	2799421	et	4	main
vabakutseline	doc_670731433469_item	2799423	et	4	main
vabakutselised	doc_670731433469_item	2799424	et	4	main
ja	doc_670731433469_item	2799425	et	3	main
esinevad	doc_670731433469_item	2799426	et	4	main
armastavakse	doc_670731433469_item	2799433	et	4	main
isegi	doc_670731433469_item	2799437	et	4	main
karmid	doc_670731433469_item	2799438	et	4	main
suhtuma	doc_670731433469_item	2799440	et	3	main
suhtuvad	doc_670731433469_item	2799441	et	4	main
kuid	doc_670731433469_item	2799452	et	4	main
noor	doc_670731433469_item	2799473	et	3	main
naine	doc_670731433469_item	2799474	et	3	main
on	doc_670731433469_item	2799502	et	4	main
vaatamata	doc_670731433469_item	2799508	et	4	main
on	doc_670731433469_item	2799518	et	4	main
tantsida	doc_670731433469_item	2799531	et	3	main
edur	doc_670731433469_item	2799547	et	4	main
elada	doc_670731433469_item	2799559	et	3	main
agel	doc_670731433468_item	2799050	et	4	main
olnud	doc_670731433468_item	2799052	et	4	main
tervisega	doc_670731433468_item	2799055	et	3	main
aastal	doc_670731433468_item	2799057	et	3	main
murdub	doc_670731433468_item	2799059	et	3	main
luikede	doc_670731433468_item	2799062	et	3	main
etendus	doc_670731433468_item	2799064	et	4	main
etendus	doc_670731433468_item	2799065	et	4	main
ka	doc_670731433468_item	2799092	et	3	main
parem	doc_670731433468_item	2799116	et	4	main
nad	doc_670731433468_item	2799121	et	3	main
tallinn	doc_670731433468_item	2799123	et	4	main
oks	doc_670731433468_item	2799132	et	3	main
nad	doc_670731433468_item	2799144	et	3	main
üks	doc_670731433468_item	2799147	et	3	main
punkti	doc_670731433468_item	2799163	et	4	main
on	doc_670731433468_item	2799187	et	4	main
registreerunud	doc_670731433468_item	2799222	et	4	main
meie	doc_670731433468_item	2799224	et	4	main
kontorist	doc_670731433468_item	2799225	et	4	main
kätte	doc_670731433468_item	2799231	et	4	main
õppematerjalid	doc_670731433468_item	2799232	et	3	main
kursuse	doc_670731433468_item	2799239	et	3	main
täidetud	doc_670731433468_item	2799246	et	4	main
kodutöö	doc_670731433468_item	2799247	et	4	main
ning	doc_670731433468_item	2799257	et	3	main
korral	doc_670731433468_item	2799260	et	4	main
tekkinud	doc_670731433468_item	2799262	et	4	main
lisaküsimustele	doc_670731433468_item	2799263	et	4	main
külaslage	doc_670731433468_item	2799270	et	3	main
või	doc_670731433468_item	2799273	et	4	main
a	doc_670731433468_item	2799277	et	4	main
b	doc_670731433468_item	2799279	et	4	main
soovid	doc_670731433468_item	2799280	et	4	main
a	doc_670731433468_item	2799286	et	4	main
seega	doc_670731433468_item	2799289	et	4	main
kuigi	doc_670731433468_item	2799291	et	3	main
d	doc_670731433468_item	2799292	et	4	main
b	doc_670731433468_item	2799306	et	4	main
eraldi	doc_670731433468_item	2799093	et	4	main
tagasihoidlikus	doc_670731433468_item	2799101	et	4	main
nende	doc_670731433468_item	2799102	et	4	main
on	doc_670731433468_item	2799105	et	4	main
planeerima	doc_670731433468_item	2799107	et	3	main
planeerima	doc_670731433468_item	2799108	et	3	main
tulevad	doc_670731433468_item	2799120	et	4	main
kaua	doc_670731433468_item	2799131	et	3	main
veel	doc_670731433468_item	2799135	et	4	main
eelistavad	doc_670731433468_item	2799145	et	4	main
ühe	doc_670731433468_item	2799149	et	4	main
sobiv	doc_670731433468_item	2799154	et	4	main
õpi	doc_670731433468_item	2799164	et	4	main
millal	doc_670731433468_item	2799165	et	3	main
1	doc_670731433468_item	2799166	et	2	main
soovid	doc_670731433468_item	2799167	et	4	main
2	doc_670731433468_item	2799176	et	2	main
seal	doc_670731433468_item	2799178	et	4	main
millal	doc_670731433468_item	2799181	et	3	main
seda	doc_670731433468_item	2799183	et	3	main
või	doc_670731433468_item	2799226	et	4	main
lähimast	doc_670731433468_item	2799227	et	4	main
postiasutusest	doc_670731433468_item	2799228	et	4	main
helikasseti	doc_670731433468_item	2799235	et	4	main
ning	doc_670731433468_item	2799237	et	3	main
eest	doc_670731433468_item	2799241	et	4	main
kättesaamisel	doc_670731433468_item	2799244	et	4	main
õpetaja	doc_670731433468_item	2799250	et	4	main
vaatab	doc_670731433468_item	2799251	et	3	main
vajaduse	doc_670731433468_item	2799259	et	3	main
on	doc_670731433468_item	2799266	et	4	main
10	doc_670731433468_item	2799269	et	2	main
meie	doc_670731433468_item	2799271	et	4	main
1	doc_670731433468_item	2799276	et	2	main
just	doc_670731433468_item	2799287	et	3	main
c	doc_670731433468_item	2799290	et	4	main
siiski	doc_670731433468_item	2799293	et	4	main
3	doc_670731433468_item	2799294	et	2	main
d	doc_670731433468_item	2799301	et	4	main
hoida	doc_670731433468_item	2799321	et	3	main
c	doc_670731433468_item	2799330	et	4	main
d	doc_670731433468_item	2799332	et	4	main
et	doc_670731433468_item	2799333	et	3	main
c	doc_670731433468_item	2799339	et	4	main
a	doc_670731433468_item	2799344	et	4	main
kirjutab	doc_670731433468_item	2799345	et	3	main
b	doc_670731433468_item	2799346	et	4	main
palub	doc_670731433468_item	2799347	et	3	main
b	doc_670731433468_item	2799364	et	4	main
kolmekümne	doc_670731433469_item	2799404	et	4	main
1997a	doc_670731433469_item	2799415	et	4	main
tuhande	doc_670731433469_item	2799416	et	3	main
neid	doc_670731433469_item	2799434	et	4	main
ning	doc_670731433469_item	2799436	et	3	main
ainult	doc_670731433469_item	2799450	et	4	main
agel	doc_670731433469_item	2799463	et	4	main
murdis	doc_670731433469_item	2799472	et	3	main
etendus	doc_670731433469_item	2799477	et	4	main
ja	doc_670731433469_item	2799480	et	3	main
pidi	doc_670731433469_item	2799482	et	4	main
mõnda	doc_670731433469_item	2799483	et	4	main
otsustanud	doc_670731433469_item	2799493	et	4	main
ainult	doc_670731433469_item	2799496	et	4	main
suurele	doc_670731433469_item	2799509	et	4	main
täpselt	doc_670731433469_item	2799519	et	4	main
ja	doc_670731433468_item	2799125	et	3	main
sõidavad	doc_670731433468_item	2799127	et	3	main
lõuna-aafrikasse	doc_670731433468_item	2799129	et	4	main
ütlevad	doc_670731433468_item	2799143	et	4	main
lünka	doc_670731433468_item	2799153	et	4	main
teksti	doc_670731433468_item	2799156	et	4	main
targemaks	doc_670731433468_item	2799175	et	4	main
kus	doc_670731433468_item	2799179	et	3	main
sa	doc_670731433468_item	2799182	et	3	main
soovid	doc_670731433468_item	2799185	et	4	main
käes	doc_670731433468_item	2799186	et	4	main
interaktiivse	doc_670731433468_item	2799188	et	3	main
õppe	doc_670731433468_item	2799189	et	4	main
ajastu	doc_670731433468_item	2799190	et	4	main
mis	doc_670731433468_item	2799191	et	4	main
annab	doc_670731433468_item	2799192	et	3	main
sulle	doc_670731433468_item	2799193	et	3	main
3	doc_670731433468_item	2799194	et	2	main
vabaduse	doc_670731433468_item	2799195	et	4	main
planeerida	doc_670731433468_item	2799196	et	3	main
aega	doc_670731433468_item	2799197	et	4	main
ning	doc_670731433468_item	2799198	et	3	main
eelise	doc_670731433468_item	2799199	et	4	main
omandada	doc_670731433468_item	2799200	et	3	main
teadmisi	doc_670731433468_item	2799201	et	4	main
vastavalt	doc_670731433468_item	2799202	et	4	main
individuaalsele	doc_670731433468_item	2799203	et	3	main
4	doc_670731433468_item	2799204	et	2	main
tasemele	doc_670731433468_item	2799205	et	3	main
aeg	doc_670731433468_item	2799206	et	3	main
on	doc_670731433468_item	2799207	et	4	main
raha	doc_670731433468_item	2799208	et	4	main
et	doc_670731433468_item	2799209	et	3	main
seda	doc_670731433468_item	2799210	et	3	main
5	doc_670731433468_item	2799211	et	2	main
kokku	doc_670731433468_item	2799212	et	3	main
saada	doc_670731433468_item	2799213	et	4	main
on	doc_670731433468_item	2799214	et	4	main
vaja	doc_670731433468_item	2799215	et	4	main
ka	doc_670731433468_item	2799216	et	3	main
pisut	doc_670731433468_item	2799217	et	3	main
tarkust	doc_670731433468_item	2799218	et	4	main
kui	doc_670731433468_item	2799219	et	3	main
oled	doc_670731433468_item	2799220	et	3	main
7	doc_670731433468_item	2799240	et	2	main
vead	doc_670731433468_item	2799256	et	4	main
9	doc_670731433468_item	2799267	et	2	main
kupong	doc_670731433468_item	2799275	et	3	main
c	doc_670731433468_item	2799281	et	4	main
kursusele	doc_670731433468_item	2799221	et	3	main
igal	doc_670731433468_item	2799229	et	3	main
kuul	doc_670731433468_item	2799230	et	4	main
kodutöö	doc_670731433468_item	2799238	et	4	main
tasud	doc_670731433468_item	2799242	et	4	main
selle	doc_670731433468_item	2799243	et	4	main
meile	doc_670731433468_item	2799248	et	4	main
tagasi	doc_670731433468_item	2799249	et	3	main
vastab	doc_670731433468_item	2799258	et	3	main
ka	doc_670731433468_item	2799261	et	3	main
lihtne	doc_670731433468_item	2799268	et	3	main
postitage	doc_670731433468_item	2799274	et	3	main
2	doc_670731433468_item	2799285	et	2	main
vajaduse	doc_670731433468_item	2799296	et	3	main
vabanduse	doc_670731433468_item	2799298	et	4	main
c	doc_670731433468_item	2799299	et	4	main
varanduse	doc_670731433468_item	2799300	et	3	main
tasule	doc_670731433468_item	2799305	et	3	main
c	doc_670731433468_item	2799308	et	4	main
tasakesi	doc_670731433468_item	2799309	et	3	main
d	doc_670731433468_item	2799310	et	4	main
tasakaalule	doc_670731433468_item	2799311	et	3	main
5	doc_670731433468_item	2799312	et	2	main
a	doc_670731433468_item	2799313	et	4	main
kokku	doc_670731433468_item	2799314	et	3	main
saada	doc_670731433468_item	2799315	et	4	main
b	doc_670731433468_item	2799316	et	4	main
kokku	doc_670731433468_item	2799317	et	3	main
liita	doc_670731433468_item	2799318	et	4	main
c	doc_670731433468_item	2799319	et	4	main
kokku	doc_670731433468_item	2799320	et	3	main
kokku	doc_670731433468_item	2799323	et	3	main
7	doc_670731433468_item	2799334	et	2	main
a	doc_670731433468_item	2799335	et	4	main
taga	doc_670731433468_item	2799336	et	4	main
d	doc_670731433468_item	2799341	et	4	main
a	doc_670731433468_item	2799353	et	4	main
liigne	doc_670731433468_item	2799354	et	3	main
abielupaar	doc_670731433469_item	2799384	et	4	main
age	doc_670731433469_item	2799385	et	4	main
oks	doc_670731433469_item	2799386	et	3	main
ja	doc_670731433469_item	2799387	et	3	main
inglismaa	doc_670731433469_item	2799397	et	4	main
londonis	doc_670731433469_item	2799400	et	4	main
on	doc_670731433469_item	2799408	et	4	main
üheksasaja	doc_670731433469_item	2799417	et	4	main
seitsmest	doc_670731433469_item	2799419	et	4	main
aastast	doc_670731433469_item	2799420	et	4	main
soovitad	doc_670731433468_item	2799282	et	3	main
d	doc_670731433468_item	2799283	et	4	main
solvud	doc_670731433468_item	2799284	et	3	main
a	doc_670731433468_item	2799295	et	4	main
vabaduse	doc_670731433468_item	2799302	et	4	main
4	doc_670731433468_item	2799303	et	2	main
d	doc_670731433468_item	2799322	et	4	main
ette	doc_670731433468_item	2799338	et	4	main
muudab	doc_670731433468_item	2799351	et	3	main
c	doc_670731433468_item	2799357	et	4	main
liikuv	doc_670731433468_item	2799358	et	4	main
lihtne	doc_670731433468_item	2799360	et	3	main
10	doc_670731433468_item	2799361	et	2	main
toomas	doc_670731433469_item	2799388	et	3	main
edur	doc_670731433469_item	2799389	et	4	main
aastane	doc_670731433469_item	2799405	et	4	main
ja	doc_670731433469_item	2799406	et	3	main
toomas	doc_670731433469_item	2799407	et	3	main
erinevad	doc_670731433469_item	2799427	et	4	main
teatrid	doc_670731433469_item	2799428	et	3	main
erinevaid	doc_670731433469_item	2799429	et	4	main
teadreid	doc_670731433469_item	2799430	et	4	main
väga	doc_670731433469_item	2799435	et	3	main
ülivõrdes	doc_670731433469_item	2799451	et	3	main
pole	doc_670731433469_item	2799454	et	3	main
alati	doc_670731433469_item	2799456	et	4	main
on	doc_670731433469_item	2799464	et	4	main
1990	doc_670731433469_item	2799469	et	2	main
järve	doc_670731433469_item	2799476	et	4	main
jalaluu	doc_670731433469_item	2799479	et	4	main
pidama	doc_670731433469_item	2799481	et	4	main
eemal	doc_670731433469_item	2799486	et	3	main
olla	doc_670731433469_item	2799488	et	3	main
tantsima	doc_670731433469_item	2799494	et	3	main
tehtud	doc_670731433469_item	2799503	et	4	main
pakkumisi	doc_670731433469_item	2799504	et	4	main
edule	doc_670731433469_item	2799510	et	3	main
tagasihoidlikult	doc_670731433469_item	2799514	et	4	main
planeerimata	doc_670731433469_item	2799521	et	4	main
ja	doc_670731433469_item	2799523	et	3	main
ja	doc_670731433469_item	2799527	et	3	main
märtsis	doc_670731433469_item	2799532	et	3	main
esinema	doc_670731433469_item	2799535	et	3	main
seejärel	doc_670731433469_item	2799539	et	3	main
suudavad	doc_670731433469_item	2799550	et	3	main
päeva	doc_670731433469_item	2799563	et	4	main
kaupa	doc_670731433469_item	2799564	et	4	main
alt	doc_670731433469_item	2799570	et	4	main
õige	doc_670731433469_item	2799572	et	4	main
annab	doc_670731433469_item	2799574	et	3	main
punkti	doc_670731433469_item	2799576	et	4	main
umbne	doc_670731433469_item	2799582	et	3	main
võimaldab	doc_670731433469_item	2799585	et	3	main
kuigi	doc_670731433469_item	2799590	et	3	main
kus	doc_670731433469_item	2799592	et	3	main
ja	doc_670731433469_item	2799593	et	3	main
millal	doc_670731433469_item	2799594	et	3	main
soovid	doc_670731433469_item	2799598	et	4	main
on	doc_670731433469_item	2799600	et	4	main
interaktiivse	doc_670731433469_item	2799601	et	3	main
vastavalt	doc_670731433469_item	2799615	et	4	main
6	doc_670731433468_item	2799325	et	2	main
ning	doc_670731433468_item	2799327	et	3	main
b	doc_670731433468_item	2799328	et	4	main
b	doc_670731433468_item	2799337	et	4	main
ees	doc_670731433468_item	2799342	et	4	main
8	doc_670731433468_item	2799343	et	2	main
9	doc_670731433468_item	2799352	et	2	main
b	doc_670731433468_item	2799355	et	4	main
käige	doc_670731433468_item	2799365	et	3	main
c	doc_670731433468_item	2799366	et	4	main
külastage	doc_670731433468_item	2799367	et	3	main
d	doc_670731433468_item	2799368	et	4	main
minge	doc_670731433468_item	2799369	et	3	main
harjutus	doc_670731433469_item	2799370	et	4	main
avage	doc_670731433469_item	2799371	et	3	main
sulud	doc_670731433469_item	2799372	et	3	main
numbrid	doc_670731433469_item	2799373	et	3	main
kirjutage	doc_670731433469_item	2799374	et	3	main
sõnadega	doc_670731433469_item	2799375	et	3	main
iga	doc_670731433469_item	2799376	et	4	main
õige	doc_670731433469_item	2799377	et	4	main
vastus	doc_670731433469_item	2799378	et	3	main
annab	doc_670731433469_item	2799379	et	3	main
ühe	doc_670731433469_item	2799380	et	4	main
punkti	doc_670731433469_item	2799381	et	4	main
maailmakuulsad	doc_670731433469_item	2799382	et	3	main
on	doc_670731433469_item	2799390	et	4	main
pärit	doc_670731433469_item	2799391	et	3	main
london	doc_670731433469_item	2799398	et	4	main
32	doc_670731433469_item	2799409	et	2	main
kolmkümend	doc_670731433469_item	2799410	et	4	main
kaks	doc_670731433469_item	2799411	et	3	main
aastat	doc_670731433469_item	2799412	et	3	main
vana	doc_670731433469_item	2799413	et	4	main
alates	doc_670731433469_item	2799414	et	3	main
üheksakümne	doc_670731433469_item	2799418	et	4	main
kergelt	doc_670731433469_item	2799458	et	4	main
läinud	doc_670731433469_item	2799459	et	4	main
mõlemal	doc_670731433469_item	2799460	et	3	main
ja	doc_670731433469_item	2799461	et	3	main
eriti	doc_670731433469_item	2799462	et	3	main
murdma	doc_670731433469_item	2799471	et	3	main
etendusel	doc_670731433469_item	2799478	et	4	main
tantsimisest	doc_670731433469_item	2799485	et	4	main
olema	doc_670731433469_item	2799487	et	4	main
age	doc_670731433469_item	2799489	et	4	main
ja	doc_670731433469_item	2799490	et	3	main
toomas	doc_670731433469_item	2799491	et	3	main
paaris	doc_670731433469_item	2799498	et	4	main
kuigi	doc_670731433469_item	2799499	et	3	main
nemad	doc_670731433469_item	2799500	et	3	main
nendele	doc_670731433469_item	2799501	et	4	main
tantsimiseks	doc_670731433469_item	2799507	et	4	main
elavad	doc_670731433469_item	2799511	et	4	main
tagasihoidlik	doc_670731433469_item	2799513	et	3	main
nende	doc_670731433469_item	2799515	et	4	main
lähiaja	doc_670731433469_item	2799516	et	3	main
esinemised	doc_670731433469_item	2799517	et	4	main
age	doc_670731433469_item	2799522	et	4	main
tahavad	doc_670731433469_item	2799525	et	3	main
nad	doc_670731433469_item	2799534	et	3	main
veel	doc_670731433469_item	2799548	et	4	main
ei	doc_670731433469_item	2799552	et	4	main
nad	doc_670731433469_item	2799554	et	3	main
sõna	doc_670731433469_item	2799568	et	4	main
unusta	doc_670731433469_item	2799581	et	4	main
koduõppesüsteem	doc_670731433469_item	2799584	et	3	main
targemaks	doc_670731433469_item	2799588	et	4	main
mis	doc_670731433469_item	2799604	et	4	main
annab	doc_670731433469_item	2799605	et	3	main
sulle	doc_670731433469_item	2799606	et	3	main
3	doc_670731433469_item	2799607	et	2	main
tasemele	doc_670731433469_item	2799618	et	3	main
aeg	doc_670731433469_item	2799619	et	3	main
on	doc_670731433469_item	2799627	et	4	main
tarkust	doc_670731433469_item	2799631	et	4	main
kursusele	doc_670731433469_item	2799634	et	3	main
kätte	doc_670731433469_item	2799644	et	4	main
kättesaamisel	doc_670731433469_item	2799657	et	4	main
meile	doc_670731433469_item	2799661	et	4	main
vaatab	doc_670731433469_item	2799664	et	3	main
8	doc_670731433469_item	2799667	et	2	main
ning	doc_670731433469_item	2799670	et	3	main
vajaduse	doc_670731433469_item	2799672	et	3	main
lihtne	doc_670731433469_item	2799681	et	3	main
1	doc_670731433469_item	2799689	et	2	main
sobid	doc_670731433469_item	2799691	et	4	main
soovid	doc_670731433469_item	2799693	et	4	main
b	doc_670731433469_item	2799701	et	4	main
seega	doc_670731433469_item	2799702	et	4	main
siiski	doc_670731433469_item	2799706	et	4	main
vajaduse	doc_670731433469_item	2799709	et	3	main
vabanduse	doc_670731433469_item	2799711	et	4	main
c	doc_670731433469_item	2799712	et	4	main
varanduse	doc_670731433469_item	2799713	et	3	main
d	doc_670731433469_item	2799714	et	4	main
c	doc_670731433469_item	2799721	et	4	main
c	doc_670731433469_item	2799732	et	4	main
c	doc_670731433469_item	2799743	et	4	main
taga	doc_670731433469_item	2799749	et	4	main
9	doc_670731433469_item	2799765	et	2	main
sõnadega	doc_670731433470_item	2799788	et	3	main
age	doc_670731433470_item	2799798	et	4	main
oks	doc_670731433470_item	2799799	et	3	main
ja	doc_670731433470_item	2799800	et	3	main
aga	doc_670731433470_item	2799807	et	3	main
londonis	doc_670731433470_item	2799813	et	4	main
on	doc_670731433470_item	2799815	et	4	main
nad	doc_670731433469_item	2799422	et	3	main
inglismaal	doc_670731433469_item	2799431	et	4	main
armastama	doc_670731433469_item	2799432	et	3	main
kriitikud	doc_670731433469_item	2799439	et	3	main
nendesse	doc_670731433469_item	2799442	et	4	main
üldiselt	doc_670731433469_item	2799443	et	4	main
hästi	doc_670731433469_item	2799444	et	3	main
viimased	doc_670731433469_item	2799445	et	3	main
artiklid	doc_670731433469_item	2799446	et	3	main
räägivad	doc_670731433469_item	2799447	et	3	main
noored	doc_670731433469_item	2799448	et	3	main
noorele	doc_670731433469_item	2799449	et	3	main
kõik	doc_670731433469_item	2799453	et	4	main
sugugi	doc_670731433469_item	2799455	et	4	main
nii	doc_670731433469_item	2799457	et	3	main
olnud	doc_670731433469_item	2799465	et	4	main
probleeme	doc_670731433469_item	2799466	et	3	main
tervis	doc_670731433469_item	2799467	et	3	main
tervisega	doc_670731433469_item	2799468	et	3	main
aastal	doc_670731433469_item	2799470	et	3	main
luikede	doc_670731433469_item	2799475	et	3	main
aega	doc_670731433469_item	2799484	et	4	main
on	doc_670731433469_item	2799492	et	4	main
tantsida	doc_670731433469_item	2799495	et	3	main
teineteisega	doc_670731433469_item	2799497	et	3	main
ka	doc_670731433469_item	2799505	et	3	main
eraldi	doc_670731433469_item	2799506	et	4	main
tantsijad	doc_670731433469_item	2799512	et	4	main
planeerima	doc_670731433469_item	2799520	et	3	main
paremini	doc_670731433469_item	2799530	et	4	main
tallinnas	doc_670731433469_item	2799537	et	4	main
sõidavad	doc_670731433469_item	2799540	et	3	main
lõuna-aafrika	doc_670731433469_item	2799541	et	4	main
lõuna-aafrikasse	doc_670731433469_item	2799542	et	4	main
kui	doc_670731433469_item	2799543	et	3	main
kaua	doc_670731433469_item	2799544	et	3	main
oks	doc_670731433469_item	2799545	et	3	main
ja	doc_670731433469_item	2799546	et	3	main
püsida	doc_670731433469_item	2799551	et	3	main
oska	doc_670731433469_item	2799553	et	4	main
ütlema	doc_670731433469_item	2799555	et	3	main
nad	doc_670731433469_item	2799557	et	3	main
kirjutage	doc_670731433469_item	2799565	et	3	main
lünka	doc_670731433469_item	2799566	et	4	main
teksti	doc_670731433469_item	2799569	et	4	main
klassiruum	doc_670731433469_item	2799583	et	3	main
sul	doc_670731433469_item	2799586	et	3	main
2	doc_670731433469_item	2799589	et	2	main
sa	doc_670731433469_item	2799595	et	3	main
vabaduse	doc_670731433469_item	2799608	et	4	main
planeerida	doc_670731433469_item	2799609	et	3	main
aega	doc_670731433469_item	2799610	et	4	main
individuaalsele	doc_670731433469_item	2799616	et	3	main
raha	doc_670731433469_item	2799621	et	4	main
5	doc_670731433469_item	2799624	et	2	main
ka	doc_670731433469_item	2799629	et	3	main
kontorist	doc_670731433469_item	2799638	et	4	main
helikasseti	doc_670731433469_item	2799648	et	4	main
ning	doc_670731433469_item	2799650	et	3	main
7	doc_670731433469_item	2799653	et	2	main
saada	doc_670731433469_item	2799658	et	4	main
tagasi	doc_670731433469_item	2799662	et	3	main
selle	doc_670731433469_item	2799665	et	4	main
üle	doc_670731433469_item	2799666	et	3	main
parandab	doc_670731433469_item	2799668	et	3	main
vastab	doc_670731433469_item	2799671	et	3	main
korral	doc_670731433469_item	2799673	et	4	main
ka	doc_670731433469_item	2799674	et	3	main
virtuaalkodu	doc_670731433469_item	2799685	et	4	main
või	doc_670731433469_item	2799686	et	4	main
a	doc_670731433469_item	2799690	et	4	main
b	doc_670731433469_item	2799692	et	4	main
solvud	doc_670731433469_item	2799697	et	3	main
a	doc_670731433469_item	2799699	et	4	main
just	doc_670731433469_item	2799700	et	3	main
d	doc_670731433469_item	2799705	et	4	main
vabaduse	doc_670731433469_item	2799715	et	4	main
tasakaalule	doc_670731433469_item	2799724	et	3	main
kuid	doc_670731433469_item	2799744	et	4	main
ette	doc_670731433469_item	2799751	et	4	main
eest	doc_670731433469_item	2799753	et	4	main
ees	doc_670731433469_item	2799755	et	4	main
parandab	doc_670731433469_item	2799762	et	3	main
d	doc_670731433469_item	2799763	et	4	main
muudab	doc_670731433469_item	2799764	et	3	main
toomas	doc_670731433469_item	2799524	et	3	main
areneda	doc_670731433469_item	2799526	et	3	main
veelgi	doc_670731433469_item	2799528	et	4	main
parem	doc_670731433469_item	2799529	et	4	main
tulevad	doc_670731433469_item	2799533	et	4	main
tallinn	doc_670731433469_item	2799536	et	4	main
ja	doc_670731433469_item	2799538	et	3	main
tipus	doc_670731433469_item	2799549	et	3	main
öelda	doc_670731433469_item	2799556	et	4	main
eelistavad	doc_670731433469_item	2799558	et	4	main
sobiv	doc_670731433469_item	2799567	et	4	main
soovid	doc_670731433469_item	2799580	et	4	main
saada	doc_670731433469_item	2799587	et	4	main
seal	doc_670731433469_item	2799591	et	4	main
seda	doc_670731433469_item	2799596	et	3	main
õppe	doc_670731433469_item	2799602	et	4	main
ajastu	doc_670731433469_item	2799603	et	4	main
ning	doc_670731433469_item	2799611	et	3	main
4	doc_670731433469_item	2799617	et	2	main
on	doc_670731433469_item	2799620	et	4	main
et	doc_670731433469_item	2799622	et	3	main
seda	doc_670731433469_item	2799623	et	3	main
kokku	doc_670731433469_item	2799625	et	3	main
meie	doc_670731433469_item	2799637	et	4	main
kuul	doc_670731433469_item	2799643	et	4	main
raamatu	doc_670731433469_item	2799646	et	4	main
selle	doc_670731433469_item	2799656	et	4	main
c	doc_670731433469_item	2799694	et	4	main
soovitad	doc_670731433469_item	2799695	et	3	main
c	doc_670731433469_item	2799703	et	4	main
kuigi	doc_670731433469_item	2799704	et	3	main
3	doc_670731433469_item	2799707	et	2	main
4	doc_670731433469_item	2799716	et	2	main
a	doc_670731433469_item	2799717	et	4	main
tasule	doc_670731433469_item	2799718	et	3	main
b	doc_670731433469_item	2799719	et	4	main
üks	doc_670731433469_item	2799560	et	3	main
päev	doc_670731433469_item	2799561	et	3	main
ühe	doc_670731433469_item	2799562	et	4	main
iga	doc_670731433469_item	2799571	et	4	main
vastus	doc_670731433469_item	2799573	et	3	main
ühe	doc_670731433469_item	2799575	et	4	main
õpi	doc_670731433469_item	2799577	et	4	main
millal	doc_670731433469_item	2799578	et	3	main
1	doc_670731433469_item	2799579	et	2	main
parasjagu	doc_670731433469_item	2799597	et	3	main
käes	doc_670731433469_item	2799599	et	4	main
eelise	doc_670731433469_item	2799612	et	4	main
omandada	doc_670731433469_item	2799613	et	3	main
teadmisi	doc_670731433469_item	2799614	et	4	main
saada	doc_670731433469_item	2799626	et	4	main
vaja	doc_670731433469_item	2799628	et	4	main
pisut	doc_670731433469_item	2799630	et	3	main
oled	doc_670731433469_item	2799633	et	3	main
või	doc_670731433469_item	2799639	et	4	main
õppematerjalid	doc_670731433469_item	2799645	et	3	main
ja	doc_670731433469_item	2799647	et	3	main
6	doc_670731433469_item	2799649	et	2	main
kodutöö	doc_670731433469_item	2799660	et	4	main
õpetaja	doc_670731433469_item	2799663	et	4	main
tekkinud	doc_670731433469_item	2799675	et	4	main
lisaküsimustele	doc_670731433469_item	2799676	et	4	main
kõik	doc_670731433469_item	2799677	et	4	main
geniaalne	doc_670731433469_item	2799678	et	3	main
postitage	doc_670731433469_item	2799687	et	3	main
2	doc_670731433469_item	2799698	et	2	main
a	doc_670731433469_item	2799708	et	4	main
b	doc_670731433469_item	2799710	et	4	main
tasemele	doc_670731433469_item	2799720	et	3	main
tasakesi	doc_670731433469_item	2799722	et	3	main
kokku	doc_670731433469_item	2799727	et	3	main
b	doc_670731433469_item	2799729	et	4	main
liita	doc_670731433469_item	2799731	et	4	main
a	doc_670731433469_item	2799739	et	4	main
c	doc_670731433469_item	2799752	et	4	main
d	doc_670731433469_item	2799754	et	4	main
8	doc_670731433469_item	2799756	et	2	main
a	doc_670731433469_item	2799757	et	4	main
kirjutab	doc_670731433469_item	2799758	et	3	main
iga	doc_670731433470_item	2799789	et	4	main
annab	doc_670731433470_item	2799792	et	3	main
praegu	doc_670731433470_item	2799809	et	3	main
london	doc_670731433470_item	2799811	et	4	main
on	doc_670731433470_item	2799821	et	4	main
aastat	doc_670731433470_item	2799824	et	3	main
alates	doc_670731433470_item	2799826	et	3	main
1997a	doc_670731433470_item	2799827	et	4	main
tuhande	doc_670731433470_item	2799828	et	3	main
esinevad	doc_670731433470_item	2799838	et	4	main
inglismaal	doc_670731433470_item	2799843	et	4	main
neid	doc_670731433470_item	2799846	et	4	main
ning	doc_670731433470_item	2799848	et	3	main
kuid	doc_670731433470_item	2799864	et	4	main
alati	doc_670731433470_item	2799868	et	4	main
läinud	doc_670731433470_item	2799871	et	4	main
suurele	doc_670731433470_item	2799921	et	4	main
elavad	doc_670731433470_item	2799923	et	4	main
tagasihoidlik	doc_670731433470_item	2799925	et	3	main
tagasihoidlikult	doc_670731433470_item	2799926	et	4	main
on	doc_670731433470_item	2799930	et	4	main
sõidavad	doc_670731433470_item	2799952	et	3	main
lõuna-afrikast	doc_670731433470_item	2799954	et	4	main
ja	doc_670731433470_item	2799958	et	3	main
oska	doc_670731433470_item	2799965	et	4	main
elada	doc_670731433470_item	2799971	et	3	main
ühe	doc_670731433470_item	2799974	et	4	main
päeva	doc_670731433470_item	2799975	et	4	main
teksti	doc_670731433470_item	2799981	et	4	main
1	doc_670731433470_item	2799991	et	2	main
klassiruum	doc_670731433470_item	2799995	et	3	main
võimaldab	doc_670731433470_item	2799997	et	3	main
saada	doc_670731433470_item	2799999	et	4	main
2	doc_670731433470_item	2800001	et	2	main
just	doc_670731433470_item	2800002	et	3	main
seal	doc_670731433470_item	2800003	et	4	main
millal	doc_670731433470_item	2800006	et	3	main
eelise	doc_670731433470_item	2800024	et	4	main
aeg	doc_670731433470_item	2800031	et	3	main
kui	doc_670731433469_item	2799632	et	3	main
registreerunud	doc_670731433469_item	2799635	et	4	main
saad	doc_670731433469_item	2799636	et	4	main
lähimast	doc_670731433469_item	2799640	et	4	main
postiasutusest	doc_670731433469_item	2799641	et	4	main
igal	doc_670731433469_item	2799642	et	3	main
kodutöö	doc_670731433469_item	2799651	et	4	main
kursuse	doc_670731433469_item	2799652	et	3	main
eest	doc_670731433469_item	2799654	et	4	main
tasud	doc_670731433469_item	2799655	et	4	main
täidetud	doc_670731433469_item	2799659	et	4	main
vead	doc_670731433469_item	2799669	et	4	main
on	doc_670731433469_item	2799679	et	4	main
9	doc_670731433469_item	2799680	et	2	main
10	doc_670731433469_item	2799682	et	2	main
külastage	doc_670731433469_item	2799683	et	3	main
meie	doc_670731433469_item	2799684	et	4	main
kupong	doc_670731433469_item	2799688	et	3	main
d	doc_670731433469_item	2799696	et	4	main
d	doc_670731433469_item	2799723	et	4	main
a	doc_670731433469_item	2799726	et	4	main
saada	doc_670731433469_item	2799728	et	4	main
kokku	doc_670731433469_item	2799730	et	3	main
d	doc_670731433469_item	2799735	et	4	main
kokku	doc_670731433469_item	2799736	et	3	main
panna	doc_670731433469_item	2799737	et	4	main
d	doc_670731433469_item	2799745	et	4	main
et	doc_670731433469_item	2799746	et	3	main
7	doc_670731433469_item	2799747	et	2	main
b	doc_670731433469_item	2799750	et	4	main
b	doc_670731433469_item	2799759	et	4	main
palub	doc_670731433469_item	2799760	et	3	main
c	doc_670731433469_item	2799761	et	4	main
kirjutage	doc_670731433470_item	2799787	et	3	main
õige	doc_670731433470_item	2799790	et	4	main
ühe	doc_670731433470_item	2799793	et	4	main
punkti	doc_670731433470_item	2799794	et	4	main
maailmakuulsad	doc_670731433470_item	2799795	et	3	main
balletitantsijad	doc_670731433470_item	2799796	et	3	main
pärit	doc_670731433470_item	2799804	et	3	main
eestist	doc_670731433470_item	2799806	et	3	main
aastane	doc_670731433470_item	2799818	et	4	main
ja	doc_670731433470_item	2799819	et	3	main
toomas	doc_670731433470_item	2799820	et	3	main
üheksasaja	doc_670731433470_item	2799829	et	4	main
erinevad	doc_670731433470_item	2799839	et	4	main
armastama	doc_670731433470_item	2799844	et	3	main
väga	doc_670731433470_item	2799847	et	3	main
isegi	doc_670731433470_item	2799849	et	4	main
karmid	doc_670731433470_item	2799850	et	4	main
kriitikud	doc_670731433470_item	2799851	et	3	main
nendesse	doc_670731433470_item	2799854	et	4	main
viimased	doc_670731433470_item	2799857	et	3	main
artiklid	doc_670731433470_item	2799858	et	3	main
räägivad	doc_670731433470_item	2799859	et	3	main
noored	doc_670731433470_item	2799860	et	3	main
nooreid	doc_670731433470_item	2799861	et	4	main
sugugi	doc_670731433470_item	2799867	et	4	main
kergelt	doc_670731433470_item	2799870	et	4	main
järve	doc_670731433470_item	2799888	et	4	main
tantsijad	doc_670731433470_item	2799924	et	4	main
täpselt	doc_670731433470_item	2799931	et	4	main
planeerima	doc_670731433470_item	2799932	et	3	main
rohkem	doc_670731433470_item	2799942	et	4	main
tantsida	doc_670731433470_item	2799943	et	3	main
märtsis	doc_670731433470_item	2799944	et	3	main
tulevad	doc_670731433470_item	2799945	et	4	main
nad	doc_670731433470_item	2799946	et	3	main
esinema	doc_670731433470_item	2799947	et	3	main
tallinnas	doc_670731433470_item	2799949	et	4	main
seejärel	doc_670731433470_item	2799951	et	3	main
ei	doc_670731433470_item	2799964	et	4	main
kaupa	doc_670731433470_item	2799976	et	4	main
kirjutage	doc_670731433470_item	2799977	et	3	main
lünka	doc_670731433470_item	2799978	et	4	main
sobiv	doc_670731433470_item	2799979	et	4	main
sõna	doc_670731433470_item	2799980	et	4	main
iga	doc_670731433470_item	2799983	et	4	main
õige	doc_670731433470_item	2799984	et	4	main
millal	doc_670731433470_item	2799990	et	3	main
umbne	doc_670731433470_item	2799994	et	3	main
koduõppesüsteem	doc_670731433470_item	2799996	et	3	main
ajastu	doc_670731433470_item	2800015	et	4	main
individuaalsele	doc_670731433470_item	2800028	et	3	main
5	doc_670731433469_item	2799725	et	2	main
kokku	doc_670731433469_item	2799733	et	3	main
hoida	doc_670731433469_item	2799734	et	3	main
6	doc_670731433469_item	2799738	et	2	main
ning	doc_670731433469_item	2799740	et	3	main
b	doc_670731433469_item	2799741	et	4	main
vaid	doc_670731433469_item	2799742	et	3	main
a	doc_670731433469_item	2799748	et	4	main
liigne	doc_670731433469_item	2799767	et	3	main
b	doc_670731433469_item	2799768	et	4	main
libe	doc_670731433469_item	2799769	et	3	main
c	doc_670731433469_item	2799770	et	4	main
liikuv	doc_670731433469_item	2799771	et	4	main
d	doc_670731433469_item	2799772	et	4	main
lihtne	doc_670731433469_item	2799773	et	3	main
10	doc_670731433469_item	2799774	et	2	main
a	doc_670731433469_item	2799775	et	4	main
tulge	doc_670731433469_item	2799776	et	3	main
b	doc_670731433469_item	2799777	et	4	main
käige	doc_670731433469_item	2799778	et	3	main
c	doc_670731433469_item	2799779	et	4	main
külastage	doc_670731433469_item	2799780	et	3	main
d	doc_670731433469_item	2799781	et	4	main
minge	doc_670731433469_item	2799782	et	3	main
harjutus	doc_670731433470_item	2799783	et	4	main
avage	doc_670731433470_item	2799784	et	3	main
sulud	doc_670731433470_item	2799785	et	3	main
numbrid	doc_670731433470_item	2799786	et	3	main
a	doc_670731433469_item	2799766	et	4	main
abielupaar	doc_670731433470_item	2799797	et	4	main
inglismaalis	doc_670731433470_item	2799812	et	3	main
age	doc_670731433470_item	2799814	et	4	main
30	doc_670731433470_item	2799816	et	2	main
kolmekümne	doc_670731433470_item	2799817	et	4	main
kolmkümmend	doc_670731433470_item	2799823	et	4	main
vana	doc_670731433470_item	2799825	et	4	main
seitsmendast	doc_670731433470_item	2799831	et	3	main
nad	doc_670731433470_item	2799834	et	3	main
vabakutselised	doc_670731433470_item	2799836	et	4	main
ja	doc_670731433470_item	2799837	et	3	main
armastavad	doc_670731433470_item	2799845	et	4	main
suhtlemise	doc_670731433470_item	2799853	et	4	main
kõik	doc_670731433470_item	2799865	et	4	main
pole	doc_670731433470_item	2799866	et	3	main
nii	doc_670731433470_item	2799869	et	3	main
mõlemal	doc_670731433470_item	2799872	et	3	main
on	doc_670731433470_item	2799876	et	4	main
etendus	doc_670731433470_item	2799889	et	4	main
etendusel	doc_670731433470_item	2799890	et	4	main
ja	doc_670731433470_item	2799939	et	3	main
veelgi	doc_670731433470_item	2799940	et	4	main
parem	doc_670731433470_item	2799941	et	4	main
tallinn	doc_670731433470_item	2799948	et	4	main
ja	doc_670731433470_item	2799950	et	3	main
lõuna-aafrika	doc_670731433470_item	2799953	et	4	main
kui	doc_670731433470_item	2799955	et	3	main
kaua	doc_670731433470_item	2799956	et	3	main
edur	doc_670731433470_item	2799959	et	4	main
veel	doc_670731433470_item	2799960	et	4	main
tipus	doc_670731433470_item	2799961	et	3	main
suudavad	doc_670731433470_item	2799962	et	3	main
püsida	doc_670731433470_item	2799963	et	3	main
nad	doc_670731433470_item	2799966	et	3	main
punkti	doc_670731433470_item	2799988	et	4	main
kus	doc_670731433470_item	2800004	et	3	main
ja	doc_670731433470_item	2800005	et	3	main
sa	doc_670731433470_item	2800007	et	3	main
parasjagu	doc_670731433470_item	2800009	et	3	main
mis	doc_670731433470_item	2800016	et	4	main
4	doc_670731433470_item	2800029	et	2	main
raha	doc_670731433470_item	2800033	et	4	main
et	doc_670731433470_item	2800034	et	3	main
seda	doc_670731433470_item	2800035	et	3	main
on	doc_670731433470_item	2800039	et	4	main
vaja	doc_670731433470_item	2800040	et	4	main
ka	doc_670731433470_item	2800041	et	3	main
pisut	doc_670731433470_item	2800042	et	3	main
saad	doc_670731433470_item	2800048	et	4	main
ja	doc_670731433470_item	2800059	et	3	main
kodutöö	doc_670731433470_item	2800063	et	4	main
kursuse	doc_670731433470_item	2800064	et	3	main
eest	doc_670731433470_item	2800066	et	4	main
meie	doc_670731433470_item	2800096	et	4	main
soovitad	doc_670731433470_item	2800107	et	3	main
seega	doc_670731433470_item	2800114	et	4	main
b	doc_670731433470_item	2800122	et	4	main
c	doc_670731433470_item	2800124	et	4	main
varanduse	doc_670731433470_item	2800125	et	3	main
saada	doc_670731433470_item	2800140	et	4	main
c	doc_670731433470_item	2800155	et	4	main
b	doc_670731433470_item	2800162	et	4	main
liikuv	doc_670731433470_item	2800183	et	4	main
lihtne	doc_670731433470_item	2800185	et	3	main
harjutus	doc_670731433471_item	2800195	et	4	main
avage	doc_670731433471_item	2800196	et	3	main
sulud	doc_670731433471_item	2800197	et	3	main
numbrid	doc_670731433471_item	2800198	et	3	main
kirjutage	doc_670731433471_item	2800199	et	3	main
vastus	doc_670731433471_item	2800203	et	3	main
pärit	doc_670731433471_item	2800216	et	3	main
praegu	doc_670731433471_item	2800221	et	3	main
inglismaal	doc_670731433471_item	2800224	et	4	main
londonis	doc_670731433471_item	2800225	et	4	main
toomas	doc_670731433471_item	2800232	et	3	main
32	doc_670731433471_item	2800234	et	2	main
üheksakümme	doc_670731433471_item	2800244	et	4	main
seitsmest	doc_670731433471_item	2800245	et	4	main
vabakutseline	doc_670731433471_item	2800249	et	4	main
ja	doc_670731433471_item	2800251	et	3	main
teatrides	doc_670731433471_item	2800256	et	4	main
vastus	doc_670731433470_item	2799791	et	3	main
toomas	doc_670731433470_item	2799801	et	3	main
edur	doc_670731433470_item	2799802	et	4	main
on	doc_670731433470_item	2799803	et	4	main
eesti	doc_670731433470_item	2799805	et	4	main
elavad	doc_670731433470_item	2799808	et	4	main
inglismaa	doc_670731433470_item	2799810	et	4	main
aastast	doc_670731433470_item	2799832	et	4	main
erinevades	doc_670731433470_item	2799841	et	4	main
teatrides	doc_670731433470_item	2799842	et	4	main
ainult	doc_670731433470_item	2799862	et	4	main
ülivõrdes	doc_670731433470_item	2799863	et	3	main
ja	doc_670731433470_item	2799873	et	3	main
1990	doc_670731433470_item	2799881	et	2	main
aastal	doc_670731433470_item	2799882	et	3	main
murdma	doc_670731433470_item	2799883	et	3	main
murdas	doc_670731433470_item	2799884	et	4	main
noor	doc_670731433470_item	2799885	et	3	main
naine	doc_670731433470_item	2799886	et	3	main
luikede	doc_670731433470_item	2799887	et	3	main
pidama	doc_670731433470_item	2799893	et	4	main
pidas	doc_670731433470_item	2799894	et	3	main
mõnda	doc_670731433470_item	2799895	et	4	main
aega	doc_670731433470_item	2799896	et	4	main
tantsimisest	doc_670731433470_item	2799897	et	4	main
eemal	doc_670731433470_item	2799898	et	3	main
olema	doc_670731433470_item	2799899	et	4	main
olla	doc_670731433470_item	2799900	et	3	main
age	doc_670731433470_item	2799901	et	4	main
ja	doc_670731433470_item	2799902	et	3	main
toomas	doc_670731433470_item	2799903	et	3	main
on	doc_670731433470_item	2799904	et	4	main
otsustanud	doc_670731433470_item	2799905	et	4	main
tantsima	doc_670731433470_item	2799906	et	3	main
tantsida	doc_670731433470_item	2799907	et	3	main
ainult	doc_670731433470_item	2799908	et	4	main
teineteisega	doc_670731433470_item	2799909	et	3	main
paaris	doc_670731433470_item	2799910	et	4	main
kuigi	doc_670731433470_item	2799911	et	3	main
nemad	doc_670731433470_item	2799912	et	3	main
nemadel	doc_670731433470_item	2799913	et	4	main
on	doc_670731433470_item	2799914	et	4	main
tehtud	doc_670731433470_item	2799915	et	4	main
pakkumisi	doc_670731433470_item	2799916	et	4	main
ka	doc_670731433470_item	2799917	et	3	main
eraldi	doc_670731433470_item	2799918	et	4	main
tantsimiseks	doc_670731433470_item	2799919	et	4	main
vaatamata	doc_670731433470_item	2799920	et	4	main
32	doc_670731433470_item	2799822	et	2	main
üheksakümne	doc_670731433470_item	2799830	et	4	main
on	doc_670731433470_item	2799833	et	4	main
vabakutseline	doc_670731433470_item	2799835	et	4	main
teatrid	doc_670731433470_item	2799840	et	3	main
suhtuma	doc_670731433470_item	2799852	et	3	main
üldiselt	doc_670731433470_item	2799855	et	4	main
hästi	doc_670731433470_item	2799856	et	3	main
eriti	doc_670731433470_item	2799874	et	3	main
agel	doc_670731433470_item	2799875	et	4	main
olnud	doc_670731433470_item	2799877	et	4	main
probleeme	doc_670731433470_item	2799878	et	3	main
tervis	doc_670731433470_item	2799879	et	3	main
tervisega	doc_670731433470_item	2799880	et	3	main
jalaluu	doc_670731433470_item	2799891	et	4	main
ja	doc_670731433470_item	2799892	et	3	main
nende	doc_670731433470_item	2799927	et	4	main
lähiaja	doc_670731433470_item	2799928	et	3	main
age	doc_670731433470_item	2799934	et	4	main
ja	doc_670731433470_item	2799935	et	3	main
toomas	doc_670731433470_item	2799936	et	3	main
oks	doc_670731433470_item	2799957	et	3	main
ütlema	doc_670731433470_item	2799967	et	3	main
nad	doc_670731433470_item	2799969	et	3	main
üks	doc_670731433470_item	2799972	et	3	main
alt	doc_670731433470_item	2799982	et	4	main
vastus	doc_670731433470_item	2799985	et	3	main
annab	doc_670731433470_item	2799986	et	3	main
ühe	doc_670731433470_item	2799987	et	4	main
soovitad	doc_670731433470_item	2799992	et	3	main
seda	doc_670731433470_item	2800008	et	3	main
soovid	doc_670731433470_item	2800010	et	4	main
on	doc_670731433470_item	2800012	et	4	main
interaktiivse	doc_670731433470_item	2800013	et	3	main
õppe	doc_670731433470_item	2800014	et	4	main
edule	doc_670731433470_item	2799922	et	3	main
esinemised	doc_670731433470_item	2799929	et	4	main
planeeritud	doc_670731433470_item	2799933	et	4	main
tahavad	doc_670731433470_item	2799937	et	3	main
areneda	doc_670731433470_item	2799938	et	3	main
ütelda	doc_670731433470_item	2799968	et	4	main
eelistavad	doc_670731433470_item	2799970	et	4	main
päev	doc_670731433470_item	2799973	et	3	main
õpi	doc_670731433470_item	2799989	et	4	main
unusta	doc_670731433470_item	2799993	et	4	main
sul	doc_670731433470_item	2799998	et	3	main
targemaks	doc_670731433470_item	2800000	et	4	main
käes	doc_670731433470_item	2800011	et	4	main
annab	doc_670731433470_item	2800017	et	3	main
sulle	doc_670731433470_item	2800018	et	3	main
3	doc_670731433470_item	2800019	et	2	main
vabaduse	doc_670731433470_item	2800020	et	4	main
planeerida	doc_670731433470_item	2800021	et	3	main
ning	doc_670731433470_item	2800023	et	3	main
omandada	doc_670731433470_item	2800025	et	3	main
teadmisi	doc_670731433470_item	2800026	et	4	main
tasemele	doc_670731433470_item	2800030	et	3	main
5	doc_670731433470_item	2800036	et	2	main
kokku	doc_670731433470_item	2800037	et	3	main
registreerunud	doc_670731433470_item	2800047	et	4	main
või	doc_670731433470_item	2800051	et	4	main
lähimast	doc_670731433470_item	2800052	et	4	main
õppematerjalid	doc_670731433470_item	2800057	et	3	main
6	doc_670731433470_item	2800061	et	2	main
kõik	doc_670731433470_item	2800089	et	4	main
geniaalne	doc_670731433470_item	2800090	et	3	main
just	doc_670731433470_item	2800112	et	3	main
b	doc_670731433470_item	2800113	et	4	main
3	doc_670731433470_item	2800119	et	2	main
a	doc_670731433470_item	2800120	et	4	main
aega	doc_670731433470_item	2800022	et	4	main
vastavalt	doc_670731433470_item	2800027	et	4	main
tarkust	doc_670731433470_item	2800043	et	4	main
postiasutusest	doc_670731433470_item	2800053	et	4	main
igal	doc_670731433470_item	2800054	et	3	main
raamatu	doc_670731433470_item	2800058	et	4	main
ning	doc_670731433470_item	2800062	et	3	main
7	doc_670731433470_item	2800065	et	2	main
selle	doc_670731433470_item	2800068	et	4	main
kättesaamisel	doc_670731433470_item	2800069	et	4	main
saada	doc_670731433470_item	2800070	et	4	main
täidetud	doc_670731433470_item	2800071	et	4	main
kodutöö	doc_670731433470_item	2800072	et	4	main
meile	doc_670731433470_item	2800073	et	4	main
tagasi	doc_670731433470_item	2800074	et	3	main
õpetaja	doc_670731433470_item	2800075	et	4	main
vaatab	doc_670731433470_item	2800076	et	3	main
selle	doc_670731433470_item	2800077	et	4	main
üle	doc_670731433470_item	2800078	et	3	main
8	doc_670731433470_item	2800079	et	2	main
parandab	doc_670731433470_item	2800080	et	3	main
vead	doc_670731433470_item	2800081	et	4	main
ning	doc_670731433470_item	2800082	et	3	main
vastab	doc_670731433470_item	2800083	et	3	main
vajaduse	doc_670731433470_item	2800084	et	3	main
korral	doc_670731433470_item	2800085	et	4	main
ka	doc_670731433470_item	2800086	et	3	main
tekkinud	doc_670731433470_item	2800087	et	4	main
lisaküsimustele	doc_670731433470_item	2800088	et	4	main
on	doc_670731433470_item	2800032	et	4	main
hoida	doc_670731433470_item	2800038	et	3	main
meie	doc_670731433470_item	2800049	et	4	main
kontorist	doc_670731433470_item	2800050	et	4	main
on	doc_670731433470_item	2800091	et	4	main
9	doc_670731433470_item	2800092	et	2	main
lihtne	doc_670731433470_item	2800093	et	3	main
10	doc_670731433470_item	2800094	et	2	main
tulge	doc_670731433470_item	2800095	et	3	main
sobid	doc_670731433470_item	2800103	et	4	main
c	doc_670731433470_item	2800115	et	4	main
4	doc_670731433470_item	2800128	et	2	main
d	doc_670731433470_item	2800147	et	4	main
panna	doc_670731433470_item	2800149	et	4	main
a	doc_670731433470_item	2800151	et	4	main
ning	doc_670731433470_item	2800152	et	3	main
a	doc_670731433470_item	2800160	et	4	main
c	doc_670731433470_item	2800182	et	4	main
tulge	doc_670731433470_item	2800188	et	3	main
käige	doc_670731433470_item	2800190	et	3	main
c	doc_670731433470_item	2800191	et	4	main
külastage	doc_670731433470_item	2800192	et	3	main
annab	doc_670731433471_item	2800204	et	3	main
punkti	doc_670731433471_item	2800206	et	4	main
abielupaar	doc_670731433471_item	2800209	et	4	main
age	doc_670731433471_item	2800210	et	4	main
oks	doc_670731433471_item	2800211	et	3	main
ja	doc_670731433471_item	2800212	et	3	main
toomas	doc_670731433471_item	2800213	et	3	main
eesti	doc_670731433471_item	2800217	et	4	main
aga	doc_670731433471_item	2800219	et	3	main
kui	doc_670731433470_item	2800044	et	3	main
oled	doc_670731433470_item	2800045	et	3	main
kursusele	doc_670731433470_item	2800046	et	3	main
kuul	doc_670731433470_item	2800055	et	4	main
kätte	doc_670731433470_item	2800056	et	4	main
helikasseti	doc_670731433470_item	2800060	et	4	main
tasud	doc_670731433470_item	2800067	et	4	main
virtuaalkodu	doc_670731433470_item	2800097	et	4	main
b	doc_670731433470_item	2800104	et	4	main
c	doc_670731433470_item	2800106	et	4	main
solvud	doc_670731433470_item	2800109	et	3	main
kuigi	doc_670731433470_item	2800116	et	3	main
d	doc_670731433470_item	2800117	et	4	main
a	doc_670731433470_item	2800129	et	4	main
b	doc_670731433470_item	2800131	et	4	main
d	doc_670731433470_item	2800135	et	4	main
tasakaalule	doc_670731433470_item	2800136	et	3	main
kokku	doc_670731433470_item	2800148	et	3	main
ette	doc_670731433470_item	2800163	et	4	main
a	doc_670731433470_item	2800178	et	4	main
liigne	doc_670731433470_item	2800179	et	3	main
b	doc_670731433470_item	2800180	et	4	main
libe	doc_670731433470_item	2800181	et	3	main
d	doc_670731433470_item	2800184	et	4	main
10	doc_670731433470_item	2800186	et	2	main
a	doc_670731433470_item	2800187	et	4	main
iga	doc_670731433471_item	2800201	et	4	main
balletitantsijad	doc_670731433471_item	2800208	et	3	main
aastane	doc_670731433471_item	2800230	et	4	main
on	doc_670731433471_item	2800233	et	4	main
aastat	doc_670731433471_item	2800238	et	3	main
aastast	doc_670731433471_item	2800246	et	4	main
armastama	doc_670731433471_item	2800258	et	3	main
armastatakse	doc_670731433471_item	2800259	et	3	main
neid	doc_670731433471_item	2800260	et	4	main
väga	doc_670731433471_item	2800261	et	3	main
ning	doc_670731433471_item	2800262	et	3	main
üldiselt	doc_670731433471_item	2800269	et	4	main
järve	doc_670731433471_item	2800302	et	4	main
olema	doc_670731433471_item	2800313	et	4	main
olla	doc_670731433471_item	2800314	et	3	main
tehtud	doc_670731433471_item	2800329	et	4	main
suurele	doc_670731433471_item	2800335	et	4	main
edule	doc_670731433471_item	2800336	et	3	main
esinemised	doc_670731433471_item	2800343	et	4	main
täpselt	doc_670731433471_item	2800345	et	4	main
areneda	doc_670731433471_item	2800352	et	3	main
esinema	doc_670731433471_item	2800361	et	3	main
tallinnasse	doc_670731433471_item	2800363	et	3	main
seejärel	doc_670731433471_item	2800365	et	3	main
tipus	doc_670731433471_item	2800375	et	3	main
oska	doc_670731433471_item	2800379	et	4	main
parasjagu	doc_670731433471_item	2800423	et	3	main
interaktiivse	doc_670731433471_item	2800427	et	3	main
on	doc_670731433471_item	2800446	et	4	main
raha	doc_670731433471_item	2800447	et	4	main
et	doc_670731433471_item	2800448	et	3	main
seda	doc_670731433471_item	2800449	et	3	main
5	doc_670731433471_item	2800450	et	2	main
kokku	doc_670731433471_item	2800451	et	3	main
vaja	doc_670731433471_item	2800454	et	4	main
tarkust	doc_670731433471_item	2800457	et	4	main
kursusele	doc_670731433471_item	2800460	et	3	main
saad	doc_670731433471_item	2800462	et	4	main
meie	doc_670731433471_item	2800463	et	4	main
postiasutusest	doc_670731433471_item	2800467	et	4	main
igal	doc_670731433471_item	2800468	et	3	main
vaatab	doc_670731433471_item	2800490	et	3	main
kõik	doc_670731433471_item	2800503	et	4	main
geniaalne	doc_670731433471_item	2800504	et	3	main
sobid	doc_670731433471_item	2800517	et	4	main
soovid	doc_670731433471_item	2800519	et	4	main
või	doc_670731433470_item	2800098	et	4	main
postitage	doc_670731433470_item	2800099	et	3	main
kupong	doc_670731433470_item	2800100	et	3	main
1	doc_670731433470_item	2800101	et	2	main
a	doc_670731433470_item	2800102	et	4	main
soovid	doc_670731433470_item	2800105	et	4	main
d	doc_670731433470_item	2800108	et	4	main
2	doc_670731433470_item	2800110	et	2	main
a	doc_670731433470_item	2800111	et	4	main
siiski	doc_670731433470_item	2800118	et	4	main
vajaduse	doc_670731433470_item	2800121	et	3	main
vabanduse	doc_670731433470_item	2800123	et	4	main
d	doc_670731433470_item	2800126	et	4	main
tasemele	doc_670731433470_item	2800132	et	3	main
tasakesi	doc_670731433470_item	2800134	et	3	main
5	doc_670731433470_item	2800137	et	2	main
a	doc_670731433470_item	2800138	et	4	main
kokku	doc_670731433470_item	2800139	et	3	main
hoida	doc_670731433470_item	2800146	et	3	main
6	doc_670731433470_item	2800150	et	2	main
b	doc_670731433470_item	2800153	et	4	main
vaid	doc_670731433470_item	2800154	et	3	main
taga	doc_670731433470_item	2800161	et	4	main
d	doc_670731433470_item	2800193	et	4	main
minge	doc_670731433470_item	2800194	et	3	main
õige	doc_670731433471_item	2800202	et	4	main
ühe	doc_670731433471_item	2800205	et	4	main
maailmakuulsad	doc_670731433471_item	2800207	et	3	main
edur	doc_670731433471_item	2800214	et	4	main
elavad	doc_670731433471_item	2800220	et	4	main
age	doc_670731433471_item	2800226	et	4	main
on	doc_670731433471_item	2800227	et	4	main
30	doc_670731433471_item	2800228	et	2	main
üheksasaja	doc_670731433471_item	2800243	et	4	main
nad	doc_670731433471_item	2800248	et	3	main
erinevad	doc_670731433471_item	2800253	et	4	main
viimased	doc_670731433471_item	2800271	et	3	main
peas	doc_670731433471_item	2800308	et	4	main
mõnda	doc_670731433471_item	2800309	et	4	main
age	doc_670731433471_item	2800315	et	4	main
ja	doc_670731433471_item	2800316	et	3	main
toomas	doc_670731433471_item	2800317	et	3	main
on	doc_670731433471_item	2800318	et	4	main
ainult	doc_670731433471_item	2800322	et	4	main
ka	doc_670731433471_item	2800331	et	3	main
eraldi	doc_670731433471_item	2800332	et	4	main
tantsijad	doc_670731433471_item	2800338	et	4	main
on	doc_670731433471_item	2800344	et	4	main
planeerima	doc_670731433471_item	2800346	et	3	main
toomas	doc_670731433471_item	2800350	et	3	main
veel	doc_670731433471_item	2800374	et	4	main
ei	doc_670731433471_item	2800378	et	4	main
öelda	doc_670731433471_item	2800382	et	4	main
eelistavad	doc_670731433471_item	2800384	et	4	main
käes	doc_670731433471_item	2800425	et	4	main
planeerida	doc_670731433471_item	2800435	et	3	main
vastavalt	doc_670731433471_item	2800441	et	4	main
4	doc_670731433471_item	2800443	et	2	main
tasemele	doc_670731433471_item	2800444	et	3	main
aeg	doc_670731433471_item	2800445	et	3	main
selle	doc_670731433471_item	2800491	et	4	main
parandab	doc_670731433471_item	2800494	et	3	main
on	doc_670731433471_item	2800505	et	4	main
lihtne	doc_670731433471_item	2800507	et	3	main
kupong	doc_670731433471_item	2800514	et	3	main
soovitad	doc_670731433471_item	2800521	et	3	main
seega	doc_670731433471_item	2800528	et	4	main
vajaduse	doc_670731433471_item	2800535	et	3	main
liita	doc_670731433471_item	2800557	et	4	main
a	doc_670731433471_item	2800565	et	4	main
ning	doc_670731433471_item	2800566	et	3	main
et	doc_670731433471_item	2800572	et	3	main
taga	doc_670731433471_item	2800575	et	4	main
ette	doc_670731433471_item	2800577	et	4	main
a	doc_670731433471_item	2800583	et	4	main
kirjutab	doc_670731433471_item	2800584	et	3	main
avage	doc_670731433472_item	2800610	et	3	main
age	doc_670731433472_item	2800624	et	4	main
ja	doc_670731433472_item	2800626	et	3	main
on	doc_670731433472_item	2800629	et	4	main
elavad	doc_670731433472_item	2800634	et	4	main
age	doc_670731433472_item	2800640	et	4	main
on	doc_670731433472_item	2800647	et	4	main
vabaduse	doc_670731433470_item	2800127	et	4	main
tasule	doc_670731433470_item	2800130	et	3	main
c	doc_670731433470_item	2800133	et	4	main
b	doc_670731433470_item	2800141	et	4	main
kokku	doc_670731433470_item	2800142	et	3	main
liita	doc_670731433470_item	2800143	et	4	main
c	doc_670731433470_item	2800144	et	4	main
kokku	doc_670731433470_item	2800145	et	3	main
kuid	doc_670731433470_item	2800156	et	4	main
d	doc_670731433470_item	2800157	et	4	main
et	doc_670731433470_item	2800158	et	3	main
7	doc_670731433470_item	2800159	et	2	main
c	doc_670731433470_item	2800164	et	4	main
eest	doc_670731433470_item	2800165	et	4	main
d	doc_670731433470_item	2800166	et	4	main
ees	doc_670731433470_item	2800167	et	4	main
8	doc_670731433470_item	2800168	et	2	main
a	doc_670731433470_item	2800169	et	4	main
kirjutab	doc_670731433470_item	2800170	et	3	main
b	doc_670731433470_item	2800171	et	4	main
palub	doc_670731433470_item	2800172	et	3	main
c	doc_670731433470_item	2800173	et	4	main
parandab	doc_670731433470_item	2800174	et	3	main
d	doc_670731433470_item	2800175	et	4	main
muudab	doc_670731433470_item	2800176	et	3	main
9	doc_670731433470_item	2800177	et	2	main
b	doc_670731433470_item	2800189	et	4	main
sõnadega	doc_670731433471_item	2800200	et	3	main
on	doc_670731433471_item	2800215	et	4	main
eestist	doc_670731433471_item	2800218	et	3	main
inglismaa	doc_670731433471_item	2800222	et	4	main
ja	doc_670731433471_item	2800231	et	3	main
kolm	doc_670731433471_item	2800235	et	3	main
kaks	doc_670731433471_item	2800237	et	3	main
esinevad	doc_670731433471_item	2800252	et	4	main
teatrid	doc_670731433471_item	2800254	et	3	main
isegi	doc_670731433471_item	2800263	et	4	main
hästi	doc_670731433471_item	2800270	et	3	main
olnud	doc_670731433471_item	2800291	et	4	main
probleeme	doc_670731433471_item	2800292	et	3	main
tervis	doc_670731433471_item	2800293	et	3	main
tervisega	doc_670731433471_item	2800294	et	3	main
noor	doc_670731433471_item	2800299	et	3	main
pidama	doc_670731433471_item	2800307	et	4	main
tantsida	doc_670731433471_item	2800321	et	3	main
pakkumisi	doc_670731433471_item	2800330	et	4	main
elavad	doc_670731433471_item	2800337	et	4	main
planeeritud	doc_670731433471_item	2800347	et	4	main
veelgi	doc_670731433471_item	2800354	et	4	main
parem	doc_670731433471_item	2800355	et	4	main
parem	doc_670731433471_item	2800356	et	4	main
tulevad	doc_670731433471_item	2800359	et	4	main
lõuna-aafrika	doc_670731433471_item	2800367	et	4	main
püsida	doc_670731433471_item	2800377	et	3	main
nad	doc_670731433471_item	2800380	et	3	main
nad	doc_670731433471_item	2800383	et	3	main
elada	doc_670731433471_item	2800385	et	3	main
üks	doc_670731433471_item	2800386	et	3	main
päev	doc_670731433471_item	2800387	et	3	main
ühe	doc_670731433471_item	2800388	et	4	main
london	doc_670731433471_item	2800223	et	4	main
kolmekümne	doc_670731433471_item	2800229	et	4	main
kümmend	doc_670731433471_item	2800236	et	4	main
vana	doc_670731433471_item	2800239	et	4	main
alates	doc_670731433471_item	2800240	et	3	main
1997a	doc_670731433471_item	2800241	et	4	main
tuha	doc_670731433471_item	2800242	et	3	main
on	doc_670731433471_item	2800247	et	4	main
vabakutselised	doc_670731433471_item	2800250	et	4	main
erinevates	doc_670731433471_item	2800255	et	4	main
karmid	doc_670731433471_item	2800264	et	4	main
kriitikud	doc_670731433471_item	2800265	et	3	main
suhtuma	doc_670731433471_item	2800266	et	3	main
suhtuvad	doc_670731433471_item	2800267	et	4	main
artiklid	doc_670731433471_item	2800272	et	3	main
räägivad	doc_670731433471_item	2800273	et	3	main
noored	doc_670731433471_item	2800274	et	3	main
noortest	doc_670731433471_item	2800275	et	4	main
ülivõrdes	doc_670731433471_item	2800277	et	3	main
kuid	doc_670731433471_item	2800278	et	4	main
ainult	doc_670731433471_item	2800276	et	4	main
kõik	doc_670731433471_item	2800279	et	4	main
pole	doc_670731433471_item	2800280	et	3	main
sugugi	doc_670731433471_item	2800281	et	4	main
nii	doc_670731433471_item	2800283	et	3	main
alati	doc_670731433471_item	2800282	et	4	main
kergelt	doc_670731433471_item	2800284	et	4	main
läinud	doc_670731433471_item	2800285	et	4	main
mõlemal	doc_670731433471_item	2800286	et	3	main
ja	doc_670731433471_item	2800287	et	3	main
eriti	doc_670731433471_item	2800288	et	3	main
agel	doc_670731433471_item	2800289	et	4	main
on	doc_670731433471_item	2800290	et	4	main
inglismaal	doc_670731433471_item	2800257	et	4	main
nendesse	doc_670731433471_item	2800268	et	4	main
jalaluu	doc_670731433471_item	2800305	et	4	main
ja	doc_670731433471_item	2800306	et	3	main
tantsimisest	doc_670731433471_item	2800311	et	4	main
eemal	doc_670731433471_item	2800312	et	3	main
teineteisega	doc_670731433471_item	2800323	et	3	main
kuigi	doc_670731433471_item	2800325	et	3	main
nemad	doc_670731433471_item	2800326	et	3	main
nendele	doc_670731433471_item	2800327	et	4	main
tantsimiseks	doc_670731433471_item	2800333	et	4	main
tagasihoidlik	doc_670731433471_item	2800339	et	3	main
tagasihoidlikult	doc_670731433471_item	2800340	et	4	main
ja	doc_670731433471_item	2800349	et	3	main
tahavad	doc_670731433471_item	2800351	et	3	main
ja	doc_670731433471_item	2800353	et	3	main
tantsida	doc_670731433471_item	2800357	et	3	main
märtsis	doc_670731433471_item	2800358	et	3	main
tallinn	doc_670731433471_item	2800362	et	4	main
lõuna-aafrikast	doc_670731433471_item	2800368	et	4	main
kui	doc_670731433471_item	2800369	et	3	main
kaua	doc_670731433471_item	2800370	et	3	main
oks	doc_670731433471_item	2800371	et	3	main
ja	doc_670731433471_item	2800372	et	3	main
edur	doc_670731433471_item	2800373	et	4	main
ütlema	doc_670731433471_item	2800381	et	3	main
päeva	doc_670731433471_item	2800389	et	4	main
vabaduse	doc_670731433471_item	2800434	et	4	main
eelise	doc_670731433471_item	2800438	et	4	main
teadmisi	doc_670731433471_item	2800440	et	4	main
individuaalsele	doc_670731433471_item	2800442	et	3	main
on	doc_670731433471_item	2800453	et	4	main
kontorist	doc_670731433471_item	2800464	et	4	main
meile	doc_670731433471_item	2800487	et	4	main
tagasi	doc_670731433471_item	2800488	et	3	main
üle	doc_670731433471_item	2800492	et	3	main
ning	doc_670731433471_item	2800496	et	3	main
ka	doc_670731433471_item	2800500	et	3	main
9	doc_670731433471_item	2800506	et	2	main
10	doc_670731433471_item	2800508	et	2	main
virtuaalkodu	doc_670731433471_item	2800511	et	4	main
postitage	doc_670731433471_item	2800513	et	3	main
a	doc_670731433471_item	2800525	et	4	main
just	doc_670731433471_item	2800526	et	3	main
c	doc_670731433471_item	2800529	et	4	main
kuigi	doc_670731433471_item	2800530	et	3	main
d	doc_670731433471_item	2800531	et	4	main
b	doc_670731433471_item	2800536	et	4	main
d	doc_670731433471_item	2800540	et	4	main
tasakaalule	doc_670731433471_item	2800550	et	3	main
b	doc_670731433471_item	2800555	et	4	main
c	doc_670731433471_item	2800558	et	4	main
hoida	doc_670731433471_item	2800560	et	3	main
kokku	doc_670731433471_item	2800562	et	3	main
panna	doc_670731433471_item	2800563	et	4	main
6	doc_670731433471_item	2800564	et	2	main
d	doc_670731433471_item	2800571	et	4	main
eest	doc_670731433471_item	2800579	et	4	main
d	doc_670731433471_item	2800580	et	4	main
ees	doc_670731433471_item	2800581	et	4	main
8	doc_670731433471_item	2800582	et	2	main
9	doc_670731433471_item	2800591	et	2	main
libe	doc_670731433471_item	2800595	et	3	main
c	doc_670731433471_item	2800596	et	4	main
liikuv	doc_670731433471_item	2800597	et	4	main
käige	doc_670731433471_item	2800604	et	3	main
numbrid	doc_670731433472_item	2800612	et	3	main
balletitantsijad	doc_670731433472_item	2800622	et	3	main
eestist	doc_670731433472_item	2800632	et	3	main
kolmekümne	doc_670731433472_item	2800643	et	4	main
32	doc_670731433472_item	2800648	et	2	main
vana	doc_670731433472_item	2800652	et	4	main
alates	doc_670731433472_item	2800653	et	3	main
üheksasaja	doc_670731433472_item	2800656	et	4	main
seitsmendal	doc_670731433472_item	2800658	et	3	main
vabakutseline	doc_670731433472_item	2800662	et	4	main
ja	doc_670731433472_item	2800664	et	3	main
suhtuvad	doc_670731433472_item	2800680	et	4	main
üldiselt	doc_670731433472_item	2800682	et	4	main
hästi	doc_670731433472_item	2800683	et	3	main
viimased	doc_670731433472_item	2800684	et	3	main
artiklid	doc_670731433472_item	2800685	et	3	main
1990	doc_670731433471_item	2800295	et	2	main
aastal	doc_670731433471_item	2800296	et	3	main
murdma	doc_670731433471_item	2800297	et	3	main
murdis	doc_670731433471_item	2800298	et	3	main
naine	doc_670731433471_item	2800300	et	3	main
luikede	doc_670731433471_item	2800301	et	3	main
etendus	doc_670731433471_item	2800303	et	4	main
etenduses	doc_670731433471_item	2800304	et	4	main
aega	doc_670731433471_item	2800310	et	4	main
otsustanud	doc_670731433471_item	2800319	et	4	main
tantsima	doc_670731433471_item	2800320	et	3	main
paaris	doc_670731433471_item	2800324	et	4	main
on	doc_670731433471_item	2800328	et	4	main
vaatamata	doc_670731433471_item	2800334	et	4	main
nende	doc_670731433471_item	2800341	et	4	main
lähiaja	doc_670731433471_item	2800342	et	3	main
age	doc_670731433471_item	2800348	et	4	main
nad	doc_670731433471_item	2800360	et	3	main
ja	doc_670731433471_item	2800364	et	3	main
sõidavad	doc_670731433471_item	2800366	et	3	main
suudavad	doc_670731433471_item	2800376	et	3	main
kaupa	doc_670731433471_item	2800390	et	4	main
kirjutage	doc_670731433471_item	2800391	et	3	main
lünka	doc_670731433471_item	2800392	et	4	main
sobiv	doc_670731433471_item	2800393	et	4	main
sõna	doc_670731433471_item	2800394	et	4	main
teksti	doc_670731433471_item	2800395	et	4	main
alt	doc_670731433471_item	2800396	et	4	main
iga	doc_670731433471_item	2800397	et	4	main
õige	doc_670731433471_item	2800398	et	4	main
vastus	doc_670731433471_item	2800399	et	3	main
annab	doc_670731433471_item	2800400	et	3	main
ühe	doc_670731433471_item	2800401	et	4	main
punkti	doc_670731433471_item	2800402	et	4	main
õpi	doc_670731433471_item	2800403	et	4	main
millal	doc_670731433471_item	2800404	et	3	main
1	doc_670731433471_item	2800405	et	2	main
soovid	doc_670731433471_item	2800406	et	4	main
unusta	doc_670731433471_item	2800407	et	4	main
umbne	doc_670731433471_item	2800408	et	3	main
klassiruum	doc_670731433471_item	2800409	et	3	main
koduõppesüsteem	doc_670731433471_item	2800410	et	3	main
võimaldab	doc_670731433471_item	2800411	et	3	main
sul	doc_670731433471_item	2800412	et	3	main
saada	doc_670731433471_item	2800413	et	4	main
2	doc_670731433471_item	2800415	et	2	main
just	doc_670731433471_item	2800416	et	3	main
targemaks	doc_670731433471_item	2800414	et	4	main
seal	doc_670731433471_item	2800417	et	4	main
kus	doc_670731433471_item	2800418	et	3	main
ja	doc_670731433471_item	2800419	et	3	main
millal	doc_670731433471_item	2800420	et	3	main
sa	doc_670731433471_item	2800421	et	3	main
soovid	doc_670731433471_item	2800424	et	4	main
ajastu	doc_670731433471_item	2800429	et	4	main
aega	doc_670731433471_item	2800436	et	4	main
omandada	doc_670731433471_item	2800439	et	3	main
ka	doc_670731433471_item	2800455	et	3	main
pisut	doc_670731433471_item	2800456	et	3	main
kui	doc_670731433471_item	2800458	et	3	main
registreerunud	doc_670731433471_item	2800461	et	4	main
vajaduse	doc_670731433471_item	2800498	et	3	main
tulge	doc_670731433471_item	2800509	et	3	main
seda	doc_670731433471_item	2800422	et	3	main
on	doc_670731433471_item	2800426	et	4	main
õppe	doc_670731433471_item	2800428	et	4	main
mis	doc_670731433471_item	2800430	et	4	main
annab	doc_670731433471_item	2800431	et	3	main
sulle	doc_670731433471_item	2800432	et	3	main
3	doc_670731433471_item	2800433	et	2	main
ning	doc_670731433471_item	2800437	et	3	main
saada	doc_670731433471_item	2800452	et	4	main
oled	doc_670731433471_item	2800459	et	3	main
või	doc_670731433471_item	2800465	et	4	main
lähimast	doc_670731433471_item	2800466	et	4	main
kuul	doc_670731433471_item	2800469	et	4	main
kätte	doc_670731433471_item	2800470	et	4	main
õppematerjalid	doc_670731433471_item	2800471	et	3	main
raamatu	doc_670731433471_item	2800472	et	4	main
ja	doc_670731433471_item	2800473	et	3	main
helikasseti	doc_670731433471_item	2800474	et	4	main
6	doc_670731433471_item	2800475	et	2	main
ning	doc_670731433471_item	2800476	et	3	main
kursuse	doc_670731433471_item	2800478	et	3	main
7	doc_670731433471_item	2800479	et	2	main
eest	doc_670731433471_item	2800480	et	4	main
tasud	doc_670731433471_item	2800481	et	4	main
kodutöö	doc_670731433471_item	2800477	et	4	main
selle	doc_670731433471_item	2800482	et	4	main
kättesaamisel	doc_670731433471_item	2800483	et	4	main
saada	doc_670731433471_item	2800484	et	4	main
kodutöö	doc_670731433471_item	2800486	et	4	main
täidetud	doc_670731433471_item	2800485	et	4	main
õpetaja	doc_670731433471_item	2800489	et	4	main
8	doc_670731433471_item	2800493	et	2	main
vead	doc_670731433471_item	2800495	et	4	main
vastab	doc_670731433471_item	2800497	et	3	main
korral	doc_670731433471_item	2800499	et	4	main
tekkinud	doc_670731433471_item	2800501	et	4	main
lisaküsimustele	doc_670731433471_item	2800502	et	4	main
meie	doc_670731433471_item	2800510	et	4	main
või	doc_670731433471_item	2800512	et	4	main
1	doc_670731433471_item	2800515	et	2	main
b	doc_670731433471_item	2800518	et	4	main
c	doc_670731433471_item	2800520	et	4	main
solvud	doc_670731433471_item	2800523	et	3	main
siiski	doc_670731433471_item	2800532	et	4	main
a	doc_670731433471_item	2800534	et	4	main
vabaduse	doc_670731433471_item	2800541	et	4	main
a	doc_670731433471_item	2800543	et	4	main
tasule	doc_670731433471_item	2800544	et	3	main
b	doc_670731433471_item	2800545	et	4	main
tasemele	doc_670731433471_item	2800546	et	3	main
saada	doc_670731433471_item	2800554	et	4	main
d	doc_670731433471_item	2800561	et	4	main
7	doc_670731433471_item	2800573	et	2	main
b	doc_670731433471_item	2800576	et	4	main
c	doc_670731433471_item	2800587	et	4	main
parandab	doc_670731433471_item	2800588	et	3	main
d	doc_670731433471_item	2800589	et	4	main
muudab	doc_670731433471_item	2800590	et	3	main
a	doc_670731433471_item	2800601	et	4	main
tulge	doc_670731433471_item	2800602	et	3	main
c	doc_670731433471_item	2800605	et	4	main
külastage	doc_670731433471_item	2800606	et	3	main
d	doc_670731433471_item	2800607	et	4	main
kirjutage	doc_670731433472_item	2800613	et	3	main
abielupaar	doc_670731433472_item	2800623	et	4	main
oks	doc_670731433472_item	2800625	et	3	main
edur	doc_670731433472_item	2800628	et	4	main
londonis	doc_670731433472_item	2800639	et	4	main
aastane	doc_670731433472_item	2800644	et	4	main
1997a	doc_670731433472_item	2800654	et	4	main
aastal	doc_670731433472_item	2800659	et	3	main
armastama	doc_670731433472_item	2800671	et	3	main
armastavad	doc_670731433472_item	2800672	et	4	main
neid	doc_670731433472_item	2800673	et	4	main
väga	doc_670731433472_item	2800674	et	3	main
ning	doc_670731433472_item	2800675	et	3	main
isegi	doc_670731433472_item	2800676	et	4	main
nendesse	doc_670731433472_item	2800681	et	4	main
olema	doc_670731433472_item	2800726	et	4	main
oli	doc_670731433472_item	2800727	et	3	main
age	doc_670731433472_item	2800728	et	4	main
ja	doc_670731433472_item	2800729	et	3	main
toomas	doc_670731433472_item	2800730	et	3	main
tehtud	doc_670731433472_item	2800742	et	4	main
suurele	doc_670731433472_item	2800748	et	4	main
tantsijad	doc_670731433472_item	2800751	et	4	main
parem	doc_670731433472_item	2800769	et	4	main
tantsida	doc_670731433472_item	2800770	et	3	main
märtsis	doc_670731433472_item	2800771	et	3	main
tulevad	doc_670731433472_item	2800772	et	4	main
kaua	doc_670731433472_item	2800783	et	3	main
püsida	doc_670731433472_item	2800790	et	3	main
oska	doc_670731433472_item	2800792	et	4	main
ütelda	doc_670731433472_item	2800795	et	4	main
nad	doc_670731433472_item	2800796	et	3	main
eelistavad	doc_670731433472_item	2800797	et	4	main
elada	doc_670731433472_item	2800798	et	3	main
üks	doc_670731433472_item	2800799	et	3	main
päev	doc_670731433472_item	2800800	et	3	main
õige	doc_670731433472_item	2800811	et	4	main
vastus	doc_670731433472_item	2800812	et	3	main
unusta	doc_670731433472_item	2800820	et	4	main
a	doc_670731433471_item	2800516	et	4	main
d	doc_670731433471_item	2800522	et	4	main
c	doc_670731433471_item	2800538	et	4	main
varanduse	doc_670731433471_item	2800539	et	3	main
4	doc_670731433471_item	2800542	et	2	main
kokku	doc_670731433471_item	2800556	et	3	main
kokku	doc_670731433471_item	2800559	et	3	main
c	doc_670731433471_item	2800569	et	4	main
kuid	doc_670731433471_item	2800570	et	4	main
a	doc_670731433471_item	2800574	et	4	main
liigne	doc_670731433471_item	2800593	et	3	main
b	doc_670731433471_item	2800594	et	4	main
b	doc_670731433471_item	2800603	et	4	main
sulud	doc_670731433472_item	2800611	et	3	main
2	doc_670731433471_item	2800524	et	2	main
b	doc_670731433471_item	2800527	et	4	main
3	doc_670731433471_item	2800533	et	2	main
vabanduse	doc_670731433471_item	2800537	et	4	main
c	doc_670731433471_item	2800547	et	4	main
tasakesi	doc_670731433471_item	2800548	et	3	main
d	doc_670731433471_item	2800549	et	4	main
5	doc_670731433471_item	2800551	et	2	main
a	doc_670731433471_item	2800552	et	4	main
kokku	doc_670731433471_item	2800553	et	3	main
b	doc_670731433471_item	2800567	et	4	main
vaid	doc_670731433471_item	2800568	et	3	main
c	doc_670731433471_item	2800578	et	4	main
b	doc_670731433471_item	2800585	et	4	main
palub	doc_670731433471_item	2800586	et	3	main
a	doc_670731433471_item	2800592	et	4	main
d	doc_670731433471_item	2800598	et	4	main
lihtne	doc_670731433471_item	2800599	et	3	main
10	doc_670731433471_item	2800600	et	2	main
minge	doc_670731433471_item	2800608	et	3	main
harjutus	doc_670731433472_item	2800609	et	4	main
sõnadega	doc_670731433472_item	2800614	et	3	main
iga	doc_670731433472_item	2800615	et	4	main
õige	doc_670731433472_item	2800616	et	4	main
vastus	doc_670731433472_item	2800617	et	3	main
annab	doc_670731433472_item	2800618	et	3	main
ühe	doc_670731433472_item	2800619	et	4	main
punkti	doc_670731433472_item	2800620	et	4	main
maailmakuulsad	doc_670731433472_item	2800621	et	3	main
toomas	doc_670731433472_item	2800627	et	3	main
aga	doc_670731433472_item	2800633	et	3	main
inglismaa	doc_670731433472_item	2800636	et	4	main
london	doc_670731433472_item	2800637	et	4	main
inglismaal	doc_670731433472_item	2800638	et	4	main
30	doc_670731433472_item	2800642	et	2	main
ja	doc_670731433472_item	2800645	et	3	main
kolmküment	doc_670731433472_item	2800649	et	4	main
kaks	doc_670731433472_item	2800650	et	3	main
nad	doc_670731433472_item	2800661	et	3	main
inglismaal	doc_670731433472_item	2800670	et	4	main
noored	doc_670731433472_item	2800687	et	3	main
pärit	doc_670731433472_item	2800630	et	3	main
eesti	doc_670731433472_item	2800631	et	4	main
praegu	doc_670731433472_item	2800635	et	3	main
on	doc_670731433472_item	2800641	et	4	main
toomas	doc_670731433472_item	2800646	et	3	main
on	doc_670731433472_item	2800660	et	4	main
vabakutselised	doc_670731433472_item	2800663	et	4	main
esinevad	doc_670731433472_item	2800665	et	4	main
erinevad	doc_670731433472_item	2800666	et	4	main
teatrid	doc_670731433472_item	2800667	et	3	main
noortele	doc_670731433472_item	2800688	et	3	main
ainult	doc_670731433472_item	2800689	et	4	main
ülivõrdes	doc_670731433472_item	2800690	et	3	main
kuid	doc_670731433472_item	2800691	et	4	main
kõik	doc_670731433472_item	2800692	et	4	main
pole	doc_670731433472_item	2800693	et	3	main
sugugi	doc_670731433472_item	2800694	et	4	main
alati	doc_670731433472_item	2800695	et	4	main
nii	doc_670731433472_item	2800696	et	3	main
kergelt	doc_670731433472_item	2800697	et	4	main
läinud	doc_670731433472_item	2800698	et	4	main
mõlemal	doc_670731433472_item	2800699	et	3	main
ja	doc_670731433472_item	2800700	et	3	main
eriti	doc_670731433472_item	2800701	et	3	main
agel	doc_670731433472_item	2800702	et	4	main
on	doc_670731433472_item	2800703	et	4	main
olnud	doc_670731433472_item	2800704	et	4	main
probleeme	doc_670731433472_item	2800705	et	3	main
tervis	doc_670731433472_item	2800706	et	3	main
tervisega	doc_670731433472_item	2800707	et	3	main
1990	doc_670731433472_item	2800708	et	2	main
aastal	doc_670731433472_item	2800709	et	3	main
murdma	doc_670731433472_item	2800710	et	3	main
murdis	doc_670731433472_item	2800711	et	3	main
noor	doc_670731433472_item	2800712	et	3	main
naine	doc_670731433472_item	2800713	et	3	main
luikede	doc_670731433472_item	2800714	et	3	main
järve	doc_670731433472_item	2800715	et	4	main
etendus	doc_670731433472_item	2800716	et	4	main
etenduse	doc_670731433472_item	2800717	et	4	main
jalaluu	doc_670731433472_item	2800718	et	4	main
ja	doc_670731433472_item	2800719	et	3	main
pidama	doc_670731433472_item	2800720	et	4	main
otsustanud	doc_670731433472_item	2800732	et	4	main
teineteisega	doc_670731433472_item	2800736	et	3	main
kuigi	doc_670731433472_item	2800738	et	3	main
ka	doc_670731433472_item	2800744	et	3	main
vaatamata	doc_670731433472_item	2800747	et	4	main
ja	doc_670731433472_item	2800766	et	3	main
aastat	doc_670731433472_item	2800651	et	3	main
tuhande	doc_670731433472_item	2800655	et	3	main
üheksakümne	doc_670731433472_item	2800657	et	4	main
erinevaid	doc_670731433472_item	2800668	et	4	main
teatreid	doc_670731433472_item	2800669	et	3	main
karmid	doc_670731433472_item	2800677	et	4	main
kriitikud	doc_670731433472_item	2800678	et	3	main
suhtuma	doc_670731433472_item	2800679	et	3	main
mõnda	doc_670731433472_item	2800722	et	4	main
aega	doc_670731433472_item	2800723	et	4	main
tantsimisest	doc_670731433472_item	2800724	et	4	main
eemal	doc_670731433472_item	2800725	et	3	main
tantsida	doc_670731433472_item	2800734	et	3	main
ainult	doc_670731433472_item	2800735	et	4	main
paaris	doc_670731433472_item	2800737	et	4	main
nemad	doc_670731433472_item	2800739	et	3	main
pakkumisi	doc_670731433472_item	2800743	et	4	main
elavad	doc_670731433472_item	2800750	et	4	main
nende	doc_670731433472_item	2800754	et	4	main
veelgi	doc_670731433472_item	2800767	et	4	main
ja	doc_670731433472_item	2800777	et	3	main
seejärel	doc_670731433472_item	2800778	et	3	main
sõidavad	doc_670731433472_item	2800779	et	3	main
lõuna-aafrika	doc_670731433472_item	2800780	et	4	main
ja	doc_670731433472_item	2800785	et	3	main
veel	doc_670731433472_item	2800787	et	4	main
ütlema	doc_670731433472_item	2800794	et	3	main
kaupa	doc_670731433472_item	2800803	et	4	main
kirjutage	doc_670731433472_item	2800804	et	3	main
sõna	doc_670731433472_item	2800807	et	4	main
ühe	doc_670731433472_item	2800814	et	4	main
punkti	doc_670731433472_item	2800815	et	4	main
õpi	doc_670731433472_item	2800816	et	4	main
millal	doc_670731433472_item	2800817	et	3	main
1	doc_670731433472_item	2800818	et	2	main
sul	doc_670731433472_item	2800825	et	3	main
targemaks	doc_670731433472_item	2800827	et	4	main
seal	doc_670731433472_item	2800830	et	4	main
kus	doc_670731433472_item	2800831	et	3	main
soovid	doc_670731433472_item	2800837	et	4	main
teadmisi	doc_670731433472_item	2800853	et	4	main
on	doc_670731433472_item	2800866	et	4	main
tarkust	doc_670731433472_item	2800870	et	4	main
kursusele	doc_670731433472_item	2800873	et	3	main
kuul	doc_670731433472_item	2800882	et	4	main
kätte	doc_670731433472_item	2800883	et	4	main
õppematerjalid	doc_670731433472_item	2800884	et	3	main
6	doc_670731433472_item	2800888	et	2	main
tasud	doc_670731433472_item	2800894	et	4	main
selle	doc_670731433472_item	2800895	et	4	main
täidetud	doc_670731433472_item	2800898	et	4	main
meile	doc_670731433472_item	2800900	et	4	main
siiski	doc_670731433472_item	2800945	et	4	main
3	doc_670731433472_item	2800946	et	2	main
d	doc_670731433472_item	2800984	et	4	main
et	doc_670731433472_item	2800985	et	3	main
7	doc_670731433472_item	2800986	et	2	main
c	doc_670731433472_item	2800991	et	4	main
libe	doc_670731433472_item	2801008	et	3	main
liikuv	doc_670731433472_item	2801010	et	4	main
lihtne	doc_670731433472_item	2801012	et	3	main
abielupaar	doc_670731433473_item	2801036	et	4	main
30	doc_670731433473_item	2801055	et	2	main
üheksasaja	doc_670731433473_item	2801068	et	4	main
seitsemendast	doc_670731433473_item	2801070	et	4	main
on	doc_670731433473_item	2801071	et	4	main
nad	doc_670731433473_item	2801072	et	3	main
ja	doc_670731433473_item	2801075	et	3	main
inglismaal	doc_670731433473_item	2801081	et	4	main
armastama	doc_670731433473_item	2801082	et	3	main
karmid	doc_670731433473_item	2801088	et	4	main
noored	doc_670731433473_item	2801098	et	3	main
noortest	doc_670731433473_item	2801099	et	4	main
ainult	doc_670731433473_item	2801100	et	4	main
ülivõrdes	doc_670731433473_item	2801101	et	3	main
nii	doc_670731433473_item	2801107	et	3	main
mõlemal	doc_670731433473_item	2801110	et	3	main
agel	doc_670731433473_item	2801113	et	4	main
naine	doc_670731433473_item	2801124	et	3	main
etendusel	doc_670731433473_item	2801128	et	4	main
jalaluu	doc_670731433473_item	2801129	et	4	main
räägivad	doc_670731433472_item	2800686	et	3	main
tantsima	doc_670731433472_item	2800733	et	3	main
eraldi	doc_670731433472_item	2800745	et	4	main
tantsimiseks	doc_670731433472_item	2800746	et	4	main
tagasihoidlikku	doc_670731433472_item	2800753	et	4	main
areneda	doc_670731433472_item	2800765	et	3	main
nad	doc_670731433472_item	2800773	et	3	main
esinema	doc_670731433472_item	2800774	et	3	main
tallinn	doc_670731433472_item	2800775	et	4	main
kui	doc_670731433472_item	2800782	et	3	main
edur	doc_670731433472_item	2800786	et	4	main
ühe	doc_670731433472_item	2800801	et	4	main
iga	doc_670731433472_item	2800810	et	4	main
soovid	doc_670731433472_item	2800819	et	4	main
käes	doc_670731433472_item	2800838	et	4	main
on	doc_670731433472_item	2800839	et	4	main
aeg	doc_670731433472_item	2800858	et	3	main
vaja	doc_670731433472_item	2800867	et	4	main
saad	doc_670731433472_item	2800875	et	4	main
kontorist	doc_670731433472_item	2800877	et	4	main
igal	doc_670731433472_item	2800881	et	3	main
helikasseti	doc_670731433472_item	2800887	et	4	main
kursuse	doc_670731433472_item	2800891	et	3	main
ette	doc_670731433472_item	2800893	et	4	main
külastage	doc_670731433472_item	2800922	et	3	main
virtuaalkodu	doc_670731433472_item	2800924	et	4	main
või	doc_670731433472_item	2800925	et	4	main
postitage	doc_670731433472_item	2800926	et	3	main
kupong	doc_670731433472_item	2800927	et	3	main
c	doc_670731433472_item	2800933	et	4	main
soovitad	doc_670731433472_item	2800934	et	3	main
just	doc_670731433472_item	2800939	et	3	main
a	doc_670731433472_item	2800947	et	4	main
c	doc_670731433472_item	2800971	et	4	main
kokku	doc_670731433472_item	2800972	et	3	main
hoida	doc_670731433472_item	2800973	et	3	main
d	doc_670731433472_item	2800974	et	4	main
kokku	doc_670731433472_item	2800975	et	3	main
d	doc_670731433472_item	2800993	et	4	main
ees	doc_670731433472_item	2800994	et	4	main
c	doc_670731433472_item	2801009	et	4	main
b	doc_670731433472_item	2801016	et	4	main
käige	doc_670731433472_item	2801017	et	3	main
punkti	doc_670731433473_item	2801033	et	4	main
maailmakuulsad	doc_670731433473_item	2801034	et	3	main
balletitantsijad	doc_670731433473_item	2801035	et	3	main
on	doc_670731433473_item	2801042	et	4	main
london	doc_670731433473_item	2801050	et	4	main
vabakutseline	doc_670731433473_item	2801073	et	4	main
esinevad	doc_670731433473_item	2801076	et	4	main
teatrid	doc_670731433473_item	2801078	et	3	main
väga	doc_670731433473_item	2801085	et	3	main
suhtuma	doc_670731433473_item	2801090	et	3	main
on	doc_670731433473_item	2801114	et	4	main
luikede	doc_670731433473_item	2801125	et	3	main
etendus	doc_670731433473_item	2801127	et	4	main
eemal	doc_670731433473_item	2801136	et	3	main
olema	doc_670731433473_item	2801137	et	4	main
olla	doc_670731433473_item	2801138	et	3	main
ainult	doc_670731433473_item	2801146	et	4	main
teineteisega	doc_670731433473_item	2801147	et	3	main
pakkumisi	doc_670731433473_item	2801154	et	4	main
ka	doc_670731433473_item	2801155	et	3	main
esinemised	doc_670731433473_item	2801167	et	4	main
päev	doc_670731433473_item	2801211	et	3	main
alt	doc_670731433473_item	2801220	et	4	main
iga	doc_670731433473_item	2801221	et	4	main
vastus	doc_670731433473_item	2801223	et	3	main
umbne	doc_670731433473_item	2801232	et	3	main
klassiruum	doc_670731433473_item	2801233	et	3	main
võimaldab	doc_670731433473_item	2801235	et	3	main
saada	doc_670731433473_item	2801237	et	4	main
parasjagu	doc_670731433473_item	2801247	et	3	main
on	doc_670731433473_item	2801250	et	4	main
interaktiivse	doc_670731433473_item	2801251	et	3	main
õppe	doc_670731433473_item	2801252	et	4	main
aega	doc_670731433473_item	2801260	et	4	main
ning	doc_670731433473_item	2801261	et	3	main
eelise	doc_670731433473_item	2801262	et	4	main
omandada	doc_670731433473_item	2801263	et	3	main
4	doc_670731433473_item	2801267	et	2	main
tarkust	doc_670731433473_item	2801281	et	4	main
pidis	doc_670731433472_item	2800721	et	4	main
on	doc_670731433472_item	2800731	et	4	main
nendel	doc_670731433472_item	2800740	et	4	main
on	doc_670731433472_item	2800741	et	4	main
edule	doc_670731433472_item	2800749	et	3	main
tagasihoidlik	doc_670731433472_item	2800752	et	3	main
lähiaja	doc_670731433472_item	2800755	et	3	main
esinemised	doc_670731433472_item	2800756	et	4	main
on	doc_670731433472_item	2800757	et	4	main
täpselt	doc_670731433472_item	2800758	et	4	main
planeerima	doc_670731433472_item	2800759	et	3	main
planeeritatakse	doc_670731433472_item	2800760	et	4	main
age	doc_670731433472_item	2800761	et	4	main
ja	doc_670731433472_item	2800762	et	3	main
toomas	doc_670731433472_item	2800763	et	3	main
tahavad	doc_670731433472_item	2800764	et	3	main
parem	doc_670731433472_item	2800768	et	4	main
lõuna-aafrikasse	doc_670731433472_item	2800781	et	4	main
oks	doc_670731433472_item	2800784	et	3	main
tipus	doc_670731433472_item	2800788	et	3	main
ei	doc_670731433472_item	2800791	et	4	main
nad	doc_670731433472_item	2800793	et	3	main
päeva	doc_670731433472_item	2800802	et	4	main
sobiv	doc_670731433472_item	2800806	et	4	main
annab	doc_670731433472_item	2800813	et	3	main
umbne	doc_670731433472_item	2800821	et	3	main
saada	doc_670731433472_item	2800826	et	4	main
just	doc_670731433472_item	2800829	et	3	main
ja	doc_670731433472_item	2800832	et	3	main
millal	doc_670731433472_item	2800833	et	3	main
sa	doc_670731433472_item	2800834	et	3	main
seda	doc_670731433472_item	2800835	et	3	main
parasjagu	doc_670731433472_item	2800836	et	3	main
ajastu	doc_670731433472_item	2800842	et	4	main
mis	doc_670731433472_item	2800843	et	4	main
annab	doc_670731433472_item	2800844	et	3	main
sulle	doc_670731433472_item	2800845	et	3	main
3	doc_670731433472_item	2800846	et	2	main
vastavalt	doc_670731433472_item	2800854	et	4	main
individuaalsele	doc_670731433472_item	2800855	et	3	main
4	doc_670731433472_item	2800856	et	2	main
tasemele	doc_670731433472_item	2800857	et	3	main
ka	doc_670731433472_item	2800868	et	3	main
oled	doc_670731433472_item	2800872	et	3	main
ja	doc_670731433472_item	2800886	et	3	main
7	doc_670731433472_item	2800892	et	2	main
tagasi	doc_670731433472_item	2800901	et	3	main
b	doc_670731433472_item	2800931	et	4	main
soovid	doc_670731433472_item	2800932	et	4	main
a	doc_670731433472_item	2800938	et	4	main
4	doc_670731433472_item	2800955	et	2	main
tasule	doc_670731433472_item	2800957	et	3	main
kokku	doc_670731433472_item	2800969	et	3	main
liita	doc_670731433472_item	2800970	et	4	main
6	doc_670731433472_item	2800977	et	2	main
ning	doc_670731433472_item	2800979	et	3	main
c	doc_670731433472_item	2800982	et	4	main
kuid	doc_670731433472_item	2800983	et	4	main
ette	doc_670731433472_item	2800990	et	4	main
8	doc_670731433472_item	2800995	et	2	main
c	doc_670731433472_item	2801000	et	4	main
b	doc_670731433472_item	2801007	et	4	main
d	doc_670731433472_item	2801011	et	4	main
10	doc_670731433472_item	2801013	et	2	main
a	doc_670731433472_item	2801014	et	4	main
tulge	doc_670731433472_item	2801015	et	3	main
minge	doc_670731433472_item	2801021	et	3	main
avage	doc_670731433473_item	2801023	et	3	main
numbrid	doc_670731433473_item	2801025	et	3	main
sõnadega	doc_670731433473_item	2801027	et	3	main
õige	doc_670731433473_item	2801029	et	4	main
vastus	doc_670731433473_item	2801030	et	3	main
ühe	doc_670731433473_item	2801032	et	4	main
age	doc_670731433473_item	2801037	et	4	main
toomas	doc_670731433473_item	2801040	et	3	main
eesti	doc_670731433473_item	2801044	et	4	main
eestist	doc_670731433473_item	2801045	et	3	main
aga	doc_670731433473_item	2801046	et	3	main
inglismaal	doc_670731433473_item	2801051	et	4	main
londonis	doc_670731433473_item	2801052	et	4	main
age	doc_670731433473_item	2801053	et	4	main
alates	doc_670731433473_item	2801065	et	3	main
1997a	doc_670731433473_item	2801066	et	4	main
üheksakümne	doc_670731433473_item	2801069	et	4	main
armastavad	doc_670731433473_item	2801083	et	4	main
neid	doc_670731433473_item	2801084	et	4	main
ning	doc_670731433473_item	2801086	et	3	main
suhtuda	doc_670731433473_item	2801091	et	3	main
üldiselt	doc_670731433473_item	2801093	et	4	main
räägivad	doc_670731433473_item	2801097	et	3	main
alati	doc_670731433473_item	2801106	et	4	main
läinud	doc_670731433473_item	2801109	et	4	main
ja	doc_670731433473_item	2801111	et	3	main
murdma	doc_670731433473_item	2801121	et	3	main
järve	doc_670731433473_item	2801126	et	4	main
otsustanud	doc_670731433473_item	2801143	et	4	main
tantsima	doc_670731433473_item	2801144	et	3	main
tantsisid	doc_670731433473_item	2801145	et	4	main
tallinna	doc_670731433472_item	2800776	et	4	main
suudavad	doc_670731433472_item	2800789	et	3	main
lünka	doc_670731433472_item	2800805	et	4	main
teksti	doc_670731433472_item	2800808	et	4	main
alt	doc_670731433472_item	2800809	et	4	main
koduõppesüsteem	doc_670731433472_item	2800823	et	3	main
2	doc_670731433472_item	2800828	et	2	main
interaktiivse	doc_670731433472_item	2800840	et	3	main
õppe	doc_670731433472_item	2800841	et	4	main
on	doc_670731433472_item	2800859	et	4	main
raha	doc_670731433472_item	2800860	et	4	main
5	doc_670731433472_item	2800863	et	2	main
kokku	doc_670731433472_item	2800864	et	3	main
saada	doc_670731433472_item	2800865	et	4	main
kui	doc_670731433472_item	2800871	et	3	main
või	doc_670731433472_item	2800878	et	4	main
raamatu	doc_670731433472_item	2800885	et	4	main
kättesaamisel	doc_670731433472_item	2800896	et	4	main
saada	doc_670731433472_item	2800897	et	4	main
korral	doc_670731433472_item	2800912	et	4	main
10	doc_670731433472_item	2800921	et	2	main
sobid	doc_670731433472_item	2800930	et	4	main
2	doc_670731433472_item	2800937	et	2	main
seega	doc_670731433472_item	2800941	et	4	main
vajaduse	doc_670731433472_item	2800948	et	3	main
b	doc_670731433472_item	2800949	et	4	main
vabanduse	doc_670731433472_item	2800950	et	4	main
c	doc_670731433472_item	2800951	et	4	main
varanduse	doc_670731433472_item	2800952	et	3	main
d	doc_670731433472_item	2800953	et	4	main
a	doc_670731433472_item	2800956	et	4	main
a	doc_670731433472_item	2800978	et	4	main
b	doc_670731433472_item	2800980	et	4	main
vaid	doc_670731433472_item	2800981	et	3	main
taga	doc_670731433472_item	2800988	et	4	main
b	doc_670731433472_item	2800989	et	4	main
kirjutab	doc_670731433472_item	2800997	et	3	main
palub	doc_670731433472_item	2800999	et	3	main
parandab	doc_670731433472_item	2801001	et	3	main
d	doc_670731433472_item	2801002	et	4	main
muudab	doc_670731433472_item	2801003	et	3	main
9	doc_670731433472_item	2801004	et	2	main
a	doc_670731433472_item	2801005	et	4	main
c	doc_670731433472_item	2801018	et	4	main
külastage	doc_670731433472_item	2801019	et	3	main
d	doc_670731433472_item	2801020	et	4	main
klassiruum	doc_670731433472_item	2800822	et	3	main
võimaldab	doc_670731433472_item	2800824	et	3	main
vabaduse	doc_670731433472_item	2800847	et	4	main
planeerida	doc_670731433472_item	2800848	et	3	main
aega	doc_670731433472_item	2800849	et	4	main
ning	doc_670731433472_item	2800850	et	3	main
eelise	doc_670731433472_item	2800851	et	4	main
omandada	doc_670731433472_item	2800852	et	3	main
et	doc_670731433472_item	2800861	et	3	main
seda	doc_670731433472_item	2800862	et	3	main
pisut	doc_670731433472_item	2800869	et	3	main
registreerunud	doc_670731433472_item	2800874	et	4	main
meie	doc_670731433472_item	2800876	et	4	main
lähimast	doc_670731433472_item	2800879	et	4	main
postiasutusest	doc_670731433472_item	2800880	et	4	main
ning	doc_670731433472_item	2800889	et	3	main
kodutöö	doc_670731433472_item	2800890	et	4	main
kodutöö	doc_670731433472_item	2800899	et	4	main
õpetaja	doc_670731433472_item	2800902	et	4	main
vaatab	doc_670731433472_item	2800903	et	3	main
selle	doc_670731433472_item	2800904	et	4	main
üle	doc_670731433472_item	2800905	et	3	main
8	doc_670731433472_item	2800906	et	2	main
palub	doc_670731433472_item	2800907	et	3	main
vead	doc_670731433472_item	2800908	et	4	main
ning	doc_670731433472_item	2800909	et	3	main
vastab	doc_670731433472_item	2800910	et	3	main
vajaduse	doc_670731433472_item	2800911	et	3	main
ka	doc_670731433472_item	2800913	et	3	main
tekkinud	doc_670731433472_item	2800914	et	4	main
lisaküsimustele	doc_670731433472_item	2800915	et	4	main
kõik	doc_670731433472_item	2800916	et	4	main
geniaalne	doc_670731433472_item	2800917	et	3	main
on	doc_670731433472_item	2800918	et	4	main
9	doc_670731433472_item	2800919	et	2	main
lihtne	doc_670731433472_item	2800920	et	3	main
meie	doc_670731433472_item	2800923	et	4	main
1	doc_670731433472_item	2800928	et	2	main
a	doc_670731433472_item	2800929	et	4	main
d	doc_670731433472_item	2800935	et	4	main
solvud	doc_670731433472_item	2800936	et	3	main
b	doc_670731433472_item	2800940	et	4	main
c	doc_670731433472_item	2800942	et	4	main
kuigi	doc_670731433472_item	2800943	et	3	main
d	doc_670731433472_item	2800944	et	4	main
vabaduse	doc_670731433472_item	2800954	et	4	main
b	doc_670731433472_item	2800958	et	4	main
tasemele	doc_670731433472_item	2800959	et	3	main
c	doc_670731433472_item	2800960	et	4	main
tasakesi	doc_670731433472_item	2800961	et	3	main
d	doc_670731433472_item	2800962	et	4	main
tasakaalule	doc_670731433472_item	2800963	et	3	main
5	doc_670731433472_item	2800964	et	2	main
a	doc_670731433472_item	2800965	et	4	main
kokku	doc_670731433472_item	2800966	et	3	main
saada	doc_670731433472_item	2800967	et	4	main
b	doc_670731433472_item	2800968	et	4	main
panna	doc_670731433472_item	2800976	et	4	main
a	doc_670731433472_item	2800987	et	4	main
eest	doc_670731433472_item	2800992	et	4	main
a	doc_670731433472_item	2800996	et	4	main
b	doc_670731433472_item	2800998	et	4	main
liigne	doc_670731433472_item	2801006	et	3	main
iga	doc_670731433473_item	2801028	et	4	main
annab	doc_670731433473_item	2801031	et	3	main
ja	doc_670731433473_item	2801039	et	3	main
inglismaa	doc_670731433473_item	2801049	et	4	main
on	doc_670731433473_item	2801054	et	4	main
vabakutselised	doc_670731433473_item	2801074	et	4	main
erinevad	doc_670731433473_item	2801077	et	4	main
erinevades	doc_670731433473_item	2801079	et	4	main
teatrides	doc_670731433473_item	2801080	et	4	main
isegi	doc_670731433473_item	2801087	et	4	main
kuid	doc_670731433473_item	2801102	et	4	main
kõik	doc_670731433473_item	2801103	et	4	main
pole	doc_670731433473_item	2801104	et	3	main
kergelt	doc_670731433473_item	2801108	et	4	main
eriti	doc_670731433473_item	2801112	et	3	main
olnud	doc_670731433473_item	2801115	et	4	main
tervisega	doc_670731433473_item	2801118	et	3	main
harjutus	doc_670731433473_item	2801022	et	4	main
sulud	doc_670731433473_item	2801024	et	3	main
kirjutage	doc_670731433473_item	2801026	et	3	main
oks	doc_670731433473_item	2801038	et	3	main
edur	doc_670731433473_item	2801041	et	4	main
pärit	doc_670731433473_item	2801043	et	3	main
elavad	doc_670731433473_item	2801047	et	4	main
praegu	doc_670731433473_item	2801048	et	3	main
kolmekümne	doc_670731433473_item	2801056	et	4	main
ja	doc_670731433473_item	2801058	et	3	main
aastane	doc_670731433473_item	2801057	et	4	main
toomas	doc_670731433473_item	2801059	et	3	main
on	doc_670731433473_item	2801060	et	4	main
32	doc_670731433473_item	2801061	et	2	main
kolme	doc_670731433473_item	2801062	et	4	main
aastat	doc_670731433473_item	2801063	et	3	main
vana	doc_670731433473_item	2801064	et	4	main
tuhande	doc_670731433473_item	2801067	et	3	main
kriitikud	doc_670731433473_item	2801089	et	3	main
nendesse	doc_670731433473_item	2801092	et	4	main
hästi	doc_670731433473_item	2801094	et	3	main
viimased	doc_670731433473_item	2801095	et	3	main
artiklid	doc_670731433473_item	2801096	et	3	main
sugugi	doc_670731433473_item	2801105	et	4	main
probleeme	doc_670731433473_item	2801116	et	3	main
tervis	doc_670731433473_item	2801117	et	3	main
1990	doc_670731433473_item	2801119	et	2	main
aastal	doc_670731433473_item	2801120	et	3	main
murdis	doc_670731433473_item	2801122	et	3	main
mõnda	doc_670731433473_item	2801133	et	4	main
ja	doc_670731433473_item	2801140	et	3	main
toomas	doc_670731433473_item	2801141	et	3	main
on	doc_670731433473_item	2801142	et	4	main
eraldi	doc_670731433473_item	2801156	et	4	main
tantsijad	doc_670731433473_item	2801162	et	4	main
tagasihoidlik	doc_670731433473_item	2801163	et	3	main
täpselt	doc_670731433473_item	2801169	et	4	main
eelistavad	doc_670731433473_item	2801208	et	4	main
elada	doc_670731433473_item	2801209	et	3	main
üks	doc_670731433473_item	2801210	et	3	main
päeva	doc_670731433473_item	2801213	et	4	main
teksti	doc_670731433473_item	2801219	et	4	main
unusta	doc_670731433473_item	2801231	et	4	main
ajastu	doc_670731433473_item	2801253	et	4	main
teadmisi	doc_670731433473_item	2801264	et	4	main
on	doc_670731433473_item	2801270	et	4	main
et	doc_670731433473_item	2801272	et	3	main
on	doc_670731433473_item	2801277	et	4	main
kursusele	doc_670731433473_item	2801284	et	3	main
meie	doc_670731433473_item	2801287	et	4	main
lähimast	doc_670731433473_item	2801290	et	4	main
kuul	doc_670731433473_item	2801293	et	4	main
vajaduse	doc_670731433473_item	2801322	et	3	main
ka	doc_670731433473_item	2801324	et	3	main
10	doc_670731433473_item	2801332	et	2	main
tulge	doc_670731433473_item	2801333	et	3	main
kupong	doc_670731433473_item	2801338	et	3	main
sobid	doc_670731433473_item	2801341	et	4	main
vabanduse	doc_670731433473_item	2801361	et	4	main
vabaduse	doc_670731433473_item	2801365	et	4	main
a	doc_670731433473_item	2801367	et	4	main
tasule	doc_670731433473_item	2801368	et	3	main
b	doc_670731433473_item	2801369	et	4	main
tasemele	doc_670731433473_item	2801370	et	3	main
taga	doc_670731433473_item	2801399	et	4	main
c	doc_670731433473_item	2801402	et	4	main
a	doc_670731433473_item	2801407	et	4	main
a	doc_670731433473_item	2801425	et	4	main
d	doc_670731433473_item	2801431	et	4	main
minge	doc_670731433473_item	2801432	et	3	main
harjutus	doc_670731433474_item	2801433	et	4	main
avage	doc_670731433474_item	2801434	et	3	main
sulud	doc_670731433474_item	2801435	et	3	main
õige	doc_670731433474_item	2801440	et	4	main
edur	doc_670731433474_item	2801452	et	4	main
elavad	doc_670731433474_item	2801458	et	4	main
london	doc_670731433474_item	2801461	et	4	main
on	doc_670731433474_item	2801465	et	4	main
ja	doc_670731433474_item	2801469	et	3	main
toomas	doc_670731433474_item	2801470	et	3	main
esinevad	doc_670731433474_item	2801489	et	4	main
läinud	doc_670731433474_item	2801522	et	4	main
mõlemal	doc_670731433474_item	2801523	et	3	main
ja	doc_670731433474_item	2801524	et	3	main
olnud	doc_670731433474_item	2801528	et	4	main
tervis	doc_670731433474_item	2801530	et	3	main
murras	doc_670731433474_item	2801535	et	4	main
ja	doc_670731433474_item	2801543	et	3	main
mõnda	doc_670731433474_item	2801546	et	4	main
aega	doc_670731433474_item	2801547	et	4	main
olema	doc_670731433474_item	2801551	et	4	main
on	doc_670731433474_item	2801565	et	4	main
vaatamata	doc_670731433474_item	2801571	et	4	main
tallinn	doc_670731433474_item	2801599	et	4	main
seejärel	doc_670731433474_item	2801602	et	3	main
edur	doc_670731433474_item	2801610	et	4	main
suudavad	doc_670731433474_item	2801613	et	3	main
eelistavad	doc_670731433474_item	2801621	et	4	main
üks	doc_670731433474_item	2801623	et	3	main
noor	doc_670731433473_item	2801123	et	3	main
pidi	doc_670731433473_item	2801132	et	4	main
age	doc_670731433473_item	2801139	et	4	main
paaris	doc_670731433473_item	2801148	et	4	main
kuigi	doc_670731433473_item	2801149	et	3	main
nemad	doc_670731433473_item	2801150	et	3	main
nendele	doc_670731433473_item	2801151	et	4	main
tantsimiseks	doc_670731433473_item	2801157	et	4	main
tagasihoidlikult	doc_670731433473_item	2801164	et	4	main
planeerima	doc_670731433473_item	2801170	et	3	main
planeerimine	doc_670731433473_item	2801171	et	4	main
parem	doc_670731433473_item	2801179	et	4	main
paremeni	doc_670731433473_item	2801180	et	4	main
tantsida	doc_670731433473_item	2801181	et	3	main
märtsis	doc_670731433473_item	2801182	et	3	main
tulevad	doc_670731433473_item	2801183	et	4	main
nad	doc_670731433473_item	2801184	et	3	main
esinema	doc_670731433473_item	2801185	et	3	main
tallinn	doc_670731433473_item	2801186	et	4	main
tallinnasse	doc_670731433473_item	2801187	et	3	main
ja	doc_670731433473_item	2801188	et	3	main
seejärel	doc_670731433473_item	2801189	et	3	main
sõidavad	doc_670731433473_item	2801190	et	3	main
lõuna-aafrika	doc_670731433473_item	2801191	et	4	main
lõuna-aafrikasse	doc_670731433473_item	2801192	et	4	main
kui	doc_670731433473_item	2801193	et	3	main
kaua	doc_670731433473_item	2801194	et	3	main
oks	doc_670731433473_item	2801195	et	3	main
ja	doc_670731433473_item	2801196	et	3	main
edur	doc_670731433473_item	2801197	et	4	main
veel	doc_670731433473_item	2801198	et	4	main
tipus	doc_670731433473_item	2801199	et	3	main
suudavad	doc_670731433473_item	2801200	et	3	main
püsida	doc_670731433473_item	2801201	et	3	main
ei	doc_670731433473_item	2801202	et	4	main
oska	doc_670731433473_item	2801203	et	4	main
nad	doc_670731433473_item	2801204	et	3	main
ütlema	doc_670731433473_item	2801205	et	3	main
öelda	doc_670731433473_item	2801206	et	4	main
nad	doc_670731433473_item	2801207	et	3	main
ja	doc_670731433473_item	2801130	et	3	main
pidama	doc_670731433473_item	2801131	et	4	main
aega	doc_670731433473_item	2801134	et	4	main
tantsimisest	doc_670731433473_item	2801135	et	4	main
on	doc_670731433473_item	2801152	et	4	main
vaatamata	doc_670731433473_item	2801158	et	4	main
nende	doc_670731433473_item	2801165	et	4	main
lähiaja	doc_670731433473_item	2801166	et	3	main
age	doc_670731433473_item	2801172	et	4	main
ja	doc_670731433473_item	2801173	et	3	main
toomas	doc_670731433473_item	2801174	et	3	main
tahavad	doc_670731433473_item	2801175	et	3	main
areneda	doc_670731433473_item	2801176	et	3	main
ja	doc_670731433473_item	2801177	et	3	main
sõna	doc_670731433473_item	2801218	et	4	main
ühe	doc_670731433473_item	2801225	et	4	main
just	doc_670731433473_item	2801240	et	3	main
seal	doc_670731433473_item	2801241	et	4	main
kus	doc_670731433473_item	2801242	et	3	main
ja	doc_670731433473_item	2801243	et	3	main
millal	doc_670731433473_item	2801244	et	3	main
sa	doc_670731433473_item	2801245	et	3	main
seda	doc_670731433473_item	2801246	et	3	main
käes	doc_670731433473_item	2801249	et	4	main
planeerida	doc_670731433473_item	2801259	et	3	main
vastavalt	doc_670731433473_item	2801265	et	4	main
vaja	doc_670731433473_item	2801278	et	4	main
ka	doc_670731433473_item	2801279	et	3	main
pisut	doc_670731433473_item	2801280	et	3	main
kätte	doc_670731433473_item	2801294	et	4	main
raamatu	doc_670731433473_item	2801296	et	4	main
tehtud	doc_670731433473_item	2801153	et	4	main
suurele	doc_670731433473_item	2801159	et	4	main
edule	doc_670731433473_item	2801160	et	3	main
elavad	doc_670731433473_item	2801161	et	4	main
on	doc_670731433473_item	2801168	et	4	main
veelgi	doc_670731433473_item	2801178	et	4	main
lünka	doc_670731433473_item	2801216	et	4	main
sobiv	doc_670731433473_item	2801217	et	4	main
õige	doc_670731433473_item	2801222	et	4	main
annab	doc_670731433473_item	2801224	et	3	main
õpi	doc_670731433473_item	2801227	et	4	main
millal	doc_670731433473_item	2801228	et	3	main
koduõppesüsteem	doc_670731433473_item	2801234	et	3	main
soovid	doc_670731433473_item	2801248	et	4	main
vabaduse	doc_670731433473_item	2801258	et	4	main
individuaalsele	doc_670731433473_item	2801266	et	3	main
tasemele	doc_670731433473_item	2801268	et	3	main
raha	doc_670731433473_item	2801271	et	4	main
seda	doc_670731433473_item	2801273	et	3	main
kui	doc_670731433473_item	2801282	et	3	main
õppematerjalid	doc_670731433473_item	2801295	et	3	main
helikasseti	doc_670731433473_item	2801298	et	4	main
on	doc_670731433473_item	2801329	et	4	main
9	doc_670731433473_item	2801330	et	2	main
c	doc_670731433473_item	2801344	et	4	main
soovitad	doc_670731433473_item	2801345	et	3	main
c	doc_670731433473_item	2801353	et	4	main
kuigi	doc_670731433473_item	2801354	et	3	main
3	doc_670731433473_item	2801357	et	2	main
vajaduse	doc_670731433473_item	2801359	et	3	main
d	doc_670731433473_item	2801364	et	4	main
et	doc_670731433473_item	2801396	et	3	main
ees	doc_670731433473_item	2801405	et	4	main
8	doc_670731433473_item	2801406	et	2	main
9	doc_670731433473_item	2801415	et	2	main
libe	doc_670731433473_item	2801419	et	3	main
c	doc_670731433473_item	2801420	et	4	main
liikuv	doc_670731433473_item	2801421	et	4	main
tulge	doc_670731433473_item	2801426	et	3	main
käige	doc_670731433473_item	2801428	et	3	main
sõnadega	doc_670731433474_item	2801438	et	3	main
on	doc_670731433474_item	2801453	et	4	main
pärit	doc_670731433474_item	2801454	et	3	main
aga	doc_670731433474_item	2801457	et	3	main
30	doc_670731433474_item	2801466	et	2	main
on	doc_670731433474_item	2801471	et	4	main
kolmekümne	doc_670731433474_item	2801473	et	4	main
kahe	doc_670731433474_item	2801474	et	3	main
aastat	doc_670731433474_item	2801475	et	3	main
vana	doc_670731433474_item	2801476	et	4	main
alates	doc_670731433474_item	2801477	et	3	main
1997a	doc_670731433474_item	2801478	et	4	main
tuhande	doc_670731433474_item	2801479	et	3	main
seitsmest	doc_670731433474_item	2801482	et	4	main
on	doc_670731433474_item	2801484	et	4	main
nad	doc_670731433474_item	2801485	et	3	main
inglismaal	doc_670731433474_item	2801494	et	4	main
armastavad	doc_670731433474_item	2801496	et	4	main
kergelt	doc_670731433474_item	2801521	et	4	main
agel	doc_670731433474_item	2801526	et	4	main
1990	doc_670731433474_item	2801532	et	2	main
murdma	doc_670731433474_item	2801534	et	3	main
naine	doc_670731433474_item	2801537	et	3	main
luikede	doc_670731433474_item	2801538	et	3	main
tantsimisest	doc_670731433474_item	2801548	et	4	main
eemal	doc_670731433474_item	2801549	et	3	main
age	doc_670731433474_item	2801552	et	4	main
on	doc_670731433474_item	2801555	et	4	main
tantsima	doc_670731433474_item	2801557	et	3	main
tantsida	doc_670731433474_item	2801558	et	3	main
ainult	doc_670731433474_item	2801559	et	4	main
teineteisega	doc_670731433474_item	2801560	et	3	main
eraldi	doc_670731433474_item	2801569	et	4	main
paremeni	doc_670731433474_item	2801593	et	4	main
tantsida	doc_670731433474_item	2801594	et	3	main
märtsis	doc_670731433474_item	2801595	et	3	main
tulevad	doc_670731433474_item	2801596	et	4	main
nad	doc_670731433474_item	2801597	et	3	main
esinema	doc_670731433474_item	2801598	et	3	main
veel	doc_670731433474_item	2801611	et	4	main
ei	doc_670731433474_item	2801615	et	4	main
nad	doc_670731433474_item	2801617	et	3	main
ühe	doc_670731433473_item	2801212	et	4	main
kaupa	doc_670731433473_item	2801214	et	4	main
kirjutage	doc_670731433473_item	2801215	et	3	main
punkti	doc_670731433473_item	2801226	et	4	main
1	doc_670731433473_item	2801229	et	2	main
soovid	doc_670731433473_item	2801230	et	4	main
sul	doc_670731433473_item	2801236	et	3	main
targemaks	doc_670731433473_item	2801238	et	4	main
2	doc_670731433473_item	2801239	et	2	main
mis	doc_670731433473_item	2801254	et	4	main
annab	doc_670731433473_item	2801255	et	3	main
sulle	doc_670731433473_item	2801256	et	3	main
3	doc_670731433473_item	2801257	et	2	main
aeg	doc_670731433473_item	2801269	et	3	main
5	doc_670731433473_item	2801274	et	2	main
kokku	doc_670731433473_item	2801275	et	3	main
panna	doc_670731433473_item	2801276	et	4	main
oled	doc_670731433473_item	2801283	et	3	main
saad	doc_670731433473_item	2801286	et	4	main
kontorist	doc_670731433473_item	2801288	et	4	main
või	doc_670731433473_item	2801289	et	4	main
postiasutusest	doc_670731433473_item	2801291	et	4	main
ja	doc_670731433473_item	2801297	et	3	main
6	doc_670731433473_item	2801299	et	2	main
ning	doc_670731433473_item	2801300	et	3	main
kursuse	doc_670731433473_item	2801302	et	3	main
7	doc_670731433473_item	2801303	et	2	main
kodutöö	doc_670731433473_item	2801301	et	4	main
eest	doc_670731433473_item	2801304	et	4	main
tasud	doc_670731433473_item	2801305	et	4	main
selle	doc_670731433473_item	2801306	et	4	main
kättesaamisel	doc_670731433473_item	2801307	et	4	main
saada	doc_670731433473_item	2801308	et	4	main
täidetud	doc_670731433473_item	2801309	et	4	main
kodutöö	doc_670731433473_item	2801310	et	4	main
meile	doc_670731433473_item	2801311	et	4	main
tagasi	doc_670731433473_item	2801312	et	3	main
õpetaja	doc_670731433473_item	2801313	et	4	main
vaatab	doc_670731433473_item	2801314	et	3	main
selle	doc_670731433473_item	2801315	et	4	main
üle	doc_670731433473_item	2801316	et	3	main
8	doc_670731433473_item	2801317	et	2	main
parandab	doc_670731433473_item	2801318	et	3	main
vead	doc_670731433473_item	2801319	et	4	main
ning	doc_670731433473_item	2801320	et	3	main
vastab	doc_670731433473_item	2801321	et	3	main
lisaküsimustele	doc_670731433473_item	2801326	et	4	main
kõik	doc_670731433473_item	2801327	et	4	main
geniaalne	doc_670731433473_item	2801328	et	3	main
postitage	doc_670731433473_item	2801337	et	3	main
solvud	doc_670731433473_item	2801347	et	3	main
a	doc_670731433473_item	2801349	et	4	main
just	doc_670731433473_item	2801350	et	3	main
b	doc_670731433473_item	2801351	et	4	main
c	doc_670731433473_item	2801362	et	4	main
varanduse	doc_670731433473_item	2801363	et	3	main
4	doc_670731433473_item	2801366	et	2	main
a	doc_670731433473_item	2801398	et	4	main
b	doc_670731433473_item	2801409	et	4	main
palub	doc_670731433473_item	2801410	et	3	main
c	doc_670731433473_item	2801411	et	4	main
parandab	doc_670731433473_item	2801412	et	3	main
liigne	doc_670731433473_item	2801417	et	3	main
b	doc_670731433473_item	2801418	et	4	main
registreerunud	doc_670731433473_item	2801285	et	4	main
igal	doc_670731433473_item	2801292	et	3	main
korral	doc_670731433473_item	2801323	et	4	main
lihtne	doc_670731433473_item	2801331	et	3	main
meie	doc_670731433473_item	2801334	et	4	main
virtuaalkodu	doc_670731433473_item	2801335	et	4	main
1	doc_670731433473_item	2801339	et	2	main
d	doc_670731433473_item	2801346	et	4	main
2	doc_670731433473_item	2801348	et	2	main
d	doc_670731433473_item	2801355	et	4	main
c	doc_670731433473_item	2801371	et	4	main
b	doc_670731433473_item	2801400	et	4	main
eest	doc_670731433473_item	2801403	et	4	main
d	doc_670731433473_item	2801404	et	4	main
d	doc_670731433473_item	2801413	et	4	main
muudab	doc_670731433473_item	2801414	et	3	main
d	doc_670731433473_item	2801422	et	4	main
b	doc_670731433473_item	2801427	et	4	main
c	doc_670731433473_item	2801429	et	4	main
külastage	doc_670731433473_item	2801430	et	3	main
iga	doc_670731433474_item	2801439	et	4	main
ühe	doc_670731433474_item	2801443	et	4	main
balletitantsijad	doc_670731433474_item	2801446	et	3	main
eesti	doc_670731433474_item	2801455	et	4	main
eestis	doc_670731433474_item	2801456	et	3	main
inglismaa	doc_670731433474_item	2801460	et	4	main
inglismaal	doc_670731433474_item	2801462	et	4	main
londonis	doc_670731433474_item	2801463	et	4	main
üheksakümne	doc_670731433474_item	2801481	et	4	main
erinevad	doc_670731433474_item	2801490	et	4	main
teatrid	doc_670731433474_item	2801491	et	3	main
tekkinud	doc_670731433473_item	2801325	et	4	main
või	doc_670731433473_item	2801336	et	4	main
a	doc_670731433473_item	2801340	et	4	main
b	doc_670731433473_item	2801342	et	4	main
soovid	doc_670731433473_item	2801343	et	4	main
seega	doc_670731433473_item	2801352	et	4	main
siiski	doc_670731433473_item	2801356	et	4	main
a	doc_670731433473_item	2801358	et	4	main
b	doc_670731433473_item	2801360	et	4	main
tasakesi	doc_670731433473_item	2801372	et	3	main
d	doc_670731433473_item	2801373	et	4	main
tasakaalule	doc_670731433473_item	2801374	et	3	main
5	doc_670731433473_item	2801375	et	2	main
a	doc_670731433473_item	2801376	et	4	main
kokku	doc_670731433473_item	2801377	et	3	main
saada	doc_670731433473_item	2801378	et	4	main
b	doc_670731433473_item	2801379	et	4	main
kokku	doc_670731433473_item	2801380	et	3	main
liita	doc_670731433473_item	2801381	et	4	main
c	doc_670731433473_item	2801382	et	4	main
kokku	doc_670731433473_item	2801383	et	3	main
hoida	doc_670731433473_item	2801384	et	3	main
d	doc_670731433473_item	2801385	et	4	main
kokku	doc_670731433473_item	2801386	et	3	main
panna	doc_670731433473_item	2801387	et	4	main
6	doc_670731433473_item	2801388	et	2	main
a	doc_670731433473_item	2801389	et	4	main
ning	doc_670731433473_item	2801390	et	3	main
b	doc_670731433473_item	2801391	et	4	main
vaid	doc_670731433473_item	2801392	et	3	main
c	doc_670731433473_item	2801393	et	4	main
kuid	doc_670731433473_item	2801394	et	4	main
d	doc_670731433473_item	2801395	et	4	main
7	doc_670731433473_item	2801397	et	2	main
ette	doc_670731433473_item	2801401	et	4	main
kirjutab	doc_670731433473_item	2801408	et	3	main
a	doc_670731433473_item	2801416	et	4	main
10	doc_670731433473_item	2801424	et	2	main
kirjutage	doc_670731433474_item	2801437	et	3	main
annab	doc_670731433474_item	2801442	et	3	main
punkti	doc_670731433474_item	2801444	et	4	main
maailmakuulsad	doc_670731433474_item	2801445	et	3	main
praegu	doc_670731433474_item	2801459	et	3	main
kolmekümne	doc_670731433474_item	2801467	et	4	main
32	doc_670731433474_item	2801472	et	2	main
vabakutseline	doc_670731433474_item	2801486	et	4	main
erinevaid	doc_670731433474_item	2801492	et	4	main
karmid	doc_670731433474_item	2801501	et	4	main
on	doc_670731433474_item	2801527	et	4	main
tervisega	doc_670731433474_item	2801531	et	3	main
aastal	doc_670731433474_item	2801533	et	3	main
jalaluu	doc_670731433474_item	2801542	et	4	main
pidis	doc_670731433474_item	2801545	et	4	main
ja	doc_670731433474_item	2801553	et	3	main
tehtud	doc_670731433474_item	2801566	et	4	main
tallinnasse	doc_670731433474_item	2801600	et	3	main
ja	doc_670731433474_item	2801601	et	3	main
sõidavad	doc_670731433474_item	2801603	et	3	main
lõuna-aafrikasse	doc_670731433474_item	2801605	et	4	main
kui	doc_670731433474_item	2801606	et	3	main
kaua	doc_670731433474_item	2801607	et	3	main
oks	doc_670731433474_item	2801608	et	3	main
püsida	doc_670731433474_item	2801614	et	3	main
oska	doc_670731433474_item	2801616	et	4	main
elada	doc_670731433474_item	2801622	et	3	main
sõna	doc_670731433474_item	2801631	et	4	main
annab	doc_670731433474_item	2801637	et	3	main
soovid	doc_670731433474_item	2801643	et	4	main
unusta	doc_670731433474_item	2801644	et	4	main
võimaldab	doc_670731433474_item	2801648	et	3	main
sul	doc_670731433474_item	2801649	et	3	main
saada	doc_670731433474_item	2801650	et	4	main
sa	doc_670731433474_item	2801658	et	3	main
ajastu	doc_670731433474_item	2801666	et	4	main
mis	doc_670731433474_item	2801667	et	4	main
annab	doc_670731433474_item	2801668	et	3	main
sulle	doc_670731433474_item	2801669	et	3	main
eelise	doc_670731433474_item	2801675	et	4	main
liita	doc_670731433474_item	2801689	et	4	main
tarkust	doc_670731433474_item	2801694	et	4	main
vaid	doc_670731433474_item	2801713	et	3	main
vead	doc_670731433474_item	2801732	et	4	main
ning	doc_670731433474_item	2801733	et	3	main
vastab	doc_670731433474_item	2801734	et	3	main
vajaduse	doc_670731433474_item	2801735	et	3	main
korral	doc_670731433474_item	2801736	et	4	main
ka	doc_670731433474_item	2801737	et	3	main
on	doc_670731433474_item	2801742	et	4	main
kupong	doc_670731433474_item	2801751	et	3	main
c	doc_670731433474_item	2801757	et	4	main
soovitad	doc_670731433474_item	2801758	et	3	main
kuigi	doc_670731433474_item	2801767	et	3	main
b	doc_670731433474_item	2801773	et	4	main
eest	doc_670731433474_item	2801816	et	4	main
muudab	doc_670731433474_item	2801827	et	3	main
b	doc_670731433474_item	2801831	et	4	main
c	doc_670731433474_item	2801833	et	4	main
käige	doc_670731433474_item	2801841	et	3	main
minge	doc_670731433474_item	2801845	et	3	main
iga	doc_670731433475_item	2801852	et	4	main
vastus	doc_670731433475_item	2801854	et	3	main
annab	doc_670731433475_item	2801855	et	3	main
ühe	doc_670731433475_item	2801856	et	4	main
ja	doc_670731433475_item	2801863	et	3	main
on	doc_670731433475_item	2801866	et	4	main
inglismaal	doc_670731433475_item	2801875	et	4	main
kolmkümentkaks	doc_670731433475_item	2801886	et	4	main
vabakutselised	doc_670731433475_item	2801896	et	4	main
ülivõrdes	doc_670731433475_item	2801922	et	3	main
läinud	doc_670731433475_item	2801930	et	4	main
eriti	doc_670731433475_item	2801933	et	3	main
aastal	doc_670731433475_item	2801941	et	3	main
ainult	doc_670731433475_item	2801967	et	4	main
teineteisega	doc_670731433475_item	2801968	et	3	main
eraldi	doc_670731433475_item	2801977	et	4	main
lihtne	doc_670731433473_item	2801423	et	3	main
numbrid	doc_670731433474_item	2801436	et	3	main
vastus	doc_670731433474_item	2801441	et	3	main
abielupaar	doc_670731433474_item	2801447	et	4	main
age	doc_670731433474_item	2801448	et	4	main
oks	doc_670731433474_item	2801449	et	3	main
ja	doc_670731433474_item	2801450	et	3	main
toomas	doc_670731433474_item	2801451	et	3	main
age	doc_670731433474_item	2801464	et	4	main
aastane	doc_670731433474_item	2801468	et	4	main
üheksasaja	doc_670731433474_item	2801480	et	4	main
aastast	doc_670731433474_item	2801483	et	4	main
vabakutselised	doc_670731433474_item	2801487	et	4	main
ja	doc_670731433474_item	2801488	et	3	main
teatrid	doc_670731433474_item	2801493	et	3	main
armastama	doc_670731433474_item	2801495	et	3	main
neid	doc_670731433474_item	2801497	et	4	main
väga	doc_670731433474_item	2801498	et	3	main
ning	doc_670731433474_item	2801499	et	3	main
isegi	doc_670731433474_item	2801500	et	4	main
kriitikud	doc_670731433474_item	2801502	et	3	main
suhtuma	doc_670731433474_item	2801503	et	3	main
suhtuvad	doc_670731433474_item	2801504	et	4	main
nendesse	doc_670731433474_item	2801505	et	4	main
üldiselt	doc_670731433474_item	2801506	et	4	main
hästi	doc_670731433474_item	2801507	et	3	main
viimased	doc_670731433474_item	2801508	et	3	main
artiklid	doc_670731433474_item	2801509	et	3	main
räägivad	doc_670731433474_item	2801510	et	3	main
noored	doc_670731433474_item	2801511	et	3	main
noored	doc_670731433474_item	2801512	et	3	main
ainult	doc_670731433474_item	2801513	et	4	main
ülivõrdes	doc_670731433474_item	2801514	et	3	main
kuid	doc_670731433474_item	2801515	et	4	main
kõik	doc_670731433474_item	2801516	et	4	main
pole	doc_670731433474_item	2801517	et	3	main
sugugi	doc_670731433474_item	2801518	et	4	main
alati	doc_670731433474_item	2801519	et	4	main
nii	doc_670731433474_item	2801520	et	3	main
etenduse	doc_670731433474_item	2801541	et	4	main
toomas	doc_670731433474_item	2801554	et	3	main
pakkumisi	doc_670731433474_item	2801567	et	4	main
ka	doc_670731433474_item	2801568	et	3	main
parem	doc_670731433474_item	2801592	et	4	main
eriti	doc_670731433474_item	2801525	et	3	main
probleeme	doc_670731433474_item	2801529	et	3	main
noor	doc_670731433474_item	2801536	et	3	main
järve	doc_670731433474_item	2801539	et	4	main
etendus	doc_670731433474_item	2801540	et	4	main
pidama	doc_670731433474_item	2801544	et	4	main
olema	doc_670731433474_item	2801550	et	4	main
otsustanud	doc_670731433474_item	2801556	et	4	main
paaris	doc_670731433474_item	2801561	et	4	main
kuigi	doc_670731433474_item	2801562	et	3	main
nemad	doc_670731433474_item	2801563	et	3	main
nemad	doc_670731433474_item	2801564	et	3	main
tantsimiseks	doc_670731433474_item	2801570	et	4	main
suurele	doc_670731433474_item	2801572	et	4	main
edule	doc_670731433474_item	2801573	et	3	main
elavad	doc_670731433474_item	2801574	et	4	main
tantsijad	doc_670731433474_item	2801575	et	4	main
tagasihoidlik	doc_670731433474_item	2801576	et	3	main
tagasihoidlikult	doc_670731433474_item	2801577	et	4	main
nende	doc_670731433474_item	2801578	et	4	main
lähiaja	doc_670731433474_item	2801579	et	3	main
esinemised	doc_670731433474_item	2801580	et	4	main
on	doc_670731433474_item	2801581	et	4	main
täpselt	doc_670731433474_item	2801582	et	4	main
planeerima	doc_670731433474_item	2801583	et	3	main
planeerivad	doc_670731433474_item	2801584	et	4	main
age	doc_670731433474_item	2801585	et	4	main
ja	doc_670731433474_item	2801586	et	3	main
toomas	doc_670731433474_item	2801587	et	3	main
tahavad	doc_670731433474_item	2801588	et	3	main
areneda	doc_670731433474_item	2801589	et	3	main
ja	doc_670731433474_item	2801590	et	3	main
veelgi	doc_670731433474_item	2801591	et	4	main
lõuna-aafrika	doc_670731433474_item	2801604	et	4	main
ja	doc_670731433474_item	2801609	et	3	main
tipus	doc_670731433474_item	2801612	et	3	main
teksti	doc_670731433474_item	2801632	et	4	main
ühe	doc_670731433474_item	2801638	et	4	main
seal	doc_670731433474_item	2801654	et	4	main
kus	doc_670731433474_item	2801655	et	3	main
käes	doc_670731433474_item	2801662	et	4	main
õppe	doc_670731433474_item	2801665	et	4	main
aega	doc_670731433474_item	2801673	et	4	main
ning	doc_670731433474_item	2801674	et	3	main
vastavalt	doc_670731433474_item	2801678	et	4	main
4	doc_670731433474_item	2801680	et	2	main
tasemele	doc_670731433474_item	2801681	et	3	main
ka	doc_670731433474_item	2801692	et	3	main
või	doc_670731433474_item	2801702	et	4	main
raamatu	doc_670731433474_item	2801709	et	4	main
ja	doc_670731433474_item	2801710	et	3	main
kodutöö	doc_670731433474_item	2801714	et	4	main
saada	doc_670731433474_item	2801721	et	4	main
selle	doc_670731433474_item	2801728	et	4	main
8	doc_670731433474_item	2801730	et	2	main
kõik	doc_670731433474_item	2801740	et	4	main
geniaalne	doc_670731433474_item	2801741	et	3	main
10	doc_670731433474_item	2801745	et	2	main
1	doc_670731433474_item	2801752	et	2	main
a	doc_670731433474_item	2801753	et	4	main
soovid	doc_670731433474_item	2801756	et	4	main
seega	doc_670731433474_item	2801765	et	4	main
vabanduse	doc_670731433474_item	2801774	et	4	main
c	doc_670731433474_item	2801775	et	4	main
varanduse	doc_670731433474_item	2801776	et	3	main
d	doc_670731433474_item	2801817	et	4	main
kirjutab	doc_670731433474_item	2801821	et	3	main
9	doc_670731433474_item	2801828	et	2	main
a	doc_670731433474_item	2801838	et	4	main
b	doc_670731433474_item	2801840	et	4	main
avage	doc_670731433475_item	2801847	et	3	main
edur	doc_670731433475_item	2801865	et	4	main
praegu	doc_670731433475_item	2801872	et	3	main
inglismaa	doc_670731433475_item	2801873	et	4	main
32	doc_670731433475_item	2801885	et	2	main
vana	doc_670731433475_item	2801888	et	4	main
tuhadüheksasajaüheksakümne	doc_670731433475_item	2801891	et	4	main
vabakutseline	doc_670731433475_item	2801895	et	4	main
esinevad	doc_670731433475_item	2801898	et	4	main
teatrid	doc_670731433475_item	2801900	et	3	main
erinevad	doc_670731433475_item	2801901	et	4	main
ainult	doc_670731433475_item	2801921	et	4	main
kuid	doc_670731433475_item	2801923	et	4	main
kõik	doc_670731433475_item	2801924	et	4	main
pole	doc_670731433475_item	2801925	et	3	main
sugugi	doc_670731433475_item	2801926	et	4	main
mõlemal	doc_670731433475_item	2801931	et	3	main
tervisega	doc_670731433475_item	2801939	et	3	main
luikede	doc_670731433475_item	2801946	et	3	main
etendus	doc_670731433475_item	2801948	et	4	main
etenduse	doc_670731433475_item	2801949	et	4	main
tantsimisest	doc_670731433475_item	2801956	et	4	main
paaris	doc_670731433475_item	2801969	et	4	main
kuigi	doc_670731433475_item	2801970	et	3	main
pakkumisi	doc_670731433475_item	2801975	et	4	main
veelgi	doc_670731433475_item	2801999	et	4	main
parem	doc_670731433475_item	2802000	et	4	main
tulevad	doc_670731433475_item	2802004	et	4	main
tallinnasse	doc_670731433475_item	2802008	et	3	main
lõuna-aafrika	doc_670731433475_item	2802012	et	4	main
kirjutage	doc_670731433475_item	2802036	et	3	main
iga	doc_670731433475_item	2802042	et	4	main
õige	doc_670731433475_item	2802043	et	4	main
vastus	doc_670731433475_item	2802044	et	3	main
annab	doc_670731433475_item	2802045	et	3	main
ühe	doc_670731433475_item	2802046	et	4	main
umbne	doc_670731433475_item	2802053	et	3	main
võimaldab	doc_670731433475_item	2802056	et	3	main
sa	doc_670731433475_item	2802066	et	3	main
käes	doc_670731433475_item	2802070	et	4	main
postiasutusest	doc_670731433475_item	2802112	et	4	main
õppematerjalid	doc_670731433475_item	2802116	et	3	main
raamatu	doc_670731433475_item	2802117	et	4	main
ütlema	doc_670731433474_item	2801618	et	3	main
öelda	doc_670731433474_item	2801619	et	4	main
nad	doc_670731433474_item	2801620	et	3	main
lünka	doc_670731433474_item	2801629	et	4	main
iga	doc_670731433474_item	2801634	et	4	main
punkti	doc_670731433474_item	2801639	et	4	main
1	doc_670731433474_item	2801642	et	2	main
ja	doc_670731433474_item	2801656	et	3	main
vabaduse	doc_670731433474_item	2801671	et	4	main
on	doc_670731433474_item	2801690	et	4	main
kui	doc_670731433474_item	2801695	et	3	main
registreerunud	doc_670731433474_item	2801698	et	4	main
kontorist	doc_670731433474_item	2801701	et	4	main
igal	doc_670731433474_item	2801705	et	3	main
helikasseti	doc_670731433474_item	2801711	et	4	main
7	doc_670731433474_item	2801716	et	2	main
meile	doc_670731433474_item	2801724	et	4	main
tagasi	doc_670731433474_item	2801725	et	3	main
vaatab	doc_670731433474_item	2801727	et	3	main
üle	doc_670731433474_item	2801729	et	3	main
parandab	doc_670731433474_item	2801731	et	3	main
ligne	doc_670731433474_item	2801744	et	4	main
meie	doc_670731433474_item	2801747	et	4	main
virtuaalkodu	doc_670731433474_item	2801748	et	4	main
d	doc_670731433474_item	2801759	et	4	main
solvud	doc_670731433474_item	2801760	et	3	main
a	doc_670731433474_item	2801762	et	4	main
just	doc_670731433474_item	2801763	et	3	main
b	doc_670731433474_item	2801764	et	4	main
d	doc_670731433474_item	2801768	et	4	main
d	doc_670731433474_item	2801777	et	4	main
ees	doc_670731433474_item	2801818	et	4	main
8	doc_670731433474_item	2801819	et	2	main
b	doc_670731433474_item	2801822	et	4	main
c	doc_670731433474_item	2801824	et	4	main
parandab	doc_670731433474_item	2801825	et	3	main
liigne	doc_670731433474_item	2801830	et	3	main
sulud	doc_670731433475_item	2801848	et	3	main
numbrid	doc_670731433475_item	2801849	et	3	main
abielupaar	doc_670731433475_item	2801860	et	4	main
oks	doc_670731433475_item	2801862	et	3	main
pärit	doc_670731433475_item	2801867	et	3	main
aga	doc_670731433475_item	2801870	et	3	main
age	doc_670731433475_item	2801877	et	4	main
on	doc_670731433475_item	2801878	et	4	main
30	doc_670731433475_item	2801879	et	2	main
erinevad	doc_670731433475_item	2801899	et	4	main
kergelt	doc_670731433475_item	2801929	et	4	main
ja	doc_670731433475_item	2801932	et	3	main
agel	doc_670731433475_item	2801934	et	4	main
olnud	doc_670731433475_item	2801936	et	4	main
probleeme	doc_670731433475_item	2801937	et	3	main
noor	doc_670731433475_item	2801944	et	3	main
olema	doc_670731433475_item	2801958	et	4	main
ja	doc_670731433475_item	2801961	et	3	main
otsustanud	doc_670731433475_item	2801964	et	4	main
tantsima	doc_670731433475_item	2801965	et	3	main
tantsida	doc_670731433475_item	2801966	et	3	main
tehtud	doc_670731433475_item	2801974	et	4	main
tagasihoidlik	doc_670731433475_item	2801984	et	3	main
nende	doc_670731433475_item	2801986	et	4	main
planeerima	doc_670731433475_item	2801991	et	3	main
age	doc_670731433475_item	2801993	et	4	main
tahavad	doc_670731433475_item	2801996	et	3	main
areneda	doc_670731433475_item	2801997	et	3	main
ja	doc_670731433475_item	2801998	et	3	main
lõuna-aafrikasse	doc_670731433475_item	2802013	et	4	main
kui	doc_670731433475_item	2802014	et	3	main
kaua	doc_670731433475_item	2802015	et	3	main
oks	doc_670731433475_item	2802016	et	3	main
ja	doc_670731433475_item	2802017	et	3	main
edur	doc_670731433475_item	2802018	et	4	main
ühe	doc_670731433475_item	2802033	et	4	main
sobiv	doc_670731433475_item	2802038	et	4	main
teksti	doc_670731433475_item	2802040	et	4	main
punkti	doc_670731433475_item	2802047	et	4	main
õpi	doc_670731433475_item	2802048	et	4	main
millal	doc_670731433475_item	2802049	et	3	main
1	doc_670731433475_item	2802050	et	2	main
parasjagu	doc_670731433475_item	2802068	et	3	main
õppe	doc_670731433475_item	2802073	et	4	main
ajastu	doc_670731433475_item	2802074	et	4	main
sobiv	doc_670731433474_item	2801630	et	4	main
päev	doc_670731433474_item	2801624	et	3	main
ühe	doc_670731433474_item	2801625	et	4	main
päeva	doc_670731433474_item	2801626	et	4	main
kaupa	doc_670731433474_item	2801627	et	4	main
kirjutage	doc_670731433474_item	2801628	et	3	main
alt	doc_670731433474_item	2801633	et	4	main
õpi	doc_670731433474_item	2801640	et	4	main
millal	doc_670731433474_item	2801641	et	3	main
umbne	doc_670731433474_item	2801645	et	3	main
klassiruum	doc_670731433474_item	2801646	et	3	main
koduõppesüsteem	doc_670731433474_item	2801647	et	3	main
millal	doc_670731433474_item	2801657	et	3	main
soovid	doc_670731433474_item	2801661	et	4	main
on	doc_670731433474_item	2801663	et	4	main
interaktiivse	doc_670731433474_item	2801664	et	3	main
3	doc_670731433474_item	2801670	et	2	main
planeerida	doc_670731433474_item	2801672	et	3	main
omandada	doc_670731433474_item	2801676	et	3	main
teadmisi	doc_670731433474_item	2801677	et	4	main
individuaalsele	doc_670731433474_item	2801679	et	3	main
aeg	doc_670731433474_item	2801682	et	3	main
vaja	doc_670731433474_item	2801691	et	4	main
pisut	doc_670731433474_item	2801693	et	3	main
postiasutusest	doc_670731433474_item	2801704	et	4	main
kuul	doc_670731433474_item	2801706	et	4	main
kätte	doc_670731433474_item	2801707	et	4	main
õppematerjalid	doc_670731433474_item	2801708	et	3	main
kursuse	doc_670731433474_item	2801715	et	3	main
tasud	doc_670731433474_item	2801718	et	4	main
selle	doc_670731433474_item	2801719	et	4	main
kodutöö	doc_670731433474_item	2801723	et	4	main
õpetaja	doc_670731433474_item	2801726	et	4	main
9	doc_670731433474_item	2801743	et	2	main
postitage	doc_670731433474_item	2801750	et	3	main
c	doc_670731433474_item	2801766	et	4	main
3	doc_670731433474_item	2801770	et	2	main
vajaduse	doc_670731433474_item	2801772	et	3	main
4	doc_670731433474_item	2801779	et	2	main
a	doc_670731433474_item	2801780	et	4	main
tasule	doc_670731433474_item	2801781	et	3	main
c	doc_670731433474_item	2801815	et	4	main
palub	doc_670731433474_item	2801823	et	3	main
d	doc_670731433474_item	2801826	et	4	main
libe	doc_670731433474_item	2801832	et	3	main
liikuv	doc_670731433474_item	2801834	et	4	main
d	doc_670731433474_item	2801835	et	4	main
lihtne	doc_670731433474_item	2801836	et	3	main
10	doc_670731433474_item	2801837	et	2	main
harjutus	doc_670731433475_item	2801846	et	4	main
kirjutage	doc_670731433475_item	2801850	et	3	main
age	doc_670731433475_item	2801861	et	4	main
toomas	doc_670731433475_item	2801864	et	3	main
eestist	doc_670731433475_item	2801869	et	3	main
elavad	doc_670731433475_item	2801871	et	4	main
london	doc_670731433475_item	2801874	et	4	main
kolmekümne	doc_670731433475_item	2801880	et	4	main
aastane	doc_670731433475_item	2801881	et	4	main
ja	doc_670731433475_item	2801882	et	3	main
toomas	doc_670731433475_item	2801883	et	3	main
aastat	doc_670731433475_item	2801887	et	3	main
alates	doc_670731433475_item	2801889	et	3	main
1997a	doc_670731433475_item	2801890	et	4	main
seitsmendast	doc_670731433475_item	2801892	et	3	main
on	doc_670731433475_item	2801893	et	4	main
ja	doc_670731433475_item	2801897	et	3	main
alati	doc_670731433475_item	2801927	et	4	main
1990	doc_670731433475_item	2801940	et	2	main
murdma	doc_670731433475_item	2801942	et	3	main
eemal	doc_670731433475_item	2801957	et	3	main
age	doc_670731433475_item	2801960	et	4	main
neile	doc_670731433475_item	2801972	et	4	main
on	doc_670731433475_item	2801973	et	4	main
elavad	doc_670731433475_item	2801982	et	4	main
on	doc_670731433475_item	2801989	et	4	main
paremini	doc_670731433475_item	2802001	et	4	main
ja	doc_670731433475_item	2802009	et	3	main
ei	doc_670731433475_item	2802023	et	4	main
nad	doc_670731433475_item	2802025	et	3	main
kaupa	doc_670731433475_item	2802035	et	4	main
unusta	doc_670731433475_item	2802052	et	4	main
koduõppesüsteem	doc_670731433475_item	2802055	et	3	main
saada	doc_670731433475_item	2802058	et	4	main
õige	doc_670731433474_item	2801635	et	4	main
vastus	doc_670731433474_item	2801636	et	3	main
targemaks	doc_670731433474_item	2801651	et	4	main
2	doc_670731433474_item	2801652	et	2	main
kuigi	doc_670731433474_item	2801653	et	3	main
seda	doc_670731433474_item	2801659	et	3	main
parasjagu	doc_670731433474_item	2801660	et	3	main
on	doc_670731433474_item	2801683	et	4	main
raha	doc_670731433474_item	2801684	et	4	main
et	doc_670731433474_item	2801685	et	3	main
seda	doc_670731433474_item	2801686	et	3	main
5	doc_670731433474_item	2801687	et	2	main
kokku	doc_670731433474_item	2801688	et	3	main
oled	doc_670731433474_item	2801696	et	3	main
kursusele	doc_670731433474_item	2801697	et	3	main
saad	doc_670731433474_item	2801699	et	4	main
meie	doc_670731433474_item	2801700	et	4	main
lähimast	doc_670731433474_item	2801703	et	4	main
6	doc_670731433474_item	2801712	et	2	main
ees	doc_670731433474_item	2801717	et	4	main
kättesaamisel	doc_670731433474_item	2801720	et	4	main
täidetud	doc_670731433474_item	2801722	et	4	main
tekkinud	doc_670731433474_item	2801738	et	4	main
lisaküsimustele	doc_670731433474_item	2801739	et	4	main
külastage	doc_670731433474_item	2801746	et	3	main
või	doc_670731433474_item	2801749	et	4	main
sobid	doc_670731433474_item	2801754	et	4	main
b	doc_670731433474_item	2801755	et	4	main
2	doc_670731433474_item	2801761	et	2	main
siiski	doc_670731433474_item	2801769	et	4	main
a	doc_670731433474_item	2801771	et	4	main
vabaduse	doc_670731433474_item	2801778	et	4	main
b	doc_670731433474_item	2801782	et	4	main
tasemele	doc_670731433474_item	2801783	et	3	main
c	doc_670731433474_item	2801784	et	4	main
tasakesi	doc_670731433474_item	2801785	et	3	main
d	doc_670731433474_item	2801786	et	4	main
tasakaalule	doc_670731433474_item	2801787	et	3	main
5	doc_670731433474_item	2801788	et	2	main
a	doc_670731433474_item	2801789	et	4	main
kokku	doc_670731433474_item	2801790	et	3	main
saada	doc_670731433474_item	2801791	et	4	main
b	doc_670731433474_item	2801792	et	4	main
kokku	doc_670731433474_item	2801793	et	3	main
liita	doc_670731433474_item	2801794	et	4	main
kokku	doc_670731433474_item	2801796	et	3	main
c	doc_670731433474_item	2801795	et	4	main
hoida	doc_670731433474_item	2801797	et	3	main
d	doc_670731433474_item	2801798	et	4	main
kokku	doc_670731433474_item	2801799	et	3	main
panna	doc_670731433474_item	2801800	et	4	main
6	doc_670731433474_item	2801801	et	2	main
a	doc_670731433474_item	2801802	et	4	main
ning	doc_670731433474_item	2801803	et	3	main
b	doc_670731433474_item	2801804	et	4	main
vaid	doc_670731433474_item	2801805	et	3	main
c	doc_670731433474_item	2801806	et	4	main
kuid	doc_670731433474_item	2801807	et	4	main
et	doc_670731433474_item	2801809	et	3	main
d	doc_670731433474_item	2801808	et	4	main
7	doc_670731433474_item	2801810	et	2	main
a	doc_670731433474_item	2801811	et	4	main
taga	doc_670731433474_item	2801812	et	4	main
b	doc_670731433474_item	2801813	et	4	main
ette	doc_670731433474_item	2801814	et	4	main
a	doc_670731433474_item	2801820	et	4	main
a	doc_670731433474_item	2801829	et	4	main
tulge	doc_670731433474_item	2801839	et	3	main
c	doc_670731433474_item	2801842	et	4	main
külastage	doc_670731433474_item	2801843	et	3	main
d	doc_670731433474_item	2801844	et	4	main
sõnadega	doc_670731433475_item	2801851	et	3	main
õige	doc_670731433475_item	2801853	et	4	main
punkti	doc_670731433475_item	2801857	et	4	main
maailmakuulsad	doc_670731433475_item	2801858	et	3	main
balletitantsijad	doc_670731433475_item	2801859	et	3	main
eesti	doc_670731433475_item	2801868	et	4	main
londonis	doc_670731433475_item	2801876	et	4	main
on	doc_670731433475_item	2801884	et	4	main
nad	doc_670731433475_item	2801894	et	3	main
teatrid	doc_670731433475_item	2801902	et	3	main
inglismaal	doc_670731433475_item	2801903	et	4	main
armastama	doc_670731433475_item	2801904	et	3	main
armastavad	doc_670731433475_item	2801905	et	4	main
neid	doc_670731433475_item	2801906	et	4	main
väga	doc_670731433475_item	2801907	et	3	main
ning	doc_670731433475_item	2801908	et	3	main
isegi	doc_670731433475_item	2801909	et	4	main
karmid	doc_670731433475_item	2801910	et	4	main
kriitikud	doc_670731433475_item	2801911	et	3	main
suhtuma	doc_670731433475_item	2801912	et	3	main
suhtlema	doc_670731433475_item	2801913	et	3	main
nendesse	doc_670731433475_item	2801914	et	4	main
üldiselt	doc_670731433475_item	2801915	et	4	main
hästi	doc_670731433475_item	2801916	et	3	main
viimased	doc_670731433475_item	2801917	et	3	main
artiklid	doc_670731433475_item	2801918	et	3	main
räägivad	doc_670731433475_item	2801919	et	3	main
noored	doc_670731433475_item	2801920	et	3	main
nii	doc_670731433475_item	2801928	et	3	main
on	doc_670731433475_item	2801935	et	4	main
tervis	doc_670731433475_item	2801938	et	3	main
murdis	doc_670731433475_item	2801943	et	3	main
naine	doc_670731433475_item	2801945	et	3	main
järve	doc_670731433475_item	2801947	et	4	main
jalaluu	doc_670731433475_item	2801950	et	4	main
ja	doc_670731433475_item	2801951	et	3	main
pidama	doc_670731433475_item	2801952	et	4	main
pidada	doc_670731433475_item	2801953	et	4	main
mõnda	doc_670731433475_item	2801954	et	4	main
aega	doc_670731433475_item	2801955	et	4	main
olla	doc_670731433475_item	2801959	et	3	main
toomas	doc_670731433475_item	2801962	et	3	main
on	doc_670731433475_item	2801963	et	4	main
nemad	doc_670731433475_item	2801971	et	3	main
ka	doc_670731433475_item	2801976	et	3	main
tantsimiseks	doc_670731433475_item	2801978	et	4	main
tantsijad	doc_670731433475_item	2801983	et	4	main
tagashoidlikul	doc_670731433475_item	2801985	et	3	main
lähiaja	doc_670731433475_item	2801987	et	3	main
täpselt	doc_670731433475_item	2801990	et	4	main
planeeritud	doc_670731433475_item	2801992	et	4	main
ja	doc_670731433475_item	2801994	et	3	main
toomas	doc_670731433475_item	2801995	et	3	main
märtsis	doc_670731433475_item	2802003	et	3	main
esinema	doc_670731433475_item	2802006	et	3	main
tallinn	doc_670731433475_item	2802007	et	4	main
seejärel	doc_670731433475_item	2802010	et	3	main
sõidavad	doc_670731433475_item	2802011	et	3	main
vaatamata	doc_670731433475_item	2801979	et	4	main
suurele	doc_670731433475_item	2801980	et	4	main
edule	doc_670731433475_item	2801981	et	3	main
esinemised	doc_670731433475_item	2801988	et	4	main
tantsida	doc_670731433475_item	2802002	et	3	main
nad	doc_670731433475_item	2802005	et	3	main
veel	doc_670731433475_item	2802019	et	4	main
tipus	doc_670731433475_item	2802020	et	3	main
suudavad	doc_670731433475_item	2802021	et	3	main
ütlema	doc_670731433475_item	2802026	et	3	main
päeva	doc_670731433475_item	2802034	et	4	main
soovid	doc_670731433475_item	2802051	et	4	main
millal	doc_670731433475_item	2802065	et	3	main
vabaduse	doc_670731433475_item	2802079	et	4	main
planeerida	doc_670731433475_item	2802080	et	3	main
aega	doc_670731433475_item	2802081	et	4	main
ning	doc_670731433475_item	2802082	et	3	main
kuul	doc_670731433475_item	2802114	et	4	main
kätte	doc_670731433475_item	2802115	et	4	main
7	doc_670731433475_item	2802124	et	2	main
selle	doc_670731433475_item	2802127	et	4	main
saada	doc_670731433475_item	2802129	et	4	main
ka	doc_670731433475_item	2802145	et	3	main
tekkinud	doc_670731433475_item	2802146	et	4	main
9	doc_670731433475_item	2802151	et	2	main
a	doc_670731433475_item	2802161	et	4	main
a	doc_670731433475_item	2802170	et	4	main
c	doc_670731433475_item	2802174	et	4	main
d	doc_670731433475_item	2802176	et	4	main
c	doc_670731433475_item	2802183	et	4	main
varanduse	doc_670731433475_item	2802184	et	3	main
püsida	doc_670731433475_item	2802022	et	3	main
oska	doc_670731433475_item	2802024	et	4	main
öölda	doc_670731433475_item	2802027	et	4	main
nad	doc_670731433475_item	2802028	et	3	main
eelistavad	doc_670731433475_item	2802029	et	4	main
elada	doc_670731433475_item	2802030	et	3	main
üks	doc_670731433475_item	2802031	et	3	main
päev	doc_670731433475_item	2802032	et	3	main
lünka	doc_670731433475_item	2802037	et	4	main
sõna	doc_670731433475_item	2802039	et	4	main
alt	doc_670731433475_item	2802041	et	4	main
klassiruum	doc_670731433475_item	2802054	et	3	main
sul	doc_670731433475_item	2802057	et	3	main
seda	doc_670731433475_item	2802067	et	3	main
soovid	doc_670731433475_item	2802069	et	4	main
on	doc_670731433475_item	2802071	et	4	main
mis	doc_670731433475_item	2802075	et	4	main
eelise	doc_670731433475_item	2802083	et	4	main
omandada	doc_670731433475_item	2802084	et	3	main
teadmisi	doc_670731433475_item	2802085	et	4	main
vastavalt	doc_670731433475_item	2802086	et	4	main
individuaalsele	doc_670731433475_item	2802087	et	3	main
4	doc_670731433475_item	2802088	et	2	main
tasakesi	doc_670731433475_item	2802089	et	3	main
aeg	doc_670731433475_item	2802090	et	3	main
on	doc_670731433475_item	2802091	et	4	main
raha	doc_670731433475_item	2802092	et	4	main
et	doc_670731433475_item	2802093	et	3	main
seda	doc_670731433475_item	2802094	et	3	main
5	doc_670731433475_item	2802095	et	2	main
saada	doc_670731433475_item	2802097	et	4	main
on	doc_670731433475_item	2802098	et	4	main
vaja	doc_670731433475_item	2802099	et	4	main
ka	doc_670731433475_item	2802100	et	3	main
kokku	doc_670731433475_item	2802096	et	3	main
pisut	doc_670731433475_item	2802101	et	3	main
tarkust	doc_670731433475_item	2802102	et	4	main
kui	doc_670731433475_item	2802103	et	3	main
oled	doc_670731433475_item	2802104	et	3	main
kursusele	doc_670731433475_item	2802105	et	3	main
registreerunud	doc_670731433475_item	2802106	et	4	main
saad	doc_670731433475_item	2802107	et	4	main
meie	doc_670731433475_item	2802108	et	4	main
kontorist	doc_670731433475_item	2802109	et	4	main
targemaks	doc_670731433475_item	2802059	et	4	main
2	doc_670731433475_item	2802060	et	2	main
just	doc_670731433475_item	2802061	et	3	main
seal	doc_670731433475_item	2802062	et	4	main
kus	doc_670731433475_item	2802063	et	3	main
ja	doc_670731433475_item	2802064	et	3	main
interaktiivse	doc_670731433475_item	2802072	et	3	main
lähimast	doc_670731433475_item	2802111	et	4	main
kursuse	doc_670731433475_item	2802123	et	3	main
täidetud	doc_670731433475_item	2802130	et	4	main
vead	doc_670731433475_item	2802140	et	4	main
ning	doc_670731433475_item	2802141	et	3	main
vastab	doc_670731433475_item	2802142	et	3	main
vajaduse	doc_670731433475_item	2802143	et	3	main
korral	doc_670731433475_item	2802144	et	4	main
on	doc_670731433475_item	2802150	et	4	main
külastage	doc_670731433475_item	2802154	et	3	main
sobid	doc_670731433475_item	2802162	et	4	main
soovid	doc_670731433475_item	2802164	et	4	main
c	doc_670731433475_item	2802165	et	4	main
soovitad	doc_670731433475_item	2802166	et	3	main
siiski	doc_670731433475_item	2802177	et	4	main
3	doc_670731433475_item	2802178	et	2	main
d	doc_670731433475_item	2802185	et	4	main
b	doc_670731433475_item	2802190	et	4	main
tasakaalule	doc_670731433475_item	2802195	et	3	main
a	doc_670731433475_item	2802197	et	4	main
kokku	doc_670731433475_item	2802198	et	3	main
ees	doc_670731433475_item	2802226	et	4	main
c	doc_670731433475_item	2802241	et	4	main
c	doc_670731433475_item	2802250	et	4	main
minge	doc_670731433475_item	2802253	et	3	main
avage	doc_670731433476_item	2802255	et	3	main
sulud	doc_670731433476_item	2802256	et	3	main
numbrid	doc_670731433476_item	2802257	et	3	main
kirjutage	doc_670731433476_item	2802258	et	3	main
sõnadega	doc_670731433476_item	2802259	et	3	main
iga	doc_670731433476_item	2802260	et	4	main
balletitantsijad	doc_670731433476_item	2802267	et	3	main
on	doc_670731433476_item	2802292	et	4	main
32	doc_670731433476_item	2802293	et	2	main
on	doc_670731433476_item	2802305	et	4	main
erinevades	doc_670731433476_item	2802313	et	4	main
teatris	doc_670731433476_item	2802314	et	3	main
armastama	doc_670731433476_item	2802316	et	3	main
armastavad	doc_670731433476_item	2802317	et	4	main
isegi	doc_670731433476_item	2802321	et	4	main
suhtuma	doc_670731433476_item	2802324	et	3	main
üldiselt	doc_670731433476_item	2802327	et	4	main
räägivad	doc_670731433476_item	2802331	et	3	main
agel	doc_670731433476_item	2802347	et	4	main
tervises	doc_670731433476_item	2802352	et	3	main
murdis	doc_670731433476_item	2802356	et	3	main
ja	doc_670731433476_item	2802364	et	3	main
aega	doc_670731433476_item	2802367	et	4	main
olema	doc_670731433476_item	2802370	et	4	main
oli	doc_670731433476_item	2802371	et	3	main
pakkumisi	doc_670731433476_item	2802387	et	4	main
ka	doc_670731433476_item	2802388	et	3	main
lähiaja	doc_670731433476_item	2802399	et	3	main
ja	doc_670731433476_item	2802421	et	3	main
veel	doc_670731433476_item	2802431	et	4	main
suudavad	doc_670731433476_item	2802433	et	3	main
eelistavad	doc_670731433476_item	2802441	et	4	main
ühe	doc_670731433476_item	2802445	et	4	main
päeva	doc_670731433476_item	2802446	et	4	main
kaupa	doc_670731433476_item	2802447	et	4	main
kirjutage	doc_670731433476_item	2802448	et	3	main
annab	doc_670731433476_item	2802457	et	3	main
soovid	doc_670731433476_item	2802463	et	4	main
umbne	doc_670731433476_item	2802465	et	3	main
klassiruum	doc_670731433476_item	2802466	et	3	main
sul	doc_670731433476_item	2802469	et	3	main
seda	doc_670731433476_item	2802479	et	3	main
soovid	doc_670731433476_item	2802481	et	4	main
mis	doc_670731433476_item	2802487	et	4	main
annab	doc_670731433476_item	2802488	et	3	main
sulle	doc_670731433476_item	2802489	et	3	main
vabaduse	doc_670731433476_item	2802491	et	4	main
planeerida	doc_670731433476_item	2802492	et	3	main
aega	doc_670731433476_item	2802493	et	4	main
annab	doc_670731433475_item	2802076	et	3	main
sulle	doc_670731433475_item	2802077	et	3	main
3	doc_670731433475_item	2802078	et	2	main
igal	doc_670731433475_item	2802113	et	3	main
eest	doc_670731433475_item	2802125	et	4	main
tasud	doc_670731433475_item	2802126	et	4	main
kättesaamisel	doc_670731433475_item	2802128	et	4	main
tagasi	doc_670731433475_item	2802133	et	3	main
õpetaja	doc_670731433475_item	2802134	et	4	main
vaatab	doc_670731433475_item	2802135	et	3	main
selle	doc_670731433475_item	2802136	et	4	main
üle	doc_670731433475_item	2802137	et	3	main
8	doc_670731433475_item	2802138	et	2	main
parandab	doc_670731433475_item	2802139	et	3	main
kõik	doc_670731433475_item	2802148	et	4	main
geniaalne	doc_670731433475_item	2802149	et	3	main
virtuaalkodu	doc_670731433475_item	2802156	et	4	main
1	doc_670731433475_item	2802160	et	2	main
b	doc_670731433475_item	2802163	et	4	main
just	doc_670731433475_item	2802171	et	3	main
a	doc_670731433475_item	2802179	et	4	main
vajaduse	doc_670731433475_item	2802180	et	3	main
a	doc_670731433475_item	2802188	et	4	main
b	doc_670731433475_item	2802221	et	4	main
c	doc_670731433475_item	2802223	et	4	main
eest	doc_670731433475_item	2802224	et	4	main
kirjutab	doc_670731433475_item	2802229	et	3	main
9	doc_670731433475_item	2802236	et	2	main
a	doc_670731433475_item	2802237	et	4	main
liigne	doc_670731433475_item	2802238	et	3	main
b	doc_670731433475_item	2802239	et	4	main
libe	doc_670731433475_item	2802240	et	3	main
b	doc_670731433475_item	2802248	et	4	main
ühe	doc_670731433476_item	2802264	et	4	main
oks	doc_670731433476_item	2802270	et	3	main
tuhande	doc_670731433476_item	2802300	et	3	main
erinevad	doc_670731433476_item	2802311	et	4	main
teatrid	doc_670731433476_item	2802312	et	3	main
ning	doc_670731433476_item	2802320	et	3	main
kõik	doc_670731433476_item	2802337	et	4	main
alati	doc_670731433476_item	2802340	et	4	main
probleeme	doc_670731433476_item	2802350	et	3	main
tervis	doc_670731433476_item	2802351	et	3	main
järve	doc_670731433476_item	2802360	et	4	main
age	doc_670731433476_item	2802372	et	4	main
ja	doc_670731433476_item	2802373	et	3	main
toomas	doc_670731433476_item	2802374	et	3	main
paaris	doc_670731433476_item	2802381	et	4	main
eraldi	doc_670731433476_item	2802389	et	4	main
tantsimiseks	doc_670731433476_item	2802390	et	4	main
vaatamata	doc_670731433476_item	2802391	et	4	main
seejärel	doc_670731433476_item	2802422	et	3	main
kui	doc_670731433476_item	2802426	et	3	main
oks	doc_670731433476_item	2802428	et	3	main
elada	doc_670731433476_item	2802442	et	3	main
üks	doc_670731433476_item	2802443	et	3	main
sobiv	doc_670731433476_item	2802450	et	4	main
õige	doc_670731433476_item	2802455	et	4	main
vastus	doc_670731433476_item	2802456	et	3	main
võimaldab	doc_670731433476_item	2802468	et	3	main
saada	doc_670731433476_item	2802470	et	4	main
targemaks	doc_670731433476_item	2802471	et	4	main
2	doc_670731433476_item	2802472	et	2	main
just	doc_670731433476_item	2802473	et	3	main
õppe	doc_670731433476_item	2802485	et	4	main
kättesaamisel	doc_670731433476_item	2802540	et	4	main
ning	doc_670731433476_item	2802553	et	3	main
on	doc_670731433476_item	2802562	et	4	main
9	doc_670731433476_item	2802563	et	2	main
10	doc_670731433476_item	2802565	et	2	main
külastage	doc_670731433476_item	2802566	et	3	main
1	doc_670731433476_item	2802572	et	2	main
seega	doc_670731433476_item	2802585	et	4	main
siiski	doc_670731433476_item	2802589	et	4	main
3	doc_670731433476_item	2802590	et	2	main
vabanduse	doc_670731433476_item	2802594	et	4	main
varanduse	doc_670731433476_item	2802596	et	3	main
või	doc_670731433475_item	2802110	et	4	main
ning	doc_670731433475_item	2802121	et	3	main
10	doc_670731433475_item	2802153	et	2	main
meie	doc_670731433475_item	2802155	et	4	main
või	doc_670731433475_item	2802157	et	4	main
postitage	doc_670731433475_item	2802158	et	3	main
kupong	doc_670731433475_item	2802159	et	3	main
b	doc_670731433475_item	2802172	et	4	main
seega	doc_670731433475_item	2802173	et	4	main
kuigi	doc_670731433475_item	2802175	et	3	main
vabaduse	doc_670731433475_item	2802186	et	4	main
4	doc_670731433475_item	2802187	et	2	main
tasemele	doc_670731433475_item	2802191	et	3	main
tasakesi	doc_670731433475_item	2802193	et	3	main
5	doc_670731433475_item	2802196	et	2	main
saada	doc_670731433475_item	2802199	et	4	main
d	doc_670731433475_item	2802225	et	4	main
palub	doc_670731433475_item	2802231	et	3	main
liikuv	doc_670731433475_item	2802242	et	4	main
d	doc_670731433475_item	2802243	et	4	main
lihtne	doc_670731433475_item	2802244	et	3	main
punkti	doc_670731433476_item	2802265	et	4	main
maailmakuulsad	doc_670731433476_item	2802266	et	3	main
kolmkümmend	doc_670731433476_item	2802294	et	4	main
üheksasaja	doc_670731433476_item	2802301	et	4	main
seitsmendal	doc_670731433476_item	2802303	et	3	main
aastal	doc_670731433476_item	2802304	et	3	main
vabakutseline	doc_670731433476_item	2802307	et	4	main
vabakutselised	doc_670731433476_item	2802308	et	4	main
ja	doc_670731433476_item	2802309	et	3	main
inglismaal	doc_670731433476_item	2802315	et	4	main
väga	doc_670731433476_item	2802319	et	3	main
karmid	doc_670731433476_item	2802322	et	4	main
nendesse	doc_670731433476_item	2802326	et	4	main
hästi	doc_670731433476_item	2802328	et	3	main
artiklid	doc_670731433476_item	2802330	et	3	main
noored	doc_670731433476_item	2802332	et	3	main
ainult	doc_670731433476_item	2802334	et	4	main
ülivõrdes	doc_670731433476_item	2802335	et	3	main
kuid	doc_670731433476_item	2802336	et	4	main
on	doc_670731433476_item	2802348	et	4	main
aastal	doc_670731433476_item	2802354	et	3	main
naine	doc_670731433476_item	2802358	et	3	main
etendus	doc_670731433476_item	2802361	et	4	main
jalaluu	doc_670731433476_item	2802363	et	4	main
otsustanud	doc_670731433476_item	2802376	et	4	main
tantsima	doc_670731433476_item	2802377	et	3	main
tantsida	doc_670731433476_item	2802378	et	3	main
ainult	doc_670731433476_item	2802379	et	4	main
teineteisega	doc_670731433476_item	2802380	et	3	main
tantsijad	doc_670731433476_item	2802395	et	4	main
tagasihoidlik	doc_670731433476_item	2802396	et	3	main
tagasihoidliku	doc_670731433476_item	2802397	et	3	main
lõuna-aafrika	doc_670731433476_item	2802424	et	4	main
kaua	doc_670731433476_item	2802427	et	3	main
ütelda	doc_670731433476_item	2802439	et	4	main
nad	doc_670731433476_item	2802440	et	3	main
lünka	doc_670731433476_item	2802449	et	4	main
iga	doc_670731433476_item	2802454	et	4	main
õpi	doc_670731433476_item	2802460	et	4	main
seal	doc_670731433476_item	2802474	et	4	main
kus	doc_670731433476_item	2802475	et	3	main
ja	doc_670731433476_item	2802476	et	3	main
millal	doc_670731433476_item	2802477	et	3	main
ajastu	doc_670731433476_item	2802486	et	4	main
3	doc_670731433476_item	2802490	et	2	main
või	doc_670731433476_item	2802522	et	4	main
raamatu	doc_670731433476_item	2802529	et	4	main
ja	doc_670731433476_item	2802530	et	3	main
helikasseti	doc_670731433476_item	2802531	et	4	main
6	doc_670731433476_item	2802532	et	2	main
7	doc_670731433476_item	2802536	et	2	main
tasud	doc_670731433476_item	2802538	et	4	main
selle	doc_670731433476_item	2802548	et	4	main
8	doc_670731433476_item	2802550	et	2	main
postitage	doc_670731433476_item	2802570	et	3	main
d	doc_670731433476_item	2802579	et	4	main
solvud	doc_670731433476_item	2802580	et	3	main
a	doc_670731433476_item	2802582	et	4	main
just	doc_670731433476_item	2802583	et	3	main
c	doc_670731433476_item	2802586	et	4	main
b	doc_670731433476_item	2802593	et	4	main
ja	doc_670731433475_item	2802118	et	3	main
helikasseti	doc_670731433475_item	2802119	et	4	main
6	doc_670731433475_item	2802120	et	2	main
kodutöö	doc_670731433475_item	2802122	et	4	main
kodutöö	doc_670731433475_item	2802131	et	4	main
meile	doc_670731433475_item	2802132	et	4	main
lisaküsimustele	doc_670731433475_item	2802147	et	4	main
lihtne	doc_670731433475_item	2802152	et	3	main
d	doc_670731433475_item	2802167	et	4	main
solvud	doc_670731433475_item	2802168	et	3	main
2	doc_670731433475_item	2802169	et	2	main
b	doc_670731433475_item	2802181	et	4	main
vabanduse	doc_670731433475_item	2802182	et	4	main
tasule	doc_670731433475_item	2802189	et	3	main
c	doc_670731433475_item	2802192	et	4	main
d	doc_670731433475_item	2802194	et	4	main
b	doc_670731433475_item	2802200	et	4	main
kokku	doc_670731433475_item	2802201	et	3	main
liita	doc_670731433475_item	2802202	et	4	main
c	doc_670731433475_item	2802203	et	4	main
kokku	doc_670731433475_item	2802204	et	3	main
hoida	doc_670731433475_item	2802205	et	3	main
d	doc_670731433475_item	2802206	et	4	main
kokku	doc_670731433475_item	2802207	et	3	main
panna	doc_670731433475_item	2802208	et	4	main
6	doc_670731433475_item	2802209	et	2	main
a	doc_670731433475_item	2802210	et	4	main
ning	doc_670731433475_item	2802211	et	3	main
b	doc_670731433475_item	2802212	et	4	main
vaid	doc_670731433475_item	2802213	et	3	main
c	doc_670731433475_item	2802214	et	4	main
kuid	doc_670731433475_item	2802215	et	4	main
d	doc_670731433475_item	2802216	et	4	main
et	doc_670731433475_item	2802217	et	3	main
7	doc_670731433475_item	2802218	et	2	main
a	doc_670731433475_item	2802219	et	4	main
taga	doc_670731433475_item	2802220	et	4	main
ette	doc_670731433475_item	2802222	et	4	main
8	doc_670731433475_item	2802227	et	2	main
a	doc_670731433475_item	2802228	et	4	main
c	doc_670731433475_item	2802232	et	4	main
parandab	doc_670731433475_item	2802233	et	3	main
muudab	doc_670731433475_item	2802235	et	3	main
käige	doc_670731433475_item	2802249	et	3	main
d	doc_670731433475_item	2802252	et	4	main
age	doc_670731433476_item	2802269	et	4	main
kaks	doc_670731433476_item	2802295	et	3	main
aastat	doc_670731433476_item	2802296	et	3	main
vana	doc_670731433476_item	2802297	et	4	main
alates	doc_670731433476_item	2802298	et	3	main
1997a	doc_670731433476_item	2802299	et	4	main
üheksakümne	doc_670731433476_item	2802302	et	4	main
nad	doc_670731433476_item	2802306	et	3	main
neid	doc_670731433476_item	2802318	et	4	main
suhtused	doc_670731433476_item	2802325	et	4	main
viimased	doc_670731433476_item	2802329	et	3	main
noortele	doc_670731433476_item	2802333	et	3	main
sugugi	doc_670731433476_item	2802339	et	4	main
nii	doc_670731433476_item	2802341	et	3	main
olnud	doc_670731433476_item	2802349	et	4	main
murdma	doc_670731433476_item	2802355	et	3	main
noor	doc_670731433476_item	2802357	et	3	main
luikede	doc_670731433476_item	2802359	et	3	main
etenduse	doc_670731433476_item	2802362	et	4	main
mõnda	doc_670731433476_item	2802366	et	4	main
b	doc_670731433475_item	2802230	et	4	main
d	doc_670731433475_item	2802234	et	4	main
10	doc_670731433475_item	2802245	et	2	main
a	doc_670731433475_item	2802246	et	4	main
tulge	doc_670731433475_item	2802247	et	3	main
külastage	doc_670731433475_item	2802251	et	3	main
harjutus	doc_670731433476_item	2802254	et	4	main
õige	doc_670731433476_item	2802261	et	4	main
vastus	doc_670731433476_item	2802262	et	3	main
annab	doc_670731433476_item	2802263	et	3	main
abielupaar	doc_670731433476_item	2802268	et	4	main
ja	doc_670731433476_item	2802271	et	3	main
toomas	doc_670731433476_item	2802272	et	3	main
edur	doc_670731433476_item	2802273	et	4	main
pärit	doc_670731433476_item	2802275	et	3	main
on	doc_670731433476_item	2802274	et	4	main
eesti	doc_670731433476_item	2802276	et	4	main
eestis	doc_670731433476_item	2802277	et	3	main
aga	doc_670731433476_item	2802278	et	3	main
elavad	doc_670731433476_item	2802279	et	4	main
praegu	doc_670731433476_item	2802280	et	3	main
inglismaa	doc_670731433476_item	2802281	et	4	main
london	doc_670731433476_item	2802282	et	4	main
inglismaas	doc_670731433476_item	2802283	et	3	main
londonnis	doc_670731433476_item	2802284	et	4	main
age	doc_670731433476_item	2802285	et	4	main
on	doc_670731433476_item	2802286	et	4	main
30	doc_670731433476_item	2802287	et	2	main
kolmekümne	doc_670731433476_item	2802288	et	4	main
aastane	doc_670731433476_item	2802289	et	4	main
ja	doc_670731433476_item	2802290	et	3	main
toomas	doc_670731433476_item	2802291	et	3	main
esinevad	doc_670731433476_item	2802310	et	4	main
kriitikud	doc_670731433476_item	2802323	et	3	main
pole	doc_670731433476_item	2802338	et	3	main
kergelt	doc_670731433476_item	2802342	et	4	main
läinud	doc_670731433476_item	2802343	et	4	main
mõlemal	doc_670731433476_item	2802344	et	3	main
ja	doc_670731433476_item	2802345	et	3	main
eriti	doc_670731433476_item	2802346	et	3	main
1990	doc_670731433476_item	2802353	et	2	main
pidama	doc_670731433476_item	2802365	et	4	main
tantsimisest	doc_670731433476_item	2802368	et	4	main
eemal	doc_670731433476_item	2802369	et	3	main
nendel	doc_670731433476_item	2802384	et	4	main
nende	doc_670731433476_item	2802398	et	4	main
on	doc_670731433476_item	2802401	et	4	main
täpselt	doc_670731433476_item	2802402	et	4	main
planeerima	doc_670731433476_item	2802403	et	3	main
planeeritud	doc_670731433476_item	2802404	et	4	main
age	doc_670731433476_item	2802405	et	4	main
ja	doc_670731433476_item	2802406	et	3	main
toomas	doc_670731433476_item	2802407	et	3	main
tahavad	doc_670731433476_item	2802408	et	3	main
areneda	doc_670731433476_item	2802409	et	3	main
ja	doc_670731433476_item	2802410	et	3	main
veelgi	doc_670731433476_item	2802411	et	4	main
parem	doc_670731433476_item	2802412	et	4	main
paremini	doc_670731433476_item	2802413	et	4	main
tantsida	doc_670731433476_item	2802414	et	3	main
märtsis	doc_670731433476_item	2802415	et	3	main
tulevad	doc_670731433476_item	2802416	et	4	main
nad	doc_670731433476_item	2802417	et	3	main
esinema	doc_670731433476_item	2802418	et	3	main
tallinn	doc_670731433476_item	2802419	et	4	main
tallinnas	doc_670731433476_item	2802420	et	4	main
sõidavad	doc_670731433476_item	2802423	et	3	main
ja	doc_670731433476_item	2802429	et	3	main
püsida	doc_670731433476_item	2802434	et	3	main
päev	doc_670731433476_item	2802444	et	3	main
sõna	doc_670731433476_item	2802451	et	4	main
punkti	doc_670731433476_item	2802459	et	4	main
1	doc_670731433476_item	2802462	et	2	main
sa	doc_670731433476_item	2802478	et	3	main
parasjagu	doc_670731433476_item	2802480	et	3	main
käes	doc_670731433476_item	2802482	et	4	main
on	doc_670731433476_item	2802483	et	4	main
interaktiivse	doc_670731433476_item	2802484	et	3	main
kontorist	doc_670731433476_item	2802521	et	4	main
lähimast	doc_670731433476_item	2802523	et	4	main
postiasutusest	doc_670731433476_item	2802524	et	4	main
igal	doc_670731433476_item	2802525	et	3	main
ning	doc_670731433476_item	2802533	et	3	main
ees	doc_670731433476_item	2802537	et	4	main
selle	doc_670731433476_item	2802539	et	4	main
meile	doc_670731433476_item	2802544	et	4	main
tagasi	doc_670731433476_item	2802545	et	3	main
vead	doc_670731433476_item	2802552	et	4	main
vajaduse	doc_670731433476_item	2802555	et	3	main
ka	doc_670731433476_item	2802557	et	3	main
liikuv	doc_670731433476_item	2802564	et	4	main
meie	doc_670731433476_item	2802567	et	4	main
virtuaalkodu	doc_670731433476_item	2802568	et	4	main
või	doc_670731433476_item	2802569	et	4	main
a	doc_670731433476_item	2802573	et	4	main
on	doc_670731433476_item	2802375	et	4	main
kuigi	doc_670731433476_item	2802382	et	3	main
nemad	doc_670731433476_item	2802383	et	3	main
on	doc_670731433476_item	2802385	et	4	main
tehtud	doc_670731433476_item	2802386	et	4	main
suurele	doc_670731433476_item	2802392	et	4	main
edule	doc_670731433476_item	2802393	et	3	main
elavad	doc_670731433476_item	2802394	et	4	main
esinemised	doc_670731433476_item	2802400	et	4	main
lõuna-aafrikas	doc_670731433476_item	2802425	et	4	main
edur	doc_670731433476_item	2802430	et	4	main
tipus	doc_670731433476_item	2802432	et	3	main
ei	doc_670731433476_item	2802435	et	4	main
oska	doc_670731433476_item	2802436	et	4	main
nad	doc_670731433476_item	2802437	et	3	main
ütlema	doc_670731433476_item	2802438	et	3	main
teksti	doc_670731433476_item	2802452	et	4	main
alt	doc_670731433476_item	2802453	et	4	main
ühe	doc_670731433476_item	2802458	et	4	main
millal	doc_670731433476_item	2802461	et	3	main
unusta	doc_670731433476_item	2802464	et	4	main
koduõppesüsteem	doc_670731433476_item	2802467	et	3	main
ning	doc_670731433476_item	2802494	et	3	main
eelise	doc_670731433476_item	2802495	et	4	main
omandada	doc_670731433476_item	2802496	et	3	main
teadmisi	doc_670731433476_item	2802497	et	4	main
individuaalsele	doc_670731433476_item	2802499	et	3	main
4	doc_670731433476_item	2802500	et	2	main
tasemele	doc_670731433476_item	2802501	et	3	main
aeg	doc_670731433476_item	2802502	et	3	main
vastavalt	doc_670731433476_item	2802498	et	4	main
on	doc_670731433476_item	2802503	et	4	main
raha	doc_670731433476_item	2802504	et	4	main
et	doc_670731433476_item	2802505	et	3	main
seda	doc_670731433476_item	2802506	et	3	main
5	doc_670731433476_item	2802507	et	2	main
kokku	doc_670731433476_item	2802508	et	3	main
saada	doc_670731433476_item	2802509	et	4	main
on	doc_670731433476_item	2802510	et	4	main
vaja	doc_670731433476_item	2802511	et	4	main
ka	doc_670731433476_item	2802512	et	3	main
pisut	doc_670731433476_item	2802513	et	3	main
tarkust	doc_670731433476_item	2802514	et	4	main
kui	doc_670731433476_item	2802515	et	3	main
oled	doc_670731433476_item	2802516	et	3	main
kursusele	doc_670731433476_item	2802517	et	3	main
registreerunud	doc_670731433476_item	2802518	et	4	main
saad	doc_670731433476_item	2802519	et	4	main
meie	doc_670731433476_item	2802520	et	4	main
kuul	doc_670731433476_item	2802526	et	4	main
kodutöö	doc_670731433476_item	2802534	et	4	main
saada	doc_670731433476_item	2802541	et	4	main
täidetud	doc_670731433476_item	2802542	et	4	main
kodutöö	doc_670731433476_item	2802543	et	4	main
vastab	doc_670731433476_item	2802554	et	3	main
lisaküsimustele	doc_670731433476_item	2802559	et	4	main
kõik	doc_670731433476_item	2802560	et	4	main
geniaalne	doc_670731433476_item	2802561	et	3	main
c	doc_670731433476_item	2802577	et	4	main
soovitad	doc_670731433476_item	2802578	et	3	main
a	doc_670731433476_item	2802591	et	4	main
vajaduse	doc_670731433476_item	2802592	et	3	main
4	doc_670731433476_item	2802599	et	2	main
a	doc_670731433476_item	2802600	et	4	main
kätte	doc_670731433476_item	2802527	et	4	main
õppematerjalid	doc_670731433476_item	2802528	et	3	main
kursuse	doc_670731433476_item	2802535	et	3	main
õpetaja	doc_670731433476_item	2802546	et	4	main
vaatab	doc_670731433476_item	2802547	et	3	main
üle	doc_670731433476_item	2802549	et	3	main
kirjutab	doc_670731433476_item	2802551	et	3	main
korral	doc_670731433476_item	2802556	et	4	main
tekkinud	doc_670731433476_item	2802558	et	4	main
kupong	doc_670731433476_item	2802571	et	3	main
sobid	doc_670731433476_item	2802574	et	4	main
2	doc_670731433476_item	2802581	et	2	main
c	doc_670731433476_item	2802595	et	4	main
c	doc_670731433476_item	2802604	et	4	main
tasakesi	doc_670731433476_item	2802605	et	3	main
d	doc_670731433476_item	2802606	et	4	main
tasakaalule	doc_670731433476_item	2802607	et	3	main
5	doc_670731433476_item	2802608	et	2	main
a	doc_670731433476_item	2802609	et	4	main
kokku	doc_670731433476_item	2802610	et	3	main
saada	doc_670731433476_item	2802611	et	4	main
b	doc_670731433476_item	2802612	et	4	main
kokku	doc_670731433476_item	2802613	et	3	main
liita	doc_670731433476_item	2802614	et	4	main
c	doc_670731433476_item	2802615	et	4	main
kokku	doc_670731433476_item	2802616	et	3	main
hoida	doc_670731433476_item	2802617	et	3	main
d	doc_670731433476_item	2802618	et	4	main
kokku	doc_670731433476_item	2802619	et	3	main
panna	doc_670731433476_item	2802620	et	4	main
a	doc_670731433476_item	2802622	et	4	main
c	doc_670731433476_item	2802626	et	4	main
ees	doc_670731433476_item	2802638	et	4	main
8	doc_670731433476_item	2802639	et	2	main
a	doc_670731433476_item	2802649	et	4	main
kirjutage	doc_670731433477_item	2802670	et	3	main
õige	doc_670731433477_item	2802673	et	4	main
edur	doc_670731433477_item	2802685	et	4	main
on	doc_670731433477_item	2802686	et	4	main
elavad	doc_670731433477_item	2802691	et	4	main
age	doc_670731433477_item	2802697	et	4	main
30	doc_670731433477_item	2802699	et	2	main
kolmküment	doc_670731433477_item	2802706	et	4	main
esinevad	doc_670731433477_item	2802721	et	4	main
ning	doc_670731433477_item	2802731	et	3	main
kergelt	doc_670731433477_item	2802753	et	4	main
olnud	doc_670731433477_item	2802760	et	4	main
1990	doc_670731433477_item	2802764	et	2	main
noor	doc_670731433477_item	2802768	et	3	main
etendus	doc_670731433477_item	2802772	et	4	main
jalaluu	doc_670731433477_item	2802774	et	4	main
ja	doc_670731433477_item	2802775	et	3	main
pidama	doc_670731433477_item	2802776	et	4	main
tallinnasse	doc_670731433477_item	2802832	et	3	main
kaua	doc_670731433477_item	2802839	et	3	main
oks	doc_670731433477_item	2802840	et	3	main
ja	doc_670731433477_item	2802841	et	3	main
edur	doc_670731433477_item	2802842	et	4	main
oska	doc_670731433477_item	2802848	et	4	main
kaupa	doc_670731433477_item	2802859	et	4	main
kirjutage	doc_670731433477_item	2802860	et	3	main
lünka	doc_670731433477_item	2802861	et	4	main
teksti	doc_670731433477_item	2802864	et	4	main
punkti	doc_670731433477_item	2802871	et	4	main
1	doc_670731433477_item	2802874	et	2	main
b	doc_670731433476_item	2802575	et	4	main
soovid	doc_670731433476_item	2802576	et	4	main
b	doc_670731433476_item	2802584	et	4	main
kuigi	doc_670731433476_item	2802587	et	3	main
d	doc_670731433476_item	2802588	et	4	main
d	doc_670731433476_item	2802597	et	4	main
tasule	doc_670731433476_item	2802601	et	3	main
b	doc_670731433476_item	2802624	et	4	main
taga	doc_670731433476_item	2802632	et	4	main
liigne	doc_670731433476_item	2802650	et	3	main
c	doc_670731433476_item	2802653	et	4	main
b	doc_670731433476_item	2802660	et	4	main
c	doc_670731433476_item	2802662	et	4	main
külastage	doc_670731433476_item	2802663	et	3	main
d	doc_670731433476_item	2802664	et	4	main
minge	doc_670731433476_item	2802665	et	3	main
sõnadega	doc_670731433477_item	2802671	et	3	main
age	doc_670731433477_item	2802681	et	4	main
oks	doc_670731433477_item	2802682	et	3	main
ja	doc_670731433477_item	2802683	et	3	main
toomas	doc_670731433477_item	2802684	et	3	main
eestist	doc_670731433477_item	2802689	et	3	main
praegu	doc_670731433477_item	2802692	et	3	main
kaks	doc_670731433477_item	2802707	et	3	main
erinevad	doc_670731433477_item	2802722	et	4	main
armastavad	doc_670731433477_item	2802728	et	4	main
neid	doc_670731433477_item	2802729	et	4	main
suhtuvad	doc_670731433477_item	2802736	et	4	main
kuid	doc_670731433477_item	2802747	et	4	main
agel	doc_670731433477_item	2802758	et	4	main
tantsimisest	doc_670731433477_item	2802780	et	4	main
olla	doc_670731433477_item	2802783	et	3	main
age	doc_670731433477_item	2802784	et	4	main
on	doc_670731433477_item	2802787	et	4	main
areneda	doc_670731433477_item	2802821	et	3	main
veelgi	doc_670731433477_item	2802823	et	4	main
esinema	doc_670731433477_item	2802830	et	3	main
ja	doc_670731433477_item	2802833	et	3	main
sõidavad	doc_670731433477_item	2802835	et	3	main
lõuna-afrikasse	doc_670731433477_item	2802837	et	4	main
üks	doc_670731433477_item	2802855	et	3	main
ühe	doc_670731433477_item	2802870	et	4	main
kus	doc_670731433477_item	2802887	et	3	main
parasjagu	doc_670731433477_item	2802892	et	3	main
käes	doc_670731433477_item	2802894	et	4	main
interaktiivse	doc_670731433477_item	2802896	et	3	main
õppe	doc_670731433477_item	2802897	et	4	main
3	doc_670731433477_item	2802902	et	2	main
aega	doc_670731433477_item	2802905	et	4	main
ning	doc_670731433477_item	2802906	et	3	main
vabaduse	doc_670731433476_item	2802598	et	4	main
b	doc_670731433476_item	2802602	et	4	main
6	doc_670731433476_item	2802621	et	2	main
b	doc_670731433476_item	2802633	et	4	main
eest	doc_670731433476_item	2802636	et	4	main
d	doc_670731433476_item	2802637	et	4	main
b	doc_670731433476_item	2802651	et	4	main
käige	doc_670731433476_item	2802661	et	3	main
abielupaar	doc_670731433477_item	2802680	et	4	main
aga	doc_670731433477_item	2802690	et	3	main
london	doc_670731433477_item	2802694	et	4	main
inglismaal	doc_670731433477_item	2802695	et	4	main
londonis	doc_670731433477_item	2802696	et	4	main
tasemele	doc_670731433476_item	2802603	et	3	main
d	doc_670731433476_item	2802628	et	4	main
et	doc_670731433476_item	2802629	et	3	main
7	doc_670731433476_item	2802630	et	2	main
a	doc_670731433476_item	2802631	et	4	main
a	doc_670731433476_item	2802640	et	4	main
kirjutab	doc_670731433476_item	2802641	et	3	main
b	doc_670731433476_item	2802642	et	4	main
palub	doc_670731433476_item	2802643	et	3	main
c	doc_670731433476_item	2802644	et	4	main
parandab	doc_670731433476_item	2802645	et	3	main
d	doc_670731433476_item	2802646	et	4	main
muudab	doc_670731433476_item	2802647	et	3	main
9	doc_670731433476_item	2802648	et	2	main
libe	doc_670731433476_item	2802652	et	3	main
liikuv	doc_670731433476_item	2802654	et	4	main
d	doc_670731433476_item	2802655	et	4	main
lihtne	doc_670731433476_item	2802656	et	3	main
10	doc_670731433476_item	2802657	et	2	main
harjutus	doc_670731433477_item	2802666	et	4	main
avage	doc_670731433477_item	2802667	et	3	main
numbrid	doc_670731433477_item	2802669	et	3	main
annab	doc_670731433477_item	2802675	et	3	main
ühe	doc_670731433477_item	2802676	et	4	main
eesti	doc_670731433477_item	2802688	et	4	main
on	doc_670731433477_item	2802698	et	4	main
kolmekümne	doc_670731433477_item	2802700	et	4	main
aastat	doc_670731433477_item	2802708	et	3	main
teatre	doc_670731433477_item	2802725	et	4	main
väga	doc_670731433477_item	2802730	et	3	main
kõik	doc_670731433477_item	2802748	et	4	main
pole	doc_670731433477_item	2802749	et	3	main
sugugi	doc_670731433477_item	2802750	et	4	main
on	doc_670731433477_item	2802759	et	4	main
muura	doc_670731433477_item	2802767	et	4	main
naine	doc_670731433477_item	2802769	et	3	main
pidi	doc_670731433477_item	2802777	et	4	main
mõnda	doc_670731433477_item	2802778	et	4	main
nad	doc_670731433477_item	2802829	et	3	main
ei	doc_670731433477_item	2802847	et	4	main
nad	doc_670731433477_item	2802852	et	3	main
päev	doc_670731433477_item	2802856	et	3	main
sobiv	doc_670731433477_item	2802862	et	4	main
alt	doc_670731433477_item	2802865	et	4	main
õige	doc_670731433477_item	2802867	et	4	main
vastus	doc_670731433477_item	2802868	et	3	main
annab	doc_670731433477_item	2802869	et	3	main
sul	doc_670731433477_item	2802881	et	3	main
seal	doc_670731433477_item	2802886	et	4	main
seda	doc_670731433477_item	2802891	et	3	main
on	doc_670731433477_item	2802895	et	4	main
ajastu	doc_670731433477_item	2802898	et	4	main
planeerida	doc_670731433477_item	2802904	et	3	main
kuul	doc_670731433477_item	2802938	et	4	main
kätte	doc_670731433477_item	2802939	et	4	main
õppematerjalid	doc_670731433477_item	2802940	et	3	main
ning	doc_670731433477_item	2802945	et	3	main
parandab	doc_670731433477_item	2802963	et	3	main
ning	doc_670731433477_item	2802965	et	3	main
vajaduse	doc_670731433477_item	2802967	et	3	main
virtuaalkodu	doc_670731433477_item	2802980	et	4	main
või	doc_670731433477_item	2802981	et	4	main
postitage	doc_670731433477_item	2802982	et	3	main
1	doc_670731433477_item	2802984	et	2	main
a	doc_670731433477_item	2802985	et	4	main
soovid	doc_670731433477_item	2802988	et	4	main
soovitad	doc_670731433477_item	2802990	et	3	main
2	doc_670731433477_item	2802993	et	2	main
a	doc_670731433477_item	2802994	et	4	main
just	doc_670731433477_item	2802995	et	3	main
a	doc_670731433477_item	2803012	et	4	main
tasule	doc_670731433477_item	2803013	et	3	main
a	doc_670731433477_item	2803021	et	4	main
saada	doc_670731433477_item	2803023	et	4	main
kokku	doc_670731433477_item	2803031	et	3	main
a	doc_670731433477_item	2803034	et	4	main
ning	doc_670731433477_item	2803035	et	3	main
b	doc_670731433477_item	2803036	et	4	main
vaid	doc_670731433477_item	2803037	et	3	main
et	doc_670731433477_item	2803041	et	3	main
d	doc_670731433477_item	2803049	et	4	main
ees	doc_670731433477_item	2803050	et	4	main
tulge	doc_670731433477_item	2803071	et	3	main
ning	doc_670731433476_item	2802623	et	3	main
vaid	doc_670731433476_item	2802625	et	3	main
kuid	doc_670731433476_item	2802627	et	4	main
ette	doc_670731433476_item	2802634	et	4	main
c	doc_670731433476_item	2802635	et	4	main
a	doc_670731433476_item	2802658	et	4	main
tulge	doc_670731433476_item	2802659	et	3	main
sulud	doc_670731433477_item	2802668	et	3	main
iga	doc_670731433477_item	2802672	et	4	main
vastus	doc_670731433477_item	2802674	et	3	main
punkti	doc_670731433477_item	2802677	et	4	main
maailmakuulsad	doc_670731433477_item	2802678	et	3	main
balletitantsijad	doc_670731433477_item	2802679	et	3	main
pärit	doc_670731433477_item	2802687	et	3	main
inglismaa	doc_670731433477_item	2802693	et	4	main
aastane	doc_670731433477_item	2802701	et	4	main
ja	doc_670731433477_item	2802702	et	3	main
toomas	doc_670731433477_item	2802703	et	3	main
on	doc_670731433477_item	2802704	et	4	main
32	doc_670731433477_item	2802705	et	2	main
vana	doc_670731433477_item	2802709	et	4	main
1997a	doc_670731433477_item	2802711	et	4	main
alates	doc_670731433477_item	2802710	et	3	main
tuhande	doc_670731433477_item	2802712	et	3	main
üheksasaja	doc_670731433477_item	2802713	et	4	main
üheksaküme	doc_670731433477_item	2802714	et	4	main
seitsmest	doc_670731433477_item	2802715	et	4	main
on	doc_670731433477_item	2802716	et	4	main
nad	doc_670731433477_item	2802717	et	3	main
vabakutseline	doc_670731433477_item	2802718	et	4	main
vabakutselised	doc_670731433477_item	2802719	et	4	main
ja	doc_670731433477_item	2802720	et	3	main
erinevaid	doc_670731433477_item	2802724	et	4	main
inglismaal	doc_670731433477_item	2802726	et	4	main
isegi	doc_670731433477_item	2802732	et	4	main
suhtuma	doc_670731433477_item	2802735	et	3	main
nendesse	doc_670731433477_item	2802737	et	4	main
üldiselt	doc_670731433477_item	2802738	et	4	main
hästi	doc_670731433477_item	2802739	et	3	main
viimased	doc_670731433477_item	2802740	et	3	main
artiklid	doc_670731433477_item	2802741	et	3	main
räägivad	doc_670731433477_item	2802742	et	3	main
noored	doc_670731433477_item	2802743	et	3	main
noorte	doc_670731433477_item	2802744	et	3	main
ainult	doc_670731433477_item	2802745	et	4	main
ülivõrdes	doc_670731433477_item	2802746	et	3	main
alati	doc_670731433477_item	2802751	et	4	main
nii	doc_670731433477_item	2802752	et	3	main
probleeme	doc_670731433477_item	2802761	et	3	main
tervis	doc_670731433477_item	2802762	et	3	main
tervisega	doc_670731433477_item	2802763	et	3	main
aastal	doc_670731433477_item	2802765	et	3	main
luikede	doc_670731433477_item	2802770	et	3	main
aega	doc_670731433477_item	2802779	et	4	main
toomas	doc_670731433477_item	2802786	et	3	main
otsustanud	doc_670731433477_item	2802788	et	4	main
tantsima	doc_670731433477_item	2802789	et	3	main
teatrid	doc_670731433477_item	2802723	et	3	main
armastama	doc_670731433477_item	2802727	et	3	main
karmid	doc_670731433477_item	2802733	et	4	main
kriitikud	doc_670731433477_item	2802734	et	3	main
läinud	doc_670731433477_item	2802754	et	4	main
mõlemal	doc_670731433477_item	2802755	et	3	main
ja	doc_670731433477_item	2802756	et	3	main
eriti	doc_670731433477_item	2802757	et	3	main
murdma	doc_670731433477_item	2802766	et	3	main
järve	doc_670731433477_item	2802771	et	4	main
etend	doc_670731433477_item	2802773	et	4	main
eemal	doc_670731433477_item	2802781	et	3	main
olema	doc_670731433477_item	2802782	et	4	main
ja	doc_670731433477_item	2802785	et	3	main
tantsida	doc_670731433477_item	2802790	et	3	main
ainult	doc_670731433477_item	2802791	et	4	main
teineteisega	doc_670731433477_item	2802792	et	3	main
paaris	doc_670731433477_item	2802793	et	4	main
kuigi	doc_670731433477_item	2802794	et	3	main
nemad	doc_670731433477_item	2802795	et	3	main
nendel	doc_670731433477_item	2802796	et	4	main
on	doc_670731433477_item	2802797	et	4	main
tehtud	doc_670731433477_item	2802798	et	4	main
pakkumisi	doc_670731433477_item	2802799	et	4	main
ka	doc_670731433477_item	2802800	et	3	main
eraldi	doc_670731433477_item	2802801	et	4	main
tantsimiseks	doc_670731433477_item	2802802	et	4	main
vaatamata	doc_670731433477_item	2802803	et	4	main
suurele	doc_670731433477_item	2802804	et	4	main
edule	doc_670731433477_item	2802805	et	3	main
elavad	doc_670731433477_item	2802806	et	4	main
tantsijad	doc_670731433477_item	2802807	et	4	main
tagasihoidlik	doc_670731433477_item	2802808	et	3	main
tagasihoidjad	doc_670731433477_item	2802809	et	3	main
nende	doc_670731433477_item	2802810	et	4	main
lähiaja	doc_670731433477_item	2802811	et	3	main
esinemised	doc_670731433477_item	2802812	et	4	main
on	doc_670731433477_item	2802813	et	4	main
täpselt	doc_670731433477_item	2802814	et	4	main
planeerima	doc_670731433477_item	2802815	et	3	main
planeeritud	doc_670731433477_item	2802816	et	4	main
ja	doc_670731433477_item	2802818	et	3	main
age	doc_670731433477_item	2802817	et	4	main
toomas	doc_670731433477_item	2802819	et	3	main
tahavad	doc_670731433477_item	2802820	et	3	main
parim	doc_670731433477_item	2802825	et	4	main
tulevad	doc_670731433477_item	2802828	et	4	main
lõuna-aafrika	doc_670731433477_item	2802836	et	4	main
kui	doc_670731433477_item	2802838	et	3	main
veel	doc_670731433477_item	2802843	et	4	main
ja	doc_670731433477_item	2802822	et	3	main
parem	doc_670731433477_item	2802824	et	4	main
tantsida	doc_670731433477_item	2802826	et	3	main
märtsis	doc_670731433477_item	2802827	et	3	main
tallinn	doc_670731433477_item	2802831	et	4	main
seejärel	doc_670731433477_item	2802834	et	3	main
ütlevad	doc_670731433477_item	2802851	et	4	main
sõna	doc_670731433477_item	2802863	et	4	main
õpi	doc_670731433477_item	2802872	et	4	main
millal	doc_670731433477_item	2802873	et	3	main
ja	doc_670731433477_item	2802888	et	3	main
soovid	doc_670731433477_item	2802893	et	4	main
eelise	doc_670731433477_item	2802907	et	4	main
omandada	doc_670731433477_item	2802908	et	3	main
teadmisi	doc_670731433477_item	2802909	et	4	main
on	doc_670731433477_item	2802915	et	4	main
raha	doc_670731433477_item	2802916	et	4	main
et	doc_670731433477_item	2802917	et	3	main
seda	doc_670731433477_item	2802918	et	3	main
5	doc_670731433477_item	2802919	et	2	main
kokku	doc_670731433477_item	2802920	et	3	main
ka	doc_670731433477_item	2802924	et	3	main
kui	doc_670731433477_item	2802927	et	3	main
kursusele	doc_670731433477_item	2802929	et	3	main
saad	doc_670731433477_item	2802931	et	4	main
ja	doc_670731433477_item	2802942	et	3	main
kättesaamisel	doc_670731433477_item	2802952	et	4	main
sobid	doc_670731433477_item	2802986	et	4	main
c	doc_670731433477_item	2802989	et	4	main
d	doc_670731433477_item	2802991	et	4	main
solvud	doc_670731433477_item	2802992	et	3	main
d	doc_670731433477_item	2803000	et	4	main
siiski	doc_670731433477_item	2803001	et	4	main
3	doc_670731433477_item	2803002	et	2	main
vabanduse	doc_670731433477_item	2803006	et	4	main
c	doc_670731433477_item	2803007	et	4	main
vabaduse	doc_670731433477_item	2803010	et	4	main
4	doc_670731433477_item	2803011	et	2	main
tipus	doc_670731433477_item	2802844	et	3	main
suudavad	doc_670731433477_item	2802845	et	3	main
püsida	doc_670731433477_item	2802846	et	3	main
nad	doc_670731433477_item	2802849	et	3	main
ütlema	doc_670731433477_item	2802850	et	3	main
eelistavad	doc_670731433477_item	2802853	et	4	main
elada	doc_670731433477_item	2802854	et	3	main
ühe	doc_670731433477_item	2802857	et	4	main
päeva	doc_670731433477_item	2802858	et	4	main
iga	doc_670731433477_item	2802866	et	4	main
saada	doc_670731433477_item	2802882	et	4	main
2	doc_670731433477_item	2802884	et	2	main
millal	doc_670731433477_item	2802889	et	3	main
vastavalt	doc_670731433477_item	2802910	et	4	main
4	doc_670731433477_item	2802912	et	2	main
tasemele	doc_670731433477_item	2802913	et	3	main
hoida	doc_670731433477_item	2802921	et	3	main
vaja	doc_670731433477_item	2802923	et	4	main
või	doc_670731433477_item	2802934	et	4	main
raamatu	doc_670731433477_item	2802941	et	4	main
7	doc_670731433477_item	2802948	et	2	main
tasud	doc_670731433477_item	2802950	et	4	main
selle	doc_670731433477_item	2802951	et	4	main
selle	doc_670731433477_item	2802960	et	4	main
vead	doc_670731433477_item	2802964	et	4	main
vastab	doc_670731433477_item	2802966	et	3	main
korral	doc_670731433477_item	2802968	et	4	main
kõik	doc_670731433477_item	2802972	et	4	main
geniaalne	doc_670731433477_item	2802973	et	3	main
on	doc_670731433477_item	2802974	et	4	main
9	doc_670731433477_item	2802975	et	2	main
lihtne	doc_670731433477_item	2802976	et	3	main
10	doc_670731433477_item	2802977	et	2	main
külastage	doc_670731433477_item	2802978	et	3	main
meie	doc_670731433477_item	2802979	et	4	main
seega	doc_670731433477_item	2802997	et	4	main
tasemele	doc_670731433477_item	2803015	et	3	main
c	doc_670731433477_item	2803016	et	4	main
tasakesi	doc_670731433477_item	2803017	et	3	main
d	doc_670731433477_item	2803018	et	4	main
tasakaalule	doc_670731433477_item	2803019	et	3	main
5	doc_670731433477_item	2803020	et	2	main
c	doc_670731433477_item	2803027	et	4	main
kuid	doc_670731433477_item	2803039	et	4	main
7	doc_670731433477_item	2803042	et	2	main
b	doc_670731433477_item	2803045	et	4	main
parandab	doc_670731433477_item	2803057	et	3	main
minge	doc_670731433477_item	2803077	et	3	main
numbrid	doc_670731433478_item	2803081	et	3	main
sõnadega	doc_670731433478_item	2803083	et	3	main
õige	doc_670731433478_item	2803085	et	4	main
vastus	doc_670731433478_item	2803086	et	3	main
on	doc_670731433478_item	2803098	et	4	main
pärit	doc_670731433478_item	2803099	et	3	main
eesti	doc_670731433478_item	2803100	et	4	main
eestist	doc_670731433478_item	2803101	et	3	main
aga	doc_670731433478_item	2803102	et	3	main
elavad	doc_670731433478_item	2803103	et	4	main
praegu	doc_670731433478_item	2803104	et	3	main
inglismaal	doc_670731433478_item	2803107	et	4	main
on	doc_670731433478_item	2803110	et	4	main
30	doc_670731433478_item	2803111	et	2	main
kaks	doc_670731433478_item	2803119	et	3	main
ühekümne	doc_670731433478_item	2803126	et	4	main
esinevad	doc_670731433478_item	2803134	et	4	main
erinevad	doc_670731433478_item	2803135	et	4	main
teatrid	doc_670731433478_item	2803136	et	3	main
armastatakse	doc_670731433478_item	2803141	et	3	main
ning	doc_670731433478_item	2803144	et	3	main
karmid	doc_670731433478_item	2803146	et	4	main
viimased	doc_670731433478_item	2803153	et	3	main
räägivad	doc_670731433478_item	2803155	et	3	main
nii	doc_670731433478_item	2803165	et	3	main
kergelt	doc_670731433478_item	2803166	et	4	main
ja	doc_670731433478_item	2803169	et	3	main
aega	doc_670731433478_item	2803192	et	4	main
tagasihoidlik	doc_670731433478_item	2803221	et	3	main
tallinnasse	doc_670731433478_item	2803245	et	3	main
kaua	doc_670731433478_item	2803252	et	3	main
oks	doc_670731433478_item	2803253	et	3	main
ütelda	doc_670731433478_item	2803264	et	4	main
ühe	doc_670731433478_item	2803270	et	4	main
solvud	doc_670731433477_item	2802875	et	3	main
unusta	doc_670731433477_item	2802876	et	4	main
umbne	doc_670731433477_item	2802877	et	3	main
klassiruum	doc_670731433477_item	2802878	et	3	main
koduõppesüsteem	doc_670731433477_item	2802879	et	3	main
võimaldab	doc_670731433477_item	2802880	et	3	main
targemaks	doc_670731433477_item	2802883	et	4	main
just	doc_670731433477_item	2802885	et	3	main
sa	doc_670731433477_item	2802890	et	3	main
mis	doc_670731433477_item	2802899	et	4	main
annab	doc_670731433477_item	2802900	et	3	main
sulle	doc_670731433477_item	2802901	et	3	main
vabaduse	doc_670731433477_item	2802903	et	4	main
individuaalsele	doc_670731433477_item	2802911	et	3	main
aeg	doc_670731433477_item	2802914	et	3	main
on	doc_670731433477_item	2802922	et	4	main
pisut	doc_670731433477_item	2802925	et	3	main
oled	doc_670731433477_item	2802928	et	3	main
registreerunud	doc_670731433477_item	2802930	et	4	main
meie	doc_670731433477_item	2802932	et	4	main
kontorist	doc_670731433477_item	2802933	et	4	main
helikasseti	doc_670731433477_item	2802943	et	4	main
kursuse	doc_670731433477_item	2802947	et	3	main
8	doc_670731433477_item	2802962	et	2	main
tekkinud	doc_670731433477_item	2802970	et	4	main
b	doc_670731433477_item	2802987	et	4	main
c	doc_670731433477_item	2802998	et	4	main
kuigi	doc_670731433477_item	2802999	et	3	main
b	doc_670731433477_item	2803005	et	4	main
varanduse	doc_670731433477_item	2803008	et	3	main
d	doc_670731433477_item	2803009	et	4	main
kokku	doc_670731433477_item	2803028	et	3	main
a	doc_670731433477_item	2803043	et	4	main
ette	doc_670731433477_item	2803046	et	4	main
eest	doc_670731433477_item	2803048	et	4	main
c	doc_670731433477_item	2803056	et	4	main
d	doc_670731433477_item	2803076	et	4	main
iga	doc_670731433478_item	2803084	et	4	main
annab	doc_670731433478_item	2803087	et	3	main
punkti	doc_670731433478_item	2803089	et	4	main
age	doc_670731433478_item	2803093	et	4	main
ja	doc_670731433478_item	2803095	et	3	main
toomas	doc_670731433478_item	2803096	et	3	main
edur	doc_670731433478_item	2803097	et	4	main
inglismaa	doc_670731433478_item	2803105	et	4	main
londonis	doc_670731433478_item	2803108	et	4	main
age	doc_670731433478_item	2803109	et	4	main
32	doc_670731433478_item	2803117	et	2	main
kolmkümmend	doc_670731433478_item	2803118	et	4	main
seitsmendalt	doc_670731433478_item	2803127	et	3	main
nad	doc_670731433478_item	2803130	et	3	main
vabakutselised	doc_670731433478_item	2803132	et	4	main
inglismaal	doc_670731433478_item	2803139	et	4	main
nendesse	doc_670731433478_item	2803150	et	4	main
artiklid	doc_670731433478_item	2803154	et	3	main
noortele	doc_670731433478_item	2803157	et	3	main
ainult	doc_670731433478_item	2803158	et	4	main
ülivõrdes	doc_670731433478_item	2803159	et	3	main
kuid	doc_670731433478_item	2803160	et	4	main
olnud	doc_670731433478_item	2803173	et	4	main
probleeme	doc_670731433478_item	2803174	et	3	main
tervis	doc_670731433478_item	2803175	et	3	main
tervisega	doc_670731433478_item	2803176	et	3	main
etendust	doc_670731433478_item	2803186	et	4	main
ja	doc_670731433478_item	2803188	et	3	main
tarkust	doc_670731433477_item	2802926	et	4	main
lähimast	doc_670731433477_item	2802935	et	4	main
postiasutusest	doc_670731433477_item	2802936	et	4	main
igal	doc_670731433477_item	2802937	et	3	main
6	doc_670731433477_item	2802944	et	2	main
kodutöö	doc_670731433477_item	2802946	et	4	main
eest	doc_670731433477_item	2802949	et	4	main
saada	doc_670731433477_item	2802953	et	4	main
täidetud	doc_670731433477_item	2802954	et	4	main
kodutöö	doc_670731433477_item	2802955	et	4	main
meile	doc_670731433477_item	2802956	et	4	main
tagasi	doc_670731433477_item	2802957	et	3	main
õpetaja	doc_670731433477_item	2802958	et	4	main
vaatab	doc_670731433477_item	2802959	et	3	main
üle	doc_670731433477_item	2802961	et	3	main
ka	doc_670731433477_item	2802969	et	3	main
lisaküsimustele	doc_670731433477_item	2802971	et	4	main
kupong	doc_670731433477_item	2802983	et	3	main
b	doc_670731433477_item	2802996	et	4	main
a	doc_670731433477_item	2803003	et	4	main
vajaduse	doc_670731433477_item	2803004	et	3	main
b	doc_670731433477_item	2803014	et	4	main
hoida	doc_670731433477_item	2803029	et	3	main
panna	doc_670731433477_item	2803032	et	4	main
c	doc_670731433477_item	2803038	et	4	main
taga	doc_670731433477_item	2803044	et	4	main
c	doc_670731433477_item	2803047	et	4	main
b	doc_670731433477_item	2803054	et	4	main
palub	doc_670731433477_item	2803055	et	3	main
muudab	doc_670731433477_item	2803059	et	3	main
b	doc_670731433477_item	2803072	et	4	main
käige	doc_670731433477_item	2803073	et	3	main
c	doc_670731433477_item	2803074	et	4	main
külastage	doc_670731433477_item	2803075	et	3	main
avage	doc_670731433478_item	2803079	et	3	main
sulud	doc_670731433478_item	2803080	et	3	main
kirjutage	doc_670731433478_item	2803082	et	3	main
ühe	doc_670731433478_item	2803088	et	4	main
london	doc_670731433478_item	2803106	et	4	main
ja	doc_670731433478_item	2803114	et	3	main
toomas	doc_670731433478_item	2803115	et	3	main
on	doc_670731433478_item	2803116	et	4	main
1997a	doc_670731433478_item	2803123	et	4	main
tuhande	doc_670731433478_item	2803124	et	3	main
üheksasaja	doc_670731433478_item	2803125	et	4	main
vabakutseline	doc_670731433478_item	2803131	et	4	main
ja	doc_670731433478_item	2803133	et	3	main
neid	doc_670731433478_item	2803142	et	4	main
väga	doc_670731433478_item	2803143	et	3	main
kõik	doc_670731433478_item	2803161	et	4	main
pole	doc_670731433478_item	2803162	et	3	main
läinud	doc_670731433478_item	2803167	et	4	main
mõlemal	doc_670731433478_item	2803168	et	3	main
agel	doc_670731433478_item	2803171	et	4	main
etendus	doc_670731433478_item	2803185	et	4	main
tantsimisest	doc_670731433478_item	2803193	et	4	main
eemal	doc_670731433478_item	2803194	et	3	main
olema	doc_670731433478_item	2803195	et	4	main
tagasihoidlikuks	doc_670731433478_item	2803222	et	3	main
veelgi	doc_670731433478_item	2803236	et	4	main
parem	doc_670731433478_item	2803237	et	4	main
esinema	doc_670731433478_item	2803243	et	3	main
ja	doc_670731433478_item	2803246	et	3	main
sõidavad	doc_670731433478_item	2803248	et	3	main
lõuna-aafrikale	doc_670731433478_item	2803250	et	4	main
kui	doc_670731433478_item	2803251	et	3	main
ja	doc_670731433478_item	2803254	et	3	main
ei	doc_670731433478_item	2803260	et	4	main
nad	doc_670731433478_item	2803265	et	3	main
iga	doc_670731433478_item	2803279	et	4	main
õige	doc_670731433478_item	2803280	et	4	main
vastus	doc_670731433478_item	2803281	et	3	main
seal	doc_670731433478_item	2803299	et	4	main
3	doc_670731433478_item	2803315	et	2	main
vabaduse	doc_670731433478_item	2803316	et	4	main
planeerida	doc_670731433478_item	2803317	et	3	main
aega	doc_670731433478_item	2803318	et	4	main
vastavalt	doc_670731433478_item	2803323	et	4	main
4	doc_670731433478_item	2803325	et	2	main
saada	doc_670731433478_item	2803334	et	4	main
vaja	doc_670731433478_item	2803336	et	4	main
kontorist	doc_670731433478_item	2803346	et	4	main
kättesaamisel	doc_670731433478_item	2803365	et	4	main
õpetaja	doc_670731433478_item	2803371	et	4	main
ning	doc_670731433478_item	2803378	et	3	main
meie	doc_670731433478_item	2803392	et	4	main
virtuaalkodu	doc_670731433478_item	2803393	et	4	main
või	doc_670731433478_item	2803394	et	4	main
postitage	doc_670731433478_item	2803395	et	3	main
b	doc_670731433478_item	2803427	et	4	main
c	doc_670731433478_item	2803429	et	4	main
b	doc_670731433478_item	2803437	et	4	main
c	doc_670731433478_item	2803440	et	4	main
d	doc_670731433478_item	2803443	et	4	main
b	doc_670731433478_item	2803449	et	4	main
kuid	doc_670731433478_item	2803452	et	4	main
kokku	doc_670731433477_item	2803022	et	3	main
b	doc_670731433477_item	2803024	et	4	main
kokku	doc_670731433477_item	2803025	et	3	main
liita	doc_670731433477_item	2803026	et	4	main
d	doc_670731433477_item	2803030	et	4	main
6	doc_670731433477_item	2803033	et	2	main
d	doc_670731433477_item	2803040	et	4	main
8	doc_670731433477_item	2803051	et	2	main
a	doc_670731433477_item	2803052	et	4	main
kirjutab	doc_670731433477_item	2803053	et	3	main
d	doc_670731433477_item	2803058	et	4	main
9	doc_670731433477_item	2803060	et	2	main
a	doc_670731433477_item	2803061	et	4	main
liigne	doc_670731433477_item	2803062	et	3	main
b	doc_670731433477_item	2803063	et	4	main
libe	doc_670731433477_item	2803064	et	3	main
c	doc_670731433477_item	2803065	et	4	main
liikuv	doc_670731433477_item	2803066	et	4	main
d	doc_670731433477_item	2803067	et	4	main
lihtne	doc_670731433477_item	2803068	et	3	main
10	doc_670731433477_item	2803069	et	2	main
a	doc_670731433477_item	2803070	et	4	main
oks	doc_670731433478_item	2803094	et	3	main
aastane	doc_670731433478_item	2803113	et	4	main
harjutus	doc_670731433478_item	2803078	et	4	main
maailmakuulsad	doc_670731433478_item	2803090	et	3	main
balletitantsijad	doc_670731433478_item	2803091	et	3	main
abielupaar	doc_670731433478_item	2803092	et	4	main
kolmekümne	doc_670731433478_item	2803112	et	4	main
aastat	doc_670731433478_item	2803120	et	3	main
vana	doc_670731433478_item	2803121	et	4	main
aastalt	doc_670731433478_item	2803128	et	3	main
erinevades	doc_670731433478_item	2803137	et	4	main
suhtuvad	doc_670731433478_item	2803149	et	4	main
üldiselt	doc_670731433478_item	2803151	et	4	main
hästi	doc_670731433478_item	2803152	et	3	main
noored	doc_670731433478_item	2803156	et	3	main
alati	doc_670731433478_item	2803164	et	4	main
on	doc_670731433478_item	2803172	et	4	main
1990	doc_670731433478_item	2803177	et	2	main
aastal	doc_670731433478_item	2803178	et	3	main
murdma	doc_670731433478_item	2803179	et	3	main
murdis	doc_670731433478_item	2803180	et	3	main
noor	doc_670731433478_item	2803181	et	3	main
naine	doc_670731433478_item	2803182	et	3	main
luikede	doc_670731433478_item	2803183	et	3	main
järve	doc_670731433478_item	2803184	et	4	main
pidi	doc_670731433478_item	2803190	et	4	main
mõnda	doc_670731433478_item	2803191	et	4	main
olla	doc_670731433478_item	2803196	et	3	main
nende	doc_670731433478_item	2803223	et	4	main
age	doc_670731433478_item	2803230	et	4	main
ja	doc_670731433478_item	2803231	et	3	main
toomas	doc_670731433478_item	2803232	et	3	main
tahavad	doc_670731433478_item	2803233	et	3	main
areneda	doc_670731433478_item	2803234	et	3	main
ja	doc_670731433478_item	2803235	et	3	main
nad	doc_670731433478_item	2803242	et	3	main
seejärel	doc_670731433478_item	2803247	et	3	main
suudavad	doc_670731433478_item	2803258	et	3	main
oska	doc_670731433478_item	2803261	et	4	main
ütlema	doc_670731433478_item	2803263	et	3	main
elada	doc_670731433478_item	2803267	et	3	main
päev	doc_670731433478_item	2803269	et	3	main
päeva	doc_670731433478_item	2803271	et	4	main
kaupa	doc_670731433478_item	2803272	et	4	main
kirjutage	doc_670731433478_item	2803273	et	3	main
alt	doc_670731433478_item	2803278	et	4	main
ühe	doc_670731433478_item	2803283	et	4	main
millal	doc_670731433478_item	2803286	et	3	main
targemaks	doc_670731433478_item	2803296	et	4	main
2	doc_670731433478_item	2803297	et	2	main
sa	doc_670731433478_item	2803303	et	3	main
ajastu	doc_670731433478_item	2803311	et	4	main
kokku	doc_670731433478_item	2803333	et	3	main
või	doc_670731433478_item	2803347	et	4	main
kätte	doc_670731433478_item	2803352	et	4	main
helikasseti	doc_670731433478_item	2803356	et	4	main
ning	doc_670731433478_item	2803358	et	3	main
saada	doc_670731433478_item	2803366	et	4	main
täidetud	doc_670731433478_item	2803367	et	4	main
üle	doc_670731433478_item	2803374	et	3	main
parandab	doc_670731433478_item	2803376	et	3	main
korral	doc_670731433478_item	2803381	et	4	main
tekkinud	doc_670731433478_item	2803383	et	4	main
lisaküsimustele	doc_670731433478_item	2803384	et	4	main
d	doc_670731433478_item	2803422	et	4	main
tasule	doc_670731433478_item	2803426	et	3	main
tasakaalule	doc_670731433478_item	2803432	et	3	main
kokku	doc_670731433478_item	2803438	et	3	main
ning	doc_670731433478_item	2803448	et	3	main
c	doc_670731433478_item	2803451	et	4	main
d	doc_670731433478_item	2803453	et	4	main
et	doc_670731433478_item	2803454	et	3	main
c	doc_670731433478_item	2803460	et	4	main
eest	doc_670731433478_item	2803461	et	4	main
c	doc_670731433478_item	2803478	et	4	main
10	doc_670731433478_item	2803482	et	2	main
tulge	doc_670731433478_item	2803484	et	3	main
c	doc_670731433478_item	2803487	et	4	main
külastage	doc_670731433478_item	2803488	et	3	main
on	doc_670731433479_item	2803523	et	4	main
toomas	doc_670731433479_item	2803528	et	3	main
1997a	doc_670731433479_item	2803536	et	4	main
tuhande	doc_670731433479_item	2803537	et	3	main
vabakutselised	doc_670731433479_item	2803544	et	4	main
alates	doc_670731433478_item	2803122	et	3	main
on	doc_670731433478_item	2803129	et	4	main
teatrides	doc_670731433478_item	2803138	et	4	main
armastama	doc_670731433478_item	2803140	et	3	main
isegi	doc_670731433478_item	2803145	et	4	main
kriitikud	doc_670731433478_item	2803147	et	3	main
suhtuma	doc_670731433478_item	2803148	et	3	main
sugugi	doc_670731433478_item	2803163	et	4	main
eriti	doc_670731433478_item	2803170	et	3	main
jalaluu	doc_670731433478_item	2803187	et	4	main
pidama	doc_670731433478_item	2803189	et	4	main
age	doc_670731433478_item	2803197	et	4	main
ja	doc_670731433478_item	2803198	et	3	main
toomas	doc_670731433478_item	2803199	et	3	main
on	doc_670731433478_item	2803200	et	4	main
otsustanud	doc_670731433478_item	2803201	et	4	main
tantsima	doc_670731433478_item	2803202	et	3	main
tantsida	doc_670731433478_item	2803203	et	3	main
ainult	doc_670731433478_item	2803204	et	4	main
teineteisega	doc_670731433478_item	2803205	et	3	main
paaris	doc_670731433478_item	2803206	et	4	main
kuigi	doc_670731433478_item	2803207	et	3	main
nemad	doc_670731433478_item	2803208	et	3	main
nendel	doc_670731433478_item	2803209	et	4	main
on	doc_670731433478_item	2803210	et	4	main
tehtud	doc_670731433478_item	2803211	et	4	main
ka	doc_670731433478_item	2803213	et	3	main
eraldi	doc_670731433478_item	2803214	et	4	main
pakkumisi	doc_670731433478_item	2803212	et	4	main
tantsimiseks	doc_670731433478_item	2803215	et	4	main
vaatamata	doc_670731433478_item	2803216	et	4	main
suurele	doc_670731433478_item	2803217	et	4	main
edule	doc_670731433478_item	2803218	et	3	main
elavad	doc_670731433478_item	2803219	et	4	main
tantsijad	doc_670731433478_item	2803220	et	4	main
lähiaja	doc_670731433478_item	2803224	et	3	main
täpselt	doc_670731433478_item	2803227	et	4	main
tallinn	doc_670731433478_item	2803244	et	4	main
lõuna-aafrika	doc_670731433478_item	2803249	et	4	main
edur	doc_670731433478_item	2803255	et	4	main
veel	doc_670731433478_item	2803256	et	4	main
tipus	doc_670731433478_item	2803257	et	3	main
lünka	doc_670731433478_item	2803274	et	4	main
saada	doc_670731433478_item	2803295	et	4	main
millal	doc_670731433478_item	2803302	et	3	main
soovid	doc_670731433478_item	2803306	et	4	main
on	doc_670731433478_item	2803308	et	4	main
interaktiivse	doc_670731433478_item	2803309	et	3	main
õppe	doc_670731433478_item	2803310	et	4	main
omandada	doc_670731433478_item	2803321	et	3	main
saad	doc_670731433478_item	2803344	et	4	main
õppematerjalid	doc_670731433478_item	2803353	et	3	main
ja	doc_670731433478_item	2803355	et	3	main
6	doc_670731433478_item	2803357	et	2	main
7	doc_670731433478_item	2803361	et	2	main
kodutöö	doc_670731433478_item	2803368	et	4	main
vaatab	doc_670731433478_item	2803372	et	3	main
vead	doc_670731433478_item	2803377	et	4	main
vajaduse	doc_670731433478_item	2803380	et	3	main
esinemised	doc_670731433478_item	2803225	et	4	main
on	doc_670731433478_item	2803226	et	4	main
planeerima	doc_670731433478_item	2803228	et	3	main
planeeritud	doc_670731433478_item	2803229	et	4	main
paremaks	doc_670731433478_item	2803238	et	4	main
tantsida	doc_670731433478_item	2803239	et	3	main
märtsis	doc_670731433478_item	2803240	et	3	main
tulevad	doc_670731433478_item	2803241	et	4	main
püsida	doc_670731433478_item	2803259	et	3	main
nad	doc_670731433478_item	2803262	et	3	main
eelistavad	doc_670731433478_item	2803266	et	4	main
üks	doc_670731433478_item	2803268	et	3	main
sobiv	doc_670731433478_item	2803275	et	4	main
sõna	doc_670731433478_item	2803276	et	4	main
teksti	doc_670731433478_item	2803277	et	4	main
punkti	doc_670731433478_item	2803284	et	4	main
õpi	doc_670731433478_item	2803285	et	4	main
unusta	doc_670731433478_item	2803289	et	4	main
umbne	doc_670731433478_item	2803290	et	3	main
klassiruum	doc_670731433478_item	2803291	et	3	main
koduõppesüsteem	doc_670731433478_item	2803292	et	3	main
võimaldab	doc_670731433478_item	2803293	et	3	main
sul	doc_670731433478_item	2803294	et	3	main
ja	doc_670731433478_item	2803301	et	3	main
seda	doc_670731433478_item	2803304	et	3	main
mis	doc_670731433478_item	2803312	et	4	main
annab	doc_670731433478_item	2803313	et	3	main
sulle	doc_670731433478_item	2803314	et	3	main
ning	doc_670731433478_item	2803319	et	3	main
eelise	doc_670731433478_item	2803320	et	4	main
on	doc_670731433478_item	2803335	et	4	main
ka	doc_670731433478_item	2803337	et	3	main
pisut	doc_670731433478_item	2803338	et	3	main
tarkust	doc_670731433478_item	2803339	et	4	main
kui	doc_670731433478_item	2803340	et	3	main
oled	doc_670731433478_item	2803341	et	3	main
kursusele	doc_670731433478_item	2803342	et	3	main
registreerunud	doc_670731433478_item	2803343	et	4	main
lähimast	doc_670731433478_item	2803348	et	4	main
postiasutusest	doc_670731433478_item	2803349	et	4	main
igal	doc_670731433478_item	2803350	et	3	main
kodutöö	doc_670731433478_item	2803359	et	4	main
eest	doc_670731433478_item	2803362	et	4	main
tasud	doc_670731433478_item	2803363	et	4	main
selle	doc_670731433478_item	2803364	et	4	main
tagasi	doc_670731433478_item	2803370	et	3	main
selle	doc_670731433478_item	2803373	et	4	main
kõik	doc_670731433478_item	2803385	et	4	main
vabaduse	doc_670731433478_item	2803423	et	4	main
a	doc_670731433478_item	2803425	et	4	main
kokku	doc_670731433478_item	2803444	et	3	main
panna	doc_670731433478_item	2803445	et	4	main
6	doc_670731433478_item	2803446	et	2	main
vaid	doc_670731433478_item	2803450	et	3	main
d	doc_670731433478_item	2803462	et	4	main
b	doc_670731433478_item	2803467	et	4	main
muudab	doc_670731433478_item	2803472	et	3	main
liigne	doc_670731433478_item	2803475	et	3	main
b	doc_670731433478_item	2803476	et	4	main
libe	doc_670731433478_item	2803477	et	3	main
lihtne	doc_670731433478_item	2803481	et	3	main
b	doc_670731433478_item	2803485	et	4	main
käige	doc_670731433478_item	2803486	et	3	main
harjutus	doc_670731433479_item	2803491	et	4	main
avage	doc_670731433479_item	2803492	et	3	main
numbrid	doc_670731433479_item	2803494	et	3	main
sõnadega	doc_670731433479_item	2803496	et	3	main
30	doc_670731433479_item	2803524	et	2	main
aastane	doc_670731433479_item	2803526	et	4	main
32	doc_670731433479_item	2803530	et	2	main
üheksasaja	doc_670731433479_item	2803538	et	4	main
nad	doc_670731433479_item	2803542	et	3	main
ja	doc_670731433479_item	2803545	et	3	main
teatrid	doc_670731433479_item	2803548	et	3	main
erinevates	doc_670731433479_item	2803549	et	4	main
teatrides	doc_670731433479_item	2803550	et	4	main
karmid	doc_670731433479_item	2803558	et	4	main
nendesse	doc_670731433479_item	2803562	et	4	main
hästi	doc_670731433479_item	2803564	et	3	main
artiklid	doc_670731433479_item	2803566	et	3	main
annab	doc_670731433478_item	2803282	et	3	main
1	doc_670731433478_item	2803287	et	2	main
soovid	doc_670731433478_item	2803288	et	4	main
just	doc_670731433478_item	2803298	et	3	main
kus	doc_670731433478_item	2803300	et	3	main
parasjagu	doc_670731433478_item	2803305	et	3	main
käes	doc_670731433478_item	2803307	et	4	main
teadmisi	doc_670731433478_item	2803322	et	4	main
individuaalsele	doc_670731433478_item	2803324	et	3	main
tasemele	doc_670731433478_item	2803326	et	3	main
aeg	doc_670731433478_item	2803327	et	3	main
on	doc_670731433478_item	2803328	et	4	main
raha	doc_670731433478_item	2803329	et	4	main
et	doc_670731433478_item	2803330	et	3	main
seda	doc_670731433478_item	2803331	et	3	main
5	doc_670731433478_item	2803332	et	2	main
meie	doc_670731433478_item	2803345	et	4	main
kuul	doc_670731433478_item	2803351	et	4	main
raamatu	doc_670731433478_item	2803354	et	4	main
kursuse	doc_670731433478_item	2803360	et	3	main
meile	doc_670731433478_item	2803369	et	4	main
8	doc_670731433478_item	2803375	et	2	main
vastab	doc_670731433478_item	2803379	et	3	main
geniaalne	doc_670731433478_item	2803386	et	3	main
9	doc_670731433478_item	2803388	et	2	main
10	doc_670731433478_item	2803390	et	2	main
kupong	doc_670731433478_item	2803396	et	3	main
1	doc_670731433478_item	2803397	et	2	main
a	doc_670731433478_item	2803398	et	4	main
sobid	doc_670731433478_item	2803399	et	4	main
b	doc_670731433478_item	2803400	et	4	main
soovid	doc_670731433478_item	2803401	et	4	main
c	doc_670731433478_item	2803402	et	4	main
soovitad	doc_670731433478_item	2803403	et	3	main
d	doc_670731433478_item	2803404	et	4	main
solvud	doc_670731433478_item	2803405	et	3	main
2	doc_670731433478_item	2803406	et	2	main
a	doc_670731433478_item	2803407	et	4	main
just	doc_670731433478_item	2803408	et	3	main
b	doc_670731433478_item	2803409	et	4	main
seega	doc_670731433478_item	2803410	et	4	main
c	doc_670731433478_item	2803411	et	4	main
kuigi	doc_670731433478_item	2803412	et	3	main
d	doc_670731433478_item	2803413	et	4	main
siiski	doc_670731433478_item	2803414	et	4	main
3	doc_670731433478_item	2803415	et	2	main
a	doc_670731433478_item	2803416	et	4	main
vajaduse	doc_670731433478_item	2803417	et	3	main
b	doc_670731433478_item	2803418	et	4	main
vabanduse	doc_670731433478_item	2803419	et	4	main
c	doc_670731433478_item	2803420	et	4	main
varanduse	doc_670731433478_item	2803421	et	3	main
4	doc_670731433478_item	2803424	et	2	main
tasemele	doc_670731433478_item	2803428	et	3	main
tasakesi	doc_670731433478_item	2803430	et	3	main
d	doc_670731433478_item	2803431	et	4	main
5	doc_670731433478_item	2803433	et	2	main
a	doc_670731433478_item	2803434	et	4	main
kokku	doc_670731433478_item	2803435	et	3	main
a	doc_670731433478_item	2803447	et	4	main
taga	doc_670731433478_item	2803457	et	4	main
b	doc_670731433478_item	2803458	et	4	main
ees	doc_670731433478_item	2803463	et	4	main
8	doc_670731433478_item	2803464	et	2	main
a	doc_670731433478_item	2803465	et	4	main
ka	doc_670731433478_item	2803382	et	3	main
on	doc_670731433478_item	2803387	et	4	main
lihtne	doc_670731433478_item	2803389	et	3	main
külastage	doc_670731433478_item	2803391	et	3	main
saada	doc_670731433478_item	2803436	et	4	main
liita	doc_670731433478_item	2803439	et	4	main
kokku	doc_670731433478_item	2803441	et	3	main
hoida	doc_670731433478_item	2803442	et	3	main
ette	doc_670731433478_item	2803459	et	4	main
palub	doc_670731433478_item	2803468	et	3	main
parandab	doc_670731433478_item	2803470	et	3	main
minge	doc_670731433478_item	2803490	et	3	main
kirjutage	doc_670731433479_item	2803495	et	3	main
iga	doc_670731433479_item	2803497	et	4	main
vastus	doc_670731433479_item	2803499	et	3	main
annab	doc_670731433479_item	2803500	et	3	main
ühe	doc_670731433479_item	2803501	et	4	main
punkti	doc_670731433479_item	2803502	et	4	main
maailmakuulsad	doc_670731433479_item	2803503	et	3	main
balletitantsijad	doc_670731433479_item	2803504	et	3	main
abielupaar	doc_670731433479_item	2803505	et	4	main
age	doc_670731433479_item	2803506	et	4	main
oks	doc_670731433479_item	2803507	et	3	main
ja	doc_670731433479_item	2803508	et	3	main
toomas	doc_670731433479_item	2803509	et	3	main
edur	doc_670731433479_item	2803510	et	4	main
on	doc_670731433479_item	2803511	et	4	main
pärit	doc_670731433479_item	2803512	et	3	main
eesti	doc_670731433479_item	2803513	et	4	main
eestist	doc_670731433479_item	2803514	et	3	main
aga	doc_670731433479_item	2803515	et	3	main
elavad	doc_670731433479_item	2803516	et	4	main
praegu	doc_670731433479_item	2803517	et	3	main
inglismaa	doc_670731433479_item	2803518	et	4	main
london	doc_670731433479_item	2803519	et	4	main
inglismaal	doc_670731433479_item	2803520	et	4	main
londonis	doc_670731433479_item	2803521	et	4	main
vana	doc_670731433479_item	2803534	et	4	main
alates	doc_670731433479_item	2803535	et	3	main
seitsmendast	doc_670731433479_item	2803540	et	3	main
esinevad	doc_670731433479_item	2803546	et	4	main
erinevad	doc_670731433479_item	2803547	et	4	main
kõik	doc_670731433479_item	2803573	et	4	main
pole	doc_670731433479_item	2803574	et	3	main
sugugi	doc_670731433479_item	2803575	et	4	main
7	doc_670731433478_item	2803455	et	2	main
a	doc_670731433478_item	2803456	et	4	main
kirjutab	doc_670731433478_item	2803466	et	3	main
liikuv	doc_670731433478_item	2803479	et	4	main
d	doc_670731433478_item	2803489	et	4	main
sulud	doc_670731433479_item	2803493	et	3	main
õige	doc_670731433479_item	2803498	et	4	main
age	doc_670731433479_item	2803522	et	4	main
ja	doc_670731433479_item	2803527	et	3	main
on	doc_670731433479_item	2803529	et	4	main
kolmeteistkümne	doc_670731433479_item	2803531	et	4	main
teist	doc_670731433479_item	2803532	et	4	main
aastat	doc_670731433479_item	2803533	et	3	main
on	doc_670731433479_item	2803541	et	4	main
vabakutseline	doc_670731433479_item	2803543	et	4	main
neid	doc_670731433479_item	2803554	et	4	main
väga	doc_670731433479_item	2803555	et	3	main
ning	doc_670731433479_item	2803556	et	3	main
isegi	doc_670731433479_item	2803557	et	4	main
suhelda	doc_670731433479_item	2803561	et	4	main
viimased	doc_670731433479_item	2803565	et	3	main
noortele	doc_670731433479_item	2803569	et	3	main
läinud	doc_670731433479_item	2803579	et	4	main
eriti	doc_670731433479_item	2803582	et	3	main
eraldi	doc_670731433479_item	2803626	et	4	main
tantsimiseks	doc_670731433479_item	2803627	et	4	main
vaatamata	doc_670731433479_item	2803628	et	4	main
on	doc_670731433479_item	2803638	et	4	main
planeerima	doc_670731433479_item	2803640	et	3	main
planeeritud	doc_670731433479_item	2803641	et	4	main
parem	doc_670731433479_item	2803649	et	4	main
tantsida	doc_670731433479_item	2803651	et	3	main
tulevad	doc_670731433479_item	2803653	et	4	main
tallinn	doc_670731433479_item	2803656	et	4	main
tallinnas	doc_670731433479_item	2803657	et	4	main
tipus	doc_670731433479_item	2803669	et	3	main
päev	doc_670731433479_item	2803681	et	3	main
kirjutage	doc_670731433479_item	2803685	et	3	main
sõna	doc_670731433479_item	2803688	et	4	main
punkti	doc_670731433479_item	2803696	et	4	main
õpi	doc_670731433479_item	2803697	et	4	main
millal	doc_670731433479_item	2803698	et	3	main
1	doc_670731433479_item	2803699	et	2	main
koduõppesüsteem	doc_670731433479_item	2803704	et	3	main
2	doc_670731433479_item	2803709	et	2	main
seal	doc_670731433479_item	2803711	et	4	main
kus	doc_670731433479_item	2803712	et	3	main
ja	doc_670731433479_item	2803713	et	3	main
millal	doc_670731433479_item	2803714	et	3	main
sa	doc_670731433479_item	2803715	et	3	main
seda	doc_670731433479_item	2803716	et	3	main
käes	doc_670731433479_item	2803719	et	4	main
interaktiivse	doc_670731433479_item	2803721	et	3	main
ajastu	doc_670731433479_item	2803723	et	4	main
annab	doc_670731433479_item	2803725	et	3	main
raha	doc_670731433479_item	2803741	et	4	main
et	doc_670731433479_item	2803742	et	3	main
seda	doc_670731433479_item	2803743	et	3	main
on	doc_670731433479_item	2803747	et	4	main
ka	doc_670731433479_item	2803749	et	3	main
pisut	doc_670731433479_item	2803750	et	3	main
või	doc_670731433479_item	2803759	et	4	main
kuul	doc_670731433479_item	2803763	et	4	main
tasud	doc_670731433479_item	2803775	et	4	main
selle	doc_670731433479_item	2803776	et	4	main
seega	doc_670731433479_item	2803822	et	4	main
c	doc_670731433479_item	2803832	et	4	main
varanduse	doc_670731433479_item	2803833	et	3	main
d	doc_670731433479_item	2803834	et	4	main
tasule	doc_670731433479_item	2803838	et	3	main
d	doc_670731433479_item	2803843	et	4	main
kokku	doc_670731433479_item	2803850	et	3	main
c	doc_670731433479_item	2803852	et	4	main
kokku	doc_670731433479_item	2803856	et	3	main
a	doc_670731433479_item	2803859	et	4	main
ning	doc_670731433479_item	2803860	et	3	main
b	doc_670731433479_item	2803861	et	4	main
vaid	doc_670731433479_item	2803862	et	3	main
taga	doc_670731433479_item	2803869	et	4	main
c	doc_670731433479_item	2803872	et	4	main
c	doc_670731433479_item	2803881	et	4	main
liikuv	doc_670731433479_item	2803891	et	4	main
c	doc_670731433478_item	2803469	et	4	main
d	doc_670731433478_item	2803471	et	4	main
9	doc_670731433478_item	2803473	et	2	main
a	doc_670731433478_item	2803474	et	4	main
d	doc_670731433478_item	2803480	et	4	main
a	doc_670731433478_item	2803483	et	4	main
kolmeteistkümne	doc_670731433479_item	2803525	et	4	main
üheksateistkümnenda	doc_670731433479_item	2803539	et	4	main
inglismaal	doc_670731433479_item	2803551	et	4	main
armastama	doc_670731433479_item	2803552	et	3	main
armastatakse	doc_670731433479_item	2803553	et	3	main
suhtuma	doc_670731433479_item	2803560	et	3	main
kergelt	doc_670731433479_item	2803578	et	4	main
ja	doc_670731433479_item	2803581	et	3	main
agel	doc_670731433479_item	2803583	et	4	main
järve	doc_670731433479_item	2803596	et	4	main
etendus	doc_670731433479_item	2803597	et	4	main
etendus	doc_670731433479_item	2803598	et	4	main
jalaluu	doc_670731433479_item	2803599	et	4	main
ja	doc_670731433479_item	2803600	et	3	main
pidama	doc_670731433479_item	2803601	et	4	main
pidada	doc_670731433479_item	2803602	et	4	main
mõnda	doc_670731433479_item	2803603	et	4	main
aega	doc_670731433479_item	2803604	et	4	main
tantsimisest	doc_670731433479_item	2803605	et	4	main
eemal	doc_670731433479_item	2803606	et	3	main
olema	doc_670731433479_item	2803607	et	4	main
olema	doc_670731433479_item	2803608	et	4	main
age	doc_670731433479_item	2803609	et	4	main
ja	doc_670731433479_item	2803610	et	3	main
toomas	doc_670731433479_item	2803611	et	3	main
on	doc_670731433479_item	2803612	et	4	main
otsustanud	doc_670731433479_item	2803613	et	4	main
tantsima	doc_670731433479_item	2803614	et	3	main
tantsida	doc_670731433479_item	2803615	et	3	main
ainult	doc_670731433479_item	2803616	et	4	main
teineteisega	doc_670731433479_item	2803617	et	3	main
paaris	doc_670731433479_item	2803618	et	4	main
kuigi	doc_670731433479_item	2803619	et	3	main
nemad	doc_670731433479_item	2803620	et	3	main
on	doc_670731433479_item	2803622	et	4	main
esinemised	doc_670731433479_item	2803637	et	4	main
täpselt	doc_670731433479_item	2803639	et	4	main
veelgi	doc_670731433479_item	2803648	et	4	main
märtsis	doc_670731433479_item	2803652	et	3	main
esinema	doc_670731433479_item	2803655	et	3	main
ja	doc_670731433479_item	2803658	et	3	main
lõuna-aafrika	doc_670731433479_item	2803661	et	4	main
lõuna-aafrikas	doc_670731433479_item	2803662	et	4	main
kui	doc_670731433479_item	2803663	et	3	main
kaua	doc_670731433479_item	2803664	et	3	main
oks	doc_670731433479_item	2803665	et	3	main
ja	doc_670731433479_item	2803666	et	3	main
üks	doc_670731433479_item	2803680	et	3	main
kaupa	doc_670731433479_item	2803684	et	4	main
ühe	doc_670731433479_item	2803695	et	4	main
klassiruum	doc_670731433479_item	2803703	et	3	main
sulle	doc_670731433479_item	2803726	et	3	main
on	doc_670731433479_item	2803740	et	4	main
hoida	doc_670731433479_item	2803746	et	3	main
vaja	doc_670731433479_item	2803748	et	4	main
kontorist	doc_670731433479_item	2803758	et	4	main
kriitikud	doc_670731433479_item	2803559	et	3	main
üldiselt	doc_670731433479_item	2803563	et	4	main
räägivad	doc_670731433479_item	2803567	et	3	main
noored	doc_670731433479_item	2803568	et	3	main
alati	doc_670731433479_item	2803576	et	4	main
on	doc_670731433479_item	2803584	et	4	main
olnud	doc_670731433479_item	2803585	et	4	main
probleeme	doc_670731433479_item	2803586	et	3	main
tervis	doc_670731433479_item	2803587	et	3	main
tervisega	doc_670731433479_item	2803588	et	3	main
1990	doc_670731433479_item	2803589	et	2	main
aastal	doc_670731433479_item	2803590	et	3	main
murdma	doc_670731433479_item	2803591	et	3	main
murda	doc_670731433479_item	2803592	et	3	main
noor	doc_670731433479_item	2803593	et	3	main
naine	doc_670731433479_item	2803594	et	3	main
luikede	doc_670731433479_item	2803595	et	3	main
suurele	doc_670731433479_item	2803629	et	4	main
edur	doc_670731433479_item	2803667	et	4	main
ei	doc_670731433479_item	2803672	et	4	main
oska	doc_670731433479_item	2803673	et	4	main
nad	doc_670731433479_item	2803677	et	3	main
eelistavad	doc_670731433479_item	2803678	et	4	main
elada	doc_670731433479_item	2803679	et	3	main
lünka	doc_670731433479_item	2803686	et	4	main
vastus	doc_670731433479_item	2803693	et	3	main
unusta	doc_670731433479_item	2803701	et	4	main
sul	doc_670731433479_item	2803706	et	3	main
targemaks	doc_670731433479_item	2803708	et	4	main
just	doc_670731433479_item	2803710	et	3	main
parasjagu	doc_670731433479_item	2803717	et	3	main
3	doc_670731433479_item	2803727	et	2	main
planeerida	doc_670731433479_item	2803729	et	3	main
ning	doc_670731433479_item	2803731	et	3	main
eelise	doc_670731433479_item	2803732	et	4	main
omandada	doc_670731433479_item	2803733	et	3	main
teadmisi	doc_670731433479_item	2803734	et	4	main
kokku	doc_670731433479_item	2803745	et	3	main
meie	doc_670731433479_item	2803757	et	4	main
kodutöö	doc_670731433479_item	2803771	et	4	main
kursuse	doc_670731433479_item	2803772	et	3	main
7	doc_670731433479_item	2803773	et	2	main
saada	doc_670731433479_item	2803778	et	4	main
tagasi	doc_670731433479_item	2803782	et	3	main
b	doc_670731433479_item	2803821	et	4	main
siiski	doc_670731433479_item	2803826	et	4	main
a	doc_670731433479_item	2803828	et	4	main
vajaduse	doc_670731433479_item	2803829	et	3	main
b	doc_670731433479_item	2803830	et	4	main
vabanduse	doc_670731433479_item	2803831	et	4	main
b	doc_670731433479_item	2803839	et	4	main
c	doc_670731433479_item	2803841	et	4	main
saada	doc_670731433479_item	2803848	et	4	main
liita	doc_670731433479_item	2803851	et	4	main
d	doc_670731433479_item	2803855	et	4	main
panna	doc_670731433479_item	2803857	et	4	main
7	doc_670731433479_item	2803867	et	2	main
a	doc_670731433479_item	2803868	et	4	main
ette	doc_670731433479_item	2803871	et	4	main
d	doc_670731433479_item	2803874	et	4	main
ees	doc_670731433479_item	2803875	et	4	main
a	doc_670731433479_item	2803877	et	4	main
kirjutab	doc_670731433479_item	2803878	et	3	main
b	doc_670731433479_item	2803888	et	4	main
libe	doc_670731433479_item	2803889	et	3	main
ainult	doc_670731433479_item	2803570	et	4	main
ülivõrdes	doc_670731433479_item	2803571	et	3	main
kuid	doc_670731433479_item	2803572	et	4	main
nii	doc_670731433479_item	2803577	et	3	main
mõlemal	doc_670731433479_item	2803580	et	3	main
nendel	doc_670731433479_item	2803621	et	4	main
tehtud	doc_670731433479_item	2803623	et	4	main
pakkumisi	doc_670731433479_item	2803624	et	4	main
ka	doc_670731433479_item	2803625	et	3	main
edule	doc_670731433479_item	2803630	et	3	main
tantsijad	doc_670731433479_item	2803632	et	4	main
tagasihoidlik	doc_670731433479_item	2803633	et	3	main
tagasihoidlikult	doc_670731433479_item	2803634	et	4	main
parem	doc_670731433479_item	2803650	et	4	main
nad	doc_670731433479_item	2803654	et	3	main
veel	doc_670731433479_item	2803668	et	4	main
suudavad	doc_670731433479_item	2803670	et	3	main
nad	doc_670731433479_item	2803674	et	3	main
ütlema	doc_670731433479_item	2803675	et	3	main
öelda	doc_670731433479_item	2803676	et	4	main
päeva	doc_670731433479_item	2803683	et	4	main
õige	doc_670731433479_item	2803692	et	4	main
annab	doc_670731433479_item	2803694	et	3	main
umbne	doc_670731433479_item	2803702	et	3	main
saada	doc_670731433479_item	2803707	et	4	main
on	doc_670731433479_item	2803720	et	4	main
õppe	doc_670731433479_item	2803722	et	4	main
mis	doc_670731433479_item	2803724	et	4	main
vabaduse	doc_670731433479_item	2803728	et	4	main
aega	doc_670731433479_item	2803730	et	4	main
5	doc_670731433479_item	2803744	et	2	main
tarkust	doc_670731433479_item	2803751	et	4	main
kui	doc_670731433479_item	2803752	et	3	main
oled	doc_670731433479_item	2803753	et	3	main
kursusele	doc_670731433479_item	2803754	et	3	main
registreerunud	doc_670731433479_item	2803755	et	4	main
saad	doc_670731433479_item	2803756	et	4	main
lähimast	doc_670731433479_item	2803760	et	4	main
postiasutusest	doc_670731433479_item	2803761	et	4	main
kätte	doc_670731433479_item	2803764	et	4	main
raamatu	doc_670731433479_item	2803766	et	4	main
kodutöö	doc_670731433479_item	2803780	et	4	main
õpetaja	doc_670731433479_item	2803783	et	4	main
c	doc_670731433479_item	2803823	et	4	main
3	doc_670731433479_item	2803827	et	2	main
vabaduse	doc_670731433479_item	2803835	et	4	main
5	doc_670731433479_item	2803845	et	2	main
a	doc_670731433479_item	2803846	et	4	main
kokku	doc_670731433479_item	2803847	et	3	main
c	doc_670731433479_item	2803863	et	4	main
b	doc_670731433479_item	2803870	et	4	main
eest	doc_670731433479_item	2803873	et	4	main
parandab	doc_670731433479_item	2803882	et	3	main
d	doc_670731433479_item	2803883	et	4	main
muudab	doc_670731433479_item	2803884	et	3	main
9	doc_670731433479_item	2803885	et	2	main
a	doc_670731433479_item	2803886	et	4	main
liigne	doc_670731433479_item	2803887	et	3	main
a	doc_670731433479_item	2803895	et	4	main
toomas	doc_670731433480_item	2803921	et	3	main
praegu	doc_670731433480_item	2803929	et	3	main
inglismaa	doc_670731433480_item	2803930	et	4	main
aastat	doc_670731433480_item	2803945	et	3	main
1997a	doc_670731433480_item	2803948	et	4	main
üheksasaja	doc_670731433480_item	2803950	et	4	main
vabakutselised	doc_670731433480_item	2803957	et	4	main
ja	doc_670731433480_item	2803958	et	3	main
isegi	doc_670731433480_item	2803970	et	4	main
viimased	doc_670731433480_item	2803978	et	3	main
artiklid	doc_670731433480_item	2803979	et	3	main
läinud	doc_670731433480_item	2803992	et	4	main
agel	doc_670731433480_item	2803996	et	4	main
aega	doc_670731433480_item	2804017	et	4	main
on	doc_670731433480_item	2804024	et	4	main
paaris	doc_670731433480_item	2804030	et	4	main
nemad	doc_670731433480_item	2804032	et	3	main
nendele	doc_670731433480_item	2804033	et	4	main
tantsijad	doc_670731433480_item	2804044	et	4	main
tagasihoidlik	doc_670731433480_item	2804045	et	3	main
esinemised	doc_670731433480_item	2804049	et	4	main
planeeritud	doc_670731433480_item	2804053	et	4	main
elavad	doc_670731433479_item	2803631	et	4	main
nende	doc_670731433479_item	2803635	et	4	main
lähiaja	doc_670731433479_item	2803636	et	3	main
age	doc_670731433479_item	2803642	et	4	main
ja	doc_670731433479_item	2803643	et	3	main
toomas	doc_670731433479_item	2803644	et	3	main
tahavad	doc_670731433479_item	2803645	et	3	main
areneda	doc_670731433479_item	2803646	et	3	main
ja	doc_670731433479_item	2803647	et	3	main
seejärel	doc_670731433479_item	2803659	et	3	main
sõidavad	doc_670731433479_item	2803660	et	3	main
püsida	doc_670731433479_item	2803671	et	3	main
ühe	doc_670731433479_item	2803682	et	4	main
sobiv	doc_670731433479_item	2803687	et	4	main
teksti	doc_670731433479_item	2803689	et	4	main
alt	doc_670731433479_item	2803690	et	4	main
iga	doc_670731433479_item	2803691	et	4	main
soovid	doc_670731433479_item	2803700	et	4	main
võimaldab	doc_670731433479_item	2803705	et	3	main
soovid	doc_670731433479_item	2803718	et	4	main
vastavalt	doc_670731433479_item	2803735	et	4	main
individuaalsele	doc_670731433479_item	2803736	et	3	main
4	doc_670731433479_item	2803737	et	2	main
tasemele	doc_670731433479_item	2803738	et	3	main
aeg	doc_670731433479_item	2803739	et	3	main
eest	doc_670731433479_item	2803774	et	4	main
täidetud	doc_670731433479_item	2803779	et	4	main
vaatab	doc_670731433479_item	2803784	et	3	main
selle	doc_670731433479_item	2803785	et	4	main
üle	doc_670731433479_item	2803786	et	3	main
8	doc_670731433479_item	2803787	et	2	main
parandab	doc_670731433479_item	2803788	et	3	main
vead	doc_670731433479_item	2803789	et	4	main
ning	doc_670731433479_item	2803790	et	3	main
vastab	doc_670731433479_item	2803791	et	3	main
vajaduse	doc_670731433479_item	2803792	et	3	main
korral	doc_670731433479_item	2803793	et	4	main
tekkinud	doc_670731433479_item	2803795	et	4	main
ka	doc_670731433479_item	2803794	et	3	main
lisaküsimustele	doc_670731433479_item	2803796	et	4	main
kõik	doc_670731433479_item	2803797	et	4	main
geniaalne	doc_670731433479_item	2803798	et	3	main
on	doc_670731433479_item	2803799	et	4	main
9	doc_670731433479_item	2803800	et	2	main
lihtne	doc_670731433479_item	2803801	et	3	main
10	doc_670731433479_item	2803802	et	2	main
külastage	doc_670731433479_item	2803803	et	3	main
meie	doc_670731433479_item	2803804	et	4	main
virtuaalkodu	doc_670731433479_item	2803805	et	4	main
või	doc_670731433479_item	2803806	et	4	main
postitage	doc_670731433479_item	2803807	et	3	main
kupong	doc_670731433479_item	2803808	et	3	main
1	doc_670731433479_item	2803809	et	2	main
a	doc_670731433479_item	2803810	et	4	main
sobid	doc_670731433479_item	2803811	et	4	main
b	doc_670731433479_item	2803812	et	4	main
soovid	doc_670731433479_item	2803813	et	4	main
c	doc_670731433479_item	2803814	et	4	main
soovitad	doc_670731433479_item	2803815	et	3	main
d	doc_670731433479_item	2803816	et	4	main
solvud	doc_670731433479_item	2803817	et	3	main
2	doc_670731433479_item	2803818	et	2	main
a	doc_670731433479_item	2803819	et	4	main
just	doc_670731433479_item	2803820	et	3	main
4	doc_670731433479_item	2803836	et	2	main
igal	doc_670731433479_item	2803762	et	3	main
õppematerjalid	doc_670731433479_item	2803765	et	3	main
ja	doc_670731433479_item	2803767	et	3	main
helikasseti	doc_670731433479_item	2803768	et	4	main
6	doc_670731433479_item	2803769	et	2	main
ning	doc_670731433479_item	2803770	et	3	main
kättesaamisel	doc_670731433479_item	2803777	et	4	main
meile	doc_670731433479_item	2803781	et	4	main
kuigi	doc_670731433479_item	2803824	et	3	main
d	doc_670731433479_item	2803825	et	4	main
a	doc_670731433479_item	2803837	et	4	main
tasemele	doc_670731433479_item	2803840	et	3	main
tasakesi	doc_670731433479_item	2803842	et	3	main
tasakaalule	doc_670731433479_item	2803844	et	3	main
b	doc_670731433479_item	2803849	et	4	main
hoida	doc_670731433479_item	2803854	et	3	main
6	doc_670731433479_item	2803858	et	2	main
kuid	doc_670731433479_item	2803864	et	4	main
b	doc_670731433479_item	2803879	et	4	main
palub	doc_670731433479_item	2803880	et	3	main
c	doc_670731433479_item	2803890	et	4	main
tulge	doc_670731433479_item	2803896	et	3	main
b	doc_670731433479_item	2803897	et	4	main
käige	doc_670731433479_item	2803898	et	3	main
c	doc_670731433479_item	2803899	et	4	main
külastage	doc_670731433479_item	2803900	et	3	main
d	doc_670731433479_item	2803901	et	4	main
minge	doc_670731433479_item	2803902	et	3	main
harjutus	doc_670731433480_item	2803903	et	4	main
avage	doc_670731433480_item	2803904	et	3	main
sulud	doc_670731433480_item	2803905	et	3	main
numbrid	doc_670731433480_item	2803906	et	3	main
kirjutage	doc_670731433480_item	2803907	et	3	main
sõnadega	doc_670731433480_item	2803908	et	3	main
iga	doc_670731433480_item	2803909	et	4	main
õige	doc_670731433480_item	2803910	et	4	main
vastus	doc_670731433480_item	2803911	et	3	main
annab	doc_670731433480_item	2803912	et	3	main
ühe	doc_670731433480_item	2803913	et	4	main
punkti	doc_670731433480_item	2803914	et	4	main
maailmakuulsad	doc_670731433480_item	2803915	et	3	main
balletitantsijad	doc_670731433480_item	2803916	et	3	main
abielupaar	doc_670731433480_item	2803917	et	4	main
age	doc_670731433480_item	2803918	et	4	main
oks	doc_670731433480_item	2803919	et	3	main
ja	doc_670731433480_item	2803920	et	3	main
edur	doc_670731433480_item	2803922	et	4	main
eesti	doc_670731433480_item	2803925	et	4	main
age	doc_670731433480_item	2803934	et	4	main
on	doc_670731433480_item	2803935	et	4	main
kolmekümmend	doc_670731433480_item	2803943	et	4	main
kaks	doc_670731433480_item	2803944	et	3	main
on	doc_670731433480_item	2803954	et	4	main
nad	doc_670731433480_item	2803955	et	3	main
vabakutseline	doc_670731433480_item	2803956	et	4	main
erinevaid	doc_670731433480_item	2803962	et	4	main
kriitikud	doc_670731433480_item	2803972	et	3	main
suhtuma	doc_670731433480_item	2803973	et	3	main
suhtuvad	doc_670731433480_item	2803974	et	4	main
sugugi	doc_670731433480_item	2803988	et	4	main
mõlemal	doc_670731433480_item	2803993	et	3	main
ja	doc_670731433480_item	2803994	et	3	main
etendus	doc_670731433480_item	2804010	et	4	main
etenduse	doc_670731433480_item	2804011	et	4	main
jalaluu	doc_670731433480_item	2804012	et	4	main
kokku	doc_670731433479_item	2803853	et	3	main
d	doc_670731433479_item	2803865	et	4	main
et	doc_670731433479_item	2803866	et	3	main
8	doc_670731433479_item	2803876	et	2	main
d	doc_670731433479_item	2803892	et	4	main
lihtne	doc_670731433479_item	2803893	et	3	main
10	doc_670731433479_item	2803894	et	2	main
on	doc_670731433480_item	2803923	et	4	main
pärit	doc_670731433480_item	2803924	et	3	main
eestist	doc_670731433480_item	2803926	et	3	main
aga	doc_670731433480_item	2803927	et	3	main
london	doc_670731433480_item	2803931	et	4	main
inglismaal	doc_670731433480_item	2803932	et	4	main
aastane	doc_670731433480_item	2803938	et	4	main
ja	doc_670731433480_item	2803939	et	3	main
toomas	doc_670731433480_item	2803940	et	3	main
on	doc_670731433480_item	2803941	et	4	main
32	doc_670731433480_item	2803942	et	2	main
tuhande	doc_670731433480_item	2803949	et	3	main
üheksakümne	doc_670731433480_item	2803951	et	4	main
seitsmendast	doc_670731433480_item	2803952	et	3	main
aastatest	doc_670731433480_item	2803953	et	4	main
esinevad	doc_670731433480_item	2803959	et	4	main
erinevad	doc_670731433480_item	2803960	et	4	main
teatrid	doc_670731433480_item	2803961	et	3	main
karmid	doc_670731433480_item	2803971	et	4	main
noored	doc_670731433480_item	2803981	et	3	main
ainult	doc_670731433480_item	2803983	et	4	main
kergelt	doc_670731433480_item	2803991	et	4	main
tantsimisest	doc_670731433480_item	2804018	et	4	main
pakkumisi	doc_670731433480_item	2804036	et	4	main
ka	doc_670731433480_item	2804037	et	3	main
elavad	doc_670731433480_item	2804043	et	4	main
lähiaja	doc_670731433480_item	2804048	et	3	main
täpselt	doc_670731433480_item	2804051	et	4	main
ja	doc_670731433480_item	2804055	et	3	main
märtsis	doc_670731433480_item	2804064	et	3	main
tallinn	doc_670731433480_item	2804068	et	4	main
tallinnas	doc_670731433480_item	2804069	et	4	main
suudavad	doc_670731433480_item	2804082	et	3	main
nad	doc_670731433480_item	2804086	et	3	main
elada	doc_670731433480_item	2804091	et	3	main
üks	doc_670731433480_item	2804092	et	3	main
elavad	doc_670731433480_item	2803928	et	4	main
30	doc_670731433480_item	2803936	et	2	main
kolmekümne	doc_670731433480_item	2803937	et	4	main
alates	doc_670731433480_item	2803947	et	3	main
teatre	doc_670731433480_item	2803963	et	4	main
inglismaal	doc_670731433480_item	2803964	et	4	main
armastama	doc_670731433480_item	2803965	et	3	main
armastavad	doc_670731433480_item	2803966	et	4	main
nendesse	doc_670731433480_item	2803975	et	4	main
noortest	doc_670731433480_item	2803982	et	4	main
kuid	doc_670731433480_item	2803985	et	4	main
kõik	doc_670731433480_item	2803986	et	4	main
pole	doc_670731433480_item	2803987	et	3	main
nii	doc_670731433480_item	2803990	et	3	main
on	doc_670731433480_item	2803997	et	4	main
olnud	doc_670731433480_item	2803998	et	4	main
probleeme	doc_670731433480_item	2803999	et	3	main
tervis	doc_670731433480_item	2804000	et	3	main
tervisega	doc_670731433480_item	2804001	et	3	main
1990	doc_670731433480_item	2804002	et	2	main
aastal	doc_670731433480_item	2804003	et	3	main
murdma	doc_670731433480_item	2804004	et	3	main
murdis	doc_670731433480_item	2804005	et	3	main
noor	doc_670731433480_item	2804006	et	3	main
naine	doc_670731433480_item	2804007	et	3	main
luikede	doc_670731433480_item	2804008	et	3	main
pidama	doc_670731433480_item	2804014	et	4	main
eemal	doc_670731433480_item	2804019	et	3	main
olema	doc_670731433480_item	2804020	et	4	main
age	doc_670731433480_item	2804021	et	4	main
teineteisega	doc_670731433480_item	2804029	et	3	main
kuigi	doc_670731433480_item	2804031	et	3	main
tantsimiseks	doc_670731433480_item	2804039	et	4	main
vaatamata	doc_670731433480_item	2804040	et	4	main
suurele	doc_670731433480_item	2804041	et	4	main
edule	doc_670731433480_item	2804042	et	3	main
nende	doc_670731433480_item	2804047	et	4	main
on	doc_670731433480_item	2804050	et	4	main
parem	doc_670731433480_item	2804061	et	4	main
tantsida	doc_670731433480_item	2804063	et	3	main
lõuna-afrikasse	doc_670731433480_item	2804074	et	4	main
kui	doc_670731433480_item	2804075	et	3	main
kaua	doc_670731433480_item	2804076	et	3	main
veel	doc_670731433480_item	2804080	et	4	main
tipus	doc_670731433480_item	2804081	et	3	main
ei	doc_670731433480_item	2804084	et	4	main
ütlema	doc_670731433480_item	2804087	et	3	main
nad	doc_670731433480_item	2804089	et	3	main
mis	doc_670731433480_item	2804136	et	4	main
annab	doc_670731433480_item	2804137	et	3	main
sulle	doc_670731433480_item	2804138	et	3	main
vastavalt	doc_670731433480_item	2804147	et	4	main
individuaalsele	doc_670731433480_item	2804148	et	3	main
kätte	doc_670731433480_item	2804176	et	4	main
õppematerjalid	doc_670731433480_item	2804177	et	3	main
õpetaja	doc_670731433480_item	2804195	et	4	main
vead	doc_670731433480_item	2804201	et	4	main
ning	doc_670731433480_item	2804202	et	3	main
londonis	doc_670731433480_item	2803933	et	4	main
vana	doc_670731433480_item	2803946	et	4	main
neid	doc_670731433480_item	2803967	et	4	main
väga	doc_670731433480_item	2803968	et	3	main
ning	doc_670731433480_item	2803969	et	3	main
üldiselt	doc_670731433480_item	2803976	et	4	main
hästi	doc_670731433480_item	2803977	et	3	main
räägivad	doc_670731433480_item	2803980	et	3	main
ülivõrdes	doc_670731433480_item	2803984	et	3	main
alati	doc_670731433480_item	2803989	et	4	main
eriti	doc_670731433480_item	2803995	et	3	main
järve	doc_670731433480_item	2804009	et	4	main
pidas	doc_670731433480_item	2804015	et	3	main
mõnda	doc_670731433480_item	2804016	et	4	main
ainult	doc_670731433480_item	2804028	et	4	main
on	doc_670731433480_item	2804034	et	4	main
tehtud	doc_670731433480_item	2804035	et	4	main
planeerima	doc_670731433480_item	2804052	et	3	main
toomas	doc_670731433480_item	2804056	et	3	main
tahavad	doc_670731433480_item	2804057	et	3	main
areneda	doc_670731433480_item	2804058	et	3	main
ja	doc_670731433480_item	2804059	et	3	main
veelgi	doc_670731433480_item	2804060	et	4	main
parem	doc_670731433480_item	2804062	et	4	main
tulevad	doc_670731433480_item	2804065	et	4	main
nad	doc_670731433480_item	2804066	et	3	main
ja	doc_670731433480_item	2804078	et	3	main
kirjutage	doc_670731433480_item	2804097	et	3	main
2	doc_670731433480_item	2804121	et	2	main
ja	doc_670731433480_item	2804125	et	3	main
soovid	doc_670731433480_item	2804130	et	4	main
käes	doc_670731433480_item	2804131	et	4	main
on	doc_670731433480_item	2804132	et	4	main
interaktiivse	doc_670731433480_item	2804133	et	3	main
vabaduse	doc_670731433480_item	2804140	et	4	main
planeerida	doc_670731433480_item	2804141	et	3	main
aega	doc_670731433480_item	2804142	et	4	main
ning	doc_670731433480_item	2804143	et	3	main
tasemele	doc_670731433480_item	2804150	et	3	main
kokku	doc_670731433480_item	2804157	et	3	main
on	doc_670731433480_item	2804159	et	4	main
lähimast	doc_670731433480_item	2804172	et	4	main
ja	doc_670731433480_item	2804179	et	3	main
helikasseti	doc_670731433480_item	2804180	et	4	main
eest	doc_670731433480_item	2804186	et	4	main
selle	doc_670731433480_item	2804188	et	4	main
kättesaamisel	doc_670731433480_item	2804189	et	4	main
tagasi	doc_670731433480_item	2804194	et	3	main
selle	doc_670731433480_item	2804197	et	4	main
8	doc_670731433480_item	2804199	et	2	main
korral	doc_670731433480_item	2804205	et	4	main
tekkinud	doc_670731433480_item	2804207	et	4	main
geniaalne	doc_670731433480_item	2804210	et	3	main
9	doc_670731433480_item	2804212	et	2	main
lihtne	doc_670731433480_item	2804213	et	3	main
tulge	doc_670731433480_item	2804215	et	3	main
1	doc_670731433480_item	2804221	et	2	main
b	doc_670731433480_item	2804224	et	4	main
soovid	doc_670731433480_item	2804225	et	4	main
seega	doc_670731433480_item	2804234	et	4	main
b	doc_670731433480_item	2804242	et	4	main
a	doc_670731433480_item	2804249	et	4	main
c	doc_670731433480_item	2804253	et	4	main
liita	doc_670731433480_item	2804263	et	4	main
c	doc_670731433480_item	2804264	et	4	main
kokku	doc_670731433480_item	2804265	et	3	main
hoida	doc_670731433480_item	2804266	et	3	main
panna	doc_670731433480_item	2804269	et	4	main
ning	doc_670731433480_item	2804272	et	3	main
b	doc_670731433480_item	2804273	et	4	main
a	doc_670731433480_item	2804280	et	4	main
taga	doc_670731433480_item	2804281	et	4	main
eest	doc_670731433480_item	2804285	et	4	main
d	doc_670731433480_item	2804286	et	4	main
ees	doc_670731433480_item	2804287	et	4	main
b	doc_670731433480_item	2804300	et	4	main
libe	doc_670731433480_item	2804301	et	3	main
c	doc_670731433480_item	2804302	et	4	main
tulge	doc_670731433480_item	2804308	et	3	main
d	doc_670731433480_item	2804313	et	4	main
kontrolltöö	doc_676618345565_item	2804315	et	4	main
a-te	doc_676618345565_item	2804319	et	3	main
ja	doc_670731433480_item	2804013	et	3	main
ja	doc_670731433480_item	2804022	et	3	main
toomas	doc_670731433480_item	2804023	et	3	main
otsustanud	doc_670731433480_item	2804025	et	4	main
tantsima	doc_670731433480_item	2804026	et	3	main
tantsida	doc_670731433480_item	2804027	et	3	main
eraldi	doc_670731433480_item	2804038	et	4	main
tagasihoidlikult	doc_670731433480_item	2804046	et	4	main
esinema	doc_670731433480_item	2804067	et	3	main
oks	doc_670731433480_item	2804077	et	3	main
püsida	doc_670731433480_item	2804083	et	3	main
oska	doc_670731433480_item	2804085	et	4	main
öelda	doc_670731433480_item	2804088	et	4	main
päeva	doc_670731433480_item	2804095	et	4	main
kaupa	doc_670731433480_item	2804096	et	4	main
sobiv	doc_670731433480_item	2804099	et	4	main
teksti	doc_670731433480_item	2804101	et	4	main
alt	doc_670731433480_item	2804102	et	4	main
iga	doc_670731433480_item	2804103	et	4	main
õige	doc_670731433480_item	2804104	et	4	main
vastus	doc_670731433480_item	2804105	et	3	main
annab	doc_670731433480_item	2804106	et	3	main
ühe	doc_670731433480_item	2804107	et	4	main
punkti	doc_670731433480_item	2804108	et	4	main
õpi	doc_670731433480_item	2804109	et	4	main
millal	doc_670731433480_item	2804110	et	3	main
1	doc_670731433480_item	2804111	et	2	main
sobid	doc_670731433480_item	2804112	et	4	main
unusta	doc_670731433480_item	2804113	et	4	main
umbne	doc_670731433480_item	2804114	et	3	main
klassiruum	doc_670731433480_item	2804115	et	3	main
koduõppesüsteem	doc_670731433480_item	2804116	et	3	main
võimaldab	doc_670731433480_item	2804117	et	3	main
sul	doc_670731433480_item	2804118	et	3	main
saada	doc_670731433480_item	2804119	et	4	main
targemaks	doc_670731433480_item	2804120	et	4	main
õppe	doc_670731433480_item	2804134	et	4	main
eelise	doc_670731433480_item	2804144	et	4	main
omandada	doc_670731433480_item	2804145	et	3	main
aeg	doc_670731433480_item	2804151	et	3	main
5	doc_670731433480_item	2804156	et	2	main
postiasutusest	doc_670731433480_item	2804173	et	4	main
igal	doc_670731433480_item	2804174	et	3	main
kuul	doc_670731433480_item	2804175	et	4	main
6	doc_670731433480_item	2804181	et	2	main
7	doc_670731433480_item	2804185	et	2	main
tasud	doc_670731433480_item	2804187	et	4	main
täidetud	doc_670731433480_item	2804191	et	4	main
kodutöö	doc_670731433480_item	2804192	et	4	main
meile	doc_670731433480_item	2804193	et	4	main
lisaküsimustele	doc_670731433480_item	2804208	et	4	main
on	doc_670731433480_item	2804211	et	4	main
meie	doc_670731433480_item	2804216	et	4	main
virtuaalkodu	doc_670731433480_item	2804217	et	4	main
soovitad	doc_670731433480_item	2804227	et	3	main
2	doc_670731433480_item	2804230	et	2	main
a	doc_670731433480_item	2804231	et	4	main
vabanduse	doc_670731433480_item	2804243	et	4	main
tasule	doc_670731433480_item	2804250	et	3	main
6	doc_670731433480_item	2804270	et	2	main
a	doc_670731433480_item	2804271	et	4	main
vaid	doc_670731433480_item	2804274	et	3	main
age	doc_670731433480_item	2804054	et	4	main
ja	doc_670731433480_item	2804070	et	3	main
seejärel	doc_670731433480_item	2804071	et	3	main
sõidavad	doc_670731433480_item	2804072	et	3	main
lõuna-aafrika	doc_670731433480_item	2804073	et	4	main
edur	doc_670731433480_item	2804079	et	4	main
eelistavad	doc_670731433480_item	2804090	et	4	main
päev	doc_670731433480_item	2804093	et	3	main
ühe	doc_670731433480_item	2804094	et	4	main
lünka	doc_670731433480_item	2804098	et	4	main
sõna	doc_670731433480_item	2804100	et	4	main
seal	doc_670731433480_item	2804123	et	4	main
seda	doc_670731433480_item	2804128	et	3	main
ajastu	doc_670731433480_item	2804135	et	4	main
teadmisi	doc_670731433480_item	2804146	et	4	main
on	doc_670731433480_item	2804152	et	4	main
et	doc_670731433480_item	2804154	et	3	main
saada	doc_670731433480_item	2804158	et	4	main
raamatu	doc_670731433480_item	2804178	et	4	main
kodutöö	doc_670731433480_item	2804183	et	4	main
kursuse	doc_670731433480_item	2804184	et	3	main
saada	doc_670731433480_item	2804190	et	4	main
vaatab	doc_670731433480_item	2804196	et	3	main
üle	doc_670731433480_item	2804198	et	3	main
parandab	doc_670731433480_item	2804200	et	3	main
vastab	doc_670731433480_item	2804203	et	3	main
või	doc_670731433480_item	2804218	et	4	main
postitage	doc_670731433480_item	2804219	et	3	main
kupong	doc_670731433480_item	2804220	et	3	main
c	doc_670731433480_item	2804226	et	4	main
d	doc_670731433480_item	2804228	et	4	main
solvud	doc_670731433480_item	2804229	et	3	main
a	doc_670731433480_item	2804240	et	4	main
vajaduse	doc_670731433480_item	2804241	et	3	main
vabaduse	doc_670731433480_item	2804247	et	4	main
4	doc_670731433480_item	2804248	et	2	main
saada	doc_670731433480_item	2804260	et	4	main
b	doc_670731433480_item	2804261	et	4	main
kokku	doc_670731433480_item	2804262	et	3	main
c	doc_670731433480_item	2804275	et	4	main
kuid	doc_670731433480_item	2804276	et	4	main
b	doc_670731433480_item	2804282	et	4	main
a	doc_670731433480_item	2804289	et	4	main
c	doc_670731433480_item	2804293	et	4	main
parandab	doc_670731433480_item	2804294	et	3	main
d	doc_670731433480_item	2804295	et	4	main
muudab	doc_670731433480_item	2804296	et	3	main
9	doc_670731433480_item	2804297	et	2	main
d	doc_670731433480_item	2804304	et	4	main
lihtne	doc_670731433480_item	2804305	et	3	main
10	doc_670731433480_item	2804306	et	2	main
külastage	doc_670731433480_item	2804312	et	3	main
öölaulupidudeja	doc_676618345565_item	2804324	et	4	main
perestroika	doc_676618345565_item	2804332	et	4	main
ja	doc_676618345565_item	2804336	et	3	main
sisu	doc_676618345565_item	2804337	et	4	main
inimeste	doc_676618345565_item	2804344	et	3	main
ühinenud	doc_676618345565_item	2804351	et	4	main
ühel	doc_676618345565_item	2804353	et	3	main
sai	doc_676618345565_item	2804355	et	4	main
kujutati	doc_676618345565_item	2804371	et	4	main
lemmikuks	doc_676618345565_item	2804375	et	4	main
sai	doc_676618345565_item	2804377	et	4	main
olid	doc_676618345565_item	2804382	et	4	main
huvi	doc_676618345565_item	2804391	et	4	main
tehti	doc_676618345565_item	2804425	et	3	main
põhjal	doc_676618345565_item	2804427	et	4	main
rahvas	doc_676618345565_item	2804432	et	4	main
kvantitatiivne	doc_676618345565_item	2804436	et	3	main
teaduskraadiga	doc_676618345565_item	2804440	et	3	main
kasvas	doc_676618345565_item	2804452	et	3	main
omapärasust	doc_676618345565_item	2804477	et	4	main
palju	doc_676618345565_item	2804480	et	4	main
kõik	doc_676618345565_item	2804487	et	4	main
kõik	doc_676618345565_item	2804497	et	4	main
kasutusele	doc_676618345565_item	2804507	et	4	main
majanduse	doc_676618345565_item	2804511	et	4	main
intensiivsust	doc_676618345565_item	2804512	et	4	main
ka	doc_676618345565_item	2804519	et	3	main
seda	doc_676618345565_item	2804520	et	3	main
kõik	doc_676618345565_item	2804522	et	4	main
oli	doc_676618345565_item	2804524	et	3	main
just	doc_670731433480_item	2804122	et	3	main
kus	doc_670731433480_item	2804124	et	3	main
millal	doc_670731433480_item	2804126	et	3	main
sa	doc_670731433480_item	2804127	et	3	main
parasjagu	doc_670731433480_item	2804129	et	3	main
3	doc_670731433480_item	2804139	et	2	main
4	doc_670731433480_item	2804149	et	2	main
raha	doc_670731433480_item	2804153	et	4	main
seda	doc_670731433480_item	2804155	et	3	main
vaja	doc_670731433480_item	2804160	et	4	main
ka	doc_670731433480_item	2804161	et	3	main
pisut	doc_670731433480_item	2804162	et	3	main
tarkust	doc_670731433480_item	2804163	et	4	main
kui	doc_670731433480_item	2804164	et	3	main
oled	doc_670731433480_item	2804165	et	3	main
kursusele	doc_670731433480_item	2804166	et	3	main
registreerunud	doc_670731433480_item	2804167	et	4	main
meie	doc_670731433480_item	2804169	et	4	main
saad	doc_670731433480_item	2804168	et	4	main
kontorist	doc_670731433480_item	2804170	et	4	main
või	doc_670731433480_item	2804171	et	4	main
ning	doc_670731433480_item	2804182	et	3	main
vajaduse	doc_670731433480_item	2804204	et	3	main
ka	doc_670731433480_item	2804206	et	3	main
kõik	doc_670731433480_item	2804209	et	4	main
10	doc_670731433480_item	2804214	et	2	main
a	doc_670731433480_item	2804222	et	4	main
b	doc_670731433480_item	2804233	et	4	main
c	doc_670731433480_item	2804235	et	4	main
c	doc_670731433480_item	2804244	et	4	main
varanduse	doc_670731433480_item	2804245	et	3	main
b	doc_670731433480_item	2804251	et	4	main
d	doc_670731433480_item	2804255	et	4	main
5	doc_670731433480_item	2804257	et	2	main
7	doc_670731433480_item	2804279	et	2	main
kirjutab	doc_670731433480_item	2804290	et	3	main
palub	doc_670731433480_item	2804292	et	3	main
liikuv	doc_670731433480_item	2804303	et	4	main
b	doc_670731433480_item	2804309	et	4	main
2	doc_676618345565_item	2804322	et	2	main
ja	doc_676618345565_item	2804333	et	3	main
tähendus	doc_676618345565_item	2804335	et	4	main
2	doc_676618345565_item	2804338	et	2	main
öölaulupeod	doc_676618345565_item	2804339	et	4	main
ja	doc_676618345565_item	2804340	et	3	main
laulev	doc_676618345565_item	2804341	et	4	main
revolutsioon	doc_676618345565_item	2804342	et	3	main
enesetunnust	doc_676618345565_item	2804345	et	3	main
ühinesid	doc_676618345565_item	2804347	et	4	main
oma	doc_676618345565_item	2804350	et	4	main
jõududesse	doc_676618345565_item	2804352	et	3	main
hümniks	doc_676618345565_item	2804356	et	3	main
mu	doc_676618345565_item	2804357	et	3	main
keelatud	doc_676618345565_item	2804365	et	4	main
1970	doc_676618345565_item	2804367	et	2	main
aastatel	doc_676618345565_item	2804369	et	4	main
kunstis	doc_676618345565_item	2804370	et	3	main
üha	doc_676618345565_item	2804374	et	3	main
emantsipeeritud	doc_676618345565_item	2804378	et	4	main
abeeman	doc_676618345565_item	2804386	et	4	main
valikuvõimalus	doc_676618345565_item	2804387	et	3	main
mtraat	doc_676618345565_item	2804388	et	4	main
sobid	doc_670731433480_item	2804223	et	4	main
just	doc_670731433480_item	2804232	et	3	main
kuigi	doc_670731433480_item	2804236	et	3	main
d	doc_670731433480_item	2804237	et	4	main
siiski	doc_670731433480_item	2804238	et	4	main
3	doc_670731433480_item	2804239	et	2	main
d	doc_670731433480_item	2804246	et	4	main
tasemele	doc_670731433480_item	2804252	et	3	main
tasakesi	doc_670731433480_item	2804254	et	3	main
tasakaalule	doc_670731433480_item	2804256	et	3	main
a	doc_670731433480_item	2804258	et	4	main
kokku	doc_670731433480_item	2804259	et	3	main
d	doc_670731433480_item	2804267	et	4	main
kokku	doc_670731433480_item	2804268	et	3	main
d	doc_670731433480_item	2804277	et	4	main
et	doc_670731433480_item	2804278	et	3	main
c	doc_670731433480_item	2804284	et	4	main
a	doc_670731433480_item	2804298	et	4	main
liigne	doc_670731433480_item	2804299	et	3	main
c	doc_670731433480_item	2804311	et	4	main
minge	doc_670731433480_item	2804314	et	3	main
iseloomustage	doc_676618345565_item	2804317	et	4	main
laulva	doc_676618345565_item	2804325	et	4	main
osa	doc_676618345565_item	2804327	et	4	main
eesti	doc_676618345565_item	2804328	et	4	main
taasiseseisvumisel	doc_676618345565_item	2804329	et	3	main
glasnostj	doc_676618345565_item	2804334	et	4	main
tõstsid	doc_676618345565_item	2804343	et	4	main
inimesed	doc_676618345565_item	2804346	et	3	main
on	doc_676618345565_item	2804359	et	4	main
varem	doc_676618345565_item	2804363	et	4	main
ühiskondlikke	doc_676618345565_item	2804372	et	3	main
kaetud	doc_676618345565_item	2804384	et	4	main
lauad	doc_676618345565_item	2804385	et	3	main
rahvuskultuuri	doc_676618345565_item	2804392	et	4	main
vastu	doc_676618345565_item	2804394	et	3	main
balletti	doc_676618345565_item	2804424	et	4	main
eestiballaadide	doc_676618345565_item	2804426	et	3	main
tegi	doc_676618345565_item	2804429	et	4	main
veelinnu	doc_676618345565_item	2804431	et	4	main
teadusel	doc_676618345565_item	2804433	et	3	main
kasv	doc_676618345565_item	2804437	et	3	main
kõige	doc_676618345565_item	2804443	et	4	main
ajal	doc_676618345565_item	2804485	et	4	main
püüti	doc_676618345565_item	2804486	et	3	main
ümberkorraldata	doc_676618345565_item	2804489	et	4	main
kõik	doc_676618345565_item	2804495	et	4	main
ei	doc_676618345565_item	2804499	et	4	main
tohi	doc_676618345565_item	2804500	et	4	main
olla	doc_676618345565_item	2804501	et	3	main
mingeid	doc_676618345565_item	2804502	et	3	main
saladusi	doc_676618345565_item	2804503	et	3	main
tähendust	doc_676618345565_item	2804505	et	4	main
arengut	doc_676618345565_item	2804513	et	3	main
pärast	doc_676618345565_item	2804514	et	4	main
glasnost	doc_676618345565_item	2804517	et	4	main
ette	doc_670731433480_item	2804283	et	4	main
8	doc_670731433480_item	2804288	et	2	main
b	doc_670731433480_item	2804291	et	4	main
a	doc_670731433480_item	2804307	et	4	main
käige	doc_670731433480_item	2804310	et	3	main
1	doc_676618345565_item	2804316	et	2	main
19701980	doc_676618345565_item	2804318	et	2	main
eesti	doc_676618345565_item	2804320	et	4	main
kultuurielu	doc_676618345565_item	2804321	et	4	main
ja	doc_676618345565_item	2804348	et	3	main
usuvat	doc_676618345565_item	2804349	et	4	main
laulupeol	doc_676618345565_item	2804354	et	4	main
minu	doc_676618345565_item	2804360	et	3	main
apervik	doc_676618345565_item	2804383	et	4	main
jt	doc_676618345565_item	2804389	et	4	main
mälu	doc_676618345565_item	2804393	et	4	main
lmeri	doc_676618345565_item	2804430	et	4	main
piirduma	doc_676618345565_item	2804435	et	3	main
osakaal	doc_676618345565_item	2804442	et	3	main
arv	doc_676618345565_item	2804451	et	3	main
käia	doc_676618345565_item	2804455	et	4	main
kinos	doc_676618345565_item	2804457	et	3	main
kasvas	doc_676618345565_item	2804459	et	3	main
eripärasust	doc_676618345565_item	2804476	et	4	main
eestlasi	doc_676618345565_item	2804478	et	3	main
muuta	doc_676618345565_item	2804488	et	4	main
majandust	doc_676618345565_item	2804490	et	4	main
eluviisi	doc_676618345565_item	2804491	et	4	main
glasnostj	doc_676618345565_item	2804492	et	4	main
tähendas	doc_676618345565_item	2804493	et	3	main
et	doc_676618345565_item	2804494	et	3	main
stagnatsiooni	doc_676618345565_item	2804515	et	4	main
tähendas	doc_676618345565_item	2804518	et	3	main
ja	doc_680929863179_item	2804659	et	3	main
kodumaafilmid	doc_680929863179_item	2804660	et	3	main
armastusfilm	doc_680929863179_item	2804663	et	3	main
abielluvad	doc_680929863179_item	2804715	et	4	main
woman	doc_680929863179_item	2804717	et	4	main
on	doc_680929863179_item	2804718	et	4	main
olla	doc_680929863179_item	2804724	et	3	main
sureb	doc_680929863179_item	2804734	et	3	main
näide	doc_680929863179_item	2804735	et	3	main
selleks	doc_680929863179_item	2804736	et	4	main
rääkitakse	doc_680929863179_item	2804745	et	4	main
meeldi	doc_680929863179_item	2804754	et	4	main
partner	doc_680929863179_item	2804755	et	3	main
salaja	doc_680929863179_item	2804759	et	3	main
kodumaafilmid	doc_680929863179_item	2804761	et	3	main
samal	doc_680929863179_item	2804765	et	3	main
aga	doc_680929863179_item	2804768	et	3	main
räägivad	doc_680929863179_item	2804771	et	3	main
alati	doc_680929863179_item	2804799	et	4	main
filmis	doc_680929863179_item	2804803	et	4	main
õnnelik	doc_680929863179_item	2804806	et	3	main
oli	doc_680929863179_item	2804809	et	3	main
suurem	doc_680929863179_item	2804812	et	4	main
1950	doc_680929863179_item	2804814	et	2	main
ja	doc_680929863179_item	2804815	et	3	main
nn	doc_676618345565_item	2804323	et	4	main
revolutsiooni	doc_676618345565_item	2804326	et	4	main
3	doc_676618345565_item	2804330	et	2	main
sõnade	doc_676618345565_item	2804331	et	3	main
isamaa	doc_676618345565_item	2804358	et	4	main
arm	doc_676618345565_item	2804361	et	3	main
mis	doc_676618345565_item	2804362	et	4	main
oli	doc_676618345565_item	2804364	et	3	main
1	doc_676618345565_item	2804366	et	2	main
1980	doc_676618345565_item	2804368	et	2	main
konfliktseise	doc_676618345565_item	2804373	et	4	main
tegelaseks	doc_676618345565_item	2804376	et	3	main
naine	doc_676618345565_item	2804379	et	3	main
väga	doc_676618345565_item	2804380	et	3	main
tuntud	doc_676618345565_item	2804381	et	4	main
kasvas	doc_676618345565_item	2804390	et	3	main
kunstis	doc_676618345565_item	2804395	et	3	main
püüti	doc_676618345565_item	2804396	et	3	main
vastata	doc_676618345565_item	2804397	et	4	main
küsimusele	doc_676618345565_item	2804398	et	4	main
kes	doc_676618345565_item	2804399	et	4	main
me	doc_676618345565_item	2804400	et	4	main
oleme	doc_676618345565_item	2804401	et	3	main
ja	doc_676618345565_item	2804402	et	3	main
kust	doc_676618345565_item	2804403	et	4	main
me	doc_676618345565_item	2804404	et	4	main
tuleme	doc_676618345565_item	2804405	et	3	main
publitsistikas	doc_676618345565_item	2804406	et	3	main
oli	doc_676618345565_item	2804407	et	3	main
väga	doc_676618345565_item	2804408	et	3	main
hea	doc_676618345565_item	2804409	et	4	main
töö	doc_676618345565_item	2804410	et	4	main
lmerel	doc_676618345565_item	2804411	et	4	main
hõbevalge	doc_676618345565_item	2804412	et	4	main
veel	doc_676618345565_item	2804413	et	4	main
jkross	doc_676618345565_item	2804414	et	4	main
kirjutas	doc_676618345565_item	2804415	et	3	main
ajaloolisi	doc_676618345565_item	2804416	et	4	main
romaane	doc_676618345565_item	2804417	et	3	main
luuletajast	doc_676618345565_item	2804418	et	4	main
oli	doc_676618345565_item	2804419	et	3	main
hanno	doc_676618345565_item	2804420	et	4	main
runnel	doc_676618345565_item	2804421	et	4	main
filmid	doc_676618345565_item	2804428	et	4	main
suurenes	doc_676618345565_item	2804439	et	4	main
töötajate	doc_676618345565_item	2804441	et	4	main
olulisemad	doc_676618345565_item	2804444	et	4	main
saavutused	doc_676618345565_item	2804445	et	4	main
olid	doc_676618345565_item	2804446	et	4	main
reaal-	doc_676618345565_item	2804447	et	3	main
ja	doc_676618345565_item	2804448	et	3	main
loodusteaduses	doc_676618345565_item	2804449	et	3	main
kultuuritarbijate	doc_676618345565_item	2804450	et	3	main
rohkem	doc_676618345565_item	2804454	et	4	main
muuseumis	doc_676618345565_item	2804458	et	3	main
koorimuusikat	doc_676618345565_item	2804422	et	3	main
ja	doc_676618345565_item	2804423	et	3	main
hakkas	doc_676618345565_item	2804434	et	3	main
aga	doc_676618345565_item	2804438	et	3	main
hakati	doc_676618345565_item	2804453	et	3	main
teatris	doc_676618345565_item	2804456	et	3	main
raamatukogude	doc_676618345565_item	2804461	et	3	main
arv	doc_676618345565_item	2804462	et	3	main
aga	doc_676618345565_item	2804463	et	3	main
halvenes	doc_676618345565_item	2804464	et	3	main
olukord	doc_676618345565_item	2804465	et	3	main
maal	doc_676618345565_item	2804466	et	4	main
küla	doc_676618345565_item	2804467	et	4	main
kultuuri	doc_676618345565_item	2804468	et	4	main
struktuur	doc_676618345565_item	2804469	et	3	main
lähenes	doc_676618345565_item	2804470	et	3	main
linna	doc_676618345565_item	2804471	et	4	main
omale	doc_676618345565_item	2804472	et	3	main
ning	doc_676618345565_item	2804473	et	3	main
kaotas	doc_676618345565_item	2804474	et	3	main
oma	doc_676618345565_item	2804475	et	4	main
kiiresti	doc_676618345565_item	2804460	et	3	main
perestroika	doc_676618345565_item	2804484	et	4	main
võttis	doc_676618345565_item	2804506	et	3	main
see	doc_676618345565_item	2804509	et	3	main
ajast	doc_676618345565_item	2804516	et	4	main
armastus-	doc_680929863179_item	2804658	et	4	main
meelest	doc_680929863179_item	2804662	et	4	main
on	doc_680929863179_item	2804664	et	4	main
milles	doc_680929863179_item	2804667	et	3	main
armastusest	doc_680929863179_item	2804669	et	4	main
olla	doc_680929863179_item	2804672	et	3	main
tihti	doc_680929863179_item	2804713	et	3	main
ka	doc_680929863179_item	2804725	et	3	main
draama	doc_680929863179_item	2804726	et	4	main
siis	doc_680929863179_item	2804727	et	3	main
vähemalt	doc_680929863179_item	2804728	et	4	main
üks	doc_680929863179_item	2804729	et	3	main
on	doc_680929863179_item	2804737	et	4	main
minu	doc_680929863179_item	2804738	et	3	main
titanic	doc_680929863179_item	2804743	et	4	main
probleemidest	doc_680929863179_item	2804748	et	3	main
armastaja	doc_680929863179_item	2804751	et	4	main
ja	doc_680929863179_item	2804756	et	3	main
ajal	doc_680929863179_item	2804766	et	4	main
juhtub	doc_680929863179_item	2804801	et	3	main
kõige	doc_680929863179_item	2804811	et	4	main
žanre	doc_680929863179_item	2804813	et	2	main
1960	doc_680929863179_item	2804816	et	2	main
aastal	doc_680929863179_item	2804817	et	3	main
ma	doc_680929863179_item	2804818	et	3	main
usun	doc_680929863179_item	2804819	et	3	main
et	doc_680929863179_item	2804820	et	3	main
filmides	doc_680929863179_item	2804834	et	4	main
inimestel	doc_680929863179_item	2804835	et	3	main
laulavad	doc_680929863179_item	2804843	et	4	main
perekonnad	doc_680929863179_item	2804846	et	4	main
on	doc_680929863179_item	2804847	et	4	main
korras	doc_680929863179_item	2804848	et	4	main
inimestel	doc_680929863179_item	2804849	et	3	main
hea	doc_680929863179_item	2804854	et	4	main
on	doc_680929863179_item	2804857	et	4	main
ja	doc_680929863179_item	2804859	et	3	main
konfliktid	doc_680929863179_item	2804860	et	3	main
pole	doc_680929863179_item	2804861	et	3	main
pahad	doc_680929863179_item	2804862	et	4	main
tüüpilised	doc_680929863179_item	2804863	et	3	main
ametid	doc_680929863179_item	2804864	et	3	main
kodumaafilmides	doc_680929863179_item	2804865	et	3	main
õpetaja	doc_680929863179_item	2804873	et	4	main
et	doc_680929863179_item	2804877	et	3	main
teadmatus	doc_680929863179_item	2804880	et	4	main
aga	doc_680929863179_item	2804888	et	3	main
ta	doc_680929863179_item	2804889	et	4	main
kunagi	doc_680929863179_item	2804891	et	3	main
tulevad	doc_680929863179_item	2804902	et	4	main
tulevad	doc_680929863179_item	2804906	et	4	main
ja	doc_680929863179_item	2804908	et	3	main
maa	doc_680929863179_item	2804909	et	4	main
kummistuslikud	doc_680929863179_item	2804925	et	4	main
selles	doc_680929863179_item	2804926	et	4	main
ilus	doc_680929863179_item	2804933	et	4	main
sest	doc_680929863179_item	2804946	et	4	main
mõjus	doc_676618345565_item	2804479	et	4	main
soome	doc_676618345565_item	2804481	et	3	main
televisioon	doc_676618345565_item	2804482	et	4	main
3	doc_676618345565_item	2804483	et	2	main
peavad	doc_676618345565_item	2804496	et	4	main
reada	doc_676618345565_item	2804498	et	4	main
perestroika	doc_676618345565_item	2804504	et	4	main
gorbatshov	doc_676618345565_item	2804508	et	4	main
tähendab	doc_676618345565_item	2804510	et	3	main
et	doc_676618345565_item	2804521	et	3	main
kättesaadav	doc_676618345565_item	2804525	et	4	main
väliskapitaali	doc_676618345565_item	2804528	et	4	main
spetsialiste	doc_676618345565_item	2804530	et	3	main
minu	doc_680929863179_item	2804661	et	3	main
armastuspaar	doc_680929863179_item	2804709	et	4	main
ja	doc_680929863179_item	2804712	et	3	main
armastuskomöödia	doc_680929863179_item	2804721	et	4	main
võib	doc_680929863179_item	2804723	et	3	main
schiwago	doc_680929863179_item	2804741	et	4	main
ka	doc_680929863179_item	2804746	et	3	main
armastajad	doc_680929863179_item	2804757	et	4	main
sõprust	doc_680929863179_item	2804772	et	3	main
ja	doc_680929863179_item	2804802	et	3	main
saksamaal	doc_680929863179_item	2804810	et	4	main
tahtsid	doc_680929863179_item	2804822	et	4	main
ja	doc_680929863179_item	2804844	et	3	main
ja	doc_680929863179_item	2804855	et	3	main
pastor	doc_680929863179_item	2804867	et	3	main
metsavaht	doc_680929863179_item	2804871	et	3	main
selleks	doc_680929863179_item	2804876	et	4	main
on	doc_680929863179_item	2804879	et	4	main
tuleb	doc_680929863179_item	2804881	et	3	main
ka	doc_680929863179_item	2804882	et	3	main
hangeldaja	doc_680929863179_item	2804883	et	4	main
mitte	doc_680929863179_item	2804890	et	3	main
paha	doc_680929863179_item	2804894	et	4	main
esile	doc_680929863179_item	2804903	et	3	main
imelik	doc_680929863179_item	2804911	et	3	main
meelest	doc_680929863179_item	2804922	et	4	main
on	doc_680929863179_item	2804924	et	4	main
mõnikord	doc_680929863179_item	2804944	et	3	main
ja	doc_680929863179_item	2804963	et	3	main
meeldi	doc_680929863179_item	2804986	et	4	main
et	doc_680929863179_item	2804987	et	3	main
näida	doc_680929863179_item	2804990	et	4	main
kümme	doc_680929863179_item	2805000	et	3	main
sõja	doc_680929863179_item	2805004	et	3	main
ameerikas	doc_680929863179_item	2805020	et	4	main
informatsioon	doc_676618345565_item	2804523	et	3	main
hakati	doc_676618345565_item	2804526	et	3	main
kasutama	doc_676618345565_item	2804527	et	3	main
ja	doc_676618345565_item	2804529	et	3	main
essee	doc_680929863179_item	2804657	et	4	main
film	doc_680929863179_item	2804666	et	3	main
võib	doc_680929863179_item	2804671	et	3	main
komöödia	doc_680929863179_item	2804699	et	4	main
end	doc_680929863179_item	2804702	et	4	main
ehk	doc_680929863179_item	2804703	et	3	main
õnnelik	doc_680929863179_item	2804704	et	3	main
lõpp	doc_680929863179_item	2804705	et	3	main
see	doc_680929863179_item	2804706	et	3	main
tähendab	doc_680929863179_item	2804707	et	3	main
et	doc_680929863179_item	2804708	et	3	main
koos	doc_680929863179_item	2804711	et	4	main
minu	doc_680929863179_item	2804719	et	3	main
meelest	doc_680929863179_item	2804720	et	4	main
selline	doc_680929863179_item	2804665	et	4	main
rääkitakse	doc_680929863179_item	2804668	et	4	main
see	doc_680929863179_item	2804670	et	3	main
draama	doc_680929863179_item	2804673	et	4	main
ehk	doc_680929863179_item	2804674	et	3	main
komöödia	doc_680929863179_item	2804675	et	4	main
film	doc_680929863179_item	2804676	et	3	main
räägib	doc_680929863179_item	2804677	et	3	main
tihti	doc_680929863179_item	2804678	et	3	main
romantilistelt	doc_680929863179_item	2804679	et	3	main
teemadelt	doc_680929863179_item	2804680	et	3	main
peaasjalikult	doc_680929863179_item	2804681	et	4	main
ühelt	doc_680929863179_item	2804682	et	3	main
või	doc_680929863179_item	2804683	et	4	main
rohkem	doc_680929863179_item	2804684	et	4	main
paaridelt	doc_680929863179_item	2804685	et	3	main
kes	doc_680929863179_item	2804686	et	4	main
on	doc_680929863179_item	2804687	et	4	main
armastuses	doc_680929863179_item	2804688	et	4	main
muu	doc_680929863179_item	2804689	et	4	main
jutustus	doc_680929863179_item	2804690	et	4	main
on	doc_680929863179_item	2804691	et	4	main
vähem	doc_680929863179_item	2804692	et	4	main
huvitav	doc_680929863179_item	2804693	et	4	main
ja	doc_680929863179_item	2804694	et	3	main
tagapõhjal	doc_680929863179_item	2804695	et	3	main
kui	doc_680929863179_item	2804696	et	3	main
armastusfilm	doc_680929863179_item	2804697	et	3	main
on	doc_680929863179_item	2804698	et	4	main
juhtub	doc_680929863179_item	2804700	et	3	main
happy	doc_680929863179_item	2804701	et	4	main
jääb	doc_680929863179_item	2804710	et	3	main
armastajad	doc_680929863179_item	2804714	et	4	main
pretty	doc_680929863179_item	2804716	et	4	main
armastajadest	doc_680929863179_item	2804731	et	4	main
lahkub	doc_680929863179_item	2804732	et	3	main
või	doc_680929863179_item	2804733	et	4	main
või	doc_680929863179_item	2804742	et	4	main
armastusfilmis	doc_680929863179_item	2804744	et	3	main
näiteks	doc_680929863179_item	2804749	et	4	main
ühe	doc_680929863179_item	2804750	et	4	main
vanemadele	doc_680929863179_item	2804752	et	4	main
ei	doc_680929863179_item	2804753	et	4	main
peavad	doc_680929863179_item	2804758	et	4	main
kohtuda	doc_680929863179_item	2804760	et	3	main
on	doc_680929863179_item	2804762	et	4	main
tihti	doc_680929863179_item	2804764	et	3	main
need	doc_680929863179_item	2804769	et	3	main
mis	doc_680929863179_item	2804800	et	4	main
loomulikult	doc_680929863179_item	2804805	et	4	main
kodumaafilm	doc_680929863179_item	2804808	et	3	main
inimesed	doc_680929863179_item	2804821	et	3	main
ajaviidet	doc_680929863179_item	2804823	et	3	main
tahtsid	doc_680929863179_item	2804826	et	4	main
ei	doc_680929863179_item	2804836	et	4	main
ole	doc_680929863179_item	2804837	et	4	main
paljusid	doc_680929863179_item	2804838	et	3	main
probleeme	doc_680929863179_item	2804839	et	3	main
tihti	doc_680929863179_item	2804842	et	3	main
traditsionaalseid	doc_680929863179_item	2804851	et	3	main
võõrastemaja	doc_680929863179_item	2804869	et	4	main
ja	doc_680929863179_item	2804874	et	3	main
filmides	doc_680929863179_item	2804878	et	4	main
paha	doc_680929863179_item	2804886	et	4	main
inimene	doc_680929863179_item	2804887	et	3	main
nad	doc_680929863179_item	2804904	et	3	main
on	doc_680929863179_item	2804910	et	4	main
ethelberti	doc_680929863179_item	2804921	et	4	main
hobused	doc_680929863179_item	2804923	et	4	main
näiteks	doc_680929863179_item	2804932	et	4	main
holsteiner	doc_680929863179_item	2804935	et	4	main
päästa	doc_680929863179_item	2804941	et	4	main
kodumaafilmides	doc_680929863179_item	2804945	et	3	main
kodumaafilmid	doc_680929863179_item	2804956	et	3	main
sest	doc_680929863179_item	2804959	et	4	main
need	doc_680929863179_item	2804960	et	3	main
sügavad	doc_680929863179_item	2804962	et	4	main
probleemid	doc_680929863179_item	2804965	et	3	main
need	doc_680929863179_item	2804988	et	3	main
tõelisust	doc_680929863179_item	2804991	et	4	main
kuidas	doc_680929863179_item	2804992	et	3	main
see	doc_680929863179_item	2804993	et	3	main
oli	doc_680929863179_item	2804994	et	3	main
aga	doc_680929863179_item	2804995	et	3	main
ma	doc_680929863179_item	2804996	et	3	main
saan	doc_680929863179_item	2804997	et	4	main
aastat	doc_680929863179_item	2805001	et	3	main
keegi	doc_680929863179_item	2805006	et	4	main
sõjaajalt	doc_680929863179_item	2805011	et	3	main
saksamaa	doc_680929863179_item	2805012	et	4	main
milles	doc_680929863179_item	2805016	et	3	main
žanrena	doc_680929863179_item	2805019	et	2	main
on	doc_680929863179_item	2805021	et	4	main
samasugused	doc_680929863179_item	2805024	et	3	main
armastusfilm	doc_680929863179_item	2804722	et	3	main
neist	doc_680929863179_item	2804730	et	4	main
meelest	doc_680929863179_item	2804739	et	4	main
doktor	doc_680929863179_item	2804740	et	3	main
armastajade	doc_680929863179_item	2804747	et	4	main
väga	doc_680929863179_item	2804763	et	3	main
armastusfilmid	doc_680929863179_item	2804767	et	3	main
ka	doc_680929863179_item	2804770	et	3	main
perekonnast	doc_680929863179_item	2804773	et	4	main
maa-elust	doc_680929863179_item	2804775	et	3	main
ja	doc_680929863179_item	2804774	et	3	main
sageli	doc_680929863179_item	2804776	et	3	main
jutustus	doc_680929863179_item	2804777	et	4	main
baierimaa	doc_680929863179_item	2804779	et	4	main
austria	doc_680929863179_item	2804780	et	4	main
on	doc_680929863179_item	2804778	et	4	main
või	doc_680929863179_item	2804781	et	4	main
šveitsi	doc_680929863179_item	2804782	et	2	main
mäedes	doc_680929863179_item	2804783	et	4	main
mustmetsas	doc_680929863179_item	2804784	et	3	main
või	doc_680929863179_item	2804785	et	4	main
see	doc_680929863179_item	2804786	et	3	main
võib	doc_680929863179_item	2804787	et	3	main
olla	doc_680929863179_item	2804788	et	3	main
ka	doc_680929863179_item	2804789	et	3	main
põhisaksamaal	doc_680929863179_item	2804790	et	4	main
näiteks	doc_680929863179_item	2804791	et	4	main
lüneburgi	doc_680929863179_item	2804792	et	4	main
heidis	doc_680929863179_item	2804793	et	4	main
kui	doc_680929863179_item	2804794	et	3	main
vaadab	doc_680929863179_item	2804795	et	4	main
sellist	doc_680929863179_item	2804796	et	4	main
filmit	doc_680929863179_item	2804797	et	4	main
teab	doc_680929863179_item	2804798	et	3	main
on	doc_680929863179_item	2804804	et	4	main
lõpp	doc_680929863179_item	2804807	et	3	main
sõjalt	doc_680929863179_item	2804824	et	3	main
nad	doc_680929863179_item	2804825	et	3	main
iluseid	doc_680929863179_item	2804829	et	3	main
maastikke	doc_680929863179_item	2804830	et	4	main
ja	doc_680929863179_item	2804831	et	3	main
iluseid	doc_680929863179_item	2804832	et	3	main
inimesi	doc_680929863179_item	2804833	et	4	main
nad	doc_680929863179_item	2804841	et	3	main
tantsivad	doc_680929863179_item	2804845	et	4	main
köstüüme	doc_680929863179_item	2804852	et	4	main
on	doc_680929863179_item	2804866	et	4	main
või	doc_680929863179_item	2804884	et	4	main
teine	doc_680929863179_item	2804885	et	3	main
on	doc_680929863179_item	2804892	et	4	main
tapja	doc_680929863179_item	2804896	et	4	main
ka	doc_680929863179_item	2804900	et	3	main
neile	doc_680929863179_item	2804912	et	4	main
filmis	doc_680929863179_item	2804927	et	4	main
on	doc_680929863179_item	2804928	et	4	main
ka	doc_680929863179_item	2804929	et	3	main
tüüpilisi	doc_680929863179_item	2804930	et	3	main
schweiz	doc_680929863179_item	2804936	et	4	main
hobuseid	doc_680929863179_item	2804937	et	4	main
ja	doc_680929863179_item	2804938	et	3	main
on	doc_680929863179_item	2804943	et	4	main
paljusid	doc_680929863179_item	2804948	et	3	main
vastandeid	doc_680929863179_item	2804950	et	4	main
nii	doc_680929863179_item	2804951	et	3	main
kui	doc_680929863179_item	2804952	et	3	main
vanad-noored	doc_680929863179_item	2804954	et	3	main
ei	doc_680929863179_item	2805007	et	4	main
tahtnud	doc_680929863179_item	2805008	et	4	main
ainuke	doc_680929863179_item	2805014	et	4	main
ainult	doc_680929863179_item	2804827	et	4	main
vaadata	doc_680929863179_item	2804828	et	4	main
ja	doc_680929863179_item	2804840	et	3	main
on	doc_680929863179_item	2804850	et	4	main
peal	doc_680929863179_item	2804853	et	4	main
paha	doc_680929863179_item	2804856	et	4	main
eraldadud	doc_680929863179_item	2804858	et	4	main
arst	doc_680929863179_item	2804868	et	3	main
omanik	doc_680929863179_item	2804870	et	3	main
jahimees	doc_680929863179_item	2804872	et	4	main
maaharija	doc_680929863179_item	2804875	et	4	main
nii	doc_680929863179_item	2804893	et	3	main
kui	doc_680929863179_item	2804895	et	3	main
või	doc_680929863179_item	2804897	et	4	main
veemöll	doc_680929863179_item	2804898	et	3	main
sageli	doc_680929863179_item	2804899	et	3	main
turistid	doc_680929863179_item	2804901	et	3	main
tavaliselt	doc_680929863179_item	2804905	et	4	main
linnast	doc_680929863179_item	2804907	et	4	main
nii	doc_680929863179_item	2804913	et	3	main
kui	doc_680929863179_item	2804914	et	3	main
die	doc_680929863179_item	2804915	et	4	main
mädchen	doc_680929863179_item	2804916	et	4	main
vom	doc_680929863179_item	2804917	et	4	main
immenhof	doc_680929863179_item	2804918	et	4	main
tüdrukute	doc_680929863179_item	2804919	et	4	main
onupoja	doc_680929863179_item	2804920	et	4	main
klišeid	doc_680929863179_item	2804931	et	2	main
maastik	doc_680929863179_item	2804934	et	3	main
perekonna	doc_680929863179_item	2804939	et	4	main
mõisa	doc_680929863179_item	2804940	et	3	main
teadmatus	doc_680929863179_item	2804942	et	4	main
on	doc_680929863179_item	2804947	et	4	main
erinevaid	doc_680929863179_item	2804949	et	4	main
traditsioonid-arenamised	doc_680929863179_item	2804955	et	4	main
kitsch	doc_680929863179_item	2804958	et	4	main
ka	doc_680929863179_item	2804964	et	3	main
nii	doc_680929863179_item	2804967	et	3	main
halvad	doc_680929863179_item	2804968	et	4	main
situatsionid	doc_680929863179_item	2804969	et	4	main
filmis	doc_680929863179_item	2804970	et	4	main
ei	doc_680929863179_item	2804971	et	4	main
ole	doc_680929863179_item	2804972	et	4	main
reaalsed	doc_680929863179_item	2804973	et	3	main
aga	doc_680929863179_item	2804974	et	3	main
need	doc_680929863179_item	2804975	et	3	main
filmid	doc_680929863179_item	2804976	et	4	main
on	doc_680929863179_item	2804977	et	4	main
üsna	doc_680929863179_item	2804978	et	3	main
naljakad	doc_680929863179_item	2804979	et	3	main
näiteks	doc_680929863179_item	2804980	et	4	main
kui	doc_680929863179_item	2804981	et	3	main
inimesed	doc_680929863179_item	2804982	et	3	main
mulle	doc_680929863179_item	2804984	et	4	main
laulavad	doc_680929863179_item	2804983	et	4	main
ei	doc_680929863179_item	2804985	et	4	main
maa-linn	doc_680929863179_item	2804953	et	3	main
on	doc_680929863179_item	2804957	et	4	main
polnud	doc_680929863179_item	2804961	et	3	main
polnud	doc_680929863179_item	2804966	et	3	main
ei	doc_680929863179_item	2804989	et	4	main
vaadata	doc_680929863179_item	2805009	et	4	main
on	doc_680929863179_item	2805013	et	4	main
maa	doc_680929863179_item	2805015	et	4	main
on	doc_680929863179_item	2805017	et	4	main
kodumaafilme	doc_680929863179_item	2805018	et	3	main
üsna	doc_680929863179_item	2805023	et	3	main
aru	doc_680929863179_item	2804998	et	4	main
et	doc_680929863179_item	2804999	et	3	main
pärast	doc_680929863179_item	2805002	et	4	main
maailma	doc_680929863179_item	2805003	et	4	main
mitte	doc_680929863179_item	2805005	et	3	main
midagi	doc_680929863179_item	2805010	et	4	main
western-filmid	doc_680929863179_item	2805022	et	4	main
minu	doc_680929863182_item	2805505	et	3	main
külas	doc_680929863182_item	2805521	et	3	main
pizza	doc_680929863182_item	2805524	et	4	main
me	doc_680929863182_item	2805528	et	4	main
vaatasime	doc_680929863182_item	2805529	et	3	main
nimi	doc_680929863182_item	2805533	et	3	main
rumal	doc_680929863182_item	2805539	et	3	main
aga	doc_680929863182_item	2805541	et	3	main
koju	doc_680929863182_item	2805561	et	3	main
matk	doc_680929863182_item	2805562	et	3	main
mind	doc_680929863182_item	2805575	et	4	main
ees	doc_680929863182_item	2805577	et	4	main
jõuluturule	doc_680929863182_item	2805586	et	3	main
seal	doc_680929863182_item	2805593	et	4	main
palju	doc_680929863182_item	2805595	et	4	main
söövad	doc_680929863182_item	2805607	et	4	main
kestis	doc_680929863182_item	2805619	et	4	main
vaid	doc_680929863182_item	2805620	et	3	main
nädalavahetus	doc_680929863182_item	2805504	et	4	main
me	doc_680929863182_item	2805522	et	4	main
barbarella	doc_680929863182_item	2805535	et	4	main
väga	doc_680929863182_item	2805538	et	3	main
ka	doc_680929863182_item	2805542	et	3	main
reedel	doc_680929863182_item	2805545	et	3	main
raudteejaamal	doc_680929863182_item	2805555	et	3	main
kümne	doc_680929863182_item	2805557	et	4	main
rongiga	doc_680929863182_item	2805560	et	4	main
kaks	doc_680929863182_item	2805565	et	3	main
tundi	doc_680929863182_item	2805566	et	4	main
ka	doc_680929863182_item	2805582	et	3	main
me	doc_680929863182_item	2805584	et	4	main
teisiti	doc_680929863182_item	2805590	et	3	main
kes	doc_680929863182_item	2805606	et	4	main
õnneks	doc_680929863182_item	2805617	et	4	main
see	doc_680929863182_item	2805618	et	3	main
minutit	doc_680929863182_item	2805622	et	3	main
ilm	doc_680929863182_item	2805630	et	3	main
terve	doc_680929863182_item	2805632	et	4	main
päeva	doc_680929863182_item	2805633	et	4	main
tuuline	doc_680929863182_item	2805640	et	3	main
kell	doc_680929863182_item	2805653	et	3	main
kümne	doc_680929863182_item	2805655	et	4	main
hommikusööki	doc_680929863182_item	2805659	et	4	main
perekonnaga	doc_680929863182_item	2805661	et	4	main
oli	doc_680929863182_item	2805663	et	3	main
ma	doc_680929863182_item	2805667	et	3	main
kaua	doc_680929863182_item	2805672	et	3	main
göttingenisse	doc_680929863182_item	2805677	et	4	main
juba	doc_680929863182_item	2805678	et	3	main
kell	doc_680929863182_item	2805679	et	3	main
kaks	doc_680929863182_item	2805680	et	3	main
ma	doc_680929863182_item	2805681	et	3	main
göttingenis	doc_680929863182_item	2805684	et	4	main
neli	doc_680929863182_item	2805686	et	3	main
tahaksin	doc_680929863182_item	2805689	et	3	main
ei	doc_680929863182_item	2805694	et	4	main
olnud	doc_680929863182_item	2805695	et	4	main
haige	doc_680929863182_item	2805699	et	4	main
ja	doc_680929863182_item	2805704	et	3	main
taas	doc_680929863182_item	2805706	et	3	main
pizza	doc_680929863182_item	2805707	et	4	main
oma	doc_680929863182_item	2805708	et	4	main
pühapäeva	doc_680929863182_item	2805721	et	4	main
sõpratega	doc_680929863182_item	2805731	et	4	main
siia	doc_680929863182_item	2805735	et	4	main
ei	doc_680929863182_item	2805745	et	4	main
jagrattaga	doc_680929863182_item	2805748	et	4	main
olin	doc_680929863183_item	2805782	et	3	main
mida	doc_680929863183_item	2805787	et	4	main
õele	doc_680929863183_item	2805791	et	3	main
essee	doc_680929863182_item	2805503	et	4	main
nädalavahetus	doc_680929863182_item	2805506	et	4	main
kestab	doc_680929863182_item	2805507	et	4	main
kolm	doc_680929863182_item	2805508	et	3	main
päeva	doc_680929863182_item	2805509	et	4	main
sest	doc_680929863182_item	2805510	et	4	main
mul	doc_680929863182_item	2805511	et	3	main
ei	doc_680929863182_item	2805512	et	4	main
ole	doc_680929863182_item	2805513	et	4	main
ülikooli	doc_680929863182_item	2805514	et	4	main
reedel	doc_680929863182_item	2805515	et	3	main
neljapäeval	doc_680929863182_item	2805516	et	3	main
ma	doc_680929863182_item	2805517	et	3	main
olin	doc_680929863182_item	2805518	et	3	main
õhtul	doc_680929863182_item	2805519	et	3	main
sõbranna	doc_680929863182_item	2805520	et	4	main
küpsetasime	doc_680929863182_item	2805523	et	3	main
ja	doc_680929863182_item	2805525	et	3	main
televiisorit	doc_680929863182_item	2805527	et	3	main
ühe	doc_680929863182_item	2805530	et	4	main
oli	doc_680929863182_item	2805534	et	3	main
on	doc_680929863182_item	2805537	et	4	main
film	doc_680929863182_item	2805540	et	3	main
lõbus	doc_680929863182_item	2805544	et	4	main
ma	doc_680929863182_item	2805546	et	3	main
olla	doc_680929863182_item	2805554	et	3	main
kell	doc_680929863182_item	2805556	et	3	main
ma	doc_680929863182_item	2805558	et	3	main
ümbres	doc_680929863182_item	2805564	et	4	main
vabapäev	doc_680929863182_item	2805583	et	3	main
läksime	doc_680929863182_item	2805585	et	3	main
celles	doc_680929863182_item	2805587	et	4	main
üliõpilasi	doc_680929863182_item	2805596	et	3	main
joovad	doc_680929863182_item	2805598	et	4	main
hõõgveini	doc_680929863182_item	2805599	et	4	main
aga	doc_680929863182_item	2805600	et	3	main
inimesi	doc_680929863182_item	2805605	et	4	main
kaks	doc_680929863182_item	2805610	et	3	main
pidasin	doc_680929863182_item	2805612	et	3	main
siis	doc_680929863182_item	2805623	et	3	main
aegana	doc_680929863182_item	2805634	et	4	main
halb	doc_680929863182_item	2805635	et	3	main
oli	doc_680929863182_item	2805639	et	3	main
me	doc_680929863182_item	2805641	et	4	main
ja	doc_680929863182_item	2805646	et	3	main
ajasime	doc_680929863182_item	2805647	et	3	main
juttu	doc_680929863182_item	2805648	et	4	main
laupäeval	doc_680929863182_item	2805649	et	3	main
ma	doc_680929863182_item	2805650	et	3	main
tõusin	doc_680929863182_item	2805651	et	3	main
nagu	doc_680929863182_item	2805665	et	3	main
mängisin	doc_680929863182_item	2805668	et	3	main
siis	doc_680929863182_item	2805700	et	3	main
ma	doc_680929863182_item	2805723	et	3	main
filmi	doc_680929863182_item	2805531	et	4	main
see	doc_680929863182_item	2805536	et	3	main
väga	doc_680929863182_item	2805543	et	3	main
ema	doc_680929863182_item	2805573	et	4	main
ootas	doc_680929863182_item	2805574	et	3	main
on	doc_680929863182_item	2805581	et	4	main
on	doc_680929863182_item	2805589	et	4	main
on	doc_680929863182_item	2805594	et	4	main
kes	doc_680929863182_item	2805597	et	4	main
palju	doc_680929863182_item	2805603	et	4	main
vanu	doc_680929863182_item	2805604	et	4	main
ma	doc_680929863182_item	2805611	et	3	main
hambaarsti	doc_680929863182_item	2805614	et	4	main
juurde	doc_680929863182_item	2805615	et	4	main
aga	doc_680929863182_item	2805616	et	3	main
ma	doc_680929863182_item	2805624	et	3	main
vihma	doc_680929863182_item	2805636	et	4	main
istusimme	doc_680929863182_item	2805642	et	4	main
elutoas	doc_680929863182_item	2805643	et	3	main
jõime	doc_680929863182_item	2805644	et	3	main
teet	doc_680929863182_item	2805645	et	4	main
pool	doc_680929863182_item	2805654	et	4	main
oma	doc_680929863182_item	2805660	et	4	main
ilm	doc_680929863182_item	2805662	et	3	main
klaverit	doc_680929863182_item	2805669	et	3	main
ei	doc_680929863182_item	2805671	et	4	main
sest	doc_680929863182_item	2805673	et	4	main
tagasi	doc_680929863182_item	2805676	et	3	main
olin	doc_680929863182_item	2805682	et	3	main
ma	doc_680929863182_item	2805688	et	3	main
peole	doc_680929863182_item	2805690	et	4	main
sünnipäevalaps	doc_680929863182_item	2805697	et	4	main
ma	doc_680929863182_item	2805701	et	3	main
olin	doc_680929863182_item	2805702	et	3	main
veel	doc_680929863182_item	2805729	et	4	main
kahe	doc_680929863182_item	2805730	et	3	main
nad	doc_680929863182_item	2805733	et	3	main
see	doc_680929863182_item	2805736	et	3	main
hea	doc_680929863182_item	2805738	et	4	main
sest	doc_680929863182_item	2805739	et	4	main
ma	doc_680929863182_item	2805740	et	3	main
olen	doc_680929863182_item	2805741	et	3	main
väga	doc_680929863182_item	2805742	et	3	main
tegemist	doc_680929863183_item	2805759	et	4	main
ma	doc_680929863183_item	2805760	et	3	main
ei	doc_680929863183_item	2805761	et	4	main
ja	doc_680929863183_item	2805784	et	3	main
raamatu	doc_680929863183_item	2805793	et	4	main
nimi	doc_680929863183_item	2805794	et	3	main
on	doc_680929863183_item	2805795	et	4	main
tintenherz	doc_680929863183_item	2805796	et	4	main
pidin	doc_680929863183_item	2805810	et	3	main
kell	doc_680929863183_item	2805814	et	3	main
ma	doc_680929863183_item	2805816	et	3	main
väsinud	doc_680929863183_item	2805820	et	4	main
oli	doc_680929863183_item	2805822	et	3	main
laulsime	doc_680929863183_item	2805828	et	3	main
keele	doc_680929863183_item	2805840	et	4	main
ja	doc_680929863183_item	2805849	et	3	main
raske	doc_680929863183_item	2805852	et	4	main
kui	doc_680929863183_item	2805857	et	3	main
ja	doc_680929863183_item	2805865	et	3	main
palju	doc_680929863183_item	2805868	et	4	main
laulsime	doc_680929863183_item	2805870	et	3	main
ka	doc_680929863183_item	2805871	et	3	main
jõululalud	doc_680929863183_item	2805872	et	4	main
oli	doc_680929863183_item	2805873	et	3	main
väga	doc_680929863183_item	2805874	et	3	main
ja	doc_680929863183_item	2805876	et	3	main
kuni	doc_680929863183_item	2805880	et	3	main
kuus	doc_680929863183_item	2805882	et	4	main
vaatasime	doc_680929863182_item	2805526	et	3	main
mis	doc_680929863182_item	2805532	et	4	main
tõusin	doc_680929863182_item	2805547	et	3	main
üles	doc_680929863182_item	2805548	et	3	main
kell	doc_680929863182_item	2805549	et	3	main
kaheksa	doc_680929863182_item	2805550	et	4	main
sest	doc_680929863182_item	2805551	et	4	main
ma	doc_680929863182_item	2805552	et	3	main
tahtsin	doc_680929863182_item	2805553	et	3	main
sõitsin	doc_680929863182_item	2805559	et	3	main
kestab	doc_680929863182_item	2805563	et	4	main
ma	doc_680929863182_item	2805567	et	3	main
olin	doc_680929863182_item	2805568	et	3	main
celles	doc_680929863182_item	2805569	et	4	main
kell	doc_680929863182_item	2805570	et	3	main
kaksteist	doc_680929863182_item	2805571	et	4	main
minu	doc_680929863182_item	2805572	et	3	main
raudteejaama	doc_680929863182_item	2805576	et	4	main
sest	doc_680929863182_item	2805578	et	4	main
temal	doc_680929863182_item	2805579	et	3	main
reedel	doc_680929863182_item	2805580	et	3	main
j6uluturul	doc_680929863182_item	2805588	et	4	main
kui	doc_680929863182_item	2805591	et	3	main
göttingenisgöttingenis	doc_680929863182_item	2805592	et	4	main
celles	doc_680929863182_item	2805601	et	4	main
on	doc_680929863182_item	2805602	et	4	main
vorsti	doc_680929863182_item	2805608	et	4	main
kell	doc_680929863182_item	2805609	et	3	main
minema	doc_680929863182_item	2805613	et	3	main
paar	doc_680929863182_item	2805621	et	3	main
oma	doc_680929863182_item	2805626	et	4	main
koju	doc_680929863182_item	2805628	et	3	main
oli	doc_680929863182_item	2805631	et	3	main
ja	doc_680929863182_item	2805638	et	3	main
üles	doc_680929863182_item	2805652	et	3	main
ja	doc_680929863182_item	2805656	et	3	main
sõin	doc_680929863182_item	2805658	et	3	main
halb	doc_680929863182_item	2805664	et	3	main
ma	doc_680929863182_item	2805674	et	3	main
sõitsin	doc_680929863182_item	2805675	et	3	main
kell	doc_680929863182_item	2805685	et	3	main
minna	doc_680929863182_item	2805691	et	3	main
aga	doc_680929863182_item	2805692	et	3	main
pidu	doc_680929863182_item	2805693	et	4	main
jäi	doc_680929863182_item	2805698	et	3	main
kodus	doc_680929863182_item	2805703	et	4	main
s6in	doc_680929863182_item	2805705	et	4	main
sõitsin	doc_680929863182_item	2805625	et	3	main
emaga	doc_680929863182_item	2805627	et	3	main
sest	doc_680929863182_item	2805629	et	4	main
sadas	doc_680929863182_item	2805637	et	3	main
siis	doc_680929863182_item	2805657	et	3	main
reedel	doc_680929863182_item	2805666	et	3	main
aga	doc_680929863182_item	2805670	et	3	main
siis	doc_680929863182_item	2805683	et	3	main
õhtul	doc_680929863182_item	2805687	et	3	main
sest	doc_680929863182_item	2805696	et	4	main
kaasüürilisega	doc_680929863182_item	2805709	et	4	main
pühapäeval	doc_680929863182_item	2805710	et	3	main
ma	doc_680929863182_item	2805711	et	3	main
magasin	doc_680929863182_item	2805712	et	4	main
palju	doc_680929863182_item	2805713	et	4	main
ma	doc_680929863182_item	2805714	et	3	main
õppisin	doc_680929863182_item	2805715	et	3	main
palju	doc_680929863182_item	2805716	et	4	main
ja	doc_680929863182_item	2805717	et	3	main
jõin	doc_680929863182_item	2805718	et	3	main
teet	doc_680929863182_item	2805719	et	4	main
iga	doc_680929863182_item	2805720	et	4	main
õhtul	doc_680929863182_item	2805722	et	3	main
nüüd	doc_680929863182_item	2805747	et	4	main
sõita	doc_680929863182_item	2805749	et	3	main
sest	doc_680929863182_item	2805750	et	4	main
vihma	doc_680929863182_item	2805751	et	4	main
sajab	doc_680929863182_item	2805752	et	3	main
essee	doc_680929863183_item	2805753	et	4	main
õppida	doc_680929863183_item	2805763	et	3	main
kodus	doc_680929863183_item	2805783	et	4	main
ma	doc_680929863183_item	2805788	et	3	main
ostsin	doc_680929863183_item	2805789	et	3	main
väga	doc_680929863183_item	2805801	et	3	main
hea	doc_680929863183_item	2805802	et	4	main
lugesin	doc_680929863183_item	2805805	et	3	main
olema	doc_680929863183_item	2805811	et	4	main
kümne	doc_680929863183_item	2805815	et	4	main
siis	doc_680929863183_item	2805818	et	3	main
aga	doc_680929863183_item	2805821	et	3	main
laulu	doc_680929863183_item	2805830	et	4	main
kell	doc_680929863183_item	2805831	et	3	main
üks	doc_680929863183_item	2805832	et	3	main
juba	doc_680929863183_item	2805835	et	3	main
õpettaja	doc_680929863183_item	2805841	et	4	main
kutsus	doc_680929863183_item	2805842	et	4	main
mäel	doc_680929863183_item	2805848	et	3	main
aga	doc_680929863183_item	2805856	et	3	main
me	doc_680929863183_item	2805858	et	4	main
lõpuks	doc_680929863183_item	2805860	et	4	main
väga	doc_680929863183_item	2805867	et	3	main
sööki	doc_680929863183_item	2805869	et	4	main
mugav	doc_680929863183_item	2805875	et	3	main
haigeks	doc_680929863183_item	2805929	et	4	main
aga	doc_680929863183_item	2805930	et	3	main
õhtul	doc_680929863183_item	2805931	et	3	main
seal	doc_680929863183_item	2805940	et	4	main
et	doc_680929863183_item	2805953	et	3	main
me	doc_680929863183_item	2805954	et	4	main
laulame	doc_680929863183_item	2805955	et	4	main
ja	doc_680929863183_item	2805980	et	3	main
seminaris	doc_680929863183_item	2805983	et	3	main
aga	doc_680929863183_item	2805996	et	3	main
ei	doc_680929863183_item	2805998	et	4	main
sest	doc_680929863183_item	2806000	et	4	main
skandinavistises	doc_680929863183_item	2806001	et	4	main
oli	doc_680929863183_item	2806002	et	3	main
väga	doc_680929863183_item	2806003	et	3	main
sest	doc_680929863183_item	2806031	et	4	main
ma	doc_680929863183_item	2806041	et	3	main
vaatan	doc_680929863182_item	2805724	et	3	main
kaasüürilisega	doc_680929863182_item	2805727	et	4	main
ja	doc_680929863182_item	2805728	et	3	main
täna	doc_680929863182_item	2805732	et	4	main
on	doc_680929863182_item	2805737	et	4	main
taha	doc_680929863182_item	2805746	et	4	main
nädalavehetusel	doc_680929863183_item	2805755	et	4	main
mul	doc_680929863183_item	2805756	et	3	main
oli	doc_680929863183_item	2805757	et	3	main
palu	doc_680929863183_item	2805758	et	4	main
jaksanud	doc_680929863183_item	2805762	et	4	main
nii	doc_680929863183_item	2805764	et	3	main
palju	doc_680929863183_item	2805765	et	4	main
aga	doc_680929863183_item	2805766	et	3	main
ma	doc_680929863183_item	2805767	et	3	main
laulsin	doc_680929863183_item	2805768	et	3	main
palju	doc_680929863183_item	2805769	et	4	main
õhtul	doc_680929863183_item	2805771	et	3	main
ma	doc_680929863183_item	2805772	et	3	main
olin	doc_680929863183_item	2805773	et	3	main
reedel	doc_680929863183_item	2805770	et	3	main
vaid	doc_680929863183_item	2805774	et	3	main
seminaris	doc_680929863183_item	2805775	et	3	main
kus	doc_680929863183_item	2805776	et	3	main
me	doc_680929863183_item	2805777	et	4	main
tatort	doc_680929863182_item	2805725	et	4	main
oma	doc_680929863182_item	2805726	et	4	main
tulevad	doc_680929863182_item	2805734	et	4	main
väsinud	doc_680929863182_item	2805743	et	4	main
ja	doc_680929863182_item	2805744	et	3	main
nädalavahetus	doc_680929863183_item	2805754	et	4	main
lugesin	doc_680929863183_item	2805785	et	3	main
omale	doc_680929863183_item	2805790	et	3	main
jõulekingitusekes	doc_680929863183_item	2805792	et	4	main
see	doc_680929863183_item	2805799	et	3	main
on	doc_680929863183_item	2805800	et	4	main
raamat	doc_680929863183_item	2805803	et	3	main
terve	doc_680929863183_item	2805806	et	4	main
õhtu	doc_680929863183_item	2805807	et	4	main
laupäeval	doc_680929863183_item	2805808	et	3	main
ma	doc_680929863183_item	2805809	et	3	main
vaatasime	doc_680929863183_item	2805778	et	3	main
filmi	doc_680929863183_item	2805779	et	4	main
siis	doc_680929863183_item	2805780	et	3	main
ma	doc_680929863183_item	2805781	et	3	main
raamatut	doc_680929863183_item	2805786	et	3	main
sest	doc_680929863183_item	2805798	et	4	main
ma	doc_680929863183_item	2805804	et	3	main
hea	doc_680929863183_item	2805824	et	4	main
seal	doc_680929863183_item	2805825	et	4	main
ma	doc_680929863183_item	2805833	et	3	main
minema	doc_680929863183_item	2805836	et	3	main
tema	doc_680929863183_item	2805846	et	4	main
jalgrattaga	doc_680929863183_item	2805854	et	3	main
olime	doc_680929863183_item	2805859	et	3	main
väga	doc_680929863183_item	2805866	et	3	main
olin	doc_680929863183_item	2805878	et	3	main
kell	doc_680929863183_item	2805881	et	3	main
siis	doc_680929863183_item	2805883	et	3	main
me	doc_680929863183_item	2805884	et	4	main
ma	doc_680929863183_item	2805932	et	3	main
taani	doc_680929863183_item	2805942	et	4	main
palus	doc_680929863183_item	2805952	et	4	main
ka	doc_680929863183_item	2805957	et	3	main
nelipäeva	doc_680929863183_item	2805971	et	4	main
oli	doc_680929863183_item	2805973	et	3	main
seminaris	doc_680929863183_item	2805979	et	3	main
seminarisse	doc_680929863183_item	2805994	et	3	main
sõitsin	doc_680929863183_item	2806021	et	3	main
gilmore	doc_680929863183_item	2806027	et	4	main
poeg	doc_680929863183_item	2806033	et	3	main
aeg	doc_680929863183_item	2806040	et	3	main
ja	doc_680929863183_item	2806045	et	3	main
küpsesid	doc_680929863183_item	2806047	et	4	main
janis	doc_680929863183_item	2806051	et	4	main
seal	doc_680929863183_item	2806068	et	4	main
oli	doc_680929863183_item	2806069	et	3	main
ma	doc_680929863183_item	2806072	et	3	main
kuni	doc_680929863183_item	2806077	et	3	main
seal	doc_680929863183_item	2806080	et	4	main
oli	doc_680929863183_item	2806086	et	3	main
aga	doc_680929863183_item	2806089	et	3	main
siis	doc_680929863183_item	2806133	et	3	main
vaatame	doc_680929863183_item	2806167	et	3	main
midagi	doc_680929863183_item	2806171	et	4	main
jään	doc_680929863184_item	2806184	et	3	main
põhvamaa	doc_680929863186_item	2806394	et	4	main
ida-virumaa	doc_680929863186_item	2806395	et	4	main
pärnumaa	doc_680929863186_item	2806397	et	4	main
eestis	doc_680929863186_item	2806408	et	3	main
pihkajärv	doc_680929863186_item	2806423	et	4	main
võrtsjärv	doc_680929863186_item	2806425	et	3	main
eestlased	doc_680929863186_item	2806428	et	3	main
ukrainlased	doc_680929863186_item	2806430	et	3	main
eestlased	doc_680929863186_item	2806435	et	3	main
ja	doc_680929863186_item	2806440	et	3	main
ja	doc_680929863183_item	2805797	et	3	main
kooril	doc_680929863183_item	2805812	et	4	main
juba	doc_680929863183_item	2805813	et	3	main
olin	doc_680929863183_item	2805817	et	3	main
väga	doc_680929863183_item	2805819	et	3	main
siiski	doc_680929863183_item	2805823	et	4	main
sest	doc_680929863183_item	2805826	et	4	main
meie	doc_680929863183_item	2805838	et	4	main
taani	doc_680929863183_item	2805839	et	4	main
meid	doc_680929863183_item	2805843	et	4	main
oma	doc_680929863183_item	2805844	et	4	main
elab	doc_680929863183_item	2805847	et	3	main
oli	doc_680929863183_item	2805850	et	3	main
sinna	doc_680929863183_item	2805855	et	3	main
aquavit	doc_680929863183_item	2805864	et	4	main
ma	doc_680929863183_item	2805877	et	3	main
läksime	doc_680929863183_item	2805885	et	3	main
veel	doc_680929863183_item	2805886	et	4	main
sõbrale	doc_680929863183_item	2805887	et	3	main
hiiret	doc_680929863183_item	2805921	et	4	main
ma	doc_680929863183_item	2805923	et	3	main
pean	doc_680929863183_item	2805933	et	4	main
taas	doc_680929863183_item	2805934	et	3	main
laulma	doc_680929863183_item	2805935	et	3	main
see	doc_680929863183_item	2805936	et	3	main
kord	doc_680929863183_item	2805937	et	4	main
ja	doc_680929863183_item	2805944	et	3	main
väike	doc_680929863183_item	2805946	et	4	main
ta	doc_680929863183_item	2805951	et	4	main
seal	doc_680929863183_item	2805956	et	4	main
jõululaulu	doc_680929863183_item	2805959	et	4	main
taas	doc_680929863183_item	2805962	et	3	main
nädalavahetusest	doc_680929863183_item	2805964	et	4	main
nelipäeval	doc_680929863183_item	2805970	et	3	main
õhtul	doc_680929863183_item	2805972	et	3	main
jõulepeod	doc_680929863183_item	2805975	et	4	main
oli	doc_680929863183_item	2805977	et	3	main
soome-uugri	doc_680929863183_item	2805993	et	4	main
minna	doc_680929863183_item	2805995	et	3	main
ma	doc_680929863183_item	2805997	et	3	main
lõbus	doc_680929863183_item	2806004	et	4	main
me	doc_680929863183_item	2806005	et	4	main
julianele	doc_680929863183_item	2806022	et	4	main
koos	doc_680929863183_item	2806026	et	4	main
girls	doc_680929863183_item	2806028	et	4	main
vaadata	doc_680929863183_item	2806029	et	4	main
aga	doc_680929863183_item	2806030	et	3	main
terve	doc_680929863183_item	2806039	et	4	main
jõin	doc_680929863183_item	2806042	et	3	main
ta	doc_680929863183_item	2806055	et	4	main
ajasin	doc_680929863183_item	2806059	et	3	main
julianega	doc_680929863183_item	2806061	et	4	main
kaksteistest	doc_680929863183_item	2806076	et	4	main
kell	doc_680929863183_item	2806078	et	3	main
meil	doc_680929863183_item	2806085	et	4	main
õlut	doc_680929863183_item	2806093	et	3	main
seal	doc_680929863183_item	2806125	et	4	main
ja	doc_680929863183_item	2806126	et	3	main
ma	doc_680929863183_item	2806127	et	3	main
sõitsin	doc_680929863183_item	2806128	et	3	main
alles	doc_680929863183_item	2806129	et	3	main
kell	doc_680929863183_item	2806130	et	3	main
korterikaaslasega	doc_680929863183_item	2806158	et	3	main
õhtul	doc_680929863183_item	2806160	et	3	main
sõitan	doc_680929863183_item	2806162	et	4	main
ja	doc_680929863183_item	2806169	et	3	main
kiri	doc_680929863184_item	2806173	et	3	main
pudustan	doc_680929863184_item	2806182	et	4	main
me	doc_680929863183_item	2805827	et	4	main
uue	doc_680929863183_item	2805829	et	3	main
pidin	doc_680929863183_item	2805834	et	3	main
sest	doc_680929863183_item	2805837	et	4	main
kojju	doc_680929863183_item	2805845	et	4	main
väga	doc_680929863183_item	2805851	et	3	main
sõita	doc_680929863183_item	2805853	et	3	main
seal	doc_680929863183_item	2805861	et	4	main
me	doc_680929863183_item	2805862	et	4	main
saime	doc_680929863183_item	2805863	et	3	main
seal	doc_680929863183_item	2805879	et	4	main
külale	doc_680929863183_item	2805888	et	3	main
temal	doc_680929863183_item	2805889	et	3	main
on	doc_680929863183_item	2805890	et	4	main
kitarr	doc_680929863183_item	2805891	et	3	main
ja	doc_680929863183_item	2805892	et	3	main
me	doc_680929863183_item	2805893	et	4	main
mängisime	doc_680929863183_item	2805894	et	3	main
kitarri	doc_680929863183_item	2805895	et	4	main
la	doc_680929863183_item	2805896	et	4	main
laulsime	doc_680929863183_item	2805897	et	3	main
koos	doc_680929863183_item	2805898	et	4	main
tema	doc_680929863183_item	2805899	et	4	main
köögis	doc_680929863183_item	2805900	et	3	main
elab	doc_680929863183_item	2805901	et	3	main
hiir	doc_680929863183_item	2805902	et	4	main
kes	doc_680929863183_item	2805903	et	4	main
kuulus	doc_680929863183_item	2805904	et	4	main
meid	doc_680929863183_item	2805905	et	4	main
kapi	doc_680929863183_item	2805906	et	4	main
tagalt	doc_680929863183_item	2805907	et	4	main
hiir	doc_680929863183_item	2805908	et	4	main
meeldis	doc_680929863183_item	2805909	et	3	main
mulle	doc_680929863183_item	2805910	et	4	main
aga	doc_680929863183_item	2805911	et	3	main
ma	doc_680929863183_item	2805912	et	3	main
olen	doc_680929863183_item	2805913	et	3	main
siiski	doc_680929863183_item	2805914	et	4	main
rahul	doc_680929863183_item	2805915	et	4	main
et	doc_680929863183_item	2805916	et	3	main
oma	doc_680929863183_item	2805917	et	4	main
köögis	doc_680929863183_item	2805918	et	3	main
ei	doc_680929863183_item	2805919	et	4	main
ela	doc_680929863183_item	2805920	et	4	main
pühapäeval	doc_680929863183_item	2805922	et	3	main
õpisin	doc_680929863183_item	2805924	et	4	main
ma	doc_680929863183_item	2805926	et	3	main
natuke	doc_680929863183_item	2805928	et	4	main
sest	doc_680929863183_item	2805939	et	4	main
film	doc_680929863183_item	2805943	et	3	main
palju	doc_680929863183_item	2805925	et	4	main
jäin	doc_680929863183_item	2805927	et	3	main
lumièris	doc_680929863183_item	2805938	et	4	main
on	doc_680929863183_item	2805941	et	4	main
ka	doc_680929863183_item	2805945	et	3	main
meie	doc_680929863183_item	2805948	et	4	main
õpettajast	doc_680929863183_item	2805950	et	4	main
taanlasi	doc_680929863183_item	2805958	et	3	main
kirjutan	doc_680929863183_item	2805961	et	3	main
oma	doc_680929863183_item	2805963	et	4	main
minu	doc_680929863183_item	2805965	et	3	main
nädalavahetus	doc_680929863183_item	2805966	et	4	main
algas	doc_680929863183_item	2805967	et	3	main
taas	doc_680929863183_item	2805968	et	3	main
juba	doc_680929863183_item	2805969	et	3	main
kaks	doc_680929863183_item	2805974	et	3	main
üks	doc_680929863183_item	2805976	et	3	main
meie	doc_680929863183_item	2805978	et	4	main
skandinavistises	doc_680929863183_item	2805982	et	4	main
skandinavistises	doc_680929863183_item	2805984	et	4	main
seminaris	doc_680929863183_item	2805985	et	3	main
ma	doc_680929863183_item	2805986	et	3	main
laulsin	doc_680929863183_item	2805987	et	3	main
lucia	doc_680929863183_item	2805988	et	4	main
kooris	doc_680929863183_item	2805989	et	4	main
siis	doc_680929863183_item	2805990	et	3	main
ma	doc_680929863183_item	2805991	et	3	main
tahtsin	doc_680929863183_item	2805992	et	3	main
läinud	doc_680929863183_item	2805999	et	4	main
laulsime	doc_680929863183_item	2806006	et	3	main
veel	doc_680929863183_item	2806007	et	4	main
palju	doc_680929863183_item	2806008	et	4	main
ja	doc_680929863183_item	2806009	et	3	main
jõime	doc_680929863183_item	2806010	et	3	main
hõõgveini	doc_680929863183_item	2806011	et	4	main
reedel	doc_680929863183_item	2806012	et	3	main
ma	doc_680929863183_item	2806013	et	3	main
magasin	doc_680929863183_item	2806014	et	4	main
palju	doc_680929863183_item	2806015	et	4	main
ja	doc_680929863183_item	2806016	et	3	main
õppisin	doc_680929863183_item	2806017	et	3	main
õhtul	doc_680929863183_item	2806019	et	3	main
vähe	doc_680929863183_item	2806018	et	3	main
ma	doc_680929863183_item	2806020	et	3	main
sest	doc_680929863183_item	2806023	et	4	main
tahtsime	doc_680929863183_item	2806025	et	3	main
karjus	doc_680929863183_item	2806038	et	4	main
sõin	doc_680929863183_item	2806046	et	3	main
ja	doc_680929863183_item	2806048	et	3	main
ootasin	doc_680929863183_item	2806049	et	3	main
et	doc_680929863183_item	2806050	et	3	main
magama	doc_680929863183_item	2806052	et	3	main
jäi	doc_680929863183_item	2806053	et	3	main
kui	doc_680929863183_item	2806054	et	3	main
lõpuks	doc_680929863183_item	2806056	et	4	main
magas	doc_680929863183_item	2806057	et	4	main
pidu	doc_680929863183_item	2806070	et	4	main
müüsin	doc_680929863183_item	2806073	et	3	main
tegemist	doc_680929863183_item	2806088	et	4	main
sain	doc_680929863183_item	2806091	et	3	main
kolm	doc_680929863183_item	2806096	et	3	main
kojju	doc_680929863183_item	2806132	et	4	main
mind	doc_680929863183_item	2806142	et	4	main
ja	doc_680929863183_item	2806143	et	3	main
me	doc_680929863183_item	2806144	et	4	main
rääkisime	doc_680929863183_item	2806145	et	3	main
kaua	doc_680929863183_item	2806146	et	3	main
pühapäeval	doc_680929863183_item	2806147	et	3	main
ma	doc_680929863183_item	2806148	et	3	main
film	doc_680929863183_item	2805947	et	3	main
taani	doc_680929863183_item	2805949	et	4	main
ma	doc_680929863183_item	2805960	et	3	main
teine	doc_680929863183_item	2805981	et	3	main
me	doc_680929863183_item	2806024	et	4	main
juliane	doc_680929863183_item	2806032	et	4	main
ei	doc_680929863183_item	2806034	et	4	main
tahtnud	doc_680929863183_item	2806035	et	4	main
magada	doc_680929863183_item	2806036	et	3	main
ja	doc_680929863183_item	2806037	et	3	main
vaid	doc_680929863183_item	2806043	et	3	main
kell	doc_680929863183_item	2806075	et	3	main
kaks	doc_680929863183_item	2806079	et	3	main
oli	doc_680929863183_item	2806081	et	3	main
palju	doc_680929863183_item	2806082	et	4	main
ma	doc_680929863183_item	2806097	et	3	main
sõitsin	doc_680929863183_item	2806098	et	3	main
sõbrale	doc_680929863183_item	2806100	et	3	main
sest	doc_680929863183_item	2806101	et	4	main
seal	doc_680929863183_item	2806102	et	4	main
ka	doc_680929863183_item	2806103	et	3	main
oli	doc_680929863183_item	2806104	et	3	main
pidu	doc_680929863183_item	2806105	et	4	main
aga	doc_680929863183_item	2806106	et	3	main
kui	doc_680929863183_item	2806107	et	3	main
ma	doc_680929863183_item	2806108	et	3	main
saabusin	doc_680929863183_item	2806109	et	3	main
pidu	doc_680929863183_item	2806110	et	4	main
oli	doc_680929863183_item	2806111	et	3	main
juba	doc_680929863183_item	2806112	et	3	main
otsas	doc_680929863183_item	2806113	et	4	main
seal	doc_680929863183_item	2806114	et	4	main
istusivad	doc_680929863183_item	2806115	et	4	main
vaid	doc_680929863183_item	2806116	et	3	main
neli	doc_680929863183_item	2806117	et	3	main
inimesi	doc_680929863183_item	2806118	et	4	main
ja	doc_680929863183_item	2806119	et	3	main
ajasivad	doc_680929863183_item	2806120	et	4	main
teet	doc_680929863183_item	2806044	et	4	main
ma	doc_680929863183_item	2806058	et	3	main
juttu	doc_680929863183_item	2806060	et	4	main
ja	doc_680929863183_item	2806062	et	3	main
siis	doc_680929863183_item	2806063	et	3	main
ma	doc_680929863183_item	2806064	et	3	main
sõitsin	doc_680929863183_item	2806065	et	3	main
põhi	doc_680929863183_item	2806066	et	3	main
campusesse	doc_680929863183_item	2806067	et	4	main
ja	doc_680929863183_item	2806071	et	3	main
õlut	doc_680929863183_item	2806074	et	3	main
inimesi	doc_680929863183_item	2806083	et	4	main
ja	doc_680929863183_item	2806084	et	3	main
palju	doc_680929863183_item	2806087	et	4	main
ma	doc_680929863183_item	2806090	et	3	main
juua	doc_680929863183_item	2806092	et	3	main
tasuta	doc_680929863183_item	2806094	et	4	main
kell	doc_680929863183_item	2806095	et	3	main
vell	doc_680929863183_item	2806099	et	4	main
juttu	doc_680929863183_item	2806121	et	4	main
siiski	doc_680929863183_item	2806123	et	4	main
ma	doc_680929863183_item	2806134	et	3	main
magasin	doc_680929863183_item	2806135	et	4	main
peaaegu	doc_680929863183_item	2806136	et	3	main
terve	doc_680929863183_item	2806137	et	4	main
laupäev	doc_680929863183_item	2806138	et	3	main
minu	doc_680929863183_item	2806139	et	3	main
õde	doc_680929863183_item	2806140	et	4	main
ma	doc_680929863183_item	2806155	et	3	main
oma	doc_680929863183_item	2806157	et	4	main
metsas	doc_680929863183_item	2806159	et	3	main
ma	doc_680929863183_item	2806161	et	3	main
veel	doc_680929863183_item	2806163	et	4	main
sõbrannale	doc_680929863183_item	2806164	et	3	main
kus	doc_680929863183_item	2806165	et	3	main
me	doc_680929863183_item	2806166	et	4	main
sööme	doc_680929863183_item	2806170	et	4	main
ametlik	doc_680929863184_item	2806172	et	3	main
ma	doc_680929863184_item	2806175	et	3	main
koodused	doc_680929863184_item	2806178	et	4	main
sest	doc_680929863184_item	2806183	et	4	main
lp	doc_680929863184_item	2806186	et	4	main
essee	doc_680929863186_item	2806360	et	4	main
vabariik	doc_680929863186_item	2806362	et	3	main
saaremaa	doc_680929863186_item	2806388	et	4	main
hiiumaa	doc_680929863186_item	2806389	et	4	main
valgamaa	doc_680929863186_item	2806393	et	4	main
ja	doc_680929863186_item	2806398	et	3	main
suurlinna	doc_680929863186_item	2806401	et	4	main
elavad	doc_680929863186_item	2806403	et	4	main
oli	doc_680929863183_item	2806122	et	3	main
mugav	doc_680929863183_item	2806124	et	3	main
viis	doc_680929863183_item	2806131	et	4	main
helistais	doc_680929863183_item	2806141	et	4	main
siis	doc_680929863183_item	2806149	et	3	main
õppisin	doc_680929863183_item	2806150	et	3	main
oli	doc_680929863183_item	2806151	et	3	main
külm	doc_680929863183_item	2806152	et	3	main
väljas	doc_680929863183_item	2806153	et	4	main
ja	doc_680929863183_item	2806154	et	3	main
jalutasin	doc_680929863183_item	2806156	et	3	main
tere	doc_680929863184_item	2806174	et	3	main
saadan	doc_680929863184_item	2806176	et	4	main
haigeks	doc_680929863184_item	2806185	et	4	main
eesnimi	doc_680929863184_item	2806187	et	3	main
tallinn	doc_680929863186_item	2806383	et	4	main
eestis	doc_680929863186_item	2806384	et	3	main
15	doc_680929863186_item	2806386	et	2	main
maakonda	doc_680929863186_item	2806387	et	4	main
tartumaa	doc_680929863186_item	2806391	et	4	main
võrumaa	doc_680929863186_item	2806392	et	4	main
aga	doc_680929863186_item	2806407	et	3	main
järved	doc_680929863186_item	2806419	et	3	main
valgevenelased	doc_680929863186_item	2806431	et	3	main
vene	doc_680929863186_item	2806438	et	4	main
saksa	doc_680929863186_item	2806439	et	4	main
eesti	doc_680929863186_item	2806443	et	4	main
riik	doc_680929863186_item	2806444	et	3	main
vana	doc_680929863186_item	2806448	et	4	main
on	doc_680929863186_item	2806457	et	4	main
sinine	doc_680929863186_item	2806458	et	4	main
vaatamisväärsused	doc_680929863186_item	2806465	et	4	main
raekoja	doc_680929863186_item	2806466	et	3	main
aleksander	doc_680929863186_item	2806469	et	4	main
paks	doc_680929863186_item	2806472	et	3	main
oleviste	doc_680929863186_item	2806474	et	4	main
saksamaal	doc_680929863187_item	2806484	et	4	main
elavad	doc_680929863187_item	2806485	et	4	main
inimest	doc_680929863187_item	2806489	et	3	main
tatort	doc_680929863183_item	2806168	et	4	main
minu	doc_680929863184_item	2806177	et	3	main
tööd	doc_680929863184_item	2806179	et	4	main
täna	doc_680929863184_item	2806180	et	4	main
ma	doc_680929863184_item	2806181	et	3	main
perekonnanimi	doc_680929863184_item	2806188	et	3	main
eesti	doc_680929863186_item	2806361	et	4	main
eesti	doc_680929863186_item	2806363	et	4	main
asub	doc_680929863186_item	2806364	et	3	main
eesti	doc_680929863186_item	2806380	et	4	main
pealinn	doc_680929863186_item	2806381	et	3	main
on	doc_680929863186_item	2806382	et	4	main
on	doc_680929863186_item	2806385	et	4	main
lääne-virumaa	doc_680929863186_item	2806396	et	4	main
pole	doc_680929863186_item	2806400	et	3	main
tallinnas	doc_680929863186_item	2806402	et	4	main
inimest	doc_680929863186_item	2806406	et	3	main
palju	doc_680929863186_item	2806410	et	4	main
on	doc_680929863186_item	2806421	et	4	main
elavad	doc_680929863186_item	2806427	et	4	main
venelased	doc_680929863186_item	2806429	et	3	main
89	doc_680929863186_item	2806446	et	2	main
eesti	doc_680929863186_item	2806450	et	4	main
on	doc_680929863186_item	2806452	et	4	main
eesti	doc_680929863186_item	2806455	et	4	main
lipp	doc_680929863186_item	2806456	et	3	main
must	doc_680929863186_item	2806459	et	4	main
plats	doc_680929863186_item	2806467	et	4	main
nevski	doc_680929863186_item	2806470	et	4	main
loss	doc_680929863186_item	2806477	et	3	main
saksamaa	doc_680929863187_item	2806481	et	4	main
asub	doc_680929863187_item	2806482	et	3	main
naaberriigid	doc_680929863187_item	2806491	et	3	main
berliin	doc_680929863187_item	2806532	et	4	main
aga	doc_680929863187_item	2806541	et	3	main
main	doc_680929863187_item	2806568	et	4	main
müritz	doc_680929863187_item	2806573	et	4	main
poolakased	doc_680929863187_item	2806580	et	4	main
lipp	doc_680929863187_item	2806582	et	3	main
kirre-europas	doc_680929863186_item	2806365	et	4	main
ääres	doc_680929863186_item	2806367	et	4	main
läänemere	doc_680929863186_item	2806366	et	3	main
eesti	doc_680929863186_item	2806368	et	4	main
naaberriigid	doc_680929863186_item	2806369	et	3	main
on	doc_680929863186_item	2806370	et	4	main
läti	doc_680929863186_item	2806371	et	4	main
ja	doc_680929863186_item	2806372	et	3	main
venemaa	doc_680929863186_item	2806373	et	4	main
eestis	doc_680929863186_item	2806374	et	3	main
elavad	doc_680929863186_item	2806375	et	4	main
umbes	doc_680929863186_item	2806376	et	4	main
13	doc_680929863186_item	2806377	et	2	main
miljon	doc_680929863186_item	2806378	et	3	main
inimest	doc_680929863186_item	2806379	et	3	main
harjumaa	doc_680929863186_item	2806390	et	4	main
eestis	doc_680929863186_item	2806399	et	3	main
palju	doc_680929863186_item	2806416	et	4	main
jõed	doc_680929863186_item	2806417	et	3	main
ja	doc_680929863186_item	2806418	et	3	main
ainult	doc_680929863186_item	2806404	et	4	main
400000	doc_680929863186_item	2806405	et	2	main
on	doc_680929863186_item	2806409	et	4	main
väikelinna	doc_680929863186_item	2806411	et	4	main
ja	doc_680929863186_item	2806412	et	3	main
küla	doc_680929863186_item	2806413	et	4	main
eestis	doc_680929863186_item	2806414	et	3	main
pole	doc_680929863186_item	2806415	et	3	main
siin	doc_680929863186_item	2806420	et	4	main
ainult	doc_680929863186_item	2806422	et	4	main
eestis	doc_680929863186_item	2806426	et	3	main
soomlased	doc_680929863186_item	2806432	et	3	main
eesti	doc_680929863186_item	2806437	et	4	main
aastat	doc_680929863186_item	2806447	et	3	main
valge	doc_680929863186_item	2806461	et	4	main
on	doc_680929863186_item	2806463	et	4	main
palju	doc_680929863186_item	2806464	et	4	main
toompea	doc_680929863186_item	2806476	et	4	main
miljon	doc_680929863187_item	2806488	et	3	main
schleswig-holstein	doc_680929863187_item	2806521	et	4	main
palju	doc_680929863187_item	2806530	et	4	main
frankfurt	doc_680929863187_item	2806537	et	4	main
meil	doc_680929863187_item	2806542	et	4	main
põhja-meri	doc_680929863187_item	2806551	et	3	main
ja	doc_680929863187_item	2806552	et	3	main
ja	doc_680929863187_item	2806557	et	3	main
palju	doc_680929863187_item	2806562	et	4	main
rhein	doc_680929863187_item	2806564	et	4	main
donau	doc_680929863187_item	2806565	et	4	main
suurin	doc_680929863187_item	2806570	et	4	main
itaallased	doc_680929863187_item	2806578	et	3	main
on	doc_680929863187_item	2806583	et	4	main
ja	doc_680929863187_item	2806586	et	3	main
kollane	doc_680929863187_item	2806587	et	4	main
pois	doc_681992022005_item	2806602	et	3	main
tüdruk	doc_681992022005_item	2806607	et	3	main
papagoit	doc_681992022005_item	2806612	et	4	main
tüdruk	doc_681992022005_item	2806613	et	3	main
ma	doc_681992022005_item	2806615	et	3	main
karjuma	doc_681992022005_item	2806639	et	3	main
ehmatab	doc_681992022005_item	2806641	et	3	main
ma	doc_681992022005_item	2806644	et	3	main
papagoi	doc_681992022005_item	2806651	et	4	main
poisil	doc_681992022006_item	2806656	et	3	main
õpetas	doc_681992022006_item	2806662	et	3	main
selgeks	doc_681992022006_item	2806666	et	3	main
tutvus	doc_681992022006_item	2806675	et	4	main
tuttavadega	doc_681992022006_item	2806676	et	3	main
laulma	doc_681992022006_item	2806679	et	3	main
sellepärast	doc_681992022006_item	2806685	et	3	main
vaatama	doc_681992022006_item	2806687	et	3	main
poiss	doc_681992022006_item	2806689	et	3	main
neju	doc_681992022006_item	2806721	et	4	main
neiu	doc_681992022006_item	2806725	et	4	main
muutuma	doc_681992022006_item	2806733	et	4	main
ja	doc_681992022006_item	2806735	et	3	main
ta	doc_681992022007_item	2806744	et	4	main
papagoi	doc_681992022007_item	2806747	et	4	main
selgeks	doc_681992022007_item	2806749	et	3	main
100	doc_681992022007_item	2806751	et	2	main
varem	doc_681992022007_item	2806770	et	4	main
õppis	doc_681992022007_item	2806771	et	3	main
lapsed	doc_681992022007_item	2806772	et	3	main
eest	doc_681992022007_item	2806821	et	4	main
neid	doc_681992022007_item	2806825	et	4	main
oma	doc_681992022007_item	2806831	et	4	main
tüdruk	doc_681992022007_item	2806834	et	3	main
rääkis	doc_681992022007_item	2806860	et	3	main
kõvasti	doc_681992022007_item	2806862	et	3	main
ükskord	doc_681992022008_item	2806874	et	3	main
oma	doc_681992022008_item	2806878	et	4	main
halvad	doc_681992022008_item	2806886	et	4	main
on	doc_681992022008_item	2806899	et	4	main
ja	doc_680929863186_item	2806424	et	3	main
ja	doc_680929863186_item	2806433	et	3	main
lätlased	doc_680929863186_item	2806434	et	3	main
räägivad	doc_680929863186_item	2806436	et	3	main
on	doc_680929863186_item	2806445	et	4	main
ja	doc_680929863186_item	2806460	et	3	main
tallinnas	doc_680929863186_item	2806462	et	4	main
raekoda	doc_680929863186_item	2806468	et	4	main
katedraal	doc_680929863186_item	2806471	et	3	main
margareta	doc_680929863186_item	2806473	et	3	main
kesk-europas	doc_680929863187_item	2806483	et	4	main
82	doc_680929863187_item	2806487	et	2	main
saksamaa	doc_680929863187_item	2806490	et	4	main
prantsusmaa	doc_680929863187_item	2806493	et	4	main
belgia	doc_680929863187_item	2806494	et	4	main
holland	doc_680929863187_item	2806495	et	4	main
taani	doc_680929863187_item	2806496	et	4	main
poola	doc_680929863187_item	2806497	et	4	main
t	doc_680929863187_item	2806498	et	4	main
šehhi	doc_680929863187_item	2806499	et	2	main
austria	doc_680929863187_item	2806500	et	4	main
ja	doc_680929863187_item	2806501	et	3	main
ṧveits	doc_680929863187_item	2806502	et	2	main
saksamaal	doc_680929863187_item	2806503	et	4	main
on	doc_680929863187_item	2806504	et	4	main
16	doc_680929863187_item	2806505	et	2	main
maakonda	doc_680929863187_item	2806506	et	4	main
bayern	doc_680929863187_item	2806507	et	4	main
baden-württemberg	doc_680929863187_item	2806508	et	4	main
saarland	doc_680929863187_item	2806509	et	4	main
hessen	doc_680929863187_item	2806510	et	4	main
rhein-land-pfalz	doc_680929863187_item	2806511	et	4	main
niedersachsen	doc_680929863187_item	2806512	et	4	main
sachsen-anhalt	doc_680929863187_item	2806513	et	4	main
hamburg	doc_680929863187_item	2806514	et	4	main
bremen	doc_680929863187_item	2806515	et	4	main
berlin	doc_680929863187_item	2806516	et	4	main
mecklenburg-vorpommern	doc_680929863187_item	2806517	et	4	main
nordrhein-westfalen	doc_680929863187_item	2806518	et	4	main
thüringen	doc_680929863187_item	2806519	et	4	main
sachsen	doc_680929863187_item	2806520	et	4	main
berliin	doc_680929863187_item	2806527	et	4	main
meil	doc_680929863187_item	2806528	et	4	main
suurlinna	doc_680929863187_item	2806531	et	4	main
hamburg	doc_680929863187_item	2806533	et	4	main
köln	doc_680929863187_item	2806535	et	4	main
düsseldorf	doc_680929863187_item	2806536	et	4	main
essen	doc_680929863187_item	2806540	et	4	main
põhjas	doc_680929863187_item	2806549	et	4	main
on	doc_680929863187_item	2806550	et	4	main
bodenjärv	doc_680929863187_item	2806556	et	4	main
alpenmäestik	doc_680929863187_item	2806558	et	4	main
on	doc_680929863187_item	2806560	et	4	main
soome	doc_680929863186_item	2806441	et	3	main
kelt	doc_680929863186_item	2806442	et	3	main
ja	doc_680929863186_item	2806449	et	3	main
rahvuslikpühapaev	doc_680929863186_item	2806451	et	4	main
24	doc_680929863186_item	2806453	et	2	main
veebruaris	doc_680929863186_item	2806454	et	3	main
kirik	doc_680929863186_item	2806475	et	3	main
essee	doc_680929863187_item	2806478	et	4	main
saksa	doc_680929863187_item	2806479	et	4	main
riik	doc_680929863187_item	2806480	et	3	main
umbes	doc_680929863187_item	2806486	et	4	main
on	doc_680929863187_item	2806492	et	4	main
ja	doc_680929863187_item	2806522	et	3	main
on	doc_680929863187_item	2806529	et	4	main
am	doc_680929863187_item	2806538	et	4	main
ka	doc_680929863187_item	2806544	et	3	main
palju	doc_680929863187_item	2806545	et	4	main
saksamaal	doc_680929863187_item	2806559	et	4	main
spree	doc_680929863187_item	2806566	et	4	main
saksamaa	doc_680929863187_item	2806569	et	4	main
järv	doc_680929863187_item	2806571	et	3	main
on	doc_680929863187_item	2806572	et	4	main
venelased	doc_680929863187_item	2806579	et	3	main
saksamaa	doc_680929863187_item	2806581	et	4	main
must	doc_680929863187_item	2806584	et	4	main
hamburgis	doc_680929863187_item	2806595	et	4	main
kölnis	doc_680929863187_item	2806596	et	4	main
ümberjutustus	doc_681992022005_item	2806597	et	3	main
pois	doc_681992022005_item	2806598	et	3	main
tutvustab	doc_681992022005_item	2806599	et	3	main
sõbrad	doc_681992022005_item	2806600	et	3	main
papagoiga	doc_681992022005_item	2806601	et	3	main
tahab	doc_681992022005_item	2806603	et	3	main
papagoiga	doc_681992022005_item	2806606	et	3	main
palun	doc_681992022005_item	2806609	et	3	main
tahan	doc_681992022005_item	2806616	et	3	main
noornaine	doc_681992022005_item	2806621	et	3	main
papagojiga	doc_681992022005_item	2806623	et	4	main
kui	doc_681992022005_item	2806637	et	3	main
tervist	doc_681992022005_item	2806647	et	4	main
ümberjutustus	doc_681992022006_item	2806654	et	3	main
oli	doc_681992022006_item	2806657	et	3	main
papagoi	doc_681992022006_item	2806659	et	4	main
kelle	doc_681992022006_item	2806660	et	4	main
papagoi	doc_681992022006_item	2806664	et	4	main
100	doc_681992022006_item	2806668	et	2	main
sõbraid	doc_681992022006_item	2806672	et	4	main
linnuga	doc_681992022006_item	2806673	et	3	main
papagoi	doc_681992022006_item	2806674	et	4	main
tahasin	doc_681992022006_item	2806686	et	4	main
uute	doc_681992022006_item	2806723	et	3	main
ehmusid	doc_681992022006_item	2806729	et	4	main
ta	doc_681992022006_item	2806731	et	4	main
otsustas	doc_681992022007_item	2806755	et	3	main
tutvustada	doc_681992022007_item	2806756	et	3	main
oma	doc_681992022007_item	2806757	et	4	main
lastega	doc_681992022007_item	2806762	et	3	main
ükskord	doc_681992022007_item	2806774	et	3	main
aega	doc_681992022007_item	2806844	et	4	main
ajal	doc_681992022007_item	2806858	et	4	main
tüdrukud	doc_681992022007_item	2806864	et	3	main
ehmusid	doc_681992022007_item	2806866	et	4	main
tüdruk	doc_681992022007_item	2806868	et	3	main
tutvustas	doc_681992022008_item	2806876	et	3	main
anne	doc_681992022008_item	2806900	et	4	main
peatas	doc_681992022008_item	2806901	et	3	main
poisi	doc_681992022008_item	2806902	et	3	main
ja	doc_681992022008_item	2806903	et	3	main
ta	doc_681992022008_item	2806904	et	4	main
tahtis	doc_681992022008_item	2806905	et	3	main
avo	doc_681992022008_item	2806926	et	4	main
kodus	doc_681992022008_item	2806933	et	4	main
kui	doc_681992022008_item	2806934	et	3	main
järsku	doc_681992022008_item	2806938	et	4	main
väga	doc_681992022008_item	2806940	et	3	main
papagoi	doc_681992022008_item	2806949	et	4	main
tihti	doc_681992022008_item	2806950	et	3	main
kasutas	doc_681992022008_item	2806951	et	3	main
sellised	doc_681992022008_item	2806952	et	4	main
ümberkasvatamiseks	doc_681992022008_item	2806962	et	3	main
harjus	doc_681992022008_item	2806965	et	4	main
brandenburg	doc_680929863187_item	2806523	et	4	main
saksamaa	doc_680929863187_item	2806524	et	4	main
pealinn	doc_680929863187_item	2806525	et	3	main
on	doc_680929863187_item	2806526	et	4	main
münchen	doc_680929863187_item	2806534	et	4	main
stuttgart	doc_680929863187_item	2806539	et	4	main
on	doc_680929863187_item	2806543	et	4	main
väikelinna	doc_680929863187_item	2806546	et	4	main
ja	doc_680929863187_item	2806547	et	3	main
küla	doc_680929863187_item	2806548	et	4	main
ida-meri	doc_680929863187_item	2806553	et	3	main
lõunas	doc_680929863187_item	2806554	et	3	main
on	doc_680929863187_item	2806555	et	4	main
ka	doc_680929863187_item	2806561	et	3	main
elbe	doc_680929863187_item	2806567	et	4	main
saksamaal	doc_680929863187_item	2806574	et	4	main
türklased	doc_680929863187_item	2806577	et	3	main
on	doc_680929863187_item	2806589	et	4	main
dresdenis	doc_680929863187_item	2806594	et	4	main
tutvub	doc_681992022005_item	2806604	et	3	main
peatab	doc_681992022005_item	2806610	et	3	main
soovib	doc_681992022005_item	2806622	et	3	main
raakida	doc_681992022005_item	2806624	et	4	main
papagoji	doc_681992022005_item	2806627	et	4	main
silitama	doc_681992022005_item	2806628	et	4	main
pois	doc_681992022005_item	2806629	et	3	main
harjutasin	doc_681992022005_item	2806645	et	3	main
ema	doc_681992022005_item	2806652	et	4	main
ühel	doc_681992022006_item	2806655	et	3	main
kodus	doc_681992022006_item	2806658	et	4	main
rääkima	doc_681992022006_item	2806663	et	3	main
õppis	doc_681992022006_item	2806665	et	3	main
umbes	doc_681992022006_item	2806667	et	4	main
sõna	doc_681992022006_item	2806669	et	4	main
poiss	doc_681992022006_item	2806670	et	3	main
tutvustas	doc_681992022006_item	2806671	et	3	main
algas	doc_681992022006_item	2806678	et	3	main
poisi	doc_681992022006_item	2806682	et	3	main
harjub	doc_681992022006_item	2806722	et	3	main
raamatuga	doc_681992022006_item	2806724	et	4	main
nad	doc_681992022006_item	2806728	et	3	main
kui	doc_681992022006_item	2806730	et	3	main
näo	doc_681992022006_item	2806736	et	3	main
ühel	doc_681992022007_item	2806738	et	3	main
oli	doc_681992022007_item	2806740	et	3	main
papagoi	doc_681992022007_item	2806742	et	4	main
kelle	doc_681992022007_item	2806743	et	4	main
papagoi	doc_681992022007_item	2806758	et	4	main
ja	doc_681992022007_item	2806763	et	3	main
neile	doc_681992022007_item	2806766	et	4	main
sõnu	doc_681992022007_item	2806768	et	4	main
niissugused	doc_681992022007_item	2806769	et	4	main
sest	doc_681992022007_item	2806782	et	4	main
tahtis	doc_681992022007_item	2806783	et	3	main
midagi	doc_681992022007_item	2806784	et	4	main
küsida	doc_681992022007_item	2806785	et	3	main
tüdruk	doc_681992022007_item	2806786	et	3	main
peatas	doc_681992022007_item	2806787	et	3	main
pärast	doc_681992022007_item	2806822	et	4	main
ta	doc_681992022007_item	2806823	et	4	main
saatis	doc_681992022007_item	2806824	et	3	main
tüdruku	doc_681992022007_item	2806830	et	3	main
karjumisega	doc_681992022007_item	2806833	et	4	main
ehtamatas	doc_681992022007_item	2806835	et	4	main
ootamatusest	doc_681992022007_item	2806836	et	4	main
et	doc_681992022007_item	2806837	et	3	main
papagoi	doc_681992022007_item	2806838	et	4	main
võib	doc_681992022007_item	2806839	et	3	main
nii	doc_681992022007_item	2806840	et	3	main
kõvasti	doc_681992022007_item	2806841	et	3	main
rääkida	doc_681992022007_item	2806842	et	3	main
tüdruk	doc_681992022007_item	2806846	et	3	main
papagoi	doc_681992022007_item	2806848	et	4	main
harjutas	doc_681992022007_item	2806849	et	3	main
laulda	doc_681992022007_item	2806850	et	4	main
sel	doc_681992022007_item	2806851	et	3	main
ajal	doc_681992022007_item	2806852	et	4	main
kui	doc_681992022007_item	2806853	et	3	main
tüdruk	doc_681992022007_item	2806854	et	3	main
õpiku	doc_681992022007_item	2806855	et	3	main
vaatas	doc_681992022007_item	2806856	et	3	main
ta	doc_681992022007_item	2806859	et	4	main
ehmutada	doc_681992022007_item	2806871	et	4	main
ta	doc_681992022008_item	2806883	et	4	main
rääkis	doc_681992022008_item	2806884	et	3	main
naljakad	doc_681992022008_item	2806885	et	3	main
nalja	doc_681992022008_item	2806892	et	4	main
üks	doc_681992022008_item	2806893	et	3	main
tüdruk	doc_681992022008_item	2806894	et	3	main
tema	doc_681992022008_item	2806897	et	4	main
nimi	doc_681992022008_item	2806898	et	3	main
soovis	doc_681992022008_item	2806921	et	4	main
hea	doc_681992022008_item	2806924	et	4	main
meelega	doc_681992022008_item	2806925	et	4	main
sai	doc_681992022008_item	2806931	et	4	main
jõge	doc_680929863187_item	2806563	et	3	main
elavad	doc_680929863187_item	2806575	et	4	main
palju	doc_680929863187_item	2806576	et	4	main
palju	doc_680929863187_item	2806590	et	4	main
vaatamisväärsused	doc_680929863187_item	2806591	et	4	main
peamiselt	doc_680929863187_item	2806592	et	4	main
sõbrad	doc_681992022005_item	2806605	et	3	main
noornaine	doc_681992022005_item	2806625	et	3	main
soovitan	doc_681992022005_item	2806626	et	3	main
papagoi	doc_681992022005_item	2806638	et	4	main
kui	doc_681992022005_item	2806650	et	3	main
neiu	doc_681992022006_item	2806680	et	4	main
neiu	doc_681992022006_item	2806683	et	4	main
ostma	doc_681992022006_item	2806691	et	3	main
punane	doc_680929863187_item	2806585	et	4	main
meil	doc_680929863187_item	2806588	et	4	main
berliinis	doc_680929863187_item	2806593	et	4	main
raagib	doc_681992022005_item	2806608	et	4	main
teda	doc_681992022005_item	2806611	et	4	main
raagib	doc_681992022005_item	2806614	et	4	main
peatuma	doc_681992022005_item	2806617	et	4	main
ja	doc_681992022005_item	2806618	et	3	main
rakida	doc_681992022005_item	2806619	et	4	main
sinuga	doc_681992022005_item	2806620	et	3	main
rahat	doc_681992022005_item	2806630	et	4	main
saatsin	doc_681992022005_item	2806631	et	3	main
noornaine	doc_681992022005_item	2806632	et	3	main
saatsin	doc_681992022005_item	2806633	et	3	main
papagoja	doc_681992022005_item	2806634	et	4	main
tüdruk	doc_681992022005_item	2806635	et	3	main
ehmuma	doc_681992022005_item	2806636	et	3	main
tudruk	doc_681992022005_item	2806640	et	4	main
papagoi	doc_681992022005_item	2806642	et	4	main
räkib	doc_681992022005_item	2806643	et	4	main
teda	doc_681992022005_item	2806646	et	4	main
tudrukud	doc_681992022005_item	2806648	et	4	main
ehmatavad	doc_681992022005_item	2806649	et	4	main
karjub	doc_681992022005_item	2806653	et	3	main
ta	doc_681992022006_item	2806661	et	4	main
ja	doc_681992022006_item	2806677	et	3	main
peatas	doc_681992022006_item	2806681	et	3	main
peatus	doc_681992022006_item	2806684	et	4	main
linnu	doc_681992022006_item	2806688	et	4	main
soovitas	doc_681992022006_item	2806690	et	3	main
neiule	doc_681992022006_item	2806692	et	4	main
linnu	doc_681992022006_item	2806693	et	4	main
papagoi	doc_681992022006_item	2806694	et	4	main
soovis	doc_681992022006_item	2806695	et	4	main
jääma	doc_681992022006_item	2806696	et	4	main
poisiga	doc_681992022006_item	2806697	et	3	main
poiss	doc_681992022006_item	2806698	et	3	main
saadab	doc_681992022006_item	2806699	et	3	main
neiule	doc_681992022006_item	2806700	et	4	main
linnu	doc_681992022006_item	2806701	et	4	main
poiss	doc_681992022006_item	2806702	et	3	main
saab	doc_681992022006_item	2806703	et	3	main
palju	doc_681992022006_item	2806704	et	4	main
raha	doc_681992022006_item	2806705	et	4	main
neiu	doc_681992022006_item	2806706	et	4	main
ehmus	doc_681992022006_item	2806707	et	4	main
kui	doc_681992022006_item	2806708	et	3	main
papagoi	doc_681992022006_item	2806709	et	4	main
hakas	doc_681992022006_item	2806710	et	4	main
rääkima	doc_681992022006_item	2806711	et	3	main
papagoi	doc_681992022006_item	2806712	et	4	main
ehmatas	doc_681992022006_item	2806713	et	3	main
neiu	doc_681992022006_item	2806714	et	4	main
väga	doc_681992022006_item	2806715	et	3	main
kõvasti	doc_681992022006_item	2806716	et	3	main
papagoi	doc_681992022006_item	2806717	et	4	main
harjutab	doc_681992022006_item	2806718	et	3	main
laulu	doc_681992022006_item	2806719	et	4	main
aga	doc_681992022006_item	2806720	et	3	main
tuttavaid	doc_681992022006_item	2806727	et	3	main
algas	doc_681992022006_item	2806732	et	3	main
hääle	doc_681992022006_item	2806734	et	3	main
poisil	doc_681992022007_item	2806739	et	3	main
ehmatas	doc_681992022006_item	2806726	et	3	main
ümberjutustus	doc_681992022007_item	2806737	et	3	main
õpetas	doc_681992022007_item	2806745	et	3	main
õppis	doc_681992022007_item	2806748	et	3	main
umbes	doc_681992022007_item	2806750	et	4	main
sõna	doc_681992022007_item	2806752	et	4	main
ükskord	doc_681992022007_item	2806753	et	3	main
poiss	doc_681992022007_item	2806754	et	3	main
tutvus	doc_681992022007_item	2806761	et	4	main
naersid	doc_681992022007_item	2806773	et	4	main
poiss	doc_681992022007_item	2806775	et	3	main
papagoiaga	doc_681992022007_item	2806777	et	4	main
tüdruku	doc_681992022007_item	2806780	et	3	main
neid	doc_681992022007_item	2806788	et	4	main
et	doc_681992022007_item	2806789	et	3	main
kuulata	doc_681992022007_item	2806790	et	4	main
ära	doc_681992022007_item	2806791	et	4	main
kõik	doc_681992022007_item	2806792	et	4	main
mida	doc_681992022007_item	2806793	et	4	main
ütleb	doc_681992022007_item	2806794	et	3	main
poiss	doc_681992022007_item	2806795	et	3	main
tüdruk	doc_681992022007_item	2806796	et	3	main
soovis	doc_681992022007_item	2806797	et	4	main
papagoi	doc_681992022007_item	2806798	et	4	main
silitada	doc_681992022007_item	2806799	et	3	main
aga	doc_681992022007_item	2806800	et	3	main
poiss	doc_681992022007_item	2806801	et	3	main
soovitas	doc_681992022007_item	2806802	et	3	main
talle	doc_681992022007_item	2806803	et	4	main
olla	doc_681992022007_item	2806804	et	3	main
ettevaatlik	doc_681992022007_item	2806805	et	3	main
sest	doc_681992022007_item	2806806	et	4	main
papagoi	doc_681992022007_item	2806807	et	4	main
võis	doc_681992022007_item	2806808	et	4	main
nokaga	doc_681992022007_item	2806809	et	3	main
lööma	doc_681992022007_item	2806810	et	4	main
poiss	doc_681992022007_item	2806811	et	3	main
otsustas	doc_681992022007_item	2806812	et	3	main
ära	doc_681992022007_item	2806813	et	4	main
müüma	doc_681992022007_item	2806814	et	3	main
oma	doc_681992022007_item	2806815	et	4	main
looma	doc_681992022007_item	2806816	et	4	main
ja	doc_681992022007_item	2806817	et	3	main
saada	doc_681992022007_item	2806818	et	4	main
raha	doc_681992022007_item	2806819	et	4	main
tema	doc_681992022007_item	2806820	et	4	main
kodus	doc_681992022007_item	2806741	et	4	main
rääkima	doc_681992022007_item	2806746	et	3	main
klassikaaslastega	doc_681992022007_item	2806759	et	4	main
papagoi	doc_681992022007_item	2806760	et	4	main
ta	doc_681992022007_item	2806764	et	4	main
hakkas	doc_681992022007_item	2806765	et	3	main
rääkida	doc_681992022007_item	2806767	et	3	main
jalutas	doc_681992022007_item	2806776	et	3	main
ja	doc_681992022007_item	2806778	et	3	main
peatus	doc_681992022007_item	2806779	et	4	main
ees	doc_681992022007_item	2806781	et	4	main
kohe	doc_681992022007_item	2806826	et	4	main
koju	doc_681992022007_item	2806827	et	3	main
papagoi	doc_681992022007_item	2806828	et	4	main
ehmatas	doc_681992022007_item	2806829	et	3	main
mõnda	doc_681992022007_item	2806843	et	4	main
pärast	doc_681992022007_item	2806845	et	4	main
harjus	doc_681992022007_item	2806847	et	4	main
ja	doc_681992022007_item	2806863	et	3	main
sõbrannaid	doc_681992022007_item	2806872	et	4	main
ümberjutustus	doc_681992022008_item	2806873	et	3	main
poiss	doc_681992022008_item	2806875	et	3	main
papagoi	doc_681992022008_item	2806877	et	4	main
sõpradega	doc_681992022008_item	2806879	et	3	main
tutvus	doc_681992022008_item	2806881	et	4	main
nendega	doc_681992022008_item	2806882	et	4	main
tegi	doc_681992022008_item	2806890	et	4	main
see	doc_681992022008_item	2806891	et	3	main
juuksega	doc_681992022008_item	2806896	et	3	main
ostma	doc_681992022008_item	2806922	et	3	main
sai	doc_681992022008_item	2806927	et	4	main
raha	doc_681992022008_item	2806928	et	4	main
aga	doc_681992022008_item	2806929	et	3	main
luges	doc_681992022008_item	2806936	et	3	main
teda	doc_681992022008_item	2806942	et	4	main
papagoi	doc_681992022008_item	2806944	et	4	main
sõnad	doc_681992022008_item	2806953	et	4	main
harjutama	doc_681992022008_item	2806956	et	4	main
ehmutas	doc_681992022008_item	2806970	et	4	main
rääkima	doc_681992022008_item	2806976	et	3	main
papagoi	doc_681992022008_item	2806978	et	4	main
odanud	doc_681992022008_item	2806984	et	4	main
papagoi	doc_681992022009_item	2806994	et	4	main
pärast	doc_681992022009_item	2806998	et	4	main
50	doc_681992022009_item	2807002	et	2	main
ja	doc_681992022009_item	2807004	et	3	main
tutvustama	doc_681992022009_item	2807007	et	3	main
oma	doc_681992022009_item	2807008	et	4	main
küsis	doc_681992022009_item	2807032	et	3	main
teda	doc_681992022009_item	2807033	et	4	main
palju	doc_681992022009_item	2807035	et	4	main
looma	doc_681992022009_item	2807040	et	4	main
eest	doc_681992022009_item	2807041	et	4	main
rahulik	doc_681992022009_item	2807055	et	3	main
värske	doc_681992022009_item	2807061	et	4	main
temaga	doc_681992022009_item	2807065	et	3	main
pärast	doc_681992022009_item	2807068	et	4	main
ja	doc_681992022009_item	2807073	et	3	main
saattis	doc_681992022009_item	2807074	et	4	main
papagoi	doc_681992022009_item	2807078	et	4	main
päeva	doc_681992022009_item	2807081	et	4	main
rääkima	doc_681992022009_item	2807090	et	3	main
ootamatut	doc_681992022007_item	2806832	et	4	main
kohtumise	doc_681992022007_item	2806857	et	4	main
kuidagi	doc_681992022007_item	2806861	et	3	main
isegi	doc_681992022007_item	2806865	et	4	main
aga	doc_681992022007_item	2806867	et	3	main
ei	doc_681992022007_item	2806869	et	4	main
tahtnud	doc_681992022007_item	2806870	et	4	main
papagoi	doc_681992022008_item	2806880	et	4	main
sõnad	doc_681992022008_item	2806887	et	4	main
et	doc_681992022008_item	2806888	et	3	main
kõigile	doc_681992022008_item	2806889	et	4	main
helega	doc_681992022008_item	2806895	et	4	main
midagi	doc_681992022008_item	2806906	et	4	main
küsida	doc_681992022008_item	2806907	et	3	main
poiss	doc_681992022008_item	2806908	et	3	main
papagoiga	doc_681992022008_item	2806909	et	3	main
peatus	doc_681992022008_item	2806910	et	4	main
tüdrukule	doc_681992022008_item	2806911	et	3	main
väga	doc_681992022008_item	2806912	et	3	main
meeldis	doc_681992022008_item	2806913	et	3	main
papagoi	doc_681992022008_item	2806914	et	4	main
ja	doc_681992022008_item	2806915	et	3	main
poiss	doc_681992022008_item	2806916	et	3	main
soovitas	doc_681992022008_item	2806917	et	3	main
ostma	doc_681992022008_item	2806918	et	3	main
ja	doc_681992022008_item	2806919	et	3	main
anne	doc_681992022008_item	2806920	et	4	main
papagoi	doc_681992022008_item	2806923	et	4	main
anne	doc_681992022008_item	2806930	et	4	main
anne	doc_681992022008_item	2806935	et	4	main
ta	doc_681992022008_item	2806939	et	4	main
ehmus	doc_681992022008_item	2806941	et	4	main
ehmatas	doc_681992022008_item	2806943	et	3	main
otsustas	doc_681992022008_item	2806955	et	3	main
hiljem	doc_681992022008_item	2806963	et	3	main
oma	doc_681992022008_item	2806971	et	4	main
sõbrannateid	doc_681992022008_item	2806972	et	3	main
jutustus	doc_681992022008_item	2806973	et	4	main
teda	doc_681992022008_item	2806977	et	4	main
papagoi	doc_681992022009_item	2806999	et	4	main
sõna	doc_681992022009_item	2807003	et	4	main
pois	doc_681992022009_item	2807005	et	3	main
ja	doc_681992022009_item	2807031	et	3	main
seda	doc_681992022009_item	2807048	et	3	main
ta	doc_681992022009_item	2807051	et	4	main
oli	doc_681992022009_item	2807052	et	3	main
anda	doc_681992022009_item	2807058	et	3	main
semneid	doc_681992022009_item	2807060	et	4	main
tüdruku	doc_681992022009_item	2807076	et	3	main
kui	doc_681992022009_item	2807087	et	3	main
papagoi	doc_681992022009_item	2807088	et	4	main
algas	doc_681992022009_item	2807089	et	3	main
kohtus	doc_681992022009_item	2807121	et	4	main
ehmusid	doc_681992022009_item	2807128	et	4	main
tüdruk	doc_681992022009_item	2807129	et	3	main
ehmatas	doc_681992022009_item	2807130	et	3	main
papagoi	doc_681992022010_item	2807141	et	4	main
ta	doc_681992022010_item	2807148	et	4	main
üks	doc_681992022010_item	2807169	et	3	main
peatas	doc_681992022010_item	2807171	et	3	main
ja	doc_681992022010_item	2807173	et	3	main
sinu	doc_681992022010_item	2807176	et	3	main
tüdruk	doc_681992022010_item	2807188	et	3	main
osta	doc_681992022010_item	2807190	et	4	main
nõustus	doc_681992022010_item	2807193	et	4	main
ja	doc_681992022010_item	2807194	et	3	main
soovitas	doc_681992022010_item	2807195	et	3	main
papagoi	doc_681992022008_item	2806932	et	4	main
ta	doc_681992022008_item	2806945	et	4	main
rääkis	doc_681992022008_item	2806946	et	3	main
ebatsensuursed	doc_681992022008_item	2806947	et	3	main
sõnad	doc_681992022008_item	2806948	et	4	main
anne	doc_681992022008_item	2806954	et	4	main
papagoi	doc_681992022008_item	2806957	et	4	main
rääkima	doc_681992022008_item	2806958	et	3	main
head	doc_681992022008_item	2806959	et	4	main
sõnad	doc_681992022008_item	2806960	et	4	main
tegeles	doc_681992022008_item	2806961	et	3	main
väga	doc_681992022008_item	2806980	et	3	main
nad	doc_681992022008_item	2806982	et	3	main
rääkima	doc_681992022009_item	2806995	et	3	main
õppis	doc_681992022009_item	2807000	et	3	main
kui	doc_681992022009_item	2807011	et	3	main
nad	doc_681992022009_item	2807012	et	3	main
tulid	doc_681992022009_item	2807013	et	4	main
temu	doc_681992022009_item	2807014	et	4	main
juurde	doc_681992022009_item	2807015	et	4	main
siis	doc_681992022009_item	2807016	et	3	main
papagoi	doc_681992022009_item	2807017	et	4	main
tutvus	doc_681992022009_item	2807018	et	4	main
nendega	doc_681992022009_item	2807019	et	4	main
ise	doc_681992022009_item	2807020	et	4	main
ükskord	doc_681992022009_item	2807021	et	3	main
papagoiga	doc_681992022009_item	2807023	et	3	main
õues	doc_681992022009_item	2807025	et	4	main
üks	doc_681992022009_item	2807027	et	3	main
ta	doc_681992022009_item	2807036	et	4	main
tahab	doc_681992022009_item	2807037	et	3	main
seda	doc_681992022009_item	2807038	et	3	main
kena	doc_681992022009_item	2807039	et	4	main
üllatusega	doc_681992022009_item	2807044	et	4	main
papagoi	doc_681992022009_item	2807049	et	4	main
soovitas	doc_681992022009_item	2807057	et	3	main
vett	doc_681992022009_item	2807062	et	3	main
jalutada	doc_681992022009_item	2807064	et	3	main
minuti	doc_681992022009_item	2807067	et	3	main
seda	doc_681992022009_item	2807075	et	3	main
ehmus	doc_681992022009_item	2807086	et	4	main
ehmatas	doc_681992022009_item	2807092	et	3	main
oma	doc_681992022009_item	2807132	et	4	main
laulma	doc_681992022010_item	2807150	et	3	main
selgeks	doc_681992022010_item	2807153	et	3	main
vana	doc_681992022010_item	2807155	et	4	main
tutvus	doc_681992022010_item	2807163	et	4	main
laulis	doc_681992022010_item	2807166	et	4	main
oskab	doc_681992022010_item	2807186	et	3	main
teda	doc_681992022010_item	2807197	et	4	main
uued	doc_681992022010_item	2807212	et	3	main
hakkas	doc_681992022010_item	2807224	et	3	main
pärast	doc_681992022010_item	2807226	et	4	main
harjus	doc_681992022010_item	2807228	et	4	main
papagoiga	doc_681992022010_item	2807229	et	3	main
ja	doc_681992022010_item	2807230	et	3	main
papagoi	doc_681992022011_item	2807249	et	4	main
ja	doc_681992022011_item	2807273	et	3	main
tüdruk	doc_681992022011_item	2807276	et	3	main
ja	doc_681992022011_item	2807280	et	3	main
siis	doc_681992022011_item	2807286	et	3	main
sai	doc_681992022011_item	2807291	et	4	main
oma	doc_681992022011_item	2807292	et	4	main
kodus	doc_681992022011_item	2807297	et	4	main
papagoi	doc_681992022011_item	2807298	et	4	main
tüdruk	doc_681992022011_item	2807321	et	3	main
nagu	doc_681992022011_item	2807325	et	3	main
raamat	doc_681992022008_item	2806937	et	3	main
papagoi	doc_681992022008_item	2806964	et	4	main
rääkima	doc_681992022008_item	2806966	et	3	main
korralikud	doc_681992022008_item	2806967	et	3	main
mida	doc_681992022008_item	2806974	et	4	main
oskab	doc_681992022008_item	2806975	et	3	main
sõbrannad	doc_681992022008_item	2806979	et	3	main
ei	doc_681992022008_item	2806983	et	4	main
sellise	doc_681992022008_item	2806985	et	4	main
ümberjutustus	doc_681992022009_item	2806986	et	3	main
ühel	doc_681992022009_item	2806987	et	3	main
poisil	doc_681992022009_item	2806988	et	3	main
oli	doc_681992022009_item	2806989	et	3	main
papagoi	doc_681992022009_item	2806990	et	4	main
ja	doc_681992022009_item	2806991	et	3	main
pois	doc_681992022009_item	2806992	et	3	main
2	doc_681992022009_item	2806996	et	2	main
jalutasid	doc_681992022009_item	2807024	et	4	main
poisi	doc_681992022009_item	2807030	et	3	main
kui	doc_681992022009_item	2807034	et	3	main
see	doc_681992022009_item	2807045	et	3	main
tüdruk	doc_681992022009_item	2807046	et	3	main
soovis	doc_681992022009_item	2807047	et	4	main
pois	doc_681992022009_item	2807056	et	3	main
papagoile	doc_681992022009_item	2807059	et	3	main
ja	doc_681992022009_item	2807063	et	3	main
15	doc_681992022009_item	2807066	et	2	main
sai	doc_681992022009_item	2807070	et	4	main
ja	doc_681992022009_item	2807077	et	3	main
koju	doc_681992022009_item	2807079	et	3	main
pärast	doc_681992022009_item	2807082	et	4	main
ostmiseks	doc_681992022009_item	2807084	et	4	main
tüdruk	doc_681992022009_item	2807085	et	3	main
ta	doc_681992022009_item	2807091	et	4	main
sõnadega	doc_681992022009_item	2807133	et	3	main
papagoi	doc_681992022009_item	2807139	et	4	main
ümberjutustus	doc_681992022010_item	2807140	et	3	main
ühel	doc_681992022010_item	2807142	et	3	main
poisil	doc_681992022010_item	2807143	et	3	main
elas	doc_681992022010_item	2807144	et	3	main
kodus	doc_681992022010_item	2807145	et	4	main
õpetas	doc_681992022010_item	2807149	et	3	main
õppis	doc_681992022010_item	2807152	et	3	main
üks	doc_681992022010_item	2807154	et	3	main
laul	doc_681992022010_item	2807156	et	4	main
poiss	doc_681992022010_item	2807157	et	3	main
tutvustas	doc_681992022010_item	2807158	et	3	main
laulu	doc_681992022010_item	2807167	et	4	main
tüdruk	doc_681992022010_item	2807170	et	3	main
küsis	doc_681992022010_item	2807174	et	3	main
papagoi	doc_681992022010_item	2807177	et	4	main
oskab	doc_681992022010_item	2807178	et	3	main
rääkida	doc_681992022010_item	2807179	et	3	main
poiss	doc_681992022010_item	2807180	et	3	main
peatus	doc_681992022010_item	2807181	et	4	main
toita	doc_681992022010_item	2807196	et	4	main
sai	doc_681992022010_item	2807200	et	4	main
raha	doc_681992022010_item	2807201	et	4	main
edasi	doc_681992022010_item	2807204	et	3	main
papagoi	doc_681992022010_item	2807207	et	4	main
kodu	doc_681992022010_item	2807210	et	4	main
sõnad	doc_681992022008_item	2806968	et	4	main
anne	doc_681992022008_item	2806969	et	4	main
ehmusid	doc_681992022008_item	2806981	et	4	main
õpetas	doc_681992022009_item	2806993	et	3	main
nädala	doc_681992022009_item	2806997	et	3	main
umbes	doc_681992022009_item	2807001	et	4	main
otsustas	doc_681992022009_item	2807006	et	3	main
papagoi	doc_681992022009_item	2807009	et	4	main
sõbradele	doc_681992022009_item	2807010	et	4	main
pois	doc_681992022009_item	2807022	et	3	main
ja	doc_681992022009_item	2807026	et	3	main
tüdruk	doc_681992022009_item	2807028	et	3	main
peatas	doc_681992022009_item	2807029	et	3	main
pois	doc_681992022009_item	2807042	et	3	main
peatus	doc_681992022009_item	2807043	et	4	main
sest	doc_681992022009_item	2807050	et	4	main
ilus	doc_681992022009_item	2807053	et	4	main
ja	doc_681992022009_item	2807054	et	3	main
pois	doc_681992022009_item	2807069	et	3	main
200	doc_681992022009_item	2807071	et	2	main
krooni	doc_681992022009_item	2807072	et	4	main
1	doc_681992022009_item	2807080	et	2	main
papagoi	doc_681992022009_item	2807083	et	4	main
tüdruku	doc_681992022009_item	2807093	et	3	main
oma	doc_681992022009_item	2807094	et	4	main
sõnadega	doc_681992022009_item	2807095	et	3	main
ta	doc_681992022009_item	2807096	et	4	main
teas	doc_681992022009_item	2807097	et	4	main
100	doc_681992022009_item	2807098	et	2	main
paha	doc_681992022009_item	2807099	et	4	main
sõnu	doc_681992022009_item	2807100	et	4	main
umbes	doc_681992022009_item	2807101	et	4	main
5	doc_681992022009_item	2807102	et	2	main
päeva	doc_681992022009_item	2807103	et	4	main
pärast	doc_681992022009_item	2807104	et	4	main
tüdruk	doc_681992022009_item	2807105	et	3	main
harjutas	doc_681992022009_item	2807106	et	3	main
iga	doc_681992022009_item	2807107	et	4	main
päev	doc_681992022009_item	2807108	et	3	main
papagoi	doc_681992022009_item	2807109	et	4	main
juures	doc_681992022009_item	2807110	et	4	main
ja	doc_681992022009_item	2807111	et	3	main
ta	doc_681992022009_item	2807112	et	4	main
harjus	doc_681992022009_item	2807113	et	4	main
kuulata	doc_681992022009_item	2807114	et	4	main
papagoi	doc_681992022009_item	2807115	et	4	main
paha	doc_681992022009_item	2807116	et	4	main
sõnu	doc_681992022009_item	2807117	et	4	main
ja	doc_681992022009_item	2807118	et	3	main
kui	doc_681992022009_item	2807119	et	3	main
tüdruk	doc_681992022009_item	2807120	et	3	main
nende	doc_681992022009_item	2807131	et	4	main
nagu	doc_681992022009_item	2807136	et	3	main
uus	doc_681992022009_item	2807138	et	3	main
klassikaaslasele	doc_681992022010_item	2807159	et	3	main
lind	doc_681992022010_item	2807162	et	3	main
lastega	doc_681992022010_item	2807164	et	3	main
ja	doc_681992022010_item	2807165	et	3	main
õues	doc_681992022010_item	2807168	et	4	main
poissi	doc_681992022010_item	2807172	et	4	main
kas	doc_681992022010_item	2807175	et	3	main
laulma	doc_681992022010_item	2807187	et	3	main
porgandiga	doc_681992022010_item	2807198	et	3	main
läks	doc_681992022010_item	2807203	et	3	main
tüdruk	doc_681992022010_item	2807205	et	3	main
tema	doc_681992022009_item	2807122	et	4	main
sõbradega	doc_681992022009_item	2807123	et	4	main
ja	doc_681992022009_item	2807124	et	3	main
algas	doc_681992022009_item	2807125	et	3	main
rääkima	doc_681992022009_item	2807126	et	3	main
nad	doc_681992022009_item	2807127	et	3	main
ta	doc_681992022009_item	2807134	et	4	main
sõimas	doc_681992022009_item	2807135	et	3	main
tema	doc_681992022009_item	2807137	et	4	main
papagoi	doc_681992022010_item	2807146	et	4	main
kelle	doc_681992022010_item	2807147	et	4	main
papagoi	doc_681992022010_item	2807151	et	4	main
oma	doc_681992022010_item	2807160	et	4	main
papagoid	doc_681992022010_item	2807161	et	4	main
ja	doc_681992022010_item	2807182	et	3	main
ütles	doc_681992022010_item	2807183	et	3	main
minu	doc_681992022010_item	2807184	et	3	main
papagoi	doc_681992022010_item	2807185	et	4	main
soovis	doc_681992022010_item	2807189	et	4	main
papagoi	doc_681992022010_item	2807191	et	4	main
poiss	doc_681992022010_item	2807192	et	3	main
poiss	doc_681992022010_item	2807199	et	3	main
ja	doc_681992022010_item	2807202	et	3	main
uus	doc_681992022010_item	2807209	et	3	main
ja	doc_681992022010_item	2807211	et	3	main
ehmatasid	doc_681992022010_item	2807214	et	4	main
ja	doc_681992022010_item	2807216	et	3	main
ta	doc_681992022010_item	2807217	et	4	main
hakkas	doc_681992022010_item	2807218	et	3	main
hirmsasti	doc_681992022010_item	2807219	et	3	main
karjuma	doc_681992022010_item	2807220	et	3	main
tüdruk	doc_681992022010_item	2807221	et	3	main
ja	doc_681992022010_item	2807223	et	3	main
ei	doc_681992022010_item	2807234	et	4	main
papagoi	doc_681992022011_item	2807260	et	4	main
võib	doc_681992022011_item	2807261	et	3	main
tutvuda	doc_681992022011_item	2807262	et	3	main
ja	doc_681992022011_item	2807263	et	3	main
pois	doc_681992022011_item	2807264	et	3	main
tutvustas	doc_681992022011_item	2807265	et	3	main
sõpru	doc_681992022011_item	2807266	et	3	main
papagoiga	doc_681992022011_item	2807267	et	3	main
tüdruk	doc_681992022011_item	2807272	et	3	main
poiss	doc_681992022011_item	2807281	et	3	main
tüdruk	doc_681992022011_item	2807287	et	3	main
papagoit	doc_681992022011_item	2807289	et	4	main
saatis	doc_681992022011_item	2807295	et	3	main
neid	doc_681992022011_item	2807296	et	4	main
ehmatas	doc_681992022011_item	2807304	et	3	main
ja	doc_681992022011_item	2807313	et	3	main
lugema	doc_681992022011_item	2807316	et	4	main
papagoiga	doc_681992022011_item	2807318	et	3	main
väga	doc_681992022011_item	2807322	et	3	main
sõpru	doc_681992022011_item	2807324	et	3	main
papagoi	doc_681992022011_item	2807327	et	4	main
ja	doc_681992022011_item	2807328	et	3	main
ka	doc_681992022011_item	2807330	et	3	main
töötab	doc_681992022013_item	2807453	et	3	main
arvan	doc_681992022013_item	2807456	et	3	main
tugev	doc_681992022013_item	2807460	et	4	main
ja	doc_681992022013_item	2807461	et	3	main
juuksed	doc_681992022013_item	2807469	et	3	main
veel	doc_681992022013_item	2807470	et	4	main
kindad	doc_681992022013_item	2807479	et	3	main
töötab	doc_681992022013_item	2807483	et	3	main
triibuline	doc_681992022013_item	2807498	et	4	main
t-särk	doc_681992022013_item	2807499	et	3	main
saatis	doc_681992022010_item	2807206	et	3	main
koju	doc_681992022010_item	2807208	et	3	main
papagoi	doc_681992022010_item	2807233	et	4	main
papagoi	doc_681992022010_item	2807237	et	4	main
papagoi	doc_681992022011_item	2807254	et	4	main
poiss	doc_681992022011_item	2807274	et	3	main
soovis	doc_681992022011_item	2807277	et	4	main
vaadata	doc_681992022011_item	2807278	et	4	main
lähemalt	doc_681992022011_item	2807285	et	4	main
ehmus	doc_681992022011_item	2807299	et	4	main
tüdrukut	doc_681992022011_item	2807300	et	3	main
ja	doc_681992022011_item	2807301	et	3	main
papagoi	doc_681992022011_item	2807309	et	4	main
harjutas	doc_681992022011_item	2807310	et	3	main
tüdrukut	doc_681992022011_item	2807311	et	3	main
harjus	doc_681992022011_item	2807315	et	4	main
koos	doc_681992022011_item	2807317	et	4	main
kord	doc_681992022011_item	2807320	et	4	main
ehmus	doc_681992022011_item	2807323	et	4	main
ehmatasid	doc_681992022011_item	2807332	et	4	main
noormees	doc_681992022013_item	2807451	et	4	main
ma	doc_681992022013_item	2807455	et	3	main
noormees	doc_681992022013_item	2807458	et	4	main
mustad	doc_681992022013_item	2807478	et	4	main
ta	doc_681992022013_item	2807482	et	4	main
naine	doc_681992022013_item	2807485	et	3	main
on	doc_681992022013_item	2807497	et	4	main
nüüd	doc_681992022014_item	2807521	et	4	main
elab	doc_681992022014_item	2807523	et	3	main
safariparki	doc_681992022014_item	2807524	et	4	main
ta	doc_681992022014_item	2807525	et	4	main
se	doc_681992022014_item	2807536	et	4	main
talle	doc_681992022014_item	2807539	et	4	main
võib	doc_681992022014_item	2807549	et	3	main
et	doc_681992022014_item	2807556	et	3	main
talle	doc_681992022014_item	2807557	et	4	main
ndiyo	doc_681992022014_item	2807571	et	4	main
magab	doc_681992022014_item	2807572	et	3	main
lapsega	doc_681992022014_item	2807577	et	3	main
kasvab	doc_681992022014_item	2807586	et	3	main
lõvikutsikas	doc_681992022015_item	2807595	et	4	main
ning	doc_681992022015_item	2807603	et	3	main
viidi	doc_681992022015_item	2807605	et	4	main
tema	doc_681992022015_item	2807608	et	4	main
ema	doc_681992022015_item	2807609	et	4	main
nii	doc_681992022015_item	2807610	et	3	main
ülemvahil	doc_681992022015_item	2807628	et	3	main
saa	doc_681992022015_item	2807641	et	4	main
ööseks	doc_681992022015_item	2807643	et	4	main
jätta	doc_681992022015_item	2807645	et	3	main
talle	doc_681992022015_item	2807646	et	4	main
päeval	doc_681992022015_item	2807648	et	3	main
parki	doc_681992022015_item	2807652	et	4	main
kuhu	doc_681992022015_item	2807663	et	3	main
pole	doc_681992022015_item	2807664	et	3	main
ümberjutustus	doc_681992022016_item	2807666	et	3	main
kellel	doc_681992022016_item	2807672	et	4	main
pruunid	doc_681992022016_item	2807675	et	3	main
ja	doc_681992022016_item	2807677	et	3	main
isepäine	doc_681992022016_item	2807678	et	3	main
ta	doc_681992022016_item	2807680	et	4	main
temaga	doc_681992022016_item	2807731	et	3	main
laamasid	doc_681992022016_item	2807742	et	4	main
nendega	doc_681992022016_item	2807746	et	4	main
mängida	doc_681992022016_item	2807747	et	3	main
ka	doc_681992022016_item	2807757	et	3	main
neli	doc_681992022016_item	2807761	et	3	main
viivad	doc_681992022016_item	2807763	et	4	main
inimesed	doc_681992022010_item	2807213	et	3	main
papagoid	doc_681992022010_item	2807215	et	4	main
nutma	doc_681992022010_item	2807225	et	3	main
et	doc_681992022010_item	2807232	et	3	main
aga	doc_681992022010_item	2807236	et	3	main
natuke	doc_681992022010_item	2807239	et	4	main
ja	doc_681992022010_item	2807240	et	3	main
hakkas	doc_681992022010_item	2807241	et	3	main
poisil	doc_681992022011_item	2807246	et	3	main
oli	doc_681992022011_item	2807247	et	3	main
kodus	doc_681992022011_item	2807248	et	4	main
ta	doc_681992022011_item	2807251	et	4	main
rääkima	doc_681992022011_item	2807253	et	3	main
õppis	doc_681992022011_item	2807255	et	3	main
umbes	doc_681992022011_item	2807257	et	4	main
õues	doc_681992022011_item	2807268	et	4	main
peatas	doc_681992022011_item	2807270	et	3	main
üks	doc_681992022011_item	2807271	et	3	main
soovitas	doc_681992022011_item	2807282	et	3	main
vaadata	doc_681992022011_item	2807284	et	4	main
ostis	doc_681992022011_item	2807288	et	4	main
poiss	doc_681992022011_item	2807290	et	3	main
ja	doc_681992022011_item	2807294	et	3	main
sest	doc_681992022011_item	2807305	et	4	main
ta	doc_681992022011_item	2807306	et	4	main
väga	doc_681992022011_item	2807307	et	3	main
kärjus	doc_681992022011_item	2807308	et	4	main
ta	doc_681992022011_item	2807314	et	4	main
teda	doc_681992022011_item	2807326	et	4	main
nad	doc_681992022011_item	2807329	et	3	main
väga	doc_681992022011_item	2807331	et	3	main
vormis	doc_681992022013_item	2807463	et	4	main
spordidress	doc_681992022013_item	2807474	et	3	main
naine	doc_681992022013_item	2807481	et	3	main
fotomodellina	doc_681992022013_item	2807484	et	3	main
ja	doc_681992022013_item	2807493	et	3	main
kollane	doc_681992022013_item	2807494	et	4	main
juuksed	doc_681992022013_item	2807495	et	3	main
naisel	doc_681992022013_item	2807496	et	3	main
värvi	doc_681992022013_item	2807501	et	4	main
ta	doc_681992022014_item	2807522	et	4	main
talle	doc_681992022014_item	2807544	et	4	main
meeldib	doc_681992022014_item	2807545	et	3	main
teleka	doc_681992022014_item	2807546	et	3	main
tundide	doc_681992022014_item	2807550	et	3	main
silma	doc_681992022014_item	2807553	et	4	main
vaipu	doc_681992022014_item	2807559	et	3	main
ndiyo	doc_681992022014_item	2807561	et	4	main
korda	doc_681992022014_item	2807564	et	4	main
suur	doc_681992022014_item	2807565	et	3	main
taldriku	doc_681992022014_item	2807566	et	3	main
sonjast	doc_681992022014_item	2807574	et	4	main
suhtlema	doc_681992022014_item	2807578	et	3	main
on	doc_681992022014_item	2807581	et	4	main
kui	doc_681992022014_item	2807583	et	3	main
ndiyo	doc_681992022014_item	2807584	et	4	main
tagasi	doc_681992022014_item	2807588	et	3	main
paradiisi	doc_681992022014_item	2807590	et	4	main
ümberjutustus	doc_681992022015_item	2807592	et	3	main
ndiyo	doc_681992022015_item	2807593	et	4	main
lõpus	doc_681992022015_item	2807599	et	4	main
kui	doc_681992022015_item	2807607	et	3	main
ehmatas	doc_681992022010_item	2807222	et	3	main
ta	doc_681992022010_item	2807227	et	4	main
mõtles	doc_681992022010_item	2807231	et	3	main
laula	doc_681992022010_item	2807235	et	4	main
harjutas	doc_681992022010_item	2807238	et	3	main
ilusasti	doc_681992022010_item	2807242	et	3	main
laulma	doc_681992022010_item	2807243	et	3	main
ümberjutustus	doc_681992022011_item	2807244	et	3	main
ühel	doc_681992022011_item	2807245	et	3	main
kelle	doc_681992022011_item	2807250	et	4	main
õpetas	doc_681992022011_item	2807252	et	3	main
selgeks	doc_681992022011_item	2807256	et	3	main
100	doc_681992022011_item	2807258	et	2	main
sõna	doc_681992022011_item	2807259	et	4	main
poissi	doc_681992022011_item	2807269	et	4	main
peatus	doc_681992022011_item	2807275	et	4	main
papagoit	doc_681992022011_item	2807279	et	4	main
talle	doc_681992022011_item	2807283	et	4	main
raha	doc_681992022011_item	2807293	et	4	main
ta	doc_681992022011_item	2807302	et	4	main
väga	doc_681992022011_item	2807303	et	3	main
kärale	doc_681992022011_item	2807312	et	3	main
üks	doc_681992022011_item	2807319	et	3	main
kirjeldus	doc_681992022013_item	2807450	et	4	main
fotomodellina	doc_681992022013_item	2807454	et	3	main
tal	doc_681992022013_item	2807464	et	3	main
on	doc_681992022013_item	2807465	et	4	main
tumedad	doc_681992022013_item	2807466	et	3	main
ja	doc_681992022013_item	2807467	et	3	main
lühikesed	doc_681992022013_item	2807468	et	4	main
väga	doc_681992022013_item	2807487	et	3	main
välimus	doc_681992022013_item	2807489	et	3	main
on	doc_681992022013_item	2807491	et	4	main
keskpikka	doc_681992022013_item	2807492	et	4	main
seljas	doc_681992022013_item	2807502	et	4	main
viidi	doc_681992022014_item	2807526	et	4	main
osakonna	doc_681992022014_item	2807532	et	4	main
et	doc_681992022014_item	2807538	et	3	main
ona	doc_681992022014_item	2807540	et	4	main
vaja	doc_681992022014_item	2807541	et	4	main
elada	doc_681992022014_item	2807542	et	3	main
peres	doc_681992022014_item	2807543	et	3	main
telekaekraanile	doc_681992022014_item	2807554	et	3	main
meeldib	doc_681992022014_item	2807558	et	3	main
5	doc_681992022014_item	2807563	et	2	main
hakkliha	doc_681992022014_item	2807567	et	4	main
ja	doc_681992022014_item	2807568	et	3	main
erikoostisega	doc_681992022014_item	2807569	et	3	main
meeldib	doc_681992022014_item	2807576	et	3	main
ta	doc_681992022014_item	2807587	et	4	main
tuleb	doc_681992022014_item	2807589	et	3	main
kaitseala	doc_681992022014_item	2807591	et	4	main
kaitseala	doc_681992022015_item	2807601	et	4	main
tema	doc_681992022015_item	2807611	et	4	main
ka	doc_681992022015_item	2807613	et	3	main
ta	doc_681992022015_item	2807622	et	4	main
üles	doc_681992022015_item	2807623	et	3	main
ei	doc_681992022015_item	2807640	et	4	main
sellest	doc_681992022015_item	2807657	et	4	main
ta	doc_681992022015_item	2807659	et	4	main
topib	doc_681992022015_item	2807660	et	3	main
nina	doc_681992022015_item	2807661	et	4	main
sinna	doc_681992022015_item	2807662	et	3	main
on	doc_681992022016_item	2807670	et	4	main
sündis	doc_681992022016_item	2807681	et	3	main
juuli	doc_681992022016_item	2807682	et	4	main
lõpus	doc_681992022016_item	2807683	et	4	main
mööda	doc_681992022016_item	2807732	et	4	main
käia	doc_681992022016_item	2807734	et	4	main
pargis	doc_681992022016_item	2807735	et	3	main
ja	doc_681992022016_item	2807741	et	3	main
talle	doc_681992022016_item	2807744	et	4	main
lõvid	doc_681992022016_item	2807748	et	3	main
hoida	doc_681992022016_item	2807774	et	3	main
ndiyo	doc_681992022016_item	2807782	et	4	main
tõmmata	doc_681992022016_item	2807819	et	4	main
ndiyole	doc_681992022016_item	2807820	et	4	main
pildi	doc_681992022013_item	2807449	et	4	main
ta	doc_681992022013_item	2807452	et	4	main
et	doc_681992022013_item	2807457	et	3	main
on	doc_681992022013_item	2807459	et	4	main
hea	doc_681992022013_item	2807462	et	4	main
ta	doc_681992022013_item	2807471	et	4	main
kannab	doc_681992022013_item	2807472	et	3	main
tume	doc_681992022013_item	2807473	et	3	main
ja	doc_681992022013_item	2807475	et	3	main
tal	doc_681992022013_item	2807476	et	3	main
on	doc_681992022013_item	2807477	et	4	main
jalas	doc_681992022013_item	2807480	et	4	main
on	doc_681992022013_item	2807486	et	4	main
ilus	doc_681992022013_item	2807488	et	4	main
tal	doc_681992022013_item	2807490	et	3	main
tal	doc_681992022013_item	2807503	et	3	main
on	doc_681992022013_item	2807504	et	4	main
sinised	doc_681992022013_item	2807505	et	4	main
püksid	doc_681992022013_item	2807506	et	3	main
ja	doc_681992022013_item	2807507	et	3	main
mustad	doc_681992022013_item	2807508	et	4	main
saapad	doc_681992022013_item	2807509	et	3	main
jalas	doc_681992022013_item	2807510	et	4	main
ümberjutustus	doc_681992022014_item	2807511	et	3	main
ndiyo	doc_681992022014_item	2807512	et	4	main
on	doc_681992022014_item	2807513	et	4	main
väike	doc_681992022014_item	2807514	et	4	main
lõvi	doc_681992022014_item	2807515	et	4	main
ndiyo	doc_681992022014_item	2807516	et	4	main
sündis	doc_681992022014_item	2807517	et	3	main
paradiisi	doc_681992022014_item	2807518	et	4	main
kaitseala	doc_681992022014_item	2807519	et	4	main
pargis	doc_681992022014_item	2807520	et	3	main
tumeda	doc_681992022013_item	2807500	et	3	main
safariparki	doc_681992022014_item	2807527	et	4	main
on	doc_681992022014_item	2807534	et	4	main
tähendab	doc_681992022014_item	2807537	et	3	main
ta	doc_681992022014_item	2807548	et	4	main
kaupa	doc_681992022014_item	2807551	et	4	main
selleks	doc_681992022014_item	2807555	et	4	main
päevast	doc_681992022014_item	2807560	et	4	main
sööb	doc_681992022014_item	2807562	et	3	main
voodise	doc_681992022014_item	2807573	et	4	main
see	doc_681992022014_item	2807580	et	3	main
vastastikune	doc_681992022014_item	2807582	et	4	main
suureks	doc_681992022014_item	2807585	et	4	main
ndiyo	doc_681992022015_item	2807596	et	4	main
sündis	doc_681992022015_item	2807597	et	3	main
juuli	doc_681992022015_item	2807598	et	4	main
pargis	doc_681992022015_item	2807602	et	3	main
kui	doc_681992022015_item	2807612	et	3	main
sonja	doc_681992022014_item	2807528	et	4	main
töötab	doc_681992022014_item	2807529	et	3	main
pargi	doc_681992022014_item	2807530	et	4	main
lemmikloomade	doc_681992022014_item	2807531	et	4	main
ta	doc_681992022014_item	2807533	et	4	main
ülemvahil	doc_681992022014_item	2807535	et	3	main
vaatama	doc_681992022014_item	2807547	et	3	main
lamada	doc_681992022014_item	2807552	et	3	main
piima	doc_681992022014_item	2807570	et	4	main
ndyo	doc_681992022014_item	2807575	et	4	main
ja	doc_681992022014_item	2807579	et	3	main
on	doc_681992022015_item	2807594	et	4	main
paradiisi	doc_681992022015_item	2807600	et	4	main
ta	doc_681992022015_item	2807604	et	4	main
safariparki	doc_681992022015_item	2807606	et	4	main
ülejäänud	doc_681992022015_item	2807614	et	4	main
sonia	doc_681992022015_item	2807625	et	4	main
ndiyot	doc_681992022015_item	2807639	et	4	main
ka	doc_681992022015_item	2807642	et	3	main
üksi	doc_681992022015_item	2807644	et	4	main
aga	doc_681992022015_item	2807654	et	3	main
probleemid	doc_681992022015_item	2807655	et	3	main
tekivad	doc_681992022015_item	2807656	et	3	main
et	doc_681992022015_item	2807658	et	3	main
koduloom	doc_681992022016_item	2807668	et	3	main
suured	doc_681992022016_item	2807674	et	3	main
tal	doc_681992022016_item	2807723	et	3	main
pesakonna	doc_681992022015_item	2807615	et	4	main
hülga	doc_681992022015_item	2807616	et	4	main
oli	doc_681992022015_item	2807617	et	3	main
selge	doc_681992022015_item	2807618	et	4	main
et	doc_681992022015_item	2807619	et	3	main
inimesed	doc_681992022015_item	2807620	et	3	main
peavad	doc_681992022015_item	2807621	et	4	main
on	doc_681992022015_item	2807627	et	4	main
sonia	doc_681992022015_item	2807629	et	4	main
on	doc_681992022015_item	2807630	et	4	main
lõviga	doc_681992022015_item	2807631	et	3	main
eriti	doc_681992022015_item	2807632	et	3	main
söbralikud	doc_681992022015_item	2807633	et	4	main
suhted	doc_681992022015_item	2807634	et	3	main
see	doc_681992022015_item	2807635	et	3	main
aga	doc_681992022015_item	2807636	et	3	main
tähendab	doc_681992022015_item	2807637	et	3	main
et	doc_681992022015_item	2807638	et	3	main
meldib	doc_681992022015_item	2807647	et	4	main
koos	doc_681992022015_item	2807649	et	4	main
minuga	doc_681992022015_item	2807650	et	3	main
mööda	doc_681992022015_item	2807651	et	4	main
ndiyo	doc_681992022016_item	2807669	et	4	main
lõvikutsikas	doc_681992022016_item	2807671	et	4	main
silmad	doc_681992022016_item	2807676	et	4	main
iseloom	doc_681992022016_item	2807679	et	3	main
lõvikutsikuga	doc_681992022016_item	2807722	et	4	main
koos	doc_681992022016_item	2807730	et	4	main
loomi	doc_681992022016_item	2807738	et	4	main
ei	doc_681992022016_item	2807755	et	4	main
hooldajat	doc_681992022016_item	2807762	et	4	main
ta	doc_681992022016_item	2807764	et	4	main
kordamööda	doc_681992022016_item	2807765	et	3	main
tuleb	doc_681992022016_item	2807770	et	3	main
silma	doc_681992022016_item	2807772	et	4	main
peal	doc_681992022016_item	2807773	et	4	main
loodussaated	doc_681992022016_item	2807781	et	3	main
meeldivad	doc_681992022016_item	2807821	et	4	main
ja	doc_681992022016_item	2807823	et	3	main
on	doc_681992022016_item	2807825	et	4	main
vastastikune	doc_681992022016_item	2807826	et	4	main
aga	doc_681992022016_item	2807827	et	3	main
nad	doc_681992022016_item	2807828	et	3	main
neile	doc_681992022016_item	2807837	et	4	main
küllalt	doc_681992022016_item	2807843	et	4	main
viiakse	doc_681992022016_item	2807848	et	3	main
korteri	doc_681992022017_item	2807863	et	3	main
tingimused	doc_681992022017_item	2807867	et	3	main
1	doc_681992022017_item	2807872	et	2	main
miks	doc_681992022017_item	2807873	et	4	main
tuleb	doc_681992022017_item	2807874	et	3	main
minna	doc_681992022017_item	2807877	et	3	main
oskab	doc_681992022017_item	2807881	et	3	main
öelda	doc_681992022017_item	2807882	et	4	main
kas	doc_681992022017_item	2807883	et	3	main
selle	doc_681992022017_item	2807893	et	4	main
1	doc_681992022017_item	2807897	et	2	main
kes	doc_681992022017_item	2807898	et	4	main
freeman	doc_681992022017_item	2807901	et	4	main
lemmikloomade	doc_681992022017_item	2807906	et	4	main
oli	doc_681992022017_item	2807924	et	3	main
viidi	doc_681992022017_item	2807934	et	4	main
liigitatakse	doc_681992022017_item	2807938	et	3	main
mõttekam	doc_681992022017_item	2807946	et	4	main
viia	doc_681992022017_item	2807949	et	3	main
otsustas	doc_681992022017_item	2807957	et	3	main
perekonnanimi	doc_681992022017_item	2807959	et	3	main
sorteerima	doc_681992022017_item	2807961	et	3	main
nende	doc_681992022017_item	2807966	et	4	main
prügikast	doc_681992022017_item	2807967	et	3	main
sisse	doc_681992022017_item	2807968	et	4	main
jääkide	doc_681992022017_item	2807976	et	3	main
pandud	doc_681992022017_item	2807979	et	4	main
mahutitesse	doc_681992022017_item	2807980	et	4	main
meeldib	doc_681992022018_item	2808008	et	3	main
filmi	doc_681992022018_item	2808015	et	4	main
seda	doc_681992022018_item	2808021	et	3	main
teen	doc_681992022018_item	2808025	et	3	main
harva	doc_681992022018_item	2808026	et	4	main
kui	doc_681992022018_item	2808027	et	3	main
palun	doc_681992022018_item	2808039	et	3	main
kasvatama	doc_681992022015_item	2807624	et	4	main
freemanil	doc_681992022015_item	2807626	et	4	main
käia	doc_681992022015_item	2807653	et	4	main
vaja	doc_681992022015_item	2807665	et	4	main
ideaalne	doc_681992022016_item	2807667	et	3	main
on	doc_681992022016_item	2807673	et	4	main
paradiisi	doc_681992022016_item	2807684	et	4	main
kaitseala	doc_681992022016_item	2807685	et	4	main
pargis	doc_681992022016_item	2807686	et	3	main
nüüd	doc_681992022016_item	2807687	et	4	main
ndiyo	doc_681992022016_item	2807688	et	4	main
elab	doc_681992022016_item	2807689	et	3	main
safaripargis	doc_681992022016_item	2807690	et	3	main
kus	doc_681992022016_item	2807691	et	3	main
personalil	doc_681992022016_item	2807692	et	3	main
on	doc_681992022016_item	2807693	et	4	main
rohkem	doc_681992022016_item	2807694	et	4	main
tema	doc_681992022016_item	2807696	et	4	main
aega	doc_681992022016_item	2807695	et	4	main
eest	doc_681992022016_item	2807697	et	4	main
hoolitsemiseks	doc_681992022016_item	2807698	et	4	main
tema	doc_681992022016_item	2807699	et	4	main
ema	doc_681992022016_item	2807700	et	4	main
nii	doc_681992022016_item	2807701	et	3	main
tema	doc_681992022016_item	2807702	et	4	main
kui	doc_681992022016_item	2807703	et	3	main
ka	doc_681992022016_item	2807704	et	3	main
ülejäänud	doc_681992022016_item	2807705	et	4	main
pesakonna	doc_681992022016_item	2807706	et	4	main
hülgas	doc_681992022016_item	2807707	et	3	main
ja	doc_681992022016_item	2807708	et	3	main
nüüd	doc_681992022016_item	2807709	et	4	main
ndiyo	doc_681992022016_item	2807710	et	4	main
peab	doc_681992022016_item	2807711	et	4	main
õppima	doc_681992022016_item	2807712	et	3	main
elama	doc_681992022016_item	2807713	et	3	main
inimeste	doc_681992022016_item	2807714	et	3	main
kombel	doc_681992022016_item	2807715	et	4	main
sonia	doc_681992022016_item	2807716	et	4	main
on	doc_681992022016_item	2807717	et	4	main
pargi	doc_681992022016_item	2807718	et	4	main
lemmikloomade	doc_681992022016_item	2807719	et	4	main
osakonna	doc_681992022016_item	2807720	et	4	main
ülemvahi	doc_681992022016_item	2807721	et	3	main
sõbralikud	doc_681992022016_item	2807725	et	3	main
suhted	doc_681992022016_item	2807726	et	3	main
on	doc_681992022016_item	2807724	et	4	main
lõvikutsikule	doc_681992022016_item	2807727	et	4	main
eesleid	doc_681992022016_item	2807739	et	4	main
kitsi	doc_681992022016_item	2807740	et	4	main
ning	doc_681992022016_item	2807743	et	3	main
saa	doc_681992022016_item	2807756	et	4	main
üksi	doc_681992022016_item	2807759	et	4	main
meeldivad	doc_681992022016_item	2807780	et	4	main
närib	doc_681992022016_item	2807783	et	3	main
vaipu	doc_681992022016_item	2807784	et	3	main
sest	doc_681992022016_item	2807785	et	4	main
ta	doc_681992022016_item	2807786	et	4	main
kohtleb	doc_681992022016_item	2807787	et	3	main
neid	doc_681992022016_item	2807788	et	4	main
saagina	doc_681992022016_item	2807789	et	3	main
ja	doc_681992022016_item	2807790	et	3	main
asub	doc_681992022016_item	2807791	et	3	main
nende	doc_681992022016_item	2807792	et	4	main
eest	doc_681992022016_item	2807793	et	4	main
võitlusse	doc_681992022016_item	2807794	et	3	main
viis	doc_681992022016_item	2807795	et	4	main
korda	doc_681992022016_item	2807796	et	4	main
päevas	doc_681992022016_item	2807797	et	3	main
sööb	doc_681992022016_item	2807798	et	3	main
ndiyo	doc_681992022016_item	2807799	et	4	main
ära	doc_681992022016_item	2807800	et	4	main
suure	doc_681992022016_item	2807801	et	3	main
taldrikutäie	doc_681992022016_item	2807802	et	3	main
hakkliha	doc_681992022016_item	2807803	et	4	main
ja	doc_681992022016_item	2807804	et	3	main
joob	doc_681992022016_item	2807805	et	3	main
ära	doc_681992022016_item	2807806	et	4	main
erikoostisega	doc_681992022016_item	2807807	et	3	main
piima	doc_681992022016_item	2807808	et	4	main
ndiyo	doc_681992022016_item	2807809	et	4	main
eelistab	doc_681992022016_item	2807810	et	3	main
magada	doc_681992022016_item	2807811	et	3	main
sonia	doc_681992022016_item	2807812	et	4	main
voodis	doc_681992022016_item	2807813	et	3	main
talle	doc_681992022016_item	2807814	et	4	main
meeldib	doc_681992022016_item	2807815	et	3	main
end	doc_681992022016_item	2807816	et	4	main
padjal	doc_681992022016_item	2807817	et	3	main
kerra	doc_681992022016_item	2807818	et	4	main
meeldib	doc_681992022016_item	2807728	et	3	main
päeval	doc_681992022016_item	2807729	et	3	main
pargi	doc_681992022016_item	2807733	et	4	main
on	doc_681992022016_item	2807736	et	4	main
igasuguseid	doc_681992022016_item	2807737	et	3	main
meeldib	doc_681992022016_item	2807745	et	3	main
on	doc_681992022016_item	2807749	et	4	main
seltskondlikud	doc_681992022016_item	2807750	et	3	main
loomad	doc_681992022016_item	2807751	et	3	main
see	doc_681992022016_item	2807752	et	3	main
tähendab	doc_681992022016_item	2807753	et	3	main
ndiyot	doc_681992022016_item	2807754	et	4	main
ööseks	doc_681992022016_item	2807758	et	4	main
jätta	doc_681992022016_item	2807760	et	3	main
oma	doc_681992022016_item	2807766	et	4	main
aga	doc_681992022016_item	2807768	et	3	main
lapsed	doc_681992022016_item	2807822	et	3	main
sümpaatia	doc_681992022016_item	2807824	et	4	main
sest	doc_681992022016_item	2807835	et	4	main
tahab	doc_681992022016_item	2807836	et	3	main
paradiisi	doc_681992022016_item	2807851	et	4	main
kaitseala	doc_681992022016_item	2807852	et	4	main
küsimusele	doc_681992022017_item	2807855	et	4	main
teada	doc_681992022017_item	2807859	et	3	main
ostmisel	doc_681992022017_item	2807861	et	4	main
seisukord	doc_681992022017_item	2807864	et	3	main
ja	doc_681992022017_item	2807866	et	3	main
koos	doc_681992022017_item	2807878	et	4	main
tema	doc_681992022017_item	2807880	et	4	main
kehva	doc_681992022017_item	2807888	et	4	main
ostu	doc_681992022017_item	2807890	et	4	main
takistab	doc_681992022017_item	2807891	et	3	main
kulukaks	doc_681992022017_item	2807895	et	3	main
sonja	doc_681992022017_item	2807902	et	4	main
osakonna	doc_681992022017_item	2807907	et	4	main
1	doc_681992022017_item	2807909	et	2	main
miks	doc_681992022017_item	2807910	et	4	main
ta	doc_681992022017_item	2807929	et	4	main
üles	doc_681992022017_item	2807930	et	3	main
kasvatama	doc_681992022017_item	2807931	et	4	main
1	doc_681992022017_item	2807936	et	2	main
need	doc_681992022017_item	2807950	et	3	main
perekond	doc_681992022017_item	2807958	et	3	main
prügi	doc_681992022017_item	2807960	et	4	main
otsustasime	doc_681992022017_item	2807971	et	3	main
lugeda	doc_681992022018_item	2808010	et	3	main
muusikat	doc_681992022018_item	2808012	et	3	main
helistan	doc_681992022018_item	2808034	et	3	main
emale	doc_681992022018_item	2808035	et	3	main
ja	doc_681992022018_item	2808038	et	3	main
parandada	doc_681992022018_item	2808052	et	3	main
tuttaval	doc_681992022018_item	2808056	et	4	main
sünnipäev	doc_681992022018_item	2808058	et	3	main
temaga	doc_681992022018_item	2808062	et	3	main
mõtlen	doc_681992022018_item	2808064	et	3	main
siiski	doc_681992022018_item	2808069	et	4	main
ja	doc_681992022018_item	2808073	et	3	main
kõikidel	doc_681992022018_item	2808074	et	4	main
hea	doc_681992022018_item	2808076	et	4	main
sünnipäevi	doc_681992022018_item	2808084	et	4	main
sõber	doc_681992022018_item	2808087	et	3	main
appi	doc_681992022018_item	2808090	et	4	main
lähen	doc_681992022018_item	2808096	et	3	main
nende	doc_681992022019_item	2808145	et	4	main
marju	doc_681992022019_item	2808160	et	3	main
seeni	doc_681992022019_item	2808162	et	3	main
ta	doc_681992022019_item	2808175	et	4	main
mind	doc_681992022019_item	2808178	et	4	main
annab	doc_681992022019_item	2808180	et	3	main
mu	doc_681992022019_item	2808192	et	3	main
tuttaval	doc_681992022019_item	2808194	et	4	main
õnnitlen	doc_681992022019_item	2808199	et	3	main
sünnipäevi	doc_681992022019_item	2808203	et	4	main
suhelda	doc_681992022019_item	2808206	et	4	main
alati	doc_681992022019_item	2808208	et	4	main
tähistan	doc_681992022019_item	2808209	et	3	main
siis	doc_681992022019_item	2808218	et	3	main
sest	doc_681992022019_item	2808222	et	4	main
ei	doc_681992022019_item	2808235	et	4	main
ei	doc_681992022019_item	2808243	et	4	main
palju	doc_681992022019_item	2808247	et	4	main
õppimine	doc_681992022019_item	2808251	et	4	main
koju	doc_681992022016_item	2807767	et	3	main
tal	doc_681992022016_item	2807769	et	3	main
pidevalt	doc_681992022016_item	2807771	et	4	main
ndiyo	doc_681992022016_item	2807775	et	4	main
jumaldab	doc_681992022016_item	2807776	et	3	main
teleka	doc_681992022016_item	2807777	et	3	main
vaatamist	doc_681992022016_item	2807778	et	4	main
talle	doc_681992022016_item	2807779	et	4	main
kardavad	doc_681992022016_item	2807829	et	4	main
kui	doc_681992022016_item	2807830	et	3	main
1	doc_681992022017_item	2807856	et	2	main
tuleb	doc_681992022017_item	2807858	et	3	main
korteri	doc_681992022017_item	2807860	et	3	main
asukoht	doc_681992022017_item	2807862	et	3	main
hind	doc_681992022017_item	2807865	et	3	main
on	doc_681992022017_item	2807885	et	4	main
nii	doc_681992022017_item	2807887	et	3	main
mis	doc_681992022017_item	2807889	et	4	main
on	doc_681992022017_item	2807899	et	4	main
sonja	doc_681992022017_item	2807900	et	4	main
on	doc_681992022017_item	2807904	et	4	main
lõvi	doc_681992022017_item	2807912	et	4	main
ülejaanud	doc_681992022017_item	2807921	et	4	main
selge	doc_681992022017_item	2807925	et	4	main
et	doc_681992022017_item	2807926	et	3	main
inimesed	doc_681992022017_item	2807927	et	3	main
peavad	doc_681992022017_item	2807928	et	4	main
kui	doc_681992022017_item	2807940	et	3	main
liigitamine	doc_681992022017_item	2807942	et	4	main
osutub	doc_681992022017_item	2807943	et	3	main
raskeks	doc_681992022017_item	2807944	et	3	main
miks	doc_681992022017_item	2807956	et	4	main
hakata	doc_681992022017_item	2807962	et	4	main
sest	doc_681992022017_item	2807963	et	4	main
hakata	doc_681992022017_item	2807972	et	4	main
viima	doc_681992022017_item	2807974	et	3	main
mulle	doc_681992022018_item	2808007	et	4	main
ma	doc_681992022018_item	2808023	et	3	main
mulle	doc_681992022018_item	2808045	et	4	main
aitab	doc_681992022018_item	2808046	et	3	main
muidugi	doc_681992022018_item	2808047	et	4	main
ma	doc_681992022018_item	2808048	et	3	main
heal	doc_681992022018_item	2808055	et	3	main
siis	doc_681992022018_item	2808059	et	3	main
tähistan	doc_681992022018_item	2808061	et	3	main
ma	doc_681992022018_item	2808063	et	3	main
et	doc_681992022018_item	2808065	et	3	main
see	doc_681992022018_item	2808070	et	3	main
on	doc_681992022018_item	2808071	et	4	main
mind	doc_681992022018_item	2808089	et	4	main
ma	doc_681992022018_item	2808092	et	3	main
abistan	doc_681992022018_item	2808093	et	3	main
teda	doc_681992022018_item	2808094	et	4	main
ta	doc_681992022016_item	2807831	et	4	main
neid	doc_681992022016_item	2807832	et	4	main
jälitama	doc_681992022016_item	2807833	et	3	main
hakkab	doc_681992022016_item	2807834	et	3	main
on	doc_681992022016_item	2807842	et	4	main
teiste	doc_681992022016_item	2807845	et	4	main
taastutvumiseks	doc_681992022016_item	2807847	et	4	main
parki	doc_681992022016_item	2807853	et	4	main
plussid	doc_681992022017_item	2807868	et	3	main
raha	doc_681992022017_item	2807870	et	4	main
korterit	doc_681992022017_item	2807875	et	3	main
vaatama	doc_681992022017_item	2807876	et	3	main
seal	doc_681992022017_item	2807884	et	4	main
või	doc_681992022017_item	2807892	et	4	main
teeb	doc_681992022017_item	2807896	et	3	main
pargi	doc_681992022017_item	2807905	et	4	main
sattus	doc_681992022017_item	2807911	et	3	main
kui	doc_681992022017_item	2807914	et	3	main
ema	doc_681992022017_item	2807916	et	4	main
nii	doc_681992022017_item	2807917	et	3	main
ka	doc_681992022017_item	2807920	et	3	main
safariparki	doc_681992022017_item	2807935	et	4	main
prügi	doc_681992022017_item	2807939	et	4	main
patareide	doc_681992022017_item	2807941	et	3	main
on	doc_681992022017_item	2807945	et	4	main
ohutum	doc_681992022017_item	2807948	et	4	main
mil	doc_681992022017_item	2807965	et	4	main
ja	doc_681992022017_item	2807970	et	3	main
erinevate	doc_681992022017_item	2807975	et	4	main
vaadata	doc_681992022018_item	2808016	et	4	main
ja	doc_681992022018_item	2808017	et	3	main
minu	doc_681992022018_item	2808018	et	3	main
suhelda	doc_681992022018_item	2808020	et	4	main
pingeline	doc_681992022018_item	2808030	et	4	main
olukord	doc_681992022018_item	2808031	et	3	main
siis	doc_681992022018_item	2808032	et	3	main
ma	doc_681992022018_item	2808033	et	3	main
või	doc_681992022018_item	2808036	et	4	main
sõbrale	doc_681992022018_item	2808037	et	3	main
appi	doc_681992022018_item	2808040	et	4	main
sellepärast	doc_681992022018_item	2808041	et	3	main
minu	doc_681992022018_item	2808042	et	3	main
ema	doc_681992022018_item	2808043	et	4	main
alati	doc_681992022018_item	2808044	et	4	main
ise	doc_681992022018_item	2808050	et	4	main
on	doc_681992022018_item	2808057	et	4	main
ma	doc_681992022018_item	2808060	et	3	main
mulle	doc_681992022018_item	2808066	et	4	main
meeldivad	doc_681992022018_item	2808067	et	4	main
palub	doc_681992022018_item	2808088	et	3	main
siis	doc_681992022018_item	2808091	et	3	main
loen	doc_681992022018_item	2808121	et	3	main
hetki	doc_681992022018_item	2808123	et	4	main
väga	doc_681992022018_item	2808125	et	3	main
harva	doc_681992022018_item	2808126	et	4	main
sellepärast	doc_681992022018_item	2808127	et	3	main
mul	doc_681992022018_item	2808128	et	3	main
midagi	doc_681992022019_item	2808144	et	4	main
ja	doc_681992022019_item	2808157	et	3	main
korjame	doc_681992022019_item	2808159	et	3	main
kuulame	doc_681992022019_item	2808164	et	4	main
vaikust	doc_681992022019_item	2808165	et	4	main
kui	doc_681992022019_item	2808166	et	3	main
siis	doc_681992022019_item	2808171	et	3	main
helistan	doc_681992022019_item	2808173	et	3	main
kuulab	doc_681992022019_item	2808177	et	3	main
nõu	doc_681992022019_item	2808181	et	4	main
tõsta	doc_681992022019_item	2808189	et	4	main
on	doc_681992022019_item	2808195	et	4	main
sünnipäev	doc_681992022019_item	2808196	et	3	main
siis	doc_681992022019_item	2808197	et	3	main
mu	doc_681992022019_item	2808213	et	3	main
mind	doc_681992022019_item	2808216	et	4	main
teda	doc_681992022019_item	2808221	et	4	main
musi	doc_681992022016_item	2807838	et	4	main
anda	doc_681992022016_item	2807839	et	3	main
kui	doc_681992022016_item	2807840	et	3	main
ndiyo	doc_681992022016_item	2807841	et	4	main
vana	doc_681992022016_item	2807844	et	4	main
lõvidega	doc_681992022016_item	2807846	et	3	main
ta	doc_681992022016_item	2807849	et	4	main
tagasi	doc_681992022016_item	2807850	et	3	main
vastus	doc_681992022017_item	2807854	et	3	main
mida	doc_681992022017_item	2807857	et	4	main
miinused	doc_681992022017_item	2807869	et	3	main
võimalused	doc_681992022017_item	2807871	et	3	main
asjatundjaga	doc_681992022017_item	2807879	et	3	main
midagi	doc_681992022017_item	2807886	et	4	main
väga	doc_681992022017_item	2807894	et	3	main
freeman	doc_681992022017_item	2807903	et	4	main
ülemvahil	doc_681992022017_item	2807908	et	3	main
loomaparki	doc_681992022017_item	2807913	et	4	main
tema	doc_681992022017_item	2807915	et	4	main
tema	doc_681992022017_item	2807918	et	4	main
kui	doc_681992022017_item	2807919	et	3	main
pesakonna	doc_681992022017_item	2807922	et	4	main
hülgas	doc_681992022017_item	2807923	et	3	main
ning	doc_681992022017_item	2807932	et	3	main
ta	doc_681992022017_item	2807933	et	4	main
kuidas	doc_681992022017_item	2807937	et	3	main
ja	doc_681992022017_item	2807947	et	3	main
siiski	doc_681992022017_item	2807951	et	4	main
ohtlike	doc_681992022017_item	2807952	et	3	main
jäätmete	doc_681992022017_item	2807953	et	4	main
kogumispunkti	doc_681992022017_item	2807954	et	4	main
1	doc_681992022017_item	2807955	et	2	main
päevast	doc_681992022017_item	2807964	et	4	main
vehiti	doc_681992022017_item	2807969	et	3	main
prügi	doc_681992022017_item	2807973	et	4	main
jaoks	doc_681992022017_item	2807977	et	4	main
välja	doc_681992022017_item	2807978	et	4	main
räägib	doc_681992022017_item	2807981	et	3	main
peremaa	doc_681992022017_item	2807982	et	4	main
essee	doc_681992022018_item	2807983	et	4	main
ma	doc_681992022018_item	2807984	et	3	main
olen	doc_681992022018_item	2807985	et	3	main
alati	doc_681992022018_item	2807986	et	4	main
jooksev	doc_681992022018_item	2807987	et	4	main
ja	doc_681992022018_item	2807988	et	3	main
mõtlik	doc_681992022018_item	2807989	et	3	main
inimene	doc_681992022018_item	2807990	et	3	main
hommikul	doc_681992022018_item	2807991	et	3	main
ma	doc_681992022018_item	2807992	et	3	main
jooksen	doc_681992022018_item	2807993	et	3	main
hariduskeskusse	doc_681992022018_item	2807994	et	4	main
pärast	doc_681992022018_item	2807995	et	4	main
ma	doc_681992022018_item	2807996	et	3	main
jooksen	doc_681992022018_item	2807997	et	3	main
tööle	doc_681992022018_item	2807998	et	3	main
ja	doc_681992022018_item	2807999	et	3	main
alatasa	doc_681992022018_item	2808000	et	3	main
ma	doc_681992022018_item	2808001	et	3	main
mõtlen	doc_681992022018_item	2808002	et	3	main
milleks	doc_681992022018_item	2808003	et	4	main
ma	doc_681992022018_item	2808004	et	3	main
seda	doc_681992022018_item	2808005	et	3	main
teen	doc_681992022018_item	2808006	et	3	main
raamatuid	doc_681992022018_item	2808009	et	3	main
hea	doc_681992022018_item	2808011	et	4	main
kuulata	doc_681992022018_item	2808013	et	4	main
hea	doc_681992022018_item	2808014	et	4	main
pojaga	doc_681992022018_item	2808019	et	4	main
kõike	doc_681992022018_item	2808022	et	4	main
kahjuks	doc_681992022018_item	2808024	et	4	main
mul	doc_681992022018_item	2808028	et	3	main
on	doc_681992022018_item	2808029	et	4	main
proovin	doc_681992022018_item	2808049	et	3	main
kui	doc_681992022018_item	2808053	et	3	main
on	doc_681992022018_item	2808075	et	4	main
tuju	doc_681992022018_item	2808077	et	4	main
ma	doc_681992022018_item	2808078	et	3	main
tähistan	doc_681992022018_item	2808079	et	3	main
mitte	doc_681992022018_item	2808080	et	3	main
eriti	doc_681992022018_item	2808081	et	3	main
tihti	doc_681992022018_item	2808082	et	3	main
sõpradega	doc_681992022018_item	2808083	et	3	main
kui	doc_681992022018_item	2808085	et	3	main
mu	doc_681992022018_item	2808086	et	3	main
appi	doc_681992022018_item	2808097	et	4	main
sellepärast	doc_681992022018_item	2808098	et	3	main
see	doc_681992022018_item	2808099	et	3	main
on	doc_681992022018_item	2808100	et	4	main
vaja	doc_681992022018_item	2808101	et	4	main
selliseid	doc_681992022018_item	2808102	et	4	main
olukordi	doc_681992022018_item	2808103	et	4	main
juhtub	doc_681992022018_item	2808104	et	3	main
harva	doc_681992022018_item	2808105	et	4	main
kui	doc_681992022018_item	2808106	et	3	main
mul	doc_681992022018_item	2808107	et	3	main
ei	doc_681992022018_item	2808108	et	4	main
ole	doc_681992022018_item	2808109	et	4	main
mingeid	doc_681992022018_item	2808110	et	3	main
kohustusi	doc_681992022018_item	2808111	et	4	main
siis	doc_681992022018_item	2808112	et	3	main
ma	doc_681992022018_item	2808113	et	3	main
puhkan	doc_681992022018_item	2808114	et	3	main
ma	doc_681992022018_item	2808115	et	3	main
jalutan	doc_681992022018_item	2808116	et	3	main
metsas	doc_681992022018_item	2808117	et	3	main
või	doc_681992022018_item	2808118	et	4	main
mere	doc_681992022018_item	2808119	et	3	main
ääres	doc_681992022018_item	2808120	et	4	main
selliseid	doc_681992022018_item	2808122	et	4	main
on	doc_681992022018_item	2808124	et	4	main
essee	doc_681992022019_item	2808132	et	4	main
ma	doc_681992022019_item	2808133	et	3	main
olen	doc_681992022019_item	2808134	et	3	main
abivalmis	doc_681992022019_item	2808135	et	3	main
inimene	doc_681992022019_item	2808136	et	3	main
tuttavatele	doc_681992022019_item	2808137	et	3	main
tulen	doc_681992022019_item	2808138	et	3	main
alati	doc_681992022019_item	2808139	et	4	main
jaoks	doc_681992022019_item	2808146	et	4	main
meeldib	doc_681992022019_item	2808149	et	3	main
sügisel	doc_681992022019_item	2808158	et	3	main
olukord	doc_681992022019_item	2808170	et	3	main
sõbrannale	doc_681992022019_item	2808174	et	3	main
mind	doc_681992022019_item	2808182	et	4	main
ma	doc_681992022019_item	2808201	et	3	main
sünnipäevi	doc_681992022019_item	2808210	et	4	main
sõpradega	doc_681992022019_item	2808211	et	3	main
asja	doc_681992022018_item	2808051	et	4	main
mu	doc_681992022018_item	2808054	et	3	main
sünnipäevad	doc_681992022018_item	2808068	et	3	main
pidupäev	doc_681992022018_item	2808072	et	3	main
ma	doc_681992022018_item	2808095	et	3	main
on	doc_681992022018_item	2808129	et	4	main
appi	doc_681992022019_item	2808140	et	4	main
kui	doc_681992022019_item	2808141	et	3	main
olen	doc_681992022019_item	2808142	et	3	main
võimeline	doc_681992022019_item	2808143	et	4	main
talvel	doc_681992022019_item	2808163	et	4	main
mul	doc_681992022019_item	2808167	et	3	main
on	doc_681992022019_item	2808168	et	4	main
ma	doc_681992022019_item	2808172	et	3	main
alati	doc_681992022019_item	2808176	et	4	main
ja	doc_681992022019_item	2808179	et	3	main
positiivsus	doc_681992022019_item	2808185	et	4	main
tuju	doc_681992022019_item	2808190	et	4	main
teda	doc_681992022019_item	2808200	et	4	main
armastan	doc_681992022019_item	2808202	et	3	main
sest	doc_681992022019_item	2808204	et	4	main
armastan	doc_681992022019_item	2808205	et	3	main
ma	doc_681992022019_item	2808207	et	3	main
appi	doc_681992022019_item	2808217	et	4	main
ei	doc_681992022019_item	2808225	et	4	main
see	doc_681992022019_item	2808227	et	3	main
selliseid	doc_681992022019_item	2808229	et	4	main
olukordi	doc_681992022019_item	2808230	et	4	main
juhtub	doc_681992022019_item	2808231	et	3	main
tihti	doc_681992022019_item	2808232	et	3	main
kui	doc_681992022019_item	2808233	et	3	main
mul	doc_681992022019_item	2808234	et	3	main
hetki	doc_681992022019_item	2808246	et	4	main
palju	doc_681992022019_item	2808253	et	4	main
aega	doc_681992022019_item	2808254	et	4	main
sellepärast	doc_681992022020_item	2808261	et	3	main
meldib	doc_681992022020_item	2808277	et	4	main
käija	doc_681992022020_item	2808280	et	4	main
olukord	doc_681992022020_item	2808297	et	3	main
tavaliselt	doc_681992022020_item	2808303	et	4	main
oma	doc_681992022020_item	2808305	et	4	main
sõbrannale	doc_681992022020_item	2808306	et	3	main
et	doc_681992022020_item	2808307	et	3	main
rääkida	doc_681992022020_item	2808308	et	3	main
temale	doc_681992022020_item	2808309	et	3	main
palju	doc_681992022018_item	2808130	et	4	main
kohustusi	doc_681992022018_item	2808131	et	4	main
teha	doc_681992022019_item	2808147	et	3	main
mulle	doc_681992022019_item	2808148	et	4	main
jalutada	doc_681992022019_item	2808150	et	3	main
me	doc_681992022019_item	2808152	et	4	main
nädalavahetustel	doc_681992022019_item	2808151	et	4	main
käime	doc_681992022019_item	2808153	et	4	main
perega	doc_681992022019_item	2808154	et	3	main
metsas	doc_681992022019_item	2808155	et	3	main
suvel	doc_681992022019_item	2808156	et	3	main
ja	doc_681992022019_item	2808161	et	3	main
pingeline	doc_681992022019_item	2808169	et	4	main
aitab	doc_681992022019_item	2808183	et	3	main
tema	doc_681992022019_item	2808184	et	4	main
ta	doc_681992022019_item	2808186	et	4	main
oskab	doc_681992022019_item	2808187	et	3	main
mulle	doc_681992022019_item	2808188	et	4	main
kui	doc_681992022019_item	2808191	et	3	main
heal	doc_681992022019_item	2808193	et	3	main
ma	doc_681992022019_item	2808198	et	3	main
kui	doc_681992022019_item	2808212	et	3	main
palub	doc_681992022019_item	2808215	et	3	main
aitan	doc_681992022019_item	2808220	et	3	main
jaoks	doc_681992022019_item	2808224	et	4	main
ole	doc_681992022019_item	2808226	et	4	main
mingeid	doc_681992022019_item	2808237	et	3	main
ole	doc_681992022019_item	2808244	et	4	main
sest	doc_681992022019_item	2808248	et	4	main
pere	doc_681992022019_item	2808249	et	4	main
ja	doc_681992022019_item	2808250	et	3	main
essee	doc_681992022020_item	2808255	et	4	main
ma	doc_681992022020_item	2808256	et	3	main
olen	doc_681992022020_item	2808257	et	3	main
koos	doc_681992022020_item	2808283	et	4	main
ma	doc_681992022020_item	2808299	et	3	main
heal	doc_681992022020_item	2808342	et	3	main
on	doc_681992022020_item	2808344	et	4	main
ma	doc_681992022020_item	2808347	et	3	main
kui	doc_681992022020_item	2808353	et	3	main
mina	doc_681992022020_item	2808354	et	4	main
käin	doc_681992022020_item	2808355	et	3	main
sünnipäevadel	doc_681992022020_item	2808356	et	3	main
siis	doc_681992022020_item	2808357	et	3	main
tulevad	doc_681992022020_item	2808375	et	4	main
minu	doc_681992022020_item	2808376	et	3	main
peast	doc_681992022020_item	2808385	et	4	main
vaid	doc_681992022020_item	2808386	et	3	main
oma	doc_681992022020_item	2808391	et	4	main
ikka	doc_681992022020_item	2808395	et	4	main
tähistan	doc_681992022020_item	2808396	et	3	main
kui	doc_681992022020_item	2808397	et	3	main
mu	doc_681992022020_item	2808398	et	3	main
sõber	doc_681992022020_item	2808399	et	3	main
palub	doc_681992022020_item	2808400	et	3	main
mind	doc_681992022020_item	2808401	et	4	main
olen	doc_681992022020_item	2808406	et	3	main
aitama	doc_681992022020_item	2808413	et	3	main
juhtub	doc_681992022020_item	2808415	et	3	main
harva	doc_681992022020_item	2808417	et	4	main
mul	doc_681992022020_item	2808419	et	3	main
siis	doc_681992022020_item	2808424	et	3	main
lihtsalt	doc_681992022020_item	2808426	et	4	main
oma	doc_681992022020_item	2808435	et	4	main
tavaliselt	doc_681992022020_item	2808437	et	4	main
korraldame	doc_681992022020_item	2808438	et	3	main
kui	doc_681992022021_item	2808458	et	3	main
vaja	doc_681992022021_item	2808460	et	4	main
raamatud	doc_681992022021_item	2808469	et	4	main
ma	doc_681992022021_item	2808495	et	3	main
sünnipäev	doc_681992022021_item	2808510	et	3	main
palub	doc_681992022021_item	2808524	et	3	main
aitan	doc_681992022021_item	2808529	et	3	main
sest	doc_681992022021_item	2808531	et	4	main
ei	doc_681992022021_item	2808538	et	4	main
sest	doc_681992022021_item	2808559	et	4	main
mul	doc_681992022021_item	2808560	et	3	main
alati	doc_681992022022_item	2808568	et	4	main
sõbralik	doc_681992022022_item	2808569	et	3	main
inimene	doc_681992022022_item	2808570	et	3	main
juhtub	doc_681992022022_item	2808621	et	3	main
kui	doc_681992022022_item	2808625	et	3	main
tihti	doc_681992022022_item	2808646	et	3	main
ei	doc_681992022022_item	2808660	et	4	main
ma	doc_681992022023_item	2808667	et	3	main
alati	doc_681992022023_item	2808669	et	4	main
mulle	doc_681992022023_item	2808690	et	4	main
ma	doc_681992022023_item	2808706	et	3	main
ja	doc_681992022023_item	2808710	et	3	main
sõbradega	doc_681992022023_item	2808713	et	4	main
ma	doc_681992022023_item	2808715	et	3	main
teen	doc_681992022023_item	2808716	et	3	main
seda	doc_681992022023_item	2808717	et	3	main
sellepärast	doc_681992022023_item	2808718	et	3	main
sõber	doc_681992022019_item	2808214	et	3	main
ma	doc_681992022019_item	2808219	et	3	main
selliseid	doc_681992022019_item	2808245	et	4	main
võttavad	doc_681992022019_item	2808252	et	4	main
lahke	doc_681992022020_item	2808259	et	4	main
mulle	doc_681992022020_item	2808263	et	4	main
olen	doc_681992022020_item	2808266	et	3	main
õues	doc_681992022020_item	2808278	et	4	main
iga	doc_681992022020_item	2808281	et	4	main
õhtu	doc_681992022020_item	2808282	et	4	main
parandada	doc_681992022020_item	2808288	et	3	main
ja	doc_681992022020_item	2808289	et	3	main
natuke	doc_681992022020_item	2808290	et	4	main
alla	doc_681992022020_item	2808291	et	3	main
võtta	doc_681992022020_item	2808292	et	3	main
kui	doc_681992022020_item	2808293	et	3	main
mul	doc_681992022020_item	2808294	et	3	main
on	doc_681992022020_item	2808295	et	4	main
ja	doc_681992022020_item	2808301	et	3	main
oma	doc_681992022020_item	2808310	et	4	main
aita	doc_681992022020_item	2808329	et	4	main
kui	doc_681992022020_item	2808330	et	3	main
mind	doc_681992022020_item	2808331	et	4	main
süüdistatakse	doc_681992022020_item	2808332	et	3	main
vaid	doc_681992022020_item	2808333	et	3	main
aitab	doc_681992022020_item	2808334	et	3	main
see	doc_681992022020_item	2808335	et	3	main
kui	doc_681992022020_item	2808336	et	3	main
antakse	doc_681992022020_item	2808337	et	3	main
häid	doc_681992022020_item	2808338	et	3	main
kui	doc_681992022020_item	2808340	et	3	main
kingituse	doc_681992022020_item	2808351	et	4	main
talle	doc_681992022020_item	2808352	et	4	main
sest	doc_681992022020_item	2808378	et	4	main
ei	doc_681992022020_item	2808381	et	4	main
külalistest	doc_681992022020_item	2808389	et	4	main
hoolitseda	doc_681992022020_item	2808390	et	3	main
kord	doc_681992022020_item	2808393	et	4	main
appi	doc_681992022020_item	2808402	et	4	main
siis	doc_681992022020_item	2808403	et	3	main
sõpradele	doc_681992022020_item	2808410	et	3	main
aga	doc_681992022020_item	2808416	et	3	main
mingeid	doc_681992022020_item	2808422	et	3	main
veedan	doc_681992022020_item	2808429	et	3	main
sõpradega	doc_681992022020_item	2808431	et	3	main
vaid	doc_681992022020_item	2808432	et	3	main
eelistan	doc_681992022020_item	2808434	et	3	main
perekonda	doc_681992022020_item	2808436	et	4	main
ma	doc_681992022020_item	2808446	et	3	main
õpin	doc_681992022020_item	2808447	et	3	main
väljas	doc_681992022020_item	2808449	et	4	main
ma	doc_681992022021_item	2808451	et	3	main
olen	doc_681992022021_item	2808452	et	3	main
alati	doc_681992022021_item	2808453	et	4	main
abi	doc_681992022021_item	2808462	et	4	main
ma	doc_681992022021_item	2808464	et	3	main
sügav	doc_681992022021_item	2808504	et	4	main
kui	doc_681992022021_item	2808505	et	3	main
mul	doc_681992022021_item	2808506	et	3	main
tuttaval	doc_681992022021_item	2808508	et	4	main
seda	doc_681992022021_item	2808514	et	3	main
mind	doc_681992022021_item	2808525	et	4	main
neid	doc_681992022021_item	2808537	et	4	main
ole	doc_681992022021_item	2808544	et	4	main
siis	doc_681992022021_item	2808547	et	3	main
ma	doc_681992022021_item	2808548	et	3	main
puhkan	doc_681992022021_item	2808549	et	3	main
kodus	doc_681992022021_item	2808550	et	4	main
selliseid	doc_681992022021_item	2808554	et	4	main
ole	doc_681992022021_item	2808557	et	4	main
palju	doc_681992022021_item	2808558	et	4	main
essee	doc_681992022022_item	2808565	et	4	main
ma	doc_681992022022_item	2808566	et	3	main
olen	doc_681992022022_item	2808567	et	3	main
ma	doc_681992022022_item	2808574	et	3	main
mis	doc_681992022022_item	2808583	et	4	main
tahan	doc_681992022022_item	2808584	et	3	main
ole	doc_681992022022_item	2808623	et	4	main
ma	doc_681992022022_item	2808632	et	3	main
mul	doc_681992022022_item	2808648	et	3	main
hetki	doc_681992022022_item	2808659	et	4	main
praegu	doc_681992022022_item	2808663	et	3	main
õpin	doc_681992022022_item	2808665	et	3	main
minu	doc_681992022019_item	2808223	et	3	main
raske	doc_681992022019_item	2808228	et	4	main
ole	doc_681992022019_item	2808236	et	4	main
kohustusi	doc_681992022019_item	2808238	et	4	main
siis	doc_681992022019_item	2808239	et	3	main
ma	doc_681992022019_item	2808240	et	3	main
loen	doc_681992022019_item	2808241	et	3	main
kahjuks	doc_681992022019_item	2808242	et	4	main
inimene	doc_681992022020_item	2808260	et	3	main
meeldivad	doc_681992022020_item	2808264	et	4	main
inimesed	doc_681992022020_item	2808265	et	3	main
sõbranaga	doc_681992022020_item	2808284	et	4	main
et	doc_681992022020_item	2808285	et	3	main
pingeline	doc_681992022020_item	2808296	et	4	main
närvitsen	doc_681992022020_item	2808300	et	3	main
muredest	doc_681992022020_item	2808311	et	3	main
siis	doc_681992022020_item	2808312	et	3	main
tundub	doc_681992022020_item	2808313	et	3	main
mulle	doc_681992022020_item	2808314	et	4	main
et	doc_681992022020_item	2808315	et	3	main
süda	doc_681992022020_item	2808316	et	3	main
muutub	doc_681992022020_item	2808317	et	3	main
rahulikuks	doc_681992022020_item	2808318	et	3	main
sest	doc_681992022020_item	2808319	et	4	main
ma	doc_681992022020_item	2808320	et	3	main
ei	doc_681992022020_item	2808321	et	4	main
seda	doc_681992022020_item	2808323	et	3	main
elama	doc_681992022020_item	2808326	et	3	main
mind	doc_681992022020_item	2808327	et	4	main
siis	doc_681992022020_item	2808346	et	3	main
ette	doc_681992022020_item	2808349	et	4	main
hea	doc_681992022020_item	2808350	et	4	main
ma	doc_681992022020_item	2808404	et	3	main
peab	doc_681992022020_item	2808411	et	4	main
kui	doc_681992022020_item	2808418	et	3	main
ei	doc_681992022020_item	2808420	et	4	main
puhkan	doc_681992022020_item	2808427	et	3	main
pigem	doc_681992022020_item	2808433	et	3	main
üüritused	doc_681992022020_item	2808440	et	4	main
selliseid	doc_681992022020_item	2808441	et	4	main
hetki	doc_681992022020_item	2808442	et	4	main
vähe	doc_681992022020_item	2808445	et	3	main
linnast	doc_681992022020_item	2808448	et	4	main
essee	doc_681992022021_item	2808450	et	4	main
on	doc_681992022021_item	2808459	et	4	main
minu	doc_681992022021_item	2808461	et	3	main
siis	doc_681992022021_item	2808463	et	3	main
lugeda	doc_681992022021_item	2808468	et	3	main
rahu	doc_681992022021_item	2808497	et	4	main
joon	doc_681992022021_item	2808499	et	4	main
ma	doc_681992022021_item	2808512	et	3	main
jah	doc_681992022021_item	2808515	et	3	main
meeldivad	doc_681992022021_item	2808517	et	4	main
tihti	doc_681992022021_item	2808520	et	3	main
kui	doc_681992022021_item	2808521	et	3	main
ei	doc_681992022021_item	2808536	et	4	main
juhtu	doc_681992022021_item	2808539	et	4	main
mul	doc_681992022021_item	2808542	et	3	main
oma	doc_681992022021_item	2808552	et	4	main
on	doc_681992022021_item	2808561	et	4	main
see	doc_681992022022_item	2808571	et	3	main
ei	doc_681992022022_item	2808622	et	4	main
tihti	doc_681992022022_item	2808624	et	3	main
mind	doc_681992022022_item	2808629	et	4	main
appi	doc_681992022022_item	2808630	et	4	main
siis	doc_681992022022_item	2808631	et	3	main
kuulan	doc_681992022022_item	2808633	et	3	main
sõbrame	doc_681992022022_item	2808642	et	4	main
mitte	doc_681992022022_item	2808645	et	3	main
kui	doc_681992022022_item	2808647	et	3	main
selliseid	doc_681992022022_item	2808658	et	4	main
tihti	doc_681992022022_item	2808662	et	3	main
alati	doc_681992022020_item	2808258	et	4	main
et	doc_681992022020_item	2808262	et	3	main
alati	doc_681992022020_item	2808267	et	4	main
nende	doc_681992022020_item	2808268	et	4	main
vastu	doc_681992022020_item	2808269	et	3	main
sõbralik	doc_681992022020_item	2808270	et	3	main
ja	doc_681992022020_item	2808271	et	3	main
heatahtlik	doc_681992022020_item	2808272	et	3	main
mulle	doc_681992022020_item	2808273	et	4	main
meeldib	doc_681992022020_item	2808274	et	3	main
spordiga	doc_681992022020_item	2808275	et	3	main
tegeleda	doc_681992022020_item	2808276	et	3	main
jala	doc_681992022020_item	2808279	et	4	main
oma	doc_681992022020_item	2808286	et	4	main
tervist	doc_681992022020_item	2808287	et	4	main
siis	doc_681992022020_item	2808298	et	3	main
pabistan	doc_681992022020_item	2808302	et	3	main
helistan	doc_681992022020_item	2808304	et	3	main
ei	doc_681992022020_item	2808328	et	4	main
mu	doc_681992022020_item	2808341	et	3	main
tuttaval	doc_681992022020_item	2808343	et	4	main
sünnipäev	doc_681992022020_item	2808345	et	3	main
valmistan	doc_681992022020_item	2808348	et	3	main
külalised	doc_681992022020_item	2808374	et	4	main
nüüd	doc_681992022020_item	2808379	et	4	main
saa	doc_681992022020_item	2808382	et	4	main
rahulikult	doc_681992022020_item	2808383	et	4	main
nautida	doc_681992022020_item	2808384	et	3	main
pean	doc_681992022020_item	2808388	et	4	main
aastas	doc_681992022020_item	2808394	et	3	main
alati	doc_681992022020_item	2808405	et	4	main
leian	doc_681992022020_item	2808408	et	3	main
alati	doc_681992022020_item	2808412	et	4	main
pea	doc_681992022020_item	2808322	et	4	main
üksi	doc_681992022020_item	2808324	et	4	main
üle	doc_681992022020_item	2808325	et	3	main
nõuandeid	doc_681992022020_item	2808339	et	3	main
see	doc_681992022020_item	2808358	et	3	main
mulle	doc_681992022020_item	2808359	et	4	main
meeldib	doc_681992022020_item	2808360	et	3	main
et	doc_681992022020_item	2808361	et	3	main
ma	doc_681992022020_item	2808362	et	3	main
olen	doc_681992022020_item	2808363	et	3	main
seal	doc_681992022020_item	2808364	et	4	main
külas	doc_681992022020_item	2808365	et	3	main
ja	doc_681992022020_item	2808366	et	3	main
minu	doc_681992022020_item	2808367	et	3	main
eest	doc_681992022020_item	2808368	et	4	main
hoolitsetakse	doc_681992022020_item	2808369	et	3	main
ei	doc_681992022020_item	2808370	et	4	main
meeldi	doc_681992022020_item	2808371	et	4	main
mulle	doc_681992022020_item	2808372	et	4	main
kui	doc_681992022020_item	2808373	et	3	main
juurde	doc_681992022020_item	2808377	et	4	main
mina	doc_681992022020_item	2808380	et	4	main
ise	doc_681992022020_item	2808387	et	4	main
sünipäeva	doc_681992022020_item	2808392	et	4	main
abivalmis	doc_681992022020_item	2808407	et	3	main
et	doc_681992022020_item	2808409	et	3	main
mõnikord	doc_681992022020_item	2808414	et	3	main
ole	doc_681992022020_item	2808421	et	4	main
kohustusi	doc_681992022020_item	2808423	et	4	main
ma	doc_681992022020_item	2808425	et	3	main
peresisselised	doc_681992022020_item	2808439	et	4	main
on	doc_681992022020_item	2808443	et	4	main
lahke	doc_681992022021_item	2808454	et	4	main
inimene	doc_681992022021_item	2808455	et	3	main
see	doc_681992022021_item	2808456	et	3	main
aitan	doc_681992022021_item	2808465	et	3	main
säilitan	doc_681992022021_item	2808496	et	3	main
heal	doc_681992022021_item	2808507	et	3	main
õnnitlen	doc_681992022021_item	2808513	et	3	main
mõnikord	doc_681992022020_item	2808428	et	3	main
aega	doc_681992022020_item	2808430	et	4	main
väga	doc_681992022020_item	2808444	et	3	main
tähendab	doc_681992022021_item	2808457	et	3	main
mulle	doc_681992022021_item	2808466	et	4	main
meeldib	doc_681992022021_item	2808467	et	3	main
ja	doc_681992022021_item	2808470	et	3	main
tegelema	doc_681992022021_item	2808471	et	3	main
floristika	doc_681992022021_item	2808472	et	4	main
ei	doc_681992022021_item	2808473	et	4	main
tihti	doc_681992022021_item	2808474	et	3	main
kui	doc_681992022021_item	2808475	et	3	main
mul	doc_681992022021_item	2808476	et	3	main
on	doc_681992022021_item	2808477	et	4	main
aega	doc_681992022021_item	2808478	et	4	main
sest	doc_681992022021_item	2808479	et	4	main
raamatud	doc_681992022021_item	2808480	et	4	main
teevad	doc_681992022021_item	2808481	et	3	main
targas	doc_681992022021_item	2808482	et	3	main
ja	doc_681992022021_item	2808483	et	3	main
floristika	doc_681992022021_item	2808484	et	4	main
andma	doc_681992022021_item	2808485	et	3	main
mulle	doc_681992022021_item	2808486	et	4	main
hea	doc_681992022021_item	2808487	et	4	main
tuju	doc_681992022021_item	2808488	et	4	main
kui	doc_681992022021_item	2808489	et	3	main
mul	doc_681992022021_item	2808490	et	3	main
on	doc_681992022021_item	2808491	et	4	main
pingeline	doc_681992022021_item	2808492	et	4	main
olukord	doc_681992022021_item	2808493	et	3	main
siis	doc_681992022021_item	2808494	et	3	main
ma	doc_681992022021_item	2808498	et	3	main
klaasivese	doc_681992022021_item	2808500	et	4	main
vett	doc_681992022021_item	2808501	et	3	main
ja	doc_681992022021_item	2808502	et	3	main
hingen	doc_681992022021_item	2808503	et	4	main
on	doc_681992022021_item	2808509	et	4	main
siis	doc_681992022021_item	2808511	et	3	main
mulle	doc_681992022021_item	2808516	et	4	main
sünnipäevad	doc_681992022021_item	2808518	et	3	main
ei	doc_681992022021_item	2808519	et	4	main
sõber	doc_681992022021_item	2808523	et	3	main
appi	doc_681992022021_item	2808526	et	4	main
ma	doc_681992022021_item	2808528	et	3	main
seda	doc_681992022021_item	2808530	et	3	main
ta	doc_681992022021_item	2808532	et	4	main
on	doc_681992022021_item	2808533	et	4	main
mu	doc_681992022021_item	2808534	et	3	main
sõber	doc_681992022021_item	2808535	et	3	main
kui	doc_681992022021_item	2808541	et	3	main
koos	doc_681992022021_item	2808551	et	4	main
perega	doc_681992022021_item	2808553	et	3	main
ie	doc_681992022021_item	2808556	et	4	main
vähe	doc_681992022021_item	2808562	et	3	main
vaba	doc_681992022021_item	2808563	et	4	main
aega	doc_681992022021_item	2808564	et	4	main
tähendab	doc_681992022022_item	2808572	et	3	main
oma	doc_681992022022_item	2808575	et	4	main
mulle	doc_681992022022_item	2808578	et	4	main
õpida	doc_681992022022_item	2808579	et	4	main
meeldib	doc_681992022022_item	2808580	et	3	main
ma	doc_681992022022_item	2808581	et	3	main
parandama	doc_681992022022_item	2808582	et	3	main
mu	doc_681992022021_item	2808522	et	3	main
siis	doc_681992022021_item	2808527	et	3	main
tihti	doc_681992022021_item	2808540	et	3	main
ei	doc_681992022021_item	2808543	et	4	main
mingeid	doc_681992022021_item	2808545	et	3	main
kohustusi	doc_681992022021_item	2808546	et	4	main
hetki	doc_681992022021_item	2808555	et	4	main
et	doc_681992022022_item	2808573	et	3	main
sõpra	doc_681992022022_item	2808576	et	4	main
armastan	doc_681992022022_item	2808577	et	3	main
asja	doc_681992022022_item	2808585	et	4	main
õpin	doc_681992022022_item	2808586	et	3	main
kui	doc_681992022022_item	2808587	et	3	main
mul	doc_681992022022_item	2808588	et	3	main
on	doc_681992022022_item	2808589	et	4	main
pingeline	doc_681992022022_item	2808590	et	4	main
olukord	doc_681992022022_item	2808591	et	3	main
siis	doc_681992022022_item	2808592	et	3	main
ma	doc_681992022022_item	2808593	et	3	main
räägin	doc_681992022022_item	2808594	et	3	main
sõbrale	doc_681992022022_item	2808595	et	3	main
mulle	doc_681992022022_item	2808596	et	4	main
aitan	doc_681992022022_item	2808597	et	3	main
nõuanne	doc_681992022022_item	2808598	et	4	main
kui	doc_681992022022_item	2808599	et	3	main
mu	doc_681992022022_item	2808600	et	3	main
heal	doc_681992022022_item	2808601	et	3	main
tuttaval	doc_681992022022_item	2808602	et	4	main
sünnipäev	doc_681992022022_item	2808604	et	3	main
siis	doc_681992022022_item	2808605	et	3	main
on	doc_681992022022_item	2808603	et	4	main
ma	doc_681992022022_item	2808606	et	3	main
lähen	doc_681992022022_item	2808607	et	3	main
talle	doc_681992022022_item	2808608	et	4	main
pärast	doc_681992022022_item	2808609	et	4	main
tööd	doc_681992022022_item	2808610	et	4	main
külla	doc_681992022022_item	2808611	et	4	main
mulle	doc_681992022022_item	2808612	et	4	main
meeldib	doc_681992022022_item	2808613	et	3	main
sünnipäevad	doc_681992022022_item	2808614	et	3	main
need	doc_681992022022_item	2808615	et	3	main
on	doc_681992022022_item	2808616	et	4	main
väga	doc_681992022022_item	2808617	et	3	main
toredad	doc_681992022022_item	2808618	et	3	main
selliseid	doc_681992022022_item	2808619	et	4	main
olukordi	doc_681992022022_item	2808620	et	4	main
sõber	doc_681992022022_item	2808627	et	3	main
ta	doc_681992022022_item	2808634	et	4	main
ära	doc_681992022022_item	2808635	et	4	main
ja	doc_681992022022_item	2808636	et	3	main
püüan	doc_681992022022_item	2808637	et	3	main
selliseid	doc_681992022022_item	2808643	et	4	main
juhtub	doc_681992022022_item	2808644	et	3	main
ei	doc_681992022022_item	2808649	et	4	main
mingeid	doc_681992022022_item	2808651	et	3	main
välja	doc_681992022022_item	2808656	et	4	main
jalutama	doc_681992022022_item	2808657	et	3	main
ole	doc_681992022022_item	2808661	et	4	main
olen	doc_681992022023_item	2808668	et	3	main
sõbralik	doc_681992022023_item	2808670	et	3	main
ja	doc_681992022023_item	2808671	et	3	main
hea	doc_681992022023_item	2808672	et	4	main
inimene	doc_681992022023_item	2808673	et	3	main
kui	doc_681992022023_item	2808674	et	3	main
ma	doc_681992022023_item	2808675	et	3	main
olen	doc_681992022023_item	2808676	et	3	main
uues	doc_681992022023_item	2808677	et	3	main
ühiskonnas	doc_681992022023_item	2808678	et	4	main
siis	doc_681992022023_item	2808679	et	3	main
ma	doc_681992022023_item	2808680	et	3	main
lõbustan	doc_681992022023_item	2808681	et	3	main
ja	doc_681992022023_item	2808682	et	3	main
suhtlen	doc_681992022023_item	2808683	et	3	main
teisega	doc_681992022023_item	2808684	et	4	main
mulle	doc_681992022023_item	2808685	et	4	main
meeldib	doc_681992022023_item	2808686	et	3	main
suhelda	doc_681992022023_item	2808687	et	4	main
inimesega	doc_681992022023_item	2808689	et	3	main
hea	doc_681992022023_item	2808688	et	4	main
mu	doc_681992022022_item	2808626	et	3	main
palub	doc_681992022022_item	2808628	et	3	main
aidata	doc_681992022022_item	2808638	et	4	main
sellepärast	doc_681992022022_item	2808639	et	3	main
et	doc_681992022022_item	2808640	et	3	main
me	doc_681992022022_item	2808641	et	4	main
ole	doc_681992022022_item	2808650	et	4	main
kohustusi	doc_681992022022_item	2808652	et	4	main
siis	doc_681992022022_item	2808653	et	3	main
ma	doc_681992022022_item	2808654	et	3	main
lähen	doc_681992022022_item	2808655	et	3	main
ma	doc_681992022022_item	2808664	et	3	main
kuulata	doc_681992022023_item	2808692	et	4	main
muusikat	doc_681992022023_item	2808693	et	3	main
kuulan	doc_681992022023_item	2808695	et	3	main
muusikat	doc_681992022023_item	2808708	et	3	main
hoidma	doc_681992022023_item	2808735	et	3	main
olukord	doc_681992022023_item	2808738	et	3	main
sõbranna	doc_681992022023_item	2808750	et	4	main
mis	doc_681992022023_item	2808754	et	4	main
see	doc_681992022023_item	2808756	et	3	main
talle	doc_681992022023_item	2808768	et	4	main
õnne	doc_681992022023_item	2808772	et	4	main
lõbus	doc_681992022023_item	2808782	et	4	main
ja	doc_681992022023_item	2808783	et	3	main
seal	doc_681992022023_item	2808784	et	4	main
tähistan	doc_681992022023_item	2808788	et	3	main
sõpradega	doc_681992022023_item	2808789	et	3	main
mind	doc_681992022023_item	2808798	et	4	main
appi	doc_681992022023_item	2808799	et	4	main
proovin	doc_681992022023_item	2808802	et	3	main
ole	doc_681992022023_item	2808822	et	4	main
või	doc_681992022023_item	2808835	et	4	main
kuulan	doc_681992022023_item	2808836	et	3	main
suhtlen	doc_681992022023_item	2808841	et	3	main
nime	doc_681992022024_item	2808858	et	4	main
on	doc_681992022024_item	2808859	et	4	main
ma	doc_681992022024_item	2808861	et	3	main
olen	doc_681992022024_item	2808862	et	3	main
sündinud	doc_681992022024_item	2808863	et	4	main
ma	doc_681992022024_item	2808870	et	3	main
mul	doc_681992022024_item	2808873	et	3	main
arvan	doc_681992022024_item	2808921	et	3	main
kohtla-järvel	doc_681992022025_item	2808937	et	4	main
mina	doc_681992022025_item	2808938	et	4	main
olen	doc_681992022025_item	2808939	et	3	main
poja	doc_681992022025_item	2808949	et	4	main
talle	doc_681992022025_item	2808959	et	4	main
meeldib	doc_681992022025_item	2808961	et	3	main
ma	doc_681992022025_item	2808970	et	3	main
korterit	doc_681992022025_item	2808973	et	3	main
emaga	doc_681992022025_item	2808988	et	3	main
meie	doc_681992022025_item	2808991	et	4	main
minu	doc_681992022025_item	2808993	et	3	main
vanem	doc_681992022025_item	2808994	et	4	main
sportliga	doc_681992022025_item	2809002	et	4	main
juba	doc_681992022025_item	2809003	et	3	main
aastat	doc_681992022025_item	2809005	et	3	main
mõnikord	doc_681992022025_item	2809026	et	3	main
või	doc_681992022025_item	2809031	et	4	main
ajalehte	doc_681992022025_item	2809032	et	4	main
meeldib	doc_681992022025_item	2809038	et	3	main
mul	doc_681992022025_item	2809041	et	3	main
inimistega	doc_681992022025_item	2809075	et	3	main
üks	doc_681992022025_item	2809079	et	3	main
ma	doc_681992022025_item	2809081	et	3	main
alati	doc_681992022026_item	2809091	et	4	main
inimene	doc_681992022026_item	2809095	et	3	main
aidatan	doc_681992022026_item	2809097	et	4	main
treeningume	doc_681992022026_item	2809113	et	4	main
trenni	doc_681992022026_item	2809121	et	4	main
on	doc_681992022026_item	2809130	et	4	main
olukord	doc_681992022026_item	2809132	et	3	main
istun	doc_681992022026_item	2809135	et	3	main
on	doc_681992022026_item	2809148	et	4	main
lähen	doc_681992022026_item	2809152	et	3	main
ja	doc_681992022026_item	2809154	et	3	main
kingituse	doc_681992022026_item	2809156	et	4	main
mulle	doc_681992022026_item	2809157	et	4	main
väga	doc_681992022026_item	2809158	et	3	main
ja	doc_681992022026_item	2809166	et	3	main
väga	doc_681992022026_item	2809168	et	3	main
essee	doc_681992022023_item	2808666	et	4	main
kodus	doc_681992022023_item	2808703	et	4	main
aga	doc_681992022023_item	2808704	et	3	main
puhkepäeval	doc_681992022023_item	2808705	et	3	main
kuulan	doc_681992022023_item	2808707	et	3	main
baarides	doc_681992022023_item	2808711	et	3	main
meeldib	doc_681992022023_item	2808721	et	3	main
kui	doc_681992022023_item	2808724	et	3	main
on	doc_681992022023_item	2808726	et	4	main
siis	doc_681992022023_item	2808729	et	3	main
ma	doc_681992022023_item	2808730	et	3	main
proovin	doc_681992022023_item	2808731	et	3	main
siis	doc_681992022023_item	2808739	et	3	main
tuttaval	doc_681992022023_item	2808762	et	4	main
soovin	doc_681992022023_item	2808770	et	3	main
väga	doc_681992022023_item	2808781	et	3	main
kahjuks	doc_681992022023_item	2808787	et	4	main
meeldib	doc_681992022023_item	2808691	et	3	main
ma	doc_681992022023_item	2808694	et	3	main
muusikat	doc_681992022023_item	2808696	et	3	main
iga	doc_681992022023_item	2808697	et	4	main
päev	doc_681992022023_item	2808698	et	3	main
tihti	doc_681992022023_item	2808699	et	3	main
ma	doc_681992022023_item	2808700	et	3	main
teen	doc_681992022023_item	2808701	et	3	main
seda	doc_681992022023_item	2808702	et	3	main
klubides	doc_681992022023_item	2808709	et	3	main
minu	doc_681992022023_item	2808712	et	3	main
seda	doc_681992022023_item	2808723	et	3	main
mul	doc_681992022023_item	2808725	et	3	main
pingeline	doc_681992022023_item	2808727	et	4	main
olukord	doc_681992022023_item	2808728	et	3	main
all	doc_681992022023_item	2808734	et	3	main
seda	doc_681992022023_item	2808737	et	3	main
ma	doc_681992022023_item	2808740	et	3	main
vahel	doc_681992022023_item	2808746	et	4	main
ma	doc_681992022023_item	2808747	et	3	main
helistan	doc_681992022023_item	2808748	et	3	main
mu	doc_681992022023_item	2808749	et	3	main
on	doc_681992022023_item	2808763	et	4	main
mulle	doc_681992022023_item	2808773	et	4	main
väga	doc_681992022023_item	2808774	et	3	main
meeldivad	doc_681992022023_item	2808775	et	4	main
sünnipäevad	doc_681992022023_item	2808776	et	3	main
sellepärast	doc_681992022023_item	2808777	et	3	main
et	doc_681992022023_item	2808778	et	3	main
palju	doc_681992022023_item	2808785	et	4	main
ei	doc_681992022023_item	2808821	et	4	main
mingeid	doc_681992022023_item	2808823	et	3	main
kohustusi	doc_681992022023_item	2808824	et	4	main
siis	doc_681992022023_item	2808825	et	3	main
ma	doc_681992022023_item	2808826	et	3	main
või	doc_681992022023_item	2808828	et	4	main
lähen	doc_681992022023_item	2808829	et	3	main
jalutada	doc_681992022023_item	2808830	et	3	main
õuel	doc_681992022023_item	2808839	et	3	main
selliseid	doc_681992022023_item	2808843	et	4	main
ma	doc_681992022023_item	2808849	et	3	main
haiglas	doc_681992022024_item	2808865	et	3	main
siin	doc_681992022024_item	2808869	et	4	main
olen	doc_681992022024_item	2808871	et	3	main
venelane	doc_681992022024_item	2808872	et	3	main
on	doc_681992022024_item	2808874	et	4	main
vene	doc_681992022024_item	2808875	et	4	main
kodakonsus	doc_681992022024_item	2808876	et	4	main
ma	doc_681992022024_item	2808877	et	3	main
olen	doc_681992022024_item	2808878	et	3	main
18	doc_681992022024_item	2808879	et	2	main
aastat	doc_681992022024_item	2808880	et	3	main
kohtla-jarve	doc_681992022024_item	2808884	et	4	main
et	doc_681992022024_item	2808922	et	3	main
sõbralik	doc_681992022024_item	2808925	et	3	main
ja	doc_681992022024_item	2808927	et	3	main
pojaga	doc_681992022025_item	2808948	et	4	main
eesnimi	doc_681992022025_item	2808952	et	3	main
käib	doc_681992022025_item	2808954	et	3	main
seal	doc_681992022025_item	2808962	et	4	main
korrusel	doc_681992022025_item	2808969	et	3	main
meie	doc_681992022025_item	2808980	et	4	main
juurde	doc_681992022025_item	2808981	et	4	main
minu	doc_681992022025_item	2808982	et	3	main
ema	doc_681992022025_item	2808983	et	4	main
ja	doc_681992022025_item	2808984	et	3	main
mängib	doc_681992022025_item	2808985	et	3	main
pojaga	doc_681992022025_item	2808986	et	4	main
juurde	doc_681992022025_item	2808992	et	4	main
armastan	doc_681992022025_item	2809023	et	3	main
mulle	doc_681992022025_item	2809037	et	4	main
kui	doc_681992022025_item	2809040	et	3	main
ilus	doc_681992022025_item	2809051	et	4	main
ja	doc_681992022025_item	2809052	et	3	main
mul	doc_681992022025_item	2809064	et	3	main
on	doc_681992022025_item	2809065	et	4	main
sõpradega	doc_681992022026_item	2809101	et	3	main
mulle	doc_681992022026_item	2809102	et	4	main
korda	doc_681992022026_item	2809109	et	4	main
ma	doc_681992022026_item	2809116	et	3	main
maadleja	doc_681992022026_item	2809118	et	4	main
juba	doc_681992022026_item	2809122	et	3	main
koos	doc_681992022023_item	2808714	et	4	main
mulle	doc_681992022023_item	2808719	et	4	main
väga	doc_681992022023_item	2808720	et	3	main
oma	doc_681992022023_item	2808732	et	4	main
süüa	doc_681992022023_item	2808742	et	3	main
küpsetan	doc_681992022023_item	2808744	et	3	main
ja	doc_681992022023_item	2808751	et	3	main
teda	doc_681992022023_item	2808753	et	4	main
juhtus	doc_681992022023_item	2808755	et	3	main
aitab	doc_681992022023_item	2808757	et	3	main
mind	doc_681992022023_item	2808758	et	4	main
kui	doc_681992022023_item	2808759	et	3	main
mu	doc_681992022023_item	2808760	et	3	main
heal	doc_681992022023_item	2808761	et	3	main
ja	doc_681992022023_item	2808769	et	3	main
palju	doc_681992022023_item	2808771	et	4	main
on	doc_681992022023_item	2808780	et	4	main
inimesest	doc_681992022023_item	2808786	et	3	main
sünnipäevi	doc_681992022023_item	2808790	et	4	main
ei	doc_681992022023_item	2808791	et	4	main
ole	doc_681992022023_item	2808792	et	4	main
tihti	doc_681992022023_item	2808793	et	3	main
kui	doc_681992022023_item	2808794	et	3	main
mu	doc_681992022023_item	2808795	et	3	main
sõber	doc_681992022023_item	2808796	et	3	main
ma	doc_681992022023_item	2808801	et	3	main
ma	doc_681992022023_item	2808832	et	3	main
vaatan	doc_681992022023_item	2808833	et	3	main
lihtne	doc_681992022023_item	2808840	et	3	main
sõbradega	doc_681992022023_item	2808842	et	4	main
et	doc_681992022023_item	2808848	et	3	main
õpin	doc_681992022023_item	2808850	et	3	main
koduseid	doc_681992022023_item	2808852	et	4	main
ma	doc_681992022024_item	2808867	et	3	main
elan	doc_681992022024_item	2808868	et	3	main
ma	doc_681992022024_item	2808882	et	3	main
ole	doc_681992022024_item	2808924	et	4	main
tagasihoidlik	doc_681992022024_item	2808926	et	3	main
kakskümmend	doc_681992022025_item	2808940	et	4	main
aastat	doc_681992022025_item	2808941	et	3	main
nimi	doc_681992022025_item	2808950	et	3	main
lasteaeda	doc_681992022025_item	2808955	et	4	main
juba	doc_681992022025_item	2808956	et	3	main
pool	doc_681992022025_item	2808957	et	4	main
käia	doc_681992022025_item	2808963	et	4	main
mina	doc_681992022025_item	2808964	et	4	main
elan	doc_681992022025_item	2808965	et	3	main
külalisi	doc_681992022025_item	2808977	et	4	main
nädalas	doc_681992022025_item	2808978	et	3	main
tuleb	doc_681992022025_item	2808979	et	3	main
õde	doc_681992022025_item	2808995	et	4	main
leena	doc_681992022025_item	2808996	et	3	main
ja	doc_681992022025_item	2808997	et	3	main
minu	doc_681992022025_item	2808998	et	3	main
koer	doc_681992022025_item	2808999	et	3	main
elada	doc_681992022025_item	2809021	et	3	main
lugeda	doc_681992022025_item	2809024	et	3	main
õhtuti	doc_681992022025_item	2809029	et	3	main
filosoofia	doc_681992022025_item	2809035	et	4	main
on	doc_681992022025_item	2809049	et	4	main
nii	doc_681992022025_item	2809050	et	3	main
ja	doc_681992022025_item	2809062	et	3	main
palju	doc_681992022025_item	2809066	et	4	main
sõpru	doc_681992022025_item	2809067	et	3	main
ma	doc_681992022025_item	2809068	et	3	main
olen	doc_681992022025_item	2809069	et	3	main
vaikne	doc_681992022025_item	2809070	et	3	main
inimene	doc_681992022025_item	2809071	et	3	main
aga	doc_681992022025_item	2809072	et	3	main
armastan	doc_681992022025_item	2809073	et	3	main
aitavad	doc_681992022025_item	2809077	et	4	main
elada	doc_681992022025_item	2809083	et	3	main
elu	doc_681992022025_item	2809085	et	4	main
heasüdamlik	doc_681992022026_item	2809092	et	3	main
sporti	doc_681992022026_item	2809104	et	4	main
sõidan	doc_681992022026_item	2809107	et	3	main
kolm	doc_681992022026_item	2809108	et	3	main
nädalas	doc_681992022026_item	2809110	et	3	main
trenni	doc_681992022026_item	2809111	et	4	main
me	doc_681992022026_item	2809112	et	4	main
tee	doc_681992022023_item	2808722	et	4	main
käpa	doc_681992022023_item	2808733	et	3	main
kui	doc_681992022023_item	2808736	et	3	main
teen	doc_681992022023_item	2808741	et	3	main
või	doc_681992022023_item	2808743	et	4	main
midagi	doc_681992022023_item	2808745	et	4	main
rääkin	doc_681992022023_item	2808752	et	4	main
sünnipäev	doc_681992022023_item	2808764	et	3	main
siis	doc_681992022023_item	2808765	et	3	main
ma	doc_681992022023_item	2808766	et	3	main
helistan	doc_681992022023_item	2808767	et	3	main
seal	doc_681992022023_item	2808779	et	4	main
palub	doc_681992022023_item	2808797	et	3	main
siis	doc_681992022023_item	2808800	et	3	main
aita	doc_681992022023_item	2808803	et	4	main
teda	doc_681992022023_item	2808804	et	4	main
kui	doc_681992022023_item	2808805	et	3	main
ma	doc_681992022023_item	2808806	et	3	main
saan	doc_681992022023_item	2808807	et	4	main
aita	doc_681992022023_item	2808808	et	4	main
teda	doc_681992022023_item	2808809	et	4	main
siis	doc_681992022023_item	2808810	et	3	main
ma	doc_681992022023_item	2808811	et	3	main
aitan	doc_681992022023_item	2808812	et	3	main
muidugi	doc_681992022023_item	2808813	et	4	main
selliseid	doc_681992022023_item	2808814	et	4	main
olukordi	doc_681992022023_item	2808815	et	4	main
juhtub	doc_681992022023_item	2808816	et	3	main
üsna	doc_681992022023_item	2808817	et	3	main
tihti	doc_681992022023_item	2808818	et	3	main
kui	doc_681992022023_item	2808819	et	3	main
mul	doc_681992022023_item	2808820	et	3	main
kodus	doc_681992022023_item	2808831	et	4	main
telerit	doc_681992022023_item	2808834	et	3	main
muusikat	doc_681992022023_item	2808837	et	3	main
hetki	doc_681992022023_item	2808844	et	4	main
harva	doc_681992022023_item	2808846	et	4	main
teen	doc_681992022023_item	2808851	et	3	main
tööd	doc_681992022023_item	2808853	et	4	main
ja	doc_681992022023_item	2808854	et	3	main
töötan	doc_681992022023_item	2808855	et	3	main
essee	doc_681992022024_item	2808856	et	4	main
minu	doc_681992022024_item	2808857	et	3	main
kohtla-järve	doc_681992022024_item	2808864	et	4	main
vana	doc_681992022024_item	2808881	et	4	main
ma	doc_681992022024_item	2808923	et	3	main
töökas	doc_681992022024_item	2808928	et	4	main
inimene	doc_681992022024_item	2808929	et	3	main
vana	doc_681992022025_item	2808942	et	4	main
praegu	doc_681992022025_item	2808943	et	3	main
elan	doc_681992022025_item	2808944	et	3	main
aasta	doc_681992022025_item	2808958	et	4	main
kahetoalises	doc_681992022025_item	2808966	et	4	main
korteris	doc_681992022025_item	2808967	et	3	main
kolmandal	doc_681992022025_item	2808968	et	3	main
oma	doc_681992022025_item	2808972	et	4	main
koos	doc_681992022025_item	2808987	et	4	main
tuleb	doc_681992022025_item	2808990	et	3	main
viis	doc_681992022025_item	2809004	et	4	main
ma	doc_681992022025_item	2809022	et	3	main
loen	doc_681992022025_item	2809027	et	3	main
pojale	doc_681992022025_item	2809028	et	4	main
muinasjuttu	doc_681992022025_item	2809030	et	4	main
lugeda	doc_681992022025_item	2809036	et	3	main
mets	doc_681992022025_item	2809039	et	3	main
puhkan	doc_681992022023_item	2808827	et	3	main
aga	doc_681992022023_item	2808838	et	3	main
on	doc_681992022023_item	2808845	et	4	main
sellepärast	doc_681992022023_item	2808847	et	3	main
eesnimi	doc_681992022024_item	2808860	et	3	main
praegu	doc_681992022024_item	2808866	et	3	main
lõpetasin	doc_681992022024_item	2808883	et	3	main
ühisgümnaasium	doc_681992022024_item	2808885	et	3	main
praegu	doc_681992022024_item	2808886	et	3	main
õpin	doc_681992022024_item	2808887	et	3	main
kutsekeskhariduskeskuses	doc_681992022024_item	2808888	et	4	main
pärast	doc_681992022024_item	2808889	et	4	main
astuda	doc_681992022024_item	2808891	et	3	main
tahan	doc_681992022024_item	2808890	et	3	main
tallinnaülikooli	doc_681992022024_item	2808892	et	4	main
koolis	doc_681992022024_item	2808893	et	4	main
mul	doc_681992022024_item	2808894	et	3	main
oli	doc_681992022024_item	2808895	et	3	main
kaks	doc_681992022024_item	2808896	et	3	main
lemmikõppeaineid	doc_681992022024_item	2808897	et	3	main
see	doc_681992022024_item	2808898	et	3	main
ühiskonnaõpetus	doc_681992022024_item	2808899	et	3	main
ja	doc_681992022024_item	2808900	et	3	main
inimene	doc_681992022024_item	2808901	et	3	main
ja	doc_681992022024_item	2808902	et	3	main
õigus	doc_681992022024_item	2808903	et	4	main
varmistas	doc_681992022024_item	2808904	et	4	main
raskusi	doc_681992022024_item	2808905	et	4	main
matemaatika	doc_681992022024_item	2808906	et	4	main
mul	doc_681992022024_item	2808907	et	3	main
on	doc_681992022024_item	2808908	et	4	main
palju	doc_681992022024_item	2808909	et	4	main
hobisid	doc_681992022024_item	2808910	et	3	main
naiteks	doc_681992022024_item	2808911	et	4	main
ma	doc_681992022024_item	2808912	et	3	main
armastan	doc_681992022024_item	2808913	et	3	main
ujuda	doc_681992022024_item	2808914	et	3	main
ratsustada	doc_681992022024_item	2808915	et	4	main
ka	doc_681992022024_item	2808916	et	3	main
ma	doc_681992022024_item	2808917	et	3	main
koliksioneerin	doc_681992022024_item	2808918	et	4	main
münte	doc_681992022024_item	2808919	et	3	main
ma	doc_681992022024_item	2808920	et	3	main
essee	doc_681992022025_item	2808930	et	4	main
minu	doc_681992022025_item	2808931	et	3	main
nimi	doc_681992022025_item	2808932	et	3	main
on	doc_681992022025_item	2808933	et	4	main
eesnimi	doc_681992022025_item	2808934	et	3	main
ma	doc_681992022025_item	2808935	et	3	main
elan	doc_681992022025_item	2808936	et	3	main
koos	doc_681992022025_item	2808945	et	4	main
abikaasaga	doc_681992022025_item	2808946	et	3	main
ja	doc_681992022025_item	2808947	et	3	main
on	doc_681992022025_item	2808951	et	4	main
ta	doc_681992022025_item	2808953	et	4	main
väga	doc_681992022025_item	2808960	et	3	main
armastan	doc_681992022025_item	2808971	et	3	main
meil	doc_681992022025_item	2808974	et	4	main
on	doc_681992022025_item	2808975	et	4	main
palju	doc_681992022025_item	2808976	et	4	main
mõnikord	doc_681992022025_item	2808989	et	3	main
mina	doc_681992022025_item	2809000	et	4	main
tegelen	doc_681992022025_item	2809001	et	3	main
mina	doc_681992022025_item	2809006	et	4	main
tegelen	doc_681992022025_item	2809007	et	3	main
kung-fu-ga	doc_681992022025_item	2809008	et	3	main
see	doc_681992022025_item	2809009	et	3	main
on	doc_681992022025_item	2809010	et	4	main
väga	doc_681992022025_item	2809011	et	3	main
huvitav	doc_681992022025_item	2809012	et	4	main
ilus	doc_681992022025_item	2809013	et	4	main
ja	doc_681992022025_item	2809014	et	3	main
tugev	doc_681992022025_item	2809015	et	4	main
stiil	doc_681992022025_item	2809016	et	3	main
kung-	doc_681992022025_item	2809017	et	4	main
fu	doc_681992022025_item	2809018	et	4	main
aitab	doc_681992022025_item	2809019	et	3	main
mulle	doc_681992022025_item	2809020	et	4	main
raamatuid	doc_681992022025_item	2809025	et	3	main
mulle	doc_681992022025_item	2809033	et	4	main
meeldib	doc_681992022025_item	2809034	et	3	main
seal	doc_681992022025_item	2809048	et	4	main
vaikne	doc_681992022025_item	2809053	et	3	main
seal	doc_681992022025_item	2809054	et	4	main
ma	doc_681992022025_item	2809055	et	3	main
puhkan	doc_681992022025_item	2809056	et	3	main
mõnikord	doc_681992022025_item	2809057	et	3	main
lähen	doc_681992022025_item	2809058	et	3	main
kaasaga	doc_681992022025_item	2809059	et	3	main
oma	doc_681992022025_item	2809060	et	4	main
poja	doc_681992022025_item	2809061	et	4	main
koeraga	doc_681992022025_item	2809063	et	3	main
on	doc_681992022025_item	2809042	et	4	main
pühapäevad	doc_681992022025_item	2809043	et	3	main
siis	doc_681992022025_item	2809044	et	3	main
ma	doc_681992022025_item	2809045	et	3	main
tulen	doc_681992022025_item	2809046	et	3	main
metsa	doc_681992022025_item	2809047	et	4	main
suhelda	doc_681992022025_item	2809074	et	4	main
mulle	doc_681992022025_item	2809078	et	4	main
sõnaga	doc_681992022025_item	2809080	et	3	main
mind	doc_681992022025_item	2809087	et	4	main
essee	doc_681992022026_item	2809088	et	4	main
ma	doc_681992022026_item	2809089	et	3	main
olen	doc_681992022026_item	2809090	et	3	main
vastutuslik	doc_681992022026_item	2809094	et	4	main
sugulastega	doc_681992022026_item	2809099	et	4	main
ja	doc_681992022026_item	2809100	et	3	main
tegelema	doc_681992022026_item	2809105	et	3	main
spordiklubis	doc_681992022026_item	2809115	et	3	main
ma	doc_681992022026_item	2809134	et	3	main
loen	doc_681992022026_item	2809137	et	3	main
sünnipäev	doc_681992022026_item	2809149	et	3	main
kauplusesse	doc_681992022026_item	2809153	et	4	main
meeldivad	doc_681992022026_item	2809159	et	4	main
sünnipäevad	doc_681992022026_item	2809160	et	3	main
tihti	doc_681992022026_item	2809177	et	3	main
mind	doc_681992022026_item	2809182	et	4	main
haruldus	doc_681992022026_item	2809195	et	3	main
ma	doc_681992022026_item	2809203	et	3	main
ole	doc_681992022026_item	2809226	et	4	main
vaba	doc_681992022026_item	2809227	et	4	main
see	doc_681992022027_item	2809235	et	3	main
lähendab	doc_681992022027_item	2809236	et	3	main
meeldib	doc_681992022027_item	2809239	et	3	main
lastega	doc_681992022027_item	2809246	et	3	main
mulle	doc_681992022027_item	2809290	et	4	main
meeldivad	doc_681992022027_item	2809291	et	4	main
minu	doc_681992022027_item	2809332	et	3	main
kui	doc_681992022027_item	2809336	et	3	main
ei	doc_681992022027_item	2809338	et	4	main
mingeid	doc_681992022027_item	2809340	et	3	main
loen	doc_681992022027_item	2809344	et	3	main
raamatuid	doc_681992022027_item	2809345	et	3	main
ja	doc_681992022027_item	2809346	et	3	main
juhtuda	doc_681992022027_item	2809351	et	3	main
õhtuti	doc_681992022027_item	2809352	et	3	main
essee	doc_681992022028_item	2809353	et	4	main
tähendab	doc_681992022028_item	2809360	et	3	main
mulle	doc_681992022028_item	2809362	et	4	main
inimesi	doc_681992022028_item	2809393	et	4	main
mulle	doc_681992022028_item	2809396	et	4	main
meeldib	doc_681992022028_item	2809397	et	3	main
ja	doc_681992022028_item	2809419	et	3	main
olla	doc_681992022028_item	2809426	et	3	main
ka	doc_681992022028_item	2809431	et	3	main
on	doc_681992022028_item	2809435	et	4	main
olukord	doc_681992022028_item	2809437	et	3	main
siis	doc_681992022028_item	2809438	et	3	main
ma	doc_681992022028_item	2809439	et	3	main
püüan	doc_681992022028_item	2809440	et	3	main
lahendada	doc_681992022028_item	2809441	et	3	main
ise	doc_681992022028_item	2809444	et	4	main
ma	doc_681992022028_item	2809446	et	3	main
veel	doc_681992022028_item	2809465	et	4	main
minu	doc_681992022028_item	2809466	et	3	main
probleeme	doc_681992022028_item	2809467	et	3	main
tuttaval	doc_681992022028_item	2809471	et	4	main
põhjus	doc_681992022028_item	2809489	et	4	main
ma	doc_681992022028_item	2809501	et	3	main
see	doc_681992022028_item	2809505	et	3	main
ju	doc_681992022028_item	2809507	et	3	main
pean	doc_681992022028_item	2809512	et	4	main
teda	doc_681992022028_item	2809513	et	4	main
ole	doc_681992022028_item	2809524	et	4	main
varem	doc_681992022028_item	2809531	et	4	main
ma	doc_681992022028_item	2809533	et	3	main
õnnelik	doc_681992022028_item	2809544	et	3	main
ma	doc_681992022028_item	2809549	et	3	main
minu	doc_681992022028_item	2809553	et	3	main
ma	doc_681992022029_item	2809557	et	3	main
alati	doc_681992022029_item	2809559	et	4	main
muutlik	doc_681992022029_item	2809560	et	3	main
inimene	doc_681992022029_item	2809561	et	3	main
sõbrannad	doc_681992022025_item	2809076	et	3	main
armastan	doc_681992022025_item	2809082	et	3	main
ja	doc_681992022025_item	2809084	et	3	main
armastab	doc_681992022025_item	2809086	et	3	main
ja	doc_681992022026_item	2809093	et	3	main
ma	doc_681992022026_item	2809096	et	3	main
minu	doc_681992022026_item	2809098	et	3	main
meeldib	doc_681992022026_item	2809103	et	3	main
ma	doc_681992022026_item	2809106	et	3	main
kohtla-järvel	doc_681992022026_item	2809114	et	4	main
olen	doc_681992022026_item	2809117	et	3	main
ma	doc_681992022026_item	2809119	et	3	main
läks	doc_681992022026_item	2809120	et	3	main
mul	doc_681992022026_item	2809129	et	3	main
või	doc_681992022026_item	2809139	et	4	main
trennin	doc_681992022026_item	2809140	et	4	main
ma	doc_681992022026_item	2809162	et	3	main
armastan	doc_681992022026_item	2809163	et	3	main
me	doc_681992022026_item	2809167	et	4	main
puhkasime	doc_681992022026_item	2809170	et	3	main
sünnipäev	doc_681992022026_item	2809172	et	3	main
sõpradega	doc_681992022026_item	2809175	et	3	main
appi	doc_681992022026_item	2809183	et	4	main
ma	doc_681992022026_item	2809185	et	3	main
sind	doc_681992022026_item	2809187	et	4	main
lähen	doc_681992022026_item	2809189	et	3	main
emmale	doc_681992022026_item	2809192	et	3	main
kui	doc_681992022026_item	2809196	et	3	main
on	doc_681992022026_item	2809222	et	4	main
tihti	doc_681992022026_item	2809224	et	3	main
essee	doc_681992022027_item	2809229	et	4	main
ma	doc_681992022027_item	2809230	et	3	main
olen	doc_681992022027_item	2809231	et	3	main
mulle	doc_681992022027_item	2809238	et	4	main
tegelen	doc_681992022027_item	2809247	et	3	main
kodus	doc_681992022027_item	2809249	et	4	main
kui	doc_681992022027_item	2809257	et	3	main
pingeline	doc_681992022027_item	2809260	et	4	main
ma	doc_681992022027_item	2809263	et	3	main
õue	doc_681992022027_item	2809265	et	4	main
jalutan	doc_681992022027_item	2809267	et	3	main
mõtlen	doc_681992022027_item	2809270	et	3	main
järele	doc_681992022027_item	2809273	et	4	main
mu	doc_681992022027_item	2809275	et	3	main
sünnipäevad	doc_681992022027_item	2809292	et	3	main
kindlasti	doc_681992022027_item	2809322	et	3	main
keegi	doc_681992022027_item	2809331	et	4	main
kohustusi	doc_681992022027_item	2809341	et	4	main
siis	doc_681992022027_item	2809342	et	3	main
ma	doc_681992022027_item	2809343	et	3	main
vaatan	doc_681992022027_item	2809347	et	3	main
telerit	doc_681992022027_item	2809348	et	3	main
seda	doc_681992022027_item	2809349	et	3	main
võib	doc_681992022027_item	2809350	et	3	main
alati	doc_681992022028_item	2809356	et	4	main
see	doc_681992022028_item	2809359	et	3	main
inimesega	doc_681992022028_item	2809364	et	3	main
mul	doc_681992022028_item	2809366	et	3	main
erinevatest	doc_681992022028_item	2809394	et	4	main
puhata	doc_681992022028_item	2809398	et	4	main
või	doc_681992022028_item	2809399	et	4	main
sõpradega	doc_681992022028_item	2809400	et	3	main
puhata	doc_681992022028_item	2809413	et	4	main
istun	doc_681992022028_item	2809417	et	3	main
aeg-ajalt	doc_681992022028_item	2809424	et	4	main
ja	doc_681992022028_item	2809428	et	3	main
juhtub	doc_681992022028_item	2809432	et	3	main
mul	doc_681992022028_item	2809434	et	3	main
ei	doc_681992022028_item	2809459	et	4	main
sõbrad	doc_681992022028_item	2809463	et	3	main
mu	doc_681992022028_item	2809469	et	3	main
on	doc_681992022028_item	2809472	et	4	main
siis	doc_681992022028_item	2809474	et	3	main
õnne	doc_681992022028_item	2809481	et	4	main
puhata	doc_681992022028_item	2809490	et	4	main
mul	doc_681992022028_item	2809522	et	3	main
juba	doc_681992022028_item	2809530	et	3	main
või	doc_681992022028_item	2809535	et	4	main
kohtud	doc_681992022028_item	2809536	et	4	main
ma	doc_681992022028_item	2809538	et	3	main
võin	doc_681992022028_item	2809539	et	3	main
öelda	doc_681992022028_item	2809540	et	4	main
kuus	doc_681992022026_item	2809123	et	4	main
siis	doc_681992022026_item	2809133	et	3	main
tuttaval	doc_681992022026_item	2809147	et	4	main
sest	doc_681992022026_item	2809161	et	4	main
sõbrad	doc_681992022026_item	2809165	et	3	main
minu	doc_681992022026_item	2809171	et	3	main
väga	doc_681992022026_item	2809176	et	3	main
sõber	doc_681992022026_item	2809180	et	3	main
aidatan	doc_681992022026_item	2809186	et	4	main
appi	doc_681992022026_item	2809190	et	4	main
minuga	doc_681992022026_item	2809191	et	3	main
või	doc_681992022026_item	2809193	et	4	main
mul	doc_681992022026_item	2809197	et	3	main
kohustusi	doc_681992022026_item	2809201	et	4	main
või	doc_681992022026_item	2809205	et	4	main
istun	doc_681992022026_item	2809206	et	3	main
interneetiga	doc_681992022026_item	2809207	et	4	main
või	doc_681992022026_item	2809208	et	4	main
vaatan	doc_681992022026_item	2809209	et	3	main
telerit	doc_681992022026_item	2809210	et	3	main
selliseid	doc_681992022026_item	2809211	et	4	main
hetki	doc_681992022026_item	2809212	et	4	main
ei	doc_681992022026_item	2809213	et	4	main
tihti	doc_681992022026_item	2809214	et	3	main
sest	doc_681992022026_item	2809215	et	4	main
ma	doc_681992022026_item	2809216	et	3	main
õppisin	doc_681992022026_item	2809217	et	3	main
ja	doc_681992022026_item	2809218	et	3	main
lähen	doc_681992022026_item	2809219	et	3	main
trenni	doc_681992022026_item	2809220	et	4	main
väga	doc_681992022026_item	2809223	et	3	main
alati	doc_681992022027_item	2809232	et	4	main
töökas	doc_681992022027_item	2809233	et	4	main
inimene	doc_681992022027_item	2809234	et	3	main
alati	doc_681992022027_item	2809240	et	4	main
teha	doc_681992022027_item	2809242	et	3	main
mulle	doc_681992022027_item	2809243	et	4	main
meeldib	doc_681992022027_item	2809244	et	3	main
tegeleda	doc_681992022027_item	2809245	et	3	main
lapsed	doc_681992022027_item	2809256	et	3	main
mul	doc_681992022027_item	2809258	et	3	main
juhtunu	doc_681992022027_item	2809271	et	4	main
kui	doc_681992022027_item	2809274	et	3	main
heal	doc_681992022027_item	2809276	et	3	main
on	doc_681992022027_item	2809278	et	4	main
saab	doc_681992022027_item	2809294	et	3	main
ma	doc_681992022027_item	2809321	et	3	main
ta	doc_681992022027_item	2809324	et	4	main
on	doc_681992022027_item	2809325	et	4	main
vajab	doc_681992022027_item	2809335	et	3	main
mul	doc_681992022027_item	2809337	et	3	main
ole	doc_681992022027_item	2809339	et	4	main
seltsiv	doc_681992022028_item	2809357	et	4	main
maadest	doc_681992022028_item	2809395	et	4	main
lihtsalt	doc_681992022028_item	2809412	et	4	main
ma	doc_681992022028_item	2809416	et	3	main
aasta	doc_681992022026_item	2809124	et	4	main
mulle	doc_681992022026_item	2809125	et	4	main
väga	doc_681992022026_item	2809126	et	3	main
meeldib	doc_681992022026_item	2809127	et	3	main
kui	doc_681992022026_item	2809128	et	3	main
pingeline	doc_681992022026_item	2809131	et	4	main
ja	doc_681992022026_item	2809136	et	3	main
raamatu	doc_681992022026_item	2809138	et	4	main
mulle	doc_681992022026_item	2809141	et	4	main
aitab	doc_681992022026_item	2809142	et	3	main
treening	doc_681992022026_item	2809143	et	3	main
kui	doc_681992022026_item	2809144	et	3	main
mu	doc_681992022026_item	2809145	et	3	main
heal	doc_681992022026_item	2809146	et	3	main
siis	doc_681992022026_item	2809150	et	3	main
ma	doc_681992022026_item	2809151	et	3	main
ostan	doc_681992022026_item	2809155	et	3	main
minu	doc_681992022026_item	2809164	et	3	main
kui	doc_681992022026_item	2809178	et	3	main
mu	doc_681992022026_item	2809179	et	3	main
ma	doc_681992022026_item	2809188	et	3	main
sõ	doc_681992022026_item	2809194	et	4	main
ole	doc_681992022026_item	2809199	et	4	main
magan	doc_681992022026_item	2809204	et	3	main
aja	doc_681992022026_item	2809228	et	4	main
midagi	doc_681992022027_item	2809241	et	4	main
nendega	doc_681992022027_item	2809248	et	4	main
iga	doc_681992022027_item	2809250	et	4	main
päev	doc_681992022027_item	2809251	et	3	main
sest	doc_681992022027_item	2809252	et	4	main
nad	doc_681992022027_item	2809253	et	3	main
siis	doc_681992022027_item	2809262	et	3	main
lähen	doc_681992022027_item	2809264	et	3	main
linnas	doc_681992022027_item	2809268	et	4	main
üle	doc_681992022027_item	2809272	et	3	main
õnnitlema	doc_681992022027_item	2809289	et	3	main
sest	doc_681992022027_item	2809293	et	4	main
hea	doc_681992022026_item	2809169	et	4	main
ma	doc_681992022026_item	2809173	et	3	main
tähistan	doc_681992022026_item	2809174	et	3	main
palub	doc_681992022026_item	2809181	et	3	main
siis	doc_681992022026_item	2809184	et	3	main
ei	doc_681992022026_item	2809198	et	4	main
mingeid	doc_681992022026_item	2809200	et	3	main
sis	doc_681992022026_item	2809202	et	3	main
mul	doc_681992022026_item	2809221	et	3	main
ei	doc_681992022026_item	2809225	et	4	main
et	doc_681992022027_item	2809237	et	3	main
on	doc_681992022027_item	2809254	et	4	main
minu	doc_681992022027_item	2809255	et	3	main
on	doc_681992022027_item	2809259	et	4	main
olukord	doc_681992022027_item	2809261	et	3	main
jalutama	doc_681992022027_item	2809266	et	3	main
ja	doc_681992022027_item	2809269	et	3	main
tuttaval	doc_681992022027_item	2809277	et	4	main
sünnipäev	doc_681992022027_item	2809279	et	3	main
siis	doc_681992022027_item	2809280	et	3	main
ma	doc_681992022027_item	2809281	et	3	main
ostan	doc_681992022027_item	2809282	et	3	main
kingituse	doc_681992022027_item	2809283	et	4	main
ja	doc_681992022027_item	2809284	et	3	main
lilled	doc_681992022027_item	2809285	et	3	main
ja	doc_681992022027_item	2809286	et	3	main
lähen	doc_681992022027_item	2809287	et	3	main
teda	doc_681992022027_item	2809288	et	4	main
külas	doc_681992022027_item	2809295	et	3	main
käia	doc_681992022027_item	2809296	et	4	main
ja	doc_681992022027_item	2809297	et	3	main
kui	doc_681992022027_item	2809298	et	3	main
endal	doc_681992022027_item	2809299	et	4	main
on	doc_681992022027_item	2809300	et	4	main
sünnipäev	doc_681992022027_item	2809301	et	3	main
siis	doc_681992022027_item	2809302	et	3	main
kingitusi	doc_681992022027_item	2809303	et	4	main
saada	doc_681992022027_item	2809304	et	4	main
kui	doc_681992022027_item	2809305	et	3	main
kellegil	doc_681992022027_item	2809306	et	4	main
sõpradest	doc_681992022027_item	2809307	et	3	main
on	doc_681992022027_item	2809308	et	4	main
sünnipäev	doc_681992022027_item	2809309	et	3	main
siis	doc_681992022027_item	2809310	et	3	main
tähistama	doc_681992022027_item	2809311	et	3	main
kindlasti	doc_681992022027_item	2809312	et	3	main
kui	doc_681992022027_item	2809313	et	3	main
mu	doc_681992022027_item	2809314	et	3	main
sõber	doc_681992022027_item	2809315	et	3	main
palub	doc_681992022027_item	2809316	et	3	main
mind	doc_681992022027_item	2809317	et	4	main
appi	doc_681992022027_item	2809318	et	4	main
siis	doc_681992022027_item	2809319	et	3	main
lähen	doc_681992022027_item	2809320	et	3	main
sest	doc_681992022027_item	2809323	et	4	main
minu	doc_681992022027_item	2809326	et	3	main
sõber	doc_681992022027_item	2809327	et	3	main
vahel	doc_681992022027_item	2809328	et	4	main
juhtub	doc_681992022027_item	2809329	et	3	main
et	doc_681992022027_item	2809330	et	3	main
abi	doc_681992022027_item	2809334	et	4	main
ma	doc_681992022028_item	2809354	et	3	main
inimene	doc_681992022028_item	2809358	et	3	main
et	doc_681992022028_item	2809361	et	3	main
suhelda	doc_681992022028_item	2809365	et	4	main
sõpradest	doc_681992022027_item	2809333	et	3	main
olen	doc_681992022028_item	2809355	et	3	main
meeldib	doc_681992022028_item	2809363	et	3	main
on	doc_681992022028_item	2809367	et	4	main
palju	doc_681992022028_item	2809368	et	4	main
sõpru	doc_681992022028_item	2809369	et	3	main
kellega	doc_681992022028_item	2809370	et	3	main
ma	doc_681992022028_item	2809371	et	3	main
armastan	doc_681992022028_item	2809372	et	3	main
vaba	doc_681992022028_item	2809373	et	4	main
aega	doc_681992022028_item	2809374	et	4	main
veeta	doc_681992022028_item	2809375	et	4	main
me	doc_681992022028_item	2809376	et	4	main
lobiseme	doc_681992022028_item	2809377	et	3	main
lakkamatult	doc_681992022028_item	2809378	et	4	main
vaatame	doc_681992022028_item	2809379	et	3	main
filmit	doc_681992022028_item	2809381	et	4	main
ja	doc_681992022028_item	2809382	et	3	main
koos	doc_681992022028_item	2809380	et	4	main
lihtsalt	doc_681992022028_item	2809383	et	4	main
jalutame	doc_681992022028_item	2809384	et	3	main
veel	doc_681992022028_item	2809385	et	4	main
armastan	doc_681992022028_item	2809386	et	3	main
väga	doc_681992022028_item	2809387	et	3	main
internetiga	doc_681992022028_item	2809388	et	4	main
suhelda	doc_681992022028_item	2809389	et	4	main
ma	doc_681992022028_item	2809390	et	3	main
tean	doc_681992022028_item	2809391	et	3	main
palju	doc_681992022028_item	2809392	et	4	main
ja	doc_681992022028_item	2809414	et	3	main
kodus	doc_681992022028_item	2809418	et	4	main
vaatan	doc_681992022028_item	2809420	et	3	main
telerit	doc_681992022028_item	2809421	et	3	main
minuga	doc_681992022028_item	2809429	et	3	main
probleeme	doc_681992022028_item	2809443	et	3	main
olen	doc_681992022028_item	2809447	et	3	main
ma	doc_681992022028_item	2809450	et	3	main
et	doc_681992022028_item	2809452	et	3	main
et	doc_681992022028_item	2809461	et	3	main
lahendaksid	doc_681992022028_item	2809464	et	4	main
kui	doc_681992022028_item	2809468	et	3	main
ma	doc_681992022028_item	2809475	et	3	main
muidugi	doc_681992022028_item	2809476	et	4	main
soovin	doc_681992022028_item	2809477	et	3	main
sõbrale	doc_681992022028_item	2809478	et	3	main
sünnipäeva	doc_681992022028_item	2809479	et	4	main
mulle	doc_681992022028_item	2809483	et	4	main
meeldivad	doc_681992022028_item	2809484	et	4	main
sünnipäevad	doc_681992022028_item	2809485	et	3	main
see	doc_681992022028_item	2809486	et	3	main
sõpradega	doc_681992022028_item	2809493	et	3	main
kui	doc_681992022028_item	2809494	et	3	main
mu	doc_681992022028_item	2809495	et	3	main
sõber	doc_681992022028_item	2809496	et	3	main
palub	doc_681992022028_item	2809497	et	3	main
mind	doc_681992022028_item	2809498	et	4	main
lähen	doc_681992022028_item	2809503	et	3	main
mu	doc_681992022028_item	2809508	et	3	main
ma	doc_681992022028_item	2809511	et	3	main
suhelda	doc_681992022028_item	2809401	et	4	main
ma	doc_681992022028_item	2809402	et	3	main
kohtun	doc_681992022028_item	2809403	et	3	main
sõpradega	doc_681992022028_item	2809404	et	3	main
iga	doc_681992022028_item	2809405	et	4	main
päev	doc_681992022028_item	2809406	et	3	main
õhtul	doc_681992022028_item	2809407	et	3	main
aga	doc_681992022028_item	2809408	et	3	main
mõnikord	doc_681992022028_item	2809409	et	3	main
ma	doc_681992022028_item	2809410	et	3	main
tahan	doc_681992022028_item	2809411	et	3	main
siis	doc_681992022028_item	2809415	et	3	main
tahab	doc_681992022028_item	2809425	et	3	main
oma	doc_681992022028_item	2809442	et	4	main
seltsiv	doc_681992022028_item	2809448	et	4	main
inimesel	doc_681992022028_item	2809454	et	3	main
taha	doc_681992022028_item	2809460	et	4	main
heal	doc_681992022028_item	2809470	et	3	main
puhul	doc_681992022028_item	2809480	et	4	main
loomulikult	doc_681992022028_item	2809482	et	4	main
koos	doc_681992022028_item	2809491	et	4	main
armsate	doc_681992022028_item	2809492	et	3	main
loomulikult	doc_681992022028_item	2809502	et	4	main
kui	doc_681992022028_item	2809521	et	3	main
ei	doc_681992022028_item	2809523	et	4	main
mingeid	doc_681992022028_item	2809525	et	3	main
kohustusi	doc_681992022028_item	2809526	et	4	main
siis	doc_681992022028_item	2809527	et	3	main
mina	doc_681992022028_item	2809542	et	4	main
olen	doc_681992022028_item	2809543	et	3	main
inimene	doc_681992022028_item	2809545	et	3	main
leian	doc_681992022028_item	2809550	et	3	main
natuke	doc_681992022028_item	2809551	et	4	main
sõprade	doc_681992022028_item	2809554	et	3	main
taime	doc_681992022029_item	2809601	et	4	main
meeldib	doc_681992022029_item	2809603	et	3	main
pingiline	doc_681992022029_item	2809613	et	4	main
olukord	doc_681992022029_item	2809614	et	3	main
siis	doc_681992022029_item	2809615	et	3	main
sugulastel	doc_681992022029_item	2809619	et	4	main
sõpradelt	doc_681992022029_item	2809621	et	3	main
aitavad	doc_681992022029_item	2809623	et	4	main
minu	doc_681992022029_item	2809634	et	3	main
siis	doc_681992022029_item	2809650	et	3	main
sest	doc_681992022029_item	2809657	et	4	main
teda	doc_681992022029_item	2809671	et	4	main
alati	doc_681992022029_item	2809677	et	4	main
sõbrat	doc_681992022029_item	2809694	et	4	main
ja	doc_681992022029_item	2809725	et	3	main
leian	doc_681992022029_item	2809726	et	3	main
endale	doc_681992022029_item	2809727	et	4	main
21	doc_681992022030_item	2809737	et	2	main
vana	doc_681992022030_item	2809739	et	4	main
praegu	doc_681992022030_item	2809740	et	3	main
kutsekeskharidus	doc_681992022030_item	2809744	et	3	main
enne	doc_681992022030_item	2809747	et	4	main
töötasin	doc_681992022030_item	2809749	et	3	main
aga	doc_681992022030_item	2809764	et	3	main
ma	doc_681992022030_item	2809765	et	3	main
palkaga	doc_681992022030_item	2809771	et	4	main
selle	doc_681992022030_item	2809772	et	4	main
rohelised	doc_681992022030_item	2809795	et	4	main
kohtla-järvel	doc_681992022030_item	2809799	et	4	main
essee	doc_681992022031_item	2809803	et	4	main
olen	doc_681992022031_item	2809805	et	3	main
see	doc_681992022031_item	2809809	et	3	main
on	doc_681992022031_item	2809813	et	4	main
hea	doc_681992022031_item	2809814	et	4	main
tuju	doc_681992022031_item	2809815	et	4	main
ma	doc_681992022031_item	2809816	et	3	main
iga	doc_681992022028_item	2809422	et	4	main
inimene	doc_681992022028_item	2809423	et	3	main
üksinduses	doc_681992022028_item	2809427	et	3	main
see	doc_681992022028_item	2809430	et	3	main
kui	doc_681992022028_item	2809433	et	3	main
pingeline	doc_681992022028_item	2809436	et	4	main
kuigi	doc_681992022028_item	2809445	et	3	main
inimene	doc_681992022028_item	2809449	et	3	main
arvan	doc_681992022028_item	2809451	et	3	main
igal	doc_681992022028_item	2809453	et	3	main
on	doc_681992022028_item	2809455	et	4	main
oma	doc_681992022028_item	2809456	et	4	main
probleemid	doc_681992022028_item	2809457	et	3	main
ja	doc_681992022028_item	2809458	et	3	main
minu	doc_681992022028_item	2809462	et	3	main
sünnipäev	doc_681992022028_item	2809473	et	3	main
on	doc_681992022028_item	2809487	et	4	main
liigne	doc_681992022028_item	2809488	et	3	main
appi	doc_681992022028_item	2809499	et	4	main
siis	doc_681992022028_item	2809500	et	3	main
appi	doc_681992022028_item	2809504	et	4	main
on	doc_681992022028_item	2809506	et	4	main
sõber	doc_681992022028_item	2809509	et	3	main
ja	doc_681992022028_item	2809510	et	3	main
aitama	doc_681992022028_item	2809514	et	3	main
aga	doc_681992022028_item	2809515	et	3	main
õnneks	doc_681992022028_item	2809516	et	4	main
selliseid	doc_681992022028_item	2809517	et	4	main
olukordi	doc_681992022028_item	2809518	et	4	main
juhtuvad	doc_681992022028_item	2809519	et	4	main
harva	doc_681992022028_item	2809520	et	4	main
ma	doc_681992022028_item	2809528	et	3	main
puhkan	doc_681992022028_item	2809534	et	3	main
sest	doc_681992022028_item	2809546	et	4	main
tihti	doc_681992022029_item	2809566	et	3	main
ja	doc_681992022029_item	2809567	et	3	main
sellest	doc_681992022029_item	2809568	et	4	main
hoolitseda	doc_681992022029_item	2809604	et	3	main
eest	doc_681992022029_item	2809606	et	4	main
seda	doc_681992022029_item	2809607	et	3	main
rahuneb	doc_681992022029_item	2809608	et	3	main
mind	doc_681992022029_item	2809609	et	4	main
kui	doc_681992022029_item	2809610	et	3	main
mul	doc_681992022029_item	2809611	et	3	main
nad	doc_681992022029_item	2809622	et	3	main
kui	doc_681992022029_item	2809625	et	3	main
võimalus	doc_681992022029_item	2809627	et	3	main
kuidas	doc_681992022029_item	2809631	et	3	main
perekonnas	doc_681992022029_item	2809635	et	4	main
head	doc_681992022029_item	2809637	et	4	main
suhted	doc_681992022029_item	2809638	et	3	main
ja	doc_681992022029_item	2809639	et	3	main
kõik	doc_681992022029_item	2809640	et	4	main
on	doc_681992022029_item	2809648	et	4	main
sünnipäev	doc_681992022029_item	2809649	et	3	main
mulle	doc_681992022029_item	2809654	et	4	main
inimesed	doc_681992022029_item	2809660	et	3	main
sõber	doc_681992022029_item	2809664	et	3	main
mulle	doc_681992022029_item	2809679	et	4	main
teen	doc_681992022029_item	2809685	et	3	main
neile	doc_681992022029_item	2809688	et	4	main
olen	doc_681992022028_item	2809529	et	3	main
öelnud	doc_681992022028_item	2809532	et	4	main
sõpradega	doc_681992022028_item	2809537	et	3	main
iga	doc_681992022028_item	2809547	et	4	main
aega	doc_681992022028_item	2809552	et	4	main
jaoks	doc_681992022028_item	2809555	et	4	main
vahel	doc_681992022029_item	2809569	et	4	main
mull	doc_681992022029_item	2809570	et	3	main
on	doc_681992022029_item	2809571	et	4	main
probleemid	doc_681992022029_item	2809572	et	3	main
suhtlemis	doc_681992022029_item	2809573	et	4	main
oma	doc_681992022029_item	2809574	et	4	main
sugulastega	doc_681992022029_item	2809575	et	4	main
ja	doc_681992022029_item	2809576	et	3	main
sõpradega	doc_681992022029_item	2809577	et	3	main
mulle	doc_681992022029_item	2809578	et	4	main
meeldib	doc_681992022029_item	2809579	et	3	main
lilled	doc_681992022029_item	2809580	et	3	main
kodus	doc_681992022029_item	2809581	et	4	main
kasvada	doc_681992022029_item	2809582	et	4	main
mulle	doc_681992022029_item	2809583	et	4	main
lihtsalt	doc_681992022029_item	2809584	et	4	main
meeldib	doc_681992022029_item	2809585	et	3	main
kodus	doc_681992022029_item	2809587	et	4	main
kui	doc_681992022029_item	2809586	et	3	main
on	doc_681992022029_item	2809588	et	4	main
palju	doc_681992022029_item	2809589	et	4	main
taime	doc_681992022029_item	2809590	et	4	main
ja	doc_681992022029_item	2809591	et	3	main
ma	doc_681992022029_item	2809592	et	3	main
tegelen	doc_681992022029_item	2809593	et	3	main
sellega	doc_681992022029_item	2809594	et	3	main
praegu	doc_681992022029_item	2809595	et	3	main
et	doc_681992022028_item	2809541	et	3	main
päev	doc_681992022028_item	2809548	et	3	main
essee	doc_681992022029_item	2809556	et	4	main
olen	doc_681992022029_item	2809558	et	3	main
on	doc_681992022029_item	2809597	et	4	main
on	doc_681992022029_item	2809612	et	4	main
abi	doc_681992022029_item	2809618	et	4	main
ja	doc_681992022029_item	2809620	et	3	main
teha	doc_681992022029_item	2809633	et	3	main
on	doc_681992022029_item	2809636	et	4	main
õnnetlen	doc_681992022029_item	2809652	et	4	main
meeldivad	doc_681992022029_item	2809655	et	4	main
kohtuvad	doc_681992022029_item	2809661	et	4	main
mu	doc_681992022029_item	2809663	et	3	main
mind	doc_681992022029_item	2809666	et	4	main
appi	doc_681992022029_item	2809667	et	4	main
siis	doc_681992022029_item	2809668	et	3	main
ma	doc_681992022029_item	2809669	et	3	main
aitan	doc_681992022029_item	2809670	et	3	main
on	doc_681992022029_item	2809681	et	4	main
vaja	doc_681992022029_item	2809682	et	4	main
seda	doc_681992022029_item	2809686	et	3	main
alati	doc_681992022029_item	2809695	et	4	main
ma	doc_681992022030_item	2809751	et	3	main
klienditeenindaja	doc_681992022030_item	2809753	et	4	main
meeldisid	doc_681992022030_item	2809755	et	4	main
seda	doc_681992022030_item	2809756	et	3	main
ma	doc_681992022030_item	2809760	et	3	main
armastan	doc_681992022030_item	2809761	et	3	main
inimestega	doc_681992022030_item	2809763	et	3	main
parem	doc_681992022030_item	2809768	et	4	main
tööd	doc_681992022030_item	2809769	et	4	main
õppima	doc_681992022030_item	2809776	et	3	main
noormehega	doc_681992022030_item	2809802	et	3	main
et	doc_681992022031_item	2809811	et	3	main
mulle	doc_681992022031_item	2809832	et	4	main
see	doc_681992022031_item	2809833	et	3	main
meeldib	doc_681992022031_item	2809834	et	3	main
kui	doc_681992022031_item	2809835	et	3	main
õppisin	doc_681992022031_item	2809836	et	3	main
koolis	doc_681992022031_item	2809837	et	4	main
siis	doc_681992022031_item	2809838	et	3	main
käisin	doc_681992022031_item	2809839	et	3	main
mitu	doc_681992022031_item	2809840	et	4	main
aastat	doc_681992022031_item	2809841	et	3	main
tantsuringis	doc_681992022031_item	2809842	et	3	main
kui	doc_681992022031_item	2809843	et	3	main
mul	doc_681992022031_item	2809844	et	3	main
midagi	doc_681992022031_item	2809856	et	4	main
ema	doc_681992022031_item	2809862	et	4	main
poole	doc_681992022031_item	2809863	et	4	main
inimene	doc_681992022031_item	2809869	et	3	main
sest	doc_681992022031_item	2809885	et	4	main
et	doc_681992022031_item	2809886	et	3	main
on	doc_681992022031_item	2809888	et	4	main
palju	doc_681992022031_item	2809893	et	4	main
palub	doc_681992022031_item	2809904	et	3	main
appi	doc_681992022031_item	2809906	et	4	main
aitan	doc_681992022031_item	2809909	et	3	main
aitan	doc_681992022031_item	2809913	et	3	main
sõbrad	doc_681992022031_item	2809929	et	3	main
looduses	doc_681992022031_item	2809945	et	4	main
on	doc_681992022031_item	2809948	et	4	main
kiire	doc_681992022031_item	2809954	et	4	main
essee	doc_681992022032_item	2809955	et	4	main
minu	doc_681992022032_item	2809956	et	3	main
nimi	doc_681992022032_item	2809957	et	3	main
on	doc_681992022032_item	2809958	et	4	main
eesnimi	doc_681992022032_item	2809959	et	3	main
ma	doc_681992022032_item	2809960	et	3	main
veel	doc_681992022032_item	2809963	et	4	main
on	doc_681992022032_item	2809984	et	4	main
tumedad	doc_681992022032_item	2809985	et	3	main
aga	doc_681992022032_item	2809986	et	3	main
silman	doc_681992022032_item	2809987	et	3	main
meil	doc_681992022032_item	2809995	et	4	main
abikaasaga	doc_681992022032_item	2809999	et	3	main
kõigest	doc_681992022032_item	2810006	et	4	main
abivalmis	doc_681992022032_item	2810018	et	3	main
enam	doc_681992022032_item	2810020	et	4	main
ma	doc_681992022032_item	2810021	et	3	main
ei	doc_681992022033_item	2810041	et	4	main
armasta	doc_681992022033_item	2810042	et	4	main
minu	doc_681992022029_item	2809562	et	3	main
tuju	doc_681992022029_item	2809563	et	4	main
muutub	doc_681992022029_item	2809564	et	3	main
liiga	doc_681992022029_item	2809565	et	4	main
mulle	doc_681992022029_item	2809602	et	4	main
nende	doc_681992022029_item	2809605	et	4	main
palun	doc_681992022029_item	2809617	et	3	main
mull	doc_681992022029_item	2809596	et	3	main
kodus	doc_681992022029_item	2809598	et	4	main
palju	doc_681992022029_item	2809599	et	4	main
dekoratiivseid	doc_681992022029_item	2809600	et	3	main
ma	doc_681992022029_item	2809616	et	3	main
mulle	doc_681992022029_item	2809624	et	4	main
on	doc_681992022029_item	2809626	et	4	main
ja	doc_681992022029_item	2809628	et	3	main
nad	doc_681992022029_item	2809629	et	3	main
teavad	doc_681992022029_item	2809630	et	3	main
aitavad	doc_681992022029_item	2809641	et	4	main
teine	doc_681992022029_item	2809642	et	3	main
teisele	doc_681992022029_item	2809643	et	4	main
ma	doc_681992022029_item	2809651	et	3	main
kõik	doc_681992022029_item	2809658	et	4	main
ma	doc_681992022029_item	2809672	et	3	main
tean	doc_681992022029_item	2809673	et	3	main
et	doc_681992022029_item	2809674	et	3	main
minu	doc_681992022029_item	2809675	et	3	main
sõbrad	doc_681992022029_item	2809676	et	3	main
kui	doc_681992022029_item	2809680	et	3	main
ja	doc_681992022029_item	2809683	et	3	main
jäoks	doc_681992022029_item	2809689	et	4	main
ma	doc_681992022029_item	2809690	et	3	main
arvan	doc_681992022029_item	2809691	et	3	main
et	doc_681992022029_item	2809692	et	3	main
head	doc_681992022029_item	2809693	et	4	main
vahel	doc_681992022029_item	2809722	et	4	main
jään	doc_681992022029_item	2809723	et	3	main
kodus	doc_681992022029_item	2809724	et	4	main
on	doc_681992022030_item	2809733	et	4	main
eesnimi	doc_681992022030_item	2809734	et	3	main
ma	doc_681992022030_item	2809735	et	3	main
olen	doc_681992022030_item	2809736	et	3	main
aastat	doc_681992022030_item	2809738	et	3	main
õpin	doc_681992022030_item	2809742	et	3	main
ma	doc_681992022030_item	2809748	et	3	main
olin	doc_681992022030_item	2809752	et	3	main
sest	doc_681992022030_item	2809758	et	4	main
suurema	doc_681992022030_item	2809770	et	4	main
olen	doc_681992022030_item	2809778	et	3	main
rahulik	doc_681992022030_item	2809782	et	3	main
mulle	doc_681992022030_item	2809784	et	4	main
lugeda	doc_681992022030_item	2809786	et	3	main
mul	doc_681992022030_item	2809789	et	3	main
ma	doc_681992022030_item	2809797	et	3	main
elan	doc_681992022030_item	2809798	et	3	main
koos	doc_681992022030_item	2809800	et	4	main
oma	doc_681992022030_item	2809801	et	4	main
mina	doc_681992022031_item	2809804	et	4	main
alati	doc_681992022031_item	2809806	et	4	main
meeldib	doc_681992022031_item	2809821	et	3	main
koos	doc_681992022031_item	2809825	et	4	main
ma	doc_681992022031_item	2809855	et	3	main
saamiseks	doc_681992022031_item	2809859	et	4	main
ma	doc_681992022031_item	2809860	et	3	main
kõige	doc_681992022031_item	2809867	et	4	main
lähedane	doc_681992022031_item	2809868	et	3	main
mulle	doc_681992022031_item	2809882	et	4	main
sõbru	doc_681992022031_item	2809894	et	4	main
ma	doc_681992022031_item	2809896	et	3	main
tähistan	doc_681992022031_item	2809897	et	3	main
sõpradega	doc_681992022031_item	2809899	et	3	main
kui	doc_681992022031_item	2809901	et	3	main
mind	doc_681992022031_item	2809905	et	4	main
ma	doc_681992022031_item	2809908	et	3	main
kindlasti	doc_681992022031_item	2809910	et	3	main
aita	doc_681992022031_item	2809921	et	4	main
olukordi	doc_681992022031_item	2809923	et	4	main
iseloomuga	doc_681992022031_item	2809932	et	3	main
inimesed	doc_681992022031_item	2809933	et	3	main
kui	doc_681992022031_item	2809934	et	3	main
mul	doc_681992022031_item	2809935	et	3	main
selliseid	doc_681992022031_item	2809946	et	4	main
ei	doc_681992022032_item	2809961	et	4	main
on	doc_681992022032_item	2809988	et	4	main
pruunid	doc_681992022032_item	2809989	et	3	main
ma	doc_681992022032_item	2809990	et	3	main
olen	doc_681992022032_item	2809991	et	3	main
abielus	doc_681992022032_item	2809992	et	4	main
maja	doc_681992022032_item	2810003	et	4	main
meeldib	doc_681992022032_item	2810005	et	3	main
kodus	doc_681992022032_item	2810008	et	4	main
seda	doc_681992022029_item	2809632	et	3	main
kui	doc_681992022029_item	2809644	et	3	main
mu	doc_681992022029_item	2809645	et	3	main
heal	doc_681992022029_item	2809646	et	3	main
tuttaval	doc_681992022029_item	2809647	et	4	main
teda	doc_681992022029_item	2809653	et	4	main
sünnipäevad	doc_681992022029_item	2809656	et	3	main
kallimad	doc_681992022029_item	2809659	et	4	main
kui	doc_681992022029_item	2809662	et	3	main
palub	doc_681992022029_item	2809665	et	3	main
aitavad	doc_681992022029_item	2809678	et	4	main
ma	doc_681992022029_item	2809684	et	3	main
ka	doc_681992022029_item	2809687	et	3	main
aitavad	doc_681992022029_item	2809696	et	4	main
teine	doc_681992022029_item	2809697	et	3	main
teist	doc_681992022029_item	2809698	et	4	main
kui	doc_681992022029_item	2809699	et	3	main
on	doc_681992022029_item	2809700	et	4	main
vaja	doc_681992022029_item	2809701	et	4	main
kui	doc_681992022029_item	2809702	et	3	main
mul	doc_681992022029_item	2809703	et	3	main
ei	doc_681992022029_item	2809704	et	4	main
ole	doc_681992022029_item	2809705	et	4	main
mingeid	doc_681992022029_item	2809706	et	3	main
kohustusi	doc_681992022029_item	2809707	et	4	main
siis	doc_681992022029_item	2809708	et	3	main
ma	doc_681992022029_item	2809709	et	3	main
kuulan	doc_681992022029_item	2809710	et	3	main
muusikat	doc_681992022029_item	2809711	et	3	main
või	doc_681992022029_item	2809712	et	4	main
kohtun	doc_681992022029_item	2809713	et	3	main
sugulastega	doc_681992022029_item	2809714	et	4	main
ja	doc_681992022029_item	2809715	et	3	main
sõpradega	doc_681992022029_item	2809716	et	3	main
tihti	doc_681992022029_item	2809717	et	3	main
ma	doc_681992022029_item	2809718	et	3	main
sõidan	doc_681992022029_item	2809719	et	3	main
vanaema	doc_681992022029_item	2809720	et	4	main
külla	doc_681992022029_item	2809721	et	4	main
essee	doc_681992022030_item	2809730	et	4	main
minu	doc_681992022030_item	2809731	et	3	main
nimi	doc_681992022030_item	2809732	et	3	main
johvi	doc_681992022030_item	2809743	et	4	main
aga	doc_681992022030_item	2809746	et	3	main
kohvikus	doc_681992022030_item	2809750	et	3	main
mulle	doc_681992022030_item	2809754	et	4	main
et	doc_681992022030_item	2809759	et	3	main
suhtelda	doc_681992022030_item	2809762	et	4	main
veel	doc_681992022030_item	2809767	et	4	main
jaoks	doc_681992022030_item	2809773	et	4	main
ma	doc_681992022030_item	2809774	et	3	main
läksin	doc_681992022030_item	2809775	et	3	main
aus	doc_681992022030_item	2809779	et	4	main
ja	doc_681992022030_item	2809781	et	3	main
inimene	doc_681992022030_item	2809783	et	3	main
ja	doc_681992022030_item	2809787	et	3	main
on	doc_681992022030_item	2809790	et	4	main
keskmine	doc_681992022030_item	2809791	et	3	main
kasv	doc_681992022030_item	2809792	et	3	main
huvitav	doc_681992022029_item	2809728	et	4	main
tegevust	doc_681992022029_item	2809729	et	4	main
ma	doc_681992022030_item	2809741	et	3	main
keskus	doc_681992022030_item	2809745	et	3	main
tööd	doc_681992022030_item	2809757	et	4	main
tahan	doc_681992022030_item	2809766	et	3	main
ma	doc_681992022030_item	2809777	et	3	main
lojaalne	doc_681992022030_item	2809780	et	3	main
meeldib	doc_681992022030_item	2809785	et	3	main
tantsida	doc_681992022030_item	2809788	et	3	main
silmad	doc_681992022030_item	2809796	et	4	main
lõbus	doc_681992022031_item	2809807	et	4	main
teen	doc_681992022031_item	2809817	et	3	main
tihti	doc_681992022031_item	2809818	et	3	main
nalja	doc_681992022031_item	2809819	et	4	main
mulle	doc_681992022031_item	2809820	et	4	main
laupäeviti	doc_681992022031_item	2809823	et	4	main
pingelises	doc_681992022031_item	2809851	et	4	main
olukorras	doc_681992022031_item	2809852	et	3	main
teha	doc_681992022031_item	2809857	et	3	main
sest	doc_681992022031_item	2809864	et	4	main
ema	doc_681992022031_item	2809865	et	4	main
kui	doc_681992022031_item	2809870	et	3	main
on	doc_681992022031_item	2809874	et	4	main
ma	doc_681992022031_item	2809877	et	3	main
ostan	doc_681992022031_item	2809878	et	3	main
lille	doc_681992022031_item	2809879	et	4	main
sünnipäevad	doc_681992022031_item	2809884	et	3	main
sünnipäevad	doc_681992022031_item	2809887	et	3	main
lõbusad	doc_681992022031_item	2809889	et	3	main
ja	doc_681992022031_item	2809895	et	3	main
tihti	doc_681992022031_item	2809898	et	3	main
sünnipäeva	doc_681992022031_item	2809900	et	4	main
sõber	doc_681992022031_item	2809903	et	3	main
siis	doc_681992022031_item	2809907	et	3	main
tumedad	doc_681992022030_item	2809793	et	3	main
juuksed	doc_681992022030_item	2809794	et	3	main
inimene	doc_681992022031_item	2809808	et	3	main
tähendab	doc_681992022031_item	2809810	et	3	main
mul	doc_681992022031_item	2809812	et	3	main
käin	doc_681992022031_item	2809824	et	3	main
diskole	doc_681992022031_item	2809827	et	4	main
ma	doc_681992022031_item	2809828	et	3	main
käin	doc_681992022031_item	2809829	et	3	main
tantsida	doc_681992022031_item	2809830	et	3	main
sest	doc_681992022031_item	2809831	et	4	main
pingeline	doc_681992022031_item	2809846	et	4	main
olukord	doc_681992022031_item	2809847	et	3	main
siis	doc_681992022031_item	2809848	et	3	main
ma	doc_681992022031_item	2809849	et	3	main
pabistan	doc_681992022031_item	2809850	et	3	main
saa	doc_681992022031_item	2809854	et	4	main
abi	doc_681992022031_item	2809858	et	4	main
pöördun	doc_681992022031_item	2809861	et	3	main
on	doc_681992022031_item	2809866	et	4	main
heal	doc_681992022031_item	2809872	et	3	main
tuttaval	doc_681992022031_item	2809873	et	4	main
sünnipäev	doc_681992022031_item	2809875	et	3	main
siis	doc_681992022031_item	2809876	et	3	main
meeldivad	doc_681992022031_item	2809883	et	4	main
peod	doc_681992022031_item	2809890	et	4	main
mu	doc_681992022031_item	2809902	et	3	main
ma	doc_681992022031_item	2809912	et	3	main
sõbra	doc_681992022031_item	2809914	et	3	main
selliseid	doc_681992022031_item	2809922	et	4	main
juhtub	doc_681992022031_item	2809924	et	3	main
harva	doc_681992022031_item	2809925	et	4	main
on	doc_681992022031_item	2809953	et	4	main
lapsi	doc_681992022032_item	2809994	et	4	main
me	doc_681992022032_item	2810000	et	4	main
meie	doc_681992022032_item	2810002	et	4	main
loomad	doc_681992022032_item	2810007	et	3	main
mul	doc_681992022032_item	2810009	et	3	main
on	doc_681992022032_item	2810010	et	4	main
koer	doc_681992022032_item	2810011	et	3	main
kass	doc_681992022032_item	2810012	et	3	main
ja	doc_681992022032_item	2810013	et	3	main
hindan	doc_681992022032_item	2810022	et	3	main
ausust	doc_681992022032_item	2810024	et	4	main
siirust	doc_681992022032_item	2810026	et	4	main
võin	doc_681992022032_item	2810027	et	3	main
väikest	doc_681992022032_item	2810030	et	4	main
essee	doc_681992022033_item	2810032	et	4	main
mulle	doc_681992022033_item	2810047	et	4	main
inimestega	doc_681992022033_item	2810051	et	3	main
meeldib	doc_681992022033_item	2810053	et	3	main
oma	doc_681992022033_item	2810057	et	4	main
koeraga	doc_681992022033_item	2810058	et	3	main
aias	doc_681992022033_item	2810059	et	4	main
ja	doc_681992022033_item	2810060	et	3	main
mängida	doc_681992022033_item	2810061	et	3	main
temaga	doc_681992022033_item	2810062	et	3	main
eriti	doc_681992022033_item	2810082	et	3	main
mu	doc_681992022033_item	2810085	et	3	main
ma	doc_681992022033_item	2810091	et	3	main
ostan	doc_681992022033_item	2810092	et	3	main
ja	doc_681992022033_item	2810096	et	3	main
kui	doc_681992022033_item	2810099	et	3	main
mind	doc_681992022033_item	2810103	et	4	main
appi	doc_681992022033_item	2810104	et	4	main
siis	doc_681992022033_item	2810105	et	3	main
teda	doc_681992022033_item	2810108	et	4	main
ma	doc_681992022033_item	2810110	et	3	main
sõbrad	doc_681992022033_item	2810113	et	3	main
ja	doc_681992022033_item	2810133	et	3	main
magan	doc_681992022033_item	2810134	et	3	main
hetki	doc_681992022033_item	2810137	et	4	main
mitte	doc_681992022033_item	2810139	et	3	main
tihti	doc_681992022033_item	2810140	et	3	main
sest	doc_681992022033_item	2810141	et	4	main
ma	doc_681992022033_item	2810142	et	3	main
diskole	doc_681992022034_item	2810175	et	4	main
targat	doc_681992022034_item	2810212	et	4	main
tuttaval	doc_681992022034_item	2810229	et	4	main
on	doc_681992022034_item	2810230	et	4	main
ma	doc_681992022034_item	2810233	et	3	main
kingin	doc_681992022034_item	2810234	et	3	main
tantsida	doc_681992022031_item	2809822	et	3	main
sõpradega	doc_681992022031_item	2809826	et	3	main
on	doc_681992022031_item	2809845	et	4	main
ei	doc_681992022031_item	2809853	et	4	main
mu	doc_681992022031_item	2809871	et	3	main
ja	doc_681992022031_item	2809880	et	3	main
kingitusi	doc_681992022031_item	2809881	et	4	main
mul	doc_681992022031_item	2809891	et	3	main
on	doc_681992022031_item	2809892	et	4	main
teda	doc_681992022031_item	2809911	et	4	main
kes	doc_681992022031_item	2809915	et	4	main
aitab	doc_681992022031_item	2809916	et	3	main
teda	doc_681992022031_item	2809917	et	4	main
kui	doc_681992022031_item	2809918	et	3	main
ma	doc_681992022031_item	2809919	et	3	main
ei	doc_681992022031_item	2809920	et	4	main
sest	doc_681992022031_item	2809926	et	4	main
et	doc_681992022031_item	2809927	et	3	main
on	doc_681992022031_item	2809930	et	4	main
tugeva	doc_681992022031_item	2809931	et	4	main
ei	doc_681992022031_item	2809936	et	4	main
ole	doc_681992022031_item	2809937	et	4	main
mingeid	doc_681992022031_item	2809938	et	3	main
kohustisi	doc_681992022031_item	2809939	et	3	main
siis	doc_681992022031_item	2809940	et	3	main
ma	doc_681992022031_item	2809941	et	3	main
magan	doc_681992022031_item	2809942	et	3	main
sest	doc_681992022031_item	2809950	et	4	main
et	doc_681992022031_item	2809951	et	3	main
ole	doc_681992022032_item	2809962	et	4	main
kuid	doc_681992022032_item	2809993	et	4	main
ole	doc_681992022032_item	2809997	et	4	main
ehitame	doc_681992022032_item	2810001	et	3	main
mulle	doc_681992022032_item	2810004	et	4	main
rahulik	doc_681992022032_item	2810017	et	3	main
minu	doc_681992022031_item	2809928	et	3	main
või	doc_681992022031_item	2809943	et	4	main
sõidan	doc_681992022031_item	2809944	et	3	main
hetki	doc_681992022031_item	2809947	et	4	main
harva	doc_681992022031_item	2809949	et	4	main
elu	doc_681992022031_item	2809952	et	4	main
olen	doc_681992022032_item	2809965	et	3	main
kahehümnene	doc_681992022032_item	2809964	et	4	main
sündinud	doc_681992022032_item	2809966	et	4	main
tallinnas	doc_681992022032_item	2809967	et	4	main
aga	doc_681992022032_item	2809968	et	3	main
elan	doc_681992022032_item	2809969	et	3	main
kiviõlis	doc_681992022032_item	2809970	et	4	main
mina	doc_681992022032_item	2809971	et	4	main
olen	doc_681992022032_item	2809972	et	3	main
venelane	doc_681992022032_item	2809973	et	3	main
minu	doc_681992022032_item	2809974	et	3	main
kodakondsus	doc_681992022032_item	2809975	et	3	main
on	doc_681992022032_item	2809976	et	4	main
eesti	doc_681992022032_item	2809977	et	4	main
ma	doc_681992022032_item	2809978	et	3	main
olen	doc_681992022032_item	2809979	et	3	main
keskmist	doc_681992022032_item	2809980	et	3	main
kasvu	doc_681992022032_item	2809981	et	4	main
minu	doc_681992022032_item	2809982	et	3	main
juuksed	doc_681992022032_item	2809983	et	3	main
ei	doc_681992022032_item	2809996	et	4	main
koos	doc_681992022032_item	2809998	et	4	main
hiir	doc_681992022032_item	2810014	et	4	main
kõige	doc_681992022032_item	2810019	et	4	main
inimestes	doc_681992022032_item	2810023	et	3	main
inimestele	doc_681992022032_item	2810029	et	3	main
riielda	doc_681992022033_item	2810044	et	4	main
ja	doc_681992022033_item	2810045	et	3	main
vaielda	doc_681992022033_item	2810046	et	4	main
tutvuda	doc_681992022033_item	2810049	et	3	main
mind	doc_681992022033_item	2810080	et	4	main
rahuldab	doc_681992022033_item	2810081	et	3	main
kui	doc_681992022033_item	2810084	et	3	main
heal	doc_681992022033_item	2810086	et	3	main
sünnipäev	doc_681992022033_item	2810089	et	3	main
kingitus	doc_681992022033_item	2810093	et	4	main
õnnitlema	doc_681992022033_item	2810098	et	3	main
sõber	doc_681992022033_item	2810101	et	3	main
palub	doc_681992022033_item	2810102	et	3	main
ma	doc_681992022033_item	2810106	et	3	main
arvan	doc_681992022033_item	2810111	et	3	main
peavad	doc_681992022033_item	2810114	et	4	main
aitama	doc_681992022033_item	2810116	et	3	main
aga	doc_681992022033_item	2810117	et	3	main
selline	doc_681992022033_item	2810118	et	4	main
olukord	doc_681992022033_item	2810119	et	3	main
juhtub	doc_681992022033_item	2810120	et	3	main
mina	doc_681992022032_item	2810015	et	4	main
olen	doc_681992022032_item	2810016	et	3	main
kavalust	doc_681992022032_item	2810031	et	4	main
ma	doc_681992022033_item	2810033	et	3	main
olen	doc_681992022033_item	2810034	et	3	main
uue	doc_681992022033_item	2810050	et	3	main
iga	doc_681992022033_item	2810054	et	4	main
päev	doc_681992022033_item	2810055	et	3	main
jalutada	doc_681992022033_item	2810056	et	3	main
loendamine	doc_681992022033_item	2810079	et	4	main
detektiivid	doc_681992022033_item	2810083	et	3	main
tuttaval	doc_681992022033_item	2810087	et	4	main
tordi	doc_681992022033_item	2810094	et	3	main
lilled	doc_681992022033_item	2810095	et	3	main
lähen	doc_681992022033_item	2810097	et	3	main
tingimata	doc_681992022033_item	2810107	et	4	main
aitan	doc_681992022033_item	2810109	et	3	main
et	doc_681992022033_item	2810112	et	3	main
harva	doc_681992022033_item	2810121	et	4	main
ole	doc_681992022033_item	2810125	et	4	main
mingeid	doc_681992022033_item	2810126	et	3	main
kohustusi	doc_681992022033_item	2810127	et	4	main
siis	doc_681992022033_item	2810128	et	3	main
ma	doc_681992022033_item	2810129	et	3	main
selliseid	doc_681992022033_item	2810136	et	4	main
on	doc_681992022033_item	2810138	et	4	main
töötavad	doc_681992022033_item	2810147	et	4	main
alati	doc_681992022034_item	2810151	et	4	main
ei	doc_681992022034_item	2810155	et	4	main
armasta	doc_681992022034_item	2810156	et	4	main
elurõõmus	doc_681992022034_item	2810160	et	4	main
huvitundev	doc_681992022034_item	2810162	et	3	main
õhtuti	doc_681992022034_item	2810167	et	3	main
inimesed	doc_681992022034_item	2810213	et	3	main
alati	doc_681992022034_item	2810223	et	4	main
mind	doc_681992022034_item	2810225	et	4	main
mu	doc_681992022034_item	2810227	et	3	main
kõik	doc_681992022034_item	2810247	et	4	main
üksteist	doc_681992022034_item	2810254	et	4	main
kui	doc_681992022034_item	2810255	et	3	main
mu	doc_681992022034_item	2810256	et	3	main
sõber	doc_681992022034_item	2810257	et	3	main
palub	doc_681992022034_item	2810258	et	3	main
mind	doc_681992022034_item	2810259	et	4	main
sest	doc_681992022034_item	2810269	et	4	main
et	doc_681992022034_item	2810270	et	3	main
talle	doc_681992022034_item	2810278	et	4	main
aitama	doc_681992022034_item	2810279	et	3	main
aega	doc_681992022034_item	2810318	et	4	main
headust	doc_681992022032_item	2810025	et	4	main
andestada	doc_681992022032_item	2810028	et	3	main
alati	doc_681992022033_item	2810035	et	4	main
rahulik	doc_681992022033_item	2810036	et	3	main
ja	doc_681992022033_item	2810037	et	3	main
sõbralik	doc_681992022033_item	2810038	et	3	main
inimene	doc_681992022033_item	2810039	et	3	main
ma	doc_681992022033_item	2810040	et	3	main
meeldib	doc_681992022033_item	2810048	et	3	main
mulle	doc_681992022033_item	2810052	et	4	main
meeldib	doc_681992022033_item	2810063	et	3	main
kuulda	doc_681992022033_item	2810064	et	4	main
muusikat	doc_681992022033_item	2810065	et	3	main
käia	doc_681992022033_item	2810066	et	4	main
teatris	doc_681992022033_item	2810067	et	3	main
kui	doc_681992022033_item	2810068	et	3	main
mul	doc_681992022033_item	2810069	et	3	main
on	doc_681992022033_item	2810070	et	4	main
pingeline	doc_681992022033_item	2810071	et	4	main
olukord	doc_681992022033_item	2810072	et	3	main
siis	doc_681992022033_item	2810073	et	3	main
ma	doc_681992022033_item	2810074	et	3	main
loen	doc_681992022033_item	2810075	et	3	main
raamatu	doc_681992022033_item	2810076	et	4	main
väga	doc_681992022033_item	2810043	et	3	main
on	doc_681992022033_item	2810088	et	4	main
mu	doc_681992022033_item	2810100	et	3	main
jalutan	doc_681992022033_item	2810130	et	3	main
õppin	doc_681992022033_item	2810143	et	4	main
ja	doc_681992022033_item	2810144	et	3	main
mu	doc_681992022033_item	2810145	et	3	main
essee	doc_681992022034_item	2810148	et	4	main
olen	doc_681992022034_item	2810150	et	3	main
rahulik	doc_681992022034_item	2810152	et	3	main
ma	doc_681992022034_item	2810154	et	3	main
inimestega	doc_681992022034_item	2810158	et	3	main
ja	doc_681992022034_item	2810161	et	3	main
mulle	doc_681992022034_item	2810164	et	4	main
meeldib	doc_681992022034_item	2810165	et	3	main
üksinda	doc_681992022034_item	2810168	et	4	main
meeldib	doc_681992022034_item	2810169	et	3	main
tantsida	doc_681992022034_item	2810170	et	3	main
ma	doc_681992022034_item	2810171	et	3	main
tantsin	doc_681992022034_item	2810172	et	3	main
kodus	doc_681992022034_item	2810173	et	4	main
lähen	doc_681992022034_item	2810174	et	3	main
sõbranna	doc_681992022034_item	2810208	et	4	main
ja	doc_681992022034_item	2810214	et	3	main
vaatan	doc_681992022033_item	2810077	et	3	main
telerit	doc_681992022033_item	2810078	et	3	main
siis	doc_681992022033_item	2810090	et	3	main
teineteist	doc_681992022033_item	2810115	et	4	main
kui	doc_681992022033_item	2810122	et	3	main
ei	doc_681992022033_item	2810124	et	4	main
puhkan	doc_681992022033_item	2810132	et	3	main
aga	doc_681992022033_item	2810135	et	3	main
ma	doc_681992022034_item	2810149	et	3	main
vaielda	doc_681992022034_item	2810157	et	4	main
inimene	doc_681992022034_item	2810163	et	3	main
lugeda	doc_681992022034_item	2810166	et	3	main
on	doc_681992022034_item	2810211	et	4	main
olla	doc_681992022034_item	2810216	et	3	main
olid	doc_681992022034_item	2810218	et	4	main
olukorras	doc_681992022034_item	2810220	et	3	main
minu	doc_681992022034_item	2810221	et	3	main
aitab	doc_681992022034_item	2810224	et	3	main
kui	doc_681992022034_item	2810226	et	3	main
lilleid	doc_681992022034_item	2810238	et	4	main
sünnad	doc_681992022034_item	2810241	et	4	main
me	doc_681992022034_item	2810244	et	4	main
appi	doc_681992022034_item	2810260	et	4	main
minu	doc_681992022034_item	2810271	et	3	main
sõber	doc_681992022034_item	2810272	et	3	main
palub	doc_681992022034_item	2810273	et	3	main
mind	doc_681992022034_item	2810274	et	4	main
appi	doc_681992022034_item	2810275	et	4	main
pean	doc_681992022034_item	2810277	et	4	main
vaba	doc_681992022034_item	2810317	et	4	main
ma	doc_681992022034_item	2810321	et	3	main
tegen	doc_681992022034_item	2810324	et	4	main
tahat	doc_681992022035_item	2810328	et	4	main
või	doc_681992022035_item	2810337	et	4	main
küsida	doc_681992022035_item	2810338	et	3	main
kui	doc_681992022035_item	2810339	et	3	main
probleem	doc_681992022035_item	2810342	et	3	main
elus	doc_681992022035_item	2810344	et	4	main
kooli	doc_681992022035_item	2810350	et	4	main
peab	doc_681992022035_item	2810352	et	4	main
erinevaid	doc_681992022035_item	2810354	et	4	main
ärge	doc_681992022035_item	2810364	et	3	main
unustage	doc_681992022035_item	2810365	et	3	main
oma	doc_681992022035_item	2810366	et	4	main
õppilastele	doc_681992022035_item	2810379	et	4	main
ja	doc_681992022035_item	2810381	et	3	main
suures	doc_681992022035_item	2810383	et	3	main
õpetaja	doc_681992022035_item	2810385	et	4	main
huvitavaid	doc_681992022035_item	2810393	et	4	main
asju	doc_681992022035_item	2810394	et	3	main
laia	doc_681992022035_item	2810395	et	4	main
et	doc_681992022035_item	2810399	et	3	main
tund	doc_681992022035_item	2810401	et	3	main
meile	doc_681992022035_item	2810403	et	4	main
heamelsed	doc_681992022035_item	2810408	et	4	main
targad	doc_681992022035_item	2810409	et	3	main
ja	doc_681992022035_item	2810410	et	3	main
seminaritöö	doc_685122975254_item	2810418	et	4	main
sissejuhatus	doc_685122975254_item	2810419	et	4	main
me	doc_685122975254_item	2810424	et	4	main
on	doc_685122975254_item	2810430	et	4	main
tea	doc_685122975254_item	2810438	et	4	main
oletada	doc_685122975254_item	2810442	et	3	main
muistsetest	doc_685122975254_item	2810456	et	3	main
räägivad	doc_685122975254_item	2810458	et	3	main
nende	doc_685122975254_item	2810466	et	4	main
maailmapildist	doc_685122975254_item	2810467	et	3	main
ja	doc_685122975254_item	2810469	et	3	main
suhetest	doc_685122975254_item	2810471	et	3	main
raamatutest	doc_685122975254_item	2810480	et	4	main
tõdeda	doc_685122975254_item	2810485	et	3	main
eesti	doc_685122975254_item	2810487	et	4	main
tema	doc_685122975254_item	2810521	et	4	main
kuulus	doc_685122975254_item	2810523	et	4	main
ta	doc_685122975254_item	2810548	et	4	main
kõigist	doc_685122975254_item	2810556	et	4	main
seniajani	doc_685122975254_item	2810557	et	3	main
koha	doc_685122975254_item	2810566	et	4	main
kus	doc_685122975254_item	2810567	et	3	main
lääne-euroopa	doc_685122975254_item	2810572	et	4	main
ajaloolasi	doc_685122975254_item	2810573	et	3	main
on	doc_685122975254_item	2810574	et	4	main
mul	doc_681992022033_item	2810123	et	3	main
sõbradega	doc_681992022033_item	2810131	et	4	main
sõbrad	doc_681992022033_item	2810146	et	3	main
inimene	doc_681992022034_item	2810153	et	3	main
olen	doc_681992022034_item	2810159	et	3	main
sõbrannadega	doc_681992022034_item	2810176	et	3	main
no	doc_681992022034_item	2810177	et	3	main
mitte	doc_681992022034_item	2810178	et	3	main
nii	doc_681992022034_item	2810179	et	3	main
tihti	doc_681992022034_item	2810180	et	3	main
kui	doc_681992022034_item	2810181	et	3	main
tahaks	doc_681992022034_item	2810182	et	3	main
ja	doc_681992022034_item	2810184	et	3	main
lugemine	doc_681992022034_item	2810183	et	4	main
tantsimine	doc_681992022034_item	2810185	et	4	main
aitavad	doc_681992022034_item	2810186	et	4	main
mul	doc_681992022034_item	2810187	et	3	main
lõõgastuda	doc_681992022034_item	2810188	et	3	main
ning	doc_681992022034_item	2810189	et	3	main
tõstavad	doc_681992022034_item	2810190	et	3	main
meeleolu	doc_681992022034_item	2810191	et	4	main
kui	doc_681992022034_item	2810192	et	3	main
mul	doc_681992022034_item	2810193	et	3	main
on	doc_681992022034_item	2810194	et	4	main
pingeline	doc_681992022034_item	2810195	et	4	main
olukord	doc_681992022034_item	2810196	et	3	main
siis	doc_681992022034_item	2810197	et	3	main
ma	doc_681992022034_item	2810198	et	3	main
küsin	doc_681992022034_item	2810199	et	3	main
nõu	doc_681992022034_item	2810200	et	4	main
mina	doc_681992022034_item	2810201	et	4	main
pöördan	doc_681992022034_item	2810202	et	4	main
oma	doc_681992022034_item	2810203	et	4	main
ema	doc_681992022034_item	2810204	et	4	main
poole	doc_681992022034_item	2810205	et	4	main
ja	doc_681992022034_item	2810206	et	3	main
lähedase	doc_681992022034_item	2810207	et	3	main
poole	doc_681992022034_item	2810209	et	4	main
nad	doc_681992022034_item	2810210	et	3	main
võib	doc_681992022034_item	2810215	et	3	main
nad	doc_681992022034_item	2810217	et	3	main
samasuguses	doc_681992022034_item	2810219	et	3	main
heal	doc_681992022034_item	2810228	et	3	main
sünnipäev	doc_681992022034_item	2810231	et	3	main
siis	doc_681992022034_item	2810232	et	3	main
mulle	doc_681992022034_item	2810239	et	4	main
tavalisedes	doc_681992022034_item	2810249	et	4	main
päevades	doc_681992022034_item	2810250	et	3	main
me	doc_681992022034_item	2810251	et	4	main
siis	doc_681992022034_item	2810261	et	3	main
ma	doc_681992022034_item	2810262	et	3	main
muidugi	doc_681992022034_item	2810263	et	4	main
aitan	doc_681992022034_item	2810264	et	3	main
hea	doc_681992022035_item	2810329	et	4	main
on	doc_681992022035_item	2810340	et	4	main
isiklikus	doc_681992022035_item	2810343	et	4	main
siis	doc_681992022035_item	2810345	et	3	main
selle	doc_681992022035_item	2810349	et	4	main
õpetajad	doc_681992022035_item	2810369	et	4	main
ma	doc_681992022035_item	2810370	et	3	main
või	doc_681992022035_item	2810375	et	4	main
liiderik	doc_681992022035_item	2810376	et	4	main
et	doc_681992022035_item	2810377	et	3	main
rohkem	doc_681992022035_item	2810392	et	4	main
teile	doc_681992022035_item	2810400	et	4	main
meeldib	doc_681992022035_item	2810402	et	3	main
oleme	doc_685122975254_item	2810422	et	3	main
esivanemad	doc_685122975254_item	2810429	et	4	main
enamuse	doc_685122975254_item	2810443	et	4	main
arheoloogia	doc_685122975254_item	2810447	et	4	main
välja	doc_685122975254_item	2810448	et	4	main
eluolust	doc_685122975254_item	2810460	et	3	main
omavahelistest	doc_685122975254_item	2810470	et	4	main
teada	doc_685122975254_item	2810476	et	3	main
kroonikatest	doc_685122975254_item	2810478	et	4	main
eepostest	doc_685122975254_item	2810482	et	3	main
palju	doc_685122975254_item	2810493	et	4	main
maailmameri	doc_685122975254_item	2810522	et	3	main
320	doc_685122975254_item	2810533	et	2	main
ette	doc_685122975254_item	2810537	et	4	main
põhja	doc_685122975254_item	2810540	et	4	main
külastada	doc_685122975254_item	2810542	et	3	main
thule	doc_685122975254_item	2810544	et	4	main
maad	doc_685122975254_item	2810545	et	4	main
reisist	doc_685122975254_item	2810546	et	3	main
kirjutas	doc_685122975254_item	2810547	et	3	main
raamatu	doc_685122975254_item	2810549	et	4	main
olev	doc_685122975254_item	2810553	et	4	main
tuttavatest	doc_685122975254_item	2810558	et	4	main
kaugemal	doc_685122975254_item	2810560	et	4	main
näidanud	doc_685122975254_item	2810562	et	4	main
kohalikud	doc_685122975254_item	2810563	et	3	main
talle	doc_685122975254_item	2810564	et	4	main
mõned	doc_685122975254_item	2810582	et	3	main
tegu	doc_685122975254_item	2810591	et	4	main
võis	doc_685122975254_item	2810606	et	4	main
meteoriidi	doc_685122975254_item	2810607	et	3	main
ema	doc_681992022034_item	2810222	et	4	main
kingitust	doc_681992022034_item	2810236	et	4	main
ja	doc_681992022034_item	2810237	et	3	main
meeldivad	doc_681992022034_item	2810240	et	4	main
sest	doc_681992022034_item	2810242	et	4	main
et	doc_681992022034_item	2810243	et	3	main
koos	doc_681992022034_item	2810248	et	4	main
appi	doc_681992022034_item	2810268	et	4	main
kui	doc_681992022034_item	2810280	et	3	main
mul	doc_681992022034_item	2810281	et	3	main
on	doc_681992022034_item	2810282	et	4	main
võimalus	doc_681992022034_item	2810283	et	3	main
ja	doc_681992022034_item	2810284	et	3	main
kui	doc_681992022034_item	2810285	et	3	main
see	doc_681992022034_item	2810286	et	3	main
on	doc_681992022034_item	2810287	et	4	main
minu	doc_681992022034_item	2810288	et	3	main
võimuses	doc_681992022034_item	2810289	et	3	main
enneks	doc_681992022034_item	2810290	et	4	main
minu	doc_681992022034_item	2810291	et	3	main
sõbrad	doc_681992022034_item	2810292	et	3	main
harva	doc_681992022034_item	2810293	et	4	main
sattuvad	doc_681992022034_item	2810294	et	4	main
sellistesse	doc_681992022034_item	2810295	et	4	main
olukordadesse	doc_681992022034_item	2810296	et	3	main
kui	doc_681992022034_item	2810297	et	3	main
mul	doc_681992022034_item	2810298	et	3	main
ei	doc_681992022034_item	2810299	et	4	main
ole	doc_681992022034_item	2810300	et	4	main
mingeid	doc_681992022034_item	2810301	et	3	main
kohustusi	doc_681992022034_item	2810302	et	4	main
siis	doc_681992022034_item	2810303	et	3	main
ma	doc_681992022034_item	2810304	et	3	main
kuulan	doc_681992022034_item	2810305	et	3	main
muusikat	doc_681992022034_item	2810306	et	3	main
jalutan	doc_681992022034_item	2810307	et	3	main
istun	doc_681992022034_item	2810308	et	3	main
arvutitaga	doc_681992022034_item	2810309	et	3	main
suhtlen	doc_681992022034_item	2810310	et	3	main
oma	doc_681992022034_item	2810311	et	4	main
sõbradega	doc_681992022034_item	2810312	et	4	main
talle	doc_681992022034_item	2810235	et	4	main
saame	doc_681992022034_item	2810245	et	4	main
kokku	doc_681992022034_item	2810246	et	3	main
harva	doc_681992022034_item	2810252	et	4	main
näeme	doc_681992022034_item	2810253	et	3	main
t	doc_681992022034_item	2810265	et	4	main
ma	doc_681992022034_item	2810266	et	3	main
lähen	doc_681992022034_item	2810267	et	3	main
ma	doc_681992022034_item	2810276	et	3	main
on	doc_681992022034_item	2810315	et	4	main
vähe	doc_681992022034_item	2810316	et	3	main
ja	doc_681992022034_item	2810323	et	3	main
too	doc_681992022035_item	2810348	et	4	main
korraldama	doc_681992022035_item	2810353	et	3	main
lugupeetud	doc_681992022035_item	2810368	et	4	main
soovin	doc_681992022035_item	2810371	et	3	main
te	doc_681992022035_item	2810386	et	4	main
peate	doc_681992022035_item	2810387	et	4	main
olla	doc_681992022035_item	2810388	et	3	main
huvitavam	doc_681992022035_item	2810389	et	4	main
jutustage	doc_681992022035_item	2810390	et	3	main
meile	doc_681992022035_item	2810396	et	4	main
peavad	doc_681992022035_item	2810406	et	4	main
seminaritöö	doc_685122975254_item	2810413	et	4	main
esimesed	doc_685122975254_item	2810414	et	3	main
kirjalikud	doc_685122975254_item	2810415	et	3	main
eestlastest	doc_685122975254_item	2810417	et	4	main
kes	doc_685122975254_item	2810420	et	4	main
me	doc_685122975254_item	2810421	et	4	main
kust	doc_685122975254_item	2810423	et	4	main
tuleme	doc_685122975254_item	2810425	et	3	main
kes	doc_685122975254_item	2810426	et	4	main
palju	doc_685122975254_item	2810431	et	4	main
me	doc_685122975254_item	2810439	et	4	main
annab	doc_685122975254_item	2810445	et	3	main
kommetest	doc_685122975254_item	2810462	et	4	main
aga	doc_685122975254_item	2810463	et	3	main
inimestest	doc_685122975254_item	2810465	et	3	main
saame	doc_685122975254_item	2810475	et	4	main
ja	doc_685122975254_item	2810481	et	3	main
aga	doc_685122975254_item	2810484	et	3	main
pytheas	doc_685122975254_item	2810528	et	4	main
võttis	doc_685122975254_item	2810529	et	3	main
oletatavasti	doc_685122975254_item	2810530	et	3	main
reisi	doc_685122975254_item	2810538	et	4	main
arvamusel	doc_685122975254_item	2810575	et	3	main
asub	doc_685122975254_item	2810578	et	3	main
norra	doc_685122975254_item	2810579	et	4	main
rannikul	doc_685122975254_item	2810580	et	3	main
aga	doc_685122975254_item	2810581	et	3	main
on	doc_685122975254_item	2810592	et	4	main
ja	doc_685122975254_item	2810595	et	3	main
hõimult	doc_685122975254_item	2810621	et	3	main
seepärast	doc_685122975254_item	2810623	et	3	main
all	doc_685122975254_item	2810629	et	3	main
teoses	doc_685122975254_item	2810643	et	3	main
hõbevalge	doc_685122975254_item	2810644	et	4	main
2	doc_685122975254_item	2810645	et	2	main
mis	doc_685122975254_item	2810650	et	4	main
ja	doc_685122975254_item	2810671	et	3	main
balti	doc_685122975254_item	2810675	et	3	main
hõimud	doc_685122975254_item	2810676	et	4	main
et	doc_685122975254_item	2810682	et	3	main
fennide	doc_685122975254_item	2810689	et	4	main
kaugemale	doc_685122975254_item	2810708	et	4	main
seda	doc_685122975254_item	2810724	et	3	main
puhul	doc_685122975254_item	2810727	et	4	main
on	doc_685122975254_item	2810738	et	4	main
üks	doc_685122975254_item	2810739	et	3	main
ebamäärane	doc_685122975254_item	2810740	et	4	main
mööda	doc_685122975254_item	2810746	et	4	main
balti	doc_685122975254_item	2810747	et	3	main
võib	doc_685122975254_item	2810759	et	3	main
oletada	doc_685122975254_item	2810761	et	3	main
on	doc_685122975254_item	2810763	et	4	main
toob	doc_685122975254_item	2810773	et	3	main
nende	doc_685122975254_item	2810774	et	4	main
kirjeldamisel	doc_685122975254_item	2810776	et	4	main
keele	doc_685122975254_item	2810781	et	4	main
4	doc_685122975254_item	2810784	et	2	main
suhed	doc_685122975254_item	2810786	et	4	main
huvitasid	doc_685122975254_item	2810801	et	4	main
kahjuks	doc_681992022034_item	2810313	et	4	main
mul	doc_681992022034_item	2810314	et	3	main
sest	doc_681992022034_item	2810319	et	4	main
et	doc_681992022034_item	2810320	et	3	main
kodutööd	doc_681992022034_item	2810325	et	4	main
essee	doc_681992022035_item	2810326	et	4	main
kui	doc_681992022035_item	2810327	et	3	main
kammandage	doc_681992022035_item	2810334	et	4	main
parem	doc_681992022035_item	2810335	et	4	main
paluda	doc_681992022035_item	2810336	et	3	main
mingi	doc_681992022035_item	2810341	et	4	main
ta	doc_681992022035_item	2810346	et	4	main
ei	doc_681992022035_item	2810347	et	4	main
koolipäevad	doc_681992022035_item	2810367	et	3	main
teile	doc_681992022035_item	2810372	et	4	main
olla	doc_681992022035_item	2810373	et	3	main
organisaatorik	doc_681992022035_item	2810374	et	4	main
elada	doc_681992022035_item	2810382	et	3	main
meile	doc_681992022035_item	2810391	et	4	main
silmaringi	doc_681992022035_item	2810397	et	4	main
olema	doc_681992022035_item	2810407	et	4	main
teated	doc_685122975254_item	2810416	et	3	main
olid	doc_685122975254_item	2810427	et	4	main
küsimusi	doc_685122975254_item	2810432	et	4	main
aga	doc_685122975254_item	2810433	et	3	main
midagi	doc_685122975254_item	2810440	et	4	main
informatsioonist	doc_685122975254_item	2810444	et	3	main
meile	doc_685122975254_item	2810446	et	4	main
kaevatud	doc_685122975254_item	2810449	et	4	main
esemed	doc_685122975254_item	2810450	et	3	main
luustikud	doc_685122975254_item	2810451	et	3	main
ja	doc_685122975254_item	2810452	et	3	main
aegadest	doc_685122975254_item	2810457	et	3	main
ja	doc_685122975254_item	2810461	et	3	main
tuleb	doc_685122975254_item	2810483	et	3	main
et	doc_685122975254_item	2810486	et	3	main
ajaloo	doc_685122975254_item	2810489	et	4	main
kohta	doc_685122975254_item	2810490	et	4	main
pole	doc_685122975254_item	2810491	et	3	main
just	doc_685122975254_item	2810492	et	3	main
vanakreeka	doc_685122975254_item	2810524	et	4	main
meresõitja	doc_685122975254_item	2810525	et	4	main
ja	doc_685122975254_item	2810526	et	3	main
teadlane	doc_685122975254_item	2810527	et	3	main
ekr	doc_685122975254_item	2810536	et	4	main
et	doc_685122975254_item	2810541	et	3	main
salapärast	doc_685122975254_item	2810543	et	4	main
maailmameri	doc_685122975254_item	2810550	et	3	main
all	doc_685122975254_item	2810552	et	3	main
maa	doc_685122975254_item	2810554	et	4	main
asus	doc_685122975254_item	2810555	et	4	main
maadest	doc_685122975254_item	2810559	et	4	main
seal	doc_685122975254_item	2810561	et	4	main
päike	doc_685122975254_item	2810568	et	3	main
magama	doc_685122975254_item	2810569	et	3	main
heidab	doc_685122975254_item	2810570	et	3	main
enamik	doc_685122975254_item	2810571	et	3	main
eesti	doc_685122975254_item	2810583	et	4	main
ajaloolased	doc_685122975254_item	2810584	et	3	main
ja	doc_685122975254_item	2810585	et	3	main
arheoloogid	doc_685122975254_item	2810586	et	3	main
ei	doc_685122975254_item	2810587	et	4	main
saaremaa	doc_685122975254_item	2810594	et	4	main
kaaliga	doc_685122975254_item	2810596	et	3	main
meteoriidikraatri	doc_685122975254_item	2810598	et	3	main
vanuseks	doc_685122975254_item	2810599	et	4	main
hinnatakse	doc_685122975254_item	2810600	et	4	main
kuskil	doc_685122975254_item	2810601	et	3	main
2400	doc_685122975254_item	2810602	et	2	main
2800	doc_685122975254_item	2810603	et	2	main
aastat	doc_685122975254_item	2810604	et	3	main
pealtnägijatele	doc_685122975254_item	2810605	et	3	main
päikese	doc_685122975254_item	2810610	et	4	main
et	doc_685122975254_item	2810627	et	3	main
thule	doc_685122975254_item	2810628	et	4	main
saaremaad	doc_685122975254_item	2810632	et	4	main
seda	doc_685122975254_item	2810633	et	3	main
teooriat	doc_685122975254_item	2810634	et	3	main
ja	doc_685122975254_item	2810648	et	3	main
aestii	doc_685122975254_item	2810652	et	4	main
järel	doc_685122975254_item	2810665	et	4	main
õpin	doc_681992022034_item	2810322	et	3	main
suhtleja	doc_681992022035_item	2810330	et	4	main
olla	doc_681992022035_item	2810331	et	3	main
siis	doc_681992022035_item	2810332	et	3	main
ärge	doc_681992022035_item	2810333	et	3	main
ta	doc_681992022035_item	2810351	et	4	main
konkursse	doc_681992022035_item	2810355	et	3	main
ja	doc_681992022035_item	2810356	et	3	main
mängu	doc_681992022035_item	2810357	et	4	main
et	doc_681992022035_item	2810358	et	3	main
õpilastele	doc_681992022035_item	2810359	et	4	main
oli	doc_681992022035_item	2810360	et	3	main
huvitavam	doc_681992022035_item	2810361	et	4	main
tunnis	doc_681992022035_item	2810362	et	3	main
töötada	doc_681992022035_item	2810363	et	3	main
aidata	doc_681992022035_item	2810378	et	4	main
õppida	doc_681992022035_item	2810380	et	3	main
elus	doc_681992022035_item	2810384	et	4	main
sest	doc_681992022035_item	2810398	et	4	main
kõik	doc_681992022035_item	2810404	et	4	main
õpetajad	doc_681992022035_item	2810405	et	4	main
hea	doc_681992022035_item	2810411	et	4	main
suhtlejad	doc_681992022035_item	2810412	et	4	main
meie	doc_685122975254_item	2810428	et	4	main
vähe	doc_685122975254_item	2810434	et	3	main
vastuseid	doc_685122975254_item	2810435	et	3	main
kindlalt	doc_685122975254_item	2810436	et	4	main
ei	doc_685122975254_item	2810437	et	4	main
võime	doc_685122975254_item	2810441	et	4	main
asulakohad	doc_685122975254_item	2810453	et	4	main
kõnelevad	doc_685122975254_item	2810454	et	4	main
meile	doc_685122975254_item	2810455	et	4	main
meile	doc_685122975254_item	2810459	et	4	main
vaikib	doc_685122975254_item	2810464	et	3	main
keelest	doc_685122975254_item	2810468	et	4	main
keelest	doc_685122975254_item	2810472	et	4	main
ja	doc_685122975254_item	2810473	et	3	main
kultuurist	doc_685122975254_item	2810474	et	3	main
säilinud	doc_685122975254_item	2810477	et	4	main
kirjadest	doc_685122975254_item	2810479	et	3	main
varase	doc_685122975254_item	2810488	et	4	main
andmeid	doc_685122975254_item	2810494	et	3	main
leitud	doc_685122975254_item	2810495	et	4	main
tõenäoliselt	doc_685122975254_item	2810496	et	4	main
kõige	doc_685122975254_item	2810497	et	4	main
varasem	doc_685122975254_item	2810498	et	4	main
teade	doc_685122975254_item	2810499	et	4	main
eestlastest	doc_685122975254_item	2810500	et	4	main
pärineb	doc_685122975254_item	2810501	et	3	main
aastast	doc_685122975254_item	2810502	et	4	main
322	doc_685122975254_item	2810503	et	2	main
ema	doc_685122975254_item	2810504	et	4	main
aga	doc_685122975254_item	2810505	et	3	main
seegi	doc_685122975254_item	2810506	et	4	main
ei	doc_685122975254_item	2810507	et	4	main
ole	doc_685122975254_item	2810508	et	4	main
kindel	doc_685122975254_item	2810509	et	3	main
järgnevalt	doc_685122975254_item	2810510	et	4	main
annan	doc_685122975254_item	2810511	et	3	main
ülevaate	doc_685122975254_item	2810512	et	4	main
esimestest	doc_685122975254_item	2810513	et	4	main
kirjalikest	doc_685122975254_item	2810514	et	3	main
allikatest	doc_685122975254_item	2810515	et	4	main
eestlaste	doc_685122975254_item	2810516	et	4	main
kohta	doc_685122975254_item	2810517	et	4	main
1	doc_685122975254_item	2810518	et	2	main
pytheas	doc_685122975254_item	2810519	et	4	main
ja	doc_685122975254_item	2810520	et	3	main
350	doc_685122975254_item	2810531	et	2	main
ja	doc_685122975254_item	2810532	et	3	main
aasta	doc_685122975254_item	2810534	et	4	main
vahel	doc_685122975254_item	2810535	et	4	main
kaugele	doc_685122975254_item	2810539	et	4	main
kõne	doc_685122975254_item	2810551	et	4	main
kätte	doc_685122975254_item	2810565	et	4	main
et	doc_685122975254_item	2810576	et	3	main
thule	doc_685122975254_item	2810577	et	4	main
et	doc_685122975254_item	2810590	et	3	main
tunduda	doc_685122975254_item	2810609	et	3	main
langemisega	doc_685122975254_item	2810611	et	4	main
maale	doc_685122975254_item	2810612	et	4	main
ja	doc_685122975254_item	2810613	et	3	main
teade	doc_685122975254_item	2810614	et	4	main
sellest	doc_685122975254_item	2810615	et	4	main
sündmusest	doc_685122975254_item	2810616	et	4	main
levis	doc_685122975254_item	2810617	et	4	main
inimeselt	doc_685122975254_item	2810618	et	3	main
inimesele	doc_685122975254_item	2810619	et	3	main
ja	doc_685122975254_item	2810620	et	3	main
hõimule	doc_685122975254_item	2810622	et	3	main
on	doc_685122975254_item	2810624	et	4	main
võimalik	doc_685122975254_item	2810626	et	3	main
ilmunud	doc_685122975254_item	2810642	et	4	main
germania	doc_685122975254_item	2810647	et	4	main
all	doc_685122975254_item	2810653	et	3	main
eestlasi	doc_685122975254_item	2810655	et	3	main
idamere-suund	doc_685122975254_item	2810657	et	3	main
vaadatakse	doc_685122975254_item	2810660	et	3	main
visla	doc_685122975254_item	2810662	et	4	main
gootide	doc_685122975254_item	2810664	et	3	main
eestlased	doc_685122975254_item	2810677	et	3	main
aestii	doc_685122975254_item	2810683	et	4	main
hulka	doc_685122975254_item	2810684	et	4	main
aga	doc_685122975254_item	2810688	et	3	main
nende	doc_685122975254_item	2810693	et	4	main
geograafia	doc_685122975254_item	2810702	et	4	main
eripäraks	doc_685122975254_item	2810703	et	3	main
on	doc_685122975254_item	2810704	et	4	main
see	doc_685122975254_item	2810705	et	3	main
et	doc_685122975254_item	2810706	et	3	main
välista	doc_685122975254_item	2810588	et	4	main
võimalust	doc_685122975254_item	2810589	et	3	main
hoopiski	doc_685122975254_item	2810593	et	3	main
kaali	doc_685122975254_item	2810597	et	4	main
allakukkumine	doc_685122975254_item	2810608	et	3	main
oma	doc_685122975254_item	2810639	et	4	main
1976	doc_685122975254_item	2810640	et	2	main
aastal	doc_685122975254_item	2810641	et	3	main
nägemast	doc_685122975254_item	2810654	et	3	main
poolt	doc_685122975254_item	2810659	et	4	main
üle	doc_685122975254_item	2810661	et	3	main
tulevad	doc_685122975254_item	2810666	et	4	main
järgi	doc_685122975254_item	2810668	et	4	main
eellased	doc_685122975254_item	2810673	et	3	main
liiga	doc_685122975254_item	2810680	et	4	main
vaadata	doc_685122975254_item	2810687	et	4	main
siis	doc_685122975254_item	2810691	et	3	main
tacituse	doc_685122975254_item	2810699	et	4	main
aestii	doc_685122975254_item	2810700	et	4	main
antiikaja	doc_685122975254_item	2810701	et	3	main
nö	doc_685122975254_item	2810709	et	4	main
keskusest	doc_685122975254_item	2810710	et	4	main
vahemaad	doc_685122975254_item	2810714	et	4	main
ja	doc_685122975254_item	2810715	et	3	main
andmed	doc_685122975254_item	2810716	et	3	main
ning	doc_685122975254_item	2810717	et	3	main
seda	doc_685122975254_item	2810718	et	3	main
ettekujutus	doc_685122975254_item	2810721	et	4	main
näeme	doc_685122975254_item	2810723	et	3	main
kulgeb	doc_685122975254_item	2810743	et	3	main
miks	doc_685122975254_item	2810752	et	4	main
eestlased	doc_685122975254_item	2810754	et	3	main
tacitus	doc_685122975254_item	2810769	et	4	main
hõime	doc_685122975254_item	2810771	et	3	main
eripära	doc_685122975254_item	2810775	et	4	main
esile	doc_685122975254_item	2810777	et	3	main
asendi	doc_685122975254_item	2810779	et	3	main
sotsiaalsed	doc_685122975254_item	2810785	et	3	main
välimuse	doc_685122975254_item	2810787	et	3	main
on	doc_685122975254_item	2810792	et	4	main
erinevust	doc_685122975254_item	2810794	et	4	main
germaanlastest	doc_685122975254_item	2810795	et	3	main
peamiseks	doc_685122975254_item	2810796	et	3	main
põhjuseks	doc_685122975254_item	2810797	et	3	main
miks	doc_685122975254_item	2810798	et	4	main
balti	doc_685122975254_item	2810808	et	3	main
tuntud	doc_685122975254_item	2810813	et	4	main
aja	doc_685122975254_item	2810815	et	4	main
etruski	doc_685122975254_item	2810820	et	4	main
ka	doc_685122975254_item	2810625	et	3	main
mõeldakse	doc_685122975254_item	2810630	et	3	main
tõepoolest	doc_685122975254_item	2810631	et	3	main
toetab	doc_685122975254_item	2810635	et	3	main
ka	doc_685122975254_item	2810636	et	3	main
lennart	doc_685122975254_item	2810637	et	4	main
meri	doc_685122975254_item	2810638	et	3	main
tacitus	doc_685122975254_item	2810646	et	4	main
aestid	doc_685122975254_item	2810649	et	4	main
takistab	doc_685122975254_item	2810651	et	3	main
tõenäoliselt	doc_685122975254_item	2810656	et	4	main
mille	doc_685122975254_item	2810658	et	3	main
ja	doc_685122975254_item	2810663	et	3	main
selle	doc_685122975254_item	2810667	et	4	main
preislaste	doc_685122975254_item	2810669	et	3	main
leedulaste	doc_685122975254_item	2810670	et	4	main
so	doc_685122975254_item	2810674	et	4	main
on	doc_685122975254_item	2810678	et	4	main
sealt	doc_685122975254_item	2810679	et	4	main
kuuluda	doc_685122975254_item	2810685	et	4	main
kui	doc_685122975254_item	2810686	et	3	main
poolt	doc_685122975254_item	2810690	et	4	main
mida	doc_685122975254_item	2810707	et	4	main
ebamäärasemaks	doc_685122975254_item	2810712	et	4	main
muutuvad	doc_685122975254_item	2810713	et	4	main
on	doc_685122975254_item	2810720	et	4	main
fennide	doc_685122975254_item	2810726	et	4	main
loogiliselt	doc_685122975254_item	2810733	et	4	main
rannikut	doc_685122975254_item	2810749	et	3	main
vaadata	doc_685122975254_item	2810764	et	4	main
seda	doc_685122975254_item	2810765	et	3	main
mille	doc_685122975254_item	2810766	et	3	main
3	doc_685122975254_item	2810782	et	2	main
keele	doc_685122975254_item	2810788	et	4	main
ja	doc_685122975254_item	2810789	et	3	main
kommete	doc_685122975254_item	2810790	et	4	main
rõhutatud	doc_685122975254_item	2810793	et	4	main
levinud	doc_685122975254_item	2810807	et	4	main
kreekas	doc_685122975254_item	2810816	et	4	main
leidub	doc_685122975254_item	2810818	et	3	main
merevaiku	doc_685122975254_item	2810819	et	4	main
ajal	doc_685122975254_item	2810830	et	4	main
moeasjaks	doc_685122975254_item	2810835	et	3	main
sai	doc_685122975254_item	2810837	et	4	main
ajal	doc_685122975254_item	2810840	et	4	main
kuni	doc_685122975254_item	2810843	et	3	main
ad	doc_685122975254_item	2810844	et	4	main
150	doc_685122975254_item	2810845	et	2	main
võis	doc_685122975254_item	2810870	et	4	main
erinev	doc_685122975254_item	2810872	et	4	main
aestii	doc_685122975254_item	2810881	et	4	main
koondnimetus	doc_685122975254_item	2810882	et	4	main
hulka	doc_685122975254_item	2810884	et	4	main
pole	doc_685122975254_item	2810890	et	3	main
põhjust	doc_685122975254_item	2810893	et	4	main
hulka	doc_685122975254_item	2810899	et	4	main
germania	doc_685122975254_item	2810909	et	4	main
teadmise	doc_685122975254_item	2810928	et	4	main
ja	doc_685122975254_item	2810941	et	3	main
aeg	doc_685122975254_item	2810948	et	3	main
alates	doc_685122975254_item	2810971	et	3	main
esimeseks	doc_685122975254_item	2810975	et	3	main
kiievis	doc_685122975254_item	2810985	et	4	main
ajalike	doc_685122975254_item	2810987	et	3	main
aastate	doc_685122975254_item	2810988	et	3	main
kiievi	doc_685122975254_item	2811000	et	4	main
targa	doc_685122975254_item	2811003	et	3	main
pole	doc_685122975254_item	2811007	et	3	main
leetopiss	doc_685122975254_item	2811008	et	3	main
ümberkirjutatuna	doc_685122975254_item	2811015	et	3	main
linnus	doc_685122975254_item	2811023	et	4	main
sai	doc_685122975254_item	2811025	et	4	main
leitud	doc_685122975254_item	2811031	et	4	main
ka	doc_685122975254_item	2811032	et	3	main
venelastele	doc_685122975254_item	2811039	et	4	main
iseloomulikke	doc_685122975254_item	2811040	et	3	main
suur	doc_685122975254_item	2811059	et	3	main
eesti	doc_685122975254_item	2811063	et	4	main
veel	doc_685122975254_item	2811065	et	4	main
leitud	doc_685122975254_item	2811066	et	4	main
kolm	doc_685122975254_item	2811067	et	3	main
viitavad	doc_685122975254_item	2811073	et	4	main
eesti	doc_685122975254_item	2811074	et	4	main
lätlaste	doc_685122975254_item	2810672	et	3	main
kaugel	doc_685122975254_item	2810681	et	4	main
on	doc_685122975254_item	2810692	et	4	main
lõunanaabriteks	doc_685122975254_item	2810694	et	4	main
ju	doc_685122975254_item	2810695	et	3	main
loomulikult	doc_685122975254_item	2810696	et	4	main
eestlased	doc_685122975254_item	2810697	et	3	main
ehk	doc_685122975254_item	2810698	et	3	main
seda	doc_685122975254_item	2810711	et	3	main
fantaasiaküllasem	doc_685122975254_item	2810719	et	4	main
saa	doc_685122975254_item	2810731	et	4	main
mõõta	doc_685122975254_item	2810732	et	3	main
arvestatavate	doc_685122975254_item	2810734	et	4	main
see	doc_685122975254_item	2810737	et	3	main
laheni	doc_685122975254_item	2810751	et	3	main
ainult	doc_685122975254_item	2810753	et	4	main
on	doc_685122975254_item	2810755	et	4	main
selle	doc_685122975254_item	2810756	et	4	main
tähtsam	doc_685122975254_item	2810762	et	4	main
kaudu	doc_685122975254_item	2810767	et	3	main
ta	doc_685122975254_item	2810772	et	4	main
puhul	doc_685122975254_item	2810791	et	4	main
laialt	doc_685122975254_item	2810806	et	4	main
kiviajal	doc_685122975254_item	2810811	et	3	main
uus	doc_685122975254_item	2810831	et	3	main
see	doc_685122975254_item	2810832	et	3	main
oli	doc_685122975254_item	2810833	et	3	main
alguse	doc_685122975254_item	2810838	et	3	main
ja	doc_685122975254_item	2810841	et	3	main
toimis	doc_685122975254_item	2810842	et	4	main
merevaiku	doc_685122975254_item	2810851	et	4	main
kasutatav	doc_685122975254_item	2810864	et	4	main
tinglik	doc_685122975254_item	2810865	et	3	main
oma	doc_685122975254_item	2810868	et	4	main
on	doc_685122975254_item	2810880	et	4	main
eellased	doc_685122975254_item	2810889	et	3	main
reaalset	doc_685122975254_item	2810892	et	3	main
nad	doc_685122975254_item	2810895	et	3	main
ei	doc_685122975254_item	2810896	et	4	main
on	doc_685122975254_item	2810908	et	4	main
ikkagi	doc_685122975254_item	2810913	et	4	main
see	doc_685122975254_item	2810914	et	3	main
kuulus	doc_685122975254_item	2810917	et	4	main
poolt	doc_685122975254_item	2810919	et	4	main
hõlmatavasse	doc_685122975254_item	2810920	et	4	main
tacitusel	doc_685122975254_item	2810722	et	4	main
eriti	doc_685122975254_item	2810725	et	3	main
aestii	doc_685122975254_item	2810728	et	4	main
ala	doc_685122975254_item	2810729	et	4	main
ei	doc_685122975254_item	2810730	et	4	main
miilidega	doc_685122975254_item	2810735	et	3	main
vaid	doc_685122975254_item	2810736	et	3	main
tervik	doc_685122975254_item	2810741	et	3	main
mis	doc_685122975254_item	2810742	et	4	main
vislast	doc_685122975254_item	2810744	et	4	main
kirdesse	doc_685122975254_item	2810745	et	4	main
mere	doc_685122975254_item	2810748	et	3	main
soome	doc_685122975254_item	2810750	et	3	main
nime	doc_685122975254_item	2810757	et	4	main
pärinud	doc_685122975254_item	2810758	et	4	main
ainult	doc_685122975254_item	2810760	et	4	main
iseloomustab	doc_685122975254_item	2810768	et	4	main
eesti	doc_685122975254_item	2810770	et	4	main
1	doc_685122975254_item	2810778	et	2	main
2	doc_685122975254_item	2810780	et	2	main
kultuuri	doc_685122975254_item	2810783	et	4	main
aestii	doc_685122975254_item	2810799	et	4	main
roomlasi	doc_685122975254_item	2810800	et	3	main
aladel	doc_685122975254_item	2810809	et	3	main
itaalias	doc_685122975254_item	2810817	et	4	main
hankimiseks	doc_685122975254_item	2810826	et	4	main
oli	doc_685122975254_item	2810827	et	3	main
aga	doc_685122975254_item	2810828	et	3	main
saanud	doc_685122975254_item	2810834	et	4	main
merevaigutee	doc_685122975254_item	2810836	et	4	main
nero	doc_685122975254_item	2810839	et	4	main
ütleb	doc_685122975254_item	2810847	et	3	main
olla	doc_685122975254_item	2810862	et	3	main
vastata	doc_685122975254_item	2810871	et	4	main
ka	doc_685122975254_item	2810886	et	3	main
mingit	doc_685122975254_item	2810891	et	3	main
aestide	doc_685122975254_item	2810898	et	4	main
kuid	doc_685122975254_item	2810901	et	4	main
kui	doc_685122975254_item	2810903	et	3	main
kirjelduse	doc_685122975254_item	2810910	et	4	main
et	doc_685122975254_item	2810915	et	3	main
vahemere	doc_685122975254_item	2810918	et	4	main
selle	doc_685122975254_item	2810936	et	4	main
rooma	doc_685122975254_item	2810937	et	4	main
autori	doc_685122975254_item	2810938	et	3	main
langenud	doc_685122975254_item	2810942	et	4	main
kirjutama	doc_685122975254_item	2810970	et	3	main
sajandist	doc_685122975254_item	2810973	et	3	main
jutustab	doc_685122975254_item	2810978	et	3	main
eestlastest	doc_685122975254_item	2810980	et	4	main
koostatud	doc_685122975254_item	2810986	et	4	main
lugu	doc_685122975254_item	2810989	et	4	main
milles	doc_685122975254_item	2810990	et	3	main
selle	doc_685122975254_item	2810991	et	4	main
esineb	doc_685122975254_item	2811014	et	3	main
sõjakäigu	doc_685122975254_item	2811021	et	3	main
on	doc_685122975254_item	2811030	et	4	main
leitud	doc_685122975254_item	2811038	et	4	main
nooleteravik	doc_685122975254_item	2811046	et	3	main
et	doc_685122975254_item	2811050	et	3	main
targa	doc_685122975254_item	2811069	et	3	main
hõbemünti	doc_685122975254_item	2811070	et	4	main
mis	doc_685122975254_item	2811071	et	4	main
samuti	doc_685122975254_item	2811072	et	3	main
mainida	doc_685122975254_item	2811079	et	3	main
on	doc_685122975254_item	2811094	et	4	main
ainult	doc_685122975254_item	2811097	et	4	main
kaupa	doc_685122975254_item	2811099	et	4	main
grammaticus	doc_685122975254_item	2811102	et	4	main
toimunud	doc_685122975254_item	2811110	et	4	main
taanlaste	doc_685122975254_item	2811112	et	3	main
eestlaste	doc_685122975254_item	2811114	et	4	main
eestlased	doc_685122975254_item	2811123	et	3	main
olnud	doc_685122975254_item	2811126	et	4	main
seal	doc_685122975254_item	2811127	et	4	main
parasjagu	doc_685122975254_item	2811128	et	3	main
oma	doc_685122975254_item	2811133	et	4	main
laevad	doc_685122975254_item	2811140	et	4	main
maha	doc_685122975254_item	2811142	et	4	main
taganeda	doc_685122975254_item	2811145	et	3	main
aga	doc_685122975254_item	2811147	et	3	main
rünnata	doc_685122975254_item	2811149	et	4	main
nagu	doc_685122975254_item	2811158	et	3	main
oli	doc_685122975254_item	2811160	et	3	main
ajutise	doc_685122975254_item	2811190	et	3	main
siiski	doc_685122975254_item	2811194	et	4	main
jutu	doc_685122975254_item	2811201	et	3	main
välja	doc_685122975254_item	2811204	et	4	main
taanlased	doc_685122975254_item	2811207	et	3	main
eesti	doc_685122975254_item	2811211	et	4	main
keelde	doc_685122975254_item	2811212	et	4	main
valik	doc_685122975254_item	2811215	et	3	main
oli	doc_685122975254_item	2810802	et	3	main
merevaik	doc_685122975254_item	2810803	et	3	main
see	doc_685122975254_item	2810804	et	3	main
oli	doc_685122975254_item	2810805	et	3	main
juba	doc_685122975254_item	2810810	et	3	main
ja	doc_685122975254_item	2810812	et	3	main
homerose	doc_685122975254_item	2810814	et	4	main
haudades	doc_685122975254_item	2810821	et	3	main
otsetee	doc_685122975254_item	2810823	et	4	main
merevaigu	doc_685122975254_item	2810825	et	3	main
tacituse	doc_685122975254_item	2810829	et	4	main
et	doc_685122975254_item	2810848	et	3	main
glaesum	doc_685122975254_item	2810852	et	4	main
kauplemisel	doc_685122975254_item	2810863	et	4	main
millele	doc_685122975254_item	2810867	et	3	main
keeles	doc_685122975254_item	2810869	et	4	main
sõna	doc_685122975254_item	2810873	et	4	main
nt	doc_685122975254_item	2810874	et	4	main
tõenäolisemalt	doc_685122975254_item	2810879	et	4	main
kelle	doc_685122975254_item	2810883	et	4	main
kuulusid	doc_685122975254_item	2810885	et	4	main
eestlaste	doc_685122975254_item	2810888	et	4	main
kuuluda	doc_685122975254_item	2810900	et	4	main
isegi	doc_685122975254_item	2810902	et	4	main
päritolu	doc_685122975254_item	2810905	et	4	main
probleem	doc_685122975254_item	2810906	et	3	main
lahtiseks	doc_685122975254_item	2810907	et	4	main
ilmne	doc_685122975254_item	2810912	et	4	main
eesti	doc_685122975254_item	2810916	et	4	main
võlgneme	doc_685122975254_item	2810929	et	3	main
me	doc_685122975254_item	2810930	et	4	main
tacitusele	doc_685122975254_item	2810931	et	4	main
kui	doc_685122975254_item	2810932	et	3	main
sajandite	doc_685122975254_item	2810933	et	3	main
kestel	doc_685122975254_item	2810934	et	4	main
eestimaal	doc_685122975254_item	2810944	et	4	main
praegu	doc_685122975254_item	2810946	et	3	main
sobiv	doc_685122975254_item	2810947	et	4	main
uuesti	doc_685122975254_item	2810949	et	3	main
3	doc_685122975254_item	2810953	et	2	main
ruunikivid	doc_685122975254_item	2810954	et	3	main
ja	doc_685122975254_item	2810955	et	3	main
leetopissid	doc_685122975254_item	2810956	et	3	main
ehk	doc_685122975254_item	2810966	et	3	main
hakati	doc_685122975254_item	2810969	et	3	main
11	doc_685122975254_item	2810972	et	2	main
üheks	doc_685122975254_item	2810974	et	3	main
alguse	doc_685122975254_item	2810984	et	3	main
jaroslav	doc_685122975254_item	2811002	et	4	main
jõjaretkest	doc_685122975254_item	2811004	et	4	main
originaalkujul	doc_685122975254_item	2811006	et	3	main
aga	doc_685122975254_item	2811011	et	3	main
tekst	doc_685122975254_item	2811013	et	3	main
mitmes	doc_685122975254_item	2811016	et	4	main
hilisemas	doc_685122975254_item	2811017	et	4	main
kroonikas	doc_685122975254_item	2811018	et	3	main
tartusse	doc_685122975254_item	2811019	et	3	main
rajati	doc_685122975254_item	2811020	et	3	main
suur	doc_685122975254_item	2810822	et	3	main
itaaliaga	doc_685122975254_item	2810824	et	4	main
tacitus	doc_685122975254_item	2810846	et	4	main
eestid	doc_685122975254_item	2810849	et	3	main
nimetavad	doc_685122975254_item	2810850	et	4	main
so	doc_685122975254_item	2810853	et	4	main
klaas	doc_685122975254_item	2810854	et	3	main
germaani	doc_685122975254_item	2810855	et	3	main
päritolu	doc_685122975254_item	2810856	et	4	main
nimi	doc_685122975254_item	2810857	et	3	main
vsks	doc_685122975254_item	2810858	et	4	main
glaes	doc_685122975254_item	2810859	et	4	main
see	doc_685122975254_item	2810860	et	3	main
võis	doc_685122975254_item	2810861	et	4	main
nimetus	doc_685122975254_item	2810866	et	4	main
eesti	doc_685122975254_item	2810875	et	4	main
keeles	doc_685122975254_item	2810876	et	4	main
helm	doc_685122975254_item	2810877	et	4	main
kõige	doc_685122975254_item	2810878	et	4	main
praeguste	doc_685122975254_item	2810887	et	3	main
miks	doc_685122975254_item	2810894	et	4	main
võinuks	doc_685122975254_item	2810897	et	4	main
jätta	doc_685122975254_item	2810904	et	3	main
järgi	doc_685122975254_item	2810911	et	4	main
euroopa	doc_685122975254_item	2810921	et	4	main
juba	doc_685122975254_item	2810923	et	3	main
kaks	doc_685122975254_item	2810924	et	3	main
populaarsus	doc_685122975254_item	2810939	et	4	main
siis	doc_685122975254_item	2810943	et	3	main
avastada	doc_685122975254_item	2810950	et	3	main
a	doc_685122975254_item	2810951	et	4	main
lill	doc_685122975254_item	2810952	et	3	main
mida	doc_685122975254_item	2810968	et	4	main
leetopissiks	doc_685122975254_item	2810976	et	3	main
ka	doc_685122975254_item	2810979	et	3	main
on	doc_685122975254_item	2810981	et	4	main
12	doc_685122975254_item	2810982	et	2	main
sajandi	doc_685122975254_item	2810983	et	3	main
aastal	doc_685122975254_item	2810998	et	3	main
suurvürsti	doc_685122975254_item	2811001	et	4	main
tartusse	doc_685122975254_item	2811005	et	3	main
küll	doc_685122975254_item	2811009	et	4	main
tulemusena	doc_685122975254_item	2811022	et	3	main
sündmustest	doc_685122975254_item	2811029	et	4	main
on	doc_685122975254_item	2811037	et	4	main
üks	doc_685122975254_item	2811043	et	3	main
kroonikatest	doc_685122975254_item	2811048	et	4	main
jaroslav	doc_685122975254_item	2811051	et	4	main
targa	doc_685122975254_item	2811052	et	3	main
vägedes	doc_685122975254_item	2811053	et	3	main
oli	doc_685122975254_item	2811054	et	3	main
viikingitest	doc_685122975254_item	2811055	et	4	main
vägagi	doc_685122975254_item	2811058	et	3	main
jaroslav	doc_685122975254_item	2811068	et	4	main
tuleks	doc_685122975254_item	2811077	et	4	main
antud	doc_685122975254_item	2811081	et	4	main
mündid	doc_685122975254_item	2811082	et	4	main
maailma	doc_685122975254_item	2811084	et	4	main
neid	doc_685122975254_item	2811089	et	4	main
4	doc_685122975254_item	2811100	et	2	main
1170	doc_685122975254_item	2811108	et	2	main
vahel	doc_685122975254_item	2811117	et	4	main
rüüsteretkel	doc_685122975254_item	2811129	et	4	main
taani	doc_685122975254_item	2811130	et	4	main
hoiatanud	doc_685122975254_item	2811135	et	4	main
eest	doc_685122975254_item	2811138	et	4	main
hoiatuse	doc_685122975254_item	2811153	et	4	main
tähelepanuta	doc_685122975254_item	2811154	et	3	main
ja	doc_685122975254_item	2811155	et	3	main
just	doc_685122975254_item	2811156	et	3	main
on	doc_685122975254_item	2811164	et	4	main
muust	doc_685122975254_item	2811187	et	4	main
tapnud	doc_685122975254_item	2811198	et	4	main
tuleb	doc_685122975254_item	2811203	et	3	main
et	doc_685122975254_item	2811205	et	3	main
kannatanud	doc_685122975254_item	2811208	et	4	main
suur	doc_685122975254_item	2811227	et	3	main
mitte	doc_685122975254_item	2811232	et	3	main
võiks	doc_685122975254_item	2811236	et	4	main
piisavalt	doc_685122975254_item	2811251	et	4	main
kust	doc_685122975254_item	2811263	et	4	main
ajalugu	doc_685122975254_item	2811271	et	4	main
seda	doc_685122975254_item	2811276	et	3	main
nagu	doc_685122975254_item	2811279	et	3	main
teateid	doc_685122975254_item	2811287	et	3	main
juba	doc_685122975254_item	2811291	et	3	main
ekr	doc_685122975254_item	2811294	et	4	main
teateid	doc_685122975254_item	2811298	et	3	main
kultuuripilti	doc_685122975254_item	2810922	et	4	main
aastatuhandet	doc_685122975254_item	2810925	et	4	main
tagasi	doc_685122975254_item	2810926	et	3	main
selle	doc_685122975254_item	2810927	et	4	main
on	doc_685122975254_item	2810935	et	4	main
tõusnud	doc_685122975254_item	2810940	et	4	main
oleks	doc_685122975254_item	2810945	et	3	main
ruunikivide	doc_685122975254_item	2810957	et	3	main
kõrval	doc_685122975254_item	2810958	et	4	main
on	doc_685122975254_item	2810959	et	4	main
tähtsamateks	doc_685122975254_item	2810960	et	4	main
kirjalikeks	doc_685122975254_item	2810961	et	3	main
ajalooallikateks	doc_685122975254_item	2810962	et	4	main
vene	doc_685122975254_item	2810963	et	4	main
käsikirjalised	doc_685122975254_item	2810964	et	4	main
kroonikad	doc_685122975254_item	2810965	et	3	main
leetopissid	doc_685122975254_item	2810967	et	3	main
mis	doc_685122975254_item	2810977	et	4	main
oletatav	doc_685122975254_item	2810992	et	4	main
autor	doc_685122975254_item	2810993	et	3	main
munk	doc_685122975254_item	2810994	et	3	main
nestor	doc_685122975254_item	2810995	et	3	main
jutustab	doc_685122975254_item	2810996	et	3	main
ka	doc_685122975254_item	2810997	et	3	main
1030	doc_685122975254_item	2810999	et	2	main
säilinud	doc_685122975254_item	2811010	et	4	main
selle	doc_685122975254_item	2811012	et	4	main
mis	doc_685122975254_item	2811024	et	4	main
nimeks	doc_685122975254_item	2811026	et	3	main
jurjev	doc_685122975254_item	2811027	et	4	main
arheoloogilisi	doc_685122975254_item	2811033	et	4	main
tõendeid	doc_685122975254_item	2811034	et	3	main
mõnedel	doc_685122975254_item	2811035	et	3	main
nooleotsi	doc_685122975254_item	2811041	et	4	main
osakaal	doc_685122975254_item	2811057	et	3	main
sellele	doc_685122975254_item	2811061	et	4	main
maapõuest	doc_685122975254_item	2811064	et	4	main
veel	doc_685122975254_item	2811078	et	4	main
haruldasemate	doc_685122975254_item	2811086	et	4	main
hulka	doc_685122975254_item	2811087	et	4	main
ning	doc_685122975254_item	2811088	et	3	main
leidub	doc_685122975254_item	2811090	et	3	main
ainult	doc_685122975254_item	2811091	et	4	main
8	doc_685122975254_item	2811092	et	2	main
mujalt	doc_685122975254_item	2811093	et	3	main
leitud	doc_685122975254_item	2811096	et	4	main
saxo	doc_685122975254_item	2811101	et	4	main
dorum	doc_685122975254_item	2811105	et	4	main
kroonik	doc_685122975254_item	2811106	et	3	main
lahingut	doc_685122975254_item	2811111	et	3	main
ja	doc_685122975254_item	2811113	et	3	main
ning	doc_685122975254_item	2811115	et	3	main
kurelaste	doc_685122975254_item	2811116	et	4	main
sellistest	doc_685122975254_item	2811028	et	4	main
kaevamistel	doc_685122975254_item	2811036	et	4	main
ja	doc_685122975254_item	2811042	et	3	main
viikingitele	doc_685122975254_item	2811044	et	3	main
tüüpiline	doc_685122975254_item	2811045	et	3	main
vene	doc_685122975254_item	2811047	et	4	main
teame	doc_685122975254_item	2811049	et	3	main
sõjameeste	doc_685122975254_item	2811056	et	4	main
lisaks	doc_685122975254_item	2811060	et	4	main
on	doc_685122975254_item	2811062	et	4	main
et	doc_685122975254_item	2811080	et	3	main
kuuluvad	doc_685122975254_item	2811083	et	4	main
kõige	doc_685122975254_item	2811085	et	4	main
ühe	doc_685122975254_item	2811098	et	4	main
ja	doc_685122975254_item	2811103	et	3	main
gestra	doc_685122975254_item	2811104	et	4	main
aastal	doc_685122975254_item	2811109	et	3	main
või	doc_685122975254_item	2811119	et	4	main
kusagil	doc_685122975254_item	2811120	et	3	main
selle	doc_685122975254_item	2811121	et	4	main
olevat	doc_685122975254_item	2811132	et	4	main
kombe	doc_685122975254_item	2811137	et	4	main
oma	doc_685122975254_item	2811139	et	4	main
justnagu	doc_685122975254_item	2811141	et	3	main
nii	doc_685122975254_item	2811157	et	3	main
kuningas	doc_685122975254_item	2811159	et	4	main
õelnud	doc_685122975254_item	2811161	et	4	main
oma	doc_685122975254_item	2811184	et	4	main
laevadest	doc_685122975254_item	2811185	et	3	main
ja	doc_685122975254_item	2811186	et	3	main
taanlased	doc_685122975254_item	2811193	et	3	main
eestlased	doc_685122975254_item	2811200	et	3	main
lõpuosas	doc_685122975254_item	2811202	et	3	main
kombel	doc_685122975254_item	2811222	et	4	main
on	doc_685122975254_item	2811223	et	4	main
orjad	doc_685122975254_item	2811234	et	4	main
ajalooga	doc_685122975254_item	2811244	et	4	main
rahvas	doc_685122975254_item	2811245	et	4	main
noortele	doc_685122975254_item	2811257	et	3	main
kes	doc_685122975254_item	2811259	et	4	main
me	doc_685122975254_item	2811260	et	4	main
oleme	doc_685122975254_item	2811261	et	3	main
ja	doc_685122975254_item	2811262	et	3	main
ei	doc_685122975254_item	2811284	et	4	main
ole	doc_685122975254_item	2811285	et	4	main
eestlastest	doc_685122975254_item	2811288	et	4	main
seosele	doc_685122975254_item	2811075	et	3	main
venemaaga	doc_685122975254_item	2811076	et	3	main
münte	doc_685122975254_item	2811095	et	3	main
kirjeldab	doc_685122975254_item	2811107	et	3	main
ölandil	doc_685122975254_item	2811118	et	4	main
väejuhte	doc_685122975254_item	2811134	et	4	main
ja	doc_685122975254_item	2811144	et	3	main
siis	doc_685122975254_item	2811146	et	3	main
ootamatult	doc_685122975254_item	2811148	et	4	main
väejuhid	doc_685122975254_item	2811150	et	3	main
jätsid	doc_685122975254_item	2811151	et	4	main
kuninga	doc_685122975254_item	2811152	et	3	main
läkski	doc_685122975254_item	2811162	et	3	main
huvitav	doc_685122975254_item	2811163	et	4	main
kokku	doc_685122975254_item	2811189	et	3	main
vallutanud	doc_685122975254_item	2811196	et	4	main
suuri	doc_685122975254_item	2811209	et	3	main
kaotusi	doc_685122975254_item	2811210	et	4	main
eesti	doc_685122975254_item	2811216	et	4	main
jaoks	doc_685122975254_item	2811217	et	4	main
eestlastel	doc_685122975254_item	2811225	et	4	main
ajalugu	doc_685122975254_item	2811228	et	4	main
me	doc_685122975254_item	2811229	et	4	main
ei	doc_685122975254_item	2811230	et	4	main
kahjuks	doc_685122975254_item	2811246	et	4	main
esiajaloole	doc_685122975254_item	2811250	et	4	main
jääbki	doc_685122975254_item	2811254	et	3	main
paljudele	doc_685122975254_item	2811256	et	3	main
tuleme	doc_685122975254_item	2811265	et	3	main
alles	doc_685122975254_item	2811272	et	3	main
enne	doc_685122975254_item	2811275	et	4	main
meid	doc_685122975254_item	2811277	et	4	main
poleks	doc_685122975254_item	2811278	et	3	main
olemas	doc_685122975254_item	2811280	et	4	main
olnudki	doc_685122975254_item	2811281	et	4	main
aga	doc_685122975254_item	2811282	et	3	main
see	doc_685122975254_item	2811283	et	3	main
võib	doc_685122975254_item	2811289	et	3	main
aastast	doc_685122975254_item	2811293	et	4	main
hilisemast	doc_685122975254_item	2811295	et	4	main
läheduses	doc_685122975254_item	2811122	et	4	main
ja	doc_685122975254_item	2811124	et	3	main
kurelased	doc_685122975254_item	2811125	et	3	main
kuningas	doc_685122975254_item	2811131	et	4	main
eestlaste	doc_685122975254_item	2811136	et	4	main
jätta	doc_685122975254_item	2811143	et	3	main
ka	doc_685122975254_item	2811165	et	3	main
kirjeldus	doc_685122975254_item	2811166	et	4	main
sellest	doc_685122975254_item	2811167	et	4	main
kuidas	doc_685122975254_item	2811168	et	3	main
enne	doc_685122975254_item	2811169	et	4	main
otsustavat	doc_685122975254_item	2811170	et	4	main
lahingut	doc_685122975254_item	2811171	et	3	main
eestlased	doc_685122975254_item	2811172	et	3	main
laulnud-tantsinud	doc_685122975254_item	2811173	et	4	main
öö	doc_685122975254_item	2811174	et	4	main
läbi	doc_685122975254_item	2811175	et	4	main
samal	doc_685122975254_item	2811176	et	3	main
ajal	doc_685122975254_item	2811177	et	4	main
aga	doc_685122975254_item	2811178	et	3	main
taanlased	doc_685122975254_item	2811179	et	3	main
norutnud	doc_685122975254_item	2811180	et	4	main
eestlased	doc_685122975254_item	2811181	et	3	main
seadnud	doc_685122975254_item	2811183	et	4	main
olevat	doc_685122975254_item	2811182	et	4	main
puumaterjalist	doc_685122975254_item	2811188	et	4	main
kindlustise	doc_685122975254_item	2811191	et	3	main
mille	doc_685122975254_item	2811192	et	3	main
lõpuks	doc_685122975254_item	2811195	et	4	main
ja	doc_685122975254_item	2811197	et	3	main
kõik	doc_685122975254_item	2811199	et	4	main
ka	doc_685122975254_item	2811206	et	3	main
on	doc_685122975254_item	2811213	et	4	main
tõlgitud	doc_685122975254_item	2811214	et	4	main
huvitaval	doc_685122975254_item	2811221	et	4	main
meil	doc_685122975254_item	2811224	et	4	main
sündinud	doc_685122975254_item	2811233	et	4	main
huvitava	doc_685122975254_item	2811243	et	4	main
pöörata	doc_685122975254_item	2811248	et	4	main
meie	doc_685122975254_item	2811249	et	4	main
tähelepanu	doc_685122975254_item	2811252	et	4	main
me	doc_685122975254_item	2811264	et	4	main
jääb	doc_685122975254_item	2811266	et	3	main
muistse	doc_685122975254_item	2811273	et	3	main
nii	doc_685122975254_item	2811286	et	3	main
ajast	doc_685122975254_item	2811296	et	4	main
on	doc_685122975254_item	2811299	et	4	main
huvipakkuvamaid	doc_685122975254_item	2811218	et	4	main
osi	doc_685122975254_item	2811219	et	4	main
kokkuvõte	doc_685122975254_item	2811220	et	3	main
nii	doc_685122975254_item	2811226	et	3	main
ole	doc_685122975254_item	2811231	et	4	main
nagu	doc_685122975254_item	2811235	et	3	main
ekslikult	doc_685122975254_item	2811237	et	4	main
arvata	doc_685122975254_item	2811238	et	4	main
vaid	doc_685122975254_item	2811239	et	3	main
väga	doc_685122975254_item	2811240	et	3	main
vana	doc_685122975254_item	2811241	et	4	main
ja	doc_685122975254_item	2811242	et	3	main
ei	doc_685122975254_item	2811247	et	4	main
seepärast	doc_685122975254_item	2811253	et	3	main
väga	doc_685122975254_item	2811255	et	3	main
arusaamatuks	doc_685122975254_item	2811258	et	4	main
mulje	doc_685122975254_item	2811267	et	4	main
nagu	doc_685122975254_item	2811268	et	3	main
algaks	doc_685122975254_item	2811269	et	3	main
meie	doc_685122975254_item	2811270	et	4	main
vabadusvõitlusega	doc_685122975254_item	2811274	et	3	main
leida	doc_685122975254_item	2811290	et	3	main
322	doc_685122975254_item	2811292	et	2	main
pärinevaid	doc_685122975254_item	2811297	et	4	main
rohkem	doc_685122975254_item	2811301	et	4	main
veelgi	doc_685122975254_item	2811300	et	4	main
kõik	doc_685122975254_item	2811302	et	4	main
need	doc_685122975254_item	2811303	et	3	main
allikad	doc_685122975254_item	2811304	et	3	main
on	doc_685122975254_item	2811305	et	4	main
kujuteldamatult	doc_685122975254_item	2811306	et	4	main
tähtsad	doc_685122975254_item	2811307	et	3	main
eestlaste	doc_685122975254_item	2811308	et	4	main
ajaloo	doc_685122975254_item	2811309	et	4	main
määramiseks	doc_685122975254_item	2811310	et	4	main
ja	doc_685122975254_item	2811311	et	3	main
mõistmiseks	doc_685122975254_item	2811312	et	4	main
seda	doc_685122975266_item	2813510	et	3	main
liiga	doc_685122975266_item	2813525	et	4	main
on	doc_685122975266_item	2813529	et	4	main
et	doc_685122975266_item	2813531	et	3	main
kõik	doc_685122975266_item	2813532	et	4	main
oma	doc_685122975266_item	2813542	et	4	main
kaalep	doc_685122975266_item	2813501	et	4	main
eelmisel	doc_685122975266_item	2813502	et	3	main
nädalal	doc_685122975266_item	2813503	et	3	main
ma	doc_685122975266_item	2813504	et	3	main
lugesin	doc_685122975266_item	2813505	et	3	main
ma	doc_685122975266_item	2813511	et	3	main
teie	doc_685122975266_item	2813506	et	4	main
ja	doc_685122975266_item	2813508	et	3	main
põlvkond	doc_685122975266_item	2813523	et	3	main
nende	doc_685122975266_item	2813535	et	4	main
koos	doc_685122975266_item	2813541	et	4	main
elada	doc_685122975266_item	2813548	et	3	main
selle	doc_685122975266_item	2813552	et	4	main
on	doc_685122975266_item	2813554	et	4	main
vaja	doc_685122975266_item	2813555	et	4	main
laenu	doc_685122975266_item	2813567	et	4	main
korteri	doc_685122975266_item	2813568	et	3	main
eest	doc_685122975266_item	2813569	et	4	main
teie	doc_685122975266_item	2813570	et	4	main
artiklis	doc_685122975266_item	2813571	et	3	main
tahavad	doc_685122975266_item	2813576	et	3	main
nagu	doc_685122975266_item	2813578	et	3	main
mõnel	doc_685122975266_item	2813585	et	3	main
on	doc_685122975266_item	2813587	et	4	main
see	doc_685122975266_item	2813592	et	3	main
on	doc_685122975266_item	2813593	et	4	main
elada	doc_685122975266_item	2813598	et	3	main
lõpetama	doc_685122975266_item	2813607	et	4	main
ja	doc_685122975266_item	2813608	et	3	main
leida	doc_685122975266_item	2813609	et	3	main
heapalgaline	doc_685122975266_item	2813610	et	4	main
mõtlete	doc_685122975266_item	2813614	et	3	main
vanemad	doc_685122975266_item	2813616	et	4	main
aitama	doc_685122975266_item	2813618	et	3	main
oma	doc_685122975266_item	2813619	et	4	main
eraldi	doc_685122975266_item	2813623	et	4	main
ei	doc_685122975266_item	2813625	et	4	main
kuidas	doc_685122975266_item	2813626	et	3	main
selles	doc_685122975266_item	2813628	et	4	main
situatsioonis	doc_685122975266_item	2813629	et	3	main
kui	doc_685122975266_item	2813630	et	3	main
inimene	doc_685122975266_item	2813631	et	3	main
saada	doc_685122975266_item	2813640	et	4	main
et	doc_685122975266_item	2813641	et	3	main
ja	doc_685122975266_item	2813648	et	3	main
vastutav	doc_685122975266_item	2813652	et	4	main
kui	doc_685122975266_item	2813669	et	3	main
kui	doc_685122975266_item	2813674	et	3	main
tahab	doc_685122975266_item	2813676	et	3	main
puhas	doc_685122975266_item	2813678	et	3	main
te	doc_685122975266_item	2813690	et	4	main
oma	doc_685122975266_item	2813693	et	4	main
arstiteenindusest	doc_685122975266_item	2813695	et	4	main
olen	doc_685122975266_item	2813696	et	3	main
teiega	doc_685122975266_item	2813697	et	3	main
mitte	doc_685122975266_item	2813698	et	3	main
täiesti	doc_685122975266_item	2813699	et	3	main
nõus	doc_685122975266_item	2813700	et	4	main
töökohal	doc_685122975266_item	2813716	et	4	main
igal	doc_685122975266_item	2813717	et	3	main
peavad	doc_685122975266_item	2813719	et	4	main
kiri	doc_685122975266_item	2813498	et	3	main
lugupeetud	doc_685122975266_item	2813499	et	4	main
artikkel	doc_685122975266_item	2813507	et	3	main
tänane	doc_685122975266_item	2813522	et	3	main
peab	doc_685122975266_item	2813533	et	4	main
jooksma	doc_685122975266_item	2813534	et	3	main
noorus	doc_685122975266_item	2813539	et	4	main
elab	doc_685122975266_item	2813540	et	3	main
tahtsid	doc_685122975266_item	2813547	et	4	main
mingi	doc_685122975266_item	2813565	et	4	main
kahekümneaastased	doc_685122975266_item	2813575	et	4	main
see	doc_685122975266_item	2813580	et	3	main
noortel	doc_685122975266_item	2813586	et	3	main
oma	doc_685122975266_item	2813589	et	4	main
selge	doc_685122975266_item	2813594	et	4	main
lapsele	doc_685122975266_item	2813620	et	4	main
tiina	doc_685122975266_item	2813500	et	4	main
pärast	doc_685122975266_item	2813509	et	4	main
tahtsin	doc_685122975266_item	2813512	et	3	main
teile	doc_685122975266_item	2813513	et	4	main
kirjutada	doc_685122975266_item	2813514	et	3	main
olen	doc_685122975266_item	2813515	et	3	main
täielikult	doc_685122975266_item	2813516	et	4	main
teiega	doc_685122975266_item	2813517	et	3	main
nõus	doc_685122975266_item	2813518	et	4	main
mõtlen	doc_685122975266_item	2813519	et	3	main
ka	doc_685122975266_item	2813520	et	3	main
on	doc_685122975266_item	2813524	et	4	main
mõned	doc_685122975266_item	2813527	et	3	main
kätte	doc_685122975266_item	2813536	et	4	main
et	doc_685122975266_item	2813551	et	3	main
kirjutasite	doc_685122975266_item	2813573	et	3	main
elada	doc_685122975266_item	2813577	et	3	main
kuid	doc_685122975266_item	2813595	et	4	main
vanematest	doc_685122975266_item	2813599	et	4	main
aga	doc_685122975266_item	2813601	et	3	main
nad	doc_685122975266_item	2813604	et	3	main
peavad	doc_685122975266_item	2813605	et	4	main
kas	doc_685122975266_item	2813615	et	3	main
peavad	doc_685122975266_item	2813617	et	4	main
alustama	doc_685122975266_item	2813621	et	3	main
arsti	doc_685122975266_item	2813633	et	4	main
ta	doc_685122975266_item	2813637	et	4	main
on	doc_685122975266_item	2813644	et	4	main
töö	doc_685122975266_item	2813653	et	4	main
suhteliselt	doc_685122975266_item	2813677	et	4	main
heapalgaline	doc_685122975266_item	2813681	et	4	main
siis	doc_685122975266_item	2813683	et	3	main
võib	doc_685122975266_item	2813685	et	3	main
valida	doc_685122975266_item	2813686	et	3	main
just	doc_685122975266_item	2813687	et	3	main
arvate	doc_685122975266_item	2813692	et	3	main
juurde	doc_685122975266_item	2813704	et	4	main
käiv	doc_685122975266_item	2813705	et	4	main
sel	doc_685122975266_item	2813708	et	3	main
nad	doc_685122975266_item	2813710	et	3	main
oma	doc_685122975266_item	2813715	et	4	main
koostama	doc_685122975266_item	2813724	et	3	main
lapsi	doc_685122975266_item	2813733	et	4	main
õppida	doc_685122975266_item	2813734	et	3	main
aga	doc_685122975266_item	2813735	et	3	main
see	doc_685122975266_item	2813736	et	3	main
ka	doc_685122975266_item	2813737	et	3	main
pole	doc_685122975266_item	2813738	et	3	main
õppatajana	doc_685122975266_item	2813754	et	4	main
mõtlen	doc_685122975266_item	2813758	et	3	main
oma	doc_685122975266_item	2813764	et	4	main
selline	doc_685122975266_item	2813772	et	4	main
ühiskondlik	doc_685122975266_item	2813773	et	3	main
töö	doc_685122975266_item	2813774	et	4	main
kus	doc_685122975266_item	2813775	et	3	main
millised	doc_685122975266_item	2813782	et	3	main
töö	doc_685122975266_item	2813792	et	4	main
rohkem	doc_685122975266_item	2813798	et	4	main
raha	doc_685122975266_item	2813799	et	4	main
lugupidamisega	doc_685122975266_item	2813803	et	3	main
et	doc_685122975266_item	2813521	et	3	main
laisk	doc_685122975266_item	2813526	et	3	main
noored	doc_685122975266_item	2813528	et	3	main
harjunud	doc_685122975266_item	2813530	et	4	main
täna	doc_685122975266_item	2813537	et	4	main
õppiv	doc_685122975266_item	2813538	et	4	main
aga	doc_685122975266_item	2813544	et	3	main
nad	doc_685122975266_item	2813545	et	3	main
muidugi	doc_685122975266_item	2813546	et	4	main
mõtlen	doc_685122975266_item	2813550	et	3	main
rohkem	doc_685122975266_item	2813556	et	4	main
aega	doc_685122975266_item	2813557	et	4	main
ja	doc_685122975266_item	2813558	et	3	main
muidugi	doc_685122975266_item	2813559	et	4	main
raha	doc_685122975266_item	2813560	et	4	main
raisata	doc_685122975266_item	2813561	et	4	main
näiteks	doc_685122975266_item	2813562	et	4	main
maksma	doc_685122975266_item	2813563	et	3	main
vanematega	doc_685122975266_item	2813543	et	4	main
eraldi	doc_685122975266_item	2813549	et	4	main
eest	doc_685122975266_item	2813553	et	4	main
välja	doc_685122975266_item	2813564	et	4	main
et	doc_685122975266_item	2813574	et	3	main
ei	doc_685122975266_item	2813581	et	4	main
saladus	doc_685122975266_item	2813583	et	3	main
et	doc_685122975266_item	2813584	et	3	main
muidugi	doc_685122975266_item	2813591	et	4	main
nad	doc_685122975266_item	2813596	et	3	main
ülikooli	doc_685122975266_item	2813606	et	4	main
te	doc_685122975266_item	2813613	et	4	main
valib	doc_685122975266_item	2813632	et	3	main
siis	doc_685122975266_item	2813636	et	3	main
peab	doc_685122975266_item	2813638	et	4	main
aru	doc_685122975266_item	2813639	et	4	main
erialal	doc_685122975266_item	2813643	et	3	main
väga	doc_685122975266_item	2813645	et	3	main
raske	doc_685122975266_item	2813646	et	4	main
ja	doc_685122975266_item	2813651	et	3	main
raha	doc_685122975266_item	2813668	et	4	main
vaikne	doc_685122975266_item	2813679	et	3	main
töö	doc_685122975266_item	2813682	et	4	main
ta	doc_685122975266_item	2813684	et	4	main
tänapäeva	doc_685122975266_item	2813694	et	4	main
suvevaheaeg	doc_685122975266_item	2813707	et	3	main
õpinguprogramm	doc_685122975266_item	2813727	et	3	main
see	doc_685122975266_item	2813729	et	3	main
võib	doc_685122975266_item	2813740	et	3	main
valimiseks	doc_685122975266_item	2813747	et	4	main
mõned	doc_685122975266_item	2813749	et	3	main
noored	doc_685122975266_item	2813750	et	3	main
mõtlevad	doc_685122975266_item	2813751	et	4	main
et	doc_685122975266_item	2813752	et	3	main
töötada	doc_685122975266_item	2813753	et	3	main
õpetajad	doc_685122975266_item	2813760	et	4	main
järel	doc_685122975266_item	2813781	et	4	main
eest	doc_685122975266_item	2813793	et	4	main
ajalehest	doc_685122975268_item	2814057	et	4	main
avaldada	doc_685122975268_item	2814068	et	3	main
tegelikult	doc_685122975268_item	2814102	et	4	main
olukord	doc_685122975268_item	2814103	et	3	main
kellest	doc_685122975268_item	2814119	et	4	main
räägitakse	doc_685122975268_item	2814120	et	3	main
pikaajalise	doc_685122975266_item	2813566	et	4	main
te	doc_685122975266_item	2813572	et	4	main
neljakümnesed	doc_685122975266_item	2813579	et	3	main
ole	doc_685122975266_item	2813582	et	4	main
juba	doc_685122975266_item	2813588	et	3	main
isiklikelu	doc_685122975266_item	2813590	et	4	main
tahavad	doc_685122975266_item	2813597	et	3	main
eraldi	doc_685122975266_item	2813600	et	4	main
enne	doc_685122975266_item	2813602	et	4	main
seda	doc_685122975266_item	2813603	et	3	main
töö	doc_685122975266_item	2813611	et	4	main
kuidas	doc_685122975266_item	2813612	et	3	main
või	doc_685122975266_item	2813624	et	4	main
käituda	doc_685122975266_item	2813627	et	3	main
amet	doc_685122975266_item	2813634	et	3	main
õppimine	doc_685122975266_item	2813647	et	4	main
enam	doc_685122975266_item	2813649	et	4	main
rohkem	doc_685122975266_item	2813667	et	4	main
olen	doc_685122975266_item	2813671	et	3	main
nõus	doc_685122975266_item	2813672	et	4	main
noormees	doc_685122975266_item	2813675	et	4	main
sellineeriala	doc_685122975266_item	2813688	et	4	main
mida	doc_685122975266_item	2813689	et	4	main
ise	doc_685122975266_item	2813691	et	4	main
hommikul	doc_685122975266_item	2813718	et	3	main
istuma	doc_685122975266_item	2813720	et	3	main
aastale	doc_685122975266_item	2813726	et	3	main
olla	doc_685122975266_item	2813741	et	3	main
on	doc_685122975266_item	2813755	et	4	main
mitte	doc_685122975266_item	2813756	et	3	main
nadu	doc_685122975266_item	2813761	et	4	main
raha	doc_685122975266_item	2813769	et	4	main
see	doc_685122975266_item	2813770	et	3	main
on	doc_685122975266_item	2813771	et	4	main
päev	doc_685122975266_item	2813779	et	3	main
ametikohad	doc_685122975266_item	2813783	et	4	main
arvamusest	doc_685122975266_item	2813785	et	4	main
liiga	doc_685122975266_item	2813786	et	4	main
ohtlikud	doc_685122975266_item	2813787	et	3	main
noorte	doc_685122975266_item	2813788	et	3	main
inimeste	doc_685122975266_item	2813789	et	3	main
tervisele	doc_685122975266_item	2813790	et	3	main
millise	doc_685122975266_item	2813791	et	3	main
inimesed	doc_685122975266_item	2813794	et	3	main
saama	doc_685122975266_item	2813796	et	4	main
elada	doc_685122975266_item	2813622	et	3	main
õppimiseks	doc_685122975266_item	2813635	et	4	main
sellel	doc_685122975266_item	2813642	et	4	main
keeruline	doc_685122975266_item	2813650	et	4	main
teie	doc_685122975266_item	2813654	et	4	main
artiklis	doc_685122975266_item	2813655	et	3	main
kirjutasite	doc_685122975266_item	2813657	et	3	main
et	doc_685122975266_item	2813658	et	3	main
arstid	doc_685122975266_item	2813659	et	4	main
te	doc_685122975266_item	2813656	et	4	main
peavad	doc_685122975266_item	2813660	et	4	main
oma	doc_685122975266_item	2813661	et	4	main
töö	doc_685122975266_item	2813662	et	4	main
eest	doc_685122975266_item	2813663	et	4	main
saama	doc_685122975266_item	2813664	et	4	main
väga	doc_685122975266_item	2813665	et	3	main
palju	doc_685122975266_item	2813666	et	4	main
täna	doc_685122975266_item	2813670	et	4	main
et	doc_685122975266_item	2813673	et	3	main
ja	doc_685122975266_item	2813680	et	3	main
et	doc_685122975266_item	2813701	et	3	main
õpeteja	doc_685122975266_item	2813702	et	4	main
ameti	doc_685122975266_item	2813703	et	3	main
pikk	doc_685122975266_item	2813706	et	4	main
ajal	doc_685122975266_item	2813709	et	4	main
peavad	doc_685122975266_item	2813711	et	4	main
olla	doc_685122975266_item	2813712	et	3	main
kui	doc_685122975266_item	2813713	et	3	main
alati	doc_685122975266_item	2813714	et	4	main
oma	doc_685122975266_item	2813721	et	4	main
ja	doc_685122975266_item	2813723	et	3	main
muidugi	doc_685122975266_item	2813728	et	4	main
on	doc_685122975266_item	2813730	et	4	main
kergem	doc_685122975266_item	2813731	et	4	main
kui	doc_685122975266_item	2813732	et	3	main
see	doc_685122975266_item	2813742	et	3	main
argument	doc_685122975266_item	2813744	et	3	main
ameti	doc_685122975266_item	2813746	et	3	main
aga	doc_685122975266_item	2813748	et	3	main
austavalt	doc_685122975266_item	2813757	et	4	main
arstid	doc_685122975266_item	2813762	et	4	main
eest	doc_685122975266_item	2813766	et	4	main
päeva	doc_685122975266_item	2813780	et	4	main
teie	doc_685122975266_item	2813784	et	4	main
kui	doc_685122975266_item	2813800	et	3	main
praegu	doc_685122975266_item	2813801	et	3	main
makstakse	doc_685122975266_item	2813802	et	3	main
klassitoas	doc_685122975266_item	2813722	et	3	main
järgmisele	doc_685122975266_item	2813725	et	3	main
meelelahutus	doc_685122975266_item	2813739	et	4	main
on	doc_685122975266_item	2813743	et	4	main
selle	doc_685122975266_item	2813745	et	4	main
et	doc_685122975266_item	2813759	et	3	main
peavad	doc_685122975266_item	2813763	et	4	main
töö	doc_685122975266_item	2813765	et	4	main
saama	doc_685122975266_item	2813767	et	4	main
rohkem	doc_685122975266_item	2813768	et	4	main
sa	doc_685122975266_item	2813776	et	3	main
pead	doc_685122975266_item	2813777	et	4	main
töötada	doc_685122975266_item	2813778	et	3	main
peavad	doc_685122975266_item	2813795	et	4	main
ka	doc_685122975266_item	2813797	et	3	main
eesnimi	doc_685122975266_item	2813804	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975266_item	2813805	et	4	main
teie	doc_685122975268_item	2814058	et	4	main
artiklit	doc_685122975268_item	2814059	et	3	main
vähenõudlike	doc_685122975268_item	2814060	et	3	main
põlvkond	doc_685122975268_item	2814061	et	3	main
8062006	doc_685122975268_item	2814063	et	2	main
oma	doc_685122975268_item	2814066	et	4	main
tahaksin	doc_685122975268_item	2814071	et	3	main
tekkinud	doc_685122975268_item	2814094	et	4	main
arvamus	doc_685122975268_item	2814096	et	3	main
väidan	doc_685122975268_item	2814107	et	3	main
kellel	doc_685122975268_item	2814115	et	4	main
on	doc_685122975268_item	2814116	et	4	main
palju	doc_685122975268_item	2814117	et	4	main
tuttavaid	doc_685122975268_item	2814118	et	3	main
ma	doc_685122975268_item	2814122	et	3	main
kindel	doc_685122975268_item	2814125	et	3	main
lugupeetud	doc_685122975268_item	2814054	et	4	main
tiina	doc_685122975268_item	2814055	et	4	main
lugesin	doc_685122975268_item	2814056	et	3	main
arvamust	doc_685122975268_item	2814067	et	3	main
öeldes	doc_685122975268_item	2814070	et	3	main
teiega	doc_685122975268_item	2814072	et	3	main
vaielda	doc_685122975268_item	2814073	et	4	main
selle	doc_685122975268_item	2814074	et	4	main
probleemi	doc_685122975268_item	2814075	et	4	main
mis	doc_685122975268_item	2814076	et	4	main
on	doc_685122975268_item	2814077	et	4	main
artiklis	doc_685122975268_item	2814078	et	3	main
kirjeldatud	doc_685122975268_item	2814079	et	4	main
üle	doc_685122975268_item	2814080	et	3	main
ma	doc_685122975268_item	2814081	et	3	main
olen	doc_685122975268_item	2814082	et	3	main
osaliselt	doc_685122975268_item	2814083	et	4	main
teiega	doc_685122975268_item	2814084	et	3	main
nõus	doc_685122975268_item	2814085	et	4	main
meie	doc_685122975268_item	2814086	et	4	main
vaadete	doc_685122975268_item	2814087	et	3	main
erinevus	doc_685122975268_item	2814088	et	4	main
seisneb	doc_685122975268_item	2814089	et	3	main
selles	doc_685122975268_item	2814090	et	4	main
et	doc_685122975268_item	2814091	et	3	main
teil	doc_685122975268_item	2814092	et	4	main
on	doc_685122975268_item	2814093	et	4	main
kiri	doc_685122975268_item	2814053	et	3	main
soovin	doc_685122975268_item	2814065	et	3	main
ausalt	doc_685122975268_item	2814069	et	4	main
pärast	doc_685122975268_item	2814097	et	4	main
mõnede	doc_685122975268_item	2814098	et	3	main
abiturientide	doc_685122975268_item	2814099	et	3	main
küsitlust	doc_685122975268_item	2814100	et	4	main
ma	doc_685122975268_item	2814106	et	3	main
sest	doc_685122975268_item	2814109	et	4	main
et	doc_685122975268_item	2814110	et	3	main
ise	doc_685122975268_item	2814111	et	4	main
olen	doc_685122975268_item	2814112	et	3	main
pole	doc_685122975268_item	2814123	et	3	main
et	doc_685122975268_item	2814127	et	3	main
noori	doc_685122975268_item	2814128	et	3	main
üksikute	doc_685122975268_item	2814136	et	4	main
valmis	doc_685122975268_item	2814141	et	4	main
edu	doc_685122975268_item	2814146	et	4	main
häbenevad	doc_685122975268_item	2814161	et	4	main
võlgu	doc_685122975268_item	2814170	et	4	main
see	doc_685122975268_item	2814177	et	3	main
abituriendid	doc_685122975268_item	2814186	et	3	main
lõpetamist	doc_685122975268_item	2814189	et	4	main
välismaale	doc_685122975268_item	2814190	et	4	main
seal	doc_685122975268_item	2814193	et	4	main
tänapäeva	doc_685122975268_item	2814206	et	4	main
noori	doc_685122975268_item	2814207	et	3	main
ei	doc_685122975268_item	2814225	et	4	main
saab	doc_685122975268_item	2814229	et	3	main
mida	doc_685122975268_item	2814237	et	4	main
et	doc_685122975268_item	2814243	et	3	main
ja	doc_685122975268_item	2814247	et	3	main
saada	doc_685122975268_item	2814251	et	4	main
teha	doc_685122975268_item	2814259	et	3	main
valik	doc_685122975268_item	2814261	et	3	main
peaks	doc_685122975268_item	2814264	et	4	main
tegema	doc_685122975268_item	2814265	et	3	main
mitte	doc_685122975268_item	2814266	et	3	main
pärast	doc_685122975268_item	2814267	et	4	main
lõpueksamite	doc_685122975268_item	2814268	et	3	main
edaspidises	doc_685122975268_item	2814297	et	3	main
lugupidamisega	doc_685122975268_item	2814299	et	3	main
perekonnanimi	doc_685122975268_item	2814301	et	3	main
ee	doc_685122975268_item	2814062	et	3	main
ja	doc_685122975268_item	2814064	et	3	main
kuid	doc_685122975268_item	2814101	et	4	main
noor	doc_685122975268_item	2814113	et	3	main
neiu	doc_685122975268_item	2814114	et	4	main
artiklis	doc_685122975268_item	2814121	et	3	main
ainult	doc_685122975268_item	2814134	et	4	main
mõnede	doc_685122975268_item	2814135	et	3	main
aga	doc_685122975268_item	2814139	et	3	main
elus	doc_685122975268_item	2814145	et	4	main
taotleda	doc_685122975268_item	2814147	et	3	main
need	doc_685122975268_item	2814151	et	3	main
kätte	doc_685122975268_item	2814159	et	4	main
lihtsalt	doc_685122975268_item	2814160	et	4	main
tahab	doc_685122975268_item	2814166	et	3	main
terve	doc_685122975268_item	2814167	et	4	main
kinni	doc_685122975268_item	2814171	et	3	main
igaüks	doc_685122975268_item	2814173	et	3	main
laialt	doc_685122975268_item	2814175	et	4	main
on	doc_685122975268_item	2814178	et	4	main
iga	doc_685122975268_item	2814179	et	4	main
pärast	doc_685122975268_item	2814187	et	4	main
teenivad	doc_685122975268_item	2814192	et	4	main
iseloomustab	doc_685122975268_item	2814205	et	4	main
teie	doc_685122975268_item	2814209	et	4	main
selline	doc_685122975268_item	2814095	et	4	main
on	doc_685122975268_item	2814104	et	4	main
teissugune	doc_685122975268_item	2814105	et	3	main
seda	doc_685122975268_item	2814108	et	3	main
üldse	doc_685122975268_item	2814124	et	3	main
selles	doc_685122975268_item	2814126	et	4	main
huvitab	doc_685122975268_item	2814129	et	3	main
unistus	doc_685122975268_item	2814137	et	4	main
selleks	doc_685122975268_item	2814142	et	4	main
keegi	doc_685122975268_item	2814165	et	4	main
pangale	doc_685122975268_item	2814169	et	3	main
maksta	doc_685122975268_item	2814172	et	4	main
soovib	doc_685122975268_item	2814174	et	3	main
elada	doc_685122975268_item	2814176	et	3	main
sõidavadki	doc_685122975268_item	2814184	et	3	main
aitab	doc_685122975268_item	2814196	et	3	main
neil	doc_685122975268_item	2814197	et	4	main
omaette	doc_685122975268_item	2814198	et	3	main
elada	doc_685122975268_item	2814199	et	3	main
nooruslik	doc_685122975268_item	2814200	et	3	main
ind	doc_685122975268_item	2814201	et	3	main
ja	doc_685122975268_item	2814202	et	3	main
maksimalism	doc_685122975268_item	2814203	et	3	main
mõned	doc_685122975268_item	2814223	et	3	main
peaks	doc_685122975268_item	2814234	et	4	main
juba	doc_685122975268_item	2814235	et	3	main
teadma	doc_685122975268_item	2814236	et	3	main
selleks	doc_685122975268_item	2814242	et	4	main
heaks	doc_685122975268_item	2814245	et	4	main
oma	doc_685122975268_item	2814248	et	4	main
tööst	doc_685122975268_item	2814249	et	3	main
naudingut	doc_685122975268_item	2814250	et	3	main
peas	doc_685122975268_item	2814256	et	4	main
kaalutleda	doc_685122975268_item	2814257	et	3	main
ja	doc_685122975268_item	2814258	et	3	main
kõike	doc_685122975268_item	2814262	et	4	main
edu	doc_685122975268_item	2814296	et	4	main
loomingus	doc_685122975268_item	2814298	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975268_item	2814303	et	4	main
kiri	doc_685122975270_item	2814471	et	3	main
nimi	doc_685122975270_item	2814476	et	3	main
eesnimi	doc_685122975270_item	2814478	et	3	main
noormehed	doc_685122975270_item	2814521	et	3	main
ainult	doc_685122975270_item	2814523	et	4	main
saada	doc_685122975270_item	2814525	et	4	main
ja	doc_685122975270_item	2814526	et	3	main
mitte	doc_685122975270_item	2814527	et	3	main
kõige	doc_685122975270_item	2814530	et	4	main
erialad	doc_685122975270_item	2814532	et	3	main
käigus	doc_685122975270_item	2814566	et	4	main
on	doc_685122975270_item	2814567	et	4	main
graadi	doc_685122975270_item	2814574	et	4	main
vaid	doc_685122975270_item	2814575	et	3	main
saada	doc_685122975270_item	2814576	et	4	main
on	doc_685122975268_item	2814140	et	4	main
et	doc_685122975268_item	2814143	et	3	main
kes	doc_685122975268_item	2814152	et	4	main
ütlevad	doc_685122975268_item	2814153	et	4	main
et	doc_685122975268_item	2814154	et	3	main
tahavad	doc_685122975268_item	2814155	et	3	main
saada	doc_685122975268_item	2814156	et	4	main
kümme	doc_685122975268_item	2814157	et	3	main
tõtt	doc_685122975268_item	2814162	et	4	main
rääkida	doc_685122975268_item	2814163	et	3	main
elu	doc_685122975268_item	2814168	et	4	main
tahtmine	doc_685122975268_item	2814182	et	4	main
seepärast	doc_685122975268_item	2814183	et	3	main
paljud	doc_685122975268_item	2814185	et	3	main
nad	doc_685122975268_item	2814191	et	3	main
raha	doc_685122975268_item	2814194	et	4	main
mis	doc_685122975268_item	2814195	et	4	main
teooriat	doc_685122975268_item	2814210	et	3	main
vähenõudlikest	doc_685122975268_item	2814211	et	3	main
ümber	doc_685122975268_item	2814213	et	3	main
põlvkonnast	doc_685122975268_item	2814212	et	4	main
probleem	doc_685122975268_item	2814214	et	3	main
mida	doc_685122975268_item	2814215	et	4	main
peaks	doc_685122975268_item	2814216	et	4	main
tõesti	doc_685122975268_item	2814217	et	3	main
arvesse	doc_685122975268_item	2814218	et	4	main
võtma	doc_685122975268_item	2814219	et	3	main
seisneb	doc_685122975268_item	2814220	et	3	main
koolilaps	doc_685122975268_item	2814233	et	4	main
hakkab	doc_685122975268_item	2814239	et	3	main
tulevikus	doc_685122975268_item	2814240	et	4	main
õppima	doc_685122975268_item	2814241	et	3	main
vaja	doc_685122975268_item	2814253	et	4	main
palju	doc_685122975268_item	2814254	et	4	main
eluaspekte	doc_685122975268_item	2814255	et	3	main
seda	doc_685122975268_item	2814263	et	3	main
m	doc_685122975270_item	2814473	et	4	main
õpin	doc_685122975270_item	2814481	et	3	main
tulevikus	doc_685122975270_item	2814484	et	4	main
leia	doc_685122975270_item	2814486	et	4	main
midagi	doc_685122975270_item	2814528	et	4	main
majandus	doc_685122975270_item	2814536	et	4	main
juura	doc_685122975270_item	2814538	et	4	main
ja	doc_685122975270_item	2814539	et	3	main
psühholoog	doc_685122975270_item	2814540	et	4	main
mõtlen	doc_685122975270_item	2814541	et	3	main
et	doc_685122975270_item	2814542	et	3	main
praegu	doc_685122975270_item	2814543	et	3	main
neid	doc_685122975270_item	2814550	et	4	main
ja	doc_685122975270_item	2814553	et	3	main
rahu	doc_685122975268_item	2814130	et	4	main
kodune	doc_685122975268_item	2814131	et	4	main
idüll	doc_685122975268_item	2814132	et	3	main
on	doc_685122975268_item	2814133	et	4	main
teised	doc_685122975268_item	2814138	et	4	main
selles	doc_685122975268_item	2814144	et	4	main
ma	doc_685122975268_item	2814148	et	3	main
arvan	doc_685122975268_item	2814149	et	3	main
et	doc_685122975268_item	2814150	et	3	main
tuhat	doc_685122975268_item	2814158	et	4	main
vaevalt	doc_685122975268_item	2814164	et	4	main
inimese	doc_685122975268_item	2814180	et	4	main
loomulik	doc_685122975268_item	2814181	et	3	main
gümnaasiumi	doc_685122975268_item	2814188	et	4	main
mis	doc_685122975268_item	2814204	et	4	main
lükkab	doc_685122975268_item	2814208	et	3	main
selles	doc_685122975268_item	2814221	et	4	main
tea	doc_685122975268_item	2814226	et	4	main
arust	doc_685122975268_item	2814231	et	4	main
ta	doc_685122975268_item	2814238	et	4	main
saada	doc_685122975268_item	2814244	et	4	main
spetsialistiks	doc_685122975268_item	2814246	et	3	main
õige	doc_685122975268_item	2814260	et	4	main
hakkama	doc_685122975268_item	2814294	et	3	main
3122005	doc_685122975268_item	2814302	et	2	main
jürgen	doc_685122975270_item	2814474	et	4	main
on	doc_685122975270_item	2814477	et	4	main
perekonnanimi	doc_685122975270_item	2814479	et	3	main
tööd	doc_685122975270_item	2814487	et	4	main
tahavad	doc_685122975270_item	2814522	et	3	main
pappi	doc_685122975270_item	2814524	et	4	main
sotsiaaltöötaja	doc_685122975270_item	2814535	et	4	main
on	doc_685122975270_item	2814545	et	4	main
trendikad	doc_685122975270_item	2814547	et	4	main
tulevad	doc_685122975270_item	2814551	et	4	main
oluline	doc_685122975270_item	2814568	et	4	main
ainult	doc_685122975270_item	2814578	et	4	main
saad	doc_685122975270_item	2814581	et	4	main
kandideerida	doc_685122975270_item	2814582	et	3	main
näiteks	doc_685122975270_item	2814589	et	4	main
psühholoogiks	doc_685122975270_item	2814590	et	4	main
lõpetavad	doc_685122975270_item	2814593	et	4	main
ülikooli	doc_685122975270_item	2814594	et	4	main
ja	doc_685122975270_item	2814595	et	3	main
et	doc_685122975268_item	2814222	et	3	main
noored	doc_685122975268_item	2814224	et	3	main
mis	doc_685122975268_item	2814227	et	4	main
neist	doc_685122975268_item	2814228	et	4	main
minu	doc_685122975268_item	2814230	et	3	main
viieteistkümneaastane	doc_685122975268_item	2814232	et	4	main
on	doc_685122975268_item	2814252	et	4	main
sooritamist	doc_685122975268_item	2814269	et	4	main
vaid	doc_685122975268_item	2814270	et	3	main
juba	doc_685122975268_item	2814271	et	3	main
pärast	doc_685122975268_item	2814272	et	4	main
üheksanda	doc_685122975268_item	2814273	et	3	main
klassi	doc_685122975268_item	2814274	et	4	main
lõpetamist	doc_685122975268_item	2814275	et	4	main
olen	doc_685122975268_item	2814276	et	3	main
kindel	doc_685122975268_item	2814277	et	3	main
et	doc_685122975268_item	2814278	et	3	main
paljud	doc_685122975268_item	2814279	et	3	main
nõustuvad	doc_685122975268_item	2814280	et	4	main
minu	doc_685122975268_item	2814281	et	3	main
arvamusega	doc_685122975268_item	2814282	et	3	main
loodan	doc_685122975268_item	2814283	et	3	main
et	doc_685122975268_item	2814284	et	3	main
teie	doc_685122975268_item	2814285	et	4	main
artikkel	doc_685122975268_item	2814286	et	3	main
paneb	doc_685122975268_item	2814287	et	3	main
noori	doc_685122975268_item	2814288	et	3	main
oma	doc_685122975268_item	2814289	et	4	main
tuleviku	doc_685122975268_item	2814290	et	4	main
üle	doc_685122975268_item	2814291	et	3	main
järele	doc_685122975268_item	2814292	et	4	main
mõtlema	doc_685122975268_item	2814293	et	3	main
soovin	doc_685122975268_item	2814295	et	3	main
eesnimi	doc_685122975268_item	2814300	et	3	main
minu	doc_685122975270_item	2814475	et	3	main
praegu	doc_685122975270_item	2814480	et	3	main
energeetikateaduskonnas	doc_685122975270_item	2814483	et	4	main
lp	doc_685122975270_item	2814472	et	4	main
ttü-s	doc_685122975270_item	2814482	et	3	main
soovin	doc_685122975270_item	2814485	et	3	main
seotud	doc_685122975270_item	2814488	et	4	main
oma	doc_685122975270_item	2814489	et	4	main
erialaga	doc_685122975270_item	2814490	et	3	main
lugesin	doc_685122975270_item	2814491	et	3	main
ära	doc_685122975270_item	2814492	et	4	main
teie	doc_685122975270_item	2814493	et	4	main
artiiklit	doc_685122975270_item	2814494	et	4	main
mind	doc_685122975270_item	2814496	et	4	main
väga	doc_685122975270_item	2814497	et	3	main
huvitas	doc_685122975270_item	2814498	et	3	main
ja	doc_685122975270_item	2814495	et	3	main
teema	doc_685122975270_item	2814499	et	4	main
meile	doc_685122975270_item	2814500	et	4	main
jaoks	doc_685122975270_item	2814501	et	4	main
ta	doc_685122975270_item	2814502	et	4	main
on	doc_685122975270_item	2814503	et	4	main
aktuaalne	doc_685122975270_item	2814504	et	3	main
tahaks	doc_685122975270_item	2814505	et	3	main
öelda	doc_685122975270_item	2814506	et	4	main
et	doc_685122975270_item	2814507	et	3	main
tänapäeval	doc_685122975270_item	2814508	et	3	main
on	doc_685122975270_item	2814509	et	4	main
üsna	doc_685122975270_item	2814510	et	3	main
vähe	doc_685122975270_item	2814511	et	3	main
inimest	doc_685122975270_item	2814512	et	3	main
kes	doc_685122975270_item	2814513	et	4	main
tõesti	doc_685122975270_item	2814514	et	3	main
soovivad	doc_685122975270_item	2814515	et	4	main
töötada	doc_685122975270_item	2814516	et	3	main
vaid	doc_685122975270_item	2814517	et	3	main
õppida	doc_685122975270_item	2814518	et	3	main
minu	doc_685122975270_item	2814519	et	3	main
arvatest	doc_685122975270_item	2814520	et	3	main
on	doc_685122975270_item	2814533	et	4	main
pangandus	doc_685122975270_item	2814537	et	3	main
lihtsalt	doc_685122975270_item	2814546	et	4	main
iga	doc_685122975270_item	2814548	et	4	main
teha	doc_685122975270_item	2814529	et	3	main
popuulaarsemad	doc_685122975270_item	2814531	et	4	main
õpetaja	doc_685122975270_item	2814534	et	4	main
nad	doc_685122975270_item	2814544	et	3	main
rohkem	doc_685122975270_item	2814552	et	4	main
rohkem	doc_685122975270_item	2814554	et	4	main
mõned	doc_685122975270_item	2814555	et	3	main
lähevad	doc_685122975270_item	2814556	et	3	main
õppima	doc_685122975270_item	2814558	et	3	main
ja	doc_685122975270_item	2814559	et	3	main
loobuvad	doc_685122975270_item	2814560	et	4	main
midagi	doc_685122975270_item	2814557	et	4	main
tulevases	doc_685122975270_item	2814561	et	4	main
erialas	doc_685122975270_item	2814562	et	3	main
aasta	doc_685122975270_item	2814549	et	4	main
jõuda	doc_685122975270_item	2814564	et	3	main
õppimise	doc_685122975270_item	2814565	et	4	main
aga	doc_685122975270_item	2814571	et	3	main
sellel	doc_685122975270_item	2814579	et	4	main
töökohale	doc_685122975270_item	2814584	et	4	main
või	doc_685122975270_item	2814591	et	4	main
piisav	doc_685122975270_item	2814610	et	4	main
raha	doc_685122975270_item	2814612	et	4	main
tõesti	doc_685122975270_item	2814614	et	3	main
mõtlevad	doc_685122975270_item	2814625	et	4	main
raha	doc_685122975270_item	2814627	et	4	main
ole	doc_685122975270_item	2814629	et	4	main
esmatahtis	doc_685122975270_item	2814630	et	4	main
ma	doc_685122975270_item	2814631	et	3	main
olen	doc_685122975270_item	2814632	et	3	main
et	doc_685122975270_item	2814636	et	3	main
töötamise	doc_685122975270_item	2814645	et	4	main
head	doc_685122975270_item	2814653	et	4	main
artiikel	doc_685122975270_item	2814673	et	4	main
paljudele	doc_685122975270_item	2814691	et	3	main
lugesin	doc_685122975271_item	2814721	et	3	main
oli	doc_685122975271_item	2814729	et	3	main
ma	doc_685122975271_item	2814738	et	3	main
vanemaid	doc_685122975271_item	2814749	et	4	main
oma	doc_685122975271_item	2814754	et	4	main
kogu	doc_685122975271_item	2814759	et	4	main
ei	doc_685122975271_item	2814765	et	4	main
annavad	doc_685122975271_item	2814766	et	3	main
tähelepannu	doc_685122975271_item	2814767	et	4	main
eeskätt	doc_685122975271_item	2814768	et	3	main
lapsel	doc_685122975271_item	2814769	et	4	main
ütleda	doc_685122975271_item	2814777	et	4	main
nendel	doc_685122975271_item	2814808	et	4	main
mida	doc_685122975271_item	2814814	et	4	main
nägu	doc_685122975271_item	2814827	et	4	main
kõik	doc_685122975271_item	2814831	et	4	main
ja	doc_685122975271_item	2814832	et	3	main
praegu	doc_685122975271_item	2814833	et	3	main
tööle	doc_685122975271_item	2814849	et	3	main
olin	doc_685122975271_item	2814856	et	3	main
tööandjad	doc_685122975271_item	2814868	et	3	main
tööle	doc_685122975271_item	2814871	et	3	main
ses	doc_685122975271_item	2814873	et	3	main
noored	doc_685122975271_item	2814876	et	3	main
tarksed	doc_685122975271_item	2814892	et	4	main
noor	doc_685122975271_item	2814893	et	3	main
inimesed	doc_685122975271_item	2814894	et	3	main
kes	doc_685122975271_item	2814895	et	4	main
palju	doc_685122975272_item	2814925	et	4	main
ja	doc_685122975272_item	2814927	et	3	main
lisada	doc_685122975272_item	2814943	et	3	main
ja	doc_685122975272_item	2814944	et	3	main
läbi	doc_685122975272_item	2814945	et	4	main
arutada	doc_685122975272_item	2814946	et	3	main
saada	doc_685122975272_item	2814961	et	4	main
ja	doc_685122975272_item	2814967	et	3	main
lihtne	doc_685122975272_item	2814975	et	3	main
on	doc_685122975272_item	2814984	et	4	main
ja	doc_685122975272_item	2815024	et	3	main
olen	doc_685122975272_item	2815026	et	3	main
kes	doc_685122975272_item	2815030	et	4	main
rääkivad	doc_685122975272_item	2815031	et	4	main
selge	doc_685122975272_item	2815034	et	4	main
piir	doc_685122975272_item	2815035	et	3	main
ongi	doc_685122975272_item	2815043	et	4	main
et	doc_685122975272_item	2815054	et	3	main
tööta	doc_685122975272_item	2815062	et	4	main
ja	doc_685122975272_item	2815063	et	3	main
võib	doc_685122975272_item	2815075	et	3	main
oma	doc_685122975272_item	2815079	et	4	main
nõus	doc_685122975272_item	2815082	et	4	main
rahata	doc_685122975272_item	2815084	et	4	main
teil	doc_685122975272_item	2815086	et	4	main
vist	doc_685122975272_item	2815102	et	4	main
selgusele	doc_685122975270_item	2814563	et	4	main
saada	doc_685122975270_item	2814569	et	4	main
mitte	doc_685122975270_item	2814572	et	3	main
õppivad	doc_685122975270_item	2814588	et	4	main
leia	doc_685122975270_item	2814598	et	4	main
eriala	doc_685122975270_item	2814607	et	4	main
suure	doc_685122975270_item	2814611	et	3	main
saamiseks	doc_685122975270_item	2814613	et	4	main
oluline	doc_685122975270_item	2814616	et	4	main
kes	doc_685122975270_item	2814624	et	4	main
tervet	doc_685122975270_item	2814643	et	4	main
peale	doc_685122975270_item	2814646	et	4	main
palju	doc_685122975270_item	2814651	et	4	main
muud	doc_685122975270_item	2814652	et	4	main
andma	doc_685122975270_item	2814657	et	3	main
arenguks	doc_685122975270_item	2814659	et	3	main
paigalseisuks	doc_685122975270_item	2814661	et	3	main
märkida	doc_685122975270_item	2814664	et	4	main
virelda	doc_685122975270_item	2814666	et	4	main
ka	doc_685122975270_item	2814667	et	3	main
kui	doc_685122975270_item	2814678	et	3	main
muljed	doc_685122975270_item	2814683	et	3	main
mitte	doc_685122975270_item	2814686	et	3	main
kõrgharidus	doc_685122975270_item	2814570	et	3	main
bakalauruse	doc_685122975270_item	2814573	et	4	main
juhul	doc_685122975270_item	2814580	et	3	main
hea	doc_685122975270_item	2814583	et	4	main
tööd	doc_685122975270_item	2814599	et	4	main
miks	doc_685122975270_item	2814600	et	4	main
see	doc_685122975270_item	2814608	et	3	main
suhtumine	doc_685122975270_item	2814618	et	4	main
oma	doc_685122975270_item	2814619	et	4	main
tööle	doc_685122975270_item	2814620	et	3	main
magistriks	doc_685122975270_item	2814577	et	3	main
enamus	doc_685122975270_item	2814585	et	4	main
inimest	doc_685122975270_item	2814586	et	3	main
kes	doc_685122975270_item	2814587	et	4	main
sotsiaaltöötajaks	doc_685122975270_item	2814592	et	4	main
on	doc_685122975270_item	2814615	et	4	main
muidugi	doc_685122975270_item	2814621	et	4	main
sellised	doc_685122975270_item	2814623	et	4	main
ei	doc_685122975270_item	2814628	et	4	main
põhiline	doc_685122975270_item	2814635	et	3	main
töö	doc_685122975270_item	2814637	et	4	main
pakkuks	doc_685122975270_item	2814638	et	4	main
raisata	doc_685122975270_item	2814647	et	4	main
töökoht	doc_685122975270_item	2814655	et	3	main
mitte	doc_685122975270_item	2814660	et	3	main
aga	doc_685122975270_item	2814662	et	3	main
et	doc_685122975270_item	2814665	et	3	main
päris	doc_685122975270_item	2814674	et	4	main
hästi	doc_685122975270_item	2814675	et	3	main
seletas	doc_685122975270_item	2814676	et	3	main
noormehele	doc_685122975270_item	2814677	et	3	main
vaidlus	doc_685122975271_item	2814732	et	3	main
oma	doc_685122975271_item	2814735	et	4	main
täiesti	doc_685122975271_item	2814740	et	3	main
teie	doc_685122975271_item	2814742	et	4	main
lapsed	doc_685122975271_item	2814745	et	3	main
ei	doc_685122975271_item	2814752	et	4	main
ostavad	doc_685122975271_item	2814761	et	3	main
lapsele	doc_685122975271_item	2814762	et	4	main
mänguasjad	doc_685122975271_item	2814763	et	3	main
aga	doc_685122975271_item	2814764	et	3	main
on	doc_685122975271_item	2814770	et	4	main
vanemate	doc_685122975271_item	2814772	et	4	main
ei	doc_685122975271_item	2814775	et	4	main
mul	doc_685122975271_item	2814779	et	3	main
nad	doc_685122975271_item	2814815	et	3	main
nad	doc_685122975271_item	2814829	et	3	main
ma	doc_685122975271_item	2814839	et	3	main
tahaksin	doc_685122975271_item	2814840	et	3	main
minna	doc_685122975271_item	2814841	et	3	main
kõik	doc_685122975271_item	2814844	et	4	main
tööandjad	doc_685122975271_item	2814845	et	3	main
ei	doc_685122975271_item	2814846	et	4	main
tahaks	doc_685122975271_item	2814847	et	3	main
sest	doc_685122975271_item	2814851	et	4	main
nad	doc_685122975271_item	2814860	et	3	main
minus	doc_685122975271_item	2814862	et	3	main
saan	doc_685122975271_item	2814866	et	4	main
taha	doc_685122975271_item	2814880	et	4	main
õppida	doc_685122975271_item	2814881	et	3	main
töötada	doc_685122975271_item	2814882	et	3	main
õnneks	doc_685122975271_item	2814887	et	4	main
on	doc_685122975271_item	2814889	et	4	main
veel	doc_685122975271_item	2814890	et	4	main
mida	doc_685122975271_item	2814897	et	4	main
firmas	doc_685122975272_item	2814922	et	3	main
artikleid	doc_685122975272_item	2814926	et	3	main
teie	doc_685122975272_item	2814928	et	4	main
aga	doc_685122975272_item	2814934	et	3	main
kirjutan	doc_685122975272_item	2814935	et	3	main
teile	doc_685122975272_item	2814936	et	4	main
sellepärast	doc_685122975272_item	2814937	et	3	main
et	doc_685122975272_item	2814938	et	3	main
tahan	doc_685122975272_item	2814939	et	3	main
ka	doc_685122975272_item	2814940	et	3	main
midagi	doc_685122975272_item	2814941	et	4	main
teema	doc_685122975272_item	2814949	et	4	main
eriala	doc_685122975272_item	2814951	et	4	main
õppima	doc_685122975272_item	2814953	et	3	main
on	doc_685122975272_item	2814962	et	4	main
päris	doc_685122975272_item	2814963	et	4	main
aktuaalne	doc_685122975272_item	2814964	et	3	main
meie	doc_685122975272_item	2814965	et	4	main
eriala	doc_685122975272_item	2814969	et	4	main
ei	doc_685122975272_item	2814973	et	4	main
ole	doc_685122975272_item	2814974	et	4	main
ole	doc_685122975272_item	2815019	et	4	main
võimalust	doc_685122975272_item	2815020	et	3	main
ei	doc_685122975270_item	2814596	et	4	main
saa	doc_685122975270_item	2814597	et	4	main
on	doc_685122975270_item	2814601	et	4	main
nii	doc_685122975270_item	2814602	et	3	main
inimesed	doc_685122975270_item	2814603	et	3	main
arvavad	doc_685122975270_item	2814604	et	4	main
et	doc_685122975270_item	2814605	et	3	main
moodne	doc_685122975270_item	2814606	et	3	main
on	doc_685122975270_item	2814609	et	4	main
hea	doc_685122975270_item	2814617	et	4	main
et	doc_685122975270_item	2814626	et	3	main
naudingut	doc_685122975270_item	2814639	et	3	main
ma	doc_685122975270_item	2814640	et	3	main
ei	doc_685122975270_item	2814641	et	4	main
tahaks	doc_685122975270_item	2814642	et	3	main
on	doc_685122975270_item	2814650	et	4	main
saa	doc_685122975270_item	2814669	et	4	main
igal	doc_685122975270_item	2814670	et	3	main
juhul	doc_685122975270_item	2814671	et	3	main
teie	doc_685122975270_item	2814672	et	4	main
on	doc_685122975270_item	2814679	et	4	main
saada	doc_685122975270_item	2814681	et	4	main
tööst	doc_685122975270_item	2814684	et	3	main
raha	doc_685122975270_item	2814687	et	4	main
saamiseks	doc_685122975270_item	2814688	et	4	main
loodan	doc_685122975270_item	2814689	et	3	main
et	doc_685122975270_item	2814690	et	3	main
inimestele	doc_685122975270_item	2814692	et	3	main
teie	doc_685122975271_item	2814722	et	4	main
vähenõudlike	doc_685122975271_item	2814724	et	3	main
tõsine	doc_685122975271_item	2814731	et	4	main
oma	doc_685122975271_item	2814748	et	4	main
ole	doc_685122975271_item	2814753	et	4	main
vanemad	doc_685122975271_item	2814757	et	4	main
või	doc_685122975271_item	2814776	et	4	main
endale	doc_685122975271_item	2814812	et	4	main
või	doc_685122975271_item	2814817	et	4	main
neljakümnesed	doc_685122975271_item	2814828	et	3	main
tahavad	doc_685122975271_item	2814830	et	3	main
aga	doc_685122975271_item	2814834	et	3	main
on	doc_685122975271_item	2814836	et	4	main
suvel	doc_685122975271_item	2814838	et	3	main
võtta	doc_685122975271_item	2814850	et	3	main
nii	doc_685122975271_item	2814857	et	3	main
praegu	doc_685122975271_item	2814864	et	3	main
ei	doc_685122975271_item	2814869	et	4	main
et	doc_685122975271_item	2814874	et	3	main
on	doc_685122975271_item	2814877	et	4	main
vastustundetu	doc_685122975271_item	2814878	et	4	main
aga	doc_685122975271_item	2814885	et	3	main
palju	doc_685122975271_item	2814886	et	4	main
et	doc_685122975271_item	2814888	et	3	main
teavad	doc_685122975271_item	2814896	et	3	main
nad	doc_685122975271_item	2814898	et	3	main
tahavad	doc_685122975271_item	2814899	et	3	main
lugesin	doc_685122975272_item	2814924	et	3	main
meeldis	doc_685122975272_item	2814931	et	3	main
juurde	doc_685122975272_item	2814942	et	4	main
selline	doc_685122975272_item	2814948	et	4	main
lähed	doc_685122975272_item	2814954	et	3	main
minu	doc_685122975272_item	2814968	et	3	main
alustades	doc_685122975272_item	2814976	et	3	main
pingereast	doc_685122975272_item	2814978	et	4	main
mina	doc_685122975272_item	2815025	et	4	main
on	doc_685122975272_item	2815036	et	4	main
10000	doc_685122975272_item	2815037	et	2	main
krooni	doc_685122975272_item	2815038	et	4	main
kohe	doc_685122975272_item	2815039	et	4	main
peab	doc_685122975272_item	2815046	et	4	main
nendega	doc_685122975272_item	2815051	et	4	main
kes	doc_685122975272_item	2815052	et	4	main
võib	doc_685122975272_item	2815058	et	3	main
kasutu	doc_685122975272_item	2815072	et	4	main
inimene	doc_685122975272_item	2815073	et	3	main
olla	doc_685122975272_item	2815076	et	3	main
armastab	doc_685122975272_item	2815078	et	3	main
tööd	doc_685122975272_item	2815080	et	4	main
ilma	doc_685122975272_item	2815083	et	4	main
töötada	doc_685122975272_item	2815085	et	3	main
meeles	doc_685122975272_item	2815093	et	3	main
siiamaani	doc_685122975272_item	2815095	et	3	main
mina	doc_685122975272_item	2815107	et	4	main
on	doc_685122975270_item	2814622	et	4	main
nendega	doc_685122975270_item	2814633	et	4	main
nõus	doc_685122975270_item	2814634	et	4	main
elu	doc_685122975270_item	2814644	et	4	main
vaid	doc_685122975270_item	2814648	et	3	main
elus	doc_685122975270_item	2814649	et	4	main
asju	doc_685122975270_item	2814654	et	3	main
peab	doc_685122975270_item	2814656	et	4	main
võimalust	doc_685122975270_item	2814658	et	3	main
tahaks	doc_685122975270_item	2814663	et	3	main
ei	doc_685122975270_item	2814668	et	4	main
oluline	doc_685122975270_item	2814680	et	4	main
positiivsed	doc_685122975270_item	2814682	et	3	main
vaid	doc_685122975270_item	2814685	et	3	main
teie	doc_685122975270_item	2814693	et	4	main
aitas	doc_685122975270_item	2814695	et	3	main
artiikel	doc_685122975270_item	2814694	et	4	main
tänan	doc_685122975270_item	2814696	et	3	main
teid	doc_685122975270_item	2814697	et	4	main
väga	doc_685122975270_item	2814698	et	3	main
lugupidamisega	doc_685122975270_item	2814699	et	3	main
eesnimi	doc_685122975270_item	2814700	et	3	main
perekonnanimi	doc_685122975270_item	2814701	et	3	main
kiri	doc_685122975271_item	2814703	et	3	main
tere	doc_685122975271_item	2814704	et	3	main
httpwwwekspresseeviewdoc54f0555e004dbacec2257186002b9be3	doc_685122975270_item	2814702	et	4	main
lugupeetud	doc_685122975271_item	2814705	et	4	main
tiina	doc_685122975271_item	2814706	et	4	main
kaalep	doc_685122975271_item	2814707	et	4	main
minu	doc_685122975271_item	2814708	et	3	main
nimi	doc_685122975271_item	2814709	et	3	main
on	doc_685122975271_item	2814710	et	4	main
eesnimi	doc_685122975271_item	2814711	et	3	main
perekonnanimi	doc_685122975271_item	2814712	et	3	main
ma	doc_685122975271_item	2814713	et	3	main
on	doc_685122975271_item	2814714	et	4	main
tallinna	doc_685122975271_item	2814715	et	4	main
tehnika	doc_685122975271_item	2814716	et	4	main
ülikooli	doc_685122975271_item	2814717	et	4	main
üliõpilane	doc_685122975271_item	2814718	et	3	main
eile	doc_685122975271_item	2814719	et	3	main
ma	doc_685122975271_item	2814720	et	3	main
artikkel	doc_685122975271_item	2814723	et	3	main
põlvkond	doc_685122975271_item	2814725	et	3	main
mul	doc_685122975271_item	2814728	et	3	main
sellel	doc_685122975271_item	2814733	et	4	main
olen	doc_685122975271_item	2814739	et	3	main
et	doc_685122975271_item	2814744	et	3	main
kodus	doc_685122975271_item	2814750	et	4	main
idulli	doc_685122975271_item	2814755	et	4	main
hool	doc_685122975271_item	2814773	et	4	main
ma	doc_685122975271_item	2814774	et	3	main
et	doc_685122975271_item	2814778	et	3	main
pärast	doc_685122975271_item	2814726	et	4	main
seda	doc_685122975271_item	2814727	et	3	main
väga	doc_685122975271_item	2814730	et	3	main
teemal	doc_685122975271_item	2814734	et	3	main
noorte	doc_685122975271_item	2814736	et	3	main
vennaga	doc_685122975271_item	2814737	et	3	main
nõus	doc_685122975271_item	2814741	et	4	main
arvamusega	doc_685122975271_item	2814743	et	3	main
ei	doc_685122975271_item	2814746	et	4	main
näe	doc_685122975271_item	2814747	et	4	main
nendel	doc_685122975271_item	2814751	et	4	main
kõik	doc_685122975271_item	2814756	et	4	main
töötavad	doc_685122975271_item	2814758	et	4	main
aeg	doc_685122975271_item	2814760	et	3	main
vaja	doc_685122975271_item	2814771	et	4	main
oli	doc_685122975271_item	2814780	et	3	main
väga	doc_685122975271_item	2814781	et	3	main
rikkas	doc_685122975271_item	2814782	et	4	main
lapsepõlves	doc_685122975271_item	2814783	et	4	main
aga	doc_685122975271_item	2814784	et	3	main
praegu	doc_685122975271_item	2814785	et	3	main
ma	doc_685122975271_item	2814786	et	3	main
iga	doc_685122975271_item	2814787	et	4	main
päev	doc_685122975271_item	2814788	et	3	main
ütlen	doc_685122975271_item	2814789	et	3	main
emale	doc_685122975271_item	2814790	et	3	main
aitäh	doc_685122975271_item	2814791	et	3	main
et	doc_685122975271_item	2814792	et	3	main
sa	doc_685122975271_item	2814793	et	3	main
oli	doc_685122975271_item	2814794	et	3	main
minu	doc_685122975271_item	2814795	et	3	main
juures	doc_685122975271_item	2814796	et	4	main
ja	doc_685122975271_item	2814797	et	3	main
õpis	doc_685122975271_item	2814798	et	3	main
mind	doc_685122975271_item	2814799	et	4	main
väga	doc_685122975271_item	2814800	et	3	main
paljudele	doc_685122975271_item	2814801	et	3	main
elu	doc_685122975271_item	2814802	et	4	main
asjadele	doc_685122975271_item	2814803	et	3	main
kõik	doc_685122975271_item	2814804	et	4	main
üles	doc_685122975271_item	2814805	et	3	main
kasvavad	doc_685122975271_item	2814806	et	4	main
ja	doc_685122975271_item	2814807	et	3	main
kõik	doc_685122975271_item	2814813	et	4	main
või	doc_685122975271_item	2814820	et	4	main
on	doc_685122975271_item	2814809	et	4	main
võimalus	doc_685122975271_item	2814810	et	3	main
osta	doc_685122975271_item	2814811	et	4	main
tahaksid	doc_685122975271_item	2814816	et	4	main
minna	doc_685122975271_item	2814818	et	3	main
välismaale	doc_685122975271_item	2814819	et	4	main
veel	doc_685122975271_item	2814821	et	4	main
mind	doc_685122975271_item	2814848	et	4	main
ma	doc_685122975271_item	2814852	et	3	main
noor	doc_685122975271_item	2814854	et	3	main
et	doc_685122975271_item	2814859	et	3	main
kahtlevad	doc_685122975271_item	2814861	et	4	main
kõik	doc_685122975271_item	2814865	et	4	main
aru	doc_685122975271_item	2814867	et	4	main
tahaksid	doc_685122975271_item	2814870	et	4	main
võtta	doc_685122975271_item	2814872	et	3	main
praegu	doc_685122975271_item	2814875	et	3	main
mitte	doc_685122975271_item	2814883	et	3	main
midagi	doc_685122975271_item	2814822	et	4	main
kahjuks	doc_685122975271_item	2814823	et	4	main
kahekümneaastlased	doc_685122975271_item	2814824	et	4	main
tahavad	doc_685122975271_item	2814825	et	3	main
elada	doc_685122975271_item	2814826	et	3	main
see	doc_685122975271_item	2814835	et	3	main
võimatu	doc_685122975271_item	2814837	et	4	main
tööle	doc_685122975271_item	2814842	et	3	main
ja	doc_685122975271_item	2814843	et	3	main
olen	doc_685122975271_item	2814853	et	3	main
ma	doc_685122975271_item	2814855	et	3	main
kurb	doc_685122975271_item	2814858	et	3	main
aga	doc_685122975271_item	2814863	et	3	main
ei	doc_685122975271_item	2814879	et	4	main
kõik	doc_685122975271_item	2814884	et	4	main
head	doc_685122975271_item	2814891	et	4	main
ja	doc_685122975271_item	2814900	et	3	main
mida	doc_685122975271_item	2814901	et	4	main
peavad	doc_685122975271_item	2814902	et	4	main
teha	doc_685122975271_item	2814903	et	3	main
seda	doc_685122975271_item	2814904	et	3	main
elus	doc_685122975271_item	2814905	et	4	main
paremate	doc_685122975271_item	2814906	et	4	main
soovidega	doc_685122975271_item	2814907	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975271_item	2814908	et	4	main
kiri	doc_685122975272_item	2814909	et	3	main
lugupeetud	doc_685122975272_item	2814910	et	4	main
m	doc_685122975272_item	2814911	et	4	main
jirgeni	doc_685122975272_item	2814912	et	4	main
mina	doc_685122975272_item	2814913	et	4	main
olen	doc_685122975272_item	2814914	et	3	main
eesnimi	doc_685122975272_item	2814915	et	3	main
perekonnanimi	doc_685122975272_item	2814916	et	3	main
ja	doc_685122975272_item	2814917	et	3	main
töötan	doc_685122975272_item	2814918	et	3	main
juristina	doc_685122975272_item	2814919	et	3	main
ühes	doc_685122975272_item	2814920	et	4	main
suures	doc_685122975272_item	2814921	et	3	main
artikkel	doc_685122975272_item	2814929	et	3	main
kõige	doc_685122975272_item	2814932	et	4	main
sest	doc_685122975272_item	2814947	et	4	main
ja	doc_685122975272_item	2814955	et	3	main
palju	doc_685122975272_item	2814957	et	4	main
tulevikus	doc_685122975272_item	2814958	et	4	main
valdkonnas	doc_685122975272_item	2814971	et	4	main
üldse	doc_685122975272_item	2814972	et	3	main
sellest	doc_685122975272_item	2814980	et	4	main
keskkonnakaitse	doc_685122975272_item	2814982	et	4	main
valdkond	doc_685122975272_item	2814983	et	3	main
tööle	doc_685122975272_item	2815022	et	3	main
täitsa	doc_685122975272_item	2815027	et	3	main
inimestega	doc_685122975272_item	2815029	et	3	main
et	doc_685122975272_item	2815032	et	3	main
rahaküsimuse	doc_685122975272_item	2815033	et	3	main
kätte	doc_685122975272_item	2815040	et	4	main
noh	doc_685122975272_item	2815041	et	3	main
see	doc_685122975272_item	2815042	et	3	main
mis	doc_685122975272_item	2815045	et	4	main
rääkivad	doc_685122975272_item	2815053	et	4	main
pole	doc_685122975272_item	2815056	et	3	main
eestis	doc_685122975272_item	2814923	et	3	main
mulle	doc_685122975272_item	2814930	et	4	main
rohkem	doc_685122975272_item	2814933	et	4	main
mis	doc_685122975272_item	2814950	et	4	main
sa	doc_685122975272_item	2814952	et	3	main
kui	doc_685122975272_item	2814956	et	3	main
palka	doc_685122975272_item	2814959	et	4	main
tahad	doc_685122975272_item	2814960	et	3	main
maailmas	doc_685122975272_item	2814966	et	3	main
selles	doc_685122975272_item	2814970	et	4	main
elukutsete	doc_685122975272_item	2814977	et	3	main
rääkida	doc_685122975272_item	2814979	et	3	main
et	doc_685122975272_item	2814981	et	3	main
üsna	doc_685122975272_item	2814985	et	3	main
kõige	doc_685122975272_item	2814986	et	4	main
perspektiivne	doc_685122975272_item	2814987	et	3	main
ei	doc_685122975272_item	2814988	et	4	main
sest	doc_685122975272_item	2814990	et	4	main
tohi	doc_685122975272_item	2814989	et	4	main
meil	doc_685122975272_item	2814991	et	4	main
peab	doc_685122975272_item	2814992	et	4	main
eksisteerima	doc_685122975272_item	2814993	et	4	main
sõltuvus	doc_685122975272_item	2814995	et	4	main
võrdne	doc_685122975272_item	2814994	et	3	main
igas	doc_685122975272_item	2814996	et	3	main
elukutses	doc_685122975272_item	2814997	et	4	main
on	doc_685122975272_item	2814998	et	4	main
oma	doc_685122975272_item	2814999	et	4	main
maailm	doc_685122975272_item	2815000	et	3	main
kus	doc_685122975272_item	2815001	et	3	main
töötavad	doc_685122975272_item	2815002	et	4	main
proffessionaalid	doc_685122975272_item	2815003	et	4	main
need	doc_685122975272_item	2815004	et	3	main
inimesed	doc_685122975272_item	2815005	et	3	main
kes	doc_685122975272_item	2815006	et	4	main
teevad	doc_685122975272_item	2815007	et	3	main
oma	doc_685122975272_item	2815008	et	4	main
tööd	doc_685122975272_item	2815009	et	4	main
ja	doc_685122975272_item	2815010	et	3	main
kes	doc_685122975272_item	2815011	et	4	main
lihtsalt	doc_685122975272_item	2815012	et	4	main
töötavad	doc_685122975272_item	2815013	et	4	main
raha	doc_685122975272_item	2815014	et	4	main
pärast	doc_685122975272_item	2815015	et	4	main
lihtsalt	doc_685122975272_item	2815016	et	4	main
nemadel	doc_685122975272_item	2815017	et	4	main
ei	doc_685122975272_item	2815018	et	4	main
hea	doc_685122975272_item	2815021	et	4	main
nõus	doc_685122975272_item	2815028	et	4	main
meie	doc_685122975272_item	2815048	et	4	main
aga	doc_685122975272_item	2815050	et	3	main
palk	doc_685122975272_item	2815055	et	3	main
oluline	doc_685122975272_item	2815057	et	4	main
olla	doc_685122975272_item	2815059	et	3	main
raha	doc_685122975272_item	2815067	et	4	main
minu	doc_685122975272_item	2815070	et	3	main
arust	doc_685122975272_item	2815071	et	4	main
ja	doc_685122975272_item	2815094	et	3	main
astu	doc_685122975272_item	2815101	et	4	main
keegi	doc_685122975272_item	2815103	et	4	main
raha	doc_685122975272_item	2815104	et	4	main
pärast	doc_685122975272_item	2815122	et	4	main
küll	doc_685122975272_item	2815123	et	4	main
nad	doc_685122975272_item	2815124	et	3	main
tahtmata	doc_685122975272_item	2815132	et	4	main
mingit	doc_685122975272_item	2815138	et	3	main
nendega	doc_685122975272_item	2815140	et	4	main
suuremad	doc_685122975272_item	2815145	et	4	main
et	doc_685122975272_item	2815151	et	3	main
oleks	doc_685122975272_item	2815153	et	3	main
töökoht	doc_685122975272_item	2815156	et	3	main
peaks	doc_685122975272_item	2815157	et	4	main
andma	doc_685122975272_item	2815158	et	3	main
töös	doc_685122975272_item	2815165	et	3	main
ja	doc_685122975272_item	2815171	et	3	main
materialism	doc_685122975272_item	2815177	et	3	main
on	doc_685122975272_item	2815188	et	4	main
mõtle	doc_685122975272_item	2815195	et	4	main
teile	doc_685122975272_item	2815202	et	4	main
soovidega	doc_685122975272_item	2815207	et	3	main
olen	doc_685122975273_item	2815223	et	3	main
kohaajalehest	doc_685122975273_item	2815227	et	4	main
oma	doc_685122975273_item	2815228	et	4	main
muidugi	doc_685122975273_item	2815245	et	4	main
on	doc_685122975273_item	2815254	et	4	main
alati	doc_685122975273_item	2815259	et	4	main
tahavad	doc_685122975273_item	2815260	et	3	main
tänapäeva	doc_685122975273_item	2815265	et	4	main
põlvkond	doc_685122975273_item	2815266	et	3	main
võib	doc_685122975273_item	2815267	et	3	main
maadelda	doc_685122975273_item	2815268	et	4	main
saavad	doc_685122975273_item	2815295	et	4	main
välismaa	doc_685122975273_item	2815296	et	4	main
keeled	doc_685122975273_item	2815297	et	3	main
nad	doc_685122975273_item	2815298	et	3	main
kõik	doc_685122975273_item	2815312	et	4	main
tahab	doc_685122975273_item	2815313	et	3	main
selle	doc_685122975273_item	2815325	et	4	main
otsib	doc_685122975273_item	2815329	et	3	main
et	doc_685122975273_item	2815332	et	3	main
kasvu	doc_685122975273_item	2815340	et	4	main
keegi	doc_685122975273_item	2815344	et	4	main
saa	doc_685122975273_item	2815346	et	4	main
sega	doc_685122975273_item	2815347	et	4	main
ohtu	doc_685122975273_item	2815372	et	4	main
kõik	doc_685122975273_item	2815375	et	4	main
on	doc_685122975274_item	2815402	et	4	main
ma	doc_685122975274_item	2815404	et	3	main
tallinna	doc_685122975274_item	2815406	et	4	main
tehnikaülikooli	doc_685122975274_item	2815407	et	4	main
õpilane	doc_685122975274_item	2815408	et	3	main
ma	doc_685122975274_item	2815409	et	3	main
kirjutan	doc_685122975274_item	2815410	et	3	main
teile	doc_685122975274_item	2815411	et	4	main
artiklit	doc_685122975274_item	2815417	et	3	main
mulle	doc_685122975274_item	2815424	et	4	main
te	doc_685122975274_item	2815428	et	4	main
te	doc_685122975274_item	2815432	et	4	main
sellest	doc_685122975274_item	2815437	et	4	main
valivad	doc_685122975274_item	2815442	et	4	main
olen	doc_685122975274_item	2815446	et	3	main
inimesi	doc_685122975274_item	2815451	et	4	main
kelleks	doc_685122975274_item	2815455	et	4	main
see	doc_685122975274_item	2815466	et	3	main
ebaõigelt	doc_685122975274_item	2815468	et	4	main
kus	doc_685122975274_item	2815474	et	3	main
niisuguse	doc_685122975274_item	2815480	et	3	main
ei	doc_685122975274_item	2815484	et	4	main
minna	doc_685122975272_item	2815023	et	3	main
miinimum	doc_685122975272_item	2815044	et	3	main
olema	doc_685122975272_item	2815047	et	4	main
riigis	doc_685122975272_item	2815049	et	3	main
ise	doc_685122975272_item	2815060	et	4	main
aga	doc_685122975272_item	2815074	et	3	main
inimene	doc_685122975272_item	2815077	et	3	main
ilmus	doc_685122975272_item	2815087	et	4	main
üks	doc_685122975272_item	2815088	et	3	main
väljend	doc_685122975272_item	2815089	et	3	main
mis	doc_685122975272_item	2815090	et	4	main
mul	doc_685122975272_item	2815091	et	3	main
jäi	doc_685122975272_item	2815092	et	3	main
on	doc_685122975272_item	2815096	et	4	main
peas	doc_685122975272_item	2815097	et	4	main
riigi	doc_685122975272_item	2815098	et	3	main
teenistusse	doc_685122975272_item	2815099	et	3	main
ei	doc_685122975272_item	2815100	et	4	main
arvan	doc_685122975272_item	2815108	et	3	main
et	doc_685122975272_item	2815109	et	3	main
see	doc_685122975272_item	2815110	et	3	main
ei	doc_685122975272_item	2815111	et	4	main
ole	doc_685122975272_item	2815112	et	4	main
nii	doc_685122975272_item	2815113	et	3	main
seal	doc_685122975272_item	2815114	et	4	main
istuvadki	doc_685122975272_item	2815115	et	4	main
paljud	doc_685122975272_item	2815116	et	3	main
raha	doc_685122975272_item	2815117	et	4	main
ja	doc_685122975272_item	2815118	et	3	main
niiöelda	doc_685122975272_item	2815119	et	4	main
elumoodse	doc_685122975272_item	2815120	et	3	main
stiili	doc_685122975272_item	2815121	et	4	main
teevad	doc_685122975272_item	2815125	et	3	main
oma	doc_685122975272_item	2815126	et	4	main
et	doc_685122975272_item	2815133	et	3	main
huvitav	doc_685122975272_item	2815154	et	4	main
ja	doc_685122975272_item	2815155	et	3	main
paigalseisuks	doc_685122975272_item	2815162	et	3	main
olema	doc_685122975272_item	2815167	et	4	main
ei	doc_685122975272_item	2815173	et	4	main
sest	doc_685122975272_item	2815176	et	4	main
on	doc_685122975272_item	2815178	et	4	main
kõigest	doc_685122975272_item	2815182	et	4	main
et	doc_685122975272_item	2815192	et	3	main
isegi	doc_685122975272_item	2815193	et	4	main
selle	doc_685122975272_item	2815203	et	4	main
perekonnanimi	doc_685122975272_item	2815210	et	3	main
ajalehekirjutis	doc_685122975273_item	2815229	et	4	main
te	doc_685122975273_item	2815230	et	4	main
kirjutate	doc_685122975273_item	2815231	et	3	main
aga	doc_685122975273_item	2815237	et	3	main
on	doc_685122975273_item	2815247	et	4	main
muutunud	doc_685122975273_item	2815248	et	4	main
aga	doc_685122975273_item	2815249	et	3	main
et	doc_685122975273_item	2815252	et	3	main
kui	doc_685122975273_item	2815256	et	3	main
inimesed	doc_685122975273_item	2815258	et	3	main
palju	doc_685122975273_item	2815261	et	4	main
oma	doc_685122975273_item	2815269	et	4	main
parem	doc_685122975273_item	2815293	et	4	main
õnnelik	doc_685122975273_item	2815307	et	3	main
peab	doc_685122975273_item	2815310	et	4	main
elada	doc_685122975273_item	2815314	et	3	main
oma	doc_685122975273_item	2815315	et	4	main
korteris	doc_685122975273_item	2815316	et	3	main
raha	doc_685122975273_item	2815324	et	4	main
pärast	doc_685122975273_item	2815326	et	4	main
inimene	doc_685122975273_item	2815328	et	3	main
töö	doc_685122975273_item	2815330	et	4	main
ei	doc_685122975272_item	2815061	et	4	main
ei	doc_685122975272_item	2815064	et	4	main
tea	doc_685122975272_item	2815065	et	4	main
kuidas	doc_685122975272_item	2815066	et	3	main
teenida	doc_685122975272_item	2815068	et	3	main
ja	doc_685122975272_item	2815069	et	3	main
ja	doc_685122975272_item	2815081	et	3	main
pärast	doc_685122975272_item	2815105	et	4	main
aga	doc_685122975272_item	2815106	et	3	main
aga	doc_685122975272_item	2815128	et	3	main
nii	doc_685122975272_item	2815129	et	3	main
mul	doc_685122975272_item	2815134	et	3	main
mitte	doc_685122975272_item	2815137	et	3	main
tahtmist	doc_685122975272_item	2815139	et	4	main
puutuda	doc_685122975272_item	2815141	et	3	main
palgad	doc_685122975272_item	2815146	et	3	main
ja	doc_685122975272_item	2815147	et	3	main
on	doc_685122975272_item	2815149	et	4	main
töö	doc_685122975272_item	2815152	et	4	main
mitte	doc_685122975272_item	2815161	et	3	main
igas	doc_685122975272_item	2815164	et	3	main
peab	doc_685122975272_item	2815166	et	4	main
kindel	doc_685122975272_item	2815168	et	3	main
amet	doc_685122975272_item	2815169	et	3	main
palk	doc_685122975272_item	2815170	et	3	main
väärtustama	doc_685122975272_item	2815175	et	3	main
ja	doc_685122975272_item	2815180	et	3	main
sellest	doc_685122975272_item	2815181	et	4	main
mina	doc_685122975272_item	2815183	et	4	main
sain	doc_685122975272_item	2815184	et	3	main
aru	doc_685122975272_item	2815185	et	4	main
et	doc_685122975272_item	2815186	et	3	main
inimesed	doc_685122975272_item	2815187	et	3	main
ei	doc_685122975272_item	2815194	et	4	main
tänu	doc_685122975272_item	2815201	et	4	main
artikkli	doc_685122975272_item	2815204	et	4	main
eesnimi	doc_685122975272_item	2815209	et	3	main
ma	doc_685122975273_item	2815222	et	3	main
lugenud	doc_685122975273_item	2815224	et	4	main
artikkel	doc_685122975273_item	2815226	et	3	main
et	doc_685122975273_item	2815232	et	3	main
meie	doc_685122975273_item	2815233	et	4	main
põlvkond	doc_685122975273_item	2815234	et	3	main
ma	doc_685122975273_item	2815238	et	3	main
põlvkond	doc_685122975273_item	2815246	et	3	main
raha	doc_685122975273_item	2815262	et	4	main
ja	doc_685122975273_item	2815263	et	3	main
või	doc_685122975273_item	2815317	et	4	main
majas	doc_685122975273_item	2815318	et	3	main
aga	doc_685122975273_item	2815319	et	3	main
praegu	doc_685122975273_item	2815320	et	3	main
laisalt	doc_685122975272_item	2815130	et	4	main
ja	doc_685122975272_item	2815131	et	3	main
ole	doc_685122975272_item	2815136	et	4	main
küll	doc_685122975272_item	2815142	et	4	main
nad	doc_685122975272_item	2815143	et	3	main
võimaluse	doc_685122975272_item	2815159	et	3	main
raha	doc_685122975272_item	2815172	et	4	main
haigus	doc_685122975272_item	2815179	et	4	main
erinevad	doc_685122975272_item	2815189	et	4	main
nii	doc_685122975272_item	2815190	et	3	main
sügavalt	doc_685122975272_item	2815191	et	4	main
paremate	doc_685122975272_item	2815206	et	4	main
httpwwwekspresseeviewdoc54f0555e004dbacec2257186002b9be3	doc_685122975272_item	2815211	et	4	main
kiri	doc_685122975273_item	2815212	et	3	main
lugupeetud	doc_685122975273_item	2815213	et	4	main
tiina	doc_685122975273_item	2815214	et	4	main
kaalep	doc_685122975273_item	2815215	et	4	main
ma	doc_685122975273_item	2815216	et	3	main
otsustan	doc_685122975273_item	2815217	et	3	main
kirjuda	doc_685122975273_item	2815218	et	4	main
teile	doc_685122975273_item	2815219	et	4	main
kiri	doc_685122975273_item	2815220	et	3	main
tööd	doc_685122975272_item	2815127	et	4	main
ei	doc_685122975272_item	2815135	et	4	main
saavad	doc_685122975272_item	2815144	et	4	main
põhiline	doc_685122975272_item	2815148	et	3	main
see	doc_685122975272_item	2815150	et	3	main
arenguks	doc_685122975272_item	2815160	et	3	main
ja	doc_685122975272_item	2815163	et	3	main
pea	doc_685122975272_item	2815174	et	4	main
sellest	doc_685122975272_item	2815196	et	4	main
mida	doc_685122975272_item	2815197	et	4	main
nad	doc_685122975272_item	2815198	et	3	main
rääkivad	doc_685122975272_item	2815199	et	4	main
suur	doc_685122975272_item	2815200	et	3	main
eest	doc_685122975272_item	2815205	et	4	main
teie	doc_685122975272_item	2815208	et	4	main
kui	doc_685122975273_item	2815221	et	3	main
vähenõudlik	doc_685122975273_item	2815236	et	3	main
ole	doc_685122975273_item	2815240	et	4	main
sellega	doc_685122975273_item	2815242	et	3	main
väitega	doc_685122975273_item	2815243	et	3	main
täielikult	doc_685122975273_item	2815244	et	4	main
ma	doc_685122975273_item	2815250	et	3	main
ta	doc_685122975273_item	2815253	et	4	main
ei	doc_685122975273_item	2815299	et	4	main
karta	doc_685122975273_item	2815300	et	3	main
mitte	doc_685122975273_item	2815301	et	3	main
keegi	doc_685122975273_item	2815302	et	4	main
kui	doc_685122975273_item	2815303	et	3	main
sa	doc_685122975273_item	2815304	et	3	main
tahad	doc_685122975273_item	2815305	et	3	main
siis	doc_685122975273_item	2815308	et	3	main
see	doc_685122975273_item	2815321	et	3	main
noor	doc_685122975273_item	2815327	et	3	main
proovib	doc_685122975273_item	2815331	et	3	main
tema	doc_685122975273_item	2815333	et	4	main
palk	doc_685122975273_item	2815334	et	3	main
suureneb	doc_685122975273_item	2815335	et	3	main
tavaliselt	doc_685122975273_item	2815336	et	4	main
tal	doc_685122975273_item	2815337	et	3	main
ja	doc_685122975273_item	2815341	et	3	main
õnnelik	doc_685122975273_item	2815367	et	3	main
saadavad	doc_685122975273_item	2815369	et	4	main
oma	doc_685122975273_item	2815370	et	4	main
teha	doc_685122975273_item	2815376	et	3	main
avata	doc_685122975273_item	2815378	et	4	main
või	doc_685122975273_item	2815383	et	4	main
nagu	doc_685122975273_item	2815384	et	3	main
omanik	doc_685122975273_item	2815385	et	3	main
ma	doc_685122975273_item	2815386	et	3	main
loodan	doc_685122975273_item	2815387	et	3	main
et	doc_685122975273_item	2815388	et	3	main
mind	doc_685122975273_item	2815391	et	4	main
lugupidamisega	doc_685122975273_item	2815392	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975273_item	2815395	et	4	main
teie	doc_685122975274_item	2815416	et	4	main
teie	doc_685122975273_item	2815225	et	4	main
on	doc_685122975273_item	2815235	et	4	main
ei	doc_685122975273_item	2815239	et	4	main
nõus	doc_685122975273_item	2815241	et	4	main
arvan	doc_685122975273_item	2815251	et	3	main
tugevam	doc_685122975273_item	2815255	et	4	main
enne	doc_685122975273_item	2815257	et	4	main
võimu	doc_685122975273_item	2815264	et	4	main
õiguse	doc_685122975273_item	2815270	et	4	main
eest	doc_685122975273_item	2815271	et	4	main
tänapäeval	doc_685122975273_item	2815272	et	3	main
te	doc_685122975273_item	2815273	et	4	main
ei	doc_685122975273_item	2815274	et	4	main
saa	doc_685122975273_item	2815275	et	4	main
valladama	doc_685122975273_item	2815276	et	4	main
kedagi	doc_685122975273_item	2815277	et	4	main
sest	doc_685122975273_item	2815278	et	4	main
ta	doc_685122975273_item	2815279	et	4	main
ei	doc_685122975273_item	2815280	et	4	main
meeldi	doc_685122975273_item	2815281	et	4	main
sulle	doc_685122975273_item	2815282	et	3	main
aga	doc_685122975273_item	2815283	et	3	main
vanad	doc_685122975273_item	2815284	et	3	main
inimesed	doc_685122975273_item	2815285	et	3	main
ei	doc_685122975273_item	2815286	et	4	main
tahavad	doc_685122975273_item	2815287	et	3	main
maadelda	doc_685122975273_item	2815288	et	4	main
töökoha	doc_685122975273_item	2815289	et	4	main
eest	doc_685122975273_item	2815290	et	4	main
noored	doc_685122975273_item	2815291	et	3	main
inimesed	doc_685122975273_item	2815292	et	3	main
aru	doc_685122975273_item	2815294	et	4	main
olla	doc_685122975273_item	2815306	et	3	main
sa	doc_685122975273_item	2815309	et	3	main
maadlema	doc_685122975273_item	2815311	et	3	main
palju	doc_685122975273_item	2815323	et	4	main
töö	doc_685122975273_item	2815339	et	4	main
talle	doc_685122975273_item	2815348	et	4	main
vaata	doc_685122975273_item	2815349	et	4	main
meie	doc_685122975273_item	2815350	et	4	main
valitsuses	doc_685122975273_item	2815351	et	4	main
erinevates	doc_685122975273_item	2815352	et	4	main
peab	doc_685122975273_item	2815363	et	4	main
ollo	doc_685122975273_item	2815366	et	4	main
tervist	doc_685122975273_item	2815371	et	4	main
te	doc_685122975273_item	2815389	et	4	main
kiri	doc_685122975274_item	2815396	et	3	main
eesnimi	doc_685122975274_item	2815403	et	3	main
vähenõudlike	doc_685122975274_item	2815418	et	3	main
ja	doc_685122975274_item	2815420	et	3	main
muljeid	doc_685122975274_item	2815422	et	3	main
põlvkonnast	doc_685122975274_item	2815431	et	4	main
välja	doc_685122975274_item	2815435	et	4	main
endale	doc_685122975274_item	2815443	et	4	main
saada	doc_685122975274_item	2815458	et	4	main
on	doc_685122975274_item	2815467	et	4	main
sellepärast	doc_685122975274_item	2815469	et	3	main
õpib	doc_685122975274_item	2815472	et	3	main
meeldi	doc_685122975274_item	2815477	et	4	main
milline	doc_685122975274_item	2815482	et	3	main
ma	doc_685122975274_item	2815486	et	3	main
kellele	doc_685122975274_item	2815491	et	4	main
vaja	doc_685122975274_item	2815493	et	4	main
kus	doc_685122975274_item	2815498	et	3	main
arvan	doc_685122975274_item	2815505	et	3	main
juba	doc_685122975274_item	2815510	et	3	main
kelleks	doc_685122975274_item	2815518	et	4	main
tahab	doc_685122975274_item	2815520	et	3	main
peab	doc_685122975274_item	2815527	et	4	main
ülikooli	doc_685122975274_item	2815535	et	4	main
õppima	doc_685122975274_item	2815536	et	3	main
ka	doc_685122975274_item	2815537	et	3	main
olen	doc_685122975274_item	2815539	et	3	main
rahaasjus	doc_685122975274_item	2815543	et	3	main
abituriendid	doc_685122975274_item	2815545	et	3	main
realistlikud	doc_685122975274_item	2815547	et	3	main
kõik	doc_685122975274_item	2815561	et	4	main
inimesed	doc_685122975274_item	2815562	et	3	main
tahavad	doc_685122975274_item	2815563	et	3	main
vääriliselt	doc_685122975274_item	2815564	et	4	main
elada	doc_685122975274_item	2815565	et	3	main
maja	doc_685122975274_item	2815567	et	4	main
ja	doc_685122975274_item	2815568	et	3	main
probleemita	doc_685122975274_item	2815573	et	3	main
õpetajad	doc_685122975274_item	2815580	et	4	main
palju	doc_685122975274_item	2815588	et	4	main
rohkem	doc_685122975274_item	2815589	et	4	main
õige	doc_685122975274_item	2815628	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975274_item	2815639	et	4	main
kiri	doc_685122975275_item	2815640	et	3	main
olin	doc_685122975275_item	2815644	et	3	main
teie	doc_685122975275_item	2815647	et	4	main
esimeses	doc_685122975275_item	2815677	et	3	main
ehituse	doc_685122975275_item	2815679	et	4	main
olla	doc_685122975275_item	2815704	et	3	main
on	doc_685122975275_item	2815712	et	4	main
see	doc_685122975275_item	2815713	et	3	main
hingemeelne	doc_685122975275_item	2815715	et	3	main
eriala	doc_685122975275_item	2815716	et	4	main
tulla	doc_685122975275_item	2815728	et	3	main
kuulsama	doc_685122975275_item	2815730	et	4	main
astuda	doc_685122975275_item	2815738	et	3	main
mul	doc_685122975275_item	2815740	et	3	main
eksami	doc_685122975275_item	2815743	et	3	main
parema	doc_685122975275_item	2815756	et	4	main
sisse	doc_685122975275_item	2815759	et	4	main
selge	doc_685122975275_item	2815765	et	4	main
üliõpilane	doc_685122975275_item	2815773	et	3	main
huvi	doc_685122975275_item	2815781	et	4	main
mingid	doc_685122975275_item	2815784	et	4	main
tulevikus	doc_685122975275_item	2815786	et	4	main
saada	doc_685122975275_item	2815787	et	4	main
maksab	doc_685122975273_item	2815322	et	3	main
on	doc_685122975273_item	2815338	et	4	main
mitte	doc_685122975273_item	2815343	et	3	main
ministeriumides	doc_685122975273_item	2815353	et	4	main
midagi	doc_685122975273_item	2815354	et	4	main
uut	doc_685122975273_item	2815355	et	3	main
pakkub	doc_685122975273_item	2815356	et	4	main
noored	doc_685122975273_item	2815357	et	3	main
politikud	doc_685122975273_item	2815358	et	4	main
ja	doc_685122975273_item	2815359	et	3	main
töötajad	doc_685122975273_item	2815360	et	4	main
tänapäeva	doc_685122975273_item	2815361	et	4	main
põlvkond	doc_685122975273_item	2815362	et	3	main
ta	doc_685122975273_item	2815342	et	4	main
ei	doc_685122975273_item	2815345	et	4	main
riskima	doc_685122975273_item	2815364	et	3	main
nad	doc_685122975273_item	2815368	et	3	main
ja	doc_685122975273_item	2815377	et	3	main
kõik	doc_685122975273_item	2815379	et	4	main
uksed	doc_685122975273_item	2815380	et	3	main
nagu	doc_685122975273_item	2815381	et	3	main
kannatanu	doc_685122975273_item	2815382	et	4	main
lugeja	doc_685122975273_item	2815394	et	4	main
lp	doc_685122975274_item	2815397	et	4	main
tiina	doc_685122975274_item	2815398	et	4	main
kaalep	doc_685122975274_item	2815399	et	4	main
minu	doc_685122975274_item	2815400	et	3	main
nimi	doc_685122975274_item	2815401	et	3	main
sellepärast	doc_685122975274_item	2815412	et	3	main
lugesin	doc_685122975274_item	2815414	et	3	main
tahaksin	doc_685122975274_item	2815421	et	3	main
meeldis	doc_685122975274_item	2815426	et	3	main
mõtelda	doc_685122975274_item	2815436	et	4	main
noored	doc_685122975274_item	2815440	et	3	main
tea	doc_685122975274_item	2815454	et	4	main
nad	doc_685122975274_item	2815456	et	3	main
sinna	doc_685122975274_item	2815462	et	3	main
saavad	doc_685122975274_item	2815465	et	4	main
et	doc_685122975274_item	2815470	et	3	main
seal	doc_685122975274_item	2815473	et	4	main
ja	doc_685122975274_item	2815478	et	3	main
ei	doc_685122975274_item	2815487	et	4	main
on	doc_685122975274_item	2815492	et	4	main
ainult	doc_685122975274_item	2815494	et	4	main
käia	doc_685122975274_item	2815499	et	4	main
palka	doc_685122975274_item	2815502	et	4	main
inimene	doc_685122975274_item	2815507	et	3	main
kuhu	doc_685122975274_item	2815512	et	3	main
edasi	doc_685122975274_item	2815515	et	3	main
talle	doc_685122975274_item	2815524	et	4	main
meeldib	doc_685122975274_item	2815525	et	3	main
võimelisused	doc_685122975274_item	2815531	et	4	main
nõus	doc_685122975274_item	2815540	et	4	main
mõtlen	doc_685122975274_item	2815549	et	3	main
aga	doc_685122975274_item	2815554	et	3	main
õigesti	doc_685122975274_item	2815574	et	3	main
arstid	doc_685122975274_item	2815579	et	4	main
oma	doc_685122975274_item	2815583	et	4	main
raha	doc_685122975274_item	2815590	et	4	main
et	doc_685122975273_item	2815365	et	3	main
aga	doc_685122975273_item	2815373	et	3	main
võib	doc_685122975273_item	2815374	et	3	main
vastate	doc_685122975273_item	2815390	et	3	main
teie	doc_685122975273_item	2815393	et	4	main
olen	doc_685122975274_item	2815405	et	3	main
et	doc_685122975274_item	2815413	et	3	main
ajalehest	doc_685122975274_item	2815415	et	4	main
põlvkond	doc_685122975274_item	2815419	et	3	main
jutustama	doc_685122975274_item	2815423	et	3	main
väga	doc_685122975274_item	2815425	et	3	main
meiest	doc_685122975274_item	2815430	et	4	main
mind	doc_685122975274_item	2815434	et	4	main
inimesed	doc_685122975274_item	2815441	et	3	main
elukutset	doc_685122975274_item	2815444	et	3	main
nõus	doc_685122975274_item	2815447	et	4	main
üldse	doc_685122975274_item	2815452	et	3	main
ei	doc_685122975274_item	2815453	et	4	main
ja	doc_685122975274_item	2815459	et	3	main
õppima	doc_685122975274_item	2815461	et	3	main
sisse	doc_685122975274_item	2815464	et	4	main
inimene	doc_685122975274_item	2815471	et	3	main
talle	doc_685122975274_item	2815475	et	4	main
saab	doc_685122975274_item	2815479	et	3	main
talle	doc_685122975274_item	2815483	et	4	main
saa	doc_685122975274_item	2815488	et	4	main
inimesi	doc_685122975274_item	2815490	et	4	main
ja	doc_685122975274_item	2815500	et	3	main
et	doc_685122975274_item	2815506	et	3	main
koolis	doc_685122975274_item	2815511	et	4	main
kavatseb	doc_685122975274_item	2815514	et	3	main
saada	doc_685122975274_item	2815521	et	4	main
elukutse	doc_685122975274_item	2815523	et	4	main
ta	doc_685122975274_item	2815526	et	4	main
millal	doc_685122975274_item	2815532	et	3	main
ta	doc_685122975274_item	2815533	et	4	main
läheb	doc_685122975274_item	2815534	et	3	main
teiega	doc_685122975274_item	2815541	et	3	main
mitte	doc_685122975274_item	2815551	et	3	main
saada	doc_685122975274_item	2815560	et	4	main
auto	doc_685122975274_item	2815569	et	4	main
elada	doc_685122975274_item	2815571	et	3	main
et	doc_685122975274_item	2815577	et	3	main
peavad	doc_685122975274_item	2815582	et	4	main
töö	doc_685122975274_item	2815584	et	4	main
eest	doc_685122975274_item	2815585	et	4	main
kui	doc_685122975274_item	2815591	et	3	main
võib	doc_685122975274_item	2815622	et	3	main
tere	doc_685122975275_item	2815641	et	3	main
täilikult	doc_685122975275_item	2815668	et	4	main
nõus	doc_685122975275_item	2815669	et	4	main
minu	doc_685122975275_item	2815670	et	3	main
nimi	doc_685122975275_item	2815671	et	3	main
on	doc_685122975275_item	2815672	et	4	main
õpin	doc_685122975275_item	2815674	et	3	main
valiku	doc_685122975275_item	2815699	et	3	main
teha	doc_685122975275_item	2815700	et	3	main
tunnen	doc_685122975275_item	2815706	et	3	main
see	doc_685122975275_item	2815708	et	3	main
mulle	doc_685122975275_item	2815710	et	4	main
ei	doc_685122975275_item	2815719	et	4	main
kuidas	doc_685122975274_item	2815427	et	3	main
kirjutasite	doc_685122975274_item	2815429	et	3	main
sundisite	doc_685122975274_item	2815433	et	3	main
kuidas	doc_685122975274_item	2815438	et	3	main
tänapäeval	doc_685122975274_item	2815439	et	3	main
ma	doc_685122975274_item	2815445	et	3	main
teiega	doc_685122975274_item	2815448	et	3	main
et	doc_685122975274_item	2815449	et	3	main
palju	doc_685122975274_item	2815450	et	4	main
tahaad	doc_685122975274_item	2815457	et	4	main
lähevad	doc_685122975274_item	2815460	et	3	main
kuhu	doc_685122975274_item	2815463	et	3	main
ei	doc_685122975274_item	2815476	et	4	main
elukutset	doc_685122975274_item	2815481	et	3	main
aru	doc_685122975274_item	2815489	et	4	main
oleks	doc_685122975274_item	2815496	et	3	main
mingi	doc_685122975274_item	2815501	et	4	main
ma	doc_685122975274_item	2815504	et	3	main
mõtlema	doc_685122975274_item	2815509	et	3	main
õppida	doc_685122975274_item	2815517	et	3	main
ta	doc_685122975274_item	2815519	et	4	main
huvita	doc_685122975274_item	2815485	et	4	main
et	doc_685122975274_item	2815495	et	3	main
koht	doc_685122975274_item	2815497	et	3	main
saada	doc_685122975274_item	2815503	et	4	main
peab	doc_685122975274_item	2815508	et	4	main
ta	doc_685122975274_item	2815513	et	4	main
minna	doc_685122975274_item	2815516	et	3	main
tõeliselt	doc_685122975274_item	2815528	et	4	main
hindama	doc_685122975274_item	2815529	et	3	main
oma	doc_685122975274_item	2815530	et	4	main
on	doc_685122975274_item	2815544	et	4	main
ma	doc_685122975274_item	2815548	et	3	main
ainult	doc_685122975274_item	2815552	et	4	main
kõik	doc_685122975274_item	2815555	et	4	main
inimesed	doc_685122975274_item	2815556	et	3	main
tahavad	doc_685122975274_item	2815557	et	3	main
suurt	doc_685122975274_item	2815558	et	3	main
palka	doc_685122975274_item	2815559	et	4	main
reisida	doc_685122975274_item	2815566	et	3	main
osta	doc_685122975274_item	2815570	et	4	main
see	doc_685122975274_item	2815576	et	3	main
saama	doc_685122975274_item	2815586	et	4	main
väga	doc_685122975274_item	2815587	et	3	main
õpetus	doc_685122975274_item	2815621	et	4	main
olla	doc_685122975274_item	2815623	et	3	main
rohkem	doc_685122975274_item	2815625	et	4	main
inimesi	doc_685122975274_item	2815626	et	4	main
sellele	doc_685122975274_item	2815630	et	4	main
ma	doc_685122975274_item	2815631	et	3	main
tahaksin	doc_685122975274_item	2815632	et	3	main
lõpetada	doc_685122975274_item	2815633	et	3	main
oma	doc_685122975274_item	2815634	et	4	main
kiri	doc_685122975274_item	2815635	et	3	main
lugupidamisega	doc_685122975274_item	2815636	et	3	main
eesnimi	doc_685122975274_item	2815637	et	3	main
tiina	doc_685122975275_item	2815642	et	4	main
läbi	doc_685122975275_item	2815645	et	4	main
vähenõudlike	doc_685122975275_item	2815649	et	3	main
ja	doc_685122975275_item	2815651	et	3	main
teile	doc_685122975275_item	2815653	et	4	main
kiri	doc_685122975275_item	2815654	et	3	main
praegu	doc_685122975275_item	2815675	et	3	main
kursuses	doc_685122975275_item	2815678	et	3	main
üliõppilasest	doc_685122975275_item	2815685	et	4	main
palju	doc_685122975275_item	2815687	et	4	main
edasi	doc_685122975275_item	2815690	et	3	main
minna	doc_685122975275_item	2815691	et	3	main
kooli	doc_685122975275_item	2815694	et	4	main
ja	doc_685122975275_item	2815695	et	3	main
kuidas	doc_685122975275_item	2815696	et	3	main
oma	doc_685122975275_item	2815698	et	4	main
sest	doc_685122975275_item	2815705	et	4	main
aga	doc_685122975275_item	2815717	et	3	main
olnud	doc_685122975275_item	2815720	et	4	main
kõige	doc_685122975275_item	2815729	et	4	main
ülikooli	doc_685122975275_item	2815732	et	4	main
tallinnas	doc_685122975275_item	2815733	et	4	main
proovisin	doc_685122975275_item	2815734	et	3	main
tulemused	doc_685122975275_item	2815744	et	3	main
on	doc_685122975275_item	2815748	et	4	main
õppima	doc_685122975275_item	2815750	et	3	main
parast	doc_685122975275_item	2815752	et	3	main
parema	doc_685122975275_item	2815754	et	4	main
töökohta	doc_685122975275_item	2815755	et	4	main
kõik	doc_685122975275_item	2815764	et	4	main
seal	doc_685122975275_item	2815776	et	4	main
mingid	doc_685122975275_item	2815780	et	4	main
parema	doc_685122975275_item	2815788	et	4	main
aasta	doc_685122975275_item	2815795	et	4	main
ei	doc_685122975275_item	2815804	et	4	main
alguses	doc_685122975275_item	2815814	et	4	main
olin	doc_685122975275_item	2815815	et	3	main
saavad	doc_685122975275_item	2815822	et	4	main
hea	doc_685122975275_item	2815836	et	4	main
eriala	doc_685122975275_item	2815843	et	4	main
ja	doc_685122975275_item	2815844	et	3	main
siis	doc_685122975275_item	2815845	et	3	main
kirjutage	doc_685122975275_item	2815858	et	3	main
palun	doc_685122975275_item	2815859	et	3	main
tiina	doc_685122975276_item	2815872	et	4	main
artikklit	doc_685122975276_item	2815877	et	4	main
teile	doc_685122975276_item	2815883	et	4	main
milline	doc_685122975274_item	2815522	et	3	main
ma	doc_685122975274_item	2815538	et	3	main
et	doc_685122975274_item	2815542	et	3	main
väga	doc_685122975274_item	2815546	et	3	main
et	doc_685122975274_item	2815550	et	3	main
abituriendid	doc_685122975274_item	2815553	et	3	main
ilma	doc_685122975274_item	2815572	et	4	main
on	doc_685122975274_item	2815575	et	4	main
meie	doc_685122975274_item	2815578	et	4	main
sotsiaaltöötajad	doc_685122975274_item	2815581	et	3	main
täna	doc_685122975274_item	2815592	et	4	main
nenden	doc_685122975274_item	2815593	et	4	main
on	doc_685122975274_item	2815594	et	4	main
väga	doc_685122975274_item	2815595	et	3	main
raske	doc_685122975274_item	2815596	et	4	main
töö	doc_685122975274_item	2815597	et	4	main
milline	doc_685122975274_item	2815598	et	3	main
nõudleb	doc_685122975274_item	2815599	et	3	main
palju	doc_685122975274_item	2815600	et	4	main
teadmiseid	doc_685122975274_item	2815601	et	4	main
oskusi	doc_685122975274_item	2815602	et	3	main
ja	doc_685122975274_item	2815603	et	3	main
tahtejõudu	doc_685122975274_item	2815604	et	4	main
ma	doc_685122975274_item	2815606	et	3	main
tahan	doc_685122975274_item	2815607	et	3	main
öelda	doc_685122975274_item	2815608	et	4	main
et	doc_685122975274_item	2815609	et	3	main
ma	doc_685122975274_item	2815610	et	3	main
mõtlen	doc_685122975274_item	2815611	et	3	main
et	doc_685122975274_item	2815612	et	3	main
lõppes	doc_685122975274_item	2815605	et	4	main
palju	doc_685122975274_item	2815613	et	4	main
sõltub	doc_685122975274_item	2815614	et	3	main
meiest	doc_685122975274_item	2815615	et	4	main
riigist	doc_685122975274_item	2815616	et	3	main
kui	doc_685122975274_item	2815617	et	3	main
meil	doc_685122975274_item	2815618	et	4	main
oleks	doc_685122975274_item	2815619	et	3	main
tasuta	doc_685122975274_item	2815620	et	4	main
elukutse	doc_685122975274_item	2815629	et	4	main
kaalep	doc_685122975275_item	2815643	et	4	main
põlvkond	doc_685122975275_item	2815650	et	3	main
kirjutada	doc_685122975275_item	2815655	et	3	main
eesnimi	doc_685122975275_item	2815673	et	3	main
erialas	doc_685122975275_item	2815680	et	3	main
nii	doc_685122975275_item	2815686	et	3	main
mõtlesin	doc_685122975275_item	2815688	et	3	main
parast	doc_685122975275_item	2815693	et	3	main
et	doc_685122975275_item	2815707	et	3	main
meeldib	doc_685122975275_item	2815709	et	3	main
riigi	doc_685122975275_item	2815721	et	3	main
kus	doc_685122975275_item	2815723	et	3	main
õpida	doc_685122975275_item	2815725	et	4	main
et	doc_685122975274_item	2815624	et	3	main
valivad	doc_685122975274_item	2815627	et	4	main
p	doc_685122975274_item	2815638	et	4	main
luugenud	doc_685122975275_item	2815646	et	4	main
artikel	doc_685122975275_item	2815648	et	4	main
otsustan	doc_685122975275_item	2815652	et	3	main
sest	doc_685122975275_item	2815656	et	4	main
viimasel	doc_685122975275_item	2815657	et	3	main
ajal	doc_685122975275_item	2815658	et	4	main
olin	doc_685122975275_item	2815659	et	3	main
ka	doc_685122975275_item	2815660	et	3	main
sellest	doc_685122975275_item	2815661	et	4	main
küsimustest	doc_685122975275_item	2815662	et	4	main
palju	doc_685122975275_item	2815663	et	4	main
mõeldnud	doc_685122975275_item	2815664	et	4	main
ja	doc_685122975275_item	2815665	et	3	main
olen	doc_685122975275_item	2815666	et	3	main
teiega	doc_685122975275_item	2815667	et	3	main
ttü-s	doc_685122975275_item	2815676	et	3	main
mina	doc_685122975275_item	2815681	et	4	main
nagu	doc_685122975275_item	2815682	et	3	main
suur	doc_685122975275_item	2815683	et	3	main
osa	doc_685122975275_item	2815684	et	4	main
kuhu	doc_685122975275_item	2815689	et	3	main
õppima	doc_685122975275_item	2815692	et	3	main
õigem	doc_685122975275_item	2815697	et	4	main
alguses	doc_685122975275_item	2815701	et	4	main
tahaksin	doc_685122975275_item	2815702	et	3	main
disaineriks	doc_685122975275_item	2815703	et	3	main
ja	doc_685122975275_item	2815711	et	3	main
mu	doc_685122975275_item	2815714	et	3	main
tallinnas	doc_685122975275_item	2815718	et	4	main
ülikooli	doc_685122975275_item	2815722	et	4	main
võiks	doc_685122975275_item	2815724	et	4	main
siis	doc_685122975275_item	2815726	et	3	main
eriala	doc_685122975275_item	2815736	et	4	main
keskmised	doc_685122975275_item	2815742	et	3	main
miks	doc_685122975275_item	2815745	et	4	main
kui	doc_685122975275_item	2815747	et	3	main
saada	doc_685122975275_item	2815753	et	4	main
astusin	doc_685122975275_item	2815758	et	3	main
et	doc_685122975275_item	2815766	et	3	main
see	doc_685122975275_item	2815767	et	3	main
pole	doc_685122975275_item	2815768	et	3	main
minu	doc_685122975275_item	2815769	et	3	main
arvan	doc_685122975275_item	2815771	et	3	main
peab	doc_685122975275_item	2815774	et	4	main
õppima	doc_685122975275_item	2815775	et	3	main
on	doc_685122975275_item	2815779	et	4	main
palka	doc_685122975275_item	2815789	et	4	main
tule	doc_685122975275_item	2815805	et	4	main
praegu	doc_685122975275_item	2815806	et	3	main
otsustasin	doc_685122975275_item	2815807	et	3	main
jargmisel	doc_685122975275_item	2815808	et	4	main
aastal	doc_685122975275_item	2815809	et	3	main
ikka	doc_685122975275_item	2815810	et	4	main
disaineri	doc_685122975275_item	2815811	et	3	main
eriala	doc_685122975275_item	2815812	et	4	main
minna	doc_685122975275_item	2815813	et	3	main
gruppis	doc_685122975275_item	2815817	et	4	main
kes	doc_685122975275_item	2815818	et	4	main
otsustasin	doc_685122975275_item	2815727	et	3	main
riigi	doc_685122975275_item	2815731	et	3	main
inseneeri	doc_685122975275_item	2815735	et	4	main
sisse	doc_685122975275_item	2815737	et	4	main
oli	doc_685122975275_item	2815741	et	3	main
kus	doc_685122975275_item	2815777	et	3	main
mitte	doc_685122975275_item	2815783	et	3	main
jooksul	doc_685122975275_item	2815796	et	4	main
ühes	doc_685122975275_item	2815797	et	4	main
tapselt	doc_685122975275_item	2815800	et	4	main
sisse	doc_685122975275_item	2815821	et	4	main
nagu	doc_685122975275_item	2815823	et	3	main
kirjutate	doc_685122975275_item	2815825	et	3	main
aga	doc_685122975275_item	2815826	et	3	main
praegu	doc_685122975275_item	2815827	et	3	main
minu	doc_685122975275_item	2815828	et	3	main
inseneeri	doc_685122975275_item	2815837	et	4	main
spetsialist	doc_685122975275_item	2815838	et	3	main
see	doc_685122975275_item	2815839	et	3	main
rohkem	doc_685122975275_item	2815852	et	4	main
kaalep	doc_685122975276_item	2815873	et	4	main
ma	doc_685122975276_item	2815874	et	3	main
lugesin	doc_685122975276_item	2815875	et	3	main
kirjutada	doc_685122975276_item	2815882	et	3	main
vastust	doc_685122975276_item	2815884	et	4	main
sain	doc_685122975276_item	2815886	et	3	main
kes	doc_685122975276_item	2815913	et	4	main
keskkonnakaitsja	doc_685122975276_item	2815917	et	4	main
ise	doc_685122975276_item	2815919	et	4	main
sest	doc_685122975275_item	2815739	et	4	main
mitte	doc_685122975275_item	2815746	et	3	main
võimalus	doc_685122975275_item	2815749	et	3	main
ja	doc_685122975275_item	2815751	et	3	main
palkaga	doc_685122975275_item	2815757	et	4	main
kahjuks	doc_685122975275_item	2815760	et	4	main
nüüd	doc_685122975275_item	2815761	et	4	main
mul	doc_685122975275_item	2815762	et	3	main
on	doc_685122975275_item	2815763	et	4	main
lugu	doc_685122975275_item	2815770	et	4	main
et	doc_685122975275_item	2815772	et	3	main
tall	doc_685122975275_item	2815778	et	3	main
aga	doc_685122975275_item	2815782	et	3	main
lootust	doc_685122975275_item	2815785	et	4	main
ilma	doc_685122975275_item	2815790	et	4	main
ja	doc_685122975275_item	2815792	et	3	main
tahtmist	doc_685122975275_item	2815793	et	4	main
viie	doc_685122975275_item	2815794	et	3	main
kohas	doc_685122975275_item	2815798	et	4	main
mitte	doc_685122975275_item	2815801	et	3	main
midagi	doc_685122975275_item	2815802	et	4	main
heat	doc_685122975275_item	2815803	et	4	main
selles	doc_685122975275_item	2815816	et	4	main
lähevad	doc_685122975275_item	2815819	et	3	main
kuhu	doc_685122975275_item	2815820	et	3	main
tule	doc_685122975275_item	2815835	et	4	main
olen	doc_685122975275_item	2815846	et	3	main
kindel	doc_685122975275_item	2815847	et	3	main
et	doc_685122975275_item	2815848	et	3	main
tulevikus	doc_685122975275_item	2815849	et	4	main
tuleb	doc_685122975275_item	2815850	et	3	main
minust	doc_685122975275_item	2815851	et	3	main
lugupeetud	doc_685122975276_item	2815871	et	4	main
põlvkond	doc_685122975276_item	2815879	et	3	main
ja	doc_685122975276_item	2815880	et	3	main
ja	doc_685122975276_item	2815901	et	3	main
unistusi	doc_685122975276_item	2815903	et	4	main
räägivad	doc_685122975276_item	2815914	et	3	main
nõus	doc_685122975276_item	2815922	et	4	main
rühmale	doc_685122975276_item	2815930	et	3	main
kuulun	doc_685122975276_item	2815932	et	3	main
18	doc_685122975276_item	2815935	et	2	main
kes	doc_685122975276_item	2815938	et	4	main
pärast	doc_685122975276_item	2815947	et	4	main
ülikooli	doc_685122975276_item	2815948	et	4	main
tööd	doc_685122975276_item	2815953	et	4	main
kuulun	doc_685122975276_item	2815959	et	3	main
esimese	doc_685122975276_item	2815961	et	3	main
rühmale	doc_685122975276_item	2815962	et	3	main
kuid	doc_685122975276_item	2815963	et	4	main
arvan	doc_685122975276_item	2815964	et	3	main
ka	doc_685122975276_item	2815965	et	3	main
et	doc_685122975276_item	2815966	et	3	main
olen	doc_685122975276_item	2815967	et	3	main
minu	doc_685122975276_item	2816009	et	3	main
lugupidamisega	doc_685122975276_item	2816011	et	3	main
10122006	doc_685122975276_item	2816014	et	2	main
saada	doc_685122975277_item	2816036	et	4	main
huvitav	doc_685122975277_item	2816045	et	4	main
olen	doc_685122975277_item	2816047	et	3	main
et	doc_685122975277_item	2816049	et	3	main
on	doc_685122975277_item	2816051	et	4	main
tuleviku	doc_685122975277_item	2816052	et	4	main
aina	doc_685122975277_item	2816057	et	4	main
et	doc_685122975277_item	2816071	et	3	main
elu	doc_685122975277_item	2816074	et	4	main
kõik	doc_685122975277_item	2816077	et	4	main
ju	doc_685122975277_item	2816079	et	3	main
arst	doc_685122975277_item	2816126	et	3	main
mina	doc_685122975277_item	2816145	et	4	main
kellega	doc_685122975277_item	2816158	et	3	main
olla	doc_685122975277_item	2816161	et	3	main
tea	doc_685122975277_item	2816164	et	4	main
vähemalt	doc_685122975277_item	2816180	et	4	main
minu	doc_685122975277_item	2816181	et	3	main
ka	doc_685122975277_item	2816187	et	3	main
et	doc_685122975277_item	2816189	et	3	main
kedagi	doc_685122975277_item	2816192	et	4	main
sotsiaaltöötajana	doc_685122975277_item	2816197	et	3	main
talle	doc_685122975277_item	2816199	et	4	main
ei	doc_685122975277_item	2816210	et	4	main
teiega	doc_685122975278_item	2816237	et	3	main
huvi	doc_685122975275_item	2815791	et	4	main
õppinud	doc_685122975275_item	2815799	et	4	main
ei	doc_685122975275_item	2815834	et	4	main
kasu	doc_685122975275_item	2815853	et	4	main
nagu	doc_685122975275_item	2815854	et	3	main
disainer	doc_685122975275_item	2815855	et	3	main
kui	doc_685122975275_item	2815856	et	3	main
kiri	doc_685122975276_item	2815870	et	3	main
teie	doc_685122975276_item	2815876	et	4	main
ma	doc_685122975276_item	2815887	et	3	main
et	doc_685122975276_item	2815889	et	3	main
noorte	doc_685122975276_item	2815892	et	3	main
põlvkonda	doc_685122975276_item	2815893	et	4	main
3	doc_685122975276_item	2815894	et	2	main
kes	doc_685122975276_item	2815897	et	4	main
ootavad	doc_685122975276_item	2815898	et	4	main
jõulisemat	doc_685122975276_item	2815899	et	4	main
ei	doc_685122975276_item	2815906	et	4	main
tea	doc_685122975276_item	2815907	et	4	main
mis	doc_685122975276_item	2815908	et	4	main
neist	doc_685122975276_item	2815909	et	4	main
saab	doc_685122975276_item	2815910	et	3	main
ja	doc_685122975276_item	2815911	et	3	main
neid	doc_685122975276_item	2815912	et	4	main
ning	doc_685122975276_item	2815916	et	3	main
ei	doc_685122975276_item	2815927	et	4	main
mina	doc_685122975276_item	2815933	et	4	main
tütarlaps	doc_685122975276_item	2815937	et	4	main
läks	doc_685122975276_item	2815939	et	3	main
sellel	doc_685122975276_item	2815940	et	4	main
aastal	doc_685122975276_item	2815941	et	3	main
ülikooli	doc_685122975276_item	2815942	et	4	main
leida	doc_685122975276_item	2815950	et	3	main
endale	doc_685122975276_item	2815951	et	4	main
suurt	doc_685122975276_item	2815955	et	3	main
3	doc_685122975276_item	2815969	et	2	main
rühmale	doc_685122975276_item	2815970	et	3	main
sest	doc_685122975276_item	2815971	et	4	main
pakub	doc_685122975276_item	2815972	et	3	main
huvi	doc_685122975276_item	2815973	et	4	main
töötada	doc_685122975276_item	2815974	et	3	main
teile	doc_685122975276_item	2816004	et	4	main
kirju	doc_685122975276_item	2816010	et	4	main
eesnimi	doc_685122975276_item	2816012	et	3	main
mis	doc_685122975277_item	2816025	et	4	main
eriala	doc_685122975277_item	2816026	et	4	main
sa	doc_685122975277_item	2816027	et	3	main
kui	doc_685122975277_item	2816031	et	3	main
tulevikus	doc_685122975277_item	2816033	et	4	main
palka	doc_685122975277_item	2816034	et	4	main
tahad	doc_685122975277_item	2816035	et	3	main
abiturienti	doc_685122975277_item	2816041	et	4	main
üle	doc_685122975277_item	2816042	et	3	main
teavad	doc_685122975277_item	2816078	et	3	main
ilus	doc_685122975277_item	2816081	et	4	main
aidata	doc_685122975277_item	2816119	et	4	main
teistele	doc_685122975277_item	2816120	et	4	main
te	doc_685122975275_item	2815824	et	4	main
arvamus	doc_685122975275_item	2815829	et	3	main
muutunud	doc_685122975275_item	2815830	et	4	main
arvan	doc_685122975275_item	2815831	et	3	main
et	doc_685122975275_item	2815832	et	3	main
minust	doc_685122975275_item	2815833	et	3	main
on	doc_685122975275_item	2815840	et	4	main
väga	doc_685122975275_item	2815841	et	3	main
tõsine	doc_685122975275_item	2815842	et	4	main
inseneer	doc_685122975275_item	2815857	et	4	main
oma	doc_685122975275_item	2815860	et	4	main
arvamus	doc_685122975275_item	2815861	et	3	main
minu	doc_685122975275_item	2815862	et	3	main
otsustuse	doc_685122975275_item	2815863	et	4	main
eest	doc_685122975275_item	2815864	et	4	main
ootan	doc_685122975275_item	2815865	et	3	main
vastust	doc_685122975275_item	2815866	et	4	main
lugupidamisega	doc_685122975275_item	2815867	et	3	main
eesnimi	doc_685122975275_item	2815868	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975275_item	2815869	et	4	main
vähenõudlike	doc_685122975276_item	2815878	et	3	main
tahaks	doc_685122975276_item	2815881	et	3	main
te	doc_685122975276_item	2815890	et	4	main
neid	doc_685122975276_item	2815896	et	4	main
tulemist	doc_685122975276_item	2815900	et	4	main
sotsiaaltöötaja	doc_685122975276_item	2815915	et	4	main
ametist	doc_685122975276_item	2815918	et	3	main
olen	doc_685122975276_item	2815920	et	3	main
mina	doc_685122975276_item	2815921	et	4	main
niisuguse	doc_685122975276_item	2815923	et	3	main
jagamisega	doc_685122975276_item	2815924	et	4	main
millisele	doc_685122975276_item	2815929	et	3	main
olen	doc_685122975276_item	2815934	et	3	main
soobiv	doc_685122975276_item	2815968	et	4	main
rühmale	doc_685122975276_item	2816002	et	3	main
aitäh	doc_685122975276_item	2816003	et	3	main
teie	doc_685122975277_item	2816021	et	4	main
palju	doc_685122975277_item	2816032	et	4	main
oli	doc_685122975277_item	2816044	et	3	main
nõus	doc_685122975277_item	2816048	et	4	main
olemas	doc_685122975277_item	2816065	et	4	main
ja	doc_685122975277_item	2816068	et	3	main
teevad	doc_685122975277_item	2816069	et	3	main
midagi	doc_685122975277_item	2816070	et	4	main
loodus	doc_685122975277_item	2816072	et	4	main
et	doc_685122975277_item	2816080	et	3	main
ja	doc_685122975277_item	2816082	et	3	main
ja	doc_685122975277_item	2816116	et	3	main
kõik	doc_685122975277_item	2816117	et	4	main
arvan	doc_685122975277_item	2816124	et	3	main
ta	doc_685122975277_item	2816142	et	4	main
ta	doc_685122975277_item	2816154	et	4	main
hea	doc_685122975277_item	2816157	et	4	main
ma	doc_685122975277_item	2816159	et	3	main
ei	doc_685122975277_item	2816163	et	4	main
meeldib	doc_685122975277_item	2816165	et	3	main
sotsialtöötaja	doc_685122975277_item	2816166	et	4	main
aidata	doc_685122975277_item	2816167	et	4	main
öeldes	doc_685122975277_item	2816178	et	3	main
oluline	doc_685122975277_item	2816179	et	4	main
ju	doc_685122975277_item	2816186	et	3	main
minu	doc_685122975277_item	2816194	et	3	main
meeldib	doc_685122975277_item	2816200	et	3	main
ttüs	doc_685122975277_item	2816203	et	4	main
amet	doc_685122975277_item	2816204	et	3	main
arvan	doc_685122975277_item	2816216	et	3	main
nagu	doc_685122975276_item	2815885	et	3	main
aru	doc_685122975276_item	2815888	et	4	main
agate	doc_685122975276_item	2815891	et	4	main
rühmale	doc_685122975276_item	2815895	et	3	main
erilisemaid	doc_685122975276_item	2815902	et	4	main
neid	doc_685122975276_item	2815904	et	4	main
kes	doc_685122975276_item	2815905	et	4	main
ise	doc_685122975276_item	2815926	et	4	main
ma	doc_685122975276_item	2815931	et	3	main
aastane	doc_685122975276_item	2815936	et	4	main
lõpetamist	doc_685122975276_item	2815949	et	4	main
ja	doc_685122975276_item	2815954	et	3	main
sellest	doc_685122975276_item	2815957	et	4	main
et	doc_685122975276_item	2816005	et	3	main
aega	doc_685122975276_item	2816007	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975276_item	2816015	et	4	main
m	doc_685122975277_item	2816018	et	4	main
jurgen	doc_685122975277_item	2816019	et	4	main
lugesin	doc_685122975277_item	2816020	et	3	main
kuid	doc_685122975276_item	2815925	et	4	main
tea	doc_685122975276_item	2815928	et	4	main
muidugi	doc_685122975276_item	2815943	et	4	main
tahan	doc_685122975276_item	2815944	et	3	main
ja	doc_685122975276_item	2815945	et	3	main
ootan	doc_685122975276_item	2815946	et	3	main
sobivad	doc_685122975276_item	2815952	et	4	main
palka	doc_685122975276_item	2815956	et	4	main
aspektist	doc_685122975276_item	2815958	et	3	main
mina	doc_685122975276_item	2815960	et	4	main
sotsiaaltöötajana	doc_685122975276_item	2815975	et	3	main
või	doc_685122975276_item	2815976	et	4	main
töötada	doc_685122975276_item	2815977	et	3	main
ministeeriumis	doc_685122975276_item	2815978	et	3	main
ja	doc_685122975276_item	2815979	et	3	main
proovida	doc_685122975276_item	2815980	et	3	main
muuta	doc_685122975276_item	2815981	et	4	main
keskkonda	doc_685122975276_item	2815982	et	4	main
paremaks	doc_685122975276_item	2815983	et	4	main
mulle	doc_685122975276_item	2815984	et	4	main
meeldis	doc_685122975276_item	2815985	et	3	main
väga	doc_685122975276_item	2815986	et	3	main
niisugune	doc_685122975276_item	2815987	et	3	main
põlvkonna	doc_685122975276_item	2815988	et	4	main
rühmade	doc_685122975276_item	2815989	et	3	main
jagamine	doc_685122975276_item	2815990	et	4	main
kuid	doc_685122975276_item	2815991	et	4	main
ei	doc_685122975276_item	2815992	et	4	main
mina	doc_685122975276_item	2815994	et	4	main
saa	doc_685122975276_item	2815993	et	4	main
öelda	doc_685122975276_item	2815995	et	4	main
et	doc_685122975276_item	2815996	et	3	main
igaüks	doc_685122975276_item	2815997	et	3	main
inimene	doc_685122975276_item	2815998	et	3	main
kuulub	doc_685122975276_item	2815999	et	3	main
ainult	doc_685122975276_item	2816000	et	4	main
ühele	doc_685122975276_item	2816001	et	3	main
leidsite	doc_685122975276_item	2816006	et	3	main
lugeda	doc_685122975276_item	2816008	et	3	main
perekonnanimi	doc_685122975276_item	2816013	et	3	main
kiri	doc_685122975277_item	2816016	et	3	main
tere	doc_685122975277_item	2816017	et	3	main
artiikel	doc_685122975277_item	2816022	et	4	main
eesti	doc_685122975277_item	2816023	et	4	main
ekspresis	doc_685122975277_item	2816024	et	4	main
ekspressi	doc_685122975277_item	2816037	et	4	main
küsimustele	doc_685122975277_item	2816038	et	4	main
vastas	doc_685122975277_item	2816039	et	4	main
140	doc_685122975277_item	2816040	et	2	main
lugeda	doc_685122975277_item	2816046	et	3	main
eriala	doc_685122975277_item	2816053	et	4	main
kuna	doc_685122975277_item	2816054	et	3	main
probleemid	doc_685122975277_item	2816055	et	3	main
keskonnaga	doc_685122975277_item	2816056	et	4	main
probleemid	doc_685122975277_item	2816062	et	3	main
on	doc_685122975277_item	2816064	et	4	main
aga	doc_685122975277_item	2816066	et	3	main
aitavad	doc_685122975277_item	2816067	et	4	main
paremaks	doc_685122975277_item	2816076	et	4	main
või	doc_685122975277_item	2816118	et	4	main
tunduma	doc_685122975277_item	2816131	et	3	main
võib	doc_685122975277_item	2816135	et	3	main
olla	doc_685122975277_item	2816136	et	3	main
meeldib	doc_685122975277_item	2816139	et	3	main
amet	doc_685122975277_item	2816141	et	3	main
nagu	doc_685122975277_item	2816144	et	3	main
hea	doc_685122975277_item	2816146	et	4	main
nagu	doc_685122975277_item	2816148	et	3	main
nii	doc_685122975277_item	2816149	et	3	main
saab	doc_685122975277_item	2816150	et	3	main
palju	doc_685122975277_item	2816151	et	4	main
ikka	doc_685122975277_item	2816156	et	4	main
tahan	doc_685122975277_item	2816160	et	3	main
neid	doc_685122975277_item	2816168	et	4	main
kes	doc_685122975277_item	2816169	et	4	main
ja	doc_685122975277_item	2816172	et	3	main
alguses	doc_685122975277_item	2816174	et	4	main
palk	doc_685122975277_item	2816176	et	3	main
ausalt	doc_685122975277_item	2816177	et	4	main
oleks	doc_685122975277_item	2816185	et	3	main
heaolutunne	doc_685122975277_item	2816188	et	3	main
saanud	doc_685122975277_item	2816191	et	4	main
aidata	doc_685122975277_item	2816193	et	4	main
praegu	doc_685122975277_item	2816201	et	3	main
täpselt	doc_685122975277_item	2816209	et	4	main
see	doc_685122975277_item	2816213	et	3	main
peab	doc_685122975277_item	2816218	et	4	main
nõus	doc_685122975278_item	2816239	et	4	main
saada	doc_685122975278_item	2816250	et	4	main
pühapäeval	doc_685122975278_item	2816277	et	3	main
ma	doc_685122975278_item	2816278	et	3	main
piirkonnas	doc_685122975278_item	2816286	et	4	main
seest	doc_685122975278_item	2816287	et	3	main
et	doc_685122975278_item	2816288	et	3	main
see	doc_685122975278_item	2816289	et	3	main
on	doc_685122975278_item	2816290	et	4	main
väga	doc_685122975278_item	2816291	et	3	main
aeg	doc_685122975278_item	2816296	et	3	main
õppimist	doc_685122975278_item	2816298	et	4	main
olla	doc_685122975278_item	2816303	et	3	main
ei	doc_685122975278_item	2816331	et	4	main
ole	doc_685122975278_item	2816332	et	4	main
õige	doc_685122975278_item	2816333	et	4	main
seest	doc_685122975278_item	2816334	et	3	main
et	doc_685122975278_item	2816335	et	3	main
noorte	doc_685122975278_item	2816336	et	3	main
erinevad	doc_685122975278_item	2816342	et	4	main
noored	doc_685122975278_item	2816343	et	3	main
elu	doc_685122975278_item	2816352	et	4	main
algab	doc_685122975278_item	2816353	et	3	main
see	doc_685122975278_item	2816354	et	3	main
ja	doc_685122975278_item	2816358	et	3	main
seest	doc_685122975278_item	2816362	et	3	main
inimene	doc_685122975278_item	2816364	et	3	main
oma	doc_685122975278_item	2816366	et	4	main
ta	doc_685122975278_item	2816369	et	4	main
eriala	doc_685122975278_item	2816372	et	4	main
ei	doc_685122975278_item	2816399	et	4	main
saame	doc_685122975278_item	2816406	et	4	main
õppima	doc_685122975277_item	2816028	et	3	main
lähed	doc_685122975277_item	2816029	et	3	main
ja	doc_685122975277_item	2816030	et	3	main
eesti	doc_685122975277_item	2816043	et	4	main
keskkonnakaitse	doc_685122975277_item	2816050	et	4	main
surenevad	doc_685122975277_item	2816058	et	4	main
kõik	doc_685122975277_item	2816059	et	4	main
teavad	doc_685122975277_item	2816060	et	3	main
et	doc_685122975277_item	2816061	et	3	main
loodusega	doc_685122975277_item	2816063	et	4	main
ja	doc_685122975277_item	2816073	et	3	main
muutuks	doc_685122975277_item	2816075	et	4	main
puhas	doc_685122975277_item	2816083	et	3	main
loodus	doc_685122975277_item	2816084	et	4	main
on	doc_685122975277_item	2816085	et	4	main
meie	doc_685122975277_item	2816086	et	4	main
tervis	doc_685122975277_item	2816087	et	3	main
amet	doc_685122975277_item	2816088	et	3	main
arst	doc_685122975277_item	2816089	et	3	main
tüdruk	doc_685122975277_item	2816090	et	3	main
haapsalust	doc_685122975277_item	2816091	et	4	main
kirjutab	doc_685122975277_item	2816092	et	3	main
et	doc_685122975277_item	2816093	et	3	main
tahan	doc_685122975277_item	2816094	et	3	main
arstiks	doc_685122975277_item	2816095	et	4	main
saada	doc_685122975277_item	2816096	et	4	main
sest	doc_685122975277_item	2816097	et	4	main
mulle	doc_685122975277_item	2816098	et	4	main
meeldib	doc_685122975277_item	2816099	et	3	main
see	doc_685122975277_item	2816100	et	3	main
amet	doc_685122975277_item	2816101	et	3	main
ja	doc_685122975277_item	2816102	et	3	main
tahan	doc_685122975277_item	2816103	et	3	main
palju	doc_685122975277_item	2816104	et	4	main
pappi	doc_685122975277_item	2816105	et	4	main
saada	doc_685122975277_item	2816106	et	4	main
ei	doc_685122975277_item	2816107	et	4	main
saanud	doc_685122975277_item	2816108	et	4	main
aru	doc_685122975277_item	2816109	et	4	main
et	doc_685122975277_item	2816110	et	3	main
ta	doc_685122975277_item	2816111	et	4	main
tahab	doc_685122975277_item	2816112	et	3	main
pappi	doc_685122975277_item	2816114	et	4	main
palju	doc_685122975277_item	2816113	et	4	main
saada	doc_685122975277_item	2816115	et	4	main
tahab	doc_685122975277_item	2816122	et	3	main
et	doc_685122975277_item	2816125	et	3	main
peab	doc_685122975277_item	2816127	et	4	main
kõige	doc_685122975277_item	2816129	et	4	main
aidata	doc_685122975277_item	2816132	et	4	main
kui	doc_685122975277_item	2816137	et	3	main
see	doc_685122975277_item	2816140	et	3	main
mõtleb	doc_685122975277_item	2816143	et	3	main
arst	doc_685122975277_item	2816147	et	3	main
ka	doc_685122975277_item	2816121	et	3	main
ma	doc_685122975277_item	2816123	et	3	main
seda	doc_685122975277_item	2816128	et	3	main
pealt	doc_685122975277_item	2816130	et	4	main
teistele	doc_685122975277_item	2816133	et	4	main
aga	doc_685122975277_item	2816134	et	3	main
talle	doc_685122975277_item	2816138	et	4	main
pappi	doc_685122975277_item	2816152	et	4	main
kui	doc_685122975277_item	2816153	et	3	main
veel	doc_685122975277_item	2816162	et	4	main
vajavad	doc_685122975277_item	2816170	et	4	main
abi	doc_685122975277_item	2816173	et	4	main
pole	doc_685122975277_item	2816175	et	3	main
palgaks	doc_685122975277_item	2816184	et	3	main
olen	doc_685122975277_item	2816190	et	3	main
töötab	doc_685122975277_item	2816196	et	3	main
veel	doc_685122975277_item	2816208	et	4	main
tea	doc_685122975277_item	2816211	et	4	main
aga	doc_685122975277_item	2816215	et	3	main
et	doc_685122975277_item	2816217	et	3	main
huvitav	doc_685122975277_item	2816220	et	4	main
aitäh	doc_685122975277_item	2816221	et	3	main
teie	doc_685122975277_item	2816223	et	4	main
artiikli	doc_685122975277_item	2816224	et	4	main
eest	doc_685122975277_item	2816225	et	4	main
lugesin	doc_685122975278_item	2816231	et	3	main
teie	doc_685122975278_item	2816232	et	4	main
artiklit	doc_685122975278_item	2816233	et	3	main
vähenõudlike	doc_685122975278_item	2816234	et	3	main
põlvkond	doc_685122975278_item	2816235	et	3	main
olen	doc_685122975278_item	2816236	et	3	main
noored	doc_685122975278_item	2816243	et	3	main
me	doc_685122975278_item	2816251	et	4	main
ülikoolis	doc_685122975278_item	2816273	et	4	main
saan	doc_685122975278_item	2816280	et	4	main
paljud	doc_685122975278_item	2816283	et	3	main
töötavad	doc_685122975278_item	2816284	et	4	main
saate	doc_685122975278_item	2816294	et	4	main
tahaksid	doc_685122975278_item	2816302	et	4	main
teie	doc_685122975278_item	2816305	et	4	main
artiklis	doc_685122975278_item	2816306	et	3	main
lugesin	doc_685122975278_item	2816307	et	3	main
veel	doc_685122975278_item	2816308	et	4	main
et	doc_685122975278_item	2816309	et	3	main
motiiv	doc_685122975278_item	2816313	et	3	main
põlvkonnast	doc_685122975278_item	2816318	et	4	main
oli	doc_685122975278_item	2816322	et	3	main
see	doc_685122975278_item	2816328	et	3	main
elu	doc_685122975278_item	2816329	et	4	main
peavad	doc_685122975278_item	2816344	et	4	main
õppima	doc_685122975278_item	2816345	et	3	main
ja	doc_685122975278_item	2816346	et	3	main
oluline	doc_685122975278_item	2816357	et	4	main
moment	doc_685122975278_item	2816360	et	3	main
valib	doc_685122975278_item	2816365	et	3	main
tuleviku	doc_685122975278_item	2816367	et	4	main
tea	doc_685122975278_item	2816400	et	4	main
mis	doc_685122975278_item	2816401	et	4	main
seda	doc_685122975278_item	2816407	et	3	main
näidata	doc_685122975278_item	2816408	et	4	main
väga	doc_685122975278_item	2816409	et	3	main
tihti	doc_685122975278_item	2816410	et	3	main
et	doc_685122975278_item	2816411	et	3	main
paljud	doc_685122975278_item	2816412	et	3	main
nad	doc_685122975278_item	2816416	et	3	main
tahavad	doc_685122975278_item	2816417	et	3	main
neile	doc_685122975278_item	2816422	et	4	main
nende	doc_685122975278_item	2816432	et	4	main
ei	doc_685122975278_item	2816437	et	4	main
nad	doc_685122975278_item	2816442	et	3	main
ei	doc_685122975278_item	2816447	et	4	main
praegu	doc_685122975278_item	2816454	et	3	main
sellega	doc_685122975278_item	2816457	et	3	main
tihti	doc_685122975278_item	2816459	et	3	main
on	doc_685122975278_item	2816465	et	4	main
on	doc_685122975277_item	2816155	et	4	main
hoolt	doc_685122975277_item	2816171	et	4	main
jaoks	doc_685122975277_item	2816182	et	4	main
minu	doc_685122975277_item	2816183	et	3	main
isa	doc_685122975277_item	2816195	et	4	main
ja	doc_685122975277_item	2816198	et	3	main
õpin	doc_685122975277_item	2816202	et	3	main
elektrijamid	doc_685122975277_item	2816205	et	4	main
ja	doc_685122975277_item	2816206	et	3	main
jõuelektronika	doc_685122975277_item	2816207	et	4	main
mida	doc_685122975277_item	2816212	et	4	main
tähendab	doc_685122975277_item	2816214	et	3	main
olema	doc_685122975277_item	2816219	et	4	main
httpwwwekspresseeviewdoc54f0555e004dbacec2257186002b9be3	doc_685122975277_item	2816226	et	4	main
kiri	doc_685122975278_item	2816227	et	3	main
lugupeetud	doc_685122975278_item	2816228	et	4	main
tiina	doc_685122975278_item	2816229	et	4	main
täpselt	doc_685122975278_item	2816238	et	4	main
täna	doc_685122975278_item	2816241	et	4	main
tahaksid	doc_685122975278_item	2816245	et	4	main
õppida	doc_685122975278_item	2816246	et	3	main
ja	doc_685122975278_item	2816247	et	3	main
palju	doc_685122975278_item	2816248	et	4	main
saame	doc_685122975278_item	2816252	et	4	main
aga	doc_685122975278_item	2816274	et	3	main
töötan	doc_685122975278_item	2816279	et	3	main
et	doc_685122975278_item	2816282	et	3	main
mugav	doc_685122975278_item	2816292	et	3	main
toimunud	doc_685122975278_item	2816311	et	4	main
vanemate	doc_685122975278_item	2816317	et	4	main
teile	doc_685122975277_item	2816222	et	4	main
kaalep	doc_685122975278_item	2816230	et	4	main
palka	doc_685122975278_item	2816249	et	4	main
noored	doc_685122975278_item	2816256	et	3	main
õppivad	doc_685122975278_item	2816257	et	4	main
koolis	doc_685122975278_item	2816258	et	4	main
või	doc_685122975278_item	2816259	et	4	main
ülikoolis	doc_685122975278_item	2816260	et	4	main
ja	doc_685122975278_item	2816261	et	3	main
nad	doc_685122975278_item	2816262	et	3	main
töötavad	doc_685122975278_item	2816263	et	4	main
näiteks	doc_685122975278_item	2816264	et	4	main
mina	doc_685122975278_item	2816265	et	4	main
olen	doc_685122975278_item	2816266	et	3	main
praegu	doc_685122975278_item	2816267	et	3	main
tudeng	doc_685122975278_item	2816268	et	3	main
ja	doc_685122975278_item	2816269	et	3	main
et	doc_685122975278_item	2816240	et	3	main
paljud	doc_685122975278_item	2816242	et	3	main
inimesed	doc_685122975278_item	2816244	et	3	main
seda	doc_685122975278_item	2816253	et	3	main
näidata	doc_685122975278_item	2816254	et	4	main
et	doc_685122975278_item	2816255	et	3	main
õpin	doc_685122975278_item	2816270	et	3	main
tallinna	doc_685122975278_item	2816271	et	4	main
tehnika	doc_685122975278_item	2816272	et	4	main
ja	doc_685122975278_item	2816276	et	3	main
te	doc_685122975278_item	2816293	et	4	main
prantsusmaal	doc_685122975278_item	2816310	et	4	main
polnud	doc_685122975278_item	2816314	et	3	main
eristuda	doc_685122975278_item	2816316	et	3	main
nagu	doc_685122975278_item	2816320	et	3	main
mõtlen	doc_685122975278_item	2816326	et	3	main
elu	doc_685122975278_item	2816337	et	4	main
ja	doc_685122975278_item	2816338	et	3	main
midagi	doc_685122975278_item	2816348	et	4	main
saavutada	doc_685122975278_item	2816349	et	3	main
kahekümneaastases	doc_685122975278_item	2816350	et	4	main
on	doc_685122975278_item	2816355	et	4	main
kui	doc_685122975278_item	2816368	et	3	main
valib	doc_685122975278_item	2816370	et	3	main
oma	doc_685122975278_item	2816371	et	4	main
täna	doc_685122975278_item	2816404	et	4	main
teha	doc_685122975278_item	2816418	et	3	main
tulevikus	doc_685122975278_item	2816419	et	4	main
laupäeval	doc_685122975278_item	2816275	et	3	main
öelda	doc_685122975278_item	2816281	et	4	main
teenindamise	doc_685122975278_item	2816285	et	4	main
valida	doc_685122975278_item	2816295	et	3	main
pärast	doc_685122975278_item	2816297	et	4	main
või	doc_685122975278_item	2816299	et	4	main
puhkepäevadel	doc_685122975278_item	2816300	et	3	main
kõik	doc_685122975278_item	2816301	et	4	main
sõltumatu	doc_685122975278_item	2816304	et	4	main
noorsoorahutuste	doc_685122975278_item	2816312	et	4	main
soov	doc_685122975278_item	2816315	et	3	main
nii	doc_685122975278_item	2816319	et	3	main
see	doc_685122975278_item	2816321	et	3	main
aastal	doc_685122975278_item	2816324	et	3	main
et	doc_685122975278_item	2816327	et	3	main
mõte	doc_685122975278_item	2816330	et	3	main
on	doc_685122975278_item	2816341	et	4	main
ainult	doc_685122975278_item	2816351	et	4	main
väga	doc_685122975278_item	2816356	et	3	main
neist	doc_685122975278_item	2816402	et	4	main
saab	doc_685122975278_item	2816403	et	3	main
ei	doc_685122975278_item	2816413	et	4	main
tea	doc_685122975278_item	2816414	et	4	main
ja	doc_685122975278_item	2816420	et	3	main
mida	doc_685122975278_item	2816421	et	4	main
meeldib	doc_685122975278_item	2816423	et	3	main
huvid	doc_685122975278_item	2816425	et	3	main
tulevad	doc_685122975278_item	2816428	et	4	main
õppida	doc_685122975278_item	2816429	et	3	main
kus	doc_685122975278_item	2816430	et	3	main
tahavad	doc_685122975278_item	2816431	et	3	main
pärast	doc_685122975278_item	2816435	et	4	main
lõpetada	doc_685122975278_item	2816439	et	3	main
et	doc_685122975278_item	2816441	et	3	main
me	doc_685122975278_item	2816455	et	4	main
kohtume	doc_685122975278_item	2816456	et	3	main
olen	doc_685122975278_item	2816461	et	3	main
et	doc_685122975278_item	2816463	et	3	main
samas	doc_685122975278_item	2816467	et	4	main
väga	doc_685122975278_item	2816468	et	3	main
realistikud	doc_685122975278_item	2816469	et	4	main
aga	doc_685122975278_item	2816470	et	3	main
see	doc_685122975278_item	2816471	et	3	main
on	doc_685122975278_item	2816472	et	4	main
palka	doc_685122975278_item	2816517	et	4	main
perekonnanimi	doc_685122975278_item	2816537	et	3	main
tahtsin	doc_685122975279_item	2816556	et	3	main
huvitav	doc_685122975279_item	2816563	et	4	main
kelleks	doc_685122975279_item	2816580	et	4	main
ja	doc_685122975279_item	2816586	et	3	main
see	doc_685122975279_item	2816589	et	3	main
riigi	doc_685122975279_item	2816592	et	3	main
peavad	doc_685122975279_item	2816595	et	4	main
erinevad	doc_685122975279_item	2816597	et	4	main
rohkem	doc_685122975279_item	2816606	et	4	main
siis	doc_685122975279_item	2816607	et	3	main
parem	doc_685122975279_item	2816608	et	4	main
68	doc_685122975278_item	2816323	et	2	main
ma	doc_685122975278_item	2816325	et	3	main
vanemate	doc_685122975278_item	2816339	et	4	main
elu	doc_685122975278_item	2816340	et	4	main
proovima	doc_685122975278_item	2816347	et	3	main
huvitav	doc_685122975278_item	2816359	et	4	main
elus	doc_685122975278_item	2816361	et	4	main
et	doc_685122975278_item	2816363	et	3	main
aga	doc_685122975278_item	2816373	et	3	main
mõnikord	doc_685122975278_item	2816374	et	3	main
võib	doc_685122975278_item	2816375	et	3	main
olla	doc_685122975278_item	2816376	et	3	main
et	doc_685122975278_item	2816377	et	3	main
nende	doc_685122975278_item	2816378	et	4	main
oskus	doc_685122975278_item	2816379	et	3	main
sõltub	doc_685122975278_item	2816380	et	3	main
riigieksamite	doc_685122975278_item	2816381	et	3	main
tulemustest	doc_685122975278_item	2816382	et	4	main
see	doc_685122975278_item	2816383	et	3	main
arvestus	doc_685122975278_item	2816384	et	4	main
kuhu	doc_685122975278_item	2816385	et	3	main
nende	doc_685122975278_item	2816386	et	4	main
punktidega	doc_685122975278_item	2816387	et	3	main
üldse	doc_685122975278_item	2816388	et	3	main
saab	doc_685122975278_item	2816389	et	3	main
minna	doc_685122975278_item	2816390	et	3	main
veel	doc_685122975278_item	2816391	et	4	main
nagu	doc_685122975278_item	2816392	et	3	main
te	doc_685122975278_item	2816393	et	4	main
kirjutasite	doc_685122975278_item	2816394	et	3	main
et	doc_685122975278_item	2816395	et	3	main
inimeste	doc_685122975278_item	2816396	et	3	main
rühm	doc_685122975278_item	2816397	et	3	main
kes	doc_685122975278_item	2816398	et	4	main
me	doc_685122975278_item	2816405	et	4	main
missugused	doc_685122975278_item	2816424	et	3	main
siis	doc_685122975278_item	2816426	et	3	main
nad	doc_685122975278_item	2816427	et	3	main
mõned	doc_685122975278_item	2816436	et	3	main
ole	doc_685122975278_item	2816448	et	4	main
nõus	doc_685122975278_item	2816462	et	4	main
kas	doc_685122975278_item	2816506	et	3	main
küsite	doc_685122975278_item	2816508	et	3	main
sellest	doc_685122975278_item	2816509	et	4	main
õppida	doc_685122975278_item	2816514	et	3	main
abituriendid	doc_685122975278_item	2816519	et	3	main
eesnimi	doc_685122975278_item	2816536	et	3	main
eesti	doc_685122975279_item	2816545	et	4	main
teie	doc_685122975279_item	2816551	et	4	main
artikli	doc_685122975279_item	2816552	et	3	main
vähenõudlike	doc_685122975279_item	2816553	et	3	main
põlvkond	doc_685122975279_item	2816554	et	3	main
kirjutada	doc_685122975279_item	2816557	et	3	main
on	doc_685122975279_item	2816562	et	4	main
mulle	doc_685122975279_item	2816573	et	4	main
et	doc_685122975279_item	2816575	et	3	main
tahate	doc_685122975279_item	2816577	et	3	main
saada	doc_685122975279_item	2816583	et	4	main
tanapäevased	doc_685122975279_item	2816584	et	4	main
suunas	doc_685122975279_item	2816601	et	4	main
ja	doc_685122975279_item	2816602	et	3	main
kui	doc_685122975279_item	2816603	et	3	main
on	doc_685122975279_item	2816621	et	4	main
nii	doc_685122975279_item	2816623	et	3	main
ei	doc_685122975279_item	2816626	et	4	main
arva	doc_685122975279_item	2816627	et	4	main
et	doc_685122975279_item	2816628	et	3	main
see	doc_685122975279_item	2816629	et	3	main
on	doc_685122975279_item	2816639	et	4	main
vähenõudlik	doc_685122975279_item	2816640	et	3	main
mingi	doc_685122975279_item	2816649	et	4	main
mitte	doc_685122975279_item	2816653	et	3	main
midagi	doc_685122975279_item	2816654	et	4	main
küsitluses	doc_685122975279_item	2816661	et	4	main
et	doc_685122975279_item	2816665	et	3	main
ta	doc_685122975279_item	2816677	et	4	main
saab	doc_685122975279_item	2816678	et	3	main
rääkida	doc_685122975279_item	2816688	et	3	main
kes	doc_685122975279_item	2816702	et	4	main
oskavad	doc_685122975279_item	2816703	et	4	main
mõtlema	doc_685122975279_item	2816704	et	3	main
töötama	doc_685122975279_item	2816705	et	3	main
meie	doc_685122975279_item	2816709	et	4	main
mina	doc_685122975280_item	2816720	et	4	main
mida	doc_685122975278_item	2816415	et	4	main
kaaslased	doc_685122975278_item	2816433	et	3	main
saa	doc_685122975278_item	2816438	et	4	main
seest	doc_685122975278_item	2816440	et	3	main
saavad	doc_685122975278_item	2816443	et	4	main
aru	doc_685122975278_item	2816444	et	4	main
et	doc_685122975278_item	2816445	et	3	main
see	doc_685122975278_item	2816446	et	3	main
töötada	doc_685122975278_item	2816453	et	3	main
väga	doc_685122975278_item	2816458	et	3	main
hea	doc_685122975278_item	2816473	et	4	main
mõte	doc_685122975278_item	2816474	et	3	main
et	doc_685122975278_item	2816505	et	3	main
te	doc_685122975278_item	2816507	et	4	main
aastal	doc_685122975278_item	2816511	et	3	main
mida	doc_685122975278_item	2816512	et	4	main
tahavad	doc_685122975278_item	2816513	et	3	main
ja	doc_685122975278_item	2816515	et	3	main
palju	doc_685122975278_item	2816516	et	4	main
see	doc_685122975278_item	2816520	et	3	main
olla	doc_685122975278_item	2816522	et	3	main
huvitav	doc_685122975278_item	2816523	et	4	main
missugused	doc_685122975278_item	2816525	et	3	main
vastused	doc_685122975278_item	2816526	et	3	main
on	doc_685122975278_item	2816527	et	4	main
järgmisel	doc_685122975278_item	2816528	et	3	main
tiina	doc_685122975279_item	2816541	et	4	main
lugeja	doc_685122975279_item	2816548	et	4	main
olen	doc_685122975279_item	2816549	et	3	main
eriala	doc_685122975279_item	2816560	et	4	main
teema	doc_685122975279_item	2816564	et	4	main
meie	doc_685122975279_item	2816568	et	4	main
elus	doc_685122975279_item	2816569	et	4	main
palju	doc_685122975279_item	2816570	et	4	main
te	doc_685122975279_item	2816576	et	4	main
aru	doc_685122975279_item	2816578	et	4	main
saada	doc_685122975279_item	2816579	et	4	main
abiturientid	doc_685122975279_item	2816585	et	4	main
inimesed	doc_685122975279_item	2816588	et	3	main
on	doc_685122975279_item	2816590	et	4	main
neid	doc_685122975279_item	2816604	et	4	main
ainult	doc_685122975279_item	2816643	et	4	main
huvi	doc_685122975279_item	2816659	et	4	main
töö	doc_685122975279_item	2816676	et	4	main
palju	doc_685122975279_item	2816683	et	4	main
oskavad	doc_685122975279_item	2816686	et	4	main
on	doc_685122975279_item	2816698	et	4	main
tahavad	doc_685122975279_item	2816707	et	3	main
tiina	doc_685122975280_item	2816718	et	4	main
tehnikaülikooli	doc_685122975280_item	2816723	et	4	main
üliõppilane	doc_685122975280_item	2816724	et	4	main
on	doc_685122975280_item	2816727	et	4	main
eesnimi	doc_685122975280_item	2816728	et	3	main
perekonnanimi	doc_685122975280_item	2816729	et	3	main
ja	doc_685122975280_item	2816741	et	3	main
neist	doc_685122975280_item	2816746	et	4	main
oli	doc_685122975280_item	2816747	et	3	main
ehitas	doc_685122975280_item	2816748	et	3	main
firma	doc_685122975280_item	2816749	et	4	main
aga	doc_685122975280_item	2816750	et	3	main
teine	doc_685122975280_item	2816751	et	3	main
oli	doc_685122975280_item	2816752	et	3	main
teiega	doc_685122975280_item	2816764	et	3	main
isegi	doc_685122975280_item	2816767	et	4	main
tõenäoliselt	doc_685122975280_item	2816778	et	4	main
meie	doc_685122975280_item	2816779	et	4	main
põlvkond	doc_685122975280_item	2816780	et	3	main
on	doc_685122975280_item	2816785	et	4	main
raske	doc_685122975280_item	2816786	et	4	main
selle	doc_685122975280_item	2816796	et	4	main
probleemi	doc_685122975280_item	2816797	et	4	main
sügavamalt	doc_685122975280_item	2816801	et	4	main
pole	doc_685122975280_item	2816806	et	3	main
ainult	doc_685122975280_item	2816807	et	4	main
vanad	doc_685122975280_item	2816810	et	3	main
kui	doc_685122975280_item	2816812	et	3	main
kokku	doc_685122975280_item	2816818	et	3	main
kavalad	doc_685122975280_item	2816825	et	3	main
või	doc_685122975280_item	2816840	et	4	main
on	doc_685122975280_item	2816852	et	4	main
see	doc_685122975280_item	2816853	et	3	main
et	doc_685122975280_item	2816854	et	3	main
aga	doc_685122975278_item	2816434	et	3	main
huvitav	doc_685122975278_item	2816449	et	4	main
ja	doc_685122975278_item	2816450	et	3	main
nad	doc_685122975278_item	2816451	et	3	main
algavad	doc_685122975278_item	2816452	et	4	main
ma	doc_685122975278_item	2816460	et	3	main
rahaasjus	doc_685122975278_item	2816464	et	3	main
abituriendid	doc_685122975278_item	2816466	et	3	main
et	doc_685122975278_item	2816475	et	3	main
arstid	doc_685122975278_item	2816476	et	4	main
peavad	doc_685122975278_item	2816477	et	4	main
töö	doc_685122975278_item	2816478	et	4	main
eest	doc_685122975278_item	2816479	et	4	main
saama	doc_685122975278_item	2816480	et	4	main
palju	doc_685122975278_item	2816482	et	4	main
väga	doc_685122975278_item	2816481	et	3	main
rohkem	doc_685122975278_item	2816483	et	4	main
raha	doc_685122975278_item	2816484	et	4	main
kui	doc_685122975278_item	2816485	et	3	main
nad	doc_685122975278_item	2816487	et	3	main
teenivad	doc_685122975278_item	2816488	et	4	main
seda	doc_685122975278_item	2816489	et	3	main
ära	doc_685122975278_item	2816490	et	4	main
täna	doc_685122975278_item	2816486	et	4	main
lõpuks	doc_685122975278_item	2816491	et	4	main
ma	doc_685122975278_item	2816492	et	3	main
tahaksin	doc_685122975278_item	2816493	et	3	main
öelda	doc_685122975278_item	2816494	et	4	main
et	doc_685122975278_item	2816495	et	3	main
ma	doc_685122975278_item	2816496	et	3	main
olen	doc_685122975278_item	2816497	et	3	main
täpselt	doc_685122975278_item	2816498	et	4	main
nõus	doc_685122975278_item	2816499	et	4	main
teie	doc_685122975278_item	2816500	et	4	main
artikliga	doc_685122975278_item	2816501	et	3	main
ja	doc_685122975278_item	2816502	et	3	main
tahaksin	doc_685122975278_item	2816503	et	3	main
küsida	doc_685122975278_item	2816504	et	3	main
igal	doc_685122975278_item	2816510	et	3	main
saada	doc_685122975278_item	2816518	et	4	main
võib	doc_685122975278_item	2816521	et	3	main
vaadata	doc_685122975278_item	2816524	et	4	main
aastal	doc_685122975278_item	2816529	et	3	main
igal	doc_685122975278_item	2816530	et	3	main
aastal	doc_685122975278_item	2816531	et	3	main
on	doc_685122975278_item	2816532	et	4	main
kaalep	doc_685122975279_item	2816542	et	4	main
ma	doc_685122975279_item	2816543	et	3	main
olen	doc_685122975279_item	2816544	et	3	main
lugenud	doc_685122975279_item	2816550	et	4	main
valimine	doc_685122975279_item	2816561	et	4	main
valikust	doc_685122975279_item	2816566	et	4	main
sõltub	doc_685122975279_item	2816567	et	3	main
artiklis	doc_685122975279_item	2816572	et	3	main
noored	doc_685122975279_item	2816587	et	3	main
tähtis	doc_685122975279_item	2816591	et	4	main
olema	doc_685122975279_item	2816596	et	4	main
spetsialistid	doc_685122975279_item	2816598	et	3	main
iga	doc_685122975279_item	2816599	et	4	main
omas	doc_685122975279_item	2816600	et	4	main
on	doc_685122975279_item	2816605	et	4	main
täpselt	doc_685122975279_item	2816622	et	4	main
ma	doc_685122975279_item	2816625	et	3	main
tähenda	doc_685122975279_item	2816635	et	4	main
et	doc_685122975279_item	2816636	et	3	main
kui	doc_685122975279_item	2816637	et	3	main
inimene	doc_685122975279_item	2816638	et	3	main
kohta	doc_685122975279_item	2816644	et	4	main
ekspressi	doc_685122975279_item	2816660	et	4	main
ütlesid	doc_685122975279_item	2816664	et	4	main
tuua	doc_685122975279_item	2816679	et	3	main
kasu	doc_685122975279_item	2816680	et	4	main
inimesi	doc_685122975279_item	2816684	et	4	main
osaleda	doc_685122975279_item	2816690	et	3	main
saates	doc_685122975279_item	2816692	et	4	main
mitte	doc_685122975279_item	2816694	et	3	main
teha	doc_685122975279_item	2816708	et	3	main
kaalep	doc_685122975280_item	2816719	et	4	main
tallinna	doc_685122975280_item	2816722	et	4	main
tagasi	doc_685122975280_item	2816734	et	3	main
aastaga	doc_685122975280_item	2816736	et	3	main
mereväes	doc_685122975280_item	2816738	et	3	main
töötada	doc_685122975280_item	2816742	et	3	main
firmas	doc_685122975280_item	2816744	et	3	main
osaliselt	doc_685122975280_item	2816765	et	4	main
omas	doc_685122975280_item	2816772	et	4	main
artiklis	doc_685122975280_item	2816773	et	3	main
põlvkonna	doc_685122975280_item	2816776	et	4	main
sellega	doc_685122975280_item	2816784	et	3	main
vaielda	doc_685122975280_item	2816787	et	4	main
aga	doc_685122975280_item	2816788	et	3	main
peab	doc_685122975280_item	2816789	et	4	main
leida	doc_685122975280_item	2816790	et	3	main
vastuse	doc_685122975280_item	2816791	et	3	main
peale	doc_685122975280_item	2816798	et	4	main
peab	doc_685122975280_item	2816799	et	4	main
minu	doc_685122975280_item	2816803	et	3	main
te	doc_685122975280_item	2816813	et	4	main
lõppuni	doc_685122975280_item	2816821	et	3	main
ära	doc_685122975280_item	2816822	et	4	main
need	doc_685122975280_item	2816824	et	3	main
on	doc_685122975280_item	2816831	et	4	main
muuta	doc_685122975280_item	2816839	et	4	main
heaks	doc_685122975280_item	2816843	et	4	main
pole	doc_685122975280_item	2816845	et	3	main
tuleb	doc_685122975280_item	2816862	et	3	main
kännu	doc_685122975280_item	2816864	et	3	main
mulle	doc_685122975280_item	2816905	et	4	main
11102006a	doc_685122975280_item	2816907	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975280_item	2816908	et	4	main
kiri	doc_685122975281_item	2816909	et	3	main
tere	doc_685122975281_item	2816910	et	3	main
lugupetud	doc_685122975281_item	2816911	et	3	main
arvamus	doc_685122975281_item	2816922	et	3	main
oli	doc_685122975281_item	2816925	et	3	main
kohta	doc_685122975281_item	2816940	et	4	main
ma	doc_685122975281_item	2816941	et	3	main
olen	doc_685122975281_item	2816942	et	3	main
midagi	doc_685122975278_item	2816533	et	4	main
uus	doc_685122975278_item	2816534	et	3	main
lugupidamisega	doc_685122975278_item	2816535	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975278_item	2816538	et	4	main
kiri	doc_685122975279_item	2816539	et	3	main
lp	doc_685122975279_item	2816540	et	4	main
ekspressi	doc_685122975279_item	2816546	et	4	main
püsiv	doc_685122975279_item	2816547	et	4	main
ja	doc_685122975279_item	2816555	et	3	main
vastust	doc_685122975279_item	2816558	et	4	main
tuleviku	doc_685122975279_item	2816559	et	4	main
sellest	doc_685122975279_item	2816565	et	4	main
teie	doc_685122975279_item	2816571	et	4	main
meeldis	doc_685122975279_item	2816574	et	3	main
tulevikus	doc_685122975279_item	2816581	et	4	main
tahavad	doc_685122975279_item	2816582	et	3	main
tulevikule	doc_685122975279_item	2816593	et	4	main
meil	doc_685122975279_item	2816594	et	4	main
te	doc_685122975279_item	2816609	et	4	main
olete	doc_685122975279_item	2816610	et	3	main
kirjutanud	doc_685122975279_item	2816611	et	4	main
et	doc_685122975279_item	2816612	et	3	main
meie	doc_685122975279_item	2816613	et	4	main
põlvkond	doc_685122975279_item	2816614	et	3	main
on	doc_685122975279_item	2816615	et	4	main
vähenõudlik	doc_685122975279_item	2816616	et	3	main
ma	doc_685122975279_item	2816617	et	3	main
arvan	doc_685122975279_item	2816618	et	3	main
teiega	doc_685122975279_item	2816619	et	3	main
enamik	doc_685122975279_item	2816620	et	3	main
on	doc_685122975279_item	2816630	et	4	main
halb	doc_685122975279_item	2816631	et	3	main
sest	doc_685122975279_item	2816632	et	4	main
see	doc_685122975279_item	2816633	et	3	main
ta	doc_685122975279_item	2816641	et	4	main
kus	doc_685122975279_item	2816645	et	3	main
saada	doc_685122975279_item	2816651	et	4	main
ja	doc_685122975279_item	2816652	et	3	main
neid	doc_685122975279_item	2816656	et	4	main
palju	doc_685122975279_item	2816662	et	4	main
väga	doc_685122975279_item	2816666	et	3	main
et	doc_685122975279_item	2816668	et	3	main
oleks	doc_685122975279_item	2816670	et	3	main
huvitav	doc_685122975279_item	2816671	et	4	main
kui	doc_685122975279_item	2816672	et	3	main
teistele	doc_685122975279_item	2816681	et	4	main
väga	doc_685122975279_item	2816682	et	3	main
kes	doc_685122975279_item	2816685	et	4	main
ainult	doc_685122975279_item	2816687	et	4	main
tele	doc_685122975279_item	2816691	et	4	main
aga	doc_685122975279_item	2816693	et	3	main
midagi	doc_685122975279_item	2816695	et	4	main
rohkem	doc_685122975279_item	2816696	et	4	main
riigile	doc_685122975279_item	2816697	et	3	main
ja	doc_685122975279_item	2816706	et	3	main
elu	doc_685122975279_item	2816710	et	4	main
parem	doc_685122975279_item	2816711	et	4	main
lugupidamisega	doc_685122975279_item	2816712	et	3	main
eesnimi	doc_685122975279_item	2816713	et	3	main
perekonnanimi	doc_685122975279_item	2816714	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975279_item	2816715	et	4	main
kiri	doc_685122975280_item	2816716	et	3	main
gümnaasiumi	doc_685122975280_item	2816730	et	4	main
aastat	doc_685122975280_item	2816733	et	3	main
jõudsin	doc_685122975280_item	2816737	et	3	main
käia	doc_685122975280_item	2816740	et	4	main
pärast	doc_685122975280_item	2816770	et	4	main
et	doc_685122975280_item	2816771	et	3	main
on	doc_685122975280_item	2816781	et	4	main
aga	doc_685122975279_item	2816624	et	3	main
ei	doc_685122975279_item	2816634	et	4	main
tahab	doc_685122975279_item	2816642	et	3	main
käia	doc_685122975279_item	2816646	et	4	main
tööl	doc_685122975279_item	2816647	et	3	main
ja	doc_685122975279_item	2816648	et	3	main
palk	doc_685122975279_item	2816650	et	3	main
rohkem	doc_685122975279_item	2816655	et	4	main
elus	doc_685122975279_item	2816657	et	4	main
ei	doc_685122975279_item	2816658	et	4	main
inimesi	doc_685122975279_item	2816663	et	4	main
tähtis	doc_685122975279_item	2816667	et	4	main
töö	doc_685122975279_item	2816669	et	4	main
inimene	doc_685122975279_item	2816673	et	3	main
armastab	doc_685122975279_item	2816674	et	3	main
oma	doc_685122975279_item	2816675	et	4	main
ja	doc_685122975279_item	2816689	et	3	main
vaja	doc_685122975279_item	2816699	et	4	main
häid	doc_685122975279_item	2816700	et	3	main
spetsialiste	doc_685122975279_item	2816701	et	3	main
lp	doc_685122975280_item	2816717	et	4	main
olen	doc_685122975280_item	2816721	et	3	main
minu	doc_685122975280_item	2816725	et	3	main
nimi	doc_685122975280_item	2816726	et	3	main
ära	doc_685122975280_item	2816739	et	4	main
kahes	doc_685122975280_item	2816743	et	4	main
üks	doc_685122975280_item	2816745	et	3	main
nõus	doc_685122975280_item	2816766	et	4	main
täesti	doc_685122975280_item	2816768	et	4	main
selle	doc_685122975280_item	2816769	et	4	main
meie	doc_685122975280_item	2816775	et	4	main
väga	doc_685122975280_item	2816777	et	3	main
olukord	doc_685122975280_item	2816794	et	3	main
tekkis	doc_685122975280_item	2816795	et	3	main
probleem	doc_685122975280_item	2816805	et	3	main
nendega	doc_685122975280_item	2816817	et	4	main
võivad	doc_685122975280_item	2816819	et	4	main
lõpetasin	doc_685122975280_item	2816731	et	3	main
kaks	doc_685122975280_item	2816732	et	3	main
kahe	doc_685122975280_item	2816735	et	3	main
puuimutamine	doc_685122975280_item	2816753	et	4	main
kirjutan	doc_685122975280_item	2816754	et	3	main
teile	doc_685122975280_item	2816755	et	4	main
seoses	doc_685122975280_item	2816756	et	4	main
sellega	doc_685122975280_item	2816757	et	3	main
et	doc_685122975280_item	2816758	et	3	main
õppetaja	doc_685122975280_item	2816759	et	4	main
andis	doc_685122975280_item	2816760	et	3	main
selle	doc_685122975280_item	2816761	et	4	main
ülesanne	doc_685122975280_item	2816762	et	4	main
olen	doc_685122975280_item	2816763	et	3	main
kirjeldasite	doc_685122975280_item	2816774	et	3	main
miks	doc_685122975280_item	2816792	et	4	main
sest	doc_685122975280_item	2816802	et	4	main
meis	doc_685122975280_item	2816808	et	3	main
korda	doc_685122975280_item	2816815	et	4	main
saate	doc_685122975280_item	2816816	et	4	main
neil	doc_685122975280_item	2816830	et	4	main
midagi	doc_685122975280_item	2816838	et	4	main
üks	doc_685122975280_item	2816860	et	3	main
peale	doc_685122975280_item	2816866	et	4	main
uus	doc_685122975280_item	2816867	et	3	main
noor	doc_685122975280_item	2816868	et	3	main
spetsialist	doc_685122975280_item	2816869	et	3	main
muudatused	doc_685122975280_item	2816870	et	3	main
tulevad	doc_685122975280_item	2816871	et	4	main
aga	doc_685122975280_item	2816872	et	3	main
et	doc_685122975280_item	2816902	et	3	main
kirjutate	doc_685122975280_item	2816904	et	3	main
kaalep	doc_685122975281_item	2816913	et	4	main
teie	doc_685122975281_item	2816916	et	4	main
kirjutada	doc_685122975281_item	2816920	et	3	main
oma	doc_685122975281_item	2816921	et	4	main
sellest	doc_685122975281_item	2816923	et	4	main
huvitav	doc_685122975281_item	2816926	et	4	main
ja	doc_685122975281_item	2816927	et	3	main
ma	doc_685122975281_item	2816928	et	3	main
mõtlen	doc_685122975281_item	2816929	et	3	main
et	doc_685122975281_item	2816930	et	3	main
ta	doc_685122975281_item	2816931	et	4	main
andis	doc_685122975281_item	2816932	et	3	main
nõus	doc_685122975281_item	2816943	et	4	main
ei	doc_685122975281_item	2816952	et	4	main
ei	doc_685122975281_item	2816965	et	4	main
tea	doc_685122975281_item	2816966	et	4	main
kuhu	doc_685122975281_item	2816967	et	3	main
minu	doc_685122975281_item	2816984	et	3	main
ema	doc_685122975281_item	2816985	et	4	main
kas	doc_685122975281_item	2816992	et	3	main
lähevad	doc_685122975281_item	2817022	et	3	main
sinna	doc_685122975281_item	2817025	et	3	main
nad	doc_685122975281_item	2817027	et	3	main
lähevad	doc_685122975281_item	2817031	et	3	main
alast	doc_685122975281_item	2817038	et	4	main
sellest	doc_685122975281_item	2817041	et	4	main
kus	doc_685122975281_item	2817045	et	3	main
tänavatel	doc_685122975281_item	2817056	et	4	main
igatahes	doc_685122975281_item	2817057	et	3	main
mitte	doc_685122975281_item	2817058	et	3	main
tööga	doc_685122975281_item	2817059	et	3	main
vaid	doc_685122975281_item	2817061	et	3	main
viibime	doc_685122975281_item	2817064	et	3	main
rohkem	doc_685122975281_item	2817065	et	4	main
kui	doc_685122975281_item	2817067	et	3	main
on	doc_685122975281_item	2817085	et	4	main
üsna	doc_685122975281_item	2817086	et	3	main
kes	doc_685122975281_item	2817124	et	4	main
saavadki	doc_685122975281_item	2817127	et	4	main
ministriks	doc_685122975281_item	2817128	et	3	main
ja	doc_685122975281_item	2817129	et	3	main
peaministriks	doc_685122975281_item	2817130	et	3	main
kes	doc_685122975281_item	2817131	et	4	main
vead	doc_685122975281_item	2817138	et	4	main
tulevikus	doc_685122975281_item	2817148	et	4	main
riik	doc_685122975281_item	2817149	et	3	main
hakkab	doc_685122975281_item	2817150	et	3	main
aitama	doc_685122975281_item	2817151	et	3	main
noori	doc_685122975281_item	2817152	et	3	main
inimesi	doc_685122975281_item	2817153	et	4	main
on	doc_685122975281_item	2817165	et	4	main
aastakäikude	doc_685122975281_item	2817168	et	3	main
tahaksin	doc_685122975282_item	2817178	et	3	main
eest	doc_685122975282_item	2817183	et	4	main
oli	doc_685122975282_item	2817185	et	3	main
uut	doc_685122975282_item	2817191	et	3	main
noorte	doc_685122975282_item	2817193	et	3	main
et	doc_685122975282_item	2817200	et	3	main
inimesi	doc_685122975282_item	2817202	et	4	main
soovib	doc_685122975282_item	2817203	et	3	main
palka	doc_685122975282_item	2817212	et	4	main
et	doc_685122975282_item	2817213	et	3	main
poleks	doc_685122975282_item	2817214	et	3	main
iga	doc_685122975282_item	2817220	et	4	main
ebaaktiivne	doc_685122975280_item	2816782	et	3	main
ja	doc_685122975280_item	2816783	et	3	main
selline	doc_685122975280_item	2816793	et	4	main
vaadata	doc_685122975280_item	2816800	et	4	main
arvatest	doc_685122975280_item	2816804	et	3	main
need	doc_685122975280_item	2816809	et	3	main
kännud	doc_685122975280_item	2816811	et	3	main
esimest	doc_685122975280_item	2816814	et	4	main
elu	doc_685122975280_item	2816820	et	4	main
päriselt	doc_685122975280_item	2816827	et	3	main
ajavad	doc_685122975280_item	2816828	et	4	main
närvi	doc_685122975280_item	2816829	et	4	main
oma	doc_685122975280_item	2816834	et	4	main
asju	doc_685122975280_item	2816835	et	3	main
ajada	doc_685122975280_item	2816836	et	3	main
ja	doc_685122975280_item	2816837	et	3	main
inimeste	doc_685122975280_item	2816842	et	3	main
neil	doc_685122975280_item	2816844	et	4	main
jõudu	doc_685122975280_item	2816846	et	4	main
ega	doc_685122975280_item	2816847	et	3	main
tahtmist	doc_685122975280_item	2816848	et	4	main
aga	doc_685122975280_item	2816849	et	3	main
hea	doc_685122975280_item	2816850	et	4	main
uudis	doc_685122975280_item	2816851	et	3	main
päev	doc_685122975280_item	2816861	et	3	main
teie	doc_685122975280_item	2816903	et	4	main
lugesin	doc_685122975281_item	2816914	et	3	main
ja	doc_685122975281_item	2816918	et	3	main
palju	doc_685122975281_item	2816933	et	4	main
uut	doc_685122975281_item	2816934	et	3	main
ja	doc_685122975281_item	2816935	et	3	main
kasulikku	doc_685122975281_item	2816936	et	4	main
informatsiooni	doc_685122975281_item	2816937	et	4	main
noorte	doc_685122975281_item	2816938	et	3	main
inimeste	doc_685122975281_item	2816939	et	3	main
sellega	doc_685122975281_item	2816948	et	3	main
et	doc_685122975281_item	2816949	et	3	main
palju	doc_685122975281_item	2816950	et	4	main
eest	doc_685122975281_item	2816963	et	4	main
nende	doc_685122975281_item	2816968	et	4	main
punktidega	doc_685122975281_item	2816969	et	3	main
üldse	doc_685122975281_item	2816970	et	3	main
saab	doc_685122975281_item	2816971	et	3	main
minna	doc_685122975281_item	2816972	et	3	main
mul	doc_685122975281_item	2816973	et	3	main
oli	doc_685122975281_item	2816974	et	3	main
ka	doc_685122975281_item	2816975	et	3	main
loomulikult	doc_685122975281_item	2816976	et	4	main
ma	doc_685122975281_item	2816977	et	3	main
lõpetasin	doc_685122975281_item	2816986	et	3	main
see	doc_685122975281_item	2816987	et	3	main
aga	doc_685122975281_item	2816988	et	3	main
ma	doc_685122975281_item	2816989	et	3	main
ma	doc_685122975281_item	2816993	et	3	main
astuda	doc_685122975281_item	2816995	et	3	main
õppima	doc_685122975281_item	2817024	et	3	main
hooli	doc_685122975281_item	2817037	et	4	main
toimub	doc_685122975281_item	2817053	et	3	main
tööl	doc_685122975281_item	2817062	et	3	main
ja	doc_685122975281_item	2817069	et	3	main
kätte	doc_685122975281_item	2817084	et	4	main
ehmatada	doc_685122975280_item	2816823	et	3	main
afferistid	doc_685122975280_item	2816826	et	4	main
vaja	doc_685122975280_item	2816832	et	4	main
ainult	doc_685122975280_item	2816833	et	4	main
teha	doc_685122975280_item	2816841	et	3	main
peab	doc_685122975280_item	2816873	et	4	main
natuke	doc_685122975280_item	2816874	et	4	main
oodata	doc_685122975280_item	2816875	et	4	main
tallinna	doc_685122975280_item	2816876	et	4	main
linnapea	doc_685122975280_item	2816877	et	4	main
on	doc_685122975280_item	2816878	et	4	main
juri	doc_685122975280_item	2816879	et	4	main
ratas	doc_685122975280_item	2816880	et	3	main
kahekümmne	doc_685122975280_item	2816881	et	4	main
viie	doc_685122975280_item	2816882	et	3	main
aastane	doc_685122975280_item	2816883	et	4	main
mees	doc_685122975280_item	2816884	et	4	main
ja	doc_685122975280_item	2816885	et	3	main
see	doc_685122975280_item	2816886	et	3	main
tähendab	doc_685122975280_item	2816887	et	3	main
et	doc_685122975280_item	2816888	et	3	main
asi	doc_685122975280_item	2816889	et	4	main
läks	doc_685122975280_item	2816890	et	3	main
peame	doc_685122975280_item	2816891	et	4	main
olema	doc_685122975280_item	2816892	et	4	main
optimistid	doc_685122975280_item	2816893	et	3	main
ja	doc_685122975280_item	2816894	et	3	main
kõik	doc_685122975280_item	2816895	et	4	main
saab	doc_685122975280_item	2816896	et	3	main
korda	doc_685122975280_item	2816897	et	4	main
lugupidamisega	doc_685122975280_item	2816898	et	3	main
eesnimi	doc_685122975280_item	2816899	et	3	main
perekonnanimi	doc_685122975280_item	2816900	et	3	main
loodan	doc_685122975280_item	2816901	et	3	main
inimesed	doc_685122975280_item	2816855	et	3	main
ei	doc_685122975280_item	2816856	et	4	main
ela	doc_685122975280_item	2816857	et	4	main
kaua	doc_685122975280_item	2816858	et	3	main
ja	doc_685122975280_item	2816859	et	3	main
vana	doc_685122975280_item	2816863	et	4	main
kaha	doc_685122975280_item	2816865	et	4	main
artikkel	doc_685122975281_item	2816924	et	3	main
absoluutselt	doc_685122975281_item	2816944	et	4	main
teie	doc_685122975281_item	2816945	et	4	main
artikliga	doc_685122975281_item	2816946	et	3	main
eriti	doc_685122975281_item	2816947	et	3	main
tea	doc_685122975281_item	2816953	et	4	main
nende	doc_685122975281_item	2816958	et	4	main
alati	doc_685122975281_item	2816978	et	4	main
tahaksin	doc_685122975281_item	2816979	et	3	main
õppida	doc_685122975281_item	2816980	et	3	main
tahavad	doc_685122975281_item	2817028	et	3	main
kuhu	doc_685122975281_item	2817032	et	3	main
sisse	doc_685122975281_item	2817033	et	4	main
saavad	doc_685122975281_item	2817034	et	4	main
nad	doc_685122975281_item	2817035	et	3	main
vaid	doc_685122975281_item	2817039	et	3	main
oleks	doc_685122975281_item	2817043	et	3	main
aega	doc_685122975281_item	2817066	et	4	main
mõjutab	doc_685122975281_item	2817071	et	3	main
halvasti	doc_685122975281_item	2817072	et	3	main
inimestel	doc_685122975281_item	2817074	et	3	main
rahaasjus	doc_685122975281_item	2817078	et	3	main
samas	doc_685122975281_item	2817080	et	4	main
realistlikud	doc_685122975281_item	2817081	et	3	main
kümme	doc_685122975281_item	2817082	et	3	main
tuhat	doc_685122975281_item	2817083	et	4	main
neid	doc_685122975281_item	2817123	et	4	main
ja	doc_685122975281_item	2817126	et	3	main
mis	doc_685122975281_item	2817137	et	4	main
loodan	doc_685122975281_item	2817146	et	3	main
midagi	doc_685122975281_item	2817158	et	4	main
lugupeetud	doc_685122975282_item	2817175	et	4	main
teie	doc_685122975282_item	2817181	et	4	main
see	doc_685122975282_item	2817184	et	3	main
informatsiooni	doc_685122975282_item	2817192	et	4	main
kohta	doc_685122975282_item	2817195	et	4	main
ma	doc_685122975282_item	2817196	et	3	main
olen	doc_685122975282_item	2817197	et	3	main
ja	doc_685122975282_item	2817207	et	3	main
kuu	doc_685122975282_item	2817210	et	4	main
oma	doc_685122975282_item	2817211	et	4	main
välja	doc_685122975282_item	2817218	et	4	main
mõelda	doc_685122975282_item	2817219	et	4	main
päev	doc_685122975282_item	2817221	et	3	main
pead	doc_685122975282_item	2817231	et	4	main
hoolitsev	doc_685122975282_item	2817239	et	4	main
nagu	doc_685122975282_item	2817240	et	3	main
meie	doc_685122975282_item	2817241	et	4	main
lõpetamist	doc_685122975282_item	2817249	et	4	main
leida	doc_685122975282_item	2817252	et	3	main
tööd	doc_685122975282_item	2817268	et	4	main
vastus	doc_685122975282_item	2817272	et	3	main
on	doc_685122975282_item	2817274	et	4	main
õiget	doc_685122975282_item	2817276	et	3	main
suvalistele	doc_685122975282_item	2817298	et	4	main
vastuse	doc_685122975280_item	2816906	et	3	main
tiina	doc_685122975281_item	2816912	et	4	main
hiljuti	doc_685122975281_item	2816915	et	4	main
artikkel	doc_685122975281_item	2816917	et	3	main
tahaksin	doc_685122975281_item	2816919	et	3	main
mis	doc_685122975281_item	2816954	et	4	main
saab	doc_685122975281_item	2816956	et	3	main
nad	doc_685122975281_item	2816964	et	3	main
ei	doc_685122975281_item	2816990	et	4	main
mitte	doc_685122975281_item	2816997	et	3	main
tõeline	doc_685122975281_item	2816998	et	4	main
et	doc_685122975281_item	2816999	et	3	main
abiturieentidel	doc_685122975281_item	2817000	et	4	main
pole	doc_685122975281_item	2817001	et	3	main
peale	doc_685122975281_item	2817002	et	4	main
sisetunde	doc_685122975281_item	2817003	et	4	main
kuidas	doc_685122975281_item	2817004	et	3	main
eksamid	doc_685122975281_item	2817005	et	3	main
läksid	doc_685122975281_item	2817006	et	4	main
tegelikult	doc_685122975281_item	2817007	et	4	main
midagi	doc_685122975281_item	2817008	et	4	main
millele	doc_685122975281_item	2817009	et	3	main
tulevikuplaane	doc_685122975281_item	2817010	et	3	main
rajada	doc_685122975281_item	2817011	et	3	main
kõik	doc_685122975281_item	2817012	et	4	main
on	doc_685122975281_item	2817013	et	4	main
otsustanud	doc_685122975281_item	2817014	et	4	main
millal	doc_685122975281_item	2817015	et	3	main
tulid	doc_685122975281_item	2817016	et	4	main
eksamite	doc_685122975281_item	2817017	et	3	main
tulemused	doc_685122975281_item	2817018	et	3	main
mitte	doc_685122975281_item	2817019	et	3	main
kõik	doc_685122975281_item	2817020	et	4	main
inimesed	doc_685122975281_item	2817021	et	3	main
palju	doc_685122975281_item	2817029	et	4	main
inimesi	doc_685122975281_item	2817030	et	4	main
ainult	doc_685122975281_item	2817040	et	4	main
et	doc_685122975281_item	2817042	et	3	main
käia	doc_685122975281_item	2817046	et	4	main
mingi	doc_685122975281_item	2817048	et	4	main
palk	doc_685122975281_item	2817049	et	3	main
saada	doc_685122975281_item	2817050	et	4	main
tegelik	doc_685122975281_item	2817051	et	3	main
seoses	doc_685122975281_item	2817060	et	4	main
me	doc_685122975281_item	2817063	et	4	main
see	doc_685122975281_item	2817070	et	3	main
nendel	doc_685122975281_item	2817073	et	4	main
täpselt	doc_685122975281_item	2817076	et	4	main
et	doc_685122975281_item	2817077	et	3	main
keskmine	doc_685122975281_item	2817087	et	3	main
uut	doc_685122975281_item	2817121	et	3	main
rohkem	doc_685122975281_item	2817154	et	4	main
ja	doc_685122975281_item	2817155	et	3	main
võib	doc_685122975281_item	2817156	et	3	main
olla	doc_685122975281_item	2817157	et	3	main
suunas	doc_685122975281_item	2817161	et	4	main
see	doc_685122975281_item	2817163	et	3	main
järgmiste	doc_685122975281_item	2817167	et	3	main
kaalep	doc_685122975282_item	2817177	et	4	main
artikli	doc_685122975282_item	2817182	et	3	main
väga	doc_685122975282_item	2817186	et	3	main
ja	doc_685122975282_item	2817188	et	3	main
palju	doc_685122975282_item	2817190	et	4	main
abiturieendid	doc_685122975281_item	2816951	et	4	main
neist	doc_685122975281_item	2816955	et	4	main
sellepärast	doc_685122975281_item	2816957	et	3	main
otsustus	doc_685122975281_item	2816959	et	4	main
sõltub	doc_685122975281_item	2816960	et	3	main
riigieksamite	doc_685122975281_item	2816961	et	3	main
tulemuste	doc_685122975281_item	2816962	et	4	main
majandusteatuskondis	doc_685122975281_item	2816981	et	4	main
ttüs	doc_685122975281_item	2816982	et	4	main
sellepärast	doc_685122975281_item	2816983	et	3	main
teadsin	doc_685122975281_item	2816991	et	3	main
oskaksin	doc_685122975281_item	2816994	et	3	main
või	doc_685122975281_item	2816996	et	4	main
kuhu	doc_685122975281_item	2817026	et	3	main
edasi	doc_685122975281_item	2817023	et	3	main
ei	doc_685122975281_item	2817036	et	4	main
koht	doc_685122975281_item	2817044	et	3	main
ja	doc_685122975281_item	2817047	et	3	main
elu	doc_685122975281_item	2817052	et	4	main
mujal	doc_685122975281_item	2817054	et	3	main
kodus	doc_685122975281_item	2817055	et	4	main
kodus	doc_685122975281_item	2817068	et	4	main
väga	doc_685122975281_item	2817075	et	3	main
abituriendid	doc_685122975281_item	2817079	et	3	main
number	doc_685122975281_item	2817088	et	3	main
reisida	doc_685122975281_item	2817089	et	3	main
ja	doc_685122975281_item	2817090	et	3	main
maja	doc_685122975281_item	2817091	et	4	main
liisida	doc_685122975281_item	2817092	et	4	main
on	doc_685122975281_item	2817093	et	4	main
sellega	doc_685122975281_item	2817094	et	3	main
juba	doc_685122975281_item	2817095	et	3	main
keeruline	doc_685122975281_item	2817096	et	4	main
vaid	doc_685122975281_item	2817097	et	3	main
üksikud	doc_685122975281_item	2817098	et	3	main
unistavad	doc_685122975281_item	2817099	et	4	main
julgemalt	doc_685122975281_item	2817100	et	4	main
ja	doc_685122975281_item	2817101	et	3	main
võtavad	doc_685122975281_item	2817102	et	3	main
kas	doc_685122975281_item	2817103	et	3	main
või	doc_685122975281_item	2817104	et	4	main
mõttes	doc_685122975281_item	2817105	et	3	main
riske	doc_685122975281_item	2817107	et	3	main
ja	doc_685122975281_item	2817108	et	3	main
see	doc_685122975281_item	2817109	et	3	main
suuremaid	doc_685122975281_item	2817106	et	4	main
on	doc_685122975281_item	2817110	et	4	main
õige	doc_685122975281_item	2817111	et	4	main
minu	doc_685122975281_item	2817112	et	3	main
üldine	doc_685122975281_item	2817113	et	4	main
et	doc_685122975281_item	2817115	et	3	main
arvamus	doc_685122975281_item	2817114	et	3	main
vajab	doc_685122975281_item	2817116	et	3	main
ühiskond	doc_685122975281_item	2817117	et	3	main
värskust	doc_685122975281_item	2817118	et	3	main
särtsu	doc_685122975281_item	2817120	et	4	main
ja	doc_685122975281_item	2817119	et	3	main
verd	doc_685122975281_item	2817122	et	3	main
tahavad	doc_685122975281_item	2817125	et	3	main
on	doc_685122975281_item	2817139	et	4	main
hariduses	doc_685122975281_item	2817140	et	3	main
ja	doc_685122975281_item	2817141	et	3	main
suudaksid	doc_685122975281_item	2817142	et	4	main
seda	doc_685122975281_item	2817143	et	3	main
teeksid	doc_685122975281_item	2817132	et	4	main
ümber	doc_685122975281_item	2817133	et	3	main
mittetoimiva	doc_685122975281_item	2817134	et	3	main
meditsiinisüsteemi	doc_685122975281_item	2817135	et	4	main
teaksid	doc_685122975281_item	2817136	et	4	main
muuta	doc_685122975281_item	2817144	et	4	main
ma	doc_685122975281_item	2817145	et	3	main
et	doc_685122975281_item	2817147	et	3	main
muutub	doc_685122975281_item	2817159	et	3	main
kõik	doc_685122975281_item	2817164	et	4	main
lootus	doc_685122975281_item	2817166	et	4	main
peal	doc_685122975281_item	2817169	et	4	main
lugupidamisega	doc_685122975281_item	2817170	et	3	main
eesnimi	doc_685122975281_item	2817171	et	3	main
perekonnanimi	doc_685122975281_item	2817172	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975281_item	2817173	et	4	main
kiri	doc_685122975282_item	2817174	et	3	main
tänada	doc_685122975282_item	2817179	et	3	main
saada	doc_685122975282_item	2817208	et	4	main
iga	doc_685122975282_item	2817209	et	4	main
vaja	doc_685122975282_item	2817215	et	4	main
midagi	doc_685122975282_item	2817216	et	4	main
elada	doc_685122975282_item	2817223	et	3	main
praeguses	doc_685122975282_item	2817226	et	3	main
elus	doc_685122975282_item	2817227	et	4	main
kus	doc_685122975282_item	2817228	et	3	main
sa	doc_685122975282_item	2817229	et	3	main
ise	doc_685122975282_item	2817230	et	4	main
hoolima	doc_685122975282_item	2817235	et	4	main
igaüks	doc_685122975282_item	2817236	et	3	main
tahaks	doc_685122975282_item	2817237	et	3	main
olla	doc_685122975282_item	2817238	et	3	main
tahavad	doc_685122975282_item	2817245	et	3	main
nõus	doc_685122975282_item	2817260	et	4	main
et	doc_685122975282_item	2817261	et	3	main
meie	doc_685122975282_item	2817262	et	4	main
üks	doc_685122975282_item	2817270	et	3	main
milline	doc_685122975282_item	2817285	et	3	main
ma	doc_685122975282_item	2817291	et	3	main
põhjus	doc_685122975282_item	2817294	et	4	main
miks	doc_685122975282_item	2817295	et	4	main
noored	doc_685122975282_item	2817296	et	3	main
lähevad	doc_685122975282_item	2817297	et	3	main
see	doc_685122975282_item	2817301	et	3	main
mitte	doc_685122975282_item	2817322	et	3	main
abituriendit	doc_685122975282_item	2817324	et	4	main
mõtlevat	doc_685122975282_item	2817325	et	4	main
haridussüsteemi	doc_685122975282_item	2817330	et	4	main
rohkem	doc_685122975282_item	2817345	et	4	main
aitama	doc_685122975282_item	2817346	et	3	main
noori	doc_685122975282_item	2817347	et	3	main
inimesi	doc_685122975282_item	2817348	et	4	main
ja	doc_685122975282_item	2817349	et	3	main
kes	doc_685122975282_item	2817352	et	4	main
õppima	doc_685122975282_item	2817355	et	3	main
ei	doc_685122975282_item	2817358	et	4	main
muuta	doc_685122975282_item	2817359	et	4	main
tiina	doc_685122975283_item	2817369	et	4	main
kaalep	doc_685122975283_item	2817370	et	4	main
linnas	doc_685122975283_item	2817380	et	4	main
kaheksa	doc_685122975283_item	2817383	et	4	main
aastat	doc_685122975283_item	2817384	et	3	main
loen	doc_685122975283_item	2817385	et	3	main
artikel	doc_685122975283_item	2817400	et	4	main
ja	doc_685122975283_item	2817401	et	3	main
endid	doc_685122975283_item	2817413	et	4	main
ülikooli	doc_685122975283_item	2817424	et	4	main
ja	doc_685122975283_item	2817426	et	3	main
on	doc_685122975283_item	2817427	et	4	main
üks	doc_685122975283_item	2817428	et	3	main
rühm	doc_685122975283_item	2817429	et	3	main
neist	doc_685122975283_item	2817430	et	4	main
neist	doc_685122975283_item	2817435	et	4	main
saab	doc_685122975283_item	2817436	et	3	main
vaid	doc_685122975283_item	2817437	et	3	main
mõni	doc_685122975283_item	2817438	et	3	main
nädal	doc_685122975283_item	2817439	et	3	main
aega	doc_685122975283_item	2817443	et	4	main
asi	doc_685122975283_item	2817454	et	4	main
tulevikuplaane	doc_685122975283_item	2817479	et	3	main
selle	doc_685122975283_item	2817484	et	4	main
lõpetuteks	doc_685122975283_item	2817504	et	4	main
tahan	doc_685122975283_item	2817505	et	3	main
paremas	doc_685122975281_item	2817160	et	4	main
kahjuks	doc_685122975281_item	2817162	et	4	main
tiina	doc_685122975282_item	2817176	et	4	main
teid	doc_685122975282_item	2817180	et	4	main
huvitav	doc_685122975282_item	2817187	et	4	main
andis	doc_685122975282_item	2817189	et	3	main
nõus	doc_685122975282_item	2817199	et	4	main
tööd	doc_685122975282_item	2817206	et	4	main
suurt	doc_685122975282_item	2817217	et	3	main
ühesõnaga	doc_685122975282_item	2817222	et	3	main
oma	doc_685122975282_item	2817232	et	4	main
ajal	doc_685122975282_item	2817243	et	4	main
et	doc_685122975282_item	2817246	et	3	main
kõrgkooli	doc_685122975282_item	2817248	et	4	main
saada	doc_685122975282_item	2817267	et	4	main
tänasel	doc_685122975282_item	2817278	et	3	main
ameti	doc_685122975282_item	2817280	et	3	main
sõltub	doc_685122975282_item	2817282	et	3	main
et	doc_685122975282_item	2817284	et	3	main
tulevikus	doc_685122975282_item	2817288	et	4	main
raha	doc_685122975282_item	2817290	et	4	main
et	doc_685122975282_item	2817293	et	3	main
ühiskonnast	doc_685122975282_item	2817326	et	4	main
ja	doc_685122975282_item	2817331	et	3	main
on	doc_685122975282_item	2817338	et	4	main
selline	doc_685122975282_item	2817339	et	4	main
et	doc_685122975282_item	2817340	et	3	main
riik	doc_685122975282_item	2817342	et	3	main
peamiselt	doc_685122975282_item	2817350	et	4	main
peal	doc_685122975282_item	2817362	et	4	main
eesnimi	doc_685122975282_item	2817364	et	3	main
perekonnanimi	doc_685122975282_item	2817365	et	3	main
kiri	doc_685122975283_item	2817367	et	3	main
teile	doc_685122975283_item	2817372	et	4	main
teie	doc_685122975283_item	2817373	et	4	main
ja	doc_685122975283_item	2817381	et	3	main
juba	doc_685122975283_item	2817382	et	3	main
hea	doc_685122975283_item	2817388	et	4	main
meelega	doc_685122975283_item	2817389	et	4	main
üldse	doc_685122975283_item	2817391	et	3	main
seoses	doc_685122975283_item	2817394	et	4	main
sellega	doc_685122975283_item	2817395	et	3	main
et	doc_685122975283_item	2817396	et	3	main
mina	doc_685122975283_item	2817397	et	4	main
lugesin	doc_685122975283_item	2817398	et	3	main
teie	doc_685122975283_item	2817406	et	4	main
arvamusega	doc_685122975283_item	2817407	et	3	main
et	doc_685122975283_item	2817408	et	3	main
õigupoolest	doc_685122975283_item	2817409	et	3	main
huvitas	doc_685122975283_item	2817410	et	3	main
see	doc_685122975283_item	2817411	et	3	main
teid	doc_685122975283_item	2817412	et	4	main
palka	doc_685122975283_item	2817419	et	4	main
saada	doc_685122975283_item	2817420	et	4	main
inimeste	doc_685122975282_item	2817194	et	3	main
teiega	doc_685122975282_item	2817198	et	3	main
osa	doc_685122975282_item	2817201	et	4	main
leida	doc_685122975282_item	2817204	et	3	main
rahulikkut	doc_685122975282_item	2817205	et	4	main
rahulikut	doc_685122975282_item	2817224	et	4	main
heaolu	doc_685122975282_item	2817233	et	4	main
noored	doc_685122975282_item	2817244	et	3	main
saaksid	doc_685122975282_item	2817251	et	4	main
tööd	doc_685122975282_item	2817253	et	4	main
oma	doc_685122975282_item	2817254	et	4	main
alas	doc_685122975282_item	2817255	et	3	main
ma	doc_685122975282_item	2817256	et	3	main
olen	doc_685122975282_item	2817257	et	3	main
sellega	doc_685122975282_item	2817258	et	3	main
täitsa	doc_685122975282_item	2817259	et	3	main
lihtsam	doc_685122975282_item	2817266	et	4	main
veel	doc_685122975282_item	2817269	et	4	main
abituriendil	doc_685122975282_item	2817273	et	3	main
valida	doc_685122975282_item	2817275	et	3	main
ametit	doc_685122975282_item	2817277	et	3	main
päeval	doc_685122975282_item	2817279	et	3	main
valik	doc_685122975282_item	2817281	et	3	main
sellest	doc_685122975282_item	2817283	et	4	main
töö	doc_685122975282_item	2817286	et	4	main
sulle	doc_685122975282_item	2817289	et	3	main
arvan	doc_685122975282_item	2817292	et	3	main
on	doc_685122975282_item	2817300	et	4	main
riigist	doc_685122975282_item	2817333	et	3	main
üldine	doc_685122975282_item	2817335	et	4	main
tulevikust	doc_685122975282_item	2817337	et	4	main
lähevad	doc_685122975282_item	2817353	et	3	main
siis	doc_685122975282_item	2817356	et	3	main
aastakäikude	doc_685122975282_item	2817361	et	3	main
lugupidamisega	doc_685122975282_item	2817363	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975282_item	2817366	et	4	main
sillamäe	doc_685122975283_item	2817379	et	3	main
teie	doc_685122975283_item	2817399	et	4	main
kes	doc_685122975283_item	2817431	et	4	main
on	doc_685122975283_item	2817440	et	4	main
ülikoolidesse	doc_685122975283_item	2817441	et	3	main
tulnud	doc_685122975283_item	2817455	et	4	main
arvestus	doc_685122975283_item	2817461	et	4	main
nende	doc_685122975283_item	2817463	et	4	main
üldse	doc_685122975283_item	2817465	et	3	main
neil	doc_685122975283_item	2817468	et	4	main
abiturientidel	doc_685122975283_item	2817469	et	3	main
pole	doc_685122975283_item	2817470	et	3	main
peale	doc_685122975283_item	2817471	et	4	main
sisetunde	doc_685122975283_item	2817472	et	4	main
kuidas	doc_685122975283_item	2817473	et	3	main
eksamid	doc_685122975283_item	2817474	et	3	main
rajada	doc_685122975283_item	2817480	et	3	main
tulevad	doc_685122975283_item	2817483	et	4	main
nädala	doc_685122975283_item	2817485	et	3	main
lõplikud	doc_685122975283_item	2817487	et	3	main
et	doc_685122975283_item	2817495	et	3	main
et	doc_685122975283_item	2817507	et	3	main
artikel	doc_685122975283_item	2817509	et	4	main
oli	doc_685122975283_item	2817510	et	3	main
väga	doc_685122975283_item	2817511	et	3	main
huvitav	doc_685122975283_item	2817512	et	4	main
minu	doc_685122975283_item	2817513	et	3	main
aga	doc_685122975283_item	2817531	et	3	main
mõni	doc_685122975283_item	2817535	et	3	main
mis	doc_685122975283_item	2817540	et	4	main
kiri	doc_685122975284_item	2817546	et	3	main
teie	doc_685122975284_item	2817551	et	4	main
et	doc_685122975284_item	2817558	et	3	main
ei	doc_685122975284_item	2817564	et	4	main
oleks	doc_685122975284_item	2817565	et	3	main
tähelepanu	doc_685122975284_item	2817572	et	4	main
pühendatud	doc_685122975284_item	2817574	et	4	main
millest	doc_685122975284_item	2817576	et	3	main
tekkib	doc_685122975284_item	2817577	et	3	main
apaatia	doc_685122975284_item	2817579	et	4	main
sooviksin	doc_685122975284_item	2817580	et	3	main
valgust	doc_685122975284_item	2817581	et	4	main
tänapäeva	doc_685122975284_item	2817588	et	4	main
on	doc_685122975284_item	2817622	et	4	main
asi	doc_685122975284_item	2817628	et	4	main
elu	doc_685122975282_item	2817225	et	4	main
eest	doc_685122975282_item	2817234	et	4	main
vanemate	doc_685122975282_item	2817242	et	4	main
pärast	doc_685122975282_item	2817247	et	4	main
naad	doc_685122975282_item	2817250	et	4	main
vanemate	doc_685122975282_item	2817263	et	4	main
ajal	doc_685122975282_item	2817264	et	4	main
oli	doc_685122975282_item	2817265	et	3	main
suur	doc_685122975282_item	2817271	et	3	main
toob	doc_685122975282_item	2817287	et	3	main
töökohtadele	doc_685122975282_item	2817299	et	3	main
et	doc_685122975282_item	2817302	et	3	main
nad	doc_685122975282_item	2817303	et	3	main
lihtsalt	doc_685122975282_item	2817304	et	4	main
vajavad	doc_685122975282_item	2817305	et	4	main
eluks	doc_685122975282_item	2817306	et	3	main
raha	doc_685122975282_item	2817307	et	4	main
rahasuhtes	doc_685122975282_item	2817308	et	3	main
ma	doc_685122975282_item	2817309	et	3	main
arvan	doc_685122975282_item	2817310	et	3	main
et	doc_685122975282_item	2817311	et	3	main
iga	doc_685122975282_item	2817312	et	4	main
abiturient	doc_685122975282_item	2817313	et	3	main
juba	doc_685122975282_item	2817314	et	3	main
tunneb	doc_685122975282_item	2817315	et	3	main
raha	doc_685122975282_item	2817317	et	4	main
on	doc_685122975282_item	2817318	et	4	main
palju	doc_685122975282_item	2817316	et	4	main
eluks	doc_685122975282_item	2817319	et	3	main
vaja	doc_685122975282_item	2817320	et	4	main
kahjuks	doc_685122975282_item	2817321	et	4	main
palju	doc_685122975282_item	2817323	et	4	main
üldse	doc_685122975282_item	2817332	et	3	main
ei	doc_685122975282_item	2817343	et	4	main
neid	doc_685122975282_item	2817351	et	4	main
isegi	doc_685122975282_item	2817360	et	4	main
lugeja	doc_685122975283_item	2817374	et	4	main
eesnimi	doc_685122975283_item	2817375	et	3	main
perekonnanimi	doc_685122975283_item	2817376	et	3	main
teie	doc_685122975283_item	2817386	et	4	main
kiri	doc_685122975283_item	2817393	et	3	main
täiesti	doc_685122975283_item	2817404	et	3	main
nõus	doc_685122975283_item	2817405	et	4	main
tänavu	doc_685122975283_item	2817423	et	3	main
lähevad	doc_685122975283_item	2817425	et	3	main
tea	doc_685122975283_item	2817433	et	4	main
astumiseni	doc_685122975283_item	2817442	et	4	main
tea	doc_685122975283_item	2817447	et	4	main
koos	doc_685122975283_item	2817456	et	4	main
riigieksamite	doc_685122975283_item	2817457	et	3	main
loteriiga	doc_685122975283_item	2817458	et	3	main
kuhu	doc_685122975283_item	2817462	et	3	main
minna	doc_685122975283_item	2817467	et	3	main
midagi	doc_685122975283_item	2817477	et	4	main
mille	doc_685122975283_item	2817478	et	3	main
teha	doc_685122975283_item	2817496	et	3	main
jaoks	doc_685122975283_item	2817514	et	4	main
ja	doc_685122975283_item	2817515	et	3	main
kõik	doc_685122975283_item	2817524	et	4	main
ainult	doc_685122975283_item	2817526	et	4	main
nendelt	doc_685122975283_item	2817527	et	4	main
kuidas	doc_685122975283_item	2817528	et	3	main
nad	doc_685122975283_item	2817529	et	3	main
pärast	doc_685122975283_item	2817532	et	4	main
sellest	doc_685122975282_item	2817327	et	4	main
kui	doc_685122975282_item	2817341	et	3	main
kuidas	doc_685122975282_item	2817328	et	3	main
muuta	doc_685122975282_item	2817329	et	4	main
minu	doc_685122975282_item	2817334	et	3	main
arvamus	doc_685122975282_item	2817336	et	3	main
hakka	doc_685122975282_item	2817344	et	4	main
kõrgkooli	doc_685122975282_item	2817354	et	4	main
midagi	doc_685122975282_item	2817357	et	4	main
lugupeetud	doc_685122975283_item	2817368	et	4	main
kirjutab	doc_685122975283_item	2817371	et	3	main
mina	doc_685122975283_item	2817377	et	4	main
elan	doc_685122975283_item	2817378	et	3	main
kirjandus	doc_685122975283_item	2817387	et	3	main
ja	doc_685122975283_item	2817390	et	3	main
minu	doc_685122975283_item	2817392	et	3	main
mina	doc_685122975283_item	2817402	et	4	main
olen	doc_685122975283_item	2817403	et	3	main
mida	doc_685122975283_item	2817414	et	4	main
tahavad	doc_685122975283_item	2817415	et	3	main
õppida	doc_685122975283_item	2817416	et	3	main
ja	doc_685122975283_item	2817417	et	3	main
palju	doc_685122975283_item	2817418	et	4	main
kes	doc_685122975283_item	2817422	et	4	main
ei	doc_685122975283_item	2817432	et	4	main
aga	doc_685122975283_item	2817444	et	3	main
kaine	doc_685122975283_item	2817460	et	4	main
punktidega	doc_685122975283_item	2817464	et	3	main
saab	doc_685122975283_item	2817466	et	3	main
tegelikult	doc_685122975283_item	2817476	et	4	main
tulemused	doc_685122975283_item	2817482	et	3	main
otsus	doc_685122975283_item	2817497	et	3	main
saadab	doc_685122975283_item	2817499	et	3	main
neid	doc_685122975283_item	2817500	et	4	main
kogu	doc_685122975283_item	2817501	et	4	main
öelda	doc_685122975283_item	2817506	et	4	main
mina	doc_685122975283_item	2817517	et	4	main
olen	doc_685122975283_item	2817518	et	3	main
arvamusega	doc_685122975283_item	2817522	et	3	main
sõltub	doc_685122975283_item	2817525	et	3	main
saadab	doc_685122975283_item	2817541	et	3	main
kogu	doc_685122975283_item	2817543	et	4	main
austatud	doc_685122975284_item	2817547	et	4	main
kaalep	doc_685122975284_item	2817549	et	4	main
noorsugude	doc_685122975284_item	2817553	et	3	main
kuigi	doc_685122975284_item	2817559	et	3	main
see	doc_685122975284_item	2817563	et	3	main
abituriendid	doc_685122975283_item	2817421	et	3	main
mis	doc_685122975283_item	2817434	et	4	main
nad	doc_685122975283_item	2817445	et	3	main
ei	doc_685122975283_item	2817446	et	4	main
isegi	doc_685122975283_item	2817448	et	4	main
umbkaudu	doc_685122975283_item	2817449	et	3	main
mitte	doc_685122975283_item	2817450	et	3	main
see	doc_685122975283_item	2817451	et	3	main
on	doc_685122975283_item	2817452	et	4	main
uus	doc_685122975283_item	2817453	et	3	main
see	doc_685122975283_item	2817459	et	3	main
läksid	doc_685122975283_item	2817475	et	4	main
esimesed	doc_685122975283_item	2817481	et	3	main
lõpuks	doc_685122975283_item	2817486	et	4	main
19	doc_685122975283_item	2817488	et	2	main
juuniks	doc_685122975283_item	2817489	et	3	main
siis	doc_685122975283_item	2817490	et	3	main
jääb	doc_685122975283_item	2817491	et	3	main
vaid	doc_685122975283_item	2817492	et	3	main
mõni	doc_685122975283_item	2817493	et	3	main
päev	doc_685122975283_item	2817494	et	3	main
mis	doc_685122975283_item	2817498	et	4	main
elu	doc_685122975283_item	2817502	et	4	main
ja	doc_685122975283_item	2817503	et	3	main
muigugi	doc_685122975283_item	2817516	et	4	main
õppivad	doc_685122975283_item	2817530	et	4	main
päev	doc_685122975283_item	2817536	et	3	main
teha	doc_685122975283_item	2817538	et	3	main
neid	doc_685122975283_item	2817542	et	4	main
tänapäeva	doc_685122975284_item	2817552	et	4	main
õigu	doc_685122975284_item	2817570	et	4	main
on	doc_685122975284_item	2817573	et	4	main
olukorrale	doc_685122975284_item	2817575	et	3	main
olukorra	doc_685122975284_item	2817589	et	3	main
algpõhjus	doc_685122975284_item	2817590	et	4	main
ajaloolises	doc_685122975284_item	2817592	et	4	main
taustas	doc_685122975284_item	2817593	et	3	main
praegu	doc_685122975284_item	2817594	et	3	main
see	doc_685122975284_item	2817595	et	3	main
ongi	doc_685122975284_item	2817596	et	4	main
stabilne	doc_685122975284_item	2817598	et	4	main
tunde	doc_685122975284_item	2817625	et	4	main
selles	doc_685122975284_item	2817630	et	4	main
veab	doc_685122975284_item	2817649	et	3	main
selle	doc_685122975284_item	2817656	et	4	main
vaja	doc_685122975284_item	2817660	et	4	main
meie	doc_685122975284_item	2817664	et	4	main
tööd	doc_685122975284_item	2817686	et	4	main
erinevatest	doc_685122975284_item	2817694	et	4	main
eeskuju	doc_685122975284_item	2817699	et	4	main
ei	doc_685122975284_item	2817712	et	4	main
aita	doc_685122975284_item	2817713	et	4	main
alla	doc_685122975284_item	2817716	et	3	main
kui	doc_685122975284_item	2817719	et	3	main
protsess	doc_685122975284_item	2817726	et	3	main
tähendab	doc_685122975284_item	2817728	et	3	main
isegi	doc_685122975284_item	2817730	et	4	main
ülesanne	doc_685122975284_item	2817740	et	4	main
mille	doc_685122975284_item	2817741	et	3	main
meeldiv	doc_685122975284_item	2817745	et	4	main
ma	doc_685122975284_item	2817750	et	3	main
selgelt	doc_685122975284_item	2817758	et	4	main
õiglasem	doc_685122975284_item	2817760	et	4	main
uuringu	doc_685122975284_item	2817763	et	3	main
tee	doc_685122975285_item	2817783	et	4	main
koolis	doc_685122975285_item	2817785	et	4	main
tuleb	doc_685122975285_item	2817787	et	3	main
otsustada	doc_685122975285_item	2817788	et	3	main
õppima	doc_685122975285_item	2817796	et	3	main
või	doc_685122975285_item	2817798	et	4	main
tööle	doc_685122975285_item	2817800	et	3	main
minna	doc_685122975285_item	2817801	et	3	main
näiteks	doc_685122975285_item	2817812	et	4	main
kui	doc_685122975285_item	2817816	et	3	main
teie	doc_685122975283_item	2817508	et	4	main
täiesti	doc_685122975283_item	2817519	et	3	main
nõus	doc_685122975283_item	2817520	et	4	main
teie	doc_685122975283_item	2817521	et	4	main
et	doc_685122975283_item	2817523	et	3	main
jääb	doc_685122975283_item	2817533	et	3	main
vaid	doc_685122975283_item	2817534	et	3	main
et	doc_685122975283_item	2817537	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975283_item	2817545	et	4	main
retseinsiooniga	doc_685122975284_item	2817554	et	4	main
ja	doc_685122975284_item	2817556	et	3	main
kriitiline	doc_685122975284_item	2817560	et	3	main
halastamatu	doc_685122975284_item	2817562	et	4	main
vähe	doc_685122975284_item	2817571	et	3	main
heita	doc_685122975284_item	2817582	et	3	main
situatsioonile	doc_685122975284_item	2817583	et	3	main
noorte	doc_685122975284_item	2817584	et	3	main
põlvkonna	doc_685122975284_item	2817585	et	4	main
liigi	doc_685122975284_item	2817586	et	4	main
ja	doc_685122975284_item	2817599	et	3	main
noortel	doc_685122975284_item	2817600	et	3	main
on	doc_685122975284_item	2817601	et	4	main
kõik	doc_685122975284_item	2817602	et	4	main
alused	doc_685122975284_item	2817603	et	4	main
lootmiseks	doc_685122975284_item	2817604	et	4	main
et	doc_685122975284_item	2817605	et	3	main
see	doc_685122975284_item	2817606	et	3	main
niisuguseks	doc_685122975284_item	2817607	et	4	main
jääb	doc_685122975284_item	2817608	et	3	main
või	doc_685122975284_item	2817609	et	4	main
vähemalt	doc_685122975284_item	2817610	et	4	main
see	doc_685122975284_item	2817611	et	3	main
on	doc_685122975284_item	2817612	et	4	main
fakt	doc_685122975284_item	2817613	et	3	main
milline	doc_685122975284_item	2817614	et	3	main
ebapealetükkivalt	doc_685122975284_item	2817615	et	4	main
meid	doc_685122975284_item	2817616	et	4	main
uskuma	doc_685122975284_item	2817617	et	3	main
pannakse	doc_685122975284_item	2817618	et	3	main
kõik	doc_685122975284_item	2817619	et	4	main
rigi	doc_685122975284_item	2817620	et	4	main
kasvatuse	doc_685122975284_item	2817626	et	4	main
et	doc_685122975284_item	2817631	et	3	main
ei	doc_685122975284_item	2817632	et	4	main
mida	doc_685122975284_item	2817636	et	4	main
meid	doc_685122975284_item	2817638	et	4	main
naa	doc_685122975284_item	2817647	et	3	main
või	doc_685122975284_item	2817672	et	4	main
eluetabil	doc_685122975284_item	2817674	et	4	main
teada	doc_685122975284_item	2817677	et	3	main
on	doc_685122975284_item	2817682	et	4	main
ebaproportsioonalselt	doc_685122975284_item	2817684	et	4	main
rohkem	doc_685122975284_item	2817685	et	4	main
on	doc_685122975284_item	2817691	et	4	main
ka	doc_685122975284_item	2817692	et	3	main
tingimustest	doc_685122975284_item	2817696	et	3	main
nn	doc_685122975284_item	2817706	et	4	main
vastu	doc_685122975284_item	2817717	et	3	main
õpilased	doc_685122975284_item	2817721	et	3	main
tunne	doc_685122975284_item	2817723	et	4	main
sooritamise	doc_685122975284_item	2817742	et	4	main
oma	doc_685122975284_item	2817752	et	4	main
otsus	doc_685122975283_item	2817539	et	3	main
elu	doc_685122975283_item	2817544	et	4	main
tiina	doc_685122975284_item	2817548	et	4	main
olen	doc_685122975284_item	2817550	et	3	main
tutvunud	doc_685122975284_item	2817555	et	4	main
tunnistan	doc_685122975284_item	2817557	et	3	main
ja	doc_685122975284_item	2817561	et	3	main
ongi	doc_685122975284_item	2817566	et	4	main
te	doc_685122975284_item	2817567	et	4	main
kirjeldaksite	doc_685122975284_item	2817568	et	3	main
vaid	doc_685122975284_item	2817569	et	3	main
käesolev	doc_685122975284_item	2817578	et	3	main
silmanurgast	doc_685122975284_item	2817587	et	4	main
seiseneb	doc_685122975284_item	2817591	et	4	main
püsiv	doc_685122975284_item	2817597	et	4	main
jõud	doc_685122975284_item	2817621	et	4	main
suunatud	doc_685122975284_item	2817623	et	4	main
turvalise	doc_685122975284_item	2817624	et	4	main
on	doc_685122975284_item	2817629	et	4	main
palka	doc_685122975284_item	2817635	et	4	main
või	doc_685122975284_item	2817646	et	4	main
normalselt	doc_685122975284_item	2817650	et	3	main
elu	doc_685122975284_item	2817652	et	4	main
üleliigis	doc_685122975284_item	2817662	et	3	main
eesmärgid	doc_685122975284_item	2817665	et	3	main
madalamaad	doc_685122975284_item	2817669	et	4	main
sest	doc_685122975284_item	2817670	et	4	main
ühel	doc_685122975284_item	2817671	et	3	main
teisel	doc_685122975284_item	2817673	et	4	main
kõrgema	doc_685122975284_item	2817679	et	4	main
eesmärgi	doc_685122975284_item	2817680	et	4	main
vaja	doc_685122975284_item	2817683	et	4	main
süüstem	doc_685122975284_item	2817690	et	4	main
ajaloo	doc_685122975284_item	2817695	et	4	main
kajad	doc_685122975284_item	2817703	et	4	main
millest	doc_685122975284_item	2817704	et	3	main
demokraatia	doc_685122975284_item	2817708	et	4	main
peale	doc_685122975284_item	2817627	et	4	main
ole	doc_685122975284_item	2817633	et	4	main
niisugust	doc_685122975284_item	2817634	et	3	main
suunitakste	doc_685122975284_item	2817637	et	4	main
julgelt	doc_685122975284_item	2817639	et	4	main
tegutsema	doc_685122975284_item	2817640	et	3	main
meies	doc_685122975284_item	2817641	et	4	main
valitseb	doc_685122975284_item	2817642	et	3	main
usk	doc_685122975284_item	2817643	et	3	main
et	doc_685122975284_item	2817644	et	3	main
nii	doc_685122975284_item	2817645	et	3	main
meile	doc_685122975284_item	2817648	et	4	main
seda	doc_685122975284_item	2817651	et	3	main
lõpuni	doc_685122975284_item	2817653	et	3	main
ja	doc_685122975284_item	2817655	et	3	main
soovi	doc_685122975284_item	2817657	et	4	main
täitmiseks	doc_685122975284_item	2817658	et	4	main
pole	doc_685122975284_item	2817659	et	3	main
elada	doc_685122975284_item	2817654	et	3	main
pingutusi	doc_685122975284_item	2817663	et	4	main
tihti	doc_685122975284_item	2817666	et	3	main
suhtiliselt	doc_685122975284_item	2817668	et	4	main
et	doc_685122975284_item	2817678	et	3	main
meie	doc_685122975284_item	2817687	et	4	main
kummaline	doc_685122975284_item	2817688	et	3	main
väärtuse	doc_685122975284_item	2817689	et	3	main
kapitalistlike	doc_685122975284_item	2817698	et	3	main
sotsialiismi	doc_685122975284_item	2817702	et	4	main
kujuneb	doc_685122975284_item	2817705	et	3	main
apaatiline	doc_685122975284_item	2817707	et	4	main
haridusesüsteemi	doc_685122975284_item	2817710	et	4	main
kahjuks	doc_685122975284_item	2817711	et	4	main
kaasa	doc_685122975284_item	2817714	et	4	main
õppimise	doc_685122975284_item	2817725	et	4	main
raske	doc_685122975284_item	2817727	et	4	main
et	doc_685122975284_item	2817729	et	3	main
lapsepõlvest	doc_685122975284_item	2817731	et	4	main
on	doc_685122975284_item	2817732	et	4	main
töösse	doc_685122975284_item	2817733	et	3	main
ainult	doc_685122975284_item	2817739	et	4	main
pärast	doc_685122975284_item	2817743	et	4	main
tuleb	doc_685122975284_item	2817744	et	3	main
elu	doc_685122975284_item	2817747	et	4	main
väljendasin	doc_685122975284_item	2817751	et	3	main
haridus	doc_685122975285_item	2817782	et	3	main
tahad	doc_685122975285_item	2817794	et	3	main
minna	doc_685122975285_item	2817799	et	3	main
kohe	doc_685122975285_item	2817803	et	4	main
peale	doc_685122975285_item	2817804	et	4	main
kooli	doc_685122975285_item	2817805	et	4	main
kui	doc_685122975285_item	2817810	et	3	main
elu	doc_685122975285_item	2817811	et	4	main
tahab	doc_685122975285_item	2817822	et	3	main
kui	doc_685122975285_item	2817838	et	3	main
peale	doc_685122975285_item	2817853	et	4	main
ülikooli	doc_685122975285_item	2817854	et	4	main
tulevikus	doc_685122975285_item	2817870	et	4	main
10	doc_685122975285_item	2817884	et	2	main
aga	doc_685122975285_item	2817887	et	3	main
neljakünneaastased	doc_685122975285_item	2817901	et	4	main
hooli	doc_685122975285_item	2817914	et	4	main
alast	doc_685122975285_item	2817915	et	4	main
vaid	doc_685122975285_item	2817916	et	3	main
oleks	doc_685122975285_item	2817920	et	3	main
ja	doc_685122975285_item	2817924	et	3	main
palk	doc_685122975285_item	2817926	et	3	main
olen	doc_685122975285_item	2817930	et	3	main
sellel	doc_685122975285_item	2817938	et	4	main
teemal	doc_685122975285_item	2817939	et	3	main
väga	doc_685122975285_item	2817941	et	3	main
sarnased	doc_685122975285_item	2817942	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975285_item	2817943	et	4	main
kiri	doc_685122975286_item	2817944	et	3	main
teiega	doc_685122975286_item	2817959	et	3	main
praegune	doc_685122975286_item	2817990	et	3	main
on	doc_685122975286_item	2817992	et	4	main
väga	doc_685122975286_item	2817993	et	3	main
ambitsioosne	doc_685122975286_item	2817994	et	3	main
maja	doc_685122975286_item	2818004	et	4	main
sellepärast	doc_685122975286_item	2818016	et	3	main
on	doc_685122975286_item	2818019	et	4	main
defitsiit	doc_685122975286_item	2818020	et	3	main
on	doc_685122975286_item	2818027	et	4	main
teie	doc_685122975286_item	2818033	et	4	main
maldamatu	doc_685122975286_item	2818035	et	4	main
teie	doc_685122975286_item	2818037	et	4	main
lugeja	doc_685122975286_item	2818038	et	4	main
eesnimi	doc_685122975286_item	2818039	et	3	main
perekonnanimi	doc_685122975286_item	2818040	et	3	main
23102005	doc_685122975286_item	2818041	et	2	main
kaalep	doc_685122975287_item	2818046	et	4	main
minu	doc_685122975287_item	2818047	et	3	main
perekonnanimi	doc_685122975287_item	2818051	et	3	main
on	doc_685122975287_item	2818053	et	4	main
artikklit	doc_685122975287_item	2818070	et	4	main
mis	doc_685122975287_item	2818071	et	4	main
nimetatakse	doc_685122975287_item	2818072	et	3	main
vähenõudlike	doc_685122975287_item	2818073	et	3	main
minge	doc_685122975284_item	2817661	et	3	main
on	doc_685122975284_item	2817667	et	4	main
me	doc_685122975284_item	2817675	et	4	main
saame	doc_685122975284_item	2817676	et	4	main
saavutamiseks	doc_685122975284_item	2817681	et	4	main
parit	doc_685122975284_item	2817693	et	4	main
tänane	doc_685122975284_item	2817697	et	3	main
prevaleerimine	doc_685122975284_item	2817700	et	4	main
katab	doc_685122975284_item	2817701	et	3	main
tegutsev	doc_685122975284_item	2817709	et	4	main
huvi	doc_685122975284_item	2817715	et	4	main
kujunemiseks	doc_685122975284_item	2817718	et	4	main
ka	doc_685122975284_item	2817720	et	3	main
huvi	doc_685122975284_item	2817724	et	4	main
suhtumine	doc_685122975284_item	2817736	et	4	main
see	doc_685122975284_item	2817737	et	3	main
on	doc_685122975284_item	2817738	et	4	main
aeg	doc_685122975284_item	2817746	et	3	main
et	doc_685122975284_item	2817749	et	3	main
järgmise	doc_685122975284_item	2817762	et	3	main
juhul	doc_685122975284_item	2817764	et	3	main
kas	doc_685122975285_item	2817793	et	3	main
teed	doc_685122975285_item	2817806	et	4	main
inimene	doc_685122975285_item	2817817	et	3	main
ülikooli	doc_685122975285_item	2817819	et	4	main
teadumiste	doc_685122975285_item	2817824	et	4	main
ja	doc_685122975285_item	2817826	et	3	main
oma	doc_685122975285_item	2817827	et	4	main
kollegidega	doc_685122975285_item	2817848	et	4	main
minu	doc_685122975285_item	2817849	et	3	main
arvates	doc_685122975285_item	2817850	et	4	main
et	doc_685122975285_item	2817851	et	3	main
praegu	doc_685122975285_item	2817852	et	3	main
on	doc_685122975285_item	2817859	et	4	main
üsna	doc_685122975285_item	2817860	et	3	main
väike	doc_685122975285_item	2817861	et	4	main
töötasu	doc_685122975285_item	2817862	et	4	main
praegu	doc_685122975285_item	2817863	et	3	main
niisugust	doc_685122975285_item	2817864	et	3	main
palka	doc_685122975285_item	2817865	et	4	main
võib	doc_685122975285_item	2817866	et	3	main
teenida	doc_685122975285_item	2817867	et	3	main
osta	doc_685122975285_item	2817874	et	4	main
kõik	doc_685122975285_item	2817879	et	4	main
000	doc_685122975285_item	2817885	et	2	main
palju	doc_685122975285_item	2817888	et	4	main
on	doc_685122975285_item	2817889	et	4	main
tea	doc_685122975285_item	2817893	et	4	main
nägu	doc_685122975285_item	2817900	et	4	main
koht	doc_685122975285_item	2817921	et	3	main
tegelikult	doc_685122975285_item	2817928	et	4	main
mõtted	doc_685122975285_item	2817937	et	3	main
tiina	doc_685122975286_item	2817946	et	4	main
artikel	doc_685122975286_item	2817952	et	4	main
vähenõudlike	doc_685122975286_item	2817953	et	3	main
põlvkond	doc_685122975286_item	2817954	et	3	main
ma	doc_685122975286_item	2817955	et	3	main
olen	doc_685122975286_item	2817956	et	3	main
vähenõudlik	doc_685122975286_item	2817964	et	3	main
ja	doc_685122975286_item	2817965	et	3	main
kõik	doc_685122975286_item	2817999	et	4	main
auto	doc_685122975286_item	2818006	et	4	main
ja	doc_685122975286_item	2818007	et	3	main
hulgast	doc_685122975286_item	2818011	et	4	main
soovi	doc_685122975286_item	2818013	et	4	main
oskutöölisega	doc_685122975286_item	2818021	et	4	main
ja	doc_685122975286_item	2818030	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975286_item	2818042	et	4	main
tiina	doc_685122975287_item	2818045	et	4	main
mul	doc_685122975287_item	2818052	et	3	main
et	doc_685122975287_item	2818066	et	3	main
hiljuti	doc_685122975287_item	2818068	et	4	main
selle	doc_685122975287_item	2818080	et	4	main
kohta	doc_685122975287_item	2818081	et	4	main
teie	doc_685122975287_item	2818084	et	4	main
normaalset	doc_685122975287_item	2818100	et	3	main
suurt	doc_685122975287_item	2818103	et	3	main
ei	doc_685122975284_item	2817722	et	4	main
formeeritud	doc_685122975284_item	2817734	et	4	main
negatiivne	doc_685122975284_item	2817735	et	3	main
loodan	doc_685122975284_item	2817748	et	3	main
positsiooni	doc_685122975284_item	2817753	et	4	main
oleks	doc_685122975284_item	2817759	et	3	main
kui	doc_685122975284_item	2817761	et	3	main
probleemi	doc_685122975284_item	2817765	et	4	main
kääsitlakse	doc_685122975284_item	2817766	et	4	main
objektiivsemalt	doc_685122975284_item	2817767	et	4	main
ja	doc_685122975284_item	2817768	et	3	main
mitmekülgsemalt	doc_685122975284_item	2817769	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975284_item	2817770	et	4	main
kiri	doc_685122975285_item	2817771	et	3	main
olen	doc_685122975285_item	2817772	et	3	main
paljude	doc_685122975285_item	2817773	et	3	main
asjadega	doc_685122975285_item	2817774	et	3	main
nõus	doc_685122975285_item	2817775	et	4	main
kuigi	doc_685122975285_item	2817776	et	3	main
mõned	doc_685122975285_item	2817777	et	3	main
arutaksin	doc_685122975285_item	2817778	et	3	main
oma	doc_685122975285_item	2817779	et	4	main
moodi	doc_685122975285_item	2817780	et	4	main
inimene	doc_685122975285_item	2817781	et	3	main
piisavalt	doc_685122975284_item	2817754	et	4	main
kergesti	doc_685122975284_item	2817755	et	3	main
arusaadavalt	doc_685122975284_item	2817756	et	4	main
ja	doc_685122975284_item	2817757	et	3	main
algab	doc_685122975285_item	2817784	et	3	main
seal	doc_685122975285_item	2817786	et	4	main
kelleks	doc_685122975285_item	2817789	et	4	main
sa	doc_685122975285_item	2817790	et	3	main
tahad	doc_685122975285_item	2817791	et	3	main
minna	doc_685122975285_item	2817797	et	3	main
hetkeks	doc_685122975285_item	2817808	et	4	main
lihtsamaks	doc_685122975285_item	2817809	et	4	main
ülikooli	doc_685122975285_item	2817813	et	4	main
õppilasel	doc_685122975285_item	2817814	et	4	main
aga	doc_685122975285_item	2817815	et	3	main
harituse	doc_685122975285_item	2817828	et	4	main
saada	doc_685122975285_item	2817830	et	4	main
tööle	doc_685122975285_item	2817837	et	3	main
sa	doc_685122975285_item	2817839	et	3	main
hea	doc_685122975285_item	2817841	et	4	main
sa	doc_685122975285_item	2817843	et	3	main
haruduseta	doc_685122975285_item	2817869	et	4	main
vajab	doc_685122975285_item	2817880	et	3	main
kui	doc_685122975285_item	2817883	et	3	main
eek	doc_685122975285_item	2817886	et	4	main
neid	doc_685122975285_item	2817890	et	4	main
neist	doc_685122975285_item	2817895	et	4	main
saab	doc_685122975285_item	2817896	et	3	main
noored	doc_685122975285_item	2817897	et	3	main
tahavad	doc_685122975285_item	2817898	et	3	main
elada	doc_685122975285_item	2817899	et	3	main
taha	doc_685122975285_item	2817909	et	4	main
selleks	doc_685122975285_item	2817910	et	4	main
õppida	doc_685122975285_item	2817911	et	3	main
ainult	doc_685122975285_item	2817917	et	4	main
et	doc_685122975285_item	2817919	et	3	main
käia	doc_685122975285_item	2817923	et	4	main
olen	doc_685122975286_item	2817949	et	3	main
lugenud	doc_685122975286_item	2817950	et	4	main
teie	doc_685122975286_item	2817951	et	4	main
ma	doc_685122975286_item	2817966	et	3	main
et	doc_685122975286_item	2817968	et	3	main
ei	doc_685122975286_item	2817996	et	4	main
taha	doc_685122975286_item	2817997	et	4	main
õppida	doc_685122975286_item	2817998	et	3	main
kallis	doc_685122975286_item	2818005	et	4	main
keegi	doc_685122975286_item	2818009	et	4	main
et	doc_685122975286_item	2818017	et	3	main
saada	doc_685122975285_item	2817792	et	4	main
edasi	doc_685122975285_item	2817795	et	3	main
tööle	doc_685122975285_item	2817802	et	3	main
elu	doc_685122975285_item	2817807	et	4	main
lõpetab	doc_685122975285_item	2817818	et	3	main
muidugi	doc_685122975285_item	2817820	et	4	main
ta	doc_685122975285_item	2817821	et	4	main
oma	doc_685122975285_item	2817823	et	4	main
oskuste	doc_685122975285_item	2817825	et	3	main
hästi	doc_685122975285_item	2817831	et	3	main
tasustatud	doc_685122975285_item	2817832	et	4	main
see	doc_685122975285_item	2817834	et	3	main
et	doc_685122975285_item	2817835	et	3	main
tulles	doc_685122975285_item	2817836	et	4	main
said	doc_685122975285_item	2817840	et	4	main
töökohta	doc_685122975285_item	2817842	et	4	main
pead	doc_685122975285_item	2817844	et	4	main
lugupidamisega	doc_685122975285_item	2817845	et	3	main
suhtuma	doc_685122975285_item	2817846	et	3	main
uute	doc_685122975285_item	2817847	et	3	main
lõpetamist	doc_685122975285_item	2817855	et	4	main
10	doc_685122975285_item	2817856	et	2	main
000	doc_685122975285_item	2817857	et	2	main
ma	doc_685122975285_item	2817871	et	3	main
tahan	doc_685122975285_item	2817872	et	3	main
endale	doc_685122975285_item	2817873	et	4	main
see	doc_685122975285_item	2817878	et	3	main
palka	doc_685122975285_item	2817882	et	4	main
kes	doc_685122975285_item	2817891	et	4	main
tahavad	doc_685122975285_item	2817902	et	3	main
kõik	doc_685122975285_item	2817903	et	4	main
kohe	doc_685122975285_item	2817905	et	4	main
nad	doc_685122975285_item	2817912	et	3	main
sellest	doc_685122975285_item	2817918	et	4	main
eest	doc_685122975285_item	2817829	et	4	main
tööd	doc_685122975285_item	2817833	et	4	main
eek	doc_685122975285_item	2817858	et	4	main
ilma	doc_685122975285_item	2817868	et	4	main
maja	doc_685122975285_item	2817875	et	4	main
korralik	doc_685122975285_item	2817876	et	3	main
auto	doc_685122975285_item	2817877	et	4	main
suuremat	doc_685122975285_item	2817881	et	4	main
ei	doc_685122975285_item	2817892	et	4	main
mis	doc_685122975285_item	2817894	et	4	main
asjad	doc_685122975285_item	2817904	et	3	main
saada	doc_685122975285_item	2817906	et	4	main
ja	doc_685122975285_item	2817907	et	3	main
ei	doc_685122975285_item	2817908	et	4	main
ei	doc_685122975285_item	2817913	et	4	main
kus	doc_685122975285_item	2817922	et	3	main
nõus	doc_685122975285_item	2817934	et	4	main
ja	doc_685122975285_item	2817935	et	3	main
minu	doc_685122975285_item	2817936	et	3	main
lp	doc_685122975286_item	2817945	et	4	main
osaliselt	doc_685122975286_item	2817957	et	4	main
nõus	doc_685122975286_item	2817958	et	4	main
meie	doc_685122975286_item	2817960	et	4	main
tänapäevane	doc_685122975286_item	2817961	et	4	main
põlvkond	doc_685122975286_item	2817962	et	3	main
mõtle	doc_685122975286_item	2817988	et	4	main
tulevikust	doc_685122975286_item	2817989	et	4	main
tahavad	doc_685122975286_item	2818000	et	3	main
suur	doc_685122975286_item	2818001	et	3	main
palka	doc_685122975286_item	2818002	et	4	main
mitte	doc_685122975286_item	2818008	et	3	main
ja	doc_685122975286_item	2818022	et	3	main
profitsiit	doc_685122975286_item	2818023	et	4	main
juhajaga	doc_685122975286_item	2818024	et	4	main
teie	doc_685122975286_item	2818025	et	4	main
väga	doc_685122975286_item	2818028	et	3	main
artikli	doc_685122975286_item	2818034	et	3	main
kiri	doc_685122975287_item	2818043	et	3	main
on	doc_685122975287_item	2818049	et	4	main
sellepärast	doc_685122975287_item	2818065	et	3	main
lugesin	doc_685122975287_item	2818067	et	3	main
teie	doc_685122975287_item	2818069	et	4	main
rabelemata	doc_685122975287_item	2818098	et	4	main
ja	doc_685122975287_item	2818102	et	3	main
võitlust	doc_685122975287_item	2818104	et	3	main
ellu	doc_685122975287_item	2818106	et	4	main
olla	doc_685122975287_item	2818119	et	3	main
tea	doc_685122975287_item	2818126	et	4	main
neist	doc_685122975287_item	2818138	et	4	main
saab	doc_685122975287_item	2818139	et	3	main
ja	doc_685122975287_item	2818140	et	3	main
see	doc_685122975287_item	2818141	et	3	main
inimesed	doc_685122975287_item	2818149	et	3	main
kuhu	doc_685122975287_item	2818151	et	3	main
saavad	doc_685122975287_item	2818153	et	4	main
õpivad	doc_685122975287_item	2818155	et	3	main
algul	doc_685122975287_item	2818164	et	4	main
ei	doc_685122975287_item	2818165	et	4	main
olen	doc_685122975287_item	2818174	et	3	main
kindel	doc_685122975287_item	2818175	et	3	main
on	doc_685122975287_item	2818178	et	4	main
elu	doc_685122975287_item	2818202	et	4	main
ülikoolis	doc_685122975288_item	2818228	et	4	main
esimesel	doc_685122975288_item	2818229	et	3	main
kursusel	doc_685122975288_item	2818230	et	3	main
huvitav	doc_685122975288_item	2818250	et	4	main
ja	doc_685122975288_item	2818251	et	3	main
tahan	doc_685122975288_item	2818252	et	3	main
kes	doc_685122975288_item	2818276	et	4	main
palgast	doc_685122975288_item	2818279	et	4	main
autost	doc_685122975288_item	2818280	et	3	main
18	doc_685122975288_item	2818285	et	2	main
minu	doc_685122975288_item	2818301	et	3	main
ei	doc_685122975288_item	2818305	et	4	main
teine	doc_685122975288_item	2818313	et	3	main
on	doc_685122975288_item	2818316	et	4	main
kes	doc_685122975288_item	2818318	et	4	main
kooli	doc_685122975288_item	2818325	et	4	main
nad	doc_685122975288_item	2818327	et	3	main
õlikooli	doc_685122975288_item	2818337	et	4	main
nad	doc_685122975288_item	2818338	et	3	main
ei	doc_685122975288_item	2818339	et	4	main
saada	doc_685122975288_item	2818353	et	4	main
mingi	doc_685122975285_item	2817925	et	4	main
saada	doc_685122975285_item	2817927	et	4	main
ma	doc_685122975285_item	2817929	et	3	main
tiina	doc_685122975285_item	2817931	et	4	main
kaalepi	doc_685122975285_item	2817932	et	4	main
artikliga	doc_685122975285_item	2817933	et	3	main
on	doc_685122975285_item	2817940	et	4	main
kaalep	doc_685122975286_item	2817947	et	4	main
ma	doc_685122975286_item	2817948	et	3	main
on	doc_685122975286_item	2817963	et	4	main
arvan	doc_685122975286_item	2817967	et	3	main
see	doc_685122975286_item	2817969	et	3	main
on	doc_685122975286_item	2817970	et	4	main
praegune	doc_685122975286_item	2817971	et	3	main
probleem	doc_685122975286_item	2817972	et	3	main
palju	doc_685122975286_item	2817973	et	4	main
inimesi	doc_685122975286_item	2817974	et	4	main
ei	doc_685122975286_item	2817975	et	4	main
tea	doc_685122975286_item	2817976	et	4	main
keelega	doc_685122975286_item	2817977	et	3	main
nad	doc_685122975286_item	2817978	et	3	main
tahavad	doc_685122975286_item	2817979	et	3	main
saada	doc_685122975286_item	2817980	et	4	main
või	doc_685122975286_item	2817981	et	4	main
töötada	doc_685122975286_item	2817982	et	3	main
nad	doc_685122975286_item	2817983	et	3	main
lihtsalt	doc_685122975286_item	2817984	et	4	main
elavad	doc_685122975286_item	2817985	et	4	main
ja	doc_685122975286_item	2817986	et	3	main
ei	doc_685122975286_item	2817987	et	4	main
noored	doc_685122975286_item	2817991	et	3	main
aga	doc_685122975286_item	2817995	et	3	main
ilus	doc_685122975286_item	2818003	et	4	main
nende	doc_685122975286_item	2818010	et	4	main
ei	doc_685122975286_item	2818012	et	4	main
töötada	doc_685122975286_item	2818014	et	3	main
töölisena	doc_685122975286_item	2818015	et	3	main
nüüd	doc_685122975286_item	2818018	et	4	main
artikel	doc_685122975286_item	2818026	et	4	main
huvitav	doc_685122975286_item	2818031	et	4	main
ootan	doc_685122975286_item	2818032	et	3	main
eesnimi	doc_685122975287_item	2818050	et	3	main
teile	doc_685122975287_item	2818064	et	4	main
oma	doc_685122975287_item	2818077	et	4	main
mulle	doc_685122975287_item	2818082	et	4	main
te	doc_685122975287_item	2818086	et	4	main
kirjutasite	doc_685122975287_item	2818087	et	3	main
et	doc_685122975287_item	2818088	et	3	main
tänapäeval	doc_685122975287_item	2818089	et	3	main
meie	doc_685122975287_item	2818090	et	4	main
noor	doc_685122975287_item	2818091	et	3	main
põlvkond	doc_685122975287_item	2818092	et	3	main
tahab	doc_685122975287_item	2818093	et	3	main
elada	doc_685122975287_item	2818094	et	3	main
ja	doc_685122975287_item	2818095	et	3	main
töötada	doc_685122975287_item	2818096	et	3	main
rahulikult	doc_685122975287_item	2818097	et	4	main
palka	doc_685122975287_item	2818101	et	4	main
oma	doc_685122975287_item	2818105	et	4	main
ei	doc_685122975287_item	2818107	et	4	main
taheta	doc_685122975287_item	2818108	et	3	main
ja	doc_685122975287_item	2818109	et	3	main
see	doc_685122975287_item	2818110	et	3	main
on	doc_685122975287_item	2818111	et	4	main
nii	doc_685122975287_item	2818112	et	3	main
aeg	doc_685122975287_item	2818113	et	3	main
muutub	doc_685122975287_item	2818114	et	3	main
ja	doc_685122975287_item	2818115	et	3	main
muutub	doc_685122975287_item	2818116	et	3	main
põlvkond	doc_685122975287_item	2818117	et	3	main
võib	doc_685122975287_item	2818118	et	3	main
te	doc_685122975287_item	2818132	et	4	main
on	doc_685122975287_item	2818142	et	4	main
ka	doc_685122975287_item	2818143	et	3	main
suur	doc_685122975287_item	2818144	et	3	main
probleem	doc_685122975287_item	2818145	et	3	main
sellepärast	doc_685122975287_item	2818146	et	3	main
sisse	doc_685122975287_item	2818152	et	4	main
see	doc_685122975287_item	2818157	et	3	main
nüüd	doc_685122975287_item	2818172	et	4	main
öelda	doc_685122975287_item	2818185	et	4	main
et	doc_685122975287_item	2818186	et	3	main
on	doc_685122975287_item	2818187	et	4	main
aga	doc_685122975287_item	2818188	et	3	main
sihikindlad	doc_685122975287_item	2818189	et	3	main
ma	doc_685122975287_item	2818204	et	3	main
19	doc_685122975288_item	2818221	et	2	main
üliõpelane	doc_685122975288_item	2818223	et	4	main
tallinna	doc_685122975288_item	2818226	et	4	main
tehnika	doc_685122975288_item	2818227	et	4	main
lugenud	doc_685122975288_item	2818232	et	4	main
teie	doc_685122975288_item	2818235	et	4	main
ja	doc_685122975288_item	2818237	et	3	main
väga	doc_685122975288_item	2818242	et	3	main
oluline	doc_685122975288_item	2818243	et	4	main
probleem	doc_685122975288_item	2818244	et	3	main
täna	doc_685122975288_item	2818245	et	4	main
öelda	doc_685122975288_item	2818253	et	4	main
esimene	doc_685122975288_item	2818271	et	3	main
suurest	doc_685122975288_item	2818278	et	4	main
väike	doc_685122975288_item	2818282	et	4	main
aastased	doc_685122975288_item	2818286	et	4	main
põnnid	doc_685122975288_item	2818288	et	3	main
kui	doc_685122975288_item	2818289	et	3	main
poed	doc_685122975288_item	2818290	et	4	main
tühjad	doc_685122975288_item	2818291	et	3	main
ja	doc_685122975288_item	2818292	et	3	main
ole	doc_685122975288_item	2818306	et	4	main
õige	doc_685122975288_item	2818307	et	4	main
suur	doc_685122975288_item	2818314	et	3	main
tea	doc_685122975288_item	2818320	et	4	main
aktuaalne	doc_685122975286_item	2818029	et	3	main
lugupidamisega	doc_685122975286_item	2818036	et	3	main
lp	doc_685122975287_item	2818044	et	4	main
nimi	doc_685122975287_item	2818048	et	3	main
üheksateist	doc_685122975287_item	2818054	et	4	main
aastat	doc_685122975287_item	2818055	et	3	main
vana	doc_685122975287_item	2818056	et	4	main
ja	doc_685122975287_item	2818057	et	3	main
ma	doc_685122975287_item	2818058	et	3	main
õpin	doc_685122975287_item	2818059	et	3	main
tallinna	doc_685122975287_item	2818060	et	4	main
tehnikaülikoolis	doc_685122975287_item	2818061	et	4	main
majandusteaduskonnas	doc_685122975287_item	2818062	et	4	main
kirjutan	doc_685122975287_item	2818063	et	3	main
põlvkond	doc_685122975287_item	2818074	et	3	main
ja	doc_685122975287_item	2818075	et	3	main
tahan	doc_685122975287_item	2818076	et	3	main
raskusi	doc_685122975287_item	2818122	et	4	main
või	doc_685122975287_item	2818123	et	4	main
nad	doc_685122975287_item	2818124	et	3	main
tulevikus	doc_685122975287_item	2818130	et	4	main
tea	doc_685122975287_item	2818136	et	4	main
mis	doc_685122975287_item	2818137	et	4	main
sellised	doc_685122975287_item	2818148	et	4	main
lähevad	doc_685122975287_item	2818150	et	3	main
kasu	doc_685122975287_item	2818158	et	4	main
ei	doc_685122975287_item	2818159	et	4	main
teadnud	doc_685122975287_item	2818166	et	4	main
kelleks	doc_685122975287_item	2818167	et	4	main
ma	doc_685122975287_item	2818168	et	3	main
tahan	doc_685122975287_item	2818169	et	3	main
kõik	doc_685122975287_item	2818179	et	4	main
korras	doc_685122975287_item	2818180	et	4	main
taotlevad	doc_685122975287_item	2818192	et	4	main
kogu	doc_685122975287_item	2818200	et	4	main
sellega	doc_685122975287_item	2818203	et	3	main
õpin	doc_685122975288_item	2818225	et	3	main
eesti	doc_685122975288_item	2818233	et	4	main
päevalehest	doc_685122975288_item	2818234	et	4	main
artiikel	doc_685122975288_item	2818236	et	4	main
meelest	doc_685122975288_item	2818239	et	4	main
on	doc_685122975288_item	2818241	et	4	main
päeval	doc_685122975288_item	2818246	et	3	main
artiikel	doc_685122975288_item	2818247	et	4	main
oli	doc_685122975288_item	2818248	et	3	main
mis	doc_685122975288_item	2818254	et	4	main
suur	doc_685122975288_item	2818272	et	3	main
on	doc_685122975288_item	2818274	et	4	main
neid	doc_685122975288_item	2818275	et	4	main
tänased	doc_685122975288_item	2818284	et	3	main
olid	doc_685122975288_item	2818287	et	4	main
kodud	doc_685122975288_item	2818293	et	3	main
vaesed	doc_685122975288_item	2818294	et	4	main
noored	doc_685122975288_item	2818295	et	3	main
tahavad	doc_685122975288_item	2818296	et	3	main
arvates	doc_685122975288_item	2818302	et	4	main
on	doc_685122975288_item	2818304	et	4	main
nagu	doc_685122975288_item	2818311	et	3	main
pärast	doc_685122975288_item	2818324	et	4	main
hooli	doc_685122975288_item	2818340	et	4	main
ainult	doc_685122975288_item	2818343	et	4	main
et	doc_685122975288_item	2818345	et	3	main
käia	doc_685122975288_item	2818349	et	4	main
ja	doc_685122975288_item	2818350	et	3	main
mingi	doc_685122975288_item	2818351	et	4	main
palk	doc_685122975288_item	2818352	et	3	main
toimub	doc_685122975288_item	2818356	et	3	main
tööga	doc_685122975288_item	2818362	et	3	main
see	doc_685122975288_item	2818364	et	3	main
on	doc_685122975288_item	2818365	et	4	main
väga	doc_685122975288_item	2818366	et	3	main
halb	doc_685122975288_item	2818367	et	3	main
ja	doc_685122975288_item	2818374	et	3	main
on	doc_685122975288_item	2818378	et	4	main
meie	doc_685122975288_item	2818389	et	4	main
mugavam	doc_685122975288_item	2818393	et	4	main
see	doc_685122975288_item	2818394	et	3	main
lugesin	doc_685122975289_item	2818421	et	3	main
kaalep	doc_685122975289_item	2818428	et	4	main
praegu	doc_685122975289_item	2818429	et	3	main
kirjutan	doc_685122975289_item	2818430	et	3	main
arvamusega	doc_685122975289_item	2818442	et	3	main
et	doc_685122975289_item	2818443	et	3	main
saada	doc_685122975289_item	2818463	et	4	main
see	doc_685122975289_item	2818464	et	3	main
inimene	doc_685122975289_item	2818465	et	3	main
tahab	doc_685122975289_item	2818466	et	3	main
oma	doc_685122975289_item	2818469	et	4	main
auto	doc_685122975289_item	2818472	et	4	main
omada	doc_685122975289_item	2818473	et	3	main
soovivad	doc_685122975289_item	2818476	et	4	main
veeta	doc_685122975289_item	2818479	et	4	main
nende	doc_685122975289_item	2818481	et	4	main
ja	doc_685122975289_item	2818489	et	3	main
oma	doc_685122975289_item	2818494	et	4	main
sellega	doc_685122975289_item	2818500	et	3	main
seisukohta	doc_685122975287_item	2818078	et	4	main
avaldada	doc_685122975287_item	2818079	et	3	main
meeldis	doc_685122975287_item	2818083	et	3	main
artikkel	doc_685122975287_item	2818085	et	3	main
saada	doc_685122975287_item	2818099	et	4	main
noored	doc_685122975287_item	2818120	et	3	main
kardavad	doc_685122975287_item	2818121	et	4	main
ei	doc_685122975287_item	2818125	et	4	main
kuidas	doc_685122975287_item	2818131	et	3	main
paljud	doc_685122975287_item	2818134	et	3	main
ja	doc_685122975287_item	2818154	et	3	main
aga	doc_685122975287_item	2818156	et	3	main
too	doc_685122975287_item	2818160	et	4	main
mina	doc_685122975287_item	2818161	et	4	main
ma	doc_685122975287_item	2818173	et	3	main
et	doc_685122975287_item	2818176	et	3	main
mul	doc_685122975287_item	2818177	et	3	main
lõpuks	doc_685122975287_item	2818182	et	4	main
ma	doc_685122975287_item	2818183	et	3	main
tahan	doc_685122975287_item	2818184	et	3	main
kes	doc_685122975287_item	2818191	et	4	main
tahavad	doc_685122975287_item	2818198	et	3	main
oma	doc_685122975287_item	2818201	et	4	main
kõike	doc_685122975287_item	2818206	et	4	main
minu	doc_685122975288_item	2818238	et	3	main
vaga	doc_685122975288_item	2818249	et	4	main
see	doc_685122975288_item	2818255	et	3	main
unistavad	doc_685122975288_item	2818277	et	4	main
ja	doc_685122975288_item	2818281	et	3	main
kõik	doc_685122975288_item	2818297	et	4	main
ja	doc_685122975288_item	2818298	et	3	main
see	doc_685122975288_item	2818303	et	3	main
kahekümneaastased	doc_685122975288_item	2818308	et	4	main
tahavad	doc_685122975288_item	2818309	et	3	main
elada	doc_685122975288_item	2818310	et	3	main
neid	doc_685122975288_item	2818317	et	4	main
ei	doc_685122975288_item	2818319	et	4	main
neist	doc_685122975288_item	2818322	et	4	main
ei	doc_685122975288_item	2818328	et	4	main
mujal	doc_685122975288_item	2818357	et	3	main
tänavatel	doc_685122975288_item	2818359	et	4	main
igatahes	doc_685122975288_item	2818360	et	3	main
mitte	doc_685122975288_item	2818361	et	3	main
sotsiaaltöötaja	doc_685122975288_item	2818382	et	4	main
parem	doc_685122975288_item	2818391	et	4	main
on	doc_685122975288_item	2818395	et	4	main
aga	doc_685122975288_item	2818399	et	3	main
häirivad	doc_685122975288_item	2818402	et	4	main
mis	doc_685122975287_item	2818127	et	4	main
ootab	doc_685122975287_item	2818128	et	3	main
neid	doc_685122975287_item	2818129	et	4	main
kirjutasite	doc_685122975287_item	2818133	et	3	main
ei	doc_685122975287_item	2818135	et	4	main
et	doc_685122975287_item	2818147	et	3	main
näiteks	doc_685122975287_item	2818162	et	4	main
ka	doc_685122975287_item	2818163	et	3	main
saada	doc_685122975287_item	2818170	et	4	main
aga	doc_685122975287_item	2818171	et	3	main
tulevikus	doc_685122975287_item	2818181	et	4	main
inimesed	doc_685122975287_item	2818190	et	3	main
edu	doc_685122975287_item	2818193	et	4	main
ja	doc_685122975287_item	2818194	et	3	main
teavad	doc_685122975287_item	2818195	et	3	main
mis	doc_685122975287_item	2818196	et	4	main
nad	doc_685122975287_item	2818197	et	3	main
teha	doc_685122975287_item	2818199	et	3	main
lõpetan	doc_685122975287_item	2818205	et	3	main
head	doc_685122975287_item	2818207	et	4	main
teile	doc_685122975287_item	2818208	et	4	main
eesnimi	doc_685122975287_item	2818209	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975287_item	2818210	et	4	main
kiri	doc_685122975288_item	2818211	et	3	main
lp	doc_685122975288_item	2818212	et	4	main
tiina	doc_685122975288_item	2818213	et	4	main
kaalep	doc_685122975288_item	2818214	et	4	main
minu	doc_685122975288_item	2818215	et	3	main
nimi	doc_685122975288_item	2818216	et	3	main
on	doc_685122975288_item	2818217	et	4	main
eesnimi	doc_685122975288_item	2818218	et	3	main
ma	doc_685122975288_item	2818219	et	3	main
olen	doc_685122975288_item	2818220	et	3	main
aastane	doc_685122975288_item	2818222	et	4	main
ma	doc_685122975288_item	2818224	et	3	main
olen	doc_685122975288_item	2818231	et	3	main
see	doc_685122975288_item	2818240	et	3	main
probleem	doc_685122975288_item	2818256	et	3	main
tähendab	doc_685122975288_item	2818257	et	3	main
minu	doc_685122975288_item	2818258	et	3	main
jaoks	doc_685122975288_item	2818259	et	4	main
ma	doc_685122975288_item	2818260	et	3	main
olen	doc_685122975288_item	2818261	et	3	main
nõus	doc_685122975288_item	2818262	et	4	main
sellega	doc_685122975288_item	2818263	et	3	main
et	doc_685122975288_item	2818264	et	3	main
meie	doc_685122975288_item	2818265	et	4	main
ühiskond	doc_685122975288_item	2818266	et	3	main
on	doc_685122975288_item	2818267	et	4	main
kolm	doc_685122975288_item	2818268	et	3	main
suur	doc_685122975288_item	2818269	et	3	main
rühma	doc_685122975288_item	2818270	et	4	main
rühm	doc_685122975288_item	2818273	et	3	main
kodust	doc_685122975288_item	2818283	et	4	main
samal	doc_685122975288_item	2818299	et	3	main
ajal	doc_685122975288_item	2818300	et	4	main
neljakümnesed	doc_685122975288_item	2818312	et	3	main
rühm	doc_685122975288_item	2818315	et	3	main
mis	doc_685122975288_item	2818321	et	4	main
alast	doc_685122975288_item	2818341	et	4	main
oleks	doc_685122975288_item	2818346	et	3	main
kus	doc_685122975288_item	2818348	et	3	main
elu	doc_685122975288_item	2818355	et	4	main
tänapäeva	doc_685122975288_item	2818369	et	4	main
noorpõlvkond	doc_685122975288_item	2818370	et	3	main
nii	doc_685122975288_item	2818371	et	3	main
sama	doc_685122975288_item	2818372	et	4	main
arvestatav	doc_685122975288_item	2818376	et	4	main
õige	doc_685122975288_item	2818396	et	4	main
inimesed	doc_685122975288_item	2818401	et	3	main
vahenõudlike	doc_685122975289_item	2818422	et	3	main
tiina	doc_685122975289_item	2818440	et	4	main
erilisemaid	doc_685122975289_item	2818448	et	4	main
julgemat	doc_685122975289_item	2818451	et	4	main
mõned	doc_685122975289_item	2818474	et	3	main
iseseisva	doc_685122975289_item	2818477	et	3	main
elu	doc_685122975289_item	2818478	et	4	main
nagu	doc_685122975289_item	2818480	et	3	main
inimesed	doc_685122975289_item	2818485	et	3	main
soovi	doc_685122975289_item	2818493	et	4	main
sisse	doc_685122975289_item	2818507	et	4	main
sellepärast	doc_685122975289_item	2818510	et	3	main
oma	doc_685122975289_item	2818520	et	4	main
saab	doc_685122975288_item	2818323	et	3	main
lõpetada	doc_685122975288_item	2818326	et	3	main
tea	doc_685122975288_item	2818329	et	4	main
kuhu	doc_685122975288_item	2818330	et	3	main
edasi	doc_685122975288_item	2818331	et	3	main
õppida	doc_685122975288_item	2818332	et	3	main
aga	doc_685122975288_item	2818333	et	3	main
kui	doc_685122975288_item	2818334	et	3	main
nad	doc_685122975288_item	2818335	et	3	main
lõpetada	doc_685122975288_item	2818336	et	3	main
vaid	doc_685122975288_item	2818342	et	3	main
sellest	doc_685122975288_item	2818344	et	4	main
koht	doc_685122975288_item	2818347	et	3	main
sest	doc_685122975288_item	2818368	et	4	main
täitsa	doc_685122975288_item	2818375	et	3	main
rühm	doc_685122975288_item	2818377	et	3	main
neid	doc_685122975288_item	2818379	et	4	main
kes	doc_685122975288_item	2818380	et	4	main
räägivad	doc_685122975288_item	2818381	et	3	main
tahavad	doc_685122975288_item	2818387	et	3	main
ja	doc_685122975288_item	2818392	et	3	main
seda	doc_685122975288_item	2818403	et	3	main
teha	doc_685122975288_item	2818404	et	3	main
minu	doc_685122975288_item	2818405	et	3	main
arvates	doc_685122975288_item	2818406	et	4	main
meie	doc_685122975288_item	2818407	et	4	main
põlvkond	doc_685122975288_item	2818408	et	3	main
peab	doc_685122975288_item	2818409	et	4	main
ühineda	doc_685122975288_item	2818410	et	3	main
ja	doc_685122975288_item	2818411	et	3	main
siis	doc_685122975288_item	2818412	et	3	main
kõik	doc_685122975288_item	2818413	et	4	main
on	doc_685122975288_item	2818414	et	4	main
hea	doc_685122975288_item	2818415	et	4	main
tulevikus	doc_685122975288_item	2818416	et	4	main
eesnimi	doc_685122975288_item	2818417	et	3	main
perekonnanimi	doc_685122975288_item	2818418	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975288_item	2818419	et	4	main
kiri	doc_685122975289_item	2818420	et	3	main
põlvkond	doc_685122975289_item	2818423	et	3	main
mis	doc_685122975289_item	2818425	et	4	main
kirjutas	doc_685122975289_item	2818426	et	3	main
arvamust	doc_685122975289_item	2818432	et	3	main
teema	doc_685122975289_item	2818434	et	4	main
me	doc_685122975289_item	2818444	et	4	main
ootame	doc_685122975289_item	2818445	et	3	main
unistusi	doc_685122975289_item	2818449	et	4	main
mõtet	doc_685122975289_item	2818452	et	3	main
et	doc_685122975289_item	2818453	et	3	main
jõukalt	doc_685122975289_item	2818467	et	4	main
kodu	doc_685122975289_item	2818470	et	4	main
ja	doc_685122975289_item	2818471	et	3	main
elada	doc_685122975289_item	2818483	et	3	main
hea	doc_685122975289_item	2818487	et	4	main
tea	doc_685122975289_item	2818505	et	4	main
nende	doc_685122975289_item	2818513	et	4	main
ei	doc_685122975289_item	2818526	et	4	main
läheb	doc_685122975289_item	2818530	et	3	main
ainult	doc_685122975289_item	2818543	et	4	main
inimesel	doc_685122975289_item	2818549	et	3	main
huvi	doc_685122975289_item	2818551	et	4	main
ta	doc_685122975289_item	2818555	et	4	main
palkaga	doc_685122975289_item	2818565	et	4	main
tea	doc_685122975290_item	2818602	et	4	main
palk	doc_685122975290_item	2818604	et	3	main
tegelikult	doc_685122975288_item	2818354	et	4	main
kodus	doc_685122975288_item	2818358	et	4	main
seoses	doc_685122975288_item	2818363	et	4	main
kolmas	doc_685122975288_item	2818373	et	3	main
ning	doc_685122975288_item	2818383	et	3	main
keskkonnakaitsja	doc_685122975288_item	2818384	et	4	main
ametist	doc_685122975288_item	2818385	et	3	main
nad	doc_685122975288_item	2818386	et	3	main
teha	doc_685122975288_item	2818388	et	3	main
elu	doc_685122975288_item	2818390	et	4	main
meie	doc_685122975288_item	2818397	et	4	main
põlvkonnast	doc_685122975288_item	2818398	et	4	main
mõned	doc_685122975288_item	2818400	et	3	main
artikli	doc_685122975289_item	2818424	et	3	main
tiina	doc_685122975289_item	2818427	et	4	main
selle	doc_685122975289_item	2818433	et	4	main
kaalepi	doc_685122975289_item	2818441	et	4	main
elada	doc_685122975289_item	2818468	et	3	main
vanemad	doc_685122975289_item	2818482	et	4	main
harjusid	doc_685122975289_item	2818486	et	4	main
eluga	doc_685122975289_item	2818488	et	3	main
harjumustest	doc_685122975289_item	2818495	et	4	main
kuhu	doc_685122975289_item	2818506	et	3	main
ja	doc_685122975289_item	2818509	et	3	main
kuhu	doc_685122975289_item	2818512	et	3	main
punktidega	doc_685122975289_item	2818514	et	3	main
seda	doc_685122975289_item	2818529	et	3	main
töötades	doc_685122975289_item	2818533	et	3	main
teine	doc_685122975289_item	2818535	et	3	main
minu	doc_685122975289_item	2818537	et	3	main
peab	doc_685122975289_item	2818540	et	4	main
ikka	doc_685122975289_item	2818541	et	4	main
õppima	doc_685122975289_item	2818542	et	3	main
kui	doc_685122975289_item	2818548	et	3	main
on	doc_685122975289_item	2818550	et	4	main
seda	doc_685122975289_item	2818552	et	3	main
hea	doc_685122975289_item	2818557	et	4	main
siis	doc_685122975289_item	2818559	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975289_item	2818566	et	4	main
kiri	doc_685122975290_item	2818567	et	3	main
on	doc_685122975290_item	2818608	et	4	main
paha	doc_685122975290_item	2818609	et	4	main
ka	doc_685122975290_item	2818610	et	3	main
aga	doc_685122975290_item	2818611	et	3	main
mul	doc_685122975290_item	2818612	et	3	main
aega	doc_685122975290_item	2818617	et	4	main
ja	doc_685122975290_item	2818618	et	3	main
ma	doc_685122975290_item	2818619	et	3	main
oma	doc_685122975290_item	2818621	et	4	main
minuga	doc_685122975290_item	2818628	et	3	main
jaa	doc_685122975290_item	2818629	et	3	main
mul	doc_685122975290_item	2818630	et	3	main
hea	doc_685122975290_item	2818636	et	4	main
palga	doc_685122975290_item	2818637	et	3	main
aga	doc_685122975290_item	2818638	et	3	main
oma	doc_685122975290_item	2818663	et	4	main
ja	doc_685122975290_item	2818666	et	3	main
teie	doc_685122975290_item	2818668	et	4	main
kes	doc_685122975290_item	2818670	et	4	main
üldse	doc_685122975290_item	2818672	et	3	main
eriala	doc_685122975290_item	2818705	et	4	main
täna	doc_685122975290_item	2818716	et	4	main
väha	doc_685122975290_item	2818719	et	4	main
hea	doc_685122975290_item	2818720	et	4	main
oma	doc_685122975289_item	2818431	et	4	main
järgi	doc_685122975289_item	2818435	et	4	main
ma	doc_685122975289_item	2818436	et	3	main
olen	doc_685122975289_item	2818437	et	3	main
täiesti	doc_685122975289_item	2818438	et	3	main
nõus	doc_685122975289_item	2818439	et	4	main
jõulisemat	doc_685122975289_item	2818446	et	4	main
tulemist	doc_685122975289_item	2818447	et	4	main
ning	doc_685122975289_item	2818450	et	3	main
tänapäeva	doc_685122975289_item	2818454	et	4	main
inimene	doc_685122975289_item	2818455	et	3	main
tahab	doc_685122975289_item	2818456	et	3	main
rahulikult	doc_685122975289_item	2818457	et	4	main
töötada	doc_685122975289_item	2818458	et	3	main
ja	doc_685122975289_item	2818459	et	3	main
täiesti	doc_685122975289_item	2818460	et	3	main
normaalset	doc_685122975289_item	2818461	et	3	main
palka	doc_685122975289_item	2818462	et	4	main
noored	doc_685122975289_item	2818475	et	3	main
need	doc_685122975289_item	2818484	et	3	main
nendel	doc_685122975289_item	2818490	et	4	main
ei	doc_685122975289_item	2818491	et	4	main
ole	doc_685122975289_item	2818492	et	4	main
keelduma	doc_685122975289_item	2818496	et	3	main
olen	doc_685122975289_item	2818497	et	3	main
ka	doc_685122975289_item	2818498	et	3	main
nõus	doc_685122975289_item	2818499	et	4	main
ei	doc_685122975289_item	2818504	et	4	main
lähevad	doc_685122975289_item	2818511	et	3	main
sisse	doc_685122975289_item	2818516	et	4	main
astuvad	doc_685122975289_item	2818517	et	4	main
nad	doc_685122975289_item	2818518	et	3	main
raiskavad	doc_685122975289_item	2818519	et	4	main
õppides	doc_685122975289_item	2818522	et	4	main
tööle	doc_685122975289_item	2818531	et	3	main
arvates	doc_685122975289_item	2818538	et	4	main
haridust	doc_685122975289_item	2818553	et	4	main
saada	doc_685122975289_item	2818554	et	4	main
spetsialistina	doc_685122975289_item	2818558	et	3	main
alati	doc_685122975289_item	2818561	et	4	main
kallis	doc_685122975290_item	2818569	et	4	main
tiina	doc_685122975290_item	2818570	et	4	main
ei	doc_685122975290_item	2818598	et	4	main
meeldis	doc_685122975290_item	2818599	et	3	main
ma	doc_685122975290_item	2818600	et	3	main
ei	doc_685122975290_item	2818601	et	4	main
et	doc_685122975289_item	2818501	et	3	main
paljud	doc_685122975289_item	2818502	et	3	main
abituriendid	doc_685122975289_item	2818503	et	3	main
astuda	doc_685122975289_item	2818508	et	3	main
nad	doc_685122975289_item	2818515	et	3	main
aega	doc_685122975289_item	2818521	et	4	main
selles	doc_685122975289_item	2818523	et	4	main
kohas	doc_685122975289_item	2818524	et	4	main
kus	doc_685122975289_item	2818525	et	3	main
pärast	doc_685122975289_item	2818528	et	4	main
saab	doc_685122975289_item	2818534	et	3	main
haridust	doc_685122975289_item	2818536	et	4	main
seal	doc_685122975289_item	2818544	et	4	main
kus	doc_685122975289_item	2818545	et	3	main
ta	doc_685122975289_item	2818546	et	4	main
hea	doc_685122975289_item	2818562	et	4	main
töökoha	doc_685122975289_item	2818563	et	4	main
normaalse	doc_685122975289_item	2818564	et	3	main
minu	doc_685122975290_item	2818624	et	3	main
boss	doc_685122975290_item	2818625	et	3	main
saavad	doc_685122975290_item	2818635	et	4	main
ei	doc_685122975290_item	2818645	et	4	main
või	doc_685122975290_item	2818648	et	4	main
tulevikuks	doc_685122975290_item	2818650	et	4	main
oma	doc_685122975290_item	2818653	et	4	main
perekond	doc_685122975290_item	2818654	et	3	main
siis	doc_685122975290_item	2818657	et	3	main
meeldiks	doc_685122975290_item	2818708	et	3	main
kõrgharidus	doc_685122975290_item	2818717	et	3	main
mängib	doc_685122975290_item	2818718	et	3	main
palju	doc_685122975290_item	2818728	et	4	main
inimesed	doc_685122975290_item	2818729	et	3	main
soovidega	doc_685122975290_item	2818741	et	3	main
maardus	doc_685122975291_item	2818766	et	4	main
ja	doc_685122975291_item	2818767	et	3	main
teie	doc_685122975291_item	2818774	et	4	main
ja	doc_685122975291_item	2818777	et	3	main
palju	doc_685122975291_item	2818787	et	4	main
ei	doc_685122975291_item	2818789	et	4	main
kooli	doc_685122975291_item	2818796	et	4	main
mida	doc_685122975291_item	2818804	et	4	main
nad	doc_685122975291_item	2818821	et	3	main
püüvad	doc_685122975291_item	2818827	et	4	main
on	doc_685122975291_item	2818831	et	4	main
väga	doc_685122975291_item	2818832	et	3	main
ttü-sse	doc_685122975291_item	2818838	et	3	main
klassis	doc_685122975291_item	2818841	et	3	main
küsimus	doc_685122975291_item	2818854	et	4	main
raha	doc_685122975291_item	2818858	et	4	main
on	doc_685122975291_item	2818866	et	4	main
ja	doc_685122975291_item	2818892	et	3	main
ja	doc_685122975291_item	2818897	et	3	main
aru	doc_685122975291_item	2818899	et	4	main
sa	doc_685122975291_item	2818901	et	3	main
vaja	doc_685122975291_item	2818916	et	4	main
kõik	doc_685122975291_item	2818926	et	4	main
inimesed	doc_685122975291_item	2818927	et	3	main
aastast	doc_685122975291_item	2818936	et	4	main
töötada	doc_685122975291_item	2818937	et	3	main
see	doc_685122975291_item	2818938	et	3	main
peavad	doc_685122975291_item	2818943	et	4	main
jõudma	doc_685122975291_item	2818949	et	3	main
kõike	doc_685122975291_item	2818965	et	4	main
tallinna	doc_685122975292_item	2818977	et	4	main
vähenõudlike	doc_685122975292_item	2818988	et	3	main
nüüd	doc_685122975292_item	2818998	et	4	main
tahan	doc_685122975292_item	2818999	et	3	main
arvamust	doc_685122975292_item	2819005	et	3	main
ja	doc_685122975292_item	2819011	et	3	main
saanud	doc_685122975292_item	2819027	et	4	main
ma	doc_685122975292_item	2819028	et	3	main
löövad	doc_685122975292_item	2819036	et	4	main
ukse	doc_685122975292_item	2819037	et	3	main
jalaga	doc_685122975292_item	2819038	et	3	main
kohta	doc_685122975292_item	2819061	et	4	main
aga	doc_685122975292_item	2819062	et	3	main
minu	doc_685122975292_item	2819063	et	3	main
mõttes	doc_685122975292_item	2819064	et	3	main
see	doc_685122975292_item	2819065	et	3	main
ei	doc_685122975292_item	2819070	et	4	main
neist	doc_685122975292_item	2819082	et	4	main
sõbrad	doc_685122975292_item	2819092	et	3	main
taha	doc_685122975289_item	2818527	et	4	main
ning	doc_685122975289_item	2818532	et	3	main
inimene	doc_685122975289_item	2818539	et	3	main
tahab	doc_685122975289_item	2818547	et	3	main
saab	doc_685122975289_item	2818556	et	3	main
leiab	doc_685122975289_item	2818560	et	3	main
tere	doc_685122975290_item	2818568	et	3	main
ma	doc_685122975290_item	2818571	et	3	main
olin	doc_685122975290_item	2818572	et	3	main
lugesin	doc_685122975290_item	2818573	et	3	main
teil	doc_685122975290_item	2818574	et	4	main
artiklis	doc_685122975290_item	2818575	et	3	main
see	doc_685122975290_item	2818576	et	3	main
oli	doc_685122975290_item	2818577	et	3	main
väga	doc_685122975290_item	2818578	et	3	main
huvitav	doc_685122975290_item	2818579	et	4	main
ma	doc_685122975290_item	2818580	et	3	main
olen	doc_685122975290_item	2818581	et	3	main
paljude	doc_685122975290_item	2818582	et	3	main
nõus	doc_685122975290_item	2818583	et	4	main
mul	doc_685122975290_item	2818584	et	3	main
on	doc_685122975290_item	2818585	et	4	main
palju	doc_685122975290_item	2818586	et	4	main
sõpra	doc_685122975290_item	2818587	et	4	main
ja	doc_685122975290_item	2818588	et	3	main
tuttavaid	doc_685122975290_item	2818589	et	3	main
ja	doc_685122975290_item	2818590	et	3	main
nad	doc_685122975290_item	2818591	et	3	main
töötavad	doc_685122975290_item	2818592	et	4	main
erinevad	doc_685122975290_item	2818593	et	4	main
firmad	doc_685122975290_item	2818594	et	3	main
kes	doc_685122975290_item	2818595	et	4	main
meeldis	doc_685122975290_item	2818596	et	3	main
kes	doc_685122975290_item	2818597	et	4	main
aga	doc_685122975290_item	2818603	et	3	main
ei	doc_685122975290_item	2818613	et	4	main
koostasin	doc_685122975290_item	2818620	et	3	main
tunniplaan	doc_685122975290_item	2818622	et	3	main
ja	doc_685122975290_item	2818623	et	3	main
on	doc_685122975290_item	2818626	et	4	main
nõus	doc_685122975290_item	2818627	et	4	main
on	doc_685122975290_item	2818631	et	4	main
nad	doc_685122975290_item	2818639	et	3	main
töötavad	doc_685122975290_item	2818640	et	4	main
õpitanud	doc_685122975290_item	2818646	et	3	main
kõrgkooli	doc_685122975290_item	2818649	et	4	main
kuid	doc_685122975290_item	2818651	et	4	main
tuleb	doc_685122975290_item	2818652	et	3	main
last	doc_685122975290_item	2818656	et	4	main
olema	doc_685122975290_item	2818659	et	4	main
aega	doc_685122975290_item	2818664	et	4	main
võtta	doc_685122975290_item	2818704	et	3	main
ja	doc_685122975290_item	2818709	et	3	main
pärast	doc_685122975290_item	2818710	et	4	main
hea	doc_685122975290_item	2818712	et	4	main
firmi	doc_685122975290_item	2818713	et	4	main
heast	doc_685122975290_item	2818714	et	3	main
tähtsam	doc_685122975290_item	2818721	et	4	main
ja	doc_685122975290_item	2818725	et	3	main
palgast	doc_685122975290_item	2818726	et	4	main
tahavad	doc_685122975290_item	2818730	et	3	main
ja	doc_685122975290_item	2818732	et	3	main
parimate	doc_685122975290_item	2818740	et	4	main
1311	doc_685122975290_item	2818746	et	2	main
kiri	doc_685122975291_item	2818748	et	3	main
lugesin	doc_685122975291_item	2818773	et	3	main
väga	doc_685122975291_item	2818779	et	3	main
kõik	doc_685122975291_item	2818781	et	4	main
õige	doc_685122975291_item	2818786	et	4	main
sellest	doc_685122975291_item	2818809	et	4	main
kooli	doc_685122975291_item	2818810	et	4	main
lähevad	doc_685122975291_item	2818815	et	3	main
ja	doc_685122975291_item	2818826	et	3	main
jõua	doc_685122975291_item	2818828	et	4	main
seda	doc_685122975291_item	2818829	et	3	main
see	doc_685122975291_item	2818830	et	3	main
minna	doc_685122975291_item	2818837	et	3	main
ttü-s	doc_685122975291_item	2818846	et	3	main
kõik	doc_685122975291_item	2818862	et	4	main
millised	doc_685122975291_item	2818865	et	3	main
tema	doc_685122975291_item	2818867	et	4	main
elunõuded	doc_685122975291_item	2818868	et	3	main
siis	doc_685122975291_item	2818893	et	3	main
vaatab	doc_685122975291_item	2818896	et	3	main
et	doc_685122975291_item	2818900	et	3	main
mitte	doc_685122975291_item	2818910	et	3	main
palju	doc_685122975291_item	2818917	et	4	main
mida	doc_685122975291_item	2818921	et	4	main
ma	doc_685122975291_item	2818922	et	3	main
eriala	doc_685122975291_item	2818931	et	4	main
ja	doc_685122975291_item	2818948	et	3	main
mida	doc_685122975291_item	2818951	et	4	main
väga	doc_685122975291_item	2818960	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975291_item	2818970	et	4	main
õpilane	doc_685122975292_item	2818979	et	3	main
nägin	doc_685122975292_item	2818982	et	3	main
eesti	doc_685122975292_item	2818983	et	4	main
mõttesse	doc_685122975292_item	2818997	et	4	main
oma	doc_685122975292_item	2819004	et	4	main
neid	doc_685122975292_item	2819033	et	4	main
noori	doc_685122975292_item	2819034	et	3	main
kes	doc_685122975292_item	2819035	et	4	main
rohkem	doc_685122975292_item	2819043	et	4	main
hoolivad	doc_685122975292_item	2819046	et	4	main
eeskätt	doc_685122975292_item	2819047	et	3	main
neid	doc_685122975292_item	2819049	et	4	main
tahavad	doc_685122975292_item	2819051	et	3	main
palju	doc_685122975292_item	2819052	et	4	main
pappi	doc_685122975292_item	2819053	et	4	main
öelnud	doc_685122975292_item	2819057	et	4	main
selle	doc_685122975292_item	2819059	et	4	main
arvude	doc_685122975292_item	2819060	et	4	main
nõus	doc_685122975292_item	2819074	et	4	main
mis	doc_685122975292_item	2819081	et	4	main
kõik	doc_685122975292_item	2819088	et	4	main
on	doc_685122975290_item	2818605	et	4	main
paha	doc_685122975290_item	2818606	et	4	main
mul	doc_685122975290_item	2818607	et	3	main
ole	doc_685122975290_item	2818614	et	4	main
palju	doc_685122975290_item	2818615	et	4	main
vaba	doc_685122975290_item	2818616	et	4	main
kes	doc_685122975290_item	2818634	et	4	main
firmi	doc_685122975290_item	2818642	et	4	main
ja	doc_685122975290_item	2818643	et	3	main
need	doc_685122975290_item	2818644	et	3	main
koolis	doc_685122975290_item	2818647	et	4	main
peab	doc_685122975290_item	2818658	et	4	main
noormaalset	doc_685122975290_item	2818660	et	4	main
palka	doc_685122975290_item	2818661	et	4	main
pühendada	doc_685122975290_item	2818662	et	3	main
koodule	doc_685122975290_item	2818665	et	4	main
perekonale	doc_685122975290_item	2818667	et	4	main
inimene	doc_685122975290_item	2818702	et	3	main
talle	doc_685122975290_item	2818707	et	4	main
töökoht	doc_685122975290_item	2818724	et	3	main
tahavad	doc_685122975290_item	2818737	et	3	main
edasi	doc_685122975290_item	2818738	et	3	main
õppima	doc_685122975290_item	2818739	et	3	main
2005	doc_685122975290_item	2818745	et	2	main
lugupeetud	doc_685122975291_item	2818749	et	4	main
tiina	doc_685122975291_item	2818750	et	4	main
tüdruk	doc_685122975291_item	2818758	et	3	main
siin	doc_685122975291_item	2818768	et	4	main
lõpetasin	doc_685122975291_item	2818769	et	3	main
läbi	doc_685122975291_item	2818776	et	4	main
on	doc_685122975291_item	2818785	et	4	main
pärast	doc_685122975291_item	2818797	et	4	main
teha	doc_685122975291_item	2818805	et	3	main
ei	doc_685122975291_item	2818807	et	4	main
mittu	doc_685122975290_item	2818632	et	4	main
tuttavaid	doc_685122975290_item	2818633	et	3	main
hea	doc_685122975290_item	2818641	et	4	main
oma	doc_685122975290_item	2818655	et	4	main
kiiri	doc_685122975290_item	2818669	et	4	main
noorinimesed	doc_685122975290_item	2818671	et	3	main
ei	doc_685122975290_item	2818673	et	4	main
tea	doc_685122975290_item	2818674	et	4	main
kus	doc_685122975290_item	2818675	et	3	main
õppima	doc_685122975290_item	2818676	et	3	main
ja	doc_685122975290_item	2818677	et	3	main
kust	doc_685122975290_item	2818678	et	4	main
ja	doc_685122975290_item	2818680	et	3	main
töötama	doc_685122975290_item	2818679	et	3	main
millest	doc_685122975290_item	2818681	et	3	main
palga	doc_685122975290_item	2818682	et	3	main
saada	doc_685122975290_item	2818683	et	4	main
ma	doc_685122975290_item	2818684	et	3	main
juba	doc_685122975290_item	2818685	et	3	main
ütlesin	doc_685122975290_item	2818686	et	3	main
et	doc_685122975290_item	2818687	et	3	main
ma	doc_685122975290_item	2818688	et	3	main
sellest	doc_685122975290_item	2818690	et	4	main
olen	doc_685122975290_item	2818689	et	3	main
nõus	doc_685122975290_item	2818691	et	4	main
et	doc_685122975290_item	2818692	et	3	main
palju	doc_685122975290_item	2818693	et	4	main
sõltub	doc_685122975290_item	2818694	et	3	main
eksaamitulemused	doc_685122975290_item	2818695	et	3	main
kui	doc_685122975290_item	2818696	et	3	main
kõik	doc_685122975290_item	2818697	et	4	main
eksamid	doc_685122975290_item	2818698	et	3	main
sooritatud	doc_685122975290_item	2818700	et	4	main
siis	doc_685122975290_item	2818701	et	3	main
on	doc_685122975290_item	2818699	et	4	main
võib	doc_685122975290_item	2818703	et	3	main
mis	doc_685122975290_item	2818706	et	4	main
leida	doc_685122975290_item	2818711	et	3	main
palgast	doc_685122975290_item	2818715	et	4	main
oma	doc_685122975290_item	2818723	et	4	main
aga	doc_685122975290_item	2818727	et	3	main
töötada	doc_685122975290_item	2818731	et	3	main
saada	doc_685122975290_item	2818733	et	4	main
raha	doc_685122975290_item	2818734	et	4	main
nad	doc_685122975290_item	2818735	et	3	main
eesnimi	doc_685122975290_item	2818742	et	3	main
tallinn	doc_685122975290_item	2818744	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975290_item	2818747	et	4	main
eesnimi	doc_685122975291_item	2818753	et	3	main
perekonnanimi	doc_685122975291_item	2818754	et	3	main
olen	doc_685122975291_item	2818755	et	3	main
tallinna	doc_685122975291_item	2818762	et	4	main
maardu	doc_685122975291_item	2818770	et	4	main
gümnaasiumi	doc_685122975291_item	2818771	et	4	main
artikli	doc_685122975291_item	2818775	et	3	main
noori	doc_685122975291_item	2818788	et	3	main
tea	doc_685122975291_item	2818790	et	4	main
kuhu	doc_685122975291_item	2818791	et	3	main
nad	doc_685122975291_item	2818792	et	3	main
tahavad	doc_685122975291_item	2818793	et	3	main
minna	doc_685122975291_item	2818794	et	3	main
pärast	doc_685122975291_item	2818795	et	4	main
õppima	doc_685122975291_item	2818803	et	3	main
nad	doc_685122975291_item	2818806	et	3	main
mõtle	doc_685122975291_item	2818808	et	4	main
tahavad	doc_685122975291_item	2818822	et	3	main
kus	doc_685122975291_item	2818824	et	3	main
näiteks	doc_685122975291_item	2818834	et	4	main
meeldis	doc_685122975291_item	2818850	et	3	main
midagi	doc_685122975291_item	2818851	et	4	main
arutada	doc_685122975291_item	2818852	et	3	main
teine	doc_685122975291_item	2818853	et	3	main
oli	doc_685122975291_item	2818857	et	3	main
arvan	doc_685122975291_item	2818860	et	3	main
inimestest	doc_685122975291_item	2818864	et	3	main
teie	doc_685122975291_item	2818894	et	4	main
väga	doc_685122975291_item	2818903	et	3	main
palk	doc_685122975291_item	2818908	et	3	main
õppida	doc_685122975291_item	2818918	et	3	main
töötada	doc_685122975291_item	2818919	et	3	main
viimane	doc_685122975291_item	2818920	et	3	main
saama	doc_685122975291_item	2818930	et	4	main
ole	doc_685122975291_item	2818940	et	4	main
andma	doc_685122975291_item	2818944	et	3	main
võimalusi	doc_685122975291_item	2818946	et	3	main
teile	doc_685122975292_item	2818976	et	4	main
ta	doc_685122975292_item	2818990	et	4	main
mulle	doc_685122975292_item	2818992	et	4	main
selles	doc_685122975292_item	2819000	et	4	main
artikli	doc_685122975292_item	2819006	et	3	main
olen	doc_685122975292_item	2819009	et	3	main
ei	doc_685122975292_item	2819013	et	4	main
mis	doc_685122975292_item	2819019	et	4	main
role	doc_685122975290_item	2818722	et	4	main
ei	doc_685122975290_item	2818736	et	4	main
perekonnanimi	doc_685122975290_item	2818743	et	3	main
kaalep	doc_685122975291_item	2818751	et	4	main
mina	doc_685122975291_item	2818752	et	4	main
üheksateistkümne	doc_685122975291_item	2818756	et	4	main
aastane	doc_685122975291_item	2818757	et	4	main
sellel	doc_685122975291_item	2818759	et	4	main
aastal	doc_685122975291_item	2818760	et	3	main
astusin	doc_685122975291_item	2818761	et	3	main
tehnika	doc_685122975291_item	2818763	et	4	main
ülikooli	doc_685122975291_item	2818764	et	4	main
elan	doc_685122975291_item	2818765	et	3	main
ma	doc_685122975291_item	2818772	et	3	main
mulle	doc_685122975291_item	2818778	et	4	main
meeldis	doc_685122975291_item	2818780	et	3	main
mida	doc_685122975291_item	2818782	et	4	main
te	doc_685122975291_item	2818783	et	4	main
kirjutasite	doc_685122975291_item	2818784	et	3	main
eksami	doc_685122975291_item	2818798	et	3	main
nad	doc_685122975291_item	2818799	et	3	main
mõtlevad	doc_685122975291_item	2818800	et	4	main
kuhu	doc_685122975291_item	2818801	et	3	main
minna	doc_685122975291_item	2818802	et	3	main
ajal	doc_685122975291_item	2818811	et	4	main
teised	doc_685122975291_item	2818812	et	4	main
inimesed	doc_685122975291_item	2818813	et	3	main
kes	doc_685122975291_item	2818814	et	4	main
kümnesse	doc_685122975291_item	2818816	et	4	main
klassi	doc_685122975291_item	2818817	et	4	main
juba	doc_685122975291_item	2818818	et	3	main
teavad	doc_685122975291_item	2818819	et	3	main
kelleks	doc_685122975291_item	2818820	et	4	main
saada	doc_685122975291_item	2818823	et	4	main
töötada	doc_685122975291_item	2818825	et	3	main
mina	doc_685122975291_item	2818835	et	4	main
otsustasin	doc_685122975291_item	2818836	et	3	main
üheteistkümnendas	doc_685122975291_item	2818840	et	4	main
kui	doc_685122975291_item	2818842	et	3	main
läksime	doc_685122975291_item	2818844	et	3	main
ekskursioonile	doc_685122975291_item	2818845	et	3	main
lapsepõlvest	doc_685122975291_item	2818848	et	4	main
teie	doc_685122975291_item	2818855	et	4	main
et	doc_685122975291_item	2818861	et	3	main
sõltub	doc_685122975291_item	2818863	et	3	main
tõuseb	doc_685122975291_item	2818909	et	3	main
kohe	doc_685122975291_item	2818912	et	4	main
õige	doc_685122975291_item	2818833	et	4	main
juba	doc_685122975291_item	2818839	et	3	main
me	doc_685122975291_item	2818843	et	4	main
ja	doc_685122975291_item	2818847	et	3	main
mulle	doc_685122975291_item	2818849	et	4	main
artiklis	doc_685122975291_item	2818856	et	3	main
ma	doc_685122975291_item	2818859	et	3	main
kui	doc_685122975291_item	2818869	et	3	main
sa	doc_685122975291_item	2818870	et	3	main
parajasti	doc_685122975291_item	2818871	et	3	main
lõpetad	doc_685122975291_item	2818872	et	3	main
ülikooli	doc_685122975291_item	2818873	et	4	main
on	doc_685122975291_item	2818874	et	4	main
väga	doc_685122975291_item	2818875	et	3	main
hea	doc_685122975291_item	2818876	et	4	main
kui	doc_685122975291_item	2818877	et	3	main
sa	doc_685122975291_item	2818878	et	3	main
teenid	doc_685122975291_item	2818879	et	3	main
seitse	doc_685122975291_item	2818880	et	3	main
tuhat	doc_685122975291_item	2818881	et	4	main
või	doc_685122975291_item	2818882	et	4	main
kaheksa	doc_685122975291_item	2818883	et	4	main
tuhat	doc_685122975291_item	2818884	et	4	main
kõigepealt	doc_685122975291_item	2818885	et	3	main
sa	doc_685122975291_item	2818886	et	3	main
pead	doc_685122975291_item	2818887	et	4	main
end	doc_685122975291_item	2818888	et	4	main
näitama	doc_685122975291_item	2818889	et	3	main
töötama	doc_685122975291_item	2818890	et	3	main
hoolsalt	doc_685122975291_item	2818891	et	4	main
juhataja	doc_685122975291_item	2818895	et	4	main
saab	doc_685122975291_item	2818898	et	3	main
oled	doc_685122975291_item	2818902	et	3	main
hea	doc_685122975291_item	2818904	et	4	main
töötaja	doc_685122975291_item	2818905	et	4	main
ja	doc_685122975291_item	2818906	et	3	main
siis	doc_685122975291_item	2818907	et	3	main
kõik	doc_685122975291_item	2818911	et	4	main
saavad	doc_685122975291_item	2818913	et	4	main
direktoriks	doc_685122975291_item	2818914	et	3	main
on	doc_685122975291_item	2818915	et	4	main
öelda	doc_685122975291_item	2818924	et	4	main
aga	doc_685122975291_item	2818932	et	3	main
mitte	doc_685122975291_item	2818933	et	3	main
juba	doc_685122975291_item	2818934	et	3	main
kuueteskümnest	doc_685122975291_item	2818935	et	4	main
normaalne	doc_685122975291_item	2818941	et	3	main
on	doc_685122975291_item	2818959	et	4	main
huvitav	doc_685122975291_item	2818961	et	4	main
nagu	doc_685122975291_item	2818962	et	3	main
see	doc_685122975291_item	2818963	et	3	main
artikel	doc_685122975291_item	2818964	et	4	main
kiri	doc_685122975292_item	2818971	et	3	main
tiina	doc_685122975292_item	2818973	et	4	main
tehnikaülikooli	doc_685122975292_item	2818978	et	4	main
eesnimi	doc_685122975292_item	2818980	et	3	main
perekonnanimi	doc_685122975292_item	2818981	et	3	main
põlvkond	doc_685122975292_item	2818989	et	3	main
pakkus	doc_685122975292_item	2818991	et	3	main
suure	doc_685122975292_item	2818993	et	3	main
kirjas	doc_685122975292_item	2819001	et	4	main
teiega	doc_685122975292_item	2819003	et	3	main
kohta	doc_685122975292_item	2819007	et	4	main
hea	doc_685122975292_item	2819017	et	4	main
ja	doc_685122975292_item	2819018	et	3	main
mitte	doc_685122975292_item	2819020	et	3	main
kõigepealt	doc_685122975292_item	2819021	et	3	main
et	doc_685122975292_item	2819023	et	3	main
lugedes	doc_685122975292_item	2819025	et	3	main
teada	doc_685122975292_item	2819029	et	3	main
kui	doc_685122975292_item	2819030	et	3	main
on	doc_685122975292_item	2819032	et	4	main
ei	doc_685122975292_item	2819056	et	4	main
midagi	doc_685122975292_item	2819058	et	4	main
et	doc_685122975292_item	2819075	et	3	main
rühm	doc_685122975292_item	2819076	et	3	main
neist	doc_685122975292_item	2819077	et	4	main
tea	doc_685122975292_item	2819080	et	4	main
saab	doc_685122975292_item	2819083	et	3	main
nii	doc_685122975292_item	2819085	et	3	main
unistasid	doc_685122975292_item	2819098	et	4	main
et	doc_685122975292_item	2819100	et	3	main
olid	doc_685122975292_item	2819101	et	4	main
eksamite	doc_685122975292_item	2819112	et	3	main
riigieksamite	doc_685122975292_item	2819120	et	3	main
rohkem	doc_685122975292_item	2819138	et	4	main
samal	doc_685122975292_item	2819146	et	3	main
et	doc_685122975292_item	2819149	et	3	main
ka	doc_685122975292_item	2819151	et	3	main
ja	doc_685122975292_item	2819159	et	3	main
ja	doc_685122975292_item	2819162	et	3	main
inimesi	doc_685122975292_item	2819164	et	4	main
uue	doc_685122975292_item	2819167	et	3	main
miks	doc_685122975292_item	2819175	et	4	main
loodan	doc_685122975292_item	2819181	et	3	main
kirjutan	doc_685122975293_item	2819218	et	3	main
sellepärast	doc_685122975293_item	2819220	et	3	main
eile	doc_685122975293_item	2819222	et	3	main
vähenõdlike	doc_685122975293_item	2819226	et	4	main
lugeda	doc_685122975293_item	2819231	et	3	main
artiklit	doc_685122975293_item	2819233	et	3	main
kirjutan	doc_685122975293_item	2819241	et	3	main
neid	doc_685122975293_item	2819257	et	4	main
hoolekanne	doc_685122975293_item	2819264	et	4	main
noored	doc_685122975293_item	2819265	et	3	main
inimesed	doc_685122975293_item	2819266	et	3	main
liisida	doc_685122975293_item	2819271	et	4	main
aga	doc_685122975293_item	2819276	et	3	main
oma	doc_685122975293_item	2819279	et	4	main
kõik	doc_685122975293_item	2819310	et	4	main
jaoks	doc_685122975293_item	2819313	et	4	main
avatud	doc_685122975293_item	2819315	et	4	main
tahan	doc_685122975291_item	2818923	et	3	main
et	doc_685122975291_item	2818925	et	3	main
peavad	doc_685122975291_item	2818928	et	4	main
õppima	doc_685122975291_item	2818929	et	3	main
ei	doc_685122975291_item	2818939	et	4	main
vanemad	doc_685122975291_item	2818942	et	4	main
last	doc_685122975291_item	2818945	et	4	main
õppima	doc_685122975291_item	2818947	et	3	main
kõik	doc_685122975291_item	2818950	et	4	main
nad	doc_685122975291_item	2818952	et	3	main
tahavad	doc_685122975291_item	2818953	et	3	main
ma	doc_685122975291_item	2818954	et	3	main
loodan	doc_685122975291_item	2818955	et	3	main
et	doc_685122975291_item	2818956	et	3	main
järgmine	doc_685122975291_item	2818957	et	3	main
artikel	doc_685122975291_item	2818958	et	4	main
head	doc_685122975291_item	2818966	et	4	main
eesnimi	doc_685122975291_item	2818967	et	3	main
perekonnanimi	doc_685122975291_item	2818968	et	3	main
121105	doc_685122975291_item	2818969	et	2	main
lugupeetud	doc_685122975292_item	2818972	et	4	main
kaalep	doc_685122975292_item	2818974	et	4	main
kirjutab	doc_685122975292_item	2818975	et	3	main
ekspress	doc_685122975292_item	2818984	et	4	main
ajalehes	doc_685122975292_item	2818985	et	3	main
teie	doc_685122975292_item	2818986	et	4	main
artikli	doc_685122975292_item	2818987	et	3	main
huvi	doc_685122975292_item	2818994	et	4	main
ning	doc_685122975292_item	2818995	et	3	main
pani	doc_685122975292_item	2818996	et	4	main
jagada	doc_685122975292_item	2819002	et	3	main
millega	doc_685122975292_item	2819008	et	3	main
nõus	doc_685122975292_item	2819010	et	4	main
millega	doc_685122975292_item	2819012	et	3	main
ole	doc_685122975292_item	2819014	et	4	main
mis	doc_685122975292_item	2819015	et	4	main
oli	doc_685122975292_item	2819016	et	3	main
määran	doc_685122975292_item	2819022	et	3	main
lõpuni	doc_685122975292_item	2819024	et	3	main
neid	doc_685122975292_item	2819044	et	4	main
kes	doc_685122975292_item	2819045	et	4	main
kes	doc_685122975292_item	2819050	et	4	main
te	doc_685122975292_item	2819055	et	4	main
on	doc_685122975292_item	2819066	et	4	main
väga	doc_685122975292_item	2819067	et	3	main
tähtis	doc_685122975292_item	2819068	et	4	main
mina	doc_685122975292_item	2819069	et	4	main
kes	doc_685122975292_item	2819078	et	4	main
astusid	doc_685122975292_item	2819093	et	4	main
abituriendid	doc_685122975292_item	2819103	et	3	main
ala	doc_685122975292_item	2819109	et	4	main
tuleb	doc_685122975292_item	2819117	et	3	main
vaid	doc_685122975292_item	2819122	et	3	main
asja	doc_685122975292_item	2819124	et	4	main
huvi	doc_685122975292_item	2819139	et	4	main
see	doc_685122975292_item	2819140	et	3	main
on	doc_685122975292_item	2819141	et	4	main
isiklik	doc_685122975292_item	2819144	et	3	main
meeldis	doc_685122975292_item	2819148	et	3	main
ekstraordinaarseid	doc_685122975292_item	2819161	et	3	main
unistustega	doc_685122975292_item	2819170	et	4	main
ainult	doc_685122975292_item	2819179	et	4	main
et	doc_685122975292_item	2819182	et	3	main
teie	doc_685122975293_item	2819224	et	4	main
põlvkond	doc_685122975293_item	2819227	et	3	main
pärast	doc_685122975293_item	2819234	et	4	main
vestlesime	doc_685122975293_item	2819235	et	3	main
omavahel	doc_685122975293_item	2819236	et	3	main
seda	doc_685122975293_item	2819237	et	3	main
eesti	doc_685122975293_item	2819238	et	4	main
teile	doc_685122975293_item	2819242	et	4	main
et	doc_685122975293_item	2819243	et	3	main
teie	doc_685122975293_item	2819247	et	4	main
põlvkond	doc_685122975293_item	2819251	et	3	main
vähenõudlik	doc_685122975293_item	2819253	et	3	main
ja	doc_685122975293_item	2819254	et	3	main
hindab	doc_685122975293_item	2819255	et	3	main
kõigepealt	doc_685122975293_item	2819256	et	3	main
materiaalne	doc_685122975293_item	2819260	et	3	main
riiklik	doc_685122975293_item	2819263	et	3	main
tahavad	doc_685122975293_item	2819267	et	3	main
normaalset	doc_685122975293_item	2819269	et	3	main
soetada	doc_685122975293_item	2819273	et	3	main
uksed	doc_685122975293_item	2819311	et	3	main
verd	doc_685122975293_item	2819323	et	3	main
saavutada	doc_685122975293_item	2819325	et	3	main
tahame	doc_685122975293_item	2819327	et	3	main
artikel	doc_685122975293_item	2819337	et	4	main
aga	doc_685122975293_item	2819338	et	3	main
põlvkonnas	doc_685122975293_item	2819340	et	4	main
väga	doc_685122975293_item	2819342	et	3	main
mina	doc_685122975293_item	2819345	et	4	main
meie	doc_685122975293_item	2819349	et	4	main
vigu	doc_685122975293_item	2819353	et	3	main
essee	doc_685122975294_item	2819358	et	4	main
tallinnas	doc_685122975294_item	2819367	et	4	main
koolis	doc_685122975294_item	2819371	et	4	main
ei	doc_685122975292_item	2819026	et	4	main
palju	doc_685122975292_item	2819031	et	4	main
pärani	doc_685122975292_item	2819039	et	4	main
ning	doc_685122975292_item	2819040	et	3	main
kumb	doc_685122975292_item	2819041	et	3	main
on	doc_685122975292_item	2819042	et	4	main
või	doc_685122975292_item	2819048	et	4	main
kahjuks	doc_685122975292_item	2819054	et	4	main
ole	doc_685122975292_item	2819071	et	4	main
ka	doc_685122975292_item	2819072	et	3	main
täiesti	doc_685122975292_item	2819073	et	3	main
ei	doc_685122975292_item	2819079	et	4	main
on	doc_685122975292_item	2819084	et	4	main
suur	doc_685122975292_item	2819086	et	3	main
näiteks	doc_685122975292_item	2819087	et	4	main
minu	doc_685122975292_item	2819089	et	3	main
klassikaaslased	doc_685122975292_item	2819090	et	3	main
millest	doc_685122975292_item	2819097	et	3	main
usun	doc_685122975292_item	2819099	et	3	main
valisid	doc_685122975292_item	2819105	et	4	main
tuleviku	doc_685122975292_item	2819108	et	4	main
punktid	doc_685122975292_item	2819113	et	4	main
lubasid	doc_685122975292_item	2819114	et	4	main
see	doc_685122975292_item	2819115	et	3	main
probleem	doc_685122975292_item	2819116	et	3	main
ja	doc_685122975292_item	2819091	et	3	main
selle	doc_685122975292_item	2819095	et	4	main
niisugused	doc_685122975292_item	2819102	et	3	main
mis	doc_685122975292_item	2819110	et	4	main
aga	doc_685122975292_item	2819118	et	3	main
loteriist	doc_685122975292_item	2819121	et	3	main
selle	doc_685122975292_item	2819123	et	4	main
põhjus	doc_685122975292_item	2819125	et	4	main
on	doc_685122975292_item	2819126	et	4	main
erialasid	doc_685122975292_item	2819133	et	4	main
mille	doc_685122975292_item	2819134	et	3	main
vastu	doc_685122975292_item	2819135	et	3	main
tunnevad	doc_685122975292_item	2819136	et	3	main
noored	doc_685122975292_item	2819137	et	3	main
arvamus	doc_685122975292_item	2819145	et	3	main
vaja	doc_685122975292_item	2819157	et	4	main
värskust	doc_685122975292_item	2819158	et	3	main
uue	doc_685122975292_item	2819165	et	3	main
selge	doc_685122975292_item	2819173	et	4	main
aga	doc_685122975292_item	2819174	et	3	main
olema	doc_685122975292_item	2819178	et	4	main
mina	doc_685122975293_item	2819217	et	4	main
ülikoolidesse	doc_685122975292_item	2819094	et	3	main
erialadele	doc_685122975292_item	2819096	et	3	main
kes	doc_685122975292_item	2819104	et	4	main
ainult	doc_685122975292_item	2819106	et	4	main
seda	doc_685122975292_item	2819107	et	3	main
tema	doc_685122975292_item	2819111	et	4	main
mitte	doc_685122975292_item	2819119	et	3	main
ei	doc_685122975292_item	2819130	et	4	main
aga	doc_685122975292_item	2819142	et	3	main
minu	doc_685122975292_item	2819143	et	3	main
ajal	doc_685122975292_item	2819147	et	4	main
teie	doc_685122975292_item	2819150	et	4	main
saate	doc_685122975292_item	2819152	et	4	main
aru	doc_685122975292_item	2819153	et	4	main
et	doc_685122975292_item	2819154	et	3	main
riigile	doc_685122975292_item	2819155	et	3	main
plaanidega	doc_685122975292_item	2819166	et	3	main
lootustega	doc_685122975292_item	2819168	et	4	main
uue	doc_685122975292_item	2819169	et	3	main
ei	doc_685122975292_item	2819171	et	4	main
ole	doc_685122975292_item	2819172	et	4	main
ministrid	doc_685122975292_item	2819180	et	3	main
ülikoolis	doc_685122975293_item	2819216	et	4	main
teile	doc_685122975293_item	2819219	et	4	main
et	doc_685122975293_item	2819221	et	3	main
artiklit	doc_685122975293_item	2819225	et	3	main
nõustada	doc_685122975293_item	2819244	et	3	main
asju	doc_685122975293_item	2819258	et	3	main
sotsiaaltagatised	doc_685122975293_item	2819262	et	3	main
et	doc_685122975293_item	2819324	et	3	main
olema	doc_685122975293_item	2819329	et	4	main
aktiivsed	doc_685122975293_item	2819330	et	3	main
ambitsioonilised	doc_685122975293_item	2819331	et	4	main
ja	doc_685122975293_item	2819332	et	3	main
haridus-	doc_685122975293_item	2819350	et	3	main
eesnimi	doc_685122975293_item	2819355	et	3	main
on	doc_685122975294_item	2819364	et	4	main
juudi	doc_685122975294_item	2819370	et	3	main
suvi	doc_685122975294_item	2819373	et	3	main
ülikoolis	doc_685122975294_item	2819380	et	4	main
olla	doc_685122975294_item	2819388	et	3	main
õppima	doc_685122975294_item	2819421	et	3	main
loengudel	doc_685122975294_item	2819431	et	4	main
saavad	doc_685122975294_item	2819445	et	4	main
arusama	doc_685122975294_item	2819447	et	4	main
on	doc_685122975294_item	2819453	et	4	main
pärast	doc_685122975295_item	2819469	et	4	main
klassis	doc_685122975295_item	2819473	et	3	main
tahan	doc_685122975295_item	2819478	et	3	main
rühmal	doc_685122975295_item	2819531	et	3	main
teadmusi	doc_685122975295_item	2819545	et	3	main
tahtsin	doc_685122975295_item	2819548	et	3	main
aga	doc_685122975295_item	2819551	et	3	main
tean	doc_685122975295_item	2819554	et	3	main
et	doc_685122975295_item	2819555	et	3	main
lühikeselt	doc_685122975295_item	2819567	et	4	main
sündinud	doc_685122975295_item	2819571	et	4	main
ja	doc_685122975295_item	2819573	et	3	main
kogu	doc_685122975295_item	2819576	et	4	main
õppisid	doc_685122975295_item	2819586	et	4	main
ttüs	doc_685122975295_item	2819587	et	4	main
ma	doc_685122975295_item	2819588	et	3	main
minu	doc_685122975295_item	2819623	et	3	main
uut	doc_685122975295_item	2819634	et	3	main
õppida	doc_685122975295_item	2819636	et	3	main
ülikool	doc_685122975296_item	2819642	et	4	main
perekonnanimi	doc_685122975296_item	2819649	et	3	main
pärit	doc_685122975296_item	2819654	et	3	main
seda	doc_685122975296_item	2819661	et	3	main
teenisin	doc_685122975296_item	2819664	et	3	main
läksin	doc_685122975296_item	2819670	et	3	main
tegin	doc_685122975296_item	2819674	et	3	main
sektoris	doc_685122975296_item	2819677	et	3	main
töötan	doc_685122975296_item	2819679	et	3	main
tagasi	doc_685122975296_item	2819683	et	3	main
aitab	doc_685122975296_item	2819686	et	3	main
töötada	doc_685122975296_item	2819688	et	3	main
ei	doc_685122975296_item	2819691	et	4	main
viitsi	doc_685122975296_item	2819692	et	4	main
sellega	doc_685122975296_item	2819729	et	3	main
et	doc_685122975296_item	2819730	et	3	main
minu	doc_685122975296_item	2819731	et	3	main
selles	doc_685122975292_item	2819127	et	4	main
et	doc_685122975292_item	2819128	et	3	main
riik	doc_685122975292_item	2819129	et	3	main
finantseeri	doc_685122975292_item	2819131	et	4	main
neid	doc_685122975292_item	2819132	et	4	main
on	doc_685122975292_item	2819156	et	4	main
särtsu	doc_685122975292_item	2819160	et	4	main
edasilükkavaid	doc_685122975292_item	2819163	et	3	main
neid	doc_685122975292_item	2819176	et	4	main
peavad	doc_685122975292_item	2819177	et	4	main
minu	doc_685122975292_item	2819183	et	3	main
väike	doc_685122975292_item	2819184	et	4	main
kriitika	doc_685122975292_item	2819185	et	4	main
oli	doc_685122975292_item	2819186	et	3	main
kohane	doc_685122975292_item	2819187	et	4	main
üldiselt	doc_685122975292_item	2819188	et	4	main
öeldes	doc_685122975292_item	2819189	et	3	main
artikkel	doc_685122975292_item	2819190	et	3	main
on	doc_685122975292_item	2819191	et	4	main
päris	doc_685122975292_item	2819192	et	4	main
teaduslik	doc_685122975292_item	2819193	et	3	main
ja	doc_685122975292_item	2819194	et	3	main
huvitav	doc_685122975292_item	2819195	et	4	main
parimate	doc_685122975292_item	2819196	et	4	main
soovitega	doc_685122975292_item	2819197	et	4	main
eesnimi	doc_685122975292_item	2819198	et	3	main
perekonnanimi	doc_685122975292_item	2819199	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975292_item	2819200	et	4	main
kiri	doc_685122975293_item	2819201	et	3	main
lugupeetud	doc_685122975293_item	2819202	et	4	main
tiina	doc_685122975293_item	2819203	et	4	main
kaalepi	doc_685122975293_item	2819204	et	4	main
minu	doc_685122975293_item	2819205	et	3	main
nimi	doc_685122975293_item	2819206	et	3	main
on	doc_685122975293_item	2819207	et	4	main
eesnimi	doc_685122975293_item	2819208	et	3	main
perekonnanimi	doc_685122975293_item	2819209	et	3	main
olen	doc_685122975293_item	2819210	et	3	main
esmakurslane	doc_685122975293_item	2819211	et	4	main
ja	doc_685122975293_item	2819212	et	3	main
õpin	doc_685122975293_item	2819213	et	3	main
tallinna	doc_685122975293_item	2819214	et	4	main
tehnika	doc_685122975293_item	2819215	et	4	main
oli	doc_685122975293_item	2819229	et	3	main
keele	doc_685122975293_item	2819239	et	4	main
täielikult	doc_685122975293_item	2819245	et	4	main
arvamust	doc_685122975293_item	2819248	et	3	main
noor	doc_685122975293_item	2819250	et	3	main
on	doc_685122975293_item	2819252	et	4	main
väike	doc_685122975293_item	2819274	et	4	main
mina	doc_685122975293_item	2819306	et	4	main
arvan	doc_685122975293_item	2819307	et	3	main
et	doc_685122975293_item	2819308	et	3	main
praegu	doc_685122975293_item	2819309	et	3	main
meie	doc_685122975293_item	2819312	et	4	main
lugesin	doc_685122975293_item	2819223	et	3	main
minul	doc_685122975293_item	2819228	et	3	main
koduülesanne	doc_685122975293_item	2819230	et	4	main
teie	doc_685122975293_item	2819232	et	4	main
tunnis	doc_685122975293_item	2819240	et	3	main
jagan	doc_685122975293_item	2819246	et	3	main
praegune	doc_685122975293_item	2819249	et	3	main
nagu	doc_685122975293_item	2819259	et	3	main
kindlustus	doc_685122975293_item	2819261	et	4	main
lihtsalt	doc_685122975293_item	2819268	et	4	main
palka	doc_685122975293_item	2819270	et	4	main
auto	doc_685122975293_item	2819272	et	4	main
kodu	doc_685122975293_item	2819275	et	4	main
neil	doc_685122975293_item	2819277	et	4	main
on	doc_685122975293_item	2819278	et	4	main
õigus	doc_685122975293_item	2819280	et	4	main
arvan	doc_685122975293_item	2819281	et	3	main
need	doc_685122975293_item	2819282	et	3	main
asjad	doc_685122975293_item	2819283	et	3	main
tähendavad	doc_685122975293_item	2819284	et	4	main
nende	doc_685122975293_item	2819285	et	4	main
jaoks	doc_685122975293_item	2819286	et	4	main
garantii	doc_685122975293_item	2819287	et	4	main
et	doc_685122975293_item	2819288	et	3	main
nende	doc_685122975293_item	2819289	et	4	main
ja	doc_685122975293_item	2819290	et	3	main
nende	doc_685122975293_item	2819291	et	4	main
laste	doc_685122975293_item	2819292	et	4	main
laste	doc_685122975293_item	2819293	et	4	main
laste	doc_685122975293_item	2819294	et	4	main
elu	doc_685122975293_item	2819295	et	4	main
on	doc_685122975293_item	2819296	et	4	main
rahulik	doc_685122975293_item	2819297	et	3	main
stabiilne	doc_685122975293_item	2819298	et	3	main
ja	doc_685122975293_item	2819299	et	3	main
muretu	doc_685122975293_item	2819300	et	4	main
tänapäeval	doc_685122975293_item	2819301	et	3	main
ainukesed	doc_685122975293_item	2819302	et	4	main
tahavad	doc_685122975293_item	2819303	et	3	main
saada	doc_685122975293_item	2819304	et	4	main
peaministriks	doc_685122975293_item	2819305	et	3	main
on	doc_685122975293_item	2819314	et	4	main
ühiskond	doc_685122975293_item	2819316	et	3	main
riik	doc_685122975293_item	2819318	et	3	main
vajab	doc_685122975293_item	2819319	et	3	main
ja	doc_685122975293_item	2819321	et	3	main
mida	doc_685122975293_item	2819326	et	4	main
meie	doc_685122975293_item	2819339	et	4	main
on	doc_685122975293_item	2819341	et	4	main
palju	doc_685122975293_item	2819343	et	4	main
tuleksin	doc_685122975294_item	2819379	et	3	main
õppima	doc_685122975294_item	2819381	et	3	main
pärast	doc_685122975294_item	2819383	et	4	main
tark	doc_685122975294_item	2819386	et	3	main
kes	doc_685122975294_item	2819424	et	4	main
õppitama	doc_685122975294_item	2819426	et	4	main
ma	doc_685122975294_item	2819427	et	3	main
pärast	doc_685122975294_item	2819434	et	4	main
keeles	doc_685122975294_item	2819436	et	4	main
tahan	doc_685122975294_item	2819442	et	3	main
mind	doc_685122975294_item	2819446	et	4	main
ja	doc_685122975294_item	2819448	et	3	main
see	doc_685122975294_item	2819452	et	3	main
klassis	doc_685122975295_item	2819463	et	3	main
ma	doc_685122975295_item	2819464	et	3	main
tuli	doc_685122975295_item	2819475	et	4	main
meelde	doc_685122975295_item	2819476	et	3	main
edasi	doc_685122975295_item	2819485	et	3	main
siin	doc_685122975295_item	2819523	et	4	main
ttü	doc_685122975295_item	2819534	et	4	main
palju	doc_685122975295_item	2819542	et	4	main
kogemusi	doc_685122975295_item	2819543	et	3	main
esimesena	doc_685122975295_item	2819546	et	3	main
nüüd	doc_685122975295_item	2819552	et	4	main
on	doc_685122975295_item	2819557	et	4	main
ka	doc_685122975295_item	2819559	et	3	main
minust	doc_685122975295_item	2819568	et	3	main
perega	doc_685122975295_item	2819579	et	3	main
lõppenud	doc_685122975295_item	2819590	et	4	main
tallinna	doc_685122975295_item	2819591	et	4	main
ranniku	doc_685122975295_item	2819592	et	3	main
gümnaasium	doc_685122975295_item	2819593	et	3	main
kaks	doc_685122975295_item	2819594	et	3	main
tuhat	doc_685122975295_item	2819595	et	4	main
kuuendal	doc_685122975295_item	2819596	et	3	main
ootan	doc_685122975295_item	2819621	et	3	main
mulle	doc_685122975295_item	2819632	et	4	main
essee	doc_685122975296_item	2819639	et	4	main
nimi	doc_685122975296_item	2819646	et	3	main
tallinnast	doc_685122975296_item	2819653	et	3	main
lõpetasin	doc_685122975296_item	2819655	et	3	main
kakstuhad	doc_685122975296_item	2819658	et	3	main
rühmas	doc_685122975296_item	2819667	et	4	main
teenistust	doc_685122975296_item	2819669	et	3	main
2	doc_685122975296_item	2819672	et	2	main
siiamaani	doc_685122975296_item	2819680	et	3	main
kuud	doc_685122975296_item	2819682	et	4	main
küll	doc_685122975296_item	2819687	et	4	main
et	doc_685122975296_item	2819690	et	3	main
seoses	doc_685122975296_item	2819728	et	4	main
kool	doc_685122975296_item	2819737	et	4	main
sporti	doc_685122975296_item	2819741	et	4	main
ole	doc_685122975296_item	2819745	et	4	main
oma	doc_685122975296_item	2819750	et	4	main
seeüldiselt	doc_685122975296_item	2819763	et	4	main
võin	doc_685122975296_item	2819771	et	3	main
et	doc_685122975296_item	2819773	et	3	main
on	doc_685122975296_item	2819777	et	4	main
ainuke	doc_685122975296_item	2819778	et	4	main
ja	doc_685122975296_item	2819790	et	3	main
keele	doc_685122975296_item	2819802	et	4	main
loengult	doc_685122975296_item	2819803	et	3	main
mina	doc_685122975297_item	2819812	et	4	main
sellel	doc_685122975297_item	2819827	et	4	main
sillamäe	doc_685122975297_item	2819831	et	3	main
tehnika	doc_685122975297_item	2819839	et	4	main
ülikooli	doc_685122975297_item	2819840	et	4	main
see	doc_685122975297_item	2819847	et	3	main
on	doc_685122975297_item	2819848	et	4	main
ja	doc_685122975297_item	2819851	et	3	main
prestiizne	doc_685122975297_item	2819852	et	4	main
ma	doc_685122975297_item	2819856	et	3	main
nagu	doc_685122975297_item	2819860	et	3	main
ja	doc_685122975293_item	2819317	et	3	main
värskust	doc_685122975293_item	2819320	et	3	main
uut	doc_685122975293_item	2819322	et	3	main
peame	doc_685122975293_item	2819328	et	4	main
ministre	doc_685122975293_item	2819344	et	4	main
ja	doc_685122975293_item	2819351	et	3	main
lugupidamisega	doc_685122975293_item	2819354	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975293_item	2819357	et	4	main
mina	doc_685122975294_item	2819359	et	4	main
ja	doc_685122975294_item	2819360	et	3	main
ülikool	doc_685122975294_item	2819361	et	4	main
minu	doc_685122975294_item	2819362	et	3	main
nimi	doc_685122975294_item	2819363	et	3	main
tallinna	doc_685122975294_item	2819369	et	4	main
inimene	doc_685122975294_item	2819387	et	3	main
suhtlusvõimelised	doc_685122975293_item	2819333	et	4	main
minule	doc_685122975293_item	2819334	et	3	main
meeldis	doc_685122975293_item	2819335	et	3	main
teie	doc_685122975293_item	2819336	et	4	main
võin	doc_685122975293_item	2819346	et	3	main
teile	doc_685122975293_item	2819347	et	4	main
nimetada	doc_685122975293_item	2819348	et	3	main
meditsiinisüsteemi	doc_685122975293_item	2819352	et	4	main
perekonnanimi	doc_685122975293_item	2819356	et	3	main
eesnimi	doc_685122975294_item	2819365	et	3	main
elan	doc_685122975294_item	2819366	et	3	main
õppisin	doc_685122975294_item	2819368	et	3	main
kogu	doc_685122975294_item	2819372	et	4	main
töötasin	doc_685122975294_item	2819374	et	3	main
õppin	doc_685122975294_item	2819389	et	4	main
mehanika	doc_685122975294_item	2819390	et	4	main
teaduskonnas	doc_685122975294_item	2819391	et	4	main
kolm	doc_685122975294_item	2819392	et	3	main
aasta	doc_685122975294_item	2819393	et	4	main
pärast	doc_685122975294_item	2819394	et	4	main
loodan	doc_685122975294_item	2819395	et	3	main
alustada	doc_685122975294_item	2819396	et	3	main
töötama	doc_685122975294_item	2819397	et	3	main
nagu	doc_685122975294_item	2819398	et	3	main
soojustehnik	doc_685122975294_item	2819399	et	3	main
ühes	doc_685122975294_item	2819400	et	4	main
firmas	doc_685122975294_item	2819401	et	3	main
esimene	doc_685122975294_item	2819402	et	3	main
mulje	doc_685122975294_item	2819403	et	4	main
ttüs	doc_685122975294_item	2819404	et	4	main
et	doc_685122975294_item	2819405	et	3	main
see	doc_685122975294_item	2819406	et	3	main
on	doc_685122975294_item	2819407	et	4	main
väga	doc_685122975294_item	2819408	et	3	main
suur	doc_685122975294_item	2819409	et	3	main
kõrgkool	doc_685122975294_item	2819410	et	4	main
ja	doc_685122975294_item	2819411	et	3	main
et	doc_685122975294_item	2819412	et	3	main
on	doc_685122975294_item	2819414	et	4	main
väga	doc_685122975294_item	2819415	et	3	main
siin	doc_685122975294_item	2819413	et	4	main
palju	doc_685122975294_item	2819416	et	4	main
huvitanud	doc_685122975294_item	2819417	et	4	main
inimesed	doc_685122975294_item	2819418	et	3	main
kes	doc_685122975294_item	2819419	et	4	main
tahavad	doc_685122975294_item	2819420	et	3	main
ja	doc_685122975294_item	2819422	et	3	main
keele	doc_685122975294_item	2819430	et	4	main
et	doc_685122975294_item	2819443	et	3	main
estlased	doc_685122975294_item	2819444	et	4	main
ühes	doc_685122975294_item	2819375	et	4	main
firmas	doc_685122975294_item	2819376	et	3	main
nagu	doc_685122975294_item	2819377	et	3	main
rehviekspert	doc_685122975294_item	2819378	et	3	main
selle	doc_685122975294_item	2819382	et	4	main
et	doc_685122975294_item	2819384	et	3	main
tahan	doc_685122975294_item	2819385	et	3	main
need	doc_685122975294_item	2819423	et	3	main
tahavad	doc_685122975294_item	2819425	et	3	main
ootan	doc_685122975294_item	2819428	et	3	main
eesti	doc_685122975294_item	2819429	et	4	main
eesti	doc_685122975294_item	2819435	et	4	main
rägida	doc_685122975294_item	2819437	et	4	main
ja	doc_685122975294_item	2819438	et	3	main
mitte	doc_685122975294_item	2819439	et	3	main
loodan	doc_685122975294_item	2819450	et	3	main
mina	doc_685122975295_item	2819456	et	4	main
ülikool	doc_685122975295_item	2819458	et	4	main
olin	doc_685122975295_item	2819461	et	3	main
seitsmendas	doc_685122975295_item	2819462	et	3	main
ei	doc_685122975295_item	2819465	et	4	main
teanud	doc_685122975295_item	2819466	et	4	main
kuhu	doc_685122975295_item	2819467	et	3	main
astuda	doc_685122975295_item	2819468	et	3	main
üheksandas	doc_685122975295_item	2819472	et	3	main
saada	doc_685122975295_item	2819479	et	4	main
aga	doc_685122975295_item	2819481	et	3	main
ma	doc_685122975295_item	2819483	et	3	main
läksin	doc_685122975295_item	2819484	et	3	main
gümnaasiumis	doc_685122975295_item	2819486	et	3	main
õppima	doc_685122975295_item	2819522	et	3	main
meeles	doc_685122975295_item	2819533	et	3	main
pristiizne	doc_685122975295_item	2819536	et	4	main
siin	doc_685122975295_item	2819538	et	4	main
ma	doc_685122975295_item	2819539	et	3	main
võin	doc_685122975295_item	2819540	et	3	main
saada	doc_685122975295_item	2819549	et	4	main
olin	doc_685122975295_item	2819570	et	3	main
elan	doc_685122975295_item	2819574	et	3	main
siin	doc_685122975295_item	2819575	et	4	main
millest	doc_685122975295_item	2819580	et	3	main
ja	doc_685122975295_item	2819582	et	3	main
minu	doc_685122975295_item	2819583	et	3	main
uus	doc_685122975295_item	2819624	et	3	main
olla	doc_685122975295_item	2819627	et	3	main
võib	doc_685122975295_item	2819631	et	3	main
jõud	doc_685122975295_item	2819635	et	4	main
aastane	doc_685122975296_item	2819652	et	4	main
peale	doc_685122975296_item	2819668	et	4	main
tööle	doc_685122975296_item	2819671	et	3	main
tööd	doc_685122975296_item	2819675	et	4	main
ja	doc_685122975296_item	2819678	et	3	main
2	doc_685122975296_item	2819681	et	2	main
et	doc_685122975294_item	2819432	et	3	main
saan	doc_685122975294_item	2819433	et	4	main
ainult	doc_685122975294_item	2819440	et	4	main
rägida	doc_685122975294_item	2819441	et	4	main
ma	doc_685122975294_item	2819449	et	3	main
essee	doc_685122975295_item	2819455	et	4	main
ja	doc_685122975295_item	2819457	et	3	main
kui	doc_685122975295_item	2819459	et	3	main
ma	doc_685122975295_item	2819460	et	3	main
lõpetamisest	doc_685122975295_item	2819471	et	4	main
kõrgharidust	doc_685122975295_item	2819480	et	4	main
õppima	doc_685122975295_item	2819487	et	3	main
kus	doc_685122975295_item	2819488	et	3	main
ma	doc_685122975295_item	2819489	et	3	main
sain	doc_685122975295_item	2819490	et	3	main
aru	doc_685122975295_item	2819491	et	4	main
et	doc_685122975295_item	2819492	et	3	main
tahan	doc_685122975295_item	2819493	et	3	main
astuda	doc_685122975295_item	2819494	et	3	main
tallinna	doc_685122975295_item	2819495	et	4	main
tehnika	doc_685122975295_item	2819496	et	4	main
ülikoolisse	doc_685122975295_item	2819497	et	4	main
informaatika	doc_685122975295_item	2819498	et	4	main
erialasse	doc_685122975295_item	2819499	et	3	main
see	doc_685122975295_item	2819500	et	3	main
oli	doc_685122975295_item	2819501	et	3	main
perspektivne	doc_685122975295_item	2819502	et	4	main
eriala	doc_685122975295_item	2819503	et	4	main
minu	doc_685122975295_item	2819504	et	3	main
mõeldes	doc_685122975295_item	2819505	et	3	main
et	doc_685122975295_item	2819506	et	3	main
kõik	doc_685122975295_item	2819507	et	4	main
muutub	doc_685122975295_item	2819508	et	3	main
automaatikaliselt	doc_685122975295_item	2819509	et	4	main
ja	doc_685122975295_item	2819510	et	3	main
arvuti	doc_685122975295_item	2819511	et	4	main
juhib	doc_685122975295_item	2819512	et	3	main
seda	doc_685122975295_item	2819513	et	3	main
nüüd	doc_685122975295_item	2819514	et	4	main
ma	doc_685122975295_item	2819515	et	3	main
olen	doc_685122975295_item	2819516	et	3	main
ttü	doc_685122975295_item	2819517	et	4	main
üliõpilane	doc_685122975295_item	2819518	et	3	main
mulle	doc_685122975295_item	2819519	et	4	main
meeldib	doc_685122975295_item	2819520	et	3	main
minu	doc_685122975295_item	2819532	et	3	main
ja	doc_685122975295_item	2819544	et	3	main
ma	doc_685122975295_item	2819547	et	3	main
ma	doc_685122975295_item	2819553	et	3	main
et	doc_685122975294_item	2819451	et	3	main
võimalik	doc_685122975294_item	2819454	et	3	main
kooli	doc_685122975295_item	2819470	et	4	main
mulle	doc_685122975295_item	2819474	et	4	main
et	doc_685122975295_item	2819477	et	3	main
kust	doc_685122975295_item	2819482	et	4	main
siin	doc_685122975295_item	2819521	et	4	main
on	doc_685122975295_item	2819524	et	4	main
sõbralik	doc_685122975295_item	2819525	et	3	main
personaal	doc_685122975295_item	2819526	et	3	main
ja	doc_685122975295_item	2819527	et	3	main
head	doc_685122975295_item	2819528	et	4	main
sõbrad	doc_685122975295_item	2819529	et	3	main
minu	doc_685122975295_item	2819530	et	3	main
on	doc_685122975295_item	2819535	et	4	main
asutus	doc_685122975295_item	2819537	et	4	main
saada	doc_685122975295_item	2819541	et	4	main
kõrgharidus	doc_685122975295_item	2819550	et	3	main
oma	doc_685122975295_item	2819564	et	4	main
haridus	doc_685122975295_item	2819565	et	3	main
kasutada	doc_685122975295_item	2819566	et	3	main
elu	doc_685122975295_item	2819577	et	4	main
minu	doc_685122975295_item	2819578	et	3	main
vanem	doc_685122975295_item	2819584	et	4	main
vend	doc_685122975295_item	2819585	et	3	main
aastal	doc_685122975295_item	2819597	et	3	main
ja	doc_685122975295_item	2819598	et	3	main
sellel	doc_685122975295_item	2819599	et	4	main
aastal	doc_685122975295_item	2819600	et	3	main
ka	doc_685122975295_item	2819601	et	3	main
astunud	doc_685122975295_item	2819602	et	4	main
ttüsse	doc_685122975295_item	2819603	et	4	main
koolis	doc_685122975295_item	2819604	et	4	main
mul	doc_685122975295_item	2819605	et	3	main
olid	doc_685122975295_item	2819606	et	4	main
kanged	doc_685122975295_item	2819607	et	3	main
õppetajad	doc_685122975295_item	2819608	et	4	main
ja	doc_685122975295_item	2819609	et	3	main
mulle	doc_685122975295_item	2819610	et	4	main
meeldi	doc_685122975295_item	2819611	et	4	main
õppida	doc_685122975295_item	2819612	et	3	main
seda	doc_685122975295_item	2819613	et	3	main
aga	doc_685122975295_item	2819614	et	3	main
nad	doc_685122975295_item	2819615	et	3	main
andsid	doc_685122975295_item	2819616	et	4	main
mulle	doc_685122975295_item	2819617	et	4	main
tarku	doc_685122975295_item	2819618	et	3	main
selles	doc_685122975295_item	2819619	et	4	main
õppeaines	doc_685122975295_item	2819620	et	4	main
õppejõud	doc_685122975295_item	2819625	et	4	main
kange	doc_685122975295_item	2819628	et	4	main
aga	doc_685122975295_item	2819629	et	3	main
see	doc_685122975295_item	2819630	et	3	main
mina	doc_685122975296_item	2819640	et	4	main
ja	doc_685122975296_item	2819641	et	3	main
kahekümmne	doc_685122975296_item	2819651	et	4	main
kooli	doc_685122975296_item	2819656	et	4	main
kaitseväkke	doc_685122975296_item	2819663	et	3	main
aastat	doc_685122975296_item	2819673	et	3	main
turvateenuse	doc_685122975296_item	2819676	et	3	main
otsustasin	doc_685122975296_item	2819684	et	3	main
kooli	doc_685122975296_item	2819721	et	4	main
määrata	doc_685122975296_item	2819725	et	4	main
sport	doc_685122975296_item	2819726	et	3	main
välja	doc_685122975296_item	2819735	et	4	main
mul	doc_685122975295_item	2819556	et	3	main
vaja	doc_685122975295_item	2819558	et	4	main
saada	doc_685122975295_item	2819560	et	4	main
kuidas	doc_685122975295_item	2819561	et	3	main
ja	doc_685122975295_item	2819562	et	3	main
kus	doc_685122975295_item	2819563	et	3	main
ma	doc_685122975295_item	2819569	et	3	main
tallinnas	doc_685122975295_item	2819572	et	4	main
ema	doc_685122975295_item	2819581	et	4	main
olen	doc_685122975295_item	2819589	et	3	main
et	doc_685122975295_item	2819622	et	3	main
võib	doc_685122975295_item	2819626	et	3	main
anda	doc_685122975295_item	2819633	et	3	main
eesti	doc_685122975295_item	2819637	et	4	main
keel	doc_685122975295_item	2819638	et	4	main
tervist	doc_685122975296_item	2819643	et	4	main
kõigidele	doc_685122975296_item	2819644	et	4	main
mu	doc_685122975296_item	2819645	et	3	main
on	doc_685122975296_item	2819647	et	4	main
eesnimi	doc_685122975296_item	2819648	et	3	main
olen	doc_685122975296_item	2819650	et	3	main
aastal	doc_685122975296_item	2819657	et	3	main
neli	doc_685122975296_item	2819659	et	3	main
peale	doc_685122975296_item	2819660	et	4	main
läksin	doc_685122975296_item	2819662	et	3	main
pioneeripataljonis	doc_685122975296_item	2819665	et	3	main
demineerimis	doc_685122975296_item	2819666	et	4	main
et	doc_685122975296_item	2819685	et	3	main
ja	doc_685122975296_item	2819689	et	3	main
enam	doc_685122975296_item	2819693	et	4	main
turvatööd	doc_685122975296_item	2819694	et	4	main
teha	doc_685122975296_item	2819695	et	3	main
nii	doc_685122975296_item	2819696	et	3	main
et	doc_685122975296_item	2819697	et	3	main
pean	doc_685122975296_item	2819698	et	4	main
kindlasti	doc_685122975296_item	2819699	et	3	main
õppima	doc_685122975296_item	2819700	et	3	main
minema	doc_685122975296_item	2819701	et	3	main
kusjuures	doc_685122975296_item	2819702	et	3	main
võib	doc_685122975296_item	2819703	et	3	main
öelda	doc_685122975296_item	2819704	et	4	main
et	doc_685122975296_item	2819705	et	3	main
ma	doc_685122975296_item	2819706	et	3	main
isegi	doc_685122975296_item	2819707	et	4	main
puhkasin	doc_685122975296_item	2819708	et	3	main
õpimisest	doc_685122975296_item	2819709	et	4	main
ja	doc_685122975296_item	2819710	et	3	main
olen	doc_685122975296_item	2819711	et	3	main
väga	doc_685122975296_item	2819712	et	3	main
rahul	doc_685122975296_item	2819713	et	4	main
et	doc_685122975296_item	2819714	et	3	main
ma	doc_685122975296_item	2819715	et	3	main
ei	doc_685122975296_item	2819716	et	4	main
läinud	doc_685122975296_item	2819717	et	4	main
õppima	doc_685122975296_item	2819718	et	3	main
kohe	doc_685122975296_item	2819719	et	4	main
peale	doc_685122975296_item	2819720	et	4	main
oma	doc_685122975296_item	2819722	et	4	main
huvidest	doc_685122975296_item	2819723	et	3	main
võin	doc_685122975296_item	2819724	et	3	main
kuid	doc_685122975296_item	2819727	et	4	main
järgmiselt	doc_685122975296_item	2819736	et	4	main
eriti	doc_685122975296_item	2819743	et	3	main
võin	doc_685122975296_item	2819748	et	3	main
pragu	doc_685122975296_item	2819733	et	4	main
näeb	doc_685122975296_item	2819734	et	3	main
kodu	doc_685122975296_item	2819739	et	4	main
jaoks	doc_685122975296_item	2819742	et	4	main
mis	doc_685122975296_item	2819746	et	4	main
valitud	doc_685122975296_item	2819751	et	4	main
eriala	doc_685122975296_item	2819752	et	4	main
kohta	doc_685122975296_item	2819753	et	4	main
perspektiivne	doc_685122975296_item	2819754	et	3	main
ehitatakse	doc_685122975296_item	2819755	et	3	main
palju	doc_685122975296_item	2819756	et	4	main
elu	doc_685122975296_item	2819732	et	4	main
töö	doc_685122975296_item	2819738	et	4	main
ei	doc_685122975296_item	2819744	et	4	main
alati	doc_685122975296_item	2819759	et	4	main
kuid	doc_685122975296_item	2819760	et	4	main
eriti	doc_685122975296_item	2819767	et	3	main
öelda	doc_685122975296_item	2819772	et	4	main
minu	doc_685122975296_item	2819774	et	3	main
see	doc_685122975296_item	2819776	et	3	main
nagu	doc_685122975296_item	2819784	et	3	main
ülikool	doc_685122975296_item	2819785	et	4	main
suured	doc_685122975296_item	2819786	et	3	main
auditooriumid	doc_685122975296_item	2819787	et	3	main
labolatooriumid	doc_685122975296_item	2819788	et	4	main
olen	doc_685122975297_item	2819821	et	3	main
aastat	doc_685122975297_item	2819823	et	3	main
vana	doc_685122975297_item	2819824	et	4	main
pärast	doc_685122975297_item	2819834	et	4	main
astuda	doc_685122975297_item	2819841	et	3	main
sest	doc_685122975297_item	2819842	et	4	main
et	doc_685122975297_item	2819843	et	3	main
lisaks	doc_685122975297_item	2819854	et	4	main
tahaksin	doc_685122975297_item	2819857	et	3	main
mina	doc_685122975297_item	2819861	et	4	main
see	doc_685122975297_item	2819863	et	3	main
ttü	doc_685122975297_item	2819873	et	4	main
ülikool	doc_685122975297_item	2819877	et	4	main
jutustasid	doc_685122975297_item	2819880	et	4	main
ainult	doc_685122975297_item	2819881	et	4	main
positiivsed	doc_685122975297_item	2819882	et	3	main
mõtted	doc_685122975297_item	2819883	et	3	main
palju	doc_685122975297_item	2819922	et	4	main
näitaks	doc_685122975297_item	2819924	et	3	main
ja	doc_685122975297_item	2819928	et	3	main
eesti	doc_685122975297_item	2819938	et	4	main
keeles	doc_685122975297_item	2819939	et	4	main
suhelda	doc_685122975297_item	2819951	et	4	main
ja	doc_685122975297_item	2819952	et	3	main
on	doc_685122975297_item	2819959	et	4	main
aga	doc_685122975297_item	2819963	et	3	main
loodan	doc_685122975297_item	2819965	et	3	main
kursuse	doc_685122975297_item	2819968	et	3	main
ma	doc_685122975297_item	2819970	et	3	main
saan	doc_685122975297_item	2819971	et	4	main
osaliselt	doc_685122975297_item	2819972	et	4	main
rääkida	doc_685122975297_item	2819973	et	3	main
ja	doc_685122975297_item	2819974	et	3	main
ülikoolis	doc_685122975298_item	2820021	et	4	main
eriala	doc_685122975298_item	2820023	et	4	main
huvitanud	doc_685122975298_item	2820031	et	4	main
majandust	doc_685122975298_item	2820039	et	4	main
valin	doc_685122975298_item	2820048	et	3	main
et	doc_685122975298_item	2820053	et	3	main
igav	doc_685122975298_item	2820057	et	3	main
olla	doc_685122975298_item	2820060	et	3	main
tulin	doc_685122975298_item	2820062	et	3	main
et	doc_685122975298_item	2820066	et	3	main
estlased	doc_685122975298_item	2820082	et	4	main
on	doc_685122975298_item	2820083	et	4	main
kirjalik-	doc_685122975298_item	2820117	et	3	main
oskusi	doc_685122975298_item	2820120	et	3	main
essee	doc_685122975299_item	2820122	et	4	main
mina	doc_685122975299_item	2820130	et	4	main
gümnaasium	doc_685122975299_item	2820134	et	3	main
ma	doc_685122975299_item	2820142	et	3	main
pingema	doc_685122975299_item	2820154	et	4	main
pärast	doc_685122975299_item	2820162	et	4	main
ja	doc_685122975299_item	2820166	et	3	main
eriala	doc_685122975299_item	2820171	et	4	main
ei	doc_685122975299_item	2820177	et	4	main
minna	doc_685122975299_item	2820210	et	3	main
kus	doc_685122975299_item	2820221	et	3	main
eesti	doc_685122975299_item	2820226	et	4	main
keele	doc_685122975299_item	2820227	et	4	main
tundilt	doc_685122975299_item	2820228	et	4	main
ma	doc_685122975299_item	2820229	et	3	main
ootan	doc_685122975299_item	2820230	et	3	main
kasulik	doc_685122975299_item	2820231	et	3	main
mina	doc_685122975299_item	2820234	et	4	main
õpeda	doc_685122975299_item	2820236	et	4	main
mina	doc_685122975300_item	2820240	et	4	main
mind	doc_685122975300_item	2820252	et	4	main
aega	doc_685122975296_item	2819740	et	4	main
ma	doc_685122975296_item	2819747	et	3	main
ehitatakse	doc_685122975296_item	2819758	et	3	main
kohta	doc_685122975296_item	2819770	et	4	main
arvates	doc_685122975296_item	2819775	et	4	main
jne	doc_685122975296_item	2819789	et	4	main
mis	doc_685122975296_item	2819796	et	4	main
annab	doc_685122975296_item	2819797	et	3	main
kõrgharidust	doc_685122975296_item	2819800	et	4	main
eesti	doc_685122975296_item	2819801	et	4	main
tööd	doc_685122975296_item	2819805	et	4	main
ja	doc_685122975297_item	2819813	et	3	main
ülikool	doc_685122975297_item	2819814	et	4	main
minu	doc_685122975297_item	2819815	et	3	main
nimi	doc_685122975297_item	2819816	et	3	main
on	doc_685122975297_item	2819817	et	4	main
eesnimi	doc_685122975297_item	2819818	et	3	main
perekonnanimi	doc_685122975297_item	2819819	et	3	main
ma	doc_685122975297_item	2819820	et	3	main
öelda	doc_685122975296_item	2819749	et	4	main
ja	doc_685122975296_item	2819757	et	3	main
mulle	doc_685122975296_item	2819764	et	4	main
meeldib	doc_685122975296_item	2819765	et	3	main
ehitustööd	doc_685122975296_item	2819766	et	4	main
proekteerimine	doc_685122975296_item	2819768	et	4	main
ttü	doc_685122975296_item	2819769	et	4	main
mis	doc_685122975296_item	2819780	et	4	main
üldse	doc_685122975296_item	2819781	et	3	main
välja	doc_685122975296_item	2819782	et	4	main
näeb	doc_685122975296_item	2819783	et	3	main
ttü	doc_685122975296_item	2819792	et	4	main
ainuke	doc_685122975296_item	2819794	et	4	main
õppeasutus	doc_685122975296_item	2819795	et	4	main
tehnilist	doc_685122975296_item	2819799	et	3	main
suulist	doc_685122975296_item	2819809	et	4	main
ülesandeid	doc_685122975296_item	2819810	et	3	main
essee	doc_685122975297_item	2819811	et	4	main
elan	doc_685122975297_item	2819825	et	3	main
mina	doc_685122975297_item	2819829	et	4	main
tallinna	doc_685122975297_item	2819838	et	4	main
tean	doc_685122975297_item	2819846	et	3	main
hea	doc_685122975297_item	2819850	et	4	main
inzeneerina	doc_685122975297_item	2819858	et	4	main
isa	doc_685122975297_item	2819862	et	4	main
minu	doc_685122975297_item	2819866	et	3	main
on	doc_685122975297_item	2819874	et	4	main
hea	doc_685122975297_item	2819876	et	4	main
minu	doc_685122975297_item	2819878	et	3	main
informatika	doc_685122975297_item	2819927	et	4	main
eesti	doc_685122975297_item	2819931	et	4	main
laendada	doc_685122975297_item	2819940	et	4	main
et	doc_685122975297_item	2819941	et	3	main
keel	doc_685122975297_item	2819944	et	4	main
teisest	doc_685122975297_item	2819955	et	4	main
ma	doc_685122975297_item	2819964	et	3	main
lõpuks	doc_685122975297_item	2819969	et	4	main
järve	doc_685122975298_item	2820010	et	4	main
väga	doc_685122975298_item	2820033	et	3	main
astusin	doc_685122975298_item	2820037	et	3	main
ma	doc_685122975298_item	2820051	et	3	main
parem	doc_685122975298_item	2820055	et	4	main
mulle	doc_685122975298_item	2820076	et	4	main
praktikat	doc_685122975298_item	2820113	et	3	main
ja	doc_685122975298_item	2820118	et	3	main
mina	doc_685122975299_item	2820123	et	4	main
ülikool	doc_685122975299_item	2820125	et	4	main
mina	doc_685122975299_item	2820126	et	4	main
elan	doc_685122975299_item	2820127	et	3	main
täpselt	doc_685122975299_item	2820141	et	4	main
ttüst	doc_685122975299_item	2820155	et	4	main
energeetikast	doc_685122975299_item	2820156	et	4	main
radiost	doc_685122975299_item	2820165	et	3	main
pärast	doc_685122975299_item	2820211	et	4	main
seal	doc_685122975299_item	2820215	et	4	main
ja	doc_685122975299_item	2820224	et	3	main
keel	doc_685122975299_item	2820238	et	4	main
ma	doc_685122975300_item	2820256	et	3	main
valima	doc_685122975300_item	2820258	et	3	main
tegin	doc_685122975300_item	2820279	et	3	main
ja	doc_685122975300_item	2820281	et	3	main
tahan	doc_685122975300_item	2820288	et	3	main
valisin	doc_685122975300_item	2820293	et	3	main
minu	doc_685122975300_item	2820295	et	3	main
on	doc_685122975300_item	2820298	et	4	main
rohkem	doc_685122975300_item	2820307	et	4	main
kui	doc_685122975300_item	2820308	et	3	main
minu	doc_685122975300_item	2820309	et	3	main
pangaautomaat	doc_685122975300_item	2820328	et	4	main
ja	doc_685122975301_item	2820344	et	3	main
saada	doc_685122975301_item	2820362	et	4	main
kõrgharidus	doc_685122975301_item	2820363	et	3	main
ülikool	doc_685122975301_item	2820367	et	4	main
ma	doc_685122975301_item	2820369	et	3	main
asuvad	doc_685122975301_item	2820383	et	4	main
ja	doc_685122975301_item	2820385	et	3	main
staadion	doc_685122975301_item	2820386	et	3	main
saab	doc_685122975301_item	2820421	et	3	main
väga	doc_685122975301_item	2820431	et	3	main
ka	doc_685122975301_item	2820436	et	3	main
fittest	doc_685122975301_item	2820438	et	4	main
terviseklubis	doc_685122975301_item	2820445	et	3	main
mitte	doc_685122975296_item	2819761	et	3	main
ainult	doc_685122975296_item	2819762	et	4	main
ülikool	doc_685122975296_item	2819779	et	4	main
põhimõtteliselt	doc_685122975296_item	2819791	et	4	main
on	doc_685122975296_item	2819793	et	4	main
tõsist	doc_685122975296_item	2819798	et	4	main
tõsist	doc_685122975296_item	2819804	et	4	main
palju	doc_685122975296_item	2819806	et	4	main
gramaatika	doc_685122975296_item	2819807	et	4	main
ning	doc_685122975296_item	2819808	et	3	main
sillamäel	doc_685122975297_item	2819826	et	3	main
kannuka	doc_685122975297_item	2819832	et	4	main
kool	doc_685122975297_item	2819833	et	4	main
kooli	doc_685122975297_item	2819835	et	4	main
ma	doc_685122975297_item	2819836	et	3	main
tahaksin	doc_685122975297_item	2819837	et	3	main
nagu	doc_685122975297_item	2819844	et	3	main
selle	doc_685122975297_item	2819855	et	4	main
saada	doc_685122975297_item	2819859	et	4	main
põhjus	doc_685122975297_item	2819865	et	4	main
sellel	doc_685122975297_item	2819868	et	4	main
ülikoolis	doc_685122975297_item	2819869	et	4	main
nagu	doc_685122975297_item	2819870	et	3	main
ma	doc_685122975297_item	2819871	et	3	main
tean	doc_685122975297_item	2819872	et	3	main
väga	doc_685122975297_item	2819875	et	3	main
üheksateist	doc_685122975297_item	2819822	et	4	main
aastal	doc_685122975297_item	2819828	et	3	main
lõpetasin	doc_685122975297_item	2819830	et	3	main
ma	doc_685122975297_item	2819845	et	3	main
väga	doc_685122975297_item	2819849	et	3	main
ülikool	doc_685122975297_item	2819853	et	4	main
on	doc_685122975297_item	2819864	et	4	main
astmise	doc_685122975297_item	2819867	et	4	main
sõbra	doc_685122975297_item	2819879	et	3	main
ttüst	doc_685122975297_item	2819884	et	4	main
ma	doc_685122975297_item	2819885	et	3	main
praegu	doc_685122975297_item	2819886	et	3	main
näen	doc_685122975297_item	2819887	et	3	main
et	doc_685122975297_item	2819888	et	3	main
see	doc_685122975297_item	2819889	et	3	main
on	doc_685122975297_item	2819890	et	4	main
tõesti	doc_685122975297_item	2819891	et	3	main
kõik	doc_685122975297_item	2819892	et	4	main
studentid	doc_685122975297_item	2819893	et	4	main
on	doc_685122975297_item	2819894	et	4	main
seltivad	doc_685122975297_item	2819895	et	4	main
sõbralikud	doc_685122975297_item	2819896	et	3	main
lõbusevad	doc_685122975297_item	2819897	et	4	main
õppimine	doc_685122975297_item	2819898	et	4	main
ttü-s	doc_685122975297_item	2819899	et	3	main
annab	doc_685122975297_item	2819900	et	3	main
mulle	doc_685122975297_item	2819901	et	4	main
eriala	doc_685122975297_item	2819902	et	4	main
ja	doc_685122975297_item	2819903	et	3	main
kõrgharidus	doc_685122975297_item	2819904	et	3	main
et	doc_685122975297_item	2819905	et	3	main
selle	doc_685122975297_item	2819906	et	4	main
võtta	doc_685122975297_item	2819907	et	3	main
siis	doc_685122975297_item	2819908	et	3	main
ma	doc_685122975297_item	2819909	et	3	main
pean	doc_685122975297_item	2819910	et	4	main
hea	doc_685122975297_item	2819911	et	4	main
õppima	doc_685122975297_item	2819912	et	3	main
ja	doc_685122975297_item	2819913	et	3	main
muidugi	doc_685122975297_item	2819914	et	4	main
eesti	doc_685122975297_item	2819915	et	4	main
keel	doc_685122975297_item	2819916	et	4	main
teadma	doc_685122975297_item	2819917	et	3	main
praegu	doc_685122975297_item	2819918	et	3	main
mul	doc_685122975297_item	2819919	et	3	main
on	doc_685122975297_item	2819920	et	4	main
aine	doc_685122975297_item	2819923	et	4	main
matemaatika	doc_685122975297_item	2819925	et	4	main
eesti	doc_685122975297_item	2819929	et	4	main
tundides	doc_685122975297_item	2819933	et	3	main
oskust	doc_685122975297_item	2819937	et	3	main
aru	doc_685122975297_item	2819953	et	4	main
problem	doc_685122975297_item	2819960	et	4	main
ühe	doc_685122975297_item	2819967	et	4	main
kaldal	doc_685122975298_item	2820011	et	3	main
seal	doc_685122975298_item	2820026	et	4	main
1	doc_685122975298_item	2820027	et	2	main
aasta	doc_685122975298_item	2820028	et	4	main
aga	doc_685122975298_item	2820029	et	3	main
ei	doc_685122975298_item	2820030	et	4	main
sel	doc_685122975298_item	2820035	et	3	main
öelda	doc_685122975298_item	2820045	et	4	main
miks	doc_685122975298_item	2820046	et	4	main
ma	doc_685122975298_item	2820047	et	3	main
võib	doc_685122975298_item	2820059	et	3	main
majandust	doc_685122975298_item	2820064	et	4	main
ema	doc_685122975298_item	2820068	et	4	main
töötab	doc_685122975298_item	2820069	et	3	main
on	doc_685122975298_item	2820073	et	4	main
praktida	doc_685122975298_item	2820115	et	4	main
keel	doc_685122975297_item	2819930	et	4	main
keele	doc_685122975297_item	2819932	et	4	main
tahaksin	doc_685122975297_item	2819935	et	3	main
oma	doc_685122975297_item	2819936	et	4	main
eesti	doc_685122975297_item	2819943	et	4	main
saada	doc_685122975297_item	2819954	et	4	main
minu	doc_685122975297_item	2819961	et	3	main
et	doc_685122975297_item	2819966	et	3	main
eesti	doc_685122975297_item	2819976	et	4	main
keeles	doc_685122975297_item	2819977	et	4	main
probleemita	doc_685122975297_item	2819978	et	3	main
lõpuks	doc_685122975297_item	2819979	et	4	main
ma	doc_685122975297_item	2819980	et	3	main
tahan	doc_685122975297_item	2819981	et	3	main
öelda	doc_685122975297_item	2819982	et	4	main
et	doc_685122975297_item	2819983	et	3	main
mul	doc_685122975297_item	2819984	et	3	main
on	doc_685122975297_item	2819985	et	4	main
hea	doc_685122975297_item	2819986	et	4	main
et	doc_685122975297_item	2819988	et	3	main
ma	doc_685122975297_item	2819989	et	3	main
astusin	doc_685122975297_item	2819990	et	3	main
ja	doc_685122975297_item	2819991	et	3	main
valesin	doc_685122975297_item	2819992	et	4	main
meel	doc_685122975297_item	2819987	et	4	main
ttü	doc_685122975297_item	2819993	et	4	main
essee	doc_685122975298_item	2819994	et	4	main
mina	doc_685122975298_item	2819995	et	4	main
ja	doc_685122975298_item	2819996	et	3	main
ülikool	doc_685122975298_item	2819997	et	4	main
minu	doc_685122975298_item	2819998	et	3	main
nimi	doc_685122975298_item	2819999	et	3	main
on	doc_685122975298_item	2820000	et	4	main
eesnimi	doc_685122975298_item	2820001	et	3	main
perekonnanimi	doc_685122975298_item	2820002	et	3	main
ma	doc_685122975298_item	2820003	et	3	main
olen	doc_685122975298_item	2820004	et	3	main
pärit	doc_685122975298_item	2820005	et	3	main
kallastelt	doc_685122975298_item	2820006	et	4	main
väga	doc_685122975297_item	2819921	et	3	main
füüsika	doc_685122975297_item	2819926	et	4	main
ma	doc_685122975297_item	2819934	et	3	main
minu	doc_685122975297_item	2819942	et	3	main
sai	doc_685122975297_item	2819945	et	4	main
paremaks	doc_685122975297_item	2819946	et	4	main
sest	doc_685122975297_item	2819947	et	4	main
et	doc_685122975297_item	2819948	et	3	main
ma	doc_685122975297_item	2819949	et	3	main
tahaksin	doc_685122975297_item	2819950	et	3	main
eestlastest	doc_685122975297_item	2819956	et	4	main
praegu	doc_685122975297_item	2819957	et	3	main
see	doc_685122975297_item	2819958	et	3	main
jaoks	doc_685122975297_item	2819962	et	4	main
suhelda	doc_685122975297_item	2819975	et	4	main
asub	doc_685122975298_item	2820008	et	3	main
peipsi	doc_685122975298_item	2820009	et	4	main
kallaste	doc_685122975298_item	2820013	et	4	main
tartu	doc_685122975298_item	2820020	et	4	main
ta	doc_685122975298_item	2820007	et	4	main
õpisin	doc_685122975298_item	2820012	et	4	main
keskkoolis	doc_685122975298_item	2820014	et	4	main
kuni	doc_685122975298_item	2820015	et	3	main
pärast	doc_685122975298_item	2820016	et	4	main
ma	doc_685122975298_item	2820017	et	3	main
esitasin	doc_685122975298_item	2820018	et	3	main
dokumendid	doc_685122975298_item	2820019	et	3	main
matemaatika	doc_685122975298_item	2820022	et	4	main
ja	doc_685122975298_item	2820024	et	3	main
õpisin	doc_685122975298_item	2820025	et	4	main
maatemaatikat	doc_685122975298_item	2820032	et	3	main
ttüs	doc_685122975298_item	2820038	et	4	main
õppida	doc_685122975298_item	2820040	et	3	main
majandusteaduskond	doc_685122975298_item	2820049	et	3	main
kui	doc_685122975298_item	2820056	et	3	main
ma	doc_685122975298_item	2820061	et	3	main
õppida	doc_685122975298_item	2820063	et	3	main
sellepärast	doc_685122975298_item	2820065	et	3	main
minu	doc_685122975298_item	2820067	et	3	main
raamatupidajaks	doc_685122975298_item	2820070	et	3	main
tehtikaülikool	doc_685122975298_item	2820072	et	4	main
väga	doc_685122975298_item	2820074	et	3	main
palju	doc_685122975298_item	2820077	et	4	main
tahan	doc_685122975298_item	2820114	et	3	main
oma	doc_685122975298_item	2820116	et	4	main
suulise	doc_685122975298_item	2820119	et	4	main
tänan	doc_685122975298_item	2820121	et	3	main
ja	doc_685122975299_item	2820124	et	3	main
lõpetasin	doc_685122975299_item	2820131	et	3	main
ole	doc_685122975299_item	2820139	et	4	main
hea	doc_685122975299_item	2820140	et	4	main
eksaamid	doc_685122975299_item	2820145	et	3	main
ole	doc_685122975299_item	2820147	et	4	main
ma	doc_685122975299_item	2820157	et	3	main
tulin	doc_685122975299_item	2820158	et	3	main
õppima	doc_685122975299_item	2820159	et	3	main
energetikast	doc_685122975299_item	2820160	et	4	main
selle	doc_685122975299_item	2820161	et	4	main
kes	doc_685122975299_item	2820218	et	4	main
aidata	doc_685122975299_item	2820219	et	4	main
sulle	doc_685122975299_item	2820220	et	3	main
ja	doc_685122975298_item	2820034	et	3	main
aastal	doc_685122975298_item	2820036	et	3	main
ma	doc_685122975298_item	2820041	et	3	main
ei	doc_685122975298_item	2820042	et	4	main
oska	doc_685122975298_item	2820043	et	4	main
praegu	doc_685122975298_item	2820044	et	3	main
aga	doc_685122975298_item	2820050	et	3	main
arvan	doc_685122975298_item	2820052	et	3	main
see	doc_685122975298_item	2820054	et	3	main
puhasmatemaatika	doc_685122975298_item	2820058	et	4	main
tallinna	doc_685122975298_item	2820071	et	4	main
meeldis	doc_685122975298_item	2820075	et	3	main
inimesed	doc_685122975298_item	2820078	et	3	main
on	doc_685122975298_item	2820079	et	4	main
venelased	doc_685122975298_item	2820080	et	3	main
ja	doc_685122975298_item	2820081	et	3	main
ka	doc_685122975298_item	2820084	et	3	main
väga	doc_685122975298_item	2820085	et	3	main
sõbralikud	doc_685122975298_item	2820086	et	3	main
ja	doc_685122975298_item	2820087	et	3	main
lõbusad	doc_685122975298_item	2820088	et	3	main
ma	doc_685122975298_item	2820089	et	3	main
juba	doc_685122975298_item	2820090	et	3	main
tutvusin	doc_685122975298_item	2820091	et	3	main
kõikidega	doc_685122975298_item	2820092	et	4	main
oma	doc_685122975298_item	2820093	et	4	main
kursis	doc_685122975298_item	2820094	et	3	main
kõik	doc_685122975298_item	2820095	et	4	main
on	doc_685122975298_item	2820096	et	4	main
huvitavad	doc_685122975298_item	2820097	et	4	main
tartus	doc_685122975298_item	2820098	et	3	main
ma	doc_685122975298_item	2820099	et	3	main
õpisin	doc_685122975298_item	2820100	et	4	main
eesti	doc_685122975298_item	2820101	et	4	main
keeles	doc_685122975298_item	2820102	et	4	main
aga	doc_685122975298_item	2820103	et	3	main
ei	doc_685122975298_item	2820104	et	4	main
tea	doc_685122975298_item	2820105	et	4	main
keelt	doc_685122975298_item	2820106	et	4	main
väga	doc_685122975298_item	2820107	et	3	main
hästi	doc_685122975298_item	2820108	et	3	main
loengutelt	doc_685122975298_item	2820109	et	4	main
ma	doc_685122975298_item	2820110	et	3	main
ootan	doc_685122975298_item	2820111	et	3	main
rohkem	doc_685122975298_item	2820112	et	4	main
vene	doc_685122975299_item	2820133	et	4	main
ma	doc_685122975299_item	2820136	et	3	main
sooritasin	doc_685122975299_item	2820143	et	3	main
lugesin	doc_685122975299_item	2820167	et	3	main
et	doc_685122975299_item	2820169	et	3	main
on	doc_685122975299_item	2820172	et	4	main
see	doc_685122975299_item	2820175	et	3	main
eriala	doc_685122975299_item	2820176	et	4	main
töö	doc_685122975299_item	2820178	et	4	main
palju	doc_685122975299_item	2820179	et	4	main
inemest	doc_685122975299_item	2820180	et	4	main
energetikud	doc_685122975299_item	2820181	et	4	main
on	doc_685122975299_item	2820182	et	4	main
nõutud	doc_685122975299_item	2820183	et	4	main
eriala	doc_685122975299_item	2820184	et	4	main
kuidas	doc_685122975299_item	2820185	et	3	main
ma	doc_685122975299_item	2820186	et	3	main
tulisin	doc_685122975299_item	2820187	et	4	main
ttüs	doc_685122975299_item	2820188	et	4	main
esmaspäeval	doc_685122975299_item	2820189	et	3	main
ja	doc_685122975299_item	2820190	et	3	main
ma	doc_685122975299_item	2820191	et	3	main
näisin	doc_685122975299_item	2820192	et	3	main
seelle	doc_685122975299_item	2820193	et	4	main
hoone	doc_685122975299_item	2820194	et	4	main
esimes	doc_685122975299_item	2820195	et	4	main
kord	doc_685122975299_item	2820196	et	4	main
ma	doc_685122975299_item	2820197	et	3	main
olin	doc_685122975299_item	2820198	et	3	main
ei	doc_685122975299_item	2820199	et	4	main
ole	doc_685122975299_item	2820200	et	4	main
hea	doc_685122975299_item	2820201	et	4	main
muljed	doc_685122975299_item	2820202	et	3	main
see	doc_685122975299_item	2820203	et	3	main
pärast	doc_685122975299_item	2820204	et	4	main
et	doc_685122975299_item	2820205	et	3	main
ma	doc_685122975299_item	2820206	et	3	main
ei	doc_685122975299_item	2820207	et	4	main
tea	doc_685122975299_item	2820208	et	4	main
kuhu	doc_685122975299_item	2820209	et	3	main
ida-virumaal	doc_685122975299_item	2820128	et	4	main
püssis	doc_685122975299_item	2820129	et	3	main
kiviõli	doc_685122975299_item	2820132	et	4	main
gümnaasium	doc_685122975299_item	2820135	et	3	main
lõpetasin	doc_685122975299_item	2820137	et	3	main
ei	doc_685122975299_item	2820138	et	4	main
minu	doc_685122975299_item	2820144	et	3	main
ei	doc_685122975299_item	2820146	et	4	main
tore	doc_685122975299_item	2820148	et	3	main
aga	doc_685122975299_item	2820149	et	3	main
mulle	doc_685122975299_item	2820150	et	4	main
see	doc_685122975299_item	2820151	et	3	main
aitab	doc_685122975299_item	2820152	et	3	main
et	doc_685122975299_item	2820153	et	3	main
et	doc_685122975299_item	2820163	et	3	main
kuulsin	doc_685122975299_item	2820164	et	3	main
ajalehest	doc_685122975299_item	2820168	et	4	main
see	doc_685122975299_item	2820170	et	3	main
hea	doc_685122975299_item	2820173	et	4	main
ja	doc_685122975299_item	2820174	et	3	main
palju	doc_685122975299_item	2820216	et	4	main
inimesed	doc_685122975299_item	2820217	et	3	main
asub	doc_685122975299_item	2820222	et	3	main
hoone	doc_685122975299_item	2820223	et	4	main
ruum	doc_685122975299_item	2820225	et	3	main
tahan	doc_685122975299_item	2820235	et	3	main
eesti	doc_685122975299_item	2820237	et	4	main
inimesi	doc_685122975300_item	2820304	et	4	main
kümme	doc_685122975300_item	2820305	et	3	main
et	doc_685122975300_item	2820313	et	3	main
linn	doc_685122975300_item	2820321	et	3	main
on	doc_685122975300_item	2820323	et	4	main
kõik	doc_685122975300_item	2820324	et	4	main
kohvik	doc_685122975300_item	2820325	et	3	main
sööklad	doc_685122975300_item	2820326	et	3	main
kauplused	doc_685122975300_item	2820327	et	3	main
aitavad	doc_685122975300_item	2820336	et	4	main
eesti	doc_685122975300_item	2820340	et	4	main
essee	doc_685122975301_item	2820342	et	4	main
on	doc_685122975301_item	2820348	et	4	main
praegu	doc_685122975301_item	2820351	et	3	main
õpin	doc_685122975301_item	2820353	et	3	main
mulle	doc_685122975301_item	2820356	et	4	main
meeldib	doc_685122975301_item	2820357	et	3	main
õppida	doc_685122975301_item	2820358	et	3	main
ja	doc_685122975301_item	2820359	et	3	main
ma	doc_685122975301_item	2820360	et	3	main
tahaksin	doc_685122975301_item	2820361	et	3	main
ja	doc_685122975301_item	2820372	et	3	main
sooritasin	doc_685122975301_item	2820374	et	3	main
asuvad	doc_685122975301_item	2820388	et	4	main
mulle	doc_685122975299_item	2820212	et	4	main
meeldib	doc_685122975299_item	2820213	et	3	main
ttüs	doc_685122975299_item	2820214	et	4	main
teadmisi	doc_685122975299_item	2820232	et	4	main
essee	doc_685122975300_item	2820239	et	4	main
ja	doc_685122975300_item	2820241	et	3	main
ülikool	doc_685122975300_item	2820242	et	4	main
minu	doc_685122975300_item	2820243	et	3	main
nimi	doc_685122975300_item	2820244	et	3	main
on	doc_685122975300_item	2820245	et	4	main
eesnimi	doc_685122975300_item	2820246	et	3	main
2006	doc_685122975300_item	2820247	et	2	main
aastal	doc_685122975300_item	2820248	et	3	main
lõpetasin	doc_685122975300_item	2820249	et	3	main
huvitab	doc_685122975300_item	2820253	et	3	main
elemendi	doc_685122975300_item	2820280	et	3	main
töid	doc_685122975300_item	2820285	et	3	main
saada	doc_685122975300_item	2820289	et	4	main
sellepärast	doc_685122975300_item	2820291	et	3	main
siin	doc_685122975300_item	2820300	et	4	main
õpib	doc_685122975300_item	2820301	et	3	main
väga	doc_685122975300_item	2820302	et	3	main
palju	doc_685122975300_item	2820303	et	4	main
ei	doc_685122975300_item	2820314	et	4	main
ttü	doc_685122975300_item	2820317	et	4	main
jnne	doc_685122975300_item	2820329	et	4	main
ma	doc_685122975300_item	2820330	et	3	main
suhelda	doc_685122975300_item	2820339	et	4	main
ülikool	doc_685122975301_item	2820345	et	4	main
eesnimi	doc_685122975301_item	2820349	et	3	main
ma	doc_685122975301_item	2820352	et	3	main
tallinna	doc_685122975301_item	2820354	et	4	main
tehnikaülikoolis	doc_685122975301_item	2820355	et	4	main
valin	doc_685122975301_item	2820365	et	3	main
ma	doc_685122975301_item	2820373	et	3	main
pakub	doc_685122975301_item	2820377	et	3	main
mitmekesiseid	doc_685122975301_item	2820379	et	4	main
sportivõimalusi	doc_685122975301_item	2820380	et	4	main
mustamäe	doc_685122975301_item	2820381	et	3	main
korv-	doc_685122975301_item	2820425	et	3	main
tennist	doc_685122975301_item	2820428	et	3	main
muud	doc_685122975301_item	2820433	et	4	main
asub	doc_685122975301_item	2820435	et	3	main
kus	doc_685122975301_item	2820439	et	3	main
saab	doc_685122975301_item	2820440	et	3	main
tegeleda	doc_685122975301_item	2820441	et	3	main
ja	doc_685122975301_item	2820443	et	3	main
spinninguga	doc_685122975301_item	2820444	et	3	main
on	doc_685122975301_item	2820446	et	4	main
kontrollida	doc_685122975301_item	2820448	et	4	main
vormi	doc_685122975301_item	2820451	et	4	main
solaariumis	doc_685122975301_item	2820461	et	3	main
ttü	doc_685122975301_item	2820463	et	4	main
campuse	doc_685122975301_item	2820470	et	4	main
paari	doc_685122975301_item	2820472	et	4	main
minuti	doc_685122975301_item	2820473	et	3	main
ttü	doc_685122975301_item	2820476	et	4	main
ja	doc_685122975301_item	2820478	et	3	main
kõikjal	doc_685122975301_item	2820486	et	3	main
tore	doc_685122975301_item	2820488	et	3	main
näiteks	doc_685122975301_item	2820493	et	4	main
liiga	doc_685122975301_item	2820496	et	4	main
kallis	doc_685122975301_item	2820497	et	4	main
aladel	doc_685122975301_item	2820511	et	3	main
mitmeid	doc_685122975301_item	2820514	et	4	main
suurem	doc_685122975301_item	2820516	et	4	main
tuhat	doc_685122975301_item	2820529	et	4	main
krooni	doc_685122975301_item	2820530	et	4	main
tähendab	doc_685122975301_item	2820534	et	3	main
kümnes	doc_685122975301_item	2820557	et	4	main
ülikool	doc_685122975302_item	2820563	et	4	main
nimi	doc_685122975302_item	2820565	et	3	main
eesnimi	doc_685122975302_item	2820567	et	3	main
elada	doc_685122975302_item	2820581	et	3	main
on	doc_685122975302_item	2820619	et	4	main
ja	doc_685122975299_item	2820233	et	3	main
gümnaasiumi	doc_685122975300_item	2820250	et	4	main
hõbemedaliga	doc_685122975300_item	2820251	et	3	main
õppimine	doc_685122975300_item	2820254	et	4	main
edasi	doc_685122975300_item	2820260	et	3	main
õppida	doc_685122975300_item	2820261	et	3	main
olin	doc_685122975300_item	2820262	et	3	main
kindel	doc_685122975300_item	2820263	et	3	main
et	doc_685122975300_item	2820264	et	3	main
see	doc_685122975300_item	2820265	et	3	main
peab	doc_685122975300_item	2820266	et	4	main
olema	doc_685122975300_item	2820267	et	4	main
ehituseriala	doc_685122975300_item	2820268	et	4	main
mul	doc_685122975300_item	2820269	et	3	main
on	doc_685122975300_item	2820270	et	4	main
suur	doc_685122975300_item	2820271	et	3	main
kogemus	doc_685122975300_item	2820272	et	3	main
töötamas	doc_685122975300_item	2820273	et	3	main
ehitusel	doc_685122975300_item	2820274	et	4	main
ja	doc_685122975300_item	2820275	et	3	main
e-betoonelemendis	doc_685122975300_item	2820276	et	3	main
kus	doc_685122975300_item	2820277	et	3	main
ma	doc_685122975300_item	2820278	et	3	main
suvel	doc_685122975300_item	2820255	et	3	main
pidin	doc_685122975300_item	2820257	et	3	main
kus	doc_685122975300_item	2820259	et	3	main
veel	doc_685122975300_item	2820282	et	4	main
palju	doc_685122975300_item	2820283	et	4	main
tulevikus	doc_685122975300_item	2820286	et	4	main
meelest	doc_685122975300_item	2820296	et	4	main
ttü	doc_685122975300_item	2820297	et	4	main
suurepärane	doc_685122975300_item	2820299	et	4	main
koolis	doc_685122975300_item	2820310	et	4	main
natuke	doc_685122975300_item	2820311	et	4	main
kurb	doc_685122975300_item	2820312	et	3	main
ootan	doc_685122975300_item	2820331	et	3	main
eesti	doc_685122975300_item	2820332	et	4	main
loengutelt	doc_685122975300_item	2820333	et	4	main
et	doc_685122975300_item	2820334	et	3	main
nemad	doc_685122975300_item	2820335	et	3	main
vabalt	doc_685122975300_item	2820338	et	4	main
keeles	doc_685122975300_item	2820341	et	4	main
mina	doc_685122975301_item	2820343	et	4	main
minu	doc_685122975301_item	2820346	et	3	main
perekonnanimi	doc_685122975301_item	2820350	et	3	main
see	doc_685122975301_item	2820366	et	3	main
sest	doc_685122975301_item	2820368	et	4	main
ttü	doc_685122975301_item	2820376	et	4	main
ka	doc_685122975301_item	2820378	et	3	main
linnakus	doc_685122975301_item	2820382	et	4	main
spordihoone	doc_685122975301_item	2820384	et	4	main
kus	doc_685122975301_item	2820387	et	3	main
täismõõtmetega	doc_685122975301_item	2820389	et	4	main
jalgpalliväljak	doc_685122975301_item	2820390	et	3	main
kergejõustikuga	doc_685122975301_item	2820422	et	3	main
sulg-	doc_685122975301_item	2820424	et	3	main
jalgpalli	doc_685122975301_item	2820427	et	4	main
ja	doc_685122975301_item	2820430	et	3	main
arvutuskeskuse	doc_685122975301_item	2820484	et	3	main
kõrgharidus	doc_685122975301_item	2820494	et	3	main
ei	doc_685122975301_item	2820501	et	4	main
väiksem	doc_685122975301_item	2820503	et	4	main
kui	doc_685122975301_item	2820504	et	3	main
õppevahenditeks	doc_685122975301_item	2820520	et	3	main
veel	doc_685122975301_item	2820526	et	4	main
õppekoha	doc_685122975301_item	2820532	et	4	main
minimaalselt	doc_685122975301_item	2820538	et	4	main
leibkondade	doc_685122975301_item	2820546	et	3	main
kulutusi	doc_685122975301_item	2820552	et	4	main
kanda	doc_685122975301_item	2820554	et	4	main
üksnes	doc_685122975301_item	2820555	et	3	main
iga	doc_685122975301_item	2820556	et	4	main
on	doc_685122975302_item	2820566	et	4	main
üheksateistkümne	doc_685122975302_item	2820569	et	4	main
ja	doc_685122975302_item	2820583	et	3	main
ttü	doc_685122975302_item	2820618	et	4	main
kõige	doc_685122975302_item	2820620	et	4	main
parem	doc_685122975302_item	2820621	et	4	main
omandamise	doc_685122975302_item	2820623	et	4	main
jaoks	doc_685122975302_item	2820624	et	4	main
selle	doc_685122975302_item	2820638	et	4	main
on	doc_685122975302_item	2820642	et	4	main
ei	doc_685122975302_item	2820656	et	4	main
on	doc_685122975302_item	2820661	et	4	main
vajalik	doc_685122975302_item	2820662	et	3	main
struktuur	doc_685122975302_item	2820663	et	3	main
riigis	doc_685122975302_item	2820664	et	3	main
muljedest	doc_685122975302_item	2820677	et	4	main
on	doc_685122975302_item	2820680	et	4	main
positiivsed	doc_685122975302_item	2820682	et	3	main
õpetajad	doc_685122975302_item	2820683	et	4	main
saadavad	doc_685122975302_item	2820687	et	4	main
et	doc_685122975302_item	2820698	et	3	main
juhtuda	doc_685122975302_item	2820701	et	3	main
hästi	doc_685122975302_item	2820704	et	3	main
ülikool	doc_685122975303_item	2820709	et	4	main
ameti	doc_685122975303_item	2820732	et	3	main
kõige	doc_685122975303_item	2820740	et	4	main
linna	doc_685122975303_item	2820748	et	4	main
sellepärast	doc_685122975303_item	2820770	et	3	main
teaduskond	doc_685122975303_item	2820773	et	3	main
tulin	doc_685122975303_item	2820776	et	3	main
et	doc_685122975303_item	2820784	et	3	main
ei	doc_685122975303_item	2820787	et	4	main
erinevaid	doc_685122975300_item	2820284	et	4	main
ma	doc_685122975300_item	2820287	et	3	main
inseneriks	doc_685122975300_item	2820290	et	3	main
ma	doc_685122975300_item	2820292	et	3	main
ehitusteaduskonna	doc_685122975300_item	2820294	et	4	main
korda	doc_685122975300_item	2820306	et	4	main
ole	doc_685122975300_item	2820315	et	4	main
klassijuhatajat	doc_685122975300_item	2820316	et	3	main
on	doc_685122975300_item	2820318	et	4	main
nagu	doc_685122975300_item	2820319	et	3	main
väike	doc_685122975300_item	2820320	et	4	main
seal	doc_685122975300_item	2820322	et	4	main
mind	doc_685122975300_item	2820337	et	4	main
nimi	doc_685122975301_item	2820347	et	3	main
ma	doc_685122975301_item	2820364	et	3	main
huvitun	doc_685122975301_item	2820370	et	3	main
matemaatika	doc_685122975301_item	2820371	et	4	main
eksam	doc_685122975301_item	2820375	et	3	main
ja	doc_685122975301_item	2820391	et	3	main
jooksurajad	doc_685122975301_item	2820392	et	4	main
kaasaegses	doc_685122975301_item	2820393	et	3	main
spordihoones	doc_685122975301_item	2820394	et	4	main
on	doc_685122975301_item	2820395	et	4	main
jooksurada	doc_685122975301_item	2820396	et	4	main
kolm	doc_685122975301_item	2820397	et	3	main
treeningu-	doc_685122975301_item	2820398	et	3	main
ja	doc_685122975301_item	2820399	et	3	main
üks	doc_685122975301_item	2820400	et	3	main
võistlusväljak	doc_685122975301_item	2820401	et	3	main
pallimängudeks	doc_685122975301_item	2820402	et	3	main
kaks	doc_685122975301_item	2820403	et	3	main
saali	doc_685122975301_item	2820404	et	4	main
aeroobika	doc_685122975301_item	2820405	et	4	main
tantsu	doc_685122975301_item	2820406	et	4	main
ja	doc_685122975301_item	2820407	et	3	main
võimlemise	doc_685122975301_item	2820408	et	4	main
jaoks	doc_685122975301_item	2820409	et	4	main
kaks	doc_685122975301_item	2820410	et	3	main
seinatenniseväljakut	doc_685122975301_item	2820411	et	3	main
kaks	doc_685122975301_item	2820412	et	3	main
badmintoniplatsi	doc_685122975301_item	2820413	et	4	main
ning	doc_685122975301_item	2820414	et	3	main
kaheksa	doc_685122975301_item	2820416	et	4	main
kohad	doc_685122975301_item	2820415	et	4	main
lauatennise	doc_685122975301_item	2820417	et	3	main
laua	doc_685122975301_item	2820418	et	3	main
jaoks	doc_685122975301_item	2820419	et	4	main
tegeleda	doc_685122975301_item	2820420	et	3	main
võrk-	doc_685122975301_item	2820426	et	3	main
suusatada	doc_685122975301_item	2820429	et	3	main
palju	doc_685122975301_item	2820432	et	4	main
spordihoones	doc_685122975301_item	2820434	et	4	main
võimalik	doc_685122975301_item	2820447	et	3	main
asuvad	doc_685122975301_item	2820468	et	4	main
hea-	doc_685122975301_item	2820477	et	4	main
on	doc_685122975301_item	2820490	et	4	main
mõned	doc_685122975301_item	2820491	et	3	main
on	doc_685122975301_item	2820495	et	4	main
õppekoha	doc_685122975301_item	2820498	et	4	main
keskmine	doc_685122975301_item	2820499	et	3	main
nõudlikumatel	doc_685122975301_item	2820510	et	4	main
ja	doc_685122975301_item	2820519	et	3	main
mängida	doc_685122975301_item	2820423	et	3	main
terviseklubi	doc_685122975301_item	2820437	et	4	main
aeroobika	doc_685122975301_item	2820442	et	4	main
füüsilist	doc_685122975301_item	2820450	et	3	main
lõdvestuda	doc_685122975301_item	2820452	et	4	main
massööri	doc_685122975301_item	2820453	et	4	main
käe	doc_685122975301_item	2820454	et	3	main
all	doc_685122975301_item	2820455	et	3	main
ja	doc_685122975301_item	2820456	et	3	main
hoolitseda	doc_685122975301_item	2820457	et	3	main
oma	doc_685122975301_item	2820458	et	4	main
jume	doc_685122975301_item	2820459	et	4	main
oma	doc_685122975301_item	2820449	et	4	main
eest	doc_685122975301_item	2820460	et	4	main
pakub	doc_685122975301_item	2820464	et	3	main
tehnikaülikooli	doc_685122975301_item	2820469	et	4	main
piirkonnas	doc_685122975301_item	2820471	et	4	main
kaugusel	doc_685122975301_item	2820474	et	4	main
maksumus	doc_685122975301_item	2820500	et	3	main
ole	doc_685122975301_item	2820502	et	4	main
30	doc_685122975301_item	2820505	et	2	main
tuhat	doc_685122975301_item	2820506	et	4	main
on	doc_685122975301_item	2820512	et	4	main
see	doc_685122975301_item	2820513	et	3	main
kordi	doc_685122975301_item	2820515	et	4	main
kuid	doc_685122975301_item	2820517	et	4	main
peab	doc_685122975301_item	2820521	et	4	main
veel	doc_685122975301_item	2820462	et	4	main
ka	doc_685122975301_item	2820465	et	3	main
elamispind	doc_685122975301_item	2820466	et	3	main
üliõpilaselamud	doc_685122975301_item	2820467	et	3	main
on	doc_685122975301_item	2820475	et	4	main
spordihoone	doc_685122975301_item	2820479	et	4	main
mitmed	doc_685122975301_item	2820480	et	4	main
instituudid	doc_685122975301_item	2820481	et	3	main
raamatukogu	doc_685122975301_item	2820482	et	4	main
ning	doc_685122975301_item	2820483	et	3	main
maja	doc_685122975301_item	2820485	et	4	main
on	doc_685122975301_item	2820487	et	4	main
aga	doc_685122975301_item	2820489	et	3	main
probleemid	doc_685122975301_item	2820492	et	3	main
krooni	doc_685122975301_item	2820507	et	4	main
aastas	doc_685122975301_item	2820508	et	3	main
ja	doc_685122975301_item	2820509	et	3	main
elamiseks	doc_685122975301_item	2820518	et	4	main
vähemalt	doc_685122975301_item	2820527	et	4	main
30	doc_685122975301_item	2820528	et	2	main
maksumusega	doc_685122975301_item	2820533	et	3	main
perekonnale	doc_685122975301_item	2820537	et	4	main
igakuist	doc_685122975301_item	2820539	et	4	main
vähemalt	doc_685122975301_item	2820540	et	4	main
5-6	doc_685122975301_item	2820541	et	2	main
tuhande	doc_685122975301_item	2820542	et	3	main
kulu	doc_685122975301_item	2820545	et	4	main
uuringud	doc_685122975301_item	2820548	et	3	main
mina	doc_685122975302_item	2820561	et	4	main
minu	doc_685122975302_item	2820564	et	3	main
siin	doc_685122975302_item	2820579	et	4	main
edasi	doc_685122975302_item	2820580	et	3	main
oma	doc_685122975302_item	2820584	et	4	main
midagi	doc_685122975302_item	2820586	et	4	main
et	doc_685122975302_item	2820617	et	3	main
eestis	doc_685122975302_item	2820626	et	3	main
ehitusteaduskonnas	doc_685122975302_item	2820629	et	4	main
ja	doc_685122975302_item	2820631	et	3	main
ma	doc_685122975302_item	2820635	et	3	main
kerge	doc_685122975302_item	2820643	et	4	main
sest	doc_685122975302_item	2820645	et	4	main
ma	doc_685122975302_item	2820646	et	3	main
olen	doc_685122975302_item	2820647	et	3	main
kes	doc_685122975302_item	2820651	et	4	main
lõpetab	doc_685122975302_item	2820652	et	3	main
õppimist	doc_685122975302_item	2820653	et	4	main
on	doc_685122975302_item	2820667	et	4	main
on	doc_685122975302_item	2820684	et	4	main
üliõpilane	doc_685122975301_item	2820522	et	3	main
aastas	doc_685122975301_item	2820524	et	3	main
minimaalselt	doc_685122975301_item	2820525	et	4	main
koos	doc_685122975301_item	2820531	et	4	main
üliõpilase	doc_685122975301_item	2820536	et	3	main
krooni	doc_685122975301_item	2820543	et	4	main
sissetulekute	doc_685122975301_item	2820547	et	3	main
et	doc_685122975301_item	2820550	et	3	main
eestis	doc_685122975301_item	2820559	et	3	main
essee	doc_685122975302_item	2820560	et	4	main
ja	doc_685122975302_item	2820562	et	3	main
olen	doc_685122975302_item	2820568	et	3	main
aastane	doc_685122975302_item	2820570	et	4	main
ma	doc_685122975302_item	2820571	et	3	main
olen	doc_685122975302_item	2820572	et	3	main
sündinud	doc_685122975302_item	2820573	et	4	main
eestis	doc_685122975302_item	2820574	et	3	main
sellepärast	doc_685122975302_item	2820575	et	3	main
ma	doc_685122975302_item	2820576	et	3	main
tahaksin	doc_685122975302_item	2820577	et	3	main
ka	doc_685122975302_item	2820578	et	3	main
erinevatega	doc_685122975302_item	2820588	et	4	main
sõnadega	doc_685122975302_item	2820589	et	3	main
ma	doc_685122975302_item	2820590	et	3	main
sooviksin	doc_685122975302_item	2820591	et	3	main
olla	doc_685122975302_item	2820592	et	3	main
kasulik	doc_685122975302_item	2820593	et	3	main
eesti	doc_685122975302_item	2820594	et	4	main
jaoks	doc_685122975302_item	2820595	et	4	main
selle	doc_685122975302_item	2820596	et	4	main
jaoks	doc_685122975302_item	2820597	et	4	main
mul	doc_685122975302_item	2820598	et	3	main
on	doc_685122975302_item	2820599	et	4	main
vaja	doc_685122975302_item	2820600	et	4	main
haridust	doc_685122975302_item	2820601	et	4	main
saada	doc_685122975302_item	2820602	et	4	main
sest	doc_685122975302_item	2820603	et	4	main
pärast	doc_685122975302_item	2820604	et	4	main
kooli	doc_685122975302_item	2820605	et	4	main
lõpetamist	doc_685122975302_item	2820606	et	4	main
ma	doc_685122975302_item	2820607	et	3	main
käisin	doc_685122975302_item	2820608	et	3	main
ülikooli	doc_685122975302_item	2820609	et	4	main
õppima	doc_685122975302_item	2820610	et	3	main
ma	doc_685122975302_item	2820611	et	3	main
arvasin	doc_685122975302_item	2820612	et	3	main
ja	doc_685122975302_item	2820613	et	3	main
arvan	doc_685122975302_item	2820614	et	3	main
praegu	doc_685122975302_item	2820615	et	3	main
kulutama	doc_685122975301_item	2820523	et	4	main
see	doc_685122975301_item	2820535	et	3	main
suurust	doc_685122975301_item	2820544	et	4	main
näitavad	doc_685122975301_item	2820549	et	4	main
selliseid	doc_685122975301_item	2820551	et	4	main
suudab	doc_685122975301_item	2820553	et	3	main
perekond	doc_685122975301_item	2820558	et	3	main
töötada	doc_685122975302_item	2820582	et	3	main
riigile	doc_685122975302_item	2820585	et	3	main
teha	doc_685122975302_item	2820587	et	3	main
ka	doc_685122975302_item	2820616	et	3	main
ülikool	doc_685122975302_item	2820625	et	4	main
tööstus-	doc_685122975302_item	2820630	et	3	main
tsiviiliehutuse	doc_685122975302_item	2820632	et	4	main
miks	doc_685122975302_item	2820634	et	4	main
just	doc_685122975302_item	2820637	et	3	main
selles	doc_685122975302_item	2820654	et	4	main
erialas	doc_685122975302_item	2820655	et	3	main
ehitus	doc_685122975302_item	2820660	et	4	main
spetsialiistid	doc_685122975302_item	2820670	et	4	main
kõrgharidusega	doc_685122975302_item	2820671	et	3	main
praegu	doc_685122975302_item	2820672	et	3	main
ma	doc_685122975302_item	2820673	et	3	main
tahaksin	doc_685122975302_item	2820674	et	3	main
kirjutada	doc_685122975302_item	2820675	et	3	main
ttüst	doc_685122975302_item	2820678	et	4	main
eesti	doc_685122975302_item	2820688	et	4	main
keele	doc_685122975302_item	2820689	et	4	main
loengutelt	doc_685122975302_item	2820690	et	4	main
ma	doc_685122975302_item	2820691	et	3	main
ootan	doc_685122975302_item	2820692	et	3	main
õppin	doc_685122975302_item	2820705	et	4	main
essee	doc_685122975303_item	2820706	et	4	main
ja	doc_685122975303_item	2820708	et	3	main
vaalik	doc_685122975303_item	2820733	et	4	main
on	doc_685122975303_item	2820734	et	4	main
rohkem	doc_685122975303_item	2820741	et	4	main
tunnen	doc_685122975303_item	2820742	et	3	main
olümpiadides	doc_685122975303_item	2820749	et	4	main
kus	doc_685122975303_item	2820750	et	3	main
2003	doc_685122975303_item	2820762	et	2	main
töötasin	doc_685122975303_item	2820764	et	3	main
ehitus	doc_685122975303_item	2820772	et	4	main
erialale	doc_685122975303_item	2820778	et	3	main
et	doc_685122975303_item	2820781	et	3	main
ma	doc_685122975303_item	2820786	et	3	main
ilma	doc_685122975303_item	2820789	et	4	main
tööta	doc_685122975303_item	2820790	et	4	main
see	doc_685122975303_item	2820791	et	3	main
oli	doc_685122975303_item	2820792	et	3	main
et	doc_685122975303_item	2820799	et	3	main
ja	doc_685122975303_item	2820803	et	3	main
mul	doc_685122975303_item	2820809	et	3	main
jäätnud	doc_685122975303_item	2820811	et	4	main
ja	doc_685122975303_item	2820813	et	3	main
muljed	doc_685122975303_item	2820815	et	3	main
ma	doc_685122975303_item	2820816	et	3	main
arvan	doc_685122975303_item	2820817	et	3	main
et	doc_685122975303_item	2820818	et	3	main
ma	doc_685122975303_item	2820819	et	3	main
valisin	doc_685122975303_item	2820820	et	3	main
vaja	doc_685122975303_item	2820832	et	4	main
essee	doc_685122975304_item	2820845	et	4	main
olen	doc_685122975304_item	2820850	et	3	main
kaisin	doc_685122975304_item	2820860	et	4	main
kui	doc_685122975304_item	2820867	et	3	main
ei	doc_685122975304_item	2820874	et	4	main
insineeriga	doc_685122975304_item	2820902	et	4	main
ja	doc_685122975304_item	2820903	et	3	main
sest	doc_685122975304_item	2820910	et	4	main
inimesed	doc_685122975304_item	2820911	et	3	main
palju	doc_685122975304_item	2820917	et	4	main
ja	doc_685122975304_item	2820918	et	3	main
palk	doc_685122975304_item	2820922	et	3	main
suurem	doc_685122975304_item	2820934	et	4	main
ja	doc_685122975304_item	2820935	et	3	main
tehnika	doc_685122975304_item	2820937	et	4	main
et	doc_685122975304_item	2820945	et	3	main
eesti	doc_685122975304_item	2820947	et	4	main
mina	doc_685122975305_item	2820956	et	4	main
olen	doc_685122975305_item	2820960	et	3	main
minu	doc_685122975305_item	2820963	et	3	main
kõrghariduse	doc_685122975302_item	2820622	et	3	main
õppin	doc_685122975302_item	2820628	et	4	main
erialas	doc_685122975302_item	2820633	et	3	main
tulin	doc_685122975302_item	2820636	et	3	main
eriala	doc_685122975302_item	2820639	et	4	main
õppima	doc_685122975302_item	2820640	et	3	main
see	doc_685122975302_item	2820641	et	3	main
küsimus	doc_685122975302_item	2820644	et	4	main
kindel	doc_685122975302_item	2820648	et	3	main
et	doc_685122975302_item	2820649	et	3	main
inimene	doc_685122975302_item	2820650	et	3	main
tööta	doc_685122975302_item	2820658	et	4	main
jääda	doc_685122975302_item	2820659	et	4	main
sellepärast	doc_685122975302_item	2820666	et	3	main
vaja	doc_685122975302_item	2820668	et	4	main
palju	doc_685122975302_item	2820669	et	4	main
sõbralikud	doc_685122975302_item	2820685	et	3	main
keele	doc_685122975302_item	2820693	et	4	main
loen	doc_685122975302_item	2820697	et	3	main
see	doc_685122975302_item	2820699	et	3	main
kui	doc_685122975302_item	2820702	et	3	main
ma	doc_685122975303_item	2820710	et	3	main
oli	doc_685122975303_item	2820711	et	3	main
sündinud	doc_685122975303_item	2820712	et	4	main
venemaal	doc_685122975303_item	2820713	et	4	main
1987	doc_685122975303_item	2820714	et	2	main
aastal	doc_685122975303_item	2820715	et	3	main
praegune	doc_685122975303_item	2820716	et	3	main
aastal	doc_685122975303_item	2820717	et	3	main
lõpetasin	doc_685122975303_item	2820718	et	3	main
sillamäe	doc_685122975303_item	2820719	et	3	main
kannuka	doc_685122975303_item	2820720	et	4	main
kool	doc_685122975303_item	2820721	et	4	main
ajal	doc_685122975303_item	2820723	et	4	main
piiretu	doc_685122975303_item	2820735	et	4	main
ja	doc_685122975303_item	2820736	et	3	main
võimalused	doc_685122975303_item	2820737	et	3	main
huvi	doc_685122975303_item	2820743	et	4	main
iga	doc_685122975303_item	2820751	et	4	main
aastal	doc_685122975303_item	2820752	et	3	main
oli	doc_685122975303_item	2820753	et	3	main
võitnud	doc_685122975303_item	2820754	et	4	main
ehituse	doc_685122975303_item	2820766	et	4	main
olla	doc_685122975303_item	2820769	et	3	main
valisin	doc_685122975303_item	2820771	et	3	main
õppima	doc_685122975303_item	2820779	et	3	main
tuleviks	doc_685122975303_item	2820785	et	4	main
pealik	doc_685122975303_item	2820793	et	4	main
õppimine	doc_685122975303_item	2820800	et	4	main
on	doc_685122975303_item	2820801	et	4	main
isegi	doc_685122975303_item	2820804	et	4	main
kardis	doc_685122975303_item	2820805	et	3	main
aga	doc_685122975303_item	2820806	et	3	main
on	doc_685122975303_item	2820810	et	4	main
head	doc_685122975303_item	2820814	et	4	main
ma	doc_685122975302_item	2820627	et	3	main
saa	doc_685122975302_item	2820657	et	4	main
ja	doc_685122975302_item	2820665	et	3	main
oma	doc_685122975302_item	2820676	et	4	main
nad	doc_685122975302_item	2820679	et	3	main
kõik	doc_685122975302_item	2820681	et	4	main
ja	doc_685122975302_item	2820686	et	3	main
parendamist	doc_685122975302_item	2820694	et	4	main
ja	doc_685122975302_item	2820695	et	3	main
ma	doc_685122975302_item	2820696	et	3	main
võib	doc_685122975302_item	2820700	et	3	main
ma	doc_685122975302_item	2820703	et	3	main
mina	doc_685122975303_item	2820707	et	4	main
sest	doc_685122975303_item	2820730	et	4	main
et	doc_685122975303_item	2820731	et	3	main
erinevad	doc_685122975303_item	2820739	et	4	main
muidugi	doc_685122975303_item	2820746	et	4	main
osalesin	doc_685122975303_item	2820747	et	3	main
alates	doc_685122975303_item	2820761	et	3	main
aastast	doc_685122975303_item	2820763	et	4	main
erinevatel	doc_685122975303_item	2820765	et	4	main
objektidel	doc_685122975303_item	2820767	et	3	main
võib	doc_685122975303_item	2820768	et	3	main
ma	doc_685122975303_item	2820775	et	3	main
sest	doc_685122975303_item	2820780	et	4	main
kindel	doc_685122975303_item	2820783	et	3	main
põhjus	doc_685122975303_item	2820794	et	4	main
enne	doc_685122975303_item	2820795	et	4	main
ebamugav	doc_685122975303_item	2820802	et	3	main
õppetamist	doc_685122975303_item	2820808	et	4	main
ootan	doc_685122975303_item	2820823	et	3	main
loengul	doc_685122975303_item	2820825	et	3	main
on	doc_685122975303_item	2820831	et	4	main
töötada	doc_685122975303_item	2820833	et	3	main
et	doc_685122975303_item	2820836	et	3	main
loengul	doc_685122975303_item	2820837	et	3	main
ootab	doc_685122975303_item	2820839	et	3	main
eesti	doc_685122975304_item	2820865	et	4	main
keelega	doc_685122975304_item	2820866	et	3	main
narvas	doc_685122975304_item	2820869	et	4	main
kuni	doc_685122975304_item	2820870	et	3	main
klass	doc_685122975304_item	2820872	et	3	main
pean	doc_685122975304_item	2820886	et	4	main
õppida	doc_685122975304_item	2820887	et	3	main
inglismaal	doc_685122975304_item	2820888	et	4	main
mina	doc_685122975304_item	2820904	et	4	main
tehnika	doc_685122975304_item	2820912	et	4	main
haridusega	doc_685122975304_item	2820913	et	3	main
ttü	doc_685122975304_item	2820930	et	4	main
on	doc_685122975304_item	2820949	et	4	main
ma	doc_685122975304_item	2820952	et	3	main
kõrgtase	doc_685122975304_item	2820954	et	3	main
mina	doc_685122975305_item	2820959	et	4	main
ja	doc_685122975305_item	2820996	et	3	main
sellepärast	doc_685122975305_item	2820998	et	3	main
väga	doc_685122975305_item	2821004	et	3	main
tulla	doc_685122975305_item	2821021	et	3	main
valisin	doc_685122975305_item	2821025	et	3	main
sest	doc_685122975305_item	2821036	et	4	main
mulle	doc_685122975305_item	2821037	et	4	main
meeldib	doc_685122975305_item	2821038	et	3	main
tööstus-	doc_685122975305_item	2821046	et	3	main
tsiviilehituses	doc_685122975305_item	2821048	et	3	main
praegu	doc_685122975305_item	2821058	et	3	main
kahesta	doc_685122975305_item	2821061	et	4	main
kolledžis	doc_685122975305_item	2821101	et	2	main
aga	doc_685122975305_item	2821102	et	3	main
eesti	doc_685122975305_item	2821112	et	4	main
keelest	doc_685122975305_item	2821113	et	4	main
ma	doc_685122975305_item	2821114	et	3	main
ootan	doc_685122975305_item	2821115	et	3	main
minu	doc_685122975305_item	2821116	et	3	main
teadmisi	doc_685122975305_item	2821117	et	4	main
ma	doc_685122975305_item	2821122	et	3	main
meie	doc_685122975305_item	2821125	et	4	main
keel	doc_685122975305_item	2821130	et	4	main
ning	doc_685122975305_item	2821131	et	3	main
essee	doc_685122975306_item	2821145	et	4	main
kes	doc_685122975306_item	2821153	et	4	main
aastal	doc_685122975306_item	2821158	et	3	main
akadeemilise	doc_685122975306_item	2821164	et	3	main
tegemine	doc_685122975306_item	2821190	et	4	main
kooli	doc_685122975303_item	2820722	et	4	main
oli	doc_685122975303_item	2820724	et	3	main
raske	doc_685122975303_item	2820725	et	4	main
arvestada	doc_685122975303_item	2820726	et	3	main
kuhu	doc_685122975303_item	2820727	et	3	main
edasi	doc_685122975303_item	2820728	et	3	main
õppida	doc_685122975303_item	2820729	et	3	main
on	doc_685122975303_item	2820738	et	4	main
geograafia	doc_685122975303_item	2820744	et	4	main
vastu	doc_685122975303_item	2820745	et	3	main
esimest	doc_685122975303_item	2820755	et	4	main
kuni	doc_685122975303_item	2820756	et	3	main
kolmani	doc_685122975303_item	2820757	et	4	main
kohta	doc_685122975303_item	2820758	et	4	main
igal	doc_685122975303_item	2820759	et	3	main
suvil	doc_685122975303_item	2820760	et	4	main
kõigepealt	doc_685122975303_item	2820774	et	3	main
selle	doc_685122975303_item	2820777	et	4	main
olen	doc_685122975303_item	2820782	et	3	main
pärast	doc_685122975303_item	2820807	et	4	main
suurepärased	doc_685122975303_item	2820812	et	4	main
et	doc_685122975303_item	2820824	et	3	main
ei	doc_685122975303_item	2820826	et	4	main
et	doc_685122975303_item	2820830	et	3	main
ka	doc_685122975303_item	2820834	et	3	main
mind	doc_685122975303_item	2820838	et	4	main
rühma	doc_685122975303_item	2820840	et	4	main
töö	doc_685122975303_item	2820841	et	4	main
ja	doc_685122975303_item	2820842	et	3	main
heameelne	doc_685122975303_item	2820843	et	3	main
sündinud	doc_685122975304_item	2820851	et	4	main
talvel	doc_685122975304_item	2820853	et	4	main
koolis	doc_685122975304_item	2820861	et	4	main
ma	doc_685122975304_item	2820873	et	3	main
minu	doc_685122975304_item	2820877	et	3	main
ülikoolis	doc_685122975304_item	2820879	et	4	main
võib	doc_685122975304_item	2820880	et	3	main
olla	doc_685122975304_item	2820881	et	3	main
insineer	doc_685122975304_item	2820882	et	4	main
mina	doc_685122975304_item	2820883	et	4	main
arvasin	doc_685122975304_item	2820884	et	3	main
ma	doc_685122975304_item	2820885	et	3	main
mingi	doc_685122975304_item	2820889	et	4	main
aga	doc_685122975304_item	2820892	et	3	main
kaisin	doc_685122975304_item	2820905	et	4	main
tööstus-	doc_685122975304_item	2820906	et	3	main
ja	doc_685122975304_item	2820907	et	3	main
tsiviilehitus	doc_685122975304_item	2820908	et	4	main
alati	doc_685122975304_item	2820915	et	4	main
tallinna	doc_685122975304_item	2820923	et	4	main
tahan	doc_685122975304_item	2820926	et	3	main
heaks	doc_685122975304_item	2820928	et	4	main
spetsialistiks	doc_685122975304_item	2820929	et	3	main
eesti	doc_685122975304_item	2820932	et	4	main
keele	doc_685122975304_item	2820941	et	4	main
loengutelt	doc_685122975304_item	2820942	et	4	main
ma	doc_685122975304_item	2820943	et	3	main
ootan	doc_685122975304_item	2820944	et	3	main
ja	doc_685122975304_item	2820951	et	3	main
essee	doc_685122975305_item	2820955	et	4	main
neiu	doc_685122975305_item	2820961	et	4	main
nimi	doc_685122975305_item	2820964	et	3	main
eesnimi	doc_685122975305_item	2820966	et	3	main
ma	doc_685122975305_item	2820969	et	3	main
üheksateistkümne	doc_685122975305_item	2820971	et	4	main
ma	doc_685122975305_item	2820973	et	3	main
oma	doc_685122975305_item	2821010	et	4	main
ta	doc_685122975305_item	2821018	et	4	main
pakkus	doc_685122975305_item	2821019	et	3	main
ehitusteaduskonna	doc_685122975305_item	2821022	et	4	main
ma	doc_685122975305_item	2821024	et	3	main
veel	doc_685122975305_item	2821028	et	4	main
siis	doc_685122975305_item	2821029	et	3	main
et	doc_685122975305_item	2821030	et	3	main
minu	doc_685122975305_item	2821031	et	3	main
kujutamine	doc_685122975305_item	2821039	et	4	main
ma	doc_685122975305_item	2821040	et	3	main
valisin	doc_685122975305_item	2821041	et	3	main
keskkonnatehnikas	doc_685122975305_item	2821044	et	3	main
ainult	doc_685122975305_item	2821050	et	4	main
ma	doc_685122975305_item	2821052	et	3	main
tsiviilehituse	doc_685122975305_item	2821056	et	3	main
ei	doc_685122975305_item	2821060	et	4	main
sest	doc_685122975305_item	2821062	et	4	main
mulle	doc_685122975305_item	2821063	et	4	main
meeldib	doc_685122975305_item	2821064	et	3	main
jääta	doc_685122975303_item	2820788	et	4	main
õppetamis	doc_685122975303_item	2820796	et	4	main
ma	doc_685122975303_item	2820797	et	3	main
mõtlesin	doc_685122975303_item	2820798	et	3	main
hea	doc_685122975303_item	2820821	et	4	main
mina	doc_685122975304_item	2820846	et	4	main
ja	doc_685122975304_item	2820847	et	3	main
kogu	doc_685122975304_item	2820858	et	4	main
elu	doc_685122975304_item	2820859	et	4	main
õppisin	doc_685122975304_item	2820868	et	3	main
12	doc_685122975304_item	2820871	et	2	main
eriala	doc_685122975304_item	2820878	et	4	main
ehituse	doc_685122975304_item	2820897	et	4	main
firmas	doc_685122975304_item	2820898	et	3	main
ja	doc_685122975304_item	2820899	et	3	main
tutvustasin	doc_685122975304_item	2820900	et	3	main
palju	doc_685122975304_item	2820901	et	4	main
eriala	doc_685122975304_item	2820909	et	4	main
töötavad	doc_685122975304_item	2820916	et	4	main
ma	doc_685122975304_item	2820925	et	3	main
on	doc_685122975304_item	2820931	et	4	main
parem	doc_685122975304_item	2820950	et	4	main
saan	doc_685122975304_item	2820953	et	4	main
ja	doc_685122975305_item	2820957	et	3	main
ning	doc_685122975305_item	2820968	et	3	main
eriala	doc_685122975305_item	2821011	et	4	main
ma	doc_685122975305_item	2821012	et	3	main
pärast	doc_685122975305_item	2821015	et	4	main
nõuest	doc_685122975305_item	2821017	et	4	main
mulle	doc_685122975305_item	2821020	et	4	main
koht	doc_685122975303_item	2820822	et	3	main
ole	doc_685122975303_item	2820827	et	4	main
lihtne	doc_685122975303_item	2820828	et	3	main
tean	doc_685122975303_item	2820829	et	3	main
mõtlen	doc_685122975303_item	2820835	et	3	main
kolektiiv	doc_685122975303_item	2820844	et	4	main
ülikool	doc_685122975304_item	2820848	et	4	main
ma	doc_685122975304_item	2820849	et	3	main
narvas	doc_685122975304_item	2820852	et	4	main
1987	doc_685122975304_item	2820854	et	2	main
ma	doc_685122975304_item	2820855	et	3	main
elasin	doc_685122975304_item	2820856	et	3	main
seal	doc_685122975304_item	2820857	et	4	main
seal	doc_685122975304_item	2820862	et	4	main
ja	doc_685122975304_item	2820863	et	3	main
tutvustasin	doc_685122975304_item	2820864	et	3	main
mõtlesin	doc_685122975304_item	2820875	et	3	main
et	doc_685122975304_item	2820876	et	3	main
majandus	doc_685122975304_item	2820890	et	4	main
ülikoolis	doc_685122975304_item	2820891	et	4	main
12	doc_685122975304_item	2820893	et	2	main
klassis	doc_685122975304_item	2820894	et	3	main
ma	doc_685122975304_item	2820895	et	3	main
töötasin	doc_685122975304_item	2820896	et	3	main
on	doc_685122975304_item	2820914	et	4	main
neil	doc_685122975304_item	2820919	et	4	main
on	doc_685122975304_item	2820920	et	4	main
suur	doc_685122975304_item	2820921	et	3	main
tehnikaülikoolis	doc_685122975304_item	2820924	et	4	main
saada	doc_685122975304_item	2820927	et	4	main
kõige	doc_685122975304_item	2820933	et	4	main
populaarsem	doc_685122975304_item	2820936	et	4	main
ülikool	doc_685122975304_item	2820938	et	4	main
aga	doc_685122975304_item	2820939	et	3	main
eesti	doc_685122975304_item	2820940	et	4	main
minu	doc_685122975304_item	2820946	et	3	main
keel	doc_685122975304_item	2820948	et	4	main
ülikool	doc_685122975305_item	2820958	et	4	main
ja	doc_685122975305_item	2820962	et	3	main
perekonnanimi	doc_685122975305_item	2820967	et	3	main
aastane	doc_685122975305_item	2820972	et	4	main
olin	doc_685122975305_item	2820974	et	3	main
sündinud	doc_685122975305_item	2820975	et	4	main
eestis	doc_685122975305_item	2820976	et	3	main
kohtla-järvel	doc_685122975305_item	2820977	et	4	main
ja	doc_685122975305_item	2820978	et	3	main
elasin	doc_685122975305_item	2820979	et	3	main
seal	doc_685122975305_item	2820980	et	4	main
koos	doc_685122975305_item	2820981	et	4	main
vanematega	doc_685122975305_item	2820982	et	4	main
ja	doc_685122975305_item	2820983	et	3	main
vennaga	doc_685122975305_item	2820984	et	3	main
kuni	doc_685122975305_item	2820985	et	3	main
kooli	doc_685122975305_item	2820986	et	4	main
lõpuni	doc_685122975305_item	2820987	et	3	main
koolis	doc_685122975305_item	2820988	et	4	main
mul	doc_685122975305_item	2820989	et	3	main
olid	doc_685122975305_item	2820990	et	4	main
meeldivad	doc_685122975305_item	2820991	et	4	main
õppeained	doc_685122975305_item	2820992	et	3	main
need	doc_685122975305_item	2820993	et	3	main
olid	doc_685122975305_item	2820994	et	4	main
on	doc_685122975305_item	2820965	et	4	main
olen	doc_685122975305_item	2820970	et	3	main
matemaatika	doc_685122975305_item	2820995	et	4	main
füüsika	doc_685122975305_item	2820997	et	4	main
ma	doc_685122975305_item	2820999	et	3	main
otsustasin	doc_685122975305_item	2821000	et	3	main
ttüsse	doc_685122975305_item	2821002	et	4	main
palju	doc_685122975305_item	2821005	et	4	main
mõtlesin	doc_685122975305_item	2821006	et	3	main
millile	doc_685122975305_item	2821007	et	4	main
erialale	doc_685122975305_item	2821008	et	3	main
tulla	doc_685122975305_item	2821009	et	3	main
ainult	doc_685122975305_item	2821014	et	4	main
sõbranna	doc_685122975305_item	2821016	et	4	main
eriala	doc_685122975305_item	2821034	et	4	main
sobib	doc_685122975305_item	2821035	et	3	main
ja	doc_685122975305_item	2821045	et	3	main
see	doc_685122975305_item	2821065	et	3	main
ma	doc_685122975305_item	2821068	et	3	main
hästi	doc_685122975305_item	2821071	et	3	main
ma	doc_685122975305_item	2821103	et	3	main
parandamist	doc_685122975305_item	2821120	et	4	main
kuna	doc_685122975305_item	2821121	et	3	main
tean	doc_685122975305_item	2821123	et	3	main
mitu	doc_685122975305_item	2821132	et	4	main
aasta	doc_685122975305_item	2821133	et	4	main
pärast	doc_685122975305_item	2821134	et	4	main
mul	doc_685122975305_item	2821135	et	3	main
vabalt	doc_685122975305_item	2821143	et	4	main
ma	doc_685122975306_item	2821149	et	3	main
olen	doc_685122975306_item	2821150	et	3	main
kahekümneaastane	doc_685122975306_item	2821151	et	4	main
ttüs	doc_685122975306_item	2821156	et	4	main
sisse	doc_685122975306_item	2821160	et	4	main
puhkuse	doc_685122975306_item	2821165	et	3	main
on	doc_685122975306_item	2821175	et	4	main
käia	doc_685122975306_item	2821176	et	4	main
varem	doc_685122975306_item	2821177	et	4	main
kui	doc_685122975306_item	2821178	et	3	main
hiljem	doc_685122975306_item	2821179	et	3	main
ja	doc_685122975306_item	2821187	et	3	main
aktiivne	doc_685122975306_item	2821205	et	3	main
ja	doc_685122975306_item	2821207	et	3	main
inimene	doc_685122975306_item	2821209	et	3	main
mõtlen	doc_685122975306_item	2821212	et	3	main
kõik	doc_685122975306_item	2821214	et	4	main
astuda	doc_685122975305_item	2821001	et	3	main
aga	doc_685122975305_item	2821003	et	3	main
valisin	doc_685122975305_item	2821013	et	3	main
ning	doc_685122975305_item	2821023	et	3	main
seda	doc_685122975305_item	2821026	et	3	main
teaduskonna	doc_685122975305_item	2821027	et	4	main
arvates	doc_685122975305_item	2821032	et	4	main
see	doc_685122975305_item	2821033	et	3	main
kaks	doc_685122975305_item	2821042	et	3	main
ja	doc_685122975305_item	2821047	et	3	main
ning	doc_685122975305_item	2821049	et	3	main
astusin	doc_685122975305_item	2821053	et	3	main
ja	doc_685122975305_item	2821055	et	3	main
erialale	doc_685122975305_item	2821057	et	3	main
õppimine	doc_685122975305_item	2821066	et	4	main
väga	doc_685122975305_item	2821070	et	3	main
virumaa	doc_685122975305_item	2821100	et	4	main
ei	doc_685122975305_item	2821104	et	4	main
tahtnud	doc_685122975305_item	2821105	et	4	main
seal	doc_685122975305_item	2821106	et	4	main
õppida	doc_685122975305_item	2821107	et	3	main
ning	doc_685122975305_item	2821108	et	3	main
ma	doc_685122975305_item	2821109	et	3	main
olen	doc_685122975305_item	2821110	et	3	main
ttüs	doc_685122975305_item	2821111	et	4	main
ja	doc_685122975305_item	2821119	et	3	main
riigis	doc_685122975305_item	2821126	et	3	main
on	doc_685122975305_item	2821127	et	4	main
vaja	doc_685122975305_item	2821128	et	4	main
eesti	doc_685122975305_item	2821140	et	4	main
keelt	doc_685122975305_item	2821141	et	4	main
ja	doc_685122975305_item	2821142	et	3	main
ja	doc_685122975306_item	2821147	et	3	main
ülikool	doc_685122975306_item	2821148	et	4	main
astusin	doc_685122975306_item	2821159	et	3	main
kohe	doc_685122975306_item	2821163	et	4	main
selleks	doc_685122975306_item	2821166	et	4	main
et	doc_685122975306_item	2821167	et	3	main
käia	doc_685122975306_item	2821168	et	4	main
sõjaväes	doc_685122975306_item	2821169	et	3	main
vaheaja	doc_685122975306_item	2821189	et	3	main
järeldama	doc_685122975306_item	2821192	et	3	main
tsiviilehitusesse	doc_685122975306_item	2821223	et	4	main
erialates	doc_685122975306_item	2821229	et	4	main
sain	doc_685122975306_item	2821232	et	3	main
on	doc_685122975306_item	2821241	et	4	main
elada	doc_685122975306_item	2821251	et	3	main
eesti	doc_685122975306_item	2821279	et	4	main
kõik	doc_685122975306_item	2821287	et	4	main
hea	doc_685122975306_item	2821302	et	4	main
ja	doc_685122975306_item	2821303	et	3	main
tahaks	doc_685122975306_item	2821304	et	3	main
ja	doc_685122975307_item	2821325	et	3	main
ttü	doc_685122975307_item	2821344	et	4	main
sest	doc_685122975307_item	2821345	et	4	main
see	doc_685122975307_item	2821346	et	3	main
suured	doc_685122975307_item	2821354	et	3	main
mina	doc_685122975307_item	2821358	et	4	main
just	doc_685122975307_item	2821360	et	3	main
raha	doc_685122975307_item	2821404	et	4	main
teenida	doc_685122975307_item	2821405	et	3	main
kõrgharidus	doc_685122975307_item	2821406	et	3	main
on	doc_685122975307_item	2821415	et	4	main
suured	doc_685122975307_item	2821417	et	3	main
seal	doc_685122975307_item	2821420	et	4	main
kõik	doc_685122975307_item	2821422	et	4	main
uued	doc_685122975307_item	2821423	et	3	main
auditooriumid	doc_685122975307_item	2821426	et	3	main
sest	doc_685122975307_item	2821438	et	4	main
ma	doc_685122975307_item	2821439	et	3	main
elan	doc_685122975307_item	2821440	et	3	main
eestis	doc_685122975307_item	2821441	et	3	main
on	doc_685122975307_item	2821445	et	4	main
ek	doc_685122975307_item	2821462	et	4	main
räkida	doc_685122975307_item	2821466	et	4	main
ja	doc_685122975307_item	2821467	et	3	main
kirjutad	doc_685122975307_item	2821468	et	3	main
ja	doc_685122975308_item	2821472	et	3	main
ma	doc_685122975308_item	2821475	et	3	main
tahaksin	doc_685122975308_item	2821476	et	3	main
ja	doc_685122975308_item	2821484	et	3	main
lõpetasin	doc_685122975308_item	2821490	et	3	main
eriala	doc_685122975305_item	2821043	et	4	main
augustis	doc_685122975305_item	2821051	et	3	main
tööstus-	doc_685122975305_item	2821054	et	3	main
ma	doc_685122975305_item	2821059	et	3	main
ttüsse	doc_685122975305_item	2821067	et	4	main
suhtun	doc_685122975305_item	2821069	et	3	main
kuna	doc_685122975305_item	2821072	et	3	main
kui	doc_685122975305_item	2821073	et	3	main
ma	doc_685122975305_item	2821074	et	3	main
juba	doc_685122975305_item	2821075	et	3	main
kirjutasin	doc_685122975305_item	2821076	et	3	main
et	doc_685122975305_item	2821077	et	3	main
mu	doc_685122975305_item	2821078	et	3	main
lemmik	doc_685122975305_item	2821079	et	3	main
õppeained	doc_685122975305_item	2821080	et	3	main
on	doc_685122975305_item	2821081	et	4	main
täpsed	doc_685122975305_item	2821082	et	3	main
õppeained	doc_685122975305_item	2821083	et	3	main
ja	doc_685122975305_item	2821084	et	3	main
kõik	doc_685122975305_item	2821085	et	4	main
mis	doc_685122975305_item	2821086	et	4	main
on	doc_685122975305_item	2821087	et	4	main
seotud	doc_685122975305_item	2821088	et	4	main
tehnilise	doc_685122975305_item	2821089	et	3	main
õppimisega	doc_685122975305_item	2821090	et	4	main
minu	doc_685122975305_item	2821091	et	3	main
sõbrannad	doc_685122975305_item	2821092	et	3	main
rääkisid	doc_685122975305_item	2821093	et	4	main
et	doc_685122975305_item	2821094	et	3	main
paremini	doc_685122975305_item	2821095	et	4	main
õppida	doc_685122975305_item	2821096	et	3	main
meie	doc_685122975305_item	2821097	et	4	main
linnas	doc_685122975305_item	2821098	et	4	main
ttü	doc_685122975305_item	2821099	et	4	main
laiendamist	doc_685122975305_item	2821118	et	4	main
rohkem	doc_685122975305_item	2821139	et	4	main
mina	doc_685122975306_item	2821146	et	4	main
tuli	doc_685122975306_item	2821154	et	4	main
õpima	doc_685122975306_item	2821155	et	4	main
ja	doc_685122975306_item	2821161	et	3	main
parem	doc_685122975306_item	2821174	et	4	main
aasta	doc_685122975306_item	2821181	et	4	main
pärast	doc_685122975306_item	2821182	et	4	main
ma	doc_685122975306_item	2821183	et	3	main
oleks	doc_685122975306_item	2821184	et	3	main
õpimise	doc_685122975306_item	2821185	et	4	main
keskel	doc_685122975306_item	2821186	et	3	main
valmis	doc_685122975306_item	2821202	et	4	main
tööstus-	doc_685122975306_item	2821221	et	3	main
elukutse	doc_685122975306_item	2821239	et	4	main
tööd	doc_685122975306_item	2821243	et	4	main
keelt	doc_685122975306_item	2821280	et	4	main
ma	doc_685122975306_item	2821281	et	3	main
ja	doc_685122975306_item	2821289	et	3	main
oli	doc_685122975306_item	2821292	et	3	main
ole	doc_685122975306_item	2821299	et	4	main
mul	doc_685122975306_item	2821300	et	3	main
nii	doc_685122975306_item	2821301	et	3	main
ja	doc_685122975307_item	2821310	et	3	main
eesnimi	doc_685122975307_item	2821314	et	3	main
elan	doc_685122975307_item	2821317	et	3	main
sel	doc_685122975307_item	2821319	et	3	main
et	doc_685122975305_item	2821124	et	3	main
eesti	doc_685122975305_item	2821129	et	4	main
on	doc_685122975305_item	2821136	et	4	main
soov	doc_685122975305_item	2821137	et	3	main
teada	doc_685122975305_item	2821138	et	3	main
räägida	doc_685122975305_item	2821144	et	4	main
mees	doc_685122975306_item	2821152	et	4	main
eelmisel	doc_685122975306_item	2821157	et	3	main
võtsin	doc_685122975306_item	2821162	et	3	main
ära	doc_685122975306_item	2821170	et	4	main
ma	doc_685122975306_item	2821171	et	3	main
mõtlesin	doc_685122975306_item	2821172	et	3	main
et	doc_685122975306_item	2821173	et	3	main
kolme	doc_685122975306_item	2821180	et	4	main
suure	doc_685122975306_item	2821188	et	3	main
võiks	doc_685122975306_item	2821191	et	4	main
unustamist	doc_685122975306_item	2821193	et	4	main
seda	doc_685122975306_item	2821194	et	3	main
mida	doc_685122975306_item	2821195	et	4	main
ma	doc_685122975306_item	2821196	et	3	main
õpimiseks	doc_685122975306_item	2821203	et	4	main
avatud	doc_685122975306_item	2821206	et	4	main
ja	doc_685122975306_item	2821210	et	3	main
et	doc_685122975306_item	2821213	et	3	main
mul	doc_685122975306_item	2821215	et	3	main
läheb	doc_685122975306_item	2821216	et	3	main
hästi	doc_685122975306_item	2821217	et	3	main
ttüs	doc_685122975306_item	2821218	et	4	main
ma	doc_685122975306_item	2821219	et	3	main
tulin	doc_685122975306_item	2821220	et	3	main
sest	doc_685122975306_item	2821224	et	4	main
oli	doc_685122975306_item	2821226	et	3	main
alati	doc_685122975306_item	2821242	et	4	main
vajavad	doc_685122975306_item	2821246	et	4	main
kohti	doc_685122975306_item	2821247	et	4	main
kus	doc_685122975306_item	2821248	et	3	main
saab	doc_685122975306_item	2821249	et	3	main
hästi	doc_685122975306_item	2821250	et	3	main
ülikool	doc_685122975306_item	2821253	et	4	main
suhted	doc_685122975306_item	2821266	et	3	main
õppimisega	doc_685122975306_item	2821267	et	4	main
kõik	doc_685122975306_item	2821271	et	4	main
hästi	doc_685122975306_item	2821273	et	3	main
organiseeritud	doc_685122975306_item	2821274	et	4	main
see	doc_685122975306_item	2821276	et	3	main
pole	doc_685122975306_item	2821277	et	3	main
viga	doc_685122975306_item	2821278	et	4	main
sõjaväes	doc_685122975306_item	2821286	et	3	main
tunnid	doc_685122975306_item	2821288	et	3	main
just	doc_685122975306_item	2821293	et	3	main
natuke	doc_685122975306_item	2821306	et	4	main
ülikool	doc_685122975307_item	2821311	et	4	main
olen	doc_685122975307_item	2821313	et	3	main
ja	doc_685122975307_item	2821316	et	3	main
jõhvis	doc_685122975307_item	2821318	et	3	main
lõpetasin	doc_685122975307_item	2821321	et	3	main
tal	doc_685122975307_item	2821351	et	3	main
valiksin	doc_685122975307_item	2821359	et	3	main
sest	doc_685122975307_item	2821364	et	4	main
tahaksin	doc_685122975307_item	2821365	et	3	main
väga	doc_685122975307_item	2821370	et	3	main
mul	doc_685122975307_item	2821374	et	3	main
muljed	doc_685122975307_item	2821418	et	3	main
õpisin	doc_685122975306_item	2821197	et	4	main
praegu	doc_685122975306_item	2821198	et	3	main
olen	doc_685122975306_item	2821199	et	3	main
tagasi	doc_685122975306_item	2821200	et	3	main
ja	doc_685122975306_item	2821201	et	3	main
olen	doc_685122975306_item	2821204	et	3	main
suhtlemisvalmis	doc_685122975306_item	2821208	et	4	main
ma	doc_685122975306_item	2821211	et	3	main
ja	doc_685122975306_item	2821222	et	3	main
üks	doc_685122975306_item	2821227	et	3	main
ma	doc_685122975306_item	2821231	et	3	main
riigi	doc_685122975306_item	2821234	et	3	main
eelarveliselt	doc_685122975306_item	2821235	et	4	main
see	doc_685122975306_item	2821236	et	3	main
on	doc_685122975306_item	2821237	et	4	main
perspektiivne	doc_685122975306_item	2821238	et	3	main
ehitajatel	doc_685122975306_item	2821240	et	4	main
alati	doc_685122975306_item	2821270	et	4	main
aga	doc_685122975306_item	2821275	et	3	main
sest	doc_685122975306_item	2821285	et	4	main
palju	doc_685122975306_item	2821290	et	4	main
suhtlemist	doc_685122975306_item	2821291	et	4	main
keeles	doc_685122975306_item	2821295	et	4	main
grammaatika	doc_685122975306_item	2821297	et	4	main
ei	doc_685122975306_item	2821298	et	4	main
essee	doc_685122975307_item	2821308	et	4	main
mina	doc_685122975307_item	2821309	et	4	main
mina	doc_685122975307_item	2821312	et	4	main
perekonnanimi	doc_685122975307_item	2821315	et	3	main
aastal	doc_685122975307_item	2821320	et	3	main
gümnaasiumi	doc_685122975307_item	2821324	et	4	main
praegu	doc_685122975307_item	2821326	et	3	main
ning	doc_685122975307_item	2821332	et	3	main
aastat	doc_685122975307_item	2821334	et	3	main
jalgpalliga	doc_685122975307_item	2821336	et	3	main
tahan	doc_685122975307_item	2821338	et	3	main
ka	doc_685122975307_item	2821339	et	3	main
tegeleda	doc_685122975307_item	2821340	et	3	main
spordiga	doc_685122975307_item	2821341	et	3	main
mina	doc_685122975307_item	2821342	et	4	main
valin	doc_685122975307_item	2821343	et	3	main
ülikool	doc_685122975307_item	2821350	et	4	main
traditsioonid	doc_685122975307_item	2821357	et	3	main
oma	doc_685122975307_item	2821361	et	4	main
eriala	doc_685122975307_item	2821362	et	4	main
õppima	doc_685122975307_item	2821363	et	3	main
on	doc_685122975307_item	2821369	et	4	main
peab	doc_685122975307_item	2821407	et	4	main
olema	doc_685122975307_item	2821408	et	4	main
kui	doc_685122975307_item	2821409	et	3	main
tulin	doc_685122975307_item	2821410	et	3	main
ttüs	doc_685122975307_item	2821411	et	4	main
õppima	doc_685122975307_item	2821412	et	3	main
siis	doc_685122975307_item	2821413	et	3	main
mul	doc_685122975307_item	2821414	et	3	main
väga	doc_685122975307_item	2821416	et	3	main
on	doc_685122975307_item	2821421	et	4	main
suured	doc_685122975307_item	2821425	et	3	main
keelt	doc_685122975307_item	2821436	et	4	main
õppida	doc_685122975307_item	2821437	et	3	main
väga	doc_685122975307_item	2821446	et	3	main
seepärast	doc_685122975307_item	2821448	et	3	main
et	doc_685122975307_item	2821450	et	3	main
teadmisi	doc_685122975307_item	2821457	et	4	main
essee	doc_685122975308_item	2821470	et	4	main
ülikool	doc_685122975308_item	2821473	et	4	main
paar	doc_685122975308_item	2821478	et	3	main
endast	doc_685122975308_item	2821480	et	4	main
ma	doc_685122975308_item	2821481	et	3	main
ma	doc_685122975308_item	2821489	et	3	main
õppida	doc_685122975308_item	2821501	et	3	main
programmerimine	doc_685122975308_item	2821510	et	4	main
küllaga	doc_685122975308_item	2821513	et	4	main
ma	doc_685122975308_item	2821522	et	3	main
armastasin	doc_685122975308_item	2821523	et	3	main
praegu	doc_685122975308_item	2821525	et	3	main
juba	doc_685122975308_item	2821534	et	3	main
tehtud	doc_685122975308_item	2821535	et	4	main
et	doc_685122975308_item	2821542	et	3	main
huvi	doc_685122975308_item	2821544	et	4	main
saab	doc_685122975308_item	2821545	et	3	main
mulle	doc_685122975308_item	2821546	et	4	main
see	doc_685122975306_item	2821225	et	3	main
nendest	doc_685122975306_item	2821228	et	4	main
kuhu	doc_685122975306_item	2821230	et	3	main
minna	doc_685122975306_item	2821233	et	3	main
sest	doc_685122975306_item	2821244	et	4	main
inimesed	doc_685122975306_item	2821245	et	3	main
meie	doc_685122975306_item	2821252	et	4	main
on	doc_685122975306_item	2821254	et	4	main
väga	doc_685122975306_item	2821255	et	3	main
huvitav	doc_685122975306_item	2821256	et	4	main
koht	doc_685122975306_item	2821257	et	3	main
kus	doc_685122975306_item	2821258	et	3	main
mul	doc_685122975306_item	2821259	et	3	main
on	doc_685122975306_item	2821260	et	4	main
juba	doc_685122975306_item	2821261	et	3	main
palju	doc_685122975306_item	2821262	et	4	main
tuttavaid	doc_685122975306_item	2821263	et	3	main
ja	doc_685122975306_item	2821264	et	3	main
head	doc_685122975306_item	2821265	et	4	main
muidugi	doc_685122975306_item	2821268	et	4	main
mitte	doc_685122975306_item	2821269	et	3	main
on	doc_685122975306_item	2821272	et	4	main
tean	doc_685122975306_item	2821282	et	3	main
päris	doc_685122975306_item	2821283	et	4	main
hästi	doc_685122975306_item	2821284	et	3	main
riigi	doc_685122975306_item	2821294	et	3	main
aga	doc_685122975306_item	2821296	et	3	main
sellega	doc_685122975306_item	2821305	et	3	main
töötada	doc_685122975306_item	2821307	et	3	main
vene	doc_685122975307_item	2821323	et	4	main
õpin	doc_685122975307_item	2821327	et	3	main
mina	doc_685122975307_item	2821329	et	4	main
olen	doc_685122975307_item	2821330	et	3	main
sportlane	doc_685122975307_item	2821331	et	3	main
12	doc_685122975307_item	2821333	et	2	main
tegelen	doc_685122975307_item	2821335	et	3	main
on	doc_685122975307_item	2821347	et	4	main
väga	doc_685122975307_item	2821348	et	3	main
on	doc_685122975307_item	2821352	et	4	main
ja	doc_685122975307_item	2821356	et	3	main
inseneeriks	doc_685122975307_item	2821366	et	4	main
saada	doc_685122975307_item	2821367	et	4	main
raske	doc_685122975307_item	2821371	et	4	main
aga	doc_685122975307_item	2821373	et	3	main
saan	doc_685122975307_item	2821434	et	4	main
eesti	doc_685122975307_item	2821435	et	4	main
eesti	doc_685122975307_item	2821443	et	4	main
loodan	doc_685122975307_item	2821449	et	3	main
eesti	doc_685122975307_item	2821451	et	4	main
loengutel	doc_685122975307_item	2821453	et	4	main
ma	doc_685122975307_item	2821454	et	3	main
saan	doc_685122975307_item	2821455	et	4	main
et	doc_685122975307_item	2821461	et	3	main
lõpetamisel	doc_685122975307_item	2821464	et	4	main
mina	doc_685122975308_item	2821471	et	4	main
alguses	doc_685122975308_item	2821474	et	4	main
rääkida	doc_685122975308_item	2821477	et	3	main
õppisin	doc_685122975308_item	2821485	et	3	main
aastal	doc_685122975308_item	2821488	et	3	main
ja	doc_685122975308_item	2821524	et	3	main
kõik	doc_685122975308_item	2821527	et	4	main
mis	doc_685122975308_item	2821528	et	4	main
ma	doc_685122975308_item	2821536	et	3	main
õpin	doc_685122975308_item	2821537	et	3	main
ttü-s	doc_685122975308_item	2821538	et	3	main
ja	doc_685122975308_item	2821539	et	3	main
ma	doc_685122975308_item	2821540	et	3	main
minu	doc_685122975308_item	2821543	et	3	main
kätte	doc_685122975308_item	2821552	et	4	main
praegu	doc_685122975308_item	2821558	et	3	main
tuutorid	doc_685122975308_item	2821566	et	4	main
meeldivad	doc_685122975308_item	2821575	et	4	main
matemaatika	doc_685122975308_item	2821579	et	4	main
täiendõpe	doc_685122975308_item	2821581	et	3	main
ja	doc_685122975308_item	2821582	et	3	main
meeldi	doc_685122975308_item	2821587	et	4	main
jõhvi	doc_685122975307_item	2821322	et	4	main
ttülikoolis	doc_685122975307_item	2821328	et	4	main
ttülikoolis	doc_685122975307_item	2821337	et	4	main
hea	doc_685122975307_item	2821349	et	4	main
väga	doc_685122975307_item	2821353	et	3	main
kombed	doc_685122975307_item	2821355	et	3	main
see	doc_685122975307_item	2821368	et	3	main
eriala	doc_685122975307_item	2821372	et	4	main
on	doc_685122975307_item	2821375	et	4	main
väga	doc_685122975307_item	2821376	et	3	main
suur	doc_685122975307_item	2821377	et	3	main
huvi	doc_685122975307_item	2821378	et	4	main
õppima	doc_685122975307_item	2821379	et	3	main
ja	doc_685122975307_item	2821380	et	3	main
igal	doc_685122975307_item	2821381	et	3	main
päeval	doc_685122975307_item	2821382	et	3	main
teadmisi	doc_685122975307_item	2821384	et	4	main
uusi	doc_685122975307_item	2821383	et	3	main
saada	doc_685122975307_item	2821385	et	4	main
veel	doc_685122975307_item	2821386	et	4	main
mina	doc_685122975307_item	2821387	et	4	main
saaksin	doc_685122975307_item	2821388	et	3	main
aru	doc_685122975307_item	2821389	et	4	main
et	doc_685122975307_item	2821390	et	3	main
praegu	doc_685122975307_item	2821391	et	3	main
kõrg	doc_685122975307_item	2821392	et	4	main
haridus	doc_685122975307_item	2821393	et	3	main
on	doc_685122975307_item	2821394	et	4	main
väga	doc_685122975307_item	2821395	et	3	main
oluline	doc_685122975307_item	2821396	et	4	main
kui	doc_685122975307_item	2821397	et	3	main
tahan	doc_685122975307_item	2821398	et	3	main
head	doc_685122975307_item	2821399	et	4	main
tööd	doc_685122975307_item	2821400	et	4	main
leida	doc_685122975307_item	2821401	et	3	main
ning	doc_685122975307_item	2821402	et	3	main
palju	doc_685122975307_item	2821403	et	4	main
sest	doc_685122975307_item	2821419	et	4	main
keel	doc_685122975307_item	2821444	et	4	main
vajalik	doc_685122975307_item	2821447	et	3	main
palju	doc_685122975307_item	2821456	et	4	main
loengute	doc_685122975307_item	2821463	et	4	main
võin	doc_685122975307_item	2821465	et	3	main
korrektselt	doc_685122975307_item	2821469	et	4	main
sõnu	doc_685122975308_item	2821479	et	4	main
sündisin	doc_685122975308_item	2821482	et	3	main
narvas	doc_685122975308_item	2821486	et	4	main
huvi	doc_685122975308_item	2821508	et	4	main
arvuti	doc_685122975308_item	2821509	et	4	main
arvutiga	doc_685122975308_item	2821530	et	4	main
esimene	doc_685122975308_item	2821531	et	3	main
eesmärk	doc_685122975308_item	2821532	et	3	main
on	doc_685122975308_item	2821533	et	4	main
ma	doc_685122975308_item	2821549	et	3	main
edukas	doc_685122975308_item	2821550	et	4	main
informatikale	doc_685122975308_item	2821556	et	4	main
ja	doc_685122975308_item	2821557	et	3	main
kõik	doc_685122975308_item	2821561	et	4	main
harjutused	doc_685122975308_item	2821563	et	4	main
minu	doc_685122975308_item	2821568	et	3	main
ttü	doc_685122975308_item	2821570	et	4	main
niisuguseid	doc_685122975308_item	2821576	et	3	main
aineid	doc_685122975308_item	2821577	et	3	main
matemaatika	doc_685122975308_item	2821580	et	4	main
infotehnoloogiasse	doc_685122975308_item	2821584	et	3	main
ei	doc_685122975308_item	2821586	et	4	main
lõpetada	doc_685122975308_item	2821621	et	3	main
olen	doc_685122975308_item	2821626	et	3	main
ise	doc_685122975308_item	2821629	et	4	main
iseseisvus	doc_685122975308_item	2821641	et	4	main
tahan	doc_685122975308_item	2821653	et	3	main
kus	doc_685122975308_item	2821658	et	3	main
elasin	doc_685122975308_item	2821660	et	3	main
keele	doc_685122975308_item	2821672	et	4	main
on	doc_685122975308_item	2821676	et	4	main
tase	doc_685122975308_item	2821678	et	3	main
on	doc_685122975308_item	2821691	et	4	main
seotud	doc_685122975308_item	2821692	et	4	main
eesti	doc_685122975308_item	2821695	et	4	main
essee	doc_685122975309_item	2821697	et	4	main
minu	doc_685122975309_item	2821698	et	3	main
nimi	doc_685122975309_item	2821699	et	3	main
on	doc_685122975309_item	2821700	et	4	main
eesnimi	doc_685122975309_item	2821701	et	3	main
perekonnanimi	doc_685122975309_item	2821702	et	3	main
sügiseni	doc_685122975309_item	2821718	et	3	main
on	doc_685122975309_item	2821719	et	4	main
olen	doc_685122975309_item	2821726	et	3	main
lõpetasin	doc_685122975309_item	2821730	et	3	main
elan	doc_685122975309_item	2821746	et	3	main
sellel	doc_685122975309_item	2821749	et	4	main
astusin	doc_685122975309_item	2821752	et	3	main
mind	doc_685122975309_item	2821754	et	4	main
huvitab	doc_685122975309_item	2821755	et	3	main
sport	doc_685122975309_item	2821756	et	3	main
sest	doc_685122975309_item	2821757	et	4	main
samuti	doc_685122975309_item	2821765	et	3	main
organismi	doc_685122975309_item	2821768	et	4	main
ja	doc_685122975309_item	2821769	et	3	main
parandab	doc_685122975309_item	2821770	et	3	main
rühti	doc_685122975309_item	2821771	et	4	main
kaks	doc_685122975309_item	2821807	et	3	main
päeva	doc_685122975309_item	2821808	et	4	main
ja	doc_685122975309_item	2821809	et	3	main
sellepärast	doc_685122975309_item	2821810	et	3	main
või	doc_685122975309_item	2821813	et	4	main
minu	doc_685122975309_item	2821815	et	3	main
ja	doc_685122975309_item	2821823	et	3	main
keele	doc_685122975309_item	2821828	et	4	main
mina	doc_685122975310_item	2821836	et	4	main
ja	doc_685122975310_item	2821837	et	3	main
tallinnas	doc_685122975310_item	2821841	et	4	main
noorem	doc_685122975310_item	2821867	et	4	main
töötasin	doc_685122975310_item	2821898	et	3	main
see	doc_685122975310_item	2821900	et	3	main
minu	doc_685122975310_item	2821902	et	3	main
kuni	doc_685122975310_item	2821904	et	3	main
mul	doc_685122975310_item	2821906	et	3	main
madrus	doc_685122975310_item	2821912	et	3	main
asjad	doc_685122975307_item	2821424	et	3	main
erinevad	doc_685122975307_item	2821427	et	4	main
kabinetid	doc_685122975307_item	2821428	et	3	main
spordihoone	doc_685122975307_item	2821429	et	4	main
olen	doc_685122975307_item	2821430	et	3	main
väga	doc_685122975307_item	2821431	et	3	main
õnnelik	doc_685122975307_item	2821432	et	3	main
et	doc_685122975307_item	2821433	et	3	main
ja	doc_685122975307_item	2821442	et	3	main
keele	doc_685122975307_item	2821452	et	4	main
ja	doc_685122975307_item	2821458	et	3	main
informatsiooni	doc_685122975307_item	2821459	et	4	main
loodan	doc_685122975307_item	2821460	et	3	main
elasin	doc_685122975308_item	2821483	et	3	main
sellisel	doc_685122975308_item	2821487	et	4	main
ja	doc_685122975308_item	2821492	et	3	main
aastat	doc_685122975308_item	2821499	et	3	main
tahaksin	doc_685122975308_item	2821500	et	3	main
enam	doc_685122975308_item	2821511	et	4	main
ma	doc_685122975308_item	2821514	et	3	main
tehniliseid	doc_685122975308_item	2821516	et	4	main
õpikuid	doc_685122975308_item	2821517	et	4	main
õppisin	doc_685122975308_item	2821518	et	3	main
pähi	doc_685122975308_item	2821519	et	4	main
programmerimise	doc_685122975308_item	2821520	et	4	main
keeleid	doc_685122975308_item	2821521	et	4	main
aidata	doc_685122975308_item	2821547	et	4	main
ja	doc_685122975308_item	2821548	et	3	main
õppin	doc_685122975308_item	2821555	et	4	main
loengud	doc_685122975308_item	2821562	et	3	main
praktikumid	doc_685122975308_item	2821564	et	3	main
inimesed	doc_685122975308_item	2821565	et	3	main
ja	doc_685122975308_item	2821567	et	3	main
tuba	doc_685122975308_item	2821569	et	4	main
sissejuhatus	doc_685122975308_item	2821583	et	4	main
et	doc_685122975308_item	2821628	et	3	main
saan	doc_685122975308_item	2821630	et	4	main
see	doc_685122975308_item	2821631	et	3	main
teha	doc_685122975308_item	2821632	et	3	main
ttü	doc_685122975308_item	2821633	et	4	main
rõõmus	doc_685122975308_item	2821642	et	4	main
aastat	doc_685122975308_item	2821662	et	3	main
eesti	doc_685122975308_item	2821679	et	4	main
keeles	doc_685122975308_item	2821680	et	4	main
keeles	doc_685122975308_item	2821696	et	4	main
narva	doc_685122975309_item	2821709	et	4	main
väike	doc_685122975309_item	2821712	et	4	main
rohelist	doc_685122975309_item	2821720	et	4	main
ma	doc_685122975309_item	2821721	et	3	main
ma	doc_685122975309_item	2821725	et	3	main
narvas	doc_685122975309_item	2821728	et	4	main
narva	doc_685122975309_item	2821731	et	4	main
kesklinna	doc_685122975309_item	2821732	et	4	main
sõpradega	doc_685122975309_item	2821741	et	3	main
ma	doc_685122975309_item	2821745	et	3	main
tallinnas	doc_685122975309_item	2821747	et	4	main
aastal	doc_685122975309_item	2821750	et	3	main
spordiala	doc_685122975309_item	2821759	et	4	main
annab	doc_685122975309_item	2821760	et	3	main
inimesele	doc_685122975309_item	2821761	et	3	main
palju	doc_685122975309_item	2821762	et	4	main
energiat	doc_685122975309_item	2821763	et	3	main
aga	doc_685122975309_item	2821764	et	3	main
tugevdab	doc_685122975309_item	2821767	et	3	main
õpin	doc_685122975309_item	2821804	et	3	main
ei	doc_685122975309_item	2821812	et	4	main
ütelda	doc_685122975309_item	2821814	et	4	main
muljed	doc_685122975309_item	2821816	et	3	main
aga	doc_685122975309_item	2821817	et	3	main
hoone	doc_685122975309_item	2821818	et	4	main
väga	doc_685122975309_item	2821821	et	3	main
suur	doc_685122975309_item	2821824	et	3	main
ootan	doc_685122975309_item	2821826	et	3	main
võimalik	doc_685122975309_item	2821834	et	3	main
essee	doc_685122975310_item	2821835	et	4	main
elan	doc_685122975310_item	2821840	et	3	main
keskkooli	doc_685122975308_item	2821491	et	4	main
astun	doc_685122975308_item	2821493	et	3	main
läbi	doc_685122975308_item	2821494	et	4	main
ttü-sse	doc_685122975308_item	2821495	et	3	main
ma	doc_685122975308_item	2821496	et	3	main
juba	doc_685122975308_item	2821497	et	3	main
kolm	doc_685122975308_item	2821498	et	3	main
ttü-s	doc_685122975308_item	2821502	et	3	main
infotehnoloogia	doc_685122975308_item	2821503	et	4	main
teaduskonnale	doc_685122975308_item	2821504	et	4	main
mul	doc_685122975308_item	2821505	et	3	main
oli	doc_685122975308_item	2821506	et	3	main
üks	doc_685122975308_item	2821507	et	3	main
kui	doc_685122975308_item	2821512	et	3	main
lugesin	doc_685122975308_item	2821515	et	3	main
armastan	doc_685122975308_item	2821526	et	3	main
seotud	doc_685122975308_item	2821529	et	4	main
loodan	doc_685122975308_item	2821541	et	3	main
saan	doc_685122975308_item	2821551	et	4	main
meeldib	doc_685122975308_item	2821560	et	3	main
mulle	doc_685122975308_item	2821573	et	4	main
ja	doc_685122975308_item	2821585	et	3	main
mulle	doc_685122975308_item	2821588	et	4	main
juba	doc_685122975308_item	2821589	et	3	main
filosoofia	doc_685122975308_item	2821590	et	4	main
sest	doc_685122975308_item	2821591	et	4	main
et	doc_685122975308_item	2821592	et	3	main
ruumis	doc_685122975308_item	2821593	et	4	main
on	doc_685122975308_item	2821594	et	4	main
alati	doc_685122975308_item	2821595	et	4	main
müra	doc_685122975308_item	2821596	et	4	main
ja	doc_685122975308_item	2821597	et	3	main
see	doc_685122975308_item	2821598	et	3	main
sõltub	doc_685122975308_item	2821599	et	3	main
ka	doc_685122975308_item	2821600	et	3	main
praegu	doc_685122975308_item	2821602	et	3	main
õpetajast	doc_685122975308_item	2821601	et	4	main
ttü-st	doc_685122975308_item	2821603	et	3	main
ma	doc_685122975308_item	2821604	et	3	main
tean	doc_685122975308_item	2821605	et	3	main
väga	doc_685122975308_item	2821606	et	3	main
ja	doc_685122975308_item	2821608	et	3	main
vähe	doc_685122975308_item	2821607	et	3	main
võib	doc_685122975308_item	2821609	et	3	main
olla	doc_685122975308_item	2821610	et	3	main
ma	doc_685122975308_item	2821611	et	3	main
saan	doc_685122975308_item	2821612	et	4	main
muutuda	doc_685122975308_item	2821613	et	3	main
arvamus	doc_685122975308_item	2821615	et	3	main
oma	doc_685122975308_item	2821614	et	4	main
paraku	doc_685122975308_item	2821616	et	3	main
teine	doc_685122975308_item	2821617	et	3	main
eesmärk	doc_685122975308_item	2821618	et	3	main
on	doc_685122975308_item	2821619	et	4	main
hästi	doc_685122975308_item	2821620	et	3	main
ttü-s	doc_685122975308_item	2821623	et	3	main
kindel	doc_685122975308_item	2821627	et	3	main
on	doc_685122975308_item	2821640	et	4	main
vahest	doc_685122975308_item	2821649	et	4	main
ma	doc_685122975308_item	2821650	et	3	main
tunnen	doc_685122975308_item	2821651	et	3	main
et	doc_685122975308_item	2821652	et	3	main
näha	doc_685122975308_item	2821656	et	3	main
linnu	doc_685122975308_item	2821657	et	4	main
19	doc_685122975308_item	2821661	et	2	main
diploomi	doc_685122975308_item	2821553	et	4	main
ma	doc_685122975308_item	2821554	et	3	main
mulle	doc_685122975308_item	2821559	et	4	main
ühiselamus	doc_685122975308_item	2821571	et	4	main
praegu	doc_685122975308_item	2821572	et	3	main
väga	doc_685122975308_item	2821574	et	3	main
diskreetne	doc_685122975308_item	2821578	et	3	main
annab	doc_685122975308_item	2821634	et	3	main
mulle	doc_685122975308_item	2821635	et	4	main
väga	doc_685122975308_item	2821636	et	3	main
huvilised	doc_685122975308_item	2821643	et	4	main
ained	doc_685122975308_item	2821644	et	3	main
narva-sse	doc_685122975308_item	2821654	et	3	main
ma	doc_685122975308_item	2821659	et	3	main
inimeseid	doc_685122975308_item	2821664	et	4	main
koos	doc_685122975308_item	2821665	et	4	main
kellega	doc_685122975308_item	2821666	et	3	main
elasin	doc_685122975308_item	2821667	et	3	main
kõrgem	doc_685122975308_item	2821681	et	4	main
teha	doc_685122975308_item	2821682	et	3	main
süveneda	doc_685122975308_item	2821683	et	3	main
oma	doc_685122975308_item	2821684	et	4	main
missuguseid	doc_685122975308_item	2821690	et	3	main
ttü-s	doc_685122975308_item	2821694	et	3	main
see	doc_685122975309_item	2821711	et	3	main
ilus	doc_685122975309_item	2821714	et	4	main
linn	doc_685122975309_item	2821715	et	3	main
aga	doc_685122975309_item	2821716	et	3	main
kevadest	doc_685122975309_item	2821717	et	4	main
õppimist	doc_685122975308_item	2821622	et	4	main
ja	doc_685122975308_item	2821624	et	3	main
ma	doc_685122975308_item	2821625	et	3	main
palju	doc_685122975308_item	2821637	et	4	main
muljet	doc_685122975308_item	2821638	et	3	main
see	doc_685122975308_item	2821639	et	3	main
uued	doc_685122975308_item	2821645	et	3	main
tutvused	doc_685122975308_item	2821646	et	3	main
küll	doc_685122975308_item	2821647	et	4	main
ega	doc_685122975308_item	2821648	et	3	main
tahan	doc_685122975308_item	2821655	et	3	main
eesti	doc_685122975308_item	2821671	et	4	main
see	doc_685122975308_item	2821675	et	3	main
oma	doc_685122975308_item	2821677	et	4	main
kergem	doc_685122975308_item	2821687	et	4	main
ületada	doc_685122975308_item	2821688	et	3	main
probleemeid	doc_685122975308_item	2821689	et	4	main
on	doc_685122975309_item	2821703	et	4	main
perekonnanimi	doc_685122975309_item	2821704	et	3	main
ma	doc_685122975309_item	2821705	et	3	main
olen	doc_685122975309_item	2821706	et	3	main
on	doc_685122975309_item	2821710	et	4	main
ja	doc_685122975309_item	2821713	et	3	main
et	doc_685122975309_item	2821724	et	3	main
gümnaasiumi	doc_685122975309_item	2821733	et	4	main
vabal	doc_685122975309_item	2821734	et	3	main
ajal	doc_685122975309_item	2821735	et	4	main
spordiga	doc_685122975309_item	2821743	et	3	main
sest	doc_685122975309_item	2821748	et	4	main
ma	doc_685122975309_item	2821751	et	3	main
ttü	doc_685122975309_item	2821753	et	4	main
sport	doc_685122975309_item	2821766	et	3	main
ttü	doc_685122975309_item	2821805	et	4	main
ainult	doc_685122975309_item	2821806	et	4	main
on	doc_685122975309_item	2821820	et	4	main
ja	doc_685122975308_item	2821663	et	3	main
mida	doc_685122975308_item	2821668	et	4	main
ma	doc_685122975308_item	2821669	et	3	main
ootan	doc_685122975308_item	2821670	et	3	main
tunnidest	doc_685122975308_item	2821673	et	4	main
eelkõige	doc_685122975308_item	2821674	et	3	main
teadmiseid	doc_685122975308_item	2821685	et	4	main
ja	doc_685122975308_item	2821686	et	3	main
õppimisest	doc_685122975308_item	2821693	et	4	main
sündinud	doc_685122975309_item	2821707	et	4	main
narvas	doc_685122975309_item	2821708	et	4	main
rõõmus	doc_685122975309_item	2821723	et	4	main
tegelen	doc_685122975309_item	2821742	et	3	main
praegu	doc_685122975309_item	2821744	et	3	main
iga	doc_685122975309_item	2821758	et	4	main
mis	doc_685122975309_item	2821772	et	4	main
puutub	doc_685122975309_item	2821773	et	3	main
ma	doc_685122975309_item	2821811	et	3	main
suhtlemine	doc_685122975309_item	2821831	et	4	main
kui	doc_685122975309_item	2821832	et	3	main
mina	doc_685122975310_item	2821839	et	4	main
kaks	doc_685122975310_item	2821849	et	3	main
vanematega	doc_685122975310_item	2821859	et	4	main
mul	doc_685122975310_item	2821860	et	3	main
kui	doc_685122975310_item	2821868	et	3	main
ttüs	doc_685122975310_item	2821917	et	4	main
meeldib	doc_685122975310_item	2821929	et	3	main
veel	doc_685122975310_item	2821933	et	4	main
see	doc_685122975310_item	2821939	et	3	main
naisi	doc_685122975310_item	2821957	et	3	main
kasulikud	doc_685122975310_item	2821970	et	3	main
keel	doc_685122975310_item	2821978	et	4	main
ja	doc_685122975311_item	2821981	et	3	main
ülikool	doc_685122975311_item	2821982	et	4	main
minu	doc_685122975311_item	2821983	et	3	main
nimi	doc_685122975311_item	2821984	et	3	main
on	doc_685122975311_item	2821985	et	4	main
eesnimi	doc_685122975311_item	2821986	et	3	main
mul	doc_685122975311_item	2821988	et	3	main
on	doc_685122975311_item	2821989	et	4	main
19	doc_685122975311_item	2821990	et	2	main
aastat	doc_685122975311_item	2821991	et	3	main
olen	doc_685122975309_item	2821722	et	3	main
sündinud	doc_685122975309_item	2821727	et	4	main
ma	doc_685122975309_item	2821729	et	3	main
narvas	doc_685122975309_item	2821736	et	4	main
ma	doc_685122975309_item	2821737	et	3	main
käin	doc_685122975309_item	2821738	et	3	main
discol	doc_685122975309_item	2821739	et	4	main
jalutan	doc_685122975309_item	2821740	et	3	main
minu	doc_685122975309_item	2821774	et	3	main
eriala	doc_685122975309_item	2821775	et	4	main
siis	doc_685122975309_item	2821776	et	3	main
ma	doc_685122975309_item	2821777	et	3	main
tahan	doc_685122975309_item	2821778	et	3	main
ütelda	doc_685122975309_item	2821779	et	4	main
et	doc_685122975309_item	2821780	et	3	main
energiat	doc_685122975309_item	2821781	et	3	main
on	doc_685122975309_item	2821782	et	4	main
väga	doc_685122975309_item	2821783	et	3	main
huvitav	doc_685122975309_item	2821784	et	4	main
eriala	doc_685122975309_item	2821785	et	4	main
ta	doc_685122975309_item	2821786	et	4	main
pakkub	doc_685122975309_item	2821787	et	4	main
palju	doc_685122975309_item	2821788	et	4	main
võimalusi	doc_685122975309_item	2821789	et	3	main
edaspidi	doc_685122975309_item	2821790	et	3	main
energia	doc_685122975309_item	2821791	et	4	main
on	doc_685122975309_item	2821792	et	4	main
vaja	doc_685122975309_item	2821793	et	4	main
inimestele	doc_685122975309_item	2821794	et	3	main
ma	doc_685122975309_item	2821795	et	3	main
ei	doc_685122975309_item	2821796	et	4	main
või	doc_685122975309_item	2821797	et	4	main
kujutada	doc_685122975309_item	2821798	et	3	main
meie	doc_685122975309_item	2821799	et	4	main
elu	doc_685122975309_item	2821800	et	4	main
energia	doc_685122975309_item	2821801	et	4	main
ilma	doc_685122975309_item	2821802	et	4	main
ma	doc_685122975309_item	2821803	et	3	main
ttü	doc_685122975309_item	2821819	et	4	main
ilus	doc_685122975309_item	2821822	et	4	main
ma	doc_685122975309_item	2821825	et	3	main
on	doc_685122975309_item	2821833	et	4	main
gümnaasium	doc_685122975310_item	2821848	et	3	main
tagasi	doc_685122975310_item	2821851	et	3	main
suuna	doc_685122975310_item	2821854	et	4	main
mina	doc_685122975310_item	2821869	et	4	main
väga	doc_685122975310_item	2821872	et	3	main
oli	doc_685122975310_item	2821901	et	3	main
praaktika	doc_685122975310_item	2821903	et	3	main
ttü	doc_685122975310_item	2821905	et	4	main
on	doc_685122975310_item	2821908	et	4	main
üks	doc_685122975310_item	2821909	et	3	main
eriala	doc_685122975310_item	2821910	et	4	main
koolis	doc_685122975310_item	2821913	et	4	main
on	doc_685122975310_item	2821918	et	4	main
mina	doc_685122975310_item	2821920	et	4	main
oma	doc_685122975310_item	2821923	et	4	main
on	doc_685122975310_item	2821940	et	4	main
väga	doc_685122975310_item	2821941	et	3	main
nõutus	doc_685122975310_item	2821942	et	4	main
on	doc_685122975310_item	2821947	et	4	main
parem	doc_685122975310_item	2821950	et	4	main
parem	doc_685122975310_item	2821975	et	4	main
teada	doc_685122975310_item	2821976	et	3	main
essee	doc_685122975311_item	2821979	et	4	main
tallinna	doc_685122975311_item	2821995	et	4	main
pae	doc_685122975311_item	2821996	et	3	main
minu	doc_685122975311_item	2822023	et	3	main
ma	doc_685122975311_item	2822041	et	3	main
töö	doc_685122975311_item	2822047	et	4	main
raske	doc_685122975311_item	2822055	et	4	main
õppida	doc_685122975311_item	2822056	et	3	main
mina	doc_685122975312_item	2822083	et	4	main
on	doc_685122975312_item	2822088	et	4	main
perekonnanimi	doc_685122975312_item	2822090	et	3	main
aastat	doc_685122975312_item	2822094	et	3	main
elan	doc_685122975312_item	2822096	et	3	main
on	doc_685122975312_item	2822114	et	4	main
huvitav	doc_685122975312_item	2822116	et	4	main
oluline	doc_685122975312_item	2822118	et	4	main
eriala	doc_685122975312_item	2822119	et	4	main
eestis	doc_685122975312_item	2822120	et	3	main
on	doc_685122975312_item	2822121	et	4	main
sellel	doc_685122975312_item	2822126	et	4	main
ja	doc_685122975312_item	2822138	et	3	main
on	doc_685122975312_item	2822140	et	4	main
kohvid	doc_685122975312_item	2822151	et	3	main
linn	doc_685122975312_item	2822158	et	3	main
õpetajad	doc_685122975312_item	2822165	et	4	main
halb	doc_685122975312_item	2822166	et	3	main
et	doc_685122975312_item	2822167	et	3	main
gramaatika	doc_685122975312_item	2822181	et	4	main
vene	doc_685122975312_item	2822185	et	4	main
mina	doc_685122975313_item	2822188	et	4	main
ja	doc_685122975313_item	2822189	et	3	main
sain	doc_685122975313_item	2822199	et	3	main
ökonoomikat	doc_685122975313_item	2822203	et	3	main
kõike	doc_685122975313_item	2822235	et	4	main
et	doc_685122975313_item	2822240	et	3	main
hoonega	doc_685122975313_item	2822253	et	4	main
sellepärast	doc_685122975313_item	2822254	et	3	main
see	doc_685122975313_item	2822255	et	3	main
on	doc_685122975313_item	2822256	et	4	main
hoone	doc_685122975313_item	2822259	et	4	main
leia	doc_685122975313_item	2822262	et	4	main
üliõpilaselt	doc_685122975313_item	2822274	et	3	main
rohkem	doc_685122975313_item	2822291	et	4	main
jalutada	doc_685122975313_item	2822296	et	3	main
siis	doc_685122975313_item	2822305	et	3	main
on	doc_685122975313_item	2822306	et	4	main
et	doc_685122975313_item	2822308	et	3	main
hakkan	doc_685122975313_item	2822310	et	3	main
näiteks	doc_685122975313_item	2822314	et	4	main
viimasel	doc_685122975313_item	2822319	et	3	main
peatusel	doc_685122975313_item	2822320	et	4	main
eesti	doc_685122975309_item	2821827	et	4	main
tundidelt	doc_685122975309_item	2821829	et	3	main
rohkem	doc_685122975309_item	2821830	et	4	main
ülikool	doc_685122975310_item	2821838	et	4	main
lasnamäel	doc_685122975310_item	2821842	et	3	main
mikroraioonis	doc_685122975310_item	2821844	et	4	main
lõpetasin	doc_685122975310_item	2821845	et	3	main
lasnamäe	doc_685122975310_item	2821846	et	3	main
aastat	doc_685122975310_item	2821850	et	3	main
on	doc_685122975310_item	2821861	et	4	main
üks	doc_685122975310_item	2821862	et	3	main
vend	doc_685122975310_item	2821863	et	3	main
ta	doc_685122975310_item	2821864	et	4	main
on	doc_685122975310_item	2821865	et	4	main
huvitav	doc_685122975310_item	2821873	et	4	main
rõõmus	doc_685122975310_item	2821875	et	4	main
noormees	doc_685122975310_item	2821876	et	4	main
minu	doc_685122975310_item	2821877	et	3	main
hobbid	doc_685122975310_item	2821878	et	4	main
on	doc_685122975310_item	2821879	et	4	main
daiving	doc_685122975310_item	2821880	et	4	main
ja	doc_685122975310_item	2821881	et	3	main
kalapüük	doc_685122975310_item	2821882	et	3	main
ja	doc_685122975310_item	2821883	et	3	main
see	doc_685122975310_item	2821884	et	3	main
on	doc_685122975310_item	2821885	et	4	main
perekonna	doc_685122975310_item	2821886	et	4	main
üks	doc_685122975310_item	2821888	et	3	main
biisnes	doc_685122975310_item	2821887	et	4	main
aasta	doc_685122975310_item	2821889	et	4	main
oli	doc_685122975310_item	2821890	et	3	main
mereväes	doc_685122975310_item	2821891	et	3	main
pärast	doc_685122975310_item	2821892	et	4	main
natukene	doc_685122975310_item	2821893	et	4	main
töötasin	doc_685122975310_item	2821894	et	3	main
seal	doc_685122975310_item	2821895	et	4	main
kolmas	doc_685122975310_item	2821843	et	3	main
vene	doc_685122975310_item	2821847	et	4	main
keemia	doc_685122975310_item	2821852	et	4	main
bioloogiline	doc_685122975310_item	2821853	et	4	main
olen	doc_685122975310_item	2821855	et	3	main
valaline	doc_685122975310_item	2821856	et	4	main
elan	doc_685122975310_item	2821857	et	3	main
koos	doc_685122975310_item	2821858	et	4	main
natukene	doc_685122975310_item	2821866	et	4	main
mina	doc_685122975310_item	2821870	et	4	main
on	doc_685122975310_item	2821871	et	4	main
ja	doc_685122975310_item	2821874	et	3	main
pärast	doc_685122975310_item	2821896	et	4	main
juba	doc_685122975310_item	2821907	et	3	main
tulin	doc_685122975310_item	2821921	et	3	main
eriala	doc_685122975310_item	2821924	et	4	main
õppima	doc_685122975310_item	2821925	et	3	main
ma	doc_685122975310_item	2821930	et	3	main
eriala	doc_685122975310_item	2821943	et	4	main
kindlasti	doc_685122975310_item	2821948	et	3	main
ja	doc_685122975310_item	2821958	et	3	main
väga	doc_685122975310_item	2821960	et	3	main
õppejõud	doc_685122975310_item	2821962	et	4	main
aga	doc_685122975310_item	2821963	et	3	main
palju	doc_685122975310_item	2821969	et	4	main
vana	doc_685122975311_item	2821992	et	4	main
ma	doc_685122975311_item	2821993	et	3	main
mulle	doc_685122975311_item	2821998	et	4	main
sest	doc_685122975311_item	2822022	et	4	main
isa	doc_685122975311_item	2822024	et	4	main
on	doc_685122975311_item	2822031	et	4	main
väga	doc_685122975311_item	2822032	et	3	main
popularne	doc_685122975311_item	2822033	et	4	main
ja	doc_685122975311_item	2822034	et	3	main
perspektivne	doc_685122975311_item	2822035	et	4	main
töö	doc_685122975311_item	2822036	et	4	main
ma	doc_685122975311_item	2822037	et	3	main
head	doc_685122975311_item	2822044	et	4	main
rahat	doc_685122975311_item	2822045	et	4	main
oma	doc_685122975311_item	2822046	et	4	main
on	doc_685122975311_item	2822053	et	4	main
väga	doc_685122975311_item	2822054	et	3	main
vaja	doc_685122975311_item	2822058	et	4	main
ja	doc_685122975312_item	2822084	et	3	main
nimi	doc_685122975312_item	2822087	et	3	main
ma	doc_685122975312_item	2822091	et	3	main
ehitus	doc_685122975312_item	2822100	et	4	main
see	doc_685122975312_item	2822113	et	3	main
on	doc_685122975312_item	2822127	et	4	main
tööl	doc_685122975312_item	2822128	et	3	main
profession	doc_685122975312_item	2822132	et	4	main
vi	doc_685122975312_item	2822145	et	4	main
suur	doc_685122975312_item	2822157	et	3	main
palju	doc_685122975312_item	2822161	et	4	main
et	doc_685122975312_item	2822175	et	3	main
olla	doc_685122975312_item	2822183	et	3	main
aastat	doc_685122975313_item	2822193	et	3	main
tagasi	doc_685122975313_item	2822198	et	3	main
tahan	doc_685122975313_item	2822202	et	3	main
1aasta	doc_685122975310_item	2821897	et	4	main
ja	doc_685122975310_item	2821899	et	3	main
vanem	doc_685122975310_item	2821911	et	4	main
huvitav	doc_685122975310_item	2821915	et	4	main
mulle	doc_685122975310_item	2821928	et	4	main
tea	doc_685122975310_item	2821932	et	4	main
miks	doc_685122975310_item	2821934	et	4	main
aga	doc_685122975310_item	2821935	et	3	main
meeldib	doc_685122975310_item	2821936	et	3	main
ma	doc_685122975310_item	2821937	et	3	main
mõtlen	doc_685122975310_item	2821938	et	3	main
targed	doc_685122975310_item	2821956	et	3	main
keele	doc_685122975310_item	2821965	et	4	main
tundidelt	doc_685122975310_item	2821966	et	3	main
ma	doc_685122975310_item	2821967	et	3	main
eesti	doc_685122975310_item	2821977	et	4	main
mina	doc_685122975311_item	2821980	et	4	main
õpesin	doc_685122975311_item	2821994	et	4	main
meeldib	doc_685122975311_item	2821999	et	3	main
on	doc_685122975311_item	2822025	et	4	main
insener	doc_685122975311_item	2822026	et	3	main
aga	doc_685122975311_item	2822027	et	3	main
üldse	doc_685122975311_item	2822028	et	3	main
täna	doc_685122975311_item	2822029	et	4	main
tulevikus	doc_685122975311_item	2822040	et	4	main
est	doc_685122975311_item	2822048	et	4	main
õppida	doc_685122975311_item	2822059	et	3	main
on	doc_685122975311_item	2822079	et	4	main
ülikool	doc_685122975312_item	2822085	et	4	main
huvitan	doc_685122975312_item	2822098	et	3	main
õpida	doc_685122975312_item	2822106	et	4	main
ehitus	doc_685122975312_item	2822107	et	4	main
tsivil	doc_685122975312_item	2822111	et	4	main
väga	doc_685122975312_item	2822115	et	3	main
see	doc_685122975312_item	2822129	et	3	main
ttü	doc_685122975312_item	2822133	et	4	main
see	doc_685122975312_item	2822139	et	3	main
tula	doc_685122975312_item	2822144	et	4	main
vahem	doc_685122975312_item	2822150	et	4	main
ja	doc_685122975312_item	2822152	et	3	main
üleõpilasi	doc_685122975312_item	2822154	et	3	main
nägu	doc_685122975312_item	2822156	et	4	main
on	doc_685122975312_item	2822160	et	4	main
inimesi	doc_685122975312_item	2822162	et	4	main
palju	doc_685122975312_item	2822163	et	4	main
vene	doc_685122975312_item	2822171	et	4	main
võib	doc_685122975312_item	2822182	et	3	main
keeles	doc_685122975312_item	2822186	et	4	main
essee	doc_685122975313_item	2822187	et	4	main
aru	doc_685122975313_item	2822200	et	4	main
eesti	doc_685122975313_item	2822223	et	4	main
tudeng	doc_685122975313_item	2822225	et	3	main
ülikooli	doc_685122975313_item	2822226	et	4	main
ise	doc_685122975313_item	2822233	et	4	main
pead	doc_685122975313_item	2822234	et	4	main
tuntub	doc_685122975313_item	2822239	et	4	main
harjuma	doc_685122975313_item	2822247	et	3	main
olid	doc_685122975313_item	2822250	et	4	main
väikesed	doc_685122975313_item	2822251	et	4	main
probleemid	doc_685122975313_item	2822252	et	3	main
on	doc_685122975313_item	2822265	et	4	main
aega	doc_685122975313_item	2822267	et	4	main
aga	doc_685122975313_item	2822268	et	3	main
kindel	doc_685122975313_item	2822276	et	3	main
parim	doc_685122975313_item	2822278	et	4	main
on	doc_685122975313_item	2822280	et	4	main
uued	doc_685122975313_item	2822281	et	3	main
sõbrad	doc_685122975313_item	2822282	et	3	main
see	doc_685122975313_item	2822283	et	3	main
on	doc_685122975313_item	2822284	et	4	main
väga	doc_685122975313_item	2822285	et	3	main
on	doc_685122975313_item	2822290	et	4	main
ma	doc_685122975313_item	2822294	et	3	main
võin	doc_685122975313_item	2822295	et	3	main
käia	doc_685122975313_item	2822298	et	4	main
kaudu	doc_685122975313_item	2822303	et	3	main
ma	doc_685122975313_item	2822315	et	3	main
olin	doc_685122975313_item	2822316	et	3	main
korras	doc_685122975313_item	2822318	et	4	main
on	doc_685122975313_item	2822328	et	4	main
ka	doc_685122975313_item	2822329	et	3	main
on	doc_685122975313_item	2822332	et	4	main
oli	doc_685122975310_item	2821914	et	3	main
aga	doc_685122975310_item	2821916	et	3	main
parem	doc_685122975310_item	2821919	et	4	main
just	doc_685122975310_item	2821922	et	3	main
selle	doc_685122975310_item	2821926	et	4	main
pärast	doc_685122975310_item	2821927	et	4	main
ei	doc_685122975310_item	2821931	et	4	main
minu	doc_685122975310_item	2821944	et	3	main
muljed	doc_685122975310_item	2821945	et	3	main
ttüst	doc_685122975310_item	2821946	et	4	main
kõigi	doc_685122975310_item	2821949	et	4	main
ülikool	doc_685122975310_item	2821951	et	4	main
eestis	doc_685122975310_item	2821952	et	3	main
palju	doc_685122975310_item	2821953	et	4	main
ilusad	doc_685122975310_item	2821954	et	3	main
ja	doc_685122975310_item	2821955	et	3	main
muidugi	doc_685122975310_item	2821959	et	4	main
head	doc_685122975310_item	2821961	et	4	main
eesti	doc_685122975310_item	2821964	et	4	main
ootan	doc_685122975310_item	2821968	et	3	main
teadmised	doc_685122975310_item	2821971	et	4	main
ja	doc_685122975310_item	2821972	et	3	main
muidugi	doc_685122975310_item	2821973	et	4	main
tahan	doc_685122975310_item	2821974	et	3	main
perekonnanimi	doc_685122975311_item	2821987	et	3	main
gümnaasiumis	doc_685122975311_item	2821997	et	3	main
lugeda	doc_685122975311_item	2822000	et	3	main
ramatud	doc_685122975311_item	2822001	et	4	main
magada	doc_685122975311_item	2822002	et	3	main
veel	doc_685122975311_item	2822003	et	4	main
ma	doc_685122975311_item	2822004	et	3	main
armastan	doc_685122975311_item	2822005	et	3	main
mängida	doc_685122975311_item	2822006	et	3	main
malet	doc_685122975311_item	2822007	et	3	main
ma	doc_685122975311_item	2822008	et	3	main
kain	doc_685122975311_item	2822009	et	3	main
maleklubis	doc_685122975311_item	2822010	et	3	main
koos	doc_685122975311_item	2822011	et	4	main
sõpradega	doc_685122975311_item	2822012	et	3	main
ma	doc_685122975311_item	2822013	et	3	main
olen	doc_685122975311_item	2822014	et	3	main
väga	doc_685122975311_item	2822015	et	3	main
energeline	doc_685122975311_item	2822016	et	4	main
pois	doc_685122975311_item	2822017	et	3	main
ma	doc_685122975311_item	2822018	et	3	main
tahan	doc_685122975311_item	2822019	et	3	main
sada	doc_685122975311_item	2822020	et	4	main
inseneriks	doc_685122975311_item	2822021	et	3	main
et	doc_685122975311_item	2822039	et	3	main
saada	doc_685122975311_item	2822043	et	4	main
esimese	doc_685122975311_item	2822049	et	3	main
on	doc_685122975311_item	2822057	et	4	main
iga	doc_685122975311_item	2822060	et	4	main
teadused	doc_685122975311_item	2822078	et	3	main
vaga	doc_685122975311_item	2822080	et	4	main
pahad	doc_685122975311_item	2822081	et	4	main
eesnimi	doc_685122975312_item	2822089	et	3	main
19	doc_685122975312_item	2822093	et	2	main
tallinnas	doc_685122975312_item	2822097	et	4	main
in	doc_685122975312_item	2822099	et	4	main
osada	doc_685122975312_item	2822108	et	4	main
tööstus	doc_685122975312_item	2822109	et	3	main
ehitus	doc_685122975312_item	2822112	et	4	main
ehitus	doc_685122975311_item	2822030	et	4	main
arvan	doc_685122975311_item	2822038	et	3	main
võin	doc_685122975311_item	2822042	et	3	main
mulje	doc_685122975311_item	2822050	et	4	main
et	doc_685122975311_item	2822051	et	3	main
ttüs	doc_685122975311_item	2822052	et	4	main
õppeaine	doc_685122975311_item	2822061	et	4	main
aga	doc_685122975311_item	2822062	et	3	main
kõik	doc_685122975311_item	2822063	et	4	main
õppeaine	doc_685122975311_item	2822064	et	4	main
väga	doc_685122975311_item	2822065	et	3	main
keerulised	doc_685122975311_item	2822066	et	4	main
ttüs	doc_685122975311_item	2822067	et	4	main
on	doc_685122975311_item	2822068	et	4	main
vaga	doc_685122975311_item	2822069	et	4	main
tugevad	doc_685122975311_item	2822070	et	4	main
õpejõudu	doc_685122975311_item	2822071	et	4	main
ma	doc_685122975311_item	2822072	et	3	main
tahaksin	doc_685122975311_item	2822073	et	3	main
valdada	doc_685122975311_item	2822074	et	4	main
eesti	doc_685122975311_item	2822075	et	4	main
keelt	doc_685122975311_item	2822076	et	4	main
minu	doc_685122975311_item	2822077	et	3	main
essee	doc_685122975312_item	2822082	et	4	main
minu	doc_685122975312_item	2822086	et	3	main
olen	doc_685122975312_item	2822092	et	3	main
vana	doc_685122975312_item	2822095	et	4	main
jalgpalli	doc_685122975312_item	2822101	et	4	main
ja	doc_685122975312_item	2822102	et	3	main
infotehnologia	doc_685122975312_item	2822103	et	4	main
ma	doc_685122975312_item	2822104	et	3	main
tulen	doc_685122975312_item	2822105	et	3	main
ja	doc_685122975312_item	2822110	et	3	main
ja	doc_685122975312_item	2822117	et	3	main
palju	doc_685122975312_item	2822122	et	4	main
ehitus	doc_685122975312_item	2822123	et	4	main
firmad	doc_685122975312_item	2822124	et	3	main
on	doc_685122975312_item	2822130	et	4	main
on	doc_685122975312_item	2822134	et	4	main
suur	doc_685122975312_item	2822136	et	3	main
väga	doc_685122975312_item	2822141	et	3	main
suur	doc_685122975312_item	2822142	et	3	main
aega	doc_685122975312_item	2822143	et	4	main
õpehoones	doc_685122975312_item	2822149	et	4	main
kus	doc_685122975312_item	2822159	et	3	main
ei	doc_685122975312_item	2822168	et	4	main
ole	doc_685122975312_item	2822169	et	4	main
infot	doc_685122975312_item	2822170	et	3	main
eesti	doc_685122975312_item	2822176	et	4	main
loengutel	doc_685122975312_item	2822178	et	4	main
me	doc_685122975312_item	2822179	et	4	main
õpime	doc_685122975312_item	2822180	et	3	main
ülikool	doc_685122975313_item	2822190	et	4	main
olen	doc_685122975313_item	2822191	et	3	main
et	doc_685122975313_item	2822201	et	3	main
olen	doc_685122975313_item	2822221	et	3	main
leidma	doc_685122975313_item	2822236	et	3	main
lugema	doc_685122975313_item	2822237	et	4	main
see	doc_685122975313_item	2822241	et	3	main
raske	doc_685122975313_item	2822243	et	4	main
et	doc_685122975313_item	2822261	et	3	main
vanemalt	doc_685122975313_item	2822273	et	4	main
inimesi	doc_685122975313_item	2822292	et	4	main
kellettega	doc_685122975313_item	2822293	et	4	main
klubis	doc_685122975313_item	2822297	et	3	main
või	doc_685122975313_item	2822299	et	4	main
lihtsalt	doc_685122975313_item	2822300	et	4	main
lobiseda	doc_685122975313_item	2822301	et	3	main
veel	doc_685122975313_item	2822304	et	4	main
koplis	doc_685122975313_item	2822321	et	3	main
aga	doc_685122975313_item	2822327	et	3	main
miinused	doc_685122975313_item	2822330	et	3	main
on	doc_685122975313_item	2822342	et	4	main
teeb	doc_685122975313_item	2822368	et	3	main
mu	doc_685122975313_item	2822369	et	3	main
nüüd	doc_685122975313_item	2822372	et	4	main
loengud	doc_685122975313_item	2822379	et	3	main
suurem	doc_685122975313_item	2822380	et	4	main
osa	doc_685122975313_item	2822381	et	4	main
meeldib	doc_685122975313_item	2822382	et	3	main
on	doc_685122975313_item	2822390	et	4	main
ma	doc_685122975313_item	2822393	et	3	main
i	doc_688103945038_item	2822435	et	4	main
ettevõtlik	doc_688103945038_item	2822445	et	3	main
naine	doc_688103945038_item	2822446	et	3	main
küla	doc_688103945038_item	2822456	et	4	main
külasse	doc_688103945038_item	2822457	et	3	main
otsitakse	doc_688103945038_item	2822458	et	3	main
on	doc_688103945038_item	2822467	et	4	main
üle	doc_688103945038_item	2822470	et	3	main
pireti	doc_688103945038_item	2822480	et	4	main
ta	doc_688103945038_item	2822483	et	4	main
siberisse	doc_688103945038_item	2822484	et	4	main
jõudma	doc_688103945038_item	2822485	et	3	main
üllatunud	doc_688103945038_item	2822493	et	4	main
õppeaasta	doc_688103945038_item	2822525	et	4	main
siin	doc_688103945038_item	2822542	et	4	main
sügisel	doc_688103945038_item	2822543	et	3	main
on	doc_688103945038_item	2822549	et	4	main
mahlakas	doc_688103945038_item	2822566	et	4	main
ei	doc_688103945038_item	2822619	et	4	main
kartma	doc_688103945038_item	2822620	et	3	main
mulle	doc_688103945038_item	2822622	et	4	main
toodi	doc_688103945038_item	2822625	et	4	main
talvepuud	doc_688103945038_item	2822626	et	4	main
ja	doc_685122975312_item	2822125	et	3	main
oluline	doc_685122975312_item	2822131	et	4	main
väga	doc_685122975312_item	2822135	et	3	main
ülikool	doc_685122975312_item	2822137	et	4	main
õpehoones	doc_685122975312_item	2822146	et	4	main
kuni	doc_685122975312_item	2822147	et	3	main
i	doc_685122975312_item	2822148	et	4	main
palju	doc_685122975312_item	2822153	et	4	main
ttü	doc_685122975312_item	2822155	et	4	main
huvitavaid	doc_685122975312_item	2822164	et	4	main
keeles	doc_685122975312_item	2822172	et	4	main
ma	doc_685122975312_item	2822173	et	3	main
tahan	doc_685122975312_item	2822174	et	3	main
keele	doc_685122975312_item	2822177	et	4	main
infot	doc_685122975312_item	2822184	et	3	main
kaheksateist	doc_685122975313_item	2822192	et	4	main
vana	doc_685122975313_item	2822194	et	4	main
juba	doc_685122975313_item	2822195	et	3	main
kaks	doc_685122975313_item	2822196	et	3	main
aastat	doc_685122975313_item	2822197	et	3	main
uurida	doc_685122975313_item	2822204	et	3	main
sellest	doc_685122975313_item	2822205	et	4	main
ma	doc_685122975313_item	2822207	et	3	main
alustasin	doc_685122975313_item	2822208	et	3	main
veel	doc_685122975313_item	2822209	et	4	main
õppeaastast	doc_685122975313_item	2822206	et	4	main
kevadel	doc_685122975313_item	2822210	et	4	main
mina	doc_685122975313_item	2822211	et	4	main
olen	doc_685122975313_item	2822212	et	3	main
õpilane	doc_685122975313_item	2822213	et	3	main
aga	doc_685122975313_item	2822214	et	3	main
nüüd	doc_685122975313_item	2822215	et	4	main
üliõpilane	doc_685122975313_item	2822216	et	3	main
ka	doc_685122975313_item	2822217	et	3	main
tahan	doc_685122975313_item	2822218	et	3	main
märkida	doc_685122975313_item	2822219	et	4	main
et	doc_685122975313_item	2822220	et	3	main
parima	doc_685122975313_item	2822222	et	4	main
ülikooli	doc_685122975313_item	2822224	et	4	main
mul	doc_685122975313_item	2822249	et	3	main
küllaltki	doc_685122975313_item	2822257	et	4	main
ja	doc_685122975313_item	2822260	et	3	main
tubat	doc_685122975313_item	2822264	et	4	main
vaja	doc_685122975313_item	2822266	et	4	main
on	doc_685122975313_item	2822269	et	4	main
ka	doc_685122975313_item	2822270	et	3	main
võimalus	doc_685122975313_item	2822271	et	3	main
küsida	doc_685122975313_item	2822272	et	3	main
et	doc_685122975313_item	2822277	et	3	main
ülikoolis	doc_685122975313_item	2822279	et	4	main
mul	doc_685122975313_item	2822289	et	3	main
interneti	doc_685122975313_item	2822302	et	4	main
plus	doc_685122975313_item	2822307	et	4	main
ma	doc_685122975313_item	2822309	et	3	main
parem	doc_685122975313_item	2822311	et	4	main
tallinna	doc_685122975313_item	2822312	et	4	main
ma	doc_685122975313_item	2822324	et	3	main
ülikoolini	doc_685122975313_item	2822340	et	4	main
see	doc_685122975313_item	2822341	et	3	main
maardust	doc_685122975313_item	2822348	et	4	main
tahaks	doc_685122975313_item	2822351	et	3	main
teaduskonnas	doc_685122975313_item	2822355	et	4	main
õpivad	doc_685122975313_item	2822356	et	3	main
väga	doc_685122975313_item	2822357	et	3	main
palju	doc_685122975313_item	2822358	et	4	main
ilusaid	doc_685122975313_item	2822359	et	3	main
elu	doc_685122975313_item	2822227	et	4	main
mitte	doc_685122975313_item	2822228	et	3	main
nagu	doc_685122975313_item	2822229	et	3	main
koolis	doc_685122975313_item	2822230	et	4	main
siin	doc_685122975313_item	2822231	et	4	main
sa	doc_685122975313_item	2822232	et	3	main
algusel	doc_685122975313_item	2822238	et	4	main
on	doc_685122975313_item	2822242	et	4	main
aga	doc_685122975313_item	2822244	et	3	main
pärast	doc_685122975313_item	2822245	et	4	main
hakkad	doc_685122975313_item	2822246	et	3	main
ka	doc_685122975313_item	2822248	et	3	main
suur	doc_685122975313_item	2822258	et	3	main
vajalikku	doc_685122975313_item	2822263	et	4	main
olen	doc_685122975313_item	2822275	et	3	main
hea	doc_685122975313_item	2822286	et	4	main
et	doc_685122975313_item	2822287	et	3	main
nüüd	doc_685122975313_item	2822288	et	4	main
teadma	doc_685122975313_item	2822313	et	3	main
esimeses	doc_685122975313_item	2822317	et	3	main
nüüd	doc_685122975313_item	2822323	et	4	main
siin	doc_685122975313_item	2822326	et	4	main
mul	doc_685122975313_item	2822331	et	3	main
vaja	doc_685122975313_item	2822333	et	4	main
natukene	doc_685122975313_item	2822343	et	4	main
tallinnini	doc_685122975313_item	2822349	et	4	main
märkida	doc_685122975313_item	2822352	et	4	main
et	doc_685122975313_item	2822353	et	3	main
tüdrukuid	doc_685122975313_item	2822360	et	4	main
kõikjal	doc_685122975313_item	2822363	et	3	main
ja	doc_685122975313_item	2822364	et	3	main
see	doc_685122975313_item	2822365	et	3	main
oma	doc_685122975313_item	2822366	et	4	main
mul	doc_685122975313_item	2822373	et	3	main
uued	doc_685122975313_item	2822375	et	3	main
ülikoolis	doc_685122975313_item	2822377	et	4	main
nimetatakse	doc_685122975313_item	2822378	et	3	main
on	doc_685122975313_item	2822385	et	4	main
ka	doc_685122975313_item	2822386	et	3	main
sellised	doc_685122975313_item	2822387	et	4	main
asjad	doc_685122975313_item	2822388	et	3	main
vähemalt	doc_685122975313_item	2822405	et	4	main
mul	doc_685122975313_item	2822406	et	3	main
minu	doc_685122975313_item	2822421	et	3	main
ja	doc_685122975313_item	2822423	et	3	main
pange	doc_688103945038_item	2822436	et	4	main
piret	doc_688103945038_item	2822442	et	4	main
nägema	doc_688103945038_item	2822448	et	3	main
kuulutus	doc_688103945038_item	2822452	et	4	main
siberisse	doc_688103945038_item	2822454	et	4	main
ülem-suetuki	doc_688103945038_item	2822455	et	4	main
konkurssi	doc_688103945038_item	2822465	et	4	main
nädala	doc_688103945038_item	2822472	et	3	main
nende	doc_688103945038_item	2822476	et	4	main
emakeelt	doc_688103945038_item	2822477	et	4	main
õpetama	doc_688103945038_item	2822478	et	3	main
õpetamas	doc_688103945038_item	2822479	et	3	main
jõudes	doc_688103945038_item	2822486	et	3	main
et	doc_688103945038_item	2822487	et	3	main
on	doc_688103945038_item	2822488	et	4	main
kui	doc_688103945038_item	2822494	et	3	main
tulema	doc_688103945038_item	2822496	et	4	main
algust	doc_688103945038_item	2822526	et	4	main
koht	doc_688103945038_item	2822527	et	3	main
kohale	doc_688103945038_item	2822528	et	4	main
jõudis	doc_688103945038_item	2822529	et	3	main
polnud	doc_688103945038_item	2822530	et	3	main
küla	doc_688103945038_item	2822536	et	4	main
võtma	doc_688103945038_item	2822537	et	3	main
võttis	doc_688103945038_item	2822538	et	3	main
kartuleid	doc_688103945038_item	2822539	et	3	main
kartulivõtt	doc_688103945038_item	2822540	et	3	main
tähtsam	doc_688103945038_item	2822546	et	4	main
ettevõtmine	doc_688103945038_item	2822547	et	3	main
ja	doc_688103945038_item	2822553	et	3	main
käib	doc_688103945038_item	2822555	et	3	main
hooga	doc_688103945038_item	2822558	et	3	main
teistmoodi	doc_688103945038_item	2822563	et	3	main
ja	doc_688103945038_item	2822565	et	3	main
mahlakalt	doc_688103945038_item	2822569	et	4	main
saatma	doc_688103945038_item	2822611	et	3	main
uued	doc_688103945038_item	2822614	et	3	main
siberi	doc_688103945038_item	2822616	et	4	main
on	doc_688103945038_item	2822628	et	4	main
päevad	doc_688103945038_item	2822629	et	3	main
veel	doc_688103945038_item	2822630	et	4	main
juba	doc_688103945038_item	2822635	et	3	main
juba	doc_688103945038_item	2822639	et	3	main
sellepärast	doc_685122975313_item	2822322	et	3	main
õpin	doc_685122975313_item	2822325	et	3	main
tundi	doc_685122975313_item	2822337	et	4	main
et	doc_685122975313_item	2822338	et	3	main
sõita	doc_685122975313_item	2822339	et	3	main
iga	doc_685122975313_item	2822345	et	4	main
päev	doc_685122975313_item	2822346	et	3	main
sõita	doc_685122975313_item	2822347	et	3	main
mu	doc_685122975313_item	2822354	et	3	main
nad	doc_685122975313_item	2822361	et	3	main
on	doc_685122975313_item	2822362	et	4	main
elu	doc_685122975313_item	2822370	et	4	main
parem	doc_685122975313_item	2822371	et	4	main
tunnid	doc_685122975313_item	2822376	et	3	main
millised	doc_685122975313_item	2822389	et	3	main
igavad	doc_685122975313_item	2822391	et	3	main
pean	doc_685122975313_item	2822402	et	4	main
neid	doc_685122975313_item	2822403	et	4	main
õppima	doc_685122975313_item	2822404	et	3	main
on	doc_685122975313_item	2822407	et	4	main
kolm	doc_685122975313_item	2822408	et	3	main
õpeaastat	doc_685122975313_item	2822409	et	4	main
muidugi	doc_685122975313_item	2822410	et	4	main
võib	doc_685122975313_item	2822411	et	3	main
olla	doc_685122975313_item	2822412	et	3	main
rohkem	doc_685122975313_item	2822413	et	4	main
loodan	doc_685122975313_item	2822414	et	3	main
et	doc_685122975313_item	2822415	et	3	main
sellised	doc_685122975313_item	2822416	et	4	main
aastad	doc_685122975313_item	2822417	et	3	main
hakkavad	doc_685122975313_item	2822418	et	4	main
olema	doc_685122975313_item	2822419	et	4	main
parimaid	doc_685122975313_item	2822420	et	4	main
elus	doc_685122975313_item	2822422	et	4	main
on	doc_685122975313_item	2822425	et	4	main
sulgudes	doc_688103945038_item	2822437	et	4	main
toomet	doc_688103945038_item	2822443	et	4	main
ta	doc_688103945038_item	2822450	et	4	main
keele	doc_688103945038_item	2822460	et	4	main
nüüd	doc_688103945038_item	2822468	et	4	main
nädal	doc_688103945038_item	2822471	et	3	main
oodatud	doc_688103945038_item	2822489	et	4	main
olin	doc_688103945038_item	2822490	et	3	main
üsna	doc_688103945038_item	2822491	et	3	main
mulle	doc_688103945038_item	2822495	et	4	main
tuldi	doc_688103945038_item	2822497	et	3	main
tahtmist	doc_688103945038_item	2822521	et	4	main
piret	doc_688103945038_item	2822523	et	4	main
pärast	doc_688103945038_item	2822524	et	4	main
on	doc_688103945038_item	2822541	et	4	main
tänaseks	doc_688103945038_item	2822548	et	4	main
salvedes	doc_688103945038_item	2822552	et	4	main
mõnusalt	doc_688103945038_item	2822567	et	4	main
ja	doc_688103945038_item	2822568	et	3	main
mitte	doc_688103945038_item	2822570	et	3	main
vene	doc_688103945038_item	2822571	et	4	main
aktsent	doc_688103945038_item	2822572	et	3	main
aktsendiga	doc_688103945038_item	2822573	et	3	main
vaid	doc_688103945038_item	2822574	et	3	main
poolpõlenud	doc_688103945038_item	2822607	et	4	main
saadetakse	doc_688103945038_item	2822612	et	3	main
talve	doc_688103945038_item	2822617	et	4	main
piret	doc_688103945038_item	2822618	et	4	main
karda	doc_688103945038_item	2822621	et	4	main
juba	doc_688103945038_item	2822623	et	3	main
tooma	doc_688103945038_item	2822624	et	3	main
kuid	doc_688103945038_item	2822633	et	4	main
harjutan	doc_688103945038_item	2822638	et	3	main
päevas	doc_685122975313_item	2822334	et	3	main
umbes	doc_685122975313_item	2822335	et	4	main
kolm	doc_685122975313_item	2822336	et	3	main
raske	doc_685122975313_item	2822344	et	4	main
ka	doc_685122975313_item	2822350	et	3	main
jarjekorras	doc_685122975313_item	2822367	et	4	main
mulle	doc_685122975313_item	2822383	et	4	main
aga	doc_685122975313_item	2822384	et	3	main
aga	doc_685122975313_item	2822392	et	3	main
ei	doc_685122975313_item	2822394	et	4	main
midagi	doc_685122975313_item	2822398	et	4	main
teha	doc_685122975313_item	2822399	et	3	main
lihtsalt	doc_685122975313_item	2822400	et	4	main
ma	doc_685122975313_item	2822401	et	3	main
see	doc_685122975313_item	2822424	et	3	main
ma	doc_685122975313_item	2822428	et	3	main
tahan	doc_685122975313_item	2822429	et	3	main
olevad	doc_688103945038_item	2822438	et	4	main
sõnad	doc_688103945038_item	2822439	et	4	main
õigesse	doc_688103945038_item	2822440	et	3	main
vormi	doc_688103945038_item	2822441	et	4	main
suvel	doc_688103945038_item	2822447	et	3	main
eesti	doc_688103945038_item	2822459	et	4	main
ja	doc_688103945038_item	2822466	et	3	main
eestlastele	doc_688103945038_item	2822474	et	4	main
kinnitusel	doc_688103945038_item	2822481	et	4	main
üllatuma	doc_688103945038_item	2822492	et	3	main
vastu	doc_688103945038_item	2822498	et	3	main
on	doc_685122975313_item	2822374	et	4	main
või	doc_685122975313_item	2822395	et	4	main
sellega	doc_685122975313_item	2822396	et	3	main
mitte	doc_685122975313_item	2822397	et	3	main
see	doc_685122975313_item	2822426	et	3	main
mis	doc_685122975313_item	2822427	et	4	main
ja	doc_685122975313_item	2822430	et	3	main
millega	doc_685122975313_item	2822431	et	3	main
tahan	doc_685122975313_item	2822432	et	3	main
tegeleda	doc_685122975313_item	2822433	et	3	main
eksamitöö	doc_688103945038_item	2822434	et	4	main
on	doc_688103945038_item	2822444	et	4	main
nägi	doc_688103945038_item	2822449	et	3	main
ajalehes	doc_688103945038_item	2822451	et	3	main
et	doc_688103945038_item	2822453	et	3	main
õpetajat	doc_688103945038_item	2822461	et	4	main
piret	doc_688103945038_item	2822462	et	4	main
võitis	doc_688103945038_item	2822463	et	3	main
konkurss	doc_688103945038_item	2822464	et	3	main
juba	doc_688103945038_item	2822469	et	3	main
väikestele	doc_688103945038_item	2822473	et	4	main
need	doc_688103945038_item	2822475	et	3	main
tundis	doc_688103945038_item	2822482	et	3	main
korralik	doc_688103945038_item	2822499	et	3	main
audiga	doc_688103945038_item	2822501	et	3	main
mulle	doc_688103945038_item	2822502	et	4	main
maaliti	doc_688103945038_item	2822503	et	3	main
korralikku	doc_688103945038_item	2822500	et	4	main
siber	doc_688103945038_item	2822504	et	4	main
siberist	doc_688103945038_item	2822505	et	4	main
selline	doc_688103945038_item	2822506	et	4	main
pilt	doc_688103945038_item	2822507	et	3	main
et	doc_688103945038_item	2822508	et	3	main
seal	doc_688103945038_item	2822509	et	4	main
ei	doc_688103945038_item	2822510	et	4	main
lendama	doc_688103945038_item	2822511	et	3	main
lind	doc_688103945038_item	2822513	et	3	main
ega	doc_688103945038_item	2822514	et	3	main
kasva	doc_688103945038_item	2822515	et	4	main
lenda	doc_688103945038_item	2822512	et	4	main
rohi	doc_688103945038_item	2822516	et	4	main
kui	doc_688103945038_item	2822517	et	3	main
noor	doc_688103945038_item	2822518	et	3	main
ja	doc_688103945038_item	2822519	et	3	main
tahtmine	doc_688103945038_item	2822520	et	4	main
täis	doc_688103945038_item	2822522	et	4	main
kool	doc_688103945038_item	2822531	et	4	main
veel	doc_688103945038_item	2822532	et	4	main
algama	doc_688103945038_item	2822533	et	3	main
alganud	doc_688103945038_item	2822534	et	4	main
kõige	doc_688103945038_item	2822544	et	4	main
kartul	doc_688103945038_item	2822550	et	3	main
õppimine	doc_688103945038_item	2822554	et	4	main
täie	doc_688103945038_item	2822556	et	3	main
siinsed	doc_688103945038_item	2822559	et	3	main
räägivad	doc_688103945038_item	2822561	et	3	main
sõnul	doc_688103945038_item	2822604	et	3	main
lapsed	doc_688103945038_item	2822606	et	3	main
raamatud	doc_688103945038_item	2822608	et	4	main
raamatutest	doc_688103945038_item	2822609	et	4	main
varsti	doc_688103945038_item	2822610	et	3	main
eestist	doc_688103945038_item	2822613	et	3	main
õpikud	doc_688103945038_item	2822615	et	3	main
jahe	doc_688103945038_item	2822636	et	3	main
kogu	doc_688103945038_item	2822535	et	4	main
tähtis	doc_688103945038_item	2822545	et	4	main
salv	doc_688103945038_item	2822551	et	3	main
hoog	doc_688103945038_item	2822557	et	3	main
eestlased	doc_688103945038_item	2822560	et	3	main
kuidagi	doc_688103945038_item	2822562	et	3	main
mõnus	doc_688103945038_item	2822564	et	4	main
nagu	doc_688103945038_item	2822575	et	3	main
mõni	doc_688103945038_item	2822576	et	3	main
mõnd	doc_688103945038_item	2822577	et	3	main
murret	doc_688103945038_item	2822578	et	4	main
kool	doc_688103945038_item	2822579	et	4	main
on	doc_688103945038_item	2822580	et	4	main
siiski	doc_688103945038_item	2822581	et	4	main
venemaa	doc_688103945038_item	2822582	et	4	main
kool	doc_688103945038_item	2822583	et	4	main
ja	doc_688103945038_item	2822584	et	3	main
ülejäänud	doc_688103945038_item	2822585	et	4	main
aine	doc_688103945038_item	2822586	et	4	main
ained	doc_688103945038_item	2822587	et	3	main
õpetatakse	doc_688103945038_item	2822588	et	3	main
vene	doc_688103945038_item	2822589	et	4	main
keeles	doc_688103945038_item	2822590	et	4	main
külas	doc_688103945038_item	2822591	et	3	main
elab	doc_688103945038_item	2822592	et	3	main
veidi	doc_688103945038_item	2822593	et	3	main
üle	doc_688103945038_item	2822594	et	3	main
kolmsada	doc_688103945038_item	2822595	et	4	main
kolmesaja	doc_688103945038_item	2822596	et	4	main
inimene	doc_688103945038_item	2822597	et	3	main
emakeelt	doc_688103945038_item	2822598	et	4	main
saab	doc_688103945038_item	2822599	et	3	main
kõik	doc_688103945038_item	2822600	et	4	main
kõigidega	doc_688103945038_item	2822601	et	4	main
rääkida	doc_688103945038_item	2822602	et	3	main
pireti	doc_688103945038_item	2822603	et	4	main
õpivad	doc_688103945038_item	2822605	et	3	main
soe	doc_688103945038_item	2822631	et	4	main
soojad	doc_688103945038_item	2822632	et	3	main
jahedad	doc_688103945038_item	2822637	et	3	main
muud	doc_688103945038_item	2822654	et	4	main
lühendatud	doc_688103945038_item	2822663	et	4	main
sõnad	doc_688103945038_item	2822672	et	4	main
kirjavahemärke	doc_688103945038_item	2822677	et	4	main
naeratus	doc_688103945038_item	2822679	et	4	main
naised	doc_688103945038_item	2822681	et	3	main
kaunim	doc_688103945038_item	2822687	et	4	main
naeratus	doc_688103945038_item	2822688	et	4	main
teeb	doc_688103945038_item	2822689	et	3	main
naisi	doc_688103945038_item	2822690	et	3	main
mehelikumaks	doc_688103945038_item	2822694	et	4	main
kaunimaks	doc_688103945038_item	2822696	et	4	main
paras	doc_688103945038_item	2822698	et	3	main
meie	doc_688103945038_item	2822702	et	4	main
tegutsema	doc_688103945038_item	2822703	et	3	main
aga	doc_688103945038_item	2822704	et	3	main
lisakoormus	doc_688103945038_item	2822705	et	3	main
võima	doc_688103945038_item	2822706	et	3	main
tooma	doc_688103945038_item	2822707	et	3	main
soovimatu	doc_688103945038_item	2822708	et	4	main
tagajärg	doc_688103945038_item	2822709	et	3	main
paras	doc_688103945038_item	2822710	et	3	main
kogus	doc_688103945038_item	2822711	et	4	main
stressi	doc_688103945038_item	2822712	et	4	main
paneb	doc_688103945038_item	2822713	et	3	main
meid	doc_688103945038_item	2822714	et	4	main
tegutsema	doc_688103945038_item	2822715	et	3	main
aga	doc_688103945038_item	2822716	et	3	main
lisakoormus	doc_688103945038_item	2822717	et	3	main
võib	doc_688103945038_item	2822718	et	3	main
tuua	doc_688103945038_item	2822719	et	3	main
soovitatuid	doc_688103945038_item	2822720	et	4	main
tagajargi	doc_688103945038_item	2822721	et	4	main
laskma	doc_688103945038_item	2822725	et	3	main
ja	doc_688103945038_item	2822732	et	3	main
saab	doc_688103945038_item	2822740	et	3	main
abil	doc_688103945038_item	2822745	et	4	main
aparaat	doc_688103945038_item	2822775	et	3	main
ei	doc_688103945038_item	2822779	et	4	main
saa	doc_688103945038_item	2822780	et	4	main
lõunasooki	doc_688103945038_item	2822826	et	4	main
ka	doc_688103945038_item	2822829	et	3	main
pahandab	doc_688103945038_item	2822831	et	3	main
inimest	doc_688103945038_item	2822832	et	3	main
küll	doc_688103945038_item	2822839	et	4	main
lause	doc_688103945038_item	2822842	et	4	main
sõnad	doc_688103945038_item	2822848	et	4	main
vormi	doc_688103945038_item	2822850	et	4	main
ma	doc_688103945038_item	2822852	et	3	main
aitavad	doc_688103945038_item	2822861	et	4	main
artikli	doc_688103945038_item	2822870	et	3	main
nõudeid	doc_688103945038_item	2822872	et	3	main
7	doc_688103945038_item	2822926	et	2	main
see	doc_688103945038_item	2822927	et	3	main
kuulub	doc_688103945038_item	2822929	et	3	main
teisele	doc_688103945038_item	2822932	et	4	main
juurde	doc_688103945038_item	2822937	et	4	main
8	doc_688103945038_item	2822938	et	2	main
närimiskumm	doc_688103945038_item	2822939	et	3	main
praegu	doc_688103945038_item	2822627	et	3	main
ööd	doc_688103945038_item	2822634	et	4	main
müüdagi	doc_688103945038_item	2822656	et	3	main
naerab	doc_688103945038_item	2822657	et	3	main
valmistuma	doc_688103945038_item	2822659	et	3	main
valmistuv	doc_688103945038_item	2822660	et	4	main
piret	doc_688103945038_item	2822661	et	4	main
vormi	doc_688103945038_item	2822674	et	4	main
kasutades	doc_688103945038_item	2822676	et	3	main
ja	doc_688103945038_item	2822683	et	3	main
mehelikum	doc_688103945038_item	2822685	et	4	main
igaüks	doc_688103945038_item	2822686	et	3	main
ja	doc_688103945038_item	2822692	et	3	main
suure	doc_688103945038_item	2822640	et	3	main
ahju	doc_688103945038_item	2822642	et	4	main
kütmine	doc_688103945038_item	2822643	et	4	main
külapoest	doc_688103945038_item	2822649	et	4	main
vildid	doc_688103945038_item	2822650	et	4	main
ega	doc_688103945038_item	2822651	et	3	main
ei	doc_688103945038_item	2822655	et	4	main
talveks	doc_688103945038_item	2822658	et	4	main
ajalehest	doc_688103945038_item	2822664	et	4	main
pannes	doc_688103945038_item	2822671	et	4	main
4	doc_688103945038_item	2822722	et	2	main
tohtima	doc_688103945038_item	2822724	et	3	main
tekkima	doc_688103945038_item	2822727	et	3	main
ülekoormust	doc_688103945038_item	2822737	et	4	main
tekkida	doc_688103945038_item	2822738	et	3	main
maandada	doc_688103945038_item	2822741	et	3	main
tänapäev	doc_688103945038_item	2822756	et	3	main
maagiline	doc_688103945038_item	2822759	et	4	main
et	doc_688103945038_item	2822761	et	3	main
lausa	doc_688103945038_item	2822764	et	4	main
elama	doc_688103945038_item	2822765	et	3	main
ja	doc_688103945038_item	2822766	et	3	main
hingama	doc_688103945038_item	2822767	et	3	main
i	doc_688103945038_item	2822768	et	4	main
telefon	doc_688103945038_item	2822769	et	3	main
et	doc_688103945038_item	2822776	et	3	main
abita	doc_688103945038_item	2822778	et	3	main
telefonist	doc_688103945038_item	2822786	et	4	main
on	doc_688103945038_item	2822787	et	4	main
saanud	doc_688103945038_item	2822788	et	4	main
vene	doc_688103945038_item	2822641	et	4	main
kütmist	doc_688103945038_item	2822644	et	4	main
kui	doc_688103945038_item	2822645	et	3	main
seal	doc_688103945038_item	2822652	et	4	main
suurt	doc_688103945038_item	2822653	et	3	main
slõhtuleht	doc_688103945038_item	2822665	et	4	main
iii	doc_688103945038_item	2822666	et	4	main
moodustage	doc_688103945038_item	2822667	et	3	main
õigesse	doc_688103945038_item	2822673	et	3	main
ja	doc_688103945038_item	2822675	et	3	main
2	doc_688103945038_item	2822678	et	2	main
naiselikum	doc_688103945038_item	2822682	et	4	main
mehed	doc_688103945038_item	2822684	et	3	main
naiselikumaks	doc_688103945038_item	2822691	et	4	main
igauhe	doc_688103945038_item	2822695	et	4	main
kogus	doc_688103945038_item	2822699	et	4	main
stress	doc_688103945038_item	2822700	et	3	main
panema	doc_688103945038_item	2822701	et	3	main
saama	doc_688103945038_item	2822729	et	4	main
puhkama	doc_688103945038_item	2822733	et	3	main
pingeid	doc_688103945038_item	2822739	et	3	main
spordi	doc_688103945038_item	2822742	et	4	main
sport	doc_688103945038_item	2822747	et	3	main
puhkus	doc_688103945038_item	2822749	et	3	main
tekkivaid	doc_688103945038_item	2822751	et	4	main
pingeid	doc_688103945038_item	2822752	et	3	main
nii	doc_688103945038_item	2822758	et	3	main
see	doc_688103945038_item	2822762	et	3	main
abil	doc_688103945038_item	2822763	et	4	main
on	doc_688103945038_item	2822771	et	4	main
ei	doc_688103945038_item	2822781	et	4	main
hingama	doc_688103945038_item	2822782	et	3	main
ega	doc_688103945038_item	2822783	et	3	main
elama	doc_688103945038_item	2822784	et	3	main
tanapaeval	doc_688103945038_item	2822789	et	4	main
puhkajat	doc_688103945038_item	2822833	et	4	main
jne	doc_688103945038_item	2822834	et	4	main
huvitava	doc_688103945038_item	2822835	et	4	main
on	doc_688103945038_item	2822840	et	4	main
sulgudes	doc_688103945038_item	2822846	et	4	main
1	doc_688103945038_item	2822851	et	2	main
pean	doc_688103945038_item	2822853	et	4	main
väga	doc_688103945038_item	2822854	et	3	main
lugu	doc_688103945038_item	2822855	et	4	main
oma	doc_688103945038_item	2822856	et	4	main
sest	doc_688103945038_item	2822859	et	4	main
kohandasin	doc_688103945038_item	2822869	et	3	main
on	doc_688103945038_item	2822905	et	4	main
oht	doc_688103945038_item	2822906	et	3	main
haigestuda	doc_688103945038_item	2822907	et	3	main
5	doc_688103945038_item	2822910	et	2	main
töökoht	doc_688103945038_item	2822913	et	3	main
piirdusime	doc_688103945038_item	2822918	et	3	main
väikeste	doc_688103945038_item	2822924	et	4	main
teise	doc_688103945038_item	2822935	et	4	main
peab	doc_688103945038_item	2822946	et	4	main
külmetamisest	doc_688103945038_item	2822949	et	4	main
rõõmu	doc_688103945038_item	2822953	et	4	main
suvine	doc_688103945038_item	2822954	et	4	main
päike	doc_688103945038_item	2822955	et	3	main
täitke	doc_688103945038_item	2822959	et	3	main
õpetajad	doc_688103945038_item	2822978	et	4	main
4	doc_688103945038_item	2822987	et	2	main
kõrvallauast	doc_688103945038_item	2822988	et	4	main
oleks	doc_688103945038_item	2822992	et	3	main
hoopis	doc_688103945038_item	2823004	et	3	main
teatrisse	doc_688103945038_item	2823005	et	3	main
ei	doc_688103945038_item	2823015	et	4	main
alkoholi	doc_688103945038_item	2823019	et	4	main
nad	doc_688103945038_item	2823022	et	3	main
küll	doc_688103945038_item	2823024	et	4	main
linna	doc_688103945038_item	2823037	et	4	main
10	doc_688103945038_item	2823038	et	2	main
avasin	doc_688103945038_item	2823039	et	3	main
ukse	doc_688103945038_item	2823040	et	3	main
kuulsin	doc_688103945038_item	2823042	et	3	main
2	doc_689641833088_item	2823049	et	2	main
milliseid	doc_689641833088_item	2823050	et	3	main
kaasa	doc_689641833088_item	2823055	et	4	main
tähendas	doc_689641833088_item	2823059	et	3	main
hulgas	doc_689641833088_item	2823075	et	4	main
ka	doc_689641833088_item	2823076	et	3	main
vaja	doc_688103945038_item	2822646	et	4	main
ostan	doc_688103945038_item	2822647	et	3	main
külapood	doc_688103945038_item	2822648	et	3	main
vapralt	doc_688103945038_item	2822662	et	4	main
etteantud	doc_688103945038_item	2822668	et	4	main
sõnadest	doc_688103945038_item	2822669	et	3	main
laused	doc_688103945038_item	2822670	et	3	main
tegema	doc_688103945038_item	2822680	et	3	main
mehi	doc_688103945038_item	2822693	et	3	main
3	doc_688103945038_item	2822697	et	2	main
pinge	doc_688103945038_item	2822728	et	4	main
maandama	doc_688103945038_item	2822730	et	3	main
ei	doc_688103945038_item	2822734	et	4	main
tohi	doc_688103945038_item	2822735	et	4	main
ja	doc_688103945038_item	2822743	et	3	main
parem	doc_688103945038_item	2822746	et	4	main
saama	doc_688103945038_item	2822757	et	4	main
aparaat	doc_688103945038_item	2822760	et	3	main
tänapäeval	doc_688103945038_item	2822772	et	3	main
nii	doc_688103945038_item	2822773	et	3	main
maagiline	doc_688103945038_item	2822774	et	4	main
selle	doc_688103945038_item	2822777	et	4	main
und	doc_688103945038_item	2822823	et	4	main
segab	doc_688103945038_item	2822824	et	3	main
ajal	doc_688103945038_item	2822838	et	4	main
siiruviiruline	doc_688103945038_item	2822841	et	4	main
bk	doc_688103945038_item	2822843	et	4	main
iv	doc_688103945038_item	2822844	et	4	main
nad	doc_688103945038_item	2822860	et	3	main
kõik	doc_688103945038_item	2822862	et	4	main
ja	doc_688103945038_item	2822864	et	3	main
nõuded	doc_688103945038_item	2822871	et	3	main
ja	doc_688103945038_item	2822900	et	3	main
kiirtest	doc_688103945038_item	2822901	et	3	main
autodest	doc_688103945038_item	2822902	et	3	main
4	doc_688103945038_item	2822903	et	2	main
praegu	doc_688103945038_item	2822904	et	3	main
uuest	doc_688103945038_item	2822914	et	3	main
kiiresti	doc_688103945038_item	2822916	et	3	main
selles	doc_688103945038_item	2822919	et	4	main
küsimuses	doc_688103945038_item	2822920	et	4	main
vaid	doc_688103945038_item	2822921	et	3	main
ei	doc_688103945038_item	2822723	et	4	main
ülekoormus	doc_688103945038_item	2822726	et	3	main
sportima	doc_688103945038_item	2822731	et	4	main
lasta	doc_688103945038_item	2822736	et	4	main
puhkehetkede	doc_688103945038_item	2822744	et	3	main
ja	doc_688103945038_item	2822748	et	3	main
maandavad	doc_688103945038_item	2822750	et	4	main
5	doc_688103945038_item	2822753	et	2	main
telefon	doc_688103945038_item	2822754	et	3	main
olema	doc_688103945038_item	2822755	et	4	main
olevat	doc_688103945038_item	2822770	et	4	main
ii	doc_688103945038_item	2822785	et	4	main
nii	doc_688103945038_item	2822790	et	3	main
maagiline	doc_688103945038_item	2822791	et	4	main
aparaat	doc_688103945038_item	2822792	et	3	main
et	doc_688103945038_item	2822793	et	3	main
ainult	doc_688103945038_item	2822794	et	4	main
selle	doc_688103945038_item	2822795	et	4	main
abil	doc_688103945038_item	2822796	et	4	main
saab	doc_688103945038_item	2822797	et	3	main
lausa	doc_688103945038_item	2822798	et	4	main
elada	doc_688103945038_item	2822799	et	3	main
ja	doc_688103945038_item	2822800	et	3	main
hingata	doc_688103945038_item	2822801	et	4	main
6	doc_688103945038_item	2822802	et	2	main
kuid	doc_688103945038_item	2822803	et	4	main
telefonihelin	doc_688103945038_item	2822804	et	3	main
katkestama	doc_688103945038_item	2822805	et	3	main
ka	doc_688103945038_item	2822806	et	3	main
pühapäev	doc_688103945038_item	2822807	et	3	main
varahommik	doc_688103945038_item	2822808	et	3	main
uni	doc_688103945038_item	2822809	et	3	main
segama	doc_688103945038_item	2822810	et	3	main
lõunasöök	doc_688103945038_item	2822811	et	3	main
valmistamine	doc_688103945038_item	2822812	et	4	main
ja	doc_688103945038_item	2822813	et	3	main
söömine	doc_688103945038_item	2822814	et	4	main
pahandab	doc_688103945038_item	2822815	et	3	main
huvitav	doc_688103945038_item	2822816	et	4	main
vaatamine	doc_688103945038_item	2822818	et	4	main
telesaade	doc_688103945038_item	2822817	et	4	main
aeg	doc_688103945038_item	2822819	et	3	main
telefonihelin	doc_688103945038_item	2822820	et	3	main
katkestab	doc_688103945038_item	2822821	et	3	main
nii	doc_688103945038_item	2822825	et	3	main
kui	doc_688103945038_item	2822828	et	3	main
soomist	doc_688103945038_item	2822830	et	4	main
vaatamise	doc_688103945038_item	2822837	et	4	main
õigesse	doc_688103945038_item	2822849	et	3	main
vanematest	doc_688103945038_item	2822858	et	4	main
varahmmikust	doc_688103945038_item	2822822	et	4	main
valmistamist	doc_688103945038_item	2822827	et	4	main
telesaade	doc_688103945038_item	2822836	et	4	main
pange	doc_688103945038_item	2822845	et	4	main
olevad	doc_688103945038_item	2822847	et	4	main
vanemad	doc_688103945038_item	2822857	et	4	main
igaüht	doc_688103945038_item	2822867	et	3	main
3	doc_688103945038_item	2822873	et	2	main
ma	doc_688103945038_item	2822874	et	3	main
arvasin	doc_688103945038_item	2822875	et	3	main
et	doc_688103945038_item	2822876	et	3	main
sa	doc_688103945038_item	2822877	et	3	main
huvitud	doc_688103945038_item	2822878	et	4	main
sport	doc_688103945038_item	2822879	et	3	main
spordist	doc_688103945038_item	2822880	et	3	main
aga	doc_688103945038_item	2822881	et	3	main
sa	doc_688103945038_item	2822882	et	3	main
tunned	doc_688103945038_item	2822883	et	3	main
huvi	doc_688103945038_item	2822884	et	4	main
ainult	doc_688103945038_item	2822885	et	4	main
ilusad	doc_688103945038_item	2822886	et	3	main
naised	doc_688103945038_item	2822887	et	3	main
ja	doc_688103945038_item	2822888	et	3	main
kiired	doc_688103945038_item	2822889	et	4	main
autod	doc_688103945038_item	2822890	et	3	main
ilusate	doc_688103945038_item	2822891	et	3	main
naiste	doc_688103945038_item	2822892	et	3	main
ja	doc_688103945038_item	2822893	et	3	main
kiirete	doc_688103945038_item	2822894	et	4	main
autode	doc_688103945038_item	2822895	et	3	main
vastu	doc_688103945038_item	2822896	et	3	main
või	doc_688103945038_item	2822897	et	4	main
ilusatest	doc_688103945038_item	2822898	et	3	main
naistest	doc_688103945038_item	2822899	et	4	main
kõiki	doc_688103945038_item	2822863	et	4	main
usaldavad	doc_688103945038_item	2822865	et	4	main
igaüks	doc_688103945038_item	2822866	et	3	main
2	doc_688103945038_item	2822868	et	2	main
difteeriale	doc_688103945038_item	2822909	et	3	main
uus	doc_688103945038_item	2822912	et	3	main
töökohast	doc_688103945038_item	2822915	et	4	main
6	doc_688103945038_item	2822917	et	2	main
valdkonnale	doc_688103945038_item	2822933	et	4	main
9	doc_688103945038_item	2822943	et	2	main
külmal	doc_688103945038_item	2822944	et	3	main
ajal	doc_688103945038_item	2822945	et	4	main
päikesest	doc_688103945038_item	2822957	et	4	main
tulevad	doc_688103945038_item	2822986	et	4	main
nagu	doc_688103945038_item	2822991	et	3	main
just	doc_688103945038_item	2822994	et	3	main
rääkinud	doc_688103945038_item	2822996	et	4	main
ei	doc_688103945038_item	2822999	et	4	main
selles	doc_688103945038_item	2823013	et	4	main
baaris	doc_688103945038_item	2823014	et	3	main
8	doc_688103945038_item	2823021	et	2	main
tulemust	doc_688103945038_item	2823027	et	4	main
olnud	doc_688103945038_item	2823029	et	4	main
kui	doc_688103945038_item	2823041	et	3	main
kirjanduselu	doc_689641833088_item	2823048	et	4	main
muudatusi	doc_689641833088_item	2823051	et	3	main
pärastsõjajärgne	doc_689641833088_item	2823053	et	3	main
mida	doc_689641833088_item	2823058	et	4	main
maailmasõda	doc_689641833088_item	2823061	et	4	main
1	doc_689641833088_item	2823064	et	2	main
tema	doc_689641833088_item	2823088	et	4	main
õigus	doc_689641833088_item	2823092	et	4	main
on	doc_689641833088_item	2823093	et	4	main
ka	doc_689641833088_item	2823094	et	3	main
difteeria	doc_688103945038_item	2822908	et	4	main
tüdinesin	doc_688103945038_item	2822911	et	3	main
muudatused	doc_688103945038_item	2822923	et	3	main
muudatustega	doc_688103945038_item	2822925	et	3	main
küsimus	doc_688103945038_item	2822928	et	4	main
teine	doc_688103945038_item	2822930	et	3	main
valdkond	doc_688103945038_item	2822931	et	3	main
valdkonna	doc_688103945038_item	2822936	et	4	main
hoiduma	doc_688103945038_item	2822947	et	3	main
ma	doc_688103945038_item	2822951	et	3	main
tunnen	doc_688103945038_item	2822952	et	3	main
3	doc_688103945038_item	2822979	et	2	main
lapsel	doc_688103945038_item	2822980	et	4	main
paluti	doc_688103945038_item	2822981	et	3	main
kostis	doc_688103945038_item	2822989	et	4	main
keegi	doc_688103945038_item	2822993	et	4	main
ta	doc_688103945038_item	2822998	et	4	main
tule	doc_688103945038_item	2823000	et	4	main
trenni	doc_688103945038_item	2823001	et	4	main
kuna	doc_688103945038_item	2823002	et	3	main
läheb	doc_688103945038_item	2823003	et	3	main
6	doc_688103945038_item	2823006	et	2	main
lõpetage	doc_688103945038_item	2823007	et	3	main
töö	doc_688103945038_item	2823008	et	4	main
siis	doc_688103945038_item	2823009	et	3	main
lähete	doc_688103945038_item	2823010	et	4	main
jalutama	doc_688103945038_item	2823011	et	3	main
7	doc_688103945038_item	2823012	et	2	main
tohi	doc_688103945038_item	2823016	et	4	main
tarbida	doc_688103945038_item	2823020	et	3	main
jääd	doc_688103945038_item	2823036	et	4	main
ew	doc_689641833088_item	2823047	et	4	main
külaühiskonda	doc_689641833088_item	2823056	et	4	main
tekkis	doc_689641833088_item	2823071	et	3	main
igasuguseid	doc_689641833088_item	2823072	et	3	main
seltse	doc_689641833088_item	2823073	et	3	main
nende	doc_689641833088_item	2823074	et	4	main
ahtammsaare	doc_689641833088_item	2823086	et	4	main
eriti	doc_689641833088_item	2823087	et	3	main
tõde	doc_689641833088_item	2823090	et	4	main
tõi	doc_689641833088_item	2823130	et	3	main
eesti	doc_689641833088_item	2823142	et	4	main
kõige	doc_689641833088_item	2823150	et	4	main
pärast	doc_689641833088_item	2823155	et	4	main
pidid	doc_689641833088_item	2823164	et	4	main
saama	doc_689641833088_item	2823193	et	4	main
3ii	doc_689641833088_item	2823194	et	4	main
mure	doc_689641833088_item	2823200	et	4	main
majandus	doc_689641833088_item	2823202	et	4	main
tööstus	doc_689641833088_item	2823203	et	3	main
ew	doc_689641833088_item	2823213	et	4	main
perioodil	doc_689641833088_item	2823214	et	3	main
saksa	doc_689641833088_item	2823215	et	4	main
kõik	doc_689641833088_item	2823221	et	4	main
maad	doc_689641833088_item	2823234	et	4	main
palju	doc_689641833088_item	2823245	et	4	main
oli	doc_689641833088_item	2823251	et	3	main
aasate	doc_689641833089_item	2823264	et	3	main
kauge	doc_689641833089_item	2823273	et	4	main
korea	doc_689641833089_item	2823274	et	4	main
ega	doc_689641833089_item	2823275	et	3	main
hiina	doc_689641833089_item	2823276	et	3	main
sest	doc_689641833089_item	2823277	et	4	main
vahel	doc_689641833089_item	2823282	et	4	main
luuletuses	doc_689641833089_item	2823321	et	4	main
nn	doc_689641833089_item	2823327	et	4	main
balti	doc_689641833089_item	2823328	et	3	main
riia	doc_689641833089_item	2823333	et	4	main
plakatid	doc_689641833089_item	2823338	et	3	main
oli	doc_689641833089_item	2823340	et	3	main
relvi	doc_689641833089_item	2823349	et	4	main
lihtsalt	doc_689641833089_item	2823350	et	4	main
ei	doc_689641833089_item	2823355	et	4	main
selle	doc_689641833089_item	2823358	et	4	main
poliitikaga	doc_689641833089_item	2823359	et	3	main
balti	doc_689641833089_item	2823360	et	3	main
mis	doc_689641833089_item	2823372	et	4	main
tähendas	doc_689641833089_item	2823373	et	3	main
rahva	doc_689641833089_item	2823375	et	3	main
jõud	doc_689641833089_item	2823376	et	4	main
1	doc_689641833089_item	2823377	et	2	main
sulaperiood	doc_689641833089_item	2823378	et	3	main
väikesed	doc_688103945038_item	2822922	et	4	main
või	doc_688103945038_item	2822934	et	4	main
külmetamine	doc_688103945038_item	2822948	et	4	main
10	doc_688103945038_item	2822950	et	2	main
v	doc_688103945038_item	2822958	et	4	main
sobivate	doc_688103945038_item	2822961	et	4	main
sidenditega	doc_688103945038_item	2822962	et	3	main
1	doc_688103945038_item	2822963	et	2	main
tellisime	doc_688103945038_item	2822964	et	4	main
kolmekäigulise	doc_688103945038_item	2822965	et	4	main
lõuna	doc_688103945038_item	2822966	et	4	main
kuigi	doc_688103945038_item	2822967	et	3	main
see	doc_688103945038_item	2822968	et	3	main
maksis	doc_688103945038_item	2822969	et	4	main
palju	doc_688103945038_item	2822970	et	4	main
2	doc_688103945038_item	2822971	et	2	main
kohal	doc_688103945038_item	2822972	et	4	main
olid	doc_688103945038_item	2822973	et	4	main
nii	doc_688103945038_item	2822974	et	3	main
õpilased	doc_688103945038_item	2822975	et	3	main
kui	doc_688103945038_item	2822976	et	3	main
ka	doc_688103945038_item	2822977	et	3	main
kleepus	doc_688103945038_item	2822940	et	3	main
püksid	doc_688103945038_item	2822941	et	3	main
pükstele	doc_688103945038_item	2822942	et	3	main
suvisest	doc_688103945038_item	2822956	et	4	main
lüngad	doc_688103945038_item	2822960	et	3	main
oodata	doc_688103945038_item	2822982	et	4	main
kuni	doc_688103945038_item	2822983	et	3	main
vanemad	doc_688103945038_item	2822984	et	4	main
tagasi	doc_688103945038_item	2822985	et	3	main
naeru	doc_688103945038_item	2822990	et	4	main
anekdooti	doc_688103945038_item	2822995	et	4	main
5	doc_688103945038_item	2822997	et	2	main
suitsetada	doc_688103945038_item	2823017	et	3	main
töötasid	doc_688103945038_item	2823023	et	4	main
pingsalt	doc_688103945038_item	2823025	et	4	main
kuid	doc_688103945038_item	2823026	et	4	main
või	doc_688103945038_item	2823035	et	4	main
kollektiviseerimine	doc_689641833088_item	2823054	et	4	main
eestlaste	doc_689641833088_item	2823062	et	4	main
kõigepealt	doc_689641833088_item	2823079	et	3	main
eesti	doc_689641833088_item	2823080	et	4	main
kirjanikutest	doc_689641833088_item	2823081	et	3	main
oli	doc_689641833088_item	2823082	et	3	main
väga	doc_689641833088_item	2823083	et	3	main
tuntud	doc_689641833088_item	2823084	et	4	main
romaan	doc_689641833088_item	2823089	et	3	main
ja	doc_689641833088_item	2823091	et	3	main
kogu	doc_689641833088_item	2823099	et	4	main
palju	doc_689641833088_item	2823124	et	4	main
hakkasid	doc_689641833088_item	2823138	et	4	main
siis	doc_689641833088_item	2823141	et	3	main
talud	doc_689641833088_item	2823143	et	4	main
astusid	doc_689641833088_item	2823144	et	4	main
siin	doc_689641833088_item	2823145	et	4	main
edukamad	doc_689641833088_item	2823151	et	4	main
liiga	doc_689641833088_item	2823184	et	4	main
tekkimist	doc_689641833088_item	2823188	et	4	main
nendega	doc_689641833088_item	2823189	et	4	main
oli	doc_689641833088_item	2823190	et	3	main
eestlastele	doc_689641833088_item	2823197	et	4	main
pärast	doc_689641833088_item	2823217	et	4	main
ka	doc_689641833088_item	2823218	et	3	main
oli	doc_689641833088_item	2823223	et	3	main
eesti	doc_689641833088_item	2823224	et	4	main
rahvasele	doc_689641833088_item	2823225	et	4	main
väga	doc_689641833088_item	2823226	et	3	main
küüditamist	doc_689641833088_item	2823232	et	4	main
eestist	doc_689641833088_item	2823247	et	3	main
ii	doc_689641833088_item	2823248	et	4	main
võimu	doc_689641833088_item	2823255	et	4	main
sulaperioodi	doc_689641833089_item	2823266	et	4	main
eesti	doc_689641833089_item	2823267	et	4	main
me	doc_689641833089_item	2823279	et	4	main
pealinnade	doc_689641833089_item	2823281	et	3	main
kett	doc_689641833089_item	2823329	et	4	main
hoidsid	doc_689641833089_item	2823336	et	4	main
nsv	doc_689641833089_item	2823343	et	4	main
et	doc_689641833089_item	2823353	et	3	main
umbes	doc_689641833089_item	2823364	et	4	main
eesti	doc_689641833089_item	2823379	et	4	main
kultuuris	doc_689641833089_item	2823380	et	3	main
kuldsed	doc_689641833089_item	2823381	et	3	main
60	doc_689641833089_item	2823382	et	2	main
oli	doc_689641833089_item	2823383	et	3	main
suur	doc_689641833089_item	2823411	et	3	main
balett	doc_689641833089_item	2823415	et	4	main
järv	doc_689641833089_item	2823417	et	3	main
selle	doc_689641833089_item	2823428	et	4	main
filmiga	doc_689641833089_item	2823429	et	3	main
valgas	doc_689641833089_item	2823430	et	4	main
koordis	doc_689641833089_item	2823431	et	4	main
stalin	doc_689641833089_item	2823440	et	4	main
ehitamisest	doc_689641833089_item	2823446	et	4	main
detailid	doc_689641833089_item	2823471	et	3	main
vaatajatele	doc_689641833089_item	2823473	et	4	main
hea	doc_689641833089_item	2823474	et	4	main
tehtud	doc_689641833089_item	2823480	et	4	main
põhjal	doc_689641833089_item	2823484	et	4	main
autor	doc_689641833089_item	2823487	et	3	main
ta	doc_689641833089_item	2823494	et	4	main
sai	doc_689641833089_item	2823495	et	4	main
ega	doc_688103945038_item	2823018	et	3	main
ei	doc_688103945038_item	2823028	et	4	main
9	doc_688103945038_item	2823030	et	2	main
kas	doc_688103945038_item	2823031	et	3	main
sa	doc_688103945038_item	2823032	et	3	main
sõidad	doc_688103945038_item	2823033	et	3	main
maale	doc_688103945038_item	2823034	et	4	main
koputust	doc_688103945038_item	2823043	et	4	main
kontrolltöö	doc_689641833088_item	2823044	et	4	main
1	doc_689641833088_item	2823045	et	2	main
iseloomustage	doc_689641833088_item	2823046	et	4	main
tõi	doc_689641833088_item	2823052	et	3	main
3	doc_689641833088_item	2823057	et	2	main
ii	doc_689641833088_item	2823060	et	4	main
jaoks	doc_689641833088_item	2823063	et	4	main
eesti	doc_689641833088_item	2823065	et	4	main
vabariigi	doc_689641833088_item	2823066	et	3	main
kirjanduselu	doc_689641833088_item	2823067	et	4	main
arenes	doc_689641833088_item	2823068	et	3	main
väga	doc_689641833088_item	2823069	et	3	main
kiiresti	doc_689641833088_item	2823070	et	3	main
evilde	doc_689641833088_item	2823085	et	4	main
kirjanduselu	doc_689641833088_item	2823097	et	4	main
ja	doc_689641833088_item	2823098	et	3	main
kultuurielu	doc_689641833088_item	2823100	et	4	main
toetus	doc_689641833088_item	2823101	et	4	main
riik	doc_689641833088_item	2823102	et	3	main
tol	doc_689641833088_item	2823103	et	3	main
ajal	doc_689641833088_item	2823104	et	4	main
ka	doc_689641833088_item	2823105	et	3	main
arenes	doc_689641833088_item	2823106	et	3	main
trükisõna	doc_689641833088_item	2823107	et	4	main
seoses	doc_689641833088_item	2823108	et	4	main
sellega	doc_689641833088_item	2823109	et	3	main
et	doc_689641833088_item	2823110	et	3	main
haridus	doc_689641833088_item	2823111	et	3	main
muudeti	doc_689641833088_item	2823112	et	3	main
emakeelseks	doc_689641833088_item	2823113	et	4	main
siis	doc_689641833088_item	2823114	et	3	main
eesti	doc_689641833088_item	2823115	et	4	main
keel	doc_689641833088_item	2823116	et	4	main
sa	doc_689641833088_item	2823117	et	3	main
väärtuslikuks	doc_689641833088_item	2823119	et	3	main
ja	doc_689641833088_item	2823120	et	3	main
tõeliselt	doc_689641833088_item	2823118	et	4	main
ametlikuks	doc_689641833088_item	2823121	et	3	main
kirjutasid	doc_689641833088_item	2823123	et	4	main
isikute	doc_689641833088_item	2823125	et	4	main
olulisest	doc_689641833088_item	2823126	et	4	main
2	doc_689641833088_item	2823127	et	2	main
pärastsõjajärgne	doc_689641833088_item	2823128	et	3	main
jaoks	doc_689641833088_item	2823135	et	4	main
esiteks	doc_689641833088_item	2823136	et	3	main
kolhoosid	doc_689641833088_item	2823140	et	3	main
olid	doc_689641833088_item	2823149	et	4	main
rikkad	doc_689641833088_item	2823153	et	4	main
niisugune	doc_689641833088_item	2823157	et	3	main
kõige	doc_689641833088_item	2823161	et	4	main
jäi	doc_689641833088_item	2823180	et	3	main
raske	doc_689641833088_item	2823191	et	4	main
kaasa	doc_689641833088_item	2823198	et	4	main
kultuurielu	doc_689641833088_item	2823201	et	4	main
kirjanduse	doc_689641833088_item	2823077	et	3	main
selts	doc_689641833088_item	2823078	et	3	main
oluline	doc_689641833088_item	2823095	et	4	main
et	doc_689641833088_item	2823096	et	3	main
kollektiviseerimine	doc_689641833088_item	2823129	et	4	main
kui	doc_689641833088_item	2823137	et	3	main
need	doc_689641833088_item	2823148	et	3	main
talud	doc_689641833088_item	2823154	et	4	main
väiksemad	doc_689641833088_item	2823162	et	4	main
talud	doc_689641833088_item	2823163	et	4	main
raskel	doc_689641833088_item	2823181	et	3	main
aga	doc_689641833088_item	2823183	et	3	main
suure	doc_689641833088_item	2823185	et	3	main
arvu	doc_689641833088_item	2823187	et	4	main
maailmasõda	doc_689641833088_item	2823195	et	4	main
tõi	doc_689641833088_item	2823196	et	3	main
palju	doc_689641833088_item	2823199	et	4	main
okkupatsioo	doc_689641833088_item	2823220	et	4	main
kirjanikud	doc_689641833088_item	2823122	et	3	main
kaasa	doc_689641833088_item	2823131	et	4	main
raskusi	doc_689641833088_item	2823132	et	4	main
eesti	doc_689641833088_item	2823133	et	4	main
talupoegade	doc_689641833088_item	2823134	et	3	main
ilmuma	doc_689641833088_item	2823139	et	3	main
vabatahtlikult	doc_689641833088_item	2823146	et	4	main
aga	doc_689641833088_item	2823147	et	3	main
ja	doc_689641833088_item	2823152	et	3	main
ilmus	doc_689641833088_item	2823156	et	4	main
asi	doc_689641833088_item	2823158	et	4	main
nagu	doc_689641833088_item	2823159	et	3	main
maksupress	doc_689641833088_item	2823160	et	3	main
maksu	doc_689641833088_item	2823165	et	4	main
maksma	doc_689641833088_item	2823166	et	3	main
ja	doc_689641833088_item	2823167	et	3	main
siis	doc_689641833088_item	2823168	et	3	main
tekkis	doc_689641833088_item	2823169	et	3	main
selline	doc_689641833088_item	2823170	et	4	main
olukord	doc_689641833088_item	2823171	et	3	main
et	doc_689641833088_item	2823172	et	3	main
kõik	doc_689641833088_item	2823173	et	4	main
talud	doc_689641833088_item	2823174	et	4	main
pidid	doc_689641833088_item	2823175	et	4	main
kohustuslik	doc_689641833088_item	2823176	et	3	main
kolhoosides	doc_689641833088_item	2823177	et	3	main
astuma	doc_689641833088_item	2823178	et	3	main
talurahvas	doc_689641833088_item	2823179	et	4	main
olukorral	doc_689641833088_item	2823182	et	3	main
kolhooside	doc_689641833088_item	2823186	et	3	main
hakkama	doc_689641833088_item	2823192	et	3	main
teadus	doc_689641833088_item	2823205	et	4	main
ei	doc_689641833088_item	2823206	et	4	main
okkupatsioon	doc_689641833088_item	2823216	et	4	main
ajaks	doc_689641833088_item	2823228	et	4	main
eesti	doc_689641833088_item	2823229	et	4	main
kaotamist	doc_689641833088_item	2823235	et	4	main
võib	doc_689641833088_item	2823236	et	3	main
inimesi	doc_689641833088_item	2823246	et	4	main
ka	doc_689641833088_item	2823252	et	3	main
algasid	doc_689641833088_item	2823257	et	4	main
eestlastel	doc_689641833088_item	2823258	et	4	main
üldiseloomustus	doc_689641833089_item	2823269	et	4	main
2	doc_689641833089_item	2823270	et	2	main
2	doc_689641833089_item	2823319	et	2	main
ja	doc_689641833088_item	2823204	et	3	main
olnud	doc_689641833088_item	2823207	et	4	main
nii	doc_689641833088_item	2823208	et	3	main
kiiresti	doc_689641833088_item	2823209	et	3	main
arenenud	doc_689641833088_item	2823210	et	4	main
kui	doc_689641833088_item	2823211	et	3	main
näitek	doc_689641833088_item	2823212	et	4	main
vene	doc_689641833088_item	2823219	et	4	main
rahvas	doc_689641833088_item	2823230	et	4	main
kardis	doc_689641833088_item	2823231	et	3	main
öelda	doc_689641833088_item	2823237	et	4	main
et	doc_689641833088_item	2823238	et	3	main
ii	doc_689641833088_item	2823239	et	4	main
maailmasõja	doc_689641833088_item	2823240	et	3	main
maailmasõjajärgne	doc_689641833088_item	2823249	et	3	main
probleemne	doc_689641833088_item	2823253	et	3	main
all	doc_689641833088_item	2823256	et	3	main
mustad	doc_689641833088_item	2823259	et	4	main
aastad	doc_689641833088_item	2823260	et	3	main
kontrolltöö	doc_689641833089_item	2823261	et	4	main
1	doc_689641833089_item	2823262	et	2	main
1960	doc_689641833089_item	2823263	et	2	main
aima	doc_689641833089_item	2823272	et	4	main
balti	doc_689641833089_item	2823280	et	3	main
loengutes	doc_689641833089_item	2823315	et	4	main
põhjal	doc_689641833089_item	2823318	et	4	main
selle	doc_689641833089_item	2823320	et	4	main
inimesed	doc_689641833089_item	2823330	et	3	main
seisid	doc_689641833089_item	2823331	et	4	main
vilnius	doc_689641833089_item	2823334	et	4	main
nagu	doc_689641833089_item	2823341	et	3	main
näidata	doc_689641833089_item	2823352	et	4	main
oli	doc_689641833089_item	2823369	et	3	main
teatri	doc_689641833089_item	2823413	et	3	main
euroopa	doc_689641833089_item	2823424	et	4	main
vastu	doc_689641833089_item	2823425	et	3	main
3	doc_689641833089_item	2823426	et	2	main
alustan	doc_689641833089_item	2823427	et	3	main
ekraniseeritud	doc_689641833089_item	2823435	et	4	main
see	doc_689641833089_item	2823447	et	3	main
oli	doc_689641833089_item	2823449	et	3	main
film	doc_689641833089_item	2823452	et	3	main
propaganda	doc_689641833089_item	2823454	et	4	main
ise	doc_689641833089_item	2823461	et	4	main
eesti	doc_689641833089_item	2823465	et	4	main
film	doc_689641833089_item	2823467	et	3	main
et	doc_689641833089_item	2823468	et	3	main
ilusaid	doc_689641833089_item	2823470	et	3	main
eesti	doc_689641833089_item	2823481	et	4	main
raamatu	doc_689641833089_item	2823483	et	4	main
aga	doc_689641833089_item	2823485	et	3	main
ei	doc_689641833089_item	2823488	et	4	main
kuldsed	doc_689641833089_item	2823521	et	3	main
seal	doc_689641833089_item	2823533	et	4	main
talle	doc_689641833089_item	2823548	et	4	main
ta	doc_689641833089_item	2823556	et	4	main
päästab	doc_689641833089_item	2823570	et	3	main
räägiva	doc_689641833089_item	2823575	et	4	main
filmis	doc_689641833089_item	2823584	et	4	main
lõpp	doc_689641833089_item	2823587	et	3	main
see	doc_689641833089_item	2823588	et	3	main
nagu	doc_689641833089_item	2823590	et	3	main
mida	doc_689641833089_item	2823600	et	4	main
ma	doc_689641833089_item	2823601	et	3	main
võtan	doc_689641833089_item	2823602	et	3	main
ta	doc_689641833089_item	2823614	et	4	main
oli	doc_689641833089_item	2823615	et	3	main
tehtud	doc_689641833089_item	2823616	et	4	main
sisu	doc_689641833089_item	2823631	et	4	main
läheb	doc_689641833089_item	2823632	et	3	main
mineviku	doc_689641833089_item	2823633	et	3	main
kaugele	doc_689641833089_item	2823634	et	4	main
aga	doc_689641833089_item	2823635	et	3	main
ole	doc_689641833089_item	2823652	et	4	main
viimane	doc_689641833089_item	2823663	et	3	main
kõige	doc_689641833089_item	2823666	et	4	main
vanem	doc_689641833089_item	2823667	et	4	main
ja	doc_689641833089_item	2823676	et	3	main
hallim	doc_689641833089_item	2823678	et	4	main
kauge	doc_689641833090_item	2823691	et	4	main
korea	doc_689641833090_item	2823692	et	4	main
ega	doc_689641833090_item	2823693	et	3	main
seda	doc_689641833088_item	2823222	et	3	main
raske	doc_689641833088_item	2823227	et	4	main
oma	doc_689641833088_item	2823233	et	4	main
jooksul	doc_689641833088_item	2823241	et	4	main
tapeti	doc_689641833088_item	2823242	et	3	main
ja	doc_689641833088_item	2823243	et	3	main
küüditati	doc_689641833088_item	2823244	et	3	main
periood	doc_689641833088_item	2823250	et	3	main
nsvl	doc_689641833088_item	2823254	et	4	main
nn	doc_689641833089_item	2823265	et	4	main
kultuuri	doc_689641833089_item	2823268	et	4	main
ei	doc_689641833089_item	2823271	et	4	main
paelast	doc_689641833089_item	2823278	et	4	main
aga	doc_689641833089_item	2823283	et	3	main
nii	doc_689641833089_item	2823284	et	3	main
toompealt	doc_689641833089_item	2823285	et	3	main
kui	doc_689641833089_item	2823286	et	3	main
gediminasest	doc_689641833089_item	2823287	et	4	main
moskvale	doc_689641833089_item	2823288	et	4	main
sisendab	doc_689641833089_item	2823289	et	3	main
hirmu	doc_689641833089_item	2823290	et	4	main
see	doc_689641833089_item	2823291	et	3	main
ahel	doc_689641833089_item	2823292	et	3	main
millistest	doc_689641833089_item	2823293	et	3	main
sündmustest	doc_689641833089_item	2823294	et	4	main
kõneldakse	doc_689641833089_item	2823295	et	3	main
paimla	doc_689641833089_item	2823296	et	4	main
luuletuses	doc_689641833089_item	2823297	et	4	main
millal	doc_689641833089_item	2823298	et	3	main
see	doc_689641833089_item	2823299	et	3	main
toimus	doc_689641833089_item	2823300	et	3	main
ja	doc_689641833089_item	2823301	et	3	main
mida	doc_689641833089_item	2823302	et	4	main
see	doc_689641833089_item	2823303	et	3	main
balti	doc_689641833089_item	2823304	et	3	main
riikide	doc_689641833089_item	2823305	et	3	main
jaoks	doc_689641833089_item	2823306	et	4	main
tähendas	doc_689641833089_item	2823307	et	3	main
3	doc_689641833089_item	2823308	et	2	main
eesti	doc_689641833089_item	2823309	et	4	main
aja-	doc_689641833089_item	2823310	et	4	main
ja	doc_689641833089_item	2823311	et	3	main
kultuurilugu	doc_689641833089_item	2823312	et	4	main
filmis	doc_689641833089_item	2823313	et	4	main
esmajoones	doc_689641833089_item	2823314	et	3	main
vaadatud	doc_689641833089_item	2823316	et	4	main
filmide	doc_689641833089_item	2823317	et	3	main
on	doc_689641833089_item	2823322	et	4	main
23	doc_689641833089_item	2823324	et	2	main
tallinn	doc_689641833089_item	2823332	et	4	main
see	doc_689641833089_item	2823339	et	3	main
nad	doc_689641833089_item	2823354	et	3	main
kettis	doc_689641833089_item	2823361	et	4	main
osa	doc_689641833089_item	2823362	et	4	main
inimeste	doc_689641833089_item	2823370	et	3	main
kultuuri	doc_689641833089_item	2823384	et	4	main
tõus	doc_689641833089_item	2823385	et	4	main
50-ndal	doc_689641833089_item	2823436	et	4	main
kui	doc_689641833089_item	2823437	et	3	main
oli	doc_689641833089_item	2823438	et	3	main
veel	doc_689641833089_item	2823439	et	4	main
on	doc_689641833089_item	2823444	et	4	main
film	doc_689641833089_item	2823448	et	3	main
isegi	doc_689641833089_item	2823459	et	4	main
film	doc_689641833089_item	2823460	et	3	main
esimene	doc_689641833089_item	2823464	et	3	main
tegelikult	doc_689641833089_item	2823476	et	4	main
see	doc_689641833089_item	2823477	et	3	main
film	doc_689641833089_item	2823478	et	3	main
oli	doc_689641833089_item	2823479	et	3	main
autori	doc_689641833089_item	2823482	et	3	main
olnud	doc_689641833089_item	2823489	et	4	main
populaarne	doc_689641833089_item	2823490	et	3	main
siin	doc_689641833089_item	2823491	et	4	main
eestis	doc_689641833089_item	2823492	et	3	main
aga	doc_689641833089_item	2823493	et	3	main
teine	doc_689641833089_item	2823500	et	3	main
film	doc_689641833089_item	2823525	et	3	main
koolis	doc_689641833089_item	2823532	et	4	main
sõprus	doc_689641833089_item	2823538	et	3	main
laps	doc_689641833089_item	2823540	et	4	main
et	doc_689641833089_item	2823545	et	3	main
teised	doc_689641833089_item	2823546	et	4	main
inimesed	doc_689641833089_item	2823547	et	3	main
mees	doc_689641833089_item	2823568	et	4	main
elust	doc_689641833089_item	2823576	et	3	main
kultuuri	doc_689641833089_item	2823593	et	4	main
libahunt	doc_689641833089_item	2823604	et	3	main
tegelikult	doc_689641833089_item	2823607	et	4	main
see	doc_689641833089_item	2823608	et	3	main
film	doc_689641833089_item	2823609	et	3	main
70-ndatel	doc_689641833089_item	2823617	et	4	main
väga	doc_689641833089_item	2823624	et	3	main
hea	doc_689641833089_item	2823625	et	4	main
väljendab	doc_689641833089_item	2823626	et	3	main
see	doc_689641833089_item	2823627	et	3	main
aeg	doc_689641833089_item	2823628	et	3	main
probleemist	doc_689641833089_item	2823638	et	4	main
ajal	doc_689641833089_item	2823642	et	4	main
inimesed	doc_689641833089_item	2823647	et	3	main
ja	doc_689641833089_item	2823649	et	3	main
nendel	doc_689641833089_item	2823650	et	4	main
kevade	doc_689641833089_item	2823656	et	4	main
film	doc_689641833089_item	2823664	et	3	main
1	doc_689641833090_item	2823680	et	2	main
kultuuri	doc_689641833090_item	2823686	et	4	main
see	doc_689641833090_item	2823721	et	3	main
filmis	doc_689641833090_item	2823731	et	4	main
esmajoones	doc_689641833090_item	2823732	et	3	main
seotud	doc_689641833090_item	2823740	et	4	main
uue	doc_689641833090_item	2823741	et	3	main
pehmeme	doc_689641833090_item	2823749	et	4	main
parem	doc_689641833090_item	2823752	et	4	main
rahvale	doc_689641833090_item	2823754	et	3	main
relikvia	doc_689641833090_item	2823790	et	4	main
näitused	doc_689641833090_item	2823794	et	3	main
jälgisid	doc_689641833090_item	2823797	et	4	main
euroopa	doc_689641833090_item	2823798	et	4	main
kavas	doc_689641833090_item	2823801	et	3	main
vähenes	doc_689641833090_item	2823822	et	3	main
stalinismi	doc_689641833090_item	2823824	et	4	main
kirjanikutel	doc_689641833090_item	2823826	et	4	main
sõnu	doc_689641833090_item	2823831	et	4	main
kokkuvõtteks	doc_689641833090_item	2823841	et	3	main
sulaaeg	doc_689641833090_item	2823849	et	3	main
või	doc_689641833090_item	2823873	et	4	main
nagu	doc_689641833090_item	2823884	et	3	main
sündmused	doc_689641833089_item	2823323	et	3	main
augusti	doc_689641833089_item	2823325	et	3	main
1988a	doc_689641833089_item	2823326	et	4	main
nad	doc_689641833089_item	2823335	et	3	main
käed	doc_689641833089_item	2823337	et	3	main
miiting	doc_689641833089_item	2823342	et	3	main
poliitika	doc_689641833089_item	2823344	et	4	main
vastu	doc_689641833089_item	2823345	et	3	main
inimesed	doc_689641833089_item	2823346	et	3	main
ei	doc_689641833089_item	2823347	et	4	main
kasutati	doc_689641833089_item	2823348	et	4	main
tahtsid	doc_689641833089_item	2823351	et	4	main
ole	doc_689641833089_item	2823356	et	4	main
nõus	doc_689641833089_item	2823357	et	4	main
võttis	doc_689641833089_item	2823363	et	3	main
2	doc_689641833089_item	2823365	et	2	main
milj	doc_689641833089_item	2823366	et	4	main
inimest	doc_689641833089_item	2823367	et	3	main
see	doc_689641833089_item	2823368	et	3	main
kogunemine	doc_689641833089_item	2823371	et	4	main
ühendust	doc_689641833089_item	2823374	et	4	main
moodsad	doc_689641833089_item	2823386	et	3	main
rõivad	doc_689641833089_item	2823387	et	3	main
soome	doc_689641833089_item	2823388	et	3	main
televisioon	doc_689641833089_item	2823389	et	4	main
heliplaadid	doc_689641833089_item	2823390	et	3	main
uued	doc_689641833089_item	2823391	et	3	main
kunstniku	doc_689641833089_item	2823392	et	3	main
voolad	doc_689641833089_item	2823393	et	3	main
igasuguseid	doc_689641833089_item	2823394	et	3	main
filmid	doc_689641833089_item	2823395	et	4	main
nagu	doc_689641833089_item	2823396	et	3	main
eesti	doc_689641833089_item	2823397	et	4	main
parim	doc_689641833089_item	2823398	et	4	main
film	doc_689641833089_item	2823399	et	3	main
kevade	doc_689641833089_item	2823400	et	4	main
oskar	doc_689641833089_item	2823401	et	4	main
luts	doc_689641833089_item	2823402	et	3	main
mäeküla	doc_689641833089_item	2823403	et	4	main
piimamees	doc_689641833089_item	2823404	et	4	main
lauluväljaku	doc_689641833089_item	2823405	et	3	main
ehitamine	doc_689641833089_item	2823406	et	4	main
tsensuuri	doc_689641833089_item	2823407	et	4	main
langusinimesed	doc_689641833089_item	2823408	et	3	main
hakkava	doc_689641833089_item	2823409	et	4	main
lugeda	doc_689641833089_item	2823410	et	3	main
huvi	doc_689641833089_item	2823412	et	4	main
luikede	doc_689641833089_item	2823416	et	3	main
tõlgivad	doc_689641833089_item	2823418	et	3	main
raamatuid	doc_689641833089_item	2823420	et	3	main
eesti	doc_689641833089_item	2823421	et	4	main
kolhoosi	doc_689641833089_item	2823445	et	4	main
nsv	doc_689641833089_item	2823451	et	4	main
nagu	doc_689641833089_item	2823453	et	3	main
et	doc_689641833089_item	2823455	et	3	main
oli	doc_689641833089_item	2823462	et	3	main
värviline	doc_689641833089_item	2823466	et	4	main
andsid	doc_689641833089_item	2823472	et	4	main
mulje	doc_689641833089_item	2823475	et	4	main
see	doc_689641833089_item	2823486	et	3	main
filmi	doc_689641833089_item	2823497	et	4	main
eest	doc_689641833089_item	2823498	et	4	main
60	doc_689641833089_item	2823522	et	2	main
siis	doc_689641833089_item	2823524	et	3	main
vaga	doc_689641833089_item	2823527	et	4	main
lahendavad	doc_689641833089_item	2823530	et	4	main
probleemid	doc_689641833089_item	2823531	et	3	main
ei	doc_689641833089_item	2823564	et	4	main
mäletan	doc_689641833089_item	2823565	et	3	main
tema	doc_689641833089_item	2823566	et	4	main
nimi	doc_689641833089_item	2823567	et	3	main
see	doc_689641833089_item	2823571	et	3	main
talvel	doc_689641833089_item	2823573	et	4	main
hea	doc_689641833089_item	2823581	et	4	main
on	doc_689641833089_item	2823585	et	4	main
hea	doc_689641833089_item	2823613	et	4	main
on	doc_689641833089_item	2823620	et	4	main
ja	doc_689641833089_item	2823622	et	3	main
räägib	doc_689641833089_item	2823636	et	3	main
samast	doc_689641833089_item	2823637	et	4	main
sell	doc_689641833089_item	2823641	et	3	main
vabadust	doc_689641833089_item	2823653	et	4	main
libahunt	doc_689641833089_item	2823654	et	3	main
ja	doc_689641833089_item	2823655	et	3	main
valged	doc_689641833089_item	2823659	et	3	main
aga	doc_689641833089_item	2823661	et	3	main
nsväle	doc_689641833089_item	2823675	et	4	main
1960	doc_689641833090_item	2823681	et	2	main
nn	doc_689641833090_item	2823683	et	4	main
eesti	doc_689641833090_item	2823685	et	4	main
2	doc_689641833090_item	2823688	et	2	main
riikide	doc_689641833090_item	2823723	et	3	main
3	doc_689641833090_item	2823726	et	2	main
aja-	doc_689641833090_item	2823728	et	4	main
ja	doc_689641833090_item	2823729	et	3	main
kultuurilugu	doc_689641833090_item	2823730	et	4	main
hrushtshovi	doc_689641833090_item	2823744	et	4	main
ja	doc_689641833090_item	2823750	et	3	main
estonia	doc_689641833090_item	2823765	et	4	main
teater	doc_689641833090_item	2823766	et	3	main
rohkem	doc_689641833090_item	2823770	et	4	main
lavastajad	doc_689641833090_item	2823776	et	4	main
ja	doc_689641833090_item	2823777	et	3	main
uued	doc_689641833090_item	2823778	et	3	main
eesti	doc_689641833090_item	2823782	et	4	main
viimane	doc_689641833090_item	2823789	et	3	main
levib	doc_689641833090_item	2823791	et	3	main
eestis	doc_689641833090_item	2823793	et	3	main
kunstnikud	doc_689641833090_item	2823796	et	3	main
kassettipõlvkond	doc_689641833090_item	2823803	et	4	main
filmid	doc_689641833090_item	2823804	et	4	main
muusikat	doc_689641833090_item	2823805	et	3	main
kui	doc_689641833090_item	2823821	et	3	main
rohkem	doc_689641833090_item	2823828	et	4	main
beatles	doc_689641833090_item	2823839	et	4	main
ansambel	doc_689641833090_item	2823840	et	3	main
võib	doc_689641833090_item	2823842	et	3	main
kultuuri	doc_689641833090_item	2823854	et	4	main
kõik	doc_689641833090_item	2823857	et	4	main
teist	doc_689641833090_item	2823867	et	4	main
sündimust	doc_689641833090_item	2823868	et	3	main
inimesed	doc_689641833090_item	2823869	et	3	main
ise	doc_689641833090_item	2823870	et	4	main
mingi	doc_689641833090_item	2823874	et	4	main
ringis	doc_689641833090_item	2823875	et	4	main
harrastusi	doc_689641833090_item	2823879	et	4	main
päevast	doc_689641833090_item	2823919	et	4	main
vastu	doc_689641833089_item	2823414	et	3	main
palju	doc_689641833089_item	2823419	et	4	main
keelele	doc_689641833089_item	2823422	et	4	main
huvi	doc_689641833089_item	2823423	et	4	main
see	doc_689641833089_item	2823432	et	3	main
oli	doc_689641833089_item	2823433	et	3	main
tehtud	doc_689641833089_item	2823434	et	4	main
elus	doc_689641833089_item	2823441	et	4	main
see	doc_689641833089_item	2823442	et	3	main
film	doc_689641833089_item	2823443	et	3	main
tüüpiline	doc_689641833089_item	2823450	et	3	main
kõik	doc_689641833089_item	2823456	et	4	main
on	doc_689641833089_item	2823457	et	4	main
hästi	doc_689641833089_item	2823458	et	3	main
värviline	doc_689641833089_item	2823463	et	4	main
kõik	doc_689641833089_item	2823469	et	4	main
selle	doc_689641833089_item	2823496	et	4	main
film	doc_689641833089_item	2823501	et	3	main
millest	doc_689641833089_item	2823502	et	3	main
ma	doc_689641833089_item	2823503	et	3	main
räägin	doc_689641833089_item	2823504	et	3	main
on	doc_689641833089_item	2823505	et	4	main
kevade	doc_689641833089_item	2823506	et	4	main
oskar	doc_689641833089_item	2823507	et	4	main
luts	doc_689641833089_item	2823508	et	3	main
see	doc_689641833089_item	2823509	et	3	main
film	doc_689641833089_item	2823510	et	3	main
on	doc_689641833089_item	2823511	et	4	main
nagu	doc_689641833089_item	2823512	et	3	main
kunsti	doc_689641833089_item	2823513	et	4	main
teos	doc_689641833089_item	2823514	et	4	main
see	doc_689641833089_item	2823515	et	3	main
film	doc_689641833089_item	2823516	et	3	main
oli	doc_689641833089_item	2823517	et	3	main
tehtud	doc_689641833089_item	2823518	et	4	main
1969	doc_689641833089_item	2823519	et	2	main
aastal	doc_689641833089_item	2823520	et	3	main
preemiat	doc_689641833089_item	2823499	et	3	main
on	doc_689641833089_item	2823526	et	4	main
positiivne	doc_689641833089_item	2823528	et	3	main
lapsed	doc_689641833089_item	2823529	et	3	main
armastus	doc_689641833089_item	2823536	et	4	main
üks	doc_689641833089_item	2823539	et	3	main
vaga	doc_689641833089_item	2823541	et	4	main
hoolitseb	doc_689641833089_item	2823542	et	3	main
joodiku	doc_689641833089_item	2823543	et	3	main
vastu	doc_689641833089_item	2823544	et	3	main
on	doc_689641833089_item	2823557	et	4	main
hea	doc_689641833089_item	2823558	et	4	main
inimene	doc_689641833089_item	2823559	et	3	main
see	doc_689641833089_item	2823560	et	3	main
inimene	doc_689641833089_item	2823561	et	3	main
kahjuks	doc_689641833089_item	2823562	et	4	main
ma	doc_689641833089_item	2823563	et	3	main
poisi	doc_689641833089_item	2823572	et	3	main
filmi	doc_689641833089_item	2823578	et	4	main
jätakse	doc_689641833089_item	2823580	et	4	main
mulje	doc_689641833089_item	2823582	et	4	main
tõus	doc_689641833089_item	2823594	et	4	main
positiivne	doc_689641833089_item	2823595	et	3	main
aeg	doc_689641833089_item	2823596	et	3	main
ja	doc_689641833089_item	2823597	et	3	main
kolmas	doc_689641833089_item	2823598	et	3	main
film	doc_689641833089_item	2823599	et	3	main
on	doc_689641833089_item	2823603	et	4	main
kitzberg	doc_689641833089_item	2823606	et	4	main
on	doc_689641833089_item	2823610	et	4	main
ka	doc_689641833089_item	2823611	et	3	main
väga	doc_689641833089_item	2823612	et	3	main
a	doc_689641833089_item	2823618	et	4	main
film	doc_689641833089_item	2823619	et	3	main
raske	doc_689641833089_item	2823621	et	4	main
ta	doc_689641833089_item	2823623	et	4	main
aga	doc_689641833089_item	2823629	et	3	main
filmi	doc_689641833089_item	2823630	et	4	main
mis	doc_689641833089_item	2823639	et	4	main
millal	doc_689641833089_item	2823643	et	3	main
ekraniseeriti	doc_689641833089_item	2823645	et	3	main
kardavad	doc_689641833089_item	2823648	et	4	main
must	doc_689641833089_item	2823658	et	4	main
filmid	doc_689641833089_item	2823660	et	4	main
vaja	doc_689641833089_item	2823674	et	4	main
balti	doc_689641833090_item	2823722	et	3	main
tähendas	doc_689641833090_item	2823725	et	3	main
loengutes	doc_689641833090_item	2823733	et	4	main
vaadatud	doc_689641833090_item	2823734	et	4	main
filmide	doc_689641833090_item	2823735	et	3	main
põhjal	doc_689641833090_item	2823736	et	4	main
1	doc_689641833090_item	2823737	et	2	main
sulaperiood	doc_689641833090_item	2823738	et	3	main
on	doc_689641833090_item	2823739	et	4	main
valite	doc_689641833090_item	2823745	et	3	main
periood	doc_689641833090_item	2823746	et	3	main
oli	doc_689641833090_item	2823747	et	3	main
palju	doc_689641833090_item	2823748	et	4	main
nsv	doc_689641833090_item	2823753	et	4	main
kui	doc_689641833090_item	2823755	et	3	main
hakkas	doc_689641833090_item	2823758	et	3	main
arenema	doc_689641833090_item	2823759	et	3	main
teatrikultuur	doc_689641833090_item	2823760	et	3	main
olulisemad	doc_689641833090_item	2823761	et	4	main
teatri	doc_689641833090_item	2823762	et	3	main
keskused	doc_689641833090_item	2823763	et	3	main
oli	doc_689641833090_item	2823764	et	3	main
inimesed	doc_689641833090_item	2823769	et	3	main
tulevad	doc_689641833090_item	2823774	et	4	main
kromanov	doc_689641833090_item	2823786	et	4	main
piimamees	doc_689641833090_item	2823788	et	4	main
kunstihuvi	doc_689641833090_item	2823792	et	4	main
uued	doc_689641833090_item	2823795	et	3	main
abstraktsionismi	doc_689641833090_item	2823800	et	4	main
tsensuur	doc_689641833090_item	2823823	et	3	main
julgesti	doc_689641833090_item	2823843	et	3	main
aspektidele	doc_689641833090_item	2823855	et	3	main
vastu	doc_689641833090_item	2823856	et	3	main
mis	doc_689641833090_item	2823858	et	4	main
oli	doc_689641833090_item	2823859	et	3	main
surve	doc_689641833090_item	2823860	et	4	main
all	doc_689641833090_item	2823861	et	3	main
nii	doc_689641833089_item	2823523	et	3	main
on	doc_689641833089_item	2823534	et	4	main
ju	doc_689641833089_item	2823535	et	3	main
ja	doc_689641833089_item	2823537	et	3	main
ei	doc_689641833089_item	2823549	et	4	main
usuvad	doc_689641833089_item	2823550	et	3	main
aga	doc_689641833089_item	2823551	et	3	main
see	doc_689641833089_item	2823552	et	3	main
pois	doc_689641833089_item	2823553	et	3	main
teab	doc_689641833089_item	2823554	et	3	main
et	doc_689641833089_item	2823555	et	3	main
joodik	doc_689641833089_item	2823569	et	3	main
nad	doc_689641833089_item	2823574	et	3	main
pärast	doc_689641833089_item	2823577	et	4	main
vaatamist	doc_689641833089_item	2823579	et	4	main
sest	doc_689641833089_item	2823583	et	4	main
hea	doc_689641833089_item	2823586	et	4	main
oli	doc_689641833089_item	2823589	et	3	main
sellel	doc_689641833089_item	2823591	et	4	main
ajal	doc_689641833089_item	2823592	et	4	main
august	doc_689641833089_item	2823605	et	4	main
olid	doc_689641833089_item	2823640	et	4	main
teda	doc_689641833089_item	2823644	et	4	main
et	doc_689641833089_item	2823646	et	3	main
ei	doc_689641833089_item	2823651	et	4	main
on	doc_689641833089_item	2823657	et	4	main
see	doc_689641833089_item	2823662	et	3	main
on	doc_689641833089_item	2823665	et	4	main
neist	doc_689641833089_item	2823668	et	4	main
tähendab	doc_689641833089_item	2823669	et	3	main
et	doc_689641833089_item	2823670	et	3	main
see	doc_689641833089_item	2823671	et	3	main
film	doc_689641833089_item	2823672	et	3	main
oli	doc_689641833089_item	2823673	et	3	main
oli	doc_689641833089_item	2823677	et	3	main
kontrolltöö	doc_689641833090_item	2823679	et	4	main
aastate	doc_689641833090_item	2823682	et	3	main
sulaperioodi	doc_689641833090_item	2823684	et	4	main
üldiseloomustus	doc_689641833090_item	2823687	et	4	main
ei	doc_689641833090_item	2823689	et	4	main
aima	doc_689641833090_item	2823690	et	4	main
hiina	doc_689641833090_item	2823694	et	3	main
sest	doc_689641833090_item	2823695	et	4	main
paelast	doc_689641833090_item	2823696	et	4	main
me	doc_689641833090_item	2823697	et	4	main
balti	doc_689641833090_item	2823698	et	3	main
pealinnade	doc_689641833090_item	2823699	et	3	main
vahel	doc_689641833090_item	2823700	et	4	main
aga	doc_689641833090_item	2823701	et	3	main
nii	doc_689641833090_item	2823702	et	3	main
toompealt	doc_689641833090_item	2823703	et	3	main
kui	doc_689641833090_item	2823704	et	3	main
gediminasest	doc_689641833090_item	2823705	et	4	main
moskvale	doc_689641833090_item	2823706	et	4	main
sisendab	doc_689641833090_item	2823707	et	3	main
hirmu	doc_689641833090_item	2823708	et	4	main
see	doc_689641833090_item	2823709	et	3	main
ahel	doc_689641833090_item	2823710	et	3	main
millisest	doc_689641833090_item	2823711	et	3	main
sündmusest	doc_689641833090_item	2823712	et	4	main
kõneldakse	doc_689641833090_item	2823713	et	3	main
paimla	doc_689641833090_item	2823714	et	4	main
luuletuses	doc_689641833090_item	2823715	et	4	main
millal	doc_689641833090_item	2823716	et	3	main
see	doc_689641833090_item	2823717	et	3	main
toimus	doc_689641833090_item	2823718	et	3	main
ja	doc_689641833090_item	2823719	et	3	main
mida	doc_689641833090_item	2823720	et	4	main
eesti	doc_689641833090_item	2823727	et	4	main
palju	doc_689641833090_item	2823751	et	4	main
stalinismi	doc_689641833090_item	2823756	et	4	main
terror	doc_689641833090_item	2823757	et	3	main
vanemuine	doc_689641833090_item	2823768	et	4	main
huvitatud	doc_689641833090_item	2823771	et	4	main
ooperas	doc_689641833090_item	2823772	et	4	main
debüteerivad	doc_689641833090_item	2823781	et	4	main
müür	doc_689641833090_item	2823784	et	3	main
käsper	doc_689641833090_item	2823785	et	4	main
uus	doc_689641833090_item	2823802	et	3	main
areneb	doc_689641833090_item	2823810	et	3	main
televisioon	doc_689641833090_item	2823811	et	4	main
paljudes	doc_689641833090_item	2823812	et	3	main
korterites	doc_689641833090_item	2823813	et	3	main
oli	doc_689641833090_item	2823814	et	3	main
juba	doc_689641833090_item	2823815	et	3	main
teler	doc_689641833090_item	2823816	et	3	main
vaatasid	doc_689641833090_item	2823817	et	4	main
rohkem	doc_689641833090_item	2823818	et	4	main
soome	doc_689641833090_item	2823819	et	3	main
televisioone	doc_689641833090_item	2823820	et	4	main
peale	doc_689641833090_item	2823825	et	4	main
tuli	doc_689641833090_item	2823827	et	4	main
esitleda	doc_689641833090_item	2823832	et	3	main
et	doc_689641833090_item	2823845	et	3	main
oli	doc_689641833090_item	2823847	et	3	main
tundsid	doc_689641833090_item	2823851	et	4	main
oma	doc_689641833090_item	2823866	et	4	main
huvilisi	doc_689641833090_item	2823877	et	4	main
arenema	doc_689641833090_item	2823880	et	3	main
2	doc_689641833090_item	2823883	et	2	main
välja	doc_689641833090_item	2823922	et	4	main
ja	doc_689641833090_item	2823924	et	3	main
elav	doc_689641833090_item	2823931	et	4	main
inimeste	doc_689641833090_item	2823932	et	3	main
hoidsid	doc_689641833090_item	2823936	et	4	main
vabaduse	doc_689641833090_item	2823942	et	4	main
sündmus	doc_689641833090_item	2823946	et	3	main
vapustas	doc_689641833090_item	2823949	et	3	main
liidu	doc_689641833090_item	2823951	et	3	main
tähelepanu	doc_689641833090_item	2823959	et	4	main
saavutamiseks	doc_689641833090_item	2823970	et	4	main
organiseerimine	doc_689641833090_item	2823983	et	4	main
oma	doc_689641833090_item	2823984	et	4	main
eesmärgi	doc_689641833090_item	2823991	et	4	main
saavutada	doc_689641833090_item	2823992	et	3	main
kultuurilugu	doc_689641833090_item	2824000	et	4	main
sovhoosi	doc_689641833090_item	2824031	et	4	main
hea	doc_689641833090_item	2824045	et	4	main
head	doc_689641833090_item	2824051	et	4	main
talumehede	doc_689641833090_item	2824057	et	4	main
raamat	doc_689641833090_item	2824069	et	3	main
kevade	doc_689641833090_item	2824083	et	4	main
lahke	doc_689641833090_item	2824088	et	4	main
uurisin	doc_689641833090_item	2824122	et	3	main
keelne	doc_689641833090_item	2824131	et	3	main
hästi	doc_689641833090_item	2824139	et	3	main
on	doc_689641833090_item	2824152	et	4	main
teiste	doc_689641833090_item	2824166	et	4	main
näitlejäid	doc_689641833090_item	2824170	et	4	main
see	doc_689641833090_item	2824171	et	3	main
annab	doc_689641833090_item	2824172	et	3	main
hästi	doc_689641833090_item	2824173	et	3	main
eseet	doc_689641833091_item	2824187	et	4	main
kontrolltöö	doc_689641833092_item	2824190	et	4	main
anna	doc_689641833092_item	2824192	et	4	main
arengust	doc_689641833092_item	2824195	et	3	main
wabariigis	doc_689641833092_item	2824197	et	4	main
eesti	doc_689641833092_item	2824204	et	4	main
jaoks	doc_689641833090_item	2823724	et	4	main
valitsejaga	doc_689641833090_item	2823742	et	4	main
nikita	doc_689641833090_item	2823743	et	4	main
ja	doc_689641833090_item	2823767	et	3	main
baletis	doc_689641833090_item	2823773	et	4	main
uued	doc_689641833090_item	2823775	et	3	main
etendused	doc_689641833090_item	2823779	et	4	main
kinos	doc_689641833090_item	2823780	et	3	main
rezisöörid	doc_689641833090_item	2823783	et	4	main
mäekula	doc_689641833090_item	2823787	et	4	main
stiili	doc_689641833090_item	2823799	et	4	main
võiks	doc_689641833090_item	2823806	et	4	main
nüüd	doc_689641833090_item	2823807	et	4	main
lindistada	doc_689641833090_item	2823808	et	3	main
säilitada	doc_689641833090_item	2823809	et	3	main
võimalusi	doc_689641833090_item	2823829	et	3	main
oma	doc_689641833090_item	2823830	et	4	main
kuulati	doc_689641833090_item	2823833	et	4	main
raadiot	doc_689641833090_item	2823834	et	3	main
muusikat	doc_689641833090_item	2823835	et	3	main
oli	doc_689641833090_item	2823836	et	3	main
populaarne	doc_689641833090_item	2823837	et	3	main
inglismaa	doc_689641833090_item	2823838	et	4	main
öelda	doc_689641833090_item	2823844	et	4	main
see	doc_689641833090_item	2823846	et	3	main
täpselt	doc_689641833090_item	2823848	et	4	main
inimesed	doc_689641833090_item	2823850	et	3	main
huvi	doc_689641833090_item	2823852	et	4	main
kõigedele	doc_689641833090_item	2823853	et	4	main
arenes	doc_689641833090_item	2823863	et	3	main
ja	doc_689641833090_item	2823864	et	3	main
sai	doc_689641833090_item	2823865	et	4	main
ja	doc_689641833090_item	2823878	et	3	main
ja	doc_689641833090_item	2823881	et	3	main
aru	doc_689641833090_item	2823886	et	4	main
see	doc_689641833090_item	2823888	et	3	main
on	doc_689641833090_item	2823889	et	4	main
seotud	doc_689641833090_item	2823890	et	4	main
baltik	doc_689641833090_item	2823891	et	4	main
kettiga	doc_689641833090_item	2823892	et	4	main
see	doc_689641833090_item	2823893	et	3	main
tõeline	doc_689641833090_item	2823894	et	4	main
surve	doc_689641833090_item	2823895	et	4	main
vastu	doc_689641833090_item	2823896	et	3	main
protest	doc_689641833090_item	2823897	et	3	main
kogunes	doc_689641833090_item	2823898	et	3	main
ja	doc_689641833090_item	2823899	et	3	main
ühendas	doc_689641833090_item	2823900	et	3	main
2	doc_689641833090_item	2823901	et	2	main
miljonit	doc_689641833090_item	2823902	et	3	main
inimest	doc_689641833090_item	2823903	et	3	main
eestis	doc_689641833090_item	2823904	et	3	main
leedus	doc_689641833090_item	2823905	et	4	main
ja	doc_689641833090_item	2823906	et	3	main
23	doc_689641833090_item	2823908	et	2	main
lätis	doc_689641833090_item	2823907	et	4	main
augustil	doc_689641833090_item	2823909	et	3	main
1988a	doc_689641833090_item	2823910	et	4	main
see	doc_689641833090_item	2823911	et	3	main
oli	doc_689641833090_item	2823912	et	3	main
50	doc_689641833090_item	2823913	et	2	main
aastat	doc_689641833090_item	2823914	et	3	main
ribbentroppi-molotovi	doc_689641833090_item	2823915	et	4	main
pakti	doc_689641833090_item	2823916	et	4	main
praegu	doc_689641833090_item	2823862	et	3	main
käisid	doc_689641833090_item	2823871	et	4	main
koorides	doc_689641833090_item	2823872	et	4	main
oma	doc_689641833090_item	2823876	et	4	main
nautida	doc_689641833090_item	2823882	et	3	main
mina	doc_689641833090_item	2823885	et	4	main
sain	doc_689641833090_item	2823887	et	3	main
kirjutamise	doc_689641833090_item	2823918	et	4	main
inimesed	doc_689641833090_item	2823920	et	3	main
leedust	doc_689641833090_item	2823926	et	4	main
põhja	doc_689641833090_item	2823927	et	4	main
eestini	doc_689641833090_item	2823928	et	4	main
oli	doc_689641833090_item	2823929	et	3	main
üks	doc_689641833090_item	2823930	et	3	main
inimesed	doc_689641833090_item	2823935	et	3	main
teise	doc_689641833090_item	2823937	et	4	main
käed	doc_689641833090_item	2823939	et	3	main
see	doc_689641833090_item	2823940	et	3	main
väga	doc_689641833090_item	2823948	et	3	main
nsv	doc_689641833090_item	2823950	et	4	main
kogu	doc_689641833090_item	2823954	et	4	main
ameerika	doc_689641833090_item	2823956	et	3	main
panid	doc_689641833090_item	2823958	et	4	main
maade	doc_689641833090_item	2823961	et	3	main
küsimustele	doc_689641833090_item	2823963	et	4	main
tõeline	doc_689641833090_item	2823966	et	4	main
suur	doc_689641833090_item	2823967	et	3	main
streik	doc_689641833090_item	2823979	et	3	main
hirve	doc_689641833090_item	2823980	et	4	main
pargis	doc_689641833090_item	2823981	et	3	main
aitas	doc_689641833090_item	2823988	et	3	main
eestimaale	doc_689641833090_item	2823989	et	4	main
eesti	doc_689641833090_item	2823997	et	4	main
olen	doc_689641833090_item	2824023	et	3	main
ma	doc_689641833090_item	2824024	et	3	main
näinud	doc_689641833090_item	2824026	et	4	main
elada	doc_689641833090_item	2824043	et	3	main
oli	doc_689641833090_item	2824047	et	3	main
aastal	doc_689641833090_item	2824049	et	3	main
kolhooside	doc_689641833090_item	2824056	et	3	main
vahel	doc_689641833090_item	2824058	et	4	main
muidugi	doc_689641833090_item	2824059	et	4	main
ajal	doc_689641833090_item	2824067	et	4	main
pärast	doc_689641833090_item	2824071	et	4	main
said	doc_689641833090_item	2824077	et	4	main
veel	doc_689641833090_item	2824079	et	4	main
oskar	doc_689641833090_item	2824084	et	4	main
hea	doc_689641833090_item	2824089	et	4	main
jägisin	doc_689641833090_item	2824124	et	4	main
minu	doc_689641833090_item	2824126	et	3	main
esitletud	doc_689641833090_item	2824134	et	4	main
demonstreeris	doc_689641833090_item	2824140	et	3	main
ja	doc_689641833090_item	2824143	et	3	main
ajalood	doc_689641833090_item	2824155	et	4	main
annab	doc_689641833090_item	2824158	et	3	main
ainul	doc_689641833090_item	2824160	et	4	main
aga	doc_689641833090_item	2824163	et	3	main
ka	doc_689641833090_item	2824165	et	3	main
rezisööri	doc_689641833090_item	2824169	et	4	main
tollajase	doc_689641833090_item	2824174	et	4	main
atmosfääri	doc_689641833090_item	2824175	et	4	main
tajuda	doc_689641833090_item	2824176	et	3	main
kiri	doc_689641833091_item	2824177	et	3	main
mul	doc_689641833091_item	2824178	et	3	main
1	doc_689641833092_item	2824191	et	2	main
rahvusteaduste	doc_689641833092_item	2824194	et	3	main
eesti	doc_689641833092_item	2824196	et	4	main
2	doc_689641833092_item	2824198	et	2	main
hinda	doc_689641833092_item	2824199	et	4	main
1905	doc_689641833092_item	2824200	et	2	main
kui	doc_689641833092_item	2824210	et	3	main
filmi	doc_689641833092_item	2824212	et	4	main
valgus	doc_689641833092_item	2824213	et	4	main
ajal	doc_689641833092_item	2824221	et	4	main
levima	doc_689641833092_item	2824223	et	3	main
teaduste	doc_689641833092_item	2824225	et	3	main
vastu	doc_689641833092_item	2824226	et	3	main
paljud	doc_689641833092_item	2824229	et	3	main
inimesi	doc_689641833092_item	2824237	et	4	main
sellepärast	doc_689641833092_item	2824240	et	3	main
suurenes	doc_689641833092_item	2824243	et	4	main
eesti-soome-ugri	doc_689641833092_item	2824246	et	3	main
all	doc_689641833090_item	2823917	et	3	main
tulid	doc_689641833090_item	2823921	et	4	main
tänavasse	doc_689641833090_item	2823923	et	4	main
lõuna	doc_689641833090_item	2823925	et	4	main
kõik	doc_689641833090_item	2823934	et	4	main
inimeste	doc_689641833090_item	2823938	et	3	main
oli	doc_689641833090_item	2823941	et	3	main
euroopa	doc_689641833090_item	2823957	et	4	main
vabaduse	doc_689641833090_item	2823969	et	4	main
ime	doc_689641833090_item	2823982	et	4	main
oma	doc_689641833090_item	2823990	et	4	main
aja-	doc_689641833090_item	2823998	et	4	main
ja	doc_689641833090_item	2823999	et	3	main
sümbol	doc_689641833090_item	2823944	et	3	main
see	doc_689641833090_item	2823945	et	3	main
muidugi	doc_689641833090_item	2823947	et	4	main
moskvat	doc_689641833090_item	2823952	et	4	main
ja	doc_689641833090_item	2823953	et	3	main
oli	doc_689641833090_item	2823965	et	3	main
samm	doc_689641833090_item	2823968	et	3	main
sündmus	doc_689641833090_item	2823972	et	3	main
teiste	doc_689641833090_item	2823974	et	4	main
eestis	doc_689641833090_item	2823975	et	3	main
toimunud	doc_689641833090_item	2823976	et	4	main
sündmustega	doc_689641833090_item	2823977	et	3	main
nagu	doc_689641833090_item	2823978	et	3	main
lippu	doc_689641833090_item	2823985	et	4	main
tagasi	doc_689641833090_item	2823986	et	3	main
tulek	doc_689641833090_item	2823987	et	3	main
vabadust	doc_689641833090_item	2823995	et	4	main
3	doc_689641833090_item	2823996	et	2	main
esimestest	doc_689641833090_item	2824004	et	4	main
filmidest	doc_689641833090_item	2824005	et	3	main
mis	doc_689641833090_item	2824006	et	4	main
tehti	doc_689641833090_item	2824007	et	3	main
meie	doc_689641833090_item	2824008	et	4	main
eesti	doc_689641833090_item	2824009	et	4	main
rexisöörid	doc_689641833090_item	2824010	et	4	main
leningradi	doc_689641833090_item	2824011	et	4	main
stuudias	doc_689641833090_item	2824012	et	4	main
esimene	doc_689641833090_item	2824013	et	3	main
värvifilm	doc_689641833090_item	2824014	et	3	main
oli	doc_689641833090_item	2824015	et	3	main
valgus	doc_689641833090_item	2824016	et	4	main
koordis	doc_689641833090_item	2824017	et	4	main
georg	doc_689641833090_item	2824018	et	4	main
otsiga	doc_689641833090_item	2824019	et	4	main
pearollis	doc_689641833090_item	2824020	et	3	main
seda	doc_689641833090_item	2824021	et	3	main
loenguses	doc_689641833090_item	2824025	et	3	main
kolhoosi	doc_689641833090_item	2824029	et	4	main
ja	doc_689641833090_item	2824030	et	3	main
ja	doc_689641833090_item	2824052	et	3	main
suhted	doc_689641833090_item	2824054	et	3	main
natuke	doc_689641833090_item	2824062	et	4	main
teine	doc_689641833090_item	2824063	et	3	main
toll	doc_689641833090_item	2824066	et	3	main
see	doc_689641833090_item	2824068	et	3	main
see	doc_689641833090_item	2824072	et	3	main
väga	doc_689641833090_item	2824075	et	3	main
hiljuti	doc_689641833090_item	2824080	et	4	main
vaadanud	doc_689641833090_item	2824081	et	4	main
film	doc_689641833090_item	2824082	et	3	main
järgi	doc_689641833090_item	2824087	et	4	main
kett	doc_689641833090_item	2823933	et	4	main
tahtmise	doc_689641833090_item	2823943	et	4	main
maailmat	doc_689641833090_item	2823955	et	4	main
balti	doc_689641833090_item	2823960	et	3	main
vabaduse	doc_689641833090_item	2823962	et	4	main
see	doc_689641833090_item	2823964	et	3	main
see	doc_689641833090_item	2823971	et	3	main
koos	doc_689641833090_item	2823973	et	4	main
1991	doc_689641833090_item	2823993	et	2	main
a	doc_689641833090_item	2823994	et	4	main
filmis	doc_689641833090_item	2824001	et	4	main
võib	doc_689641833090_item	2824002	et	3	main
jälgida	doc_689641833090_item	2824003	et	3	main
filmi	doc_689641833090_item	2824022	et	4	main
see	doc_689641833090_item	2824027	et	3	main
iseloomustab	doc_689641833090_item	2824028	et	4	main
kui	doc_689641833090_item	2824037	et	3	main
hea	doc_689641833090_item	2824038	et	4	main
ja	doc_689641833090_item	2824039	et	3	main
kasulik	doc_689641833090_item	2824040	et	3	main
oli	doc_689641833090_item	2824041	et	3	main
kolhoosis	doc_689641833090_item	2824042	et	3	main
saak	doc_689641833090_item	2824046	et	3	main
igal	doc_689641833090_item	2824048	et	3	main
kui	doc_689641833090_item	2824050	et	3	main
on	doc_689641833090_item	2824055	et	4	main
pilt	doc_689641833090_item	2824064	et	3	main
aga	doc_689641833090_item	2824065	et	3	main
olid	doc_689641833090_item	2824074	et	4	main
populaarsed	doc_689641833090_item	2824076	et	3	main
vene	doc_689641833090_item	2824130	et	4	main
aga	doc_689641833090_item	2824137	et	3	main
oli	doc_689641833090_item	2824145	et	3	main
väga	doc_689641833090_item	2824153	et	3	main
inimeste	doc_689641833090_item	2824167	et	3	main
on	doc_689641833091_item	2824179	et	4	main
esimest	doc_689641833091_item	2824182	et	4	main
kontrolltöö	doc_689641833091_item	2824183	et	4	main
kirjutada	doc_689641833091_item	2824184	et	3	main
tulen	doc_689641833091_item	2824185	et	3	main
teisipäeval	doc_689641833091_item	2824186	et	3	main
aasta	doc_689641833092_item	2824201	et	4	main
sündmuste	doc_689641833092_item	2824202	et	3	main
3	doc_689641833092_item	2824206	et	2	main
nähtu	doc_689641833092_item	2824215	et	4	main
inimesed	doc_689641833092_item	2824230	et	3	main
käisid	doc_689641833092_item	2824231	et	4	main
sai	doc_689641833092_item	2824238	et	4	main
muinasteadust	doc_689641833092_item	2824252	et	4	main
tööd	doc_689641833092_item	2824259	et	4	main
ainult	doc_689641833092_item	2824262	et	4	main
kaheks	doc_689641833092_item	2824276	et	4	main
bioloogia	doc_689641833092_item	2824282	et	4	main
vabalt	doc_689641833092_item	2824338	et	4	main
ja	doc_689641833092_item	2824339	et	3	main
peterburis	doc_689641833092_item	2824351	et	4	main
rohkem	doc_689641833092_item	2824359	et	4	main
streigid	doc_689641833092_item	2824363	et	4	main
koolitöö	doc_689641833092_item	2824370	et	4	main
oma	doc_689641833092_item	2824374	et	4	main
algas	doc_689641833092_item	2824378	et	3	main
streigisid	doc_689641833092_item	2824387	et	4	main
töölised	doc_689641833092_item	2824388	et	3	main
revolutsione	doc_689641833092_item	2824391	et	4	main
ja	doc_689641833092_item	2824421	et	3	main
saavutused	doc_689641833092_item	2824423	et	4	main
väikesed	doc_689641833092_item	2824425	et	4	main
eestlastele	doc_689641833092_item	2824430	et	4	main
ja	doc_689641833092_item	2824448	et	3	main
on	doc_689641833092_item	2824458	et	4	main
filmis	doc_689641833092_item	2824467	et	4	main
palju	doc_689641833092_item	2824477	et	4	main
parem	doc_689641833092_item	2824478	et	4	main
elada	doc_689641833092_item	2824479	et	3	main
atmosfäär	doc_689641833092_item	2824480	et	3	main
on	doc_689641833092_item	2824481	et	4	main
edu	doc_689641833092_item	2824486	et	4	main
saab	doc_689641833092_item	2824487	et	3	main
sellele	doc_689641833092_item	2824500	et	4	main
ja	doc_689641833092_item	2824511	et	3	main
hästi	doc_689641833092_item	2824523	et	3	main
nii	doc_689641833092_item	2824529	et	3	main
asutamisega	doc_689641833090_item	2824032	et	4	main
see	doc_689641833090_item	2824033	et	3	main
muinasjutt	doc_689641833090_item	2824034	et	3	main
näitab	doc_689641833090_item	2824035	et	3	main
meile	doc_689641833090_item	2824036	et	4	main
kui	doc_689641833090_item	2824044	et	3	main
sõbralikud	doc_689641833090_item	2824053	et	3	main
tõeliselt	doc_689641833090_item	2824060	et	4	main
oli	doc_689641833090_item	2824061	et	3	main
ja	doc_689641833090_item	2824070	et	3	main
film	doc_689641833090_item	2824073	et	3	main
preemiad	doc_689641833090_item	2824078	et	3	main
lutsu	doc_689641833090_item	2824085	et	4	main
raamatu	doc_689641833090_item	2824086	et	4	main
ja	doc_689641833090_item	2824090	et	3	main
tõesi	doc_689641833090_item	2824091	et	4	main
huvitav	doc_689641833090_item	2824092	et	4	main
film	doc_689641833090_item	2824093	et	3	main
eesti	doc_689641833090_item	2824094	et	4	main
õpilastest	doc_689641833090_item	2824095	et	4	main
venestamise	doc_689641833090_item	2824096	et	4	main
aega	doc_689641833090_item	2824097	et	4	main
kasvatanud	doc_689641833090_item	2824098	et	4	main
kui	doc_689641833090_item	2824099	et	3	main
raske	doc_689641833090_item	2824100	et	4	main
oli	doc_689641833090_item	2824101	et	3	main
vene	doc_689641833090_item	2824102	et	4	main
keeles	doc_689641833090_item	2824103	et	4	main
õppida	doc_689641833090_item	2824104	et	3	main
kui	doc_689641833090_item	2824106	et	3	main
ja	doc_689641833090_item	2824105	et	3	main
armas	doc_689641833090_item	2824107	et	3	main
ja	doc_689641833090_item	2824108	et	3	main
huvitav	doc_689641833090_item	2824109	et	4	main
oli	doc_689641833090_item	2824110	et	3	main
kõik	doc_689641833090_item	2824111	et	4	main
mis	doc_689641833090_item	2824112	et	4	main
õppinguid	doc_689641833090_item	2824113	et	4	main
ei	doc_689641833090_item	2824114	et	4	main
puudu	doc_689641833090_item	2824115	et	4	main
veel	doc_689641833090_item	2824116	et	4	main
revolutsiooni	doc_689641833090_item	2824117	et	4	main
perioodi	doc_689641833090_item	2824118	et	4	main
ka	doc_689641833090_item	2824119	et	3	main
ma	doc_689641833090_item	2824120	et	3	main
hästi	doc_689641833090_item	2824121	et	3	main
ja	doc_689641833090_item	2824123	et	3	main
kõik	doc_689641833090_item	2824125	et	4	main
lugu	doc_689641833090_item	2824132	et	4	main
oli	doc_689641833090_item	2824133	et	3	main
nagu	doc_689641833090_item	2824135	et	3	main
leninid	doc_689641833090_item	2824127	et	4	main
filmis	doc_689641833090_item	2824128	et	4	main
see	doc_689641833090_item	2824129	et	3	main
nali	doc_689641833090_item	2824136	et	3	main
missugune	doc_689641833090_item	2824141	et	3	main
tollajasel	doc_689641833090_item	2824146	et	4	main
eestil	doc_689641833090_item	2824147	et	3	main
ja	doc_689641833090_item	2824148	et	3	main
venemaal	doc_689641833090_item	2824149	et	4	main
filmide	doc_689641833090_item	2824150	et	3	main
mitte	doc_689641833090_item	2824159	et	3	main
pildi	doc_689641833090_item	2824162	et	4	main
veel	doc_689641833090_item	2824164	et	4	main
arvamusi	doc_689641833090_item	2824168	et	3	main
veel	doc_689641833091_item	2824181	et	4	main
võtan	doc_689641833091_item	2824189	et	3	main
ülevaade	doc_689641833092_item	2824193	et	3	main
tähtsust	doc_689641833092_item	2824203	et	4	main
kirjelda	doc_689641833092_item	2824207	et	4	main
realismi	doc_689641833092_item	2824209	et	4	main
põhjal	doc_689641833092_item	2824216	et	4	main
1	doc_689641833092_item	2824217	et	2	main
eesti	doc_689641833092_item	2824218	et	4	main
wabariigis	doc_689641833092_item	2824219	et	4	main
toll	doc_689641833092_item	2824220	et	3	main
veterinaar	doc_689641833092_item	2824233	et	4	main
akadeemias	doc_689641833092_item	2824234	et	3	main
tugevnes	doc_689641833092_item	2824241	et	3	main
ja	doc_689641833092_item	2824242	et	3	main
haritlaskond	doc_689641833092_item	2824244	et	3	main
eesti	doc_689641833092_item	2824253	et	4	main
lnnus	doc_689641833092_item	2824255	et	4	main
ränk	doc_689641833092_item	2824256	et	3	main
koidula	doc_689641833092_item	2824257	et	4	main
arenesid	doc_689641833092_item	2824265	et	4	main
kõrgkoolis	doc_689641833092_item	2824267	et	4	main
tehnikumis	doc_689641833092_item	2824268	et	3	main
õpiti	doc_689641833092_item	2824269	et	3	main
matemaatikat	doc_689641833092_item	2824270	et	3	main
ja	doc_689641833092_item	2824271	et	3	main
füüsikat	doc_689641833092_item	2824272	et	3	main
reaalkallukaga	doc_689641833092_item	2824273	et	4	main
klassid	doc_689641833092_item	2824274	et	3	main
jagati	doc_689641833092_item	2824275	et	3	main
ja	doc_689641833092_item	2824280	et	3	main
suund	doc_689641833092_item	2824284	et	3	main
õpitati	doc_689641833092_item	2824286	et	3	main
tartu	doc_689641833092_item	2824287	et	4	main
ülikoolis	doc_689641833092_item	2824288	et	4	main
sepp	doc_689641833092_item	2824289	et	3	main
tegesid	doc_689641833092_item	2824298	et	4	main
edu	doc_689641833092_item	2824321	et	4	main
ja	doc_689641833092_item	2824324	et	3	main
sellepärast	doc_689641833092_item	2824328	et	3	main
see	doc_689641833092_item	2824330	et	3	main
avaldasid	doc_689641833092_item	2824347	et	4	main
lühenemist	doc_689641833092_item	2824355	et	4	main
kõrgemasse	doc_689641833092_item	2824375	et	4	main
eesti	doc_689641833092_item	2824383	et	4	main
läks	doc_689641833092_item	2824385	et	3	main
streigima	doc_689641833092_item	2824386	et	4	main
tunne	doc_689641833092_item	2824392	et	4	main
tugev	doc_689641833092_item	2824394	et	4	main
ja	doc_689641833092_item	2824424	et	3	main
võitlused	doc_689641833092_item	2824426	et	3	main
sellel	doc_689641833092_item	2824427	et	4	main
edasi	doc_689641833092_item	2824436	et	3	main
oma	doc_689641833092_item	2824440	et	4	main
elule	doc_689641833092_item	2824441	et	3	main
sotsialistlik	doc_689641833092_item	2824445	et	3	main
elada	doc_689641833092_item	2824459	et	3	main
on	doc_689641833092_item	2824476	et	4	main
ainult	doc_689641833092_item	2824489	et	4	main
ja	doc_689641833092_item	2824503	et	3	main
ja	doc_689641833092_item	2824506	et	3	main
väga	doc_689641833092_item	2824509	et	3	main
ka	doc_689641833090_item	2824138	et	3	main
kaos	doc_689641833090_item	2824142	et	4	main
ebakindlus	doc_689641833090_item	2824144	et	4	main
järgi	doc_689641833090_item	2824151	et	4	main
huvitav	doc_689641833090_item	2824154	et	4	main
uurida	doc_689641833090_item	2824156	et	3	main
see	doc_689641833090_item	2824157	et	3	main
visuaalset	doc_689641833090_item	2824161	et	3	main
vaja	doc_689641833091_item	2824180	et	4	main
kaasa	doc_689641833091_item	2824188	et	4	main
ajaloos	doc_689641833092_item	2824205	et	4	main
koordis	doc_689641833092_item	2824214	et	4	main
huvi	doc_689641833092_item	2824224	et	4	main
paljud	doc_689641833092_item	2824227	et	3	main
ja	doc_689641833092_item	2824228	et	3	main
ülikoolis	doc_689641833092_item	2824232	et	4	main
rahvaluule	doc_689641833092_item	2824248	et	4	main
suitsuetersoni	doc_689641833092_item	2824258	et	4	main
humanitaar	doc_689641833092_item	2824263	et	4	main
füüsika	doc_689641833092_item	2824278	et	4	main
suund	doc_689641833092_item	2824279	et	3	main
observatooriumis	doc_689641833092_item	2824290	et	3	main
tähte	doc_689641833092_item	2824293	et	4	main
astronoomiat	doc_689641833092_item	2824295	et	3	main
akadeemia	doc_689641833092_item	2824297	et	4	main
toll	doc_689641833092_item	2824322	et	3	main
ajal	doc_689641833092_item	2824323	et	4	main
just	doc_689641833092_item	2824327	et	3	main
et	doc_689641833092_item	2824329	et	3	main
oli	doc_689641833092_item	2824331	et	3	main
juba	doc_689641833092_item	2824332	et	3	main
wabariik	doc_689641833092_item	2824333	et	4	main
ja	doc_689641833092_item	2824334	et	3	main
nad	doc_689641833092_item	2824335	et	3	main
tegid	doc_689641833092_item	2824336	et	4	main
seda	doc_689641833092_item	2824337	et	3	main
oma	doc_689641833092_item	2824348	et	4	main
tingimused	doc_689641833092_item	2824349	et	3	main
nagu	doc_689641833092_item	2824350	et	3	main
palga	doc_689641833092_item	2824356	et	3	main
tõusmist	doc_689641833092_item	2824357	et	4	main
ja	doc_689641833092_item	2824358	et	3	main
koosolekut	doc_689641833092_item	2824364	et	3	main
paljud	doc_689641833092_item	2824365	et	3	main
katkes	doc_689641833092_item	2824369	et	4	main
sai	doc_689641833092_item	2824372	et	4	main
eestis	doc_689641833092_item	2824377	et	3	main
poliitiline	doc_689641833092_item	2824379	et	3	main
oktoobris	doc_689641833092_item	2824382	et	3	main
raudtee	doc_689641833092_item	2824384	et	4	main
ja	doc_689641833092_item	2824393	et	3	main
andsid	doc_689641833092_item	2824429	et	4	main
eest	doc_689641833092_item	2824442	et	4	main
3	doc_689641833092_item	2824444	et	2	main
hea	doc_689641833092_item	2824453	et	4	main
nsv	doc_689641833092_item	2824460	et	4	main
kui	doc_689641833092_item	2824464	et	3	main
oli	doc_689641833092_item	2824466	et	3	main
talu	doc_689641833092_item	2824469	et	4	main
isegi	doc_689641833092_item	2824491	et	4	main
kui	doc_689641833092_item	2824492	et	3	main
ususid	doc_689641833092_item	2824498	et	4	main
inimesed	doc_689641833092_item	2824499	et	3	main
populaarne	doc_689641833092_item	2824510	et	3	main
sotsialistlikku	doc_689641833092_item	2824208	et	4	main
loomismeetodit	doc_689641833092_item	2824211	et	3	main
hakkas	doc_689641833092_item	2824222	et	3	main
tehnikumis	doc_689641833092_item	2824235	et	3	main
rohkem	doc_689641833092_item	2824236	et	4	main
kõrgharidust	doc_689641833092_item	2824239	et	4	main
uuriti	doc_689641833092_item	2824245	et	3	main
keelt	doc_689641833092_item	2824247	et	4	main
eesti	doc_689641833092_item	2824249	et	4	main
etnograafiat	doc_689641833092_item	2824254	et	3	main
muidugi	doc_689641833092_item	2824260	et	4	main
alad	doc_689641833092_item	2824264	et	3	main
tehnika	doc_689641833092_item	2824266	et	4	main
keemia	doc_689641833092_item	2824283	et	4	main
majandusteadust	doc_689641833092_item	2824285	et	4	main
ka	doc_689641833092_item	2824292	et	3	main
ja	doc_689641833092_item	2824294	et	3	main
põllumajanduse	doc_689641833092_item	2824296	et	3	main
paljud	doc_689641833092_item	2824299	et	3	main
mpilli	doc_689641833092_item	2824300	et	4	main
kuidas	doc_689641833092_item	2824301	et	3	main
saada	doc_689641833092_item	2824302	et	4	main
head	doc_689641833092_item	2824303	et	4	main
saake	doc_689641833092_item	2824304	et	3	main
kuidas	doc_689641833092_item	2824305	et	3	main
uut	doc_689641833092_item	2824306	et	3	main
sorte	doc_689641833092_item	2824307	et	3	main
avalda	doc_689641833092_item	2824308	et	4	main
näitused	doc_689641833092_item	2824309	et	3	main
põllumajanduses	doc_689641833092_item	2824310	et	3	main
kokkuvõteks	doc_689641833092_item	2824311	et	3	main
võib	doc_689641833092_item	2824312	et	3	main
et	doc_689641833092_item	2824314	et	3	main
haridus	doc_689641833092_item	2824315	et	3	main
ja	doc_689641833092_item	2824316	et	3	main
teadus	doc_689641833092_item	2824317	et	4	main
öelda	doc_689641833092_item	2824313	et	4	main
arenesid	doc_689641833092_item	2824318	et	4	main
ja	doc_689641833092_item	2824319	et	3	main
saavutasid	doc_689641833092_item	2824320	et	4	main
see	doc_689641833092_item	2824325	et	3	main
toimus	doc_689641833092_item	2824326	et	3	main
tahtsid	doc_689641833092_item	2824352	et	4	main
nad	doc_689641833092_item	2824353	et	3	main
tehased	doc_689641833092_item	2824366	et	3	main
koolis	doc_689641833092_item	2824368	et	4	main
oktoobris	doc_689641833092_item	2824371	et	3	main
revolutsioon	doc_689641833092_item	2824373	et	3	main
14	doc_689641833092_item	2824381	et	2	main
postitöölised	doc_689641833092_item	2824389	et	3	main
soov	doc_689641833092_item	2824395	et	3	main
ajalugu	doc_689641833092_item	2824250	et	4	main
eesti	doc_689641833092_item	2824251	et	4	main
mitte	doc_689641833092_item	2824261	et	3	main
matemaatika	doc_689641833092_item	2824277	et	4	main
looduse	doc_689641833092_item	2824281	et	4	main
hakati	doc_689641833092_item	2824291	et	3	main
iseenda	doc_689641833092_item	2824340	et	3	main
jaoks	doc_689641833092_item	2824341	et	4	main
2	doc_689641833092_item	2824342	et	2	main
revolutsioon	doc_689641833092_item	2824343	et	3	main
1905a	doc_689641833092_item	2824344	et	4	main
eestis	doc_689641833092_item	2824345	et	3	main
töölised	doc_689641833092_item	2824346	et	3	main
tööpäeva	doc_689641833092_item	2824354	et	4	main
õigusi	doc_689641833092_item	2824360	et	4	main
korraldasid	doc_689641833092_item	2824361	et	4	main
nad	doc_689641833092_item	2824362	et	3	main
seisasid	doc_689641833092_item	2824367	et	4	main
faasi	doc_689641833092_item	2824376	et	4	main
üldstreik	doc_689641833092_item	2824380	et	3	main
käsitöölised	doc_689641833092_item	2824390	et	3	main
oma	doc_689641833092_item	2824396	et	4	main
elu	doc_689641833092_item	2824397	et	4	main
muutuda	doc_689641833092_item	2824398	et	3	main
andis	doc_689641833092_item	2824399	et	3	main
inimestele	doc_689641833092_item	2824400	et	3	main
jõudu	doc_689641833092_item	2824401	et	4	main
ja	doc_689641833092_item	2824402	et	3	main
ühendas	doc_689641833092_item	2824403	et	3	main
rahvast	doc_689641833092_item	2824404	et	4	main
nad	doc_689641833092_item	2824405	et	3	main
lihtsad	doc_689641833092_item	2824406	et	3	main
tahtsid	doc_689641833092_item	2824407	et	4	main
olla	doc_689641833092_item	2824408	et	3	main
rohkem	doc_689641833092_item	2824409	et	4	main
iseseisvalt	doc_689641833092_item	2824410	et	4	main
ja	doc_689641833092_item	2824411	et	3	main
kasutada	doc_689641833092_item	2824412	et	3	main
oma	doc_689641833092_item	2824413	et	4	main
keelt	doc_689641833092_item	2824414	et	4	main
kasutada	doc_689641833092_item	2824415	et	3	main
oma	doc_689641833092_item	2824416	et	4	main
aega	doc_689641833092_item	2824417	et	4	main
mitte	doc_689641833092_item	2824418	et	3	main
ainult	doc_689641833092_item	2824419	et	4	main
tööle	doc_689641833092_item	2824420	et	3	main
need	doc_689641833092_item	2824422	et	3	main
rohkem	doc_689641833092_item	2824431	et	4	main
ja	doc_689641833092_item	2824432	et	3	main
rohkem	doc_689641833092_item	2824433	et	4	main
oma	doc_689641833092_item	2824437	et	4	main
ja	doc_689641833092_item	2824439	et	3	main
soov	doc_689641833092_item	2824447	et	3	main
näidata	doc_689641833092_item	2824450	et	4	main
kui	doc_689641833092_item	2824452	et	3	main
ja	doc_689641833092_item	2824454	et	3	main
ilus	doc_689641833092_item	2824455	et	4	main
ja	doc_689641833092_item	2824456	et	3	main
liidu	doc_689641833092_item	2824461	et	3	main
elu	doc_689641833092_item	2824470	et	4	main
kolhooside	doc_689641833092_item	2824471	et	3	main
tekkimise	doc_689641833092_item	2824472	et	4	main
perioodil	doc_689641833092_item	2824473	et	3	main
sõjal	doc_689641833092_item	2824428	et	3	main
jõudu	doc_689641833092_item	2824434	et	4	main
et	doc_689641833092_item	2824435	et	3	main
iseseisvuste	doc_689641833092_item	2824438	et	4	main
võitlema	doc_689641833092_item	2824443	et	3	main
realism	doc_689641833092_item	2824446	et	3	main
meetod	doc_689641833092_item	2824449	et	3	main
inimestele	doc_689641833092_item	2824451	et	3	main
kaunis	doc_689641833092_item	2824457	et	4	main
reeglite	doc_689641833092_item	2824462	et	3	main
järgi	doc_689641833092_item	2824463	et	4	main
see	doc_689641833092_item	2824465	et	3	main
ühe	doc_689641833092_item	2824468	et	4	main
on	doc_689641833092_item	2824484	et	4	main
koos	doc_689641833092_item	2824490	et	4	main
see	doc_689641833092_item	2824493	et	3	main
tõesti	doc_689641833092_item	2824494	et	3	main
ei	doc_689641833092_item	2824496	et	4	main
olnud	doc_689641833092_item	2824497	et	4	main
see	doc_689641833092_item	2824504	et	3	main
film	doc_689641833092_item	2824507	et	3	main
mingit	doc_689641833092_item	2824513	et	3	main
preemiat	doc_689641833092_item	2824514	et	3	main
ka	doc_689641833092_item	2824515	et	3	main
see	doc_689641833092_item	2824516	et	3	main
oli	doc_689641833092_item	2824517	et	3	main
nagu	doc_689641833092_item	2824518	et	3	main
propaganda	doc_689641833092_item	2824519	et	4	main
et	doc_689641833092_item	2824520	et	3	main
vaadake	doc_689641833092_item	2824521	et	3	main
see	doc_689641833092_item	2824530	et	3	main
olnud	doc_689641833092_item	2824532	et	4	main
muinasjutt	doc_689641833092_item	2824535	et	3	main
tuli	doc_689641833092_item	2824536	et	4	main
see	doc_689641833092_item	2824541	et	3	main
kontrolltöö	doc_696163377508_item	2824544	et	4	main
tähendab	doc_696163377508_item	2824549	et	3	main
kuulusid	doc_696163377508_item	2824561	et	4	main
talupoeg	doc_696163377508_item	2824563	et	3	main
sattub	doc_696163377508_item	2824564	et	3	main
vene	doc_696163377508_item	2824568	et	4	main
kolalikud	doc_696163377508_item	2824570	et	4	main
baltisaksa	doc_696163377508_item	2824571	et	4	main
aadlikud	doc_696163377508_item	2824572	et	3	main
10	doc_696163377508_item	2824581	et	2	main
isegi	doc_696163377508_item	2824597	et	4	main
tugevnes	doc_696163377508_item	2824598	et	3	main
talupoegade	doc_696163377508_item	2824599	et	3	main
vara	doc_696163377508_item	2824600	et	4	main
mõisnike	doc_696163377508_item	2824603	et	3	main
neid	doc_696163377508_item	2824605	et	4	main
poolvabad	doc_696163377508_item	2824612	et	3	main
muudeti	doc_696163377508_item	2824613	et	3	main
otsustatakse	doc_696163377508_item	2824617	et	3	main
rootsi	doc_696163377508_item	2824619	et	4	main
kodukari	doc_696163377508_item	2824625	et	4	main
õigusmõisnik	doc_696163377508_item	2824626	et	3	main
ta	doc_696163377508_item	2824627	et	4	main
nähtavale	doc_696163377508_item	2824643	et	4	main
kristlikust	doc_696163377508_item	2824658	et	4	main
valgustus	doc_696163377508_item	2824662	et	4	main
inimese	doc_696163377508_item	2824666	et	4	main
balti	doc_696163377508_item	2824673	et	3	main
ja	doc_696163377508_item	2824684	et	3	main
rahvusele	doc_696163377508_item	2824721	et	3	main
vaimuvara	doc_696163377508_item	2824732	et	4	main
rahvaluule	doc_696163377508_item	2824733	et	4	main
ja	doc_696163377508_item	2824734	et	3	main
mitmeid	doc_696163377508_item	2824744	et	4	main
raamatuid	doc_696163377508_item	2824745	et	3	main
kalendreid	doc_696163377508_item	2824746	et	3	main
jne	doc_696163377508_item	2824747	et	4	main
ning	doc_696163377508_item	2824754	et	3	main
et	doc_689641833092_item	2824474	et	3	main
kolhoosidel	doc_689641833092_item	2824475	et	3	main
sõbraline	doc_689641833092_item	2824482	et	4	main
saak	doc_689641833092_item	2824483	et	3	main
suurepärane	doc_689641833092_item	2824485	et	4	main
saavutada	doc_689641833092_item	2824488	et	3	main
nii	doc_689641833092_item	2824495	et	3	main
ilusale	doc_689641833092_item	2824501	et	4	main
pildile	doc_689641833092_item	2824502	et	3	main
raamat	doc_689641833092_item	2824505	et	3	main
oli	doc_689641833092_item	2824508	et	3	main
muidugi	doc_689641833092_item	2824528	et	4	main
meeldis	doc_689641833092_item	2824542	et	3	main
balti	doc_696163377508_item	2824550	et	3	main
eesti	doc_696163377508_item	2824556	et	4	main
sinna	doc_696163377508_item	2824560	et	3	main
2	doc_696163377508_item	2824565	et	2	main
isanda	doc_696163377508_item	2824566	et	3	main
90	doc_696163377508_item	2824573	et	2	main
tol	doc_696163377508_item	2824574	et	3	main
ajal	doc_696163377508_item	2824575	et	4	main
talupoeg	doc_696163377508_item	2824583	et	3	main
vabad	doc_696163377508_item	2824610	et	3	main
või	doc_696163377508_item	2824611	et	4	main
et	doc_696163377508_item	2824618	et	3	main
talupoegadele	doc_696163377508_item	2824629	et	3	main
ihunuhtlust	doc_696163377508_item	2824630	et	3	main
tihti	doc_696163377508_item	2824633	et	3	main
ülesleiti	doc_696163377508_item	2824640	et	4	main
prantsusmaal	doc_696163377508_item	2824648	et	4	main
välja	doc_696163377508_item	2824649	et	4	main
andma	doc_696163377508_item	2824650	et	3	main
alanud	doc_696163377508_item	2824661	et	4	main
lahendada	doc_696163377508_item	2824669	et	3	main
päästis	doc_696163377508_item	2824675	et	3	main
keele	doc_696163377508_item	2824677	et	4	main
balti	doc_696163377508_item	2824678	et	3	main
saksa	doc_696163377508_item	2824679	et	4	main
mõisnik	doc_696163377508_item	2824680	et	3	main
õppis	doc_696163377508_item	2824681	et	3	main
sai	doc_689641833092_item	2824512	et	4	main
kui	doc_689641833092_item	2824522	et	3	main
ja	doc_689641833092_item	2824524	et	3	main
me	doc_689641833092_item	2824526	et	4	main
mulle	doc_689641833092_item	2824540	et	4	main
2	doc_696163377508_item	2824552	et	2	main
tegeles	doc_696163377508_item	2824554	et	3	main
kes	doc_696163377508_item	2824559	et	4	main
elavatest	doc_696163377508_item	2824576	et	4	main
talurahvas	doc_696163377508_item	2824579	et	4	main
maal	doc_696163377508_item	2824580	et	4	main
maa-aadlikud	doc_696163377508_item	2824582	et	3	main
ajal	doc_696163377508_item	2824586	et	4	main
oli	doc_696163377508_item	2824590	et	3	main
püüti	doc_696163377508_item	2824601	et	3	main
varem	doc_696163377508_item	2824609	et	4	main
edukalt	doc_689641833092_item	2824525	et	4	main
elame	doc_689641833092_item	2824527	et	3	main
film	doc_689641833092_item	2824534	et	3	main
välja	doc_689641833092_item	2824537	et	4	main
hästi	doc_689641833092_item	2824538	et	3	main
ja	doc_689641833092_item	2824539	et	3	main
kontrolltöö	doc_696163377508_item	2824543	et	4	main
eesti	doc_696163377508_item	2824545	et	4	main
erikord	doc_696163377508_item	2824551	et	3	main
selts	doc_696163377508_item	2824557	et	3	main
ja	doc_696163377508_item	2824558	et	3	main
1	doc_696163377508_item	2824562	et	2	main
tsaar	doc_696163377508_item	2824569	et	3	main
inimestest	doc_696163377508_item	2824577	et	3	main
oli	doc_696163377508_item	2824578	et	3	main
sel	doc_696163377508_item	2824585	et	3	main
pärisori	doc_696163377508_item	2824587	et	4	main
pärisorjus	doc_696163377508_item	2824588	et	3	main
euroopas	doc_696163377508_item	2824589	et	3	main
ammu	doc_696163377508_item	2824591	et	4	main
kaotatud	doc_696163377508_item	2824592	et	4	main
balti	doc_696163377508_item	2824593	et	3	main
erikorra	doc_696163377508_item	2824594	et	3	main
raamees	doc_696163377508_item	2824595	et	3	main
pärisorjus	doc_696163377508_item	2824596	et	3	main
muuta	doc_696163377508_item	2824602	et	4	main
omandiks	doc_696163377508_item	2824604	et	3	main
talupoegi	doc_696163377508_item	2824606	et	4	main
kes	doc_696163377508_item	2824607	et	4	main
olid	doc_696163377508_item	2824608	et	4	main
pärisorjadeks	doc_696163377508_item	2824615	et	3	main
aegsed	doc_696163377508_item	2824620	et	3	main
jäävad	doc_696163377508_item	2824622	et	4	main
püsima	doc_696163377508_item	2824623	et	3	main
säilis	doc_696163377508_item	2824624	et	4	main
jagada	doc_696163377508_item	2824631	et	3	main
põgenesid	doc_696163377508_item	2824634	et	4	main
talupojad	doc_696163377508_item	2824635	et	4	main
talle	doc_696163377508_item	2824642	et	4	main
hakkati	doc_696163377508_item	2824647	et	3	main
oli	doc_696163377508_item	2824660	et	3	main
mõistus	doc_696163377508_item	2824667	et	4	main
kõik	doc_696163377508_item	2824670	et	4	main
eesti	doc_696163377508_item	2824676	et	4	main
tegi	doc_696163377508_item	2824685	et	4	main
tema	doc_696163377508_item	2824723	et	4	main
tööd	doc_696163377508_item	2824725	et	4	main
teha	doc_696163377508_item	2824726	et	3	main
eriti	doc_696163377508_item	2824727	et	3	main
ajaloo	doc_696163377508_item	2824735	et	4	main
tagasiandmist	doc_696163377508_item	2824736	et	3	main
rahvale	doc_696163377508_item	2824737	et	3	main
eestlasi	doc_696163377508_item	2824753	et	3	main
eestlastele	doc_696163377508_item	2824756	et	4	main
palju	doc_696163377508_item	2824758	et	4	main
faehlmanni	doc_696163377508_item	2824779	et	4	main
eepose	doc_696163377508_item	2824783	et	3	main
saksa	doc_696163377508_item	2824790	et	4	main
keelde	doc_696163377508_item	2824791	et	4	main
nii	doc_696163377508_item	2824794	et	3	main
ta	doc_696163377508_item	2824804	et	4	main
poleks	doc_696163377508_item	2824805	et	3	main
eesti	doc_696163377509_item	2824810	et	4	main
juures	doc_696163377509_item	2824818	et	4	main
2	doc_696163377509_item	2824819	et	2	main
hansa	doc_696163377509_item	2824822	et	4	main
kultuuri	doc_696163377509_item	2824828	et	4	main
keskusteks	doc_696163377509_item	2824829	et	4	main
kultuuri	doc_696163377509_item	2824835	et	4	main
säilijaks	doc_696163377509_item	2824839	et	4	main
põhjusi	doc_696163377509_item	2824843	et	3	main
külade	doc_696163377509_item	2824847	et	3	main
oli	doc_696163377509_item	2824849	et	3	main
ristima	doc_696163377509_item	2824878	et	4	main
kohakeelt	doc_696163377509_item	2824882	et	4	main
talupojad	doc_696163377509_item	2824883	et	4	main
jumalateenistust	doc_696163377509_item	2824892	et	3	main
pidama	doc_696163377509_item	2824893	et	4	main
šokk	doc_696163377509_item	2824914	et	2	main
baltimaade	doc_696163377509_item	2824921	et	3	main
ei	doc_689641833092_item	2824531	et	4	main
aga	doc_689641833092_item	2824533	et	3	main
kultuuriloost	doc_696163377508_item	2824546	et	4	main
1	doc_696163377508_item	2824547	et	2	main
mida	doc_696163377508_item	2824548	et	4	main
millega	doc_696163377508_item	2824553	et	3	main
õpetatud	doc_696163377508_item	2824555	et	4	main
alla	doc_696163377508_item	2824567	et	3	main
oli	doc_696163377508_item	2824584	et	3	main
ka	doc_696163377508_item	2824614	et	3	main
hiljem	doc_696163377508_item	2824616	et	3	main
seadused	doc_696163377508_item	2824621	et	3	main
võis	doc_696163377508_item	2824628	et	4	main
üpris	doc_696163377508_item	2824632	et	3	main
põletati	doc_696163377508_item	2824641	et	3	main
1751a	doc_696163377508_item	2824646	et	4	main
entsüklopeediat	doc_696163377508_item	2824651	et	3	main
selle	doc_696163377508_item	2824652	et	4	main
mõte	doc_696163377508_item	2824653	et	3	main
oli	doc_696163377508_item	2824654	et	3	main
ka	doc_696163377508_item	2824655	et	3	main
vabastada	doc_696163377508_item	2824656	et	3	main
inimesed	doc_696163377508_item	2824657	et	3	main
arvati	doc_696163377508_item	2824664	et	4	main
suudab	doc_696163377508_item	2824668	et	3	main
probleemid	doc_696163377508_item	2824671	et	3	main
ratsionalism	doc_696163377508_item	2824672	et	3	main
erikord	doc_696163377508_item	2824674	et	3	main
maakeele	doc_696163377508_item	2824683	et	4	main
soovides	doc_696163377508_item	2824722	et	4	main
jaoks	doc_696163377508_item	2824724	et	4	main
oli	doc_696163377508_item	2824751	et	3	main
see	doc_696163377508_item	2824778	et	3	main
hatti	doc_696163377508_item	2824781	et	4	main
vajalikkusest	doc_696163377508_item	2824784	et	4	main
faehlmann	doc_696163377508_item	2824785	et	4	main
tõlkis	doc_696163377508_item	2824786	et	3	main
kultuuriloost	doc_696163377509_item	2824811	et	4	main
1	doc_696163377509_item	2824812	et	2	main
mis	doc_696163377509_item	2824820	et	4	main
venemaale	doc_696163377508_item	2824636	et	4	main
kui	doc_696163377508_item	2824637	et	3	main
põgenenud	doc_696163377508_item	2824638	et	4	main
talupoeg	doc_696163377508_item	2824639	et	3	main
kohale	doc_696163377508_item	2824644	et	4	main
häbimärk	doc_696163377508_item	2824645	et	3	main
dogmaatikast	doc_696163377508_item	2824659	et	4	main
aeg	doc_696163377508_item	2824663	et	3	main
et	doc_696163377508_item	2824665	et	3	main
ära	doc_696163377508_item	2824682	et	4	main
kõik	doc_696163377508_item	2824686	et	4	main
et	doc_696163377508_item	2824687	et	3	main
siinsed	doc_696163377508_item	2824688	et	3	main
inimesed	doc_696163377508_item	2824689	et	3	main
ei	doc_696163377508_item	2824690	et	4	main
õpiks	doc_696163377508_item	2824691	et	4	main
ära	doc_696163377508_item	2824692	et	4	main
saksa	doc_696163377508_item	2824693	et	4	main
keelt	doc_696163377508_item	2824694	et	4	main
2	doc_696163377508_item	2824695	et	2	main
õpetatud	doc_696163377508_item	2824696	et	4	main
eesti	doc_696163377508_item	2824697	et	4	main
seltsi	doc_696163377508_item	2824698	et	4	main
kuulusid	doc_696163377508_item	2824699	et	4	main
tolla	doc_696163377508_item	2824700	et	4	main
aegsed	doc_696163377508_item	2824701	et	3	main
haritlased	doc_696163377508_item	2824702	et	3	main
nt	doc_696163377508_item	2824703	et	4	main
faehlmann	doc_696163377508_item	2824704	et	4	main
jakob	doc_696163377508_item	2824705	et	4	main
hurt	doc_696163377508_item	2824706	et	3	main
1839-1907	doc_696163377508_item	2824707	et	2	main
vaatamata	doc_696163377508_item	2824708	et	4	main
paljutõotavatele	doc_696163377508_item	2824709	et	3	main
võimalustele	doc_696163377508_item	2824710	et	3	main
sakslaseks	doc_696163377508_item	2824711	et	3	main
saades	doc_696163377508_item	2824712	et	3	main
kiiresti	doc_696163377508_item	2824713	et	3	main
karjääri	doc_696163377508_item	2824714	et	4	main
teha	doc_696163377508_item	2824715	et	3	main
oli	doc_696163377508_item	2824716	et	3	main
hurt	doc_696163377508_item	2824717	et	3	main
jäänud	doc_696163377508_item	2824718	et	4	main
ustavaks	doc_696163377508_item	2824719	et	4	main
oma	doc_696163377508_item	2824720	et	4	main
pidas	doc_696163377508_item	2824729	et	3	main
oluliseks	doc_696163377508_item	2824728	et	4	main
õpetatud	doc_696163377508_item	2824738	et	4	main
sealsete	doc_696163377508_item	2824748	et	4	main
haritlaste	doc_696163377508_item	2824749	et	3	main
eesmärgiks	doc_696163377508_item	2824750	et	3	main
võimalikult	doc_696163377508_item	2824757	et	4	main
haridust	doc_696163377508_item	2824759	et	4	main
1838a	doc_696163377508_item	2824762	et	4	main
hakkas	doc_696163377508_item	2824763	et	3	main
tegutsema	doc_696163377508_item	2824764	et	3	main
ões	doc_696163377508_item	2824765	et	4	main
tartu	doc_696163377508_item	2824766	et	4	main
ülikooli	doc_696163377508_item	2824767	et	4	main
juures	doc_696163377508_item	2824768	et	4	main
koosolekud	doc_696163377508_item	2824769	et	3	main
olid	doc_696163377508_item	2824770	et	4	main
iga	doc_696163377508_item	2824771	et	4	main
kuu	doc_696163377508_item	2824772	et	4	main
viimasel	doc_696163377508_item	2824773	et	3	main
kolmapäeval	doc_696163377508_item	2824774	et	3	main
ka	doc_696163377508_item	2824775	et	3	main
tänapäeval	doc_696163377508_item	2824776	et	3	main
ta	doc_696163377508_item	2824730	et	4	main
rahva	doc_696163377508_item	2824731	et	3	main
eesti	doc_696163377508_item	2824739	et	4	main
selts	doc_696163377508_item	2824740	et	3	main
andis	doc_696163377508_item	2824741	et	3	main
välja	doc_696163377508_item	2824742	et	4	main
ka	doc_696163377508_item	2824743	et	3	main
harida	doc_696163377508_item	2824752	et	3	main
anda	doc_696163377508_item	2824755	et	3	main
oma	doc_696163377508_item	2824760	et	4	main
emakeelest	doc_696163377508_item	2824761	et	4	main
toimib	doc_696163377508_item	2824777	et	3	main
keelsed	doc_696163377508_item	2824788	et	3	main
kokkupanijaks	doc_696163377508_item	2824802	et	4	main
kui	doc_696163377508_item	2824803	et	3	main
mis	doc_696163377509_item	2824813	et	4	main
soodustas	doc_696163377509_item	2824814	et	3	main
muinasusundi	doc_696163377509_item	2824815	et	3	main
säilimist	doc_696163377509_item	2824816	et	4	main
eestlaste	doc_696163377509_item	2824817	et	4	main
kui	doc_696163377509_item	2824825	et	3	main
olid	doc_696163377509_item	2824827	et	4	main
ajaks	doc_696163377509_item	2824833	et	4	main
traditsioonilise	doc_696163377509_item	2824834	et	4	main
kommete	doc_696163377509_item	2824838	et	4	main
ja	doc_696163377509_item	2824846	et	3	main
ja	doc_696163377509_item	2824852	et	3	main
jumalasõnast	doc_696163377509_item	2824886	et	4	main
ainult	doc_696163377509_item	2824888	et	4	main
kirikureformatsiooni	doc_696163377509_item	2824889	et	4	main
olnud	doc_696163377509_item	2824897	et	4	main
uuele	doc_696163377509_item	2824906	et	3	main
kaupmeeste	doc_696163377509_item	2824919	et	4	main
sest	doc_696163377509_item	2824928	et	4	main
läbis	doc_696163377509_item	2824936	et	3	main
paljud	doc_696163377509_item	2824940	et	3	main
initsiatiivil	doc_696163377509_item	2824944	et	3	main
liit	doc_696163377509_item	2824946	et	3	main
kontrollis	doc_696163377509_item	2824947	et	4	main
linnad	doc_696163377509_item	2824954	et	3	main
kool	doc_697936465046_item	2824966	et	4	main
analüüsiv	doc_6982649480_item	2824994	et	4	main
väiteid	doc_6982649480_item	2825003	et	4	main
on	doc_6982649480_item	2825004	et	4	main
näiteks	doc_6982649480_item	2825014	et	4	main
maailma	doc_6982649480_item	2825017	et	4	main
on	doc_6982649480_item	2825021	et	4	main
oma	doc_6982649480_item	2825023	et	4	main
vane	doc_6982649480_item	2825034	et	4	main
vanesti	doc_6982649480_item	2825039	et	4	main
loomi	doc_6982649480_item	2825047	et	4	main
hirmutama	doc_6982649480_item	2825048	et	4	main
loomade	doc_6982649480_item	2825051	et	4	main
rohkem	doc_6982649480_item	2825054	et	4	main
mehed	doc_6982649480_item	2825058	et	3	main
eestlastele	doc_6982649480_item	2825059	et	4	main
meeldib	doc_6982649480_item	2825060	et	3	main
laulda	doc_6982649480_item	2825061	et	4	main
sellepärast	doc_6982649480_item	2825062	et	3	main
lauldes	doc_6982649480_item	2825063	et	3	main
mõtlen	doc_6982649480_item	2825069	et	3	main
lauldest	doc_6982649480_item	2825072	et	4	main
mis	doc_6982649480_item	2825081	et	4	main
on	doc_6982649480_item	2825085	et	4	main
me	doc_6982649480_item	2825089	et	4	main
kus	doc_6982649480_item	2825095	et	3	main
laulupeod	doc_6982649480_item	2825137	et	4	main
toimuvad	doc_6982649480_item	2825143	et	4	main
tänapäeval	doc_6982649480_item	2825144	et	3	main
see	doc_6982649480_item	2825145	et	3	main
on	doc_6982649480_item	2825146	et	4	main
kõige	doc_6982649480_item	2825147	et	4	main
esinevad	doc_6982649480_item	2825150	et	4	main
teised	doc_6982649480_item	2825152	et	4	main
me	doc_6982649480_item	2825159	et	4	main
näita	doc_6982649480_item	2825161	et	4	main
nende	doc_6982649480_item	2825162	et	4	main
kultuur	doc_6982649480_item	2825163	et	3	main
sellepärast	doc_6982649480_item	2825172	et	3	main
et	doc_6982649480_item	2825175	et	3	main
eestvedamisel	doc_696163377508_item	2824780	et	3	main
arutama	doc_696163377508_item	2824782	et	3	main
ööedud	doc_696163377508_item	2824795	et	3	main
õhtuid	doc_696163377508_item	2824797	et	3	main
faehlmann	doc_696163377508_item	2824798	et	4	main
oleks	doc_696163377508_item	2824799	et	3	main
saanud	doc_696163377508_item	2824800	et	4	main
eepose	doc_696163377508_item	2824801	et	3	main
surnud	doc_696163377508_item	2824807	et	4	main
liit	doc_696163377509_item	2824823	et	3	main
linnad	doc_696163377509_item	2824826	et	3	main
talurahvas	doc_696163377509_item	2824830	et	4	main
jäi	doc_696163377509_item	2824831	et	3	main
oli	doc_696163377509_item	2824841	et	3	main
mitu	doc_696163377509_item	2824842	et	4	main
kõigepealt	doc_696163377509_item	2824844	et	3	main
vahel	doc_696163377509_item	2824848	et	4	main
kui	doc_696163377509_item	2824853	et	3	main
oli	doc_696163377509_item	2824856	et	3	main
siis	doc_696163377509_item	2824858	et	3	main
tihti	doc_696163377509_item	2824859	et	3	main
nad	doc_696163377509_item	2824860	et	3	main
teadnud	doc_696163377509_item	2824862	et	4	main
talurahvast	doc_696163377509_item	2824879	et	4	main
ei	doc_696163377509_item	2824884	et	4	main
aru	doc_696163377509_item	2824887	et	4	main
kohakeeles	doc_696163377509_item	2824894	et	4	main
samuti	doc_696163377509_item	2824895	et	3	main
ei	doc_696163377509_item	2824896	et	4	main
eluviisile	doc_696163377509_item	2824907	et	3	main
ühendus	doc_696163377509_item	2824920	et	4	main
eesti	doc_696163377508_item	2824787	et	4	main
muistendid	doc_696163377508_item	2824789	et	3	main
ta	doc_696163377508_item	2824792	et	4	main
korraldas	doc_696163377508_item	2824793	et	3	main
kalevipoja	doc_696163377508_item	2824796	et	4	main
ära	doc_696163377508_item	2824806	et	4	main
kontrolltöö	doc_696163377509_item	2824808	et	4	main
kontrolltöö	doc_696163377509_item	2824809	et	4	main
keele	doc_696163377509_item	2824836	et	4	main
ja	doc_696163377509_item	2824837	et	3	main
erinevus	doc_696163377509_item	2824851	et	4	main
eluviis	doc_696163377509_item	2824855	et	3	main
paikne	doc_696163377509_item	2824857	et	4	main
osanud	doc_696163377509_item	2824881	et	4	main
pärast	doc_696163377509_item	2824890	et	4	main
hakati	doc_696163377509_item	2824891	et	3	main
emakeele	doc_696163377509_item	2824898	et	4	main
kirjandust	doc_696163377509_item	2824899	et	3	main
talupoegadele	doc_696163377509_item	2824900	et	3	main
oli	doc_696163377509_item	2824901	et	3	main
vaja	doc_696163377509_item	2824902	et	4	main
jaoks	doc_696163377509_item	2824912	et	4	main
kultuurne	doc_696163377509_item	2824913	et	3	main
2	doc_696163377509_item	2824915	et	2	main
hansa	doc_696163377509_item	2824916	et	4	main
liit	doc_696163377509_item	2824917	et	3	main
oli	doc_696163377509_item	2824918	et	3	main
ristiusustamine	doc_696163377509_item	2824923	et	3	main
algas	doc_696163377509_item	2824924	et	3	main
said	doc_696163377509_item	2824930	et	4	main
väljapääsu	doc_696163377509_item	2824931	et	4	main
ja	doc_696163377509_item	2824933	et	3	main
alasid	doc_696163377509_item	2824938	et	4	main
linnad	doc_696163377509_item	2824941	et	3	main
hansakaupmeeste	doc_696163377509_item	2824943	et	4	main
hansa	doc_696163377509_item	2824945	et	4	main
eesti	doc_696163377509_item	2824953	et	4	main
vene	doc_697936465046_item	2824965	et	4	main
essee	doc_6982649480_item	2824970	et	4	main
soovitatav	doc_6982649480_item	2825005	et	4	main
illustreerida	doc_6982649480_item	2825006	et	3	main
näidetega	doc_6982649480_item	2825007	et	3	main
teevad	doc_6982649480_item	2825016	et	3	main
parim	doc_6982649480_item	2825018	et	4	main
pizzad	doc_6982649480_item	2825019	et	4	main
laulumine	doc_6982649480_item	2825030	et	4	main
traditsioon	doc_6982649480_item	2825031	et	3	main
on	doc_6982649480_item	2825032	et	4	main
väga	doc_6982649480_item	2825033	et	3	main
oli	doc_6982649480_item	2825037	et	3	main
ema	doc_6982649480_item	2825040	et	4	main
lapsele	doc_6982649480_item	2825042	et	4	main
laulu	doc_6982649480_item	2825043	et	4	main
ka	doc_6982649480_item	2825044	et	3	main
lauldi	doc_6982649480_item	2825045	et	3	main
et	doc_6982649480_item	2825046	et	3	main
hääled	doc_6982649480_item	2825052	et	3	main
näita	doc_6982649480_item	2825065	et	4	main
varem	doc_6982649480_item	2825078	et	4	main
kuidas	doc_6982649480_item	2825079	et	3	main
lauldi	doc_6982649480_item	2825080	et	3	main
ja	doc_6982649480_item	2825087	et	3	main
ajast	doc_6982649480_item	2825094	et	4	main
on	doc_6982649480_item	2825126	et	4	main
eesti	doc_6982649480_item	2825127	et	4	main
mis	doc_6982649480_item	2825138	et	4	main
toimuti	doc_6982649480_item	2825139	et	3	main
festivaalis	doc_6982649480_item	2825149	et	4	main
riigid	doc_6982649480_item	2825153	et	3	main
sellest	doc_6982649480_item	2825158	et	4	main
et	doc_6982649480_item	2825166	et	3	main
laulad	doc_6982649480_item	2825176	et	3	main
väga	doc_6982649480_item	2825179	et	3	main
naad	doc_6982649480_item	2825182	et	4	main
seda	doc_6982649480_item	2825183	et	3	main
traditsioon	doc_6982649480_item	2825184	et	3	main
talupoeg	doc_701263568939_item	2825221	et	3	main
kord	doc_701263568939_item	2825229	et	4	main
oli	doc_701263568939_item	2825232	et	3	main
talupojad	doc_701263568939_item	2825245	et	4	main
isegi	doc_701263568939_item	2825258	et	4	main
tappa	doc_701263568939_item	2825259	et	4	main
oma	doc_701263568939_item	2825260	et	4	main
oli	doc_696163377509_item	2824821	et	3	main
1	doc_696163377509_item	2824824	et	2	main
pikaks	doc_696163377509_item	2824832	et	4	main
selleks	doc_696163377509_item	2824840	et	4	main
linnade	doc_696163377509_item	2824845	et	3	main
suur	doc_696163377509_item	2824850	et	3	main
talurahva	doc_696163377509_item	2824854	et	3	main
ei	doc_696163377509_item	2824861	et	4	main
mida	doc_696163377509_item	2824863	et	4	main
toimus	doc_696163377509_item	2824864	et	3	main
linnades	doc_696163377509_item	2824865	et	3	main
see	doc_696163377509_item	2824866	et	3	main
traditsioonilisus	doc_696163377509_item	2824867	et	4	main
tulenes	doc_696163377509_item	2824868	et	3	main
veel	doc_696163377509_item	2824869	et	4	main
põllumajandusliku	doc_696163377509_item	2824870	et	3	main
tegevuse	doc_696163377509_item	2824871	et	4	main
iseloomust	doc_696163377509_item	2824872	et	4	main
samuti	doc_696163377509_item	2824873	et	3	main
mõned	doc_696163377509_item	2824874	et	3	main
piiskopid	doc_696163377509_item	2824875	et	3	main
mis	doc_696163377509_item	2824876	et	4	main
tulid	doc_696163377509_item	2824877	et	4	main
ei	doc_696163377509_item	2824880	et	4	main
saanud	doc_696163377509_item	2824885	et	4	main
aega	doc_696163377509_item	2824903	et	4	main
et	doc_696163377509_item	2824904	et	3	main
harjuda	doc_696163377509_item	2824905	et	3	main
sest	doc_696163377509_item	2824908	et	4	main
see	doc_696163377509_item	2824909	et	3	main
poleks	doc_696163377509_item	2824910	et	3	main
nende	doc_696163377509_item	2824911	et	4	main
rahvaste	doc_696163377509_item	2824922	et	4	main
osaliselt	doc_696163377509_item	2824925	et	4	main
nende	doc_696163377509_item	2824934	et	4	main
tee	doc_696163377509_item	2824935	et	4	main
liidu	doc_696163377509_item	2824957	et	3	main
tartu	doc_696163377509_item	2824959	et	4	main
eesti	doc_697936465046_item	2824967	et	4	main
keeles	doc_697936465046_item	2824968	et	4	main
body	doc_697936465046_item	2824969	et	4	main
essee	doc_6982649480_item	2824990	et	4	main
ja	doc_6982649480_item	2824995	et	3	main
italiased	doc_6982649480_item	2825015	et	4	main
kultuuri	doc_6982649480_item	2825024	et	4	main
traditsioonid	doc_6982649480_item	2825025	et	3	main
eestlased	doc_6982649480_item	2825026	et	3	main
nimetavad	doc_6982649480_item	2825027	et	4	main
iseendas	doc_6982649480_item	2825028	et	3	main
vana	doc_6982649480_item	2825035	et	4	main
noored	doc_6982649480_item	2825049	et	3	main
naised	doc_6982649480_item	2825056	et	3	main
mina	doc_6982649480_item	2825068	et	4	main
lauldi	doc_6982649480_item	2825082	et	3	main
selles	doc_6982649480_item	2825088	et	4	main
võime	doc_6982649480_item	2825090	et	4	main
teada	doc_6982649480_item	2825091	et	3	main
kõik	doc_6982649480_item	2825092	et	4	main
vene	doc_6982649480_item	2825122	et	4	main
muusika	doc_6982649480_item	2825128	et	4	main
naaber	doc_6982649480_item	2825129	et	3	main
mis	doc_6982649480_item	2825130	et	4	main
näitab	doc_6982649480_item	2825131	et	3	main
tänapäeval	doc_6982649480_item	2825132	et	3	main
et	doc_6982649480_item	2825133	et	3	main
eestlased	doc_6982649480_item	2825134	et	3	main
on	doc_6982649480_item	2825135	et	4	main
laulurahva	doc_6982649480_item	2825136	et	3	main
varem	doc_6982649480_item	2825142	et	4	main
mis	doc_6982649480_item	2825154	et	4	main
ja	doc_6982649480_item	2825157	et	3	main
võime	doc_6982649480_item	2825160	et	4	main
see	doc_6982649480_item	2825173	et	3	main
tähistavad	doc_6982649480_item	2825177	et	4	main
palju	doc_6982649480_item	2825180	et	4	main
ja	doc_6982649480_item	2825181	et	3	main
oli	doc_701263568939_item	2825222	et	3	main
euroopas	doc_701263568939_item	2825225	et	3	main
mõned	doc_701263568939_item	2825244	et	3	main
poolvabad	doc_701263568939_item	2825247	et	3	main
õigus	doc_701263568939_item	2825255	et	4	main
ta	doc_701263568939_item	2825256	et	4	main
et	doc_701263568939_item	2825270	et	3	main
see	doc_701263568939_item	2825271	et	3	main
päästis	doc_701263568939_item	2825272	et	3	main
andnud	doc_701263568939_item	2825285	et	4	main
võimaluse	doc_701263568939_item	2825286	et	3	main
õppida	doc_701263568939_item	2825287	et	3	main
ning	doc_701263568939_item	2825288	et	3	main
sellepärast	doc_701263568939_item	2825289	et	3	main
et	doc_701263568939_item	2825295	et	3	main
saab	doc_701263568939_item	2825298	et	3	main
aleksander	doc_701263568939_item	2825302	et	4	main
esimene	doc_701263568939_item	2825303	et	3	main
ei	doc_701263568939_item	2825304	et	4	main
tegeles	doc_701263568939_item	2825332	et	3	main
muid	doc_701263568939_item	2825346	et	4	main
tegutsesid	doc_701263568939_item	2825351	et	4	main
hurt	doc_701263568939_item	2825354	et	3	main
f	doc_701263568939_item	2825355	et	4	main
seltsi	doc_701263568939_item	2825360	et	4	main
liider	doc_701263568939_item	2825361	et	3	main
hakkas	doc_701263568939_item	2825363	et	3	main
tema	doc_701263568939_item	2825374	et	4	main
jannsen	doc_701263568939_item	2825388	et	4	main
andis	doc_701263568939_item	2825389	et	3	main
tänu	doc_696163377509_item	2824926	et	4	main
hansakaupmeestele	doc_696163377509_item	2824927	et	4	main
läänemerele	doc_696163377509_item	2824932	et	3	main
samuti	doc_696163377509_item	2824939	et	3	main
tekkisid	doc_696163377509_item	2824942	et	4	main
tootmist	doc_696163377509_item	2824950	et	4	main
keskajal	doc_696163377509_item	2824951	et	3	main
kaksteist	doc_696163377509_item	2824952	et	4	main
kuulusid	doc_696163377509_item	2824955	et	4	main
tallinn	doc_696163377509_item	2824958	et	4	main
narva	doc_696163377509_item	2824960	et	4	main
ja	doc_696163377509_item	2824961	et	3	main
teised	doc_696163377509_item	2824962	et	4	main
uus	doc_697936465046_item	2824963	et	3	main
dokument	doc_697936465046_item	2824964	et	3	main
eesti	doc_6982649480_item	2824971	et	4	main
keele	doc_6982649480_item	2824972	et	4	main
kui	doc_6982649480_item	2824973	et	3	main
teise	doc_6982649480_item	2824974	et	4	main
keele	doc_6982649480_item	2824975	et	4	main
test	doc_6982649480_item	2824976	et	3	main
kirjutamine	doc_6982649480_item	2824977	et	4	main
kirjutage	doc_6982649480_item	2824978	et	3	main
teemal	doc_6982649480_item	2824980	et	3	main
essee	doc_6982649480_item	2824979	et	4	main
mis	doc_6982649480_item	2824981	et	4	main
teeb	doc_6982649480_item	2824982	et	3	main
eestlastest	doc_6982649480_item	2824983	et	4	main
laulurahva	doc_6982649480_item	2824984	et	3	main
essee	doc_6982649480_item	2824985	et	4	main
300	doc_6982649480_item	2824987	et	2	main
350	doc_6982649480_item	2824988	et	2	main
pikkus	doc_6982649480_item	2824986	et	4	main
sõna	doc_6982649480_item	2824989	et	4	main
nad	doc_696163377509_item	2824929	et	3	main
paganate	doc_696163377509_item	2824937	et	3	main
konkurentsi	doc_696163377509_item	2824948	et	4	main
korraldas	doc_696163377509_item	2824949	et	3	main
hansa	doc_696163377509_item	2824956	et	4	main
peab	doc_6982649480_item	2824991	et	4	main
üldistav	doc_6982649480_item	2824996	et	4	main
loengus	doc_6982649480_item	2824998	et	3	main
lugemistekstis	doc_6982649480_item	2825000	et	3	main
faktidele	doc_6982649480_item	2825002	et	3	main
on	doc_6982649480_item	2825010	et	4	main
oma	doc_6982649480_item	2825011	et	4	main
traditsioonid	doc_6982649480_item	2825012	et	3	main
kultuur	doc_6982649480_item	2825013	et	3	main
laulurahvas	doc_6982649480_item	2825029	et	4	main
laulad	doc_6982649480_item	2825036	et	3	main
võid	doc_6982649480_item	2825064	et	4	main
et	doc_6982649480_item	2825070	et	3	main
kõik	doc_6982649480_item	2825083	et	4	main
see	doc_6982649480_item	2825084	et	3	main
vanest	doc_6982649480_item	2825093	et	4	main
olema	doc_6982649480_item	2824992	et	4	main
arutlev	doc_6982649480_item	2824993	et	4	main
tuginema	doc_6982649480_item	2824997	et	3	main
ja	doc_6982649480_item	2824999	et	3	main
esitatud	doc_6982649480_item	2825001	et	4	main
kõikidel	doc_6982649480_item	2825008	et	4	main
rahvadel	doc_6982649480_item	2825009	et	4	main
venelastel	doc_6982649480_item	2825020	et	4	main
ka	doc_6982649480_item	2825022	et	3	main
aeglased	doc_6982649480_item	2825038	et	3	main
laulas	doc_6982649480_item	2825041	et	4	main
tehti	doc_6982649480_item	2825050	et	3	main
aga	doc_6982649480_item	2825053	et	3	main
laulavad	doc_6982649480_item	2825055	et	4	main
kui	doc_6982649480_item	2825057	et	3	main
oma	doc_6982649480_item	2825066	et	4	main
kultuur	doc_6982649480_item	2825067	et	3	main
vanest	doc_6982649480_item	2825071	et	4	main
me	doc_6982649480_item	2825073	et	4	main
võime	doc_6982649480_item	2825074	et	4	main
teada	doc_6982649480_item	2825075	et	3	main
kuidas	doc_6982649480_item	2825076	et	3	main
elati	doc_6982649480_item	2825077	et	3	main
ajaloo	doc_6982649480_item	2825086	et	4	main
veel	doc_6982649480_item	2825096	et	4	main
laulavad	doc_6982649480_item	2825097	et	4	main
eestlased	doc_6982649480_item	2825098	et	3	main
pulmadest	doc_6982649480_item	2825099	et	3	main
lauldi	doc_6982649480_item	2825100	et	3	main
kõik	doc_6982649480_item	2825101	et	4	main
mida	doc_6982649480_item	2825102	et	4	main
tehti	doc_6982649480_item	2825103	et	3	main
näiteks	doc_6982649480_item	2825104	et	4	main
tervitati	doc_6982649480_item	2825105	et	3	main
pulmarongi	doc_6982649480_item	2825106	et	4	main
ka	doc_6982649480_item	2825107	et	3	main
lauldi	doc_6982649480_item	2825108	et	3	main
kui	doc_6982649480_item	2825109	et	3	main
on	doc_6982649480_item	2825111	et	4	main
keegi	doc_6982649480_item	2825110	et	4	main
surnud	doc_6982649480_item	2825112	et	4	main
kui	doc_6982649480_item	2825113	et	3	main
eesti	doc_6982649480_item	2825114	et	4	main
sai	doc_6982649480_item	2825115	et	4	main
iseseisvuse	doc_6982649480_item	2825116	et	4	main
tuli	doc_6982649480_item	2825117	et	4	main
uue	doc_6982649480_item	2825118	et	3	main
muusika	doc_6982649480_item	2825119	et	4	main
stiilid	doc_6982649480_item	2825120	et	4	main
näiteks	doc_6982649480_item	2825121	et	4	main
ja	doc_6982649480_item	2825123	et	3	main
läti	doc_6982649480_item	2825124	et	4	main
palju	doc_6982649480_item	2825140	et	4	main
palju	doc_6982649480_item	2825151	et	4	main
laulavad	doc_6982649480_item	2825155	et	4	main
tantsivad	doc_6982649480_item	2825156	et	4	main
mõtlen	doc_6982649480_item	2825165	et	3	main
on	doc_6982649480_item	2825168	et	4	main
väga	doc_6982649480_item	2825169	et	3	main
tähtis	doc_6982649480_item	2825170	et	4	main
faktor	doc_6982649480_item	2825171	et	3	main
näitab	doc_6982649480_item	2825174	et	3	main
eestlastele	doc_6982649480_item	2825178	et	4	main
täielik	doc_701263568939_item	2825223	et	3	main
juba	doc_701263568939_item	2825227	et	3	main
olid	doc_701263568939_item	2825246	et	4	main
kuid	doc_701263568939_item	2825248	et	4	main
jäid	doc_701263568939_item	2825250	et	4	main
mõisnikul	doc_701263568939_item	2825252	et	3	main
oli	doc_701263568939_item	2825253	et	3	main
muusika	doc_6982649480_item	2825125	et	4	main
aega	doc_6982649480_item	2825141	et	4	main
tähelepanuväärsem	doc_6982649480_item	2825148	et	4	main
mina	doc_6982649480_item	2825164	et	4	main
see	doc_6982649480_item	2825167	et	3	main
ei	doc_6982649480_item	2825185	et	4	main
suri	doc_6982649480_item	2825186	et	3	main
kontrolltöö	doc_701263568939_item	2825187	et	4	main
1	doc_701263568939_item	2825188	et	2	main
mida	doc_701263568939_item	2825189	et	4	main
tähendab	doc_701263568939_item	2825190	et	3	main
balti	doc_701263568939_item	2825191	et	3	main
erikord	doc_701263568939_item	2825192	et	3	main
2	doc_701263568939_item	2825193	et	2	main
millega	doc_701263568939_item	2825194	et	3	main
tegeles	doc_701263568939_item	2825195	et	3	main
eesti	doc_701263568939_item	2825197	et	4	main
selts	doc_701263568939_item	2825198	et	3	main
ja	doc_701263568939_item	2825199	et	3	main
kes	doc_701263568939_item	2825200	et	4	main
sinna	doc_701263568939_item	2825201	et	3	main
õpetatud	doc_701263568939_item	2825196	et	4	main
kuulusid	doc_701263568939_item	2825202	et	4	main
1	doc_701263568939_item	2825203	et	2	main
balti	doc_701263568939_item	2825204	et	3	main
erikord	doc_701263568939_item	2825205	et	3	main
tähendab	doc_701263568939_item	2825206	et	3	main
peeter	doc_701263568939_item	2825207	et	3	main
i	doc_701263568939_item	2825208	et	4	main
ja	doc_701263568939_item	2825209	et	3	main
rootsi	doc_701263568939_item	2825210	et	4	main
aadlike	doc_701263568939_item	2825211	et	4	main
võimu	doc_701263568939_item	2825212	et	4	main
maal	doc_701263568939_item	2825213	et	4	main
elas	doc_701263568939_item	2825214	et	3	main
90	doc_701263568939_item	2825215	et	2	main
talurahvast	doc_701263568939_item	2825216	et	4	main
ja	doc_701263568939_item	2825217	et	3	main
10	doc_701263568939_item	2825218	et	2	main
maa	doc_701263568939_item	2825219	et	4	main
aadlikke	doc_701263568939_item	2825220	et	3	main
aga	doc_701263568939_item	2825235	et	3	main
eestis	doc_701263568939_item	2825236	et	3	main
see	doc_701263568939_item	2825237	et	3	main
tugevnes	doc_701263568939_item	2825238	et	3	main
talupoeg	doc_701263568939_item	2825239	et	3	main
oli	doc_701263568939_item	2825240	et	3	main
pärisori	doc_701263568939_item	2825224	et	4	main
valitses	doc_701263568939_item	2825226	et	3	main
kapitalistlik	doc_701263568939_item	2825228	et	3	main
ja	doc_701263568939_item	2825230	et	3	main
pärisorjus	doc_701263568939_item	2825231	et	3	main
ammu	doc_701263568939_item	2825233	et	4	main
kadunud	doc_701263568939_item	2825234	et	4	main
omandiks	doc_701263568939_item	2825243	et	3	main
pärisorja	doc_701263568939_item	2825261	et	4	main
balti	doc_701263568939_item	2825262	et	3	main
erikorra	doc_701263568939_item	2825263	et	3	main
ajal	doc_701263568939_item	2825264	et	4	main
haridus	doc_701263568939_item	2825265	et	3	main
oli	doc_701263568939_item	2825266	et	3	main
saksakeelne	doc_701263568939_item	2825267	et	3	main
võib	doc_701263568939_item	2825268	et	3	main
sakslastest	doc_701263568939_item	2825276	et	3	main
et	doc_701263568939_item	2825280	et	3	main
saksastuks	doc_701263568939_item	2825282	et	3	main
nad	doc_701263568939_item	2825283	et	3	main
ei	doc_701263568939_item	2825284	et	4	main
kartsid	doc_701263568939_item	2825294	et	4	main
olnud	doc_701263568939_item	2825305	et	4	main
rahul	doc_701263568939_item	2825306	et	4	main
balti	doc_701263568939_item	2825307	et	3	main
erikorraga	doc_701263568939_item	2825308	et	3	main
ning	doc_701263568939_item	2825309	et	3	main
hakkas	doc_701263568939_item	2825310	et	3	main
venestuspoliitikat	doc_701263568939_item	2825311	et	3	main
viima	doc_701263568939_item	2825313	et	3	main
ellu	doc_701263568939_item	2825312	et	4	main
2	doc_701263568939_item	2825314	et	2	main
õpetatud	doc_701263568939_item	2825315	et	4	main
eesti	doc_701263568939_item	2825316	et	4	main
selts	doc_701263568939_item	2825317	et	3	main
oli	doc_701263568939_item	2825318	et	3	main
loodud	doc_701263568939_item	2825319	et	4	main
tartus	doc_701263568939_item	2825320	et	3	main
1839	doc_701263568939_item	2825321	et	2	main
tegelaseks	doc_701263568939_item	2825324	et	3	main
r	doc_701263568939_item	2825327	et	4	main
eesti	doc_701263568939_item	2825330	et	4	main
selts	doc_701263568939_item	2825331	et	3	main
keele	doc_701263568939_item	2825334	et	4	main
ilmalikku	doc_701263568939_item	2825347	et	4	main
kirjandust	doc_701263568939_item	2825348	et	3	main
ka	doc_701263568939_item	2825352	et	3	main
jannsen	doc_701263568939_item	2825359	et	4	main
kogutud	doc_701263568939_item	2825372	et	4	main
materjale	doc_701263568939_item	2825373	et	3	main
teatud	doc_701263568939_item	2825381	et	4	main
keeleteadlane	doc_701263568939_item	2825382	et	3	main
ning	doc_701263568939_item	2825383	et	3	main
sai	doc_701263568939_item	2825384	et	4	main
mõisniku	doc_701263568939_item	2825241	et	3	main
täielikuks	doc_701263568939_item	2825242	et	3	main
siiski	doc_701263568939_item	2825249	et	4	main
pärisorjadeks	doc_701263568939_item	2825251	et	3	main
kodukari	doc_701263568939_item	2825254	et	4	main
sest	doc_701263568939_item	2825275	et	4	main
talurahvas	doc_701263568939_item	2825290	et	4	main
jäi	doc_701263568939_item	2825291	et	3	main
eestikeelseks	doc_701263568939_item	2825292	et	4	main
protest	doc_701263568939_item	2825297	et	3	main
aastal	doc_701263568939_item	2825322	et	3	main
oli	doc_701263568939_item	2825325	et	3	main
eesti	doc_701263568939_item	2825333	et	4	main
uurimisega	doc_701263568939_item	2825335	et	4	main
korraldas	doc_701263568939_item	2825336	et	3	main
eestikeelseid	doc_701263568939_item	2825337	et	3	main
trükimisi	doc_701263568939_item	2825338	et	4	main
see	doc_701263568939_item	2825339	et	3	main
andis	doc_701263568939_item	2825340	et	3	main
seltsi	doc_701263568939_item	2825349	et	4	main
koostama	doc_701263568939_item	2825364	et	3	main
kasutades	doc_701263568939_item	2825368	et	3	main
teiste	doc_701263568939_item	2825369	et	4	main
liikmete	doc_701263568939_item	2825370	et	3	main
jätkas	doc_701263568939_item	2825376	et	3	main
kreutzwald	doc_701263568939_item	2825377	et	4	main
aleksandrikooli	doc_701263568939_item	2825385	et	4	main
ja	doc_701263568939_item	2825421	et	3	main
kontrolltöö	doc_701263568940_item	2825423	et	4	main
kirik	doc_701263568940_item	2825425	et	3	main
19501960	doc_701263568940_item	2825428	et	2	main
kirikutes	doc_701263568940_item	2825429	et	4	main
oli	doc_701263568940_item	2825430	et	3	main
suur	doc_701263568940_item	2825431	et	3	main
ülikoolis	doc_701263568940_item	2825434	et	4	main
pühavaimu	doc_701263568940_item	2825447	et	4	main
kiriku	doc_701263568940_item	2825448	et	3	main
kui	doc_701263568940_item	2825454	et	3	main
sõrmused	doc_701263568940_item	2825469	et	3	main
siis	doc_701263568940_item	2825470	et	3	main
ateismi	doc_701263568940_item	2825473	et	4	main
poliitika	doc_701263568940_item	2825474	et	4	main
ja	doc_701263568940_item	2825475	et	3	main
hakkasid	doc_701263568940_item	2825476	et	4	main
toimuma	doc_701263568940_item	2825477	et	3	main
kodanikke	doc_701263568940_item	2825478	et	3	main
kombed	doc_701263568940_item	2825479	et	3	main
jumalasse	doc_701263568940_item	2825499	et	4	main
sõnad	doc_705833728516_item	2825505	et	4	main
naine	doc_705833728516_item	2825512	et	3	main
piret	doc_705833728516_item	2825529	et	4	main
ja	doc_705833728516_item	2825533	et	3	main
emakeelt	doc_705833728516_item	2825544	et	4	main
õpetama	doc_705833728516_item	2825545	et	3	main
üllatunud	doc_705833728516_item	2825560	et	4	main
kui	doc_705833728516_item	2825561	et	3	main
mulle	doc_705833728516_item	2825562	et	4	main
korraliku	doc_705833728516_item	2825567	et	3	main
ja	doc_705833728516_item	2825586	et	3	main
õppeaasta	doc_705833728516_item	2825592	et	4	main
kartuleid	doc_705833728516_item	2825606	et	3	main
kõige	doc_705833728516_item	2825611	et	4	main
tähtsam	doc_705833728516_item	2825613	et	4	main
ettevõtmine	doc_705833728516_item	2825614	et	3	main
käib	doc_705833728516_item	2825621	et	3	main
siinsed	doc_705833728516_item	2825625	et	3	main
kuidagi	doc_705833728516_item	2825628	et	3	main
mahlakas	doc_705833728516_item	2825632	et	4	main
kool	doc_705833728516_item	2825645	et	4	main
siiski	doc_705833728516_item	2825647	et	4	main
kool	doc_705833728516_item	2825649	et	4	main
ja	doc_705833728516_item	2825650	et	3	main
elab	doc_705833728516_item	2825658	et	3	main
veidi	doc_705833728516_item	2825659	et	3	main
üle	doc_705833728516_item	2825660	et	3	main
saab	doc_705833728516_item	2825666	et	3	main
poolpõlenud	doc_705833728516_item	2825674	et	4	main
siberi	doc_705833728516_item	2825684	et	4	main
talve	doc_705833728516_item	2825685	et	4	main
muud	doc_705833728516_item	2825722	et	4	main
naerab	doc_705833728516_item	2825725	et	3	main
võis	doc_701263568939_item	2825257	et	4	main
öelda	doc_701263568939_item	2825269	et	4	main
ei	doc_701263568939_item	2825278	et	4	main
talurahva	doc_701263568939_item	2825296	et	3	main
suulise	doc_701263568939_item	2825299	et	4	main
keiser	doc_701263568939_item	2825301	et	3	main
f	doc_701263568939_item	2825326	et	4	main
välja	doc_701263568939_item	2825341	et	4	main
lõunaeesti	doc_701263568939_item	2825342	et	3	main
ajal	doc_701263568939_item	2825350	et	4	main
jakob	doc_701263568939_item	2825353	et	4	main
poolt	doc_701263568939_item	2825371	et	4	main
jakob	doc_701263568939_item	2825378	et	4	main
hurt	doc_701263568939_item	2825379	et	3	main
oli	doc_701263568939_item	2825380	et	3	main
liideriks	doc_701263568939_item	2825387	et	4	main
oli	doc_701263568939_item	2825394	et	3	main
arendamises	doc_701263568939_item	2825422	et	4	main
tartu	doc_701263568940_item	2825433	et	4	main
oli	doc_701263568940_item	2825441	et	3	main
usuteaduse	doc_701263568940_item	2825443	et	3	main
instituut	doc_701263568940_item	2825444	et	3	main
mis	doc_701263568940_item	2825445	et	4	main
võimul	doc_701263568940_item	2825455	et	3	main
stalin	doc_701263568940_item	2825457	et	4	main
kommed	doc_701263568940_item	2825464	et	4	main
isegi	doc_701263568940_item	2825465	et	4	main
olid	doc_701263568940_item	2825466	et	4	main
näiteks	doc_701263568940_item	2825480	et	4	main
kirikutes	doc_701263568940_item	2825486	et	4	main
lakkasid	doc_701263568940_item	2825495	et	4	main
uskuma	doc_701263568940_item	2825496	et	3	main
ja	doc_701263568940_item	2825498	et	3	main
i	doc_705833728516_item	2825501	et	4	main
vormi	doc_705833728516_item	2825507	et	4	main
piret	doc_705833728516_item	2825508	et	4	main
keele	doc_705833728516_item	2825527	et	4	main
õpetajat	doc_705833728516_item	2825528	et	4	main
väikestele	doc_705833728516_item	2825540	et	4	main
eestlastele	doc_705833728516_item	2825541	et	4	main
need	doc_705833728516_item	2825542	et	3	main
kinnitusel	doc_705833728516_item	2825548	et	4	main
et	doc_705833728516_item	2825554	et	3	main
tulema	doc_705833728516_item	2825563	et	4	main
noor	doc_705833728516_item	2825585	et	3	main
tahtmist	doc_705833728516_item	2825588	et	4	main
kohale	doc_705833728516_item	2825595	et	4	main
jõudis	doc_705833728516_item	2825596	et	3	main
küla	doc_705833728516_item	2825603	et	4	main
võtma	doc_705833728516_item	2825604	et	3	main
võttis	doc_705833728516_item	2825605	et	3	main
täie	doc_705833728516_item	2825622	et	3	main
hooga	doc_705833728516_item	2825624	et	3	main
räägivad	doc_705833728516_item	2825627	et	3	main
teistmoodi	doc_705833728516_item	2825629	et	3	main
mitte	doc_705833728516_item	2825636	et	3	main
vene	doc_705833728516_item	2825637	et	4	main
aktsent	doc_705833728516_item	2825638	et	3	main
aktsendiga	doc_705833728516_item	2825639	et	3	main
vaid	doc_705833728516_item	2825640	et	3	main
nagu	doc_705833728516_item	2825641	et	3	main
mõni	doc_705833728516_item	2825642	et	3	main
mõnd	doc_705833728516_item	2825643	et	3	main
aine	doc_705833728516_item	2825652	et	4	main
ained	doc_705833728516_item	2825653	et	3	main
õpetatakse	doc_705833728516_item	2825654	et	3	main
uued	doc_705833728516_item	2825682	et	3	main
kartma	doc_705833728516_item	2825688	et	3	main
juba	doc_705833728516_item	2825691	et	3	main
toodi	doc_705833728516_item	2825693	et	4	main
talvepuud	doc_705833728516_item	2825694	et	4	main
praegu	doc_705833728516_item	2825695	et	3	main
ei	doc_705833728516_item	2825723	et	4	main
talveks	doc_705833728516_item	2825726	et	4	main
valmistuma	doc_705833728516_item	2825727	et	3	main
valmistuv	doc_705833728516_item	2825728	et	4	main
slõhtuleht	doc_705833728516_item	2825733	et	4	main
sõnadest	doc_705833728516_item	2825737	et	3	main
laused	doc_705833728516_item	2825738	et	3	main
vormi	doc_705833728516_item	2825742	et	4	main
ja	doc_705833728516_item	2825743	et	3	main
eesti	doc_701263568939_item	2825273	et	4	main
keele	doc_701263568939_item	2825274	et	4	main
mõisnikud	doc_701263568939_item	2825277	et	3	main
tahtnud	doc_701263568939_item	2825279	et	4	main
talurahvas	doc_701263568939_item	2825281	et	4	main
mõisnikud	doc_701263568939_item	2825293	et	3	main
vormi	doc_701263568939_item	2825300	et	4	main
tähtsamaks	doc_701263568939_item	2825323	et	4	main
faehlmann	doc_701263568939_item	2825328	et	4	main
õpetatud	doc_701263568939_item	2825329	et	4	main
keeles	doc_701263568939_item	2825343	et	4	main
aabitsaid	doc_701263568939_item	2825344	et	3	main
ja	doc_701263568939_item	2825345	et	3	main
r	doc_701263568939_item	2825356	et	4	main
kreutzwald	doc_701263568939_item	2825357	et	4	main
ja	doc_701263568939_item	2825358	et	3	main
faehlmann	doc_701263568939_item	2825362	et	4	main
eesti	doc_701263568939_item	2825365	et	4	main
rahvuseepose	doc_701263568939_item	2825366	et	3	main
kalevipoeg	doc_701263568939_item	2825367	et	3	main
tööd	doc_701263568939_item	2825375	et	4	main
liikumise	doc_701263568939_item	2825386	et	4	main
ajalehte	doc_701263568939_item	2825391	et	4	main
postimees	doc_701263568939_item	2825392	et	4	main
ja	doc_701263568939_item	2825393	et	3	main
tuntud	doc_701263568939_item	2825395	et	4	main
nagu	doc_701263568939_item	2825396	et	3	main
postipapa	doc_701263568939_item	2825397	et	4	main
ta	doc_701263568939_item	2825398	et	4	main
päästis	doc_701263568939_item	2825399	et	3	main
köleri	doc_701263568939_item	2825400	et	4	main
kaaslasi	doc_701263568939_item	2825401	et	3	main
vanglasse	doc_701263568939_item	2825402	et	4	main
sattumisest	doc_701263568939_item	2825403	et	4	main
palvekirju	doc_701263568939_item	2825404	et	4	main
saatmise	doc_701263568939_item	2825405	et	4	main
eest	doc_701263568939_item	2825406	et	4	main
tema	doc_701263568939_item	2825407	et	4	main
algatusel	doc_701263568939_item	2825408	et	4	main
tartus	doc_701263568939_item	2825410	et	3	main
i	doc_701263568939_item	2825411	et	4	main
üldlaulupidu	doc_701263568939_item	2825412	et	4	main
toimus	doc_701263568939_item	2825409	et	3	main
õpetatud	doc_701263568939_item	2825413	et	4	main
seltsi	doc_701263568939_item	2825414	et	4	main
mängis	doc_701263568939_item	2825415	et	3	main
suurt	doc_701263568939_item	2825416	et	3	main
rolli	doc_701263568939_item	2825417	et	4	main
eesti	doc_701263568939_item	2825418	et	4	main
keele	doc_701263568939_item	2825419	et	4	main
uurimises	doc_701263568939_item	2825420	et	4	main
5	doc_701263568940_item	2825424	et	2	main
nõuk	doc_701263568940_item	2825426	et	4	main
eestis	doc_701263568940_item	2825427	et	3	main
suletud	doc_701263568940_item	2825436	et	4	main
tallinnas	doc_701263568940_item	2825440	et	4	main
alla	doc_701263568940_item	2825449	et	3	main
seal	doc_701263568940_item	2825450	et	4	main
oli	doc_701263568940_item	2825451	et	3	main
ainult	doc_701263568940_item	2825452	et	4	main
peod	doc_701263568940_item	2825463	et	4	main
abielu	doc_701263568940_item	2825468	et	4	main
välja	doc_701263568939_item	2825390	et	4	main
oli	doc_701263568940_item	2825435	et	3	main
teaduskond	doc_701263568940_item	2825438	et	3	main
oli	doc_701263568940_item	2825456	et	3	main
siis	doc_701263568940_item	2825458	et	3	main
kirikutes	doc_701263568940_item	2825459	et	4	main
suur	doc_701263568940_item	2825472	et	3	main
varem	doc_701263568940_item	2825483	et	4	main
abielu	doc_701263568940_item	2825484	et	4	main
sõlmiti	doc_701263568940_item	2825485	et	3	main
abielu	doc_701263568940_item	2825489	et	4	main
büroos	doc_701263568940_item	2825491	et	3	main
sulgudes	doc_705833728516_item	2825503	et	4	main
toomet	doc_705833728516_item	2825509	et	4	main
õpetanud	doc_705833728516_item	2825546	et	4	main
ta	doc_705833728516_item	2825550	et	4	main
jõudma	doc_705833728516_item	2825552	et	3	main
on	doc_705833728516_item	2825555	et	4	main
oodatud	doc_705833728516_item	2825556	et	4	main
olin	doc_705833728516_item	2825557	et	3	main
üsna	doc_705833728516_item	2825558	et	3	main
üllatuma	doc_705833728516_item	2825559	et	3	main
vastu	doc_705833728516_item	2825565	et	3	main
täis	doc_705833728516_item	2825589	et	4	main
piret	doc_705833728516_item	2825590	et	4	main
kool	doc_705833728516_item	2825598	et	4	main
veel	doc_705833728516_item	2825599	et	4	main
algama	doc_705833728516_item	2825600	et	3	main
alanud	doc_705833728516_item	2825601	et	4	main
tähtis	doc_705833728516_item	2825612	et	4	main
salv	doc_705833728516_item	2825618	et	3	main
hoog	doc_705833728516_item	2825623	et	3	main
keeles	doc_705833728516_item	2825656	et	4	main
külas	doc_705833728516_item	2825657	et	3	main
õpikud	doc_705833728516_item	2825683	et	3	main
piret	doc_705833728516_item	2825686	et	4	main
mulle	doc_705833728516_item	2825690	et	4	main
renditasu	doc_701263568940_item	2825432	et	4	main
usuteaduse	doc_701263568940_item	2825437	et	3	main
aga	doc_701263568940_item	2825439	et	3	main
avatud	doc_701263568940_item	2825442	et	4	main
kuulus	doc_701263568940_item	2825446	et	4	main
kaugõppe	doc_701263568940_item	2825453	et	4	main
olid	doc_701263568940_item	2825460	et	4	main
keelatud	doc_701263568940_item	2825461	et	4	main
igasugused	doc_701263568940_item	2825462	et	3	main
keelatud	doc_701263568940_item	2825467	et	4	main
aga	doc_701263568940_item	2825488	et	3	main
sõlmimise	doc_701263568940_item	2825490	et	4	main
kuuekümnendatel	doc_701263568940_item	2825492	et	3	main
aastatel	doc_701263568940_item	2825493	et	4	main
kirikusse	doc_701263568940_item	2825497	et	4	main
eksamitöö	doc_705833728516_item	2825500	et	4	main
pange	doc_705833728516_item	2825502	et	4	main
õigesse	doc_705833728516_item	2825506	et	3	main
suvel	doc_705833728516_item	2825513	et	3	main
nägema	doc_705833728516_item	2825514	et	3	main
nägi	doc_705833728516_item	2825515	et	3	main
ta	doc_705833728516_item	2825516	et	4	main
ajalehes	doc_705833728516_item	2825517	et	3	main
kuulutus	doc_705833728516_item	2825518	et	4	main
kuulutuse	doc_705833728516_item	2825519	et	4	main
et	doc_705833728516_item	2825520	et	3	main
tuli	doc_701263568940_item	2825471	et	4	main
abielu	doc_701263568940_item	2825481	et	4	main
kui	doc_701263568940_item	2825482	et	3	main
praegu	doc_701263568940_item	2825487	et	3	main
noored	doc_701263568940_item	2825494	et	3	main
olevad	doc_705833728516_item	2825504	et	4	main
on	doc_705833728516_item	2825510	et	4	main
ettevõtlik	doc_705833728516_item	2825511	et	3	main
siberisse	doc_705833728516_item	2825521	et	4	main
küla	doc_705833728516_item	2825523	et	4	main
külasse	doc_705833728516_item	2825524	et	3	main
otsitakse	doc_705833728516_item	2825525	et	3	main
konkurss	doc_705833728516_item	2825531	et	3	main
nende	doc_705833728516_item	2825543	et	4	main
pireti	doc_705833728516_item	2825547	et	4	main
siberisse	doc_705833728516_item	2825551	et	4	main
jõudes	doc_705833728516_item	2825553	et	3	main
tuldi	doc_705833728516_item	2825564	et	3	main
tahtmine	doc_705833728516_item	2825587	et	4	main
polnud	doc_705833728516_item	2825597	et	3	main
kartulivõtt	doc_705833728516_item	2825607	et	3	main
siin	doc_705833728516_item	2825609	et	4	main
tänaseks	doc_705833728516_item	2825615	et	4	main
on	doc_705833728516_item	2825616	et	4	main
kartul	doc_705833728516_item	2825617	et	3	main
õppimine	doc_705833728516_item	2825620	et	4	main
eestlased	doc_705833728516_item	2825626	et	3	main
ja	doc_705833728516_item	2825631	et	3	main
murret	doc_705833728516_item	2825644	et	4	main
venemaa	doc_705833728516_item	2825648	et	4	main
ülejäänud	doc_705833728516_item	2825651	et	4	main
kolmsada	doc_705833728516_item	2825661	et	4	main
kolmesaja	doc_705833728516_item	2825662	et	4	main
inimene	doc_705833728516_item	2825663	et	3	main
inimest	doc_705833728516_item	2825664	et	3	main
kõik	doc_705833728516_item	2825667	et	4	main
pireti	doc_705833728516_item	2825670	et	4	main
sõnul	doc_705833728516_item	2825671	et	3	main
õpivad	doc_705833728516_item	2825672	et	3	main
raamatud	doc_705833728516_item	2825675	et	4	main
järgi	doc_705833728516_item	2825677	et	4	main
varsti	doc_705833728516_item	2825678	et	3	main
saatma	doc_705833728516_item	2825679	et	3	main
eestist	doc_705833728516_item	2825681	et	3	main
karda	doc_705833728516_item	2825689	et	4	main
tooma	doc_705833728516_item	2825692	et	3	main
piret	doc_705833728516_item	2825729	et	4	main
ii	doc_705833728516_item	2825734	et	4	main
sõnad	doc_705833728516_item	2825740	et	4	main
naiselikum	doc_705833728516_item	2825750	et	4	main
ja	doc_705833728516_item	2825751	et	3	main
pinge	doc_705833728516_item	2825796	et	4	main
lasta	doc_705833728516_item	2825804	et	4	main
ülekoormusel	doc_705833728516_item	2825805	et	3	main
tekkida	doc_705833728516_item	2825806	et	3	main
aga	doc_705833728516_item	2825807	et	3	main
aparaat	doc_705833728516_item	2825823	et	3	main
hingama	doc_705833728516_item	2825830	et	3	main
telefon	doc_705833728516_item	2825831	et	3	main
on	doc_705833728516_item	2825832	et	4	main
tänapäeval	doc_705833728516_item	2825833	et	3	main
lausa	doc_705833728516_item	2825841	et	4	main
elatakse	doc_705833728516_item	2825842	et	3	main
ja	doc_705833728516_item	2825843	et	3	main
uni	doc_705833728516_item	2825852	et	3	main
vaatamine	doc_705833728516_item	2825861	et	4	main
ka	doc_705833728516_item	2825866	et	3	main
varahommikul	doc_705833728516_item	2825868	et	3	main
huvitava	doc_705833728516_item	2825876	et	4	main
telesaate	doc_705833728516_item	2825877	et	3	main
vaatamise	doc_705833728516_item	2825878	et	4	main
ajal	doc_705833728516_item	2825879	et	4	main
iv	doc_705833728516_item	2825880	et	4	main
3	doc_705833728516_item	2825910	et	2	main
et	doc_705833728516_item	2825913	et	3	main
tunned	doc_705833728516_item	2825920	et	3	main
huvi	doc_705833728516_item	2825921	et	4	main
ilusad	doc_705833728516_item	2825923	et	3	main
ja	doc_705833728516_item	2825925	et	3	main
autod	doc_705833728516_item	2825927	et	3	main
4	doc_705833728516_item	2825934	et	2	main
ülem-suetuki	doc_705833728516_item	2825522	et	4	main
eesti	doc_705833728516_item	2825526	et	4	main
võitis	doc_705833728516_item	2825530	et	3	main
konkursi	doc_705833728516_item	2825532	et	3	main
on	doc_705833728516_item	2825534	et	4	main
nüüd	doc_705833728516_item	2825535	et	4	main
juba	doc_705833728516_item	2825536	et	3	main
üle	doc_705833728516_item	2825537	et	3	main
nädal	doc_705833728516_item	2825538	et	3	main
nädala	doc_705833728516_item	2825539	et	3	main
tundis	doc_705833728516_item	2825549	et	3	main
korralik	doc_705833728516_item	2825566	et	3	main
audiga	doc_705833728516_item	2825568	et	3	main
mulle	doc_705833728516_item	2825569	et	4	main
maaliti	doc_705833728516_item	2825570	et	3	main
siber	doc_705833728516_item	2825571	et	4	main
siberist	doc_705833728516_item	2825572	et	4	main
selline	doc_705833728516_item	2825573	et	4	main
pilt	doc_705833728516_item	2825574	et	3	main
et	doc_705833728516_item	2825575	et	3	main
seal	doc_705833728516_item	2825576	et	4	main
ei	doc_705833728516_item	2825577	et	4	main
lendama	doc_705833728516_item	2825578	et	3	main
lenda	doc_705833728516_item	2825579	et	4	main
lind	doc_705833728516_item	2825580	et	3	main
ega	doc_705833728516_item	2825581	et	3	main
kasva	doc_705833728516_item	2825582	et	4	main
rohi	doc_705833728516_item	2825583	et	4	main
kui	doc_705833728516_item	2825584	et	3	main
pärast	doc_705833728516_item	2825591	et	4	main
algust	doc_705833728516_item	2825593	et	4	main
koht	doc_705833728516_item	2825594	et	3	main
kogu	doc_705833728516_item	2825602	et	4	main
on	doc_705833728516_item	2825608	et	4	main
sügisel	doc_705833728516_item	2825610	et	3	main
ja	doc_705833728516_item	2825619	et	3	main
mõnus	doc_705833728516_item	2825630	et	4	main
mõnusalt	doc_705833728516_item	2825633	et	4	main
ja	doc_705833728516_item	2825634	et	3	main
mahlakalt	doc_705833728516_item	2825635	et	4	main
on	doc_705833728516_item	2825646	et	4	main
vene	doc_705833728516_item	2825655	et	4	main
emakeelt	doc_705833728516_item	2825665	et	4	main
kõigidega	doc_705833728516_item	2825668	et	4	main
rääkida	doc_705833728516_item	2825669	et	3	main
lapsed	doc_705833728516_item	2825673	et	3	main
raamatute	doc_705833728516_item	2825676	et	3	main
saadetakse	doc_705833728516_item	2825680	et	3	main
ei	doc_705833728516_item	2825687	et	4	main
on	doc_705833728516_item	2825696	et	4	main
päevad	doc_705833728516_item	2825697	et	3	main
veel	doc_705833728516_item	2825698	et	4	main
soe	doc_705833728516_item	2825699	et	4	main
soojad	doc_705833728516_item	2825700	et	3	main
kuid	doc_705833728516_item	2825701	et	4	main
ööd	doc_705833728516_item	2825702	et	4	main
juba	doc_705833728516_item	2825703	et	3	main
jahe	doc_705833728516_item	2825704	et	3	main
jahedad	doc_705833728516_item	2825705	et	3	main
harjutan	doc_705833728516_item	2825706	et	3	main
juba	doc_705833728516_item	2825707	et	3	main
suure	doc_705833728516_item	2825708	et	3	main
vene	doc_705833728516_item	2825709	et	4	main
kütmine	doc_705833728516_item	2825711	et	4	main
ahju	doc_705833728516_item	2825710	et	4	main
kütmist	doc_705833728516_item	2825712	et	4	main
kui	doc_705833728516_item	2825713	et	3	main
vaja	doc_705833728516_item	2825714	et	4	main
ostan	doc_705833728516_item	2825715	et	3	main
külapood	doc_705833728516_item	2825716	et	3	main
külapoest	doc_705833728516_item	2825717	et	4	main
vildid	doc_705833728516_item	2825718	et	4	main
ega	doc_705833728516_item	2825719	et	3	main
seal	doc_705833728516_item	2825720	et	4	main
suurt	doc_705833728516_item	2825721	et	3	main
müüdagi	doc_705833728516_item	2825724	et	3	main
lühendatud	doc_705833728516_item	2825731	et	4	main
naeratus	doc_705833728516_item	2825747	et	4	main
naised	doc_705833728516_item	2825749	et	3	main
mehelikum	doc_705833728516_item	2825753	et	4	main
naeratus	doc_705833728516_item	2825756	et	4	main
teeb	doc_705833728516_item	2825757	et	3	main
naisi	doc_705833728516_item	2825758	et	3	main
naiselikumaks	doc_705833728516_item	2825759	et	4	main
ja	doc_705833728516_item	2825760	et	3	main
mehi	doc_705833728516_item	2825761	et	3	main
saama	doc_705833728516_item	2825797	et	4	main
maandada	doc_705833728516_item	2825810	et	3	main
sportides	doc_705833728516_item	2825812	et	4	main
saama	doc_705833728516_item	2825820	et	4	main
nii	doc_705833728516_item	2825821	et	3	main
maagiliseks	doc_705833728516_item	2825836	et	4	main
aparaadiks	doc_705833728516_item	2825837	et	3	main
vapralt	doc_705833728516_item	2825730	et	4	main
moodustage	doc_705833728516_item	2825735	et	3	main
tegema	doc_705833728516_item	2825748	et	3	main
3	doc_705833728516_item	2825765	et	2	main
paras	doc_705833728516_item	2825766	et	3	main
kogus	doc_705833728516_item	2825767	et	4	main
stress	doc_705833728516_item	2825768	et	3	main
panema	doc_705833728516_item	2825769	et	3	main
meie	doc_705833728516_item	2825770	et	4	main
tegutsema	doc_705833728516_item	2825771	et	3	main
aga	doc_705833728516_item	2825772	et	3	main
lisakoormus	doc_705833728516_item	2825773	et	3	main
võima	doc_705833728516_item	2825774	et	3	main
tooma	doc_705833728516_item	2825775	et	3	main
soovimatu	doc_705833728516_item	2825776	et	4	main
tagajärg	doc_705833728516_item	2825777	et	3	main
paras	doc_705833728516_item	2825778	et	3	main
kogus	doc_705833728516_item	2825779	et	4	main
stressi	doc_705833728516_item	2825780	et	4	main
paneb	doc_705833728516_item	2825781	et	3	main
meid	doc_705833728516_item	2825782	et	4	main
tegutsema	doc_705833728516_item	2825783	et	3	main
aga	doc_705833728516_item	2825784	et	3	main
lisakoormus	doc_705833728516_item	2825785	et	3	main
võib	doc_705833728516_item	2825786	et	3	main
ajalehest	doc_705833728516_item	2825732	et	4	main
etteantud	doc_705833728516_item	2825736	et	4	main
pannes	doc_705833728516_item	2825739	et	4	main
õigesse	doc_705833728516_item	2825741	et	3	main
mehed	doc_705833728516_item	2825752	et	3	main
kaunim	doc_705833728516_item	2825755	et	4	main
mehelikumaks	doc_705833728516_item	2825762	et	4	main
igaüht	doc_705833728516_item	2825763	et	3	main
soovimatuid	doc_705833728516_item	2825788	et	4	main
maandama	doc_705833728516_item	2825798	et	3	main
sportima	doc_705833728516_item	2825799	et	4	main
puhkama	doc_705833728516_item	2825801	et	3	main
pinge	doc_705833728516_item	2825808	et	4	main
saab	doc_705833728516_item	2825809	et	3	main
sportimisega	doc_705833728516_item	2825811	et	4	main
ja	doc_705833728516_item	2825813	et	3	main
puhkamisega	doc_705833728516_item	2825814	et	4	main
telefon	doc_705833728516_item	2825817	et	3	main
tänapäev	doc_705833728516_item	2825819	et	3	main
kasutades	doc_705833728516_item	2825744	et	3	main
kirjavahemärke	doc_705833728516_item	2825745	et	4	main
2	doc_705833728516_item	2825746	et	2	main
igaüks	doc_705833728516_item	2825754	et	3	main
kaunimaks	doc_705833728516_item	2825764	et	4	main
tagajärgi	doc_705833728516_item	2825789	et	4	main
tekkima	doc_705833728516_item	2825795	et	3	main
ja	doc_705833728516_item	2825800	et	3	main
ei	doc_705833728516_item	2825802	et	4	main
tohi	doc_705833728516_item	2825803	et	4	main
puhates	doc_705833728516_item	2825815	et	3	main
see	doc_705833728516_item	2825825	et	3	main
selle	doc_705833728516_item	2825839	et	4	main
telefonihelin	doc_705833728516_item	2825847	et	3	main
katkestama	doc_705833728516_item	2825848	et	3	main
segama	doc_705833728516_item	2825853	et	3	main
telefonihelin	doc_705833728516_item	2825864	et	3	main
lõunasööki	doc_705833728516_item	2825871	et	4	main
ja	doc_705833728516_item	2825873	et	3	main
ma	doc_705833728516_item	2825911	et	3	main
sport	doc_705833728516_item	2825916	et	3	main
aga	doc_705833728516_item	2825918	et	3	main
5	doc_705833728516_item	2825941	et	2	main
tüdinesin	doc_705833728516_item	2825942	et	3	main
uus	doc_705833728516_item	2825943	et	3	main
töökoht	doc_705833728516_item	2825944	et	3	main
uuest	doc_705833728516_item	2825945	et	3	main
kiiresti	doc_705833728516_item	2825947	et	3	main
vaid	doc_705833728516_item	2825952	et	3	main
muudatused	doc_705833728516_item	2825954	et	3	main
7	doc_705833728516_item	2825957	et	2	main
see	doc_705833728516_item	2825958	et	3	main
küsimus	doc_705833728516_item	2825959	et	4	main
kuulub	doc_705833728516_item	2825960	et	3	main
teine	doc_705833728516_item	2825961	et	3	main
valdkond	doc_705833728516_item	2825962	et	3	main
teisse	doc_705833728516_item	2825963	et	4	main
külge	doc_705833728516_item	2825970	et	4	main
külmal	doc_705833728516_item	2825973	et	3	main
rõõmu	doc_705833728516_item	2825982	et	4	main
v	doc_705833728516_item	2825987	et	4	main
täitke	doc_705833728516_item	2825988	et	3	main
lüngad	doc_705833728516_item	2825989	et	3	main
sidenditega	doc_705833728516_item	2825991	et	3	main
tellisime	doc_705833728516_item	2825993	et	4	main
kolmekäigulise	doc_705833728516_item	2825994	et	4	main
keegi	doc_705833728516_item	2826024	et	4	main
5	doc_705833728516_item	2826028	et	2	main
töö	doc_705833728516_item	2826039	et	4	main
alles	doc_705833728516_item	2826042	et	3	main
selles	doc_705833728516_item	2826047	et	4	main
linna	doc_705833728516_item	2826071	et	4	main
10	doc_705833728516_item	2826072	et	2	main
avasin	doc_705833728516_item	2826073	et	3	main
ukse	doc_705833728516_item	2826074	et	3	main
pange	doc_705833728517_item	2826080	et	4	main
kui	doc_705833728517_item	2826138	et	3	main
mulle	doc_705833728517_item	2826145	et	4	main
siber	doc_705833728517_item	2826147	et	4	main
kasva	doc_705833728517_item	2826158	et	4	main
kui	doc_705833728517_item	2826160	et	3	main
noor	doc_705833728517_item	2826161	et	3	main
ja	doc_705833728517_item	2826162	et	3	main
pärast	doc_705833728517_item	2826167	et	4	main
kool	doc_705833728517_item	2826174	et	4	main
siin	doc_705833728517_item	2826184	et	4	main
kõige	doc_705833728517_item	2826186	et	4	main
tähtsam	doc_705833728517_item	2826188	et	4	main
tänaseks	doc_705833728517_item	2826190	et	4	main
eestlased	doc_705833728517_item	2826200	et	3	main
kuidagi	doc_705833728517_item	2826202	et	3	main
ülejäänud	doc_705833728517_item	2826222	et	4	main
saavad	doc_705833728517_item	2826245	et	4	main
eestist	doc_705833728517_item	2826246	et	3	main
suure	doc_705833728517_item	2826273	et	3	main
vene	doc_705833728517_item	2826274	et	4	main
külapood	doc_705833728517_item	2826281	et	3	main
ega	doc_705833728517_item	2826284	et	3	main
mehelikum	doc_705833728517_item	2826327	et	4	main
meie	doc_705833728517_item	2826335	et	4	main
tegutsema	doc_705833728517_item	2826336	et	3	main
tuua	doc_705833728516_item	2825787	et	3	main
4	doc_705833728516_item	2825790	et	2	main
ei	doc_705833728516_item	2825791	et	4	main
tohtima	doc_705833728516_item	2825792	et	3	main
laskma	doc_705833728516_item	2825793	et	3	main
ülekoormus	doc_705833728516_item	2825794	et	3	main
5	doc_705833728516_item	2825816	et	2	main
olema	doc_705833728516_item	2825818	et	4	main
maagiline	doc_705833728516_item	2825822	et	4	main
lausa	doc_705833728516_item	2825827	et	4	main
abil	doc_705833728516_item	2825840	et	4	main
kuid	doc_705833728516_item	2825846	et	4	main
pühapäev	doc_705833728516_item	2825850	et	3	main
valmistamine	doc_705833728516_item	2825855	et	4	main
söömine	doc_705833728516_item	2825857	et	4	main
pahandab	doc_705833728516_item	2825858	et	3	main
kuid	doc_705833728516_item	2825863	et	4	main
sulgudes	doc_705833728516_item	2825882	et	4	main
nõudeid	doc_705833728516_item	2825909	et	3	main
sa	doc_705833728516_item	2825914	et	3	main
sa	doc_705833728516_item	2825919	et	3	main
külmetamisest	doc_705833728516_item	2825978	et	4	main
10	doc_705833728516_item	2825979	et	2	main
ma	doc_705833728516_item	2825980	et	3	main
tunnen	doc_705833728516_item	2825981	et	3	main
lõuna	doc_705833728516_item	2825995	et	4	main
aga	doc_705833728516_item	2825996	et	3	main
vaid	doc_705833728516_item	2825997	et	3	main
kuigi	doc_705833728516_item	2825998	et	3	main
see	doc_705833728516_item	2825999	et	3	main
naeru	doc_705833728516_item	2826021	et	4	main
tule	doc_705833728516_item	2826031	et	4	main
trenni	doc_705833728516_item	2826032	et	4	main
vaid	doc_705833728516_item	2826033	et	3	main
läheb	doc_705833728516_item	2826034	et	3	main
hoopis	doc_705833728516_item	2826035	et	3	main
teatrisse	doc_705833728516_item	2826036	et	3	main
lõpetage	doc_705833728516_item	2826038	et	3	main
ja	doc_705833728516_item	2826041	et	3	main
lähete	doc_705833728516_item	2826044	et	4	main
baaris	doc_705833728516_item	2826048	et	3	main
tulemust	doc_705833728516_item	2826061	et	4	main
sõnad	doc_705833728517_item	2826083	et	4	main
emakeelt	doc_705833728517_item	2826121	et	4	main
pireti	doc_705833728517_item	2826124	et	4	main
tulema	doc_705833728517_item	2826140	et	4	main
audiga	doc_705833728517_item	2826144	et	3	main
lendama	doc_705833728517_item	2826154	et	3	main
lind	doc_705833728517_item	2826156	et	3	main
õppeaasta	doc_705833728517_item	2826168	et	4	main
kartulivõtt	doc_705833728517_item	2826182	et	3	main
salv	doc_705833728517_item	2826193	et	3	main
täie	doc_705833728517_item	2826197	et	3	main
siinsed	doc_705833728517_item	2826199	et	3	main
mõnus	doc_705833728517_item	2826204	et	4	main
ja	doc_705833728517_item	2826221	et	3	main
vene	doc_705833728517_item	2826225	et	4	main
keeles	doc_705833728517_item	2826226	et	4	main
külas	doc_705833728517_item	2826227	et	3	main
elab	doc_705833728517_item	2826228	et	3	main
veidi	doc_705833728517_item	2826229	et	3	main
üle	doc_705833728517_item	2826230	et	3	main
õpivad	doc_705833728517_item	2826239	et	3	main
saatma	doc_705833728517_item	2826244	et	3	main
uued	doc_705833728517_item	2826247	et	3	main
siberi	doc_705833728517_item	2826249	et	4	main
talve	doc_705833728517_item	2826250	et	4	main
praegu	doc_705833728517_item	2826260	et	3	main
ööd	doc_705833728517_item	2826267	et	4	main
juba	doc_705833728517_item	2826268	et	3	main
jahe	doc_705833728517_item	2826269	et	3	main
jad	doc_705833728517_item	2826270	et	4	main
harjutan	doc_705833728517_item	2826271	et	3	main
juba	doc_705833728517_item	2826272	et	3	main
vaja	doc_705833728517_item	2826279	et	4	main
ostan	doc_705833728517_item	2826280	et	3	main
vildid	doc_705833728517_item	2826283	et	4	main
et	doc_705833728516_item	2825824	et	3	main
abil	doc_705833728516_item	2825826	et	4	main
elama	doc_705833728516_item	2825828	et	3	main
ja	doc_705833728516_item	2825829	et	3	main
saanud	doc_705833728516_item	2825834	et	4	main
nii	doc_705833728516_item	2825835	et	3	main
hingatakse	doc_705833728516_item	2825844	et	3	main
ka	doc_705833728516_item	2825849	et	3	main
lõunasöök	doc_705833728516_item	2825854	et	3	main
ja	doc_705833728516_item	2825856	et	3	main
huvitav	doc_705833728516_item	2825859	et	4	main
telesaade	doc_705833728516_item	2825860	et	4	main
katkestab	doc_705833728516_item	2825865	et	3	main
segab	doc_705833728516_item	2825870	et	3	main
valmistamist	doc_705833728516_item	2825872	et	4	main
söömist	doc_705833728516_item	2825874	et	4	main
pahandab	doc_705833728516_item	2825875	et	3	main
pange	doc_705833728516_item	2825881	et	4	main
olevad	doc_705833728516_item	2825883	et	4	main
sõnad	doc_705833728516_item	2825884	et	4	main
õigesse	doc_705833728516_item	2825885	et	3	main
vormi	doc_705833728516_item	2825886	et	4	main
1	doc_705833728516_item	2825887	et	2	main
ma	doc_705833728516_item	2825888	et	3	main
pean	doc_705833728516_item	2825889	et	4	main
lugu	doc_705833728516_item	2825891	et	4	main
väga	doc_705833728516_item	2825890	et	3	main
oma	doc_705833728516_item	2825892	et	4	main
vanemad	doc_705833728516_item	2825893	et	4	main
oma	doc_705833728516_item	2825894	et	4	main
vanematest	doc_705833728516_item	2825895	et	4	main
sest	doc_705833728516_item	2825896	et	4	main
nad	doc_705833728516_item	2825897	et	3	main
aitavad	doc_705833728516_item	2825898	et	4	main
kõik	doc_705833728516_item	2825899	et	4	main
kõiki	doc_705833728516_item	2825900	et	4	main
ja	doc_705833728516_item	2825901	et	3	main
usaldavad	doc_705833728516_item	2825902	et	4	main
igaüks	doc_705833728516_item	2825903	et	3	main
igaüht	doc_705833728516_item	2825904	et	3	main
2	doc_705833728516_item	2825905	et	2	main
kohandasin	doc_705833728516_item	2825906	et	3	main
artikli	doc_705833728516_item	2825907	et	3	main
nõuded	doc_705833728516_item	2825908	et	3	main
et	doc_705833728516_item	2825838	et	3	main
6	doc_705833728516_item	2825845	et	2	main
varahommik	doc_705833728516_item	2825851	et	3	main
aeg	doc_705833728516_item	2825862	et	3	main
pühapäeval	doc_705833728516_item	2825867	et	3	main
und	doc_705833728516_item	2825869	et	4	main
arvasin	doc_705833728516_item	2825912	et	3	main
naised	doc_705833728516_item	2825924	et	3	main
töökohast	doc_705833728516_item	2825946	et	4	main
6	doc_705833728516_item	2825948	et	2	main
piirdusime	doc_705833728516_item	2825949	et	3	main
valdkonda	doc_705833728516_item	2825964	et	4	main
püksid	doc_705833728516_item	2825968	et	3	main
ajal	doc_705833728516_item	2825974	et	4	main
suvine	doc_705833728516_item	2825983	et	4	main
päike	doc_705833728516_item	2825984	et	3	main
suvisest	doc_705833728516_item	2825985	et	4	main
sobivate	doc_705833728516_item	2825990	et	4	main
1	doc_705833728516_item	2825992	et	2	main
nagu	doc_705833728516_item	2826022	et	3	main
rääkinud	doc_705833728516_item	2826027	et	4	main
ta	doc_705833728516_item	2826029	et	4	main
ei	doc_705833728516_item	2826030	et	4	main
siis	doc_705833728516_item	2826040	et	3	main
siis	doc_705833728516_item	2826043	et	3	main
tohi	doc_705833728516_item	2826050	et	4	main
töötasid	doc_705833728516_item	2826057	et	4	main
ei	doc_705833728516_item	2826062	et	4	main
maale	doc_705833728516_item	2826068	et	4	main
õigesse	doc_705833728517_item	2826084	et	3	main
piret	doc_705833728517_item	2826086	et	4	main
toomet	doc_705833728517_item	2826087	et	4	main
siberisse	doc_705833728517_item	2826128	et	4	main
üllatanud	doc_705833728517_item	2826137	et	4	main
tuleb	doc_705833728517_item	2826141	et	3	main
korralik	doc_705833728517_item	2826143	et	3	main
ei	doc_705833728517_item	2826153	et	4	main
lenda	doc_705833728517_item	2826155	et	4	main
piret	doc_705833728517_item	2826166	et	4	main
võttis	doc_705833728517_item	2826180	et	3	main
sügisel	doc_705833728517_item	2826185	et	3	main
tähtis	doc_705833728517_item	2826187	et	4	main
ettevõtmine	doc_705833728517_item	2826189	et	3	main
ja	doc_705833728517_item	2826205	et	3	main
aine	doc_705833728517_item	2826223	et	4	main
õpetatakse	doc_705833728517_item	2826224	et	3	main
kõik	doc_705833728517_item	2826235	et	4	main
rääkida	doc_705833728517_item	2826236	et	3	main
pireti	doc_705833728517_item	2826237	et	4	main
sõnul	doc_705833728517_item	2826238	et	3	main
piret	doc_705833728517_item	2826251	et	4	main
toonud	doc_705833728517_item	2826258	et	4	main
on	doc_705833728517_item	2826261	et	4	main
veel	doc_705833728517_item	2826263	et	4	main
sojad	doc_705833728517_item	2826265	et	3	main
ei	doc_705833728517_item	2826288	et	4	main
naeratus	doc_705833728517_item	2826321	et	4	main
naised	doc_705833728517_item	2826323	et	3	main
aga	doc_705833728517_item	2826325	et	3	main
3	doc_705833728517_item	2826330	et	2	main
paneb	doc_705833728517_item	2826346	et	3	main
tagajärg	doc_705833728517_item	2826354	et	3	main
ei	doc_705833728517_item	2826356	et	4	main
tohtima	doc_705833728517_item	2826357	et	3	main
laskma	doc_705833728517_item	2826358	et	3	main
ülekoormus	doc_705833728517_item	2826359	et	3	main
tekkima	doc_705833728517_item	2826360	et	3	main
saama	doc_705833728517_item	2826362	et	4	main
maandama	doc_705833728517_item	2826363	et	3	main
ei	doc_705833728517_item	2826367	et	4	main
laskma	doc_705833728517_item	2826369	et	3	main
saama	doc_705833728517_item	2826382	et	4	main
abil	doc_705833728517_item	2826388	et	4	main
tänapäeval	doc_705833728517_item	2826395	et	3	main
saama	doc_705833728517_item	2826396	et	4	main
nii	doc_705833728517_item	2826397	et	3	main
lausa	doc_705833728517_item	2826403	et	4	main
elab	doc_705833728517_item	2826404	et	3	main
huvitud	doc_705833728516_item	2825915	et	4	main
spordist	doc_705833728516_item	2825917	et	3	main
ainult	doc_705833728516_item	2825922	et	4	main
kiired	doc_705833728516_item	2825926	et	4	main
ilusate	doc_705833728516_item	2825928	et	3	main
naiste	doc_705833728516_item	2825929	et	3	main
ja	doc_705833728516_item	2825930	et	3	main
kiirte	doc_705833728516_item	2825931	et	3	main
autode	doc_705833728516_item	2825932	et	3	main
vastu	doc_705833728516_item	2825933	et	3	main
selles	doc_705833728516_item	2825950	et	4	main
väikeste	doc_705833728516_item	2825955	et	4	main
muudatustega	doc_705833728516_item	2825956	et	3	main
pükste	doc_705833728516_item	2825969	et	3	main
9	doc_705833728516_item	2825972	et	2	main
peab	doc_705833728516_item	2825975	et	4	main
hoiduma	doc_705833728516_item	2825976	et	3	main
külmetamine	doc_705833728516_item	2825977	et	4	main
päikest	doc_705833728516_item	2825986	et	4	main
maksis	doc_705833728516_item	2826000	et	4	main
palju	doc_705833728516_item	2826001	et	4	main
2	doc_705833728516_item	2826002	et	2	main
kohal	doc_705833728516_item	2826003	et	4	main
olid	doc_705833728516_item	2826004	et	4	main
nii	doc_705833728516_item	2826005	et	3	main
õpilased	doc_705833728516_item	2826006	et	3	main
kui	doc_705833728516_item	2826007	et	3	main
ka	doc_705833728516_item	2826008	et	3	main
õpetajad	doc_705833728516_item	2826009	et	4	main
3	doc_705833728516_item	2826010	et	2	main
lapsel	doc_705833728516_item	2826011	et	4	main
paluti	doc_705833728516_item	2826012	et	3	main
oodata	doc_705833728516_item	2826013	et	4	main
kui	doc_705833728516_item	2826014	et	3	main
vanemad	doc_705833728516_item	2826015	et	4	main
tagasi	doc_705833728516_item	2826016	et	3	main
tulevad	doc_705833728516_item	2826017	et	4	main
4	doc_705833728516_item	2826018	et	2	main
kõrvallauast	doc_705833728516_item	2826019	et	4	main
kostis	doc_705833728516_item	2826020	et	4	main
oleks	doc_705833728516_item	2826023	et	3	main
6	doc_705833728516_item	2826037	et	2	main
7	doc_705833728516_item	2826046	et	2	main
ei	doc_705833728516_item	2826049	et	4	main
suitsetada	doc_705833728516_item	2826051	et	3	main
ega	doc_705833728516_item	2826052	et	3	main
alkoholi	doc_705833728516_item	2826053	et	4	main
tarbida	doc_705833728516_item	2826054	et	3	main
8	doc_705833728516_item	2826055	et	2	main
nad	doc_705833728516_item	2826056	et	3	main
9	doc_705833728516_item	2826064	et	2	main
sa	doc_705833728516_item	2826066	et	3	main
sest	doc_705833728516_item	2826075	et	4	main
kuulsin	doc_705833728516_item	2826076	et	3	main
koputust	doc_705833728516_item	2826077	et	4	main
sulgudes	doc_705833728517_item	2826081	et	4	main
vormi	doc_705833728517_item	2826085	et	4	main
on	doc_705833728517_item	2826088	et	4	main
ettevõtlik	doc_705833728517_item	2826089	et	3	main
naine	doc_705833728517_item	2826090	et	3	main
praegu	doc_705833728516_item	2825935	et	3	main
on	doc_705833728516_item	2825936	et	4	main
oht	doc_705833728516_item	2825937	et	3	main
haigestuda	doc_705833728516_item	2825938	et	3	main
difteeria	doc_705833728516_item	2825939	et	4	main
difteeriasse	doc_705833728516_item	2825940	et	3	main
küsimuses	doc_705833728516_item	2825951	et	4	main
väikesed	doc_705833728516_item	2825953	et	4	main
8	doc_705833728516_item	2825965	et	2	main
närimiskumm	doc_705833728516_item	2825966	et	3	main
kleepus	doc_705833728516_item	2825967	et	3	main
pükstele	doc_705833728516_item	2825971	et	3	main
just	doc_705833728516_item	2826025	et	3	main
anekdooti	doc_705833728516_item	2826026	et	4	main
jalutama	doc_705833728516_item	2826045	et	3	main
küll	doc_705833728516_item	2826058	et	4	main
pingsalt	doc_705833728516_item	2826059	et	4	main
kuigi	doc_705833728516_item	2826060	et	3	main
olnud	doc_705833728516_item	2826063	et	4	main
kas	doc_705833728516_item	2826065	et	3	main
sõidad	doc_705833728516_item	2826067	et	3	main
või	doc_705833728516_item	2826069	et	4	main
jääd	doc_705833728516_item	2826070	et	4	main
eksamitöö	doc_705833728517_item	2826078	et	4	main
i	doc_705833728517_item	2826079	et	4	main
olevad	doc_705833728517_item	2826082	et	4	main
suvel	doc_705833728517_item	2826091	et	3	main
nägema	doc_705833728517_item	2826092	et	3	main
näin	doc_705833728517_item	2826093	et	3	main
ta	doc_705833728517_item	2826094	et	4	main
ajalehes	doc_705833728517_item	2826095	et	3	main
kuulutus	doc_705833728517_item	2826096	et	4	main
kuulutusis	doc_705833728517_item	2826097	et	4	main
et	doc_705833728517_item	2826098	et	3	main
siberisse	doc_705833728517_item	2826099	et	4	main
ülem-suetuki	doc_705833728517_item	2826100	et	4	main
küla	doc_705833728517_item	2826101	et	4	main
külasse	doc_705833728517_item	2826102	et	3	main
otsitakse	doc_705833728517_item	2826103	et	3	main
eesti	doc_705833728517_item	2826104	et	4	main
keele	doc_705833728517_item	2826105	et	4	main
õpetajat	doc_705833728517_item	2826106	et	4	main
piret	doc_705833728517_item	2826107	et	4	main
võitis	doc_705833728517_item	2826108	et	3	main
konkurss	doc_705833728517_item	2826109	et	3	main
konkursis	doc_705833728517_item	2826110	et	3	main
ja	doc_705833728517_item	2826111	et	3	main
on	doc_705833728517_item	2826112	et	4	main
nüüd	doc_705833728517_item	2826113	et	4	main
juba	doc_705833728517_item	2826114	et	3	main
üle	doc_705833728517_item	2826115	et	3	main
nädal	doc_705833728517_item	2826116	et	3	main
nädala	doc_705833728517_item	2826117	et	3	main
väikestele	doc_705833728517_item	2826118	et	4	main
eestlastele	doc_705833728517_item	2826119	et	4	main
need	doc_705833728517_item	2826120	et	3	main
õpetama	doc_705833728517_item	2826122	et	3	main
õpetab	doc_705833728517_item	2826123	et	3	main
jõudma	doc_705833728517_item	2826129	et	3	main
jõudnud	doc_705833728517_item	2826130	et	4	main
et	doc_705833728517_item	2826131	et	3	main
on	doc_705833728517_item	2826132	et	4	main
oodatud	doc_705833728517_item	2826133	et	4	main
kinnitusel	doc_705833728517_item	2826125	et	4	main
tundis	doc_705833728517_item	2826126	et	3	main
ta	doc_705833728517_item	2826127	et	4	main
üllatuma	doc_705833728517_item	2826136	et	3	main
maaliti	doc_705833728517_item	2826146	et	3	main
siberis	doc_705833728517_item	2826148	et	4	main
selline	doc_705833728517_item	2826149	et	4	main
pilt	doc_705833728517_item	2826150	et	3	main
et	doc_705833728517_item	2826151	et	3	main
ega	doc_705833728517_item	2826157	et	3	main
rohi	doc_705833728517_item	2826159	et	4	main
tahtmine	doc_705833728517_item	2826163	et	4	main
tahti	doc_705833728517_item	2826164	et	4	main
algust	doc_705833728517_item	2826169	et	4	main
koht	doc_705833728517_item	2826170	et	3	main
kohta	doc_705833728517_item	2826171	et	4	main
jõudis	doc_705833728517_item	2826172	et	3	main
polnud	doc_705833728517_item	2826173	et	3	main
küla	doc_705833728517_item	2826178	et	4	main
võtma	doc_705833728517_item	2826179	et	3	main
kartuleid	doc_705833728517_item	2826181	et	3	main
ja	doc_705833728517_item	2826194	et	3	main
käib	doc_705833728517_item	2826196	et	3	main
räägivad	doc_705833728517_item	2826201	et	3	main
teistmoodi	doc_705833728517_item	2826203	et	3	main
mahlakas	doc_705833728517_item	2826206	et	4	main
mitte	doc_705833728517_item	2826207	et	3	main
vene	doc_705833728517_item	2826208	et	4	main
aktsent	doc_705833728517_item	2826209	et	3	main
aktsenti	doc_705833728517_item	2826210	et	4	main
vaid	doc_705833728517_item	2826211	et	3	main
nagu	doc_705833728517_item	2826212	et	3	main
mõni	doc_705833728517_item	2826213	et	3	main
mõned	doc_705833728517_item	2826214	et	3	main
murret	doc_705833728517_item	2826215	et	4	main
kool	doc_705833728517_item	2826216	et	4	main
on	doc_705833728517_item	2826217	et	4	main
siiski	doc_705833728517_item	2826218	et	4	main
venemaa	doc_705833728517_item	2826219	et	4	main
kool	doc_705833728517_item	2826220	et	4	main
emakeelt	doc_705833728517_item	2826233	et	4	main
saab	doc_705833728517_item	2826234	et	3	main
poolpõlenud	doc_705833728517_item	2826241	et	4	main
raamatud	doc_705833728517_item	2826242	et	4	main
ei	doc_705833728517_item	2826252	et	4	main
kartma	doc_705833728517_item	2826253	et	3	main
karda	doc_705833728517_item	2826254	et	4	main
mulle	doc_705833728517_item	2826255	et	4	main
juba	doc_705833728517_item	2826256	et	3	main
tooma	doc_705833728517_item	2826257	et	3	main
soe	doc_705833728517_item	2826264	et	4	main
ahju	doc_705833728517_item	2826275	et	4	main
kütmine	doc_705833728517_item	2826276	et	4	main
külapoodis	doc_705833728517_item	2826282	et	4	main
seal	doc_705833728517_item	2826285	et	4	main
suurt	doc_705833728517_item	2826286	et	3	main
muud	doc_705833728517_item	2826287	et	4	main
tegeb	doc_705833728517_item	2826322	et	4	main
naiselikum	doc_705833728517_item	2826324	et	4	main
mehed	doc_705833728517_item	2826326	et	3	main
panema	doc_705833728517_item	2826334	et	3	main
lisakoormus	doc_705833728517_item	2826338	et	3	main
soovimatu	doc_705833728517_item	2826341	et	4	main
tagajärg	doc_705833728517_item	2826342	et	3	main
paras	doc_705833728517_item	2826343	et	3	main
tegutsema	doc_705833728517_item	2826348	et	3	main
puhkama	doc_705833728517_item	2826366	et	3	main
olin	doc_705833728517_item	2826134	et	3	main
üsna	doc_705833728517_item	2826135	et	3	main
mulle	doc_705833728517_item	2826139	et	4	main
vastu	doc_705833728517_item	2826142	et	3	main
seal	doc_705833728517_item	2826152	et	4	main
täis	doc_705833728517_item	2826165	et	4	main
veel	doc_705833728517_item	2826175	et	4	main
algama	doc_705833728517_item	2826176	et	3	main
kogu	doc_705833728517_item	2826177	et	4	main
on	doc_705833728517_item	2826183	et	4	main
on	doc_705833728517_item	2826191	et	4	main
kartul	doc_705833728517_item	2826192	et	3	main
õppimine	doc_705833728517_item	2826195	et	4	main
hoog	doc_705833728517_item	2826198	et	3	main
kolmsada	doc_705833728517_item	2826231	et	4	main
inimene	doc_705833728517_item	2826232	et	3	main
lapsed	doc_705833728517_item	2826240	et	3	main
varsti	doc_705833728517_item	2826243	et	3	main
õpikud	doc_705833728517_item	2826248	et	3	main
talvepuud	doc_705833728517_item	2826259	et	4	main
päevad	doc_705833728517_item	2826262	et	3	main
kuid	doc_705833728517_item	2826266	et	4	main
kütama	doc_705833728517_item	2826277	et	4	main
kui	doc_705833728517_item	2826278	et	3	main
müüdagi	doc_705833728517_item	2826289	et	3	main
naerab	doc_705833728517_item	2826290	et	3	main
talveks	doc_705833728517_item	2826291	et	4	main
valmistuma	doc_705833728517_item	2826292	et	3	main
valmistamiseks	doc_705833728517_item	2826293	et	4	main
piret	doc_705833728517_item	2826294	et	4	main
vapralt	doc_705833728517_item	2826295	et	4	main
lühendatud	doc_705833728517_item	2826296	et	4	main
ajalehest	doc_705833728517_item	2826297	et	4	main
slõhtuleht	doc_705833728517_item	2826298	et	4	main
moodustage	doc_705833728517_item	2826300	et	3	main
iii	doc_705833728517_item	2826299	et	4	main
etteantud	doc_705833728517_item	2826301	et	4	main
sõnadest	doc_705833728517_item	2826302	et	3	main
laused	doc_705833728517_item	2826303	et	3	main
pannes	doc_705833728517_item	2826304	et	4	main
sõnad	doc_705833728517_item	2826305	et	4	main
õigesse	doc_705833728517_item	2826306	et	3	main
vormi	doc_705833728517_item	2826307	et	4	main
ja	doc_705833728517_item	2826308	et	3	main
kasutades	doc_705833728517_item	2826309	et	3	main
kirjavahemärke	doc_705833728517_item	2826310	et	4	main
2	doc_705833728517_item	2826311	et	2	main
naeratus	doc_705833728517_item	2826312	et	4	main
tegema	doc_705833728517_item	2826313	et	3	main
naised	doc_705833728517_item	2826314	et	3	main
naiselikum	doc_705833728517_item	2826315	et	4	main
ja	doc_705833728517_item	2826316	et	3	main
mehed	doc_705833728517_item	2826317	et	3	main
mehelikum	doc_705833728517_item	2826318	et	4	main
igaüks	doc_705833728517_item	2826319	et	3	main
kaunim	doc_705833728517_item	2826320	et	4	main
kaunim	doc_705833728517_item	2826329	et	4	main
kogus	doc_705833728517_item	2826332	et	4	main
stress	doc_705833728517_item	2826333	et	3	main
võib	doc_705833728517_item	2826351	et	3	main
soovimatu	doc_705833728517_item	2826353	et	4	main
ja	doc_705833728517_item	2826365	et	3	main
igaüks	doc_705833728517_item	2826328	et	3	main
paras	doc_705833728517_item	2826331	et	3	main
meie	doc_705833728517_item	2826347	et	4	main
lisakoormus	doc_705833728517_item	2826350	et	3	main
tooma	doc_705833728517_item	2826352	et	3	main
4	doc_705833728517_item	2826355	et	2	main
pinge	doc_705833728517_item	2826361	et	4	main
olema	doc_705833728517_item	2826380	et	4	main
tänapäev	doc_705833728517_item	2826381	et	3	main
aparaat	doc_705833728517_item	2826385	et	3	main
et	doc_705833728517_item	2826386	et	3	main
kuid	doc_705833728517_item	2826408	et	4	main
telefonihelin	doc_705833728517_item	2826409	et	3	main
katkestama	doc_705833728517_item	2826410	et	3	main
ka	doc_705833728517_item	2826411	et	3	main
pühapäev	doc_705833728517_item	2826412	et	3	main
varahommik	doc_705833728517_item	2826413	et	3	main
uni	doc_705833728517_item	2826414	et	3	main
segama	doc_705833728517_item	2826415	et	3	main
lõunasöök	doc_705833728517_item	2826416	et	3	main
valmistamine	doc_705833728517_item	2826417	et	4	main
ja	doc_705833728517_item	2826418	et	3	main
söömine	doc_705833728517_item	2826419	et	4	main
pahandab	doc_705833728517_item	2826420	et	3	main
varahommikul	doc_705833728517_item	2826430	et	3	main
vaatamine	doc_705833728517_item	2826440	et	4	main
aeg	doc_705833728517_item	2826441	et	3	main
oma	doc_705833728517_item	2826454	et	4	main
vanemad	doc_705833728517_item	2826455	et	4	main
aitavad	doc_705833728517_item	2826460	et	4	main
artikli	doc_705833728517_item	2826469	et	3	main
arvasin	doc_705833728517_item	2826473	et	3	main
tunned	doc_705833728517_item	2826481	et	3	main
ilusad	doc_705833728517_item	2826489	et	3	main
ja	doc_705833728517_item	2826491	et	3	main
teine	doc_705833728517_item	2826521	et	3	main
hoiduma	doc_705833728517_item	2826534	et	3	main
külmetamine	doc_705833728517_item	2826535	et	4	main
v	doc_705833728517_item	2826545	et	4	main
täitke	doc_705833728517_item	2826546	et	3	main
lüngad	doc_705833728517_item	2826547	et	3	main
kohal	doc_705833728517_item	2826559	et	4	main
ja	doc_705833728517_item	2826563	et	3	main
õpetajad	doc_705833728517_item	2826565	et	4	main
lapsel	doc_705833728517_item	2826567	et	4	main
kostis	doc_705833728517_item	2826576	et	4	main
naeru	doc_705833728517_item	2826577	et	4	main
sest	doc_705833728517_item	2826613	et	4	main
sõidad	doc_705833728517_item	2826620	et	3	main
või	doc_705833728517_item	2826622	et	4	main
avasin	doc_705833728517_item	2826626	et	3	main
et	doc_705833728517_item	2826628	et	3	main
sulgudes	doc_705833728518_item	2826634	et	4	main
ettevõtlik	doc_705833728518_item	2826642	et	3	main
ta	doc_705833728518_item	2826647	et	4	main
kuulutus	doc_705833728518_item	2826649	et	4	main
on	doc_705833728518_item	2826664	et	4	main
juba	doc_705833728518_item	2826666	et	3	main
et	doc_705833728518_item	2826684	et	3	main
olin	doc_705833728518_item	2826687	et	3	main
üsna	doc_705833728518_item	2826688	et	3	main
üllatanud	doc_705833728518_item	2826690	et	4	main
mulle	doc_705833728518_item	2826699	et	4	main
siber	doc_705833728518_item	2826701	et	4	main
pilt	doc_705833728518_item	2826704	et	3	main
seal	doc_705833728518_item	2826706	et	4	main
ja	doc_705833728518_item	2826716	et	3	main
aga	doc_705833728517_item	2826337	et	3	main
võima	doc_705833728517_item	2826339	et	3	main
tooma	doc_705833728517_item	2826340	et	3	main
kogus	doc_705833728517_item	2826344	et	4	main
stress	doc_705833728517_item	2826345	et	3	main
aga	doc_705833728517_item	2826349	et	3	main
sportima	doc_705833728517_item	2826364	et	4	main
tohi	doc_705833728517_item	2826368	et	4	main
tekkima	doc_705833728517_item	2826371	et	3	main
saama	doc_705833728517_item	2826373	et	4	main
maandama	doc_705833728517_item	2826374	et	3	main
sportima	doc_705833728517_item	2826375	et	4	main
ja	doc_705833728517_item	2826376	et	3	main
puhkama	doc_705833728517_item	2826377	et	3	main
5	doc_705833728517_item	2826378	et	2	main
telefon	doc_705833728517_item	2826379	et	3	main
maagiline	doc_705833728517_item	2826384	et	4	main
maagiline	doc_705833728517_item	2826398	et	4	main
aparaat	doc_705833728517_item	2826399	et	3	main
et	doc_705833728517_item	2826400	et	3	main
see	doc_705833728517_item	2826401	et	3	main
ja	doc_705833728517_item	2826405	et	3	main
6	doc_705833728517_item	2826407	et	2	main
telesaade	doc_705833728517_item	2826422	et	4	main
kuid	doc_705833728517_item	2826425	et	4	main
telefonihelin	doc_705833728517_item	2826426	et	3	main
katkestab	doc_705833728517_item	2826427	et	3	main
ka	doc_705833728517_item	2826428	et	3	main
pühapäeval	doc_705833728517_item	2826429	et	3	main
lõunasööki	doc_705833728517_item	2826433	et	4	main
ja	doc_705833728517_item	2826435	et	3	main
iv	doc_705833728517_item	2826442	et	4	main
pange	doc_705833728517_item	2826443	et	4	main
sulgudes	doc_705833728517_item	2826444	et	4	main
ma	doc_705833728517_item	2826450	et	3	main
väga	doc_705833728517_item	2826452	et	3	main
vanematele	doc_705833728517_item	2826457	et	4	main
sest	doc_705833728517_item	2826458	et	4	main
nad	doc_705833728517_item	2826459	et	3	main
kõik	doc_705833728517_item	2826461	et	4	main
kõigile	doc_705833728517_item	2826462	et	4	main
ja	doc_705833728517_item	2826463	et	3	main
nõuded	doc_705833728517_item	2826470	et	3	main
et	doc_705833728517_item	2826474	et	3	main
sportiga	doc_705833728517_item	2826478	et	4	main
aga	doc_705833728517_item	2826479	et	3	main
difteeria	doc_705833728517_item	2826499	et	4	main
5	doc_705833728517_item	2826501	et	2	main
töökoht	doc_705833728517_item	2826504	et	3	main
valdkonnast	doc_705833728517_item	2826524	et	4	main
8	doc_705833728517_item	2826525	et	2	main
närimiskumm	doc_705833728517_item	2826526	et	3	main
külmetamisest	doc_705833728517_item	2826536	et	4	main
10	doc_705833728517_item	2826537	et	2	main
ma	doc_705833728517_item	2826538	et	3	main
päikest	doc_705833728517_item	2826544	et	4	main
tellisime	doc_705833728517_item	2826551	et	4	main
olid	doc_705833728517_item	2826560	et	4	main
kõrvallauast	doc_705833728517_item	2826575	et	4	main
keegi	doc_705833728517_item	2826580	et	4	main
küll	doc_705833728517_item	2826611	et	4	main
ülekoormus	doc_705833728517_item	2826370	et	3	main
pinge	doc_705833728517_item	2826372	et	4	main
abil	doc_705833728517_item	2826402	et	4	main
hingib	doc_705833728517_item	2826406	et	4	main
uni	doc_705833728517_item	2826431	et	3	main
valmistamine	doc_705833728517_item	2826434	et	4	main
söömine	doc_705833728517_item	2826436	et	4	main
pahandab	doc_705833728517_item	2826437	et	3	main
huvitav	doc_705833728517_item	2826438	et	4	main
1	doc_705833728517_item	2826449	et	2	main
lugu	doc_705833728517_item	2826453	et	4	main
kohandasin	doc_705833728517_item	2826468	et	3	main
sa	doc_705833728517_item	2826475	et	3	main
sport	doc_705833728517_item	2826477	et	3	main
sa	doc_705833728517_item	2826480	et	3	main
naised	doc_705833728517_item	2826485	et	3	main
autod	doc_705833728517_item	2826488	et	3	main
uus	doc_705833728517_item	2826503	et	3	main
töökohte	doc_705833728517_item	2826506	et	3	main
nii	doc_705833728517_item	2826383	et	3	main
see	doc_705833728517_item	2826387	et	3	main
lausa	doc_705833728517_item	2826389	et	4	main
elama	doc_705833728517_item	2826390	et	3	main
ja	doc_705833728517_item	2826391	et	3	main
hingama	doc_705833728517_item	2826392	et	3	main
telefon	doc_705833728517_item	2826393	et	3	main
on	doc_705833728517_item	2826394	et	4	main
huvitav	doc_705833728517_item	2826421	et	4	main
vaatamine	doc_705833728517_item	2826423	et	4	main
aeg	doc_705833728517_item	2826424	et	3	main
sõnad	doc_705833728517_item	2826446	et	4	main
õigesse	doc_705833728517_item	2826447	et	3	main
vormi	doc_705833728517_item	2826448	et	4	main
pean	doc_705833728517_item	2826451	et	4	main
usaldavad	doc_705833728517_item	2826464	et	4	main
igaüks	doc_705833728517_item	2826465	et	3	main
igaühele	doc_705833728517_item	2826466	et	3	main
3	doc_705833728517_item	2826471	et	2	main
ainult	doc_705833728517_item	2826483	et	4	main
ilusad	doc_705833728517_item	2826484	et	3	main
ja	doc_705833728517_item	2826486	et	3	main
difteeriaga	doc_705833728517_item	2826500	et	3	main
tüdinesin	doc_705833728517_item	2826502	et	3	main
uude	doc_705833728517_item	2826505	et	3	main
peab	doc_705833728517_item	2826533	et	4	main
rõõmu	doc_705833728517_item	2826540	et	4	main
suvist	doc_705833728517_item	2826543	et	4	main
sobivate	doc_705833728517_item	2826548	et	4	main
sidenditega	doc_705833728517_item	2826549	et	3	main
kolmekäigulise	doc_705833728517_item	2826552	et	4	main
sellepärast	doc_705833728517_item	2826554	et	3	main
paluti	doc_705833728517_item	2826568	et	3	main
just	doc_705833728517_item	2826581	et	3	main
maale	doc_705833728517_item	2826621	et	4	main
koputust	doc_705833728517_item	2826630	et	4	main
toomet	doc_705833728518_item	2826640	et	4	main
nägema	doc_705833728518_item	2826645	et	3	main
ajalehes	doc_705833728518_item	2826648	et	3	main
et	doc_705833728518_item	2826650	et	3	main
ja	doc_705833728518_item	2826663	et	3	main
nädala	doc_705833728518_item	2826669	et	3	main
eestlastele	doc_705833728518_item	2826671	et	4	main
tundis	doc_705833728518_item	2826679	et	3	main
on	doc_705833728518_item	2826685	et	4	main
üllatuma	doc_705833728518_item	2826689	et	3	main
kui	doc_705833728518_item	2826691	et	3	main
selline	doc_705833728518_item	2826703	et	4	main
et	doc_705833728518_item	2826705	et	3	main
ei	doc_705833728518_item	2826707	et	4	main
lendama	doc_705833728518_item	2826708	et	3	main
lenda	doc_705833728518_item	2826709	et	4	main
lind	doc_705833728518_item	2826710	et	3	main
ega	doc_705833728518_item	2826711	et	3	main
täis	doc_705833728518_item	2826719	et	4	main
pärast	doc_705833728518_item	2826721	et	4	main
algust	doc_705833728518_item	2826723	et	4	main
kohale	doc_705833728518_item	2826725	et	4	main
jõudis	doc_705833728518_item	2826726	et	3	main
veel	doc_705833728518_item	2826729	et	4	main
siin	doc_705833728518_item	2826739	et	4	main
sügisel	doc_705833728518_item	2826740	et	3	main
tänaseks	doc_705833728518_item	2826744	et	4	main
täie	doc_705833728518_item	2826752	et	3	main
siinsed	doc_705833728518_item	2826755	et	3	main
räägivad	doc_705833728518_item	2826757	et	3	main
mõnus	doc_705833728518_item	2826760	et	4	main
ja	doc_705833728518_item	2826761	et	3	main
vaid	doc_705833728518_item	2826767	et	3	main
nagu	doc_705833728518_item	2826768	et	3	main
mõned	doc_705833728518_item	2826770	et	3	main
kool	doc_705833728518_item	2826776	et	4	main
ja	doc_705833728518_item	2826777	et	3	main
ülejäänud	doc_705833728518_item	2826778	et	4	main
aine	doc_705833728518_item	2826779	et	4	main
ained	doc_705833728518_item	2826780	et	3	main
õpetatakse	doc_705833728518_item	2826781	et	3	main
kolmesaja	doc_705833728518_item	2826789	et	4	main
inimene	doc_705833728518_item	2826790	et	3	main
inimisi	doc_705833728518_item	2826791	et	4	main
sõnul	doc_705833728518_item	2826798	et	3	main
õpivad	doc_705833728518_item	2826799	et	3	main
segab	doc_705833728517_item	2826432	et	3	main
telesaade	doc_705833728517_item	2826439	et	4	main
olevad	doc_705833728517_item	2826445	et	4	main
oma	doc_705833728517_item	2826456	et	4	main
2	doc_705833728517_item	2826467	et	2	main
ma	doc_705833728517_item	2826472	et	3	main
huvitud	doc_705833728517_item	2826476	et	4	main
huvi	doc_705833728517_item	2826482	et	4	main
kiired	doc_705833728517_item	2826487	et	4	main
naiseks	doc_705833728517_item	2826490	et	3	main
kiired	doc_705833728517_item	2826492	et	4	main
autoks	doc_705833728517_item	2826493	et	4	main
4	doc_705833728517_item	2826494	et	2	main
praegu	doc_705833728517_item	2826495	et	3	main
on	doc_705833728517_item	2826496	et	4	main
oht	doc_705833728517_item	2826497	et	3	main
haigestuda	doc_705833728517_item	2826498	et	3	main
kiiresti	doc_705833728517_item	2826507	et	3	main
6	doc_705833728517_item	2826508	et	2	main
piirdusime	doc_705833728517_item	2826509	et	3	main
selles	doc_705833728517_item	2826510	et	4	main
küsimuses	doc_705833728517_item	2826511	et	4	main
vaid	doc_705833728517_item	2826512	et	3	main
väikesed	doc_705833728517_item	2826513	et	4	main
muudatused	doc_705833728517_item	2826514	et	3	main
väikese	doc_705833728517_item	2826515	et	4	main
muudatusi	doc_705833728517_item	2826516	et	3	main
7	doc_705833728517_item	2826517	et	2	main
see	doc_705833728517_item	2826518	et	3	main
küsimus	doc_705833728517_item	2826519	et	4	main
kuulub	doc_705833728517_item	2826520	et	3	main
valdkond	doc_705833728517_item	2826522	et	3	main
kleepus	doc_705833728517_item	2826527	et	3	main
püksid	doc_705833728517_item	2826528	et	3	main
püksistele	doc_705833728517_item	2826529	et	4	main
9	doc_705833728517_item	2826530	et	2	main
külmal	doc_705833728517_item	2826531	et	3	main
ajal	doc_705833728517_item	2826532	et	4	main
tunnen	doc_705833728517_item	2826539	et	3	main
päike	doc_705833728517_item	2826542	et	3	main
palju	doc_705833728517_item	2826557	et	4	main
2	doc_705833728517_item	2826558	et	2	main
õpilased	doc_705833728517_item	2826562	et	3	main
tulevad	doc_705833728517_item	2826573	et	4	main
4	doc_705833728517_item	2826574	et	2	main
pingsalt	doc_705833728517_item	2826612	et	4	main
kas	doc_705833728517_item	2826618	et	3	main
10	doc_705833728517_item	2826625	et	2	main
eksamitöö	doc_705833728518_item	2826631	et	4	main
on	doc_705833728518_item	2826641	et	4	main
nägi	doc_705833728518_item	2826646	et	3	main
konkurssis	doc_705833728518_item	2826662	et	4	main
väikestele	doc_705833728518_item	2826670	et	4	main
nende	doc_705833728518_item	2826673	et	4	main
emakeelt	doc_705833728518_item	2826674	et	4	main
õpetama	doc_705833728518_item	2826675	et	3	main
õpetas	doc_705833728518_item	2826676	et	3	main
tuli	doc_705833728518_item	2826694	et	4	main
vastu	doc_705833728518_item	2826695	et	3	main
korralik	doc_705833728518_item	2826696	et	3	main
korralikuga	doc_705833728518_item	2826697	et	3	main
siberi	doc_705833728518_item	2826702	et	4	main
rohi	doc_705833728518_item	2826713	et	4	main
kui	doc_705833728518_item	2826714	et	3	main
tahtmine	doc_705833728518_item	2826717	et	4	main
tahtmitega	doc_705833728518_item	2826718	et	4	main
polnud	doc_705833728518_item	2826727	et	3	main
teisest	doc_705833728517_item	2826523	et	4	main
suvine	doc_705833728517_item	2826541	et	4	main
1	doc_705833728517_item	2826550	et	2	main
lõuna	doc_705833728517_item	2826553	et	4	main
see	doc_705833728517_item	2826555	et	3	main
maksis	doc_705833728517_item	2826556	et	4	main
kõik	doc_705833728517_item	2826561	et	4	main
need	doc_705833728517_item	2826564	et	3	main
3	doc_705833728517_item	2826566	et	2	main
oodata	doc_705833728517_item	2826569	et	4	main
kui	doc_705833728517_item	2826570	et	3	main
vanemad	doc_705833728517_item	2826571	et	4	main
tagasi	doc_705833728517_item	2826572	et	3	main
seal	doc_705833728517_item	2826578	et	4	main
oleks	doc_705833728517_item	2826579	et	3	main
anekdooti	doc_705833728517_item	2826582	et	4	main
rääkinud	doc_705833728517_item	2826583	et	4	main
5	doc_705833728517_item	2826584	et	2	main
ta	doc_705833728517_item	2826585	et	4	main
ei	doc_705833728517_item	2826586	et	4	main
tule	doc_705833728517_item	2826587	et	4	main
trenni	doc_705833728517_item	2826588	et	4	main
aga	doc_705833728517_item	2826589	et	3	main
läheb	doc_705833728517_item	2826590	et	3	main
hoopis	doc_705833728517_item	2826591	et	3	main
teatrisse	doc_705833728517_item	2826592	et	3	main
6	doc_705833728517_item	2826593	et	2	main
lõpetage	doc_705833728517_item	2826594	et	3	main
töö	doc_705833728517_item	2826595	et	4	main
pärast	doc_705833728517_item	2826596	et	4	main
lähete	doc_705833728517_item	2826597	et	4	main
jalutama	doc_705833728517_item	2826598	et	3	main
7	doc_705833728517_item	2826599	et	2	main
selles	doc_705833728517_item	2826600	et	4	main
baaris	doc_705833728517_item	2826601	et	3	main
ei	doc_705833728517_item	2826602	et	4	main
tohi	doc_705833728517_item	2826603	et	4	main
suitsetada	doc_705833728517_item	2826604	et	3	main
ning	doc_705833728517_item	2826605	et	3	main
alkoholi	doc_705833728517_item	2826606	et	4	main
tarbida	doc_705833728517_item	2826607	et	3	main
8	doc_705833728517_item	2826608	et	2	main
nad	doc_705833728517_item	2826609	et	3	main
töötasid	doc_705833728517_item	2826610	et	4	main
tulemust	doc_705833728517_item	2826614	et	4	main
ei	doc_705833728517_item	2826615	et	4	main
olnud	doc_705833728517_item	2826616	et	4	main
9	doc_705833728517_item	2826617	et	2	main
sa	doc_705833728517_item	2826619	et	3	main
jääd	doc_705833728517_item	2826623	et	4	main
kuulsin	doc_705833728517_item	2826629	et	3	main
i	doc_705833728518_item	2826632	et	4	main
pange	doc_705833728518_item	2826633	et	4	main
vormi	doc_705833728518_item	2826638	et	4	main
piret	doc_705833728518_item	2826639	et	4	main
naine	doc_705833728518_item	2826643	et	3	main
küla	doc_705833728518_item	2826653	et	4	main
külas	doc_705833728518_item	2826654	et	3	main
otsitakse	doc_705833728518_item	2826655	et	3	main
eesti	doc_705833728518_item	2826656	et	4	main
keele	doc_705833728518_item	2826657	et	4	main
nüüd	doc_705833728518_item	2826665	et	4	main
üle	doc_705833728518_item	2826667	et	3	main
nädal	doc_705833728518_item	2826668	et	3	main
pireti	doc_705833728518_item	2826677	et	4	main
ta	doc_705833728518_item	2826680	et	4	main
jõudis	doc_705833728518_item	2826683	et	3	main
oodatud	doc_705833728518_item	2826686	et	4	main
mulle	doc_705833728518_item	2826692	et	4	main
tulema	doc_705833728518_item	2826693	et	4	main
kasva	doc_705833728518_item	2826712	et	4	main
küla	doc_705833728518_item	2826733	et	4	main
võtma	doc_705833728518_item	2826734	et	3	main
võttis	doc_705833728518_item	2826735	et	3	main
kartuleid	doc_705833728518_item	2826736	et	3	main
kartulivõtt	doc_705833728518_item	2826737	et	3	main
on	doc_705833728518_item	2826738	et	4	main
ettevõtmine	doc_705833728518_item	2826743	et	3	main
aktsentiga	doc_705833728518_item	2826766	et	4	main
mõni	doc_705833728518_item	2826769	et	3	main
kool	doc_705833728518_item	2826772	et	4	main
emakeelt	doc_705833728518_item	2826792	et	4	main
saab	doc_705833728518_item	2826793	et	3	main
poolpõlenud	doc_705833728518_item	2826801	et	4	main
soe	doc_705833728518_item	2826825	et	4	main
soojad	doc_705833728518_item	2826826	et	3	main
kuid	doc_705833728518_item	2826827	et	4	main
juba	doc_705833728518_item	2826833	et	3	main
vildid	doc_705833728518_item	2826844	et	4	main
piret	doc_705833728518_item	2826855	et	4	main
iii	doc_705833728518_item	2826860	et	4	main
moodustage	doc_705833728518_item	2826861	et	3	main
etteantud	doc_705833728518_item	2826862	et	4	main
naiselikum	doc_705833728518_item	2826876	et	4	main
ja	doc_705833728518_item	2826877	et	3	main
mehed	doc_705833728518_item	2826878	et	3	main
mehelikum	doc_705833728518_item	2826879	et	4	main
igaüks	doc_705833728518_item	2826880	et	3	main
kaunim	doc_705833728518_item	2826881	et	4	main
kaunim	doc_705833728518_item	2826883	et	4	main
naisi	doc_705833728518_item	2826886	et	3	main
sportima	doc_705833728518_item	2826922	et	4	main
puhkama	doc_705833728518_item	2826924	et	3	main
nii	doc_705833728518_item	2826930	et	3	main
et	doc_705833728518_item	2826947	et	3	main
6	doc_705833728518_item	2826953	et	2	main
kuid	doc_705833728518_item	2826954	et	4	main
varahommik	doc_705833728518_item	2826959	et	3	main
söömine	doc_705833728518_item	2826981	et	4	main
ja	doc_705833728518_item	2826982	et	3	main
katkestab	doc_705833728518_item	2826983	et	3	main
huvitava	doc_705833728518_item	2826984	et	4	main
olevad	doc_705833728518_item	2826991	et	4	main
oma	doc_705833728518_item	2827000	et	4	main
sest	doc_705833728518_item	2827004	et	4	main
et	doc_705833728518_item	2827021	et	3	main
huvitud	doc_705833728518_item	2827023	et	4	main
huvi	doc_705833728518_item	2827029	et	4	main
ilusad	doc_705833728518_item	2827031	et	3	main
kiired	doc_705833728518_item	2827034	et	4	main
autod	doc_705833728518_item	2827035	et	3	main
ilusa	doc_705833728518_item	2827036	et	3	main
naisega	doc_705833728518_item	2827037	et	3	main
ja	doc_705833728518_item	2827038	et	3	main
kiire	doc_705833728518_item	2827039	et	4	main
autoga	doc_705833728518_item	2827040	et	3	main
linna	doc_705833728517_item	2826624	et	4	main
ukse	doc_705833728517_item	2826627	et	3	main
olevad	doc_705833728518_item	2826635	et	4	main
sõnad	doc_705833728518_item	2826636	et	4	main
õigesse	doc_705833728518_item	2826637	et	3	main
suvel	doc_705833728518_item	2826644	et	3	main
siberisse	doc_705833728518_item	2826651	et	4	main
ülem-suetuki	doc_705833728518_item	2826652	et	4	main
õpetajat	doc_705833728518_item	2826658	et	4	main
piret	doc_705833728518_item	2826659	et	4	main
võitis	doc_705833728518_item	2826660	et	3	main
konkurss	doc_705833728518_item	2826661	et	3	main
need	doc_705833728518_item	2826672	et	3	main
kinnitusel	doc_705833728518_item	2826678	et	4	main
siberisse	doc_705833728518_item	2826681	et	4	main
jõudma	doc_705833728518_item	2826682	et	3	main
audiga	doc_705833728518_item	2826698	et	3	main
maaliti	doc_705833728518_item	2826700	et	3	main
noor	doc_705833728518_item	2826715	et	3	main
piret	doc_705833728518_item	2826720	et	4	main
õppeaasta	doc_705833728518_item	2826722	et	4	main
koht	doc_705833728518_item	2826724	et	3	main
on	doc_705833728518_item	2826745	et	4	main
salves	doc_705833728518_item	2826748	et	4	main
õppimine	doc_705833728518_item	2826750	et	4	main
hoog	doc_705833728518_item	2826753	et	3	main
eestlased	doc_705833728518_item	2826756	et	3	main
kuidagi	doc_705833728518_item	2826758	et	3	main
aktsent	doc_705833728518_item	2826765	et	3	main
venemaa	doc_705833728518_item	2826775	et	4	main
vene	doc_705833728518_item	2826782	et	4	main
elab	doc_705833728518_item	2826785	et	3	main
üle	doc_705833728518_item	2826787	et	3	main
kõik	doc_705833728518_item	2826794	et	4	main
on	doc_705833728518_item	2826822	et	4	main
harjutan	doc_705833728518_item	2826832	et	3	main
ega	doc_705833728518_item	2826845	et	3	main
ei	doc_705833728518_item	2826849	et	4	main
talveks	doc_705833728518_item	2826852	et	4	main
valmistuma	doc_705833728518_item	2826853	et	3	main
valmistuseks	doc_705833728518_item	2826854	et	4	main
slõhtuleht	doc_705833728518_item	2826859	et	4	main
kirjavahemärke	doc_705833728518_item	2826871	et	4	main
igaüks	doc_705833728518_item	2826882	et	3	main
kool	doc_705833728518_item	2826728	et	4	main
alanud	doc_705833728518_item	2826731	et	4	main
kõige	doc_705833728518_item	2826741	et	4	main
tähtis	doc_705833728518_item	2826742	et	4	main
ja	doc_705833728518_item	2826749	et	3	main
käib	doc_705833728518_item	2826751	et	3	main
hooga	doc_705833728518_item	2826754	et	3	main
teistmoodi	doc_705833728518_item	2826759	et	3	main
mahlakas	doc_705833728518_item	2826762	et	4	main
mitte	doc_705833728518_item	2826763	et	3	main
keeles	doc_705833728518_item	2826783	et	4	main
kõik	doc_705833728518_item	2826795	et	4	main
rääkida	doc_705833728518_item	2826796	et	3	main
pireti	doc_705833728518_item	2826797	et	4	main
raamatuid	doc_705833728518_item	2826803	et	3	main
varsti	doc_705833728518_item	2826804	et	3	main
saatma	doc_705833728518_item	2826805	et	3	main
saavad	doc_705833728518_item	2826806	et	4	main
eestist	doc_705833728518_item	2826807	et	3	main
uued	doc_705833728518_item	2826808	et	3	main
õpikud	doc_705833728518_item	2826809	et	3	main
siberi	doc_705833728518_item	2826810	et	4	main
talve	doc_705833728518_item	2826811	et	4	main
piret	doc_705833728518_item	2826812	et	4	main
ei	doc_705833728518_item	2826813	et	4	main
kartma	doc_705833728518_item	2826814	et	3	main
karda	doc_705833728518_item	2826815	et	4	main
mulle	doc_705833728518_item	2826816	et	4	main
juba	doc_705833728518_item	2826817	et	3	main
tooma	doc_705833728518_item	2826818	et	3	main
toodi	doc_705833728518_item	2826819	et	4	main
talvepuud	doc_705833728518_item	2826820	et	4	main
praegu	doc_705833728518_item	2826821	et	3	main
päevad	doc_705833728518_item	2826823	et	3	main
veel	doc_705833728518_item	2826824	et	4	main
suure	doc_705833728518_item	2826834	et	3	main
ahju	doc_705833728518_item	2826836	et	4	main
kütma	doc_705833728518_item	2826838	et	3	main
vapralt	doc_705833728518_item	2826856	et	4	main
lühendatud	doc_705833728518_item	2826857	et	4	main
laused	doc_705833728518_item	2826864	et	3	main
sõnad	doc_705833728518_item	2826866	et	4	main
ja	doc_705833728518_item	2826923	et	3	main
tänapäev	doc_705833728518_item	2826928	et	3	main
et	doc_705833728518_item	2826933	et	3	main
tema	doc_705833728518_item	2826948	et	4	main
ka	doc_705833728518_item	2826957	et	3	main
aeg	doc_705833728518_item	2826970	et	3	main
telefonihelin	doc_705833728518_item	2826971	et	3	main
pühapäeva	doc_705833728518_item	2826972	et	4	main
varahommikul	doc_705833728518_item	2826973	et	3	main
segab	doc_705833728518_item	2826974	et	3	main
vatamise	doc_705833728518_item	2826986	et	4	main
õigesse	doc_705833728518_item	2826993	et	3	main
vormi	doc_705833728518_item	2826994	et	4	main
1	doc_705833728518_item	2826995	et	2	main
ma	doc_705833728518_item	2826996	et	3	main
oma	doc_705833728518_item	2827002	et	4	main
nõudesse	doc_705833728518_item	2827017	et	4	main
3	doc_705833728518_item	2827018	et	2	main
ma	doc_705833728518_item	2827019	et	3	main
arvasin	doc_705833728518_item	2827020	et	3	main
algama	doc_705833728518_item	2826730	et	3	main
kogu	doc_705833728518_item	2826732	et	4	main
kartul	doc_705833728518_item	2826746	et	3	main
salv	doc_705833728518_item	2826747	et	3	main
vene	doc_705833728518_item	2826764	et	4	main
murret	doc_705833728518_item	2826771	et	4	main
on	doc_705833728518_item	2826773	et	4	main
siiski	doc_705833728518_item	2826774	et	4	main
külas	doc_705833728518_item	2826784	et	3	main
veidi	doc_705833728518_item	2826786	et	3	main
kolmsada	doc_705833728518_item	2826788	et	4	main
raamatud	doc_705833728518_item	2826802	et	4	main
lapsed	doc_705833728518_item	2826800	et	3	main
ööd	doc_705833728518_item	2826828	et	4	main
juba	doc_705833728518_item	2826829	et	3	main
jahe	doc_705833728518_item	2826830	et	3	main
vene	doc_705833728518_item	2826835	et	4	main
kütmine	doc_705833728518_item	2826837	et	4	main
vaja	doc_705833728518_item	2826840	et	4	main
ostan	doc_705833728518_item	2826841	et	3	main
külapood	doc_705833728518_item	2826842	et	3	main
külapooes	doc_705833728518_item	2826843	et	4	main
suurt	doc_705833728518_item	2826847	et	3	main
muud	doc_705833728518_item	2826848	et	4	main
müüdagi	doc_705833728518_item	2826850	et	3	main
naerab	doc_705833728518_item	2826851	et	3	main
pannes	doc_705833728518_item	2826865	et	4	main
naeratus	doc_705833728518_item	2826884	et	4	main
teeb	doc_705833728518_item	2826885	et	3	main
naiselikum	doc_705833728518_item	2826887	et	4	main
ja	doc_705833728518_item	2826888	et	3	main
mehi	doc_705833728518_item	2826889	et	3	main
mehelikum	doc_705833728518_item	2826890	et	4	main
maandama	doc_705833728518_item	2826921	et	3	main
telefon	doc_705833728518_item	2826926	et	3	main
olema	doc_705833728518_item	2826927	et	4	main
see	doc_705833728518_item	2826934	et	3	main
lausa	doc_705833728518_item	2826936	et	4	main
on	doc_705833728518_item	2826941	et	4	main
saanud	doc_705833728518_item	2826943	et	4	main
nii	doc_705833728518_item	2826944	et	3	main
elame	doc_705833728518_item	2826950	et	3	main
ja	doc_705833728518_item	2826951	et	3	main
pühapäev	doc_705833728518_item	2826958	et	3	main
lõunasööki	doc_705833728518_item	2826978	et	4	main
telesaade	doc_705833728518_item	2826985	et	4	main
aega	doc_705833728518_item	2826987	et	4	main
iv	doc_705833728518_item	2826988	et	4	main
sõnad	doc_705833728518_item	2826992	et	4	main
vanemad	doc_705833728518_item	2827001	et	4	main
nad	doc_705833728518_item	2827005	et	3	main
kõike	doc_705833728518_item	2827008	et	4	main
ja	doc_705833728518_item	2827009	et	3	main
usaldavad	doc_705833728518_item	2827010	et	4	main
igaüks	doc_705833728518_item	2827011	et	3	main
igaühele	doc_705833728518_item	2827012	et	3	main
2	doc_705833728518_item	2827013	et	2	main
kohandasin	doc_705833728518_item	2827014	et	3	main
artikli	doc_705833728518_item	2827015	et	3	main
nõuded	doc_705833728518_item	2827016	et	3	main
sa	doc_705833728518_item	2827022	et	3	main
sport	doc_705833728518_item	2827024	et	3	main
sportiga	doc_705833728518_item	2827025	et	4	main
ajal	doc_705833728518_item	2827079	et	4	main
rõõmu	doc_705833728518_item	2827087	et	4	main
kolmekäigulise	doc_705833728518_item	2827099	et	4	main
tule	doc_705833728518_item	2827133	et	4	main
lõpetage	doc_705833728518_item	2827140	et	3	main
siis	doc_705833728518_item	2827142	et	3	main
7	doc_705833728518_item	2827145	et	2	main
suitsetada	doc_705833728518_item	2827150	et	3	main
sõidad	doc_705833728518_item	2827166	et	3	main
10	doc_705833728518_item	2827171	et	2	main
ukse	doc_705833728518_item	2827173	et	3	main
kuulsin	doc_705833728518_item	2827175	et	3	main
1	doc_713316236902_item	2827178	et	2	main
muutused	doc_713316236902_item	2827179	et	4	main
mis	doc_713316236902_item	2827186	et	4	main
sündmus	doc_713316236902_item	2827187	et	3	main
rahavstele	doc_713316236902_item	2827194	et	4	main
uutmine	doc_713316236902_item	2827230	et	4	main
uutmoodi	doc_713316236902_item	2827231	et	3	main
poliitika	doc_713316236902_item	2827232	et	4	main
ja	doc_713316236902_item	2827236	et	3	main
läbipaistvus	doc_713316236902_item	2827237	et	4	main
poliitikas	doc_713316236902_item	2827238	et	3	main
uutmine	doc_713316236902_item	2827239	et	4	main
ja	doc_713316236902_item	2827240	et	3	main
stalinismi	doc_713316236902_item	2827244	et	4	main
ehk	doc_713316236902_item	2827251	et	3	main
nad	doc_713316236902_item	2827253	et	3	main
tööd	doc_713316236902_item	2827255	et	4	main
või	doc_713316236902_item	2827256	et	4	main
lihtsalt	doc_713316236902_item	2827257	et	4	main
jahedad	doc_705833728518_item	2826831	et	3	main
kui	doc_705833728518_item	2826839	et	3	main
seal	doc_705833728518_item	2826846	et	4	main
ajalehest	doc_705833728518_item	2826858	et	4	main
sõnadest	doc_705833728518_item	2826863	et	3	main
õigesse	doc_705833728518_item	2826867	et	3	main
vormi	doc_705833728518_item	2826868	et	4	main
ja	doc_705833728518_item	2826869	et	3	main
kasutades	doc_705833728518_item	2826870	et	3	main
2	doc_705833728518_item	2826872	et	2	main
naeratus	doc_705833728518_item	2826873	et	4	main
tegema	doc_705833728518_item	2826874	et	3	main
naised	doc_705833728518_item	2826875	et	3	main
3	doc_705833728518_item	2826891	et	2	main
paras	doc_705833728518_item	2826892	et	3	main
kogus	doc_705833728518_item	2826893	et	4	main
stress	doc_705833728518_item	2826894	et	3	main
panema	doc_705833728518_item	2826895	et	3	main
meie	doc_705833728518_item	2826896	et	4	main
tegutsema	doc_705833728518_item	2826897	et	3	main
aga	doc_705833728518_item	2826898	et	3	main
lisakoormus	doc_705833728518_item	2826899	et	3	main
võima	doc_705833728518_item	2826900	et	3	main
tooma	doc_705833728518_item	2826901	et	3	main
soovimatu	doc_705833728518_item	2826902	et	4	main
tagajärg	doc_705833728518_item	2826903	et	3	main
stress	doc_705833728518_item	2826904	et	3	main
paneb	doc_705833728518_item	2826905	et	3	main
meile	doc_705833728518_item	2826906	et	4	main
paras	doc_705833728518_item	2826907	et	3	main
lisakoormus	doc_705833728518_item	2826908	et	3	main
ja	doc_705833728518_item	2826909	et	3	main
toob	doc_705833728518_item	2826910	et	3	main
tagajarg	doc_705833728518_item	2826912	et	4	main
4	doc_705833728518_item	2826913	et	2	main
soovimatu	doc_705833728518_item	2826911	et	4	main
ei	doc_705833728518_item	2826914	et	4	main
tohtima	doc_705833728518_item	2826915	et	3	main
laskma	doc_705833728518_item	2826916	et	3	main
ülekoormus	doc_705833728518_item	2826917	et	3	main
tekkima	doc_705833728518_item	2826918	et	3	main
pinge	doc_705833728518_item	2826919	et	4	main
saama	doc_705833728518_item	2826920	et	4	main
saama	doc_705833728518_item	2826929	et	4	main
aparaat	doc_705833728518_item	2826932	et	3	main
maagilise	doc_705833728518_item	2826945	et	4	main
aparaat	doc_705833728518_item	2826946	et	3	main
telefonihelin	doc_705833728518_item	2826955	et	3	main
valmistamine	doc_705833728518_item	2826979	et	4	main
ja	doc_705833728518_item	2826980	et	3	main
sulgudes	doc_705833728518_item	2826990	et	4	main
5	doc_705833728518_item	2826925	et	2	main
maagiline	doc_705833728518_item	2826931	et	4	main
abil	doc_705833728518_item	2826935	et	4	main
elama	doc_705833728518_item	2826937	et	3	main
ja	doc_705833728518_item	2826938	et	3	main
hingama	doc_705833728518_item	2826939	et	3	main
telefon	doc_705833728518_item	2826940	et	3	main
tänapäeval	doc_705833728518_item	2826942	et	3	main
abil	doc_705833728518_item	2826949	et	4	main
hingame	doc_705833728518_item	2826952	et	3	main
katkestama	doc_705833728518_item	2826956	et	3	main
uni	doc_705833728518_item	2826960	et	3	main
segama	doc_705833728518_item	2826961	et	3	main
lõunasöök	doc_705833728518_item	2826962	et	3	main
valmistamine	doc_705833728518_item	2826963	et	4	main
ja	doc_705833728518_item	2826964	et	3	main
söömine	doc_705833728518_item	2826965	et	4	main
pahandab	doc_705833728518_item	2826966	et	3	main
huvitav	doc_705833728518_item	2826967	et	4	main
telesaade	doc_705833728518_item	2826968	et	4	main
vaatamine	doc_705833728518_item	2826969	et	4	main
und	doc_705833728518_item	2826975	et	4	main
ka	doc_705833728518_item	2826976	et	3	main
pahandab	doc_705833728518_item	2826977	et	3	main
pange	doc_705833728518_item	2826989	et	4	main
pean	doc_705833728518_item	2826997	et	4	main
aitavad	doc_705833728518_item	2827006	et	4	main
kõik	doc_705833728518_item	2827007	et	4	main
aga	doc_705833728518_item	2827026	et	3	main
uus	doc_705833728518_item	2827050	et	3	main
uue	doc_705833728518_item	2827052	et	3	main
6	doc_705833728518_item	2827055	et	2	main
piirdusime	doc_705833728518_item	2827056	et	3	main
muudatused	doc_705833728518_item	2827061	et	3	main
7	doc_705833728518_item	2827064	et	2	main
kuulub	doc_705833728518_item	2827067	et	3	main
peab	doc_705833728518_item	2827080	et	4	main
külmetamine	doc_705833728518_item	2827082	et	4	main
10	doc_705833728518_item	2827084	et	2	main
suvisel	doc_705833728518_item	2827090	et	4	main
v	doc_705833728518_item	2827092	et	4	main
lõuna	doc_705833728518_item	2827100	et	4	main
aga	doc_705833728518_item	2827101	et	3	main
see	doc_705833728518_item	2827102	et	3	main
maksis	doc_705833728518_item	2827103	et	4	main
kõrvallauast	doc_705833728518_item	2827121	et	4	main
rääkinud	doc_705833728518_item	2827129	et	4	main
hoopis	doc_705833728518_item	2827137	et	3	main
ei	doc_705833728518_item	2827148	et	4	main
alkoholi	doc_705833728518_item	2827152	et	4	main
tarbida	doc_705833728518_item	2827153	et	3	main
ei	doc_705833728518_item	2827161	et	4	main
olnud	doc_705833728518_item	2827162	et	4	main
9	doc_705833728518_item	2827163	et	2	main
kas	doc_705833728518_item	2827164	et	3	main
baltikumi	doc_713316236902_item	2827193	et	4	main
ja	doc_713316236902_item	2827195	et	3	main
võimule	doc_713316236902_item	2827222	et	3	main
gorbatšov	doc_713316236902_item	2827224	et	2	main
perstroika	doc_713316236902_item	2827233	et	4	main
glasnost	doc_713316236902_item	2827241	et	4	main
kuritegu	doc_713316236902_item	2827245	et	4	main
kontrolliti	doc_713316236902_item	2827249	et	3	main
gorbatsov	doc_713316236902_item	2827260	et	4	main
lõpul	doc_713316236902_item	2827269	et	3	main
oli	doc_713316236902_item	2827276	et	3	main
oli	doc_713316236902_item	2827284	et	3	main
sellele	doc_713316236902_item	2827286	et	4	main
see	doc_713316236902_item	2827290	et	3	main
saada	doc_713316236902_item	2827304	et	4	main
dokumenti	doc_713316236902_item	2827307	et	4	main
poliitiliselt	doc_713316236902_item	2827322	et	4	main
olla	doc_713316236902_item	2827324	et	3	main
a	doc_713316236902_item	2827326	et	4	main
toetas	doc_713316236902_item	2827333	et	3	main
rr	doc_713316236902_item	2827334	et	4	main
rolli	doc_713316236902_item	2827339	et	4	main
see	doc_713316236902_item	2827340	et	3	main
ei	doc_713316236902_item	2827341	et	4	main
süsteemi	doc_713316236902_item	2827344	et	4	main
dotatsioon	doc_713316236902_item	2827349	et	3	main
süsteemiks	doc_713316236902_item	2827353	et	3	main
maksnud	doc_713316236902_item	2827356	et	4	main
ja	doc_713316236902_item	2827358	et	3	main
ei	doc_713316236902_item	2827360	et	4	main
kuid	doc_713316236902_item	2827371	et	4	main
tasapisi	doc_713316236902_item	2827372	et	3	main
see	doc_713316236902_item	2827373	et	3	main
ammenduma	doc_713316236902_item	2827375	et	3	main
1987	doc_713316236902_item	2827380	et	2	main
külastab	doc_713316236902_item	2827382	et	3	main
eesti	doc_713316236902_item	2827384	et	4	main
1989	doc_713316236902_item	2827390	et	2	main
pärast	doc_713316236902_item	2827434	et	4	main
ümbernimetus	doc_713316236902_item	2827445	et	4	main
keskkool	doc_713316236902_item	2827450	et	4	main
siin	doc_713316236902_item	2827459	et	4	main
rakendusharidust	doc_713316236902_item	2827463	et	4	main
nimetused	doc_713316236902_item	2827465	et	4	main
kasu	doc_713316236902_item	2827495	et	4	main
see	doc_713316236902_item	2827496	et	3	main
polnud	doc_713316236902_item	2827497	et	3	main
eriti	doc_713316236902_item	2827498	et	3	main
väga	doc_705833728518_item	2826998	et	3	main
lugu	doc_705833728518_item	2826999	et	4	main
vanematele	doc_705833728518_item	2827003	et	4	main
sa	doc_705833728518_item	2827027	et	3	main
ainult	doc_705833728518_item	2827030	et	4	main
naised	doc_705833728518_item	2827032	et	3	main
ja	doc_705833728518_item	2827033	et	3	main
oht	doc_705833728518_item	2827044	et	3	main
haigestuda	doc_705833728518_item	2827045	et	3	main
difteeria	doc_705833728518_item	2827046	et	4	main
difteeriaks	doc_705833728518_item	2827047	et	3	main
tüdinesin	doc_705833728518_item	2827049	et	3	main
väikesed	doc_705833728518_item	2827060	et	4	main
muudatusi	doc_705833728518_item	2827063	et	3	main
valdkond	doc_705833728518_item	2827069	et	3	main
valdkonnas	doc_705833728518_item	2827071	et	4	main
8	doc_705833728518_item	2827072	et	2	main
närimiskumm	doc_705833728518_item	2827073	et	3	main
kleepus	doc_705833728518_item	2827074	et	3	main
püksid	doc_705833728518_item	2827075	et	3	main
püksile	doc_705833728518_item	2827076	et	3	main
hoiduma	doc_705833728518_item	2827081	et	3	main
külmetamiseks	doc_705833728518_item	2827083	et	4	main
päike	doc_705833728518_item	2827089	et	3	main
kostis	doc_705833728518_item	2827122	et	4	main
naeru	doc_705833728518_item	2827123	et	4	main
et	doc_705833728518_item	2827124	et	3	main
oleks	doc_705833728518_item	2827125	et	3	main
keegi	doc_705833728518_item	2827126	et	4	main
just	doc_705833728518_item	2827127	et	3	main
5	doc_705833728518_item	2827130	et	2	main
ei	doc_705833728518_item	2827132	et	4	main
6	doc_705833728518_item	2827139	et	2	main
töö	doc_705833728518_item	2827141	et	4	main
lähete	doc_705833728518_item	2827143	et	4	main
jalutama	doc_705833728518_item	2827144	et	3	main
selles	doc_705833728518_item	2827146	et	4	main
baaris	doc_705833728518_item	2827147	et	3	main
tohi	doc_705833728518_item	2827149	et	4	main
ega	doc_705833728518_item	2827151	et	3	main
8	doc_705833728518_item	2827154	et	2	main
nad	doc_705833728518_item	2827155	et	3	main
töötasid	doc_705833728518_item	2827156	et	4	main
maale	doc_705833728518_item	2827167	et	4	main
jääd	doc_705833728518_item	2827169	et	4	main
kui	doc_705833728518_item	2827174	et	3	main
kontrolltöö	doc_713316236902_item	2827177	et	4	main
ja	doc_713316236902_item	2827180	et	3	main
muudatused	doc_713316236902_item	2827181	et	3	main
taasiseseisvunud	doc_713316236902_item	2827182	et	4	main
balti	doc_713316236902_item	2827189	et	3	main
tuli	doc_713316236902_item	2827223	et	4	main
tema	doc_713316236902_item	2827225	et	4	main
valitsemisel	doc_713316236902_item	2827226	et	4	main
kaasa	doc_713316236902_item	2827243	et	4	main
majandus	doc_713316236902_item	2827246	et	4	main
inimesi	doc_713316236902_item	2827250	et	4	main
teevad	doc_713316236902_item	2827254	et	3	main
aa	doc_713316236902_item	2827268	et	3	main
moskvas	doc_713316236902_item	2827270	et	4	main
üüritus	doc_713316236902_item	2827272	et	4	main
nsvl	doc_713316236902_item	2827279	et	4	main
nsvl	doc_713316236902_item	2827295	et	4	main
lammutamise	doc_713316236902_item	2827296	et	4	main
majanduslikult	doc_713316236902_item	2827302	et	4	main
autonoomseks	doc_713316236902_item	2827303	et	3	main
kodanikuks	doc_713316236902_item	2827313	et	4	main
ilmub	doc_713316236902_item	2827314	et	3	main
dokument	doc_713316236902_item	2827315	et	3	main
1988	doc_713316236902_item	2827317	et	2	main
ekp	doc_713316236902_item	2827336	et	4	main
kaotab	doc_713316236902_item	2827337	et	3	main
enamkontrollida	doc_713316236902_item	2827343	et	4	main
peeti	doc_713316236902_item	2827351	et	4	main
elekter	doc_713316236902_item	2827354	et	3	main
mõõdetud	doc_713316236902_item	2827361	et	4	main
suur	doc_713316236902_item	2827362	et	3	main
avaldus	doc_713316236902_item	2827363	et	4	main
meditsiiniks	doc_713316236902_item	2827364	et	3	main
ravimid	doc_713316236902_item	2827365	et	3	main
tasuta	doc_713316236902_item	2827366	et	4	main
tunned	doc_705833728518_item	2827028	et	3	main
on	doc_705833728518_item	2827043	et	4	main
5	doc_705833728518_item	2827048	et	2	main
töökoht	doc_705833728518_item	2827051	et	3	main
töökoha	doc_705833728518_item	2827053	et	4	main
kiiresti	doc_705833728518_item	2827054	et	3	main
selles	doc_705833728518_item	2827057	et	4	main
küsimuses	doc_705833728518_item	2827058	et	4	main
vaid	doc_705833728518_item	2827059	et	3	main
väikesi	doc_705833728518_item	2827062	et	4	main
küsimus	doc_705833728518_item	2827066	et	4	main
teine	doc_705833728518_item	2827068	et	3	main
teises	doc_705833728518_item	2827070	et	4	main
9	doc_705833728518_item	2827077	et	2	main
külmal	doc_705833728518_item	2827078	et	3	main
tunnen	doc_705833728518_item	2827086	et	3	main
päikesel	doc_705833728518_item	2827091	et	4	main
täitke	doc_705833728518_item	2827093	et	3	main
lüngad	doc_705833728518_item	2827094	et	3	main
sobivate	doc_705833728518_item	2827095	et	4	main
sidenditega	doc_705833728518_item	2827096	et	3	main
palju	doc_705833728518_item	2827104	et	4	main
2	doc_705833728518_item	2827105	et	2	main
kohal	doc_705833728518_item	2827106	et	4	main
olid	doc_705833728518_item	2827107	et	4	main
kõik	doc_705833728518_item	2827108	et	4	main
õpilased	doc_705833728518_item	2827109	et	3	main
ja	doc_705833728518_item	2827110	et	3	main
õpetajad	doc_705833728518_item	2827111	et	4	main
3	doc_705833728518_item	2827112	et	2	main
lapsel	doc_705833728518_item	2827113	et	4	main
paluti	doc_705833728518_item	2827114	et	3	main
oodata	doc_705833728518_item	2827115	et	4	main
kui	doc_705833728518_item	2827116	et	3	main
vanemad	doc_705833728518_item	2827117	et	4	main
tagasi	doc_705833728518_item	2827118	et	3	main
tulevad	doc_705833728518_item	2827119	et	4	main
4	doc_705833728518_item	2827120	et	2	main
anekdooti	doc_705833728518_item	2827128	et	4	main
ta	doc_705833728518_item	2827131	et	4	main
teatrisse	doc_705833728518_item	2827138	et	3	main
pingsalt	doc_705833728518_item	2827158	et	4	main
aga	doc_705833728518_item	2827159	et	3	main
tulemust	doc_705833728518_item	2827160	et	4	main
linna	doc_705833728518_item	2827170	et	4	main
koputust	doc_705833728518_item	2827176	et	4	main
kett	doc_713316236902_item	2827190	et	4	main
tähendus	doc_713316236902_item	2827192	et	4	main
a	doc_713316236902_item	2827221	et	4	main
4	doc_705833728518_item	2827041	et	2	main
praegu	doc_705833728518_item	2827042	et	3	main
see	doc_705833728518_item	2827065	et	3	main
ma	doc_705833728518_item	2827085	et	3	main
suvine	doc_705833728518_item	2827088	et	4	main
1	doc_705833728518_item	2827097	et	2	main
tellisime	doc_705833728518_item	2827098	et	4	main
trenni	doc_705833728518_item	2827134	et	4	main
vaid	doc_705833728518_item	2827135	et	3	main
läheb	doc_705833728518_item	2827136	et	3	main
küll	doc_705833728518_item	2827157	et	4	main
sa	doc_705833728518_item	2827165	et	3	main
või	doc_705833728518_item	2827168	et	4	main
avasin	doc_705833728518_item	2827172	et	3	main
eesti	doc_713316236902_item	2827183	et	4	main
kultuurielus	doc_713316236902_item	2827184	et	4	main
2	doc_713316236902_item	2827185	et	2	main
oli	doc_713316236902_item	2827188	et	3	main
selle	doc_713316236902_item	2827191	et	4	main
maailmale	doc_713316236902_item	2827196	et	4	main
1	doc_713316236902_item	2827197	et	2	main
1980-ndatel	doc_713316236902_item	2827198	et	4	main
aastatel	doc_713316236902_item	2827199	et	4	main
valitsuses	doc_713316236902_item	2827200	et	4	main
hakati	doc_713316236902_item	2827201	et	3	main
juhte	doc_713316236902_item	2827202	et	4	main
vahetama	doc_713316236902_item	2827203	et	3	main
pärast	doc_713316236902_item	2827204	et	4	main
brežnevi	doc_713316236902_item	2827205	et	2	main
surma	doc_713316236902_item	2827206	et	4	main
võimule	doc_713316236902_item	2827207	et	3	main
tuli	doc_713316236902_item	2827208	et	4	main
andropov	doc_713316236902_item	2827209	et	4	main
alkoholi	doc_713316236902_item	2827210	et	4	main
poliitikaga	doc_713316236902_item	2827211	et	3	main
tema	doc_713316236902_item	2827212	et	4	main
valitsemisaeg	doc_713316236902_item	2827213	et	3	main
oli	doc_713316236902_item	2827214	et	3	main
lühike	doc_713316236902_item	2827215	et	4	main
tema	doc_713316236902_item	2827216	et	4	main
järel	doc_713316236902_item	2827217	et	4	main
tuli	doc_713316236902_item	2827218	et	4	main
tsernenko	doc_713316236902_item	2827219	et	4	main
1985	doc_713316236902_item	2827220	et	2	main
on	doc_713316236902_item	2827227	et	4	main
2	doc_713316236902_item	2827228	et	2	main
glasnost	doc_713316236902_item	2827234	et	4	main
tõid	doc_713316236902_item	2827242	et	4	main
madalseisu	doc_713316236902_item	2827248	et	4	main
kas	doc_713316236902_item	2827252	et	3	main
käivad	doc_713316236902_item	2827258	et	4	main
seal	doc_713316236902_item	2827259	et	4	main
jätkata	doc_713316236902_item	2827262	et	4	main
1980	doc_713316236902_item	2827267	et	2	main
kirjanikud	doc_713316236902_item	2827273	et	3	main
väike	doc_713316236902_item	2827280	et	4	main
rahvaste	doc_713316236902_item	2827281	et	4	main
keeltega	doc_713316236902_item	2827282	et	3	main
vastaseks	doc_713316236902_item	2827287	et	3	main
oli	doc_713316236902_item	2827291	et	3	main
komitee	doc_713316236902_item	2827299	et	4	main
eesti	doc_713316236902_item	2827300	et	4	main
võiks	doc_713316236902_item	2827301	et	4	main
märksõna	doc_713316236902_item	2827229	et	4	main
selgus	doc_713316236902_item	2827235	et	4	main
näitas	doc_713316236902_item	2827247	et	3	main
samuti	doc_713316236902_item	2827263	et	3	main
andropovi	doc_713316236902_item	2827264	et	4	main
poliitikat	doc_713316236902_item	2827266	et	3	main
toimus	doc_713316236902_item	2827271	et	3	main
selle	doc_713316236902_item	2827274	et	4	main
teemaks	doc_713316236902_item	2827275	et	4	main
mis	doc_713316236902_item	2827277	et	4	main
saab	doc_713316236902_item	2827278	et	3	main
oli	doc_713316236902_item	2827288	et	3	main
poolne	doc_713316236902_item	2827293	et	3	main
peatumist	doc_713316236902_item	2827297	et	4	main
kodanike	doc_713316236902_item	2827298	et	3	main
välja	doc_713316236902_item	2827306	et	4	main
kuhu	doc_713316236902_item	2827308	et	3	main
võis	doc_713316236902_item	2827309	et	4	main
suveräänsusdeklaratsioon	doc_713316236902_item	2827316	et	3	main
ime	doc_713316236902_item	2827318	et	4	main
idee	doc_713316236902_item	2827319	et	4	main
eesti	doc_713316236902_item	2827320	et	4	main
võiks	doc_713316236902_item	2827321	et	4	main
iseseisvaks	doc_713316236902_item	2827323	et	3	main
korda	doc_713316236902_item	2827332	et	4	main
oli	doc_713316236902_item	2827348	et	3	main
varem	doc_713316236902_item	2827368	et	4	main
ei	doc_713316236902_item	2827369	et	4	main
olnud	doc_713316236902_item	2827370	et	4	main
oma	doc_713316236902_item	2827387	et	4	main
püütis	doc_713316236902_item	2827261	et	4	main
alkohooli	doc_713316236902_item	2827265	et	3	main
rr	doc_713316236902_item	2827283	et	4	main
massorganisatsioon	doc_713316236902_item	2827285	et	3	main
interrinne	doc_713316236902_item	2827289	et	3	main
nsvl	doc_713316236902_item	2827292	et	4	main
nõudis	doc_713316236902_item	2827294	et	3	main
annab	doc_713316236902_item	2827305	et	3	main
end	doc_713316236902_item	2827310	et	4	main
registreerida	doc_713316236902_item	2827311	et	3	main
eesti	doc_713316236902_item	2827312	et	4	main
partei	doc_713316236902_item	2827329	et	4	main
pleenum	doc_713316236902_item	2827330	et	3	main
esimesti	doc_713316236902_item	2827331	et	4	main
oma	doc_713316236902_item	2827338	et	4	main
mõni	doc_713316236902_item	2827345	et	3	main
aeg	doc_713316236902_item	2827346	et	3	main
eestis	doc_713316236902_item	2827347	et	3	main
seda	doc_713316236902_item	2827350	et	3	main
ei	doc_713316236902_item	2827355	et	4	main
vett	doc_713316236902_item	2827359	et	3	main
lõpp	doc_713316236902_item	2827377	et	3	main
rahvarevolutsioon	doc_713316236902_item	2827379	et	3	main
eestit	doc_713316236902_item	2827383	et	3	main
vabaks	doc_713316236902_item	2827389	et	3	main
valitakse	doc_713316236902_item	2827422	et	3	main
kongressi	doc_713316236902_item	2827423	et	4	main
eesti	doc_713316236902_item	2827435	et	4	main
iseseisvumist	doc_713316236902_item	2827436	et	3	main
hariduses	doc_713316236902_item	2827437	et	3	main
samuti	doc_713316236902_item	2827438	et	3	main
vahetati	doc_713316236902_item	2827443	et	4	main
nt	doc_713316236902_item	2827447	et	4	main
õppetool	doc_713316236902_item	2827449	et	3	main
gümnaasium	doc_713316236902_item	2827451	et	3	main
võis	doc_713316236902_item	2827460	et	4	main
vanad	doc_713316236902_item	2827464	et	3	main
taastati	doc_713316236902_item	2827466	et	4	main
koolid	doc_713316236902_item	2827467	et	3	main
hakati	doc_713316236902_item	2827468	et	3	main
nimetama	doc_713316236902_item	2827469	et	3	main
1990	doc_713316236902_item	2827508	et	2	main
rahval	doc_713316236902_item	2827511	et	3	main
leedus	doc_713316236902_item	2827516	et	4	main
lülitatakse	doc_713316236902_item	2827523	et	3	main
kuid	doc_713316236902_item	2827525	et	4	main
eesti	doc_713316236902_item	2827526	et	4	main
tuli	doc_713316236902_item	2827527	et	4	main
lahkusid	doc_713316236902_item	2827536	et	4	main
eestist	doc_713316236902_item	2827537	et	3	main
võivad	doc_713316236902_item	2827550	et	4	main
see	doc_713316236902_item	2827553	et	3	main
organiseeritud	doc_713316236902_item	2827556	et	4	main
inimesed	doc_713316236902_item	2827557	et	3	main
baltikumis	doc_713316236902_item	2827558	et	4	main
moodustati	doc_713316236902_item	2827565	et	3	main
kõigile	doc_713316236902_item	2827610	et	4	main
eesti	doc_713316236902_item	2827616	et	4	main
see	doc_713316236902_item	2827634	et	3	main
1	doc_713316236903_item	2827638	et	2	main
2	doc_713316236903_item	2827645	et	2	main
sündmus	doc_713316236903_item	2827647	et	3	main
balti	doc_713316236903_item	2827649	et	3	main
selle	doc_713316236903_item	2827651	et	4	main
nimetati	doc_713316236903_item	2827658	et	4	main
on	doc_713316236903_item	2827671	et	4	main
laulsid	doc_713316236903_item	2827683	et	4	main
uusi	doc_713316236903_item	2827718	et	3	main
minna	doc_713316236903_item	2827721	et	3	main
kolledž	doc_713316236903_item	2827724	et	2	main
andma	doc_713316236903_item	2827726	et	3	main
kõrgharidust	doc_713316236903_item	2827728	et	4	main
ainult	doc_713316236903_item	2827730	et	4	main
eestlased	doc_713316236903_item	2827732	et	3	main
rääkida	doc_713316236903_item	2827736	et	3	main
hakatakse	doc_713316236903_item	2827743	et	3	main
a	doc_713316236903_item	2827750	et	4	main
oli	doc_713316236903_item	2827752	et	3	main
kus	doc_713316236903_item	2827754	et	3	main
leedu	doc_713316236903_item	2827756	et	4	main
muutused	doc_713316236904_item	2827764	et	4	main
ja	doc_713316236904_item	2827765	et	3	main
muudatused	doc_713316236904_item	2827766	et	3	main
2	doc_713316236904_item	2827770	et	2	main
sündmus	doc_713316236904_item	2827772	et	3	main
kett	doc_713316236904_item	2827775	et	4	main
selle	doc_713316236904_item	2827776	et	4	main
1	doc_713316236904_item	2827782	et	2	main
kõige	doc_713316236904_item	2827814	et	4	main
mõiste	doc_713316236904_item	2827828	et	4	main
eesti	doc_713316236904_item	2827829	et	4	main
1988	doc_713316236902_item	2827325	et	2	main
eesti	doc_713316236902_item	2827327	et	4	main
kommunistlik	doc_713316236902_item	2827328	et	3	main
avalikult	doc_713316236902_item	2827335	et	4	main
suuda	doc_713316236902_item	2827342	et	4	main
heaks	doc_713316236902_item	2827352	et	4	main
kütust	doc_713316236902_item	2827357	et	4	main
80	doc_713316236902_item	2827376	et	2	main
maad	doc_713316236902_item	2827388	et	4	main
24	doc_713316236902_item	2827391	et	2	main
veebruar	doc_713316236902_item	2827392	et	3	main
eesti	doc_713316236902_item	2827393	et	4	main
iseseisvuspäev	doc_713316236902_item	2827394	et	3	main
peatakse	doc_713316236902_item	2827395	et	3	main
peod	doc_713316236902_item	2827396	et	4	main
mis	doc_713316236902_item	2827397	et	4	main
nsvl-s	doc_713316236902_item	2827398	et	3	main
ei	doc_713316236902_item	2827399	et	4	main
soovitavad	doc_713316236902_item	2827401	et	4	main
olnud	doc_713316236902_item	2827400	et	4	main
ilmub	doc_713316236902_item	2827402	et	3	main
folklooriorganisatsioon	doc_713316236902_item	2827403	et	3	main
1990	doc_713316236902_item	2827404	et	2	main
aa	doc_713316236902_item	2827405	et	3	main
venemaal	doc_713316236902_item	2827406	et	4	main
võimule	doc_713316236902_item	2827407	et	3	main
tuleb	doc_713316236902_item	2827408	et	3	main
jeltsin	doc_713316236902_item	2827409	et	4	main
kinnitab	doc_713316236902_item	2827410	et	3	main
veel	doc_713316236902_item	2827411	et	4	main
kord	doc_713316236902_item	2827412	et	4	main
eesti	doc_713316236902_item	2827413	et	4	main
iseseisvumist	doc_713316236902_item	2827414	et	3	main
ev	doc_713316236902_item	2827415	et	4	main
nimetus	doc_713316236902_item	2827416	et	4	main
kasutusele	doc_713316236902_item	2827418	et	4	main
ilmub	doc_713316236902_item	2827419	et	3	main
jälle	doc_713316236902_item	2827417	et	3	main
eesti	doc_713316236902_item	2827420	et	4	main
muutused	doc_713316236902_item	2827440	et	4	main
teaduskonnas	doc_713316236902_item	2827454	et	4	main
ja	doc_713316236902_item	2827455	et	3	main
õppimissuunad	doc_713316236902_item	2827456	et	3	main
ilmus	doc_713316236902_item	2827457	et	4	main
kolledž	doc_713316236902_item	2827458	et	2	main
uut	doc_713316236902_item	2827462	et	3	main
vaja	doc_713316236902_item	2827500	et	4	main
lapsi	doc_713316236902_item	2827501	et	4	main
hirm	doc_713316236902_item	2827513	et	3	main
elekter	doc_713316236902_item	2827522	et	3	main
leidis	doc_713316236902_item	2827542	et	4	main
1990	doc_713316236902_item	2827544	et	2	main
pensionisüsteem	doc_713316236902_item	2827367	et	3	main
hakkas	doc_713316236902_item	2827374	et	3	main
laulupidu	doc_713316236902_item	2827378	et	4	main
gorbatšov	doc_713316236902_item	2827381	et	2	main
rahvas	doc_713316236902_item	2827385	et	4	main
laulis	doc_713316236902_item	2827386	et	4	main
kroon	doc_713316236902_item	2827421	et	3	main
e	doc_713316236902_item	2827424	et	4	main
savisaar	doc_713316236902_item	2827425	et	3	main
aasta	doc_713316236902_item	2827426	et	4	main
hiljem	doc_713316236902_item	2827427	et	3	main
valitakse	doc_713316236902_item	2827428	et	3	main
riigikogu	doc_713316236902_item	2827429	et	4	main
ja	doc_713316236902_item	2827430	et	3	main
toimuvad	doc_713316236902_item	2827439	et	4	main
ehk	doc_713316236902_item	2827444	et	3	main
taastati	doc_713316236902_item	2827452	et	4	main
mõned	doc_713316236902_item	2827453	et	3	main
saada	doc_713316236902_item	2827461	et	4	main
rakendusliku	doc_713316236902_item	2827494	et	3	main
pandi	doc_713316236902_item	2827502	et	4	main
juba	doc_713316236902_item	2827503	et	3	main
algkoolidest	doc_713316236902_item	2827504	et	3	main
algus	doc_713316236902_item	2827509	et	4	main
oli	doc_713316236902_item	2827512	et	3	main
presidenti	doc_713316236902_item	2827431	et	4	main
l	doc_713316236902_item	2827432	et	4	main
meri	doc_713316236902_item	2827433	et	3	main
kõrgkooli	doc_713316236902_item	2827441	et	4	main
süsteemi	doc_713316236902_item	2827442	et	4	main
toimus	doc_713316236902_item	2827446	et	3	main
kateeder	doc_713316236902_item	2827448	et	3	main
millegi	doc_713316236902_item	2827470	et	4	main
järgi	doc_713316236902_item	2827471	et	4	main
enam	doc_713316236902_item	2827472	et	4	main
ei	doc_713316236902_item	2827473	et	4	main
pandud	doc_713316236902_item	2827474	et	4	main
numbrid	doc_713316236902_item	2827475	et	3	main
kadusid	doc_713316236902_item	2827476	et	4	main
erivärvi	doc_713316236902_item	2827477	et	4	main
kõrgkooli	doc_713316236902_item	2827478	et	4	main
mütsid	doc_713316236902_item	2827479	et	3	main
eesti	doc_713316236902_item	2827480	et	4	main
keelt	doc_713316236902_item	2827481	et	4	main
hakati	doc_713316236902_item	2827482	et	3	main
õpetama	doc_713316236902_item	2827483	et	3	main
ka	doc_713316236902_item	2827484	et	3	main
teistele	doc_713316236902_item	2827485	et	4	main
rahvastele	doc_713316236902_item	2827486	et	4	main
kuid	doc_713316236902_item	2827487	et	4	main
nsvl	doc_713316236902_item	2827488	et	4	main
ajal	doc_713316236902_item	2827489	et	4	main
eesti	doc_713316236902_item	2827490	et	4	main
keelel	doc_713316236902_item	2827491	et	4	main
ei	doc_713316236902_item	2827492	et	4	main
olnud	doc_713316236902_item	2827493	et	4	main
elus	doc_713316236902_item	2827499	et	4	main
keelt	doc_713316236902_item	2827506	et	4	main
õppima	doc_713316236902_item	2827507	et	3	main
eesti	doc_713316236902_item	2827510	et	4	main
lätis	doc_713316236902_item	2827514	et	4	main
1994	doc_713316236902_item	2827534	et	2	main
aastal	doc_713316236902_item	2827535	et	3	main
2	doc_713316236902_item	2827538	et	2	main
balti	doc_713316236902_item	2827539	et	3	main
kett	doc_713316236902_item	2827540	et	4	main
see	doc_713316236902_item	2827541	et	3	main
tundsid	doc_713316236902_item	2827548	et	4	main
saada	doc_713316236902_item	2827551	et	4	main
rahvaga	doc_713316236902_item	2827555	et	3	main
nagu	doc_713316236902_item	2827566	et	3	main
2-3	doc_713316236902_item	2827570	et	2	main
miljonit	doc_713316236902_item	2827571	et	3	main
see	doc_713316236902_item	2827572	et	3	main
kett	doc_713316236902_item	2827573	et	4	main
väikesed	doc_713316236902_item	2827612	et	4	main
laul	doc_713316236902_item	2827617	et	4	main
momendil	doc_713316236902_item	2827622	et	3	main
oli	doc_713316236902_item	2827625	et	3	main
ainult	doc_713316236902_item	2827626	et	4	main
kord	doc_713316236902_item	2827628	et	4	main
ja	doc_713316236902_item	2827629	et	3	main
ajalukku	doc_713316236902_item	2827636	et	4	main
kultuurielus	doc_713316236903_item	2827644	et	4	main
oli	doc_713316236903_item	2827648	et	3	main
kett	doc_713316236903_item	2827650	et	4	main
tähendus	doc_713316236903_item	2827652	et	4	main
koole	doc_713316236903_item	2827659	et	4	main
ümber	doc_713316236903_item	2827660	et	3	main
olnud	doc_713316236903_item	2827663	et	4	main
enam	doc_713316236903_item	2827664	et	4	main
koolivorme	doc_713316236903_item	2827665	et	3	main
eestis	doc_713316236903_item	2827666	et	3	main
hakkatakse	doc_713316236903_item	2827667	et	4	main
tegema	doc_713316236903_item	2827668	et	3	main
mobiiltelefone	doc_713316236903_item	2827669	et	3	main
kohal	doc_713316236903_item	2827681	et	4	main
ja	doc_713316236903_item	2827682	et	3	main
hakkab	doc_713316236903_item	2827725	et	3	main
armastavad	doc_713316236903_item	2827733	et	4	main
tõuseb	doc_713316236903_item	2827737	et	3	main
balti	doc_713316236903_item	2827746	et	3	main
eesti	doc_713316236903_item	2827758	et	4	main
see	doc_713316236903_item	2827759	et	3	main
tähendas	doc_713316236903_item	2827760	et	3	main
piiriprobleemi	doc_713316236903_item	2827761	et	4	main
kultuurielus	doc_713316236904_item	2827769	et	4	main
mis	doc_713316236904_item	2827771	et	4	main
sündmused	doc_713316236904_item	2827822	et	3	main
tartu	doc_713316236904_item	2827837	et	4	main
kolledž	doc_713316236904_item	2827849	et	2	main
see	doc_713316236904_item	2827854	et	3	main
tasulistes	doc_713316236904_item	2827860	et	4	main
mõned	doc_713316236904_item	2827862	et	3	main
õpetamisesüsteem	doc_713316236904_item	2827868	et	4	main
õpilaste	doc_713316236904_item	2827872	et	4	main
teiste	doc_713316236904_item	2827874	et	4	main
hakkasid	doc_713316236904_item	2827876	et	4	main
taas	doc_713316236904_item	2827877	et	3	main
tegutsema	doc_713316236904_item	2827878	et	3	main
hakkab	doc_713316236904_item	2827882	et	3	main
eestlastega	doc_713316236904_item	2827889	et	4	main
on	doc_713316236904_item	2827891	et	4	main
kultuuri	doc_713316236904_item	2827900	et	4	main
siberisse	doc_713316236904_item	2827922	et	4	main
ja	doc_713316236904_item	2827923	et	3	main
läände	doc_713316236904_item	2827925	et	3	main
et	doc_713316236904_item	2827945	et	3	main
mõiste	doc_713316236904_item	2827949	et	4	main
uued	doc_713316236904_item	2827958	et	3	main
n	doc_713316236904_item	2827960	et	4	main
kokkuvõtteks	doc_713316236904_item	2827965	et	3	main
öelda	doc_713316236904_item	2827967	et	4	main
et	doc_713316236904_item	2827968	et	3	main
inimeste	doc_713316236904_item	2827969	et	3	main
elu	doc_713316236904_item	2827970	et	4	main
ja	doc_713316236904_item	2827999	et	3	main
vene	doc_713316236902_item	2827505	et	4	main
ja	doc_713316236902_item	2827515	et	3	main
olid	doc_713316236902_item	2827517	et	4	main
vene	doc_713316236902_item	2827518	et	4	main
sõjaväed	doc_713316236902_item	2827519	et	3	main
kardeti	doc_713316236902_item	2827520	et	3	main
välja	doc_713316236902_item	2827524	et	4	main
aset	doc_713316236902_item	2827543	et	3	main
et	doc_713316236902_item	2827549	et	3	main
iseseisvateks	doc_713316236902_item	2827552	et	3	main
võtsid	doc_713316236902_item	2827559	et	4	main
teine	doc_713316236902_item	2827560	et	3	main
baltikumi	doc_713316236902_item	2827576	et	4	main
ja	doc_713316236902_item	2827604	et	3	main
ning	doc_713316236902_item	2827606	et	3	main
nad	doc_713316236902_item	2827608	et	3	main
balti	doc_713316236902_item	2827614	et	3	main
kett	doc_713316236902_item	2827615	et	4	main
et	doc_713316236902_item	2827521	et	3	main
veretult	doc_713316236902_item	2827528	et	4	main
välja	doc_713316236902_item	2827529	et	4	main
oma	doc_713316236902_item	2827530	et	4	main
iseseisvumisteele	doc_713316236902_item	2827531	et	3	main
võõrad	doc_713316236902_item	2827532	et	3	main
sõjaväed	doc_713316236902_item	2827533	et	3	main
inimesed	doc_713316236902_item	2827547	et	3	main
oli	doc_713316236902_item	2827554	et	3	main
käest	doc_713316236902_item	2827562	et	4	main
kinni	doc_713316236902_item	2827563	et	3	main
ja	doc_713316236902_item	2827564	et	3	main
selles	doc_713316236902_item	2827568	et	4	main
arvan	doc_713316236902_item	2827577	et	3	main
et	doc_713316236902_item	2827578	et	3	main
rahvas	doc_713316236902_item	2827579	et	4	main
sellega	doc_713316236902_item	2827580	et	3	main
tõestas	doc_713316236902_item	2827581	et	3	main
maailmale	doc_713316236902_item	2827582	et	4	main
oma	doc_713316236902_item	2827583	et	4	main
püsivust	doc_713316236902_item	2827584	et	4	main
soovi	doc_713316236902_item	2827585	et	4	main
ja	doc_713316236902_item	2827586	et	3	main
võimet	doc_713316236902_item	2827587	et	3	main
saada	doc_713316236902_item	2827588	et	4	main
iseseisvaks	doc_713316236902_item	2827589	et	3	main
ja	doc_713316236902_item	2827590	et	3	main
eelkõige	doc_713316236902_item	2827591	et	3	main
see	doc_713316236902_item	2827592	et	3	main
oli	doc_713316236902_item	2827593	et	3	main
tähti	doc_713316236902_item	2827594	et	4	main
nendele	doc_713316236902_item	2827595	et	4	main
endale	doc_713316236902_item	2827596	et	4	main
nad	doc_713316236902_item	2827597	et	3	main
said	doc_713316236902_item	2827598	et	4	main
aru	doc_713316236902_item	2827599	et	4	main
et	doc_713316236902_item	2827600	et	3	main
neid	doc_713316236902_item	2827601	et	4	main
aa	doc_713316236902_item	2827545	et	3	main
algul	doc_713316236902_item	2827546	et	4	main
teist	doc_713316236902_item	2827561	et	4	main
ketti	doc_713316236902_item	2827567	et	4	main
osalesid	doc_713316236902_item	2827569	et	4	main
ulatus	doc_713316236902_item	2827574	et	4	main
üle	doc_713316236902_item	2827575	et	3	main
ühtsustunne	doc_713316236902_item	2827603	et	3	main
mängisid	doc_713316236902_item	2827618	et	4	main
suurt	doc_713316236902_item	2827619	et	3	main
mis	doc_713316236903_item	2827646	et	4	main
rahavstele	doc_713316236903_item	2827654	et	4	main
ja	doc_713316236903_item	2827655	et	3	main
maailmale	doc_713316236903_item	2827656	et	4	main
1	doc_713316236903_item	2827657	et	2	main
ei	doc_713316236903_item	2827662	et	4	main
palju	doc_713316236903_item	2827672	et	4	main
a	doc_713316236903_item	2827675	et	4	main
eesti	doc_713316236903_item	2827684	et	4	main
loenguid	doc_713316236903_item	2827719	et	4	main
tahetakse	doc_713316236903_item	2827720	et	4	main
süsteemile	doc_713316236903_item	2827722	et	3	main
väga	doc_713316236903_item	2827734	et	3	main
arutlema	doc_713316236903_item	2827744	et	3	main
1989	doc_713316236903_item	2827749	et	2	main
see	doc_713316236903_item	2827751	et	3	main
sündmus	doc_713316236903_item	2827753	et	3	main
ühenesid	doc_713316236903_item	2827755	et	4	main
ja	doc_713316236903_item	2827757	et	3	main
tähendus	doc_713316236904_item	2827777	et	4	main
rohkem	doc_713316236904_item	2827815	et	4	main
mõju	doc_713316236904_item	2827816	et	4	main
avaldab	doc_713316236904_item	2827817	et	3	main
keskkond	doc_713316236904_item	2827818	et	3	main
ja	doc_713316236904_item	2827819	et	3	main
ümber	doc_713316236904_item	2827820	et	3	main
keel	doc_713316236904_item	2827827	et	4	main
nimetati	doc_713316236904_item	2827835	et	4	main
ümber	doc_713316236904_item	2827836	et	3	main
tallinna	doc_713316236904_item	2827842	et	4	main
mõiste	doc_713316236904_item	2827848	et	4	main
tänapäeval	doc_713316236904_item	2827852	et	3	main
usuteadus	doc_713316236904_item	2827865	et	4	main
n	doc_713316236904_item	2827869	et	4	main
ões	doc_713316236904_item	2827879	et	4	main
tegutsema	doc_713316236904_item	2827881	et	3	main
eesti	doc_713316236904_item	2827895	et	4	main
saavad	doc_713316236904_item	2827928	et	4	main
paljud	doc_713316236904_item	2827929	et	3	main
euroopa	doc_713316236904_item	2827930	et	4	main
teame	doc_713316236904_item	2827944	et	3	main
eesti	doc_713316236904_item	2827955	et	4	main
rahvale	doc_713316236904_item	2827956	et	3	main
jne	doc_713316236904_item	2827964	et	4	main
pärast	doc_713316236904_item	2827973	et	4	main
mina	doc_713316236904_item	2828000	et	4	main
hakkasin	doc_713316236904_item	2828002	et	3	main
kuidagi	doc_713316236904_item	2828005	et	3	main
siis	doc_713316236904_item	2828018	et	3	main
küll	doc_713316236904_item	2828021	et	4	main
seega	doc_713316236904_item	2828023	et	4	main
suurim	doc_713316236904_item	2828024	et	3	main
esimest	doc_713316236904_item	2828032	et	4	main
ostis	doc_713316236904_item	2828042	et	4	main
ei	doc_713316236904_item	2828049	et	4	main
olnud	doc_713316236904_item	2828050	et	4	main
iseseisev	doc_713316236904_item	2828051	et	3	main
on	doc_713316236904_item	2828066	et	4	main
suured	doc_713316236904_item	2828067	et	3	main
aga	doc_713316236904_item	2828068	et	3	main
peamine	doc_713316236904_item	2828069	et	3	main
vabadena	doc_713316236904_item	2828075	et	3	main
neid	doc_713316236904_item	2828077	et	4	main
ei	doc_713316236904_item	2828078	et	4	main
2	doc_713316236904_item	2828083	et	2	main
balti	doc_713316236904_item	2828084	et	3	main
kett	doc_713316236904_item	2828085	et	4	main
oli	doc_713316236904_item	2828086	et	3	main
1989	doc_713316236904_item	2828089	et	2	main
koosnev	doc_713316236904_item	2828100	et	4	main
kett	doc_713316236904_item	2828101	et	4	main
läti	doc_713316236904_item	2828123	et	4	main
seob	doc_713316236902_item	2827602	et	3	main
toetus	doc_713316236902_item	2827605	et	4	main
seda	doc_713316236902_item	2827607	et	3	main
demonstreerisid	doc_713316236902_item	2827609	et	4	main
need	doc_713316236902_item	2827611	et	3	main
rahvapüüed	doc_713316236902_item	2827613	et	4	main
rolli	doc_713316236902_item	2827620	et	4	main
teatud	doc_713316236902_item	2827621	et	4	main
see	doc_713316236902_item	2827623	et	3	main
hetk	doc_713316236902_item	2827624	et	3	main
jääb	doc_713316236902_item	2827635	et	3	main
muutused	doc_713316236903_item	2827639	et	4	main
ja	doc_713316236903_item	2827640	et	3	main
muudatused	doc_713316236903_item	2827641	et	3	main
taasiseseisvunud	doc_713316236903_item	2827642	et	4	main
baltikumi	doc_713316236903_item	2827653	et	4	main
koolis	doc_713316236903_item	2827661	et	4	main
1989	doc_713316236903_item	2827674	et	2	main
toimus	doc_713316236903_item	2827676	et	3	main
1	doc_713316236902_item	2827627	et	2	main
rahvas	doc_713316236902_item	2827630	et	4	main
kasutas	doc_713316236902_item	2827631	et	3	main
seda	doc_713316236902_item	2827632	et	3	main
ning	doc_713316236902_item	2827633	et	3	main
kontrolltöö	doc_713316236903_item	2827637	et	4	main
eesti	doc_713316236903_item	2827643	et	4	main
televisioon	doc_713316236903_item	2827670	et	4	main
parem	doc_713316236903_item	2827673	et	4	main
rahvalaul	doc_713316236903_item	2827677	et	4	main
paljud	doc_713316236903_item	2827678	et	3	main
eestlased	doc_713316236903_item	2827679	et	3	main
olid	doc_713316236903_item	2827680	et	4	main
rahvalaule	doc_713316236903_item	2827685	et	4	main
1992	doc_713316236903_item	2827686	et	2	main
a	doc_713316236903_item	2827687	et	4	main
tuleb	doc_713316236903_item	2827688	et	3	main
eestisse	doc_713316236903_item	2827689	et	4	main
kroon	doc_713316236903_item	2827690	et	3	main
ja	doc_713316236903_item	2827691	et	3	main
samal	doc_713316236903_item	2827692	et	3	main
aastal	doc_713316236903_item	2827693	et	3	main
tõuseb	doc_713316236903_item	2827694	et	3	main
eesti	doc_713316236903_item	2827696	et	4	main
küsimus	doc_713316236903_item	2827695	et	4	main
minevikuks	doc_713316236903_item	2827697	et	3	main
euroopa	doc_713316236903_item	2827698	et	4	main
liitu	doc_713316236903_item	2827699	et	4	main
1992	doc_713316236903_item	2827700	et	2	main
a	doc_713316236903_item	2827701	et	4	main
valitakse	doc_713316236903_item	2827702	et	3	main
esimene	doc_713316236903_item	2827703	et	3	main
eesti	doc_713316236903_item	2827704	et	4	main
president	doc_713316236903_item	2827705	et	3	main
lennart	doc_713316236903_item	2827706	et	4	main
meri	doc_713316236903_item	2827707	et	3	main
ja	doc_713316236903_item	2827708	et	3	main
riigikogu	doc_713316236903_item	2827709	et	4	main
kus	doc_713316236903_item	2827710	et	3	main
olid	doc_713316236903_item	2827711	et	4	main
101	doc_713316236903_item	2827712	et	2	main
pärnapikme	doc_713316236903_item	2827713	et	4	main
tartu	doc_713316236903_item	2827714	et	4	main
ülikoolis	doc_713316236903_item	2827715	et	4	main
hakkatakse	doc_713316236903_item	2827716	et	4	main
lugema	doc_713316236903_item	2827717	et	4	main
ka	doc_713316236903_item	2827727	et	3	main
mitte	doc_713316236903_item	2827729	et	3	main
ülikoolid	doc_713316236903_item	2827731	et	3	main
palju	doc_713316236903_item	2827735	et	4	main
on	doc_713316236903_item	2827740	et	4	main
toimus	doc_713316236903_item	2827748	et	3	main
taasiseseisvunud	doc_713316236904_item	2827767	et	4	main
baltikumi	doc_713316236904_item	2827778	et	4	main
sest	doc_713316236904_item	2827812	et	4	main
kunstile	doc_713316236904_item	2827813	et	3	main
toimuvad	doc_713316236904_item	2827821	et	4	main
kõigepealt	doc_713316236904_item	2827823	et	3	main
sai	doc_713316236904_item	2827825	et	4	main
eesti	doc_713316236904_item	2827826	et	4	main
ülikooliks	doc_713316236904_item	2827841	et	4	main
koolivorm	doc_713316236904_item	2827851	et	3	main
seega	doc_713316236904_item	2827853	et	4	main
on	doc_713316236904_item	2827855	et	4	main
ainult	doc_713316236904_item	2827856	et	4	main
mõnedes	doc_713316236904_item	2827857	et	3	main
tü	doc_713316236904_item	2827866	et	4	main
reorganiseeriti	doc_713316236904_item	2827867	et	3	main
õppetool	doc_713316236904_item	2827871	et	3	main
venemaa	doc_713316236904_item	2827888	et	4	main
õnneks	doc_713316236904_item	2827897	et	4	main
ja	doc_713316236904_item	2827898	et	3	main
ka	doc_713316236904_item	2827899	et	3	main
32	doc_713316236903_item	2827723	et	2	main
küsimus	doc_713316236903_item	2827738	et	4	main
mis	doc_713316236903_item	2827739	et	4	main
keel	doc_713316236903_item	2827741	et	4	main
seda	doc_713316236903_item	2827742	et	3	main
2	doc_713316236903_item	2827745	et	2	main
kett	doc_713316236903_item	2827747	et	4	main
kontrolltöö	doc_713316236904_item	2827762	et	4	main
1	doc_713316236904_item	2827763	et	2	main
eesti	doc_713316236904_item	2827768	et	4	main
oli	doc_713316236904_item	2827773	et	3	main
balti	doc_713316236904_item	2827774	et	3	main
rahavstele	doc_713316236904_item	2827779	et	4	main
ja	doc_713316236904_item	2827780	et	3	main
maailmale	doc_713316236904_item	2827781	et	4	main
pärast	doc_713316236904_item	2827783	et	4	main
kui	doc_713316236904_item	2827784	et	3	main
eesti	doc_713316236904_item	2827785	et	4	main
sai	doc_713316236904_item	2827786	et	4	main
taasiseseisvus	doc_713316236904_item	2827787	et	4	main
toimusid	doc_713316236904_item	2827788	et	4	main
muutused	doc_713316236904_item	2827789	et	4	main
mitte	doc_713316236904_item	2827790	et	3	main
ainult	doc_713316236904_item	2827791	et	4	main
poliitilises	doc_713316236904_item	2827792	et	3	main
elus	doc_713316236904_item	2827793	et	4	main
vaid	doc_713316236904_item	2827794	et	3	main
ka	doc_713316236904_item	2827795	et	3	main
kultuurielus	doc_713316236904_item	2827796	et	4	main
olid	doc_713316236904_item	2827797	et	4	main
mitte	doc_713316236904_item	2827798	et	3	main
ainult	doc_713316236904_item	2827799	et	4	main
muutused	doc_713316236904_item	2827800	et	4	main
vaid	doc_713316236904_item	2827801	et	3	main
ka	doc_713316236904_item	2827802	et	3	main
muudatused	doc_713316236904_item	2827803	et	3	main
see	doc_713316236904_item	2827804	et	3	main
kõik	doc_713316236904_item	2827805	et	4	main
puudutas	doc_713316236904_item	2827806	et	3	main
haridust	doc_713316236904_item	2827807	et	4	main
elu	doc_713316236904_item	2827808	et	4	main
valdkondi	doc_713316236904_item	2827810	et	4	main
erinevaid	doc_713316236904_item	2827809	et	4	main
kunsti	doc_713316236904_item	2827811	et	4	main
riigikeeleks	doc_713316236904_item	2827824	et	4	main
kodanik	doc_713316236904_item	2827830	et	3	main
sai	doc_713316236904_item	2827831	et	4	main
ka	doc_713316236904_item	2827832	et	3	main
väga	doc_713316236904_item	2827833	et	3	main
oluliseks	doc_713316236904_item	2827834	et	4	main
tartu	doc_713316236904_item	2827840	et	4	main
kaotati	doc_713316236904_item	2827850	et	3	main
tavaliselt	doc_713316236904_item	2827859	et	4	main
õpetamissuunad	doc_713316236904_item	2827863	et	4	main
n	doc_713316236904_item	2827864	et	4	main
vahetused	doc_713316236904_item	2827873	et	4	main
riikidega	doc_713316236904_item	2827875	et	3	main
ars	doc_713316236904_item	2827880	et	4	main
üliõpilaste	doc_713316236904_item	2827883	et	4	main
selts	doc_713316236904_item	2827884	et	3	main
veljesto	doc_713316236904_item	2827885	et	4	main
keelt	doc_713316236904_item	2827896	et	4	main
mõnedes	doc_713316236904_item	2827902	et	3	main
ülikoolides	doc_713316236904_item	2827903	et	3	main
venemaal	doc_713316236904_item	2827904	et	4	main
edasi	doc_713316236904_item	2827905	et	3	main
tsensuur	doc_713316236904_item	2827906	et	3	main
kaob	doc_713316236904_item	2827907	et	3	main
mis	doc_713316236904_item	2827908	et	4	main
on	doc_713316236904_item	2827909	et	4	main
väga	doc_713316236904_item	2827910	et	3	main
tähtis	doc_713316236904_item	2827911	et	4	main
ja	doc_713316236904_item	2827913	et	3	main
üldse	doc_713316236904_item	2827914	et	3	main
inimeste	doc_713316236904_item	2827915	et	3	main
jaoks	doc_713316236904_item	2827916	et	4	main
kirjanike	doc_713316236904_item	2827912	et	3	main
tulevad	doc_713316236904_item	2827917	et	4	main
tagasi	doc_713316236904_item	2827918	et	3	main
paljud	doc_713316236904_item	2827919	et	3	main
välja	doc_713316236904_item	2827920	et	4	main
saadetud	doc_713316236904_item	2827921	et	4	main
põgenenud	doc_713316236904_item	2827924	et	4	main
eestlased	doc_713316236904_item	2827926	et	3	main
kättesaadavaks	doc_713316236904_item	2827927	et	4	main
oluline	doc_713316236904_item	2827937	et	4	main
siinse	doc_713316236904_item	2827938	et	3	main
rahva	doc_713316236904_item	2827939	et	3	main
jaoks	doc_713316236904_item	2827940	et	4	main
kuna	doc_713316236904_item	2827941	et	3	main
on	doc_713316236904_item	2827946	et	4	main
niisugune	doc_713316236904_item	2827948	et	3	main
nagu	doc_713316236904_item	2827950	et	3	main
nipernaadlikkus	doc_713316236904_item	2827951	et	4	main
mis	doc_713316236904_item	2827952	et	4	main
palju	doc_713316236904_item	2827972	et	4	main
isiklukult	doc_713316236904_item	2828001	et	3	main
laps	doc_713316236904_item	2828017	et	4	main
endale	doc_713316236904_item	2828031	et	4	main
ajal	doc_713316236904_item	2828039	et	4	main
palju	doc_713316236904_item	2828059	et	4	main
ja	doc_713316236904_item	2828060	et	3	main
tihti	doc_713316236904_item	2828061	et	3	main
võrdlen	doc_713316236904_item	2828062	et	3	main
et	doc_713316236904_item	2828071	et	3	main
tunnevad	doc_713316236904_item	2828073	et	3	main
riiklik	doc_713316236904_item	2827838	et	3	main
ülikool	doc_713316236904_item	2827839	et	4	main
pedagoogika	doc_713316236904_item	2827843	et	4	main
instituut	doc_713316236904_item	2827844	et	3	main
tallinna	doc_713316236904_item	2827845	et	4	main
pedagoogikaülikool	doc_713316236904_item	2827846	et	4	main
tekkis	doc_713316236904_item	2827847	et	3	main
koolides	doc_713316236904_item	2827858	et	3	main
taastati	doc_713316236904_item	2827861	et	4	main
kateeder	doc_713316236904_item	2827870	et	3	main
katkevad	doc_713316236904_item	2827886	et	4	main
sidemed	doc_713316236904_item	2827887	et	3	main
mis	doc_713316236904_item	2827890	et	4	main
väga	doc_713316236904_item	2827892	et	3	main
kurb	doc_713316236904_item	2827893	et	3	main
kuid	doc_713316236904_item	2827894	et	4	main
õpetatakse	doc_713316236904_item	2827901	et	3	main
me	doc_713316236904_item	2827942	et	4	main
ju	doc_713316236904_item	2827943	et	3	main
olemas	doc_713316236904_item	2827947	et	4	main
tekivad	doc_713316236904_item	2827957	et	3	main
ametid	doc_713316236904_item	2827959	et	3	main
sotsaiilpsühholoog	doc_713316236904_item	2827961	et	4	main
igasugused	doc_713316236904_item	2827962	et	3	main
valik	doc_713316236904_item	2827998	et	3	main
ennast	doc_713316236904_item	2828003	et	4	main
eurooplastena	doc_713316236904_item	2828006	et	3	main
huvitasid	doc_713316236904_item	2828020	et	4	main
mänguasjad	doc_713316236904_item	2828022	et	3	main
mälestus	doc_713316236904_item	2828025	et	4	main
on	doc_713316236904_item	2828026	et	4	main
see	doc_713316236904_item	2828027	et	3	main
kuidas	doc_713316236904_item	2828028	et	3	main
ma	doc_713316236904_item	2828029	et	3	main
valisin	doc_713316236904_item	2828030	et	3	main
kes	doc_713316236904_item	2828037	et	4	main
tol	doc_713316236904_item	2828038	et	3	main
teda	doc_713316236904_item	2828043	et	4	main
see	doc_713316236904_item	2828045	et	3	main
eesti	doc_713316236904_item	2828048	et	4	main
ole	doc_713316236904_item	2828053	et	4	main
kauge	doc_713316236904_item	2828054	et	4	main
minevik	doc_713316236904_item	2828055	et	3	main
seega	doc_713316236904_item	2828056	et	4	main
ma	doc_713316236904_item	2828057	et	3	main
mäletan	doc_713316236904_item	2828058	et	3	main
asi	doc_713316236904_item	2828070	et	4	main
ennast	doc_713316236904_item	2828074	et	4	main
aastal	doc_713316236904_item	2828090	et	3	main
kanalid	doc_713316236904_item	2827931	et	3	main
võimalus	doc_713316236904_item	2827932	et	3	main
reisida	doc_713316236904_item	2827933	et	3	main
on	doc_713316236904_item	2827934	et	4	main
ka	doc_713316236904_item	2827935	et	3	main
väga	doc_713316236904_item	2827936	et	3	main
on	doc_713316236904_item	2827953	et	4	main
omane	doc_713316236904_item	2827954	et	3	main
mänadzerid	doc_713316236904_item	2827963	et	4	main
võib	doc_713316236904_item	2827966	et	3	main
muutus	doc_713316236904_item	2827971	et	4	main
taasiseseisvumist	doc_713316236904_item	2827974	et	3	main
mina	doc_713316236904_item	2827975	et	4	main
ise	doc_713316236904_item	2827976	et	4	main
seda	doc_713316236904_item	2827977	et	3	main
aega	doc_713316236904_item	2827978	et	4	main
mäletan	doc_713316236904_item	2827979	et	3	main
kõige	doc_713316236904_item	2827980	et	4	main
rohkem	doc_713316236904_item	2827981	et	4	main
minu	doc_713316236904_item	2827982	et	3	main
mälus	doc_713316236904_item	2827983	et	4	main
on	doc_713316236904_item	2827984	et	4	main
sailitanud	doc_713316236904_item	2827985	et	4	main
see	doc_713316236904_item	2827986	et	3	main
et	doc_713316236904_item	2827987	et	3	main
pärast	doc_713316236904_item	2827988	et	4	main
perestroika	doc_713316236904_item	2827989	et	4	main
ajal	doc_713316236904_item	2827990	et	4	main
olnud	doc_713316236904_item	2827991	et	4	main
toidu	doc_713316236904_item	2827992	et	3	main
puudust	doc_713316236904_item	2827993	et	4	main
defitsiit	doc_713316236904_item	2827994	et	3	main
kauplustes	doc_713316236904_item	2827995	et	4	main
oli	doc_713316236904_item	2827996	et	3	main
suur	doc_713316236904_item	2827997	et	3	main
tundma	doc_713316236904_item	2828004	et	3	main
kauplustes	doc_713316236904_item	2828007	et	4	main
olid	doc_713316236904_item	2828008	et	4	main
uued	doc_713316236904_item	2828009	et	3	main
ilusad	doc_713316236904_item	2828010	et	3	main
kaubad	doc_713316236904_item	2828011	et	3	main
kuna	doc_713316236904_item	2828012	et	3	main
ma	doc_713316236904_item	2828013	et	3	main
olin	doc_713316236904_item	2828014	et	3	main
tol	doc_713316236904_item	2828015	et	3	main
mind	doc_713316236904_item	2828019	et	4	main
barbie	doc_713316236904_item	2828033	et	4	main
ja	doc_713316236904_item	2828034	et	3	main
mu	doc_713316236904_item	2828035	et	3	main
onu	doc_713316236904_item	2828036	et	4	main
meremees	doc_713316236904_item	2828041	et	4	main
aeg	doc_713316236904_item	2828046	et	3	main
ei	doc_713316236904_item	2828052	et	4	main
ega	doc_713316236904_item	2828080	et	3	main
keela	doc_713316236904_item	2828081	et	4	main
sellest	doc_713316236904_item	2828091	et	4	main
sai	doc_713316236904_item	2828092	et	4	main
läbi	doc_713316236904_item	2828102	et	4	main
olnud	doc_713316236904_item	2828136	et	4	main
vastavalt	doc_713316236904_item	2828150	et	4	main
tartu	doc_713316236904_item	2828151	et	4	main
tagused	doc_713316236904_item	2828157	et	3	main
kuuluv	doc_713316236904_item	2828161	et	4	main
kuuluvaks	doc_713316236904_item	2828168	et	4	main
eesti	doc_713316236904_item	2828181	et	4	main
ja	doc_713316236904_item	2828182	et	3	main
balti	doc_713316236904_item	2828187	et	3	main
oli	doc_713316236904_item	2828189	et	3	main
tähtis	doc_713316236904_item	2828191	et	4	main
eesti	doc_713316236904_item	2828192	et	4	main
taasiseseisvumisel	doc_713316236904_item	2828193	et	3	main
kontrolltöö	doc_713316236905_item	2828211	et	4	main
1	doc_713316236905_item	2828212	et	2	main
mis	doc_713316236905_item	2828220	et	4	main
ajal	doc_713316236904_item	2828016	et	4	main
oli	doc_713316236904_item	2828040	et	3	main
mulle	doc_713316236904_item	2828044	et	4	main
millal	doc_713316236904_item	2828047	et	3	main
muutused	doc_713316236904_item	2828063	et	4	main
ja	doc_713316236904_item	2828064	et	3	main
muudatused	doc_713316236904_item	2828065	et	3	main
inimesed	doc_713316236904_item	2828072	et	3	main
jälgi	doc_713316236904_item	2828079	et	4	main
midagi	doc_713316236904_item	2828082	et	4	main
23	doc_713316236904_item	2828087	et	2	main
augustil	doc_713316236904_item	2828088	et	3	main
kuulda	doc_713316236904_item	2828093	et	4	main
terve	doc_713316236904_item	2828094	et	4	main
maailm	doc_713316236904_item	2828095	et	3	main
eesti	doc_713316236904_item	2828103	et	4	main
läti	doc_713316236904_item	2828104	et	4	main
ja	doc_713316236904_item	2828105	et	3	main
leedu	doc_713316236904_item	2828106	et	4	main
balti	doc_713316236904_item	2828107	et	3	main
keti	doc_713316236904_item	2828108	et	3	main
eesmärgiks	doc_713316236904_item	2828109	et	3	main
li	doc_713316236904_item	2828110	et	4	main
mrp	doc_713316236904_item	2828111	et	4	main
avalikustamine	doc_713316236904_item	2828112	et	4	main
ja	doc_713316236904_item	2828113	et	3	main
tühjendamine	doc_713316236904_item	2828114	et	4	main
ja	doc_713316236904_item	2828115	et	3	main
see	doc_713316236904_item	2828116	et	3	main
tõigi	doc_713316236904_item	2828117	et	4	main
oma	doc_713316236904_item	2828118	et	4	main
tulemusi	doc_713316236904_item	2828119	et	4	main
mrp	doc_713316236904_item	2828120	et	4	main
õiguse	doc_713316236904_item	2828127	et	4	main
kuulutada	doc_713316236904_item	2828128	et	3	main
okupeeritud	doc_713316236904_item	2828129	et	4	main
peamine	doc_713316236904_item	2828137	et	3	main
asi	doc_713316236904_item	2828138	et	4	main
narva	doc_713316236904_item	2828156	et	4	main
probleemiks	doc_713316236904_item	2828180	et	4	main
üldiselt	doc_713316236904_item	2828186	et	4	main
samuti	doc_713316236904_item	2828194	et	3	main
terve	doc_713316236904_item	2828198	et	4	main
maailm	doc_713316236904_item	2828199	et	3	main
sai	doc_713316236904_item	2828200	et	4	main
loost	doc_713316236904_item	2828206	et	4	main
maailma	doc_713316236904_item	2828208	et	4	main
sõja	doc_713316236904_item	2828209	et	3	main
järel	doc_713316236904_item	2828210	et	4	main
kett	doc_713316236905_item	2828224	et	4	main
suur	doc_713316236905_item	2828236	et	3	main
poliitiline	doc_713316236905_item	2828237	et	3	main
tähendus	doc_713316236905_item	2828238	et	4	main
selle	doc_713316236905_item	2828239	et	4	main
omajärel	doc_713316236905_item	2828279	et	3	main
elamisvõime	doc_713316236905_item	2828290	et	4	main
näitas	doc_713316236905_item	2828294	et	3	main
et	doc_713316236905_item	2828295	et	3	main
riigid	doc_713316236905_item	2828297	et	3	main
saaksid	doc_713316236905_item	2828299	et	4	main
viia	doc_713316236905_item	2828301	et	3	main
olla	doc_713316236905_item	2828307	et	3	main
1989	doc_713316236905_item	2828318	et	2	main
likvideeritud	doc_713316236905_item	2828325	et	4	main
tegutsesid	doc_713316236905_item	2828332	et	4	main
keegi	doc_713316236904_item	2828076	et	4	main
sest	doc_713316236904_item	2828096	et	4	main
see	doc_713316236904_item	2828097	et	3	main
oli	doc_713316236904_item	2828098	et	3	main
inimestest	doc_713316236904_item	2828099	et	3	main
tühjendati	doc_713316236904_item	2828121	et	3	main
leedu	doc_713316236904_item	2828125	et	4	main
sai	doc_713316236904_item	2828126	et	4	main
ei	doc_713316236904_item	2828135	et	4	main
kui	doc_713316236904_item	2828142	et	3	main
nii	doc_713316236904_item	2828143	et	3	main
arvas	doc_713316236904_item	2828144	et	3	main
petseri	doc_713316236904_item	2828153	et	4	main
peeti	doc_713316236904_item	2828166	et	4	main
venemaale	doc_713316236904_item	2828167	et	4	main
ei	doc_713316236904_item	2828174	et	4	main
vahel	doc_713316236904_item	2828184	et	4	main
aga	doc_713316236904_item	2828185	et	3	main
muutused	doc_713316236905_item	2828213	et	4	main
ja	doc_713316236905_item	2828214	et	3	main
muudatused	doc_713316236905_item	2828215	et	3	main
balti	doc_713316236905_item	2828223	et	3	main
baltikumi	doc_713316236905_item	2828227	et	4	main
rahavstele	doc_713316236905_item	2828228	et	4	main
inimesed	doc_713316236905_item	2828244	et	3	main
püüdsid	doc_713316236905_item	2828245	et	4	main
viia	doc_713316236905_item	2828246	et	3	main
maailma	doc_713316236905_item	2828247	et	4	main
riikide	doc_713316236905_item	2828248	et	3	main
peale	doc_713316236905_item	2828253	et	4	main
surmaks	doc_713316236905_item	2828284	et	4	main
balti	doc_713316236905_item	2828292	et	3	main
balti	doc_713316236905_item	2828296	et	3	main
üheskoos	doc_713316236905_item	2828298	et	3	main
edukalt	doc_713316236905_item	2828300	et	4	main
oma	doc_713316236905_item	2828302	et	4	main
teistele	doc_713316236905_item	2828308	et	4	main
nsv-sse	doc_713316236905_item	2828309	et	3	main
inkorporeeritud	doc_713316236905_item	2828310	et	4	main
kett	doc_713316236905_item	2828314	et	4	main
1	doc_713316236905_item	2828319	et	2	main
olid	doc_713316236905_item	2828321	et	4	main
kultuuritegelased	doc_713316236905_item	2828330	et	3	main
välismaal	doc_713316236905_item	2828333	et	4	main
võimaluse	doc_713316236905_item	2828336	et	3	main
tulla	doc_713316236905_item	2828337	et	3	main
tagasi	doc_713316236905_item	2828338	et	3	main
isamaale	doc_713316236905_item	2828339	et	4	main
ja	doc_713316236905_item	2828340	et	3	main
rahvalaulu	doc_713316236905_item	2828346	et	4	main
aktiivselt	doc_713316236905_item	2828356	et	4	main
suletakse	doc_713316236905_item	2828357	et	4	main
integreerimis	doc_713316236905_item	2828381	et	4	main
integreerimis	doc_713316236905_item	2828390	et	4	main
laagrid	doc_713316236905_item	2828391	et	3	main
õppeprotsessi	doc_713316236905_item	2828395	et	4	main
keelele	doc_713316236905_item	2828397	et	4	main
võimalus	doc_713316236905_item	2828399	et	3	main
riigikeeles	doc_713316236905_item	2828400	et	4	main
kirjanduse	doc_713316236905_item	2828401	et	3	main
märgata	doc_713316236905_item	2828417	et	4	main
ajutilist	doc_713316236905_item	2828418	et	4	main
seisakut	doc_713316236905_item	2828419	et	3	main
vanu	doc_713316236905_item	2828423	et	4	main
jaoks	doc_713316236905_item	2828426	et	4	main
ajaloolised	doc_713316236905_item	2828433	et	4	main
lindid	doc_713316236905_item	2828434	et	3	main
maalikunst	doc_713316236905_item	2828435	et	3	main
kommunismi	doc_713316236905_item	2828442	et	4	main
seltskonna	doc_713316236905_item	2828450	et	3	main
nad	doc_713316236905_item	2828454	et	3	main
üheks	doc_713316236905_item	2828456	et	3	main
kontrolltöö	doc_713316236906_item	2828458	et	4	main
muutused	doc_713316236906_item	2828460	et	4	main
isemajandamisele	doc_713316236906_item	2828485	et	3	main
oli	doc_713316236906_item	2828488	et	3	main
lõppenud	doc_713316236906_item	2828489	et	4	main
ja	doc_713316236906_item	2828490	et	3	main
minema	doc_713316236906_item	2828498	et	3	main
kartes	doc_713316236906_item	2828500	et	3	main
meri	doc_713316236906_item	2828508	et	3	main
eesti	doc_713316236904_item	2828122	et	4	main
nsvl	doc_713316236904_item	2828130	et	4	main
poolt	doc_713316236904_item	2828131	et	4	main
aladeks	doc_713316236904_item	2828132	et	3	main
aga	doc_713316236904_item	2828133	et	3	main
see	doc_713316236904_item	2828134	et	3	main
rahvas	doc_713316236904_item	2828140	et	4	main
nii	doc_713316236904_item	2828141	et	3	main
niimoodi	doc_713316236904_item	2828145	et	3	main
peamine	doc_713316236904_item	2828146	et	3	main
on	doc_713316236904_item	2828147	et	4	main
see	doc_713316236904_item	2828148	et	3	main
et	doc_713316236904_item	2828149	et	3	main
alad	doc_713316236904_item	2828154	et	3	main
ja	doc_713316236904_item	2828155	et	3	main
ja	doc_713316236904_item	2828124	et	3	main
sest	doc_713316236904_item	2828139	et	4	main
rahule	doc_713316236904_item	2828152	et	4	main
alad	doc_713316236904_item	2828158	et	3	main
mida	doc_713316236904_item	2828163	et	4	main
pärast	doc_713316236904_item	2828169	et	4	main
taasiseseisvumist	doc_713316236904_item	2828170	et	3	main
antud	doc_713316236904_item	2828175	et	4	main
mis	doc_713316236904_item	2828176	et	4	main
on	doc_713316236904_item	2828177	et	4	main
praegu	doc_713316236904_item	2828178	et	3	main
üheks	doc_713316236904_item	2828179	et	3	main
kett	doc_713316236904_item	2828188	et	4	main
väga	doc_713316236904_item	2828190	et	3	main
laulev	doc_713316236904_item	2828196	et	4	main
revolutsioon	doc_713316236904_item	2828197	et	3	main
teada	doc_713316236904_item	2828201	et	3	main
eesti	doc_713316236904_item	2828202	et	4	main
ja	doc_713316236904_item	2828203	et	3	main
üldse	doc_713316236904_item	2828204	et	3	main
ii	doc_713316236904_item	2828207	et	4	main
eesti	doc_713316236905_item	2828217	et	4	main
kultuurielus	doc_713316236905_item	2828218	et	4	main
2	doc_713316236905_item	2828219	et	2	main
oli	doc_713316236905_item	2828222	et	3	main
tähendus	doc_713316236905_item	2828226	et	4	main
maailmale	doc_713316236905_item	2828230	et	4	main
2	doc_713316236905_item	2828231	et	2	main
balti	doc_713316236905_item	2828232	et	3	main
kettil	doc_713316236905_item	2828233	et	4	main
oli	doc_713316236905_item	2828234	et	3	main
oli	doc_713316236905_item	2828241	et	3	main
tähelepanu	doc_713316236905_item	2828249	et	4	main
balti	doc_713316236905_item	2828250	et	3	main
riikide	doc_713316236905_item	2828251	et	3	main
võimatust	doc_713316236905_item	2828291	et	4	main
iseseisvusest	doc_713316236905_item	2828304	et	4	main
eeskujuks	doc_713316236905_item	2828312	et	3	main
18	doc_713316236905_item	2828315	et	2	main
on	doc_713316236904_item	2828159	et	4	main
eestile	doc_713316236904_item	2828160	et	3	main
territoorium	doc_713316236904_item	2828162	et	3	main
nsvl	doc_713316236904_item	2828164	et	4	main
ajal	doc_713316236904_item	2828165	et	4	main
neid	doc_713316236904_item	2828171	et	4	main
eestile	doc_713316236904_item	2828172	et	3	main
tagasi	doc_713316236904_item	2828173	et	3	main
venemaa	doc_713316236904_item	2828183	et	4	main
kui	doc_713316236904_item	2828195	et	3	main
baltikumi	doc_713316236904_item	2828205	et	4	main
taasiseseisvunud	doc_713316236905_item	2828216	et	4	main
sündmus	doc_713316236905_item	2828221	et	3	main
selle	doc_713316236905_item	2828225	et	4	main
pandud	doc_713316236905_item	2828235	et	4	main
600	doc_713316236905_item	2828242	et	2	main
km	doc_713316236905_item	2828243	et	4	main
oli	doc_713316236905_item	2828258	et	3	main
konkreetne	doc_713316236905_item	2828259	et	3	main
natsionaal	doc_713316236905_item	2828260	et	4	main
mõistete	doc_713316236905_item	2828261	et	3	main
kommunismi	doc_713316236905_item	2828283	et	4	main
võiks	doc_713316236905_item	2828286	et	4	main
unistuse	doc_713316236905_item	2828303	et	4	main
riikide	doc_713316236905_item	2828311	et	3	main
miljonit	doc_713316236905_item	2828316	et	3	main
muutused	doc_713316236905_item	2828320	et	4	main
kes	doc_713316236905_item	2828331	et	4	main
looma	doc_713316236905_item	2828342	et	4	main
suurt	doc_713316236905_item	2828343	et	3	main
tähtsust	doc_713316236905_item	2828344	et	4	main
kõrgenes	doc_713316236905_item	2828348	et	3	main
tähtsus	doc_713316236905_item	2828351	et	4	main
poliitikat	doc_713316236905_item	2828382	et	3	main
80-nde	doc_713316236905_item	2828383	et	4	main
integreerimine	doc_713316236905_item	2828386	et	4	main
õppekavad	doc_713316236905_item	2828392	et	3	main
olid	doc_713316236905_item	2828403	et	4	main
püüdi	doc_713316236905_item	2828420	et	4	main
ja	doc_713316236905_item	2828229	et	3	main
pikkus	doc_713316236905_item	2828240	et	4	main
elu	doc_713316236905_item	2828252	et	4	main
ekp	doc_713316236905_item	2828254	et	4	main
ja	doc_713316236905_item	2828255	et	3	main
moskva	doc_713316236905_item	2828256	et	4	main
reaktsioon	doc_713316236905_item	2828257	et	3	main
levitamine	doc_713316236905_item	2828262	et	4	main
masside	doc_713316236905_item	2828263	et	3	main
seas	doc_713316236905_item	2828264	et	4	main
päpast	doc_713316236905_item	2828265	et	4	main
aktsioni	doc_713316236905_item	2828266	et	4	main
euroopa	doc_713316236905_item	2828267	et	4	main
riigid	doc_713316236905_item	2828268	et	3	main
keskendusid	doc_713316236905_item	2828269	et	4	main
rohkem	doc_713316236905_item	2828270	et	4	main
probleemidele	doc_713316236905_item	2828271	et	3	main
mis	doc_713316236905_item	2828272	et	4	main
aitaksid	doc_713316236905_item	2828273	et	4	main
balti	doc_713316236905_item	2828274	et	3	main
riikide	doc_713316236905_item	2828275	et	3	main
iseseisvuse	doc_713316236905_item	2828276	et	4	main
taastamist	doc_713316236905_item	2828277	et	4	main
mis	doc_713316236905_item	2828278	et	4	main
viib	doc_713316236905_item	2828280	et	3	main
nsv	doc_713316236905_item	2828281	et	4	main
lagunemiseks	doc_713316236905_item	2828282	et	4	main
mis	doc_713316236905_item	2828285	et	4	main
täielikult	doc_713316236905_item	2828287	et	4	main
väljendada	doc_713316236905_item	2828288	et	3	main
kommunismi	doc_713316236905_item	2828289	et	4	main
kett	doc_713316236905_item	2828293	et	4	main
ellu	doc_713316236905_item	2828305	et	4	main
ja	doc_713316236905_item	2828306	et	3	main
balti	doc_713316236905_item	2828313	et	3	main
osavõtjat	doc_713316236905_item	2828317	et	3	main
suured	doc_713316236905_item	2828322	et	3	main
esiteks	doc_713316236905_item	2828323	et	3	main
kõik	doc_713316236905_item	2828329	et	4	main
said	doc_713316236905_item	2828334	et	4	main
suurepärase	doc_713316236905_item	2828335	et	4	main
omasid	doc_713316236905_item	2828345	et	4	main
rahva	doc_713316236905_item	2828349	et	3	main
eesti	doc_713316236905_item	2828358	et	4	main
tunneb	doc_713316236905_item	2828359	et	3	main
eesti	doc_713316236905_item	2828379	et	4	main
hakkas	doc_713316236905_item	2828380	et	3	main
sissetoomine	doc_713316236905_item	2828385	et	4	main
suhtes	doc_713316236905_item	2828402	et	4	main
läbinud	doc_713316236905_item	2828406	et	4	main
hakkas	doc_713316236905_item	2828409	et	3	main
kirjanikude	doc_713316236905_item	2828412	et	3	main
filmi	doc_713316236905_item	2828414	et	4	main
kunstis	doc_713316236905_item	2828415	et	3	main
oli	doc_713316236905_item	2828416	et	3	main
sai	doc_713316236905_item	2828438	et	4	main
populaarseks	doc_713316236905_item	2828439	et	4	main
sotsrealism	doc_713316236905_item	2828440	et	3	main
rõhutavad	doc_713316236905_item	2828448	et	4	main
muutub	doc_713316236905_item	2828452	et	3	main
nüüd	doc_713316236906_item	2828491	et	4	main
pärast	doc_713316236906_item	2828503	et	4	main
lennart	doc_713316236906_item	2828507	et	4	main
pikaks	doc_713316236906_item	2828518	et	4	main
ajaks	doc_713316236906_item	2828519	et	4	main
tallinna	doc_713316236906_item	2828520	et	4	main
oli	doc_713316236905_item	2828324	et	3	main
vangle	doc_713316236905_item	2828326	et	4	main
nsv	doc_713316236905_item	2828327	et	4	main
tsensuur	doc_713316236905_item	2828328	et	3	main
suurt	doc_713316236905_item	2828360	et	3	main
puudust	doc_713316236905_item	2828361	et	4	main
kõik	doc_713316236905_item	2828363	et	4	main
õppematerjalid	doc_713316236905_item	2828364	et	3	main
olid	doc_713316236905_item	2828365	et	4	main
koostatud	doc_713316236905_item	2828366	et	4	main
tsensuuri	doc_713316236905_item	2828367	et	4	main
ja	doc_713316236905_item	2828368	et	3	main
nsv	doc_713316236905_item	2828369	et	4	main
kontrolli	doc_713316236905_item	2828370	et	4	main
all	doc_713316236905_item	2828371	et	3	main
mis	doc_713316236905_item	2828372	et	4	main
täielikult	doc_713316236905_item	2828373	et	4	main
põhjendasid	doc_713316236905_item	2828374	et	4	main
nsv	doc_713316236905_item	2828375	et	4	main
poliitikat	doc_713316236905_item	2828376	et	3	main
liitlaste	doc_713316236905_item	2828377	et	3	main
vastu	doc_713316236905_item	2828378	et	3	main
avalikult	doc_713316236905_item	2828341	et	4	main
peod	doc_713316236905_item	2828347	et	4	main
kultuuri	doc_713316236905_item	2828350	et	4	main
nõukogu	doc_713316236905_item	2828352	et	4	main
liidu	doc_713316236905_item	2828353	et	3	main
kultuuri	doc_713316236905_item	2828354	et	4	main
majad	doc_713316236905_item	2828355	et	3	main
õppematerjalidest	doc_713316236905_item	2828362	et	3	main
loodud	doc_713316236905_item	2828389	et	4	main
üleminekut	doc_713316236905_item	2828394	et	3	main
eesti	doc_713316236905_item	2828396	et	4	main
kõrghariduse	doc_713316236905_item	2828398	et	3	main
mitte	doc_713316236905_item	2828405	et	3	main
teosed	doc_713316236905_item	2828408	et	3	main
uute	doc_713316236905_item	2828411	et	3	main
propageerida	doc_713316236905_item	2828422	et	3	main
uute	doc_713316236905_item	2828425	et	3	main
polnud	doc_713316236905_item	2828427	et	3	main
resurse	doc_713316236905_item	2828428	et	4	main
edaspidi	doc_713316236905_item	2828429	et	3	main
viimasel	doc_713316236905_item	2828436	et	3	main
ajal	doc_713316236905_item	2828437	et	4	main
arusaam	doc_713316236905_item	2828443	et	3	main
ning	doc_713316236905_item	2828444	et	3	main
obstraktsianism	doc_713316236905_item	2828445	et	4	main
kuidas	doc_713316236905_item	2828453	et	3	main
ühinevad	doc_713316236905_item	2828455	et	4	main
1	doc_713316236906_item	2828459	et	2	main
ja	doc_713316236906_item	2828461	et	3	main
muudatused	doc_713316236906_item	2828462	et	3	main
võib	doc_713316236906_item	2828483	et	3	main
kaugele	doc_713316236906_item	2828499	et	4	main
esimeseks	doc_713316236906_item	2828504	et	3	main
heisati	doc_713316236906_item	2828509	et	3	main
pikka	doc_713316236906_item	2828512	et	4	main
hermanni	doc_713316236906_item	2828513	et	4	main
lauluväljakul	doc_713316236906_item	2828521	et	3	main
pidu	doc_713316236906_item	2828523	et	4	main
niikuinii	doc_713316236906_item	2828534	et	4	main
najaad	doc_713316236906_item	2828541	et	3	main
ei	doc_713316236906_item	2828542	et	4	main
jõukas	doc_713316236906_item	2828548	et	4	main
see	doc_713316236906_item	2828550	et	3	main
kellel	doc_713316236906_item	2828551	et	4	main
võis	doc_713316236906_item	2828582	et	4	main
koolivorm	doc_713316236906_item	2828592	et	3	main
muutus	doc_713316236906_item	2828602	et	4	main
et	doc_713316236906_item	2828611	et	3	main
seda	doc_713316236906_item	2828615	et	3	main
selle	doc_713316236906_item	2828620	et	4	main
et	doc_713316236906_item	2828621	et	3	main
aastastele	doc_713316236906_item	2828628	et	4	main
hakati	doc_713316236906_item	2828629	et	3	main
teostama	doc_713316236906_item	2828635	et	3	main
niisama	doc_713316236906_item	2828639	et	3	main
kella	doc_713316236906_item	2828650	et	4	main
hommikuni	doc_713316236906_item	2828653	et	4	main
muud	doc_713316236906_item	2828664	et	4	main
lapsed	doc_713316236906_item	2828670	et	3	main
majanduse	doc_713316236907_item	2828712	et	4	main
ja	doc_713316236907_item	2828713	et	3	main
üldine	doc_713316236907_item	2828714	et	4	main
elutase	doc_713316236907_item	2828715	et	3	main
väga	doc_713316236907_item	2828716	et	3	main
madal	doc_713316236907_item	2828717	et	3	main
läbi	doc_713316236907_item	2828721	et	4	main
uuendamisega	doc_713316236907_item	2828723	et	4	main
pidurdasid	doc_713316236907_item	2828724	et	4	main
oma	doc_713316236907_item	2828729	et	4	main
keegi	doc_713316236907_item	2828738	et	4	main
ei	doc_713316236907_item	2828739	et	4	main
juhtkonna	doc_713316236907_item	2828747	et	4	main
ebakindla	doc_713316236907_item	2828748	et	3	main
viima	doc_713316236907_item	2828758	et	3	main
1991	doc_713316236907_item	2828761	et	2	main
kõik	doc_713316236907_item	2828769	et	4	main
nsv	doc_713316236907_item	2828770	et	4	main
ajal	doc_713316236907_item	2828772	et	4	main
ära	doc_713316236907_item	2828773	et	4	main
endistele	doc_713316236907_item	2828778	et	3	main
omanikele	doc_713316236907_item	2828779	et	3	main
tööjõu	doc_713316236905_item	2828384	et	3	main
eesti	doc_713316236905_item	2828387	et	4	main
seltskonda	doc_713316236905_item	2828388	et	4	main
eeldavad	doc_713316236905_item	2828393	et	4	main
trükitatud	doc_713316236905_item	2828404	et	4	main
tsensuuri	doc_713316236905_item	2828407	et	4	main
tegutsema	doc_713316236905_item	2828410	et	3	main
põlvkond	doc_713316236905_item	2828413	et	3	main
rohkem	doc_713316236905_item	2828421	et	4	main
loominguid	doc_713316236905_item	2828424	et	3	main
sarjad	doc_713316236905_item	2828432	et	4	main
tunnistajate	doc_713316236905_item	2828441	et	4	main
eestlaste	doc_713316236905_item	2828449	et	4	main
rahvaks	doc_713316236905_item	2828457	et	3	main
et	doc_713316236906_item	2828481	et	3	main
ei	doc_713316236906_item	2828492	et	4	main
pidanud	doc_713316236906_item	2828493	et	4	main
noored	doc_713316236906_item	2828494	et	3	main
sõdurid	doc_713316236906_item	2828495	et	3	main
enam	doc_713316236906_item	2828496	et	4	main
teenima	doc_713316236906_item	2828497	et	3	main
oma	doc_713316236906_item	2828501	et	4	main
elu	doc_713316236906_item	2828502	et	4	main
mis	doc_713316236906_item	2828515	et	4	main
jäi	doc_713316236906_item	2828516	et	3	main
sinna	doc_713316236906_item	2828517	et	3	main
me	doc_713316236906_item	2828532	et	4	main
võidame	doc_713316236906_item	2828533	et	3	main
kuna	doc_713316236906_item	2828535	et	3	main
meil	doc_713316236906_item	2828536	et	4	main
endil	doc_713316236906_item	2828537	et	4	main
toodi	doc_713316236906_item	2828545	et	4	main
seda	doc_713316236906_item	2828546	et	3	main
võim	doc_713316236906_item	2828553	et	3	main
kütust	doc_713316236906_item	2828556	et	4	main
vaja	doc_713316236906_item	2828558	et	4	main
selleks	doc_713316236906_item	2828559	et	4	main
et	doc_713316236906_item	2828560	et	3	main
iga	doc_713316236906_item	2828578	et	4	main
haiglasse	doc_713316236906_item	2828587	et	4	main
võeti	doc_713316236906_item	2828589	et	3	main
eesti	doc_713316236906_item	2828601	et	4	main
see	doc_713316236906_item	2828610	et	3	main
koike	doc_713316236906_item	2828614	et	4	main
ei	doc_713316236906_item	2828623	et	4	main
käima	doc_713316236906_item	2828630	et	4	main
ei	doc_713316236906_item	2828644	et	4	main
sellele	doc_713316236906_item	2828658	et	4	main
hakati	doc_713316236906_item	2828659	et	3	main
tarvitama	doc_713316236906_item	2828660	et	3	main
igasuguseid	doc_713316236906_item	2828661	et	3	main
odekolonne	doc_713316236906_item	2828662	et	3	main
ja	doc_713316236906_item	2828663	et	3	main
nendes	doc_713316236906_item	2828666	et	4	main
müümine	doc_713316236906_item	2828673	et	4	main
et	doc_713316236906_item	2828675	et	3	main
eesti	doc_713316236907_item	2828702	et	4	main
taasiseseisvumisprotsessis	doc_713316236907_item	2828703	et	3	main
1eesti	doc_713316236907_item	2828704	et	4	main
ametlik	doc_713316236907_item	2828705	et	3	main
taasiseseisvumine	doc_713316236907_item	2828706	et	3	main
oli	doc_713316236907_item	2828710	et	3	main
seoses	doc_713316236907_item	2828718	et	4	main
viidud	doc_713316236907_item	2828722	et	4	main
nsv	doc_713316236907_item	2828727	et	4	main
elusfäärid	doc_713316236907_item	2828728	et	3	main
arengu	doc_713316236907_item	2828730	et	3	main
hakkasid	doc_713316236907_item	2828731	et	4	main
ilmuma	doc_713316236907_item	2828732	et	3	main
mõtted	doc_713316236907_item	2828733	et	3	main
taasiseseisvumisest	doc_713316236907_item	2828734	et	3	main
ning	doc_713316236907_item	2828735	et	3	main
hoolitsenud	doc_713316236907_item	2828740	et	4	main
kannatada	doc_713316236907_item	2828743	et	3	main
liidu	doc_713316236907_item	2828745	et	3	main
majandus	doc_713316236907_item	2828746	et	4	main
pärast	doc_713316236907_item	2828751	et	4	main
iseseisvumise	doc_713316236907_item	2828752	et	3	main
taastamist	doc_713316236907_item	2828753	et	4	main
hakkas	doc_713316236907_item	2828754	et	3	main
uus	doc_713316236907_item	2828755	et	3	main
ilmusid	doc_713316236905_item	2828430	et	4	main
oma	doc_713316236905_item	2828431	et	4	main
eesti	doc_713316236905_item	2828446	et	4	main
kunstnikud	doc_713316236905_item	2828447	et	3	main
eluvastuvõttmine	doc_713316236905_item	2828451	et	4	main
taasiseseisvunud	doc_713316236906_item	2828463	et	4	main
eesti	doc_713316236906_item	2828464	et	4	main
majanduselus	doc_713316236906_item	2828465	et	4	main
2	doc_713316236906_item	2828466	et	2	main
inerrinde	doc_713316236906_item	2828467	et	4	main
roll	doc_713316236906_item	2828468	et	3	main
eesti	doc_713316236906_item	2828469	et	4	main
taasiseseisvumisprotsessis	doc_713316236906_item	2828470	et	3	main
1	doc_713316236906_item	2828471	et	2	main
rubla	doc_713316236906_item	2828472	et	4	main
väärtus	doc_713316236906_item	2828473	et	3	main
oli	doc_713316236906_item	2828474	et	3	main
langenud	doc_713316236906_item	2828475	et	4	main
50	doc_713316236906_item	2828476	et	2	main
toimus	doc_713316236906_item	2828477	et	3	main
üleminek	doc_713316236906_item	2828478	et	3	main
eekile	doc_713316236906_item	2828479	et	4	main
arvati	doc_713316236906_item	2828480	et	4	main
eesti	doc_713316236906_item	2828482	et	4	main
üleminna	doc_713316236906_item	2828484	et	3	main
sõda	doc_713316236906_item	2828486	et	4	main
afganistaniga	doc_713316236906_item	2828487	et	4	main
presidendiks	doc_713316236906_item	2828505	et	4	main
sai	doc_713316236906_item	2828506	et	4	main
sini-must-valge	doc_713316236906_item	2828510	et	4	main
torni	doc_713316236906_item	2828514	et	4	main
lauldi	doc_713316236906_item	2828525	et	3	main
laule	doc_713316236906_item	2828527	et	4	main
kus	doc_713316236906_item	2828528	et	3	main
lausuti	doc_713316236906_item	2828529	et	4	main
et	doc_713316236906_item	2828530	et	3	main
ükskord	doc_713316236906_item	2828531	et	3	main
veel	doc_713316236906_item	2828538	et	4	main
kütet	doc_713316236906_item	2828539	et	3	main
sisse	doc_713316236906_item	2828547	et	4	main
üle	doc_713316236906_item	2828555	et	3	main
haiguse	doc_713316236906_item	2828580	et	4	main
tõttu	doc_713316236906_item	2828581	et	4	main
2	doc_713316236906_item	2828605	et	2	main
inerrinde	doc_713316236906_item	2828606	et	4	main
roll	doc_713316236906_item	2828607	et	3	main
taasiseseisvumisprotsessis	doc_713316236906_item	2828608	et	3	main
saavutada	doc_713316236906_item	2828613	et	3	main
gorbatšov	doc_713316236906_item	2828618	et	2	main
lipp	doc_713316236906_item	2828511	et	3	main
kus	doc_713316236906_item	2828524	et	3	main
eesti	doc_713316236906_item	2828526	et	4	main
olnud	doc_713316236906_item	2828543	et	4	main
siis	doc_713316236906_item	2828544	et	3	main
oli	doc_713316236906_item	2828552	et	3	main
saada	doc_713316236906_item	2828583	et	4	main
ks	doc_713316236906_item	2828585	et	4	main
õpilastel	doc_713316236906_item	2828591	et	4	main
eestisse	doc_713316236906_item	2828594	et	4	main
hakati	doc_713316236906_item	2828595	et	3	main
sisse	doc_713316236906_item	2828596	et	4	main
tooma	doc_713316236906_item	2828597	et	3	main
banaane	doc_713316236906_item	2828598	et	3	main
jogurtit	doc_713316236906_item	2828599	et	3	main
jne	doc_713316236906_item	2828600	et	4	main
oli	doc_713316236906_item	2828609	et	3	main
taheti	doc_713316236906_item	2828617	et	3	main
alkoholi	doc_713316236906_item	2828622	et	4	main
tohi	doc_713316236906_item	2828624	et	4	main
müüja	doc_713316236906_item	2828625	et	4	main
alla	doc_713316236906_item	2828626	et	3	main
21	doc_713316236906_item	2828627	et	2	main
ja	doc_713316236906_item	2828632	et	3	main
kontrolli	doc_713316236906_item	2828636	et	4	main
et	doc_713316236906_item	2828637	et	3	main
koolist	doc_713316236906_item	2828640	et	4	main
või	doc_713316236906_item	2828641	et	4	main
töölt	doc_713316236906_item	2828642	et	3	main
ära	doc_713316236906_item	2828643	et	4	main
keelati	doc_713316236906_item	2828648	et	4	main
teatud	doc_713316236906_item	2828655	et	4	main
poodides	doc_713316236906_item	2828656	et	3	main
tänu	doc_713316236906_item	2828657	et	4	main
sarnast	doc_713316236906_item	2828665	et	4	main
peredes	doc_713316236906_item	2828667	et	3	main
väärarenguga	doc_713316236906_item	2828669	et	3	main
sund	doc_713316236906_item	2828672	et	3	main
200891sellel	doc_713316236907_item	2828708	et	4	main
nsv	doc_713316236907_item	2828719	et	4	main
kõik	doc_713316236907_item	2828725	et	4	main
majanduse	doc_713316236907_item	2828736	et	4	main
poliitika	doc_713316236907_item	2828749	et	4	main
valitsus	doc_713316236907_item	2828756	et	4	main
tagastatud	doc_713316236907_item	2828768	et	4	main
võetud	doc_713316236907_item	2828774	et	4	main
sugulased	doc_713316236907_item	2828783	et	3	main
väga	doc_713316236907_item	2828790	et	3	main
osa	doc_713316236907_item	2828796	et	4	main
omanikule	doc_713316236907_item	2828800	et	3	main
sai	doc_713316236907_item	2828830	et	4	main
ei	doc_713316236907_item	2828846	et	4	main
segadust	doc_713316236907_item	2828863	et	4	main
panganduses	doc_713316236907_item	2828864	et	3	main
õnnestus	doc_713316236907_item	2828870	et	4	main
seda	doc_713316236907_item	2828871	et	3	main
loodud	doc_713316236907_item	2828875	et	4	main
eelarve	doc_713316236907_item	2828878	et	4	main
mis	doc_713316236907_item	2828879	et	4	main
võimaldas	doc_713316236907_item	2828880	et	3	main
väikesed	doc_713316236907_item	2828892	et	4	main
toimus	doc_713316236906_item	2828522	et	3	main
või	doc_713316236906_item	2828540	et	4	main
oli	doc_713316236906_item	2828549	et	3	main
najta	doc_713316236906_item	2828554	et	4	main
traktoritega	doc_713316236906_item	2828561	et	3	main
oli	doc_713316236906_item	2828557	et	3	main
maad	doc_713316236906_item	2828562	et	4	main
künda	doc_713316236906_item	2828563	et	3	main
jne	doc_713316236906_item	2828564	et	4	main
elu	doc_713316236906_item	2828565	et	4	main
oli	doc_713316236906_item	2828566	et	3	main
odav	doc_713316236906_item	2828567	et	3	main
st	doc_713316236906_item	2828568	et	3	main
elekter	doc_713316236906_item	2828569	et	3	main
ja	doc_713316236906_item	2828570	et	3	main
vesi	doc_713316236906_item	2828571	et	4	main
olid	doc_713316236906_item	2828572	et	4	main
peaaegu	doc_713316236906_item	2828573	et	3	main
tasuta	doc_713316236906_item	2828574	et	4	main
palgast	doc_713316236906_item	2828575	et	4	main
võeti	doc_713316236906_item	2828576	et	3	main
maha	doc_713316236906_item	2828577	et	4	main
väiksemagi	doc_713316236906_item	2828579	et	4	main
2	doc_713316236906_item	2828584	et	2	main
nädalaks	doc_713316236906_item	2828586	et	3	main
koolis	doc_713316236906_item	2828588	et	4	main
keelati	doc_713316236906_item	2828590	et	4	main
ära	doc_713316236906_item	2828593	et	4	main
eesti	doc_713316236906_item	2828603	et	4	main
vabariigiks	doc_713316236906_item	2828604	et	3	main
aitas	doc_713316236906_item	2828612	et	3	main
mida	doc_713316236906_item	2828616	et	4	main
kehtestas	doc_713316236906_item	2828619	et	3	main
mujal	doc_713316236906_item	2828633	et	3	main
ning	doc_713316236906_item	2828634	et	3	main
inimesed	doc_713316236906_item	2828638	et	3	main
alates	doc_713316236906_item	2828649	et	3	main
toimus	doc_713316236907_item	2828707	et	3	main
eesti	doc_713316236907_item	2828711	et	4	main
liidus	doc_713316236907_item	2828720	et	4	main
arengust	doc_713316236907_item	2828737	et	3	main
sai	doc_713316236907_item	2828742	et	4	main
nsv	doc_713316236907_item	2828744	et	4	main
läbi	doc_713316236907_item	2828757	et	4	main
esiteks	doc_713316236907_item	2828760	et	3	main
toimus	doc_713316236907_item	2828763	et	3	main
ja	doc_713316236907_item	2828776	et	3	main
tähendas	doc_713316236907_item	2828794	et	3	main
oli	doc_713316236907_item	2828824	et	3	main
oma	doc_713316236907_item	2828831	et	4	main
saksa	doc_713316236907_item	2828838	et	4	main
margaga	doc_713316236907_item	2828839	et	3	main
vana	doc_713316236907_item	2828848	et	4	main
hoiusi	doc_713316236907_item	2828856	et	4	main
rahapoliitika	doc_713316236907_item	2828858	et	4	main
lahendada	doc_713316236907_item	2828872	et	3	main
ev	doc_713316236907_item	2828876	et	4	main
kiire	doc_713316236907_item	2828885	et	4	main
minema	doc_713316236907_item	2828891	et	3	main
saanud	doc_713316236907_item	2828928	et	4	main
võrreldes	doc_713316236907_item	2828930	et	3	main
eesti	doc_713316236907_item	2828934	et	4	main
oli	doc_713316236907_item	2828936	et	3	main
elu	doc_713316236907_item	2828955	et	4	main
ja	doc_713316236907_item	2828956	et	3	main
majandussfäärid	doc_713316236907_item	2828957	et	3	main
aastal	doc_713316236907_item	2828966	et	3	main
oli	doc_713316236907_item	2828969	et	3	main
nsvl	doc_713316236907_item	2828971	et	4	main
tegelaseks	doc_713316236907_item	2828986	et	3	main
kellam	doc_713316236907_item	2828988	et	4	main
liikmed	doc_713316236907_item	2828990	et	3	main
streike	doc_713316236907_item	2828994	et	3	main
samuti	doc_713316236907_item	2829002	et	3	main
liidu	doc_713316236907_item	2829004	et	3	main
liikmed	doc_713316236907_item	2829006	et	3	main
eesti	doc_713316236907_item	2829014	et	4	main
taasiseseisvumist	doc_713316236907_item	2829015	et	3	main
minu	doc_713316236907_item	2829016	et	3	main
meelest	doc_713316236907_item	2829017	et	4	main
polnud	doc_713316236907_item	2829018	et	3	main
see	doc_713316236907_item	2829023	et	3	main
nsvi	doc_713316236908_item	2829038	et	4	main
2	doc_713316236908_item	2829043	et	2	main
teie	doc_713316236908_item	2829049	et	4	main
arvates	doc_713316236908_item	2829050	et	4	main
ajaloodokument	doc_713316236908_item	2829051	et	3	main
ei	doc_713316236908_item	2829057	et	4	main
nsvl-s	doc_713316236908_item	2829083	et	3	main
vaatajateni	doc_713316236908_item	2829086	et	4	main
näitama	doc_713316236908_item	2829095	et	3	main
eesti	doc_713316236908_item	2829123	et	4	main
turistid	doc_713316236908_item	2829125	et	3	main
valuutapoed	doc_713316236908_item	2829126	et	3	main
elatustase	doc_713316236908_item	2829129	et	3	main
siiski	doc_713316236908_item	2829130	et	4	main
joala	doc_713316236908_item	2829135	et	4	main
olid	doc_713316236908_item	2829144	et	4	main
pärit	doc_713316236908_item	2829145	et	3	main
vene	doc_713316236908_item	2829151	et	4	main
v	doc_713316236908_item	2829152	et	4	main
kes	doc_713316236908_item	2829185	et	4	main
näit	doc_713316236908_item	2829191	et	3	main
kinodes	doc_713316236906_item	2828631	et	3	main
ole	doc_713316236906_item	2828645	et	4	main
alkoholi	doc_713316236906_item	2828646	et	4	main
müüa	doc_713316236906_item	2828647	et	3	main
1400	doc_713316236906_item	2828651	et	2	main
kuni	doc_713316236906_item	2828652	et	3	main
ja	doc_713316236906_item	2828654	et	3	main
sündisid	doc_713316236906_item	2828668	et	4	main
toimus	doc_713316236906_item	2828671	et	3	main
st	doc_713316236906_item	2828674	et	3	main
müüdi	doc_713316236906_item	2828676	et	4	main
neid	doc_713316236906_item	2828677	et	4	main
asju	doc_713316236906_item	2828678	et	3	main
mida	doc_713316236906_item	2828679	et	4	main
ei	doc_713316236906_item	2828680	et	4	main
tahetud	doc_713316236906_item	2828681	et	4	main
koos	doc_713316236906_item	2828682	et	4	main
vajalikudega	doc_713316236906_item	2828683	et	3	main
poeletid	doc_713316236906_item	2828684	et	3	main
olid	doc_713316236906_item	2828685	et	4	main
tühjad	doc_713316236906_item	2828686	et	3	main
toiduvarusid	doc_713316236906_item	2828687	et	3	main
sai	doc_713316236906_item	2828688	et	4	main
tellida	doc_713316236906_item	2828689	et	3	main
abipakkidena	doc_713316236906_item	2828690	et	3	main
kontrolltöö	doc_713316236907_item	2828691	et	4	main
1	doc_713316236907_item	2828692	et	2	main
muutused	doc_713316236907_item	2828693	et	4	main
ja	doc_713316236907_item	2828694	et	3	main
muudatused	doc_713316236907_item	2828695	et	3	main
taasiseseisvunud	doc_713316236907_item	2828696	et	4	main
eesti	doc_713316236907_item	2828697	et	4	main
majanduselus	doc_713316236907_item	2828698	et	4	main
2	doc_713316236907_item	2828699	et	2	main
inerrinde	doc_713316236907_item	2828700	et	4	main
roll	doc_713316236907_item	2828701	et	3	main
etapil	doc_713316236907_item	2828709	et	3	main
eesti	doc_713316236907_item	2828726	et	4	main
samuti	doc_713316236907_item	2828741	et	3	main
tõttu	doc_713316236907_item	2828750	et	4	main
majandusreforme	doc_713316236907_item	2828759	et	3	main
a	doc_713316236907_item	2828762	et	4	main
maareform	doc_713316236907_item	2828764	et	3	main
käigus	doc_713316236907_item	2828766	et	4	main
olid	doc_713316236907_item	2828767	et	4	main
maavarad	doc_713316236907_item	2828775	et	3	main
kauged	doc_713316236907_item	2828782	et	3	main
selle	doc_713316236907_item	2828787	et	4	main
mis	doc_713316236907_item	2828793	et	4	main
koondumist	doc_713316236907_item	2828798	et	4	main
riigi	doc_713316236907_item	2828801	et	3	main
poolt	doc_713316236907_item	2828802	et	4	main
saadud	doc_713316236907_item	2828803	et	4	main
kollaste	doc_713316236907_item	2828804	et	4	main
kaartide	doc_713316236907_item	2828805	et	3	main
abil	doc_713316236907_item	2828806	et	4	main
paljud	doc_713316236907_item	2828807	et	3	main
inimesed	doc_713316236907_item	2828808	et	3	main
kellel	doc_713316236907_item	2828809	et	4	main
olid	doc_713316236907_item	2828810	et	4	main
probleemid	doc_713316236907_item	2828811	et	3	main
elamispaigadega	doc_713316236907_item	2828812	et	4	main
said	doc_713316236907_item	2828813	et	4	main
neid	doc_713316236907_item	2828814	et	4	main
lahendada	doc_713316236907_item	2828815	et	3	main
halvema	doc_713316236907_item	2828816	et	4	main
olukorda	doc_713316236907_item	2828817	et	4	main
sattusid	doc_713316236907_item	2828818	et	4	main
nn	doc_713316236907_item	2828819	et	4	main
kohtulikud	doc_713316236907_item	2828820	et	3	main
raha	doc_713316236907_item	2828827	et	4	main
reform	doc_713316236907_item	2828828	et	3	main
eesti	doc_713316236907_item	2828829	et	4	main
kroon	doc_713316236907_item	2828834	et	3	main
mis	doc_713316236907_item	2828835	et	4	main
oli	doc_713316236907_item	2828836	et	3	main
seotud	doc_713316236907_item	2828837	et	4	main
jõudnud	doc_713316236907_item	2828847	et	4	main
kaotasid	doc_713316236907_item	2828854	et	4	main
kindel	doc_713316236907_item	2828857	et	3	main
tõi	doc_713316236907_item	2828859	et	3	main
aja	doc_713316236907_item	2828867	et	4	main
pärast	doc_713316236907_item	2828868	et	4	main
oli	doc_713316236907_item	2828873	et	3	main
liidust	doc_713316236907_item	2828884	et	4	main
bankrotti	doc_713316236907_item	2828890	et	4	main
aastal	doc_713316236907_item	2828921	et	3	main
arenes	doc_713316236907_item	2828923	et	3	main
riikide	doc_713316236907_item	2828929	et	3	main
tänu	doc_713316236907_item	2828931	et	4	main
suurem	doc_713316236907_item	2828938	et	4	main
rahasumma	doc_713316236907_item	2828939	et	4	main
elanikule	doc_713316236907_item	2828946	et	3	main
oli	doc_713316236907_item	2828950	et	3	main
peatamine	doc_713316236907_item	2828973	et	4	main
ja	doc_713316236907_item	2828974	et	3	main
rahvarindega	doc_713316236907_item	2828983	et	3	main
oli	doc_713316236907_item	2828987	et	3	main
selle	doc_713316236907_item	2828765	et	4	main
liidu	doc_713316236907_item	2828771	et	3	main
korterid	doc_713316236907_item	2828777	et	3	main
isegi	doc_713316236907_item	2828780	et	4	main
kõrvalt	doc_713316236907_item	2828788	et	4	main
toimus	doc_713316236907_item	2828789	et	3	main
edukalt	doc_713316236907_item	2828791	et	4	main
aktsiaid	doc_713316236907_item	2828797	et	3	main
ühele	doc_713316236907_item	2828799	et	3	main
1992	doc_713316236907_item	2828822	et	2	main
üsna	doc_713316236907_item	2828781	et	3	main
said	doc_713316236907_item	2828784	et	4	main
kätte	doc_713316236907_item	2828785	et	4	main
kinnisvarasid	doc_713316236907_item	2828786	et	3	main
erastamine	doc_713316236907_item	2828792	et	4	main
suurima	doc_713316236907_item	2828795	et	4	main
üürinikud	doc_713316236907_item	2828821	et	4	main
a	doc_713316236907_item	2828823	et	4	main
läbi	doc_713316236907_item	2828825	et	4	main
viidud	doc_713316236907_item	2828826	et	4	main
valuuta	doc_713316236907_item	2828832	et	4	main
sellega	doc_713316236907_item	2828840	et	3	main
kaasnesid	doc_713316236907_item	2828841	et	4	main
suured	doc_713316236907_item	2828842	et	3	main
probleemid	doc_713316236907_item	2828843	et	3	main
inimestel	doc_713316236907_item	2828844	et	3	main
raha	doc_713316236907_item	2828849	et	4	main
uue	doc_713316236907_item	2828850	et	3	main
oma	doc_713316236907_item	2828855	et	4	main
ainult	doc_713316236907_item	2828865	et	4	main
mõne	doc_713316236907_item	2828866	et	3	main
samuti	doc_713316236907_item	2828874	et	3	main
iseseisev	doc_713316236907_item	2828877	et	3	main
majanduse	doc_713316236907_item	2828886	et	4	main
arengu	doc_713316236907_item	2828887	et	3	main
teiste	doc_713316236907_item	2828926	et	4	main
aastas	doc_713316236907_item	2828940	et	3	main
kui	doc_713316236907_item	2828941	et	3	main
nt	doc_713316236907_item	2828942	et	4	main
läände	doc_713316236907_item	2828947	et	3	main
tõhus	doc_713316236907_item	2828951	et	4	main
ning	doc_713316236907_item	2828952	et	3	main
varsti	doc_713316236907_item	2828953	et	3	main
kõik	doc_713316236907_item	2828954	et	4	main
1988	doc_713316236907_item	2828965	et	2	main
põhieesmärgiks	doc_713316236907_item	2828968	et	3	main
impeeriumi	doc_713316236907_item	2828970	et	4	main
lammutamise	doc_713316236907_item	2828972	et	4	main
selle	doc_713316236907_item	2828984	et	4	main
interrinne	doc_713316236907_item	2828989	et	3	main
nsv	doc_713316236907_item	2829003	et	4	main
kgb	doc_713316236907_item	2829005	et	4	main
eesti	doc_713316236907_item	2828833	et	4	main
kes	doc_713316236907_item	2828845	et	4	main
peale	doc_713316236907_item	2828851	et	4	main
vahetada	doc_713316236907_item	2828852	et	3	main
ja	doc_713316236907_item	2828853	et	3	main
endaga	doc_713316236907_item	2828860	et	4	main
kaasa	doc_713316236907_item	2828861	et	4	main
samuti	doc_713316236907_item	2828862	et	3	main
valitsusel	doc_713316236907_item	2828869	et	4	main
mitte	doc_713316236907_item	2828881	et	3	main
sõltuda	doc_713316236907_item	2828882	et	3	main
ens	doc_713316236907_item	2828883	et	4	main
pärast	doc_713316236907_item	2828888	et	4	main
hakkasid	doc_713316236907_item	2828889	et	4	main
ettevõtted	doc_713316236907_item	2828893	et	3	main
riik	doc_713316236907_item	2828894	et	3	main
ei	doc_713316236907_item	2828895	et	4	main
takistanud	doc_713316236907_item	2828896	et	4	main
seda	doc_713316236907_item	2828897	et	3	main
varsti	doc_713316236907_item	2828898	et	3	main
oli	doc_713316236907_item	2828899	et	3	main
eesti	doc_713316236907_item	2828900	et	4	main
iseenda	doc_713316236907_item	2828901	et	3	main
majandanud	doc_713316236907_item	2828902	et	4	main
65	doc_713316236907_item	2828903	et	2	main
1990-te	doc_713316236907_item	2828904	et	3	main
algusel	doc_713316236907_item	2828905	et	4	main
oli	doc_713316236907_item	2828906	et	3	main
sõlmitud	doc_713316236907_item	2828907	et	4	main
leping	doc_713316236907_item	2828908	et	3	main
euroopaga	doc_713316236907_item	2828909	et	3	main
vaba	doc_713316236907_item	2828910	et	4	main
kaubandusest	doc_713316236907_item	2828911	et	4	main
hakkas	doc_713316236907_item	2828912	et	3	main
arenema	doc_713316236907_item	2828913	et	3	main
eksport	doc_713316236907_item	2828914	et	3	main
eesti	doc_713316236907_item	2828915	et	4	main
sai	doc_713316236907_item	2828916	et	4	main
euroopa	doc_713316236907_item	2828917	et	4	main
nõukogu	doc_713316236907_item	2828918	et	4	main
täisliikmeks	doc_713316236907_item	2828919	et	3	main
1994	doc_713316236907_item	2828920	et	2	main
eesti	doc_713316236907_item	2828922	et	4	main
kõige	doc_713316236907_item	2828924	et	4	main
iseseisvuse	doc_713316236907_item	2828927	et	4	main
ühele	doc_713316236907_item	2828933	et	3	main
elanikule	doc_713316236907_item	2828935	et	3	main
läti	doc_713316236907_item	2828943	et	4	main
suunatud	doc_713316236907_item	2828948	et	4	main
majandus	doc_713316236907_item	2828949	et	4	main
hakkasid	doc_713316236907_item	2828958	et	4	main
töötama	doc_713316236907_item	2828959	et	3	main
selle	doc_713316236907_item	2828967	et	4	main
kiiremini	doc_713316236907_item	2828925	et	4	main
välisinvesteeringutele	doc_713316236907_item	2828932	et	3	main
antud	doc_713316236907_item	2828937	et	4	main
või	doc_713316236907_item	2828944	et	4	main
leedu	doc_713316236907_item	2828945	et	4	main
2	doc_713316236907_item	2828960	et	2	main
interrinne	doc_713316236907_item	2828961	et	3	main
liikumine	doc_713316236907_item	2828962	et	4	main
sai	doc_713316236907_item	2828963	et	4	main
alguse	doc_713316236907_item	2828964	et	3	main
tähtsamaks	doc_713316236907_item	2828985	et	4	main
sees	doc_713316236907_item	2829000	et	4	main
kelle	doc_713316236907_item	2829007	et	4	main
tegevus	doc_713316236907_item	2829008	et	4	main
oli	doc_713316236907_item	2829009	et	3	main
interrinde	doc_713316236907_item	2829019	et	4	main
suur	doc_713316236907_item	2829022	et	3	main
tegi	doc_713316236907_item	2829025	et	4	main
tegevusele	doc_713316236907_item	2829027	et	4	main
1970ndatel	doc_713316236908_item	2829035	et	4	main
nsvl	doc_713316236908_item	2829041	et	4	main
või	doc_713316236908_item	2829052	et	4	main
ühiskonnakriitika	doc_713316236908_item	2829053	et	4	main
olnud	doc_713316236908_item	2829058	et	4	main
tootmist	doc_713316236908_item	2829074	et	4	main
näit	doc_713316236908_item	2829075	et	3	main
ilmusid	doc_713316236908_item	2829076	et	4	main
ekraanile	doc_713316236908_item	2829077	et	3	main
lapstähed	doc_713316236908_item	2829078	et	3	main
entel-tentel	doc_713316236908_item	2829079	et	4	main
mida	doc_713316236908_item	2829098	et	4	main
eestis	doc_713316236908_item	2829111	et	3	main
kõrgkoolides	doc_713316236908_item	2829116	et	3	main
tsentraliseerimine	doc_713316236908_item	2829119	et	4	main
püsiühendus	doc_713316236908_item	2829120	et	3	main
vahel	doc_713316236908_item	2829124	et	4	main
siin	doc_713316236908_item	2829127	et	4	main
oli	doc_713316236908_item	2829128	et	3	main
mis	doc_713316236908_item	2829143	et	4	main
eesti	doc_713316236908_item	2829153	et	4	main
meelest	doc_713316236908_item	2829157	et	4	main
pigem	doc_713316236908_item	2829158	et	3	main
sest	doc_713316236908_item	2829160	et	4	main
filmis	doc_713316236908_item	2829161	et	4	main
heideti	doc_713316236908_item	2829162	et	3	main
kõiki	doc_713316236908_item	2829184	et	4	main
nsvl	doc_713316236908_item	2829188	et	4	main
keda	doc_713316236908_item	2829193	et	4	main
nsvl	doc_713316236908_item	2829194	et	4	main
on	doc_713316236908_item	2829204	et	4	main
hirm	doc_713316236908_item	2829205	et	3	main
nsvl	doc_713316236908_item	2829206	et	4	main
kartis	doc_713316236908_item	2829207	et	3	main
teisitimõtlejaid	doc_713316236908_item	2829208	et	3	main
valitsevale	doc_713316236908_item	2829221	et	4	main
väga	doc_713316236908_item	2829226	et	3	main
omalaadne	doc_713316236908_item	2829227	et	3	main
eesti	doc_713316236908_item	2829229	et	4	main
jazzmuusika	doc_713316236908_item	2829236	et	4	main
tuule	doc_713316236908_item	2829237	et	3	main
tiibadesse	doc_713316236908_item	2829238	et	3	main
kerge	doc_713316236908_item	2829239	et	4	main
olid	doc_713316236908_item	2829244	et	4	main
eesti	doc_713316236908_item	2829248	et	4	main
näha	doc_713316236908_item	2829252	et	3	main
tv-d	doc_713316236908_item	2829254	et	4	main
andis	doc_713316236908_item	2829256	et	3	main
eesti	doc_713316236908_item	2829282	et	4	main
oleme	doc_713316236908_item	2829284	et	3	main
piiririik	doc_713316236908_item	2829286	et	3	main
mitteeestlaste	doc_713316236908_item	2829288	et	4	main
arvu	doc_713316236908_item	2829289	et	4	main
tahtnud	doc_713316236908_item	2829306	et	4	main
olla	doc_713316236908_item	2829307	et	3	main
lihtne	doc_713316236908_item	2829308	et	3	main
1970ndate	doc_714827497072_item	2829316	et	4	main
kuidas	doc_714827497072_item	2829324	et	3	main
film	doc_714827497072_item	2829327	et	3	main
on	doc_714827497072_item	2829335	et	4	main
stagnatsiooni	doc_714827497072_item	2829336	et	4	main
selleks	doc_714827497072_item	2829348	et	4	main
leida	doc_714827497072_item	2829353	et	3	main
eesti	doc_713316236907_item	2828975	et	4	main
natsionalismile	doc_713316236907_item	2828976	et	3	main
vastuseis	doc_713316236907_item	2828977	et	4	main
interrinne	doc_713316236907_item	2828978	et	3	main
oli	doc_713316236907_item	2828979	et	3	main
oppositsioonis	doc_713316236907_item	2828980	et	4	main
ekp	doc_713316236907_item	2828981	et	4	main
ja	doc_713316236907_item	2828982	et	3	main
korraldasid	doc_713316236907_item	2828991	et	4	main
meeleavaldusi	doc_713316236907_item	2828992	et	3	main
et	doc_713316236907_item	2828995	et	3	main
rahvarinde	doc_713316236907_item	2828997	et	4	main
tegevust	doc_713316236907_item	2828998	et	4	main
interrinne	doc_713316236907_item	2828999	et	3	main
suunatud	doc_713316236907_item	2829010	et	4	main
roll	doc_713316236907_item	2829020	et	3	main
kontrolltöö	doc_713316236908_item	2829029	et	4	main
1	doc_713316236908_item	2829030	et	2	main
missugused	doc_713316236908_item	2829031	et	3	main
eesti	doc_713316236908_item	2829037	et	4	main
lähisvälismaana	doc_713316236908_item	2829042	et	3	main
laiuse	doc_713316236908_item	2829045	et	4	main
mängufilm	doc_713316236908_item	2829046	et	3	main
libahunt	doc_713316236908_item	2829047	et	3	main
oli	doc_713316236908_item	2829081	et	3	main
ainulaadne	doc_713316236908_item	2829082	et	3	main
seriaalid	doc_713316236908_item	2829088	et	3	main
alustas	doc_713316236908_item	2829090	et	3	main
reklaamfilm	doc_713316236908_item	2829092	et	3	main
nähtus	doc_713316236908_item	2829097	et	4	main
väga	doc_713316236908_item	2829102	et	3	main
populaarseks	doc_713316236908_item	2829103	et	4	main
said	doc_713316236908_item	2829104	et	4	main
mälumängud	doc_713316236908_item	2829105	et	3	main
1970-ndatel	doc_713316236908_item	2829106	et	4	main
ilmus	doc_713316236908_item	2829107	et	4	main
eestis	doc_713316236908_item	2829108	et	3	main
esimene	doc_713316236908_item	2829109	et	3	main
vähenes	doc_713316236908_item	2829118	et	3	main
ja	doc_713316236907_item	2828993	et	3	main
takistada	doc_713316236907_item	2828996	et	3	main
tegutsesid	doc_713316236907_item	2829001	et	4	main
sellele	doc_713316236907_item	2829011	et	4	main
et	doc_713316236907_item	2829012	et	3	main
takistada	doc_713316236907_item	2829013	et	3	main
kuidagi	doc_713316236907_item	2829021	et	3	main
takistusi	doc_713316236907_item	2829028	et	4	main
põhjust	doc_713316236908_item	2829036	et	4	main
end	doc_713316236908_item	2829040	et	4	main
l	doc_713316236908_item	2829044	et	4	main
kas	doc_713316236908_item	2829048	et	3	main
miks	doc_713316236908_item	2829054	et	4	main
1	doc_713316236908_item	2829055	et	2	main
eestis	doc_713316236908_item	2829056	et	3	main
ideoloogiline	doc_713316236908_item	2829059	et	4	main
jõudsid	doc_713316236908_item	2829085	et	4	main
tv-s	doc_713316236908_item	2829093	et	3	main
hakati	doc_713316236908_item	2829094	et	3	main
tuntud	doc_713316236908_item	2829101	et	4	main
koomiks	doc_713316236908_item	2829110	et	3	main
omakeelne	doc_713316236908_item	2829113	et	3	main
ka	doc_713316236908_item	2829115	et	3	main
soome	doc_713316236908_item	2829121	et	3	main
kõrgem	doc_713316236908_item	2829131	et	4	main
oma	doc_713316236908_item	2829141	et	4	main
lauludega	doc_713316236908_item	2829142	et	3	main
kuid	doc_713316236908_item	2829147	et	4	main
keeles	doc_713316236908_item	2829154	et	4	main
pidid	doc_713316236908_item	2829178	et	4	main
oma	doc_713316236908_item	2829180	et	4	main
sobimatuse	doc_713316236908_item	2829181	et	4	main
polnud	doc_713316236908_item	2829197	et	3	main
selleks	doc_713316236908_item	2829203	et	4	main
tegutseda	doc_713316236908_item	2829216	et	3	main
muutuda	doc_713316236908_item	2829219	et	3	main
lihtsalt	doc_713316236907_item	2829024	et	4	main
rahvarinde	doc_713316236907_item	2829026	et	4	main
majanduslikud-kultuurilised	doc_713316236908_item	2829032	et	4	main
tegurid	doc_713316236908_item	2829033	et	3	main
andsid	doc_713316236908_item	2829034	et	4	main
tunda	doc_713316236908_item	2829039	et	3	main
surve	doc_713316236908_item	2829060	et	4	main
nii	doc_713316236908_item	2829061	et	3	main
tugev	doc_713316236908_item	2829062	et	4	main
kultuuri	doc_713316236908_item	2829063	et	4	main
poole	doc_713316236908_item	2829064	et	4	main
pealt	doc_713316236908_item	2829065	et	4	main
võid	doc_713316236908_item	2829066	et	4	main
näiteks	doc_713316236908_item	2829067	et	4	main
nimetada	doc_713316236908_item	2829068	et	3	main
etv-d	doc_713316236908_item	2829069	et	4	main
mis	doc_713316236908_item	2829070	et	4	main
alustas	doc_713316236908_item	2829071	et	3	main
läänelike	doc_713316236908_item	2829072	et	4	main
saadete	doc_713316236908_item	2829073	et	3	main
mis	doc_713316236908_item	2829080	et	4	main
samuti	doc_713316236908_item	2829084	et	3	main
esimesed	doc_713316236908_item	2829087	et	3	main
tööd	doc_713316236908_item	2829089	et	4	main
eesti	doc_713316236908_item	2829091	et	4	main
reklaame	doc_713316236908_item	2829096	et	3	main
venemaal	doc_713316236908_item	2829099	et	4	main
ei	doc_713316236908_item	2829100	et	4	main
säilis	doc_713316236908_item	2829112	et	4	main
õpe	doc_713316236908_item	2829114	et	3	main
maj	doc_713316236908_item	2829117	et	4	main
ja	doc_713316236908_item	2829122	et	3	main
eesti	doc_713316236908_item	2829133	et	4	main
artistid	doc_713316236908_item	2829134	et	3	main
saavutasid	doc_713316236908_item	2829137	et	4	main
esitati	doc_713316236908_item	2829149	et	4	main
kas	doc_713316236908_item	2829150	et	3	main
minu	doc_713316236908_item	2829156	et	3	main
lahkuma	doc_713316236908_item	2829179	et	3	main
vastanud	doc_713316236908_item	2829187	et	4	main
ka	doc_713316236908_item	2829190	et	3	main
s	doc_713316236908_item	2829195	et	4	main
on	doc_713316236908_item	2829200	et	4	main
ka	doc_713316236908_item	2829201	et	3	main
kuna	doc_713316236908_item	2829209	et	3	main
vabalt	doc_713316236908_item	2829215	et	4	main
nad	doc_713316236908_item	2829218	et	3	main
jazzilikus	doc_713316236908_item	2829232	et	4	main
e	doc_713316236908_item	2829240	et	4	main
u	doc_713316236908_item	2829245	et	4	main
põhjarannikul	doc_713316236908_item	2829249	et	3	main
välismaal	doc_713316236908_item	2829264	et	4	main
sai	doc_713316236908_item	2829265	et	4	main
ju	doc_713316236908_item	2829285	et	3	main
a	doc_713316236908_item	2829292	et	4	main
eestlased	doc_713316236908_item	2829297	et	3	main
vajati	doc_713316236908_item	2829299	et	3	main
eesti	doc_714827497072_item	2829317	et	4	main
nsv-s	doc_714827497072_item	2829318	et	3	main
kevade	doc_714827497072_item	2829321	et	4	main
ja	doc_714827497072_item	2829323	et	3	main
1	doc_714827497072_item	2829332	et	2	main
1970ndad	doc_714827497072_item	2829333	et	4	main
aastad	doc_714827497072_item	2829334	et	3	main
algus	doc_714827497072_item	2829338	et	4	main
süvenemine	doc_714827497072_item	2829347	et	4	main
tuleks	doc_714827497072_item	2829352	et	4	main
tegutses	doc_714827497072_item	2829357	et	3	main
kõigepealt	doc_714827497072_item	2829362	et	3	main
siis	doc_714827497072_item	2829383	et	3	main
algas	doc_714827497072_item	2829384	et	3	main
järsk	doc_714827497072_item	2829385	et	3	main
migrantide	doc_714827497072_item	2829386	et	3	main
vool	doc_714827497072_item	2829387	et	4	main
20000	doc_714827497072_item	2829392	et	2	main
migrantid	doc_714827497072_item	2829422	et	4	main
said	doc_714827497072_item	2829424	et	4	main
suurte	doc_714827497072_item	2829428	et	3	main
elasid	doc_714827497072_item	2829446	et	4	main
ja	doc_714827497072_item	2829447	et	3	main
töötasid	doc_714827497072_item	2829448	et	4	main
salased	doc_714827497072_item	2829460	et	4	main
väikesed	doc_714827497072_item	2829469	et	4	main
elasid	doc_714827497072_item	2829472	et	4	main
osaliselt	doc_714827497072_item	2829483	et	4	main
ma	doc_714827497072_item	2829489	et	3	main
sellel	doc_714827497072_item	2829522	et	4	main
tulemus	doc_714827497072_item	2829526	et	3	main
järgi	doc_714827497072_item	2829534	et	4	main
põhikooli	doc_714827497072_item	2829537	et	4	main
et	doc_714827497072_item	2829542	et	3	main
see	doc_714827497072_item	2829552	et	3	main
minu	doc_714827497072_item	2829559	et	3	main
sobib	doc_714827497072_item	2829562	et	3	main
ainult	doc_714827497072_item	2829564	et	4	main
näide	doc_714827497072_item	2829574	et	3	main
mitte-eestlastele	doc_714827497072_item	2829591	et	4	main
ajalugu	doc_714827497072_item	2829598	et	4	main
kus	doc_714827497072_item	2829599	et	3	main
nad	doc_714827497072_item	2829600	et	3	main
elavad	doc_714827497072_item	2829601	et	4	main
kõige	doc_714827497072_item	2829608	et	4	main
mitmed	doc_713316236908_item	2829132	et	4	main
veski	doc_713316236908_item	2829136	et	4	main
venemaal	doc_713316236908_item	2829138	et	4	main
suure	doc_713316236908_item	2829139	et	3	main
populaarsuse	doc_713316236908_item	2829140	et	4	main
läänest	doc_713316236908_item	2829146	et	4	main
neid	doc_713316236908_item	2829148	et	4	main
2	doc_713316236908_item	2829155	et	2	main
ühiskonnakriitika	doc_713316236908_item	2829159	et	4	main
tiina	doc_713316236908_item	2829163	et	4	main
oma	doc_713316236908_item	2829164	et	4	main
teistsuguse	doc_713316236908_item	2829165	et	3	main
loomuse	doc_713316236908_item	2829166	et	3	main
pärast	doc_713316236908_item	2829167	et	4	main
kogukonnast	doc_713316236908_item	2829168	et	4	main
välja	doc_713316236908_item	2829169	et	4	main
sama	doc_713316236908_item	2829170	et	4	main
süsteem	doc_713316236908_item	2829171	et	3	main
toimis	doc_713316236908_item	2829172	et	4	main
ka	doc_713316236908_item	2829173	et	3	main
nsvl-s	doc_713316236908_item	2829174	et	3	main
kust	doc_713316236908_item	2829175	et	4	main
paljud	doc_713316236908_item	2829176	et	3	main
loomeinimesed	doc_713316236908_item	2829177	et	3	main
pärast	doc_713316236908_item	2829182	et	4	main
ignoreeriti	doc_713316236908_item	2829183	et	3	main
ei	doc_713316236908_item	2829186	et	4	main
standardile	doc_713316236908_item	2829189	et	4	main
invaliide	doc_713316236908_item	2829192	et	4	main
väljatõrjumise	doc_713316236908_item	2829198	et	3	main
neil	doc_713316236908_item	2829214	et	4	main
võivad	doc_713316236908_item	2829217	et	4	main
ohtlikuks	doc_713316236908_item	2829220	et	3	main
suund	doc_713316236908_item	2829228	et	3	main
folkloormuusikat	doc_713316236908_item	2829230	et	4	main
esitati	doc_713316236908_item	2829231	et	4	main
tegijad	doc_713316236908_item	2829243	et	4	main
võimalik	doc_713316236908_item	2829251	et	3	main
sellest	doc_713316236908_item	2829261	et	4	main
tõus	doc_713316236908_item	2829290	et	4	main
1985	doc_713316236908_item	2829291	et	2	main
elanikkonnast	doc_713316236908_item	2829296	et	4	main
tööde	doc_713316236908_item	2829301	et	3	main
eestlane	doc_713316236908_item	2829304	et	3	main
ei	doc_713316236908_item	2829305	et	4	main
majanduse	doc_714827497072_item	2829312	et	4	main
ja	doc_714827497072_item	2829313	et	3	main
migratsiooni	doc_714827497072_item	2829314	et	4	main
seosed	doc_714827497072_item	2829315	et	3	main
kas	doc_714827497072_item	2829322	et	3	main
see	doc_714827497072_item	2829326	et	3	main
õppevahendiks	doc_714827497072_item	2829328	et	3	main
eesti	doc_714827497072_item	2829339	et	4	main
ajaloos	doc_714827497072_item	2829340	et	4	main
siis	doc_714827497072_item	2829341	et	3	main
toimus	doc_714827497072_item	2829342	et	3	main
majanduse	doc_714827497072_item	2829343	et	4	main
midagi	doc_714827497072_item	2829350	et	4	main
järgi	doc_714827497072_item	2829361	et	4	main
soojus	doc_714827497072_item	2829374	et	4	main
põhja-eestis	doc_714827497072_item	2829377	et	3	main
ettevoted	doc_714827497072_item	2829379	et	4	main
aastal	doc_714827497072_item	2829394	et	3	main
ettevõtete	doc_714827497072_item	2829429	et	3	main
kaasa	doc_714827497072_item	2829433	et	4	main
migrantid	doc_714827497072_item	2829449	et	4	main
linna	doc_714827497072_item	2829452	et	4	main
nt	doc_714827497072_item	2829454	et	4	main
linnas	doc_714827497072_item	2829461	et	4	main
kuhu	doc_714827497072_item	2829462	et	3	main
sissepääs	doc_714827497072_item	2829463	et	3	main
oli	doc_714827497072_item	2829464	et	3	main
lubatud	doc_714827497072_item	2829465	et	4	main
ainult	doc_714827497072_item	2829466	et	4	main
eriloaga	doc_714827497072_item	2829467	et	4	main
nagu	doc_714827497072_item	2829468	et	3	main
vahel	doc_714827497072_item	2829479	et	4	main
oli	doc_714827497072_item	2829480	et	3	main
väga	doc_714827497072_item	2829481	et	3	main
suur	doc_714827497072_item	2829482	et	3	main
venestuspoliitika	doc_714827497072_item	2829488	et	4	main
migrantide	doc_714827497072_item	2829492	et	3	main
väidetavalt	doc_713316236908_item	2829196	et	4	main
põhjus	doc_713316236908_item	2829199	et	4	main
sarnane	doc_713316236908_item	2829202	et	4	main
arvati	doc_713316236908_item	2829210	et	4	main
et	doc_713316236908_item	2829211	et	3	main
kui	doc_713316236908_item	2829212	et	3	main
lasta	doc_713316236908_item	2829213	et	4	main
1	doc_713316236908_item	2829223	et	2	main
laadis	doc_713316236908_item	2829233	et	4	main
üleüldse	doc_713316236908_item	2829234	et	3	main
sai	doc_713316236908_item	2829235	et	4	main
tuntuimad	doc_713316236908_item	2829242	et	4	main
aoit	doc_713316236908_item	2829247	et	4	main
mis	doc_713316236908_item	2829255	et	4	main
siinsele	doc_713316236908_item	2829257	et	3	main
vähegi	doc_713316236908_item	2829259	et	4	main
aimu	doc_713316236908_item	2829260	et	4	main
jätkus	doc_713316236908_item	2829287	et	4	main
moodustasid	doc_713316236908_item	2829293	et	4	main
vaid	doc_713316236908_item	2829294	et	3	main
võõrtööjõudu	doc_713316236908_item	2829298	et	4	main
lihtsate	doc_713316236908_item	2829300	et	3	main
tegemiseks	doc_713316236908_item	2829302	et	4	main
sest	doc_713316236908_item	2829303	et	4	main
õpilastele	doc_714827497072_item	2829331	et	4	main
et	doc_714827497072_item	2829349	et	3	main
parandada	doc_714827497072_item	2829351	et	3	main
lahendusi	doc_714827497072_item	2829355	et	4	main
suured	doc_714827497072_item	2829364	et	3	main
olid	doc_714827497072_item	2829366	et	4	main
balti	doc_714827497072_item	2829373	et	3	main
eestisse	doc_714827497072_item	2829388	et	4	main
peamiselt	doc_714827497072_item	2829389	et	4	main
venelased	doc_714827497072_item	2829390	et	3	main
siis	doc_714827497072_item	2829421	et	3	main
tihti	doc_714827497072_item	2829423	et	3	main
elupinda	doc_714827497072_item	2829425	et	4	main
loodusprobleemide	doc_714827497072_item	2829434	et	3	main
kõige	doc_714827497072_item	2829436	et	4	main
said	doc_714827497072_item	2829450	et	4	main
mis	doc_714827497072_item	2829471	et	4	main
sellele	doc_714827497072_item	2829485	et	4	main
et	doc_714827497072_item	2829486	et	3	main
algas	doc_714827497072_item	2829487	et	3	main
erinevust	doc_714827497072_item	2829521	et	4	main
vastupidine	doc_714827497072_item	2829525	et	3	main
2	doc_714827497072_item	2829527	et	2	main
minu	doc_714827497072_item	2829528	et	3	main
arvates	doc_714827497072_item	2829529	et	4	main
film	doc_714827497072_item	2829530	et	3	main
sobiks	doc_714827497072_item	2829535	et	4	main
tõesti	doc_714827497072_item	2829553	et	3	main
probleemid	doc_714827497072_item	2829556	et	3	main
rõõmud	doc_714827497072_item	2829558	et	3	main
meelest	doc_714827497072_item	2829560	et	4	main
kui	doc_714827497072_item	2829571	et	3	main
alati	doc_714827497072_item	2829593	et	4	main
tähtis	doc_714827497072_item	2829594	et	4	main
teada	doc_714827497072_item	2829595	et	3	main
kontrolltöö	doc_714827497073_item	2829616	et	4	main
1	doc_714827497073_item	2829617	et	2	main
süsteemile	doc_713316236908_item	2829222	et	3	main
muusikas	doc_713316236908_item	2829224	et	3	main
tekkis	doc_713316236908_item	2829225	et	3	main
levimuusika	doc_713316236908_item	2829241	et	4	main
naissoo	doc_713316236908_item	2829246	et	4	main
oli	doc_713316236908_item	2829250	et	3	main
soome	doc_713316236908_item	2829253	et	3	main
rahvale	doc_713316236908_item	2829258	et	3	main
mis	doc_713316236908_item	2829262	et	4	main
toimub	doc_713316236908_item	2829263	et	3	main
alguse	doc_713316236908_item	2829266	et	3	main
välismaist	doc_713316236908_item	2829267	et	4	main
päritolu	doc_713316236908_item	2829268	et	4	main
toodete	doc_713316236908_item	2829269	et	3	main
kultus	doc_713316236908_item	2829270	et	3	main
küll	doc_713316236908_item	2829271	et	4	main
piirangutega	doc_713316236908_item	2829272	et	3	main
kuid	doc_713316236908_item	2829273	et	4	main
siiski	doc_713316236908_item	2829274	et	4	main
sai	doc_713316236908_item	2829275	et	4	main
suhelda	doc_713316236908_item	2829276	et	4	main
muu	doc_713316236908_item	2829277	et	4	main
maailmaga	doc_713316236908_item	2829278	et	3	main
osaliselt	doc_713316236908_item	2829279	et	4	main
ka	doc_713316236908_item	2829280	et	3	main
tänu	doc_713316236908_item	2829281	et	4	main
asendile	doc_713316236908_item	2829283	et	3	main
60	doc_713316236908_item	2829295	et	2	main
torujüri	doc_713316236908_item	2829309	et	4	main
kontrolltöö	doc_714827497072_item	2829310	et	4	main
1	doc_714827497072_item	2829311	et	2	main
2	doc_714827497072_item	2829319	et	2	main
kruusemendilutsu	doc_714827497072_item	2829320	et	4	main
sobiks	doc_714827497072_item	2829325	et	4	main
mitte-eestlastest	doc_714827497072_item	2829329	et	4	main
põhikooli	doc_714827497072_item	2829330	et	4	main
perioodi	doc_714827497072_item	2829337	et	4	main
ja	doc_714827497072_item	2829344	et	3	main
kultuuri	doc_714827497072_item	2829345	et	4	main
probleemide	doc_714827497072_item	2829346	et	3	main
uusi	doc_714827497072_item	2829354	et	3	main
keskvõim	doc_714827497072_item	2829356	et	3	main
aga	doc_714827497072_item	2829358	et	3	main
skeemi	doc_714827497072_item	2829360	et	4	main
ida-virumaal	doc_714827497072_item	2829369	et	4	main
seotus	doc_714827497072_item	2829370	et	4	main
põlevkivi	doc_714827497072_item	2829371	et	4	main
kaevandamisega	doc_714827497072_item	2829372	et	4	main
nõudsid	doc_714827497072_item	2829380	et	4	main
aga	doc_714827497072_item	2829381	et	3	main
tööjõudu	doc_714827497072_item	2829382	et	4	main
umbes	doc_714827497072_item	2829391	et	4	main
siis	doc_714827497072_item	2829395	et	3	main
tekkisid	doc_714827497072_item	2829396	et	4	main
uued	doc_714827497072_item	2829397	et	3	main
probleemid	doc_714827497072_item	2829398	et	3	main
seotud	doc_714827497072_item	2829399	et	4	main
migrantidega	doc_714827497072_item	2829400	et	3	main
kes	doc_714827497072_item	2829401	et	4	main
ei	doc_714827497072_item	2829402	et	4	main
tunnustanud	doc_714827497072_item	2829403	et	4	main
eesti	doc_714827497072_item	2829404	et	4	main
omapära	doc_714827497072_item	2829405	et	4	main
vaid	doc_714827497072_item	2829406	et	3	main
pidid	doc_714827497072_item	2829407	et	4	main
seda	doc_714827497072_item	2829408	et	3	main
ainult	doc_714827497072_item	2829409	et	4	main
nsv-liidu	doc_714827497072_item	2829410	et	3	main
osaks	doc_714827497072_item	2829411	et	3	main
nt	doc_714827497072_item	2829412	et	4	main
kui	doc_714827497072_item	2829413	et	3	main
põliselanikute	doc_714827497072_item	2829414	et	4	main
jaoks	doc_714827497072_item	2829415	et	4	main
korteri	doc_714827497072_item	2829416	et	3	main
järjekord	doc_714827497072_item	2829417	et	3	main
suurenes	doc_714827497072_item	2829418	et	4	main
15-20	doc_714827497072_item	2829419	et	2	main
aastani	doc_714827497072_item	2829420	et	3	main
järjekorrata	doc_714827497072_item	2829427	et	3	main
arenemine	doc_714827497072_item	2829431	et	4	main
rohkem	doc_714827497072_item	2829437	et	4	main
nappis	doc_714827497072_item	2829438	et	3	main
puid	doc_714827497072_item	2829439	et	3	main
ja	doc_714827497072_item	2829440	et	3	main
palju	doc_714827497072_item	2829441	et	4	main
loodusobjekte	doc_714827497072_item	2829442	et	3	main
mõned	doc_714827497072_item	2829443	et	3	main
linnad	doc_714827497072_item	2829444	et	3	main
vana	doc_714827497072_item	2829359	et	4	main
uued	doc_714827497072_item	2829363	et	3	main
ettevõted	doc_714827497072_item	2829365	et	4	main
loodud	doc_714827497072_item	2829367	et	4	main
peamiselt	doc_714827497072_item	2829368	et	4	main
elektrijaam	doc_714827497072_item	2829375	et	3	main
ja	doc_714827497072_item	2829376	et	3	main
need	doc_714827497072_item	2829378	et	3	main
inimest	doc_714827497072_item	2829393	et	3	main
ilma	doc_714827497072_item	2829426	et	4	main
kiir	doc_714827497072_item	2829430	et	4	main
tõi	doc_714827497072_item	2829432	et	3	main
halvenemist	doc_714827497072_item	2829435	et	4	main
kinnise	doc_714827497072_item	2829451	et	4	main
narva	doc_714827497072_item	2829456	et	4	main
need	doc_714827497072_item	2829457	et	3	main
olid	doc_714827497072_item	2829458	et	4	main
nagu	doc_714827497072_item	2829459	et	3	main
eestlaste	doc_714827497072_item	2829476	et	4	main
ja	doc_714827497072_item	2829477	et	3	main
migrantide	doc_714827497072_item	2829478	et	3	main
et	doc_714827497072_item	2829491	et	3	main
eestisse	doc_714827497072_item	2829494	et	4	main
oli	doc_714827497072_item	2829495	et	3	main
tingitud	doc_714827497072_item	2829496	et	4	main
mitte	doc_714827497072_item	2829497	et	3	main
ainult	doc_714827497072_item	2829498	et	4	main
tööjõu	doc_714827497072_item	2829499	et	3	main
nappimisega	doc_714827497072_item	2829500	et	4	main
aga	doc_714827497072_item	2829501	et	3	main
see	doc_714827497072_item	2829502	et	3	main
oli	doc_714827497072_item	2829503	et	3	main
samuti	doc_714827497072_item	2829504	et	3	main
poliitiline	doc_714827497072_item	2829505	et	3	main
viis	doc_714827497072_item	2829506	et	4	main
selleks	doc_714827497072_item	2829507	et	4	main
et	doc_714827497072_item	2829508	et	3	main
vähendada	doc_714827497072_item	2829509	et	3	main
eestlaste	doc_714827497072_item	2829510	et	4	main
kultuuri	doc_714827497072_item	2829511	et	4	main
tähtsus	doc_714827497072_item	2829512	et	4	main
ja	doc_714827497072_item	2829513	et	3	main
luua	doc_714827497072_item	2829514	et	4	main
üleliidu	doc_714827497072_item	2829515	et	3	main
rahvast	doc_714827497072_item	2829516	et	4	main
vähendada	doc_714827497072_item	2829517	et	3	main
eestlaste	doc_714827497072_item	2829518	et	4	main
ja	doc_714827497072_item	2829519	et	3	main
muulaste	doc_714827497072_item	2829520	et	4	main
oli	doc_714827497072_item	2829523	et	3	main
aga	doc_714827497072_item	2829524	et	3	main
o	doc_714827497072_item	2829531	et	4	main
kõigepealt	doc_714827497072_item	2829539	et	3	main
elu	doc_714827497072_item	2829549	et	4	main
nii	doc_714827497072_item	2829550	et	3	main
nagu	doc_714827497072_item	2829551	et	3	main
see	doc_714827497072_item	2829561	et	3	main
lihtsalt	doc_714827497072_item	2829570	et	4	main
väga	doc_714827497072_item	2829577	et	3	main
ajalooliselt	doc_714827497072_item	2829579	et	4	main
see	doc_714827497072_item	2829580	et	3	main
lubab	doc_714827497072_item	2829581	et	3	main
võrrelda	doc_714827497072_item	2829582	et	4	main
mineviku	doc_714827497072_item	2829583	et	3	main
kus	doc_714827497072_item	2829445	et	3	main
staatuse	doc_714827497072_item	2829453	et	3	main
sillamäe	doc_714827497072_item	2829455	et	3	main
riigid	doc_714827497072_item	2829470	et	3	main
oma	doc_714827497072_item	2829473	et	4	main
eluga	doc_714827497072_item	2829474	et	3	main
erinevus	doc_714827497072_item	2829475	et	4	main
tänu	doc_714827497072_item	2829484	et	4	main
arvan	doc_714827497072_item	2829490	et	3	main
vool	doc_714827497072_item	2829493	et	4	main
mitte-eestlastest	doc_714827497072_item	2829536	et	4	main
selle	doc_714827497072_item	2829540	et	4	main
oli	doc_714827497072_item	2829554	et	3	main
mitte	doc_714827497072_item	2829563	et	3	main
mitte-eestlastele	doc_714827497072_item	2829565	et	4	main
aga	doc_714827497072_item	2829566	et	3	main
ka	doc_714827497072_item	2829567	et	3	main
eesti	doc_714827497072_item	2829568	et	4	main
mineviku	doc_714827497072_item	2829572	et	3	main
filmon	doc_714827497072_item	2829576	et	4	main
tähtis	doc_714827497072_item	2829578	et	4	main
arusaamise	doc_714827497072_item	2829614	et	4	main
kaudu	doc_714827497072_item	2829615	et	3	main
migratsiooni	doc_714827497073_item	2829620	et	4	main
seosed	doc_714827497073_item	2829621	et	3	main
ja	doc_714827497073_item	2829629	et	3	main
aastatel	doc_714827497073_item	2829640	et	4	main
hakkas	doc_714827497073_item	2829641	et	3	main
nõukogude	doc_714827497073_item	2829642	et	3	main
majandus	doc_714827497073_item	2829643	et	4	main
paremini	doc_714827497073_item	2829644	et	4	main
arenema	doc_714827497073_item	2829645	et	3	main
seega	doc_714827497073_item	2829646	et	4	main
ka	doc_714827497073_item	2829647	et	3	main
eestis	doc_714827497073_item	2829648	et	3	main
kasulik	doc_714827497073_item	2829662	et	3	main
eesti	doc_714827497073_item	2829663	et	4	main
põllumajandus	doc_714827497073_item	2829665	et	3	main
arenes	doc_714827497073_item	2829666	et	3	main
kiiresti	doc_714827497073_item	2829667	et	3	main
kolhoosid	doc_714827497073_item	2829668	et	3	main
olid	doc_714827497073_item	2829669	et	4	main
küsimus	doc_714827497073_item	2829677	et	4	main
endiselt	doc_714827497073_item	2829680	et	4	main
tööle	doc_714827497073_item	2829684	et	3	main
kaugele	doc_714827497073_item	2829685	et	4	main
nende	doc_714827497073_item	2829686	et	4	main
ja	doc_714827497073_item	2829697	et	3	main
riikides	doc_714827497073_item	2829706	et	3	main
seal	doc_714827497073_item	2829709	et	4	main
meelest	doc_714827497073_item	2829713	et	4	main
võis	doc_714827497073_item	2829715	et	4	main
suurepärane	doc_714827497073_item	2829727	et	4	main
arvan	doc_714827497073_item	2829733	et	3	main
õpilastel	doc_714827497073_item	2829736	et	4	main
õppevahendiks	doc_714827497073_item	2829746	et	3	main
see	doc_714827497073_item	2829747	et	3	main
eesti	doc_714827497073_item	2829756	et	4	main
kuidas	doc_714827497073_item	2829763	et	3	main
ja	doc_714827497073_item	2829767	et	3	main
nende	doc_714827497073_item	2829770	et	4	main
sea	doc_714827497073_item	2829777	et	4	main
ajastut	doc_714827497073_item	2829778	et	3	main
ja	doc_714827497073_item	2829779	et	3	main
selles	doc_714827497073_item	2829782	et	4	main
film	doc_714827497073_item	2829816	et	3	main
oleks	doc_714827497073_item	2829817	et	3	main
märka	doc_714827497073_item	2829826	et	4	main
aru	doc_714827497073_item	2829830	et	4	main
sellest	doc_714827497073_item	2829831	et	4	main
vaadata	doc_714827497073_item	2829839	et	4	main
arvan	doc_714827497073_item	2829845	et	3	main
võivad	doc_714827497073_item	2829850	et	4	main
sealt	doc_714827497073_item	2829851	et	4	main
kui	doc_723935141568_item	2829857	et	3	main
ma	doc_723935141568_item	2829858	et	3	main
sõna	doc_723935141568_item	2829860	et	4	main
kujutan	doc_723935141568_item	2829863	et	3	main
või	doc_723935141568_item	2829869	et	4	main
ja	doc_723935141568_item	2829875	et	3	main
muidugi	doc_723935141568_item	2829886	et	4	main
lutsu	doc_714827497072_item	2829532	et	4	main
kevade	doc_714827497072_item	2829533	et	4	main
õpilastele	doc_714827497072_item	2829538	et	4	main
poolest	doc_714827497072_item	2829541	et	4	main
see	doc_714827497072_item	2829543	et	3	main
selgelt	doc_714827497072_item	2829544	et	4	main
näitab	doc_714827497072_item	2829545	et	3	main
tolleaegsete	doc_714827497072_item	2829546	et	4	main
noorte	doc_714827497072_item	2829547	et	3	main
inimeste	doc_714827497072_item	2829548	et	3	main
nende	doc_714827497072_item	2829555	et	4	main
ja	doc_714827497072_item	2829557	et	3	main
õpilastele	doc_714827497072_item	2829569	et	4	main
aja	doc_714827497072_item	2829573	et	4	main
see	doc_714827497072_item	2829575	et	3	main
alu	doc_714827497072_item	2829586	et	4	main
nt	doc_714827497072_item	2829587	et	4	main
õpetajate	doc_714827497072_item	2829588	et	4	main
suhtumine	doc_714827497072_item	2829589	et	4	main
on	doc_714827497072_item	2829592	et	4	main
see	doc_714827497072_item	2829602	et	3	main
aitab	doc_714827497072_item	2829603	et	3	main
paremini	doc_714827497072_item	2829604	et	4	main
mõista	doc_714827497072_item	2829605	et	4	main
paremini	doc_714827497072_item	2829609	et	4	main
ja	doc_714827497073_item	2829619	et	3	main
nsv-s	doc_714827497073_item	2829624	et	3	main
kas	doc_714827497073_item	2829628	et	3	main
sobiks	doc_714827497073_item	2829631	et	4	main
film	doc_714827497073_item	2829633	et	3	main
mitte-eestlastest	doc_714827497073_item	2829635	et	4	main
olnud	doc_714827497073_item	2829661	et	4	main
kui	doc_714827497073_item	2829674	et	3	main
keeruline	doc_714827497073_item	2829681	et	4	main
saadeti	doc_714827497073_item	2829683	et	3	main
neil	doc_714827497073_item	2829693	et	4	main
võimalust	doc_714827497073_item	2829694	et	3	main
tagasi	doc_714827497073_item	2829695	et	3	main
tulla	doc_714827497073_item	2829696	et	3	main
elasid	doc_714827497073_item	2829701	et	4	main
või	doc_714827497073_item	2829703	et	4	main
elavad	doc_714827497073_item	2829708	et	4	main
tänapäevani	doc_714827497073_item	2829710	et	3	main
see	doc_714827497073_item	2829714	et	3	main
aidata	doc_714827497073_item	2829716	et	4	main
majanduse	doc_714827497073_item	2829717	et	4	main
tahaks	doc_714827497073_item	2829722	et	3	main
raamat	doc_714827497073_item	2829728	et	3	main
et	doc_714827497073_item	2829734	et	3	main
huvitav	doc_714827497073_item	2829739	et	4	main
seda	doc_714827497073_item	2829740	et	3	main
film	doc_714827497073_item	2829748	et	3	main
külades	doc_714827497073_item	2829757	et	3	main
seal	doc_714827497073_item	2829758	et	4	main
viha	doc_714827497073_item	2829771	et	4	main
selle	doc_714827497073_item	2829780	et	4	main
on	doc_714827497073_item	2829784	et	4	main
arvan	doc_714827497073_item	2829813	et	3	main
parem	doc_714827497073_item	2829818	et	4	main
ja	doc_714827497072_item	2829584	et	3	main
oleviku	doc_714827497072_item	2829585	et	3	main
õpilastele	doc_714827497072_item	2829590	et	4	main
selle	doc_714827497072_item	2829596	et	4	main
riigi	doc_714827497072_item	2829597	et	3	main
eestlaste	doc_714827497072_item	2829606	et	4	main
olemust	doc_714827497072_item	2829607	et	3	main
õnnestub	doc_714827497072_item	2829611	et	3	main
igapäevase	doc_714827497072_item	2829612	et	4	main
elu	doc_714827497072_item	2829613	et	4	main
2	doc_714827497073_item	2829625	et	2	main
kevade	doc_714827497073_item	2829627	et	4	main
tõusis	doc_714827497073_item	2829650	et	4	main
hakkasid	doc_714827497073_item	2829651	et	4	main
arenema	doc_714827497073_item	2829652	et	3	main
ei	doc_714827497073_item	2829660	et	4	main
loodusele	doc_714827497073_item	2829664	et	4	main
nüüd	doc_714827497073_item	2829670	et	4	main
pisut	doc_714827497073_item	2829671	et	3	main
migratsiooni	doc_714827497073_item	2829676	et	4	main
aga	doc_714827497073_item	2829679	et	3	main
inimesi	doc_714827497073_item	2829682	et	4	main
olnud	doc_714827497073_item	2829692	et	4	main
eestlased	doc_714827497073_item	2829700	et	3	main
venemaal	doc_714827497073_item	2829702	et	4	main
teistes	doc_714827497073_item	2829704	et	4	main
mõned	doc_714827497073_item	2829707	et	3	main
minu	doc_714827497073_item	2829712	et	3	main
et	doc_714827497073_item	2829724	et	3	main
see	doc_714827497073_item	2829725	et	3	main
sobiks	doc_714827497073_item	2829744	et	4	main
oli	doc_714827497073_item	2829752	et	3	main
on	doc_714827497073_item	2829759	et	4	main
näidatud	doc_714827497073_item	2829760	et	4	main
elasid	doc_714827497073_item	2829764	et	4	main
saksa	doc_714827497073_item	2829768	et	4	main
lapsed	doc_714827497073_item	2829769	et	3	main
mõista	doc_714827497073_item	2829776	et	4	main
ka	doc_714827497073_item	2829785	et	3	main
see	doc_714827497073_item	2829815	et	3	main
õpilastele	doc_714827497073_item	2829821	et	4	main
paljud	doc_714827497073_item	2829823	et	3	main
õppusest	doc_714827497073_item	2829832	et	4	main
aga	doc_714827497073_item	2829833	et	3	main
muidu	doc_714827497073_item	2829834	et	3	main
seda	doc_714827497073_item	2829835	et	3	main
lastele	doc_714827497073_item	2829843	et	4	main
näiteks	doc_723935141568_item	2829867	et	4	main
meelde	doc_723935141568_item	2829873	et	3	main
veel	doc_723935141568_item	2829878	et	4	main
on	doc_723935141568_item	2829881	et	4	main
ka	doc_723935141568_item	2829882	et	3	main
teater	doc_723935141568_item	2829883	et	3	main
kino	doc_723935141568_item	2829884	et	4	main
ja	doc_723935141568_item	2829885	et	3	main
see	doc_714827497072_item	2829610	et	3	main
majanduse	doc_714827497073_item	2829618	et	4	main
eesti	doc_714827497073_item	2829623	et	4	main
kuidas	doc_714827497073_item	2829630	et	3	main
1970ndatel	doc_714827497073_item	2829639	et	4	main
ta	doc_714827497073_item	2829649	et	4	main
see	doc_714827497073_item	2829659	et	3	main
seisundis	doc_714827497073_item	2829673	et	3	main
kodust	doc_714827497073_item	2829687	et	4	main
ja	doc_714827497073_item	2829688	et	3	main
üsna	doc_714827497073_item	2829689	et	3	main
tihti	doc_714827497073_item	2829690	et	3	main
seetõttu	doc_714827497073_item	2829698	et	3	main
nsv	doc_714827497073_item	2829705	et	4	main
arenemist	doc_714827497073_item	2829718	et	4	main
2	doc_714827497073_item	2829719	et	2	main
kevade	doc_714827497073_item	2829720	et	4	main
1970ndate	doc_714827497073_item	2829622	et	4	main
kruusemendilutsu	doc_714827497073_item	2829626	et	4	main
see	doc_714827497073_item	2829632	et	3	main
õppevahendiks	doc_714827497073_item	2829634	et	3	main
põhikooli	doc_714827497073_item	2829636	et	4	main
õpilastele	doc_714827497073_item	2829637	et	4	main
1	doc_714827497073_item	2829638	et	2	main
tehased	doc_714827497073_item	2829653	et	3	main
ja	doc_714827497073_item	2829654	et	3	main
algas	doc_714827497073_item	2829655	et	3	main
põlevkivi	doc_714827497073_item	2829656	et	4	main
kaevandus	doc_714827497073_item	2829657	et	4	main
kuigi	doc_714827497073_item	2829658	et	3	main
paremas	doc_714827497073_item	2829672	et	4	main
ennem	doc_714827497073_item	2829675	et	4	main
oli	doc_714827497073_item	2829678	et	3	main
ei	doc_714827497073_item	2829691	et	4	main
paljud	doc_714827497073_item	2829699	et	3	main
kuid	doc_714827497073_item	2829711	et	4	main
ja	doc_714827497073_item	2829729	et	3	main
film	doc_714827497073_item	2829730	et	3	main
ma	doc_714827497073_item	2829732	et	3	main
kindlasti	doc_714827497073_item	2829745	et	3	main
näitab	doc_714827497073_item	2829749	et	3	main
elu	doc_714827497073_item	2829750	et	4	main
kõrvuti	doc_714827497073_item	2829765	et	3	main
eesti	doc_714827497073_item	2829766	et	4	main
filmis	doc_714827497073_item	2829783	et	4	main
et	doc_714827497073_item	2829814	et	3	main
gümnaasiumi	doc_714827497073_item	2829820	et	4	main
ja	doc_714827497073_item	2829827	et	3	main
saa	doc_714827497073_item	2829829	et	4	main
kõikidele	doc_714827497073_item	2829840	et	4	main
mitte	doc_714827497073_item	2829841	et	3	main
ainult	doc_714827497073_item	2829842	et	4	main
1	doc_723935141568_item	2829856	et	2	main
kuulen	doc_723935141568_item	2829859	et	3	main
ma	doc_723935141568_item	2829862	et	3	main
kunst	doc_723935141568_item	2829870	et	3	main
üldse	doc_723935141568_item	2829876	et	3	main
seotud	doc_723935141568_item	2829893	et	4	main
tammsaare	doc_723935141568_item	2829903	et	3	main
muidugi	doc_723935141568_item	2829906	et	4	main
arvates	doc_723935141568_item	2829910	et	4	main
kultuur	doc_723935141570_item	2830036	et	3	main
all	doc_723935141570_item	2830038	et	3	main
teater	doc_723935141570_item	2830041	et	3	main
kirjandus	doc_723935141570_item	2830043	et	3	main
ka	doc_723935141570_item	2830045	et	3	main
rahval	doc_723935141570_item	2830047	et	3	main
elavad	doc_723935141570_item	2830053	et	4	main
räägivad	doc_723935141570_item	2830056	et	3	main
on	doc_723935141570_item	2830058	et	4	main
nende	doc_723935141570_item	2830059	et	4	main
meile	doc_723935141570_item	2830068	et	4	main
mis	doc_723935141570_item	2830069	et	4	main
ta	doc_723935141570_item	2830072	et	4	main
vaja	doc_723935141570_item	2830082	et	4	main
käituda	doc_723935141570_item	2830083	et	3	main
ja	doc_723935141570_item	2830090	et	3	main
ütleb	doc_723935141570_item	2830092	et	3	main
tere	doc_723935141570_item	2830093	et	3	main
muidugi	doc_723935141570_item	2830094	et	4	main
et	doc_723935141570_item	2830103	et	3	main
see	doc_723935141570_item	2830104	et	3	main
hästikasvatatud	doc_723935141570_item	2830109	et	3	main
eesti	doc_723935141570_item	2830111	et	4	main
ülikool	doc_724355862913_item	2830121	et	4	main
olen	doc_724355862913_item	2830123	et	3	main
lõpetasin	doc_724355862913_item	2830134	et	3	main
eriala	doc_724355862913_item	2830139	et	4	main
kõigepealt	doc_714827497073_item	2829721	et	3	main
öelda	doc_714827497073_item	2829723	et	4	main
on	doc_714827497073_item	2829726	et	4	main
ja	doc_714827497073_item	2829731	et	3	main
põhikooli	doc_714827497073_item	2829735	et	4	main
oleks	doc_714827497073_item	2829737	et	3	main
väga	doc_714827497073_item	2829738	et	3	main
näha	doc_714827497073_item	2829741	et	3	main
ja	doc_714827497073_item	2829742	et	3	main
see	doc_714827497073_item	2829743	et	3	main
mis	doc_714827497073_item	2829751	et	4	main
20-da	doc_714827497073_item	2829753	et	4	main
sajandi	doc_714827497073_item	2829754	et	3	main
alguses	doc_714827497073_item	2829755	et	4	main
õpilaste	doc_714827497073_item	2829761	et	4	main
suhteid	doc_714827497073_item	2829762	et	3	main
üksteise	doc_714827497073_item	2829772	et	4	main
vastu	doc_714827497073_item	2829773	et	3	main
aitab	doc_714827497073_item	2829774	et	3	main
paremini	doc_714827497073_item	2829775	et	4	main
iseloome	doc_714827497073_item	2829781	et	4	main
palju	doc_714827497073_item	2829786	et	4	main
inimlikust	doc_714827497073_item	2829787	et	4	main
näiteks	doc_714827497073_item	2829788	et	4	main
arno	doc_714827497073_item	2829789	et	4	main
suhted	doc_714827497073_item	2829790	et	3	main
oma	doc_714827497073_item	2829791	et	4	main
õpetajaga	doc_714827497073_item	2829792	et	4	main
kes	doc_714827497073_item	2829793	et	4	main
oli	doc_714827497073_item	2829794	et	3	main
arno	doc_714827497073_item	2829795	et	4	main
jaoks	doc_714827497073_item	2829796	et	4	main
mitte	doc_714827497073_item	2829797	et	3	main
ainult	doc_714827497073_item	2829798	et	4	main
kooli	doc_714827497073_item	2829799	et	4	main
õpetaja	doc_714827497073_item	2829800	et	4	main
ta	doc_714827497073_item	2829801	et	4	main
oli	doc_714827497073_item	2829802	et	3	main
midagi	doc_714827497073_item	2829803	et	4	main
rohkemat	doc_714827497073_item	2829804	et	4	main
ta	doc_714827497073_item	2829805	et	4	main
õpetas	doc_714827497073_item	2829806	et	3	main
kudias	doc_714827497073_item	2829807	et	4	main
elust	doc_714827497073_item	2829808	et	3	main
rõõmu	doc_714827497073_item	2829809	et	4	main
tunda	doc_714827497073_item	2829810	et	3	main
kuid	doc_714827497073_item	2829811	et	4	main
ma	doc_714827497073_item	2829812	et	3	main
õppevahendina	doc_714827497073_item	2829819	et	3	main
põhikoolilapsed	doc_714827497073_item	2829824	et	3	main
ei	doc_714827497073_item	2829825	et	4	main
oleks	doc_714827497073_item	2829837	et	3	main
et	doc_714827497073_item	2829846	et	3	main
midagi	doc_714827497073_item	2829852	et	4	main
õppida	doc_714827497073_item	2829853	et	3	main
vastus	doc_723935141568_item	2829854	et	3	main
muusika	doc_723935141568_item	2829868	et	4	main
ajalugu	doc_723935141568_item	2829874	et	4	main
tsivilisatsioon	doc_723935141568_item	2829877	et	3	main
kultuuri	doc_723935141568_item	2829879	et	4	main
2	doc_723935141568_item	2829888	et	2	main
minu	doc_723935141568_item	2829891	et	3	main
ernesaks	doc_723935141568_item	2829902	et	4	main
jne	doc_723935141568_item	2829904	et	4	main
aga	doc_723935141568_item	2829905	et	3	main
assotsiatsioon	doc_723935141568_item	2829908	et	3	main
rahvuseepos	doc_723935141568_item	2829913	et	3	main
kuulsamad	doc_723935141568_item	2829916	et	4	main
vastus	doc_723935141570_item	2830033	et	3	main
kultuuri	doc_723935141570_item	2830037	et	4	main
on	doc_723935141570_item	2830048	et	4	main
oma	doc_723935141570_item	2830049	et	4	main
kultuur	doc_723935141570_item	2830050	et	3	main
kuidas	doc_723935141570_item	2830051	et	3	main
kultuur	doc_723935141570_item	2830071	et	3	main
meid	doc_723935141570_item	2830074	et	4	main
kuidas	doc_723935141570_item	2830075	et	3	main
me	doc_723935141570_item	2830076	et	4	main
peame	doc_723935141570_item	2830077	et	4	main
istuma	doc_723935141570_item	2830078	et	3	main
õpis	doc_723935141570_item	2830079	et	3	main
kuidas	doc_723935141570_item	2830080	et	3	main
tuleb	doc_723935141570_item	2830088	et	3	main
võime	doc_723935141570_item	2830100	et	4	main
ka	doc_723935141570_item	2830101	et	3	main
aastat	doc_724355862913_item	2830125	et	3	main
elan	doc_724355862913_item	2830128	et	3	main
tallinnas	doc_724355862913_item	2830130	et	4	main
selles	doc_724355862913_item	2830131	et	4	main
aastal	doc_724355862913_item	2830132	et	3	main
polütehnikum	doc_724355862913_item	2830136	et	3	main
edasi	doc_724355862913_item	2830147	et	3	main
eriala	doc_724355862913_item	2830154	et	4	main
aga	doc_724355862913_item	2830155	et	3	main
miks	doc_724355862913_item	2830156	et	4	main
selle	doc_724355862913_item	2830160	et	4	main
et	doc_724355862913_item	2830162	et	3	main
mul	doc_724355862913_item	2830163	et	3	main
on	doc_724355862913_item	2830164	et	4	main
kergem	doc_724355862913_item	2830172	et	4	main
õppida	doc_724355862913_item	2830173	et	3	main
ma	doc_724355862913_item	2830174	et	3	main
praktika	doc_724355862913_item	2830222	et	4	main
püan	doc_724355862913_item	2830224	et	4	main
rääkida	doc_724355862913_item	2830225	et	3	main
aitavad	doc_724355862913_item	2830230	et	4	main
ma	doc_724355862913_item	2830233	et	3	main
ainult	doc_724355862913_item	2830235	et	4	main
eesti	doc_724355862913_item	2830241	et	4	main
hea	doc_724355862913_item	2830260	et	4	main
sest	doc_714827497073_item	2829822	et	4	main
ei	doc_714827497073_item	2829828	et	4	main
filmi	doc_714827497073_item	2829836	et	4	main
kasulik	doc_714827497073_item	2829838	et	3	main
ma	doc_714827497073_item	2829844	et	3	main
ka	doc_714827497073_item	2829847	et	3	main
vanemad	doc_714827497073_item	2829848	et	4	main
inimesed	doc_714827497073_item	2829849	et	3	main
küsimusele	doc_723935141568_item	2829855	et	4	main
kultuur	doc_723935141568_item	2829861	et	3	main
ette	doc_723935141568_item	2829864	et	4	main
mingisugust	doc_723935141568_item	2829865	et	3	main
väärtust	doc_723935141568_item	2829866	et	4	main
veel	doc_723935141568_item	2829871	et	4	main
tuleb	doc_723935141568_item	2829872	et	3	main
osad	doc_723935141568_item	2829880	et	3	main
meeles	doc_723935141568_item	2829892	et	3	main
eesti	doc_723935141568_item	2829895	et	4	main
näiteks	doc_723935141568_item	2829897	et	4	main
on	doc_723935141568_item	2829911	et	4	main
ja	doc_723935141568_item	2829915	et	3	main
1	doc_723935141570_item	2830035	et	2	main
mõistetakse	doc_723935141570_item	2830039	et	3	main
nad	doc_723935141570_item	2830055	et	3	main
lapsepõlvest	doc_723935141570_item	2830065	et	4	main
on	doc_723935141570_item	2830070	et	4	main
õpis	doc_723935141570_item	2830073	et	3	main
end	doc_723935141570_item	2830084	et	4	main
sisse	doc_723935141570_item	2830089	et	4	main
ta	doc_723935141570_item	2830091	et	4	main
loomulikult	doc_723935141570_item	2830097	et	4	main
aga	doc_723935141570_item	2830098	et	3	main
kultuurne	doc_723935141570_item	2830107	et	3	main
koosneb	doc_723935141570_item	2830115	et	3	main
ma	doc_724355862913_item	2830133	et	3	main
saan	doc_724355862913_item	2830138	et	4	main
soojus	doc_724355862913_item	2830142	et	4	main
valin	doc_724355862913_item	2830158	et	3	main
pärast	doc_724355862913_item	2830161	et	4	main
juba	doc_724355862913_item	2830165	et	3	main
töstus-	doc_724355862913_item	2830166	et	4	main
ja	doc_724355862913_item	2830167	et	3	main
praegu	doc_724355862913_item	2830177	et	3	main
selle	doc_724355862913_item	2830179	et	4	main
kirjandus	doc_723935141568_item	2829887	et	3	main
eesti	doc_723935141568_item	2829889	et	4	main
kultuur	doc_723935141568_item	2829890	et	3	main
paljude	doc_723935141568_item	2829894	et	3	main
nimedega	doc_723935141568_item	2829896	et	3	main
krewtzwald	doc_723935141568_item	2829898	et	4	main
koidula	doc_723935141568_item	2829899	et	4	main
luts	doc_723935141568_item	2829900	et	3	main
gustav	doc_723935141568_item	2829901	et	4	main
esimene	doc_723935141568_item	2829907	et	3	main
minu	doc_723935141568_item	2829909	et	3	main
meie	doc_723935141568_item	2829912	et	4	main
kalevipoeg	doc_723935141568_item	2829914	et	3	main
laulupeod	doc_723935141568_item	2829917	et	4	main
lauluväljakul	doc_723935141568_item	2829918	et	3	main
küsimusele	doc_723935141570_item	2830034	et	4	main
nad	doc_723935141570_item	2830052	et	3	main
kuidas	doc_723935141570_item	2830054	et	3	main
mis	doc_723935141570_item	2830057	et	4	main
ema	doc_723935141570_item	2830066	et	4	main
ütles	doc_723935141570_item	2830067	et	3	main
on	doc_723935141570_item	2830081	et	4	main
see	doc_723935141570_item	2830095	et	3	main
on	doc_723935141570_item	2830096	et	4	main
öelda	doc_723935141570_item	2830102	et	4	main
inimene	doc_723935141570_item	2830105	et	3	main
on	doc_723935141570_item	2830106	et	4	main
2	doc_723935141570_item	2830110	et	2	main
kultuur	doc_723935141570_item	2830112	et	3	main
kultuur	doc_723935141570_item	2830114	et	3	main
eesti	doc_723935141570_item	2830116	et	4	main
kirjandusest	doc_723935141570_item	2830117	et	4	main
essee	doc_724355862913_item	2830118	et	4	main
mina	doc_724355862913_item	2830119	et	4	main
ja	doc_724355862913_item	2830120	et	3	main
ma	doc_724355862913_item	2830122	et	3	main
ma	doc_724355862913_item	2830127	et	3	main
eestis	doc_724355862913_item	2830129	et	3	main
tallinna	doc_724355862913_item	2830135	et	4	main
automaatika	doc_724355862913_item	2830143	et	4	main
siis	doc_724355862913_item	2830144	et	3	main
ma	doc_724355862913_item	2830145	et	3	main
tahan	doc_724355862913_item	2830146	et	3	main
ja	doc_724355862913_item	2830149	et	3	main
bakalaurise	doc_724355862913_item	2830151	et	4	main
soojus	doc_724355862913_item	2830152	et	4	main
tehnika	doc_724355862913_item	2830153	et	4	main
soojus	doc_724355862913_item	2830168	et	4	main
ei	doc_724355862913_item	2830175	et	4	main
tallinna	doc_724355862913_item	2830185	et	4	main
polütehnikum	doc_724355862913_item	2830186	et	3	main
ja	doc_724355862913_item	2830187	et	3	main
mulle	doc_724355862913_item	2830231	et	4	main
töötan	doc_724355862913_item	2830234	et	3	main
nädalat	doc_724355862913_item	2830237	et	3	main
mõtlen	doc_724355862913_item	2830239	et	3	main
keele	doc_724355862913_item	2830242	et	4	main
mina	doc_724355862913_item	2830254	et	4	main
mulle	doc_724355862913_item	2830264	et	4	main
õpida	doc_724355862913_item	2830265	et	4	main
keele	doc_724355862913_item	2830267	et	4	main
olen	doc_724355862914_item	2830281	et	3	main
perekonnanimi	doc_724355862914_item	2830283	et	3	main
ma	doc_724355862914_item	2830284	et	3	main
aastat	doc_724355862914_item	2830288	et	3	main
vana	doc_724355862914_item	2830289	et	4	main
elan	doc_724355862914_item	2830290	et	3	main
tallinnas	doc_724355862914_item	2830291	et	4	main
vaja	doc_724355862914_item	2830302	et	4	main
mul	doc_724355862914_item	2830305	et	3	main
kutsekeskharidus	doc_724355862914_item	2830307	et	3	main
on	doc_724355862914_item	2830311	et	4	main
ka	doc_724355862914_item	2830321	et	3	main
eriala	doc_724355862914_item	2830325	et	4	main
see	doc_724355862914_item	2830327	et	3	main
väga	doc_724355862914_item	2830329	et	3	main
huvitav	doc_724355862914_item	2830330	et	4	main
ja	doc_724355862914_item	2830331	et	3	main
mina	doc_724355862914_item	2830347	et	4	main
siin	doc_724355862914_item	2830349	et	4	main
aga	doc_724355862914_item	2830352	et	3	main
mulje	doc_724355862914_item	2830354	et	4	main
oli	doc_724355862914_item	2830355	et	3	main
vau	doc_724355862914_item	2830356	et	4	main
kui	doc_724355862914_item	2830357	et	3	main
ja	doc_724355862914_item	2830363	et	3	main
loengust	doc_724355862914_item	2830373	et	4	main
muuseum	doc_723935141570_item	2830040	et	3	main
näitus	doc_723935141570_item	2830042	et	3	main
ning	doc_723935141570_item	2830044	et	3	main
igak	doc_723935141570_item	2830046	et	4	main
kombeid	doc_723935141570_item	2830060	et	4	main
ja	doc_723935141570_item	2830061	et	3	main
nii	doc_723935141570_item	2830062	et	3	main
edasi	doc_723935141570_item	2830063	et	3	main
juba	doc_723935141570_item	2830064	et	3	main
ühiskonnas	doc_723935141570_item	2830085	et	4	main
kui	doc_723935141570_item	2830086	et	3	main
inimene	doc_723935141570_item	2830087	et	3	main
me	doc_723935141570_item	2830099	et	4	main
ja	doc_723935141570_item	2830108	et	3	main
eesti	doc_723935141570_item	2830113	et	4	main
20	doc_724355862913_item	2830124	et	2	main
vana	doc_724355862913_item	2830126	et	4	main
ja	doc_724355862913_item	2830137	et	3	main
soojustehnika	doc_724355862913_item	2830159	et	4	main
automaatika	doc_724355862913_item	2830169	et	4	main
ja	doc_724355862913_item	2830170	et	3	main
mulle	doc_724355862913_item	2830171	et	4	main
saanud	doc_724355862913_item	2830176	et	4	main
muljed	doc_724355862913_item	2830178	et	3	main
pärast	doc_724355862913_item	2830180	et	4	main
et	doc_724355862913_item	2830181	et	3	main
olen	doc_724355862913_item	2830182	et	3	main
õppinud	doc_724355862913_item	2830183	et	4	main
se	doc_724355862913_item	2830188	et	4	main
on	doc_724355862913_item	2830189	et	4	main
nagu	doc_724355862913_item	2830190	et	3	main
ttü	doc_724355862913_item	2830191	et	4	main
praegu	doc_724355862913_item	2830192	et	3	main
ma	doc_724355862913_item	2830193	et	3	main
töötan	doc_724355862913_item	2830194	et	3	main
firmas	doc_724355862913_item	2830195	et	3	main
selle	doc_724355862913_item	2830196	et	4	main
nimi	doc_724355862913_item	2830198	et	3	main
firmi	doc_724355862913_item	2830197	et	4	main
on	doc_724355862913_item	2830199	et	4	main
oü	doc_724355862913_item	2830200	et	4	main
napal	doc_724355862913_item	2830201	et	4	main
ja	doc_724355862913_item	2830202	et	3	main
see	doc_724355862913_item	2830203	et	3	main
on	doc_724355862913_item	2830204	et	4	main
eriala	doc_724355862913_item	2830205	et	4	main
töö	doc_724355862913_item	2830206	et	4	main
väga	doc_724355862913_item	2830207	et	3	main
huvitav	doc_724355862913_item	2830208	et	4	main
ja	doc_724355862913_item	2830209	et	3	main
raske	doc_724355862913_item	2830210	et	4	main
töö	doc_724355862913_item	2830211	et	4	main
ka	doc_724355862913_item	2830212	et	3	main
firmas	doc_724355862913_item	2830213	et	3	main
on	doc_724355862913_item	2830214	et	4	main
ainult	doc_724355862913_item	2830215	et	4	main
eestlased	doc_724355862913_item	2830216	et	3	main
ja	doc_724355862913_item	2830217	et	3	main
seal	doc_724355862913_item	2830218	et	4	main
on	doc_724355862913_item	2830219	et	4	main
eesti	doc_724355862913_item	2830220	et	4	main
keele	doc_724355862913_item	2830221	et	4	main
ma	doc_724355862913_item	2830223	et	3	main
eesti	doc_724355862913_item	2830226	et	4	main
aga	doc_724355862913_item	2830232	et	3	main
töstus-	doc_724355862913_item	2830140	et	4	main
ja	doc_724355862913_item	2830141	et	3	main
õppida	doc_724355862913_item	2830148	et	3	main
saada	doc_724355862913_item	2830150	et	4	main
ma	doc_724355862913_item	2830157	et	3	main
tpt	doc_724355862913_item	2830184	et	4	main
keelt	doc_724355862913_item	2830227	et	4	main
ka	doc_724355862913_item	2830228	et	3	main
inimesed	doc_724355862913_item	2830229	et	3	main
väga	doc_724355862913_item	2830245	et	3	main
räägime	doc_724355862913_item	2830253	et	3	main
et	doc_724355862913_item	2830256	et	3	main
ta	doc_724355862913_item	2830262	et	4	main
eesti	doc_724355862913_item	2830266	et	4	main
selle	doc_724355862913_item	2830268	et	4	main
essee	doc_724355862914_item	2830276	et	4	main
mina	doc_724355862914_item	2830280	et	4	main
kaks	doc_724355862914_item	2830287	et	3	main
sellepärast	doc_724355862914_item	2830298	et	3	main
on	doc_724355862914_item	2830306	et	4	main
vaja	doc_724355862914_item	2830319	et	4	main
meeldib	doc_724355862914_item	2830323	et	3	main
on	doc_724355862914_item	2830328	et	4	main
osakonnas	doc_724355862914_item	2830337	et	4	main
minu	doc_724355862914_item	2830338	et	3	main
muljed	doc_724355862914_item	2830339	et	3	main
on	doc_724355862914_item	2830342	et	4	main
väiksed	doc_724355862914_item	2830344	et	4	main
esimene	doc_724355862914_item	2830353	et	3	main
ma	doc_724355862914_item	2830369	et	3	main
eesti	doc_724355862914_item	2830385	et	4	main
et	doc_724355862915_item	2830424	et	3	main
väga	doc_724355862915_item	2830430	et	3	main
meil	doc_724355862915_item	2830432	et	4	main
elus	doc_724355862915_item	2830433	et	4	main
inimene	doc_724355862915_item	2830434	et	3	main
leidis	doc_724355862915_item	2830438	et	4	main
oma	doc_724355862915_item	2830439	et	4	main
mehaanika	doc_724355862915_item	2830448	et	4	main
olen	doc_724355862915_item	2830453	et	3	main
et	doc_724355862915_item	2830455	et	3	main
töökohta	doc_724355862915_item	2830460	et	4	main
meeldib	doc_724355862915_item	2830463	et	3	main
oleks	doc_724355862915_item	2830470	et	3	main
ma	doc_724355862915_item	2830473	et	3	main
praegu	doc_724355862915_item	2830475	et	3	main
otan	doc_724355862915_item	2830477	et	4	main
mina	doc_724355862917_item	2830660	et	4	main
4	doc_724355862913_item	2830236	et	2	main
et	doc_724355862913_item	2830240	et	3	main
on	doc_724355862913_item	2830244	et	4	main
seal	doc_724355862913_item	2830247	et	4	main
me	doc_724355862913_item	2830248	et	4	main
treenime	doc_724355862913_item	2830249	et	3	main
gramaatika	doc_724355862913_item	2830250	et	4	main
ja	doc_724355862913_item	2830251	et	3	main
palju	doc_724355862913_item	2830252	et	4	main
ma	doc_724355862913_item	2830238	et	3	main
loengud	doc_724355862913_item	2830243	et	3	main
hea	doc_724355862913_item	2830246	et	4	main
ja	doc_724355862913_item	2830261	et	3	main
pärast	doc_724355862913_item	2830269	et	4	main
mina	doc_724355862914_item	2830277	et	4	main
ja	doc_724355862914_item	2830278	et	3	main
olen	doc_724355862914_item	2830285	et	3	main
koplis	doc_724355862914_item	2830292	et	3	main
mängin	doc_724355862914_item	2830293	et	3	main
jälgpallis	doc_724355862914_item	2830294	et	4	main
ma	doc_724355862914_item	2830295	et	3	main
tulin	doc_724355862914_item	2830296	et	3	main
mull	doc_724355862914_item	2830300	et	3	main
ja	doc_724355862914_item	2830308	et	3	main
minu	doc_724355862914_item	2830309	et	3	main
eriala	doc_724355862914_item	2830310	et	4	main
arvan	doc_724355862913_item	2830255	et	3	main
õpetaja	doc_724355862913_item	2830257	et	4	main
on	doc_724355862913_item	2830258	et	4	main
väga	doc_724355862913_item	2830259	et	3	main
aitab	doc_724355862913_item	2830263	et	3	main
et	doc_724355862913_item	2830270	et	3	main
tahan	doc_724355862913_item	2830272	et	3	main
eesti	doc_724355862913_item	2830274	et	4	main
keelt	doc_724355862913_item	2830275	et	4	main
ttüs	doc_724355862914_item	2830297	et	4	main
on	doc_724355862914_item	2830301	et	4	main
kõrgharidus	doc_724355862914_item	2830303	et	3	main
praegu	doc_724355862914_item	2830304	et	3	main
sa	doc_724355862914_item	2830315	et	3	main
tuled	doc_724355862914_item	2830316	et	4	main
tööle	doc_724355862914_item	2830317	et	3	main
on	doc_724355862914_item	2830318	et	4	main
seda	doc_724355862914_item	2830324	et	3	main
sest	doc_724355862914_item	2830326	et	4	main
selles	doc_724355862914_item	2830336	et	4	main
praegu	doc_724355862914_item	2830341	et	3	main
väga	doc_724355862914_item	2830343	et	3	main
sellepärast	doc_724355862914_item	2830345	et	3	main
inimised	doc_724355862914_item	2830359	et	4	main
kui	doc_724355862914_item	2830360	et	3	main
ma	doc_724355862914_item	2830365	et	3	main
ootan	doc_724355862914_item	2830370	et	3	main
keele	doc_724355862914_item	2830372	et	4	main
et	doc_724355862914_item	2830374	et	3	main
minu	doc_724355862914_item	2830375	et	3	main
eesti	doc_724355862914_item	2830376	et	4	main
töö	doc_724355862914_item	2830383	et	4	main
kool	doc_724355862915_item	2830421	et	4	main
arvan	doc_724355862915_item	2830423	et	3	main
see	doc_724355862915_item	2830428	et	3	main
kes	doc_724355862915_item	2830435	et	4	main
kõrgharidus	doc_724355862915_item	2830437	et	3	main
ma	doc_724355862915_item	2830452	et	3	main
enseneer	doc_724355862915_item	2830456	et	4	main
alati	doc_724355862915_item	2830457	et	4	main
leidis	doc_724355862915_item	2830458	et	4	main
väga	doc_724355862915_item	2830462	et	3	main
ülikoolis	doc_724355862915_item	2830469	et	4	main
mõtlesin	doc_724355862915_item	2830474	et	3	main
ma	doc_724355862915_item	2830476	et	3	main
tugendemis	doc_724355862915_item	2830478	et	4	main
oma	doc_724355862915_item	2830479	et	4	main
eesti	doc_724355862915_item	2830480	et	4	main
ma	doc_724355862913_item	2830271	et	3	main
õpida	doc_724355862913_item	2830273	et	4	main
ülikool	doc_724355862914_item	2830279	et	4	main
eesnimi	doc_724355862914_item	2830282	et	3	main
kakskümend	doc_724355862914_item	2830286	et	4	main
et	doc_724355862914_item	2830299	et	3	main
mehhatroonik	doc_724355862914_item	2830312	et	4	main
aga	doc_724355862914_item	2830313	et	3	main
kui	doc_724355862914_item	2830314	et	3	main
kõrgharidus	doc_724355862914_item	2830320	et	3	main
mulle	doc_724355862914_item	2830322	et	4	main
kõik	doc_724355862914_item	2830335	et	4	main
ttüst	doc_724355862914_item	2830340	et	4	main
et	doc_724355862914_item	2830346	et	3	main
olen	doc_724355862914_item	2830348	et	3	main
esimene	doc_724355862914_item	2830350	et	3	main
päev	doc_724355862914_item	2830351	et	3	main
palju	doc_724355862914_item	2830361	et	4	main
sõbrad	doc_724355862914_item	2830362	et	3	main
tahan	doc_724355862914_item	2830366	et	3	main
õppida	doc_724355862914_item	2830367	et	3	main
eesti	doc_724355862914_item	2830371	et	4	main
keel	doc_724355862914_item	2830377	et	4	main
saab	doc_724355862914_item	2830378	et	3	main
keel	doc_724355862914_item	2830386	et	4	main
praegu	doc_724355862915_item	2830425	et	3	main
on	doc_724355862915_item	2830429	et	4	main
tähtis	doc_724355862915_item	2830431	et	4	main
koha	doc_724355862915_item	2830440	et	4	main
elus	doc_724355862915_item	2830441	et	4	main
ma	doc_724355862915_item	2830442	et	3	main
tulin	doc_724355862915_item	2830443	et	3	main
seda	doc_724355862915_item	2830444	et	3	main
raskem	doc_724355862915_item	2830471	et	4	main
kui	doc_724355862915_item	2830472	et	3	main
keele	doc_724355862915_item	2830481	et	4	main
eesnimi	doc_724355862917_item	2830666	et	3	main
edukalt	doc_724355862917_item	2830671	et	4	main
pärit	doc_724355862917_item	2830676	et	3	main
hea	doc_724355862917_item	2830686	et	4	main
meelega	doc_724355862917_item	2830687	et	4	main
rääkida	doc_724355862917_item	2830691	et	3	main
kui	doc_724355862917_item	2830694	et	3	main
meeldib	doc_724355862917_item	2830707	et	3	main
ja	doc_724355862917_item	2830712	et	3	main
tulin	doc_724355862917_item	2830716	et	3	main
arvan	doc_724355862917_item	2830722	et	3	main
selline	doc_724355862917_item	2830724	et	4	main
on	doc_724355862917_item	2830726	et	4	main
vajalik	doc_724355862917_item	2830727	et	3	main
tulevikus	doc_724355862917_item	2830728	et	4	main
töö	doc_724355862917_item	2830740	et	4	main
minule	doc_724355862917_item	2830749	et	3	main
prespektiivne	doc_724355862914_item	2830332	et	4	main
tahan	doc_724355862914_item	2830333	et	3	main
teada	doc_724355862914_item	2830334	et	3	main
palju	doc_724355862914_item	2830358	et	4	main
siis	doc_724355862914_item	2830364	et	3	main
edasi	doc_724355862914_item	2830368	et	3	main
parem	doc_724355862914_item	2830379	et	4	main
kui	doc_724355862914_item	2830380	et	3	main
ma	doc_724355862914_item	2830381	et	3	main
otsin	doc_724355862914_item	2830382	et	3	main
siis	doc_724355862914_item	2830384	et	3	main
on	doc_724355862914_item	2830387	et	4	main
kindlasli	doc_724355862914_item	2830388	et	4	main
vaja	doc_724355862914_item	2830389	et	4	main
ja	doc_724355862914_item	2830390	et	3	main
ma	doc_724355862914_item	2830391	et	3	main
tahan	doc_724355862914_item	2830392	et	3	main
teada	doc_724355862914_item	2830393	et	3	main
seda	doc_724355862914_item	2830394	et	3	main
keel	doc_724355862914_item	2830395	et	4	main
hästi	doc_724355862914_item	2830396	et	3	main
ja	doc_724355862914_item	2830397	et	3	main
inglise	doc_724355862914_item	2830398	et	4	main
keel	doc_724355862914_item	2830399	et	4	main
ka	doc_724355862914_item	2830400	et	3	main
essee	doc_724355862915_item	2830401	et	4	main
mina	doc_724355862915_item	2830402	et	4	main
ja	doc_724355862915_item	2830403	et	3	main
ülikool	doc_724355862915_item	2830404	et	4	main
minu	doc_724355862915_item	2830405	et	3	main
nimi	doc_724355862915_item	2830406	et	3	main
on	doc_724355862915_item	2830407	et	4	main
eesnimi	doc_724355862915_item	2830408	et	3	main
aga	doc_724355862915_item	2830409	et	3	main
perekonnanimi	doc_724355862915_item	2830410	et	3	main
on	doc_724355862915_item	2830411	et	4	main
perekonnanimi	doc_724355862915_item	2830412	et	3	main
ma	doc_724355862915_item	2830413	et	3	main
olen	doc_724355862915_item	2830414	et	3	main
pärit	doc_724355862915_item	2830415	et	3	main
narvast	doc_724355862915_item	2830416	et	4	main
ma	doc_724355862915_item	2830417	et	3	main
lõpetasin	doc_724355862915_item	2830418	et	3	main
narva	doc_724355862915_item	2830419	et	4	main
6	doc_724355862915_item	2830420	et	2	main
vaja	doc_724355862915_item	2830426	et	4	main
see	doc_724355862915_item	2830449	et	3	main
on	doc_724355862915_item	2830450	et	4	main
endale	doc_724355862915_item	2830459	et	4	main
ma	doc_724355862915_item	2830422	et	3	main
kõrgharidus	doc_724355862915_item	2830427	et	3	main
sai	doc_724355862915_item	2830436	et	4	main
eriala	doc_724355862915_item	2830445	et	4	main
õppima	doc_724355862915_item	2830446	et	3	main
sest	doc_724355862915_item	2830447	et	4	main
huvitav	doc_724355862915_item	2830451	et	4	main
vendunud	doc_724355862915_item	2830454	et	4	main
mulle	doc_724355862915_item	2830461	et	4	main
tudengielu	doc_724355862915_item	2830464	et	4	main
mulle	doc_724355862915_item	2830465	et	4	main
tundub	doc_724355862915_item	2830466	et	3	main
et	doc_724355862915_item	2830467	et	3	main
oskuse	doc_724355862915_item	2830482	et	3	main
essee	doc_724355862917_item	2830659	et	4	main
ülikool	doc_724355862917_item	2830662	et	4	main
minu	doc_724355862917_item	2830663	et	3	main
nimi	doc_724355862917_item	2830664	et	3	main
esmakurslane	doc_724355862917_item	2830668	et	4	main
narva	doc_724355862917_item	2830681	et	4	main
praegu	doc_724355862917_item	2830683	et	3	main
nii	doc_724355862917_item	2830692	et	3	main
ka	doc_724355862917_item	2830695	et	3	main
ja	doc_724355862917_item	2830709	et	3	main
tutvuda	doc_724355862917_item	2830710	et	3	main
ellusuhtumine	doc_724355862917_item	2830714	et	3	main
õpida	doc_724355862915_item	2830468	et	4	main
olen	doc_724355862917_item	2830667	et	3	main
humanitaargümnaasiumis	doc_724355862917_item	2830682	et	3	main
tallinnas	doc_724355862917_item	2830685	et	4	main
siin	doc_724355862917_item	2830689	et	4	main
eesti	doc_724355862917_item	2830693	et	4	main
suhelda	doc_724355862917_item	2830708	et	4	main
inimestega	doc_724355862917_item	2830711	et	3	main
positiivne	doc_724355862917_item	2830713	et	3	main
mina	doc_724355862917_item	2830715	et	4	main
oma	doc_724355862917_item	2830718	et	4	main
eriala	doc_724355862917_item	2830719	et	4	main
on	doc_724355862917_item	2830665	et	4	main
ja	doc_724355862917_item	2830669	et	3	main
ttü-s	doc_724355862917_item	2830673	et	3	main
olen	doc_724355862917_item	2830675	et	3	main
elan	doc_724355862917_item	2830684	et	3	main
võin	doc_724355862917_item	2830690	et	3	main
vene	doc_724355862917_item	2830696	et	4	main
keeles	doc_724355862917_item	2830697	et	4	main
olen	doc_724355862917_item	2830698	et	3	main
aktiivne	doc_724355862917_item	2830699	et	3	main
sportlane	doc_724355862917_item	2830700	et	3	main
tegelen	doc_724355862917_item	2830701	et	3	main
jalgpalliga	doc_724355862917_item	2830702	et	3	main
korvpalliga	doc_724355862917_item	2830703	et	3	main
ja	doc_724355862917_item	2830704	et	3	main
ju-doga	doc_724355862917_item	2830705	et	3	main
minule	doc_724355862917_item	2830706	et	3	main
sellepärast	doc_724355862917_item	2830721	et	3	main
ja	doc_724355862917_item	2830729	et	3	main
edukalt	doc_724355862917_item	2830732	et	4	main
peab	doc_724355862917_item	2830741	et	4	main
tooma	doc_724355862917_item	2830742	et	3	main
nii	doc_724355862917_item	2830743	et	3	main
meeldib	doc_724355862917_item	2830750	et	3	main
eriala	doc_724355862917_item	2830752	et	4	main
ja	doc_724355862917_item	2830761	et	3	main
minu	doc_724355862917_item	2830772	et	3	main
ole	doc_724355862917_item	2830778	et	4	main
siin	doc_724355862917_item	2830779	et	4	main
igav	doc_724355862917_item	2830780	et	3	main
saan	doc_724355862917_item	2830789	et	4	main
eesti	doc_724355862917_item	2830797	et	4	main
ja	doc_724355862917_item	2830799	et	3	main
minu	doc_724355862917_item	2830801	et	3	main
essee	doc_724355862918_item	2830824	et	4	main
kasvanud	doc_724355862918_item	2830850	et	4	main
ja	doc_724355862918_item	2830851	et	3	main
õppinud	doc_724355862918_item	2830852	et	4	main
jätkan	doc_724355862918_item	2830858	et	3	main
mottes	doc_724355862918_item	2830866	et	4	main
ma	doc_724355862918_item	2830870	et	3	main
on	doc_724355862918_item	2830875	et	4	main
surepäraselt	doc_724355862918_item	2830907	et	4	main
kodust	doc_724355862918_item	2830912	et	4	main
kes	doc_724355862918_item	2830939	et	4	main
vabalt	doc_724355862918_item	2830954	et	4	main
eesti	doc_724355862918_item	2830955	et	4	main
lahendada	doc_724355862918_item	2830962	et	3	main
vedan	doc_724355862919_item	2830975	et	4	main
rohkem	doc_724355862919_item	2830976	et	4	main
ma	doc_724355862919_item	2830981	et	3	main
olen	doc_724355862919_item	2830982	et	3	main
ttü-tudeng	doc_724355862919_item	2830983	et	3	main
lõpetasin	doc_724355862919_item	2830985	et	3	main
arvates	doc_724355862919_item	2830991	et	4	main
sportiga	doc_724355862919_item	2830995	et	4	main
ujumine	doc_724355862919_item	2830998	et	4	main
mul	doc_724355862919_item	2830999	et	3	main
on	doc_724355862919_item	2831000	et	4	main
et	doc_724355862919_item	2831023	et	3	main
valida	doc_724355862919_item	2831026	et	3	main
olevad	doc_724355862919_item	2831033	et	4	main
energia	doc_724355862919_item	2831047	et	4	main
abiga	doc_724355862919_item	2831048	et	3	main
ma	doc_724355862919_item	2831049	et	3	main
valisin	doc_724355862919_item	2831050	et	3	main
elektriajamid	doc_724355862919_item	2831051	et	3	main
jõuenergetika	doc_724355862919_item	2831053	et	4	main
et	doc_724355862919_item	2831055	et	3	main
on	doc_724355862919_item	2831058	et	4	main
siin	doc_724355862919_item	2831068	et	4	main
väga	doc_724355862919_item	2831070	et	3	main
lihtsalt	doc_724355862919_item	2831071	et	4	main
õppida	doc_724355862919_item	2831072	et	3	main
kui	doc_724355862919_item	2831073	et	3	main
tahad	doc_724355862919_item	2831074	et	3	main
õppida	doc_724355862919_item	2831075	et	3	main
õppi	doc_724355862919_item	2831076	et	4	main
aga	doc_724355862919_item	2831077	et	3	main
praegu	doc_724355862919_item	2831078	et	3	main
ja	doc_724355862917_item	2830661	et	3	main
tahaksin	doc_724355862917_item	2830670	et	3	main
õppida	doc_724355862917_item	2830672	et	3	main
mina	doc_724355862917_item	2830674	et	4	main
narvast	doc_724355862917_item	2830677	et	4	main
kus	doc_724355862917_item	2830678	et	3	main
mina	doc_724355862917_item	2830679	et	4	main
õppisin	doc_724355862917_item	2830680	et	3	main
sest	doc_724355862917_item	2830688	et	4	main
eriala	doc_724355862917_item	2830725	et	4	main
võin	doc_724355862917_item	2830731	et	3	main
leida	doc_724355862917_item	2830733	et	3	main
raha	doc_724355862917_item	2830744	et	4	main
kui	doc_724355862917_item	2830745	et	3	main
ka	doc_724355862917_item	2830746	et	3	main
vaimset	doc_724355862917_item	2830747	et	3	main
õppejõud	doc_724355862917_item	2830762	et	4	main
targad	doc_724355862917_item	2830764	et	3	main
siin	doc_724355862917_item	2830766	et	4	main
väga	doc_724355862917_item	2830768	et	3	main
ka	doc_724355862917_item	2830774	et	3	main
ttü-s	doc_724355862917_item	2830787	et	3	main
mina	doc_724355862917_item	2830788	et	4	main
ek	doc_724355862917_item	2830794	et	4	main
rääkida	doc_724355862917_item	2830796	et	3	main
just	doc_724355862917_item	2830717	et	3	main
et	doc_724355862917_item	2830723	et	3	main
muidugi	doc_724355862917_item	2830737	et	4	main
arvan	doc_724355862917_item	2830738	et	3	main
et	doc_724355862917_item	2830739	et	3	main
rahuldamist	doc_724355862917_item	2830748	et	4	main
kõik	doc_724355862917_item	2830759	et	4	main
tudengid	doc_724355862917_item	2830760	et	3	main
õpivad	doc_724355862917_item	2830771	et	3	main
ei	doc_724355862917_item	2830777	et	4	main
kavatsen	doc_724355862917_item	2830781	et	3	main
nendega	doc_724355862917_item	2830782	et	4	main
rääkida	doc_724355862917_item	2830783	et	3	main
targemaks	doc_724355862917_item	2830790	et	4	main
ja	doc_724355862917_item	2830791	et	3	main
loengutel	doc_724355862917_item	2830795	et	4	main
keeles	doc_724355862917_item	2830798	et	4	main
arendada	doc_724355862917_item	2830800	et	3	main
aitada	doc_724355862917_item	2830821	et	4	main
ja	doc_724355862918_item	2830826	et	3	main
ennast	doc_724355862918_item	2830832	et	4	main
eesnimi	doc_724355862918_item	2830840	et	3	main
jaoks	doc_724355862918_item	2830842	et	4	main
olen	doc_724355862918_item	2830844	et	3	main
pärit	doc_724355862918_item	2830845	et	3	main
tallinnast	doc_724355862918_item	2830846	et	3	main
selle	doc_724355862918_item	2830853	et	4	main
momendini	doc_724355862918_item	2830854	et	3	main
et	doc_724355862918_item	2830857	et	3	main
kasvatamist	doc_724355862918_item	2830860	et	4	main
nii	doc_724355862918_item	2830861	et	3	main
füüsilises	doc_724355862918_item	2830862	et	3	main
kui	doc_724355862918_item	2830863	et	3	main
ka	doc_724355862918_item	2830864	et	3	main
tarkuses	doc_724355862918_item	2830865	et	4	main
astusin	doc_724355862918_item	2830873	et	3	main
ja	doc_724355862918_item	2830877	et	3	main
sobib	doc_724355862918_item	2830906	et	3	main
jalutamist	doc_724355862918_item	2830910	et	4	main
ja	doc_724355862918_item	2830913	et	3	main
olen	doc_724355862918_item	2830914	et	3	main
siin	doc_724355862918_item	2830916	et	4	main
kohal	doc_724355862918_item	2830917	et	4	main
huvitavad	doc_724355862918_item	2830921	et	4	main
ja	doc_724355862918_item	2830925	et	3	main
mugavad	doc_724355862918_item	2830926	et	3	main
ja	doc_724355862918_item	2830928	et	3	main
toredad	doc_724355862918_item	2830929	et	3	main
e	doc_724355862918_item	2830937	et	4	main
võimalust	doc_724355862918_item	2830959	et	3	main
nüüd	doc_724355862919_item	2830980	et	4	main
ma	doc_724355862919_item	2830984	et	3	main
ma	doc_724355862919_item	2831021	et	3	main
inimene	doc_724355862919_item	2831024	et	3	main
palju	doc_724355862919_item	2831037	et	4	main
järelekult	doc_724355862919_item	2831039	et	3	main
koht	doc_724355862919_item	2831041	et	3	main
ja	doc_724355862919_item	2831052	et	3	main
siin	doc_724355862919_item	2831086	et	4	main
kõik	doc_724355862919_item	2831088	et	4	main
näiteks	doc_724355862919_item	2831091	et	4	main
eesti	doc_724355862919_item	2831099	et	4	main
keele	doc_724355862919_item	2831100	et	4	main
tundides	doc_724355862919_item	2831101	et	3	main
õppima	doc_724355862917_item	2830720	et	3	main
mina	doc_724355862917_item	2830730	et	4	main
endale	doc_724355862917_item	2830734	et	4	main
tööd	doc_724355862917_item	2830735	et	4	main
aga	doc_724355862917_item	2830736	et	3	main
õppida	doc_724355862917_item	2830756	et	3	main
sõbrad	doc_724355862917_item	2830773	et	3	main
mul	doc_724355862917_item	2830776	et	3	main
kultuursemaks	doc_724355862917_item	2830792	et	4	main
riigikeeleoskust	doc_724355862917_item	2830802	et	3	main
eesti	doc_724355862917_item	2830803	et	4	main
keele	doc_724355862917_item	2830804	et	4	main
loengud	doc_724355862917_item	2830805	et	3	main
aitavad	doc_724355862917_item	2830806	et	4	main
mul	doc_724355862917_item	2830807	et	3	main
õpida	doc_724355862917_item	2830808	et	4	main
ttü-s	doc_724355862917_item	2830809	et	3	main
elada	doc_724355862917_item	2830810	et	3	main
tallinnas	doc_724355862917_item	2830811	et	4	main
ja	doc_724355862917_item	2830812	et	3	main
töötada	doc_724355862917_item	2830813	et	3	main
tulevikus	doc_724355862917_item	2830814	et	4	main
püüan	doc_724355862917_item	2830815	et	3	main
töötada	doc_724355862917_item	2830816	et	3	main
aktiivselt	doc_724355862917_item	2830817	et	4	main
ek	doc_724355862917_item	2830818	et	4	main
loengutel	doc_724355862917_item	2830819	et	4	main
ja	doc_724355862917_item	2830820	et	3	main
sõnu	doc_724355862918_item	2830831	et	4	main
lühedalt	doc_724355862918_item	2830839	et	4	main
xxx	doc_724355862918_item	2830843	et	4	main
olin	doc_724355862918_item	2830847	et	3	main
ttü-sse	doc_724355862918_item	2830872	et	3	main
see	doc_724355862918_item	2830874	et	3	main
siin	doc_724355862918_item	2830918	et	4	main
kus	doc_724355862918_item	2830919	et	3	main
kaasõpilased	doc_724355862918_item	2830923	et	3	main
perekonnanimi	doc_724355862918_item	2830938	et	3	main
mind	doc_724355862918_item	2830941	et	4	main
tema	doc_724355862918_item	2830944	et	4	main
tundidelt	doc_724355862918_item	2830945	et	3	main
ma	doc_724355862918_item	2830946	et	3	main
ootan	doc_724355862918_item	2830947	et	3	main
ja	doc_724355862918_item	2830948	et	3	main
olen	doc_724355862918_item	2830949	et	3	main
kindel	doc_724355862918_item	2830950	et	3	main
suhelda	doc_724355862918_item	2830957	et	4	main
sõnavara	doc_724355862918_item	2830961	et	4	main
mina	doc_724355862919_item	2830964	et	4	main
ülikool	doc_724355862919_item	2830965	et	4	main
minu	doc_724355862919_item	2830966	et	3	main
nimi	doc_724355862919_item	2830967	et	3	main
on	doc_724355862919_item	2830968	et	4	main
eesnimi	doc_724355862919_item	2830969	et	3	main
perekonnanimi	doc_724355862919_item	2830970	et	3	main
elasin	doc_724355862919_item	2830971	et	3	main
sillamäes	doc_724355862919_item	2830972	et	3	main
aga	doc_724355862919_item	2830973	et	3	main
praegu	doc_724355862919_item	2830974	et	3	main
sest	doc_724355862919_item	2830979	et	4	main
õpisin	doc_724355862919_item	2830989	et	4	main
minu	doc_724355862919_item	2830990	et	3	main
tegelen	doc_724355862919_item	2830994	et	3	main
oma	doc_724355862917_item	2830751	et	4	main
minule	doc_724355862917_item	2830753	et	3	main
meeldib	doc_724355862917_item	2830754	et	3	main
ttü-s	doc_724355862917_item	2830755	et	3	main
siin	doc_724355862917_item	2830757	et	4	main
on	doc_724355862917_item	2830758	et	4	main
väga	doc_724355862917_item	2830763	et	3	main
sellepärast	doc_724355862917_item	2830765	et	3	main
on	doc_724355862917_item	2830767	et	4	main
huvitav	doc_724355862917_item	2830769	et	4	main
ttü-s	doc_724355862917_item	2830770	et	3	main
sellepärast	doc_724355862917_item	2830775	et	3	main
eesti	doc_724355862917_item	2830784	et	4	main
keeles	doc_724355862917_item	2830785	et	4	main
just	doc_724355862917_item	2830786	et	3	main
tahaksin	doc_724355862917_item	2830793	et	3	main
oma	doc_724355862917_item	2830822	et	4	main
öelda	doc_724355862918_item	2830833	et	4	main
mu	doc_724355862918_item	2830834	et	3	main
nimi	doc_724355862918_item	2830835	et	3	main
on	doc_724355862918_item	2830836	et	4	main
eesnimi	doc_724355862918_item	2830837	et	3	main
perekonnanimi	doc_724355862918_item	2830838	et	3	main
sõbrade	doc_724355862918_item	2830841	et	4	main
siin	doc_724355862918_item	2830848	et	4	main
sündinud	doc_724355862918_item	2830849	et	4	main
looda	doc_724355862918_item	2830856	et	4	main
oma	doc_724355862918_item	2830859	et	4	main
lihtne	doc_724355862918_item	2830876	et	3	main
15	doc_724355862918_item	2830908	et	2	main
jalgsi	doc_724355862918_item	2830911	et	3	main
juba	doc_724355862918_item	2830915	et	3	main
auditooriumid	doc_724355862918_item	2830927	et	3	main
e	doc_724355862918_item	2830932	et	4	main
perekonnanimi	doc_724355862918_item	2830933	et	3	main
e	doc_724355862918_item	2830934	et	4	main
perekonnanimi	doc_724355862918_item	2830935	et	3	main
ja	doc_724355862918_item	2830936	et	3	main
õpetab	doc_724355862918_item	2830940	et	3	main
eesti	doc_724355862918_item	2830942	et	4	main
keelt	doc_724355862918_item	2830943	et	4	main
keeles	doc_724355862918_item	2830956	et	4	main
oma	doc_724355862918_item	2830960	et	4	main
aega	doc_724355862919_item	2830977	et	4	main
sillamae	doc_724355862919_item	2830986	et	4	main
hästi	doc_724355862919_item	2830992	et	3	main
tulevikus	doc_724355862919_item	2831030	et	4	main
tal	doc_724355862919_item	2831031	et	3	main
on	doc_724355862919_item	2831035	et	4	main
energetikul	doc_724355862919_item	2831042	et	4	main
sellepärast	doc_724355862919_item	2831043	et	3	main
et	doc_724355862919_item	2831044	et	3	main
kõik	doc_724355862919_item	2831045	et	4	main
töötab	doc_724355862919_item	2831046	et	3	main
erinevad	doc_724355862919_item	2831063	et	4	main
on	doc_724355862919_item	2831082	et	4	main
väga	doc_724355862919_item	2831083	et	3	main
suur	doc_724355862919_item	2831084	et	3	main
ja	doc_724355862919_item	2831085	et	3	main
joon	doc_724355862919_item	2831093	et	4	main
exmatrekulerimine	doc_724355862919_item	2831094	et	4	main
ja	doc_724355862919_item	2831095	et	3	main
nii	doc_724355862919_item	2831096	et	3	main
tahaksin	doc_724355862919_item	2831098	et	3	main
lektorit	doc_724355862917_item	2830823	et	3	main
mina	doc_724355862918_item	2830825	et	4	main
ülikool	doc_724355862918_item	2830827	et	4	main
esiteks	doc_724355862918_item	2830828	et	3	main
tahaksin	doc_724355862918_item	2830829	et	3	main
paar	doc_724355862918_item	2830830	et	3	main
kuid	doc_724355862918_item	2830855	et	4	main
siin	doc_724355862918_item	2830867	et	4	main
ttü-s	doc_724355862918_item	2830868	et	3	main
miks	doc_724355862918_item	2830869	et	4	main
just	doc_724355862918_item	2830871	et	3	main
loogiline	doc_724355862918_item	2830878	et	4	main
sest	doc_724355862918_item	2830879	et	4	main
see	doc_724355862918_item	2830880	et	3	main
on	doc_724355862918_item	2830881	et	4	main
mu	doc_724355862918_item	2830882	et	3	main
arvates	doc_724355862918_item	2830883	et	4	main
üks	doc_724355862918_item	2830884	et	3	main
ja	doc_724355862918_item	2830885	et	3	main
ainuke	doc_724355862918_item	2830886	et	4	main
ülikool	doc_724355862918_item	2830887	et	4	main
tallinnas	doc_724355862918_item	2830888	et	4	main
mis	doc_724355862918_item	2830889	et	4	main
annab	doc_724355862918_item	2830890	et	3	main
kvaliteetse	doc_724355862918_item	2830891	et	3	main
hariduse	doc_724355862918_item	2830892	et	3	main
teised	doc_724355862918_item	2830893	et	4	main
ülikoolid	doc_724355862918_item	2830894	et	3	main
lihtsalt	doc_724355862918_item	2830895	et	4	main
puhkavad	doc_724355862918_item	2830896	et	4	main
kui	doc_724355862918_item	2830897	et	3	main
me	doc_724355862918_item	2830898	et	4	main
paneme	doc_724355862918_item	2830899	et	3	main
neid	doc_724355862918_item	2830900	et	4	main
reasse	doc_724355862918_item	2830902	et	3	main
ühesse	doc_724355862918_item	2830901	et	3	main
j	doc_724355862918_item	2830903	et	4	main
ttü	doc_724355862918_item	2830904	et	4	main
mulle	doc_724355862918_item	2830905	et	4	main
minutid	doc_724355862918_item	2830909	et	3	main
on	doc_724355862918_item	2830920	et	4	main
inimesed	doc_724355862918_item	2830922	et	3	main
suured	doc_724355862918_item	2830924	et	3	main
lektorid	doc_724355862918_item	2830930	et	3	main
nagu	doc_724355862918_item	2830931	et	3	main
et	doc_724355862918_item	2830951	et	3	main
saan	doc_724355862918_item	2830952	et	4	main
oskust	doc_724355862918_item	2830953	et	3	main
ja	doc_724355862918_item	2830958	et	3	main
essee	doc_724355862919_item	2830963	et	4	main
tallinnas	doc_724355862919_item	2830978	et	4	main
vanalinna	doc_724355862919_item	2830987	et	4	main
kool	doc_724355862919_item	2830988	et	4	main
ma	doc_724355862919_item	2830993	et	3	main
see	doc_724355862919_item	2830996	et	3	main
on	doc_724355862919_item	2830997	et	4	main
head	doc_724355862919_item	2831001	et	4	main
tulemused	doc_724355862919_item	2831002	et	3	main
sillamäes	doc_724355862919_item	2831003	et	3	main
ma	doc_724355862919_item	2831004	et	3	main
elasin	doc_724355862919_item	2831005	et	3	main
koos	doc_724355862919_item	2831006	et	4	main
minu	doc_724355862919_item	2831007	et	3	main
perega	doc_724355862919_item	2831008	et	3	main
see	doc_724355862919_item	2831009	et	3	main
on	doc_724355862919_item	2831010	et	4	main
isa	doc_724355862919_item	2831011	et	4	main
ema	doc_724355862919_item	2831012	et	4	main
ja	doc_724355862919_item	2831013	et	3	main
minu	doc_724355862919_item	2831014	et	3	main
õde	doc_724355862919_item	2831015	et	4	main
kes	doc_724355862919_item	2831016	et	4	main
nüüd	doc_724355862919_item	2831017	et	4	main
kaheteiskümnes	doc_724355862919_item	2831018	et	4	main
klassis	doc_724355862919_item	2831019	et	3	main
õppib	doc_724355862919_item	2831020	et	4	main
selline	doc_724355862919_item	2831027	et	4	main
eriala	doc_724355862919_item	2831028	et	4	main
sest	doc_724355862919_item	2831029	et	4	main
ida-virumaal	doc_724355862919_item	2831034	et	4	main
tähtis	doc_724355862919_item	2831040	et	4	main
minu	doc_724355862919_item	2831056	et	3	main
õige	doc_724355862919_item	2831059	et	4	main
ttüst	doc_724355862919_item	2831060	et	4	main
mul	doc_724355862919_item	2831061	et	3	main
muljed	doc_724355862919_item	2831064	et	3	main
et	doc_724355862919_item	2831067	et	3	main
väga	doc_724355862919_item	2831089	et	3	main
kerge	doc_724355862919_item	2831090	et	4	main
edasi	doc_724355862919_item	2831097	et	3	main
arvan	doc_724355862919_item	2831022	et	3	main
peab	doc_724355862919_item	2831025	et	4	main
perspektivid	doc_724355862919_item	2831032	et	4	main
väga	doc_724355862919_item	2831036	et	3	main
tehaseid	doc_724355862919_item	2831038	et	3	main
arvan	doc_724355862919_item	2831054	et	3	main
valik	doc_724355862919_item	2831057	et	3	main
on	doc_724355862919_item	2831062	et	4	main
alguses	doc_724355862919_item	2831065	et	4	main
arvasin	doc_724355862919_item	2831066	et	3	main
on	doc_724355862919_item	2831069	et	4	main
ttü	doc_724355862919_item	2831081	et	4	main
on	doc_724355862919_item	2831087	et	4	main
riigikeel	doc_724355862919_item	2831103	et	4	main
parem	doc_724355862919_item	2831104	et	4	main
ja	doc_724355862919_item	2831105	et	3	main
rohkem	doc_724355862919_item	2831106	et	4	main
õppida	doc_724355862919_item	2831107	et	3	main
sest	doc_724355862919_item	2831108	et	4	main
tulevikus	doc_724355862919_item	2831109	et	4	main
mul	doc_724355862919_item	2831110	et	3	main
ei	doc_724355862919_item	2831111	et	4	main
ole	doc_724355862919_item	2831112	et	4	main
problemeid	doc_724355862919_item	2831113	et	4	main
estlastega	doc_724355862919_item	2831114	et	4	main
suhtlemises	doc_724355862919_item	2831115	et	4	main
mõtlen	doc_724355862919_item	2831079	et	3	main
et	doc_724355862919_item	2831080	et	3	main
punane	doc_724355862919_item	2831092	et	4	main
meie	doc_724355862919_item	2831102	et	4	main
on	doc_724355862922_item	2831421	et	4	main
olen	doc_724355862922_item	2831424	et	3	main
aastat	doc_724355862922_item	2831426	et	3	main
puhkus	doc_724355862922_item	2831445	et	3	main
on	doc_724355862922_item	2831447	et	4	main
parem	doc_724355862922_item	2831449	et	4	main
puhkus	doc_724355862922_item	2831450	et	3	main
järve	doc_724355862922_item	2831453	et	4	main
on	doc_724355862922_item	2831455	et	4	main
viida	doc_724355862922_item	2831458	et	4	main
mahtra	doc_724355862922_item	2831468	et	4	main
elan	doc_724355862922_item	2831478	et	3	main
sind	doc_724355862922_item	2831520	et	4	main
ja	doc_724355862922_item	2831527	et	3	main
saada	doc_724355862922_item	2831533	et	4	main
insineeriks	doc_724355862922_item	2831534	et	4	main
arvan	doc_724355862922_item	2831536	et	3	main
väga	doc_724355862922_item	2831540	et	3	main
huvitav	doc_724355862922_item	2831555	et	4	main
kõige	doc_724355862922_item	2831563	et	4	main
suurem	doc_724355862922_item	2831564	et	4	main
ja	doc_724355862922_item	2831565	et	3	main
on	doc_724355862922_item	2831572	et	4	main
kes	doc_724355862922_item	2831582	et	4	main
soovib	doc_724355862922_item	2831583	et	3	main
mina	doc_724355862922_item	2831416	et	4	main
ja	doc_724355862922_item	2831417	et	3	main
ma	doc_724355862922_item	2831423	et	3	main
kakskümmend	doc_724355862922_item	2831425	et	4	main
ajal	doc_724355862922_item	2831429	et	4	main
spordiga	doc_724355862922_item	2831431	et	3	main
mängin	doc_724355862922_item	2831432	et	3	main
ja	doc_724355862922_item	2831434	et	3	main
matkas	doc_724355862922_item	2831441	et	4	main
et	doc_724355862922_item	2831444	et	3	main
loodusel	doc_724355862922_item	2831446	et	4	main
kampaanias	doc_724355862922_item	2831452	et	3	main
kaldal	doc_724355862922_item	2831454	et	3	main
essee	doc_724355862922_item	2831415	et	4	main
nimi	doc_724355862922_item	2831420	et	3	main
eesnimi	doc_724355862922_item	2831422	et	3	main
vabal	doc_724355862922_item	2831428	et	3	main
ka	doc_724355862922_item	2831440	et	3	main
arvan	doc_724355862922_item	2831443	et	3	main
aja	doc_724355862922_item	2831457	et	4	main
kaheksateist	doc_724355862922_item	2831459	et	4	main
aastat	doc_724355862922_item	2831460	et	3	main
elasin	doc_724355862922_item	2831461	et	3	main
lasnamäel	doc_724355862922_item	2831464	et	3	main
tallinna	doc_724355862922_item	2831467	et	4	main
gümnaasiumi	doc_724355862922_item	2831469	et	4	main
seal	doc_724355862922_item	2831470	et	4	main
linna	doc_724355862922_item	2831479	et	4	main
taga	doc_724355862922_item	2831480	et	4	main
kõrgharidust	doc_724355862922_item	2831483	et	4	main
võivad	doc_724355862922_item	2831521	et	4	main
tuttavad	doc_724355862922_item	2831523	et	4	main
seotud	doc_724355862922_item	2831530	et	4	main
on	doc_724355862922_item	2831539	et	4	main
ei	doc_724355862922_item	2831549	et	4	main
jää	doc_724355862922_item	2831550	et	4	main
see	doc_724355862922_item	2831551	et	3	main
on	doc_724355862922_item	2831552	et	4	main
ka	doc_724355862922_item	2831553	et	3	main
ülikool	doc_724355862922_item	2831418	et	4	main
minu	doc_724355862922_item	2831419	et	3	main
vana	doc_724355862922_item	2831427	et	4	main
tegelen	doc_724355862922_item	2831430	et	3	main
jalgpalli	doc_724355862922_item	2831433	et	4	main
korvpalli	doc_724355862922_item	2831435	et	4	main
oma	doc_724355862922_item	2831436	et	4	main
sõpradega	doc_724355862922_item	2831437	et	3	main
kõige	doc_724355862922_item	2831448	et	4	main
tallinnas	doc_724355862922_item	2831462	et	4	main
lõpetasin	doc_724355862922_item	2831466	et	3	main
tahan	doc_724355862922_item	2831481	et	3	main
on	doc_724355862922_item	2831485	et	4	main
väga	doc_724355862922_item	2831486	et	3	main
ehitus	doc_724355862922_item	2831526	et	4	main
kõik	doc_724355862922_item	2831528	et	4	main
mis	doc_724355862922_item	2831529	et	4	main
ma	doc_724355862922_item	2831535	et	3	main
see	doc_724355862922_item	2831538	et	3	main
inimesed	doc_724355862922_item	2831542	et	3	main
alati	doc_724355862922_item	2831543	et	4	main
ttü	doc_724355862922_item	2831571	et	4	main
ja	doc_724355862922_item	2831574	et	3	main
lugupeetud	doc_724355862922_item	2831575	et	4	main
see	doc_724355862922_item	2831577	et	3	main
ootan	doc_724355862922_item	2831588	et	3	main
õppimist	doc_724355862922_item	2831590	et	4	main
tahan	doc_724355862922_item	2831591	et	3	main
eesti	doc_724355862922_item	2831598	et	4	main
keeles	doc_724355862922_item	2831599	et	4	main
majanduse	doc_725976921216_item	2831722	et	4	main
loodushoiu	doc_725976921216_item	2831724	et	3	main
1970ndate	doc_725976921216_item	2831726	et	4	main
2	doc_725976921216_item	2831729	et	2	main
kellel	doc_725976921216_item	2831730	et	4	main
identiteediprobleemid	doc_725976921216_item	2831735	et	3	main
erikal	doc_725976921216_item	2831737	et	4	main
oskaril	doc_725976921216_item	2831739	et	4	main
tammsaare	doc_725976921216_item	2831740	et	3	main
ma	doc_725976921216_item	2831741	et	3	main
armastasin	doc_725976921216_item	2831742	et	3	main
1	doc_725976921216_item	2831745	et	2	main
vajas	doc_725976921216_item	2831752	et	4	main
kaevandusse	doc_725976921216_item	2831755	et	4	main
ei	doc_725976921216_item	2831757	et	4	main
põlevkivi-kaevandused	doc_725976921216_item	2831762	et	4	main
narva	doc_725976921216_item	2831763	et	4	main
sillamäe	doc_725976921216_item	2831764	et	3	main
kohtla-järve	doc_725976921216_item	2831765	et	4	main
nt	doc_725976921216_item	2831792	et	4	main
põliselanikkel	doc_725976921216_item	2831793	et	4	main
nsvls	doc_725976921216_item	2831800	et	4	main
loodi	doc_725976921216_item	2831801	et	4	main
eestis	doc_725976921216_item	2831802	et	3	main
põlevkivi	doc_725976921216_item	2831808	et	4	main
kaevandati	doc_725976921216_item	2831809	et	3	main
sealt	doc_725976921216_item	2831810	et	4	main
kus	doc_725976921216_item	2831811	et	3	main
et	doc_725976921216_item	2831816	et	3	main
eestlaste	doc_725976921216_item	2831820	et	4	main
püha	doc_725976921216_item	2831831	et	4	main
mägesid	doc_725976921216_item	2831832	et	3	main
mulle	doc_724355862922_item	2831438	et	4	main
meeldib	doc_724355862922_item	2831439	et	3	main
käia	doc_724355862922_item	2831442	et	4	main
lõbusas	doc_724355862922_item	2831451	et	3	main
tore	doc_724355862922_item	2831456	et	3	main
lasnamäel	doc_724355862922_item	2831463	et	3	main
ma	doc_724355862922_item	2831465	et	3	main
elavad	doc_724355862922_item	2831471	et	4	main
kõik	doc_724355862922_item	2831472	et	4	main
minu	doc_724355862922_item	2831473	et	3	main
sõprad	doc_724355862922_item	2831474	et	4	main
aga	doc_724355862922_item	2831475	et	3	main
praegu	doc_724355862922_item	2831476	et	3	main
ma	doc_724355862922_item	2831477	et	3	main
saada	doc_724355862922_item	2831482	et	4	main
see	doc_724355862922_item	2831484	et	3	main
tähtis	doc_724355862922_item	2831487	et	4	main
mulle	doc_724355862922_item	2831488	et	4	main
kõrgharidus	doc_724355862922_item	2831489	et	3	main
annab	doc_724355862922_item	2831490	et	3	main
inimesele	doc_724355862922_item	2831491	et	3	main
väga	doc_724355862922_item	2831492	et	3	main
palju	doc_724355862922_item	2831493	et	4	main
aitab	doc_724355862922_item	2831494	et	3	main
leida	doc_724355862922_item	2831495	et	3	main
oma	doc_724355862922_item	2831496	et	4	main
koht	doc_724355862922_item	2831497	et	3	main
elus	doc_724355862922_item	2831498	et	4	main
ülikoolis	doc_724355862922_item	2831499	et	4	main
sa	doc_724355862922_item	2831500	et	3	main
võid	doc_724355862922_item	2831501	et	4	main
ka	doc_724355862922_item	2831502	et	3	main
tutvustada	doc_724355862922_item	2831503	et	3	main
palju	doc_724355862922_item	2831504	et	4	main
inimestega	doc_724355862922_item	2831505	et	3	main
kui	doc_724355862922_item	2831506	et	3	main
sul	doc_724355862922_item	2831507	et	3	main
on	doc_724355862922_item	2831508	et	4	main
palju	doc_724355862922_item	2831509	et	4	main
tuttavaid	doc_724355862922_item	2831510	et	3	main
siis	doc_724355862922_item	2831511	et	3	main
elada	doc_724355862922_item	2831512	et	3	main
on	doc_724355862922_item	2831513	et	4	main
natuke	doc_724355862922_item	2831514	et	4	main
lihtsam	doc_724355862922_item	2831515	et	4	main
kui	doc_724355862922_item	2831516	et	3	main
sul	doc_724355862922_item	2831517	et	3	main
on	doc_724355862922_item	2831518	et	4	main
probleemid	doc_724355862922_item	2831519	et	3	main
aidata	doc_724355862922_item	2831522	et	4	main
mulle	doc_724355862922_item	2831524	et	4	main
meeldib	doc_724355862922_item	2831525	et	3	main
ehitusega	doc_724355862922_item	2831531	et	4	main
tahan	doc_724355862922_item	2831532	et	3	main
et	doc_724355862922_item	2831537	et	3	main
väga	doc_724355862922_item	2831554	et	3	main
uuid	doc_724355862922_item	2831557	et	4	main
ja	doc_724355862922_item	2831559	et	3	main
maju	doc_724355862922_item	2831560	et	3	main
ülikool	doc_724355862922_item	2831567	et	4	main
eestis	doc_724355862922_item	2831568	et	3	main
ja	doc_724355862922_item	2831569	et	3	main
baltikus	doc_724355862922_item	2831570	et	4	main
prestiizne	doc_724355862922_item	2831573	et	4	main
ülikool	doc_724355862922_item	2831576	et	4	main
eesti	doc_724355862922_item	2831585	et	4	main
arvates	doc_725976921216_item	2831733	et	4	main
mis	doc_725976921216_item	2831751	et	4	main
vene	doc_725976921216_item	2831768	et	4	main
park	doc_725976921216_item	2831807	et	3	main
vaatamata	doc_725976921216_item	2831814	et	4	main
võisid	doc_725976921216_item	2831818	et	4	main
perspektiivne	doc_724355862922_item	2831541	et	3	main
ehitavad	doc_724355862922_item	2831544	et	4	main
midagi	doc_724355862922_item	2831545	et	4	main
ja	doc_724355862922_item	2831546	et	3	main
tööta	doc_724355862922_item	2831547	et	4	main
ma	doc_724355862922_item	2831548	et	3	main
parem	doc_724355862922_item	2831566	et	4	main
on	doc_724355862922_item	2831578	et	4	main
hea	doc_724355862922_item	2831579	et	4	main
valik	doc_724355862922_item	2831580	et	3	main
inimestele	doc_724355862922_item	2831581	et	3	main
keele	doc_724355862922_item	2831586	et	4	main
vabalt	doc_724355862922_item	2831596	et	4	main
rääkida	doc_724355862922_item	2831597	et	3	main
ehitada	doc_724355862922_item	2831556	et	3	main
hooneid	doc_724355862922_item	2831558	et	4	main
ttü	doc_724355862922_item	2831561	et	4	main
on	doc_724355862922_item	2831562	et	4	main
tõsta	doc_724355862922_item	2831592	et	4	main
oma	doc_724355862922_item	2831593	et	4	main
teaduseid	doc_724355862922_item	2831594	et	3	main
ja	doc_724355862922_item	2831595	et	3	main
õpida	doc_724355862922_item	2831584	et	4	main
loengutelt	doc_724355862922_item	2831587	et	4	main
heat	doc_724355862922_item	2831589	et	4	main
1	doc_725976921216_item	2831721	et	2	main
ja	doc_725976921216_item	2831723	et	3	main
on	doc_725976921216_item	2831731	et	4	main
või	doc_725976921216_item	2831738	et	4	main
sakslast	doc_725976921216_item	2831743	et	3	main
põhjendage	doc_725976921216_item	2831744	et	3	main
1973	doc_725976921216_item	2831746	et	2	main
aastal	doc_725976921216_item	2831747	et	3	main
loodi	doc_725976921216_item	2831748	et	4	main
balti	doc_725976921216_item	2831749	et	3	main
soojuselektrijaam	doc_725976921216_item	2831750	et	3	main
laienevad	doc_725976921216_item	2831761	et	4	main
kujunevad	doc_725976921216_item	2831767	et	4	main
looduskaitse	doc_725976921216_item	2831803	et	4	main
seal	doc_725976921216_item	2831812	et	4	main
need	doc_725976921216_item	2831817	et	3	main
olla	doc_725976921216_item	2831819	et	3	main
põhad	doc_725976921216_item	2831821	et	4	main
rajuti	doc_725976921216_item	2831824	et	4	main
koht	doc_725976921216_item	2831846	et	3	main
see	doc_725976921216_item	2831847	et	3	main
tol	doc_725976921216_item	2831850	et	3	main
ei	doc_725976921216_item	2831853	et	4	main
sinna	doc_725976921216_item	2831861	et	3	main
saanud	doc_725976921216_item	2831869	et	4	main
üldse	doc_725976921216_item	2831870	et	3	main
jätku	doc_725976921216_item	2831881	et	4	main
vett	doc_725976921216_item	2831883	et	3	main
a	doc_725976921216_item	2831885	et	4	main
ilmus	doc_725976921216_item	2831886	et	4	main
ja	doc_725976921216_item	2831900	et	3	main
hakkati	doc_725976921216_item	2831903	et	3	main
kaevandama	doc_725976921216_item	2831904	et	3	main
olid	doc_725976921216_item	2831911	et	4	main
puid	doc_725976921216_item	2831916	et	3	main
kontrolltöö	doc_725976921216_item	2831720	et	4	main
suuremad	doc_725976921216_item	2831734	et	4	main
töölisi	doc_725976921216_item	2831753	et	3	main
tööle	doc_725976921216_item	2831756	et	3	main
tahtnud	doc_725976921216_item	2831758	et	4	main
asuda	doc_725976921216_item	2831759	et	3	main
kohtla-järve	doc_725976921216_item	2831760	et	4	main
keelatud	doc_725976921216_item	2831794	et	4	main
sillamäe	doc_725976921216_item	2831795	et	3	main
loksa	doc_725976921216_item	2831796	et	4	main
esimesena	doc_725976921216_item	2831797	et	3	main
a	doc_725976921216_item	2831799	et	4	main
oli	doc_725976921216_item	2831813	et	3	main
vastasseis	doc_725976921216_item	2831725	et	3	main
eesti	doc_725976921216_item	2831727	et	4	main
nsv-s	doc_725976921216_item	2831728	et	3	main
teie	doc_725976921216_item	2831732	et	4	main
kas	doc_725976921216_item	2831736	et	3	main
eestlane	doc_725976921216_item	2831754	et	3	main
piirkonnad	doc_725976921216_item	2831766	et	4	main
keelseteks	doc_725976921216_item	2831769	et	4	main
eestlastele	doc_725976921216_item	2831770	et	4	main
tehakse	doc_725976921216_item	2831771	et	3	main
trakistusi	doc_725976921216_item	2831772	et	4	main
pärast	doc_725976921216_item	2831773	et	4	main
sõda	doc_725976921216_item	2831774	et	4	main
narva	doc_725976921216_item	2831775	et	4	main
elama	doc_725976921216_item	2831776	et	3	main
asumisele	doc_725976921216_item	2831777	et	4	main
sissekirjutus	doc_725976921216_item	2831778	et	3	main
oli	doc_725976921216_item	2831779	et	3	main
kohustuslik	doc_725976921216_item	2831780	et	3	main
ja	doc_725976921216_item	2831781	et	3	main
väga	doc_725976921216_item	2831782	et	3	main
vajalik	doc_725976921216_item	2831783	et	3	main
olid	doc_725976921216_item	2831784	et	4	main
n-ö	doc_725976921216_item	2831785	et	4	main
linnad	doc_725976921216_item	2831787	et	3	main
kinnised	doc_725976921216_item	2831786	et	4	main
teatud	doc_725976921216_item	2831788	et	4	main
linnadesse	doc_725976921216_item	2831789	et	3	main
oli	doc_725976921216_item	2831790	et	3	main
sissepääs	doc_725976921216_item	2831791	et	3	main
1974	doc_725976921216_item	2831798	et	2	main
ala	doc_725976921216_item	2831804	et	4	main
lahemaa	doc_725976921216_item	2831805	et	4	main
rahvus	doc_725976921216_item	2831806	et	3	main
sellele	doc_725976921216_item	2831815	et	4	main
nt	doc_725976921216_item	2831823	et	4	main
põha	doc_725976921216_item	2831826	et	4	main
tammed	doc_725976921216_item	2831827	et	3	main
kaevati	doc_725976921216_item	2831828	et	4	main
selle	doc_725976921216_item	2831840	et	4	main
peale	doc_725976921216_item	2831841	et	4	main
üldse	doc_725976921216_item	2831842	et	3	main
ei	doc_725976921216_item	2831843	et	4	main
saartele	doc_725976921216_item	2831849	et	3	main
niisama	doc_725976921216_item	2831858	et	3	main
ei	doc_725976921216_item	2831859	et	4	main
saanud	doc_725976921216_item	2831860	et	4	main
ei	doc_725976921216_item	2831868	et	4	main
päästa	doc_725976921216_item	2831875	et	4	main
hävitamisest	doc_725976921216_item	2831876	et	4	main
tekkis	doc_725976921216_item	2831877	et	3	main
hirm	doc_725976921216_item	2831878	et	3	main
keeles	doc_725976921216_item	2831888	et	4	main
allkakohad	doc_725976921216_item	2831908	et	4	main
ka	doc_725976921216_item	2831914	et	3	main
ettevõtteid	doc_725976921216_item	2831926	et	3	main
just	doc_725976921216_item	2831929	et	3	main
tillukesed	doc_725976921216_item	2831931	et	4	main
sai	doc_725976921216_item	2831933	et	4	main
uueks	doc_725976921216_item	2831943	et	3	main
letialune	doc_725976921216_item	2831946	et	4	main
tuli	doc_725976921216_item	2831963	et	4	main
peale	doc_725976921216_item	2831969	et	4	main
ja	doc_725976921216_item	2831970	et	3	main
tegelikult	doc_725976921216_item	2831973	et	4	main
olnud	doc_725976921216_item	2831975	et	4	main
üldse	doc_725976921216_item	2831977	et	3	main
seda	doc_725976921216_item	2831978	et	3	main
saadavat	doc_725976921216_item	2831989	et	4	main
sai	doc_725976921216_item	2831991	et	4	main
teiste	doc_725976921216_item	2831992	et	4	main
inimestega	doc_725976921216_item	2831993	et	3	main
vahetada	doc_725976921216_item	2831994	et	3	main
müüjal	doc_725976921216_item	2831995	et	4	main
oli	doc_725976921216_item	2831996	et	3	main
arvestatav	doc_725976921216_item	2831997	et	4	main
positsioon	doc_725976921216_item	2831998	et	3	main
kuna	doc_725976921216_item	2832011	et	3	main
raamatud	doc_725976921216_item	2832012	et	4	main
lugenud	doc_725976921216_item	2832015	et	4	main
see	doc_725976921216_item	2832016	et	3	main
oli	doc_725976921216_item	2832017	et	3	main
erikal	doc_725976921216_item	2832022	et	4	main
oskar	doc_725976921216_item	2832031	et	4	main
teadis	doc_725976921216_item	2832032	et	4	main
kõike	doc_725976921216_item	2832038	et	4	main
ta	doc_725976921216_item	2832040	et	4	main
olemas	doc_725976921216_item	2832046	et	4	main
ta	doc_725976921216_item	2832053	et	4	main
tahtis	doc_725976921216_item	2832060	et	3	main
iseseisev	doc_725976921216_item	2832064	et	3	main
aeg	doc_725976921216_item	2832066	et	3	main
vanemate	doc_725976921216_item	2832068	et	4	main
saanud	doc_725976921216_item	2832102	et	4	main
teha	doc_725976921216_item	2832103	et	3	main
ei	doc_725976921216_item	2832109	et	4	main
vanemate	doc_725976921216_item	2832115	et	4	main
aga	doc_725976921216_item	2832117	et	3	main
julguse	doc_725976921216_item	2832122	et	4	main
kokku	doc_725976921216_item	2832123	et	3	main
ta	doc_725976921216_item	2832128	et	4	main
ikka	doc_725976921216_item	2832139	et	4	main
tagasi	doc_725976921216_item	2832140	et	3	main
koju	doc_725976921216_item	2832141	et	3	main
vaba	doc_725976921216_item	2832150	et	4	main
naisena	doc_725976921216_item	2832151	et	3	main
erika	doc_725976921216_item	2832162	et	4	main
siin	doc_725976921216_item	2832169	et	4	main
teadnud	doc_725976921216_item	2832176	et	4	main
vaeva	doc_725976921216_item	2832188	et	4	main
sai	doc_725976921216_item	2832200	et	4	main
paigad	doc_725976921216_item	2831822	et	3	main
käisid	doc_725976921216_item	2831835	et	4	main
jumalaid	doc_725976921216_item	2831836	et	3	main
palvetamas	doc_725976921216_item	2831837	et	3	main
nii	doc_725976921216_item	2831838	et	3	main
maha	doc_725976921216_item	2831825	et	4	main
või	doc_725976921216_item	2831829	et	4	main
lõhuti	doc_725976921216_item	2831830	et	3	main
oli	doc_725976921216_item	2831848	et	3	main
ainult	doc_725976921216_item	2831856	et	4	main
erilubadega	doc_725976921216_item	2831857	et	3	main
keegi	doc_725976921216_item	2831862	et	4	main
vms	doc_725976921216_item	2831864	et	4	main
pidi	doc_725976921216_item	2831865	et	4	main
olema	doc_725976921216_item	2831866	et	4	main
et	doc_725976921216_item	2831879	et	3	main
pühast	doc_725976921216_item	2831882	et	4	main
1968	doc_725976921216_item	2831884	et	2	main
rõhutati	doc_725976921216_item	2831895	et	4	main
looduhoidu	doc_725976921216_item	2831896	et	4	main
hakkas	doc_725976921216_item	2831897	et	3	main
mis	doc_725976921216_item	2831909	et	4	main
pühad	doc_725976921216_item	2831913	et	3	main
mägesid	doc_725976921216_item	2831918	et	3	main
ära	doc_725976921216_item	2831920	et	4	main
poolt	doc_725976921216_item	2831922	et	4	main
mis	doc_725976921216_item	2831927	et	4	main
fenomeniks	doc_725976921216_item	2831944	et	3	main
midagi	doc_725976921216_item	2831951	et	4	main
vaja	doc_725976921216_item	2831984	et	4	main
keskonnas	doc_725976921216_item	2831999	et	4	main
2	doc_725976921216_item	2832000	et	2	main
küllalti	doc_725976921216_item	2832018	et	4	main
huvitav	doc_725976921216_item	2832019	et	4	main
minu	doc_725976921216_item	2832020	et	3	main
kus	doc_725976921216_item	2831833	et	3	main
eestlased	doc_725976921216_item	2831834	et	3	main
vaadeti	doc_725976921216_item	2831844	et	4	main
pääsenud	doc_725976921216_item	2831854	et	4	main
pääses	doc_725976921216_item	2831855	et	4	main
küllakutse	doc_725976921216_item	2831863	et	4	main
loodust	doc_725976921216_item	2831871	et	4	main
pidi	doc_725976921216_item	2831872	et	4	main
kaitsma	doc_725976921216_item	2831873	et	3	main
hakkama	doc_725976921216_item	2831874	et	3	main
ei	doc_725976921216_item	2831880	et	4	main
tõlgitud	doc_725976921216_item	2831889	et	4	main
r	doc_725976921216_item	2831890	et	4	main
carson	doc_725976921216_item	2831891	et	4	main
nappima	doc_725976921216_item	2831898	et	3	main
liiva	doc_725976921216_item	2831901	et	4	main
eestlastele	doc_725976921216_item	2831910	et	4	main
pühasid	doc_725976921216_item	2831915	et	3	main
ja	doc_725976921216_item	2831917	et	3	main
veeti	doc_725976921216_item	2831919	et	3	main
teiselt	doc_725976921216_item	2831921	et	4	main
tehti	doc_725976921216_item	2831923	et	3	main
näidimajandeid	doc_725976921216_item	2831925	et	4	main
tööd	doc_725976921216_item	2831937	et	4	main
toodi	doc_725976921216_item	2831938	et	4	main
koju	doc_725976921216_item	2831939	et	3	main
see	doc_725976921216_item	2831940	et	3	main
kujunes	doc_725976921216_item	2831941	et	3	main
elustiiliks	doc_725976921216_item	2831942	et	3	main
sai	doc_725976921216_item	2831945	et	4	main
kaubandus	doc_725976921216_item	2831947	et	3	main
lendasid	doc_725976921216_item	2831968	et	4	main
ära	doc_725976921216_item	2831972	et	4	main
mõtlesid	doc_725976921216_item	2831985	et	4	main
meeldis	doc_725976921216_item	2832003	et	3	main
see	doc_725976921216_item	2832004	et	3	main
film	doc_725976921216_item	2832005	et	3	main
filmist	doc_725976921216_item	2832010	et	4	main
pole	doc_725976921216_item	2832014	et	3	main
oskaril	doc_725976921216_item	2832027	et	4	main
et	doc_725976921216_item	2832030	et	3	main
ta	doc_725976921216_item	2832035	et	4	main
oli	doc_725976921216_item	2832042	et	3	main
alati	doc_725976921216_item	2832044	et	4	main
vastus	doc_725976921216_item	2832045	et	3	main
erika	doc_725976921216_item	2832048	et	4	main
tal	doc_725976921216_item	2832049	et	3	main
ei	doc_725976921216_item	2832050	et	4	main
ei	doc_725976921216_item	2832054	et	4	main
ei	doc_725976921216_item	2832062	et	4	main
mida	doc_725976921216_item	2832105	et	4	main
ta	doc_725976921216_item	2832106	et	4	main
iseseisev	doc_725976921216_item	2832111	et	3	main
kuulas	doc_725976921216_item	2832114	et	3	main
sõna	doc_725976921216_item	2832116	et	4	main
kui	doc_725976921216_item	2832119	et	3	main
et	doc_725976921216_item	2831839	et	3	main
mis	doc_725976921216_item	2831845	et	4	main
ajal	doc_725976921216_item	2831851	et	4	main
üldse	doc_725976921216_item	2831852	et	3	main
ruhnu	doc_725976921216_item	2831867	et	4	main
eesti	doc_725976921216_item	2831887	et	4	main
hääletu	doc_725976921216_item	2831892	et	4	main
kevad	doc_725976921216_item	2831893	et	3	main
seal	doc_725976921216_item	2831894	et	4	main
kruusa	doc_725976921216_item	2831899	et	4	main
seda	doc_725976921216_item	2831902	et	3	main
mõtlematult	doc_725976921216_item	2831905	et	4	main
hävinesid	doc_725976921216_item	2831906	et	4	main
mõned	doc_725976921216_item	2831907	et	3	main
ajalooliselt	doc_725976921216_item	2831912	et	4	main
olid	doc_725976921216_item	2831928	et	4	main
kui	doc_725976921216_item	2831930	et	3	main
riigid	doc_725976921216_item	2831932	et	3	main
kombeks	doc_725976921216_item	2831934	et	4	main
riigilt	doc_725976921216_item	2831935	et	3	main
näppamine	doc_725976921216_item	2831936	et	4	main
müüdud	doc_725976921216_item	2831950	et	4	main
kaup	doc_725976921216_item	2831965	et	3	main
kohe	doc_725976921216_item	2831966	et	4	main
kõik	doc_725976921216_item	2831967	et	4	main
siis	doc_725976921216_item	2831986	et	3	main
inimesed	doc_725976921216_item	2831987	et	3	main
vähese	doc_725976921216_item	2831988	et	3	main
saan	doc_725976921216_item	2832007	et	4	main
rääkida	doc_725976921216_item	2832008	et	3	main
mulle	doc_725976921216_item	2832028	et	4	main
tundus	doc_725976921216_item	2832029	et	3	main
mida	doc_725976921216_item	2832034	et	4	main
mida	doc_725976921216_item	2832039	et	4	main
tegi	doc_725976921216_item	2832041	et	4	main
vabadust	doc_725976921216_item	2832052	et	4	main
teha	doc_725976921216_item	2832056	et	3	main
ta	doc_725976921216_item	2832059	et	4	main
kogu	doc_725976921216_item	2832065	et	4	main
sõna	doc_725976921216_item	2832069	et	4	main
aga	doc_725976921216_item	2832070	et	3	main
siis	doc_725976921216_item	2832071	et	3	main
kui	doc_725976921216_item	2832072	et	3	main
tahtis	doc_725976921216_item	2832107	et	3	main
ta	doc_725976921216_item	2832108	et	4	main
ta	doc_725976921216_item	2832120	et	4	main
võttis	doc_725976921216_item	2832124	et	3	main
otsustas	doc_725976921216_item	2832126	et	3	main
armsa	doc_725976921216_item	2832132	et	3	main
ta	doc_725976921216_item	2832137	et	4	main
tuli	doc_725976921216_item	2832138	et	4	main
vabadust	doc_725976921216_item	2832145	et	4	main
ei	doc_725976921216_item	2832156	et	4	main
saanud	doc_725976921216_item	2832157	et	4	main
temaga	doc_725976921216_item	2832158	et	3	main
koos	doc_725976921216_item	2832159	et	4	main
olla	doc_725976921216_item	2832160	et	3	main
lõppudeks	doc_725976921216_item	2832161	et	3	main
tema	doc_725976921216_item	2832167	et	4	main
koht	doc_725976921216_item	2832168	et	3	main
sattus	doc_725976921216_item	2832172	et	3	main
ja	doc_725976921216_item	2832174	et	3	main
näinud	doc_725976921216_item	2832184	et	4	main
üldse	doc_725976921216_item	2832185	et	3	main
mitte	doc_725976921216_item	2832186	et	3	main
käisid	doc_725976921216_item	2832191	et	4	main
hea	doc_725976921216_item	2832192	et	4	main
piletid	doc_725976921216_item	2832194	et	3	main
popularne	doc_725976921216_item	2832208	et	4	main
isegi	doc_725976921216_item	2832210	et	4	main
väiksed	doc_725976921216_item	2832211	et	4	main
teatri	doc_725976921216_item	2832212	et	3	main
jaoks	doc_725976921216_item	2832220	et	4	main
muulastele	doc_725976921216_item	2832230	et	4	main
eesti	doc_725976921217_item	2832239	et	4	main
nsv-s	doc_725976921217_item	2832240	et	3	main
suuremad	doc_725976921217_item	2832246	et	4	main
gigantproektid	doc_725976921217_item	2832282	et	4	main
loodusressursside	doc_725976921217_item	2832289	et	3	main
raiskamine	doc_725976921217_item	2832290	et	4	main
hruštšovi	doc_725976921217_item	2832304	et	2	main
sulaks	doc_725976921217_item	2832307	et	4	main
eestis	doc_725976921216_item	2831924	et	3	main
eestlastele	doc_725976921216_item	2831948	et	4	main
ei	doc_725976921216_item	2831949	et	4	main
kõike	doc_725976921216_item	2831952	et	4	main
viidi	doc_725976921216_item	2831953	et	4	main
riigist	doc_725976921216_item	2831954	et	3	main
välja	doc_725976921216_item	2831955	et	4	main
oli	doc_725976921216_item	2831956	et	3	main
defitsiit	doc_725976921216_item	2831957	et	3	main
nt	doc_725976921216_item	2831958	et	4	main
wc	doc_725976921216_item	2831959	et	4	main
paber	doc_725976921216_item	2831960	et	3	main
kui	doc_725976921216_item	2831961	et	3	main
kuskilt	doc_725976921216_item	2831962	et	4	main
mingi	doc_725976921216_item	2831964	et	4	main
ostsid	doc_725976921216_item	2831971	et	4	main
ei	doc_725976921216_item	2831974	et	4	main
neil	doc_725976921216_item	2831976	et	4	main
vaja	doc_725976921216_item	2831979	et	4	main
aga	doc_725976921216_item	2831980	et	3	main
äkki	doc_725976921216_item	2831981	et	3	main
kunagi	doc_725976921216_item	2831982	et	3	main
läheb	doc_725976921216_item	2831983	et	3	main
kaupa	doc_725976921216_item	2831990	et	4	main
mulle	doc_725976921216_item	2832001	et	4	main
väga	doc_725976921216_item	2832002	et	3	main
ma	doc_725976921216_item	2832006	et	3	main
ainult	doc_725976921216_item	2832009	et	4	main
ma	doc_725976921216_item	2832013	et	3	main
arvates	doc_725976921216_item	2832021	et	4	main
olid	doc_725976921216_item	2832023	et	4	main
suuremad	doc_725976921216_item	2832024	et	4	main
identiteediprobleemid	doc_725976921216_item	2832025	et	3	main
kui	doc_725976921216_item	2832026	et	3	main
kõike	doc_725976921216_item	2832033	et	4	main
ja	doc_725976921216_item	2832037	et	3	main
tal	doc_725976921216_item	2832043	et	3	main
aga	doc_725976921216_item	2832047	et	3	main
kõikke	doc_725976921216_item	2832057	et	4	main
mida	doc_725976921216_item	2832058	et	4	main
kõikke	doc_725976921216_item	2832104	et	4	main
kogu	doc_725976921216_item	2832112	et	4	main
aeg	doc_725976921216_item	2832113	et	3	main
siis	doc_725976921216_item	2832118	et	3	main
oma	doc_725976921216_item	2832131	et	4	main
erikal	doc_725976921216_item	2832142	et	4	main
ta	doc_725976921216_item	2832152	et	4	main
armastas	doc_725976921216_item	2832153	et	3	main
inimest	doc_725976921216_item	2832154	et	3	main
maailmas	doc_725976921216_item	2832170	et	3	main
ei	doc_725976921216_item	2832175	et	4	main
mida	doc_725976921216_item	2832177	et	4	main
teha	doc_725976921216_item	2832178	et	3	main
aga	doc_725976921216_item	2832179	et	3	main
oskar	doc_725976921216_item	2832180	et	4	main
minu	doc_725976921216_item	2832181	et	3	main
mingisugust	doc_725976921216_item	2832187	et	3	main
teatris	doc_725976921216_item	2832189	et	3	main
ringid	doc_725976921216_item	2832213	et	4	main
tahtis	doc_725976921216_item	2832036	et	3	main
olnud	doc_725976921216_item	2832051	et	4	main
saanud	doc_725976921216_item	2832055	et	4	main
ta	doc_725976921216_item	2832061	et	4	main
olnud	doc_725976921216_item	2832063	et	4	main
kuulas	doc_725976921216_item	2832067	et	3	main
ta	doc_725976921216_item	2832073	et	4	main
üks	doc_725976921216_item	2832074	et	3	main
kord	doc_725976921216_item	2832075	et	4	main
julguse	doc_725976921216_item	2832076	et	4	main
kokku	doc_725976921216_item	2832077	et	3	main
võttis	doc_725976921216_item	2832078	et	3	main
ja	doc_725976921216_item	2832079	et	3	main
otsustas	doc_725976921216_item	2832080	et	3	main
et	doc_725976921216_item	2832081	et	3	main
ta	doc_725976921216_item	2832082	et	4	main
põgeneb	doc_725976921216_item	2832083	et	3	main
kodust	doc_725976921216_item	2832084	et	4	main
oma	doc_725976921216_item	2832085	et	4	main
armsa	doc_725976921216_item	2832086	et	3	main
inimese	doc_725976921216_item	2832087	et	4	main
lõppude	doc_725976921216_item	2832089	et	4	main
lõppuks	doc_725976921216_item	2832090	et	3	main
pärast	doc_725976921216_item	2832088	et	4	main
ta	doc_725976921216_item	2832091	et	4	main
tuli	doc_725976921216_item	2832092	et	4	main
ikka	doc_725976921216_item	2832093	et	4	main
tagasi	doc_725976921216_item	2832094	et	3	main
koju	doc_725976921216_item	2832095	et	3	main
erikal	doc_725976921216_item	2832096	et	4	main
polnud	doc_725976921216_item	2832097	et	3	main
üldse	doc_725976921216_item	2832098	et	3	main
vabadust	doc_725976921216_item	2832099	et	4	main
ta	doc_725976921216_item	2832100	et	4	main
ei	doc_725976921216_item	2832101	et	4	main
olnud	doc_725976921216_item	2832110	et	4	main
ja	doc_725976921216_item	2832125	et	3	main
et	doc_725976921216_item	2832127	et	3	main
põgeneb	doc_725976921216_item	2832129	et	3	main
inimeses	doc_725976921216_item	2832133	et	3	main
lõppude	doc_725976921216_item	2832135	et	4	main
polnud	doc_725976921216_item	2832143	et	3	main
ta	doc_725976921216_item	2832146	et	4	main
on	doc_725976921216_item	2832166	et	4	main
ta	doc_725976921216_item	2832171	et	4	main
meelest	doc_725976921216_item	2832182	et	4	main
ei	doc_725976921216_item	2832183	et	4	main
soodsad	doc_725976921216_item	2832197	et	4	main
ja	doc_725976921216_item	2832198	et	3	main
igaüks	doc_725976921216_item	2832199	et	3	main
väga	doc_725976921216_item	2832207	et	3	main
iseloomulikult	doc_725976921216_item	2832216	et	4	main
palju	doc_725976921216_item	2832224	et	4	main
rohkem	doc_725976921216_item	2832227	et	4	main
romaanikirjandus	doc_725976921216_item	2832228	et	3	main
aga	doc_725976921216_item	2832229	et	3	main
1970ndate	doc_725976921217_item	2832238	et	4	main
arvates	doc_725976921217_item	2832245	et	4	main
erikal	doc_725976921217_item	2832249	et	4	main
tammsaare	doc_725976921217_item	2832252	et	3	main
sakslast	doc_725976921217_item	2832255	et	3	main
1	doc_725976921217_item	2832257	et	2	main
riigis	doc_725976921217_item	2832270	et	3	main
oli	doc_725976921217_item	2832271	et	3	main
juhtimine	doc_725976921217_item	2832273	et	4	main
sellele	doc_725976921217_item	2832283	et	4	main
looduse	doc_725976921217_item	2832291	et	4	main
nsvl	doc_725976921217_item	2832298	et	4	main
hakkas	doc_725976921217_item	2832299	et	3	main
lääneriikidest	doc_725976921217_item	2832300	et	3	main
maha	doc_725976921217_item	2832301	et	4	main
valitsemisajajärku	doc_725976921217_item	2832305	et	4	main
tol	doc_725976921217_item	2832322	et	3	main
oli	doc_725976921217_item	2832324	et	3	main
kõik	doc_725976921217_item	2832329	et	4	main
ka	doc_725976921217_item	2832332	et	3	main
kaasa	doc_725976921217_item	2832345	et	4	main
üheks	doc_725976921217_item	2832352	et	3	main
oma	doc_725976921217_item	2832359	et	4	main
oli	doc_725976921217_item	2832364	et	3	main
oli	doc_725976921217_item	2832367	et	3	main
tehaseid	doc_725976921217_item	2832369	et	3	main
mis	doc_725976921217_item	2832370	et	4	main
või	doc_725976921217_item	2832379	et	4	main
keemitehased	doc_725976921217_item	2832380	et	4	main
poliitikas	doc_725976921217_item	2832387	et	3	main
pärlijõe	doc_725976921217_item	2832422	et	3	main
seal	doc_725976921217_item	2832426	et	4	main
hakati	doc_725976921217_item	2832432	et	3	main
rohkem	doc_725976921217_item	2832433	et	4	main
tundma	doc_725976921217_item	2832434	et	3	main
puudu	doc_725976921217_item	2832435	et	4	main
mõnedest	doc_725976921217_item	2832436	et	3	main
piirkondades	doc_725976921217_item	2832449	et	3	main
see	doc_725976921217_item	2832452	et	3	main
maailmavaade	doc_725976921217_item	2832467	et	3	main
oli	doc_725976921217_item	2832469	et	3	main
kui	doc_725976921217_item	2832492	et	3	main
puhkus	doc_725976921217_item	2832496	et	3	main
elu	doc_725976921217_item	2832498	et	4	main
oli	doc_725976921217_item	2832506	et	3	main
kes	doc_725976921217_item	2832510	et	4	main
ääremaadele	doc_725976921217_item	2832516	et	4	main
kokkuvõtteks	doc_725976921217_item	2832517	et	3	main
võib	doc_725976921217_item	2832518	et	3	main
öelda	doc_725976921217_item	2832519	et	4	main
vastasseis	doc_725976921217_item	2832524	et	3	main
majanduse	doc_725976921217_item	2832527	et	4	main
romaanidest	doc_725976921217_item	2832539	et	3	main
on	doc_725976921217_item	2832541	et	4	main
filmistatud	doc_725976921217_item	2832542	et	4	main
ja	doc_725976921217_item	2832547	et	3	main
peremees	doc_725976921217_item	2832554	et	4	main
romaad	doc_725976921217_item	2832576	et	4	main
kohe	doc_725976921217_item	2832584	et	4	main
mitu	doc_725976921217_item	2832585	et	4	main
ükskord	doc_725976921216_item	2832121	et	3	main
kodust	doc_725976921216_item	2832130	et	4	main
pärast	doc_725976921216_item	2832134	et	4	main
lõppuks	doc_725976921216_item	2832136	et	3	main
üldse	doc_725976921216_item	2832144	et	3	main
ei	doc_725976921216_item	2832147	et	4	main
tunnud	doc_725976921216_item	2832148	et	4	main
ennast	doc_725976921216_item	2832149	et	4	main
ja	doc_725976921216_item	2832155	et	3	main
ei	doc_725976921216_item	2832163	et	4	main
teandus	doc_725976921216_item	2832164	et	4	main
kus	doc_725976921216_item	2832165	et	3	main
segadusse	doc_725976921216_item	2832173	et	3	main
inimesed	doc_725976921216_item	2832190	et	3	main
meelega	doc_725976921216_item	2832193	et	4	main
olid	doc_725976921216_item	2832195	et	4	main
väga	doc_725976921216_item	2832196	et	3	main
käimine	doc_725976921216_item	2832205	et	4	main
oli	doc_725976921216_item	2832206	et	3	main
tekkisid	doc_725976921216_item	2832209	et	4	main
pigem	doc_725976921216_item	2832217	et	3	main
mitte	doc_725976921216_item	2832218	et	3	main
eestlaste	doc_725976921216_item	2832219	et	4	main
eestlastele	doc_725976921216_item	2832225	et	4	main
meeldib	doc_725976921216_item	2832226	et	3	main
1	doc_725976921217_item	2832233	et	2	main
majanduse	doc_725976921217_item	2832234	et	4	main
ja	doc_725976921217_item	2832235	et	3	main
loodushoiu	doc_725976921217_item	2832236	et	3	main
vastasseis	doc_725976921217_item	2832237	et	3	main
teie	doc_725976921217_item	2832244	et	4	main
või	doc_725976921217_item	2832250	et	4	main
armastasin	doc_725976921217_item	2832254	et	3	main
käsumajandus	doc_725976921217_item	2832269	et	3	main
büroklaatlik	doc_725976921217_item	2832272	et	4	main
priviligeerituks	doc_725976921217_item	2832274	et	4	main
majandusharuks	doc_725976921217_item	2832275	et	3	main
oli	doc_725976921217_item	2832276	et	3	main
sõjatööstus	doc_725976921217_item	2832277	et	3	main
majandus	doc_725976921217_item	2832278	et	4	main
arenes	doc_725976921217_item	2832279	et	3	main
ajaloo	doc_725976921217_item	2832284	et	4	main
perioodile	doc_725976921217_item	2832285	et	3	main
saastamine	doc_725976921217_item	2832292	et	4	main
varsti	doc_725976921217_item	2832293	et	3	main
aga	doc_725976921217_item	2832294	et	3	main
nimetatakse	doc_725976921217_item	2832306	et	3	main
eesti	doc_725976921217_item	2832321	et	4	main
see	doc_725976921217_item	2832328	et	3	main
ja	doc_725976921217_item	2832337	et	3	main
reostajaks	doc_725976921217_item	2832355	et	4	main
oli	doc_725976921217_item	2832356	et	3	main
nõukogude	doc_725976921217_item	2832357	et	3	main
ida-virumaa	doc_725976921217_item	2832365	et	4	main
jaoks	doc_725976921217_item	2832378	et	4	main
peamine	doc_725976921217_item	2832385	et	3	main
põhimõtteliselt	doc_725976921216_item	2832201	et	4	main
need	doc_725976921216_item	2832202	et	3	main
kätte	doc_725976921216_item	2832203	et	4	main
see	doc_725976921216_item	2832204	et	3	main
kino	doc_725976921216_item	2832214	et	4	main
oli	doc_725976921216_item	2832215	et	3	main
lugesid	doc_725976921216_item	2832221	et	4	main
ka	doc_725976921216_item	2832223	et	3	main
kontrolltöö	doc_725976921217_item	2832232	et	4	main
on	doc_725976921217_item	2832243	et	4	main
kas	doc_725976921217_item	2832248	et	3	main
oskaril	doc_725976921217_item	2832251	et	4	main
järgi	doc_725976921217_item	2832268	et	4	main
ekstensiivselt	doc_725976921217_item	2832280	et	4	main
põhjendamatud	doc_725976921217_item	2832281	et	4	main
majanduse	doc_725976921217_item	2832295	et	4	main
allakäik	doc_725976921217_item	2832296	et	3	main
jäätma	doc_725976921217_item	2832302	et	4	main
siis	doc_725976921217_item	2832308	et	3	main
ajal	doc_725976921217_item	2832323	et	4	main
veel	doc_725976921217_item	2832325	et	4	main
nsvl	doc_725976921217_item	2832326	et	4	main
oli	doc_725976921217_item	2832330	et	3	main
iseloomulik	doc_725976921217_item	2832331	et	3	main
eestile	doc_725976921217_item	2832333	et	3	main
ekstensiivne	doc_725976921217_item	2832335	et	3	main
loodusvaresid	doc_725976921217_item	2832338	et	3	main
areng	doc_725976921217_item	2832340	et	3	main
oeamiseks	doc_725976921217_item	2832353	et	4	main
looduse	doc_725976921217_item	2832354	et	4	main
sõjaväebaasidega	doc_725976921217_item	2832360	et	3	main
tööstusrajooniks	doc_725976921217_item	2832363	et	3	main
palju	doc_725976921217_item	2832368	et	4	main
tootsid	doc_725976921217_item	2832371	et	4	main
igasuguseid	doc_725976921217_item	2832372	et	3	main
asju	doc_725976921217_item	2832373	et	3	main
näiteks	doc_725976921217_item	2832374	et	4	main
mingisuguseid	doc_725976921217_item	2832375	et	3	main
detailid	doc_725976921217_item	2832376	et	3	main
relvade	doc_725976921217_item	2832377	et	3	main
tootsid	doc_725976921217_item	2832382	et	4	main
asi	doc_725976921217_item	2832386	et	4	main
ja	doc_725976921217_item	2832405	et	3	main
pärlid	doc_725976921217_item	2832430	et	3	main
taimeliikidest	doc_725976921217_item	2832437	et	3	main
kaldest	doc_725976921217_item	2832438	et	4	main
oli	doc_725976921217_item	2832453	et	3	main
ainult	doc_725976921217_item	2832465	et	4	main
ka	doc_725976921217_item	2832470	et	3	main
kõik	doc_725976921217_item	2832488	et	4	main
said	doc_725976921217_item	2832489	et	4	main
sellest	doc_725976921217_item	2832491	et	4	main
looduse	doc_725976921217_item	2832495	et	4	main
meie	doc_725976921217_item	2832497	et	4	main
ringis	doc_725976921217_item	2832499	et	4	main
see	doc_725976921217_item	2832500	et	3	main
range	doc_725976921217_item	2832507	et	4	main
70	doc_725976921217_item	2832521	et	2	main
vahel	doc_725976921217_item	2832528	et	4	main
oli	doc_725976921217_item	2832529	et	3	main
tugev	doc_725976921217_item	2832531	et	4	main
2	doc_725976921217_item	2832532	et	2	main
ma	doc_725976921217_item	2832533	et	3	main
armastasin	doc_725976921217_item	2832534	et	3	main
sakslast	doc_725976921217_item	2832535	et	3	main
mina	doc_725976921217_item	2832543	et	4	main
olen	doc_725976921217_item	2832544	et	3	main
armastus	doc_725976921217_item	2832551	et	4	main
ning	doc_725976921217_item	2832552	et	3	main
põrgupõhja	doc_725976921217_item	2832559	et	4	main
oskari	doc_725976921217_item	2832573	et	4	main
kihtide	doc_725976921217_item	2832592	et	3	main
vahekorda	doc_725976921217_item	2832593	et	4	main
erinevate	doc_725976921217_item	2832594	et	4	main
vahekorda	doc_725976921217_item	2832597	et	4	main
ning	doc_725976921217_item	2832598	et	3	main
suuremad	doc_725976921217_item	2832606	et	4	main
erikal	doc_725976921217_item	2832609	et	4	main
oskar	doc_725976921217_item	2832631	et	4	main
armastas	doc_725976921217_item	2832632	et	3	main
sakslast	doc_725976921217_item	2832633	et	3	main
nad	doc_725976921216_item	2832222	et	3	main
luule	doc_725976921216_item	2832231	et	4	main
2	doc_725976921217_item	2832241	et	2	main
kellel	doc_725976921217_item	2832242	et	4	main
identiteediprobleemid	doc_725976921217_item	2832247	et	3	main
ma	doc_725976921217_item	2832253	et	3	main
põhjendage	doc_725976921217_item	2832256	et	3	main
1970	doc_725976921217_item	2832258	et	2	main
aas	doc_725976921217_item	2832259	et	3	main
tatel	doc_725976921217_item	2832260	et	3	main
nsvl	doc_725976921217_item	2832261	et	4	main
peaks	doc_725976921217_item	2832262	et	4	main
oli	doc_725976921217_item	2832263	et	3	main
breznev	doc_725976921217_item	2832264	et	4	main
majanduselu	doc_725976921217_item	2832265	et	4	main
oli	doc_725976921217_item	2832266	et	3	main
plaani	doc_725976921217_item	2832267	et	4	main
nsvl-u	doc_725976921217_item	2832286	et	4	main
ajaloos	doc_725976921217_item	2832287	et	4	main
iseloomulik	doc_725976921217_item	2832288	et	3	main
sest	doc_725976921217_item	2832297	et	4	main
kui	doc_725976921217_item	2832303	et	3	main
koosseisus	doc_725976921217_item	2832327	et	4	main
majanduse	doc_725976921217_item	2832334	et	4	main
eesti	doc_725976921217_item	2832346	et	4	main
olukorra	doc_725976921217_item	2832348	et	3	main
halvenemise	doc_725976921217_item	2832349	et	4	main
tol	doc_725976921217_item	2832350	et	3	main
ajal	doc_725976921217_item	2832351	et	4	main
armee	doc_725976921217_item	2832358	et	4	main
eestis	doc_725976921217_item	2832361	et	3	main
peamiseks	doc_725976921217_item	2832362	et	3	main
seal	doc_725976921217_item	2832366	et	4	main
keemilisi	doc_725976921217_item	2832383	et	4	main
saavutada	doc_725976921217_item	2832389	et	3	main
näiteks	doc_725976921217_item	2832421	et	4	main
aga	doc_725976921217_item	2832439	et	3	main
ka	doc_725976921217_item	2832440	et	3	main
maavaradest	doc_725976921217_item	2832441	et	3	main
aga	doc_725976921217_item	2832442	et	3	main
see	doc_725976921217_item	2832443	et	3	main
küll	doc_725976921217_item	2832444	et	4	main
polnud	doc_725976921217_item	2832445	et	3	main
kõikjal	doc_725976921217_item	2832446	et	3	main
ja	doc_725976921217_item	2832473	et	3	main
mida	doc_725976921217_item	2832475	et	4	main
tehaste	doc_725976921217_item	2832478	et	3	main
kasutati	doc_725976921217_item	2832481	et	4	main
endiselt	doc_725976921217_item	2832482	et	4	main
vett	doc_725976921217_item	2832483	et	3	main
jõed	doc_725976921217_item	2832484	et	3	main
järved	doc_725976921217_item	2832485	et	3	main
aru	doc_725976921217_item	2832490	et	4	main
tähtis	doc_725976921217_item	2832493	et	4	main
tsensuur	doc_725976921217_item	2832508	et	3	main
neid	doc_725976921217_item	2832509	et	4	main
oli	doc_725976921217_item	2832511	et	3	main
desidentmõtlemisega	doc_725976921217_item	2832512	et	4	main
kõrvaldati	doc_725976921217_item	2832513	et	3	main
ühiskonnast	doc_725976921217_item	2832514	et	4	main
breznevi	doc_725976921217_item	2832309	et	4	main
võimul	doc_725976921217_item	2832310	et	3	main
oleku	doc_725976921217_item	2832311	et	3	main
aega	doc_725976921217_item	2832312	et	4	main
riigi	doc_725976921217_item	2832313	et	3	main
iseloomustades	doc_725976921217_item	2832314	et	3	main
nimetatakse	doc_725976921217_item	2832315	et	3	main
stagnatsiooniks	doc_725976921217_item	2832316	et	3	main
e	doc_725976921217_item	2832317	et	4	main
seisakuks	doc_725976921217_item	2832318	et	3	main
ja	doc_725976921217_item	2832319	et	3	main
kuna	doc_725976921217_item	2832320	et	3	main
areng	doc_725976921217_item	2832336	et	3	main
raiskav	doc_725976921217_item	2832339	et	4	main
siinsetel	doc_725976921217_item	2832341	et	4	main
aladel	doc_725976921217_item	2832342	et	3	main
tõi	doc_725976921217_item	2832343	et	3	main
endaga	doc_725976921217_item	2832344	et	4	main
ökoloogilise	doc_725976921217_item	2832347	et	4	main
mis	doc_725976921217_item	2832381	et	4	main
tooteid	doc_725976921217_item	2832384	et	4	main
oli	doc_725976921217_item	2832388	et	3	main
kõrge	doc_725976921217_item	2832390	et	4	main
taseme	doc_725976921217_item	2832391	et	3	main
ja	doc_725976921217_item	2832392	et	3	main
rahvusvahelise	doc_725976921217_item	2832393	et	4	main
ja	doc_725976921217_item	2832395	et	3	main
loodushoiust	doc_725976921217_item	2832396	et	4	main
eriti	doc_725976921217_item	2832397	et	3	main
tunnistuse	doc_725976921217_item	2832394	et	4	main
ei	doc_725976921217_item	2832398	et	4	main
mõeldud	doc_725976921217_item	2832399	et	4	main
aga	doc_725976921217_item	2832400	et	3	main
sel	doc_725976921217_item	2832401	et	3	main
ajal	doc_725976921217_item	2832402	et	4	main
olukord	doc_725976921217_item	2832403	et	3	main
halvenes	doc_725976921217_item	2832404	et	3	main
halvenes	doc_725976921217_item	2832406	et	3	main
eestis	doc_725976921217_item	2832407	et	3	main
isegi	doc_725976921217_item	2832408	et	4	main
oli	doc_725976921217_item	2832409	et	3	main
oht	doc_725976921217_item	2832410	et	3	main
jääda	doc_725976921217_item	2832411	et	4	main
ilma	doc_725976921217_item	2832412	et	4	main
joogiveeta	doc_725976921217_item	2832413	et	3	main
mõned	doc_725976921217_item	2832414	et	3	main
loomaliigid	doc_725976921217_item	2832415	et	3	main
surid	doc_725976921217_item	2832416	et	4	main
välja	doc_725976921217_item	2832417	et	4	main
inimeste	doc_725976921217_item	2832418	et	3	main
ükskõiksuse	doc_725976921217_item	2832419	et	4	main
tõttu	doc_725976921217_item	2832420	et	4	main
karbid	doc_725976921217_item	2832423	et	3	main
aga	doc_725976921217_item	2832424	et	3	main
kõige	doc_725976921217_item	2832428	et	4	main
suuremad	doc_725976921217_item	2832429	et	4	main
vaid	doc_725976921217_item	2832447	et	3	main
juba	doc_725976921217_item	2832451	et	3	main
isik	doc_725976921217_item	2832463	et	3	main
riik	doc_725976921217_item	2832466	et	3	main
inimestel	doc_725976921217_item	2832468	et	3	main
natuke	doc_725976921217_item	2832471	et	4	main
väärtused	doc_725976921217_item	2832474	et	3	main
kunagi	doc_725976921217_item	2832425	et	3	main
oli	doc_725976921217_item	2832427	et	3	main
baltikumis	doc_725976921217_item	2832431	et	4	main
mõnedes	doc_725976921217_item	2832448	et	3	main
kuid	doc_725976921217_item	2832450	et	4	main
valitsuse	doc_725976921217_item	2832454	et	4	main
tähelepanuväärne	doc_725976921217_item	2832455	et	3	main
seetõttu	doc_725976921217_item	2832456	et	3	main
et	doc_725976921217_item	2832457	et	3	main
tol	doc_725976921217_item	2832458	et	3	main
valitsemiskorral	doc_725976921217_item	2832459	et	3	main
oli	doc_725976921217_item	2832461	et	3	main
peamine	doc_725976921217_item	2832460	et	3	main
mitte	doc_725976921217_item	2832462	et	3	main
vaid	doc_725976921217_item	2832464	et	3	main
teine	doc_725976921217_item	2832472	et	3	main
õhku	doc_725976921217_item	2832486	et	4	main
mitte	doc_725976921217_item	2832487	et	3	main
võis	doc_725976921217_item	2832501	et	4	main
olla	doc_725976921217_item	2832502	et	3	main
ka	doc_725976921217_item	2832503	et	3	main
sellepärast	doc_725976921217_item	2832504	et	3	main
kuskile	doc_725976921217_item	2832515	et	4	main
loodushoiu	doc_725976921217_item	2832525	et	3	main
on	doc_725976921217_item	2832536	et	4	main
mis	doc_725976921217_item	2832540	et	4	main
kõrbeoja	doc_725976921217_item	2832553	et	4	main
ja	doc_725976921217_item	2832572	et	3	main
on	doc_725976921217_item	2832577	et	4	main
filosoofiline	doc_725976921217_item	2832579	et	4	main
tammsaare	doc_725976921217_item	2832580	et	3	main
puudutab	doc_725976921217_item	2832581	et	3	main
ühes	doc_725976921217_item	2832582	et	4	main
teoses	doc_725976921217_item	2832583	et	3	main
ühiskonna	doc_725976921217_item	2832590	et	4	main
meelest	doc_725976921217_item	2832602	et	4	main
noormehel	doc_725976921217_item	2832603	et	3	main
oli	doc_725976921217_item	2832604	et	3	main
identiteediga	doc_725976921217_item	2832605	et	4	main
ikkagi	doc_725976921217_item	2832627	et	4	main
isegi	doc_725976921217_item	2832635	et	4	main
seda	doc_725976921217_item	2832636	et	3	main
rõhutab	doc_725976921217_item	2832638	et	3	main
kõla	doc_725976921217_item	2832642	et	4	main
ma	doc_725976921217_item	2832643	et	3	main
armastasin	doc_725976921217_item	2832644	et	3	main
erikat	doc_725976921217_item	2832645	et	4	main
ma	doc_725976921217_item	2832659	et	3	main
armastusest	doc_725976921217_item	2832670	et	4	main
kui	doc_725976921217_item	2832671	et	3	main
mehed	doc_725976921217_item	2832672	et	3	main
ja	doc_725976921217_item	2832673	et	3	main
veel	doc_725976921217_item	2832674	et	4	main
sellepärast	doc_725976921217_item	2832675	et	3	main
et	doc_725976921217_item	2832676	et	3	main
mõttekäigust	doc_725976921217_item	2832684	et	3	main
maailma	doc_725976921217_item	2832686	et	4	main
ellu	doc_725976921217_item	2832688	et	4	main
on	doc_725976921217_item	2832692	et	4	main
ta	doc_725976921217_item	2832732	et	4	main
ja	doc_725976921217_item	2832738	et	3	main
tütre	doc_725976921217_item	2832740	et	3	main
aga	doc_725976921217_item	2832750	et	3	main
ei	doc_725976921217_item	2832768	et	4	main
lõpus	doc_725976921217_item	2832775	et	4	main
õigesse	doc_737963622253_item	2832782	et	3	main
piret	doc_737963622253_item	2832784	et	4	main
toomet	doc_737963622253_item	2832785	et	4	main
kuulutust	doc_737963622253_item	2832795	et	4	main
et	doc_737963622253_item	2832796	et	3	main
õpetama	doc_737963622253_item	2832821	et	3	main
mulle	doc_737963622253_item	2832836	et	4	main
siberist	doc_737963622253_item	2832845	et	4	main
kui	doc_737963622253_item	2832857	et	3	main
pärast	doc_737963622253_item	2832864	et	4	main
sügisel	doc_737963622253_item	2832883	et	3	main
vaid	doc_737963622253_item	2832913	et	3	main
murret	doc_737963622253_item	2832917	et	4	main
on	doc_737963622253_item	2832919	et	4	main
vene	doc_737963622253_item	2832928	et	4	main
keeles	doc_737963622253_item	2832929	et	4	main
külas	doc_737963622253_item	2832930	et	3	main
elab	doc_737963622253_item	2832931	et	3	main
pireti	doc_737963622253_item	2832942	et	4	main
sõnul	doc_737963622253_item	2832943	et	3	main
lapsed	doc_737963622253_item	2832945	et	3	main
raamatud	doc_737963622253_item	2832947	et	4	main
saadetakse	doc_737963622253_item	2832950	et	3	main
õpikud	doc_737963622253_item	2832953	et	3	main
kartma	doc_737963622253_item	2832958	et	3	main
soe	doc_737963622253_item	2832969	et	4	main
juba	doc_737963622253_item	2832977	et	3	main
ahju	doc_737963622253_item	2832980	et	4	main
ja	doc_737963622253_item	2833021	et	3	main
kaunim	doc_737963622253_item	2833025	et	4	main
naeratus	doc_737963622253_item	2833026	et	4	main
hinnati	doc_725976921217_item	2832476	et	3	main
ka	doc_725976921217_item	2832477	et	3	main
jäänuste	doc_725976921217_item	2832479	et	3	main
jaoks	doc_725976921217_item	2832480	et	4	main
on	doc_725976921217_item	2832494	et	4	main
et	doc_725976921217_item	2832505	et	3	main
et	doc_725976921217_item	2832520	et	3	main
ndate	doc_725976921217_item	2832522	et	4	main
üks	doc_725976921217_item	2832537	et	3	main
tammsaare	doc_725976921217_item	2832538	et	3	main
lugenud	doc_725976921217_item	2832545	et	4	main
õigus	doc_725976921217_item	2832548	et	4	main
elu	doc_725976921217_item	2832549	et	4	main
ja	doc_725976921217_item	2832550	et	3	main
armastuslugu	doc_725976921217_item	2832574	et	4	main
käsitlev	doc_725976921217_item	2832575	et	4	main
vahekorda	doc_725976921217_item	2832589	et	4	main
kultuuri	doc_725976921217_item	2832595	et	4	main
identiteedi	doc_725976921217_item	2832599	et	4	main
probleemi	doc_725976921217_item	2832600	et	4	main
minu	doc_725976921217_item	2832601	et	3	main
probleemid	doc_725976921217_item	2832607	et	3	main
palju	doc_725976921217_item	2832621	et	4	main
eestlased	doc_725976921217_item	2832623	et	3	main
venelased	doc_725976921217_item	2832625	et	3	main
kuidagi	doc_725976921217_item	2832637	et	3	main
on	doc_725976921217_item	2832657	et	4	main
et	doc_725976921217_item	2832661	et	3	main
on	doc_725976921217_item	2832663	et	4	main
hästi	doc_725976921217_item	2832680	et	3	main
ja	doc_725976921217_item	2832687	et	3	main
on	doc_725976921217_item	2832722	et	4	main
näha	doc_725976921217_item	2832730	et	3	main
meelde	doc_725976921217_item	2832736	et	3	main
ja	doc_725976921217_item	2832741	et	3	main
piir	doc_725976921217_item	2832743	et	3	main
nende	doc_725976921217_item	2832762	et	4	main
vahel	doc_725976921217_item	2832763	et	4	main
nendes	doc_725976921217_item	2832764	et	4	main
suhetes	doc_725976921217_item	2832765	et	3	main
oma	doc_725976921217_item	2832770	et	4	main
probleemid	doc_725976921217_item	2832771	et	3	main
identiteediga	doc_725976921217_item	2832772	et	4	main
ka	doc_725976921217_item	2832773	et	3	main
pange	doc_737963622253_item	2832778	et	4	main
on	doc_737963622253_item	2832786	et	4	main
ettevõtlik	doc_737963622253_item	2832787	et	3	main
naine	doc_737963622253_item	2832788	et	3	main
suvel	doc_737963622253_item	2832789	et	3	main
nägema	doc_737963622253_item	2832790	et	3	main
nägi	doc_737963622253_item	2832791	et	3	main
ta	doc_737963622253_item	2832792	et	4	main
ülem-suetuki	doc_737963622253_item	2832798	et	4	main
ta	doc_737963622253_item	2832825	et	4	main
selline	doc_737963622253_item	2832846	et	4	main
pilt	doc_737963622253_item	2832847	et	3	main
et	doc_737963622253_item	2832848	et	3	main
noor	doc_737963622253_item	2832858	et	3	main
kõige	doc_737963622253_item	2832884	et	4	main
tähtis	doc_737963622253_item	2832885	et	4	main
tänaseks	doc_737963622253_item	2832888	et	4	main
kartul	doc_737963622253_item	2832890	et	3	main
salv	doc_737963622253_item	2832891	et	3	main
aktsentiga	doc_737963622253_item	2832912	et	4	main
venemaa	doc_737963622253_item	2832921	et	4	main
ja	doc_737963622253_item	2832923	et	3	main
ülejäänud	doc_737963622253_item	2832924	et	4	main
aine	doc_737963622253_item	2832925	et	4	main
ained	doc_737963622253_item	2832926	et	3	main
õpetatakse	doc_737963622253_item	2832927	et	3	main
kolmesaja	doc_737963622253_item	2832935	et	4	main
inimene	doc_737963622253_item	2832936	et	3	main
inimest	doc_737963622253_item	2832937	et	3	main
emakeelt	doc_737963622253_item	2832938	et	4	main
poolpõlenud	doc_737963622253_item	2832946	et	4	main
saatma	doc_737963622253_item	2832949	et	3	main
eestist	doc_737963622253_item	2832951	et	3	main
siberi	doc_737963622253_item	2832954	et	4	main
talve	doc_737963622253_item	2832955	et	4	main
veel	doc_737963622253_item	2832968	et	4	main
harjutan	doc_737963622253_item	2832976	et	3	main
aastate	doc_725976921217_item	2832523	et	3	main
ja	doc_725976921217_item	2832526	et	3	main
päris	doc_725976921217_item	2832530	et	4	main
tõde	doc_725976921217_item	2832546	et	4	main
ning	doc_725976921217_item	2832555	et	3	main
olen	doc_725976921217_item	2832556	et	3	main
läbi	doc_725976921217_item	2832557	et	4	main
vaadanud	doc_725976921217_item	2832558	et	4	main
vanapagan	doc_725976921217_item	2832560	et	3	main
ning	doc_725976921217_item	2832561	et	3	main
siin	doc_725976921217_item	2832562	et	4	main
ülikoolis	doc_725976921217_item	2832563	et	4	main
ma	doc_725976921217_item	2832564	et	3	main
armastasin	doc_725976921217_item	2832565	et	3	main
sakslast	doc_725976921217_item	2832566	et	3	main
nagu	doc_725976921217_item	2832567	et	3	main
kõik	doc_725976921217_item	2832568	et	4	main
tema	doc_725976921217_item	2832569	et	4	main
teosedki	doc_725976921217_item	2832570	et	3	main
erika	doc_725976921217_item	2832571	et	4	main
väga	doc_725976921217_item	2832578	et	3	main
erinevatge	doc_725976921217_item	2832591	et	4	main
kandjate	doc_725976921217_item	2832596	et	4	main
armastas	doc_725976921217_item	2832614	et	3	main
inimest	doc_725976921217_item	2832615	et	3	main
kes	doc_725976921217_item	2832616	et	4	main
erines	doc_725976921217_item	2832617	et	3	main
muidu	doc_725976921217_item	2832618	et	3	main
mitte	doc_725976921217_item	2832619	et	3	main
nii	doc_725976921217_item	2832620	et	3	main
probleemi	doc_725976921217_item	2832586	et	4	main
armastava	doc_725976921217_item	2832587	et	4	main
inimeste	doc_725976921217_item	2832588	et	3	main
kui	doc_725976921217_item	2832608	et	3	main
kõigeopealt	doc_725976921217_item	2832610	et	4	main
sellepärast	doc_725976921217_item	2832611	et	3	main
et	doc_725976921217_item	2832612	et	3	main
ta	doc_725976921217_item	2832613	et	4	main
nagu	doc_725976921217_item	2832622	et	3	main
aga	doc_725976921217_item	2832626	et	3	main
kultuuri	doc_725976921217_item	2832629	et	4	main
poolest	doc_725976921217_item	2832630	et	4	main
näiteks	doc_725976921217_item	2832639	et	4	main
arvasin	doc_725976921217_item	2832660	et	3	main
mees	doc_725976921217_item	2832664	et	4	main
tuleb	doc_725976921217_item	2832678	et	3	main
kirjutada	doc_725976921217_item	2832681	et	3	main
suhtumisest	doc_725976921217_item	2832689	et	4	main
ta	doc_725976921217_item	2832721	et	4	main
enese	doc_725976921217_item	2832723	et	4	main
tõmbunud	doc_725976921217_item	2832724	et	4	main
nagu	doc_725976921217_item	2832725	et	3	main
paljudki	doc_725976921217_item	2832726	et	3	main
kunstiinimesed	doc_725976921217_item	2832727	et	3	main
kogu	doc_725976921217_item	2832733	et	4	main
nende	doc_725976921217_item	2832744	et	4	main
et	doc_725976921217_item	2832746	et	3	main
eestlane	doc_725976921217_item	2832749	et	3	main
siiski	doc_725976921217_item	2832751	et	4	main
elab	doc_725976921217_item	2832752	et	3	main
oma	doc_725976921217_item	2832753	et	4	main
lahenda	doc_725976921217_item	2832769	et	4	main
elsamitöö	doc_737963622253_item	2832776	et	4	main
sõnad	doc_737963622253_item	2832781	et	4	main
siberisse	doc_737963622253_item	2832797	et	4	main
küla	doc_737963622253_item	2832799	et	4	main
keele	doc_737963622253_item	2832803	et	4	main
ja	doc_725976921217_item	2832624	et	3	main
temast	doc_725976921217_item	2832628	et	3	main
ta	doc_725976921217_item	2832640	et	4	main
ei	doc_725976921217_item	2832641	et	4	main
vaid	doc_725976921217_item	2832646	et	3	main
just	doc_725976921217_item	2832647	et	3	main
sakslast	doc_725976921217_item	2832648	et	3	main
enne	doc_725976921217_item	2832649	et	4	main
kui	doc_725976921217_item	2832650	et	3	main
ma	doc_725976921217_item	2832651	et	3	main
sain	doc_725976921217_item	2832652	et	3	main
teada	doc_725976921217_item	2832653	et	3	main
et	doc_725976921217_item	2832654	et	3	main
see	doc_725976921217_item	2832655	et	3	main
sakslane	doc_725976921217_item	2832656	et	3	main
sest	doc_725976921217_item	2832665	et	4	main
naised	doc_725976921217_item	2832667	et	3	main
rohkem	doc_725976921217_item	2832668	et	4	main
tammsaarel	doc_725976921217_item	2832677	et	3	main
oskar	doc_725976921217_item	2832691	et	4	main
ju	doc_725976921217_item	2832693	et	3	main
mees	doc_725976921217_item	2832694	et	4	main
ja	doc_725976921217_item	2832695	et	3	main
ta	doc_725976921217_item	2832696	et	4	main
armastab	doc_725976921217_item	2832697	et	3	main
erikat	doc_725976921217_item	2832698	et	4	main
juba	doc_725976921217_item	2832699	et	3	main
lapsepõlvest	doc_725976921217_item	2832700	et	4	main
saadik	doc_725976921217_item	2832701	et	4	main
aga	doc_725976921217_item	2832702	et	3	main
mida	doc_725976921217_item	2832703	et	4	main
ta	doc_725976921217_item	2832704	et	4	main
võib	doc_725976921217_item	2832705	et	3	main
niisugusele	doc_725976921217_item	2832706	et	3	main
peenele	doc_725976921217_item	2832707	et	3	main
daamile	doc_725976921217_item	2832708	et	3	main
pakkuda	doc_725976921217_item	2832709	et	3	main
peale	doc_725976921217_item	2832710	et	4	main
oma	doc_725976921217_item	2832711	et	4	main
armastust	doc_725976921217_item	2832712	et	4	main
ta	doc_725976921217_item	2832713	et	4	main
ei	doc_725976921217_item	2832714	et	4	main
ole	doc_725976921217_item	2832715	et	4	main
enesekindel	doc_725976921217_item	2832716	et	3	main
mingis	doc_725976921217_item	2832717	et	4	main
mõttes	doc_725976921217_item	2832718	et	3	main
ta	doc_725976921217_item	2832719	et	4	main
kõhkleb	doc_725976921217_item	2832720	et	3	main
pealkiri	doc_725976921217_item	2832634	et	3	main
naine	doc_725976921217_item	2832658	et	3	main
see	doc_725976921217_item	2832662	et	3	main
tavaliselt	doc_725976921217_item	2832666	et	4	main
kannatavad	doc_725976921217_item	2832669	et	4	main
väga	doc_725976921217_item	2832679	et	3	main
naistest	doc_725976921217_item	2832682	et	4	main
naiste	doc_725976921217_item	2832683	et	3	main
ning	doc_725976921217_item	2832685	et	3	main
aga	doc_725976921217_item	2832690	et	3	main
filmis	doc_725976921217_item	2832728	et	4	main
on	doc_725976921217_item	2832729	et	4	main
aeg	doc_725976921217_item	2832734	et	3	main
tuletab	doc_725976921217_item	2832735	et	3	main
saksa	doc_725976921217_item	2832739	et	4	main
see	doc_725976921217_item	2832742	et	3	main
vahel	doc_725976921217_item	2832745	et	4	main
ta	doc_725976921217_item	2832747	et	4	main
lihtne	doc_725976921217_item	2832748	et	3	main
ta	doc_725976921217_item	2832756	et	4	main
on	doc_725976921217_item	2832757	et	4	main
rikkas	doc_725976921217_item	2832758	et	4	main
sakslane	doc_725976921217_item	2832759	et	3	main
on	doc_725976921217_item	2832760	et	4	main
olemas	doc_725976921217_item	2832766	et	4	main
i	doc_737963622253_item	2832777	et	4	main
oloevad	doc_737963622253_item	2832780	et	4	main
vormi	doc_737963622253_item	2832783	et	4	main
kuulutus	doc_737963622253_item	2832794	et	4	main
küllas	doc_737963622253_item	2832800	et	3	main
otsitakse	doc_737963622253_item	2832801	et	3	main
eesti	doc_737963622253_item	2832802	et	4	main
konkurss	doc_737963622253_item	2832807	et	3	main
konkurssi	doc_737963622253_item	2832808	et	4	main
tundis	doc_737963622253_item	2832824	et	3	main
on	doc_737963622253_item	2832829	et	4	main
oodatud	doc_737963622253_item	2832830	et	4	main
olin	doc_737963622253_item	2832831	et	3	main
üsna	doc_737963622253_item	2832832	et	3	main
üllatuma	doc_737963622253_item	2832833	et	3	main
audiga	doc_737963622253_item	2832841	et	3	main
mulle	doc_737963622253_item	2832842	et	4	main
maaliti	doc_737963622253_item	2832843	et	3	main
ei	doc_737963622253_item	2832850	et	4	main
lendama	doc_737963622253_item	2832851	et	3	main
rohi	doc_737963622253_item	2832856	et	4	main
tahtmine	doc_737963622253_item	2832860	et	4	main
tahtmise	doc_737963622253_item	2832861	et	4	main
täis	doc_737963622253_item	2832862	et	4	main
hoog	doc_737963622253_item	2832896	et	3	main
hooguga	doc_737963622253_item	2832897	et	4	main
siinsed	doc_737963622253_item	2832898	et	3	main
eestlased	doc_737963622253_item	2832899	et	3	main
räägivad	doc_737963622253_item	2832900	et	3	main
kuidagi	doc_737963622253_item	2832901	et	3	main
teistmoodi	doc_737963622253_item	2832902	et	3	main
mõnus	doc_737963622253_item	2832903	et	4	main
mahlakaselt	doc_737963622253_item	2832908	et	3	main
nagu	doc_737963622253_item	2832914	et	3	main
mõne	doc_737963622253_item	2832916	et	3	main
kool	doc_737963622253_item	2832922	et	4	main
üle	doc_737963622253_item	2832933	et	3	main
kõik	doc_737963622253_item	2832940	et	4	main
õpivad	doc_737963622253_item	2832944	et	3	main
karda	doc_737963622253_item	2832959	et	4	main
talvepuud	doc_737963622253_item	2832964	et	4	main
kuid	doc_737963622253_item	2832971	et	4	main
külapoest	doc_737963622253_item	2832987	et	4	main
müüdagi	doc_737963622253_item	2832994	et	3	main
mehelikum	doc_737963622253_item	2833023	et	4	main
kaunimaks	doc_737963622253_item	2833034	et	4	main
3	doc_737963622253_item	2833035	et	2	main
kogus	doc_737963622253_item	2833037	et	4	main
meid	doc_737963622253_item	2833052	et	4	main
tegutsema	doc_737963622253_item	2833053	et	3	main
aga	doc_737963622253_item	2833054	et	3	main
soovimatu	doc_737963622253_item	2833058	et	4	main
saama	doc_737963622253_item	2833078	et	4	main
nii	doc_737963622253_item	2833079	et	3	main
maagiline	doc_737963622253_item	2833080	et	4	main
aparaat	doc_737963622253_item	2833081	et	3	main
et	doc_737963622253_item	2833082	et	3	main
et	doc_725976921217_item	2832731	et	3	main
lapsepõlve	doc_725976921217_item	2832737	et	4	main
kodumaal	doc_725976921217_item	2832754	et	4	main
ja	doc_725976921217_item	2832755	et	3	main
siiski	doc_725976921217_item	2832761	et	4	main
oskar	doc_725976921217_item	2832767	et	4	main
filmi	doc_725976921217_item	2832774	et	4	main
sulgudes	doc_737963622253_item	2832779	et	4	main
ajalehes	doc_737963622253_item	2832793	et	3	main
õpetajat	doc_737963622253_item	2832804	et	4	main
piret	doc_737963622253_item	2832805	et	4	main
võitis	doc_737963622253_item	2832806	et	3	main
ja	doc_737963622253_item	2832809	et	3	main
on	doc_737963622253_item	2832810	et	4	main
nüüd	doc_737963622253_item	2832811	et	4	main
juba	doc_737963622253_item	2832812	et	3	main
üle	doc_737963622253_item	2832813	et	3	main
nädal	doc_737963622253_item	2832814	et	3	main
nädala	doc_737963622253_item	2832815	et	3	main
väikestele	doc_737963622253_item	2832816	et	4	main
eestlastele	doc_737963622253_item	2832817	et	4	main
need	doc_737963622253_item	2832818	et	3	main
neid	doc_737963622253_item	2832819	et	4	main
emakeelt	doc_737963622253_item	2832820	et	4	main
kinnitusel	doc_737963622253_item	2832823	et	4	main
jõudma	doc_737963622253_item	2832827	et	3	main
üllatatud	doc_737963622253_item	2832834	et	4	main
kui	doc_737963622253_item	2832835	et	3	main
siber	doc_737963622253_item	2832844	et	4	main
lenda	doc_737963622253_item	2832852	et	4	main
lind	doc_737963622253_item	2832853	et	3	main
ega	doc_737963622253_item	2832854	et	3	main
piret	doc_737963622253_item	2832863	et	4	main
tähtsam	doc_737963622253_item	2832886	et	4	main
on	doc_737963622253_item	2832889	et	4	main
ja	doc_737963622253_item	2832892	et	3	main
õppimine	doc_737963622253_item	2832893	et	4	main
käib	doc_737963622253_item	2832894	et	3	main
täie	doc_737963622253_item	2832895	et	3	main
mahlakas	doc_737963622253_item	2832905	et	4	main
mõnusalt	doc_737963622253_item	2832906	et	4	main
mitte	doc_737963622253_item	2832909	et	3	main
mõni	doc_737963622253_item	2832915	et	3	main
saab	doc_737963622253_item	2832939	et	3	main
piret	doc_737963622253_item	2832956	et	4	main
mulle	doc_737963622253_item	2832960	et	4	main
tooma	doc_737963622253_item	2832962	et	3	main
soe	doc_737963622253_item	2832970	et	4	main
suure	doc_737963622253_item	2832978	et	3	main
vildid	doc_737963622253_item	2832988	et	4	main
ega	doc_737963622253_item	2832989	et	3	main
pireti	doc_737963622253_item	2832822	et	4	main
siberisse	doc_737963622253_item	2832826	et	4	main
et	doc_737963622253_item	2832828	et	3	main
tulema	doc_737963622253_item	2832837	et	4	main
tuli	doc_737963622253_item	2832838	et	4	main
vastu	doc_737963622253_item	2832839	et	3	main
korralik	doc_737963622253_item	2832840	et	3	main
seal	doc_737963622253_item	2832849	et	4	main
kasva	doc_737963622253_item	2832855	et	4	main
ja	doc_737963622253_item	2832859	et	3	main
õppeaasta	doc_737963622253_item	2832865	et	4	main
algust	doc_737963622253_item	2832866	et	4	main
koht	doc_737963622253_item	2832867	et	3	main
kohale	doc_737963622253_item	2832868	et	4	main
jõudis	doc_737963622253_item	2832869	et	3	main
polnud	doc_737963622253_item	2832870	et	3	main
kool	doc_737963622253_item	2832871	et	4	main
veel	doc_737963622253_item	2832872	et	4	main
algama	doc_737963622253_item	2832873	et	3	main
alganud	doc_737963622253_item	2832874	et	4	main
kogu	doc_737963622253_item	2832875	et	4	main
küla	doc_737963622253_item	2832876	et	4	main
võtma	doc_737963622253_item	2832877	et	3	main
võttis	doc_737963622253_item	2832878	et	3	main
kartuleid	doc_737963622253_item	2832879	et	3	main
kartulivõtt	doc_737963622253_item	2832880	et	3	main
on	doc_737963622253_item	2832881	et	4	main
siin	doc_737963622253_item	2832882	et	4	main
ettevõtmine	doc_737963622253_item	2832887	et	3	main
ja	doc_737963622253_item	2832904	et	3	main
ja	doc_737963622253_item	2832907	et	3	main
vene	doc_737963622253_item	2832910	et	4	main
aktsent	doc_737963622253_item	2832911	et	3	main
kool	doc_737963622253_item	2832918	et	4	main
siiski	doc_737963622253_item	2832920	et	4	main
veidi	doc_737963622253_item	2832932	et	3	main
kolmsada	doc_737963622253_item	2832934	et	4	main
rääkida	doc_737963622253_item	2832941	et	3	main
varsti	doc_737963622253_item	2832948	et	3	main
uued	doc_737963622253_item	2832952	et	3	main
ei	doc_737963622253_item	2832957	et	4	main
juba	doc_737963622253_item	2832961	et	3	main
toodud	doc_737963622253_item	2832963	et	4	main
praegu	doc_737963622253_item	2832965	et	3	main
on	doc_737963622253_item	2832966	et	4	main
päevad	doc_737963622253_item	2832967	et	3	main
ööd	doc_737963622253_item	2832972	et	4	main
juba	doc_737963622253_item	2832973	et	3	main
jahe	doc_737963622253_item	2832974	et	3	main
jahe	doc_737963622253_item	2832975	et	3	main
vene	doc_737963622253_item	2832979	et	4	main
kütmine	doc_737963622253_item	2832981	et	4	main
kütma	doc_737963622253_item	2832982	et	3	main
kui	doc_737963622253_item	2832983	et	3	main
vaja	doc_737963622253_item	2832984	et	4	main
ostan	doc_737963622253_item	2832985	et	3	main
külapood	doc_737963622253_item	2832986	et	3	main
ei	doc_737963622253_item	2832993	et	4	main
naerab	doc_737963622253_item	2832995	et	3	main
talveks	doc_737963622253_item	2832996	et	4	main
valmistuma	doc_737963622253_item	2832997	et	3	main
valmistatud	doc_737963622253_item	2832998	et	4	main
piret	doc_737963622253_item	2832999	et	4	main
vapralt	doc_737963622253_item	2833000	et	4	main
lühendatud	doc_737963622253_item	2833001	et	4	main
ajalehest	doc_737963622253_item	2833002	et	4	main
slõhtuleht	doc_737963622253_item	2833003	et	4	main
iii	doc_737963622253_item	2833004	et	4	main
moodustage	doc_737963622253_item	2833005	et	3	main
etteantud	doc_737963622253_item	2833006	et	4	main
sõnadest	doc_737963622253_item	2833007	et	3	main
laused	doc_737963622253_item	2833008	et	3	main
pannes	doc_737963622253_item	2833009	et	4	main
sõnad	doc_737963622253_item	2833010	et	4	main
õigesse	doc_737963622253_item	2833011	et	3	main
vormi	doc_737963622253_item	2833012	et	4	main
ja	doc_737963622253_item	2833013	et	3	main
kasutades	doc_737963622253_item	2833014	et	3	main
kirjavahemärke	doc_737963622253_item	2833015	et	4	main
2	doc_737963622253_item	2833016	et	2	main
tegema	doc_737963622253_item	2833018	et	3	main
naised	doc_737963622253_item	2833019	et	3	main
naiselikum	doc_737963622253_item	2833020	et	4	main
naeratus	doc_737963622253_item	2833017	et	4	main
mehelikumaks	doc_737963622253_item	2833031	et	4	main
ja	doc_737963622253_item	2833032	et	3	main
igaühe	doc_737963622253_item	2833033	et	4	main
soovimatu	doc_737963622253_item	2833046	et	4	main
tagajärg	doc_737963622253_item	2833047	et	3	main
lisakoormus	doc_737963622253_item	2833048	et	3	main
seal	doc_737963622253_item	2832990	et	4	main
suurt	doc_737963622253_item	2832991	et	3	main
muud	doc_737963622253_item	2832992	et	4	main
mehed	doc_737963622253_item	2833022	et	3	main
igaüks	doc_737963622253_item	2833024	et	3	main
paras	doc_737963622253_item	2833036	et	3	main
koguses	doc_737963622253_item	2833050	et	4	main
paneb	doc_737963622253_item	2833051	et	3	main
tuua	doc_737963622253_item	2833057	et	3	main
sportima	doc_737963622253_item	2833069	et	4	main
ja	doc_737963622253_item	2833070	et	3	main
puhkama	doc_737963622253_item	2833071	et	3	main
ei	doc_737963622253_item	2833072	et	4	main
telefon	doc_737963622253_item	2833075	et	3	main
tänapäev	doc_737963622253_item	2833077	et	3	main
tänapäeval	doc_737963622253_item	2833090	et	3	main
nii	doc_737963622253_item	2833092	et	3	main
abil	doc_737963622253_item	2833097	et	4	main
6	doc_737963622253_item	2833103	et	2	main
kuid	doc_737963622253_item	2833104	et	4	main
telefonihelin	doc_737963622253_item	2833105	et	3	main
lõunasöök	doc_737963622253_item	2833112	et	3	main
huvitav	doc_737963622253_item	2833117	et	4	main
huvitava	doc_737963622253_item	2833121	et	4	main
varahommikul	doc_737963622253_item	2833133	et	3	main
olevad	doc_737963622253_item	2833138	et	4	main
pean	doc_737963622253_item	2833144	et	4	main
väga	doc_737963622253_item	2833145	et	3	main
lugu	doc_737963622253_item	2833146	et	4	main
sest	doc_737963622253_item	2833151	et	4	main
nad	doc_737963622253_item	2833152	et	3	main
tunned	doc_737963622253_item	2833175	et	3	main
ainult	doc_737963622253_item	2833177	et	4	main
difteeria	doc_737963622253_item	2833193	et	4	main
peab	doc_737963622253_item	2833227	et	4	main
ma	doc_737963622253_item	2833232	et	3	main
sobivate	doc_737963622253_item	2833242	et	4	main
1	doc_737963622253_item	2833244	et	2	main
tellisime	doc_737963622253_item	2833245	et	4	main
kolmekäigulise	doc_737963622253_item	2833246	et	4	main
õpetajad	doc_737963622253_item	2833259	et	4	main
vanemad	doc_737963622253_item	2833265	et	4	main
4	doc_737963622253_item	2833268	et	2	main
kostis	doc_737963622253_item	2833270	et	4	main
ei	doc_737963622253_item	2833280	et	4	main
hoopis	doc_737963622253_item	2833285	et	3	main
lähete	doc_737963622253_item	2833291	et	4	main
7	doc_737963622253_item	2833293	et	2	main
suitsetada	doc_737963622253_item	2833298	et	3	main
8	doc_737963622253_item	2833302	et	2	main
tulemust	doc_737963622253_item	2833308	et	4	main
või	doc_737963622253_item	2833316	et	4	main
10	doc_737963622253_item	2833319	et	2	main
meie	doc_737963622253_item	2833040	et	4	main
teeb	doc_737963622253_item	2833027	et	3	main
naisi	doc_737963622253_item	2833028	et	3	main
naiselikumaks	doc_737963622253_item	2833029	et	4	main
mehi	doc_737963622253_item	2833030	et	3	main
stress	doc_737963622253_item	2833038	et	3	main
panema	doc_737963622253_item	2833039	et	3	main
tegutsema	doc_737963622253_item	2833041	et	3	main
aga	doc_737963622253_item	2833042	et	3	main
lisakoormus	doc_737963622253_item	2833043	et	3	main
võima	doc_737963622253_item	2833044	et	3	main
tooma	doc_737963622253_item	2833045	et	3	main
saama	doc_737963622253_item	2833067	et	4	main
maandama	doc_737963622253_item	2833068	et	3	main
5	doc_737963622253_item	2833074	et	2	main
lausa	doc_737963622253_item	2833085	et	4	main
elama	doc_737963622253_item	2833086	et	3	main
ja	doc_737963622253_item	2833087	et	3	main
hingama	doc_737963622253_item	2833088	et	3	main
telefon	doc_737963622253_item	2833089	et	3	main
aparaat	doc_737963622253_item	2833094	et	3	main
selle	doc_737963622253_item	2833096	et	4	main
saab	doc_737963622253_item	2833098	et	3	main
lausa	doc_737963622253_item	2833099	et	4	main
elama	doc_737963622253_item	2833100	et	3	main
ja	doc_737963622253_item	2833101	et	3	main
hingama	doc_737963622253_item	2833102	et	3	main
varahommik	doc_737963622253_item	2833109	et	3	main
segama	doc_737963622253_item	2833111	et	3	main
aeg	doc_737963622253_item	2833120	et	3	main
vaatamine	doc_737963622253_item	2833123	et	4	main
lõunasöögi	doc_737963622253_item	2833125	et	3	main
pange	doc_737963622253_item	2833136	et	4	main
oma	doc_737963622253_item	2833149	et	4	main
kõiki	doc_737963622253_item	2833155	et	4	main
igaühe	doc_737963622253_item	2833159	et	4	main
et	doc_737963622253_item	2833168	et	3	main
sa	doc_737963622253_item	2833174	et	3	main
4	doc_737963622253_item	2833188	et	2	main
praegu	doc_737963622253_item	2833189	et	3	main
on	doc_737963622253_item	2833190	et	4	main
oht	doc_737963622253_item	2833191	et	3	main
haigestuda	doc_737963622253_item	2833192	et	3	main
kleepus	doc_737963622253_item	2833221	et	3	main
pükstel	doc_737963622253_item	2833223	et	3	main
külmal	doc_737963622253_item	2833225	et	3	main
külmetamine	doc_737963622253_item	2833229	et	4	main
külmetamisest	doc_737963622253_item	2833230	et	4	main
10	doc_737963622253_item	2833231	et	2	main
rõõmu	doc_737963622253_item	2833234	et	4	main
päike	doc_737963622253_item	2833236	et	3	main
suvisest	doc_737963622253_item	2833237	et	4	main
päikesest	doc_737963622253_item	2833238	et	4	main
see	doc_737963622253_item	2833249	et	3	main
maksis	doc_737963622253_item	2833250	et	4	main
2	doc_737963622253_item	2833252	et	2	main
3	doc_737963622253_item	2833260	et	2	main
paluti	doc_737963622253_item	2833262	et	3	main
kõrvallauast	doc_737963622253_item	2833269	et	4	main
ta	doc_737963622253_item	2833279	et	4	main
trenni	doc_737963622253_item	2833282	et	4	main
alkoholi	doc_737963622253_item	2833300	et	4	main
tarbida	doc_737963622253_item	2833301	et	3	main
töötasid	doc_737963622253_item	2833304	et	4	main
küll	doc_737963622253_item	2833305	et	4	main
pingsalt	doc_737963622253_item	2833306	et	4	main
aga	doc_737963622253_item	2833307	et	3	main
sõidad	doc_737963622253_item	2833314	et	3	main
ukse	doc_737963622253_item	2833321	et	3	main
sulgudes	doc_737963622254_item	2833328	et	4	main
toomet	doc_737963622254_item	2833334	et	4	main
on	doc_737963622254_item	2833335	et	4	main
naine	doc_737963622254_item	2833337	et	3	main
ta	doc_737963622254_item	2833341	et	4	main
kuulutus	doc_737963622254_item	2833343	et	4	main
kuulutuse	doc_737963622254_item	2833344	et	4	main
nädala	doc_737963622254_item	2833364	et	3	main
väikestele	doc_737963622254_item	2833365	et	4	main
eestlastele	doc_737963622254_item	2833366	et	4	main
need	doc_737963622254_item	2833367	et	3	main
oodatud	doc_737963622254_item	2833381	et	4	main
olin	doc_737963622254_item	2833382	et	3	main
parases	doc_737963622253_item	2833049	et	4	main
stres	doc_737963622253_item	2833055	et	4	main
tagajärgi	doc_737963622253_item	2833059	et	4	main
ei	doc_737963622253_item	2833061	et	4	main
tohtima	doc_737963622253_item	2833062	et	3	main
laskma	doc_737963622253_item	2833063	et	3	main
ülekoormus	doc_737963622253_item	2833064	et	3	main
tekkima	doc_737963622253_item	2833065	et	3	main
et	doc_737963622253_item	2833095	et	3	main
pühapäev	doc_737963622253_item	2833108	et	3	main
ja	doc_737963622253_item	2833114	et	3	main
kuid	doc_737963622253_item	2833129	et	4	main
telefonihelin	doc_737963622253_item	2833130	et	3	main
katkestab	doc_737963622253_item	2833131	et	3	main
pühapäeval	doc_737963622253_item	2833132	et	3	main
õigesse	doc_737963622253_item	2833140	et	3	main
vormi	doc_737963622253_item	2833141	et	4	main
vanemad	doc_737963622253_item	2833148	et	4	main
kõik	doc_737963622253_item	2833154	et	4	main
igaüks	doc_737963622253_item	2833158	et	3	main
2	doc_737963622253_item	2833160	et	2	main
artikli	doc_737963622253_item	2833162	et	3	main
ma	doc_737963622253_item	2833166	et	3	main
arvasin	doc_737963622253_item	2833167	et	3	main
huvitud	doc_737963622253_item	2833170	et	4	main
huvi	doc_737963622253_item	2833176	et	4	main
ilusad	doc_737963622253_item	2833178	et	3	main
naised	doc_737963622253_item	2833179	et	3	main
ja	doc_737963622253_item	2833180	et	3	main
kiired	doc_737963622253_item	2833181	et	4	main
autod	doc_737963622253_item	2833182	et	3	main
ilusate	doc_737963622253_item	2833183	et	3	main
naistele	doc_737963622253_item	2833184	et	3	main
ja	doc_737963622253_item	2833185	et	3	main
hoiduma	doc_737963622253_item	2833228	et	3	main
tunnen	doc_737963622253_item	2833233	et	3	main
suvine	doc_737963622253_item	2833235	et	4	main
sidenditega	doc_737963622253_item	2833243	et	3	main
olid	doc_737963622253_item	2833254	et	4	main
nii	doc_737963622253_item	2833255	et	3	main
õpilased	doc_737963622253_item	2833256	et	3	main
kui	doc_737963622253_item	2833257	et	3	main
ka	doc_737963622253_item	2833258	et	3	main
anekdooti	doc_737963622253_item	2833276	et	4	main
tule	doc_737963622253_item	2833281	et	4	main
6	doc_737963622253_item	2833287	et	2	main
siis	doc_737963622253_item	2833290	et	3	main
jalutama	doc_737963622253_item	2833292	et	3	main
selles	doc_737963622253_item	2833294	et	4	main
baaris	doc_737963622253_item	2833295	et	3	main
ei	doc_737963622253_item	2833296	et	4	main
ei	doc_737963622253_item	2833309	et	4	main
koputust	doc_737963622253_item	2833324	et	4	main
i	doc_737963622254_item	2833326	et	4	main
pange	doc_737963622254_item	2833327	et	4	main
piret	doc_737963622254_item	2833333	et	4	main
suvel	doc_737963622254_item	2833338	et	3	main
ajalehes	doc_737963622254_item	2833342	et	3	main
ja	doc_737963622254_item	2833358	et	3	main
juba	doc_737963622254_item	2833361	et	3	main
üle	doc_737963622254_item	2833362	et	3	main
õpetanud	doc_737963622254_item	2833371	et	4	main
tulema	doc_737963622254_item	2833388	et	4	main
audiga	doc_737963622254_item	2833393	et	3	main
kasva	doc_737963622254_item	2833407	et	4	main
rohi	doc_737963622254_item	2833408	et	4	main
kui	doc_737963622254_item	2833409	et	3	main
noor	doc_737963622254_item	2833410	et	3	main
ja	doc_737963622254_item	2833411	et	3	main
tahtmine	doc_737963622254_item	2833412	et	4	main
piret	doc_737963622254_item	2833415	et	4	main
pärast	doc_737963622254_item	2833416	et	4	main
õppeaasta	doc_737963622254_item	2833417	et	4	main
algama	doc_737963622254_item	2833425	et	3	main
siin	doc_737963622254_item	2833434	et	4	main
sügisel	doc_737963622254_item	2833435	et	3	main
kõige	doc_737963622254_item	2833436	et	4	main
ja	doc_737963622254_item	2833456	et	3	main
mahlakalt	doc_737963622254_item	2833460	et	4	main
mitte	doc_737963622254_item	2833461	et	3	main
aktsent	doc_737963622254_item	2833463	et	3	main
aktsendiga	doc_737963622254_item	2833464	et	3	main
võib	doc_737963622253_item	2833056	et	3	main
4	doc_737963622253_item	2833060	et	2	main
pinge	doc_737963622253_item	2833066	et	4	main
tea	doc_737963622253_item	2833073	et	4	main
olema	doc_737963622253_item	2833076	et	4	main
on	doc_737963622253_item	2833091	et	4	main
ka	doc_737963622253_item	2833107	et	3	main
valmistamine	doc_737963622253_item	2833113	et	4	main
söömine	doc_737963622253_item	2833115	et	4	main
see	doc_737963622253_item	2833083	et	3	main
abil	doc_737963622253_item	2833084	et	4	main
magiline	doc_737963622253_item	2833093	et	4	main
katkestama	doc_737963622253_item	2833106	et	3	main
uni	doc_737963622253_item	2833110	et	3	main
pahandab	doc_737963622253_item	2833116	et	3	main
telesaade	doc_737963622253_item	2833118	et	4	main
vaatamine	doc_737963622253_item	2833119	et	4	main
telesaate	doc_737963622253_item	2833122	et	3	main
segab	doc_737963622253_item	2833124	et	3	main
valmistamist	doc_737963622253_item	2833126	et	4	main
ja	doc_737963622253_item	2833127	et	3	main
söömist	doc_737963622253_item	2833128	et	4	main
sõnad	doc_737963622253_item	2833139	et	4	main
1	doc_737963622253_item	2833142	et	2	main
oma	doc_737963622253_item	2833147	et	4	main
aitavad	doc_737963622253_item	2833153	et	4	main
usaldavad	doc_737963622253_item	2833157	et	4	main
kohandasin	doc_737963622253_item	2833161	et	3	main
nõudeid	doc_737963622253_item	2833164	et	3	main
sa	doc_737963622253_item	2833169	et	3	main
sport	doc_737963622253_item	2833171	et	3	main
sporti	doc_737963622253_item	2833172	et	4	main
aga	doc_737963622253_item	2833173	et	3	main
9	doc_737963622253_item	2833224	et	2	main
ajal	doc_737963622253_item	2833226	et	4	main
kuid	doc_737963622253_item	2833248	et	4	main
palju	doc_737963622253_item	2833251	et	4	main
kohal	doc_737963622253_item	2833253	et	4	main
tagasi	doc_737963622253_item	2833266	et	3	main
rääkinud	doc_737963622253_item	2833277	et	4	main
5	doc_737963622253_item	2833278	et	2	main
sest	doc_737963622253_item	2833283	et	4	main
teatrisse	doc_737963622253_item	2833286	et	3	main
töö	doc_737963622253_item	2833289	et	4	main
ning	doc_737963622253_item	2833299	et	3	main
olnud	doc_737963622253_item	2833310	et	4	main
9	doc_737963622253_item	2833311	et	2	main
kas	doc_737963622253_item	2833312	et	3	main
sa	doc_737963622253_item	2833313	et	3	main
jääd	doc_737963622253_item	2833317	et	4	main
kuulsin	doc_737963622253_item	2833323	et	3	main
olevad	doc_737963622254_item	2833329	et	4	main
sõnad	doc_737963622254_item	2833330	et	4	main
õigesse	doc_737963622254_item	2833331	et	3	main
ettevõtlik	doc_737963622254_item	2833336	et	3	main
ülem-suetuki	doc_737963622254_item	2833347	et	4	main
küla	doc_737963622254_item	2833348	et	4	main
külasse	doc_737963622254_item	2833349	et	3	main
nüüd	doc_737963622254_item	2833360	et	4	main
nädal	doc_737963622254_item	2833363	et	3	main
pireti	doc_737963622254_item	2833372	et	4	main
kinnitusel	doc_737963622254_item	2833373	et	4	main
tundis	doc_737963622254_item	2833374	et	3	main
üsna	doc_737963622254_item	2833383	et	3	main
üllatuma	doc_737963622254_item	2833384	et	3	main
üllatunud	doc_737963622254_item	2833385	et	4	main
kui	doc_737963622254_item	2833386	et	3	main
korralik	doc_737963622254_item	2833391	et	3	main
siber	doc_737963622254_item	2833396	et	4	main
lenda	doc_737963622254_item	2833404	et	4	main
lind	doc_737963622254_item	2833405	et	3	main
ega	doc_737963622254_item	2833406	et	3	main
täis	doc_737963622254_item	2833414	et	4	main
kool	doc_737963622254_item	2833423	et	4	main
alganud	doc_737963622254_item	2833426	et	4	main
küla	doc_737963622254_item	2833428	et	4	main
võtma	doc_737963622254_item	2833429	et	3	main
võttis	doc_737963622254_item	2833430	et	3	main
kartuleid	doc_737963622254_item	2833431	et	3	main
kartulivõtt	doc_737963622254_item	2833432	et	3	main
on	doc_737963622254_item	2833433	et	4	main
tähtsam	doc_737963622254_item	2833438	et	4	main
ettevõtmine	doc_737963622254_item	2833439	et	3	main
tänaseks	doc_737963622254_item	2833440	et	4	main
mahlakas	doc_737963622254_item	2833457	et	4	main
kool	doc_737963622254_item	2833470	et	4	main
venemaa	doc_737963622254_item	2833473	et	4	main
ja	doc_737963622254_item	2833475	et	3	main
aine	doc_737963622254_item	2833477	et	4	main
ained	doc_737963622254_item	2833478	et	3	main
und	doc_737963622253_item	2833134	et	4	main
iv	doc_737963622253_item	2833135	et	4	main
sulgudes	doc_737963622253_item	2833137	et	4	main
ma	doc_737963622253_item	2833143	et	3	main
vanematest	doc_737963622253_item	2833150	et	4	main
ja	doc_737963622253_item	2833156	et	3	main
nõuded	doc_737963622253_item	2833163	et	3	main
3	doc_737963622253_item	2833165	et	2	main
kiirde	doc_737963622253_item	2833186	et	4	main
autodele	doc_737963622253_item	2833187	et	3	main
difteeriaga	doc_737963622253_item	2833194	et	3	main
5	doc_737963622253_item	2833195	et	2	main
tüdinesin	doc_737963622253_item	2833196	et	3	main
uus	doc_737963622253_item	2833197	et	3	main
uuel	doc_737963622253_item	2833199	et	3	main
töökoht	doc_737963622253_item	2833198	et	3	main
töökohal	doc_737963622253_item	2833200	et	4	main
kiiresti	doc_737963622253_item	2833201	et	3	main
6	doc_737963622253_item	2833202	et	2	main
piirdusime	doc_737963622253_item	2833203	et	3	main
selles	doc_737963622253_item	2833204	et	4	main
küsimuses	doc_737963622253_item	2833205	et	4	main
vaid	doc_737963622253_item	2833206	et	3	main
väikesed	doc_737963622253_item	2833207	et	4	main
muudatused	doc_737963622253_item	2833208	et	3	main
väikestel	doc_737963622253_item	2833209	et	4	main
muudatustel	doc_737963622253_item	2833210	et	3	main
7	doc_737963622253_item	2833211	et	2	main
see	doc_737963622253_item	2833212	et	3	main
küsimus	doc_737963622253_item	2833213	et	4	main
kuulub	doc_737963622253_item	2833214	et	3	main
teine	doc_737963622253_item	2833215	et	3	main
valdkond	doc_737963622253_item	2833216	et	3	main
teise	doc_737963622253_item	2833217	et	4	main
valdkonda	doc_737963622253_item	2833218	et	4	main
8	doc_737963622253_item	2833219	et	2	main
närimiskumm	doc_737963622253_item	2833220	et	3	main
püksid	doc_737963622253_item	2833222	et	3	main
v	doc_737963622253_item	2833239	et	4	main
täitke	doc_737963622253_item	2833240	et	3	main
lüngad	doc_737963622253_item	2833241	et	3	main
lõuna	doc_737963622253_item	2833247	et	4	main
lapsel	doc_737963622253_item	2833261	et	4	main
oodata	doc_737963622253_item	2833263	et	4	main
kuna	doc_737963622253_item	2833264	et	3	main
tulevad	doc_737963622253_item	2833267	et	4	main
naeru	doc_737963622253_item	2833271	et	4	main
nagu	doc_737963622253_item	2833272	et	3	main
oleks	doc_737963622253_item	2833273	et	3	main
keegi	doc_737963622253_item	2833274	et	4	main
just	doc_737963622253_item	2833275	et	3	main
läheb	doc_737963622253_item	2833284	et	3	main
lõpetage	doc_737963622253_item	2833288	et	3	main
tohi	doc_737963622253_item	2833297	et	4	main
nad	doc_737963622253_item	2833303	et	3	main
maale	doc_737963622253_item	2833315	et	4	main
linna	doc_737963622253_item	2833318	et	4	main
avasin	doc_737963622253_item	2833320	et	3	main
kui	doc_737963622253_item	2833322	et	3	main
nägi	doc_737963622254_item	2833340	et	3	main
et	doc_737963622254_item	2833345	et	3	main
siberisse	doc_737963622254_item	2833346	et	4	main
konkurssi	doc_737963622254_item	2833357	et	4	main
nende	doc_737963622254_item	2833368	et	4	main
ta	doc_737963622254_item	2833375	et	4	main
mulle	doc_737963622254_item	2833387	et	4	main
korraliku	doc_737963622254_item	2833392	et	3	main
mulle	doc_737963622254_item	2833394	et	4	main
siberist	doc_737963622254_item	2833397	et	4	main
algust	doc_737963622254_item	2833418	et	4	main
koht	doc_737963622254_item	2833419	et	3	main
polnud	doc_737963622254_item	2833422	et	3	main
kogu	doc_737963622254_item	2833427	et	4	main
kuidagi	doc_737963622254_item	2833453	et	3	main
on	doc_737963622254_item	2833471	et	4	main
lapsed	doc_737963622254_item	2833498	et	3	main
soe	doc_737963622254_item	2833523	et	4	main
kuid	doc_737963622254_item	2833525	et	4	main
ööd	doc_737963622254_item	2833526	et	4	main
juba	doc_737963622254_item	2833527	et	3	main
jahe	doc_737963622254_item	2833528	et	3	main
jahedad	doc_737963622254_item	2833529	et	3	main
vene	doc_737963622254_item	2833533	et	4	main
kütmine	doc_737963622254_item	2833535	et	4	main
ostan	doc_737963622254_item	2833539	et	3	main
iii	doc_737963622254_item	2833558	et	4	main
moodustage	doc_737963622254_item	2833559	et	3	main
kasutades	doc_737963622254_item	2833568	et	3	main
2	doc_737963622254_item	2833570	et	2	main
tegema	doc_737963622254_item	2833572	et	3	main
mehelikum	doc_737963622254_item	2833577	et	4	main
kogus	doc_737963622254_item	2833591	et	4	main
stress	doc_737963622254_item	2833592	et	3	main
ei	doc_737963622254_item	2833626	et	4	main
saamisel	doc_737963622254_item	2833632	et	4	main
maanduge	doc_737963622254_item	2833633	et	3	main
olema	doc_737963622254_item	2833639	et	4	main
tänapäev	doc_737963622254_item	2833640	et	3	main
nii	doc_737963622254_item	2833642	et	3	main
aparaat	doc_737963622254_item	2833644	et	3	main
et	doc_737963622254_item	2833645	et	3	main
nii	doc_737963622254_item	2833655	et	3	main
saa	doc_737963622254_item	2833663	et	4	main
elada	doc_737963622254_item	2833664	et	3	main
ja	doc_737963622254_item	2833665	et	3	main
ja	doc_737963622254_item	2833678	et	3	main
segab	doc_737963622254_item	2833692	et	3	main
olevad	doc_737963622254_item	2833702	et	4	main
oma	doc_737963622254_item	2833711	et	4	main
2	doc_737963622254_item	2833724	et	2	main
kiired	doc_737963622254_item	2833744	et	4	main
4	doc_737963622254_item	2833751	et	2	main
on	doc_737963622254_item	2833753	et	4	main
difteeria	doc_737963622254_item	2833756	et	4	main
peab	doc_737963622254_item	2833790	et	4	main
hoiduma	doc_737963622254_item	2833791	et	3	main
tunnen	doc_737963622254_item	2833796	et	3	main
suvise	doc_737963622254_item	2833800	et	4	main
eksamitöö	doc_737963622254_item	2833325	et	4	main
vormi	doc_737963622254_item	2833332	et	4	main
nägema	doc_737963622254_item	2833339	et	3	main
otsitakse	doc_737963622254_item	2833350	et	3	main
eesti	doc_737963622254_item	2833351	et	4	main
keele	doc_737963622254_item	2833352	et	4	main
õpetajat	doc_737963622254_item	2833353	et	4	main
piret	doc_737963622254_item	2833354	et	4	main
võitis	doc_737963622254_item	2833355	et	3	main
konkurss	doc_737963622254_item	2833356	et	3	main
on	doc_737963622254_item	2833359	et	4	main
emakeelt	doc_737963622254_item	2833369	et	4	main
õpetama	doc_737963622254_item	2833370	et	3	main
siberisse	doc_737963622254_item	2833376	et	4	main
jõudma	doc_737963622254_item	2833377	et	3	main
jõudes	doc_737963622254_item	2833378	et	3	main
et	doc_737963622254_item	2833379	et	3	main
on	doc_737963622254_item	2833380	et	4	main
tulid	doc_737963622254_item	2833389	et	4	main
pilt	doc_737963622254_item	2833399	et	3	main
et	doc_737963622254_item	2833400	et	3	main
seal	doc_737963622254_item	2833401	et	4	main
ei	doc_737963622254_item	2833402	et	4	main
lendama	doc_737963622254_item	2833403	et	3	main
tahtmist	doc_737963622254_item	2833413	et	4	main
jõudis	doc_737963622254_item	2833421	et	3	main
on	doc_737963622254_item	2833441	et	4	main
kartul	doc_737963622254_item	2833442	et	3	main
õppimine	doc_737963622254_item	2833445	et	4	main
käib	doc_737963622254_item	2833446	et	3	main
täie	doc_737963622254_item	2833447	et	3	main
hoog	doc_737963622254_item	2833448	et	3	main
hooga	doc_737963622254_item	2833449	et	3	main
siinsed	doc_737963622254_item	2833450	et	3	main
eestlased	doc_737963622254_item	2833451	et	3	main
räägivad	doc_737963622254_item	2833452	et	3	main
mõnus	doc_737963622254_item	2833455	et	4	main
mõnusalt	doc_737963622254_item	2833458	et	4	main
vene	doc_737963622254_item	2833462	et	4	main
mõni	doc_737963622254_item	2833467	et	3	main
mõni	doc_737963622254_item	2833468	et	3	main
murret	doc_737963622254_item	2833469	et	4	main
kool	doc_737963622254_item	2833474	et	4	main
ülejäänud	doc_737963622254_item	2833476	et	4	main
pireti	doc_737963622254_item	2833495	et	4	main
juba	doc_737963622254_item	2833531	et	3	main
muud	doc_737963622254_item	2833546	et	4	main
piret	doc_737963622254_item	2833553	et	4	main
lühendatud	doc_737963622254_item	2833555	et	4	main
ajalehest	doc_737963622254_item	2833556	et	4	main
sõnad	doc_737963622254_item	2833564	et	4	main
naised	doc_737963622254_item	2833573	et	3	main
mehed	doc_737963622254_item	2833576	et	3	main
kaunim	doc_737963622254_item	2833579	et	4	main
naisi	doc_737963622254_item	2833582	et	3	main
naiselikumaks	doc_737963622254_item	2833583	et	4	main
ja	doc_737963622254_item	2833584	et	3	main
mehi	doc_737963622254_item	2833585	et	3	main
vastu	doc_737963622254_item	2833390	et	3	main
maaliti	doc_737963622254_item	2833395	et	3	main
selline	doc_737963622254_item	2833398	et	4	main
kohale	doc_737963622254_item	2833420	et	4	main
veel	doc_737963622254_item	2833424	et	4	main
tähtis	doc_737963622254_item	2833437	et	4	main
salv	doc_737963622254_item	2833443	et	3	main
ja	doc_737963622254_item	2833444	et	3	main
teistmoodi	doc_737963622254_item	2833454	et	3	main
ja	doc_737963622254_item	2833459	et	3	main
keeles	doc_737963622254_item	2833481	et	4	main
külas	doc_737963622254_item	2833482	et	3	main
elab	doc_737963622254_item	2833483	et	3	main
veidi	doc_737963622254_item	2833484	et	3	main
üle	doc_737963622254_item	2833485	et	3	main
kõikidega	doc_737963622254_item	2833493	et	4	main
rääkida	doc_737963622254_item	2833494	et	3	main
poolpõlenud	doc_737963622254_item	2833499	et	4	main
raamatud	doc_737963622254_item	2833500	et	4	main
raamatutega	doc_737963622254_item	2833501	et	3	main
varsti	doc_737963622254_item	2833502	et	3	main
saatma	doc_737963622254_item	2833503	et	3	main
saadavad	doc_737963622254_item	2833504	et	4	main
eestist	doc_737963622254_item	2833505	et	3	main
uued	doc_737963622254_item	2833506	et	3	main
õpikud	doc_737963622254_item	2833507	et	3	main
siberi	doc_737963622254_item	2833508	et	4	main
talve	doc_737963622254_item	2833509	et	4	main
piret	doc_737963622254_item	2833510	et	4	main
ei	doc_737963622254_item	2833511	et	4	main
kartma	doc_737963622254_item	2833512	et	3	main
kartnud	doc_737963622254_item	2833513	et	4	main
mulle	doc_737963622254_item	2833514	et	4	main
juba	doc_737963622254_item	2833515	et	3	main
tooma	doc_737963622254_item	2833516	et	3	main
toodi	doc_737963622254_item	2833517	et	4	main
talvepuud	doc_737963622254_item	2833518	et	4	main
praegu	doc_737963622254_item	2833519	et	3	main
on	doc_737963622254_item	2833520	et	4	main
harjutan	doc_737963622254_item	2833530	et	3	main
kui	doc_737963622254_item	2833537	et	3	main
külapood	doc_737963622254_item	2833540	et	3	main
vildid	doc_737963622254_item	2833542	et	4	main
seal	doc_737963622254_item	2833544	et	4	main
suurt	doc_737963622254_item	2833545	et	3	main
valmistumas	doc_737963622254_item	2833552	et	3	main
etteantud	doc_737963622254_item	2833560	et	4	main
pannes	doc_737963622254_item	2833563	et	4	main
ja	doc_737963622254_item	2833567	et	3	main
naeratus	doc_737963622254_item	2833571	et	4	main
mehelikumaks	doc_737963622254_item	2833586	et	4	main
igatühte	doc_737963622254_item	2833587	et	3	main
kaunimaks	doc_737963622254_item	2833588	et	4	main
3	doc_737963622254_item	2833589	et	2	main
paras	doc_737963622254_item	2833590	et	3	main
maandama	doc_737963622254_item	2833622	et	3	main
ja	doc_737963622254_item	2833624	et	3	main
puhkama	doc_737963622254_item	2833625	et	3	main
tohi	doc_737963622254_item	2833627	et	4	main
sportima	doc_737963622254_item	2833634	et	4	main
ja	doc_737963622254_item	2833635	et	3	main
puhkama	doc_737963622254_item	2833636	et	3	main
maagiline	doc_737963622254_item	2833643	et	4	main
vaid	doc_737963622254_item	2833465	et	3	main
nagu	doc_737963622254_item	2833466	et	3	main
siiski	doc_737963622254_item	2833472	et	4	main
kolmsada	doc_737963622254_item	2833486	et	4	main
kolmesaja	doc_737963622254_item	2833487	et	4	main
inimene	doc_737963622254_item	2833488	et	3	main
inimest	doc_737963622254_item	2833489	et	3	main
sõnul	doc_737963622254_item	2833496	et	3	main
õpetatakse	doc_737963622254_item	2833479	et	3	main
vene	doc_737963622254_item	2833480	et	4	main
emakeelt	doc_737963622254_item	2833490	et	4	main
saab	doc_737963622254_item	2833491	et	3	main
kõik	doc_737963622254_item	2833492	et	4	main
õpivad	doc_737963622254_item	2833497	et	3	main
päevad	doc_737963622254_item	2833521	et	3	main
suure	doc_737963622254_item	2833532	et	3	main
ahju	doc_737963622254_item	2833534	et	4	main
kütmisega	doc_737963622254_item	2833536	et	4	main
vaja	doc_737963622254_item	2833538	et	4	main
külapoest	doc_737963622254_item	2833541	et	4	main
ega	doc_737963622254_item	2833543	et	3	main
valmistuma	doc_737963622254_item	2833551	et	3	main
vapralt	doc_737963622254_item	2833554	et	4	main
sõnadest	doc_737963622254_item	2833561	et	3	main
laused	doc_737963622254_item	2833562	et	3	main
vormi	doc_737963622254_item	2833566	et	4	main
naiselikum	doc_737963622254_item	2833574	et	4	main
ja	doc_737963622254_item	2833575	et	3	main
sportima	doc_737963622254_item	2833623	et	4	main
pinge	doc_737963622254_item	2833631	et	4	main
telefon	doc_737963622254_item	2833638	et	3	main
saama	doc_737963622254_item	2833641	et	4	main
tänapäeval	doc_737963622254_item	2833654	et	3	main
lõunasöök	doc_737963622254_item	2833676	et	3	main
und	doc_737963622254_item	2833688	et	4	main
pühapäeval	doc_737963622254_item	2833690	et	3	main
lõunasoogi	doc_737963622254_item	2833693	et	4	main
valmistamisel	doc_737963622254_item	2833694	et	4	main
ja	doc_737963622254_item	2833695	et	3	main
sõnad	doc_737963622254_item	2833703	et	4	main
vormi	doc_737963622254_item	2833705	et	4	main
oma	doc_737963622254_item	2833713	et	4	main
aitavad	doc_737963622254_item	2833717	et	4	main
kõike	doc_737963622254_item	2833719	et	4	main
ja	doc_737963622254_item	2833720	et	3	main
veel	doc_737963622254_item	2833522	et	4	main
soojad	doc_737963622254_item	2833524	et	3	main
ei	doc_737963622254_item	2833547	et	4	main
müüdagi	doc_737963622254_item	2833548	et	3	main
naerab	doc_737963622254_item	2833549	et	3	main
talveks	doc_737963622254_item	2833550	et	4	main
slõhtuleht	doc_737963622254_item	2833557	et	4	main
õigesse	doc_737963622254_item	2833565	et	3	main
kirjavahemärke	doc_737963622254_item	2833569	et	4	main
igaüks	doc_737963622254_item	2833578	et	3	main
naeratus	doc_737963622254_item	2833580	et	4	main
teeb	doc_737963622254_item	2833581	et	3	main
panema	doc_737963622254_item	2833593	et	3	main
meie	doc_737963622254_item	2833594	et	4	main
tegutsema	doc_737963622254_item	2833595	et	3	main
aga	doc_737963622254_item	2833596	et	3	main
lisakoormus	doc_737963622254_item	2833597	et	3	main
võima	doc_737963622254_item	2833598	et	3	main
tooma	doc_737963622254_item	2833599	et	3	main
soovimatu	doc_737963622254_item	2833600	et	4	main
tagajärg	doc_737963622254_item	2833601	et	3	main
parajasti	doc_737963622254_item	2833602	et	3	main
kogutud	doc_737963622254_item	2833603	et	4	main
stress	doc_737963622254_item	2833604	et	3	main
paneb	doc_737963622254_item	2833605	et	3	main
meid	doc_737963622254_item	2833606	et	4	main
tegutsema	doc_737963622254_item	2833607	et	3	main
aga	doc_737963622254_item	2833608	et	3	main
lisakoormus	doc_737963622254_item	2833609	et	3	main
võib	doc_737963622254_item	2833610	et	3	main
tuua	doc_737963622254_item	2833611	et	3	main
soovimatuid	doc_737963622254_item	2833612	et	4	main
tagajargi	doc_737963622254_item	2833613	et	4	main
4	doc_737963622254_item	2833614	et	2	main
ei	doc_737963622254_item	2833615	et	4	main
tohtima	doc_737963622254_item	2833616	et	3	main
laskma	doc_737963622254_item	2833617	et	3	main
ülekoormus	doc_737963622254_item	2833618	et	3	main
tekkima	doc_737963622254_item	2833619	et	3	main
pinge	doc_737963622254_item	2833620	et	4	main
saama	doc_737963622254_item	2833621	et	4	main
5	doc_737963622254_item	2833637	et	2	main
on	doc_737963622254_item	2833653	et	4	main
segama	doc_737963622254_item	2833675	et	3	main
söömine	doc_737963622254_item	2833679	et	4	main
huvitav	doc_737963622254_item	2833681	et	4	main
ka	doc_737963622254_item	2833689	et	3	main
varahommikul	doc_737963622254_item	2833691	et	3	main
telesaade	doc_737963622254_item	2833697	et	4	main
vanemad	doc_737963622254_item	2833712	et	4	main
sest	doc_737963622254_item	2833715	et	4	main
kõik	doc_737963622254_item	2833718	et	4	main
usaldavad	doc_737963622254_item	2833721	et	4	main
artikli	doc_737963622254_item	2833726	et	3	main
lasta	doc_737963622254_item	2833628	et	4	main
ülekoormuse	doc_737963622254_item	2833629	et	3	main
tekkimist	doc_737963622254_item	2833630	et	4	main
abil	doc_737963622254_item	2833647	et	4	main
lausa	doc_737963622254_item	2833648	et	4	main
elama	doc_737963622254_item	2833649	et	3	main
ja	doc_737963622254_item	2833650	et	3	main
hingama	doc_737963622254_item	2833651	et	3	main
telefon	doc_737963622254_item	2833652	et	3	main
maagiline	doc_737963622254_item	2833656	et	4	main
aparaat	doc_737963622254_item	2833657	et	3	main
et	doc_737963622254_item	2833658	et	3	main
selle	doc_737963622254_item	2833659	et	4	main
abil	doc_737963622254_item	2833660	et	4	main
lausa	doc_737963622254_item	2833661	et	4	main
ei	doc_737963622254_item	2833662	et	4	main
see	doc_737963622254_item	2833646	et	3	main
hingata	doc_737963622254_item	2833666	et	4	main
6	doc_737963622254_item	2833667	et	2	main
kuid	doc_737963622254_item	2833668	et	4	main
telefonihelin	doc_737963622254_item	2833669	et	3	main
katkestama	doc_737963622254_item	2833670	et	3	main
ka	doc_737963622254_item	2833671	et	3	main
pühapäev	doc_737963622254_item	2833672	et	3	main
varahommik	doc_737963622254_item	2833673	et	3	main
uni	doc_737963622254_item	2833674	et	3	main
valmistamine	doc_737963622254_item	2833677	et	4	main
pahandab	doc_737963622254_item	2833680	et	3	main
telesaade	doc_737963622254_item	2833682	et	4	main
vaatamine	doc_737963622254_item	2833683	et	4	main
aeg	doc_737963622254_item	2833684	et	3	main
lühendab	doc_737963622254_item	2833696	et	3	main
pange	doc_737963622254_item	2833700	et	4	main
sulgudes	doc_737963622254_item	2833701	et	4	main
pean	doc_737963622254_item	2833708	et	4	main
väga	doc_737963622254_item	2833709	et	3	main
lugu	doc_737963622254_item	2833710	et	4	main
nad	doc_737963622254_item	2833716	et	3	main
igaühte	doc_737963622254_item	2833723	et	4	main
huvitud	doc_737963622254_item	2833733	et	4	main
spordiga	doc_737963622254_item	2833735	et	3	main
sa	doc_737963622254_item	2833737	et	3	main
tunned	doc_737963622254_item	2833738	et	3	main
ilusate	doc_737963622254_item	2833746	et	3	main
autode	doc_737963622254_item	2833749	et	3	main
praegu	doc_737963622254_item	2833752	et	3	main
oht	doc_737963622254_item	2833754	et	3	main
haigestuda	doc_737963622254_item	2833755	et	3	main
difteeriaga	doc_737963622254_item	2833757	et	3	main
kiiresti	doc_737963622254_item	2833764	et	3	main
külmal	doc_737963622254_item	2833788	et	3	main
ajal	doc_737963622254_item	2833789	et	4	main
ma	doc_737963622254_item	2833795	et	3	main
sobivate	doc_737963622254_item	2833806	et	4	main
sidenditega	doc_737963622254_item	2833807	et	3	main
tellisime	doc_737963622254_item	2833809	et	4	main
kolmekäigulise	doc_737963622254_item	2833810	et	4	main
maksis	doc_737963622254_item	2833814	et	4	main
palju	doc_737963622254_item	2833815	et	4	main
kohal	doc_737963622254_item	2833817	et	4	main
olid	doc_737963622254_item	2833818	et	4	main
nii	doc_737963622254_item	2833819	et	3	main
õpilased	doc_737963622254_item	2833820	et	3	main
kui	doc_737963622254_item	2833821	et	3	main
kuid	doc_737963622254_item	2833685	et	4	main
telefonihelin	doc_737963622254_item	2833686	et	3	main
katkestab	doc_737963622254_item	2833687	et	3	main
vaatamiseaega	doc_737963622254_item	2833698	et	4	main
iv	doc_737963622254_item	2833699	et	4	main
õigesse	doc_737963622254_item	2833704	et	3	main
1	doc_737963622254_item	2833706	et	2	main
ma	doc_737963622254_item	2833707	et	3	main
vanematest	doc_737963622254_item	2833714	et	4	main
igaüks	doc_737963622254_item	2833722	et	3	main
3	doc_737963622254_item	2833728	et	2	main
et	doc_737963622254_item	2833731	et	3	main
naiste	doc_737963622254_item	2833747	et	3	main
vastu	doc_737963622254_item	2833750	et	3	main
tüdinesin	doc_737963622254_item	2833759	et	3	main
uue	doc_737963622254_item	2833762	et	3	main
valdkond	doc_737963622254_item	2833779	et	3	main
külmetamine	doc_737963622254_item	2833792	et	4	main
v	doc_737963622254_item	2833803	et	4	main
täitke	doc_737963622254_item	2833804	et	3	main
lüngad	doc_737963622254_item	2833805	et	3	main
aga	doc_737963622254_item	2833812	et	3	main
2	doc_737963622254_item	2833816	et	2	main
4	doc_737963622254_item	2833832	et	2	main
kõrvallauast	doc_737963622254_item	2833833	et	4	main
oleks	doc_737963622254_item	2833837	et	3	main
just	doc_737963622254_item	2833839	et	3	main
ja	doc_737963622254_item	2833853	et	3	main
pingsalt	doc_737963622254_item	2833871	et	4	main
kuulsin	doc_737963622254_item	2833888	et	3	main
sõnad	doc_737963622255_item	2833895	et	4	main
õigesse	doc_737963622255_item	2833896	et	3	main
piret	doc_737963622255_item	2833919	et	4	main
võitis	doc_737963622255_item	2833920	et	3	main
need	doc_737963622255_item	2833932	et	3	main
pireti	doc_737963622255_item	2833937	et	4	main
oodatud	doc_737963622255_item	2833946	et	4	main
olin	doc_737963622255_item	2833947	et	3	main
üsna	doc_737963622255_item	2833948	et	3	main
ei	doc_737963622255_item	2833967	et	4	main
lind	doc_737963622255_item	2833970	et	3	main
kui	doc_737963622255_item	2833974	et	3	main
ja	doc_737963622255_item	2833976	et	3	main
tahtmist	doc_737963622255_item	2833978	et	4	main
mitte	doc_737963622255_item	2834026	et	3	main
venemaa	doc_737963622255_item	2834038	et	4	main
ja	doc_737963622255_item	2834040	et	3	main
kolmsada	doc_737963622255_item	2834051	et	4	main
sõnul	doc_737963622255_item	2834061	et	3	main
soe	doc_737963622255_item	2834088	et	4	main
sojad	doc_737963622255_item	2834089	et	3	main
kuid	doc_737963622255_item	2834090	et	4	main
suure	doc_737963622255_item	2834097	et	3	main
seal	doc_737963622255_item	2834109	et	4	main
piret	doc_737963622255_item	2834118	et	4	main
etteantud	doc_737963622255_item	2834125	et	4	main
tegema	doc_737963622255_item	2834137	et	3	main
tagajärg	doc_737963622255_item	2834166	et	3	main
stress	doc_737963622255_item	2834169	et	3	main
meid	doc_737963622255_item	2834171	et	4	main
aga	doc_737963622255_item	2834173	et	3	main
tohtima	doc_737963622255_item	2834181	et	3	main
tänapäev	doc_737963622255_item	2834200	et	3	main
on	doc_737963622255_item	2834213	et	4	main
maagiliseks	doc_737963622255_item	2834217	et	4	main
et	doc_737963622255_item	2834219	et	3	main
ja	doc_737963622255_item	2834224	et	3	main
6	doc_737963622255_item	2834226	et	2	main
telefonihelin	doc_737963622255_item	2834228	et	3	main
varahommik	doc_737963622255_item	2834232	et	3	main
valmistamine	doc_737963622255_item	2834236	et	4	main
lõunasöögi	doc_737963622255_item	2834252	et	3	main
aega	doc_737963622255_item	2834260	et	4	main
iv	doc_737963622255_item	2834261	et	4	main
pange	doc_737963622255_item	2834262	et	4	main
ma	doc_737963622255_item	2834269	et	3	main
lugu	doc_737963622255_item	2834272	et	4	main
artikli	doc_737963622255_item	2834288	et	3	main
5	doc_737963622255_item	2834322	et	2	main
kuulub	doc_737963622255_item	2834341	et	3	main
teisele	doc_737963622255_item	2834344	et	4	main
valdkonnale	doc_737963622255_item	2834345	et	4	main
kohandasin	doc_737963622254_item	2833725	et	3	main
nõuded	doc_737963622254_item	2833727	et	3	main
arvasin	doc_737963622254_item	2833730	et	3	main
sa	doc_737963622254_item	2833732	et	3	main
sport	doc_737963622254_item	2833734	et	3	main
aga	doc_737963622254_item	2833736	et	3	main
huvi	doc_737963622254_item	2833739	et	4	main
ainult	doc_737963622254_item	2833740	et	4	main
ilusad	doc_737963622254_item	2833741	et	3	main
naised	doc_737963622254_item	2833742	et	3	main
ja	doc_737963622254_item	2833743	et	3	main
5	doc_737963622254_item	2833758	et	2	main
töökohaga	doc_737963622254_item	2833763	et	4	main
6	doc_737963622254_item	2833765	et	2	main
piirdusime	doc_737963622254_item	2833766	et	3	main
selles	doc_737963622254_item	2833767	et	4	main
vaid	doc_737963622254_item	2833769	et	3	main
küsimuses	doc_737963622254_item	2833768	et	4	main
väikesed	doc_737963622254_item	2833770	et	4	main
muudatused	doc_737963622254_item	2833771	et	3	main
väikeste	doc_737963622254_item	2833772	et	4	main
muudatustega	doc_737963622254_item	2833773	et	3	main
7	doc_737963622254_item	2833774	et	2	main
see	doc_737963622254_item	2833775	et	3	main
küsimus	doc_737963622254_item	2833776	et	4	main
ma	doc_737963622254_item	2833729	et	3	main
autod	doc_737963622254_item	2833745	et	3	main
kiirete	doc_737963622254_item	2833748	et	4	main
uus	doc_737963622254_item	2833760	et	3	main
töökoht	doc_737963622254_item	2833761	et	3	main
teine	doc_737963622254_item	2833778	et	3	main
teisele	doc_737963622254_item	2833780	et	4	main
valdkonnale	doc_737963622254_item	2833781	et	4	main
8	doc_737963622254_item	2833782	et	2	main
närimiskumm	doc_737963622254_item	2833783	et	3	main
kleepus	doc_737963622254_item	2833784	et	3	main
püksid	doc_737963622254_item	2833785	et	3	main
pükstele	doc_737963622254_item	2833786	et	3	main
9	doc_737963622254_item	2833787	et	2	main
10	doc_737963622254_item	2833794	et	2	main
suvine	doc_737963622254_item	2833798	et	4	main
päike	doc_737963622254_item	2833799	et	3	main
1	doc_737963622254_item	2833808	et	2	main
see	doc_737963622254_item	2833813	et	3	main
õpetajad	doc_737963622254_item	2833823	et	4	main
oodata	doc_737963622254_item	2833827	et	4	main
kuna	doc_737963622254_item	2833828	et	3	main
vanemad	doc_737963622254_item	2833829	et	4	main
tagasi	doc_737963622254_item	2833830	et	3	main
naeru	doc_737963622254_item	2833835	et	4	main
rääkinud	doc_737963622254_item	2833841	et	4	main
alkoholi	doc_737963622254_item	2833865	et	4	main
tarbida	doc_737963622254_item	2833866	et	3	main
8	doc_737963622254_item	2833867	et	2	main
nad	doc_737963622254_item	2833868	et	3	main
tulemust	doc_737963622254_item	2833873	et	4	main
9	doc_737963622254_item	2833876	et	2	main
sa	doc_737963622254_item	2833878	et	3	main
ukse	doc_737963622254_item	2833886	et	3	main
koputust	doc_737963622254_item	2833889	et	4	main
i	doc_737963622255_item	2833891	et	4	main
olevad	doc_737963622255_item	2833894	et	4	main
toomet	doc_737963622255_item	2833899	et	4	main
naine	doc_737963622255_item	2833902	et	3	main
ta	doc_737963622255_item	2833906	et	4	main
ajalehes	doc_737963622255_item	2833907	et	3	main
kuulutus	doc_737963622255_item	2833908	et	4	main
külla	doc_737963622255_item	2833914	et	4	main
otsitakse	doc_737963622255_item	2833915	et	3	main
nende	doc_737963622255_item	2833933	et	4	main
emakeelt	doc_737963622255_item	2833934	et	4	main
õpetama	doc_737963622255_item	2833935	et	3	main
õpetanud	doc_737963622255_item	2833936	et	4	main
jõudma	doc_737963622255_item	2833942	et	3	main
jõudmas	doc_737963622255_item	2833943	et	3	main
et	doc_737963622255_item	2833944	et	3	main
on	doc_737963622255_item	2833945	et	4	main
kui	doc_737963622255_item	2833951	et	3	main
tulema	doc_737963622255_item	2833953	et	4	main
lendama	doc_737963622255_item	2833968	et	3	main
ega	doc_737963622255_item	2833971	et	3	main
noor	doc_737963622255_item	2833975	et	3	main
tahtmine	doc_737963622255_item	2833977	et	4	main
õppimine	doc_737963622255_item	2834010	et	4	main
käib	doc_737963622255_item	2834011	et	3	main
ja	doc_737963622255_item	2834024	et	3	main
nagu	doc_737963622255_item	2834031	et	3	main
kool	doc_737963622255_item	2834035	et	4	main
on	doc_737963622255_item	2834036	et	4	main
elab	doc_737963622255_item	2834048	et	3	main
üle	doc_737963622255_item	2834050	et	3	main
rääkida	doc_737963622255_item	2834059	et	3	main
päevad	doc_737963622255_item	2834086	et	3	main
ööd	doc_737963622255_item	2834091	et	4	main
juba	doc_737963622255_item	2834092	et	3	main
jahe	doc_737963622255_item	2834093	et	3	main
vaja	doc_737963622255_item	2834103	et	4	main
valmistunud	doc_737963622255_item	2834117	et	4	main
laused	doc_737963622255_item	2834127	et	3	main
sõnad	doc_737963622255_item	2834129	et	4	main
õigesse	doc_737963622255_item	2834130	et	3	main
vormi	doc_737963622255_item	2834131	et	4	main
ja	doc_737963622255_item	2834132	et	3	main
kasutades	doc_737963622255_item	2834133	et	3	main
naised	doc_737963622255_item	2834138	et	3	main
mehed	doc_737963622255_item	2834141	et	3	main
igaüks	doc_737963622255_item	2834143	et	3	main
kuulub	doc_737963622254_item	2833777	et	3	main
külmetamisest	doc_737963622254_item	2833793	et	4	main
rõõmu	doc_737963622254_item	2833797	et	4	main
tulevad	doc_737963622254_item	2833831	et	4	main
nagu	doc_737963622254_item	2833836	et	3	main
anekdooti	doc_737963622254_item	2833840	et	4	main
ta	doc_737963622254_item	2833843	et	4	main
töö	doc_737963622254_item	2833852	et	4	main
aga	doc_737963622254_item	2833872	et	3	main
ei	doc_737963622254_item	2833874	et	4	main
kas	doc_737963622254_item	2833877	et	3	main
sõidad	doc_737963622254_item	2833879	et	3	main
avasin	doc_737963622254_item	2833885	et	3	main
eksamitöö	doc_737963622255_item	2833890	et	4	main
pange	doc_737963622255_item	2833892	et	4	main
vormi	doc_737963622255_item	2833897	et	4	main
on	doc_737963622255_item	2833900	et	4	main
suvel	doc_737963622255_item	2833903	et	3	main
nägema	doc_737963622255_item	2833904	et	3	main
ülem-suetuki	doc_737963622255_item	2833912	et	4	main
konkurssi	doc_737963622255_item	2833922	et	4	main
on	doc_737963622255_item	2833924	et	4	main
nädal	doc_737963622255_item	2833928	et	3	main
nädala	doc_737963622255_item	2833929	et	3	main
väikestele	doc_737963622255_item	2833930	et	4	main
ta	doc_737963622255_item	2833940	et	4	main
siberisse	doc_737963622255_item	2833941	et	4	main
üllatunud	doc_737963622255_item	2833950	et	4	main
siber	doc_737963622255_item	2833961	et	4	main
siberist	doc_737963622255_item	2833962	et	4	main
selline	doc_737963622255_item	2833963	et	4	main
pilt	doc_737963622255_item	2833964	et	3	main
et	doc_737963622255_item	2833965	et	3	main
kasva	doc_737963622255_item	2833972	et	4	main
rohi	doc_737963622255_item	2833973	et	4	main
hoog	doc_737963622255_item	2834013	et	3	main
eestlased	doc_737963622255_item	2834016	et	3	main
kuidagi	doc_737963622255_item	2834018	et	3	main
päikese	doc_737963622254_item	2833801	et	4	main
vastu	doc_737963622254_item	2833802	et	3	main
lõuna	doc_737963622254_item	2833811	et	4	main
3	doc_737963622254_item	2833824	et	2	main
lapsel	doc_737963622254_item	2833825	et	4	main
kostis	doc_737963622254_item	2833834	et	4	main
keegi	doc_737963622254_item	2833838	et	4	main
5	doc_737963622254_item	2833842	et	2	main
ei	doc_737963622254_item	2833844	et	4	main
tule	doc_737963622254_item	2833845	et	4	main
suitsetada	doc_737963622254_item	2833862	et	3	main
ja	doc_737963622254_item	2833863	et	3	main
ning	doc_737963622254_item	2833864	et	3	main
küll	doc_737963622254_item	2833870	et	4	main
olnud	doc_737963622254_item	2833875	et	4	main
maale	doc_737963622254_item	2833880	et	4	main
või	doc_737963622254_item	2833881	et	4	main
kui	doc_737963622254_item	2833887	et	3	main
sulgudes	doc_737963622255_item	2833893	et	4	main
kuulutust	doc_737963622255_item	2833909	et	4	main
et	doc_737963622255_item	2833910	et	3	main
siberisse	doc_737963622255_item	2833911	et	4	main
eesti	doc_737963622255_item	2833916	et	4	main
õpetajat	doc_737963622255_item	2833918	et	4	main
ka	doc_737963622254_item	2833822	et	3	main
paluti	doc_737963622254_item	2833826	et	3	main
trenni	doc_737963622254_item	2833846	et	4	main
läheb	doc_737963622254_item	2833847	et	3	main
hoopis	doc_737963622254_item	2833848	et	3	main
teatrisse	doc_737963622254_item	2833849	et	3	main
6	doc_737963622254_item	2833850	et	2	main
lõpetage	doc_737963622254_item	2833851	et	3	main
siis	doc_737963622254_item	2833854	et	3	main
lähete	doc_737963622254_item	2833855	et	4	main
jalutama	doc_737963622254_item	2833856	et	3	main
7	doc_737963622254_item	2833857	et	2	main
selles	doc_737963622254_item	2833858	et	4	main
baaris	doc_737963622254_item	2833859	et	3	main
ei	doc_737963622254_item	2833860	et	4	main
tohi	doc_737963622254_item	2833861	et	4	main
töötasid	doc_737963622254_item	2833869	et	4	main
jääd	doc_737963622254_item	2833882	et	4	main
linna	doc_737963622254_item	2833883	et	4	main
10	doc_737963622254_item	2833884	et	2	main
piret	doc_737963622255_item	2833898	et	4	main
ettevõtlik	doc_737963622255_item	2833901	et	3	main
nägi	doc_737963622255_item	2833905	et	3	main
küla	doc_737963622255_item	2833913	et	4	main
keele	doc_737963622255_item	2833917	et	4	main
konkurss	doc_737963622255_item	2833921	et	3	main
eestlastele	doc_737963622255_item	2833931	et	4	main
vastu	doc_737963622255_item	2833955	et	3	main
korralik	doc_737963622255_item	2833956	et	3	main
korraliku	doc_737963622255_item	2833957	et	3	main
audiga	doc_737963622255_item	2833958	et	3	main
seal	doc_737963622255_item	2833966	et	4	main
lenda	doc_737963622255_item	2833969	et	4	main
kartul	doc_737963622255_item	2834007	et	3	main
salv	doc_737963622255_item	2834008	et	3	main
hooaga	doc_737963622255_item	2834014	et	4	main
siinsed	doc_737963622255_item	2834015	et	3	main
räägivad	doc_737963622255_item	2834017	et	3	main
mõnus	doc_737963622255_item	2834020	et	4	main
ja	doc_737963622255_item	2834021	et	3	main
mahlakati	doc_737963622255_item	2834025	et	3	main
aktsent	doc_737963622255_item	2834028	et	3	main
vaid	doc_737963622255_item	2834030	et	3	main
mõni	doc_737963622255_item	2834032	et	3	main
mõnd	doc_737963622255_item	2834033	et	3	main
kool	doc_737963622255_item	2834039	et	4	main
ülejäänud	doc_737963622255_item	2834041	et	4	main
aine	doc_737963622255_item	2834042	et	4	main
ained	doc_737963622255_item	2834043	et	3	main
õpetatakse	doc_737963622255_item	2834044	et	3	main
kolmesaja	doc_737963622255_item	2834052	et	4	main
inimene	doc_737963622255_item	2834053	et	3	main
inimest	doc_737963622255_item	2834054	et	3	main
emakeelt	doc_737963622255_item	2834055	et	4	main
saab	doc_737963622255_item	2834056	et	3	main
pireti	doc_737963622255_item	2834060	et	4	main
poolpõlenud	doc_737963622255_item	2834064	et	4	main
veel	doc_737963622255_item	2834087	et	4	main
juba	doc_737963622255_item	2834096	et	3	main
vene	doc_737963622255_item	2834098	et	4	main
kütmine	doc_737963622255_item	2834100	et	4	main
kütmisega	doc_737963622255_item	2834101	et	4	main
kui	doc_737963622255_item	2834102	et	3	main
ega	doc_737963622255_item	2834108	et	3	main
muud	doc_737963622255_item	2834111	et	4	main
ei	doc_737963622255_item	2834112	et	4	main
müüdagi	doc_737963622255_item	2834113	et	3	main
naerab	doc_737963622255_item	2834114	et	3	main
talveks	doc_737963622255_item	2834115	et	4	main
valmistuma	doc_737963622255_item	2834116	et	3	main
lühendatud	doc_737963622255_item	2834120	et	4	main
ja	doc_737963622255_item	2833923	et	3	main
nüüd	doc_737963622255_item	2833925	et	4	main
juba	doc_737963622255_item	2833926	et	3	main
üle	doc_737963622255_item	2833927	et	3	main
kinnitusel	doc_737963622255_item	2833938	et	4	main
tundis	doc_737963622255_item	2833939	et	3	main
üllatuma	doc_737963622255_item	2833949	et	3	main
mulle	doc_737963622255_item	2833952	et	4	main
tuli	doc_737963622255_item	2833954	et	4	main
mulle	doc_737963622255_item	2833959	et	4	main
maaliti	doc_737963622255_item	2833960	et	3	main
täis	doc_737963622255_item	2833979	et	4	main
piret	doc_737963622255_item	2833980	et	4	main
pärast	doc_737963622255_item	2833981	et	4	main
õppeaasta	doc_737963622255_item	2833982	et	4	main
algust	doc_737963622255_item	2833983	et	4	main
koht	doc_737963622255_item	2833984	et	3	main
kohale	doc_737963622255_item	2833985	et	4	main
jõudis	doc_737963622255_item	2833986	et	3	main
polnud	doc_737963622255_item	2833987	et	3	main
kool	doc_737963622255_item	2833988	et	4	main
veel	doc_737963622255_item	2833989	et	4	main
algama	doc_737963622255_item	2833990	et	3	main
alganud	doc_737963622255_item	2833991	et	4	main
kogu	doc_737963622255_item	2833992	et	4	main
küla	doc_737963622255_item	2833993	et	4	main
võtma	doc_737963622255_item	2833994	et	3	main
võttis	doc_737963622255_item	2833995	et	3	main
kartuleid	doc_737963622255_item	2833996	et	3	main
kartulivõtt	doc_737963622255_item	2833997	et	3	main
on	doc_737963622255_item	2833998	et	4	main
siin	doc_737963622255_item	2833999	et	4	main
sügisel	doc_737963622255_item	2834000	et	3	main
kõige	doc_737963622255_item	2834001	et	4	main
tähtis	doc_737963622255_item	2834002	et	4	main
tähtsam	doc_737963622255_item	2834003	et	4	main
ettevõtmine	doc_737963622255_item	2834004	et	3	main
tänaseks	doc_737963622255_item	2834005	et	4	main
on	doc_737963622255_item	2834006	et	4	main
ja	doc_737963622255_item	2834009	et	3	main
täie	doc_737963622255_item	2834012	et	3	main
teistmoodi	doc_737963622255_item	2834019	et	3	main
mõnusasti	doc_737963622255_item	2834023	et	3	main
vene	doc_737963622255_item	2834027	et	4	main
aktsendiga	doc_737963622255_item	2834029	et	3	main
murret	doc_737963622255_item	2834034	et	4	main
keeles	doc_737963622255_item	2834046	et	4	main
külas	doc_737963622255_item	2834047	et	3	main
veidi	doc_737963622255_item	2834049	et	3	main
kõikjal	doc_737963622255_item	2834058	et	3	main
lapsed	doc_737963622255_item	2834063	et	3	main
jahedad	doc_737963622255_item	2834094	et	3	main
ostan	doc_737963622255_item	2834104	et	3	main
külapood	doc_737963622255_item	2834105	et	3	main
külapoest	doc_737963622255_item	2834106	et	4	main
sõnadest	doc_737963622255_item	2834126	et	3	main
pannes	doc_737963622255_item	2834128	et	4	main
naeratus	doc_737963622255_item	2834136	et	4	main
ja	doc_737963622255_item	2834149	et	3	main
igaühest	doc_737963622255_item	2834152	et	4	main
3	doc_737963622255_item	2834154	et	2	main
paras	doc_737963622255_item	2834155	et	3	main
kogus	doc_737963622255_item	2834156	et	4	main
stress	doc_737963622255_item	2834157	et	3	main
panema	doc_737963622255_item	2834158	et	3	main
võib	doc_737963622255_item	2834175	et	3	main
soovimatut	doc_737963622255_item	2834177	et	4	main
ei	doc_737963622255_item	2834180	et	4	main
tekkima	doc_737963622255_item	2834184	et	3	main
ülekoormust	doc_737963622255_item	2834194	et	4	main
saanud	doc_737963622255_item	2834214	et	4	main
lausab	doc_737963622255_item	2834222	et	4	main
vaatamine	doc_737963622255_item	2834242	et	4	main
aeg	doc_737963622255_item	2834243	et	3	main
sulgudes	doc_737963622255_item	2834263	et	4	main
olevad	doc_737963622255_item	2834264	et	4	main
töökoht	doc_737963622255_item	2834325	et	3	main
töökohal	doc_737963622255_item	2834327	et	4	main
piirdusime	doc_737963622255_item	2834330	et	3	main
küsimuses	doc_737963622255_item	2834332	et	4	main
väikesed	doc_737963622255_item	2834334	et	4	main
muudatused	doc_737963622255_item	2834335	et	3	main
kleepus	doc_737963622255_item	2834348	et	3	main
püksid	doc_737963622255_item	2834349	et	3	main
1	doc_737963622255_item	2834371	et	2	main
maksis	doc_737963622255_item	2834377	et	4	main
palju	doc_737963622255_item	2834378	et	4	main
lapsel	doc_737963622255_item	2834387	et	4	main
kui	doc_737963622255_item	2834390	et	3	main
tagasi	doc_737963622255_item	2834392	et	3	main
tulevad	doc_737963622255_item	2834393	et	4	main
4	doc_737963622255_item	2834394	et	2	main
selles	doc_737963622255_item	2834421	et	4	main
tarbida	doc_737963622255_item	2834428	et	3	main
töötasid	doc_737963622255_item	2834431	et	4	main
küll	doc_737963622255_item	2834432	et	4	main
tulemust	doc_737963622255_item	2834436	et	4	main
maale	doc_737963622255_item	2834443	et	4	main
mahlakas	doc_737963622255_item	2834022	et	4	main
siiski	doc_737963622255_item	2834037	et	4	main
vene	doc_737963622255_item	2834045	et	4	main
kõik	doc_737963622255_item	2834057	et	4	main
õpivad	doc_737963622255_item	2834062	et	3	main
raamatud	doc_737963622255_item	2834065	et	4	main
raamatuid	doc_737963622255_item	2834066	et	3	main
varsti	doc_737963622255_item	2834067	et	3	main
saatma	doc_737963622255_item	2834068	et	3	main
saadetakse	doc_737963622255_item	2834069	et	3	main
eestist	doc_737963622255_item	2834070	et	3	main
uued	doc_737963622255_item	2834071	et	3	main
õpikud	doc_737963622255_item	2834072	et	3	main
siberi	doc_737963622255_item	2834073	et	4	main
talve	doc_737963622255_item	2834074	et	4	main
piret	doc_737963622255_item	2834075	et	4	main
ei	doc_737963622255_item	2834076	et	4	main
kartma	doc_737963622255_item	2834077	et	3	main
kartnud	doc_737963622255_item	2834078	et	4	main
mulle	doc_737963622255_item	2834079	et	4	main
juba	doc_737963622255_item	2834080	et	3	main
tooma	doc_737963622255_item	2834081	et	3	main
toonud	doc_737963622255_item	2834082	et	4	main
talvepuud	doc_737963622255_item	2834083	et	4	main
praegu	doc_737963622255_item	2834084	et	3	main
on	doc_737963622255_item	2834085	et	4	main
harjutan	doc_737963622255_item	2834095	et	3	main
ahju	doc_737963622255_item	2834099	et	4	main
vildid	doc_737963622255_item	2834107	et	4	main
suurt	doc_737963622255_item	2834110	et	3	main
vapralt	doc_737963622255_item	2834119	et	4	main
slõhtuleht	doc_737963622255_item	2834122	et	4	main
iii	doc_737963622255_item	2834123	et	4	main
naiselikum	doc_737963622255_item	2834139	et	4	main
ja	doc_737963622255_item	2834140	et	3	main
kaunim	doc_737963622255_item	2834144	et	4	main
naeratus	doc_737963622255_item	2834145	et	4	main
teeb	doc_737963622255_item	2834146	et	3	main
mehilikumaks	doc_737963622255_item	2834151	et	4	main
kaunimaks	doc_737963622255_item	2834153	et	4	main
parases	doc_737963622255_item	2834167	et	4	main
lisakoormus	doc_737963622255_item	2834174	et	3	main
tuua	doc_737963622255_item	2834176	et	3	main
tagajärg	doc_737963622255_item	2834178	et	3	main
saama	doc_737963622255_item	2834186	et	4	main
maandama	doc_737963622255_item	2834187	et	3	main
tekkima	doc_737963622255_item	2834196	et	3	main
telefon	doc_737963622255_item	2834198	et	3	main
saama	doc_737963622255_item	2834201	et	4	main
nii	doc_737963622255_item	2834202	et	3	main
maagiline	doc_737963622255_item	2834203	et	4	main
aparaat	doc_737963622255_item	2834204	et	3	main
et	doc_737963622255_item	2834205	et	3	main
see	doc_737963622255_item	2834206	et	3	main
abil	doc_737963622255_item	2834207	et	4	main
tänapäeval	doc_737963622255_item	2834215	et	3	main
aparaadiks	doc_737963622255_item	2834218	et	3	main
selle	doc_737963622255_item	2834220	et	4	main
abiga	doc_737963622255_item	2834221	et	3	main
elama	doc_737963622255_item	2834223	et	3	main
hingama	doc_737963622255_item	2834225	et	3	main
katkestama	doc_737963622255_item	2834229	et	3	main
ka	doc_737963622255_item	2834230	et	3	main
segama	doc_737963622255_item	2834234	et	3	main
ja	doc_737963622255_item	2834237	et	3	main
pahandab	doc_737963622255_item	2834239	et	3	main
huvitav	doc_737963622255_item	2834240	et	4	main
telesaade	doc_737963622255_item	2834241	et	4	main
varahommikul	doc_737963622255_item	2834249	et	3	main
segab	doc_737963622255_item	2834251	et	3	main
soomist	doc_737963622255_item	2834255	et	4	main
sõnad	doc_737963622255_item	2834265	et	4	main
õigesse	doc_737963622255_item	2834266	et	3	main
vanematele	doc_737963622255_item	2834276	et	4	main
usaldavad	doc_737963622255_item	2834283	et	4	main
igaüks	doc_737963622255_item	2834284	et	3	main
igaüht	doc_737963622255_item	2834285	et	3	main
2	doc_737963622255_item	2834286	et	2	main
kohandasin	doc_737963622255_item	2834287	et	3	main
uus	doc_737963622255_item	2834324	et	3	main
uuel	doc_737963622255_item	2834326	et	3	main
6	doc_737963622255_item	2834329	et	2	main
selles	doc_737963622255_item	2834331	et	4	main
vaid	doc_737963622255_item	2834333	et	3	main
teine	doc_737963622255_item	2834342	et	3	main
valdkond	doc_737963622255_item	2834343	et	3	main
ajal	doc_737963622255_item	2834353	et	4	main
külmetamine	doc_737963622255_item	2834356	et	4	main
10	doc_737963622255_item	2834358	et	2	main
ma	doc_737963622255_item	2834359	et	3	main
tunnen	doc_737963622255_item	2834360	et	3	main
rõõmu	doc_737963622255_item	2834361	et	4	main
v	doc_737963622255_item	2834366	et	4	main
lüngad	doc_737963622255_item	2834368	et	3	main
tellisime	doc_737963622255_item	2834372	et	4	main
2	doc_737963622255_item	2834379	et	2	main
kohal	doc_737963622255_item	2834380	et	4	main
paluti	doc_737963622255_item	2834388	et	3	main
vanemad	doc_737963622255_item	2834391	et	4	main
suitsetada	doc_737963622255_item	2834425	et	3	main
8	doc_737963622255_item	2834429	et	2	main
ei	doc_737963622255_item	2834437	et	4	main
olnud	doc_737963622255_item	2834438	et	4	main
9	doc_737963622255_item	2834439	et	2	main
kas	doc_737963622255_item	2834440	et	3	main
sõidad	doc_737963622255_item	2834442	et	3	main
linna	doc_737963622255_item	2834446	et	4	main
koputust	doc_737963622255_item	2834452	et	4	main
ajalehest	doc_737963622255_item	2834121	et	4	main
moodustage	doc_737963622255_item	2834124	et	3	main
kirjavahemärke	doc_737963622255_item	2834134	et	4	main
2	doc_737963622255_item	2834135	et	2	main
mehelikum	doc_737963622255_item	2834142	et	4	main
naisi	doc_737963622255_item	2834147	et	3	main
naiselikumaks	doc_737963622255_item	2834148	et	4	main
mehi	doc_737963622255_item	2834150	et	3	main
soovimatu	doc_737963622255_item	2834165	et	4	main
laskma	doc_737963622255_item	2834182	et	3	main
ülekoormus	doc_737963622255_item	2834183	et	3	main
pinge	doc_737963622255_item	2834185	et	4	main
sportima	doc_737963622255_item	2834188	et	4	main
puhkama	doc_737963622255_item	2834190	et	3	main
tohi	doc_737963622255_item	2834192	et	4	main
lasta	doc_737963622255_item	2834193	et	4	main
5	doc_737963622255_item	2834197	et	2	main
olema	doc_737963622255_item	2834199	et	4	main
telefon	doc_737963622255_item	2834212	et	3	main
nii	doc_737963622255_item	2834216	et	3	main
meie	doc_737963622255_item	2834159	et	4	main
tegutsema	doc_737963622255_item	2834160	et	3	main
aga	doc_737963622255_item	2834161	et	3	main
lisakoormus	doc_737963622255_item	2834162	et	3	main
võima	doc_737963622255_item	2834163	et	3	main
tooma	doc_737963622255_item	2834164	et	3	main
koguses	doc_737963622255_item	2834168	et	4	main
paneb	doc_737963622255_item	2834170	et	3	main
tegutsema	doc_737963622255_item	2834172	et	3	main
4	doc_737963622255_item	2834179	et	2	main
ja	doc_737963622255_item	2834189	et	3	main
ei	doc_737963622255_item	2834191	et	4	main
pinge	doc_737963622255_item	2834195	et	4	main
lausa	doc_737963622255_item	2834208	et	4	main
elama	doc_737963622255_item	2834209	et	3	main
ja	doc_737963622255_item	2834210	et	3	main
hingama	doc_737963622255_item	2834211	et	3	main
lõunasöök	doc_737963622255_item	2834235	et	3	main
kuid	doc_737963622255_item	2834244	et	4	main
telefonihelin	doc_737963622255_item	2834245	et	3	main
katkestab	doc_737963622255_item	2834246	et	3	main
ka	doc_737963622255_item	2834247	et	3	main
und	doc_737963622255_item	2834250	et	4	main
pahandab	doc_737963622255_item	2834256	et	3	main
telesaade	doc_737963622255_item	2834258	et	4	main
vaatamise	doc_737963622255_item	2834259	et	4	main
väga	doc_737963622255_item	2834271	et	3	main
oma	doc_737963622255_item	2834273	et	4	main
vanemad	doc_737963622255_item	2834274	et	4	main
oma	doc_737963622255_item	2834275	et	4	main
difteeriaga	doc_737963622255_item	2834321	et	3	main
kiiresti	doc_737963622255_item	2834328	et	3	main
7	doc_737963622255_item	2834338	et	2	main
see	doc_737963622255_item	2834339	et	3	main
küsimus	doc_737963622255_item	2834340	et	4	main
külmal	doc_737963622255_item	2834352	et	3	main
suvine	doc_737963622255_item	2834362	et	4	main
päike	doc_737963622255_item	2834363	et	3	main
sobivate	doc_737963622255_item	2834369	et	4	main
olid	doc_737963622255_item	2834381	et	4	main
nii	doc_737963622255_item	2834382	et	3	main
õpilased	doc_737963622255_item	2834383	et	3	main
kui	doc_737963622255_item	2834384	et	3	main
õpetajad	doc_737963622255_item	2834385	et	4	main
3	doc_737963622255_item	2834386	et	2	main
oodata	doc_737963622255_item	2834389	et	4	main
naeru	doc_737963622255_item	2834397	et	4	main
nii	doc_737963622255_item	2834398	et	3	main
et	doc_737963622255_item	2834399	et	3	main
oleks	doc_737963622255_item	2834400	et	3	main
keegi	doc_737963622255_item	2834401	et	4	main
just	doc_737963622255_item	2834402	et	3	main
tohi	doc_737963622255_item	2834424	et	4	main
alkoholi	doc_737963622255_item	2834427	et	4	main
kuid	doc_737963622255_item	2834435	et	4	main
või	doc_737963622255_item	2834444	et	4	main
10	doc_737963622255_item	2834447	et	2	main
ukse	doc_737963622255_item	2834449	et	3	main
kuulsin	doc_737963622255_item	2834451	et	3	main
kuid	doc_737963622255_item	2834227	et	4	main
pühapäev	doc_737963622255_item	2834231	et	3	main
uni	doc_737963622255_item	2834233	et	3	main
söömine	doc_737963622255_item	2834238	et	4	main
pühapäeval	doc_737963622255_item	2834248	et	3	main
valmistamist	doc_737963622255_item	2834253	et	4	main
ja	doc_737963622255_item	2834254	et	3	main
huvitava	doc_737963622255_item	2834257	et	4	main
vormi	doc_737963622255_item	2834267	et	4	main
1	doc_737963622255_item	2834268	et	2	main
pean	doc_737963622255_item	2834270	et	4	main
sest	doc_737963622255_item	2834277	et	4	main
nad	doc_737963622255_item	2834278	et	3	main
aitavad	doc_737963622255_item	2834279	et	4	main
kõik	doc_737963622255_item	2834280	et	4	main
kõiki	doc_737963622255_item	2834281	et	4	main
ja	doc_737963622255_item	2834282	et	3	main
nõuded	doc_737963622255_item	2834289	et	3	main
nõudeid	doc_737963622255_item	2834290	et	3	main
3	doc_737963622255_item	2834291	et	2	main
ma	doc_737963622255_item	2834292	et	3	main
arvasin	doc_737963622255_item	2834293	et	3	main
et	doc_737963622255_item	2834294	et	3	main
sa	doc_737963622255_item	2834295	et	3	main
huvitud	doc_737963622255_item	2834296	et	4	main
sport	doc_737963622255_item	2834297	et	3	main
spordiga	doc_737963622255_item	2834298	et	3	main
aga	doc_737963622255_item	2834299	et	3	main
sa	doc_737963622255_item	2834300	et	3	main
tunned	doc_737963622255_item	2834301	et	3	main
ainult	doc_737963622255_item	2834303	et	4	main
ilusad	doc_737963622255_item	2834304	et	3	main
huvi	doc_737963622255_item	2834302	et	4	main
naised	doc_737963622255_item	2834305	et	3	main
ja	doc_737963622255_item	2834306	et	3	main
kiired	doc_737963622255_item	2834307	et	4	main
autod	doc_737963622255_item	2834308	et	3	main
ilusade	doc_737963622255_item	2834309	et	3	main
naiste	doc_737963622255_item	2834310	et	3	main
ja	doc_737963622255_item	2834311	et	3	main
kiirte	doc_737963622255_item	2834312	et	3	main
autode	doc_737963622255_item	2834313	et	3	main
vastu	doc_737963622255_item	2834314	et	3	main
4	doc_737963622255_item	2834315	et	2	main
praegu	doc_737963622255_item	2834316	et	3	main
on	doc_737963622255_item	2834317	et	4	main
oht	doc_737963622255_item	2834318	et	3	main
haigestuda	doc_737963622255_item	2834319	et	3	main
difteeria	doc_737963622255_item	2834320	et	4	main
tüdinesin	doc_737963622255_item	2834323	et	3	main
väikeste	doc_737963622255_item	2834336	et	4	main
muudatustega	doc_737963622255_item	2834337	et	3	main
9	doc_737963622255_item	2834351	et	2	main
hoiduma	doc_737963622255_item	2834355	et	3	main
suvisest	doc_737963622255_item	2834364	et	4	main
päikest	doc_737963622255_item	2834365	et	4	main
sidenditega	doc_737963622255_item	2834370	et	3	main
kolmekäigulise	doc_737963622255_item	2834373	et	4	main
lõuna	doc_737963622255_item	2834374	et	4	main
kuid	doc_737963622255_item	2834375	et	4	main
see	doc_737963622255_item	2834376	et	3	main
kostis	doc_737963622255_item	2834396	et	4	main
anekdooti	doc_737963622255_item	2834403	et	4	main
rääkinud	doc_737963622255_item	2834404	et	4	main
5	doc_737963622255_item	2834405	et	2	main
ta	doc_737963622255_item	2834406	et	4	main
ei	doc_737963622255_item	2834407	et	4	main
tule	doc_737963622255_item	2834408	et	4	main
trenni	doc_737963622255_item	2834409	et	4	main
sest	doc_737963622255_item	2834410	et	4	main
läheb	doc_737963622255_item	2834411	et	3	main
hoopis	doc_737963622255_item	2834412	et	3	main
teatrisse	doc_737963622255_item	2834413	et	3	main
6	doc_737963622255_item	2834414	et	2	main
lõpetage	doc_737963622255_item	2834415	et	3	main
töö	doc_737963622255_item	2834416	et	4	main
siis	doc_737963622255_item	2834417	et	3	main
lähete	doc_737963622255_item	2834418	et	4	main
jalutama	doc_737963622255_item	2834419	et	3	main
7	doc_737963622255_item	2834420	et	2	main
8	doc_737963622255_item	2834346	et	2	main
närimiskumm	doc_737963622255_item	2834347	et	3	main
pükstele	doc_737963622255_item	2834350	et	3	main
peab	doc_737963622255_item	2834354	et	4	main
külmetamist	doc_737963622255_item	2834357	et	4	main
täitke	doc_737963622255_item	2834367	et	3	main
kõrvallauast	doc_737963622255_item	2834395	et	4	main
baaris	doc_737963622255_item	2834422	et	3	main
jääd	doc_737963622255_item	2834445	et	4	main
avasin	doc_737963622255_item	2834448	et	3	main
sest	doc_737963622255_item	2834450	et	4	main
ei	doc_737963622255_item	2834423	et	4	main
ega	doc_737963622255_item	2834426	et	3	main
nad	doc_737963622255_item	2834430	et	3	main
pingsalt	doc_737963622255_item	2834433	et	4	main
aga	doc_737963622255_item	2834434	et	3	main
sa	doc_737963622255_item	2834441	et	3	main
peavad	doc_740091150997_item	2834733	et	4	main
kas	doc_740091150997_item	2834734	et	3	main
seda	doc_740091150997_item	2834735	et	3	main
igaühel	doc_740091150997_item	2834750	et	3	main
on	doc_740091150997_item	2834751	et	4	main
küll	doc_740091150997_item	2834769	et	4	main
kuid	doc_740091150997_item	2834775	et	4	main
tegelikult	doc_740091150997_item	2834776	et	4	main
võib	doc_740091150997_item	2834777	et	3	main
muudab	doc_740091150997_item	2834783	et	3	main
keskkonda	doc_740091150997_item	2834785	et	4	main
teinekors	doc_740091150997_item	2834792	et	4	main
palju	doc_740091150997_item	2834793	et	4	main
andekat	doc_740091150997_item	2834808	et	3	main
on	doc_740091150997_item	2834810	et	4	main
olla	doc_740091150997_item	2834812	et	3	main
mida	doc_740091150997_item	2834815	et	4	main
oskasid	doc_740091150997_item	2834725	et	4	main
normaalse	doc_740091150997_item	2834729	et	3	main
võimalik	doc_740091150997_item	2834738	et	3	main
inimene	doc_740091150997_item	2834746	et	3	main
nõrgad	doc_740091150997_item	2834755	et	3	main
kuljed	doc_740091150997_item	2834756	et	4	main
samuti	doc_740091150997_item	2834757	et	3	main
kiiksud	doc_740091150997_item	2834765	et	4	main
ei	doc_740091150997_item	2834766	et	4	main
sageli	doc_740091150997_item	2834770	et	3	main
nn	doc_740091150997_item	2834771	et	4	main
mis	doc_740091150997_item	2834782	et	4	main
on	doc_740091150997_item	2834791	et	4	main
meeskonda	doc_740091150997_item	2834799	et	4	main
ega	doc_740091150997_item	2834804	et	3	main
seda	doc_740091150997_item	2834806	et	3	main
võib	doc_740091150997_item	2834811	et	3	main
isiksustest	doc_740091150997_item	2834817	et	3	main
tulemuslikumalt	doc_740091150997_item	2834821	et	4	main
tegutseb	doc_740091150997_item	2834823	et	3	main
on	doc_740091150997_item	2834827	et	4	main
meeskonna	doc_740091150997_item	2834828	et	4	main
eraldi	doc_740091150997_item	2834838	et	4	main
meeskonnaliikmeid	doc_740091150997_item	2834844	et	3	main
arvatud	doc_740091150997_item	2834851	et	4	main
muidugi	doc_740091150997_item	2834852	et	4	main
töörühma	doc_740091150997_item	2834859	et	4	main
ikkagi	doc_740091150997_item	2834862	et	4	main
inimest	doc_740091150997_item	2834863	et	3	main
ja	doc_740091150997_item	2834864	et	3	main
tema	doc_740091150997_item	2834865	et	4	main
andeid	doc_740091150997_item	2834866	et	3	main
oleneb	doc_740091150997_item	2834869	et	3	main
et	doc_740091150997_item	2834876	et	3	main
esmakohtumisel	doc_740091150997_item	2834881	et	3	main
legendaarsed	doc_740091150997_item	2834722	et	3	main
keda	doc_740091150997_item	2834727	et	4	main
nad	doc_740091150997_item	2834728	et	3	main
on	doc_740091150997_item	2834736	et	4	main
üldse	doc_740091150997_item	2834737	et	3	main
on	doc_740091150997_item	2834742	et	4	main
inimene	doc_740091150997_item	2834744	et	3	main
on	doc_740091150997_item	2834747	et	4	main
pisikesed	doc_740091150997_item	2834758	et	4	main
kiiksud	doc_740091150997_item	2834759	et	4	main
ja	doc_740091150997_item	2834760	et	3	main
tavakujutluses	doc_740091150997_item	2834768	et	3	main
normi	doc_740091150997_item	2834772	et	4	main
alla	doc_740091150997_item	2834773	et	3	main
mahtuda	doc_740091150997_item	2834774	et	3	main
loov	doc_740091150997_item	2834780	et	4	main
alge	doc_740091150997_item	2834781	et	4	main
ümbritsevat	doc_740091150997_item	2834784	et	4	main
mitmekesisemaks	doc_740091150997_item	2834786	et	4	main
ja	doc_740091150997_item	2834787	et	3	main
rikkamaks	doc_740091150997_item	2834788	et	4	main
ja	doc_740091150997_item	2834789	et	3	main
kasugi	doc_740091150997_item	2834794	et	4	main
valib	doc_740091150997_item	2834797	et	3	main
just	doc_740091150997_item	2834801	et	3	main
erinevamatest	doc_740091150997_item	2834816	et	4	main
see	doc_740091150997_item	2834822	et	3	main
kui	doc_740091150997_item	2834833	et	3	main
selle	doc_740091150997_item	2834835	et	4	main
liikmed	doc_740091150997_item	2834836	et	3	main
oleks	doc_740091150997_item	2834837	et	3	main
valides	doc_740091150997_item	2834845	et	3	main
tohiks	doc_740091150997_item	2834848	et	3	main
parimaks	doc_740091150997_item	2834856	et	4	main
kuidas	doc_740091150997_item	2834861	et	3	main
palju	doc_740091150997_item	2834868	et	4	main
tajumisel	doc_740091150997_item	2834871	et	4	main
esmamulje	doc_740091150997_item	2834872	et	4	main
efektist	doc_740091150997_item	2834873	et	3	main
psühholoogid	doc_740091150997_item	2834874	et	4	main
meeldivuse	doc_740091150997_item	2834878	et	4	main
tekib	doc_740091150997_item	2834880	et	3	main
inimestest	doc_740091150997_item	2834884	et	3	main
so	doc_740091150997_item	2834885	et	4	main
20	doc_740091150997_item	2834886	et	2	main
inimestest	doc_740091150997_item	2834887	et	3	main
me	doc_740091150997_item	2834891	et	4	main
20	doc_740091150997_item	2834894	et	2	main
meeldi	doc_740091150997_item	2834900	et	4	main
kena	doc_740091150997_item	2834904	et	4	main
meeldiv	doc_740091150997_item	2834906	et	4	main
pealispinna	doc_740091150997_item	2834921	et	3	main
essee	doc_740091150997_item	2834696	et	4	main
saage	doc_740091150997_item	2834697	et	4	main
tuttavaks	doc_740091150997_item	2834698	et	4	main
normaalne	doc_740091150997_item	2834699	et	3	main
inimene	doc_740091150997_item	2834700	et	3	main
normaalne	doc_740091150997_item	2834701	et	3	main
kommenteerisid	doc_740091150997_item	2834702	et	4	main
telesaatest	doc_740091150997_item	2834703	et	4	main
wremja	doc_740091150997_item	2834704	et	4	main
tuntud	doc_740091150997_item	2834705	et	4	main
rullnokad	doc_740091150997_item	2834706	et	3	main
aiku	doc_740091150997_item	2834707	et	4	main
ja	doc_740091150997_item	2834708	et	3	main
pets	doc_740091150997_item	2834709	et	4	main
sageli	doc_740091150997_item	2834710	et	3	main
enamasti	doc_740091150997_item	2834711	et	4	main
tähendas	doc_740091150997_item	2834712	et	3	main
see	doc_740091150997_item	2834713	et	3	main
inimesele	doc_740091150997_item	2834714	et	3	main
või	doc_740091150997_item	2834715	et	4	main
tema	doc_740091150997_item	2834716	et	4	main
teole	doc_740091150997_item	2834717	et	4	main
positiivset	doc_740091150997_item	2834718	et	3	main
hinnangut	doc_740091150997_item	2834719	et	3	main
vaevalt	doc_740091150997_item	2834720	et	4	main
et	doc_740091150997_item	2834721	et	3	main
rullnokad	doc_740091150997_item	2834723	et	3	main
selgitada	doc_740091150997_item	2834726	et	3	main
inimese	doc_740091150997_item	2834730	et	4	main
all	doc_740091150997_item	2834731	et	3	main
silmas	doc_740091150997_item	2834732	et	4	main
lahti	doc_740091150997_item	2834739	et	4	main
mõtestada	doc_740091150997_item	2834740	et	3	main
ise	doc_740091150997_item	2834724	et	4	main
kus	doc_740091150997_item	2834741	et	3	main
normaalne	doc_740091150997_item	2834743	et	3	main
iga	doc_740091150997_item	2834745	et	4	main
isiksus	doc_740091150997_item	2834749	et	3	main
veidrused	doc_740091150997_item	2834761	et	4	main
toredad	doc_740091150997_item	2834762	et	3	main
taha	doc_740091150997_item	2834767	et	4	main
neis	doc_740091150997_item	2834778	et	4	main
neist	doc_740091150997_item	2834790	et	4	main
hea	doc_740091150997_item	2834795	et	4	main
oma	doc_740091150997_item	2834798	et	4	main
töötajaid	doc_740091150997_item	2834800	et	4	main
annete	doc_740091150997_item	2834802	et	3	main
alusel	doc_740091150997_item	2834803	et	4	main
meeskond	doc_740091150997_item	2834818	et	3	main
koosneb	doc_740091150997_item	2834819	et	3	main
seda	doc_740091150997_item	2834820	et	3	main
seda	doc_740091150997_item	2834825	et	3	main
suurem	doc_740091150997_item	2834826	et	4	main
tegutsenud	doc_740091150997_item	2834839	et	4	main
millele	doc_740091150997_item	2834843	et	3	main
toetuda	doc_740091150997_item	2834846	et	3	main
välja	doc_740091150997_item	2834850	et	4	main
meeskonna	doc_740091150997_item	2834853	et	4	main
arvuline	doc_740091150997_item	2834854	et	4	main
peetakse	doc_740091150997_item	2834857	et	3	main
hinnata	doc_740091150997_item	2834867	et	4	main
vastastikuse	doc_740091150997_item	2834877	et	4	main
efekt	doc_740091150997_item	2834879	et	3	main
neid	doc_740091150997_item	2834896	et	4	main
me	doc_740091150997_item	2834898	et	4	main
et	doc_740091150997_item	2834903	et	3	main
välimus	doc_740091150997_item	2834905	et	3	main
käitumine	doc_740091150997_item	2834907	et	4	main
ja	doc_740091150997_item	2834908	et	3	main
ladus	doc_740091150997_item	2834909	et	4	main
suurem	doc_740091150997_item	2834937	et	4	main
roll	doc_740091150997_item	2834938	et	3	main
seega	doc_740091150997_item	2834960	et	4	main
olla	doc_740091150997_item	2834965	et	3	main
inimene	doc_740091150997_item	2834970	et	3	main
toimetuses	doc_740091150997_item	2835006	et	4	main
näiteks	doc_740091150997_item	2835015	et	4	main
teatas	doc_740091150997_item	2835016	et	3	main
lehe	doc_740091150997_item	2835017	et	3	main
ülienergiline	doc_740091150997_item	2835018	et	3	main
tegevjuht	doc_740091150997_item	2835019	et	3	main
juku	doc_740091150997_item	2835020	et	4	main
kordumatu	doc_740091150997_item	2834748	et	4	main
omad	doc_740091150997_item	2834752	et	4	main
tugevad	doc_740091150997_item	2834753	et	4	main
ja	doc_740091150997_item	2834754	et	3	main
ja	doc_740091150997_item	2834763	et	3	main
eluterved	doc_740091150997_item	2834764	et	4	main
peituda	doc_740091150997_item	2834779	et	3	main
juht	doc_740091150997_item	2834796	et	3	main
karda	doc_740091150997_item	2834805	et	4	main
et	doc_740091150997_item	2834807	et	3	main
inimest	doc_740091150997_item	2834809	et	3	main
raskem	doc_740091150997_item	2834813	et	4	main
juhtida	doc_740091150997_item	2834814	et	4	main
loodud	doc_740091150997_item	2834829	et	4	main
kõik	doc_740091150997_item	2834834	et	4	main
kindlaid	doc_740091150997_item	2834841	et	3	main
norme	doc_740091150997_item	2834842	et	3	main
ei	doc_740091150997_item	2834847	et	4	main
olla	doc_740091150997_item	2834849	et	3	main
inimese	doc_740091150997_item	2834870	et	4	main
on	doc_740091150997_item	2834888	et	4	main
kellele	doc_740091150997_item	2834890	et	4	main
meeldime	doc_740091150997_item	2834892	et	3	main
on	doc_740091150997_item	2834895	et	4	main
kellele	doc_740091150997_item	2834897	et	4	main
arvatakse	doc_740091150997_item	2834901	et	3	main
loovad	doc_740091150997_item	2834911	et	4	main
inimesest	doc_740091150997_item	2834912	et	3	main
hea	doc_740091150997_item	2834913	et	4	main
ning	doc_740091150997_item	2834824	et	3	main
lisaväärtus	doc_740091150997_item	2834830	et	3	main
võrreldes	doc_740091150997_item	2834831	et	3	main
sellega	doc_740091150997_item	2834832	et	3	main
seega	doc_740091150997_item	2834840	et	4	main
suurus	doc_740091150997_item	2834855	et	4	main
7-liikmelist	doc_740091150997_item	2834858	et	4	main
aga	doc_740091150997_item	2834860	et	3	main
väidavad	doc_740091150997_item	2834875	et	3	main
suhtlumaneer	doc_740091150997_item	2834910	et	4	main
so	doc_740091150997_item	2834914	et	4	main
normaalse	doc_740091150997_item	2834915	et	3	main
mulje	doc_740091150997_item	2834916	et	4	main
mis	doc_740091150997_item	2834917	et	4	main
on	doc_740091150997_item	2834918	et	4	main
kauni	doc_740091150997_item	2834920	et	4	main
peidus	doc_740091150997_item	2834919	et	3	main
sageli	doc_740091150997_item	2834926	et	3	main
järjest	doc_740091150997_item	2834936	et	4	main
teadmisi	doc_740091150997_item	2834947	et	4	main
vahetada	doc_740091150997_item	2834948	et	3	main
annab	doc_740091150997_item	2834949	et	3	main
koostöö	doc_740091150997_item	2834953	et	4	main
alus	doc_740091150997_item	2834959	et	4	main
suhtlusoskused	doc_740091150997_item	2834964	et	3	main
kaasaja	doc_740091150997_item	2834969	et	4	main
vastama	doc_740091150997_item	2834972	et	3	main
tipp-positsioonil	doc_740091150997_item	2835001	et	3	main
oma	doc_740091150997_item	2835033	et	4	main
optimistlik	doc_740091150997_item	2835039	et	3	main
piltlikult	doc_740091150997_item	2835043	et	4	main
uutele	doc_740091150997_item	2835045	et	3	main
töövõitudele	doc_740091150997_item	2835046	et	3	main
margus	doc_740091150997_item	2835048	et	3	main
tippjuhtide	doc_740091150997_item	2835055	et	3	main
seletas	doc_740091150997_item	2835058	et	3	main
hiljem	doc_740091150997_item	2835061	et	3	main
juhtkond	doc_740091150997_item	2835068	et	3	main
hakkama	doc_740091150997_item	2835074	et	3	main
tegema	doc_740091150997_item	2835075	et	3	main
mõistagi	doc_740091150997_item	2835080	et	4	main
juhtuma	doc_740091150997_item	2835089	et	4	main
ei	doc_740091150997_item	2835108	et	4	main
õigel	doc_740091150997_item	2835117	et	3	main
vaid	doc_740091150997_item	2834882	et	3	main
4l	doc_740091150997_item	2834883	et	4	main
neid	doc_740091150997_item	2834889	et	4	main
ning	doc_740091150997_item	2834893	et	3	main
ei	doc_740091150997_item	2834899	et	4	main
ka	doc_740091150997_item	2834902	et	3	main
alles	doc_740091150997_item	2834924	et	3	main
avaldub	doc_740091150997_item	2834927	et	3	main
loomus	doc_740091150997_item	2834930	et	4	main
kriisiolukordades	doc_740091150997_item	2834932	et	3	main
märku	doc_740091150997_item	2834950	et	4	main
võiks	doc_740091150997_item	2834961	et	4	main
avatus	doc_740091150997_item	2834962	et	4	main
ja	doc_740091150997_item	2834963	et	3	main
norm	doc_740091150997_item	2834967	et	3	main
pealtnäha	doc_740091150997_item	2834995	et	3	main
kena	doc_740091150997_item	2834996	et	4	main
inimene	doc_740091150997_item	2834997	et	3	main
ehkki	doc_740091150997_item	2834998	et	3	main
sugugi	doc_740091150997_item	2834999	et	4	main
mitte	doc_740091150997_item	2835000	et	3	main
ta	doc_740091150997_item	2835003	et	4	main
ülejäänud	doc_740091150997_item	2835012	et	4	main
tõlkeabi	doc_740091150997_item	2835014	et	4	main
oomen	doc_740091150997_item	2835021	et	3	main
plaanidest	doc_740091150997_item	2835023	et	3	main
hakata	doc_740091150997_item	2835024	et	4	main
ja	doc_740091150997_item	2835038	et	3	main
murelikke	doc_740091150997_item	2835056	et	3	main
olemuse	doc_740091150997_item	2835060	et	3	main
lahti	doc_740091150997_item	2835062	et	4	main
järgmiselt	doc_740091150997_item	2835063	et	4	main
lehe	doc_740091150997_item	2835064	et	3	main
tiraaž	doc_740091150997_item	2835065	et	2	main
toimetus	doc_740091150997_item	2835072	et	4	main
lisatööd	doc_740091150997_item	2835076	et	4	main
ilma	doc_740091150997_item	2835077	et	4	main
täpselt	doc_740091150997_item	2835081	et	4	main
hakkab	doc_740091150997_item	2835090	et	3	main
kes	doc_740091150997_item	2835092	et	4	main
lahti	doc_740091150997_item	2835093	et	4	main
lastakse	doc_740091150997_item	2835094	et	3	main
see	doc_740091150997_item	2835098	et	3	main
lausa	doc_740091150997_item	2835100	et	4	main
nagu	doc_740091150997_item	2835103	et	3	main
päris	doc_740091150997_item	2835113	et	4	main
suhelda	doc_740091150997_item	2835116	et	4	main
saa	doc_740091150997_item	2835122	et	4	main
siiski	doc_740091150997_item	2835123	et	4	main
alahinnata	doc_740091150997_item	2835124	et	4	main
eesõo	doc_740091150997_item	2835131	et	4	main
oluline	doc_740091150997_item	2835133	et	4	main
beasley	doc_740091150997_item	2835135	et	4	main
positsiooniga	doc_740091150997_item	2835137	et	3	main
peeti	doc_740091150997_item	2835141	et	4	main
peremehe	doc_740091150997_item	2835149	et	3	main
maja	doc_740091150997_item	2835150	et	4	main
läks	doc_740091150997_item	2835157	et	3	main
oskusi	doc_740091150997_item	2835159	et	3	main
telepaatiat	doc_740091150997_item	2835167	et	3	main
lugemise	doc_740091150997_item	2835175	et	4	main
ikka	doc_740091150997_item	2835194	et	4	main
usub	doc_740091150997_item	2835195	et	3	main
alahinnata	doc_740091150997_item	2835201	et	4	main
kohe	doc_740091150997_item	2835212	et	4	main
tuleb	doc_740091150997_item	2835217	et	3	main
ennatlik	doc_740091150997_item	2835220	et	3	main
on	doc_740091150997_item	2835221	et	4	main
inimese	doc_740091150997_item	2835223	et	4	main
ainult	doc_740091150997_item	2835225	et	4	main
mingi	doc_740091150997_item	2835226	et	4	main
ülemaailmse	doc_740091150997_item	2835232	et	3	main
juhid	doc_740091150997_item	2835235	et	4	main
kirjutavad	doc_740091150997_item	2835236	et	4	main
rikkudes	doc_740091150997_item	2835241	et	3	main
ära	doc_740091150997_item	2835254	et	4	main
tema	doc_740091150997_item	2835257	et	4	main
vaid	doc_740091150997_item	2835271	et	3	main
ise	doc_740091150997_item	2835277	et	4	main
saab	doc_740091150997_item	2835278	et	3	main
arendada	doc_740091150997_item	2835279	et	3	main
ka	doc_740091150997_item	2835280	et	3	main
all	doc_740091150997_item	2834922	et	3	main
inimese	doc_740091150997_item	2834928	et	4	main
nüüdisaja	doc_740091150997_item	2834933	et	3	main
inimese	doc_740091150997_item	2834939	et	4	main
suhtlusoskustel	doc_740091150997_item	2834940	et	3	main
soov	doc_740091150997_item	2834941	et	3	main
aktiivselt	doc_740091150997_item	2834942	et	4	main
koostöövalmidusest	doc_740091150997_item	2834952	et	4	main
aga	doc_740091150997_item	2834955	et	3	main
organisatsiooni	doc_740091150997_item	2834957	et	4	main
edu	doc_740091150997_item	2834958	et	4	main
millele	doc_740091150997_item	2834968	et	3	main
aga	doc_740091150997_item	2834973	et	3	main
ainult	doc_740091150997_item	2834974	et	4	main
lobedast	doc_740091150997_item	2834975	et	3	main
suhtlemisest	doc_740091150997_item	2834976	et	4	main
ei	doc_740091150997_item	2834977	et	4	main
piisa	doc_740091150997_item	2834978	et	4	main
oma	doc_740091150997_item	2834979	et	4	main
romaanis	doc_740091150997_item	2834980	et	3	main
progressiivsed	doc_740091150997_item	2834981	et	3	main
kiired	doc_740091150997_item	2834982	et	4	main
kirjeldas	doc_740091150997_item	2834983	et	3	main
mihkel	doc_740091150997_item	2834984	et	3	main
mutt	doc_740091150997_item	2834985	et	3	main
värvikalt	doc_740091150997_item	2834986	et	4	main
sellist	doc_740091150997_item	2834987	et	4	main
tegelast	doc_740091150997_item	2834988	et	3	main
nagu	doc_740091150997_item	2834989	et	3	main
margus	doc_740091150997_item	2834990	et	3	main
kena	doc_740091150997_item	2834991	et	4	main
kes	doc_740091150997_item	2834992	et	4	main
oli	doc_740091150997_item	2834993	et	3	main
selgub	doc_740091150997_item	2834923	et	3	main
hiljem	doc_740091150997_item	2834925	et	3	main
tegelik	doc_740091150997_item	2834929	et	3	main
just	doc_740091150997_item	2834931	et	3	main
teadmusühiskonnas	doc_740091150997_item	2834934	et	4	main
on	doc_740091150997_item	2834935	et	4	main
suhelda	doc_740091150997_item	2834943	et	4	main
ning	doc_740091150997_item	2834944	et	3	main
infot	doc_740091150997_item	2834945	et	3	main
ja	doc_740091150997_item	2834946	et	3	main
inimese	doc_740091150997_item	2834951	et	4	main
on	doc_740091150997_item	2834954	et	4	main
iga	doc_740091150997_item	2834956	et	4	main
üks	doc_740091150997_item	2834966	et	3	main
peab	doc_740091150997_item	2834971	et	4	main
tõepoolest	doc_740091150997_item	2834994	et	3	main
teadis	doc_740091150997_item	2835002	et	4	main
alati	doc_740091150997_item	2835004	et	4	main
mis	doc_740091150997_item	2835005	et	4	main
nädalalõpu-lisalehte	doc_740091150997_item	2835032	et	4	main
ta	doc_740091150997_item	2835036	et	4	main
entusiastlik	doc_740091150997_item	2835037	et	3	main
osalenud	doc_740091150997_item	2835054	et	4	main
nägusid	doc_740091150997_item	2835057	et	4	main
teate	doc_740091150997_item	2835059	et	4	main
on	doc_740091150997_item	2835069	et	4	main
paanikas	doc_740091150997_item	2835070	et	3	main
ning	doc_740091150997_item	2835071	et	3	main
täiendava	doc_740091150997_item	2835078	et	4	main
nii	doc_740091150997_item	2835082	et	3	main
inimesi	doc_740091150997_item	2835085	et	4	main
teavad	doc_740091150997_item	2835087	et	3	main
mis	doc_740091150997_item	2835088	et	4	main
on	doc_740091150997_item	2835095	et	4	main
igas	doc_740091150997_item	2835096	et	3	main
kollektiivis	doc_740091150997_item	2835097	et	3	main
lõpetanud	doc_740091150997_item	2835109	et	4	main
margus	doc_740091150997_item	2835110	et	3	main
oskust	doc_740091150997_item	2835115	et	3	main
õigete	doc_740091150997_item	2835119	et	3	main
ei	doc_740091150997_item	2835121	et	4	main
ulmejutus	doc_740091150997_item	2835128	et	3	main
meie	doc_740091150997_item	2835129	et	4	main
suur	doc_740091150997_item	2835130	et	3	main
madala	doc_740091150997_item	2835136	et	3	main
so	doc_740091150997_item	2835143	et	4	main
ta	doc_740091150997_item	2835165	et	4	main
ainsana	doc_740091150997_item	2835170	et	3	main
eks	doc_740091150997_item	2835178	et	3	main
ta	doc_740091150997_item	2835179	et	4	main
oli	doc_740091150997_item	2835180	et	3	main
mõtteid	doc_740091150997_item	2835188	et	3	main
kedagi	doc_740091150997_item	2835200	et	4	main
inimeses	doc_740091150997_item	2835203	et	3	main
üle	doc_740091150997_item	2835218	et	3	main
teoksil	doc_740091150997_item	2835007	et	3	main
oli	doc_740091150997_item	2835008	et	3	main
ning	doc_740091150997_item	2835009	et	3	main
vajadusel	doc_740091150997_item	2835010	et	3	main
osutas	doc_740091150997_item	2835011	et	3	main
kollektiivile	doc_740091150997_item	2835013	et	3	main
toimetusele	doc_740091150997_item	2835022	et	4	main
esinemises	doc_740091150997_item	2835034	et	4	main
oli	doc_740091150997_item	2835035	et	3	main
kutsus	doc_740091150997_item	2835041	et	4	main
kena	doc_740091150997_item	2835049	et	4	main
olles	doc_740091150997_item	2835050	et	3	main
tähele	doc_740091150997_item	2835051	et	3	main
pannud	doc_740091150997_item	2835052	et	4	main
koosolekul	doc_740091150997_item	2835053	et	3	main
on	doc_740091150997_item	2835066	et	4	main
vähenenud	doc_740091150997_item	2835067	et	4	main
peab	doc_740091150997_item	2835073	et	4	main
selliseid	doc_740091150997_item	2835084	et	4	main
kes	doc_740091150997_item	2835086	et	4	main
aga	doc_740091150997_item	2835102	et	3	main
muti	doc_740091150997_item	2835105	et	4	main
raamatus	doc_740091150997_item	2835106	et	4	main
oli	doc_740091150997_item	2835107	et	3	main
kena	doc_740091150997_item	2835111	et	4	main
aifford	doc_740091150997_item	2835125	et	4	main
teenija	doc_740091150997_item	2835138	et	4	main
napakaks	doc_740091150997_item	2835142	et	3	main
normile	doc_740091150997_item	2835144	et	3	main
mittevastavaks	doc_740091150997_item	2835145	et	4	main
maailma	doc_740091150997_item	2835156	et	4	main
et	doc_740091150997_item	2835164	et	3	main
ning	doc_740091150997_item	2835168	et	3	main
tundmatute	doc_740091150997_item	2835172	et	4	main
suhelda	doc_740091150997_item	2835177	et	4	main
siit	doc_740091150997_item	2835196	et	3	main
järeldub	doc_740091150997_item	2835197	et	3	main
ei	doc_740091150997_item	2835198	et	4	main
igas	doc_740091150997_item	2835202	et	3	main
välja	doc_740091150997_item	2835213	et	4	main
ei	doc_740091150997_item	2835214	et	4	main
tunnuse	doc_740091150997_item	2835230	et	3	main
kõiki	doc_740091150997_item	2835239	et	4	main
maailma	doc_740091150997_item	2835243	et	4	main
juhid	doc_740091150997_item	2835245	et	4	main
teisiti	doc_740091150997_item	2835246	et	3	main
teevad	doc_740091150997_item	2835247	et	3	main
andekat	doc_740091150997_item	2835252	et	3	main
tuli	doc_740091150997_item	2835286	et	4	main
aastal	doc_740091150997_item	2835288	et	3	main
välja	doc_740091150997_item	2835289	et	4	main
neid	doc_740091150997_item	2835298	et	4	main
suunas	doc_740091150997_item	2835300	et	4	main
juhtida	doc_740091150997_item	2835301	et	4	main
on	doc_740091150997_item	2835302	et	4	main
võti	doc_740091150997_item	2835305	et	4	main
et	doc_740091150997_item	2835308	et	3	main
intelligentsemad	doc_740091150997_item	2835310	et	4	main
on	doc_740091150997_item	2835312	et	4	main
elus	doc_740091150997_item	2835313	et	4	main
edukamad	doc_740091150997_item	2835314	et	4	main
läbilöövamad	doc_740091150997_item	2835316	et	4	main
kõrge	doc_740091150997_item	2835318	et	4	main
iq	doc_740091150997_item	2835319	et	4	main
ehk	doc_740091150997_item	2835320	et	3	main
välja	doc_740091150997_item	2835025	et	4	main
andma	doc_740091150997_item	2835026	et	3	main
toredat	doc_740091150997_item	2835027	et	3	main
sisukat	doc_740091150997_item	2835028	et	3	main
ja	doc_740091150997_item	2835029	et	3	main
värviliste	doc_740091150997_item	2835030	et	4	main
piltidega	doc_740091150997_item	2835031	et	3	main
ning	doc_740091150997_item	2835040	et	3	main
toimetust	doc_740091150997_item	2835042	et	4	main
üles	doc_740091150997_item	2835044	et	3	main
ent	doc_740091150997_item	2835047	et	3	main
tasuta	doc_740091150997_item	2835079	et	4	main
läkski	doc_740091150997_item	2835083	et	3	main
ja	doc_740091150997_item	2835091	et	3	main
on	doc_740091150997_item	2835099	et	4	main
normaalne	doc_740091150997_item	2835101	et	3	main
mihkel	doc_740091150997_item	2835104	et	3	main
just	doc_740091150997_item	2835112	et	3	main
hästi	doc_740091150997_item	2835114	et	3	main
ajal	doc_740091150997_item	2835118	et	4	main
inimestega	doc_740091150997_item	2835120	et	3	main
on	doc_740091150997_item	2835132	et	4	main
teise	doc_740091150997_item	2835155	et	4	main
beasley	doc_740091150997_item	2835158	et	4	main
vaja	doc_740091150997_item	2835161	et	4	main
selgus	doc_740091150997_item	2835163	et	4	main
mõtete	doc_740091150997_item	2835174	et	3	main
abil	doc_740091150997_item	2835176	et	4	main
muidugi	doc_740091150997_item	2835181	et	4	main
lollikest	doc_740091150997_item	2835193	et	4	main
maksa	doc_740091150997_item	2835199	et	4	main
mingi	doc_740091150997_item	2835205	et	4	main
anne	doc_740091150997_item	2835206	et	4	main
paista	doc_740091150997_item	2835215	et	4	main
saada	doc_740091150997_item	2835219	et	4	main
välise	doc_740091150997_item	2835227	et	4	main
alusel	doc_740091150997_item	2835231	et	4	main
uuringufirma	doc_740091150997_item	2835233	et	4	main
oma	doc_740091150997_item	2835237	et	4	main
reegleid	doc_740091150997_item	2835240	et	3	main
et	doc_740091150997_item	2835263	et	3	main
inimene	doc_740091150997_item	2835264	et	3	main
oma	doc_740091150997_item	2835265	et	4	main
põhiolemuselt	doc_740091150997_item	2835266	et	3	main
eriti	doc_740091150997_item	2835267	et	3	main
saab	doc_740091150997_item	2835270	et	3	main
tugevaid	doc_740091150997_item	2835273	et	4	main
arendada	doc_740091150997_item	2835275	et	3	main
emotsionaalset	doc_740091150997_item	2835282	et	3	main
aru	doc_740091150997_item	2835293	et	4	main
saada	doc_740091150997_item	2835294	et	4	main
edu	doc_740091150997_item	2835304	et	4	main
väidab	doc_740091150997_item	2835307	et	3	main
ja	doc_740091150997_item	2835315	et	3	main
ratsionaalselt	doc_740091150997_item	2835321	et	4	main
on	doc_740091150997_item	2835328	et	4	main
isikliku	doc_740091150997_item	2835336	et	3	main
tegevusega	doc_740091150997_item	2835337	et	4	main
muutub	doc_740091150997_item	2835343	et	3	main
järjest	doc_740091150997_item	2835347	et	4	main
unikaalsuses	doc_740091150997_item	2835359	et	4	main
normaalne	doc_740091150997_item	2835360	et	3	main
saada	doc_740091150997_item	2835365	et	4	main
traditsioonilise	doc_740091150997_item	2835368	et	4	main
loomulikult	doc_740091150997_item	2835378	et	4	main
hõlbustab	doc_740091150997_item	2835379	et	3	main
see	doc_740091150997_item	2835380	et	3	main
on	doc_740091150997_item	2835383	et	4	main
maailmas	doc_740091150997_item	2835385	et	3	main
olulisem	doc_740091150997_item	2835387	et	4	main
d	doc_740091150997_item	2835126	et	4	main
simaki	doc_740091150997_item	2835127	et	4	main
tegelane	doc_740091150997_item	2835134	et	3	main
keda	doc_740091150997_item	2835139	et	4	main
üldiselt	doc_740091150997_item	2835140	et	4	main
aga	doc_740091150997_item	2835146	et	3	main
kui	doc_740091150997_item	2835147	et	3	main
tema	doc_740091150997_item	2835148	et	4	main
hoovist	doc_740091150997_item	2835151	et	4	main
avanes	doc_740091150997_item	2835152	et	3	main
ootamatult	doc_740091150997_item	2835153	et	4	main
uks	doc_740091150997_item	2835154	et	3	main
vägagi	doc_740091150997_item	2835160	et	3	main
nimelt	doc_740091150997_item	2835162	et	4	main
valdab	doc_740091150997_item	2835166	et	3	main
tema	doc_740091150997_item	2835169	et	4	main
suutis	doc_740091150997_item	2835171	et	3	main
külalistega	doc_740091150997_item	2835173	et	4	main
varem	doc_740091150997_item	2835182	et	4	main
ka	doc_740091150997_item	2835183	et	3	main
väitnud	doc_740091150997_item	2835184	et	4	main
et	doc_740091150997_item	2835185	et	3	main
suudab	doc_740091150997_item	2835186	et	3	main
koera	doc_740091150997_item	2835187	et	4	main
lugeda	doc_740091150997_item	2835189	et	3	main
aga	doc_740091150997_item	2835190	et	3	main
kes	doc_740091150997_item	2835191	et	4	main
siis	doc_740091150997_item	2835192	et	3	main
on	doc_740091150997_item	2835204	et	4	main
olemas	doc_740091150997_item	2835207	et	4	main
ka	doc_740091150997_item	2835208	et	3	main
siis	doc_740091150997_item	2835209	et	3	main
kui	doc_740091150997_item	2835210	et	3	main
see	doc_740091150997_item	2835211	et	3	main
eelarvamustest	doc_740091150997_item	2835216	et	4	main
üle	doc_740091150997_item	2835224	et	3	main
silmatorkava	doc_740091150997_item	2835229	et	3	main
mida	doc_740091150997_item	2835242	et	4	main
inimest	doc_740091150997_item	2835253	et	3	main
ning	doc_740091150997_item	2835256	et	3	main
annet	doc_740091150997_item	2835258	et	4	main
juhtida	doc_740091150997_item	2835259	et	4	main
samuti	doc_740091150997_item	2835260	et	3	main
väidavad	doc_740091150997_item	2835261	et	3	main
nad	doc_740091150997_item	2835262	et	3	main
muutu	doc_740091150997_item	2835269	et	4	main
külgi	doc_740091150997_item	2835274	et	4	main
inimene	doc_740091150997_item	2835276	et	3	main
oma	doc_740091150997_item	2835295	et	4	main
emotsionaalselt	doc_740091150997_item	2835309	et	4	main
on	doc_740091150997_item	2835334	et	4	main
neid	doc_740091150997_item	2835338	et	4	main
inimene	doc_740091150997_item	2835346	et	3	main
halvemini	doc_740091150997_item	2835348	et	4	main
mis	doc_740091150997_item	2835350	et	4	main
kogu	doc_740091150997_item	2835357	et	4	main
stereotüüpidest	doc_740091150997_item	2835366	et	3	main
sisse	doc_740091150997_item	2835375	et	4	main
järjest	doc_740091150997_item	2835386	et	4	main
roll	doc_740091150997_item	2835388	et	3	main
nüüdisajal	doc_740091150997_item	2835389	et	3	main
võikski	doc_740091150997_item	2835390	et	4	main
eesmärgiks	doc_740091150997_item	2835391	et	3	main
selle	doc_740091150997_item	2835393	et	4	main
või	doc_740091150997_item	2835399	et	4	main
teist	doc_740091150997_item	2835400	et	4	main
inimest	doc_740091150997_item	2835401	et	3	main
otsustada	doc_740091150997_item	2835222	et	3	main
kõigile	doc_740091150997_item	2835228	et	4	main
gallup	doc_740091150997_item	2835234	et	4	main
raamatus	doc_740091150997_item	2835238	et	4	main
parimad	doc_740091150997_item	2835244	et	4	main
et	doc_740091150997_item	2835248	et	3	main
hea	doc_740091150997_item	2835249	et	4	main
juht	doc_740091150997_item	2835250	et	3	main
oskab	doc_740091150997_item	2835251	et	3	main
tunda	doc_740091150997_item	2835255	et	3	main
ei	doc_740091150997_item	2835268	et	4	main
tema	doc_740091150997_item	2835272	et	4	main
eq-d	doc_740091150997_item	2835284	et	4	main
1995	doc_740091150997_item	2835287	et	2	main
goleman	doc_740091150997_item	2835291	et	4	main
võime	doc_740091150997_item	2835292	et	4	main
ja	doc_740091150997_item	2835297	et	3	main
tundub	doc_740091150997_item	2835324	et	3	main
normide	doc_740091150997_item	2835326	et	3	main
veelgi	doc_740091150997_item	2835332	et	4	main
nihutada	doc_740091150997_item	2835341	et	3	main
nii	doc_740091150997_item	2835342	et	3	main
piiritletavaks	doc_740091150997_item	2835349	et	4	main
hea	doc_740091150997_item	2835353	et	4	main
iga	doc_740091150997_item	2835354	et	4	main
inimene	doc_740091150997_item	2835355	et	3	main
see	doc_740091150997_item	2835361	et	3	main
teadmine	doc_740091150997_item	2835362	et	4	main
aitab	doc_740091150997_item	2835363	et	3	main
mõttelaadi	doc_740091150997_item	2835369	et	4	main
on	doc_740091150997_item	2835371	et	4	main
ja	doc_740091150997_item	2835377	et	3	main
suhtlemist	doc_740091150997_item	2835381	et	4	main
tutvustades	doc_740091150997_item	2835402	et	3	main
rahulolevalt	doc_740091150997_item	2835403	et	4	main
nentida	doc_740091150997_item	2835404	et	3	main
tuttavaks	doc_740091150997_item	2835406	et	4	main
inimene	doc_740091150997_item	2835408	et	3	main
oma	doc_740091150997_item	2835281	et	4	main
intelligentsust	doc_740091150997_item	2835283	et	4	main
millega	doc_740091150997_item	2835285	et	3	main
daniel	doc_740091150997_item	2835290	et	4	main
tunnetest	doc_740091150997_item	2835296	et	3	main
soovitud	doc_740091150997_item	2835299	et	4	main
oluline	doc_740091150997_item	2835303	et	4	main
goleman	doc_740091150997_item	2835306	et	4	main
inimesed	doc_740091150997_item	2835311	et	3	main
kui	doc_740091150997_item	2835317	et	3	main
intelligentsed	doc_740091150997_item	2835322	et	3	main
et	doc_740091150997_item	2835325	et	3	main
piirid	doc_740091150997_item	2835327	et	3	main
veelgi	doc_740091150997_item	2835339	et	4	main
tegelikult	doc_740091150997_item	2835352	et	4	main
oma	doc_740091150997_item	2835358	et	4	main
mis	doc_740091150997_item	2835367	et	4	main
järgi	doc_740091150997_item	2835370	et	4	main
ikka	doc_740091150997_item	2835372	et	4	main
veel	doc_740091150997_item	2835373	et	4	main
paljudesse	doc_740091150997_item	2835374	et	3	main
nüüdisaja	doc_740091150997_item	2835384	et	3	main
seada	doc_740091150997_item	2835392	et	3	main
et	doc_740091150997_item	2835394	et	3	main
võib	doc_740091150997_item	2835396	et	3	main
vaadates	doc_740091150997_item	2835398	et	3	main
normaalne	doc_740091150997_item	2835407	et	3	main
inimesed	doc_740091150997_item	2835323	et	3	main
avardunud	doc_740091150997_item	2835329	et	4	main
ja	doc_740091150997_item	2835330	et	3	main
avarduvad	doc_740091150997_item	2835331	et	4	main
vahva	doc_740091150997_item	2835333	et	4	main
oma	doc_740091150997_item	2835335	et	4	main
kaugemale	doc_740091150997_item	2835340	et	4	main
mõiste	doc_740091150997_item	2835344	et	4	main
normaalne	doc_740091150997_item	2835345	et	3	main
ongi	doc_740091150997_item	2835351	et	4	main
on	doc_740091150997_item	2835356	et	4	main
üle	doc_740091150997_item	2835364	et	3	main
juurdunud	doc_740091150997_item	2835376	et	4	main
milel	doc_740091150997_item	2835382	et	4	main
igaüks	doc_740091150997_item	2835395	et	3	main
peeglisse	doc_740091150997_item	2835397	et	4	main
saage	doc_740091150997_item	2835405	et	4	main
tulenevalt	doc_740091150999_item	2835923	et	4	main
see	doc_740091150999_item	2835926	et	3	main
kõlapinda	doc_740091150999_item	2835927	et	4	main
kas	doc_740091150999_item	2835931	et	3	main
on	doc_740091150999_item	2835932	et	4	main
saame	doc_740091150999_item	2835946	et	4	main
vaadelda	doc_740091150999_item	2835947	et	4	main
millegagi	doc_740091150999_item	2835950	et	4	main
juhul	doc_740091150999_item	2835952	et	3	main
meelest	doc_740091150999_item	2835954	et	4	main
tuleb	doc_740091150999_item	2835955	et	3	main
siiski	doc_740091150999_item	2835956	et	4	main
on	doc_740091150999_item	2835982	et	4	main
ikka	doc_740091150999_item	2835985	et	4	main
omakorda	doc_740091150999_item	2835996	et	3	main
oma	doc_740091150999_item	2835997	et	4	main
ühiskolnd	doc_740091150999_item	2836003	et	4	main
areneb	doc_740091150999_item	2836004	et	3	main
me	doc_740091150999_item	2836011	et	4	main
oma	doc_740091150999_item	2836014	et	4	main
võtame	doc_740091150999_item	2836017	et	3	main
mis	doc_740091150999_item	2836019	et	4	main
teemal	doc_740091150999_item	2835921	et	3	main
leidnud	doc_740091150999_item	2835929	et	4	main
või	doc_740091150999_item	2835935	et	4	main
antud	doc_740091150999_item	2835939	et	4	main
võrdluses	doc_740091150999_item	2835949	et	3	main
minu	doc_740091150999_item	2835953	et	3	main
essee	doc_740091150999_item	2835899	et	4	main
kuidas	doc_740091150999_item	2835900	et	3	main
on	doc_740091150999_item	2835901	et	4	main
mõelnud	doc_740091150999_item	2835922	et	4	main
sellest	doc_740091150999_item	2835924	et	4	main
kuidas	doc_740091150999_item	2835925	et	3	main
õige	doc_740091150999_item	2835934	et	4	main
otstarbekas	doc_740091150999_item	2835936	et	4	main
sellise	doc_740091150999_item	2835944	et	4	main
ainult	doc_740091150999_item	2835948	et	4	main
naise	doc_740091150999_item	2835959	et	3	main
kes	doc_740091150999_item	2835992	et	4	main
mehe	doc_740091150999_item	2835902	et	3	main
roll	doc_740091150999_item	2835903	et	3	main
muutunud	doc_740091150999_item	2835904	et	4	main
viimase	doc_740091150999_item	2835905	et	3	main
20	doc_740091150999_item	2835906	et	2	main
aastaga	doc_740091150999_item	2835907	et	3	main
seda	doc_740091150999_item	2835908	et	3	main
teemat	doc_740091150999_item	2835909	et	3	main
on	doc_740091150999_item	2835910	et	4	main
ajakirjanduses	doc_740091150999_item	2835911	et	3	main
käsitletud	doc_740091150999_item	2835912	et	4	main
küll	doc_740091150999_item	2835913	et	4	main
ja	doc_740091150999_item	2835914	et	3	main
küll	doc_740091150999_item	2835915	et	4	main
ning	doc_740091150999_item	2835916	et	3	main
olen	doc_740091150999_item	2835917	et	3	main
isegi	doc_740091150999_item	2835918	et	4	main
palju	doc_740091150999_item	2835919	et	4	main
sellel	doc_740091150999_item	2835920	et	4	main
on	doc_740091150999_item	2835928	et	4	main
kuid	doc_740091150999_item	2835930	et	4	main
vaatenurgast	doc_740091150999_item	2835940	et	4	main
kuna	doc_740091150999_item	2835941	et	3	main
mehe	doc_740091150999_item	2835942	et	3	main
kui	doc_740091150999_item	2835943	et	3	main
rohkem	doc_740091150999_item	2835957	et	4	main
esile	doc_740091150999_item	2835958	et	3	main
sellise	doc_740091150999_item	2835960	et	4	main
rolli	doc_740091150999_item	2835961	et	4	main
sees	doc_740091150999_item	2835984	et	4	main
kasvatatud	doc_740091150999_item	2835995	et	4	main
ning	doc_740091150999_item	2836005	et	3	main
inimene	doc_740091150999_item	2836006	et	3	main
paratamatult	doc_740091150999_item	2836007	et	4	main
areneb	doc_740091150999_item	2836008	et	3	main
vaja	doc_740091150999_item	2836027	et	4	main
teha	doc_740091150999_item	2836028	et	3	main
just	doc_740091150999_item	2836029	et	3	main
alati	doc_740091150999_item	2836036	et	4	main
tööd	doc_740091150999_item	2836037	et	4	main
kes	doc_740091150999_item	2836047	et	4	main
ning	doc_740091150999_item	2836050	et	3	main
toidu	doc_740091150999_item	2836052	et	3	main
on	doc_740091150999_item	2836054	et	4	main
üldse	doc_740091150999_item	2835933	et	3	main
peatuda	doc_740091150999_item	2835937	et	3	main
sellel	doc_740091150999_item	2835938	et	4	main
rolli	doc_740091150999_item	2835945	et	4	main
antud	doc_740091150999_item	2835951	et	4	main
ajas	doc_740091150999_item	2835963	et	4	main
ja	doc_740091150999_item	2835964	et	3	main
ühiskonnas	doc_740091150999_item	2835965	et	4	main
seega	doc_740091150999_item	2835966	et	4	main
kas	doc_740091150999_item	2835967	et	3	main
mehe	doc_740091150999_item	2835968	et	3	main
roll	doc_740091150999_item	2835969	et	3	main
on	doc_740091150999_item	2835970	et	4	main
nii	doc_740091150999_item	2835971	et	3	main
väga	doc_740091150999_item	2835972	et	3	main
üldse	doc_740091150999_item	2835973	et	3	main
muutunud	doc_740091150999_item	2835974	et	4	main
tegelikult	doc_740091150999_item	2835975	et	4	main
peab	doc_740091150999_item	2835976	et	4	main
nentima	doc_740091150999_item	2835977	et	3	main
et	doc_740091150999_item	2835978	et	3	main
erinevate	doc_740091150999_item	2835979	et	4	main
põlvkondade	doc_740091150999_item	2835980	et	3	main
meestel	doc_740091150999_item	2835981	et	4	main
muutumine	doc_740091150999_item	2835962	et	4	main
vahe	doc_740091150999_item	2835983	et	4	main
küll	doc_740091150999_item	2835986	et	4	main
kui	doc_740091150999_item	2835987	et	3	main
võrrelda	doc_740091150999_item	2835988	et	4	main
isasid	doc_740091150999_item	2835989	et	3	main
ja	doc_740091150999_item	2835990	et	3	main
poegasid	doc_740091150999_item	2835991	et	3	main
vanemate	doc_740091150999_item	2835998	et	4	main
koos	doc_740091150999_item	2836009	et	4	main
kõik	doc_740091150999_item	2836012	et	4	main
rollid	doc_740091150999_item	2836018	et	3	main
tööd	doc_740091150999_item	2836024	et	4	main
ühiskonnas	doc_740091150999_item	2836033	et	4	main
mehed	doc_740091150999_item	2836034	et	3	main
on	doc_740091150999_item	2836035	et	4	main
peale	doc_740091150999_item	2836042	et	4	main
kaitsevad	doc_740091150999_item	2836048	et	4	main
nii	doc_740091150999_item	2836058	et	3	main
hoolitseda	doc_740091150999_item	2836071	et	3	main
hinge	doc_740091150999_item	2836073	et	4	main
mehe	doc_740091150999_item	2836076	et	3	main
eest	doc_740091150999_item	2836078	et	4	main
on	doc_740091150999_item	2836084	et	4	main
mõningased	doc_740091150999_item	2836086	et	3	main
ja	doc_740091150999_item	2836088	et	3	main
omadused	doc_740091150999_item	2836090	et	4	main
maskuliinseteks	doc_740091150999_item	2836091	et	3	main
mõtlemine	doc_740091150999_item	2836097	et	4	main
ning	doc_740091150999_item	2836098	et	3	main
tooks	doc_740091150999_item	2836100	et	3	main
ka	doc_740091150999_item	2836102	et	3	main
aastasadu	doc_740091150999_item	2836121	et	4	main
rollide	doc_740091150999_item	2836140	et	3	main
ja	doc_740091150999_item	2836141	et	3	main
nii	doc_740091150999_item	2836150	et	3	main
ning	doc_740091150999_item	2836160	et	3	main
mehe	doc_740091150999_item	2836163	et	3	main
ja	doc_740091150999_item	2836178	et	3	main
väita	doc_740091150999_item	2836181	et	4	main
vastu	doc_740091150999_item	2836183	et	3	main
muutuvad	doc_740091150999_item	2836227	et	4	main
kui	doc_740091150999_item	2836232	et	3	main
naised	doc_740091150999_item	2836234	et	3	main
ühiskond	doc_740091150999_item	2836236	et	3	main
on	doc_740091150999_item	2836241	et	4	main
ja	doc_740091150999_item	2836245	et	3	main
ehk	doc_740091150999_item	2836255	et	3	main
järgivad	doc_740091150999_item	2836275	et	4	main
ja	doc_740091150999_item	2836297	et	3	main
nende	doc_740091150999_item	2836304	et	4	main
enam	doc_740091150999_item	2836307	et	4	main
nii	doc_740091150999_item	2836308	et	3	main
polariseeritud	doc_740091150999_item	2836309	et	3	main
muutuste	doc_740091150999_item	2836314	et	4	main
hoopis	doc_740091150999_item	2836320	et	3	main
läheb	doc_740091150999_item	2836326	et	3	main
perele	doc_740091150999_item	2836328	et	3	main
käiku	doc_740091150999_item	2836341	et	4	main
ja	doc_740091150999_item	2836348	et	3	main
meeste	doc_740091150999_item	2836360	et	4	main
tulevate	doc_740091150999_item	2836370	et	4	main
võib	doc_740091150999_item	2836373	et	3	main
sest	doc_740091150999_item	2836380	et	4	main
aga	doc_740091150999_item	2836387	et	3	main
võib	doc_740091150999_item	2836388	et	3	main
see	doc_740091150999_item	2836391	et	3	main
käib	doc_740091150999_item	2836395	et	3	main
edasi	doc_740091150999_item	2836422	et	3	main
kui	doc_740091150999_item	2836445	et	3	main
hämaruses	doc_740091150999_item	2836449	et	4	main
toovad	doc_740091150999_item	2836480	et	4	main
raha	doc_740091150999_item	2836481	et	4	main
koju	doc_740091150999_item	2836482	et	3	main
ning	doc_740091150999_item	2836483	et	3	main
pealegi	doc_740091150999_item	2836487	et	4	main
kes	doc_740091150999_item	2836489	et	4	main
lapsi	doc_740091150999_item	2836492	et	4	main
enda	doc_740091150999_item	2836501	et	4	main
ja	doc_740091150999_item	2836502	et	3	main
rahulolu	doc_740091150999_item	2836505	et	4	main
rahuldust	doc_740091150999_item	2836510	et	4	main
on	doc_740091150999_item	2835993	et	4	main
üles	doc_740091150999_item	2835994	et	3	main
muutuvad	doc_740091150999_item	2836001	et	4	main
kuna	doc_740091150999_item	2836002	et	3	main
ühiskonna	doc_740091150999_item	2836015	et	4	main
peale	doc_740091150999_item	2836020	et	4	main
teeme	doc_740091150999_item	2836022	et	3	main
sellelel	doc_740091150999_item	2836030	et	4	main
momendil	doc_740091150999_item	2836031	et	3	main
selles	doc_740091150999_item	2836032	et	4	main
teinud	doc_740091150999_item	2836038	et	4	main
juba	doc_740091150999_item	2836039	et	3	main
aegade	doc_740091150999_item	2836040	et	3	main
olnud	doc_740091150999_item	2836045	et	4	main
kodu	doc_740091150999_item	2836049	et	4	main
hangivad	doc_740091150999_item	2836051	et	3	main
traditsiooniline	doc_740091150999_item	2836056	et	4	main
roll	doc_740091150999_item	2836057	et	3	main
naise	doc_740091150999_item	2836060	et	3	main
kodusoojust	doc_740091150999_item	2836070	et	4	main
eest	doc_740091150999_item	2836074	et	4	main
samuti	doc_740091150999_item	2836075	et	3	main
hinge	doc_740091150999_item	2836077	et	4	main
ma	doc_740091150999_item	2836079	et	3	main
nõus	doc_740091150999_item	2836082	et	4	main
maskuliinsed	doc_740091150999_item	2836087	et	3	main
feminiinsed	doc_740091150999_item	2836089	et	3	main
oleks	doc_740091150999_item	2836093	et	3	main
juhtimine	doc_740091150999_item	2836095	et	4	main
aidanud	doc_740091150999_item	2836126	et	4	main
toita	doc_740091150999_item	2836134	et	4	main
märgata	doc_740091150999_item	2836145	et	4	main
teevad	doc_740091150999_item	2836153	et	3	main
naisele	doc_740091150999_item	2836155	et	3	main
omistatud	doc_740091150999_item	2836156	et	4	main
töid	doc_740091150999_item	2836157	et	3	main
ja	doc_740091150999_item	2836158	et	3	main
rolle	doc_740091150999_item	2836159	et	3	main
juhivad	doc_740091150999_item	2836165	et	3	main
kraanat	doc_740091150999_item	2836169	et	3	main
rakendavad	doc_740091150999_item	2836170	et	4	main
ning	doc_740091150999_item	2836171	et	3	main
siinkohal	doc_740091150999_item	2836179	et	3	main
võib	doc_740091150999_item	2836180	et	3	main
ning	doc_740091150999_item	2836182	et	3	main
vaielda	doc_740091150999_item	2836184	et	4	main
poolt	doc_740091150999_item	2835999	et	4	main
rollid	doc_740091150999_item	2836000	et	3	main
ühiskonnaga	doc_740091150999_item	2836010	et	4	main
oleme	doc_740091150999_item	2836013	et	3	main
nägu	doc_740091150999_item	2836016	et	4	main
sunnitakse	doc_740091150999_item	2836021	et	4	main
seda	doc_740091150999_item	2836023	et	3	main
on	doc_740091150999_item	2836043	et	4	main
nad	doc_740091150999_item	2836044	et	3	main
lapsi	doc_740091150999_item	2836065	et	4	main
teha	doc_740091150999_item	2836066	et	3	main
süüa	doc_740091150999_item	2836067	et	3	main
ning	doc_740091150999_item	2836068	et	3	main
hoida	doc_740091150999_item	2836069	et	3	main
kodu	doc_740091150999_item	2836072	et	4	main
olemas	doc_740091150999_item	2836085	et	4	main
näiteks	doc_740091150999_item	2836094	et	4	main
on	doc_740091150999_item	2836123	et	4	main
mida	doc_740091150999_item	2836025	et	4	main
on	doc_740091150999_item	2836026	et	4	main
algusest	doc_740091150999_item	2836041	et	4	main
need	doc_740091150999_item	2836046	et	3	main
see	doc_740091150999_item	2836053	et	3	main
mehe	doc_740091150999_item	2836055	et	3	main
nagu	doc_740091150999_item	2836059	et	3	main
traditsiooniline	doc_740091150999_item	2836061	et	4	main
roll	doc_740091150999_item	2836062	et	3	main
olen	doc_740091150999_item	2836080	et	3	main
täiesti	doc_740091150999_item	2836081	et	3	main
et	doc_740091150999_item	2836083	et	3	main
omadusteks	doc_740091150999_item	2836092	et	4	main
loogiline	doc_740091150999_item	2836096	et	4	main
kinnisuse	doc_740091150999_item	2836103	et	3	main
kui	doc_740091150999_item	2836104	et	3	main
hingeomaduse	doc_740091150999_item	2836105	et	4	main
mis	doc_740091150999_item	2836106	et	4	main
meeste	doc_740091150999_item	2836107	et	4	main
puhul	doc_740091150999_item	2836108	et	4	main
paistab	doc_740091150999_item	2836109	et	3	main
levinum	doc_740091150999_item	2836110	et	4	main
olevat	doc_740091150999_item	2836111	et	4	main
eks	doc_740091150999_item	2836112	et	3	main
need	doc_740091150999_item	2836113	et	3	main
omadused	doc_740091150999_item	2836114	et	4	main
ongi	doc_740091150999_item	2836115	et	4	main
kujunenud	doc_740091150999_item	2836116	et	4	main
läbi	doc_740091150999_item	2836117	et	4	main
tegevuste	doc_740091150999_item	2836118	et	4	main
mida	doc_740091150999_item	2836119	et	4	main
mehed	doc_740091150999_item	2836120	et	3	main
oma	doc_740091150999_item	2836128	et	4	main
perekonda	doc_740091150999_item	2836133	et	4	main
ja	doc_740091150999_item	2836135	et	3	main
selles	doc_740091150999_item	2836137	et	4	main
on	doc_740091150999_item	2836139	et	4	main
omaduste	doc_740091150999_item	2836142	et	4	main
hägustumist	doc_740091150999_item	2836143	et	4	main
piirjooned	doc_740091150999_item	2836147	et	3	main
mehed	doc_740091150999_item	2836152	et	3	main
traditsiooniliselt	doc_740091150999_item	2836154	et	4	main
näiteks	doc_740091150999_item	2836166	et	4	main
oma	doc_740091150999_item	2836173	et	4	main
juhtimisoskusi	doc_740091150999_item	2836174	et	3	main
ning	doc_740091150999_item	2836175	et	3	main
loogilist	doc_740091150999_item	2836176	et	4	main
ja	doc_740091150999_item	2836221	et	3	main
ka	doc_740091150999_item	2836233	et	3	main
on	doc_740091150999_item	2836237	et	4	main
muutunud	doc_740091150999_item	2836238	et	4	main
avatumaks	doc_740091150999_item	2836239	et	4	main
muutunud	doc_740091150999_item	2836242	et	4	main
selle	doc_740091150999_item	2836247	et	4	main
võetakse	doc_740091150999_item	2836249	et	3	main
nende	doc_740091150999_item	2836272	et	4	main
isad	doc_740091150999_item	2836273	et	3	main
aga	doc_740091150999_item	2836274	et	3	main
traditsioonilisemat	doc_740091150999_item	2836276	et	4	main
võib-olla	doc_740091150999_item	2836279	et	3	main
neid	doc_740091150999_item	2836294	et	4	main
ju	doc_740091150999_item	2836295	et	3	main
küttima	doc_740091150999_item	2836296	et	3	main
on	doc_740091150999_item	2836063	et	4	main
kasvatada	doc_740091150999_item	2836064	et	3	main
ma	doc_740091150999_item	2836099	et	3	main
välja	doc_740091150999_item	2836101	et	4	main
teinud	doc_740091150999_item	2836122	et	4	main
neil	doc_740091150999_item	2836127	et	4	main
üleannet	doc_740091150999_item	2836129	et	4	main
edukalt	doc_740091150999_item	2836130	et	4	main
täita	doc_740091150999_item	2836131	et	4	main
katta	doc_740091150999_item	2836136	et	3	main
suhtes	doc_740091150999_item	2836138	et	4	main
küll	doc_740091150999_item	2836146	et	4	main
enam	doc_740091150999_item	2836149	et	4	main
teevad	doc_740091150999_item	2836162	et	3	main
töid	doc_740091150999_item	2836164	et	3	main
ettevõtet	doc_740091150999_item	2836167	et	3	main
arendavad	doc_740091150999_item	2836172	et	4	main
mõtlemist	doc_740091150999_item	2836177	et	4	main
feminiinsetest	doc_740091150999_item	2836222	et	3	main
koos	doc_740091150999_item	2836224	et	4	main
ka	doc_740091150999_item	2836228	et	3	main
nii	doc_740091150999_item	2836230	et	3	main
naised	doc_740091150999_item	2836246	et	3	main
sees	doc_740091150999_item	2836248	et	4	main
vastu	doc_740091150999_item	2836250	et	3	main
mida	doc_740091150999_item	2836252	et	4	main
järgima	doc_740091150999_item	2836278	et	3	main
õige	doc_740091150999_item	2836281	et	4	main
mida	doc_740091150999_item	2836283	et	4	main
kasutada	doc_740091150999_item	2836284	et	3	main
kuna	doc_740091150999_item	2836285	et	3	main
nendes	doc_740091150999_item	2836286	et	4	main
võitlema	doc_740091150999_item	2836298	et	3	main
veel	doc_740091150999_item	2836302	et	4	main
aga	doc_740091150999_item	2836306	et	3	main
ühiskonnas	doc_740091150999_item	2836310	et	4	main
nad	doc_740091150999_item	2836317	et	3	main
see	doc_740091150999_item	2836324	et	3	main
tunnistajaks	doc_740091150999_item	2836335	et	4	main
võtavad	doc_740091150999_item	2836336	et	3	main
seda	doc_740091150999_item	2836337	et	3	main
kui	doc_740091150999_item	2836338	et	3	main
normaalset	doc_740091150999_item	2836339	et	3	main
asjade	doc_740091150999_item	2836340	et	3	main
kasvavad	doc_740091150999_item	2836342	et	4	main
on	doc_740091150999_item	2836365	et	4	main
muutunud	doc_740091150999_item	2836366	et	4	main
avatumaks	doc_740091150999_item	2836367	et	4	main
dünaamilisemad	doc_740091150999_item	2836385	et	4	main
tuleneb	doc_740091150999_item	2836390	et	3	main
olekusvõitlus	doc_740091150999_item	2836397	et	4	main
need	doc_740091150999_item	2836124	et	3	main
on	doc_740091150999_item	2836125	et	4	main
aidanud	doc_740091150999_item	2836132	et	4	main
ühiskonnas	doc_740091150999_item	2836144	et	4	main
pole	doc_740091150999_item	2836148	et	3	main
selged	doc_740091150999_item	2836151	et	3	main
naised	doc_740091150999_item	2836161	et	3	main
või	doc_740091150999_item	2836168	et	4	main
laialt	doc_740091150999_item	2836185	et	4	main
arvamisele	doc_740091150999_item	2836187	et	4	main
levinud	doc_740091150999_item	2836186	et	4	main
et	doc_740091150999_item	2836188	et	3	main
naistel	doc_740091150999_item	2836189	et	3	main
puudub	doc_740091150999_item	2836190	et	3	main
igasugune	doc_740091150999_item	2836191	et	3	main
loogiline	doc_740091150999_item	2836192	et	4	main
mõtlemine	doc_740091150999_item	2836193	et	4	main
ja	doc_740091150999_item	2836194	et	3	main
juhtimisoskus	doc_740091150999_item	2836195	et	3	main
neil	doc_740091150999_item	2836196	et	4	main
pole	doc_740091150999_item	2836197	et	3	main
lihtsalt	doc_740091150999_item	2836198	et	4	main
olnud	doc_740091150999_item	2836199	et	4	main
võimalust	doc_740091150999_item	2836200	et	3	main
neid	doc_740091150999_item	2836201	et	4	main
rakendada	doc_740091150999_item	2836202	et	3	main
ja	doc_740091150999_item	2836203	et	3	main
arendada	doc_740091150999_item	2836204	et	3	main
nende	doc_740091150999_item	2836205	et	4	main
roll	doc_740091150999_item	2836207	et	3	main
on	doc_740091150999_item	2836208	et	4	main
traditsiooniline	doc_740091150999_item	2836206	et	4	main
nõudnud	doc_740091150999_item	2836209	et	4	main
teisi	doc_740091150999_item	2836210	et	4	main
omadusi	doc_740091150999_item	2836211	et	4	main
järelikult	doc_740091150999_item	2836212	et	3	main
ma	doc_740091150999_item	2836213	et	3	main
polegi	doc_740091150999_item	2836214	et	3	main
kindel	doc_740091150999_item	2836215	et	3	main
kui	doc_740091150999_item	2836216	et	3	main
tõsiselt	doc_740091150999_item	2836217	et	4	main
võtta	doc_740091150999_item	2836218	et	3	main
juttu	doc_740091150999_item	2836219	et	4	main
maskuliinsetest	doc_740091150999_item	2836220	et	3	main
omadustest	doc_740091150999_item	2836223	et	4	main
meie	doc_740091150999_item	2836235	et	4	main
poleks	doc_740091150999_item	2836254	et	3	main
juletud	doc_740091150999_item	2836256	et	4	main
võtta	doc_740091150999_item	2836257	et	3	main
tänapäeva	doc_740091150999_item	2836258	et	4	main
pojad	doc_740091150999_item	2836259	et	4	main
on	doc_740091150999_item	2836260	et	4	main
ehk	doc_740091150999_item	2836261	et	3	main
altimad	doc_740091150999_item	2836262	et	4	main
muudatustele	doc_740091150999_item	2836263	et	3	main
kuna	doc_740091150999_item	2836264	et	3	main
nad	doc_740091150999_item	2836265	et	3	main
on	doc_740091150999_item	2836266	et	4	main
ise	doc_740091150999_item	2836267	et	4	main
üles	doc_740091150999_item	2836268	et	3	main
kasvanud	doc_740091150999_item	2836269	et	4	main
muutuste	doc_740091150999_item	2836270	et	4	main
ühiskonna	doc_740091150999_item	2836225	et	4	main
muutumisega	doc_740091150999_item	2836226	et	4	main
inimesed	doc_740091150999_item	2836229	et	3	main
mehed	doc_740091150999_item	2836231	et	3	main
avanemaks	doc_740091150999_item	2836240	et	3	main
ka	doc_740091150999_item	2836243	et	3	main
mehed	doc_740091150999_item	2836244	et	3	main
rolle	doc_740091150999_item	2836251	et	3	main
varasemalt	doc_740091150999_item	2836253	et	4	main
tuultes	doc_740091150999_item	2836271	et	3	main
joont	doc_740091150999_item	2836277	et	3	main
polegi	doc_740091150999_item	2836280	et	3	main
on	doc_740091150999_item	2836287	et	4	main
juurdunud	doc_740091150999_item	2836289	et	4	main
eelnevate	doc_740091150999_item	2836290	et	4	main
põlvkondade	doc_740091150999_item	2836291	et	3	main
kasvatusviis	doc_740091150999_item	2836292	et	3	main
kasvatati	doc_740091150999_item	2836293	et	3	main
niimoodi	doc_740091150999_item	2836300	et	3	main
enam	doc_740091150999_item	2836311	et	4	main
on	doc_740091150999_item	2836316	et	4	main
et	doc_740091150999_item	2836319	et	3	main
ema	doc_740091150999_item	2836321	et	4	main
olla	doc_740091150999_item	2836323	et	3	main
tooma	doc_740091150999_item	2836331	et	3	main
ülesse	doc_740091150999_item	2836343	et	4	main
teadmisega	doc_740091150999_item	2836344	et	4	main
et	doc_740091150999_item	2836345	et	3	main
polegi	doc_740091150999_item	2836346	et	3	main
naiselikku	doc_740091150999_item	2836349	et	4	main
maskuliinseid	doc_740091150999_item	2836351	et	3	main
suur	doc_740091150999_item	2836355	et	3	main
meelest	doc_740091150999_item	2836358	et	4	main
ongi	doc_740091150999_item	2836359	et	4	main
see	doc_740091150999_item	2836362	et	3	main
nad	doc_740091150999_item	2836364	et	3	main
avatumaks	doc_740091150999_item	2836368	et	4	main
mõjude	doc_740091150999_item	2836371	et	3	main
olla	doc_740091150999_item	2836374	et	3	main
teene	doc_740091150999_item	2836379	et	4	main
on	doc_740091150999_item	2836381	et	4	main
sisemiselt	doc_740091150999_item	2836384	et	3	main
kohanemisvõimelisemad	doc_740091150999_item	2836386	et	4	main
ühiskonnast	doc_740091150999_item	2836393	et	4	main
saada	doc_740091150999_item	2836421	et	4	main
siiski	doc_740091150999_item	2836437	et	4	main
on	doc_740091150999_item	2836438	et	4	main
eksisteerivad	doc_740091150999_item	2836442	et	4	main
mehe	doc_740091150999_item	2836444	et	3	main
selle	doc_740091150999_item	2836460	et	4	main
vastu	doc_740091150999_item	2836461	et	3	main
võistlema	doc_740091150999_item	2836462	et	3	main
ainult	doc_740091150999_item	2836463	et	4	main
oma	doc_740091150999_item	2836469	et	4	main
mööda	doc_740091150999_item	2836471	et	4	main
las	doc_740091150999_item	2836472	et	4	main
mehed	doc_740091150999_item	2836473	et	3	main
või	doc_740091150999_item	2836493	et	4	main
siis	doc_740091150999_item	2836494	et	3	main
oma	doc_740091150999_item	2836503	et	4	main
mõnele	doc_740091150999_item	2836507	et	3	main
on	doc_740091150999_item	2836517	et	4	main
see	doc_740091150999_item	2836518	et	3	main
tänapäeval	doc_740091150999_item	2836519	et	3	main
aktsepteeritav	doc_740091150999_item	2836521	et	4	main
kui	doc_740091150999_item	2836529	et	3	main
parema	doc_740091150999_item	2836535	et	4	main
on	doc_740091150999_item	2836541	et	4	main
täiesti	doc_740091150999_item	2836544	et	3	main
on	doc_740091150999_item	2836550	et	4	main
ning	doc_740091150999_item	2836554	et	3	main
tundmise	doc_740091150999_item	2836564	et	4	main
ajast	doc_740091150999_item	2836570	et	4	main
polegi	doc_740091150999_item	2836576	et	3	main
peavad	doc_740091150999_item	2836591	et	4	main
mehed	doc_740091150999_item	2836593	et	3	main
naistele	doc_740091150999_item	2836596	et	3	main
on	doc_740091150999_item	2836626	et	4	main
tervitatav	doc_740091150999_item	2836629	et	4	main
nagu	doc_740091150999_item	2836631	et	3	main
rõõmustav	doc_740091150999_item	2836633	et	4	main
sõna	doc_740091150999_item	2836282	et	4	main
lihtsalt	doc_740091150999_item	2836288	et	4	main
kui	doc_740091150999_item	2836299	et	3	main
väljendada	doc_740091150999_item	2836301	et	3	main
ei	doc_740091150999_item	2836312	et	4	main
ühiskonnas	doc_740091150999_item	2836315	et	4	main
võib	doc_740091150999_item	2836322	et	3	main
kes	doc_740091150999_item	2836325	et	4	main
tööle	doc_740091150999_item	2836327	et	3	main
koju	doc_740091150999_item	2836329	et	3	main
töid	doc_740091150999_item	2836350	et	3	main
feminiinseid	doc_740091150999_item	2836353	et	3	main
edusamm	doc_740091150999_item	2836356	et	3	main
minu	doc_740091150999_item	2836357	et	3	main
puhul	doc_740091150999_item	2836361	et	4	main
et	doc_740091150999_item	2836363	et	3	main
väljaspoolt	doc_740091150999_item	2836369	et	4	main
eest	doc_740091150999_item	2836372	et	4	main
on	doc_740091150999_item	2836375	et	4	main
nende	doc_740091150999_item	2836377	et	4	main
ju	doc_740091150999_item	2836382	et	3	main
naised	doc_740091150999_item	2836383	et	3	main
olla	doc_740091150999_item	2836389	et	3	main
meie	doc_740091150999_item	2836392	et	4	main
püüelda	doc_740091150999_item	2836423	et	4	main
on	doc_740091150999_item	2836428	et	4	main
levinud	doc_740091150999_item	2836439	et	4	main
naise	doc_740091150999_item	2836446	et	3	main
on	doc_740091150999_item	2836450	et	4	main
peakski	doc_740091150999_item	2836458	et	4	main
jõuliselt	doc_740091150999_item	2836459	et	4	main
las	doc_740091150999_item	2836466	et	4	main
elu	doc_740091150999_item	2836467	et	4	main
kes	doc_740091150999_item	2836476	et	4	main
naised	doc_740091150999_item	2836485	et	3	main
need	doc_740091150999_item	2836488	et	3	main
tähtis	doc_740091150999_item	2836496	et	4	main
naisele	doc_740091150999_item	2836508	et	3	main
ettevõtet	doc_740091150999_item	2836511	et	3	main
leiab	doc_740091150999_item	2836532	et	3	main
kodus	doc_740091150999_item	2836538	et	4	main
siis	doc_740091150999_item	2836540	et	3	main
ka	doc_740091150999_item	2836542	et	3	main
elu	doc_740091150999_item	2836547	et	4	main
inimese	doc_740091150999_item	2836563	et	4	main
arenenud	doc_740091150999_item	2836569	et	4	main
jaotusid	doc_740091150999_item	2836573	et	4	main
tegelikult	doc_740091150999_item	2836575	et	4	main
mehe	doc_740091150999_item	2836577	et	3	main
roll	doc_740091150999_item	2836578	et	3	main
väga	doc_740091150999_item	2836580	et	3	main
hoopis	doc_740091150999_item	2836582	et	3	main
sellest	doc_740091150999_item	2836589	et	4	main
kohanema	doc_740091150999_item	2836595	et	3	main
on	doc_740091150999_item	2836597	et	4	main
antud	doc_740091150999_item	2836598	et	4	main
võimalus	doc_740091150999_item	2836599	et	3	main
on	doc_740091150999_item	2836632	et	4	main
maksma	doc_740091150999_item	2836643	et	3	main
sinule	doc_740091150999_item	2836649	et	3	main
naisele	doc_740091150999_item	2836651	et	3	main
looduse	doc_740091150999_item	2836653	et	4	main
selline	doc_740091150999_item	2836656	et	4	main
seda	doc_740091150999_item	2836659	et	3	main
on	doc_740091150999_item	2836660	et	4	main
emadus	doc_740091150999_item	2836661	et	4	main
siis	doc_740091150999_item	2836662	et	3	main
tuleb	doc_740091150999_item	2836670	et	3	main
rohkem	doc_740091150999_item	2836692	et	4	main
oma	doc_740091150999_item	2836722	et	4	main
siis	doc_740091150999_item	2836730	et	3	main
ühiskond	doc_740091150999_item	2836737	et	3	main
rolli	doc_740091150999_item	2836740	et	4	main
emapalk	doc_740091150999_item	2836741	et	3	main
ning	doc_740091150999_item	2836742	et	3	main
tunnevad	doc_740091150999_item	2836745	et	3	main
väärtuslikumana	doc_740091150999_item	2836747	et	4	main
ka	doc_740091150999_item	2836748	et	3	main
naised	doc_740091150999_item	2836749	et	3	main
ning	doc_740091150999_item	2836750	et	3	main
me	doc_740091150999_item	2836751	et	4	main
jõuame	doc_740091150999_item	2836752	et	3	main
võib	doc_740091150999_item	2836303	et	3	main
lapsed	doc_740091150999_item	2836305	et	3	main
kasvanud	doc_740091150999_item	2836313	et	4	main
näinud	doc_740091150999_item	2836318	et	4	main
raha	doc_740091150999_item	2836330	et	4	main
on	doc_740091150999_item	2836332	et	4	main
rollide	doc_740091150999_item	2836333	et	3	main
muutumise	doc_740091150999_item	2836334	et	4	main
meheliku	doc_740091150999_item	2836347	et	3	main
ja	doc_740091150999_item	2836352	et	3	main
omadusi	doc_740091150999_item	2836354	et	4	main
see	doc_740091150999_item	2836376	et	3	main
naiste	doc_740091150999_item	2836378	et	3	main
kus	doc_740091150999_item	2836394	et	3	main
halastamatu	doc_740091150999_item	2836396	et	4	main
vahendeid	doc_740091150999_item	2836398	et	3	main
valimata	doc_740091150999_item	2836399	et	4	main
tingibki	doc_740091150999_item	2836401	et	3	main
selle	doc_740091150999_item	2836402	et	4	main
mis	doc_740091150999_item	2836400	et	4	main
et	doc_740091150999_item	2836403	et	3	main
inimene	doc_740091150999_item	2836404	et	3	main
peab	doc_740091150999_item	2836405	et	4	main
olema	doc_740091150999_item	2836406	et	4	main
vastuvõtlikum	doc_740091150999_item	2836407	et	4	main
ning	doc_740091150999_item	2836408	et	3	main
leplikum	doc_740091150999_item	2836409	et	4	main
kõige	doc_740091150999_item	2836410	et	4	main
suhtes	doc_740091150999_item	2836411	et	4	main
ka	doc_740091150999_item	2836412	et	3	main
oma	doc_740091150999_item	2836413	et	4	main
rolli	doc_740091150999_item	2836414	et	4	main
suhtes	doc_740091150999_item	2836415	et	4	main
ühiskonnas	doc_740091150999_item	2836416	et	4	main
sest	doc_740091150999_item	2836417	et	4	main
tähtis	doc_740091150999_item	2836418	et	4	main
on	doc_740091150999_item	2836419	et	4	main
hakkama	doc_740091150999_item	2836420	et	3	main
edasi	doc_740091150999_item	2836424	et	3	main
rollid	doc_740091150999_item	2836427	et	3	main
visad	doc_740091150999_item	2836429	et	3	main
kaduma	doc_740091150999_item	2836430	et	4	main
kuigi	doc_740091150999_item	2836431	et	3	main
muutusi	doc_740091150999_item	2836432	et	4	main
võib	doc_740091150999_item	2836433	et	3	main
juba	doc_740091150999_item	2836434	et	3	main
tähendada	doc_740091150999_item	2836435	et	3	main
aga	doc_740091150999_item	2836436	et	3	main
et	doc_740091150999_item	2836441	et	3	main
aegade	doc_740091150999_item	2836448	et	3	main
pärast	doc_740091150999_item	2836465	et	4	main
on	doc_740091150999_item	2836474	et	4	main
need	doc_740091150999_item	2836475	et	3	main
las	doc_740091150999_item	2836484	et	4	main
vastupidi	doc_740091150999_item	2836495	et	3	main
on	doc_740091150999_item	2836497	et	4	main
tänapäeval	doc_740091150999_item	2836498	et	3	main
üksikindiviidi	doc_740091150999_item	2836499	et	4	main
õnn	doc_740091150999_item	2836500	et	3	main
kui	doc_740091150999_item	2836506	et	3	main
täiesti	doc_740091150999_item	2836520	et	3	main
olgu	doc_740091150999_item	2836522	et	3	main
natuke	doc_740091150999_item	2836524	et	4	main
kasvataks	doc_740091150999_item	2836537	et	4	main
jõuda	doc_740091150999_item	2836425	et	3	main
traditsioonilised	doc_740091150999_item	2836426	et	4	main
see	doc_740091150999_item	2836440	et	3	main
nii	doc_740091150999_item	2836443	et	3	main
tööd	doc_740091150999_item	2836447	et	4	main
selline	doc_740091150999_item	2836451	et	4	main
rollide	doc_740091150999_item	2836452	et	3	main
jaotus	doc_740091150999_item	2836453	et	4	main
sündinud	doc_740091150999_item	2836454	et	4	main
ning	doc_740091150999_item	2836455	et	3	main
me	doc_740091150999_item	2836456	et	4	main
ei	doc_740091150999_item	2836457	et	4	main
võitlemise	doc_740091150999_item	2836464	et	4	main
kulgeb	doc_740091150999_item	2836468	et	3	main
rada	doc_740091150999_item	2836470	et	4	main
käivad	doc_740091150999_item	2836477	et	4	main
tööl	doc_740091150999_item	2836478	et	3	main
ning	doc_740091150999_item	2836479	et	3	main
olla	doc_740091150999_item	2836486	et	3	main
kasvatavad	doc_740091150999_item	2836490	et	4	main
kodus	doc_740091150999_item	2836491	et	4	main
eluga	doc_740091150999_item	2836504	et	3	main
pakub	doc_740091150999_item	2836509	et	3	main
või	doc_740091150999_item	2836512	et	4	main
näiteks	doc_740091150999_item	2836513	et	4	main
kraanat	doc_740091150999_item	2836514	et	3	main
juhtida	doc_740091150999_item	2836515	et	4	main
siis	doc_740091150999_item	2836516	et	3	main
pealegi	doc_740091150999_item	2836523	et	4	main
mõni	doc_740091150999_item	2836530	et	3	main
et	doc_740091150999_item	2836533	et	3	main
lapsi	doc_740091150999_item	2836539	et	4	main
see	doc_740091150999_item	2836543	et	3	main
tänapäeva	doc_740091150999_item	2836546	et	4	main
kui	doc_740091150999_item	2836552	et	3	main
me	doc_740091150999_item	2836555	et	4	main
mõistame	doc_740091150999_item	2836556	et	3	main
mehi	doc_740091150999_item	2836557	et	3	main
ja	doc_740091150999_item	2836558	et	3	main
naisi	doc_740091150999_item	2836559	et	3	main
ennast	doc_740091150999_item	2836560	et	4	main
teadus	doc_740091150999_item	2836565	et	4	main
kui	doc_740091150999_item	2836571	et	3	main
nii	doc_740091150999_item	2836579	et	3	main
muutunud	doc_740091150999_item	2836581	et	4	main
suurema	doc_740091150999_item	2836583	et	4	main
hüppe	doc_740091150999_item	2836584	et	3	main
on	doc_740091150999_item	2836585	et	4	main
tulenevalt	doc_740091150999_item	2836590	et	4	main
ka	doc_740091150999_item	2836592	et	3	main
kohalduma	doc_740091150999_item	2836594	et	4	main
ennast	doc_740091150999_item	2836603	et	4	main
toimetuste	doc_740091150999_item	2836622	et	4	main
seltsis	doc_740091150999_item	2836623	et	4	main
veetma	doc_740091150999_item	2836624	et	3	main
mis	doc_740091150999_item	2836625	et	4	main
igati	doc_740091150999_item	2836628	et	3	main
küsimus	doc_740091150999_item	2836647	et	4	main
kui	doc_740091150999_item	2836650	et	3	main
milleks	doc_740091150999_item	2836663	et	4	main
seda	doc_740091150999_item	2836664	et	3	main
ikkagi	doc_740091150999_item	2836672	et	4	main
et	doc_740091150999_item	2836674	et	3	main
kui	doc_740091150999_item	2836683	et	3	main
ei	doc_740091150999_item	2836689	et	4	main
varem	doc_740091150999_item	2836729	et	4	main
tasapisi	doc_740091150999_item	2836733	et	3	main
asi	doc_740091150999_item	2836734	et	4	main
rahunema	doc_740091150999_item	2836736	et	3	main
ema	doc_740091150999_item	2836739	et	4	main
koos	doc_740091150999_item	2836743	et	4	main
end	doc_740091150999_item	2836746	et	4	main
rollijaotuseni	doc_740091150999_item	2836756	et	4	main
kasvatavad	doc_740091150999_item	2836758	et	4	main
lapsi	doc_740091150999_item	2836759	et	4	main
mehed	doc_740091150999_item	2836760	et	3	main
käivad	doc_740091150999_item	2836761	et	4	main
varem	doc_740091150999_item	2836769	et	4	main
veel	doc_740091150999_item	2836525	et	4	main
kumukartust	doc_740091150999_item	2836526	et	4	main
tekitav	doc_740091150999_item	2836527	et	4	main
ning	doc_740091150999_item	2836528	et	3	main
mees	doc_740091150999_item	2836531	et	4	main
tema	doc_740091150999_item	2836534	et	4	main
meelega	doc_740091150999_item	2836536	et	4	main
normaalne	doc_740091150999_item	2836545	et	3	main
ühiskond	doc_740091150999_item	2836549	et	3	main
mitmetahulisem	doc_740091150999_item	2836551	et	4	main
varem	doc_740091150999_item	2836553	et	4	main
sest	doc_740091150999_item	2836562	et	4	main
palju	doc_740091150999_item	2836568	et	4	main
teinud	doc_740091150999_item	2836586	et	4	main
naised	doc_740091150999_item	2836587	et	3	main
ning	doc_740091150999_item	2836588	et	3	main
ka	doc_740091150999_item	2836604	et	3	main
väljaspool	doc_740091150999_item	2836605	et	3	main
kodu	doc_740091150999_item	2836606	et	4	main
sellest	doc_740091150999_item	2836607	et	4	main
tulenevalt	doc_740091150999_item	2836608	et	4	main
peavad	doc_740091150999_item	2836609	et	4	main
perekonnad	doc_740091150999_item	2836610	et	4	main
teinekord	doc_740091150999_item	2836611	et	3	main
kompromisse	doc_740091150999_item	2836612	et	3	main
tegema	doc_740091150999_item	2836613	et	3	main
ning	doc_740091150999_item	2836614	et	3	main
mees	doc_740091150999_item	2836615	et	4	main
näiteks	doc_740091150999_item	2836616	et	4	main
rohkem	doc_740091150999_item	2836617	et	4	main
aega	doc_740091150999_item	2836618	et	4	main
kodus	doc_740091150999_item	2836619	et	4	main
ja	doc_740091150999_item	2836620	et	3	main
koduste	doc_740091150999_item	2836621	et	4	main
loomulikult	doc_740091150999_item	2836627	et	4	main
niisamuti	doc_740091150999_item	2836630	et	3	main
võimalus	doc_740091150999_item	2836639	et	3	main
valdkonnas	doc_740091150999_item	2836642	et	4	main
on	doc_740091150999_item	2836652	et	4	main
võimalust	doc_740091150999_item	2836665	et	3	main
tuulde	doc_740091150999_item	2836666	et	3	main
visata	doc_740091150999_item	2836667	et	4	main
välja	doc_740091150999_item	2836671	et	4	main
see	doc_740091150999_item	2836673	et	3	main
miski	doc_740091150999_item	2836676	et	4	main
roll	doc_740091150999_item	2836678	et	3	main
pole	doc_740091150999_item	2836679	et	3	main
muu	doc_740091150999_item	2836688	et	4	main
paku	doc_740091150999_item	2836690	et	4	main
rahuldust	doc_740091150999_item	2836693	et	4	main
ja	doc_740091150999_item	2836548	et	3	main
paremini	doc_740091150999_item	2836561	et	4	main
on	doc_740091150999_item	2836566	et	4	main
üsna	doc_740091150999_item	2836567	et	3	main
rollid	doc_740091150999_item	2836572	et	3	main
jäigemalt	doc_740091150999_item	2836574	et	4	main
end	doc_740091150999_item	2836600	et	4	main
tõestada	doc_740091150999_item	2836601	et	3	main
rakendada	doc_740091150999_item	2836602	et	3	main
antud	doc_740091150999_item	2836638	et	4	main
kui	doc_740091150999_item	2836648	et	3	main
antud	doc_740091150999_item	2836655	et	4	main
nagu	doc_740091150999_item	2836658	et	3	main
sest	doc_740091150999_item	2836668	et	4	main
rikastavam	doc_740091150999_item	2836682	et	4	main
ema	doc_740091150999_item	2836684	et	4	main
roll	doc_740091150999_item	2836685	et	3	main
mitte	doc_740091150999_item	2836686	et	3	main
miski	doc_740091150999_item	2836687	et	4	main
kui	doc_740091150999_item	2836694	et	3	main
rakendada	doc_740091150999_item	2836695	et	3	main
end	doc_740091150999_item	2836696	et	4	main
emana	doc_740091150999_item	2836697	et	3	main
ma	doc_740091150999_item	2836698	et	3	main
usun	doc_740091150999_item	2836699	et	3	main
ning	doc_740091150999_item	2836700	et	3	main
sellest	doc_740091150999_item	2836701	et	4	main
on	doc_740091150999_item	2836702	et	4	main
hakatud	doc_740091150999_item	2836703	et	4	main
ka	doc_740091150999_item	2836704	et	3	main
järjest	doc_740091150999_item	2836705	et	4	main
enam	doc_740091150999_item	2836706	et	4	main
aru	doc_740091150999_item	2836707	et	4	main
saama	doc_740091150999_item	2836708	et	4	main
seda	doc_740091150999_item	2836709	et	3	main
on	doc_740091150999_item	2836710	et	4	main
hakatud	doc_740091150999_item	2836711	et	4	main
väärtustama	doc_740091150999_item	2836712	et	3	main
kui	doc_740091150999_item	2836713	et	3	main
mingi	doc_740091150999_item	2836714	et	4	main
aeg	doc_740091150999_item	2836715	et	3	main
tagasi	doc_740091150999_item	2836716	et	3	main
võis	doc_740091150999_item	2836717	et	4	main
täheldada	doc_740091150999_item	2836718	et	3	main
et	doc_740091150999_item	2836719	et	3	main
naised	doc_740091150999_item	2836720	et	3	main
traditsioonilise	doc_740091150999_item	2836723	et	4	main
vastu	doc_740091150999_item	2836725	et	3	main
sõjakamalt	doc_740091150999_item	2836726	et	4	main
kui	doc_740091150999_item	2836727	et	3	main
kunagi	doc_740091150999_item	2836728	et	3	main
nüüd	doc_740091150999_item	2836731	et	4	main
sellega	doc_740091150999_item	2836744	et	3	main
tööl	doc_740091150999_item	2836762	et	3	main
ning	doc_740091150999_item	2836763	et	3	main
perekonnad	doc_740091150999_item	2836764	et	4	main
et	doc_740091150999_item	2836634	et	3	main
ka	doc_740091150999_item	2836635	et	3	main
naistele	doc_740091150999_item	2836636	et	3	main
on	doc_740091150999_item	2836637	et	4	main
end	doc_740091150999_item	2836640	et	4	main
muus	doc_740091150999_item	2836641	et	4	main
panna	doc_740091150999_item	2836644	et	4	main
samas	doc_740091150999_item	2836645	et	4	main
tekib	doc_740091150999_item	2836646	et	3	main
poolt	doc_740091150999_item	2836654	et	4	main
kingitus	doc_740091150999_item	2836657	et	4	main
tihtilugu	doc_740091150999_item	2836669	et	3	main
mitte	doc_740091150999_item	2836675	et	3	main
muu	doc_740091150999_item	2836677	et	4	main
naise	doc_740091150999_item	2836680	et	3	main
jaoks	doc_740091150999_item	2836681	et	4	main
naisele	doc_740091150999_item	2836691	et	3	main
sõidavad	doc_740091150999_item	2836721	et	3	main
rolli	doc_740091150999_item	2836724	et	4	main
jälle	doc_740091150999_item	2836735	et	3	main
väärtustab	doc_740091150999_item	2836738	et	3	main
traditsioonilise	doc_740091150999_item	2836755	et	4	main
on	doc_740091150999_item	2836765	et	4	main
hakkab	doc_740091150999_item	2836732	et	3	main
ikka	doc_740091150999_item	2836754	et	4	main
tasapisi	doc_740091150999_item	2836753	et	3	main
naised	doc_740091150999_item	2836757	et	3	main
tugevamad	doc_740091150999_item	2836766	et	4	main
kui	doc_740091150999_item	2836767	et	3	main
kunagi	doc_740091150999_item	2836768	et	3	main
või	doc_740091151002_item	2838021	et	4	main
mehe	doc_740091151002_item	2838023	et	3	main
nii	doc_740091151002_item	2838025	et	3	main
isegi	doc_740091151002_item	2838031	et	4	main
aeg	doc_740091151002_item	2838032	et	3	main
ei	doc_740091151002_item	2838033	et	4	main
kuidas	doc_740091151002_item	2837978	et	3	main
roll	doc_740091151002_item	2837981	et	3	main
roll	doc_740091151002_item	2838024	et	3	main
muuta	doc_740091151002_item	2838036	et	4	main
sellest	doc_740091151002_item	2838050	et	4	main
omandatud	doc_740091151002_item	2838062	et	4	main
väga	doc_740091151002_item	2838073	et	3	main
kultuuri	doc_740091151002_item	2838076	et	4	main
mõju	doc_740091151002_item	2838079	et	4	main
abi	doc_740091151002_item	2838085	et	4	main
abikaasat	doc_740091151002_item	2838132	et	3	main
ka	doc_740091151002_item	2838133	et	3	main
tema	doc_740091151002_item	2838134	et	4	main
ja	doc_740091151002_item	2838141	et	3	main
abikaasa	doc_740091151002_item	2838142	et	4	main
aktiivsus	doc_740091151002_item	2838155	et	4	main
oskus	doc_740091151002_item	2838156	et	3	main
kohaneda	doc_740091151002_item	2838157	et	3	main
kiiresti	doc_740091151002_item	2838160	et	3	main
elule	doc_740091151002_item	2838162	et	3	main
vägagi	doc_740091151002_item	2838178	et	3	main
erinevad	doc_740091151002_item	2838179	et	4	main
vaatame	doc_740091151002_item	2838180	et	3	main
on	doc_740091151002_item	2837979	et	4	main
mehe	doc_740091151002_item	2837980	et	3	main
viimase	doc_740091151002_item	2837983	et	3	main
muutunud	doc_740091151002_item	2838020	et	4	main
on	doc_740091151002_item	2838038	et	4	main
ettekujutus	doc_740091151002_item	2838042	et	4	main
meie	doc_740091151002_item	2838057	et	4	main
mälestused	doc_740091151002_item	2838060	et	4	main
kultuuriruum	doc_740091151002_item	2838064	et	3	main
olla	doc_740091151002_item	2838072	et	3	main
oli	doc_740091151002_item	2838123	et	3	main
käte	doc_740091151002_item	2838125	et	3	main
nüüd	doc_740091151002_item	2838129	et	4	main
vaatan	doc_740091151002_item	2838130	et	3	main
mees	doc_740091151002_item	2838138	et	4	main
suhtleja	doc_740091151002_item	2838146	et	4	main
tänapäeva	doc_740091151002_item	2838150	et	4	main
ja	doc_740091151002_item	2838165	et	3	main
lähemalt	doc_740091151002_item	2838182	et	4	main
pidi	doc_740091151002_item	2838243	et	4	main
et	doc_740091151002_item	2838252	et	3	main
täita	doc_740091151002_item	2838253	et	4	main
mees	doc_740091151002_item	2838257	et	4	main
mutkiks	doc_740091151002_item	2838264	et	4	main
poliitilised	doc_740091151002_item	2838265	et	3	main
väljavaated	doc_740091151002_item	2838266	et	3	main
olema	doc_740091151002_item	2838268	et	4	main
ja	doc_740091151002_item	2838271	et	3	main
tänapäevase	doc_740091151002_item	2838287	et	4	main
on	doc_740091151002_item	2838322	et	4	main
olla	doc_740091151002_item	2838323	et	3	main
edukas	doc_740091151002_item	2838324	et	4	main
pakkuda	doc_740091151002_item	2838325	et	3	main
kindlust	doc_740091151002_item	2838326	et	4	main
ja	doc_740091151002_item	2838327	et	3	main
ning	doc_740091151002_item	2838337	et	3	main
lisaks	doc_740091151002_item	2838351	et	4	main
uutega	doc_740091151002_item	2838358	et	3	main
väärtused	doc_740091151002_item	2838360	et	3	main
ja	doc_740091151002_item	2838363	et	3	main
avalduvad	doc_740091151002_item	2838365	et	4	main
mõju	doc_740091151002_item	2838367	et	4	main
mõju	doc_740091151002_item	2838370	et	4	main
rolli	doc_740091151002_item	2838372	et	4	main
muutub	doc_740091151002_item	2838374	et	3	main
kui	doc_740091151002_item	2838383	et	3	main
aktiivsemalt	doc_740091151002_item	2838389	et	4	main
kõrged	doc_740091151002_item	2838394	et	3	main
on	doc_740091151002_item	2838396	et	4	main
osa	doc_740091151002_item	2838401	et	4	main
traditsioonilisest	doc_740091151002_item	2838402	et	4	main
mehe	doc_740091151002_item	2838403	et	3	main
rollist	doc_740091151002_item	2838404	et	4	main
aina	doc_740091151002_item	2838413	et	4	main
märkamatuks	doc_740091151002_item	2838414	et	4	main
roll	doc_740091151002_item	2838419	et	3	main
muutunud	doc_740091151002_item	2838421	et	4	main
viimase	doc_740091151002_item	2838423	et	3	main
jooksul	doc_740091151002_item	2838426	et	4	main
mees	doc_740091151002_item	2838435	et	4	main
tänapäeval	doc_740091151002_item	2838436	et	3	main
essee	doc_740091151002_item	2837977	et	4	main
muutunud	doc_740091151002_item	2837982	et	4	main
on	doc_740091151002_item	2838022	et	4	main
20	doc_740091151002_item	2837984	et	2	main
aastaga	doc_740091151002_item	2837985	et	3	main
abikaasa	doc_740091151002_item	2837986	et	4	main
isa	doc_740091151002_item	2837987	et	4	main
ühiskonna	doc_740091151002_item	2837988	et	4	main
liige	doc_740091151002_item	2837989	et	4	main
karjääriinimene	doc_740091151002_item	2837990	et	3	main
igal	doc_740091151002_item	2837991	et	3	main
mehel	doc_740091151002_item	2837992	et	3	main
on	doc_740091151002_item	2837993	et	4	main
kümneid	doc_740091151002_item	2837994	et	4	main
rolle	doc_740091151002_item	2837995	et	3	main
ning	doc_740091151002_item	2837996	et	3	main
veel	doc_740091151002_item	2837997	et	4	main
rohkem	doc_740091151002_item	2837998	et	4	main
on	doc_740091151002_item	2837999	et	4	main
omadussõnu	doc_740091151002_item	2838000	et	3	main
millega	doc_740091151002_item	2838001	et	3	main
me	doc_740091151002_item	2838002	et	4	main
kirjeldame	doc_740091151002_item	2838003	et	3	main
neid	doc_740091151002_item	2838004	et	4	main
rolle	doc_740091151002_item	2838005	et	3	main
edukas	doc_740091151002_item	2838006	et	4	main
hooliv	doc_740091151002_item	2838007	et	4	main
tugev	doc_740091151002_item	2838008	et	4	main
mõistev	doc_740091151002_item	2838009	et	4	main
iseseisev	doc_740091151002_item	2838010	et	3	main
kuidas	doc_740091151002_item	2838011	et	3	main
on	doc_740091151002_item	2838012	et	4	main
mehe	doc_740091151002_item	2838013	et	3	main
roll	doc_740091151002_item	2838014	et	3	main
muutunud	doc_740091151002_item	2838015	et	4	main
viimastel	doc_740091151002_item	2838016	et	3	main
aastatel	doc_740091151002_item	2838017	et	4	main
kas	doc_740091151002_item	2838018	et	3	main
on	doc_740091151002_item	2838019	et	4	main
kindel	doc_740091151002_item	2838026	et	3	main
stabiilne	doc_740091151002_item	2838027	et	3	main
ja	doc_740091151002_item	2838028	et	3	main
traditsiooniline	doc_740091151002_item	2838029	et	4	main
et	doc_740091151002_item	2838030	et	3	main
kindlasti	doc_740091151002_item	2838037	et	3	main
ühiskonnas	doc_740091151002_item	2838047	et	4	main
kindel	doc_740091151002_item	2838048	et	3	main
üks	doc_740091151002_item	2838054	et	3	main
ettekujutust	doc_740091151002_item	2838058	et	4	main
lapsepõlvest	doc_740091151002_item	2838061	et	4	main
ühiskonna	doc_740091151002_item	2838066	et	4	main
on	doc_740091151002_item	2838080	et	4	main
kakskümmend	doc_740091151002_item	2838086	et	4	main
aastat	doc_740091151002_item	2838087	et	3	main
tagasi	doc_740091151002_item	2838088	et	3	main
elaksime	doc_740091151002_item	2838089	et	3	main
aastas	doc_740091151002_item	2838090	et	3	main
1988	doc_740091151002_item	2838091	et	2	main
teine	doc_740091151002_item	2838092	et	3	main
ja	doc_740091151002_item	2838094	et	3	main
riik	doc_740091151002_item	2838093	et	3	main
riigikord	doc_740091151002_item	2838095	et	3	main
teised	doc_740091151002_item	2838096	et	4	main
väärtused	doc_740091151002_item	2838097	et	3	main
rõõmud	doc_740091151002_item	2838098	et	3	main
ja	doc_740091151002_item	2838099	et	3	main
mured	doc_740091151002_item	2838100	et	3	main
mäletan	doc_740091151002_item	2838101	et	3	main
oma	doc_740091151002_item	2838102	et	4	main
isa	doc_740091151002_item	2838103	et	4	main
nendel	doc_740091151002_item	2838104	et	4	main
aastatel	doc_740091151002_item	2838105	et	4	main
ta	doc_740091151002_item	2838106	et	4	main
oli	doc_740091151002_item	2838107	et	3	main
tõeline	doc_740091151002_item	2838108	et	4	main
õige	doc_740091151002_item	2838109	et	4	main
eesti	doc_740091151002_item	2838110	et	4	main
mees	doc_740091151002_item	2838111	et	4	main
tegi	doc_740091151002_item	2838112	et	4	main
rasket	doc_740091151002_item	2838113	et	3	main
füüsilist	doc_740091151002_item	2838114	et	3	main
tööd	doc_740091151002_item	2838115	et	4	main
armastas	doc_740091151002_item	2838116	et	3	main
oma	doc_740091151002_item	2838117	et	4	main
abikaasat	doc_740091151002_item	2838118	et	3	main
ja	doc_740091151002_item	2838119	et	3	main
suuda	doc_740091151002_item	2838034	et	4	main
seda	doc_740091151002_item	2838035	et	3	main
igaühel	doc_740091151002_item	2838039	et	3	main
perekonnas	doc_740091151002_item	2838045	et	4	main
ja	doc_740091151002_item	2838046	et	3	main
milline	doc_740091151002_item	2838051	et	3	main
olema	doc_740091151002_item	2838053	et	4	main
õige	doc_740091151002_item	2838055	et	4	main
mees	doc_740091151002_item	2838056	et	4	main
mõjutavad	doc_740091151002_item	2838059	et	4	main
võivad	doc_740091151002_item	2838071	et	4	main
kuid	doc_740091151002_item	2838075	et	4	main
ja	doc_740091151002_item	2838077	et	3	main
ühiskonna	doc_740091151002_item	2838078	et	4	main
vanemaid	doc_740091151002_item	2838122	et	4	main
kuldsete	doc_740091151002_item	2838124	et	4	main
on	doc_740091151002_item	2838135	et	4	main
eeskujulik	doc_740091151002_item	2838136	et	3	main
edukas	doc_740091151002_item	2838143	et	4	main
karjääriinimene	doc_740091151002_item	2838144	et	3	main
hea	doc_740091151002_item	2838145	et	4	main
aus	doc_740091151002_item	2838149	et	4	main
ja	doc_740091151002_item	2838158	et	3	main
reageerida	doc_740091151002_item	2838159	et	3	main
esmapilgul	doc_740091151002_item	2838167	et	4	main
et	doc_740091151002_item	2838169	et	3	main
rollid	doc_740091151002_item	2838171	et	3	main
ja	doc_740091151002_item	2838173	et	3	main
minu	doc_740091151002_item	2838184	et	3	main
kuid	doc_740091151002_item	2838221	et	4	main
ikkagi	doc_740091151002_item	2838224	et	4	main
mehe	doc_740091151002_item	2838228	et	3	main
rolli	doc_740091151002_item	2838229	et	4	main
tasandil	doc_740091151002_item	2838239	et	3	main
kakskümmend	doc_740091151002_item	2838240	et	4	main
aastat	doc_740091151002_item	2838241	et	3	main
tagasi	doc_740091151002_item	2838242	et	3	main
ehk	doc_740091151002_item	2838256	et	3	main
mõistetavad	doc_740091151002_item	2838273	et	4	main
isiklik	doc_740091151002_item	2838274	et	3	main
karjäär	doc_740091151002_item	2838277	et	3	main
silmis	doc_740091151002_item	2838281	et	4	main
tagaplaanile	doc_740091151002_item	2838282	et	4	main
see	doc_740091151002_item	2838283	et	3	main
oli	doc_740091151002_item	2838284	et	3	main
võrdsete	doc_740091151002_item	2838285	et	4	main
aeg	doc_740091151002_item	2838286	et	3	main
aga	doc_740091151002_item	2838292	et	3	main
teinud	doc_740091151002_item	2838293	et	4	main
mehe	doc_740091151002_item	2838296	et	3	main
meist	doc_740091151002_item	2838040	et	3	main
oma	doc_740091151002_item	2838041	et	4	main
mehe	doc_740091151002_item	2838043	et	3	main
rollist	doc_740091151002_item	2838044	et	4	main
nägemus	doc_740091151002_item	2838049	et	3	main
peab	doc_740091151002_item	2838052	et	4	main
kogemused	doc_740091151002_item	2838063	et	3	main
meedia	doc_740091151002_item	2838065	et	4	main
väärtused	doc_740091151002_item	2838067	et	3	main
meie	doc_740091151002_item	2838068	et	4	main
isiklikud	doc_740091151002_item	2838069	et	3	main
kogemused	doc_740091151002_item	2838070	et	3	main
erinevad	doc_740091151002_item	2838074	et	4	main
siiski	doc_740091151002_item	2838081	et	4	main
mingil	doc_740091151002_item	2838082	et	4	main
määral	doc_740091151002_item	2838083	et	3	main
võrreldatav	doc_740091151002_item	2838084	et	4	main
lapsi	doc_740091151002_item	2838120	et	4	main
oma	doc_740091151002_item	2838131	et	4	main
armastav	doc_740091151002_item	2838139	et	4	main
poeg	doc_740091151002_item	2838140	et	3	main
sihikindel	doc_740091151002_item	2838147	et	3	main
mehe	doc_740091151002_item	2838151	et	3	main
on	doc_740091151002_item	2838153	et	4	main
olulised	doc_740091151002_item	2838154	et	4	main
tagada	doc_740091151002_item	2838163	et	3	main
kindlus	doc_740091151002_item	2838166	et	4	main
kakskümmend	doc_740091151002_item	2838174	et	4	main
aastat	doc_740091151002_item	2838175	et	3	main
tagasi	doc_740091151002_item	2838176	et	3	main
on	doc_740091151002_item	2838177	et	4	main
isa	doc_740091151002_item	2838185	et	4	main
kui	doc_740091151002_item	2838186	et	3	main
ka	doc_740091151002_item	2838187	et	3	main
mu	doc_740091151002_item	2838188	et	3	main
abikaasa	doc_740091151002_item	2838189	et	4	main
rollid	doc_740091151002_item	2838190	et	3	main
pereelus	doc_740091151002_item	2838191	et	4	main
tegelikult	doc_740091151002_item	2838192	et	4	main
kattuvad	doc_740091151002_item	2838193	et	4	main
mehe	doc_740091151002_item	2838194	et	3	main
rollid	doc_740091151002_item	2838195	et	3	main
on	doc_740091151002_item	2838196	et	4	main
läbi	doc_740091151002_item	2838197	et	4	main
aegade	doc_740091151002_item	2838198	et	3	main
olnud	doc_740091151002_item	2838199	et	4	main
samad	doc_740091151002_item	2838200	et	3	main
perekonna	doc_740091151002_item	2838201	et	4	main
kaitsmine	doc_740091151002_item	2838202	et	4	main
materiaalse	doc_740091151002_item	2838203	et	3	main
tagamise	doc_740091151002_item	2838205	et	4	main
baasi	doc_740091151002_item	2838204	et	4	main
stabiilsuse	doc_740091151002_item	2838206	et	4	main
ja	doc_740091151002_item	2838207	et	3	main
kindluse	doc_740091151002_item	2838208	et	4	main
pakkumine	doc_740091151002_item	2838209	et	4	main
muutunud	doc_740091151002_item	2838210	et	4	main
vaid	doc_740091151002_item	2838211	et	3	main
oskused	doc_740091151002_item	2838212	et	3	main
mis	doc_740091151002_item	2838213	et	4	main
on	doc_740091151002_item	2838214	et	4	main
vajalikud	doc_740091151002_item	2838215	et	3	main
rolli	doc_740091151002_item	2838216	et	4	main
ning	doc_740091151002_item	2838218	et	3	main
austas	doc_740091151002_item	2838121	et	3	main
ning	doc_740091151002_item	2838126	et	3	main
sooja	doc_740091151002_item	2838127	et	4	main
südamega	doc_740091151002_item	2838128	et	3	main
eesti	doc_740091151002_item	2838137	et	4	main
ning	doc_740091151002_item	2838148	et	3	main
juures	doc_740091151002_item	2838152	et	4	main
muutuvale	doc_740091151002_item	2838161	et	4	main
stabiilsus	doc_740091151002_item	2838164	et	4	main
tundub	doc_740091151002_item	2838168	et	3	main
mehe	doc_740091151002_item	2838170	et	3	main
täna	doc_740091151002_item	2838172	et	4	main
nii	doc_740091151002_item	2838183	et	3	main
täitmiseks	doc_740091151002_item	2838217	et	4	main
sisu	doc_740091151002_item	2838222	et	4	main
ainult	doc_740091151002_item	2838232	et	4	main
perekonnas	doc_740091151002_item	2838233	et	4	main
võib	doc_740091151002_item	2838234	et	3	main
ka	doc_740091151002_item	2838235	et	3	main
olema	doc_740091151002_item	2838245	et	4	main
rolli	doc_740091151002_item	2838255	et	4	main
pidid	doc_740091151002_item	2838267	et	4	main
korrektsed	doc_740091151002_item	2838270	et	3	main
üheselt	doc_740091151002_item	2838272	et	4	main
jäid	doc_740091151002_item	2838278	et	4	main
on	doc_740091151002_item	2838291	et	4	main
korrektuurid	doc_740091151002_item	2838295	et	3	main
sotsiaalsesse	doc_740091151002_item	2838297	et	4	main
meedia	doc_740091151002_item	2838299	et	4	main
ja	doc_740091151002_item	2838331	et	3	main
liikuda	doc_740091151002_item	2838338	et	3	main
hakkama	doc_740091151002_item	2838355	et	3	main
ühiskonna	doc_740091151002_item	2838359	et	4	main
naiste	doc_740091151002_item	2838369	et	3	main
mehe	doc_740091151002_item	2838371	et	3	main
muutumisele	doc_740091151002_item	2838373	et	4	main
aina	doc_740091151002_item	2838375	et	4	main
aina	doc_740091151002_item	2838388	et	4	main
ootused	doc_740091151002_item	2838392	et	3	main
kätte	doc_740091151002_item	2838399	et	4	main
olulise	doc_740091151002_item	2838400	et	4	main
kõvasti	doc_740091151002_item	2838420	et	3	main
kõrvale	doc_740091151002_item	2838431	et	4	main
veelgi	doc_740091151002_item	2838433	et	4	main
tugevam	doc_740091151002_item	2838434	et	4	main
tasakaalu	doc_740091151002_item	2838445	et	4	main
meedia	doc_740091151002_item	2838461	et	4	main
naiste	doc_740091151002_item	2838463	et	3	main
säilitavad	doc_740091151002_item	2838465	et	4	main
vahel	doc_740091151002_item	2838475	et	4	main
olles	doc_740091151002_item	2838476	et	3	main
edukad	doc_740091151002_item	2838477	et	3	main
muutmisele	doc_740091151002_item	2838492	et	4	main
viimase	doc_740091151002_item	2838494	et	3	main
traditsiooniline	doc_740091151002_item	2838500	et	4	main
aasta	doc_740091151002_item	2838519	et	4	main
ja	doc_740091151002_item	2838529	et	3	main
rõõmustab	doc_740091151002_item	2838533	et	3	main
see	doc_740091151002_item	2838535	et	3	main
hoolivad	doc_740091151002_item	2838555	et	4	main
roll	doc_740091151003_item	2838567	et	3	main
meist	doc_740091151003_item	2838573	et	3	main
kuulnud	doc_740091151003_item	2838575	et	4	main
olla	doc_740091151003_item	2838589	et	3	main
essee	doc_740091151003_item	2838593	et	4	main
küsimusele	doc_740091151003_item	2838599	et	4	main
ja	doc_740091151003_item	2838602	et	3	main
ühiskonnad	doc_740091151003_item	2838619	et	4	main
rõhuasetus	doc_740091151003_item	2838620	et	3	main
aga	doc_740091151002_item	2838181	et	3	main
laiemalt	doc_740091151002_item	2838230	et	4	main
mitte	doc_740091151002_item	2838231	et	3	main
mees	doc_740091151002_item	2838244	et	4	main
oma	doc_740091151002_item	2838254	et	4	main
olema	doc_740091151002_item	2838259	et	4	main
tugevaks	doc_740091151002_item	2838260	et	4	main
heaolu	doc_740091151002_item	2838262	et	4	main
tagamise	doc_740091151002_item	2838263	et	4	main
selged	doc_740091151002_item	2838269	et	3	main
ühiskonna	doc_740091151002_item	2838280	et	4	main
ühiskonna	doc_740091151002_item	2838289	et	4	main
areng	doc_740091151002_item	2838290	et	3	main
ühiskonnas	doc_740091151002_item	2838321	et	4	main
saavutatut	doc_740091151002_item	2838336	et	4	main
arvamus	doc_740091151002_item	2838343	et	3	main
on	doc_740091151002_item	2838349	et	4	main
ootused	doc_740091151002_item	2838362	et	3	main
ka	doc_740091151002_item	2838368	et	3	main
tänapäeva	doc_740091151002_item	2838377	et	4	main
naised	doc_740091151002_item	2838378	et	3	main
on	doc_740091151002_item	2838379	et	4	main
saavutanud	doc_740091151002_item	2838380	et	4	main
iseseisvust	doc_740091151002_item	2838382	et	4	main
varem	doc_740091151002_item	2838385	et	4	main
nad	doc_740091151002_item	2838386	et	3	main
tõusevad	doc_740091151002_item	2838387	et	4	main
karjääriredelil	doc_740091151002_item	2838390	et	3	main
selge	doc_740091151002_item	2838405	et	4	main
piir	doc_740091151002_item	2838406	et	3	main
naise	doc_740091151002_item	2838409	et	3	main
on	doc_740091151002_item	2838417	et	4	main
mehe	doc_740091151002_item	2838418	et	3	main
tugeva	doc_740091151002_item	2838427	et	4	main
iseseisva	doc_740091151002_item	2838429	et	3	main
kes	doc_740091151002_item	2838441	et	4	main
ja	doc_740091151002_item	2838447	et	3	main
ning	doc_740091151002_item	2838450	et	3	main
ühiskonna	doc_740091151002_item	2838460	et	4	main
ning	doc_740091151002_item	2838479	et	3	main
mul	doc_740091151002_item	2838481	et	3	main
meel	doc_740091151002_item	2838484	et	4	main
tõdeda	doc_740091151002_item	2838485	et	3	main
siiski	doc_740091151002_item	2838502	et	4	main
mõju	doc_740091151002_item	2838526	et	4	main
on	doc_740091151002_item	2838539	et	4	main
saada	doc_740091151002_item	2838544	et	4	main
ning	doc_740091151002_item	2838559	et	3	main
liikmed	doc_740091151002_item	2838562	et	3	main
muutunud	doc_740091151003_item	2838568	et	4	main
viimase	doc_740091151003_item	2838569	et	3	main
väljendit	doc_740091151003_item	2838576	et	3	main
on	doc_740091151003_item	2838578	et	4	main
marsilt	doc_740091151003_item	2838579	et	3	main
ja	doc_740091151003_item	2838580	et	3	main
naised	doc_740091151003_item	2838581	et	3	main
veenuselt	doc_740091151003_item	2838582	et	4	main
tõepoolest	doc_740091151003_item	2838583	et	3	main
on	doc_740091151003_item	2838584	et	4	main
võivad	doc_740091151003_item	2838588	et	4	main
selle	doc_740091151003_item	2838592	et	4	main
vastav	doc_740091151003_item	2838608	et	4	main
vaadelda	doc_740091151003_item	2838613	et	4	main
mehe	doc_740091151003_item	2838614	et	3	main
rolli	doc_740091151003_item	2838628	et	4	main
läbi	doc_740091151003_item	2838632	et	4	main
on	doc_740091151003_item	2838634	et	4	main
meest	doc_740091151003_item	2838635	et	4	main
pidas	doc_740091151003_item	2838640	et	3	main
jahti	doc_740091151003_item	2838641	et	4	main
selline	doc_740091151003_item	2838653	et	4	main
mitmeid	doc_740091151003_item	2838661	et	4	main
järsku	doc_740091151003_item	2838664	et	4	main
kuulda	doc_740091151003_item	2838668	et	4	main
ning	doc_740091151003_item	2838669	et	3	main
oluliseks	doc_740091151003_item	2838673	et	4	main
hääleõiguse	doc_740091151003_item	2838677	et	4	main
poole	doc_740091151003_item	2838682	et	4	main
vähem	doc_740091151003_item	2838684	et	4	main
keskel	doc_740091151003_item	2838690	et	3	main
ülalmainitud	doc_740091151003_item	2838698	et	3	main
eesmärkide	doc_740091151002_item	2838219	et	3	main
saavutamiseks	doc_740091151002_item	2838220	et	4	main
jäi	doc_740091151002_item	2838223	et	3	main
samaks	doc_740091151002_item	2838225	et	3	main
vaatame	doc_740091151002_item	2838226	et	3	main
aga	doc_740091151002_item	2838227	et	3	main
ühiskonna	doc_740091151002_item	2838236	et	4	main
ja	doc_740091151002_item	2838237	et	3	main
riigi	doc_740091151002_item	2838238	et	3	main
ühiskondlikult	doc_740091151002_item	2838246	et	4	main
ning	doc_740091151002_item	2838247	et	3	main
tihti	doc_740091151002_item	2838248	et	3	main
ka	doc_740091151002_item	2838249	et	3	main
poliitiliselt	doc_740091151002_item	2838250	et	4	main
aktiivne	doc_740091151002_item	2838251	et	3	main
pidi	doc_740091151002_item	2838258	et	4	main
ühiskonna	doc_740091151002_item	2838261	et	4	main
edukus	doc_740091151002_item	2838275	et	4	main
ja	doc_740091151002_item	2838276	et	3	main
aga	doc_740091151002_item	2838279	et	3	main
heaolu	doc_740091151002_item	2838288	et	4	main
oma	doc_740091151002_item	2838294	et	4	main
rolli	doc_740091151002_item	2838298	et	4	main
avaliku	doc_740091151002_item	2838300	et	3	main
arvamuse	doc_740091151002_item	2838301	et	3	main
ning	doc_740091151002_item	2838302	et	3	main
koosmõjul	doc_740091151002_item	2838304	et	3	main
eeskujude	doc_740091151002_item	2838303	et	3	main
on	doc_740091151002_item	2838305	et	4	main
prioriteedid	doc_740091151002_item	2838306	et	3	main
muutunud	doc_740091151002_item	2838308	et	4	main
tugevasti	doc_740091151002_item	2838307	et	3	main
mehe	doc_740091151002_item	2838310	et	3	main
roll	doc_740091151002_item	2838311	et	3	main
tänapäeva	doc_740091151002_item	2838309	et	4	main
on	doc_740091151002_item	2838312	et	4	main
muutunud	doc_740091151002_item	2838313	et	4	main
rohkem	doc_740091151002_item	2838314	et	4	main
isiksuse	doc_740091151002_item	2838315	et	3	main
kui	doc_740091151002_item	2838316	et	3	main
ühiskonna	doc_740091151002_item	2838317	et	4	main
keskseks	doc_740091151002_item	2838318	et	4	main
mehe	doc_740091151002_item	2838319	et	3	main
roll	doc_740091151002_item	2838320	et	3	main
stabiilsust	doc_740091151002_item	2838328	et	4	main
aktiivne	doc_740091151002_item	2838332	et	3	main
meedia	doc_740091151002_item	2838340	et	4	main
avalik	doc_740091151002_item	2838342	et	3	main
survestavad	doc_740091151002_item	2838344	et	4	main
kõrged	doc_740091151002_item	2838350	et	3	main
traditsioonilistele	doc_740091151002_item	2838352	et	4	main
saada	doc_740091151002_item	2838356	et	4	main
ka	doc_740091151002_item	2838357	et	3	main
elustandardid	doc_740091151002_item	2838364	et	4	main
tugevat	doc_740091151002_item	2838366	et	4	main
naiste	doc_740091151002_item	2838391	et	3	main
on	doc_740091151002_item	2838393	et	4	main
naised	doc_740091151002_item	2838395	et	3	main
ja	doc_740091151002_item	2838408	et	3	main
seoses	doc_740091151002_item	2838415	et	4	main
sellega	doc_740091151002_item	2838416	et	3	main
olla	doc_740091151002_item	2838329	et	3	main
tark	doc_740091151002_item	2838330	et	3	main
selleks	doc_740091151002_item	2838333	et	4	main
et	doc_740091151002_item	2838334	et	3	main
säilitada	doc_740091151002_item	2838335	et	3	main
edasi	doc_740091151002_item	2838339	et	3	main
ning	doc_740091151002_item	2838341	et	3	main
meest	doc_740091151002_item	2838345	et	4	main
väga	doc_740091151002_item	2838346	et	3	main
tugevalt	doc_740091151002_item	2838347	et	4	main
ootused	doc_740091151002_item	2838348	et	3	main
rollidele	doc_740091151002_item	2838353	et	3	main
tuleb	doc_740091151002_item	2838354	et	3	main
kõrged	doc_740091151002_item	2838361	et	3	main
olulisemaks	doc_740091151002_item	2838376	et	4	main
rohkem	doc_740091151002_item	2838381	et	4	main
kunagi	doc_740091151002_item	2838384	et	3	main
võitnud	doc_740091151002_item	2838397	et	4	main
enda	doc_740091151002_item	2838398	et	4	main
mehe	doc_740091151002_item	2838407	et	3	main
rolli	doc_740091151002_item	2838410	et	4	main
vahel	doc_740091151002_item	2838411	et	4	main
muutub	doc_740091151002_item	2838412	et	3	main
kahekümne	doc_740091151002_item	2838424	et	4	main
aasta	doc_740091151002_item	2838425	et	4	main
siiralt	doc_740091151002_item	2838438	et	4	main
mehi	doc_740091151002_item	2838440	et	3	main
on	doc_740091151002_item	2838442	et	4	main
leidnud	doc_740091151002_item	2838443	et	4	main
mehe	doc_740091151002_item	2838446	et	3	main
traditsiooniliste	doc_740091151002_item	2838449	et	4	main
sotsiaalsete	doc_740091151002_item	2838451	et	4	main
rollide	doc_740091151002_item	2838452	et	3	main
vahel	doc_740091151002_item	2838453	et	4	main
ma	doc_740091151002_item	2838454	et	3	main
imetlen	doc_740091151002_item	2838455	et	3	main
neid	doc_740091151002_item	2838456	et	4	main
mehi	doc_740091151002_item	2838457	et	3	main
olulisust	doc_740091151002_item	2838468	et	4	main
sotsiaalelus	doc_740091151002_item	2838480	et	4	main
on	doc_740091151002_item	2838482	et	4	main
hea	doc_740091151002_item	2838483	et	4	main
vaatamata	doc_740091151002_item	2838487	et	4	main
ühiskonna	doc_740091151002_item	2838489	et	4	main
jooksul	doc_740091151002_item	2838497	et	4	main
jäi	doc_740091151002_item	2838498	et	3	main
pidevalt	doc_740091151002_item	2838521	et	4	main
ning	doc_740091151002_item	2838523	et	3	main
sellega	doc_740091151002_item	2838530	et	3	main
ootustele	doc_740091151002_item	2838532	et	3	main
et	doc_740091151002_item	2838536	et	3	main
siiski	doc_740091151002_item	2838540	et	4	main
edukalt	doc_740091151002_item	2838542	et	4	main
täidavad	doc_740091151002_item	2838546	et	3	main
oma	doc_740091151002_item	2838547	et	4	main
rolle	doc_740091151002_item	2838548	et	3	main
väärikalt	doc_740091151002_item	2838549	et	4	main
ja	doc_740091151002_item	2838550	et	3	main
isad	doc_740091151002_item	2838556	et	3	main
ühiskonna	doc_740091151002_item	2838561	et	4	main
mehe	doc_740091151003_item	2838566	et	3	main
20	doc_740091151003_item	2838570	et	2	main
poleks	doc_740091151003_item	2838574	et	3	main
kaks	doc_740091151003_item	2838590	et	3	main
sugupoolt	doc_740091151003_item	2838591	et	4	main
ei	doc_740091151003_item	2838595	et	4	main
otsida	doc_740091151003_item	2838597	et	4	main
vastust	doc_740091151003_item	2838598	et	4	main
lihtsalt	doc_740091151003_item	2838607	et	4	main
pädevus	doc_740091151003_item	2838610	et	4	main
püüan	doc_740091151003_item	2838612	et	3	main
ja	doc_740091151003_item	2838615	et	3	main
naise	doc_740091151003_item	2838616	et	3	main
erinevaid	doc_740091151003_item	2838617	et	4	main
rolle	doc_740091151003_item	2838618	et	3	main
viimasele	doc_740091151003_item	2838622	et	3	main
ja	doc_740091151003_item	2838625	et	3	main
muutumisele	doc_740091151003_item	2838629	et	4	main
aegade	doc_740091151003_item	2838633	et	3	main
käis	doc_740091151003_item	2838643	et	4	main
elu	doc_740091151003_item	2838654	et	4	main
revolutsioonilisi	doc_740091151003_item	2838662	et	4	main
muudatusi	doc_740091151003_item	2838663	et	3	main
oli	doc_740091151003_item	2838665	et	3	main
tunda	doc_740091151003_item	2838671	et	3	main
pidada	doc_740091151003_item	2838688	et	4	main
seksuaalrevolutsiooni	doc_740091151003_item	2838692	et	4	main
ja	doc_740091151003_item	2838699	et	3	main
järk-järgulisele	doc_740091151003_item	2838709	et	4	main
täpsemalt	doc_740091151003_item	2838724	et	4	main
mehe	doc_740091151003_item	2838726	et	3	main
meestekeskses	doc_740091151003_item	2838735	et	3	main
maailmas	doc_740091151003_item	2838736	et	3	main
enam	doc_740091151003_item	2838743	et	4	main
just	doc_740091151002_item	2838422	et	3	main
ja	doc_740091151002_item	2838428	et	3	main
naise	doc_740091151002_item	2838430	et	3	main
sobib	doc_740091151002_item	2838432	et	3	main
imetlen	doc_740091151002_item	2838439	et	3	main
naise	doc_740091151002_item	2838448	et	3	main
ja	doc_740091151002_item	2838462	et	3	main
survele	doc_740091151002_item	2838464	et	3	main
traditsioonilise	doc_740091151002_item	2838466	et	4	main
rolli	doc_740091151002_item	2838467	et	4	main
tasakaalu	doc_740091151002_item	2838471	et	4	main
kodu	doc_740091151002_item	2838472	et	4	main
ja	doc_740091151002_item	2838473	et	3	main
töö	doc_740091151002_item	2838474	et	4	main
meie	doc_740091151002_item	2838488	et	4	main
ja	doc_740091151002_item	2838490	et	3	main
kahekümne	doc_740091151002_item	2838495	et	4	main
aasta	doc_740091151002_item	2838496	et	4	main
roll	doc_740091151002_item	2838501	et	3	main
samaks	doc_740091151002_item	2838503	et	3	main
murelikuks	doc_740091151002_item	2838504	et	3	main
teevad	doc_740091151002_item	2838505	et	3	main
aga	doc_740091151002_item	2838506	et	3	main
surve	doc_740091151002_item	2838508	et	4	main
ja	doc_740091151002_item	2838509	et	3	main
avalikkuse	doc_740091151002_item	2838507	et	4	main
kõrged	doc_740091151002_item	2838510	et	3	main
ootused	doc_740091151002_item	2838511	et	3	main
mehe	doc_740091151002_item	2838512	et	3	main
sotsiaalsele	doc_740091151002_item	2838513	et	3	main
rollile	doc_740091151002_item	2838514	et	3	main
mis	doc_740091151002_item	2838515	et	4	main
on	doc_740091151002_item	2838516	et	4	main
viimase	doc_740091151002_item	2838517	et	3	main
kahekümne	doc_740091151002_item	2838518	et	4	main
jooksul	doc_740091151002_item	2838520	et	4	main
ma	doc_740091151002_item	2838437	et	3	main
maagilise	doc_740091151002_item	2838444	et	4	main
kes	doc_740091151002_item	2838458	et	4	main
vaatamata	doc_740091151002_item	2838459	et	4	main
oskavad	doc_740091151002_item	2838469	et	4	main
leida	doc_740091151002_item	2838470	et	3	main
era-	doc_740091151002_item	2838478	et	4	main
et	doc_740091151002_item	2838486	et	3	main
väärtuste	doc_740091151002_item	2838491	et	4	main
just	doc_740091151002_item	2838493	et	3	main
mehe	doc_740091151002_item	2838499	et	3	main
kasvanud	doc_740091151002_item	2838522	et	4	main
avaldanud	doc_740091151002_item	2838524	et	4	main
tugevat	doc_740091151002_item	2838525	et	4	main
mehed	doc_740091151002_item	2838538	et	3	main
suutnud	doc_740091151002_item	2838541	et	4	main
karjääriinimesed	doc_740091151002_item	2838558	et	3	main
aktiivsed	doc_740091151002_item	2838560	et	3	main
essee	doc_740091151003_item	2838563	et	4	main
kuidas	doc_740091151003_item	2838564	et	3	main
on	doc_740091151003_item	2838565	et	4	main
aastaga	doc_740091151003_item	2838571	et	3	main
mehed	doc_740091151003_item	2838577	et	3	main
eesmärk	doc_740091151003_item	2838594	et	3	main
ole	doc_740091151003_item	2838596	et	4	main
mehed	doc_740091151003_item	2838601	et	3	main
erinevad	doc_740091151003_item	2838604	et	4	main
erialane	doc_740091151003_item	2838609	et	4	main
pigem	doc_740091151003_item	2838611	et	3	main
just	doc_740091151003_item	2838626	et	3	main
neil	doc_740091151003_item	2838630	et	4	main
mees	doc_740091151003_item	2838639	et	4	main
20	doc_740091151003_item	2838657	et	2	main
verstapostiks	doc_740091151003_item	2838674	et	4	main
naistele	doc_740091151003_item	2838676	et	3	main
andmine	doc_740091151003_item	2838678	et	4	main
20	doc_740091151003_item	2838679	et	2	main
sajandi	doc_740091151003_item	2838680	et	3	main
esimese	doc_740091151003_item	2838681	et	3	main
kõik	doc_740091151003_item	2838697	et	4	main
paljud	doc_740091151003_item	2838701	et	3	main
teised	doc_740091151003_item	2838702	et	4	main
vähenemisele	doc_740091151003_item	2838710	et	4	main
viimase	doc_740091151003_item	2838711	et	3	main
mehe	doc_740091151002_item	2838527	et	3	main
rollile	doc_740091151002_item	2838528	et	3	main
seotud	doc_740091151002_item	2838531	et	4	main
aga	doc_740091151002_item	2838534	et	3	main
paljud	doc_740091151002_item	2838537	et	3	main
hakkama	doc_740091151002_item	2838543	et	3	main
ja	doc_740091151002_item	2838545	et	3	main
paindlikult	doc_740091151002_item	2838551	et	4	main
olles	doc_740091151002_item	2838552	et	3	main
toetavad	doc_740091151002_item	2838553	et	4	main
abikaasad	doc_740091151002_item	2838554	et	3	main
edukad	doc_740091151002_item	2838557	et	3	main
kes	doc_740091151003_item	2838572	et	4	main
hämmastav	doc_740091151003_item	2838585	et	4	main
kui	doc_740091151003_item	2838586	et	3	main
erinevad	doc_740091151003_item	2838587	et	4	main
miks	doc_740091151003_item	2838600	et	4	main
naised	doc_740091151003_item	2838603	et	3	main
autoril	doc_740091151003_item	2838605	et	3	main
puudub	doc_740091151003_item	2838606	et	3	main
jääb	doc_740091151003_item	2838621	et	3	main
aastale	doc_740091151003_item	2838624	et	3	main
mehe	doc_740091151003_item	2838627	et	3	main
tugevamaks	doc_740091151003_item	2838637	et	4	main
sugupooleks	doc_740091151003_item	2838638	et	3	main
sõjas	doc_740091151003_item	2838644	et	3	main
kaitses	doc_740091151003_item	2838646	et	4	main
sajandeid	doc_740091151003_item	2838656	et	3	main
tõi	doc_740091151003_item	2838659	et	3	main
naiste	doc_740091151003_item	2838666	et	3	main
häält	doc_740091151003_item	2838667	et	3	main
üheks	doc_740091151003_item	2838672	et	3	main
ei	doc_740091151003_item	2838686	et	4	main
saa	doc_740091151003_item	2838687	et	4	main
toimunud	doc_740091151003_item	2838691	et	4	main
milles	doc_740091151003_item	2838693	et	3	main
naised	doc_740091151003_item	2838694	et	3	main
aktiivselt	doc_740091151003_item	2838695	et	4	main
osalesid	doc_740091151003_item	2838696	et	4	main
ka	doc_740091151003_item	2838700	et	3	main
tähtsuse	doc_740091151003_item	2838708	et	4	main
naisõiguslased	doc_740091151003_item	2838722	et	3	main
milles	doc_740091151003_item	2838723	et	3	main
muutumine	doc_740091151003_item	2838728	et	4	main
siiamaani	doc_740091151003_item	2838729	et	3	main
armastatakse	doc_740091151003_item	2838730	et	3	main
mitte	doc_740091151003_item	2838742	et	3	main
võib	doc_740091151003_item	2838747	et	3	main
meediast	doc_740091151003_item	2838749	et	4	main
kirjutavas	doc_740091151003_item	2838751	et	4	main
telemeedias	doc_740091151003_item	2838754	et	4	main
figureerivad	doc_740091151003_item	2838755	et	4	main
naised	doc_740091151003_item	2838757	et	3	main
et	doc_740091151003_item	2838771	et	3	main
samas	doc_740091151003_item	2838789	et	4	main
valdavalt	doc_740091151003_item	2838794	et	4	main
vähe	doc_740091151003_item	2838801	et	3	main
naisi	doc_740091151003_item	2838802	et	3	main
kohale	doc_740091151003_item	2838804	et	4	main
on	doc_740091151003_item	2838806	et	4	main
kindlasti	doc_740091151003_item	2838812	et	3	main
juba	doc_740091151003_item	2838819	et	3	main
pakuvad	doc_740091151003_item	2838821	et	3	main
tööturul	doc_740091151003_item	2838823	et	3	main
väga	doc_740091151003_item	2838825	et	3	main
targad	doc_740091151003_item	2838826	et	3	main
ja	doc_740091151003_item	2838827	et	3	main
kelle	doc_740091151003_item	2838830	et	4	main
lisatrump	doc_740091151003_item	2838831	et	3	main
rohkem	doc_740091151003_item	2838839	et	4	main
muutunud	doc_740091151003_item	2838843	et	4	main
kes	doc_740091151003_item	2838851	et	4	main
peab	doc_740091151003_item	2838852	et	4	main
üksi	doc_740091151003_item	2838853	et	4	main
naist	doc_740091151003_item	2838854	et	3	main
ja	doc_740091151003_item	2838855	et	3	main
tahavad	doc_740091151003_item	2838860	et	3	main
lihtsalt	doc_740091151003_item	2838863	et	4	main
tõestada	doc_740091151003_item	2838865	et	3	main
tuleb	doc_740091151003_item	2838868	et	3	main
märgatavalt	doc_740091151003_item	2838873	et	4	main
olda	doc_740091151003_item	2838886	et	3	main
harjunud	doc_740091151003_item	2838887	et	4	main
võib	doc_740091151003_item	2838889	et	3	main
muutused	doc_740091151003_item	2838924	et	4	main
võtavad	doc_740091151003_item	2838925	et	3	main
siin	doc_740091151003_item	2838926	et	4	main
aga	doc_740091151003_item	2838938	et	3	main
sees	doc_740091151003_item	2838944	et	4	main
tundnud	doc_740091151003_item	2838948	et	4	main
end	doc_740091151003_item	2838950	et	4	main
ning	doc_740091151003_item	2838963	et	3	main
20	doc_740091151003_item	2838623	et	2	main
aastatel	doc_740091151003_item	2838631	et	4	main
peetud	doc_740091151003_item	2838636	et	4	main
mees	doc_740091151003_item	2838642	et	4	main
mees	doc_740091151003_item	2838645	et	4	main
perekonda	doc_740091151003_item	2838647	et	4	main
ning	doc_740091151003_item	2838648	et	3	main
mees	doc_740091151003_item	2838649	et	4	main
tõi	doc_740091151003_item	2838650	et	3	main
leiva	doc_740091151003_item	2838651	et	3	main
lauale	doc_740091151003_item	2838652	et	4	main
vältas	doc_740091151003_item	2838655	et	3	main
sajand	doc_740091151003_item	2838658	et	3	main
kaasa	doc_740091151003_item	2838660	et	4	main
tegevust	doc_740091151003_item	2838670	et	4	main
oli	doc_740091151003_item	2838675	et	3	main
inglismaal	doc_740091151003_item	2838683	et	4	main
tähtsaks	doc_740091151003_item	2838685	et	4	main
sajandi	doc_740091151003_item	2838689	et	3	main
on	doc_740091151003_item	2838704	et	4	main
20	doc_740091151003_item	2838712	et	2	main
aasta	doc_740091151003_item	2838713	et	4	main
jooksul	doc_740091151003_item	2838714	et	4	main
üle	doc_740091151003_item	2838715	et	3	main
maailma	doc_740091151003_item	2838716	et	4	main
on	doc_740091151003_item	2838717	et	4	main
pead	doc_740091151003_item	2838718	et	4	main
tõstnud	doc_740091151003_item	2838719	et	4	main
võrd-	doc_740091151003_item	2838720	et	4	main
ja	doc_740091151003_item	2838721	et	3	main
me	doc_740091151003_item	2838733	et	4	main
on	doc_740091151003_item	2838738	et	4	main
küll	doc_740091151003_item	2838739	et	4	main
sajaprotsendiliselt	doc_740091151003_item	2838744	et	4	main
tuua	doc_740091151003_item	2838748	et	3	main
välja	doc_740091151003_item	2838770	et	4	main
meeste	doc_740091151003_item	2838779	et	4	main
hea	doc_740091151003_item	2838781	et	4	main
välimus	doc_740091151003_item	2838782	et	3	main
kunagi	doc_740091151003_item	2838783	et	3	main
teab	doc_740091151003_item	2838784	et	3	main
mis	doc_740091151003_item	2838785	et	4	main
suur	doc_740091151003_item	2838786	et	3	main
argument	doc_740091151003_item	2838787	et	3	main
muutuvatele	doc_740091151003_item	2838797	et	4	main
jõuab	doc_740091151003_item	2838799	et	3	main
siiski	doc_740091151003_item	2838807	et	4	main
rohkem	doc_740091151003_item	2838814	et	4	main
edukaid	doc_740091151003_item	2838817	et	4	main
karjäärinaisi	doc_740091151003_item	2838818	et	3	main
praegu	doc_740091151003_item	2838820	et	3	main
nende	doc_740091151003_item	2838833	et	4	main
roll	doc_740091151003_item	2838842	et	3	main
mees	doc_740091151003_item	2838846	et	4	main
ole	doc_740091151003_item	2838848	et	4	main
enam	doc_740091151003_item	2838849	et	4	main
see	doc_740091151003_item	2838850	et	3	main
üleval	doc_740091151003_item	2838857	et	4	main
end	doc_740091151003_item	2838862	et	4	main
jaotada	doc_740091151003_item	2838870	et	3	main
palju	doc_740091151003_item	2838881	et	4	main
sellega	doc_740091151003_item	2838884	et	3	main
palju	doc_740091151003_item	2838927	et	4	main
rohkem	doc_740091151003_item	2838928	et	4	main
aega	doc_740091151003_item	2838929	et	4	main
ning	doc_740091151003_item	2838930	et	3	main
neid	doc_740091151003_item	2838931	et	4	main
mehed	doc_740091151003_item	2838939	et	3	main
tunnevad	doc_740091151003_item	2838945	et	3	main
pereemad	doc_740091151003_item	2838958	et	3	main
ühtäkki	doc_740091151003_item	2838960	et	3	main
aga	doc_740091151003_item	2838967	et	3	main
pea	doc_740091151003_item	2838991	et	4	main
tõestama	doc_740091151003_item	2838996	et	3	main
vaja	doc_740091151003_item	2839000	et	4	main
tegurid	doc_740091151003_item	2838703	et	3	main
viinud	doc_740091151003_item	2838705	et	4	main
mehe	doc_740091151003_item	2838706	et	3	main
rolli	doc_740091151003_item	2838707	et	4	main
seisneb	doc_740091151003_item	2838725	et	3	main
elame	doc_740091151003_item	2838734	et	3	main
see	doc_740091151003_item	2838737	et	3	main
kuid	doc_740091151003_item	2838741	et	4	main
hea	doc_740091151003_item	2838745	et	4	main
ka	doc_740091151003_item	2838753	et	3	main
neil	doc_740091151003_item	2838772	et	4	main
midagi	doc_740091151003_item	2838774	et	4	main
puhul	doc_740091151003_item	2838780	et	4	main
majandus-	doc_740091151003_item	2838791	et	4	main
ja	doc_740091151003_item	2838792	et	3	main
poliitikauudistes	doc_740091151003_item	2838793	et	3	main
ajapikku	doc_740091151003_item	2838810	et	3	main
ja	doc_740091151003_item	2838815	et	3	main
konkurentsi	doc_740091151003_item	2838824	et	4	main
edukad	doc_740091151003_item	2838828	et	3	main
naised	doc_740091151003_item	2838829	et	3	main
kõige	doc_740091151003_item	2838838	et	4	main
lapsi	doc_740091151003_item	2838856	et	4	main
naised	doc_740091151003_item	2838861	et	3	main
ning	doc_740091151003_item	2838866	et	3	main
võrdselt	doc_740091151003_item	2838869	et	4	main
rohkem	doc_740091151003_item	2838874	et	4	main
samas	doc_740091151003_item	2838877	et	4	main
ei	doc_740091151003_item	2838885	et	4	main
ülalkirjutatust	doc_740091151003_item	2838888	et	4	main
arengult	doc_740091151003_item	2838922	et	3	main
keeruline	doc_740091151003_item	2838934	et	4	main
läbi	doc_740091151003_item	2838935	et	4	main
viia	doc_740091151003_item	2838936	et	3	main
kuidas	doc_740091151003_item	2838937	et	3	main
end	doc_740091151003_item	2838940	et	4	main
kõigi	doc_740091151003_item	2838941	et	4	main
ei	doc_740091151003_item	2838947	et	4	main
tasu	doc_740091151003_item	2838964	et	4	main
vähemalt	doc_740091151003_item	2838969	et	4	main
meestelt	doc_740091151003_item	2838981	et	4	main
oodata	doc_740091151003_item	2838983	et	4	main
enam	doc_740091151003_item	2838984	et	4	main
nii	doc_740091151003_item	2838985	et	3	main
suurt	doc_740091151003_item	2838986	et	3	main
ning	doc_740091151003_item	2838988	et	3	main
suurel	doc_740091151003_item	2838994	et	3	main
ei	doc_740091151003_item	2838998	et	4	main
meeletult	doc_740091151003_item	2839001	et	4	main
töötada	doc_740091151003_item	2839002	et	3	main
sest	doc_740091151003_item	2839003	et	4	main
naised	doc_740091151003_item	2839004	et	3	main
aega	doc_740091151003_item	2839011	et	4	main
ning	doc_740091151003_item	2839013	et	3	main
rolli	doc_740091151003_item	2838727	et	4	main
öelda	doc_740091151003_item	2838731	et	4	main
et	doc_740091151003_item	2838732	et	3	main
tõsi	doc_740091151003_item	2838740	et	4	main
näite	doc_740091151003_item	2838746	et	4	main
enamasti	doc_740091151003_item	2838756	et	4	main
esialgu	doc_740091151003_item	2838758	et	3	main
toodi	doc_740091151003_item	2838759	et	4	main
naised	doc_740091151003_item	2838760	et	3	main
avalikkuse	doc_740091151003_item	2838761	et	4	main
ette	doc_740091151003_item	2838762	et	4	main
nende	doc_740091151003_item	2838763	et	4	main
atraktiivse	doc_740091151003_item	2838764	et	4	main
välimuse	doc_740091151003_item	2838765	et	3	main
tõttu	doc_740091151003_item	2838766	et	4	main
kuid	doc_740091151003_item	2838767	et	4	main
siis	doc_740091151003_item	2838768	et	3	main
tuli	doc_740091151003_item	2838769	et	4	main
nii	doc_740091151003_item	2838750	et	3	main
kui	doc_740091151003_item	2838752	et	3	main
olnud	doc_740091151003_item	2838788	et	4	main
mehed	doc_740091151003_item	2838795	et	3	main
olukord	doc_740091151003_item	2838805	et	3	main
ning	doc_740091151003_item	2838809	et	3	main
järjest	doc_740091151003_item	2838813	et	4	main
rohkem	doc_740091151003_item	2838816	et	4	main
on	doc_740091151003_item	2838773	et	4	main
ka	doc_740091151003_item	2838775	et	3	main
öelda	doc_740091151003_item	2838776	et	4	main
olgem	doc_740091151003_item	2838777	et	3	main
ausad	doc_740091151003_item	2838778	et	3	main
figureerivad	doc_740091151003_item	2838790	et	4	main
vaatamata	doc_740091151003_item	2838796	et	4	main
soorollidele	doc_740091151003_item	2838798	et	3	main
väga	doc_740091151003_item	2838800	et	3	main
tippjuhi	doc_740091151003_item	2838803	et	3	main
transformeerumas	doc_740091151003_item	2838808	et	3	main
näeme	doc_740091151003_item	2838811	et	3	main
meestele	doc_740091151003_item	2838822	et	4	main
kena	doc_740091151003_item	2838834	et	4	main
välimus	doc_740091151003_item	2838835	et	3	main
leian	doc_740091151003_item	2838836	et	3	main
et	doc_740091151003_item	2838837	et	3	main
siiski	doc_740091151003_item	2838844	et	4	main
tööalaselt	doc_740091151003_item	2838864	et	4	main
osalevad	doc_740091151003_item	2838872	et	4	main
ka	doc_740091151003_item	2838875	et	3	main
majapidamistöödes	doc_740091151003_item	2838876	et	4	main
võiksid	doc_740091151003_item	2838878	et	4	main
nad	doc_740091151003_item	2838879	et	3	main
teha	doc_740091151003_item	2838880	et	3	main
kuid	doc_740091151003_item	2838883	et	4	main
võrdsustumine	doc_740091151003_item	2838894	et	4	main
omast	doc_740091151003_item	2838921	et	4	main
taga	doc_740091151003_item	2838923	et	4	main
muutuste	doc_740091151003_item	2838943	et	4	main
kohtlemist	doc_740091151003_item	2838962	et	4	main
harjub	doc_740091151003_item	2838966	et	3	main
kõigega	doc_740091151003_item	2838968	et	3	main
piirini	doc_740091151003_item	2838971	et	4	main
tegelikult	doc_740091151003_item	2838972	et	4	main
soodne	doc_740091151003_item	2838980	et	3	main
nad	doc_740091151003_item	2838989	et	3	main
liialt	doc_740091151003_item	2838993	et	4	main
oleks	doc_740091151003_item	2838999	et	3	main
lastega	doc_740091151003_item	2839012	et	3	main
seetõttu	doc_740091151003_item	2839016	et	3	main
enam	doc_740091151003_item	2839021	et	4	main
ometi	doc_740091151003_item	2839023	et	3	main
tunda	doc_740091151003_item	2839025	et	3	main
nad	doc_740091151003_item	2839034	et	3	main
edasist	doc_740091151003_item	2839036	et	3	main
praegu	doc_740091151003_item	2839038	et	3	main
näidanud	doc_740091151003_item	2839048	et	4	main
on	doc_740091151003_item	2839055	et	4	main
raske	doc_740091151003_item	2839056	et	4	main
saavutavad	doc_740091151003_item	2839059	et	4	main
nii	doc_740091151003_item	2839061	et	3	main
pere	doc_740091151003_item	2839062	et	4	main
kui	doc_740091151003_item	2839063	et	3	main
ka	doc_740091151003_item	2839064	et	3	main
meestel	doc_740091151003_item	2839072	et	4	main
sellest	doc_740091151003_item	2839075	et	4	main
on	doc_740091151003_item	2839093	et	4	main
see	doc_740091151003_item	2839110	et	3	main
päris	doc_740091151003_item	2839111	et	4	main
lähe	doc_740091151003_item	2839113	et	4	main
aega	doc_740091151003_item	2839120	et	4	main
on	doc_740091151003_item	2838832	et	4	main
on	doc_740091151003_item	2838840	et	4	main
mehe	doc_740091151003_item	2838841	et	3	main
pereelus	doc_740091151003_item	2838845	et	4	main
ei	doc_740091151003_item	2838847	et	4	main
pidama	doc_740091151003_item	2838858	et	4	main
tihtipelae	doc_740091151003_item	2838859	et	4	main
lapsevanemakohused	doc_740091151003_item	2838867	et	3	main
mehed	doc_740091151003_item	2838871	et	3	main
rohkem	doc_740091151003_item	2838882	et	4	main
jääda	doc_740091151003_item	2838890	et	4	main
mulje	doc_740091151003_item	2838891	et	4	main
et	doc_740091151003_item	2838892	et	3	main
rollide	doc_740091151003_item	2838893	et	3	main
on	doc_740091151003_item	2838895	et	4	main
ainult	doc_740091151003_item	2838896	et	4	main
aja	doc_740091151003_item	2838897	et	4	main
küsimus	doc_740091151003_item	2838898	et	4	main
võib-olla	doc_740091151003_item	2838899	et	3	main
küll	doc_740091151003_item	2838900	et	4	main
aga	doc_740091151003_item	2838901	et	3	main
sel	doc_740091151003_item	2838902	et	3	main
juhul	doc_740091151003_item	2838903	et	3	main
on	doc_740091151003_item	2838904	et	4	main
tegemist	doc_740091151003_item	2838905	et	4	main
väga	doc_740091151003_item	2838906	et	3	main
pika	doc_740091151003_item	2838907	et	4	main
ajaga	doc_740091151003_item	2838908	et	3	main
kõik	doc_740091151003_item	2838909	et	4	main
täheldatavad	doc_740091151003_item	2838910	et	4	main
tendentsid	doc_740091151003_item	2838911	et	3	main
on	doc_740091151003_item	2838912	et	4	main
tohutult	doc_740091151003_item	2838913	et	4	main
aeglased	doc_740091151003_item	2838914	et	3	main
lisaks	doc_740091151003_item	2838915	et	4	main
on	doc_740091151003_item	2838916	et	4	main
ida-euroopa	doc_740091151003_item	2838917	et	4	main
võrdõiguslikkuse	doc_740091151003_item	2838918	et	4	main
poliitika	doc_740091151003_item	2838919	et	4	main
lääne-euroopa	doc_740091151003_item	2838920	et	4	main
on	doc_740091151003_item	2838932	et	4	main
väga	doc_740091151003_item	2838933	et	3	main
nende	doc_740091151003_item	2838942	et	4	main
algul	doc_740091151003_item	2838946	et	4	main
nad	doc_740091151003_item	2838949	et	3	main
sugugi	doc_740091151003_item	2838951	et	4	main
hästi	doc_740091151003_item	2838952	et	3	main
oli	doc_740091151003_item	2838953	et	3	main
ju	doc_740091151003_item	2838954	et	3	main
ennekuulmatu	doc_740091151003_item	2838955	et	4	main
et	doc_740091151003_item	2838956	et	3	main
vagurad	doc_740091151003_item	2838957	et	3	main
nõudsid	doc_740091151003_item	2838959	et	4	main
võrdset	doc_740091151003_item	2838961	et	3	main
inimene	doc_740091151003_item	2838965	et	3	main
on	doc_740091151003_item	2838973	et	4	main
meeste	doc_740091151003_item	2838974	et	4	main
praegune	doc_740091151003_item	2838975	et	3	main
roll	doc_740091151003_item	2838976	et	3	main
ühiskonnas	doc_740091151003_item	2838977	et	4	main
ei	doc_740091151003_item	2838990	et	4	main
määral	doc_740091151003_item	2838995	et	3	main
käivad	doc_740091151003_item	2839005	et	4	main
tööl	doc_740091151003_item	2839006	et	3	main
isad	doc_740091151003_item	2839007	et	3	main
saavad	doc_740091151003_item	2839008	et	4	main
tunnete	doc_740091151003_item	2839018	et	4	main
avaldamine	doc_740091151003_item	2839019	et	4	main
pole	doc_740091151003_item	2839020	et	3	main
miks	doc_740091151003_item	2839030	et	4	main
kõik	doc_740091151003_item	2839040	et	4	main
üsna	doc_740091151003_item	2839042	et	3	main
kuid	doc_740091151003_item	2839045	et	4	main
naised	doc_740091151003_item	2839046	et	3	main
peatada	doc_740091151003_item	2839057	et	3	main
püsivad	doc_740091151003_item	2839070	et	4	main
kõigest	doc_740091151003_item	2839074	et	4	main
vajaka	doc_740091151003_item	2839077	et	3	main
võiks	doc_740091151003_item	2839088	et	4	main
väita	doc_740091151003_item	2839090	et	4	main
sugupool	doc_740091151003_item	2839096	et	4	main
roll	doc_740091151003_item	2839099	et	3	main
võtnud	doc_740091151003_item	2839118	et	4	main
on	doc_740091151003_item	2839123	et	4	main
kui	doc_740091151003_item	2839136	et	3	main
tõrjutakse	doc_740091151003_item	2839138	et	3	main
silmas	doc_740091151003_item	2839141	et	4	main
pidada	doc_740091151003_item	2839142	et	4	main
et	doc_740091151003_item	2839143	et	3	main
infoajastul	doc_740091151003_item	2839144	et	3	main
väheneb	doc_740091151003_item	2839145	et	3	main
on	doc_740091151003_item	2839151	et	4	main
mis	doc_740091151003_item	2839158	et	4	main
kui	doc_740091151003_item	2839166	et	3	main
kui	doc_740091151003_item	2839169	et	3	main
vajadus	doc_740091151003_item	2839174	et	3	main
tahe	doc_740091151003_item	2839176	et	4	main
vastandada	doc_740091151003_item	2839177	et	3	main
kaht	doc_740091151003_item	2839178	et	3	main
sugupoolt	doc_740091151003_item	2839179	et	4	main
ning	doc_740091151003_item	2839187	et	3	main
loomulikult	doc_740091151003_item	2839191	et	4	main
ülalkirjeldam	doc_740091151003_item	2839193	et	4	main
alles	doc_740091151003_item	2839195	et	3	main
aastate	doc_740091151003_item	2839197	et	3	main
mõningast	doc_740091151003_item	2839210	et	4	main
edu	doc_740091151003_item	2839211	et	4	main
omakorda	doc_740091151003_item	2839213	et	3	main
püüavad	doc_740091151003_item	2839214	et	3	main
oma	doc_740091151003_item	2839215	et	4	main
oluline	doc_740091151003_item	2839222	et	4	main
pere	doc_740091151003_item	2839224	et	4	main
ning	doc_740091151003_item	2839225	et	3	main
ei	doc_740091151003_item	2839229	et	4	main
peaks	doc_740091151003_item	2839234	et	4	main
on	doc_740091151003_item	2839247	et	4	main
iga	doc_740091151004_item	2839254	et	4	main
jõuavad	doc_740091151004_item	2839256	et	4	main
kõrvu	doc_740091151004_item	2839258	et	4	main
mingi	doc_740091151003_item	2838970	et	4	main
neile	doc_740091151003_item	2838978	et	4	main
vägagi	doc_740091151003_item	2838979	et	3	main
ei	doc_740091151003_item	2838982	et	4	main
vastutust	doc_740091151003_item	2838987	et	4	main
end	doc_740091151003_item	2838992	et	4	main
ka	doc_740091151003_item	2838997	et	3	main
rohkem	doc_740091151003_item	2839010	et	4	main
on	doc_740091151003_item	2839015	et	4	main
et	doc_740091151003_item	2839026	et	3	main
mehi	doc_740091151003_item	2839027	et	3	main
valdab	doc_740091151003_item	2839028	et	3	main
rahutus	doc_740091151003_item	2839029	et	4	main
küll	doc_740091151003_item	2839031	et	4	main
arengut	doc_740091151003_item	2839037	et	3	main
võib	doc_740091151003_item	2839039	et	3	main
hästi	doc_740091151003_item	2839043	et	3	main
naised	doc_740091151003_item	2839058	et	3	main
on	doc_740091151003_item	2839067	et	4	main
sihikindlad	doc_740091151003_item	2839068	et	3	main
töökad	doc_740091151003_item	2839069	et	3	main
lisaks	doc_740091151003_item	2839078	et	4	main
altimad	doc_740091151003_item	2839081	et	4	main
ahvatlustele	doc_740091151003_item	2839082	et	4	main
nagu	doc_740091151003_item	2839083	et	3	main
alkohol	doc_740091151003_item	2839084	et	3	main
hasartmängud	doc_740091151003_item	2839085	et	3	main
jms	doc_740091151003_item	2839086	et	4	main
et	doc_740091151003_item	2839091	et	3	main
naised	doc_740091151003_item	2839092	et	3	main
saamas	doc_740091151003_item	2839094	et	4	main
tugevam	doc_740091151003_item	2839095	et	4	main
meeste	doc_740091151003_item	2839098	et	4	main
ühiskonnas	doc_740091151003_item	2839100	et	4	main
langeb	doc_740091151003_item	2839103	et	3	main
minimaalseni	doc_740091151003_item	2839104	et	3	main
julgen	doc_740091151003_item	2839105	et	3	main
tohutult	doc_740091151003_item	2839119	et	4	main
astutud	doc_740091151003_item	2839122	et	4	main
väikesed	doc_740091151003_item	2839125	et	4	main
sekundaarsele	doc_740091151003_item	2839131	et	3	main
nii	doc_740091151003_item	2839134	et	3	main
roll	doc_740091151003_item	2839147	et	3	main
ühiskonnas	doc_740091151003_item	2839148	et	4	main
robotid	doc_740091151003_item	2839153	et	3	main
palju	doc_740091151003_item	2839155	et	4	main
osavamaks	doc_740091151003_item	2839165	et	4	main
juhtub	doc_740091151003_item	2839171	et	3	main
igasugune	doc_740091151003_item	2839173	et	3	main
leiutistele	doc_740091151003_item	2839186	et	3	main
võib	doc_740091151003_item	2839192	et	3	main
sadade	doc_740091151003_item	2839196	et	3	main
pärast	doc_740091151003_item	2839198	et	4	main
naised	doc_740091151003_item	2839201	et	3	main
nad	doc_740091151003_item	2839220	et	3	main
valu	doc_740091151004_item	2839253	et	4	main
globaliseerumise	doc_740091151004_item	2839263	et	4	main
ühistatakse	doc_740091151004_item	2839267	et	3	main
kaasnevaid	doc_740091151004_item	2839269	et	4	main
privileege	doc_740091151004_item	2839270	et	3	main
teisalt	doc_740091151004_item	2839271	et	4	main
saavad	doc_740091151004_item	2839296	et	4	main
kaks	doc_740091151004_item	2839299	et	3	main
mõjutamata	doc_740091151004_item	2839306	et	4	main
globaalne	doc_740091151004_item	2839310	et	3	main
inimeste	doc_740091151004_item	2839312	et	3	main
sõnavarasse	doc_740091151004_item	2839314	et	3	main
tugevalt	doc_740091151004_item	2839315	et	4	main
lisandunud	doc_740091151004_item	2839329	et	4	main
oleme	doc_740091151004_item	2839335	et	3	main
pole	doc_740091151004_item	2839341	et	3	main
keskkool	doc_740091151004_item	2839346	et	4	main
ainult	doc_740091151004_item	2839356	et	4	main
üks	doc_740091151004_item	2839357	et	3	main
piiritustest	doc_740091151004_item	2839360	et	4	main
hollandi	doc_740091151004_item	2839362	et	4	main
väärtusi	doc_740091151004_item	2839390	et	3	main
ka	doc_740091151004_item	2839391	et	3	main
hofstede	doc_740091151004_item	2839392	et	4	main
on	doc_740091151004_item	2839433	et	4	main
globaalruumiga	doc_740091151004_item	2839440	et	4	main
veeta	doc_740091151003_item	2839009	et	4	main
pered	doc_740091151003_item	2839014	et	3	main
lähedasemad	doc_740091151003_item	2839017	et	4	main
häbiasi	doc_740091151003_item	2839022	et	3	main
arvatavasti	doc_740091151003_item	2839032	et	3	main
asjade	doc_740091151003_item	2839035	et	3	main
on	doc_740091151003_item	2839047	et	4	main
tööelus	doc_740091151003_item	2839065	et	4	main
nad	doc_740091151003_item	2839066	et	3	main
jääb	doc_740091151003_item	2839073	et	3	main
tihtilugu	doc_740091151003_item	2839076	et	3	main
on	doc_740091151003_item	2839079	et	4	main
nad	doc_740091151003_item	2839080	et	3	main
seega	doc_740091151003_item	2839087	et	4	main
ei	doc_740091151003_item	2839112	et	4	main
kuna	doc_740091151003_item	2839114	et	3	main
soorollide	doc_740091151003_item	2839115	et	3	main
veel	doc_740091151003_item	2839133	et	4	main
tuleb	doc_740091151003_item	2839140	et	3	main
üldiselt	doc_740091151003_item	2839149	et	4	main
meil	doc_740091151003_item	2839150	et	4	main
varem	doc_740091151003_item	2839159	et	4	main
inimkond	doc_740091151003_item	2839167	et	3	main
kaob	doc_740091151003_item	2839172	et	3	main
jätkamine	doc_740091151003_item	2839181	et	4	main
saab	doc_740091151003_item	2839182	et	3	main
peremudel	doc_740091151003_item	2839189	et	3	main
võitlevad	doc_740091151003_item	2839200	et	4	main
ikka	doc_740091151003_item	2839202	et	4	main
õiguste	doc_740091151003_item	2839204	et	4	main
eest	doc_740091151003_item	2839205	et	4	main
ning	doc_740091151003_item	2839206	et	3	main
liidrirolli	doc_740091151003_item	2839216	et	4	main
säilitada	doc_740091151003_item	2839217	et	3	main
on	doc_740091151003_item	2839223	et	4	main
et	doc_740091151003_item	2839226	et	3	main
tunnete	doc_740091151003_item	2839227	et	4	main
nõrkust	doc_740091151003_item	2839231	et	4	main
kui	doc_740091151003_item	2839232	et	3	main
tõepoolest	doc_740091151003_item	2839235	et	3	main
jõudma	doc_740091151003_item	2839237	et	3	main
kosmoseajastu	doc_740091151003_item	2839240	et	4	main
hoopis	doc_740091151003_item	2839244	et	3	main
väljend	doc_740091151003_item	2839245	et	3	main
globaliseerimise	doc_740091151004_item	2839250	et	4	main
võlu	doc_740091151004_item	2839251	et	4	main
ja	doc_740091151004_item	2839252	et	3	main
päev	doc_740091151004_item	2839255	et	3	main
meie	doc_740091151004_item	2839257	et	4	main
arutelud	doc_740091151004_item	2839260	et	3	main
ja	doc_740091151004_item	2839261	et	3	main
sõnavõtud	doc_740091151004_item	2839262	et	3	main
kritiseeritakse	doc_740091151004_item	2839272	et	3	main
dimensiooni	doc_740091151004_item	2839302	et	4	main
on	doc_740091151004_item	2839308	et	4	main
end	doc_740091151004_item	2839311	et	4	main
aktiivsesse	doc_740091151004_item	2839313	et	4	main
tänapäeva	doc_740091151004_item	2839325	et	4	main
inimeste	doc_740091151004_item	2839326	et	3	main
mõttemaailma	doc_740091151004_item	2839327	et	4	main
maailmakodanikena	doc_740091151004_item	2839334	et	3	main
vabaduse	doc_740091151004_item	2839337	et	4	main
ebatavaline	doc_740091151004_item	2839342	et	4	main
lasteaiaaastad	doc_740091151004_item	2839344	et	3	main
saksamaal	doc_740091151004_item	2839348	et	4	main
kaitsta	doc_740091151004_item	2839351	et	4	main
austraalias	doc_740091151004_item	2839352	et	4	main
globaalne	doc_740091151004_item	2839353	et	3	main
haridusruum	doc_740091151004_item	2839354	et	3	main
globaalmaailma	doc_740091151004_item	2839359	et	4	main
ei	doc_740091151004_item	2839368	et	4	main
kaasne	doc_740091151004_item	2839369	et	4	main
unifitseerumist	doc_740091151004_item	2839371	et	4	main
väärtused	doc_740091151004_item	2839372	et	3	main
traditsioonid	doc_740091151004_item	2839373	et	3	main
ja	doc_740091151004_item	2839374	et	3	main
kombed	doc_740091151004_item	2839375	et	3	main
on	doc_740091151004_item	2839376	et	4	main
need	doc_740091151004_item	2839377	et	3	main
juurdunud	doc_740091151004_item	2839381	et	4	main
uurimus	doc_740091151004_item	2839393	et	3	main
on	doc_740091151003_item	2839024	et	4	main
kardavad	doc_740091151003_item	2839033	et	4	main
ju	doc_740091151003_item	2839041	et	3	main
olla	doc_740091151003_item	2839044	et	3	main
milleks	doc_740091151003_item	2839049	et	4	main
nad	doc_740091151003_item	2839050	et	3	main
võimelised	doc_740091151003_item	2839051	et	4	main
on	doc_740091151003_item	2839052	et	4	main
ning	doc_740091151003_item	2839053	et	3	main
neid	doc_740091151003_item	2839054	et	4	main
edu	doc_740091151003_item	2839060	et	4	main
jne	doc_740091151003_item	2839071	et	4	main
ju	doc_740091151003_item	2839089	et	3	main
ning	doc_740091151003_item	2839097	et	3	main
väheneb	doc_740091151003_item	2839101	et	3	main
kuni	doc_740091151003_item	2839102	et	3	main
siiski	doc_740091151003_item	2839106	et	4	main
väita	doc_740091151003_item	2839107	et	4	main
et	doc_740091151003_item	2839108	et	3	main
nii	doc_740091151003_item	2839109	et	3	main
muutumine	doc_740091151003_item	2839116	et	4	main
on	doc_740091151003_item	2839117	et	4	main
ja	doc_740091151003_item	2839121	et	3	main
vaid	doc_740091151003_item	2839124	et	3	main
sammud	doc_740091151003_item	2839126	et	4	main
siis	doc_740091151003_item	2839127	et	3	main
mehi	doc_740091151003_item	2839128	et	3	main
kohale	doc_740091151003_item	2839132	et	4	main
inimese	doc_740091151003_item	2839146	et	4	main
ja	doc_740091151003_item	2839154	et	3	main
muud	doc_740091151003_item	2839156	et	4	main
uuendusi	doc_740091151003_item	2839157	et	4	main
hiljem	doc_740091151003_item	2839161	et	3	main
targemaks	doc_740091151003_item	2839163	et	4	main
see	doc_740091151003_item	2839170	et	3	main
soo	doc_740091151003_item	2839180	et	4	main
tänu	doc_740091151003_item	2839184	et	4	main
oma	doc_740091151003_item	2839203	et	4	main
mehed	doc_740091151003_item	2839212	et	3	main
samas	doc_740091151003_item	2839218	et	4	main
ei	doc_740091151003_item	2839129	et	4	main
tõrjuta	doc_740091151003_item	2839130	et	3	main
pea	doc_740091151003_item	2839135	et	4	main
üldse	doc_740091151003_item	2839137	et	3	main
nimelt	doc_740091151003_item	2839139	et	4	main
internet	doc_740091151003_item	2839152	et	4	main
või	doc_740091151003_item	2839160	et	4	main
saavad	doc_740091151003_item	2839162	et	4	main
ja	doc_740091151003_item	2839164	et	3	main
tervikuna	doc_740091151003_item	2839168	et	3	main
või	doc_740091151003_item	2839175	et	4	main
teoks	doc_740091151003_item	2839183	et	4	main
tehnoinnovaatilistele	doc_740091151003_item	2839185	et	4	main
traditsiooniline	doc_740091151003_item	2839188	et	4	main
kaob	doc_740091151003_item	2839190	et	3	main
juhtuda	doc_740091151003_item	2839194	et	3	main
senimaani	doc_740091151003_item	2839199	et	3	main
kindlasti	doc_740091151003_item	2839207	et	3	main
saavutavad	doc_740091151003_item	2839208	et	4	main
ka	doc_740091151003_item	2839209	et	3	main
mõistavad	doc_740091151003_item	2839219	et	3	main
kui	doc_740091151003_item	2839221	et	3	main
tähenda	doc_740091151003_item	2839230	et	4	main
kätte	doc_740091151003_item	2839236	et	4	main
roboti-	doc_740091151003_item	2839238	et	3	main
maalt	doc_740091151003_item	2839248	et	3	main
ühelt	doc_740091151004_item	2839265	et	3	main
need	doc_740091151004_item	2839298	et	3	main
teineteist	doc_740091151004_item	2839305	et	4	main
globaliseerumisest	doc_740091151004_item	2839318	et	4	main
globalprobleemidega	doc_740091151004_item	2839321	et	4	main
et	doc_740091151004_item	2839324	et	3	main
mööde	doc_740091151004_item	2839332	et	4	main
globaalmõtlemine	doc_740091151004_item	2839333	et	3	main
harjunud	doc_740091151004_item	2839336	et	4	main
eestis	doc_740091151004_item	2839345	et	3	main
on	doc_740091151004_item	2839355	et	4	main
globaliseerumisega	doc_740091151004_item	2839367	et	4	main
oma	doc_740091151004_item	2839388	et	4	main
rahvuslikke	doc_740091151004_item	2839389	et	3	main
erinevate	doc_740091151004_item	2839394	et	4	main
näitamine	doc_740091151003_item	2839228	et	4	main
ükskord	doc_740091151003_item	2839233	et	3	main
ja	doc_740091151003_item	2839239	et	3	main
hakkab	doc_740091151003_item	2839241	et	3	main
ehk	doc_740091151003_item	2839242	et	3	main
levima	doc_740091151003_item	2839243	et	3	main
inimesed	doc_740091151003_item	2839246	et	3	main
essee	doc_740091151004_item	2839249	et	4	main
teemadel	doc_740091151004_item	2839264	et	3	main
poolt	doc_740091151004_item	2839266	et	4	main
maailmastumisega	doc_740091151004_item	2839268	et	4	main
nn	doc_740091151004_item	2839273	et	4	main
oma	doc_740091151004_item	2839274	et	4	main
näo	doc_740091151004_item	2839275	et	3	main
kadumist	doc_740091151004_item	2839276	et	4	main
ning	doc_740091151004_item	2839277	et	3	main
kultuuri	doc_740091151004_item	2839278	et	4	main
iseärasuste	doc_740091151004_item	2839279	et	4	main
hääbumist	doc_740091151004_item	2839280	et	4	main
jääb	doc_740091151004_item	2839281	et	3	main
mulje	doc_740091151004_item	2839282	et	4	main
et	doc_740091151004_item	2839283	et	3	main
globaalsus	doc_740091151004_item	2839284	et	4	main
ja	doc_740091151004_item	2839285	et	3	main
on	doc_740091151004_item	2839287	et	4	main
kaks	doc_740091151004_item	2839288	et	3	main
lokaalsus	doc_740091151004_item	2839286	et	4	main
vastandlikku	doc_740091151004_item	2839289	et	4	main
nähtust	doc_740091151004_item	2839290	et	4	main
mis	doc_740091151004_item	2839291	et	4	main
välistavad	doc_740091151004_item	2839292	et	4	main
teineteise	doc_740091151004_item	2839293	et	4	main
olemasolu	doc_740091151004_item	2839294	et	4	main
kirglikud	doc_740091151004_item	2839259	et	3	main
koos	doc_740091151004_item	2839303	et	4	main
eksisteerida	doc_740091151004_item	2839304	et	3	main
sõna	doc_740091151004_item	2839309	et	4	main
kinnistunud	doc_740091151004_item	2839316	et	4	main
alustades	doc_740091151004_item	2839317	et	3	main
lõpetades	doc_740091151004_item	2839320	et	3	main
on	doc_740091151004_item	2839328	et	4	main
piiritute	doc_740091151004_item	2839339	et	4	main
veeta	doc_740091151004_item	2839343	et	4	main
lõpetada	doc_740091151004_item	2839347	et	3	main
bakalaureusetöö	doc_740091151004_item	2839350	et	4	main
kultuuriuurija	doc_740091151004_item	2839363	et	4	main
hofstede	doc_740091151004_item	2839364	et	4	main
usub	doc_740091151004_item	2839365	et	3	main
et	doc_740091151004_item	2839366	et	3	main
väärtuste	doc_740091151004_item	2839370	et	4	main
mis	doc_740091151004_item	2839378	et	4	main
sügavalt	doc_740091151004_item	2839380	et	4	main
ning	doc_740091151004_item	2839382	et	3	main
globaliseerivas	doc_740091151004_item	2839383	et	4	main
maailmas	doc_740091151004_item	2839384	et	3	main
inimesed	doc_740091151004_item	2839385	et	3	main
pigem	doc_740091151004_item	2839386	et	3	main
rõhutavad	doc_740091151004_item	2839387	et	4	main
ei	doc_740091151004_item	2839422	et	4	main
ka	doc_740091151004_item	2839424	et	3	main
seega	doc_740091151004_item	2839425	et	4	main
et	doc_740091151004_item	2839428	et	3	main
pole	doc_740091151004_item	2839429	et	3	main
muu	doc_740091151004_item	2839438	et	4	main
eksisteerivad	doc_740091151004_item	2839442	et	4	main
erinevused	doc_740091151004_item	2839452	et	4	main
tuttavam	doc_740091151004_item	2839499	et	4	main
tööd	doc_740091151004_item	2839502	et	4	main
mugavamalt	doc_740091151004_item	2839510	et	4	main
ja	doc_740091151004_item	2839511	et	3	main
kindlamalt	doc_740091151004_item	2839512	et	4	main
inimene	doc_740091151004_item	2839513	et	3	main
tunneb	doc_740091151004_item	2839515	et	3	main
arvukalt	doc_740091151004_item	2839520	et	4	main
arusaamatuks	doc_740091151004_item	2839530	et	4	main
ning	doc_740091151004_item	2839531	et	3	main
tunduvad	doc_740091151004_item	2839537	et	4	main
tekitavad	doc_740091151004_item	2839541	et	4	main
esialgu	doc_740091151004_item	2839543	et	3	main
eelnevast	doc_740091151004_item	2839553	et	4	main
maailmas	doc_740091151004_item	2839562	et	3	main
ühtsete	doc_740091151004_item	2839564	et	4	main
areneda	doc_740091151004_item	2839574	et	3	main
on	doc_740091151004_item	2839576	et	4	main
kultuuri	doc_740091151004_item	2839579	et	4	main
vooderdada	doc_740091151004_item	2839586	et	3	main
turvalisse	doc_740091151004_item	2839587	et	4	main
globaalkeskkonda	doc_740091151004_item	2839588	et	4	main
ole	doc_740091151004_item	2839598	et	4	main
võimalik	doc_740091151004_item	2839599	et	3	main
inimesed	doc_740091151004_item	2839605	et	3	main
mõistaksid	doc_740091151004_item	2839606	et	4	main
positiivne	doc_740091151004_item	2839638	et	3	main
rahvuslik	doc_740091151004_item	2839646	et	3	main
olla	doc_740091151004_item	2839668	et	3	main
sügavalt	doc_740091151004_item	2839684	et	4	main
aga	doc_740091151004_item	2839686	et	3	main
oluline	doc_740091151004_item	2839698	et	4	main
toidetakse	doc_740091151004_item	2839703	et	3	main
kindlasti	doc_740091151004_item	2839705	et	3	main
parim	doc_740091151004_item	2839711	et	4	main
on	doc_740091151004_item	2839722	et	4	main
aga	doc_740091151004_item	2839733	et	3	main
palju	doc_740091151004_item	2839734	et	4	main
negatiivset	doc_740091151004_item	2839735	et	3	main
näidanud	doc_740091151004_item	2839746	et	4	main
ka	doc_740091151004_item	2839747	et	3	main
ei	doc_740091151004_item	2839754	et	4	main
kas	doc_740091151004_item	2839757	et	3	main
jensenil	doc_740091151004_item	2839759	et	4	main
on	doc_740091151004_item	2839760	et	4	main
unelmate	doc_740091151004_item	2839768	et	3	main
ühiskond	doc_740091151004_item	2839769	et	3	main
mille	doc_740091151004_item	2839770	et	3	main
kas	doc_740091151004_item	2839295	et	3	main
aga	doc_740091151004_item	2839297	et	3	main
näiliselt	doc_740091151004_item	2839300	et	4	main
vastandlikku	doc_740091151004_item	2839301	et	4	main
tänaseks	doc_740091151004_item	2839307	et	4	main
ja	doc_740091151004_item	2839319	et	3	main
kohati	doc_740091151004_item	2839322	et	4	main
tundub	doc_740091151004_item	2839323	et	3	main
lausa	doc_740091151004_item	2839330	et	4	main
uus	doc_740091151004_item	2839331	et	3	main
ning	doc_740091151004_item	2839338	et	3	main
võimalustega	doc_740091151004_item	2839340	et	3	main
ning	doc_740091151004_item	2839349	et	3	main
näide	doc_740091151004_item	2839358	et	3	main
võimalustest	doc_740091151004_item	2839361	et	3	main
on	doc_740091151004_item	2839379	et	4	main
rahvuste	doc_740091151004_item	2839395	et	3	main
kohta	doc_740091151004_item	2839396	et	4	main
mille	doc_740091151004_item	2839397	et	3	main
tulemusel	doc_740091151004_item	2839398	et	3	main
eristab	doc_740091151004_item	2839399	et	3	main
ta	doc_740091151004_item	2839400	et	4	main
viit	doc_740091151004_item	2839401	et	4	main
erinevat	doc_740091151004_item	2839402	et	4	main
kultuuridimensiooni	doc_740091151004_item	2839403	et	4	main
tõestab	doc_740091151004_item	2839404	et	3	main
sama	doc_740091151004_item	2839405	et	4	main
see	doc_740091151004_item	2839406	et	3	main
näiteks	doc_740091151004_item	2839407	et	4	main
et	doc_740091151004_item	2839408	et	3	main
eesti	doc_740091151004_item	2839409	et	4	main
kuulub	doc_740091151004_item	2839410	et	3	main
feminiinsete	doc_740091151004_item	2839411	et	3	main
kultuuride	doc_740091151004_item	2839412	et	3	main
hulka	doc_740091151004_item	2839413	et	4	main
ei	doc_740091151004_item	2839414	et	4	main
ole	doc_740091151004_item	2839415	et	4	main
pikkade	doc_740091151004_item	2839416	et	4	main
aastate	doc_740091151004_item	2839417	et	3	main
jooksul	doc_740091151004_item	2839418	et	4	main
muutunud	doc_740091151004_item	2839419	et	4	main
tema	doc_740091151004_item	2839420	et	4	main
võib	doc_740091151004_item	2839426	et	3	main
järeldada	doc_740091151004_item	2839427	et	3	main
vahet	doc_740091151004_item	2839430	et	3	main
kas	doc_740091151004_item	2839431	et	3	main
tegu	doc_740091151004_item	2839432	et	4	main
valdkonna	doc_740091151004_item	2839439	et	4	main
määramatust	doc_740091151004_item	2839485	et	4	main
ta	doc_740091151004_item	2839488	et	4	main
suhtleb	doc_740091151004_item	2839491	et	3	main
selleks	doc_740091151004_item	2839493	et	4	main
nii	doc_740091151004_item	2839501	et	3	main
seda	doc_740091151004_item	2839526	et	3	main
alati	doc_740091151004_item	2839441	et	4	main
nn	doc_740091151004_item	2839444	et	4	main
on	doc_740091151004_item	2839451	et	4	main
võõrale	doc_740091151004_item	2839459	et	4	main
reisides	doc_740091151004_item	2839462	et	4	main
euroopas	doc_740091151004_item	2839463	et	3	main
valib	doc_740091151004_item	2839464	et	3	main
suure	doc_740091151004_item	2839465	et	3	main
tõenäosusega	doc_740091151004_item	2839466	et	3	main
lõunasöögiks	doc_740091151004_item	2839467	et	3	main
mcdonaldsi	doc_740091151004_item	2839468	et	4	main
burgerieine	doc_740091151004_item	2839469	et	4	main
sest	doc_740091151004_item	2839470	et	4	main
see	doc_740091151004_item	2839471	et	3	main
on	doc_740091151004_item	2839472	et	4	main
talle	doc_740091151004_item	2839473	et	4	main
tuttav	doc_740091151004_item	2839474	et	3	main
ka	doc_740091151004_item	2839475	et	3	main
määramatuse	doc_740091151004_item	2839476	et	4	main
vahendamise	doc_740091151004_item	2839477	et	4	main
teooria	doc_740091151004_item	2839478	et	4	main
kohaselt	doc_740091151004_item	2839479	et	4	main
sõnul	doc_740091151004_item	2839421	et	3	main
muutu	doc_740091151004_item	2839423	et	4	main
hariduse	doc_740091151004_item	2839434	et	3	main
majanduse	doc_740091151004_item	2839435	et	4	main
või	doc_740091151004_item	2839436	et	4	main
mõne	doc_740091151004_item	2839437	et	3	main
varieerumised	doc_740091151004_item	2839443	et	4	main
piiritu	doc_740091151004_item	2839445	et	4	main
sees	doc_740091151004_item	2839447	et	4	main
pole	doc_740091151004_item	2839448	et	3	main
piire	doc_740091151004_item	2839449	et	4	main
aga	doc_740091151004_item	2839450	et	3	main
on	doc_740091151004_item	2839455	et	4	main
omane	doc_740091151004_item	2839456	et	3	main
eelistada	doc_740091151004_item	2839457	et	3	main
tuttavat	doc_740091151004_item	2839458	et	3	main
ameeriklane	doc_740091151004_item	2839461	et	3	main
on	doc_740091151004_item	2839480	et	4	main
vähendada	doc_740091151004_item	2839484	et	3	main
sotsiaalset	doc_740091151004_item	2839489	et	3	main
teda	doc_740091151004_item	2839495	et	4	main
ümbritsev	doc_740091151004_item	2839496	et	4	main
maailm	doc_740091151004_item	2839497	et	3	main
oleks	doc_740091151004_item	2839498	et	3	main
määramatus	doc_740091151004_item	2839508	et	4	main
seda	doc_740091151004_item	2839509	et	3	main
ka	doc_740091151004_item	2839516	et	3	main
saab	doc_740091151004_item	2839518	et	3	main
sellest	doc_740091151004_item	2839522	et	4	main
kuidas	doc_740091151004_item	2839523	et	3	main
avastused	doc_740091151004_item	2839534	et	4	main
inimajus	doc_740091151004_item	2839542	et	4	main
paradigmade	doc_740091151004_item	2839546	et	3	main
on	doc_740091151004_item	2839548	et	4	main
inimene	doc_740091151004_item	2839560	et	3	main
oma	doc_740091151004_item	2839563	et	4	main
tuttavate	doc_740091151004_item	2839565	et	3	main
ja	doc_740091151004_item	2839566	et	3	main
turvaliste	doc_740091151004_item	2839567	et	4	main
arusaamadega	doc_740091151004_item	2839568	et	3	main
inimlik	doc_740091151004_item	2839569	et	3	main
on	doc_740091151004_item	2839570	et	4	main
õppida	doc_740091151004_item	2839573	et	3	main
inimlik	doc_740091151004_item	2839575	et	3	main
end	doc_740091151004_item	2839585	et	4	main
võimalik	doc_740091151004_item	2839591	et	3	main
globaalruumi	doc_740091151004_item	2839594	et	4	main
samamoodi	doc_740091151004_item	2839595	et	3	main
nagu	doc_740091151004_item	2839596	et	3	main
ei	doc_740091151004_item	2839597	et	4	main
universaalset	doc_740091151004_item	2839601	et	3	main
keelt	doc_740091151004_item	2839602	et	4	main
kõik	doc_740091151004_item	2839604	et	4	main
süsteemi	doc_740091151004_item	2839446	et	4	main
inimese	doc_740091151004_item	2839453	et	4	main
psühholoogiale	doc_740091151004_item	2839454	et	4	main
näiteks	doc_740091151004_item	2839460	et	4	main
kaasasündinud	doc_740091151004_item	2839482	et	4	main
kogub	doc_740091151004_item	2839487	et	3	main
informatsiooni	doc_740091151004_item	2839490	et	4	main
suhteid	doc_740091151004_item	2839504	et	3	main
väiksem	doc_740091151004_item	2839506	et	4	main
on	doc_740091151004_item	2839507	et	4	main
end	doc_740091151004_item	2839514	et	4	main
ajaloost	doc_740091151004_item	2839517	et	4	main
tuua	doc_740091151004_item	2839519	et	3	main
inimesed	doc_740091151004_item	2839524	et	3	main
mõistmatuks	doc_740091151004_item	2839532	et	4	main
teooriad	doc_740091151004_item	2839535	et	3	main
need	doc_740091151004_item	2839540	et	3	main
äreva	doc_740091151004_item	2839544	et	3	main
muutused	doc_740091151004_item	2839547	et	4	main
alati	doc_740091151004_item	2839549	et	4	main
teatud	doc_740091151004_item	2839550	et	4	main
ka	doc_740091151004_item	2839572	et	3	main
oma	doc_740091151004_item	2839578	et	4	main
austada	doc_740091151004_item	2839580	et	3	main
ei	doc_740091151004_item	2839582	et	4	main
ole	doc_740091151004_item	2839583	et	4	main
võimalik	doc_740091151004_item	2839584	et	3	main
ei	doc_740091151004_item	2839589	et	4	main
luua	doc_740091151004_item	2839592	et	4	main
nii	doc_740091151004_item	2839607	et	3	main
turvaliselt	doc_740091151004_item	2839621	et	4	main
mikromaailma	doc_740091151004_item	2839623	et	4	main
saab	doc_740091151004_item	2839624	et	3	main
iga	doc_740091151004_item	2839625	et	4	main
inimene	doc_740091151004_item	2839626	et	3	main
luua	doc_740091151004_item	2839630	et	4	main
globaalsuse	doc_740091151004_item	2839632	et	4	main
või	doc_740091151004_item	2839634	et	4	main
on	doc_740091151004_item	2839640	et	4	main
kindlasti	doc_740091151004_item	2839641	et	3	main
asjaolu	doc_740091151004_item	2839655	et	4	main
ignoreerides	doc_740091151004_item	2839656	et	3	main
keeruliseks	doc_740091151004_item	2839662	et	4	main
globliseerumine	doc_740091151004_item	2839666	et	4	main
sest	doc_740091151004_item	2839670	et	4	main
vastupidiselt	doc_740091151004_item	2839671	et	4	main
käitudes	doc_740091151004_item	2839672	et	3	main
eraldab	doc_740091151004_item	2839673	et	3	main
inimene	doc_740091151004_item	2839674	et	3	main
end	doc_740091151004_item	2839675	et	4	main
maailmakodanike	doc_740091151004_item	2839677	et	3	main
soovides	doc_740091151004_item	2839687	et	4	main
olla	doc_740091151004_item	2839688	et	3	main
suhtleja	doc_740091151004_item	2839691	et	4	main
inimene	doc_740091151004_item	2839693	et	3	main
kõrvale	doc_740091151004_item	2839695	et	4	main
heitma	doc_740091151004_item	2839696	et	3	main
kaudu	doc_740091151004_item	2839701	et	3	main
on	doc_740091151004_item	2839708	et	4	main
piire	doc_740091151004_item	2839717	et	4	main
raske	doc_740091151004_item	2839719	et	4	main
hoomata	doc_740091151004_item	2839720	et	4	main
inimesel	doc_740091151004_item	2839481	et	3	main
vajadus	doc_740091151004_item	2839483	et	3	main
selleks	doc_740091151004_item	2839486	et	4	main
inimestega	doc_740091151004_item	2839492	et	3	main
et	doc_740091151004_item	2839494	et	3	main
hõlmates	doc_740091151004_item	2839500	et	3	main
kui	doc_740091151004_item	2839503	et	3	main
mida	doc_740091151004_item	2839505	et	4	main
näiteid	doc_740091151004_item	2839521	et	3	main
kardavad	doc_740091151004_item	2839525	et	4	main
mis	doc_740091151004_item	2839527	et	4	main
jääb	doc_740091151004_item	2839528	et	3	main
uued	doc_740091151004_item	2839533	et	3	main
kõik	doc_740091151004_item	2839539	et	4	main
reaktsiooni	doc_740091151004_item	2839545	et	4	main
väljakutse	doc_740091151004_item	2839551	et	4	main
tundub	doc_740091151004_item	2839555	et	3	main
lausa	doc_740091151004_item	2839557	et	4	main
inimlik	doc_740091151004_item	2839558	et	3	main
aga	doc_740091151004_item	2839571	et	3	main
ole	doc_740091151004_item	2839590	et	4	main
luua	doc_740091151004_item	2839600	et	4	main
mida	doc_740091151004_item	2839603	et	4	main
ole	doc_740091151004_item	2839609	et	4	main
ise	doc_740091151004_item	2839627	et	4	main
enda	doc_740091151004_item	2839628	et	4	main
ümber	doc_740091151004_item	2839629	et	3	main
nähtus	doc_740091151004_item	2839639	et	4	main
püüe	doc_740091151004_item	2839642	et	3	main
taust	doc_740091151004_item	2839647	et	4	main
konkreetse	doc_740091151004_item	2839651	et	3	main
indiviidi	doc_740091151004_item	2839652	et	4	main
seda	doc_740091151004_item	2839654	et	3	main
kujuneda	doc_740091151004_item	2839663	et	3	main
tingib	doc_740091151004_item	2839665	et	3	main
vajaduse	doc_740091151004_item	2839667	et	3	main
teiste	doc_740091151004_item	2839676	et	4	main
rahvuslikud	doc_740091151004_item	2839679	et	3	main
on	doc_740091151004_item	2839681	et	4	main
küll	doc_740091151004_item	2839682	et	4	main
tihti	doc_740091151004_item	2839683	et	3	main
üks	doc_740091151004_item	2839697	et	3	main
ning	doc_740091151004_item	2839713	et	3	main
lokaalseid	doc_740091151004_item	2839716	et	3	main
sealt	doc_740091151004_item	2839721	et	4	main
ammutada	doc_740091151004_item	2839724	et	3	main
saanud	doc_740091151004_item	2839737	et	4	main
nakkav	doc_740091151004_item	2839739	et	4	main
sõltuvust	doc_740091151004_item	2839740	et	4	main
tekitav	doc_740091151004_item	2839741	et	4	main
ning	doc_740091151004_item	2839742	et	3	main
petlik	doc_740091151004_item	2839743	et	3	main
rolf	doc_740091151004_item	2839758	et	4	main
ees	doc_740091151004_item	2839766	et	4	main
nn	doc_740091151004_item	2839767	et	4	main
infoühiskonna	doc_740091151004_item	2839778	et	4	main
aga	doc_740091151004_item	2839780	et	3	main
globaliseerumisprotsessis	doc_740091151004_item	2839789	et	4	main
pole	doc_740091151004_item	2839790	et	3	main
aga	doc_740091151004_item	2839794	et	3	main
kas	doc_740091151004_item	2839796	et	3	main
sellest	doc_740091151004_item	2839807	et	4	main
muutuks	doc_740091151004_item	2839822	et	4	main
ainult	doc_740091151004_item	2839823	et	4	main
rahvuste	doc_740091151004_item	2839825	et	3	main
nägu	doc_740091151004_item	2839826	et	4	main
oleks	doc_740091151004_item	2839827	et	3	main
amerikaniseerumine	doc_740091151004_item	2839837	et	4	main
peale	doc_740091151004_item	2839850	et	4	main
globaalsuse	doc_740091151004_item	2839860	et	4	main
pärast	doc_740091151004_item	2839861	et	4	main
globaalsus	doc_740091151004_item	2839862	et	4	main
ja	doc_740091151004_item	2839863	et	3	main
ühtse	doc_740091151004_item	2839870	et	3	main
neid	doc_740091151004_item	2839894	et	4	main
kahte	doc_740091151004_item	2839895	et	4	main
neile	doc_740091151004_item	2839529	et	4	main
utoopilistena	doc_740091151004_item	2839536	et	3	main
ennustused	doc_740091151004_item	2839538	et	4	main
kui	doc_740091151004_item	2839552	et	3	main
lähtuda	doc_740091151004_item	2839554	et	3	main
globaliseerumine	doc_740091151004_item	2839556	et	4	main
globaalne	doc_740091151004_item	2839559	et	3	main
globaalses	doc_740091151004_item	2839561	et	3	main
väärtustada	doc_740091151004_item	2839577	et	3	main
esivanemaid	doc_740091151004_item	2839581	et	4	main
absoluutset	doc_740091151004_item	2839593	et	3	main
ei	doc_740091151004_item	2839608	et	4	main
võimalik	doc_740091151004_item	2839610	et	3	main
ka	doc_740091151004_item	2839611	et	3	main
universaalne	doc_740091151004_item	2839612	et	3	main
globaalmaailm	doc_740091151004_item	2839613	et	3	main
kus	doc_740091151004_item	2839614	et	3	main
kõik	doc_740091151004_item	2839615	et	4	main
inimesed	doc_740091151004_item	2839616	et	3	main
tunneksid	doc_740091151004_item	2839617	et	4	main
end	doc_740091151004_item	2839618	et	4	main
mugavalt	doc_740091151004_item	2839619	et	4	main
ja	doc_740091151004_item	2839620	et	3	main
kaasnev	doc_740091151004_item	2839637	et	4	main
teineteist	doc_740091151004_item	2839643	et	4	main
paremini	doc_740091151004_item	2839644	et	4	main
määrab	doc_740091151004_item	2839648	et	3	main
tasandil	doc_740091151004_item	2839659	et	3	main
väga	doc_740091151004_item	2839661	et	3	main
tolerantsem	doc_740091151004_item	2839669	et	4	main
edukas	doc_740091151004_item	2839689	et	4	main
neid	doc_740091151004_item	2839694	et	4	main
mille	doc_740091151004_item	2839700	et	3	main
globaliseerumist	doc_740091151004_item	2839702	et	4	main
on	doc_740091151004_item	2839704	et	4	main
globaalse	doc_740091151004_item	2839709	et	3	main
näide	doc_740091151004_item	2839712	et	3	main
kus	doc_740091151004_item	2839715	et	3	main
oma	doc_740091151004_item	2839730	et	4	main
pahupool	doc_740091151004_item	2839744	et	4	main
ei	doc_740091151004_item	2839745	et	4	main
see	doc_740091151004_item	2839748	et	3	main
ei	doc_740091151004_item	2839750	et	4	main
kaugeltki	doc_740091151004_item	2839752	et	4	main
oska	doc_740091151004_item	2839755	et	4	main
vähenemist	doc_740091151004_item	2839788	et	4	main
näha	doc_740091151004_item	2839793	et	3	main
kaotada	doc_740091151004_item	2839810	et	3	main
globaliseerumisprotsess	doc_740091151004_item	2839814	et	4	main
teiste	doc_740091151004_item	2839816	et	4	main
järgi	doc_740091151004_item	2839818	et	4	main
ning	doc_740091151004_item	2839819	et	3	main
maailm	doc_740091151004_item	2839820	et	3	main
muretsemiseks	doc_740091151004_item	2839829	et	4	main
nn	doc_740091151004_item	2839836	et	4	main
me	doc_740091151004_item	2839840	et	4	main
eestitseerumisse	doc_740091151004_item	2839842	et	4	main
tundub	doc_740091151004_item	2839843	et	3	main
et	doc_740091151004_item	2839844	et	3	main
nii	doc_740091151004_item	2839845	et	3	main
kaua	doc_740091151004_item	2839846	et	3	main
kui	doc_740091151004_item	2839847	et	3	main
ei	doc_740091151004_item	2839848	et	4	main
pole	doc_740091151004_item	2839853	et	3	main
selle	doc_740091151004_item	2839858	et	4	main
sõna	doc_740091151004_item	2839859	et	4	main
ei	doc_740091151004_item	2839865	et	4	main
ühendada	doc_740091151004_item	2839897	et	3	main
sellese	doc_740091151004_item	2839622	et	4	main
kohandades	doc_740091151004_item	2839631	et	3	main
lokaalsusega	doc_740091151004_item	2839633	et	4	main
vastupidi	doc_740091151004_item	2839635	et	3	main
globaliseerimisega	doc_740091151004_item	2839636	et	4	main
mõista	doc_740091151004_item	2839645	et	4	main
suuresti	doc_740091151004_item	2839649	et	4	main
ära	doc_740091151004_item	2839650	et	4	main
näo	doc_740091151004_item	2839653	et	3	main
võib	doc_740091151004_item	2839657	et	3	main
globaalses	doc_740091151004_item	2839658	et	3	main
suhtlemine	doc_740091151004_item	2839660	et	4	main
paratamatult	doc_740091151004_item	2839664	et	4	main
seast	doc_740091151004_item	2839678	et	4	main
stereotüübid	doc_740091151004_item	2839680	et	4	main
juurdunud	doc_740091151004_item	2839685	et	4	main
kultuuridevaheline	doc_740091151004_item	2839690	et	4	main
õpib	doc_740091151004_item	2839692	et	3	main
meedium	doc_740091151004_item	2839699	et	3	main
internet	doc_740091151004_item	2839706	et	4	main
internet	doc_740091151004_item	2839707	et	4	main
keskkonna	doc_740091151004_item	2839710	et	3	main
maailm	doc_740091151004_item	2839714	et	3	main
on	doc_740091151004_item	2839718	et	4	main
teadmisjanu	doc_740091151004_item	2839731	et	4	main
kuna	doc_740091151004_item	2839732	et	3	main
globaalruum	doc_740091151004_item	2839749	et	3	main
öelda	doc_740091151004_item	2839756	et	4	main
meid	doc_740091151004_item	2839764	et	4	main
ootab	doc_740091151004_item	2839765	et	3	main
on	doc_740091151004_item	2839772	et	4	main
ja	doc_740091151004_item	2839774	et	3	main
või	doc_740091151004_item	2839776	et	4	main
olla	doc_740091151004_item	2839784	et	3	main
lähitulevikus	doc_740091151004_item	2839791	et	4	main
siiski	doc_740091151004_item	2839795	et	4	main
kardetakse	doc_740091151004_item	2839809	et	3	main
omapära	doc_740091151004_item	2839812	et	4	main
käiks	doc_740091151004_item	2839815	et	3	main
reeglite	doc_740091151004_item	2839817	et	3	main
võimalik	doc_740091151004_item	2839723	et	3	main
piiritustes	doc_740091151004_item	2839725	et	4	main
kogustes	doc_740091151004_item	2839726	et	3	main
informatsiooni	doc_740091151004_item	2839727	et	4	main
ning	doc_740091151004_item	2839728	et	3	main
rahuldada	doc_740091151004_item	2839729	et	3	main
kriitikat	doc_740091151004_item	2839736	et	3	main
virtuaalkeskkonna	doc_740091151004_item	2839738	et	4	main
ole	doc_740091151004_item	2839751	et	4	main
ideaalne	doc_740091151004_item	2839753	et	3	main
õigus	doc_740091151004_item	2839761	et	4	main
öeldes	doc_740091151004_item	2839762	et	3	main
et	doc_740091151004_item	2839763	et	3	main
lugu	doc_740091151004_item	2839773	et	4	main
vist	doc_740091151004_item	2839782	et	4	main
et	doc_740091151004_item	2839785	et	3	main
globaliseerumine	doc_740091151004_item	2839797	et	4	main
on	doc_740091151004_item	2839798	et	4	main
nii	doc_740091151004_item	2839799	et	3	main
ohtlik	doc_740091151004_item	2839800	et	3	main
kui	doc_740091151004_item	2839801	et	3	main
kardetakse	doc_740091151004_item	2839802	et	3	main
usun	doc_740091151004_item	2839803	et	3	main
et	doc_740091151004_item	2839804	et	3	main
põhihirm	doc_740091151004_item	2839805	et	3	main
et	doc_740091151004_item	2839808	et	3	main
kui	doc_740091151004_item	2839813	et	3	main
põhjust	doc_740091151004_item	2839828	et	4	main
näiteks	doc_740091151004_item	2839841	et	4	main
põhjust	doc_740091151004_item	2839854	et	4	main
vastandid	doc_740091151004_item	2839867	et	3	main
need	doc_740091151004_item	2839868	et	3	main
on	doc_740091151004_item	2839869	et	4	main
harmooniliselt	doc_740091151004_item	2839893	et	4	main
maailma	doc_740091151004_item	2839896	et	4	main
keskmeks	doc_740091151004_item	2839771	et	3	main
emotsioon	doc_740091151004_item	2839775	et	3	main
jätkub	doc_740091151004_item	2839777	et	3	main
võidukäik	doc_740091151004_item	2839779	et	3	main
võib	doc_740091151004_item	2839781	et	3	main
kindel	doc_740091151004_item	2839783	et	3	main
interneti	doc_740091151004_item	2839786	et	4	main
mõju	doc_740091151004_item	2839787	et	4	main
küll	doc_740091151004_item	2839792	et	4	main
tuleneb	doc_740091151004_item	2839806	et	3	main
väikerahvuste	doc_740091151004_item	2839811	et	3	main
ei	doc_740091151004_item	2839821	et	4	main
suurte	doc_740091151004_item	2839824	et	3	main
suhtuks	doc_740091151004_item	2839839	et	4	main
nägu	doc_740091151004_item	2839852	et	4	main
karta	doc_740091151004_item	2839855	et	3	main
lihtsalt	doc_740091151004_item	2839857	et	4	main
lokaalsus	doc_740091151004_item	2839864	et	4	main
suudab	doc_740091151004_item	2839891	et	3	main
maailmakodanik	doc_740091151004_item	2839892	et	3	main
vähem	doc_740091151004_item	2839830	et	4	main
globaliseerumine	doc_740091151004_item	2839831	et	4	main
polegi	doc_740091151004_item	2839832	et	3	main
nii	doc_740091151004_item	2839833	et	3	main
hirmus	doc_740091151004_item	2839834	et	4	main
aga	doc_740091151004_item	2839835	et	3	main
kuidas	doc_740091151004_item	2839838	et	3	main
suruta	doc_740091151004_item	2839849	et	4	main
vastuvõetamatut	doc_740091151004_item	2839851	et	3	main
globaliseerumist	doc_740091151004_item	2839856	et	4	main
ole	doc_740091151004_item	2839866	et	4	main
maailma	doc_740091151004_item	2839871	et	4	main
kaks	doc_740091151004_item	2839872	et	3	main
erinevat	doc_740091151004_item	2839873	et	4	main
tasandit	doc_740091151004_item	2839874	et	3	main
mis	doc_740091151004_item	2839875	et	4	main
paratamatult	doc_740091151004_item	2839876	et	4	main
eksisteerivad	doc_740091151004_item	2839877	et	4	main
koos	doc_740091151004_item	2839878	et	4	main
nad	doc_740091151004_item	2839879	et	3	main
ei	doc_740091151004_item	2839880	et	4	main
välista	doc_740091151004_item	2839881	et	4	main
teineteist	doc_740091151004_item	2839882	et	4	main
samas	doc_740091151004_item	2839883	et	4	main
mõjutavad	doc_740091151004_item	2839884	et	4	main
vastastikku	doc_740091151004_item	2839885	et	4	main
oluliselt	doc_740091151004_item	2839886	et	4	main
nende	doc_740091151004_item	2839888	et	4	main
nähes	doc_740091151004_item	2839887	et	4	main
kahe	doc_740091151004_item	2839889	et	3	main
sümbioosi	doc_740091151004_item	2839890	et	4	main
kuna	doc_740091151006_item	2840285	et	3	main
et	doc_740091151006_item	2840295	et	3	main
kõik	doc_740091151006_item	2840297	et	4	main
peeter	doc_740091151006_item	2840312	et	3	main
normaalsem	doc_740091151006_item	2840313	et	4	main
on	doc_740091151006_item	2840322	et	4	main
muretsema	doc_740091151006_item	2840335	et	3	main
ole	doc_740091151006_item	2840342	et	4	main
normaalsem	doc_740091151006_item	2840343	et	4	main
kui	doc_740091151006_item	2840344	et	3	main
normaalsem	doc_740091151006_item	2840350	et	4	main
kui	doc_740091151006_item	2840351	et	3	main
ma	doc_740091151006_item	2840293	et	3	main
me	doc_740091151006_item	2840296	et	4	main
võiks	doc_740091151006_item	2840298	et	4	main
omavahel	doc_740091151006_item	2840299	et	3	main
rohkem	doc_740091151006_item	2840300	et	4	main
kõik	doc_740091151006_item	2840305	et	4	main
oleme	doc_740091151006_item	2840306	et	3	main
normaalsed	doc_740091151006_item	2840307	et	3	main
teisalt	doc_740091151006_item	2840308	et	4	main
aga	doc_740091151006_item	2840309	et	3	main
normaalsem	doc_740091151006_item	2840318	et	4	main
kui	doc_740091151006_item	2840319	et	3	main
mina	doc_740091151006_item	2840320	et	4	main
mis	doc_740091151006_item	2840326	et	4	main
asi	doc_740091151006_item	2840327	et	4	main
peaks	doc_740091151006_item	2840333	et	4	main
sellepärast	doc_740091151006_item	2840334	et	3	main
muretse	doc_740091151006_item	2840338	et	4	main
ja	doc_740091151006_item	2840346	et	3	main
dima	doc_740091151006_item	2840347	et	4	main
ei	doc_740091151006_item	2840348	et	4	main
miks	doc_740091151006_item	2840361	et	4	main
keegi	doc_740091151006_item	2840363	et	4	main
ole	doc_740091151006_item	2840365	et	4	main
see	doc_740091151006_item	2840372	et	3	main
on	doc_740091151006_item	2840317	et	4	main
kes	doc_740091151006_item	2840321	et	4	main
üldse	doc_740091151006_item	2840323	et	3	main
see	doc_740091151006_item	2840328	et	3	main
mina	doc_740091151006_item	2840336	et	4	main
peeter	doc_740091151006_item	2840340	et	3	main
mina	doc_740091151006_item	2840352	et	4	main
me	doc_740091151006_item	2840375	et	4	main
tea	doc_740091151006_item	2840379	et	4	main
võiks	doc_740091151006_item	2840386	et	4	main
keda	doc_740091151006_item	2840389	et	4	main
endale	doc_740091151006_item	2840427	et	4	main
ning	doc_740091151006_item	2840430	et	3	main
saanud	doc_740091151006_item	2840444	et	4	main
ärijuhtimist	doc_740091151006_item	2840459	et	3	main
õppima	doc_740091151006_item	2840460	et	3	main
ametikoha	doc_740091151006_item	2840466	et	4	main
peeter	doc_740091151006_item	2840488	et	3	main
selle	doc_740091151006_item	2840491	et	4	main
müügi-	doc_740091151006_item	2840494	et	4	main
on	doc_740091151006_item	2840498	et	4	main
pets	doc_740091151006_item	2840505	et	4	main
ei	doc_740091151006_item	2840506	et	4	main
kasvades	doc_740091151006_item	2840510	et	3	main
tõusnud	doc_740091151006_item	2840512	et	4	main
ta	doc_740091151006_item	2840513	et	4	main
koolitusi	doc_740091151006_item	2840516	et	4	main
argumenteerides	doc_740091151006_item	2840522	et	3	main
läheb	doc_740091151006_item	2840532	et	3	main
kommunikatsiooni	doc_740091151006_item	2840541	et	4	main
on	doc_740091151006_item	2840554	et	4	main
tema	doc_740091151006_item	2840564	et	4	main
pealinna	doc_740091151006_item	2840569	et	4	main
narva	doc_740091151006_item	2840576	et	4	main
kooli	doc_740091151006_item	2840578	et	4	main
jõhvi	doc_740091151006_item	2840589	et	4	main
matemaatikat	doc_740091151006_item	2840603	et	3	main
jällegi	doc_740091151006_item	2840626	et	4	main
väga	doc_740091151006_item	2840627	et	3	main
normaalne	doc_740091151006_item	2840628	et	3	main
oma	doc_740091151006_item	2840636	et	4	main
on	doc_740091151006_item	2840644	et	4	main
mõlemast	doc_740091151006_item	2840645	et	3	main
on	doc_740091151006_item	2840287	et	4	main
nii	doc_740091151006_item	2840288	et	3	main
lõputu	doc_740091151006_item	2840289	et	4	main
ja	doc_740091151006_item	2840290	et	3	main
intrigeeriv	doc_740091151006_item	2840291	et	4	main
esiteks	doc_740091151006_item	2840292	et	3	main
arvan	doc_740091151006_item	2840294	et	3	main
saada	doc_740091151006_item	2840302	et	4	main
kuna	doc_740091151006_item	2840303	et	3	main
me	doc_740091151006_item	2840304	et	4	main
on	doc_740091151006_item	2840311	et	4	main
dima	doc_740091151006_item	2840315	et	4	main
dima	doc_740091151006_item	2840316	et	4	main
normaalne	doc_740091151006_item	2840324	et	3	main
normaalsus	doc_740091151006_item	2840329	et	4	main
on	doc_740091151006_item	2840330	et	4	main
kas	doc_740091151006_item	2840331	et	3	main
ma	doc_740091151006_item	2840332	et	3	main
dima	doc_740091151006_item	2840345	et	4	main
ja	doc_740091151006_item	2840358	et	3	main
me	doc_740091151006_item	2840362	et	4	main
ei	doc_740091151006_item	2840364	et	4	main
üle	doc_740091151006_item	2840368	et	3	main
inimene	doc_740091151006_item	2840385	et	3	main
tüüp	doc_740091151006_item	2840388	et	3	main
nutab	doc_740091151006_item	2840396	et	3	main
väljendab	doc_740091151006_item	2840399	et	3	main
siin	doc_740091151006_item	2840428	et	4	main
elada	doc_740091151006_item	2840431	et	3	main
tavaline	doc_740091151006_item	2840440	et	4	main
müügiesindaja	doc_740091151006_item	2840441	et	4	main
võiks	doc_740091151006_item	2840446	et	4	main
et	doc_740091151006_item	2840448	et	3	main
tehtud	doc_740091151006_item	2840452	et	4	main
peale	doc_740091151006_item	2840453	et	4	main
seda	doc_740091151006_item	2840454	et	3	main
kui	doc_740091151006_item	2840455	et	3	main
peeter	doc_740091151006_item	2840456	et	3	main
oli	doc_740091151006_item	2840457	et	3	main
tooteesitleja	doc_740091151006_item	2840465	et	4	main
suurepärast	doc_740091151006_item	2840471	et	4	main
veenmisoskust	doc_740091151006_item	2840474	et	3	main
tegevjuht	doc_740091151006_item	2840476	et	3	main
kes	doc_740091151006_item	2840477	et	4	main
mehe	doc_740091151006_item	2840479	et	3	main
juurde	doc_740091151006_item	2840481	et	4	main
on	doc_740091151006_item	2840489	et	4	main
sama	doc_740091151006_item	2840492	et	4	main
normaalne	doc_740091151006_item	2840499	et	3	main
ole	doc_740091151006_item	2840507	et	4	main
kogemuste	doc_740091151006_item	2840509	et	3	main
kõrgemale	doc_740091151006_item	2840511	et	4	main
essee	doc_740091151006_item	2840275	et	4	main
saage	doc_740091151006_item	2840276	et	4	main
tuttavaks	doc_740091151006_item	2840277	et	4	main
normaalne	doc_740091151006_item	2840278	et	3	main
inimene	doc_740091151006_item	2840279	et	3	main
mind	doc_740091151006_item	2840280	et	4	main
haaras	doc_740091151006_item	2840281	et	4	main
kirjutama	doc_740091151006_item	2840282	et	3	main
antud	doc_740091151006_item	2840283	et	4	main
teema	doc_740091151006_item	2840284	et	4	main
see	doc_740091151006_item	2840286	et	3	main
tuttavaks	doc_740091151006_item	2840301	et	4	main
äkki	doc_740091151006_item	2840310	et	3	main
kui	doc_740091151006_item	2840314	et	3	main
ja	doc_740091151006_item	2840325	et	3	main
ei	doc_740091151006_item	2840337	et	4	main
sest	doc_740091151006_item	2840339	et	4	main
ei	doc_740091151006_item	2840341	et	4	main
ole	doc_740091151006_item	2840349	et	4	main
kes	doc_740091151006_item	2840353	et	4	main
on	doc_740091151006_item	2840354	et	4	main
peeter	doc_740091151006_item	2840355	et	3	main
ja	doc_740091151006_item	2840356	et	3	main
dima	doc_740091151006_item	2840357	et	4	main
ja	doc_740091151006_item	2840360	et	3	main
üksteisest	doc_740091151006_item	2840366	et	4	main
esiteks	doc_740091151006_item	2840369	et	3	main
keegi	doc_740091151006_item	2840376	et	4	main
tegelikult	doc_740091151006_item	2840377	et	4	main
mis	doc_740091151006_item	2840380	et	4	main
on	doc_740091151006_item	2840382	et	4	main
normaalsus	doc_740091151006_item	2840383	et	4	main
normaalne	doc_740091151006_item	2840384	et	3	main
kõik	doc_740091151006_item	2840390	et	4	main
keskmine	doc_740091151006_item	2840392	et	3	main
ta	doc_740091151006_item	2840394	et	4	main
eksisteerib	doc_740091151006_item	2840397	et	3	main
end	doc_740091151006_item	2840400	et	4	main
massiühikonnas	doc_740091151006_item	2840401	et	4	main
aktsepteeritud	doc_740091151006_item	2840402	et	4	main
viisil	doc_740091151006_item	2840403	et	4	main
peeter	doc_740091151006_item	2840404	et	3	main
normaalne	doc_740091151006_item	2840405	et	3	main
inimene	doc_740091151006_item	2840406	et	3	main
peeter	doc_740091151006_item	2840407	et	3	main
elab	doc_740091151006_item	2840408	et	3	main
pealinnas	doc_740091151006_item	2840409	et	4	main
nagu	doc_740091151006_item	2840410	et	3	main
enamik	doc_740091151006_item	2840411	et	3	main
normaalseid	doc_740091151006_item	2840412	et	3	main
inimesi	doc_740091151006_item	2840413	et	4	main
ta	doc_740091151006_item	2840414	et	4	main
on	doc_740091151006_item	2840415	et	4	main
kolmekümnendates	doc_740091151006_item	2840417	et	3	main
umbes	doc_740091151006_item	2840416	et	4	main
meesterahvas	doc_740091151006_item	2840418	et	4	main
kes	doc_740091151006_item	2840419	et	4	main
tuli	doc_740091151006_item	2840420	et	4	main
mina	doc_740091151006_item	2840359	et	4	main
normaalselt	doc_740091151006_item	2840367	et	4	main
ei	doc_740091151006_item	2840370	et	4	main
ole	doc_740091151006_item	2840371	et	4	main
ei	doc_740091151006_item	2840378	et	4	main
asi	doc_740091151006_item	2840381	et	4	main
olla	doc_740091151006_item	2840387	et	3	main
aktsepteerivad	doc_740091151006_item	2840391	et	4	main
inimene	doc_740091151006_item	2840393	et	3	main
suhtleb	doc_740091151006_item	2840395	et	3	main
tagasi	doc_740091151006_item	2840422	et	3	main
et	doc_740091151006_item	2840425	et	3	main
leida	doc_740091151006_item	2840426	et	3	main
töö	doc_740091151006_item	2840429	et	4	main
ühiskonnas	doc_740091151006_item	2840432	et	4	main
aktsepteeritud	doc_740091151006_item	2840433	et	4	main
mis	doc_740091151006_item	2840442	et	4	main
done	doc_740091151006_item	2840450	et	4	main
hetkel	doc_740091151006_item	2840468	et	4	main
märkas	doc_740091151006_item	2840469	et	3	main
peetri	doc_740091151006_item	2840470	et	3	main
tänavate	doc_740091151006_item	2840484	et	4	main
reklaami	doc_740091151006_item	2840486	et	4	main
läbinud	doc_740091151006_item	2840515	et	4	main
ideed	doc_740091151006_item	2840526	et	4	main
ju	doc_740091151006_item	2840528	et	3	main
alati	doc_740091151006_item	2840529	et	4	main
võlusid	doc_740091151006_item	2840542	et	4	main
oskab	doc_740091151006_item	2840544	et	3	main
kasutada	doc_740091151006_item	2840546	et	3	main
meesterahvas	doc_740091151006_item	2840555	et	4	main
vana	doc_740091151006_item	2840563	et	4	main
tulemisele	doc_740091151006_item	2840570	et	4	main
tuli	doc_740091151006_item	2840583	et	4	main
sõjavägi	doc_740091151006_item	2840584	et	3	main
kujutate	doc_740091151006_item	2840585	et	3	main
ette	doc_740091151006_item	2840586	et	4	main
selle	doc_740091151006_item	2840594	et	4	main
näiteks	doc_740091151006_item	2840602	et	4	main
õigusteadust	doc_740091151006_item	2840605	et	4	main
arvates	doc_740091151006_item	2840607	et	4	main
ei	doc_740091151006_item	2840608	et	4	main
võimalik	doc_740091151006_item	2840373	et	3	main
sest	doc_740091151006_item	2840374	et	4	main
ja	doc_740091151006_item	2840398	et	3	main
aastaid	doc_740091151006_item	2840421	et	4	main
viisil	doc_740091151006_item	2840434	et	4	main
ehk	doc_740091151006_item	2840435	et	3	main
siis	doc_740091151006_item	2840436	et	3	main
peetrist	doc_740091151006_item	2840443	et	4	main
öelda	doc_740091151006_item	2840447	et	4	main
well	doc_740091151006_item	2840449	et	4	main
hästi	doc_740091151006_item	2840451	et	3	main
endale	doc_740091151006_item	2840463	et	4	main
poes	doc_740091151006_item	2840464	et	3	main
ajakirjadesse	doc_740091151006_item	2840482	et	3	main
reklaampostidele	doc_740091151006_item	2840485	et	3	main
müüma	doc_740091151006_item	2840487	et	3	main
nüüd	doc_740091151006_item	2840490	et	4	main
firma	doc_740091151006_item	2840493	et	4	main
ja	doc_740091151006_item	2840495	et	3	main
ta	doc_740091151006_item	2840497	et	4	main
vahest	doc_740091151006_item	2840501	et	4	main
isegi	doc_740091151006_item	2840502	et	4	main
liiga	doc_740091151006_item	2840503	et	4	main
normaalne	doc_740091151006_item	2840504	et	3	main
jääda	doc_740091151006_item	2840521	et	4	main
parimad	doc_740091151006_item	2840530	et	4	main
tal	doc_740091151006_item	2840531	et	3	main
sest	doc_740091151006_item	2840534	et	4	main
kliendid	doc_740091151006_item	2840535	et	3	main
kuulavad	doc_740091151006_item	2840536	et	4	main
ja	doc_740091151006_item	2840537	et	3	main
tunneb	doc_740091151006_item	2840540	et	3	main
ning	doc_740091151006_item	2840543	et	3	main
ta	doc_740091151006_item	2840547	et	4	main
on	doc_740091151006_item	2840548	et	4	main
normaalne	doc_740091151006_item	2840549	et	3	main
dima	doc_740091151006_item	2840550	et	4	main
normaalne	doc_740091151006_item	2840551	et	3	main
inimene	doc_740091151006_item	2840552	et	3	main
tema	doc_740091151006_item	2840556	et	4	main
ja	doc_740091151006_item	2840559	et	3	main
ole	doc_740091151006_item	2840566	et	4	main
kunagi	doc_740091151006_item	2840567	et	3	main
mõelnud	doc_740091151006_item	2840568	et	4	main
omal	doc_740091151006_item	2840579	et	3	main
kiitusega	doc_740091151006_item	2840581	et	4	main
peale	doc_740091151006_item	2840590	et	4	main
ülikoolis	doc_740091151006_item	2840597	et	4	main
mõnda	doc_740091151006_item	2840598	et	4	main
või	doc_740091151006_item	2840604	et	4	main
sest	doc_740091151006_item	2840629	et	4	main
dimast	doc_740091151006_item	2840648	et	4	main
kooli	doc_740091151006_item	2840681	et	4	main
ühiskonnas	doc_740091151006_item	2840683	et	4	main
on	doc_740091151006_item	2840684	et	4	main
see	doc_740091151006_item	2840685	et	3	main
ju	doc_740091151006_item	2840686	et	3	main
normaalsust	doc_740091151006_item	2840691	et	4	main
tõestada	doc_740091151006_item	2840692	et	3	main
18	doc_740091151006_item	2840701	et	2	main
aastane	doc_740091151006_item	2840702	et	4	main
mõtlebki	doc_740091151006_item	2840703	et	3	main
nii	doc_740091151006_item	2840704	et	3	main
ja	doc_740091151006_item	2840705	et	3	main
et	doc_740091151006_item	2840711	et	3	main
saab	doc_740091151006_item	2840713	et	3	main
inimesi	doc_740091151006_item	2840730	et	4	main
kelle	doc_740091151006_item	2840741	et	4	main
on	doc_740091151006_item	2840753	et	4	main
dima	doc_740091151006_item	2840758	et	4	main
oma	doc_740091151006_item	2840772	et	4	main
peas	doc_740091151006_item	2840773	et	4	main
mõtteid	doc_740091151006_item	2840774	et	3	main
mõtleme	doc_740091151006_item	2840777	et	3	main
eksistentsi	doc_740091151006_item	2840778	et	4	main
võiksime	doc_740091151006_item	2840797	et	3	main
soovin	doc_740091151006_item	2840806	et	3	main
väitis	doc_740091151006_item	2840822	et	3	main
inimene	doc_740091151006_item	2840824	et	3	main
peame	doc_740091151006_item	2840833	et	4	main
kõigepealt	doc_740091151006_item	2840834	et	3	main
suhtlemise	doc_740091151006_item	2840842	et	4	main
pealinna	doc_740091151006_item	2840423	et	4	main
kooli	doc_740091151006_item	2840424	et	4	main
jõuda	doc_740091151006_item	2840437	et	3	main
kõrgemale	doc_740091151006_item	2840438	et	4	main
kui	doc_740091151006_item	2840439	et	3	main
on	doc_740091151006_item	2840445	et	4	main
asunud	doc_740091151006_item	2840458	et	4	main
sai	doc_740091151006_item	2840461	et	4	main
ta	doc_740091151006_item	2840462	et	4	main
ühel	doc_740091151006_item	2840467	et	3	main
suhtlemis-	doc_740091151006_item	2840472	et	4	main
ja	doc_740091151006_item	2840473	et	3	main
reklaamibüroo	doc_740091151006_item	2840475	et	4	main
kutsus	doc_740091151006_item	2840478	et	4	main
enda	doc_740091151006_item	2840480	et	4	main
ning	doc_740091151006_item	2840483	et	3	main
turundusjuht	doc_740091151006_item	2840496	et	3	main
inimene	doc_740091151006_item	2840500	et	3	main
lihtsalt	doc_740091151006_item	2840508	et	4	main
on	doc_740091151006_item	2840514	et	4	main
kuidas	doc_740091151006_item	2840517	et	3	main
ratsionaalse	doc_740091151006_item	2840518	et	3	main
argumenteerimise	doc_740091151006_item	2840519	et	4	main
teel	doc_740091151006_item	2840520	et	4	main
peale	doc_740091151006_item	2840523	et	4	main
tema	doc_740091151006_item	2840525	et	4	main
hästi	doc_740091151006_item	2840533	et	3	main
dima	doc_740091151006_item	2840553	et	4	main
elab	doc_740091151006_item	2840557	et	3	main
ei	doc_740091151006_item	2840565	et	4	main
dimale	doc_740091151006_item	2840571	et	4	main
meeldib	doc_740091151006_item	2840572	et	3	main
lõpetas	doc_740091151006_item	2840575	et	3	main
pähklimäe	doc_740091151006_item	2840577	et	3	main
ajal	doc_740091151006_item	2840580	et	4	main
siis	doc_740091151006_item	2840582	et	3	main
sõjaväge	doc_740091151006_item	2840591	et	3	main
õppima	doc_740091151006_item	2840593	et	3	main
asemel	doc_740091151006_item	2840595	et	4	main
et	doc_740091151006_item	2840596	et	3	main
õppida	doc_740091151006_item	2840601	et	3	main
ole	doc_740091151006_item	2840609	et	4	main
dima	doc_740091151006_item	2840610	et	4	main
normaalne	doc_740091151006_item	2840611	et	3	main
on	doc_740091151006_item	2840624	et	4	main
dima	doc_740091151006_item	2840625	et	4	main
kõik	doc_740091151006_item	2840633	et	4	main
inimesed	doc_740091151006_item	2840634	et	3	main
on	doc_740091151006_item	2840635	et	4	main
viisil	doc_740091151006_item	2840638	et	4	main
mina	doc_740091151006_item	2840640	et	4	main
minus	doc_740091151006_item	2840643	et	3	main
ka	doc_740091151006_item	2840650	et	3	main
peetrist	doc_740091151006_item	2840651	et	4	main
olen	doc_740091151006_item	2840653	et	3	main
dima	doc_740091151006_item	2840656	et	4	main
sotsiaalne	doc_740091151006_item	2840658	et	3	main
taust	doc_740091151006_item	2840659	et	4	main
on	doc_740091151006_item	2840660	et	4	main
suhteliselt	doc_740091151006_item	2840687	et	4	main
ainus	doc_740091151006_item	2840688	et	4	main
viis	doc_740091151006_item	2840689	et	4	main
võiks	doc_740091151006_item	2840695	et	4	main
ümber	doc_740091151006_item	2840696	et	3	main
lükata	doc_740091151006_item	2840697	et	4	main
hiljem	doc_740091151006_item	2840709	et	3	main
tegelikult	doc_740091151006_item	2840712	et	4	main
normaalne	doc_740091151006_item	2840714	et	3	main
ka	doc_740091151006_item	2840716	et	3	main
mulle	doc_740091151006_item	2840718	et	4	main
tundub	doc_740091151006_item	2840719	et	3	main
lihtsalt	doc_740091151006_item	2840720	et	4	main
sest	doc_740091151006_item	2840524	et	4	main
on	doc_740091151006_item	2840527	et	4	main
ostavad	doc_740091151006_item	2840538	et	3	main
peeter	doc_740091151006_item	2840539	et	3	main
neid	doc_740091151006_item	2840545	et	4	main
ida-virumaal	doc_740091151006_item	2840558	et	4	main
on	doc_740091151006_item	2840560	et	4	main
alla	doc_740091151006_item	2840561	et	3	main
kolmekümne	doc_740091151006_item	2840562	et	4	main
ida-virumaal	doc_740091151006_item	2840573	et	4	main
dima	doc_740091151006_item	2840574	et	4	main
dima	doc_740091151006_item	2840587	et	4	main
läks	doc_740091151006_item	2840588	et	3	main
autoremondilukksepaks	doc_740091151006_item	2840592	et	3	main
normaalsemat	doc_740091151006_item	2840599	et	4	main
asja	doc_740091151006_item	2840600	et	4	main
mõnede	doc_740091151006_item	2840606	et	3	main
sest	doc_740091151006_item	2840612	et	4	main
tal	doc_740091151006_item	2840613	et	3	main
pole	doc_740091151006_item	2840614	et	3	main
ülikooli	doc_740091151006_item	2840615	et	4	main
diplomit	doc_740091151006_item	2840616	et	3	main
ning	doc_740091151006_item	2840617	et	3	main
tema	doc_740091151006_item	2840618	et	4	main
tööriideks	doc_740091151006_item	2840619	et	3	main
on	doc_740091151006_item	2840620	et	4	main
tunked	doc_740091151006_item	2840621	et	3	main
arvates	doc_740091151006_item	2840623	et	4	main
dima	doc_740091151006_item	2840630	et	4	main
teab	doc_740091151006_item	2840631	et	3	main
et	doc_740091151006_item	2840632	et	3	main
iseäralikul	doc_740091151006_item	2840637	et	3	main
normaalsed	doc_740091151006_item	2840639	et	3	main
normaalne	doc_740091151006_item	2840641	et	3	main
inimene	doc_740091151006_item	2840642	et	3	main
kui	doc_740091151006_item	2840649	et	3	main
ida-virumaalt	doc_740091151006_item	2840654	et	3	main
selle	doc_740091151006_item	2840693	et	4	main
nüüd	doc_740091151006_item	2840706	et	4	main
mõned	doc_740091151006_item	2840707	et	3	main
siiski	doc_740091151006_item	2840729	et	4	main
nagu	doc_740091151006_item	2840736	et	3	main
backpackusid	doc_740091151006_item	2840737	et	4	main
hulljulged	doc_740091151006_item	2840738	et	3	main
seljakoti	doc_740091151006_item	2840739	et	3	main
on	doc_740091151006_item	2840743	et	4	main
austraaliast	doc_740091151006_item	2840750	et	4	main
peeter	doc_740091151006_item	2840757	et	3	main
ja	doc_740091151006_item	2840759	et	3	main
oma	doc_740091151006_item	2840764	et	4	main
viisil	doc_740091151006_item	2840766	et	4	main
normaalsed	doc_740091151006_item	2840767	et	3	main
freudlikul	doc_740091151006_item	2840769	et	4	main
viisil	doc_740091151006_item	2840770	et	4	main
sätime	doc_740091151006_item	2840771	et	3	main
ritta	doc_740091151006_item	2840775	et	3	main
inimesi	doc_740091151006_item	2840787	et	4	main
normaalseteks	doc_740091151006_item	2840788	et	4	main
ja	doc_740091151006_item	2840789	et	3	main
saada	doc_740091151006_item	2840803	et	4	main
tahaksin	doc_740091151006_item	2840804	et	3	main
et	doc_740091151006_item	2840807	et	3	main
minu	doc_740091151006_item	2840622	et	3	main
nii	doc_740091151006_item	2840647	et	3	main
sarnane	doc_740091151006_item	2840661	et	4	main
samas	doc_740091151006_item	2840662	et	4	main
olen	doc_740091151006_item	2840663	et	3	main
osa	doc_740091151006_item	2840664	et	4	main
ka	doc_740091151006_item	2840665	et	3	main
peetrist	doc_740091151006_item	2840666	et	4	main
mina	doc_740091151006_item	2840667	et	4	main
ei	doc_740091151006_item	2840668	et	4	main
ela	doc_740091151006_item	2840669	et	4	main
juba	doc_740091151006_item	2840670	et	3	main
mõnda	doc_740091151006_item	2840671	et	4	main
aega	doc_740091151006_item	2840672	et	4	main
enam	doc_740091151006_item	2840673	et	4	main
ida-virumaal	doc_740091151006_item	2840674	et	4	main
vaid	doc_740091151006_item	2840675	et	3	main
pealinnas	doc_740091151006_item	2840676	et	4	main
nagu	doc_740091151006_item	2840677	et	3	main
peeter	doc_740091151006_item	2840678	et	3	main
mina	doc_740091151006_item	2840679	et	4	main
tulin	doc_740091151006_item	2840680	et	3	main
midagi	doc_740091151006_item	2840646	et	4	main
mina	doc_740091151006_item	2840652	et	4	main
nagu	doc_740091151006_item	2840655	et	3	main
meie	doc_740091151006_item	2840657	et	4	main
arvamuse	doc_740091151006_item	2840694	et	3	main
aastad	doc_740091151006_item	2840708	et	3	main
olla	doc_740091151006_item	2840715	et	3	main
nii	doc_740091151006_item	2840721	et	3	main
normaalne	doc_740091151006_item	2840723	et	3	main
meie	doc_740091151006_item	2840726	et	4	main
kultuuridevaheline	doc_740091151006_item	2840748	et	4	main
mina	doc_740091151006_item	2840760	et	4	main
me	doc_740091151006_item	2840761	et	4	main
kõik	doc_740091151006_item	2840762	et	4	main
et	doc_740091151006_item	2840783	et	3	main
ei	doc_740091151006_item	2840784	et	4	main
tasu	doc_740091151006_item	2840785	et	4	main
jagada	doc_740091151006_item	2840786	et	3	main
et	doc_740091151006_item	2840795	et	3	main
ühiskonnas	doc_740091151006_item	2840798	et	4	main
rohkem	doc_740091151006_item	2840800	et	4	main
üksteisega	doc_740091151006_item	2840801	et	3	main
et	doc_740091151006_item	2840823	et	3	main
on	doc_740091151006_item	2840825	et	4	main
kui	doc_740091151006_item	2840828	et	3	main
tema	doc_740091151006_item	2840829	et	4	main
põhivajadused	doc_740091151006_item	2840830	et	3	main
massiühiskonnas	doc_740091151006_item	2840836	et	4	main
ja	doc_740091151006_item	2840837	et	3	main
saame	doc_740091151006_item	2840847	et	4	main
väidelda	doc_740091151006_item	2840851	et	4	main
oleme	doc_740091151006_item	2840865	et	3	main
sest	doc_740091151006_item	2840682	et	4	main
oma	doc_740091151006_item	2840690	et	4	main
ja	doc_740091151006_item	2840698	et	3	main
öelda	doc_740091151006_item	2840699	et	4	main
et	doc_740091151006_item	2840700	et	3	main
näen	doc_740091151006_item	2840710	et	3	main
teistmoodi	doc_740091151006_item	2840717	et	3	main
kohutavalt	doc_740091151006_item	2840722	et	4	main
see	doc_740091151006_item	2840724	et	3	main
et	doc_740091151006_item	2840725	et	3	main
kes	doc_740091151006_item	2840731	et	4	main
teevad	doc_740091151006_item	2840732	et	3	main
pööraseid	doc_740091151006_item	2840733	et	4	main
asju	doc_740091151006_item	2840734	et	3	main
reisijad	doc_740091151006_item	2840740	et	4	main
sihtkoht	doc_740091151006_item	2840742	et	3	main
teadmata	doc_740091151006_item	2840744	et	4	main
reis	doc_740091151006_item	2840745	et	4	main
seiklus	doc_740091151006_item	2840746	et	3	main
meil	doc_740091151006_item	2840754	et	4	main
kolm	doc_740091151006_item	2840755	et	3	main
tüüpi	doc_740091151006_item	2840756	et	4	main
oleme	doc_740091151006_item	2840763	et	3	main
ning	doc_740091151006_item	2840776	et	3	main
küsimuste	doc_740091151006_item	2840779	et	4	main
üle	doc_740091151006_item	2840780	et	3	main
ma	doc_740091151006_item	2840781	et	3	main
arvan	doc_740091151006_item	2840782	et	3	main
mittenormaalseteks	doc_740091151006_item	2840790	et	4	main
mul	doc_740091151006_item	2840791	et	3	main
on	doc_740091151006_item	2840792	et	4	main
hoopis	doc_740091151006_item	2840793	et	3	main
ettepanek	doc_740091151006_item	2840794	et	3	main
me	doc_740091151006_item	2840796	et	4	main
kõik	doc_740091151006_item	2840799	et	4	main
tuttavaks	doc_740091151006_item	2840802	et	4	main
henzbergki	doc_740091151006_item	2840821	et	4	main
rahul	doc_740091151006_item	2840826	et	4	main
siis	doc_740091151006_item	2840827	et	3	main
siin	doc_740091151006_item	2840835	et	4	main
rahulolu	doc_740091151006_item	2840844	et	4	main
põhivajadused	doc_740091151006_item	2840845	et	3	main
siis	doc_740091151006_item	2840846	et	3	main
kes	doc_740091151006_item	2840853	et	4	main
normaalne	doc_740091151006_item	2840855	et	3	main
kõik	doc_740091151006_item	2840866	et	4	main
seas	doc_740091151006_item	2840727	et	4	main
on	doc_740091151006_item	2840728	et	4	main
näiteks	doc_740091151006_item	2840735	et	4	main
kommunikatsioon	doc_740091151006_item	2840747	et	3	main
erinevus	doc_740091151006_item	2840749	et	4	main
ameerikani	doc_740091151006_item	2840751	et	4	main
kokkuvõtteks	doc_740091151006_item	2840752	et	3	main
iseloomulikul	doc_740091151006_item	2840765	et	3	main
ning	doc_740091151006_item	2840768	et	3	main
ja	doc_740091151006_item	2840805	et	3	main
me	doc_740091151006_item	2840808	et	4	main
kõik	doc_740091151006_item	2840809	et	4	main
jõuaks	doc_740091151006_item	2840810	et	3	main
oma	doc_740091151006_item	2840811	et	4	main
normaalsuseni	doc_740091151006_item	2840812	et	4	main
viisil	doc_740091151006_item	2840813	et	4	main
mis	doc_740091151006_item	2840814	et	4	main
pole	doc_740091151006_item	2840815	et	3	main
üldsuse	doc_740091151006_item	2840816	et	3	main
arvamustest	doc_740091151006_item	2840817	et	4	main
mõjutatud	doc_740091151006_item	2840818	et	4	main
nii	doc_740091151006_item	2840819	et	3	main
nagu	doc_740091151006_item	2840820	et	3	main
on	doc_740091151006_item	2840831	et	4	main
rahuldatud	doc_740091151006_item	2840832	et	4	main
paika	doc_740091151006_item	2840840	et	4	main
tuleviku	doc_740091151006_item	2840841	et	4	main
istuda	doc_740091151006_item	2840848	et	3	main
on	doc_740091151006_item	2840854	et	4	main
asi	doc_740091151006_item	2840859	et	4	main
normaalsed	doc_740091151006_item	2840867	et	3	main
kultuuris	doc_740091151006_item	2840838	et	3	main
panema	doc_740091151006_item	2840839	et	3	main
kokku	doc_740091151006_item	2840849	et	3	main
on	doc_740091151006_item	2840860	et	4	main
normaalsus	doc_740091151006_item	2840861	et	4	main
ja	doc_740091151006_item	2840843	et	3	main
et	doc_740091151006_item	2840850	et	3	main
teemal	doc_740091151006_item	2840852	et	3	main
inimene	doc_740091151006_item	2840856	et	3	main
ja	doc_740091151006_item	2840857	et	3	main
mis	doc_740091151006_item	2840858	et	4	main
saame	doc_740091151006_item	2840862	et	4	main
tuttavaks	doc_740091151006_item	2840863	et	4	main
me	doc_740091151006_item	2840864	et	4	main
maailma	doc_740091151012_item	2842845	et	4	main
ja	doc_740091151012_item	2842860	et	3	main
uurides	doc_740091151012_item	2842862	et	4	main
silm	doc_740091151012_item	2842870	et	3	main
kes	doc_740091151012_item	2842873	et	4	main
tohutult	doc_740091151012_item	2842876	et	4	main
liidust	doc_740091151012_item	2842882	et	4	main
meie	doc_740091151012_item	2842885	et	4	main
riigi	doc_740091151012_item	2842886	et	3	main
edusammude	doc_740091151012_item	2842887	et	3	main
ja	doc_740091151012_item	2842888	et	3	main
naiivne	doc_740091151012_item	2842921	et	3	main
head	doc_740091151012_item	2842929	et	4	main
erinevaid	doc_740091151012_item	2842932	et	4	main
tülisid	doc_740091151012_item	2842933	et	3	main
tuleb	doc_740091151012_item	2842934	et	3	main
kõikjal	doc_740091151012_item	2842935	et	3	main
ette	doc_740091151012_item	2842936	et	4	main
ma	doc_740091151012_item	2842937	et	3	main
sõdurpoisiga	doc_740091151012_item	2842945	et	3	main
inimesed	doc_740091151012_item	2842947	et	3	main
et	doc_740091151012_item	2842949	et	3	main
elavate	doc_740091151012_item	2842951	et	4	main
pingeid	doc_740091151012_item	2842955	et	3	main
mõelnud	doc_740091151012_item	2842958	et	4	main
avastanud	doc_740091151012_item	2842962	et	4	main
et	doc_740091151012_item	2842963	et	3	main
essee	doc_740091151012_item	2842839	et	4	main
eestlased	doc_740091151012_item	2842840	et	3	main
ja	doc_740091151012_item	2842841	et	3	main
eestivenelased	doc_740091151012_item	2842842	et	3	main
on	doc_740091151012_item	2842846	et	4	main
osadeks	doc_740091151012_item	2842848	et	3	main
natuke	doc_740091151012_item	2842856	et	4	main
hiljem	doc_740091151012_item	2842857	et	3	main
arengumaadest	doc_740091151012_item	2842861	et	4	main
lähemalt	doc_740091151012_item	2842863	et	4	main
riike	doc_740091151012_item	2842864	et	3	main
kes	doc_740091151012_item	2842865	et	4	main
ka	doc_740091151012_item	2842871	et	3	main
on	doc_740091151012_item	2842878	et	4	main
näitab	doc_740091151012_item	2842883	et	3	main
et	doc_740091151012_item	2842923	et	3	main
rahvuse	doc_740091151012_item	2842927	et	3	main
pea	doc_740091151012_item	2842939	et	4	main
meenutama	doc_740091151012_item	2842940	et	4	main
seoses	doc_740091151012_item	2842943	et	4	main
pronksist	doc_740091151012_item	2842944	et	4	main
naabritena	doc_740091151012_item	2842950	et	3	main
rahvuste	doc_740091151012_item	2842952	et	3	main
tajuda	doc_740091151012_item	2842956	et	3	main
meil	doc_740091151012_item	2842964	et	4	main
sulle	doc_740091151012_item	2842980	et	3	main
istudes	doc_740091151012_item	2842989	et	4	main
kokku	doc_740091151012_item	2842990	et	3	main
sooviks	doc_740091151012_item	2843021	et	4	main
kes	doc_740091151012_item	2843033	et	4	main
saama	doc_740091151012_item	2843040	et	4	main
poes	doc_740091151012_item	2843041	et	3	main
juures	doc_740091151012_item	2843044	et	4	main
siis	doc_740091151012_item	2843048	et	3	main
keeles	doc_740091151012_item	2843050	et	4	main
ka	doc_740091151012_item	2843055	et	3	main
ära	doc_740091151012_item	2843071	et	4	main
ise	doc_740091151012_item	2843077	et	4	main
ühtegi	doc_740091151012_item	2843125	et	4	main
venelasest	doc_740091151012_item	2843126	et	3	main
ta	doc_740091151012_item	2843129	et	4	main
nii	doc_740091151012_item	2843142	et	3	main
kui	doc_740091151012_item	2843144	et	3	main
negatiivselt	doc_740091151012_item	2843146	et	4	main
kolmandast	doc_740091151012_item	2842854	et	4	main
maailmast	doc_740091151012_item	2842855	et	4	main
arenenute	doc_740091151012_item	2842867	et	4	main
viimase	doc_740091151012_item	2842874	et	3	main
dekaadiga	doc_740091151012_item	2842875	et	3	main
arenenud	doc_740091151012_item	2842877	et	4	main
olles	doc_740091151012_item	2842879	et	3	main
osa	doc_740091151012_item	2842880	et	4	main
arengu	doc_740091151012_item	2842889	et	3	main
on	doc_740091151012_item	2842925	et	4	main
ei	doc_740091151012_item	2842938	et	4	main
lugu	doc_740091151012_item	2842942	et	4	main
et	doc_740091151012_item	2842946	et	3	main
olen	doc_740091151012_item	2842957	et	3	main
ja	doc_740091151012_item	2842959	et	3	main
inimesi	doc_740091151012_item	2842960	et	4	main
puudu	doc_740091151012_item	2842966	et	4	main
lihtsalt	doc_740091151012_item	2842967	et	4	main
me	doc_740091151012_item	2842970	et	4	main
kord	doc_740091151012_item	2842986	et	4	main
kes	doc_740091151012_item	2842993	et	4	main
kunagi	doc_740091151012_item	2842997	et	3	main
et	doc_740091151012_item	2843022	et	3	main
riigil	doc_740091151012_item	2843024	et	3	main
oleks	doc_740091151012_item	2843025	et	3	main
kaks	doc_740091151012_item	2843026	et	3	main
argument	doc_740091151012_item	2843028	et	3	main
miks	doc_740091151012_item	2843029	et	4	main
meie	doc_740091151012_item	2843037	et	4	main
emakeeles	doc_740091151012_item	2843046	et	4	main
võrdlusesse	doc_740091151012_item	2843054	et	4	main
saksamaal	doc_740091151012_item	2843065	et	4	main
siis	doc_740091151012_item	2843068	et	3	main
saksa	doc_740091151012_item	2843069	et	4	main
keele	doc_740091151012_item	2843070	et	4	main
miks	doc_740091151012_item	2843075	et	4	main
sa	doc_740091151012_item	2843076	et	3	main
räägid	doc_740091151012_item	2843082	et	4	main
tema	doc_740091151012_item	2843085	et	4	main
pole	doc_740091151012_item	2843124	et	3	main
räägi	doc_740091151012_item	2843132	et	4	main
vene	doc_740091151012_item	2843133	et	4	main
keelt	doc_740091151012_item	2843134	et	4	main
peale	doc_740091151012_item	2843135	et	4	main
positiivselt	doc_740091151012_item	2843143	et	4	main
ka	doc_740091151012_item	2843145	et	3	main
esiteks	doc_740091151012_item	2843147	et	3	main
ma	doc_740091151012_item	2843150	et	3	main
leidub	doc_740091151012_item	2843154	et	3	main
neile	doc_740091151012_item	2843162	et	4	main
ja	doc_740091151012_item	2843165	et	3	main
teisaks	doc_740091151012_item	2843170	et	4	main
mulle	doc_740091151012_item	2843173	et	4	main
meeldi	doc_740091151012_item	2843175	et	4	main
inimene	doc_740091151012_item	2843177	et	3	main
arutleb	doc_740091151012_item	2843178	et	3	main
eestlasi	doc_740091151012_item	2843191	et	3	main
seadusi	doc_740091151012_item	2843210	et	3	main
ei	doc_740091151012_item	2843212	et	4	main
meist	doc_740091151012_item	2843214	et	3	main
on	doc_740091151012_item	2843224	et	4	main
sest	doc_740091151012_item	2843228	et	4	main
igapäevaselt	doc_740091151012_item	2843231	et	4	main
ma	doc_740091151012_item	2843236	et	3	main
saa	doc_740091151012_item	2843238	et	4	main
üle	doc_740091151012_item	2843240	et	3	main
ümber	doc_740091151012_item	2843242	et	3	main
et	doc_740091151012_item	2843244	et	3	main
alati	doc_740091151012_item	2842847	et	4	main
jaotatud	doc_740091151012_item	2842849	et	4	main
räägiti	doc_740091151012_item	2842850	et	3	main
esimesest	doc_740091151012_item	2842851	et	3	main
ja	doc_740091151012_item	2842853	et	3	main
arenenud	doc_740091151012_item	2842858	et	4	main
hulka	doc_740091151012_item	2842868	et	4	main
peatub	doc_740091151012_item	2842869	et	3	main
eestil	doc_740091151012_item	2842872	et	3	main
euroopa	doc_740091151012_item	2842881	et	4	main
see	doc_740091151012_item	2842884	et	3	main
tulemust	doc_740091151012_item	2842890	et	4	main
ühelt	doc_740091151012_item	2842891	et	3	main
poolt	doc_740091151012_item	2842892	et	4	main
teiselt	doc_740091151012_item	2842893	et	4	main
aga	doc_740091151012_item	2842895	et	3	main
tajume	doc_740091151012_item	2842896	et	3	main
justkui	doc_740091151012_item	2842897	et	3	main
poolt	doc_740091151012_item	2842894	et	4	main
vitsahoope	doc_740091151012_item	2842898	et	3	main
kui	doc_740091151012_item	2842899	et	3	main
teemaks	doc_740091151012_item	2842900	et	4	main
tuleb	doc_740091151012_item	2842901	et	3	main
eestlaste	doc_740091151012_item	2842902	et	4	main
ja	doc_740091151012_item	2842903	et	3	main
eesti	doc_740091151012_item	2842904	et	4	main
venelaste	doc_740091151012_item	2842905	et	4	main
omavahelised	doc_740091151012_item	2842906	et	4	main
suhted	doc_740091151012_item	2842907	et	3	main
kas	doc_740091151012_item	2842908	et	3	main
mina	doc_740091151012_item	2842909	et	4	main
näen	doc_740091151012_item	2842910	et	3	main
viimaste	doc_740091151012_item	2842911	et	3	main
suhteid	doc_740091151012_item	2842912	et	3	main
nii	doc_740091151012_item	2842913	et	3	main
nagu	doc_740091151012_item	2842914	et	3	main
näeb	doc_740091151012_item	2842915	et	3	main
neid	doc_740091151012_item	2842916	et	4	main
muu	doc_740091151012_item	2842917	et	4	main
eurooplane	doc_740091151012_item	2842918	et	3	main
on	doc_740091151012_item	2842919	et	4	main
ilmselgelt	doc_740091151012_item	2842920	et	4	main
uskuda	doc_740091151012_item	2842922	et	3	main
tegelikult	doc_740091151012_item	2842924	et	4	main
ja	doc_740091151012_item	2842930	et	3	main
ühine	doc_740091151012_item	2842843	et	4	main
kultuuriruum	doc_740091151012_item	2842844	et	3	main
teisest	doc_740091151012_item	2842852	et	4	main
riikidest	doc_740091151012_item	2842859	et	3	main
kuuluvad	doc_740091151012_item	2842866	et	4	main
kahe	doc_740091151012_item	2842926	et	3	main
suhted	doc_740091151012_item	2842928	et	3	main
jälgides	doc_740091151012_item	2842961	et	4	main
sina	doc_740091151012_item	2842976	et	4	main
vanalinnas	doc_740091151012_item	2842987	et	4	main
kohvikus	doc_740091151012_item	2842988	et	3	main
mul	doc_740091151012_item	2842994	et	3	main
meelest	doc_740091151012_item	2842998	et	4	main
ei	doc_740091151012_item	2842999	et	4	main
lähe	doc_740091151012_item	2843000	et	4	main
ei	doc_740091151012_item	2843001	et	4	main
seda	doc_740091151012_item	2843002	et	3	main
mitte	doc_740091151012_item	2843003	et	3	main
tema	doc_740091151012_item	2843004	et	4	main
välimuse	doc_740091151012_item	2843005	et	3	main
või	doc_740091151012_item	2843006	et	4	main
intelligentsi	doc_740091151012_item	2843007	et	4	main
pärast	doc_740091151012_item	2843008	et	4	main
seda	doc_740091151012_item	2843009	et	3	main
hoopis	doc_740091151012_item	2843010	et	3	main
põhjusel	doc_740091151012_item	2843011	et	3	main
et	doc_740091151012_item	2843012	et	3	main
ta	doc_740091151012_item	2843013	et	4	main
on	doc_740091151012_item	2843014	et	4	main
ainus	doc_740091151012_item	2843015	et	4	main
eestlane	doc_740091151012_item	2843016	et	3	main
keda	doc_740091151012_item	2843017	et	4	main
ma	doc_740091151012_item	2843018	et	3	main
tean	doc_740091151012_item	2843019	et	3	main
kes	doc_740091151012_item	2843020	et	4	main
meie	doc_740091151012_item	2843023	et	4	main
riigikeelt	doc_740091151012_item	2843027	et	4	main
on	doc_740091151012_item	2843034	et	4	main
40	doc_740091151012_item	2843035	et	2	main
aastat	doc_740091151012_item	2843036	et	3	main
või	doc_740091151012_item	2843042	et	4	main
vene	doc_740091151012_item	2843049	et	4	main
rääkida	doc_740091151012_item	2843051	et	3	main
kus	doc_740091151012_item	2843057	et	3	main
on	doc_740091151012_item	2843058	et	4	main
on	doc_740091151012_item	2843072	et	4	main
inglismaale	doc_740091151012_item	2843078	et	4	main
minnes	doc_740091151012_item	2843079	et	3	main
ei	doc_740091151012_item	2843083	et	4	main
aeg-ajalt	doc_740091151012_item	2842931	et	4	main
koletut	doc_740091151012_item	2842941	et	3	main
mõistaksid	doc_740091151012_item	2842948	et	4	main
vahel	doc_740091151012_item	2842953	et	4	main
on	doc_740091151012_item	2842954	et	4	main
on	doc_740091151012_item	2842965	et	4	main
sest	doc_740091151012_item	2842969	et	4	main
ei	doc_740091151012_item	2842971	et	4	main
saa	doc_740091151012_item	2842972	et	4	main
suhtuda	doc_740091151012_item	2842973	et	3	main
teineteisesse	doc_740091151012_item	2842974	et	3	main
kuidas	doc_740091151012_item	2842975	et	3	main
aga	doc_740091151012_item	2842981	et	3	main
tehakse	doc_740091151012_item	2842984	et	3	main
juhtusin	doc_740091151012_item	2842985	et	4	main
ühe	doc_740091151012_item	2842991	et	4	main
noormehega	doc_740091151012_item	2842992	et	3	main
tolerantsist	doc_740091151012_item	2842968	et	3	main
mulle	doc_740091151012_item	2842977	et	4	main
nii	doc_740091151012_item	2842978	et	3	main
mina	doc_740091151012_item	2842979	et	4	main
ikkagi	doc_740091151012_item	2842982	et	4	main
seda	doc_740091151012_item	2842983	et	3	main
ilmselt	doc_740091151012_item	2842995	et	4	main
mitte	doc_740091151012_item	2842996	et	3	main
peaks	doc_740091151012_item	2843031	et	4	main
inimene	doc_740091151012_item	2843032	et	3	main
elanud	doc_740091151012_item	2843039	et	4	main
oma	doc_740091151012_item	2843045	et	4	main
lisaks	doc_740091151012_item	2843052	et	4	main
toodi	doc_740091151012_item	2843053	et	4	main
3	doc_740091151012_item	2843060	et	2	main
miks	doc_740091151012_item	2843064	et	4	main
türklased	doc_740091151012_item	2843067	et	3	main
või	doc_740091151012_item	2843074	et	4	main
keelt	doc_740091151012_item	2843081	et	4	main
omanud	doc_740091151012_item	2843084	et	4	main
tõeliselt	doc_740091151012_item	2843139	et	4	main
et	doc_740091151012_item	2843153	et	3	main
eest	doc_740091151012_item	2843159	et	4	main
mille	doc_740091151012_item	2843160	et	3	main
tuttav	doc_740091151012_item	2843163	et	3	main
seda	doc_740091151012_item	2843167	et	3	main
ei	doc_740091151012_item	2843183	et	4	main
kodumaal	doc_740091151012_item	2843188	et	4	main
venelasi	doc_740091151012_item	2843193	et	3	main
venelases	doc_740091151012_item	2843198	et	3	main
meie	doc_740091151012_item	2843201	et	4	main
siin	doc_740091151012_item	2843203	et	4	main
venelased	doc_740091151012_item	2843205	et	3	main
ja	doc_740091151012_item	2843208	et	3	main
numbritena	doc_740091151012_item	2843221	et	3	main
ei	doc_740091151012_item	2843239	et	4	main
ega	doc_740091151012_item	2843241	et	3	main
olemust	doc_740091151012_item	2843250	et	3	main
abil	doc_740091151012_item	2843273	et	4	main
aru	doc_740091151012_item	2843314	et	4	main
ta	doc_740091151012_item	2843317	et	4	main
tekitab	doc_740091151012_item	2843320	et	3	main
kui	doc_740091151012_item	2843323	et	3	main
ta	doc_740091151012_item	2843327	et	4	main
niimoodi	doc_740091151012_item	2843335	et	3	main
ütleb	doc_740091151012_item	2843342	et	3	main
ole	doc_740091151012_item	2843345	et	4	main
muu	doc_740091151012_item	2843349	et	4	main
eurooplane	doc_740091151012_item	2843350	et	3	main
ei	doc_740091151012_item	2843351	et	4	main
riigis	doc_740091151012_item	2843354	et	3	main
koos	doc_740091151012_item	2843366	et	4	main
teist	doc_740091151012_item	2843388	et	4	main
on	doc_740091151012_item	2843399	et	4	main
juba	doc_740091151012_item	2843400	et	3	main
pikka	doc_740091151012_item	2843401	et	4	main
elame	doc_740091151012_item	2843406	et	3	main
kuid	doc_740091151012_item	2843409	et	4	main
ühises	doc_740091151012_item	2843411	et	3	main
ei	doc_740091151012_item	2843030	et	4	main
kodumaal	doc_740091151012_item	2843038	et	4	main
arsti	doc_740091151012_item	2843043	et	4	main
ehk	doc_740091151012_item	2843047	et	3	main
šveits	doc_740091151012_item	2843056	et	2	main
lausa	doc_740091151012_item	2843059	et	4	main
riigikeelt	doc_740091151012_item	2843061	et	4	main
minu	doc_740091151012_item	2843062	et	3	main
argument	doc_740091151012_item	2843063	et	3	main
elavad	doc_740091151012_item	2843066	et	4	main
õppinud	doc_740091151012_item	2843073	et	4	main
inglise	doc_740091151012_item	2843080	et	4	main
arvates	doc_740091151012_item	2843086	et	4	main
tähtsust	doc_740091151012_item	2843087	et	4	main
küll	doc_740091151012_item	2843088	et	4	main
aga	doc_740091151012_item	2843089	et	3	main
avaldas	doc_740091151012_item	2843090	et	3	main
ta	doc_740091151012_item	2843091	et	4	main
lootust	doc_740091151012_item	2843092	et	4	main
et	doc_740091151012_item	2843093	et	3	main
varsti	doc_740091151012_item	2843094	et	3	main
on	doc_740091151012_item	2843095	et	4	main
riigikogus	doc_740091151012_item	2843096	et	4	main
piisavalt	doc_740091151012_item	2843097	et	4	main
palju	doc_740091151012_item	2843098	et	4	main
venelasi	doc_740091151012_item	2843099	et	3	main
kus	doc_740091151012_item	2843100	et	3	main
oma	doc_740091151012_item	2843101	et	4	main
rahvuskaaslaste	doc_740091151012_item	2843102	et	4	main
heaolu	doc_740091151012_item	2843103	et	4	main
nimel	doc_740091151012_item	2843104	et	3	main
võitlevad	doc_740091151012_item	2843105	et	4	main
diskussioon	doc_740091151012_item	2843106	et	3	main
kestis	doc_740091151012_item	2843107	et	4	main
veel	doc_740091151012_item	2843108	et	4	main
kaua	doc_740091151012_item	2843109	et	3	main
kuid	doc_740091151012_item	2843110	et	4	main
kulmineerus	doc_740091151012_item	2843111	et	4	main
ja	doc_740091151012_item	2843112	et	3	main
see	doc_740091151012_item	2843114	et	3	main
noormehe	doc_740091151012_item	2843115	et	3	main
enda	doc_740091151012_item	2843116	et	4	main
lõppes	doc_740091151012_item	2843113	et	4	main
sõnade	doc_740091151012_item	2843117	et	3	main
tõttu	doc_740091151012_item	2843118	et	4	main
sest	doc_740091151012_item	2843119	et	4	main
ta	doc_740091151012_item	2843120	et	4	main
et	doc_740091151012_item	2843122	et	3	main
sõnu	doc_740091151012_item	2843137	et	4	main
olin	doc_740091151012_item	2843138	et	3	main
seda	doc_740091151012_item	2843141	et	3	main
et	doc_740091151012_item	2843149	et	3	main
kes	doc_740091151012_item	2843156	et	4	main
teevad	doc_740091151012_item	2843166	et	3	main
äärmiselt	doc_740091151012_item	2843168	et	4	main
et	doc_740091151012_item	2843172	et	3	main
valda	doc_740091151012_item	2843184	et	4	main
kõrvuti	doc_740091151012_item	2843189	et	3	main
ja	doc_740091151012_item	2843192	et	3	main
poliitikud	doc_740091151012_item	2843195	et	3	main
igas	doc_740091151012_item	2843197	et	3	main
potensiaalset	doc_740091151012_item	2843199	et	4	main
riigile	doc_740091151012_item	2843202	et	3	main
elavad	doc_740091151012_item	2843204	et	4	main
surveavaldamist	doc_740091151012_item	2843207	et	3	main
erinevatel	doc_740091151012_item	2843219	et	4	main
raportitel	doc_740091151012_item	2843220	et	3	main
mainis	doc_740091151012_item	2843121	et	3	main
tal	doc_740091151012_item	2843123	et	3	main
sõpra	doc_740091151012_item	2843127	et	4	main
ja	doc_740091151012_item	2843128	et	3	main
ise	doc_740091151012_item	2843130	et	4	main
ei	doc_740091151012_item	2843131	et	4	main
tema	doc_740091151012_item	2843136	et	4	main
üllatunud	doc_740091151012_item	2843140	et	4	main
uskunud	doc_740091151012_item	2843152	et	4	main
olukord	doc_740091151012_item	2843161	et	3	main
leidlikult	doc_740091151012_item	2843169	et	4	main
seetõttu	doc_740091151012_item	2843171	et	3	main
ei	doc_740091151012_item	2843174	et	4	main
kui	doc_740091151012_item	2843176	et	3	main
mina	doc_740091151012_item	2843185	et	4	main
näen	doc_740091151012_item	2843186	et	3	main
oma	doc_740091151012_item	2843187	et	4	main
näevad	doc_740091151012_item	2843206	et	3	main
tobedaid	doc_740091151012_item	2843209	et	3	main
viimasest	doc_740091151012_item	2843223	et	3	main
kahju	doc_740091151012_item	2843227	et	4	main
see	doc_740091151012_item	2843229	et	3	main
mõiste	doc_740091151012_item	2843247	et	4	main
muutmas	doc_740091151012_item	2843251	et	3	main
kultuuri	doc_740091151012_item	2843257	et	4	main
tavade	doc_740091151012_item	2843258	et	3	main
ja	doc_740091151012_item	2843259	et	3	main
kommetega	doc_740091151012_item	2843260	et	4	main
tihti	doc_740091151012_item	2843267	et	3	main
konteksti	doc_740091151012_item	2843270	et	4	main
tema	doc_740091151012_item	2843272	et	4	main
erinevusi	doc_740091151012_item	2843275	et	4	main
ütles	doc_740091151012_item	2843318	et	3	main
minus	doc_740091151012_item	2843321	et	3	main
miks	doc_740091151012_item	2843326	et	4	main
ütles	doc_740091151012_item	2843329	et	3	main
eks	doc_740091151012_item	2843343	et	3	main
näe	doc_740091151012_item	2843352	et	4	main
toimuvat	doc_740091151012_item	2843355	et	4	main
iialgi	doc_740091151012_item	2843356	et	4	main
näen	doc_740091151012_item	2843362	et	3	main
veski	doc_740091151012_item	2843405	et	4	main
maalapil	doc_740091151012_item	2843408	et	3	main
ruumis	doc_740091151012_item	2843413	et	4	main
seetõttu	doc_740091151012_item	2843148	et	3	main
poleks	doc_740091151012_item	2843151	et	3	main
inimesi	doc_740091151012_item	2843155	et	4	main
võitlevad	doc_740091151012_item	2843157	et	4	main
millegi	doc_740091151012_item	2843158	et	4	main
pole	doc_740091151012_item	2843164	et	3	main
teemadel	doc_740091151012_item	2843179	et	3	main
mida	doc_740091151012_item	2843180	et	4	main
ta	doc_740091151012_item	2843181	et	4	main
hästi	doc_740091151012_item	2843182	et	3	main
elavaid	doc_740091151012_item	2843190	et	4	main
meie	doc_740091151012_item	2843194	et	4	main
näevad	doc_740091151012_item	2843196	et	3	main
ohtu	doc_740091151012_item	2843200	et	4	main
eurooplane	doc_740091151012_item	2843211	et	3	main
tea	doc_740091151012_item	2843213	et	4	main
muud	doc_740091151012_item	2843215	et	4	main
kui	doc_740091151012_item	2843216	et	3	main
seda	doc_740091151012_item	2843217	et	3	main
mis	doc_740091151012_item	2843218	et	4	main
seisab	doc_740091151012_item	2843222	et	3	main
eriti	doc_740091151012_item	2843226	et	3	main
ei	doc_740091151012_item	2843234	et	4	main
ei	doc_740091151012_item	2843237	et	4	main
tundest	doc_740091151012_item	2843243	et	4	main
traditsioon	doc_740091151012_item	2843245	et	3	main
varasemalt	doc_740091151012_item	2843253	et	4	main
see	doc_740091151012_item	2843255	et	3	main
nüüd	doc_740091151012_item	2843263	et	4	main
on	doc_740091151012_item	2843264	et	4	main
see	doc_740091151012_item	2843265	et	3	main
sõna	doc_740091151012_item	2843266	et	4	main
tüdruk	doc_740091151012_item	2843311	et	3	main
tegelikult	doc_740091151012_item	2843312	et	4	main
ka	doc_740091151012_item	2843313	et	3	main
kuid	doc_740091151012_item	2843319	et	4	main
mul	doc_740091151012_item	2843225	et	3	main
mis	doc_740091151012_item	2843230	et	4	main
toimub	doc_740091151012_item	2843232	et	3	main
paberitel	doc_740091151012_item	2843233	et	3	main
kajastu	doc_740091151012_item	2843235	et	4	main
kui	doc_740091151012_item	2843252	et	3	main
oli	doc_740091151012_item	2843254	et	3	main
tihedalt	doc_740091151012_item	2843256	et	4	main
ka	doc_740091151012_item	2843269	et	3	main
kus	doc_740091151012_item	2843271	et	3	main
rõhutada	doc_740091151012_item	2843277	et	3	main
uskumatumal	doc_740091151012_item	2843279	et	4	main
kuulsin	doc_740091151012_item	2843281	et	3	main
seda	doc_740091151012_item	2843282	et	3	main
ühistranspordis	doc_740091151012_item	2843283	et	3	main
kus	doc_740091151012_item	2843284	et	3	main
väikesed	doc_740091151012_item	2843285	et	4	main
tüdrukud	doc_740091151012_item	2843286	et	3	main
omavahel	doc_740091151012_item	2843287	et	3	main
vestlesid	doc_740091151012_item	2843288	et	4	main
ja	doc_740091151012_item	2843289	et	3	main
üks	doc_740091151012_item	2843290	et	3	main
neist	doc_740091151012_item	2843291	et	4	main
teatas	doc_740091151012_item	2843292	et	3	main
et	doc_740091151012_item	2843293	et	3	main
tema	doc_740091151012_item	2843294	et	4	main
venelastega	doc_740091151012_item	2843295	et	4	main
ei	doc_740091151012_item	2843296	et	4	main
suhtle	doc_740091151012_item	2843297	et	4	main
sest	doc_740091151012_item	2843298	et	4	main
see	doc_740091151012_item	2843299	et	3	main
on	doc_740091151012_item	2843300	et	4	main
nende	doc_740091151012_item	2843301	et	4	main
pere	doc_740091151012_item	2843302	et	4	main
traditsioon	doc_740091151012_item	2843303	et	3	main
ma	doc_740091151012_item	2843304	et	3	main
ei	doc_740091151012_item	2843305	et	4	main
usu	doc_740091151012_item	2843306	et	4	main
iialgi	doc_740091151012_item	2843307	et	4	main
et	doc_740091151012_item	2843308	et	3	main
see	doc_740091151012_item	2843309	et	3	main
pisike	doc_740091151012_item	2843310	et	3	main
kui	doc_740091151012_item	2843246	et	3	main
on	doc_740091151012_item	2843248	et	4	main
oma	doc_740091151012_item	2843249	et	4	main
seotud	doc_740091151012_item	2843261	et	4	main
siis	doc_740091151012_item	2843262	et	3	main
haaratud	doc_740091151012_item	2843268	et	4	main
inimeste	doc_740091151012_item	2843274	et	3	main
saab	doc_740091151012_item	2843276	et	3	main
kõige	doc_740091151012_item	2843278	et	4	main
moel	doc_740091151012_item	2843280	et	4	main
mida	doc_740091151012_item	2843316	et	4	main
muret	doc_740091151012_item	2843322	et	3	main
mõtlen	doc_740091151012_item	2843324	et	3	main
õdedest-vendadest	doc_740091151012_item	2843333	et	3	main
vanavanematest	doc_740091151012_item	2843334	et	4	main
öelnud	doc_740091151012_item	2843336	et	4	main
on	doc_740091151012_item	2843337	et	4	main
et	doc_740091151012_item	2843338	et	3	main
7-aastane	doc_740091151012_item	2843339	et	4	main
et	doc_740091151012_item	2843348	et	3	main
nagu	doc_740091151012_item	2843358	et	3	main
me	doc_740091151012_item	2843359	et	4	main
mina	doc_740091151012_item	2843361	et	4	main
kes	doc_740091151012_item	2843364	et	4	main
elavad	doc_740091151012_item	2843365	et	4	main
märkimisväärne	doc_740091151012_item	2843390	et	3	main
on	doc_740091151012_item	2843391	et	4	main
et	doc_740091151012_item	2843393	et	3	main
mitte	doc_740091151012_item	2843410	et	3	main
kultuuri	doc_740091151012_item	2843412	et	4	main
sai	doc_740091151012_item	2843315	et	4	main
et	doc_740091151012_item	2843325	et	3	main
nii	doc_740091151012_item	2843328	et	3	main
kes	doc_740091151012_item	2843330	et	4	main
tema	doc_740091151012_item	2843331	et	4	main
ise	doc_740091151012_item	2843360	et	4	main
inimesi	doc_740091151012_item	2843363	et	4	main
omamoodi	doc_740091151012_item	2843389	et	3	main
kahe	doc_740091151012_item	2843394	et	3	main
kultuuriruumi	doc_740091151012_item	2843396	et	4	main
suurimaks	doc_740091151012_item	2843397	et	4	main
ühisosaks	doc_740091151012_item	2843398	et	3	main
anne	doc_740091151012_item	2843404	et	4	main
vanematest	doc_740091151012_item	2843332	et	4	main
laps	doc_740091151012_item	2843340	et	4	main
nii	doc_740091151012_item	2843341	et	3	main
see	doc_740091151012_item	2843344	et	3	main
kurbtõsine	doc_740091151012_item	2843346	et	4	main
fakt	doc_740091151012_item	2843347	et	3	main
meie	doc_740091151012_item	2843353	et	4	main
sellisena	doc_740091151012_item	2843357	et	4	main
suhtlevad	doc_740091151012_item	2843367	et	4	main
omavahel	doc_740091151012_item	2843368	et	3	main
kuid	doc_740091151012_item	2843369	et	4	main
alati	doc_740091151012_item	2843370	et	4	main
on	doc_740091151012_item	2843371	et	4	main
õhus	doc_740091151012_item	2843372	et	3	main
teatav	doc_740091151012_item	2843373	et	4	main
pinge	doc_740091151012_item	2843374	et	4	main
eestlastel	doc_740091151012_item	2843375	et	4	main
on	doc_740091151012_item	2843376	et	4	main
oma	doc_740091151012_item	2843377	et	4	main
kultuur	doc_740091151012_item	2843378	et	3	main
venelastel	doc_740091151012_item	2843379	et	4	main
oma	doc_740091151012_item	2843380	et	4	main
ja	doc_740091151012_item	2843381	et	3	main
eestivenelased	doc_740091151012_item	2843382	et	3	main
haaravad	doc_740091151012_item	2843383	et	4	main
nii	doc_740091151012_item	2843384	et	3	main
ühte	doc_740091151012_item	2843385	et	4	main
kui	doc_740091151012_item	2843386	et	3	main
ka	doc_740091151012_item	2843387	et	3	main
asjaolu	doc_740091151012_item	2843392	et	4	main
rahvuse	doc_740091151012_item	2843395	et	3	main
aega	doc_740091151012_item	2843402	et	4	main
hoopistühis	doc_740091151012_item	2843403	et	4	main
samal	doc_740091151012_item	2843407	et	3	main
pruunid	doc_740091151014_item	2843833	et	3	main
the	doc_740091151014_item	2843851	et	4	main
mustad	doc_740091151014_item	2843860	et	4	main
on	doc_740091151014_item	2843862	et	4	main
külastada	doc_740091151014_item	2843870	et	3	main
on	doc_740091151014_item	2843875	et	4	main
sisse	doc_740091151014_item	2843881	et	4	main
nii	doc_740091151014_item	2843885	et	3	main
ongi	doc_740091151014_item	2843938	et	4	main
normaalne	doc_740091151014_item	2843939	et	3	main
tunduvalt	doc_740091151014_item	2843946	et	4	main
parem	doc_740091151014_item	2843947	et	4	main
või	doc_740091151014_item	2843948	et	4	main
halvem	doc_740091151014_item	2843949	et	4	main
nimetatakse	doc_740091151014_item	2843950	et	3	main
olema	doc_740091151014_item	2843969	et	4	main
kas	doc_740091151014_item	2843970	et	3	main
olete	doc_740091151014_item	2843971	et	3	main
see	doc_740091151014_item	2843977	et	3	main
ju	doc_740091151014_item	2843979	et	3	main
normaalne	doc_740091151014_item	2843982	et	3	main
ometi	doc_740091151014_item	2843988	et	3	main
et	doc_740091151014_item	2843990	et	3	main
piiri	doc_740091151014_item	2843998	et	4	main
minu	doc_740091151014_item	2843999	et	3	main
ei	doc_740091151014_item	2844002	et	4	main
kindlasti	doc_740091151014_item	2844004	et	3	main
normaalne	doc_740091151014_item	2843821	et	3	main
55	doc_740091151014_item	2843827	et	2	main
silmade	doc_740091151014_item	2843829	et	3	main
värv	doc_740091151014_item	2843830	et	3	main
roheline	doc_740091151014_item	2843831	et	4	main
juuksed	doc_740091151014_item	2843832	et	3	main
kuulu	doc_740091151014_item	2843838	et	4	main
suni	doc_740091151014_item	2843852	et	4	main
mingeid	doc_740091151014_item	2843853	et	3	main
nõudepesulapid	doc_740091151014_item	2843861	et	3	main
ka	doc_740091151014_item	2843865	et	3	main
inimesed	doc_740091151014_item	2843876	et	3	main
teatud	doc_740091151014_item	2843878	et	4	main
standardit	doc_740091151014_item	2843879	et	3	main
välimuses	doc_740091151014_item	2843886	et	3	main
ka	doc_740091151014_item	2843921	et	3	main
leiutanud	doc_740091151014_item	2843928	et	4	main
sellise	doc_740091151014_item	2843929	et	4	main
mahtumine	doc_740091151014_item	2843937	et	4	main
miski	doc_740091151014_item	2843941	et	4	main
on	doc_740091151014_item	2843942	et	4	main
inimeste	doc_740091151014_item	2843956	et	3	main
kuulnud	doc_740091151014_item	2843972	et	4	main
väljendit	doc_740091151014_item	2843973	et	3	main
iseloomustamises	doc_740091151014_item	2843976	et	3	main
on	doc_740091151014_item	2843978	et	4	main
küll	doc_740091151014_item	2843980	et	4	main
täiesti	doc_740091151014_item	2843981	et	3	main
mina	doc_740091151014_item	2843984	et	4	main
küll	doc_740091151014_item	2843985	et	4	main
loodus	doc_740091151014_item	2843992	et	4	main
paika	doc_740091151014_item	2843994	et	4	main
koer	doc_740091151014_item	2844001	et	3	main
ole	doc_740091151014_item	2844003	et	4	main
ja	doc_740091151014_item	2844021	et	3	main
pikkus	doc_740091151014_item	2843823	et	4	main
cm	doc_740091151014_item	2843825	et	4	main
ma	doc_740091151014_item	2843836	et	3	main
ka	doc_740091151014_item	2843841	et	3	main
suvel	doc_740091151014_item	2843844	et	3	main
õllesummeril	doc_740091151014_item	2843846	et	3	main
ja	doc_740091151014_item	2843847	et	3	main
erilisi	doc_740091151014_item	2843854	et	4	main
foobiaid	doc_740091151014_item	2843855	et	3	main
ok	doc_740091151014_item	2843858	et	4	main
rõvedad	doc_740091151014_item	2843863	et	3	main
psühhiaatrit	doc_740091151014_item	2843866	et	3	main
vajadust	doc_740091151014_item	2843868	et	4	main
normaalne	doc_740091151014_item	2843871	et	3	main
läbi	doc_740091151014_item	2843873	et	4	main
aegade	doc_740091151014_item	2843874	et	3	main
otsinud	doc_740091151014_item	2843877	et	4	main
mille	doc_740091151014_item	2843880	et	3	main
käitumises	doc_740091151014_item	2843887	et	4	main
otsivad	doc_740091151014_item	2843923	et	4	main
nimelt	doc_740091151014_item	2843925	et	4	main
nagu	doc_740091151014_item	2843931	et	3	main
teatud	doc_740091151014_item	2843934	et	4	main
kui	doc_740091151014_item	2843940	et	3	main
sellest	doc_740091151014_item	2843943	et	4	main
koer	doc_740091151014_item	2843983	et	3	main
arvan	doc_740091151014_item	2843989	et	3	main
on	doc_740091151014_item	2843993	et	4	main
sättinud	doc_740091151014_item	2843995	et	4	main
nö	doc_740091151014_item	2843996	et	4	main
isiklik	doc_740091151014_item	2844000	et	3	main
aga	doc_740091151014_item	2844025	et	3	main
säilitab	doc_740091151014_item	2844046	et	3	main
oma	doc_740091151014_item	2844048	et	4	main
kui	doc_740091151014_item	2844051	et	3	main
veetase	doc_740091151014_item	2844052	et	3	main
või	doc_740091151014_item	2844053	et	4	main
õnnetusi	doc_740091151014_item	2844064	et	4	main
tugevamad	doc_740091151014_item	2844070	et	4	main
essee	doc_740091151014_item	2843810	et	4	main
saage	doc_740091151014_item	2843811	et	4	main
tuttavaks	doc_740091151014_item	2843812	et	4	main
normaalne	doc_740091151014_item	2843813	et	3	main
tere	doc_740091151014_item	2843815	et	3	main
inimene	doc_740091151014_item	2843814	et	3	main
saame	doc_740091151014_item	2843816	et	4	main
mina	doc_740091151014_item	2843818	et	4	main
tuttavaks	doc_740091151014_item	2843817	et	4	main
olen	doc_740091151014_item	2843819	et	3	main
täiesti	doc_740091151014_item	2843820	et	3	main
erakondadesse	doc_740091151014_item	2843835	et	3	main
inimene	doc_740091151014_item	2843822	et	3	main
170	doc_740091151014_item	2843824	et	2	main
kaal	doc_740091151014_item	2843826	et	3	main
kg	doc_740091151014_item	2843828	et	4	main
poliitilistesse	doc_740091151014_item	2843834	et	3	main
ei	doc_740091151014_item	2843837	et	4	main
kuid	doc_740091151014_item	2843839	et	4	main
keskerakonda	doc_740091151014_item	2843840	et	4	main
armasta	doc_740091151014_item	2843843	et	4	main
tanel	doc_740091151014_item	2843849	et	4	main
padar	doc_740091151014_item	2843850	et	4	main
mul	doc_740091151014_item	2843856	et	3	main
eriliselt	doc_740091151014_item	2843869	et	4	main
ju	doc_740091151014_item	2843872	et	3	main
mahtuda	doc_740091151014_item	2843882	et	3	main
on	doc_740091151014_item	2843884	et	4	main
kultuuris	doc_740091151014_item	2843888	et	3	main
jne	doc_740091151014_item	2843890	et	4	main
normidest	doc_740091151014_item	2843891	et	3	main
ei	doc_740091151014_item	2843892	et	4	main
tahetagi	doc_740091151014_item	2843893	et	4	main
kõrvale	doc_740091151014_item	2843895	et	4	main
kalduda	doc_740091151014_item	2843896	et	3	main
harilikult	doc_740091151014_item	2843894	et	4	main
hallist	doc_740091151014_item	2843897	et	4	main
massist	doc_740091151014_item	2843898	et	3	main
ei	doc_740091151014_item	2843899	et	4	main
taheta	doc_740091151014_item	2843900	et	3	main
erineda	doc_740091151014_item	2843901	et	3	main
see	doc_740091151014_item	2843902	et	3	main
on	doc_740091151014_item	2843903	et	4	main
ja	doc_740091151014_item	2843905	et	3	main
elu	doc_740091151014_item	2843904	et	4	main
see	doc_740091151014_item	2843906	et	3	main
ongi	doc_740091151014_item	2843907	et	4	main
normaalsus	doc_740091151014_item	2843908	et	4	main
normaalsus	doc_740091151014_item	2843909	et	4	main
on	doc_740091151014_item	2843910	et	4	main
normaalne	doc_740091151014_item	2843911	et	3	main
inimesed	doc_740091151014_item	2843912	et	3	main
vajavad	doc_740091151014_item	2843913	et	4	main
seda	doc_740091151014_item	2843914	et	3	main
võtame	doc_740091151014_item	2843915	et	3	main
kasvõi	doc_740091151014_item	2843916	et	3	main
sellise	doc_740091151014_item	2843917	et	4	main
täppisteaduse	doc_740091151014_item	2843918	et	3	main
nagu	doc_740091151014_item	2843919	et	3	main
matemaatika	doc_740091151014_item	2843920	et	4	main
ei	doc_740091151014_item	2843842	et	4	main
käin	doc_740091151014_item	2843845	et	3	main
kuulan	doc_740091151014_item	2843848	et	3	main
pole	doc_740091151014_item	2843857	et	3	main
ok	doc_740091151014_item	2843859	et	4	main
ja	doc_740091151014_item	2843864	et	3	main
pole	doc_740091151014_item	2843867	et	3	main
standard	doc_740091151014_item	2843883	et	3	main
hoiakutes	doc_740091151014_item	2843889	et	3	main
matemaakikud	doc_740091151014_item	2843922	et	4	main
normaalsust	doc_740091151014_item	2843924	et	4	main
viguri	doc_740091151014_item	2843930	et	3	main
nö	doc_740091151014_item	2843944	et	4	main
normaalsusest	doc_740091151014_item	2843945	et	4	main
seda	doc_740091151014_item	2843951	et	3	main
hälbeks	doc_740091151014_item	2843952	et	3	main
elu	doc_740091151014_item	2843953	et	4	main
näitab	doc_740091151014_item	2843954	et	3	main
et	doc_740091151014_item	2843955	et	3	main
võrdlemisel	doc_740091151014_item	2843958	et	4	main
valdav	doc_740091151014_item	2843961	et	4	main
enamus	doc_740091151014_item	2843962	et	4	main
normaalkõvera	doc_740091151014_item	2843963	et	3	main
normaalpiiridesse	doc_740091151014_item	2843964	et	3	main
ja	doc_740091151014_item	2843965	et	3	main
see	doc_740091151014_item	2843966	et	3	main
peabki	doc_740091151014_item	2843967	et	4	main
nii	doc_740091151014_item	2843968	et	3	main
looma	doc_740091151014_item	2843975	et	4	main
ei	doc_740091151014_item	2843986	et	4	main
normaalsuse	doc_740091151014_item	2843997	et	4	main
eelistab	doc_740091151014_item	2844023	et	3	main
ta	doc_740091151014_item	2844024	et	4	main
õuna	doc_740091151014_item	2844029	et	4	main
kas	doc_740091151014_item	2844030	et	3	main
olete	doc_740091151014_item	2844031	et	3	main
teooria	doc_740091151014_item	2844039	et	4	main
ja	doc_740091151014_item	2844041	et	3	main
temperatuur	doc_740091151014_item	2844054	et	3	main
normaalsest	doc_740091151014_item	2844056	et	3	main
kõrgemale	doc_740091151014_item	2844057	et	4	main
on	doc_740091151014_item	2844058	et	4	main
hälbega	doc_740091151014_item	2844065	et	3	main
normaalne	doc_740091151014_item	2844075	et	3	main
jällegi	doc_740091151014_item	2844078	et	4	main
paigalt	doc_740091151014_item	2844080	et	4	main
minu	doc_740091151014_item	2844081	et	3	main
sest	doc_740091151014_item	2844088	et	4	main
tänaval	doc_740091151014_item	2844098	et	4	main
mõnda	doc_740091151014_item	2844099	et	4	main
inimest	doc_740091151014_item	2844100	et	3	main
totaalse	doc_740091151014_item	2844103	et	3	main
meist	doc_740091151014_item	2844113	et	3	main
nahavärv	doc_740091151014_item	2844121	et	3	main
mis	doc_740091151014_item	2844123	et	4	main
iganes	doc_740091151014_item	2844124	et	4	main
ometi	doc_740091151014_item	2844125	et	3	main
nähes	doc_740091151014_item	2844133	et	4	main
ongi	doc_740091151014_item	2844138	et	4	main
vaatame	doc_740091151014_item	2844144	et	3	main
tuttavalt	doc_740091151014_item	2844153	et	4	main
siis	doc_740091151014_item	2844159	et	3	main
väljaminekut	doc_740091151014_item	2844183	et	3	main
kuidas	doc_740091151014_item	2844192	et	3	main
väga	doc_740091151014_item	2844221	et	3	main
sõber	doc_740091151014_item	2844223	et	3	main
elukaaslane	doc_740091151014_item	2844226	et	3	main
pigem	doc_740091151014_item	2844234	et	3	main
kui	doc_740091151014_item	2844241	et	3	main
iga	doc_740091151014_item	2844244	et	4	main
hakkab	doc_740091151014_item	2844248	et	3	main
rõhutan	doc_740091151014_item	2844256	et	3	main
inimesed	doc_740091151014_item	2844257	et	3	main
vajavad	doc_740091151014_item	2844258	et	4	main
hulka	doc_740091151014_item	2844269	et	4	main
olen	doc_740091151014_item	2844270	et	3	main
juuksed	doc_740091151014_item	2844278	et	3	main
samuti	doc_740091151014_item	2844281	et	3	main
ka	doc_740091151014_item	2844283	et	3	main
kuulu	doc_740091151014_item	2844286	et	4	main
kuhugi	doc_740091151014_item	2844287	et	4	main
on	doc_740091151014_item	2843926	et	4	main
nad	doc_740091151014_item	2843927	et	3	main
normaalkõver	doc_740091151014_item	2843932	et	3	main
normaalkõvera	doc_740091151014_item	2843933	et	3	main
osa	doc_740091151014_item	2843935	et	4	main
sisse	doc_740091151014_item	2843936	et	4	main
tulemuste	doc_740091151014_item	2843957	et	4	main
mahub	doc_740091151014_item	2843959	et	3	main
tõepoolest	doc_740091151014_item	2843960	et	3	main
mõne	doc_740091151014_item	2843974	et	3	main
ole	doc_740091151014_item	2843987	et	4	main
ka	doc_740091151014_item	2843991	et	3	main
normaalne	doc_740091151014_item	2844005	et	3	main
jalutada	doc_740091151014_item	2844006	et	3	main
ega	doc_740091151014_item	2844007	et	3	main
liikuda	doc_740091151014_item	2844008	et	3	main
talle	doc_740091151014_item	2844009	et	4	main
üldse	doc_740091151014_item	2844010	et	3	main
ei	doc_740091151014_item	2844011	et	4	main
pigem	doc_740091151014_item	2844013	et	3	main
meeldi	doc_740091151014_item	2844012	et	4	main
armastab	doc_740091151014_item	2844014	et	3	main
ta	doc_740091151014_item	2844015	et	4	main
diivani	doc_740091151014_item	2844016	et	4	main
all	doc_740091151014_item	2844017	et	3	main
mõnusalt	doc_740091151014_item	2844018	et	4	main
lesida	doc_740091151014_item	2844019	et	3	main
vorstile	doc_740091151014_item	2844020	et	3	main
lihale	doc_740091151014_item	2844022	et	3	main
kurki	doc_740091151014_item	2844027	et	4	main
kindlasti	doc_740091151014_item	2844040	et	3	main
et	doc_740091151014_item	2844043	et	3	main
kaudu	doc_740091151014_item	2844045	et	3	main
normaalsuse	doc_740091151014_item	2844050	et	4	main
rikuradapidi	doc_740091151014_item	2844060	et	4	main
katastroofe	doc_740091151014_item	2844061	et	3	main
ja	doc_740091151014_item	2844062	et	3	main
isendid	doc_740091151014_item	2844066	et	3	main
on	doc_740091151014_item	2844074	et	4	main
läheks	doc_740091151014_item	2844077	et	3	main
te	doc_740091151014_item	2844096	et	4	main
mina	doc_740091151014_item	2844106	et	4	main
mäleta	doc_740091151014_item	2844108	et	4	main
sellist	doc_740091151014_item	2844109	et	4	main
neid	doc_740091151014_item	2844128	et	4	main
kui	doc_740091151014_item	2844129	et	3	main
me	doc_740091151014_item	2844130	et	4	main
ei	doc_740091151014_item	2844136	et	4	main
ta	doc_740091151014_item	2844139	et	4	main
veel	doc_740091151014_item	2844145	et	4	main
inimeste	doc_740091151014_item	2844146	et	3	main
kooliõpilaselt	doc_740091151014_item	2844154	et	3	main
pea	doc_740091151014_item	2844160	et	4	main
on	doc_740091151014_item	2844162	et	4	main
normaalselt	doc_740091151014_item	2844164	et	4	main
küsid	doc_740091151014_item	2844165	et	3	main
sõbralt	doc_740091151014_item	2844166	et	3	main
kellega	doc_740091151014_item	2844167	et	3	main
kinos	doc_740091151014_item	2844168	et	3	main
vastuseks	doc_740091151014_item	2844177	et	4	main
lakooniline	doc_740091151014_item	2844178	et	3	main
normaalne	doc_740091151014_item	2844179	et	3	main
olles	doc_740091151014_item	2844184	et	3	main
end	doc_740091151014_item	2844186	et	4	main
3	doc_740091151014_item	2844188	et	2	main
tundi	doc_740091151014_item	2844189	et	4	main
hoopiski	doc_740091151014_item	2844026	et	3	main
ja	doc_740091151014_item	2844028	et	3	main
kuulnud	doc_740091151014_item	2844032	et	4	main
väljendeid	doc_740091151014_item	2844033	et	3	main
nagu	doc_740091151014_item	2844034	et	3	main
looduslik	doc_740091151014_item	2844035	et	3	main
tasakaal	doc_740091151014_item	2844036	et	3	main
väidan	doc_740091151014_item	2844042	et	3	main
nende	doc_740091151014_item	2844044	et	4	main
loodus	doc_740091151014_item	2844047	et	4	main
tõusevad	doc_740091151014_item	2844055	et	4	main
muid	doc_740091151014_item	2844063	et	4	main
surevad	doc_740091151014_item	2844068	et	4	main
taimetoitlasest	doc_740091151014_item	2844082	et	3	main
koer	doc_740091151014_item	2844083	et	3	main
ta	doc_740091151014_item	2844089	et	4	main
kaldub	doc_740091151014_item	2844090	et	3	main
nähes	doc_740091151014_item	2844101	et	4	main
osaliseks	doc_740091151014_item	2844105	et	4	main
ei	doc_740091151014_item	2844107	et	4	main
kes	doc_740091151014_item	2844112	et	4	main
mööduvad	doc_740091151014_item	2844114	et	4	main
võivad	doc_740091151014_item	2844115	et	4	main
olla	doc_740091151014_item	2844116	et	3	main
väga	doc_740091151014_item	2844117	et	3	main
erinevad	doc_740091151014_item	2844118	et	4	main
erinev	doc_740091151014_item	2844119	et	4	main
riietusstiil	doc_740091151014_item	2844120	et	3	main
me	doc_740091151014_item	2844126	et	4	main
aktsepteerime	doc_740091151014_item	2844127	et	3	main
lausa	doc_740091151014_item	2844134	et	4	main
normaalne	doc_740091151014_item	2844142	et	3	main
küsida	doc_740091151014_item	2844151	et	3	main
kelleltki	doc_740091151014_item	2844152	et	4	main
kuidas	doc_740091151014_item	2844156	et	3	main
koolis	doc_740091151014_item	2844157	et	4	main
no	doc_740091151014_item	2844170	et	3	main
kuidas	doc_740091151014_item	2844171	et	3	main
film	doc_740091151014_item	2844172	et	3	main
sättinud	doc_740091151014_item	2844190	et	4	main
maailma	doc_740091151014_item	2844227	et	4	main
ilusam	doc_740091151014_item	2844229	et	4	main
oleks	doc_740091151014_item	2844231	et	3	main
inimene	doc_740091151014_item	2844242	et	3	main
midagi	doc_740091151014_item	2844246	et	4	main
normaalseks	doc_740091151014_item	2844254	et	4	main
ma	doc_740091151014_item	2844255	et	3	main
olen	doc_740091151014_item	2844264	et	3	main
ja	doc_740091151014_item	2844274	et	3	main
aga	doc_740091151014_item	2844277	et	3	main
on	doc_740091151014_item	2844279	et	4	main
pruunid	doc_740091151014_item	2844282	et	3	main
mina	doc_740091151014_item	2844284	et	4	main
keskerakonda	doc_740091151014_item	2844290	et	4	main
ei	doc_740091151014_item	2844292	et	4	main
õllesummeril	doc_740091151014_item	2844294	et	3	main
pole	doc_740091151014_item	2844295	et	3	main
padar	doc_740091151014_item	2844301	et	4	main
the	doc_740091151014_item	2844302	et	4	main
saun	doc_740091151014_item	2844303	et	3	main
ja	doc_740091151014_item	2844315	et	3	main
ja	doc_740091151014_item	2844037	et	3	main
darwini	doc_740091151014_item	2844038	et	4	main
nö	doc_740091151014_item	2844049	et	4	main
oodata	doc_740091151014_item	2844059	et	4	main
looduses	doc_740091151014_item	2844067	et	4	main
välja	doc_740091151014_item	2844069	et	4	main
söövad	doc_740091151014_item	2844071	et	4	main
nõrgemaid	doc_740091151014_item	2844072	et	4	main
nii	doc_740091151014_item	2844073	et	3	main
tasakaal	doc_740091151014_item	2844079	et	3	main
tõenäoliselt	doc_740091151014_item	2844084	et	4	main
looduslikus	doc_740091151014_item	2844085	et	4	main
keskkonnas	doc_740091151014_item	2844086	et	3	main
vajalikust	doc_740091151014_item	2844092	et	4	main
viimati	doc_740091151014_item	2844097	et	3	main
saite	doc_740091151014_item	2844102	et	4	main
mõnda	doc_740091151014_item	2844131	et	4	main
inimest	doc_740091151014_item	2844132	et	3	main
lange	doc_740091151014_item	2844137	et	4	main
mõistes	doc_740091151014_item	2844141	et	4	main
igapäevane	doc_740091151014_item	2844143	et	4	main
omavahelist	doc_740091151014_item	2844147	et	4	main
igapäevast	doc_740091151014_item	2844148	et	4	main
no	doc_740091151014_item	2844155	et	3	main
läheb	doc_740091151014_item	2844158	et	3	main
alati	doc_740091151014_item	2844161	et	4	main
vastuseks	doc_740091151014_item	2844163	et	4	main
oli	doc_740091151014_item	2844173	et	3	main
küsid	doc_740091151014_item	2844180	et	3	main
enne	doc_740091151014_item	2844182	et	4	main
eelnevalt	doc_740091151014_item	2844185	et	4	main
loomulikult	doc_740091151014_item	2844187	et	4	main
vingelt	doc_740091151014_item	2844222	et	4	main
vastatud	doc_740091151014_item	2844233	et	4	main
midagi	doc_740091151014_item	2844235	et	4	main
erakordset	doc_740091151014_item	2844236	et	3	main
kindlasti	doc_740091151014_item	2844237	et	3	main
kuuleb	doc_740091151014_item	2844243	et	3	main
päev	doc_740091151014_item	2844245	et	3	main
erakordset	doc_740091151014_item	2844247	et	3	main
ta	doc_740091151014_item	2844249	et	4	main
lõpuks	doc_740091151014_item	2844250	et	4	main
sedagi	doc_740091151014_item	2844251	et	3	main
normaalsust	doc_740091151014_item	2844259	et	4	main
tere	doc_740091151014_item	2844260	et	3	main
end	doc_740091151014_item	2844265	et	4	main
alati	doc_740091151014_item	2844266	et	4	main
arvanud	doc_740091151014_item	2844267	et	4	main
normaalsete	doc_740091151014_item	2844268	et	4	main
lühem	doc_740091151014_item	2844273	et	4	main
kaalun	doc_740091151014_item	2844275	et	3	main
erakonda	doc_740091151014_item	2844288	et	4	main
kah	doc_740091151014_item	2844291	et	3	main
kuid	doc_740091151014_item	2844299	et	4	main
tanel	doc_740091151014_item	2844300	et	4	main
pole	doc_740091151014_item	2844309	et	3	main
kuid	doc_740091151014_item	2844312	et	4	main
kardan	doc_740091151014_item	2844314	et	4	main
muidu	doc_740091151014_item	2844076	et	3	main
hukkuks	doc_740091151014_item	2844087	et	3	main
sellest	doc_740091151014_item	2844091	et	4	main
normist	doc_740091151014_item	2844093	et	4	main
kõrvale	doc_740091151014_item	2844094	et	4	main
millal	doc_740091151014_item	2844095	et	3	main
šoki	doc_740091151014_item	2844104	et	2	main
reaktsiooni	doc_740091151014_item	2844110	et	4	main
inimesed	doc_740091151014_item	2844111	et	3	main
nägu	doc_740091151014_item	2844122	et	4	main
minestusse	doc_740091151014_item	2844135	et	4	main
meie	doc_740091151014_item	2844140	et	4	main
suhtlemist	doc_740091151014_item	2844149	et	4	main
kui	doc_740091151014_item	2844150	et	3	main
käisid	doc_740091151014_item	2844169	et	4	main
jällegi	doc_740091151014_item	2844174	et	4	main
tihti	doc_740091151014_item	2844175	et	3	main
on	doc_740091151014_item	2844176	et	4	main
elukaaslaselt	doc_740091151014_item	2844181	et	3	main
no	doc_740091151014_item	2844191	et	3	main
ma	doc_740091151014_item	2844193	et	3	main
välja	doc_740091151014_item	2844194	et	4	main
näen	doc_740091151014_item	2844195	et	3	main
ikkagi	doc_740091151014_item	2844196	et	4	main
on	doc_740091151014_item	2844197	et	4	main
pahatihti	doc_740091151014_item	2844198	et	3	main
vastuseks	doc_740091151014_item	2844199	et	4	main
seesama	doc_740091151014_item	2844200	et	3	main
normaalne	doc_740091151014_item	2844201	et	3	main
ja	doc_740091151014_item	2844202	et	3	main
paradoksaalsel	doc_740091151014_item	2844203	et	3	main
kombel	doc_740091151014_item	2844204	et	4	main
see	doc_740091151014_item	2844205	et	3	main
vastus	doc_740091151014_item	2844206	et	3	main
ongi	doc_740091151014_item	2844207	et	4	main
normaalne	doc_740091151014_item	2844208	et	3	main
see	doc_740091151014_item	2844209	et	3	main
rahuldab	doc_740091151014_item	2844210	et	3	main
meid	doc_740091151014_item	2844211	et	4	main
ja	doc_740091151014_item	2844212	et	3	main
me	doc_740091151014_item	2844213	et	4	main
ei	doc_740091151014_item	2844214	et	4	main
vajagi	doc_740091151014_item	2844215	et	4	main
midagi	doc_740091151014_item	2844216	et	4	main
enamat	doc_740091151014_item	2844217	et	3	main
kui	doc_740091151014_item	2844218	et	3	main
kooliõpilane	doc_740091151014_item	2844219	et	3	main
vastaks	doc_740091151014_item	2844220	et	3	main
ja	doc_740091151014_item	2844225	et	3	main
ülikõva	doc_740091151014_item	2844224	et	4	main
kõige	doc_740091151014_item	2844228	et	4	main
siis	doc_740091151014_item	2844230	et	3	main
pidama	doc_740091151014_item	2844252	et	4	main
saame	doc_740091151014_item	2844261	et	4	main
ka	doc_740091151014_item	2844262	et	3	main
sutsu	doc_740091151014_item	2844272	et	4	main
rohkem	doc_740091151014_item	2844276	et	4	main
mul	doc_740091151014_item	2844280	et	3	main
kuid	doc_740091151014_item	2844289	et	4	main
salli	doc_740091151014_item	2844293	et	4	main
kordagi	doc_740091151014_item	2844297	et	4	main
käinud	doc_740091151014_item	2844298	et	4	main
rokib	doc_740091151014_item	2844304	et	4	main
täiega	doc_740091151014_item	2844305	et	3	main
mustade	doc_740091151014_item	2844306	et	3	main
nõudepesulappide	doc_740091151014_item	2844307	et	3	main
vastu	doc_740091151014_item	2844308	et	3	main
samuti	doc_740091151014_item	2844317	et	3	main
ei	doc_740091151014_item	2844318	et	4	main
külasta	doc_740091151014_item	2844319	et	4	main
täiesti	doc_740091151014_item	2844320	et	3	main
inimesed	doc_740091151014_item	2844322	et	3	main
meile	doc_740091151014_item	2844232	et	4	main
mitte	doc_740091151014_item	2844238	et	3	main
normaalset	doc_740091151014_item	2844239	et	3	main
ja	doc_740091151014_item	2844240	et	3	main
kõigest	doc_740091151014_item	2844253	et	4	main
mina	doc_740091151014_item	2844263	et	4	main
küll	doc_740091151014_item	2844271	et	4	main
ei	doc_740091151014_item	2844285	et	4	main
ma	doc_740091151014_item	2844296	et	3	main
mul	doc_740091151014_item	2844310	et	3	main
midagi	doc_740091151014_item	2844311	et	4	main
ämblikke	doc_740091151014_item	2844313	et	3	main
psühhiaatrit	doc_740091151014_item	2844316	et	3	main
normaalsed	doc_740091151014_item	2844321	et	3	main
muutunud	doc_740091151017_item	2845139	et	4	main
20	doc_740091151017_item	2845141	et	2	main
kakskümmend	doc_740091151017_item	2845143	et	4	main
jooksul	doc_740091151017_item	2845151	et	4	main
on	doc_740091151017_item	2845152	et	4	main
kui	doc_740091151017_item	2845164	et	3	main
pidevas	doc_740091151017_item	2845169	et	3	main
kõige	doc_740091151017_item	2845176	et	4	main
ka	doc_740091151017_item	2845180	et	3	main
on	doc_740091151017_item	2845184	et	4	main
aastakümnete	doc_740091151017_item	2845186	et	4	main
palju	doc_740091151017_item	2845188	et	4	main
kirjutatud	doc_740091151017_item	2845189	et	4	main
ja	doc_740091151017_item	2845190	et	3	main
võib	doc_740091151017_item	2845191	et	3	main
ka	doc_740091151017_item	2845192	et	3	main
üsna	doc_740091151017_item	2845193	et	3	main
roll	doc_740091151017_item	2845138	et	3	main
aastaga	doc_740091151017_item	2845142	et	3	main
aastat	doc_740091151017_item	2845144	et	3	main
üsna	doc_740091151017_item	2845146	et	3	main
tööelu	doc_740091151017_item	2845156	et	4	main
argielu	doc_740091151017_item	2845158	et	4	main
on	doc_740091151017_item	2845168	et	4	main
uueneb	doc_740091151017_item	2845174	et	3	main
muutume	doc_740091151017_item	2845179	et	4	main
naistest	doc_740091151017_item	2845183	et	4	main
veendunult	doc_740091151017_item	2845194	et	4	main
väita	doc_740091151017_item	2845195	et	4	main
et	doc_740091151017_item	2845196	et	3	main
naiste	doc_740091151017_item	2845197	et	3	main
roll	doc_740091151017_item	2845198	et	3	main
on	doc_740091151017_item	2845199	et	4	main
ajaga	doc_740091151017_item	2845200	et	3	main
palju	doc_740091151017_item	2845201	et	4	main
miks	doc_740091151017_item	2845204	et	4	main
lühike	doc_740091151017_item	2845229	et	4	main
märgata	doc_740091151017_item	2845233	et	4	main
on	doc_740091151017_item	2845236	et	4	main
rolli	doc_740091151017_item	2845244	et	4	main
koju	doc_740091151017_item	2845266	et	3	main
tuli	doc_740091151017_item	2845267	et	4	main
tuli	doc_740091151017_item	2845269	et	4	main
õhtuti	doc_740091151017_item	2845270	et	3	main
käis	doc_740091151017_item	2845301	et	4	main
tööl	doc_740091151017_item	2845302	et	3	main
ja	doc_740091151017_item	2845303	et	3	main
nägema	doc_740091151017_item	2845316	et	3	main
ei	doc_740091151017_item	2845327	et	4	main
teha	doc_740091151017_item	2845337	et	3	main
oli	doc_740091151017_item	2845345	et	3	main
et	doc_740091151017_item	2845352	et	3	main
just	doc_740091151017_item	2845353	et	3	main
kantseldaja	doc_740091151017_item	2845359	et	4	main
ja	doc_740091151017_item	2845360	et	3	main
mees	doc_740091151017_item	2845361	et	4	main
toob	doc_740091151017_item	2845362	et	3	main
paljud	doc_740091151017_item	2845373	et	3	main
ja	doc_740091151017_item	2845377	et	3	main
seda	doc_740091151017_item	2845378	et	3	main
essee	doc_740091151017_item	2845134	et	4	main
on	doc_740091151017_item	2845136	et	4	main
aja	doc_740091151017_item	2845150	et	4	main
meie	doc_740091151017_item	2845155	et	4	main
meie	doc_740091151017_item	2845166	et	4	main
ja	doc_740091151017_item	2845173	et	3	main
me	doc_740091151017_item	2845181	et	4	main
viimaste	doc_740091151017_item	2845185	et	3	main
seda	doc_740091151017_item	2845222	et	3	main
on	doc_740091151017_item	2845225	et	4	main
aastat	doc_740091151017_item	2845227	et	3	main
liiga	doc_740091151017_item	2845228	et	4	main
muutusi	doc_740091151017_item	2845232	et	4	main
näiteks	doc_740091151017_item	2845242	et	4	main
mehe	doc_740091151017_item	2845243	et	3	main
oli	doc_740091151017_item	2845249	et	3	main
laps	doc_740091151017_item	2845256	et	4	main
ka	doc_740091151017_item	2845278	et	3	main
oli	doc_740091151017_item	2845281	et	3	main
emme	doc_740091151017_item	2845282	et	4	main
just	doc_740091151017_item	2845283	et	3	main
pisike	doc_740091151017_item	2845290	et	3	main
haigeks	doc_740091151017_item	2845291	et	4	main
jäänud	doc_740091151017_item	2845293	et	4	main
et	doc_740091151017_item	2845304	et	3	main
olla	doc_740091151017_item	2845308	et	3	main
teinekord	doc_740091151017_item	2845317	et	3	main
eest	doc_740091151017_item	2845320	et	4	main
aja	doc_740091151017_item	2845325	et	4	main
mehed	doc_740091151017_item	2845326	et	3	main
isegi	doc_740091151017_item	2845339	et	4	main
meesterahvas	doc_740091151017_item	2845342	et	4	main
lapsega	doc_740091151017_item	2845343	et	3	main
teema	doc_740091151017_item	2845347	et	4	main
kõik	doc_740091151017_item	2845348	et	4	main
olid	doc_740091151017_item	2845350	et	4	main
harjunud	doc_740091151017_item	2845351	et	4	main
naine	doc_740091151017_item	2845354	et	3	main
naudivad	doc_740091151017_item	2845375	et	3	main
ilma	doc_740091151017_item	2845379	et	4	main
paljud	doc_740091151017_item	2845382	et	3	main
aru	doc_740091151017_item	2845385	et	4	main
kahekümne	doc_740091151017_item	2845423	et	4	main
muutunud	doc_740091151017_item	2845425	et	4	main
juba	doc_740091151017_item	2845430	et	3	main
muutunud	doc_740091151017_item	2845438	et	4	main
tagasi	doc_740091151017_item	2845446	et	3	main
pereelu	doc_740091151017_item	2845461	et	4	main
siis	doc_740091151017_item	2845462	et	3	main
alustatakse	doc_740091151017_item	2845463	et	3	main
ja	doc_740091151017_item	2845480	et	3	main
et	doc_740091151017_item	2845482	et	3	main
luua	doc_740091151017_item	2845484	et	4	main
ei	doc_740091151017_item	2845485	et	4	main
tänapäeval	doc_740091151017_item	2845490	et	3	main
näitabki	doc_740091151017_item	2845499	et	3	main
kooseluks	doc_740091151017_item	2845502	et	3	main
olda	doc_740091151017_item	2845504	et	3	main
või	doc_740091151017_item	2845506	et	4	main
nähakse	doc_740091151017_item	2845507	et	3	main
vaeva	doc_740091151017_item	2845511	et	4	main
on	doc_740091151017_item	2845513	et	4	main
on	doc_740091151017_item	2845145	et	4	main
pikk	doc_740091151017_item	2845147	et	4	main
aeg	doc_740091151017_item	2845148	et	3	main
selle	doc_740091151017_item	2845149	et	4	main
muutunud	doc_740091151017_item	2845153	et	4	main
paljugi	doc_740091151017_item	2845154	et	4	main
meie	doc_740091151017_item	2845157	et	4	main
reisimisvõimalused	doc_740091151017_item	2845160	et	3	main
palju	doc_740091151017_item	2845162	et	4	main
muudki	doc_740091151017_item	2845163	et	4	main
kõik	doc_740091151017_item	2845165	et	4	main
kõik	doc_740091151017_item	2845171	et	4	main
kas	doc_740091151017_item	2845175	et	3	main
koos	doc_740091151017_item	2845178	et	4	main
ise	doc_740091151017_item	2845182	et	4	main
aga	doc_740091151017_item	2845203	et	3	main
või	doc_740091151017_item	2845224	et	4	main
et	doc_740091151017_item	2845231	et	3	main
roll	doc_740091151017_item	2845235	et	3	main
jooksul	doc_740091151017_item	2845238	et	4	main
kindlasti	doc_740091151017_item	2845239	et	3	main
muutunud	doc_740091151017_item	2845240	et	4	main
võtame	doc_740091151017_item	2845241	et	3	main
väike	doc_740091151017_item	2845255	et	4	main
lasteaeda	doc_740091151017_item	2845268	et	4	main
ikka	doc_740091151017_item	2845271	et	4	main
samuti	doc_740091151017_item	2845280	et	3	main
oli	doc_740091151017_item	2845292	et	3	main
miks	doc_740091151017_item	2845295	et	4	main
eks	doc_740091151017_item	2845296	et	3	main
kindlasti	doc_740091151017_item	2845297	et	3	main
sellepärast	doc_740091151017_item	2845298	et	3	main
et	doc_740091151017_item	2845299	et	3	main
perel	doc_740091151017_item	2845305	et	3	main
hea	doc_740091151017_item	2845307	et	4	main
toit	doc_740091151017_item	2845309	et	3	main
ja	doc_740091151017_item	2845311	et	3	main
tundub	doc_740091151017_item	2845322	et	3	main
avatud	doc_740091151017_item	2845330	et	4	main
toimetusi	doc_740091151017_item	2845336	et	4	main
kodus	doc_740091151017_item	2845344	et	4	main
raha	doc_740091151017_item	2845363	et	4	main
koju	doc_740091151017_item	2845364	et	3	main
on	doc_740091151017_item	2845366	et	4	main
aga	doc_740091151017_item	2845368	et	3	main
isad	doc_740091151017_item	2845374	et	3	main
igasuguse	doc_740091151017_item	2845380	et	3	main
mehed	doc_740091151017_item	2845383	et	3	main
saanud	doc_740091151017_item	2845386	et	4	main
kuidas	doc_740091151017_item	2845135	et	3	main
mehe	doc_740091151017_item	2845137	et	3	main
viimase	doc_740091151017_item	2845140	et	3	main
õppimisvõimalused	doc_740091151017_item	2845159	et	3	main
ja	doc_740091151017_item	2845161	et	3	main
ümber	doc_740091151017_item	2845167	et	3	main
muutumises	doc_740091151017_item	2845170	et	4	main
areneb	doc_740091151017_item	2845172	et	3	main
sellega	doc_740091151017_item	2845177	et	3	main
jooksul	doc_740091151017_item	2845187	et	4	main
muutunud	doc_740091151017_item	2845202	et	4	main
me	doc_740091151017_item	2845205	et	4	main
räägime	doc_740091151017_item	2845206	et	3	main
meestest	doc_740091151017_item	2845207	et	4	main
nii	doc_740091151017_item	2845208	et	3	main
vähe	doc_740091151017_item	2845209	et	3	main
kas	doc_740091151017_item	2845210	et	3	main
meeste	doc_740091151017_item	2845211	et	4	main
roll	doc_740091151017_item	2845212	et	3	main
ei	doc_740091151017_item	2845213	et	4	main
ole	doc_740091151017_item	2845214	et	4	main
siis	doc_740091151017_item	2845215	et	3	main
nii	doc_740091151017_item	2845216	et	3	main
oluline	doc_740091151017_item	2845217	et	4	main
muutuv	doc_740091151017_item	2845218	et	4	main
ja	doc_740091151017_item	2845219	et	3	main
põnev	doc_740091151017_item	2845220	et	3	main
et	doc_740091151017_item	2845221	et	3	main
arutada	doc_740091151017_item	2845223	et	3	main
kakskümmend	doc_740091151017_item	2845226	et	4	main
mehe	doc_740091151017_item	2845234	et	3	main
kakskümmend	doc_740091151017_item	2845246	et	4	main
tagasi	doc_740091151017_item	2845248	et	3	main
tavaliselt	doc_740091151017_item	2845250	et	4	main
just	doc_740091151017_item	2845251	et	3	main
see	doc_740091151017_item	2845253	et	3	main
keda	doc_740091151017_item	2845254	et	4	main
oli	doc_740091151017_item	2845257	et	3	main
nägema	doc_740091151017_item	2845259	et	3	main
harjunud	doc_740091151017_item	2845258	et	4	main
enamasti	doc_740091151017_item	2845260	et	4	main
õhtuti	doc_740091151017_item	2845261	et	3	main
siis	doc_740091151017_item	2845262	et	3	main
kui	doc_740091151017_item	2845263	et	3	main
isa	doc_740091151017_item	2845264	et	4	main
töölt	doc_740091151017_item	2845265	et	3	main
aeg	doc_740091151017_item	2845230	et	3	main
aja	doc_740091151017_item	2845237	et	4	main
isana	doc_740091151017_item	2845245	et	3	main
aastat	doc_740091151017_item	2845247	et	3	main
isa	doc_740091151017_item	2845252	et	4	main
pani	doc_740091151017_item	2845276	et	4	main
selga	doc_740091151017_item	2845277	et	4	main
kui	doc_740091151017_item	2845289	et	3	main
aga	doc_740091151017_item	2845294	et	3	main
isa	doc_740091151017_item	2845300	et	4	main
oleks	doc_740091151017_item	2845306	et	3	main
seljas	doc_740091151017_item	2845313	et	4	main
lausa	doc_740091151017_item	2845318	et	4	main
kahe	doc_740091151017_item	2845319	et	3	main
teisalt	doc_740091151017_item	2845321	et	4	main
et	doc_740091151017_item	2845323	et	3	main
olnud	doc_740091151017_item	2845328	et	4	main
igasuguseid	doc_740091151017_item	2845332	et	3	main
nö	doc_740091151017_item	2845334	et	4	main
tabu	doc_740091151017_item	2845346	et	4	main
ju	doc_740091151017_item	2845349	et	3	main
perenaine	doc_740091151017_item	2845356	et	3	main
lastega	doc_740091151017_item	2845358	et	3	main
täna	doc_740091151017_item	2845365	et	4	main
selline	doc_740091151017_item	2845369	et	4	main
olukord	doc_740091151017_item	2845370	et	3	main
kus	doc_740091151017_item	2845371	et	3	main
väga	doc_740091151017_item	2845372	et	3	main
isapuhkust	doc_740091151017_item	2845376	et	4	main
on	doc_740091151017_item	2845384	et	4	main
kindlasti	doc_740091151017_item	2845421	et	3	main
aastaga	doc_740091151017_item	2845424	et	3	main
ainuüksi	doc_740091151017_item	2845431	et	3	main
tundub	doc_740091151017_item	2845440	et	3	main
kui	doc_740091151017_item	2845442	et	3	main
otsustas	doc_740091151017_item	2845447	et	3	main
oli	doc_740091151017_item	2845465	et	3	main
selleks	doc_740091151017_item	2845481	et	4	main
ilmtingimata	doc_740091151017_item	2845488	et	3	main
palju	doc_740091151017_item	2845495	et	4	main
et	doc_740091151017_item	2845501	et	3	main
emme	doc_740091151017_item	2845272	et	4	main
järgi	doc_740091151017_item	2845273	et	4	main
puhtad	doc_740091151017_item	2845274	et	3	main
riided	doc_740091151017_item	2845275	et	3	main
emme	doc_740091151017_item	2845279	et	4	main
see	doc_740091151017_item	2845284	et	3	main
kes	doc_740091151017_item	2845285	et	4	main
lapsekesega	doc_740091151017_item	2845286	et	4	main
koju	doc_740091151017_item	2845287	et	3	main
jäi	doc_740091151017_item	2845288	et	3	main
laual	doc_740091151017_item	2845310	et	3	main
riided	doc_740091151017_item	2845312	et	3	main
pidi	doc_740091151017_item	2845314	et	4	main
vaeva	doc_740091151017_item	2845315	et	4	main
selle	doc_740091151017_item	2845324	et	4	main
nii	doc_740091151017_item	2845329	et	3	main
et	doc_740091151017_item	2845331	et	3	main
tavaliselt	doc_740091151017_item	2845333	et	4	main
naiste	doc_740091151017_item	2845335	et	3	main
võiks	doc_740091151017_item	2845338	et	4	main
väita	doc_740091151017_item	2845340	et	4	main
et	doc_740091151017_item	2845341	et	3	main
on	doc_740091151017_item	2845355	et	4	main
koduhoidja	doc_740091151017_item	2845357	et	4	main
meil	doc_740091151017_item	2845367	et	4	main
et	doc_740091151017_item	2845387	et	3	main
ei	doc_740091151017_item	2845388	et	4	main
pea	doc_740091151017_item	2845389	et	4	main
alati	doc_740091151017_item	2845390	et	4	main
naine	doc_740091151017_item	2845391	et	3	main
olema	doc_740091151017_item	2845392	et	4	main
kodune	doc_740091151017_item	2845393	et	4	main
ka	doc_740091151017_item	2845394	et	3	main
mees	doc_740091151017_item	2845395	et	4	main
võib	doc_740091151017_item	2845396	et	3	main
ja	doc_740091151017_item	2845397	et	3	main
saab	doc_740091151017_item	2845398	et	3	main
kõigega	doc_740091151017_item	2845399	et	3	main
ilusasti	doc_740091151017_item	2845400	et	3	main
hakkama	doc_740091151017_item	2845401	et	3	main
mehed	doc_740091151017_item	2845402	et	3	main
oskavad	doc_740091151017_item	2845403	et	4	main
nautida	doc_740091151017_item	2845404	et	3	main
aega	doc_740091151017_item	2845405	et	4	main
rohkem	doc_740091151017_item	2845406	et	4	main
neile	doc_740091151017_item	2845407	et	4	main
meeldib	doc_740091151017_item	2845408	et	3	main
võtta	doc_740091151017_item	2845409	et	3	main
aeg	doc_740091151017_item	2845410	et	3	main
maha	doc_740091151017_item	2845411	et	4	main
ja	doc_740091151017_item	2845412	et	3	main
tegeleda	doc_740091151017_item	2845413	et	3	main
elu	doc_740091151017_item	2845414	et	4	main
põhiväärtustega	doc_740091151017_item	2845415	et	4	main
iseendaga	doc_740091151017_item	2845416	et	3	main
oma	doc_740091151017_item	2845417	et	4	main
perega	doc_740091151017_item	2845418	et	3	main
oma	doc_740091151017_item	2845419	et	4	main
koduga	doc_740091151017_item	2845420	et	3	main
on	doc_740091151017_item	2845422	et	4	main
roll	doc_740091151017_item	2845428	et	3	main
abikaasana	doc_740091151017_item	2845429	et	3	main
selle	doc_740091151017_item	2845435	et	4	main
tähendus	doc_740091151017_item	2845436	et	4	main
valehäbita	doc_740091151017_item	2845381	et	3	main
mehe	doc_740091151017_item	2845427	et	3	main
mõiste	doc_740091151017_item	2845433	et	4	main
üldiselt	doc_740091151017_item	2845439	et	4	main
aastat	doc_740091151017_item	2845445	et	3	main
abielluda	doc_740091151017_item	2845448	et	3	main
seda	doc_740091151017_item	2845452	et	3	main
et	doc_740091151017_item	2845454	et	3	main
oli	doc_740091151017_item	2845456	et	3	main
osa	doc_740091151017_item	2845467	et	4	main
tänapäeval	doc_740091151017_item	2845468	et	3	main
on	doc_740091151017_item	2845469	et	4	main
koos	doc_740091151017_item	2845479	et	4	main
vaja	doc_740091151017_item	2845487	et	4	main
abielluda	doc_740091151017_item	2845489	et	3	main
valmid	doc_740091151017_item	2845505	et	4	main
vähe	doc_740091151017_item	2845510	et	3	main
mees	doc_740091151017_item	2845517	et	4	main
lausa	doc_740091151017_item	2845527	et	4	main
arvestavad	doc_740091151017_item	2845542	et	4	main
mees	doc_740091151017_item	2845547	et	4	main
teeb	doc_740091151017_item	2845548	et	3	main
süüa	doc_740091151017_item	2845549	et	3	main
aitab	doc_740091151017_item	2845550	et	3	main
aitab	doc_740091151017_item	2845552	et	3	main
on	doc_740091151017_item	2845579	et	4	main
tippjuhtide	doc_740091151017_item	2845583	et	3	main
palju	doc_740091151017_item	2845586	et	4	main
asjalikumaks	doc_740091151017_item	2845594	et	4	main
ja	doc_740091151017_item	2845595	et	3	main
pakuvad	doc_740091151017_item	2845596	et	3	main
igas	doc_740091151017_item	2845599	et	3	main
rahulikuks	doc_740091151017_item	2845612	et	3	main
jäänud	doc_740091151017_item	2845613	et	4	main
ja	doc_740091151017_item	2845614	et	3	main
on	doc_740091151017_item	2845620	et	4	main
selletaoliste	doc_740091151017_item	2845640	et	3	main
naine	doc_740091151017_item	2845642	et	3	main
ettevõtjana	doc_740091151017_item	2845644	et	3	main
sealjuures	doc_740091151017_item	2845653	et	3	main
on	doc_740091151017_item	2845663	et	4	main
kakskümmend	doc_740091151017_item	2845671	et	4	main
pikk	doc_740091151017_item	2845675	et	4	main
et	doc_740091151017_item	2845677	et	3	main
mõista	doc_740091151017_item	2845680	et	4	main
kuidas	doc_740091151017_item	2845681	et	3	main
inimesed	doc_740091151017_item	2845682	et	3	main
on	doc_740091151017_item	2845683	et	4	main
rollid	doc_740091151017_item	2845693	et	3	main
välja	doc_740091151017_item	2845727	et	4	main
näitama	doc_740091151017_item	2845728	et	3	main
kontrolltöö	doc_744799184082_item	2845729	et	4	main
1	doc_744799184082_item	2845730	et	2	main
millised	doc_744799184082_item	2845731	et	3	main
mis	doc_744799184082_item	2845744	et	4	main
iseloomustage	doc_744799184082_item	2845748	et	4	main
nn	doc_744799184082_item	2845751	et	4	main
kultuurielu	doc_744799184082_item	2845753	et	4	main
augustil	doc_744799184082_item	2845762	et	3	main
24	doc_744799184082_item	2845766	et	2	main
valiti	doc_744799184082_item	2845769	et	3	main
valiti	doc_744799184082_item	2845774	et	3	main
ülemnõukogu	doc_744799184082_item	2845776	et	4	main
sõjaväeline	doc_744799184082_item	2845787	et	4	main
riigipööre	doc_744799184082_item	2845788	et	4	main
eestis	doc_744799184082_item	2845794	et	3	main
iseseisvuse	doc_744799184082_item	2845796	et	4	main
ühiskondliku	doc_744799184082_item	2845799	et	3	main
elu	doc_744799184082_item	2845809	et	4	main
ja	doc_744799184082_item	2845810	et	3	main
ja	doc_744799184082_item	2845822	et	3	main
1965	doc_744799184082_item	2845832	et	2	main
a	doc_744799184082_item	2845833	et	4	main
võimuvahetus	doc_744799184082_item	2845834	et	4	main
kremlis	doc_744799184082_item	2845835	et	3	main
partei	doc_744799184082_item	2845840	et	4	main
astumist	doc_744799184082_item	2845846	et	4	main
parteisse	doc_744799184082_item	2845847	et	3	main
segakoolide	doc_744799184082_item	2845849	et	3	main
umbes	doc_744799184082_item	2845856	et	4	main
dissidentlik	doc_744799184082_item	2845858	et	4	main
ka	doc_740091151017_item	2845426	et	3	main
abiellumise	doc_740091151017_item	2845432	et	3	main
ja	doc_740091151017_item	2845434	et	3	main
kakskümmend	doc_740091151017_item	2845444	et	4	main
tegi	doc_740091151017_item	2845450	et	4	main
ta	doc_740091151017_item	2845451	et	4	main
sellepärast	doc_740091151017_item	2845453	et	3	main
traditsioon	doc_740091151017_item	2845455	et	3	main
selline	doc_740091151017_item	2845457	et	4	main
kuidas	doc_740091151017_item	2845458	et	3	main
ikka	doc_740091151017_item	2845459	et	4	main
muidu	doc_740091151017_item	2845460	et	3	main
aga	doc_740091151017_item	2845470	et	3	main
väga	doc_740091151017_item	2845471	et	3	main
loomulik	doc_740091151017_item	2845472	et	3	main
just	doc_740091151017_item	2845473	et	3	main
see	doc_740091151017_item	2845474	et	3	main
et	doc_740091151017_item	2845475	et	3	main
inimesed	doc_740091151017_item	2845476	et	3	main
lihtsalt	doc_740091151017_item	2845477	et	4	main
ole	doc_740091151017_item	2845486	et	4	main
on	doc_740091151017_item	2845491	et	4	main
ju	doc_740091151017_item	2845493	et	3	main
tegelikult	doc_740091151017_item	2845498	et	4	main
selle	doc_740091151017_item	2845508	et	4	main
abikaasana	doc_740091151017_item	2845518	et	3	main
on	doc_740091151017_item	2845520	et	4	main
elukaaslasena	doc_740091151017_item	2845519	et	3	main
oma	doc_740091151017_item	2845521	et	4	main
palju	doc_740091151017_item	2845523	et	4	main
rohkem	doc_740091151017_item	2845524	et	4	main
toeks	doc_740091151017_item	2845525	et	3	main
väita	doc_740091151017_item	2845528	et	4	main
mees	doc_740091151017_item	2845530	et	4	main
ja	doc_740091151017_item	2845531	et	3	main
naine	doc_740091151017_item	2845532	et	3	main
on	doc_740091151017_item	2845533	et	4	main
hoolivamaks	doc_740091151017_item	2845540	et	4	main
ja	doc_740091151017_item	2845541	et	3	main
ei	doc_740091151017_item	2845556	et	4	main
nii	doc_740091151017_item	2845576	et	3	main
rohkem	doc_740091151017_item	2845581	et	4	main
seas	doc_740091151017_item	2845584	et	4	main
näeme	doc_740091151017_item	2845585	et	3	main
julgemaks	doc_740091151017_item	2845593	et	4	main
konkurentsi	doc_740091151017_item	2845601	et	4	main
tundub	doc_740091151017_item	2845603	et	3	main
meeldib	doc_740091151017_item	2845617	et	3	main
et	doc_740091151017_item	2845618	et	3	main
naised	doc_740091151017_item	2845619	et	3	main
aktiivsemad	doc_740091151017_item	2845621	et	4	main
kui	doc_740091151017_item	2845625	et	3	main
naine	doc_740091151017_item	2845626	et	3	main
saab	doc_740091151017_item	2845627	et	3	main
endaga	doc_740091151017_item	2845628	et	4	main
ja	doc_740091151017_item	2845638	et	3	main
probleemidega	doc_740091151017_item	2845641	et	3	main
eduka	doc_740091151017_item	2845643	et	3	main
ise	doc_740091151017_item	2845647	et	4	main
tähtsusest	doc_740091151017_item	2845662	et	4	main
käsi	doc_740091151017_item	2845668	et	4	main
on	doc_740091151017_item	2845673	et	4	main
piisavalt	doc_740091151017_item	2845674	et	4	main
aeg	doc_740091151017_item	2845676	et	3	main
näha	doc_740091151017_item	2845678	et	3	main
meie	doc_740091151017_item	2845686	et	4	main
ümber	doc_740091151017_item	2845687	et	3	main
muutub	doc_740091151017_item	2845688	et	3	main
ja	doc_740091151017_item	2845691	et	3	main
ühiskonnas	doc_740091151017_item	2845694	et	4	main
on	doc_740091151017_item	2845437	et	4	main
et	doc_740091151017_item	2845441	et	3	main
mees	doc_740091151017_item	2845443	et	4	main
siis	doc_740091151017_item	2845449	et	3	main
abielu	doc_740091151017_item	2845464	et	4	main
loomulik	doc_740091151017_item	2845466	et	3	main
elavad	doc_740091151017_item	2845478	et	4	main
pere	doc_740091151017_item	2845483	et	4	main
ka	doc_740091151017_item	2845492	et	3	main
lahutusi	doc_740091151017_item	2845494	et	4	main
rohkem	doc_740091151017_item	2845496	et	4	main
mis	doc_740091151017_item	2845497	et	4	main
seda	doc_740091151017_item	2845500	et	3	main
ei	doc_740091151017_item	2845503	et	4	main
toimimisel	doc_740091151017_item	2845509	et	4	main
üldiselt	doc_740091151017_item	2845512	et	4	main
võiks	doc_740091151017_item	2845526	et	4	main
et	doc_740091151017_item	2845529	et	3	main
muutunud	doc_740091151017_item	2845539	et	4	main
kus	doc_740091151017_item	2845546	et	3	main
tegemisel	doc_740091151017_item	2845555	et	4	main
ole	doc_740091151017_item	2845557	et	4	main
nad	doc_740091151017_item	2845575	et	3	main
enam	doc_740091151017_item	2845587	et	4	main
naiste	doc_740091151017_item	2845588	et	3	main
nimesid	doc_740091151017_item	2845589	et	3	main
naised	doc_740091151017_item	2845590	et	3	main
pea	doc_740091151017_item	2845598	et	4	main
et	doc_740091151017_item	2845604	et	3	main
muutumisprotsessi	doc_740091151017_item	2845607	et	4	main
ise	doc_740091151017_item	2845629	et	4	main
hakkama	doc_740091151017_item	2845630	et	3	main
naine	doc_740091151017_item	2845631	et	3	main
roolis	doc_740091151017_item	2845632	et	4	main
naine	doc_740091151017_item	2845633	et	3	main
tegeleb	doc_740091151017_item	2845634	et	3	main
oma	doc_740091151017_item	2845635	et	4	main
autoliisingu	doc_740091151017_item	2845636	et	3	main
on	doc_740091151017_item	2845652	et	4	main
mõistva	doc_740091151017_item	2845656	et	4	main
abikaasana	doc_740091151017_item	2845657	et	3	main
aru	doc_740091151017_item	2845660	et	4	main
kodu	doc_740091151017_item	2845661	et	4	main
abistav	doc_740091151017_item	2845667	et	4	main
oma	doc_740091151017_item	2845669	et	4	main
mehele	doc_740091151017_item	2845670	et	3	main
ja	doc_740091151017_item	2845679	et	3	main
pidevalt	doc_740091151017_item	2845689	et	4	main
naiste	doc_740091151017_item	2845690	et	3	main
naised	doc_740091151017_item	2845722	et	3	main
seda	doc_740091151017_item	2845724	et	3	main
võimalikuks	doc_744799184082_item	2845735	et	3	main
1990	doc_744799184082_item	2845738	et	2	main
aastatel	doc_744799184082_item	2845739	et	4	main
2	doc_744799184082_item	2845740	et	2	main
eestlased	doc_744799184082_item	2845741	et	3	main
lühidalt	doc_744799184082_item	2845749	et	4	main
mida	doc_744799184082_item	2845755	et	4	main
kujutas	doc_744799184082_item	2845756	et	3	main
40	doc_744799184082_item	2845758	et	2	main
kiri	doc_744799184082_item	2845759	et	3	main
23	doc_744799184082_item	2845761	et	2	main
märtsil	doc_744799184082_item	2845773	et	3	main
1991	doc_744799184082_item	2845793	et	2	main
tahtsid	doc_744799184082_item	2845807	et	4	main
näha	doc_740091151017_item	2845514	et	3	main
et	doc_740091151017_item	2845515	et	3	main
tänapäeva	doc_740091151017_item	2845516	et	4	main
kodustes	doc_740091151017_item	2845534	et	4	main
rohkem	doc_740091151017_item	2845544	et	4	main
lapsi	doc_740091151017_item	2845553	et	4	main
kodutööde	doc_740091151017_item	2845554	et	3	main
enam	doc_740091151017_item	2845558	et	4	main
võõras	doc_740091151017_item	2845559	et	4	main
domineerivad	doc_740091151017_item	2845577	et	4	main
palju	doc_740091151017_item	2845580	et	4	main
naisi	doc_740091151017_item	2845582	et	3	main
on	doc_740091151017_item	2845591	et	4	main
muutunud	doc_740091151017_item	2845592	et	4	main
eluvaldkonnas	doc_740091151017_item	2845600	et	4	main
samas	doc_740091151017_item	2845602	et	4	main
selle	doc_740091151017_item	2845606	et	4	main
neile	doc_740091151017_item	2845615	et	4	main
lausa	doc_740091151017_item	2845616	et	4	main
mees	doc_740091151017_item	2845622	et	4	main
on	doc_740091151017_item	2845623	et	4	main
õnnelik	doc_740091151017_item	2845624	et	3	main
remondi	doc_740091151017_item	2845637	et	4	main
naine	doc_740091151017_item	2845645	et	3	main
oma	doc_740091151017_item	2845649	et	4	main
edukas	doc_740091151017_item	2845654	et	4	main
naine	doc_740091151017_item	2845655	et	3	main
saab	doc_740091151017_item	2845659	et	3	main
aastat	doc_740091151017_item	2845672	et	3	main
muutunud	doc_740091151017_item	2845684	et	4	main
väljaspool	doc_744799184082_item	2845742	et	3	main
kus	doc_744799184082_item	2845747	et	3	main
väliseesti	doc_744799184082_item	2845752	et	4	main
endast	doc_744799184082_item	2845757	et	4	main
1	doc_744799184082_item	2845760	et	2	main
baltui	doc_744799184082_item	2845764	et	4	main
1990	doc_744799184082_item	2845768	et	2	main
oli	doc_744799184082_item	2845778	et	3	main
1991	doc_744799184082_item	2845781	et	2	main
liidus	doc_744799184082_item	2845790	et	4	main
20	doc_744799184082_item	2845791	et	2	main
taastati	doc_744799184082_item	2845795	et	4	main
elu	doc_744799184082_item	2845800	et	4	main
ja	doc_744799184082_item	2845801	et	3	main
said	doc_744799184082_item	2845802	et	4	main
võimalikuks	doc_744799184082_item	2845803	et	3	main
kontaktid	doc_744799184082_item	2845804	et	3	main
väliseestlastega	doc_744799184082_item	2845805	et	4	main
inimesed	doc_744799184082_item	2845806	et	3	main
suured	doc_744799184082_item	2845824	et	3	main
sotsiaalses	doc_744799184082_item	2845826	et	3	main
ja	doc_744799184082_item	2845828	et	3	main
rahvuslikus	doc_744799184082_item	2845830	et	4	main
juhiks	doc_744799184082_item	2845837	et	4	main
leonid	doc_744799184082_item	2845838	et	4	main
breznev	doc_744799184082_item	2845839	et	4	main
ka	doc_744799184082_item	2845844	et	3	main
ning	doc_744799184082_item	2845848	et	3	main
suurendamine	doc_744799184082_item	2845850	et	4	main
eestis	doc_744799184082_item	2845853	et	3	main
osakaal	doc_744799184082_item	2845855	et	3	main
liidu	doc_744799184082_item	2845865	et	3	main
katse	doc_744799184082_item	2845869	et	4	main
üle	doc_744799184082_item	2845870	et	3	main
minna	doc_744799184082_item	2845871	et	3	main
ekstensiivarengult	doc_744799184082_item	2845872	et	3	main
intensiivarengule	doc_744799184082_item	2845873	et	3	main
ka	doc_744799184082_item	2845875	et	3	main
inimeste	doc_744799184082_item	2845878	et	3	main
tarbimine	doc_744799184082_item	2845886	et	4	main
avalik	doc_744799184082_item	2845892	et	3	main
haritlast	doc_744799184082_item	2845900	et	3	main
bürokraatile	doc_744799184082_item	2845921	et	4	main
dokument	doc_744962874519_item	2845923	et	3	main
v	doc_744962874519_item	2845925	et	4	main
äga	doc_744962874519_item	2845926	et	4	main
mõjutab	doc_744962874519_item	2845927	et	3	main
inimese	doc_744962874519_item	2845928	et	4	main
teadmised	doc_744962874519_item	2845937	et	4	main
tal	doc_744962874519_item	2845938	et	3	main
span	doc_744962874519_item	2845943	et	4	main
naisele	doc_740091151017_item	2845522	et	3	main
toimetustes	doc_740091151017_item	2845535	et	4	main
võrdsed	doc_740091151017_item	2845536	et	3	main
mehed	doc_740091151017_item	2845537	et	3	main
on	doc_740091151017_item	2845538	et	4	main
naistega	doc_740091151017_item	2845543	et	3	main
olukord	doc_740091151017_item	2845545	et	3	main
majapidamistöödega	doc_740091151017_item	2845551	et	4	main
pigem	doc_740091151017_item	2845560	et	3	main
lausa	doc_740091151017_item	2845561	et	4	main
tavaline	doc_740091151017_item	2845562	et	4	main
meeste	doc_740091151017_item	2845563	et	4	main
roll	doc_740091151017_item	2845564	et	3	main
on	doc_740091151017_item	2845565	et	4	main
muutunud	doc_740091151017_item	2845566	et	4	main
ka	doc_740091151017_item	2845567	et	3	main
kindlasti	doc_740091151017_item	2845568	et	3	main
osas	doc_740091151017_item	2845570	et	4	main
et	doc_740091151017_item	2845571	et	3	main
enam	doc_740091151017_item	2845572	et	4	main
selles	doc_740091151017_item	2845569	et	4	main
ei	doc_740091151017_item	2845573	et	4	main
ole	doc_740091151017_item	2845574	et	4	main
poliitikas	doc_740091151017_item	2845578	et	3	main
meestele	doc_740091151017_item	2845597	et	4	main
kogu	doc_740091151017_item	2845605	et	4	main
juures	doc_740091151017_item	2845608	et	4	main
on	doc_740091151017_item	2845609	et	4	main
mehed	doc_740091151017_item	2845610	et	3	main
täitsa	doc_740091151017_item	2845611	et	3	main
muude	doc_740091151017_item	2845639	et	4	main
saab	doc_740091151017_item	2845646	et	3	main
hakkama	doc_740091151017_item	2845648	et	3	main
äriasjadega	doc_740091151017_item	2845650	et	3	main
ja	doc_740091151017_item	2845651	et	3	main
naine	doc_740091151017_item	2845658	et	3	main
toetav	doc_740091151017_item	2845664	et	4	main
kaasa	doc_740091151017_item	2845665	et	4	main
ja	doc_740091151017_item	2845666	et	3	main
elu	doc_740091151017_item	2845685	et	4	main
meeste	doc_740091151017_item	2845692	et	4	main
oleks	doc_740091151017_item	2845696	et	3	main
väga	doc_740091151017_item	2845697	et	3	main
tore	doc_740091151017_item	2845698	et	3	main
näha	doc_740091151017_item	2845699	et	3	main
kuulda	doc_740091151017_item	2845700	et	4	main
ja	doc_740091151017_item	2845701	et	3	main
lugeda	doc_740091151017_item	2845702	et	3	main
just	doc_740091151017_item	2845703	et	3	main
meeste	doc_740091151017_item	2845704	et	4	main
samuti	doc_740091151017_item	2845695	et	3	main
rollist	doc_740091151017_item	2845705	et	4	main
pisut	doc_740091151017_item	2845706	et	3	main
rohkem	doc_740091151017_item	2845707	et	4	main
seda	doc_740091151017_item	2845708	et	3	main
nii	doc_740091151017_item	2845709	et	3	main
meeste	doc_740091151017_item	2845710	et	4	main
vaatevinklist	doc_740091151017_item	2845711	et	4	main
kui	doc_740091151017_item	2845712	et	3	main
ka	doc_740091151017_item	2845713	et	3	main
naiste	doc_740091151017_item	2845714	et	3	main
omast	doc_740091151017_item	2845715	et	4	main
mehed	doc_740091151017_item	2845716	et	3	main
väärivad	doc_740091151017_item	2845717	et	4	main
samuti	doc_740091151017_item	2845718	et	3	main
tunnustamist	doc_740091151017_item	2845719	et	4	main
ja	doc_740091151017_item	2845720	et	3	main
kultuurilis-poliitilised	doc_744799184082_item	2845732	et	3	main
tegurid	doc_744799184082_item	2845733	et	3	main
eesti	doc_744799184082_item	2845736	et	4	main
taasiseseisvumise	doc_744799184082_item	2845737	et	3	main
põhjustel	doc_744799184082_item	2845745	et	3	main
ja	doc_744799184082_item	2845746	et	3	main
1989	doc_744799184082_item	2845763	et	2	main
kett	doc_744799184082_item	2845765	et	4	main
veebruaril	doc_744799184082_item	2845767	et	3	main
eesti	doc_744799184082_item	2845770	et	4	main
kongressi	doc_744799184082_item	2845771	et	4	main
16	doc_744799184082_item	2845772	et	2	main
ensv	doc_744799184082_item	2845775	et	4	main
majandusblokaad	doc_744799184082_item	2845779	et	3	main
l	doc_744799184082_item	2845782	et	4	main
nsv	doc_744799184082_item	2845789	et	4	main
küberneetika	doc_744799184082_item	2845821	et	4	main
rahvastiku	doc_744799184082_item	2845829	et	3	main
koosseisus	doc_744799184082_item	2845831	et	4	main
meie	doc_740091151017_item	2845721	et	4	main
peaksime	doc_740091151017_item	2845723	et	4	main
palju	doc_740091151017_item	2845725	et	4	main
rohkem	doc_740091151017_item	2845726	et	4	main
tegid	doc_744799184082_item	2845734	et	4	main
kodumaad	doc_744799184082_item	2845743	et	4	main
ka	doc_744799184082_item	2845750	et	3	main
3	doc_744799184082_item	2845754	et	2	main
märtsis	doc_744799184082_item	2845777	et	3	main
maksureform	doc_744799184082_item	2845780	et	3	main
sai	doc_744799184082_item	2845783	et	4	main
jeltsin	doc_744799184082_item	2845784	et	4	main
presidendiks	doc_744799184082_item	2845785	et	4	main
1991	doc_744799184082_item	2845786	et	2	main
augustil	doc_744799184082_item	2845792	et	3	main
2	doc_744799184082_item	2845797	et	2	main
laienes	doc_744799184082_item	2845798	et	3	main
paremat	doc_744799184082_item	2845808	et	4	main
sellepärast	doc_744799184082_item	2845811	et	3	main
paljud	doc_744799184082_item	2845812	et	3	main
tahtsid	doc_744799184082_item	2845813	et	4	main
välismaale	doc_744799184082_item	2845814	et	4	main
minna	doc_744799184082_item	2845815	et	3	main
kõige	doc_744799184082_item	2845816	et	4	main
moodsamaid	doc_744799184082_item	2845817	et	4	main
teadusharud	doc_744799184082_item	2845818	et	3	main
olid	doc_744799184082_item	2845819	et	4	main
psühholoogia	doc_744799184082_item	2845820	et	4	main
sotsioloogia	doc_744799184082_item	2845823	et	4	main
nlkp	doc_744799184082_item	2845836	et	4	main
liikmeskonna	doc_744799184082_item	2845841	et	4	main
intelligentsi	doc_744799184082_item	2845845	et	4	main
1989	doc_744799184082_item	2845851	et	2	main
62	doc_744799184082_item	2845857	et	2	main
nsv	doc_744799184082_item	2845864	et	4	main
majanduskriis	doc_744799184082_item	2845866	et	3	main
ka	doc_744799184082_item	2845868	et	3	main
halvenes	doc_744799184082_item	2845874	et	3	main
oli	doc_744799184082_item	2845880	et	3	main
kahepalgaline	doc_744799184082_item	2845881	et	4	main
elustiil	doc_744799184082_item	2845882	et	4	main
3	doc_744799184082_item	2845887	et	2	main
kaitseks	doc_744799184082_item	2845889	et	4	main
kiri	doc_744799184082_item	2845891	et	3	main
eesti	doc_744799184082_item	2845894	et	4	main
kirjutasid	doc_744799184082_item	2845896	et	4	main
40	doc_744799184082_item	2845898	et	2	main
kirjas	doc_744799184082_item	2845907	et	4	main
päärati	doc_744799184082_item	2845908	et	4	main
uus	doc_744962874519_item	2845922	et	3	main
1	doc_744962874519_item	2845924	et	2	main
ole	doc_744962874519_item	2845948	et	4	main
hästi	doc_744962874519_item	2845955	et	3	main
span	doc_744962874519_item	2845956	et	4	main
on	doc_744962874519_item	2845960	et	4	main
ise	doc_744962874519_item	2845986	et	4	main
inimene	doc_744962874519_item	2845987	et	3	main
sõbrad	doc_744962874519_item	2845991	et	3	main
muutused	doc_744799184082_item	2845825	et	4	main
struktuuris	doc_744799184082_item	2845827	et	3	main
kihistumine	doc_744799184082_item	2845842	et	4	main
süvenes	doc_744799184082_item	2845860	et	3	main
lääneriikidest	doc_744799184082_item	2845863	et	3	main
ebaõnnestus	doc_744799184082_item	2845867	et	4	main
suhtumine	doc_744799184082_item	2845877	et	4	main
alkoholi	doc_744799184082_item	2845885	et	4	main
rahvuskultuuri	doc_744799184082_item	2845888	et	4	main
40	doc_744799184082_item	2845890	et	2	main
kiri	doc_744799184082_item	2845893	et	3	main
nsv-st	doc_744799184082_item	2845895	et	3	main
selle	doc_744799184082_item	2845906	et	4	main
eesti	doc_744799184082_item	2845913	et	4	main
oli	doc_744799184082_item	2845918	et	3	main
halb	doc_744799184082_item	2845919	et	3	main
partei	doc_744799184082_item	2845920	et	4	main
ei	doc_744962874519_item	2845939	et	4	main
ei	doc_744962874519_item	2845947	et	4	main
või	doc_744962874519_item	2845953	et	4	main
elada	doc_744962874519_item	2845954	et	3	main
iseloom	doc_744962874519_item	2845963	et	3	main
segab	doc_744962874519_item	2845965	et	3	main
mõjutab	doc_744962874519_item	2845974	et	3	main
kui	doc_744962874519_item	2845989	et	3	main
tähtis	doc_744962874522_item	2846262	et	4	main
sest	doc_744962874522_item	2846263	et	4	main
haridus	doc_744962874522_item	2846276	et	3	main
tähtis	doc_744962874522_item	2846278	et	4	main
töökoht	doc_744962874522_item	2846285	et	3	main
raha	doc_744962874522_item	2846328	et	4	main
on	doc_744962874522_item	2846329	et	4	main
väga	doc_744962874522_item	2846330	et	3	main
annavad	doc_744962874522_item	2846338	et	3	main
vähem	doc_744962874522_item	2846348	et	4	main
võimalused	doc_744962874522_item	2846352	et	3	main
takistati	doc_744799184082_item	2845843	et	3	main
migratsioon	doc_744799184082_item	2845852	et	3	main
põlisrahvuse	doc_744799184082_item	2845854	et	3	main
tehniline	doc_744799184082_item	2845861	et	3	main
töösse	doc_744799184082_item	2845876	et	3	main
poolt	doc_744799184082_item	2845879	et	4	main
alla	doc_744799184082_item	2845897	et	3	main
tuntud	doc_744799184082_item	2845899	et	4	main
selle	doc_744799184082_item	2845901	et	4	main
kirja	doc_744799184082_item	2845902	et	4	main
saadeti	doc_744799184082_item	2845903	et	3	main
ka	doc_744799184082_item	2845904	et	3	main
ahistamisele	doc_744799184082_item	2845915	et	4	main
elu	doc_744962874519_item	2845929	et	4	main
haridus	doc_744962874519_item	2845930	et	3	main
sellepärast	doc_744962874519_item	2845931	et	3	main
kui	doc_744962874519_item	2845932	et	3	main
inimesel	doc_744962874519_item	2845933	et	3	main
ei	doc_744962874519_item	2845934	et	4	main
ole	doc_744962874519_item	2845935	et	4	main
hea	doc_744962874519_item	2845936	et	4	main
tööd	doc_744962874519_item	2845942	et	4	main
siis	doc_744962874519_item	2845950	et	3	main
ta	doc_744962874519_item	2845951	et	4	main
paljude	doc_744962874519_item	2845958	et	3	main
väga	doc_744962874519_item	2845961	et	3	main
mis	doc_744962874519_item	2845964	et	4	main
temal	doc_744962874519_item	2845966	et	3	main
elu	doc_744962874519_item	2845976	et	4	main
on	doc_744962874519_item	2845981	et	4	main
ja	doc_744962874519_item	2845983	et	3	main
vastutavad	doc_744962874519_item	2845984	et	4	main
siis	doc_744962874519_item	2845985	et	3	main
tema	doc_744962874519_item	2845990	et	4	main
liikumine	doc_744799184082_item	2845859	et	4	main
mahajäämus	doc_744799184082_item	2845862	et	3	main
suurenes	doc_744799184082_item	2845883	et	4	main
ka	doc_744799184082_item	2845884	et	3	main
pravdale	doc_744799184082_item	2845905	et	4	main
tähelepanu	doc_744799184082_item	2845909	et	4	main
rahvussuhete	doc_744799184082_item	2845910	et	3	main
pingestumisele	doc_744799184082_item	2845911	et	4	main
ja	doc_744799184082_item	2845912	et	3	main
keele	doc_744799184082_item	2845914	et	4	main
ja	doc_744799184082_item	2845916	et	3	main
see	doc_744799184082_item	2845917	et	3	main
ole	doc_744962874519_item	2845940	et	4	main
hea	doc_744962874519_item	2845941	et	4	main
raha	doc_744962874519_item	2845949	et	4	main
3	doc_744962874519_item	2845957	et	2	main
span	doc_744962874519_item	2845970	et	4	main
4	doc_744962874519_item	2845971	et	2	main
ka	doc_744962874519_item	2845972	et	3	main
väga	doc_744962874519_item	2845973	et	3	main
inimese	doc_744962874519_item	2845975	et	4	main
sõbrad	doc_744962874519_item	2845978	et	3	main
on	doc_744962874519_item	2845988	et	4	main
span	doc_744962874519_item	2845992	et	4	main
5	doc_744962874519_item	2845993	et	2	main
palju	doc_744962874519_item	2845994	et	4	main
inimesed	doc_744962874519_item	2845995	et	3	main
elavad	doc_744962874519_item	2845996	et	4	main
vanematega	doc_744962874519_item	2845997	et	4	main
kes	doc_744962874519_item	2845998	et	4	main
ei	doc_744962874519_item	2845999	et	4	main
lubanud	doc_744962874519_item	2846000	et	4	main
ja	doc_744962874519_item	2846001	et	3	main
kontrollida	doc_744962874519_item	2846002	et	4	main
nende	doc_744962874519_item	2846003	et	4	main
tegevused	doc_744962874519_item	2846004	et	4	main
span	doc_744962874519_item	2846005	et	4	main
2	doc_744962874519_item	2845944	et	2	main
kui	doc_744962874519_item	2845945	et	3	main
inimesel	doc_744962874519_item	2845946	et	3	main
ei	doc_744962874519_item	2845952	et	4	main
inimestel	doc_744962874519_item	2845959	et	3	main
raske	doc_744962874519_item	2845962	et	4	main
suhelda	doc_744962874519_item	2845967	et	4	main
teiste	doc_744962874519_item	2845968	et	4	main
inimestega	doc_744962874519_item	2845969	et	3	main
tema	doc_744962874519_item	2845977	et	4	main
kui	doc_744962874519_item	2845979	et	3	main
sõbrad	doc_744962874519_item	2845980	et	3	main
head	doc_744962874519_item	2845982	et	4	main
rohkem	doc_744962874522_item	2846258	et	4	main
on	doc_744962874522_item	2846260	et	4	main
väga	doc_744962874522_item	2846261	et	3	main
elu	doc_744962874522_item	2846267	et	4	main
kindel	doc_744962874522_item	2846274	et	3	main
on	doc_744962874522_item	2846277	et	4	main
sest	doc_744962874522_item	2846279	et	4	main
haridust	doc_744962874522_item	2846280	et	4	main
sõltub	doc_744962874522_item	2846281	et	3	main
sinu	doc_744962874522_item	2846282	et	3	main
tulemus	doc_744962874522_item	2846283	et	3	main
heaolu	doc_744962874522_item	2846287	et	4	main
on	doc_744962874522_item	2846289	et	4	main
või	doc_744962874522_item	2846323	et	4	main
arvates	doc_744962874522_item	2846326	et	4	main
et	doc_744962874522_item	2846327	et	3	main
raha	doc_744962874522_item	2846334	et	4	main
see	doc_744962874522_item	2846335	et	3	main
elus	doc_744962874522_item	2846347	et	4	main
suurem	doc_744962874522_item	2846351	et	4	main
uus	doc_744962874524_item	2846499	et	3	main
ma	doc_744962874524_item	2846501	et	3	main
elu	doc_744962874522_item	2846256	et	4	main
vanemad	doc_744962874522_item	2846264	et	4	main
sinu	doc_744962874522_item	2846265	et	3	main
annavad	doc_744962874522_item	2846266	et	3	main
et	doc_744962874522_item	2846275	et	3	main
on	doc_744962874522_item	2846336	et	4	main
praegu	doc_744962874522_item	2846337	et	3	main
võimalus	doc_744962874522_item	2846339	et	3	main
hästi	doc_744962874522_item	2846340	et	3	main
elama	doc_744962874522_item	2846341	et	3	main
millal	doc_744962874522_item	2846342	et	3	main
raha	doc_744962874522_item	2846343	et	4	main
probleemi	doc_744962874522_item	2846349	et	4	main
arvan	doc_744962874524_item	2846502	et	3	main
haridus	doc_744962874524_item	2846513	et	3	main
sõbrad	doc_744962874524_item	2846514	et	3	main
raha	doc_744962874524_item	2846518	et	4	main
ma	doc_744962874524_item	2846519	et	3	main
essee	doc_744962874522_item	2846252	et	4	main
kõige	doc_744962874522_item	2846257	et	4	main
nad	doc_744962874522_item	2846268	et	3	main
sind	doc_744962874522_item	2846270	et	4	main
olen	doc_744962874522_item	2846273	et	3	main
sinu	doc_744962874522_item	2846284	et	3	main
sõbrad	doc_744962874522_item	2846288	et	3	main
anda	doc_744962874522_item	2846321	et	3	main
on	doc_744962874522_item	2846344	et	4	main
siis	doc_744962874522_item	2846350	et	3	main
mis	doc_744962874522_item	2846253	et	4	main
mõjutab	doc_744962874522_item	2846254	et	3	main
inimese	doc_744962874522_item	2846255	et	4	main
vanemad	doc_744962874522_item	2846259	et	4	main
teavad	doc_744962874522_item	2846269	et	3	main
inimeseks	doc_744962874522_item	2846271	et	3	main
ma	doc_744962874522_item	2846272	et	3	main
sinu	doc_744962874522_item	2846286	et	3	main
tähtis	doc_744962874522_item	2846290	et	4	main
sest	doc_744962874522_item	2846291	et	4	main
nad	doc_744962874522_item	2846292	et	3	main
aitavad	doc_744962874522_item	2846293	et	4	main
elus	doc_744962874522_item	2846294	et	4	main
see	doc_744962874522_item	2846295	et	3	main
inimesed	doc_744962874522_item	2846296	et	3	main
kellele	doc_744962874522_item	2846297	et	4	main
sa	doc_744962874522_item	2846298	et	3	main
võib	doc_744962874522_item	2846299	et	3	main
usuta	doc_744962874522_item	2846300	et	4	main
nad	doc_744962874522_item	2846301	et	3	main
sinu	doc_744962874522_item	2846302	et	3	main
tõstab	doc_744962874522_item	2846303	et	3	main
tuju	doc_744962874522_item	2846304	et	4	main
nad	doc_744962874522_item	2846305	et	3	main
sinu	doc_744962874522_item	2846306	et	3	main
armastavad	doc_744962874522_item	2846307	et	4	main
mulle	doc_744962874522_item	2846308	et	4	main
tundub	doc_744962874522_item	2846309	et	3	main
et	doc_744962874522_item	2846310	et	3	main
juhus	doc_744962874522_item	2846311	et	4	main
on	doc_744962874522_item	2846312	et	4	main
tähtis	doc_744962874522_item	2846313	et	4	main
sest	doc_744962874522_item	2846314	et	4	main
et	doc_744962874522_item	2846315	et	3	main
juhus	doc_744962874522_item	2846316	et	4	main
võib	doc_744962874522_item	2846317	et	3	main
muutuda	doc_744962874522_item	2846318	et	3	main
sinu	doc_744962874522_item	2846319	et	3	main
elu	doc_744962874522_item	2846320	et	4	main
õnnestus	doc_744962874522_item	2846322	et	4	main
mure	doc_744962874522_item	2846324	et	4	main
minu	doc_744962874522_item	2846325	et	3	main
tähtis	doc_744962874522_item	2846331	et	4	main
sest	doc_744962874522_item	2846332	et	4	main
et	doc_744962874522_item	2846333	et	3	main
palju	doc_744962874522_item	2846345	et	4	main
siis	doc_744962874522_item	2846346	et	3	main
huvitava	doc_744962874522_item	2846353	et	4	main
puhata	doc_744962874522_item	2846354	et	4	main
dokument	doc_744962874524_item	2846500	et	3	main
inimese	doc_744962874524_item	2846504	et	4	main
elu	doc_744962874524_item	2846505	et	4	main
paljud	doc_744962874524_item	2846507	et	3	main
tegureid	doc_744962874524_item	2846508	et	4	main
see	doc_744962874524_item	2846509	et	3	main
inimesed	doc_744962874524_item	2846528	et	3	main
hariduseta	doc_744962874524_item	2846530	et	3	main
tööd	doc_744962874524_item	2846536	et	4	main
kõike	doc_744962874524_item	2846545	et	4	main
on	doc_744962874524_item	2846556	et	4	main
mõjutavad	doc_744962874524_item	2846562	et	4	main
ka	doc_744962874524_item	2846563	et	3	main
see	doc_744962874524_item	2846570	et	3	main
ei	doc_744962874524_item	2846573	et	4	main
elus	doc_744962874524_item	2846581	et	4	main
väga	doc_744962874524_item	2846582	et	3	main
ma	doc_744962874524_item	2846585	et	3	main
veel	doc_744962874524_item	2846588	et	4	main
vanemad	doc_744962874524_item	2846589	et	4	main
1	doc_744962874525_item	2846601	et	2	main
väga	doc_744962874525_item	2846608	et	3	main
see	doc_744962874525_item	2846612	et	3	main
väga	doc_744962874525_item	2846624	et	3	main
et	doc_744962874524_item	2846503	et	3	main
et	doc_744962874524_item	2846521	et	3	main
on	doc_744962874524_item	2846524	et	4	main
haridus	doc_744962874524_item	2846525	et	3	main
sest	doc_744962874524_item	2846526	et	4	main
saa	doc_744962874524_item	2846532	et	4	main
leida	doc_744962874524_item	2846533	et	3	main
endale	doc_744962874524_item	2846534	et	4	main
ka	doc_744962874524_item	2846539	et	3	main
väga	doc_744962874524_item	2846540	et	3	main
tähtis	doc_744962874524_item	2846541	et	4	main
ja	doc_744962874524_item	2846550	et	3	main
kõik	doc_744962874524_item	2846551	et	4	main
raha	doc_744962874524_item	2846557	et	4	main
rohkem	doc_744962874524_item	2846558	et	4	main
võimalusi	doc_744962874524_item	2846559	et	3	main
ma	doc_744962874524_item	2846565	et	3	main
reeda	doc_744962874524_item	2846574	et	4	main
aitavad	doc_744962874524_item	2846590	et	4	main
mina	doc_744962874525_item	2846602	et	4	main
iseloom	doc_744962874525_item	2846606	et	3	main
on	doc_744962874525_item	2846623	et	4	main
ja	doc_744962874525_item	2846631	et	3	main
tähtis	doc_744962874525_item	2846640	et	4	main
vanemad	doc_744962874525_item	2846650	et	4	main
sest	doc_744962874525_item	2846654	et	4	main
nad	doc_744962874525_item	2846655	et	3	main
tähtis	doc_744962874526_item	2846664	et	4	main
väga	doc_744962874526_item	2846671	et	3	main
raha	doc_744962874526_item	2846674	et	4	main
annab	doc_744962874526_item	2846675	et	3	main
mulle	doc_744962874526_item	2846676	et	4	main
võim	doc_744962874526_item	2846677	et	3	main
haridus	doc_744962874526_item	2846678	et	3	main
meid	doc_744962874526_item	2846685	et	4	main
saad	doc_744962874527_item	2846730	et	4	main
leida	doc_744962874527_item	2846731	et	3	main
ja	doc_744962874527_item	2846740	et	3	main
inimestega	doc_744962874527_item	2846760	et	3	main
elus	doc_744962874527_item	2846767	et	4	main
kui	doc_744962874527_item	2846768	et	3	main
ja	doc_744962874527_item	2846787	et	3	main
uus	doc_744962874529_item	2846839	et	3	main
sest	doc_744962874529_item	2846843	et	4	main
õppivad	doc_744962874529_item	2846845	et	4	main
ja	doc_744962874529_item	2846847	et	3	main
rahad	doc_744962874529_item	2846852	et	4	main
on	doc_744962874529_item	2846853	et	4	main
väga	doc_744962874529_item	2846854	et	3	main
tähtis	doc_744962874529_item	2846855	et	4	main
kuna	doc_744962874529_item	2846856	et	3	main
rahata	doc_744962874529_item	2846857	et	4	main
inimese	doc_744962874530_item	2846884	et	4	main
rohkem	doc_744962874530_item	2846887	et	4	main
mõjutab	doc_744962874530_item	2846888	et	3	main
raha	doc_744962874530_item	2846892	et	4	main
ja	doc_744962874530_item	2846893	et	3	main
ma	doc_744962874530_item	2846895	et	3	main
hea	doc_744962874530_item	2846902	et	4	main
töö	doc_744962874530_item	2846906	et	4	main
ja	doc_744962874530_item	2846907	et	3	main
et	doc_744962874530_item	2846917	et	3	main
inimene	doc_744962874530_item	2846918	et	3	main
peab	doc_744962874530_item	2846919	et	4	main
linnas	doc_744962874530_item	2846924	et	4	main
ma	doc_744962874531_item	2846926	et	3	main
et	doc_744962874531_item	2846929	et	3	main
sest	doc_744962874531_item	2846934	et	4	main
kõik	doc_744962874531_item	2846939	et	4	main
elukoht	doc_744962874531_item	2846941	et	3	main
väga	doc_744962874531_item	2846944	et	3	main
tähtis	doc_744962874531_item	2846945	et	4	main
seal	doc_744962874531_item	2846952	et	4	main
ka	doc_744962874531_item	2846965	et	3	main
võimalusi	doc_744962874531_item	2846967	et	3	main
abisaamiseks	doc_744962874531_item	2846978	et	4	main
mõjutavad	doc_744962874524_item	2846506	et	4	main
on	doc_744962874524_item	2846510	et	4	main
tähtsam	doc_744962874524_item	2846523	et	4	main
ilma	doc_744962874524_item	2846529	et	4	main
raha	doc_744962874524_item	2846537	et	4	main
on	doc_744962874524_item	2846538	et	4	main
eest	doc_744962874524_item	2846546	et	4	main
vaja	doc_744962874524_item	2846548	et	4	main
maksta	doc_744962874524_item	2846549	et	4	main
sõbrad	doc_744962874524_item	2846564	et	3	main
sõber	doc_744962874524_item	2846568	et	3	main
tundub	doc_744962874524_item	2846576	et	3	main
aitavad	doc_744962874524_item	2846583	et	4	main
arvan	doc_744962874524_item	2846586	et	3	main
et	doc_744962874524_item	2846587	et	3	main
et	doc_744962874525_item	2846605	et	3	main
sõnnikoht	doc_744962874524_item	2846511	et	4	main
välimus	doc_744962874524_item	2846512	et	3	main
tarkus	doc_744962874524_item	2846515	et	4	main
saatus	doc_744962874524_item	2846516	et	3	main
iseloom	doc_744962874524_item	2846517	et	3	main
arvan	doc_744962874524_item	2846520	et	3	main
tänapäeval	doc_744962874524_item	2846527	et	3	main
ei	doc_744962874524_item	2846531	et	4	main
ajal	doc_744962874524_item	2846544	et	4	main
on	doc_744962874524_item	2846547	et	4	main
kes	doc_744962874524_item	2846555	et	4	main
elu	doc_744962874524_item	2846561	et	4	main
et	doc_744962874524_item	2846567	et	3	main
on	doc_744962874524_item	2846569	et	4	main
kes	doc_744962874524_item	2846571	et	4	main
sind	doc_744962874524_item	2846572	et	4	main
head	doc_744962874524_item	2846578	et	4	main
sõbrad	doc_744962874524_item	2846579	et	3	main
meie	doc_744962874524_item	2846580	et	4	main
mulle	doc_744962874524_item	2846591	et	4	main
tundub	doc_744962874524_item	2846592	et	3	main
et	doc_744962874524_item	2846593	et	3	main
essee	doc_744962874525_item	2846600	et	4	main
arvama	doc_744962874525_item	2846604	et	3	main
tähtis	doc_744962874525_item	2846609	et	4	main
sest	doc_744962874525_item	2846611	et	4	main
et	doc_744962874525_item	2846621	et	3	main
tähtis	doc_744962874525_item	2846625	et	4	main
mina	doc_744962874525_item	2846647	et	4	main
arvan	doc_744962874525_item	2846648	et	3	main
et	doc_744962874525_item	2846649	et	3	main
on	doc_744962874526_item	2846662	et	4	main
väga	doc_744962874526_item	2846663	et	3	main
on	doc_744962874526_item	2846670	et	4	main
sest	doc_744962874526_item	2846673	et	4	main
teine	doc_744962874527_item	2846722	et	3	main
nad	doc_744962874527_item	2846737	et	3	main
aitavad	doc_744962874527_item	2846738	et	4	main
väga	doc_744962874527_item	2846743	et	3	main
tähtis	doc_744962874527_item	2846744	et	4	main
on	doc_744962874527_item	2846746	et	4	main
teiste	doc_744962874527_item	2846759	et	4	main
oluline	doc_744962874527_item	2846764	et	4	main
meie	doc_744962874527_item	2846766	et	4	main
kõik	doc_744962874527_item	2846776	et	4	main
inimene	doc_744962874527_item	2846782	et	3	main
kõige	doc_744962874524_item	2846522	et	4	main
head	doc_744962874524_item	2846535	et	4	main
sest	doc_744962874524_item	2846542	et	4	main
käesoleval	doc_744962874524_item	2846543	et	3	main
kallis	doc_744962874524_item	2846552	et	4	main
aga	doc_744962874524_item	2846553	et	3	main
inimesel	doc_744962874524_item	2846554	et	3	main
inimese	doc_744962874524_item	2846560	et	4	main
arvan	doc_744962874524_item	2846566	et	3	main
mulle	doc_744962874524_item	2846575	et	4	main
et	doc_744962874524_item	2846577	et	3	main
kõiges	doc_744962874524_item	2846584	et	4	main
head	doc_744962874524_item	2846594	et	4	main
vanemad	doc_744962874524_item	2846595	et	4	main
igal	doc_744962874524_item	2846596	et	3	main
juhul	doc_744962874524_item	2846597	et	3	main
toetavad	doc_744962874524_item	2846598	et	4	main
span	doc_744962874524_item	2846599	et	4	main
kaldun	doc_744962874525_item	2846603	et	3	main
on	doc_744962874525_item	2846607	et	4	main
ka	doc_744962874525_item	2846610	et	3	main
on	doc_744962874525_item	2846613	et	4	main
minu	doc_744962874525_item	2846614	et	3	main
moraalne	doc_744962874525_item	2846615	et	3	main
välimus	doc_744962874525_item	2846616	et	3	main
mina	doc_744962874525_item	2846617	et	4	main
olen	doc_744962874525_item	2846618	et	3	main
veendunud	doc_744962874525_item	2846619	et	4	main
ka	doc_744962874525_item	2846620	et	3	main
mina	doc_744962874525_item	2846627	et	4	main
nendega	doc_744962874525_item	2846628	et	4	main
suhtlen	doc_744962874525_item	2846629	et	3	main
jalutan	doc_744962874525_item	2846630	et	3	main
veedan	doc_744962874525_item	2846633	et	3	main
sest	doc_744962874525_item	2846642	et	4	main
sõltub	doc_744962874525_item	2846643	et	3	main
essee	doc_744962874526_item	2846659	et	4	main
1	doc_744962874526_item	2846660	et	2	main
sõbrad	doc_744962874526_item	2846661	et	3	main
raha	doc_744962874526_item	2846669	et	4	main
tähtis	doc_744962874526_item	2846681	et	4	main
faktor	doc_744962874527_item	2846723	et	3	main
on	doc_744962874527_item	2846724	et	4	main
nad	doc_744962874527_item	2846741	et	3	main
tähtis	doc_744962874527_item	2846748	et	4	main
sest	doc_744962874527_item	2846749	et	4	main
et	doc_744962874527_item	2846750	et	3	main
kui	doc_744962874527_item	2846751	et	3	main
inimesel	doc_744962874527_item	2846752	et	3	main
suhelda	doc_744962874527_item	2846758	et	4	main
on	doc_744962874527_item	2846770	et	4	main
palju	doc_744962874527_item	2846771	et	4	main
raha	doc_744962874527_item	2846772	et	4	main
sa	doc_744962874527_item	2846773	et	3	main
võid	doc_744962874527_item	2846774	et	4	main
asjad	doc_744962874527_item	2846777	et	3	main
soobid	doc_744962874527_item	2846780	et	3	main
ei	doc_744962874527_item	2846783	et	4	main
asjad	doc_744962874527_item	2846789	et	3	main
dokument	doc_744962874529_item	2846840	et	3	main
nad	doc_744962874529_item	2846844	et	3	main
iseloomust	doc_744962874529_item	2846846	et	4	main
lapsepõlves	doc_744962874529_item	2846848	et	4	main
kasvatavad	doc_744962874529_item	2846849	et	4	main
span	doc_744962874529_item	2846879	et	4	main
essee	doc_744962874530_item	2846880	et	4	main
ma	doc_744962874530_item	2846881	et	3	main
mõtlen	doc_744962874530_item	2846882	et	3	main
et	doc_744962874530_item	2846883	et	3	main
kõige	doc_744962874530_item	2846886	et	4	main
sõbrad	doc_744962874530_item	2846889	et	3	main
elukoht	doc_744962874530_item	2846891	et	3	main
saatuses	doc_744962874530_item	2846897	et	4	main
haridus	doc_744962874530_item	2846898	et	3	main
sõbrad	doc_744962874525_item	2846622	et	3	main
aja	doc_744962874525_item	2846632	et	4	main
mina	doc_744962874525_item	2846634	et	4	main
arvan	doc_744962874525_item	2846635	et	3	main
et	doc_744962874525_item	2846636	et	3	main
sünnikoht	doc_744962874525_item	2846637	et	3	main
väga	doc_744962874525_item	2846639	et	3	main
sest	doc_744962874525_item	2846641	et	4	main
minu	doc_744962874525_item	2846644	et	3	main
tulevik	doc_744962874525_item	2846645	et	3	main
elu	doc_744962874525_item	2846646	et	4	main
tähtis	doc_744962874525_item	2846653	et	4	main
kasvanud	doc_744962874525_item	2846657	et	4	main
mind	doc_744962874525_item	2846658	et	4	main
aitab	doc_744962874526_item	2846667	et	3	main
meid	doc_744962874526_item	2846668	et	4	main
tähtis	doc_744962874526_item	2846672	et	4	main
sest	doc_744962874526_item	2846682	et	4	main
see	doc_744962874526_item	2846683	et	3	main
tegid	doc_744962874526_item	2846684	et	4	main
on	doc_744962874526_item	2846688	et	4	main
väga	doc_744962874526_item	2846689	et	3	main
oluline	doc_744962874526_item	2846690	et	4	main
sest	doc_744962874526_item	2846691	et	4	main
see	doc_744962874526_item	2846692	et	3	main
on	doc_744962874526_item	2846693	et	4	main
meid	doc_744962874526_item	2846694	et	4	main
hea	doc_744962874526_item	2846695	et	4	main
tulevikus	doc_744962874526_item	2846696	et	4	main
vanemad	doc_744962874526_item	2846697	et	4	main
on	doc_744962874526_item	2846698	et	4	main
väga	doc_744962874526_item	2846699	et	3	main
tähtis	doc_744962874526_item	2846700	et	4	main
sest	doc_744962874526_item	2846701	et	4	main
nad	doc_744962874526_item	2846702	et	3	main
kasvatab	doc_744962874526_item	2846703	et	3	main
meid	doc_744962874526_item	2846704	et	4	main
uus	doc_744962874527_item	2846705	et	3	main
dokument	doc_744962874527_item	2846706	et	3	main
ma	doc_744962874527_item	2846707	et	3	main
arvan	doc_744962874527_item	2846708	et	3	main
et	doc_744962874527_item	2846709	et	3	main
kõige	doc_744962874527_item	2846710	et	4	main
rohkem	doc_744962874527_item	2846711	et	4	main
mõjub	doc_744962874527_item	2846712	et	3	main
vanemad	doc_744962874527_item	2846713	et	4	main
sest	doc_744962874527_item	2846714	et	4	main
et	doc_744962874527_item	2846715	et	3	main
nad	doc_744962874527_item	2846716	et	3	main
on	doc_744962874527_item	2846717	et	4	main
sest	doc_744962874525_item	2846626	et	4	main
on	doc_744962874525_item	2846638	et	4	main
on	doc_744962874525_item	2846651	et	4	main
väga	doc_744962874525_item	2846652	et	3	main
oled	doc_744962874525_item	2846656	et	3	main
sest	doc_744962874526_item	2846665	et	4	main
nad	doc_744962874526_item	2846666	et	3	main
on	doc_744962874526_item	2846679	et	4	main
väga	doc_744962874526_item	2846680	et	3	main
tarkem	doc_744962874526_item	2846686	et	4	main
iseloom	doc_744962874526_item	2846687	et	3	main
kogu	doc_744962874527_item	2846718	et	4	main
elu	doc_744962874527_item	2846719	et	4	main
inimese	doc_744962874527_item	2846720	et	4	main
hea	doc_744962874527_item	2846732	et	4	main
töökoht	doc_744962874527_item	2846733	et	3	main
järgmine	doc_744962874527_item	2846734	et	3	main
on	doc_744962874527_item	2846735	et	4	main
sõbrad	doc_744962874527_item	2846736	et	3	main
on	doc_744962874527_item	2846742	et	4	main
iseloom	doc_744962874527_item	2846745	et	3	main
ka	doc_744962874527_item	2846747	et	3	main
raha	doc_744962874527_item	2846761	et	4	main
sul	doc_744962874527_item	2846769	et	3	main
mida	doc_744962874527_item	2846778	et	4	main
sa	doc_744962874527_item	2846779	et	3	main
aga	doc_744962874527_item	2846781	et	3	main
osta	doc_744962874527_item	2846784	et	4	main
armastus	doc_744962874527_item	2846785	et	4	main
sõprus	doc_744962874527_item	2846786	et	3	main
span	doc_744962874527_item	2846790	et	4	main
head	doc_744962874529_item	2846877	et	4	main
tööd	doc_744962874529_item	2846878	et	4	main
haridus	doc_744962874530_item	2846890	et	3	main
kõrval	doc_744962874527_item	2846721	et	4	main
haridus	doc_744962874527_item	2846725	et	3	main
sest	doc_744962874527_item	2846726	et	4	main
et	doc_744962874527_item	2846727	et	3	main
haritud	doc_744962874527_item	2846728	et	4	main
inimene	doc_744962874527_item	2846729	et	3	main
sind	doc_744962874527_item	2846739	et	4	main
on	doc_744962874527_item	2846753	et	4	main
hea	doc_744962874527_item	2846754	et	4	main
iseloom	doc_744962874527_item	2846755	et	3	main
ta	doc_744962874527_item	2846756	et	4	main
võib	doc_744962874527_item	2846757	et	3	main
ka	doc_744962874527_item	2846762	et	3	main
on	doc_744962874527_item	2846763	et	4	main
asi	doc_744962874527_item	2846765	et	4	main
osta	doc_744962874527_item	2846775	et	4	main
teised	doc_744962874527_item	2846788	et	4	main
vanemad	doc_744962874529_item	2846842	et	4	main
elu	doc_744962874530_item	2846885	et	4	main
täna	doc_744962874530_item	2846901	et	4	main
hea	doc_744962874530_item	2846905	et	4	main
sest	doc_744962874530_item	2846916	et	4	main
võimalusid	doc_744962874530_item	2846922	et	4	main
kaldun	doc_744962874531_item	2846927	et	3	main
vanemad	doc_744962874531_item	2846930	et	4	main
on	doc_744962874531_item	2846931	et	4	main
väga	doc_744962874531_item	2846932	et	3	main
nad	doc_744962874531_item	2846936	et	3	main
on	doc_744962874531_item	2846942	et	4	main
ka	doc_744962874531_item	2846943	et	3	main
sündinud	doc_744962874531_item	2846951	et	4	main
on	doc_744962874531_item	2846959	et	4	main
palju	doc_744962874531_item	2846960	et	4	main
võimalusi	doc_744962874531_item	2846961	et	3	main
sõbrad	doc_744962874531_item	2846968	et	3	main
ka	doc_744962874531_item	2846970	et	3	main
sest	doc_744962874531_item	2846972	et	4	main
et	doc_744962874531_item	2846973	et	3	main
ma	doc_744962874531_item	2846974	et	3	main
pöördun	doc_744962874531_item	2846975	et	3	main
nende	doc_744962874531_item	2846976	et	4	main
tähtis	doc_744962874531_item	2846981	et	4	main
elu	doc_744962874531_item	2846985	et	4	main
aprem	doc_744962874532_item	2847021	et	4	main
vanemadest	doc_744962874532_item	2847034	et	4	main
sest	doc_744962874532_item	2847035	et	4	main
kui	doc_744962874532_item	2847036	et	3	main
nad	doc_744962874532_item	2847037	et	3	main
sõltub	doc_744962874532_item	2847041	et	3	main
span	doc_744962874532_item	2847044	et	4	main
ma	doc_744962874532_item	2847046	et	3	main
iseloom	doc_744962874532_item	2847049	et	3	main
teile	doc_744962874532_item	2847067	et	4	main
sest	doc_744962874532_item	2847077	et	4	main
ei	doc_744962874532_item	2847079	et	4	main
uus	doc_744962874533_item	2847083	et	3	main
mõjutab	doc_744962874533_item	2847085	et	3	main
võib	doc_744962874533_item	2847088	et	3	main
näiteks	doc_744962874533_item	2847090	et	4	main
hea	doc_744962874533_item	2847095	et	4	main
teine	doc_744962874533_item	2847099	et	3	main
haridus	doc_744962874533_item	2847101	et	3	main
inimese	doc_744962874533_item	2847113	et	4	main
1	doc_744962874529_item	2846841	et	2	main
span	doc_744962874529_item	2846850	et	4	main
2	doc_744962874529_item	2846851	et	2	main
ei	doc_744962874529_item	2846858	et	4	main
elu	doc_744962874529_item	2846859	et	4	main
ja	doc_744962874529_item	2846860	et	3	main
rahaga	doc_744962874529_item	2846861	et	4	main
on	doc_744962874529_item	2846862	et	4	main
võimalus	doc_744962874529_item	2846863	et	3	main
ostma	doc_744962874529_item	2846864	et	3	main
kõik	doc_744962874529_item	2846865	et	4	main
ümber	doc_744962874529_item	2846866	et	3	main
span	doc_744962874529_item	2846867	et	4	main
3	doc_744962874529_item	2846868	et	2	main
kõige	doc_744962874529_item	2846869	et	4	main
tähtsem	doc_744962874529_item	2846870	et	4	main
haridus	doc_744962874529_item	2846871	et	3	main
või	doc_744962874529_item	2846872	et	4	main
kõrgharidus	doc_744962874529_item	2846873	et	3	main
sest	doc_744962874529_item	2846874	et	4	main
võin	doc_744962874529_item	2846875	et	3	main
leida	doc_744962874529_item	2846876	et	3	main
saatus	doc_744962874530_item	2846894	et	3	main
usun	doc_744962874530_item	2846896	et	3	main
haridus	doc_744962874530_item	2846903	et	3	main
hea	doc_744962874530_item	2846908	et	4	main
amet	doc_744962874530_item	2846909	et	3	main
elukoht	doc_744962874530_item	2846910	et	3	main
on	doc_744962874530_item	2846911	et	4	main
ka	doc_744962874530_item	2846912	et	3	main
mõjutab	doc_744962874530_item	2846913	et	3	main
olema	doc_744962874530_item	2846920	et	4	main
on	doc_744962874530_item	2846899	et	4	main
hädavajalik	doc_744962874530_item	2846900	et	3	main
inimese	doc_744962874530_item	2846914	et	4	main
elu	doc_744962874530_item	2846915	et	4	main
palju	doc_744962874530_item	2846921	et	4	main
essee	doc_744962874531_item	2846925	et	4	main
arvama	doc_744962874531_item	2846928	et	3	main
et	doc_744962874531_item	2846935	et	3	main
et	doc_744962874531_item	2846947	et	3	main
ta	doc_744962874531_item	2846953	et	4	main
elas	doc_744962874531_item	2846954	et	3	main
ja	doc_744962874531_item	2846955	et	3	main
kui	doc_744962874531_item	2846956	et	3	main
sest	doc_744962874531_item	2846962	et	4	main
sulle	doc_744962874531_item	2846963	et	3	main
palju	doc_744962874531_item	2846966	et	4	main
pärast	doc_744962874531_item	2846983	et	4	main
rahast	doc_744962874531_item	2846987	et	4	main
dokument	doc_744962874532_item	2846989	et	3	main
span	doc_744962874532_item	2847026	et	4	main
kasvatavad	doc_744962874532_item	2847038	et	4	main
sest	doc_744962874532_item	2847053	et	4	main
kui	doc_744962874532_item	2847054	et	3	main
head	doc_744962874532_item	2847062	et	4	main
span	doc_744962874532_item	2847068	et	4	main
mõtlen	doc_744962874532_item	2847071	et	3	main
saatust	doc_744962874532_item	2847078	et	4	main
võida	doc_744962874533_item	2847091	et	4	main
haridust	doc_744962874533_item	2847103	et	4	main
sest	doc_744962874533_item	2847124	et	4	main
rohkem	doc_744962874533_item	2847134	et	4	main
kasvatus	doc_744962874533_item	2847148	et	4	main
1	doc_744962874534_item	2847152	et	2	main
sõbrad	doc_744962874534_item	2847155	et	3	main
väga	doc_744962874534_item	2847157	et	3	main
sul	doc_744962874534_item	2847164	et	3	main
iseloom	doc_744962874534_item	2847171	et	3	main
tähtis	doc_744962874534_item	2847175	et	4	main
et	doc_744962874534_item	2847177	et	3	main
elab	doc_744962874534_item	2847180	et	3	main
span	doc_744962874534_item	2847188	et	4	main
3	doc_744962874534_item	2847189	et	2	main
muidugi	doc_744962874534_item	2847190	et	4	main
vanemate	doc_744962874534_item	2847202	et	4	main
vanemad	doc_744962874534_item	2847208	et	4	main
raha	doc_744962874534_item	2847216	et	4	main
sest	doc_744962874534_item	2847221	et	4	main
ei	doc_744962874534_item	2847225	et	4	main
elada	doc_744962874534_item	2847228	et	3	main
uus	doc_744962874535_item	2847230	et	3	main
arvan	doc_744962874535_item	2847233	et	3	main
kui	doc_744962874535_item	2847241	et	3	main
inimesel	doc_744962874535_item	2847242	et	3	main
on	doc_744962874535_item	2847243	et	4	main
ta	doc_744962874535_item	2847256	et	4	main
perekond	doc_744962874535_item	2847263	et	3	main
see	doc_744962874535_item	2847305	et	3	main
suur	doc_744962874535_item	2847308	et	3	main
on	doc_744962874530_item	2846904	et	4	main
tähtis	doc_744962874531_item	2846933	et	4	main
annavad	doc_744962874531_item	2846937	et	3	main
sest	doc_744962874531_item	2846946	et	4	main
uus	doc_744962874531_item	2846948	et	3	main
selle	doc_744962874531_item	2846957	et	4	main
linnus	doc_744962874531_item	2846958	et	4	main
on	doc_744962874531_item	2846964	et	4	main
on	doc_744962874531_item	2846969	et	4	main
tähtis	doc_744962874531_item	2846971	et	4	main
on	doc_744962874531_item	2846980	et	4	main
ma	doc_744962874532_item	2847028	et	3	main
et	doc_744962874532_item	2847030	et	3	main
meid	doc_744962874532_item	2847039	et	4	main
meie	doc_744962874532_item	2847042	et	4	main
teil	doc_744962874532_item	2847055	et	4	main
saate	doc_744962874532_item	2847060	et	4	main
kes	doc_744962874532_item	2847064	et	4	main
saavad	doc_744962874532_item	2847065	et	4	main
abida	doc_744962874532_item	2847066	et	4	main
et	doc_744962874532_item	2847072	et	3	main
tähtis	doc_744962874532_item	2847076	et	4	main
span	doc_744962874532_item	2847082	et	4	main
või	doc_744962874533_item	2847093	et	4	main
saada	doc_744962874533_item	2847094	et	4	main
minu	doc_744962874533_item	2847098	et	3	main
saatnud	doc_744962874533_item	2847106	et	4	main
hea	doc_744962874533_item	2847107	et	4	main
töökoht	doc_744962874533_item	2847108	et	3	main
ja	doc_744962874533_item	2847109	et	3	main
võib	doc_744962874533_item	2847111	et	3	main
mõjutab	doc_744962874533_item	2847112	et	3	main
elu	doc_744962874533_item	2847114	et	4	main
span	doc_744962874533_item	2847115	et	4	main
kus	doc_744962874533_item	2847125	et	3	main
sa	doc_744962874533_item	2847126	et	3	main
või	doc_744962874533_item	2847129	et	4	main
tallinnas	doc_744962874533_item	2847133	et	4	main
elus	doc_744962874533_item	2847136	et	4	main
vanemad	doc_744962874533_item	2847140	et	4	main
nad	doc_744962874533_item	2847141	et	3	main
sulle	doc_744962874533_item	2847143	et	3	main
haridus	doc_744962874533_item	2847145	et	3	main
ja	doc_744962874533_item	2847146	et	3	main
dokument	doc_744962874534_item	2847151	et	3	main
tähtis	doc_744962874534_item	2847158	et	4	main
sest	doc_744962874534_item	2847159	et	4	main
nad	doc_744962874534_item	2847160	et	3	main
span	doc_744962874534_item	2847168	et	4	main
inimeste	doc_744962874534_item	2847170	et	3	main
teise	doc_744962874534_item	2847184	et	4	main
inimestega	doc_744962874534_item	2847185	et	3	main
haridus	doc_744962874534_item	2847194	et	3	main
elus	doc_744962874534_item	2847205	et	4	main
kavatavad	doc_744962874534_item	2847209	et	3	main
elu	doc_744962874534_item	2847211	et	4	main
või	doc_744962874534_item	2847226	et	4	main
inimese	doc_744962874535_item	2847238	et	4	main
ei	doc_744962874535_item	2847247	et	4	main
ole	doc_744962874535_item	2847248	et	4	main
aga	doc_744962874535_item	2847250	et	3	main
ei	doc_744962874535_item	2847253	et	4	main
elus	doc_744962874535_item	2847270	et	4	main
samuti	doc_744962874535_item	2847271	et	3	main
suur	doc_744962874535_item	2847272	et	3	main
roll	doc_744962874535_item	2847273	et	3	main
mängib	doc_744962874535_item	2847274	et	3	main
selle	doc_744962874535_item	2847276	et	4	main
päras	doc_744962874535_item	2847277	et	3	main
mis	doc_744962874536_item	2847314	et	4	main
mõjutab	doc_744962874536_item	2847315	et	3	main
inimese	doc_744962874536_item	2847316	et	4	main
elu	doc_744962874536_item	2847317	et	4	main
olen	doc_744962874536_item	2847323	et	3	main
kindel	doc_744962874536_item	2847324	et	3	main
rohkem	doc_744962874536_item	2847333	et	4	main
elukoht	doc_744962874536_item	2847337	et	3	main
igal	doc_744962874536_item	2847339	et	3	main
ja	doc_744962874536_item	2847344	et	3	main
on	doc_744962874536_item	2847347	et	4	main
väga	doc_744962874536_item	2847348	et	3	main
tähtis	doc_744962874536_item	2847349	et	4	main
ka	doc_744962874536_item	2847350	et	3	main
suur	doc_744962874530_item	2846923	et	3	main
mulle	doc_744962874531_item	2846938	et	4	main
hea	doc_744962874531_item	2846940	et	4	main
ta	doc_744962874531_item	2846949	et	4	main
on	doc_744962874531_item	2846950	et	4	main
poole	doc_744962874531_item	2846977	et	4	main
selle	doc_744962874531_item	2846982	et	4	main
sõltub	doc_744962874531_item	2846986	et	3	main
uus	doc_744962874532_item	2846988	et	3	main
ma	doc_744962874532_item	2846990	et	3	main
arvan	doc_744962874532_item	2846991	et	3	main
et	doc_744962874532_item	2846992	et	3	main
kõige	doc_744962874532_item	2846993	et	4	main
tähtsam	doc_744962874532_item	2846994	et	4	main
on	doc_744962874532_item	2846995	et	4	main
inimene	doc_744962874532_item	2846996	et	3	main
tarkus	doc_744962874532_item	2846997	et	4	main
sest	doc_744962874532_item	2846998	et	4	main
kui	doc_744962874532_item	2846999	et	3	main
inimene	doc_744962874532_item	2847000	et	3	main
on	doc_744962874532_item	2847001	et	4	main
tark	doc_744962874532_item	2847002	et	3	main
ta	doc_744962874532_item	2847003	et	4	main
saab	doc_744962874532_item	2847004	et	3	main
leida	doc_744962874532_item	2847005	et	3	main
töö	doc_744962874532_item	2847006	et	4	main
alati	doc_744962874532_item	2847007	et	4	main
span	doc_744962874532_item	2847008	et	4	main
teise	doc_744962874532_item	2847009	et	4	main
kohale	doc_744962874532_item	2847010	et	4	main
ma	doc_744962874532_item	2847011	et	3	main
panen	doc_744962874532_item	2847012	et	3	main
haridust	doc_744962874532_item	2847013	et	4	main
sest	doc_744962874532_item	2847014	et	4	main
praegu	doc_744962874532_item	2847015	et	3	main
meie	doc_744962874532_item	2847016	et	4	main
tulevik	doc_744962874532_item	2847017	et	3	main
sõltub	doc_744962874532_item	2847018	et	3	main
haridust	doc_744962874532_item	2847019	et	4	main
ja	doc_744962874532_item	2847020	et	3	main
raha	doc_744962874531_item	2846979	et	4	main
et	doc_744962874531_item	2846984	et	3	main
kõrgharidus	doc_744962874532_item	2847025	et	3	main
meie	doc_744962874532_item	2847031	et	4	main
mõjutab	doc_744962874532_item	2847033	et	3	main
sellest	doc_744962874532_item	2847040	et	4	main
tulevik	doc_744962874532_item	2847043	et	3	main
arvan	doc_744962874532_item	2847047	et	3	main
on	doc_744962874532_item	2847050	et	4	main
ka	doc_744962874532_item	2847051	et	3	main
tähtis	doc_744962874532_item	2847052	et	4	main
leida	doc_744962874532_item	2847061	et	3	main
sõbrad	doc_744962874532_item	2847063	et	3	main
viimaseks	doc_744962874532_item	2847069	et	3	main
ma	doc_744962874532_item	2847070	et	3	main
on	doc_744962874532_item	2847074	et	4	main
muuta	doc_744962874532_item	2847081	et	4	main
dokument	doc_744962874533_item	2847084	et	3	main
elu	doc_744962874533_item	2847087	et	4	main
juhus	doc_744962874533_item	2847089	et	4	main
töö	doc_744962874533_item	2847096	et	4	main
vajalik	doc_744962874533_item	2847100	et	3	main
võib	doc_744962874533_item	2847122	et	3	main
valik	doc_744962874533_item	2847139	et	3	main
span	doc_744962874533_item	2847149	et	4	main
abistavad	doc_744962874534_item	2847161	et	4	main
sind	doc_744962874534_item	2847162	et	4	main
kui	doc_744962874534_item	2847163	et	3	main
2	doc_744962874534_item	2847169	et	2	main
on	doc_744962874534_item	2847172	et	4	main
inimene	doc_744962874534_item	2847179	et	3	main
on	doc_744962874534_item	2847191	et	4	main
hea	doc_744962874534_item	2847193	et	4	main
rool	doc_744962874534_item	2847203	et	4	main
inimeste	doc_744962874534_item	2847204	et	3	main
lihtsalt	doc_744962874534_item	2847224	et	4	main
dokument	doc_744962874535_item	2847231	et	3	main
raha	doc_744962874535_item	2847235	et	4	main
vaga	doc_744962874535_item	2847236	et	4	main
mõjutab	doc_744962874535_item	2847237	et	3	main
palju	doc_744962874535_item	2847244	et	4	main
kui	doc_744962874535_item	2847251	et	3	main
ja	doc_744962874535_item	2847264	et	3	main
palju	doc_744962874535_item	2847267	et	4	main
vanemad	doc_744962874535_item	2847275	et	4	main
ja	doc_744962874535_item	2847304	et	3	main
väga	doc_744962874535_item	2847307	et	3	main
span	doc_744962874536_item	2847320	et	4	main
span	doc_744962874536_item	2847321	et	4	main
inimese	doc_744962874536_item	2847326	et	4	main
sest	doc_744962874536_item	2847338	et	4	main
haritud	doc_744962874536_item	2847352	et	4	main
inimene	doc_744962874536_item	2847353	et	3	main
saab	doc_744962874536_item	2847354	et	3	main
valida	doc_744962874536_item	2847355	et	3	main
inimene	doc_744962874536_item	2847359	et	3	main
raha	doc_744962874536_item	2847362	et	4	main
paluda	doc_744962874536_item	2847365	et	3	main
omale	doc_744962874536_item	2847366	et	3	main
veel	doc_744962874536_item	2847370	et	4	main
et	doc_744962874536_item	2847373	et	3	main
ja	doc_744962874536_item	2847384	et	3	main
tõenäoliselt	doc_744962874536_item	2847390	et	4	main
ja	doc_744962874536_item	2847401	et	3	main
igaüks	doc_744962874536_item	2847402	et	3	main
peab	doc_744962874536_item	2847403	et	4	main
hoidma	doc_744962874536_item	2847404	et	3	main
oma	doc_744962874536_item	2847405	et	4	main
dokument	doc_744962874537_item	2847411	et	3	main
inimese	doc_744962874537_item	2847414	et	4	main
kõige	doc_744962874537_item	2847416	et	4	main
arvan	doc_744962874537_item	2847421	et	3	main
sest	doc_744962874537_item	2847428	et	4	main
paremas	doc_744962874537_item	2847434	et	4	main
inimese	doc_744962874537_item	2847438	et	4	main
ning	doc_744962874537_item	2847448	et	3	main
on	doc_744962874537_item	2847450	et	4	main
raske	doc_744962874537_item	2847452	et	4	main
leida	doc_744962874537_item	2847453	et	3	main
sõpru	doc_744962874537_item	2847454	et	3	main
ja	doc_744962874537_item	2847455	et	3	main
raske	doc_744962874537_item	2847456	et	4	main
on	doc_744962874537_item	2847462	et	4	main
kui	doc_744962874532_item	2847022	et	3	main
teil	doc_744962874532_item	2847023	et	4	main
on	doc_744962874532_item	2847024	et	4	main
kolmandaks	doc_744962874532_item	2847027	et	4	main
mõtlen	doc_744962874532_item	2847029	et	3	main
elu	doc_744962874532_item	2847032	et	4	main
neljandaks	doc_744962874532_item	2847045	et	4	main
et	doc_744962874532_item	2847048	et	3	main
on	doc_744962874532_item	2847056	et	4	main
hea	doc_744962874532_item	2847057	et	4	main
iseloom	doc_744962874532_item	2847058	et	3	main
te	doc_744962874532_item	2847059	et	4	main
saatus	doc_744962874532_item	2847073	et	3	main
väga	doc_744962874532_item	2847075	et	3	main
saa	doc_744962874532_item	2847080	et	4	main
inimese	doc_744962874533_item	2847086	et	4	main
loterejas	doc_744962874533_item	2847092	et	4	main
span	doc_744962874533_item	2847097	et	4	main
ilma	doc_744962874533_item	2847102	et	4	main
te	doc_744962874533_item	2847104	et	4	main
ei	doc_744962874533_item	2847105	et	4	main
see	doc_744962874533_item	2847110	et	3	main
ma	doc_744962874533_item	2847116	et	3	main
arvan	doc_744962874533_item	2847117	et	3	main
et	doc_744962874533_item	2847118	et	3	main
mõjutab	doc_744962874533_item	2847119	et	3	main
inimese	doc_744962874533_item	2847120	et	4	main
elu	doc_744962874533_item	2847121	et	4	main
tallinnas	doc_744962874533_item	2847128	et	4	main
kohtla-jerve	doc_744962874533_item	2847130	et	4	main
ma	doc_744962874533_item	2847131	et	3	main
mõtlen	doc_744962874533_item	2847132	et	3	main
perpertivsed	doc_744962874533_item	2847135	et	4	main
neli	doc_744962874533_item	2847138	et	3	main
annavad	doc_744962874533_item	2847142	et	3	main
hea	doc_744962874533_item	2847144	et	4	main
hea	doc_744962874533_item	2847147	et	4	main
uus	doc_744962874534_item	2847150	et	3	main
minu	doc_744962874534_item	2847153	et	3	main
abi	doc_744962874534_item	2847167	et	4	main
väga	doc_744962874534_item	2847174	et	3	main
iga	doc_744962874534_item	2847178	et	4	main
ühiskonnas	doc_744962874534_item	2847181	et	4	main
ja	doc_744962874534_item	2847182	et	3	main
peab	doc_744962874534_item	2847183	et	4	main
span	doc_744962874534_item	2847200	et	4	main
4	doc_744962874534_item	2847201	et	2	main
surepärane	doc_744962874534_item	2847207	et	4	main
õpitavad	doc_744962874534_item	2847210	et	4	main
annavad	doc_744962874534_item	2847212	et	3	main
nõu	doc_744962874534_item	2847213	et	4	main
span	doc_744962874534_item	2847214	et	4	main
5	doc_744962874534_item	2847215	et	2	main
rahata	doc_744962874534_item	2847223	et	4	main
elus	doc_744962874535_item	2847239	et	4	main
sellepärast	doc_744962874535_item	2847240	et	3	main
raha	doc_744962874535_item	2847245	et	4	main
probleemid	doc_744962874535_item	2847249	et	3	main
ei	doc_744962874535_item	2847257	et	4	main
või	doc_744962874535_item	2847258	et	4	main
kindlustama	doc_744962874535_item	2847259	et	3	main
ise	doc_744962874535_item	2847260	et	4	main
sul	doc_744962874535_item	2847265	et	3	main
on	doc_744962874535_item	2847306	et	4	main
problema	doc_744962874535_item	2847309	et	4	main
elus	doc_744962874535_item	2847310	et	4	main
span	doc_744962874535_item	2847311	et	4	main
uus	doc_744962874536_item	2847312	et	3	main
dokument	doc_744962874536_item	2847313	et	3	main
rohkem	doc_744962874536_item	2847319	et	4	main
kõige	doc_744962874536_item	2847332	et	4	main
maal	doc_744962874536_item	2847340	et	4	main
traditsioonid	doc_744962874536_item	2847343	et	3	main
kultuur	doc_744962874536_item	2847345	et	3	main
omab	doc_744962874536_item	2847360	et	3	main
tema	doc_744962874536_item	2847377	et	4	main
valik	doc_744962874536_item	2847389	et	3	main
tähtis	doc_744962874536_item	2847397	et	4	main
elukoht	doc_744962874533_item	2847123	et	3	main
elad	doc_744962874533_item	2847127	et	3	main
span	doc_744962874533_item	2847137	et	4	main
arvates	doc_744962874534_item	2847154	et	4	main
on	doc_744962874534_item	2847156	et	4	main
on	doc_744962874534_item	2847165	et	4	main
vaja	doc_744962874534_item	2847166	et	4	main
ka	doc_744962874534_item	2847173	et	3	main
sellepärast	doc_744962874534_item	2847176	et	3	main
läbi	doc_744962874534_item	2847186	et	4	main
saama	doc_744962874534_item	2847187	et	4	main
vaja	doc_744962874534_item	2847192	et	4	main
mis	doc_744962874534_item	2847195	et	4	main
annab	doc_744962874534_item	2847196	et	3	main
ühele	doc_744962874534_item	2847197	et	3	main
head	doc_744962874534_item	2847198	et	4	main
võimalusi	doc_744962874534_item	2847199	et	3	main
on	doc_744962874534_item	2847206	et	4	main
on	doc_744962874534_item	2847217	et	4	main
ka	doc_744962874534_item	2847218	et	3	main
väga	doc_744962874534_item	2847219	et	3	main
tähtis	doc_744962874534_item	2847220	et	4	main
et	doc_744962874534_item	2847222	et	3	main
normaalselt	doc_744962874534_item	2847227	et	4	main
span	doc_744962874534_item	2847229	et	4	main
ma	doc_744962874535_item	2847232	et	3	main
et	doc_744962874535_item	2847234	et	3	main
temal	doc_744962874535_item	2847246	et	3	main
inimesel	doc_744962874535_item	2847252	et	3	main
ole	doc_744962874535_item	2847254	et	4	main
raha	doc_744962874535_item	2847255	et	4	main
ja	doc_744962874535_item	2847261	et	3	main
oma	doc_744962874535_item	2847262	et	4	main
on	doc_744962874535_item	2847266	et	4	main
problemid	doc_744962874535_item	2847268	et	4	main
ise	doc_744962874535_item	2847269	et	4	main
ta	doc_744962874535_item	2847278	et	4	main
ei	doc_744962874535_item	2847279	et	4	main
kasvatus	doc_744962874535_item	2847280	et	4	main
oma	doc_744962874535_item	2847281	et	4	main
laps	doc_744962874535_item	2847282	et	4	main
ja	doc_744962874535_item	2847283	et	3	main
lapse	doc_744962874535_item	2847284	et	4	main
elus	doc_744962874535_item	2847285	et	4	main
seisib	doc_744962874535_item	2847286	et	4	main
paha	doc_744962874535_item	2847287	et	4	main
mõjutab	doc_744962874535_item	2847288	et	3	main
inimese	doc_744962874535_item	2847289	et	4	main
elu	doc_744962874535_item	2847290	et	4	main
haridus	doc_744962874535_item	2847291	et	3	main
kui	doc_744962874535_item	2847292	et	3	main
inimesel	doc_744962874535_item	2847293	et	3	main
ei	doc_744962874535_item	2847294	et	4	main
haridus	doc_744962874535_item	2847296	et	3	main
ikka	doc_744962874535_item	2847297	et	4	main
temal	doc_744962874535_item	2847298	et	3	main
ole	doc_744962874535_item	2847295	et	4	main
ei	doc_744962874535_item	2847299	et	4	main
ole	doc_744962874535_item	2847300	et	4	main
töö	doc_744962874535_item	2847301	et	4	main
ja	doc_744962874535_item	2847302	et	3	main
raha	doc_744962874535_item	2847303	et	4	main
kõige	doc_744962874536_item	2847318	et	4	main
et	doc_744962874536_item	2847325	et	3	main
mõjutab	doc_744962874536_item	2847334	et	3	main
sünnikoht	doc_744962874536_item	2847335	et	3	main
ja	doc_744962874536_item	2847336	et	3	main
sest	doc_744962874536_item	2847351	et	4	main
haritud	doc_744962874536_item	2847358	et	4	main
palju	doc_744962874536_item	2847368	et	4	main
mulle	doc_744962874536_item	2847371	et	4	main
inimese	doc_744962874536_item	2847374	et	4	main
elu	doc_744962874536_item	2847375	et	4	main
sõltub	doc_744962874536_item	2847376	et	3	main
on	doc_744962874536_item	2847382	et	4	main
saab	doc_744962874536_item	2847386	et	3	main
teha	doc_744962874536_item	2847387	et	3	main
meie	doc_744962874536_item	2847391	et	4	main
sõbrad	doc_744962874536_item	2847394	et	3	main
väga	doc_744962874536_item	2847396	et	3	main
mõjutab	doc_744962874537_item	2847413	et	3	main
span	doc_744962874537_item	2847419	et	4	main
elu	doc_744962874537_item	2847425	et	4	main
mõjutab	doc_744962874537_item	2847426	et	3	main
mõjutab	doc_744962874537_item	2847440	et	3	main
raske	doc_744962874537_item	2847446	et	4	main
suhelda	doc_744962874537_item	2847457	et	4	main
ka	doc_744962874537_item	2847463	et	3	main
ei	doc_744962874537_item	2847467	et	4	main
tal	doc_744962874537_item	2847471	et	3	main
väga	doc_744962874537_item	2847473	et	3	main
raske	doc_744962874537_item	2847474	et	4	main
jutustada	doc_744962874537_item	2847481	et	3	main
haridus	doc_744962874538_item	2847523	et	3	main
väga	doc_744962874538_item	2847525	et	3	main
tähtis	doc_744962874538_item	2847526	et	4	main
tavaliselt	doc_744962874538_item	2847531	et	4	main
töökoha	doc_744962874538_item	2847534	et	4	main
arvates	doc_744962874538_item	2847536	et	4	main
tähtis	doc_744962874538_item	2847539	et	4	main
on	doc_744962874538_item	2847540	et	4	main
tähtsad	doc_744962874538_item	2847546	et	3	main
arvates	doc_744962874538_item	2847550	et	4	main
iseloom	doc_744962874538_item	2847567	et	3	main
hea	doc_744962874538_item	2847571	et	4	main
siis	doc_744962874538_item	2847573	et	3	main
sinu	doc_744962874538_item	2847574	et	3	main
elada	doc_744962874539_item	2847619	et	3	main
ja	doc_744962874539_item	2847647	et	3	main
suhted	doc_744962874539_item	2847649	et	3	main
rahulik	doc_744962874539_item	2847653	et	3	main
mis	doc_744962874539_item	2847659	et	4	main
saab	doc_744962874539_item	2847662	et	3	main
sa	doc_744962874540_item	2847692	et	3	main
oluline	doc_744962874540_item	2847696	et	4	main
riik	doc_744962874540_item	2847699	et	3	main
ei	doc_744962874540_item	2847724	et	4	main
elu	doc_744962874540_item	2847748	et	4	main
elu	doc_744962874540_item	2847751	et	4	main
mõjutab	doc_744962874540_item	2847753	et	3	main
et	doc_744962874540_item	2847773	et	3	main
inimese	doc_744962874541_item	2847782	et	4	main
elu	doc_744962874541_item	2847783	et	4	main
kõige	doc_744962874541_item	2847784	et	4	main
sest	doc_744962874541_item	2847790	et	4	main
on	doc_744962874541_item	2847797	et	4	main
näiteks	doc_744962874541_item	2847815	et	4	main
vanemad	doc_744962874541_item	2847822	et	4	main
iseloomu	doc_744962874541_item	2847830	et	4	main
kes	doc_744962874541_item	2847837	et	4	main
on	doc_744962874541_item	2847838	et	4	main
võimalusi	doc_744962874541_item	2847843	et	3	main
et	doc_744962874541_item	2847844	et	3	main
edukaks	doc_744962874541_item	2847845	et	3	main
saada	doc_744962874541_item	2847846	et	4	main
juhend	doc_744962874542_item	2847847	et	3	main
karbist	doc_744962874542_item	2847852	et	3	main
pange	doc_744962874542_item	2847854	et	4	main
seinakontakti	doc_744962874542_item	2847860	et	4	main
see	doc_744962874542_item	2847867	et	3	main
siis	doc_744962874542_item	2847873	et	3	main
pistik	doc_744962874542_item	2847886	et	3	main
hoidke	doc_744962874542_item	2847892	et	3	main
eest	doc_744962874542_item	2847894	et	4	main
ma	doc_744962874536_item	2847322	et	3	main
elu	doc_744962874536_item	2847327	et	4	main
mõjutavad	doc_744962874536_item	2847328	et	4	main
paljud	doc_744962874536_item	2847329	et	3	main
asjad	doc_744962874536_item	2847330	et	3	main
aga	doc_744962874536_item	2847331	et	3	main
on	doc_744962874536_item	2847341	et	4	main
oma	doc_744962874536_item	2847342	et	4	main
haridus	doc_744962874536_item	2847346	et	3	main
oma	doc_744962874536_item	2847356	et	4	main
elu	doc_744962874536_item	2847357	et	4	main
palju	doc_744962874536_item	2847361	et	4	main
ja	doc_744962874536_item	2847363	et	3	main
võib	doc_744962874536_item	2847364	et	3	main
väga	doc_744962874536_item	2847367	et	3	main
iseloomist	doc_744962874536_item	2847378	et	4	main
erinevad	doc_744962874536_item	2847383	et	4	main
vanemad	doc_744962874536_item	2847392	et	4	main
elus	doc_744962874536_item	2847400	et	4	main
uus	doc_744962874537_item	2847410	et	3	main
elu	doc_744962874537_item	2847415	et	4	main
rohkem	doc_744962874537_item	2847417	et	4	main
mina	doc_744962874537_item	2847420	et	4	main
et	doc_744962874537_item	2847422	et	3	main
inimese	doc_744962874537_item	2847424	et	4	main
elukoht	doc_744962874537_item	2847427	et	3	main
heas	doc_744962874537_item	2847432	et	3	main
elutingimuses	doc_744962874537_item	2847435	et	3	main
span	doc_744962874537_item	2847436	et	4	main
teiseks	doc_744962874537_item	2847437	et	4	main
kui	doc_744962874537_item	2847443	et	3	main
on	doc_744962874537_item	2847445	et	4	main
tal	doc_744962874537_item	2847449	et	3	main
väga	doc_744962874537_item	2847451	et	3	main
sübrad	doc_744962874537_item	2847461	et	4	main
tähtis	doc_744962874537_item	2847464	et	4	main
inimesel	doc_744962874537_item	2847466	et	3	main
ole	doc_744962874537_item	2847468	et	4	main
probleemid	doc_744962874537_item	2847483	et	3	main
haridus	doc_744962874537_item	2847485	et	3	main
väga	doc_744962874537_item	2847487	et	3	main
span	doc_744962874537_item	2847521	et	4	main
on	doc_744962874538_item	2847524	et	4	main
parema	doc_744962874538_item	2847533	et	4	main
minu	doc_744962874538_item	2847535	et	3	main
et	doc_744962874538_item	2847537	et	3	main
saavad	doc_744962874538_item	2847558	et	4	main
on	doc_744962874538_item	2847566	et	4	main
on	doc_744962874538_item	2847570	et	4	main
iseloom	doc_744962874538_item	2847572	et	3	main
on	doc_744962874538_item	2847578	et	4	main
arvates	doc_744962874538_item	2847581	et	4	main
et	doc_744962874538_item	2847582	et	3	main
et	doc_744962874539_item	2847618	et	3	main
töötama	doc_744962874539_item	2847622	et	3	main
parem	doc_744962874539_item	2847623	et	4	main
elu	doc_744962874539_item	2847625	et	4	main
tingimusest	doc_744962874539_item	2847626	et	4	main
et	doc_744962874539_item	2847627	et	3	main
inimene	doc_744962874539_item	2847628	et	3	main
harjub	doc_744962874539_item	2847629	et	3	main
aga	doc_744962874539_item	2847630	et	3	main
ma	doc_744962874539_item	2847631	et	3	main
olen	doc_744962874539_item	2847632	et	3	main
inimese	doc_744962874539_item	2847637	et	4	main
on	doc_744962874539_item	2847639	et	4	main
perekond	doc_744962874539_item	2847641	et	3	main
laps	doc_744962874539_item	2847650	et	4	main
ka	doc_744962874539_item	2847657	et	3	main
haridus	doc_744962874539_item	2847660	et	3	main
sündis	doc_744962874539_item	2847674	et	3	main
sest	doc_744962874540_item	2847690	et	4	main
kus	doc_744962874540_item	2847691	et	3	main
see	doc_744962874540_item	2847698	et	3	main
kuidas	doc_744962874540_item	2847701	et	3	main
sa	doc_744962874540_item	2847723	et	3	main
võid	doc_744962874540_item	2847736	et	4	main
saada	doc_744962874540_item	2847737	et	4	main
on	doc_744962874540_item	2847742	et	4	main
span	doc_744962874540_item	2847749	et	4	main
arvan	doc_744962874540_item	2847772	et	3	main
juhus	doc_744962874541_item	2847786	et	4	main
asjad	doc_744962874541_item	2847792	et	3	main
tahtel	doc_744962874541_item	2847795	et	3	main
inimesel	doc_744962874541_item	2847801	et	3	main
kes	doc_744962874541_item	2847802	et	4	main
haridus	doc_744962874541_item	2847804	et	3	main
korraldata	doc_744962874541_item	2847809	et	3	main
üles	doc_744962874541_item	2847820	et	3	main
on	doc_744962874541_item	2847832	et	4	main
tähtis	doc_744962874541_item	2847834	et	4	main
span	doc_744962874536_item	2847369	et	4	main
tundub	doc_744962874536_item	2847372	et	3	main
sest	doc_744962874536_item	2847379	et	4	main
kõik	doc_744962874536_item	2847380	et	4	main
inimesed	doc_744962874536_item	2847381	et	3	main
igaüks	doc_744962874536_item	2847385	et	3	main
oma	doc_744962874536_item	2847388	et	4	main
ja	doc_744962874536_item	2847393	et	3	main
on	doc_744962874536_item	2847395	et	4	main
pere	doc_744962874536_item	2847406	et	4	main
ja	doc_744962874536_item	2847407	et	3	main
sõpru	doc_744962874536_item	2847408	et	3	main
span	doc_744962874536_item	2847409	et	4	main
asi	doc_744962874536_item	2847398	et	4	main
meie	doc_744962874536_item	2847399	et	4	main
mis	doc_744962874537_item	2847412	et	4	main
span	doc_744962874537_item	2847418	et	4	main
esiteks	doc_744962874537_item	2847423	et	3	main
inimene	doc_744962874537_item	2847429	et	3	main
elada	doc_744962874537_item	2847431	et	3	main
ja	doc_744962874537_item	2847433	et	3	main
elu	doc_744962874537_item	2847439	et	4	main
iseloom	doc_744962874537_item	2847441	et	3	main
inimesel	doc_744962874537_item	2847444	et	3	main
teise	doc_744962874537_item	2847458	et	4	main
inimesega	doc_744962874537_item	2847459	et	3	main
span	doc_744962874537_item	2847460	et	4	main
sellepärast	doc_744962874537_item	2847476	et	3	main
et	doc_744962874537_item	2847477	et	3	main
talle	doc_744962874537_item	2847478	et	4	main
mitte	doc_744962874537_item	2847479	et	3	main
oma	doc_744962874537_item	2847482	et	4	main
on	doc_744962874537_item	2847486	et	4	main
tähtis	doc_744962874537_item	2847488	et	4	main
tahaks	doc_744962874537_item	2847430	et	3	main
näiteks	doc_744962874537_item	2847442	et	4	main
iseloom	doc_744962874537_item	2847447	et	3	main
kui	doc_744962874537_item	2847465	et	3	main
elus	doc_744962874537_item	2847475	et	4	main
haritud	doc_744962874537_item	2847490	et	4	main
inimene	doc_744962874537_item	2847491	et	3	main
saab	doc_744962874537_item	2847492	et	3	main
tavaliselt	doc_744962874537_item	2847493	et	4	main
ka	doc_744962874537_item	2847494	et	3	main
parema	doc_744962874537_item	2847495	et	4	main
töökoha	doc_744962874537_item	2847496	et	4	main
span	doc_744962874537_item	2847497	et	4	main
vanemad	doc_744962874537_item	2847498	et	4	main
on	doc_744962874537_item	2847499	et	4	main
ka	doc_744962874537_item	2847500	et	3	main
tähtis	doc_744962874537_item	2847501	et	4	main
sest	doc_744962874537_item	2847502	et	4	main
et	doc_744962874537_item	2847503	et	3	main
vanemad	doc_744962874537_item	2847504	et	4	main
on	doc_744962874537_item	2847505	et	4	main
väga	doc_744962874537_item	2847506	et	3	main
oluline	doc_744962874537_item	2847507	et	4	main
osa	doc_744962874537_item	2847508	et	4	main
inimese	doc_744962874537_item	2847509	et	4	main
elus	doc_744962874537_item	2847510	et	4	main
ja	doc_744962874537_item	2847511	et	3	main
ma	doc_744962874537_item	2847512	et	3	main
arvan	doc_744962874537_item	2847513	et	3	main
et	doc_744962874537_item	2847514	et	3	main
iga	doc_744962874537_item	2847515	et	4	main
inimene	doc_744962874537_item	2847516	et	3	main
peab	doc_744962874537_item	2847517	et	4	main
hoolitsema	doc_744962874537_item	2847518	et	4	main
oma	doc_744962874537_item	2847519	et	4	main
vanematele	doc_744962874537_item	2847520	et	4	main
essee	doc_744962874538_item	2847522	et	4	main
inimene	doc_744962874538_item	2847529	et	3	main
vanemad	doc_744962874538_item	2847541	et	4	main
sest	doc_744962874538_item	2847542	et	4	main
nad	doc_744962874538_item	2847543	et	3	main
on	doc_744962874538_item	2847544	et	4	main
väga	doc_744962874538_item	2847545	et	3	main
elus	doc_744962874538_item	2847548	et	4	main
väga	doc_744962874538_item	2847552	et	3	main
on	doc_744962874538_item	2847554	et	4	main
minu	doc_744962874538_item	2847561	et	3	main
arvates	doc_744962874538_item	2847562	et	4	main
et	doc_744962874538_item	2847563	et	3	main
väga	doc_744962874538_item	2847564	et	3	main
tähtis	doc_744962874538_item	2847565	et	4	main
inimestega	doc_744962874538_item	2847577	et	3	main
sõpru	doc_744962874537_item	2847469	et	3	main
nii	doc_744962874537_item	2847470	et	3	main
on	doc_744962874537_item	2847472	et	4	main
kegile	doc_744962874537_item	2847480	et	4	main
span	doc_744962874537_item	2847484	et	4	main
sest	doc_744962874537_item	2847489	et	4	main
sest	doc_744962874538_item	2847527	et	4	main
ka	doc_744962874538_item	2847532	et	3	main
minu	doc_744962874538_item	2847547	et	3	main
tähtis	doc_744962874538_item	2847553	et	4	main
sõbrad	doc_744962874538_item	2847555	et	3	main
sest	doc_744962874538_item	2847556	et	4	main
nad	doc_744962874538_item	2847557	et	3	main
sul	doc_744962874538_item	2847569	et	3	main
ja	doc_744962874539_item	2847621	et	3	main
sellest	doc_744962874539_item	2847624	et	4	main
tema	doc_744962874539_item	2847640	et	4	main
perekonnas	doc_744962874539_item	2847643	et	4	main
usalduslikud	doc_744962874539_item	2847648	et	3	main
ja	doc_744962874539_item	2847654	et	3	main
sest	doc_744962874539_item	2847670	et	4	main
et	doc_744962874539_item	2847671	et	3	main
millal	doc_744962874539_item	2847672	et	3	main
inimene	doc_744962874539_item	2847673	et	3	main
ei	doc_744962874539_item	2847676	et	4	main
span	doc_744962874539_item	2847681	et	4	main
uus	doc_744962874540_item	2847682	et	3	main
dokument	doc_744962874540_item	2847683	et	3	main
minu	doc_744962874540_item	2847684	et	3	main
arvates	doc_744962874540_item	2847685	et	4	main
et	doc_744962874540_item	2847686	et	3	main
mõjutab	doc_744962874540_item	2847687	et	3	main
elu	doc_744962874540_item	2847688	et	4	main
sünnikoht	doc_744962874540_item	2847689	et	3	main
sündinud	doc_744962874540_item	2847694	et	4	main
sõbrad	doc_744962874540_item	2847721	et	3	main
ole	doc_744962874540_item	2847725	et	4	main
span	doc_744962874540_item	2847727	et	4	main
ja	doc_744962874540_item	2847728	et	3	main
kui	doc_744962874540_item	2847729	et	3	main
sul	doc_744962874540_item	2847730	et	3	main
on	doc_744962874540_item	2847731	et	4	main
töökoha	doc_744962874540_item	2847739	et	4	main
ja	doc_744962874540_item	2847740	et	3	main
palju	doc_744962874540_item	2847743	et	4	main
inimese	doc_744962874540_item	2847750	et	4	main
ka	doc_744962874540_item	2847752	et	3	main
sest	doc_744962874540_item	2847755	et	4	main
ma	doc_744962874540_item	2847771	et	3	main
mõjutame	doc_744962874540_item	2847775	et	3	main
saatust	doc_744962874540_item	2847777	et	4	main
span	doc_744962874540_item	2847778	et	4	main
on	doc_744962874541_item	2847787	et	4	main
ka	doc_744962874541_item	2847788	et	3	main
tähtis	doc_744962874541_item	2847789	et	4	main
toimuvad	doc_744962874541_item	2847793	et	4	main
kergem	doc_744962874541_item	2847806	et	4	main
oma	doc_744962874541_item	2847807	et	4	main
sest	doc_744962874541_item	2847814	et	4	main
neiul	doc_744962874541_item	2847817	et	4	main
raskem	doc_744962874541_item	2847818	et	4	main
haritud	doc_744962874538_item	2847528	et	4	main
saab	doc_744962874538_item	2847530	et	3	main
väga	doc_744962874538_item	2847538	et	3	main
minu	doc_744962874538_item	2847549	et	3	main
et	doc_744962874538_item	2847551	et	3	main
mind	doc_744962874538_item	2847559	et	4	main
aru	doc_744962874538_item	2847560	et	4	main
kui	doc_744962874538_item	2847568	et	3	main
suhtlemine	doc_744962874538_item	2847575	et	4	main
teiste	doc_744962874538_item	2847576	et	4	main
kergem	doc_744962874538_item	2847579	et	4	main
väga	doc_744962874538_item	2847583	et	3	main
tähtis	doc_744962874538_item	2847584	et	4	main
on	doc_744962874538_item	2847585	et	4	main
sünnikoht	doc_744962874538_item	2847586	et	3	main
sellepärast	doc_744962874538_item	2847587	et	3	main
et	doc_744962874538_item	2847588	et	3	main
kus	doc_744962874538_item	2847589	et	3	main
oled	doc_744962874538_item	2847590	et	3	main
sündinud	doc_744962874538_item	2847591	et	4	main
sest	doc_744962874538_item	2847592	et	4	main
see	doc_744962874538_item	2847593	et	3	main
mõjutab	doc_744962874538_item	2847594	et	3	main
su	doc_744962874538_item	2847595	et	3	main
tulevikut	doc_744962874538_item	2847596	et	4	main
uus	doc_744962874539_item	2847598	et	3	main
elu	doc_744962874538_item	2847597	et	4	main
dokument	doc_744962874539_item	2847599	et	3	main
minu	doc_744962874539_item	2847600	et	3	main
arust	doc_744962874539_item	2847601	et	4	main
kõige	doc_744962874539_item	2847602	et	4	main
rohkem	doc_744962874539_item	2847603	et	4	main
mõjutavad	doc_744962874539_item	2847604	et	4	main
inimese	doc_744962874539_item	2847605	et	4	main
elu	doc_744962874539_item	2847606	et	4	main
on	doc_744962874539_item	2847607	et	4	main
sünnikoht	doc_744962874539_item	2847608	et	3	main
ja	doc_744962874539_item	2847609	et	3	main
elukoht	doc_744962874539_item	2847610	et	3	main
sellepärast	doc_744962874539_item	2847611	et	3	main
see	doc_744962874539_item	2847612	et	3	main
on	doc_744962874539_item	2847613	et	4	main
isama	doc_744962874539_item	2847614	et	4	main
ma	doc_744962874539_item	2847615	et	3	main
minu	doc_744962874538_item	2847580	et	3	main
kindel	doc_744962874539_item	2847617	et	3	main
õppima	doc_744962874539_item	2847620	et	3	main
et	doc_744962874539_item	2847634	et	3	main
elus	doc_744962874539_item	2847638	et	4	main
on	doc_744962874539_item	2847644	et	4	main
heasoovlik	doc_744962874539_item	2847645	et	3	main
atmosfäär	doc_744962874539_item	2847646	et	3	main
kasvab	doc_744962874539_item	2847651	et	3	main
veel	doc_744962874539_item	2847656	et	4	main
saatus	doc_744962874539_item	2847664	et	3	main
ka	doc_744962874539_item	2847665	et	3	main
mängib	doc_744962874539_item	2847666	et	3	main
roll	doc_744962874539_item	2847667	et	3	main
inimese	doc_744962874539_item	2847668	et	4	main
ta	doc_744962874539_item	2847675	et	4	main
vali	doc_744962874539_item	2847677	et	4	main
riik	doc_744962874539_item	2847678	et	3	main
ja	doc_744962874539_item	2847679	et	3	main
perekond	doc_744962874539_item	2847680	et	3	main
oled	doc_744962874540_item	2847693	et	3	main
väga	doc_744962874540_item	2847695	et	3	main
milline	doc_744962874540_item	2847697	et	3	main
tähendab	doc_744962874540_item	2847700	et	3	main
hea	doc_744962874540_item	2847732	et	4	main
haridus	doc_744962874540_item	2847733	et	3	main
siis	doc_744962874540_item	2847734	et	3	main
sa	doc_744962874540_item	2847735	et	3	main
sul	doc_744962874540_item	2847741	et	3	main
raha	doc_744962874540_item	2847744	et	4	main
see	doc_744962874540_item	2847745	et	3	main
mõjutab	doc_744962874540_item	2847746	et	3	main
ka	doc_744962874540_item	2847747	et	3	main
juhus	doc_744962874540_item	2847754	et	4	main
me	doc_744962874540_item	2847774	et	4	main
mis	doc_744962874541_item	2847780	et	4	main
mõjutab	doc_744962874541_item	2847781	et	3	main
tähtis	doc_744962874541_item	2847799	et	4	main
sest	doc_744962874541_item	2847800	et	4	main
elu	doc_744962874541_item	2847808	et	4	main
rahvus	doc_744962874541_item	2847810	et	3	main
on	doc_744962874541_item	2847811	et	4	main
väga	doc_744962874541_item	2847812	et	3	main
idamaal	doc_744962874541_item	2847816	et	4	main
nendel	doc_744962874541_item	2847827	et	4	main
väga	doc_744962874541_item	2847833	et	3	main
et	doc_744962874542_item	2847869	et	3	main
puhur	doc_744962874542_item	2847870	et	3	main
muud	doc_744962874542_item	2847875	et	4	main
võimsuse	doc_744962874542_item	2847877	et	4	main
toimingud	doc_744962874542_item	2847878	et	3	main
kasutamise	doc_744962874542_item	2847879	et	4	main
tõmmake	doc_744962874542_item	2847885	et	3	main
mitte	doc_744962874542_item	2847889	et	3	main
ärge	doc_744962874542_item	2847895	et	3	main
püüdke	doc_744962874542_item	2847896	et	3	main
ise	doc_744962874542_item	2847897	et	4	main
kohvimasin	doc_744962874543_item	2847903	et	3	main
olen	doc_744962874539_item	2847616	et	3	main
veendunud	doc_744962874539_item	2847633	et	4	main
kõige	doc_744962874539_item	2847635	et	4	main
tähtsam	doc_744962874539_item	2847636	et	4	main
kui	doc_744962874539_item	2847642	et	3	main
väga	doc_744962874539_item	2847652	et	3	main
enesekindelik	doc_744962874539_item	2847655	et	4	main
tähtis	doc_744962874539_item	2847658	et	4	main
inimene	doc_744962874539_item	2847661	et	3	main
tõenäoliselt	doc_744962874539_item	2847663	et	4	main
elus	doc_744962874539_item	2847669	et	4	main
sa	doc_744962874540_item	2847702	et	3	main
võid	doc_744962874540_item	2847703	et	4	main
elada	doc_744962874540_item	2847704	et	3	main
span	doc_744962874540_item	2847705	et	4	main
väga	doc_744962874540_item	2847706	et	3	main
oluline	doc_744962874540_item	2847707	et	4	main
ka	doc_744962874540_item	2847708	et	3	main
iseloom	doc_744962874540_item	2847709	et	3	main
sest	doc_744962874540_item	2847710	et	4	main
kui	doc_744962874540_item	2847711	et	3	main
sul	doc_744962874540_item	2847712	et	3	main
on	doc_744962874540_item	2847713	et	4	main
hea	doc_744962874540_item	2847714	et	4	main
sõbralik	doc_744962874540_item	2847715	et	3	main
iseloom	doc_744962874540_item	2847716	et	3	main
siis	doc_744962874540_item	2847717	et	3	main
sul	doc_744962874540_item	2847718	et	3	main
on	doc_744962874540_item	2847719	et	4	main
palju	doc_744962874540_item	2847720	et	4	main
ja	doc_744962874540_item	2847722	et	3	main
üksi	doc_744962874540_item	2847726	et	4	main
hea	doc_744962874540_item	2847738	et	4	main
on	doc_744962874540_item	2847757	et	4	main
elu	doc_744962874540_item	2847756	et	4	main
väga	doc_744962874540_item	2847758	et	3	main
ettearvamatu	doc_744962874540_item	2847759	et	4	main
span	doc_744962874540_item	2847760	et	4	main
aga	doc_744962874540_item	2847761	et	3	main
ma	doc_744962874540_item	2847762	et	3	main
ei	doc_744962874540_item	2847763	et	4	main
arva	doc_744962874540_item	2847764	et	4	main
et	doc_744962874540_item	2847765	et	3	main
saatus	doc_744962874540_item	2847766	et	3	main
võib	doc_744962874540_item	2847767	et	3	main
mõjutada	doc_744962874540_item	2847768	et	3	main
meie	doc_744962874540_item	2847769	et	4	main
elus	doc_744962874540_item	2847770	et	4	main
meie	doc_744962874540_item	2847776	et	4	main
essee	doc_744962874541_item	2847779	et	4	main
rohkem	doc_744962874541_item	2847785	et	4	main
paljud	doc_744962874541_item	2847791	et	3	main
juhuse	doc_744962874541_item	2847794	et	3	main
haridus	doc_744962874541_item	2847796	et	3	main
väga	doc_744962874541_item	2847798	et	3	main
on	doc_744962874541_item	2847803	et	4	main
on	doc_744962874541_item	2847805	et	4	main
tähtis	doc_744962874541_item	2847813	et	4	main
end	doc_744962874541_item	2847819	et	4	main
näidata	doc_744962874541_item	2847821	et	4	main
on	doc_744962874541_item	2847823	et	4	main
väga	doc_744962874541_item	2847824	et	3	main
tähtsad	doc_744962874541_item	2847825	et	3	main
sest	doc_744962874541_item	2847826	et	4	main
sünnikoht	doc_744962874541_item	2847831	et	3	main
sest	doc_744962874541_item	2847835	et	4	main
on	doc_744962874541_item	2847841	et	4	main
rohkem	doc_744962874541_item	2847842	et	4	main
kasutusjuhend	doc_744962874542_item	2847849	et	3	main
puhur	doc_744962874542_item	2847851	et	3	main
välja	doc_744962874542_item	2847853	et	4	main
puhur	doc_744962874542_item	2847855	et	3	main
vajalikule	doc_744962874542_item	2847856	et	3	main
kohale	doc_744962874542_item	2847857	et	4	main
pistke	doc_744962874542_item	2847858	et	3	main
pistik	doc_744962874542_item	2847859	et	3	main
peab	doc_744962874542_item	2847862	et	4	main
sisse	doc_744962874542_item	2847863	et	4	main
lülitama	doc_744962874542_item	2847864	et	4	main
tähendab	doc_744962874542_item	2847868	et	3	main
töötab	doc_744962874542_item	2847872	et	3	main
valige	doc_744962874542_item	2847874	et	3	main
välja	doc_744962874542_item	2847888	et	4	main
kinni	doc_744962874542_item	2847890	et	3	main
elektriohtlik	doc_744962874542_item	2847901	et	3	main
kallake	doc_744962874543_item	2847906	et	4	main
puistake	doc_744962874543_item	2847910	et	3	main
kohvi	doc_744962874543_item	2847911	et	4	main
3	doc_744962874543_item	2847912	et	2	main
pistke	doc_744962874543_item	2847913	et	3	main
pistik	doc_744962874543_item	2847914	et	3	main
ja	doc_744962874543_item	2847926	et	3	main
pärast	doc_744962874543_item	2847927	et	4	main
tohi	doc_744962874543_item	2847934	et	4	main
1	doc_744962874543_item	2847935	et	2	main
kasutage	doc_744962874543_item	2847937	et	3	main
3	doc_744962874543_item	2847946	et	2	main
span	doc_744962874544_item	2847980	et	4	main
vanematega	doc_744962874544_item	2847989	et	4	main
sellepärast	doc_744962874544_item	2847990	et	3	main
nad	doc_744962874544_item	2847991	et	3	main
tähtis	doc_744962874544_item	2848001	et	4	main
tark	doc_744962874544_item	2848003	et	3	main
inimene	doc_744962874544_item	2848004	et	3	main
võib	doc_744962874544_item	2848005	et	3	main
saada	doc_744962874544_item	2848006	et	4	main
saa	doc_744962874544_item	2848014	et	4	main
tähtis	doc_744962874544_item	2848023	et	4	main
sest	doc_744962874544_item	2848024	et	4	main
korralik	doc_744962874544_item	2848025	et	3	main
5	doc_744962874544_item	2848031	et	2	main
sündis	doc_744962874544_item	2848040	et	3	main
haridust	doc_744962874544_item	2848048	et	4	main
jõukased	doc_744962874544_item	2848053	et	3	main
inimese	doc_744962874545_item	2848062	et	4	main
elu	doc_744962874545_item	2848063	et	4	main
sõbralik	doc_744962874545_item	2848073	et	3	main
mitte	doc_744962874545_item	2848075	et	3	main
inimene	doc_744962874545_item	2848077	et	3	main
talle	doc_744962874545_item	2848079	et	4	main
essee	doc_744962874546_item	2848127	et	4	main
mina	doc_744962874546_item	2848128	et	4	main
elu	doc_744962874546_item	2848134	et	4	main
meie	doc_744962874546_item	2848143	et	4	main
on	doc_744962874546_item	2848151	et	4	main
jne	doc_744962874546_item	2848159	et	4	main
suhtub	doc_744962874546_item	2848171	et	3	main
tuleviku	doc_744962874546_item	2848195	et	4	main
töökoht	doc_744962874546_item	2848196	et	3	main
2006	doc_75394297594_item	2848210	et	2	main
mõjul	doc_744962874541_item	2847828	et	4	main
kujundatakse	doc_744962874541_item	2847829	et	3	main
sünnitud	doc_744962874541_item	2847839	et	4	main
inimesel	doc_744962874541_item	2847836	et	3	main
puhuri	doc_744962874542_item	2847848	et	3	main
punane	doc_744962874542_item	2847865	et	4	main
juba	doc_744962874542_item	2847871	et	3	main
programmivalija	doc_744962874542_item	2847882	et	4	main
nullasendisse	doc_744962874542_item	2847883	et	3	main
nüüd	doc_744962874542_item	2847884	et	4	main
seinakontaktist	doc_744962874542_item	2847887	et	3	main
katta	doc_744962874542_item	2847891	et	3	main
vee	doc_744962874542_item	2847893	et	3	main
parandada	doc_744962874542_item	2847898	et	3	main
see	doc_744962874542_item	2847899	et	3	main
on	doc_744962874542_item	2847900	et	4	main
seinakontakti	doc_744962874543_item	2847915	et	4	main
4	doc_744962874543_item	2847916	et	2	main
nuppule	doc_744962874543_item	2847918	et	4	main
seda	doc_744962874543_item	2847920	et	3	main
pistik	doc_744962874543_item	2847929	et	3	main
ärge	doc_744962874543_item	2847936	et	3	main
ärge	doc_744962874543_item	2847940	et	3	main
töötavat	doc_744962874543_item	2847942	et	4	main
ilma	doc_744962874543_item	2847944	et	4	main
katlakivist	doc_744962874543_item	2847954	et	4	main
hoidke	doc_744962874543_item	2847956	et	3	main
eest	doc_744962874543_item	2847958	et	4	main
iseloom	doc_744962874544_item	2847962	et	3	main
väga	doc_744962874544_item	2847964	et	3	main
sest	doc_744962874544_item	2847966	et	4	main
otsustav	doc_744962874544_item	2847967	et	4	main
ja	doc_744962874544_item	2847968	et	3	main
ettevõtlik	doc_744962874544_item	2847969	et	3	main
inimene	doc_744962874544_item	2847970	et	3	main
võib	doc_744962874544_item	2847971	et	3	main
teha	doc_744962874544_item	2847972	et	3	main
väga	doc_744962874544_item	2847973	et	3	main
palju	doc_744962874544_item	2847974	et	4	main
oma	doc_744962874544_item	2847986	et	4	main
sõprade	doc_744962874544_item	2847987	et	3	main
ja	doc_744962874544_item	2847988	et	3	main
tarkus	doc_744962874544_item	2847998	et	4	main
ilma	doc_744962874544_item	2848010	et	4	main
hariduseta	doc_744962874544_item	2848011	et	3	main
inimene	doc_744962874544_item	2848012	et	3	main
span	doc_744962874544_item	2848018	et	4	main
puhas	doc_744962874544_item	2848026	et	3	main
hästi	doc_744962874544_item	2848029	et	3	main
kui	doc_744962874544_item	2848038	et	3	main
natuke	doc_744962874544_item	2848044	et	4	main
saada	doc_744962874544_item	2848046	et	4	main
hea	doc_744962874544_item	2848047	et	4	main
ela	doc_744962874544_item	2848052	et	4	main
span	doc_744962874544_item	2848055	et	4	main
dokument	doc_744962874545_item	2848057	et	3	main
arvates	doc_744962874545_item	2848059	et	4	main
iseloom	doc_744962874545_item	2848060	et	3	main
inimesel	doc_744962874545_item	2848067	et	3	main
teiste	doc_744962874545_item	2848082	et	4	main
inimestega	doc_744962874545_item	2848083	et	3	main
niisugune	doc_744962874545_item	2848084	et	3	main
inimene	doc_744962874545_item	2848085	et	3	main
kõige	doc_744962874546_item	2848135	et	4	main
sest	doc_744962874546_item	2848137	et	4	main
see	doc_744962874546_item	2848139	et	3	main
on	doc_744962874546_item	2848140	et	4	main
väga	doc_744962874546_item	2848141	et	3	main
töö	doc_744962874546_item	2848158	et	4	main
on	doc_744962874546_item	2848164	et	4	main
ka	doc_744962874546_item	2848165	et	3	main
väga	doc_744962874546_item	2848166	et	3	main
ma	doc_744962874546_item	2848197	et	3	main
arvan	doc_744962874546_item	2848198	et	3	main
et	doc_744962874546_item	2848199	et	3	main
suur	doc_744962874546_item	2848200	et	3	main
palk	doc_744962874546_item	2848201	et	3	main
sõltub	doc_744962874546_item	2848202	et	3	main
haridust	doc_744962874546_item	2848203	et	4	main
inimeste	doc_744962874546_item	2848204	et	3	main
slaavi	doc_75394297594_item	2848215	et	3	main
linnas	doc_744962874541_item	2847840	et	4	main
võtke	doc_744962874542_item	2847850	et	3	main
panellis	doc_744962874542_item	2847861	et	4	main
lamp	doc_744962874542_item	2847866	et	3	main
võimalikud	doc_744962874542_item	2847876	et	3	main
pärast	doc_744962874542_item	2847880	et	4	main
keerake	doc_744962874542_item	2847881	et	3	main
1	doc_744962874543_item	2847905	et	2	main
vett	doc_744962874543_item	2847907	et	3	main
reservuarile	doc_744962874543_item	2847908	et	4	main
2	doc_744962874543_item	2847909	et	2	main
vajutage	doc_744962874543_item	2847917	et	3	main
kohv	doc_744962874543_item	2847923	et	3	main
kokku	doc_744962874543_item	2847925	et	3	main
tühjalt	doc_744962874543_item	2847938	et	4	main
jätke	doc_744962874543_item	2847941	et	4	main
seadet	doc_744962874543_item	2847943	et	4	main
ärge	doc_744962874543_item	2847947	et	3	main
kasutage	doc_744962874543_item	2847948	et	3	main
vaja	doc_744962874543_item	2847951	et	4	main
puhustada	doc_744962874543_item	2847952	et	4	main
5	doc_744962874543_item	2847955	et	2	main
laste	doc_744962874543_item	2847957	et	4	main
uus	doc_744962874544_item	2847959	et	3	main
1	doc_744962874544_item	2847961	et	2	main
oma	doc_744962874544_item	2847975	et	4	main
karjääri	doc_744962874544_item	2847976	et	4	main
ja	doc_744962874544_item	2847977	et	3	main
elu	doc_744962874544_item	2847978	et	4	main
on	doc_744962874544_item	2847992	et	4	main
väga	doc_744962874544_item	2847993	et	3	main
on	doc_744962874544_item	2847999	et	4	main
hea	doc_744962874544_item	2848015	et	4	main
ametil	doc_744962874544_item	2848016	et	3	main
töötada	doc_744962874544_item	2848017	et	3	main
valimus	doc_744962874544_item	2848020	et	4	main
inimene	doc_744962874544_item	2848027	et	3	main
näiteks	doc_744962874544_item	2848037	et	4	main
inimene	doc_744962874544_item	2848039	et	3	main
ei	doc_744962874544_item	2848051	et	4	main
minu	doc_744962874545_item	2848058	et	3	main
mõjutab	doc_744962874545_item	2848061	et	3	main
on	doc_744962874545_item	2848072	et	4	main
ja	doc_744962874545_item	2848074	et	3	main
äkiline	doc_744962874545_item	2848076	et	3	main
alati	doc_744962874545_item	2848086	et	4	main
tähtkuju	doc_744962874545_item	2848121	et	4	main
mõjuta	doc_744962874545_item	2848123	et	4	main
seda	doc_744962874545_item	2848124	et	3	main
rohkem	doc_744962874546_item	2848136	et	4	main
palju	doc_744962874546_item	2848152	et	4	main
näiteks	doc_744962874546_item	2848155	et	4	main
leida	doc_744962874546_item	2848156	et	3	main
hea	doc_744962874546_item	2848157	et	4	main
inimene	doc_744962874546_item	2848170	et	3	main
57	doc_75394297594_item	2848208	et	2	main
a	doc_75394297594_item	2848211	et	4	main
vene	doc_75394297594_item	2848220	et	4	main
aspekt	doc_75394297594_item	2848225	et	3	main
vnemaalt	doc_75394297594_item	2848234	et	4	main
usa-st	doc_75394297594_item	2848235	et	3	main
ja	doc_75394297594_item	2848236	et	3	main
eestist	doc_75394297594_item	2848237	et	3	main
seminari	doc_75394297594_item	2848238	et	4	main
eesmärk	doc_75394297594_item	2848239	et	3	main
kogemust	doc_75394297594_item	2848247	et	3	main
ning	doc_75394297594_item	2848249	et	3	main
avatud	doc_75394297594_item	2848266	et	4	main
demokraatliku	doc_75394297594_item	2848267	et	3	main
teadvuses	doc_75394297594_item	2848274	et	4	main
pidada	doc_75394297594_item	2848279	et	4	main
ülikooli	doc_75394297594_item	2848281	et	4	main
isa	doc_75394297594_item	2848289	et	4	main
andrejev	doc_75394297594_item	2848291	et	4	main
gümnaasiumi	doc_75394297594_item	2848305	et	4	main
ja	doc_75394297594_item	2848306	et	3	main
läks	doc_75394297594_item	2848307	et	3	main
väga	doc_75394297594_item	2848321	et	3	main
nkondakovi	doc_75394297594_item	2848323	et	4	main
instituudi	doc_75394297594_item	2848324	et	3	main
oli	doc_75394297594_item	2848333	et	3	main
vabanemist	doc_75394297594_item	2848344	et	4	main
sai	doc_75394297594_item	2848345	et	4	main
juhend	doc_744962874543_item	2847902	et	3	main
kasutamine	doc_744962874543_item	2847904	et	4	main
pärast	doc_744962874543_item	2847919	et	4	main
oodake	doc_744962874543_item	2847921	et	3	main
keelamine	doc_744962874543_item	2847932	et	4	main
ei	doc_744962874543_item	2847933	et	4	main
2	doc_744962874543_item	2847939	et	2	main
4	doc_744962874543_item	2847950	et	2	main
tuleme	doc_744962874544_item	2847983	et	3	main
elu	doc_744962874544_item	2847984	et	4	main
mööda	doc_744962874544_item	2847985	et	4	main
span	doc_744962874544_item	2847995	et	4	main
väga	doc_744962874544_item	2848000	et	3	main
sest	doc_744962874544_item	2848002	et	4	main
ei	doc_744962874544_item	2848013	et	4	main
4	doc_744962874544_item	2848019	et	2	main
kuni	doc_744962874543_item	2847922	et	3	main
kevitas	doc_744962874543_item	2847924	et	4	main
tõmmake	doc_744962874543_item	2847928	et	3	main
seinakontakti	doc_744962874543_item	2847930	et	4	main
välja	doc_744962874543_item	2847931	et	4	main
järelevalveta	doc_744962874543_item	2847945	et	3	main
niiskust	doc_744962874543_item	2847949	et	4	main
aeg-ajalt	doc_744962874543_item	2847953	et	4	main
dokument	doc_744962874544_item	2847960	et	3	main
on	doc_744962874544_item	2847963	et	4	main
tähtis	doc_744962874544_item	2847965	et	4	main
jaoks	doc_744962874544_item	2847979	et	4	main
2	doc_744962874544_item	2847981	et	2	main
me	doc_744962874544_item	2847982	et	4	main
tähtsad	doc_744962874544_item	2847994	et	3	main
3	doc_744962874544_item	2847996	et	2	main
muidugi	doc_744962874544_item	2847997	et	4	main
hea	doc_744962874544_item	2848007	et	4	main
haridust	doc_744962874544_item	2848008	et	4	main
kuna	doc_744962874544_item	2848009	et	3	main
on	doc_744962874544_item	2848021	et	4	main
mõjub	doc_744962874544_item	2848028	et	3	main
span	doc_744962874544_item	2848030	et	4	main
inimese	doc_744962874544_item	2848032	et	4	main
sõltub	doc_744962874544_item	2848034	et	3	main
külas	doc_744962874544_item	2848042	et	3	main
raskem	doc_744962874544_item	2848045	et	4	main
külas	doc_744962874544_item	2848050	et	3	main
inimesed	doc_744962874544_item	2848054	et	3	main
uus	doc_744962874545_item	2848056	et	3	main
rohkem	doc_744962874545_item	2848065	et	4	main
kui	doc_744962874545_item	2848066	et	3	main
on	doc_744962874545_item	2848068	et	4	main
hea	doc_744962874545_item	2848069	et	4	main
iseloom	doc_744962874545_item	2848070	et	3	main
siis	doc_744962874545_item	2848078	et	3	main
kergem	doc_744962874545_item	2848080	et	4	main
suhelda	doc_744962874545_item	2848081	et	4	main
ka	doc_744962874544_item	2848022	et	3	main
elu	doc_744962874544_item	2848033	et	4	main
sünnikohast	doc_744962874544_item	2848035	et	4	main
ka	doc_744962874544_item	2848036	et	3	main
vene	doc_744962874544_item	2848041	et	4	main
temale	doc_744962874544_item	2848043	et	3	main
vene	doc_744962874544_item	2848049	et	4	main
kõige	doc_744962874545_item	2848064	et	4	main
ta	doc_744962874545_item	2848071	et	4	main
leida	doc_744962874545_item	2848087	et	3	main
sõpru	doc_744962874545_item	2848088	et	3	main
ja	doc_744962874545_item	2848089	et	3	main
inimeseid	doc_744962874545_item	2848090	et	4	main
kes	doc_744962874545_item	2848091	et	4	main
aitavad	doc_744962874545_item	2848092	et	4	main
talle	doc_744962874545_item	2848093	et	4	main
lahutada	doc_744962874545_item	2848094	et	3	main
probleemid	doc_744962874545_item	2848095	et	3	main
span	doc_744962874545_item	2848096	et	4	main
minu	doc_744962874545_item	2848097	et	3	main
arvates	doc_744962874545_item	2848098	et	4	main
tähtkuju	doc_744962874545_item	2848099	et	4	main
ei	doc_744962874545_item	2848100	et	4	main
mõjuta	doc_744962874545_item	2848101	et	4	main
inimese	doc_744962874545_item	2848102	et	4	main
elu	doc_744962874545_item	2848103	et	4	main
kui	doc_744962874545_item	2848104	et	3	main
inimene	doc_744962874545_item	2848105	et	3	main
usub	doc_744962874545_item	2848106	et	3	main
saatuses	doc_744962874545_item	2848107	et	4	main
siis	doc_744962874545_item	2848108	et	3	main
olla	doc_744962874545_item	2848110	et	3	main
võib	doc_744962874545_item	2848109	et	3	main
tähtkuju	doc_744962874545_item	2848111	et	4	main
mõjutab	doc_744962874545_item	2848112	et	3	main
teda	doc_744962874545_item	2848113	et	4	main
elu	doc_744962874545_item	2848114	et	4	main
kõikel	doc_744962874545_item	2848115	et	4	main
inimestel	doc_744962874545_item	2848116	et	3	main
on	doc_744962874545_item	2848117	et	4	main
samasugune	doc_744962874545_item	2848118	et	3	main
võimalused	doc_744962874545_item	2848119	et	3	main
ja	doc_744962874545_item	2848120	et	3	main
arvan	doc_744962874546_item	2848129	et	3	main
et	doc_744962874546_item	2848130	et	3	main
tarkus	doc_744962874546_item	2848131	et	4	main
mõjutab	doc_744962874546_item	2848132	et	3	main
elus	doc_744962874546_item	2848144	et	4	main
ei	doc_744962874545_item	2848122	et	4	main
võimalusi	doc_744962874545_item	2848125	et	3	main
span	doc_744962874545_item	2848126	et	4	main
inimese	doc_744962874546_item	2848133	et	4	main
tarkus	doc_744962874546_item	2848138	et	4	main
tähtis	doc_744962874546_item	2848142	et	4	main
võimalusi	doc_744962874546_item	2848153	et	3	main
elus	doc_744962874546_item	2848154	et	4	main
tähtis	doc_744962874546_item	2848167	et	4	main
ja	doc_744962874546_item	2848168	et	3	main
kui	doc_744962874546_item	2848169	et	3	main
teiega	doc_744962874546_item	2848172	et	3	main
inimestega	doc_744962874546_item	2848173	et	3	main
ma	doc_744962874546_item	2848174	et	3	main
arvan	doc_744962874546_item	2848175	et	3	main
et	doc_744962874546_item	2848176	et	3	main
raha	doc_744962874546_item	2848177	et	4	main
ei	doc_744962874546_item	2848178	et	4	main
mõjuta	doc_744962874546_item	2848179	et	4	main
inimese	doc_744962874546_item	2848180	et	4	main
elu	doc_744962874546_item	2848181	et	4	main
kõige	doc_744962874546_item	2848182	et	4	main
rohkem	doc_744962874546_item	2848183	et	4	main
kui	doc_744962874546_item	2848184	et	3	main
inimestel	doc_744962874546_item	2848185	et	3	main
on	doc_744962874546_item	2848186	et	4	main
hea	doc_744962874546_item	2848187	et	4	main
haridus	doc_744962874546_item	2848188	et	3	main
tal	doc_744962874546_item	2848189	et	3	main
on	doc_744962874546_item	2848190	et	4	main
palju	doc_744962874546_item	2848191	et	4	main
raha	doc_744962874546_item	2848192	et	4	main
tulevikus	doc_744962874546_item	2848193	et	4	main
tema	doc_744962874546_item	2848194	et	4	main
kui	doc_744962874546_item	2848145	et	3	main
inimesel	doc_744962874546_item	2848146	et	3	main
on	doc_744962874546_item	2848147	et	4	main
hea	doc_744962874546_item	2848148	et	4	main
haridus	doc_744962874546_item	2848149	et	3	main
tal	doc_744962874546_item	2848150	et	3	main
muidugi	doc_744962874546_item	2848160	et	4	main
sest	doc_744962874546_item	2848161	et	4	main
suhtlemine	doc_744962874546_item	2848162	et	4	main
see	doc_744962874546_item	2848163	et	3	main
filoloogia	doc_75394297594_item	2848216	et	4	main
korraldusel	doc_75394297594_item	2848218	et	4	main
teadusseminari	doc_75394297594_item	2848219	et	4	main
ajalooline	doc_75394297594_item	2848224	et	4	main
osalevad	doc_75394297594_item	2848227	et	4	main
teadlased	doc_75394297594_item	2848228	et	3	main
inglismaalt	doc_75394297594_item	2848229	et	3	main
emigratsiooni	doc_75394297594_item	2848246	et	4	main
emigratsiooniprotsessi	doc_75394297594_item	2848252	et	4	main
osalisi	doc_75394297594_item	2848255	et	4	main
suundumusi	doc_75394297594_item	2848256	et	4	main
teadusliku	doc_75394297594_item	2848258	et	3	main
ja	doc_75394297594_item	2848262	et	3	main
ühiskonna	doc_75394297594_item	2848268	et	4	main
arendada	doc_75394297594_item	2848272	et	3	main
ajaloo	doc_75394297594_item	2848283	et	4	main
tuli	doc_75394297594_item	2848292	et	4	main
vanematega	doc_75394297594_item	2848297	et	4	main
siin	doc_75394297594_item	2848300	et	4	main
tuntud	doc_75394297594_item	2848322	et	4	main
direktor	doc_75394297594_item	2848325	et	3	main
organid	doc_75394297594_item	2848328	et	3	main
natsivõimust	doc_75394297594_item	2848335	et	4	main
nandrejev	doc_75394297594_item	2848339	et	4	main
koha	doc_75394297594_item	2848352	et	4	main
poolt	doc_75394297594_item	2848358	et	4	main
austatud	doc_75394297594_item	2848379	et	4	main
ning	doc_758697966141_item	2848413	et	3	main
meelest	doc_758697966141_item	2848429	et	4	main
nii	doc_758697966141_item	2848433	et	3	main
jõudsin	doc_758697966141_item	2848439	et	3	main
ilmusid	doc_758697966141_item	2848454	et	4	main
siis	doc_758697966141_item	2848457	et	3	main
löödud	doc_758697966141_item	2848467	et	4	main
mind	doc_758697966141_item	2848475	et	4	main
häiris	doc_758697966141_item	2848476	et	3	main
aga	doc_758697966141_item	2848477	et	3	main
ainult	doc_758697966141_item	2848485	et	4	main
ei	doc_758697966141_item	2848526	et	4	main
mida	doc_758697966141_item	2848530	et	4	main
kohas	doc_758697966141_item	2848545	et	4	main
selge	doc_758697966141_item	2848554	et	4	main
kasutuses	doc_758697966141_item	2848567	et	4	main
kanal	doc_758697966141_item	2848572	et	4	main
2	doc_758697966141_item	2848573	et	2	main
oli	doc_758697966141_item	2848574	et	3	main
kui	doc_758697966141_item	2848581	et	3	main
subtiiter	doc_758697966141_item	2848594	et	4	main
suurem	doc_758697966141_item	2848600	et	4	main
33	doc_758697966141_item	2848603	et	2	main
inglisekeelse	doc_758697966141_item	2848605	et	3	main
olnud	doc_758697966141_item	2848609	et	4	main
veaks	doc_758697966141_item	2848618	et	4	main
see	doc_758697966141_item	2848619	et	3	main
et	doc_758697966141_item	2848620	et	3	main
tarkust	doc_744962874546_item	2848205	et	4	main
ametlik	doc_75394297594_item	2848206	et	3	main
kiri-kutse	doc_75394297594_item	2848207	et	4	main
oktoobril	doc_75394297594_item	2848209	et	3	main
tallinna	doc_75394297594_item	2848213	et	4	main
emigratsioon	doc_75394297594_item	2848221	et	3	main
leedust	doc_75394297594_item	2848232	et	4	main
saksamaalt	doc_75394297594_item	2848233	et	3	main
välja	doc_75394297594_item	2848251	et	4	main
terviklikke	doc_75394297594_item	2848253	et	3	main
ja	doc_75394297594_item	2848254	et	3	main
ja	doc_75394297594_item	2848271	et	3	main
oxford	doc_75394297594_item	2848280	et	4	main
l	doc_75394297594_item	2848286	et	4	main
nikolai	doc_75394297594_item	2848290	et	4	main
11aastaselt	doc_75394297594_item	2848293	et	4	main
vene	doc_75394297594_item	2848304	et	4	main
praha	doc_75394297594_item	2848332	et	4	main
vabastatud	doc_75394297594_item	2848334	et	4	main
kolm	doc_75394297594_item	2848336	et	3	main
oli	doc_75394297594_item	2848338	et	3	main
saksamaal	doc_75394297594_item	2848342	et	4	main
ta	doc_75394297594_item	2848346	et	4	main
cambridge	doc_75394297594_item	2848349	et	4	main
ülikooli	doc_75394297594_item	2848350	et	4	main
lektori	doc_75394297594_item	2848351	et	3	main
inglise	doc_75394297594_item	2848371	et	4	main
kolm	doc_75394297594_item	2848374	et	3	main
olid	doc_758697966141_item	2848408	et	4	main
etv	doc_758697966141_item	2848409	et	4	main
ja	doc_758697966141_item	2848410	et	3	main
kanal	doc_758697966141_item	2848411	et	4	main
2	doc_758697966141_item	2848412	et	2	main
ja	doc_758697966141_item	2848422	et	3	main
seriaal	doc_758697966141_item	2848425	et	3	main
oli	doc_758697966141_item	2848431	et	3	main
kui	doc_758697966141_item	2848435	et	3	main
heli	doc_758697966141_item	2848447	et	4	main
subtiitrid	doc_758697966141_item	2848453	et	4	main
tegi	doc_758697966141_item	2848462	et	4	main
paar	doc_758697966141_item	2848463	et	3	main
subtiiter	doc_758697966141_item	2848468	et	4	main
hilja	doc_758697966141_item	2848470	et	3	main
arvates	doc_758697966141_item	2848472	et	4	main
kanal	doc_758697966141_item	2848473	et	4	main
2	doc_758697966141_item	2848474	et	2	main
tiiter	doc_758697966141_item	2848481	et	3	main
nägin	doc_758697966141_item	2848484	et	3	main
toimub	doc_75394297594_item	2848212	et	3	main
ülikooli	doc_75394297594_item	2848214	et	4	main
osakonna	doc_75394297594_item	2848217	et	4	main
kultuuriline	doc_75394297594_item	2848222	et	4	main
ja	doc_75394297594_item	2848223	et	3	main
seminaril	doc_75394297594_item	2848226	et	3	main
itaaliast	doc_75394297594_item	2848230	et	4	main
on	doc_75394297594_item	2848240	et	4	main
uurida	doc_75394297594_item	2848241	et	3	main
ja	doc_75394297594_item	2848242	et	3	main
analüüsida	doc_75394297594_item	2848243	et	3	main
euroopas	doc_75394297594_item	2848248	et	3	main
läbi	doc_75394297594_item	2848257	et	4	main
ja	doc_75394297594_item	2848259	et	3	main
teadlaste-	doc_75394297594_item	2848261	et	3	main
luua	doc_75394297594_item	2848270	et	4	main
uusima	doc_75394297594_item	2848282	et	4	main
prof	doc_75394297594_item	2848284	et	4	main
catherine	doc_75394297594_item	2848285	et	4	main
andreyev	doc_75394297594_item	2848287	et	4	main
õpetajatest	doc_75394297594_item	2848296	et	4	main
eestisse	doc_75394297594_item	2848299	et	4	main
lõpetas	doc_75394297594_item	2848301	et	3	main
edasi	doc_75394297594_item	2848308	et	3	main
lätist	doc_75394297594_item	2848231	et	4	main
xx	doc_75394297594_item	2848244	et	4	main
sajandi	doc_75394297594_item	2848245	et	3	main
tuua	doc_75394297594_item	2848250	et	3	main
kultuurilise	doc_75394297594_item	2848260	et	4	main
ühiskonnategelastevahelise	doc_75394297594_item	2848263	et	4	main
dialoogi	doc_75394297594_item	2848264	et	4	main
arendada	doc_75394297594_item	2848265	et	3	main
ideesid	doc_75394297594_item	2848269	et	3	main
ühiskondlikus	doc_75394297594_item	2848273	et	4	main
eurointegratsiooni	doc_75394297594_item	2848275	et	4	main
malle	doc_75394297594_item	2848276	et	3	main
võtmeesinejaks	doc_75394297594_item	2848277	et	3	main
võib	doc_75394297594_item	2848278	et	3	main
kelle	doc_75394297594_item	2848288	et	4	main
koos	doc_75394297594_item	2848294	et	4	main
oma	doc_75394297594_item	2848295	et	4	main
elama	doc_75394297594_item	2848298	et	3	main
ta	doc_75394297594_item	2848302	et	4	main
tallinna	doc_75394297594_item	2848303	et	4	main
õppima	doc_75394297594_item	2848309	et	3	main
prahasse	doc_75394297594_item	2848310	et	4	main
kus	doc_75394297594_item	2848311	et	3	main
lõpetas	doc_75394297594_item	2848312	et	3	main
kaarli	doc_75394297594_item	2848313	et	4	main
filosoofia	doc_75394297594_item	2848315	et	4	main
ülikooli	doc_75394297594_item	2848314	et	4	main
teaduskonna	doc_75394297594_item	2848316	et	4	main
ajaloolasena	doc_75394297594_item	2848317	et	3	main
nandrejevist	doc_75394297594_item	2848318	et	4	main
sai	doc_75394297594_item	2848319	et	4	main
maailmas	doc_75394297594_item	2848320	et	3	main
kelle	doc_75394297594_item	2848326	et	4	main
nõukogude	doc_75394297594_item	2848327	et	3	main
arreteerisid	doc_75394297594_item	2848329	et	4	main
niipea	doc_75394297594_item	2848330	et	3	main
kui	doc_75394297594_item	2848331	et	3	main
aastat	doc_75394297594_item	2848337	et	3	main
tema	doc_75394297594_item	2848353	et	4	main
valvatud	doc_75394297594_item	2848359	et	4	main
meenutab	doc_75394297594_item	2848364	et	3	main
süzheega	doc_75394297594_item	2848366	et	4	main
neiuga	doc_75394297594_item	2848372	et	4	main
last	doc_75394297594_item	2848375	et	4	main
žanriks	doc_758697966141_item	2848414	et	2	main
seriaalid	doc_758697966141_item	2848416	et	3	main
tõsielusarjad	doc_758697966141_item	2848418	et	3	main
seriaal	doc_758697966141_item	2848420	et	3	main
robinsons	doc_758697966141_item	2848421	et	4	main
2	doc_758697966141_item	2848424	et	2	main
etvs	doc_758697966141_item	2848434	et	4	main
2s	doc_758697966141_item	2848438	et	4	main
ka	doc_758697966141_item	2848443	et	3	main
pilti	doc_758697966141_item	2848444	et	4	main
vaatama	doc_758697966141_item	2848445	et	3	main
sisu	doc_758697966141_item	2848450	et	4	main
olid	doc_758697966141_item	2848451	et	4	main
mõlemal	doc_758697966141_item	2848455	et	3	main
kui	doc_758697966141_item	2848458	et	3	main
korda	doc_758697966141_item	2848464	et	4	main
2	doc_758697966141_item	2848486	et	2	main
etvs	doc_758697966141_item	2848488	et	4	main
oli	doc_758697966141_item	2848521	et	3	main
kursiivis	doc_758697966141_item	2848525	et	3	main
isa	doc_758697966141_item	2848531	et	4	main
pojale	doc_758697966141_item	2848533	et	4	main
oli	doc_758697966141_item	2848534	et	3	main
kursiivis	doc_758697966141_item	2848537	et	3	main
mis	doc_758697966141_item	2848546	et	4	main
oli	doc_758697966141_item	2848547	et	3	main
loogiline	doc_758697966141_item	2848548	et	4	main
nõukogude	doc_75394297594_item	2848340	et	3	main
vanglas	doc_75394297594_item	2848341	et	3	main
peale	doc_75394297594_item	2848343	et	4	main
sõpradele	doc_75394297594_item	2848348	et	3	main
berliini	doc_75394297594_item	2848355	et	4	main
nõukogude	doc_75394297594_item	2848356	et	3	main
armee	doc_75394297594_item	2848357	et	4	main
ülikoolini	doc_75394297594_item	2848363	et	4	main
terava	doc_75394297594_item	2848365	et	3	main
inglismaal	doc_75394297594_item	2848368	et	4	main
abiellus	doc_75394297594_item	2848369	et	3	main
ta	doc_75394297594_item	2848370	et	4	main
sai	doc_75394297594_item	2848373	et	4	main
kellest	doc_75394297594_item	2848376	et	4	main
vanem	doc_75394297594_item	2848377	et	4	main
meie	doc_75394297594_item	2848378	et	4	main
läks	doc_75394297594_item	2848381	et	3	main
edukalt	doc_75394297594_item	2848382	et	4	main
elus	doc_75394297594_item	2848383	et	4	main
ajaloolasest	doc_75394297594_item	2848384	et	3	main
isa	doc_75394297594_item	2848385	et	4	main
konverentsi	doc_75394297594_item	2848387	et	4	main
teed	doc_75394297594_item	2848386	et	4	main
töökeeleks	doc_75394297594_item	2848388	et	4	main
on	doc_75394297594_item	2848389	et	4	main
vene	doc_75394297594_item	2848390	et	4	main
analüüs	doc_758697966141_item	2848392	et	3	main
keel	doc_75394297594_item	2848391	et	4	main
subtiitrite	doc_758697966141_item	2848393	et	4	main
anal	doc_758697966141_item	2848394	et	4	main
üüs	doc_758697966141_item	2848395	et	4	main
lindistasin	doc_758697966141_item	2848396	et	3	main
ja	doc_758697966141_item	2848397	et	3	main
vaatasin	doc_758697966141_item	2848398	et	3	main
kahe	doc_758697966141_item	2848400	et	3	main
läbi	doc_758697966141_item	2848399	et	4	main
erineva	doc_758697966141_item	2848401	et	4	main
žanriga	doc_758697966141_item	2848402	et	2	main
saateid	doc_758697966141_item	2848403	et	3	main
kahelt	doc_758697966141_item	2848404	et	4	main
erinevalt	doc_758697966141_item	2848405	et	4	main
telekanalilt	doc_758697966141_item	2848406	et	3	main
need	doc_758697966141_item	2848407	et	3	main
tänu	doc_75394297594_item	2848347	et	4	main
tee	doc_75394297594_item	2848354	et	4	main
sektorist	doc_75394297594_item	2848360	et	3	main
inglismaa	doc_75394297594_item	2848361	et	4	main
kuulsa	doc_75394297594_item	2848362	et	3	main
detektiivromaani	doc_75394297594_item	2848367	et	4	main
külaline	doc_75394297594_item	2848380	et	4	main
kanal	doc_758697966141_item	2848423	et	4	main
las	doc_758697966141_item	2848426	et	4	main
vegas	doc_758697966141_item	2848427	et	4	main
minu	doc_758697966141_item	2848428	et	3	main
hea	doc_758697966141_item	2848432	et	4	main
kanal	doc_758697966141_item	2848437	et	4	main
subtiitreid	doc_758697966141_item	2848440	et	4	main
ja	doc_758697966141_item	2848442	et	3	main
ja	doc_758697966141_item	2848448	et	3	main
subtiitri	doc_758697966141_item	2848449	et	4	main
kanalil	doc_758697966141_item	2848456	et	3	main
kõneleja	doc_758697966141_item	2848459	et	4	main
suu	doc_758697966141_item	2848460	et	4	main
etvs	doc_758697966141_item	2848465	et	4	main
liiga	doc_758697966141_item	2848469	et	4	main
kaadrisse	doc_758697966141_item	2848479	et	3	main
aga	doc_758697966141_item	2848482	et	3	main
olid	doc_758697966141_item	2848495	et	4	main
paksud	doc_758697966141_item	2848496	et	3	main
suurim	doc_758697966141_item	2848497	et	3	main
tähemärkide	doc_758697966141_item	2848498	et	3	main
arv	doc_758697966141_item	2848499	et	3	main
tsentreeritud	doc_758697966141_item	2848523	et	4	main
ei	doc_758697966141_item	2848539	et	4	main
viga	doc_758697966141_item	2848555	et	4	main
ka	doc_758697966141_item	2848566	et	3	main
teisiti	doc_758697966141_item	2848576	et	3	main
inglise	doc_758697966141_item	2848596	et	4	main
teksi	doc_758697966141_item	2848606	et	4	main
kaos	doc_758697966141_item	2848612	et	4	main
etvs	doc_758697966141_item	2848616	et	4	main
oli	doc_758697966141_item	2848617	et	3	main
kursiivis	doc_758697966141_item	2848630	et	3	main
oli	doc_758697966141_item	2848631	et	3	main
üks	doc_758697966141_item	2848636	et	3	main
korda	doc_758697966141_item	2848641	et	4	main
olnud	doc_758697966141_item	2848647	et	4	main
ja	doc_758697966141_item	2848654	et	3	main
laanejärv	doc_758697966141_item	2848660	et	3	main
kanal	doc_758697966141_item	2848665	et	4	main
ainult	doc_758697966141_item	2848679	et	4	main
puhul	doc_758697966141_item	2848681	et	4	main
keelekasutus	doc_758697966141_item	2848682	et	4	main
oli	doc_758697966141_item	2848683	et	3	main
vabam	doc_758697966141_item	2848684	et	4	main
näidati	doc_758697966141_item	2848690	et	3	main
inimese	doc_758697966141_item	2848692	et	4	main
nimi	doc_758697966141_item	2848693	et	3	main
subtiiter	doc_758697966141_item	2848694	et	4	main
ilmus	doc_758697966141_item	2848710	et	4	main
rita	doc_758697966141_item	2848736	et	4	main
jüri	doc_758697966141_item	2848738	et	4	main
subtiitrite	doc_758697966141_item	2848740	et	4	main
ma	doc_758697966141_item	2848753	et	3	main
kohta	doc_758697966141_item	2848761	et	4	main
punkti	doc_758697966141_item	2848768	et	4	main
mõnikord	doc_758697966141_item	2848773	et	3	main
rida	doc_758697966141_item	2848775	et	4	main
selle	doc_758697966141_item	2848784	et	4	main
ja	doc_758697966142_item	2848821	et	3	main
reet	doc_758697966142_item	2848829	et	4	main
grosberg	doc_758697966142_item	2848830	et	4	main
janno	doc_758697966142_item	2848834	et	4	main
buschmann	doc_758697966142_item	2848835	et	4	main
seal	doc_758697966142_item	2848845	et	4	main
vigu	doc_758697966142_item	2848851	et	3	main
ilmus	doc_758697966142_item	2848858	et	4	main
õigel	doc_758697966142_item	2848859	et	3	main
ajal	doc_758697966142_item	2848860	et	4	main
tekst	doc_758697966142_item	2848861	et	3	main
ja	doc_758697966142_item	2848862	et	3	main
kõne	doc_758697966142_item	2848863	et	4	main
lause	doc_758697966142_item	2848869	et	4	main
laulis	doc_758697966142_item	2848877	et	4	main
see	doc_758697966142_item	2848878	et	3	main
olid	doc_758697966141_item	2848415	et	4	main
ja	doc_758697966141_item	2848417	et	3	main
etv	doc_758697966141_item	2848419	et	4	main
lugemiskiirus	doc_758697966141_item	2848430	et	4	main
ka	doc_758697966141_item	2848436	et	3	main
lugema	doc_758697966141_item	2848441	et	4	main
kuuldav	doc_758697966141_item	2848446	et	4	main
sünkroonis	doc_758697966141_item	2848452	et	4	main
lahti	doc_758697966141_item	2848461	et	4	main
oli	doc_758697966141_item	2848466	et	3	main
minu	doc_758697966141_item	2848471	et	3	main
teise	doc_758697966141_item	2848478	et	4	main
jooksev	doc_758697966141_item	2848480	et	4	main
seda	doc_758697966141_item	2848483	et	3	main
korda	doc_758697966141_item	2848487	et	4	main
valge	doc_758697966141_item	2848489	et	4	main
teksti	doc_758697966141_item	2848490	et	4	main
taustaks	doc_758697966141_item	2848491	et	3	main
oli	doc_758697966141_item	2848492	et	3	main
telepilt	doc_758697966141_item	2848493	et	3	main
tähed	doc_758697966141_item	2848494	et	3	main
reas	doc_758697966141_item	2848500	et	3	main
oli	doc_758697966141_item	2848501	et	3	main
34	doc_758697966141_item	2848502	et	2	main
subtiiter	doc_758697966141_item	2848503	et	4	main
oli	doc_758697966141_item	2848504	et	3	main
kaherealine	doc_758697966141_item	2848505	et	4	main
ekraani	doc_758697966141_item	2848506	et	4	main
all	doc_758697966141_item	2848507	et	3	main
serval	doc_758697966141_item	2848509	et	3	main
alumine	doc_758697966141_item	2848510	et	3	main
vasakul	doc_758697966141_item	2848508	et	4	main
rida	doc_758697966141_item	2848511	et	4	main
oli	doc_758697966141_item	2848512	et	3	main
tavaliselt	doc_758697966141_item	2848513	et	4	main
pikem	doc_758697966141_item	2848514	et	4	main
kui	doc_758697966141_item	2848515	et	3	main
ülemine	doc_758697966141_item	2848516	et	4	main
kui	doc_758697966141_item	2848517	et	3	main
tõlgiti	doc_758697966141_item	2848518	et	3	main
tekst	doc_758697966141_item	2848519	et	3	main
internetist	doc_758697966141_item	2848520	et	4	main
see	doc_758697966141_item	2848522	et	3	main
aga	doc_758697966141_item	2848524	et	3	main
osa	doc_758697966141_item	2848528	et	4	main
aga	doc_758697966141_item	2848536	et	3	main
ka	doc_758697966141_item	2848538	et	3	main
subtiitri	doc_758697966141_item	2848541	et	4	main
tehtud	doc_758697966141_item	2848544	et	4	main
lause	doc_758697966141_item	2848568	et	4	main
järgmised	doc_758697966141_item	2848578	et	3	main
siis	doc_758697966141_item	2848580	et	3	main
olid	doc_758697966141_item	2848583	et	4	main
must	doc_758697966141_item	2848590	et	4	main
kast	doc_758697966141_item	2848591	et	3	main
ja	doc_758697966141_item	2848592	et	3	main
keele	doc_758697966141_item	2848597	et	4	main
tähemärkide	doc_758697966141_item	2848601	et	3	main
must	doc_758697966141_item	2848610	et	4	main
kast	doc_758697966141_item	2848611	et	3	main
ära	doc_758697966141_item	2848613	et	4	main
samamoodi	doc_758697966141_item	2848614	et	3	main
nagu	doc_758697966141_item	2848615	et	3	main
telefooni	doc_758697966141_item	2848627	et	4	main
olnud	doc_758697966141_item	2848527	et	4	main
raamatust	doc_758697966141_item	2848529	et	4	main
luges	doc_758697966141_item	2848532	et	3	main
jutumärkides	doc_758697966141_item	2848535	et	3	main
olnud	doc_758697966141_item	2848540	et	4	main
poolitamine	doc_758697966141_item	2848542	et	4	main
oli	doc_758697966141_item	2848543	et	3	main
oli	doc_758697966141_item	2848556	et	3	main
see	doc_758697966141_item	2848557	et	3	main
et	doc_758697966141_item	2848558	et	3	main
subtiiter	doc_758697966141_item	2848559	et	4	main
tihti	doc_758697966141_item	2848560	et	3	main
lõpes	doc_758697966141_item	2848561	et	3	main
kolme	doc_758697966141_item	2848562	et	4	main
punktiga	doc_758697966141_item	2848563	et	4	main
semikoolon	doc_758697966141_item	2848564	et	4	main
oli	doc_758697966141_item	2848565	et	3	main
nii	doc_758697966141_item	2848549	et	3	main
semantiliselt	doc_758697966141_item	2848550	et	4	main
kui	doc_758697966141_item	2848551	et	3	main
ka	doc_758697966141_item	2848552	et	3	main
süntaktiliselt	doc_758697966141_item	2848553	et	4	main
samasuguselt	doc_758697966141_item	2848575	et	4	main
asjad	doc_758697966141_item	2848579	et	3	main
keeles	doc_758697966141_item	2848586	et	4	main
subtiitril	doc_758697966141_item	2848587	et	4	main
oli	doc_758697966141_item	2848588	et	3	main
lihtsalt	doc_758697966141_item	2848589	et	4	main
oli	doc_758697966141_item	2848595	et	3	main
seletuse	doc_758697966141_item	2848598	et	4	main
arv	doc_758697966141_item	2848602	et	3	main
siis	doc_758697966141_item	2848643	et	3	main
kui	doc_758697966141_item	2848644	et	3	main
etv	doc_758697966141_item	2848669	et	4	main
dokumentaalsarjas	doc_758697966141_item	2848670	et	3	main
peaaegu	doc_758697966141_item	2848671	et	3	main
samamoodi	doc_758697966141_item	2848674	et	3	main
seriaali	doc_758697966141_item	2848680	et	4	main
lohakam	doc_758697966141_item	2848686	et	4	main
kui	doc_758697966141_item	2848687	et	3	main
dokumentaalsarjas	doc_758697966141_item	2848688	et	3	main
ekraani	doc_758697966141_item	2848696	et	4	main
sest	doc_758697966141_item	2848700	et	4	main
2	doc_758697966141_item	2848702	et	2	main
s	doc_758697966141_item	2848703	et	4	main
nii	doc_758697966141_item	2848704	et	3	main
seriaalis	doc_758697966141_item	2848705	et	3	main
kui	doc_758697966141_item	2848706	et	3	main
ka	doc_758697966141_item	2848707	et	3	main
oleva	doc_758697966141_item	2848714	et	4	main
olid	doc_758697966141_item	2848721	et	4	main
mõnikord	doc_758697966141_item	2848723	et	3	main
talson	doc_758697966141_item	2848737	et	4	main
pärni	doc_758697966141_item	2848739	et	4	main
toimetaja	doc_758697966141_item	2848741	et	4	main
marju	doc_758697966141_item	2848742	et	3	main
samamoodi	doc_758697966141_item	2848751	et	3	main
enne	doc_758697966141_item	2848755	et	4	main
suurem	doc_758697966141_item	2848769	et	4	main
veaks	doc_758697966141_item	2848780	et	4	main
oli	doc_758697966141_item	2848781	et	3	main
see	doc_758697966141_item	2848782	et	3	main
sõbrad	doc_758697966142_item	2848824	et	3	main
salajane	doc_758697966142_item	2848826	et	3	main
ja	doc_758697966142_item	2848831	et	3	main
kõige	doc_758697966142_item	2848836	et	4	main
etv	doc_758697966142_item	2848843	et	4	main
lauseid	doc_758697966142_item	2848852	et	3	main
kõik	doc_758697966142_item	2848857	et	4	main
loetav	doc_758697966142_item	2848867	et	4	main
olid	doc_758697966142_item	2848871	et	4	main
punktid	doc_758697966142_item	2848872	et	4	main
teksti	doc_758697966142_item	2848879	et	4	main
osa	doc_758697966142_item	2848880	et	4	main
tekst	doc_758697966142_item	2848891	et	3	main
panin	doc_758697966142_item	2848895	et	3	main
tähele	doc_758697966142_item	2848898	et	3	main
i	doc_758697966142_item	2848905	et	4	main
keelde	doc_758697966142_item	2848909	et	4	main
see	doc_758697966142_item	2848910	et	3	main
tõlgitud	doc_758697966142_item	2848912	et	4	main
pean	doc_758697966142_item	2848914	et	4	main
tööle	doc_758697966142_item	2848915	et	3	main
minema	doc_758697966142_item	2848916	et	3	main
sõbrad	doc_758697966142_item	2848917	et	3	main
alguses	doc_758697966142_item	2848918	et	4	main
ja	doc_758697966142_item	2848919	et	3	main
kasutatud	doc_758697966142_item	2848922	et	4	main
must	doc_758697966142_item	2848923	et	4	main
sõnad	doc_758697966142_item	2848929	et	4	main
tõlgimata	doc_758697966142_item	2848931	et	4	main
küsis	doc_758697966142_item	2848947	et	3	main
kui	doc_758697966142_item	2848950	et	3	main
pannud	doc_758697966142_item	2848958	et	4	main
subtiiter	doc_758697966142_item	2848977	et	4	main
jäi	doc_758697966142_item	2848978	et	3	main
hiljaks	doc_758697966142_item	2848979	et	3	main
ja	doc_758697966142_item	2848980	et	3	main
punktiga	doc_758697966142_item	2848986	et	4	main
lõpus	doc_758697966141_item	2848569	et	4	main
olid	doc_758697966141_item	2848570	et	4	main
punktid	doc_758697966141_item	2848571	et	4	main
oli	doc_758697966141_item	2848577	et	3	main
filmis	doc_758697966141_item	2848582	et	4	main
seletused	doc_758697966141_item	2848584	et	4	main
inglise	doc_758697966141_item	2848585	et	4	main
eestikeelne	doc_758697966141_item	2848593	et	3	main
peal	doc_758697966141_item	2848599	et	4	main
kui	doc_758697966141_item	2848604	et	3	main
enam	doc_758697966141_item	2848607	et	4	main
ei	doc_758697966141_item	2848608	et	4	main
paar	doc_758697966141_item	2848621	et	3	main
subtiiter	doc_758697966141_item	2848623	et	4	main
lõpes	doc_758697966141_item	2848624	et	3	main
veaks	doc_758697966141_item	2848632	et	4	main
ka	doc_758697966141_item	2848633	et	3	main
see	doc_758697966141_item	2848634	et	3	main
sõna	doc_758697966141_item	2848637	et	4	main
oli	doc_758697966141_item	2848638	et	3	main
kirjutatud	doc_758697966141_item	2848639	et	4	main
ei	doc_758697966141_item	2848646	et	4	main
tõlkija	doc_758697966141_item	2848650	et	4	main
oli	doc_758697966141_item	2848651	et	3	main
2	doc_758697966141_item	2848656	et	2	main
oli	doc_758697966141_item	2848658	et	3	main
etv	doc_758697966141_item	2848661	et	4	main
teeliiklusest	doc_758697966141_item	2848663	et	4	main
ja	doc_758697966141_item	2848664	et	3	main
2	doc_758697966141_item	2848666	et	2	main
dokumentaalsari	doc_758697966141_item	2848667	et	4	main
lastetaltsutaja	doc_758697966141_item	2848668	et	4	main
etv	doc_758697966141_item	2848676	et	4	main
seriaalis	doc_758697966141_item	2848677	et	3	main
robinsons	doc_758697966141_item	2848678	et	4	main
ülaossa	doc_758697966141_item	2848697	et	3	main
see	doc_758697966141_item	2848698	et	3	main
samaaegselt	doc_758697966141_item	2848711	et	4	main
ekraani	doc_758697966141_item	2848712	et	4	main
alaosas	doc_758697966141_item	2848713	et	3	main
oli	doc_758697966141_item	2848718	et	3	main
eelmine	doc_758697966141_item	2848724	et	3	main
jäi	doc_758697966141_item	2848726	et	3	main
järgmisesse	doc_758697966141_item	2848727	et	3	main
kaadrisse	doc_758697966141_item	2848728	et	3	main
toppama	doc_758697966141_item	2848729	et	3	main
suurim	doc_758697966141_item	2848730	et	3	main
tähemärkide	doc_758697966141_item	2848731	et	3	main
arv	doc_758697966141_item	2848732	et	3	main
jälle	doc_758697966141_item	2848733	et	3	main
makki	doc_758697966141_item	2848743	et	4	main
kirjutasin	doc_758697966141_item	2848754	et	3	main
2	doc_758697966141_item	2848757	et	2	main
palju	doc_758697966141_item	2848762	et	4	main
korda	doc_758697966141_item	2848763	et	4	main
tähemärkide	doc_758697966141_item	2848770	et	3	main
lapsehoidja	doc_758697966141_item	2848787	et	4	main
korda	doc_758697966141_item	2848622	et	4	main
kolme	doc_758697966141_item	2848625	et	4	main
punktiga	doc_758697966141_item	2848626	et	4	main
et	doc_758697966141_item	2848635	et	3	main
järjest	doc_758697966141_item	2848642	et	4	main
see	doc_758697966141_item	2848645	et	3	main
vajalik	doc_758697966141_item	2848648	et	3	main
etv	doc_758697966141_item	2848649	et	4	main
kanal	doc_758697966141_item	2848655	et	4	main
tõlkija	doc_758697966141_item	2848657	et	4	main
tiina	doc_758697966141_item	2848659	et	4	main
nadu	doc_758697966141_item	2848675	et	4	main
kui	doc_758697966141_item	2848689	et	3	main
kõneleva	doc_758697966141_item	2848691	et	4	main
oli	doc_758697966141_item	2848699	et	3	main
kanal	doc_758697966141_item	2848701	et	4	main
kasutus	doc_758697966141_item	2848717	et	4	main
sobiv	doc_758697966141_item	2848719	et	4	main
pausid	doc_758697966141_item	2848720	et	3	main
tõlkijad	doc_758697966141_item	2848735	et	4	main
2	doc_758697966141_item	2848745	et	2	main
dokumentaalsarjas	doc_758697966141_item	2848746	et	3	main
oli	doc_758697966141_item	2848748	et	3	main
peaaegu	doc_758697966141_item	2848749	et	3	main
kõik	doc_758697966141_item	2848750	et	4	main
nagu	doc_758697966141_item	2848752	et	3	main
kanal	doc_758697966141_item	2848756	et	4	main
seriaali	doc_758697966141_item	2848758	et	4	main
las	doc_758697966141_item	2848759	et	4	main
oli	doc_758697966141_item	2848764	et	3	main
lause	doc_758697966141_item	2848765	et	4	main
arv	doc_758697966141_item	2848771	et	3	main
ülemine	doc_758697966141_item	2848774	et	4	main
oli	doc_758697966141_item	2848776	et	3	main
et	doc_758697966141_item	2848783	et	3	main
kanal	doc_758697966142_item	2848822	et	4	main
meie	doc_758697966142_item	2848825	et	4	main
sest	doc_758697966142_item	2848844	et	4	main
üldse	doc_758697966142_item	2848849	et	3	main
ühes	doc_758697966142_item	2848873	et	4	main
ei	doc_758697966142_item	2848881	et	4	main
lõppus	doc_758697966142_item	2848920	et	4	main
kõne	doc_758697966141_item	2848628	et	4	main
oli	doc_758697966141_item	2848629	et	3	main
mitu	doc_758697966141_item	2848640	et	4	main
tiia-mai	doc_758697966141_item	2848652	et	4	main
nõmmik	doc_758697966141_item	2848653	et	3	main
dokumentaalsari	doc_758697966141_item	2848662	et	4	main
kõik	doc_758697966141_item	2848672	et	4	main
oli	doc_758697966141_item	2848673	et	3	main
isegi	doc_758697966141_item	2848685	et	4	main
asetati	doc_758697966141_item	2848695	et	4	main
dokumentaalsaades	doc_758697966141_item	2848708	et	4	main
tiiter	doc_758697966141_item	2848709	et	3	main
subtiitriga	doc_758697966141_item	2848715	et	4	main
sõnade	doc_758697966141_item	2848716	et	3	main
piisavad	doc_758697966141_item	2848722	et	4	main
subtiiter	doc_758697966141_item	2848725	et	4	main
34	doc_758697966141_item	2848734	et	2	main
kanal	doc_758697966141_item	2848744	et	4	main
lastetaltsutaja	doc_758697966141_item	2848747	et	4	main
vegas	doc_758697966141_item	2848760	et	4	main
lõppus	doc_758697966141_item	2848766	et	4	main
kolm	doc_758697966141_item	2848767	et	3	main
34	doc_758697966141_item	2848772	et	2	main
pikem	doc_758697966141_item	2848777	et	4	main
ku	doc_758697966141_item	2848778	et	4	main
alumine	doc_758697966141_item	2848779	et	3	main
saade	doc_758697966141_item	2848785	et	4	main
alguses	doc_758697966141_item	2848786	et	4	main
seletused	doc_758697966141_item	2848788	et	4	main
olid	doc_758697966141_item	2848789	et	4	main
normaaltekstis	doc_758697966141_item	2848790	et	3	main
hiljem	doc_758697966141_item	2848791	et	3	main
äkki	doc_758697966141_item	2848792	et	3	main
olid	doc_758697966141_item	2848793	et	4	main
kursiivis	doc_758697966141_item	2848794	et	3	main
halb	doc_758697966141_item	2848795	et	3	main
oli	doc_758697966141_item	2848796	et	3	main
ka	doc_758697966141_item	2848797	et	3	main
see	doc_758697966141_item	2848798	et	3	main
et	doc_758697966141_item	2848799	et	3	main
olid	doc_758697966141_item	2848800	et	4	main
kasutatud	doc_758697966141_item	2848801	et	4	main
keerukaid	doc_758697966141_item	2848802	et	3	main
läbi	doc_758697966141_item	2848803	et	4	main
kolme	doc_758697966141_item	2848804	et	4	main
subtiitri	doc_758697966141_item	2848805	et	4	main
jooksvaid	doc_758697966141_item	2848806	et	4	main
lauseid	doc_758697966141_item	2848807	et	3	main
tõlkis	doc_758697966141_item	2848808	et	3	main
tiina	doc_758697966141_item	2848809	et	4	main
laanejärv	doc_758697966141_item	2848810	et	3	main
analüüs	doc_758697966142_item	2848811	et	3	main
subtitreerimine	doc_758697966142_item	2848812	et	4	main
ma	doc_758697966142_item	2848813	et	3	main
vaatasin	doc_758697966142_item	2848814	et	3	main
kahte	doc_758697966142_item	2848815	et	4	main
sarja	doc_758697966142_item	2848816	et	4	main
etv	doc_758697966142_item	2848817	et	4	main
meie	doc_758697966142_item	2848818	et	4	main
salajane	doc_758697966142_item	2848819	et	3	main
elu	doc_758697966142_item	2848820	et	4	main
elu	doc_758697966142_item	2848827	et	4	main
2	doc_758697966142_item	2848823	et	2	main
tõlgis	doc_758697966142_item	2848828	et	3	main
sõbrad	doc_758697966142_item	2848832	et	3	main
kuidas	doc_758697966142_item	2848840	et	3	main
ma	doc_758697966142_item	2848846	et	3	main
ei	doc_758697966142_item	2848847	et	4	main
leidnud	doc_758697966142_item	2848848	et	4	main
tõlgis	doc_758697966142_item	2848833	et	3	main
rohkem	doc_758697966142_item	2848837	et	4	main
mulle	doc_758697966142_item	2848838	et	4	main
meeldis	doc_758697966142_item	2848839	et	3	main
on	doc_758697966142_item	2848841	et	4	main
tõlgitud	doc_758697966142_item	2848842	et	4	main
loogilises	doc_758697966142_item	2848854	et	4	main
tekst	doc_758697966142_item	2848868	et	3	main
lõppus	doc_758697966142_item	2848870	et	4	main
poiss	doc_758697966142_item	2848876	et	3	main
kursiivis	doc_758697966142_item	2848883	et	3	main
ainuke	doc_758697966142_item	2848886	et	4	main
see	doc_758697966142_item	2848889	et	3	main
tõlgitud	doc_758697966142_item	2848904	et	4	main
go	doc_758697966142_item	2848907	et	4	main
ma	doc_758697966142_item	2848913	et	3	main
oli	doc_758697966142_item	2848921	et	3	main
mis	doc_758697966142_item	2848925	et	4	main
oli	doc_758697966142_item	2848934	et	3	main
dialoog	doc_758697966142_item	2848935	et	3	main
poole	doc_758697966142_item	2848943	et	4	main
ütles	doc_758697966142_item	2848944	et	3	main
midagi	doc_758697966142_item	2848948	et	4	main
aga	doc_758697966142_item	2848949	et	3	main
eesti	doc_758697966142_item	2848952	et	4	main
korda	doc_758697966142_item	2848982	et	4	main
subtiiter	doc_758697966142_item	2848983	et	4	main
lõpes	doc_758697966142_item	2848984	et	3	main
tiina	doc_758697966142_item	2849004	et	4	main
mind	doc_758697966142_item	2849010	et	4	main
ei	doc_758697966142_item	2849021	et	4	main
lugeda	doc_758697966142_item	2849023	et	3	main
oli	doc_758697966142_item	2849028	et	3	main
poolitatud	doc_758697966142_item	2849029	et	4	main
mitte	doc_758697966142_item	2849030	et	3	main
loogiliselt	doc_758697966142_item	2849031	et	4	main
uued	doc_758697966142_item	2849032	et	3	main
lauseid	doc_758697966142_item	2849033	et	3	main
ja	doc_758697966142_item	2849041	et	3	main
olnud	doc_758697966142_item	2849044	et	4	main
grammatilst	doc_758697966142_item	2849046	et	4	main
vigu	doc_758697966142_item	2849047	et	3	main
ma	doc_758697966142_item	2849048	et	3	main
ei	doc_758697966142_item	2849049	et	4	main
näinud	doc_758697966142_item	2849050	et	4	main
punkt	doc_758697966142_item	2849051	et	4	main
kasutati	doc_758697966142_item	2849052	et	4	main
vaja	doc_758697966142_item	2849056	et	4	main
ei	doc_758697966142_item	2849057	et	4	main
liiga	doc_758697966142_item	2849067	et	4	main
lõpupunkti	doc_758697966142_item	2849076	et	4	main
jooksul	doc_758697966142_item	2849081	et	4	main
eesti	doc_758697966142_item	2849121	et	4	main
ei	doc_758697966142_item	2849123	et	4	main
thank	doc_758697966142_item	2849129	et	4	main
aru	doc_758697966142_item	2849153	et	4	main
saadav	doc_758697966142_item	2849154	et	4	main
poiss	doc_758697966142_item	2849156	et	3	main
hea	doc_758697966142_item	2849162	et	4	main
tekstid	doc_758697966142_item	2849163	et	3	main
ei	doc_758697966142_item	2849164	et	4	main
olnud	doc_758697966142_item	2849165	et	4	main
grammatilist	doc_758697966142_item	2848850	et	3	main
olid	doc_758697966142_item	2848853	et	4	main
kohas	doc_758697966142_item	2848855	et	4	main
poolitatud	doc_758697966142_item	2848856	et	4	main
väga	doc_758697966142_item	2848864	et	3	main
hästi	doc_758697966142_item	2848865	et	3	main
oli	doc_758697966142_item	2848866	et	3	main
kohas	doc_758697966142_item	2848874	et	4	main
kui	doc_758697966142_item	2848875	et	3	main
olnud	doc_758697966142_item	2848882	et	4	main
üks	doc_758697966142_item	2848885	et	3	main
oli	doc_758697966142_item	2848888	et	3	main
teisesse	doc_758697966142_item	2848893	et	4	main
ka	doc_758697966142_item	2848896	et	3	main
ühes	doc_758697966142_item	2848900	et	4	main
kohas	doc_758697966142_item	2848901	et	4	main
oli	doc_758697966142_item	2848902	et	3	main
valesti	doc_758697966142_item	2848903	et	3	main
must	doc_758697966142_item	2848906	et	4	main
kast	doc_758697966142_item	2848924	et	3	main
häiris	doc_758697966142_item	2848926	et	3	main
mind	doc_758697966142_item	2848927	et	4	main
olid	doc_758697966142_item	2848930	et	4	main
inimesi	doc_758697966142_item	2848939	et	4	main
naine	doc_758697966142_item	2848940	et	3	main
pöördas	doc_758697966142_item	2848941	et	4	main
mehe	doc_758697966142_item	2848942	et	3	main
ei	doc_758697966142_item	2848957	et	4	main
mitu	doc_758697966142_item	2848981	et	4	main
mängufilme	doc_758697966142_item	2848991	et	3	main
pbk	doc_758697966142_item	2848992	et	4	main
вызов	doc_758697966142_item	2848993	et	2	main
tõlgis	doc_758697966142_item	2848994	et	3	main
a	doc_758697966142_item	2848995	et	4	main
huck	doc_758697966142_item	2849002	et	4	main
filmi	doc_758697966142_item	2849007	et	4	main
kast	doc_758697966142_item	2849013	et	3	main
hakkanud	doc_758697966142_item	2849035	et	4	main
igas	doc_758697966142_item	2849036	et	3	main
kus	doc_758697966142_item	2849053	et	3	main
oli	doc_758697966142_item	2849054	et	3	main
seda	doc_758697966142_item	2849055	et	3	main
tom	doc_758697966142_item	2849069	et	4	main
subtiiter	doc_758697966142_item	2849072	et	4	main
oli	doc_758697966142_item	2849073	et	3	main
poolitatud	doc_758697966142_item	2849074	et	4	main
loogiliselt	doc_758697966142_item	2849075	et	4	main
sir	doc_758697966142_item	2849083	et	4	main
mr	doc_758697966142_item	2849084	et	4	main
keelde	doc_758697966142_item	2849122	et	4	main
olnud	doc_758697966142_item	2849124	et	4	main
paar	doc_758697966142_item	2849125	et	3	main
you	doc_758697966142_item	2849130	et	4	main
palun	doc_758697966142_item	2849131	et	3	main
tänan	doc_758697966142_item	2849132	et	3	main
äkki	doc_758697966142_item	2849133	et	3	main
ei	doc_758697966142_item	2849139	et	4	main
poissi	doc_758697966142_item	2849146	et	4	main
nimi	doc_758697966142_item	2849147	et	3	main
on	doc_758697966142_item	2849151	et	4	main
poissi	doc_758697966142_item	2849159	et	4	main
lugemiskiirus	doc_758697966142_item	2849160	et	4	main
liiga	doc_758697966142_item	2849166	et	4	main
ja	doc_758697966142_item	2848884	et	3	main
kord	doc_758697966142_item	2848887	et	4	main
et	doc_758697966142_item	2848890	et	3	main
jäi	doc_758697966142_item	2848892	et	3	main
kaadrisse	doc_758697966142_item	2848894	et	3	main
seda	doc_758697966142_item	2848897	et	3	main
et	doc_758697966142_item	2848899	et	3	main
eesti	doc_758697966142_item	2848908	et	4	main
oli	doc_758697966142_item	2848911	et	3	main
mõned	doc_758697966142_item	2848928	et	3	main
palju	doc_758697966142_item	2848938	et	4	main
ja	doc_758697966142_item	2848946	et	3	main
tõlgiti	doc_758697966142_item	2848951	et	3	main
keelde	doc_758697966142_item	2848953	et	4	main
siis	doc_758697966142_item	2848954	et	3	main
mehe	doc_758697966142_item	2848955	et	3	main
nime	doc_758697966142_item	2848956	et	4	main
veel	doc_758697966142_item	2848990	et	4	main
tom	doc_758697966142_item	2849000	et	4	main
ja	doc_758697966142_item	2849001	et	3	main
kohtadest	doc_758697966142_item	2849026	et	3	main
kohas	doc_758697966142_item	2849037	et	4	main
laulutekst	doc_758697966142_item	2849040	et	3	main
meeldinud	doc_758697966142_item	2849058	et	4	main
veel	doc_758697966142_item	2849059	et	4	main
see	doc_758697966142_item	2849060	et	3	main
et	doc_758697966142_item	2849061	et	3	main
huck	doc_758697966142_item	2849071	et	4	main
terve	doc_758697966142_item	2849079	et	4	main
filmi	doc_758697966142_item	2849080	et	4	main
mrs	doc_758697966142_item	2849085	et	4	main
seda	doc_758697966142_item	2849086	et	3	main
ühes	doc_758697966142_item	2848932	et	4	main
kohas	doc_758697966142_item	2848933	et	4	main
ruumis	doc_758697966142_item	2848936	et	4	main
oli	doc_758697966142_item	2848937	et	3	main
joey	doc_758697966142_item	2848945	et	4	main
ja	doc_758697966142_item	2848959	et	3	main
selline	doc_758697966142_item	2848960	et	4	main
mulje	doc_758697966142_item	2848961	et	4	main
jäi	doc_758697966142_item	2848962	et	3	main
et	doc_758697966142_item	2848963	et	3	main
kelle	doc_758697966142_item	2848964	et	4	main
poole	doc_758697966142_item	2848965	et	4	main
naine	doc_758697966142_item	2848966	et	3	main
siis	doc_758697966142_item	2848967	et	3	main
ikka	doc_758697966142_item	2848968	et	4	main
pöördas	doc_758697966142_item	2848969	et	4	main
lauseid	doc_758697966142_item	2848970	et	3	main
olid	doc_758697966142_item	2848971	et	4	main
loogilises	doc_758697966142_item	2848972	et	4	main
kohas	doc_758697966142_item	2848973	et	4	main
poolitatud	doc_758697966142_item	2848974	et	4	main
paar	doc_758697966142_item	2848975	et	3	main
korda	doc_758697966142_item	2848976	et	4	main
kolme	doc_758697966142_item	2848985	et	4	main
kuzmina	doc_758697966142_item	2848996	et	4	main
ja	doc_758697966142_item	2848997	et	3	main
tõlgis	doc_758697966142_item	2849003	et	3	main
häiris	doc_758697966142_item	2849011	et	3	main
hall	doc_758697966142_item	2849012	et	4	main
ei	doc_758697966142_item	2849034	et	4	main
telefonivestlus	doc_758697966142_item	2849042	et	3	main
subtiiter	doc_758697966142_item	2849062	et	4	main
oli	doc_758697966142_item	2849063	et	3	main
keskel	doc_758697966142_item	2849064	et	3	main
tekstid	doc_758697966142_item	2849065	et	3	main
olid	doc_758697966142_item	2849066	et	4	main
ja	doc_758697966142_item	2849070	et	3	main
oluline	doc_758697966142_item	2849141	et	4	main
korda	doc_758697966142_item	2849143	et	4	main
oli	doc_758697966142_item	2849144	et	3	main
tõlgitud	doc_758697966142_item	2849145	et	4	main
niigi	doc_758697966142_item	2849152	et	4	main
et	doc_758697966142_item	2849155	et	3	main
hüüab	doc_758697966142_item	2849157	et	3	main
tema	doc_761051790173_item	2849351	et	4	main
sõbrad	doc_761051790173_item	2849352	et	3	main
kui	doc_761051790173_item	2849353	et	3	main
sõbrad	doc_761051790173_item	2849354	et	3	main
on	doc_761051790173_item	2849355	et	4	main
kui	doc_761051790173_item	2849363	et	3	main
tema	doc_761051790173_item	2849364	et	4	main
see	doc_767882159205_item	2849420	et	3	main
on	doc_767882159205_item	2849421	et	4	main
et	doc_767882159205_item	2849426	et	3	main
eestlastel	doc_767882159205_item	2849427	et	4	main
erinevaid	doc_767882159205_item	2849440	et	4	main
1869	doc_767882159205_item	2849446	et	2	main
on	doc_767882159205_item	2849465	et	4	main
praegu	doc_767882159205_item	2849466	et	3	main
toimuvad	doc_767882159205_item	2849469	et	4	main
laulutraditsioonid	doc_767882159205_item	2849519	et	3	main
eeslaulja	doc_767882159205_item	2849536	et	4	main
värsse	doc_767882159205_item	2849538	et	3	main
tol	doc_767882159205_item	2849555	et	3	main
19	doc_767882159205_item	2849564	et	2	main
sajandi	doc_767882159205_item	2849565	et	3	main
teisest	doc_767882159205_item	2849566	et	4	main
poolest	doc_767882159205_item	2849567	et	4	main
kõnelema	doc_767882159205_item	2849570	et	3	main
muusika	doc_767882159205_item	2849571	et	4	main
koha	doc_767882159205_item	2849606	et	4	main
lauluvõistlus	doc_767882159205_item	2849612	et	3	main
eestis	doc_767882159205_item	2849614	et	3	main
juhtus	doc_767882159205_item	2849621	et	3	main
dave	doc_767882159205_item	2849626	et	4	main
neil	doc_767882159205_item	2849645	et	4	main
on	doc_767882159205_item	2849646	et	4	main
tore	doc_767882159205_item	2849647	et	3	main
tulevik	doc_767882159205_item	2849648	et	3	main
oli	doc_767882159205_item	2849651	et	3	main
laul	doc_767882159205_item	2849656	et	4	main
nagu	doc_767882159205_item	2849658	et	3	main
eestlasi	doc_767882159205_item	2849664	et	3	main
nii	doc_767882159205_item	2849665	et	3	main
siis	doc_758697966142_item	2848987	et	3	main
ma	doc_758697966142_item	2848988	et	3	main
vaatasin	doc_758697966142_item	2848989	et	3	main
tv	doc_758697966142_item	2848998	et	4	main
3	doc_758697966142_item	2848999	et	2	main
leemets	doc_758697966142_item	2849005	et	4	main
terve	doc_758697966142_item	2849006	et	4	main
jooksul	doc_758697966142_item	2849008	et	4	main
вызов	doc_758697966142_item	2849009	et	2	main
subtiiter	doc_758697966142_item	2849014	et	4	main
jooksis	doc_758697966142_item	2849015	et	4	main
mõne	doc_758697966142_item	2849016	et	3	main
kohtades	doc_758697966142_item	2849017	et	3	main
liiga	doc_758697966142_item	2849018	et	4	main
kiiresti	doc_758697966142_item	2849019	et	3	main
et	doc_758697966142_item	2849020	et	3	main
jõudnud	doc_758697966142_item	2849022	et	4	main
lõpuni	doc_758697966142_item	2849024	et	3	main
paljudes	doc_758697966142_item	2849025	et	3	main
tekst	doc_758697966142_item	2849027	et	3	main
suure	doc_758697966142_item	2849038	et	3	main
läbitähega	doc_758697966142_item	2849039	et	3	main
ei	doc_758697966142_item	2849043	et	4	main
kursiivis	doc_758697966142_item	2849045	et	3	main
pikkad	doc_758697966142_item	2849068	et	4	main
ei	doc_758697966142_item	2849077	et	4	main
kasutanud	doc_758697966142_item	2849078	et	4	main
ühtegi	doc_758697966142_item	2849082	et	4	main
üldse	doc_758697966142_item	2849087	et	3	main
pole	doc_758697966142_item	2849088	et	3	main
tõlgitud	doc_758697966142_item	2849089	et	4	main
eesti	doc_758697966142_item	2849090	et	4	main
keelde	doc_758697966142_item	2849091	et	4	main
ühes	doc_758697966142_item	2849092	et	4	main
kohas	doc_758697966142_item	2849093	et	4	main
poiss	doc_758697966142_item	2849094	et	3	main
ütles	doc_758697966142_item	2849095	et	3	main
say	doc_758697966142_item	2849096	et	4	main
tom	doc_758697966142_item	2849097	et	4	main
eesti	doc_758697966142_item	2849098	et	4	main
keeles	doc_758697966142_item	2849099	et	4	main
oleks	doc_758697966142_item	2849100	et	3	main
olnud	doc_758697966142_item	2849101	et	4	main
ütle	doc_758697966142_item	2849102	et	4	main
tom	doc_758697966142_item	2849103	et	4	main
aga	doc_758697966142_item	2849104	et	3	main
seda	doc_758697966142_item	2849105	et	3	main
teksti	doc_758697966142_item	2849106	et	4	main
osa	doc_758697966142_item	2849107	et	4	main
tõlkija	doc_758697966142_item	2849108	et	4	main
üldse	doc_758697966142_item	2849109	et	3	main
jättis	doc_758697966142_item	2849110	et	3	main
ära	doc_758697966142_item	2849111	et	4	main
minu	doc_758697966142_item	2849112	et	3	main
meelest	doc_758697966142_item	2849113	et	4	main
see	doc_758697966142_item	2849114	et	3	main
oli	doc_758697966142_item	2849115	et	3	main
tähtis	doc_758697966142_item	2849116	et	4	main
panin	doc_758697966142_item	2849117	et	3	main
ka	doc_758697966142_item	2849118	et	3	main
tähele	doc_758697966142_item	2849119	et	3	main
et	doc_758697966142_item	2849120	et	3	main
korda	doc_758697966142_item	2849126	et	4	main
tõlkija	doc_758697966142_item	2849134	et	4	main
tõlgitud	doc_758697966142_item	2849127	et	4	main
please	doc_758697966142_item	2849128	et	4	main
arvates	doc_758697966142_item	2849135	et	4	main
see	doc_758697966142_item	2849136	et	3	main
teksti	doc_758697966142_item	2849137	et	4	main
osa	doc_758697966142_item	2849138	et	4	main
paar	doc_758697966142_item	2849142	et	3	main
meelest	doc_758697966142_item	2849150	et	4	main
teise	doc_758697966142_item	2849158	et	4	main
olnud	doc_758697966142_item	2849140	et	4	main
huck	doc_758697966142_item	2849148	et	4	main
minu	doc_758697966142_item	2849149	et	3	main
on	doc_758697966142_item	2849161	et	4	main
pikkad	doc_758697966142_item	2849167	et	4	main
uus	doc_761051790173_item	2849299	et	3	main
dokument	doc_761051790173_item	2849300	et	3	main
1	doc_761051790173_item	2849301	et	2	main
v	doc_761051790173_item	2849302	et	4	main
äga	doc_761051790173_item	2849303	et	4	main
mõjutab	doc_761051790173_item	2849304	et	3	main
inimese	doc_761051790173_item	2849305	et	4	main
elu	doc_761051790173_item	2849306	et	4	main
haridus	doc_761051790173_item	2849307	et	3	main
sellepärast	doc_761051790173_item	2849308	et	3	main
kui	doc_761051790173_item	2849309	et	3	main
inimesel	doc_761051790173_item	2849310	et	3	main
ei	doc_761051790173_item	2849311	et	4	main
ole	doc_761051790173_item	2849312	et	4	main
hea	doc_761051790173_item	2849313	et	4	main
teadmised	doc_761051790173_item	2849314	et	4	main
tal	doc_761051790173_item	2849315	et	3	main
ei	doc_761051790173_item	2849316	et	4	main
ole	doc_761051790173_item	2849317	et	4	main
hea	doc_761051790173_item	2849318	et	4	main
tööd	doc_761051790173_item	2849319	et	4	main
2	doc_761051790173_item	2849320	et	2	main
ei	doc_761051790173_item	2849323	et	4	main
raha	doc_761051790173_item	2849325	et	4	main
või	doc_761051790173_item	2849329	et	4	main
elada	doc_761051790173_item	2849330	et	3	main
hästi	doc_761051790173_item	2849331	et	3	main
inimestel	doc_761051790173_item	2849334	et	3	main
on	doc_761051790173_item	2849335	et	4	main
väga	doc_761051790173_item	2849336	et	3	main
raske	doc_761051790173_item	2849337	et	4	main
iseloom	doc_761051790173_item	2849338	et	3	main
inimesel	doc_761051790173_item	2849322	et	3	main
ole	doc_761051790173_item	2849324	et	4	main
siis	doc_761051790173_item	2849326	et	3	main
ta	doc_761051790173_item	2849327	et	4	main
3	doc_761051790173_item	2849332	et	2	main
4	doc_761051790173_item	2849345	et	2	main
inimese	doc_761051790173_item	2849349	et	4	main
head	doc_761051790173_item	2849356	et	4	main
ja	doc_761051790173_item	2849357	et	3	main
sõbrad	doc_761051790173_item	2849365	et	3	main
inimesed	doc_761051790173_item	2849368	et	3	main
vanematega	doc_761051790173_item	2849370	et	4	main
kes	doc_761051790173_item	2849371	et	4	main
eesti	doc_767882159205_item	2849379	et	4	main
keele	doc_767882159205_item	2849380	et	4	main
mis	doc_761051790173_item	2849339	et	4	main
segab	doc_761051790173_item	2849340	et	3	main
temal	doc_761051790173_item	2849341	et	3	main
suhelda	doc_761051790173_item	2849342	et	4	main
mõjutab	doc_761051790173_item	2849348	et	3	main
5	doc_761051790173_item	2849366	et	2	main
lubanud	doc_761051790173_item	2849373	et	4	main
ja	doc_761051790173_item	2849374	et	3	main
kontrollida	doc_761051790173_item	2849375	et	4	main
nende	doc_761051790173_item	2849376	et	4	main
tegevused	doc_761051790173_item	2849377	et	4	main
kui	doc_767882159205_item	2849381	et	3	main
teise	doc_767882159205_item	2849382	et	4	main
kirjutamine	doc_767882159205_item	2849385	et	4	main
on	doc_767882159205_item	2849428	et	4	main
aastal	doc_767882159205_item	2849447	et	3	main
idee	doc_767882159205_item	2849451	et	4	main
johann	doc_767882159205_item	2849456	et	4	main
jannseniga	doc_767882159205_item	2849458	et	4	main
välismaalaste	doc_767882159205_item	2849473	et	4	main
esitate	doc_767882159205_item	2849474	et	3	main
rahva	doc_767882159205_item	2849475	et	3	main
laulda	doc_767882159205_item	2849483	et	4	main
on	doc_767882159205_item	2849517	et	4	main
vanemat	doc_767882159205_item	2849521	et	4	main
esindab	doc_767882159205_item	2849523	et	3	main
kultuurile	doc_767882159205_item	2849525	et	3	main
koor	doc_767882159205_item	2849533	et	4	main
esitatud	doc_767882159205_item	2849537	et	4	main
talle	doc_767882159205_item	2849541	et	4	main
olid	doc_767882159205_item	2849543	et	4	main
ka	doc_767882159205_item	2849544	et	3	main
regilaulud	doc_767882159205_item	2849545	et	3	main
regilaule	doc_767882159205_item	2849546	et	4	main
tihti	doc_767882159205_item	2849547	et	3	main
lauldi	doc_767882159205_item	2849548	et	3	main
naised	doc_767882159205_item	2849549	et	3	main
ilma	doc_767882159205_item	2849559	et	4	main
pillisaateta	doc_767882159205_item	2849560	et	3	main
oli	doc_767882159205_item	2849561	et	3	main
ainult	doc_767882159205_item	2849562	et	4	main
muusikat	doc_767882159205_item	2849577	et	3	main
nii	doc_767882159205_item	2849622	et	3	main
laulsid	doc_767882159205_item	2849628	et	4	main
meeldis	doc_767882159205_item	2849632	et	3	main
eestlaste	doc_767882159205_item	2849649	et	4	main
on	doc_767882159205_item	2849653	et	4	main
laul	doc_767882159205_item	2849661	et	4	main
kui	doc_761051790173_item	2849321	et	3	main
ei	doc_761051790173_item	2849328	et	4	main
paljude	doc_761051790173_item	2849333	et	3	main
teiste	doc_761051790173_item	2849343	et	4	main
inimestega	doc_761051790173_item	2849344	et	3	main
ka	doc_761051790173_item	2849346	et	3	main
elu	doc_761051790173_item	2849350	et	4	main
inimene	doc_761051790173_item	2849361	et	3	main
on	doc_761051790173_item	2849362	et	4	main
palju	doc_761051790173_item	2849367	et	4	main
elavad	doc_761051790173_item	2849369	et	4	main
test	doc_767882159205_item	2849384	et	3	main
kirjutage	doc_767882159205_item	2849386	et	3	main
essee	doc_767882159205_item	2849387	et	4	main
teemal	doc_767882159205_item	2849388	et	3	main
mis	doc_767882159205_item	2849389	et	4	main
teeb	doc_767882159205_item	2849390	et	3	main
eestlastest	doc_767882159205_item	2849391	et	4	main
laulurahva	doc_767882159205_item	2849392	et	3	main
essee	doc_767882159205_item	2849393	et	4	main
pikkus	doc_767882159205_item	2849394	et	4	main
300	doc_767882159205_item	2849395	et	2	main
350	doc_767882159205_item	2849396	et	2	main
sõna	doc_767882159205_item	2849397	et	4	main
essee	doc_767882159205_item	2849398	et	4	main
peab	doc_767882159205_item	2849399	et	4	main
olema	doc_767882159205_item	2849400	et	4	main
arutlev	doc_767882159205_item	2849401	et	4	main
analüüsiv	doc_767882159205_item	2849402	et	4	main
ja	doc_767882159205_item	2849403	et	3	main
üldistav	doc_767882159205_item	2849404	et	4	main
tuginema	doc_767882159205_item	2849405	et	3	main
loengus	doc_767882159205_item	2849406	et	3	main
ja	doc_767882159205_item	2849407	et	3	main
lugemistekstis	doc_767882159205_item	2849408	et	3	main
esitatud	doc_767882159205_item	2849409	et	4	main
faktidele	doc_767882159205_item	2849410	et	3	main
väiteid	doc_767882159205_item	2849411	et	4	main
on	doc_767882159205_item	2849412	et	4	main
soovitatav	doc_767882159205_item	2849413	et	4	main
illustreerida	doc_767882159205_item	2849414	et	3	main
näidetega	doc_767882159205_item	2849415	et	3	main
mis	doc_767882159205_item	2849416	et	4	main
teeb	doc_767882159205_item	2849417	et	3	main
eestlastest	doc_767882159205_item	2849418	et	4	main
laulurahva	doc_767882159205_item	2849419	et	3	main
väga	doc_761051790173_item	2849347	et	3	main
vastutavad	doc_761051790173_item	2849358	et	4	main
siis	doc_761051790173_item	2849359	et	3	main
ise	doc_761051790173_item	2849360	et	4	main
ei	doc_761051790173_item	2849372	et	4	main
essee	doc_767882159205_item	2849378	et	4	main
keele	doc_767882159205_item	2849383	et	4	main
huvitavad	doc_767882159205_item	2849430	et	4	main
laulupeod	doc_767882159205_item	2849441	et	4	main
mille	doc_767882159205_item	2849449	et	3	main
korraldamise	doc_767882159205_item	2849450	et	4	main
tuli	doc_767882159205_item	2849452	et	4	main
vanemuise	doc_767882159205_item	2849453	et	4	main
voldemar	doc_767882159205_item	2849457	et	4	main
osalesid	doc_767882159205_item	2849460	et	4	main
traditsioonilised	doc_767882159205_item	2849467	et	4	main
tallinnas	doc_767882159205_item	2849470	et	4	main
lauluväljakul	doc_767882159205_item	2849471	et	3	main
palju	doc_767882159205_item	2849472	et	4	main
hulgas	doc_767882159205_item	2849480	et	4	main
on	doc_767882159205_item	2849481	et	4	main
populaarne	doc_767882159205_item	2849482	et	3	main
eestlastel	doc_767882159205_item	2849516	et	4	main
huvitav	doc_767882159205_item	2849422	et	4	main
küsimus	doc_767882159205_item	2849423	et	4	main
ma	doc_767882159205_item	2849424	et	3	main
arvan	doc_767882159205_item	2849425	et	3	main
ja	doc_767882159205_item	2849431	et	3	main
tõelised	doc_767882159205_item	2849432	et	4	main
näiteks	doc_767882159205_item	2849434	et	4	main
eestis	doc_767882159205_item	2849435	et	3	main
tihti	doc_767882159205_item	2849436	et	3	main
kõige	doc_767882159205_item	2849442	et	4	main
tähtsaim	doc_767882159205_item	2849443	et	4	main
laulupidu	doc_767882159205_item	2849444	et	4	main
toimus	doc_767882159205_item	2849445	et	3	main
seltsist	doc_767882159205_item	2849454	et	4	main
laulupeod	doc_767882159205_item	2849464	et	4	main
muusika	doc_767882159205_item	2849476	et	4	main
ja	doc_767882159205_item	2849477	et	3	main
populaarne	doc_767882159205_item	2849485	et	3	main
ka	doc_767882159205_item	2849486	et	3	main
vana	doc_767882159205_item	2849488	et	4	main
arhiivides	doc_767882159205_item	2849487	et	3	main
laulu	doc_767882159205_item	2849489	et	4	main
otsima	doc_767882159205_item	2849490	et	4	main
ma	doc_767882159205_item	2849491	et	3	main
arvan	doc_767882159205_item	2849492	et	3	main
et	doc_767882159205_item	2849493	et	3	main
see	doc_767882159205_item	2849494	et	3	main
on	doc_767882159205_item	2849495	et	4	main
huvitav	doc_767882159205_item	2849496	et	4	main
oma	doc_767882159205_item	2849497	et	4	main
rahvast	doc_767882159205_item	2849498	et	4	main
palju	doc_767882159205_item	2849499	et	4	main
teada	doc_767882159205_item	2849500	et	3	main
ja	doc_767882159205_item	2849501	et	3	main
noored	doc_767882159205_item	2849502	et	3	main
peavad	doc_767882159205_item	2849503	et	4	main
teada	doc_767882159205_item	2849504	et	3	main
oma	doc_767882159205_item	2849505	et	4	main
rahvaajaloost	doc_767882159205_item	2849506	et	4	main
ja	doc_767882159205_item	2849507	et	3	main
ka	doc_767882159205_item	2849508	et	3	main
oma	doc_767882159205_item	2849509	et	4	main
palju	doc_767882159205_item	2849511	et	4	main
rahvalauluajaloost	doc_767882159205_item	2849510	et	4	main
on	doc_767882159205_item	2849512	et	4	main
huvitav	doc_767882159205_item	2849513	et	4	main
väga	doc_767882159205_item	2849429	et	3	main
laulutraditsioonid	doc_767882159205_item	2849433	et	3	main
toimusid	doc_767882159205_item	2849437	et	4	main
ja	doc_767882159205_item	2849438	et	3	main
toimuvad	doc_767882159205_item	2849439	et	4	main
tartus	doc_767882159205_item	2849448	et	3	main
eesotsas	doc_767882159205_item	2849455	et	4	main
peol	doc_767882159205_item	2849459	et	4	main
palju	doc_767882159205_item	2849461	et	4	main
inimesi	doc_767882159205_item	2849462	et	4	main
niisugused	doc_767882159205_item	2849463	et	3	main
nad	doc_767882159205_item	2849468	et	3	main
tantsu	doc_767882159205_item	2849478	et	4	main
noorte	doc_767882159205_item	2849479	et	3	main
on	doc_767882159205_item	2849484	et	4	main
rikkad	doc_767882159205_item	2849518	et	4	main
eeslaulja	doc_767882159205_item	2849531	et	4	main
ja	doc_767882159205_item	2849532	et	3	main
sellega	doc_767882159205_item	2849540	et	3	main
mõtteaega	doc_767882159205_item	2849542	et	4	main
meres	doc_767882159205_item	2849554	et	3	main
vokaalnelaulud	doc_767882159205_item	2849563	et	4	main
oma	doc_767882159205_item	2849576	et	4	main
sai	doc_767882159205_item	2849604	et	4	main
ma	doc_767882159205_item	2849616	et	3	main
aru	doc_767882159205_item	2849618	et	4	main
padar	doc_767882159205_item	2849624	et	4	main
tore	doc_767882159205_item	2849629	et	3	main
ta	doc_767882159205_item	2849631	et	4	main
mulle	doc_767882159205_item	2849633	et	4	main
väga	doc_767882159205_item	2849634	et	3	main
ma	doc_767882159205_item	2849635	et	3	main
arvan	doc_767882159205_item	2849636	et	3	main
et	doc_767882159205_item	2849637	et	3	main
populaarne	doc_767882159205_item	2849654	et	3	main
teada	doc_767882159205_item	2849514	et	3	main
et	doc_767882159205_item	2849515	et	3	main
eesti	doc_767882159205_item	2849520	et	4	main
laulutraditsiooni	doc_767882159205_item	2849522	et	4	main
rahvalaul	doc_767882159205_item	2849527	et	4	main
rahvalaulus	doc_767882159205_item	2849528	et	3	main
kordis	doc_767882159205_item	2849535	et	4	main
sest	doc_767882159205_item	2849550	et	4	main
mehed	doc_767882159205_item	2849551	et	3	main
muusikal	doc_767882159205_item	2849568	et	4	main
praegu	doc_767882159205_item	2849578	et	3	main
esimese	doc_767882159205_item	2849605	et	3	main
2001	doc_767882159205_item	2849609	et	2	main
eurovisioon	doc_767882159205_item	2849611	et	3	main
ja	doc_767882159205_item	2849615	et	3	main
saan	doc_767882159205_item	2849617	et	4	main
miks	doc_767882159205_item	2849619	et	4	main
see	doc_767882159205_item	2849620	et	3	main
läänemeresoome	doc_767882159205_item	2849524	et	3	main
iseloomulik	doc_767882159205_item	2849526	et	3	main
tihti	doc_767882159205_item	2849529	et	3	main
laulsid	doc_767882159205_item	2849530	et	4	main
mis	doc_767882159205_item	2849534	et	4	main
andes	doc_767882159205_item	2849539	et	4	main
olid	doc_767882159205_item	2849552	et	4	main
tihti	doc_767882159205_item	2849553	et	3	main
ajal	doc_767882159205_item	2849556	et	4	main
laule	doc_767882159205_item	2849557	et	4	main
lauldi	doc_767882159205_item	2849558	et	3	main
hakkavad	doc_767882159205_item	2849569	et	4	main
instrumentid	doc_767882159205_item	2849572	et	4	main
kapp	doc_767882159205_item	2849573	et	3	main
ka	doc_767882159205_item	2849574	et	3	main
kirjutas	doc_767882159205_item	2849575	et	3	main
on	doc_767882159205_item	2849579	et	4	main
populaarne	doc_767882159205_item	2849580	et	3	main
pop	doc_767882159205_item	2849581	et	4	main
ja	doc_767882159205_item	2849583	et	3	main
muusika	doc_767882159205_item	2849582	et	4	main
eestis	doc_767882159205_item	2849584	et	3	main
on	doc_767882159205_item	2849585	et	4	main
ka	doc_767882159205_item	2849586	et	3	main
oma	doc_767882159205_item	2849587	et	4	main
pop	doc_767882159205_item	2849588	et	4	main
muusika	doc_767882159205_item	2849589	et	4	main
ma	doc_767882159205_item	2849590	et	3	main
arvan	doc_767882159205_item	2849591	et	3	main
et	doc_767882159205_item	2849592	et	3	main
see	doc_767882159205_item	2849593	et	3	main
on	doc_767882159205_item	2849594	et	4	main
hea	doc_767882159205_item	2849595	et	4	main
muusika	doc_767882159205_item	2849596	et	4	main
ja	doc_767882159205_item	2849597	et	3	main
eestlased	doc_767882159205_item	2849598	et	3	main
oskavad	doc_767882159205_item	2849599	et	4	main
seda	doc_767882159205_item	2849600	et	3	main
teha	doc_767882159205_item	2849601	et	3	main
sest	doc_767882159205_item	2849602	et	4	main
eesti	doc_767882159205_item	2849603	et	4	main
eurovisioonis	doc_767882159205_item	2849607	et	3	main
ja	doc_767882159205_item	2849608	et	3	main
aastal	doc_767882159205_item	2849610	et	3	main
toimus	doc_767882159205_item	2849613	et	3	main
tanel	doc_767882159205_item	2849623	et	4	main
benton	doc_767882159205_item	2849627	et	4	main
hulgas	doc_767882159205_item	2849650	et	4	main
laulda	doc_767882159205_item	2849655	et	4	main
on	doc_767882159205_item	2849657	et	4	main
osa	doc_767882159205_item	2849659	et	4	main
elust	doc_767882159205_item	2849660	et	3	main
heal	doc_767882159205_item	2849668	et	3	main
ja	doc_767882159205_item	2849625	et	3	main
laulu	doc_767882159205_item	2849630	et	4	main
eestlaste	doc_767882159205_item	2849638	et	4	main
laulutraditsioonitel	doc_767882159205_item	2849639	et	4	main
oli	doc_767882159205_item	2849640	et	3	main
tore	doc_767882159205_item	2849641	et	3	main
minevik	doc_767882159205_item	2849642	et	3	main
ja	doc_767882159205_item	2849643	et	3	main
ka	doc_767882159205_item	2849644	et	3	main
ja	doc_767882159205_item	2849652	et	3	main
on	doc_767882159205_item	2849662	et	4	main
saatnud	doc_767882159205_item	2849663	et	4	main
halval	doc_767882159205_item	2849666	et	3	main
ajal	doc_767882159205_item	2849669	et	4	main
ja	doc_767882159205_item	2849670	et	3	main
see	doc_767882159205_item	2849671	et	3	main
teeb	doc_767882159205_item	2849672	et	3	main
eestlastest	doc_767882159205_item	2849673	et	4	main
laulurahva	doc_767882159205_item	2849674	et	3	main
kui	doc_767882159205_item	2849667	et	3	main
eesti	doc_767882159208_item	2850259	et	4	main
faktidele	doc_767882159208_item	2850290	et	3	main
on	doc_767882159208_item	2850297	et	4	main
rahvasel	doc_767882159208_item	2850304	et	4	main
omadused	doc_767882159208_item	2850307	et	4	main
me	doc_767882159208_item	2850312	et	4	main
keele	doc_767882159208_item	2850263	et	4	main
kirjutamine	doc_767882159208_item	2850265	et	4	main
kirjutage	doc_767882159208_item	2850266	et	3	main
essee	doc_767882159208_item	2850267	et	4	main
lugemistekstis	doc_767882159208_item	2850288	et	3	main
on	doc_767882159208_item	2850292	et	4	main
soovitatav	doc_767882159208_item	2850293	et	4	main
illustreerida	doc_767882159208_item	2850294	et	3	main
oma	doc_767882159208_item	2850306	et	4	main
poolest	doc_767882159208_item	2850311	et	4	main
voime	doc_767882159208_item	2850313	et	4	main
teada	doc_767882159208_item	2850314	et	3	main
mis	doc_767882159208_item	2850315	et	4	main
teeb	doc_767882159208_item	2850316	et	3	main
palju	doc_767882159208_item	2850325	et	4	main
laule	doc_767882159208_item	2850326	et	4	main
nad	doc_767882159208_item	2850327	et	3	main
olnud	doc_767882159208_item	2850339	et	4	main
folkloor	doc_767882159208_item	2850350	et	4	main
3	doc_767882159208_item	2850352	et	2	main
mis	doc_767882159208_item	2850366	et	4	main
sündmus	doc_767882159208_item	2850373	et	3	main
ülemaaline	doc_767882159208_item	2850376	et	4	main
aastal	doc_767882159208_item	2850391	et	3	main
ainult	doc_767882159208_item	2850397	et	4	main
meeskoorid	doc_767882159208_item	2850398	et	4	main
osavõtjatena	doc_767882159208_item	2850402	et	3	main
keele	doc_767882159208_item	2850260	et	4	main
kui	doc_767882159208_item	2850261	et	3	main
esitatud	doc_767882159208_item	2850289	et	4	main
väiteid	doc_767882159208_item	2850291	et	4	main
iga	doc_767882159208_item	2850298	et	4	main
on	doc_767882159208_item	2850305	et	4	main
mille	doc_767882159208_item	2850310	et	3	main
eestlased	doc_767882159208_item	2850322	et	3	main
väga	doc_767882159208_item	2850324	et	3	main
et	doc_767882159208_item	2850336	et	3	main
eestlaste	doc_767882159208_item	2850341	et	4	main
hingedes	doc_767882159208_item	2850342	et	3	main
eesti	doc_767882159208_item	2850343	et	4	main
folkloor	doc_767882159208_item	2850344	et	4	main
mängib	doc_767882159208_item	2850345	et	3	main
suurt	doc_767882159208_item	2850346	et	3	main
rolli	doc_767882159208_item	2850347	et	4	main
ka	doc_767882159208_item	2850348	et	3	main
pillid	doc_767882159208_item	2850354	et	4	main
laulud	doc_767882159208_item	2850355	et	3	main
laulud	doc_767882159208_item	2850358	et	3	main
mis	doc_767882159208_item	2850378	et	4	main
tartus	doc_767882159208_item	2850382	et	3	main
traditsioon	doc_767882159208_item	2850384	et	3	main
tallinnasse	doc_767882159208_item	2850386	et	3	main
ajal	doc_767882159208_item	2850393	et	4	main
võttsid	doc_767882159208_item	2850395	et	4	main
juba	doc_767882159208_item	2850399	et	3	main
ka	doc_767882159208_item	2850421	et	3	main
öelda	doc_767882159208_item	2850424	et	4	main
et	doc_767882159208_item	2850425	et	3	main
ole	doc_767882159208_item	2850430	et	4	main
tagupidi	doc_767882159208_item	2850433	et	3	main
huvi	doc_767882159208_item	2850435	et	4	main
igal	doc_767882159208_item	2850437	et	3	main
peol	doc_767882159208_item	2850438	et	4	main
esinevad	doc_767882159208_item	2850439	et	4	main
lastekoorid	doc_767882159208_item	2850440	et	3	main
väga	doc_767882159208_item	2850445	et	3	main
mis	doc_767882159208_item	2850448	et	4	main
on	doc_767882159208_item	2850449	et	4	main
muusikale	doc_767882159208_item	2850459	et	4	main
seetõttu	doc_767882159208_item	2850460	et	3	main
ma	doc_767882159208_item	2850461	et	3	main
arvan	doc_767882159208_item	2850462	et	3	main
omapärane	doc_767882159208_item	2850467	et	4	main
instrument	doc_767882159208_item	2850470	et	3	main
kaneel	doc_767882159208_item	2850471	et	3	main
kui	doc_767882159208_item	2850478	et	3	main
eesti	doc_767882159208_item	2850479	et	4	main
üks	doc_767882159208_item	2850481	et	3	main
ka	doc_767882159208_item	2850486	et	3	main
koigepealt	doc_767882159208_item	2850499	et	4	main
et	doc_767882159208_item	2850504	et	3	main
oskab	doc_767882159208_item	2850507	et	3	main
säilitada	doc_767882159208_item	2850508	et	3	main
kombeid	doc_767882159208_item	2850509	et	4	main
nende	doc_767882159208_item	2850510	et	4	main
see	doc_767882159208_item	2850515	et	3	main
teise	doc_767882159208_item	2850262	et	4	main
üldistav	doc_767882159208_item	2850284	et	4	main
tuginema	doc_767882159208_item	2850285	et	3	main
loengus	doc_767882159208_item	2850286	et	3	main
kultuurinähtus	doc_767882159208_item	2850299	et	4	main
kombed	doc_767882159208_item	2850308	et	3	main
laulurahva	doc_767882159208_item	2850319	et	3	main
nii	doc_767882159208_item	2850329	et	3	main
töötades	doc_767882159208_item	2850330	et	3	main
kui	doc_767882159208_item	2850331	et	3	main
ka	doc_767882159208_item	2850332	et	3	main
puhkamisel	doc_767882159208_item	2850333	et	4	main
see	doc_767882159208_item	2850334	et	3	main
tähendab	doc_767882159208_item	2850335	et	3	main
ajaloos	doc_767882159208_item	2850349	et	4	main
koosneb	doc_767882159208_item	2850351	et	3	main
osadest	doc_767882159208_item	2850353	et	3	main
ja	doc_767882159208_item	2850356	et	3	main
tantsud	doc_767882159208_item	2850357	et	3	main
on	doc_767882159208_item	2850367	et	4	main
kiriku	doc_767882159208_item	2850368	et	3	main
sisuga	doc_767882159208_item	2850369	et	3	main
kõige	doc_767882159208_item	2850370	et	4	main
on	doc_767882159208_item	2850374	et	4	main
laulupidu	doc_767882159208_item	2850377	et	4	main
aastal	doc_767882159208_item	2850381	et	3	main
kandus	doc_767882159208_item	2850385	et	3	main
ja	doc_767882159208_item	2850387	et	3	main
toimus	doc_767882159208_item	2850389	et	3	main
kohta	doc_767882159208_item	2850428	et	4	main
ei	doc_767882159208_item	2850429	et	4	main
see	doc_767882159208_item	2850434	et	3	main
kasvab	doc_767882159208_item	2850436	et	3	main
lauljad	doc_767882159208_item	2850441	et	4	main
samuti	doc_767882159208_item	2850442	et	3	main
seotud	doc_767882159208_item	2850450	et	4	main
et	doc_767882159208_item	2850463	et	3	main
eestlastel	doc_767882159208_item	2850468	et	4	main
eestlastel	doc_767882159208_item	2850484	et	4	main
palju	doc_767882159208_item	2850487	et	4	main
on	doc_767882159208_item	2850500	et	4	main
jaoks	doc_767882159208_item	2850511	et	4	main
essee	doc_767882159208_item	2850258	et	4	main
test	doc_767882159208_item	2850264	et	3	main
teemal	doc_767882159208_item	2850268	et	3	main
mis	doc_767882159208_item	2850269	et	4	main
teeb	doc_767882159208_item	2850270	et	3	main
eestlastest	doc_767882159208_item	2850271	et	4	main
laulurahva	doc_767882159208_item	2850272	et	3	main
essee	doc_767882159208_item	2850273	et	4	main
pikkus	doc_767882159208_item	2850274	et	4	main
350	doc_767882159208_item	2850276	et	2	main
sõna	doc_767882159208_item	2850277	et	4	main
essee	doc_767882159208_item	2850278	et	4	main
300	doc_767882159208_item	2850275	et	2	main
peab	doc_767882159208_item	2850279	et	4	main
olema	doc_767882159208_item	2850280	et	4	main
arutlev	doc_767882159208_item	2850281	et	4	main
analüüsiv	doc_767882159208_item	2850282	et	4	main
ja	doc_767882159208_item	2850283	et	3	main
ja	doc_767882159208_item	2850287	et	3	main
näidetega	doc_767882159208_item	2850295	et	3	main
laulmine	doc_767882159208_item	2850296	et	4	main
laulmine	doc_767882159208_item	2850300	et	4	main
väljendab	doc_767882159208_item	2850301	et	3	main
meid	doc_767882159208_item	2850302	et	4	main
igal	doc_767882159208_item	2850303	et	3	main
eluviisid	doc_767882159208_item	2850309	et	3	main
näiteks	doc_767882159208_item	2850317	et	4	main
eestlastest	doc_767882159208_item	2850318	et	4	main
vanal	doc_767882159208_item	2850320	et	3	main
ajal	doc_767882159208_item	2850321	et	4	main
kasutati	doc_767882159208_item	2850323	et	4	main
muusika	doc_767882159208_item	2850337	et	4	main
on	doc_767882159208_item	2850338	et	4	main
kui	doc_767882159208_item	2850362	et	3	main
ka	doc_767882159208_item	2850363	et	3	main
uus	doc_767882159208_item	2850364	et	3	main
rahvalaul	doc_767882159208_item	2850365	et	4	main
ajalooline	doc_767882159208_item	2850372	et	4	main
kujunes	doc_767882159208_item	2850379	et	3	main
osa	doc_767882159208_item	2850396	et	4	main
hiljem	doc_767882159208_item	2850400	et	3	main
muusika	doc_767882159208_item	2850427	et	4	main
nad	doc_767882159208_item	2850473	et	3	main
tihti	doc_767882159208_item	2850474	et	3	main
kasutavad	doc_767882159208_item	2850475	et	4	main
bajaani	doc_767882159208_item	2850476	et	4	main
venemaa	doc_767882159208_item	2850482	et	4	main
osadest	doc_767882159208_item	2850483	et	3	main
rahvalaulu	doc_767882159208_item	2850489	et	4	main
jne	doc_767882159208_item	2850490	et	4	main
laulupidu	doc_767882159208_item	2850501	et	4	main
see	doc_767882159208_item	2850502	et	3	main
näitab	doc_767882159208_item	2850503	et	3	main
eesti	doc_767882159208_item	2850505	et	4	main
laulsid	doc_767882159208_item	2850328	et	4	main
alati	doc_767882159208_item	2850340	et	4	main
on	doc_767882159208_item	2850359	et	4	main
nii	doc_767882159208_item	2850360	et	3	main
vanadrahvalaulud	doc_767882159208_item	2850361	et	4	main
tähtsam	doc_767882159208_item	2850371	et	4	main
esimene	doc_767882159208_item	2850375	et	3	main
1869	doc_767882159208_item	2850380	et	2	main
pärast	doc_767882159208_item	2850383	et	4	main
see	doc_767882159208_item	2850388	et	3	main
1869	doc_767882159208_item	2850390	et	2	main
vanal	doc_767882159208_item	2850392	et	3	main
laulupeol	doc_767882159208_item	2850394	et	4	main
lisanduti	doc_767882159208_item	2850401	et	4	main
naiskoorid	doc_767882159208_item	2850403	et	3	main
lastekoorid	doc_767882159208_item	2850404	et	3	main
ja	doc_767882159208_item	2850405	et	3	main
siis	doc_767882159208_item	2850406	et	3	main
poistekoorid	doc_767882159208_item	2850407	et	3	main
on	doc_767882159208_item	2850409	et	4	main
ka	doc_767882159208_item	2850410	et	3	main
meie	doc_767882159208_item	2850411	et	4	main
koorid	doc_767882159208_item	2850408	et	4	main
päevadel	doc_767882159208_item	2850412	et	3	main
väga	doc_767882159208_item	2850413	et	3	main
palju	doc_767882159208_item	2850414	et	4	main
last	doc_767882159208_item	2850415	et	4	main
laulavad	doc_767882159208_item	2850416	et	4	main
muusikakoolides	doc_767882159208_item	2850417	et	3	main
ja	doc_767882159208_item	2850418	et	3	main
tavaliste	doc_767882159208_item	2850419	et	4	main
koolides	doc_767882159208_item	2850420	et	3	main
võib-olla	doc_767882159208_item	2850432	et	3	main
on	doc_767882159208_item	2850444	et	4	main
mänge	doc_767882159208_item	2850447	et	3	main
eesti	doc_767882159208_item	2850458	et	4	main
eesti	doc_767882159208_item	2850464	et	4	main
on	doc_767882159208_item	2850466	et	4	main
on	doc_767882159208_item	2850469	et	4	main
veel	doc_767882159208_item	2850472	et	4	main
oli	doc_767882159208_item	2850480	et	3	main
on	doc_767882159208_item	2850485	et	4	main
heliloojat	doc_767882159208_item	2850488	et	3	main
ma	doc_767882159208_item	2850491	et	3	main
arvan	doc_767882159208_item	2850492	et	3	main
et	doc_767882159208_item	2850493	et	3	main
see	doc_767882159208_item	2850494	et	3	main
mis	doc_767882159208_item	2850495	et	4	main
teeb	doc_767882159208_item	2850496	et	3	main
rahvas	doc_767882159208_item	2850506	et	4	main
siinme	doc_767882159208_item	2850422	et	4	main
võime	doc_767882159208_item	2850423	et	4	main
huvi	doc_767882159208_item	2850426	et	4	main
kadunud	doc_767882159208_item	2850431	et	4	main
eestlastel	doc_767882159208_item	2850443	et	4	main
palju	doc_767882159208_item	2850446	et	4	main
muusikaga	doc_767882159208_item	2850451	et	3	main
ajaloos	doc_767882159208_item	2850452	et	4	main
on	doc_767882159208_item	2850453	et	4	main
palju	doc_767882159208_item	2850454	et	4	main
faktoreid	doc_767882159208_item	2850455	et	3	main
mis	doc_767882159208_item	2850456	et	4	main
mõjutasid	doc_767882159208_item	2850457	et	4	main
rahvaviis	doc_767882159208_item	2850465	et	3	main
näiteks	doc_767882159208_item	2850477	et	4	main
eestirahvast	doc_767882159208_item	2850497	et	4	main
laulurahva	doc_767882159208_item	2850498	et	3	main
on	doc_767882159208_item	2850512	et	4	main
väga	doc_767882159208_item	2850513	et	3	main
tähtis	doc_767882159208_item	2850514	et	4	main
essee	doc_767882159213_item	2851522	et	4	main
rahvakultuur	doc_767882159213_item	2851544	et	3	main
laulu-	doc_767882159213_item	2851550	et	4	main
iseloomulik	doc_767882159213_item	2851566	et	3	main
tuhat	doc_767882159213_item	2851574	et	4	main
aastat	doc_767882159213_item	2851575	et	3	main
sellest	doc_767882159213_item	2851611	et	4	main
peab	doc_767882159213_item	2851523	et	4	main
väiteid	doc_767882159213_item	2851535	et	4	main
riiklik	doc_767882159213_item	2851543	et	3	main
et	doc_767882159213_item	2851547	et	3	main
on	doc_767882159213_item	2851549	et	4	main
ja	doc_767882159213_item	2851551	et	3	main
tantsurahvas	doc_767882159213_item	2851552	et	4	main
ja	doc_767882159213_item	2851557	et	3	main
ajalugu	doc_767882159213_item	2851559	et	4	main
vanemat	doc_767882159213_item	2851561	et	4	main
kujunenud	doc_767882159213_item	2851571	et	4	main
enam	doc_767882159213_item	2851572	et	4	main
kui	doc_767882159213_item	2851573	et	3	main
liikumise	doc_767882159213_item	2851615	et	4	main
kõrghetk	doc_767882159213_item	2851616	et	3	main
räägib	doc_767882159213_item	2851618	et	3	main
meile	doc_767882159213_item	2851619	et	4	main
et	doc_767882159213_item	2851621	et	3	main
on	doc_767882159213_item	2851625	et	4	main
vaga	doc_767882159213_item	2851626	et	4	main
tähtsad	doc_767882159213_item	2851627	et	3	main
ja	doc_767882159213_item	2851628	et	3	main
meie	doc_767882159213_item	2851638	et	4	main
laulupeod	doc_767882159213_item	2851640	et	4	main
toimuvad	doc_767882159213_item	2851641	et	4	main
ka	doc_767882159213_item	2851642	et	3	main
igal	doc_767882159213_item	2851643	et	3	main
aastal	doc_767882159213_item	2851644	et	3	main
see	doc_767882159213_item	2851645	et	3	main
tähendab	doc_767882159213_item	2851646	et	3	main
et	doc_767882159213_item	2851647	et	3	main
eestlased	doc_767882159213_item	2851648	et	3	main
ja	doc_767882159213_item	2851652	et	3	main
56	doc_767882159213_item	2851671	et	2	main
aastal	doc_767882159213_item	2851675	et	3	main
lauljat	doc_767882159213_item	2851681	et	4	main
70	doc_767882159213_item	2851682	et	2	main
000	doc_767882159213_item	2851683	et	2	main
ühtekokku	doc_767882159213_item	2851687	et	3	main
arutlev	doc_767882159213_item	2851525	et	4	main
ja	doc_767882159213_item	2851527	et	3	main
eestlastel	doc_767882159213_item	2851540	et	4	main
rääkida	doc_767882159213_item	2851546	et	3	main
on	doc_767882159213_item	2851555	et	4	main
huvitav	doc_767882159213_item	2851558	et	4	main
eesti	doc_767882159213_item	2851560	et	4	main
regivärsiline	doc_767882159213_item	2851567	et	4	main
rahvalaul	doc_767882159213_item	2851568	et	4	main
mis	doc_767882159213_item	2851569	et	4	main
on	doc_767882159213_item	2851570	et	4	main
võtsid	doc_767882159213_item	2851579	et	4	main
tähtsusega	doc_767882159213_item	2851610	et	4	main
sellest	doc_767882159213_item	2851620	et	4	main
eesti	doc_767882159213_item	2851622	et	4	main
essee	doc_767882159213_item	2851502	et	4	main
eesti	doc_767882159213_item	2851503	et	4	main
keele	doc_767882159213_item	2851504	et	4	main
kui	doc_767882159213_item	2851505	et	3	main
teise	doc_767882159213_item	2851506	et	4	main
keele	doc_767882159213_item	2851507	et	4	main
test	doc_767882159213_item	2851508	et	3	main
kirjutamine	doc_767882159213_item	2851509	et	4	main
kirjutage	doc_767882159213_item	2851510	et	3	main
essee	doc_767882159213_item	2851511	et	4	main
teemal	doc_767882159213_item	2851512	et	3	main
mis	doc_767882159213_item	2851513	et	4	main
teeb	doc_767882159213_item	2851514	et	3	main
eestlastest	doc_767882159213_item	2851515	et	4	main
laulurahva	doc_767882159213_item	2851516	et	3	main
essee	doc_767882159213_item	2851517	et	4	main
pikkus	doc_767882159213_item	2851518	et	4	main
300	doc_767882159213_item	2851519	et	2	main
350	doc_767882159213_item	2851520	et	2	main
sõna	doc_767882159213_item	2851521	et	4	main
olema	doc_767882159213_item	2851524	et	4	main
analüüsiv	doc_767882159213_item	2851526	et	4	main
üldistav	doc_767882159213_item	2851528	et	4	main
tuginema	doc_767882159213_item	2851529	et	3	main
loengus	doc_767882159213_item	2851530	et	3	main
ja	doc_767882159213_item	2851531	et	3	main
lugemistekstis	doc_767882159213_item	2851532	et	3	main
esitatud	doc_767882159213_item	2851533	et	4	main
faktidele	doc_767882159213_item	2851534	et	3	main
on	doc_767882159213_item	2851541	et	4	main
väga	doc_767882159213_item	2851542	et	3	main
pikk	doc_767882159213_item	2851556	et	4	main
palju	doc_767882159213_item	2851580	et	4	main
saksa	doc_767882159213_item	2851581	et	4	main
rootsi	doc_767882159213_item	2851582	et	4	main
soome	doc_767882159213_item	2851583	et	3	main
ja	doc_767882159213_item	2851584	et	3	main
slaavi	doc_767882159213_item	2851585	et	3	main
laulutraditsioonidest	doc_767882159213_item	2851586	et	3	main
selle	doc_767882159213_item	2851587	et	4	main
pärast	doc_767882159213_item	2851588	et	4	main
eesti	doc_767882159213_item	2851589	et	4	main
kultuur	doc_767882159213_item	2851590	et	3	main
on	doc_767882159213_item	2851591	et	4	main
väga	doc_767882159213_item	2851592	et	3	main
erinev	doc_767882159213_item	2851593	et	4	main
ja	doc_767882159213_item	2851594	et	3	main
huvitav	doc_767882159213_item	2851595	et	4	main
eestlased	doc_767882159213_item	2851596	et	3	main
alati	doc_767882159213_item	2851597	et	4	main
armastasid	doc_767882159213_item	2851598	et	4	main
oma	doc_767882159213_item	2851599	et	4	main
laulud	doc_767882159213_item	2851600	et	3	main
ja	doc_767882159213_item	2851601	et	3	main
rakendasid	doc_767882159213_item	2851602	et	4	main
oma	doc_767882159213_item	2851603	et	4	main
traditsioonid	doc_767882159213_item	2851604	et	3	main
laulupeo	doc_767882159213_item	2851605	et	4	main
korraldamine	doc_767882159213_item	2851606	et	4	main
on	doc_767882159213_item	2851607	et	4	main
on	doc_767882159213_item	2851536	et	4	main
soovitatav	doc_767882159213_item	2851537	et	4	main
illustreerida	doc_767882159213_item	2851538	et	3	main
näidetega	doc_767882159213_item	2851539	et	3	main
võib	doc_767882159213_item	2851545	et	3	main
eestlased	doc_767882159213_item	2851548	et	3	main
eesti	doc_767882159213_item	2851553	et	4	main
kultuuris	doc_767882159213_item	2851554	et	3	main
laulutraditsiooni	doc_767882159213_item	2851562	et	4	main
esindab	doc_767882159213_item	2851563	et	3	main
läänemeresoome	doc_767882159213_item	2851564	et	3	main
kultuurile	doc_767882159213_item	2851565	et	3	main
tagasi	doc_767882159213_item	2851576	et	3	main
eestlaste	doc_767882159213_item	2851577	et	4	main
laulutraditsioonid	doc_767882159213_item	2851578	et	3	main
eestlaste	doc_767882159213_item	2851613	et	4	main
rahvusliku	doc_767882159213_item	2851614	et	3	main
ajaloos	doc_767882159213_item	2851623	et	4	main
laulurahva	doc_767882159213_item	2851631	et	3	main
neile	doc_767882159213_item	2851660	et	4	main
laulupeol	doc_767882159213_item	2851662	et	4	main
46	doc_767882159213_item	2851664	et	2	main
822	doc_767882159213_item	2851666	et	2	main
lauljaga	doc_767882159213_item	2851667	et	4	main
ja	doc_767882159213_item	2851668	et	3	main
5	doc_767882159213_item	2851669	et	2	main
puhkpilliorkestrit	doc_767882159213_item	2851670	et	3	main
1994	doc_767882159213_item	2851674	et	2	main
tartus	doc_767882159213_item	2851676	et	3	main
laulis	doc_767882159213_item	2851677	et	4	main
umbes	doc_767882159213_item	2851678	et	4	main
16	doc_767882159213_item	2851679	et	2	main
000	doc_767882159213_item	2851680	et	2	main
laulis	doc_767882159213_item	2851686	et	4	main
pealtvaatajale	doc_767882159213_item	2851693	et	3	main
see	doc_767882159213_item	2851700	et	3	main
eller	doc_767882159213_item	2851722	et	4	main
tore	doc_767882159213_item	2851729	et	3	main
laulupeol	doc_767882159213_item	2851731	et	4	main
alati	doc_767882159213_item	2851733	et	4	main
palju	doc_767882159213_item	2851734	et	4	main
noori	doc_767882159213_item	2851735	et	3	main
see	doc_767882159213_item	2851736	et	3	main
tähendab	doc_767882159213_item	2851737	et	3	main
muusika	doc_767882159213_item	2851752	et	4	main
padari	doc_767882159213_item	2851756	et	4	main
bentoni	doc_767882159213_item	2851759	et	4	main
võit	doc_767882159213_item	2851760	et	3	main
2001	doc_767882159213_item	2851762	et	2	main
suur	doc_767882159213_item	2851765	et	3	main
mäletavad	doc_767882159213_item	2851773	et	4	main
poisid	doc_767882159213_item	2851782	et	4	main
vanad	doc_767882159213_item	2851784	et	3	main
on	doc_767882159213_item	2851796	et	4	main
sündmus	doc_767882159213_item	2851608	et	3	main
ajaloolise	doc_767882159213_item	2851609	et	4	main
see	doc_767882159213_item	2851617	et	3	main
eestlastest	doc_767882159213_item	2851630	et	4	main
oli	doc_767882159213_item	2851634	et	3	main
ja	doc_767882159213_item	2851637	et	3	main
oma	doc_767882159213_item	2851650	et	4	main
traditsioonid	doc_767882159213_item	2851651	et	3	main
väga	doc_767882159213_item	2851658	et	3	main
mängijaga	doc_767882159213_item	2851672	et	4	main
000	doc_767882159213_item	2851689	et	2	main
100	doc_767882159213_item	2851691	et	2	main
ja	doc_767882159213_item	2851694	et	3	main
igal	doc_767882159213_item	2851695	et	3	main
laulupidu	doc_767882159213_item	2851697	et	4	main
heino	doc_767882159213_item	2851721	et	4	main
ja	doc_767882159213_item	2851723	et	3	main
eesti	doc_767882159213_item	2851739	et	4	main
sellest	doc_767882159213_item	2851753	et	4	main
ja	doc_767882159213_item	2851757	et	3	main
laulavad	doc_767882159213_item	2851783	et	4	main
laulud	doc_767882159213_item	2851785	et	3	main
tähendab	doc_767882159213_item	2851790	et	3	main
eestlased	doc_767882159213_item	2851792	et	3	main
praegu	doc_767882159213_item	2851795	et	3	main
kujunes	doc_767882159213_item	2851612	et	3	main
tegevad	doc_767882159213_item	2851629	et	4	main
laulupidu	doc_767882159213_item	2851633	et	4	main
aastal	doc_767882159213_item	2851636	et	3	main
maletavad	doc_767882159213_item	2851649	et	4	main
nende	doc_767882159213_item	2851653	et	4	main
kultuur	doc_767882159213_item	2851654	et	3	main
ja	doc_767882159213_item	2851655	et	3	main
ajalugu	doc_767882159213_item	2851656	et	4	main
tähtsad	doc_767882159213_item	2851659	et	3	main
kuulajale	doc_767882159213_item	2851684	et	4	main
25	doc_767882159213_item	2851688	et	2	main
on	doc_767882159213_item	2851702	et	4	main
alati	doc_767882159213_item	2851703	et	4	main
populaarne	doc_767882159213_item	2851704	et	3	main
ma	doc_767882159213_item	2851705	et	3	main
arvan	doc_767882159213_item	2851706	et	3	main
et	doc_767882159213_item	2851707	et	3	main
laulupeod	doc_767882159213_item	2851708	et	4	main
aitavad	doc_767882159213_item	2851709	et	4	main
noortele	doc_767882159213_item	2851710	et	3	main
inimestele	doc_767882159213_item	2851711	et	3	main
teada	doc_767882159213_item	2851712	et	3	main
et	doc_767882159213_item	2851713	et	3	main
eestis	doc_767882159213_item	2851714	et	3	main
olid	doc_767882159213_item	2851715	et	4	main
kuulsad	doc_767882159213_item	2851716	et	3	main
nimed	doc_767882159213_item	2851717	et	3	main
nagu	doc_767882159213_item	2851718	et	3	main
gustav	doc_767882159213_item	2851719	et	4	main
ernesaks	doc_767882159213_item	2851720	et	4	main
on	doc_767882159213_item	2851728	et	4	main
et	doc_767882159213_item	2851730	et	3	main
on	doc_767882159213_item	2851732	et	4	main
et	doc_767882159213_item	2851738	et	3	main
elab	doc_767882159213_item	2851741	et	3	main
kasvab	doc_767882159213_item	2851743	et	3	main
on	doc_767882159213_item	2851745	et	4	main
populaarne	doc_767882159213_item	2851747	et	3	main
praegu	doc_767882159213_item	2851748	et	3	main
pop-	doc_767882159213_item	2851749	et	4	main
ja	doc_767882159213_item	2851750	et	3	main
tanel	doc_767882159213_item	2851755	et	4	main
dave	doc_767882159213_item	2851758	et	4	main
eurovisioonil	doc_767882159213_item	2851761	et	3	main
ja	doc_767882159213_item	2851764	et	3	main
ka	doc_767882159213_item	2851774	et	3	main
kuulsin	doc_767882159213_item	2851778	et	3	main
koolist	doc_767882159213_item	2851781	et	4	main
setu	doc_767882159213_item	2851786	et	4	main
keeles	doc_767882159213_item	2851787	et	4	main
rock-muusikaga	doc_767882159213_item	2851788	et	3	main
see	doc_767882159213_item	2851789	et	3	main
olid	doc_767882159213_item	2851793	et	4	main
ja	doc_767882159213_item	2851794	et	3	main
laulutraditsioonid	doc_767882159213_item	2851624	et	3	main
esimene	doc_767882159213_item	2851632	et	3	main
1869	doc_767882159213_item	2851635	et	2	main
ajas	doc_767882159213_item	2851639	et	4	main
on	doc_767882159213_item	2851657	et	4	main
esimesel	doc_767882159213_item	2851661	et	3	main
osales	doc_767882159213_item	2851663	et	3	main
meeskoori	doc_767882159213_item	2851665	et	4	main
aga	doc_767882159213_item	2851673	et	3	main
tallinnas	doc_767882159213_item	2851685	et	4	main
esinejat	doc_767882159213_item	2851690	et	4	main
aastal	doc_767882159213_item	2851696	et	3	main
saab	doc_767882159213_item	2851698	et	3	main
suuremaks	doc_767882159213_item	2851699	et	4	main
üritus	doc_767882159213_item	2851701	et	4	main
arvamustes	doc_767882159213_item	2851727	et	3	main
rock-	doc_767882159213_item	2851751	et	4	main
aastal	doc_767882159213_item	2851763	et	3	main
vanilla	doc_767882159213_item	2851766	et	4	main
ninja	doc_767882159213_item	2851767	et	4	main
vanad	doc_767882159213_item	2851775	et	3	main
värska	doc_767882159213_item	2851780	et	4	main
laulurahvas	doc_767882159213_item	2851797	et	4	main
000	doc_767882159213_item	2851692	et	2	main
miina	doc_767882159213_item	2851724	et	4	main
härma	doc_767882159213_item	2851725	et	4	main
minu	doc_767882159213_item	2851726	et	3	main
kultuur	doc_767882159213_item	2851740	et	3	main
ja	doc_767882159213_item	2851742	et	3	main
eestis	doc_767882159213_item	2851744	et	3	main
vaga	doc_767882159213_item	2851746	et	4	main
rääkivad	doc_767882159213_item	2851754	et	4	main
populaarsus	doc_767882159213_item	2851768	et	4	main
eestis	doc_767882159213_item	2851769	et	3	main
ja	doc_767882159213_item	2851770	et	3	main
euroopas	doc_767882159213_item	2851771	et	3	main
noored	doc_767882159213_item	2851772	et	3	main
laulud	doc_767882159213_item	2851776	et	3	main
ma	doc_767882159213_item	2851777	et	3	main
et	doc_767882159213_item	2851779	et	3	main
et	doc_767882159213_item	2851791	et	3	main
essee	doc_767882159220_item	2853529	et	4	main
kirjutamine	doc_767882159220_item	2853536	et	4	main
sõna	doc_767882159220_item	2853548	et	4	main
essee	doc_767882159220_item	2853549	et	4	main
arutlev	doc_767882159220_item	2853552	et	4	main
soovitatav	doc_767882159220_item	2853564	et	4	main
illustreerida	doc_767882159220_item	2853565	et	3	main
näidetega	doc_767882159220_item	2853566	et	3	main
mis	doc_767882159220_item	2853567	et	4	main
teeb	doc_767882159220_item	2853568	et	3	main
kui	doc_767882159220_item	2853573	et	3	main
kolmandas	doc_767882159220_item	2853575	et	3	main
mul	doc_767882159220_item	2853578	et	3	main
kooli	doc_767882159220_item	2853581	et	4	main
ilus	doc_767882159220_item	2853589	et	4	main
sinine	doc_767882159220_item	2853590	et	4	main
rahvuskleit	doc_767882159220_item	2853591	et	3	main
koos	doc_767882159220_item	2853604	et	4	main
nendega	doc_767882159220_item	2853605	et	4	main
teise	doc_767882159220_item	2853533	et	4	main
keele	doc_767882159220_item	2853534	et	4	main
essee	doc_767882159220_item	2853538	et	4	main
teeb	doc_767882159220_item	2853541	et	3	main
peab	doc_767882159220_item	2853550	et	4	main
analüüsiv	doc_767882159220_item	2853553	et	4	main
ja	doc_767882159220_item	2853554	et	3	main
loengus	doc_767882159220_item	2853557	et	3	main
esitatud	doc_767882159220_item	2853560	et	4	main
faktidele	doc_767882159220_item	2853561	et	3	main
väiteid	doc_767882159220_item	2853562	et	4	main
eestlastest	doc_767882159220_item	2853569	et	4	main
osaleda	doc_767882159220_item	2853579	et	3	main
seljas	doc_767882159220_item	2853592	et	4	main
kes	doc_767882159220_item	2853607	et	4	main
kuulas	doc_767882159220_item	2853608	et	3	main
koos	doc_767882159220_item	2853616	et	4	main
kadriorus	doc_767882159220_item	2853622	et	3	main
oli	doc_767882159220_item	2853623	et	3	main
eestlased	doc_767882159220_item	2853630	et	3	main
kõigepealt	doc_767882159220_item	2853631	et	3	main
eestlastest	doc_767882159220_item	2853636	et	4	main
laulurahva	doc_767882159220_item	2853638	et	3	main
vanad	doc_767882159220_item	2853640	et	3	main
kogemus	doc_767882159220_item	2853644	et	3	main
võiks	doc_767882159220_item	2853647	et	4	main
ajal	doc_767882159220_item	2853652	et	4	main
olnud	doc_767882159220_item	2853657	et	4	main
telerit	doc_767882159220_item	2853665	et	3	main
ja	doc_767882159220_item	2853666	et	3	main
inimesed	doc_767882159220_item	2853667	et	3	main
haridusest	doc_767882159220_item	2853713	et	4	main
ju	doc_767882159220_item	2853715	et	3	main
eestlastest	doc_767882159220_item	2853720	et	4	main
ütelda	doc_767882159220_item	2853727	et	4	main
kuidas	doc_767882159220_item	2853728	et	3	main
eesti	doc_767882159220_item	2853530	et	4	main
keele	doc_767882159220_item	2853531	et	4	main
kui	doc_767882159220_item	2853532	et	3	main
kirjutage	doc_767882159220_item	2853537	et	3	main
mis	doc_767882159220_item	2853540	et	4	main
eestlastest	doc_767882159220_item	2853542	et	4	main
essee	doc_767882159220_item	2853544	et	4	main
pikkus	doc_767882159220_item	2853545	et	4	main
300	doc_767882159220_item	2853546	et	2	main
350	doc_767882159220_item	2853547	et	2	main
tuginema	doc_767882159220_item	2853556	et	3	main
ja	doc_767882159220_item	2853558	et	3	main
lapsena	doc_767882159220_item	2853572	et	3	main
oli	doc_767882159220_item	2853588	et	3	main
ja	doc_767882159220_item	2853593	et	3	main
ma	doc_767882159220_item	2853594	et	3	main
koos	doc_767882159220_item	2853596	et	4	main
teiste	doc_767882159220_item	2853597	et	4	main
inimestega	doc_767882159220_item	2853598	et	3	main
suure	doc_767882159220_item	2853599	et	3	main
katuse	doc_767882159220_item	2853600	et	3	main
all	doc_767882159220_item	2853601	et	3	main
ja	doc_767882159220_item	2853602	et	3	main
laulsin	doc_767882159220_item	2853603	et	3	main
vahva	doc_767882159220_item	2853611	et	4	main
laulis	doc_767882159220_item	2853618	et	4	main
ja	doc_767882159220_item	2853619	et	3	main
kuulas	doc_767882159220_item	2853620	et	3	main
ühendatud	doc_767882159220_item	2853624	et	4	main
laulurahvas	doc_767882159220_item	2853627	et	4	main
et	doc_767882159220_item	2853635	et	3	main
teeb	doc_767882159220_item	2853637	et	3	main
kuulda	doc_767882159220_item	2853648	et	4	main
kui	doc_767882159220_item	2853653	et	3	main
ei	doc_767882159220_item	2853656	et	4	main
tol	doc_767882159220_item	2853658	et	3	main
ajal	doc_767882159220_item	2853659	et	4	main
audiokasette	doc_767882159220_item	2853663	et	3	main
või	doc_767882159220_item	2853664	et	4	main
laulsid	doc_767882159220_item	2853669	et	4	main
laulis	doc_767882159220_item	2853672	et	4	main
läksid	doc_767882159220_item	2853703	et	4	main
edasi	doc_767882159220_item	2853704	et	3	main
ja	doc_767882159220_item	2853705	et	3	main
euroopas	doc_767882159220_item	2853706	et	3	main
kui	doc_767882159220_item	2853707	et	3	main
ka	doc_767882159220_item	2853708	et	3	main
eestis	doc_767882159220_item	2853709	et	3	main
tuli	doc_767882159220_item	2853716	et	4	main
laulutraditsioon	doc_767882159220_item	2853719	et	3	main
teemal	doc_767882159220_item	2853539	et	3	main
olema	doc_767882159220_item	2853551	et	4	main
üldistav	doc_767882159220_item	2853555	et	4	main
lugemistekstis	doc_767882159220_item	2853559	et	3	main
laulurahva	doc_767882159220_item	2853570	et	3	main
õppisin	doc_767882159220_item	2853574	et	3	main
klassis	doc_767882159220_item	2853576	et	3	main
koos	doc_767882159220_item	2853580	et	4	main
segakooriga	doc_767882159220_item	2853582	et	4	main
kadriorus	doc_767882159220_item	2853583	et	3	main
lauluväljakul	doc_767882159220_item	2853584	et	3	main
mäletan	doc_767882159220_item	2853585	et	3	main
et	doc_767882159220_item	2853586	et	3	main
meil	doc_767882159220_item	2853587	et	4	main
tunda	doc_767882159220_item	2853612	et	3	main
et	doc_767882159220_item	2853613	et	3	main
laulumisega	doc_767882159220_item	2853614	et	4	main
kõik	doc_767882159220_item	2853615	et	4	main
test	doc_767882159220_item	2853535	et	3	main
laulurahva	doc_767882159220_item	2853543	et	3	main
on	doc_767882159220_item	2853563	et	4	main
juba	doc_767882159220_item	2853571	et	3	main
juhtus	doc_767882159220_item	2853577	et	3	main
seisin	doc_767882159220_item	2853595	et	3	main
meid	doc_767882159220_item	2853609	et	4	main
oli	doc_767882159220_item	2853610	et	3	main
kes	doc_767882159220_item	2853617	et	4	main
me	doc_767882159220_item	2853628	et	4	main
ka	doc_767882159220_item	2853654	et	3	main
ajad	doc_767882159220_item	2853702	et	4	main
mõtlema	doc_767882159220_item	2853712	et	3	main
haridus	doc_767882159220_item	2853714	et	3	main
vist	doc_767882159220_item	2853722	et	4	main
oli	doc_767882159220_item	2853731	et	3	main
laulu	doc_767882159220_item	2853747	et	4	main
mööda	doc_767882159220_item	2853748	et	4	main
tantsud	doc_767882159220_item	2853765	et	3	main
ja	doc_767882159220_item	2853766	et	3	main
laulud	doc_767882159220_item	2853767	et	3	main
oma	doc_767882159220_item	2853769	et	4	main
ja	doc_767882159220_item	2853771	et	3	main
ja	doc_767882159220_item	2853774	et	3	main
niimodi	doc_767882159220_item	2853777	et	4	main
jõudu	doc_767882159220_item	2853781	et	4	main
lihavõted	doc_767882159220_item	2853795	et	4	main
inimesed	doc_767882159220_item	2853796	et	3	main
ja	doc_767882159220_item	2853800	et	3	main
tahaks	doc_767882159220_item	2853803	et	3	main
suurt	doc_767882159220_item	2853823	et	3	main
tuli	doc_767882159220_item	2853827	et	4	main
kui	doc_767882159220_item	2853845	et	3	main
tugevaim	doc_767882159220_item	2853854	et	4	main
see	doc_767882159220_item	2853855	et	3	main
mis	doc_767882159220_item	2853856	et	4	main
puutub	doc_767882159220_item	2853857	et	3	main
traditsioonist	doc_767882159220_item	2853858	et	3	main
teeb	doc_767882159220_item	2853863	et	3	main
laulurahva	doc_767882159220_item	2853864	et	3	main
praeguses	doc_767882159220_item	2853881	et	3	main
olukorras	doc_767882159220_item	2853882	et	3	main
suletud	doc_767882159220_item	2853912	et	4	main
test	doc_767882159221_item	2853938	et	3	main
pikkus	doc_767882159221_item	2853948	et	4	main
350	doc_767882159221_item	2853950	et	2	main
sõna	doc_767882159221_item	2853951	et	4	main
essee	doc_767882159221_item	2853952	et	4	main
tuginema	doc_767882159221_item	2853959	et	3	main
ja	doc_767882159221_item	2853961	et	3	main
esitatud	doc_767882159221_item	2853963	et	4	main
on	doc_767882159221_item	2853966	et	4	main
me	doc_767882159221_item	2853996	et	4	main
eeldame	doc_767882159221_item	2853997	et	3	main
see	doc_767882159221_item	2853998	et	3	main
näitab	doc_767882159221_item	2853999	et	3	main
eluviis	doc_767882159221_item	2854008	et	3	main
kuulame	doc_767882159221_item	2854011	et	4	main
hip-hop	doc_767882159221_item	2854018	et	4	main
rahvale	doc_767882159220_item	2853606	et	3	main
olime	doc_767882159220_item	2853629	et	3	main
võiks	doc_767882159220_item	2853632	et	4	main
algama	doc_767882159220_item	2853633	et	3	main
endised	doc_767882159220_item	2853639	et	3	main
ajad	doc_767882159220_item	2853641	et	4	main
traditsioonid	doc_767882159220_item	2853642	et	3	main
sellistel	doc_767882159220_item	2853645	et	4	main
ajadel	doc_767882159220_item	2853646	et	4	main
pidutsedes	doc_767882159220_item	2853655	et	3	main
telefoni	doc_767882159220_item	2853660	et	4	main
kõikjal	doc_767882159220_item	2853668	et	3	main
õhtuti	doc_767882159220_item	2853670	et	3	main
värviline	doc_767882159220_item	2853699	et	4	main
ja	doc_767882159220_item	2853700	et	3	main
hakkasid	doc_767882159220_item	2853710	et	4	main
tuli	doc_767882159220_item	2853721	et	4	main
jälle	doc_767882159220_item	2853723	et	3	main
ei	doc_767882159220_item	2853725	et	4	main
aga	doc_767882159220_item	2853732	et	3	main
tundub	doc_767882159220_item	2853734	et	3	main
kui	doc_767882159220_item	2853736	et	3	main
informatsiooni	doc_767882159220_item	2853746	et	4	main
mängisid	doc_767882159220_item	2853760	et	4	main
pidutsedel	doc_767882159220_item	2853761	et	4	main
inimesed	doc_767882159220_item	2853762	et	3	main
nii	doc_767882159220_item	2853782	et	3	main
kui	doc_767882159220_item	2853784	et	3	main
heal	doc_767882159220_item	2853786	et	3	main
tegelikult	doc_767882159220_item	2853788	et	4	main
kas	doc_767882159220_item	2853789	et	3	main
oli	doc_767882159220_item	2853790	et	3	main
see	doc_767882159220_item	2853791	et	3	main
jõulupidu	doc_767882159220_item	2853792	et	4	main
niimodi	doc_767882159220_item	2853798	et	4	main
lisada	doc_767882159220_item	2853805	et	3	main
siin	doc_767882159220_item	2853621	et	4	main
me	doc_767882159220_item	2853625	et	4	main
olime	doc_767882159220_item	2853626	et	3	main
sellest	doc_767882159220_item	2853634	et	4	main
ja	doc_767882159220_item	2853643	et	3	main
laule	doc_767882159220_item	2853649	et	4	main
nii	doc_767882159220_item	2853650	et	3	main
töötamise	doc_767882159220_item	2853651	et	4	main
või	doc_767882159220_item	2853661	et	4	main
interneti	doc_767882159220_item	2853662	et	4	main
ema	doc_767882159220_item	2853671	et	4	main
omale	doc_767882159220_item	2853673	et	3	main
lastele	doc_767882159220_item	2853674	et	4	main
sõbrad	doc_767882159220_item	2853675	et	3	main
laulsid	doc_767882159220_item	2853676	et	4	main
et	doc_767882159220_item	2853677	et	3	main
ei	doc_767882159220_item	2853678	et	4	main
olnud	doc_767882159220_item	2853679	et	4	main
igav	doc_767882159220_item	2853680	et	3	main
mängida	doc_767882159220_item	2853681	et	3	main
ja	doc_767882159220_item	2853682	et	3	main
lihtsalt	doc_767882159220_item	2853683	et	4	main
suhelda	doc_767882159220_item	2853684	et	4	main
naised	doc_767882159220_item	2853685	et	3	main
metsas	doc_767882159220_item	2853686	et	3	main
laulsid	doc_767882159220_item	2853687	et	4	main
et	doc_767882159220_item	2853688	et	3	main
ei	doc_767882159220_item	2853689	et	4	main
söö	doc_767882159220_item	2853690	et	4	main
ära	doc_767882159220_item	2853691	et	4	main
kõike	doc_767882159220_item	2853692	et	4	main
marju	doc_767882159220_item	2853693	et	3	main
koos	doc_767882159220_item	2853694	et	4	main
lauludega	doc_767882159220_item	2853695	et	3	main
elu	doc_767882159220_item	2853696	et	4	main
oli	doc_767882159220_item	2853697	et	3	main
enam	doc_767882159220_item	2853698	et	4	main
huvitav	doc_767882159220_item	2853701	et	4	main
inimesed	doc_767882159220_item	2853711	et	3	main
kirikutest	doc_767882159220_item	2853717	et	4	main
ja	doc_767882159220_item	2853718	et	3	main
saa	doc_767882159220_item	2853726	et	4	main
palju	doc_767882159220_item	2853741	et	4	main
hakati	doc_767882159220_item	2853742	et	3	main
andma	doc_767882159220_item	2853743	et	3	main
haridust	doc_767882159220_item	2853744	et	4	main
mingit	doc_767882159220_item	2853745	et	3	main
ei	doc_767882159220_item	2853749	et	4	main
lõbustasid	doc_767882159220_item	2853763	et	4	main
aga	doc_767882159220_item	2853764	et	3	main
rohkem	doc_767882159220_item	2853780	et	4	main
ajal	doc_767882159220_item	2853787	et	4	main
saaksid	doc_767882159220_item	2853797	et	4	main
olla	doc_767882159220_item	2853801	et	3	main
veel	doc_767882159220_item	2853804	et	4	main
mängis	doc_767882159220_item	2853822	et	3	main
vist	doc_767882159220_item	2853842	et	4	main
inimesi	doc_767882159220_item	2853849	et	4	main
siis	doc_767882159220_item	2853850	et	3	main
tegi	doc_767882159220_item	2853852	et	4	main
eestlastest	doc_767882159220_item	2853860	et	4	main
nii	doc_767882159220_item	2853887	et	3	main
pidu	doc_767882159220_item	2853898	et	4	main
kadriorus	doc_767882159220_item	2853902	et	3	main
lauljate	doc_767882159220_item	2853913	et	4	main
inimesi	doc_767882159220_item	2853919	et	4	main
rõõm	doc_767882159220_item	2853920	et	3	main
vaid	doc_767882159220_item	2853921	et	3	main
kirikust	doc_767882159220_item	2853724	et	4	main
tegelikult	doc_767882159220_item	2853729	et	4	main
see	doc_767882159220_item	2853730	et	3	main
ei	doc_767882159220_item	2853738	et	4	main
saa	doc_767882159220_item	2853750	et	4	main
et	doc_767882159220_item	2853753	et	3	main
asja	doc_767882159220_item	2853770	et	4	main
tekitas	doc_767882159220_item	2853772	et	3	main
hea	doc_767882159220_item	2853773	et	4	main
atmosfäär	doc_767882159220_item	2853776	et	3	main
inimestel	doc_767882159220_item	2853778	et	3	main
oli	doc_767882159220_item	2853779	et	3	main
pahal	doc_767882159220_item	2853783	et	4	main
ka	doc_767882159220_item	2853785	et	3	main
või	doc_767882159220_item	2853794	et	4	main
rõõmsaid	doc_767882159220_item	2853802	et	3	main
et	doc_767882159220_item	2853806	et	3	main
võib	doc_767882159220_item	2853807	et	3	main
olla	doc_767882159220_item	2853808	et	3	main
eestlaste	doc_767882159220_item	2853809	et	4	main
laulurahva	doc_767882159220_item	2853810	et	3	main
algus	doc_767882159220_item	2853811	et	4	main
on	doc_767882159220_item	2853812	et	4	main
koorides	doc_767882159220_item	2853813	et	4	main
asi	doc_767882159220_item	2853814	et	4	main
on	doc_767882159220_item	2853815	et	4	main
selles	doc_767882159220_item	2853816	et	4	main
et	doc_767882159220_item	2853817	et	3	main
kirik	doc_767882159220_item	2853818	et	3	main
tol	doc_767882159220_item	2853819	et	3	main
vanadel	doc_767882159220_item	2853820	et	3	main
ajal	doc_767882159220_item	2853821	et	4	main
oli	doc_767882159220_item	2853841	et	3	main
suur	doc_767882159220_item	2853843	et	3	main
palju	doc_767882159220_item	2853848	et	4	main
meelest	doc_767882159220_item	2853862	et	4	main
on	doc_767882159220_item	2853884	et	4	main
folkloori-	doc_767882159220_item	2853888	et	4	main
ka	doc_767882159220_item	2853890	et	3	main
vaid	doc_767882159220_item	2853895	et	3	main
siiski	doc_767882159220_item	2853900	et	4	main
võib	doc_767882159220_item	2853903	et	3	main
räägivad	doc_767882159220_item	2853906	et	3	main
paraad	doc_767882159220_item	2853914	et	3	main
vabaväljakust	doc_767882159220_item	2853915	et	4	main
palju	doc_767882159220_item	2853917	et	4	main
seob	doc_767882159220_item	2853924	et	3	main
ajad	doc_767882159220_item	2853926	et	4	main
kui	doc_767882159221_item	2853935	et	3	main
essee	doc_767882159221_item	2853947	et	4	main
peab	doc_767882159221_item	2853953	et	4	main
soovitatav	doc_767882159221_item	2853967	et	4	main
mis	doc_767882159221_item	2853994	et	4	main
stiilid	doc_767882159221_item	2853995	et	4	main
oleme	doc_767882159221_item	2854003	et	3	main
me	doc_767882159221_item	2854010	et	4	main
see	doc_767882159221_item	2854021	et	3	main
see	doc_767882159221_item	2854024	et	3	main
me	doc_767882159221_item	2854026	et	4	main
meie	doc_767882159221_item	2854028	et	4	main
muidugi	doc_767882159221_item	2854030	et	4	main
me	doc_767882159221_item	2854031	et	4	main
teame	doc_767882159221_item	2854032	et	3	main
väga	doc_767882159221_item	2854037	et	3	main
laulurahvad	doc_767882159221_item	2854039	et	3	main
me	doc_767882159221_item	2854041	et	4	main
teame	doc_767882159221_item	2854042	et	3	main
nii	doc_767882159221_item	2854043	et	3	main
mulle	doc_767882159220_item	2853733	et	4	main
et	doc_767882159220_item	2853735	et	3	main
raamatuid	doc_767882159220_item	2853737	et	3	main
olnud	doc_767882159220_item	2853739	et	4	main
eriti	doc_767882159220_item	2853740	et	3	main
aga	doc_767882159220_item	2853751	et	3	main
unustada	doc_767882159220_item	2853752	et	3	main
pea	doc_767882159220_item	2853754	et	4	main
rolli	doc_767882159220_item	2853755	et	4	main
laulud	doc_767882159220_item	2853756	et	3	main
ja	doc_767882159220_item	2853757	et	3	main
ka	doc_767882159220_item	2853758	et	3	main
tantsud	doc_767882159220_item	2853759	et	3	main
tegid	doc_767882159220_item	2853768	et	4	main
sõbralik	doc_767882159220_item	2853775	et	3	main
pulmapidu	doc_767882159220_item	2853793	et	4	main
tutvustama	doc_767882159220_item	2853799	et	3	main
rolli	doc_767882159220_item	2853824	et	4	main
võiks	doc_767882159220_item	2853836	et	4	main
olla	doc_767882159220_item	2853837	et	3	main
niimodi	doc_767882159220_item	2853838	et	4	main
et	doc_767882159220_item	2853839	et	3	main
kooridest	doc_767882159220_item	2853840	et	3	main
kirikus	doc_767882159220_item	2853846	et	3	main
oli	doc_767882159220_item	2853847	et	3	main
koor	doc_767882159220_item	2853851	et	4	main
tänapäeval	doc_767882159220_item	2853859	et	3	main
minu	doc_767882159220_item	2853861	et	3	main
laulupidused	doc_767882159220_item	2853865	et	4	main
stiile	doc_767882159220_item	2853886	et	3	main
pop-	doc_767882159220_item	2853891	et	4	main
ja	doc_767882159220_item	2853892	et	3	main
kõige	doc_767882159220_item	2853896	et	4	main
oluline	doc_767882159220_item	2853897	et	4	main
olla	doc_767882159220_item	2853904	et	3	main
mulle	doc_767882159220_item	2853907	et	4	main
minu	doc_767882159220_item	2853908	et	3	main
mälestused	doc_767882159220_item	2853909	et	4	main
vanad	doc_767882159220_item	2853925	et	3	main
praeguse	doc_767882159220_item	2853927	et	3	main
uue	doc_767882159220_item	2853930	et	3	main
elukorraga	doc_767882159220_item	2853931	et	3	main
eesti	doc_767882159221_item	2853933	et	4	main
keele	doc_767882159221_item	2853937	et	4	main
kirjutamine	doc_767882159221_item	2853939	et	4	main
essee	doc_767882159221_item	2853941	et	4	main
teemal	doc_767882159221_item	2853942	et	3	main
mis	doc_767882159221_item	2853943	et	4	main
teeb	doc_767882159221_item	2853944	et	3	main
olema	doc_767882159221_item	2853954	et	4	main
ja	doc_767882159221_item	2853957	et	3	main
teeb	doc_767882159221_item	2853971	et	3	main
meile	doc_767882159221_item	2854000	et	4	main
praegu	doc_767882159221_item	2854009	et	3	main
erinevad	doc_767882159221_item	2854012	et	4	main
stiilid	doc_767882159221_item	2854013	et	4	main
nagu	doc_767882159221_item	2854014	et	3	main
muusikad	doc_767882159221_item	2854019	et	3	main
aga	doc_767882159221_item	2854020	et	3	main
tähendab	doc_767882159221_item	2854023	et	3	main
me	doc_767882159221_item	2854058	et	4	main
muidugi	doc_767882159221_item	2854066	et	4	main
millest	doc_767882159221_item	2854069	et	3	main
eesti	doc_767882159221_item	2854072	et	4	main
kultuur	doc_767882159221_item	2854073	et	3	main
tean	doc_767882159221_item	2854074	et	3	main
iga	doc_767882159221_item	2854080	et	4	main
aastal	doc_767882159221_item	2854081	et	3	main
toimub	doc_767882159221_item	2854086	et	3	main
see	doc_767882159221_item	2854088	et	3	main
on	doc_767882159221_item	2854090	et	4	main
kujunes	doc_767882159221_item	2854100	et	3	main
tartus	doc_767882159221_item	2854104	et	3	main
46	doc_767882159221_item	2854109	et	2	main
mängijaga	doc_767882159221_item	2854117	et	4	main
see	doc_767882159221_item	2854118	et	3	main
tähendab	doc_767882159221_item	2854119	et	3	main
ja	doc_767882159220_item	2853825	et	3	main
laul	doc_767882159220_item	2853826	et	4	main
ka	doc_767882159220_item	2853828	et	3	main
kirikust	doc_767882159220_item	2853829	et	4	main
ja	doc_767882159220_item	2853830	et	3	main
just	doc_767882159220_item	2853831	et	3	main
kirik	doc_767882159220_item	2853832	et	3	main
ühendas	doc_767882159220_item	2853833	et	3	main
inimesi	doc_767882159220_item	2853834	et	4	main
kuidas	doc_767882159220_item	2853835	et	3	main
vajadus	doc_767882159220_item	2853844	et	3	main
laulu	doc_767882159220_item	2853853	et	4	main
mis	doc_767882159220_item	2853866	et	4	main
toimuvad	doc_767882159220_item	2853867	et	4	main
tallinnas	doc_767882159220_item	2853868	et	4	main
1869	doc_767882159220_item	2853870	et	2	main
juba	doc_767882159220_item	2853869	et	3	main
aastalt	doc_767882159220_item	2853871	et	3	main
kord	doc_767882159220_item	2853872	et	4	main
aastas	doc_767882159220_item	2853873	et	3	main
ja	doc_767882159220_item	2853874	et	3	main
järgnevad	doc_767882159220_item	2853875	et	4	main
ühendada	doc_767882159220_item	2853876	et	3	main
inimesi	doc_767882159220_item	2853877	et	4	main
võib	doc_767882159220_item	2853878	et	3	main
märgata	doc_767882159220_item	2853879	et	4	main
et	doc_767882159220_item	2853880	et	3	main
muusikal	doc_767882159220_item	2853883	et	4	main
palju	doc_767882159220_item	2853885	et	4	main
kui	doc_767882159220_item	2853889	et	3	main
rokk-	doc_767882159220_item	2853893	et	3	main
stiile	doc_767882159220_item	2853894	et	3	main
on	doc_767882159220_item	2853899	et	4	main
laulupidu	doc_767882159220_item	2853901	et	4	main
sellest	doc_767882159220_item	2853905	et	4	main
transpordiliikumine	doc_767882159220_item	2853910	et	3	main
on	doc_767882159220_item	2853911	et	4	main
lauluväljakuni	doc_767882159220_item	2853916	et	3	main
ühendatuid	doc_767882159220_item	2853918	et	4	main
laulupidu	doc_767882159220_item	2853923	et	4	main
essee	doc_767882159221_item	2853932	et	4	main
keele	doc_767882159221_item	2853934	et	4	main
eestlastest	doc_767882159221_item	2853945	et	4	main
laulurahva	doc_767882159221_item	2853946	et	3	main
analüüsiv	doc_767882159221_item	2853956	et	4	main
loengus	doc_767882159221_item	2853960	et	3	main
lugemistekstis	doc_767882159221_item	2853962	et	3	main
faktidele	doc_767882159221_item	2853964	et	3	main
väiteid	doc_767882159221_item	2853965	et	4	main
pop	doc_767882159221_item	2854015	et	4	main
unustasime	doc_767882159221_item	2854027	et	3	main
rahvaskultuur	doc_767882159221_item	2854029	et	4	main
on	doc_767882159221_item	2854036	et	4	main
kujutavad	doc_767882159221_item	2854048	et	4	main
lauldest	doc_767882159221_item	2854052	et	4	main
peol	doc_767882159221_item	2854061	et	4	main
saada	doc_767882159221_item	2854062	et	4	main
pidu	doc_767882159221_item	2854078	et	4	main
ajaloolise	doc_767882159221_item	2854097	et	4	main
esimene	doc_767882159221_item	2854101	et	3	main
peol	doc_767882159221_item	2854107	et	4	main
meeskoori	doc_767882159221_item	2854110	et	4	main
lauljaga	doc_767882159221_item	2854112	et	4	main
5	doc_767882159221_item	2854114	et	2	main
56	doc_767882159221_item	2854116	et	2	main
et	doc_767882159221_item	2854120	et	3	main
palju	doc_767882159221_item	2854124	et	4	main
kõik	doc_767882159221_item	2854137	et	4	main
mis	doc_767882159221_item	2854138	et	4	main
minu	doc_767882159221_item	2854142	et	3	main
arvatatakse	doc_767882159221_item	2854143	et	4	main
viulit	doc_767882159221_item	2854154	et	4	main
klaverit	doc_767882159221_item	2854155	et	3	main
meie	doc_767882159221_item	2854166	et	4	main
rahvalaulad	doc_767882159221_item	2854167	et	4	main
et	doc_767882159221_item	2854181	et	3	main
kunagi	doc_767882159221_item	2854183	et	3	main
unustati	doc_767882159221_item	2854185	et	3	main
see	doc_767882159221_item	2854187	et	3	main
on	doc_767882159221_item	2854188	et	4	main
eestis	doc_767882159221_item	2854189	et	3	main
kombe	doc_767882159221_item	2854190	et	4	main
praegu	doc_767882159221_item	2854191	et	3	main
populäärne	doc_767882159221_item	2854195	et	4	main
kui	doc_767882159221_item	2854205	et	3	main
siiski	doc_767882159220_item	2853922	et	4	main
ajadega	doc_767882159220_item	2853928	et	4	main
traditsioonid	doc_767882159220_item	2853929	et	3	main
teise	doc_767882159221_item	2853936	et	4	main
kirjutage	doc_767882159221_item	2853940	et	3	main
300	doc_767882159221_item	2853949	et	2	main
arutlev	doc_767882159221_item	2853955	et	4	main
üldistav	doc_767882159221_item	2853958	et	4	main
illustreerida	doc_767882159221_item	2853968	et	3	main
näidetega	doc_767882159221_item	2853969	et	3	main
mis	doc_767882159221_item	2853970	et	4	main
eestlastest	doc_767882159221_item	2853972	et	4	main
laulurahva	doc_767882159221_item	2853973	et	3	main
meie	doc_767882159221_item	2853974	et	4	main
ajal	doc_767882159221_item	2853975	et	4	main
muusika	doc_767882159221_item	2853976	et	4	main
on	doc_767882159221_item	2853977	et	4	main
väga	doc_767882159221_item	2853978	et	3	main
populäärne	doc_767882159221_item	2853979	et	4	main
sest	doc_767882159221_item	2853980	et	4	main
kõik	doc_767882159221_item	2853981	et	4	main
peod	doc_767882159221_item	2853982	et	4	main
mis	doc_767882159221_item	2853983	et	4	main
toimuvad	doc_767882159221_item	2853984	et	4	main
mailmas	doc_767882159221_item	2853985	et	4	main
on	doc_767882159221_item	2853986	et	4	main
seotud	doc_767882159221_item	2853987	et	4	main
muusikaga	doc_767882159221_item	2853988	et	3	main
arvan	doc_767882159221_item	2853989	et	3	main
et	doc_767882159221_item	2853990	et	3	main
mida	doc_767882159221_item	2853991	et	4	main
me	doc_767882159221_item	2853992	et	4	main
kuulame	doc_767882159221_item	2853993	et	4	main
missugused	doc_767882159221_item	2854001	et	3	main
me	doc_767882159221_item	2854002	et	4	main
meie	doc_767882159221_item	2854004	et	4	main
iseloom	doc_767882159221_item	2854005	et	3	main
ja	doc_767882159221_item	2854006	et	3	main
meie	doc_767882159221_item	2854007	et	4	main
jazz	doc_767882159221_item	2854016	et	4	main
rock	doc_767882159221_item	2854017	et	4	main
ei	doc_767882159221_item	2854022	et	4	main
et	doc_767882159221_item	2854025	et	3	main
rahvalaulu	doc_767882159221_item	2854045	et	4	main
ja	doc_767882159221_item	2854051	et	3	main
saame	doc_767882159221_item	2854059	et	4	main
aru	doc_767882159221_item	2854067	et	4	main
meie	doc_767882159221_item	2854071	et	4	main
et	doc_767882159221_item	2854075	et	3	main
see	doc_767882159221_item	2854082	et	3	main
on	doc_767882159221_item	2854083	et	4	main
sündmuseks	doc_767882159221_item	2854099	et	3	main
ajal	doc_767882159221_item	2854106	et	4	main
osaleda	doc_767882159221_item	2854133	et	3	main
organitsioonis	doc_767882159221_item	2854134	et	4	main
kus	doc_767882159221_item	2854135	et	3	main
pakutakse	doc_767882159221_item	2854136	et	3	main
eestis	doc_767882159221_item	2854145	et	3	main
õppe	doc_767882159221_item	2854148	et	4	main
ringi	doc_767882159221_item	2854149	et	4	main
võivad	doc_767882159221_item	2854152	et	4	main
õppida	doc_767882159221_item	2854153	et	3	main
ja	doc_767882159221_item	2854159	et	3	main
mulle	doc_767882159221_item	2854173	et	4	main
kuidas	doc_767882159221_item	2854175	et	3	main
laulvad	doc_767882159221_item	2854179	et	4	main
mulle	doc_767882159221_item	2854199	et	4	main
võistlus	doc_767882159221_item	2854222	et	3	main
saame	doc_767882159221_item	2854226	et	4	main
laulu	doc_767882159221_item	2854249	et	4	main
näiteks	doc_767882159221_item	2854250	et	4	main
mu	doc_767882159221_item	2854254	et	3	main
on	doc_767882159221_item	2854256	et	4	main
ernesaks	doc_767882159221_item	2854261	et	4	main
peab	doc_767882159222_item	2854283	et	4	main
olema	doc_767882159222_item	2854284	et	4	main
lugemistekstis	doc_767882159222_item	2854292	et	3	main
võib	doc_767882159222_item	2854301	et	3	main
me	doc_767882159222_item	2854312	et	4	main
näeme	doc_767882159222_item	2854313	et	3	main
juba	doc_767882159222_item	2854316	et	3	main
nad	doc_767882159222_item	2854321	et	3	main
töötades	doc_767882159222_item	2854324	et	3	main
puhates	doc_767882159222_item	2854325	et	3	main
üksi	doc_767882159222_item	2854326	et	4	main
olles	doc_767882159222_item	2854327	et	3	main
probleemidest	doc_767882159222_item	2854335	et	3	main
tagasi	doc_767882159222_item	2854340	et	3	main
ja	doc_767882159222_item	2854351	et	3	main
koor	doc_767882159222_item	2854352	et	4	main
vaheldumisi	doc_767882159222_item	2854353	et	4	main
pillisaateta	doc_767882159222_item	2854357	et	3	main
keha	doc_767882159222_item	2854360	et	4	main
eesti	doc_767882159222_item	2854362	et	4	main
teistelt	doc_767882159222_item	2854368	et	4	main
maalt	doc_767882159222_item	2854369	et	3	main
pillisaatega	doc_767882159222_item	2854378	et	3	main
autor	doc_767882159222_item	2854380	et	3	main
aastal	doc_767882159222_item	2854400	et	3	main
esimene	doc_767882159222_item	2854403	et	3	main
ajal	doc_767882159222_item	2854414	et	4	main
oli	doc_767882159222_item	2854415	et	3	main
eestlastel	doc_767882159222_item	2854416	et	4	main
see	doc_767882159222_item	2854422	et	3	main
kuuendast	doc_767882159222_item	2854428	et	3	main
toimuvad	doc_767882159222_item	2854436	et	4	main
manifestatsioon	doc_767882159222_item	2854448	et	3	main
eestis	doc_767882159222_item	2854449	et	3	main
lisaks	doc_767882159222_item	2854450	et	4	main
see	doc_767882159222_item	2854451	et	3	main
on	doc_767882159222_item	2854452	et	4	main
muusika	doc_767882159222_item	2854459	et	4	main
oli	doc_767882159222_item	2854460	et	3	main
see	doc_767882159222_item	2854466	et	3	main
lihtsam	doc_767882159222_item	2854475	et	4	main
ajaloost	doc_767882159221_item	2854033	et	4	main
et	doc_767882159221_item	2854034	et	3	main
eestis	doc_767882159221_item	2854035	et	3	main
rikkavad	doc_767882159221_item	2854038	et	4	main
sest	doc_767882159221_item	2854040	et	4	main
need	doc_767882159221_item	2854046	et	3	main
laulad	doc_767882159221_item	2854047	et	3	main
palju	doc_767882159221_item	2854044	et	4	main
minevik	doc_767882159221_item	2854050	et	3	main
midagi	doc_767882159221_item	2854054	et	4	main
suurel	doc_767882159221_item	2854060	et	3	main
koosneb	doc_767882159221_item	2854070	et	3	main
kõige	doc_767882159221_item	2854076	et	4	main
suurem	doc_767882159221_item	2854077	et	4	main
laulupidu	doc_767882159221_item	2854084	et	4	main
lauluväljakus	doc_767882159221_item	2854087	et	3	main
traditsioon	doc_767882159221_item	2854089	et	3	main
1869	doc_767882159221_item	2854091	et	2	main
aastalt	doc_767882159221_item	2854092	et	3	main
sest	doc_767882159221_item	2854093	et	4	main
see	doc_767882159221_item	2854094	et	3	main
aeg	doc_767882159221_item	2854095	et	3	main
on	doc_767882159221_item	2854096	et	4	main
laulupidu	doc_767882159221_item	2854103	et	4	main
tool	doc_767882159221_item	2854105	et	3	main
võib	doc_767882159221_item	2854122	et	3	main
ja	doc_767882159221_item	2854126	et	3	main
kui	doc_767882159221_item	2854128	et	3	main
vanemad	doc_767882159221_item	2854129	et	4	main
nii	doc_767882159221_item	2854130	et	3	main
noored	doc_767882159221_item	2854131	et	3	main
on	doc_767882159221_item	2854139	et	4	main
muusikatega	doc_767882159221_item	2854140	et	3	main
on	doc_767882159221_item	2854146	et	4	main
või	doc_767882159221_item	2854157	et	4	main
ilusa	doc_767882159221_item	2854161	et	3	main
tahak	doc_767882159221_item	2854163	et	4	main
on	doc_767882159221_item	2854168	et	4	main
väga	doc_767882159221_item	2854169	et	3	main
ilusad	doc_767882159221_item	2854170	et	3	main
ja	doc_767882159221_item	2854171	et	3	main
arvan	doc_767882159221_item	2854180	et	3	main
see	doc_767882159221_item	2854182	et	3	main
ei	doc_767882159221_item	2854184	et	4	main
sest	doc_767882159221_item	2854186	et	4	main
meeldib	doc_767882159221_item	2854200	et	3	main
seda	doc_767882159221_item	2854201	et	3	main
vaadata	doc_767882159221_item	2854202	et	4	main
muidugi	doc_767882159221_item	2854225	et	4	main
esimesed	doc_767882159221_item	2854227	et	3	main
lauluvõistlustes	doc_767882159221_item	2854229	et	3	main
muidugi	doc_767882159221_item	2854241	et	4	main
tuntud	doc_767882159221_item	2854242	et	4	main
gimn	doc_767882159221_item	2854253	et	4	main
arm	doc_767882159221_item	2854258	et	3	main
eesti	doc_767882159222_item	2854263	et	4	main
teeb	doc_767882159222_item	2854274	et	3	main
loengus	doc_767882159222_item	2854290	et	3	main
soovitatav	doc_767882159222_item	2854297	et	4	main
nimetada	doc_767882159222_item	2854302	et	3	main
laulurahvaks	doc_767882159222_item	2854303	et	3	main
et	doc_767882159222_item	2854314	et	3	main
laulsid	doc_767882159222_item	2854322	et	4	main
laulmine	doc_767882159222_item	2854328	et	4	main
aitas	doc_767882159222_item	2854329	et	3	main
aastat	doc_767882159222_item	2854339	et	3	main
tavaliselt	doc_767882159222_item	2854349	et	4	main
eeslaulja	doc_767882159222_item	2854350	et	4	main
lauldi	doc_767882159222_item	2854355	et	3	main
rahvamuusika	doc_767882159222_item	2854363	et	4	main
oli	doc_767882159222_item	2854365	et	3	main
suur	doc_767882159222_item	2854366	et	3	main
juba	doc_767882159222_item	2854376	et	3	main
vaja	doc_767882159222_item	2854392	et	4	main
peol	doc_767882159222_item	2854406	et	4	main
osales	doc_767882159222_item	2854407	et	3	main
väga	doc_767882159222_item	2854408	et	3	main
palju	doc_767882159222_item	2854409	et	4	main
sellel	doc_767882159222_item	2854413	et	4	main
meile	doc_767882159221_item	2854049	et	4	main
võib	doc_767882159221_item	2854053	et	3	main
huvitavad	doc_767882159221_item	2854055	et	4	main
kuulata	doc_767882159221_item	2854056	et	4	main
seda	doc_767882159221_item	2854057	et	3	main
tedma	doc_767882159221_item	2854063	et	4	main
ka	doc_767882159221_item	2854064	et	3	main
ja	doc_767882159221_item	2854065	et	3	main
saada	doc_767882159221_item	2854068	et	4	main
on	doc_767882159221_item	2854079	et	4	main
mis	doc_767882159221_item	2854085	et	4	main
tähtsusega	doc_767882159221_item	2854098	et	4	main
ülemaaline	doc_767882159221_item	2854102	et	4	main
osales	doc_767882159221_item	2854108	et	3	main
822	doc_767882159221_item	2854111	et	2	main
ja	doc_767882159221_item	2854113	et	3	main
puhkpilliorkestrit	doc_767882159221_item	2854115	et	3	main
meil	doc_767882159221_item	2854121	et	4	main
lauljaid	doc_767882159221_item	2854125	et	4	main
koore	doc_767882159221_item	2854127	et	4	main
peavad	doc_767882159221_item	2854132	et	4	main
et	doc_767882159221_item	2854144	et	3	main
palju	doc_767882159221_item	2854147	et	4	main
pillit	doc_767882159221_item	2854156	et	4	main
bojanit	doc_767882159221_item	2854158	et	4	main
muidugi	doc_767882159221_item	2854160	et	4	main
laulmise	doc_767882159221_item	2854162	et	4	main
öelda	doc_767882159221_item	2854164	et	4	main
et	doc_767882159221_item	2854165	et	3	main
meil	doc_767882159221_item	2854192	et	4	main
väga	doc_767882159221_item	2854194	et	3	main
euroviision	doc_767882159221_item	2854196	et	4	main
võistlus	doc_767882159221_item	2854197	et	3	main
ja	doc_767882159221_item	2854198	et	3	main
võime	doc_767882159221_item	2854221	et	4	main
kohtad	doc_767882159221_item	2854228	et	3	main
me	doc_767882159221_item	2854231	et	4	main
oleme	doc_767882159221_item	2854232	et	3	main
laulurahvad	doc_767882159221_item	2854233	et	3	main
teeb	doc_767882159221_item	2854237	et	3	main
eestlastest	doc_767882159221_item	2854238	et	4	main
laulurahva	doc_767882159221_item	2854239	et	3	main
ja	doc_767882159221_item	2854240	et	3	main
meile	doc_767882159221_item	2854246	et	4	main
nii	doc_767882159221_item	2854247	et	3	main
ilusad	doc_767882159221_item	2854248	et	3	main
minu	doc_767882159221_item	2854257	et	3	main
keele	doc_767882159222_item	2854264	et	4	main
kui	doc_767882159222_item	2854265	et	3	main
teise	doc_767882159222_item	2854266	et	4	main
keele	doc_767882159222_item	2854267	et	4	main
test	doc_767882159222_item	2854268	et	3	main
mis	doc_767882159222_item	2854273	et	4	main
eestlastest	doc_767882159222_item	2854275	et	4	main
essee	doc_767882159222_item	2854277	et	4	main
pikkus	doc_767882159222_item	2854278	et	4	main
300	doc_767882159222_item	2854279	et	2	main
350	doc_767882159222_item	2854280	et	2	main
arutlev	doc_767882159222_item	2854285	et	4	main
illustreerida	doc_767882159222_item	2854298	et	3	main
aga	doc_767882159222_item	2854304	et	3	main
neid	doc_767882159222_item	2854307	et	4	main
selliseks	doc_767882159222_item	2854308	et	4	main
rahvaks	doc_767882159222_item	2854309	et	3	main
vaadates	doc_767882159222_item	2854310	et	3	main
elavad	doc_767882159222_item	2854319	et	4	main
lauldes	doc_767882159222_item	2854320	et	3	main
olla	doc_767882159221_item	2854123	et	3	main
seotatud	doc_767882159221_item	2854141	et	4	main
kus	doc_767882159221_item	2854150	et	3	main
inimesed	doc_767882159221_item	2854151	et	3	main
meloodilised	doc_767882159221_item	2854172	et	3	main
meeldib	doc_767882159221_item	2854174	et	3	main
tantsitega	doc_767882159221_item	2854176	et	4	main
ringis	doc_767882159221_item	2854177	et	4	main
rahvased	doc_767882159221_item	2854178	et	4	main
on	doc_767882159221_item	2854193	et	4	main
mina	doc_767882159221_item	2854203	et	4	main
mäletan	doc_767882159221_item	2854204	et	3	main
2001	doc_767882159221_item	2854206	et	2	main
aastal	doc_767882159221_item	2854207	et	3	main
tanel	doc_767882159221_item	2854208	et	4	main
pader	doc_767882159221_item	2854209	et	4	main
oli	doc_767882159221_item	2854210	et	3	main
esimene	doc_767882159221_item	2854211	et	3	main
ja	doc_767882159221_item	2854212	et	3	main
meil	doc_767882159221_item	2854213	et	4	main
siis	doc_767882159221_item	2854214	et	3	main
oli	doc_767882159221_item	2854215	et	3	main
euroviision	doc_767882159221_item	2854216	et	4	main
see	doc_767882159221_item	2854217	et	3	main
tähendab	doc_767882159221_item	2854218	et	3	main
et	doc_767882159221_item	2854219	et	3	main
me	doc_767882159221_item	2854220	et	4	main
olla	doc_767882159221_item	2854223	et	3	main
sest	doc_767882159221_item	2854230	et	4	main
arvan	doc_767882159221_item	2854234	et	3	main
komposiitorit	doc_767882159221_item	2854243	et	4	main
meie	doc_767882159221_item	2854251	et	4	main
isamaa	doc_767882159221_item	2854255	et	4	main
komposiitor	doc_767882159221_item	2854259	et	4	main
gustav	doc_767882159221_item	2854260	et	4	main
teemal	doc_767882159222_item	2854272	et	3	main
laulurahva	doc_767882159222_item	2854276	et	3	main
sõna	doc_767882159222_item	2854281	et	4	main
analüüsiv	doc_767882159222_item	2854286	et	4	main
ja	doc_767882159222_item	2854287	et	3	main
esitatud	doc_767882159222_item	2854293	et	4	main
faktidele	doc_767882159222_item	2854294	et	3	main
näidetega	doc_767882159222_item	2854299	et	3	main
mis	doc_767882159222_item	2854305	et	4	main
eestlased	doc_767882159222_item	2854315	et	3	main
ammusest	doc_767882159222_item	2854317	et	4	main
ajast	doc_767882159222_item	2854318	et	4	main
raskustest	doc_767882159222_item	2854330	et	4	main
läbi	doc_767882159222_item	2854331	et	4	main
rohkem	doc_767882159222_item	2854336	et	4	main
tuhat	doc_767882159222_item	2854338	et	4	main
rahvalaul	doc_767882159222_item	2854344	et	4	main
ilma	doc_767882159222_item	2854356	et	4	main
väikse	doc_767882159222_item	2854359	et	4	main
liigutamisega	doc_767882159222_item	2854361	et	4	main
peale	doc_767882159222_item	2854364	et	4	main
ja	doc_767882159222_item	2854379	et	3	main
oli	doc_767882159222_item	2854381	et	3	main
laulmine	doc_767882159222_item	2854383	et	4	main
midagi	doc_767882159222_item	2854393	et	4	main
kogu	doc_767882159222_item	2854396	et	4	main
jaoks	doc_767882159222_item	2854398	et	4	main
tartus	doc_767882159222_item	2854401	et	3	main
ülemaaline	doc_767882159222_item	2854404	et	4	main
laulupidu	doc_767882159222_item	2854405	et	4	main
pillimängijaid	doc_767882159222_item	2854412	et	3	main
toimuma	doc_767882159222_item	2854421	et	3	main
laulupidu	doc_767882159222_item	2854423	et	4	main
aeg	doc_767882159222_item	2854425	et	3	main
ja	doc_767882159221_item	2854224	et	3	main
et	doc_767882159221_item	2854235	et	3	main
muusika	doc_767882159221_item	2854236	et	4	main
kes	doc_767882159221_item	2854244	et	4	main
komposeerivad	doc_767882159221_item	2854245	et	3	main
eestise	doc_767882159221_item	2854252	et	4	main
essee	doc_767882159222_item	2854262	et	4	main
kirjutamine	doc_767882159222_item	2854269	et	4	main
kirjutage	doc_767882159222_item	2854270	et	3	main
essee	doc_767882159222_item	2854271	et	4	main
essee	doc_767882159222_item	2854282	et	4	main
üldistav	doc_767882159222_item	2854288	et	4	main
tuginema	doc_767882159222_item	2854289	et	3	main
ja	doc_767882159222_item	2854291	et	3	main
väiteid	doc_767882159222_item	2854295	et	4	main
on	doc_767882159222_item	2854296	et	4	main
eestlasi	doc_767882159222_item	2854300	et	3	main
teeb	doc_767882159222_item	2854306	et	3	main
ajaloosse	doc_767882159222_item	2854311	et	4	main
igalpool	doc_767882159222_item	2854323	et	4	main
saada	doc_767882159222_item	2854332	et	4	main
ja	doc_767882159222_item	2854333	et	3	main
unustada	doc_767882159222_item	2854334	et	3	main
kui	doc_767882159222_item	2854337	et	3	main
kujunes	doc_767882159222_item	2854341	et	3	main
aga	doc_767882159222_item	2854358	et	3	main
mõju	doc_767882159222_item	2854367	et	4	main
nii	doc_767882159222_item	2854370	et	3	main
tekkis	doc_767882159222_item	2854371	et	3	main
uus	doc_767882159222_item	2854372	et	3	main
riimiline	doc_767882159222_item	2854373	et	4	main
mängiti	doc_767882159222_item	2854377	et	3	main
teatud	doc_767882159222_item	2854382	et	4	main
hakkas	doc_767882159222_item	2854384	et	3	main
juba	doc_767882159222_item	2854386	et	3	main
nii	doc_767882159222_item	2854387	et	3	main
populaarne	doc_767882159222_item	2854388	et	3	main
tegevus	doc_767882159222_item	2854389	et	4	main
et	doc_767882159222_item	2854390	et	3	main
oli	doc_767882159222_item	2854391	et	3	main
suurt	doc_767882159222_item	2854395	et	3	main
kogu	doc_767882159222_item	2854424	et	4	main
traditsioon	doc_767882159222_item	2854431	et	3	main
tallinnasse	doc_767882159222_item	2854432	et	3	main
ajani	doc_767882159222_item	2854435	et	3	main
laulupeod	doc_767882159222_item	2854438	et	4	main
praegu	doc_767882159222_item	2854439	et	3	main
on	doc_767882159222_item	2854440	et	4	main
see	doc_767882159222_item	2854441	et	3	main
massilisem	doc_767882159222_item	2854446	et	4	main
pidu	doc_767882159222_item	2854456	et	4	main
eesti	doc_767882159222_item	2854462	et	4	main
rahva	doc_767882159222_item	2854463	et	3	main
eesti	doc_767882159222_item	2854342	et	4	main
vanem	doc_767882159222_item	2854343	et	4	main
regivärsiline	doc_767882159222_item	2854345	et	4	main
rahvalaul	doc_767882159222_item	2854346	et	4	main
seda	doc_767882159222_item	2854347	et	3	main
esitas	doc_767882159222_item	2854348	et	3	main
regilaule	doc_767882159222_item	2854354	et	4	main
rahvalaul	doc_767882159222_item	2854374	et	4	main
neid	doc_767882159222_item	2854375	et	4	main
olema	doc_767882159222_item	2854385	et	4	main
organiiserida	doc_767882159222_item	2854394	et	4	main
rahva	doc_767882159222_item	2854397	et	3	main
1869	doc_767882159222_item	2854399	et	2	main
toimus	doc_767882159222_item	2854402	et	3	main
lauljaid	doc_767882159222_item	2854410	et	4	main
ja	doc_767882159222_item	2854411	et	3	main
kõrghetk	doc_767882159222_item	2854417	et	3	main
siis	doc_767882159222_item	2854418	et	3	main
pärast	doc_767882159222_item	2854419	et	4	main
hakkas	doc_767882159222_item	2854420	et	3	main
kohtades	doc_767882159222_item	2854427	et	3	main
kandus	doc_767882159222_item	2854430	et	3	main
kõige	doc_767882159222_item	2854442	et	4	main
kõige	doc_767882159222_item	2854443	et	4	main
tähelepanuväärsem	doc_767882159222_item	2854444	et	4	main
ja	doc_767882159222_item	2854445	et	3	main
rahvusluse	doc_767882159222_item	2854447	et	4	main
jaoks	doc_767882159222_item	2854458	et	4	main
ja	doc_767882159222_item	2854465	et	3	main
sest	doc_767882159222_item	2854469	et	4	main
erinevates	doc_767882159222_item	2854426	et	4	main
meie	doc_767882159222_item	2854434	et	4	main
pere	doc_767882159222_item	2854457	et	4	main
sümbol	doc_767882159222_item	2854464	et	3	main
lõbusam	doc_767882159222_item	2854474	et	4	main
eesti	doc_767882159224_item	2854757	et	4	main
kirjutamine	doc_767882159224_item	2854763	et	4	main
kirjutage	doc_767882159224_item	2854764	et	3	main
pikkus	doc_767882159224_item	2854772	et	4	main
300	doc_767882159224_item	2854773	et	2	main
350	doc_767882159224_item	2854774	et	2	main
ja	doc_767882159224_item	2854781	et	3	main
loengus	doc_767882159224_item	2854784	et	3	main
lugemistekstis	doc_767882159224_item	2854786	et	3	main
aastal	doc_767882159224_item	2854829	et	3	main
alates	doc_767882159224_item	2854833	et	3	main
125	doc_767882159224_item	2854847	et	2	main
laulupidude	doc_767882159224_item	2854850	et	4	main
me	doc_767882159224_item	2854863	et	4	main
näeme	doc_767882159224_item	2854864	et	3	main
peost	doc_767882159222_item	2854429	et	4	main
1896	doc_767882159222_item	2854433	et	2	main
need	doc_767882159222_item	2854437	et	3	main
suur	doc_767882159222_item	2854453	et	3	main
ja	doc_767882159222_item	2854454	et	3	main
lõbus	doc_767882159222_item	2854455	et	4	main
alati	doc_767882159222_item	2854461	et	4	main
jääbki	doc_767882159222_item	2854467	et	3	main
selleks	doc_767882159222_item	2854468	et	4	main
muusikaga	doc_767882159222_item	2854470	et	3	main
on	doc_767882159222_item	2854471	et	4	main
ju	doc_767882159222_item	2854472	et	3	main
elada	doc_767882159222_item	2854473	et	3	main
ja	doc_767882159222_item	2854476	et	3	main
ilusam	doc_767882159222_item	2854477	et	4	main
kui	doc_767882159224_item	2854759	et	3	main
teemal	doc_767882159224_item	2854766	et	3	main
mis	doc_767882159224_item	2854767	et	4	main
olema	doc_767882159224_item	2854778	et	4	main
tuginema	doc_767882159224_item	2854783	et	3	main
huvi	doc_767882159224_item	2854821	et	4	main
tantsida	doc_767882159224_item	2854823	et	3	main
osa	doc_767882159224_item	2854826	et	4	main
pidudes	doc_767882159224_item	2854827	et	4	main
igal	doc_767882159224_item	2854828	et	3	main
ainult	doc_767882159224_item	2854835	et	4	main
lisandusid	doc_767882159224_item	2854838	et	4	main
ka	doc_767882159224_item	2854839	et	3	main
naiskoorid	doc_767882159224_item	2854840	et	3	main
lastekoorid	doc_767882159224_item	2854841	et	3	main
ja	doc_767882159224_item	2854842	et	3	main
poistekoorid	doc_767882159224_item	2854843	et	3	main
kui	doc_767882159224_item	2854844	et	3	main
eestlased	doc_767882159224_item	2854845	et	3	main
kestnud	doc_767882159224_item	2854849	et	4	main
traditsiooni	doc_767882159224_item	2854851	et	4	main
siis	doc_767882159224_item	2854852	et	3	main
oli	doc_767882159224_item	2854853	et	3	main
nii	doc_767882159224_item	2854854	et	3	main
palju	doc_767882159224_item	2854855	et	4	main
rahva	doc_767882159224_item	2854856	et	3	main
et	doc_767882159224_item	2854857	et	3	main
et	doc_767882159224_item	2854865	et	3	main
kujuta	doc_767882159224_item	2854876	et	4	main
rahvalaulul	doc_767882159224_item	2854907	et	3	main
liigutusi	doc_767882159224_item	2854910	et	4	main
kasutusele	doc_767882159224_item	2854922	et	4	main
mida	doc_767882159224_item	2854928	et	4	main
essee	doc_767882159224_item	2854756	et	4	main
keele	doc_767882159224_item	2854758	et	4	main
teise	doc_767882159224_item	2854760	et	4	main
teeb	doc_767882159224_item	2854768	et	3	main
eestlastest	doc_767882159224_item	2854769	et	4	main
laulurahva	doc_767882159224_item	2854770	et	3	main
essee	doc_767882159224_item	2854776	et	4	main
arutlev	doc_767882159224_item	2854779	et	4	main
ja	doc_767882159224_item	2854785	et	3	main
laulda	doc_767882159224_item	2854822	et	4	main
ja	doc_767882159224_item	2854824	et	3	main
osavõtjate	doc_767882159224_item	2854830	et	3	main
otsustati	doc_767882159224_item	2854858	et	3	main
korraldata	doc_767882159224_item	2854859	et	3	main
pidu	doc_767882159224_item	2854860	et	4	main
see	doc_767882159224_item	2854866	et	3	main
oli	doc_767882159224_item	2854868	et	3	main
inimestele	doc_767882159224_item	2854871	et	3	main
on	doc_767882159224_item	2854918	et	4	main
kõik	doc_767882159224_item	2854919	et	4	main
teistmoodi	doc_767882159224_item	2854920	et	3	main
essee	doc_767882159224_item	2854765	et	4	main
sõna	doc_767882159224_item	2854775	et	4	main
analüüsiv	doc_767882159224_item	2854780	et	4	main
esitatud	doc_767882159224_item	2854787	et	4	main
keele	doc_767882159224_item	2854761	et	4	main
test	doc_767882159224_item	2854762	et	3	main
essee	doc_767882159224_item	2854771	et	4	main
peab	doc_767882159224_item	2854777	et	4	main
üldistav	doc_767882159224_item	2854782	et	4	main
faktidele	doc_767882159224_item	2854788	et	3	main
väiteid	doc_767882159224_item	2854789	et	4	main
on	doc_767882159224_item	2854790	et	4	main
soovitatav	doc_767882159224_item	2854791	et	4	main
illustreerida	doc_767882159224_item	2854792	et	3	main
näidetega	doc_767882159224_item	2854793	et	3	main
mis	doc_767882159224_item	2854794	et	4	main
teeb	doc_767882159224_item	2854795	et	3	main
eestlastest	doc_767882159224_item	2854796	et	4	main
laulurahva	doc_767882159224_item	2854797	et	3	main
kõik	doc_767882159224_item	2854798	et	4	main
teavad	doc_767882159224_item	2854799	et	3	main
et	doc_767882159224_item	2854800	et	3	main
juba	doc_767882159224_item	2854801	et	3	main
1869	doc_767882159224_item	2854802	et	2	main
aastast	doc_767882159224_item	2854803	et	4	main
eestis	doc_767882159224_item	2854804	et	3	main
korraldatakse	doc_767882159224_item	2854805	et	3	main
laulupidusi	doc_767882159224_item	2854806	et	4	main
mille	doc_767882159224_item	2854807	et	3	main
korraldamise	doc_767882159224_item	2854808	et	4	main
ja	doc_767882159224_item	2854810	et	3	main
idee	doc_767882159224_item	2854809	et	4	main
teostus	doc_767882159224_item	2854811	et	4	main
tuli	doc_767882159224_item	2854812	et	4	main
vanemuise	doc_767882159224_item	2854813	et	4	main
seltsist	doc_767882159224_item	2854814	et	4	main
juba	doc_767882159224_item	2854815	et	3	main
sel	doc_767882159224_item	2854816	et	3	main
ajal	doc_767882159224_item	2854817	et	4	main
meie	doc_767882159224_item	2854818	et	4	main
rahval	doc_767882159224_item	2854819	et	3	main
oli	doc_767882159224_item	2854820	et	3	main
võtta	doc_767882159224_item	2854825	et	3	main
kasvas	doc_767882159224_item	2854832	et	3	main
tähistasid	doc_767882159224_item	2854846	et	4	main
linnas	doc_767882159224_item	2854862	et	4	main
pidu	doc_767882159224_item	2854867	et	4	main
väga	doc_767882159224_item	2854869	et	3	main
praegu	doc_767882159224_item	2854873	et	3	main
ei	doc_767882159224_item	2854875	et	4	main
ette	doc_767882159224_item	2854877	et	4	main
nad	doc_767882159224_item	2854879	et	3	main
mida	doc_767882159224_item	2854878	et	4	main
teevad	doc_767882159224_item	2854880	et	3	main
ilma	doc_767882159224_item	2854881	et	4	main
laulupiduta	doc_767882159224_item	2854882	et	3	main
sest	doc_767882159224_item	2854883	et	4	main
ka	doc_767882159224_item	2854884	et	3	main
praegusel	doc_767882159224_item	2854885	et	3	main
ajal	doc_767882159224_item	2854886	et	4	main
laulupidu	doc_767882159224_item	2854887	et	4	main
on	doc_767882159224_item	2854888	et	4	main
kõige	doc_767882159224_item	2854889	et	4	main
tähelepanuväärsem	doc_767882159224_item	2854890	et	4	main
ja	doc_767882159224_item	2854891	et	3	main
massilisem	doc_767882159224_item	2854892	et	4	main
manifestatsioon	doc_767882159224_item	2854893	et	3	main
aga	doc_767882159224_item	2854894	et	3	main
kahjuks	doc_767882159224_item	2854895	et	4	main
praegu	doc_767882159224_item	2854896	et	3	main
koorimeistrid	doc_767882159224_item	2854897	et	3	main
on	doc_767882159224_item	2854898	et	4	main
kadunud	doc_767882159224_item	2854899	et	4	main
aga	doc_767882159224_item	2854900	et	3	main
see	doc_767882159224_item	2854901	et	3	main
ei	doc_767882159224_item	2854902	et	4	main
tee	doc_767882159224_item	2854903	et	4	main
pidu	doc_767882159224_item	2854904	et	4	main
halvem	doc_767882159224_item	2854905	et	4	main
sest	doc_767882159224_item	2854906	et	4	main
arv	doc_767882159224_item	2854831	et	3	main
olid	doc_767882159224_item	2854834	et	4	main
meeskoorid	doc_767882159224_item	2854836	et	4	main
hiljem	doc_767882159224_item	2854837	et	3	main
aastat	doc_767882159224_item	2854848	et	3	main
kahes	doc_767882159224_item	2854861	et	4	main
kasutama	doc_767882159224_item	2854909	et	3	main
kui	doc_767882159224_item	2854912	et	3	main
lauldi	doc_767882159224_item	2854914	et	3	main
instrumendid	doc_767882159224_item	2854924	et	3	main
uued	doc_767882159224_item	2854926	et	3	main
näitab	doc_767882159224_item	2854951	et	3	main
on	doc_767882159224_item	2854954	et	4	main
meelega	doc_767882159224_item	2854960	et	4	main
läheb	doc_767882159224_item	2854961	et	3	main
laulupidu	doc_767882159224_item	2854964	et	4	main
kui	doc_767882159224_item	2854985	et	3	main
saavad	doc_767882159224_item	2854990	et	4	main
gustav	doc_767882159224_item	2854992	et	4	main
ernesaksa	doc_767882159224_item	2854993	et	4	main
laulupidudel	doc_767882159224_item	2855025	et	4	main
näha	doc_767882159224_item	2855029	et	3	main
tähtis	doc_767882159224_item	2854870	et	4	main
ja	doc_767882159224_item	2854872	et	3	main
nad	doc_767882159224_item	2854874	et	3	main
ja	doc_767882159224_item	2854911	et	3	main
varem	doc_767882159224_item	2854913	et	4	main
võeti	doc_767882159224_item	2854921	et	3	main
uued	doc_767882159224_item	2854923	et	3	main
nt	doc_767882159224_item	2854925	et	4	main
olnud	doc_767882159224_item	2854932	et	4	main
on	doc_767882159224_item	2854935	et	4	main
väga	doc_767882159224_item	2854936	et	3	main
vana	doc_767882159224_item	2854939	et	4	main
laulu	doc_767882159224_item	2854940	et	4	main
ja	doc_767882159224_item	2854941	et	3	main
teha	doc_767882159224_item	2854942	et	3	main
seda	doc_767882159224_item	2854943	et	3	main
uuemas	doc_767882159224_item	2854944	et	4	main
et	doc_767882159224_item	2854952	et	3	main
hea	doc_767882159224_item	2854959	et	4	main
kõik	doc_767882159224_item	2854989	et	4	main
ette	doc_767882159224_item	2855006	et	4	main
et	doc_767882159224_item	2855007	et	3	main
kõrgem	doc_767882159224_item	2855016	et	4	main
hetk	doc_767882159224_item	2855017	et	3	main
on	doc_767882159224_item	2855028	et	4	main
on	doc_767882159224_item	2855032	et	4	main
hakati	doc_767882159224_item	2854908	et	3	main
ilma	doc_767882159224_item	2854915	et	4	main
muusikata	doc_767882159224_item	2854916	et	3	main
nüüd	doc_767882159224_item	2854917	et	4	main
pillid	doc_767882159224_item	2854927	et	4	main
rahvalaulul	doc_767882159224_item	2854930	et	3	main
aastadel	doc_767882159224_item	2854934	et	4	main
moodne	doc_767882159224_item	2854937	et	3	main
see	doc_767882159224_item	2854950	et	3	main
üritusele	doc_767882159224_item	2854965	et	4	main
isamaalaulu	doc_767882159224_item	2854995	et	4	main
mu	doc_767882159224_item	2854996	et	3	main
isamaa	doc_767882159224_item	2854997	et	4	main
nad	doc_767882159224_item	2855008	et	3	main
sellel	doc_767882159224_item	2855018	et	4	main
ja	doc_767882159224_item	2855020	et	3	main
et	doc_767882159224_item	2855030	et	3	main
varem	doc_767882159224_item	2854929	et	4	main
viimastel	doc_767882159224_item	2854933	et	3	main
võtta	doc_767882159224_item	2854938	et	3	main
modern	doc_767882159224_item	2854948	et	4	main
muusikat	doc_767882159224_item	2854949	et	3	main
laulu	doc_767882159224_item	2854955	et	4	main
oma	doc_767882159224_item	2854962	et	4	main
perega	doc_767882159224_item	2854963	et	3	main
kus	doc_767882159224_item	2854966	et	3	main
saab	doc_767882159224_item	2854967	et	3	main
natuke	doc_767882159224_item	2854968	et	4	main
laulda	doc_767882159224_item	2854969	et	4	main
ja	doc_767882159224_item	2854970	et	3	main
tantsida	doc_767882159224_item	2854971	et	3	main
kohata	doc_767882159224_item	2854972	et	4	main
sõpru	doc_767882159224_item	2854973	et	3	main
tuttavaid	doc_767882159224_item	2854974	et	3	main
ja	doc_767882159224_item	2854975	et	3	main
sugulasi	doc_767882159224_item	2854976	et	3	main
kes	doc_767882159224_item	2854977	et	4	main
on	doc_767882159224_item	2854978	et	4	main
üle	doc_767882159224_item	2854979	et	3	main
kogu	doc_767882159224_item	2854980	et	4	main
eesti	doc_767882159224_item	2854981	et	4	main
kokku	doc_767882159224_item	2854982	et	3	main
sõitnud	doc_767882159224_item	2854983	et	4	main
ja	doc_767882159224_item	2854984	et	3	main
ei	doc_767882159224_item	2854931	et	4	main
stiilis	doc_767882159224_item	2854945	et	4	main
ja	doc_767882159224_item	2854946	et	3	main
esitada	doc_767882159224_item	2854947	et	3	main
eestlased	doc_767882159224_item	2854953	et	3	main
rahv	doc_767882159224_item	2854956	et	4	main
iga	doc_767882159224_item	2854957	et	4	main
eestlane	doc_767882159224_item	2854958	et	3	main
hingestatud	doc_767882159224_item	2854994	et	4	main
on	doc_767882159224_item	2855003	et	4	main
võimalus	doc_767882159224_item	2855004	et	3	main
kujutada	doc_767882159224_item	2855005	et	3	main
esimesele	doc_767882159224_item	2855010	et	3	main
laulupeole	doc_767882159224_item	2855011	et	4	main
kõige	doc_767882159224_item	2855015	et	4	main
kui	doc_767882159224_item	2855021	et	3	main
eestlased	doc_767882159224_item	2855023	et	3	main
rohkem	doc_767882159224_item	2855027	et	4	main
eestlased	doc_767882159224_item	2855031	et	3	main
pidu	doc_767882159224_item	2854986	et	4	main
lõpeb	doc_767882159224_item	2854987	et	4	main
siis	doc_767882159224_item	2854988	et	3	main
kuulata	doc_767882159224_item	2854991	et	4	main
on	doc_767882159224_item	2854998	et	4	main
minu	doc_767882159224_item	2854999	et	3	main
arm	doc_767882159224_item	2855000	et	3	main
ja	doc_767882159224_item	2855001	et	3	main
neil	doc_767882159224_item	2855002	et	4	main
sattusid	doc_767882159224_item	2855009	et	4	main
tegelikult	doc_767882159224_item	2855012	et	4	main
see	doc_767882159224_item	2855013	et	3	main
on	doc_767882159224_item	2855014	et	4	main
üritusel	doc_767882159224_item	2855019	et	4	main
kaua	doc_767882159224_item	2855022	et	3	main
käivad	doc_767882159224_item	2855024	et	4	main
seda	doc_767882159224_item	2855026	et	3	main
laulurahv	doc_767882159224_item	2855033	et	4	main
essee	doc_767882159227_item	2855613	et	4	main
keele	doc_767882159227_item	2855615	et	4	main
kui	doc_767882159227_item	2855616	et	3	main
teise	doc_767882159227_item	2855617	et	4	main
kirjutage	doc_767882159227_item	2855621	et	3	main
essee	doc_767882159227_item	2855628	et	4	main
loengus	doc_767882159227_item	2855641	et	3	main
lugemistekstis	doc_767882159227_item	2855643	et	3	main
faktidele	doc_767882159227_item	2855645	et	3	main
väiteid	doc_767882159227_item	2855646	et	4	main
näidetega	doc_767882159227_item	2855650	et	3	main
laulsid	doc_767882159227_item	2855660	et	4	main
kodus	doc_767882159227_item	2855661	et	4	main
töös	doc_767882159227_item	2855662	et	3	main
pulmadel	doc_767882159227_item	2855663	et	3	main
olnud	doc_767882159227_item	2855667	et	4	main
oluline	doc_767882159227_item	2855670	et	4	main
on	doc_767882159227_item	2855674	et	4	main
tähtis	doc_767882159227_item	2855676	et	4	main
ole	doc_767882159227_item	2855693	et	4	main
üldse	doc_767882159227_item	2855694	et	3	main
eesti	doc_767882159227_item	2855614	et	4	main
350	doc_767882159227_item	2855631	et	2	main
sõna	doc_767882159227_item	2855632	et	4	main
peab	doc_767882159227_item	2855634	et	4	main
illustreerida	doc_767882159227_item	2855649	et	3	main
on	doc_767882159227_item	2855652	et	4	main
oluline	doc_767882159227_item	2855658	et	4	main
inimesed	doc_767882159227_item	2855659	et	3	main
on	doc_767882159227_item	2855666	et	4	main
väike	doc_767882159227_item	2855690	et	4	main
territoorium	doc_767882159227_item	2855691	et	3	main
tugev	doc_767882159227_item	2855721	et	4	main
mäletada	doc_767882159227_item	2855725	et	3	main
kasulik	doc_767882159227_item	2855732	et	3	main
oli	doc_767882159227_item	2855750	et	3	main
põhiliselt	doc_767882159227_item	2855752	et	4	main
jaoks	doc_767882159227_item	2855754	et	4	main
kes	doc_767882159227_item	2855755	et	4	main
siis	doc_767882159227_item	2855761	et	3	main
praegu	doc_767882159227_item	2855762	et	3	main
uued	doc_767882159227_item	2855764	et	3	main
kollektiivid	doc_767882159227_item	2855765	et	3	main
inimestele	doc_767882159227_item	2855769	et	3	main
rahvalaulu	doc_767882159227_item	2855771	et	4	main
olid	doc_767882159227_item	2855778	et	4	main
igasugused	doc_767882159227_item	2855779	et	3	main
laulud	doc_767882159227_item	2855780	et	3	main
näiteks	doc_767882159227_item	2855781	et	4	main
lastelaulud	doc_767882159227_item	2855782	et	3	main
kahjuks	doc_767882159227_item	2855785	et	4	main
vanad	doc_767882159227_item	2855787	et	3	main
kadunud	doc_767882159227_item	2855792	et	4	main
sajandil	doc_767882159227_item	2855794	et	3	main
hakkas	doc_767882159227_item	2855795	et	3	main
ilmuma	doc_767882159227_item	2855796	et	3	main
uus	doc_767882159227_item	2855797	et	3	main
rahvalaul	doc_767882159227_item	2855798	et	4	main
keele	doc_767882159227_item	2855618	et	4	main
test	doc_767882159227_item	2855619	et	3	main
kirjutamine	doc_767882159227_item	2855620	et	4	main
mis	doc_767882159227_item	2855624	et	4	main
300	doc_767882159227_item	2855630	et	2	main
arutlev	doc_767882159227_item	2855636	et	4	main
analüüsiv	doc_767882159227_item	2855637	et	4	main
tuginema	doc_767882159227_item	2855640	et	3	main
eestlaste	doc_767882159227_item	2855655	et	4	main
igalpool	doc_767882159227_item	2855664	et	4	main
inimeste	doc_767882159227_item	2855668	et	3	main
nii	doc_767882159227_item	2855675	et	3	main
eestlaste	doc_767882159227_item	2855677	et	4	main
jaoks	doc_767882159227_item	2855678	et	4	main
ma	doc_767882159227_item	2855679	et	3	main
arvan	doc_767882159227_item	2855680	et	3	main
et	doc_767882159227_item	2855681	et	3	main
laul	doc_767882159227_item	2855682	et	4	main
aitab	doc_767882159227_item	2855683	et	3	main
olla	doc_767882159227_item	2855684	et	3	main
ei	doc_767882159227_item	2855692	et	4	main
pole	doc_767882159227_item	2855697	et	3	main
olnud	doc_767882159227_item	2855700	et	4	main
inimesi	doc_767882159227_item	2855701	et	4	main
on	doc_767882159227_item	2855702	et	4	main
uskuda	doc_767882159227_item	2855723	et	3	main
oled	doc_767882159227_item	2855728	et	3	main
ajalugu	doc_767882159227_item	2855742	et	4	main
see	doc_767882159227_item	2855749	et	3	main
naiste	doc_767882159227_item	2855753	et	3	main
regilauluks	doc_767882159227_item	2855774	et	4	main
või	doc_767882159227_item	2855783	et	4	main
laulud	doc_767882159227_item	2855788	et	3	main
praegu	doc_767882159227_item	2855790	et	3	main
olemas	doc_767882159227_item	2855829	et	4	main
teemal	doc_767882159227_item	2855623	et	3	main
pikkus	doc_767882159227_item	2855629	et	4	main
essee	doc_767882159227_item	2855633	et	4	main
olema	doc_767882159227_item	2855635	et	4	main
üldistav	doc_767882159227_item	2855639	et	4	main
soovitatav	doc_767882159227_item	2855648	et	4	main
jaoks	doc_767882159227_item	2855656	et	4	main
väga	doc_767882159227_item	2855657	et	3	main
laul	doc_767882159227_item	2855665	et	4	main
elu	doc_767882159227_item	2855669	et	4	main
osa	doc_767882159227_item	2855671	et	4	main
miks	doc_767882159227_item	2855672	et	4	main
tugevam	doc_767882159227_item	2855685	et	4	main
ja	doc_767882159227_item	2855724	et	3	main
sa	doc_767882159227_item	2855727	et	3	main
oli	doc_767882159227_item	2855730	et	3	main
selle	doc_767882159227_item	2855734	et	4	main
on	doc_767882159227_item	2855736	et	4	main
rahva	doc_767882159227_item	2855737	et	3	main
minevik	doc_767882159227_item	2855738	et	3	main
selle	doc_767882159227_item	2855739	et	4	main
kultuur	doc_767882159227_item	2855740	et	3	main
ja	doc_767882159227_item	2855741	et	3	main
muutunud	doc_767882159227_item	2855746	et	4	main
kui	doc_767882159227_item	2855747	et	3	main
vanasti	doc_767882159227_item	2855748	et	3	main
kodus	doc_767882159227_item	2855757	et	4	main
tegelesid	doc_767882159227_item	2855759	et	4	main
lastega	doc_767882159227_item	2855760	et	3	main
ravalaulu	doc_767882159227_item	2855768	et	4	main
ilma	doc_767882159227_item	2855776	et	4	main
pillisaateta	doc_767882159227_item	2855777	et	3	main
muinasjuttulaulud	doc_767882159227_item	2855784	et	3	main
on	doc_767882159227_item	2855789	et	4	main
juba	doc_767882159227_item	2855791	et	3	main
19	doc_767882159227_item	2855793	et	2	main
jaoks	doc_767882159227_item	2855821	et	4	main
ja	doc_767882159227_item	2855823	et	3	main
ka	doc_767882159227_item	2855825	et	3	main
sellel	doc_767882159227_item	2855827	et	4	main
juba	doc_767882159227_item	2855836	et	3	main
on	doc_767882159227_item	2855844	et	4	main
loomingus	doc_767882159227_item	2855853	et	3	main
kasutada	doc_767882159227_item	2855854	et	3	main
keegi	doc_767882159227_item	2855860	et	4	main
kuule	doc_767882159227_item	2855868	et	4	main
see	doc_767882159227_item	2855869	et	3	main
aga	doc_767882159227_item	2855870	et	3	main
viimase	doc_767882159227_item	2855873	et	3	main
ilmunud	doc_767882159227_item	2855878	et	4	main
laule	doc_767882159227_item	2855885	et	4	main
ja	doc_767882159227_item	2855886	et	3	main
kasutades	doc_767882159227_item	2855887	et	3	main
on	doc_767882159227_item	2855897	et	4	main
saavad	doc_767882159227_item	2855904	et	4	main
tutvuda	doc_767882159227_item	2855906	et	3	main
uued	doc_767882159227_item	2855908	et	3	main
koorid	doc_767882159227_item	2855909	et	4	main
ja	doc_767882159227_item	2855910	et	3	main
ansamblid	doc_767882159227_item	2855911	et	3	main
kus	doc_767882159227_item	2855912	et	3	main
huvitavam	doc_767882159227_item	2855928	et	4	main
ja	doc_767882159227_item	2855929	et	3	main
arusaadavam	doc_767882159227_item	2855930	et	4	main
noorte	doc_767882159227_item	2855931	et	3	main
inimeste	doc_767882159227_item	2855932	et	3	main
jaoks	doc_767882159227_item	2855933	et	4	main
ja	doc_767882159227_item	2855934	et	3	main
ise	doc_767882159227_item	2855952	et	4	main
keele	doc_767882159228_item	2855955	et	4	main
mis	doc_767882159228_item	2855964	et	4	main
sõna	doc_767882159228_item	2855972	et	4	main
eestlased	doc_767882159228_item	2856003	et	3	main
peol	doc_767882159228_item	2856008	et	4	main
laul	doc_767882159228_item	2856011	et	4	main
jaoks	doc_767882159228_item	2856014	et	4	main
nagu	doc_767882159228_item	2856015	et	3	main
abi	doc_767882159228_item	2856016	et	4	main
mehed	doc_767882159228_item	2856024	et	3	main
osa	doc_767882159228_item	2856028	et	4	main
essee	doc_767882159227_item	2855622	et	4	main
teeb	doc_767882159227_item	2855625	et	3	main
eestlastest	doc_767882159227_item	2855626	et	4	main
laulurahva	doc_767882159227_item	2855627	et	3	main
ja	doc_767882159227_item	2855638	et	3	main
ja	doc_767882159227_item	2855642	et	3	main
esitatud	doc_767882159227_item	2855644	et	4	main
on	doc_767882159227_item	2855647	et	4	main
laulmine	doc_767882159227_item	2855651	et	4	main
alati	doc_767882159227_item	2855653	et	4	main
olnud	doc_767882159227_item	2855654	et	4	main
laul	doc_767882159227_item	2855673	et	4	main
eesti	doc_767882159227_item	2855686	et	4	main
rahvas	doc_767882159227_item	2855687	et	4	main
on	doc_767882159227_item	2855688	et	4	main
päris	doc_767882159227_item	2855689	et	4	main
ja	doc_767882159227_item	2855696	et	3	main
suur	doc_767882159227_item	2855699	et	3	main
vähe	doc_767882159227_item	2855703	et	3	main
eesti	doc_767882159227_item	2855704	et	4	main
juures	doc_767882159227_item	2855705	et	4	main
on	doc_767882159227_item	2855706	et	4	main
alati	doc_767882159227_item	2855707	et	4	main
elanud	doc_767882159227_item	2855708	et	4	main
suuremad	doc_767882159227_item	2855709	et	4	main
ja	doc_767882159227_item	2855710	et	3	main
tugevamad	doc_767882159227_item	2855711	et	4	main
rahvad	doc_767882159227_item	2855712	et	3	main
ja	doc_767882159227_item	2855713	et	3	main
selleks	doc_767882159227_item	2855714	et	4	main
et	doc_767882159227_item	2855715	et	3	main
eestlaseks	doc_767882159227_item	2855716	et	3	main
jääda	doc_767882159227_item	2855717	et	4	main
oli	doc_767882159227_item	2855718	et	3	main
vaja	doc_767882159227_item	2855719	et	4	main
olla	doc_767882159227_item	2855720	et	3	main
kes	doc_767882159227_item	2855726	et	4	main
laul	doc_767882159227_item	2855731	et	4	main
sees	doc_767882159227_item	2855735	et	4	main
loomulikult	doc_767882159227_item	2855745	et	4	main
laul	doc_767882159227_item	2855751	et	4	main
ja	doc_767882159227_item	2855758	et	3	main
ilmuvad	doc_767882159227_item	2855763	et	4	main
kes	doc_767882159227_item	2855766	et	4	main
laulti	doc_767882159227_item	2855775	et	4	main
need	doc_767882159227_item	2855786	et	3	main
on	doc_767882159227_item	2855800	et	4	main
tavalisem	doc_767882159227_item	2855822	et	4	main
sellega	doc_767882159227_item	2855824	et	3	main
arusaadavam	doc_767882159227_item	2855826	et	4	main
on	doc_767882159227_item	2855833	et	4	main
hakkasid	doc_767882159227_item	2855839	et	4	main
kultuuri	doc_767882159227_item	2855845	et	4	main
väga	doc_767882159227_item	2855846	et	3	main
oluline	doc_767882159227_item	2855847	et	4	main
võib	doc_767882159227_item	2855856	et	3	main
rahvalauludest	doc_767882159227_item	2855859	et	3	main
mitte	doc_767882159227_item	2855861	et	3	main
midagi	doc_767882159227_item	2855862	et	4	main
ei	doc_767882159227_item	2855863	et	4	main
pole	doc_767882159227_item	2855871	et	3	main
palju	doc_767882159227_item	2855879	et	4	main
kes	doc_767882159227_item	2855881	et	4	main
otsivad	doc_767882159227_item	2855882	et	4	main
suur	doc_767882159227_item	2855695	et	3	main
kunagi	doc_767882159227_item	2855698	et	3	main
iseennesse	doc_767882159227_item	2855722	et	4	main
selleks	doc_767882159227_item	2855729	et	4	main
sest	doc_767882159227_item	2855733	et	4	main
rahvalaul	doc_767882159227_item	2855743	et	4	main
on	doc_767882159227_item	2855744	et	4	main
töötasid	doc_767882159227_item	2855756	et	4	main
näitavad	doc_767882159227_item	2855767	et	4	main
vanemat	doc_767882159227_item	2855770	et	4	main
mida	doc_767882159227_item	2855772	et	4	main
nimetatakse	doc_767882159227_item	2855773	et	3	main
sellel	doc_767882159227_item	2855799	et	4	main
võimalik	doc_767882159227_item	2855801	et	3	main
tunda	doc_767882159227_item	2855802	et	3	main
nii	doc_767882159227_item	2855803	et	3	main
euroopa	doc_767882159227_item	2855804	et	4	main
riikide	doc_767882159227_item	2855805	et	3	main
kui	doc_767882159227_item	2855806	et	3	main
ka	doc_767882159227_item	2855807	et	3	main
vene	doc_767882159227_item	2855808	et	4	main
laude	doc_767882159227_item	2855809	et	3	main
mõju	doc_767882159227_item	2855810	et	4	main
võib	doc_767882159227_item	2855811	et	3	main
olla	doc_767882159227_item	2855812	et	3	main
see	doc_767882159227_item	2855813	et	3	main
ongi	doc_767882159227_item	2855814	et	4	main
põhjuseks	doc_767882159227_item	2855815	et	3	main
miks	doc_767882159227_item	2855816	et	4	main
uuem	doc_767882159227_item	2855817	et	4	main
rahvalaul	doc_767882159227_item	2855818	et	4	main
on	doc_767882159227_item	2855819	et	4	main
meie	doc_767882159227_item	2855820	et	4	main
on	doc_767882159227_item	2855828	et	4	main
esitatud	doc_767882159227_item	2855834	et	4	main
oma	doc_767882159227_item	2855852	et	4	main
praegu	doc_767882159227_item	2855855	et	3	main
et	doc_767882159227_item	2855858	et	3	main
rahvalaule	doc_767882159227_item	2855866	et	4	main
30	doc_767882159227_item	2855874	et	2	main
folkloorikollektiive	doc_767882159227_item	2855880	et	3	main
neid	doc_767882159227_item	2855888	et	4	main
eesti	doc_767882159227_item	2855893	et	4	main
eestis	doc_767882159227_item	2855898	et	3	main
festivalid	doc_767882159227_item	2855901	et	3	main
inimesed	doc_767882159227_item	2855903	et	3	main
on	doc_767882159227_item	2855913	et	4	main
kasutavad	doc_767882159227_item	2855921	et	4	main
koos	doc_767882159227_item	2855923	et	4	main
rock-muusikaga	doc_767882159227_item	2855924	et	3	main
mis	doc_767882159227_item	2855925	et	4	main
teeb	doc_767882159227_item	2855926	et	3	main
aitab	doc_767882159227_item	2855935	et	3	main
ma	doc_767882159227_item	2855939	et	3	main
et	doc_767882159227_item	2855942	et	3	main
rahvas	doc_767882159227_item	2855951	et	4	main
eesti	doc_767882159228_item	2855954	et	4	main
kui	doc_767882159228_item	2855956	et	3	main
teeb	doc_767882159228_item	2855965	et	3	main
eestlastest	doc_767882159228_item	2855966	et	4	main
laulurahva	doc_767882159228_item	2855967	et	3	main
analüüsiv	doc_767882159228_item	2855977	et	4	main
laulsid	doc_767882159228_item	2856004	et	4	main
töö	doc_767882159228_item	2856005	et	4	main
pillisaatega	doc_767882159227_item	2855835	et	3	main
aru	doc_767882159227_item	2855840	et	4	main
saama	doc_767882159227_item	2855841	et	4	main
et	doc_767882159227_item	2855842	et	3	main
osa	doc_767882159227_item	2855848	et	4	main
tea	doc_767882159227_item	2855864	et	4	main
ja	doc_767882159227_item	2855865	et	3	main
nii	doc_767882159227_item	2855872	et	3	main
aasta	doc_767882159227_item	2855875	et	4	main
oma	doc_767882159227_item	2855889	et	4	main
loomingus	doc_767882159227_item	2855890	et	3	main
aitavad	doc_767882159227_item	2855891	et	4	main
meid	doc_767882159227_item	2855892	et	4	main
kuulda	doc_767882159227_item	2855895	et	4	main
ilmuvad	doc_767882159227_item	2855907	et	4	main
inimesi	doc_767882159227_item	2855916	et	4	main
peale	doc_767882159227_item	2855917	et	4	main
seda	doc_767882159227_item	2855918	et	3	main
kaasaegsed	doc_767882159227_item	2855919	et	3	main
kollektiivid	doc_767882159227_item	2855920	et	3	main
lõppriim	doc_767882159227_item	2855830	et	3	main
ja	doc_767882159227_item	2855831	et	3	main
seda	doc_767882159227_item	2855832	et	3	main
hiljem	doc_767882159227_item	2855837	et	3	main
heliloojad	doc_767882159227_item	2855838	et	3	main
rahvalaul	doc_767882159227_item	2855843	et	4	main
ja	doc_767882159227_item	2855849	et	3	main
hakkasid	doc_767882159227_item	2855850	et	4	main
seda	doc_767882159227_item	2855851	et	3	main
tuntuda	doc_767882159227_item	2855857	et	4	main
ei	doc_767882159227_item	2855867	et	4	main
jooksul	doc_767882159227_item	2855876	et	4	main
on	doc_767882159227_item	2855877	et	4	main
tänapäeval	doc_767882159227_item	2855896	et	3	main
igasugused	doc_767882159227_item	2855900	et	3	main
kus	doc_767882159227_item	2855902	et	3	main
palju	doc_767882159227_item	2855914	et	4	main
noori	doc_767882159227_item	2855915	et	3	main
kaua	doc_767882159227_item	2855947	et	3	main
kui	doc_767882159227_item	2855948	et	3	main
elab	doc_767882159227_item	2855949	et	3	main
eesti	doc_767882159227_item	2855950	et	4	main
essee	doc_767882159228_item	2855953	et	4	main
keele	doc_767882159228_item	2855958	et	4	main
kirjutamine	doc_767882159228_item	2855960	et	4	main
kirjutage	doc_767882159228_item	2855961	et	3	main
pikkus	doc_767882159228_item	2855969	et	4	main
300	doc_767882159228_item	2855970	et	2	main
350	doc_767882159228_item	2855971	et	2	main
peab	doc_767882159228_item	2855974	et	4	main
laulsid	doc_767882159228_item	2856007	et	4	main
nende	doc_767882159228_item	2856017	et	4	main
raskes	doc_767882159228_item	2856018	et	3	main
töös	doc_767882159228_item	2856019	et	3	main
peamiselt	doc_767882159228_item	2856021	et	4	main
esimese	doc_767882159228_item	2856029	et	3	main
regilaul	doc_767882159228_item	2856032	et	4	main
algas	doc_767882159228_item	2856039	et	3	main
koor	doc_767882159228_item	2856041	et	4	main
regilaul	doc_767882159228_item	2856043	et	4	main
põlvest	doc_767882159228_item	2856052	et	4	main
kirikulaul	doc_767882159228_item	2856057	et	4	main
laulu	doc_767882159228_item	2856069	et	4	main
andi	doc_767882159228_item	2856071	et	4	main
muusikapillid	doc_767882159228_item	2856072	et	3	main
ilmus	doc_767882159228_item	2856074	et	4	main
mis	doc_767882159228_item	2856084	et	4	main
laulud	doc_767882159228_item	2856089	et	3	main
juba	doc_767882159228_item	2856092	et	3	main
seda	doc_767882159228_item	2856121	et	3	main
tunda	doc_767882159228_item	2856131	et	3	main
ja	doc_767882159228_item	2856142	et	3	main
laulu	doc_767882159228_item	2856148	et	4	main
missuguseid	doc_767882159228_item	2856149	et	3	main
töötama	doc_767882159228_item	2856156	et	3	main
esimesed	doc_767882159228_item	2856158	et	3	main
eestlased	doc_767882159228_item	2856160	et	3	main
olid	doc_767882159228_item	2856162	et	4	main
lõpetanud	doc_767882159228_item	2856163	et	4	main
teater	doc_767882159228_item	2856168	et	3	main
eestlased	doc_767882159228_item	2856186	et	3	main
arhiivis	doc_767882159227_item	2855883	et	3	main
vana	doc_767882159227_item	2855884	et	4	main
rahvalaule	doc_767882159227_item	2855894	et	4	main
olemas	doc_767882159227_item	2855899	et	4	main
rahvalauluga	doc_767882159227_item	2855905	et	4	main
rahvalaulu	doc_767882159227_item	2855927	et	4	main
rahvalaulule	doc_767882159227_item	2855936	et	3	main
jääda	doc_767882159227_item	2855938	et	4	main
olen	doc_767882159227_item	2855940	et	3	main
essee	doc_767882159228_item	2855962	et	4	main
teemal	doc_767882159228_item	2855963	et	3	main
ajal	doc_767882159228_item	2856006	et	4	main
kodus	doc_767882159228_item	2856010	et	4	main
naised	doc_767882159228_item	2856022	et	3	main
võtsid	doc_767882159228_item	2856026	et	4	main
rahvalauluna	doc_767882159228_item	2856030	et	4	main
vanem	doc_767882159228_item	2856046	et	4	main
suhu	doc_767882159228_item	2856051	et	3	main
rahvalauluna	doc_767882159228_item	2856055	et	4	main
mis	doc_767882159228_item	2856058	et	4	main
arenemiseks	doc_767882159228_item	2856070	et	4	main
eestis	doc_767882159228_item	2856073	et	3	main
vargan	doc_767882159228_item	2856076	et	4	main
rahvalaul	doc_767882159228_item	2856083	et	4	main
korraldas	doc_767882159228_item	2856122	et	3	main
sai	doc_767882159228_item	2856128	et	4	main
laulumaterial	doc_767882159228_item	2856140	et	4	main
kontrollitati	doc_767882159228_item	2856141	et	3	main
eestlased	doc_767882159228_item	2856143	et	3	main
nad	doc_767882159228_item	2856150	et	3	main
konservatooriumi	doc_767882159228_item	2856164	et	4	main
tallinnas	doc_767882159228_item	2856174	et	4	main
esindavad	doc_767882159228_item	2856184	et	4	main
nii	doc_767882159228_item	2856185	et	3	main
rahvalaulu	doc_767882159227_item	2855922	et	4	main
ellu	doc_767882159227_item	2855937	et	4	main
kindel	doc_767882159227_item	2855941	et	3	main
eesti	doc_767882159227_item	2855943	et	4	main
rahvalaul	doc_767882159227_item	2855944	et	4	main
elab	doc_767882159227_item	2855945	et	3	main
nii	doc_767882159227_item	2855946	et	3	main
teise	doc_767882159228_item	2855957	et	4	main
test	doc_767882159228_item	2855959	et	3	main
essee	doc_767882159228_item	2855968	et	4	main
essee	doc_767882159228_item	2855973	et	4	main
olema	doc_767882159228_item	2855975	et	4	main
arutlev	doc_767882159228_item	2855976	et	4	main
ja	doc_767882159228_item	2855978	et	3	main
üldistav	doc_767882159228_item	2855979	et	4	main
tuginema	doc_767882159228_item	2855980	et	3	main
loengus	doc_767882159228_item	2855981	et	3	main
ja	doc_767882159228_item	2855982	et	3	main
lugemistekstis	doc_767882159228_item	2855983	et	3	main
esitatud	doc_767882159228_item	2855984	et	4	main
väiteid	doc_767882159228_item	2855986	et	4	main
faktidele	doc_767882159228_item	2855985	et	3	main
on	doc_767882159228_item	2855987	et	4	main
soovitatav	doc_767882159228_item	2855988	et	4	main
illustreerida	doc_767882159228_item	2855989	et	3	main
näidetega	doc_767882159228_item	2855990	et	3	main
kas	doc_767882159228_item	2855991	et	3	main
võime	doc_767882159228_item	2855992	et	4	main
nimetada	doc_767882159228_item	2855993	et	3	main
eestlasi	doc_767882159228_item	2855994	et	3	main
laulurahvaks	doc_767882159228_item	2855995	et	3	main
muidugi	doc_767882159228_item	2855996	et	4	main
võime	doc_767882159228_item	2855997	et	4	main
eesti	doc_767882159228_item	2855998	et	4	main
laulu	doc_767882159228_item	2855999	et	4	main
ajalugu	doc_767882159228_item	2856000	et	4	main
ülatub	doc_767882159228_item	2856001	et	4	main
muinasajale	doc_767882159228_item	2856002	et	3	main
laulsid	doc_767882159228_item	2856009	et	4	main
laulsid	doc_767882159228_item	2856020	et	4	main
kuid	doc_767882159228_item	2856023	et	4	main
esineja	doc_767882159228_item	2856038	et	4	main
aitas	doc_767882159228_item	2856042	et	3	main
on	doc_767882159228_item	2856044	et	4	main
kõige	doc_767882159228_item	2856045	et	4	main
suust	doc_767882159228_item	2856050	et	3	main
tõuk	doc_767882159228_item	2856068	et	3	main
mõjul	doc_767882159228_item	2856080	et	4	main
tekkis	doc_767882159228_item	2856081	et	3	main
uus	doc_767882159228_item	2856082	et	3	main
rahvalauluks	doc_767882159228_item	2856087	et	4	main
esitati	doc_767882159228_item	2856090	et	4	main
18	doc_767882159228_item	2856093	et	2	main
sajandi	doc_767882159228_item	2856094	et	3	main
lõpus	doc_767882159228_item	2856095	et	4	main
w	doc_767882159228_item	2856124	et	4	main
rahvas	doc_767882159228_item	2856130	et	4	main
laulupidu	doc_767882159228_item	2856134	et	4	main
korraldama	doc_767882159228_item	2856136	et	3	main
iga	doc_767882159228_item	2856137	et	4	main
aasta	doc_767882159228_item	2856138	et	4	main
aga	doc_767882159228_item	2856139	et	3	main
neid	doc_767882159228_item	2856147	et	4	main
19	doc_767882159228_item	2856152	et	2	main
hakkasid	doc_767882159228_item	2856155	et	4	main
kes	doc_767882159228_item	2856161	et	4	main
oli	doc_767882159228_item	2856169	et	3	main
kui	doc_767882159228_item	2856187	et	3	main
oli	doc_767882159228_item	2856012	et	3	main
neile	doc_767882159228_item	2856013	et	4	main
ka	doc_767882159228_item	2856025	et	3	main
laulmises	doc_767882159228_item	2856027	et	4	main
ja	doc_767882159228_item	2856040	et	3	main
rahvalaul	doc_767882159228_item	2856047	et	4	main
mis	doc_767882159228_item	2856048	et	4	main
pärandati	doc_767882159228_item	2856049	et	4	main
ilmus	doc_767882159228_item	2856059	et	4	main
18	doc_767882159228_item	2856060	et	2	main
sajandil	doc_767882159228_item	2856061	et	3	main
saksa	doc_767882159228_item	2856065	et	4	main
keeles	doc_767882159228_item	2856066	et	4	main
suur	doc_767882159228_item	2856067	et	3	main
kannel	doc_767882159228_item	2856075	et	4	main
jt	doc_767882159228_item	2856078	et	4	main
välisriigide	doc_767882159228_item	2856079	et	4	main
nimetatakse	doc_767882159228_item	2856085	et	3	main
riimilised	doc_767882159228_item	2856088	et	4	main
pillisaatega	doc_767882159228_item	2856091	et	3	main
hakkasid	doc_767882159228_item	2856096	et	4	main
eestis	doc_767882159228_item	2856097	et	3	main
tegelema	doc_767882159228_item	2856098	et	3	main
esimesed	doc_767882159228_item	2856099	et	3	main
proffesionaalsed	doc_767882159228_item	2856100	et	4	main
muusikud	doc_767882159228_item	2856101	et	4	main
keda	doc_767882159228_item	2856102	et	4	main
nimetati	doc_767882159228_item	2856103	et	4	main
räntmuusikuks	doc_767882159228_item	2856104	et	4	main
neid	doc_767882159228_item	2856105	et	4	main
esindasid	doc_767882159228_item	2856106	et	4	main
pulmas	doc_767882159228_item	2856108	et	3	main
peol	doc_767882159228_item	2856107	et	4	main
kõige	doc_767882159228_item	2856109	et	4	main
suurt	doc_767882159228_item	2856110	et	3	main
rolli	doc_767882159228_item	2856111	et	4	main
eesti	doc_767882159228_item	2856112	et	4	main
ajaloos	doc_767882159228_item	2856113	et	4	main
mängis	doc_767882159228_item	2856114	et	3	main
esimene	doc_767882159228_item	2856115	et	3	main
laulupidu	doc_767882159228_item	2856116	et	4	main
mis	doc_767882159228_item	2856117	et	4	main
toimus	doc_767882159228_item	2856118	et	3	main
tartus	doc_767882159228_item	2856119	et	3	main
ja	doc_767882159228_item	2856120	et	3	main
j	doc_767882159228_item	2856123	et	4	main
jansen	doc_767882159228_item	2856125	et	4	main
sellel	doc_767882159228_item	2856126	et	4	main
eesti	doc_767882159228_item	2856129	et	4	main
saanud	doc_767882159228_item	2856145	et	4	main
laulda	doc_767882159228_item	2856146	et	4	main
sajandi	doc_767882159228_item	2856153	et	3	main
eestis	doc_767882159228_item	2856157	et	3	main
estonia	doc_767882159228_item	2856175	et	4	main
tänapäevani	doc_767882159228_item	2856176	et	3	main
tegutsevad	doc_767882159228_item	2856177	et	4	main
eestis	doc_767882159228_item	2856178	et	3	main
teater	doc_767882159228_item	2856179	et	3	main
vanemuine	doc_767882159228_item	2856180	et	4	main
ja	doc_767882159228_item	2856181	et	3	main
estonia	doc_767882159228_item	2856182	et	4	main
kus	doc_767882159228_item	2856183	et	3	main
oli	doc_767882159228_item	2856031	et	3	main
seda	doc_767882159228_item	2856033	et	3	main
laulasid	doc_767882159228_item	2856034	et	4	main
esineja	doc_767882159228_item	2856035	et	4	main
ja	doc_767882159228_item	2856036	et	3	main
koor	doc_767882159228_item	2856037	et	4	main
põlve	doc_767882159228_item	2856053	et	4	main
teise	doc_767882159228_item	2856054	et	4	main
oli	doc_767882159228_item	2856056	et	3	main
kirikulaul	doc_767882159228_item	2856062	et	4	main
lauldi	doc_767882159228_item	2856063	et	3	main
kirikus	doc_767882159228_item	2856064	et	3	main
flööd	doc_767882159228_item	2856077	et	4	main
riimilise	doc_767882159228_item	2856086	et	4	main
peol	doc_767882159228_item	2856127	et	4	main
rahva	doc_767882159228_item	2856132	et	3	main
ühtsust	doc_767882159228_item	2856133	et	4	main
hakkati	doc_767882159228_item	2856135	et	3	main
ei	doc_767882159228_item	2856144	et	4	main
tahtsid	doc_767882159228_item	2856151	et	4	main
keskel	doc_767882159228_item	2856154	et	3	main
heliloojad	doc_767882159228_item	2856159	et	3	main
leningradis	doc_767882159228_item	2856165	et	4	main
esimene	doc_767882159228_item	2856166	et	3	main
eesti	doc_767882159228_item	2856167	et	4	main
avatud	doc_767882159228_item	2856170	et	4	main
tartus	doc_767882159228_item	2856171	et	3	main
vanemuine	doc_767882159228_item	2856172	et	4	main
teine	doc_767882159228_item	2856173	et	3	main
ka	doc_767882159228_item	2856188	et	3	main
välisriigide	doc_767882159228_item	2856189	et	4	main
esindajad	doc_767882159228_item	2856190	et	4	main
igal	doc_767882159228_item	2856191	et	3	main
suvel	doc_767882159228_item	2856192	et	3	main
viljandis	doc_767882159228_item	2856193	et	4	main
toimub	doc_767882159228_item	2856194	et	3	main
folkloorifestival	doc_767882159228_item	2856195	et	3	main
igal	doc_767882159228_item	2856196	et	3	main
aastal	doc_767882159228_item	2856197	et	3	main
selle	doc_767882159228_item	2856198	et	4	main
festivali	doc_767882159228_item	2856199	et	4	main
temaatika	doc_767882159228_item	2856200	et	4	main
muutub	doc_767882159228_item	2856201	et	3	main
kord	doc_767882159228_item	2856202	et	4	main
4	doc_767882159228_item	2856203	et	2	main
aastas	doc_767882159228_item	2856204	et	3	main
toimub	doc_767882159228_item	2856205	et	3	main
tallinnas	doc_767882159228_item	2856206	et	4	main
laulupidu	doc_767882159228_item	2856207	et	4	main
kõige	doc_767882159228_item	2856208	et	4	main
selle	doc_767882159228_item	2856209	et	4	main
fakti	doc_767882159228_item	2856210	et	4	main
järgi	doc_767882159228_item	2856211	et	4	main
ma	doc_767882159228_item	2856212	et	3	main
võiks	doc_767882159228_item	2856213	et	4	main
väidendada	doc_767882159228_item	2856214	et	4	main
et	doc_767882159228_item	2856215	et	3	main
eesti	doc_767882159228_item	2856216	et	4	main
rahvas	doc_767882159228_item	2856217	et	4	main
on	doc_767882159228_item	2856218	et	4	main
laulurahvas	doc_767882159228_item	2856219	et	4	main
teise	doc_767882159230_item	2856487	et	4	main
teeb	doc_767882159230_item	2856495	et	3	main
peab	doc_767882159230_item	2856504	et	4	main
illustreerida	doc_767882159230_item	2856519	et	3	main
eestlastest	doc_767882159230_item	2856523	et	4	main
rahval	doc_767882159230_item	2856526	et	3	main
oma	doc_767882159230_item	2856528	et	4	main
laulurahvaks	doc_767882159230_item	2856539	et	3	main
selleks	doc_767882159230_item	2856543	et	4	main
põhjusi	doc_767882159230_item	2856545	et	3	main
tähelepanu	doc_767882159230_item	2856549	et	4	main
pöörata	doc_767882159230_item	2856550	et	4	main
ja	doc_767882159230_item	2856555	et	3	main
eesti	doc_767882159230_item	2856575	et	4	main
rahvas	doc_767882159230_item	2856576	et	4	main
laulmine	doc_767882159230_item	2856580	et	4	main
nii	doc_767882159230_item	2856582	et	3	main
populaarne	doc_767882159230_item	2856583	et	3	main
ka	doc_767882159230_item	2856584	et	3	main
tänapäeval	doc_767882159230_item	2856585	et	3	main
mitte	doc_767882159230_item	2856591	et	3	main
ja	doc_767882159230_item	2856594	et	3	main
traditsioonid	doc_767882159230_item	2856604	et	3	main
saartel	doc_767882159230_item	2856607	et	3	main
jne	doc_767882159230_item	2856611	et	4	main
settumaal	doc_767882159230_item	2856613	et	4	main
kõigepealt	doc_767882159230_item	2856638	et	3	main
tegelikult	doc_767882159230_item	2856642	et	4	main
seda	doc_767882159230_item	2856647	et	3	main
tekib	doc_767882159230_item	2856651	et	3	main
kujunenud	doc_767882159230_item	2856666	et	4	main
rahvuslikeks	doc_767882159230_item	2856667	et	3	main
sümboliteks	doc_767882159230_item	2856668	et	3	main
sest	doc_767882159230_item	2856681	et	4	main
nad	doc_767882159230_item	2856682	et	3	main
essee	doc_767882159230_item	2856492	et	4	main
teemal	doc_767882159230_item	2856493	et	3	main
mis	doc_767882159230_item	2856494	et	4	main
essee	doc_767882159230_item	2856498	et	4	main
sõna	doc_767882159230_item	2856502	et	4	main
essee	doc_767882159230_item	2856503	et	4	main
arutlev	doc_767882159230_item	2856506	et	4	main
on	doc_767882159230_item	2856517	et	4	main
näidetega	doc_767882159230_item	2856520	et	3	main
igal	doc_767882159230_item	2856525	et	3	main
on	doc_767882159230_item	2856527	et	4	main
mis	doc_767882159230_item	2856532	et	4	main
puutub	doc_767882159230_item	2856533	et	3	main
eestlastesse	doc_767882159230_item	2856534	et	4	main
siis	doc_767882159230_item	2856535	et	3	main
mul	doc_767882159230_item	2856541	et	3	main
palju	doc_767882159230_item	2856544	et	4	main
kõigepealt	doc_767882159230_item	2856546	et	3	main
tantsis	doc_767882159230_item	2856554	et	4	main
oli	doc_767882159230_item	2856589	et	3	main
tallinnas	doc_767882159230_item	2856593	et	4	main
eestis	doc_767882159230_item	2856600	et	3	main
huvitavad	doc_767882159230_item	2856602	et	4	main
eestlastest	doc_767882159230_item	2856614	et	4	main
teeb	doc_767882159230_item	2856615	et	3	main
laulurahva	doc_767882159230_item	2856616	et	3	main
ka	doc_767882159230_item	2856617	et	3	main
seda	doc_767882159230_item	2856618	et	3	main
et	doc_767882159230_item	2856619	et	3	main
laulupidu	doc_767882159230_item	2856620	et	4	main
eesti	doc_767882159230_item	2856484	et	4	main
keele	doc_767882159230_item	2856485	et	4	main
kui	doc_767882159230_item	2856486	et	3	main
pikkus	doc_767882159230_item	2856499	et	4	main
300	doc_767882159230_item	2856500	et	2	main
350	doc_767882159230_item	2856501	et	2	main
olema	doc_767882159230_item	2856505	et	4	main
üldistav	doc_767882159230_item	2856509	et	4	main
loengus	doc_767882159230_item	2856511	et	3	main
ja	doc_767882159230_item	2856512	et	3	main
lugemistekstis	doc_767882159230_item	2856513	et	3	main
esitatud	doc_767882159230_item	2856514	et	4	main
faktidele	doc_767882159230_item	2856515	et	3	main
soovitatav	doc_767882159230_item	2856518	et	4	main
essee	doc_767882159230_item	2856483	et	4	main
kirjutamine	doc_767882159230_item	2856490	et	4	main
kirjutage	doc_767882159230_item	2856491	et	3	main
eestlastest	doc_767882159230_item	2856496	et	4	main
laulurahva	doc_767882159230_item	2856497	et	3	main
väiteid	doc_767882159230_item	2856516	et	4	main
mis	doc_767882159230_item	2856521	et	4	main
tegelikult	doc_767882159230_item	2856538	et	4	main
tuleb	doc_767882159230_item	2856547	et	3	main
laulis	doc_767882159230_item	2856553	et	4	main
mängis	doc_767882159230_item	2856556	et	3	main
tegi	doc_767882159230_item	2856571	et	4	main
eeldusi	doc_767882159230_item	2856573	et	4	main
tantsimine	doc_767882159230_item	2856588	et	4	main
ainult	doc_767882159230_item	2856592	et	4	main
tartus	doc_767882159230_item	2856595	et	3	main
mujal	doc_767882159230_item	2856599	et	3	main
väga	doc_767882159230_item	2856601	et	3	main
kihnu	doc_767882159230_item	2856609	et	4	main
rahvapidu	doc_767882159230_item	2856624	et	4	main
koos	doc_767882159230_item	2856627	et	4	main
perega	doc_767882159230_item	2856628	et	3	main
kus	doc_767882159230_item	2856629	et	3	main
kohata	doc_767882159230_item	2856630	et	4	main
sõpru	doc_767882159230_item	2856631	et	3	main
sugulasi	doc_767882159230_item	2856632	et	3	main
ja	doc_767882159230_item	2856633	et	3	main
tuttavaid	doc_767882159230_item	2856634	et	3	main
sõnu	doc_767882159230_item	2856656	et	4	main
viisi	doc_767882159230_item	2856659	et	4	main
eestlastel	doc_767882159230_item	2856675	et	4	main
muret	doc_767882159230_item	2856678	et	3	main
korraldamisega	doc_767882159230_item	2856680	et	4	main
palju	doc_767882159230_item	2856694	et	4	main
laule	doc_767882159230_item	2856696	et	4	main
see	doc_767882159230_item	2856699	et	3	main
osas	doc_767882159230_item	2856703	et	4	main
ka	doc_767882159230_item	2856705	et	3	main
minu	doc_767882159230_item	2856711	et	3	main
vormis	doc_767882159230_item	2856717	et	4	main
aga	doc_767882159230_item	2856722	et	3	main
kindel	doc_767882159230_item	2856725	et	3	main
muutub	doc_767882159230_item	2856734	et	3	main
essee	doc_767882159231_item	2856753	et	4	main
mis	doc_767882159231_item	2856755	et	4	main
sõna	doc_767882159231_item	2856763	et	4	main
arutlev	doc_767882159231_item	2856767	et	4	main
tuginema	doc_767882159231_item	2856771	et	3	main
lugemistekstis	doc_767882159231_item	2856774	et	3	main
laulmine	doc_767882159231_item	2856782	et	4	main
on	doc_767882159231_item	2856783	et	4	main
on	doc_767882159231_item	2856790	et	4	main
ümbrusest	doc_767882159231_item	2856821	et	4	main
sündmustest	doc_767882159231_item	2856825	et	4	main
eriline	doc_767882159231_item	2856827	et	4	main
on	doc_767882159231_item	2856835	et	4	main
ajaloolised	doc_767882159231_item	2856836	et	4	main
mis	doc_767882159231_item	2856838	et	4	main
tegid	doc_767882159231_item	2856839	et	4	main
eestlasi	doc_767882159231_item	2856848	et	3	main
ajalooliselt	doc_767882159231_item	2856860	et	4	main
rahulikult	doc_767882159231_item	2856866	et	4	main
maal	doc_767882159231_item	2856868	et	4	main
tegid	doc_767882159231_item	2856869	et	4	main
oma	doc_767882159231_item	2856873	et	4	main
lapsi	doc_767882159231_item	2856874	et	4	main
vaba	doc_767882159231_item	2856880	et	4	main
jooksul	doc_767882159231_item	2856885	et	4	main
heliloojad	doc_767882159231_item	2856887	et	3	main
rahvalaule	doc_767882159231_item	2856888	et	4	main
keele	doc_767882159230_item	2856488	et	4	main
test	doc_767882159230_item	2856489	et	3	main
analüüsiv	doc_767882159230_item	2856507	et	4	main
ja	doc_767882159230_item	2856508	et	3	main
tuginema	doc_767882159230_item	2856510	et	3	main
laulurahva	doc_767882159230_item	2856524	et	3	main
neid	doc_767882159230_item	2856536	et	4	main
võib	doc_767882159230_item	2856537	et	3	main
on	doc_767882159230_item	2856542	et	4	main
sest	doc_767882159230_item	2856551	et	4	main
eestlane	doc_767882159230_item	2856552	et	3	main
juba	doc_767882159230_item	2856558	et	3	main
ühendada	doc_767882159230_item	2856577	et	3	main
sellepärast	doc_767882159230_item	2856579	et	3	main
on	doc_767882159230_item	2856581	et	4	main
laulmine	doc_767882159230_item	2856586	et	4	main
ja	doc_767882159230_item	2856587	et	3	main
levinud	doc_767882159230_item	2856596	et	4	main
aga	doc_767882159230_item	2856597	et	3	main
ka	doc_767882159230_item	2856598	et	3	main
on	doc_767882159230_item	2856605	et	4	main
olemas	doc_767882159230_item	2856606	et	4	main
saarel	doc_767882159230_item	2856610	et	3	main
tullakse	doc_767882159230_item	2856626	et	3	main
publikule	doc_767882159230_item	2856637	et	3	main
ootab	doc_767882159230_item	2856640	et	3	main
kogedes	doc_767882159230_item	2856646	et	4	main
ja	doc_767882159230_item	2856657	et	3	main
läbi	doc_767882159230_item	2856664	et	4	main
sellest	doc_767882159230_item	2856673	et	4	main
olid	doc_767882159230_item	2856685	et	4	main
mitte	doc_767882159230_item	2856686	et	3	main
vabad	doc_767882159230_item	2856687	et	3	main
sest	doc_767882159230_item	2856698	et	4	main
oli	doc_767882159230_item	2856700	et	3	main
neid	doc_767882159230_item	2856708	et	4	main
segasid	doc_767882159230_item	2856709	et	4	main
tohi	doc_767882159230_item	2856714	et	4	main
nii	doc_767882159230_item	2856715	et	3	main
lühikises	doc_767882159230_item	2856716	et	3	main
öelda	doc_767882159230_item	2856721	et	4	main
eestlasi	doc_767882159230_item	2856727	et	3	main
täieliku	doc_767882159230_item	2856729	et	3	main
laulurahvaks	doc_767882159230_item	2856731	et	3	main
aga	doc_767882159230_item	2856735	et	3	main
essee	doc_767882159231_item	2856744	et	4	main
keele	doc_767882159231_item	2856746	et	4	main
pikkus	doc_767882159231_item	2856760	et	4	main
300	doc_767882159231_item	2856761	et	2	main
350	doc_767882159231_item	2856762	et	2	main
olema	doc_767882159231_item	2856766	et	4	main
soovitatav	doc_767882159231_item	2856779	et	4	main
illustreerida	doc_767882159231_item	2856780	et	3	main
näidetega	doc_767882159231_item	2856781	et	3	main
laul	doc_767882159231_item	2856789	et	4	main
teeb	doc_767882159230_item	2856522	et	3	main
traditsioonid	doc_767882159230_item	2856529	et	3	main
ja	doc_767882159230_item	2856530	et	3	main
kombed	doc_767882159230_item	2856531	et	3	main
nimetata	doc_767882159230_item	2856540	et	3	main
ajaloole	doc_767882159230_item	2856548	et	4	main
pilli	doc_767882159230_item	2856557	et	4	main
ammu	doc_767882159230_item	2856559	et	4	main
eestlased	doc_767882159230_item	2856560	et	3	main
laulsid	doc_767882159230_item	2856561	et	4	main
nii	doc_767882159230_item	2856562	et	3	main
töö	doc_767882159230_item	2856563	et	4	main
tehes	doc_767882159230_item	2856564	et	3	main
kui	doc_767882159230_item	2856565	et	3	main
ka	doc_767882159230_item	2856566	et	3	main
lastega	doc_767882159230_item	2856567	et	3	main
mängimas	doc_767882159230_item	2856568	et	3	main
esimene	doc_767882159230_item	2856569	et	3	main
üldlaulupidu	doc_767882159230_item	2856570	et	4	main
palju	doc_767882159230_item	2856572	et	4	main
et	doc_767882159230_item	2856574	et	3	main
just	doc_767882159230_item	2856578	et	3	main
ka	doc_767882159230_item	2856590	et	3	main
laulmise	doc_767882159230_item	2856603	et	4	main
saaremaal	doc_767882159230_item	2856608	et	4	main
ka	doc_767882159230_item	2856612	et	3	main
on	doc_767882159230_item	2856621	et	4	main
laulupidu	doc_767882159230_item	2856635	et	4	main
pealtvaataja-elamust	doc_767882159230_item	2856639	et	4	main
võimalus	doc_767882159230_item	2856643	et	3	main
tuhande	doc_767882159230_item	2856652	et	3	main
üheskoos	doc_767882159230_item	2856654	et	3	main
sama	doc_767882159230_item	2856655	et	4	main
sama	doc_767882159230_item	2856658	et	4	main
lauldes	doc_767882159230_item	2856660	et	3	main
need	doc_767882159230_item	2856661	et	3	main
laulud	doc_767882159230_item	2856662	et	3	main
on	doc_767882159230_item	2856663	et	4	main
ei	doc_767882159230_item	2856669	et	4	main
tohi	doc_767882159230_item	2856670	et	4	main
unustada	doc_767882159230_item	2856671	et	3	main
ka	doc_767882159230_item	2856672	et	3	main
oli	doc_767882159230_item	2856676	et	3	main
laulupidude	doc_767882159230_item	2856679	et	4	main
nsv	doc_767882159230_item	2856688	et	4	main
liidu	doc_767882159230_item	2856689	et	3	main
ajal	doc_767882159230_item	2856690	et	4	main
propagandistlikke	doc_767882159230_item	2856695	et	3	main
loomingut	doc_767882159230_item	2856710	et	3	main
ma	doc_767882159230_item	2856723	et	3	main
et	doc_767882159230_item	2856726	et	3	main
tänapäeval	doc_767882159230_item	2856743	et	3	main
teemal	doc_767882159231_item	2856754	et	3	main
teeb	doc_767882159231_item	2856756	et	3	main
eestlastest	doc_767882159231_item	2856757	et	4	main
laulurahva	doc_767882159231_item	2856758	et	3	main
essee	doc_767882159231_item	2856759	et	4	main
essee	doc_767882159231_item	2856764	et	4	main
ja	doc_767882159231_item	2856769	et	3	main
üldistav	doc_767882159231_item	2856770	et	4	main
loengus	doc_767882159231_item	2856772	et	3	main
esitatud	doc_767882159231_item	2856775	et	4	main
faktidele	doc_767882159231_item	2856776	et	3	main
väiteid	doc_767882159231_item	2856777	et	4	main
iga	doc_767882159231_item	2856784	et	4	main
ja	doc_767882159231_item	2856824	et	3	main
suhtuvad	doc_767882159231_item	2856832	et	4	main
põhjuseks	doc_767882159231_item	2856834	et	3	main
rahvast	doc_767882159231_item	2856842	et	4	main
viimane	doc_767882159231_item	2856849	et	3	main
on	doc_767882159231_item	2856852	et	4	main
eesti	doc_767882159231_item	2856858	et	4	main
taasiseseisvumiseni	doc_767882159231_item	2856859	et	3	main
elasid	doc_767882159231_item	2856865	et	4	main
kasvatasid	doc_767882159231_item	2856872	et	4	main
laule	doc_767882159231_item	2856877	et	4	main
eestis	doc_767882159231_item	2856893	et	3	main
on	doc_767882159231_item	2856894	et	4	main
tuntud	doc_767882159231_item	2856902	et	4	main
välismaal	doc_767882159231_item	2856903	et	4	main
kaasa	doc_767882159231_item	2856919	et	4	main
ka	doc_767882159230_item	2856622	et	3	main
suur	doc_767882159230_item	2856623	et	3	main
kuhu	doc_767882159230_item	2856625	et	3	main
pakub	doc_767882159230_item	2856636	et	3	main
kuulajaskond	doc_767882159230_item	2856641	et	3	main
kaasa	doc_767882159230_item	2856644	et	4	main
laulda	doc_767882159230_item	2856645	et	4	main
ülendavat	doc_767882159230_item	2856648	et	4	main
tunnet	doc_767882159230_item	2856649	et	3	main
mis	doc_767882159230_item	2856650	et	4	main
teistega	doc_767882159230_item	2856653	et	4	main
aja	doc_767882159230_item	2856665	et	4	main
et	doc_767882159230_item	2856674	et	3	main
palju	doc_767882159230_item	2856677	et	4	main
pidid	doc_767882159230_item	2856691	et	4	main
eestlased	doc_767882159230_item	2856692	et	3	main
kohustuslik	doc_767882159230_item	2856701	et	3	main
piirangud	doc_767882159230_item	2856707	et	3	main
palju	doc_767882159230_item	2856718	et	4	main
esitatud	doc_767882159230_item	2856719	et	4	main
küsimusest	doc_767882159230_item	2856720	et	4	main
väga	doc_767882159230_item	2856683	et	3	main
tihti	doc_767882159230_item	2856684	et	3	main
väga	doc_767882159230_item	2856693	et	3	main
laulma	doc_767882159230_item	2856697	et	3	main
repertuuari	doc_767882159230_item	2856702	et	4	main
olid	doc_767882159230_item	2856704	et	4	main
mitmesugused	doc_767882159230_item	2856706	et	3	main
arvates	doc_767882159230_item	2856712	et	4	main
ei	doc_767882159230_item	2856713	et	4	main
on	doc_767882159230_item	2856740	et	4	main
kirjutamine	doc_767882159231_item	2856751	et	4	main
kirjutage	doc_767882159231_item	2856752	et	3	main
peab	doc_767882159231_item	2856765	et	4	main
on	doc_767882159231_item	2856778	et	4	main
inimese	doc_767882159231_item	2856785	et	4	main
ja	doc_767882159231_item	2856786	et	3	main
rahvuse	doc_767882159231_item	2856787	et	3	main
väljendusvahend	doc_767882159231_item	2856788	et	3	main
ilmast	doc_767882159231_item	2856823	et	4	main
rahvalauludesse	doc_767882159231_item	2856833	et	3	main
eestlastest	doc_767882159231_item	2856840	et	4	main
balti	doc_767882159231_item	2856853	et	3	main
mis	doc_767882159231_item	2856855	et	4	main
toimus	doc_767882159231_item	2856856	et	3	main
enne	doc_767882159231_item	2856857	et	4	main
kes	doc_767882159231_item	2856864	et	4	main
oma	doc_767882159231_item	2856867	et	4	main
ja	doc_767882159231_item	2856878	et	3	main
olid	doc_767882159231_item	2856879	et	4	main
ärkamisaja	doc_767882159231_item	2856884	et	3	main
pöördusid	doc_767882159231_item	2856886	et	4	main
ka	doc_767882159231_item	2856901	et	3	main
rahvapidu	doc_767882159231_item	2856914	et	4	main
kuhu	doc_767882159231_item	2856915	et	3	main
saab	doc_767882159231_item	2856916	et	3	main
tulla	doc_767882159231_item	2856917	et	3	main
ja	doc_767882159231_item	2856918	et	3	main
ennast	doc_767882159231_item	2856922	et	4	main
üldsõnaga	doc_767882159231_item	2856929	et	3	main
armastus	doc_767882159231_item	2856938	et	4	main
keele	doc_767882159232_item	2856948	et	4	main
kui	doc_767882159232_item	2856949	et	3	main
essee	doc_767882159232_item	2856961	et	4	main
olema	doc_767882159232_item	2856968	et	4	main
üldistav	doc_767882159232_item	2856972	et	4	main
tuginema	doc_767882159232_item	2856973	et	3	main
loengus	doc_767882159232_item	2856974	et	3	main
ja	doc_767882159232_item	2856975	et	3	main
väiteid	doc_767882159232_item	2856979	et	4	main
rahval	doc_767882159232_item	2856985	et	3	main
mida	doc_767882159232_item	2856993	et	4	main
nendele	doc_767882159232_item	2856998	et	4	main
kultuurile	doc_767882159232_item	2856999	et	3	main
laulmine	doc_767882159232_item	2857000	et	4	main
ja	doc_767882159232_item	2857017	et	3	main
millest	doc_767882159232_item	2857018	et	3	main
ei	doc_767882159232_item	2857019	et	4	main
unustada	doc_767882159232_item	2857021	et	3	main
vanal	doc_767882159232_item	2857034	et	3	main
inimesed	doc_767882159232_item	2857044	et	3	main
laulsid	doc_767882159232_item	2857045	et	4	main
esitavad	doc_767882159232_item	2857055	et	4	main
laulu	doc_767882159232_item	2857064	et	4	main
neid	doc_767882159232_item	2857074	et	4	main
laulasid	doc_767882159232_item	2857098	et	4	main
setu	doc_767882159232_item	2857099	et	4	main
te	doc_767882159232_item	2857100	et	4	main
1869	doc_767882159232_item	2857107	et	2	main
toimunud	doc_767882159232_item	2857111	et	4	main
praegu	doc_767882159232_item	2857114	et	3	main
kultuurist	doc_767882159232_item	2857136	et	3	main
teada	doc_767882159232_item	2857151	et	3	main
oma	doc_767882159232_item	2857152	et	4	main
kes	doc_767882159232_item	2857183	et	4	main
see	doc_767882159232_item	2857191	et	3	main
kes	doc_767882159232_item	2857195	et	4	main
veel	doc_767882159232_item	2857208	et	4	main
arvan	doc_767882159232_item	2857210	et	3	main
saanud	doc_767882159232_item	2857223	et	4	main
on	doc_767882159232_item	2857226	et	4	main
ka	doc_767882159232_item	2857229	et	3	main
kõik	doc_767882159232_item	2857231	et	4	main
olen	doc_767882159230_item	2856724	et	3	main
võib	doc_767882159230_item	2856728	et	3	main
kindlusega	doc_767882159230_item	2856730	et	4	main
nimetada	doc_767882159230_item	2856732	et	3	main
aeg	doc_767882159230_item	2856733	et	3	main
laulmise	doc_767882159230_item	2856736	et	4	main
traditsioonid	doc_767882159230_item	2856737	et	3	main
ja	doc_767882159230_item	2856738	et	3	main
kombed	doc_767882159230_item	2856739	et	3	main
olemas	doc_767882159230_item	2856741	et	4	main
ka	doc_767882159230_item	2856742	et	3	main
eesti	doc_767882159231_item	2856745	et	4	main
kui	doc_767882159231_item	2856747	et	3	main
teise	doc_767882159231_item	2856748	et	4	main
keele	doc_767882159231_item	2856749	et	4	main
test	doc_767882159231_item	2856750	et	3	main
analüüsiv	doc_767882159231_item	2856768	et	4	main
ja	doc_767882159231_item	2856773	et	3	main
ka	doc_767882159231_item	2856791	et	3	main
üks	doc_767882159231_item	2856792	et	3	main
kultuuri	doc_767882159231_item	2856793	et	4	main
sümbolitest	doc_767882159231_item	2856794	et	4	main
rahvalaule	doc_767882159231_item	2856795	et	4	main
kaudu	doc_767882159231_item	2856796	et	3	main
saab	doc_767882159231_item	2856797	et	3	main
saada	doc_767882159231_item	2856798	et	4	main
palju	doc_767882159231_item	2856799	et	4	main
informatsiooni	doc_767882159231_item	2856800	et	4	main
rahvuse	doc_767882159231_item	2856801	et	3	main
kultuuri	doc_767882159231_item	2856802	et	4	main
ja	doc_767882159231_item	2856803	et	3	main
ajaloo	doc_767882159231_item	2856804	et	4	main
traditsioonidest	doc_767882159231_item	2856805	et	3	main
ma	doc_767882159231_item	2856806	et	3	main
ei	doc_767882159231_item	2856807	et	4	main
ütleks	doc_767882159231_item	2856808	et	3	main
et	doc_767882159231_item	2856809	et	3	main
eesti	doc_767882159231_item	2856810	et	4	main
rahvalaul	doc_767882159231_item	2856811	et	4	main
erineb	doc_767882159231_item	2856812	et	3	main
palju	doc_767882159231_item	2856813	et	4	main
teiste	doc_767882159231_item	2856814	et	4	main
rahvaste	doc_767882159231_item	2856815	et	4	main
rahvalaulust	doc_767882159231_item	2856816	et	4	main
lauldi	doc_767882159231_item	2856817	et	3	main
ju	doc_767882159231_item	2856818	et	3	main
samadest	doc_767882159231_item	2856819	et	3	main
asjadest	doc_767882159231_item	2856820	et	3	main
sündmused	doc_767882159231_item	2856837	et	3	main
laul	doc_767882159231_item	2856844	et	4	main
rahvalaul	doc_767882159231_item	2856845	et	4	main
just	doc_767882159231_item	2856843	et	3	main
tunnetest	doc_767882159231_item	2856822	et	3	main
jne	doc_767882159231_item	2856826	et	4	main
on	doc_767882159231_item	2856828	et	4	main
see	doc_767882159231_item	2856829	et	3	main
kuidas	doc_767882159231_item	2856830	et	3	main
eestlased	doc_767882159231_item	2856831	et	3	main
ühtlast	doc_767882159231_item	2856841	et	4	main
kõiki	doc_767882159231_item	2856847	et	4	main
näide	doc_767882159231_item	2856851	et	3	main
kett	doc_767882159231_item	2856854	et	4	main
on	doc_767882159231_item	2856861	et	4	main
eestlased	doc_767882159231_item	2856862	et	3	main
maainimesed	doc_767882159231_item	2856863	et	3	main
laulsid	doc_767882159231_item	2856875	et	4	main
rahvas	doc_767882159231_item	2856881	et	4	main
just	doc_767882159231_item	2856882	et	3	main
laulupidu	doc_767882159231_item	2856895	et	4	main
suurematest	doc_767882159231_item	2856897	et	4	main
sündmustest	doc_767882159231_item	2856898	et	4	main
et	doc_767882159231_item	2856906	et	3	main
on	doc_767882159231_item	2856908	et	4	main
mingi	doc_767882159231_item	2856910	et	4	main
laulda	doc_767882159231_item	2856920	et	4	main
tunnes	doc_767882159231_item	2856921	et	3	main
koos	doc_767882159231_item	2856928	et	4	main
tahe	doc_767882159231_item	2856943	et	4	main
olla	doc_767882159231_item	2856945	et	3	main
keele	doc_767882159232_item	2856951	et	4	main
kirjutage	doc_767882159232_item	2856954	et	3	main
teemal	doc_767882159232_item	2856956	et	3	main
arutlev	doc_767882159232_item	2856969	et	4	main
ja	doc_767882159232_item	2856971	et	3	main
lugemistekstis	doc_767882159232_item	2856976	et	3	main
soovitatav	doc_767882159232_item	2856981	et	4	main
igal	doc_767882159232_item	2856984	et	3	main
on	doc_767882159232_item	2856994	et	4	main
ajal	doc_767882159232_item	2857005	et	4	main
inimesed	doc_767882159232_item	2857006	et	3	main
laulasid	doc_767882159232_item	2857007	et	4	main
mida	doc_767882159232_item	2857013	et	4	main
vaja	doc_767882159232_item	2857015	et	4	main
hinnata	doc_767882159232_item	2857016	et	4	main
ajalugu	doc_767882159232_item	2857033	et	4	main
ajal	doc_767882159232_item	2857035	et	4	main
regivärseline	doc_767882159232_item	2857036	et	4	main
esindus	doc_767882159232_item	2857043	et	4	main
regilaulu	doc_767882159232_item	2857054	et	4	main
vaheldumisi	doc_767882159232_item	2857059	et	4	main
eeslaulja	doc_767882159232_item	2857060	et	4	main
edasi	doc_767882159232_item	2857065	et	3	main
regilauladel	doc_767882159232_item	2857069	et	3	main
oli	doc_767882159232_item	2857110	et	3	main
esimene	doc_767882159232_item	2857112	et	3	main
laulupidu	doc_767882159232_item	2857113	et	4	main
laulupeod	doc_767882159232_item	2857116	et	4	main
tuhand	doc_767882159232_item	2857122	et	4	main
inimesed	doc_767882159232_item	2857123	et	3	main
ja	doc_767882159232_item	2857137	et	3	main
teha	doc_767882159232_item	2857140	et	3	main
et	doc_767882159232_item	2857142	et	3	main
saavad	doc_767882159232_item	2857144	et	4	main
ajaloo	doc_767882159232_item	2857153	et	4	main
ja	doc_767882159232_item	2857154	et	3	main
sugulastega	doc_767882159232_item	2857178	et	4	main
teistes	doc_767882159232_item	2857185	et	4	main
riikides	doc_767882159232_item	2857186	et	3	main
vaadata	doc_767882159232_item	2857205	et	4	main
niisugune	doc_767882159232_item	2857211	et	3	main
mina	doc_767882159232_item	2857213	et	4	main
laulud	doc_767882159232_item	2857221	et	3	main
laulmine	doc_767882159232_item	2857225	et	4	main
eestis	doc_767882159232_item	2857228	et	3	main
laulda	doc_767882159232_item	2857246	et	4	main
tänapäeval	doc_767882159232_item	2857253	et	3	main
on	doc_767882159232_item	2857254	et	4	main
inimesed	doc_767882159232_item	2857261	et	3	main
mis	doc_767882159233_item	2857276	et	4	main
olema	doc_767882159233_item	2857287	et	4	main
eestlastest	doc_767882159233_item	2857305	et	4	main
laulurahva	doc_767882159233_item	2857306	et	3	main
ühendas	doc_767882159231_item	2856846	et	3	main
suur	doc_767882159231_item	2856850	et	3	main
oma	doc_767882159231_item	2856870	et	4	main
tööd	doc_767882159231_item	2856871	et	4	main
oma	doc_767882159231_item	2856876	et	4	main
sellepärast	doc_767882159231_item	2856883	et	3	main
poole	doc_767882159231_item	2856889	et	4	main
et	doc_767882159231_item	2856890	et	3	main
meenutada	doc_767882159231_item	2856891	et	3	main
praeguses	doc_767882159231_item	2856892	et	3	main
mis	doc_767882159231_item	2856899	et	4	main
praegu	doc_767882159231_item	2856909	et	3	main
poliitiline	doc_767882159231_item	2856911	et	3	main
motivatsioon	doc_767882159231_item	2856912	et	3	main
rohkem	doc_767882159231_item	2856913	et	4	main
mitte	doc_767882159231_item	2856923	et	3	main
tekkis	doc_767882159231_item	2856930	et	3	main
oma	doc_767882159231_item	2856939	et	4	main
maa	doc_767882159231_item	2856940	et	4	main
teise	doc_767882159232_item	2856950	et	4	main
mis	doc_767882159232_item	2856957	et	4	main
teeb	doc_767882159232_item	2856958	et	3	main
eestlastest	doc_767882159232_item	2856959	et	4	main
laulurahva	doc_767882159232_item	2856960	et	3	main
peab	doc_767882159232_item	2856967	et	4	main
analüüsiv	doc_767882159232_item	2856970	et	4	main
faktidele	doc_767882159232_item	2856978	et	3	main
on	doc_767882159232_item	2856980	et	4	main
illustreerida	doc_767882159232_item	2856982	et	3	main
näidetega	doc_767882159232_item	2856983	et	3	main
on	doc_767882159232_item	2856986	et	4	main
oma	doc_767882159232_item	2856987	et	4	main
kultuur	doc_767882159232_item	2856988	et	3	main
tehtud	doc_767882159232_item	2856995	et	4	main
on	doc_767882159232_item	2857001	et	4	main
sellest	doc_767882159232_item	2857008	et	4	main
teistel	doc_767882159232_item	2857024	et	4	main
ebatavaline	doc_767882159232_item	2857042	et	4	main
spontaalne	doc_767882159232_item	2857053	et	4	main
algab	doc_767882159232_item	2857061	et	3	main
kordab	doc_767882159232_item	2857067	et	3	main
tartus	doc_767882159232_item	2857109	et	3	main
kogunevad	doc_767882159232_item	2857121	et	4	main
nad	doc_767882159232_item	2857124	et	3	main
tantsivad	doc_767882159232_item	2857127	et	4	main
nad	doc_767882159232_item	2857128	et	3	main
oma	doc_767882159232_item	2857135	et	4	main
proovivad	doc_767882159232_item	2857139	et	4	main
nii	doc_767882159232_item	2857141	et	3	main
noored	doc_767882159232_item	2857143	et	3	main
aru	doc_767882159232_item	2857145	et	4	main
miks	doc_767882159232_item	2857146	et	4	main
see	doc_767882159232_item	2857147	et	3	main
mis	doc_767882159232_item	2857157	et	4	main
praegu	doc_767882159232_item	2857160	et	3	main
sõbradega	doc_767882159232_item	2857177	et	4	main
ja	doc_767882159232_item	2857179	et	3	main
lihtsalt	doc_767882159232_item	2857180	et	4	main
tuttavatega	doc_767882159232_item	2857181	et	3	main
inimesed	doc_767882159232_item	2857182	et	3	main
eestisse	doc_767882159232_item	2857188	et	4	main
et	doc_767882159232_item	2857189	et	3	main
näha	doc_767882159232_item	2857190	et	3	main
külastab	doc_767882159232_item	2857196	et	3	main
üritus	doc_767882159232_item	2857198	et	4	main
üks	doc_767882159232_item	2857199	et	3	main
kord	doc_767882159232_item	2857200	et	4	main
see	doc_767882159232_item	2857201	et	3	main
tahab	doc_767882159232_item	2857202	et	3	main
tulla	doc_767882159232_item	2857203	et	3	main
ja	doc_767882159232_item	2857204	et	3	main
korda	doc_767882159232_item	2857219	et	4	main
need	doc_767882159232_item	2857220	et	3	main
üks	doc_767882159231_item	2856896	et	3	main
on	doc_767882159231_item	2856900	et	4	main
ei	doc_767882159231_item	2856904	et	4	main
ütleks	doc_767882159231_item	2856905	et	3	main
selles	doc_767882159231_item	2856907	et	4	main
aga	doc_767882159231_item	2856925	et	3	main
tuhandete	doc_767882159231_item	2856926	et	3	main
laulurahvas	doc_767882159231_item	2856932	et	4	main
ajaloolised	doc_767882159231_item	2856935	et	4	main
faktorid	doc_767882159231_item	2856936	et	3	main
mentaliteet	doc_767882159231_item	2856937	et	3	main
ja	doc_767882159231_item	2856942	et	3	main
essee	doc_767882159232_item	2856946	et	4	main
eesti	doc_767882159232_item	2856947	et	4	main
test	doc_767882159232_item	2856952	et	3	main
essee	doc_767882159232_item	2856955	et	4	main
350	doc_767882159232_item	2856964	et	2	main
sõna	doc_767882159232_item	2856965	et	4	main
essee	doc_767882159232_item	2856966	et	4	main
esitatud	doc_767882159232_item	2856977	et	4	main
mäletavad	doc_767882159232_item	2856992	et	4	main
kultuurinähtus	doc_767882159232_item	2857002	et	4	main
mida	doc_767882159232_item	2857009	et	4	main
toimus	doc_767882159232_item	2857010	et	3	main
on	doc_767882159232_item	2857014	et	4	main
nagu	doc_767882159232_item	2857023	et	3	main
üksinda	doc_767882159231_item	2856924	et	4	main
teiste	doc_767882159231_item	2856927	et	4	main
eestlastest	doc_767882159231_item	2856931	et	4	main
mitmetel	doc_767882159231_item	2856933	et	4	main
põhjustel	doc_767882159231_item	2856934	et	3	main
vastu	doc_767882159231_item	2856941	et	3	main
tunnustatud	doc_767882159231_item	2856944	et	4	main
kirjutamine	doc_767882159232_item	2856953	et	4	main
pikkus	doc_767882159232_item	2856962	et	4	main
300	doc_767882159232_item	2856963	et	2	main
oma	doc_767882159232_item	2856989	et	4	main
traditsioonid	doc_767882159232_item	2856990	et	3	main
inimesed	doc_767882159232_item	2856991	et	3	main
nende	doc_767882159232_item	2856996	et	4	main
vanevanemad	doc_767882159232_item	2856997	et	4	main
sest	doc_767882159232_item	2857003	et	4	main
vanal	doc_767882159232_item	2857004	et	3	main
nende	doc_767882159232_item	2857011	et	4	main
ümber	doc_767882159232_item	2857012	et	3	main
saa	doc_767882159232_item	2857020	et	4	main
eestlastel	doc_767882159232_item	2857022	et	4	main
on	doc_767882159232_item	2857026	et	4	main
laulade	doc_767882159232_item	2857032	et	4	main
oli	doc_767882159232_item	2857039	et	3	main
suurepärane	doc_767882159232_item	2857040	et	4	main
ja	doc_767882159232_item	2857041	et	3	main
ja	doc_767882159232_item	2857048	et	3	main
tihti	doc_767882159232_item	2857049	et	3	main
see	doc_767882159232_item	2857050	et	3	main
laulmine	doc_767882159232_item	2857051	et	4	main
oli	doc_767882159232_item	2857052	et	3	main
koor	doc_767882159232_item	2857058	et	4	main
viib	doc_767882159232_item	2857063	et	3	main
koor	doc_767882159232_item	2857066	et	4	main
oli	doc_767882159232_item	2857070	et	3	main
rütm	doc_767882159232_item	2857072	et	3	main
ning	doc_767882159232_item	2857073	et	3	main
pärandati	doc_767882159232_item	2857075	et	4	main
võite	doc_767882159232_item	2857101	et	4	main
kuulata	doc_767882159232_item	2857102	et	4	main
tallinnas	doc_767882159232_item	2857119	et	4	main
kus	doc_767882159232_item	2857120	et	3	main
rahvastel	doc_767882159232_item	2857025	et	4	main
oma	doc_767882159232_item	2857027	et	4	main
kultuur	doc_767882159232_item	2857028	et	3	main
oma	doc_767882159232_item	2857029	et	4	main
laulud	doc_767882159232_item	2857030	et	3	main
ja	doc_767882159232_item	2857031	et	3	main
rahvalaul	doc_767882159232_item	2857037	et	4	main
see	doc_767882159232_item	2857038	et	3	main
ilma	doc_767882159232_item	2857046	et	4	main
muusikainstrumendita	doc_767882159232_item	2857047	et	3	main
eeslaulja	doc_767882159232_item	2857056	et	4	main
ja	doc_767882159232_item	2857057	et	3	main
siis	doc_767882159232_item	2857062	et	3	main
eeslaulja	doc_767882159232_item	2857068	et	4	main
oma	doc_767882159232_item	2857071	et	4	main
põlvest	doc_767882159232_item	2857076	et	4	main
põlve	doc_767882159232_item	2857077	et	4	main
tuginedes	doc_767882159232_item	2857079	et	3	main
mälule	doc_767882159232_item	2857080	et	3	main
ja	doc_767882159232_item	2857081	et	3	main
traditsioonidele	doc_767882159232_item	2857082	et	3	main
suuliselt	doc_767882159232_item	2857078	et	4	main
kalendris	doc_767882159232_item	2857083	et	3	main
olid	doc_767882159232_item	2857084	et	4	main
spetsiaalsed	doc_767882159232_item	2857085	et	3	main
päevad	doc_767882159232_item	2857086	et	3	main
millal	doc_767882159232_item	2857087	et	3	main
naised	doc_767882159232_item	2857088	et	3	main
laulasid	doc_767882159232_item	2857089	et	4	main
need	doc_767882159232_item	2857090	et	3	main
regilaulud	doc_767882159232_item	2857091	et	3	main
tänapäevani	doc_767882159232_item	2857092	et	3	main
inimesed	doc_767882159232_item	2857093	et	3	main
mäletavad	doc_767882159232_item	2857094	et	4	main
need	doc_767882159232_item	2857095	et	3	main
regilaulud	doc_767882159232_item	2857096	et	3	main
millised	doc_767882159232_item	2857097	et	3	main
neid	doc_767882159232_item	2857103	et	4	main
lõuna-eestis	doc_767882159232_item	2857104	et	3	main
ja	doc_767882159232_item	2857105	et	3	main
lääne-eestis	doc_767882159232_item	2857106	et	3	main
aastal	doc_767882159232_item	2857108	et	3	main
need	doc_767882159232_item	2857115	et	3	main
toimuvad	doc_767882159232_item	2857117	et	4	main
lauluväljakul	doc_767882159232_item	2857118	et	3	main
näitavad	doc_767882159232_item	2857129	et	4	main
meile	doc_767882159232_item	2857130	et	4	main
et	doc_767882159232_item	2857131	et	3	main
nad	doc_767882159232_item	2857132	et	3	main
ei	doc_767882159232_item	2857133	et	4	main
nad	doc_767882159232_item	2857138	et	3	main
tähtis	doc_767882159232_item	2857150	et	4	main
kõik	doc_767882159232_item	2857156	et	4	main
meie	doc_767882159232_item	2857158	et	4	main
elavad	doc_767882159232_item	2857184	et	4	main
esindus	doc_767882159232_item	2857192	et	4	main
veel	doc_767882159232_item	2857206	et	4	main
ja	doc_767882159232_item	2857207	et	3	main
sest	doc_767882159232_item	2857212	et	4	main
ise	doc_767882159232_item	2857214	et	4	main
olin	doc_767882159232_item	2857215	et	3	main
niisugusel	doc_767882159232_item	2857216	et	3	main
üritusel	doc_767882159232_item	2857217	et	4	main
kaks	doc_767882159232_item	2857218	et	3	main
muidugi	doc_767882159232_item	2857233	et	4	main
ka	doc_767882159232_item	2857234	et	3	main
need	doc_767882159232_item	2857235	et	3	main
lihtsalt	doc_767882159232_item	2857241	et	4	main
ainult	doc_767882159232_item	2857251	et	4	main
ürituseid	doc_767882159232_item	2857257	et	4	main
ja	doc_767882159232_item	2857258	et	3	main
kohte	doc_767882159232_item	2857259	et	3	main
laulavad	doc_767882159232_item	2857262	et	4	main
laule	doc_767882159232_item	2857264	et	4	main
essee	doc_767882159233_item	2857265	et	4	main
eesti	doc_767882159233_item	2857266	et	4	main
test	doc_767882159233_item	2857271	et	3	main
eestlastest	doc_767882159233_item	2857278	et	4	main
pikkus	doc_767882159233_item	2857281	et	4	main
350	doc_767882159233_item	2857283	et	2	main
sõna	doc_767882159233_item	2857284	et	4	main
arutlev	doc_767882159233_item	2857288	et	4	main
analüüsiv	doc_767882159233_item	2857289	et	4	main
ja	doc_767882159233_item	2857290	et	3	main
on	doc_767882159233_item	2857299	et	4	main
illustreerida	doc_767882159233_item	2857301	et	3	main
küsimus	doc_767882159233_item	2857310	et	4	main
see	doc_767882159233_item	2857321	et	3	main
laul	doc_767882159233_item	2857335	et	4	main
saatis	doc_767882159233_item	2857336	et	3	main
tulevik	doc_767882159233_item	2857346	et	3	main
enam	doc_767882159233_item	2857354	et	4	main
kui	doc_767882159233_item	2857355	et	3	main
ja	doc_767882159233_item	2857359	et	3	main
teavad	doc_767882159233_item	2857362	et	3	main
tegevus	doc_767882159233_item	2857373	et	4	main
ka	doc_767882159233_item	2857417	et	3	main
ajaloo	doc_767882159233_item	2857422	et	4	main
just	doc_767882159233_item	2857424	et	3	main
sellepärast	doc_767882159233_item	2857425	et	3	main
ongi	doc_767882159233_item	2857428	et	4	main
kõike	doc_767882159233_item	2857446	et	4	main
et	doc_767882159233_item	2857447	et	3	main
laulud	doc_767882159233_item	2857448	et	3	main
meid	doc_767882159233_item	2857456	et	4	main
elada	doc_767882159233_item	2857457	et	3	main
kasvada	doc_767882159233_item	2857458	et	4	main
siis	doc_767882159233_item	2857463	et	3	main
inimesed	doc_767882159233_item	2857464	et	3	main
sõbralikumaks	doc_767882159233_item	2857466	et	4	main
19	doc_767882159233_item	2857496	et	2	main
sajandi	doc_767882159233_item	2857497	et	3	main
et	doc_767882159233_item	2857505	et	3	main
eestlased	doc_767882159233_item	2857506	et	3	main
on	doc_767882159233_item	2857507	et	4	main
laulurahvas	doc_767882159233_item	2857508	et	4	main
kokkuvõteks	doc_767882159233_item	2857509	et	3	main
ja	doc_767882159233_item	2857548	et	3	main
laulavad	doc_767882159232_item	2857125	et	4	main
ja	doc_767882159232_item	2857126	et	3	main
unusta	doc_767882159232_item	2857134	et	4	main
on	doc_767882159232_item	2857148	et	4	main
väga	doc_767882159232_item	2857149	et	3	main
hindama	doc_767882159232_item	2857155	et	3	main
ümber	doc_767882159232_item	2857159	et	3	main
laulupidu	doc_767882159232_item	2857161	et	4	main
mitte	doc_767882159232_item	2857162	et	3	main
ainult	doc_767882159232_item	2857163	et	4	main
lihtsalt	doc_767882159232_item	2857164	et	4	main
pidu	doc_767882159232_item	2857165	et	4	main
kus	doc_767882159232_item	2857166	et	3	main
inimesed	doc_767882159232_item	2857167	et	3	main
laulavad	doc_767882159232_item	2857168	et	4	main
see	doc_767882159232_item	2857169	et	3	main
on	doc_767882159232_item	2857170	et	4	main
suur	doc_767882159232_item	2857171	et	3	main
rahvapidu	doc_767882159232_item	2857172	et	4	main
kuhu	doc_767882159232_item	2857173	et	3	main
tullakse	doc_767882159232_item	2857174	et	3	main
koos	doc_767882159232_item	2857175	et	4	main
perega	doc_767882159232_item	2857176	et	3	main
tulevad	doc_767882159232_item	2857187	et	4	main
oma	doc_767882159232_item	2857193	et	4	main
silmaga	doc_767882159232_item	2857194	et	3	main
seda	doc_767882159232_item	2857197	et	3	main
ma	doc_767882159232_item	2857209	et	3	main
on	doc_767882159232_item	2857222	et	4	main
sümboliks	doc_767882159232_item	2857224	et	4	main
populaarne	doc_767882159232_item	2857227	et	3	main
tänapäevani	doc_767882159232_item	2857230	et	3	main
ei	doc_767882159232_item	2857237	et	4	main
ole	doc_767882159232_item	2857238	et	4	main
muidugi	doc_767882159232_item	2857247	et	4	main
inimesed	doc_767882159232_item	2857248	et	3	main
palju	doc_767882159232_item	2857255	et	4	main
kirjutamine	doc_767882159233_item	2857272	et	4	main
kirjutage	doc_767882159233_item	2857273	et	3	main
essee	doc_767882159233_item	2857274	et	4	main
teemal	doc_767882159233_item	2857275	et	3	main
laulurahva	doc_767882159233_item	2857279	et	3	main
peab	doc_767882159233_item	2857286	et	4	main
soovitatav	doc_767882159233_item	2857300	et	4	main
mis	doc_767882159233_item	2857303	et	4	main
teeb	doc_767882159233_item	2857304	et	3	main
kellel	doc_767882159232_item	2857236	et	4	main
sest	doc_767882159232_item	2857242	et	4	main
et	doc_767882159232_item	2857243	et	3	main
hing	doc_767882159232_item	2857244	et	3	main
palub	doc_767882159232_item	2857245	et	3	main
laulupeol	doc_767882159232_item	2857252	et	4	main
kus	doc_767882159232_item	2857260	et	3	main
erinevaid	doc_767882159232_item	2857263	et	4	main
essee	doc_767882159233_item	2857285	et	4	main
üldistav	doc_767882159233_item	2857291	et	4	main
tuginema	doc_767882159233_item	2857292	et	3	main
loengus	doc_767882159233_item	2857293	et	3	main
ja	doc_767882159233_item	2857294	et	3	main
lugemistekstis	doc_767882159233_item	2857295	et	3	main
hea	doc_767882159233_item	2857309	et	4	main
kui	doc_767882159233_item	2857311	et	3	main
me	doc_767882159233_item	2857312	et	4	main
mõtleme	doc_767882159233_item	2857313	et	3	main
natukese	doc_767882159233_item	2857314	et	4	main
aja	doc_767882159233_item	2857315	et	4	main
siis	doc_767882159233_item	2857316	et	3	main
me	doc_767882159233_item	2857317	et	4	main
saame	doc_767882159233_item	2857318	et	4	main
aru	doc_767882159233_item	2857319	et	4	main
et	doc_767882159233_item	2857320	et	3	main
õige	doc_767882159233_item	2857324	et	4	main
see	doc_767882159233_item	2857327	et	3	main
on	doc_767882159233_item	2857331	et	4	main
laulurahvas	doc_767882159233_item	2857332	et	4	main
hällist	doc_767882159233_item	2857339	et	4	main
hauani	doc_767882159233_item	2857340	et	3	main
laulud	doc_767882159233_item	2857341	et	3	main
on	doc_767882159233_item	2857342	et	4	main
sellega	doc_767882159233_item	2857349	et	3	main
rahvalaul	doc_767882159233_item	2857351	et	4	main
tagasi	doc_767882159233_item	2857358	et	3	main
inimesi	doc_767882159233_item	2857376	et	4	main
last	doc_767882159233_item	2857409	et	4	main
rahvalauludes	doc_767882159233_item	2857411	et	3	main
minevik	doc_767882159233_item	2857414	et	3	main
rahvalauluga	doc_767882159233_item	2857418	et	4	main
pisut	doc_767882159233_item	2857420	et	3	main
uurimine	doc_767882159233_item	2857423	et	4	main
ma	doc_767882159233_item	2857430	et	3	main
on	doc_767882159233_item	2857434	et	4	main
kultuurinähtus	doc_767882159233_item	2857436	et	4	main
see	doc_767882159233_item	2857437	et	3	main
on	doc_767882159233_item	2857438	et	4	main
esteetiline	doc_767882159233_item	2857439	et	3	main
ja	doc_767882159233_item	2857440	et	3	main
emotsionaalne	doc_767882159233_item	2857441	et	3	main
väljendusvahend	doc_767882159233_item	2857442	et	3	main
laulude	doc_767882159233_item	2857443	et	3	main
autorid	doc_767882159233_item	2857444	et	3	main
teevad	doc_767882159233_item	2857445	et	3	main
aitavad	doc_767882159233_item	2857455	et	4	main
koorid	doc_767882159233_item	2857462	et	4	main
lõpupoole	doc_767882159233_item	2857498	et	4	main
see	doc_767882159233_item	2857499	et	3	main
on	doc_767882159233_item	2857500	et	4	main
erinevad	doc_767882159233_item	2857515	et	4	main
ja	doc_767882159233_item	2857516	et	3	main
seepärast	doc_767882159233_item	2857517	et	3	main
ei	doc_767882159233_item	2857518	et	4	main
ka	doc_767882159233_item	2857521	et	3	main
lähenemist	doc_767882159233_item	2857523	et	4	main
sellele	doc_767882159233_item	2857524	et	4	main
probleemile	doc_767882159233_item	2857525	et	3	main
endale	doc_767882159233_item	2857535	et	4	main
eesti	doc_767882159233_item	2857547	et	4	main
laulavad	doc_767882159232_item	2857232	et	4	main
ilus	doc_767882159232_item	2857239	et	4	main
hääl	doc_767882159232_item	2857240	et	3	main
laulavad	doc_767882159232_item	2857249	et	4	main
mitte	doc_767882159232_item	2857250	et	3	main
erinevaid	doc_767882159232_item	2857256	et	4	main
keele	doc_767882159233_item	2857267	et	4	main
kui	doc_767882159233_item	2857268	et	3	main
teise	doc_767882159233_item	2857269	et	4	main
keele	doc_767882159233_item	2857270	et	4	main
teeb	doc_767882159233_item	2857277	et	3	main
essee	doc_767882159233_item	2857280	et	4	main
300	doc_767882159233_item	2857282	et	2	main
esitatud	doc_767882159233_item	2857296	et	4	main
faktidele	doc_767882159233_item	2857297	et	3	main
väiteid	doc_767882159233_item	2857298	et	4	main
näidetega	doc_767882159233_item	2857302	et	3	main
on	doc_767882159233_item	2857323	et	4	main
läbi	doc_767882159233_item	2857333	et	4	main
aegade	doc_767882159233_item	2857334	et	3	main
ja	doc_767882159233_item	2857345	et	3	main
see	doc_767882159233_item	2857347	et	3	main
tuhat	doc_767882159233_item	2857356	et	4	main
aastat	doc_767882159233_item	2857357	et	3	main
ja	doc_767882159233_item	2857364	et	3	main
laulmine	doc_767882159233_item	2857370	et	4	main
on	doc_767882159233_item	2857371	et	4	main
sotsiaalne	doc_767882159233_item	2857372	et	3	main
lõbusam	doc_767882159233_item	2857377	et	4	main
kui	doc_767882159233_item	2857378	et	3	main
sa	doc_767882159233_item	2857379	et	3	main
rahva	doc_767882159233_item	2857413	et	3	main
mistõttu	doc_767882159233_item	2857415	et	3	main
tutvumine	doc_767882159233_item	2857419	et	4	main
see	doc_767882159233_item	2857307	et	3	main
on	doc_767882159233_item	2857308	et	4	main
väide	doc_767882159233_item	2857322	et	4	main
meie	doc_767882159233_item	2857337	et	4	main
rahvas	doc_767882159233_item	2857338	et	4	main
meie	doc_767882159233_item	2857343	et	4	main
kõik	doc_767882159233_item	2857360	et	4	main
laulavad	doc_767882159233_item	2857365	et	4	main
rahvalaulu	doc_767882159233_item	2857366	et	4	main
mis	doc_767882159233_item	2857374	et	4	main
teeb	doc_767882159233_item	2857375	et	3	main
ajal	doc_767882159233_item	2857406	et	4	main
olles	doc_767882159233_item	2857408	et	3	main
kiigutades	doc_767882159233_item	2857410	et	3	main
kajastub	doc_767882159233_item	2857412	et	3	main
on	doc_767882159233_item	2857416	et	4	main
et	doc_767882159233_item	2857432	et	3	main
olid	doc_767882159233_item	2857449	et	4	main
huvitavad	doc_767882159233_item	2857450	et	4	main
ilusad	doc_767882159233_item	2857451	et	3	main
ja	doc_767882159233_item	2857452	et	3	main
usuvärtuslikud	doc_767882159233_item	2857453	et	4	main
laulud	doc_767882159233_item	2857454	et	3	main
kui	doc_767882159233_item	2857460	et	3	main
eestlaste	doc_767882159233_item	2857493	et	4	main
rahvuslik	doc_767882159233_item	2857494	et	3	main
ilmumine	doc_767882159233_item	2857503	et	4	main
öelda	doc_767882159233_item	2857511	et	4	main
et	doc_767882159233_item	2857512	et	3	main
inimesed	doc_767882159233_item	2857513	et	3	main
olla	doc_767882159233_item	2857520	et	3	main
teile	doc_767882159233_item	2857533	et	4	main
ja	doc_767882159233_item	2857534	et	3	main
rahvas	doc_767882159233_item	2857541	et	4	main
eesti	doc_767882159235_item	2857826	et	4	main
keele	doc_767882159235_item	2857827	et	4	main
kui	doc_767882159235_item	2857828	et	3	main
essee	doc_767882159235_item	2857834	et	4	main
teemal	doc_767882159235_item	2857835	et	3	main
essee	doc_767882159235_item	2857840	et	4	main
tõepoolest	doc_767882159233_item	2857325	et	3	main
on	doc_767882159233_item	2857326	et	4	main
nii	doc_767882159233_item	2857328	et	3	main
et	doc_767882159233_item	2857329	et	3	main
eestlased	doc_767882159233_item	2857330	et	3	main
minevik	doc_767882159233_item	2857344	et	3	main
tõdeneb	doc_767882159233_item	2857348	et	4	main
et	doc_767882159233_item	2857350	et	3	main
on	doc_767882159233_item	2857352	et	4	main
kujunenud	doc_767882159233_item	2857353	et	4	main
eestlased	doc_767882159233_item	2857361	et	3	main
seda	doc_767882159233_item	2857363	et	3	main
siiamaani	doc_767882159233_item	2857367	et	3	main
minu	doc_767882159233_item	2857368	et	3	main
arvates	doc_767882159233_item	2857369	et	4	main
laulad	doc_767882159233_item	2857380	et	3	main
laulu	doc_767882159233_item	2857381	et	4	main
siis	doc_767882159233_item	2857382	et	3	main
sul	doc_767882159233_item	2857383	et	3	main
tekkib	doc_767882159233_item	2857384	et	3	main
siuke	doc_767882159233_item	2857385	et	4	main
tunne	doc_767882159233_item	2857386	et	4	main
et	doc_767882159233_item	2857387	et	3	main
oled	doc_767882159233_item	2857388	et	3	main
vaba	doc_767882159233_item	2857389	et	4	main
inimene	doc_767882159233_item	2857390	et	3	main
mis	doc_767882159233_item	2857391	et	4	main
on	doc_767882159233_item	2857392	et	4	main
väga	doc_767882159233_item	2857393	et	3	main
tähtis	doc_767882159233_item	2857394	et	4	main
meie	doc_767882159233_item	2857395	et	4	main
elus	doc_767882159233_item	2857397	et	4	main
võime	doc_767882159233_item	2857398	et	4	main
raskes	doc_767882159233_item	2857396	et	3	main
laulda	doc_767882159233_item	2857399	et	4	main
töötades	doc_767882159233_item	2857400	et	3	main
lõbutsedes	doc_767882159233_item	2857401	et	3	main
nagu	doc_767882159233_item	2857402	et	3	main
see	doc_767882159233_item	2857403	et	3	main
oli	doc_767882159233_item	2857404	et	3	main
vanal	doc_767882159233_item	2857405	et	3	main
lauldi	doc_767882159233_item	2857407	et	3	main
nagu	doc_767882159233_item	2857421	et	3	main
rahvas	doc_767882159233_item	2857427	et	4	main
laulurahvas	doc_767882159233_item	2857429	et	4	main
laulmine	doc_767882159233_item	2857433	et	4	main
tähelepanuväärne	doc_767882159233_item	2857435	et	3	main
moraalselt	doc_767882159233_item	2857459	et	4	main
ärkamine	doc_767882159233_item	2857495	et	4	main
sellest	doc_767882159233_item	2857504	et	4	main
on	doc_767882159233_item	2857514	et	4	main
eesti	doc_767882159233_item	2857426	et	4	main
arvan	doc_767882159233_item	2857431	et	3	main
tekkisid	doc_767882159233_item	2857461	et	4	main
said	doc_767882159233_item	2857465	et	4	main
nad	doc_767882159233_item	2857467	et	3	main
musitseerisid	doc_767882159233_item	2857468	et	4	main
piduõhtutel	doc_767882159233_item	2857469	et	3	main
ka	doc_767882159233_item	2857470	et	3	main
tantsusaateks	doc_767882159233_item	2857471	et	3	main
mängisid	doc_767882159233_item	2857472	et	4	main
ja	doc_767882159233_item	2857473	et	3	main
laulsid	doc_767882159233_item	2857474	et	4	main
elavad	doc_767882159233_item	2857475	et	4	main
musikat	doc_767882159233_item	2857476	et	4	main
elav	doc_767882159233_item	2857477	et	4	main
muusika	doc_767882159233_item	2857478	et	4	main
on	doc_767882159233_item	2857479	et	4	main
unustamatu	doc_767882159233_item	2857480	et	4	main
asi	doc_767882159233_item	2857481	et	4	main
on	doc_767882159233_item	2857482	et	4	main
vahva	doc_767882159233_item	2857483	et	4	main
kuulata	doc_767882159233_item	2857484	et	4	main
seda	doc_767882159233_item	2857485	et	3	main
muusika-	doc_767882159233_item	2857486	et	4	main
lauluharrastusega	doc_767882159233_item	2857488	et	3	main
ja	doc_767882159233_item	2857487	et	3	main
on	doc_767882159233_item	2857489	et	4	main
seotud	doc_767882159233_item	2857490	et	4	main
ka	doc_767882159233_item	2857492	et	3	main
tihedalt	doc_767882159233_item	2857491	et	4	main
veel	doc_767882159233_item	2857501	et	4	main
üks	doc_767882159233_item	2857502	et	3	main
võiks	doc_767882159233_item	2857510	et	4	main
saa	doc_767882159233_item	2857519	et	4	main
ikkagi	doc_767882159233_item	2857537	et	4	main
ja	doc_767882159233_item	2857539	et	3	main
maailma	doc_767882159233_item	2857549	et	4	main
ajalugu	doc_767882159233_item	2857550	et	4	main
teise	doc_767882159235_item	2857829	et	4	main
eestlastest	doc_767882159235_item	2857838	et	4	main
300	doc_767882159235_item	2857842	et	2	main
essee	doc_767882159235_item	2857845	et	4	main
olema	doc_767882159235_item	2857847	et	4	main
ja	doc_767882159235_item	2857854	et	3	main
faktidele	doc_767882159235_item	2857857	et	3	main
oli	doc_767882159235_item	2857865	et	3	main
väga	doc_767882159235_item	2857867	et	3	main
nende	doc_767882159235_item	2857869	et	4	main
muusikakultuur	doc_767882159235_item	2857870	et	3	main
nii	doc_767882159235_item	2857876	et	3	main
laulsid	doc_767882159235_item	2857883	et	4	main
ühest	doc_767882159233_item	2857522	et	4	main
aga	doc_767882159233_item	2857526	et	3	main
mina	doc_767882159233_item	2857527	et	4	main
arvan	doc_767882159233_item	2857528	et	3	main
et	doc_767882159233_item	2857529	et	3	main
ma	doc_767882159233_item	2857530	et	3	main
tegin	doc_767882159233_item	2857531	et	3	main
kindlaks	doc_767882159233_item	2857532	et	3	main
et	doc_767882159233_item	2857536	et	3	main
eestlased	doc_767882159233_item	2857538	et	3	main
eesti	doc_767882159233_item	2857540	et	4	main
on	doc_767882159233_item	2857542	et	4	main
tõepoolest	doc_767882159233_item	2857543	et	3	main
laulurahvas	doc_767882159233_item	2857544	et	4	main
see	doc_767882159233_item	2857545	et	3	main
kinnitab	doc_767882159233_item	2857546	et	3	main
test	doc_767882159235_item	2857831	et	3	main
mis	doc_767882159235_item	2857836	et	4	main
teeb	doc_767882159235_item	2857837	et	3	main
arutlev	doc_767882159235_item	2857848	et	4	main
analüüsiv	doc_767882159235_item	2857849	et	4	main
ja	doc_767882159235_item	2857850	et	3	main
lugemistekstis	doc_767882159235_item	2857855	et	3	main
on	doc_767882159235_item	2857859	et	4	main
soovitatav	doc_767882159235_item	2857860	et	4	main
illustreerida	doc_767882159235_item	2857861	et	3	main
rikkas	doc_767882159235_item	2857873	et	4	main
eestlased	doc_767882159235_item	2857874	et	3	main
pidudel	doc_767882159235_item	2857877	et	4	main
ka	doc_767882159235_item	2857879	et	3	main
vanasti	doc_767882159235_item	2857882	et	3	main
emad	doc_767882159235_item	2857884	et	3	main
palju	doc_767882159235_item	2857925	et	4	main
regliaule	doc_767882159235_item	2857935	et	4	main
lauldi	doc_767882159235_item	2857936	et	3	main
laulupidudel	doc_767882159235_item	2857955	et	4	main
võtsid	doc_767882159235_item	2857956	et	4	main
hakkasid	doc_767882159235_item	2857963	et	4	main
laulupididel	doc_767882159235_item	2857964	et	4	main
lastekoorid	doc_767882159235_item	2857967	et	3	main
1994	doc_767882159235_item	2857970	et	2	main
toimus	doc_767882159235_item	2857972	et	3	main
laulupidu	doc_767882159235_item	2857973	et	4	main
nii	doc_767882159235_item	2857974	et	3	main
tallinnas	doc_767882159235_item	2857978	et	4	main
pidu	doc_767882159235_item	2857987	et	4	main
on	doc_767882159235_item	2857989	et	4	main
ka	doc_767882159235_item	2857990	et	3	main
eesti	doc_767882159235_item	2858002	et	4	main
peost	doc_767882159235_item	2858013	et	4	main
rahvalaulu	doc_767882159235_item	2858032	et	4	main
riikidele	doc_767882159235_item	2858034	et	3	main
rock-muusika	doc_767882159235_item	2858048	et	4	main
mitte	doc_767882159235_item	2858049	et	3	main
arvan	doc_767882159235_item	2858052	et	3	main
keele	doc_767882159235_item	2857830	et	4	main
laulurahva	doc_767882159235_item	2857839	et	3	main
sõna	doc_767882159235_item	2857844	et	4	main
peab	doc_767882159235_item	2857846	et	4	main
loengus	doc_767882159235_item	2857853	et	3	main
väiteid	doc_767882159235_item	2857858	et	4	main
näidetega	doc_767882159235_item	2857862	et	3	main
alati	doc_767882159235_item	2857866	et	4	main
muusikaalne	doc_767882159235_item	2857868	et	4	main
on	doc_767882159235_item	2857871	et	4	main
väga	doc_767882159235_item	2857872	et	3	main
kui	doc_767882159235_item	2857878	et	3	main
pillissaatega	doc_767882159235_item	2857921	et	4	main
rahvalaulu	doc_767882159235_item	2857923	et	4	main
vokaalseid	doc_767882159235_item	2857927	et	3	main
vokaalselt	doc_767882159235_item	2857937	et	4	main
1869	doc_767882159235_item	2857940	et	2	main
aastal	doc_767882159235_item	2857941	et	3	main
traditsioon	doc_767882159235_item	2857954	et	3	main
pärast	doc_767882159235_item	2857962	et	4	main
osaleda	doc_767882159235_item	2857965	et	3	main
poistekoorid	doc_767882159235_item	2857969	et	3	main
aastal	doc_767882159235_item	2857971	et	3	main
tartus	doc_767882159235_item	2857975	et	3	main
kui	doc_767882159235_item	2857976	et	3	main
ka	doc_767882159235_item	2857977	et	3	main
ma	doc_767882159235_item	2857979	et	3	main
aastal	doc_767882159235_item	2857997	et	3	main
tulevad	doc_767882159235_item	2857999	et	4	main
kes	doc_767882159235_item	2858010	et	4	main
kõikidel	doc_767882159235_item	2858016	et	4	main
seljas	doc_767882159235_item	2858020	et	4	main
essee	doc_767882159235_item	2857825	et	4	main
kirjutamine	doc_767882159235_item	2857832	et	4	main
kirjutage	doc_767882159235_item	2857833	et	3	main
pikkus	doc_767882159235_item	2857841	et	4	main
tuginema	doc_767882159235_item	2857852	et	3	main
eesti	doc_767882159235_item	2857863	et	4	main
laulavad	doc_767882159235_item	2857875	et	4	main
tööl	doc_767882159235_item	2857880	et	3	main
lastele	doc_767882159235_item	2857886	et	4	main
ja	doc_767882159235_item	2857887	et	3	main
lapsed	doc_767882159235_item	2857888	et	3	main
mängides	doc_767882159235_item	2857889	et	4	main
laulsid	doc_767882159235_item	2857890	et	4	main
teine	doc_767882159235_item	2857891	et	3	main
teisele	doc_767882159235_item	2857892	et	4	main
eesti	doc_767882159235_item	2857893	et	4	main
vanemat	doc_767882159235_item	2857894	et	4	main
rahvalaulu	doc_767882159235_item	2857895	et	4	main
nimetatakse	doc_767882159235_item	2857896	et	3	main
regivärselikuks	doc_767882159235_item	2857897	et	4	main
rahvalauluks	doc_767882159235_item	2857898	et	4	main
eesti	doc_767882159235_item	2857899	et	4	main
folklöör	doc_767882159235_item	2857900	et	4	main
koosneb	doc_767882159235_item	2857901	et	3	main
kolmest	doc_767882159235_item	2857902	et	4	main
alast	doc_767882159235_item	2857903	et	4	main
laul	doc_767882159235_item	2857904	et	4	main
pillimäng	doc_767882159235_item	2857905	et	3	main
ja	doc_767882159235_item	2857906	et	3	main
tants	doc_767882159235_item	2857907	et	3	main
19	doc_767882159235_item	2857908	et	2	main
sajandil	doc_767882159235_item	2857909	et	3	main
ilmusid	doc_767882159235_item	2857910	et	4	main
uued	doc_767882159235_item	2857911	et	3	main
rahvalaulud	doc_767882159235_item	2857912	et	3	main
mida	doc_767882159235_item	2857913	et	4	main
nimetatakse	doc_767882159235_item	2857914	et	3	main
riimilised	doc_767882159235_item	2857915	et	4	main
rahvalaulud	doc_767882159235_item	2857916	et	3	main
neid	doc_767882159235_item	2857917	et	4	main
on	doc_767882159235_item	2857918	et	4	main
esitatud	doc_767882159235_item	2857919	et	4	main
ka	doc_767882159235_item	2857920	et	3	main
rahvalaulu	doc_767882159235_item	2857929	et	4	main
kahekesi	doc_767882159235_item	2857932	et	3	main
ilma	doc_767882159235_item	2857938	et	4	main
muusitita	doc_767882159235_item	2857939	et	3	main
350	doc_767882159235_item	2857843	et	2	main
üldistav	doc_767882159235_item	2857851	et	4	main
esitatud	doc_767882159235_item	2857856	et	4	main
rahvas	doc_767882159235_item	2857864	et	4	main
näiteks	doc_767882159235_item	2857881	et	4	main
oma	doc_767882159235_item	2857885	et	4	main
peole	doc_767882159235_item	2857922	et	4	main
on	doc_767882159235_item	2857924	et	4	main
ansambli	doc_767882159235_item	2857928	et	3	main
lauldi	doc_767882159235_item	2857930	et	3	main
laulupidu	doc_767882159235_item	2857944	et	4	main
sai	doc_767882159235_item	2857951	et	4	main
alguse	doc_767882159235_item	2857952	et	3	main
et	doc_767882159235_item	2857981	et	3	main
on	doc_767882159235_item	2857983	et	4	main
see	doc_767882159235_item	2857988	et	3	main
lauljad	doc_767882159235_item	2857998	et	4	main
linnadest	doc_767882159235_item	2858003	et	3	main
laulupeole	doc_767882159235_item	2858004	et	4	main
ka	doc_767882159235_item	2858006	et	3	main
külalised	doc_767882159235_item	2858007	et	4	main
rohkem	doc_767882159235_item	2858014	et	4	main
teada	doc_767882159235_item	2858015	et	3	main
on	doc_767882159235_item	2858022	et	4	main
inimesed	doc_767882159235_item	2858027	et	3	main
hakkasid	doc_767882159235_item	2858028	et	4	main
propagandeerima	doc_767882159235_item	2858029	et	4	main
teistele	doc_767882159235_item	2858033	et	4	main
on	doc_767882159235_item	2858047	et	4	main
kaks	doc_767882159235_item	2858066	et	3	main
takti	doc_767882159235_item	2858067	et	4	main
ka	doc_767882159235_item	2858070	et	3	main
öelda	doc_767882159236_item	2858116	et	4	main
et	doc_767882159236_item	2858117	et	3	main
erinevaid	doc_767882159235_item	2857926	et	4	main
üksi	doc_767882159235_item	2857931	et	4	main
või	doc_767882159235_item	2857933	et	4	main
koori	doc_767882159235_item	2857934	et	4	main
toimus	doc_767882159235_item	2857942	et	3	main
osalesid	doc_767882159235_item	2857946	et	4	main
laulupidude	doc_767882159235_item	2857953	et	4	main
aasta	doc_767882159235_item	2857961	et	4	main
naiskoorid	doc_767882159235_item	2857966	et	3	main
ja	doc_767882159235_item	2857968	et	3	main
arvan	doc_767882159235_item	2857980	et	3	main
laulupidu	doc_767882159235_item	2857982	et	4	main
on	doc_767882159235_item	2857984	et	4	main
väga	doc_767882159235_item	2857985	et	3	main
tähtis	doc_767882159235_item	2857986	et	4	main
suur	doc_767882159235_item	2857991	et	3	main
rahvapidu	doc_767882159235_item	2857992	et	4	main
laulupidu	doc_767882159235_item	2857993	et	4	main
toimub	doc_767882159235_item	2857994	et	3	main
4	doc_767882159235_item	2857996	et	2	main
peole	doc_767882159235_item	2858000	et	4	main
tulevad	doc_767882159235_item	2858005	et	4	main
teistest	doc_767882159235_item	2858008	et	4	main
riikides	doc_767882159235_item	2858009	et	3	main
on	doc_767882159235_item	2858018	et	4	main
tartus	doc_767882159235_item	2857943	et	3	main
kus	doc_767882159235_item	2857945	et	3	main
lauljad	doc_767882159235_item	2857947	et	4	main
puhkpilliorkestrid	doc_767882159235_item	2857948	et	3	main
sellest	doc_767882159235_item	2857949	et	4	main
laulupeost	doc_767882159235_item	2857950	et	4	main
osa	doc_767882159235_item	2857957	et	4	main
meestekoorid	doc_767882159235_item	2857958	et	3	main
ja	doc_767882159235_item	2857959	et	3	main
mõne	doc_767882159235_item	2857960	et	3	main
igal	doc_767882159235_item	2857995	et	3	main
erinevatest	doc_767882159235_item	2858001	et	4	main
tahavad	doc_767882159235_item	2858011	et	3	main
sellest	doc_767882159235_item	2858012	et	4	main
osajatel	doc_767882159235_item	2858017	et	4	main
rahvusriided	doc_767882159235_item	2858019	et	3	main
rahvatantsu	doc_767882159235_item	2858030	et	4	main
eestis	doc_767882159235_item	2858035	et	3	main
selle	doc_767882159235_item	2858044	et	4	main
laule	doc_767882159235_item	2858045	et	4	main
rahvamuusika	doc_767882159235_item	2858050	et	4	main
laulurahvas	doc_767882159235_item	2858056	et	4	main
toimuvad	doc_767882159235_item	2858060	et	4	main
laulupeod	doc_767882159235_item	2858061	et	4	main
ja	doc_767882159235_item	2858062	et	3	main
igasugused	doc_767882159235_item	2858063	et	3	main
laulukonkursid	doc_767882159235_item	2858064	et	3	main
eestlased	doc_767882159235_item	2858069	et	3	main
üldistav	doc_767882159236_item	2858101	et	4	main
tuginema	doc_767882159236_item	2858102	et	3	main
loengus	doc_767882159236_item	2858103	et	3	main
ja	doc_767882159236_item	2858104	et	3	main
seal	doc_767882159236_item	2858118	et	4	main
teeb	doc_767882159236_item	2858122	et	3	main
loodan	doc_767882159236_item	2858126	et	3	main
kindlasti	doc_767882159236_item	2858128	et	3	main
eestlaste	doc_767882159236_item	2858137	et	4	main
on	doc_767882159236_item	2858149	et	4	main
arvan	doc_767882159236_item	2858150	et	3	main
mitte	doc_767882159236_item	2858151	et	3	main
nii	doc_767882159236_item	2858152	et	3	main
oluline	doc_767882159236_item	2858153	et	4	main
kui	doc_767882159236_item	2858154	et	3	main
inimesed	doc_767882159236_item	2858155	et	3	main
mitte	doc_767882159236_item	2858156	et	3	main
ainult	doc_767882159236_item	2858157	et	4	main
eestlased	doc_767882159236_item	2858158	et	3	main
aga	doc_767882159236_item	2858159	et	3	main
see	doc_767882159236_item	2858165	et	3	main
laulurahvas	doc_767882159236_item	2858208	et	4	main
on	doc_767882159236_item	2858212	et	4	main
tänapäeval	doc_767882159236_item	2858218	et	3	main
vanaajal	doc_767882159235_item	2858026	et	3	main
ja	doc_767882159235_item	2858031	et	3	main
ansambel	doc_767882159235_item	2858037	et	3	main
laulab	doc_767882159235_item	2858039	et	3	main
seetu	doc_767882159235_item	2858041	et	4	main
keeles	doc_767882159235_item	2858042	et	4	main
aga	doc_767882159235_item	2858043	et	3	main
muusika	doc_767882159235_item	2858046	et	4	main
ma	doc_767882159235_item	2858051	et	3	main
eestlased	doc_767882159235_item	2858054	et	3	main
sellepärast	doc_767882159235_item	2858057	et	3	main
et	doc_767882159235_item	2858058	et	3	main
ette	doc_767882159235_item	2858068	et	4	main
osalevad	doc_767882159235_item	2858071	et	4	main
teiste	doc_767882159235_item	2858072	et	4	main
riikide	doc_767882159235_item	2858073	et	3	main
konkursidel	doc_767882159235_item	2858074	et	4	main
essee	doc_767882159236_item	2858075	et	4	main
teise	doc_767882159236_item	2858079	et	4	main
keele	doc_767882159236_item	2858080	et	4	main
test	doc_767882159236_item	2858081	et	3	main
kirjutamine	doc_767882159236_item	2858082	et	4	main
kirjutage	doc_767882159236_item	2858083	et	3	main
essee	doc_767882159236_item	2858084	et	4	main
teemal	doc_767882159236_item	2858085	et	3	main
mis	doc_767882159236_item	2858086	et	4	main
teeb	doc_767882159236_item	2858087	et	3	main
laulurahva	doc_767882159236_item	2858089	et	3	main
essee	doc_767882159236_item	2858090	et	4	main
pikkus	doc_767882159236_item	2858091	et	4	main
eestlastest	doc_767882159236_item	2858088	et	4	main
300	doc_767882159236_item	2858092	et	2	main
350	doc_767882159236_item	2858093	et	2	main
sõna	doc_767882159236_item	2858094	et	4	main
essee	doc_767882159236_item	2858095	et	4	main
peab	doc_767882159236_item	2858096	et	4	main
olema	doc_767882159236_item	2858097	et	4	main
arutlev	doc_767882159236_item	2858098	et	4	main
analüüsiv	doc_767882159236_item	2858099	et	4	main
rahvalaul	doc_767882159235_item	2858021	et	4	main
väga	doc_767882159235_item	2858023	et	3	main
populaarne	doc_767882159235_item	2858024	et	3	main
eestis	doc_767882159235_item	2858025	et	3	main
on	doc_767882159235_item	2858036	et	4	main
mis	doc_767882159235_item	2858038	et	4	main
rahvalaulu	doc_767882159235_item	2858040	et	4	main
et	doc_767882159235_item	2858053	et	3	main
näiteks	doc_767882159235_item	2858065	et	4	main
eesti	doc_767882159236_item	2858076	et	4	main
keele	doc_767882159236_item	2858077	et	4	main
kui	doc_767882159236_item	2858078	et	3	main
esitatud	doc_767882159236_item	2858106	et	4	main
väiteid	doc_767882159236_item	2858108	et	4	main
midagi	doc_767882159236_item	2858120	et	4	main
mis	doc_767882159236_item	2858121	et	4	main
mis	doc_767882159236_item	2858139	et	4	main
neid	doc_767882159236_item	2858141	et	4	main
täna	doc_767882159236_item	2858144	et	4	main
midagi	doc_767882159236_item	2858197	et	4	main
miks	doc_767882159236_item	2858209	et	4	main
pärast	doc_767882159236_item	2858210	et	4	main
ma	doc_767882159236_item	2858219	et	3	main
meeldib	doc_767882159236_item	2858229	et	3	main
laulurahvas	doc_767882159236_item	2858237	et	4	main
kellele	doc_767882159236_item	2858249	et	4	main
üldse	doc_767882159236_item	2858265	et	3	main
et	doc_767882159236_item	2858271	et	3	main
paha	doc_767882159236_item	2858274	et	4	main
laulupidudega	doc_767882159236_item	2858295	et	4	main
algas	doc_767882159236_item	2858296	et	3	main
me	doc_767882159236_item	2858301	et	4	main
teame	doc_767882159236_item	2858302	et	3	main
kes	doc_767882159236_item	2858313	et	4	main
saab	doc_767882159236_item	2858314	et	3	main
olla	doc_767882159236_item	2858315	et	3	main
seal	doc_767882159236_item	2858321	et	4	main
laulda	doc_767882159236_item	2858332	et	4	main
tantsida	doc_767882159236_item	2858333	et	3	main
miks	doc_767882159236_item	2858349	et	4	main
nad	doc_767882159236_item	2858350	et	3	main
mitte	doc_767882159236_item	2858354	et	3	main
isegi	doc_767882159236_item	2858363	et	4	main
on	doc_767882159236_item	2858366	et	4	main
laulurahvas	doc_767882159236_item	2858367	et	4	main
elada	doc_767882159236_item	2858382	et	3	main
on	doc_767882159235_item	2858055	et	4	main
eestis	doc_767882159235_item	2858059	et	3	main
lugemistekstis	doc_767882159236_item	2858105	et	3	main
on	doc_767882159236_item	2858109	et	4	main
soovitatav	doc_767882159236_item	2858110	et	4	main
illustreerida	doc_767882159236_item	2858111	et	3	main
näidetega	doc_767882159236_item	2858112	et	3	main
kas	doc_767882159236_item	2858113	et	3	main
saab	doc_767882159236_item	2858114	et	3	main
täiesti	doc_767882159236_item	2858115	et	3	main
on	doc_767882159236_item	2858119	et	4	main
laulurahva	doc_767882159236_item	2858124	et	3	main
et	doc_767882159236_item	2858127	et	3	main
jah	doc_767882159236_item	2858129	et	3	main
on	doc_767882159236_item	2858131	et	4	main
laulupeod	doc_767882159236_item	2858133	et	4	main
peod	doc_767882159236_item	2858134	et	4	main
millega	doc_767882159236_item	2858135	et	3	main
algas	doc_767882159236_item	2858136	et	3	main
kokku	doc_767882159236_item	2858142	et	3	main
ka	doc_767882159236_item	2858143	et	3	main
küsimus	doc_767882159236_item	2858145	et	4	main
laulupidude	doc_767882159236_item	2858146	et	4	main
mõelda	doc_767882159236_item	2858164	et	4	main
ole	doc_767882159236_item	2858167	et	4	main
oluline	doc_767882159236_item	2858168	et	4	main
teised	doc_767882159236_item	2858200	et	4	main
on	doc_767882159236_item	2858202	et	4	main
juba	doc_767882159236_item	2858203	et	3	main
elus	doc_767882159236_item	2858217	et	4	main
ei	doc_767882159236_item	2858220	et	4	main
on	doc_767882159236_item	2858224	et	4	main
eestlastele	doc_767882159236_item	2858227	et	4	main
väga	doc_767882159236_item	2858228	et	3	main
sest	doc_767882159236_item	2858232	et	4	main
just	doc_767882159236_item	2858235	et	3	main
ei	doc_767882159236_item	2858244	et	4	main
näinud	doc_767882159236_item	2858245	et	4	main
mitte	doc_767882159236_item	2858246	et	3	main
mulje	doc_767882159236_item	2858262	et	4	main
ma	doc_767882159236_item	2858268	et	3	main
on	doc_767882159236_item	2858280	et	4	main
minevikuga	doc_767882159236_item	2858281	et	3	main
sel	doc_767882159236_item	2858282	et	3	main
natukene	doc_767882159236_item	2858289	et	4	main
võib	doc_767882159236_item	2858291	et	3	main
et	doc_767882159236_item	2858293	et	3	main
nende	doc_767882159236_item	2858294	et	4	main
mida	doc_767882159236_item	2858300	et	4	main
said	doc_767882159236_item	2858306	et	4	main
et	doc_767882159236_item	2858308	et	3	main
rahvas	doc_767882159236_item	2858311	et	4	main
ja	doc_767882159236_item	2858334	et	3	main
et	doc_767882159236_item	2858338	et	3	main
on	doc_767882159236_item	2858351	et	4	main
laulurahvas	doc_767882159236_item	2858352	et	4	main
suurega	doc_767882159236_item	2858356	et	4	main
rahvade	doc_767882159236_item	2858360	et	4	main
kes	doc_767882159236_item	2858368	et	4	main
juhul	doc_767882159236_item	2858373	et	3	main
tantsida	doc_767882159236_item	2858379	et	3	main
ja	doc_767882159236_item	2858100	et	3	main
faktidele	doc_767882159236_item	2858107	et	3	main
eestlastest	doc_767882159236_item	2858123	et	4	main
need	doc_767882159236_item	2858130	et	3	main
muidugi	doc_767882159236_item	2858132	et	4	main
hoiavad	doc_767882159236_item	2858140	et	3	main
kohta	doc_767882159236_item	2858148	et	4	main
ja	doc_767882159236_item	2858192	et	3	main
tolline	doc_767882159236_item	2858193	et	4	main
esimene	doc_767882159236_item	2858194	et	3	main
ja	doc_767882159236_item	2858195	et	3	main
mitte	doc_767882159236_item	2858196	et	3	main
asjad	doc_767882159236_item	2858201	et	3	main
ajalugu	doc_767882159236_item	2858204	et	4	main
osa	doc_767882159236_item	2858215	et	4	main
eestlaste	doc_767882159236_item	2858216	et	4	main
arva	doc_767882159236_item	2858221	et	4	main
probleem	doc_767882159236_item	2858223	et	3	main
selles	doc_767882159236_item	2858225	et	4	main
et	doc_767882159236_item	2858226	et	3	main
ja	doc_767882159236_item	2858231	et	3	main
on	doc_767882159236_item	2858234	et	4	main
eestlast	doc_767882159236_item	2858248	et	4	main
selline	doc_767882159236_item	2858261	et	4	main
ei	doc_767882159236_item	2858266	et	4	main
ei	doc_767882159236_item	2858269	et	4	main
on	doc_767882159236_item	2858273	et	4	main
see	doc_767882159236_item	2858275	et	3	main
on	doc_767882159236_item	2858276	et	4	main
päris	doc_767882159236_item	2858277	et	4	main
normaalne	doc_767882159236_item	2858278	et	3	main
probleem	doc_767882159236_item	2858279	et	3	main
mõelda	doc_767882159236_item	2858288	et	4	main
öelda	doc_767882159236_item	2858292	et	4	main
ajalugu	doc_767882159236_item	2858299	et	4	main
on	doc_767882159236_item	2858310	et	4	main
rahvas	doc_767882159236_item	2858312	et	4	main
laulmas	doc_767882159236_item	2858318	et	3	main
sündis	doc_767882159236_item	2858322	et	3	main
riik	doc_767882159236_item	2858323	et	3	main
eestlaste	doc_767882159236_item	2858325	et	4	main
riik	doc_767882159236_item	2858326	et	3	main
kus	doc_767882159236_item	2858327	et	3	main
mängida	doc_767882159236_item	2858335	et	3	main
laulupidudel	doc_767882159236_item	2858337	et	4	main
ajal	doc_767882159236_item	2858340	et	4	main
mäletama	doc_767882159236_item	2858341	et	3	main
nii	doc_767882159236_item	2858355	et	3	main
ajalooga	doc_767882159236_item	2858357	et	4	main
nagu	doc_767882159236_item	2858358	et	3	main
teiste	doc_767882159236_item	2858359	et	4	main
nad	doc_767882159236_item	2858365	et	3	main
seda	doc_767882159236_item	2858371	et	3	main
ma	doc_767882159236_item	2858125	et	3	main
ärkamiseaeg	doc_767882159236_item	2858138	et	4	main
ajaloo	doc_767882159236_item	2858147	et	4	main
teised	doc_767882159236_item	2858160	et	4	main
rahvad	doc_767882159236_item	2858161	et	3	main
ka	doc_767882159236_item	2858162	et	3	main
saavad	doc_767882159236_item	2858163	et	4	main
ei	doc_767882159236_item	2858166	et	4	main
kui	doc_767882159236_item	2858169	et	3	main
ma	doc_767882159236_item	2858170	et	3	main
tahaksin	doc_767882159236_item	2858171	et	3	main
siin	doc_767882159236_item	2858172	et	4	main
rääkida	doc_767882159236_item	2858173	et	3	main
sellest	doc_767882159236_item	2858174	et	4	main
et	doc_767882159236_item	2858175	et	3	main
mis	doc_767882159236_item	2858176	et	4	main
seal	doc_767882159236_item	2858177	et	4	main
või	doc_767882159236_item	2858178	et	4	main
kes	doc_767882159236_item	2858179	et	4	main
teeb	doc_767882159236_item	2858180	et	3	main
eestlastest	doc_767882159236_item	2858181	et	4	main
laulurahva	doc_767882159236_item	2858182	et	3	main
see	doc_767882159236_item	2858183	et	3	main
on	doc_767882159236_item	2858184	et	4	main
nagu	doc_767882159236_item	2858185	et	3	main
esimene	doc_767882159236_item	2858186	et	3	main
laulupidu	doc_767882159236_item	2858187	et	4	main
traditsiioon	doc_767882159236_item	2858188	et	4	main
ja	doc_767882159236_item	2858189	et	3	main
aeg	doc_767882159236_item	2858190	et	3	main
praegune	doc_767882159236_item	2858191	et	3	main
veel	doc_767882159236_item	2858198	et	4	main
sest	doc_767882159236_item	2858199	et	4	main
miks	doc_767882159236_item	2858205	et	4	main
eestlased	doc_767882159236_item	2858206	et	3	main
on	doc_767882159236_item	2858207	et	4	main
laul	doc_767882159236_item	2858211	et	4	main
nagu	doc_767882159236_item	2858213	et	3	main
suurem	doc_767882159236_item	2858214	et	4	main
et	doc_767882159236_item	2858222	et	3	main
nad	doc_767882159236_item	2858233	et	3	main
seepärast	doc_767882159236_item	2858236	et	3	main
mina	doc_767882159236_item	2858238	et	4	main
ühtegi	doc_767882159236_item	2858247	et	4	main
tegi	doc_767882159236_item	2858256	et	4	main
seda	doc_767882159236_item	2858257	et	3	main
kogu	doc_767882159236_item	2858258	et	4	main
aeg	doc_767882159236_item	2858259	et	3	main
on	doc_767882159236_item	2858260	et	4	main
nad	doc_767882159236_item	2858264	et	3	main
arva	doc_767882159236_item	2858270	et	4	main
ajal	doc_767882159236_item	2858283	et	4	main
millal	doc_767882159236_item	2858284	et	3	main
oli	doc_767882159236_item	2858285	et	3	main
algus	doc_767882159236_item	2858286	et	4	main
ajalugu	doc_767882159236_item	2858297	et	4	main
täna	doc_767882159236_item	2858303	et	4	main
aru	doc_767882159236_item	2858307	et	4	main
koos	doc_767882159236_item	2858317	et	4	main
mängimas	doc_767882159236_item	2858320	et	3	main
ajal	doc_767882159236_item	2858331	et	4	main
käima	doc_767882159236_item	2858336	et	4	main
igal	doc_767882159236_item	2858339	et	3	main
ajalood	doc_767882159236_item	2858361	et	4	main
aga	doc_767882159236_item	2858362	et	3	main
peab	doc_767882159236_item	2858369	et	4	main
mäletama	doc_767882159236_item	2858370	et	3	main
ei	doc_767882159236_item	2858374	et	4	main
oma	doc_767882159236_item	2858376	et	4	main
minevikust	doc_767882159236_item	2858377	et	3	main
ja	doc_767882159236_item	2858378	et	3	main
mängida	doc_767882159236_item	2858380	et	3	main
edasi	doc_767882159236_item	2858383	et	3	main
lauda	doc_767882159236_item	2858230	et	4	main
saan	doc_767882159236_item	2858239	et	4	main
öelda	doc_767882159236_item	2858240	et	4	main
veel	doc_767882159236_item	2858241	et	4	main
et	doc_767882159236_item	2858242	et	3	main
ma	doc_767882159236_item	2858243	et	3	main
see	doc_767882159236_item	2858250	et	3	main
asi	doc_767882159236_item	2858251	et	4	main
väga	doc_767882159236_item	2858252	et	3	main
meeldis	doc_767882159236_item	2858253	et	3	main
ja	doc_767882159236_item	2858254	et	3	main
ta	doc_767882159236_item	2858255	et	4	main
et	doc_767882159236_item	2858263	et	3	main
laula	doc_767882159236_item	2858267	et	4	main
see	doc_767882159236_item	2858272	et	3	main
kui	doc_767882159236_item	2858287	et	3	main
sügavamalt	doc_767882159236_item	2858290	et	4	main
eestlaste	doc_767882159236_item	2858298	et	4	main
laulupidudega	doc_767882159236_item	2858304	et	4	main
eestlased	doc_767882159236_item	2858305	et	3	main
nad	doc_767882159236_item	2858309	et	3	main
koos	doc_767882159236_item	2858316	et	4	main
tantsimas	doc_767882159236_item	2858319	et	3	main
vaba	doc_767882159236_item	2858324	et	4	main
nad	doc_767882159236_item	2858328	et	3	main
saavad	doc_767882159236_item	2858329	et	4	main
igal	doc_767882159236_item	2858330	et	3	main
kust	doc_767882159236_item	2858342	et	4	main
nad	doc_767882159236_item	2858343	et	3	main
tulid	doc_767882159236_item	2858344	et	4	main
kuhu	doc_767882159236_item	2858345	et	3	main
nad	doc_767882159236_item	2858346	et	3	main
lähevad	doc_767882159236_item	2858347	et	3	main
ja	doc_767882159236_item	2858348	et	3	main
laulurahvas	doc_767882159236_item	2858353	et	4	main
sellega	doc_767882159236_item	2858364	et	3	main
igal	doc_767882159236_item	2858372	et	3	main
unustada	doc_767882159236_item	2858375	et	3	main
lauda	doc_767882159236_item	2858381	et	4	main
kui	doc_767882159238_item	2858689	et	3	main
kirjutamine	doc_767882159238_item	2858693	et	4	main
mis	doc_767882159238_item	2858724	et	4	main
ma	doc_767882159238_item	2858728	et	3	main
teemaga	doc_767882159238_item	2858732	et	3	main
meile	doc_767882159238_item	2858739	et	4	main
ja	doc_767882159238_item	2858742	et	3	main
selge	doc_767882159238_item	2858747	et	4	main
väljendusvahed	doc_767882159238_item	2858756	et	3	main
jutustavad	doc_767882159238_item	2858760	et	4	main
mitu	doc_767882159238_item	2858768	et	4	main
nagu	doc_767882159238_item	2858773	et	3	main
eestimaal	doc_767882159238_item	2858777	et	4	main
vormistatud	doc_767882159238_item	2858781	et	4	main
ajal	doc_767882159238_item	2858784	et	4	main
juba	doc_767882159238_item	2858789	et	3	main
läks	doc_767882159238_item	2858792	et	3	main
kultuurielus	doc_767882159238_item	2858800	et	4	main
muusika	doc_767882159238_item	2858825	et	4	main
ja	doc_767882159238_item	2858826	et	3	main
kodus	doc_767882159238_item	2858847	et	4	main
ja	doc_767882159238_item	2858855	et	3	main
sõpradega	doc_767882159238_item	2858856	et	3	main
sugulastega	doc_767882159238_item	2858857	et	4	main
ja	doc_767882159238_item	2858858	et	3	main
tuttavatega	doc_767882159238_item	2858859	et	3	main
väga	doc_767882159238_item	2858860	et	3	main
huvitav	doc_767882159238_item	2858861	et	4	main
fakt	doc_767882159238_item	2858862	et	3	main
eestikeeltes	doc_767882159238_item	2858866	et	3	main
on	doc_767882159238_item	2858868	et	4	main
populaarne	doc_767882159238_item	2858870	et	3	main
teema	doc_767882159238_item	2858872	et	4	main
et	doc_767882159238_item	2858874	et	3	main
ka	doc_767882159238_item	2858878	et	3	main
teiste	doc_767882159238_item	2858880	et	4	main
korraldamine	doc_767882159238_item	2858882	et	4	main
on	doc_767882159238_item	2858883	et	4	main
keele	doc_767882159238_item	2858688	et	4	main
kirjutage	doc_767882159238_item	2858694	et	3	main
näidetega	doc_767882159238_item	2858723	et	3	main
olen	doc_767882159238_item	2858729	et	3	main
eestlased	doc_767882159238_item	2858734	et	3	main
näitavad	doc_767882159238_item	2858738	et	4	main
kaasaegne	doc_767882159238_item	2858743	et	3	main
esteetiline	doc_767882159238_item	2858755	et	3	main
rahva	doc_767882159238_item	2858762	et	3	main
võtab	doc_767882159238_item	2858766	et	3	main
rahvalaul	doc_767882159238_item	2858772	et	4	main
minu	doc_767882159238_item	2858778	et	3	main
oli	doc_767882159238_item	2858780	et	3	main
ajalt	doc_767882159238_item	2858788	et	4	main
on	doc_767882159238_item	2858796	et	4	main
eestlased	doc_767882159238_item	2858803	et	3	main
suur	doc_767882159238_item	2858831	et	3	main
inimesed	doc_767882159238_item	2858840	et	3	main
üksi	doc_767882159238_item	2858842	et	4	main
ja	doc_767882159238_item	2858843	et	3	main
kahekesi	doc_767882159238_item	2858844	et	3	main
ja	doc_767882159238_item	2858845	et	3	main
kolmekesi	doc_767882159238_item	2858846	et	3	main
nii	doc_767882159238_item	2858875	et	3	main
kui	doc_767882159238_item	2858877	et	3	main
erinevate	doc_767882159238_item	2858879	et	4	main
et	doc_767882159238_item	2858894	et	3	main
laulis	doc_767882159238_item	2858899	et	4	main
16	doc_767882159238_item	2858901	et	2	main
teise	doc_767882159238_item	2858690	et	4	main
test	doc_767882159238_item	2858692	et	3	main
eesti	doc_767882159238_item	2858687	et	4	main
essee	doc_767882159238_item	2858695	et	4	main
teemal	doc_767882159238_item	2858696	et	3	main
mis	doc_767882159238_item	2858697	et	4	main
teeb	doc_767882159238_item	2858698	et	3	main
eestlastest	doc_767882159238_item	2858699	et	4	main
laulurahva	doc_767882159238_item	2858700	et	3	main
essee	doc_767882159238_item	2858701	et	4	main
pikkus	doc_767882159238_item	2858702	et	4	main
300	doc_767882159238_item	2858703	et	2	main
350	doc_767882159238_item	2858704	et	2	main
sõna	doc_767882159238_item	2858705	et	4	main
essee	doc_767882159238_item	2858706	et	4	main
peab	doc_767882159238_item	2858707	et	4	main
olema	doc_767882159238_item	2858708	et	4	main
arutlev	doc_767882159238_item	2858709	et	4	main
analüüsiv	doc_767882159238_item	2858710	et	4	main
ja	doc_767882159238_item	2858711	et	3	main
üldistav	doc_767882159238_item	2858712	et	4	main
tuginema	doc_767882159238_item	2858713	et	3	main
loengus	doc_767882159238_item	2858714	et	3	main
ja	doc_767882159238_item	2858715	et	3	main
lugemistekstis	doc_767882159238_item	2858716	et	3	main
esitatud	doc_767882159238_item	2858717	et	4	main
faktidele	doc_767882159238_item	2858718	et	3	main
väiteid	doc_767882159238_item	2858719	et	4	main
on	doc_767882159238_item	2858720	et	4	main
soovitatav	doc_767882159238_item	2858721	et	4	main
eestlastest	doc_767882159238_item	2858726	et	4	main
essee	doc_767882159238_item	2858731	et	4	main
laulurahvas	doc_767882159238_item	2858736	et	4	main
faktid	doc_767882159238_item	2858741	et	3	main
on	doc_767882159238_item	2858746	et	4	main
laulmine	doc_767882159238_item	2858749	et	4	main
on	doc_767882159238_item	2858750	et	4	main
ja	doc_767882159238_item	2858753	et	3	main
seejärel	doc_767882159238_item	2858757	et	3	main
põhiliselt	doc_767882159238_item	2858759	et	4	main
rahvalaul	doc_767882159238_item	2858765	et	4	main
aga	doc_767882159238_item	2858771	et	3	main
tähtsaim	doc_767882159238_item	2858775	et	4	main
esimese	doc_767882159238_item	2858782	et	3	main
küll	doc_767882159238_item	2858786	et	4	main
aastaid	doc_767882159238_item	2858791	et	4	main
laulupidu	doc_767882159238_item	2858795	et	4	main
sündmus	doc_767882159238_item	2858798	et	3	main
siiamaani	doc_767882159238_item	2858801	et	3	main
rap	doc_767882159238_item	2858822	et	4	main
essee	doc_767882159238_item	2858686	et	4	main
keele	doc_767882159238_item	2858691	et	4	main
illustreerida	doc_767882159238_item	2858722	et	3	main
laulurahva	doc_767882159238_item	2858727	et	3	main
et	doc_767882159238_item	2858733	et	3	main
ajaloolised	doc_767882159238_item	2858740	et	4	main
kõigepealt	doc_767882159238_item	2858745	et	3	main
teiseks	doc_767882159238_item	2858754	et	4	main
meile	doc_767882159238_item	2858761	et	4	main
eesti	doc_767882159238_item	2858764	et	4	main
tagasi	doc_767882159238_item	2858770	et	3	main
sümbol	doc_767882159238_item	2858776	et	3	main
arvates	doc_767882159238_item	2858779	et	4	main
on	doc_767882159238_item	2858785	et	4	main
ära	doc_767882159238_item	2858793	et	4	main
kindlasti	doc_767882159238_item	2858802	et	3	main
rock	doc_767882159238_item	2858821	et	4	main
jazz	doc_767882159238_item	2858823	et	4	main
laulurahvas	doc_767882159238_item	2858839	et	4	main
tööl	doc_767882159238_item	2858849	et	3	main
kaasaegsetes	doc_767882159238_item	2858865	et	4	main
laulufestivalide	doc_767882159238_item	2858881	et	3	main
ja	doc_767882159238_item	2858887	et	3	main
kui	doc_767882159238_item	2858889	et	3	main
tartus	doc_767882159238_item	2858898	et	3	main
kuulajale	doc_767882159238_item	2858906	et	4	main
tallinnas	doc_767882159238_item	2858908	et	4	main
laulis	doc_767882159238_item	2858909	et	4	main
ühtekokku	doc_767882159238_item	2858910	et	3	main
25	doc_767882159238_item	2858911	et	2	main
on	doc_767882159238_item	2858918	et	4	main
väga	doc_767882159238_item	2858919	et	3	main
arv	doc_767882159238_item	2858921	et	3	main
üldse	doc_767882159238_item	2858926	et	3	main
nissugune	doc_767882159238_item	2858937	et	4	main
teeb	doc_767882159238_item	2858725	et	3	main
nõus	doc_767882159238_item	2858730	et	4	main
on	doc_767882159238_item	2858735	et	4	main
see	doc_767882159238_item	2858737	et	3	main
situatsioon	doc_767882159238_item	2858744	et	3	main
et	doc_767882159238_item	2858748	et	3	main
esimeseks	doc_767882159238_item	2858751	et	3	main
emotsionaalne	doc_767882159238_item	2858752	et	3	main
rahvalaulad	doc_767882159238_item	2858758	et	4	main
minevikust	doc_767882159238_item	2858763	et	3	main
algust	doc_767882159238_item	2858767	et	4	main
sajande	doc_767882159238_item	2858769	et	4	main
rahvakultuuri	doc_767882159238_item	2858774	et	4	main
laulupidu	doc_767882159238_item	2858783	et	4	main
sealt	doc_767882159238_item	2858787	et	4	main
palju	doc_767882159238_item	2858790	et	4	main
vaid	doc_767882159238_item	2858794	et	3	main
tähtsaim	doc_767882159238_item	2858797	et	4	main
eesti	doc_767882159238_item	2858799	et	4	main
laulavad	doc_767882159238_item	2858804	et	4	main
mitte	doc_767882159238_item	2858805	et	3	main
ainult	doc_767882159238_item	2858806	et	4	main
rahvalaulad	doc_767882159238_item	2858807	et	4	main
on	doc_767882159238_item	2858808	et	4	main
väga	doc_767882159238_item	2858809	et	3	main
populaarsed	doc_767882159238_item	2858810	et	3	main
kaasaegsed	doc_767882159238_item	2858811	et	3	main
muusikalised	doc_767882159238_item	2858812	et	4	main
teemad	doc_767882159238_item	2858813	et	3	main
ja	doc_767882159238_item	2858814	et	3	main
suunad	doc_767882159238_item	2858815	et	4	main
nende	doc_767882159238_item	2858816	et	4	main
arvas	doc_767882159238_item	2858817	et	3	main
on	doc_767882159238_item	2858818	et	4	main
populaarne	doc_767882159238_item	2858819	et	3	main
muusika	doc_767882159238_item	2858820	et	4	main
teised	doc_767882159238_item	2858827	et	4	main
tele-	doc_767882159238_item	2858828	et	4	main
ja	doc_767882159238_item	2858829	et	3	main
arv	doc_767882159238_item	2858832	et	3	main
hea	doc_767882159238_item	2858834	et	4	main
ja	doc_767882159238_item	2858848	et	3	main
looduses	doc_767882159238_item	2858850	et	4	main
ja	doc_767882159238_item	2858851	et	3	main
autos	doc_767882159238_item	2858852	et	3	main
koos	doc_767882159238_item	2858853	et	4	main
perega	doc_767882159238_item	2858854	et	3	main
klaasikaline	doc_767882159238_item	2858824	et	4	main
raadiosaadete	doc_767882159238_item	2858830	et	3	main
on	doc_767882159238_item	2858833	et	4	main
näidis	doc_767882159238_item	2858835	et	4	main
et	doc_767882159238_item	2858836	et	3	main
eestlased	doc_767882159238_item	2858837	et	3	main
on	doc_767882159238_item	2858838	et	4	main
laulavad	doc_767882159238_item	2858841	et	4	main
on	doc_767882159238_item	2858863	et	4	main
et	doc_767882159238_item	2858864	et	3	main
natuke	doc_767882159238_item	2858869	et	4	main
folkloori	doc_767882159238_item	2858871	et	4	main
tõenäoliselt	doc_767882159238_item	2858873	et	4	main
laulupidu	doc_767882159238_item	2858876	et	4	main
side	doc_767882159238_item	2858884	et	4	main
läbi	doc_767882159238_item	2858885	et	4	main
tulevikut	doc_767882159238_item	2858888	et	4	main
vaadata	doc_767882159238_item	2858890	et	4	main
statiistikat	doc_767882159238_item	2858891	et	4	main
siis	doc_767882159238_item	2858892	et	3	main
näeme	doc_767882159238_item	2858893	et	3	main
pealtvaatajatele	doc_767882159238_item	2858916	et	3	main
et	doc_767882159238_item	2858924	et	3	main
1	doc_767882159238_item	2858930	et	2	main
350	doc_767882159238_item	2858931	et	2	main
000	doc_767882159238_item	2858932	et	2	main
elanikke	doc_767882159238_item	2858933	et	3	main
te	doc_767882159238_item	2858934	et	4	main
küsite	doc_767882159238_item	2858935	et	3	main
ma	doc_767882159238_item	2858939	et	3	main
laulades	doc_767882159238_item	2858867	et	3	main
1994	doc_767882159238_item	2858895	et	2	main
umbes	doc_767882159238_item	2858900	et	4	main
000	doc_767882159238_item	2858902	et	2	main
lauljat	doc_767882159238_item	2858903	et	4	main
70	doc_767882159238_item	2858904	et	2	main
000	doc_767882159238_item	2858905	et	2	main
ja	doc_767882159238_item	2858907	et	3	main
000	doc_767882159238_item	2858912	et	2	main
esinejat	doc_767882159238_item	2858913	et	4	main
100	doc_767882159238_item	2858914	et	2	main
000	doc_767882159238_item	2858915	et	2	main
mäletada	doc_767882159238_item	2858923	et	3	main
kokku	doc_767882159238_item	2858927	et	3	main
eestlased	doc_767882159238_item	2858941	et	3	main
laulurahvas	doc_767882159238_item	2858943	et	4	main
minevikut	doc_767882159238_item	2858886	et	4	main
aastal	doc_767882159238_item	2858896	et	3	main
laulupidus	doc_767882159238_item	2858897	et	3	main
see	doc_767882159238_item	2858917	et	3	main
suur	doc_767882159238_item	2858920	et	3	main
kui	doc_767882159238_item	2858922	et	3	main
eestimaal	doc_767882159238_item	2858925	et	4	main
elavad	doc_767882159238_item	2858928	et	4	main
umbes	doc_767882159238_item	2858929	et	4	main
populaarsus	doc_767882159238_item	2858938	et	4	main
on	doc_767882159238_item	2858942	et	4	main
miks	doc_767882159238_item	2858936	et	4	main
vastan	doc_767882159238_item	2858940	et	3	main
essee	doc_767882159242_item	2859604	et	4	main
300	doc_767882159242_item	2859612	et	2	main
loengus	doc_767882159242_item	2859623	et	3	main
ja	doc_767882159242_item	2859624	et	3	main
esitatud	doc_767882159242_item	2859626	et	4	main
rahvas	doc_767882159242_item	2859634	et	4	main
olnud	doc_767882159242_item	2859640	et	4	main
ka	doc_767882159242_item	2859655	et	3	main
laulsid	doc_767882159242_item	2859670	et	4	main
sai	doc_767882159242_item	2859680	et	4	main
kultuuriline	doc_767882159242_item	2859689	et	4	main
enam	doc_767882159242_item	2859696	et	4	main
laule	doc_767882159242_item	2859721	et	4	main
laulupeod	doc_767882159242_item	2859723	et	4	main
eestlaste	doc_767882159242_item	2859725	et	4	main
sest	doc_767882159242_item	2859730	et	4	main
essee	doc_767882159242_item	2859595	et	4	main
keele	doc_767882159242_item	2859597	et	4	main
teemal	doc_767882159242_item	2859605	et	3	main
mis	doc_767882159242_item	2859606	et	4	main
350	doc_767882159242_item	2859613	et	2	main
olema	doc_767882159242_item	2859617	et	4	main
analüüsiv	doc_767882159242_item	2859619	et	4	main
teise	doc_767882159242_item	2859599	et	4	main
keele	doc_767882159242_item	2859600	et	4	main
test	doc_767882159242_item	2859601	et	3	main
essee	doc_767882159242_item	2859610	et	4	main
sõna	doc_767882159242_item	2859614	et	4	main
peab	doc_767882159242_item	2859616	et	4	main
ja	doc_767882159242_item	2859620	et	3	main
soovitatav	doc_767882159242_item	2859630	et	4	main
illustreerida	doc_767882159242_item	2859631	et	3	main
näidetega	doc_767882159242_item	2859632	et	3	main
laulmine	doc_767882159242_item	2859638	et	4	main
kultuurinähtus	doc_767882159242_item	2859644	et	4	main
juba	doc_767882159242_item	2859645	et	3	main
aga	doc_767882159242_item	2859654	et	3	main
sotsiaalne	doc_767882159242_item	2859656	et	3	main
hälli	doc_767882159242_item	2859666	et	4	main
hauani	doc_767882159242_item	2859667	et	3	main
vanad	doc_767882159242_item	2859668	et	3	main
eestlased	doc_767882159242_item	2859669	et	3	main
last	doc_767882159242_item	2859674	et	4	main
eestlased	doc_767882159242_item	2859681	et	3	main
rahvalaul	doc_767882159242_item	2859692	et	4	main
on	doc_767882159242_item	2859694	et	4	main
kujunenud	doc_767882159242_item	2859695	et	4	main
tuhat	doc_767882159242_item	2859698	et	4	main
aastat	doc_767882159242_item	2859699	et	3	main
on	doc_767882159242_item	2859724	et	4	main
sai	doc_767882159242_item	2859733	et	4	main
näha	doc_767882159242_item	2859734	et	3	main
laulupeo	doc_767882159242_item	2859754	et	4	main
kus	doc_767882159242_item	2859755	et	3	main
nii	doc_767882159242_item	2859758	et	3	main
ka	doc_767882159242_item	2859761	et	3	main
inimese	doc_767882159242_item	2859771	et	4	main
ja	doc_767882159242_item	2859777	et	3	main
teevadki	doc_767882159242_item	2859779	et	3	main
eesti	doc_767882159242_item	2859596	et	4	main
kui	doc_767882159242_item	2859598	et	3	main
teeb	doc_767882159242_item	2859607	et	3	main
eestlastest	doc_767882159242_item	2859608	et	4	main
laulurahva	doc_767882159242_item	2859609	et	3	main
arutlev	doc_767882159242_item	2859618	et	4	main
tuginema	doc_767882159242_item	2859622	et	3	main
väiteid	doc_767882159242_item	2859628	et	4	main
on	doc_767882159242_item	2859629	et	4	main
rahvas	doc_767882159242_item	2859637	et	4	main
emotsionaalne	doc_767882159242_item	2859652	et	3	main
nii	doc_767882159242_item	2859661	et	3	main
töötades	doc_767882159242_item	2859673	et	3	main
kiigutades	doc_767882159242_item	2859675	et	3	main
laulutraditsiooni	doc_767882159242_item	2859686	et	4	main
esindab	doc_767882159242_item	2859687	et	3	main
laanemeresoome	doc_767882159242_item	2859688	et	3	main
eestlased	doc_767882159242_item	2859701	et	3	main
kirjutamine	doc_767882159242_item	2859602	et	4	main
kirjutage	doc_767882159242_item	2859603	et	3	main
pikkus	doc_767882159242_item	2859611	et	4	main
essee	doc_767882159242_item	2859615	et	4	main
üldistav	doc_767882159242_item	2859621	et	4	main
lugemistekstis	doc_767882159242_item	2859625	et	3	main
faktidele	doc_767882159242_item	2859627	et	3	main
on	doc_767882159242_item	2859635	et	4	main
unikaalne	doc_767882159242_item	2859636	et	3	main
eestlaste	doc_767882159242_item	2859641	et	4	main
jaoks	doc_767882159242_item	2859642	et	4	main
tähelepanuväärne	doc_767882159242_item	2859643	et	3	main
väljendusvahend	doc_767882159242_item	2859653	et	3	main
tegevus	doc_767882159242_item	2859657	et	4	main
aja	doc_767882159242_item	2859659	et	4	main
et	doc_767882159242_item	2859662	et	3	main
laul	doc_767882159242_item	2859663	et	4	main
saatis	doc_767882159242_item	2859664	et	3	main
eestlast	doc_767882159242_item	2859665	et	4	main
olles	doc_767882159242_item	2859672	et	3	main
peaaegu	doc_767882159242_item	2859676	et	3	main
pool	doc_767882159242_item	2859678	et	4	main
üritasid	doc_767882159242_item	2859682	et	4	main
eesti	doc_767882159242_item	2859684	et	4	main
vanemat	doc_767882159242_item	2859685	et	4	main
regivärsiline	doc_767882159242_item	2859691	et	4	main
mis	doc_767882159242_item	2859693	et	4	main
saanud	doc_767882159242_item	2859703	et	4	main
ja	doc_767882159242_item	2859735	et	3	main
laule	doc_767882159242_item	2859739	et	4	main
leida	doc_767882159242_item	2859741	et	3	main
head	doc_767882159242_item	2859743	et	4	main
ja	doc_767882159242_item	2859744	et	3	main
uut	doc_767882159242_item	2859745	et	3	main
enda	doc_767882159242_item	2859746	et	4	main
kakskümend	doc_767882159242_item	2859752	et	4	main
kaks	doc_767882159242_item	2859753	et	3	main
meestekoorid	doc_767882159242_item	2859759	et	3	main
laulupidudel	doc_767882159242_item	2859765	et	4	main
eesti	doc_767882159244_item	2859956	et	4	main
keele	doc_767882159244_item	2859957	et	4	main
kui	doc_767882159244_item	2859958	et	3	main
teise	doc_767882159244_item	2859959	et	4	main
essee	doc_767882159244_item	2859970	et	4	main
kultuurinähtus	doc_767882159244_item	2859996	et	4	main
oli	doc_767882159244_item	2859999	et	3	main
laulmine	doc_767882159244_item	2860000	et	4	main
üks	doc_767882159244_item	2860001	et	3	main
eesti	doc_767882159242_item	2859633	et	4	main
on	doc_767882159242_item	2859639	et	4	main
palju	doc_767882159242_item	2859646	et	4	main
sajandeid	doc_767882159242_item	2859647	et	3	main
see	doc_767882159242_item	2859648	et	3	main
on	doc_767882159242_item	2859649	et	4	main
esteetiline	doc_767882159242_item	2859650	et	3	main
ja	doc_767882159242_item	2859651	et	3	main
vanal	doc_767882159242_item	2859658	et	3	main
oli	doc_767882159242_item	2859660	et	3	main
uksi	doc_767882159242_item	2859671	et	3	main
igal	doc_767882159242_item	2859677	et	3	main
kus	doc_767882159242_item	2859679	et	3	main
laulda	doc_767882159242_item	2859683	et	4	main
iseloomulik	doc_767882159242_item	2859690	et	3	main
kui	doc_767882159242_item	2859697	et	3	main
tagasi	doc_767882159242_item	2859700	et	3	main
on	doc_767882159242_item	2859702	et	4	main
häid	doc_767882159242_item	2859704	et	3	main
mõtteid	doc_767882159242_item	2859705	et	3	main
ka	doc_767882159242_item	2859706	et	3	main
euroopa	doc_767882159242_item	2859707	et	4	main
poolt	doc_767882159242_item	2859708	et	4	main
eelkõige	doc_767882159242_item	2859709	et	3	main
saksa	doc_767882159242_item	2859710	et	4	main
aga	doc_767882159242_item	2859711	et	3	main
ka	doc_767882159242_item	2859712	et	3	main
rootsi	doc_767882159242_item	2859713	et	4	main
ja	doc_767882159242_item	2859714	et	3	main
slaavi	doc_767882159242_item	2859715	et	3	main
muusikas	doc_767882159242_item	2859716	et	3	main
mis	doc_767882159242_item	2859717	et	4	main
lõi	doc_767882159242_item	2859718	et	4	main
uusi	doc_767882159242_item	2859719	et	3	main
riimilisi	doc_767882159242_item	2859720	et	4	main
elus	doc_767882159242_item	2859726	et	4	main
laulupeol	doc_767882159242_item	2859732	et	4	main
rahvuste	doc_767882159242_item	2859738	et	3	main
ja	doc_767882159242_item	2859740	et	3	main
midagi	doc_767882159242_item	2859742	et	4	main
kui	doc_767882159242_item	2859760	et	3	main
ja	doc_767882159242_item	2859763	et	3	main
just	doc_767882159242_item	2859773	et	3	main
see	doc_767882159242_item	2859774	et	3	main
laulud	doc_767882159242_item	2859778	et	3	main
eestlasi	doc_767882159242_item	2859780	et	3	main
ka	doc_767882159242_item	2859722	et	3	main
mänginud	doc_767882159242_item	2859727	et	4	main
tahtist	doc_767882159242_item	2859728	et	4	main
rolli	doc_767882159242_item	2859729	et	4	main
kuulda	doc_767882159242_item	2859736	et	4	main
jaok	doc_767882159242_item	2859747	et	4	main
eesti	doc_767882159242_item	2859748	et	4	main
just	doc_767882159242_item	2859731	et	3	main
teiste	doc_767882159242_item	2859737	et	4	main
rahvus	doc_767882159242_item	2859749	et	3	main
on	doc_767882159242_item	2859750	et	4	main
korraldanud	doc_767882159242_item	2859751	et	4	main
on	doc_767882159242_item	2859756	et	4	main
naiste-	doc_767882159242_item	2859762	et	3	main
lastekoorid	doc_767882159242_item	2859764	et	3	main
tavaliselt	doc_767882159242_item	2859766	et	4	main
osaleb	doc_767882159242_item	2859767	et	3	main
üle	doc_767882159242_item	2859768	et	3	main
viikümne	doc_767882159242_item	2859769	et	4	main
tuhande	doc_767882159242_item	2859770	et	3	main
ilus	doc_767882159242_item	2859775	et	4	main
laulurahvaks	doc_767882159242_item	2859781	et	3	main
essee	doc_767882159244_item	2859964	et	4	main
teemal	doc_767882159244_item	2859965	et	3	main
mis	doc_767882159244_item	2859966	et	4	main
teeb	doc_767882159244_item	2859967	et	3	main
eestlastest	doc_767882159244_item	2859968	et	4	main
soovitatav	doc_767882159244_item	2859990	et	4	main
illustreerida	doc_767882159244_item	2859991	et	3	main
näidetega	doc_767882159244_item	2859992	et	3	main
laulmine	doc_767882159244_item	2859993	et	4	main
eest	doc_767882159244_item	2860004	et	4	main
inimeste	doc_767882159244_item	2860005	et	3	main
elus	doc_767882159244_item	2860006	et	4	main
lauluga	doc_767882159244_item	2860014	et	4	main
üksi	doc_767882159244_item	2860021	et	4	main
ja	doc_767882159244_item	2860024	et	3	main
kiigutades	doc_767882159244_item	2860026	et	3	main
tihti	doc_767882159244_item	2860028	et	3	main
rääkisid	doc_767882159244_item	2860047	et	4	main
18	doc_767882159244_item	2860058	et	2	main
hakkas	doc_767882159244_item	2860060	et	3	main
laulmine	doc_767882159244_item	2860062	et	4	main
lauli	doc_767882159244_item	2860064	et	4	main
ka	doc_767882159244_item	2860065	et	3	main
väljaspool	doc_767882159244_item	2860066	et	3	main
kirikut	doc_767882159244_item	2860067	et	3	main
rahvalaulus	doc_767882159244_item	2860068	et	3	main
suurt	doc_767882159244_item	2860071	et	3	main
riimiline	doc_767882159244_item	2860075	et	4	main
rahvalaul	doc_767882159244_item	2860076	et	4	main
seda	doc_767882159244_item	2860087	et	3	main
laulnud	doc_767882159242_item	2859757	et	4	main
sest	doc_767882159242_item	2859772	et	4	main
muusika	doc_767882159242_item	2859776	et	4	main
essee	doc_767882159244_item	2859955	et	4	main
asi	doc_767882159244_item	2860003	et	4	main
lauluga	doc_767882159244_item	2860009	et	4	main
ja	doc_767882159244_item	2860010	et	3	main
surid	doc_767882159244_item	2860011	et	4	main
tutvumine	doc_767882159244_item	2860036	et	4	main
mõnikord	doc_767882159244_item	2860049	et	3	main
laule	doc_767882159244_item	2860056	et	4	main
sajandil	doc_767882159244_item	2860059	et	3	main
levima	doc_767882159244_item	2860061	et	3	main
korraldati	doc_767882159244_item	2860094	et	3	main
eestlaste	doc_767882159244_item	2860121	et	4	main
kõrghetk	doc_767882159244_item	2860124	et	3	main
sai	doc_767882159244_item	2860126	et	4	main
järgnevate	doc_767882159244_item	2860133	et	4	main
algas	doc_767882159244_item	2860138	et	3	main
see	doc_767882159244_item	2860141	et	3	main
tallinnasse	doc_767882159244_item	2860143	et	3	main
laulupidu	doc_767882159244_item	2860146	et	4	main
ka	doc_767882159244_item	2860148	et	3	main
praegu	doc_767882159244_item	2860149	et	3	main
ja	doc_767882159244_item	2860152	et	3	main
või	doc_767882159244_item	2860169	et	4	main
tulnud	doc_767882159244_item	2860173	et	4	main
rahvas	doc_767882159244_item	2860176	et	4	main
koguneb	doc_767882159244_item	2860177	et	3	main
läbi	doc_767882159244_item	2860185	et	4	main
sümboliteks	doc_767882159244_item	2860189	et	3	main
kirjutamine	doc_767882159245_item	2860197	et	4	main
kogu	doc_767882159245_item	2860228	et	4	main
laul	doc_767882159245_item	2860236	et	4	main
ka	doc_767882159245_item	2860244	et	3	main
et	doc_767882159245_item	2860250	et	3	main
eestimaa	doc_767882159245_item	2860251	et	4	main
ööelda	doc_767882159245_item	2860268	et	4	main
et	doc_767882159245_item	2860269	et	3	main
eestlaste	doc_767882159245_item	2860276	et	4	main
laulud	doc_767882159245_item	2860277	et	3	main
koguaeg	doc_767882159245_item	2860278	et	3	main
elu	doc_767882159245_item	2860289	et	4	main
laulud	doc_767882159245_item	2860290	et	3	main
ja	doc_767882159245_item	2860291	et	3	main
tantsid	doc_767882159245_item	2860292	et	4	main
viis	doc_767882159245_item	2860313	et	4	main
aastat	doc_767882159245_item	2860314	et	3	main
laulupeod	doc_767882159245_item	2860317	et	4	main
palju	doc_767882159245_item	2860319	et	4	main
korraldamise	doc_767882159245_item	2860331	et	4	main
jannseniga	doc_767882159245_item	2860339	et	4	main
ööelda	doc_767882159245_item	2860343	et	4	main
hakkas	doc_767882159245_item	2860348	et	3	main
mil	doc_767882159245_item	2860355	et	4	main
rahvuslikke	doc_767882159245_item	2860356	et	3	main
ja	doc_767882159245_item	2860358	et	3	main
eestlastele	doc_767882159245_item	2860369	et	4	main
keele	doc_767882159244_item	2859960	et	4	main
test	doc_767882159244_item	2859961	et	3	main
laulurahva	doc_767882159244_item	2859969	et	3	main
on	doc_767882159244_item	2859994	et	4	main
tähelepanuväärne	doc_767882159244_item	2859995	et	3	main
ajal	doc_767882159244_item	2859998	et	4	main
ära	doc_767882159244_item	2860012	et	4	main
ka	doc_767882159244_item	2860013	et	3	main
olles	doc_767882159244_item	2860022	et	3	main
rahvalauludes	doc_767882159244_item	2860027	et	3	main
aga	doc_767882159244_item	2860057	et	3	main
vaimulike	doc_767882159244_item	2860063	et	3	main
oli	doc_767882159244_item	2860069	et	3	main
osa	doc_767882159244_item	2860072	et	4	main
regilaul	doc_767882159244_item	2860073	et	4	main
käsitöö	doc_767882159244_item	2860085	et	4	main
teedes	doc_767882159244_item	2860086	et	3	main
tegid	doc_767882159244_item	2860089	et	4	main
muusikata	doc_767882159244_item	2860091	et	3	main
sellest	doc_767882159244_item	2860127	et	4	main
musikaalne	doc_767882159244_item	2860128	et	3	main
suursündmus	doc_767882159244_item	2860129	et	3	main
mis	doc_767882159244_item	2860130	et	4	main
tartus	doc_767882159244_item	2860139	et	3	main
on	doc_767882159244_item	2860147	et	4	main
tähelepanuväärsem	doc_767882159244_item	2860153	et	4	main
eesti	doc_767882159244_item	2860157	et	4	main
elanikud	doc_767882159244_item	2860158	et	3	main
lootuses	doc_767882159244_item	2860165	et	4	main
kohtuda	doc_767882159244_item	2860166	et	3	main
kes	doc_767882159244_item	2860171	et	4	main
kaasa	doc_767882159244_item	2860181	et	4	main
need	doc_767882159244_item	2860182	et	3	main
laulud	doc_767882159244_item	2860183	et	3	main
on	doc_767882159244_item	2860184	et	4	main
teise	doc_767882159245_item	2860194	et	4	main
pikkus	doc_767882159245_item	2860206	et	4	main
esitatud	doc_767882159245_item	2860221	et	4	main
ja	doc_767882159245_item	2860237	et	3	main
tants	doc_767882159245_item	2860238	et	3	main
on	doc_767882159245_item	2860239	et	4	main
heal	doc_767882159245_item	2860245	et	3	main
ajal	doc_767882159245_item	2860246	et	4	main
me	doc_767882159245_item	2860248	et	4	main
teame	doc_767882159245_item	2860249	et	3	main
raske	doc_767882159245_item	2860273	et	4	main
uskuda	doc_767882159245_item	2860281	et	3	main
ja	doc_767882159245_item	2860283	et	3	main
eestlastele	doc_767882159245_item	2860294	et	4	main
usku	doc_767882159245_item	2860295	et	4	main
iga	doc_767882159245_item	2860312	et	4	main
ajal	doc_767882159245_item	2860316	et	4	main
kogunevad	doc_767882159245_item	2860318	et	4	main
inimesi	doc_767882159245_item	2860320	et	4	main
kirjutamine	doc_767882159244_item	2859962	et	4	main
kirjutage	doc_767882159244_item	2859963	et	3	main
pikkus	doc_767882159244_item	2859971	et	4	main
300	doc_767882159244_item	2859972	et	2	main
350	doc_767882159244_item	2859973	et	2	main
sõna	doc_767882159244_item	2859974	et	4	main
essee	doc_767882159244_item	2859975	et	4	main
peab	doc_767882159244_item	2859976	et	4	main
olema	doc_767882159244_item	2859977	et	4	main
arutlev	doc_767882159244_item	2859978	et	4	main
analüüsiv	doc_767882159244_item	2859979	et	4	main
ja	doc_767882159244_item	2859980	et	3	main
üldistav	doc_767882159244_item	2859981	et	4	main
tuginema	doc_767882159244_item	2859982	et	3	main
loengus	doc_767882159244_item	2859983	et	3	main
ja	doc_767882159244_item	2859984	et	3	main
lugemistekstis	doc_767882159244_item	2859985	et	3	main
esitatud	doc_767882159244_item	2859986	et	4	main
faktidele	doc_767882159244_item	2859987	et	3	main
väiteid	doc_767882159244_item	2859988	et	4	main
on	doc_767882159244_item	2859989	et	4	main
vanal	doc_767882159244_item	2859997	et	3	main
eestlased	doc_767882159244_item	2860007	et	3	main
sündisid	doc_767882159244_item	2860008	et	4	main
niisugused	doc_767882159244_item	2860017	et	3	main
tegevused	doc_767882159244_item	2860018	et	4	main
nagu	doc_767882159244_item	2860019	et	3	main
laulmine	doc_767882159244_item	2860020	et	4	main
tähtis	doc_767882159244_item	2860002	et	4	main
rahvalaulu	doc_767882159244_item	2860015	et	4	main
kaasnesid	doc_767882159244_item	2860016	et	4	main
töötades	doc_767882159244_item	2860023	et	3	main
ajalooga	doc_767882159244_item	2860037	et	4	main
rahvalauludes	doc_767882159244_item	2860038	et	3	main
räägitakse	doc_767882159244_item	2860039	et	3	main
muinasjutte	doc_767882159244_item	2860040	et	3	main
siis	doc_767882159244_item	2860041	et	3	main
kui	doc_767882159244_item	2860042	et	3	main
noored	doc_767882159244_item	2860043	et	3	main
omavahel	doc_767882159244_item	2860044	et	3	main
kokku	doc_767882159244_item	2860045	et	3	main
said	doc_767882159244_item	2860046	et	4	main
oma	doc_767882159244_item	2860050	et	4	main
lauludega	doc_767882159244_item	2860052	et	3	main
kirikus	doc_767882159244_item	2860053	et	3	main
lauldi	doc_767882159244_item	2860054	et	3	main
vaimulike	doc_767882159244_item	2860055	et	3	main
ja	doc_767882159244_item	2860074	et	3	main
regilaule	doc_767882159244_item	2860077	et	4	main
laulsid	doc_767882159244_item	2860078	et	4	main
naised	doc_767882159244_item	2860079	et	3	main
seda	doc_767882159244_item	2860080	et	3	main
nad	doc_767882159244_item	2860081	et	3	main
nad	doc_767882159244_item	2860088	et	3	main
ilma	doc_767882159244_item	2860090	et	4	main
1869	doc_767882159244_item	2860092	et	2	main
aastal	doc_767882159244_item	2860093	et	3	main
liikumise	doc_767882159244_item	2860123	et	4	main
ühtlasi	doc_767882159244_item	2860125	et	4	main
aluse	doc_767882159244_item	2860132	et	4	main
traditsioon	doc_767882159244_item	2860137	et	3	main
kandus	doc_767882159244_item	2860142	et	3	main
aastal	doc_767882159244_item	2860145	et	3	main
üks	doc_767882159244_item	2860150	et	3	main
kogu	doc_767882159244_item	2860159	et	4	main
tullakse	doc_767882159244_item	2860162	et	3	main
perega	doc_767882159244_item	2860164	et	3	main
sõpru	doc_767882159244_item	2860167	et	3	main
sugulasi	doc_767882159244_item	2860168	et	3	main
laulda	doc_767882159244_item	2860180	et	4	main
kujunenud	doc_767882159244_item	2860187	et	4	main
kirjutage	doc_767882159245_item	2860198	et	3	main
mis	doc_767882159245_item	2860201	et	4	main
teeb	doc_767882159245_item	2860202	et	3	main
eestlastest	doc_767882159245_item	2860203	et	4	main
laulurahva	doc_767882159245_item	2860204	et	3	main
essee	doc_767882159245_item	2860205	et	4	main
väiteid	doc_767882159245_item	2860223	et	4	main
eestlasi	doc_767882159245_item	2860241	et	3	main
maa	doc_767882159245_item	2860254	et	4	main
väga	doc_767882159245_item	2860272	et	3	main
aitasid	doc_767882159245_item	2860279	et	4	main
lootma	doc_767882159245_item	2860282	et	3	main
kinkisid	doc_767882159245_item	2860293	et	4	main
need	doc_767882159245_item	2860298	et	3	main
aitasid	doc_767882159245_item	2860299	et	4	main
ja	doc_767882159245_item	2860302	et	3	main
alates	doc_767882159245_item	2860304	et	3	main
eestis	doc_767882159245_item	2860307	et	3	main
laulupidu	doc_767882159245_item	2860309	et	4	main
laulupidu	doc_767882159245_item	2860310	et	4	main
toimub	doc_767882159245_item	2860311	et	3	main
kuid	doc_767882159245_item	2860322	et	4	main
tuli	doc_767882159245_item	2860333	et	4	main
minu	doc_767882159245_item	2860340	et	3	main
esimene	doc_767882159245_item	2860346	et	3	main
baltisaksa	doc_767882159245_item	2860361	et	4	main
linnas	doc_767882159245_item	2860364	et	4	main
elus	doc_767882159245_item	2860380	et	4	main
nagu	doc_767882159245_item	2860381	et	3	main
mina	doc_767882159245_item	2860382	et	4	main
juba	doc_767882159245_item	2860383	et	3	main
saatnud	doc_767882159245_item	2860386	et	4	main
eestlasi	doc_767882159245_item	2860387	et	3	main
koguaeg	doc_767882159245_item	2860388	et	3	main
nad	doc_767882159245_item	2860389	et	3	main
laulsid	doc_767882159245_item	2860390	et	4	main
töötades	doc_767882159245_item	2860391	et	3	main
kiigutades	doc_767882159245_item	2860396	et	3	main
last	doc_767882159244_item	2860025	et	4	main
laulavad	doc_767882159244_item	2860029	et	4	main
rahva	doc_767882159244_item	2860030	et	3	main
minevikus	doc_767882159244_item	2860031	et	3	main
mistõttu	doc_767882159244_item	2860032	et	3	main
on	doc_767882159244_item	2860033	et	4	main
ka	doc_767882159244_item	2860034	et	3	main
rahvalaulud	doc_767882159244_item	2860035	et	3	main
nad	doc_767882159244_item	2860048	et	3	main
vahel	doc_767882159244_item	2860051	et	4	main
kaks	doc_767882159244_item	2860070	et	3	main
tegid	doc_767882159244_item	2860082	et	4	main
kokku	doc_767882159244_item	2860083	et	3	main
saades	doc_767882159244_item	2860084	et	3	main
esimene	doc_767882159244_item	2860095	et	3	main
ülemaaline	doc_767882159244_item	2860096	et	4	main
laulupidu	doc_767882159244_item	2860097	et	4	main
mis	doc_767882159244_item	2860098	et	4	main
toimus	doc_767882159244_item	2860099	et	3	main
tartus	doc_767882159244_item	2860100	et	3	main
ja	doc_767882159244_item	2860101	et	3	main
mis	doc_767882159244_item	2860102	et	4	main
on	doc_767882159244_item	2860103	et	4	main
ajaloolise	doc_767882159244_item	2860104	et	4	main
tähtsusega	doc_767882159244_item	2860105	et	4	main
sündmus	doc_767882159244_item	2860106	et	3	main
laulupeo	doc_767882159244_item	2860107	et	4	main
korraldamise	doc_767882159244_item	2860108	et	4	main
idee	doc_767882159244_item	2860109	et	4	main
ja	doc_767882159244_item	2860110	et	3	main
teostus	doc_767882159244_item	2860111	et	4	main
tuli	doc_767882159244_item	2860112	et	4	main
vanemuise	doc_767882159244_item	2860113	et	4	main
seltsist	doc_767882159244_item	2860114	et	4	main
eesotsas	doc_767882159244_item	2860115	et	4	main
johann	doc_767882159244_item	2860116	et	4	main
voldemar	doc_767882159244_item	2860117	et	4	main
jannseniga	doc_767882159244_item	2860118	et	4	main
selles	doc_767882159244_item	2860119	et	4	main
kujunes	doc_767882159244_item	2860120	et	3	main
rahvusliku	doc_767882159244_item	2860122	et	3	main
üldlaulupidude	doc_767882159244_item	2860134	et	4	main
korraldamisele	doc_767882159244_item	2860135	et	4	main
aga	doc_767882159244_item	2860140	et	3	main
siia	doc_767882159244_item	2860161	et	4	main
koos	doc_767882159244_item	2860163	et	4	main
selleks	doc_767882159244_item	2860178	et	4	main
et	doc_767882159244_item	2860179	et	3	main
aja	doc_767882159244_item	2860186	et	4	main
essee	doc_767882159245_item	2860190	et	4	main
keele	doc_767882159245_item	2860192	et	4	main
keele	doc_767882159245_item	2860195	et	4	main
test	doc_767882159245_item	2860196	et	3	main
faktidele	doc_767882159245_item	2860222	et	3	main
on	doc_767882159245_item	2860224	et	4	main
pani	doc_767882159244_item	2860131	et	4	main
laulupidu	doc_767882159244_item	2860136	et	4	main
1896	doc_767882159244_item	2860144	et	2	main
suurem	doc_767882159244_item	2860151	et	4	main
sündmus	doc_767882159244_item	2860154	et	3	main
kus	doc_767882159244_item	2860155	et	3	main
kogunevad	doc_767882159244_item	2860156	et	4	main
eestist	doc_767882159244_item	2860160	et	3	main
tuttavaid	doc_767882159244_item	2860170	et	3	main
on	doc_767882159244_item	2860172	et	4	main
ka	doc_767882159244_item	2860174	et	3	main
välismaalt	doc_767882159244_item	2860175	et	3	main
rahvuslikeks	doc_767882159244_item	2860188	et	3	main
eesti	doc_767882159245_item	2860191	et	4	main
kui	doc_767882159245_item	2860193	et	3	main
essee	doc_767882159245_item	2860199	et	4	main
teemal	doc_767882159245_item	2860200	et	3	main
300	doc_767882159245_item	2860207	et	2	main
350	doc_767882159245_item	2860208	et	2	main
essee	doc_767882159245_item	2860210	et	4	main
sõna	doc_767882159245_item	2860209	et	4	main
peab	doc_767882159245_item	2860211	et	4	main
olema	doc_767882159245_item	2860212	et	4	main
arutlev	doc_767882159245_item	2860213	et	4	main
analüüsiv	doc_767882159245_item	2860214	et	4	main
ja	doc_767882159245_item	2860215	et	3	main
üldistav	doc_767882159245_item	2860216	et	4	main
tuginema	doc_767882159245_item	2860217	et	3	main
loengus	doc_767882159245_item	2860218	et	3	main
ja	doc_767882159245_item	2860219	et	3	main
lugemistekstis	doc_767882159245_item	2860220	et	3	main
oma	doc_767882159245_item	2860229	et	4	main
elu	doc_767882159245_item	2860230	et	4	main
eestlased	doc_767882159245_item	2860231	et	3	main
elasid	doc_767882159245_item	2860232	et	4	main
saatnud	doc_767882159245_item	2860240	et	4	main
halval	doc_767882159245_item	2860242	et	3	main
kuid	doc_767882159245_item	2860255	et	4	main
oma	doc_767882159245_item	2860256	et	4	main
iseseisvus	doc_767882159245_item	2860257	et	4	main
eesti	doc_767882159245_item	2860258	et	4	main
sai	doc_767882159245_item	2860259	et	4	main
esimene	doc_767882159245_item	2860260	et	3	main
kord	doc_767882159245_item	2860261	et	4	main
ainult	doc_767882159245_item	2860262	et	4	main
kahekümnenda	doc_767882159245_item	2860263	et	4	main
sajandi	doc_767882159245_item	2860264	et	3	main
alguses	doc_767882159245_item	2860265	et	4	main
sealt	doc_767882159245_item	2860266	et	4	main
võib	doc_767882159245_item	2860267	et	3	main
soovitatav	doc_767882159245_item	2860225	et	4	main
illustreerida	doc_767882159245_item	2860226	et	3	main
näidetega	doc_767882159245_item	2860227	et	3	main
laulade	doc_767882159245_item	2860233	et	4	main
ja	doc_767882159245_item	2860234	et	3	main
tantsidega	doc_767882159245_item	2860235	et	3	main
kui	doc_767882159245_item	2860243	et	3	main
praegu	doc_767882159245_item	2860247	et	3	main
on	doc_767882159245_item	2860252	et	4	main
iseseisev	doc_767882159245_item	2860253	et	3	main
oli	doc_767882159245_item	2860271	et	3	main
elu	doc_767882159245_item	2860274	et	4	main
kuid	doc_767882159245_item	2860275	et	4	main
eestlasi	doc_767882159245_item	2860280	et	3	main
oodata	doc_767882159245_item	2860284	et	4	main
millal	doc_767882159245_item	2860285	et	3	main
tuleb	doc_767882159245_item	2860286	et	3	main
uus	doc_767882159245_item	2860287	et	3	main
kergem	doc_767882159245_item	2860288	et	4	main
jõudu	doc_767882159245_item	2860297	et	4	main
inimestele	doc_767882159245_item	2860300	et	3	main
töötada	doc_767882159245_item	2860301	et	3	main
1869	doc_767882159245_item	2860305	et	2	main
tähistatakse	doc_767882159245_item	2860308	et	3	main
meie	doc_767882159245_item	2860315	et	4	main
tähistatud	doc_767882159245_item	2860327	et	4	main
tartus	doc_767882159245_item	2860328	et	3	main
selle	doc_767882159245_item	2860329	et	4	main
voldemar	doc_767882159245_item	2860338	et	4	main
võib	doc_767882159245_item	2860342	et	3	main
see	doc_767882159245_item	2860345	et	3	main
laulupidu	doc_767882159245_item	2860347	et	4	main
eestlaste	doc_767882159245_item	2860349	et	4	main
rahvuslik	doc_767882159245_item	2860350	et	3	main
ärkamine	doc_767882159245_item	2860351	et	4	main
19	doc_767882159245_item	2860352	et	2	main
sajandi	doc_767882159245_item	2860353	et	3	main
haridus-	doc_767882159245_item	2860357	et	3	main
muusikaseltse	doc_767882159245_item	2860359	et	3	main
maal	doc_767882159245_item	2860366	et	4	main
laulupidu	doc_767882159245_item	2860367	et	4	main
aitas	doc_767882159245_item	2860368	et	3	main
ütlesin	doc_767882159245_item	2860384	et	3	main
laulad	doc_767882159245_item	2860385	et	3	main
last	doc_767882159245_item	2860395	et	4	main
väga	doc_767882159245_item	2860400	et	3	main
ei	doc_767882159245_item	2860430	et	4	main
maailmas	doc_767882159245_item	2860443	et	3	main
konkursil	doc_767882159245_item	2860452	et	3	main
minu	doc_767882159245_item	2860461	et	3	main
saa	doc_767882159245_item	2860472	et	4	main
palju	doc_767882159245_item	2860485	et	4	main
põhjust	doc_767882159245_item	2860486	et	4	main
eestlaste	doc_767882159245_item	2860498	et	4	main
nendele	doc_767882159245_item	2860502	et	4	main
eestimaal	doc_767882159245_item	2860270	et	4	main
ja	doc_767882159245_item	2860296	et	3	main
elada	doc_767882159245_item	2860303	et	3	main
aasta	doc_767882159245_item	2860306	et	4	main
ülimaaline	doc_767882159245_item	2860324	et	4	main
laulupidu	doc_767882159245_item	2860325	et	4	main
oli	doc_767882159245_item	2860326	et	3	main
idee	doc_767882159245_item	2860332	et	4	main
seltsist	doc_767882159245_item	2860335	et	4	main
kogukonna	doc_767882159245_item	2860362	et	4	main
midagi	doc_767882159245_item	2860370	et	4	main
koos	doc_767882159245_item	2860371	et	4	main
ükski	doc_767882159245_item	2860393	et	4	main
olles	doc_767882159245_item	2860394	et	3	main
laulud	doc_767882159245_item	2860399	et	3	main
tea	doc_767882159245_item	2860431	et	4	main
muusikast	doc_767882159245_item	2860432	et	4	main
paar	doc_767882159245_item	2860444	et	3	main
tagasi	doc_767882159245_item	2860446	et	3	main
meie	doc_767882159245_item	2860448	et	4	main
eurovision	doc_767882159245_item	2860453	et	4	main
tol	doc_767882159245_item	2860454	et	3	main
ajal	doc_767882159245_item	2860455	et	4	main
ma	doc_767882159245_item	2860456	et	3	main
olin	doc_767882159245_item	2860457	et	3	main
väga	doc_767882159245_item	2860458	et	3	main
küsimustele	doc_767882159245_item	2860475	et	4	main
mis	doc_767882159245_item	2860476	et	4	main
teeb	doc_767882159245_item	2860477	et	3	main
ma	doc_767882159245_item	2860480	et	3	main
et	doc_767882159245_item	2860482	et	3	main
siin	doc_767882159245_item	2860484	et	4	main
mina	doc_767882159245_item	2860488	et	4	main
tantsid	doc_767882159245_item	2860494	et	4	main
ja	doc_767882159245_item	2860500	et	3	main
elada	doc_767882159245_item	2860503	et	3	main
tallinnas	doc_767882159245_item	2860321	et	4	main
esimene	doc_767882159245_item	2860323	et	3	main
peo	doc_767882159245_item	2860330	et	4	main
vanemuise	doc_767882159245_item	2860334	et	4	main
eesotsas	doc_767882159245_item	2860336	et	4	main
johann	doc_767882159245_item	2860337	et	4	main
arvates	doc_767882159245_item	2860341	et	4	main
et	doc_767882159245_item	2860344	et	3	main
lõpupoole	doc_767882159245_item	2860354	et	4	main
loodi	doc_767882159245_item	2860360	et	4	main
eeskujul	doc_767882159245_item	2860363	et	3	main
kui	doc_767882159245_item	2860365	et	3	main
tegema	doc_767882159245_item	2860372	et	3	main
see	doc_767882159245_item	2860373	et	3	main
pidu	doc_767882159245_item	2860374	et	4	main
oli	doc_767882159245_item	2860375	et	3	main
väga	doc_767882159245_item	2860376	et	3	main
suur	doc_767882159245_item	2860377	et	3	main
rõõmus	doc_767882159245_item	2860378	et	4	main
meelest	doc_767882159245_item	2860398	et	4	main
tähtsid	doc_767882159245_item	2860401	et	4	main
eestlastele	doc_767882159245_item	2860402	et	4	main
ma	doc_767882159245_item	2860403	et	3	main
arvan	doc_767882159245_item	2860404	et	3	main
et	doc_767882159245_item	2860405	et	3	main
eestlased	doc_767882159245_item	2860406	et	3	main
on	doc_767882159245_item	2860407	et	4	main
väga	doc_767882159245_item	2860408	et	3	main
muusikaline	doc_767882159245_item	2860409	et	4	main
rahvas	doc_767882159245_item	2860410	et	4	main
tänapäeval	doc_767882159245_item	2860411	et	3	main
eesti	doc_767882159245_item	2860412	et	4	main
muusika	doc_767882159245_item	2860413	et	4	main
on	doc_767882159245_item	2860414	et	4	main
kõrgel	doc_767882159245_item	2860415	et	4	main
tasemel	doc_767882159245_item	2860416	et	3	main
kahjuks	doc_767882159245_item	2860417	et	4	main
mind	doc_767882159245_item	2860418	et	4	main
üldse	doc_767882159245_item	2860419	et	3	main
ei	doc_767882159245_item	2860420	et	4	main
huvita	doc_767882159245_item	2860421	et	4	main
nii	doc_767882159245_item	2860423	et	3	main
kuulus	doc_767882159245_item	2860441	et	4	main
aastat	doc_767882159245_item	2860445	et	3	main
rõõmus	doc_767882159245_item	2860459	et	4	main
arvates	doc_767882159245_item	2860462	et	4	main
laul	doc_767882159245_item	2860464	et	4	main
tõesti	doc_767882159245_item	2860465	et	3	main
oli	doc_767882159245_item	2860466	et	3	main
eestlastest	doc_767882159245_item	2860478	et	4	main
on	doc_767882159245_item	2860483	et	4	main
saan	doc_767882159245_item	2860490	et	4	main
ööelda	doc_767882159245_item	2860491	et	4	main
et	doc_767882159245_item	2860492	et	3	main
südades	doc_767882159245_item	2860499	et	4	main
eestlaste	doc_767882159245_item	2860379	et	4	main
kodus	doc_767882159245_item	2860392	et	4	main
minu	doc_767882159245_item	2860397	et	3	main
muusika	doc_767882159245_item	2860422	et	4	main
eesti	doc_767882159245_item	2860424	et	4	main
kui	doc_767882159245_item	2860425	et	3	main
ka	doc_767882159245_item	2860426	et	3	main
vene	doc_767882159245_item	2860427	et	4	main
ja	doc_767882159245_item	2860428	et	3	main
ma	doc_767882159245_item	2860429	et	3	main
üks	doc_767882159245_item	2860437	et	3	main
eesti	doc_767882159245_item	2860438	et	4	main
derižor	doc_767882159245_item	2860439	et	2	main
väga	doc_767882159245_item	2860440	et	3	main
üks	doc_767882159245_item	2860447	et	3	main
eesti	doc_767882159245_item	2860449	et	4	main
ansambel	doc_767882159245_item	2860450	et	3	main
võttis	doc_767882159245_item	2860451	et	3	main
sest	doc_767882159245_item	2860460	et	4	main
see	doc_767882159245_item	2860463	et	3	main
täpselt	doc_767882159245_item	2860473	et	4	main
vastata	doc_767882159245_item	2860474	et	4	main
laulurahva	doc_767882159245_item	2860479	et	3	main
arvan	doc_767882159245_item	2860481	et	3	main
kuid	doc_767882159245_item	2860487	et	4	main
täpselt	doc_767882159245_item	2860489	et	4	main
laulad	doc_767882159245_item	2860493	et	3	main
ja	doc_767882159245_item	2860495	et	3	main
palju	doc_767882159245_item	2860433	et	4	main
aga	doc_767882159245_item	2860434	et	3	main
tean	doc_767882159245_item	2860435	et	3	main
et	doc_767882159245_item	2860436	et	3	main
kogu	doc_767882159245_item	2860442	et	4	main
kõige	doc_767882159245_item	2860467	et	4	main
parem	doc_767882159245_item	2860468	et	4	main
konkursil	doc_767882159245_item	2860469	et	3	main
ma	doc_767882159245_item	2860470	et	3	main
ei	doc_767882159245_item	2860471	et	4	main
muusika	doc_767882159245_item	2860496	et	4	main
istuvad	doc_767882159245_item	2860497	et	4	main
aitavad	doc_767882159245_item	2860501	et	4	main
keele	doc_767882159249_item	2861363	et	4	main
essee	doc_767882159249_item	2861367	et	4	main
kirjutamine	doc_767882159249_item	2861365	et	4	main
on	doc_767882159249_item	2861392	et	4	main
illustreerida	doc_767882159249_item	2861394	et	3	main
ajast	doc_767882159249_item	2861420	et	4	main
teise	doc_767882159249_item	2861362	et	4	main
teemal	doc_767882159249_item	2861368	et	3	main
poolt	doc_767882159249_item	2861401	et	4	main
on	doc_767882159249_item	2861402	et	4	main
see	doc_767882159249_item	2861403	et	3	main
lihtne	doc_767882159249_item	2861404	et	3	main
küsimus	doc_767882159249_item	2861405	et	4	main
ja	doc_767882159249_item	2861406	et	3	main
me	doc_767882159249_item	2861407	et	4	main
ja	doc_767882159249_item	2861424	et	3	main
aga	doc_767882159249_item	2861426	et	3	main
peame	doc_767882159249_item	2861433	et	4	main
pöörduma	doc_767882159249_item	2861434	et	3	main
laulamine	doc_767882159249_item	2861446	et	4	main
see	doc_767882159249_item	2861449	et	3	main
on	doc_767882159249_item	2861450	et	4	main
eesti	doc_767882159249_item	2861455	et	4	main
rahva	doc_767882159249_item	2861456	et	3	main
tugivamaid	doc_767882159249_item	2861471	et	4	main
ja	doc_767882159249_item	2861472	et	3	main
vanemat	doc_767882159249_item	2861476	et	4	main
regivärsiline	doc_767882159249_item	2861479	et	4	main
rahvalaul	doc_767882159249_item	2861480	et	4	main
sellest	doc_767882159249_item	2861481	et	4	main
algas	doc_767882159249_item	2861482	et	3	main
oli	doc_767882159249_item	2861486	et	3	main
esindus	doc_767882159249_item	2861489	et	4	main
eeslaulja	doc_767882159249_item	2861490	et	4	main
oli	doc_767882159249_item	2861499	et	3	main
käsitööd	doc_767882159249_item	2861507	et	4	main
mõnikord	doc_767882159249_item	2861510	et	3	main
mehed	doc_767882159249_item	2861513	et	3	main
olid	doc_767882159249_item	2861524	et	4	main
nende	doc_767882159249_item	2861526	et	4	main
lauldi	doc_767882159249_item	2861527	et	3	main
teistmoodi	doc_767882159249_item	2861528	et	3	main
inimesed	doc_767882159249_item	2861529	et	3	main
kasutasid	doc_767882159249_item	2861530	et	4	main
kui	doc_767882159249_item	2861540	et	3	main
varem	doc_767882159249_item	2861541	et	4	main
essee	doc_767882159249_item	2861358	et	4	main
eesti	doc_767882159249_item	2861359	et	4	main
keele	doc_767882159249_item	2861360	et	4	main
kui	doc_767882159249_item	2861361	et	3	main
test	doc_767882159249_item	2861364	et	3	main
kirjutage	doc_767882159249_item	2861366	et	3	main
mis	doc_767882159249_item	2861369	et	4	main
soovitatav	doc_767882159249_item	2861393	et	4	main
mis	doc_767882159249_item	2861396	et	4	main
teeb	doc_767882159249_item	2861397	et	3	main
eestlastest	doc_767882159249_item	2861398	et	4	main
laulurahva	doc_767882159249_item	2861399	et	3	main
ühelt	doc_767882159249_item	2861400	et	3	main
võime	doc_767882159249_item	2861408	et	4	main
vastata	doc_767882159249_item	2861411	et	4	main
eestlased	doc_767882159249_item	2861413	et	3	main
täpselt	doc_767882159249_item	2861430	et	4	main
kultuurisee	doc_767882159249_item	2861437	et	4	main
parandab	doc_767882159249_item	2861447	et	3	main
tähtis	doc_767882159249_item	2861452	et	4	main
raskel	doc_767882159249_item	2861453	et	3	main
ajal	doc_767882159249_item	2861454	et	4	main
eestlased	doc_767882159249_item	2861467	et	3	main
laulsid	doc_767882159249_item	2861468	et	4	main
et	doc_767882159249_item	2861469	et	3	main
olla	doc_767882159249_item	2861470	et	3	main
laulas	doc_767882159249_item	2861491	et	4	main
ja	doc_767882159249_item	2861492	et	3	main
arenes	doc_767882159249_item	2861493	et	3	main
aga	doc_767882159249_item	2861509	et	3	main
uued	doc_767882159249_item	2861522	et	3	main
näiteks	doc_767882159249_item	2861532	et	4	main
sõnad	doc_767882159249_item	2861537	et	4	main
olid	doc_767882159249_item	2861538	et	4	main
mõjusid	doc_767882159249_item	2861544	et	4	main
kiriklaulud	doc_767882159249_item	2861545	et	3	main
tänapäeval	doc_767882159249_item	2861546	et	3	main
võib	doc_767882159249_item	2861550	et	3	main
oma	doc_767882159249_item	2861562	et	4	main
see	doc_767882159249_item	2861564	et	3	main
mõned	doc_767882159249_item	2861602	et	3	main
rahvamuusikat	doc_767882159249_item	2861607	et	3	main
on	doc_767882159249_item	2861609	et	4	main
ansambleid	doc_767882159249_item	2861611	et	3	main
käivad	doc_767882159249_item	2861616	et	4	main
teeb	doc_767882159249_item	2861370	et	3	main
eestlastest	doc_767882159249_item	2861371	et	4	main
laulurahva	doc_767882159249_item	2861372	et	3	main
essee	doc_767882159249_item	2861373	et	4	main
pikkus	doc_767882159249_item	2861374	et	4	main
300	doc_767882159249_item	2861375	et	2	main
350	doc_767882159249_item	2861376	et	2	main
sõna	doc_767882159249_item	2861377	et	4	main
essee	doc_767882159249_item	2861378	et	4	main
peab	doc_767882159249_item	2861379	et	4	main
olema	doc_767882159249_item	2861380	et	4	main
arutlev	doc_767882159249_item	2861381	et	4	main
analüüsiv	doc_767882159249_item	2861382	et	4	main
ja	doc_767882159249_item	2861383	et	3	main
üldistav	doc_767882159249_item	2861384	et	4	main
tuginema	doc_767882159249_item	2861385	et	3	main
loengus	doc_767882159249_item	2861386	et	3	main
ja	doc_767882159249_item	2861387	et	3	main
lugemistekstis	doc_767882159249_item	2861388	et	3	main
esitatud	doc_767882159249_item	2861389	et	4	main
faktidele	doc_767882159249_item	2861390	et	3	main
väiteid	doc_767882159249_item	2861391	et	4	main
näidetega	doc_767882159249_item	2861395	et	3	main
hetkel	doc_767882159249_item	2861410	et	4	main
on	doc_767882159249_item	2861414	et	4	main
väga	doc_767882159249_item	2861415	et	3	main
musikaalne	doc_767882159249_item	2861416	et	3	main
rahvas	doc_767882159249_item	2861417	et	4	main
ja	doc_767882159249_item	2861418	et	3	main
vanast	doc_767882159249_item	2861419	et	3	main
laulavad	doc_767882159249_item	2861422	et	4	main
kodus	doc_767882159249_item	2861423	et	4	main
tööl	doc_767882159249_item	2861425	et	3	main
teiselt	doc_767882159249_item	2861427	et	4	main
poolt	doc_767882159249_item	2861428	et	4	main
et	doc_767882159249_item	2861429	et	3	main
ajaloosse	doc_767882159249_item	2861435	et	4	main
ja	doc_767882159249_item	2861436	et	3	main
ajad	doc_767882159249_item	2861460	et	4	main
valitsesid	doc_767882159249_item	2861464	et	4	main
tuju	doc_767882159249_item	2861474	et	4	main
eesti	doc_767882159249_item	2861475	et	4	main
nimetatakse	doc_767882159249_item	2861478	et	3	main
laulamine	doc_767882159249_item	2861484	et	4	main
vokaalne	doc_767882159249_item	2861488	et	3	main
koor	doc_767882159249_item	2861496	et	4	main
kordas	doc_767882159249_item	2861497	et	3	main
või	doc_767882159249_item	2861506	et	4	main
muusikainstrumentid	doc_767882159249_item	2861531	et	4	main
kannel	doc_767882159249_item	2861536	et	4	main
sest	doc_767882159249_item	2861542	et	4	main
kadunud	doc_767882159249_item	2861549	et	4	main
olla	doc_767882159249_item	2861551	et	3	main
saaredel	doc_767882159249_item	2861553	et	4	main
näiteks	doc_767882159249_item	2861590	et	4	main
nissugused	doc_767882159249_item	2861591	et	4	main
bas	doc_767882159249_item	2861600	et	4	main
ja	doc_767882159249_item	2861603	et	3	main
mängivad	doc_767882159249_item	2861613	et	4	main
leiavad	doc_767882159249_item	2861618	et	3	main
vanalaulu	doc_767882159249_item	2861620	et	4	main
on	doc_767882159249_item	2861632	et	4	main
noored	doc_767882159249_item	2861633	et	3	main
traditsioonid	doc_767882159249_item	2861637	et	3	main
käivad	doc_767882159249_item	2861638	et	4	main
põlvest	doc_767882159249_item	2861639	et	4	main
mitmesugused	doc_767882159249_item	2861643	et	3	main
viljandi	doc_767882159249_item	2861652	et	4	main
ma	doc_767882159249_item	2861657	et	3	main
pean	doc_767882159249_item	2861658	et	4	main
laulupeost	doc_767882159249_item	2861661	et	4	main
et	doc_767882159249_item	2861667	et	3	main
laulda	doc_767882159249_item	2861671	et	4	main
osad	doc_767882159249_item	2861679	et	3	main
oli	doc_767882159249_item	2861682	et	3	main
tartust	doc_767882159249_item	2861685	et	3	main
see	doc_767882159249_item	2861687	et	3	main
on	doc_767882159249_item	2861689	et	4	main
tänapäeval	doc_767882159249_item	2861693	et	3	main
muusikakoolis	doc_767882159249_item	2861701	et	4	main
et	doc_767882159249_item	2861702	et	3	main
osaleda	doc_767882159249_item	2861703	et	3	main
laulupeos	doc_767882159249_item	2861704	et	4	main
mina	doc_767882159249_item	2861705	et	4	main
laulupeos	doc_767882159249_item	2861709	et	4	main
see	doc_767882159249_item	2861710	et	3	main
kõik	doc_767882159249_item	2861721	et	4	main
väga	doc_767882159249_item	2861723	et	3	main
laulamine	doc_767882159249_item	2861729	et	4	main
ühineb	doc_767882159249_item	2861730	et	3	main
inimesi	doc_767882159249_item	2861731	et	4	main
eestlased	doc_767882159249_item	2861732	et	3	main
tunnevad	doc_767882159249_item	2861733	et	3	main
et	doc_767882159249_item	2861734	et	3	main
sel	doc_767882159249_item	2861409	et	3	main
et	doc_767882159249_item	2861412	et	3	main
nad	doc_767882159249_item	2861421	et	3	main
me	doc_767882159249_item	2861432	et	4	main
eriti	doc_767882159249_item	2861451	et	3	main
olid	doc_767882159249_item	2861458	et	4	main
rasked	doc_767882159249_item	2861459	et	3	main
kui	doc_767882159249_item	2861461	et	3	main
tõsta	doc_767882159249_item	2861473	et	4	main
eesti	doc_767882159249_item	2861483	et	4	main
laulu	doc_767882159249_item	2861494	et	4	main
aga	doc_767882159249_item	2861495	et	3	main
see	doc_767882159249_item	2861498	et	3	main
rohkem	doc_767882159249_item	2861502	et	4	main
tehes	doc_767882159249_item	2861508	et	3	main
laulasid	doc_767882159249_item	2861511	et	4	main
ka	doc_767882159249_item	2861512	et	3	main
ja	doc_767882159249_item	2861521	et	3	main
rahvalaulud	doc_767882159249_item	2861523	et	3	main
vene	doc_767882159249_item	2861533	et	4	main
sellesse	doc_767882159249_item	2861543	et	4	main
on	doc_767882159249_item	2861548	et	4	main
ainult	doc_767882159249_item	2861552	et	4	main
näiteks	doc_767882159249_item	2861554	et	4	main
kihnul	doc_767882159249_item	2861555	et	3	main
naised	doc_767882159249_item	2861556	et	3	main
laulavad	doc_767882159249_item	2861557	et	4	main
seda	doc_767882159249_item	2861558	et	3	main
igal	doc_767882159249_item	2861559	et	3	main
rahval	doc_767882159249_item	2861560	et	3	main
kultuur	doc_767882159249_item	2861563	et	3	main
palju	doc_767882159249_item	2861587	et	4	main
hip-hop	doc_767882159249_item	2861597	et	4	main
kuulavad	doc_767882159249_item	2861606	et	4	main
palju	doc_767882159249_item	2861610	et	4	main
mis	doc_767882159249_item	2861612	et	4	main
arhiivides	doc_767882159249_item	2861617	et	3	main
sealt	doc_767882159249_item	2861619	et	4	main
mängida	doc_767882159249_item	2861623	et	3	main
on	doc_767882159249_item	2861625	et	4	main
hea	doc_767882159249_item	2861627	et	4	main
nähtus	doc_767882159249_item	2861628	et	4	main
et	doc_767882159249_item	2861629	et	3	main
mõned	doc_767882159249_item	2861630	et	3	main
musikaantid	doc_767882159249_item	2861631	et	4	main
korraldatakse	doc_767882159249_item	2861642	et	3	main
ma	doc_767882159249_item	2861646	et	3	main
aru	doc_767882159249_item	2861648	et	4	main
kõige	doc_767882159249_item	2861649	et	4	main
tundub	doc_767882159249_item	2861650	et	3	main
on	doc_767882159249_item	2861651	et	4	main
üüritustest	doc_767882159249_item	2861655	et	4	main
eesti	doc_767882159249_item	2861660	et	4	main
selle	doc_767882159249_item	2861662	et	4	main
peo	doc_767882159249_item	2861663	et	4	main
sellest	doc_767882159249_item	2861666	et	4	main
meeldib	doc_767882159249_item	2861670	et	3	main
nendele	doc_767882159249_item	2861672	et	4	main
see	doc_767882159249_item	2861673	et	3	main
on	doc_767882159249_item	2861674	et	4	main
esimene	doc_767882159249_item	2861680	et	3	main
aastal	doc_767882159249_item	2861684	et	3	main
traditsioon	doc_767882159249_item	2861688	et	3	main
väga	doc_767882159249_item	2861690	et	3	main
inimesi	doc_767882159249_item	2861695	et	4	main
ükskord	doc_767882159249_item	2861708	et	3	main
on	doc_767882159249_item	2861711	et	4	main
aru	doc_767882159249_item	2861727	et	4	main
on	doc_767882159249_item	2861736	et	4	main
vastata	doc_767882159249_item	2861431	et	4	main
seda	doc_767882159249_item	2861438	et	3	main
ma	doc_767882159249_item	2861439	et	3	main
tahaks	doc_767882159249_item	2861440	et	3	main
teha	doc_767882159249_item	2861441	et	3	main
üldiselt	doc_767882159249_item	2861442	et	4	main
võin	doc_767882159249_item	2861443	et	3	main
öelda	doc_767882159249_item	2861444	et	4	main
et	doc_767882159249_item	2861445	et	3	main
meleolu	doc_767882159249_item	2861448	et	4	main
ajaloos	doc_767882159249_item	2861457	et	4	main
teised	doc_767882159249_item	2861462	et	4	main
riigid	doc_767882159249_item	2861463	et	3	main
eestis	doc_767882159249_item	2861465	et	3	main
muidugi	doc_767882159249_item	2861466	et	4	main
rahvalaulu	doc_767882159249_item	2861477	et	4	main
see	doc_767882159249_item	2861485	et	3	main
ainult	doc_767882159249_item	2861487	et	4	main
koos	doc_767882159249_item	2861500	et	4	main
liikumisega	doc_767882159249_item	2861501	et	4	main
laulasid	doc_767882159249_item	2861503	et	4	main
naised	doc_767882159249_item	2861504	et	3	main
kodutööd	doc_767882159249_item	2861505	et	4	main
näiteks	doc_767882159249_item	2861514	et	4	main
pulmas	doc_767882159249_item	2861515	et	3	main
aga	doc_767882159249_item	2861516	et	3	main
kõik	doc_767882159249_item	2861517	et	4	main
meie	doc_767882159249_item	2861518	et	4	main
elus	doc_767882159249_item	2861519	et	4	main
areneb	doc_767882159249_item	2861520	et	3	main
teised	doc_767882159249_item	2861525	et	4	main
bajan	doc_767882159249_item	2861534	et	4	main
või	doc_767882159249_item	2861535	et	4	main
tõsisemad	doc_767882159249_item	2861539	et	4	main
on	doc_767882159249_item	2861561	et	4	main
tähendab	doc_767882159249_item	2861565	et	3	main
oma	doc_767882159249_item	2861566	et	4	main
laulud	doc_767882159249_item	2861567	et	3	main
teosed	doc_767882159249_item	2861568	et	3	main
kangelased	doc_767882159249_item	2861569	et	3	main
võin	doc_767882159249_item	2861570	et	3	main
öelda	doc_767882159249_item	2861571	et	4	main
et	doc_767882159249_item	2861572	et	3	main
kultuur	doc_767882159249_item	2861573	et	3	main
teeb	doc_767882159249_item	2861574	et	3	main
rahvast	doc_767882159249_item	2861575	et	4	main
omapäraseks	doc_767882159249_item	2861576	et	4	main
arvan	doc_767882159249_item	2861577	et	3	main
et	doc_767882159249_item	2861578	et	3	main
eestlastest	doc_767882159249_item	2861579	et	4	main
teeb	doc_767882159249_item	2861580	et	3	main
lauarahva	doc_767882159249_item	2861581	et	3	main
see	doc_767882159249_item	2861582	et	3	main
et	doc_767882159249_item	2861583	et	3	main
tänapäeval	doc_767882159249_item	2861584	et	3	main
kui	doc_767882159249_item	2861585	et	3	main
regirahvalaulud	doc_767882159249_item	2861547	et	3	main
on	doc_767882159249_item	2861586	et	4	main
uued	doc_767882159249_item	2861592	et	3	main
ja	doc_767882159249_item	2861593	et	3	main
moodsad	doc_767882159249_item	2861594	et	3	main
stiilid	doc_767882159249_item	2861595	et	4	main
drum	doc_767882159249_item	2861598	et	4	main
eestlased	doc_767882159249_item	2861605	et	3	main
inimesed	doc_767882159249_item	2861615	et	3	main
need	doc_767882159249_item	2861622	et	3	main
see	doc_767882159249_item	2861624	et	3	main
väga	doc_767882159249_item	2861626	et	3	main
see	doc_767882159249_item	2861634	et	3	main
tähendab	doc_767882159249_item	2861635	et	3	main
muidugi	doc_767882159249_item	2861656	et	4	main
rääkib	doc_767882159249_item	2861665	et	4	main
kultuuri	doc_767882159249_item	2861678	et	4	main
laulupidu	doc_767882159249_item	2861681	et	4	main
aga	doc_767882159249_item	2861686	et	3	main
oluline	doc_767882159249_item	2861691	et	4	main
palju	doc_767882159249_item	2861694	et	4	main
erinevates	doc_767882159249_item	2861696	et	4	main
linnades	doc_767882159249_item	2861697	et	3	main
laulavad	doc_767882159249_item	2861698	et	4	main
seal	doc_767882159249_item	2861714	et	4	main
oli	doc_767882159249_item	2861715	et	3	main
nii	doc_767882159249_item	2861716	et	3	main
et	doc_767882159249_item	2861728	et	3	main
üks	doc_767882159249_item	2861737	et	3	main
erinevaid	doc_767882159249_item	2861588	et	4	main
muusikastiili	doc_767882159249_item	2861589	et	4	main
nagu	doc_767882159249_item	2861596	et	3	main
and	doc_767882159249_item	2861599	et	3	main
alternative	doc_767882159249_item	2861601	et	4	main
mõned	doc_767882159249_item	2861604	et	3	main
tänapäeval	doc_767882159249_item	2861608	et	3	main
rahvamuusikat	doc_767882159249_item	2861614	et	3	main
et	doc_767882159249_item	2861621	et	3	main
põlve	doc_767882159249_item	2861640	et	4	main
tänapäeval	doc_767882159249_item	2861641	et	3	main
folkloorfestival	doc_767882159249_item	2861653	et	4	main
rääkides	doc_767882159249_item	2861654	et	4	main
ütlema	doc_767882159249_item	2861659	et	3	main
eestlastele	doc_767882159249_item	2861668	et	4	main
väga	doc_767882159249_item	2861669	et	3	main
teised	doc_767882159249_item	2861677	et	4	main
1869	doc_767882159249_item	2861683	et	2	main
kooris	doc_767882159249_item	2861699	et	4	main
ise	doc_767882159249_item	2861706	et	4	main
unustamatu	doc_767882159249_item	2861712	et	4	main
mulje	doc_767882159249_item	2861713	et	4	main
et	doc_767882159249_item	2861636	et	3	main
muusikaüüritused	doc_767882159249_item	2861644	et	4	main
nagu	doc_767882159249_item	2861645	et	3	main
sain	doc_767882159249_item	2861647	et	3	main
olemasolu	doc_767882159249_item	2861664	et	4	main
tähtis	doc_767882159249_item	2861675	et	4	main
kui	doc_767882159249_item	2861676	et	3	main
ka	doc_767882159249_item	2861692	et	3	main
käivad	doc_767882159249_item	2861700	et	4	main
olin	doc_767882159249_item	2861707	et	3	main
palju	doc_767882159249_item	2861717	et	4	main
inimesi	doc_767882159249_item	2861718	et	4	main
kõik	doc_767882159249_item	2861719	et	4	main
laulasid	doc_767882159249_item	2861720	et	4	main
õnelikud	doc_767882159249_item	2861724	et	4	main
seal	doc_767882159249_item	2861725	et	4	main
sain	doc_767882159249_item	2861726	et	3	main
nad	doc_767882159249_item	2861735	et	3	main
olid	doc_767882159249_item	2861722	et	4	main
rahvas	doc_767882159249_item	2861738	et	4	main
laulurahvas	doc_767882159249_item	2861739	et	4	main
pikkus	doc_767882159252_item	2862221	et	4	main
sõna	doc_767882159252_item	2862224	et	4	main
essee	doc_767882159252_item	2862225	et	4	main
peab	doc_767882159252_item	2862226	et	4	main
tuginema	doc_767882159252_item	2862232	et	3	main
loengus	doc_767882159252_item	2862233	et	3	main
ja	doc_767882159252_item	2862234	et	3	main
lugemistekstis	doc_767882159252_item	2862235	et	3	main
esitatud	doc_767882159252_item	2862236	et	4	main
faktidele	doc_767882159252_item	2862237	et	3	main
näidetega	doc_767882159252_item	2862242	et	3	main
on	doc_767882159252_item	2862244	et	4	main
350	doc_767882159252_item	2862223	et	2	main
on	doc_767882159252_item	2862239	et	4	main
nagu	doc_767882159252_item	2862245	et	3	main
mul	doc_767882159252_item	2862265	et	3	main
selle	doc_767882159252_item	2862267	et	4	main
kohta	doc_767882159252_item	2862269	et	4	main
loogiline	doc_767882159252_item	2862270	et	4	main
küsimus	doc_767882159252_item	2862271	et	4	main
kultuur	doc_767882159252_item	2862282	et	3	main
koosneb	doc_767882159252_item	2862283	et	3	main
eesti	doc_767882159252_item	2862290	et	4	main
sellega	doc_767882159252_item	2862295	et	3	main
essee	doc_767882159252_item	2862205	et	4	main
eesti	doc_767882159252_item	2862206	et	4	main
keele	doc_767882159252_item	2862207	et	4	main
kui	doc_767882159252_item	2862208	et	3	main
teise	doc_767882159252_item	2862209	et	4	main
keele	doc_767882159252_item	2862210	et	4	main
test	doc_767882159252_item	2862211	et	3	main
kirjutamine	doc_767882159252_item	2862212	et	4	main
kirjutage	doc_767882159252_item	2862213	et	3	main
essee	doc_767882159252_item	2862214	et	4	main
teemal	doc_767882159252_item	2862215	et	3	main
mis	doc_767882159252_item	2862216	et	4	main
teeb	doc_767882159252_item	2862217	et	3	main
eestlastest	doc_767882159252_item	2862218	et	4	main
laulurahva	doc_767882159252_item	2862219	et	3	main
essee	doc_767882159252_item	2862220	et	4	main
arutlev	doc_767882159252_item	2862228	et	4	main
300	doc_767882159252_item	2862222	et	2	main
väiteid	doc_767882159252_item	2862238	et	4	main
eestlastel	doc_767882159252_item	2862243	et	4	main
omapärane	doc_767882159252_item	2862251	et	4	main
kultuur	doc_767882159252_item	2862252	et	3	main
väga	doc_767882159252_item	2862253	et	3	main
tihti	doc_767882159252_item	2862254	et	3	main
võib	doc_767882159252_item	2862255	et	3	main
oma	doc_767882159252_item	2862262	et	4	main
miks	doc_767882159252_item	2862272	et	4	main
ei	doc_767882159252_item	2862273	et	4	main
eesti	doc_767882159252_item	2862281	et	4	main
saksa	doc_767882159252_item	2862286	et	4	main
ole	doc_767882159252_item	2862294	et	4	main
ammu	doc_767882159252_item	2862321	et	4	main
kodus	doc_767882159252_item	2862330	et	4	main
laulurahv	doc_767882159252_item	2862338	et	4	main
eestlased	doc_767882159252_item	2862339	et	3	main
laulaga	doc_767882159252_item	2862346	et	4	main
on	doc_767882159252_item	2862355	et	4	main
meie	doc_767882159252_item	2862358	et	4	main
võib-olla	doc_767882159252_item	2862360	et	3	main
need	doc_767882159252_item	2862361	et	3	main
nad	doc_767882159252_item	2862367	et	3	main
eestlastel	doc_767882159252_item	2862370	et	4	main
laulukultuur	doc_767882159252_item	2862373	et	3	main
veel	doc_767882159252_item	2862377	et	4	main
kõik	doc_767882159252_item	2862380	et	4	main
need	doc_767882159252_item	2862381	et	3	main
valed	doc_767882159252_item	2862382	et	3	main
omanikud	doc_767882159252_item	2862383	et	3	main
sakslased	doc_767882159252_item	2862384	et	3	main
rootslased	doc_767882159252_item	2862385	et	3	main
võib-olla	doc_767882159252_item	2862393	et	3	main
sellepärast	doc_767882159252_item	2862394	et	3	main
ei	doc_767882159252_item	2862401	et	4	main
saab	doc_767882159252_item	2862411	et	3	main
aru	doc_767882159252_item	2862412	et	4	main
et	doc_767882159252_item	2862413	et	3	main
laulurahv	doc_767882159252_item	2862416	et	4	main
et	doc_767882159252_item	2862418	et	3	main
olema	doc_767882159252_item	2862227	et	4	main
illustreerida	doc_767882159252_item	2862241	et	3	main
kuulata	doc_767882159252_item	2862256	et	4	main
arvamust	doc_767882159252_item	2862257	et	3	main
ole	doc_767882159252_item	2862261	et	4	main
ja	doc_767882159252_item	2862264	et	3	main
arvamuste	doc_767882159252_item	2862268	et	3	main
kõik	doc_767882159252_item	2862280	et	4	main
kulturist	doc_767882159252_item	2862287	et	4	main
nagu	doc_767882159252_item	2862289	et	3	main
ma	doc_767882159252_item	2862292	et	3	main
nõus	doc_767882159252_item	2862296	et	4	main
väga	doc_767882159252_item	2862297	et	3	main
tihti	doc_767882159252_item	2862298	et	3	main
koolis	doc_767882159252_item	2862299	et	4	main
oma	doc_767882159252_item	2862300	et	4	main
õpikutes	doc_767882159252_item	2862301	et	3	main
ma	doc_767882159252_item	2862302	et	3	main
nägin	doc_767882159252_item	2862303	et	3	main
sõna	doc_767882159252_item	2862304	et	4	main
laulurahv	doc_767882159252_item	2862305	et	4	main
ja	doc_767882159252_item	2862306	et	3	main
ainult	doc_767882159252_item	2862307	et	4	main
pärast	doc_767882159252_item	2862308	et	4	main
kui	doc_767882159252_item	2862309	et	3	main
ma	doc_767882159252_item	2862310	et	3	main
sooritasin	doc_767882159252_item	2862311	et	3	main
ajaloo	doc_767882159252_item	2862312	et	4	main
eksamit	doc_767882159252_item	2862313	et	3	main
ma	doc_767882159252_item	2862314	et	3	main
saan	doc_767882159252_item	2862315	et	4	main
aru	doc_767882159252_item	2862316	et	4	main
mida	doc_767882159252_item	2862317	et	4	main
see	doc_767882159252_item	2862318	et	3	main
tähendab	doc_767882159252_item	2862319	et	3	main
väga	doc_767882159252_item	2862320	et	3	main
millal	doc_767882159252_item	2862322	et	3	main
tegid	doc_767882159252_item	2862324	et	4	main
ja	doc_767882159252_item	2862331	et	3	main
kõik	doc_767882159252_item	2862340	et	4	main
mida	doc_767882159252_item	2862341	et	4	main
sellest	doc_767882159252_item	2862347	et	4	main
millised	doc_767882159252_item	2862353	et	3	main
väga	doc_767882159252_item	2862356	et	3	main
vanevanematel	doc_767882159252_item	2862359	et	4	main
laulad	doc_767882159252_item	2862362	et	3	main
on	doc_767882159252_item	2862363	et	4	main
mitte	doc_767882159252_item	2862364	et	3	main
näitavad	doc_767882159252_item	2862368	et	4	main
et	doc_767882159252_item	2862369	et	3	main
oli	doc_767882159252_item	2862371	et	3	main
veenelased	doc_767882159252_item	2862386	et	4	main
arvamus	doc_767882159252_item	2862398	et	3	main
et	doc_767882159252_item	2862399	et	3	main
kui	doc_767882159252_item	2862406	et	3	main
ta	doc_767882159252_item	2862410	et	4	main
vaba	doc_767882159252_item	2862429	et	4	main
analüüsiv	doc_767882159252_item	2862229	et	4	main
ja	doc_767882159252_item	2862230	et	3	main
üldistav	doc_767882159252_item	2862231	et	4	main
soovitatav	doc_767882159252_item	2862240	et	4	main
väga	doc_767882159252_item	2862248	et	3	main
pikk	doc_767882159252_item	2862249	et	4	main
ja	doc_767882159252_item	2862250	et	3	main
ei	doc_767882159252_item	2862260	et	4	main
laulukultuuri	doc_767882159252_item	2862263	et	4	main
ole	doc_767882159252_item	2862274	et	4	main
väga	doc_767882159252_item	2862275	et	3	main
palju	doc_767882159252_item	2862276	et	4	main
vene	doc_767882159252_item	2862284	et	4	main
ja	doc_767882159252_item	2862288	et	3	main
eestlased-jahimehed	doc_767882159252_item	2862323	et	3	main
oma	doc_767882159252_item	2862325	et	4	main
valmistasid	doc_767882159252_item	2862332	et	4	main
toitu	doc_767882159252_item	2862333	et	4	main
juba	doc_767882159252_item	2862334	et	3	main
need	doc_767882159252_item	2862350	et	3	main
vanud	doc_767882159252_item	2862351	et	3	main
ilusad	doc_767882159252_item	2862365	et	3	main
see	doc_767882159252_item	2862372	et	3	main
kultuurist	doc_767882159252_item	2862391	et	3	main
see	doc_767882159252_item	2862396	et	3	main
aga	doc_767882159252_item	2862405	et	3	main
hakkab	doc_767882159252_item	2862408	et	3	main
võivad-olla	doc_767882159252_item	2862415	et	3	main
sellepärast	doc_767882159252_item	2862417	et	3	main
andis	doc_767882159252_item	2862420	et	3	main
rahv	doc_767882159252_item	2862430	et	4	main
oli	doc_767882159252_item	2862433	et	3	main
raske	doc_767882159252_item	2862434	et	4	main
ja	doc_767882159252_item	2862435	et	3	main
eestlased	doc_767882159252_item	2862436	et	3	main
kõik	doc_767882159252_item	2862437	et	4	main
proovisid	doc_767882159252_item	2862448	et	4	main
mis	doc_767882159252_item	2862456	et	4	main
organiseeritud	doc_767882159252_item	2862458	et	4	main
nii	doc_767882159252_item	2862460	et	3	main
suur	doc_767882159252_item	2862461	et	3	main
kogemus	doc_767882159252_item	2862462	et	3	main
sa	doc_767882159252_item	2862471	et	3	main
eestlastel	doc_767882159252_item	2862474	et	4	main
kultuuri	doc_767882159252_item	2862481	et	4	main
see	doc_767882159252_item	2862482	et	3	main
rahv	doc_767882159252_item	2862483	et	4	main
kõik	doc_767882159252_item	2862486	et	4	main
arvan	doc_767882159252_item	2862493	et	3	main
seda	doc_767882159252_item	2862495	et	3	main
kaotama	doc_767882159252_item	2862505	et	4	main
laulurahval	doc_767882159252_item	2862246	et	3	main
on	doc_767882159252_item	2862247	et	4	main
et	doc_767882159252_item	2862258	et	3	main
eestlastel	doc_767882159252_item	2862259	et	4	main
on	doc_767882159252_item	2862266	et	4	main
inimesed	doc_767882159252_item	2862277	et	3	main
ütlevad	doc_767882159252_item	2862278	et	4	main
et	doc_767882159252_item	2862279	et	3	main
ja	doc_767882159252_item	2862285	et	3	main
tüdruk	doc_767882159252_item	2862291	et	3	main
ei	doc_767882159252_item	2862293	et	4	main
istusid	doc_767882159252_item	2862329	et	4	main
ajal	doc_767882159252_item	2862336	et	4	main
sündis	doc_767882159252_item	2862337	et	3	main
koos	doc_767882159252_item	2862345	et	4	main
jutustada	doc_767882159252_item	2862349	et	3	main
laulud	doc_767882159252_item	2862352	et	3	main
populaarsed	doc_767882159252_item	2862357	et	3	main
millal	doc_767882159252_item	2862374	et	3	main
tuavad	doc_767882159252_item	2862387	et	4	main
väike	doc_767882159252_item	2862388	et	4	main
osa	doc_767882159252_item	2862389	et	4	main
ja	doc_767882159252_item	2862392	et	3	main
kujundus	doc_767882159252_item	2862395	et	4	main
vale	doc_767882159252_item	2862397	et	4	main
eestlastel	doc_767882159252_item	2862400	et	4	main
ole	doc_767882159252_item	2862402	et	4	main
oma	doc_767882159252_item	2862403	et	4	main
rahvale	doc_767882159252_item	2862422	et	3	main
tunne	doc_767882159252_item	2862423	et	4	main
et	doc_767882159252_item	2862424	et	3	main
omanikule	doc_767882159252_item	2862440	et	3	main
näiteks	doc_767882159252_item	2862441	et	4	main
venelased	doc_767882159252_item	2862442	et	3	main
jõudu	doc_767882159252_item	2862450	et	4	main
ja	doc_767882159252_item	2862451	et	3	main
see	doc_767882159252_item	2862452	et	3	main
aitab	doc_767882159252_item	2862453	et	3	main
muljeid	doc_767882159252_item	2862466	et	3	main
oma	doc_767882159252_item	2862477	et	4	main
oskab	doc_767882159252_item	2862484	et	3	main
tema	doc_767882159252_item	2862489	et	4	main
tööd	doc_767882159252_item	2862326	et	4	main
ja	doc_767882159252_item	2862327	et	3	main
perenaised	doc_767882159252_item	2862328	et	3	main
sellel	doc_767882159252_item	2862335	et	4	main
nad	doc_767882159252_item	2862342	et	3	main
tegid	doc_767882159252_item	2862343	et	4	main
oli	doc_767882159252_item	2862344	et	3	main
võib	doc_767882159252_item	2862348	et	3	main
praegu	doc_767882159252_item	2862354	et	3	main
aga	doc_767882159252_item	2862366	et	3	main
nad	doc_767882159252_item	2862375	et	3	main
olid	doc_767882159252_item	2862376	et	4	main
vabad	doc_767882159252_item	2862378	et	3	main
pärast	doc_767882159252_item	2862379	et	4	main
oma	doc_767882159252_item	2862390	et	4	main
laulukulturi	doc_767882159252_item	2862404	et	4	main
inimene	doc_767882159252_item	2862407	et	3	main
huvitama	doc_767882159252_item	2862409	et	3	main
eestlased	doc_767882159252_item	2862414	et	3	main
laul	doc_767882159252_item	2862419	et	4	main
sellele	doc_767882159252_item	2862421	et	4	main
on	doc_767882159252_item	2862426	et	4	main
iseseisvane	doc_767882159252_item	2862427	et	4	main
ja	doc_767882159252_item	2862428	et	3	main
laul	doc_767882159252_item	2862445	et	4	main
kõik	doc_767882159252_item	2862454	et	4	main
et	doc_767882159252_item	2862467	et	3	main
ei	doc_767882159252_item	2862470	et	4	main
laulukulturi	doc_767882159252_item	2862478	et	4	main
ja	doc_767882159252_item	2862479	et	3	main
lihtsalt	doc_767882159252_item	2862480	et	4	main
säilitama	doc_767882159252_item	2862485	et	4	main
mis	doc_767882159252_item	2862487	et	4	main
ja	doc_767882159252_item	2862491	et	3	main
oskus	doc_767882159252_item	2862496	et	3	main
muidugi	doc_767882159252_item	2862498	et	4	main
ära	doc_767882159252_item	2862504	et	4	main
nad	doc_767882159252_item	2862425	et	3	main
ajal	doc_767882159252_item	2862431	et	4	main
millal	doc_767882159252_item	2862432	et	3	main
aitab	doc_767882159252_item	2862443	et	3	main
ainult	doc_767882159252_item	2862444	et	4	main
millega	doc_767882159252_item	2862446	et	3	main
nad	doc_767882159252_item	2862447	et	3	main
andsid	doc_767882159252_item	2862438	et	4	main
uutele	doc_767882159252_item	2862439	et	3	main
säilitama	doc_767882159252_item	2862449	et	4	main
laulupeod	doc_767882159252_item	2862455	et	4	main
andsid	doc_767882159252_item	2862459	et	4	main
palju	doc_767882159252_item	2862463	et	4	main
kombeid	doc_767882159252_item	2862464	et	4	main
pärast	doc_767882159252_item	2862468	et	4	main
ütelda	doc_767882159252_item	2862472	et	4	main
seostub	doc_767882159252_item	2862488	et	3	main
eluga	doc_767882159252_item	2862490	et	3	main
ma	doc_767882159252_item	2862492	et	3	main
et	doc_767882159252_item	2862494	et	3	main
ja	doc_767882159252_item	2862497	et	3	main
omaduse	doc_767882159252_item	2862499	et	4	main
nagu	doc_767882159252_item	2862500	et	3	main
laulurahv	doc_767882159252_item	2862501	et	4	main
essee	doc_767882159254_item	2862794	et	4	main
faktidele	doc_767882159254_item	2862826	et	3	main
on	doc_767882159254_item	2862828	et	4	main
soovitatav	doc_767882159254_item	2862829	et	4	main
vastus	doc_767882159254_item	2862839	et	3	main
kõik	doc_767882159254_item	2862841	et	4	main
koovad	doc_767882159254_item	2862881	et	3	main
nad	doc_767882159254_item	2862884	et	3	main
laulavad	doc_767882159254_item	2862885	et	4	main
aga	doc_767882159254_item	2862887	et	3	main
naine	doc_767882159254_item	2862891	et	3	main
paadis	doc_767882159254_item	2862898	et	3	main
oli	doc_767882159252_item	2862457	et	3	main
ja	doc_767882159252_item	2862465	et	3	main
seda	doc_767882159252_item	2862469	et	3	main
et	doc_767882159252_item	2862473	et	3	main
ei	doc_767882159252_item	2862475	et	4	main
ole	doc_767882159252_item	2862476	et	4	main
vaja	doc_767882159252_item	2862502	et	4	main
mitte	doc_767882159252_item	2862503	et	3	main
keele	doc_767882159254_item	2862796	et	4	main
kui	doc_767882159254_item	2862797	et	3	main
teise	doc_767882159254_item	2862798	et	4	main
keele	doc_767882159254_item	2862799	et	4	main
test	doc_767882159254_item	2862800	et	3	main
kirjutamine	doc_767882159254_item	2862801	et	4	main
kirjutage	doc_767882159254_item	2862802	et	3	main
essee	doc_767882159254_item	2862803	et	4	main
teemal	doc_767882159254_item	2862804	et	3	main
mis	doc_767882159254_item	2862805	et	4	main
teeb	doc_767882159254_item	2862806	et	3	main
eestlastest	doc_767882159254_item	2862807	et	4	main
laulurahva	doc_767882159254_item	2862808	et	3	main
essee	doc_767882159254_item	2862809	et	4	main
pikkus	doc_767882159254_item	2862810	et	4	main
300	doc_767882159254_item	2862811	et	2	main
350	doc_767882159254_item	2862812	et	2	main
sõna	doc_767882159254_item	2862813	et	4	main
essee	doc_767882159254_item	2862814	et	4	main
peab	doc_767882159254_item	2862815	et	4	main
olema	doc_767882159254_item	2862816	et	4	main
arutlev	doc_767882159254_item	2862817	et	4	main
analüüsiv	doc_767882159254_item	2862818	et	4	main
ja	doc_767882159254_item	2862819	et	3	main
üldistav	doc_767882159254_item	2862820	et	4	main
tuginema	doc_767882159254_item	2862821	et	3	main
lugemistekstis	doc_767882159254_item	2862824	et	3	main
illustreerida	doc_767882159254_item	2862830	et	3	main
peas	doc_767882159254_item	2862836	et	4	main
kohe	doc_767882159254_item	2862837	et	4	main
või	doc_767882159254_item	2862851	et	4	main
nelisada	doc_767882159254_item	2862852	et	4	main
aastat	doc_767882159254_item	2862853	et	3	main
tagasi	doc_767882159254_item	2862854	et	3	main
elan	doc_767882159254_item	2862855	et	3	main
külas	doc_767882159254_item	2862856	et	3	main
kaks	doc_767882159254_item	2862879	et	3	main
ääres	doc_767882159254_item	2862889	et	4	main
seisab	doc_767882159254_item	2862890	et	3	main
kahe	doc_767882159254_item	2862892	et	3	main
laulu	doc_767882159254_item	2862915	et	4	main
tol	doc_767882159254_item	2862916	et	3	main
naised	doc_767882159254_item	2862921	et	3	main
kui	doc_767882159254_item	2862924	et	3	main
e	doc_767882159254_item	2862932	et	4	main
jalutame	doc_767882159254_item	2862933	et	3	main
edasi	doc_767882159254_item	2862934	et	3	main
ajas	doc_767882159254_item	2862935	et	4	main
eesti	doc_767882159254_item	2862795	et	4	main
ja	doc_767882159254_item	2862823	et	3	main
väiteid	doc_767882159254_item	2862827	et	4	main
näidetega	doc_767882159254_item	2862831	et	3	main
kõik	doc_767882159254_item	2862840	et	4	main
teeb	doc_767882159254_item	2862842	et	3	main
eestlastest	doc_767882159254_item	2862843	et	4	main
laulurahva	doc_767882159254_item	2862844	et	3	main
kujutan	doc_767882159254_item	2862845	et	3	main
vaadake	doc_767882159254_item	2862857	et	3	main
seal	doc_767882159254_item	2862861	et	4	main
jõe	doc_767882159254_item	2862895	et	3	main
istub	doc_767882159254_item	2862897	et	3	main
mees	doc_767882159254_item	2862900	et	4	main
kutsuti	doc_767882159254_item	2862905	et	3	main
jõe	doc_767882159254_item	2862908	et	3	main
nuttab	doc_767882159254_item	2862910	et	4	main
ja	doc_767882159254_item	2862911	et	3	main
laulab	doc_767882159254_item	2862912	et	3	main
oma	doc_767882159254_item	2862913	et	4	main
kurva	doc_767882159254_item	2862914	et	3	main
laulsid	doc_767882159254_item	2862923	et	4	main
nad	doc_767882159254_item	2862925	et	3	main
19	doc_767882159254_item	2862938	et	2	main
sajand	doc_767882159254_item	2862939	et	3	main
lähme	doc_767882159254_item	2862940	et	3	main
kiriku	doc_767882159254_item	2862941	et	3	main
ringi	doc_767882159254_item	2862942	et	4	main
need	doc_767882159254_item	2862947	et	3	main
vaimlikud	doc_767882159254_item	2862951	et	4	main
laulud	doc_767882159254_item	2862952	et	3	main
nendel	doc_767882159254_item	2862953	et	4	main
lauludel	doc_767882159254_item	2862954	et	3	main
laulud	doc_767882159254_item	2862959	et	3	main
kujunenud	doc_767882159254_item	2862962	et	4	main
aga	doc_767882159254_item	2862967	et	3	main
muusika	doc_767882159254_item	2862973	et	4	main
uuemat	doc_767882159254_item	2862975	et	4	main
rahvalaulu	doc_767882159254_item	2862976	et	4	main
toimub	doc_767882159254_item	2863012	et	3	main
esimene	doc_767882159254_item	2863015	et	3	main
ülemaaline	doc_767882159254_item	2863016	et	4	main
sain	doc_767882159254_item	2863018	et	3	main
teada	doc_767882159254_item	2863019	et	3	main
et	doc_767882159254_item	2863020	et	3	main
meeskoori	doc_767882159254_item	2863023	et	4	main
5	doc_767882159254_item	2863027	et	2	main
puhkpilliorkestrit	doc_767882159254_item	2863028	et	3	main
märk	doc_767882159254_item	2863045	et	3	main
järgmised	doc_767882159254_item	2863046	et	3	main
üldlaulupidu	doc_767882159254_item	2863048	et	4	main
tsaristliku	doc_767882159254_item	2863055	et	3	main
koosseisus	doc_767882159254_item	2863057	et	4	main
loa	doc_767882159254_item	2863058	et	4	main
keerukaks	doc_767882159254_item	2863062	et	3	main
nuppu	doc_767882159254_item	2863071	et	4	main
on	doc_767882159254_item	2863078	et	4	main
noored	doc_767882159254_item	2863123	et	3	main
kõigepealt	doc_767882159254_item	2863130	et	3	main
rahvalaule	doc_767882159254_item	2863140	et	4	main
eestlastest	doc_767882159254_item	2863144	et	4	main
laulurahva	doc_767882159254_item	2863145	et	3	main
teeb	doc_767882159254_item	2863147	et	3	main
laulurahva	doc_767882159254_item	2863149	et	3	main
loengus	doc_767882159254_item	2862822	et	3	main
teeb	doc_767882159254_item	2862833	et	3	main
laulurahva	doc_767882159254_item	2862835	et	3	main
maja	doc_767882159254_item	2862859	et	4	main
aknasse	doc_767882159254_item	2862860	et	4	main
noor	doc_767882159254_item	2862862	et	3	main
akna	doc_767882159254_item	2862878	et	3	main
neiut	doc_767882159254_item	2862880	et	3	main
midagi	doc_767882159254_item	2862882	et	4	main
jõe	doc_767882159254_item	2862888	et	3	main
lastega	doc_767882159254_item	2862893	et	3	main
keskel	doc_767882159254_item	2862896	et	3	main
sõjaväelane	doc_767882159254_item	2862903	et	3	main
naine	doc_767882159254_item	2862907	et	3	main
ääres	doc_767882159254_item	2862909	et	4	main
ainult	doc_767882159254_item	2862920	et	4	main
esitatud	doc_767882159254_item	2862825	et	4	main
mis	doc_767882159254_item	2862832	et	4	main
eestlastest	doc_767882159254_item	2862834	et	4	main
tekkib	doc_767882159254_item	2862838	et	3	main
ette	doc_767882159254_item	2862846	et	4	main
et	doc_767882159254_item	2862847	et	3	main
elan	doc_767882159254_item	2862848	et	3	main
eestis	doc_767882159254_item	2862849	et	3	main
kolmsada	doc_767882159254_item	2862850	et	4	main
selle	doc_767882159254_item	2862858	et	4	main
ema	doc_767882159254_item	2862863	et	4	main
laulab	doc_767882159254_item	2862864	et	3	main
oma	doc_767882159254_item	2862865	et	4	main
pisikesele	doc_767882159254_item	2862866	et	4	main
laulu	doc_767882159254_item	2862867	et	4	main
laul	doc_767882159254_item	2862868	et	4	main
tasa	doc_767882159254_item	2862870	et	3	main
ilus	doc_767882159254_item	2862871	et	4	main
tuleb	doc_767882159254_item	2862872	et	3	main
on	doc_767882159254_item	2862869	et	4	main
ema	doc_767882159254_item	2862873	et	4	main
südast	doc_767882159254_item	2862874	et	4	main
vaatame	doc_767882159254_item	2862875	et	3	main
järgmise	doc_767882159254_item	2862876	et	3	main
maja	doc_767882159254_item	2862877	et	4	main
ja	doc_767882159254_item	2862883	et	3	main
ka	doc_767882159254_item	2862886	et	3	main
juba	doc_767882159254_item	2862894	et	3	main
tema	doc_767882159254_item	2862899	et	4	main
kes	doc_767882159254_item	2862901	et	4	main
on	doc_767882159254_item	2862902	et	4	main
ajal	doc_767882159254_item	2862917	et	4	main
ja	doc_767882159254_item	2862930	et	3	main
n	doc_767882159254_item	2862931	et	4	main
mida	doc_767882159254_item	2862943	et	4	main
on	doc_767882159254_item	2862955	et	4	main
euroopa	doc_767882159254_item	2862963	et	4	main
muusika	doc_767882159254_item	2862964	et	4	main
eelkõige	doc_767882159254_item	2862965	et	3	main
rootsi	doc_767882159254_item	2862969	et	4	main
ja	doc_767882159254_item	2862971	et	3	main
laulupidu	doc_767882159254_item	2863017	et	4	main
teda	doc_767882159254_item	2862904	et	4	main
sõjale	doc_767882159254_item	2862906	et	3	main
inimesed	doc_767882159254_item	2862918	et	3	main
praktiliselt	doc_767882159254_item	2862919	et	4	main
alati	doc_767882159254_item	2862922	et	4	main
töötasid	doc_767882159254_item	2862926	et	4	main
kui	doc_767882159254_item	2862927	et	3	main
last	doc_767882159254_item	2862928	et	4	main
kuulame	doc_767882159254_item	2862945	et	4	main
uueaja	doc_767882159254_item	2862949	et	3	main
laulud	doc_767882159254_item	2862950	et	3	main
on	doc_767882159254_item	2862960	et	4	main
ka	doc_767882159254_item	2862968	et	3	main
soome	doc_767882159254_item	2862970	et	3	main
slaavi	doc_767882159254_item	2862972	et	3	main
aru	doc_767882159254_item	2863032	et	4	main
üht	doc_767882159254_item	2863033	et	3	main
ärkamise	doc_767882159254_item	2863044	et	4	main
võitlesid	doc_767882159254_item	2863050	et	4	main
osutus	doc_767882159254_item	2863060	et	4	main
kasvas	doc_767882159254_item	2863067	et	3	main
varem	doc_767882159254_item	2863085	et	4	main
rohkem	doc_767882159254_item	2863120	et	4	main
kiigutasid	doc_767882159254_item	2862929	et	4	main
seest	doc_767882159254_item	2862946	et	3	main
on	doc_767882159254_item	2862948	et	4	main
välja	doc_767882159254_item	2862961	et	4	main
saksa	doc_767882159254_item	2862966	et	4	main
iseloomustab	doc_767882159254_item	2862977	et	4	main
kirjalik	doc_767882159254_item	2862978	et	3	main
ülestähendus	doc_767882159254_item	2862979	et	3	main
laululehed	doc_767882159254_item	2862980	et	3	main
ja	doc_767882159254_item	2862981	et	3	main
salmialbumid	doc_767882159254_item	2862982	et	3	main
levisid	doc_767882159254_item	2862983	et	4	main
trükitult	doc_767882159254_item	2862984	et	4	main
aga	doc_767882159254_item	2862985	et	3	main
laulikuid	doc_767882159254_item	2862986	et	3	main
ja	doc_767882159254_item	2862987	et	3	main
salmikuid	doc_767882159254_item	2862988	et	4	main
kirjutati	doc_767882159254_item	2862989	et	3	main
ümber	doc_767882159254_item	2862990	et	3	main
ka	doc_767882159254_item	2862991	et	3	main
käsitsi	doc_767882159254_item	2862992	et	3	main
ilus	doc_767882159254_item	2862993	et	4	main
aeg	doc_767882159254_item	2862994	et	3	main
mulle	doc_767882159254_item	2862995	et	4	main
meeldib	doc_767882159254_item	2862996	et	3	main
siin	doc_767882159254_item	2862997	et	4	main
elada	doc_767882159254_item	2862998	et	3	main
aga	doc_767882159254_item	2862999	et	3	main
tuli	doc_767882159254_item	2863000	et	4	main
aeg	doc_767882159254_item	2863001	et	3	main
minna	doc_767882159254_item	2863002	et	3	main
edasi	doc_767882159254_item	2863003	et	3	main
vajutame	doc_767882159254_item	2863004	et	3	main
nuppu	doc_767882159254_item	2863005	et	4	main
ja	doc_767882159254_item	2863006	et	3	main
1869	doc_767882159254_item	2863007	et	2	main
aasta	doc_767882159254_item	2863008	et	4	main
uus	doc_767882159254_item	2862936	et	3	main
aeg	doc_767882159254_item	2862937	et	3	main
me	doc_767882159254_item	2862944	et	4	main
teadav	doc_767882159254_item	2862956	et	4	main
autor	doc_767882159254_item	2862957	et	3	main
need	doc_767882159254_item	2862958	et	3	main
mõjul	doc_767882159254_item	2862974	et	4	main
siin	doc_767882159254_item	2863011	et	4	main
osalevad	doc_767882159254_item	2863021	et	4	main
olulist	doc_767882159254_item	2863034	et	4	main
asja	doc_767882159254_item	2863035	et	4	main
see	doc_767882159254_item	2863036	et	3	main
lihtsalt	doc_767882159254_item	2863039	et	4	main
on	doc_767882159254_item	2863042	et	4	main
rahvuslike	doc_767882159254_item	2863043	et	3	main
eest	doc_767882159254_item	2863053	et	4	main
korraldati	doc_767882159254_item	2863054	et	3	main
aeganõudvalt	doc_767882159254_item	2863061	et	4	main
esinema	doc_767882159254_item	2863065	et	3	main
väga	doc_767882159254_item	2863068	et	3	main
mis	doc_767882159254_item	2863084	et	4	main
tänapäeval	doc_767882159254_item	2863124	et	3	main
saartel	doc_767882159254_item	2863131	et	3	main
ja	doc_767882159254_item	2863132	et	3	main
tihti	doc_767882159254_item	2863136	et	3	main
siis	doc_767882159254_item	2863142	et	3	main
tartu	doc_767882159254_item	2863009	et	4	main
täna	doc_767882159254_item	2863010	et	4	main
muusikaline	doc_767882159254_item	2863013	et	4	main
suursündmus	doc_767882159254_item	2863014	et	3	main
46	doc_767882159254_item	2863022	et	2	main
822	doc_767882159254_item	2863024	et	2	main
lauljaga	doc_767882159254_item	2863025	et	4	main
ja	doc_767882159254_item	2863026	et	3	main
56	doc_767882159254_item	2863029	et	2	main
mängijaga	doc_767882159254_item	2863030	et	4	main
sain	doc_767882159254_item	2863031	et	3	main
ei	doc_767882159254_item	2863037	et	4	main
seitse	doc_767882159254_item	2863047	et	3	main
eestlased	doc_767882159254_item	2863049	et	3	main
venemaa	doc_767882159254_item	2863056	et	4	main
soovijate	doc_767882159254_item	2863064	et	4	main
vajutame	doc_767882159254_item	2863070	et	3	main
me	doc_767882159254_item	2863072	et	4	main
asume	doc_767882159254_item	2863073	et	3	main
tallinna	doc_767882159254_item	2863074	et	4	main
lauluväljakul	doc_767882159254_item	2863075	et	3	main
praegu	doc_767882159254_item	2863076	et	3	main
siin	doc_767882159254_item	2863077	et	4	main
aasta	doc_767882159254_item	2863080	et	4	main
kõige	doc_767882159254_item	2863119	et	4	main
olid	doc_767882159254_item	2863121	et	4	main
on	doc_767882159254_item	2863126	et	4	main
väga	doc_767882159254_item	2863127	et	3	main
palju	doc_767882159254_item	2863128	et	4	main
me	doc_767882159254_item	2863134	et	4	main
mis	doc_767882159254_item	2863141	et	4	main
eestlastest	doc_767882159254_item	2863148	et	4	main
ole	doc_767882159254_item	2863038	et	4	main
lauluüritus	doc_767882159254_item	2863040	et	3	main
see	doc_767882159254_item	2863041	et	3	main
oma	doc_767882159254_item	2863051	et	4	main
tunnustamise	doc_767882159254_item	2863052	et	4	main
saamine	doc_767882159254_item	2863059	et	4	main
ja	doc_767882159254_item	2863063	et	3	main
hulk	doc_767882159254_item	2863066	et	3	main
kiiresti	doc_767882159254_item	2863069	et	3	main
1928	doc_767882159254_item	2863079	et	2	main
täna	doc_767882159254_item	2863081	et	4	main
toimub	doc_767882159254_item	2863082	et	3	main
laulupidu	doc_767882159254_item	2863083	et	4	main
toimus	doc_767882159254_item	2863086	et	3	main
tartus	doc_767882159254_item	2863087	et	3	main
ootame	doc_767882159254_item	2863088	et	3	main
veel	doc_767882159254_item	2863089	et	4	main
aega	doc_767882159254_item	2863090	et	4	main
ja	doc_767882159254_item	2863091	et	3	main
oleme	doc_767882159254_item	2863092	et	3	main
70-ndates	doc_767882159254_item	2863093	et	4	main
aastates	doc_767882159254_item	2863094	et	4	main
ilmuvad	doc_767882159254_item	2863095	et	4	main
folk	doc_767882159254_item	2863096	et	4	main
ansamblid	doc_767882159254_item	2863097	et	3	main
nende	doc_767882159254_item	2863098	et	4	main
liiged	doc_767882159254_item	2863099	et	4	main
leiavad	doc_767882159254_item	2863100	et	3	main
arhiivist	doc_767882159254_item	2863101	et	3	main
regivärsilisi	doc_767882159254_item	2863102	et	4	main
rahvalaule	doc_767882159254_item	2863103	et	4	main
paljud	doc_767882159254_item	2863104	et	3	main
muusikut	doc_767882159254_item	2863105	et	3	main
on	doc_767882159254_item	2863106	et	4	main
huvitatud	doc_767882159254_item	2863107	et	4	main
esitamine	doc_767882159254_item	2863108	et	4	main
regivärsilist	doc_767882159254_item	2863109	et	4	main
rahvalaulu	doc_767882159254_item	2863110	et	4	main
see	doc_767882159254_item	2863111	et	3	main
on	doc_767882159254_item	2863112	et	4	main
midagi	doc_767882159254_item	2863113	et	4	main
uus	doc_767882159254_item	2863114	et	3	main
aga	doc_767882159254_item	2863115	et	3	main
kõige	doc_767882159254_item	2863116	et	4	main
vanem	doc_767882159254_item	2863117	et	4	main
stiil	doc_767882159254_item	2863118	et	3	main
huvitatud	doc_767882159254_item	2863122	et	4	main
meil	doc_767882159254_item	2863125	et	4	main
väga	doc_767882159254_item	2863135	et	3	main
saame	doc_767882159254_item	2863137	et	4	main
kuulda	doc_767882159254_item	2863138	et	4	main
teeb	doc_767882159254_item	2863143	et	3	main
kõik	doc_767882159254_item	2863146	et	4	main
folkrühme	doc_767882159254_item	2863129	et	3	main
lääne-eestis	doc_767882159254_item	2863133	et	3	main
vanu	doc_767882159254_item	2863139	et	4	main
essee	doc_767882159257_item	2863746	et	4	main
essee	doc_767882159257_item	2863737	et	4	main
kirjutamine	doc_767882159257_item	2863744	et	4	main
kirjutage	doc_767882159257_item	2863745	et	3	main
teeb	doc_767882159257_item	2863749	et	3	main
arutlev	doc_767882159257_item	2863760	et	4	main
väiteid	doc_767882159257_item	2863770	et	4	main
illustreerida	doc_767882159257_item	2863773	et	3	main
laulurahvas	doc_767882159257_item	2863782	et	4	main
seda	doc_767882159257_item	2863783	et	3	main
nimet	doc_767882159257_item	2863784	et	4	main
nad	doc_767882159257_item	2863785	et	3	main
said	doc_767882159257_item	2863786	et	4	main
laulda	doc_767882159257_item	2863798	et	4	main
või	doc_767882159257_item	2863807	et	4	main
eestlaste	doc_767882159257_item	2863828	et	4	main
laulupidu	doc_767882159257_item	2863836	et	4	main
keele	doc_767882159257_item	2863742	et	4	main
test	doc_767882159257_item	2863743	et	3	main
mis	doc_767882159257_item	2863748	et	4	main
peab	doc_767882159257_item	2863758	et	4	main
olema	doc_767882159257_item	2863759	et	4	main
tuginema	doc_767882159257_item	2863764	et	3	main
eesti	doc_767882159257_item	2863738	et	4	main
keele	doc_767882159257_item	2863739	et	4	main
teemal	doc_767882159257_item	2863747	et	3	main
essee	doc_767882159257_item	2863752	et	4	main
aastaid	doc_767882159257_item	2863779	et	4	main
oma	doc_767882159257_item	2863787	et	4	main
ajaloo	doc_767882159257_item	2863790	et	4	main
juba	doc_767882159257_item	2863792	et	3	main
vanal	doc_767882159257_item	2863793	et	3	main
ajal	doc_767882159257_item	2863794	et	4	main
nad	doc_767882159257_item	2863795	et	3	main
väga	doc_767882159257_item	2863796	et	3	main
nii	doc_767882159257_item	2863801	et	3	main
ka	doc_767882159257_item	2863804	et	3	main
üksi	doc_767882159257_item	2863808	et	4	main
olles	doc_767882159257_item	2863809	et	3	main
nad	doc_767882159257_item	2863810	et	3	main
rääkisid	doc_767882159257_item	2863811	et	4	main
lauludest	doc_767882159257_item	2863812	et	3	main
ka	doc_767882159257_item	2863813	et	3	main
muinasjuttu	doc_767882159257_item	2863814	et	4	main
lastele	doc_767882159257_item	2863815	et	4	main
jutustades	doc_767882159257_item	2863816	et	3	main
nende	doc_767882159257_item	2863817	et	4	main
suur	doc_767882159257_item	2863818	et	3	main
arm	doc_767882159257_item	2863819	et	3	main
laulmisele	doc_767882159257_item	2863820	et	4	main
üheksateistkümnendal	doc_767882159257_item	2863825	et	4	main
sajandil	doc_767882159257_item	2863826	et	3	main
aeg	doc_767882159257_item	2863837	et	3	main
aga	doc_767882159257_item	2863842	et	3	main
öelda	doc_767882159257_item	2863847	et	4	main
kultuuri	doc_767882159257_item	2863856	et	4	main
algusel	doc_767882159257_item	2863865	et	4	main
laulma	doc_767882159257_item	2863873	et	3	main
olema	doc_767882159257_item	2863884	et	4	main
eesti	doc_767882159257_item	2863890	et	4	main
mu	doc_767882159257_item	2863893	et	3	main
muusika	doc_767882159257_item	2863921	et	4	main
pop	doc_767882159257_item	2863923	et	4	main
mäletavad	doc_767882159257_item	2863941	et	4	main
a	doc_767882159257_item	2863946	et	4	main
kuulata	doc_767882159257_item	2863951	et	4	main
või	doc_767882159257_item	2863954	et	4	main
gustav	doc_767882159257_item	2863955	et	4	main
ernesaks	doc_767882159257_item	2863956	et	4	main
huvitav	doc_767882159257_item	2863966	et	4	main
300	doc_767882159258_item	2864005	et	2	main
väiteid	doc_767882159258_item	2864021	et	4	main
soovitatav	doc_767882159258_item	2864023	et	4	main
illustreerida	doc_767882159258_item	2864024	et	3	main
näidetega	doc_767882159258_item	2864025	et	3	main
mis	doc_767882159258_item	2864026	et	4	main
teeb	doc_767882159258_item	2864027	et	3	main
mis	doc_767882159258_item	2864034	et	4	main
aitab	doc_767882159258_item	2864035	et	3	main
väljendada	doc_767882159258_item	2864036	et	3	main
kooris	doc_767882159258_item	2864044	et	4	main
neile	doc_767882159258_item	2864046	et	4	main
meeldib	doc_767882159258_item	2864047	et	3	main
võib	doc_767882159258_item	2864049	et	3	main
kodutöö	doc_767882159258_item	2864056	et	4	main
üksi	doc_767882159258_item	2864058	et	4	main
ka	doc_767882159258_item	2864061	et	3	main
ka	doc_767882159258_item	2864085	et	3	main
kujunenud	doc_767882159258_item	2864098	et	4	main
eestimaine	doc_767882159258_item	2864100	et	4	main
kui	doc_767882159257_item	2863740	et	3	main
teise	doc_767882159257_item	2863741	et	4	main
eestlastest	doc_767882159257_item	2863750	et	4	main
laulurahva	doc_767882159257_item	2863751	et	3	main
300	doc_767882159257_item	2863754	et	2	main
sõna	doc_767882159257_item	2863756	et	4	main
loengus	doc_767882159257_item	2863765	et	3	main
esitatud	doc_767882159257_item	2863768	et	4	main
faktidele	doc_767882159257_item	2863769	et	3	main
soovitatav	doc_767882159257_item	2863772	et	4	main
on	doc_767882159257_item	2863776	et	4	main
sada	doc_767882159257_item	2863778	et	4	main
seotud	doc_767882159257_item	2863789	et	4	main
eest	doc_767882159257_item	2863791	et	4	main
eestlased	doc_767882159257_item	2863799	et	3	main
kui	doc_767882159257_item	2863803	et	3	main
last	doc_767882159257_item	2863805	et	4	main
ainult	doc_767882159257_item	2863821	et	4	main
aega	doc_767882159257_item	2863823	et	4	main
ärkamine	doc_767882159257_item	2863830	et	4	main
ja	doc_767882159257_item	2863831	et	3	main
oli	doc_767882159257_item	2863838	et	3	main
et	doc_767882159257_item	2863848	et	3	main
jõudu	doc_767882159257_item	2863852	et	4	main
olid	doc_767882159257_item	2863866	et	4	main
ka	doc_767882159257_item	2863874	et	3	main
sest	doc_767882159257_item	2863879	et	4	main
on	doc_767882159257_item	2863881	et	4	main
laulurahvas	doc_767882159257_item	2863882	et	4	main
oma	doc_767882159257_item	2863886	et	4	main
rahvalaul	doc_767882159257_item	2863887	et	4	main
ja	doc_767882159257_item	2863924	et	3	main
rock	doc_767882159257_item	2863925	et	4	main
on	doc_767882159257_item	2863926	et	4	main
väga	doc_767882159257_item	2863927	et	3	main
parem	doc_767882159257_item	2863939	et	4	main
tuntud	doc_767882159257_item	2863943	et	4	main
kapp	doc_767882159257_item	2863947	et	3	main
võib	doc_767882159257_item	2863950	et	3	main
kes	doc_767882159257_item	2863957	et	4	main
on	doc_767882159257_item	2863961	et	4	main
minu	doc_767882159257_item	2863962	et	3	main
arm	doc_767882159257_item	2863963	et	3	main
seotud	doc_767882159257_item	2863968	et	4	main
essee	doc_767882159258_item	2864003	et	4	main
sõna	doc_767882159258_item	2864007	et	4	main
arutlev	doc_767882159258_item	2864011	et	4	main
eestlastest	doc_767882159258_item	2864028	et	4	main
laulurahva	doc_767882159258_item	2864029	et	3	main
esteetiliselt	doc_767882159258_item	2864037	et	4	main
ja	doc_767882159258_item	2864038	et	3	main
laulavad	doc_767882159258_item	2864041	et	4	main
tuju	doc_767882159258_item	2864051	et	4	main
kui	doc_767882159258_item	2864052	et	3	main
inimene	doc_767882159258_item	2864053	et	3	main
igatseb	doc_767882159258_item	2864054	et	3	main
teeb	doc_767882159258_item	2864055	et	3	main
eestlastele	doc_767882159258_item	2864060	et	4	main
mistõttu	doc_767882159258_item	2864083	et	3	main
uurimine	doc_767882159258_item	2864091	et	4	main
rahvalaul	doc_767882159258_item	2864101	et	4	main
naised	doc_767882159258_item	2864105	et	3	main
ilma	doc_767882159258_item	2864116	et	4	main
muusika	doc_767882159258_item	2864117	et	4	main
instrumentideta	doc_767882159258_item	2864118	et	3	main
või	doc_767882159258_item	2864126	et	4	main
riimilised	doc_767882159258_item	2864141	et	4	main
rahvalaulud	doc_767882159258_item	2864142	et	3	main
neid	doc_767882159258_item	2864150	et	4	main
pillisaatega	doc_767882159258_item	2864154	et	3	main
seda	doc_767882159258_item	2864155	et	3	main
rahvalaulu	doc_767882159258_item	2864156	et	4	main
sellest	doc_767882159258_item	2864170	et	4	main
ja	doc_767882159258_item	2864176	et	3	main
laulupidude	doc_767882159258_item	2864179	et	4	main
traditsioon	doc_767882159258_item	2864180	et	3	main
praegu	doc_767882159258_item	2864181	et	3	main
korraldatakse	doc_767882159258_item	2864183	et	3	main
rahvusluse	doc_767882159258_item	2864218	et	4	main
manifestatsioon	doc_767882159258_item	2864219	et	3	main
eestis	doc_767882159258_item	2864220	et	3	main
pikkus	doc_767882159257_item	2863753	et	4	main
350	doc_767882159257_item	2863755	et	2	main
essee	doc_767882159257_item	2863757	et	4	main
analüüsiv	doc_767882159257_item	2863761	et	4	main
ja	doc_767882159257_item	2863762	et	3	main
üldistav	doc_767882159257_item	2863763	et	4	main
ja	doc_767882159257_item	2863766	et	3	main
on	doc_767882159257_item	2863771	et	4	main
näidetega	doc_767882159257_item	2863774	et	3	main
eestlased	doc_767882159257_item	2863775	et	3	main
juba	doc_767882159257_item	2863777	et	3	main
meeldisid	doc_767882159257_item	2863797	et	4	main
töötades	doc_767882159257_item	2863802	et	3	main
tugenes	doc_767882159257_item	2863822	et	4	main
jooksul	doc_767882159257_item	2863824	et	4	main
eestlastele	doc_767882159257_item	2863841	et	4	main
laulupeod	doc_767882159257_item	2863843	et	4	main
võiks	doc_767882159257_item	2863846	et	4	main
nendele	doc_767882159257_item	2863851	et	4	main
ja	doc_767882159257_item	2863853	et	3	main
toimuma	doc_767882159257_item	2863859	et	3	main
kiiremini	doc_767882159257_item	2863861	et	4	main
ja	doc_767882159257_item	2863862	et	3	main
tugemini	doc_767882159257_item	2863863	et	4	main
kui	doc_767882159257_item	2863864	et	3	main
20	doc_767882159257_item	2863870	et	2	main
sajandi	doc_767882159257_item	2863871	et	3	main
jooksul	doc_767882159257_item	2863872	et	4	main
peab	doc_767882159257_item	2863883	et	4	main
sellena	doc_767882159257_item	2863888	et	3	main
isamaa	doc_767882159257_item	2863894	et	4	main
lugemistekstis	doc_767882159257_item	2863767	et	3	main
tuntud	doc_767882159257_item	2863780	et	4	main
nagu	doc_767882159257_item	2863781	et	3	main
muusikaga	doc_767882159257_item	2863788	et	3	main
lauldi	doc_767882159257_item	2863800	et	3	main
kiigutades	doc_767882159257_item	2863806	et	3	main
hakkas	doc_767882159257_item	2863827	et	3	main
rahvuslik	doc_767882159257_item	2863829	et	3	main
1869	doc_767882159257_item	2863832	et	2	main
aastal	doc_767882159257_item	2863833	et	3	main
toimus	doc_767882159257_item	2863834	et	3	main
esimene	doc_767882159257_item	2863835	et	3	main
väga	doc_767882159257_item	2863839	et	3	main
raske	doc_767882159257_item	2863840	et	4	main
neid	doc_767882159257_item	2863845	et	4	main
laulud	doc_767882159257_item	2863849	et	3	main
arenemine	doc_767882159257_item	2863857	et	4	main
hakkas	doc_767882159257_item	2863858	et	3	main
ainult	doc_767882159257_item	2863867	et	4	main
meestekoorid	doc_767882159257_item	2863868	et	3	main
hakkasid	doc_767882159257_item	2863869	et	4	main
laste-	doc_767882159257_item	2863876	et	4	main
poistekoorid	doc_767882159257_item	2863878	et	3	main
hingestatud	doc_767882159257_item	2863891	et	4	main
isamaalaul	doc_767882159257_item	2863892	et	4	main
minu	doc_767882159257_item	2863896	et	3	main
arm	doc_767882159257_item	2863897	et	3	main
ka	doc_767882159257_item	2863898	et	3	main
praegu	doc_767882159257_item	2863899	et	3	main
muusika	doc_767882159257_item	2863900	et	4	main
on	doc_767882159257_item	2863901	et	4	main
väga	doc_767882159257_item	2863902	et	3	main
populaarne	doc_767882159257_item	2863903	et	3	main
eestlaste	doc_767882159257_item	2863904	et	4	main
hulgas	doc_767882159257_item	2863905	et	4	main
sellest	doc_767882159257_item	2863906	et	4	main
paljud	doc_767882159257_item	2863908	et	3	main
rääkivad	doc_767882159257_item	2863907	et	4	main
faktid	doc_767882159257_item	2863909	et	3	main
näiteks	doc_767882159257_item	2863910	et	4	main
eestis	doc_767882159257_item	2863911	et	3	main
eriti	doc_767882159257_item	2863912	et	3	main
viljandis	doc_767882159257_item	2863913	et	4	main
toimuvad	doc_767882159257_item	2863914	et	4	main
mitmesugused	doc_767882159257_item	2863915	et	3	main
laulmisega	doc_767882159257_item	2863916	et	4	main
seotud	doc_767882159257_item	2863917	et	4	main
üritused	doc_767882159257_item	2863918	et	4	main
nagu	doc_767882159257_item	2863919	et	3	main
lauluvõistlused	doc_767882159257_item	2863920	et	3	main
eriti	doc_767882159257_item	2863922	et	3	main
eestlaste	doc_767882159257_item	2863930	et	4	main
laulude	doc_767882159257_item	2863933	et	3	main
tänu	doc_767882159257_item	2863934	et	4	main
teavad	doc_767882159257_item	2863935	et	3	main
eestlased	doc_767882159257_item	2863936	et	3	main
nad	doc_767882159257_item	2863942	et	3	main
nimed	doc_767882159257_item	2863944	et	3	main
nagu	doc_767882159257_item	2863945	et	3	main
mõnedel	doc_767882159257_item	2863952	et	3	main
mis	doc_767882159258_item	2863999	et	4	main
teeb	doc_767882159258_item	2864000	et	3	main
ühinesid	doc_767882159257_item	2863844	et	4	main
andsid	doc_767882159257_item	2863850	et	4	main
tähtejõudu	doc_767882159257_item	2863854	et	4	main
eestlaste	doc_767882159257_item	2863855	et	4	main
ainult	doc_767882159257_item	2863860	et	4	main
naiste-	doc_767882159257_item	2863875	et	3	main
ja	doc_767882159257_item	2863877	et	3	main
eestlased	doc_767882159257_item	2863880	et	3	main
neil	doc_767882159257_item	2863885	et	4	main
sai	doc_767882159257_item	2863889	et	4	main
on	doc_767882159257_item	2863895	et	4	main
populaarne	doc_767882159257_item	2863928	et	3	main
ilmtingimata	doc_767882159257_item	2863932	et	3	main
ja	doc_767882159257_item	2863940	et	3	main
kelle	doc_767882159257_item	2863948	et	4	main
filmidel	doc_767882159257_item	2863953	et	3	main
kõlas	doc_767882159257_item	2863958	et	4	main
isamaa	doc_767882159257_item	2863960	et	4	main
minu	doc_767882159257_item	2863964	et	3	main
arvates	doc_767882159257_item	2863965	et	4	main
laulmisega	doc_767882159257_item	2863967	et	4	main
eestlaste	doc_767882159257_item	2863969	et	4	main
ajalugu	doc_767882159257_item	2863970	et	4	main
ja	doc_767882159257_item	2863971	et	3	main
eestlastest	doc_767882159258_item	2864001	et	4	main
laulurahva	doc_767882159258_item	2864002	et	3	main
350	doc_767882159258_item	2864006	et	2	main
essee	doc_767882159258_item	2864008	et	4	main
peab	doc_767882159258_item	2864009	et	4	main
analüüsiv	doc_767882159258_item	2864012	et	4	main
ja	doc_767882159258_item	2864013	et	3	main
üldistav	doc_767882159258_item	2864014	et	4	main
tuginema	doc_767882159258_item	2864015	et	3	main
loengus	doc_767882159258_item	2864016	et	3	main
ja	doc_767882159258_item	2864017	et	3	main
lugemistekstis	doc_767882159258_item	2864018	et	3	main
esitatud	doc_767882159258_item	2864019	et	4	main
faktidele	doc_767882159258_item	2864020	et	3	main
noorte	doc_767882159257_item	2863929	et	3	main
hulgas	doc_767882159257_item	2863931	et	4	main
oma	doc_767882159257_item	2863937	et	4	main
ajaloo	doc_767882159257_item	2863938	et	4	main
muusikat	doc_767882159257_item	2863949	et	3	main
mu	doc_767882159257_item	2863959	et	3	main
nende	doc_767882159257_item	2863972	et	4	main
suur	doc_767882159257_item	2863973	et	3	main
arm	doc_767882159257_item	2863974	et	3	main
lauludele	doc_767882159257_item	2863975	et	3	main
on	doc_767882159257_item	2863976	et	4	main
see	doc_767882159257_item	2863977	et	3	main
põhjus	doc_767882159257_item	2863978	et	4	main
miks	doc_767882159257_item	2863979	et	4	main
me	doc_767882159257_item	2863980	et	4	main
võime	doc_767882159257_item	2863981	et	4	main
kindlasti	doc_767882159257_item	2863982	et	3	main
öelda	doc_767882159257_item	2863983	et	4	main
et	doc_767882159257_item	2863984	et	3	main
eestlased	doc_767882159257_item	2863985	et	3	main
on	doc_767882159257_item	2863986	et	4	main
laulurahvas	doc_767882159257_item	2863987	et	4	main
essee	doc_767882159258_item	2863988	et	4	main
eesti	doc_767882159258_item	2863989	et	4	main
keele	doc_767882159258_item	2863990	et	4	main
kui	doc_767882159258_item	2863991	et	3	main
teise	doc_767882159258_item	2863992	et	4	main
keele	doc_767882159258_item	2863993	et	4	main
test	doc_767882159258_item	2863994	et	3	main
kirjutamine	doc_767882159258_item	2863995	et	4	main
kirjutage	doc_767882159258_item	2863996	et	3	main
essee	doc_767882159258_item	2863997	et	4	main
teemal	doc_767882159258_item	2863998	et	3	main
pikkus	doc_767882159258_item	2864004	et	4	main
laulmine	doc_767882159258_item	2864030	et	4	main
emotsionaalselt	doc_767882159258_item	2864039	et	4	main
kuidas	doc_767882159258_item	2864045	et	3	main
laulmine	doc_767882159258_item	2864048	et	4	main
tõsta	doc_767882159258_item	2864050	et	4	main
enam	doc_767882159258_item	2864092	et	4	main
kui	doc_767882159258_item	2864093	et	3	main
tuhat	doc_767882159258_item	2864094	et	4	main
aastat	doc_767882159258_item	2864095	et	3	main
tagisi	doc_767882159258_item	2864096	et	4	main
on	doc_767882159258_item	2864097	et	4	main
regivärsiline	doc_767882159258_item	2864099	et	4	main
lauldi	doc_767882159258_item	2864103	et	3	main
tegeledes	doc_767882159258_item	2864108	et	3	main
tehes	doc_767882159258_item	2864110	et	3	main
reas	doc_767882159258_item	2864120	et	3	main
lõpetavad	doc_767882159258_item	2864127	et	4	main
on	doc_767882159258_item	2864143	et	4	main
väärismõõdult	doc_767882159258_item	2864144	et	3	main
ja	doc_767882159258_item	2864145	et	3	main
viisilt	doc_767882159258_item	2864146	et	3	main
tähtsusega	doc_767882159258_item	2864161	et	4	main
sündmuseks	doc_767882159258_item	2864162	et	3	main
oli	doc_767882159258_item	2864163	et	3	main
sai	doc_767882159258_item	2864177	et	4	main
alguse	doc_767882159258_item	2864178	et	3	main
osalevad	doc_767882159258_item	2864222	et	4	main
laste-	doc_767882159258_item	2864227	et	4	main
kui	doc_767882159258_item	2864230	et	3	main
mitmesugused	doc_767882159258_item	2864232	et	3	main
kohata	doc_767882159258_item	2864245	et	4	main
sõpru	doc_767882159258_item	2864246	et	3	main
ja	doc_767882159258_item	2864248	et	3	main
ainult	doc_767882159258_item	2864262	et	4	main
muusikat	doc_767882159258_item	2864264	et	3	main
kaasa	doc_767882159258_item	2864267	et	4	main
laulda	doc_767882159258_item	2864268	et	4	main
koguvad	doc_767882159258_item	2864275	et	4	main
rahva	doc_767882159258_item	2864276	et	3	main
üheskoos	doc_767882159258_item	2864277	et	3	main
ja	doc_767882159258_item	2864278	et	3	main
teevad	doc_767882159258_item	2864279	et	3	main
olema	doc_767882159258_item	2864010	et	4	main
on	doc_767882159258_item	2864022	et	4	main
tegevus	doc_767882159258_item	2864033	et	4	main
üksi	doc_767882159258_item	2864042	et	4	main
kahekesi	doc_767882159258_item	2864043	et	3	main
on	doc_767882159258_item	2864057	et	4	main
meeldis	doc_767882159258_item	2864062	et	3	main
tutvumine	doc_767882159258_item	2864087	et	4	main
pisut	doc_767882159258_item	2864088	et	3	main
nagu	doc_767882159258_item	2864089	et	3	main
ajaloo	doc_767882159258_item	2864090	et	4	main
enamasti	doc_767882159258_item	2864104	et	4	main
näiteks	doc_767882159258_item	2864106	et	4	main
kodutöö	doc_767882159258_item	2864111	et	4	main
tegeledes	doc_767882159258_item	2864112	et	3	main
seda	doc_767882159258_item	2864113	et	3	main
laulu	doc_767882159258_item	2864114	et	4	main
lauldakse	doc_767882159258_item	2864115	et	3	main
on	doc_767882159258_item	2864031	et	4	main
niisugune	doc_767882159258_item	2864032	et	3	main
inimesed	doc_767882159258_item	2864040	et	3	main
kodus	doc_767882159258_item	2864059	et	4	main
ja	doc_767882159258_item	2864063	et	3	main
meeldib	doc_767882159258_item	2864064	et	3	main
laulda	doc_767882159258_item	2864065	et	4	main
see	doc_767882159258_item	2864067	et	3	main
ning	doc_767882159258_item	2864066	et	3	main
paljudel	doc_767882159258_item	2864068	et	3	main
hästi	doc_767882159258_item	2864069	et	3	main
õnnestub	doc_767882159258_item	2864070	et	3	main
ja	doc_767882159258_item	2864071	et	3	main
ilusasti	doc_767882159258_item	2864072	et	3	main
juba	doc_767882159258_item	2864073	et	3	main
vanal	doc_767882159258_item	2864074	et	3	main
ajal	doc_767882159258_item	2864075	et	4	main
eestlased	doc_767882159258_item	2864076	et	3	main
lauldi	doc_767882159258_item	2864077	et	3	main
ja	doc_767882159258_item	2864078	et	3	main
rahvalauludes	doc_767882159258_item	2864079	et	3	main
kajastab	doc_767882159258_item	2864080	et	3	main
rahva	doc_767882159258_item	2864081	et	3	main
minevik	doc_767882159258_item	2864082	et	3	main
on	doc_767882159258_item	2864084	et	4	main
rahvalauluga	doc_767882159258_item	2864086	et	4	main
regilaule	doc_767882159258_item	2864102	et	4	main
lastega	doc_767882159258_item	2864107	et	3	main
käsitöö	doc_767882159258_item	2864109	et	4	main
regilaulus	doc_767882159258_item	2864119	et	3	main
sõnad	doc_767882159258_item	2864122	et	4	main
ühe	doc_767882159258_item	2864128	et	4	main
samasuguse	doc_767882159258_item	2864129	et	3	main
sõnaga	doc_767882159258_item	2864130	et	3	main
sajandil	doc_767882159258_item	2864132	et	3	main
tekkis	doc_767882159258_item	2864133	et	3	main
uus	doc_767882159258_item	2864134	et	3	main
riimiline	doc_767882159258_item	2864135	et	4	main
rahvalaul	doc_767882159258_item	2864136	et	4	main
kus	doc_767882159258_item	2864137	et	3	main
read	doc_767882159258_item	2864138	et	3	main
lõpetatakse	doc_767882159258_item	2864139	et	3	main
riimiga	doc_767882159258_item	2864140	et	3	main
on	doc_767882159258_item	2864151	et	4	main
ka	doc_767882159258_item	2864153	et	3	main
lauljad	doc_767882159258_item	2864224	et	4	main
poistekoorid	doc_767882159258_item	2864229	et	3	main
inimesed	doc_767882159258_item	2864234	et	3	main
meelega	doc_767882159258_item	2864236	et	4	main
lähevad	doc_767882159258_item	2864237	et	3	main
iga	doc_767882159258_item	2864238	et	4	main
perega	doc_767882159258_item	2864243	et	3	main
tuttavaid	doc_767882159258_item	2864249	et	3	main
läbi	doc_767882159258_item	2864269	et	4	main
aastate	doc_767882159258_item	2864270	et	3	main
eestlastest	doc_767882159258_item	2864282	et	4	main
laulurahvast	doc_767882159258_item	2864285	et	4	main
19	doc_767882159258_item	2864131	et	2	main
mitmekesisemad	doc_767882159258_item	2864148	et	4	main
iseloomustab	doc_767882159258_item	2864157	et	4	main
ülestähendus	doc_767882159258_item	2864159	et	3	main
kujunes	doc_767882159258_item	2864171	et	3	main
rahvusliku	doc_767882159258_item	2864173	et	3	main
liikumise	doc_767882159258_item	2864174	et	4	main
kõrghetk	doc_767882159258_item	2864175	et	3	main
laulupidusid	doc_767882159258_item	2864182	et	4	main
tallinnas	doc_767882159258_item	2864184	et	4	main
lauluväljakul	doc_767882159258_item	2864185	et	3	main
siia	doc_767882159258_item	2864186	et	4	main
tuleb	doc_767882159258_item	2864187	et	3	main
palju	doc_767882159258_item	2864188	et	4	main
turiste	doc_767882159258_item	2864189	et	3	main
kogu	doc_767882159258_item	2864190	et	4	main
maailmast	doc_767882159258_item	2864191	et	4	main
et	doc_767882159258_item	2864192	et	3	main
vaadata	doc_767882159258_item	2864193	et	4	main
sellele	doc_767882159258_item	2864194	et	4	main
tuntud	doc_767882159258_item	2864195	et	4	main
lauluväljakule	doc_767882159258_item	2864196	et	3	main
eestis	doc_767882159258_item	2864197	et	3	main
ka	doc_767882159258_item	2864198	et	3	main
korraldatakse	doc_767882159258_item	2864199	et	3	main
palju	doc_767882159258_item	2864200	et	4	main
muid	doc_767882159258_item	2864201	et	4	main
muusikapidusid	doc_767882159258_item	2864202	et	4	main
näiteks	doc_767882159258_item	2864203	et	4	main
folklooride	doc_767882159258_item	2864204	et	4	main
festivaali	doc_767882159258_item	2864205	et	4	main
rock	doc_767882159258_item	2864206	et	4	main
festivaali	doc_767882159258_item	2864207	et	4	main
üleeestiline	doc_767882159258_item	2864208	et	4	main
laulupidu	doc_767882159258_item	2864209	et	4	main
on	doc_767882159258_item	2864210	et	4	main
ka	doc_767882159258_item	2864211	et	3	main
praegusel	doc_767882159258_item	2864212	et	3	main
ajal	doc_767882159258_item	2864213	et	4	main
kõige	doc_767882159258_item	2864214	et	4	main
tähelepanuväärsem	doc_767882159258_item	2864215	et	4	main
ja	doc_767882159258_item	2864216	et	3	main
massilisem	doc_767882159258_item	2864217	et	4	main
kõik	doc_767882159258_item	2864121	et	4	main
algavad	doc_767882159258_item	2864123	et	4	main
ühe	doc_767882159258_item	2864124	et	4	main
tähega	doc_767882159258_item	2864125	et	3	main
regilauludest	doc_767882159258_item	2864147	et	3	main
ja	doc_767882159258_item	2864149	et	3	main
esitatud	doc_767882159258_item	2864152	et	4	main
kirjalik	doc_767882159258_item	2864158	et	3	main
ajaloolise	doc_767882159258_item	2864160	et	4	main
esimene	doc_767882159258_item	2864164	et	3	main
ülemaaline	doc_767882159258_item	2864165	et	4	main
laulupidu	doc_767882159258_item	2864166	et	4	main
1869	doc_767882159258_item	2864167	et	2	main
aastal	doc_767882159258_item	2864168	et	3	main
tartus	doc_767882159258_item	2864169	et	3	main
eestlaste	doc_767882159258_item	2864172	et	4	main
meeste-	doc_767882159258_item	2864226	et	4	main
ja	doc_767882159258_item	2864228	et	3	main
orkestrid	doc_767882159258_item	2864233	et	3	main
hea	doc_767882159258_item	2864235	et	4	main
kogu	doc_767882159258_item	2864242	et	4	main
sugulasi	doc_767882159258_item	2864247	et	3	main
kes	doc_767882159258_item	2864250	et	4	main
maailma	doc_767882159258_item	2864254	et	4	main
kokku	doc_767882159258_item	2864255	et	3	main
kuulata	doc_767882159258_item	2864263	et	4	main
kuid	doc_767882159258_item	2864265	et	4	main
nagu	doc_767882159258_item	2864284	et	3	main
kogu	doc_767882159258_item	2864286	et	4	main
maailmas	doc_767882159258_item	2864287	et	3	main
eestlastel	doc_767882159258_item	2864288	et	4	main
on	doc_767882159258_item	2864289	et	4	main
oma	doc_767882159258_item	2864290	et	4	main
muusikaline	doc_767882159258_item	2864291	et	4	main
ajalugu	doc_767882159258_item	2864292	et	4	main
ja	doc_767882159258_item	2864293	et	3	main
palju	doc_767882159258_item	2864294	et	4	main
tuntud	doc_767882159258_item	2864295	et	4	main
heliloojaid	doc_767882159258_item	2864296	et	3	main
kõik	doc_767882159258_item	2864297	et	4	main
see	doc_767882159258_item	2864298	et	3	main
teeb	doc_767882159258_item	2864299	et	3	main
eestlastest	doc_767882159258_item	2864300	et	4	main
laulurahva	doc_767882159258_item	2864301	et	3	main
laulupidudel	doc_767882159258_item	2864221	et	4	main
nii	doc_767882159258_item	2864223	et	3	main
kord	doc_767882159258_item	2864239	et	4	main
niisugustele	doc_767882159258_item	2864240	et	3	main
pidudele	doc_767882159258_item	2864241	et	4	main
on	doc_767882159258_item	2864251	et	4	main
üle	doc_767882159258_item	2864252	et	3	main
kogu	doc_767882159258_item	2864253	et	4	main
võimalus	doc_767882159258_item	2864260	et	3	main
ka	doc_767882159258_item	2864266	et	3	main
ühe	doc_767882159258_item	2864280	et	4	main
räägitakse	doc_767882159258_item	2864283	et	3	main
naiste-	doc_767882159258_item	2864225	et	3	main
ka	doc_767882159258_item	2864231	et	3	main
lootuses	doc_767882159258_item	2864244	et	4	main
sõitnud	doc_767882159258_item	2864256	et	4	main
seal	doc_767882159258_item	2864257	et	4	main
inimestel	doc_767882159258_item	2864258	et	3	main
on	doc_767882159258_item	2864259	et	4	main
mitte	doc_767882159258_item	2864261	et	3	main
laul	doc_767882159258_item	2864271	et	4	main
ühendab	doc_767882159258_item	2864272	et	3	main
inimesi	doc_767882159258_item	2864273	et	4	main
laulupeod	doc_767882159258_item	2864274	et	4	main
tervikuga	doc_767882159258_item	2864281	et	3	main
teise	doc_767882159264_item	2865288	et	4	main
kirjutamine	doc_767882159264_item	2865291	et	4	main
essee	doc_767882159264_item	2865293	et	4	main
teemal	doc_767882159264_item	2865294	et	3	main
mis	doc_767882159264_item	2865295	et	4	main
teeb	doc_767882159264_item	2865296	et	3	main
essee	doc_767882159264_item	2865304	et	4	main
kui	doc_767882159264_item	2865287	et	3	main
essee	doc_767882159264_item	2865299	et	4	main
pikkus	doc_767882159264_item	2865300	et	4	main
300	doc_767882159264_item	2865301	et	2	main
arutlev	doc_767882159264_item	2865307	et	4	main
esitatud	doc_767882159264_item	2865315	et	4	main
head	doc_767882159264_item	2865332	et	4	main
ja	doc_767882159264_item	2865333	et	3	main
laulurahva	doc_767882159264_item	2865354	et	3	main
on	doc_767882159264_item	2865358	et	4	main
tähtis	doc_767882159264_item	2865360	et	4	main
eestis	doc_767882159264_item	2865362	et	3	main
selline	doc_767882159264_item	2865364	et	4	main
esimene	doc_767882159264_item	2865368	et	3	main
tartus	doc_767882159264_item	2865371	et	3	main
aastal	doc_767882159264_item	2865373	et	3	main
rahvalaul	doc_767882159264_item	2865379	et	4	main
ja	doc_767882159264_item	2865380	et	3	main
sellest	doc_767882159264_item	2865381	et	4	main
kõrghetk	doc_767882159264_item	2865386	et	3	main
või	doc_767882159264_item	2865419	et	4	main
muusika	doc_767882159264_item	2865421	et	4	main
see	doc_767882159264_item	2865425	et	3	main
hea	doc_767882159264_item	2865430	et	4	main
test	doc_767882159264_item	2865290	et	3	main
olema	doc_767882159264_item	2865306	et	4	main
tuginema	doc_767882159264_item	2865311	et	3	main
väiteid	doc_767882159264_item	2865317	et	4	main
eestlastest	doc_767882159264_item	2865324	et	4	main
on	doc_767882159264_item	2865328	et	4	main
teeb	doc_767882159264_item	2865352	et	3	main
eestlastest	doc_767882159264_item	2865353	et	4	main
mis	doc_767882159264_item	2865377	et	4	main
rahvusliku	doc_767882159264_item	2865384	et	3	main
huvitav	doc_767882159264_item	2865428	et	4	main
et	doc_767882159264_item	2865431	et	3	main
ja	doc_767882159264_item	2865443	et	3	main
teevad	doc_767882159264_item	2865444	et	3	main
seda	doc_767882159264_item	2865445	et	3	main
aktiivselt	doc_767882159264_item	2865449	et	4	main
teavad	doc_767882159264_item	2865451	et	3	main
arusaamine	doc_767882159264_item	2865473	et	4	main
igal	doc_767882159264_item	2865474	et	3	main
aastal	doc_767882159264_item	2865475	et	3	main
toimub	doc_767882159264_item	2865476	et	3	main
ja	doc_767882159264_item	2865484	et	3	main
kuidas	doc_767882159264_item	2865489	et	3	main
ja	doc_767882159264_item	2865494	et	3	main
seda	doc_767882159264_item	2865498	et	3	main
heameelega	doc_767882159264_item	2865499	et	3	main
ja	doc_767882159264_item	2865500	et	3	main
et	doc_767882159264_item	2865502	et	3	main
on	doc_767882159264_item	2865517	et	4	main
et	doc_767882159264_item	2865523	et	3	main
populaarsed	doc_767882159264_item	2865526	et	3	main
esinevad	doc_767882159264_item	2865534	et	4	main
oma	doc_767882159264_item	2865543	et	4	main
kultuur	doc_767882159264_item	2865544	et	3	main
oma	doc_767882159264_item	2865545	et	4	main
kombed	doc_767882159264_item	2865546	et	3	main
eestlastest	doc_767882159264_item	2865553	et	4	main
väike	doc_767882159264_item	2865558	et	4	main
riik	doc_767882159264_item	2865559	et	3	main
aga	doc_767882159264_item	2865560	et	3	main
mis	doc_767882159264_item	2865579	et	4	main
teeb	doc_767882159264_item	2865580	et	3	main
keele	doc_767882159264_item	2865286	et	4	main
kirjutage	doc_767882159264_item	2865292	et	3	main
350	doc_767882159264_item	2865302	et	2	main
sõna	doc_767882159264_item	2865303	et	4	main
üldistav	doc_767882159264_item	2865310	et	4	main
loengus	doc_767882159264_item	2865312	et	3	main
teeb	doc_767882159264_item	2865323	et	3	main
pahad	doc_767882159264_item	2865334	et	4	main
targad	doc_767882159264_item	2865335	et	3	main
ja	doc_767882159264_item	2865336	et	3	main
rumalad	doc_767882159264_item	2865337	et	3	main
rikkad	doc_767882159264_item	2865338	et	4	main
ja	doc_767882159264_item	2865339	et	3	main
aga	doc_767882159264_item	2865341	et	3	main
et	doc_767882159264_item	2865346	et	3	main
selline	doc_767882159264_item	2865349	et	4	main
nagu	doc_767882159264_item	2865366	et	3	main
on	doc_767882159264_item	2865378	et	4	main
stiilis	doc_767882159264_item	2865415	et	4	main
näiteks	doc_767882159264_item	2865416	et	4	main
essee	doc_767882159264_item	2865284	et	4	main
eesti	doc_767882159264_item	2865285	et	4	main
keele	doc_767882159264_item	2865289	et	4	main
eestlastest	doc_767882159264_item	2865297	et	4	main
laulurahva	doc_767882159264_item	2865298	et	3	main
peab	doc_767882159264_item	2865305	et	4	main
ja	doc_767882159264_item	2865309	et	3	main
lugemistekstis	doc_767882159264_item	2865314	et	3	main
faktidele	doc_767882159264_item	2865316	et	3	main
on	doc_767882159264_item	2865318	et	4	main
soovitatav	doc_767882159264_item	2865319	et	4	main
illustreerida	doc_767882159264_item	2865320	et	3	main
mis	doc_767882159264_item	2865322	et	4	main
analüüsiv	doc_767882159264_item	2865308	et	4	main
ja	doc_767882159264_item	2865313	et	3	main
näidetega	doc_767882159264_item	2865321	et	3	main
meie	doc_767882159264_item	2865326	et	4	main
teavad	doc_767882159264_item	2865345	et	3	main
on	doc_767882159264_item	2865348	et	4	main
asi	doc_767882159264_item	2865350	et	4	main
mis	doc_767882159264_item	2865351	et	4	main
minu	doc_767882159264_item	2865356	et	3	main
jaoks	doc_767882159264_item	2865357	et	4	main
väga	doc_767882159264_item	2865359	et	3	main
et	doc_767882159264_item	2865361	et	3	main
laulupidu	doc_767882159264_item	2865367	et	4	main
laulupidu	doc_767882159264_item	2865369	et	4	main
inimesed	doc_767882159264_item	2865374	et	3	main
liikumise	doc_767882159264_item	2865385	et	4	main
pop	doc_767882159264_item	2865420	et	4	main
ma	doc_767882159264_item	2865422	et	3	main
väga	doc_767882159264_item	2865427	et	3	main
noored	doc_767882159264_item	2865432	et	3	main
selle	doc_767882159264_item	2865434	et	4	main
eestlased	doc_767882159264_item	2865438	et	3	main
väga	doc_767882159264_item	2865448	et	3	main
selline	doc_767882159264_item	2865454	et	4	main
asi	doc_767882159264_item	2865455	et	4	main
nagu	doc_767882159264_item	2865456	et	3	main
tüdrukud	doc_767882159264_item	2865483	et	3	main
laulda	doc_767882159264_item	2865493	et	4	main
teab	doc_767882159264_item	2865501	et	3	main
eesti	doc_767882159264_item	2865503	et	4	main
ilus	doc_767882159264_item	2865507	et	4	main
keel	doc_767882159264_item	2865508	et	4	main
kõik	doc_767882159264_item	2865520	et	4	main
on	doc_767882159264_item	2865525	et	4	main
lauljad	doc_767882159264_item	2865527	et	4	main
teab	doc_767882159264_item	2865529	et	3	main
maailm	doc_767882159264_item	2865531	et	3	main
näitavad	doc_767882159264_item	2865539	et	4	main
et	doc_767882159264_item	2865540	et	3	main
eestis	doc_767882159264_item	2865541	et	3	main
on	doc_767882159264_item	2865542	et	4	main
need	doc_767882159264_item	2865550	et	3	main
süda	doc_767882159264_item	2865562	et	3	main
eestlastest	doc_767882159264_item	2865581	et	4	main
laulurahva	doc_767882159264_item	2865582	et	3	main
küsimus	doc_767882159264_item	2865587	et	4	main
laulurahva	doc_767882159264_item	2865325	et	3	main
maailmas	doc_767882159264_item	2865327	et	3	main
kõik	doc_767882159264_item	2865329	et	4	main
inimesed	doc_767882159264_item	2865330	et	3	main
erinevad	doc_767882159264_item	2865331	et	4	main
vaesed	doc_767882159264_item	2865340	et	4	main
kõik	doc_767882159264_item	2865342	et	4	main
need	doc_767882159264_item	2865343	et	3	main
inimesed	doc_767882159264_item	2865344	et	3	main
maailmas	doc_767882159264_item	2865347	et	3	main
näiteks	doc_767882159264_item	2865355	et	4	main
toimub	doc_767882159264_item	2865363	et	3	main
üritus	doc_767882159264_item	2865365	et	4	main
toimus	doc_767882159264_item	2865370	et	3	main
1869	doc_767882159264_item	2865372	et	2	main
proovisid	doc_767882159264_item	2865375	et	4	main
näidata	doc_767882159264_item	2865376	et	4	main
kujunes	doc_767882159264_item	2865382	et	3	main
eestlaste	doc_767882159264_item	2865383	et	4	main
rahvalaul	doc_767882159264_item	2865387	et	4	main
koosneb	doc_767882159264_item	2865388	et	3	main
kolmest	doc_767882159264_item	2865389	et	4	main
osast	doc_767882159264_item	2865390	et	4	main
laul	doc_767882159264_item	2865391	et	4	main
pillimäng	doc_767882159264_item	2865392	et	3	main
ja	doc_767882159264_item	2865393	et	3	main
tants	doc_767882159264_item	2865394	et	3	main
tänapäeval	doc_767882159264_item	2865395	et	3	main
rahvalaulu	doc_767882159264_item	2865396	et	4	main
arhiivis	doc_767882159264_item	2865397	et	3	main
on	doc_767882159264_item	2865398	et	4	main
palju	doc_767882159264_item	2865399	et	4	main
erinevaid	doc_767882159264_item	2865400	et	4	main
laulu	doc_767882159264_item	2865401	et	4	main
need	doc_767882159264_item	2865402	et	3	main
laulud	doc_767882159264_item	2865403	et	3	main
meeldivad	doc_767882159264_item	2865404	et	4	main
noortele	doc_767882159264_item	2865405	et	3	main
ja	doc_767882159264_item	2865406	et	3	main
nad	doc_767882159264_item	2865407	et	3	main
hakkavad	doc_767882159264_item	2865408	et	4	main
nendest	doc_767882159264_item	2865409	et	4	main
kasutada	doc_767882159264_item	2865411	et	3	main
sõna	doc_767882159264_item	2865410	et	4	main
ja	doc_767882159264_item	2865412	et	3	main
laulda	doc_767882159264_item	2865413	et	4	main
oma	doc_767882159264_item	2865414	et	4	main
rock	doc_767882159264_item	2865417	et	4	main
muusika	doc_767882159264_item	2865418	et	4	main
arvan	doc_767882159264_item	2865423	et	3	main
ja	doc_767882159264_item	2865429	et	3	main
muusikaga	doc_767882159264_item	2865435	et	3	main
igal	doc_767882159264_item	2865436	et	3	main
osa	doc_767882159264_item	2865440	et	4	main
ja	doc_767882159264_item	2865447	et	3	main
nad	doc_767882159264_item	2865450	et	3	main
täpselt	doc_767882159264_item	2865452	et	4	main
et	doc_767882159264_item	2865453	et	3	main
oma	doc_767882159264_item	2865471	et	4	main
selline	doc_767882159264_item	2865478	et	4	main
nagu	doc_767882159264_item	2865480	et	3	main
poisid	doc_767882159264_item	2865485	et	4	main
oskusi	doc_767882159264_item	2865488	et	3	main
vaatab	doc_767882159264_item	2865497	et	3	main
keel	doc_767882159264_item	2865504	et	4	main
meie	doc_767882159264_item	2865518	et	4	main
tulevik	doc_767882159264_item	2865519	et	3	main
eestis	doc_767882159264_item	2865524	et	3	main
terve	doc_767882159264_item	2865535	et	4	main
rahva	doc_767882159264_item	2865536	et	3	main
asemel	doc_767882159264_item	2865537	et	4	main
ja	doc_767882159264_item	2865538	et	3	main
ja	doc_767882159264_item	2865547	et	3	main
asjad	doc_767882159264_item	2865551	et	3	main
eesti	doc_767882159264_item	2865555	et	4	main
on	doc_767882159264_item	2865556	et	4	main
väga	doc_767882159264_item	2865557	et	3	main
on	doc_767882159264_item	2865563	et	4	main
suur	doc_767882159264_item	2865564	et	3	main
soe	doc_767882159264_item	2865566	et	4	main
et	doc_767882159264_item	2865568	et	3	main
aitab	doc_767882159264_item	2865570	et	3	main
inimestel	doc_767882159264_item	2865571	et	3	main
elada	doc_767882159264_item	2865572	et	3	main
mitte	doc_767882159264_item	2865573	et	3	main
lihtsalt	doc_767882159264_item	2865574	et	4	main
elada	doc_767882159264_item	2865575	et	3	main
aga	doc_767882159264_item	2865576	et	3	main
elada	doc_767882159264_item	2865577	et	3	main
naeratusega	doc_767882159264_item	2865578	et	4	main
huvitav	doc_767882159264_item	2865586	et	4	main
minu	doc_767882159264_item	2865588	et	3	main
on	doc_767882159264_item	2865592	et	4	main
lihtne	doc_767882159264_item	2865593	et	3	main
et	doc_767882159264_item	2865424	et	3	main
on	doc_767882159264_item	2865426	et	4	main
tegelevad	doc_767882159264_item	2865433	et	4	main
aastal	doc_767882159264_item	2865437	et	3	main
võtavad	doc_767882159264_item	2865439	et	3	main
eurolaulu	doc_767882159264_item	2865441	et	4	main
muusika	doc_767882159264_item	2865457	et	4	main
teeb	doc_767882159264_item	2865458	et	3	main
eestlastest	doc_767882159264_item	2865459	et	4	main
laulurahva	doc_767882159264_item	2865460	et	3	main
terve	doc_767882159264_item	2865461	et	4	main
maailm	doc_767882159264_item	2865462	et	3	main
peab	doc_767882159264_item	2865463	et	4	main
teadma	doc_767882159264_item	2865464	et	3	main
et	doc_767882159264_item	2865465	et	3	main
eestis	doc_767882159264_item	2865466	et	3	main
on	doc_767882159264_item	2865467	et	4	main
oma	doc_767882159264_item	2865468	et	4	main
laulutraditsioonid	doc_767882159264_item	2865469	et	3	main
ja	doc_767882159264_item	2865470	et	3	main
võistlusest	doc_767882159264_item	2865442	et	4	main
meelsasti	doc_767882159264_item	2865446	et	3	main
muusika	doc_767882159264_item	2865472	et	4	main
üritus	doc_767882159264_item	2865479	et	4	main
vanalinna	doc_767882159264_item	2865481	et	4	main
päevad	doc_767882159264_item	2865482	et	3	main
oskavad	doc_767882159264_item	2865491	et	4	main
tantsida	doc_767882159264_item	2865492	et	3	main
on	doc_767882159264_item	2865505	et	4	main
tallinnas	doc_767882159264_item	2865477	et	4	main
näitavad	doc_767882159264_item	2865486	et	4	main
oma	doc_767882159264_item	2865487	et	4	main
nad	doc_767882159264_item	2865490	et	3	main
esineda	doc_767882159264_item	2865495	et	3	main
rahvas	doc_767882159264_item	2865496	et	4	main
väga	doc_767882159264_item	2865506	et	3	main
rahvas	doc_767882159264_item	2865509	et	4	main
teab	doc_767882159264_item	2865510	et	3	main
et	doc_767882159264_item	2865511	et	3	main
noored	doc_767882159264_item	2865512	et	3	main
teevad	doc_767882159264_item	2865513	et	3	main
eestlastest	doc_767882159264_item	2865514	et	4	main
laulurahva	doc_767882159264_item	2865515	et	3	main
noored	doc_767882159264_item	2865516	et	3	main
me	doc_767882159264_item	2865521	et	4	main
keda	doc_767882159264_item	2865528	et	4	main
terve	doc_767882159264_item	2865530	et	4	main
need	doc_767882159264_item	2865532	et	3	main
lauljad	doc_767882159264_item	2865533	et	4	main
laulutraditsioonid	doc_767882159264_item	2865548	et	3	main
teevad	doc_767882159264_item	2865552	et	3	main
aga	doc_767882159264_item	2865590	et	3	main
essee	doc_767882159266_item	2865878	et	4	main
pikkus	doc_767882159266_item	2865879	et	4	main
300	doc_767882159266_item	2865880	et	2	main
arutlev	doc_767882159266_item	2865886	et	4	main
laulmine	doc_767882159266_item	2865924	et	4	main
emotsionaalne	doc_767882159266_item	2865928	et	3	main
meid	doc_767882159266_item	2865932	et	4	main
hästi	doc_767882159266_item	2865933	et	3	main
end	doc_767882159266_item	2865934	et	4	main
väljendada	doc_767882159266_item	2865935	et	3	main
igal	doc_767882159266_item	2865936	et	3	main
rahval	doc_767882159266_item	2865937	et	3	main
on	doc_767882159266_item	2865938	et	4	main
teame	doc_767882159264_item	2865522	et	3	main
kõik	doc_767882159264_item	2865549	et	4	main
laulurahva	doc_767882159264_item	2865554	et	3	main
riigi	doc_767882159264_item	2865561	et	3	main
ja	doc_767882159264_item	2865565	et	3	main
sellepärast	doc_767882159264_item	2865567	et	3	main
laul	doc_767882159264_item	2865569	et	4	main
see	doc_767882159264_item	2865583	et	3	main
on	doc_767882159264_item	2865584	et	4	main
väga	doc_767882159264_item	2865585	et	3	main
jaoks	doc_767882159264_item	2865589	et	4	main
vastus	doc_767882159264_item	2865591	et	3	main
eesti	doc_767882159264_item	2865594	et	4	main
rahvas	doc_767882159264_item	2865595	et	4	main
teeb	doc_767882159264_item	2865596	et	3	main
ennast	doc_767882159264_item	2865597	et	4	main
laulurahva	doc_767882159264_item	2865598	et	3	main
nad	doc_767882159264_item	2865599	et	3	main
laulavad	doc_767882159264_item	2865600	et	4	main
võtavad	doc_767882159264_item	2865601	et	3	main
osa	doc_767882159264_item	2865602	et	4	main
erinevatest	doc_767882159264_item	2865603	et	4	main
võistlustest	doc_767882159264_item	2865604	et	4	main
ja	doc_767882159264_item	2865605	et	3	main
teevad	doc_767882159264_item	2865606	et	3	main
seda	doc_767882159264_item	2865607	et	3	main
enda	doc_767882159264_item	2865608	et	4	main
jaoks	doc_767882159264_item	2865609	et	4	main
teise	doc_767882159266_item	2865867	et	4	main
keele	doc_767882159266_item	2865868	et	4	main
test	doc_767882159266_item	2865869	et	3	main
teeb	doc_767882159266_item	2865875	et	3	main
350	doc_767882159266_item	2865881	et	2	main
sõna	doc_767882159266_item	2865882	et	4	main
analüüsiv	doc_767882159266_item	2865887	et	4	main
ja	doc_767882159266_item	2865888	et	3	main
niisugused	doc_767882159266_item	2865945	et	3	main
eestis	doc_767882159266_item	2865948	et	3	main
teavad	doc_767882159266_item	2865950	et	3	main
tähtis	doc_767882159266_item	2865961	et	4	main
et	doc_767882159266_item	2865965	et	3	main
tahaks	doc_767882159266_item	2865968	et	3	main
ajaloo	doc_767882159266_item	2865970	et	4	main
unustada	doc_767882159266_item	2865971	et	3	main
nad	doc_767882159266_item	2865972	et	3	main
tahaksid	doc_767882159266_item	2865973	et	4	main
et	doc_767882159266_item	2865974	et	3	main
need	doc_767882159266_item	2865975	et	3	main
laulud	doc_767882159266_item	2865976	et	3	main
unustad	doc_767882159266_item	2866014	et	3	main
tunned	doc_767882159266_item	2866017	et	3	main
laulurahva	doc_767882159266_item	2866019	et	3	main
essee	doc_767882159266_item	2865863	et	4	main
eesti	doc_767882159266_item	2865864	et	4	main
mis	doc_767882159266_item	2865874	et	4	main
eestlastest	doc_767882159266_item	2865876	et	4	main
laulurahva	doc_767882159266_item	2865877	et	3	main
tuginema	doc_767882159266_item	2865890	et	3	main
mina	doc_767882159266_item	2865921	et	4	main
et	doc_767882159266_item	2865923	et	3	main
aitab	doc_767882159266_item	2865931	et	3	main
ja	doc_767882159266_item	2865941	et	3	main
kirjutamine	doc_767882159266_item	2865870	et	4	main
essee	doc_767882159266_item	2865872	et	4	main
teemal	doc_767882159266_item	2865873	et	3	main
essee	doc_767882159266_item	2865883	et	4	main
üldistav	doc_767882159266_item	2865889	et	4	main
keele	doc_767882159266_item	2865865	et	4	main
kui	doc_767882159266_item	2865866	et	3	main
kirjutage	doc_767882159266_item	2865871	et	3	main
peab	doc_767882159266_item	2865884	et	4	main
olema	doc_767882159266_item	2865885	et	4	main
loengus	doc_767882159266_item	2865891	et	3	main
ja	doc_767882159266_item	2865892	et	3	main
lugemistekstis	doc_767882159266_item	2865893	et	3	main
esitatud	doc_767882159266_item	2865894	et	4	main
faktidele	doc_767882159266_item	2865895	et	3	main
väiteid	doc_767882159266_item	2865896	et	4	main
soovitatav	doc_767882159266_item	2865898	et	4	main
on	doc_767882159266_item	2865897	et	4	main
illustreerida	doc_767882159266_item	2865899	et	3	main
näidetega	doc_767882159266_item	2865900	et	3	main
mis	doc_767882159266_item	2865901	et	4	main
teeb	doc_767882159266_item	2865902	et	3	main
eestlastest	doc_767882159266_item	2865903	et	4	main
laulurahva	doc_767882159266_item	2865904	et	3	main
laulmine	doc_767882159266_item	2865905	et	4	main
mängib	doc_767882159266_item	2865906	et	3	main
suur	doc_767882159266_item	2865907	et	3	main
rolli	doc_767882159266_item	2865908	et	4	main
inimeste	doc_767882159266_item	2865909	et	3	main
elus	doc_767882159266_item	2865910	et	4	main
laulavad	doc_767882159266_item	2865911	et	4	main
nii	doc_767882159266_item	2865912	et	3	main
noored	doc_767882159266_item	2865913	et	3	main
kui	doc_767882159266_item	2865914	et	3	main
ka	doc_767882159266_item	2865915	et	3	main
täiskasvanud	doc_767882159266_item	2865916	et	4	main
ja	doc_767882159266_item	2865917	et	3	main
laulavad	doc_767882159266_item	2865918	et	4	main
erinevad	doc_767882159266_item	2865919	et	4	main
laulud	doc_767882159266_item	2865920	et	3	main
arvan	doc_767882159266_item	2865922	et	3	main
on	doc_767882159266_item	2865926	et	4	main
kõigepealt	doc_767882159266_item	2865927	et	3	main
väljendusvahend	doc_767882159266_item	2865929	et	3	main
mis	doc_767882159266_item	2865930	et	4	main
oma	doc_767882159266_item	2865939	et	4	main
loomulikult	doc_767882159266_item	2865942	et	4	main
on	doc_767882159266_item	2865959	et	4	main
väga	doc_767882159266_item	2865960	et	3	main
sellepärast	doc_767882159266_item	2865964	et	3	main
nad	doc_767882159266_item	2865966	et	3	main
see	doc_767882159266_item	2865925	et	3	main
kombed	doc_767882159266_item	2865940	et	3	main
laulud	doc_767882159266_item	2865946	et	3	main
mis	doc_767882159266_item	2865949	et	4	main
ka	doc_767882159266_item	2865951	et	3	main
inimeste	doc_767882159266_item	2865962	et	3	main
teaksid	doc_767882159266_item	2865977	et	4	main
ka	doc_767882159266_item	2865978	et	3	main
nende	doc_767882159266_item	2865979	et	4	main
lapsed	doc_767882159266_item	2865980	et	3	main
ma	doc_767882159266_item	2865981	et	3	main
arvan	doc_767882159266_item	2865982	et	3	main
et	doc_767882159266_item	2865983	et	3	main
jaoks	doc_767882159266_item	2865985	et	4	main
rahvalaul	doc_767882159266_item	2865986	et	4	main
eestlaste	doc_767882159266_item	2865984	et	4	main
on	doc_767882159266_item	2865987	et	4	main
väga	doc_767882159266_item	2865988	et	3	main
huvitav	doc_767882159266_item	2865989	et	4	main
me	doc_767882159266_item	2865990	et	4	main
näeme	doc_767882159266_item	2865991	et	3	main
et	doc_767882159266_item	2865992	et	3	main
lauluväljakul	doc_767882159266_item	2865993	et	3	main
on	doc_767882159266_item	2865994	et	4	main
alati	doc_767882159266_item	2865995	et	4	main
nii	doc_767882159266_item	2865996	et	3	main
palju	doc_767882159266_item	2865997	et	4	main
inimesi	doc_767882159266_item	2865998	et	4	main
nii	doc_767882159266_item	2865999	et	3	main
lapsed	doc_767882159266_item	2866000	et	3	main
kui	doc_767882159266_item	2866001	et	3	main
ka	doc_767882159266_item	2866002	et	3	main
täiskasvanud	doc_767882159266_item	2866003	et	4	main
ja	doc_767882159266_item	2866004	et	3	main
isegi	doc_767882159266_item	2866005	et	4	main
vanemad	doc_767882159266_item	2866006	et	4	main
inimesed	doc_767882159266_item	2866007	et	3	main
laulurahvas	doc_767882159266_item	2866008	et	4	main
oma	doc_767882159266_item	2865943	et	4	main
jaoks	doc_767882159266_item	2865963	et	4	main
ei	doc_767882159266_item	2865967	et	4	main
oma	doc_767882159266_item	2865969	et	4	main
iga	doc_767882159266_item	2866024	et	4	main
on	doc_767882159266_item	2866026	et	4	main
erinev	doc_767882159266_item	2866027	et	4	main
näiteks	doc_767882159266_item	2866028	et	4	main
esimeses	doc_767882159266_item	2866029	et	3	main
kokkusaades	doc_767882159266_item	2866034	et	4	main
kooriga	doc_767882159266_item	2866048	et	4	main
meeldivad	doc_767882159266_item	2866073	et	4	main
et	doc_767882159266_item	2866077	et	3	main
teised	doc_767882159266_item	2866079	et	4	main
olen	doc_767882159266_item	2866085	et	3	main
et	doc_767882159266_item	2866087	et	3	main
toob	doc_767882159266_item	2866089	et	3	main
huvi	doc_767882159266_item	2866101	et	4	main
momentid	doc_767882159266_item	2866105	et	4	main
populaarsed	doc_767882159266_item	2866107	et	3	main
lauljad	doc_767882159266_item	2866108	et	4	main
või	doc_767882159266_item	2866113	et	4	main
mulle	doc_767882159266_item	2866119	et	4	main
eestlased	doc_767882159266_item	2866122	et	3	main
rahvalaulud	doc_767882159266_item	2865944	et	3	main
on	doc_767882159266_item	2865947	et	4	main
teised	doc_767882159266_item	2865952	et	4	main
rahvad	doc_767882159266_item	2865953	et	3	main
rahvalauludes	doc_767882159266_item	2865954	et	3	main
kajastub	doc_767882159266_item	2865955	et	3	main
rahva	doc_767882159266_item	2865956	et	3	main
minevik	doc_767882159266_item	2865957	et	3	main
mis	doc_767882159266_item	2865958	et	4	main
ja	doc_767882159266_item	2866016	et	3	main
ennast	doc_767882159266_item	2866018	et	4	main
huvitav	doc_767882159266_item	2866022	et	4	main
laul	doc_767882159266_item	2866025	et	4	main
naised	doc_767882159266_item	2866032	et	3	main
koor	doc_767882159266_item	2866039	et	4	main
või	doc_767882159266_item	2866040	et	4	main
väga	doc_767882159266_item	2866042	et	3	main
tihti	doc_767882159266_item	2866043	et	3	main
mõned	doc_767882159266_item	2866078	et	3	main
rahvad	doc_767882159266_item	2866080	et	3	main
täna	doc_767882159266_item	2866096	et	4	main
inimestel	doc_767882159266_item	2866097	et	3	main
tihti	doc_767882159266_item	2866103	et	3	main
kasutavad	doc_767882159266_item	2866106	et	4	main
tekitab	doc_767882159266_item	2866116	et	3	main
alati	doc_767882159266_item	2866123	et	4	main
oma	doc_767882159266_item	2866125	et	4	main
täna	doc_767882159266_item	2866129	et	4	main
laulab	doc_767882159266_item	2866009	et	3	main
nii	doc_767882159266_item	2866010	et	3	main
ilus	doc_767882159266_item	2866011	et	4	main
et	doc_767882159266_item	2866012	et	3	main
mõnikord	doc_767882159266_item	2866013	et	3	main
osast	doc_767882159266_item	2866020	et	4	main
väga	doc_767882159266_item	2866021	et	3	main
laulavad	doc_767882159266_item	2866031	et	4	main
teises	doc_767882159266_item	2866035	et	4	main
laulas	doc_767882159266_item	2866036	et	4	main
võtab	doc_767882159266_item	2866037	et	3	main
osa	doc_767882159266_item	2866038	et	4	main
tavalised	doc_767882159266_item	2866045	et	4	main
inimesed	doc_767882159266_item	2866046	et	3	main
koos	doc_767882159266_item	2866047	et	4	main
üritused	doc_767882159266_item	2866070	et	4	main
seepärast	doc_767882159266_item	2866071	et	3	main
nad	doc_767882159266_item	2866072	et	3	main
teame	doc_767882159266_item	2866076	et	3	main
võttavad	doc_767882159266_item	2866081	et	4	main
midagi	doc_767882159266_item	2866082	et	4	main
veendunud	doc_767882159266_item	2866086	et	4	main
ka	doc_767882159266_item	2866090	et	3	main
näiteks	doc_767882159266_item	2866111	et	4	main
see	doc_767882159266_item	2866115	et	3	main
tundub	doc_767882159266_item	2866120	et	3	main
et	doc_767882159266_item	2866121	et	3	main
veel	doc_767882159266_item	2866130	et	4	main
kõikidest	doc_767882159266_item	2866015	et	4	main
et	doc_767882159266_item	2866023	et	3	main
omavahel	doc_767882159266_item	2866033	et	3	main
mehed	doc_767882159266_item	2866041	et	3	main
või	doc_767882159266_item	2866049	et	4	main
eeslauljaga	doc_767882159266_item	2866050	et	3	main
see	doc_767882159266_item	2866051	et	3	main
toob	doc_767882159266_item	2866052	et	3	main
teistele	doc_767882159266_item	2866074	et	4	main
endale	doc_767882159266_item	2866083	et	4	main
on	doc_767882159266_item	2866098	et	4	main
väga	doc_767882159266_item	2866099	et	3	main
suur	doc_767882159266_item	2866100	et	3	main
mõned	doc_767882159266_item	2866104	et	3	main
tekstisõnad	doc_767882159266_item	2866112	et	3	main
huvi	doc_767882159266_item	2866118	et	4	main
väärtustasid	doc_767882159266_item	2866124	et	4	main
kultuuri	doc_767882159266_item	2866126	et	4	main
ja	doc_767882159266_item	2866127	et	3	main
rohkem	doc_767882159266_item	2866131	et	4	main
laulas	doc_767882159266_item	2866030	et	4	main
laulavad	doc_767882159266_item	2866044	et	4	main
rõõmu	doc_767882159266_item	2866053	et	4	main
eestlased	doc_767882159266_item	2866054	et	3	main
korraldavad	doc_767882159266_item	2866055	et	4	main
erinevad	doc_767882159266_item	2866056	et	4	main
folkloorifestivalid	doc_767882159266_item	2866057	et	3	main
võtavad	doc_767882159266_item	2866058	et	3	main
osa	doc_767882159266_item	2866059	et	4	main
ka	doc_767882159266_item	2866060	et	3	main
erinevad	doc_767882159266_item	2866061	et	4	main
ansamblid	doc_767882159266_item	2866062	et	3	main
mulle	doc_767882159266_item	2866063	et	4	main
tundub	doc_767882159266_item	2866064	et	3	main
et	doc_767882159266_item	2866065	et	3	main
kui	doc_767882159266_item	2866066	et	3	main
eestlased	doc_767882159266_item	2866067	et	3	main
organiseerivad	doc_767882159266_item	2866068	et	4	main
niisugused	doc_767882159266_item	2866069	et	3	main
me	doc_767882159266_item	2866075	et	4	main
ma	doc_767882159266_item	2866084	et	3	main
laulurahvas	doc_767882159266_item	2866088	et	4	main
kaasa	doc_767882159266_item	2866091	et	4	main
naeratust	doc_767882159266_item	2866092	et	4	main
samuti	doc_767882159266_item	2866093	et	3	main
ilusad	doc_767882159266_item	2866094	et	3	main
rahvariided	doc_767882159266_item	2866095	et	3	main
rahvalaule	doc_767882159266_item	2866102	et	4	main
oma	doc_767882159266_item	2866109	et	4	main
lauldes	doc_767882159266_item	2866110	et	3	main
riided	doc_767882159266_item	2866114	et	3	main
alati	doc_767882159266_item	2866117	et	4	main
väärtustavad	doc_767882159266_item	2866128	et	4	main
on	doc_767882159269_item	2866723	et	4	main
eestlastest	doc_767882159269_item	2866741	et	4	main
laulurahva	doc_767882159269_item	2866742	et	3	main
ma	doc_767882159269_item	2866743	et	3	main
kõigepealt	doc_767882159269_item	2866746	et	3	main
et	doc_767882159269_item	2866752	et	3	main
alati	doc_767882159269_item	2866762	et	4	main
saada	doc_767882159269_item	2866764	et	4	main
headusest	doc_767882159269_item	2866794	et	4	main
areneb	doc_767882159269_item	2866796	et	3	main
varajaste	doc_767882159269_item	2866800	et	3	main
ja	doc_767882159269_item	2866811	et	3	main
pean	doc_767882159269_item	2866813	et	4	main
et	doc_767882159269_item	2866815	et	3	main
muusika	doc_767882159269_item	2866818	et	4	main
on	doc_767882159269_item	2866819	et	4	main
populaarne	doc_767882159269_item	2866820	et	3	main
meelest	doc_767882159269_item	2866720	et	4	main
faktidele	doc_767882159269_item	2866713	et	3	main
on	doc_767882159269_item	2866715	et	4	main
soovitatav	doc_767882159269_item	2866716	et	4	main
illustreerida	doc_767882159269_item	2866717	et	3	main
näidetega	doc_767882159269_item	2866718	et	3	main
essee	doc_767882159269_item	2866681	et	4	main
keele	doc_767882159269_item	2866683	et	4	main
eesti	doc_767882159269_item	2866682	et	4	main
kui	doc_767882159269_item	2866684	et	3	main
teise	doc_767882159269_item	2866685	et	4	main
keele	doc_767882159269_item	2866686	et	4	main
test	doc_767882159269_item	2866687	et	3	main
kirjutamine	doc_767882159269_item	2866688	et	4	main
kirjutage	doc_767882159269_item	2866689	et	3	main
essee	doc_767882159269_item	2866690	et	4	main
teemal	doc_767882159269_item	2866691	et	3	main
mis	doc_767882159269_item	2866692	et	4	main
teeb	doc_767882159269_item	2866693	et	3	main
eestlastest	doc_767882159269_item	2866694	et	4	main
laulurahva	doc_767882159269_item	2866695	et	3	main
essee	doc_767882159269_item	2866696	et	4	main
pikkus	doc_767882159269_item	2866697	et	4	main
300	doc_767882159269_item	2866698	et	2	main
350	doc_767882159269_item	2866699	et	2	main
sõna	doc_767882159269_item	2866700	et	4	main
essee	doc_767882159269_item	2866701	et	4	main
peab	doc_767882159269_item	2866702	et	4	main
olema	doc_767882159269_item	2866703	et	4	main
arutlev	doc_767882159269_item	2866704	et	4	main
ja	doc_767882159269_item	2866706	et	3	main
üldistav	doc_767882159269_item	2866707	et	4	main
tuginema	doc_767882159269_item	2866708	et	3	main
analüüsiv	doc_767882159269_item	2866705	et	4	main
loengus	doc_767882159269_item	2866709	et	3	main
ja	doc_767882159269_item	2866710	et	3	main
lugemistekstis	doc_767882159269_item	2866711	et	3	main
traditsiooni	doc_767882159269_item	2866721	et	4	main
väga	doc_767882159269_item	2866724	et	3	main
meie	doc_767882159269_item	2866727	et	4	main
võib	doc_767882159269_item	2866729	et	3	main
oletada	doc_767882159269_item	2866730	et	3	main
et	doc_767882159269_item	2866731	et	3	main
tänapäevaseni	doc_767882159269_item	2866732	et	4	main
nii	doc_767882159269_item	2866733	et	3	main
selleks	doc_767882159269_item	2866751	et	4	main
kui	doc_767882159269_item	2866757	et	3	main
vanemate	doc_767882159269_item	2866766	et	4	main
ajalugu	doc_767882159269_item	2866767	et	4	main
laulud	doc_767882159269_item	2866801	et	3	main
on	doc_767882159269_item	2866803	et	4	main
rahvaarhiivis	doc_767882159269_item	2866806	et	3	main
südamlikust	doc_767882159269_item	2866812	et	4	main
tunnistama	doc_767882159269_item	2866814	et	3	main
vanaaegne	doc_767882159269_item	2866817	et	3	main
teevad	doc_767882159269_item	2866825	et	3	main
kahjuks	doc_767882159269_item	2866828	et	4	main
regivärsilised	doc_767882159269_item	2866829	et	4	main
laulud	doc_767882159269_item	2866830	et	3	main
lõuna	doc_767882159269_item	2866836	et	4	main
ja	doc_767882159269_item	2866837	et	3	main
meie	doc_767882159269_item	2866844	et	4	main
tutvuda	doc_767882159269_item	2866848	et	3	main
asjades	doc_767882159269_item	2866861	et	3	main
täpselt	doc_767882159269_item	2866882	et	4	main
suhtuvad	doc_767882159269_item	2866890	et	4	main
laulusse	doc_767882159269_item	2866891	et	3	main
armastusega	doc_767882159269_item	2866892	et	4	main
ma	doc_767882159269_item	2866893	et	3	main
öelda	doc_767882159269_item	2866904	et	4	main
minust	doc_767882159269_item	2866908	et	3	main
vene	doc_767882159269_item	2866921	et	4	main
vaid	doc_767882159269_item	2866923	et	3	main
ikkagi	doc_767882159269_item	2866924	et	4	main
ja	doc_767882159269_item	2866934	et	3	main
soovi	doc_767882159269_item	2866935	et	4	main
öelda	doc_767882159269_item	2866943	et	4	main
on	doc_767882159269_item	2866947	et	4	main
arenenud	doc_767882159269_item	2866949	et	4	main
mõjult	doc_767882159269_item	2866964	et	3	main
elus	doc_767882159269_item	2866975	et	4	main
kui	doc_767882159269_item	2866977	et	3	main
esitatud	doc_767882159269_item	2866712	et	4	main
väiteid	doc_767882159269_item	2866714	et	4	main
tegu	doc_767882159269_item	2866726	et	4	main
traditsioonid	doc_767882159269_item	2866734	et	3	main
kui	doc_767882159269_item	2866735	et	3	main
ka	doc_767882159269_item	2866736	et	3	main
iseseisvate	doc_767882159269_item	2866737	et	3	main
vaim	doc_767882159269_item	2866738	et	3	main
aitavad	doc_767882159269_item	2866739	et	4	main
teha	doc_767882159269_item	2866740	et	3	main
palju	doc_767882159269_item	2866749	et	4	main
laulada	doc_767882159269_item	2866753	et	4	main
kaasaegse	doc_767882159269_item	2866755	et	3	main
ka	doc_767882159269_item	2866758	et	3	main
ja	doc_767882159269_item	2866795	et	3	main
armastust	doc_767882159269_item	2866797	et	4	main
vahel	doc_767882159269_item	2866799	et	4	main
leida	doc_767882159269_item	2866805	et	3	main
kui	doc_767882159269_item	2866823	et	3	main
kaotanud	doc_767882159269_item	2866832	et	4	main
vaid	doc_767882159269_item	2866833	et	3	main
kui	doc_767882159269_item	2866840	et	3	main
seda	doc_767882159269_item	2866841	et	3	main
lapsel	doc_767882159269_item	2866845	et	4	main
võimalus	doc_767882159269_item	2866847	et	3	main
see	doc_767882159269_item	2866862	et	3	main
koolis	doc_767882159269_item	2866876	et	4	main
aasta	doc_767882159269_item	2866878	et	4	main
jooksul	doc_767882159269_item	2866879	et	4	main
ja	doc_767882159269_item	2866880	et	3	main
tean	doc_767882159269_item	2866881	et	3	main
kõik	doc_767882159269_item	2866885	et	4	main
kes	doc_767882159269_item	2866887	et	4	main
eestis	doc_767882159269_item	2866889	et	3	main
korda	doc_767882159269_item	2866898	et	4	main
tean	doc_767882159269_item	2866900	et	3	main
rahvalaulu	doc_767882159269_item	2866902	et	4	main
laulamine	doc_767882159269_item	2866906	et	4	main
keel	doc_767882159269_item	2866922	et	4	main
vastu	doc_767882159269_item	2866931	et	3	main
annab	doc_767882159269_item	2866932	et	3	main
jõudu	doc_767882159269_item	2866933	et	4	main
armastus	doc_767882159269_item	2866937	et	4	main
võimalus	doc_767882159269_item	2866941	et	3	main
eestis	doc_767882159269_item	2866946	et	3	main
hästi	doc_767882159269_item	2866948	et	3	main
koorid	doc_767882159269_item	2866950	et	4	main
ja	doc_767882159269_item	2866951	et	3	main
nad	doc_767882159269_item	2866952	et	3	main
esitevad	doc_767882159269_item	2866953	et	4	main
maailmas	doc_767882159269_item	2866954	et	3	main
minu	doc_767882159269_item	2866955	et	3	main
teiste	doc_767882159269_item	2866961	et	4	main
oma	doc_767882159269_item	2866967	et	4	main
meiega	doc_767882159269_item	2866974	et	4	main
elu	doc_767882159269_item	2867009	et	4	main
armastus	doc_767882159269_item	2867010	et	4	main
tunned	doc_767882159269_item	2867011	et	3	main
minu	doc_767882159269_item	2866719	et	3	main
oluline	doc_767882159269_item	2866725	et	4	main
elus	doc_767882159269_item	2866728	et	4	main
mõtlen	doc_767882159269_item	2866744	et	3	main
eestlastel	doc_767882159269_item	2866747	et	4	main
on	doc_767882159269_item	2866748	et	4	main
aru	doc_767882159269_item	2866765	et	4	main
oma	doc_767882159269_item	2866771	et	4	main
elust	doc_767882159269_item	2866772	et	3	main
inimeste	doc_767882159269_item	2866798	et	3	main
võivad	doc_767882159269_item	2866807	et	4	main
lastele	doc_767882159269_item	2866809	et	4	main
modermsalt	doc_767882159269_item	2866827	et	4	main
siis	doc_767882159269_item	2866843	et	3	main
paljudes	doc_767882159269_item	2866860	et	3	main
osast	doc_767882159269_item	2866865	et	4	main
pillimäng	doc_767882159269_item	2866869	et	3	main
tahan	doc_767882159269_item	2866870	et	3	main
öelda	doc_767882159269_item	2866871	et	4	main
et	doc_767882159269_item	2866872	et	3	main
ma	doc_767882159269_item	2866873	et	3	main
üheksa	doc_767882159269_item	2866877	et	4	main
võtasin	doc_767882159269_item	2866894	et	4	main
laulurahva	doc_767882159269_item	2866909	et	3	main
jätkamine	doc_767882159269_item	2866722	et	4	main
et	doc_767882159269_item	2866745	et	3	main
põhjusi	doc_767882159269_item	2866750	et	3	main
nii	doc_767882159269_item	2866754	et	3	main
muusikat	doc_767882159269_item	2866756	et	3	main
vana	doc_767882159269_item	2866759	et	4	main
muusikat	doc_767882159269_item	2866760	et	3	main
see	doc_767882159269_item	2866761	et	3	main
aitab	doc_767882159269_item	2866763	et	3	main
varem	doc_767882159269_item	2866768	et	4	main
laulasid	doc_767882159269_item	2866769	et	4	main
naised	doc_767882159269_item	2866770	et	3	main
tööst	doc_767882159269_item	2866773	et	3	main
perekonnast	doc_767882159269_item	2866774	et	4	main
ja	doc_767882159269_item	2866775	et	3	main
see	doc_767882159269_item	2866776	et	3	main
lubas	doc_767882159269_item	2866777	et	3	main
ennast	doc_767882159269_item	2866778	et	4	main
väljandada	doc_767882159269_item	2866779	et	4	main
praegu	doc_767882159269_item	2866780	et	3	main
laulades	doc_767882159269_item	2866781	et	3	main
on	doc_767882159269_item	2866782	et	4	main
lihtsam	doc_767882159269_item	2866783	et	4	main
rääkida	doc_767882159269_item	2866784	et	3	main
tundest	doc_767882159269_item	2866785	et	4	main
teiseks	doc_767882159269_item	2866786	et	4	main
arvan	doc_767882159269_item	2866787	et	3	main
et	doc_767882159269_item	2866788	et	3	main
halbas	doc_767882159269_item	2866789	et	4	main
olukorras	doc_767882159269_item	2866790	et	3	main
laul	doc_767882159269_item	2866791	et	4	main
aitab	doc_767882159269_item	2866792	et	3	main
mõelda	doc_767882159269_item	2866793	et	4	main
mis	doc_767882159269_item	2866802	et	4	main
võimalik	doc_767882159269_item	2866804	et	3	main
jutustada	doc_767882159269_item	2866808	et	3	main
headusest	doc_767882159269_item	2866810	et	4	main
praegu	doc_767882159269_item	2866816	et	3	main
eriti	doc_767882159269_item	2866821	et	3	main
on	doc_767882159269_item	2866831	et	4	main
lääne	doc_767882159269_item	2866838	et	4	main
eestis	doc_767882159269_item	2866839	et	3	main
säilitada	doc_767882159269_item	2866842	et	3	main
on	doc_767882159269_item	2866846	et	4	main
vanemate	doc_767882159269_item	2866849	et	4	main
laulaga	doc_767882159269_item	2866850	et	4	main
ma	doc_767882159269_item	2866851	et	3	main
olen	doc_767882159269_item	2866852	et	3	main
kindel	doc_767882159269_item	2866853	et	3	main
et	doc_767882159269_item	2866854	et	3	main
kaasaegne	doc_767882159269_item	2866855	et	3	main
koosneb	doc_767882159269_item	2866863	et	3	main
kolmast	doc_767882159269_item	2866864	et	3	main
laul	doc_767882159269_item	2866866	et	4	main
tants	doc_767882159269_item	2866867	et	3	main
ja	doc_767882159269_item	2866868	et	3	main
õppisin	doc_767882159269_item	2866874	et	3	main
muusika	doc_767882159269_item	2866875	et	4	main
eestlased	doc_767882159269_item	2866884	et	3	main
osa	doc_767882159269_item	2866895	et	4	main
palju	doc_767882159269_item	2866901	et	4	main
võin	doc_767882159269_item	2866903	et	3	main
et	doc_767882159269_item	2866905	et	3	main
armastus	doc_767882159269_item	2866929	et	4	main
laulada	doc_767882159269_item	2866936	et	4	main
arvates	doc_767882159269_item	2866956	et	4	main
see	doc_767882159269_item	2866957	et	3	main
aitab	doc_767882159269_item	2866958	et	3	main
maade	doc_767882159269_item	2866962	et	3	main
kultuuri	doc_767882159269_item	2866963	et	4	main
tõsta	doc_767882159269_item	2866966	et	4	main
kokkulepel	doc_767882159269_item	2866968	et	4	main
tahaksin	doc_767882159269_item	2866969	et	3	main
öelda	doc_767882159269_item	2866970	et	4	main
et	doc_767882159269_item	2866971	et	3	main
juhul	doc_767882159269_item	2866822	et	3	main
esinejad	doc_767882159269_item	2866824	et	4	main
seda	doc_767882159269_item	2866826	et	3	main
säilinud	doc_767882159269_item	2866834	et	4	main
ainult	doc_767882159269_item	2866835	et	4	main
folklöör	doc_767882159269_item	2866856	et	4	main
erineb	doc_767882159269_item	2866857	et	3	main
vanaaegsest	doc_767882159269_item	2866858	et	3	main
mitte	doc_767882159269_item	2866859	et	3	main
et	doc_767882159269_item	2866883	et	3	main
inimesed	doc_767882159269_item	2866886	et	3	main
elab	doc_767882159269_item	2866888	et	3	main
lauapeos	doc_767882159269_item	2866896	et	4	main
mitu	doc_767882159269_item	2866897	et	4	main
ja	doc_767882159269_item	2866899	et	3	main
teeb	doc_767882159269_item	2866907	et	3	main
osa	doc_767882159269_item	2866910	et	4	main
sest	doc_767882159269_item	2866911	et	4	main
ma	doc_767882159269_item	2866912	et	3	main
rõõmu	doc_767882159269_item	2866914	et	4	main
tunnen	doc_767882159269_item	2866913	et	3	main
kui	doc_767882159269_item	2866915	et	3	main
laulan	doc_767882159269_item	2866916	et	3	main
võib-olla	doc_767882159269_item	2866917	et	3	main
minu	doc_767882159269_item	2866918	et	3	main
emakeel	doc_767882159269_item	2866919	et	4	main
on	doc_767882159269_item	2866920	et	4	main
eestimaa	doc_767882159269_item	2866930	et	4	main
muusika	doc_767882159269_item	2866938	et	4	main
imet	doc_767882159269_item	2866945	et	3	main
meile	doc_767882159269_item	2866959	et	4	main
loobuda	doc_767882159269_item	2866960	et	3	main
laul	doc_767882159269_item	2866972	et	4	main
tuleb	doc_767882159269_item	2866973	et	3	main
alati	doc_767882159269_item	2866976	et	4	main
ajaloo	doc_767882159269_item	2867012	et	4	main
teevad	doc_767882159269_item	2867013	et	3	main
meist	doc_767882159269_item	2867014	et	3	main
laulurahva	doc_767882159269_item	2867015	et	3	main
mina	doc_767882159269_item	2866925	et	4	main
olen	doc_767882159269_item	2866926	et	3	main
eestlane	doc_767882159269_item	2866927	et	3	main
ja	doc_767882159269_item	2866928	et	3	main
vastu	doc_767882159269_item	2866939	et	3	main
ja	doc_767882159269_item	2866940	et	3	main
sellest	doc_767882159269_item	2866942	et	4	main
teeb	doc_767882159269_item	2866944	et	3	main
ja	doc_767882159269_item	2866965	et	3	main
küsida	doc_767882159269_item	2866978	et	3	main
noorinimestel	doc_767882159269_item	2866979	et	3	main
mida	doc_767882159269_item	2866980	et	4	main
ta	doc_767882159269_item	2866981	et	4	main
teeb	doc_767882159269_item	2866982	et	3	main
alati	doc_767882159269_item	2866983	et	4	main
siis	doc_767882159269_item	2866984	et	3	main
ta	doc_767882159269_item	2866985	et	4	main
vastab	doc_767882159269_item	2866986	et	3	main
et	doc_767882159269_item	2866987	et	3	main
kuulab	doc_767882159269_item	2866988	et	3	main
muusikat	doc_767882159269_item	2866989	et	3	main
trammis	doc_767882159269_item	2866990	et	4	main
trollis	doc_767882159269_item	2866991	et	4	main
rongis	doc_767882159269_item	2866992	et	4	main
kui	doc_767882159269_item	2866993	et	3	main
teeb	doc_767882159269_item	2866994	et	3	main
midagi	doc_767882159269_item	2866995	et	4	main
kui	doc_767882159269_item	2866996	et	3	main
valmistab	doc_767882159269_item	2866997	et	3	main
sööki	doc_767882159269_item	2866998	et	4	main
kui	doc_767882159269_item	2866999	et	3	main
ärkab	doc_767882159269_item	2867000	et	3	main
siis	doc_767882159269_item	2867001	et	3	main
alati	doc_767882159269_item	2867002	et	4	main
kuulab	doc_767882159269_item	2867003	et	3	main
muusikat	doc_767882159269_item	2867004	et	3	main
niimoodi	doc_767882159269_item	2867005	et	3	main
võin	doc_767882159269_item	2867006	et	3	main
öelda	doc_767882159269_item	2867007	et	4	main
et	doc_767882159269_item	2867008	et	3	main
selles	doc_769634019905_item	2867508	et	4	main
kui	doc_769634019905_item	2867510	et	3	main
siis	doc_769634019905_item	2867516	et	3	main
on	doc_769634019905_item	2867531	et	4	main
ametlik	doc_769634019905_item	2867499	et	3	main
kiri	doc_769634019905_item	2867500	et	3	main
et	doc_769634019905_item	2867509	et	3	main
on	doc_769634019905_item	2867520	et	4	main
ma	doc_769634019905_item	2867524	et	3	main
on	doc_769634019905_item	2867533	et	4	main
perekonnanimi	doc_769634019905_item	2867538	et	3	main
tere	doc_769634019906_item	2867541	et	3	main
minu	doc_769634019906_item	2867550	et	3	main
te	doc_769634019906_item	2867557	et	4	main
saata	doc_769634019906_item	2867563	et	3	main
on	doc_769634019906_item	2867565	et	4	main
juhendaja	doc_769634019906_item	2867567	et	4	main
ütles	doc_769634019906_item	2867568	et	3	main
eesnimi	doc_769634019906_item	2867577	et	3	main
analüüs	doc_769634019907_item	2867579	et	3	main
telekanalite	doc_769634019907_item	2867582	et	3	main
õ	doc_769634019907_item	2867586	et	4	main
sarja	doc_769634019907_item	2867626	et	4	main
vaprad	doc_769634019907_item	2867627	et	3	main
ja	doc_769634019907_item	2867628	et	3	main
kutsuge	doc_769634019907_item	2867638	et	3	main
mind	doc_769634019907_item	2867639	et	4	main
tv	doc_769634019907_item	2867642	et	4	main
tv	doc_769634019907_item	2867651	et	4	main
politseiakadeemia	doc_769634019907_item	2867654	et	4	main
2	doc_769634019907_item	2867657	et	2	main
vaprad	doc_769634019907_item	2867658	et	3	main
ja	doc_769634019907_item	2867659	et	3	main
3	doc_769634019907_item	2867662	et	2	main
kuigi	doc_769634019907_item	2867667	et	3	main
pisiasjade	doc_769634019907_item	2867669	et	3	main
alati	doc_769634019907_item	2867675	et	4	main
ei	doc_769634019907_item	2867676	et	4	main
ekraanile	doc_769634019907_item	2867680	et	3	main
suu	doc_769634019907_item	2867683	et	4	main
avas	doc_769634019907_item	2867684	et	4	main
ja	doc_769634019907_item	2867685	et	3	main
on	doc_769634019907_item	2867724	et	4	main
jäetud	doc_769634019907_item	2867728	et	4	main
midagi	doc_769634019907_item	2867729	et	4	main
tõlkimata	doc_769634019907_item	2867730	et	4	main
right	doc_769634019907_item	2867739	et	4	main
no	doc_769634019907_item	2867740	et	3	main
okey	doc_769634019907_item	2867750	et	4	main
hea	doc_769634019907_item	2867764	et	4	main
kuna	doc_769634019907_item	2867765	et	3	main
mis	doc_769634019907_item	2867773	et	4	main
subtiitrite	doc_769634019907_item	2867776	et	4	main
5	doc_769634019907_item	2867778	et	2	main
kursiivi	doc_769634019907_item	2867779	et	4	main
mcleodi	doc_769634019907_item	2867792	et	4	main
kateiks	doc_769634019907_item	2867796	et	4	main
tereminu	doc_769634019905_item	2867501	et	4	main
nimi	doc_769634019905_item	2867502	et	3	main
on	doc_769634019905_item	2867503	et	4	main
eesnimi	doc_769634019905_item	2867504	et	3	main
asi	doc_769634019905_item	2867506	et	4	main
täna	doc_769634019905_item	2867511	et	4	main
oma	doc_769634019905_item	2867514	et	4	main
on	doc_769634019905_item	2867507	et	4	main
aga	doc_769634019905_item	2867522	et	3	main
valesti	doc_769634019905_item	2867525	et	3	main
õige	doc_769634019905_item	2867534	et	4	main
hinne	doc_769634019905_item	2867535	et	3	main
nimi	doc_769634019905_item	2867537	et	3	main
ma	doc_769634019906_item	2867542	et	3	main
oma	doc_769634019906_item	2867545	et	4	main
puhul	doc_769634019906_item	2867547	et	4	main
olen	doc_769634019906_item	2867553	et	3	main
teie	doc_769634019906_item	2867570	et	4	main
perekonnanimi	doc_769634019905_item	2867505	et	3	main
ma	doc_769634019905_item	2867512	et	3	main
vaatasin	doc_769634019905_item	2867513	et	3	main
õppekaardi	doc_769634019905_item	2867515	et	4	main
teie	doc_769634019905_item	2867517	et	4	main
aines	doc_769634019905_item	2867518	et	4	main
mul	doc_769634019905_item	2867519	et	3	main
e	doc_769634019905_item	2867521	et	4	main
vist	doc_769634019905_item	2867523	et	4	main
kuulsin	doc_769634019905_item	2867526	et	3	main
teie	doc_769634019905_item	2867527	et	4	main
käest	doc_769634019905_item	2867528	et	4	main
et	doc_769634019905_item	2867529	et	3	main
mul	doc_769634019905_item	2867530	et	3	main
kiri	doc_769634019906_item	2867540	et	3	main
kirjutan	doc_769634019906_item	2867543	et	3	main
olete	doc_769634019906_item	2867549	et	3	main
eesnimi	doc_769634019906_item	2867554	et	3	main
retsensiooni	doc_769634019906_item	2867561	et	4	main
esmaspäeval	doc_769634019906_item	2867564	et	3	main
kaitsmine	doc_769634019906_item	2867566	et	4	main
et	doc_769634019906_item	2867569	et	3	main
homset	doc_769634019906_item	2867575	et	3	main
perekonnanimi	doc_769634019906_item	2867578	et	3	main
erinevate	doc_769634019907_item	2867581	et	4	main
him	doc_769634019907_item	2867585	et	4	main
tete	doc_769634019907_item	2867587	et	4	main
dramaatilise	doc_769634019907_item	2867632	et	3	main
lizzi	doc_769634019907_item	2867649	et	4	main
3	doc_769634019907_item	2867652	et	2	main
3	doc_769634019907_item	2867655	et	2	main
oli	doc_769634019907_item	2867664	et	3	main
mõnede	doc_769634019907_item	2867668	et	3	main
enne	doc_769634019907_item	2867688	et	4	main
millest	doc_769634019907_item	2867723	et	3	main
3	doc_769634019907_item	2867726	et	2	main
nt	doc_769634019907_item	2867735	et	4	main
max	doc_769634019907_item	2867741	et	4	main
jäetud	doc_769634019907_item	2867747	et	4	main
nähtavus	doc_769634019907_item	2867761	et	4	main
ekraanil	doc_769634019907_item	2867762	et	3	main
oli	doc_769634019907_item	2867763	et	3	main
kohad	doc_769634019907_item	2867772	et	4	main
kasutatud	doc_769634019907_item	2867781	et	4	main
need	doc_769634019907_item	2867782	et	3	main
sarjas	doc_769634019907_item	2867791	et	4	main
jälgimiseks	doc_769634019907_item	2867829	et	4	main
taustal	doc_769634019907_item	2867831	et	3	main
on	doc_769634019907_item	2867832	et	4	main
hea	doc_769634019907_item	2867833	et	4	main
lahendus	doc_769634019907_item	2867834	et	4	main
2	doc_769634019907_item	2867835	et	2	main
mitte	doc_769634019907_item	2867836	et	3	main
helindatud	doc_769634019907_item	2867842	et	4	main
subtiitrid	doc_769634019907_item	2867853	et	4	main
ekraanilt	doc_769634019907_item	2867862	et	3	main
olnud	doc_769634019907_item	2867876	et	4	main
võimalik	doc_769634019907_item	2867877	et	3	main
jälgida	doc_769634019907_item	2867878	et	3	main
ekraanil	doc_769634019907_item	2867879	et	3	main
ajal	doc_769634019907_item	2867883	et	4	main
teksti	doc_769634019907_item	2867885	et	4	main
asja	doc_769634019907_item	2867892	et	4	main
dmis	doc_769634019905_item	2867532	et	4	main
teie	doc_769634019906_item	2867548	et	4	main
retsensent	doc_769634019906_item	2867551	et	3	main
ega	doc_769634019906_item	2867556	et	3	main
e-mailiga	doc_769634019906_item	2867562	et	4	main
saadate	doc_769634019906_item	2867571	et	3	main
ilusat	doc_769634019906_item	2867574	et	3	main
päeva	doc_769634019906_item	2867576	et	4	main
eesti	doc_769634019907_item	2867580	et	4	main
anal	doc_769634019907_item	2867588	et	4	main
üü	doc_769634019907_item	2867589	et	4	main
s	doc_769634019907_item	2867590	et	4	main
selles	doc_769634019907_item	2867591	et	4	main
t	doc_769634019907_item	2867592	et	4	main
öö	doc_769634019907_item	2867593	et	4	main
s	doc_769634019907_item	2867594	et	4	main
ma	doc_769634019907_item	2867595	et	3	main
koostan	doc_769634019907_item	2867596	et	3	main
ü	doc_769634019907_item	2867597	et	4	main
levaade	doc_769634019907_item	2867598	et	4	main
kus	doc_769634019907_item	2867599	et	3	main
anal	doc_769634019907_item	2867600	et	4	main
üü	doc_769634019907_item	2867601	et	4	main
sin	doc_769634019907_item	2867602	et	4	main
subtiitrite	doc_769634019907_item	2867603	et	4	main
ü	doc_769634019907_item	2867604	et	4	main
lesehitust	doc_769634019907_item	2867605	et	4	main
paigutust	doc_769634019907_item	2867606	et	4	main
keelelist	doc_769634019907_item	2867607	et	4	main
poolt	doc_769634019907_item	2867608	et	4	main
ka	doc_769634019907_item	2867609	et	3	main
t	doc_769634019907_item	2867610	et	4	main
õ	doc_769634019907_item	2867611	et	4	main
lke	doc_769634019907_item	2867612	et	4	main
adekvaatsust	doc_769634019907_item	2867613	et	4	main
ja	doc_769634019907_item	2867614	et	3	main
s	doc_769634019907_item	2867615	et	4	main
ü	doc_769634019907_item	2867616	et	4	main
nkroonsust	doc_769634019907_item	2867617	et	4	main
v	doc_769634019907_item	2867619	et	4	main
õ	doc_769634019907_item	2867620	et	4	main
ma	doc_769634019907_item	2867618	et	3	main
t	doc_769634019907_item	2867622	et	4	main
ilusad	doc_769634019907_item	2867629	et	3	main
sarja	doc_769634019907_item	2867633	et	4	main
t	doc_769634019907_item	2867635	et	4	main
ü	doc_769634019907_item	2867636	et	4	main
mcguire	doc_769634019907_item	2867650	et	4	main
hea	doc_769634019907_item	2867666	et	4	main
ilmunud	doc_769634019907_item	2867677	et	4	main
lugupidamisega	doc_769634019905_item	2867536	et	3	main
ametlik	doc_769634019906_item	2867539	et	3	main
teile	doc_769634019906_item	2867544	et	4	main
bakalaureusetöö	doc_769634019906_item	2867546	et	4	main
mina	doc_769634019906_item	2867552	et	4	main
perekonnanimi	doc_769634019906_item	2867555	et	3	main
ei	doc_769634019906_item	2867558	et	4	main
saanud	doc_769634019906_item	2867559	et	4	main
mulle	doc_769634019906_item	2867560	et	4	main
retsensiooni	doc_769634019906_item	2867572	et	4	main
nädalavahetusel	doc_769634019906_item	2867573	et	4	main
subtitreerimisp	doc_769634019907_item	2867583	et	4	main
õ	doc_769634019907_item	2867584	et	4	main
tsin	doc_769634019907_item	2867621	et	4	main
tv	doc_769634019907_item	2867630	et	4	main
mcleodi	doc_769634019907_item	2867634	et	4	main
kate	doc_769634019907_item	2867640	et	3	main
iks	doc_769634019907_item	2867641	et	3	main
2	doc_769634019907_item	2867643	et	2	main
ja	doc_769634019907_item	2867644	et	3	main
kaks	doc_769634019907_item	2867645	et	3	main
kom	doc_769634019907_item	2867646	et	4	main
öö	doc_769634019907_item	2867647	et	4	main
tv	doc_769634019907_item	2867661	et	4	main
üsna	doc_769634019907_item	2867665	et	3	main
kallal	doc_769634019907_item	2867670	et	4	main
mitte	doc_769634019907_item	2867674	et	3	main
tegelane	doc_769634019907_item	2867682	et	3	main
kõnevooru	doc_769634019907_item	2867689	et	4	main
ja	doc_769634019907_item	2867722	et	3	main
või	doc_769634019907_item	2867731	et	4	main
tõlge	doc_769634019907_item	2867732	et	3	main
oli	doc_769634019907_item	2867733	et	3	main
tõlkimata	doc_769634019907_item	2867748	et	4	main
c	doc_769634019907_item	2867755	et	4	main
ruumissiis	doc_769634019907_item	2867769	et	4	main
puudusid	doc_769634019907_item	2867770	et	4	main
valged	doc_769634019907_item	2867771	et	3	main
raskendanud	doc_769634019907_item	2867775	et	4	main
olid	doc_769634019907_item	2867783	et	4	main
lugeda	doc_769634019907_item	2867821	et	3	main
kasti	doc_769634019907_item	2867826	et	4	main
subtiitrite	doc_769634019907_item	2867828	et	4	main
kõik	doc_769634019907_item	2867837	et	4	main
nimed	doc_769634019907_item	2867838	et	3	main
sageli	doc_769634019907_item	2867843	et	3	main
3	doc_769634019907_item	2867848	et	2	main
ei	doc_769634019907_item	2867851	et	4	main
ilmunud	doc_769634019907_item	2867852	et	4	main
läbi	doc_769634019907_item	2867889	et	4	main
lugeda	doc_769634019907_item	2867890	et	3	main
väsitavaks	doc_769634019907_item	2867927	et	4	main
6	doc_769634019907_item	2867928	et	2	main
vormistus	doc_769634019907_item	2867933	et	4	main
nurgas	doc_769634019907_item	2867942	et	3	main
ei	doc_769634019907_item	2867956	et	4	main
märka	doc_769634019907_item	2867957	et	4	main
mingeid	doc_769634019907_item	2867958	et	3	main
pisiasju	doc_769634019907_item	2867959	et	3	main
ja	doc_769634019907_item	2867960	et	3	main
tv-3	doc_769634019907_item	2867969	et	4	main
ole	doc_769634019907_item	2867987	et	4	main
subtiitreid	doc_769634019907_item	2867994	et	4	main
jälgida	doc_769634019907_item	2867995	et	3	main
toimuva	doc_769634019907_item	2868000	et	4	main
tegevuse	doc_769634019907_item	2868001	et	4	main
öö	doc_769634019907_item	2867623	et	4	main
sse	doc_769634019907_item	2867624	et	4	main
melodramaatilise	doc_769634019907_item	2867625	et	3	main
3	doc_769634019907_item	2867631	et	2	main
tred	doc_769634019907_item	2867637	et	4	main
diat	doc_769634019907_item	2867648	et	4	main
ja	doc_769634019907_item	2867653	et	3	main
tv	doc_769634019907_item	2867656	et	4	main
ilusad	doc_769634019907_item	2867660	et	3	main
üldmulje	doc_769634019907_item	2867663	et	4	main
võiks	doc_769634019907_item	2867671	et	4	main
norida	doc_769634019907_item	2867672	et	3	main
1	doc_769634019907_item	2867673	et	2	main
õigeaegselt	doc_769634019907_item	2867679	et	4	main
kui	doc_769634019907_item	2867681	et	3	main
ekraanilt	doc_769634019907_item	2867687	et	3	main
lõppu	doc_769634019907_item	2867690	et	4	main
oli	doc_769634019907_item	2867693	et	3	main
kohti	doc_769634019907_item	2867694	et	4	main
sarjas	doc_769634019907_item	2867692	et	4	main
kus	doc_769634019907_item	2867695	et	3	main
subtiitrid	doc_769634019907_item	2867696	et	4	main
vahetusid	doc_769634019907_item	2867697	et	4	main
ekraanil	doc_769634019907_item	2867698	et	3	main
liiga	doc_769634019907_item	2867699	et	4	main
kiiresti	doc_769634019907_item	2867700	et	3	main
nii	doc_769634019907_item	2867701	et	3	main
et	doc_769634019907_item	2867702	et	3	main
ma	doc_769634019907_item	2867703	et	3	main
ei	doc_769634019907_item	2867704	et	4	main
jõudnud	doc_769634019907_item	2867705	et	4	main
kõike	doc_769634019907_item	2867706	et	4	main
läbi	doc_769634019907_item	2867707	et	4	main
lugeda	doc_769634019907_item	2867708	et	3	main
ning	doc_769634019907_item	2867709	et	3	main
seetõttu	doc_769634019907_item	2867710	et	3	main
jäi	doc_769634019907_item	2867711	et	3	main
osa	doc_769634019907_item	2867712	et	4	main
sarjast	doc_769634019907_item	2867713	et	4	main
arusaamatuks	doc_769634019907_item	2867714	et	4	main
ei	doc_769634019907_item	2867715	et	4	main
olnud	doc_769634019907_item	2867716	et	4	main
võimalik	doc_769634019907_item	2867717	et	3	main
aru	doc_769634019907_item	2867718	et	4	main
saada	doc_769634019907_item	2867719	et	4	main
kes	doc_769634019907_item	2867720	et	4	main
räägib	doc_769634019907_item	2867721	et	3	main
oli	doc_769634019907_item	2867727	et	3	main
ebatäpne	doc_769634019907_item	2867734	et	3	main
ei	doc_769634019907_item	2867742	et	4	main
max	doc_769634019907_item	2867743	et	4	main
esimene	doc_769634019907_item	2867744	et	3	main
b	doc_769634019907_item	2867749	et	4	main
subtiitrid	doc_769634019907_item	2867678	et	4	main
kadusid	doc_769634019907_item	2867686	et	4	main
2	doc_769634019907_item	2867691	et	2	main
jutt	doc_769634019907_item	2867725	et	3	main
a	doc_769634019907_item	2867736	et	4	main
is	doc_769634019907_item	2867737	et	4	main
all	doc_769634019907_item	2867738	et	3	main
osa	doc_769634019907_item	2867745	et	4	main
on	doc_769634019907_item	2867746	et	4	main
pole	doc_769634019907_item	2867751	et	3	main
viga	doc_769634019907_item	2867752	et	4	main
ebatäpne	doc_769634019907_item	2867753	et	3	main
tõlge	doc_769634019907_item	2867754	et	3	main
ashli	doc_769634019907_item	2867757	et	4	main
4	doc_769634019907_item	2867759	et	2	main
subtiitrite	doc_769634019907_item	2867760	et	4	main
tumedas	doc_769634019907_item	2867768	et	3	main
oleks	doc_769634019907_item	2867774	et	3	main
lugemist	doc_769634019907_item	2867777	et	4	main
n-ö	doc_769634019907_item	2867784	et	4	main
pisiasjad	doc_769634019907_item	2867785	et	3	main
mida	doc_769634019907_item	2867786	et	4	main
ma	doc_769634019907_item	2867787	et	3	main
märkasin	doc_769634019907_item	2867788	et	3	main
just	doc_769634019907_item	2867789	et	3	main
tütred	doc_769634019907_item	2867793	et	3	main
mind	doc_769634019907_item	2867795	et	4	main
siin	doc_769634019907_item	2867799	et	4	main
olid	doc_769634019907_item	2867800	et	4	main
praktilised	doc_769634019907_item	2867801	et	3	main
samad	doc_769634019907_item	2867802	et	3	main
vead	doc_769634019907_item	2867803	et	4	main
nagu	doc_769634019907_item	2867804	et	3	main
eelmises	doc_769634019907_item	2867805	et	3	main
sarjas	doc_769634019907_item	2867806	et	4	main
1	doc_769634019907_item	2867807	et	2	main
tegevus	doc_769634019907_item	2867809	et	4	main
kuna	doc_769634019907_item	2867808	et	3	main
toimub	doc_769634019907_item	2867810	et	3	main
looduses	doc_769634019907_item	2867811	et	4	main
siis	doc_769634019907_item	2867812	et	3	main
kasutatakse	doc_769634019907_item	2867813	et	3	main
subtiitrite	doc_769634019907_item	2867814	et	4	main
näitamiseks	doc_769634019907_item	2867815	et	4	main
musta	doc_769634019907_item	2867816	et	4	main
kasti	doc_769634019907_item	2867817	et	4	main
et	doc_769634019907_item	2867818	et	3	main
oleks	doc_769634019907_item	2867819	et	3	main
võimalik	doc_769634019907_item	2867820	et	3	main
räägivad	doc_769634019907_item	2867823	et	3	main
musta	doc_769634019907_item	2867825	et	4	main
kasutamine	doc_769634019907_item	2867827	et	4	main
puudus	doc_769634019907_item	2867844	et	4	main
ekraanile	doc_769634019907_item	2867855	et	3	main
suu	doc_769634019907_item	2867858	et	4	main
avas	doc_769634019907_item	2867859	et	4	main
ja	doc_769634019907_item	2867860	et	3	main
kadusid	doc_769634019907_item	2867861	et	4	main
kõnevooru	doc_769634019907_item	2867864	et	4	main
4	doc_769634019907_item	2867866	et	2	main
mõnedes	doc_769634019907_item	2867867	et	3	main
kohtades	doc_769634019907_item	2867868	et	3	main
jäi	doc_769634019907_item	2867869	et	3	main
ebaselgeks	doc_769634019907_item	2867870	et	3	main
no	doc_769634019907_item	2867756	et	3	main
ei	doc_769634019907_item	2867758	et	4	main
tegevus	doc_769634019907_item	2867766	et	4	main
toimus	doc_769634019907_item	2867767	et	3	main
ei	doc_769634019907_item	2867780	et	4	main
selles	doc_769634019907_item	2867790	et	4	main
kutsuge	doc_769634019907_item	2867794	et	3	main
kanal	doc_769634019907_item	2867797	et	4	main
2	doc_769634019907_item	2867798	et	2	main
millest	doc_769634019907_item	2867822	et	3	main
tegelased	doc_769634019907_item	2867824	et	3	main
heledal	doc_769634019907_item	2867830	et	3	main
sarjas	doc_769634019907_item	2867839	et	4	main
ei	doc_769634019907_item	2867840	et	4	main
olnud	doc_769634019907_item	2867841	et	4	main
tegelase	doc_769634019907_item	2867845	et	3	main
pöördumine	doc_769634019907_item	2867847	et	4	main
õigeaegselt	doc_769634019907_item	2867854	et	4	main
tegelane	doc_769634019907_item	2867857	et	3	main
enne	doc_769634019907_item	2867863	et	4	main
lõppu	doc_769634019907_item	2867865	et	4	main
kes	doc_769634019907_item	2867871	et	4	main
just	doc_769634019907_item	2867872	et	3	main
rääkis	doc_769634019907_item	2867873	et	3	main
silmadega	doc_769634019907_item	2867874	et	3	main
ja	doc_769634019907_item	2867881	et	3	main
kahte	doc_769634019907_item	2867891	et	4	main
lugemine	doc_769634019907_item	2867922	et	4	main
igavaks	doc_769634019907_item	2867925	et	4	main
ja	doc_769634019907_item	2867926	et	3	main
tõlkija	doc_769634019907_item	2867931	et	4	main
ei	doc_769634019907_item	2867937	et	4	main
tõlkinud	doc_769634019907_item	2867944	et	4	main
hea	doc_769634019907_item	2867952	et	4	main
subtiitrite	doc_769634019907_item	2867964	et	4	main
selles	doc_769634019907_item	2867970	et	4	main
dialooge	doc_769634019907_item	2867976	et	3	main
vaja	doc_769634019907_item	2867979	et	4	main
ei	doc_769634019907_item	2867991	et	4	main
ekraanil	doc_769634019907_item	2867999	et	3	main
kaudu	doc_769634019907_item	2868002	et	3	main
oli	doc_769634019907_item	2868015	et	3	main
moment	doc_769634019907_item	2868017	et	3	main
tekstis	doc_769634019907_item	2868027	et	3	main
ja	doc_769634019907_item	2868030	et	3	main
vaatajale	doc_769634019907_item	2868032	et	4	main
itaalia	doc_769634019907_item	2868037	et	4	main
keele	doc_769634019907_item	2868038	et	4	main
õigekirjutust	doc_769634019907_item	2868039	et	3	main
aga	doc_769634019907_item	2868040	et	3	main
tean	doc_769634019907_item	2868041	et	3	main
et	doc_769634019907_item	2868042	et	3	main
see	doc_769634019907_item	2868043	et	3	main
tõlget	doc_769634019907_item	2868053	et	3	main
mis	doc_769634019907_item	2868063	et	4	main
tõlkimata	doc_769634019907_item	2868066	et	4	main
arvan	doc_769634019907_item	2868067	et	3	main
et	doc_769634019907_item	2868068	et	3	main
laulu	doc_769634019907_item	2868069	et	4	main
ka	doc_769634019907_item	2868083	et	3	main
kuna	doc_769634019907_item	2868085	et	3	main
seda	doc_769634019907_item	2868090	et	3	main
ei	doc_769634019907_item	2868101	et	4	main
puudus	doc_769634019907_item	2868107	et	4	main
poole	doc_769634019907_item	2867846	et	4	main
mitte	doc_769634019907_item	2867849	et	3	main
alati	doc_769634019907_item	2867850	et	4	main
kui	doc_769634019907_item	2867856	et	3	main
ei	doc_769634019907_item	2867875	et	4	main
samal	doc_769634019907_item	2867882	et	3	main
lugeda	doc_769634019907_item	2867884	et	3	main
kuna	doc_769634019907_item	2867886	et	3	main
soovisin	doc_769634019907_item	2867887	et	4	main
kõike	doc_769634019907_item	2867888	et	4	main
korraga	doc_769634019907_item	2867893	et	4	main
teha	doc_769634019907_item	2867894	et	3	main
on	doc_769634019907_item	2867895	et	4	main
raske-	doc_769634019907_item	2867896	et	4	main
lugeda	doc_769634019907_item	2867897	et	3	main
teksti	doc_769634019907_item	2867898	et	4	main
ja	doc_769634019907_item	2867899	et	3	main
jälgida	doc_769634019907_item	2867900	et	3	main
tegevust	doc_769634019907_item	2867901	et	4	main
5	doc_769634019907_item	2867902	et	2	main
mulle	doc_769634019907_item	2867903	et	4	main
tundub	doc_769634019907_item	2867904	et	3	main
et	doc_769634019907_item	2867905	et	3	main
kui	doc_769634019907_item	2867906	et	3	main
tegelane	doc_769634019907_item	2867907	et	3	main
endamisi	doc_769634019907_item	2867908	et	3	main
loeb	doc_769634019907_item	2867909	et	3	main
mõtleb	doc_769634019907_item	2867911	et	3	main
või	doc_769634019907_item	2867910	et	4	main
oleks	doc_769634019907_item	2867912	et	3	main
parem	doc_769634019907_item	2867913	et	4	main
subtiitrid	doc_769634019907_item	2867914	et	4	main
panna	doc_769634019907_item	2867915	et	4	main
kursiiviga	doc_769634019907_item	2867916	et	3	main
seejuures	doc_769634019907_item	2867917	et	3	main
toimub	doc_769634019907_item	2867918	et	3	main
mingi	doc_769634019907_item	2867919	et	4	main
vaheldus	doc_769634019907_item	2867920	et	4	main
ei	doc_769634019907_item	2867923	et	4	main
muutu	doc_769634019907_item	2867924	et	4	main
subtiitrite	doc_769634019907_item	2867932	et	4	main
asemel	doc_769634019907_item	2867945	et	4	main
oli	doc_769634019907_item	2867946	et	3	main
tõlkis	doc_769634019907_item	2867948	et	3	main
on	doc_769634019907_item	2867950	et	4	main
tavaline	doc_769634019907_item	2867954	et	4	main
vaatleja	doc_769634019907_item	2867955	et	4	main
ei	doc_769634019907_item	2867961	et	4	main
mcguire	doc_769634019907_item	2867968	et	4	main
ole	doc_769634019907_item	2867973	et	4	main
nii	doc_769634019907_item	2867974	et	3	main
midagi	doc_769634019907_item	2867988	et	4	main
hirmsat	doc_769634019907_item	2867989	et	3	main
kui	doc_769634019907_item	2867990	et	3	main
selgeks	doc_769634019907_item	2867998	et	3	main
te	doc_769634019907_item	2868003	et	4	main
küsitite	doc_769634019907_item	2868004	et	3	main
toimuvat	doc_769634019907_item	2867880	et	4	main
ja	doc_769634019907_item	2867921	et	3	main
oli	doc_769634019907_item	2867934	et	3	main
ebakorrektne	doc_769634019907_item	2867935	et	3	main
paigutus	doc_769634019907_item	2867936	et	4	main
ning	doc_769634019907_item	2867943	et	3	main
märgitud	doc_769634019907_item	2867947	et	4	main
kuna	doc_769634019907_item	2867953	et	3	main
lizzi	doc_769634019907_item	2867967	et	4	main
filmis	doc_769634019907_item	2867971	et	4	main
ei	doc_769634019907_item	2867972	et	4	main
oleks	doc_769634019907_item	2867978	et	3	main
teleri	doc_769634019907_item	2867981	et	3	main
ja	doc_769634019907_item	2867983	et	3	main
kõik	doc_769634019907_item	2867996	et	4	main
saab	doc_769634019907_item	2867997	et	3	main
või	doc_769634019907_item	2868011	et	4	main
oli	doc_769634019907_item	2868012	et	3	main
ebatäpne	doc_769634019907_item	2868013	et	3	main
nt	doc_769634019907_item	2868014	et	4	main
kus	doc_769634019907_item	2868018	et	3	main
keeles	doc_769634019907_item	2868022	et	4	main
oli	doc_769634019907_item	2868028	et	3	main
arusaadav	doc_769634019907_item	2868031	et	4	main
ei	doc_769634019907_item	2868051	et	4	main
tuleks	doc_769634019907_item	2868071	et	4	main
samuti	doc_769634019907_item	2868072	et	3	main
tõlkida	doc_769634019907_item	2868073	et	3	main
3	doc_769634019907_item	2868074	et	2	main
subtiitrid	doc_769634019907_item	2868075	et	4	main
on	doc_769634019907_item	2868082	et	4	main
on	doc_769634019907_item	2868087	et	4	main
lapsed	doc_769634019907_item	2868093	et	3	main
kui	doc_769634019907_item	2868097	et	3	main
vanemad	doc_769634019907_item	2868098	et	4	main
4	doc_769634019907_item	2868099	et	2	main
helindatud	doc_769634019907_item	2868105	et	4	main
hea	doc_769634019907_item	2868117	et	4	main
ja	doc_769634019907_item	2868118	et	3	main
on	doc_769634019907_item	2868122	et	4	main
ja	doc_769634019907_item	2868124	et	3	main
3	doc_769634019907_item	2868129	et	2	main
kanal	doc_769634019907_item	2868130	et	4	main
ma	doc_769634019907_item	2868137	et	3	main
näinud	doc_769634019907_item	2868139	et	4	main
kordi	doc_769634019907_item	2868142	et	4	main
et	doc_769634019907_item	2868143	et	3	main
ainult	doc_769634019907_item	2868150	et	4	main
paar	doc_769634019907_item	2868151	et	3	main
sarjas	doc_769634019907_item	2868159	et	4	main
jah	doc_769634019907_item	2868173	et	3	main
toimuvad	doc_769634019907_item	2868177	et	4	main
kõnelused	doc_769634019907_item	2868178	et	4	main
jäid	doc_769634019907_item	2868179	et	4	main
kui	doc_769634019907_item	2868190	et	3	main
kiirusega	doc_769634019907_item	2868205	et	4	main
filmis	doc_769634019907_item	2868206	et	4	main
oli	doc_769634019907_item	2868207	et	3	main
kõne	doc_769634019907_item	2868213	et	4	main
et	doc_769634019907_item	2868231	et	3	main
parem	doc_769634019907_item	2868233	et	4	main
filmi	doc_769634019907_item	2868238	et	4	main
üheaegselt	doc_769634019907_item	2868242	et	4	main
lugeda	doc_769634019907_item	2868243	et	3	main
ei	doc_769634019907_item	2868247	et	4	main
ole	doc_769634019907_item	2868248	et	4	main
on	doc_769634019907_item	2868252	et	4	main
kanaleid	doc_769634019907_item	2868281	et	4	main
vaadata	doc_769634019907_item	2868282	et	4	main
ametlik	doc_769634019908_item	2868283	et	3	main
perekonnanimi	doc_769634019908_item	2868291	et	3	main
teema	doc_769634019908_item	2868307	et	4	main
tometamine	doc_769634019908_item	2868313	et	4	main
vaatamata	doc_769634019908_item	2868327	et	4	main
vene	doc_769634019908_item	2868334	et	4	main
kavatsen	doc_769634019908_item	2868337	et	3	main
kõik	doc_769634019908_item	2868339	et	4	main
oma	doc_769634019908_item	2868341	et	4	main
diplomitöös	doc_769634019908_item	2868342	et	3	main
mul	doc_769634019908_item	2868345	et	3	main
aidata	doc_769634019908_item	2868361	et	4	main
ette	doc_769634019908_item	2868362	et	4	main
sarja	doc_769634019907_item	2867929	et	4	main
lõpus	doc_769634019907_item	2867930	et	4	main
olnud	doc_769634019907_item	2867938	et	4	main
keskel	doc_769634019907_item	2867939	et	3	main
vaid	doc_769634019907_item	2867940	et	3	main
vasakus	doc_769634019907_item	2867941	et	4	main
üldmulje	doc_769634019907_item	2867949	et	4	main
muidugi	doc_769634019907_item	2867951	et	4	main
taha	doc_769634019907_item	2867962	et	4	main
norida	doc_769634019907_item	2867963	et	3	main
kujundamise	doc_769634019907_item	2867965	et	4	main
juures	doc_769634019907_item	2867966	et	4	main
palju	doc_769634019907_item	2867975	et	4	main
et	doc_769634019907_item	2867977	et	3	main
istuda	doc_769634019907_item	2867980	et	3	main
ees	doc_769634019907_item	2867982	et	4	main
tähelepanelikult	doc_769634019907_item	2867984	et	4	main
lugeda	doc_769634019907_item	2867985	et	3	main
ei	doc_769634019907_item	2867986	et	4	main
jõua	doc_769634019907_item	2867992	et	4	main
kõiki	doc_769634019907_item	2867993	et	4	main
1	doc_769634019907_item	2868008	et	2	main
tõlge	doc_769634019907_item	2868009	et	3	main
puudus	doc_769634019907_item	2868010	et	4	main
filmis	doc_769634019907_item	2868016	et	4	main
tegelased	doc_769634019907_item	2868019	et	3	main
vestlesid	doc_769634019907_item	2868020	et	4	main
itaalia	doc_769634019907_item	2868021	et	4	main
üks	doc_769634019907_item	2868023	et	3	main
tuttav	doc_769634019907_item	2868029	et	3	main
tähandab	doc_769634019907_item	2868044	et	4	main
teine	doc_769634019907_item	2868047	et	3	main
on	doc_769634019907_item	2868055	et	4	main
algust	doc_769634019907_item	2868070	et	4	main
see	doc_769634019907_item	2868081	et	3	main
film	doc_769634019907_item	2868086	et	3	main
ka	doc_769634019907_item	2868092	et	3	main
kes	doc_769634019907_item	2868094	et	4	main
olnud	doc_769634019907_item	2868102	et	4	main
pöördumine	doc_769634019907_item	2868108	et	4	main
poole	doc_769634019907_item	2868110	et	4	main
et	doc_769634019907_item	2868112	et	3	main
kujundus	doc_769634019907_item	2868114	et	4	main
on	doc_769634019907_item	2868115	et	4	main
üsna	doc_769634019907_item	2868116	et	3	main
filmis	doc_769634019907_item	2868123	et	4	main
põhiidee	doc_769634019907_item	2868125	et	4	main
2	doc_769634019907_item	2868131	et	2	main
see	doc_769634019907_item	2868132	et	3	main
on	doc_769634019907_item	2868133	et	4	main
minu	doc_769634019907_item	2868134	et	3	main
olen	doc_769634019907_item	2868138	et	3	main
ilma	doc_769634019907_item	2868147	et	4	main
sõnadeta	doc_769634019907_item	2868148	et	3	main
märkasin	doc_769634019907_item	2868149	et	3	main
mitte	doc_769634019907_item	2868156	et	3	main
nimed	doc_769634019907_item	2868158	et	3	main
ei	doc_769634019907_item	2868160	et	4	main
olnud	doc_769634019907_item	2868161	et	4	main
nt	doc_769634019907_item	2868168	et	4	main
kadettide	doc_769634019907_item	2868169	et	3	main
nimed	doc_769634019907_item	2868170	et	3	main
ja	doc_769634019907_item	2868171	et	3	main
sõnaühend	doc_769634019907_item	2868172	et	3	main
tagaplaanil	doc_769634019907_item	2868176	et	4	main
õigeaegselt	doc_769634019907_item	2868188	et	4	main
ekraanile	doc_769634019907_item	2868189	et	3	main
avas	doc_769634019907_item	2868193	et	4	main
ekraanilt	doc_769634019907_item	2868196	et	3	main
kõnevooru	doc_769634019907_item	2868198	et	4	main
lõppu	doc_769634019907_item	2868199	et	4	main
4	doc_769634019907_item	2868200	et	2	main
esikohal	doc_769634019907_item	2868208	et	4	main
tegevus	doc_769634019907_item	2868211	et	4	main
subtiitrite	doc_769634019907_item	2868215	et	4	main
oli	doc_769634019907_item	2868221	et	3	main
mis	doc_769634019907_item	2868223	et	4	main
muidugi	doc_769634019907_item	2868232	et	4	main
teist	doc_769634019907_item	2868249	et	4	main
milles	doc_769634019907_item	2868005	et	3	main
siis	doc_769634019907_item	2868006	et	3	main
viga	doc_769634019907_item	2868007	et	4	main
sõna	doc_769634019907_item	2868026	et	4	main
tea	doc_769634019907_item	2868035	et	4	main
küll	doc_769634019907_item	2868036	et	4	main
aitähh	doc_769634019907_item	2868045	et	4	main
tea	doc_769634019907_item	2868052	et	4	main
järelikult	doc_769634019907_item	2868054	et	3	main
tõlge	doc_769634019907_item	2868057	et	3	main
filmis	doc_769634019907_item	2868059	et	4	main
olid	doc_769634019907_item	2868060	et	4	main
ka	doc_769634019907_item	2868061	et	3	main
laulud	doc_769634019907_item	2868062	et	3	main
jäätud	doc_769634019907_item	2868065	et	4	main
vaheldusid	doc_769634019907_item	2868076	et	4	main
ekraanil	doc_769634019907_item	2868077	et	3	main
keskmise	doc_769634019907_item	2868078	et	3	main
kiirusega	doc_769634019907_item	2868079	et	4	main
ja	doc_769634019907_item	2868080	et	3	main
perefilm	doc_769634019907_item	2868088	et	3	main
vaatavad	doc_769634019907_item	2868091	et	4	main
loevad	doc_769634019907_item	2868095	et	3	main
aeglasemalt	doc_769634019907_item	2868096	et	4	main
kõik	doc_769634019907_item	2868103	et	4	main
nimed	doc_769634019907_item	2868104	et	3	main
inimeste	doc_769634019907_item	2868109	et	3	main
arvan	doc_769634019907_item	2868111	et	3	main
subtiitrite	doc_769634019907_item	2868113	et	4	main
kao	doc_769634019907_item	2868127	et	4	main
kõik	doc_769634019907_item	2868157	et	4	main
helindatud	doc_769634019907_item	2868162	et	4	main
poole	doc_769634019907_item	2868166	et	4	main
pöördumine	doc_769634019907_item	2868167	et	4	main
muidugi	doc_769634019907_item	2868180	et	4	main
subtiitrid	doc_769634019907_item	2868187	et	4	main
ja	doc_769634019907_item	2868194	et	3	main
enne	doc_769634019907_item	2868197	et	4	main
subtiitrid	doc_769634019907_item	2868201	et	4	main
seal	doc_769634019907_item	2868209	et	4	main
kui	doc_769634019907_item	2868212	et	3	main
ei	doc_769634019907_item	2868218	et	4	main
ja	doc_769634019907_item	2868236	et	3	main
ja	doc_769634019907_item	2868241	et	3	main
subtiitre	doc_769634019907_item	2868244	et	4	main
kui	doc_769634019907_item	2868246	et	3	main
parem	doc_769634019907_item	2868253	et	4	main
subtiitrite	doc_769634019907_item	2868255	et	4	main
on	doc_769634019907_item	2868257	et	4	main
korrektne	doc_769634019907_item	2868258	et	3	main
ja	doc_769634019907_item	2868259	et	3	main
tõlge	doc_769634019907_item	2868260	et	3	main
täpne	doc_769634019907_item	2868261	et	3	main
vaadates	doc_769634019907_item	2868262	et	3	main
need	doc_769634019907_item	2868263	et	3	main
mina	doc_769634019908_item	2868286	et	4	main
olen	doc_769634019908_item	2868287	et	3	main
on	doc_769634019908_item	2868294	et	4	main
perekonnanimi	doc_769634019908_item	2868300	et	3	main
mulle	doc_769634019908_item	2868302	et	4	main
venekeelsetes	doc_769634019908_item	2868314	et	4	main
ajalehtedes	doc_769634019908_item	2868315	et	4	main
sõnavara	doc_769634019908_item	2868316	et	4	main
kasutamine	doc_769634019908_item	2868320	et	4	main
konteksti	doc_769634019908_item	2868323	et	4	main
edastamine	doc_769634019908_item	2868324	et	4	main
sellele	doc_769634019908_item	2868328	et	4	main
et	doc_769634019908_item	2868329	et	3	main
minu	doc_769634019908_item	2868330	et	3	main
teema	doc_769634019908_item	2868331	et	4	main
vaja	doc_769634019908_item	2868347	et	4	main
mind	doc_769634019908_item	2868359	et	4	main
eesnimi	doc_769634019908_item	2868364	et	3	main
ametlik	doc_769634019909_item	2868366	et	3	main
kiri	doc_769634019909_item	2868367	et	3	main
on	doc_769634019909_item	2868370	et	4	main
perekonnanimele	doc_769634019909_item	2868376	et	3	main
teha	doc_769634019909_item	2868384	et	3	main
kuid	doc_769634019909_item	2868389	et	4	main
teha	doc_769634019909_item	2868421	et	3	main
itaalia	doc_769634019907_item	2868024	et	4	main
keelne	doc_769634019907_item	2868025	et	3	main
gracia	doc_769634019907_item	2868033	et	4	main
ei	doc_769634019907_item	2868034	et	4	main
ja	doc_769634019907_item	2868046	et	3	main
sõna	doc_769634019907_item	2868048	et	4	main
prego	doc_769634019907_item	2868049	et	4	main
ausalt	doc_769634019907_item	2868050	et	4	main
vajalik	doc_769634019907_item	2868056	et	3	main
2	doc_769634019907_item	2868058	et	2	main
olid	doc_769634019907_item	2868064	et	4	main
arusaadav	doc_769634019907_item	2868084	et	4	main
ja	doc_769634019907_item	2868089	et	3	main
vahel	doc_769634019907_item	2868100	et	4	main
tihti	doc_769634019907_item	2868106	et	3	main
korrektne	doc_769634019907_item	2868119	et	3	main
kogu	doc_769634019907_item	2868120	et	4	main
informatsioon	doc_769634019907_item	2868121	et	3	main
politseiakadeemia	doc_769634019907_item	2868128	et	4	main
mida	doc_769634019907_item	2868136	et	4	main
nii	doc_769634019907_item	2868140	et	3	main
kujundamisel	doc_769634019907_item	2868154	et	4	main
1	doc_769634019907_item	2868155	et	2	main
puudus	doc_769634019907_item	2868164	et	4	main
tegelase	doc_769634019907_item	2868165	et	3	main
2	doc_769634019907_item	2868175	et	2	main
alati	doc_769634019907_item	2868184	et	4	main
ei	doc_769634019907_item	2868185	et	4	main
ilmunud	doc_769634019907_item	2868186	et	4	main
suu	doc_769634019907_item	2868192	et	4	main
vaheldusid	doc_769634019907_item	2868202	et	4	main
keskmise	doc_769634019907_item	2868204	et	3	main
toimuv	doc_769634019907_item	2868210	et	4	main
kiire	doc_769634019907_item	2868216	et	4	main
vahetus	doc_769634019907_item	2868217	et	4	main
häirinud	doc_769634019907_item	2868219	et	4	main
tähtsam	doc_769634019907_item	2868220	et	4	main
ei	doc_769634019907_item	2868126	et	4	main
lemmikfilm	doc_769634019907_item	2868135	et	3	main
palju	doc_769634019907_item	2868141	et	4	main
kõik	doc_769634019907_item	2868144	et	4	main
on	doc_769634019907_item	2868145	et	4	main
arusaadav	doc_769634019907_item	2868146	et	4	main
viga	doc_769634019907_item	2868152	et	4	main
subtiitrite	doc_769634019907_item	2868153	et	4	main
sageli	doc_769634019907_item	2868163	et	3	main
söör	doc_769634019907_item	2868174	et	3	main
tõlkimata	doc_769634019907_item	2868181	et	4	main
3	doc_769634019907_item	2868182	et	2	main
mitte	doc_769634019907_item	2868183	et	3	main
tegelane	doc_769634019907_item	2868191	et	3	main
kadusid	doc_769634019907_item	2868195	et	4	main
ekraanil	doc_769634019907_item	2868203	et	3	main
seetõttu	doc_769634019907_item	2868214	et	3	main
tegevus	doc_769634019907_item	2868222	et	4	main
öelda	doc_769634019907_item	2868230	et	4	main
on	doc_769634019907_item	2868234	et	4	main
kuulata	doc_769634019907_item	2868237	et	4	main
alternattivi	doc_769634019907_item	2868250	et	4	main
muidugi	doc_769634019907_item	2868278	et	4	main
soov	doc_769634019907_item	2868279	et	3	main
xx-3	doc_769634019908_item	2868288	et	4	main
on	doc_769634019908_item	2868308	et	4	main
järgmine	doc_769634019908_item	2868309	et	3	main
eesti	doc_769634019908_item	2868310	et	4	main
keele	doc_769634019908_item	2868311	et	4	main
eesti	doc_769634019908_item	2868318	et	4	main
nimede	doc_769634019908_item	2868319	et	3	main
ja	doc_769634019908_item	2868321	et	3	main
venekeelsetele	doc_769634019908_item	2868325	et	4	main
keelega	doc_769634019908_item	2868335	et	3	main
analüüsid	doc_769634019908_item	2868340	et	4	main
keeles	doc_769634019908_item	2868344	et	4	main
oma	doc_769634019908_item	2868349	et	4	main
saate	doc_769634019908_item	2868358	et	4	main
vabandan	doc_769634019909_item	2868378	et	3	main
tahaks	doc_769634019909_item	2868382	et	3	main
koostööd	doc_769634019909_item	2868385	et	4	main
seminaritöö	doc_769634019909_item	2868387	et	4	main
kaitsmisega	doc_769634019909_item	2868388	et	4	main
seal	doc_769634019907_item	2868224	et	4	main
tegelikult	doc_769634019907_item	2868225	et	4	main
toimus	doc_769634019907_item	2868226	et	3	main
kokkuvõttes	doc_769634019907_item	2868227	et	3	main
ma	doc_769634019907_item	2868228	et	3	main
tahaks	doc_769634019907_item	2868229	et	3	main
vaadata	doc_769634019907_item	2868235	et	4	main
kui	doc_769634019907_item	2868239	et	3	main
vaadata	doc_769634019907_item	2868240	et	4	main
aga	doc_769634019907_item	2868245	et	3	main
siis	doc_769634019907_item	2868251	et	3	main
neli	doc_769634019907_item	2868264	et	3	main
filmi	doc_769634019907_item	2868265	et	4	main
ma	doc_769634019907_item	2868266	et	3	main
tahaksin	doc_769634019907_item	2868267	et	3	main
öelda	doc_769634019907_item	2868268	et	4	main
et	doc_769634019907_item	2868269	et	3	main
eestikeelsed	doc_769634019907_item	2868270	et	3	main
subtiitrid	doc_769634019907_item	2868271	et	4	main
ei	doc_769634019907_item	2868272	et	4	main
ole	doc_769634019907_item	2868273	et	4	main
nii	doc_769634019907_item	2868274	et	3	main
halvad	doc_769634019907_item	2868275	et	4	main
ja	doc_769634019907_item	2868276	et	3	main
on	doc_769634019907_item	2868277	et	4	main
kui	doc_769634019907_item	2868254	et	3	main
kujundus	doc_769634019907_item	2868256	et	4	main
kiri	doc_769634019908_item	2868284	et	3	main
tere	doc_769634019908_item	2868285	et	3	main
eesnimi	doc_769634019908_item	2868290	et	3	main
ning	doc_769634019908_item	2868292	et	3	main
eesnimi	doc_769634019908_item	2868299	et	3	main
soovitas	doc_769634019908_item	2868301	et	3	main
pöörduda	doc_769634019908_item	2868303	et	3	main
kasutamine	doc_769634019908_item	2868317	et	4	main
lugejatele	doc_769634019908_item	2868326	et	4	main
on	doc_769634019908_item	2868332	et	4	main
mina	doc_769634019908_item	2868336	et	4	main
eesti	doc_769634019908_item	2868343	et	4	main
registreerida	doc_769634019908_item	2868348	et	3	main
teemat	doc_769634019908_item	2868350	et	3	main
kuidagi	doc_769634019908_item	2868360	et	3	main
tänades	doc_769634019908_item	2868363	et	3	main
edasi	doc_769634019909_item	2868383	et	3	main
seoses	doc_769634019909_item	2868386	et	4	main
lugupidamisega	doc_769634019909_item	2868423	et	3	main
koju	doc_769634019912_item	2868732	et	3	main
mul	doc_769634019912_item	2868738	et	3	main
ettekanne	doc_769634019912_item	2868741	et	4	main
midagi	doc_769634019912_item	2868757	et	4	main
leida	doc_769634019912_item	2868758	et	3	main
ma	doc_769634019912_item	2868759	et	3	main
püha	doc_769634019912_item	2868776	et	4	main
eestikeelseid	doc_769634019907_item	2868280	et	3	main
tudeng	doc_769634019908_item	2868289	et	3	main
mul	doc_769634019908_item	2868293	et	3	main
vaja	doc_769634019908_item	2868295	et	4	main
oma	doc_769634019908_item	2868296	et	4	main
diplomitööks	doc_769634019908_item	2868297	et	3	main
juhendajat	doc_769634019908_item	2868298	et	4	main
teie	doc_769634019908_item	2868304	et	4	main
poole	doc_769634019908_item	2868305	et	4	main
minu	doc_769634019908_item	2868306	et	3	main
tõlke	doc_769634019908_item	2868312	et	4	main
informatsiooni	doc_769634019908_item	2868322	et	4	main
seotud	doc_769634019908_item	2868333	et	4	main
teha	doc_769634019908_item	2868338	et	3	main
on	doc_769634019908_item	2868346	et	4	main
kuu	doc_769634019908_item	2868351	et	4	main
lõppuni	doc_769634019908_item	2868352	et	3	main
palun	doc_769634019908_item	2868353	et	3	main
andke	doc_769634019908_item	2868354	et	3	main
teada	doc_769634019908_item	2868355	et	3	main
kui	doc_769634019908_item	2868356	et	3	main
teie	doc_769634019908_item	2868357	et	4	main
eesnimi	doc_769634019909_item	2868371	et	3	main
perekonnanimi	doc_769634019909_item	2868372	et	3	main
olen	doc_769634019909_item	2868373	et	3	main
kirjutanud	doc_769634019909_item	2868374	et	4	main
eesnimi	doc_769634019909_item	2868375	et	3	main
et	doc_769634019909_item	2868377	et	3	main
ees	doc_769634019909_item	2868380	et	4	main
ta	doc_769634019909_item	2868390	et	4	main
ei	doc_769634019909_item	2868391	et	4	main
vasta	doc_769634019909_item	2868392	et	4	main
mulle	doc_769634019909_item	2868393	et	4	main
ma	doc_769634019909_item	2868394	et	3	main
ei	doc_769634019909_item	2868395	et	4	main
tea	doc_769634019909_item	2868396	et	4	main
ta	doc_769634019909_item	2868397	et	4	main
ei	doc_769634019909_item	2868398	et	4	main
taha	doc_769634019909_item	2868399	et	4	main
mind	doc_769634019909_item	2868400	et	4	main
edasi	doc_769634019909_item	2868401	et	3	main
juhendada	doc_769634019909_item	2868402	et	3	main
palun	doc_769634019909_item	2868403	et	3	main
rääkige	doc_769634019909_item	2868404	et	3	main
teie	doc_769634019909_item	2868405	et	4	main
temaga	doc_769634019909_item	2868406	et	3	main
või	doc_769634019909_item	2868407	et	4	main
soovitage	doc_769634019909_item	2868408	et	3	main
palun	doc_769634019909_item	2868409	et	3	main
kuidas	doc_769634019909_item	2868410	et	3	main
ma	doc_769634019909_item	2868411	et	3	main
pean	doc_769634019909_item	2868412	et	4	main
käituma	doc_769634019909_item	2868413	et	3	main
kirjutan	doc_769634019909_item	2868414	et	3	main
oma	doc_769634019909_item	2868415	et	4	main
tööd	doc_769634019909_item	2868416	et	4	main
sain	doc_769634019909_item	2868417	et	3	main
ikka	doc_769634019909_item	2868418	et	4	main
aru	doc_769634019909_item	2868419	et	4	main
kuidas	doc_769634019909_item	2868420	et	3	main
tööd	doc_769634019909_item	2868422	et	4	main
perekonnanimi	doc_769634019908_item	2868365	et	3	main
tere	doc_769634019909_item	2868368	et	3	main
see	doc_769634019909_item	2868369	et	3	main
tema	doc_769634019909_item	2868379	et	4	main
et	doc_769634019909_item	2868381	et	3	main
eesnimi	doc_769634019909_item	2868424	et	3	main
reedel	doc_769634019912_item	2868722	et	3	main
ülikoolis	doc_769634019912_item	2868724	et	4	main
jõulud	doc_769634019912_item	2868727	et	3	main
pärast	doc_769634019912_item	2868728	et	4	main
seda	doc_769634019912_item	2868729	et	3	main
läksin	doc_769634019912_item	2868730	et	3	main
ma	doc_769634019912_item	2868731	et	3	main
ja	doc_769634019912_item	2868733	et	3	main
ja	doc_769634019912_item	2868736	et	3	main
ja	doc_769634019912_item	2868742	et	3	main
ei	doc_769634019912_item	2868749	et	4	main
lugesin	doc_769634019912_item	2868760	et	3	main
kitarri	doc_769634019912_item	2868771	et	4	main
kuni	doc_769634019912_item	2868773	et	3	main
neljapäevani	doc_769634019912_item	2868774	et	3	main
pean	doc_769634019912_item	2868775	et	4	main
palju	doc_769634019912_item	2868780	et	4	main
käisin	doc_769634019912_item	2868794	et	3	main
essee	doc_769634019912_item	2868713	et	4	main
nädalavahetus	doc_769634019912_item	2868714	et	4	main
mul	doc_769634019912_item	2868715	et	3	main
oli	doc_769634019912_item	2868716	et	3	main
see	doc_769634019912_item	2868717	et	3	main
kord	doc_769634019912_item	2868718	et	4	main
väga	doc_769634019912_item	2868719	et	3	main
igav	doc_769634019912_item	2868720	et	3	main
nädalavahetus	doc_769634019912_item	2868721	et	4	main
vaatasime	doc_769634019912_item	2868723	et	3	main
jõulufilmi	doc_769634019912_item	2868725	et	4	main
lepatriinude	doc_769634019912_item	2868726	et	3	main
lugema	doc_769634019912_item	2868735	et	4	main
õppima	doc_769634019912_item	2868737	et	3	main
varsti	doc_769634019912_item	2868740	et	3	main
ma	doc_769634019912_item	2868743	et	3	main
selge	doc_769634019912_item	2868752	et	4	main
terve	doc_769634019912_item	2868761	et	4	main
laupäeval	doc_769634019912_item	2868765	et	3	main
lugeda	doc_769634019912_item	2868767	et	3	main
ööd	doc_769634019912_item	2868777	et	4	main
mängida	doc_769634019912_item	2868778	et	3	main
veetsin	doc_769634019912_item	2868782	et	3	main
tahtsin	doc_769634019912_item	2868821	et	3	main
on	doc_769634019912_item	2868824	et	4	main
ja	doc_769634019912_item	2868827	et	3	main
minu	doc_769634019912_item	2868830	et	3	main
reede	doc_769634019912_item	2868849	et	4	main
hommikul	doc_769634019912_item	2868850	et	3	main
ülesanne	doc_769634019912_item	2868856	et	4	main
ettevalmistama	doc_769634019912_item	2868859	et	4	main
seal	doc_769634019912_item	2868869	et	4	main
juttu	doc_769634019912_item	2868875	et	4	main
raamatuid	doc_769634019912_item	2868883	et	3	main
oli	doc_769634019912_item	2868886	et	3	main
ja	doc_769634019912_item	2868889	et	3	main
valutas	doc_769634019912_item	2868891	et	3	main
ma	doc_769634019912_item	2868892	et	3	main
lôunaajal	doc_769634019912_item	2868897	et	4	main
ja	doc_769634019912_item	2868900	et	3	main
sôime	doc_769634019912_item	2868902	et	4	main
sôber	doc_769634019912_item	2868914	et	4	main
göttingeni	doc_769634019912_item	2868915	et	4	main
käisime	doc_769634019912_item	2868923	et	3	main
teatris	doc_769634019912_item	2868924	et	3	main
toimus	doc_769634019912_item	2868926	et	3	main
ich	doc_769634019912_item	2868928	et	4	main
sibylle	doc_769634019912_item	2868933	et	4	main
meeldis	doc_769634019912_item	2868937	et	3	main
pärast	doc_769634019912_item	2868941	et	4	main
hôôgveini	doc_769634019912_item	2868950	et	4	main
ei	doc_769634019912_item	2868951	et	4	main
saanud	doc_769634019912_item	2868952	et	4	main
juua	doc_769634019912_item	2868953	et	3	main
see	doc_769634019912_item	2868957	et	3	main
oli	doc_769634019912_item	2868958	et	3	main
töötada	doc_769634019912_item	2868969	et	3	main
toas	doc_769634019912_item	2868975	et	3	main
on	doc_769634019912_item	2868739	et	4	main
ettekanne	doc_769634019912_item	2868747	et	4	main
väga	doc_769634019912_item	2868751	et	3	main
ja	doc_769634019912_item	2868753	et	3	main
on	doc_769634019912_item	2868755	et	4	main
raske	doc_769634019912_item	2868756	et	4	main
õhtu	doc_769634019912_item	2868762	et	4	main
tahtsin	doc_769634019912_item	2868764	et	3	main
mängisin	doc_769634019912_item	2868769	et	3	main
oskama	doc_769634019912_item	2868779	et	3	main
taga	doc_769634019912_item	2868784	et	4	main
olin	doc_769634019912_item	2868786	et	3	main
pühapäeval	doc_769634019912_item	2868789	et	3	main
ka	doc_769634019912_item	2868795	et	3	main
esmaspäev	doc_769634019912_item	2868826	et	3	main
ülikoolinädal	doc_769634019912_item	2868828	et	3	main
algab	doc_769634019912_item	2868829	et	3	main
nädalavahetus	doc_769634019912_item	2868831	et	4	main
see	doc_769634019912_item	2868836	et	3	main
soomeugri	doc_769634019912_item	2868844	et	4	main
seminaris	doc_769634019912_item	2868845	et	3	main
siis	doc_769634019912_item	2868846	et	3	main
pidin	doc_769634019912_item	2868847	et	3	main
ma	doc_769634019912_item	2868848	et	3	main
päeva	doc_769634019912_item	2868855	et	4	main
sest	doc_769634019912_item	2868866	et	4	main
ma	doc_769634019912_item	2868867	et	3	main
olen	doc_769634019912_item	2868868	et	3	main
kohtanud	doc_769634019912_item	2868871	et	4	main
me	doc_769634019912_item	2868873	et	4	main
otsisin	doc_769634019912_item	2868881	et	3	main
ei	doc_769634019912_item	2868893	et	4	main
ettekandega	doc_769634019912_item	2868895	et	3	main
eesnimega	doc_769634019912_item	2868899	et	3	main
tegime	doc_769634019912_item	2868907	et	3	main
me	doc_769634019912_item	2868917	et	4	main
kokku	doc_769634019912_item	2868921	et	3	main
seal	doc_769634019912_item	2868925	et	4	main
erzählt	doc_769634019912_item	2868932	et	4	main
väga	doc_769634019912_item	2868936	et	3	main
teatri	doc_769634019912_item	2868940	et	3	main
jalutasime	doc_769634019912_item	2868942	et	3	main
ja	doc_769634019912_item	2868949	et	3	main
laupäeval	doc_769634019912_item	2868954	et	3	main
ettekandega	doc_769634019912_item	2868961	et	3	main
veeta	doc_769634019912_item	2868963	et	4	main
sellepärast	doc_769634019912_item	2868964	et	3	main
et	doc_769634019912_item	2868965	et	3	main
ma	doc_769634019912_item	2868966	et	3	main
kui	doc_769634019912_item	2868970	et	3	main
on	doc_769634019912_item	2868972	et	4	main
juba	doc_769634019912_item	2868988	et	3	main
tunni	doc_769634019912_item	2868990	et	3	main
nägin	doc_769634019912_item	2869022	et	3	main
ütlesin	doc_769634019912_item	2869026	et	3	main
peaksime	doc_769634019912_item	2869028	et	4	main
jôululaadal	doc_769634019912_item	2869034	et	4	main
tegelikult	doc_769634019912_item	2869037	et	4	main
jôuludeks	doc_769634019912_item	2869039	et	4	main
osta	doc_769634019912_item	2869040	et	4	main
natuke	doc_769634019912_item	2869044	et	4	main
kardan	doc_769634019912_item	2869052	et	4	main
ettevalmistada	doc_769634019912_item	2869067	et	4	main
ôhtu	doc_769634019912_item	2869095	et	4	main
ja	doc_769634019912_item	2869096	et	3	main
ôhtul	doc_769634019912_item	2869098	et	4	main
tegelema	doc_769634019912_item	2869103	et	3	main
ja	doc_769634019912_item	2869106	et	3	main
on	doc_769634019912_item	2869108	et	4	main
juba	doc_769634019912_item	2869109	et	3	main
esmaspäev	doc_769634019912_item	2869110	et	3	main
ettekanne	doc_769634019912_item	2869111	et	4	main
kuidas	doc_769634019912_item	2869118	et	3	main
nädalavahetus	doc_769634019912_item	2869122	et	4	main
hea	doc_769634019912_item	2869124	et	4	main
hakkasin	doc_769634019912_item	2868734	et	3	main
pean	doc_769634019912_item	2868744	et	4	main
seda	doc_769634019912_item	2868745	et	3	main
ettevalmistama	doc_769634019912_item	2868746	et	4	main
teema	doc_769634019912_item	2868748	et	4	main
ole	doc_769634019912_item	2868750	et	4	main
sellepärast	doc_769634019912_item	2868754	et	3	main
ja	doc_769634019912_item	2868763	et	3	main
edasi	doc_769634019912_item	2868766	et	3	main
ma	doc_769634019912_item	2868768	et	3	main
natukene	doc_769634019912_item	2868770	et	4	main
sest	doc_769634019912_item	2868772	et	4	main
aega	doc_769634019912_item	2868781	et	4	main
arvuti	doc_769634019912_item	2868783	et	4	main
ma	doc_769634019912_item	2868785	et	3	main
tegelnud	doc_769634019912_item	2868788	et	4	main
ühe	doc_769634019912_item	2868791	et	4	main
ja	doc_769634019912_item	2868793	et	3	main
ringi	doc_769634019912_item	2868796	et	4	main
väljas	doc_769634019912_item	2868797	et	4	main
ma	doc_769634019912_item	2868798	et	3	main
vaatsin	doc_769634019912_item	2868799	et	4	main
siis	doc_769634019912_item	2868800	et	3	main
filmi	doc_769634019912_item	2868801	et	4	main
teiste	doc_769634019912_item	2868802	et	4	main
elu	doc_769634019912_item	2868803	et	4	main
ja	doc_769634019912_item	2868804	et	3	main
helistasin	doc_769634019912_item	2868805	et	3	main
perele	doc_769634019912_item	2868806	et	3	main
ja	doc_769634019912_item	2868807	et	3	main
sõbrale	doc_769634019912_item	2868808	et	3	main
see	doc_769634019912_item	2868809	et	3	main
nädalavahetus	doc_769634019912_item	2868810	et	4	main
ei	doc_769634019912_item	2868811	et	4	main
olnud	doc_769634019912_item	2868812	et	4	main
hea	doc_769634019912_item	2868813	et	4	main
sest	doc_769634019912_item	2868814	et	4	main
ma	doc_769634019912_item	2868815	et	3	main
ei	doc_769634019912_item	2868816	et	4	main
ole	doc_769634019912_item	2868817	et	4	main
seda	doc_769634019912_item	2868818	et	3	main
teinud	doc_769634019912_item	2868819	et	4	main
mida	doc_769634019912_item	2868820	et	4	main
väga	doc_769634019912_item	2868833	et	3	main
algas	doc_769634019912_item	2868837	et	3	main
juba	doc_769634019912_item	2868839	et	3	main
neljapäeval	doc_769634019912_item	2868840	et	3	main
neljapäeval	doc_769634019912_item	2868841	et	3	main
oli	doc_769634019912_item	2868842	et	3	main
jôulupidu	doc_769634019912_item	2868843	et	4	main
käima	doc_769634019912_item	2868854	et	4	main
ettekannet	doc_769634019912_item	2868858	et	4	main
kultuuriantropoloogia	doc_769634019912_item	2868860	et	4	main
raamatukogus	doc_769634019912_item	2868861	et	4	main
olin	doc_769634019912_item	2868862	et	3	main
sôpra	doc_769634019912_item	2868870	et	4	main
ja	doc_769634019912_item	2868872	et	3	main
ajasime	doc_769634019912_item	2868874	et	3	main
jõulukingitustega	doc_769634019912_item	2868787	et	4	main
kohtusin	doc_769634019912_item	2868790	et	4	main
sõbraga	doc_769634019912_item	2868792	et	3	main
oli	doc_769634019912_item	2868832	et	3	main
tegelikult	doc_769634019912_item	2868838	et	4	main
raamatukogus	doc_769634019912_item	2868853	et	4	main
ma	doc_769634019912_item	2868863	et	3	main
liiga	doc_769634019912_item	2868864	et	4	main
kaua	doc_769634019912_item	2868865	et	3	main
siis	doc_769634019912_item	2868876	et	3	main
ma	doc_769634019912_item	2868878	et	3	main
paar	doc_769634019912_item	2868882	et	3	main
väga	doc_769634019912_item	2868887	et	3	main
siis	doc_769634019912_item	2868906	et	3	main
soome	doc_769634019912_item	2868908	et	3	main
harjutusi	doc_769634019912_item	2868910	et	4	main
ôhtul	doc_769634019912_item	2868911	et	4	main
ja	doc_769634019912_item	2868916	et	3	main
teatri	doc_769634019912_item	2868919	et	3	main
eigentlich	doc_769634019912_item	2868930	et	4	main
see	doc_769634019912_item	2868938	et	3	main
etendus	doc_769634019912_item	2868939	et	4	main
jôululaat	doc_769634019912_item	2868945	et	4	main
oli	doc_769634019912_item	2868946	et	3	main
juba	doc_769634019912_item	2868947	et	3	main
ja	doc_769634019912_item	2868956	et	3	main
vôimalus	doc_769634019912_item	2868960	et	4	main
saa	doc_769634019912_item	2868968	et	4	main
kahjuks	doc_769634019912_item	2868984	et	4	main
mu	doc_769634019912_item	2868986	et	3	main
pärast	doc_769634019912_item	2868991	et	4	main
ja	doc_769634019912_item	2868993	et	3	main
teha	doc_769634019912_item	2868822	et	3	main
nüüd	doc_769634019912_item	2868823	et	4	main
jälle	doc_769634019912_item	2868825	et	3	main
tore	doc_769634019912_item	2868834	et	3	main
sest	doc_769634019912_item	2868835	et	4	main
ülestôusma	doc_769634019912_item	2868851	et	4	main
ja	doc_769634019912_item	2868852	et	3	main
oli	doc_769634019912_item	2868857	et	3	main
ja	doc_769634019912_item	2868880	et	3	main
minu	doc_769634019912_item	2868884	et	3	main
tahtnud	doc_769634019912_item	2868894	et	4	main
tegeleda	doc_769634019912_item	2868896	et	3	main
kohtusin	doc_769634019912_item	2868898	et	4	main
me	doc_769634019912_item	2868901	et	4	main
ja	doc_769634019912_item	2868903	et	3	main
mensas	doc_769634019912_item	2868905	et	4	main
keele	doc_769634019912_item	2868909	et	4	main
saime	doc_769634019912_item	2868918	et	3	main
ees	doc_769634019912_item	2868920	et	4	main
me	doc_769634019912_item	2868922	et	4	main
habe	doc_769634019912_item	2868927	et	3	main
dir	doc_769634019912_item	2868929	et	4	main
bergist	doc_769634019912_item	2868934	et	4	main
suletud	doc_769634019912_item	2868948	et	4	main
kedagi	doc_769634019912_item	2868971	et	4	main
minuga	doc_769634019912_item	2868973	et	3	main
oma	doc_769634019912_item	2868974	et	4	main
sôpra	doc_769634019912_item	2868977	et	4	main
kahe	doc_769634019912_item	2868989	et	3	main
unustasime	doc_769634019912_item	2869043	et	3	main
on	doc_769634019912_item	2869046	et	4	main
veel	doc_769634019912_item	2869047	et	4	main
nädal	doc_769634019912_item	2869048	et	3	main
mul	doc_769634019912_item	2869056	et	3	main
pole	doc_769634019912_item	2869057	et	3	main
nüüd	doc_769634019912_item	2869092	et	4	main
on	doc_769634019912_item	2869093	et	4	main
kahjuks	doc_769634019912_item	2869094	et	4	main
väga	doc_769634019912_item	2869104	et	3	main
hea	doc_769634019912_item	2869105	et	4	main
head	doc_769634019912_item	2869116	et	4	main
seda	doc_769634019912_item	2869119	et	3	main
olin	doc_769634019912_item	2868877	et	3	main
ülikooliraamatukogus	doc_769634019912_item	2868879	et	4	main
kott	doc_769634019912_item	2868885	et	3	main
raske	doc_769634019912_item	2868888	et	4	main
pea	doc_769634019912_item	2868890	et	4	main
rääkisime	doc_769634019912_item	2868904	et	3	main
tuli	doc_769634019912_item	2868912	et	4	main
mu	doc_769634019912_item	2868913	et	3	main
schon	doc_769634019912_item	2868931	et	4	main
meile	doc_769634019912_item	2868935	et	4	main
kesklinnas	doc_769634019912_item	2868943	et	4	main
ringi	doc_769634019912_item	2868944	et	4	main
tuli	doc_769634019912_item	2868955	et	4	main
viimane	doc_769634019912_item	2868959	et	3	main
aega	doc_769634019912_item	2868962	et	4	main
ei	doc_769634019912_item	2868967	et	4	main
saatsin	doc_769634019912_item	2868976	et	3	main
tegema	doc_769634019912_item	2868979	et	3	main
pidin	doc_769634019912_item	2868981	et	3	main
sôber	doc_769634019912_item	2868987	et	4	main
tagasi	doc_769634019912_item	2868992	et	3	main
tahtis	doc_769634019912_item	2868994	et	3	main
telekat	doc_769634019912_item	2868995	et	3	main
vaadata	doc_769634019912_item	2868996	et	4	main
ma	doc_769634019912_item	2868997	et	3	main
nägin	doc_769634019912_item	2868998	et	3	main
televiisoris	doc_769634019912_item	2868999	et	3	main
lund	doc_769634019912_item	2869000	et	3	main
ja	doc_769634019912_item	2869001	et	3	main
mul	doc_769634019912_item	2869002	et	3	main
tuli	doc_769634019912_item	2869003	et	4	main
meelde	doc_769634019912_item	2869004	et	3	main
et	doc_769634019912_item	2869005	et	3	main
talispordi	doc_769634019912_item	2869006	et	3	main
vôistlused	doc_769634019912_item	2869007	et	4	main
toimuvad	doc_769634019912_item	2869008	et	4	main
mis	doc_769634019912_item	2869009	et	4	main
nüüd	doc_769634019912_item	2869010	et	4	main
ettekannet	doc_769634019912_item	2869011	et	4	main
saan	doc_769634019912_item	2869012	et	4	main
ka	doc_769634019912_item	2869013	et	3	main
hiljem	doc_769634019912_item	2869014	et	3	main
teha	doc_769634019912_item	2869015	et	3	main
selge	doc_769634019912_item	2869016	et	4	main
kui	doc_769634019912_item	2869017	et	3	main
ma	doc_769634019912_item	2869018	et	3	main
aknast	doc_769634019912_item	2869019	et	4	main
välja	doc_769634019912_item	2869020	et	4	main
päiket	doc_769634019912_item	2869024	et	4	main
välja	doc_769634019912_item	2869029	et	4	main
minema	doc_769634019912_item	2869030	et	3	main
olime	doc_769634019912_item	2869031	et	3	main
linnas	doc_769634019912_item	2869032	et	4	main
ja	doc_769634019912_item	2869033	et	3	main
kingitusi	doc_769634019912_item	2869038	et	4	main
aga	doc_769634019912_item	2869041	et	3	main
jôuludeni	doc_769634019912_item	2869049	et	4	main
järgmist	doc_769634019912_item	2869053	et	3	main
perele	doc_769634019912_item	2869059	et	3	main
ma	doc_769634019912_item	2869068	et	3	main
üritasin	doc_769634019912_item	2869069	et	3	main
ainult	doc_769634019912_item	2869070	et	4	main
nii	doc_769634019912_item	2869091	et	3	main
ettekandega	doc_769634019912_item	2869102	et	3	main
sisseosteid	doc_769634019912_item	2868978	et	4	main
nüüd	doc_769634019912_item	2868980	et	4	main
tôesti	doc_769634019912_item	2868982	et	4	main
töötama	doc_769634019912_item	2868983	et	3	main
tuli	doc_769634019912_item	2868985	et	4	main
vaatasin	doc_769634019912_item	2869021	et	3	main
ma	doc_769634019912_item	2869023	et	3	main
tahtsime	doc_769634019912_item	2869036	et	3	main
seda	doc_769634019912_item	2869042	et	3	main
ja	doc_769634019912_item	2869050	et	3	main
esmaspäeva	doc_769634019912_item	2869054	et	4	main
terve	doc_769634019912_item	2869058	et	4	main
sôpradele	doc_769634019912_item	2869061	et	4	main
pühapäeva	doc_769634019912_item	2869097	et	4	main
ma	doc_769634019912_item	2869099	et	3	main
ei	doc_769634019912_item	2869100	et	4	main
vajan	doc_769634019912_item	2869115	et	3	main
ja	doc_769634019912_item	2869025	et	3	main
et	doc_769634019912_item	2869027	et	3	main
me	doc_769634019912_item	2869035	et	4	main
nüüd	doc_769634019912_item	2869045	et	4	main
ma	doc_769634019912_item	2869051	et	3	main
sest	doc_769634019912_item	2869055	et	4	main
ja	doc_769634019912_item	2869060	et	3	main
kingitusi	doc_769634019912_item	2869062	et	4	main
eile	doc_769634019912_item	2869063	et	3	main
üritasin	doc_769634019912_item	2869064	et	3	main
jälle	doc_769634019912_item	2869065	et	3	main
ettekannet	doc_769634019912_item	2869066	et	4	main
mulle	doc_769634019912_item	2869071	et	4	main
isegi	doc_769634019912_item	2869072	et	4	main
meeldib	doc_769634019912_item	2869073	et	3	main
koristada	doc_769634019912_item	2869074	et	3	main
kui	doc_769634019912_item	2869075	et	3	main
pean	doc_769634019912_item	2869076	et	4	main
midagi	doc_769634019912_item	2869077	et	4	main
ülikooli	doc_769634019912_item	2869078	et	4	main
jaoks	doc_769634019912_item	2869079	et	4	main
tegema	doc_769634019912_item	2869080	et	3	main
ôhtul	doc_769634019912_item	2869081	et	4	main
vaatasime	doc_769634019912_item	2869082	et	3	main
filmi	doc_769634019912_item	2869083	et	4	main
forrest	doc_769634019912_item	2869084	et	4	main
gump	doc_769634019912_item	2869085	et	4	main
ja	doc_769634019912_item	2869086	et	3	main
siis	doc_769634019912_item	2869087	et	3	main
ma	doc_769634019912_item	2869088	et	3	main
ütlesin	doc_769634019912_item	2869089	et	3	main
umbes	doc_769634019912_item	2869090	et	4	main
pea	doc_769634019912_item	2869101	et	4	main
nüüd	doc_769634019912_item	2869107	et	4	main
môtet	doc_769634019912_item	2869117	et	4	main
jôuda	doc_769634019912_item	2869120	et	4	main
aga	doc_769634019912_item	2869121	et	3	main
oli	doc_769634019912_item	2869123	et	3	main
on	doc_769634019912_item	2869112	et	4	main
ülehomme	doc_769634019912_item	2869113	et	3	main
ma	doc_769634019912_item	2869114	et	3	main
i	doc_771173210946_item	2869863	et	4	main
pange	doc_771173210946_item	2869864	et	4	main
piret	doc_771173210946_item	2869870	et	4	main
toomet	doc_771173210946_item	2869871	et	4	main
on	doc_771173210946_item	2869872	et	4	main
ettevõtlik	doc_771173210946_item	2869873	et	3	main
on	doc_771173210946_item	2869896	et	4	main
nädal	doc_771173210946_item	2869900	et	3	main
pireti	doc_771173210946_item	2869909	et	4	main
siberisse	doc_771173210946_item	2869913	et	4	main
mulle	doc_771173210946_item	2869931	et	4	main
maaliti	doc_771173210946_item	2869932	et	3	main
ei	doc_771173210946_item	2869939	et	4	main
lendama	doc_771173210946_item	2869940	et	3	main
kui	doc_771173210946_item	2869946	et	3	main
täis	doc_771173210946_item	2869950	et	4	main
pärast	doc_771173210946_item	2869952	et	4	main
küla	doc_771173210946_item	2869964	et	4	main
võtma	doc_771173210946_item	2869965	et	3	main
olevad	doc_771173210946_item	2869866	et	4	main
õigesse	doc_771173210946_item	2869868	et	3	main
vormi	doc_771173210946_item	2869869	et	4	main
ja	doc_771173210946_item	2869895	et	3	main
üle	doc_771173210946_item	2869899	et	3	main
need	doc_771173210946_item	2869904	et	3	main
nendel	doc_771173210946_item	2869905	et	4	main
emakeelt	doc_771173210946_item	2869906	et	4	main
õpetama	doc_771173210946_item	2869907	et	3	main
õpetab	doc_771173210946_item	2869908	et	3	main
ta	doc_771173210946_item	2869912	et	4	main
et	doc_771173210946_item	2869916	et	3	main
oodatud	doc_771173210946_item	2869918	et	4	main
üsna	doc_771173210946_item	2869920	et	3	main
kui	doc_771173210946_item	2869923	et	3	main
siberiast	doc_771173210946_item	2869934	et	3	main
selline	doc_771173210946_item	2869935	et	4	main
pilt	doc_771173210946_item	2869936	et	3	main
et	doc_771173210946_item	2869937	et	3	main
lenda	doc_771173210946_item	2869941	et	4	main
kasva	doc_771173210946_item	2869944	et	4	main
ja	doc_771173210946_item	2869948	et	3	main
koht	doc_771173210946_item	2869955	et	3	main
kool	doc_771173210946_item	2869959	et	4	main
veel	doc_771173210946_item	2869960	et	4	main
algab	doc_771173210946_item	2869962	et	3	main
kogu	doc_771173210946_item	2869963	et	4	main
kartulivõtt	doc_771173210946_item	2869968	et	3	main
kõige	doc_771173210946_item	2869972	et	4	main
salv	doc_771173210946_item	2869979	et	3	main
õppimine	doc_771173210946_item	2869982	et	4	main
käib	doc_771173210946_item	2869983	et	3	main
siinsed	doc_771173210946_item	2869986	et	3	main
kuidagi	doc_771173210946_item	2869989	et	3	main
aktsent	doc_771173210946_item	2869999	et	3	main
nagu	doc_771173210946_item	2870002	et	3	main
mõni	doc_771173210946_item	2870003	et	3	main
keeles	doc_771173210946_item	2870016	et	4	main
veidi	doc_771173210946_item	2870019	et	3	main
kõik	doc_771173210946_item	2870027	et	4	main
piret	doc_771173210946_item	2870045	et	4	main
tooma	doc_771173210946_item	2870051	et	3	main
on	doc_771173210946_item	2870055	et	4	main
eksamitöö	doc_771173210946_item	2869862	et	4	main
sulgudes	doc_771173210946_item	2869865	et	4	main
naine	doc_771173210946_item	2869874	et	3	main
suvel	doc_771173210946_item	2869875	et	3	main
nägema	doc_771173210946_item	2869876	et	3	main
nägi	doc_771173210946_item	2869877	et	3	main
ta	doc_771173210946_item	2869878	et	4	main
ajalehes	doc_771173210946_item	2869879	et	3	main
kuulutus	doc_771173210946_item	2869880	et	4	main
kuulutust	doc_771173210946_item	2869881	et	4	main
et	doc_771173210946_item	2869882	et	3	main
siberisse	doc_771173210946_item	2869883	et	4	main
ülem-suetuki	doc_771173210946_item	2869884	et	4	main
küla	doc_771173210946_item	2869885	et	4	main
külas	doc_771173210946_item	2869886	et	3	main
otsitakse	doc_771173210946_item	2869887	et	3	main
eesti	doc_771173210946_item	2869888	et	4	main
keele	doc_771173210946_item	2869889	et	4	main
õpetajat	doc_771173210946_item	2869890	et	4	main
piret	doc_771173210946_item	2869891	et	4	main
võitis	doc_771173210946_item	2869892	et	3	main
konkurss	doc_771173210946_item	2869893	et	3	main
sõnad	doc_771173210946_item	2869867	et	4	main
konkursi	doc_771173210946_item	2869894	et	3	main
nüüd	doc_771173210946_item	2869897	et	4	main
väikestele	doc_771173210946_item	2869902	et	4	main
eestlastele	doc_771173210946_item	2869903	et	4	main
jõudma	doc_771173210946_item	2869914	et	3	main
olin	doc_771173210946_item	2869919	et	3	main
üllatud	doc_771173210946_item	2869922	et	3	main
siber	doc_771173210946_item	2869933	et	4	main
ega	doc_771173210946_item	2869943	et	3	main
rohi	doc_771173210946_item	2869945	et	4	main
tahtmine	doc_771173210946_item	2869949	et	4	main
õppeaasta	doc_771173210946_item	2869953	et	4	main
jõudis	doc_771173210946_item	2869957	et	3	main
algama	doc_771173210946_item	2869961	et	3	main
on	doc_771173210946_item	2869969	et	4	main
sügisel	doc_771173210946_item	2869971	et	3	main
tähtis	doc_771173210946_item	2869973	et	4	main
tähtsam	doc_771173210946_item	2869974	et	4	main
ettevõtmine	doc_771173210946_item	2869975	et	3	main
ja	doc_771173210946_item	2869981	et	3	main
täie	doc_771173210946_item	2869984	et	3	main
hoog	doc_771173210946_item	2869985	et	3	main
vaid	doc_771173210946_item	2870001	et	3	main
mõned	doc_771173210946_item	2870004	et	3	main
siiski	doc_771173210946_item	2870008	et	4	main
venemaa	doc_771173210946_item	2870009	et	4	main
vene	doc_771173210946_item	2870015	et	4	main
kolmsada	doc_771173210946_item	2870021	et	4	main
kolmesaja	doc_771173210946_item	2870022	et	4	main
pireti	doc_771173210946_item	2870030	et	4	main
sõnul	doc_771173210946_item	2870031	et	3	main
õpivad	doc_771173210946_item	2870032	et	3	main
talve	doc_771173210946_item	2870044	et	4	main
mulle	doc_771173210946_item	2870049	et	4	main
juba	doc_771173210946_item	2870050	et	3	main
talvepuud	doc_771173210946_item	2870053	et	4	main
kuid	doc_771173210946_item	2870060	et	4	main
vildid	doc_771173210946_item	2870077	et	4	main
ega	doc_771173210946_item	2870078	et	3	main
slõhtuleht	doc_771173210946_item	2870092	et	4	main
etteantud	doc_771173210946_item	2870095	et	4	main
tegema	doc_771173210946_item	2870107	et	3	main
naiselikum	doc_771173210946_item	2870109	et	4	main
laskma	doc_771173210946_item	2870140	et	3	main
ülekoormus	doc_771173210946_item	2870141	et	3	main
saama	doc_771173210946_item	2870144	et	4	main
olema	doc_771173210946_item	2870153	et	4	main
tänapäev	doc_771173210946_item	2870154	et	3	main
aparaat	doc_771173210946_item	2870158	et	3	main
saamas	doc_771173210946_item	2870169	et	4	main
aparat	doc_771173210946_item	2870172	et	4	main
telefonihelin	doc_771173210946_item	2870175	et	3	main
katkestama	doc_771173210946_item	2870176	et	3	main
ka	doc_771173210946_item	2870177	et	3	main
pühapäev	doc_771173210946_item	2870178	et	3	main
varahommik	doc_771173210946_item	2870179	et	3	main
uni	doc_771173210946_item	2870180	et	3	main
segama	doc_771173210946_item	2870181	et	3	main
lõunasöök	doc_771173210946_item	2870182	et	3	main
valmistamine	doc_771173210946_item	2870183	et	4	main
ja	doc_771173210946_item	2870184	et	3	main
telefonihelin	doc_771173210946_item	2870192	et	3	main
uni	doc_771173210946_item	2870197	et	3	main
lõunasööki	doc_771173210946_item	2870199	et	4	main
söömine	doc_771173210946_item	2870202	et	4	main
olevad	doc_771173210946_item	2870211	et	4	main
väga	doc_771173210946_item	2870218	et	3	main
igaühe	doc_771173210946_item	2870230	et	4	main
artikli	doc_771173210946_item	2870233	et	3	main
sa	doc_771173210946_item	2870239	et	3	main
ja	doc_771173210946_item	2870250	et	3	main
kiired	doc_771173210946_item	2870251	et	4	main
ilusast	doc_771173210946_item	2870253	et	3	main
praegu	doc_771173210946_item	2870258	et	3	main
tüdinesin	doc_771173210946_item	2870265	et	3	main
uus	doc_771173210946_item	2870268	et	3	main
kiiresti	doc_771173210946_item	2870270	et	3	main
selles	doc_771173210946_item	2870273	et	4	main
küsimuses	doc_771173210946_item	2870274	et	4	main
tundis	doc_771173210946_item	2869911	et	3	main
on	doc_771173210946_item	2869917	et	4	main
juba	doc_771173210946_item	2869898	et	3	main
nädala	doc_771173210946_item	2869901	et	3	main
kinnitusel	doc_771173210946_item	2869910	et	4	main
jõudis	doc_771173210946_item	2869915	et	3	main
üllatuma	doc_771173210946_item	2869921	et	3	main
mulle	doc_771173210946_item	2869924	et	4	main
tulema	doc_771173210946_item	2869925	et	4	main
tuleb	doc_771173210946_item	2869926	et	3	main
vastu	doc_771173210946_item	2869927	et	3	main
korralik	doc_771173210946_item	2869928	et	3	main
korraliku	doc_771173210946_item	2869929	et	3	main
audiga	doc_771173210946_item	2869930	et	3	main
seal	doc_771173210946_item	2869938	et	4	main
lind	doc_771173210946_item	2869942	et	3	main
noor	doc_771173210946_item	2869947	et	3	main
piret	doc_771173210946_item	2869951	et	4	main
algust	doc_771173210946_item	2869954	et	4	main
kohases	doc_771173210946_item	2869956	et	4	main
võtmed	doc_771173210946_item	2869966	et	3	main
tänaseks	doc_771173210946_item	2869976	et	4	main
eestlased	doc_771173210946_item	2869987	et	3	main
teistmoodi	doc_771173210946_item	2869990	et	3	main
ja	doc_771173210946_item	2869992	et	3	main
mõnusad	doc_771173210946_item	2869994	et	3	main
ja	doc_771173210946_item	2869995	et	3	main
mahlakad	doc_771173210946_item	2869996	et	3	main
murret	doc_771173210946_item	2870005	et	4	main
on	doc_771173210946_item	2870007	et	4	main
külas	doc_771173210946_item	2870017	et	3	main
elab	doc_771173210946_item	2870018	et	3	main
üle	doc_771173210946_item	2870020	et	3	main
kõigi	doc_771173210946_item	2870028	et	4	main
rääkida	doc_771173210946_item	2870029	et	3	main
poolpõlenud	doc_771173210946_item	2870034	et	4	main
siberi	doc_771173210946_item	2870043	et	4	main
ei	doc_771173210946_item	2870046	et	4	main
kartma	doc_771173210946_item	2870047	et	3	main
karda	doc_771173210946_item	2870048	et	4	main
tõime	doc_771173210946_item	2870052	et	3	main
praegu	doc_771173210946_item	2870054	et	3	main
ööd	doc_771173210946_item	2870061	et	4	main
juba	doc_771173210946_item	2870062	et	3	main
jahe	doc_771173210946_item	2870063	et	3	main
jahedad	doc_771173210946_item	2870064	et	3	main
kütmine	doc_771173210946_item	2870070	et	4	main
muud	doc_771173210946_item	2870081	et	4	main
laused	doc_771173210946_item	2870097	et	3	main
õigesse	doc_771173210946_item	2870100	et	3	main
kirjavahemärke	doc_771173210946_item	2870104	et	4	main
ja	doc_771173210946_item	2870110	et	3	main
mehelikum	doc_771173210946_item	2870112	et	4	main
tegi	doc_771173210946_item	2870116	et	4	main
naised	doc_771173210946_item	2870117	et	3	main
3	doc_771173210946_item	2870124	et	2	main
paras	doc_771173210946_item	2870125	et	3	main
kogus	doc_771173210946_item	2870126	et	4	main
meie	doc_771173210946_item	2870129	et	4	main
tegutsema	doc_771173210946_item	2870130	et	3	main
aga	doc_771173210946_item	2870131	et	3	main
lisakoormus	doc_771173210946_item	2870132	et	3	main
tohtnud	doc_771173210946_item	2870150	et	4	main
5	doc_771173210946_item	2870151	et	2	main
telefon	doc_771173210946_item	2870152	et	3	main
maagiline	doc_771173210946_item	2870157	et	4	main
abil	doc_771173210946_item	2870161	et	4	main
lausa	doc_771173210946_item	2870162	et	4	main
elama	doc_771173210946_item	2870163	et	3	main
ja	doc_771173210946_item	2870164	et	3	main
hingama	doc_771173210946_item	2870165	et	3	main
telefon	doc_771173210946_item	2870166	et	3	main
oli	doc_771173210946_item	2870167	et	3	main
tänapäeva	doc_771173210946_item	2870168	et	4	main
maagiline	doc_771173210946_item	2870171	et	4	main
kuid	doc_771173210946_item	2870174	et	4	main
telesaade	doc_771173210946_item	2870188	et	4	main
kuid	doc_771173210946_item	2870191	et	4	main
pühapäeval	doc_771173210946_item	2870195	et	3	main
ja	doc_771173210946_item	2870201	et	3	main
huvitava	doc_771173210946_item	2870204	et	4	main
vaatamist	doc_771173210946_item	2870206	et	4	main
pange	doc_771173210946_item	2870209	et	4	main
polnud	doc_771173210946_item	2869958	et	3	main
kartuleid	doc_771173210946_item	2869967	et	3	main
siin	doc_771173210946_item	2869970	et	4	main
salve	doc_771173210946_item	2869980	et	4	main
mõnus	doc_771173210946_item	2869991	et	4	main
mitte	doc_771173210946_item	2869997	et	3	main
aksendi	doc_771173210946_item	2870000	et	4	main
kool	doc_771173210946_item	2870006	et	4	main
ülejäänud	doc_771173210946_item	2870012	et	4	main
aine	doc_771173210946_item	2870013	et	4	main
õpetatakse	doc_771173210946_item	2870014	et	3	main
müüdagi	doc_771173210946_item	2870083	et	3	main
naerab	doc_771173210946_item	2870084	et	3	main
talveks	doc_771173210946_item	2870085	et	4	main
valmistuma	doc_771173210946_item	2870086	et	3	main
valmistatud	doc_771173210946_item	2870087	et	4	main
piret	doc_771173210946_item	2870088	et	4	main
vapralt	doc_771173210946_item	2870089	et	4	main
on	doc_771173210946_item	2869977	et	4	main
kartul	doc_771173210946_item	2869978	et	3	main
räägivad	doc_771173210946_item	2869988	et	3	main
mahlakas	doc_771173210946_item	2869993	et	4	main
vene	doc_771173210946_item	2869998	et	4	main
kool	doc_771173210946_item	2870010	et	4	main
ja	doc_771173210946_item	2870011	et	3	main
inimene	doc_771173210946_item	2870023	et	3	main
inimest	doc_771173210946_item	2870024	et	3	main
emakeelt	doc_771173210946_item	2870025	et	4	main
saab	doc_771173210946_item	2870026	et	3	main
lapsed	doc_771173210946_item	2870033	et	3	main
raamatud	doc_771173210946_item	2870035	et	4	main
raamatuid	doc_771173210946_item	2870036	et	3	main
varsti	doc_771173210946_item	2870037	et	3	main
saatma	doc_771173210946_item	2870038	et	3	main
saadavad	doc_771173210946_item	2870039	et	4	main
eestist	doc_771173210946_item	2870040	et	3	main
uued	doc_771173210946_item	2870041	et	3	main
õpikud	doc_771173210946_item	2870042	et	3	main
soe	doc_771173210946_item	2870058	et	4	main
soojad	doc_771173210946_item	2870059	et	3	main
ahju	doc_771173210946_item	2870069	et	4	main
kütmima	doc_771173210946_item	2870071	et	4	main
kui	doc_771173210946_item	2870072	et	3	main
vaja	doc_771173210946_item	2870073	et	4	main
ostan	doc_771173210946_item	2870074	et	3	main
külapood	doc_771173210946_item	2870075	et	3	main
külapoes	doc_771173210946_item	2870076	et	3	main
ei	doc_771173210946_item	2870082	et	4	main
lühendatud	doc_771173210946_item	2870090	et	4	main
iii	doc_771173210946_item	2870093	et	4	main
sõnadest	doc_771173210946_item	2870096	et	3	main
sõnad	doc_771173210946_item	2870099	et	4	main
naeratus	doc_771173210946_item	2870106	et	4	main
mehed	doc_771173210946_item	2870120	et	3	main
mehelikum	doc_771173210946_item	2870121	et	4	main
igaühed	doc_771173210946_item	2870122	et	3	main
kaunivad	doc_771173210946_item	2870123	et	4	main
ei	doc_771173210946_item	2870138	et	4	main
tohtima	doc_771173210946_item	2870139	et	3	main
tekkima	doc_771173210946_item	2870142	et	3	main
ja	doc_771173210946_item	2870147	et	3	main
puhkama	doc_771173210946_item	2870148	et	3	main
ei	doc_771173210946_item	2870149	et	4	main
et	doc_771173210946_item	2870159	et	3	main
see	doc_771173210946_item	2870160	et	3	main
6	doc_771173210946_item	2870173	et	2	main
söömine	doc_771173210946_item	2870185	et	4	main
pahandab	doc_771173210946_item	2870186	et	3	main
vaatamine	doc_771173210946_item	2870189	et	4	main
katkestab	doc_771173210946_item	2870193	et	3	main
segab	doc_771173210946_item	2870198	et	3	main
valmistada	doc_771173210946_item	2870200	et	3	main
ma	doc_771173210946_item	2870216	et	3	main
lugu	doc_771173210946_item	2870219	et	4	main
päevad	doc_771173210946_item	2870056	et	3	main
veel	doc_771173210946_item	2870057	et	4	main
harjutan	doc_771173210946_item	2870065	et	3	main
juba	doc_771173210946_item	2870066	et	3	main
suure	doc_771173210946_item	2870067	et	3	main
vene	doc_771173210946_item	2870068	et	4	main
seal	doc_771173210946_item	2870079	et	4	main
suurt	doc_771173210946_item	2870080	et	3	main
ajalehest	doc_771173210946_item	2870091	et	4	main
moodustage	doc_771173210946_item	2870094	et	3	main
pannes	doc_771173210946_item	2870098	et	4	main
vormi	doc_771173210946_item	2870101	et	4	main
naised	doc_771173210946_item	2870108	et	3	main
mehed	doc_771173210946_item	2870111	et	3	main
igaüks	doc_771173210946_item	2870113	et	3	main
kaunim	doc_771173210946_item	2870114	et	4	main
naerad	doc_771173210946_item	2870115	et	3	main
stress	doc_771173210946_item	2870127	et	3	main
panema	doc_771173210946_item	2870128	et	3	main
võima	doc_771173210946_item	2870133	et	3	main
tooma	doc_771173210946_item	2870134	et	3	main
soovimatu	doc_771173210946_item	2870135	et	4	main
tagajärg	doc_771173210946_item	2870136	et	3	main
4	doc_771173210946_item	2870137	et	2	main
pinge	doc_771173210946_item	2870143	et	4	main
maandama	doc_771173210946_item	2870145	et	3	main
saama	doc_771173210946_item	2870155	et	4	main
nii	doc_771173210946_item	2870156	et	3	main
nii	doc_771173210946_item	2870170	et	3	main
huvitav	doc_771173210946_item	2870187	et	4	main
aeg	doc_771173210946_item	2870190	et	3	main
ka	doc_771173210946_item	2870194	et	3	main
varahommikul	doc_771173210946_item	2870196	et	3	main
pahandab	doc_771173210946_item	2870203	et	3	main
telesaade	doc_771173210946_item	2870205	et	4	main
sõnad	doc_771173210946_item	2870212	et	4	main
õigesse	doc_771173210946_item	2870213	et	3	main
oma	doc_771173210946_item	2870220	et	4	main
usaldavad	doc_771173210946_item	2870228	et	4	main
igaüks	doc_771173210946_item	2870229	et	3	main
2	doc_771173210946_item	2870231	et	2	main
kohandasin	doc_771173210946_item	2870232	et	3	main
nõuded	doc_771173210946_item	2870234	et	3	main
huvi	doc_771173210946_item	2870246	et	4	main
naisest	doc_771173210946_item	2870254	et	3	main
autost	doc_771173210946_item	2870256	et	3	main
5	doc_771173210946_item	2870264	et	2	main
muudatus	doc_771173210946_item	2870279	et	4	main
7	doc_771173210946_item	2870280	et	2	main
see	doc_771173210946_item	2870281	et	3	main
8	doc_771173210946_item	2870288	et	2	main
närimiskumm	doc_771173210946_item	2870289	et	3	main
püksid	doc_771173210946_item	2870291	et	3	main
ajal	doc_771173210946_item	2870295	et	4	main
10	doc_771173210946_item	2870300	et	2	main
õpetajad	doc_771173210946_item	2870328	et	4	main
kuid-ehk	doc_771173210946_item	2870329	et	3	main
3	doc_771173210946_item	2870330	et	2	main
lapsel	doc_771173210946_item	2870331	et	4	main
paluti	doc_771173210946_item	2870332	et	3	main
vanemad	doc_771173210946_item	2870335	et	4	main
4	doc_771173210946_item	2870338	et	2	main
7	doc_771173210946_item	2870363	et	2	main
selles	doc_771173210946_item	2870364	et	4	main
baaris	doc_771173210946_item	2870365	et	3	main
8	doc_771173210946_item	2870372	et	2	main
küll	doc_771173210946_item	2870375	et	4	main
jääd	doc_771173210946_item	2870387	et	4	main
avasin	doc_771173210946_item	2870390	et	3	main
kuulsin	doc_771173210946_item	2870393	et	3	main
sulgudes	doc_771173210947_item	2870398	et	4	main
nägema	doc_771173210947_item	2870409	et	3	main
ajalehes	doc_771173210947_item	2870412	et	3	main
kuulutust	doc_771173210947_item	2870414	et	4	main
ülem-suetuki	doc_771173210947_item	2870417	et	4	main
külas	doc_771173210947_item	2870419	et	3	main
otsitakse	doc_771173210947_item	2870420	et	3	main
piret	doc_771173210947_item	2870424	et	4	main
võitis	doc_771173210947_item	2870425	et	3	main
konkurss	doc_771173210947_item	2870426	et	3	main
konkursi	doc_771173210947_item	2870427	et	3	main
ja	doc_771173210947_item	2870428	et	3	main
ja	doc_771173210946_item	2870102	et	3	main
kasutades	doc_771173210946_item	2870103	et	3	main
2	doc_771173210946_item	2870105	et	2	main
naiselikum	doc_771173210946_item	2870118	et	4	main
ja	doc_771173210946_item	2870119	et	3	main
sportima	doc_771173210946_item	2870146	et	4	main
aega	doc_771173210946_item	2870207	et	4	main
iv	doc_771173210946_item	2870208	et	4	main
vormi	doc_771173210946_item	2870214	et	4	main
1	doc_771173210946_item	2870215	et	2	main
pean	doc_771173210946_item	2870217	et	4	main
sest	doc_771173210946_item	2870222	et	4	main
nad	doc_771173210946_item	2870223	et	3	main
aitavad	doc_771173210946_item	2870224	et	4	main
kõik	doc_771173210946_item	2870225	et	4	main
ma	doc_771173210946_item	2870236	et	3	main
et	doc_771173210946_item	2870238	et	3	main
ainult	doc_771173210946_item	2870247	et	4	main
ilusad	doc_771173210946_item	2870248	et	3	main
naised	doc_771173210946_item	2870249	et	3	main
difteriat	doc_771173210946_item	2870263	et	4	main
töökoht	doc_771173210946_item	2870269	et	3	main
piirdusime	doc_771173210946_item	2870272	et	3	main
küsimus	doc_771173210946_item	2870282	et	4	main
kuulub	doc_771173210946_item	2870283	et	3	main
teine	doc_771173210946_item	2870284	et	3	main
valdkond	doc_771173210946_item	2870285	et	3	main
9	doc_771173210946_item	2870293	et	2	main
külmetamine	doc_771173210946_item	2870298	et	4	main
rõõmu	doc_771173210946_item	2870303	et	4	main
suvine	doc_771173210946_item	2870304	et	4	main
päike	doc_771173210946_item	2870305	et	3	main
suvest	doc_771173210946_item	2870306	et	3	main
päikest	doc_771173210946_item	2870307	et	4	main
v	doc_771173210946_item	2870308	et	4	main
täitke	doc_771173210946_item	2870309	et	3	main
lüngad	doc_771173210946_item	2870310	et	3	main
sobivate	doc_771173210946_item	2870311	et	4	main
sidenditega	doc_771173210946_item	2870312	et	3	main
1	doc_771173210946_item	2870313	et	2	main
tellisime	doc_771173210946_item	2870314	et	4	main
kolmekäigulise	doc_771173210946_item	2870315	et	4	main
lõuna	doc_771173210946_item	2870316	et	4	main
aga	doc_771173210946_item	2870317	et	3	main
see	doc_771173210946_item	2870318	et	3	main
maksis	doc_771173210946_item	2870319	et	4	main
palju	doc_771173210946_item	2870320	et	4	main
olid	doc_771173210946_item	2870323	et	4	main
oodata	doc_771173210946_item	2870333	et	4	main
tagasi	doc_771173210946_item	2870336	et	3	main
kostis	doc_771173210946_item	2870340	et	4	main
sest	doc_771173210946_item	2870342	et	4	main
ei	doc_771173210946_item	2870350	et	4	main
lähete	doc_771173210946_item	2870361	et	4	main
jalutama	doc_771173210946_item	2870362	et	3	main
ega	doc_771173210946_item	2870369	et	3	main
nad	doc_771173210946_item	2870373	et	3	main
olnud	doc_771173210946_item	2870380	et	4	main
9	doc_771173210946_item	2870381	et	2	main
kas	doc_771173210946_item	2870382	et	3	main
sa	doc_771173210946_item	2870383	et	3	main
sõidad	doc_771173210946_item	2870384	et	3	main
maale	doc_771173210946_item	2870385	et	4	main
sest	doc_771173210946_item	2870392	et	4	main
eksamitöö	doc_771173210947_item	2870395	et	4	main
i	doc_771173210947_item	2870396	et	4	main
olevad	doc_771173210947_item	2870399	et	4	main
õigesse	doc_771173210947_item	2870401	et	3	main
nägi	doc_771173210947_item	2870410	et	3	main
eesti	doc_771173210947_item	2870421	et	4	main
sulgudes	doc_771173210946_item	2870210	et	4	main
vanemad	doc_771173210946_item	2870221	et	4	main
kõiki	doc_771173210946_item	2870226	et	4	main
ja	doc_771173210946_item	2870227	et	3	main
3	doc_771173210946_item	2870235	et	2	main
arvasin	doc_771173210946_item	2870237	et	3	main
huvitud	doc_771173210946_item	2870240	et	4	main
sport	doc_771173210946_item	2870241	et	3	main
sporti	doc_771173210946_item	2870242	et	4	main
aga	doc_771173210946_item	2870243	et	3	main
sa	doc_771173210946_item	2870244	et	3	main
tunned	doc_771173210946_item	2870245	et	3	main
autod	doc_771173210946_item	2870252	et	3	main
kiirest	doc_771173210946_item	2870255	et	4	main
4	doc_771173210946_item	2870257	et	2	main
on	doc_771173210946_item	2870259	et	4	main
oht	doc_771173210946_item	2870260	et	3	main
haigestuda	doc_771173210946_item	2870261	et	3	main
difteeria	doc_771173210946_item	2870262	et	4	main
uus	doc_771173210946_item	2870266	et	3	main
töökoht	doc_771173210946_item	2870267	et	3	main
6	doc_771173210946_item	2870271	et	2	main
püksist	doc_771173210946_item	2870292	et	3	main
peab	doc_771173210946_item	2870296	et	4	main
külmetama	doc_771173210946_item	2870299	et	3	main
tunnen	doc_771173210946_item	2870302	et	3	main
palju	doc_771173210946_item	2870324	et	4	main
õpilased	doc_771173210946_item	2870325	et	3	main
ja	doc_771173210946_item	2870326	et	3	main
vähe	doc_771173210946_item	2870327	et	3	main
sest	doc_771173210946_item	2870334	et	4	main
tulevad	doc_771173210946_item	2870337	et	4	main
kõrvallauast	doc_771173210946_item	2870339	et	4	main
keegi	doc_771173210946_item	2870344	et	4	main
ta	doc_771173210946_item	2870349	et	4	main
sest	doc_771173210946_item	2870353	et	4	main
6	doc_771173210946_item	2870357	et	2	main
lõpetage	doc_771173210946_item	2870358	et	3	main
töö	doc_771173210946_item	2870359	et	4	main
siis	doc_771173210946_item	2870360	et	3	main
ei	doc_771173210946_item	2870366	et	4	main
tohi	doc_771173210946_item	2870367	et	4	main
suitsetada	doc_771173210946_item	2870368	et	3	main
alkoholi	doc_771173210946_item	2870370	et	4	main
ei	doc_771173210946_item	2870379	et	4	main
linna	doc_771173210946_item	2870388	et	4	main
koputust	doc_771173210946_item	2870394	et	4	main
on	doc_771173210947_item	2870405	et	4	main
ettevõtlik	doc_771173210947_item	2870406	et	3	main
naine	doc_771173210947_item	2870407	et	3	main
suvel	doc_771173210947_item	2870408	et	3	main
keele	doc_771173210947_item	2870422	et	4	main
õpetajat	doc_771173210947_item	2870423	et	4	main
neid	doc_771173210947_item	2870438	et	4	main
tundis	doc_771173210947_item	2870444	et	3	main
ta	doc_771173210947_item	2870445	et	4	main
jõudes	doc_771173210947_item	2870448	et	3	main
oodatud	doc_771173210947_item	2870451	et	4	main
üllatunud	doc_771173210947_item	2870455	et	4	main
korraliku	doc_771173210947_item	2870462	et	3	main
maaliti	doc_771173210947_item	2870465	et	3	main
kohta	doc_771173210947_item	2870489	et	4	main
jõudis	doc_771173210947_item	2870490	et	3	main
polnud	doc_771173210947_item	2870491	et	3	main
küla	doc_771173210947_item	2870497	et	4	main
siin	doc_771173210947_item	2870503	et	4	main
ja	doc_771173210947_item	2870512	et	3	main
täie	doc_771173210947_item	2870515	et	3	main
kool	doc_771173210947_item	2870533	et	4	main
on	doc_771173210947_item	2870534	et	4	main
siiski	doc_771173210947_item	2870535	et	4	main
aineid	doc_771173210947_item	2870541	et	3	main
veidi	doc_771173210947_item	2870547	et	3	main
inimene	doc_771173210947_item	2870550	et	3	main
emakeelt	doc_771173210947_item	2870552	et	4	main
poolpõlenud	doc_771173210947_item	2870561	et	4	main
raamatud	doc_771173210947_item	2870562	et	4	main
raamatuid	doc_771173210947_item	2870563	et	3	main
varsti	doc_771173210947_item	2870564	et	3	main
saatma	doc_771173210947_item	2870565	et	3	main
ei	doc_771173210947_item	2870575	et	4	main
juba	doc_771173210947_item	2870578	et	3	main
vaid	doc_771173210946_item	2870275	et	3	main
väikesed	doc_771173210946_item	2870276	et	4	main
muudatused	doc_771173210946_item	2870277	et	3	main
väike	doc_771173210946_item	2870278	et	4	main
teises	doc_771173210946_item	2870286	et	4	main
valdkonnas	doc_771173210946_item	2870287	et	4	main
kleepus	doc_771173210946_item	2870290	et	3	main
külmal	doc_771173210946_item	2870294	et	3	main
hoiduma	doc_771173210946_item	2870297	et	3	main
ma	doc_771173210946_item	2870301	et	3	main
2	doc_771173210946_item	2870321	et	2	main
kohal	doc_771173210946_item	2870322	et	4	main
naeru	doc_771173210946_item	2870341	et	4	main
oleks	doc_771173210946_item	2870343	et	3	main
just	doc_771173210946_item	2870345	et	3	main
anekdooti	doc_771173210946_item	2870346	et	4	main
rääkinud	doc_771173210946_item	2870347	et	4	main
5	doc_771173210946_item	2870348	et	2	main
tule	doc_771173210946_item	2870351	et	4	main
trenni	doc_771173210946_item	2870352	et	4	main
läheb	doc_771173210946_item	2870354	et	3	main
hoopis	doc_771173210946_item	2870355	et	3	main
teatrisse	doc_771173210946_item	2870356	et	3	main
tarbida	doc_771173210946_item	2870371	et	3	main
töötasid	doc_771173210946_item	2870374	et	4	main
sest	doc_771173210946_item	2870377	et	4	main
10	doc_771173210946_item	2870389	et	2	main
ukse	doc_771173210946_item	2870391	et	3	main
sõnad	doc_771173210947_item	2870400	et	4	main
vormi	doc_771173210947_item	2870402	et	4	main
piret	doc_771173210947_item	2870403	et	4	main
et	doc_771173210947_item	2870415	et	3	main
on	doc_771173210947_item	2870429	et	4	main
juba	doc_771173210947_item	2870431	et	3	main
üle	doc_771173210947_item	2870432	et	3	main
nädal	doc_771173210947_item	2870433	et	3	main
nädalat	doc_771173210947_item	2870434	et	3	main
väikestele	doc_771173210947_item	2870435	et	4	main
jõudma	doc_771173210947_item	2870447	et	3	main
üllatuma	doc_771173210947_item	2870454	et	3	main
mulle	doc_771173210947_item	2870457	et	4	main
korralik	doc_771173210947_item	2870461	et	3	main
mulle	doc_771173210947_item	2870464	et	4	main
siber	doc_771173210947_item	2870466	et	4	main
siberi	doc_771173210947_item	2870467	et	4	main
selline	doc_771173210947_item	2870468	et	4	main
pilt	doc_771173210947_item	2870469	et	3	main
et	doc_771173210947_item	2870470	et	3	main
rohi	doc_771173210947_item	2870478	et	4	main
kui	doc_771173210947_item	2870479	et	3	main
noor	doc_771173210947_item	2870480	et	3	main
piret	doc_771173210947_item	2870484	et	4	main
õppeaasta	doc_771173210947_item	2870486	et	4	main
algust	doc_771173210947_item	2870487	et	4	main
koht	doc_771173210947_item	2870488	et	3	main
kogu	doc_771173210947_item	2870496	et	4	main
kartuleid	doc_771173210947_item	2870500	et	3	main
on	doc_771173210947_item	2870509	et	4	main
kartul	doc_771173210947_item	2870510	et	3	main
õppimine	doc_771173210947_item	2870513	et	4	main
hoog	doc_771173210947_item	2870516	et	3	main
teistmoodi	doc_771173210947_item	2870521	et	3	main
mahlakas	doc_771173210947_item	2870524	et	4	main
mitte	doc_771173210947_item	2870525	et	3	main
vene	doc_771173210947_item	2870526	et	4	main
aktsent	doc_771173210947_item	2870527	et	3	main
aktsendiga	doc_771173210947_item	2870528	et	3	main
vaid	doc_771173210947_item	2870529	et	3	main
nagu	doc_771173210947_item	2870530	et	3	main
mõni	doc_771173210947_item	2870531	et	3	main
ülejäänud	doc_771173210947_item	2870539	et	4	main
vene	doc_771173210947_item	2870543	et	4	main
kõike	doc_771173210947_item	2870555	et	4	main
kartma	doc_771173210947_item	2870574	et	3	main
karda	doc_771173210947_item	2870576	et	4	main
on	doc_771173210947_item	2870583	et	4	main
veel	doc_771173210947_item	2870585	et	4	main
soojad	doc_771173210947_item	2870587	et	3	main
kuid	doc_771173210947_item	2870588	et	4	main
kütmisest	doc_771173210947_item	2870599	et	4	main
vildid	doc_771173210947_item	2870605	et	4	main
etteantud	doc_771173210947_item	2870623	et	4	main
pannes	doc_771173210947_item	2870626	et	4	main
naised	doc_771173210947_item	2870636	et	3	main
mehelikum	doc_771173210947_item	2870640	et	4	main
kaunim	doc_771173210947_item	2870644	et	4	main
soovimatu	doc_771173210947_item	2870663	et	4	main
tagajargi	doc_771173210947_item	2870676	et	4	main
4	doc_771173210947_item	2870677	et	2	main
ülekoormus	doc_771173210947_item	2870681	et	3	main
saama	doc_771173210947_item	2870704	et	4	main
maagiline	doc_771173210947_item	2870706	et	4	main
abil	doc_771173210947_item	2870710	et	4	main
lausa	doc_771173210947_item	2870711	et	4	main
elama	doc_771173210947_item	2870712	et	3	main
ja	doc_771173210947_item	2870713	et	3	main
hingama	doc_771173210947_item	2870714	et	3	main
telefon	doc_771173210947_item	2870715	et	3	main
maagiliseks	doc_771173210947_item	2870720	et	4	main
aparadiks	doc_771173210947_item	2870721	et	4	main
pingsalt	doc_771173210946_item	2870376	et	4	main
tulemust	doc_771173210946_item	2870378	et	4	main
või	doc_771173210946_item	2870386	et	4	main
pange	doc_771173210947_item	2870397	et	4	main
toomet	doc_771173210947_item	2870404	et	4	main
ta	doc_771173210947_item	2870411	et	4	main
kuulutus	doc_771173210947_item	2870413	et	4	main
siberisse	doc_771173210947_item	2870416	et	4	main
küla	doc_771173210947_item	2870418	et	4	main
nüüd	doc_771173210947_item	2870430	et	4	main
emakeelt	doc_771173210947_item	2870439	et	4	main
õpetama	doc_771173210947_item	2870440	et	3	main
õpetamas	doc_771173210947_item	2870441	et	3	main
pireti	doc_771173210947_item	2870442	et	4	main
kinnitusel	doc_771173210947_item	2870443	et	4	main
et	doc_771173210947_item	2870449	et	3	main
üsna	doc_771173210947_item	2870453	et	3	main
tulema	doc_771173210947_item	2870458	et	4	main
audiga	doc_771173210947_item	2870463	et	3	main
ei	doc_771173210947_item	2870472	et	4	main
lendama	doc_771173210947_item	2870473	et	3	main
täis	doc_771173210947_item	2870483	et	4	main
pärast	doc_771173210947_item	2870485	et	4	main
võtma	doc_771173210947_item	2870498	et	3	main
kartulivõtt	doc_771173210947_item	2870501	et	3	main
salv	doc_771173210947_item	2870511	et	3	main
räägivad	doc_771173210947_item	2870519	et	3	main
mõnus	doc_771173210947_item	2870522	et	4	main
murret	doc_771173210947_item	2870532	et	4	main
venemaa	doc_771173210947_item	2870536	et	4	main
kool	doc_771173210947_item	2870537	et	4	main
ja	doc_771173210947_item	2870538	et	3	main
õpetatakse	doc_771173210947_item	2870542	et	3	main
elab	doc_771173210947_item	2870546	et	3	main
kolmsada	doc_771173210947_item	2870549	et	4	main
rääkida	doc_771173210947_item	2870556	et	3	main
pireti	doc_771173210947_item	2870557	et	4	main
sõnul	doc_771173210947_item	2870558	et	3	main
õpivad	doc_771173210947_item	2870559	et	3	main
mulle	doc_771173210947_item	2870577	et	4	main
tooma	doc_771173210947_item	2870579	et	3	main
talvepuud	doc_771173210947_item	2870581	et	4	main
päevad	doc_771173210947_item	2870584	et	3	main
muud	doc_771173210947_item	2870609	et	4	main
vapralt	doc_771173210947_item	2870617	et	4	main
laused	doc_771173210947_item	2870625	et	3	main
naeratus	doc_771173210947_item	2870634	et	4	main
tegema	doc_771173210947_item	2870635	et	3	main
kaunim	doc_771173210947_item	2870642	et	4	main
naeratuse	doc_771173210947_item	2870645	et	4	main
tekevad	doc_771173210947_item	2870646	et	4	main
naised	doc_771173210947_item	2870647	et	3	main
meie	doc_771173210947_item	2870669	et	4	main
tegutsema	doc_771173210947_item	2870670	et	3	main
aga	doc_771173210947_item	2870671	et	3	main
lisakoormus	doc_771173210947_item	2870672	et	3	main
võib	doc_771173210947_item	2870673	et	3	main
tuua	doc_771173210947_item	2870674	et	3	main
soovimata	doc_771173210947_item	2870675	et	4	main
tohtima	doc_771173210947_item	2870679	et	3	main
pinge	doc_771173210947_item	2870683	et	4	main
ja	doc_771173210947_item	2870698	et	3	main
puhkamine	doc_771173210947_item	2870699	et	4	main
olema	doc_771173210947_item	2870702	et	4	main
tänapäev	doc_771173210947_item	2870703	et	3	main
nii	doc_771173210947_item	2870705	et	3	main
et	doc_771173210947_item	2870708	et	3	main
nii	doc_771173210947_item	2870719	et	3	main
hingab	doc_771173210947_item	2870728	et	3	main
telefon	doc_771173210947_item	2870730	et	3	main
maagiliseks	doc_771173210947_item	2870733	et	4	main
valmistamine	doc_771173210947_item	2870748	et	4	main
vaatamine	doc_771173210947_item	2870754	et	4	main
aeg	doc_771173210947_item	2870755	et	3	main
uni	doc_771173210947_item	2870762	et	3	main
telesaade	doc_771173210947_item	2870770	et	4	main
vaatamise	doc_771173210947_item	2870771	et	4	main
aeg	doc_771173210947_item	2870772	et	3	main
sulgudes	doc_771173210947_item	2870775	et	4	main
ma	doc_771173210947_item	2870781	et	3	main
lugu	doc_771173210947_item	2870784	et	4	main
vanemad	doc_771173210947_item	2870786	et	4	main
sest	doc_771173210947_item	2870787	et	4	main
nad	doc_771173210947_item	2870788	et	3	main
4	doc_771173210947_item	2870823	et	2	main
väiksedes	doc_771173210947_item	2870844	et	4	main
valdkonda	doc_771173210947_item	2870853	et	4	main
8	doc_771173210947_item	2870854	et	2	main
närimiskumm	doc_771173210947_item	2870855	et	3	main
kleepus	doc_771173210947_item	2870856	et	3	main
eestlastele	doc_771173210947_item	2870436	et	4	main
need	doc_771173210947_item	2870437	et	3	main
siberisse	doc_771173210947_item	2870446	et	4	main
on	doc_771173210947_item	2870450	et	4	main
olin	doc_771173210947_item	2870452	et	3	main
tuli	doc_771173210947_item	2870459	et	4	main
vastu	doc_771173210947_item	2870460	et	3	main
lenda	doc_771173210947_item	2870474	et	4	main
lind	doc_771173210947_item	2870475	et	3	main
ega	doc_771173210947_item	2870476	et	3	main
kasva	doc_771173210947_item	2870477	et	4	main
tahtmine	doc_771173210947_item	2870482	et	4	main
on	doc_771173210947_item	2870502	et	4	main
sügisel	doc_771173210947_item	2870504	et	3	main
kõige	doc_771173210947_item	2870505	et	4	main
tähtis	doc_771173210947_item	2870506	et	4	main
ettevõtmine	doc_771173210947_item	2870507	et	3	main
käib	doc_771173210947_item	2870514	et	3	main
siinsed	doc_771173210947_item	2870517	et	3	main
kui	doc_771173210947_item	2870456	et	3	main
seal	doc_771173210947_item	2870471	et	4	main
ja	doc_771173210947_item	2870481	et	3	main
kool	doc_771173210947_item	2870492	et	4	main
veel	doc_771173210947_item	2870493	et	4	main
algama	doc_771173210947_item	2870494	et	3	main
alatud	doc_771173210947_item	2870495	et	4	main
võti	doc_771173210947_item	2870499	et	4	main
tänaseks	doc_771173210947_item	2870508	et	4	main
eestlased	doc_771173210947_item	2870518	et	3	main
kuidagi	doc_771173210947_item	2870520	et	3	main
ja	doc_771173210947_item	2870523	et	3	main
aine	doc_771173210947_item	2870540	et	4	main
keeles	doc_771173210947_item	2870544	et	4	main
külas	doc_771173210947_item	2870545	et	3	main
üle	doc_771173210947_item	2870548	et	3	main
inimest	doc_771173210947_item	2870551	et	3	main
saab	doc_771173210947_item	2870553	et	3	main
kõik	doc_771173210947_item	2870554	et	4	main
lapsed	doc_771173210947_item	2870560	et	3	main
saadatakse	doc_771173210947_item	2870566	et	3	main
eestist	doc_771173210947_item	2870567	et	3	main
uued	doc_771173210947_item	2870568	et	3	main
õpikud	doc_771173210947_item	2870569	et	3	main
siberi	doc_771173210947_item	2870570	et	4	main
talve	doc_771173210947_item	2870571	et	4	main
piret	doc_771173210947_item	2870572	et	4	main
ei	doc_771173210947_item	2870573	et	4	main
tooti	doc_771173210947_item	2870580	et	4	main
soe	doc_771173210947_item	2870586	et	4	main
kütmine	doc_771173210947_item	2870598	et	4	main
ostan	doc_771173210947_item	2870602	et	3	main
naerab	doc_771173210947_item	2870612	et	3	main
valmistud	doc_771173210947_item	2870615	et	3	main
piret	doc_771173210947_item	2870616	et	4	main
ööd	doc_771173210947_item	2870589	et	4	main
juba	doc_771173210947_item	2870590	et	3	main
jahe	doc_771173210947_item	2870591	et	3	main
jahedad	doc_771173210947_item	2870592	et	3	main
harjutan	doc_771173210947_item	2870593	et	3	main
juba	doc_771173210947_item	2870594	et	3	main
suure	doc_771173210947_item	2870595	et	3	main
kui	doc_771173210947_item	2870600	et	3	main
külapoest	doc_771173210947_item	2870604	et	4	main
ega	doc_771173210947_item	2870606	et	3	main
seal	doc_771173210947_item	2870607	et	4	main
suurt	doc_771173210947_item	2870608	et	3	main
lühendatud	doc_771173210947_item	2870618	et	4	main
sõnadest	doc_771173210947_item	2870624	et	3	main
sõnad	doc_771173210947_item	2870627	et	4	main
õigesse	doc_771173210947_item	2870628	et	3	main
vormi	doc_771173210947_item	2870629	et	4	main
ja	doc_771173210947_item	2870630	et	3	main
kasutades	doc_771173210947_item	2870631	et	3	main
kirjavahemärke	doc_771173210947_item	2870632	et	4	main
2	doc_771173210947_item	2870633	et	2	main
igaüks	doc_771173210947_item	2870643	et	3	main
naiselikumad	doc_771173210947_item	2870648	et	4	main
ja	doc_771173210947_item	2870649	et	3	main
mehed	doc_771173210947_item	2870650	et	3	main
mehelikumad	doc_771173210947_item	2870651	et	4	main
tagajärg	doc_771173210947_item	2870664	et	3	main
paras	doc_771173210947_item	2870665	et	3	main
kogus	doc_771173210947_item	2870666	et	4	main
stress	doc_771173210947_item	2870667	et	3	main
paneb	doc_771173210947_item	2870668	et	3	main
ei	doc_771173210947_item	2870678	et	4	main
saama	doc_771173210947_item	2870684	et	4	main
maandama	doc_771173210947_item	2870685	et	3	main
sportima	doc_771173210947_item	2870686	et	4	main
ja	doc_771173210947_item	2870687	et	3	main
puhkama	doc_771173210947_item	2870688	et	3	main
ei	doc_771173210947_item	2870689	et	4	main
tohi	doc_771173210947_item	2870690	et	4	main
lasta	doc_771173210947_item	2870691	et	4	main
ülekoormusi	doc_771173210947_item	2870692	et	4	main
tekkida	doc_771173210947_item	2870693	et	3	main
pinge	doc_771173210947_item	2870694	et	4	main
saab	doc_771173210947_item	2870695	et	3	main
maandada	doc_771173210947_item	2870696	et	3	main
praegu	doc_771173210947_item	2870582	et	3	main
vene	doc_771173210947_item	2870596	et	4	main
ahju	doc_771173210947_item	2870597	et	4	main
vaja	doc_771173210947_item	2870601	et	4	main
külapood	doc_771173210947_item	2870603	et	3	main
ei	doc_771173210947_item	2870610	et	4	main
müüdagi	doc_771173210947_item	2870611	et	3	main
talveks	doc_771173210947_item	2870613	et	4	main
valmistuma	doc_771173210947_item	2870614	et	3	main
ajalehest	doc_771173210947_item	2870619	et	4	main
slõhtuleht	doc_771173210947_item	2870620	et	4	main
iii	doc_771173210947_item	2870621	et	4	main
moodustage	doc_771173210947_item	2870622	et	3	main
naiselikum	doc_771173210947_item	2870637	et	4	main
ja	doc_771173210947_item	2870638	et	3	main
mehed	doc_771173210947_item	2870639	et	3	main
igaüks	doc_771173210947_item	2870641	et	3	main
3	doc_771173210947_item	2870652	et	2	main
paras	doc_771173210947_item	2870653	et	3	main
kogus	doc_771173210947_item	2870654	et	4	main
stress	doc_771173210947_item	2870655	et	3	main
panema	doc_771173210947_item	2870656	et	3	main
meie	doc_771173210947_item	2870657	et	4	main
tegutsema	doc_771173210947_item	2870658	et	3	main
aga	doc_771173210947_item	2870659	et	3	main
lisakoormus	doc_771173210947_item	2870660	et	3	main
võima	doc_771173210947_item	2870661	et	3	main
tooma	doc_771173210947_item	2870662	et	3	main
laskma	doc_771173210947_item	2870680	et	3	main
tekkima	doc_771173210947_item	2870682	et	3	main
5	doc_771173210947_item	2870700	et	2	main
on	doc_771173210947_item	2870716	et	4	main
tänapäevaks	doc_771173210947_item	2870717	et	3	main
telefon	doc_771173210947_item	2870701	et	3	main
aparaat	doc_771173210947_item	2870707	et	3	main
see	doc_771173210947_item	2870709	et	3	main
lausa	doc_771173210947_item	2870725	et	4	main
elab	doc_771173210947_item	2870726	et	3	main
et	doc_771173210947_item	2870735	et	3	main
6	doc_771173210947_item	2870738	et	2	main
lõunasöök	doc_771173210947_item	2870747	et	3	main
ja	doc_771173210947_item	2870749	et	3	main
pahandab	doc_771173210947_item	2870751	et	3	main
huvitav	doc_771173210947_item	2870752	et	4	main
lõunasöögi	doc_771173210947_item	2870764	et	3	main
valmistamine	doc_771173210947_item	2870765	et	4	main
huvitava	doc_771173210947_item	2870769	et	4	main
iv	doc_771173210947_item	2870773	et	4	main
sõnad	doc_771173210947_item	2870777	et	4	main
1	doc_771173210947_item	2870780	et	2	main
igaüksele	doc_771173210947_item	2870794	et	3	main
2	doc_771173210947_item	2870795	et	2	main
kohandasin	doc_771173210947_item	2870796	et	3	main
artikli	doc_771173210947_item	2870797	et	3	main
nõuded	doc_771173210947_item	2870798	et	3	main
nõudeid	doc_771173210947_item	2870799	et	3	main
3	doc_771173210947_item	2870800	et	2	main
ma	doc_771173210947_item	2870801	et	3	main
arvasin	doc_771173210947_item	2870802	et	3	main
et	doc_771173210947_item	2870803	et	3	main
sa	doc_771173210947_item	2870804	et	3	main
huvitud	doc_771173210947_item	2870805	et	4	main
sport	doc_771173210947_item	2870806	et	3	main
spordi	doc_771173210947_item	2870807	et	4	main
aga	doc_771173210947_item	2870808	et	3	main
sa	doc_771173210947_item	2870809	et	3	main
tunned	doc_771173210947_item	2870810	et	3	main
huvi	doc_771173210947_item	2870811	et	4	main
ainult	doc_771173210947_item	2870812	et	4	main
ilusad	doc_771173210947_item	2870813	et	3	main
naised	doc_771173210947_item	2870814	et	3	main
ja	doc_771173210947_item	2870815	et	3	main
kiired	doc_771173210947_item	2870816	et	4	main
autod	doc_771173210947_item	2870817	et	3	main
ilusatele	doc_771173210947_item	2870818	et	3	main
naistele	doc_771173210947_item	2870819	et	3	main
ja	doc_771173210947_item	2870820	et	3	main
autodele	doc_771173210947_item	2870822	et	3	main
praegu	doc_771173210947_item	2870824	et	3	main
haigestuda	doc_771173210947_item	2870827	et	3	main
5	doc_771173210947_item	2870830	et	2	main
tüdinesin	doc_771173210947_item	2870831	et	3	main
uus	doc_771173210947_item	2870832	et	3	main
töökoht	doc_771173210947_item	2870833	et	3	main
uut	doc_771173210947_item	2870834	et	3	main
töökohti	doc_771173210947_item	2870835	et	4	main
kiiresti	doc_771173210947_item	2870836	et	3	main
6	doc_771173210947_item	2870837	et	2	main
spordimine	doc_771173210947_item	2870697	et	4	main
saab	doc_771173210947_item	2870718	et	3	main
et	doc_771173210947_item	2870722	et	3	main
see	doc_771173210947_item	2870723	et	3	main
abil	doc_771173210947_item	2870724	et	4	main
tänapäevaks	doc_771173210947_item	2870729	et	3	main
nii	doc_771173210947_item	2870732	et	3	main
see	doc_771173210947_item	2870736	et	3	main
telesaade	doc_771173210947_item	2870753	et	4	main
segas	doc_771173210947_item	2870763	et	3	main
ja	doc_771173210947_item	2870766	et	3	main
söömine	doc_771173210947_item	2870767	et	4	main
pahandab	doc_771173210947_item	2870768	et	3	main
olevad	doc_771173210947_item	2870776	et	4	main
vormi	doc_771173210947_item	2870779	et	4	main
väga	doc_771173210947_item	2870783	et	3	main
oma	doc_771173210947_item	2870785	et	4	main
usaldavad	doc_771173210947_item	2870792	et	4	main
igaüks	doc_771173210947_item	2870793	et	3	main
ja	doc_771173210947_item	2870727	et	3	main
saab	doc_771173210947_item	2870731	et	3	main
aparaadiks	doc_771173210947_item	2870734	et	3	main
abil	doc_771173210947_item	2870737	et	4	main
kuid	doc_771173210947_item	2870739	et	4	main
telefonihelin	doc_771173210947_item	2870740	et	3	main
katkestama	doc_771173210947_item	2870741	et	3	main
ka	doc_771173210947_item	2870742	et	3	main
pühapäev	doc_771173210947_item	2870743	et	3	main
varahommik	doc_771173210947_item	2870744	et	3	main
uni	doc_771173210947_item	2870745	et	3	main
segama	doc_771173210947_item	2870746	et	3	main
söömine	doc_771173210947_item	2870750	et	4	main
kuid	doc_771173210947_item	2870756	et	4	main
telefonihelin	doc_771173210947_item	2870757	et	3	main
katkestab	doc_771173210947_item	2870758	et	3	main
ka	doc_771173210947_item	2870759	et	3	main
pühapäev	doc_771173210947_item	2870760	et	3	main
varahommikul	doc_771173210947_item	2870761	et	3	main
pange	doc_771173210947_item	2870774	et	4	main
õigesse	doc_771173210947_item	2870778	et	3	main
pean	doc_771173210947_item	2870782	et	4	main
aitavad	doc_771173210947_item	2870789	et	4	main
oht	doc_771173210947_item	2870826	et	3	main
selles	doc_771173210947_item	2870839	et	4	main
küsimus	doc_771173210947_item	2870848	et	4	main
kuulub	doc_771173210947_item	2870849	et	3	main
teine	doc_771173210947_item	2870850	et	3	main
valdkond	doc_771173210947_item	2870851	et	3	main
teisele	doc_771173210947_item	2870852	et	4	main
9	doc_771173210947_item	2870859	et	2	main
külmal	doc_771173210947_item	2870860	et	3	main
õpetajad	doc_771173210947_item	2870892	et	4	main
3	doc_771173210947_item	2870893	et	2	main
vanemad	doc_771173210947_item	2870898	et	4	main
tulevad	doc_771173210947_item	2870900	et	4	main
hoopis	doc_771173210947_item	2870918	et	3	main
lõpetage	doc_771173210947_item	2870921	et	3	main
pärast	doc_771173210947_item	2870923	et	4	main
lähete	doc_771173210947_item	2870924	et	4	main
jalutama	doc_771173210947_item	2870925	et	3	main
7	doc_771173210947_item	2870926	et	2	main
alkoholi	doc_771173210947_item	2870933	et	4	main
tarbida	doc_771173210947_item	2870934	et	3	main
8	doc_771173210947_item	2870935	et	2	main
nad	doc_771173210947_item	2870936	et	3	main
tulemust	doc_771173210947_item	2870941	et	4	main
või	doc_771173210947_item	2870949	et	4	main
ja	doc_771173210947_item	2870955	et	3	main
koputust	doc_771173210947_item	2870957	et	4	main
kuulutus	doc_771173210948_item	2870976	et	4	main
küla	doc_771173210948_item	2870981	et	4	main
külasse	doc_771173210948_item	2870982	et	3	main
otsitakse	doc_771173210948_item	2870983	et	3	main
kõik	doc_771173210947_item	2870790	et	4	main
ja	doc_771173210947_item	2870791	et	3	main
kiirtele	doc_771173210947_item	2870821	et	3	main
on	doc_771173210947_item	2870825	et	4	main
difteeria	doc_771173210947_item	2870828	et	4	main
difteeriaga	doc_771173210947_item	2870829	et	3	main
muudatusedes	doc_771173210947_item	2870845	et	4	main
7	doc_771173210947_item	2870846	et	2	main
see	doc_771173210947_item	2870847	et	3	main
tunnen	doc_771173210947_item	2870868	et	3	main
rõõmu	doc_771173210947_item	2870869	et	4	main
suvine	doc_771173210947_item	2870870	et	4	main
päike	doc_771173210947_item	2870871	et	3	main
suvist	doc_771173210947_item	2870872	et	4	main
päikest	doc_771173210947_item	2870873	et	4	main
v	doc_771173210947_item	2870874	et	4	main
täitke	doc_771173210947_item	2870875	et	3	main
lüngad	doc_771173210947_item	2870876	et	3	main
sobivate	doc_771173210947_item	2870877	et	4	main
sidenditega	doc_771173210947_item	2870878	et	3	main
1	doc_771173210947_item	2870879	et	2	main
tellisime	doc_771173210947_item	2870880	et	4	main
kolmekäigulise	doc_771173210947_item	2870881	et	4	main
lõuna	doc_771173210947_item	2870882	et	4	main
aga	doc_771173210947_item	2870883	et	3	main
see	doc_771173210947_item	2870884	et	3	main
maksis	doc_771173210947_item	2870885	et	4	main
palju	doc_771173210947_item	2870886	et	4	main
2	doc_771173210947_item	2870887	et	2	main
kohal	doc_771173210947_item	2870888	et	4	main
piirdusime	doc_771173210947_item	2870838	et	3	main
küsimuses	doc_771173210947_item	2870840	et	4	main
vaid	doc_771173210947_item	2870841	et	3	main
väikesed	doc_771173210947_item	2870842	et	4	main
muudatused	doc_771173210947_item	2870843	et	3	main
pükseid	doc_771173210947_item	2870858	et	4	main
külmetamisest	doc_771173210947_item	2870865	et	4	main
10	doc_771173210947_item	2870866	et	2	main
ma	doc_771173210947_item	2870867	et	3	main
oodata	doc_771173210947_item	2870896	et	4	main
tagasi	doc_771173210947_item	2870899	et	3	main
kõrvallauast	doc_771173210947_item	2870902	et	4	main
ta	doc_771173210947_item	2870912	et	4	main
läheb	doc_771173210947_item	2870917	et	3	main
töö	doc_771173210947_item	2870922	et	4	main
ei	doc_771173210947_item	2870942	et	4	main
jääd	doc_771173210947_item	2870950	et	4	main
kuulsin	doc_771173210947_item	2870956	et	3	main
eksamitöö	doc_771173210948_item	2870958	et	4	main
i	doc_771173210948_item	2870959	et	4	main
olevad	doc_771173210948_item	2870962	et	4	main
sõnad	doc_771173210948_item	2870963	et	4	main
õigesse	doc_771173210948_item	2870964	et	3	main
kuulutust	doc_771173210948_item	2870977	et	4	main
et	doc_771173210948_item	2870978	et	3	main
tuli	doc_771173210948_item	2871021	et	4	main
vastu	doc_771173210948_item	2871022	et	3	main
selline	doc_771173210948_item	2871030	et	4	main
pilt	doc_771173210948_item	2871031	et	3	main
et	doc_771173210948_item	2871032	et	3	main
seal	doc_771173210948_item	2871033	et	4	main
lind	doc_771173210948_item	2871037	et	3	main
tahtmisega	doc_771173210948_item	2871045	et	4	main
õppeaasta	doc_771173210948_item	2871049	et	4	main
kogu	doc_771173210948_item	2871059	et	4	main
tänaseks	doc_771173210948_item	2871072	et	4	main
täie	doc_771173210948_item	2871079	et	3	main
hoog	doc_771173210948_item	2871080	et	3	main
mõnusalt	doc_771173210948_item	2871090	et	4	main
vene	doc_771173210948_item	2871094	et	4	main
kolmesaja	doc_771173210948_item	2871119	et	4	main
püksid	doc_771173210947_item	2870857	et	3	main
ajal	doc_771173210947_item	2870861	et	4	main
peab	doc_771173210947_item	2870862	et	4	main
hoiduma	doc_771173210947_item	2870863	et	3	main
külmetamine	doc_771173210947_item	2870864	et	4	main
olid	doc_771173210947_item	2870889	et	4	main
kui	doc_771173210947_item	2870890	et	3	main
õpilased	doc_771173210947_item	2870891	et	3	main
paluti	doc_771173210947_item	2870895	et	3	main
4	doc_771173210947_item	2870901	et	2	main
kostis	doc_771173210947_item	2870903	et	4	main
naeru	doc_771173210947_item	2870904	et	4	main
just	doc_771173210947_item	2870905	et	3	main
oleks	doc_771173210947_item	2870906	et	3	main
keegi	doc_771173210947_item	2870907	et	4	main
just	doc_771173210947_item	2870908	et	3	main
ei	doc_771173210947_item	2870913	et	4	main
tule	doc_771173210947_item	2870914	et	4	main
teatrisse	doc_771173210947_item	2870919	et	3	main
selles	doc_771173210947_item	2870927	et	4	main
töötasid	doc_771173210947_item	2870937	et	4	main
küll	doc_771173210947_item	2870938	et	4	main
olnud	doc_771173210947_item	2870943	et	4	main
9	doc_771173210947_item	2870944	et	2	main
kas	doc_771173210947_item	2870945	et	3	main
sa	doc_771173210947_item	2870946	et	3	main
linna	doc_771173210947_item	2870951	et	4	main
10	doc_771173210947_item	2870952	et	2	main
avasin	doc_771173210947_item	2870953	et	3	main
pange	doc_771173210948_item	2870960	et	4	main
sulgudes	doc_771173210948_item	2870961	et	4	main
piret	doc_771173210948_item	2870966	et	4	main
toomet	doc_771173210948_item	2870967	et	4	main
on	doc_771173210948_item	2870968	et	4	main
ettevõtlik	doc_771173210948_item	2870969	et	3	main
naine	doc_771173210948_item	2870970	et	3	main
suvel	doc_771173210948_item	2870971	et	3	main
nägema	doc_771173210948_item	2870972	et	3	main
nägi	doc_771173210948_item	2870973	et	3	main
siberisse	doc_771173210948_item	2870979	et	4	main
tulema	doc_771173210948_item	2871020	et	4	main
siberi	doc_771173210948_item	2871029	et	4	main
kui	doc_771173210948_item	2871041	et	3	main
noor	doc_771173210948_item	2871042	et	3	main
ja	doc_771173210948_item	2871043	et	3	main
tahtmine	doc_771173210948_item	2871044	et	4	main
kohale	doc_771173210948_item	2871052	et	4	main
jõudis	doc_771173210948_item	2871053	et	3	main
küla	doc_771173210948_item	2871060	et	4	main
tähtis	doc_771173210948_item	2871069	et	4	main
on	doc_771173210948_item	2871073	et	4	main
mahlakalt	doc_771173210948_item	2871092	et	4	main
inimesi	doc_771173210948_item	2871121	et	4	main
õpivad	doc_771173210948_item	2871129	et	3	main
poolpõlenud	doc_771173210948_item	2871131	et	4	main
raamatuid	doc_771173210948_item	2871133	et	3	main
varsti	doc_771173210948_item	2871134	et	3	main
piret	doc_771173210948_item	2871142	et	4	main
soojad	doc_771173210948_item	2871156	et	3	main
ahju	doc_771173210948_item	2871166	et	4	main
vaja	doc_771173210948_item	2871170	et	4	main
ostan	doc_771173210948_item	2871171	et	3	main
külapood	doc_771173210948_item	2871172	et	3	main
külapojast	doc_771173210948_item	2871173	et	4	main
muud	doc_771173210948_item	2871178	et	4	main
valmistuma	doc_771173210948_item	2871183	et	3	main
vapralt	doc_771173210948_item	2871186	et	4	main
laused	doc_771173210948_item	2871194	et	3	main
kirjavahemärke	doc_771173210948_item	2871201	et	4	main
tegema	doc_771173210948_item	2871204	et	3	main
naiselikum	doc_771173210948_item	2871206	et	4	main
ja	doc_771173210948_item	2871216	et	3	main
igaühe	doc_771173210948_item	2871219	et	4	main
lapsel	doc_771173210947_item	2870894	et	4	main
kuni	doc_771173210947_item	2870897	et	3	main
anekdooti	doc_771173210947_item	2870909	et	4	main
rääkinud	doc_771173210947_item	2870910	et	4	main
5	doc_771173210947_item	2870911	et	2	main
sest	doc_771173210947_item	2870916	et	4	main
trenni	doc_771173210947_item	2870915	et	4	main
6	doc_771173210947_item	2870920	et	2	main
baaris	doc_771173210947_item	2870928	et	3	main
ei	doc_771173210947_item	2870929	et	4	main
tohi	doc_771173210947_item	2870930	et	4	main
suitsetada	doc_771173210947_item	2870931	et	3	main
vaid	doc_771173210947_item	2870932	et	3	main
pingsalt	doc_771173210947_item	2870939	et	4	main
et	doc_771173210947_item	2870940	et	3	main
sõidad	doc_771173210947_item	2870947	et	3	main
maale	doc_771173210947_item	2870948	et	4	main
ukse	doc_771173210947_item	2870954	et	3	main
vormi	doc_771173210948_item	2870965	et	4	main
ta	doc_771173210948_item	2870974	et	4	main
ajalehes	doc_771173210948_item	2870975	et	3	main
ülem-suetuki	doc_771173210948_item	2870980	et	4	main
eesti	doc_771173210948_item	2870984	et	4	main
keele	doc_771173210948_item	2870985	et	4	main
õpetajat	doc_771173210948_item	2870986	et	4	main
piret	doc_771173210948_item	2870987	et	4	main
võitis	doc_771173210948_item	2870988	et	3	main
konkurss	doc_771173210948_item	2870989	et	3	main
konkurssi	doc_771173210948_item	2870990	et	4	main
ja	doc_771173210948_item	2870991	et	3	main
on	doc_771173210948_item	2870992	et	4	main
nüüd	doc_771173210948_item	2870993	et	4	main
juba	doc_771173210948_item	2870994	et	3	main
üle	doc_771173210948_item	2870995	et	3	main
nädal	doc_771173210948_item	2870996	et	3	main
nädala	doc_771173210948_item	2870997	et	3	main
väikestele	doc_771173210948_item	2870998	et	4	main
eestlastele	doc_771173210948_item	2870999	et	4	main
need	doc_771173210948_item	2871000	et	3	main
emakeelt	doc_771173210948_item	2871002	et	4	main
õpetama	doc_771173210948_item	2871003	et	3	main
õpetamas	doc_771173210948_item	2871004	et	3	main
pireti	doc_771173210948_item	2871005	et	4	main
nende	doc_771173210948_item	2871001	et	4	main
kinnitusel	doc_771173210948_item	2871006	et	4	main
tundis	doc_771173210948_item	2871007	et	3	main
ta	doc_771173210948_item	2871008	et	4	main
siberisse	doc_771173210948_item	2871009	et	4	main
jõudma	doc_771173210948_item	2871010	et	3	main
et	doc_771173210948_item	2871011	et	3	main
on	doc_771173210948_item	2871012	et	4	main
oodatud	doc_771173210948_item	2871013	et	4	main
olin	doc_771173210948_item	2871014	et	3	main
üsna	doc_771173210948_item	2871015	et	3	main
üllatuma	doc_771173210948_item	2871016	et	3	main
üllatunud	doc_771173210948_item	2871017	et	4	main
kui	doc_771173210948_item	2871018	et	3	main
korralik	doc_771173210948_item	2871023	et	3	main
korraliku	doc_771173210948_item	2871024	et	3	main
audiga	doc_771173210948_item	2871025	et	3	main
mulle	doc_771173210948_item	2871026	et	4	main
maaliti	doc_771173210948_item	2871027	et	3	main
lenda	doc_771173210948_item	2871036	et	4	main
ega	doc_771173210948_item	2871038	et	3	main
täis	doc_771173210948_item	2871046	et	4	main
algust	doc_771173210948_item	2871050	et	4	main
koht	doc_771173210948_item	2871051	et	3	main
kool	doc_771173210948_item	2871055	et	4	main
veel	doc_771173210948_item	2871056	et	4	main
alganud	doc_771173210948_item	2871058	et	4	main
siin	doc_771173210948_item	2871066	et	4	main
sügisel	doc_771173210948_item	2871067	et	3	main
kõige	doc_771173210948_item	2871068	et	4	main
kartul	doc_771173210948_item	2871074	et	3	main
õppimine	doc_771173210948_item	2871077	et	4	main
hooguga	doc_771173210948_item	2871081	et	4	main
siinsed	doc_771173210948_item	2871082	et	3	main
eestlased	doc_771173210948_item	2871083	et	3	main
räägivad	doc_771173210948_item	2871084	et	3	main
kuidagi	doc_771173210948_item	2871085	et	3	main
teistmoodi	doc_771173210948_item	2871086	et	3	main
mõnus	doc_771173210948_item	2871087	et	4	main
ja	doc_771173210948_item	2871088	et	3	main
ja	doc_771173210948_item	2871091	et	3	main
aktsent	doc_771173210948_item	2871095	et	3	main
aktsentiga	doc_771173210948_item	2871096	et	4	main
vaid	doc_771173210948_item	2871097	et	3	main
nagu	doc_771173210948_item	2871098	et	3	main
mõni	doc_771173210948_item	2871099	et	3	main
mõne	doc_771173210948_item	2871100	et	3	main
murret	doc_771173210948_item	2871101	et	4	main
kool	doc_771173210948_item	2871102	et	4	main
on	doc_771173210948_item	2871103	et	4	main
siiski	doc_771173210948_item	2871104	et	4	main
venemaa	doc_771173210948_item	2871105	et	4	main
kool	doc_771173210948_item	2871106	et	4	main
ja	doc_771173210948_item	2871107	et	3	main
ülejäänud	doc_771173210948_item	2871108	et	4	main
aine	doc_771173210948_item	2871109	et	4	main
ained	doc_771173210948_item	2871110	et	3	main
õpetatakse	doc_771173210948_item	2871111	et	3	main
vene	doc_771173210948_item	2871112	et	4	main
keeles	doc_771173210948_item	2871113	et	4	main
külas	doc_771173210948_item	2871114	et	3	main
elab	doc_771173210948_item	2871115	et	3	main
veidi	doc_771173210948_item	2871116	et	3	main
üle	doc_771173210948_item	2871117	et	3	main
kolmsada	doc_771173210948_item	2871118	et	4	main
mulle	doc_771173210948_item	2871019	et	4	main
siber	doc_771173210948_item	2871028	et	4	main
ei	doc_771173210948_item	2871034	et	4	main
lendama	doc_771173210948_item	2871035	et	3	main
kasva	doc_771173210948_item	2871039	et	4	main
rohi	doc_771173210948_item	2871040	et	4	main
piret	doc_771173210948_item	2871047	et	4	main
pärast	doc_771173210948_item	2871048	et	4	main
polnud	doc_771173210948_item	2871054	et	3	main
algama	doc_771173210948_item	2871057	et	3	main
võtma	doc_771173210948_item	2871061	et	3	main
võttis	doc_771173210948_item	2871062	et	3	main
kartuleid	doc_771173210948_item	2871063	et	3	main
kartulivõtt	doc_771173210948_item	2871064	et	3	main
on	doc_771173210948_item	2871065	et	4	main
tähtsam	doc_771173210948_item	2871070	et	4	main
ettevõtmine	doc_771173210948_item	2871071	et	3	main
salv	doc_771173210948_item	2871075	et	3	main
ja	doc_771173210948_item	2871076	et	3	main
käib	doc_771173210948_item	2871078	et	3	main
mahlakas	doc_771173210948_item	2871089	et	4	main
mitte	doc_771173210948_item	2871093	et	3	main
inimene	doc_771173210948_item	2871120	et	3	main
sõnul	doc_771173210948_item	2871128	et	3	main
lapsed	doc_771173210948_item	2871130	et	3	main
raamatud	doc_771173210948_item	2871132	et	4	main
saatma	doc_771173210948_item	2871135	et	3	main
saadavad	doc_771173210948_item	2871136	et	4	main
eestist	doc_771173210948_item	2871137	et	3	main
uued	doc_771173210948_item	2871138	et	3	main
õpikud	doc_771173210948_item	2871139	et	3	main
ei	doc_771173210948_item	2871143	et	4	main
kartma	doc_771173210948_item	2871144	et	3	main
mulle	doc_771173210948_item	2871146	et	4	main
juba	doc_771173210948_item	2871147	et	3	main
veel	doc_771173210948_item	2871154	et	4	main
soe	doc_771173210948_item	2871155	et	4	main
kuid	doc_771173210948_item	2871157	et	4	main
kütmine	doc_771173210948_item	2871167	et	4	main
seal	doc_771173210948_item	2871176	et	4	main
suurt	doc_771173210948_item	2871177	et	3	main
ei	doc_771173210948_item	2871179	et	4	main
talveks	doc_771173210948_item	2871182	et	4	main
piret	doc_771173210948_item	2871185	et	4	main
lühendatud	doc_771173210948_item	2871187	et	4	main
ajalehest	doc_771173210948_item	2871188	et	4	main
slõhtuleht	doc_771173210948_item	2871189	et	4	main
sõnad	doc_771173210948_item	2871196	et	4	main
õigesse	doc_771173210948_item	2871197	et	3	main
2	doc_771173210948_item	2871202	et	2	main
mehelikum	doc_771173210948_item	2871209	et	4	main
kaunim	doc_771173210948_item	2871211	et	4	main
3	doc_771173210948_item	2871221	et	2	main
võima	doc_771173210948_item	2871230	et	3	main
stress	doc_771173210948_item	2871236	et	3	main
lisakoormus	doc_771173210948_item	2871241	et	3	main
tuua	doc_771173210948_item	2871243	et	3	main
tagajärg	doc_771173210948_item	2871245	et	3	main
aparaat	doc_771173210948_item	2871276	et	3	main
abil	doc_771173210948_item	2871279	et	4	main
elama	doc_771173210948_item	2871281	et	3	main
hingama	doc_771173210948_item	2871283	et	3	main
hingama	doc_771173210948_item	2871297	et	3	main
katkestama	doc_771173210948_item	2871301	et	3	main
varahommik	doc_771173210948_item	2871304	et	3	main
segama	doc_771173210948_item	2871306	et	3	main
ja	doc_771173210948_item	2871309	et	3	main
telesaade	doc_771173210948_item	2871313	et	4	main
telefonihelin	doc_771173210948_item	2871317	et	3	main
kõik	doc_771173210948_item	2871124	et	4	main
kõike	doc_771173210948_item	2871125	et	4	main
rääkida	doc_771173210948_item	2871126	et	3	main
tooma	doc_771173210948_item	2871148	et	3	main
toodi	doc_771173210948_item	2871149	et	4	main
talvepuud	doc_771173210948_item	2871150	et	4	main
praegu	doc_771173210948_item	2871151	et	3	main
on	doc_771173210948_item	2871152	et	4	main
emakeelt	doc_771173210948_item	2871122	et	4	main
saab	doc_771173210948_item	2871123	et	3	main
pireti	doc_771173210948_item	2871127	et	4	main
siberi	doc_771173210948_item	2871140	et	4	main
talve	doc_771173210948_item	2871141	et	4	main
karda	doc_771173210948_item	2871145	et	4	main
ööd	doc_771173210948_item	2871158	et	4	main
juba	doc_771173210948_item	2871159	et	3	main
jahe	doc_771173210948_item	2871160	et	3	main
jaed	doc_771173210948_item	2871161	et	4	main
harjutan	doc_771173210948_item	2871162	et	3	main
juba	doc_771173210948_item	2871163	et	3	main
vildid	doc_771173210948_item	2871174	et	4	main
ega	doc_771173210948_item	2871175	et	3	main
naerab	doc_771173210948_item	2871181	et	3	main
iii	doc_771173210948_item	2871190	et	4	main
etteantud	doc_771173210948_item	2871192	et	4	main
pannes	doc_771173210948_item	2871195	et	4	main
kasutades	doc_771173210948_item	2871200	et	3	main
naeratus	doc_771173210948_item	2871203	et	4	main
naised	doc_771173210948_item	2871205	et	3	main
ja	doc_771173210948_item	2871207	et	3	main
mehed	doc_771173210948_item	2871208	et	3	main
igaüks	doc_771173210948_item	2871210	et	3	main
mehed	doc_771173210948_item	2871217	et	3	main
kaunim	doc_771173210948_item	2871220	et	4	main
paras	doc_771173210948_item	2871222	et	3	main
kogus	doc_771173210948_item	2871223	et	4	main
stress	doc_771173210948_item	2871224	et	3	main
panema	doc_771173210948_item	2871225	et	3	main
tagajärg	doc_771173210948_item	2871233	et	3	main
kogus	doc_771173210948_item	2871235	et	4	main
tegutsema	doc_771173210948_item	2871239	et	3	main
võib	doc_771173210948_item	2871242	et	3	main
saama	doc_771173210948_item	2871253	et	4	main
maandama	doc_771173210948_item	2871254	et	3	main
sportima	doc_771173210948_item	2871255	et	4	main
ja	doc_771173210948_item	2871256	et	3	main
puhkama	doc_771173210948_item	2871257	et	3	main
telefon	doc_771173210948_item	2871270	et	3	main
et	doc_771173210948_item	2871277	et	3	main
maagiline	doc_771173210948_item	2871289	et	4	main
aparaat	doc_771173210948_item	2871290	et	3	main
et	doc_771173210948_item	2871291	et	3	main
see	doc_771173210948_item	2871292	et	3	main
lausa	doc_771173210948_item	2871293	et	4	main
ja	doc_771173210948_item	2871296	et	3	main
telefonihelin	doc_771173210948_item	2871300	et	3	main
pühapäev	doc_771173210948_item	2871303	et	3	main
uni	doc_771173210948_item	2871305	et	3	main
vaatamine	doc_771173210948_item	2871314	et	4	main
valmistamine	doc_771173210948_item	2871325	et	4	main
ja	doc_771173210948_item	2871326	et	3	main
söömine	doc_771173210948_item	2871327	et	4	main
pahandab	doc_771173210948_item	2871328	et	3	main
pange	doc_771173210948_item	2871334	et	4	main
pean	doc_771173210948_item	2871342	et	4	main
oma	doc_771173210948_item	2871347	et	4	main
vanematele	doc_771173210948_item	2871348	et	4	main
kõik	doc_771173210948_item	2871352	et	4	main
sporti	doc_771173210948_item	2871370	et	4	main
sa	doc_771173210948_item	2871372	et	3	main
oht	doc_771173210948_item	2871384	et	3	main
uus	doc_771173210948_item	2871390	et	3	main
kiiresti	doc_771173210948_item	2871394	et	3	main
muudatused	doc_771173210948_item	2871401	et	3	main
7	doc_771173210948_item	2871404	et	2	main
see	doc_771173210948_item	2871405	et	3	main
küsimus	doc_771173210948_item	2871406	et	4	main
kuulub	doc_771173210948_item	2871407	et	3	main
teine	doc_771173210948_item	2871408	et	3	main
valdkond	doc_771173210948_item	2871409	et	3	main
tunnen	doc_771173210948_item	2871426	et	3	main
päikest	doc_771173210948_item	2871431	et	4	main
v	doc_771173210948_item	2871432	et	4	main
täitke	doc_771173210948_item	2871433	et	3	main
lüngad	doc_771173210948_item	2871434	et	3	main
sobivate	doc_771173210948_item	2871435	et	4	main
see	doc_771173210948_item	2871442	et	3	main
lapsel	doc_771173210948_item	2871453	et	4	main
paluti	doc_771173210948_item	2871454	et	3	main
oleks	doc_771173210948_item	2871465	et	3	main
päevad	doc_771173210948_item	2871153	et	3	main
suure	doc_771173210948_item	2871164	et	3	main
vene	doc_771173210948_item	2871165	et	4	main
kütmisega	doc_771173210948_item	2871168	et	4	main
kui	doc_771173210948_item	2871169	et	3	main
müüdagi	doc_771173210948_item	2871180	et	3	main
valmistu	doc_771173210948_item	2871184	et	4	main
moodustage	doc_771173210948_item	2871191	et	3	main
sõnadest	doc_771173210948_item	2871193	et	3	main
ja	doc_771173210948_item	2871199	et	3	main
mehelikum	doc_771173210948_item	2871218	et	4	main
tegutsema	doc_771173210948_item	2871227	et	3	main
aga	doc_771173210948_item	2871228	et	3	main
tooma	doc_771173210948_item	2871231	et	3	main
paras	doc_771173210948_item	2871234	et	3	main
meid	doc_771173210948_item	2871238	et	4	main
aga	doc_771173210948_item	2871240	et	3	main
ei	doc_771173210948_item	2871247	et	4	main
tohtima	doc_771173210948_item	2871248	et	3	main
laskma	doc_771173210948_item	2871249	et	3	main
ülekoormus	doc_771173210948_item	2871250	et	3	main
tekkima	doc_771173210948_item	2871251	et	3	main
pinge	doc_771173210948_item	2871252	et	4	main
tohi	doc_771173210948_item	2871259	et	4	main
ülekoormuse	doc_771173210948_item	2871260	et	3	main
maagiline	doc_771173210948_item	2871275	et	4	main
telefon	doc_771173210948_item	2871284	et	3	main
tänapäeval	doc_771173210948_item	2871286	et	3	main
nii	doc_771173210948_item	2871287	et	3	main
abil	doc_771173210948_item	2871294	et	4	main
6	doc_771173210948_item	2871298	et	2	main
ka	doc_771173210948_item	2871302	et	3	main
lõunasöök	doc_771173210948_item	2871307	et	3	main
aeg	doc_771173210948_item	2871315	et	3	main
katkestab	doc_771173210948_item	2871318	et	3	main
pühapäeva	doc_771173210948_item	2871320	et	4	main
varahommiku	doc_771173210948_item	2871321	et	3	main
und	doc_771173210948_item	2871322	et	4	main
segab	doc_771173210948_item	2871323	et	3	main
telesaade	doc_771173210948_item	2871330	et	4	main
vormi	doc_771173210948_item	2871339	et	4	main
1	doc_771173210948_item	2871340	et	2	main
ma	doc_771173210948_item	2871341	et	3	main
vanemad	doc_771173210948_item	2871346	et	4	main
aitavad	doc_771173210948_item	2871351	et	4	main
kõiki	doc_771173210948_item	2871353	et	4	main
ja	doc_771173210948_item	2871354	et	3	main
2	doc_771173210948_item	2871358	et	2	main
kohandasin	doc_771173210948_item	2871359	et	3	main
artikli	doc_771173210948_item	2871360	et	3	main
nõudeid	doc_771173210948_item	2871362	et	3	main
ma	doc_771173210948_item	2871364	et	3	main
sa	doc_771173210948_item	2871367	et	3	main
ainult	doc_771173210948_item	2871375	et	4	main
ilusad	doc_771173210948_item	2871376	et	3	main
naised	doc_771173210948_item	2871377	et	3	main
töökoht	doc_771173210948_item	2871391	et	3	main
töökohta	doc_771173210948_item	2871393	et	4	main
vaid	doc_771173210948_item	2871399	et	3	main
väikesed	doc_771173210948_item	2871400	et	4	main
külmetamist	doc_771173210948_item	2871423	et	4	main
päike	doc_771173210948_item	2871429	et	3	main
suvist	doc_771173210948_item	2871430	et	4	main
sidenditega	doc_771173210948_item	2871436	et	3	main
1	doc_771173210948_item	2871437	et	2	main
tellisime	doc_771173210948_item	2871438	et	4	main
maksis	doc_771173210948_item	2871443	et	4	main
2	doc_771173210948_item	2871445	et	2	main
tulevad	doc_771173210948_item	2871459	et	4	main
4	doc_771173210948_item	2871460	et	2	main
kostis	doc_771173210948_item	2871462	et	4	main
naeru	doc_771173210948_item	2871463	et	4	main
kas	doc_771173210948_item	2871464	et	3	main
ta	doc_771173210948_item	2871471	et	4	main
teatrisse	doc_771173210948_item	2871478	et	3	main
töö	doc_771173210948_item	2871481	et	4	main
jalutama	doc_771173210948_item	2871484	et	3	main
selles	doc_771173210948_item	2871486	et	4	main
ei	doc_771173210948_item	2871488	et	4	main
tarbida	doc_771173210948_item	2871493	et	3	main
jääd	doc_771173210948_item	2871509	et	4	main
vormi	doc_771173210948_item	2871198	et	4	main
naeratus	doc_771173210948_item	2871212	et	4	main
teeb	doc_771173210948_item	2871213	et	3	main
naised	doc_771173210948_item	2871214	et	3	main
naiselikum	doc_771173210948_item	2871215	et	4	main
meie	doc_771173210948_item	2871226	et	4	main
lisakoormus	doc_771173210948_item	2871229	et	3	main
soovimatu	doc_771173210948_item	2871232	et	4	main
paneb	doc_771173210948_item	2871237	et	3	main
soovimatu	doc_771173210948_item	2871244	et	4	main
4	doc_771173210948_item	2871246	et	2	main
ei	doc_771173210948_item	2871258	et	4	main
lasta	doc_771173210948_item	2871261	et	4	main
tekkib	doc_771173210948_item	2871262	et	3	main
pinge	doc_771173210948_item	2871263	et	4	main
saage	doc_771173210948_item	2871264	et	4	main
maandama	doc_771173210948_item	2871265	et	3	main
sporti	doc_771173210948_item	2871266	et	4	main
ja	doc_771173210948_item	2871267	et	3	main
5	doc_771173210948_item	2871269	et	2	main
puhkuse	doc_771173210948_item	2871268	et	3	main
olema	doc_771173210948_item	2871271	et	4	main
tänapäev	doc_771173210948_item	2871272	et	3	main
saama	doc_771173210948_item	2871273	et	4	main
nii	doc_771173210948_item	2871274	et	3	main
see	doc_771173210948_item	2871278	et	3	main
lausa	doc_771173210948_item	2871280	et	4	main
ja	doc_771173210948_item	2871282	et	3	main
on	doc_771173210948_item	2871285	et	4	main
saama	doc_771173210948_item	2871288	et	4	main
elama	doc_771173210948_item	2871295	et	3	main
kuid	doc_771173210948_item	2871299	et	4	main
söömine	doc_771173210948_item	2871310	et	4	main
lõunasööki	doc_771173210948_item	2871324	et	4	main
huvitavat	doc_771173210948_item	2871329	et	4	main
iv	doc_771173210948_item	2871333	et	4	main
olevad	doc_771173210948_item	2871336	et	4	main
väga	doc_771173210948_item	2871343	et	3	main
lugu	doc_771173210948_item	2871344	et	4	main
usaldavad	doc_771173210948_item	2871355	et	4	main
igaüks	doc_771173210948_item	2871356	et	3	main
igaühele	doc_771173210948_item	2871357	et	3	main
nõuded	doc_771173210948_item	2871361	et	3	main
et	doc_771173210948_item	2871366	et	3	main
aga	doc_771173210948_item	2871371	et	3	main
huvi	doc_771173210948_item	2871374	et	4	main
ja	doc_771173210948_item	2871378	et	3	main
kiired	doc_771173210948_item	2871379	et	4	main
autod	doc_771173210948_item	2871380	et	3	main
4	doc_771173210948_item	2871381	et	2	main
praegu	doc_771173210948_item	2871382	et	3	main
tüdinesin	doc_771173210948_item	2871389	et	3	main
6	doc_771173210948_item	2871395	et	2	main
selles	doc_771173210948_item	2871397	et	4	main
küsimuses	doc_771173210948_item	2871398	et	4	main
väikeses	doc_771173210948_item	2871402	et	4	main
muudatuses	doc_771173210948_item	2871403	et	3	main
valmistamine	doc_771173210948_item	2871308	et	4	main
pahandab	doc_771173210948_item	2871311	et	3	main
huvitav	doc_771173210948_item	2871312	et	4	main
kuid	doc_771173210948_item	2871316	et	4	main
ka	doc_771173210948_item	2871319	et	3	main
vaatamise	doc_771173210948_item	2871331	et	4	main
aeg	doc_771173210948_item	2871332	et	3	main
sulgudes	doc_771173210948_item	2871335	et	4	main
sõnad	doc_771173210948_item	2871337	et	4	main
õigesse	doc_771173210948_item	2871338	et	3	main
oma	doc_771173210948_item	2871345	et	4	main
sest	doc_771173210948_item	2871349	et	4	main
nad	doc_771173210948_item	2871350	et	3	main
3	doc_771173210948_item	2871363	et	2	main
arvasin	doc_771173210948_item	2871365	et	3	main
huvitud	doc_771173210948_item	2871368	et	4	main
sport	doc_771173210948_item	2871369	et	3	main
tunned	doc_771173210948_item	2871373	et	3	main
on	doc_771173210948_item	2871383	et	4	main
haigestuda	doc_771173210948_item	2871385	et	3	main
difteeria	doc_771173210948_item	2871386	et	4	main
difteriat	doc_771173210948_item	2871387	et	4	main
5	doc_771173210948_item	2871388	et	2	main
uue	doc_771173210948_item	2871392	et	3	main
piirdusime	doc_771173210948_item	2871396	et	3	main
teise	doc_771173210948_item	2871410	et	4	main
valdkonale	doc_771173210948_item	2871411	et	4	main
8	doc_771173210948_item	2871412	et	2	main
närimiskumm	doc_771173210948_item	2871413	et	3	main
kleepus	doc_771173210948_item	2871414	et	3	main
püksid	doc_771173210948_item	2871415	et	3	main
püksidele	doc_771173210948_item	2871416	et	3	main
9	doc_771173210948_item	2871417	et	2	main
külmal	doc_771173210948_item	2871418	et	3	main
ajal	doc_771173210948_item	2871419	et	4	main
peab	doc_771173210948_item	2871420	et	4	main
10	doc_771173210948_item	2871424	et	2	main
kolmekäigulise	doc_771173210948_item	2871439	et	4	main
õpetajad	doc_771173210948_item	2871451	et	4	main
3	doc_771173210948_item	2871452	et	2	main
vanemad	doc_771173210948_item	2871457	et	4	main
tagasi	doc_771173210948_item	2871458	et	3	main
anekdooti	doc_771173210948_item	2871468	et	4	main
tule	doc_771173210948_item	2871473	et	4	main
läheb	doc_771173210948_item	2871476	et	3	main
lõpetage	doc_771173210948_item	2871480	et	3	main
tohi	doc_771173210948_item	2871489	et	4	main
alkoholi	doc_771173210948_item	2871492	et	4	main
nad	doc_771173210948_item	2871495	et	3	main
tulemust	doc_771173210948_item	2871500	et	4	main
linna	doc_771173210948_item	2871510	et	4	main
10	doc_771173210948_item	2871511	et	2	main
ole	doc_771173210949_item	2871522	et	4	main
üks	doc_771173210949_item	2871526	et	3	main
inimesed	doc_771173210949_item	2871532	et	3	main
põrgut	doc_771173210949_item	2871539	et	3	main
olla	doc_771173210949_item	2871546	et	3	main
otsekohesed	doc_771173210949_item	2871549	et	3	main
kui	doc_771173210949_item	2871551	et	3	main
aususega	doc_771173210949_item	2871554	et	4	main
haiget	doc_771173210949_item	2871556	et	3	main
valet	doc_771173210949_item	2871559	et	3	main
päris	doc_771173210949_item	2871563	et	4	main
võrdsed	doc_771173210949_item	2871564	et	3	main
ma	doc_771173210949_item	2871565	et	3	main
ei	doc_771173210949_item	2871566	et	4	main
on	doc_771173210949_item	2871572	et	4	main
valetamine	doc_771173210949_item	2871576	et	4	main
juhtus	doc_771173210949_item	2871579	et	3	main
filmis	doc_771173210949_item	2871581	et	4	main
teine	doc_771173210949_item	2871590	et	3	main
inimene	doc_771173210949_item	2871591	et	3	main
hoiduma	doc_771173210948_item	2871421	et	3	main
külmetamine	doc_771173210948_item	2871422	et	4	main
ma	doc_771173210948_item	2871425	et	3	main
rõõmu	doc_771173210948_item	2871427	et	4	main
suvine	doc_771173210948_item	2871428	et	4	main
lõuna	doc_771173210948_item	2871440	et	4	main
kuigi	doc_771173210948_item	2871441	et	3	main
palju	doc_771173210948_item	2871444	et	4	main
kohal	doc_771173210948_item	2871446	et	4	main
olid	doc_771173210948_item	2871447	et	4	main
nii	doc_771173210948_item	2871448	et	3	main
õpilased	doc_771173210948_item	2871449	et	3	main
kui	doc_771173210948_item	2871450	et	3	main
oodata	doc_771173210948_item	2871455	et	4	main
kuni	doc_771173210948_item	2871456	et	3	main
kõrvallauast	doc_771173210948_item	2871461	et	4	main
rääkinud	doc_771173210948_item	2871469	et	4	main
5	doc_771173210948_item	2871470	et	2	main
trenni	doc_771173210948_item	2871474	et	4	main
hoopis	doc_771173210948_item	2871477	et	3	main
siis	doc_771173210948_item	2871482	et	3	main
7	doc_771173210948_item	2871485	et	2	main
pingsalt	doc_771173210948_item	2871498	et	4	main
ei	doc_771173210948_item	2871501	et	4	main
avasin	doc_771173210948_item	2871512	et	3	main
kuulsin	doc_771173210948_item	2871515	et	3	main
koputust	doc_771173210948_item	2871516	et	4	main
ei	doc_771173210949_item	2871517	et	4	main
ole	doc_771173210949_item	2871518	et	4	main
midagi	doc_771173210949_item	2871519	et	4	main
hirmsamat	doc_771173210949_item	2871520	et	4	main
hirmsamat	doc_771173210949_item	2871524	et	4	main
kui	doc_771173210949_item	2871525	et	3	main
aus	doc_771173210949_item	2871527	et	4	main
inimene	doc_771173210949_item	2871528	et	3	main
br	doc_771173210949_item	2871529	et	4	main
kui	doc_771173210949_item	2871530	et	3	main
räägiksid	doc_771173210949_item	2871533	et	4	main
ausad	doc_771173210949_item	2871547	et	3	main
aga	doc_771173210949_item	2871550	et	3	main
kaks	doc_771173210949_item	2871558	et	3	main
ei	doc_771173210949_item	2871560	et	4	main
väita	doc_771173210949_item	2871569	et	4	main
et	doc_771173210949_item	2871570	et	3	main
ja	doc_771173210949_item	2871575	et	3	main
ei	doc_771173210949_item	2871586	et	4	main
oleks	doc_771173210949_item	2871587	et	3	main
nii	doc_771173210949_item	2871588	et	3	main
aus	doc_771173210949_item	2871589	et	4	main
pärast	doc_771173210949_item	2871602	et	4	main
kannatas	doc_771173210949_item	2871603	et	3	main
alguses	doc_771173210949_item	2871610	et	4	main
armastas	doc_771173210949_item	2871611	et	3	main
naine	doc_771173210949_item	2871612	et	3	main
oli	doc_771173210949_item	2871623	et	3	main
nii	doc_771173210949_item	2871624	et	3	main
keelatud	doc_771173210949_item	2871631	et	4	main
kuid	doc_771173210949_item	2871632	et	4	main
end	doc_771173210949_item	2871644	et	4	main
on	doc_771173210949_item	2871652	et	4	main
üsna	doc_771173210949_item	2871653	et	3	main
ebaausamatel	doc_771173210949_item	2871657	et	4	main
helged	doc_771173210949_item	2871661	et	3	main
et	doc_771173210949_item	2871665	et	3	main
on	doc_771173210949_item	2871669	et	4	main
l	doc_771173210950_item	2871677	et	4	main
oli	doc_771173210950_item	2871678	et	3	main
kirjutanud	doc_771173210950_item	2871682	et	4	main
tema	doc_771173210950_item	2871687	et	4	main
koordis	doc_771173210950_item	2871692	et	4	main
eest	doc_771173210950_item	2871694	et	4	main
ta	doc_771173210950_item	2871695	et	4	main
sai	doc_771173210950_item	2871696	et	4	main
film	doc_771173210950_item	2871703	et	3	main
keegi	doc_771173210948_item	2871466	et	4	main
just	doc_771173210948_item	2871467	et	3	main
ei	doc_771173210948_item	2871472	et	4	main
ta	doc_771173210948_item	2871475	et	4	main
6	doc_771173210948_item	2871479	et	2	main
lähete	doc_771173210948_item	2871483	et	4	main
suitsetada	doc_771173210948_item	2871490	et	3	main
8	doc_771173210948_item	2871494	et	2	main
võid	doc_771173210948_item	2871508	et	4	main
midagi	doc_771173210949_item	2871523	et	4	main
ikka	doc_771173210949_item	2871544	et	4	main
oma	doc_771173210949_item	2871553	et	4	main
teeme	doc_771173210949_item	2871557	et	3	main
saa	doc_771173210949_item	2871567	et	4	main
alati	doc_771173210949_item	2871573	et	4	main
ilmtingimata	doc_771173210949_item	2871577	et	3	main
ka	doc_771173210949_item	2871580	et	3	main
arusaamatusi	doc_771173210949_item	2871582	et	4	main
näiteks	doc_771173210949_item	2871583	et	4	main
kui	doc_771173210949_item	2871584	et	3	main
jubedalt	doc_771173210949_item	2871596	et	4	main
aususega	doc_771173210949_item	2871604	et	4	main
pole	doc_771173210949_item	2871605	et	3	main
võimalik	doc_771173210949_item	2871606	et	3	main
erikut	doc_771173210949_item	2871613	et	4	main
kes	doc_771173210949_item	2871614	et	4	main
mõlemil	doc_771173210949_item	2871622	et	4	main
ei	doc_771173210949_item	2871629	et	4	main
ole	doc_771173210949_item	2871630	et	4	main
ikka	doc_771173210949_item	2871635	et	4	main
sest	doc_771173210949_item	2871639	et	4	main
nii	doc_771173210949_item	2871640	et	3	main
me	doc_771173210949_item	2871641	et	4	main
nagu	doc_771173210949_item	2871642	et	3	main
kaitseme	doc_771173210949_item	2871643	et	4	main
õigustada	doc_771173210949_item	2871648	et	3	main
käitumist	doc_771173210949_item	2871650	et	4	main
ausus	doc_771173210949_item	2871651	et	4	main
vaieldav	doc_771173210949_item	2871654	et	4	main
samas	doc_771173210949_item	2871656	et	4	main
ning	doc_771173210949_item	2871663	et	3	main
nende	doc_771173210949_item	2871666	et	4	main
veel	doc_771173210949_item	2871670	et	4	main
essee	doc_771173210950_item	2871672	et	4	main
koordis	doc_771173210950_item	2871674	et	4	main
sõna	doc_771173210950_item	2871684	et	4	main
kuulsaim	doc_771173210950_item	2871688	et	4	main
preemia	doc_771173210950_item	2871698	et	4	main
hiljem	doc_771173210950_item	2871699	et	3	main
19551	doc_771173210950_item	2871701	et	2	main
raamatu	doc_771173210950_item	2871709	et	4	main
järgi	doc_771173210950_item	2871710	et	4	main
see	doc_771173210950_item	2871711	et	3	main
oli	doc_771173210950_item	2871712	et	3	main
esimene	doc_771173210950_item	2871713	et	3	main
eesti	doc_771173210950_item	2871714	et	4	main
värvifilm	doc_771173210950_item	2871715	et	3	main
peategelase	doc_771173210950_item	2871716	et	3	main
noor	doc_771173210950_item	2871721	et	3	main
filmis	doc_771173210950_item	2871730	et	4	main
koju	doc_771173210950_item	2871742	et	3	main
talle	doc_771173210950_item	2871746	et	4	main
ta	doc_771173210950_item	2871750	et	4	main
teda	doc_771173210950_item	2871772	et	4	main
ja	doc_771173210950_item	2871773	et	3	main
tahavad	doc_771173210950_item	2871774	et	3	main
et	doc_771173210950_item	2871775	et	3	main
ta	doc_771173210950_item	2871776	et	4	main
otsustab	doc_771173210950_item	2871795	et	3	main
kõik	doc_771173210950_item	2871836	et	4	main
film	doc_771173210950_item	2871839	et	3	main
ekraniseeritud	doc_771173210950_item	2871844	et	4	main
see	doc_771173210950_item	2871847	et	3	main
ole	doc_771173210950_item	2871855	et	4	main
näiteks	doc_771173210950_item	2871858	et	4	main
ei	doc_771173210950_item	2871865	et	4	main
stalinile	doc_771173210950_item	2871868	et	4	main
ei	doc_771173210950_item	2871878	et	4	main
huvitanud	doc_771173210950_item	2871879	et	4	main
eestis	doc_771173210950_item	2871885	et	3	main
ja	doc_771173210950_item	2871886	et	3	main
nii	doc_771173210950_item	2871889	et	3	main
baaris	doc_771173210948_item	2871487	et	3	main
ega	doc_771173210948_item	2871491	et	3	main
töötasid	doc_771173210948_item	2871496	et	4	main
küll	doc_771173210948_item	2871497	et	4	main
aga	doc_771173210948_item	2871499	et	3	main
olnud	doc_771173210948_item	2871502	et	4	main
9	doc_771173210948_item	2871503	et	2	main
kas	doc_771173210948_item	2871504	et	3	main
sa	doc_771173210948_item	2871505	et	3	main
sõidad	doc_771173210948_item	2871506	et	3	main
maale	doc_771173210948_item	2871507	et	4	main
ukse	doc_771173210948_item	2871513	et	3	main
sest	doc_771173210948_item	2871514	et	4	main
ei	doc_771173210949_item	2871521	et	4	main
kõik	doc_771173210949_item	2871531	et	4	main
alati	doc_771173210949_item	2871534	et	4	main
tõtt	doc_771173210949_item	2871535	et	4	main
tähendaks	doc_771173210949_item	2871536	et	3	main
see	doc_771173210949_item	2871537	et	3	main
maapealset	doc_771173210949_item	2871538	et	3	main
jean	doc_771173210949_item	2871540	et	4	main
gabinbr	doc_771173210949_item	2871541	et	4	main
eks	doc_771173210949_item	2871542	et	3	main
me	doc_771173210949_item	2871543	et	4	main
püüame	doc_771173210949_item	2871545	et	3	main
ja	doc_771173210949_item	2871548	et	3	main
me	doc_771173210949_item	2871552	et	4	main
pigem	doc_771173210949_item	2871555	et	3	main
must-valgel	doc_771173210949_item	2871568	et	4	main
hea	doc_771173210949_item	2871574	et	4	main
halbbr	doc_771173210949_item	2871578	et	4	main
tegi	doc_771173210949_item	2871595	et	4	main
kes	doc_771173210949_item	2871599	et	4	main
peaaegu	doc_771173210949_item	2871617	et	3	main
teise	doc_771173210949_item	2871619	et	4	main
fraasiga	doc_771173210949_item	2871620	et	3	main
lihtsambr	doc_771173210949_item	2871625	et	4	main
püüdmine	doc_771173210949_item	2871626	et	4	main
aususe	doc_771173210949_item	2871627	et	4	main
poole	doc_771173210949_item	2871628	et	4	main
valed	doc_771173210949_item	2871634	et	3	main
tulevad	doc_771173210949_item	2871636	et	4	main
vahest	doc_771173210949_item	2871637	et	4	main
oma	doc_771173210949_item	2871649	et	4	main
mõiste	doc_771173210949_item	2871655	et	4	main
hetked	doc_771173210949_item	2871662	et	3	main
päevad	doc_771173210949_item	2871668	et	3	main
hans	doc_771173210950_item	2871676	et	4	main
eesti	doc_771173210950_item	2871685	et	4	main
teos	doc_771173210950_item	2871689	et	4	main
on	doc_771173210950_item	2871690	et	4	main
valgus	doc_771173210950_item	2871691	et	4	main
stalini	doc_771173210950_item	2871697	et	4	main
mis	doc_771173210950_item	2871706	et	4	main
oli	doc_771173210950_item	2871707	et	3	main
rolli	doc_771173210950_item	2871717	et	4	main
br	doc_771173210950_item	2871731	et	4	main
ii	doc_771173210950_item	2871736	et	4	main
riik	doc_771173210950_item	2871744	et	3	main
ja	doc_771173210950_item	2871748	et	3	main
tema	doc_771173210950_item	2871763	et	4	main
sõbral	doc_771173210950_item	2871764	et	3	main
aga	doc_771173210950_item	2871766	et	3	main
külas	doc_771173210950_item	2871767	et	3	main
elavad	doc_771173210950_item	2871768	et	4	main
inimesed	doc_771173210950_item	2871769	et	3	main
kaduks	doc_771173210950_item	2871777	et	4	main
maalt	doc_771173210950_item	2871778	et	3	main
aga	doc_771173210950_item	2871785	et	3	main
abiks	doc_771173210950_item	2871786	et	3	main
tulevad	doc_771173210950_item	2871787	et	4	main
kurjategijad	doc_771173210950_item	2871790	et	3	main
ja	doc_771173210950_item	2871793	et	3	main
ole	doc_771173210949_item	2871561	et	4	main
kunagi	doc_771173210949_item	2871562	et	3	main
ausus	doc_771173210949_item	2871571	et	4	main
aleks	doc_771173210949_item	2871585	et	4	main
ellu	doc_771173210949_item	2871593	et	4	main
ta	doc_771173210949_item	2871594	et	4	main
maailma	doc_771173210949_item	2871607	et	4	main
päästa	doc_771173210949_item	2871608	et	4	main
kohe	doc_771173210949_item	2871609	et	4	main
tegelikult	doc_771173210949_item	2871615	et	4	main
neil	doc_771173210949_item	2871621	et	4	main
väikesed	doc_771173210949_item	2871633	et	4	main
ette	doc_771173210949_item	2871638	et	4	main
või	doc_771173210949_item	2871645	et	4	main
siis	doc_771173210949_item	2871646	et	3	main
püüame	doc_771173210949_item	2871647	et	3	main
on	doc_771173210949_item	2871658	et	4	main
ka	doc_771173210949_item	2871659	et	3	main
omad	doc_771173210949_item	2871660	et	4	main
võimalik	doc_771173210949_item	2871664	et	3	main
paremat	doc_771173210949_item	2871667	et	4	main
br	doc_771173210950_item	2871675	et	4	main
ei	doc_771173210950_item	2871681	et	4	main
keeles	doc_771173210950_item	2871686	et	4	main
mille	doc_771173210950_item	2871693	et	3	main
tehtud	doc_771173210950_item	2871708	et	4	main
mängib	doc_771173210950_item	2871718	et	3	main
georg	doc_771173210950_item	2871719	et	4	main
ots	doc_771173210950_item	2871720	et	3	main
ja	doc_771173210950_item	2871722	et	3	main
laulja	doc_771173210950_item	2871724	et	4	main
see	doc_771173210950_item	2871725	et	3	main
oli	doc_771173210950_item	2871726	et	3	main
tegevus	doc_771173210950_item	2871732	et	4	main
toimub	doc_771173210950_item	2871733	et	3	main
eestis	doc_771173210950_item	2871734	et	3	main
tagasi	doc_771173210950_item	2871743	et	3	main
maja	doc_771173210950_item	2871747	et	4	main
abieelub	doc_771173210950_item	2871751	et	4	main
ja	doc_771173210950_item	2871752	et	3	main
elama	doc_771173210950_item	2871754	et	3	main
tema	doc_771173210950_item	2871756	et	4	main
unistus	doc_771173210950_item	2871757	et	4	main
asutada	doc_771173210950_item	2871758	et	3	main
koordis	doc_771173210950_item	2871759	et	4	main
kolhoos	doc_771173210950_item	2871760	et	3	main
just	doc_771173210950_item	2871761	et	3	main
nagu	doc_771173210950_item	2871762	et	3	main
kadestavad	doc_771173210950_item	2871771	et	4	main
lõpuks	doc_771173210950_item	2871780	et	4	main
põletavad	doc_771173210950_item	2871782	et	4	main
pannakse	doc_771173210950_item	2871791	et	3	main
teha	doc_771173210950_item	2871796	et	3	main
valgus	doc_771173210950_item	2871821	et	4	main
mille	doc_771173210950_item	2871830	et	3	main
mulle	doc_771173210950_item	2871840	et	4	main
oli	doc_771173210950_item	2871842	et	3	main
jutustus	doc_771173210950_item	2871850	et	4	main
ei	doc_771173210950_item	2871854	et	4	main
eestis	doc_771173210950_item	2871859	et	3	main
teravillja	doc_771173210950_item	2871862	et	4	main
meeldis	doc_771173210950_item	2871870	et	3	main
eest	doc_771173210950_item	2871872	et	4	main
ülistas	doc_771173210950_item	2871874	et	3	main
nsvl	doc_771173210950_item	2871875	et	4	main
tundsid	doc_771173210950_item	2871881	et	4	main
inimesed	doc_771173210950_item	2871882	et	3	main
küsimusele	doc_782723477918_item	2871893	et	4	main
1	doc_782723477918_item	2871894	et	2	main
kirjanduselu	doc_782723477918_item	2871897	et	4	main
milliseid	doc_782723477918_item	2871899	et	3	main
arenema	doc_782723477918_item	2871921	et	3	main
kirjandusorganisatsioon	doc_782723477918_item	2871923	et	3	main
gustav	doc_782723477918_item	2871929	et	4	main
suits	doc_782723477918_item	2871930	et	3	main
frtuglas	doc_782723477918_item	2871931	et	4	main
tahtsid	doc_782723477918_item	2871935	et	4	main
tutvustada	doc_782723477918_item	2871936	et	3	main
rahvast	doc_782723477918_item	2871937	et	4	main
euroopas	doc_782723477918_item	2871938	et	3	main
jääks	doc_771173210949_item	2871592	et	4	main
haiget	doc_771173210949_item	2871597	et	3	main
naisele	doc_771173210949_item	2871598	et	3	main
tema	doc_771173210949_item	2871600	et	4	main
aususe	doc_771173210949_item	2871601	et	4	main
valetas	doc_771173210949_item	2871616	et	3	main
iga	doc_771173210949_item	2871618	et	4	main
eesbr	doc_771173210949_item	2871671	et	4	main
valgus	doc_771173210950_item	2871673	et	4	main
kirjanik	doc_771173210950_item	2871679	et	3	main
kes	doc_771173210950_item	2871680	et	4	main
ühtegi	doc_771173210950_item	2871683	et	4	main
aastal	doc_771173210950_item	2871700	et	3	main
ilmus	doc_771173210950_item	2871702	et	4	main
valgus	doc_771173210950_item	2871704	et	4	main
koordis	doc_771173210950_item	2871705	et	4	main
ilus	doc_771173210950_item	2871723	et	4	main
tema	doc_771173210950_item	2871727	et	4	main
esimene	doc_771173210950_item	2871728	et	3	main
roll	doc_771173210950_item	2871729	et	3	main
pärast	doc_771173210950_item	2871735	et	4	main
maailma	doc_771173210950_item	2871737	et	4	main
sõda	doc_771173210950_item	2871738	et	4	main
noor	doc_771173210950_item	2871739	et	3	main
sõdur	doc_771173210950_item	2871740	et	3	main
tuleb	doc_771173210950_item	2871741	et	3	main
annab	doc_771173210950_item	2871745	et	3	main
maad	doc_771173210950_item	2871749	et	4	main
hakkab	doc_771173210950_item	2871753	et	3	main
maal	doc_771173210950_item	2871755	et	4	main
kes	doc_771173210950_item	2871770	et	4	main
kõik	doc_771173210950_item	2871788	et	4	main
rahvas	doc_771173210950_item	2871794	et	4	main
br	doc_771173210950_item	2871798	et	4	main
nad	doc_771173210950_item	2871799	et	3	main
sõidavad	doc_771173210950_item	2871800	et	3	main
venemaale	doc_771173210950_item	2871801	et	4	main
kolhoosi	doc_771173210950_item	2871797	et	4	main
vaatama	doc_771173210950_item	2871802	et	3	main
kuidas	doc_771173210950_item	2871803	et	3	main
kõik	doc_771173210950_item	2871804	et	4	main
töötab	doc_771173210950_item	2871805	et	3	main
asutavad	doc_771173210950_item	2871806	et	4	main
koordis	doc_771173210950_item	2871807	et	4	main
oma	doc_771173210950_item	2871808	et	4	main
kolhoosi	doc_771173210950_item	2871809	et	4	main
mis	doc_771173210950_item	2871810	et	4	main
nimetavad	doc_771173210950_item	2871811	et	4	main
uus	doc_771173210950_item	2871812	et	3	main
elu	doc_771173210950_item	2871813	et	4	main
br	doc_771173210950_item	2871814	et	4	main
filmis	doc_771173210950_item	2871815	et	4	main
tuleb	doc_771173210950_item	2871816	et	3	main
hea	doc_771173210950_item	2871817	et	4	main
ja	doc_771173210950_item	2871818	et	3	main
õnnelik	doc_771173210950_item	2871819	et	3	main
lõpp	doc_771173210950_item	2871820	et	3	main
film	doc_771173210950_item	2871829	et	3	main
oli	doc_771173210950_item	2871837	et	3	main
oli	doc_771173210950_item	2871846	et	3	main
nägu	doc_771173210950_item	2871848	et	4	main
mingi	doc_771173210950_item	2871849	et	4	main
koordis	doc_771173210950_item	2871853	et	4	main
film	doc_771173210950_item	2871857	et	3	main
ei	doc_771173210950_item	2871860	et	4	main
venemaal	doc_771173210950_item	2871765	et	4	main
ära	doc_771173210950_item	2871779	et	4	main
nad	doc_771173210950_item	2871781	et	3	main
tema	doc_771173210950_item	2871783	et	4	main
maja	doc_771173210950_item	2871784	et	4	main
külainimesed	doc_771173210950_item	2871789	et	3	main
kinni	doc_771173210950_item	2871792	et	3	main
koordis	doc_771173210950_item	2871822	et	4	main
on	doc_771173210950_item	2871823	et	4	main
väga	doc_771173210950_item	2871824	et	3	main
naiivne	doc_771173210950_item	2871825	et	3	main
ja	doc_771173210950_item	2871826	et	3	main
tüüpiline	doc_771173210950_item	2871827	et	3	main
nõukogude	doc_771173210950_item	2871828	et	3	main
tähtsus	doc_771173210950_item	2871831	et	4	main
oli	doc_771173210950_item	2871832	et	3	main
näidata	doc_771173210950_item	2871833	et	4	main
kui	doc_771173210950_item	2871834	et	3	main
hästi	doc_771173210950_item	2871835	et	3	main
tegelikult	doc_771173210950_item	2871838	et	4	main
meeldis	doc_771173210950_item	2871841	et	3	main
hästi	doc_771173210950_item	2871843	et	3	main
aga	doc_771173210950_item	2871845	et	3	main
lastele	doc_771173210950_item	2871851	et	4	main
valgus	doc_771173210950_item	2871852	et	4	main
tõenäoline	doc_771173210950_item	2871856	et	4	main
kasvatatakse	doc_771173210950_item	2871861	et	3	main
sest	doc_771173210950_item	2871863	et	4	main
sobilik	doc_771173210950_item	2871867	et	3	main
ta	doc_771173210950_item	2871869	et	4	main
et	doc_771173210950_item	2871873	et	3	main
mida	doc_771173210950_item	2871880	et	4	main
oli	doc_771173210950_item	2871888	et	3	main
tõi	doc_782723477918_item	2871901	et	3	main
külaühiskonda	doc_782723477918_item	2871905	et	4	main
3	doc_782723477918_item	2871906	et	2	main
mida	doc_782723477918_item	2871907	et	4	main
tähendas	doc_782723477918_item	2871908	et	3	main
ii	doc_782723477918_item	2871909	et	4	main
maailmasõda	doc_782723477918_item	2871910	et	4	main
eestlaste	doc_782723477918_item	2871911	et	4	main
jaoks	doc_782723477918_item	2871912	et	4	main
1	doc_782723477918_item	2871913	et	2	main
pärast	doc_782723477918_item	2871914	et	4	main
1905	doc_782723477918_item	2871915	et	2	main
aasta	doc_782723477918_item	2871916	et	4	main
revolutsioonist	doc_782723477918_item	2871917	et	3	main
eesti	doc_782723477918_item	2871918	et	4	main
kirjanduselu	doc_782723477918_item	2871919	et	4	main
hakkas	doc_782723477918_item	2871920	et	3	main
olid	doc_782723477918_item	2871928	et	4	main
jt	doc_782723477918_item	2871933	et	4	main
nad	doc_782723477918_item	2871934	et	3	main
nad	doc_782723477918_item	2871940	et	3	main
samanimelist	doc_782723477918_item	2871943	et	4	main
albumit	doc_782723477918_item	2871944	et	3	main
aga	doc_782723477918_item	2871945	et	3	main
see	doc_782723477918_item	2871946	et	3	main
oli	doc_782723477918_item	2871947	et	3	main
pärast	doc_782723477918_item	2871953	et	4	main
seda	doc_782723477918_item	2871954	et	3	main
kui	doc_782723477918_item	2871955	et	3	main
iseseisvust	doc_782723477918_item	2871958	et	4	main
ja	doc_782723477918_item	2871963	et	3	main
tõde	doc_782723477918_item	2871978	et	4	main
ja	doc_782723477918_item	2871979	et	3	main
elasid	doc_771173210950_item	2871884	et	4	main
kas	doc_771173210950_item	2871887	et	3	main
välja	doc_782723477918_item	2871942	et	4	main
kliima	doc_771173210950_item	2871864	et	4	main
ole	doc_771173210950_item	2871866	et	4	main
selle	doc_771173210950_item	2871871	et	4	main
ja	doc_771173210950_item	2871876	et	3	main
teda	doc_771173210950_item	2871877	et	4	main
kes	doc_771173210950_item	2871883	et	4	main
iseloomustage	doc_782723477918_item	2871895	et	4	main
2	doc_782723477918_item	2871898	et	2	main
kollektiviseerimine	doc_782723477918_item	2871903	et	4	main
tõeselus	doc_771173210950_item	2871890	et	4	main
body	doc_771173210950_item	2871891	et	4	main
vastus	doc_782723477918_item	2871892	et	3	main
noor	doc_782723477918_item	2871924	et	3	main
enne	doc_782723477918_item	2871948	et	4	main
eesti	doc_782723477918_item	2871956	et	4	main
haritud	doc_782723477918_item	2871966	et	4	main
arenema	doc_782723477918_item	2871972	et	3	main
väga	doc_782723477918_item	2871973	et	3	main
populaarseks	doc_782723477918_item	2871974	et	4	main
sai	doc_782723477918_item	2871975	et	4	main
ahtammsaare	doc_782723477918_item	2871976	et	4	main
romaan	doc_782723477918_item	2871977	et	3	main
õigus	doc_782723477918_item	2871980	et	4	main
väga	doc_782723477918_item	2871981	et	3	main
populaarne	doc_782723477918_item	2871982	et	3	main
oli	doc_782723477918_item	2871983	et	3	main
hakkas	doc_782723477918_item	2871989	et	3	main
ja	doc_782723477918_item	2872001	et	3	main
enamlastele	doc_782723477918_item	2872020	et	4	main
ew	doc_782723477918_item	2871896	et	4	main
muudatusi	doc_782723477918_item	2871900	et	3	main
pärastsõjajärgne	doc_782723477918_item	2871902	et	3	main
kaasa	doc_782723477918_item	2871904	et	4	main
ilmus	doc_782723477918_item	2871922	et	4	main
eesti	doc_782723477918_item	2871925	et	4	main
elle	doc_782723477918_item	2871926	et	3	main
riikmeteks	doc_782723477918_item	2871927	et	4	main
jaavik	doc_782723477918_item	2871932	et	4	main
toimuvatega	doc_782723477918_item	2871939	et	4	main
eesti	doc_782723477918_item	2871949	et	4	main
vabariigi	doc_782723477918_item	2871950	et	3	main
iseseisvust	doc_782723477918_item	2871951	et	4	main
aga	doc_782723477918_item	2871952	et	3	main
haritlaskond	doc_782723477918_item	2871962	et	3	main
inimesi	doc_782723477918_item	2871967	et	4	main
eest	doc_782723477918_item	2871968	et	4	main
luule	doc_782723477918_item	2871985	et	4	main
looming	doc_782723477918_item	2871988	et	3	main
proosa	doc_782723477918_item	2871992	et	4	main
välja	doc_782723477918_item	2871994	et	4	main
raamatuid	doc_782723477918_item	2871997	et	3	main
ilmusid	doc_782723477918_item	2871998	et	4	main
ka	doc_782723477918_item	2871999	et	3	main
sõnastikud	doc_782723477918_item	2872000	et	3	main
valitsus	doc_782723477918_item	2872011	et	4	main
ja	doc_782723477918_item	2872012	et	3	main
hävitama	doc_782723477918_item	2872014	et	4	main
sulgeda	doc_782723477918_item	2872022	et	3	main
kaasa	doc_782723477918_item	2872028	et	4	main
palju	doc_782723477918_item	2872029	et	4	main
muudatusi	doc_782723477918_item	2872030	et	3	main
ära	doc_782723477918_item	2872036	et	4	main
ülejaanud	doc_782723477918_item	2872043	et	4	main
hakkas	doc_782723477918_item	2872047	et	3	main
enamasti	doc_782723477918_item	2872053	et	4	main
inimesed	doc_782723477918_item	2872058	et	3	main
moel	doc_782723477918_item	2872060	et	4	main
vabastati	doc_782723477918_item	2872061	et	3	main
kartsid	doc_782723477918_item	2872064	et	4	main
seda	doc_782723477918_item	2872065	et	3	main
ja	doc_782723477918_item	2872066	et	3	main
hakati	doc_782723477918_item	2872067	et	3	main
jaoks	doc_782723477918_item	2872077	et	4	main
oli	doc_782723477918_item	2872086	et	3	main
otsustada	doc_782723477918_item	2872089	et	3	main
massiline	doc_782723477918_item	2872123	et	4	main
laostanud	doc_782723477918_item	2872133	et	4	main
raskused	doc_782723477918_item	2872140	et	4	main
ja	doc_782723477918_item	2872141	et	3	main
parem	doc_785467701573_item	2872147	et	4	main
kui	doc_785467701573_item	2872148	et	3	main
on	doc_785467701573_item	2872156	et	4	main
aru	doc_785467701573_item	2872161	et	4	main
mõnikord	doc_785467701573_item	2872165	et	3	main
ei	doc_785467701573_item	2872172	et	4	main
näiteks	doc_785467701573_item	2872175	et	4	main
kui	doc_785467701573_item	2872176	et	3	main
sakslased	doc_785467701573_item	2872177	et	3	main
inglise	doc_785467701573_item	2872179	et	4	main
aga	doc_785467701573_item	2872181	et	3	main
räägin	doc_785467701573_item	2872205	et	3	main
abivalmis	doc_785467701573_item	2872211	et	3	main
kuulavad	doc_785467701573_item	2872215	et	4	main
mind	doc_785467701573_item	2872216	et	4	main
kui	doc_785467701573_item	2872217	et	3	main
räägin	doc_785467701573_item	2872218	et	3	main
eesti	doc_785467701573_item	2872219	et	4	main
eestlanna	doc_785467701573_item	2872227	et	4	main
siis	doc_785467701573_item	2872228	et	3	main
lootust	doc_785467701573_item	2872232	et	4	main
et	doc_785467701573_item	2872233	et	3	main
ma	doc_785467701573_item	2872234	et	3	main
räägiksin	doc_785467701573_item	2872235	et	3	main
väga	doc_785467701573_item	2872236	et	3	main
hästi	doc_785467701573_item	2872237	et	3	main
ja	doc_785467701573_item	2872238	et	3	main
võib-olla	doc_785467701573_item	2872239	et	3	main
keegi	doc_785467701573_item	2872254	et	4	main
asub	doc_785467701573_item	2872255	et	3	main
kunagi	doc_785467701573_item	2872261	et	3	main
andsid	doc_782723477918_item	2871941	et	4	main
sai	doc_782723477918_item	2871957	et	4	main
paranesid	doc_782723477918_item	2871959	et	4	main
haridustingimused	doc_782723477918_item	2871960	et	3	main
tekis	doc_782723477918_item	2871961	et	3	main
ilmus	doc_782723477918_item	2871964	et	4	main
palju	doc_782723477918_item	2871965	et	4	main
kirjanduselu	doc_782723477918_item	2871969	et	4	main
hakkas	doc_782723477918_item	2871970	et	3	main
kiiresti	doc_782723477918_item	2871971	et	3	main
munderi	doc_782723477918_item	2871987	et	3	main
ka	doc_782723477918_item	2871991	et	3	main
aeg	doc_782723477918_item	2872004	et	3	main
hakati	doc_782723477918_item	2872013	et	3	main
ei	doc_782723477918_item	2872018	et	4	main
ajalehed	doc_782723477918_item	2872023	et	3	main
tõi	doc_782723477918_item	2872027	et	3	main
sõja	doc_782723477918_item	2872032	et	3	main
eesti	doc_782723477918_item	2872033	et	4	main
talupoegadet	doc_782723477918_item	2872034	et	4	main
võeti	doc_782723477918_item	2872035	et	3	main
tehti	doc_782723477918_item	2872045	et	3	main
küüditamine	doc_782723477918_item	2872049	et	4	main
küüditatuid	doc_782723477918_item	2872051	et	4	main
eestlaste	doc_782723477918_item	2872076	et	4	main
rahvas	doc_782723477918_item	2872085	et	4	main
ise	doc_782723477918_item	2872088	et	4	main
maast	doc_782723477918_item	2872129	et	3	main
kes	doc_782723477918_item	2872130	et	4	main
olid	doc_782723477918_item	2872131	et	4	main
raskesti	doc_782723477918_item	2872132	et	3	main
olid	doc_782723477918_item	2872138	et	4	main
suured	doc_782723477918_item	2872139	et	3	main
on	doc_785467701573_item	2872146	et	4	main
või	doc_785467701573_item	2872153	et	4	main
aktsendita	doc_785467701573_item	2872154	et	3	main
minule	doc_785467701573_item	2872155	et	3	main
saavad	doc_785467701573_item	2872160	et	4	main
rääkija	doc_785467701573_item	2872163	et	4	main
räägib	doc_785467701573_item	2872164	et	3	main
võõrkeele	doc_785467701573_item	2872166	et	4	main
rääkijadel	doc_785467701573_item	2872167	et	4	main
aktsendiga	doc_785467701573_item	2872207	et	3	main
kui	doc_785467701573_item	2872212	et	3	main
nad	doc_785467701573_item	2872221	et	3	main
neil	doc_785467701573_item	2872229	et	4	main
nad	doc_785467701573_item	2872240	et	3	main
räägi	doc_785467701573_item	2872248	et	4	main
üldse	doc_785467701573_item	2872249	et	3	main
ma	doc_785467701573_item	2872250	et	3	main
arvan	doc_785467701573_item	2872251	et	3	main
kui	doc_785467701573_item	2872253	et	3	main
ühel	doc_785467701573_item	2872257	et	3	main
hakkab	doc_785467701573_item	2872260	et	3	main
teised	doc_785467701573_item	2872267	et	4	main
ei	doc_785467701573_item	2872269	et	4	main
ta	doc_785467701573_item	2872273	et	4	main
on	doc_785467701573_item	2872274	et	4	main
välismaalane	doc_785467701573_item	2872275	et	3	main
või	doc_785467701573_item	2872276	et	4	main
kas	doc_785467701573_item	2872283	et	3	main
parem	doc_785467701573_item	2872285	et	4	main
rääkida	doc_785467701573_item	2872286	et	3	main
mu	doc_785467701573_item	2872301	et	3	main
on	doc_785467701573_item	2872304	et	4	main
loodetavasti	doc_785467701573_item	2872322	et	3	main
kuidas	doc_785467701573_item	2872328	et	3	main
üldse	doc_785467701573_item	2872333	et	3	main
kuigi	doc_785467701573_item	2872336	et	3	main
et	doc_785467701573_item	2872338	et	3	main
õpetaja	doc_785467701573_item	2872344	et	4	main
parandab	doc_785467701573_item	2872345	et	3	main
mind	doc_785467701573_item	2872346	et	4	main
vana	doc_786864950071_item	2872371	et	4	main
ta	doc_786864950071_item	2872372	et	4	main
on	doc_786864950071_item	2872373	et	4	main
ta	doc_786864950071_item	2872381	et	4	main
ta	doc_786864950071_item	2872386	et	4	main
isa	doc_786864950071_item	2872387	et	4	main
ole	doc_786864950071_item	2872389	et	4	main
eestlane	doc_786864950071_item	2872390	et	3	main
ta	doc_786864950071_item	2872391	et	4	main
ka	doc_782723477918_item	2871984	et	3	main
nt	doc_782723477918_item	2871986	et	4	main
arenema	doc_782723477918_item	2871990	et	3	main
trükiti	doc_782723477918_item	2871993	et	3	main
teadusraamatud	doc_782723477918_item	2872002	et	4	main
eesti	doc_782723477918_item	2872005	et	4	main
vene	doc_782723477918_item	2872010	et	4	main
raamatud	doc_782723477918_item	2872016	et	4	main
mis	doc_782723477918_item	2872017	et	4	main
ja	doc_782723477918_item	2872021	et	3	main
pärastsõjajärgne	doc_782723477918_item	2872025	et	3	main
kollektiviseerimine	doc_782723477918_item	2872026	et	4	main
maal	doc_782723477918_item	2872044	et	4	main
massiline	doc_782723477918_item	2872048	et	4	main
lapsed	doc_782723477918_item	2872054	et	3	main
naised	doc_782723477918_item	2872055	et	3	main
vanad	doc_782723477918_item	2872057	et	3	main
niisugusel	doc_782723477918_item	2872059	et	3	main
maad	doc_782723477918_item	2872062	et	4	main
inimesed	doc_782723477918_item	2872063	et	3	main
liituma	doc_782723477918_item	2872069	et	4	main
kolhoosi	doc_782723477918_item	2872070	et	4	main
juurde	doc_782723477918_item	2872071	et	4	main
3	doc_782723477918_item	2872072	et	2	main
teine	doc_782723477918_item	2872073	et	3	main
nõukogude	doc_782723477918_item	2872080	et	3	main
liidu	doc_782723477918_item	2872081	et	3	main
valitsuse	doc_782723477918_item	2872082	et	4	main
all	doc_782723477918_item	2872083	et	3	main
eesti	doc_782723477918_item	2872084	et	4	main
küüditamine	doc_782723477918_item	2872124	et	4	main
üks	doc_782723477918_item	2872127	et	3	main
ii	doc_782723477918_item	2872134	et	4	main
maailmasõjal	doc_782723477918_item	2872135	et	3	main
ja	doc_782723477918_item	2872136	et	3	main
kellel	doc_782723477918_item	2872137	et	4	main
kannatused	doc_782723477918_item	2872142	et	4	main
vastus	doc_785467701573_item	2872143	et	3	main
küsimusele	doc_785467701573_item	2872144	et	4	main
kas	doc_785467701573_item	2872145	et	3	main
tähtis	doc_785467701573_item	2872157	et	4	main
et	doc_785467701573_item	2872158	et	3	main
millest	doc_785467701573_item	2872162	et	3	main
mis	doc_785467701573_item	2872171	et	4	main
olla	doc_785467701573_item	2872209	et	3	main
keelt	doc_785467701573_item	2872220	et	4	main
väga	doc_782723477918_item	2871995	et	3	main
palju	doc_782723477918_item	2871996	et	4	main
oli	doc_782723477918_item	2872003	et	3	main
ajaloos	doc_782723477918_item	2872006	et	4	main
millal	doc_782723477918_item	2872007	et	3	main
siin	doc_782723477918_item	2872008	et	4	main
oli	doc_782723477918_item	2872009	et	3	main
eesti	doc_782723477918_item	2872015	et	4	main
meeldinud	doc_782723477918_item	2872019	et	4	main
2	doc_782723477918_item	2872024	et	2	main
pärast	doc_782723477918_item	2872031	et	4	main
maad	doc_782723477918_item	2872037	et	4	main
kui	doc_782723477918_item	2872038	et	3	main
nad	doc_782723477918_item	2872039	et	3	main
ületasid	doc_782723477918_item	2872040	et	4	main
30	doc_782723477918_item	2872041	et	2	main
ha	doc_782723477918_item	2872042	et	4	main
sovhoose	doc_782723477918_item	2872046	et	3	main
kus	doc_782723477918_item	2872050	et	3	main
olid	doc_782723477918_item	2872052	et	4	main
ja	doc_782723477918_item	2872056	et	3	main
vabatahtlikult	doc_782723477918_item	2872068	et	4	main
mitu	doc_782723477918_item	2872078	et	4	main
aastat	doc_782723477918_item	2872079	et	3	main
tahtsid	doc_782723477918_item	2872093	et	4	main
olla	doc_782723477918_item	2872094	et	3	main
vabad	doc_782723477918_item	2872095	et	3	main
ja	doc_782723477918_item	2872096	et	3	main
omama	doc_782723477918_item	2872097	et	4	main
oma	doc_782723477918_item	2872098	et	4	main
talud	doc_782723477918_item	2872099	et	4	main
maad	doc_782723477918_item	2872100	et	4	main
seda	doc_782723477918_item	2872101	et	3	main
nendel	doc_782723477918_item	2872102	et	4	main
ei	doc_782723477918_item	2872103	et	4	main
olnud	doc_782723477918_item	2872104	et	4	main
ii	doc_782723477918_item	2872105	et	4	main
maailmasõja	doc_782723477918_item	2872106	et	3	main
pärast	doc_782723477918_item	2872107	et	4	main
eesti	doc_782723477918_item	2872108	et	4	main
majandus	doc_782723477918_item	2872109	et	4	main
ja	doc_782723477918_item	2872110	et	3	main
kultuur	doc_782723477918_item	2872111	et	3	main
ei	doc_782723477918_item	2872112	et	4	main
arenenud	doc_782723477918_item	2872113	et	4	main
maad	doc_782723477918_item	2872114	et	4	main
olid	doc_782723477918_item	2872115	et	4	main
laostanud	doc_782723477918_item	2872116	et	4	main
eesti	doc_782723477918_item	2872117	et	4	main
kaotas	doc_782723477918_item	2872118	et	3	main
veerandi	doc_782723477918_item	2872119	et	4	main
oma	doc_782723477918_item	2872120	et	4	main
maailmasõda	doc_782723477918_item	2872074	et	4	main
tähendas	doc_782723477918_item	2872075	et	3	main
harjunud	doc_782723477918_item	2872087	et	4	main
oma	doc_782723477918_item	2872090	et	4	main
saatuse	doc_782723477918_item	2872091	et	3	main
nad	doc_782723477918_item	2872092	et	3	main
elanikust	doc_782723477918_item	2872121	et	3	main
toimus	doc_782723477918_item	2872122	et	3	main
eesti	doc_782723477918_item	2872125	et	4	main
oli	doc_782723477918_item	2872126	et	3	main
sellist	doc_782723477918_item	2872128	et	4	main
keegi	doc_785467701573_item	2872149	et	4	main
räägib	doc_785467701573_item	2872150	et	3	main
võõrkeelt	doc_785467701573_item	2872151	et	4	main
aktsendiga	doc_785467701573_item	2872152	et	3	main
kuulajad	doc_785467701573_item	2872159	et	4	main
on	doc_785467701573_item	2872168	et	4	main
imelik	doc_785467701573_item	2872169	et	3	main
aktsent	doc_785467701573_item	2872170	et	3	main
kuuldu	doc_785467701573_item	2872173	et	4	main
hästi	doc_785467701573_item	2872174	et	3	main
räägivad	doc_785467701573_item	2872178	et	3	main
keelt	doc_785467701573_item	2872180	et	4	main
kui	doc_785467701573_item	2872182	et	3	main
rääkija	doc_785467701573_item	2872183	et	4	main
räägib	doc_785467701573_item	2872184	et	3	main
selgesti	doc_785467701573_item	2872185	et	3	main
see	doc_785467701573_item	2872186	et	3	main
on	doc_785467701573_item	2872187	et	4	main
ükskõik	doc_785467701573_item	2872188	et	3	main
kas	doc_785467701573_item	2872189	et	3	main
ta	doc_785467701573_item	2872190	et	4	main
räägib	doc_785467701573_item	2872191	et	3	main
aktsendiga	doc_785467701573_item	2872192	et	3	main
või	doc_785467701573_item	2872193	et	4	main
aktsendita	doc_785467701573_item	2872194	et	3	main
ma	doc_785467701573_item	2872195	et	3	main
ise	doc_785467701573_item	2872196	et	4	main
ainult	doc_785467701573_item	2872197	et	4	main
tahan	doc_785467701573_item	2872198	et	3	main
rääkida	doc_785467701573_item	2872199	et	3	main
aktsendita	doc_785467701573_item	2872200	et	3	main
aga	doc_785467701573_item	2872201	et	3	main
kõva	doc_785467701573_item	2872206	et	4	main
ka	doc_785467701573_item	2872210	et	3	main
eestlased	doc_785467701573_item	2872214	et	3	main
teavad	doc_785467701573_item	2872222	et	3	main
et	doc_785467701573_item	2872223	et	3	main
ma	doc_785467701573_item	2872224	et	3	main
ei	doc_785467701573_item	2872225	et	4	main
ei	doc_785467701573_item	2872230	et	4	main
räägivad	doc_785467701573_item	2872242	et	3	main
pikaldaselt	doc_785467701573_item	2872244	et	4	main
et	doc_785467701573_item	2872252	et	3	main
maal	doc_785467701573_item	2872258	et	4	main
rääkida	doc_785467701573_item	2872262	et	3	main
ja	doc_785467701573_item	2872265	et	3	main
öelda	doc_785467701573_item	2872271	et	4	main
kas	doc_785467701573_item	2872272	et	3	main
aktsendiga	doc_785467701573_item	2872287	et	3	main
aktsendita	doc_785467701573_item	2872289	et	3	main
aktsent	doc_785467701573_item	2872291	et	3	main
ka	doc_785467701573_item	2872293	et	3	main
meeldiv	doc_785467701573_item	2872294	et	4	main
kas	doc_785467701573_item	2872295	et	3	main
küll	doc_785467701573_item	2872305	et	4	main
hea	doc_785467701573_item	2872306	et	4	main
ja	doc_785467701573_item	2872307	et	3	main
on	doc_785467701573_item	2872308	et	4	main
ka	doc_785467701573_item	2872309	et	3	main
hea	doc_785467701573_item	2872310	et	4	main
kui	doc_785467701573_item	2872311	et	3	main
keegi	doc_785467701573_item	2872312	et	4	main
parandab	doc_785467701573_item	2872313	et	3	main
tihti	doc_785467701573_item	2872314	et	3	main
ja	doc_785467701573_item	2872315	et	3	main
kohe	doc_785467701573_item	2872316	et	4	main
viga	doc_785467701573_item	2872318	et	4	main
pärast	doc_785467701573_item	2872317	et	4	main
niimoodi	doc_785467701573_item	2872319	et	3	main
õpilane	doc_785467701573_item	2872320	et	3	main
õpib	doc_785467701573_item	2872321	et	3	main
keelt	doc_785467701573_item	2872332	et	4	main
on	doc_785467701573_item	2872340	et	4	main
mulle	doc_785467701573_item	2872342	et	4	main
kui	doc_785467701573_item	2872343	et	3	main
10	doc_786864950071_item	2872351	et	2	main
on	doc_786864950071_item	2872368	et	4	main
kolm	doc_786864950071_item	2872369	et	3	main
kadri	doc_786864950071_item	2872377	et	4	main
eestlane	doc_786864950071_item	2872380	et	3	main
sakslane	doc_786864950071_item	2872393	et	3	main
sellepärast	doc_786864950071_item	2872394	et	3	main
ja	doc_786864950071_item	2872396	et	3	main
kui	doc_786864950071_item	2872407	et	3	main
väike	doc_786864950071_item	2872416	et	4	main
fakt	doc_785467701573_item	2872202	et	3	main
et	doc_785467701573_item	2872203	et	3	main
ma	doc_785467701573_item	2872204	et	3	main
võib	doc_785467701573_item	2872208	et	3	main
näiteks	doc_785467701573_item	2872213	et	4	main
ole	doc_785467701573_item	2872226	et	4	main
ole	doc_785467701573_item	2872231	et	4	main
ise	doc_785467701573_item	2872241	et	4	main
minule	doc_785467701573_item	2872243	et	3	main
või	doc_785467701573_item	2872245	et	4	main
nad	doc_785467701573_item	2872246	et	3	main
ei	doc_785467701573_item	2872247	et	4	main
kaua	doc_785467701573_item	2872256	et	3	main
ta	doc_785467701573_item	2872259	et	4	main
vähem	doc_785467701573_item	2872263	et	4	main
inimesed	doc_785467701573_item	2872268	et	3	main
või	doc_785467701573_item	2872280	et	4	main
tõesti	doc_785467701573_item	2872281	et	3	main
õelda	doc_785467701573_item	2872282	et	4	main
ma	doc_785467701573_item	2872324	et	3	main
tõesti	doc_785467701573_item	2872325	et	3	main
ma	doc_785467701573_item	2872335	et	3	main
hea	doc_785467701573_item	2872341	et	4	main
tihti	doc_785467701573_item	2872347	et	3	main
uus	doc_786864950071_item	2872348	et	3	main
dokument	doc_786864950071_item	2872349	et	3	main
kirjuta	doc_786864950071_item	2872350	et	4	main
pildi	doc_786864950071_item	2872353	et	4	main
see	doc_786864950071_item	2872355	et	3	main
on	doc_786864950071_item	2872356	et	4	main
sünndinud	doc_786864950071_item	2872374	et	4	main
2001	doc_786864950071_item	2872375	et	2	main
aastas	doc_786864950071_item	2872376	et	3	main
ema	doc_786864950071_item	2872378	et	4	main
on	doc_786864950071_item	2872383	et	4	main
ema	doc_786864950071_item	2872398	et	4	main
elavad	doc_786864950071_item	2872399	et	4	main
ükses	doc_786864950071_item	2872400	et	3	main
võib	doc_786864950071_item	2872401	et	3	main
olla	doc_786864950071_item	2872402	et	3	main
et	doc_786864950071_item	2872403	et	3	main
kadril	doc_786864950071_item	2872404	et	3	main
tõnu	doc_786864950071_item	2872411	et	4	main
naist	doc_786864950071_item	2872412	et	3	main
võtab	doc_786864950071_item	2872413	et	3	main
elavad	doc_786864950071_item	2872418	et	4	main
ema	doc_786864950071_item	2872421	et	4	main
kadri	doc_786864950071_item	2872424	et	4	main
käima	doc_786864950071_item	2872428	et	4	main
kodus	doc_786864950071_item	2872432	et	4	main
kui	doc_786864950071_item	2872433	et	3	main
kadri	doc_786864950071_item	2872437	et	4	main
või	doc_785467701573_item	2872270	et	4	main
ei	doc_785467701573_item	2872279	et	4	main
on	doc_785467701573_item	2872284	et	4	main
rääkijat	doc_785467701573_item	2872298	et	4	main
parandada	doc_785467701573_item	2872299	et	3	main
jah	doc_785467701573_item	2872300	et	3	main
meelest	doc_785467701573_item	2872302	et	4	main
see	doc_785467701573_item	2872303	et	3	main
väike	doc_786864950071_item	2872357	et	4	main
laps	doc_786864950071_item	2872358	et	4	main
ta	doc_786864950071_item	2872359	et	4	main
nime	doc_786864950071_item	2872360	et	4	main
on	doc_786864950071_item	2872361	et	4	main
kadri	doc_786864950071_item	2872362	et	4	main
sellepärast	doc_786864950071_item	2872363	et	3	main
ta	doc_786864950071_item	2872364	et	4	main
on	doc_786864950071_item	2872365	et	4	main
tüdruk	doc_786864950071_item	2872366	et	3	main
kadri	doc_786864950071_item	2872367	et	4	main
aksendiga	doc_785467701573_item	2872264	et	4	main
siis	doc_785467701573_item	2872266	et	3	main
ei	doc_785467701573_item	2872277	et	4	main
ma	doc_785467701573_item	2872278	et	3	main
või	doc_785467701573_item	2872288	et	4	main
mõnikord	doc_785467701573_item	2872290	et	3	main
on	doc_785467701573_item	2872292	et	4	main
on	doc_785467701573_item	2872296	et	4	main
hea	doc_785467701573_item	2872297	et	4	main
kiiresti	doc_785467701573_item	2872323	et	3	main
tunnen	doc_785467701573_item	2872326	et	3	main
ise	doc_785467701573_item	2872327	et	4	main
ma	doc_785467701573_item	2872329	et	3	main
ei	doc_785467701573_item	2872330	et	4	main
räägi	doc_785467701573_item	2872331	et	4	main
aga	doc_785467701573_item	2872334	et	3	main
tean	doc_785467701573_item	2872337	et	3	main
see	doc_785467701573_item	2872339	et	3	main
lauset	doc_786864950071_item	2872352	et	3	main
kohta	doc_786864950071_item	2872354	et	4	main
aastat	doc_786864950071_item	2872370	et	3	main
on	doc_786864950071_item	2872379	et	4	main
perekonnanimi	doc_786864950071_item	2872382	et	3	main
aga	doc_786864950071_item	2872385	et	3	main
on	doc_786864950071_item	2872392	et	4	main
kadri	doc_786864950071_item	2872395	et	4	main
isa	doc_786864950071_item	2872406	et	4	main
ta	doc_786864950071_item	2872408	et	4	main
ema	doc_786864950071_item	2872409	et	4	main
sõber	doc_786864950071_item	2872410	et	3	main
kadri	doc_786864950071_item	2872420	et	4	main
aga	doc_786864950071_item	2872423	et	3	main
ei	doc_786864950071_item	2872425	et	4	main
ta	doc_786864950071_item	2872429	et	4	main
on	doc_786864950071_item	2872435	et	4	main
on	doc_786864950071_item	2872438	et	4	main
laps	doc_786864950071_item	2872440	et	4	main
lõpik	doc_786864950071_item	2872384	et	3	main
ei	doc_786864950071_item	2872388	et	4	main
ta	doc_786864950071_item	2872397	et	4	main
tartus	doc_786864950071_item	2872419	et	3	main
pea	doc_786864950071_item	2872426	et	4	main
vanaema	doc_786864950071_item	2872430	et	4	main
ema	doc_786864950071_item	2872434	et	4	main
tööl	doc_786864950071_item	2872436	et	3	main
ilus	doc_786864950071_item	2872439	et	4	main
on	doc_786864950071_item	2872405	et	4	main
teda	doc_786864950071_item	2872414	et	4	main
see	doc_786864950071_item	2872415	et	3	main
perekond	doc_786864950071_item	2872417	et	3	main
töötab	doc_786864950071_item	2872422	et	3	main
lasteaias	doc_786864950071_item	2872427	et	4	main
on	doc_786864950071_item	2872431	et	4	main
ei	doc_78691914849_item	2874158	et	4	main
ole	doc_78691914849_item	2874159	et	4	main
on	doc_78691914849_item	2874165	et	4	main
pead	doc_78691914849_item	2874173	et	4	main
näidata	doc_78691914849_item	2874185	et	4	main
head	doc_78691914849_item	2874187	et	4	main
on	doc_78691914849_item	2874190	et	4	main
cv	doc_78691914849_item	2874193	et	4	main
õige	doc_78691914849_item	2874204	et	4	main
mul	doc_78691914849_item	2874205	et	3	main
pole	doc_78691914849_item	2874206	et	3	main
selleks	doc_78691914849_item	2874207	et	4	main
midagi	doc_78691914849_item	2874208	et	4	main
on	doc_78691914849_item	2874222	et	4	main
on	doc_78691914849_item	2874229	et	4	main
riietus	doc_78691914849_item	2874232	et	4	main
tööd	doc_78691914849_item	2874237	et	4	main
leida	doc_78691914849_item	2874238	et	3	main
õige	doc_78691914849_item	2874242	et	4	main
ette	doc_78691914849_item	2874244	et	4	main
mustas	doc_78691914849_item	2874255	et	4	main
või	doc_78691914849_item	2874257	et	4	main
teda	doc_78691914849_item	2874264	et	4	main
tööle	doc_78691914849_item	2874265	et	3	main
ma	doc_78691914849_item	2874272	et	3	main
ja	doc_78691914849_item	2874275	et	3	main
mõned	doc_78691914849_item	2874313	et	3	main
ole	doc_78691914849_item	2874316	et	4	main
proffesionaalid	doc_78691914849_item	2874317	et	4	main
mille	doc_78691914849_item	2874318	et	3	main
erineb	doc_78691914849_item	2874325	et	3	main
ainult	doc_78691914849_item	2874326	et	4	main
sellega	doc_78691914849_item	2874327	et	3	main
et	doc_78691914849_item	2874328	et	3	main
aga	doc_78691914849_item	2874332	et	3	main
sina	doc_78691914849_item	2874334	et	4	main
ise	doc_78691914849_item	2874335	et	4	main
ole	doc_78691914849_item	2874339	et	4	main
klassijuhatajaid	doc_78691914849_item	2874340	et	3	main
riski	doc_78691914849_item	2874350	et	4	main
inimene	doc_78691914849_item	2874351	et	3	main
peab	doc_78691914849_item	2874352	et	4	main
oma	doc_78691914849_item	2874360	et	4	main
ei	doc_78691914849_item	2874365	et	4	main
sellega	doc_78691914849_item	2874160	et	3	main
nõus	doc_78691914849_item	2874161	et	4	main
see	doc_78691914849_item	2874164	et	3	main
väga	doc_78691914849_item	2874166	et	3	main
hästi	doc_78691914849_item	2874174	et	3	main
proovid	doc_78691914849_item	2874184	et	4	main
asjad	doc_78691914849_item	2874188	et	3	main
sees	doc_78691914849_item	2874192	et	4	main
siis	doc_78691914849_item	2874221	et	3	main
mis	doc_78691914849_item	2874228	et	4	main
välimus	doc_78691914849_item	2874235	et	3	main
see	doc_78691914849_item	2874240	et	3	main
tööd	doc_78691914849_item	2874248	et	4	main
tööintervjuuks	doc_78691914849_item	2874153	et	3	main
pole	doc_78691914849_item	2874154	et	3	main
vaja	doc_78691914849_item	2874155	et	4	main
valmistuda	doc_78691914849_item	2874156	et	3	main
ma	doc_78691914849_item	2874157	et	3	main
sellepärast	doc_78691914849_item	2874162	et	3	main
et	doc_78691914849_item	2874163	et	3	main
oluline	doc_78691914849_item	2874167	et	4	main
olla	doc_78691914849_item	2874168	et	3	main
valmis	doc_78691914849_item	2874169	et	4	main
tööintervjuuks	doc_78691914849_item	2874170	et	3	main
esiteks	doc_78691914849_item	2874171	et	3	main
sa	doc_78691914849_item	2874172	et	3	main
välja	doc_78691914849_item	2874175	et	4	main
näha	doc_78691914849_item	2874176	et	3	main
teiseks	doc_78691914849_item	2874177	et	4	main
pead	doc_78691914849_item	2874178	et	4	main
olla	doc_78691914849_item	2874179	et	3	main
heas	doc_78691914849_item	2874180	et	3	main
tujus	doc_78691914849_item	2874181	et	3	main
kolmas	doc_78691914849_item	2874182	et	3	main
sa	doc_78691914849_item	2874183	et	3	main
mis	doc_78691914849_item	2874189	et	4	main
avaldus	doc_78691914849_item	2874195	et	4	main
olema	doc_78691914849_item	2874197	et	4	main
lühikesed	doc_78691914849_item	2874198	et	4	main
ja	doc_78691914849_item	2874199	et	3	main
lakoonilised	doc_78691914849_item	2874200	et	3	main
see	doc_78691914849_item	2874201	et	3	main
on	doc_78691914849_item	2874202	et	4	main
täitsa	doc_78691914849_item	2874203	et	3	main
sest	doc_78691914849_item	2874210	et	4	main
et	doc_78691914849_item	2874211	et	3	main
see	doc_78691914849_item	2874212	et	3	main
parem	doc_78691914849_item	2874223	et	4	main
kui	doc_78691914849_item	2874224	et	3	main
kirjutad	doc_78691914849_item	2874225	et	3	main
ainult	doc_78691914849_item	2874226	et	4	main
see	doc_78691914849_item	2874227	et	3	main
sobiv	doc_78691914849_item	2874231	et	4	main
hea	doc_78691914849_item	2874234	et	4	main
on	doc_78691914849_item	2874241	et	4	main
et	doc_78691914849_item	2874245	et	3	main
otsib	doc_78691914849_item	2874247	et	3	main
ja	doc_78691914849_item	2874251	et	3	main
tuleb	doc_78691914849_item	2874253	et	3	main
juustega	doc_78691914849_item	2874259	et	3	main
keegi	doc_78691914849_item	2874261	et	4	main
võta	doc_78691914849_item	2874263	et	4	main
kontrolltöö	doc_78691914849_item	2874152	et	4	main
ainult	doc_78691914849_item	2874186	et	4	main
sinu	doc_78691914849_item	2874191	et	3	main
ja	doc_78691914849_item	2874194	et	3	main
peavad	doc_78691914849_item	2874196	et	4	main
öelda	doc_78691914849_item	2874209	et	4	main
on	doc_78691914849_item	2874214	et	4	main
tõde	doc_78691914849_item	2874215	et	4	main
tõeliselt	doc_78691914849_item	2874216	et	4	main
kui	doc_78691914849_item	2874217	et	3	main
sa	doc_78691914849_item	2874218	et	3	main
iseennast	doc_78691914849_item	2874219	et	3	main
kirjutad	doc_78691914849_item	2874220	et	3	main
väide	doc_78691914849_item	2874213	et	4	main
vaja	doc_78691914849_item	2874230	et	4	main
ja	doc_78691914849_item	2874233	et	3	main
aitavad	doc_78691914849_item	2874236	et	4	main
muidugi	doc_78691914849_item	2874239	et	4	main
kujutage	doc_78691914849_item	2874243	et	3	main
keegi	doc_78691914849_item	2874246	et	4	main
mustaga	doc_78691914849_item	2874258	et	3	main
palju	doc_78691914849_item	2874269	et	4	main
ole	doc_78691914849_item	2874277	et	4	main
nõus	doc_78691914849_item	2874278	et	4	main
ühel	doc_78691914849_item	2874279	et	3	main
ajal	doc_78691914849_item	2874280	et	4	main
on	doc_78691914849_item	2874281	et	4	main
vaja	doc_78691914849_item	2874282	et	4	main
palju	doc_78691914849_item	2874283	et	4	main
rääkima	doc_78691914849_item	2874284	et	3	main
ainult	doc_78691914849_item	2874285	et	4	main
siis	doc_78691914849_item	2874286	et	3	main
kui	doc_78691914849_item	2874287	et	3	main
sind	doc_78691914849_item	2874288	et	4	main
küsitatakse	doc_78691914849_item	2874289	et	3	main
ja	doc_78691914849_item	2874290	et	3	main
ainult	doc_78691914849_item	2874291	et	4	main
see	doc_78691914849_item	2874292	et	3	main
mis	doc_78691914849_item	2874293	et	4	main
on	doc_78691914849_item	2874294	et	4	main
vaja	doc_78691914849_item	2874295	et	4	main
mis	doc_78691914849_item	2874296	et	4	main
on	doc_78691914849_item	2874297	et	4	main
praegu	doc_78691914849_item	2874298	et	3	main
koolis	doc_78691914849_item	2874299	et	4	main
kõige	doc_78691914849_item	2874300	et	4	main
suuremad	doc_78691914849_item	2874301	et	4	main
probleemid	doc_78691914849_item	2874302	et	3	main
liiga	doc_78691914849_item	2874303	et	4	main
suur	doc_78691914849_item	2874304	et	3	main
õppeprogramm	doc_78691914849_item	2874305	et	3	main
õpilased	doc_78691914849_item	2874306	et	3	main
lihtsalt	doc_78691914849_item	2874307	et	4	main
ei	doc_78691914849_item	2874308	et	4	main
ei	doc_78691914849_item	2874315	et	4	main
näiteks	doc_78691914849_item	2874249	et	4	main
kindlalt	doc_78691914849_item	2874260	et	4	main
ei	doc_78691914849_item	2874262	et	4	main
tööintervjuul	doc_78691914849_item	2874266	et	3	main
sellega	doc_78691914849_item	2874271	et	3	main
vaheajad	doc_78691914849_item	2874312	et	3	main
kooli	doc_78691914849_item	2874329	et	4	main
õppid	doc_78691914849_item	2874336	et	4	main
mida	doc_78691914849_item	2874341	et	4	main
kuriteo	doc_78691914849_item	2874347	et	4	main
sattumise	doc_78691914849_item	2874349	et	4	main
peame	doc_78691914849_item	2874359	et	4	main
nad	doc_78691914849_item	2874364	et	3	main
midagi	doc_78691914849_item	2874367	et	4	main
ohtliku	doc_78691914849_item	2874368	et	3	main
ja	doc_78691914849_item	2874369	et	3	main
arvan	doc_78691914849_item	2874370	et	3	main
et	doc_78691914849_item	2874371	et	3	main
koolis	doc_78691914849_item	2874372	et	4	main
peab	doc_78691914849_item	2874373	et	4	main
olema	doc_78691914849_item	2874374	et	4	main
uus	doc_78691914849_item	2874375	et	3	main
aine	doc_78691914849_item	2874376	et	4	main
kuidas	doc_78691914849_item	2874377	et	3	main
ei	doc_78691914849_item	2874378	et	4	main
saa	doc_78691914849_item	2874379	et	4	main
käituma	doc_78691914849_item	2874380	et	3	main
inimesed	doc_78691914849_item	2874381	et	3	main
ei	doc_78691914849_item	2874382	et	4	main
pea	doc_78691914849_item	2874383	et	4	main
jalutama	doc_78691914849_item	2874385	et	3	main
öösel	doc_78691914849_item	2874384	et	4	main
modellina	doc_78691914849_item	2874250	et	3	main
siis	doc_78691914849_item	2874252	et	3	main
tööintervjuule	doc_78691914849_item	2874254	et	3	main
särgis	doc_78691914849_item	2874256	et	3	main
peaks	doc_78691914849_item	2874267	et	4	main
endast	doc_78691914849_item	2874268	et	4	main
olen	doc_78691914849_item	2874273	et	3	main
nõus	doc_78691914849_item	2874274	et	4	main
poolest	doc_78691914849_item	2874319	et	4	main
erineb	doc_78691914849_item	2874320	et	3	main
rääkima	doc_78691914849_item	2874270	et	3	main
ei	doc_78691914849_item	2874276	et	4	main
jõua	doc_78691914849_item	2874309	et	4	main
sellega	doc_78691914849_item	2874310	et	3	main
õpetajad	doc_78691914849_item	2874314	et	4	main
õppimine	doc_78691914849_item	2874321	et	4	main
õppimisest	doc_78691914849_item	2874323	et	4	main
koolis	doc_78691914849_item	2874324	et	4	main
õppetati	doc_78691914849_item	2874331	et	3	main
kõrgkoolis	doc_78691914849_item	2874337	et	4	main
peaks	doc_78691914849_item	2874342	et	4	main
inimene	doc_78691914849_item	2874343	et	3	main
tegema	doc_78691914849_item	2874344	et	3	main
et	doc_78691914849_item	2874345	et	3	main
ohvriks	doc_78691914849_item	2874348	et	3	main
olema	doc_78691914849_item	2874353	et	4	main
heategijana	doc_78691914849_item	2874354	et	3	main
lapsi	doc_78691914849_item	2874361	et	4	main
vältima	doc_78691914849_item	2874362	et	3	main
teinud	doc_78691914849_item	2874366	et	4	main
väikesed	doc_78691914849_item	2874387	et	4	main
lapsed	doc_78691914849_item	2874388	et	3	main
ka	doc_78691914849_item	2874389	et	3	main
aga	doc_78691914849_item	2874390	et	3	main
kui	doc_78691914849_item	2874391	et	3	main
minna	doc_78691914849_item	2874397	et	3	main
intervjueerija	doc_78691914850_item	2874418	et	4	main
küsis	doc_78691914850_item	2874419	et	3	main
lühikesed	doc_78691914849_item	2874311	et	4	main
kõrgkoolis	doc_78691914849_item	2874322	et	4	main
sind	doc_78691914849_item	2874330	et	4	main
kõrgkoolis	doc_78691914849_item	2874333	et	4	main
ei	doc_78691914849_item	2874338	et	4	main
vähendada	doc_78691914849_item	2874346	et	3	main
aga	doc_78691914849_item	2874355	et	3	main
mitte	doc_78691914849_item	2874356	et	3	main
kuritegijana	doc_78691914849_item	2874357	et	3	main
me	doc_78691914849_item	2874358	et	4	main
et	doc_78691914849_item	2874363	et	3	main
on	doc_78691914849_item	2874393	et	4	main
siis	doc_78691914849_item	2874398	et	3	main
väga	doc_78691914849_item	2874401	et	3	main
pole	doc_78691914850_item	2874405	et	3	main
valmistuda	doc_78691914850_item	2874407	et	3	main
ma	doc_78691914850_item	2874408	et	3	main
olen	doc_78691914850_item	2874409	et	3	main
nõus	doc_78691914850_item	2874410	et	4	main
mida	doc_78691914850_item	2874417	et	4	main
oma	doc_78691914850_item	2874427	et	4	main
käest	doc_78691914850_item	2874431	et	4	main
sa	doc_78691914850_item	2874437	et	3	main
olema	doc_78691914850_item	2874446	et	4	main
ja	doc_78691914850_item	2874448	et	3	main
minu	doc_78691914850_item	2874462	et	3	main
võimalusest	doc_78691914850_item	2874471	et	4	main
see	doc_78691914850_item	2874472	et	3	main
lugeda	doc_78691914850_item	2874482	et	3	main
sinu	doc_78691914850_item	2874483	et	3	main
mõtleb	doc_78691914850_item	2874526	et	3	main
välja	doc_78691914850_item	2874531	et	4	main
ta	doc_78691914850_item	2874532	et	4	main
korralik	doc_78691914850_item	2874534	et	3	main
ja	doc_78691914850_item	2874535	et	3	main
saada	doc_78691914850_item	2874540	et	4	main
ma	doc_78691914850_item	2874541	et	3	main
arvan	doc_78691914850_item	2874542	et	3	main
kui	doc_78691914850_item	2874543	et	3	main
sa	doc_78691914850_item	2874544	et	3	main
näed	doc_78691914850_item	2874545	et	3	main
hästi	doc_78691914850_item	2874546	et	3	main
välja	doc_78691914850_item	2874547	et	4	main
endast	doc_78691914850_item	2874556	et	4	main
mitte	doc_78691914850_item	2874566	et	3	main
palju	doc_78691914850_item	2874568	et	4	main
tööintervjueerija	doc_78691914850_item	2874570	et	4	main
võib	doc_78691914850_item	2874571	et	3	main
olen	doc_78691914850_item	2874575	et	3	main
sõbralik	doc_78691914850_item	2874591	et	3	main
rääkid	doc_78691914850_item	2874596	et	4	main
ei	doc_78691914850_item	2874600	et	4	main
on	doc_78691914850_item	2874609	et	4	main
väga	doc_78691914850_item	2874610	et	3	main
kõige	doc_78691914850_item	2874616	et	4	main
välja	doc_78691914849_item	2874396	et	4	main
selle	doc_78691914850_item	2874411	et	4	main
väidega	doc_78691914850_item	2874412	et	3	main
sest	doc_78691914850_item	2874413	et	4	main
sa	doc_78691914850_item	2874414	et	3	main
ei	doc_78691914850_item	2874415	et	4	main
sinu	doc_78691914850_item	2874420	et	3	main
käest	doc_78691914850_item	2874421	et	4	main
sa	doc_78691914850_item	2874422	et	3	main
mõelda	doc_78691914850_item	2874426	et	4	main
kui	doc_78691914850_item	2874429	et	3	main
midagi	doc_78691914850_item	2874432	et	4	main
cv	doc_78691914850_item	2874434	et	4	main
et	doc_78691914850_item	2874436	et	3	main
ei	doc_78691914850_item	2874438	et	4	main
raikka	doc_78691914850_item	2874439	et	4	main
avaldus	doc_78691914850_item	2874444	et	4	main
arust	doc_78691914850_item	2874463	et	4	main
et	doc_78691914850_item	2874465	et	3	main
inimene	doc_78691914850_item	2874473	et	3	main
tööle	doc_78691914850_item	2874477	et	3	main
ta	doc_78691914850_item	2874478	et	4	main
eluloo	doc_78691914850_item	2874484	et	4	main
teda	doc_78691914850_item	2874485	et	4	main
riietus	doc_78691914850_item	2874494	et	4	main
välimus	doc_78691914850_item	2874497	et	3	main
aitavad	doc_78691914850_item	2874498	et	4	main
tööd	doc_78691914850_item	2874499	et	4	main
leida	doc_78691914850_item	2874500	et	3	main
ma	doc_78691914850_item	2874501	et	3	main
arvan	doc_78691914850_item	2874502	et	3	main
et	doc_78691914850_item	2874503	et	3	main
lugupeetud	doc_78691914850_item	2874504	et	4	main
inimene	doc_78691914850_item	2874505	et	3	main
peab	doc_78691914850_item	2874506	et	4	main
kokku	doc_78691914850_item	2874507	et	3	main
aeg	doc_78691914850_item	2874508	et	3	main
hästi	doc_78691914850_item	2874509	et	3	main
välja	doc_78691914850_item	2874510	et	4	main
näha	doc_78691914850_item	2874511	et	3	main
ma	doc_78691914850_item	2874512	et	3	main
arvan	doc_78691914850_item	2874513	et	3	main
et	doc_78691914850_item	2874514	et	3	main
see	doc_78691914850_item	2874515	et	3	main
võib	doc_78691914850_item	2874516	et	3	main
aidata	doc_78691914850_item	2874517	et	4	main
sest	doc_78691914850_item	2874518	et	4	main
inimene	doc_78691914850_item	2874519	et	3	main
kes	doc_78691914850_item	2874520	et	4	main
võtab	doc_78691914850_item	2874521	et	3	main
inimene	doc_78691914850_item	2874528	et	3	main
huvitatud	doc_78691914850_item	2874537	et	4	main
see	doc_78691914850_item	2874538	et	3	main
tööd	doc_78691914850_item	2874539	et	4	main
sul	doc_78691914850_item	2874548	et	3	main
ise	doc_78691914850_item	2874550	et	4	main
mugavam	doc_78691914850_item	2874551	et	4	main
ja	doc_78691914850_item	2874552	et	3	main
palju	doc_78691914850_item	2874557	et	4	main
rääkima	doc_78691914850_item	2874558	et	3	main
ma	doc_78691914850_item	2874559	et	3	main
arvan	doc_78691914850_item	2874560	et	3	main
ja	doc_78691914849_item	2874386	et	3	main
vaja	doc_78691914849_item	2874394	et	4	main
teeme	doc_78691914849_item	2874399	et	3	main
kontrolltöö	doc_78691914850_item	2874403	et	4	main
vaja	doc_78691914850_item	2874406	et	4	main
tea	doc_78691914850_item	2874416	et	4	main
võid	doc_78691914850_item	2874423	et	4	main
läbi	doc_78691914850_item	2874425	et	4	main
sinu	doc_78691914850_item	2874430	et	3	main
aega	doc_78691914850_item	2874440	et	4	main
lakoonilised	doc_78691914850_item	2874449	et	3	main
arvan	doc_78691914850_item	2874451	et	3	main
konkretselt	doc_78691914850_item	2874457	et	4	main
pikkus	doc_78691914850_item	2874458	et	4	main
oma	doc_78691914850_item	2874470	et	4	main
ole	doc_78691914850_item	2874480	et	4	main
sind	doc_78691914850_item	2874522	et	4	main
tööle	doc_78691914850_item	2874523	et	3	main
vaatab	doc_78691914850_item	2874524	et	3	main
hästi	doc_78691914850_item	2874530	et	3	main
parem	doc_78691914850_item	2874553	et	4	main
tööintervjuul	doc_78691914850_item	2874554	et	3	main
võid	doc_78691914850_item	2874563	et	4	main
rääkida	doc_78691914850_item	2874564	et	3	main
et	doc_78691914850_item	2874573	et	3	main
inimene	doc_78691914850_item	2874577	et	3	main
sa	doc_78691914850_item	2874592	et	3	main
kui	doc_78691914850_item	2874594	et	3	main
palju	doc_78691914850_item	2874597	et	4	main
see	doc_78691914850_item	2874598	et	3	main
mis	doc_78691914850_item	2874599	et	4	main
on	doc_78691914850_item	2874613	et	4	main
1	doc_78691914850_item	2874619	et	2	main
tööd	doc_78691914850_item	2874632	et	4	main
2	doc_78691914850_item	2874633	et	2	main
nii	doc_78691914850_item	2874637	et	3	main
klassi	doc_78691914850_item	2874640	et	4	main
3	doc_78691914850_item	2874644	et	2	main
erinev	doc_78691914850_item	2874663	et	4	main
kõrgkooli	doc_78691914850_item	2874664	et	4	main
koolis	doc_78691914850_item	2874673	et	4	main
nii	doc_78691914850_item	2874676	et	3	main
sind	doc_78691914850_item	2874682	et	4	main
langemise	doc_78691914850_item	2874721	et	4	main
ei	doc_78691914850_item	2874727	et	4	main
jääda	doc_78691914850_item	2874729	et	4	main
ta	doc_78691914850_item	2874731	et	4	main
new	doc_78691914850_item	2874740	et	4	main
normal	doc_78691914850_item	2874743	et	4	main
font-weight	doc_78691914850_item	2874746	et	4	main
line-height	doc_78691914850_item	2874750	et	4	main
font-stretch	doc_78691914850_item	2874754	et	4	main
ettevaatlik	doc_78691914850_item	2874758	et	3	main
vett	doc_78691914850_item	2874761	et	3	main
elektriseadmet	doc_78691914850_item	2874763	et	4	main
times	doc_78691914850_item	2874771	et	4	main
new	doc_78691914850_item	2874772	et	4	main
font-size	doc_78691914850_item	2874780	et	4	main
normal	doc_78691914850_item	2874783	et	4	main
läksid	doc_78691914850_item	2874791	et	4	main
ise	doc_78691914850_item	2874795	et	4	main
parandama	doc_78691914850_item	2874796	et	3	main
mida	doc_78691914850_item	2874797	et	4	main
parem	doc_78691914850_item	2874810	et	4	main
bussis	doc_78691914850_item	2874821	et	3	main
sõita	doc_78691914850_item	2874822	et	3	main
new	doc_78691914850_item	2874826	et	4	main
normal	doc_78691914850_item	2874833	et	4	main
normal	doc_78691914850_item	2874837	et	4	main
normal	doc_78691914850_item	2874841	et	4	main
otsides	doc_78691914851_item	2874852	et	4	main
mugav	doc_78691914851_item	2874866	et	3	main
mitte	doc_78691914851_item	2874871	et	3	main
mida	doc_78691914851_item	2874886	et	4	main
peab	doc_78691914851_item	2874887	et	4	main
silmas	doc_78691914851_item	2874895	et	4	main
korteri	doc_78691914851_item	2874897	et	3	main
vaja	doc_78691914851_item	2874906	et	4	main
piirkonnas	doc_78691914851_item	2874909	et	4	main
ikka	doc_78691914849_item	2874392	et	4	main
öösel	doc_78691914849_item	2874395	et	4	main
selle	doc_78691914849_item	2874400	et	4	main
kiiresti	doc_78691914849_item	2874402	et	3	main
tööintervjuuks	doc_78691914850_item	2874404	et	3	main
lihtsalt	doc_78691914850_item	2874424	et	4	main
cv	doc_78691914850_item	2874428	et	4	main
küsivad	doc_78691914850_item	2874433	et	4	main
kohta	doc_78691914850_item	2874435	et	4	main
cv	doc_78691914850_item	2874442	et	4	main
ja	doc_78691914850_item	2874443	et	3	main
ma	doc_78691914850_item	2874450	et	3	main
cv	doc_78691914850_item	2874452	et	4	main
avaldus	doc_78691914850_item	2874454	et	4	main
ei	doc_78691914850_item	2874459	et	4	main
ole	doc_78691914850_item	2874460	et	4	main
võttab	doc_78691914850_item	2874475	et	4	main
huvitatud	doc_78691914850_item	2874481	et	4	main
hea	doc_78691914850_item	2874496	et	4	main
mõtlemiseks	doc_78691914850_item	2874441	et	4	main
peavad	doc_78691914850_item	2874445	et	4	main
lühikesed	doc_78691914850_item	2874447	et	4	main
ja	doc_78691914850_item	2874453	et	3	main
peavad	doc_78691914850_item	2874455	et	4	main
olema	doc_78691914850_item	2874456	et	4	main
tähtis	doc_78691914850_item	2874461	et	4	main
lihtsalt	doc_78691914850_item	2874464	et	4	main
cv-il	doc_78691914850_item	2874466	et	3	main
on	doc_78691914850_item	2874467	et	4	main
vaja	doc_78691914850_item	2874468	et	4	main
kirjutada	doc_78691914850_item	2874469	et	3	main
kes	doc_78691914850_item	2874474	et	4	main
sind	doc_78691914850_item	2874476	et	4	main
ei	doc_78691914850_item	2874479	et	4	main
huvitab	doc_78691914850_item	2874486	et	3	main
sinu	doc_78691914850_item	2874487	et	3	main
haridus	doc_78691914850_item	2874488	et	3	main
sinu	doc_78691914850_item	2874489	et	3	main
teadmised	doc_78691914850_item	2874490	et	4	main
sinu	doc_78691914850_item	2874491	et	3	main
kogemus	doc_78691914850_item	2874492	et	3	main
sobiv	doc_78691914850_item	2874493	et	4	main
ja	doc_78691914850_item	2874495	et	3	main
ja	doc_78691914850_item	2874525	et	3	main
see	doc_78691914850_item	2874527	et	3	main
näeb	doc_78691914850_item	2874529	et	3	main
on	doc_78691914850_item	2874533	et	4	main
on	doc_78691914850_item	2874536	et	4	main
on	doc_78691914850_item	2874549	et	4	main
peaks	doc_78691914850_item	2874555	et	4	main
aga	doc_78691914850_item	2874565	et	3	main
sest	doc_78691914850_item	2874569	et	4	main
sest	doc_78691914850_item	2874578	et	4	main
halba	doc_78691914850_item	2874579	et	4	main
sinu	doc_78691914850_item	2874580	et	3	main
kohta	doc_78691914850_item	2874581	et	4	main
sa	doc_78691914850_item	2874582	et	3	main
ei	doc_78691914850_item	2874583	et	4	main
räägi	doc_78691914850_item	2874584	et	4	main
ainult	doc_78691914850_item	2874585	et	4	main
kui	doc_78691914850_item	2874586	et	3	main
tark	doc_78691914850_item	2874587	et	3	main
et	doc_78691914850_item	2874561	et	3	main
sa	doc_78691914850_item	2874562	et	3	main
väga	doc_78691914850_item	2874567	et	3	main
mõelda	doc_78691914850_item	2874572	et	4	main
sa	doc_78691914850_item	2874574	et	3	main
idiaalne	doc_78691914850_item	2874576	et	4	main
hea	doc_78691914850_item	2874589	et	4	main
ja	doc_78691914850_item	2874590	et	3	main
oled	doc_78691914850_item	2874593	et	3	main
sa	doc_78691914850_item	2874595	et	3	main
mis	doc_78691914850_item	2874612	et	4	main
probleemid	doc_78691914850_item	2874618	et	3	main
on	doc_78691914850_item	2874621	et	4	main
raske	doc_78691914850_item	2874629	et	4	main
teha	doc_78691914850_item	2874630	et	3	main
ei	doc_78691914850_item	2874635	et	4	main
palju	doc_78691914850_item	2874638	et	4	main
on	doc_78691914850_item	2874642	et	4	main
poolest	doc_78691914850_item	2874651	et	4	main
erineb	doc_78691914850_item	2874652	et	3	main
ei	doc_78691914850_item	2874665	et	4	main
tööd	doc_78691914850_item	2874671	et	4	main
õppima	doc_78691914850_item	2874683	et	3	main
keegi	doc_78691914850_item	2874685	et	4	main
too	doc_78691914850_item	2874687	et	4	main
sulle	doc_78691914850_item	2874688	et	3	main
peaks	doc_78691914850_item	2874714	et	4	main
inimene	doc_78691914850_item	2874715	et	3	main
tegema	doc_78691914850_item	2874716	et	3	main
et	doc_78691914850_item	2874717	et	3	main
vähendada	doc_78691914850_item	2874718	et	3	main
sest	doc_78691914850_item	2874726	et	4	main
saa	doc_78691914850_item	2874728	et	4	main
kui	doc_78691914850_item	2874730	et	3	main
span2span	doc_78691914850_item	2874737	et	4	main
roman	doc_78691914850_item	2874741	et	4	main
font-size	doc_78691914850_item	2874748	et	4	main
7pt	doc_78691914850_item	2874749	et	4	main
font-size-adjust	doc_78691914850_item	2874752	et	4	main
normal	doc_78691914850_item	2874755	et	4	main
span3span	doc_78691914850_item	2874769	et	4	main
stylefont-family	doc_78691914850_item	2874770	et	4	main
font-style	doc_78691914850_item	2874774	et	4	main
normal	doc_78691914850_item	2874775	et	4	main
normal	doc_78691914850_item	2874779	et	4	main
font-stretch	doc_78691914850_item	2874786	et	4	main
normal	doc_78691914850_item	2874787	et	4	main
span	doc_78691914850_item	2874788	et	4	main
kui	doc_78691914850_item	2874789	et	3	main
katki	doc_78691914850_item	2874792	et	4	main
ärge	doc_78691914850_item	2874793	et	3	main
sattumise	doc_78691914850_item	2874805	et	4	main
peavad	doc_78691914850_item	2874818	et	4	main
trammis	doc_78691914850_item	2874819	et	4	main
ja	doc_78691914850_item	2874820	et	3	main
ole	doc_78691914850_item	2874601	et	4	main
tähtis	doc_78691914850_item	2874602	et	4	main
siis	doc_78691914850_item	2874603	et	3	main
tööintervjueerija	doc_78691914850_item	2874604	et	4	main
võib	doc_78691914850_item	2874605	et	3	main
unustada	doc_78691914850_item	2874606	et	3	main
see	doc_78691914850_item	2874607	et	3	main
mida	doc_78691914850_item	2874608	et	4	main
praegu	doc_78691914850_item	2874614	et	3	main
koolis	doc_78691914850_item	2874615	et	4	main
inimest	doc_78691914850_item	2874620	et	3	main
palju	doc_78691914850_item	2874622	et	4	main
klassid	doc_78691914850_item	2874623	et	3	main
on	doc_78691914850_item	2874624	et	4	main
suured	doc_78691914850_item	2874625	et	3	main
ja	doc_78691914850_item	2874626	et	3	main
oma	doc_78691914850_item	2874631	et	4	main
ole	doc_78691914850_item	2874636	et	4	main
arvuti	doc_78691914850_item	2874639	et	4	main
vaja	doc_78691914850_item	2874643	et	4	main
palju	doc_78691914850_item	2874646	et	4	main
kes	doc_78691914850_item	2874648	et	4	main
suitsetavad	doc_78691914850_item	2874649	et	4	main
mille	doc_78691914850_item	2874650	et	3	main
on	doc_78691914850_item	2874661	et	4	main
väga	doc_78691914850_item	2874662	et	3	main
vaja	doc_78691914850_item	2874667	et	4	main
ole	doc_78691914850_item	2874675	et	4	main
õpetajad	doc_78691914850_item	2874680	et	4	main
materjalid	doc_78691914850_item	2874689	et	3	main
kätte	doc_78691914850_item	2874690	et	4	main
nagu	doc_78691914850_item	2874691	et	3	main
koolis	doc_78691914850_item	2874692	et	4	main
sa	doc_78691914850_item	2874693	et	3	main
pead	doc_78691914850_item	2874694	et	4	main
ise	doc_78691914850_item	2874695	et	4	main
kõik	doc_78691914850_item	2874696	et	4	main
otsima	doc_78691914850_item	2874697	et	4	main
korgkoolis	doc_78691914850_item	2874698	et	4	main
sa	doc_78691914850_item	2874699	et	3	main
oled	doc_78691914850_item	2874700	et	3	main
juba	doc_78691914850_item	2874701	et	3	main
täiskasvanud	doc_78691914850_item	2874702	et	4	main
inimene	doc_78691914850_item	2874703	et	3	main
sa	doc_78691914850_item	2874704	et	3	main
teha	doc_78691914850_item	2874707	et	3	main
see	doc_78691914850_item	2874708	et	3	main
ei	doc_78691914850_item	2874705	et	4	main
saa	doc_78691914850_item	2874706	et	4	main
mida	doc_78691914850_item	2874709	et	4	main
sa	doc_78691914850_item	2874710	et	3	main
koolis	doc_78691914850_item	2874711	et	4	main
tegid	doc_78691914850_item	2874712	et	4	main
mida	doc_78691914850_item	2874713	et	4	main
ja	doc_78691914850_item	2874588	et	3	main
tähtis	doc_78691914850_item	2874611	et	4	main
suuremad	doc_78691914850_item	2874617	et	4	main
õpetajal	doc_78691914850_item	2874627	et	4	main
on	doc_78691914850_item	2874628	et	4	main
koolis	doc_78691914850_item	2874634	et	4	main
palju	doc_78691914850_item	2874641	et	4	main
koolis	doc_78691914850_item	2874645	et	4	main
õppimine	doc_78691914850_item	2874653	et	4	main
kõrgkoolis	doc_78691914850_item	2874654	et	4	main
õppimisest	doc_78691914850_item	2874655	et	4	main
koolis	doc_78691914850_item	2874656	et	4	main
õppimine	doc_78691914850_item	2874657	et	4	main
iga	doc_78691914850_item	2874668	et	4	main
päev	doc_78691914850_item	2874669	et	3	main
kodumis	doc_78691914850_item	2874670	et	3	main
palju	doc_78691914850_item	2874677	et	4	main
koolis	doc_78691914850_item	2874679	et	4	main
käskivad	doc_78691914850_item	2874681	et	4	main
kõrgkoolis	doc_78691914850_item	2874684	et	4	main
ei	doc_78691914850_item	2874686	et	4	main
ei	doc_78691914850_item	2874732	et	4	main
stylefont-family	doc_78691914850_item	2874738	et	4	main
font-style	doc_78691914850_item	2874742	et	4	main
font-variant	doc_78691914850_item	2874744	et	3	main
normal	doc_78691914850_item	2874745	et	4	main
olge	doc_78691914850_item	2874757	et	3	main
kui	doc_78691914850_item	2874762	et	3	main
näiteks	doc_78691914850_item	2874767	et	4	main
roman	doc_78691914850_item	2874773	et	4	main
none	doc_78691914850_item	2874785	et	4	main
peaks	doc_78691914850_item	2874798	et	4	main
inimene	doc_78691914850_item	2874799	et	3	main
tegema	doc_78691914850_item	2874800	et	3	main
et	doc_78691914850_item	2874801	et	3	main
vähendada	doc_78691914850_item	2874802	et	3	main
kuriteo	doc_78691914850_item	2874803	et	4	main
ohvriks	doc_78691914850_item	2874804	et	3	main
peavad	doc_78691914850_item	2874809	et	4	main
teha	doc_78691914850_item	2874811	et	3	main
span2span	doc_78691914850_item	2874823	et	4	main
font-style	doc_78691914850_item	2874828	et	4	main
font-size	doc_78691914850_item	2874834	et	4	main
font-size-adjust	doc_78691914850_item	2874838	et	4	main
span	doc_78691914850_item	2874842	et	4	main
signalizatsiooni	doc_78691914850_item	2874846	et	4	main
dokument	doc_78691914851_item	2874848	et	3	main
kas	doc_78691914851_item	2874849	et	3	main
tasub	doc_78691914851_item	2874853	et	3	main
maakleri	doc_78691914851_item	2874855	et	3	main
poole	doc_78691914851_item	2874856	et	4	main
muidugi	doc_78691914851_item	2874857	et	4	main
ma	doc_78691914851_item	2874858	et	3	main
pöördun	doc_78691914851_item	2874859	et	3	main
maakleri	doc_78691914851_item	2874860	et	3	main
on	doc_78691914851_item	2874864	et	4	main
et	doc_78691914851_item	2874868	et	3	main
keegi	doc_78691914851_item	2874873	et	4	main
sind	doc_78691914851_item	2874876	et	4	main
maakler	doc_78691914851_item	2874878	et	3	main
saab	doc_78691914851_item	2874879	et	3	main
sulle	doc_78691914851_item	2874881	et	3	main
variante	doc_78691914851_item	2874883	et	3	main
hinnaga	doc_78691914851_item	2874885	et	3	main
me	doc_78691914851_item	2874893	et	4	main
valikul	doc_78691914851_item	2874898	et	3	main
on	doc_78691914851_item	2874905	et	4	main
kehv	doc_78691914851_item	2874922	et	3	main
elada	doc_78691914851_item	2874930	et	3	main
parem	doc_78691914851_item	2874940	et	4	main
võtta	doc_78691914851_item	2874941	et	3	main
kodus	doc_78691914851_item	2874967	et	4	main
on	doc_78691914851_item	2874974	et	4	main
elada	doc_78691914851_item	2874985	et	3	main
kirjeldage	doc_78691914851_item	2874986	et	3	main
hobusel	doc_78691914851_item	2874990	et	4	main
ja	doc_78691914851_item	2874998	et	3	main
saba	doc_78691914851_item	2875009	et	4	main
kihve	doc_78691914851_item	2875012	et	3	main
hamster	doc_78691914851_item	2875013	et	3	main
lühike	doc_78691914851_item	2875023	et	4	main
koon	doc_78691914851_item	2875026	et	4	main
tervis	doc_78691914851_item	2875029	et	3	main
tähtis	doc_78691914851_item	2875036	et	4	main
on	doc_78691914851_item	2875042	et	4	main
õpilast	doc_78691914850_item	2874647	et	4	main
koolis	doc_78691914850_item	2874658	et	4	main
ja	doc_78691914850_item	2874659	et	3	main
kõrgkoolis	doc_78691914850_item	2874660	et	4	main
ole	doc_78691914850_item	2874666	et	4	main
teha	doc_78691914850_item	2874672	et	3	main
ei	doc_78691914850_item	2874674	et	4	main
eksamit	doc_78691914850_item	2874678	et	3	main
kuriteo	doc_78691914850_item	2874719	et	4	main
ohvriks	doc_78691914850_item	2874720	et	3	main
none	doc_78691914850_item	2874753	et	4	main
riski	doc_78691914850_item	2874722	et	4	main
1	doc_78691914850_item	2874723	et	2	main
olge	doc_78691914850_item	2874724	et	3	main
ettevaatlik	doc_78691914850_item	2874725	et	3	main
ole	doc_78691914850_item	2874733	et	4	main
lülitatud	doc_78691914850_item	2874734	et	4	main
näiteks	doc_78691914850_item	2874735	et	4	main
triikraud	doc_78691914850_item	2874736	et	3	main
times	doc_78691914850_item	2874739	et	4	main
normal	doc_78691914850_item	2874747	et	4	main
normal	doc_78691914850_item	2874751	et	4	main
span	doc_78691914850_item	2874756	et	4	main
ärge	doc_78691914850_item	2874759	et	3	main
ei	doc_78691914850_item	2874764	et	4	main
ole	doc_78691914850_item	2874765	et	4	main
lülitatud	doc_78691914850_item	2874766	et	4	main
font-variant	doc_78691914850_item	2874776	et	3	main
normal	doc_78691914850_item	2874777	et	4	main
7pt	doc_78691914850_item	2874781	et	4	main
line-height	doc_78691914850_item	2874782	et	4	main
font-size-adjust	doc_78691914850_item	2874784	et	4	main
elektriseadmet	doc_78691914850_item	2874790	et	4	main
proovige	doc_78691914850_item	2874794	et	3	main
riski	doc_78691914850_item	2874806	et	4	main
1	doc_78691914850_item	2874807	et	2	main
politseinikud	doc_78691914850_item	2874808	et	4	main
oma	doc_78691914850_item	2874812	et	4	main
stylefont-family	doc_78691914850_item	2874824	et	4	main
roman	doc_78691914850_item	2874827	et	4	main
normal	doc_78691914850_item	2874829	et	4	main
normal	doc_78691914850_item	2874831	et	4	main
font-weight	doc_78691914850_item	2874832	et	4	main
none	doc_78691914850_item	2874839	et	4	main
kodus	doc_78691914850_item	2874843	et	4	main
võib	doc_78691914850_item	2874844	et	3	main
panna	doc_78691914850_item	2874845	et	4	main
elukohta	doc_78691914851_item	2874851	et	4	main
pöörduda	doc_78691914851_item	2874854	et	3	main
sest	doc_78691914851_item	2874862	et	4	main
see	doc_78691914851_item	2874863	et	3	main
väga	doc_78691914851_item	2874865	et	3	main
see	doc_78691914851_item	2874869	et	3	main
ohtlik	doc_78691914851_item	2874872	et	3	main
peeta	doc_78691914851_item	2874875	et	4	main
palju	doc_78691914851_item	2874882	et	4	main
vastuvõetava	doc_78691914851_item	2874884	et	3	main
pidama	doc_78691914851_item	2874896	et	4	main
hind	doc_78691914851_item	2874900	et	3	main
pärast	doc_78691914851_item	2874904	et	4	main
on	doc_78691914851_item	2874921	et	4	main
trepikoda	doc_78691914851_item	2874923	et	4	main
siis	doc_78691914851_item	2874924	et	3	main
sul	doc_78691914851_item	2874925	et	3	main
on	doc_78691914851_item	2874926	et	4	main
ebameeldiv	doc_78691914851_item	2874927	et	3	main
viimane	doc_78691914851_item	2874931	et	3	main
on	doc_78691914851_item	2874933	et	4	main
missugune	doc_78691914851_item	2874934	et	3	main
remont	doc_78691914851_item	2874935	et	3	main
kõige	doc_78691914851_item	2874939	et	4	main
korterit	doc_78691914851_item	2874942	et	3	main
ise	doc_78691914851_item	2874946	et	4	main
tegema	doc_78691914851_item	2874947	et	3	main
korteris	doc_78691914851_item	2874948	et	3	main
võib	doc_78691914851_item	2874949	et	3	main
olla	doc_78691914851_item	2874950	et	3	main
soobi	doc_78691914851_item	2874958	et	3	main
metslooma	doc_78691914851_item	2874964	et	4	main
saa	doc_78691914851_item	2874966	et	4	main
pidada	doc_78691914851_item	2874968	et	4	main
ainult	doc_78691914851_item	2874969	et	4	main
võimalik	doc_78691914851_item	2874970	et	3	main
pidada	doc_78691914851_item	2874971	et	4	main
kui	doc_78691914851_item	2874972	et	3	main
väike	doc_78691914851_item	2874975	et	4	main
jääb	doc_78691914851_item	2874978	et	3	main
ja	doc_78691914851_item	2874980	et	3	main
loomade	doc_78691914851_item	2874988	et	4	main
on	doc_78691914851_item	2874991	et	4	main
suur	doc_78691914851_item	2874992	et	3	main
pikk	doc_78691914851_item	2874994	et	4	main
keel	doc_78691914851_item	2875000	et	4	main
jaanalinnul	doc_78691914851_item	2875001	et	4	main
pikk	doc_78691914851_item	2875003	et	4	main
on	doc_78691914851_item	2875019	et	4	main
kasutage	doc_78691914850_item	2874760	et	3	main
föön	doc_78691914850_item	2874768	et	3	main
font-weight	doc_78691914850_item	2874778	et	4	main
tööd	doc_78691914850_item	2874813	et	4	main
ja	doc_78691914850_item	2874814	et	3	main
võib	doc_78691914850_item	2874815	et	3	main
olla	doc_78691914850_item	2874816	et	3	main
mõned	doc_78691914850_item	2874817	et	3	main
times	doc_78691914850_item	2874825	et	4	main
font-variant	doc_78691914850_item	2874830	et	3	main
7pt	doc_78691914850_item	2874835	et	4	main
line-height	doc_78691914850_item	2874836	et	4	main
font-stretch	doc_78691914850_item	2874840	et	4	main
uus	doc_78691914851_item	2874847	et	3	main
uut	doc_78691914851_item	2874850	et	3	main
poole	doc_78691914851_item	2874861	et	4	main
arvan	doc_78691914851_item	2874867	et	3	main
on	doc_78691914851_item	2874870	et	4	main
ei	doc_78691914851_item	2874874	et	4	main
asjatundlik	doc_78691914851_item	2874877	et	3	main
pakkuda	doc_78691914851_item	2874880	et	3	main
pidama	doc_78691914851_item	2874889	et	4	main
korteri	doc_78691914851_item	2874890	et	3	main
valikul	doc_78691914851_item	2874891	et	3	main
kõigepealt	doc_78691914851_item	2874892	et	3	main
hindadele	doc_78691914851_item	2874899	et	3	main
peab	doc_78691914851_item	2874901	et	4	main
teada	doc_78691914851_item	2874907	et	3	main
see	doc_78691914851_item	2874910	et	3	main
korter	doc_78691914851_item	2874911	et	3	main
asub	doc_78691914851_item	2874912	et	3	main
väga	doc_78691914851_item	2874913	et	3	main
tähtis	doc_78691914851_item	2874914	et	4	main
asi	doc_78691914851_item	2874915	et	4	main
on	doc_78691914851_item	2874916	et	4	main
trepikoda	doc_78691914851_item	2874917	et	4	main
majas	doc_78691914851_item	2874918	et	3	main
kui	doc_78691914851_item	2874919	et	3	main
majas	doc_78691914851_item	2874920	et	3	main
selles	doc_78691914851_item	2874928	et	4	main
on	doc_78691914851_item	2874936	et	4	main
ilma	doc_78691914851_item	2874943	et	4	main
remondita	doc_78691914851_item	2874944	et	4	main
ja	doc_78691914851_item	2874945	et	3	main
kas	doc_78691914851_item	2874959	et	3	main
metslooma	doc_78691914851_item	2874960	et	4	main
saab	doc_78691914851_item	2874961	et	3	main
kodus	doc_78691914851_item	2874962	et	4	main
pidada	doc_78691914851_item	2874963	et	4	main
ta	doc_78691914851_item	2874973	et	4	main
metsloom	doc_78691914851_item	2874977	et	3	main
ei	doc_78691914851_item	2874982	et	4	main
võimalik	doc_78691914851_item	2874984	et	3	main
nende	doc_78691914851_item	2874987	et	4	main
kikkis	doc_78691914851_item	2874996	et	3	main
kõrvad	doc_78691914851_item	2874997	et	3	main
mitte	doc_78691914851_item	2875007	et	3	main
ole	doc_78691914851_item	2875011	et	4	main
on	doc_78691914851_item	2875014	et	4	main
väga	doc_78691914851_item	2875015	et	3	main
väike	doc_78691914851_item	2875016	et	4	main
loom	doc_78691914851_item	2875017	et	3	main
tal	doc_78691914851_item	2875018	et	3	main
saba	doc_78691914851_item	2875024	et	4	main
kikkis	doc_78691914851_item	2875027	et	3	main
igaühest	doc_78691914851_item	2875031	et	4	main
meie	doc_78691914851_item	2875038	et	4	main
ta	doc_78691914851_item	2875045	et	4	main
näha	doc_78691914851_item	2875048	et	3	main
elada	doc_78691914851_item	2875052	et	3	main
sõltub	doc_78691914851_item	2875060	et	3	main
iga	doc_78691914851_item	2875063	et	4	main
peab	doc_78691914851_item	2875065	et	4	main
ja	doc_78691914851_item	2875073	et	3	main
silmas	doc_78691914851_item	2874888	et	4	main
peame	doc_78691914851_item	2874894	et	4	main
olema	doc_78691914851_item	2874902	et	4	main
vastuvõetav	doc_78691914851_item	2874903	et	4	main
missuguses	doc_78691914851_item	2874908	et	3	main
hoones	doc_78691914851_item	2874929	et	4	main
asi	doc_78691914851_item	2874932	et	4	main
tehtud	doc_78691914851_item	2874937	et	4	main
korteris	doc_78691914851_item	2874938	et	3	main
üsna	doc_78691914851_item	2874951	et	3	main
kulukas	doc_78691914851_item	2874952	et	4	main
remont	doc_78691914851_item	2874953	et	3	main
aga	doc_78691914851_item	2874954	et	3	main
sulle	doc_78691914851_item	2874955	et	3	main
see	doc_78691914851_item	2874956	et	3	main
ei	doc_78691914851_item	2874957	et	4	main
ei	doc_78691914851_item	2874965	et	4	main
pärast	doc_78691914851_item	2874976	et	4	main
metsikuks	doc_78691914851_item	2874979	et	3	main
välimust	doc_78691914851_item	2874989	et	4	main
saba	doc_78691914851_item	2874995	et	4	main
painduv	doc_78691914851_item	2875005	et	4	main
pikk	doc_78691914851_item	2875008	et	4	main
ei	doc_78691914851_item	2875010	et	4	main
kere	doc_78691914851_item	2875022	et	4	main
kõrvad	doc_78691914851_item	2875028	et	3	main
sõltub	doc_78691914851_item	2875030	et	3	main
endast	doc_78691914851_item	2875032	et	4	main
tervis	doc_78691914851_item	2875033	et	3	main
on	doc_78691914851_item	2875034	et	4	main
väga	doc_78691914851_item	2875035	et	3	main
elus	doc_78691914851_item	2875039	et	4	main
kui	doc_78691914851_item	2875040	et	3	main
inimesel	doc_78691914851_item	2875041	et	3	main
saab	doc_78691914851_item	2875046	et	3	main
raha	doc_78691914851_item	2875050	et	4	main
täisverelist	doc_78691914851_item	2875053	et	4	main
et	doc_78691914851_item	2875058	et	3	main
endast	doc_78691914851_item	2875062	et	4	main
inimene	doc_78691914851_item	2875064	et	3	main
paljudel	doc_78691914851_item	2875069	et	3	main
inimesel	doc_78691914851_item	2875070	et	3	main
on	doc_78691914851_item	2875071	et	4	main
tubaka-	doc_78691914851_item	2875072	et	3	main
kopsud	doc_78691914851_item	2875079	et	4	main
arst	doc_78691914851_item	2875088	et	3	main
selline	doc_78691914851_item	2875096	et	4	main
et	doc_78691914851_item	2875097	et	3	main
palju	doc_78691914851_item	2875098	et	4	main
kahjulik	doc_78691914851_item	2875107	et	3	main
pikendada	doc_78691914851_item	2875113	et	3	main
kõigepealt	doc_78691914851_item	2875115	et	3	main
spordiga	doc_78691914851_item	2875118	et	3	main
tegelema	doc_78691914851_item	2875119	et	3	main
teiseks	doc_78691914851_item	2875124	et	4	main
ja	doc_78691914851_item	2875127	et	3	main
alkoholi	doc_78691914851_item	2875131	et	4	main
on	doc_78691914851_item	2875132	et	4	main
võimalik	doc_78691914851_item	2875133	et	3	main
juua	doc_78691914851_item	2875134	et	3	main
aga	doc_78691914851_item	2875135	et	3	main
palju	doc_78691914851_item	2875138	et	4	main
näiteks	doc_78691914851_item	2875139	et	4	main
kui	doc_78691914851_item	2875140	et	3	main
sa	doc_78691914851_item	2875141	et	3	main
kolmandaks	doc_78691914851_item	2875154	et	4	main
elada	doc_78691914851_item	2875157	et	3	main
kus	doc_78691914851_item	2875160	et	3	main
tänapäevaks	doc_78691914852_item	2875175	et	3	main
kõik	doc_78691914852_item	2875177	et	4	main
leiutatud	doc_78691914852_item	2875180	et	4	main
on	doc_78691914852_item	2875184	et	4	main
arvan	doc_78691914852_item	2875189	et	3	main
mugavalt	doc_78691914852_item	2875221	et	4	main
väikeseid	doc_78691914852_item	2875230	et	4	main
era-lennukidest	doc_78691914852_item	2875231	et	4	main
ja	doc_78691914852_item	2875232	et	3	main
lõppetades	doc_78691914852_item	2875233	et	4	main
suurtega	doc_78691914852_item	2875234	et	3	main
disainega	doc_78691914852_item	2875239	et	4	main
ja	doc_78691914852_item	2875240	et	3	main
mugavalt	doc_78691914852_item	2875248	et	4	main
reisil	doc_78691914852_item	2875250	et	3	main
tänapäevane	doc_78691914852_item	2875252	et	4	main
leiutis	doc_78691914852_item	2875253	et	3	main
ühest	doc_78691914852_item	2875263	et	4	main
kergendab	doc_78691914852_item	2875266	et	3	main
küljest	doc_78691914852_item	2875271	et	4	main
sõltuvust	doc_78691914852_item	2875275	et	4	main
istub	doc_78691914852_item	2875278	et	3	main
ja	doc_78691914852_item	2875281	et	3	main
saab	doc_78691914852_item	2875283	et	3	main
palju	doc_78691914852_item	2875284	et	4	main
informatsiooni	doc_78691914852_item	2875285	et	4	main
inimestega	doc_78691914852_item	2875291	et	3	main
et	doc_78691914852_item	2875295	et	3	main
elu	doc_78691914852_item	2875298	et	4	main
väga	doc_78691914852_item	2875300	et	3	main
midagi	doc_78691914852_item	2875307	et	4	main
teha	doc_78691914852_item	2875308	et	3	main
meil	doc_78691914852_item	2875324	et	4	main
temaga	doc_78691914851_item	2874981	et	3	main
ole	doc_78691914851_item	2874983	et	4	main
kere	doc_78691914851_item	2874993	et	4	main
kare	doc_78691914851_item	2874999	et	3	main
on	doc_78691914851_item	2875002	et	4	main
ja	doc_78691914851_item	2875004	et	3	main
kere	doc_78691914851_item	2875006	et	4	main
mitte	doc_78691914851_item	2875020	et	3	main
suur	doc_78691914851_item	2875021	et	3	main
ümmargune	doc_78691914851_item	2875025	et	3	main
asi	doc_78691914851_item	2875037	et	4	main
vaeva	doc_78691914851_item	2875047	et	4	main
ja	doc_78691914851_item	2875051	et	3	main
elu	doc_78691914851_item	2875054	et	4	main
arstid	doc_78691914851_item	2875056	et	4	main
ütlevad	doc_78691914851_item	2875057	et	4	main
igaühest	doc_78691914851_item	2875061	et	4	main
tervisest	doc_78691914851_item	2875068	et	4	main
inimestel	doc_78691914851_item	2875077	et	3	main
nad	doc_78691914851_item	2875082	et	3	main
tulevad	doc_78691914851_item	2875083	et	4	main
arsti	doc_78691914851_item	2875084	et	4	main
on	doc_78691914851_item	2875095	et	4	main
palju	doc_78691914851_item	2875102	et	4	main
see	doc_78691914851_item	2875103	et	3	main
mis	doc_78691914851_item	2875108	et	4	main
peame	doc_78691914851_item	2875110	et	4	main
et	doc_78691914851_item	2875112	et	3	main
mitte	doc_78691914851_item	2875121	et	3	main
väga	doc_78691914851_item	2875122	et	3	main
palju	doc_78691914851_item	2875123	et	4	main
suitseta	doc_78691914851_item	2875126	et	4	main
ei	doc_78691914851_item	2875128	et	4	main
joo	doc_78691914851_item	2875129	et	4	main
alkoholi	doc_78691914851_item	2875130	et	4	main
väga	doc_78691914851_item	2875137	et	3	main
veresoonetele	doc_78691914851_item	2875153	et	4	main
parim	doc_78691914851_item	2875156	et	4	main
seal	doc_78691914851_item	2875159	et	4	main
kui	doc_78691914851_item	2875165	et	3	main
elada	doc_78691914851_item	2875172	et	3	main
leiutised	doc_78691914852_item	2875174	et	3	main
vajalik	doc_78691914852_item	2875178	et	3	main
praegu	doc_78691914852_item	2875181	et	3	main
kiiresti	doc_78691914852_item	2875187	et	3	main
täna	doc_78691914852_item	2875191	et	4	main
ja	doc_78691914852_item	2875220	et	3	main
lennata	doc_78691914852_item	2875222	et	4	main
peaaegu	doc_78691914852_item	2875223	et	3	main
igale	doc_78691914852_item	2875224	et	3	main
poole	doc_78691914852_item	2875225	et	4	main
on	doc_78691914852_item	2875237	et	4	main
et	doc_78691914852_item	2875243	et	3	main
rejsijad	doc_78691914852_item	2875244	et	4	main
tunneksid	doc_78691914852_item	2875245	et	4	main
interned	doc_78691914852_item	2875255	et	4	main
aga	doc_78691914852_item	2875269	et	3	main
internet	doc_78691914852_item	2875272	et	4	main
inimestes	doc_78691914852_item	2875274	et	3	main
internetis	doc_78691914852_item	2875276	et	4	main
suhelda	doc_78691914852_item	2875289	et	4	main
tutvuda	doc_78691914852_item	2875290	et	3	main
meie	doc_78691914852_item	2875297	et	4	main
on	doc_78691914852_item	2875299	et	4	main
mitte	doc_78691914852_item	2875306	et	3	main
kui	doc_78691914852_item	2875309	et	3	main
juua	doc_78691914852_item	2875312	et	3	main
kohvi	doc_78691914852_item	2875313	et	4	main
me	doc_78691914852_item	2875314	et	4	main
võtame	doc_78691914852_item	2875315	et	3	main
kohvimasin	doc_78691914852_item	2875316	et	3	main
me	doc_78691914852_item	2875321	et	4	main
võtame	doc_78691914852_item	2875322	et	3	main
tolmuimeja	doc_78691914852_item	2875323	et	4	main
me	doc_78691914852_item	2875328	et	4	main
ei	doc_78691914852_item	2875329	et	4	main
ma	doc_78691914852_item	2875333	et	3	main
arvan	doc_78691914852_item	2875334	et	3	main
et	doc_78691914852_item	2875335	et	3	main
lihtsalt	doc_78691914852_item	2875343	et	4	main
täiustada	doc_78691914852_item	2875344	et	3	main
kas	doc_78691914853_item	2875346	et	3	main
tuleviku	doc_78691914853_item	2875347	et	4	main
inimesed	doc_78691914853_item	2875348	et	3	main
loevad	doc_78691914853_item	2875349	et	3	main
raamatuid	doc_78691914853_item	2875350	et	3	main
olen	doc_78691914853_item	2875351	et	3	main
kindel	doc_78691914853_item	2875352	et	3	main
et	doc_78691914853_item	2875353	et	3	main
need	doc_78691914853_item	2875354	et	3	main
teosed	doc_78691914853_item	2875355	et	3	main
mida	doc_78691914853_item	2875356	et	4	main
tervis	doc_78691914851_item	2875043	et	3	main
siis	doc_78691914851_item	2875044	et	3	main
teenida	doc_78691914851_item	2875049	et	3	main
hoolitsema	doc_78691914851_item	2875066	et	4	main
pärast	doc_78691914851_item	2875075	et	4	main
valutavad	doc_78691914851_item	2875078	et	4	main
ja	doc_78691914851_item	2875080	et	3	main
neerud	doc_78691914851_item	2875081	et	3	main
vaevad	doc_78691914851_item	2875086	et	4	main
saa	doc_78691914851_item	2875090	et	4	main
aidata	doc_78691914851_item	2875092	et	4	main
teine	doc_78691914851_item	2875093	et	3	main
asi	doc_78691914851_item	2875094	et	4	main
väga	doc_78691914851_item	2875106	et	3	main
ei	doc_78691914851_item	2875125	et	4	main
jood	doc_78691914851_item	2875142	et	4	main
üks	doc_78691914851_item	2875145	et	3	main
poolaastas	doc_78691914851_item	2875147	et	3	main
siis	doc_78691914851_item	2875148	et	3	main
see	doc_78691914851_item	2875149	et	3	main
on	doc_78691914851_item	2875155	et	4	main
kuskil	doc_78691914851_item	2875158	et	3	main
õhk	doc_78691914851_item	2875161	et	3	main
ei	doc_78691914851_item	2875162	et	4	main
ole	doc_78691914851_item	2875163	et	4	main
kaua	doc_78691914851_item	2875173	et	3	main
maailm	doc_78691914852_item	2875183	et	3	main
ma	doc_78691914852_item	2875188	et	3	main
maailma	doc_78691914852_item	2875226	et	4	main
praegu	doc_78691914852_item	2875227	et	3	main
lennukid	doc_78691914852_item	2875228	et	3	main
tsharter-lennikitega	doc_78691914852_item	2875235	et	4	main
kaasaegsed	doc_78691914852_item	2875236	et	3	main
selleks	doc_78691914852_item	2875242	et	4	main
teine	doc_78691914852_item	2875251	et	3	main
oska	doc_78691914852_item	2875261	et	4	main
elada	doc_78691914852_item	2875262	et	3	main
internet	doc_78691914852_item	2875265	et	4	main
elu	doc_78691914852_item	2875268	et	4	main
tekitab	doc_78691914852_item	2875273	et	3	main
kogu	doc_78691914852_item	2875279	et	4	main
ma	doc_78691914852_item	2875293	et	3	main
praegu	doc_78691914852_item	2875296	et	3	main
ise	doc_78691914852_item	2875305	et	4	main
kui	doc_78691914852_item	2875317	et	3	main
on	doc_78691914852_item	2875325	et	4	main
autod	doc_78691914852_item	2875326	et	3	main
jalast	doc_78691914852_item	2875331	et	4	main
rohkem	doc_78691914852_item	2875336	et	4	main
pushkin	doc_78691914853_item	2875358	et	4	main
tammsaare	doc_78691914853_item	2875359	et	3	main
gügo	doc_78691914853_item	2875361	et	4	main
inimesed	doc_78691914853_item	2875363	et	3	main
maailmas	doc_78691914853_item	2875367	et	3	main
internetis	doc_78691914853_item	2875379	et	4	main
elektroonilisest	doc_78691914853_item	2875380	et	4	main
teada	doc_78691914853_item	2875416	et	3	main
mida	doc_78691914853_item	2875417	et	4	main
teadma	doc_78691914853_item	2875426	et	3	main
ta	doc_78691914853_item	2875430	et	4	main
peab	doc_78691914853_item	2875431	et	4	main
valima	doc_78691914853_item	2875432	et	3	main
vahendid	doc_78691914853_item	2875433	et	3	main
et	doc_78691914853_item	2875434	et	3	main
koostöö	doc_78691914853_item	2875439	et	4	main
ka	doc_78691914853_item	2875443	et	3	main
raha	doc_78691914853_item	2875449	et	4	main
hea	doc_78691914853_item	2875455	et	4	main
mõelda	doc_78691914853_item	2875457	et	4	main
ja	doc_78691914853_item	2875468	et	3	main
võiks	doc_78691914853_item	2875470	et	4	main
et	doc_78691914853_item	2875475	et	3	main
lahendada	doc_78691914853_item	2875479	et	3	main
iga	doc_78691914854_item	2875483	et	4	main
on	doc_78691914854_item	2875524	et	4	main
mulle	doc_78691914854_item	2875533	et	4	main
tundub	doc_78691914854_item	2875534	et	3	main
on	doc_78691914854_item	2875537	et	4	main
kodu	doc_78691914854_item	2875540	et	4	main
või	doc_78691914854_item	2875541	et	4	main
minu	doc_78691914854_item	2875542	et	3	main
pere	doc_78691914854_item	2875543	et	4	main
töö	doc_78691914854_item	2875549	et	4	main
väga	doc_78691914854_item	2875550	et	3	main
hea	doc_78691914854_item	2875551	et	4	main
kui	doc_78691914854_item	2875552	et	3	main
kõik	doc_78691914851_item	2875055	et	4	main
tervis	doc_78691914851_item	2875059	et	3	main
oma	doc_78691914851_item	2875067	et	4	main
seda	doc_78691914851_item	2875076	et	3	main
aga	doc_78691914851_item	2875087	et	3	main
nendele	doc_78691914851_item	2875091	et	4	main
inimesi	doc_78691914851_item	2875099	et	4	main
tegelevad	doc_78691914851_item	2875100	et	4	main
spordiga	doc_78691914851_item	2875101	et	3	main
inimesed	doc_78691914851_item	2875116	et	3	main
aga	doc_78691914851_item	2875120	et	3	main
mitte	doc_78691914851_item	2875136	et	3	main
punast	doc_78691914851_item	2875143	et	4	main
veini	doc_78691914851_item	2875144	et	4	main
kord	doc_78691914851_item	2875146	et	4	main
on	doc_78691914851_item	2875150	et	4	main
väga	doc_78691914851_item	2875151	et	3	main
kasjalik	doc_78691914851_item	2875152	et	4	main
säästatud	doc_78691914851_item	2875164	et	4	main
sa	doc_78691914851_item	2875166	et	3	main
kõike	doc_78691914851_item	2875167	et	4	main
seda	doc_78691914851_item	2875168	et	3	main
järgid	doc_78691914851_item	2875169	et	4	main
siis	doc_78691914851_item	2875170	et	3	main
saad	doc_78691914851_item	2875171	et	4	main
on	doc_78691914852_item	2875176	et	4	main
juba	doc_78691914852_item	2875179	et	3	main
meie	doc_78691914852_item	2875182	et	4	main
areneb	doc_78691914852_item	2875185	et	3	main
päevaks	doc_78691914852_item	2875192	et	3	main
meil	doc_78691914852_item	2875193	et	4	main
on	doc_78691914852_item	2875194	et	4	main
kõik	doc_78691914852_item	2875195	et	4	main
mis	doc_78691914852_item	2875196	et	4	main
on	doc_78691914852_item	2875197	et	4	main
vajalik	doc_78691914852_item	2875198	et	3	main
oli	doc_78691914852_item	2875199	et	3	main
teinud	doc_78691914852_item	2875200	et	4	main
väga	doc_78691914852_item	2875201	et	3	main
palju	doc_78691914852_item	2875202	et	4	main
leiutised	doc_78691914852_item	2875203	et	3	main
lennuk	doc_78691914852_item	2875204	et	3	main
oli	doc_78691914852_item	2875205	et	3	main
leiutatud	doc_78691914852_item	2875206	et	4	main
elmise	doc_78691914852_item	2875207	et	4	main
sajandi	doc_78691914852_item	2875208	et	3	main
alguses	doc_78691914852_item	2875209	et	4	main
esialgu	doc_78691914852_item	2875210	et	3	main
nad	doc_78691914852_item	2875211	et	3	main
oli	doc_78691914852_item	2875212	et	3	main
väikesed	doc_78691914852_item	2875213	et	4	main
ja	doc_78691914852_item	2875214	et	3	main
primitiivsed	doc_78691914852_item	2875215	et	3	main
praagu	doc_78691914852_item	2875216	et	4	main
me	doc_78691914852_item	2875217	et	4	main
võime	doc_78691914852_item	2875218	et	4	main
kiiresti	doc_78691914852_item	2875219	et	3	main
alkoholisõltuvust	doc_78691914851_item	2875074	et	4	main
juurde	doc_78691914851_item	2875085	et	4	main
ei	doc_78691914851_item	2875089	et	4	main
on	doc_78691914851_item	2875104	et	4	main
ka	doc_78691914851_item	2875105	et	3	main
me	doc_78691914851_item	2875109	et	4	main
tegema	doc_78691914851_item	2875111	et	3	main
eluiga	doc_78691914851_item	2875114	et	4	main
peavad	doc_78691914851_item	2875117	et	4	main
väga	doc_78691914852_item	2875186	et	3	main
et	doc_78691914852_item	2875190	et	3	main
alustades	doc_78691914852_item	2875229	et	3	main
ilusat	doc_78691914852_item	2875238	et	3	main
tehtud	doc_78691914852_item	2875241	et	4	main
ennast	doc_78691914852_item	2875246	et	4	main
väga	doc_78691914852_item	2875247	et	3	main
pikkal	doc_78691914852_item	2875249	et	4	main
on	doc_78691914852_item	2875254	et	4	main
ilma	doc_78691914852_item	2875256	et	4	main
selleta	doc_78691914852_item	2875257	et	3	main
varsti	doc_78691914852_item	2875258	et	3	main
inimesed	doc_78691914852_item	2875259	et	3	main
ei	doc_78691914852_item	2875260	et	4	main
küljest	doc_78691914852_item	2875264	et	4	main
meie	doc_78691914852_item	2875267	et	4	main
teisest	doc_78691914852_item	2875270	et	4	main
seal	doc_78691914852_item	2875286	et	4	main
võib	doc_78691914852_item	2875287	et	3	main
ka	doc_78691914852_item	2875288	et	3	main
arvan	doc_78691914852_item	2875294	et	3	main
me	doc_78691914852_item	2875302	et	4	main
peame	doc_78691914852_item	2875304	et	4	main
tahame	doc_78691914852_item	2875319	et	3	main
praegu	doc_78691914852_item	2875277	et	3	main
maailm	doc_78691914852_item	2875280	et	3	main
sealt	doc_78691914852_item	2875282	et	4	main
üldse	doc_78691914852_item	2875292	et	3	main
kerge	doc_78691914852_item	2875301	et	4	main
ei	doc_78691914852_item	2875303	et	4	main
me	doc_78691914852_item	2875310	et	4	main
tahame	doc_78691914852_item	2875311	et	3	main
me	doc_78691914852_item	2875318	et	4	main
koristada	doc_78691914852_item	2875320	et	3	main
ja	doc_78691914852_item	2875327	et	3	main
käia	doc_78691914852_item	2875332	et	4	main
pole	doc_78691914852_item	2875337	et	3	main
mitte	doc_78691914852_item	2875339	et	3	main
midagi	doc_78691914852_item	2875340	et	4	main
leiutada	doc_78691914852_item	2875341	et	3	main
aga	doc_78691914852_item	2875342	et	3	main
kontrolltöö	doc_78691914853_item	2875345	et	4	main
või	doc_78691914853_item	2875360	et	4	main
igal	doc_78691914853_item	2875368	et	3	main
või	doc_78691914853_item	2875382	et	4	main
raamatukogust	doc_78691914853_item	2875383	et	4	main
mis	doc_78691914853_item	2875384	et	4	main
asub	doc_78691914853_item	2875385	et	3	main
tõnismäel	doc_78691914853_item	2875386	et	3	main
ei	doc_78691914853_item	2875387	et	4	main
oska	doc_78691914853_item	2875388	et	4	main
öelda	doc_78691914853_item	2875389	et	4	main
kas	doc_78691914853_item	2875390	et	3	main
loevad	doc_78691914853_item	2875391	et	3	main
need	doc_78691914853_item	2875392	et	3	main
paberist	doc_78691914853_item	2875393	et	3	main
või	doc_78691914853_item	2875394	et	4	main
laptopimonitorilt	doc_78691914853_item	2875395	et	4	main
arvan	doc_78691914853_item	2875396	et	3	main
et	doc_78691914853_item	2875397	et	3	main
igaüks	doc_78691914853_item	2875398	et	3	main
valib	doc_78691914853_item	2875399	et	3	main
ise	doc_78691914853_item	2875400	et	4	main
millele	doc_78691914853_item	2875401	et	3	main
peab	doc_78691914853_item	2875402	et	4	main
mõtlema	doc_78691914853_item	2875403	et	3	main
inimene	doc_78691914853_item	2875404	et	3	main
kes	doc_78691914853_item	2875405	et	4	main
asutab	doc_78691914853_item	2875406	et	3	main
oma	doc_78691914853_item	2875407	et	4	main
see	doc_78691914853_item	2875409	et	3	main
peame	doc_78691914852_item	2875330	et	4	main
vaja	doc_78691914852_item	2875338	et	4	main
kirjutasid	doc_78691914853_item	2875357	et	4	main
ikka	doc_78691914853_item	2875362	et	4	main
tuleviku	doc_78691914853_item	2875366	et	4	main
selle	doc_78691914853_item	2875371	et	4	main
kust	doc_78691914853_item	2875374	et	4	main
nad	doc_78691914853_item	2875375	et	3	main
võtavad	doc_78691914853_item	2875376	et	3	main
need	doc_78691914853_item	2875377	et	3	main
kas	doc_78691914853_item	2875378	et	3	main
kirjutada	doc_78691914853_item	2875412	et	3	main
ja	doc_78691914853_item	2875414	et	3	main
on	doc_78691914853_item	2875415	et	4	main
inimene	doc_78691914853_item	2875423	et	3	main
kindlasti	doc_78691914853_item	2875425	et	3	main
oma	doc_78691914853_item	2875427	et	4	main
siis	doc_78691914853_item	2875429	et	3	main
turustamine	doc_78691914853_item	2875438	et	4	main
palju	doc_78691914853_item	2875448	et	4	main
on	doc_78691914853_item	2875451	et	4	main
oleks	doc_78691914853_item	2875454	et	3	main
ka	doc_78691914853_item	2875456	et	3	main
sihtgrupi	doc_78691914853_item	2875458	et	3	main
peale	doc_78691914853_item	2875459	et	4	main
riskid	doc_78691914853_item	2875474	et	4	main
valmis	doc_78691914853_item	2875477	et	4	main
sõltub	doc_78691914854_item	2875481	et	3	main
hakkavad	doc_78691914853_item	2875364	et	4	main
lugema	doc_78691914853_item	2875365	et	4	main
juhul	doc_78691914853_item	2875369	et	3	main
loodan	doc_78691914853_item	2875370	et	3	main
peale	doc_78691914853_item	2875372	et	4	main
aga	doc_78691914853_item	2875373	et	3	main
raamatukogust	doc_78691914853_item	2875381	et	4	main
peab	doc_78691914853_item	2875418	et	4	main
äriplaan	doc_78691914853_item	2875419	et	3	main
sisaldama	doc_78691914853_item	2875420	et	3	main
esiteks	doc_78691914853_item	2875421	et	3	main
neid	doc_78691914853_item	2875435	et	4	main
saavutada	doc_78691914853_item	2875436	et	3	main
partneriga	doc_78691914853_item	2875440	et	4	main
peab	doc_78691914853_item	2875442	et	4	main
selgeks	doc_78691914853_item	2875444	et	3	main
tegema	doc_78691914853_item	2875446	et	3	main
tal	doc_78691914853_item	2875450	et	3	main
ehk	doc_78691914853_item	2875452	et	3	main
käivet	doc_78691914853_item	2875453	et	3	main
teenust	doc_78691914853_item	2875467	et	3	main
oma	doc_78691914853_item	2875473	et	4	main
olla	doc_78691914853_item	2875476	et	3	main
millest	doc_78691914854_item	2875480	et	3	main
tervis	doc_78691914854_item	2875482	et	3	main
inimene	doc_78691914854_item	2875484	et	3	main
elus	doc_78691914854_item	2875517	et	4	main
on	doc_78691914854_item	2875518	et	4	main
armas	doc_78691914854_item	2875519	et	3	main
inimene	doc_78691914854_item	2875520	et	3	main
parem	doc_78691914854_item	2875521	et	4	main
kui	doc_78691914854_item	2875522	et	3	main
see	doc_78691914854_item	2875523	et	3	main
et	doc_78691914854_item	2875535	et	3	main
põhi	doc_78691914854_item	2875538	et	3	main
on	doc_78691914854_item	2875544	et	4	main
ta	doc_78691914854_item	2875553	et	4	main
parem	doc_78691914854_item	2875557	et	4	main
parem	doc_78691914854_item	2875571	et	4	main
toituda	doc_78691914854_item	2875572	et	3	main
jõukas	doc_78691914854_item	2875575	et	4	main
endale	doc_78691914854_item	2875579	et	4	main
siis	doc_78691914854_item	2875587	et	3	main
elustiilist	doc_78691914854_item	2875596	et	4	main
kui	doc_78691914854_item	2875597	et	3	main
kui	doc_78691914854_item	2875602	et	3	main
umbes	doc_78691914854_item	2875603	et	4	main
on	doc_78691914854_item	2875628	et	4	main
öelda	doc_78691914854_item	2875633	et	4	main
siis	doc_78691914854_item	2875639	et	3	main
hea	doc_78691914854_item	2875643	et	4	main
ja	doc_78691914854_item	2875649	et	3	main
parem	doc_78691914854_item	2875650	et	4	main
mida	doc_788097534636_item	2875654	et	4	main
tähendab	doc_788097534636_item	2875655	et	3	main
sotsialistlik	doc_788097534636_item	2875656	et	3	main
realism	doc_788097534636_item	2875657	et	3	main
tooge	doc_788097534636_item	2875658	et	3	main
on	doc_788097534636_item	2875661	et	4	main
kirjandusstiil	doc_788097534636_item	2875662	et	3	main
sotsialistlik	doc_788097534636_item	2875663	et	3	main
on	doc_788097534636_item	2875666	et	4	main
mis	doc_788097534636_item	2875668	et	4	main
pidi	doc_788097534636_item	2875669	et	4	main
ei	doc_788097534636_item	2875675	et	4	main
sellest	doc_788097534636_item	2875677	et	4	main
smuul	doc_788097534636_item	2875697	et	4	main
oli	doc_788097534636_item	2875699	et	3	main
stalini	doc_788097534636_item	2875703	et	4	main
teemaks	doc_788097534636_item	2875706	et	4	main
tollases	doc_788097534636_item	2875707	et	3	main
kirjanduses	doc_788097534636_item	2875708	et	3	main
oli	doc_788097534636_item	2875709	et	3	main
võitlus	doc_788097534636_item	2875710	et	3	main
kodaniku	doc_788097534636_item	2875711	et	3	main
imperialismiga	doc_788097534636_item	2875712	et	3	main
ja	doc_788097534636_item	2875713	et	3	main
kodaniku	doc_788097534636_item	2875714	et	3	main
ajal	doc_788097534636_item	2875717	et	4	main
olid	doc_788097534636_item	2875729	et	4	main
poeem	doc_788097534636_item	2875730	et	3	main
smuul	doc_788097534636_item	2875736	et	4	main
ja	doc_788097534636_item	2875737	et	3	main
drama	doc_788097534636_item	2875738	et	4	main
inimene	doc_78691914853_item	2875410	et	3	main
äriplaani	doc_78691914853_item	2875413	et	4	main
see	doc_78691914853_item	2875422	et	3	main
peab	doc_78691914853_item	2875424	et	4	main
eesmärgid	doc_78691914853_item	2875428	et	3	main
näiteks	doc_78691914853_item	2875437	et	4	main
jne	doc_78691914853_item	2875441	et	4	main
endale	doc_78691914853_item	2875445	et	4	main
kui	doc_78691914853_item	2875447	et	3	main
kelle	doc_78691914853_item	2875460	et	4	main
jaoks	doc_78691914853_item	2875461	et	4	main
ta	doc_78691914853_item	2875462	et	4	main
toodab	doc_78691914853_item	2875463	et	3	main
mingit	doc_78691914853_item	2875464	et	3	main
toodet	doc_78691914853_item	2875465	et	3	main
või	doc_78691914853_item	2875466	et	4	main
lõpuks	doc_78691914853_item	2875469	et	4	main
ka	doc_78691914853_item	2875471	et	3	main
selgitada	doc_78691914853_item	2875472	et	3	main
probleemid	doc_78691914853_item	2875478	et	3	main
tahab	doc_78691914854_item	2875485	et	3	main
et	doc_78691914854_item	2875486	et	3	main
tal	doc_78691914854_item	2875487	et	3	main
oleks	doc_78691914854_item	2875488	et	3	main
hea	doc_78691914854_item	2875489	et	4	main
tervis	doc_78691914854_item	2875490	et	3	main
ning	doc_78691914854_item	2875491	et	3	main
ta	doc_78691914854_item	2875492	et	4	main
elaks	doc_78691914854_item	2875493	et	3	main
100-aastaseks	doc_78691914854_item	2875494	et	4	main
aga	doc_78691914854_item	2875495	et	3	main
millest	doc_78691914854_item	2875496	et	3	main
sõltub	doc_78691914854_item	2875497	et	3	main
meie	doc_78691914854_item	2875498	et	4	main
tervis	doc_78691914854_item	2875499	et	3	main
ma	doc_78691914854_item	2875500	et	3	main
olen	doc_78691914854_item	2875501	et	3	main
nõus	doc_78691914854_item	2875502	et	4	main
et	doc_78691914854_item	2875503	et	3	main
elustiilist	doc_78691914854_item	2875504	et	4	main
kõigepealt	doc_78691914854_item	2875505	et	3	main
see	doc_78691914854_item	2875506	et	3	main
on	doc_78691914854_item	2875507	et	4	main
pere	doc_78691914854_item	2875508	et	4	main
me	doc_78691914854_item	2875509	et	4	main
teame	doc_78691914854_item	2875510	et	3	main
kui	doc_78691914854_item	2875511	et	3	main
peres	doc_78691914854_item	2875512	et	3	main
on	doc_78691914854_item	2875513	et	4	main
korras	doc_78691914854_item	2875514	et	4	main
firma	doc_78691914853_item	2875408	et	4	main
võiks	doc_78691914853_item	2875411	et	4	main
on	doc_78691914854_item	2875516	et	4	main
abikaasa	doc_78691914854_item	2875525	et	4	main
lapsed	doc_78691914854_item	2875526	et	3	main
on	doc_78691914854_item	2875527	et	4	main
terved	doc_78691914854_item	2875528	et	4	main
siis	doc_78691914854_item	2875529	et	3	main
inimene	doc_78691914854_item	2875530	et	3	main
elab	doc_78691914854_item	2875531	et	3	main
see	doc_78691914854_item	2875536	et	3	main
minu	doc_78691914854_item	2875539	et	3	main
edasi	doc_78691914854_item	2875547	et	3	main
on	doc_78691914854_item	2875554	et	4	main
huvitav	doc_78691914854_item	2875561	et	4	main
loomulikult	doc_78691914854_item	2875562	et	4	main
inimene	doc_78691914854_item	2875576	et	3	main
igapäevasest	doc_78691914854_item	2875595	et	4	main
hea	doc_78691914854_item	2875601	et	4	main
kas	doc_78691914854_item	2875606	et	3	main
tegeleme	doc_78691914854_item	2875607	et	3	main
spordi	doc_78691914854_item	2875608	et	4	main
tundi	doc_78691914854_item	2875605	et	4	main
kas	doc_78691914854_item	2875609	et	3	main
suitsetame	doc_78691914854_item	2875610	et	3	main
teisest	doc_78691914854_item	2875611	et	4	main
küljest	doc_78691914854_item	2875612	et	4	main
mõjub	doc_78691914854_item	2875613	et	3	main
tervisele	doc_78691914854_item	2875614	et	3	main
geneetiline	doc_78691914854_item	2875615	et	3	main
soodumus	doc_78691914854_item	2875616	et	3	main
kui	doc_78691914854_item	2875617	et	3	main
teie	doc_78691914854_item	2875618	et	4	main
sugulased	doc_78691914854_item	2875619	et	3	main
elavad	doc_78691914854_item	2875620	et	4	main
ja	doc_78691914854_item	2875622	et	3	main
haigeks	doc_78691914854_item	2875625	et	4	main
siis	doc_78691914854_item	2875626	et	3	main
teil	doc_78691914854_item	2875627	et	4	main
lõpus	doc_78691914854_item	2875631	et	4	main
tahan	doc_78691914854_item	2875632	et	3	main
kui	doc_78691914854_item	2875635	et	3	main
on	doc_78691914854_item	2875637	et	4	main
elu	doc_78691914854_item	2875640	et	4	main
ka	doc_78691914854_item	2875642	et	3	main
ning	doc_78691914854_item	2875644	et	3	main
on	doc_78691914854_item	2875646	et	4	main
kauem	doc_78691914854_item	2875648	et	4	main
näiteid	doc_788097534636_item	2875659	et	3	main
olema	doc_788097534636_item	2875670	et	4	main
oli	doc_788097534636_item	2875702	et	3	main
vene	doc_788097534636_item	2875721	et	4	main
poeetidest	doc_788097534636_item	2875733	et	3	main
jakobson	doc_788097534636_item	2875741	et	4	main
l	doc_788097534636_item	2875753	et	4	main
koidula	doc_788097534636_item	2875754	et	4	main
fr	doc_788097534636_item	2875756	et	4	main
r	doc_788097534636_item	2875757	et	4	main
kreutzwald	doc_788097534636_item	2875758	et	4	main
nad	doc_788097534636_item	2875759	et	3	main
te	doc_792821541744_item	2875771	et	4	main
plaanite	doc_792821541744_item	2875772	et	3	main
eestlasest	doc_792821541744_item	2875779	et	3	main
sõna	doc_792821541744_item	2875804	et	4	main
puhkus	doc_792821541744_item	2875826	et	3	main
venemaale	doc_792821541744_item	2875832	et	4	main
ta	doc_792821541744_item	2875836	et	4	main
me	doc_792821541744_item	2875848	et	4	main
hakkame	doc_792821541744_item	2875849	et	3	main
elada	doc_792821541744_item	2875850	et	3	main
ma	doc_792821541744_item	2875853	et	3	main
vanemad	doc_78691914854_item	2875515	et	4	main
kauem	doc_78691914854_item	2875532	et	4	main
minu	doc_78691914854_item	2875545	et	3	main
kindlus	doc_78691914854_item	2875546	et	4	main
läheb	doc_78691914854_item	2875548	et	3	main
ja	doc_78691914854_item	2875556	et	3	main
on	doc_78691914854_item	2875569	et	4	main
võimalus	doc_78691914854_item	2875570	et	3	main
puhata	doc_78691914854_item	2875574	et	4	main
võib	doc_78691914854_item	2875577	et	3	main
vitamiine	doc_78691914854_item	2875580	et	3	main
kui	doc_78691914854_item	2875583	et	3	main
haige	doc_78691914854_item	2875586	et	4	main
ostab	doc_78691914854_item	2875588	et	3	main
ravimit	doc_78691914854_item	2875590	et	3	main
veel	doc_78691914854_item	2875591	et	4	main
tervis	doc_78691914854_item	2875592	et	3	main
sõltub	doc_78691914854_item	2875593	et	3	main
magame	doc_78691914854_item	2875600	et	3	main
8	doc_78691914854_item	2875604	et	2	main
üldse	doc_78691914854_item	2875555	et	3	main
kui	doc_78691914854_item	2875558	et	3	main
töö	doc_78691914854_item	2875559	et	4	main
on	doc_78691914854_item	2875560	et	4	main
kui	doc_78691914854_item	2875563	et	3	main
töötasu	doc_78691914854_item	2875564	et	4	main
on	doc_78691914854_item	2875565	et	4	main
suur	doc_78691914854_item	2875566	et	3	main
siis	doc_78691914854_item	2875567	et	3	main
inimesel	doc_78691914854_item	2875568	et	3	main
ja	doc_78691914854_item	2875573	et	3	main
osta	doc_78691914854_item	2875578	et	4	main
kasulikuid	doc_78691914854_item	2875581	et	4	main
toidulisaid	doc_78691914854_item	2875582	et	4	main
meie	doc_78691914854_item	2875594	et	4	main
jäi	doc_78691914854_item	2875624	et	3	main
kõik	doc_78691914854_item	2875636	et	4	main
hea	doc_78691914854_item	2875638	et	4	main
tervis	doc_78691914854_item	2875645	et	3	main
kontrolltöö	doc_788097534636_item	2875652	et	4	main
4	doc_788097534636_item	2875653	et	2	main
see	doc_788097534636_item	2875665	et	3	main
kirjutanud	doc_788097534636_item	2875676	et	4	main
pühendatud	doc_788097534636_item	2875700	et	4	main
keskseks	doc_788097534636_item	2875704	et	4	main
tähtsaks	doc_788097534636_item	2875705	et	4	main
stalinismi	doc_788097534636_item	2875716	et	4	main
ilmusid	doc_788097534636_item	2875718	et	4	main
põhiliselt	doc_788097534636_item	2875719	et	4	main
tõlked	doc_788097534636_item	2875720	et	3	main
ta	doc_78691914854_item	2875584	et	4	main
jäib	doc_78691914854_item	2875585	et	4	main
head	doc_78691914854_item	2875589	et	4	main
kaua	doc_78691914854_item	2875598	et	3	main
me	doc_78691914854_item	2875599	et	4	main
kaua	doc_78691914854_item	2875621	et	3	main
ei	doc_78691914854_item	2875623	et	4	main
hea	doc_78691914854_item	2875629	et	4	main
põhibr	doc_78691914854_item	2875630	et	4	main
hea	doc_78691914854_item	2875634	et	4	main
on	doc_78691914854_item	2875641	et	4	main
elage	doc_78691914854_item	2875647	et	3	main
p	doc_78691914854_item	2875651	et	4	main
see	doc_788097534636_item	2875660	et	3	main
realism	doc_788097534636_item	2875664	et	3	main
kirjandus	doc_788097534636_item	2875667	et	3	main
parteine	doc_788097534636_item	2875671	et	4	main
ideeline	doc_788097534636_item	2875672	et	4	main
rahvalik	doc_788097534636_item	2875673	et	3	main
kirjanikud	doc_788097534636_item	2875674	et	3	main
mis	doc_788097534636_item	2875678	et	4	main
nendele	doc_788097534636_item	2875679	et	4	main
meeldib	doc_788097534636_item	2875680	et	3	main
vaid	doc_788097534636_item	2875681	et	3	main
olid	doc_788097534636_item	2875682	et	4	main
konkreetsed	doc_788097534636_item	2875683	et	3	main
teemad	doc_788097534636_item	2875684	et	3	main
millest	doc_788097534636_item	2875685	et	3	main
oli	doc_788097534636_item	2875686	et	3	main
vaja	doc_788097534636_item	2875687	et	4	main
kirjutada	doc_788097534636_item	2875688	et	3	main
poeemide	doc_788097534636_item	2875689	et	3	main
pealkirjad	doc_788097534636_item	2875690	et	3	main
näiteks	doc_788097534636_item	2875692	et	4	main
olid	doc_788097534636_item	2875691	et	4	main
mina	doc_788097534636_item	2875693	et	4	main
kommunistlik	doc_788097534636_item	2875694	et	3	main
noor	doc_788097534636_item	2875695	et	3	main
j	doc_788097534636_item	2875696	et	4	main
stalinile	doc_788097534636_item	2875701	et	4	main
natsionalismiga	doc_788097534636_item	2875715	et	3	main
keelest	doc_788097534636_item	2875722	et	4	main
võõrkeelest	doc_788097534636_item	2875723	et	4	main
kirjandust	doc_788097534636_item	2875724	et	3	main
ja	doc_788097534636_item	2875731	et	3	main
draama	doc_788097534636_item	2875732	et	4	main
domineerisid	doc_788097534636_item	2875734	et	4	main
juhan	doc_788097534636_item	2875735	et	3	main
romaane	doc_788097534636_item	2875742	et	3	main
ei	doc_788097534636_item	2875744	et	4	main
ainult	doc_788097534636_item	2875746	et	4	main
kaks	doc_788097534636_item	2875747	et	3	main
nõukogude	doc_788097534636_item	2875751	et	3	main
ajal	doc_788097534636_item	2875752	et	4	main
olid	doc_788097534636_item	2875760	et	4	main
sees	doc_788097534636_item	2875762	et	4	main
kirjandus	doc_788097534636_item	2875763	et	3	main
oli	doc_788097534636_item	2875764	et	3	main
allutatud	doc_788097534636_item	2875765	et	4	main
parteikontrollile	doc_788097534636_item	2875766	et	3	main
oli	doc_788097534636_item	2875767	et	3	main
venemaale	doc_792821541744_item	2875774	et	4	main
kiri	doc_792821541744_item	2875777	et	3	main
kirjutage	doc_792821541744_item	2875781	et	3	main
ja	doc_792821541744_item	2875783	et	3	main
kuhu	doc_792821541744_item	2875784	et	3	main
sõita	doc_792821541744_item	2875786	et	3	main
te	doc_792821541744_item	2875785	et	4	main
soovite	doc_792821541744_item	2875787	et	3	main
milelga	doc_792821541744_item	2875788	et	4	main
reisite	doc_792821541744_item	2875789	et	3	main
kus	doc_792821541744_item	2875790	et	3	main
ööbite	doc_792821541744_item	2875791	et	3	main
kui	doc_792821541744_item	2875792	et	3	main
see	doc_792821541744_item	2875794	et	3	main
maksab	doc_792821541744_item	2875795	et	3	main
millistes	doc_792821541744_item	2875796	et	3	main
palju	doc_792821541744_item	2875793	et	4	main
kohtades	doc_792821541744_item	2875797	et	3	main
peatute	doc_792821541744_item	2875798	et	4	main
kirja	doc_792821541744_item	2875799	et	4	main
nõutav	doc_792821541744_item	2875800	et	4	main
pikkus	doc_792821541744_item	2875801	et	4	main
kirjandus	doc_788097534636_item	2875698	et	3	main
ei	doc_788097534636_item	2875725	et	4	main
ilmunud	doc_788097534636_item	2875726	et	4	main
peamised	doc_788097534636_item	2875727	et	3	main
kirjandusžanrid	doc_788097534636_item	2875728	et	2	main
august	doc_788097534636_item	2875740	et	4	main
praktiliselt	doc_788097534636_item	2875743	et	4	main
kirjanikut	doc_788097534636_item	2875748	et	4	main
lubatud	doc_788097534636_item	2875750	et	4	main
ja	doc_788097534636_item	2875755	et	3	main
tugev	doc_788097534636_item	2875768	et	4	main
tsensuur	doc_788097534636_item	2875769	et	3	main
kiri	doc_792821541744_item	2875770	et	3	main
kirjutage	doc_792821541744_item	2875775	et	3	main
oma	doc_792821541744_item	2875778	et	4	main
sõbrale	doc_792821541744_item	2875780	et	3	main
umbes	doc_792821541744_item	2875802	et	4	main
väga	doc_792821541744_item	2875813	et	3	main
kirjanikest	doc_788097534636_item	2875739	et	3	main
ilmunud	doc_788097534636_item	2875745	et	4	main
olid	doc_788097534636_item	2875749	et	4	main
kooliprogrammi	doc_788097534636_item	2875761	et	4	main
reisi	doc_792821541744_item	2875773	et	4	main
sellest	doc_792821541744_item	2875776	et	4	main
millal	doc_792821541744_item	2875782	et	3	main
tere	doc_792821541744_item	2875805	et	3	main
jutta	doc_792821541744_item	2875807	et	4	main
sain	doc_792821541744_item	2875808	et	3	main
sinu	doc_792821541744_item	2875809	et	3	main
kirja	doc_792821541744_item	2875810	et	4	main
sa	doc_792821541744_item	2875815	et	3	main
ma	doc_792821541744_item	2875818	et	3	main
ma	doc_792821541744_item	2875820	et	3	main
pere	doc_792821541744_item	2875830	et	4	main
sõita	doc_792821541744_item	2875831	et	3	main
juure	doc_792821541744_item	2875835	et	3	main
meid	doc_792821541744_item	2875838	et	4	main
märtsis	doc_792821541744_item	2875842	et	3	main
elavad	doc_792821541744_item	2875844	et	4	main
linnas	doc_792821541744_item	2875846	et	4	main
ja	doc_792821541744_item	2875851	et	3	main
mõtlen	doc_792821541744_item	2875854	et	3	main
juulis	doc_792821541744_item	2875859	et	3	main
kiiresti	doc_792821541744_item	2875863	et	3	main
kallist	doc_792821541744_item	2875867	et	4	main
sinu	doc_792821541744_item	2875898	et	3	main
riigid	doc_792821541746_item	2876139	et	3	main
on	doc_792821541746_item	2876141	et	4	main
seotud	doc_792821541746_item	2876142	et	4	main
praegu	doc_792821541746_item	2876143	et	3	main
oma	doc_792821541746_item	2876152	et	4	main
jaoks	doc_792821541746_item	2876156	et	4	main
meie	doc_792821541746_item	2876157	et	4	main
looduse	doc_792821541746_item	2876161	et	4	main
meie	doc_792821541746_item	2876166	et	4	main
riik	doc_792821541746_item	2876167	et	3	main
näiteks	doc_792821541746_item	2876172	et	4	main
filtrid	doc_792821541746_item	2876176	et	4	main
meie	doc_792821541746_item	2876204	et	4	main
töötlemise	doc_792821541746_item	2876210	et	4	main
ka	doc_792821541746_item	2876223	et	3	main
selle	doc_792821541746_item	2876234	et	4	main
80	doc_792821541744_item	2875803	et	2	main
kallis	doc_792821541744_item	2875806	et	4	main
rõõmustasin	doc_792821541744_item	2875814	et	3	main
kuidas	doc_792821541744_item	2875817	et	3	main
elan	doc_792821541744_item	2875819	et	3	main
elan	doc_792821541744_item	2875821	et	3	main
hästi	doc_792821541744_item	2875822	et	3	main
meil	doc_792821541744_item	2875824	et	4	main
me	doc_792821541744_item	2875827	et	4	main
minu	doc_792821541744_item	2875833	et	3	main
ootab	doc_792821541744_item	2875837	et	3	main
külla	doc_792821541744_item	2875839	et	4	main
kutsus	doc_792821541744_item	2875840	et	4	main
seal	doc_792821541744_item	2875847	et	4	main
et	doc_792821541744_item	2875855	et	3	main
keskel	doc_792821541744_item	2875858	et	3	main
väga	doc_792821541744_item	2875862	et	3	main
kokku	doc_792821541744_item	2875868	et	3	main
pärast	doc_792821541744_item	2875874	et	4	main
me	doc_792821541744_item	2875875	et	4	main
tahame	doc_792821541744_item	2875876	et	3	main
sõita	doc_792821541744_item	2875877	et	3	main
puhata	doc_792821541744_item	2875878	et	4	main
sanatoorium	doc_792821541744_item	2875879	et	3	main
ongi	doc_792821541744_item	2875880	et	4	main
kõik	doc_792821541744_item	2875881	et	4	main
peatume	doc_792821541744_item	2875882	et	4	main
veel	doc_792821541744_item	2875883	et	4	main
mitmme	doc_792821541744_item	2875884	et	4	main
kohtades	doc_792821541744_item	2875885	et	3	main
veel	doc_792821541744_item	2875886	et	4	main
ei	doc_792821541744_item	2875887	et	4	main
tea	doc_792821541744_item	2875888	et	4	main
kus	doc_792821541744_item	2875889	et	3	main
seal	doc_792821541744_item	2875890	et	4	main
täna	doc_792821541744_item	2875811	et	4	main
ma	doc_792821541744_item	2875812	et	3	main
küsid	doc_792821541744_item	2875816	et	3	main
varsti	doc_792821541744_item	2875823	et	3	main
hakkab	doc_792821541744_item	2875825	et	3	main
tahaksime	doc_792821541744_item	2875828	et	3	main
kogu	doc_792821541744_item	2875829	et	4	main
venna	doc_792821541744_item	2875834	et	3	main
veel	doc_792821541744_item	2875841	et	4	main
nad	doc_792821541744_item	2875843	et	3	main
moskva	doc_792821541744_item	2875845	et	4	main
ööbime	doc_792821541744_item	2875852	et	3	main
sõitame	doc_792821541744_item	2875857	et	4	main
see	doc_792821541744_item	2875861	et	3	main
maksab	doc_792821541744_item	2875865	et	3	main
sada	doc_792821541744_item	2875869	et	4	main
krooni	doc_792821541744_item	2875870	et	4	main
1	doc_792821541744_item	2875871	et	2	main
pileti	doc_792821541744_item	2875872	et	3	main
eest	doc_792821541744_item	2875873	et	4	main
otsustame	doc_792821541744_item	2875891	et	3	main
seekord	doc_792821541744_item	2875892	et	3	main
sinult	doc_792821541744_item	2875895	et	3	main
me	doc_792821541744_item	2875856	et	4	main
rongiga	doc_792821541744_item	2875860	et	4	main
ja	doc_792821541744_item	2875864	et	3	main
nägemiseni	doc_792821541744_item	2875897	et	4	main
marina	doc_792821541744_item	2875900	et	3	main
mitte	doc_792821541744_item	2875866	et	3	main
lõpetan	doc_792821541744_item	2875893	et	3	main
vastus	doc_792821541744_item	2875896	et	3	main
sõbranna	doc_792821541744_item	2875899	et	4	main
ootame	doc_792821541744_item	2875894	et	3	main
arvamus	doc_792821541746_item	2876118	et	3	main
kuidas	doc_792821541746_item	2876119	et	3	main
aktsiooniga	doc_792821541746_item	2876124	et	3	main
elu	doc_792821541746_item	2876125	et	4	main
kaitsealad	doc_792821541746_item	2876126	et	3	main
paar	doc_792821541746_item	2876127	et	3	main
aastat	doc_792821541746_item	2876128	et	3	main
tagasi	doc_792821541746_item	2876129	et	3	main
sai	doc_792821541746_item	2876131	et	4	main
nagu	doc_792821541746_item	2876136	et	3	main
ta	doc_792821541746_item	2876140	et	4	main
elu	doc_792821541746_item	2876146	et	4	main
looduse	doc_792821541746_item	2876154	et	4	main
loodus	doc_792821541746_item	2876158	et	4	main
ravimise	doc_792821541746_item	2876162	et	4	main
ja	doc_792821541746_item	2876163	et	3	main
võttab	doc_792821541746_item	2876168	et	4	main
spetsiaalsed	doc_792821541746_item	2876175	et	3	main
sellepärast	doc_792821541746_item	2876192	et	3	main
ilma	doc_792821541746_item	2876194	et	4	main
lahendatakse	doc_792821541746_item	2876208	et	3	main
meie	doc_792821541746_item	2876220	et	4	main
on	doc_792821541746_item	2876222	et	4	main
sellepärast	doc_792821541746_item	2876228	et	3	main
õitseb	doc_792821541746_item	2876230	et	4	main
ja	doc_792821541746_item	2876231	et	3	main
muutub	doc_792821541746_item	2876232	et	3	main
soiseks	doc_792821541746_item	2876233	et	4	main
veekogud	doc_792821541746_item	2876237	et	3	main
puhastakse	doc_792821541746_item	2876238	et	3	main
loodus	doc_792821541746_item	2876243	et	4	main
säiliks	doc_792821541746_item	2876244	et	3	main
põlvadele	doc_792821541746_item	2876246	et	4	main
ja	doc_792821541746_item	2876247	et	3	main
ma	doc_792821541746_item	2876248	et	3	main
mõtlen	doc_792821541746_item	2876249	et	3	main
et	doc_792821541746_item	2876250	et	3	main
see	doc_792821541746_item	2876251	et	3	main
on	doc_792821541746_item	2876252	et	4	main
küsimusele	doc_798444340112_item	2876256	et	4	main
kuidas	doc_798444340112_item	2876279	et	3	main
ma	doc_798444340112_item	2876284	et	3	main
hästi	doc_798444340112_item	2876287	et	3	main
eriti	doc_798444340112_item	2876288	et	3	main
sa	doc_798444340112_item	2876301	et	3	main
et	doc_798444340112_item	2876318	et	3	main
õppimine	doc_798444340112_item	2876319	et	4	main
on	doc_798444340112_item	2876320	et	4	main
eesti	doc_792821541746_item	2876121	et	4	main
seotud	doc_792821541746_item	2876122	et	4	main
üleeuroopalise	doc_792821541746_item	2876123	et	4	main
teised	doc_792821541746_item	2876137	et	4	main
euroopa	doc_792821541746_item	2876138	et	4	main
kaitsealad	doc_792821541746_item	2876147	et	3	main
eestis	doc_792821541746_item	2876148	et	3	main
hakatakse	doc_792821541746_item	2876149	et	3	main
rohkem	doc_792821541746_item	2876150	et	4	main
mõtlema	doc_792821541746_item	2876151	et	3	main
kaitsmise	doc_792821541746_item	2876155	et	4	main
on	doc_792821541746_item	2876159	et	4	main
kaitsmise	doc_792821541746_item	2876164	et	4	main
erinevaid	doc_792821541746_item	2876169	et	4	main
abinõusid	doc_792821541746_item	2876170	et	3	main
suurettevõtetele	doc_792821541746_item	2876173	et	3	main
et	doc_792821541746_item	2876177	et	3	main
ohtlikud	doc_792821541746_item	2876178	et	3	main
ained	doc_792821541746_item	2876179	et	3	main
ei	doc_792821541746_item	2876180	et	4	main
saastaks	doc_792821541746_item	2876181	et	4	main
õhu	doc_792821541746_item	2876182	et	3	main
suurte	doc_792821541746_item	2876183	et	3	main
autode	doc_792821541746_item	2876184	et	3	main
hulka	doc_792821541746_item	2876185	et	4	main
meie	doc_792821541746_item	2876187	et	4	main
poolt	doc_792821541746_item	2876186	et	4	main
õhk	doc_792821541746_item	2876188	et	3	main
on	doc_792821541746_item	2876189	et	4	main
saastatud	doc_792821541746_item	2876190	et	4	main
on	doc_792821541746_item	2876120	et	4	main
eesti	doc_792821541746_item	2876130	et	4	main
euroopa	doc_792821541746_item	2876132	et	4	main
liidu	doc_792821541746_item	2876133	et	3	main
liikmeks	doc_792821541746_item	2876134	et	3	main
ja	doc_792821541746_item	2876135	et	3	main
üleeuroopalise	doc_792821541746_item	2876144	et	4	main
aktsiooniga	doc_792821541746_item	2876145	et	3	main
keskkonnast	doc_792821541746_item	2876153	et	4	main
saastatud	doc_792821541746_item	2876160	et	4	main
jaoks	doc_792821541746_item	2876165	et	4	main
enne	doc_792821541746_item	2876171	et	4	main
pannakse	doc_792821541746_item	2876174	et	3	main
heitgaasiga	doc_792821541746_item	2876191	et	4	main
toimuvad	doc_792821541746_item	2876196	et	4	main
euuropas	doc_792821541746_item	2876197	et	4	main
iga	doc_792821541746_item	2876198	et	4	main
aastal	doc_792821541746_item	2876199	et	3	main
ja	doc_792821541746_item	2876200	et	3	main
see	doc_792821541746_item	2876201	et	3	main
aitab	doc_792821541746_item	2876202	et	3	main
puhastada	doc_792821541746_item	2876203	et	3	main
veel	doc_792821541746_item	2876207	et	4	main
prügi	doc_792821541746_item	2876214	et	4	main
kastid	doc_792821541746_item	2876215	et	3	main
klaasile	doc_792821541746_item	2876216	et	3	main
ja	doc_792821541746_item	2876217	et	3	main
plastikule	doc_792821541746_item	2876218	et	3	main
veekogud	doc_792821541746_item	2876221	et	3	main
reostatud	doc_792821541746_item	2876224	et	4	main
ohtlikute	doc_792821541746_item	2876225	et	4	main
ainetega	doc_792821541746_item	2876226	et	3	main
vesi	doc_792821541746_item	2876229	et	4	main
lahendamiseks	doc_792821541746_item	2876236	et	4	main
palju	doc_792821541746_item	2876241	et	4	main
ainult	doc_792821541746_item	2876253	et	4	main
algus	doc_792821541746_item	2876254	et	4	main
vastus	doc_798444340112_item	2876255	et	3	main
praegu	doc_798444340112_item	2876282	et	3	main
üsna	doc_798444340112_item	2876286	et	3	main
õppeala	doc_798444340112_item	2876290	et	4	main
kuidas	doc_798444340112_item	2876300	et	3	main
varem	doc_798444340112_item	2876302	et	4	main
varem	doc_798444340112_item	2876304	et	4	main
ma	doc_798444340112_item	2876305	et	3	main
õppisin	doc_798444340112_item	2876306	et	3	main
mitte	doc_798444340112_item	2876307	et	3	main
eriti	doc_798444340112_item	2876308	et	3	main
hästi	doc_798444340112_item	2876309	et	3	main
vaja	doc_798444340112_item	2876321	et	4	main
minu	doc_798444340112_item	2876322	et	3	main
mis	doc_798444340112_item	2876329	et	4	main
arvates	doc_798444340112_item	2876336	et	4	main
peamine	doc_798444340112_item	2876338	et	3	main
õppetöös	doc_798444340112_item	2876339	et	3	main
ja	doc_798444340112_item	2876341	et	3	main
usk	doc_798444340112_item	2876342	et	3	main
oma	doc_798444340112_item	2876343	et	4	main
eesmärgid	doc_798444340112_item	2876354	et	3	main
tööd	doc_798444340112_item	2876359	et	4	main
veel	doc_798444340112_item	2876361	et	4	main
materiaali	doc_798444340112_item	2876366	et	4	main
kui	doc_798444340112_item	2876370	et	3	main
rohkem	doc_798444340112_item	2876373	et	4	main
enda	doc_798444340112_item	2876381	et	4	main
püstisasid	doc_798444340112_item	2876383	et	4	main
ma	doc_798444340112_item	2876384	et	3	main
sisse	doc_798444340112_item	2876396	et	4	main
astuda	doc_798444340112_item	2876397	et	3	main
see	doc_798444340112_item	2876398	et	3	main
segavad	doc_798444340112_item	2876425	et	4	main
koduneülesandeid	doc_798444340112_item	2876428	et	4	main
on	doc_798444340112_item	2876431	et	4	main
8	doc_798444340112_item	2876433	et	2	main
sa	doc_798444340112_item	2876435	et	3	main
tulevikus	doc_798444340112_item	2876443	et	4	main
ma	doc_798444340112_item	2876444	et	3	main
päevad	doc_792821541746_item	2876193	et	3	main
autodeta	doc_792821541746_item	2876195	et	3	main
õhku	doc_792821541746_item	2876205	et	4	main
natukene	doc_792821541746_item	2876206	et	4	main
jäätmede	doc_792821541746_item	2876209	et	4	main
probleem	doc_792821541746_item	2876211	et	3	main
paigaldakse	doc_792821541746_item	2876212	et	4	main
spetsiaalsed	doc_792821541746_item	2876213	et	3	main
tahan	doc_798444340112_item	2876263	et	3	main
õppida	doc_798444340112_item	2876264	et	3	main
et	doc_798444340112_item	2876265	et	3	main
saada	doc_798444340112_item	2876266	et	4	main
edukaks	doc_798444340112_item	2876267	et	3	main
ja	doc_798444340112_item	2876268	et	3	main
isesesvuslikuks	doc_798444340112_item	2876269	et	4	main
inimeseks	doc_798444340112_item	2876270	et	3	main
saada	doc_798444340112_item	2876271	et	4	main
head	doc_798444340112_item	2876272	et	4	main
tööd	doc_798444340112_item	2876273	et	4	main
ja	doc_798444340112_item	2876274	et	3	main
suhelda	doc_798444340112_item	2876275	et	4	main
huvitavate	doc_798444340112_item	2876276	et	4	main
lisaks	doc_792821541746_item	2876219	et	4	main
ja	doc_792821541746_item	2876227	et	3	main
probleemi	doc_792821541746_item	2876235	et	4	main
teeb	doc_792821541746_item	2876240	et	3	main
et	doc_792821541746_item	2876242	et	3	main
tulevastele	doc_792821541746_item	2876245	et	4	main
1	doc_798444340112_item	2876257	et	2	main
miks	doc_798444340112_item	2876258	et	4	main
ma	doc_798444340112_item	2876259	et	3	main
tahan	doc_798444340112_item	2876260	et	3	main
õppida	doc_798444340112_item	2876261	et	3	main
ma	doc_798444340112_item	2876262	et	3	main
2	doc_798444340112_item	2876278	et	2	main
õpid	doc_798444340112_item	2876281	et	4	main
praegu	doc_798444340112_item	2876283	et	3	main
mis	doc_798444340112_item	2876293	et	4	main
jaoks	doc_798444340112_item	2876327	et	4	main
4	doc_798444340112_item	2876328	et	2	main
õppetöös	doc_798444340112_item	2876334	et	3	main
minu	doc_798444340112_item	2876335	et	3	main
on	doc_798444340112_item	2876347	et	4	main
sinu	doc_798444340112_item	2876348	et	3	main
peamised	doc_798444340112_item	2876349	et	3	main
õppe-eesmärgid	doc_798444340112_item	2876350	et	3	main
minu	doc_798444340112_item	2876351	et	3	main
peamised	doc_798444340112_item	2876352	et	3	main
õppe-	doc_798444340112_item	2876353	et	4	main
vajalikut	doc_798444340112_item	2876358	et	4	main
saada	doc_798444340112_item	2876365	et	4	main
teada	doc_798444340112_item	2876369	et	3	main
võimalik	doc_798444340112_item	2876372	et	3	main
6	doc_798444340112_item	2876377	et	2	main
hästi	doc_798444340112_item	2876388	et	3	main
saada	doc_798444340112_item	2876391	et	4	main
suhted	doc_798444340112_item	2876422	et	3	main
sest	doc_798444340112_item	2876423	et	4	main
nad	doc_798444340112_item	2876424	et	3	main
mulle	doc_798444340112_item	2876426	et	4	main
see	doc_798444340112_item	2876430	et	3	main
näed	doc_798444340112_item	2876436	et	3	main
essee	doc_801781988527_item	2876455	et	4	main
elan	doc_801781988527_item	2876459	et	3	main
narva	doc_801781988527_item	2876465	et	4	main
linnas	doc_801781988527_item	2876466	et	4	main
elan	doc_801781988527_item	2876480	et	3	main
patarei	doc_801781988527_item	2876481	et	4	main
üheksakoruseles	doc_801781988527_item	2876483	et	4	main
majas	doc_801781988527_item	2876485	et	3	main
mugavused	doc_801781988527_item	2876490	et	4	main
ümbruses	doc_801781988527_item	2876505	et	3	main
on	doc_801781988527_item	2876511	et	4	main
hekk	doc_801781988527_item	2876512	et	3	main
on	doc_801781988527_item	2876515	et	4	main
lähedal	doc_801781988527_item	2876520	et	4	main
kaks	doc_801781988527_item	2876526	et	3	main
kaks	doc_801781988527_item	2876528	et	3	main
kõnnitee	doc_801781988527_item	2876535	et	4	main
väke	doc_801781988527_item	2876544	et	4	main
pargis	doc_801781988527_item	2876546	et	3	main
on	doc_801781988527_item	2876552	et	4	main
ma	doc_801781988527_item	2876555	et	3	main
kahetoaline	doc_801781988527_item	2876559	et	4	main
nüüd	doc_801781988527_item	2876572	et	4	main
ma	doc_801781988527_item	2876573	et	3	main
elan	doc_801781988527_item	2876574	et	3	main
üürikorteris	doc_801781988527_item	2876575	et	3	main
korteris	doc_801781988527_item	2876576	et	3	main
toad	doc_801781988527_item	2876580	et	3	main
köök	doc_801781988527_item	2876583	et	3	main
ja	doc_801781988527_item	2876585	et	3	main
on	doc_801781988527_item	2876587	et	4	main
vasakul	doc_801781988527_item	2876625	et	4	main
paremal	doc_801781988527_item	2876643	et	4	main
elutuba	doc_801781988527_item	2876647	et	4	main
on	doc_801781988527_item	2876649	et	4	main
minu	doc_801781988527_item	2876650	et	3	main
elutuba	doc_801781988527_item	2876651	et	4	main
kõrval	doc_801781988527_item	2876661	et	4	main
eest	doc_801781988527_item	2876672	et	4	main
paremal	doc_801781988527_item	2876678	et	4	main
telerilaud	doc_801781988527_item	2876687	et	4	main
telerilaual	doc_801781988527_item	2876688	et	3	main
eesti	doc_792821541746_item	2876239	et	4	main
inimestega	doc_798444340112_item	2876277	et	3	main
sa	doc_798444340112_item	2876280	et	3	main
õpin	doc_798444340112_item	2876285	et	3	main
3	doc_798444340112_item	2876299	et	2	main
õppisid	doc_798444340112_item	2876303	et	4	main
nagu	doc_798444340112_item	2876310	et	3	main
praegu	doc_798444340112_item	2876311	et	3	main
sest	doc_798444340112_item	2876312	et	4	main
ma	doc_798444340112_item	2876313	et	3	main
aru	doc_798444340112_item	2876317	et	4	main
jaoks	doc_798444340112_item	2876323	et	4	main
aga	doc_798444340112_item	2876324	et	3	main
mitte	doc_798444340112_item	2876325	et	3	main
õpetajate	doc_798444340112_item	2876326	et	4	main
on	doc_798444340112_item	2876330	et	4	main
peamine	doc_798444340112_item	2876331	et	3	main
sinu	doc_798444340112_item	2876332	et	3	main
jaoks	doc_798444340112_item	2876333	et	4	main
on	doc_798444340112_item	2876337	et	4	main
püüdlikus	doc_798444340112_item	2876340	et	4	main
on	doc_798444340112_item	2876355	et	4	main
teha	doc_798444340112_item	2876357	et	3	main
ja	doc_798444340112_item	2876360	et	3	main
rohkem	doc_798444340112_item	2876362	et	4	main
et	doc_798444340112_item	2876363	et	3	main
aru	doc_798444340112_item	2876364	et	4	main
saada	doc_798444340112_item	2876368	et	4	main
et	doc_798444340112_item	2876374	et	3	main
missugused	doc_798444340112_item	2876378	et	3	main
jaoks	doc_798444340112_item	2876387	et	4	main
kõrgkooli	doc_798444340112_item	2876399	et	4	main
kuhu	doc_798444340112_item	2876400	et	3	main
ma	doc_798444340112_item	2876401	et	3	main
mõnikord	doc_798444340112_item	2876427	et	3	main
teha	doc_798444340112_item	2876429	et	3	main
negatiivne	doc_798444340112_item	2876432	et	3	main
kuidas	doc_798444340112_item	2876434	et	3	main
oma	doc_798444340112_item	2876437	et	4	main
õpenguid	doc_798444340112_item	2876438	et	4	main
kõrgkoolis	doc_798444340112_item	2876446	et	4	main
nüüd	doc_798444340112_item	2876452	et	4	main
ei	doc_798444340112_item	2876453	et	4	main
minu	doc_801781988527_item	2876456	et	3	main
ma	doc_801781988527_item	2876458	et	3	main
maakonnas	doc_801781988527_item	2876464	et	4	main
on	doc_801781988527_item	2876468	et	4	main
suur	doc_801781988527_item	2876469	et	3	main
linn	doc_801781988527_item	2876470	et	3	main
minu	doc_801781988527_item	2876471	et	3	main
töökoht	doc_801781988527_item	2876472	et	3	main
maja	doc_801781988527_item	2876476	et	4	main
on	doc_801781988527_item	2876488	et	4	main
soe	doc_801781988527_item	2876493	et	4	main
õues	doc_801781988527_item	2876499	et	4	main
rohelust	doc_801781988527_item	2876508	et	4	main
tee	doc_801781988527_item	2876509	et	4	main
õues	doc_801781988527_item	2876514	et	4	main
pehme	doc_801781988527_item	2876516	et	4	main
muru	doc_801781988527_item	2876517	et	4	main
nendes	doc_798444340112_item	2876289	et	4	main
de	doc_798444340112_item	2876291	et	4	main
s	doc_798444340112_item	2876292	et	4	main
on	doc_798444340112_item	2876294	et	4	main
vajalikud	doc_798444340112_item	2876295	et	3	main
minu	doc_798444340112_item	2876296	et	3	main
sisseastumise	doc_798444340112_item	2876297	et	3	main
jaoks	doc_798444340112_item	2876298	et	4	main
ei	doc_798444340112_item	2876314	et	4	main
saanud	doc_798444340112_item	2876315	et	4	main
häasti	doc_798444340112_item	2876316	et	4	main
võimalikusse	doc_798444340112_item	2876344	et	4	main
5	doc_798444340112_item	2876345	et	2	main
missugused	doc_798444340112_item	2876346	et	3	main
alati	doc_798444340112_item	2876356	et	4	main
paremini	doc_798444340112_item	2876367	et	4	main
on	doc_798444340112_item	2876371	et	4	main
saada	doc_798444340112_item	2876375	et	4	main
edukaks	doc_798444340112_item	2876376	et	3	main
ülesanded	doc_798444340112_item	2876379	et	3	main
jaoks	doc_798444340112_item	2876382	et	4	main
püstitasin	doc_798444340112_item	2876385	et	3	main
enda	doc_798444340112_item	2876386	et	4	main
kooli	doc_798444340112_item	2876390	et	4	main
kõrged	doc_798444340112_item	2876392	et	3	main
hinned	doc_798444340112_item	2876393	et	4	main
eksamidel	doc_798444340112_item	2876394	et	4	main
ja	doc_798444340112_item	2876395	et	3	main
7	doc_798444340112_item	2876404	et	2	main
mõjutab	doc_798444340112_item	2876406	et	3	main
mis	doc_798444340112_item	2876405	et	4	main
sinu	doc_798444340112_item	2876407	et	3	main
õppetööd	doc_798444340112_item	2876408	et	4	main
minu	doc_798444340112_item	2876409	et	3	main
õppetööd	doc_798444340112_item	2876410	et	4	main
mõjutavad	doc_798444340112_item	2876411	et	4	main
minu	doc_798444340112_item	2876412	et	3	main
oma	doc_798444340112_item	2876413	et	4	main
püüdlikus	doc_798444340112_item	2876414	et	4	main
see	doc_798444340112_item	2876415	et	3	main
on	doc_798444340112_item	2876416	et	4	main
positiivne	doc_798444340112_item	2876417	et	3	main
aga	doc_798444340112_item	2876418	et	3	main
ka	doc_798444340112_item	2876419	et	3	main
minu	doc_798444340112_item	2876420	et	3	main
vanemate	doc_798444340112_item	2876421	et	4	main
tulevikus	doc_798444340112_item	2876439	et	4	main
ma	doc_798444340112_item	2876440	et	3	main
loodan	doc_798444340112_item	2876441	et	3	main
et	doc_798444340112_item	2876442	et	3	main
pärast	doc_798444340112_item	2876450	et	4	main
ma	doc_798444340112_item	2876451	et	3	main
viru	doc_801781988527_item	2876463	et	4	main
narva	doc_801781988527_item	2876467	et	4	main
kesklinnas	doc_801781988527_item	2876474	et	4	main
tänaval	doc_801781988527_item	2876482	et	4	main
kivi	doc_801781988527_item	2876484	et	4	main
majas	doc_801781988527_item	2876487	et	3	main
lift	doc_801781988527_item	2876491	et	3	main
minu	doc_801781988527_item	2876497	et	3	main
laste	doc_801781988527_item	2876502	et	4	main
meie	doc_801781988527_item	2876518	et	4	main
asub	doc_801781988527_item	2876521	et	3	main
tööstuskaupade	doc_801781988527_item	2876524	et	3	main
lasteaed	doc_801781988527_item	2876529	et	3	main
kaubakeskus	doc_801781988527_item	2876531	et	3	main
sa	doc_798444340112_item	2876380	et	3	main
lõpetada	doc_798444340112_item	2876389	et	3	main
ise	doc_798444340112_item	2876402	et	4	main
tahan	doc_798444340112_item	2876403	et	3	main
õpin	doc_798444340112_item	2876445	et	3	main
aga	doc_798444340112_item	2876447	et	3	main
mis	doc_798444340112_item	2876448	et	4	main
juhtub	doc_798444340112_item	2876449	et	3	main
tea	doc_798444340112_item	2876454	et	4	main
kodu	doc_801781988527_item	2876457	et	4	main
eesti	doc_801781988527_item	2876460	et	4	main
vabariigis	doc_801781988527_item	2876461	et	3	main
ida	doc_801781988527_item	2876462	et	4	main
asub	doc_801781988527_item	2876473	et	3	main
minu	doc_801781988527_item	2876475	et	3	main
asub	doc_801781988527_item	2876477	et	3	main
äärelinnas	doc_801781988527_item	2876478	et	4	main
ma	doc_801781988527_item	2876479	et	3	main
minu	doc_801781988527_item	2876486	et	3	main
kõik	doc_801781988527_item	2876489	et	4	main
ja	doc_801781988527_item	2876494	et	3	main
külm	doc_801781988527_item	2876495	et	3	main
maja	doc_801781988527_item	2876498	et	4	main
ei	doc_801781988527_item	2876500	et	4	main
ole	doc_801781988527_item	2876501	et	4	main
on	doc_801781988527_item	2876506	et	4	main
palju	doc_801781988527_item	2876507	et	4	main
ning	doc_801781988527_item	2876513	et	3	main
toidu-	doc_801781988527_item	2876522	et	3	main
kauplused	doc_801781988527_item	2876525	et	3	main
koolid	doc_801781988527_item	2876527	et	3	main
parkla	doc_801781988527_item	2876530	et	4	main
kolm	doc_801781988527_item	2876532	et	3	main
lux	doc_801781988527_item	2876537	et	4	main
eest	doc_801781988527_item	2876539	et	4	main
maja	doc_801781988527_item	2876541	et	4	main
mänguväljak	doc_801781988527_item	2876549	et	3	main
meie	doc_801781988527_item	2876550	et	4	main
puhas	doc_801781988527_item	2876554	et	3	main
elan	doc_801781988527_item	2876556	et	3	main
aga	doc_801781988527_item	2876570	et	3	main
suur	doc_801781988527_item	2876581	et	3	main
on	doc_801781988527_item	2876619	et	4	main
keskküte	doc_801781988527_item	2876492	et	3	main
vesi	doc_801781988527_item	2876496	et	4	main
manguvaljak	doc_801781988527_item	2876503	et	4	main
maja	doc_801781988527_item	2876504	et	4	main
ääres	doc_801781988527_item	2876510	et	4	main
maja	doc_801781988527_item	2876519	et	4	main
ja	doc_801781988527_item	2876523	et	3	main
apteekid	doc_801781988527_item	2876533	et	4	main
soidutee	doc_801781988527_item	2876534	et	4	main
baar	doc_801781988527_item	2876536	et	3	main
maja	doc_801781988527_item	2876538	et	4	main
park	doc_801781988527_item	2876545	et	3	main
on	doc_801781988527_item	2876547	et	4	main
laste	doc_801781988527_item	2876548	et	4	main
minu	doc_801781988527_item	2876561	et	3	main
on	doc_801781988527_item	2876563	et	4	main
ja	doc_801781988527_item	2876565	et	3	main
toad	doc_801781988527_item	2876567	et	3	main
on	doc_801781988527_item	2876568	et	4	main
päikesepoolne	doc_801781988527_item	2876569	et	3	main
kahjuks	doc_801781988527_item	2876571	et	4	main
eraldid	doc_801781988527_item	2876579	et	3	main
esik	doc_801781988527_item	2876582	et	3	main
eraldi	doc_801781988527_item	2876588	et	4	main
minu	doc_801781988527_item	2876589	et	3	main
korteris	doc_801781988527_item	2876590	et	3	main
on	doc_801781988527_item	2876591	et	4	main
rõdu	doc_801781988527_item	2876592	et	4	main
esik	doc_801781988527_item	2876593	et	3	main
see	doc_801781988527_item	2876594	et	3	main
on	doc_801781988527_item	2876595	et	4	main
esik	doc_801781988527_item	2876596	et	3	main
välisuksest	doc_801781988527_item	2876597	et	4	main
paremal	doc_801781988527_item	2876598	et	4	main
seina	doc_801781988527_item	2876599	et	4	main
juures	doc_801781988527_item	2876600	et	4	main
seisab	doc_801781988527_item	2876601	et	3	main
nägi	doc_801781988527_item	2876602	et	3	main
nagis	doc_801781988527_item	2876603	et	3	main
ripuvad	doc_801781988527_item	2876604	et	3	main
välisreeded	doc_801781988527_item	2876605	et	3	main
nägi	doc_801781988527_item	2876606	et	3	main
kõrval	doc_801781988527_item	2876607	et	4	main
paremal	doc_801781988527_item	2876608	et	4	main
seisab	doc_801781988527_item	2876609	et	3	main
suur	doc_801781988527_item	2876610	et	3	main
kapi	doc_801781988527_item	2876612	et	4	main
vastas	doc_801781988527_item	2876613	et	4	main
seinal	doc_801781988527_item	2876614	et	3	main
korteris	doc_801781988527_item	2876560	et	3	main
kõik	doc_801781988527_item	2876566	et	4	main
on	doc_801781988527_item	2876577	et	4	main
vannituba	doc_801781988527_item	2876586	et	4	main
bussipeatus	doc_801781988527_item	2876540	et	4	main
vastas	doc_801781988527_item	2876542	et	4	main
on	doc_801781988527_item	2876543	et	4	main
trepikod	doc_801781988527_item	2876551	et	4	main
alati	doc_801781988527_item	2876553	et	4	main
kuuendal	doc_801781988527_item	2876557	et	3	main
korrusel	doc_801781988527_item	2876558	et	3	main
korter	doc_801781988527_item	2876562	et	3	main
suur	doc_801781988527_item	2876564	et	3	main
kaks	doc_801781988527_item	2876578	et	3	main
wc	doc_801781988527_item	2876584	et	4	main
all	doc_801781988527_item	2876618	et	3	main
riiul	doc_801781988527_item	2876620	et	4	main
ja	doc_801781988527_item	2876622	et	3	main
ja	doc_801781988527_item	2876629	et	3	main
uks	doc_801781988527_item	2876633	et	3	main
vasakul	doc_801781988527_item	2876635	et	4	main
on	doc_801781988527_item	2876636	et	4	main
uksest	doc_801781988527_item	2876642	et	4	main
on	doc_801781988527_item	2876658	et	4	main
arvutimašin	doc_801781988527_item	2876659	et	2	main
arvutilaua	doc_801781988527_item	2876660	et	3	main
diivan	doc_801781988527_item	2876665	et	3	main
on	doc_801781988527_item	2876669	et	4	main
tugitool	doc_801781988527_item	2876670	et	3	main
akna	doc_801781988527_item	2876671	et	3	main
tüllkardin	doc_801781988527_item	2876674	et	3	main
külgkardin	doc_801781988527_item	2876676	et	3	main
aknalt	doc_801781988527_item	2876679	et	3	main
on	doc_801781988527_item	2876680	et	4	main
ukse	doc_801781988527_item	2876683	et	3	main
seisab	doc_801781988527_item	2876686	et	3	main
on	doc_801781988527_item	2876689	et	4	main
teler	doc_801781988527_item	2876690	et	3	main
elutoas	doc_801781988527_item	2876691	et	3	main
põrandal	doc_801781988527_item	2876692	et	3	main
on	doc_801781988527_item	2876693	et	4	main
hali	doc_801781988527_item	2876694	et	3	main
vaip	doc_801781988527_item	2876695	et	3	main
lastetuba	doc_801781988527_item	2876699	et	4	main
nurgas	doc_801781988527_item	2876702	et	3	main
kõrval	doc_801781988527_item	2876716	et	4	main
paremal	doc_801781988527_item	2876717	et	4	main
nurgas	doc_801781988527_item	2876718	et	3	main
seisab	doc_801781988527_item	2876719	et	3	main
väike	doc_801781988527_item	2876720	et	4	main
kapp	doc_801781988527_item	2876721	et	3	main
kõrval	doc_801781988527_item	2876728	et	4	main
vodi	doc_801781988527_item	2876733	et	4	main
vodi	doc_801781988527_item	2876736	et	4	main
voodipesu	doc_801781988527_item	2876739	et	4	main
padi	doc_801781988527_item	2876741	et	3	main
voodis	doc_801781988527_item	2876744	et	3	main
seisab	doc_801781988527_item	2876751	et	3	main
on	doc_801781988527_item	2876763	et	4	main
sügavkülmik	doc_801781988527_item	2876776	et	3	main
esemene	doc_801781988527_item	2876794	et	4	main
praetaldrikud	doc_801781988527_item	2876799	et	3	main
tassid	doc_801781988527_item	2876802	et	4	main
dessert	doc_801781988527_item	2876807	et	3	main
teine	doc_801781988527_item	2876809	et	3	main
riiulis	doc_801781988527_item	2876810	et	3	main
seisab	doc_801781988527_item	2876811	et	3	main
pannid	doc_801781988527_item	2876812	et	3	main
potid	doc_801781988527_item	2876813	et	4	main
riiv	doc_801781988527_item	2876814	et	3	main
sõel	doc_801781988527_item	2876815	et	3	main
kapp	doc_801781988527_item	2876826	et	3	main
akna	doc_801781988527_item	2876828	et	3	main
laud	doc_801781988527_item	2876838	et	4	main
on	doc_801781988527_item	2876840	et	4	main
all	doc_801781988527_item	2876844	et	3	main
seisab	doc_801781988527_item	2876845	et	3	main
kodu	doc_801781988528_item	2876850	et	4	main
ma	doc_801781988528_item	2876851	et	3	main
elan	doc_801781988528_item	2876852	et	3	main
viru	doc_801781988528_item	2876856	et	4	main
vaivara	doc_801781988528_item	2876858	et	4	main
vallas	doc_801781988528_item	2876859	et	3	main
olgina	doc_801781988528_item	2876860	et	4	main
alevis	doc_801781988528_item	2876861	et	3	main
maantee	doc_801781988528_item	2876863	et	4	main
kapi	doc_801781988527_item	2876611	et	4	main
on	doc_801781988527_item	2876615	et	4	main
peegel	doc_801781988527_item	2876616	et	3	main
on	doc_801781988527_item	2876626	et	4	main
köögi	doc_801781988527_item	2876627	et	3	main
uks	doc_801781988527_item	2876628	et	3	main
on	doc_801781988527_item	2876631	et	4	main
wc	doc_801781988527_item	2876637	et	4	main
ja	doc_801781988527_item	2876638	et	3	main
vannituba	doc_801781988527_item	2876639	et	4	main
uksed	doc_801781988527_item	2876640	et	3	main
vannitua	doc_801781988527_item	2876641	et	4	main
on	doc_801781988527_item	2876644	et	4	main
uks	doc_801781988527_item	2876646	et	3	main
uksest	doc_801781988527_item	2876652	et	4	main
vasakul	doc_801781988527_item	2876653	et	4	main
seisab	doc_801781988527_item	2876655	et	3	main
arvutilaud	doc_801781988527_item	2876656	et	4	main
laual	doc_801781988527_item	2876657	et	3	main
juures	doc_801781988527_item	2876663	et	4	main
seisab	doc_801781988527_item	2876664	et	3	main
ja	doc_801781988527_item	2876675	et	3	main
edasi	doc_801781988527_item	2876677	et	3	main
uksest	doc_801781988527_item	2876700	et	4	main
akna	doc_801781988527_item	2876703	et	3	main
väke	doc_801781988527_item	2876706	et	4	main
on	doc_801781988527_item	2876709	et	4	main
ramatud	doc_801781988527_item	2876726	et	4	main
kapi	doc_801781988527_item	2876727	et	4	main
juures	doc_801781988527_item	2876730	et	4	main
on	doc_801781988527_item	2876738	et	4	main
lina	doc_801781988527_item	2876742	et	4	main
on	doc_801781988527_item	2876745	et	4	main
tool	doc_801781988527_item	2876756	et	3	main
põrandal	doc_801781988527_item	2876757	et	3	main
köök	doc_801781988527_item	2876765	et	3	main
ei	doc_801781988527_item	2876768	et	4	main
aga	doc_801781988527_item	2876771	et	3	main
sügavkülmiku	doc_801781988527_item	2876777	et	3	main
on	doc_801781988527_item	2876779	et	4	main
valamu	doc_801781988527_item	2876781	et	4	main
all	doc_801781988527_item	2876782	et	3	main
kapp	doc_801781988527_item	2876783	et	3	main
kapis	doc_801781988527_item	2876784	et	3	main
on	doc_801781988527_item	2876785	et	4	main
prügiämber	doc_801781988527_item	2876786	et	3	main
on	doc_801781988527_item	2876792	et	4	main
klaasid	doc_801781988527_item	2876801	et	4	main
alustassd	doc_801781988527_item	2876803	et	4	main
noad	doc_801781988527_item	2876804	et	3	main
kahvlid	doc_801781988527_item	2876805	et	3	main
supi-	doc_801781988527_item	2876806	et	3	main
teelusikad	doc_801781988527_item	2876808	et	3	main
on	doc_801781988527_item	2876820	et	4	main
uus	doc_801781988527_item	2876821	et	3	main
gaasipliit	doc_801781988527_item	2876822	et	3	main
uksest	doc_801781988527_item	2876833	et	4	main
kolm	doc_801781988527_item	2876846	et	3	main
ida	doc_801781988528_item	2876855	et	4	main
tänavas	doc_801781988528_item	2876864	et	4	main
number	doc_801781988528_item	2876866	et	3	main
number	doc_801781988528_item	2876869	et	3	main
ma	doc_801781988528_item	2876871	et	3	main
neljakorruselises	doc_801781988528_item	2876873	et	4	main
toidukaupluse	doc_801781988528_item	2876884	et	3	main
rahvamaja	doc_801781988528_item	2876887	et	4	main
spordisaal	doc_801781988528_item	2876893	et	3	main
mänguväljak	doc_801781988528_item	2876895	et	3	main
aiad	doc_801781988528_item	2876896	et	4	main
kaks	doc_801781988528_item	2876901	et	3	main
on	doc_801781988528_item	2876909	et	4	main
tualetti-	doc_801781988528_item	2876921	et	4	main
elutuba	doc_801781988528_item	2876928	et	4	main
on	doc_801781988528_item	2876931	et	4	main
välisuksest	doc_801781988528_item	2876940	et	4	main
on	doc_801781988528_item	2876951	et	4	main
ripuvad	doc_801781988528_item	2876960	et	3	main
välisriided	doc_801781988528_item	2876961	et	3	main
ja	doc_801781988528_item	2876963	et	3	main
joped	doc_801781988528_item	2876964	et	3	main
vastas	doc_801781988528_item	2876970	et	4	main
tualetti-	doc_801781988528_item	2876976	et	4	main
peegli	doc_801781988527_item	2876617	et	3	main
peegli	doc_801781988527_item	2876621	et	3	main
riiuli	doc_801781988527_item	2876623	et	3	main
kõrval	doc_801781988527_item	2876624	et	4	main
paremal	doc_801781988527_item	2876630	et	4	main
lastetoa	doc_801781988527_item	2876632	et	3	main
välisuksest	doc_801781988527_item	2876634	et	4	main
elutoa	doc_801781988527_item	2876645	et	3	main
se	doc_801781988527_item	2876648	et	4	main
nurgas	doc_801781988527_item	2876654	et	3	main
seina	doc_801781988527_item	2876662	et	4	main
diivani	doc_801781988527_item	2876666	et	4	main
kõrval	doc_801781988527_item	2876667	et	4	main
nurgas	doc_801781988527_item	2876668	et	3	main
on	doc_801781988527_item	2876673	et	4	main
kõrval	doc_801781988527_item	2876684	et	4	main
paremal	doc_801781988527_item	2876685	et	4	main
see	doc_801781988527_item	2876697	et	3	main
juures	doc_801781988527_item	2876704	et	4	main
kušetil	doc_801781988527_item	2876708	et	2	main
mänguasjad	doc_801781988527_item	2876710	et	3	main
akna	doc_801781988527_item	2876711	et	3	main
eest	doc_801781988527_item	2876712	et	4	main
on	doc_801781988527_item	2876713	et	4	main
külgkardin	doc_801781988527_item	2876714	et	3	main
akna	doc_801781988527_item	2876715	et	3	main
kapis	doc_801781988527_item	2876722	et	3	main
on	doc_801781988527_item	2876723	et	4	main
mänguasjad	doc_801781988527_item	2876724	et	3	main
ja	doc_801781988527_item	2876725	et	3	main
seina	doc_801781988527_item	2876729	et	4	main
on	doc_801781988527_item	2876734	et	4	main
juures	doc_801781988527_item	2876750	et	4	main
kirjutuslaud	doc_801781988527_item	2876753	et	4	main
minu	doc_801781988527_item	2876764	et	3	main
suur	doc_801781988527_item	2876770	et	3	main
mugav	doc_801781988527_item	2876772	et	3	main
hari	doc_801781988527_item	2876787	et	4	main
ja	doc_801781988527_item	2876788	et	3	main
kühvel	doc_801781988527_item	2876789	et	3	main
teisel	doc_801781988527_item	2876790	et	4	main
taga	doc_801781988527_item	2876819	et	4	main
gaasipliidi	doc_801781988527_item	2876823	et	3	main
taga	doc_801781988527_item	2876824	et	4	main
eest	doc_801781988527_item	2876829	et	4	main
on	doc_801781988527_item	2876830	et	4	main
oranž	doc_801781988527_item	2876831	et	2	main
külgkardin	doc_801781988527_item	2876832	et	3	main
juures	doc_801781988527_item	2876836	et	4	main
seisab	doc_801781988527_item	2876837	et	3	main
eesti	doc_801781988528_item	2876853	et	4	main
vabariigis	doc_801781988528_item	2876854	et	3	main
tallinna	doc_801781988528_item	2876862	et	4	main
viisteist	doc_801781988528_item	2876867	et	4	main
kaks	doc_801781988528_item	2876883	et	3	main
raamatukogu	doc_801781988528_item	2876892	et	4	main
laste	doc_801781988528_item	2876894	et	4	main
bussipeatus	doc_801781988528_item	2876897	et	4	main
kuusteist	doc_801781988528_item	2876905	et	4	main
korterit	doc_801781988528_item	2876906	et	3	main
külm	doc_801781988528_item	2876911	et	3	main
on	doc_801781988528_item	2876916	et	4	main
kaks	doc_801781988528_item	2876917	et	3	main
tuba	doc_801781988528_item	2876918	et	4	main
köök	doc_801781988528_item	2876919	et	3	main
esik	doc_801781988528_item	2876920	et	3	main
uks	doc_801781988527_item	2876681	et	3	main
rõdule	doc_801781988527_item	2876682	et	3	main
lastetuba	doc_801781988527_item	2876696	et	4	main
seisab	doc_801781988527_item	2876705	et	3	main
kušeti	doc_801781988527_item	2876707	et	2	main
on	doc_801781988527_item	2876698	et	4	main
vasakul	doc_801781988527_item	2876701	et	4	main
seisab	doc_801781988527_item	2876731	et	3	main
vodi	doc_801781988527_item	2876732	et	4	main
sahtliga	doc_801781988527_item	2876735	et	3	main
sahtlites	doc_801781988527_item	2876737	et	3	main
tikikot	doc_801781988527_item	2876740	et	4	main
uksest	doc_801781988527_item	2876747	et	4	main
seina	doc_801781988527_item	2876749	et	4	main
pruunikirju	doc_801781988527_item	2876759	et	4	main
vaip	doc_801781988527_item	2876760	et	3	main
köök	doc_801781988527_item	2876761	et	3	main
see	doc_801781988527_item	2876762	et	3	main
köök	doc_801781988527_item	2876766	et	3	main
on	doc_801781988527_item	2876767	et	4	main
väga	doc_801781988527_item	2876769	et	3	main
uksest	doc_801781988527_item	2876773	et	4	main
paremal	doc_801781988527_item	2876774	et	4	main
seisab	doc_801781988527_item	2876775	et	3	main
kõrval	doc_801781988527_item	2876778	et	4	main
kapis	doc_801781988527_item	2876791	et	3	main
toidunõded	doc_801781988527_item	2876793	et	4	main
kanusid	doc_801781988527_item	2876800	et	4	main
edasi	doc_801781988527_item	2876817	et	3	main
seisab	doc_801781988527_item	2876825	et	3	main
toodetega	doc_801781988527_item	2876827	et	3	main
vasakul	doc_801781988527_item	2876834	et	4	main
seina	doc_801781988527_item	2876835	et	4	main
laual	doc_801781988527_item	2876839	et	3	main
elektrikann	doc_801781988527_item	2876841	et	3	main
suhkrutoos	doc_801781988527_item	2876842	et	3	main
taburete	doc_801781988527_item	2876847	et	3	main
essee	doc_801781988528_item	2876848	et	4	main
minu	doc_801781988528_item	2876849	et	3	main
maakonnas	doc_801781988528_item	2876857	et	4	main
maja	doc_801781988528_item	2876865	et	4	main
korter	doc_801781988528_item	2876868	et	3	main
kaks	doc_801781988528_item	2876870	et	3	main
elan	doc_801781988528_item	2876872	et	3	main
meie	doc_801781988528_item	2876879	et	4	main
lähedal	doc_801781988528_item	2876881	et	4	main
lasteaed	doc_801781988528_item	2876885	et	3	main
medpunkt	doc_801781988528_item	2876891	et	3	main
sissekäiku	doc_801781988528_item	2876902	et	4	main
sissekäigus	doc_801781988528_item	2876903	et	3	main
on	doc_801781988528_item	2876904	et	4	main
keskküte	doc_801781988528_item	2876910	et	3	main
meie	doc_801781988528_item	2876914	et	4	main
on	doc_801781988528_item	2876925	et	4	main
magamistuba	doc_801781988528_item	2876927	et	4	main
ja	doc_801781988528_item	2876929	et	3	main
seinal	doc_801781988528_item	2876941	et	3	main
on	doc_801781988528_item	2876942	et	4	main
ümmargune	doc_801781988528_item	2876943	et	3	main
peegel	doc_801781988528_item	2876944	et	3	main
peegli	doc_801781988528_item	2876945	et	3	main
all	doc_801781988528_item	2876946	et	3	main
seinal	doc_801781988528_item	2876947	et	3	main
on	doc_801781988528_item	2876948	et	4	main
edasi	doc_801781988528_item	2876955	et	3	main
seinajuures	doc_801781988528_item	2876956	et	3	main
nagi	doc_801781988528_item	2876958	et	4	main
palitud	doc_801781988528_item	2876962	et	4	main
all	doc_801781988528_item	2876966	et	3	main
seisab	doc_801781988528_item	2876967	et	3	main
tualetti-	doc_801781988528_item	2876972	et	4	main
ja	doc_801781988528_item	2876973	et	3	main
uks	doc_801781988528_item	2876975	et	3	main
on	doc_801781988528_item	2876979	et	4	main
kapp	doc_801781988528_item	2876986	et	3	main
kapis	doc_801781988528_item	2876987	et	3	main
pesuvahendid	doc_801781988528_item	2876989	et	3	main
seina	doc_801781988528_item	2877023	et	4	main
kõrval	doc_801781988528_item	2877035	et	4	main
dušš	doc_801781988528_item	2877038	et	2	main
siin	doc_801781988528_item	2877039	et	4	main
vasakul	doc_801781988528_item	2877043	et	4	main
seina	doc_801781988528_item	2877052	et	4	main
serviisid	doc_801781988528_item	2877061	et	3	main
juures	doc_801781988528_item	2877090	et	4	main
seisab	doc_801781988528_item	2877100	et	3	main
akna	doc_801781988528_item	2877103	et	3	main
padjapüür	doc_801781988527_item	2876743	et	3	main
laua	doc_801781988527_item	2876843	et	3	main
voodikate	doc_801781988527_item	2876746	et	3	main
paremal	doc_801781988527_item	2876748	et	4	main
kirjutuslaud	doc_801781988527_item	2876752	et	4	main
ees	doc_801781988527_item	2876754	et	4	main
on	doc_801781988527_item	2876755	et	4	main
on	doc_801781988527_item	2876758	et	4	main
valamu	doc_801781988527_item	2876780	et	4	main
riiulis	doc_801781988527_item	2876795	et	3	main
seisab	doc_801781988527_item	2876796	et	3	main
magustoidutaldrikud	doc_801781988527_item	2876797	et	3	main
ja	doc_801781988527_item	2876798	et	3	main
kann	doc_801781988527_item	2876816	et	3	main
kapi	doc_801781988527_item	2876818	et	4	main
kivimajas	doc_801781988528_item	2876874	et	4	main
kolmandal	doc_801781988528_item	2876875	et	3	main
korrusel	doc_801781988528_item	2876876	et	3	main
kahetoalises	doc_801781988528_item	2876877	et	4	main
korteris	doc_801781988528_item	2876878	et	3	main
maja	doc_801781988528_item	2876880	et	4	main
asuvad	doc_801781988528_item	2876882	et	4	main
sõidutee	doc_801781988528_item	2876888	et	4	main
baar	doc_801781988528_item	2876889	et	3	main
meie	doc_801781988528_item	2876898	et	4	main
majas	doc_801781988528_item	2876899	et	3	main
meie	doc_801781988528_item	2876907	et	4	main
majas	doc_801781988528_item	2876908	et	3	main
ja	doc_801781988528_item	2876922	et	3	main
vannituba	doc_801781988528_item	2876923	et	4	main
esik	doc_801781988528_item	2876933	et	3	main
ja	doc_801781988528_item	2876936	et	3	main
pime	doc_801781988528_item	2876937	et	3	main
korterivõitmed	doc_801781988528_item	2876952	et	4	main
ja	doc_801781988528_item	2876953	et	3	main
garaaživõiti	doc_801781988528_item	2876954	et	2	main
nagi	doc_801781988528_item	2876965	et	4	main
kingad	doc_801781988528_item	2876968	et	3	main
nagi	doc_801781988528_item	2876969	et	4	main
on	doc_801781988528_item	2876971	et	4	main
vannituba	doc_801781988528_item	2876978	et	4	main
paremal	doc_801781988528_item	2876981	et	4	main
nurgas	doc_801781988528_item	2876983	et	3	main
ja	doc_801781988528_item	2877020	et	3	main
kühvel	doc_801781988528_item	2877021	et	3	main
edasi	doc_801781988528_item	2877022	et	3	main
kraanikausi	doc_801781988528_item	2877027	et	3	main
nurgas	doc_801781988528_item	2877036	et	3	main
asub	doc_801781988528_item	2877037	et	3	main
uksest	doc_801781988528_item	2877042	et	4	main
seisab	doc_801781988528_item	2877046	et	3	main
juures	doc_801781988528_item	2877053	et	4	main
on	doc_801781988528_item	2877059	et	4	main
aknast	doc_801781988528_item	2877065	et	4	main
vasakul	doc_801781988528_item	2877074	et	4	main
on	doc_801781988528_item	2877076	et	4	main
arvuti	doc_801781988528_item	2877077	et	4	main
maalid	doc_801781988528_item	2877086	et	4	main
diivani	doc_801781988528_item	2877093	et	4	main
seinal	doc_801781988528_item	2877095	et	3	main
ripuvad	doc_801781988528_item	2877096	et	3	main
akna	doc_801781988528_item	2877098	et	3	main
raamat	doc_801781988528_item	2877102	et	3	main
ees	doc_801781988528_item	2877104	et	4	main
on	doc_801781988528_item	2877105	et	4	main
tüllkardin	doc_801781988528_item	2877106	et	3	main
ja	doc_801781988528_item	2877107	et	3	main
olgina	doc_801781988528_item	2876886	et	4	main
saun	doc_801781988528_item	2876890	et	3	main
on	doc_801781988528_item	2876900	et	4	main
vesi	doc_801781988528_item	2876912	et	4	main
elekter	doc_801781988528_item	2876913	et	3	main
korteris	doc_801781988528_item	2876915	et	3	main
elutuba	doc_801781988528_item	2876924	et	4	main
läbikäidav	doc_801781988528_item	2876926	et	4	main
köök	doc_801781988528_item	2876930	et	3	main
päikesepoolne	doc_801781988528_item	2876932	et	3	main
on	doc_801781988528_item	2876934	et	4	main
väiksevõtu	doc_801781988528_item	2876935	et	3	main
esikus	doc_801781988528_item	2876938	et	3	main
paremal	doc_801781988528_item	2876939	et	4	main
riiul	doc_801781988528_item	2876949	et	4	main
sahtlis	doc_801781988528_item	2876950	et	3	main
seisab	doc_801781988528_item	2876957	et	3	main
nagis	doc_801781988528_item	2876959	et	3	main
vannitoa	doc_801781988528_item	2876974	et	3	main
koos	doc_801781988528_item	2876980	et	4	main
uksest	doc_801781988528_item	2876982	et	4	main
valge	doc_801781988528_item	2876985	et	4	main
on	doc_801781988528_item	2876988	et	4	main
käteratikud	doc_801781988528_item	2876990	et	4	main
ja	doc_801781988528_item	2876991	et	3	main
saunalinad	doc_801781988528_item	2876992	et	3	main
kapi	doc_801781988528_item	2876993	et	4	main
kõrval	doc_801781988528_item	2876994	et	4	main
seina	doc_801781988528_item	2876995	et	4	main
juures	doc_801781988528_item	2876996	et	4	main
on	doc_801781988528_item	2876997	et	4	main
pesukorv	doc_801781988528_item	2876998	et	3	main
edasi	doc_801781988528_item	2876999	et	3	main
nurgas	doc_801781988528_item	2877000	et	3	main
asub	doc_801781988528_item	2877001	et	3	main
automaatpesumasin	doc_801781988528_item	2877002	et	3	main
pesumasina	doc_801781988528_item	2877003	et	3	main
kohal	doc_801781988528_item	2877004	et	4	main
lae	doc_801781988528_item	2877005	et	4	main
all	doc_801781988528_item	2877006	et	3	main
ripub	doc_801781988528_item	2877007	et	3	main
elektriboiler	doc_801781988528_item	2877008	et	3	main
vasakul	doc_801781988528_item	2877009	et	4	main
uksest	doc_801781988528_item	2877010	et	4	main
nurgas	doc_801781988528_item	2877011	et	3	main
on	doc_801781988528_item	2877012	et	4	main
wc	doc_801781988528_item	2877013	et	4	main
pott	doc_801781988528_item	2877014	et	3	main
vasakul	doc_801781988528_item	2877015	et	4	main
wc	doc_801781988528_item	2877016	et	4	main
potist	doc_801781988528_item	2877017	et	4	main
ja	doc_801781988528_item	2876977	et	3	main
seisab	doc_801781988528_item	2876984	et	3	main
juures	doc_801781988528_item	2877024	et	4	main
kohal	doc_801781988528_item	2877028	et	4	main
seinal	doc_801781988528_item	2877029	et	3	main
on	doc_801781988528_item	2877030	et	4	main
ümmargune	doc_801781988528_item	2877031	et	3	main
peegel	doc_801781988528_item	2877032	et	3	main
on	doc_801781988528_item	2877040	et	4	main
seina	doc_801781988528_item	2877044	et	4	main
trümoo	doc_801781988528_item	2877047	et	4	main
suure	doc_801781988528_item	2877048	et	3	main
uksest	doc_801781988528_item	2877050	et	4	main
paremal	doc_801781988528_item	2877051	et	4	main
seinakapp	doc_801781988528_item	2877055	et	3	main
ja	doc_801781988528_item	2877056	et	3	main
sektsioonikapp	doc_801781988528_item	2877057	et	4	main
sektsioonikapis	doc_801781988528_item	2877058	et	4	main
raamatud	doc_801781988528_item	2877060	et	4	main
voodipesu	doc_801781988528_item	2877063	et	4	main
lasterõivad	doc_801781988528_item	2877064	et	3	main
õmblumasina	doc_801781988528_item	2877070	et	4	main
peal	doc_801781988528_item	2877071	et	4	main
on	doc_801781988528_item	2877072	et	4	main
kohal	doc_801781988528_item	2877083	et	4	main
seinal	doc_801781988528_item	2877084	et	3	main
on	doc_801781988528_item	2877085	et	4	main
aknast	doc_801781988528_item	2877088	et	4	main
seisab	doc_801781988528_item	2877091	et	3	main
kohal	doc_801781988528_item	2877094	et	4	main
laud	doc_801781988528_item	2877101	et	4	main
peegeline	doc_801781988528_item	2877117	et	4	main
lühter	doc_801781988528_item	2877118	et	3	main
diivani	doc_801781988528_item	2877126	et	4	main
ja	doc_801781988528_item	2877127	et	3	main
on	doc_801781988528_item	2877140	et	4	main
vatitekk	doc_801781988528_item	2877143	et	3	main
juures	doc_801781988528_item	2877148	et	4	main
riide-	doc_801781988528_item	2877150	et	4	main
samasugune	doc_801781988528_item	2877159	et	3	main
vastas	doc_801781988528_item	2877162	et	4	main
on	doc_801781988528_item	2877163	et	4	main
aken	doc_801781988528_item	2877164	et	3	main
akna	doc_801781988528_item	2877165	et	3	main
tüllkardin	doc_801781988528_item	2877172	et	3	main
põrandal	doc_801781988528_item	2877173	et	3	main
rohelisekirju	doc_801781988528_item	2877175	et	4	main
vaip	doc_801781988528_item	2877176	et	3	main
on	doc_801781988528_item	2877178	et	4	main
on	doc_801781988528_item	2877181	et	4	main
kohal	doc_801781988528_item	2877193	et	4	main
on	doc_801781988528_item	2877199	et	4	main
on	doc_801781988528_item	2877025	et	4	main
kraanikauss	doc_801781988528_item	2877026	et	3	main
paremal	doc_801781988528_item	2877033	et	4	main
kraanikausi	doc_801781988528_item	2877034	et	3	main
elutuba	doc_801781988528_item	2877041	et	4	main
juures	doc_801781988528_item	2877045	et	4	main
peegliga	doc_801781988528_item	2877049	et	3	main
on	doc_801781988528_item	2877054	et	4	main
bokalid	doc_801781988528_item	2877062	et	4	main
vasakul	doc_801781988528_item	2877066	et	4	main
nurgas	doc_801781988528_item	2877067	et	3	main
on	doc_801781988528_item	2877068	et	4	main
õmblumasin	doc_801781988528_item	2877069	et	4	main
teler	doc_801781988528_item	2877073	et	3	main
laud	doc_801781988528_item	2877078	et	4	main
ja	doc_801781988528_item	2877079	et	3	main
tool	doc_801781988528_item	2877080	et	3	main
arvuti	doc_801781988528_item	2877081	et	4	main
laua	doc_801781988528_item	2877082	et	3	main
paremal	doc_801781988528_item	2877087	et	4	main
diivan	doc_801781988528_item	2877092	et	3	main
maalid	doc_801781988528_item	2877097	et	4	main
ees	doc_801781988528_item	2877099	et	4	main
külgkardinad	doc_801781988528_item	2877108	et	4	main
elutoa	doc_801781988528_item	2877109	et	3	main
pruunikirju	doc_801781988528_item	2877112	et	4	main
lael	doc_801781988528_item	2877114	et	4	main
ripub	doc_801781988528_item	2877115	et	3	main
ilus	doc_801781988528_item	2877116	et	4	main
diivani	doc_801781988528_item	2877119	et	4	main
ja	doc_801781988528_item	2877120	et	3	main
tolmuimeja	doc_801781988528_item	2877125	et	4	main
sektsioonikapi	doc_801781988528_item	2877128	et	4	main
kaks	doc_801781988528_item	2877141	et	3	main
sulepadja	doc_801781988528_item	2877142	et	3	main
voodikate	doc_801781988528_item	2877144	et	3	main
vasakul	doc_801781988528_item	2877145	et	4	main
selle	doc_801781988528_item	2877153	et	4	main
on	doc_801781988528_item	2877156	et	4	main
üks	doc_801781988528_item	2877158	et	3	main
ukse	doc_801781988528_item	2877161	et	3	main
lastevoodi	doc_801781988528_item	2877168	et	4	main
on	doc_801781988528_item	2877174	et	4	main
lael	doc_801781988528_item	2877177	et	4	main
see	doc_801781988528_item	2877180	et	3	main
vasakul	doc_801781988528_item	2877187	et	4	main
juures	doc_801781988528_item	2877189	et	4	main
elektripliiti	doc_801781988528_item	2877192	et	4	main
tõmbukapi	doc_801781988528_item	2877197	et	4	main
kohal	doc_801781988528_item	2877198	et	4	main
arstirohud	doc_801781988528_item	2877232	et	4	main
on	doc_801781988528_item	2877239	et	4	main
potid	doc_801781988528_item	2877242	et	4	main
elektripliiti	doc_801781988528_item	2877246	et	4	main
kõrval	doc_801781988528_item	2877247	et	4	main
on	doc_801781988528_item	2877253	et	4	main
prügiämber	doc_801781988528_item	2877254	et	3	main
ja	doc_801781988528_item	2877255	et	3	main
ämber	doc_801781988528_item	2877256	et	3	main
kartuliga	doc_801781988528_item	2877257	et	3	main
on	doc_801781988528_item	2877260	et	4	main
lauanõud	doc_801781988528_item	2877265	et	3	main
kruusid	doc_801781988528_item	2877267	et	3	main
dessertlusikad	doc_801781988528_item	2877279	et	4	main
kahvlid	doc_801781988528_item	2877281	et	3	main
noad	doc_801781988528_item	2877288	et	3	main
nurgas	doc_801781988528_item	2877290	et	3	main
akna	doc_801781988528_item	2877291	et	3	main
tangud	doc_801781988528_item	2877304	et	3	main
jahu	doc_801781988528_item	2877305	et	4	main
juures	doc_801781988528_item	2877313	et	4	main
mikrolaineahju	doc_801781988528_item	2877322	et	4	main
seina	doc_801781988528_item	2877330	et	4	main
väike	doc_801781988528_item	2877333	et	4	main
taburetiga	doc_801781988528_item	2877336	et	3	main
kohal	doc_801781988528_item	2877338	et	4	main
akna	doc_801781988528_item	2877342	et	3	main
ja	doc_801781988528_item	2877352	et	3	main
köögipõrand	doc_801781988528_item	2877359	et	3	main
on	doc_801781988528_item	2877018	et	4	main
hari	doc_801781988528_item	2877019	et	4	main
õmblemasinast	doc_801781988528_item	2877075	et	4	main
seina	doc_801781988528_item	2877089	et	4	main
põrandal	doc_801781988528_item	2877110	et	3	main
akna	doc_801781988528_item	2877121	et	3	main
on	doc_801781988528_item	2877124	et	4	main
paremal	doc_801781988528_item	2877134	et	4	main
uksest	doc_801781988528_item	2877146	et	4	main
seisab	doc_801781988528_item	2877149	et	3	main
ja	doc_801781988528_item	2877151	et	3	main
pesukapp	doc_801781988528_item	2877152	et	3	main
kapi	doc_801781988528_item	2877154	et	4	main
ees	doc_801781988528_item	2877166	et	4	main
asub	doc_801781988528_item	2877167	et	3	main
lühter	doc_801781988528_item	2877179	et	3	main
uksest	doc_801781988528_item	2877186	et	4	main
seina	doc_801781988528_item	2877188	et	4	main
asub	doc_801781988528_item	2877190	et	3	main
elektripliit	doc_801781988528_item	2877191	et	3	main
ja	doc_801781988528_item	2877196	et	3	main
väike	doc_801781988528_item	2877200	et	4	main
köögikapp	doc_801781988528_item	2877201	et	3	main
seal	doc_801781988528_item	2877202	et	4	main
on	doc_801781988528_item	2877203	et	4	main
tühjad	doc_801781988528_item	2877204	et	3	main
ja	doc_801781988528_item	2877206	et	3	main
karbid	doc_801781988528_item	2877207	et	3	main
purgid	doc_801781988528_item	2877205	et	4	main
vasakul	doc_801781988528_item	2877208	et	4	main
elektripliiti	doc_801781988528_item	2877209	et	4	main
kõrval	doc_801781988528_item	2877210	et	4	main
on	doc_801781988528_item	2877211	et	4	main
ka	doc_801781988528_item	2877212	et	3	main
köögikapp	doc_801781988528_item	2877213	et	3	main
köögikapis	doc_801781988528_item	2877214	et	3	main
on	doc_801781988528_item	2877215	et	4	main
palju	doc_801781988528_item	2877216	et	4	main
keediseid	doc_801781988528_item	2877217	et	3	main
köögikapi	doc_801781988528_item	2877218	et	3	main
peal	doc_801781988528_item	2877219	et	4	main
on	doc_801781988528_item	2877220	et	4	main
suhkrutoos	doc_801781988528_item	2877223	et	3	main
on	doc_801781988528_item	2877231	et	4	main
on	doc_801781988528_item	2877248	et	4	main
valamu	doc_801781988528_item	2877258	et	4	main
köögikapp	doc_801781988528_item	2877261	et	3	main
asub	doc_801781988528_item	2877264	et	3	main
klaasid	doc_801781988528_item	2877268	et	4	main
juures	doc_801781988528_item	2877271	et	4	main
kulp	doc_801781988528_item	2877282	et	3	main
juures	doc_801781988528_item	2877292	et	4	main
külmkapp	doc_801781988528_item	2877294	et	3	main
ja	doc_801781988528_item	2877296	et	3	main
külmkapi	doc_801781988528_item	2877297	et	3	main
makaroonid	doc_801781988528_item	2877303	et	4	main
peal	doc_801781988528_item	2877309	et	4	main
on	doc_801781988528_item	2877310	et	4	main
peal	doc_801781988528_item	2877318	et	4	main
on	doc_801781988528_item	2877319	et	4	main
on	doc_801781988528_item	2877111	et	4	main
vaip	doc_801781988528_item	2877113	et	3	main
vahel	doc_801781988528_item	2877122	et	4	main
nurgas	doc_801781988528_item	2877123	et	3	main
vahel	doc_801781988528_item	2877129	et	4	main
on	doc_801781988528_item	2877130	et	4	main
uks	doc_801781988528_item	2877131	et	3	main
magamistuppa	doc_801781988528_item	2877132	et	3	main
magamistoas	doc_801781988528_item	2877133	et	3	main
uksest	doc_801781988528_item	2877135	et	4	main
seisab	doc_801781988528_item	2877136	et	3	main
suur	doc_801781988528_item	2877137	et	3	main
voodi	doc_801781988528_item	2877138	et	4	main
voodil	doc_801781988528_item	2877139	et	3	main
seina	doc_801781988528_item	2877147	et	4	main
vastas	doc_801781988528_item	2877155	et	4	main
veel	doc_801781988528_item	2877157	et	4	main
kapp	doc_801781988528_item	2877160	et	3	main
akna	doc_801781988528_item	2877169	et	3	main
ees	doc_801781988528_item	2877170	et	4	main
ripub	doc_801781988528_item	2877171	et	3	main
köök	doc_801781988528_item	2877182	et	3	main
köök	doc_801781988528_item	2877183	et	3	main
väike	doc_801781988528_item	2877185	et	4	main
tõmbukapp	doc_801781988528_item	2877195	et	4	main
teekann	doc_801781988528_item	2877221	et	3	main
kohal	doc_801781988528_item	2877225	et	4	main
pannid	doc_801781988528_item	2877240	et	3	main
valamu	doc_801781988528_item	2877249	et	4	main
ümmarguse	doc_801781988528_item	2877250	et	3	main
kohal	doc_801781988528_item	2877259	et	4	main
valamu	doc_801781988528_item	2877270	et	4	main
teelusikad	doc_801781988528_item	2877280	et	3	main
vahukulp	doc_801781988528_item	2877283	et	3	main
ääres	doc_801781988528_item	2877285	et	4	main
seal	doc_801781988528_item	2877301	et	4	main
köögikapi	doc_801781988528_item	2877308	et	3	main
elektrikann	doc_801781988528_item	2877311	et	3	main
külmkapi	doc_801781988528_item	2877312	et	3	main
käteratikud	doc_801781988528_item	2877316	et	4	main
peal	doc_801781988528_item	2877323	et	4	main
asub	doc_801781988528_item	2877324	et	3	main
mikser	doc_801781988528_item	2877325	et	3	main
ja	doc_801781988528_item	2877326	et	3	main
võileivagrill	doc_801781988528_item	2877327	et	3	main
paremal	doc_801781988528_item	2877328	et	4	main
uksest	doc_801781988528_item	2877329	et	4	main
ripub	doc_801781988528_item	2877340	et	3	main
kalender	doc_801781988528_item	2877341	et	3	main
paremal	doc_801781988528_item	2877348	et	4	main
pool	doc_801781988528_item	2877349	et	4	main
on	doc_801781988528_item	2877357	et	4	main
on	doc_801781988528_item	2877360	et	4	main
linoleumiga	doc_801781988528_item	2877362	et	3	main
lambikega	doc_801781988528_item	2877367	et	4	main
pestavtapeetiga	doc_801781988528_item	2877371	et	4	main
narva	doc_801781988529_item	2877384	et	4	main
on	doc_801781988529_item	2877389	et	4	main
kolmetoalises	doc_801781988529_item	2877400	et	4	main
korteris	doc_801781988529_item	2877401	et	3	main
maja	doc_801781988529_item	2877402	et	4	main
on	doc_801781988529_item	2877417	et	4	main
erinevad	doc_801781988529_item	2877421	et	4	main
tee	doc_801781988529_item	2877425	et	4	main
hoovis	doc_801781988529_item	2877430	et	4	main
pehme	doc_801781988529_item	2877433	et	4	main
maja	doc_801781988529_item	2877436	et	4	main
lähedal	doc_801781988529_item	2877437	et	4	main
lasteaeda	doc_801781988529_item	2877445	et	4	main
parkla	doc_801781988529_item	2877446	et	4	main
kaubakeskus	doc_801781988529_item	2877447	et	3	main
ühispank	doc_801781988529_item	2877448	et	3	main
apteek	doc_801781988529_item	2877449	et	3	main
ja	doc_801781988529_item	2877453	et	3	main
busipeatus	doc_801781988529_item	2877456	et	4	main
on	doc_801781988529_item	2877473	et	4	main
kolm	doc_801781988529_item	2877474	et	3	main
magamistuba	doc_801781988529_item	2877477	et	4	main
minu	doc_801781988529_item	2877480	et	3	main
paremal	doc_801781988529_item	2877485	et	4	main
ripub	doc_801781988529_item	2877488	et	3	main
on	doc_801781988528_item	2877184	et	4	main
on	doc_801781988528_item	2877194	et	4	main
ja	doc_801781988528_item	2877222	et	3	main
köögikapi	doc_801781988528_item	2877224	et	3	main
seinal	doc_801781988528_item	2877226	et	3	main
on	doc_801781988528_item	2877227	et	4	main
ka	doc_801781988528_item	2877228	et	3	main
köögikapp	doc_801781988528_item	2877229	et	3	main
seal	doc_801781988528_item	2877230	et	4	main
elektripliiti	doc_801781988528_item	2877233	et	4	main
all	doc_801781988528_item	2877234	et	3	main
on	doc_801781988528_item	2877235	et	4	main
suur	doc_801781988528_item	2877236	et	3	main
sahtel	doc_801781988528_item	2877237	et	3	main
sahtlis	doc_801781988528_item	2877238	et	3	main
sõel	doc_801781988528_item	2877241	et	3	main
ja	doc_801781988528_item	2877243	et	3	main
salatikausid	doc_801781988528_item	2877244	et	3	main
paremal	doc_801781988528_item	2877245	et	4	main
valamu	doc_801781988528_item	2877251	et	4	main
all	doc_801781988528_item	2877252	et	3	main
selles	doc_801781988528_item	2877262	et	4	main
köögikapis	doc_801781988528_item	2877263	et	3	main
taldrikud	doc_801781988528_item	2877266	et	3	main
köögis	doc_801781988528_item	2877269	et	3	main
on	doc_801781988528_item	2877272	et	4	main
nõudepesuvahend	doc_801781988528_item	2877273	et	3	main
valamu	doc_801781988528_item	2877274	et	4	main
juures	doc_801781988528_item	2877275	et	4	main
nurgas	doc_801781988528_item	2877276	et	3	main
avaja	doc_801781988528_item	2877284	et	4	main
ripuvad	doc_801781988528_item	2877287	et	3	main
on	doc_801781988528_item	2877293	et	4	main
valamu	doc_801781988528_item	2877295	et	4	main
vahel	doc_801781988528_item	2877298	et	4	main
on	doc_801781988528_item	2877299	et	4	main
köögikapp	doc_801781988528_item	2877300	et	3	main
sool	doc_801781988528_item	2877306	et	4	main
suhkur	doc_801781988528_item	2877307	et	3	main
juures	doc_801781988528_item	2877331	et	4	main
köögilaud	doc_801781988528_item	2877334	et	4	main
nelja	doc_801781988528_item	2877335	et	4	main
on	doc_801781988528_item	2877350	et	4	main
leib	doc_801781988528_item	2877351	et	3	main
pool	doc_801781988528_item	2877356	et	4	main
laelamp	doc_801781988528_item	2877365	et	3	main
eesti	doc_801781988529_item	2877377	et	4	main
vabariigis	doc_801781988529_item	2877378	et	3	main
maakonnas	doc_801781988529_item	2877381	et	4	main
narva	doc_801781988529_item	2877382	et	4	main
elan	doc_801781988529_item	2877393	et	3	main
tänaval	doc_801781988529_item	2877395	et	4	main
üheksakorruselises	doc_801781988529_item	2877396	et	4	main
majas	doc_801781988529_item	2877397	et	3	main
neljandal	doc_801781988529_item	2877398	et	3	main
korrusel	doc_801781988529_item	2877399	et	3	main
laste	doc_801781988529_item	2877405	et	4	main
mänguväljak	doc_801781988529_item	2877406	et	3	main
liivakast	doc_801781988529_item	2877409	et	4	main
rohelust	doc_801781988529_item	2877419	et	4	main
põõsad	doc_801781988529_item	2877424	et	3	main
ääres	doc_801781988529_item	2877426	et	4	main
on	doc_801781988529_item	2877427	et	4	main
hekk	doc_801781988529_item	2877428	et	3	main
muru	doc_801781988529_item	2877434	et	4	main
tööstuskaupade	doc_801781988529_item	2877441	et	3	main
juuksla	doc_801781988529_item	2877450	et	4	main
trepikoda	doc_801781988529_item	2877458	et	4	main
meie	doc_801781988529_item	2877462	et	4	main
korter	doc_801781988529_item	2877463	et	3	main
korter	doc_801781988529_item	2877467	et	3	main
ja	doc_801781988529_item	2877478	et	3	main
töötuba	doc_801781988529_item	2877479	et	4	main
seina	doc_801781988529_item	2877486	et	4	main
nagis	doc_801781988529_item	2877490	et	3	main
on	doc_801781988529_item	2877505	et	4	main
suur	doc_801781988529_item	2877506	et	3	main
seksionkapp	doc_801781988529_item	2877510	et	4	main
sektsionkapi	doc_801781988529_item	2877519	et	4	main
põrandal	doc_801781988529_item	2877524	et	3	main
on	doc_801781988529_item	2877536	et	4	main
kardinad	doc_801781988529_item	2877541	et	4	main
sektsionkapp	doc_801781988529_item	2877553	et	4	main
juures	doc_801781988529_item	2877554	et	4	main
seisab	doc_801781988529_item	2877555	et	3	main
magamistuba	doc_801781988529_item	2877561	et	4	main
on	doc_801781988529_item	2877569	et	4	main
põhjapoolne	doc_801781988529_item	2877575	et	3	main
ees	doc_801781988529_item	2877590	et	4	main
kohal	doc_801781988529_item	2877602	et	4	main
seinal	doc_801781988529_item	2877603	et	3	main
seinalampi	doc_801781988529_item	2877606	et	4	main
on	doc_801781988528_item	2877277	et	4	main
supilusikad	doc_801781988528_item	2877278	et	3	main
seinal	doc_801781988528_item	2877286	et	3	main
teises	doc_801781988528_item	2877289	et	4	main
asuvad	doc_801781988528_item	2877302	et	4	main
seinal	doc_801781988528_item	2877314	et	3	main
ripuvad	doc_801781988528_item	2877315	et	3	main
külmkapi	doc_801781988528_item	2877317	et	3	main
mikrolaineahi	doc_801781988528_item	2877320	et	3	main
aga	doc_801781988528_item	2877321	et	3	main
seisavad	doc_801781988528_item	2877332	et	3	main
laua	doc_801781988528_item	2877337	et	3	main
seinal	doc_801781988528_item	2877339	et	3	main
ees	doc_801781988528_item	2877343	et	4	main
on	doc_801781988528_item	2877344	et	4	main
valge	doc_801781988528_item	2877345	et	4	main
tüllkardin	doc_801781988528_item	2877346	et	3	main
aknalaual	doc_801781988528_item	2877347	et	3	main
sai	doc_801781988528_item	2877353	et	4	main
aga	doc_801781988528_item	2877354	et	3	main
vasakul	doc_801781988528_item	2877355	et	4	main
lill	doc_801781988528_item	2877358	et	3	main
on	doc_801781988528_item	2877364	et	4	main
kaetud	doc_801781988528_item	2877370	et	4	main
linnas	doc_801781988529_item	2877383	et	4	main
südalinn	doc_801781988529_item	2877388	et	3	main
peetri	doc_801781988529_item	2877390	et	3	main
ma	doc_801781988529_item	2877392	et	3	main
liiva	doc_801781988529_item	2877394	et	4	main
hoovis	doc_801781988529_item	2877403	et	4	main
on	doc_801781988529_item	2877404	et	4	main
palju	doc_801781988529_item	2877418	et	4	main
puud	doc_801781988529_item	2877422	et	4	main
ja	doc_801781988529_item	2877423	et	3	main
ilus	doc_801781988529_item	2877432	et	4	main
meie	doc_801781988529_item	2877435	et	4	main
kauplused	doc_801781988529_item	2877442	et	3	main
kool	doc_801781988529_item	2877443	et	4	main
kaks	doc_801781988529_item	2877444	et	3	main
kõnnitee	doc_801781988529_item	2877452	et	4	main
natuke	doc_801781988529_item	2877454	et	4	main
on	doc_801781988529_item	2877464	et	4	main
tuba	doc_801781988529_item	2877475	et	4	main
esikus	doc_801781988529_item	2877493	et	3	main
uksest	doc_801781988529_item	2877507	et	4	main
raamatud	doc_801781988529_item	2877518	et	4	main
ees	doc_801781988529_item	2877535	et	4	main
on	doc_801781988529_item	2877544	et	4	main
on	doc_801781988529_item	2877551	et	4	main
põrandalamp	doc_801781988529_item	2877552	et	3	main
on	doc_801781988529_item	2877558	et	4	main
telefon	doc_801781988529_item	2877559	et	3	main
ei	doc_801781988529_item	2877562	et	4	main
ole	doc_801781988529_item	2877563	et	4	main
väga	doc_801781988529_item	2877564	et	3	main
suur	doc_801781988529_item	2877565	et	3	main
aga	doc_801781988529_item	2877566	et	3	main
see	doc_801781988529_item	2877567	et	3	main
magamistuba	doc_801781988529_item	2877573	et	4	main
akna	doc_801781988529_item	2877584	et	3	main
juures	doc_801781988529_item	2877585	et	4	main
seisab	doc_801781988529_item	2877586	et	3	main
lai	doc_801781988529_item	2877587	et	3	main
valge	doc_801781988529_item	2877592	et	4	main
ole	doc_801781988529_item	2877596	et	4	main
uksest	doc_801781988529_item	2877620	et	4	main
ümmargune	doc_801781988529_item	2877623	et	3	main
vastas	doc_801781988529_item	2877627	et	4	main
seinal	doc_801781988529_item	2877634	et	3	main
ripub	doc_801781988529_item	2877635	et	3	main
riiulid	doc_801781988529_item	2877636	et	3	main
on	doc_801781988529_item	2877646	et	4	main
elektriküte	doc_801781988529_item	2877647	et	3	main
elektriküte	doc_801781988529_item	2877648	et	3	main
kohal	doc_801781988529_item	2877649	et	4	main
klassid	doc_801781988529_item	2877657	et	3	main
on	doc_801781988529_item	2877666	et	4	main
teekann	doc_801781988529_item	2877672	et	3	main
köögipõrand	doc_801781988529_item	2877673	et	3	main
on	doc_801781988529_item	2877685	et	4	main
juures	doc_801781988529_item	2877688	et	4	main
ripub	doc_801781988529_item	2877690	et	3	main
on	doc_801781988529_item	2877693	et	4	main
käterätik	doc_801781988529_item	2877694	et	3	main
köögi	doc_801781988529_item	2877695	et	3	main
sein	doc_801781988529_item	2877696	et	3	main
seisab	doc_801781988529_item	2877703	et	3	main
seina	doc_801781988529_item	2877706	et	4	main
taburet	doc_801781988529_item	2877709	et	3	main
tabureti	doc_801781988529_item	2877721	et	4	main
suur	doc_801781988529_item	2877726	et	3	main
uus	doc_801781988529_item	2877727	et	3	main
kaetud	doc_801781988528_item	2877361	et	4	main
lael	doc_801781988528_item	2877363	et	4	main
kolme	doc_801781988528_item	2877366	et	4	main
köögiseinad	doc_801781988528_item	2877368	et	3	main
on	doc_801781988528_item	2877369	et	4	main
essee	doc_801781988529_item	2877372	et	4	main
minu	doc_801781988529_item	2877373	et	3	main
kodu	doc_801781988529_item	2877374	et	4	main
ma	doc_801781988529_item	2877375	et	3	main
elan	doc_801781988529_item	2877376	et	3	main
ida	doc_801781988529_item	2877379	et	4	main
on	doc_801781988529_item	2877385	et	4	main
piirilinn	doc_801781988529_item	2877386	et	3	main
narva	doc_801781988529_item	2877387	et	4	main
mänguväljakul	doc_801781988529_item	2877407	et	3	main
ronimisredelid	doc_801781988529_item	2877410	et	3	main
liumäed	doc_801781988529_item	2877411	et	3	main
ja	doc_801781988529_item	2877412	et	3	main
pingid	doc_801781988529_item	2877414	et	3	main
ümbres	doc_801781988529_item	2877416	et	4	main
ning	doc_801781988529_item	2877429	et	3	main
on	doc_801781988529_item	2877431	et	4	main
asuvad	doc_801781988529_item	2877438	et	4	main
toidu-	doc_801781988529_item	2877439	et	3	main
ja	doc_801781988529_item	2877440	et	3	main
sõidutee	doc_801781988529_item	2877451	et	4	main
jääb	doc_801781988529_item	2877455	et	3	main
meie	doc_801781988529_item	2877457	et	4	main
on	doc_801781988529_item	2877459	et	4	main
alati	doc_801781988529_item	2877460	et	4	main
puhas	doc_801781988529_item	2877461	et	3	main
meie	doc_801781988529_item	2877466	et	4	main
ei	doc_801781988529_item	2877468	et	4	main
elutuba	doc_801781988529_item	2877476	et	4	main
esik	doc_801781988529_item	2877481	et	3	main
on	doc_801781988529_item	2877482	et	4	main
vaike	doc_801781988529_item	2877483	et	3	main
uksest	doc_801781988529_item	2877484	et	4	main
juures	doc_801781988529_item	2877487	et	4	main
välisriided	doc_801781988529_item	2877492	et	3	main
veel	doc_801781988529_item	2877495	et	4	main
ja	doc_801781988529_item	2877497	et	3	main
elutuba	doc_801781988529_item	2877500	et	4	main
on	doc_801781988529_item	2877501	et	4	main
päikesepoolne	doc_801781988529_item	2877502	et	3	main
minu	doc_801781988529_item	2877503	et	3	main
elutuba	doc_801781988529_item	2877504	et	4	main
ja	doc_801781988529_item	2877514	et	3	main
sahtlid	doc_801781988529_item	2877515	et	3	main
on	doc_801781988529_item	2877517	et	4	main
seinal	doc_801781988529_item	2877521	et	3	main
maal	doc_801781988529_item	2877523	et	4	main
suur	doc_801781988529_item	2877526	et	3	main
valge	doc_801781988529_item	2877537	et	4	main
tüllkardin	doc_801781988529_item	2877538	et	3	main
ja	doc_801781988529_item	2877539	et	3	main
diivanvoodi	doc_801781988529_item	2877545	et	4	main
aknalaual	doc_801781988529_item	2877546	et	3	main
seisavad	doc_801781988529_item	2877547	et	3	main
toalilled	doc_801781988529_item	2877548	et	3	main
divani	doc_801781988529_item	2877549	et	4	main
kirjustuslaual	doc_801781988529_item	2877557	et	4	main
tuba	doc_801781988529_item	2877568	et	4	main
on	doc_801781988529_item	2877574	et	4	main
paremal	doc_801781988529_item	2877577	et	4	main
juures	doc_801781988529_item	2877579	et	4	main
valge	doc_801781988529_item	2877582	et	4	main
voodi	doc_801781988529_item	2877588	et	4	main
akna	doc_801781988529_item	2877589	et	3	main
tüllkardin	doc_801781988529_item	2877593	et	3	main
on	doc_801781988529_item	2877609	et	4	main
suur	doc_801781988529_item	2877610	et	3	main
peegel	doc_801781988529_item	2877611	et	3	main
peegali	doc_801781988529_item	2877612	et	4	main
viru	doc_801781988529_item	2877380	et	4	main
plats	doc_801781988529_item	2877391	et	4	main
on	doc_801781988529_item	2877408	et	4	main
mõned	doc_801781988529_item	2877413	et	3	main
maja	doc_801781988529_item	2877415	et	4	main
kasvavad	doc_801781988529_item	2877420	et	4	main
erastatud	doc_801781988529_item	2877465	et	4	main
ole	doc_801781988529_item	2877469	et	4	main
väga	doc_801781988529_item	2877470	et	3	main
suur	doc_801781988529_item	2877471	et	3	main
meil	doc_801781988529_item	2877472	et	4	main
nagi	doc_801781988529_item	2877489	et	4	main
on	doc_801781988529_item	2877494	et	4	main
seisab	doc_801781988529_item	2877509	et	3	main
on	doc_801781988529_item	2877512	et	4	main
riiulidel	doc_801781988529_item	2877516	et	4	main
kõrval	doc_801781988529_item	2877520	et	4	main
ripuvad	doc_801781988529_item	2877491	et	3	main
peegel	doc_801781988529_item	2877496	et	3	main
seinakapp	doc_801781988529_item	2877498	et	3	main
minu	doc_801781988529_item	2877499	et	3	main
vasakul	doc_801781988529_item	2877508	et	4	main
sektsionkappis	doc_801781988529_item	2877511	et	4	main
riiulid	doc_801781988529_item	2877513	et	3	main
on	doc_801781988529_item	2877522	et	4	main
on	doc_801781988529_item	2877525	et	4	main
rohelisekirju	doc_801781988529_item	2877527	et	4	main
vaip	doc_801781988529_item	2877528	et	3	main
akna	doc_801781988529_item	2877529	et	3	main
juures	doc_801781988529_item	2877530	et	4	main
nurgas	doc_801781988529_item	2877531	et	3	main
seisab	doc_801781988529_item	2877532	et	3	main
teler	doc_801781988529_item	2877533	et	3	main
akna	doc_801781988529_item	2877534	et	3	main
punane	doc_801781988529_item	2877540	et	4	main
vastas	doc_801781988529_item	2877542	et	4	main
vasakul	doc_801781988529_item	2877543	et	4	main
kõrval	doc_801781988529_item	2877550	et	4	main
kirjustuslaud	doc_801781988529_item	2877556	et	4	main
minu	doc_801781988529_item	2877560	et	3	main
soe	doc_801781988529_item	2877570	et	4	main
ja	doc_801781988529_item	2877571	et	3	main
hubane	doc_801781988529_item	2877572	et	3	main
uksest	doc_801781988529_item	2877576	et	4	main
seina	doc_801781988529_item	2877578	et	4	main
seisab	doc_801781988529_item	2877580	et	3	main
suur	doc_801781988529_item	2877581	et	3	main
pesukapp	doc_801781988529_item	2877583	et	3	main
külgkardinaid	doc_801781988529_item	2877594	et	4	main
ei	doc_801781988529_item	2877595	et	4	main
üldse	doc_801781988529_item	2877597	et	3	main
aknalaual	doc_801781988529_item	2877598	et	3	main
seisavad	doc_801781988529_item	2877599	et	3	main
toalilled	doc_801781988529_item	2877600	et	3	main
vodi	doc_801781988529_item	2877601	et	4	main
kaks	doc_801781988529_item	2877605	et	3	main
seisab	doc_801781988529_item	2877614	et	3	main
öökapp	doc_801781988529_item	2877615	et	3	main
on	doc_801781988529_item	2877618	et	4	main
väike	doc_801781988529_item	2877619	et	4	main
seisab	doc_801781988529_item	2877622	et	3	main
juures	doc_801781988529_item	2877645	et	4	main
köögikappis	doc_801781988529_item	2877652	et	4	main
tassid	doc_801781988529_item	2877656	et	4	main
ja	doc_801781988529_item	2877660	et	3	main
köögikappi	doc_801781988529_item	2877664	et	4	main
valamu	doc_801781988529_item	2877667	et	4	main
köögilaual	doc_801781988529_item	2877668	et	3	main
on	doc_801781988529_item	2877669	et	4	main
raadio	doc_801781988529_item	2877704	et	4	main
peal	doc_801781988529_item	2877716	et	4	main
mahlapress	doc_801781988529_item	2877718	et	3	main
ja	doc_801781988529_item	2877722	et	3	main
külmkapi	doc_801781988529_item	2877723	et	3	main
vahel	doc_801781988529_item	2877724	et	4	main
seisab	doc_801781988529_item	2877725	et	3	main
paremal	doc_801781988529_item	2877734	et	4	main
seina	doc_801781988529_item	2877735	et	4	main
ümmargune	doc_801781988529_item	2877739	et	3	main
vastas	doc_801781988529_item	2877751	et	4	main
raamatud	doc_801781988529_item	2877758	et	4	main
suur	doc_801781988529_item	2877768	et	3	main
peegel	doc_801781988529_item	2877770	et	3	main
riiulil	doc_801781988529_item	2877782	et	3	main
juures	doc_801781988529_item	2877791	et	4	main
ripub	doc_801781988529_item	2877797	et	3	main
on	doc_801781988529_item	2877801	et	4	main
avaneb	doc_801781988529_item	2877804	et	3	main
elan	doc_801781988529_item	2877808	et	3	main
maksan	doc_801781988529_item	2877823	et	3	main
kaugekõnesid	doc_801781988529_item	2877829	et	3	main
ja	doc_801781988529_item	2877830	et	3	main
telefonimaksu	doc_801781988529_item	2877832	et	4	main
kolmesaja	doc_801781988529_item	2877834	et	4	main
eraldi	doc_801781988529_item	2877840	et	4	main
vannitoas	doc_801781988529_item	2877841	et	3	main
ja	doc_801781988529_item	2877851	et	3	main
ma	doc_801781988529_item	2877853	et	3	main
on	doc_801781988529_item	2877591	et	4	main
on	doc_801781988529_item	2877604	et	4	main
vastas	doc_801781988529_item	2877607	et	4	main
vasakul	doc_801781988529_item	2877608	et	4	main
minu	doc_801781988529_item	2877616	et	3	main
laud	doc_801781988529_item	2877624	et	4	main
tooliga	doc_801781988529_item	2877626	et	4	main
vasakul	doc_801781988529_item	2877628	et	4	main
on	doc_801781988529_item	2877629	et	4	main
uks	doc_801781988529_item	2877630	et	3	main
rõdule	doc_801781988529_item	2877631	et	3	main
nurgas	doc_801781988529_item	2877637	et	3	main
on	doc_801781988529_item	2877653	et	4	main
nõud	doc_801781988529_item	2877654	et	3	main
taldrikud	doc_801781988529_item	2877655	et	3	main
kõrval	doc_801781988529_item	2877613	et	4	main
köök	doc_801781988529_item	2877617	et	3	main
paremal	doc_801781988529_item	2877621	et	4	main
nelja	doc_801781988529_item	2877625	et	4	main
uksest	doc_801781988529_item	2877632	et	4	main
vasakul	doc_801781988529_item	2877633	et	4	main
on	doc_801781988529_item	2877638	et	4	main
külmkapp	doc_801781988529_item	2877639	et	3	main
külmkapp	doc_801781988529_item	2877640	et	3	main
juures	doc_801781988529_item	2877641	et	4	main
seisab	doc_801781988529_item	2877642	et	3	main
köögikapp	doc_801781988529_item	2877643	et	3	main
köögikapp	doc_801781988529_item	2877644	et	3	main
on	doc_801781988529_item	2877650	et	4	main
tõmbekapp	doc_801781988529_item	2877651	et	3	main
noad	doc_801781988529_item	2877659	et	3	main
külmkapi	doc_801781988529_item	2877662	et	3	main
toiduained	doc_801781988529_item	2877679	et	3	main
laelamp	doc_801781988529_item	2877682	et	3	main
valamu	doc_801781988529_item	2877683	et	4	main
kohal	doc_801781988529_item	2877684	et	4	main
valamu	doc_801781988529_item	2877687	et	4	main
pestavtapeega	doc_801781988529_item	2877699	et	4	main
maast	doc_801781988529_item	2877700	et	3	main
laeni	doc_801781988529_item	2877701	et	4	main
nurgas	doc_801781988529_item	2877702	et	3	main
on	doc_801781988529_item	2877713	et	4	main
seinalamp	doc_801781988529_item	2877714	et	3	main
külmkapi	doc_801781988529_item	2877715	et	3	main
hakklihamasin	doc_801781988529_item	2877720	et	3	main
juures	doc_801781988529_item	2877736	et	4	main
laud	doc_801781988529_item	2877740	et	4	main
laual	doc_801781988529_item	2877741	et	3	main
on	doc_801781988529_item	2877742	et	4	main
laulamp	doc_801781988529_item	2877743	et	3	main
ja	doc_801781988529_item	2877744	et	3	main
telefon	doc_801781988529_item	2877745	et	3	main
põrandal	doc_801781988529_item	2877746	et	3	main
on	doc_801781988529_item	2877752	et	4	main
sektsionkappis	doc_801781988529_item	2877754	et	4	main
ripub	doc_801781988529_item	2877767	et	3	main
väike	doc_801781988529_item	2877780	et	4	main
on	doc_801781988529_item	2877783	et	4	main
vaasis	doc_801781988529_item	2877786	et	3	main
lilled	doc_801781988529_item	2877787	et	3	main
vasakul	doc_801781988529_item	2877789	et	4	main
seisab	doc_801781988529_item	2877792	et	3	main
seinal	doc_801781988529_item	2877796	et	3	main
aken	doc_801781988529_item	2877803	et	3	main
mugavustega	doc_801781988529_item	2877810	et	4	main
ma	doc_801781988529_item	2877822	et	3	main
maksan	doc_801781988529_item	2877831	et	3	main
on	doc_801781988529_item	2877839	et	4	main
jaoks	doc_801781988529_item	2877856	et	4	main
oma	doc_801781988529_item	2877861	et	4	main
korteriga	doc_801781988529_item	2877862	et	3	main
rahul	doc_801781988529_item	2877863	et	4	main
on	doc_801781988530_item	2877882	et	4	main
üheksa	doc_801781988530_item	2877887	et	4	main
rõdule	doc_801781988530_item	2877914	et	3	main
minu	doc_801781988530_item	2877917	et	3	main
köök	doc_801781988530_item	2877925	et	3	main
tualett	doc_801781988530_item	2877928	et	3	main
ei	doc_801781988530_item	2877936	et	4	main
ole	doc_801781988530_item	2877937	et	4	main
prügišaht	doc_801781988530_item	2877938	et	2	main
ja	doc_801781988530_item	2877939	et	3	main
lift	doc_801781988530_item	2877940	et	3	main
meie	doc_801781988530_item	2877941	et	4	main
sissekäigid	doc_801781988530_item	2877948	et	3	main
sissekäigus	doc_801781988530_item	2877949	et	3	main
on	doc_801781988530_item	2877959	et	4	main
kelder	doc_801781988530_item	2877960	et	3	main
väike	doc_801781988530_item	2877967	et	4	main
õues	doc_801781988530_item	2877975	et	4	main
on	doc_801781988530_item	2877980	et	4	main
suvel	doc_801781988530_item	2877993	et	3	main
maja	doc_801781988530_item	2878006	et	4	main
umbruses	doc_801781988530_item	2878007	et	3	main
on	doc_801781988530_item	2878008	et	4	main
turg	doc_801781988530_item	2878023	et	3	main
lusikad	doc_801781988529_item	2877658	et	3	main
ja	doc_801781988529_item	2877663	et	3	main
vahel	doc_801781988529_item	2877665	et	4	main
kaetud	doc_801781988529_item	2877675	et	4	main
linoleumiga	doc_801781988529_item	2877676	et	3	main
külmkapis	doc_801781988529_item	2877677	et	3	main
on	doc_801781988529_item	2877678	et	4	main
pilt	doc_801781988529_item	2877686	et	3	main
seinal	doc_801781988529_item	2877689	et	3	main
nagis	doc_801781988529_item	2877692	et	3	main
on	doc_801781988529_item	2877697	et	4	main
kaetud	doc_801781988529_item	2877698	et	4	main
juures	doc_801781988529_item	2877707	et	4	main
tabureti	doc_801781988529_item	2877710	et	4	main
seisavad	doc_801781988529_item	2877717	et	3	main
kahvlid	doc_801781988529_item	2877661	et	3	main
suhrutoos	doc_801781988529_item	2877670	et	4	main
ja	doc_801781988529_item	2877671	et	3	main
on	doc_801781988529_item	2877674	et	4	main
lael	doc_801781988529_item	2877680	et	4	main
on	doc_801781988529_item	2877681	et	4	main
nagi	doc_801781988529_item	2877691	et	4	main
edasi	doc_801781988529_item	2877705	et	3	main
seisab	doc_801781988529_item	2877708	et	3	main
kohal	doc_801781988529_item	2877711	et	4	main
seinal	doc_801781988529_item	2877712	et	3	main
ja	doc_801781988529_item	2877719	et	3	main
on	doc_801781988529_item	2877731	et	4	main
suur	doc_801781988529_item	2877732	et	3	main
uksest	doc_801781988529_item	2877733	et	4	main
on	doc_801781988529_item	2877747	et	4	main
suur	doc_801781988529_item	2877748	et	3	main
on	doc_801781988529_item	2877755	et	4	main
nõud	doc_801781988529_item	2877756	et	3	main
ja	doc_801781988529_item	2877757	et	3	main
kõrval	doc_801781988529_item	2877764	et	4	main
teisel	doc_801781988529_item	2877765	et	4	main
seinal	doc_801781988529_item	2877766	et	3	main
ümmargune	doc_801781988529_item	2877769	et	3	main
akna	doc_801781988529_item	2877771	et	3	main
riiul	doc_801781988529_item	2877781	et	4	main
klaver	doc_801781988529_item	2877793	et	3	main
kohal	doc_801781988529_item	2877795	et	4	main
maal	doc_801781988529_item	2877799	et	4	main
poole	doc_801781988529_item	2877806	et	4	main
korteris	doc_801781988529_item	2877811	et	3	main
ma	doc_801781988529_item	2877812	et	3	main
maksan	doc_801781988529_item	2877813	et	3	main
elektri	doc_801781988529_item	2877814	et	3	main
eest	doc_801781988529_item	2877815	et	4	main
umbes	doc_801781988529_item	2877816	et	4	main
sada	doc_801781988529_item	2877817	et	4	main
krooni	doc_801781988529_item	2877818	et	4	main
kuus	doc_801781988529_item	2877819	et	4	main
vee	doc_801781988529_item	2877820	et	3	main
teler	doc_801781988529_item	2877728	et	3	main
minu	doc_801781988529_item	2877729	et	3	main
töötuba	doc_801781988529_item	2877730	et	4	main
seisab	doc_801781988529_item	2877737	et	3	main
suur	doc_801781988529_item	2877738	et	3	main
punasekirju	doc_801781988529_item	2877749	et	4	main
vaip	doc_801781988529_item	2877750	et	3	main
sektsionkapp	doc_801781988529_item	2877753	et	4	main
edasi	doc_801781988529_item	2877759	et	3	main
seina	doc_801781988529_item	2877760	et	4	main
juures	doc_801781988529_item	2877761	et	4	main
seisab	doc_801781988529_item	2877762	et	3	main
tugitoll	doc_801781988529_item	2877763	et	3	main
juures	doc_801781988529_item	2877772	et	4	main
nurgas	doc_801781988529_item	2877773	et	3	main
seisab	doc_801781988529_item	2877774	et	3	main
teler	doc_801781988529_item	2877775	et	3	main
teleri	doc_801781988529_item	2877776	et	3	main
kohal	doc_801781988529_item	2877777	et	4	main
seinal	doc_801781988529_item	2877778	et	3	main
on	doc_801781988529_item	2877779	et	4	main
vaas	doc_801781988529_item	2877784	et	3	main
ja	doc_801781988529_item	2877785	et	3	main
edasi	doc_801781988529_item	2877788	et	3	main
seina	doc_801781988529_item	2877790	et	4	main
klaveri	doc_801781988529_item	2877794	et	3	main
suur	doc_801781988529_item	2877798	et	3	main
nurgas	doc_801781988529_item	2877800	et	3	main
hoovi	doc_801781988529_item	2877805	et	4	main
ma	doc_801781988529_item	2877807	et	3	main
kõigi	doc_801781988529_item	2877809	et	4	main
eest	doc_801781988529_item	2877821	et	4	main
mõõturi	doc_801781988529_item	2877824	et	4	main
järgi	doc_801781988529_item	2877825	et	4	main
sageli	doc_801781988529_item	2877826	et	3	main
ma	doc_801781988529_item	2877827	et	3	main
vannituba	doc_801781988529_item	2877838	et	4	main
hambapasta	doc_801781988529_item	2877848	et	4	main
seebid	doc_801781988529_item	2877849	et	3	main
valamu	doc_801781988529_item	2877850	et	4	main
ostan	doc_801781988529_item	2877854	et	3	main
elan	doc_801781988530_item	2877872	et	3	main
viru	doc_801781988530_item	2877876	et	4	main
tallinna	doc_801781988530_item	2877883	et	4	main
tänav	doc_801781988530_item	2877884	et	4	main
rõdu	doc_801781988530_item	2877912	et	4	main
on	doc_801781988530_item	2877915	et	4	main
vannitoa	doc_801781988530_item	2877926	et	3	main
tualett	doc_801781988530_item	2877929	et	3	main
vannituba	doc_801781988530_item	2877931	et	4	main
eraldi	doc_801781988530_item	2877933	et	4	main
minu	doc_801781988530_item	2877934	et	3	main
majas	doc_801781988530_item	2877935	et	3	main
maja	doc_801781988530_item	2877942	et	4	main
keeldriruum	doc_801781988530_item	2877961	et	4	main
uks	doc_801781988530_item	2877962	et	3	main
on	doc_801781988530_item	2877963	et	4	main
lukus	doc_801781988530_item	2877964	et	3	main
umbne	doc_801781988530_item	2877969	et	3	main
maja	doc_801781988530_item	2877970	et	4	main
vastas	doc_801781988530_item	2877971	et	4	main
asub	doc_801781988530_item	2877972	et	3	main
on	doc_801781988530_item	2877976	et	4	main
mänguväljakul	doc_801781988530_item	2877979	et	3	main
mõned	doc_801781988530_item	2877985	et	3	main
sissekäigu	doc_801781988530_item	2877994	et	3	main
alati	doc_801781988530_item	2877995	et	4	main
ilus	doc_801781988530_item	2878003	et	4	main
rohelist	doc_801781988530_item	2878010	et	4	main
maja	doc_801781988530_item	2878016	et	4	main
kõrval	doc_801781988530_item	2878017	et	4	main
ja	doc_801781988530_item	2878024	et	3	main
eemale	doc_801781988530_item	2878026	et	3	main
juuksla	doc_801781988530_item	2878044	et	4	main
kingaparandus	doc_801781988530_item	2878045	et	3	main
ja	doc_801781988530_item	2878046	et	3	main
autoparkla	doc_801781988530_item	2878054	et	4	main
edasi	doc_801781988530_item	2878055	et	3	main
narova	doc_801781988530_item	2878059	et	4	main
asub	doc_801781988530_item	2878062	et	3	main
edasi	doc_801781988530_item	2878066	et	3	main
soldina	doc_801781988530_item	2878074	et	4	main
kušet	doc_801781988529_item	2877802	et	2	main
helistan	doc_801781988529_item	2877828	et	3	main
üle	doc_801781988529_item	2877833	et	3	main
krooni	doc_801781988529_item	2877835	et	4	main
tualett	doc_801781988529_item	2877836	et	3	main
ja	doc_801781988529_item	2877837	et	3	main
on	doc_801781988529_item	2877842	et	4	main
vann	doc_801781988529_item	2877843	et	3	main
peegel	doc_801781988529_item	2877844	et	3	main
pesumasin	doc_801781988529_item	2877845	et	3	main
käterätikud	doc_801781988529_item	2877846	et	3	main
hambaharjad	doc_801781988529_item	2877847	et	3	main
nuustikud	doc_801781988529_item	2877852	et	3	main
pesumasina	doc_801781988529_item	2877855	et	3	main
spetsiaalse	doc_801781988529_item	2877857	et	3	main
olen	doc_801781988529_item	2877860	et	3	main
minu	doc_801781988530_item	2877865	et	3	main
minu	doc_801781988530_item	2877867	et	3	main
nimi	doc_801781988530_item	2877868	et	3	main
on	doc_801781988530_item	2877869	et	4	main
leena	doc_801781988530_item	2877870	et	3	main
ma	doc_801781988530_item	2877871	et	3	main
eesti	doc_801781988530_item	2877873	et	4	main
vabariigis	doc_801781988530_item	2877874	et	3	main
ida	doc_801781988530_item	2877875	et	4	main
korter	doc_801781988530_item	2877888	et	3	main
number	doc_801781988530_item	2877889	et	3	main
viisteist	doc_801781988530_item	2877890	et	4	main
ma	doc_801781988530_item	2877891	et	3	main
elan	doc_801781988530_item	2877892	et	3	main
viiekorruselises	doc_801781988530_item	2877893	et	4	main
paneel	doc_801781988530_item	2877894	et	3	main
majas	doc_801781988530_item	2877895	et	3	main
neljandal	doc_801781988530_item	2877896	et	3	main
korrusel	doc_801781988530_item	2877897	et	3	main
ühetoalisess	doc_801781988530_item	2877898	et	4	main
korteris	doc_801781988530_item	2877899	et	3	main
minu	doc_801781988530_item	2877900	et	3	main
korter	doc_801781988530_item	2877901	et	3	main
ei	doc_801781988530_item	2877902	et	4	main
ole	doc_801781988530_item	2877903	et	4	main
erastatud	doc_801781988530_item	2877904	et	4	main
õpingute	doc_801781988530_item	2877905	et	3	main
ajal	doc_801781988530_item	2877906	et	4	main
elasin	doc_801781988530_item	2877907	et	3	main
üürikorteris	doc_801781988530_item	2877908	et	3	main
minu	doc_801781988530_item	2877909	et	3	main
korteris	doc_801781988530_item	2877910	et	3	main
pesupulbri	doc_801781988529_item	2877858	et	3	main
ma	doc_801781988529_item	2877859	et	3	main
essee	doc_801781988530_item	2877864	et	4	main
kodu	doc_801781988530_item	2877866	et	4	main
maakonnas	doc_801781988530_item	2877877	et	4	main
narva	doc_801781988530_item	2877878	et	4	main
linnas	doc_801781988530_item	2877879	et	4	main
minu	doc_801781988530_item	2877880	et	3	main
aadress	doc_801781988530_item	2877881	et	3	main
maja	doc_801781988530_item	2877885	et	4	main
number	doc_801781988530_item	2877886	et	3	main
on	doc_801781988530_item	2877919	et	4	main
soe	doc_801781988530_item	2877920	et	4	main
korteris	doc_801781988530_item	2877921	et	3	main
mul	doc_801781988530_item	2877922	et	3	main
ja	doc_801781988530_item	2877930	et	3	main
on	doc_801781988530_item	2877932	et	4	main
on	doc_801781988530_item	2877947	et	4	main
on	doc_801781988530_item	2877950	et	4	main
korterit	doc_801781988530_item	2877952	et	3	main
on	doc_801781988530_item	2877966	et	4	main
ja	doc_801781988530_item	2877968	et	3	main
maja	doc_801781988530_item	2877974	et	4	main
laste	doc_801781988530_item	2877977	et	4	main
liumaed	doc_801781988530_item	2877982	et	4	main
suvel	doc_801781988530_item	2877987	et	3	main
käin	doc_801781988530_item	2877989	et	3	main
lapsega	doc_801781988530_item	2877991	et	3	main
kasvavad	doc_801781988530_item	2877996	et	4	main
ilus	doc_801781988530_item	2877997	et	4	main
lilled	doc_801781988530_item	2877998	et	3	main
aga	doc_801781988530_item	2877999	et	3	main
ning	doc_801781988530_item	2878000	et	3	main
muru	doc_801781988530_item	2878005	et	4	main
kasvavad	doc_801781988530_item	2878011	et	4	main
puud	doc_801781988530_item	2878013	et	4	main
põõsad	doc_801781988530_item	2878015	et	3	main
maja	doc_801781988530_item	2878022	et	4	main
bussipeatus	doc_801781988530_item	2878035	et	4	main
on	doc_801781988530_item	2878038	et	4	main
kaks	doc_801781988530_item	2878039	et	3	main
lasteaeda	doc_801781988530_item	2878040	et	4	main
raudtee	doc_801781988530_item	2878050	et	4	main
on	doc_801781988530_item	2878057	et	4	main
hostel	doc_801781988530_item	2878063	et	4	main
on	doc_801781988530_item	2878067	et	4	main
kauplus	doc_801781988530_item	2878069	et	3	main
kauplust	doc_801781988530_item	2878071	et	4	main
vastas	doc_801781988530_item	2878072	et	4	main
see	doc_801781988530_item	2878093	et	3	main
avar	doc_801781988530_item	2878095	et	3	main
suur	doc_801781988530_item	2878108	et	3	main
seisab	doc_801781988530_item	2878112	et	3	main
seinal	doc_801781988530_item	2878115	et	3	main
seisab	doc_801781988530_item	2878117	et	3	main
tugitoolvoodi	doc_801781988530_item	2878118	et	4	main
akna	doc_801781988530_item	2878119	et	3	main
on	doc_801781988530_item	2878125	et	4	main
teisel	doc_801781988530_item	2878151	et	4	main
sahtlis	doc_801781988530_item	2878152	et	3	main
seinal	doc_801781988530_item	2878196	et	3	main
ilus	doc_801781988530_item	2878198	et	4	main
laserplaadimängija	doc_801781988530_item	2878213	et	4	main
nurgadiivanis	doc_801781988530_item	2878214	et	3	main
aga	doc_801781988530_item	2878220	et	3	main
vaip	doc_801781988530_item	2878229	et	3	main
kaetud	doc_801781988530_item	2878232	et	4	main
tapeetiga	doc_801781988530_item	2878234	et	4	main
õhtuti	doc_801781988530_item	2878244	et	3	main
teler	doc_801781988530_item	2878247	et	3	main
minu	doc_801781988530_item	2878248	et	3	main
välisuksest	doc_801781988530_item	2878257	et	4	main
paremal	doc_801781988530_item	2878258	et	4	main
purke	doc_801781988530_item	2878267	et	3	main
herkulo	doc_801781988530_item	2878276	et	4	main
riis	doc_801781988530_item	2878277	et	3	main
manna	doc_801781988530_item	2878278	et	4	main
sool	doc_801781988530_item	2878280	et	4	main
paber	doc_801781988530_item	2878327	et	3	main
tualetis	doc_801781988530_item	2878328	et	3	main
tualet	doc_801781988530_item	2878335	et	4	main
tualetit	doc_801781988530_item	2878346	et	4	main
on	doc_801781988530_item	2877923	et	4	main
elutoa	doc_801781988530_item	2877924	et	3	main
ja	doc_801781988530_item	2877927	et	3	main
välisuks	doc_801781988530_item	2877943	et	4	main
käib	doc_801781988530_item	2877944	et	3	main
lukus	doc_801781988530_item	2877945	et	3	main
majas	doc_801781988530_item	2877946	et	3	main
kakskümmend	doc_801781988530_item	2877951	et	4	main
meie	doc_801781988530_item	2877953	et	4	main
trepikoda	doc_801781988530_item	2877954	et	4	main
on	doc_801781988530_item	2877955	et	4	main
alati	doc_801781988530_item	2877956	et	4	main
puhas	doc_801781988530_item	2877957	et	3	main
majas	doc_801781988530_item	2877958	et	3	main
on	doc_801781988530_item	2877911	et	4	main
uks	doc_801781988530_item	2877913	et	3	main
elutoast	doc_801781988530_item	2877916	et	3	main
korter	doc_801781988530_item	2877918	et	3	main
keeldriruum	doc_801781988530_item	2877965	et	4	main
õues	doc_801781988530_item	2877973	et	4	main
mänguväljak	doc_801781988530_item	2877978	et	3	main
ja	doc_801781988530_item	2877984	et	3	main
pingid	doc_801781988530_item	2877986	et	3	main
ma	doc_801781988530_item	2877988	et	3	main
õues	doc_801781988530_item	2877990	et	4	main
jalutamas	doc_801781988530_item	2877992	et	3	main
pehme	doc_801781988530_item	2878004	et	4	main
palju	doc_801781988530_item	2878009	et	4	main
autoregistri	doc_801781988530_item	2878021	et	3	main
natuke	doc_801781988530_item	2878025	et	4	main
on	doc_801781988530_item	2878031	et	4	main
sõidutee	doc_801781988530_item	2878032	et	4	main
vastas	doc_801781988530_item	2878037	et	4	main
vasakul	doc_801781988530_item	2878042	et	4	main
asub	doc_801781988530_item	2878043	et	3	main
on	doc_801781988530_item	2878053	et	4	main
mööblikombinat	doc_801781988530_item	2878058	et	4	main
paremal	doc_801781988530_item	2878061	et	4	main
baar	doc_801781988530_item	2878065	et	3	main
maxima	doc_801781988530_item	2878070	et	4	main
on	doc_801781988530_item	2878073	et	4	main
elutuba	doc_801781988530_item	2878084	et	4	main
köök	doc_801781988530_item	2878085	et	3	main
on	doc_801781988530_item	2878091	et	4	main
ja	doc_801781988530_item	2878096	et	3	main
eluaken	doc_801781988530_item	2878098	et	3	main
avaneb	doc_801781988530_item	2878099	et	3	main
hoovi	doc_801781988530_item	2878100	et	4	main
poole	doc_801781988530_item	2878101	et	4	main
aknalaual	doc_801781988530_item	2878102	et	3	main
seisavad	doc_801781988530_item	2878103	et	3	main
toalilled	doc_801781988530_item	2878104	et	3	main
elutoas	doc_801781988530_item	2878105	et	3	main
nurgadiivani	doc_801781988530_item	2878110	et	4	main
ääres	doc_801781988530_item	2878111	et	4	main
diivanilaud	doc_801781988530_item	2878113	et	4	main
edasi	doc_801781988530_item	2878114	et	3	main
nurgas	doc_801781988530_item	2878121	et	3	main
seisab	doc_801781988530_item	2878122	et	3	main
riidekapp	doc_801781988530_item	2878123	et	3	main
ja	doc_801781988530_item	2878127	et	3	main
sahtlid	doc_801781988530_item	2878128	et	3	main
on	doc_801781988530_item	2878130	et	4	main
tekikotid	doc_801781988530_item	2878132	et	3	main
padjapüürid	doc_801781988530_item	2878133	et	3	main
teisel	doc_801781988530_item	2878136	et	4	main
riiul	doc_801781988530_item	2878141	et	4	main
puhas	doc_801781988530_item	2878143	et	3	main
sahtlis	doc_801781988530_item	2878145	et	3	main
puhas	doc_801781988530_item	2878147	et	3	main
külgkardinad	doc_801781988530_item	2878148	et	4	main
ja	doc_801781988530_item	2878149	et	3	main
tüllkardin	doc_801781988530_item	2878150	et	3	main
ja	doc_801781988530_item	2878160	et	3	main
on	doc_801781988530_item	2878162	et	4	main
väike	doc_801781988530_item	2878163	et	4	main
peegel	doc_801781988530_item	2878164	et	3	main
toa	doc_801781988530_item	2878165	et	3	main
nurgas	doc_801781988530_item	2878166	et	3	main
on	doc_801781988530_item	2878167	et	4	main
suur	doc_801781988530_item	2878168	et	3	main
palm	doc_801781988530_item	2878169	et	3	main
on	doc_801781988530_item	2878190	et	4	main
külgkardinad	doc_801781988530_item	2878193	et	4	main
teler	doc_801781988530_item	2878205	et	3	main
on	doc_801781988530_item	2878215	et	4	main
padi	doc_801781988530_item	2878219	et	3	main
liivakast	doc_801781988530_item	2877981	et	4	main
ronimisredelid	doc_801781988530_item	2877983	et	3	main
õues	doc_801781988530_item	2878001	et	4	main
on	doc_801781988530_item	2878002	et	4	main
erinevad	doc_801781988530_item	2878012	et	4	main
ja	doc_801781988530_item	2878014	et	3	main
on	doc_801781988530_item	2878018	et	4	main
toidu	doc_801781988530_item	2878019	et	3	main
kauplus	doc_801781988530_item	2878020	et	3	main
on	doc_801781988530_item	2878027	et	4	main
kingaparandus	doc_801781988530_item	2878028	et	3	main
edasi	doc_801781988530_item	2878029	et	3	main
vasakul	doc_801781988530_item	2878030	et	4	main
sõiduteel	doc_801781988530_item	2878033	et	3	main
on	doc_801781988530_item	2878034	et	4	main
kauplust	doc_801781988530_item	2878036	et	4	main
maja	doc_801781988530_item	2878041	et	4	main
natuke	doc_801781988530_item	2878047	et	4	main
eemale	doc_801781988530_item	2878048	et	3	main
on	doc_801781988530_item	2878049	et	4	main
kõrval	doc_801781988530_item	2878051	et	4	main
vasakul	doc_801781988530_item	2878052	et	4	main
vasakul	doc_801781988530_item	2878056	et	4	main
kauplust	doc_801781988530_item	2878060	et	4	main
ja	doc_801781988530_item	2878064	et	3	main
suur	doc_801781988530_item	2878068	et	3	main
korter	doc_801781988530_item	2878077	et	3	main
vannituba	doc_801781988530_item	2878086	et	4	main
päikesepoolne	doc_801781988530_item	2878092	et	3	main
on	doc_801781988530_item	2878094	et	4	main
valgusküllane	doc_801781988530_item	2878097	et	4	main
juures	doc_801781988530_item	2878116	et	4	main
riiulid	doc_801781988530_item	2878126	et	3	main
riiul	doc_801781988530_item	2878137	et	4	main
on	doc_801781988530_item	2878138	et	4	main
köögikäterätikud	doc_801781988530_item	2878139	et	3	main
kolmandal	doc_801781988530_item	2878140	et	3	main
riided	doc_801781988530_item	2878144	et	3	main
on	doc_801781988530_item	2878146	et	4	main
puhas	doc_801781988530_item	2878154	et	3	main
lapse	doc_801781988530_item	2878155	et	4	main
riided	doc_801781988530_item	2878156	et	3	main
nagis	doc_801781988530_item	2878157	et	3	main
ripuvad	doc_801781988530_item	2878158	et	3	main
välisriided	doc_801781988530_item	2878159	et	3	main
uksest	doc_801781988530_item	2878170	et	4	main
tüüllkardin	doc_801781988530_item	2878191	et	4	main
ja	doc_801781988530_item	2878192	et	3	main
on	doc_801781988530_item	2878210	et	4	main
videomagnetofon	doc_801781988530_item	2878211	et	3	main
ja	doc_801781988530_item	2878212	et	3	main
villane	doc_801781988530_item	2878216	et	4	main
tekk	doc_801781988530_item	2878217	et	3	main
ja	doc_801781988530_item	2878218	et	3	main
voodikate	doc_801781988530_item	2878224	et	3	main
elutoa	doc_801781988530_item	2878225	et	3	main
põrandal	doc_801781988530_item	2878226	et	3	main
on	doc_801781988530_item	2878227	et	4	main
pruunikirju	doc_801781988530_item	2878228	et	4	main
talvel	doc_801781988530_item	2878235	et	4	main
meil	doc_801781988530_item	2878236	et	4	main
elutoas	doc_801781988530_item	2878237	et	3	main
on	doc_801781988530_item	2878238	et	4	main
külm	doc_801781988530_item	2878239	et	3	main
ma	doc_801781988530_item	2878240	et	3	main
sisse	doc_801781988530_item	2878241	et	4	main
vaatame	doc_801781988530_item	2878246	et	3	main
esik	doc_801781988530_item	2878251	et	3	main
sahveris	doc_801781988530_item	2878263	et	3	main
hojan	doc_801781988530_item	2878265	et	4	main
tühje	doc_801781988530_item	2878266	et	3	main
purkes	doc_801781988530_item	2878274	et	4	main
ja	doc_801781988530_item	2878281	et	3	main
paremal	doc_801781988530_item	2878289	et	4	main
juures	doc_801781988530_item	2878291	et	4	main
uks	doc_801781988530_item	2878321	et	3	main
tualetti	doc_801781988530_item	2878322	et	4	main
ja	doc_801781988530_item	2878323	et	3	main
seisab	doc_801781988530_item	2878329	et	3	main
vannituba	doc_801781988530_item	2878337	et	4	main
on	doc_801781988530_item	2878338	et	4	main
eraldi	doc_801781988530_item	2878339	et	4	main
vee	doc_801781988530_item	2878340	et	3	main
järgi	doc_801781988530_item	2878345	et	4	main
riiul	doc_801781988530_item	2878356	et	4	main
jaoks	doc_801781988530_item	2878359	et	4	main
pesupulbri	doc_801781988530_item	2878361	et	3	main
kahhelkiviga	doc_801781988530_item	2878373	et	3	main
seina	doc_801781988530_item	2878375	et	4	main
juures	doc_801781988530_item	2878376	et	4	main
minu	doc_801781988530_item	2878076	et	3	main
tualett	doc_801781988530_item	2878087	et	3	main
ja	doc_801781988530_item	2878088	et	3	main
esik	doc_801781988530_item	2878089	et	3	main
on	doc_801781988530_item	2878106	et	4	main
mugav	doc_801781988530_item	2878107	et	3	main
kapis	doc_801781988530_item	2878124	et	3	main
riiulis	doc_801781988530_item	2878129	et	3	main
voodipesu	doc_801781988530_item	2878131	et	4	main
ja	doc_801781988530_item	2878134	et	3	main
linad	doc_801781988530_item	2878135	et	3	main
on	doc_801781988530_item	2878142	et	4	main
on	doc_801781988530_item	2878153	et	4	main
veel	doc_801781988530_item	2878161	et	4	main
paremal	doc_801781988530_item	2878171	et	4	main
seina	doc_801781988530_item	2878172	et	4	main
juures	doc_801781988530_item	2878173	et	4	main
seisab	doc_801781988530_item	2878174	et	3	main
väike	doc_801781988530_item	2878175	et	4	main
kapp	doc_801781988530_item	2878176	et	3	main
kapis	doc_801781988530_item	2878177	et	3	main
on	doc_801781988530_item	2878178	et	4	main
riiulid	doc_801781988530_item	2878179	et	3	main
riiulis	doc_801781988530_item	2878180	et	3	main
on	doc_801781988530_item	2878181	et	4	main
ramatud	doc_801781988530_item	2878182	et	4	main
nõud	doc_801781988530_item	2878183	et	3	main
nurgadiivani	doc_801781988530_item	2878184	et	4	main
kohal	doc_801781988530_item	2878185	et	4	main
seinal	doc_801781988530_item	2878186	et	3	main
on	doc_801781988530_item	2878187	et	4	main
seinalamp	doc_801781988530_item	2878188	et	3	main
apteek	doc_801781988530_item	2878075	et	3	main
on	doc_801781988530_item	2878078	et	4	main
väike	doc_801781988530_item	2878079	et	4	main
aga	doc_801781988530_item	2878080	et	3	main
hubane	doc_801781988530_item	2878081	et	3	main
korteris	doc_801781988530_item	2878082	et	3	main
on	doc_801781988530_item	2878083	et	4	main
elutuba	doc_801781988530_item	2878090	et	4	main
nurgadiivan	doc_801781988530_item	2878109	et	3	main
juures	doc_801781988530_item	2878120	et	4	main
kohal	doc_801781988530_item	2878195	et	4	main
on	doc_801781988530_item	2878197	et	4	main
pilt	doc_801781988530_item	2878199	et	3	main
seisab	doc_801781988530_item	2878202	et	3	main
suur	doc_801781988530_item	2878203	et	3	main
teler	doc_801781988530_item	2878204	et	3	main
nurgadiivani	doc_801781988530_item	2878221	et	4	main
peal	doc_801781988530_item	2878222	et	4	main
on	doc_801781988530_item	2878223	et	4	main
aga	doc_801781988530_item	2878230	et	3	main
valge	doc_801781988530_item	2878233	et	4	main
sojapuhur	doc_801781988530_item	2878243	et	3	main
me	doc_801781988530_item	2878245	et	4	main
korteris	doc_801781988530_item	2878249	et	3	main
on	doc_801781988530_item	2878250	et	4	main
esik	doc_801781988530_item	2878252	et	3	main
on	doc_801781988530_item	2878253	et	4	main
seina	doc_801781988530_item	2878259	et	4	main
see	doc_801781988530_item	2878268	et	3	main
purked	doc_801781988530_item	2878270	et	4	main
on	doc_801781988530_item	2878275	et	4	main
liha	doc_801781988530_item	2878282	et	4	main
kana	doc_801781988530_item	2878284	et	4	main
kartuliroogade	doc_801781988530_item	2878286	et	3	main
seisab	doc_801781988530_item	2878292	et	3	main
väike	doc_801781988530_item	2878293	et	4	main
riidekapp	doc_801781988530_item	2878294	et	3	main
kapis	doc_801781988530_item	2878295	et	3	main
riipuvad	doc_801781988530_item	2878296	et	4	main
välisriided	doc_801781988530_item	2878297	et	3	main
aga	doc_801781988530_item	2878298	et	3	main
veel	doc_801781988530_item	2878299	et	4	main
on	doc_801781988530_item	2878300	et	4	main
kingad	doc_801781988530_item	2878301	et	3	main
kapis	doc_801781988530_item	2878302	et	3	main
on	doc_801781988530_item	2878303	et	4	main
toidupaketid	doc_801781988530_item	2878304	et	3	main
paremal	doc_801781988530_item	2878305	et	4	main
seina	doc_801781988530_item	2878306	et	4	main
peal	doc_801781988530_item	2878307	et	4	main
on	doc_801781988530_item	2878308	et	4	main
väike	doc_801781988530_item	2878309	et	4	main
riiul	doc_801781988530_item	2878310	et	4	main
riiulis	doc_801781988530_item	2878311	et	3	main
on	doc_801781988530_item	2878312	et	4	main
korterivõtmed	doc_801781988530_item	2878313	et	3	main
ja	doc_801781988530_item	2878314	et	3	main
masina	doc_801781988530_item	2878315	et	3	main
võti	doc_801781988530_item	2878316	et	4	main
edasi	doc_801781988530_item	2878317	et	3	main
seinal	doc_801781988530_item	2878318	et	3	main
juures	doc_801781988530_item	2878319	et	4	main
on	doc_801781988530_item	2878320	et	4	main
aknale	doc_801781988530_item	2878189	et	3	main
tugitooli	doc_801781988530_item	2878194	et	4	main
uksest	doc_801781988530_item	2878200	et	4	main
vastas	doc_801781988530_item	2878201	et	4	main
on	doc_801781988530_item	2878206	et	4	main
laua	doc_801781988530_item	2878207	et	3	main
peal	doc_801781988530_item	2878208	et	4	main
lauariiulis	doc_801781988530_item	2878209	et	3	main
sein	doc_801781988530_item	2878231	et	3	main
lülletan	doc_801781988530_item	2878242	et	4	main
vaiksevõtu	doc_801781988530_item	2878254	et	4	main
ja	doc_801781988530_item	2878255	et	3	main
pime	doc_801781988530_item	2878256	et	3	main
juures	doc_801781988530_item	2878260	et	4	main
seisab	doc_801781988530_item	2878261	et	3	main
sahver	doc_801781988530_item	2878262	et	3	main
ma	doc_801781988530_item	2878264	et	3	main
on	doc_801781988530_item	2878269	et	4	main
tangudiga	doc_801781988530_item	2878271	et	4	main
ja	doc_801781988530_item	2878272	et	3	main
suhkruga	doc_801781988530_item	2878273	et	3	main
jahu	doc_801781988530_item	2878279	et	4	main
kala	doc_801781988530_item	2878283	et	4	main
juurvilja	doc_801781988530_item	2878285	et	4	main
üldmaitseaine	doc_801781988530_item	2878287	et	4	main
uksest	doc_801781988530_item	2878288	et	4	main
vannituba	doc_801781988530_item	2878324	et	4	main
tualetis	doc_801781988530_item	2878325	et	3	main
ma	doc_801781988530_item	2878342	et	3	main
maksan	doc_801781988530_item	2878343	et	3	main
mõturi	doc_801781988530_item	2878344	et	4	main
kohal	doc_801781988530_item	2878347	et	4	main
kapp	doc_801781988530_item	2878350	et	3	main
riiulid	doc_801781988530_item	2878354	et	3	main
tööstusinstrumendid	doc_801781988530_item	2878368	et	3	main
tualeti	doc_801781988530_item	2878369	et	3	main
põrand	doc_801781988530_item	2878370	et	3	main
on	doc_801781988530_item	2878371	et	4	main
ja	doc_801781988530_item	2878379	et	3	main
ruumi	doc_801781988530_item	2878384	et	4	main
seinal	doc_801781988530_item	2878390	et	3	main
riipuvad	doc_801781988530_item	2878391	et	4	main
seinakapp	doc_801781988530_item	2878392	et	3	main
seinakapis	doc_801781988530_item	2878393	et	3	main
on	doc_801781988530_item	2878394	et	4	main
riiulid	doc_801781988530_item	2878395	et	3	main
sahtlid	doc_801781988530_item	2878397	et	3	main
on	doc_801781988530_item	2878409	et	4	main
hambapasta	doc_801781988530_item	2878410	et	4	main
hambaharjad	doc_801781988530_item	2878411	et	3	main
kahvel	doc_801781988530_item	2878412	et	4	main
ja	doc_801781988530_item	2878413	et	3	main
seina	doc_801781988530_item	2878290	et	4	main
on	doc_801781988530_item	2878326	et	4	main
soe	doc_801781988530_item	2878330	et	4	main
ja	doc_801781988530_item	2878331	et	3	main
külm	doc_801781988530_item	2878332	et	3	main
vett	doc_801781988530_item	2878333	et	3	main
mõõtur	doc_801781988530_item	2878334	et	3	main
ja	doc_801781988530_item	2878336	et	3	main
eest	doc_801781988530_item	2878341	et	4	main
väike	doc_801781988530_item	2878349	et	4	main
on	doc_801781988530_item	2878352	et	4	main
esimesel	doc_801781988530_item	2878355	et	3	main
pasta	doc_801781988530_item	2878364	et	4	main
kaetud	doc_801781988530_item	2878372	et	4	main
kühvel	doc_801781988530_item	2878380	et	3	main
vasakul	doc_801781988530_item	2878389	et	4	main
on	doc_801781988530_item	2878400	et	4	main
riiul	doc_801781988530_item	2878415	et	4	main
on	doc_801781988530_item	2878416	et	4	main
föön	doc_801781988530_item	2878417	et	3	main
ja	doc_801781988530_item	2878418	et	3	main
lokitang	doc_801781988530_item	2878419	et	3	main
uksest	doc_801781988530_item	2878420	et	4	main
valge	doc_801781988530_item	2878423	et	4	main
vann	doc_801781988530_item	2878424	et	3	main
ja	doc_801781988530_item	2878425	et	3	main
on	doc_801781988530_item	2878429	et	4	main
vannitoa	doc_801781988530_item	2878443	et	3	main
ripuvad	doc_801781988530_item	2878451	et	3	main
must	doc_801781988530_item	2878464	et	4	main
pesu	doc_801781988530_item	2878465	et	4	main
minu	doc_801781988530_item	2878466	et	3	main
poole	doc_801781988530_item	2878478	et	4	main
aknalaual	doc_801781988530_item	2878479	et	3	main
seisavad	doc_801781988530_item	2878480	et	3	main
roosa	doc_801781988530_item	2878486	et	4	main
ja	doc_801781988530_item	2878527	et	3	main
aedviljad	doc_801781988530_item	2878529	et	3	main
tomatid	doc_801781988530_item	2878533	et	3	main
on	doc_801781988530_item	2878538	et	4	main
siin	doc_801781988530_item	2878540	et	4	main
liha	doc_801781988530_item	2878544	et	4	main
ja	doc_801781988530_item	2878548	et	3	main
mugav	doc_801781988530_item	2878554	et	3	main
ja	doc_801781988530_item	2878556	et	3	main
nurgadiivani	doc_801781988530_item	2878558	et	4	main
juures	doc_801781988530_item	2878562	et	4	main
palju	doc_801781988530_item	2878569	et	4	main
eletrivahvli	doc_801781988530_item	2878577	et	4	main
küpsetusmasin	doc_801781988530_item	2878578	et	3	main
pannid	doc_801781988530_item	2878581	et	3	main
ümmargune	doc_801781988530_item	2878585	et	3	main
söögilaud	doc_801781988530_item	2878586	et	4	main
seina	doc_801781988530_item	2878599	et	4	main
juures	doc_801781988530_item	2878600	et	4	main
juures	doc_801781988530_item	2878606	et	4	main
on	doc_801781988530_item	2878607	et	4	main
nõudepesuvahend	doc_801781988530_item	2878608	et	3	main
ma	doc_801781988530_item	2878622	et	3	main
olen	doc_801781988530_item	2878623	et	3	main
väga	doc_801781988530_item	2878624	et	3	main
rahul	doc_801781988530_item	2878625	et	4	main
pidevalt	doc_801781988530_item	2878629	et	4	main
ma	doc_801781988530_item	2878630	et	3	main
koristan	doc_801781988530_item	2878631	et	3	main
lagi	doc_801781988530_item	2878633	et	4	main
lilla	doc_801781988530_item	2878637	et	4	main
laelamp	doc_801781988530_item	2878638	et	3	main
nurgas	doc_801781988530_item	2878639	et	3	main
akna	doc_801781988530_item	2878640	et	3	main
mõned	doc_801781988530_item	2878648	et	3	main
sahtel	doc_801781988530_item	2878651	et	3	main
on	doc_801781988530_item	2878657	et	4	main
kapi	doc_801781988530_item	2878668	et	4	main
peale	doc_801781988530_item	2878669	et	4	main
seisab	doc_801781988530_item	2878670	et	3	main
on	doc_801781988530_item	2878348	et	4	main
kapis	doc_801781988530_item	2878351	et	3	main
kaks	doc_801781988530_item	2878353	et	3	main
on	doc_801781988530_item	2878357	et	4	main
ja	doc_801781988530_item	2878362	et	3	main
on	doc_801781988530_item	2878367	et	4	main
hari	doc_801781988530_item	2878378	et	4	main
on	doc_801781988530_item	2878382	et	4	main
see	doc_801781988530_item	2878385	et	3	main
niiske	doc_801781988530_item	2878387	et	4	main
ja	doc_801781988530_item	2878396	et	3	main
pesemisvahendid	doc_801781988530_item	2878401	et	3	main
šampoon	doc_801781988530_item	2878403	et	2	main
balsam	doc_801781988530_item	2878404	et	4	main
ja	doc_801781988530_item	2878405	et	3	main
kreem	doc_801781988530_item	2878406	et	3	main
teisel	doc_801781988530_item	2878407	et	4	main
sahtlis	doc_801781988530_item	2878408	et	3	main
kraanikausi	doc_801781988530_item	2878431	et	3	main
kohal	doc_801781988530_item	2878432	et	4	main
vannitoas	doc_801781988530_item	2878438	et	3	main
sein	doc_801781988530_item	2878444	et	3	main
on	doc_801781988530_item	2878445	et	4	main
kaetud	doc_801781988530_item	2878446	et	4	main
kahhelkiviga	doc_801781988530_item	2878447	et	3	main
maast	doc_801781988530_item	2878448	et	3	main
vannitoas	doc_801781988530_item	2878454	et	3	main
kraanikaus	doc_801781988530_item	2878458	et	4	main
all	doc_801781988530_item	2878459	et	3	main
seisab	doc_801781988530_item	2878460	et	3	main
pesukorv	doc_801781988530_item	2878461	et	3	main
pesukorvis	doc_801781988530_item	2878462	et	3	main
on	doc_801781988530_item	2878463	et	4	main
päikesepoolne	doc_801781988530_item	2878469	et	3	main
väike	doc_801781988530_item	2878472	et	4	main
aga	doc_801781988530_item	2878473	et	3	main
hubane	doc_801781988530_item	2878474	et	3	main
köögiaken	doc_801781988530_item	2878475	et	3	main
avaneb	doc_801781988530_item	2878476	et	3	main
hoovi	doc_801781988530_item	2878477	et	4	main
on	doc_801781988530_item	2878485	et	4	main
köögiakna	doc_801781988530_item	2878488	et	3	main
on	doc_801781988530_item	2878490	et	4	main
kardinad	doc_801781988530_item	2878492	et	4	main
külmkapis	doc_801781988530_item	2878499	et	3	main
siin	doc_801781988530_item	2878503	et	4	main
apelsinid	doc_801781988530_item	2878522	et	3	main
banaanid	doc_801781988530_item	2878523	et	3	main
viinamari	doc_801781988530_item	2878525	et	4	main
palju	doc_801781988530_item	2878528	et	4	main
ja	doc_801781988530_item	2878535	et	3	main
külmkapis	doc_801781988530_item	2878537	et	3	main
sügavkülmik	doc_801781988530_item	2878539	et	3	main
ma	doc_801781988530_item	2878541	et	3	main
hojan	doc_801781988530_item	2878542	et	4	main
pelmenid	doc_801781988530_item	2878546	et	4	main
lihatoiduanned	doc_801781988530_item	2878549	et	4	main
karbid	doc_801781988530_item	2878571	et	3	main
ääres	doc_801781988530_item	2878583	et	4	main
uksest	doc_801781988530_item	2878587	et	4	main
väike	doc_801781988530_item	2878591	et	4	main
on	doc_801781988530_item	2878594	et	4	main
teekann	doc_801781988530_item	2878595	et	3	main
ja	doc_801781988530_item	2878596	et	3	main
suhkrutoos	doc_801781988530_item	2878597	et	3	main
valamu	doc_801781988530_item	2878609	et	4	main
all	doc_801781988530_item	2878610	et	3	main
seisab	doc_801781988530_item	2878611	et	3	main
prügiämber	doc_801781988530_item	2878612	et	3	main
ma	doc_801781988530_item	2878617	et	3	main
prügiämbri	doc_801781988530_item	2878619	et	3	main
välja	doc_801781988530_item	2878620	et	4	main
pesumasina	doc_801781988530_item	2878358	et	3	main
spetsiaalse	doc_801781988530_item	2878360	et	3	main
spetsiaalse	doc_801781988530_item	2878363	et	3	main
teisel	doc_801781988530_item	2878365	et	4	main
riiul	doc_801781988530_item	2878366	et	4	main
nurgas	doc_801781988530_item	2878374	et	3	main
vannitoas	doc_801781988530_item	2878381	et	3	main
vähe	doc_801781988530_item	2878383	et	3	main
on	doc_801781988530_item	2878386	et	4	main
paremal	doc_801781988530_item	2878426	et	4	main
seina	doc_801781988530_item	2878427	et	4	main
kraanikaus	doc_801781988530_item	2878430	et	4	main
on	doc_801781988530_item	2878434	et	4	main
ümmargune	doc_801781988530_item	2878436	et	3	main
on	doc_801781988530_item	2878439	et	4	main
duš	doc_801781988530_item	2878440	et	2	main
ja	doc_801781988530_item	2878441	et	3	main
kraan	doc_801781988530_item	2878442	et	3	main
nagis	doc_801781988530_item	2878453	et	3	main
ma	doc_801781988530_item	2878455	et	3	main
pesu	doc_801781988530_item	2878457	et	4	main
köök	doc_801781988530_item	2878467	et	3	main
on	doc_801781988530_item	2878468	et	4	main
on	doc_801781988530_item	2878471	et	4	main
ees	doc_801781988530_item	2878484	et	4	main
paremal	doc_801781988530_item	2878494	et	4	main
seisab	doc_801781988530_item	2878497	et	3	main
hojan	doc_801781988530_item	2878501	et	4	main
hapukoor	doc_801781988530_item	2878505	et	4	main
on	doc_801781988530_item	2878504	et	4	main
või	doc_801781988530_item	2878506	et	4	main
vorsti	doc_801781988530_item	2878507	et	4	main
majoneesi	doc_801781988530_item	2878508	et	4	main
juustu	doc_801781988530_item	2878509	et	4	main
tomatipasta	doc_801781988530_item	2878510	et	4	main
koore	doc_801781988530_item	2878511	et	4	main
mahla	doc_801781988530_item	2878512	et	4	main
pakk	doc_801781988530_item	2878513	et	3	main
piima	doc_801781988530_item	2878514	et	4	main
ja	doc_801781988530_item	2878516	et	3	main
viinerid	doc_801781988530_item	2878515	et	3	main
palju	doc_801781988530_item	2878517	et	4	main
puuviljad	doc_801781988530_item	2878518	et	3	main
see	doc_801781988530_item	2878519	et	3	main
on	doc_801781988530_item	2878520	et	4	main
pirnid	doc_801781988530_item	2878521	et	3	main
mandarinid	doc_801781988530_item	2878524	et	4	main
õunad	doc_801781988530_item	2878526	et	3	main
porgandid	doc_801781988530_item	2878531	et	3	main
kurgid	doc_801781988530_item	2878532	et	3	main
kana	doc_801781988530_item	2878543	et	4	main
seisab	doc_801781988530_item	2878553	et	3	main
kööginurgadiivan	doc_801781988530_item	2878555	et	3	main
kohal	doc_801781988530_item	2878559	et	4	main
nurgas	doc_801781988530_item	2878560	et	3	main
akna	doc_801781988530_item	2878561	et	3	main
väike	doc_801781988530_item	2878564	et	4	main
nurgadiivanis	doc_801781988530_item	2878566	et	3	main
ma	doc_801781988530_item	2878567	et	3	main
hojan	doc_801781988530_item	2878568	et	4	main
ja	doc_801781988530_item	2878579	et	3	main
vasakul	doc_801781988530_item	2878588	et	4	main
seinal	doc_801781988530_item	2878589	et	3	main
söögilaual	doc_801781988530_item	2878593	et	3	main
seisab	doc_801781988530_item	2878377	et	3	main
uksest	doc_801781988530_item	2878388	et	4	main
esimesel	doc_801781988530_item	2878398	et	3	main
sahtlis	doc_801781988530_item	2878399	et	3	main
seep	doc_801781988530_item	2878402	et	4	main
nuustikud	doc_801781988530_item	2878414	et	3	main
vastas	doc_801781988530_item	2878421	et	4	main
seisab	doc_801781988530_item	2878422	et	3	main
juures	doc_801781988530_item	2878428	et	4	main
seinal	doc_801781988530_item	2878433	et	3	main
suur	doc_801781988530_item	2878435	et	3	main
peegel	doc_801781988530_item	2878437	et	3	main
laeni	doc_801781988530_item	2878449	et	4	main
vannitoas	doc_801781988530_item	2878450	et	3	main
käterätikud	doc_801781988530_item	2878452	et	3	main
kuivatan	doc_801781988530_item	2878456	et	3	main
köök	doc_801781988530_item	2878470	et	3	main
ilus	doc_801781988530_item	2878481	et	4	main
toalill	doc_801781988530_item	2878482	et	3	main
akna	doc_801781988530_item	2878483	et	3	main
tüülkardin	doc_801781988530_item	2878487	et	4	main
ees	doc_801781988530_item	2878489	et	4	main
ribi	doc_801781988530_item	2878491	et	4	main
uksest	doc_801781988530_item	2878493	et	4	main
ääres	doc_801781988530_item	2878496	et	4	main
külmkapp	doc_801781988530_item	2878498	et	3	main
toiduained	doc_801781988530_item	2878502	et	3	main
seina	doc_801781988530_item	2878495	et	4	main
ma	doc_801781988530_item	2878500	et	3	main
kapsad	doc_801781988530_item	2878530	et	4	main
sibulat	doc_801781988530_item	2878534	et	3	main
salatid	doc_801781988530_item	2878536	et	3	main
kala	doc_801781988530_item	2878545	et	4	main
varenikut	doc_801781988530_item	2878547	et	4	main
edasi	doc_801781988530_item	2878550	et	3	main
seinal	doc_801781988530_item	2878551	et	3	main
juures	doc_801781988530_item	2878552	et	4	main
söögilaud	doc_801781988530_item	2878557	et	4	main
riipub	doc_801781988530_item	2878563	et	4	main
seinalamp	doc_801781988530_item	2878565	et	3	main
tortiga	doc_801781988530_item	2878572	et	4	main
ja	doc_801781988530_item	2878573	et	3	main
vormid	doc_801781988530_item	2878575	et	4	main
röster	doc_801781988530_item	2878576	et	3	main
nurgadiivani	doc_801781988530_item	2878582	et	4	main
seisab	doc_801781988530_item	2878584	et	3	main
riipub	doc_801781988530_item	2878590	et	4	main
teler	doc_801781988530_item	2878592	et	3	main
asub	doc_801781988530_item	2878601	et	3	main
köögis	doc_801781988530_item	2878604	et	3	main
hommikul	doc_801781988530_item	2878616	et	3	main
köögiga	doc_801781988530_item	2878621	et	3	main
peal	doc_801781988530_item	2878634	et	4	main
juures	doc_801781988530_item	2878641	et	4	main
põrandal	doc_801781988530_item	2878642	et	3	main
seisab	doc_801781988530_item	2878643	et	3	main
riiulid	doc_801781988530_item	2878649	et	3	main
sahtlis	doc_801781988530_item	2878652	et	3	main
palju	doc_801781988530_item	2878654	et	4	main
esemeid	doc_801781988530_item	2878655	et	3	main
siin	doc_801781988530_item	2878656	et	4	main
leivanuga	doc_801781988530_item	2878660	et	4	main
ja	doc_801781988530_item	2878661	et	3	main
noad	doc_801781988530_item	2878662	et	3	main
dessertluusikad	doc_801781988530_item	2878665	et	4	main
ja	doc_801781988530_item	2878666	et	3	main
hommikul	doc_801781988530_item	2878675	et	3	main
ma	doc_801781988530_item	2878676	et	3	main
keedan	doc_801781988530_item	2878677	et	3	main
kohvi	doc_801781988530_item	2878678	et	4	main
kapi	doc_801781988530_item	2878679	et	4	main
ääres	doc_801781988530_item	2878680	et	4	main
on	doc_801781988530_item	2878681	et	4	main
tühje	doc_801781988530_item	2878570	et	3	main
keksiga	doc_801781988530_item	2878574	et	4	main
kaks	doc_801781988530_item	2878580	et	3	main
paremal	doc_801781988530_item	2878598	et	4	main
valamu	doc_801781988530_item	2878603	et	4	main
ja	doc_801781988530_item	2878613	et	3	main
kartuliga	doc_801781988530_item	2878614	et	3	main
prügiämber	doc_801781988530_item	2878615	et	3	main
seina	doc_801781988530_item	2878626	et	4	main
kööki	doc_801781988530_item	2878632	et	4	main
ilus	doc_801781988530_item	2878636	et	4	main
on	doc_801781988530_item	2878653	et	4	main
supilusikad	doc_801781988530_item	2878663	et	3	main
teelusikad	doc_801781988530_item	2878664	et	3	main
sööma	doc_801781988530_item	2878687	et	4	main
pot	doc_801781988530_item	2878691	et	4	main
pann	doc_801781988530_item	2878694	et	3	main
pirukad	doc_801781988530_item	2878706	et	3	main
suur	doc_801781988530_item	2878721	et	3	main
köögiseinakapp	doc_801781988530_item	2878722	et	3	main
on	doc_801781988530_item	2878724	et	4	main
teisel	doc_801781988530_item	2878738	et	4	main
ja	doc_801781988530_item	2878744	et	3	main
koorekann	doc_801781988530_item	2878746	et	3	main
serviis	doc_801781988530_item	2878749	et	3	main
riiul	doc_801781988530_item	2878751	et	4	main
kohviveski	doc_801781988530_item	2878758	et	4	main
riiul	doc_801781988530_item	2878760	et	4	main
salatikausid	doc_801781988530_item	2878762	et	3	main
vaagnad	doc_801781988530_item	2878763	et	3	main
mõned	doc_801781988530_item	2878764	et	3	main
vaasid	doc_801781988530_item	2878765	et	3	main
ja	doc_801781988530_item	2878766	et	3	main
kannud	doc_801781988530_item	2878767	et	3	main
köögiseinakapi	doc_801781988530_item	2878768	et	3	main
paremal	doc_801781988530_item	2878777	et	4	main
seisab	doc_801781988530_item	2878781	et	3	main
kapis	doc_801781988530_item	2878783	et	3	main
panen	doc_801781988530_item	2878785	et	3	main
supitirin	doc_801781988530_item	2878789	et	3	main
vasakul	doc_801781988530_item	2878794	et	4	main
paremal	doc_801781988530_item	2878802	et	4	main
seinal	doc_801781988530_item	2878803	et	3	main
riipub	doc_801781988530_item	2878804	et	4	main
liha	doc_801781988530_item	2878823	et	4	main
üldmaitseaine	doc_801781988530_item	2878824	et	4	main
kuivpärm	doc_801781988530_item	2878825	et	3	main
kohviga	doc_801781988530_item	2878830	et	3	main
korteriga	doc_801781988530_item	2878846	et	3	main
olen	doc_801781988530_item	2878848	et	3	main
rahul	doc_801781988530_item	2878850	et	4	main
kõigi	doc_801781988530_item	2878853	et	4	main
mugavustega	doc_801781988530_item	2878854	et	4	main
korteris	doc_801781988530_item	2878855	et	3	main
minu	doc_801781988530_item	2878856	et	3	main
korter	doc_801781988530_item	2878857	et	3	main
soe	doc_801781988530_item	2878859	et	4	main
korteris	doc_801781988530_item	2878860	et	3	main
on	doc_801781988530_item	2878861	et	4	main
maja	doc_801781988531_item	2878872	et	4	main
kus	doc_801781988531_item	2878873	et	3	main
ma	doc_801781988531_item	2878874	et	3	main
elan	doc_801781988531_item	2878875	et	3	main
ma	doc_801781988531_item	2878876	et	3	main
elan	doc_801781988531_item	2878877	et	3	main
viiekorruselises	doc_801781988531_item	2878878	et	4	main
maja	doc_801781988531_item	2878882	et	4	main
roheline	doc_801781988531_item	2878885	et	4	main
y2k	doc_801781988531_item	2878889	et	4	main
viiekorruselised	doc_801781988531_item	2878924	et	4	main
kivimajad	doc_801781988531_item	2878925	et	4	main
paremal	doc_801781988531_item	2878927	et	4	main
selles	doc_801781988531_item	2878931	et	4	main
majas	doc_801781988531_item	2878932	et	3	main
esimesel	doc_801781988531_item	2878933	et	3	main
korrusel	doc_801781988531_item	2878934	et	3	main
asub	doc_801781988531_item	2878935	et	3	main
tegelevad	doc_801781988531_item	2878939	et	4	main
ja	doc_801781988531_item	2878940	et	3	main
ja	doc_801781988531_item	2878943	et	3	main
uus	doc_801781988531_item	2878953	et	3	main
köögi	doc_801781988530_item	2878602	et	3	main
valamu	doc_801781988530_item	2878605	et	4	main
viin	doc_801781988530_item	2878618	et	4	main
helesinine	doc_801781988530_item	2878627	et	4	main
tapeet	doc_801781988530_item	2878628	et	3	main
on	doc_801781988530_item	2878635	et	4	main
taevassinine	doc_801781988530_item	2878644	et	4	main
köögikapp	doc_801781988530_item	2878645	et	3	main
kapis	doc_801781988530_item	2878646	et	3	main
asuvad	doc_801781988530_item	2878647	et	4	main
ja	doc_801781988530_item	2878650	et	3	main
korgitser	doc_801781988530_item	2878658	et	3	main
avaja	doc_801781988530_item	2878659	et	4	main
kahvlid	doc_801781988530_item	2878667	et	3	main
elektripliit	doc_801781988530_item	2878682	et	3	main
kooli	doc_801781988530_item	2878684	et	4	main
ma	doc_801781988530_item	2878685	et	3	main
valmistan	doc_801781988530_item	2878686	et	3	main
on	doc_801781988530_item	2878690	et	4	main
ja	doc_801781988530_item	2878693	et	3	main
on	doc_801781988530_item	2878697	et	4	main
praeahi	doc_801781988530_item	2878698	et	3	main
koogid	doc_801781988530_item	2878703	et	4	main
pliitis	doc_801781988530_item	2878707	et	4	main
üks	doc_801781988530_item	2878709	et	3	main
ma	doc_801781988530_item	2878712	et	3	main
kapis	doc_801781988530_item	2878723	et	3	main
riiulid	doc_801781988530_item	2878726	et	3	main
riiul	doc_801781988530_item	2878728	et	4	main
on	doc_801781988530_item	2878729	et	4	main
supi	doc_801781988530_item	2878730	et	3	main
ja	doc_801781988530_item	2878731	et	3	main
riiul	doc_801781988530_item	2878739	et	4	main
seisab	doc_801781988530_item	2878740	et	3	main
alustassid	doc_801781988530_item	2878743	et	3	main
hakklihamasin	doc_801781988530_item	2878755	et	3	main
köögikombain	doc_801781988530_item	2878756	et	3	main
on	doc_801781988530_item	2878761	et	4	main
all	doc_801781988530_item	2878769	et	3	main
juures	doc_801781988530_item	2878779	et	4	main
põrandal	doc_801781988530_item	2878780	et	3	main
ma	doc_801781988530_item	2878784	et	3	main
palju	doc_801781988530_item	2878787	et	4	main
ja	doc_801781988530_item	2878791	et	3	main
elektrikann	doc_801781988530_item	2878671	et	3	main
ja	doc_801781988530_item	2878672	et	3	main
kohvimasin	doc_801781988530_item	2878673	et	3	main
igal	doc_801781988530_item	2878674	et	3	main
pliiti	doc_801781988530_item	2878688	et	4	main
peale	doc_801781988530_item	2878689	et	4	main
supiga	doc_801781988530_item	2878692	et	3	main
praega	doc_801781988530_item	2878695	et	3	main
mõnikord	doc_801781988530_item	2878699	et	3	main
armastan	doc_801781988530_item	2878701	et	3	main
on	doc_801781988530_item	2878720	et	4	main
pärast	doc_801781988530_item	2878683	et	4	main
küpsised	doc_801781988530_item	2878704	et	3	main
on	doc_801781988530_item	2878708	et	4	main
kast	doc_801781988530_item	2878710	et	3	main
panen	doc_801781988530_item	2878713	et	3	main
kandikud	doc_801781988530_item	2878716	et	3	main
pliitit	doc_801781988530_item	2878717	et	4	main
kohal	doc_801781988530_item	2878718	et	4	main
seinal	doc_801781988530_item	2878719	et	3	main
esimesel	doc_801781988530_item	2878727	et	3	main
prae	doc_801781988530_item	2878732	et	4	main
taldrikut	doc_801781988530_item	2878733	et	3	main
magustoidu	doc_801781988530_item	2878734	et	3	main
taldrikut	doc_801781988530_item	2878735	et	3	main
ja	doc_801781988530_item	2878736	et	3	main
kausid	doc_801781988530_item	2878737	et	3	main
klaasid	doc_801781988530_item	2878741	et	4	main
pitsid	doc_801781988530_item	2878747	et	3	main
mahlapress	doc_801781988530_item	2878754	et	3	main
riipub	doc_801781988530_item	2878770	et	4	main
teen	doc_801781988530_item	2878774	et	3	main
potid	doc_801781988530_item	2878788	et	4	main
riiv	doc_801781988530_item	2878790	et	3	main
uksest	doc_801781988530_item	2878793	et	4	main
riipuvad	doc_801781988530_item	2878796	et	4	main
köögikäterätikud	doc_801781988530_item	2878797	et	3	main
veel	doc_801781988530_item	2878805	et	4	main
üks	doc_801781988530_item	2878806	et	3	main
köögikapp	doc_801781988530_item	2878807	et	3	main
kapis	doc_801781988530_item	2878808	et	3	main
ma	doc_801781988530_item	2878809	et	3	main
hojan	doc_801781988530_item	2878810	et	4	main
küüslaugupipar	doc_801781988530_item	2878826	et	3	main
pizzajahu	doc_801781988530_item	2878827	et	4	main
ja	doc_801781988530_item	2878828	et	3	main
soola	doc_801781988530_item	2878831	et	4	main
kommid	doc_801781988530_item	2878832	et	3	main
suhkru	doc_801781988530_item	2878833	et	3	main
küpsised	doc_801781988530_item	2878835	et	3	main
on	doc_801781988530_item	2878837	et	4	main
igal	doc_801781988530_item	2878840	et	3	main
ma	doc_801781988530_item	2878847	et	3	main
soe	doc_801781988530_item	2878862	et	4	main
ja	doc_801781988530_item	2878863	et	3	main
külm	doc_801781988530_item	2878864	et	3	main
kaabeltelevisioon	doc_801781988530_item	2878867	et	4	main
mobiiltelefon	doc_801781988530_item	2878870	et	3	main
seisab	doc_801781988531_item	2878884	et	3	main
y2k	doc_801781988531_item	2878887	et	4	main
on	doc_801781988531_item	2878928	et	4	main
pood	doc_801781988531_item	2878936	et	4	main
kõrval	doc_801781988531_item	2878946	et	4	main
elan	doc_801781988531_item	2878970	et	3	main
viiskümmend	doc_801781988531_item	2878975	et	4	main
minu	doc_801781988531_item	2878977	et	3	main
meetri	doc_801781988531_item	2878987	et	3	main
on	doc_801781988531_item	2878991	et	4	main
hele	doc_801781988531_item	2878992	et	3	main
esikas	doc_801781988531_item	2879008	et	4	main
nurgas	doc_801781988531_item	2879009	et	3	main
väike	doc_801781988531_item	2879011	et	4	main
vastas	doc_801781988531_item	2879014	et	4	main
elutoa	doc_801781988531_item	2879017	et	3	main
vastas	doc_801781988531_item	2879019	et	4	main
ukse	doc_801781988531_item	2879023	et	3	main
tütretuba	doc_801781988531_item	2879031	et	4	main
korteris	doc_801781988531_item	2879032	et	3	main
ovalne	doc_801781988531_item	2879046	et	4	main
peegel	doc_801781988531_item	2879047	et	3	main
juures	doc_801781988531_item	2879049	et	4	main
on	doc_801781988531_item	2879051	et	4	main
lastetuba	doc_801781988531_item	2879059	et	4	main
on	doc_801781988531_item	2879060	et	4	main
juures	doc_801781988531_item	2879067	et	4	main
seisab	doc_801781988531_item	2879068	et	3	main
ainult	doc_801781988531_item	2879069	et	4	main
kušett	doc_801781988531_item	2879070	et	2	main
kõrval	doc_801781988531_item	2879072	et	4	main
paremal	doc_801781988531_item	2879073	et	4	main
uksest	doc_801781988531_item	2879078	et	4	main
juures	doc_801781988531_item	2879081	et	4	main
pliitis	doc_801781988530_item	2878696	et	4	main
ma	doc_801781988530_item	2878700	et	3	main
küpsetan	doc_801781988530_item	2878702	et	3	main
ja	doc_801781988530_item	2878705	et	3	main
kastis	doc_801781988530_item	2878711	et	4	main
vaagnad	doc_801781988530_item	2878714	et	3	main
ja	doc_801781988530_item	2878715	et	3	main
neli	doc_801781988530_item	2878725	et	3	main
bokaalid	doc_801781988530_item	2878742	et	4	main
tassid	doc_801781988530_item	2878745	et	4	main
ja	doc_801781988530_item	2878748	et	3	main
kolmandal	doc_801781988530_item	2878750	et	3	main
asub	doc_801781988530_item	2878752	et	3	main
ja	doc_801781988530_item	2878757	et	3	main
mikrolaineahi	doc_801781988530_item	2878771	et	3	main
ma	doc_801781988530_item	2878773	et	3	main
kuumad	doc_801781988530_item	2878775	et	4	main
pannid	doc_801781988530_item	2878786	et	3	main
sõel	doc_801781988530_item	2878792	et	3	main
seinal	doc_801781988530_item	2878795	et	3	main
ja	doc_801781988530_item	2878798	et	3	main
pajalapid	doc_801781988530_item	2878799	et	3	main
valamu	doc_801781988530_item	2878800	et	4	main
palju	doc_801781988530_item	2878811	et	4	main
esemeid	doc_801781988530_item	2878812	et	3	main
siin	doc_801781988530_item	2878813	et	4	main
on	doc_801781988530_item	2878814	et	4	main
maitsestatud	doc_801781988530_item	2878815	et	4	main
must	doc_801781988530_item	2878816	et	4	main
tee	doc_801781988530_item	2878817	et	4	main
vanilliinsuhkur	doc_801781988530_item	2878818	et	4	main
tuhksuhkur	doc_801781988530_item	2878819	et	4	main
kakaojuomajuhe	doc_801781988530_item	2878820	et	4	main
kaneel	doc_801781988530_item	2878822	et	3	main
purk	doc_801781988530_item	2878829	et	3	main
ja	doc_801781988530_item	2878834	et	3	main
kaetud	doc_801781988530_item	2878838	et	4	main
linoleumiga	doc_801781988530_item	2878839	et	3	main
hommikul	doc_801781988530_item	2878841	et	3	main
pühin	doc_801781988530_item	2878843	et	3	main
köögipõrandat	doc_801781988530_item	2878845	et	3	main
ma	doc_801781988530_item	2878851	et	3	main
on	doc_801781988530_item	2878858	et	4	main
keskküte	doc_801781988530_item	2878866	et	3	main
on	doc_801781988530_item	2878869	et	4	main
essee	doc_801781988531_item	2878871	et	4	main
kauplus	doc_801781988531_item	2878886	et	3	main
taga	doc_801781988531_item	2878922	et	4	main
viiekorruseline	doc_801781988531_item	2878929	et	4	main
aknaid	doc_801781988531_item	2878942	et	3	main
kaks	doc_801781988531_item	2878949	et	3	main
poodid	doc_801781988531_item	2878951	et	4	main
kauplus	doc_801781988531_item	2878954	et	3	main
majas	doc_801781988531_item	2878971	et	3	main
on	doc_801781988531_item	2878996	et	4	main
wc	doc_801781988531_item	2878997	et	4	main
edasi	doc_801781988531_item	2878998	et	3	main
on	doc_801781988531_item	2878999	et	4	main
vannituba	doc_801781988531_item	2879000	et	4	main
köök	doc_801781988531_item	2879005	et	3	main
ees	doc_801781988531_item	2879007	et	4	main
on	doc_801781988531_item	2879015	et	4	main
magamistuba	doc_801781988531_item	2879021	et	4	main
magamistoa	doc_801781988531_item	2879022	et	3	main
paremal	doc_801781988531_item	2879030	et	4	main
peegli	doc_801781988531_item	2879048	et	3	main
pruuni	doc_801781988531_item	2879056	et	4	main
kirju	doc_801781988531_item	2879057	et	4	main
linoleum	doc_801781988531_item	2879058	et	3	main
seinal	doc_801781988531_item	2879074	et	3	main
on	doc_801781988531_item	2879075	et	4	main
mikser	doc_801781988530_item	2878753	et	3	main
neljandal	doc_801781988530_item	2878759	et	3	main
siis	doc_801781988530_item	2878772	et	3	main
võileibad	doc_801781988530_item	2878776	et	4	main
elektripliiti	doc_801781988530_item	2878778	et	4	main
köögikapp	doc_801781988530_item	2878782	et	3	main
kohal	doc_801781988530_item	2878801	et	4	main
äädikas	doc_801781988530_item	2878821	et	4	main
köögipõrand	doc_801781988530_item	2878836	et	3	main
ma	doc_801781988530_item	2878842	et	3	main
harjaga	doc_801781988530_item	2878844	et	3	main
väga	doc_801781988530_item	2878849	et	3	main
elan	doc_801781988530_item	2878852	et	3	main
vesi	doc_801781988530_item	2878865	et	4	main
mul	doc_801781988530_item	2878868	et	3	main
kivimajas	doc_801781988531_item	2878879	et	4	main
kolmandal	doc_801781988531_item	2878880	et	3	main
korrusel	doc_801781988531_item	2878881	et	3	main
ees	doc_801781988531_item	2878883	et	4	main
kaupluse	doc_801781988531_item	2878888	et	3	main
tee	doc_801781988531_item	2878892	et	4	main
tee	doc_801781988531_item	2878893	et	4	main
taga	doc_801781988531_item	2878894	et	4	main
seisavad	doc_801781988531_item	2878895	et	3	main
üheksakorruselise	doc_801781988531_item	2878896	et	4	main
maja	doc_801781988531_item	2878897	et	4	main
kaks	doc_801781988531_item	2878898	et	3	main
lasteajad	doc_801781988531_item	2878899	et	3	main
gümnaasium	doc_801781988531_item	2878901	et	3	main
soldino	doc_801781988531_item	2878900	et	4	main
kulturimaja	doc_801781988531_item	2878902	et	4	main
ženeva	doc_801781988531_item	2878903	et	2	main
ja	doc_801781988531_item	2878904	et	3	main
ujula	doc_801781988531_item	2878905	et	4	main
maja	doc_801781988531_item	2878906	et	4	main
ees	doc_801781988531_item	2878907	et	4	main
kasvavad	doc_801781988531_item	2878908	et	4	main
puud	doc_801781988531_item	2878909	et	4	main
tammepuud	doc_801781988531_item	2878910	et	4	main
ja	doc_801781988531_item	2878911	et	3	main
pihlapuud	doc_801781988531_item	2878912	et	4	main
maja	doc_801781988531_item	2878913	et	4	main
taga	doc_801781988531_item	2878914	et	4	main
kasvavad	doc_801781988531_item	2878915	et	4	main
pärnapuud	doc_801781988531_item	2878916	et	4	main
ja	doc_801781988531_item	2878917	et	3	main
veel	doc_801781988531_item	2878918	et	4	main
kaštaanipuud	doc_801781988531_item	2878919	et	2	main
edasi	doc_801781988531_item	2878920	et	3	main
ees	doc_801781988531_item	2878890	et	4	main
asub	doc_801781988531_item	2878891	et	3	main
maja	doc_801781988531_item	2878921	et	4	main
asuvad	doc_801781988531_item	2878923	et	4	main
majast	doc_801781988531_item	2878926	et	4	main
maja	doc_801781988531_item	2878930	et	4	main
orion	doc_801781988531_item	2878937	et	4	main
siin	doc_801781988531_item	2878938	et	4	main
müüvad	doc_801781988531_item	2878941	et	4	main
puuukseid	doc_801781988531_item	2878944	et	4	main
maja	doc_801781988531_item	2878945	et	4	main
väikeses	doc_801781988531_item	2878957	et	4	main
müüvad	doc_801781988531_item	2878959	et	4	main
toiduained	doc_801781988531_item	2878960	et	3	main
teises	doc_801781988531_item	2878961	et	4	main
poodis	doc_801781988531_item	2878962	et	4	main
müüvad	doc_801781988531_item	2878963	et	4	main
mööblid	doc_801781988531_item	2878964	et	3	main
maxima	doc_801781988531_item	2878965	et	4	main
taga	doc_801781988531_item	2878966	et	4	main
vasakul	doc_801781988531_item	2878947	et	4	main
lasteaed	doc_801781988531_item	2878948	et	3	main
väikesed	doc_801781988531_item	2878950	et	4	main
ja	doc_801781988531_item	2878952	et	3	main
maxima	doc_801781988531_item	2878955	et	4	main
neli	doc_801781988531_item	2878973	et	3	main
on	doc_801781988531_item	2878985	et	4	main
viie	doc_801781988531_item	2878986	et	3	main
pikkune	doc_801781988531_item	2878988	et	4	main
esikus	doc_801781988531_item	2878989	et	3	main
seinadel	doc_801781988531_item	2878990	et	3	main
edasi	doc_801781988531_item	2879003	et	3	main
suur	doc_801781988531_item	2879016	et	3	main
kohal	doc_801781988531_item	2879024	et	4	main
seinal	doc_801781988531_item	2879025	et	3	main
ripub	doc_801781988531_item	2879026	et	3	main
pruuni	doc_801781988531_item	2879027	et	4	main
kell	doc_801781988531_item	2879028	et	3	main
seinal	doc_801781988531_item	2879050	et	3	main
pikk	doc_801781988531_item	2879061	et	4	main
ja	doc_801781988531_item	2879062	et	3	main
seina	doc_801781988531_item	2879066	et	4	main
paremal	doc_801781988531_item	2879079	et	4	main
sinine	doc_801781988531_item	2879101	et	4	main
tüllkardin	doc_801781988531_item	2879102	et	3	main
elutuba	doc_801781988531_item	2879106	et	4	main
on	doc_801781988531_item	2879107	et	4	main
suur	doc_801781988531_item	2879108	et	3	main
ja	doc_801781988531_item	2879109	et	3	main
päikesepaisteline	doc_801781988531_item	2879110	et	4	main
uksest	doc_801781988531_item	2879111	et	4	main
vasakul	doc_801781988531_item	2879112	et	4	main
on	doc_801781988531_item	2879113	et	4	main
keskmine	doc_801781988531_item	2879114	et	3	main
punane	doc_801781988531_item	2879115	et	4	main
diivan	doc_801781988531_item	2879116	et	3	main
diivani	doc_801781988531_item	2879117	et	4	main
ees	doc_801781988531_item	2879118	et	4	main
on	doc_801781988531_item	2879119	et	4	main
diivanilaud	doc_801781988531_item	2879120	et	4	main
diivani	doc_801781988531_item	2879126	et	4	main
vastas	doc_801781988531_item	2879127	et	4	main
palju	doc_801781988531_item	2879133	et	4	main
valge	doc_801781988531_item	2879140	et	4	main
rullikardin	doc_801781988531_item	2879141	et	3	main
seisab	doc_801781988531_item	2879148	et	3	main
seisab	doc_801781988531_item	2879154	et	3	main
magamistuba	doc_801781988531_item	2879167	et	4	main
keskmine	doc_801781988531_item	2879169	et	3	main
valge	doc_801781988531_item	2879173	et	4	main
väike	doc_801781988531_item	2879180	et	4	main
kaks	doc_801781988531_item	2879188	et	3	main
öökappi	doc_801781988531_item	2879189	et	4	main
voodi	doc_801781988531_item	2879190	et	4	main
on	doc_801781988531_item	2879194	et	4	main
kummutit	doc_801781988531_item	2879196	et	3	main
öökapp	doc_801781988531_item	2879198	et	3	main
ees	doc_801781988531_item	2879200	et	4	main
ja	doc_801781988531_item	2879204	et	3	main
halle	doc_801781988531_item	2879205	et	4	main
seisab	doc_801781988531_item	2879218	et	3	main
gaasipliit	doc_801781988531_item	2879219	et	3	main
gaasipliitis	doc_801781988531_item	2879220	et	4	main
esimeses	doc_801781988531_item	2878956	et	3	main
poodis	doc_801781988531_item	2878958	et	4	main
seisab	doc_801781988531_item	2878967	et	3	main
post	doc_801781988531_item	2878968	et	3	main
ma	doc_801781988531_item	2878969	et	3	main
üks	doc_801781988531_item	2878976	et	3	main
ei	doc_801781988531_item	2878979	et	4	main
esik	doc_801781988531_item	2878982	et	3	main
aga	doc_801781988531_item	2878983	et	3	main
ta	doc_801781988531_item	2878984	et	4	main
tapeet	doc_801781988531_item	2878993	et	3	main
on	doc_801781988531_item	2879004	et	4	main
välisukse	doc_801781988531_item	2879029	et	4	main
kõik	doc_801781988531_item	2879033	et	4	main
uksed	doc_801781988531_item	2879034	et	3	main
ja	doc_801781988531_item	2879035	et	3	main
riidekappi	doc_801781988531_item	2879036	et	4	main
uks	doc_801781988531_item	2879037	et	3	main
on	doc_801781988531_item	2879038	et	4	main
valged	doc_801781988531_item	2879039	et	3	main
esikus	doc_801781988531_item	2879040	et	3	main
uste	doc_801781988531_item	2879041	et	3	main
vahel	doc_801781988531_item	2879042	et	4	main
seinal	doc_801781988531_item	2879043	et	3	main
ripub	doc_801781988531_item	2879044	et	3	main
suur	doc_801781988531_item	2879045	et	3	main
kaks	doc_801781988531_item	2879052	et	3	main
seinalampi	doc_801781988531_item	2879053	et	4	main
põrandal	doc_801781988531_item	2879054	et	3	main
on	doc_801781988531_item	2879055	et	4	main
kitsas	doc_801781988531_item	2879063	et	4	main
uksest	doc_801781988531_item	2879064	et	4	main
vasakul	doc_801781988531_item	2879065	et	4	main
ukse	doc_801781988531_item	2879071	et	3	main
seina	doc_801781988531_item	2879080	et	4	main
ja	doc_801781988531_item	2879091	et	3	main
kohal	doc_801781988531_item	2879094	et	4	main
riiul	doc_801781988531_item	2879097	et	4	main
on	doc_801781988531_item	2879122	et	4	main
suur	doc_801781988531_item	2879123	et	3	main
punasekirju	doc_801781988531_item	2879124	et	4	main
vaip	doc_801781988531_item	2879125	et	3	main
on	doc_801781988531_item	2879132	et	4	main
on	doc_801781988531_item	2879137	et	4	main
tüllkardin	doc_801781988531_item	2879138	et	3	main
ja	doc_801781988531_item	2879139	et	3	main
muusika	doc_801781988531_item	2879145	et	4	main
aparatuur	doc_801781988531_item	2879146	et	3	main
aparatuur	doc_801781988531_item	2879147	et	3	main
seina	doc_801781988531_item	2879152	et	4	main
sektsionikapp	doc_801781988531_item	2879155	et	4	main
on	doc_801781988531_item	2879157	et	4	main
seisab	doc_801781988531_item	2879172	et	3	main
riidekapp	doc_801781988531_item	2879174	et	3	main
nagi	doc_801781988531_item	2879181	et	4	main
külgkardinad	doc_801781988531_item	2879206	et	4	main
külmkapp	doc_801781988531_item	2879215	et	3	main
külgkardinad	doc_801781988531_item	2879237	et	4	main
akna	doc_801781988531_item	2879238	et	3	main
söögikapides	doc_801781988531_item	2879242	et	4	main
kohal	doc_801781988531_item	2879252	et	4	main
magustoidutaldrikud	doc_801781988531_item	2879257	et	3	main
praetaldrikud	doc_801781988531_item	2879259	et	3	main
klassid	doc_801781988531_item	2879260	et	3	main
valamu	doc_801781988531_item	2879262	et	4	main
all	doc_801781988531_item	2879263	et	3	main
valamu	doc_801781988531_item	2879269	et	4	main
on	doc_801781988531_item	2879271	et	4	main
on	doc_801781988531_item	2879291	et	4	main
ja	doc_801781988531_item	2879294	et	3	main
all	doc_801781988531_item	2879298	et	3	main
number	doc_801781988531_item	2878972	et	3	main
korteris	doc_801781988531_item	2878974	et	3	main
korteris	doc_801781988531_item	2878978	et	3	main
ole	doc_801781988531_item	2878980	et	4	main
lai	doc_801781988531_item	2878981	et	3	main
välisuksest	doc_801781988531_item	2878994	et	4	main
vasakul	doc_801781988531_item	2878995	et	4	main
ja	doc_801781988531_item	2879001	et	3	main
veel	doc_801781988531_item	2879002	et	4	main
köögi	doc_801781988531_item	2879006	et	3	main
on	doc_801781988531_item	2879010	et	4	main
riidekapp	doc_801781988531_item	2879012	et	3	main
riidekapi	doc_801781988531_item	2879013	et	3	main
välisukse	doc_801781988531_item	2879018	et	4	main
on	doc_801781988531_item	2879020	et	4	main
väike	doc_801781988531_item	2879076	et	4	main
nagi	doc_801781988531_item	2879077	et	4	main
seisab	doc_801781988531_item	2879082	et	3	main
riidekapp	doc_801781988531_item	2879083	et	3	main
ja	doc_801781988531_item	2879086	et	3	main
kirjutuslaual	doc_801781988531_item	2879088	et	3	main
on	doc_801781988531_item	2879089	et	4	main
arvut	doc_801781988531_item	2879090	et	4	main
rulikardin	doc_801781988531_item	2879105	et	4	main
lilli	doc_801781988531_item	2879134	et	4	main
akna	doc_801781988531_item	2879135	et	3	main
akna	doc_801781988531_item	2879142	et	3	main
ees	doc_801781988531_item	2879143	et	4	main
paremal	doc_801781988531_item	2879151	et	4	main
teller	doc_801781988531_item	2879164	et	3	main
telleririiulil	doc_801781988531_item	2879166	et	4	main
vastas	doc_801781988531_item	2879171	et	4	main
ukse	doc_801781988531_item	2879175	et	3	main
kõrval	doc_801781988531_item	2879176	et	4	main
on	doc_801781988531_item	2879179	et	4	main
riidekapi	doc_801781988531_item	2879182	et	3	main
kõrval	doc_801781988531_item	2879183	et	4	main
vastas	doc_801781988531_item	2879191	et	4	main
on	doc_801781988531_item	2879208	et	4	main
väike	doc_801781988531_item	2879209	et	4	main
ukse	doc_801781988531_item	2879210	et	3	main
suur	doc_801781988531_item	2879213	et	3	main
kõrval	doc_801781988531_item	2879225	et	4	main
vastas	doc_801781988531_item	2879229	et	4	main
on	doc_801781988531_item	2879230	et	4	main
ja	doc_801781988531_item	2879232	et	3	main
aken	doc_801781988531_item	2879233	et	3	main
akna	doc_801781988531_item	2879234	et	3	main
on	doc_801781988531_item	2879243	et	4	main
ja	doc_801781988531_item	2879245	et	3	main
valamu	doc_801781988531_item	2879247	et	4	main
asub	doc_801781988531_item	2879248	et	3	main
paremas	doc_801781988531_item	2879249	et	4	main
nurgas	doc_801781988531_item	2879250	et	3	main
supitaldrikud	doc_801781988531_item	2879258	et	3	main
tassid	doc_801781988531_item	2879261	et	4	main
ja	doc_801781988531_item	2879267	et	3	main
sahtlis	doc_801781988531_item	2879273	et	3	main
lusikad	doc_801781988531_item	2879276	et	3	main
on	doc_801781988531_item	2879281	et	4	main
köögikapil	doc_801781988531_item	2879290	et	3	main
mikrolaineahi	doc_801781988531_item	2879292	et	3	main
mahlapress	doc_801781988531_item	2879295	et	3	main
mõõturi	doc_801781988531_item	2879297	et	4	main
kohal	doc_801781988531_item	2879303	et	4	main
on	doc_801781988532_item	2879317	et	4	main
ivanova	doc_801781988532_item	2879321	et	4	main
elan	doc_801781988532_item	2879323	et	3	main
vabariigis	doc_801781988532_item	2879325	et	3	main
linnas	doc_801781988532_item	2879330	et	4	main
elan	doc_801781988532_item	2879338	et	3	main
korrusel	doc_801781988532_item	2879342	et	3	main
ümbruses	doc_801781988532_item	2879355	et	3	main
ja	doc_801781988532_item	2879362	et	3	main
ees	doc_801781988532_item	2879365	et	4	main
on	doc_801781988532_item	2879372	et	4	main
palju	doc_801781988532_item	2879373	et	4	main
suur	doc_801781988532_item	2879374	et	3	main
on	doc_801781988532_item	2879380	et	4	main
meie	doc_801781988532_item	2879384	et	4	main
majast	doc_801781988532_item	2879385	et	4	main
pood	doc_801781988532_item	2879394	et	4	main
uus	doc_801781988532_item	2879395	et	3	main
suur	doc_801781988532_item	2879396	et	3	main
apteek	doc_801781988532_item	2879402	et	3	main
ees	doc_801781988532_item	2879404	et	4	main
gümnaasium	doc_801781988532_item	2879421	et	3	main
astri	doc_801781988532_item	2879423	et	3	main
kauplus	doc_801781988532_item	2879425	et	3	main
turg	doc_801781988532_item	2879426	et	3	main
ja	doc_801781988532_item	2879427	et	3	main
bensiinijaam	doc_801781988532_item	2879429	et	3	main
bussipeatused	doc_801781988532_item	2879439	et	4	main
on	doc_801781988532_item	2879448	et	4	main
alati	doc_801781988532_item	2879449	et	4	main
majas	doc_801781988532_item	2879451	et	3	main
ma	doc_801781988532_item	2879462	et	3	main
kirjutuslaud	doc_801781988531_item	2879085	et	4	main
laua	doc_801781988531_item	2879093	et	3	main
seinal	doc_801781988531_item	2879095	et	3	main
on	doc_801781988531_item	2879096	et	4	main
ees	doc_801781988531_item	2879099	et	4	main
sektsioonkapp	doc_801781988531_item	2879084	et	4	main
tool	doc_801781988531_item	2879087	et	3	main
priinter	doc_801781988531_item	2879092	et	4	main
akna	doc_801781988531_item	2879098	et	3	main
on	doc_801781988531_item	2879100	et	4	main
ja	doc_801781988531_item	2879103	et	3	main
taevasinine	doc_801781988531_item	2879104	et	4	main
põrandal	doc_801781988531_item	2879121	et	3	main
on	doc_801781988531_item	2879128	et	4	main
suur	doc_801781988531_item	2879129	et	3	main
aken	doc_801781988531_item	2879130	et	3	main
aknalaual	doc_801781988531_item	2879131	et	3	main
ees	doc_801781988531_item	2879136	et	4	main
on	doc_801781988531_item	2879144	et	4	main
muusikariiulil	doc_801781988531_item	2879149	et	3	main
uksest	doc_801781988531_item	2879150	et	4	main
juures	doc_801781988531_item	2879153	et	4	main
sektsionkapis	doc_801781988531_item	2879156	et	4	main
raamatud	doc_801781988531_item	2879158	et	4	main
ja	doc_801781988531_item	2879159	et	3	main
nõud	doc_801781988531_item	2879160	et	3	main
nurgas	doc_801781988531_item	2879161	et	3	main
ukse	doc_801781988531_item	2879170	et	3	main
paremal	doc_801781988531_item	2879177	et	4	main
seinal	doc_801781988531_item	2879178	et	3	main
seina	doc_801781988531_item	2879192	et	4	main
akna	doc_801781988531_item	2879199	et	3	main
on	doc_801781988531_item	2879201	et	4	main
valge	doc_801781988531_item	2879202	et	4	main
tüllkardin	doc_801781988531_item	2879203	et	3	main
vastas	doc_801781988531_item	2879211	et	4	main
seisab	doc_801781988531_item	2879212	et	3	main
valge	doc_801781988531_item	2879214	et	4	main
uksest	doc_801781988531_item	2879216	et	4	main
vasakul	doc_801781988531_item	2879217	et	4	main
gaasipliiti	doc_801781988531_item	2879224	et	4	main
on	doc_801781988531_item	2879226	et	4	main
gaasimõõtur	doc_801781988531_item	2879227	et	3	main
gaasipliiti	doc_801781988531_item	2879228	et	4	main
söögilaud	doc_801781988531_item	2879231	et	4	main
paremal	doc_801781988531_item	2879239	et	4	main
seisab	doc_801781988531_item	2879240	et	3	main
söögikapid	doc_801781988531_item	2879241	et	3	main
valamu	doc_801781988531_item	2879251	et	4	main
nõudekapis	doc_801781988531_item	2879255	et	3	main
veesifilter	doc_801781988531_item	2879268	et	4	main
sahtel	doc_801781988531_item	2879272	et	3	main
noad	doc_801781988531_item	2879275	et	3	main
all	doc_801781988531_item	2879279	et	3	main
seisab	doc_801781988531_item	2879299	et	3	main
on	doc_801781988531_item	2879305	et	4	main
kombain	doc_801781988531_item	2879306	et	3	main
ja	doc_801781988531_item	2879307	et	3	main
on	doc_801781988531_item	2879311	et	4	main
neli	doc_801781988531_item	2879312	et	3	main
on	doc_801781988532_item	2879320	et	4	main
ma	doc_801781988532_item	2879322	et	3	main
maakonnas	doc_801781988532_item	2879328	et	4	main
maja	doc_801781988532_item	2879332	et	4	main
ma	doc_801781988532_item	2879337	et	3	main
majas	doc_801781988532_item	2879340	et	3	main
neljandal	doc_801781988532_item	2879341	et	3	main
42	doc_801781988532_item	2879350	et	2	main
meie	doc_801781988532_item	2879353	et	4	main
puud	doc_801781988532_item	2879361	et	4	main
meie	doc_801781988532_item	2879369	et	4	main
majast	doc_801781988532_item	2879376	et	4	main
palju	doc_801781988532_item	2879381	et	4	main
väike	doc_801781988532_item	2879389	et	4	main
toidupood	doc_801781988532_item	2879390	et	3	main
ja	doc_801781988532_item	2879391	et	3	main
väike	doc_801781988532_item	2879392	et	4	main
tööstuskaupade	doc_801781988532_item	2879393	et	3	main
post	doc_801781988532_item	2879399	et	3	main
väike	doc_801781988532_item	2879401	et	4	main
kaubakeskus	doc_801781988532_item	2879422	et	3	main
säästu	doc_801781988532_item	2879424	et	4	main
palju	doc_801781988532_item	2879438	et	4	main
meie	doc_801781988532_item	2879440	et	4	main
trepikoda	doc_801781988532_item	2879444	et	4	main
minu	doc_801781988532_item	2879445	et	3	main
ei	doc_801781988532_item	2879452	et	4	main
on	doc_801781988531_item	2879162	et	4	main
teller	doc_801781988531_item	2879163	et	3	main
seisab	doc_801781988531_item	2879165	et	3	main
on	doc_801781988531_item	2879168	et	4	main
on	doc_801781988531_item	2879184	et	4	main
lai	doc_801781988531_item	2879185	et	3	main
voodi	doc_801781988531_item	2879186	et	4	main
ja	doc_801781988531_item	2879187	et	3	main
juures	doc_801781988531_item	2879193	et	4	main
kaks	doc_801781988531_item	2879195	et	3	main
ja	doc_801781988531_item	2879197	et	3	main
köök	doc_801781988531_item	2879207	et	3	main
on	doc_801781988531_item	2879221	et	4	main
kaks	doc_801781988531_item	2879222	et	3	main
panni	doc_801781988531_item	2879223	et	4	main
ees	doc_801781988531_item	2879235	et	4	main
on	doc_801781988531_item	2879236	et	4	main
nõud	doc_801781988531_item	2879244	et	3	main
toiduained	doc_801781988531_item	2879246	et	3	main
on	doc_801781988531_item	2879253	et	4	main
nõudekapp	doc_801781988531_item	2879254	et	3	main
on	doc_801781988531_item	2879256	et	4	main
on	doc_801781988531_item	2879264	et	4	main
ämber	doc_801781988531_item	2879265	et	3	main
kartuliga	doc_801781988531_item	2879266	et	3	main
ida	doc_801781988532_item	2879326	et	4	main
kõrval	doc_801781988531_item	2879270	et	4	main
on	doc_801781988531_item	2879274	et	4	main
niitnuutlid	doc_801781988531_item	2879289	et	4	main
elektrikann	doc_801781988531_item	2879293	et	3	main
gaasi	doc_801781988531_item	2879296	et	4	main
ämber	doc_801781988531_item	2879301	et	3	main
tooli	doc_801781988531_item	2879313	et	4	main
essee	doc_801781988532_item	2879314	et	4	main
minu	doc_801781988532_item	2879315	et	3	main
nimi	doc_801781988532_item	2879316	et	3	main
narva	doc_801781988532_item	2879329	et	4	main
asub	doc_801781988532_item	2879333	et	3	main
kesklinnas	doc_801781988532_item	2879334	et	4	main
uuel	doc_801781988532_item	2879335	et	3	main
on	doc_801781988532_item	2879349	et	4	main
kaks	doc_801781988532_item	2879352	et	3	main
on	doc_801781988532_item	2879356	et	4	main
rohelust	doc_801781988532_item	2879358	et	4	main
maja	doc_801781988532_item	2879370	et	4	main
taga	doc_801781988532_item	2879371	et	4	main
paremal	doc_801781988532_item	2879377	et	4	main
ja	doc_801781988532_item	2879378	et	3	main
taga	doc_801781988532_item	2879379	et	4	main
viiekorrulised	doc_801781988532_item	2879382	et	4	main
elumajad	doc_801781988532_item	2879383	et	3	main
maxima	doc_801781988532_item	2879398	et	4	main
ja	doc_801781988532_item	2879400	et	3	main
maja	doc_801781988532_item	2879403	et	4	main
on	doc_801781988532_item	2879405	et	4	main
kahvlid	doc_801781988531_item	2879277	et	3	main
sahtle	doc_801781988531_item	2879278	et	4	main
köögikapis	doc_801781988531_item	2879280	et	3	main
potid	doc_801781988531_item	2879282	et	4	main
edasi	doc_801781988531_item	2879283	et	3	main
köögikapis	doc_801781988531_item	2879284	et	3	main
on	doc_801781988531_item	2879285	et	4	main
tangud	doc_801781988531_item	2879286	et	3	main
makaronid	doc_801781988531_item	2879287	et	3	main
ja	doc_801781988531_item	2879288	et	3	main
prügi	doc_801781988531_item	2879300	et	4	main
mikrolaineahi	doc_801781988531_item	2879302	et	3	main
köögikapis	doc_801781988531_item	2879304	et	3	main
mikser	doc_801781988531_item	2879308	et	3	main
köögilaua	doc_801781988531_item	2879309	et	3	main
juures	doc_801781988531_item	2879310	et	4	main
leena	doc_801781988532_item	2879318	et	3	main
perekonnanimi	doc_801781988532_item	2879319	et	3	main
eesti	doc_801781988532_item	2879324	et	4	main
viru	doc_801781988532_item	2879327	et	4	main
meie	doc_801781988532_item	2879331	et	4	main
tänaval	doc_801781988532_item	2879336	et	4	main
viiekorruselises	doc_801781988532_item	2879339	et	4	main
maja	doc_801781988532_item	2879343	et	4	main
on	doc_801781988532_item	2879344	et	4	main
number	doc_801781988532_item	2879345	et	3	main
7	doc_801781988532_item	2879346	et	2	main
seitse	doc_801781988532_item	2879347	et	3	main
korter	doc_801781988532_item	2879348	et	3	main
nelikümmend	doc_801781988532_item	2879351	et	4	main
maja	doc_801781988532_item	2879354	et	4	main
põõsad	doc_801781988532_item	2879363	et	3	main
puud	doc_801781988532_item	2879375	et	4	main
vasakul	doc_801781988532_item	2879386	et	4	main
kauplus	doc_801781988532_item	2879397	et	3	main
alkohooli	doc_801781988532_item	2879407	et	3	main
kauplus	doc_801781988532_item	2879408	et	3	main
kaks	doc_801781988532_item	2879409	et	3	main
lasteaeda	doc_801781988532_item	2879410	et	4	main
baar	doc_801781988532_item	2879411	et	3	main
ujula	doc_801781988532_item	2879412	et	4	main
suur	doc_801781988532_item	2879413	et	3	main
üheksakorruseline	doc_801781988532_item	2879414	et	4	main
maja	doc_801781988532_item	2879415	et	4	main
meie	doc_801781988532_item	2879416	et	4	main
maja	doc_801781988532_item	2879417	et	4	main
lähedal	doc_801781988532_item	2879418	et	4	main
asuvad	doc_801781988532_item	2879419	et	4	main
soldino	doc_801781988532_item	2879420	et	4	main
tööstuskauplus	doc_801781988532_item	2879428	et	3	main
statoil	doc_801781988532_item	2879430	et	4	main
mc	doc_801781988532_item	2879431	et	4	main
hansapanga	doc_801781988532_item	2879436	et	3	main
kivimajas	doc_801781988532_item	2879441	et	4	main
trepikodas	doc_801781988532_item	2879446	et	4	main
trepp	doc_801781988532_item	2879447	et	3	main
puhas	doc_801781988532_item	2879450	et	3	main
on	doc_801781988532_item	2879458	et	4	main
3	doc_801781988532_item	2879459	et	2	main
kolm	doc_801781988532_item	2879460	et	3	main
kolmetoalises	doc_801781988532_item	2879464	et	4	main
korteris	doc_801781988532_item	2879465	et	3	main
kõigi	doc_801781988532_item	2879466	et	4	main
elutuba	doc_801781988532_item	2879477	et	4	main
ja	doc_801781988532_item	2879483	et	3	main
korter	doc_801781988532_item	2879486	et	3	main
erastatud	doc_801781988532_item	2879488	et	4	main
palju	doc_801781988532_item	2879357	et	4	main
kasvavad	doc_801781988532_item	2879359	et	4	main
erinevad	doc_801781988532_item	2879360	et	4	main
maja	doc_801781988532_item	2879364	et	4	main
on	doc_801781988532_item	2879366	et	4	main
ilus	doc_801781988532_item	2879367	et	4	main
muru	doc_801781988532_item	2879368	et	4	main
on	doc_801781988532_item	2879387	et	4	main
lasteaed	doc_801781988532_item	2879388	et	3	main
väike	doc_801781988532_item	2879406	et	4	main
donalds	doc_801781988532_item	2879432	et	4	main
tööstuskauplus	doc_801781988532_item	2879433	et	3	main
ühispank	doc_801781988532_item	2879434	et	3	main
ja	doc_801781988532_item	2879435	et	3	main
kontor	doc_801781988532_item	2879437	et	3	main
on	doc_801781988532_item	2879442	et	4	main
kuus	doc_801781988532_item	2879443	et	4	main
lifti	doc_801781988532_item	2879454	et	4	main
ja	doc_801781988532_item	2879455	et	3	main
prügišahti	doc_801781988532_item	2879456	et	2	main
korrusel	doc_801781988532_item	2879457	et	3	main
meil	doc_801781988532_item	2879468	et	4	main
on	doc_801781988532_item	2879476	et	4	main
esik	doc_801781988532_item	2879481	et	3	main
wc	doc_801781988532_item	2879484	et	4	main
korteris	doc_801781988532_item	2879489	et	3	main
välisuksest	doc_801781988532_item	2879497	et	4	main
see	doc_801781988532_item	2879502	et	3	main
ole	doc_801781988532_item	2879505	et	4	main
tuba	doc_801781988532_item	2879507	et	4	main
aga	doc_801781988532_item	2879508	et	3	main
aken	doc_801781988532_item	2879513	et	3	main
uksest	doc_801781988532_item	2879514	et	4	main
paremal	doc_801781988532_item	2879515	et	4	main
seina	doc_801781988532_item	2879516	et	4	main
juures	doc_801781988532_item	2879517	et	4	main
seisab	doc_801781988532_item	2879518	et	3	main
riidekapp	doc_801781988532_item	2879519	et	3	main
ja	doc_801781988532_item	2879520	et	3	main
on	doc_801781988532_item	2879527	et	4	main
kušett	doc_801781988532_item	2879528	et	2	main
kirjutuslaual	doc_801781988532_item	2879529	et	3	main
on	doc_801781988532_item	2879535	et	4	main
väikesed	doc_801781988532_item	2879540	et	4	main
mänguasjad	doc_801781988532_item	2879541	et	3	main
akna	doc_801781988532_item	2879542	et	3	main
välisuksest	doc_801781988532_item	2879550	et	4	main
elutuba	doc_801781988532_item	2879556	et	4	main
ukse	doc_801781988532_item	2879557	et	3	main
suur	doc_801781988532_item	2879560	et	3	main
vasakul	doc_801781988532_item	2879563	et	4	main
on	doc_801781988532_item	2879566	et	4	main
all	doc_801781988532_item	2879572	et	3	main
fikus	doc_801781988532_item	2879591	et	4	main
aknalaual	doc_801781988532_item	2879592	et	3	main
akna	doc_801781988532_item	2879596	et	3	main
on	doc_801781988532_item	2879606	et	4	main
uksest	doc_801781988532_item	2879614	et	4	main
punasekirju	doc_801781988532_item	2879624	et	4	main
vaip	doc_801781988532_item	2879625	et	3	main
akna	doc_801781988532_item	2879626	et	3	main
rulikardin	doc_801781988532_item	2879632	et	4	main
on	doc_801781988532_item	2879647	et	4	main
toa	doc_801781988532_item	2879654	et	3	main
keskel	doc_801781988532_item	2879655	et	3	main
seisab	doc_801781988532_item	2879656	et	3	main
lai	doc_801781988532_item	2879657	et	3	main
voodi	doc_801781988532_item	2879658	et	4	main
kahe	doc_801781988532_item	2879659	et	3	main
öökapiga	doc_801781988532_item	2879660	et	3	main
ees	doc_801781988532_item	2879675	et	4	main
on	doc_801781988532_item	2879676	et	4	main
väike	doc_801781988532_item	2879691	et	4	main
ja	doc_801781988532_item	2879696	et	3	main
ole	doc_801781988532_item	2879453	et	4	main
korterit	doc_801781988532_item	2879461	et	3	main
elan	doc_801781988532_item	2879463	et	3	main
mugavustega	doc_801781988532_item	2879467	et	4	main
on	doc_801781988532_item	2879469	et	4	main
soe	doc_801781988532_item	2879470	et	4	main
ja	doc_801781988532_item	2879471	et	3	main
külm	doc_801781988532_item	2879472	et	3	main
lastetuba	doc_801781988532_item	2879478	et	4	main
vannituba	doc_801781988532_item	2879482	et	4	main
meie	doc_801781988532_item	2879485	et	4	main
tuba	doc_801781988532_item	2879501	et	4	main
paremal	doc_801781988532_item	2879526	et	4	main
kohal	doc_801781988532_item	2879533	et	4	main
seinal	doc_801781988532_item	2879534	et	3	main
palju	doc_801781988532_item	2879539	et	4	main
sinine	doc_801781988532_item	2879545	et	4	main
tüllkardin	doc_801781988532_item	2879546	et	3	main
ja	doc_801781988532_item	2879547	et	3	main
rulikardin	doc_801781988532_item	2879548	et	4	main
akna	doc_801781988532_item	2879562	et	3	main
seina	doc_801781988532_item	2879564	et	4	main
on	doc_801781988532_item	2879573	et	4	main
on	doc_801781988532_item	2879598	et	4	main
pruun	doc_801781988532_item	2879607	et	3	main
raamatlaud	doc_801781988532_item	2879608	et	4	main
laual	doc_801781988532_item	2879609	et	3	main
vasakul	doc_801781988532_item	2879615	et	4	main
on	doc_801781988532_item	2879616	et	4	main
väike	doc_801781988532_item	2879617	et	4	main
diivan	doc_801781988532_item	2879618	et	3	main
elutoa	doc_801781988532_item	2879619	et	3	main
keskes	doc_801781988532_item	2879620	et	4	main
vesi	doc_801781988532_item	2879473	et	4	main
keskküte	doc_801781988532_item	2879474	et	3	main
korteris	doc_801781988532_item	2879475	et	3	main
magamistuba	doc_801781988532_item	2879479	et	4	main
köök	doc_801781988532_item	2879480	et	3	main
on	doc_801781988532_item	2879487	et	4	main
toad	doc_801781988532_item	2879490	et	3	main
ei	doc_801781988532_item	2879491	et	4	main
ole	doc_801781988532_item	2879492	et	4	main
läbikäidavad	doc_801781988532_item	2879493	et	3	main
esik	doc_801781988532_item	2879494	et	3	main
on	doc_801781988532_item	2879495	et	4	main
paremal	doc_801781988532_item	2879498	et	4	main
tutre	doc_801781988532_item	2879500	et	4	main
on	doc_801781988532_item	2879503	et	4	main
on	doc_801781988532_item	2879512	et	4	main
kirjutuslaud	doc_801781988532_item	2879522	et	4	main
ja	doc_801781988532_item	2879523	et	3	main
on	doc_801781988532_item	2879530	et	4	main
riiul	doc_801781988532_item	2879536	et	4	main
riiulil	doc_801781988532_item	2879537	et	3	main
ees	doc_801781988532_item	2879543	et	4	main
edasi	doc_801781988532_item	2879549	et	3	main
vastas	doc_801781988532_item	2879558	et	4	main
sektsioonkapp	doc_801781988532_item	2879567	et	4	main
on	doc_801781988532_item	2879569	et	4	main
teller	doc_801781988532_item	2879570	et	3	main
telleri	doc_801781988532_item	2879571	et	3	main
on	doc_801781988532_item	2879593	et	4	main
palju	doc_801781988532_item	2879594	et	4	main
ees	doc_801781988532_item	2879597	et	4	main
muusikariiul	doc_801781988532_item	2879599	et	4	main
on	doc_801781988532_item	2879601	et	4	main
põrandal	doc_801781988532_item	2879621	et	3	main
on	doc_801781988532_item	2879628	et	4	main
vastas	doc_801781988532_item	2879638	et	4	main
paremal	doc_801781988532_item	2879645	et	4	main
seinal	doc_801781988532_item	2879646	et	3	main
riidekapist	doc_801781988532_item	2879650	et	3	main
kahe	doc_801781988532_item	2879665	et	3	main
lille	doc_801781988532_item	2879673	et	4	main
akna	doc_801781988532_item	2879674	et	3	main
ja	doc_801781988532_item	2879679	et	3	main
korteris	doc_801781988532_item	2879682	et	3	main
vannituba	doc_801781988532_item	2879685	et	4	main
asuvad	doc_801781988532_item	2879693	et	4	main
suur	doc_801781988532_item	2879699	et	3	main
valge	doc_801781988532_item	2879725	et	4	main
külmkapp	doc_801781988532_item	2879726	et	3	main
külmkapis	doc_801781988532_item	2879727	et	3	main
on	doc_801781988532_item	2879728	et	4	main
paremal	doc_801781988532_item	2879732	et	4	main
nelja	doc_801781988532_item	2879738	et	4	main
tooliga	doc_801781988532_item	2879739	et	4	main
söögilaua	doc_801781988532_item	2879740	et	3	main
vastas	doc_801781988532_item	2879741	et	4	main
gaasipliidis	doc_801781988532_item	2879744	et	3	main
suur	doc_801781988532_item	2879759	et	3	main
vesifiltr	doc_801781988532_item	2879764	et	4	main
ämber	doc_801781988532_item	2879766	et	3	main
tassid	doc_801781988532_item	2879779	et	4	main
köögikapis	doc_801781988532_item	2879789	et	3	main
kulp	doc_801781988532_item	2879802	et	3	main
väike	doc_801781988532_item	2879812	et	4	main
sahtli	doc_801781988532_item	2879814	et	3	main
all	doc_801781988532_item	2879815	et	3	main
suur	doc_801781988532_item	2879822	et	3	main
on	doc_801781988532_item	2879824	et	4	main
niitnuudlid	doc_801781988532_item	2879829	et	3	main
köögikapil	doc_801781988532_item	2879830	et	3	main
elektrikann	doc_801781988532_item	2879832	et	3	main
on	doc_801781988532_item	2879840	et	4	main
hari	doc_801781988532_item	2879842	et	4	main
ja	doc_801781988532_item	2879843	et	3	main
esikupõrandal	doc_801781988532_item	2879852	et	4	main
on	doc_801781988532_item	2879853	et	4	main
minu	doc_801781988533_item	2879857	et	3	main
ma	doc_801781988533_item	2879859	et	3	main
vabariigis	doc_801781988533_item	2879862	et	3	main
linnas	doc_801781988533_item	2879867	et	4	main
tööstuslinn	doc_801781988533_item	2879870	et	3	main
elan	doc_801781988533_item	2879874	et	3	main
väike	doc_801781988532_item	2879496	et	4	main
on	doc_801781988532_item	2879499	et	4	main
päikesepaisteline	doc_801781988532_item	2879509	et	4	main
ukse	doc_801781988532_item	2879510	et	3	main
vastas	doc_801781988532_item	2879511	et	4	main
sektsioonkapp	doc_801781988532_item	2879521	et	4	main
tool	doc_801781988532_item	2879524	et	3	main
aknast	doc_801781988532_item	2879525	et	4	main
arvuti	doc_801781988532_item	2879531	et	4	main
laua	doc_801781988532_item	2879532	et	3	main
on	doc_801781988532_item	2879538	et	4	main
on	doc_801781988532_item	2879544	et	4	main
paremal	doc_801781988532_item	2879551	et	4	main
on	doc_801781988532_item	2879552	et	4	main
suur	doc_801781988532_item	2879553	et	3	main
ja	doc_801781988532_item	2879554	et	3	main
päikesepaisteline	doc_801781988532_item	2879555	et	4	main
on	doc_801781988532_item	2879559	et	4	main
aken	doc_801781988532_item	2879561	et	3	main
videomagnitofon	doc_801781988532_item	2879574	et	4	main
ja	doc_801781988532_item	2879575	et	3	main
kassetid	doc_801781988532_item	2879576	et	4	main
sektsioonkapis	doc_801781988532_item	2879577	et	4	main
on	doc_801781988532_item	2879578	et	4	main
nõud	doc_801781988532_item	2879579	et	3	main
raamatud	doc_801781988532_item	2879580	et	4	main
diski	doc_801781988532_item	2879581	et	4	main
ja	doc_801781988532_item	2879582	et	3	main
fotoalbumid	doc_801781988532_item	2879583	et	3	main
akna	doc_801781988532_item	2879584	et	3	main
ees	doc_801781988532_item	2879585	et	4	main
paremal	doc_801781988532_item	2879586	et	4	main
nurgas	doc_801781988532_item	2879587	et	3	main
on	doc_801781988532_item	2879588	et	4	main
suur	doc_801781988532_item	2879589	et	3	main
ei	doc_801781988532_item	2879504	et	4	main
suur	doc_801781988532_item	2879506	et	3	main
juures	doc_801781988532_item	2879565	et	4	main
nurgas	doc_801781988532_item	2879568	et	3	main
lill	doc_801781988532_item	2879590	et	3	main
riiulis	doc_801781988532_item	2879600	et	3	main
muusika	doc_801781988532_item	2879602	et	4	main
aparatuur	doc_801781988532_item	2879603	et	3	main
aparatuuri	doc_801781988532_item	2879604	et	4	main
on	doc_801781988532_item	2879610	et	4	main
kaks	doc_801781988532_item	2879611	et	3	main
suur	doc_801781988532_item	2879612	et	3	main
lilli	doc_801781988532_item	2879613	et	4	main
on	doc_801781988532_item	2879622	et	4	main
suur	doc_801781988532_item	2879623	et	3	main
värviline	doc_801781988532_item	2879629	et	4	main
tüllkardin	doc_801781988532_item	2879630	et	3	main
ja	doc_801781988532_item	2879631	et	3	main
tuba	doc_801781988532_item	2879634	et	4	main
on	doc_801781988532_item	2879639	et	4	main
suur	doc_801781988532_item	2879640	et	3	main
valge	doc_801781988532_item	2879641	et	4	main
väike	doc_801781988532_item	2879648	et	4	main
seina	doc_801781988532_item	2879652	et	4	main
juures	doc_801781988532_item	2879653	et	4	main
seina	doc_801781988532_item	2879663	et	4	main
kummutite	doc_801781988532_item	2879666	et	3	main
tüllkardin	doc_801781988532_item	2879678	et	3	main
meie	doc_801781988532_item	2879681	et	4	main
ja	doc_801781988532_item	2879684	et	3	main
on	doc_801781988532_item	2879686	et	4	main
eraldi	doc_801781988532_item	2879687	et	4	main
vannituba	doc_801781988532_item	2879688	et	4	main
kitsas	doc_801781988532_item	2879694	et	4	main
ole	doc_801781988532_item	2879698	et	4	main
pesumasina	doc_801781988532_item	2879701	et	3	main
kohal	doc_801781988532_item	2879702	et	4	main
seinal	doc_801781988532_item	2879703	et	3	main
ripub	doc_801781988532_item	2879704	et	3	main
ovaalne	doc_801781988532_item	2879705	et	3	main
peegel	doc_801781988532_item	2879706	et	3	main
vannitoa	doc_801781988532_item	2879707	et	3	main
vasakul	doc_801781988532_item	2879708	et	4	main
asub	doc_801781988532_item	2879709	et	3	main
meie	doc_801781988532_item	2879710	et	4	main
köök	doc_801781988532_item	2879711	et	3	main
köök	doc_801781988532_item	2879712	et	3	main
ei	doc_801781988532_item	2879713	et	4	main
ole	doc_801781988532_item	2879714	et	4	main
suur	doc_801781988532_item	2879715	et	3	main
ümbes	doc_801781988532_item	2879716	et	4	main
kaheksa	doc_801781988532_item	2879717	et	4	main
ruut	doc_801781988532_item	2879718	et	3	main
meetrit	doc_801781988532_item	2879719	et	3	main
ukse	doc_801781988532_item	2879720	et	3	main
palju	doc_801781988532_item	2879729	et	4	main
toiduained	doc_801781988532_item	2879730	et	3	main
väike	doc_801781988532_item	2879736	et	4	main
söögilaud	doc_801781988532_item	2879737	et	4	main
kaks	doc_801781988532_item	2879746	et	3	main
panni	doc_801781988532_item	2879747	et	4	main
köögisessioonkapp	doc_801781988532_item	2879756	et	4	main
nurgas	doc_801781988532_item	2879757	et	3	main
on	doc_801781988532_item	2879758	et	4	main
lille	doc_801781988532_item	2879595	et	4	main
kõrval	doc_801781988532_item	2879605	et	4	main
ees	doc_801781988532_item	2879627	et	4	main
keskmine	doc_801781988532_item	2879633	et	3	main
on	doc_801781988532_item	2879635	et	4	main
magamistuba	doc_801781988532_item	2879636	et	4	main
ukse	doc_801781988532_item	2879637	et	3	main
riidekapp	doc_801781988532_item	2879642	et	3	main
ukse	doc_801781988532_item	2879643	et	3	main
kõrval	doc_801781988532_item	2879644	et	4	main
riidenagi	doc_801781988532_item	2879649	et	4	main
paremal	doc_801781988532_item	2879651	et	4	main
voodi	doc_801781988532_item	2879661	et	4	main
vastas	doc_801781988532_item	2879662	et	4	main
juures	doc_801781988532_item	2879664	et	4	main
vahel	doc_801781988532_item	2879667	et	4	main
on	doc_801781988532_item	2879668	et	4	main
öökapp	doc_801781988532_item	2879669	et	3	main
aknalaual	doc_801781988532_item	2879670	et	3	main
on	doc_801781988532_item	2879671	et	4	main
kaks	doc_801781988532_item	2879672	et	3	main
valge	doc_801781988532_item	2879677	et	4	main
külgkardinad	doc_801781988532_item	2879680	et	4	main
on	doc_801781988532_item	2879689	et	4	main
vannitoas	doc_801781988532_item	2879692	et	3	main
pesumasin	doc_801781988532_item	2879695	et	3	main
külmkapist	doc_801781988532_item	2879731	et	3	main
akna	doc_801781988532_item	2879733	et	3	main
on	doc_801781988532_item	2879742	et	4	main
on	doc_801781988532_item	2879745	et	4	main
gaasipliidi	doc_801781988532_item	2879748	et	3	main
kohal	doc_801781988532_item	2879749	et	4	main
prae	doc_801781988532_item	2879775	et	4	main
taldrikud	doc_801781988532_item	2879776	et	3	main
klassid	doc_801781988532_item	2879777	et	3	main
suured	doc_801781988532_item	2879778	et	3	main
köögikapis	doc_801781988532_item	2879782	et	3	main
on	doc_801781988532_item	2879783	et	4	main
sahtlis	doc_801781988532_item	2879794	et	3	main
dessertlusikad	doc_801781988532_item	2879799	et	4	main
ja	doc_801781988532_item	2879833	et	3	main
ja	doc_801781988532_item	2879836	et	3	main
gaasipliidi	doc_801781988532_item	2879838	et	3	main
on	doc_801781988532_item	2879848	et	4	main
rohelisekirju	doc_801781988532_item	2879854	et	4	main
linoleum	doc_801781988532_item	2879855	et	3	main
korter	doc_801781988533_item	2879858	et	3	main
elan	doc_801781988533_item	2879860	et	3	main
ida	doc_801781988533_item	2879863	et	4	main
viru	doc_801781988533_item	2879864	et	4	main
narva	doc_801781988533_item	2879868	et	4	main
ja	doc_801781988533_item	2879871	et	3	main
äärelinnas	doc_801781988533_item	2879875	et	4	main
elan	doc_801781988533_item	2879877	et	3	main
korteris	doc_801781988533_item	2879887	et	3	main
maja	doc_801781988533_item	2879902	et	4	main
ja	doc_801781988533_item	2879912	et	3	main
bussipeatus	doc_801781988533_item	2879913	et	4	main
majas	doc_801781988533_item	2879923	et	3	main
ei	doc_801781988533_item	2879924	et	4	main
ole	doc_801781988533_item	2879925	et	4	main
ja	doc_801781988533_item	2879931	et	3	main
külm	doc_801781988533_item	2879932	et	3	main
prügišaht	doc_801781988533_item	2879935	et	2	main
meie	doc_801781988533_item	2879936	et	4	main
ja	doc_801781988533_item	2879941	et	3	main
köök	doc_801781988533_item	2879942	et	3	main
asub	doc_801781988533_item	2879944	et	3	main
väike	doc_801781988533_item	2879948	et	4	main
välisuksest	doc_801781988533_item	2879949	et	4	main
paremal	doc_801781988533_item	2879950	et	4	main
seinal	doc_801781988533_item	2879951	et	3	main
ripub	doc_801781988533_item	2879952	et	3	main
tolmuimeja	doc_801781988533_item	2879966	et	4	main
seal	doc_801781988533_item	2879969	et	4	main
purke	doc_801781988533_item	2879972	et	3	main
on	doc_801781988533_item	2879978	et	4	main
aga	doc_801781988533_item	2879980	et	3	main
magamistoas	doc_801781988533_item	2879982	et	3	main
voodi	doc_801781988533_item	2879984	et	4	main
ja	doc_801781988533_item	2879985	et	3	main
lastevoodi	doc_801781988533_item	2879986	et	4	main
wc	doc_801781988532_item	2879683	et	4	main
väga	doc_801781988532_item	2879690	et	3	main
ei	doc_801781988532_item	2879697	et	4	main
vann	doc_801781988532_item	2879700	et	3	main
vastas	doc_801781988532_item	2879721	et	4	main
nurgas	doc_801781988532_item	2879722	et	3	main
seisab	doc_801781988532_item	2879723	et	3	main
suur	doc_801781988532_item	2879724	et	3	main
ees	doc_801781988532_item	2879734	et	4	main
seisab	doc_801781988532_item	2879735	et	3	main
gaasipliit	doc_801781988532_item	2879743	et	3	main
asub	doc_801781988532_item	2879750	et	3	main
tombekapist	doc_801781988532_item	2879752	et	4	main
on	doc_801781988532_item	2879763	et	4	main
edasi	doc_801781988532_item	2879780	et	3	main
ravimtaimed	doc_801781988532_item	2879784	et	3	main
kõrval	doc_801781988532_item	2879788	et	4	main
on	doc_801781988532_item	2879790	et	4	main
ja	doc_801781988532_item	2879792	et	3	main
on	doc_801781988532_item	2879795	et	4	main
supilusikad	doc_801781988532_item	2879798	et	3	main
korgitser	doc_801781988532_item	2879803	et	3	main
ja	doc_801781988532_item	2879804	et	3	main
kõrval	doc_801781988532_item	2879806	et	4	main
teisel	doc_801781988532_item	2879807	et	4	main
sahtlis	doc_801781988532_item	2879808	et	3	main
pakid	doc_801781988532_item	2879813	et	4	main
teises	doc_801781988532_item	2879821	et	4	main
tangud	doc_801781988532_item	2879826	et	3	main
makaronid	doc_801781988532_item	2879827	et	3	main
ja	doc_801781988532_item	2879828	et	3	main
mikrolaineahi	doc_801781988532_item	2879834	et	3	main
õle	doc_801781988532_item	2879835	et	3	main
kõrval	doc_801781988532_item	2879839	et	4	main
külgkardinad	doc_801781988532_item	2879849	et	4	main
köögi	doc_801781988532_item	2879850	et	3	main
ja	doc_801781988532_item	2879851	et	3	main
maakonnas	doc_801781988533_item	2879865	et	4	main
on	doc_801781988533_item	2879869	et	4	main
piirilinn	doc_801781988533_item	2879872	et	3	main
ma	doc_801781988533_item	2879876	et	3	main
viiekorruselises	doc_801781988533_item	2879882	et	4	main
paneelmajas	doc_801781988533_item	2879883	et	3	main
neljandal	doc_801781988533_item	2879884	et	3	main
korruselises	doc_801781988533_item	2879885	et	4	main
hoovis	doc_801781988533_item	2879889	et	4	main
on	doc_801781988533_item	2879890	et	4	main
ja	doc_801781988533_item	2879892	et	3	main
pingid	doc_801781988533_item	2879894	et	3	main
mänguväljak	doc_801781988533_item	2879900	et	3	main
lähedal	doc_801781988533_item	2879903	et	4	main
asuvad	doc_801781988533_item	2879904	et	4	main
toidukauplused	doc_801781988533_item	2879905	et	3	main
tempo	doc_801781988533_item	2879906	et	4	main
ja	doc_801781988533_item	2879907	et	3	main
sendi	doc_801781988533_item	2879908	et	3	main
meie	doc_801781988533_item	2879914	et	4	main
korter	doc_801781988533_item	2879915	et	3	main
korterit	doc_801781988533_item	2879921	et	3	main
lifti	doc_801781988533_item	2879926	et	4	main
aga	doc_801781988533_item	2879927	et	3	main
soe	doc_801781988533_item	2879930	et	4	main
vesi	doc_801781988533_item	2879933	et	4	main
ja	doc_801781988533_item	2879934	et	3	main
on	doc_801781988533_item	2879947	et	4	main
peegli	doc_801781988533_item	2879955	et	3	main
on	doc_801781988533_item	2879957	et	4	main
встроенный	doc_801781988533_item	2879958	et	2	main
kapp	doc_801781988533_item	2879959	et	3	main
instrumentid	doc_801781988533_item	2879965	et	4	main
hoian	doc_801781988533_item	2879970	et	3	main
vasakul	doc_801781988533_item	2879974	et	4	main
magamistuba	doc_801781988533_item	2879976	et	4	main
pesu	doc_801781988533_item	2880021	et	4	main
pesu	doc_801781988533_item	2880033	et	4	main
ja	doc_801781988533_item	2880034	et	3	main
lasteautod	doc_801781988533_item	2880039	et	3	main
lamp	doc_801781988533_item	2880048	et	3	main
seisab	doc_801781988533_item	2880051	et	3	main
akna	doc_801781988533_item	2880053	et	3	main
põrandal	doc_801781988533_item	2880059	et	3	main
tualet	doc_801781988533_item	2880071	et	4	main
vannitoas	doc_801781988533_item	2880081	et	3	main
peegel	doc_801781988533_item	2880084	et	3	main
pesumasin	doc_801781988533_item	2880087	et	3	main
tombekapp	doc_801781988532_item	2879751	et	4	main
seina	doc_801781988532_item	2879753	et	4	main
juures	doc_801781988532_item	2879754	et	4	main
asub	doc_801781988532_item	2879755	et	3	main
valamu	doc_801781988532_item	2879768	et	4	main
ja	doc_801781988532_item	2879786	et	3	main
pipar	doc_801781988532_item	2879787	et	3	main
valamu	doc_801781988532_item	2879760	et	4	main
valamu	doc_801781988532_item	2879761	et	4	main
all	doc_801781988532_item	2879762	et	3	main
ja	doc_801781988532_item	2879765	et	3	main
kartuliga	doc_801781988532_item	2879767	et	3	main
kohal	doc_801781988532_item	2879769	et	4	main
köögikapis	doc_801781988532_item	2879770	et	3	main
on	doc_801781988532_item	2879771	et	4	main
nõud	doc_801781988532_item	2879772	et	3	main
supi	doc_801781988532_item	2879773	et	3	main
ja	doc_801781988532_item	2879774	et	3	main
teises	doc_801781988532_item	2879781	et	4	main
sool	doc_801781988532_item	2879785	et	4	main
mikser	doc_801781988532_item	2879793	et	3	main
kahvlid	doc_801781988532_item	2879797	et	3	main
ja	doc_801781988532_item	2879800	et	3	main
köögikapis	doc_801781988532_item	2879823	et	3	main
toiduained	doc_801781988532_item	2879825	et	3	main
on	doc_801781988532_item	2879831	et	4	main
kohvipress	doc_801781988532_item	2879837	et	3	main
väike	doc_801781988532_item	2879841	et	4	main
kühvel	doc_801781988532_item	2879844	et	3	main
prügiämber	doc_801781988532_item	2879845	et	3	main
akna	doc_801781988532_item	2879846	et	3	main
ees	doc_801781988532_item	2879847	et	4	main
essee	doc_801781988533_item	2879856	et	4	main
eesti	doc_801781988533_item	2879861	et	4	main
narva	doc_801781988533_item	2879866	et	4	main
ma	doc_801781988533_item	2879873	et	3	main
kahetoalises	doc_801781988533_item	2879886	et	4	main
on	doc_801781988533_item	2879898	et	4	main
meie	doc_801781988533_item	2879901	et	4	main
meie	doc_801781988533_item	2879922	et	4	main
on	doc_801781988533_item	2879928	et	4	main
korteris	doc_801781988533_item	2879937	et	3	main
on	doc_801781988533_item	2879938	et	4	main
suur	doc_801781988533_item	2879953	et	3	main
vastas	doc_801781988533_item	2879956	et	4	main
seal	doc_801781988533_item	2879960	et	4	main
ripub	doc_801781988533_item	2879961	et	3	main
välisriided	doc_801781988533_item	2879962	et	3	main
ja	doc_801781988533_item	2879967	et	3	main
esikust	doc_801781988533_item	2879973	et	4	main
vahel	doc_801781988533_item	2879990	et	4	main
vaip	doc_801781988533_item	2880008	et	3	main
ja	doc_801781988533_item	2880022	et	3	main
servant	doc_801781988533_item	2880023	et	4	main
servantil	doc_801781988533_item	2880024	et	4	main
nõud	doc_801781988533_item	2880029	et	3	main
servanti	doc_801781988533_item	2880036	et	4	main
seisab	doc_801781988533_item	2880038	et	3	main
kompjuterilaual	doc_801781988533_item	2880044	et	4	main
on	doc_801781988533_item	2880045	et	4	main
vastas	doc_801781988533_item	2880050	et	4	main
tüllkardin	doc_801781988533_item	2880056	et	3	main
on	doc_801781988533_item	2880064	et	4	main
vastas	doc_801781988533_item	2880067	et	4	main
vannituba	doc_801781988533_item	2880074	et	4	main
wc	doc_801781988533_item	2880079	et	4	main
ja	doc_801781988533_item	2880086	et	3	main
on	doc_801781988533_item	2880089	et	4	main
pesemisvahendid	doc_801781988533_item	2880090	et	3	main
köögikombain	doc_801781988532_item	2879791	et	3	main
noad	doc_801781988532_item	2879796	et	3	main
teelusikad	doc_801781988532_item	2879801	et	3	main
avaja	doc_801781988532_item	2879805	et	4	main
on	doc_801781988532_item	2879809	et	4	main
suur	doc_801781988532_item	2879810	et	3	main
ja	doc_801781988532_item	2879811	et	3	main
on	doc_801781988532_item	2879816	et	4	main
suur	doc_801781988532_item	2879817	et	3	main
ja	doc_801781988532_item	2879818	et	3	main
vaike	doc_801781988532_item	2879819	et	3	main
potid	doc_801781988532_item	2879820	et	4	main
maanteel	doc_801781988533_item	2879879	et	3	main
ma	doc_801781988533_item	2879880	et	3	main
maja	doc_801781988533_item	2879888	et	4	main
laste	doc_801781988533_item	2879899	et	4	main
on	doc_801781988533_item	2879916	et	4	main
erastatud	doc_801781988533_item	2879917	et	4	main
sissekäigus	doc_801781988533_item	2879918	et	3	main
on	doc_801781988533_item	2879919	et	4	main
keskküte	doc_801781988533_item	2879929	et	3	main
elutuba	doc_801781988533_item	2879939	et	4	main
magamistuba	doc_801781988533_item	2879940	et	4	main
lastenurga	doc_801781988533_item	2879943	et	3	main
elutubas	doc_801781988533_item	2879945	et	4	main
esik	doc_801781988533_item	2879946	et	3	main
peegel	doc_801781988533_item	2879954	et	3	main
asuvad	doc_801781988533_item	2879963	et	4	main
jalatsid	doc_801781988533_item	2879964	et	3	main
ma	doc_801781988533_item	2879968	et	3	main
tühje	doc_801781988533_item	2879971	et	3	main
asub	doc_801781988533_item	2879975	et	3	main
väiksevõitu	doc_801781988533_item	2879979	et	4	main
voodide	doc_801781988533_item	2879991	et	4	main
ripub	doc_801781988533_item	2879992	et	3	main
seinalamp	doc_801781988533_item	2879993	et	3	main
voodi	doc_801781988533_item	2879994	et	4	main
kõrval	doc_801781988533_item	2879995	et	4	main
nurgas	doc_801781988533_item	2879996	et	3	main
seisab	doc_801781988533_item	2879997	et	3	main
akna	doc_801781988533_item	2879999	et	3	main
riidekapp	doc_801781988533_item	2879998	et	3	main
ees	doc_801781988533_item	2880000	et	4	main
on	doc_801781988533_item	2880001	et	4	main
tüllkardin	doc_801781988533_item	2880002	et	3	main
ja	doc_801781988533_item	2880003	et	3	main
külgkardin	doc_801781988533_item	2880004	et	3	main
põrandal	doc_801781988533_item	2880005	et	3	main
on	doc_801781988533_item	2880006	et	4	main
pruunikirju	doc_801781988533_item	2880007	et	4	main
elutoas	doc_801781988533_item	2880009	et	3	main
on	doc_801781988533_item	2880010	et	4	main
mugavad	doc_801781988533_item	2880011	et	3	main
diivanvoodi	doc_801781988533_item	2880012	et	4	main
ja	doc_801781988533_item	2880013	et	3	main
diivani	doc_801781988533_item	2880015	et	4	main
vastas	doc_801781988533_item	2880016	et	4	main
tugitoolvoodi	doc_801781988533_item	2880014	et	4	main
asuvad	doc_801781988533_item	2880017	et	4	main
kummut	doc_801781988533_item	2880018	et	3	main
kus	doc_801781988533_item	2880019	et	3	main
asub	doc_801781988533_item	2880020	et	3	main
on	doc_801781988533_item	2880025	et	4	main
muusikakeskus	doc_801781988533_item	2880026	et	3	main
tartu	doc_801781988533_item	2879878	et	4	main
elan	doc_801781988533_item	2879881	et	3	main
liumäe	doc_801781988533_item	2879891	et	3	main
mõned	doc_801781988533_item	2879893	et	3	main
naabrine	doc_801781988533_item	2879895	et	4	main
hoovis	doc_801781988533_item	2879896	et	4	main
kõrval	doc_801781988533_item	2879897	et	4	main
parkla	doc_801781988533_item	2879909	et	4	main
sõidutee	doc_801781988533_item	2879910	et	4	main
kõnnitee	doc_801781988533_item	2879911	et	4	main
viisteist	doc_801781988533_item	2879920	et	4	main
magamistuba	doc_801781988533_item	2879977	et	4	main
hubane	doc_801781988533_item	2879981	et	3	main
on	doc_801781988533_item	2879983	et	4	main
servantis	doc_801781988533_item	2880027	et	4	main
on	doc_801781988533_item	2880028	et	4	main
diivani	doc_801781988533_item	2880040	et	4	main
kõrval	doc_801781988533_item	2880041	et	4	main
kompjuterilaud	doc_801781988533_item	2880043	et	4	main
kompjuterilauda	doc_801781988533_item	2880049	et	4	main
teler	doc_801781988533_item	2880052	et	3	main
ees	doc_801781988533_item	2880054	et	4	main
ja	doc_801781988533_item	2880057	et	3	main
vannituba	doc_801781988533_item	2880069	et	4	main
ja	doc_801781988533_item	2880070	et	3	main
eraldi	doc_801781988533_item	2880076	et	4	main
tualetis	doc_801781988533_item	2880077	et	3	main
on	doc_801781988533_item	2880078	et	4	main
on	doc_801781988533_item	2880082	et	4	main
seep	doc_801781988533_item	2880091	et	4	main
hambapasta	doc_801781988533_item	2880092	et	4	main
šampoon	doc_801781988533_item	2880093	et	2	main
hambaharjad	doc_801781988533_item	2880094	et	3	main
nuustikud	doc_801781988533_item	2880095	et	3	main
valamu	doc_801781988533_item	2880096	et	4	main
kõrval	doc_801781988533_item	2880097	et	4	main
ripuvad	doc_801781988533_item	2880098	et	3	main
käteratikud	doc_801781988533_item	2880099	et	4	main
vannitoas	doc_801781988533_item	2880100	et	3	main
on	doc_801781988533_item	2880101	et	4	main
ripplaed	doc_801781988533_item	2880102	et	4	main
kuivatan	doc_801781988533_item	2880103	et	3	main
pesu	doc_801781988533_item	2880104	et	4	main
ühisrõdul	doc_801781988533_item	2880105	et	3	main
köögis	doc_801781988533_item	2880106	et	3	main
on	doc_801781988533_item	2880107	et	4	main
laud	doc_801781988533_item	2880108	et	4	main
taburetid	doc_801781988533_item	2880109	et	3	main
ja	doc_801781988533_item	2880110	et	3	main
nurgadiivan	doc_801781988533_item	2880111	et	3	main
akna	doc_801781988533_item	2880112	et	3	main
juures	doc_801781988533_item	2880113	et	4	main
nurgas	doc_801781988533_item	2880114	et	3	main
seisab	doc_801781988533_item	2880115	et	3	main
külmkapp	doc_801781988533_item	2880116	et	3	main
külmkapi	doc_801781988533_item	2880117	et	3	main
kõrval	doc_801781988533_item	2880118	et	4	main
seisab	doc_801781988533_item	2880119	et	3	main
köögikapp	doc_801781988533_item	2880120	et	3	main
on	doc_801781988533_item	2880129	et	4	main
elektripliit	doc_801781988533_item	2880130	et	3	main
elektripliites	doc_801781988533_item	2880131	et	4	main
riidekapp	doc_801781988533_item	2879987	et	3	main
tool	doc_801781988533_item	2879988	et	3	main
seinal	doc_801781988533_item	2879989	et	3	main
raamatud	doc_801781988533_item	2880030	et	4	main
sahtlis	doc_801781988533_item	2880031	et	3	main
on	doc_801781988533_item	2880032	et	4	main
dokumentid	doc_801781988533_item	2880035	et	4	main
all	doc_801781988533_item	2880037	et	3	main
seisab	doc_801781988533_item	2880042	et	3	main
kompjuter	doc_801781988533_item	2880046	et	4	main
ja	doc_801781988533_item	2880047	et	3	main
on	doc_801781988533_item	2880055	et	4	main
külgkardin	doc_801781988533_item	2880058	et	3	main
on	doc_801781988533_item	2880060	et	4	main
vaip	doc_801781988533_item	2880062	et	3	main
elutuba	doc_801781988533_item	2880063	et	4	main
elutuba	doc_801781988533_item	2880066	et	4	main
asuvad	doc_801781988533_item	2880068	et	4	main
on	doc_801781988533_item	2880075	et	4	main
paber	doc_801781988533_item	2880080	et	3	main
vann	doc_801781988533_item	2880083	et	3	main
valamu	doc_801781988533_item	2880085	et	4	main
vannitoas	doc_801781988533_item	2880088	et	3	main
on	doc_801781988533_item	2880122	et	4	main
potid	doc_801781988533_item	2880123	et	4	main
kapil	doc_801781988533_item	2880124	et	3	main
nõudepesuvahend	doc_801781988533_item	2880141	et	3	main
valamu	doc_801781988533_item	2880142	et	4	main
vastas	doc_801781988533_item	2880152	et	4	main
asub	doc_801781988533_item	2880153	et	3	main
on	doc_801781988533_item	2880156	et	4	main
essee	doc_801781988534_item	2880177	et	4	main
vabariigis	doc_801781988534_item	2880181	et	3	main
viru	doc_801781988534_item	2880183	et	4	main
narva	doc_801781988534_item	2880185	et	4	main
timuti	doc_801781988534_item	2880187	et	3	main
tänaval	doc_801781988534_item	2880188	et	4	main
majas	doc_801781988534_item	2880189	et	3	main
number	doc_801781988534_item	2880190	et	3	main
nelikümmend	doc_801781988534_item	2880191	et	4	main
neli	doc_801781988534_item	2880192	et	3	main
korteris	doc_801781988534_item	2880193	et	3	main
ja	doc_801781988534_item	2880231	et	3	main
lift	doc_801781988534_item	2880232	et	3	main
ei	doc_801781988534_item	2880233	et	4	main
alati	doc_801781988534_item	2880235	et	4	main
puhul	doc_801781988534_item	2880236	et	4	main
aga	doc_801781988534_item	2880246	et	3	main
on	doc_801781988534_item	2880254	et	4	main
kõrval	doc_801781988534_item	2880260	et	4	main
seinal	doc_801781988534_item	2880261	et	3	main
on	doc_801781988534_item	2880262	et	4	main
telefonikataloog	doc_801781988534_item	2880269	et	3	main
on	doc_801781988534_item	2880272	et	4	main
pink	doc_801781988534_item	2880273	et	3	main
pingi	doc_801781988534_item	2880274	et	4	main
all	doc_801781988534_item	2880275	et	3	main
nagi	doc_801781988534_item	2880278	et	4	main
sarved	doc_801781988534_item	2880281	et	3	main
mütsid	doc_801781988534_item	2880284	et	3	main
paremal	doc_801781988534_item	2880294	et	4	main
külmkapp	doc_801781988534_item	2880299	et	3	main
toiduained	doc_801781988534_item	2880302	et	3	main
ja	doc_801781988534_item	2880308	et	3	main
külmkapi	doc_801781988534_item	2880310	et	3	main
ja	doc_801781988534_item	2880319	et	3	main
roosa	doc_801781988533_item	2880061	et	4	main
valguskülla	doc_801781988533_item	2880065	et	4	main
wc	doc_801781988533_item	2880072	et	4	main
ja	doc_801781988533_item	2880073	et	3	main
kapis	doc_801781988533_item	2880121	et	3	main
on	doc_801781988533_item	2880125	et	4	main
elektrikann	doc_801781988533_item	2880126	et	3	main
köögikapi	doc_801781988533_item	2880127	et	3	main
asuvad	doc_801781988533_item	2880132	et	4	main
pannid	doc_801781988533_item	2880133	et	3	main
juures	doc_801781988533_item	2880139	et	4	main
on	doc_801781988533_item	2880164	et	4	main
tüllkardin	doc_801781988533_item	2880165	et	3	main
köögipõrand	doc_801781988533_item	2880166	et	3	main
ja	doc_801781988533_item	2880167	et	3	main
on	doc_801781988533_item	2880169	et	4	main
kaetuvad	doc_801781988533_item	2880170	et	4	main
linoleumiga	doc_801781988533_item	2880171	et	3	main
ma	doc_801781988533_item	2880172	et	3	main
on	doc_801781988533_item	2880173	et	4	main
rahul	doc_801781988533_item	2880176	et	4	main
elan	doc_801781988534_item	2880179	et	3	main
ida	doc_801781988534_item	2880182	et	4	main
üheksakorruselises	doc_801781988534_item	2880199	et	4	main
majas	doc_801781988534_item	2880200	et	3	main
minu	doc_801781988534_item	2880201	et	3	main
maja	doc_801781988534_item	2880202	et	4	main
lähedal	doc_801781988534_item	2880203	et	4	main
asuvad	doc_801781988534_item	2880204	et	4	main
toidu-	doc_801781988534_item	2880205	et	3	main
ja	doc_801781988534_item	2880206	et	3	main
tööstuskaupade	doc_801781988534_item	2880207	et	3	main
kauplused	doc_801781988534_item	2880208	et	3	main
kolm	doc_801781988534_item	2880210	et	3	main
kool	doc_801781988534_item	2880209	et	4	main
lasteaeda	doc_801781988534_item	2880211	et	4	main
kolm	doc_801781988534_item	2880212	et	3	main
bensiinijaama	doc_801781988534_item	2880213	et	4	main
seb	doc_801781988534_item	2880214	et	4	main
ühispank	doc_801781988534_item	2880215	et	3	main
ja	doc_801781988534_item	2880216	et	3	main
juuksla	doc_801781988534_item	2880217	et	4	main
minu	doc_801781988534_item	2880218	et	3	main
sessekäigus	doc_801781988534_item	2880219	et	4	main
on	doc_801781988534_item	2880220	et	4	main
trepikoda	doc_801781988534_item	2880230	et	4	main
on	doc_801781988534_item	2880244	et	4	main
kitsas	doc_801781988534_item	2880247	et	4	main
esukus	doc_801781988534_item	2880248	et	4	main
on	doc_801781988534_item	2880249	et	4	main
ripplagi	doc_801781988534_item	2880250	et	3	main
esikus	doc_801781988534_item	2880251	et	3	main
paremal	doc_801781988534_item	2880253	et	4	main
riiul	doc_801781988534_item	2880263	et	4	main
riiulil	doc_801781988534_item	2880264	et	3	main
seisab	doc_801781988534_item	2880265	et	3	main
on	doc_801781988534_item	2880276	et	4	main
on	doc_801781988534_item	2880280	et	4	main
riiuli	doc_801781988534_item	2880288	et	3	main
kõrval	doc_801781988533_item	2880128	et	4	main
elektripliiti	doc_801781988533_item	2880134	et	4	main
on	doc_801781988533_item	2880136	et	4	main
on	doc_801781988533_item	2880140	et	4	main
valamu	doc_801781988533_item	2880151	et	4	main
laual	doc_801781988533_item	2880155	et	3	main
valamu	doc_801781988533_item	2880158	et	4	main
all	doc_801781988533_item	2880159	et	3	main
seisab	doc_801781988533_item	2880160	et	3	main
prügiämber	doc_801781988533_item	2880161	et	3	main
akna	doc_801781988533_item	2880162	et	3	main
esikupõrand	doc_801781988533_item	2880168	et	4	main
ma	doc_801781988534_item	2880178	et	3	main
eesti	doc_801781988534_item	2880180	et	4	main
maakonnas	doc_801781988534_item	2880184	et	4	main
linnas	doc_801781988534_item	2880186	et	4	main
kakskümmend	doc_801781988534_item	2880195	et	4	main
elan	doc_801781988534_item	2880198	et	3	main
kolmkümmend	doc_801781988534_item	2880221	et	4	main
välis	doc_801781988534_item	2880226	et	4	main
käib	doc_801781988534_item	2880227	et	3	main
lukus	doc_801781988534_item	2880228	et	3	main
minu	doc_801781988534_item	2880229	et	3	main
ole	doc_801781988534_item	2880234	et	4	main
ma	doc_801781988534_item	2880237	et	3	main
elan	doc_801781988534_item	2880238	et	3	main
kolmandal	doc_801781988534_item	2880239	et	3	main
korrusel	doc_801781988534_item	2880240	et	3	main
kolmetoalises	doc_801781988534_item	2880241	et	4	main
korteris	doc_801781988534_item	2880242	et	3	main
esik	doc_801781988534_item	2880243	et	3	main
välisuksest	doc_801781988534_item	2880252	et	4	main
nagi	doc_801781988534_item	2880255	et	4	main
ripuvad	doc_801781988534_item	2880257	et	3	main
nagi	doc_801781988534_item	2880259	et	4	main
kodutelefon	doc_801781988534_item	2880266	et	3	main
ja	doc_801781988534_item	2880267	et	3	main
all	doc_801781988534_item	2880271	et	3	main
jalatsid	doc_801781988534_item	2880277	et	3	main
sarvedel	doc_801781988534_item	2880282	et	4	main
välisuksest	doc_801781988534_item	2880285	et	4	main
uksest	doc_801781988534_item	2880293	et	4	main
valge	doc_801781988534_item	2880298	et	4	main
liha	doc_801781988534_item	2880303	et	4	main
või	doc_801781988534_item	2880304	et	4	main
majonees	doc_801781988534_item	2880305	et	3	main
on	doc_801781988534_item	2880314	et	4	main
köögikappist	doc_801781988534_item	2880334	et	4	main
vasakul	doc_801781988534_item	2880340	et	4	main
juures	doc_801781988534_item	2880345	et	4	main
valamu	doc_801781988534_item	2880348	et	4	main
vahukulp	doc_801781988534_item	2880353	et	3	main
valamu	doc_801781988534_item	2880357	et	4	main
prügiämber	doc_801781988534_item	2880360	et	3	main
kühvel	doc_801781988534_item	2880362	et	3	main
köögikapis	doc_801781988534_item	2880368	et	3	main
nendel	doc_801781988534_item	2880371	et	4	main
on	doc_801781988534_item	2880372	et	4	main
sööginõud	doc_801781988534_item	2880373	et	3	main
uksest	doc_801781988534_item	2880381	et	4	main
köögikapis	doc_801781988534_item	2880388	et	3	main
riiulitel	doc_801781988534_item	2880394	et	3	main
köögikombain	doc_801781988534_item	2880398	et	3	main
võileivagrill	doc_801781988534_item	2880400	et	3	main
laud	doc_801781988534_item	2880427	et	4	main
laua	doc_801781988534_item	2880428	et	3	main
neli	doc_801781988534_item	2880431	et	3	main
laua	doc_801781988534_item	2880433	et	3	main
ees	doc_801781988534_item	2880439	et	4	main
on	doc_801781988534_item	2880440	et	4	main
külgkardinad	doc_801781988534_item	2880441	et	4	main
köögis	doc_801781988534_item	2880442	et	3	main
suur	doc_801781988534_item	2880450	et	3	main
läbikäidav	doc_801781988534_item	2880452	et	4	main
elutoauksest	doc_801781988534_item	2880453	et	4	main
vasakul	doc_801781988534_item	2880454	et	4	main
ja	doc_801781988534_item	2880465	et	3	main
paremal	doc_801781988534_item	2880479	et	4	main
riiulitel	doc_801781988534_item	2880489	et	3	main
ja	doc_801781988534_item	2880492	et	3	main
dokumendid	doc_801781988534_item	2880496	et	3	main
kõrval	doc_801781988533_item	2880135	et	4	main
valamu	doc_801781988533_item	2880137	et	4	main
valamu	doc_801781988533_item	2880138	et	4	main
kohal	doc_801781988533_item	2880143	et	4	main
ripub	doc_801781988533_item	2880144	et	3	main
köögikapp	doc_801781988533_item	2880145	et	3	main
köögikapis	doc_801781988533_item	2880146	et	3	main
on	doc_801781988533_item	2880147	et	4	main
nõud	doc_801781988533_item	2880148	et	3	main
taldrikud	doc_801781988533_item	2880149	et	3	main
kruusid	doc_801781988533_item	2880150	et	3	main
laud	doc_801781988533_item	2880154	et	4	main
mikrolaineahi	doc_801781988533_item	2880157	et	3	main
ees	doc_801781988533_item	2880163	et	4	main
oma	doc_801781988533_item	2880174	et	4	main
korteriga	doc_801781988533_item	2880175	et	3	main
kaks	doc_801781988534_item	2880196	et	3	main
kuus	doc_801781988534_item	2880222	et	4	main
korterit	doc_801781988534_item	2880223	et	3	main
minu	doc_801781988534_item	2880224	et	3	main
majas	doc_801781988534_item	2880225	et	3	main
pikk	doc_801781988534_item	2880245	et	4	main
nagis	doc_801781988534_item	2880256	et	3	main
välisriided	doc_801781988534_item	2880258	et	3	main
lamab	doc_801781988534_item	2880268	et	3	main
nagi	doc_801781988534_item	2880270	et	4	main
kohal	doc_801781988534_item	2880279	et	4	main
ja	doc_801781988534_item	2880287	et	3	main
vastas	doc_801781988534_item	2880289	et	4	main
on	doc_801781988534_item	2880290	et	4	main
uks	doc_801781988534_item	2880291	et	3	main
köögisse	doc_801781988534_item	2880292	et	3	main
seal	doc_801781988534_item	2880300	et	4	main
on	doc_801781988534_item	2880301	et	4	main
hapukoor	doc_801781988534_item	2880307	et	4	main
teised	doc_801781988534_item	2880309	et	4	main
köögikapp	doc_801781988534_item	2880315	et	3	main
köögikapis	doc_801781988534_item	2880316	et	3	main
on	doc_801781988534_item	2880317	et	4	main
riiulid	doc_801781988534_item	2880318	et	3	main
kahvelid	doc_801781988534_item	2880326	et	3	main
riiulitel	doc_801781988534_item	2880329	et	3	main
on	doc_801781988534_item	2880336	et	4	main
gaasipliidi	doc_801781988534_item	2880339	et	3	main
nurgas	doc_801781988534_item	2880341	et	3	main
seinal	doc_801781988534_item	2880350	et	3	main
riiv	doc_801781988534_item	2880352	et	3	main
sõel	doc_801781988534_item	2880354	et	3	main
ja	doc_801781988534_item	2880361	et	3	main
klaasid	doc_801781988534_item	2880374	et	4	main
kruusid	doc_801781988534_item	2880375	et	3	main
seina	doc_801781988534_item	2880383	et	4	main
juures	doc_801781988534_item	2880425	et	4	main
seisab	doc_801781988534_item	2880426	et	3	main
on	doc_801781988534_item	2880430	et	4	main
paremal	doc_801781988534_item	2880434	et	4	main
on	doc_801781988534_item	2880435	et	4	main
rõdule	doc_801781988534_item	2880436	et	3	main
uks	doc_801781988534_item	2880437	et	3	main
juures	doc_801781988534_item	2880456	et	4	main
seisab	doc_801781988534_item	2880457	et	3	main
pruun	doc_801781988534_item	2880458	et	3	main
sektsioonkapp	doc_801781988534_item	2880459	et	4	main
seal	doc_801781988534_item	2880460	et	4	main
raamatud	doc_801781988534_item	2880463	et	4	main
muusikakeskus	doc_801781988534_item	2880466	et	3	main
vastas	doc_801781988534_item	2880468	et	4	main
nurgadivanist	doc_801781988534_item	2880474	et	4	main
seisab	doc_801781988534_item	2880476	et	3	main
sahtelis	doc_801781988534_item	2880494	et	3	main
on	doc_801781988534_item	2880498	et	4	main
toalill	doc_801781988534_item	2880499	et	3	main
ja	doc_801781988534_item	2880500	et	3	main
fotod	doc_801781988534_item	2880501	et	3	main
seisukapi	doc_801781988534_item	2880502	et	3	main
kohal	doc_801781988534_item	2880503	et	4	main
ripub	doc_801781988534_item	2880504	et	3	main
maal	doc_801781988534_item	2880505	et	4	main
põrandal	doc_801781988534_item	2880506	et	3	main
akna	doc_801781988534_item	2880510	et	3	main
valge	doc_801781988534_item	2880513	et	4	main
number	doc_801781988534_item	2880194	et	3	main
ma	doc_801781988534_item	2880197	et	3	main
ripuvad	doc_801781988534_item	2880283	et	3	main
vasakul	doc_801781988534_item	2880286	et	4	main
seina	doc_801781988534_item	2880295	et	4	main
vorst	doc_801781988534_item	2880306	et	3	main
kõrval	doc_801781988534_item	2880311	et	4	main
seina	doc_801781988534_item	2880312	et	4	main
sahtel	doc_801781988534_item	2880320	et	3	main
ahtelis	doc_801781988534_item	2880321	et	4	main
dessertlusikad	doc_801781988534_item	2880324	et	4	main
teelusikad	doc_801781988534_item	2880325	et	3	main
noad	doc_801781988534_item	2880328	et	3	main
vasakul	doc_801781988534_item	2880335	et	4	main
valge	doc_801781988534_item	2880337	et	4	main
gaasipliit	doc_801781988534_item	2880338	et	3	main
valamu	doc_801781988534_item	2880344	et	4	main
kõrval	doc_801781988534_item	2880349	et	4	main
ripuvad	doc_801781988534_item	2880351	et	3	main
käterätik	doc_801781988534_item	2880356	et	3	main
all	doc_801781988534_item	2880358	et	3	main
seisab	doc_801781988534_item	2880359	et	3	main
valamu	doc_801781988534_item	2880363	et	4	main
kohal	doc_801781988534_item	2880364	et	4	main
seinal	doc_801781988534_item	2880365	et	3	main
ripub	doc_801781988534_item	2880366	et	3	main
on	doc_801781988534_item	2880369	et	4	main
vasakul	doc_801781988534_item	2880382	et	4	main
juures	doc_801781988534_item	2880384	et	4	main
ka	doc_801781988534_item	2880387	et	3	main
purgid	doc_801781988534_item	2880396	et	4	main
on	doc_801781988534_item	2880402	et	4	main
palju	doc_801781988534_item	2880403	et	4	main
köögipisiasjasid	doc_801781988534_item	2880404	et	3	main
köögikapil	doc_801781988534_item	2880405	et	3	main
on	doc_801781988534_item	2880406	et	4	main
mikrolaineahi	doc_801781988534_item	2880407	et	3	main
köögikapi	doc_801781988534_item	2880408	et	3	main
kohal	doc_801781988534_item	2880409	et	4	main
seinal	doc_801781988534_item	2880410	et	3	main
on	doc_801781988534_item	2880411	et	4	main
köögikapp	doc_801781988534_item	2880412	et	3	main
ka	doc_801781988534_item	2880413	et	3	main
köögikappi	doc_801781988534_item	2880414	et	4	main
riiutel	doc_801781988534_item	2880415	et	4	main
on	doc_801781988534_item	2880416	et	4	main
suhkrutoos	doc_801781988534_item	2880418	et	3	main
serviis	doc_801781988534_item	2880417	et	3	main
kommid	doc_801781988534_item	2880419	et	3	main
ja	doc_801781988534_item	2880420	et	3	main
juures	doc_801781988534_item	2880429	et	4	main
taburetti	doc_801781988534_item	2880432	et	4	main
on	doc_801781988534_item	2880443	et	4	main
ripplagi	doc_801781988534_item	2880444	et	3	main
aknalaual	doc_801781988534_item	2880445	et	3	main
seisavad	doc_801781988534_item	2880446	et	3	main
toalilled	doc_801781988534_item	2880447	et	3	main
aga	doc_801781988534_item	2880451	et	3	main
serviisid	doc_801781988534_item	2880462	et	3	main
sektsioonkapi	doc_801781988534_item	2880467	et	4	main
seina	doc_801781988534_item	2880469	et	4	main
juures	doc_801781988534_item	2880470	et	4	main
seisab	doc_801781988534_item	2880471	et	3	main
pruun	doc_801781988534_item	2880472	et	3	main
juures	doc_801781988534_item	2880296	et	4	main
seisab	doc_801781988534_item	2880297	et	3	main
juures	doc_801781988534_item	2880313	et	4	main
on	doc_801781988534_item	2880322	et	4	main
supilusikad	doc_801781988534_item	2880323	et	3	main
ja	doc_801781988534_item	2880327	et	3	main
on	doc_801781988534_item	2880330	et	4	main
potid	doc_801781988534_item	2880331	et	4	main
ja	doc_801781988534_item	2880332	et	3	main
pannid	doc_801781988534_item	2880333	et	3	main
on	doc_801781988534_item	2880342	et	4	main
valamu	doc_801781988534_item	2880343	et	4	main
on	doc_801781988534_item	2880346	et	4	main
nõudepesuvahendid	doc_801781988534_item	2880347	et	3	main
ja	doc_801781988534_item	2880355	et	3	main
köögikapp	doc_801781988534_item	2880367	et	3	main
riiulid	doc_801781988534_item	2880370	et	3	main
tassid	doc_801781988534_item	2880376	et	4	main
alustassid	doc_801781988534_item	2880377	et	3	main
magustoidutaldrikud	doc_801781988534_item	2880378	et	3	main
ja	doc_801781988534_item	2880379	et	3	main
praetaldrikud	doc_801781988534_item	2880380	et	3	main
seisab	doc_801781988534_item	2880385	et	3	main
riulid	doc_801781988534_item	2880390	et	4	main
on	doc_801781988534_item	2880395	et	4	main
kruupidega	doc_801781988534_item	2880397	et	3	main
mikser	doc_801781988534_item	2880399	et	3	main
sahtlites	doc_801781988534_item	2880401	et	3	main
köögikapp	doc_801781988534_item	2880386	et	3	main
on	doc_801781988534_item	2880389	et	4	main
ja	doc_801781988534_item	2880391	et	3	main
kaks	doc_801781988534_item	2880392	et	3	main
sahtlit	doc_801781988534_item	2880393	et	3	main
küpsised	doc_801781988534_item	2880421	et	3	main
köögikapi	doc_801781988534_item	2880422	et	3	main
ees	doc_801781988534_item	2880423	et	4	main
akna	doc_801781988534_item	2880424	et	3	main
köögiakna	doc_801781988534_item	2880438	et	3	main
elutuba	doc_801781988534_item	2880448	et	4	main
on	doc_801781988534_item	2880449	et	4	main
seina	doc_801781988534_item	2880455	et	4	main
on	doc_801781988534_item	2880461	et	4	main
teler	doc_801781988534_item	2880464	et	3	main
nurgadiivan	doc_801781988534_item	2880473	et	3	main
tugitool	doc_801781988534_item	2880477	et	3	main
beez	doc_801781988534_item	2880508	et	4	main
vannituba	doc_801781988534_item	2880524	et	4	main
on	doc_801781988534_item	2880525	et	4	main
uksest	doc_801781988534_item	2880528	et	4	main
paremal	doc_801781988534_item	2880529	et	4	main
nurgas	doc_801781988534_item	2880530	et	3	main
seisab	doc_801781988534_item	2880531	et	3	main
pesumasin	doc_801781988534_item	2880532	et	3	main
uksest	doc_801781988534_item	2880533	et	4	main
kohal	doc_801781988534_item	2880543	et	4	main
seinal	doc_801781988534_item	2880544	et	3	main
riiul	doc_801781988534_item	2880546	et	4	main
paremal	doc_801781988534_item	2880556	et	4	main
peegel	doc_801781988534_item	2880558	et	3	main
all	doc_801781988534_item	2880560	et	3	main
kraanikaus	doc_801781988534_item	2880562	et	4	main
ukse	doc_801781988534_item	2880563	et	3	main
vastas	doc_801781988534_item	2880564	et	4	main
vann	doc_801781988534_item	2880568	et	3	main
wc	doc_801781988534_item	2880571	et	4	main
on	doc_801781988534_item	2880590	et	4	main
riietus	doc_801781988534_item	2880599	et	4	main
on	doc_801781988534_item	2880602	et	4	main
ees	doc_801781988534_item	2880606	et	4	main
on	doc_801781988534_item	2880607	et	4	main
kitsas	doc_801781988534_item	2880616	et	4	main
päikesepoolne	doc_801781988534_item	2880619	et	3	main
kohal	doc_801781988534_item	2880633	et	4	main
ripub	doc_801781988534_item	2880634	et	3	main
peegel	doc_801781988534_item	2880635	et	3	main
akna	doc_801781988534_item	2880636	et	3	main
ees	doc_801781988534_item	2880637	et	4	main
ei	doc_801781988534_item	2880651	et	4	main
gaasi	doc_801781988534_item	2880661	et	4	main
on	doc_801781988534_item	2880669	et	4	main
kodu	doc_801781988535_item	2880673	et	4	main
ma	doc_801781988535_item	2880674	et	3	main
linnas	doc_801781988535_item	2880682	et	4	main
ma	doc_801781988535_item	2880683	et	3	main
piirilinnas	doc_801781988535_item	2880685	et	4	main
linn	doc_801781988535_item	2880687	et	3	main
on	doc_801781988535_item	2880705	et	4	main
neli	doc_801781988535_item	2880707	et	3	main
kivimaja	doc_801781988535_item	2880717	et	4	main
palju	doc_801781988535_item	2880718	et	4	main
põõsad	doc_801781988535_item	2880724	et	3	main
viiekoruselises	doc_801781988535_item	2880728	et	4	main
majas	doc_801781988535_item	2880729	et	3	main
viiendal	doc_801781988535_item	2880730	et	3	main
korrusel	doc_801781988535_item	2880731	et	3	main
kolmetoalises	doc_801781988535_item	2880732	et	4	main
korteris	doc_801781988535_item	2880733	et	3	main
see	doc_801781988535_item	2880734	et	3	main
magamistuba	doc_801781988535_item	2880748	et	4	main
köök	doc_801781988535_item	2880750	et	3	main
on	doc_801781988535_item	2880751	et	4	main
põhjapolne	doc_801781988535_item	2880752	et	4	main
aga	doc_801781988535_item	2880753	et	3	main
teine	doc_801781988535_item	2880754	et	3	main
on	doc_801781988535_item	2880758	et	4	main
tualett	doc_801781988535_item	2880762	et	3	main
vanituba	doc_801781988535_item	2880764	et	4	main
majas	doc_801781988535_item	2880768	et	3	main
majas	doc_801781988535_item	2880773	et	3	main
ja	doc_801781988535_item	2880777	et	3	main
seina	doc_801781988534_item	2880480	et	4	main
seisab	doc_801781988534_item	2880482	et	3	main
seisukapp	doc_801781988534_item	2880483	et	3	main
seisukapis	doc_801781988534_item	2880484	et	3	main
voodipesu	doc_801781988534_item	2880493	et	4	main
on	doc_801781988534_item	2880495	et	4	main
seisukapil	doc_801781988534_item	2880497	et	3	main
vaip	doc_801781988534_item	2880509	et	3	main
ja	doc_801781988534_item	2880515	et	3	main
vasakul	doc_801781988534_item	2880475	et	4	main
elutoauksest	doc_801781988534_item	2880478	et	4	main
juures	doc_801781988534_item	2880481	et	4	main
on	doc_801781988534_item	2880485	et	4	main
riiulid	doc_801781988534_item	2880486	et	3	main
ja	doc_801781988534_item	2880487	et	3	main
sahtel	doc_801781988534_item	2880488	et	3	main
on	doc_801781988534_item	2880490	et	4	main
käterätikud	doc_801781988534_item	2880491	et	3	main
on	doc_801781988534_item	2880507	et	4	main
ees	doc_801781988534_item	2880511	et	4	main
eraldi	doc_801781988534_item	2880526	et	4	main
pesukorvi	doc_801781988534_item	2880538	et	4	main
ripub	doc_801781988534_item	2880545	et	3	main
on	doc_801781988534_item	2880548	et	4	main
hambapastad	doc_801781988534_item	2880551	et	3	main
on	doc_801781988534_item	2880561	et	4	main
seisab	doc_801781988534_item	2880582	et	3	main
uksest	doc_801781988534_item	2880592	et	4	main
paremal	doc_801781988534_item	2880593	et	4	main
riidekapp	doc_801781988534_item	2880595	et	3	main
riidekapis	doc_801781988534_item	2880596	et	3	main
on	doc_801781988534_item	2880597	et	4	main
minu	doc_801781988534_item	2880598	et	3	main
külgkardinad	doc_801781988534_item	2880609	et	4	main
aknalaual	doc_801781988534_item	2880610	et	3	main
seisavad	doc_801781988534_item	2880611	et	3	main
toalilled	doc_801781988534_item	2880612	et	3	main
seisab	doc_801781988534_item	2880622	et	3	main
riidekapi	doc_801781988534_item	2880624	et	3	main
voodi	doc_801781988534_item	2880627	et	4	main
akna	doc_801781988534_item	2880628	et	3	main
juures	doc_801781988534_item	2880629	et	4	main
seisab	doc_801781988534_item	2880630	et	3	main
seisukapp	doc_801781988534_item	2880631	et	3	main
seisukapi	doc_801781988534_item	2880632	et	3	main
on	doc_801781988534_item	2880638	et	4	main
ma	doc_801781988534_item	2880644	et	3	main
olnud	doc_801781988534_item	2880652	et	4	main
kuuma	doc_801781988534_item	2880653	et	4	main
vett	doc_801781988534_item	2880654	et	3	main
korteris	doc_801781988534_item	2880655	et	3	main
on	doc_801781988534_item	2880656	et	4	main
gaasimõõturid	doc_801781988534_item	2880658	et	3	main
vee	doc_801781988534_item	2880660	et	3	main
elektri	doc_801781988534_item	2880662	et	3	main
erastatud	doc_801781988534_item	2880670	et	4	main
viru	doc_801781988535_item	2880679	et	4	main
kaksteist	doc_801781988535_item	2880701	et	4	main
kolmkümmend	doc_801781988535_item	2880706	et	4	main
lähedal	doc_801781988535_item	2880710	et	4	main
raudtee	doc_801781988535_item	2880712	et	4	main
lasteaeda	doc_801781988535_item	2880714	et	4	main
pank	doc_801781988535_item	2880715	et	3	main
kasvavad	doc_801781988535_item	2880720	et	4	main
on	doc_801781988534_item	2880512	et	4	main
tüllkardin	doc_801781988534_item	2880514	et	3	main
vasakul	doc_801781988534_item	2880534	et	4	main
nurgas	doc_801781988534_item	2880535	et	3	main
seisab	doc_801781988534_item	2880536	et	3	main
pesukorv	doc_801781988534_item	2880537	et	3	main
riiulil	doc_801781988534_item	2880547	et	3	main
seebid	doc_801781988534_item	2880549	et	3	main
seina	doc_801781988534_item	2880565	et	4	main
juures	doc_801781988534_item	2880566	et	4	main
seisab	doc_801781988534_item	2880567	et	3	main
on	doc_801781988534_item	2880570	et	4	main
minu	doc_801781988534_item	2880573	et	3	main
arvuti	doc_801781988534_item	2880591	et	4	main
ukse	doc_801781988534_item	2880600	et	3	main
uks	doc_801781988534_item	2880603	et	3	main
akna	doc_801781988534_item	2880605	et	3	main
magamistuba	doc_801781988534_item	2880614	et	4	main
aga	doc_801781988534_item	2880618	et	3	main
paremal	doc_801781988534_item	2880621	et	4	main
pruunid	doc_801781988534_item	2880639	et	3	main
külgkardinad	doc_801781988534_item	2880640	et	4	main
toalilled	doc_801781988534_item	2880643	et	3	main
kõigi	doc_801781988534_item	2880646	et	4	main
mugavustega	doc_801781988534_item	2880647	et	4	main
korteris	doc_801781988534_item	2880648	et	3	main
aga	doc_801781988534_item	2880649	et	3	main
juunis	doc_801781988534_item	2880650	et	3	main
minu	doc_801781988535_item	2880672	et	3	main
elan	doc_801781988535_item	2880675	et	3	main
vabarrigis	doc_801781988535_item	2880677	et	4	main
ida	doc_801781988535_item	2880678	et	4	main
narva	doc_801781988535_item	2880681	et	4	main
minu	doc_801781988535_item	2880686	et	3	main
on	doc_801781988535_item	2880688	et	4	main
elan	doc_801781988535_item	2880696	et	3	main
tänav	doc_801781988535_item	2880698	et	4	main
number	doc_801781988535_item	2880700	et	3	main
korteri	doc_801781988535_item	2880703	et	3	main
maja	doc_801781988535_item	2880709	et	4	main
erinavad	doc_801781988535_item	2880721	et	4	main
puud	doc_801781988535_item	2880722	et	4	main
on	doc_801781988535_item	2880727	et	4	main
korteris	doc_801781988535_item	2880737	et	3	main
magamistuba	doc_801781988535_item	2880740	et	4	main
üks	doc_801781988535_item	2880741	et	3	main
elutuba	doc_801781988535_item	2880742	et	4	main
köök	doc_801781988535_item	2880743	et	3	main
esik	doc_801781988535_item	2880744	et	3	main
vanituba	doc_801781988535_item	2880745	et	4	main
ja	doc_801781988535_item	2880746	et	3	main
tualett	doc_801781988535_item	2880747	et	3	main
korteris	doc_801781988535_item	2880761	et	3	main
on	doc_801781988535_item	2880765	et	4	main
ole	doc_801781988535_item	2880770	et	4	main
minu	doc_801781988535_item	2880772	et	3	main
keskküte	doc_801781988535_item	2880775	et	3	main
meil	doc_801781988535_item	2880781	et	4	main
põrandal	doc_801781988535_item	2880786	et	3	main
on	doc_801781988535_item	2880793	et	4	main
köögis	doc_801781988535_item	2880823	et	3	main
on	doc_801781988535_item	2880826	et	4	main
tuba	doc_801781988535_item	2880834	et	4	main
ja	doc_801781988535_item	2880842	et	3	main
hell	doc_801781988535_item	2880843	et	3	main
seina	doc_801781988535_item	2880846	et	4	main
diivanilaud	doc_801781988535_item	2880855	et	4	main
arvuti	doc_801781988535_item	2880873	et	4	main
arvitilauale	doc_801781988535_item	2880875	et	4	main
ees	doc_801781988535_item	2880880	et	4	main
sektsioonikapp	doc_801781988535_item	2880889	et	4	main
sektsioonikappis	doc_801781988535_item	2880890	et	4	main
on	doc_801781988535_item	2880891	et	4	main
ja	doc_801781988535_item	2880898	et	3	main
vasamul	doc_801781988535_item	2880918	et	4	main
külgkardinad	doc_801781988534_item	2880516	et	4	main
aknalaual	doc_801781988534_item	2880517	et	3	main
seisavad	doc_801781988534_item	2880518	et	3	main
toalilled	doc_801781988534_item	2880519	et	3	main
minu	doc_801781988534_item	2880520	et	3	main
korteris	doc_801781988534_item	2880521	et	3	main
tualett	doc_801781988534_item	2880522	et	3	main
ja	doc_801781988534_item	2880523	et	3	main
vannitoas	doc_801781988534_item	2880527	et	3	main
kohal	doc_801781988534_item	2880539	et	4	main
ripub	doc_801781988534_item	2880540	et	3	main
käterätik	doc_801781988534_item	2880541	et	3	main
käterätiku	doc_801781988534_item	2880542	et	3	main
hambaharjad	doc_801781988534_item	2880550	et	3	main
sampunid	doc_801781988534_item	2880552	et	4	main
balsamid	doc_801781988534_item	2880553	et	4	main
nuustikud	doc_801781988534_item	2880554	et	3	main
riiulist	doc_801781988534_item	2880555	et	4	main
ripub	doc_801781988534_item	2880557	et	3	main
peegli	doc_801781988534_item	2880559	et	3	main
tualetis	doc_801781988534_item	2880569	et	3	main
paber	doc_801781988534_item	2880572	et	3	main
magamistuba	doc_801781988534_item	2880574	et	4	main
kitsas	doc_801781988534_item	2880576	et	4	main
uksest	doc_801781988534_item	2880579	et	4	main
vasakul	doc_801781988534_item	2880580	et	4	main
nurgas	doc_801781988534_item	2880581	et	3	main
voodi	doc_801781988534_item	2880584	et	4	main
rohelised	doc_801781988534_item	2880608	et	4	main
on	doc_801781988534_item	2880615	et	4	main
ka	doc_801781988534_item	2880617	et	3	main
uksest	doc_801781988534_item	2880620	et	4	main
riidekapp	doc_801781988534_item	2880623	et	3	main
vastas	doc_801781988534_item	2880625	et	4	main
seisab	doc_801781988534_item	2880626	et	3	main
aknalaual	doc_801781988534_item	2880641	et	3	main
seisavad	doc_801781988534_item	2880642	et	3	main
elan	doc_801781988534_item	2880645	et	3	main
veemõõturid	doc_801781988534_item	2880657	et	3	main
elektrimõõturid	doc_801781988534_item	2880659	et	3	main
ees	doc_801781988534_item	2880663	et	4	main
ma	doc_801781988534_item	2880664	et	3	main
maksan	doc_801781988534_item	2880665	et	3	main
mõõturite	doc_801781988534_item	2880666	et	3	main
jargi	doc_801781988534_item	2880667	et	4	main
korter	doc_801781988534_item	2880668	et	3	main
essee	doc_801781988535_item	2880671	et	4	main
eesti	doc_801781988535_item	2880676	et	4	main
maakonnas	doc_801781988535_item	2880680	et	4	main
elan	doc_801781988535_item	2880684	et	3	main
ma	doc_801781988535_item	2880695	et	3	main
maja	doc_801781988535_item	2880699	et	4	main
ja	doc_801781988535_item	2880702	et	3	main
number	doc_801781988535_item	2880704	et	3	main
minu	doc_801781988535_item	2880708	et	3	main
asuvad	doc_801781988535_item	2880711	et	4	main
kaks	doc_801781988535_item	2880713	et	3	main
rohelust	doc_801781988535_item	2880719	et	4	main
ja	doc_801781988535_item	2880723	et	3	main
elan	doc_801781988535_item	2880726	et	3	main
kivimaja	doc_801781988535_item	2880736	et	4	main
kaks	doc_801781988535_item	2880739	et	3	main
ja	doc_801781988535_item	2880749	et	3	main
elutuba	doc_801781988535_item	2880757	et	4	main
minu	doc_801781988535_item	2880760	et	3	main
eraldi	doc_801781988535_item	2880766	et	4	main
ei	doc_801781988535_item	2880769	et	4	main
külm	doc_801781988535_item	2880776	et	3	main
vesi	doc_801781988535_item	2880779	et	4	main
ja	doc_801781988535_item	2880784	et	3	main
seinal	doc_801781988535_item	2880792	et	3	main
on	doc_801781988535_item	2880821	et	4	main
ja	doc_801781988535_item	2880824	et	3	main
on	doc_801781988535_item	2880831	et	4	main
on	doc_801781988535_item	2880835	et	4	main
siin	doc_801781988535_item	2880838	et	4	main
alati	doc_801781988535_item	2880840	et	4	main
ukse	doc_801781988535_item	2880845	et	3	main
diivan	doc_801781988535_item	2880848	et	3	main
paremal	doc_801781988535_item	2880850	et	4	main
ja	doc_801781988535_item	2880858	et	3	main
juures	doc_801781988535_item	2880862	et	4	main
on	doc_801781988534_item	2880575	et	4	main
aga	doc_801781988534_item	2880577	et	3	main
hubane	doc_801781988534_item	2880578	et	3	main
voodi	doc_801781988534_item	2880583	et	4	main
taga	doc_801781988534_item	2880585	et	4	main
nurgas	doc_801781988534_item	2880586	et	3	main
seisab	doc_801781988534_item	2880587	et	3	main
arvutilaud	doc_801781988534_item	2880588	et	4	main
laual	doc_801781988534_item	2880589	et	3	main
seisab	doc_801781988534_item	2880594	et	3	main
vastas	doc_801781988534_item	2880601	et	4	main
rõdule	doc_801781988534_item	2880604	et	3	main
teine	doc_801781988534_item	2880613	et	3	main
väga	doc_801781988535_item	2880689	et	3	main
ilus	doc_801781988535_item	2880690	et	4	main
veel	doc_801781988535_item	2880691	et	4	main
minu	doc_801781988535_item	2880692	et	3	main
linn	doc_801781988535_item	2880693	et	3	main
tööstuslinn	doc_801781988535_item	2880694	et	3	main
maakri	doc_801781988535_item	2880697	et	3	main
palju	doc_801781988535_item	2880716	et	4	main
ma	doc_801781988535_item	2880725	et	3	main
on	doc_801781988535_item	2880735	et	4	main
on	doc_801781988535_item	2880738	et	4	main
magamistuba	doc_801781988535_item	2880755	et	4	main
ja	doc_801781988535_item	2880756	et	3	main
päikesepoolne	doc_801781988535_item	2880759	et	3	main
ja	doc_801781988535_item	2880763	et	3	main
meie	doc_801781988535_item	2880767	et	4	main
lift	doc_801781988535_item	2880771	et	3	main
on	doc_801781988535_item	2880774	et	4	main
on	doc_801781988535_item	2880782	et	4	main
pime	doc_801781988535_item	2880785	et	3	main
paremal	doc_801781988535_item	2880791	et	4	main
väike	doc_801781988535_item	2880796	et	4	main
korb	doc_801781988535_item	2880797	et	4	main
jalatside	doc_801781988535_item	2880798	et	4	main
jaoks	doc_801781988535_item	2880799	et	4	main
paremal	doc_801781988535_item	2880800	et	4	main
seina	doc_801781988535_item	2880801	et	4	main
juures	doc_801781988535_item	2880802	et	4	main
on	doc_801781988535_item	2880803	et	4	main
peegel	doc_801781988535_item	2880804	et	3	main
veel	doc_801781988535_item	2880805	et	4	main
meie	doc_801781988535_item	2880806	et	4	main
korteris	doc_801781988535_item	2880807	et	3	main
paremal	doc_801781988535_item	2880808	et	4	main
on	doc_801781988535_item	2880809	et	4	main
uks	doc_801781988535_item	2880810	et	3	main
vastas	doc_801781988535_item	2880812	et	4	main
elutoas	doc_801781988535_item	2880811	et	3	main
uks	doc_801781988535_item	2880815	et	3	main
on	doc_801781988535_item	2880814	et	4	main
välisukse	doc_801781988535_item	2880813	et	4	main
teises	doc_801781988535_item	2880816	et	4	main
ja	doc_801781988535_item	2880818	et	3	main
vastas	doc_801781988535_item	2880819	et	4	main
magamistoas	doc_801781988535_item	2880817	et	3	main
elutuba	doc_801781988535_item	2880820	et	4	main
uks	doc_801781988535_item	2880822	et	3	main
vasamul	doc_801781988535_item	2880825	et	4	main
vanitoas	doc_801781988535_item	2880828	et	4	main
suur	doc_801781988535_item	2880832	et	3	main
päikesepoolne	doc_801781988535_item	2880836	et	3	main
soe	doc_801781988535_item	2880841	et	4	main
vasamul	doc_801781988535_item	2880844	et	4	main
aga	doc_801781988535_item	2880849	et	3	main
on	doc_801781988535_item	2880851	et	4	main
ja	doc_801781988535_item	2880854	et	3	main
diivanilauale	doc_801781988535_item	2880856	et	4	main
veel	doc_801781988535_item	2880860	et	4	main
esik	doc_801781988535_item	2880780	et	3	main
väike	doc_801781988535_item	2880783	et	4	main
punane	doc_801781988535_item	2880788	et	4	main
valisuksest	doc_801781988535_item	2880790	et	4	main
nagi	doc_801781988535_item	2880794	et	4	main
soe	doc_801781988535_item	2880778	et	4	main
on	doc_801781988535_item	2880787	et	4	main
vaip	doc_801781988535_item	2880789	et	3	main
ja	doc_801781988535_item	2880795	et	3	main
uks	doc_801781988535_item	2880827	et	3	main
meie	doc_801781988535_item	2880829	et	4	main
elutuba	doc_801781988535_item	2880830	et	4	main
see	doc_801781988535_item	2880833	et	3	main
ja	doc_801781988535_item	2880837	et	3	main
on	doc_801781988535_item	2880839	et	4	main
juures	doc_801781988535_item	2880847	et	4	main
telefon	doc_801781988535_item	2880857	et	3	main
paremal	doc_801781988535_item	2880863	et	4	main
plaadid	doc_801781988535_item	2880878	et	4	main
kõrval	doc_801781988535_item	2880886	et	4	main
on	doc_801781988535_item	2880888	et	4	main
sektsioonikapis	doc_801781988535_item	2880894	et	4	main
raamatud	doc_801781988535_item	2880896	et	4	main
laelamp	doc_801781988535_item	2880903	et	3	main
vaip	doc_801781988535_item	2880908	et	3	main
on	doc_801781988535_item	2880910	et	4	main
magamistoas	doc_801781988535_item	2880913	et	3	main
riidekapiga	doc_801781988535_item	2880919	et	3	main
voodi	doc_801781988535_item	2880923	et	4	main
korbile	doc_801781988535_item	2880929	et	4	main
on	doc_801781988535_item	2880930	et	4	main
valge	doc_801781988535_item	2880935	et	4	main
roheline	doc_801781988535_item	2880951	et	4	main
vaip	doc_801781988535_item	2880952	et	3	main
peale	doc_801781988535_item	2880954	et	4	main
laelamp	doc_801781988535_item	2880956	et	3	main
vaas	doc_801781988535_item	2880959	et	3	main
lilled	doc_801781988535_item	2880962	et	3	main
asuvad	doc_801781988535_item	2880965	et	4	main
suur	doc_801781988535_item	2880966	et	3	main
uksest	doc_801781988535_item	2880968	et	4	main
teises	doc_801781988535_item	2880973	et	4	main
ukse	doc_801781988535_item	2880976	et	3	main
divvanvoodi	doc_801781988535_item	2880978	et	4	main
kohal	doc_801781988535_item	2880980	et	4	main
seinal	doc_801781988535_item	2880981	et	3	main
on	doc_801781988535_item	2880982	et	4	main
pruuni	doc_801781988535_item	2880993	et	4	main
riidekapiga	doc_801781988535_item	2880996	et	3	main
kirjelaud	doc_801781988535_item	2880998	et	4	main
kirjelauale	doc_801781988535_item	2880999	et	4	main
seinal	doc_801781988535_item	2881003	et	3	main
veel	doc_801781988535_item	2881022	et	4	main
ilus	doc_801781988535_item	2881025	et	4	main
tume	doc_801781988535_item	2881029	et	3	main
väike	doc_801781988535_item	2881031	et	4	main
vannitoas	doc_801781988535_item	2881036	et	3	main
seinad	doc_801781988535_item	2881037	et	3	main
valamu	doc_801781988535_item	2881048	et	4	main
on	doc_801781988535_item	2881055	et	4	main
ja	doc_801781988535_item	2881061	et	3	main
juures	doc_801781988535_item	2881065	et	4	main
pesumasina	doc_801781988535_item	2881068	et	3	main
juures	doc_801781988535_item	2881074	et	4	main
vann	doc_801781988535_item	2881076	et	3	main
sinine	doc_801781988535_item	2881082	et	4	main
vannitoas	doc_801781988535_item	2881089	et	3	main
laeni	doc_801781988535_item	2881101	et	4	main
on	doc_801781988535_item	2881103	et	4	main
siin	doc_801781988535_item	2881106	et	4	main
ripub	doc_801781988535_item	2881107	et	3	main
seinalamp	doc_801781988535_item	2881108	et	3	main
on	doc_801781988535_item	2881123	et	4	main
pimm	doc_801781988535_item	2881132	et	3	main
puuviljad	doc_801781988535_item	2881134	et	3	main
joogurt	doc_801781988535_item	2881136	et	4	main
ja	doc_801781988535_item	2881138	et	3	main
ees	doc_801781988535_item	2881151	et	4	main
vasamul	doc_801781988535_item	2881159	et	4	main
köögikapis	doc_801781988535_item	2881164	et	3	main
pannig	doc_801781988535_item	2881167	et	4	main
köödikombain	doc_801781988535_item	2881169	et	4	main
hakklihamasin	doc_801781988535_item	2881174	et	3	main
seina	doc_801781988535_item	2881177	et	4	main
kotlettid	doc_801781988535_item	2881201	et	4	main
valamu	doc_801781988535_item	2881211	et	4	main
on	doc_801781988535_item	2881213	et	4	main
kaks	doc_801781988535_item	2880852	et	3	main
tugitooli	doc_801781988535_item	2880853	et	4	main
ajalehed	doc_801781988535_item	2880859	et	3	main
akna	doc_801781988535_item	2880861	et	3	main
vasamul	doc_801781988535_item	2880867	et	4	main
arvitilaud	doc_801781988535_item	2880869	et	4	main
ja	doc_801781988535_item	2880870	et	3	main
arvutilauale	doc_801781988535_item	2880871	et	4	main
on	doc_801781988535_item	2880872	et	4	main
veel	doc_801781988535_item	2880874	et	4	main
akna	doc_801781988535_item	2880879	et	3	main
valge	doc_801781988535_item	2880882	et	4	main
ja	doc_801781988535_item	2880884	et	3	main
arvitilauaga	doc_801781988535_item	2880887	et	4	main
krustal	doc_801781988535_item	2880892	et	4	main
on	doc_801781988535_item	2880895	et	4	main
muusikakeskus	doc_801781988535_item	2880899	et	3	main
on	doc_801781988535_item	2880902	et	4	main
on	doc_801781988535_item	2880905	et	4	main
suur	doc_801781988535_item	2880906	et	3	main
pruuni	doc_801781988535_item	2880907	et	4	main
suur	doc_801781988535_item	2880922	et	3	main
kõrval	doc_801781988535_item	2880924	et	4	main
voodiga	doc_801781988535_item	2880925	et	3	main
on	doc_801781988535_item	2880926	et	4	main
suur	doc_801781988535_item	2880927	et	3	main
televiisor	doc_801781988535_item	2880931	et	3	main
akna	doc_801781988535_item	2880932	et	3	main
ees	doc_801781988535_item	2880933	et	4	main
tüllkardin	doc_801781988535_item	2880936	et	3	main
aknale	doc_801781988535_item	2880937	et	3	main
juures	doc_801781988535_item	2880942	et	4	main
laud	doc_801781988535_item	2880948	et	4	main
põrendal	doc_801781988535_item	2880949	et	4	main
on	doc_801781988535_item	2880950	et	4	main
on	doc_801781988535_item	2880958	et	4	main
seinale	doc_801781988535_item	2880964	et	3	main
paremal	doc_801781988535_item	2880969	et	4	main
on	doc_801781988535_item	2880970	et	4	main
suur	doc_801781988535_item	2880971	et	3	main
peegel	doc_801781988535_item	2880972	et	3	main
paremal	doc_801781988535_item	2880975	et	4	main
seinalampi	doc_801781988535_item	2880983	et	4	main
veel	doc_801781988535_item	2880987	et	4	main
seina	doc_801781988535_item	2880989	et	4	main
kalender	doc_801781988535_item	2881007	et	3	main
akna	doc_801781988535_item	2881008	et	3	main
ees	doc_801781988535_item	2881009	et	4	main
on	doc_801781988535_item	2881010	et	4	main
tüll	doc_801781988535_item	2881012	et	3	main
ja	doc_801781988535_item	2881013	et	3	main
kardin	doc_801781988535_item	2881014	et	3	main
roos	doc_801781988535_item	2881011	et	4	main
vasamul	doc_801781988535_item	2881015	et	4	main
seina	doc_801781988535_item	2881016	et	4	main
juures	doc_801781988535_item	2881017	et	4	main
ripub	doc_801781988535_item	2881018	et	3	main
suur	doc_801781988535_item	2881019	et	3	main
ummargene	doc_801781988535_item	2881020	et	4	main
toases	doc_801781988535_item	2881023	et	4	main
on	doc_801781988535_item	2881028	et	4	main
vaip	doc_801781988535_item	2881032	et	3	main
vastas	doc_801781988535_item	2881044	et	4	main
juures	doc_801781988535_item	2881046	et	4	main
kohal	doc_801781988535_item	2881050	et	4	main
hambaharjad	doc_801781988535_item	2881057	et	3	main
hambapasta	doc_801781988535_item	2881060	et	4	main
seina	doc_801781988535_item	2881064	et	4	main
on	doc_801781988535_item	2880864	et	4	main
aga	doc_801781988535_item	2880866	et	3	main
cd	doc_801781988535_item	2880877	et	4	main
kardin	doc_801781988535_item	2880885	et	3	main
veel	doc_801781988535_item	2880893	et	4	main
nõud	doc_801781988535_item	2880897	et	3	main
lae	doc_801781988535_item	2880900	et	4	main
põrandal	doc_801781988535_item	2880904	et	3	main
nüüd	doc_801781988535_item	2880909	et	4	main
magamistoas	doc_801781988535_item	2880911	et	3	main
vasamul	doc_801781988535_item	2880914	et	4	main
on	doc_801781988535_item	2880915	et	4	main
suur	doc_801781988535_item	2880916	et	3	main
riidekapp	doc_801781988535_item	2880917	et	3	main
juures	doc_801781988535_item	2880920	et	4	main
on	doc_801781988535_item	2880921	et	4	main
asuvad	doc_801781988535_item	2880938	et	4	main
lilled	doc_801781988535_item	2880939	et	3	main
paremal	doc_801781988535_item	2880940	et	4	main
seine	doc_801781988535_item	2880941	et	3	main
kaks	doc_801781988535_item	2880944	et	3	main
üks	doc_801781988535_item	2880947	et	3	main
lae	doc_801781988535_item	2880953	et	4	main
on	doc_801781988535_item	2880955	et	4	main
ja	doc_801781988535_item	2880960	et	3	main
vaasis	doc_801781988535_item	2880961	et	3	main
kellad	doc_801781988535_item	2880967	et	4	main
ja	doc_801781988535_item	2880984	et	3	main
juures	doc_801781988535_item	2880990	et	4	main
riidekapp	doc_801781988535_item	2880994	et	3	main
raamaturiiulid	doc_801781988535_item	2881005	et	3	main
ripub	doc_801781988535_item	2881024	et	3	main
laelamp	doc_801781988535_item	2881026	et	3	main
põrendal	doc_801781988535_item	2881027	et	4	main
punane	doc_801781988535_item	2881030	et	4	main
siin	doc_801781988535_item	2881033	et	4	main
on	doc_801781988535_item	2881034	et	4	main
laeni	doc_801781988535_item	2881042	et	4	main
ukse	doc_801781988535_item	2881043	et	3	main
valamu	doc_801781988535_item	2881049	et	4	main
on	doc_801781988535_item	2881051	et	4	main
peegel	doc_801781988535_item	2881052	et	3	main
riiuliga	doc_801781988535_item	2881053	et	4	main
riiulil	doc_801781988535_item	2881054	et	3	main
šampoon	doc_801781988535_item	2881058	et	2	main
nuustikud	doc_801781988535_item	2881062	et	3	main
kohal	doc_801781988535_item	2881069	et	4	main
ripub	doc_801781988535_item	2881070	et	3	main
paremal	doc_801781988535_item	2881072	et	4	main
vasamul	doc_801781988535_item	2881078	et	4	main
põrandal	doc_801781988535_item	2881084	et	3	main
väike	doc_801781988535_item	2881086	et	4	main
roos	doc_801781988535_item	2881087	et	4	main
tualett	doc_801781988535_item	2881092	et	3	main
kahhelkiviga	doc_801781988535_item	2881099	et	3	main
televisor	doc_801781988535_item	2880865	et	4	main
on	doc_801781988535_item	2880868	et	4	main
on	doc_801781988535_item	2880876	et	4	main
on	doc_801781988535_item	2880881	et	4	main
tull	doc_801781988535_item	2880883	et	3	main
peale	doc_801781988535_item	2880901	et	4	main
esimeses	doc_801781988535_item	2880912	et	3	main
korb	doc_801781988535_item	2880928	et	4	main
on	doc_801781988535_item	2880934	et	4	main
on	doc_801781988535_item	2880943	et	4	main
tugitooli	doc_801781988535_item	2880945	et	4	main
ja	doc_801781988535_item	2880946	et	3	main
lauale	doc_801781988535_item	2880957	et	4	main
paremal	doc_801781988535_item	2880963	et	4	main
magamistoas	doc_801781988535_item	2880974	et	3	main
on	doc_801781988535_item	2880977	et	4	main
paremal	doc_801781988535_item	2880988	et	4	main
suur	doc_801781988535_item	2880992	et	3	main
kõrval	doc_801781988535_item	2880995	et	4	main
asub	doc_801781988535_item	2880997	et	3	main
on	doc_801781988535_item	2881000	et	4	main
laulamp	doc_801781988535_item	2881001	et	3	main
ja	doc_801781988535_item	2881006	et	3	main
diivanivoodi	doc_801781988535_item	2880979	et	4	main
üks	doc_801781988535_item	2880985	et	3	main
pild	doc_801781988535_item	2880986	et	3	main
seisab	doc_801781988535_item	2880991	et	3	main
ja	doc_801781988535_item	2881002	et	3	main
on	doc_801781988535_item	2881004	et	4	main
peegel	doc_801781988535_item	2881021	et	3	main
vannituba	doc_801781988535_item	2881035	et	4	main
on	doc_801781988535_item	2881038	et	4	main
kaetud	doc_801781988535_item	2881039	et	4	main
kahhelkiviga	doc_801781988535_item	2881040	et	3	main
maast	doc_801781988535_item	2881041	et	3	main
seina	doc_801781988535_item	2881045	et	4	main
on	doc_801781988535_item	2881047	et	4	main
seebid	doc_801781988535_item	2881056	et	3	main
balsam	doc_801781988535_item	2881059	et	4	main
vasamul	doc_801781988535_item	2881063	et	4	main
on	doc_801781988535_item	2881081	et	4	main
vannivaip	doc_801781988535_item	2881088	et	3	main
väike	doc_801781988535_item	2881094	et	4	main
maast	doc_801781988535_item	2881100	et	3	main
tualetis	doc_801781988535_item	2881102	et	3	main
põrandal	doc_801781988535_item	2881109	et	3	main
on	doc_801781988535_item	2881110	et	4	main
väga	doc_801781988535_item	2881111	et	3	main
väike	doc_801781988535_item	2881112	et	4	main
roos	doc_801781988535_item	2881113	et	4	main
vaip	doc_801781988535_item	2881114	et	3	main
ja	doc_801781988535_item	2881115	et	3	main
nüüd	doc_801781988535_item	2881116	et	4	main
on	doc_801781988535_item	2881117	et	4	main
köök	doc_801781988535_item	2881118	et	3	main
köögis	doc_801781988535_item	2881119	et	3	main
paremal	doc_801781988535_item	2881120	et	4	main
seina	doc_801781988535_item	2881121	et	4	main
juures	doc_801781988535_item	2881122	et	4	main
just	doc_801781988535_item	2881128	et	3	main
salatud	doc_801781988535_item	2881130	et	4	main
või	doc_801781988535_item	2881131	et	4	main
kohvikoor	doc_801781988535_item	2881133	et	4	main
sügavkülmikus	doc_801781988535_item	2881139	et	3	main
on	doc_801781988535_item	2881152	et	4	main
seina	doc_801781988535_item	2881160	et	4	main
köögikapp	doc_801781988535_item	2881163	et	3	main
potid	doc_801781988535_item	2881166	et	4	main
kohvimasin	doc_801781988535_item	2881168	et	3	main
mikser	doc_801781988535_item	2881171	et	3	main
köögikapi	doc_801781988535_item	2881175	et	3	main
on	doc_801781988535_item	2881179	et	4	main
valamu	doc_801781988535_item	2881224	et	4	main
on	doc_801781988535_item	2881230	et	4	main
köögikapid	doc_801781988535_item	2881231	et	3	main
on	doc_801781988535_item	2881238	et	4	main
nõud	doc_801781988535_item	2881239	et	3	main
kapis	doc_801781988535_item	2881247	et	3	main
kaks	doc_801781988535_item	2881266	et	3	main
salatikausid	doc_801781988535_item	2881268	et	3	main
sõel	doc_801781988535_item	2881273	et	3	main
teelusikad	doc_801781988535_item	2881277	et	3	main
kapis	doc_801781988535_item	2881280	et	3	main
koffee	doc_801781988535_item	2881284	et	4	main
laelamp	doc_801781988535_item	2881288	et	3	main
linoleumiga	doc_801781988535_item	2881292	et	3	main
väga	doc_801781988535_item	2881294	et	3	main
pärast	doc_801781988535_item	2881299	et	4	main
on	doc_801781988535_item	2881066	et	4	main
pesumasin	doc_801781988535_item	2881067	et	3	main
käterätikud	doc_801781988535_item	2881071	et	3	main
asub	doc_801781988535_item	2881075	et	3	main
pesukorv	doc_801781988535_item	2881083	et	3	main
on	doc_801781988535_item	2881085	et	4	main
ripub	doc_801781988535_item	2881090	et	3	main
kaetud	doc_801781988535_item	2881098	et	4	main
külmik	doc_801781988535_item	2881124	et	3	main
munad	doc_801781988535_item	2881129	et	3	main
kefir	doc_801781988535_item	2881135	et	4	main
šokolaad	doc_801781988535_item	2881137	et	2	main
juures	doc_801781988535_item	2881144	et	4	main
kardinad	doc_801781988535_item	2881153	et	4	main
ja	doc_801781988535_item	2881154	et	3	main
žaluzii	doc_801781988535_item	2881155	et	2	main
on	doc_801781988535_item	2881162	et	4	main
röster	doc_801781988535_item	2881170	et	3	main
ja	doc_801781988535_item	2881173	et	3	main
kõrvale	doc_801781988535_item	2881176	et	4	main
gaasiplit	doc_801781988535_item	2881180	et	4	main
gaasiplitil	doc_801781988535_item	2881181	et	4	main
on	doc_801781988535_item	2881182	et	4	main
kaks	doc_801781988535_item	2881183	et	3	main
potid	doc_801781988535_item	2881184	et	4	main
üks	doc_801781988535_item	2881185	et	3	main
pann	doc_801781988535_item	2881186	et	3	main
ja	doc_801781988535_item	2881187	et	3	main
kann	doc_801781988535_item	2881188	et	3	main
ühes	doc_801781988535_item	2881189	et	4	main
potis	doc_801781988535_item	2881190	et	4	main
on	doc_801781988535_item	2881191	et	4	main
supp	doc_801781988535_item	2881192	et	3	main
aga	doc_801781988535_item	2881193	et	3	main
teises	doc_801781988535_item	2881194	et	4	main
potis	doc_801781988535_item	2881195	et	4	main
on	doc_801781988535_item	2881196	et	4	main
kartul	doc_801781988535_item	2881197	et	3	main
püre	doc_801781988535_item	2881198	et	4	main
pannis	doc_801781988535_item	2881199	et	3	main
on	doc_801781988535_item	2881200	et	4	main
seina	doc_801781988535_item	2881073	et	4	main
dušiga	doc_801781988535_item	2881077	et	2	main
seina	doc_801781988535_item	2881079	et	4	main
juures	doc_801781988535_item	2881080	et	4	main
seinalamp	doc_801781988535_item	2881091	et	3	main
on	doc_801781988535_item	2881093	et	4	main
tualettis	doc_801781988535_item	2881095	et	4	main
seinad	doc_801781988535_item	2881096	et	3	main
on	doc_801781988535_item	2881097	et	4	main
wc	doc_801781988535_item	2881104	et	4	main
paber	doc_801781988535_item	2881105	et	3	main
külmkappis	doc_801781988535_item	2881125	et	4	main
asuvad	doc_801781988535_item	2881126	et	4	main
vorst	doc_801781988535_item	2881127	et	3	main
on	doc_801781988535_item	2881140	et	4	main
liha	doc_801781988535_item	2881141	et	4	main
paremal	doc_801781988535_item	2881142	et	4	main
akna	doc_801781988535_item	2881143	et	3	main
on	doc_801781988535_item	2881145	et	4	main
laud	doc_801781988535_item	2881146	et	4	main
ja	doc_801781988535_item	2881147	et	3	main
neli	doc_801781988535_item	2881148	et	3	main
taburetid	doc_801781988535_item	2881149	et	3	main
akna	doc_801781988535_item	2881150	et	3	main
aknal	doc_801781988535_item	2881156	et	3	main
on	doc_801781988535_item	2881157	et	4	main
lilled	doc_801781988535_item	2881158	et	3	main
juures	doc_801781988535_item	2881161	et	4	main
on	doc_801781988535_item	2881165	et	4	main
mahlapress	doc_801781988535_item	2881172	et	3	main
juures	doc_801781988535_item	2881178	et	4	main
sees	doc_801781988535_item	2881215	et	4	main
kappis	doc_801781988535_item	2881216	et	3	main
kapsad	doc_801781988535_item	2881219	et	4	main
porgand	doc_801781988535_item	2881222	et	3	main
kõrval	doc_801781988535_item	2881229	et	4	main
teisis	doc_801781988535_item	2881236	et	4	main
kapis	doc_801781988535_item	2881237	et	3	main
tassid	doc_801781988535_item	2881241	et	4	main
noad	doc_801781988535_item	2881243	et	3	main
lusikad	doc_801781988535_item	2881244	et	3	main
pitsid	doc_801781988535_item	2881254	et	3	main
kruusid	doc_801781988535_item	2881256	et	3	main
alustassid	doc_801781988535_item	2881257	et	3	main
serviis	doc_801781988535_item	2881260	et	3	main
kapis	doc_801781988535_item	2881262	et	3	main
suhkrutoosi	doc_801781988535_item	2881267	et	4	main
riiv	doc_801781988535_item	2881270	et	3	main
ja	doc_801781988535_item	2881274	et	3	main
on	doc_801781988535_item	2881281	et	4	main
on	doc_801781988535_item	2881287	et	4	main
kaetud	doc_801781988535_item	2881291	et	4	main
selle	doc_801781988535_item	2881298	et	4	main
et	doc_801781988535_item	2881300	et	3	main
kanas	doc_801781988535_item	2881203	et	3	main
vastas	doc_801781988535_item	2881207	et	4	main
on	doc_801781988535_item	2881208	et	4	main
ja	doc_801781988535_item	2881210	et	3	main
on	doc_801781988535_item	2881217	et	4	main
on	doc_801781988535_item	2881248	et	4	main
ka	doc_801781988535_item	2881249	et	3	main
nõud	doc_801781988535_item	2881250	et	3	main
magustoidu-	doc_801781988535_item	2881251	et	3	main
aga	doc_801781988535_item	2881202	et	3	main
on	doc_801781988535_item	2881204	et	4	main
tee	doc_801781988535_item	2881205	et	4	main
gaaspliiti	doc_801781988535_item	2881206	et	4	main
valamu	doc_801781988535_item	2881209	et	4	main
alla	doc_801781988535_item	2881212	et	3	main
kartul	doc_801781988535_item	2881218	et	3	main
sibul	doc_801781988535_item	2881220	et	3	main
ja	doc_801781988535_item	2881221	et	3	main
köögis	doc_801781988535_item	2881223	et	3	main
juures	doc_801781988535_item	2881225	et	4	main
on	doc_801781988535_item	2881226	et	4	main
nõudepesuvahend	doc_801781988535_item	2881227	et	3	main
valamu	doc_801781988535_item	2881228	et	4	main
kapis	doc_801781988535_item	2881233	et	3	main
on	doc_801781988535_item	2881234	et	4	main
toiduained	doc_801781988535_item	2881235	et	3	main
kahvlid	doc_801781988535_item	2881245	et	3	main
prae-	doc_801781988535_item	2881252	et	4	main
taldrikud	doc_801781988535_item	2881253	et	3	main
bokaalid	doc_801781988535_item	2881255	et	4	main
kolm	doc_801781988535_item	2881259	et	3	main
neljas	doc_801781988535_item	2881261	et	4	main
avaja	doc_801781988535_item	2881272	et	4	main
dessert-	doc_801781988535_item	2881276	et	3	main
viies	doc_801781988535_item	2881279	et	4	main
tee	doc_801781988535_item	2881282	et	4	main
peale	doc_801781988535_item	2881286	et	4	main
köögipõrand	doc_801781988535_item	2881289	et	3	main
ma	doc_801781988535_item	2881293	et	3	main
armastan	doc_801781988535_item	2881295	et	3	main
on	doc_801781988535_item	2881302	et	4	main
nimi	doc_802069853715_item	2881450	et	3	main
eesnimi	doc_802069853715_item	2881451	et	3	main
ma	doc_802069853715_item	2881452	et	3	main
olen	doc_802069853715_item	2881453	et	3	main
aastat	doc_802069853715_item	2881455	et	3	main
praegu	doc_802069853715_item	2881459	et	3	main
kassapidaja	doc_802069853715_item	2881462	et	4	main
tulin	doc_802069853715_item	2881465	et	3	main
et	doc_802069853715_item	2881468	et	3	main
majandus	doc_802069853715_item	2881471	et	4	main
väga	doc_802069853715_item	2881472	et	3	main
huvitav	doc_802069853715_item	2881474	et	4	main
palju	doc_802069853715_item	2881478	et	4	main
oli	doc_802069853716_item	2881509	et	3	main
kakskümmend	doc_802069853716_item	2881513	et	4	main
aastat	doc_802069853716_item	2881514	et	3	main
tagasi	doc_802069853716_item	2881515	et	3	main
see	doc_802069853716_item	2881516	et	3	main
oli	doc_802069853716_item	2881517	et	3	main
raske	doc_802069853716_item	2881518	et	4	main
aeg	doc_802069853716_item	2881519	et	3	main
aga	doc_802069853716_item	2881520	et	3	main
kapp	doc_801781988535_item	2881214	et	3	main
ühes	doc_801781988535_item	2881232	et	4	main
taldrikud	doc_801781988535_item	2881240	et	3	main
klaasid	doc_801781988535_item	2881242	et	4	main
kolmas	doc_801781988535_item	2881246	et	3	main
ja	doc_801781988535_item	2881258	et	3	main
on	doc_801781988535_item	2881263	et	4	main
kolm	doc_801781988535_item	2881264	et	3	main
vaagen	doc_801781988535_item	2881265	et	3	main
vahukulp	doc_801781988535_item	2881269	et	3	main
korgitser	doc_801781988535_item	2881271	et	3	main
supi-	doc_801781988535_item	2881275	et	3	main
ja	doc_801781988535_item	2881278	et	3	main
ja	doc_801781988535_item	2881283	et	3	main
lae	doc_801781988535_item	2881285	et	4	main
on	doc_801781988535_item	2881290	et	4	main
minu	doc_801781988535_item	2881296	et	3	main
korter	doc_801781988535_item	2881297	et	3	main
ta	doc_801781988535_item	2881301	et	4	main
soe	doc_801781988535_item	2881303	et	4	main
ilus	doc_801781988535_item	2881304	et	4	main
ja	doc_801781988535_item	2881305	et	3	main
mugav	doc_801781988535_item	2881306	et	3	main
essee	doc_802069853715_item	2881445	et	4	main
töötan	doc_802069853715_item	2881460	et	3	main
on	doc_802069853715_item	2881477	et	4	main
kes	doc_802069853716_item	2881508	et	4	main
eestis	doc_802069853716_item	2881511	et	3	main
muutuks	doc_802069853716_item	2881522	et	4	main
tehnika	doc_802069853716_item	2881530	et	4	main
mule	doc_802069853716_item	2881537	et	4	main
meeldib	doc_802069853716_item	2881538	et	3	main
huvitav	doc_802069853716_item	2881547	et	4	main
tallinna	doc_802069853716_item	2881549	et	4	main
mina	doc_802069853715_item	2881446	et	4	main
ja	doc_802069853715_item	2881447	et	3	main
vana	doc_802069853715_item	2881456	et	4	main
tallinnas	doc_802069853715_item	2881458	et	4	main
kasiinos	doc_802069853715_item	2881461	et	3	main
ma	doc_802069853715_item	2881464	et	3	main
sellepärast	doc_802069853715_item	2881467	et	3	main
palju	doc_802069853715_item	2881473	et	4	main
s	doc_802069853715_item	2881476	et	4	main
võimalused	doc_802069853715_item	2881479	et	3	main
inimene	doc_802069853716_item	2881507	et	3	main
sündinud	doc_802069853716_item	2881510	et	4	main
ümbes	doc_802069853716_item	2881512	et	4	main
kõik	doc_802069853716_item	2881523	et	4	main
ülikoolis	doc_802069853716_item	2881531	et	4	main
õppida	doc_802069853716_item	2881532	et	3	main
programeerine	doc_802069853716_item	2881543	et	4	main
on	doc_802069853716_item	2881544	et	4	main
mul	doc_802069853716_item	2881545	et	3	main
ka	doc_802069853716_item	2881546	et	3	main
kõige	doc_802069853716_item	2881557	et	4	main
ülikool	doc_802069853716_item	2881560	et	4	main
kvalitetsem	doc_802069853716_item	2881565	et	4	main
on	doc_802069853716_item	2881568	et	4	main
teada	doc_802069853716_item	2881573	et	3	main
siin	doc_802069853716_item	2881575	et	4	main
et	doc_802069853716_item	2881582	et	3	main
räägida	doc_802069853716_item	2881590	et	4	main
ja	doc_802069853716_item	2881591	et	3	main
parem	doc_802069853716_item	2881592	et	4	main
hea	doc_802069853716_item	2881598	et	4	main
asi	doc_802069853716_item	2881622	et	4	main
j	doc_802069853716_item	2881623	et	4	main
et	doc_802069853716_item	2881625	et	3	main
see	doc_802069853716_item	2881626	et	3	main
aine	doc_802069853716_item	2881627	et	4	main
on	doc_802069853717_item	2881637	et	4	main
eesnimi	doc_802069853717_item	2881638	et	3	main
ma	doc_802069853717_item	2881639	et	3	main
olen	doc_802069853717_item	2881640	et	3	main
pärast	doc_802069853717_item	2881659	et	4	main
ma	doc_802069853717_item	2881660	et	3	main
mäleta	doc_802069853717_item	2881662	et	4	main
tahaksin	doc_802069853717_item	2881667	et	3	main
see	doc_802069853717_item	2881669	et	3	main
uuesti	doc_802069853717_item	2881671	et	3	main
ma	doc_802069853717_item	2881672	et	3	main
perspektiivne	doc_802069853717_item	2881680	et	3	main
haridus	doc_802069853717_item	2881688	et	3	main
ma	doc_802069853717_item	2881691	et	3	main
ülikool	doc_802069853717_item	2881695	et	4	main
ootan	doc_802069853717_item	2881700	et	3	main
et	doc_802069853717_item	2881704	et	3	main
seal	doc_802069853718_item	2881727	et	4	main
kaksteist	doc_802069853718_item	2881730	et	4	main
aastat	doc_802069853718_item	2881731	et	3	main
pärast	doc_802069853718_item	2881732	et	4	main
minna	doc_802069853718_item	2881738	et	3	main
küsimus	doc_802069853718_item	2881747	et	4	main
võib	doc_802069853718_item	2881748	et	3	main
olla	doc_802069853718_item	2881749	et	3	main
ülikool	doc_802069853715_item	2881448	et	4	main
minu	doc_802069853715_item	2881449	et	3	main
23	doc_802069853715_item	2881454	et	2	main
elan	doc_802069853715_item	2881457	et	3	main
olen	doc_802069853715_item	2881463	et	3	main
õppima	doc_802069853715_item	2881466	et	3	main
mulle	doc_802069853715_item	2881469	et	4	main
meeldub	doc_802069853715_item	2881470	et	3	main
ttü	doc_802069853715_item	2881475	et	4	main
võib	doc_802069853715_item	2881480	et	3	main
tutvuda	doc_802069853715_item	2881481	et	3	main
õpilastega	doc_802069853715_item	2881482	et	4	main
ma	doc_802069853715_item	2881483	et	3	main
loodan	doc_802069853715_item	2881484	et	3	main
et	doc_802069853715_item	2881485	et	3	main
pärast	doc_802069853715_item	2881486	et	4	main
loengult	doc_802069853715_item	2881487	et	3	main
ma	doc_802069853715_item	2881488	et	3	main
hakkan	doc_802069853715_item	2881489	et	3	main
rohkem	doc_802069853715_item	2881490	et	4	main
teada	doc_802069853715_item	2881491	et	3	main
eesti	doc_802069853715_item	2881492	et	4	main
keel	doc_802069853715_item	2881493	et	4	main
pärast	doc_802069853715_item	2881494	et	4	main
ülikooli	doc_802069853715_item	2881495	et	4	main
tahan	doc_802069853715_item	2881496	et	3	main
minna	doc_802069853715_item	2881497	et	3	main
töötada	doc_802069853715_item	2881498	et	3	main
pangas	doc_802069853715_item	2881499	et	4	main
essee	doc_802069853716_item	2881500	et	4	main
mina	doc_802069853716_item	2881501	et	4	main
ja	doc_802069853716_item	2881502	et	3	main
ülikool	doc_802069853716_item	2881503	et	4	main
olen	doc_802069853716_item	2881504	et	3	main
üks	doc_802069853716_item	2881505	et	3	main
rõõmus	doc_802069853716_item	2881506	et	4	main
nüüd	doc_802069853716_item	2881525	et	4	main
on	doc_802069853716_item	2881526	et	4	main
mul	doc_802069853716_item	2881527	et	3	main
võimalus	doc_802069853716_item	2881528	et	3	main
ma	doc_802069853716_item	2881533	et	3	main
valiksin	doc_802069853716_item	2881534	et	3	main
informatikat	doc_802069853716_item	2881535	et	4	main
sest	doc_802069853716_item	2881536	et	4	main
ja	doc_802069853716_item	2881540	et	3	main
tegeleda	doc_802069853716_item	2881542	et	3	main
astusin	doc_802069853716_item	2881548	et	3	main
ülikooli	doc_802069853716_item	2881551	et	4	main
meeles	doc_802069853716_item	2881554	et	3	main
tehnika	doc_802069853716_item	2881559	et	4	main
eestis	doc_802069853716_item	2881561	et	3	main
õppitakse	doc_802069853716_item	2881563	et	4	main
eesti	doc_802069853716_item	2881578	et	4	main
mitte	doc_802069853716_item	2881601	et	3	main
ainult	doc_802069853716_item	2881602	et	4	main
tööt	doc_802069853716_item	2881604	et	4	main
hästi	doc_802069853716_item	2881605	et	3	main
oma	doc_802069853716_item	2881603	et	4	main
teha	doc_802069853716_item	2881606	et	3	main
kui	doc_802069853716_item	2881607	et	3	main
ka	doc_802069853716_item	2881608	et	3	main
eesti	doc_802069853716_item	2881609	et	4	main
keeles	doc_802069853716_item	2881610	et	4	main
sobival	doc_802069853716_item	2881611	et	4	main
tasemal	doc_802069853716_item	2881612	et	3	main
rägida	doc_802069853716_item	2881613	et	4	main
oskama	doc_802069853716_item	2881614	et	3	main
kaks	doc_802069853716_item	2881615	et	3	main
aine	doc_802069853716_item	2881616	et	4	main
on	doc_802069853716_item	2881618	et	4	main
ka	doc_802069853716_item	2881619	et	3	main
üks	doc_802069853716_item	2881620	et	3	main
punktid	doc_802069853716_item	2881617	et	4	main
tunnen	doc_802069853716_item	2881624	et	3	main
kasulik	doc_802069853716_item	2881630	et	3	main
essee	doc_802069853717_item	2881631	et	4	main
ülikool	doc_802069853717_item	2881634	et	4	main
minu	doc_802069853717_item	2881635	et	3	main
nimi	doc_802069853717_item	2881636	et	3	main
tallinnas	doc_802069853717_item	2881646	et	4	main
ma	doc_802069853717_item	2881647	et	3	main
lõpetasin	doc_802069853717_item	2881648	et	3	main
selle	doc_802069853717_item	2881658	et	4	main
keel	doc_802069853717_item	2881664	et	4	main
sest	doc_802069853717_item	2881676	et	4	main
see	doc_802069853717_item	2881677	et	3	main
on	doc_802069853717_item	2881687	et	4	main
et	doc_802069853717_item	2881693	et	3	main
loengutelt	doc_802069853717_item	2881703	et	4	main
see	doc_802069853717_item	2881706	et	3	main
ma	doc_802069853717_item	2881708	et	3	main
eesnimi	doc_802069853718_item	2881721	et	3	main
mina	doc_802069853718_item	2881728	et	4	main
kooli	doc_802069853718_item	2881733	et	4	main
miks	doc_802069853718_item	2881739	et	4	main
mina	doc_802069853718_item	2881740	et	4	main
valisin	doc_802069853718_item	2881741	et	3	main
majandus	doc_802069853718_item	2881742	et	4	main
nüüd	doc_802069853716_item	2881521	et	4	main
paremaks	doc_802069853716_item	2881524	et	4	main
tallinna	doc_802069853716_item	2881529	et	4	main
arvutiga	doc_802069853716_item	2881539	et	4	main
internetiga	doc_802069853716_item	2881541	et	4	main
tehnika	doc_802069853716_item	2881550	et	4	main
sest	doc_802069853716_item	2881552	et	4	main
minu	doc_802069853716_item	2881553	et	3	main
see	doc_802069853716_item	2881555	et	3	main
on	doc_802069853716_item	2881556	et	4	main
siin	doc_802069853716_item	2881562	et	4	main
spetsialiste	doc_802069853716_item	2881566	et	3	main
tööturul	doc_802069853716_item	2881569	et	3	main
kui	doc_802069853716_item	2881571	et	3	main
õppitakse	doc_802069853716_item	2881576	et	4	main
ka	doc_802069853716_item	2881577	et	3	main
mõtlenud	doc_802069853716_item	2881581	et	4	main
võimalus	doc_802069853716_item	2881586	et	3	main
keeles	doc_802069853716_item	2881588	et	4	main
parem	doc_802069853716_item	2881589	et	4	main
tean	doc_802069853716_item	2881595	et	3	main
küll	doc_802069853716_item	2881596	et	4	main
et	doc_802069853716_item	2881597	et	3	main
mul	doc_802069853716_item	2881629	et	3	main
mina	doc_802069853717_item	2881632	et	4	main
ja	doc_802069853717_item	2881633	et	3	main
kooli	doc_802069853717_item	2881649	et	4	main
kaks	doc_802069853717_item	2881650	et	3	main
aastat	doc_802069853717_item	2881651	et	3	main
tagasi	doc_802069853717_item	2881652	et	3	main
ja	doc_802069853717_item	2881653	et	3	main
infoormatika	doc_802069853717_item	2881674	et	4	main
eriala	doc_802069853717_item	2881675	et	4	main
huvitav	doc_802069853717_item	2881682	et	4	main
minu	doc_802069853717_item	2881683	et	3	main
muljed	doc_802069853717_item	2881684	et	3	main
ttü	doc_802069853717_item	2881685	et	4	main
st	doc_802069853717_item	2881686	et	3	main
ja	doc_802069853717_item	2881690	et	3	main
see	doc_802069853717_item	2881694	et	3	main
väga	doc_802069853717_item	2881697	et	3	main
ma	doc_802069853717_item	2881699	et	3	main
keele	doc_802069853717_item	2881702	et	4	main
pärast	doc_802069853717_item	2881705	et	4	main
kurs	doc_802069853717_item	2881707	et	4	main
vene	doc_802069853718_item	2881725	et	4	main
gümnaasium	doc_802069853718_item	2881726	et	3	main
vaja	doc_802069853718_item	2881734	et	4	main
valida	doc_802069853718_item	2881735	et	3	main
kuhu	doc_802069853718_item	2881736	et	3	main
edasi	doc_802069853718_item	2881737	et	3	main
hea	doc_802069853718_item	2881746	et	4	main
rohkem	doc_802069853718_item	2881755	et	4	main
erialad	doc_802069853718_item	2881758	et	3	main
tahad	doc_802069853718_item	2881766	et	3	main
töötada	doc_802069853718_item	2881767	et	3	main
heal	doc_802069853718_item	2881768	et	3	main
tööl	doc_802069853718_item	2881769	et	3	main
on	doc_802069853718_item	2881778	et	4	main
ülikool	doc_802069853718_item	2881785	et	4	main
tea	doc_802069853718_item	2881788	et	4	main
inimesi	doc_802069853718_item	2881791	et	4	main
rohkem	doc_802069853718_item	2881823	et	4	main
töötada	doc_802069853718_item	2881830	et	3	main
gruppis	doc_802069853718_item	2881831	et	4	main
on	doc_802069853718_item	2881833	et	4	main
huvitavam	doc_802069853718_item	2881834	et	4	main
kui	doc_802069853718_item	2881835	et	3	main
kirjutada	doc_802069853718_item	2881836	et	3	main
ülesandeid	doc_802069853718_item	2881837	et	3	main
väike	doc_802069853719_item	2881859	et	4	main
mängisin	doc_802069853719_item	2881860	et	3	main
tahan	doc_802069853719_item	2881867	et	3	main
rohkem	doc_802069853719_item	2881869	et	4	main
ja	doc_802069853719_item	2881871	et	3	main
ärindusest	doc_802069853719_item	2881872	et	4	main
see	doc_802069853719_item	2881873	et	3	main
huvitam	doc_802069853719_item	2881876	et	4	main
teaduskond	doc_802069853719_item	2881877	et	3	main
soovib	doc_802069853719_item	2881881	et	3	main
meeldib	doc_802069853719_item	2881885	et	3	main
õppimist	doc_802069853719_item	2881893	et	4	main
parem	doc_802069853716_item	2881558	et	4	main
kõige	doc_802069853716_item	2881564	et	4	main
kes	doc_802069853716_item	2881567	et	4	main
konkurentsivõimalised	doc_802069853716_item	2881570	et	4	main
sain	doc_802069853716_item	2881572	et	3	main
keelt	doc_802069853716_item	2881579	et	4	main
oleks	doc_802069853716_item	2881584	et	3	main
aru	doc_802069853716_item	2881593	et	4	main
peab	doc_802069853716_item	2881600	et	4	main
et	doc_802069853716_item	2881574	et	3	main
olen	doc_802069853716_item	2881580	et	3	main
see	doc_802069853716_item	2881583	et	3	main
hea	doc_802069853716_item	2881585	et	4	main
eesti	doc_802069853716_item	2881587	et	4	main
saada	doc_802069853716_item	2881594	et	4	main
asjatundja	doc_802069853716_item	2881599	et	4	main
hea	doc_802069853716_item	2881621	et	4	main
oleks	doc_802069853716_item	2881628	et	3	main
kakskümmend	doc_802069853717_item	2881641	et	4	main
aastat	doc_802069853717_item	2881642	et	3	main
vana	doc_802069853717_item	2881643	et	4	main
ma	doc_802069853717_item	2881644	et	3	main
elan	doc_802069853717_item	2881645	et	3	main
pärast	doc_802069853717_item	2881654	et	4	main
ma	doc_802069853717_item	2881655	et	3	main
töötasin	doc_802069853717_item	2881656	et	3	main
iriimaas	doc_802069853717_item	2881657	et	4	main
ei	doc_802069853717_item	2881661	et	4	main
eesti	doc_802069853717_item	2881663	et	4	main
aga	doc_802069853717_item	2881665	et	3	main
ma	doc_802069853717_item	2881666	et	3	main
õppida	doc_802069853717_item	2881668	et	3	main
keel	doc_802069853717_item	2881670	et	4	main
valisin	doc_802069853717_item	2881673	et	3	main
on	doc_802069853717_item	2881678	et	4	main
väga	doc_802069853717_item	2881679	et	3	main
ja	doc_802069853717_item	2881681	et	3	main
süsteem	doc_802069853717_item	2881689	et	3	main
arvan	doc_802069853717_item	2881692	et	3	main
on	doc_802069853717_item	2881696	et	4	main
sõbrakil	doc_802069853717_item	2881698	et	4	main
eesti	doc_802069853717_item	2881701	et	4	main
saan	doc_802069853717_item	2881709	et	4	main
räkida	doc_802069853717_item	2881710	et	4	main
eesti	doc_802069853717_item	2881711	et	4	main
keel	doc_802069853717_item	2881712	et	4	main
vabalt	doc_802069853717_item	2881713	et	4	main
essee	doc_802069853718_item	2881714	et	4	main
mina	doc_802069853718_item	2881715	et	4	main
ja	doc_802069853718_item	2881716	et	3	main
ülikool	doc_802069853718_item	2881717	et	4	main
minu	doc_802069853718_item	2881718	et	3	main
nimi	doc_802069853718_item	2881719	et	3	main
on	doc_802069853718_item	2881720	et	4	main
mina	doc_802069853718_item	2881722	et	4	main
lõpetasin	doc_802069853718_item	2881723	et	3	main
lasnamäe	doc_802069853718_item	2881724	et	3	main
õppisin	doc_802069853718_item	2881729	et	3	main
see	doc_802069853718_item	2881743	et	3	main
on	doc_802069853718_item	2881744	et	4	main
väga	doc_802069853718_item	2881745	et	3	main
riigiülikool	doc_802069853718_item	2881761	et	4	main
ja	doc_802069853718_item	2881762	et	3	main
siis	doc_802069853718_item	2881763	et	3	main
kui	doc_802069853718_item	2881764	et	3	main
seda	doc_802069853718_item	2881774	et	3	main
ttü	doc_802069853718_item	2881777	et	4	main
võib	doc_802069853718_item	2881781	et	3	main
liiga	doc_802069853718_item	2881783	et	4	main
mina	doc_802069853718_item	2881786	et	4	main
kui	doc_802069853718_item	2881789	et	3	main
siin	doc_802069853718_item	2881793	et	4	main
aga	doc_802069853718_item	2881794	et	3	main
mulle	doc_802069853718_item	2881795	et	4	main
see	doc_802069853718_item	2881796	et	3	main
meeldib	doc_802069853718_item	2881797	et	3	main
siin	doc_802069853718_item	2881798	et	4	main
on	doc_802069853718_item	2881799	et	4	main
väga	doc_802069853718_item	2881800	et	3	main
huvitavad	doc_802069853718_item	2881801	et	4	main
sõbralikud	doc_802069853718_item	2881802	et	3	main
ja	doc_802069853718_item	2881803	et	3	main
lõbusad	doc_802069853718_item	2881804	et	3	main
inimesed	doc_802069853718_item	2881805	et	3	main
kui	doc_802069853718_item	2881806	et	3	main
sina	doc_802069853718_item	2881807	et	4	main
ei	doc_802069853718_item	2881808	et	4	main
tea	doc_802069853718_item	2881809	et	4	main
kus	doc_802069853718_item	2881810	et	3	main
on	doc_802069853718_item	2881811	et	4	main
mõned	doc_802069853718_item	2881812	et	3	main
klassid	doc_802069853718_item	2881813	et	3	main
siis	doc_802069853718_item	2881814	et	3	main
nad	doc_802069853718_item	2881815	et	3	main
aitavad	doc_802069853718_item	2881816	et	4	main
sind	doc_802069853718_item	2881817	et	4	main
mina	doc_802069853718_item	2881818	et	4	main
ootan	doc_802069853718_item	2881819	et	3	main
eesti	doc_802069853718_item	2881820	et	4	main
see	doc_802069853718_item	2881750	et	3	main
eriala	doc_802069853718_item	2881751	et	4	main
ärindus	doc_802069853718_item	2881752	et	3	main
mulle	doc_802069853718_item	2881753	et	4	main
sobib	doc_802069853718_item	2881754	et	3	main
teised	doc_802069853718_item	2881757	et	4	main
ttü	doc_802069853718_item	2881759	et	4	main
on	doc_802069853718_item	2881760	et	4	main
esiteks	doc_802069853718_item	2881770	et	3	main
arvan	doc_802069853718_item	2881776	et	3	main
ja	doc_802069853718_item	2881780	et	3	main
olla	doc_802069853718_item	2881782	et	3	main
keele	doc_802069853718_item	2881821	et	4	main
loengutelt	doc_802069853718_item	2881822	et	4	main
keeles	doc_802069853718_item	2881826	et	4	main
ja	doc_802069853718_item	2881827	et	3	main
essee	doc_802069853719_item	2881838	et	4	main
mina	doc_802069853719_item	2881839	et	4	main
ja	doc_802069853719_item	2881840	et	3	main
ülikool	doc_802069853719_item	2881841	et	4	main
praegu	doc_802069853719_item	2881842	et	3	main
olen	doc_802069853719_item	2881843	et	3	main
juba	doc_802069853719_item	2881844	et	3	main
üliõpilane	doc_802069853719_item	2881845	et	3	main
miks	doc_802069853719_item	2881851	et	4	main
majandus	doc_802069853719_item	2881852	et	4	main
kodus	doc_802069853719_item	2881861	et	4	main
ja	doc_802069853719_item	2881862	et	3	main
mõtlesin	doc_802069853719_item	2881863	et	3	main
pangas	doc_802069853719_item	2881866	et	4	main
on	doc_802069853719_item	2881874	et	4	main
kõige	doc_802069853719_item	2881875	et	4	main
kõige	doc_802069853719_item	2881879	et	4	main
veel	doc_802069853719_item	2881883	et	4	main
suhelda	doc_802069853719_item	2881887	et	4	main
selle	doc_802069853719_item	2881889	et	4	main
tahan	doc_802069853719_item	2881891	et	3	main
õppin	doc_802069853719_item	2881898	et	4	main
suur	doc_802069853719_item	2881912	et	3	main
et	doc_802069853719_item	2881921	et	3	main
õppetakse	doc_802069853719_item	2881924	et	3	main
loodan	doc_802069853719_item	2881936	et	3	main
gramaatikat	doc_802069853719_item	2881940	et	4	main
teada	doc_802069853719_item	2881941	et	3	main
inimestega	doc_802069853719_item	2881943	et	3	main
suhelda	doc_802069853719_item	2881945	et	4	main
meie	doc_802069853719_item	2881953	et	4	main
peab	doc_802069853719_item	2881957	et	4	main
teadma	doc_802069853719_item	2881958	et	3	main
elab	doc_802069853719_item	2881962	et	3	main
inimene	doc_802069853719_item	2881968	et	3	main
selle	doc_802069853719_item	2881970	et	4	main
eesti	doc_802069853719_item	2881975	et	4	main
väga	doc_802069853719_item	2881980	et	3	main
mina	doc_802069853720_item	2881983	et	4	main
on	doc_802069853720_item	2881988	et	4	main
aastal	doc_802069853720_item	2881994	et	3	main
prantsusmaale	doc_802069853720_item	2881998	et	4	main
hotelli	doc_802069853720_item	2881999	et	4	main
ja	doc_802069853720_item	2882000	et	3	main
mul	doc_802069853720_item	2882010	et	3	main
liiklusõnnetus	doc_802069853720_item	2882012	et	4	main
ja	doc_802069853720_item	2882013	et	3	main
enam	doc_802069853720_item	2882022	et	4	main
mul	doc_802069853720_item	2882030	et	3	main
meeldinud	doc_802069853720_item	2882032	et	4	main
väga	doc_802069853720_item	2882033	et	3	main
ja	doc_802069853720_item	2882034	et	3	main
otsustasin	doc_802069853720_item	2882035	et	3	main
töökoha	doc_802069853720_item	2882036	et	4	main
töötasin	doc_802069853720_item	2882038	et	3	main
seal	doc_802069853720_item	2882048	et	4	main
tundsin	doc_802069853720_item	2882049	et	3	main
väga	doc_802069853720_item	2882050	et	3	main
ja	doc_802069853720_item	2882053	et	3	main
õppida	doc_802069853720_item	2882056	et	3	main
õpin	doc_802069853720_item	2882059	et	3	main
ja	doc_802069853720_item	2882061	et	3	main
mul	doc_802069853720_item	2882063	et	3	main
väga	doc_802069853720_item	2882065	et	3	main
nüüd	doc_802069853720_item	2882087	et	4	main
aga	doc_802069853720_item	2882090	et	3	main
kui	doc_802069853718_item	2881756	et	3	main
sina	doc_802069853718_item	2881765	et	4	main
võtavad	doc_802069853718_item	2881771	et	3	main
töötajaid	doc_802069853718_item	2881772	et	4	main
riigikoolist	doc_802069853718_item	2881773	et	4	main
mina	doc_802069853718_item	2881775	et	4	main
väga	doc_802069853718_item	2881779	et	3	main
suur	doc_802069853718_item	2881784	et	3	main
ei	doc_802069853718_item	2881787	et	4	main
palju	doc_802069853718_item	2881790	et	4	main
õppivad	doc_802069853718_item	2881792	et	4	main
suhelda	doc_802069853718_item	2881824	et	4	main
meeldib	doc_802069853718_item	2881829	et	3	main
majandusteaduskonda	doc_802069853719_item	2881850	et	4	main
lapsepõlvest	doc_802069853719_item	2881856	et	4	main
kui	doc_802069853719_item	2881857	et	3	main
olin	doc_802069853719_item	2881858	et	3	main
töötan	doc_802069853719_item	2881865	et	3	main
teada	doc_802069853719_item	2881868	et	3	main
majandusest	doc_802069853719_item	2881870	et	4	main
ja	doc_802069853719_item	2881878	et	3	main
tüdrukule	doc_802069853719_item	2881882	et	3	main
inimestega	doc_802069853719_item	2881886	et	3	main
ja	doc_802069853719_item	2881888	et	3	main
pärast	doc_802069853719_item	2881892	et	4	main
hea	doc_802069853719_item	2881904	et	4	main
mulle	doc_802069853719_item	2881905	et	4	main
et	doc_802069853719_item	2881907	et	3	main
ja	doc_802069853719_item	2881913	et	3	main
õppib	doc_802069853719_item	2881915	et	4	main
üliõpilast	doc_802069853719_item	2881917	et	4	main
tean	doc_802069853719_item	2881918	et	3	main
ka	doc_802069853719_item	2881919	et	3	main
seda	doc_802069853719_item	2881920	et	3	main
eesti	doc_802069853718_item	2881825	et	4	main
mulle	doc_802069853718_item	2881828	et	4	main
see	doc_802069853718_item	2881832	et	3	main
astusin	doc_802069853719_item	2881846	et	3	main
tallinna	doc_802069853719_item	2881847	et	4	main
tehnika	doc_802069853719_item	2881848	et	4	main
ülikooli	doc_802069853719_item	2881849	et	4	main
sellest	doc_802069853719_item	2881853	et	4	main
mõtlesin	doc_802069853719_item	2881854	et	3	main
juba	doc_802069853719_item	2881855	et	3	main
et	doc_802069853719_item	2881864	et	3	main
rohkem	doc_802069853719_item	2881880	et	4	main
mulle	doc_802069853719_item	2881884	et	4	main
pärast	doc_802069853719_item	2881890	et	4	main
pangas	doc_802069853719_item	2881894	et	4	main
aga	doc_802069853719_item	2881896	et	3	main
on	doc_802069853719_item	2881903	et	4	main
väga	doc_802069853719_item	2881911	et	3	main
rohkem	doc_802069853719_item	2881934	et	4	main
rohkem	doc_802069853719_item	2881939	et	4	main
keel	doc_802069853719_item	2881951	et	4	main
on	doc_802069853719_item	2881952	et	4	main
keelt	doc_802069853719_item	2881956	et	4	main
kes	doc_802069853719_item	2881961	et	4	main
olen	doc_802069853719_item	2881965	et	3	main
ja	doc_802069853719_item	2881969	et	3	main
tahan	doc_802069853719_item	2881973	et	3	main
see	doc_802069853719_item	2881977	et	3	main
mulle	doc_802069853719_item	2881979	et	4	main
nimi	doc_802069853720_item	2881987	et	3	main
eesnimi	doc_802069853720_item	2881989	et	3	main
kooli	doc_802069853720_item	2881992	et	4	main
ja	doc_802069853720_item	2881995	et	3	main
minna	doc_802069853720_item	2881997	et	3	main
sinna	doc_802069853720_item	2882006	et	3	main
hotellise	doc_802069853720_item	2882028	et	4	main
ei	doc_802069853720_item	2882031	et	4	main
firmas	doc_802069853720_item	2882041	et	3	main
huvi	doc_802069853720_item	2882051	et	4	main
otsustasin	doc_802069853720_item	2882054	et	3	main
sõbrad	doc_802069853720_item	2882067	et	3	main
jaoks	doc_802069853720_item	2882076	et	4	main
kahjuks	doc_802069853720_item	2882077	et	4	main
sel	doc_802069853720_item	2882078	et	3	main
aastal	doc_802069853720_item	2882079	et	3	main
unustasin	doc_802069853720_item	2882080	et	3	main
palju	doc_802069853720_item	2882083	et	4	main
inglisekeeles	doc_802069853720_item	2882089	et	4	main
kindel	doc_802069853720_item	2882093	et	3	main
et	doc_802069853720_item	2882094	et	3	main
hea	doc_802069853720_item	2882100	et	4	main
ma	doc_802069853720_item	2882108	et	3	main
gramaatika	doc_802069853720_item	2882111	et	4	main
harjutusi	doc_802069853720_item	2882112	et	4	main
et	doc_802069853720_item	2882116	et	3	main
mina	doc_802069853721_item	2882128	et	4	main
ja	doc_802069853721_item	2882129	et	3	main
ülikool	doc_802069853721_item	2882130	et	4	main
ma	doc_802069853721_item	2882131	et	3	main
lõpetasin	doc_802069853721_item	2882132	et	3	main
sooritan	doc_802069853721_item	2882139	et	3	main
siis	doc_802069853721_item	2882141	et	3	main
tahtsin	doc_802069853721_item	2882143	et	3	main
ma	doc_802069853721_item	2882154	et	3	main
on	doc_802069853721_item	2882157	et	4	main
siin	doc_802069853721_item	2882179	et	4	main
oma	doc_802069853721_item	2882181	et	4	main
ja	doc_802069853721_item	2882188	et	3	main
tähtpäevad	doc_802069853721_item	2882189	et	3	main
iga	doc_802069853721_item	2882190	et	4	main
on	doc_802069853721_item	2882192	et	4	main
nägu	doc_802069853721_item	2882193	et	4	main
on	doc_802069853721_item	2882197	et	4	main
võimalus	doc_802069853721_item	2882199	et	3	main
ja	doc_802069853721_item	2882214	et	3	main
on	doc_802069853721_item	2882221	et	4	main
organisatsioon	doc_802069853721_item	2882224	et	3	main
saada	doc_802069853721_item	2882228	et	4	main
teadmised	doc_802069853721_item	2882229	et	4	main
millised	doc_802069853721_item	2882230	et	3	main
mina	doc_802069853722_item	2882235	et	4	main
ja	doc_802069853722_item	2882236	et	3	main
ma	doc_802069853722_item	2882238	et	3	main
eesnimi	doc_802069853722_item	2882240	et	3	main
olen	doc_802069853722_item	2882242	et	3	main
03	doc_802069853722_item	2882248	et	2	main
aprillil	doc_802069853722_item	2882249	et	3	main
lõpetasin	doc_802069853722_item	2882250	et	3	main
edukalt	doc_802069853722_item	2882259	et	4	main
ttüst	doc_802069853719_item	2881902	et	4	main
on	doc_802069853719_item	2881910	et	4	main
ülikoolis	doc_802069853719_item	2881922	et	4	main
hästi	doc_802069853719_item	2881923	et	3	main
pärast	doc_802069853719_item	2881929	et	4	main
infot	doc_802069853719_item	2881935	et	3	main
hakkan	doc_802069853719_item	2881938	et	3	main
ja	doc_802069853719_item	2881942	et	3	main
rohkem	doc_802069853719_item	2881944	et	4	main
tean	doc_802069853719_item	2881946	et	3	main
ka	doc_802069853719_item	2881947	et	3	main
seda	doc_802069853719_item	2881948	et	3	main
et	doc_802069853719_item	2881949	et	3	main
eesti	doc_802069853719_item	2881950	et	4	main
riigikeel	doc_802069853719_item	2881954	et	4	main
iga	doc_802069853719_item	2881959	et	4	main
eestis	doc_802069853719_item	2881963	et	3	main
selline	doc_802069853719_item	2881967	et	4	main
ma	doc_802069853719_item	2881972	et	3	main
keelt	doc_802069853719_item	2881976	et	4	main
meeldib	doc_802069853719_item	2881981	et	3	main
ja	doc_802069853720_item	2881984	et	3	main
ülikool	doc_802069853720_item	2881985	et	4	main
lõpetasin	doc_802069853720_item	2881991	et	3	main
eelmisel	doc_802069853720_item	2881993	et	3	main
tahtsin	doc_802069853720_item	2881996	et	3	main
kahjuks	doc_802069853720_item	2882003	et	4	main
saanud	doc_802069853720_item	2882005	et	4	main
sest	doc_802069853720_item	2882008	et	4	main
ma	doc_802069853720_item	2882014	et	3	main
veetsin	doc_802069853720_item	2882015	et	3	main
palju	doc_802069853720_item	2882016	et	4	main
aega	doc_802069853720_item	2882017	et	4	main
haiglas	doc_802069853720_item	2882018	et	3	main
pärast	doc_802069853720_item	2882019	et	4	main
kui	doc_802069853720_item	2882020	et	3	main
töötada	doc_802069853719_item	2881895	et	3	main
praegu	doc_802069853719_item	2881897	et	3	main
ttüs	doc_802069853719_item	2881899	et	4	main
minu	doc_802069853719_item	2881900	et	3	main
mulje	doc_802069853719_item	2881901	et	4	main
meeldib	doc_802069853719_item	2881906	et	3	main
see	doc_802069853719_item	2881908	et	3	main
ülikool	doc_802069853719_item	2881909	et	4	main
siin	doc_802069853719_item	2881914	et	4	main
palju	doc_802069853719_item	2881916	et	4	main
eesti	doc_802069853719_item	2881925	et	4	main
keele	doc_802069853719_item	2881926	et	4	main
ja	doc_802069853719_item	2881927	et	3	main
selle	doc_802069853719_item	2881928	et	4	main
eesti	doc_802069853719_item	2881930	et	4	main
keelte	doc_802069853719_item	2881931	et	3	main
loengutelt	doc_802069853719_item	2881932	et	4	main
ootan	doc_802069853719_item	2881933	et	3	main
et	doc_802069853719_item	2881937	et	3	main
eesti	doc_802069853719_item	2881955	et	4	main
inimine	doc_802069853719_item	2881960	et	4	main
mina	doc_802069853719_item	2881964	et	4	main
ka	doc_802069853719_item	2881966	et	3	main
pärast	doc_802069853719_item	2881971	et	4	main
õppida	doc_802069853719_item	2881974	et	3	main
keel	doc_802069853719_item	2881978	et	4	main
essee	doc_802069853720_item	2881982	et	4	main
turismimajandust	doc_802069853720_item	2882001	et	3	main
juhtus	doc_802069853720_item	2882009	et	3	main
suur	doc_802069853720_item	2882011	et	3	main
seal	doc_802069853720_item	2882029	et	4	main
lastetarbitega	doc_802069853720_item	2882047	et	4	main
majanduses	doc_802069853720_item	2882052	et	4	main
majandust	doc_802069853720_item	2882055	et	4	main
nüüd	doc_802069853720_item	2882057	et	4	main
ma	doc_802069853720_item	2882058	et	3	main
ttü-s	doc_802069853720_item	2882060	et	3	main
meeldib	doc_802069853720_item	2882062	et	3	main
ma	doc_802069853720_item	2882081	et	3	main
on	doc_802069853720_item	2882085	et	4	main
endale	doc_802069853720_item	2882098	et	4	main
ka	doc_802069853720_item	2882099	et	3	main
töökoha	doc_802069853720_item	2882101	et	4	main
ja	doc_802069853720_item	2882102	et	3	main
omandada	doc_802069853720_item	2882103	et	3	main
hariduse	doc_802069853720_item	2882104	et	3	main
ootan	doc_802069853720_item	2882109	et	3	main
gramaatikaga	doc_802069853720_item	2882117	et	4	main
suhtlemis	doc_802069853720_item	2882121	et	4	main
oskus	doc_802069853720_item	2882122	et	3	main
heal	doc_802069853720_item	2882125	et	3	main
tasemel	doc_802069853720_item	2882126	et	3	main
essee	doc_802069853721_item	2882127	et	4	main
lasnamäe	doc_802069853721_item	2882134	et	3	main
kui	doc_802069853721_item	2882137	et	3	main
ma	doc_802069853721_item	2882138	et	3	main
ttü	doc_802069853721_item	2882144	et	4	main
sellepärast	doc_802069853721_item	2882146	et	3	main
et	doc_802069853721_item	2882147	et	3	main
ma	doc_802069853721_item	2882148	et	3	main
käisin	doc_802069853721_item	2882149	et	3	main
õigus	doc_802069853721_item	2882150	et	4	main
kus	doc_802069853721_item	2882153	et	3	main
vaja	doc_802069853721_item	2882158	et	4	main
ma	doc_802069853721_item	2882169	et	3	main
elistasin	doc_802069853721_item	2882170	et	4	main
astuda	doc_802069853721_item	2882171	et	3	main
ttüs	doc_802069853721_item	2882172	et	4	main
väike	doc_802069853721_item	2882177	et	4	main
oma	doc_802069853721_item	2882186	et	4	main
reeglid	doc_802069853721_item	2882187	et	3	main
tõeline	doc_802069853721_item	2882194	et	4	main
küsida	doc_802069853721_item	2882200	et	3	main
on	doc_802069853721_item	2882212	et	4	main
saavad	doc_802069853721_item	2882215	et	4	main
sulle	doc_802069853721_item	2882217	et	3	main
nõukogu	doc_802069853721_item	2882220	et	4	main
on	doc_802069853721_item	2882231	et	4	main
kasulik	doc_802069853721_item	2882232	et	3	main
kohtla	doc_802069853722_item	2882244	et	4	main
linnast	doc_802069853722_item	2882246	et	4	main
kõik	doc_802069853722_item	2882260	et	4	main
minu	doc_802069853720_item	2881986	et	3	main
ma	doc_802069853720_item	2881990	et	3	main
õppida	doc_802069853720_item	2882002	et	3	main
ei	doc_802069853720_item	2882004	et	4	main
minna	doc_802069853720_item	2882007	et	3	main
sain	doc_802069853720_item	2882021	et	3	main
vähem	doc_802069853720_item	2882023	et	4	main
terveks	doc_802069853720_item	2882024	et	4	main
otsustasin	doc_802069853720_item	2882025	et	3	main
tööle	doc_802069853720_item	2882026	et	3	main
minna	doc_802069853720_item	2882027	et	3	main
vahetada	doc_802069853720_item	2882037	et	3	main
sekretarina	doc_802069853720_item	2882039	et	4	main
väikeses	doc_802069853720_item	2882040	et	4	main
see	doc_802069853720_item	2882042	et	3	main
firma	doc_802069853720_item	2882043	et	4	main
tegeleb	doc_802069853720_item	2882044	et	3	main
mänguasjadega	doc_802069853720_item	2882045	et	3	main
ja	doc_802069853720_item	2882046	et	3	main
siin	doc_802069853720_item	2882064	et	4	main
uued	doc_802069853720_item	2882066	et	3	main
uued	doc_802069853720_item	2882068	et	3	main
inimesed	doc_802069853720_item	2882069	et	3	main
ja	doc_802069853720_item	2882070	et	3	main
kõik	doc_802069853720_item	2882071	et	4	main
on	doc_802069853720_item	2882072	et	4	main
hästi	doc_802069853720_item	2882073	et	3	main
huvitav	doc_802069853720_item	2882074	et	4	main
minu	doc_802069853720_item	2882075	et	3	main
väga	doc_802069853720_item	2882082	et	3	main
näiteks	doc_802069853720_item	2882084	et	4	main
mul	doc_802069853720_item	2882086	et	3	main
probleemid	doc_802069853720_item	2882088	et	3	main
olen	doc_802069853720_item	2882091	et	3	main
nüüd	doc_802069853720_item	2882092	et	4	main
eestimaal	doc_802069853720_item	2882095	et	4	main
leida	doc_802069853720_item	2882097	et	3	main
tundidest	doc_802069853720_item	2882107	et	3	main
palju	doc_802069853720_item	2882110	et	4	main
sest	doc_802069853720_item	2882113	et	4	main
ma	doc_802069853720_item	2882114	et	3	main
on	doc_802069853720_item	2882118	et	4	main
võib	doc_802069853720_item	2882096	et	3	main
keele	doc_802069853720_item	2882106	et	4	main
mul	doc_802069853720_item	2882119	et	3	main
probleemid	doc_802069853720_item	2882120	et	3	main
on	doc_802069853720_item	2882123	et	4	main
mul	doc_802069853720_item	2882124	et	3	main
tallinna	doc_802069853721_item	2882133	et	4	main
lütseum	doc_802069853721_item	2882136	et	3	main
ma	doc_802069853721_item	2882142	et	3	main
ja	doc_802069853721_item	2882151	et	3	main
õppin	doc_802069853721_item	2882155	et	4	main
teha	doc_802069853721_item	2882159	et	3	main
kui	doc_802069853721_item	2882160	et	3	main
sa	doc_802069853721_item	2882161	et	3	main
tahad	doc_802069853721_item	2882162	et	3	main
olla	doc_802069853721_item	2882163	et	3	main
edukas	doc_802069853721_item	2882164	et	4	main
inimene	doc_802069853721_item	2882165	et	3	main
pärast	doc_802069853721_item	2882166	et	4	main
sellised	doc_802069853721_item	2882167	et	4	main
kursused	doc_802069853721_item	2882168	et	3	main
eesti	doc_802069853720_item	2882105	et	4	main
tunnen	doc_802069853720_item	2882115	et	3	main
vene	doc_802069853721_item	2882135	et	4	main
eksamid	doc_802069853721_item	2882140	et	3	main
saada	doc_802069853721_item	2882145	et	4	main
majandus	doc_802069853721_item	2882152	et	4	main
mida	doc_802069853721_item	2882156	et	4	main
teaduskonda	doc_802069853721_item	2882174	et	4	main
on	doc_802069853721_item	2882180	et	4	main
sümbolid	doc_802069853721_item	2882182	et	3	main
oma	doc_802069853721_item	2882183	et	4	main
president	doc_802069853721_item	2882184	et	3	main
rektor	doc_802069853721_item	2882185	et	3	main
meeskond	doc_802069853721_item	2882195	et	3	main
annda	doc_802069853721_item	2882216	et	4	main
nõu	doc_802069853721_item	2882218	et	4	main
väga	doc_802069853721_item	2882222	et	3	main
ma	doc_802069853721_item	2882226	et	3	main
ettevõittluses	doc_802069853721_item	2882233	et	4	main
essee	doc_802069853722_item	2882234	et	4	main
olen	doc_802069853722_item	2882239	et	3	main
sündinud	doc_802069853722_item	2882247	et	4	main
järve	doc_802069853722_item	2882256	et	4	main
linnaosas	doc_802069853722_item	2882257	et	3	main
sooritasin	doc_802069853722_item	2882258	et	3	main
õppima	doc_802069853722_item	2882273	et	3	main
saan	doc_802069853722_item	2882276	et	4	main
sain	doc_802069853722_item	2882278	et	3	main
klassis	doc_802069853722_item	2882282	et	3	main
teadnud	doc_802069853722_item	2882285	et	4	main
saada	doc_802069853722_item	2882287	et	4	main
arvates	doc_802069853722_item	2882290	et	4	main
inseneeri	doc_802069853722_item	2882291	et	4	main
et	doc_802069853722_item	2882297	et	3	main
kogu	doc_802069853722_item	2882298	et	4	main
tallinna	doc_802069853722_item	2882302	et	4	main
väga	doc_802069853722_item	2882307	et	3	main
teine	doc_802069853722_item	2882316	et	3	main
majandus	doc_802069853721_item	2882173	et	4	main
ttü	doc_802069853721_item	2882175	et	4	main
riik	doc_802069853721_item	2882178	et	3	main
teaduskond	doc_802069853721_item	2882191	et	3	main
sul	doc_802069853721_item	2882196	et	3	main
alati	doc_802069853721_item	2882198	et	4	main
oma	doc_802069853721_item	2882201	et	4	main
vanem	doc_802069853721_item	2882202	et	4	main
vennad	doc_802069853721_item	2882203	et	3	main
ja	doc_802069853721_item	2882204	et	3	main
õdesid	doc_802069853721_item	2882205	et	3	main
kui	doc_802069853721_item	2882206	et	3	main
sul	doc_802069853721_item	2882207	et	3	main
heatahtlikud	doc_802069853721_item	2882213	et	3	main
üliõpilasi	doc_802069853721_item	2882219	et	3	main
nägu	doc_802069853721_item	2882176	et	4	main
on	doc_802069853721_item	2882208	et	4	main
misugune	doc_802069853721_item	2882209	et	4	main
probleem	doc_802069853721_item	2882210	et	3	main
tuutorid	doc_802069853721_item	2882211	et	4	main
tugev	doc_802069853721_item	2882223	et	4	main
loengus	doc_802069853721_item	2882225	et	3	main
tahan	doc_802069853721_item	2882227	et	3	main
ülikool	doc_802069853722_item	2882237	et	4	main
perekonnanimi	doc_802069853722_item	2882241	et	3	main
pärit	doc_802069853722_item	2882243	et	3	main
järve	doc_802069853722_item	2882245	et	4	main
ahtme	doc_802069853722_item	2882251	et	4	main
gümnaasium	doc_802069853722_item	2882252	et	3	main
mis	doc_802069853722_item	2882253	et	4	main
asub	doc_802069853722_item	2882254	et	3	main
kohtla	doc_802069853722_item	2882255	et	4	main
eksamid	doc_802069853722_item	2882261	et	3	main
ja	doc_802069853722_item	2882262	et	3	main
sain	doc_802069853722_item	2882263	et	3	main
keskharidus	doc_802069853722_item	2882264	et	3	main
minu	doc_802069853722_item	2882265	et	3	main
eest	doc_802069853722_item	2882266	et	4	main
kus	doc_802069853722_item	2882271	et	3	main
tulevikus	doc_802069853722_item	2882275	et	4	main
juba	doc_802069853722_item	2882280	et	3	main
ei	doc_802069853722_item	2882284	et	4	main
on	doc_802069853722_item	2882293	et	4	main
tehnika	doc_802069853722_item	2882303	et	4	main
kuulnud	doc_802069853722_item	2882306	et	4	main
ajalehtedest	doc_802069853722_item	2882312	et	4	main
õpin	doc_802069853722_item	2882313	et	3	main
aga	doc_802069853722_item	2882318	et	3	main
juba	doc_802069853722_item	2882320	et	3	main
loengutel	doc_802069853722_item	2882327	et	4	main
tahan	doc_802069853722_item	2882328	et	3	main
pareneda	doc_802069853722_item	2882329	et	3	main
hea	doc_802069853722_item	2882335	et	4	main
tasemel	doc_802069853722_item	2882336	et	3	main
elan	doc_802069853722_item	2882338	et	3	main
kus	doc_802069853722_item	2882341	et	3	main
riigikeel	doc_802069853722_item	2882342	et	4	main
tulevikus	doc_802069853722_item	2882347	et	4	main
saab	doc_802069853722_item	2882348	et	3	main
mina	doc_802069853723_item	2882355	et	4	main
ja	doc_802069853723_item	2882356	et	3	main
lõpetasin	doc_802069853723_item	2882366	et	3	main
on	doc_802069853723_item	2882379	et	4	main
mulle	doc_802069853723_item	2882382	et	4	main
tegelen	doc_802069853723_item	2882387	et	3	main
võrkpalliga	doc_802069853723_item	2882390	et	3	main
mulle	doc_802069853723_item	2882395	et	4	main
arvan	doc_802069853723_item	2882406	et	3	main
kõrgharidus	doc_802069853723_item	2882408	et	3	main
vajalik	doc_802069853723_item	2882410	et	3	main
saada	doc_802069853723_item	2882418	et	4	main
ülikoolis	doc_802069853723_item	2882420	et	4	main
õppima	doc_802069853723_item	2882421	et	3	main
praegu	doc_802069853723_item	2882422	et	3	main
tööstus	doc_802069853723_item	2882427	et	3	main
ja	doc_802069853723_item	2882428	et	3	main
tsiviili	doc_802069853723_item	2882429	et	4	main
ehituse	doc_802069853723_item	2882430	et	4	main
tudeng	doc_802069853723_item	2882431	et	3	main
kolm	doc_802069853723_item	2882432	et	3	main
aastat	doc_802069853723_item	2882433	et	3	main
tagasi	doc_802069853723_item	2882434	et	3	main
tahaksin	doc_802069853723_item	2882436	et	3	main
saada	doc_802069853723_item	2882438	et	4	main
aga	doc_802069853723_item	2882439	et	3	main
sellel	doc_802069853723_item	2882440	et	4	main
ingeneeriks	doc_802069853723_item	2882443	et	4	main
minu	doc_802069853723_item	2882445	et	3	main
tehnika	doc_802069853723_item	2882464	et	4	main
ttüs	doc_802069853723_item	2882485	et	4	main
raske	doc_802069853723_item	2882487	et	4	main
vaid	doc_802069853723_item	2882488	et	3	main
huvitav	doc_802069853723_item	2882489	et	4	main
õppida	doc_802069853723_item	2882490	et	3	main
keel	doc_802069853723_item	2882503	et	4	main
ja	doc_802069853723_item	2882504	et	3	main
mind	doc_802069853723_item	2882508	et	4	main
seisas	doc_802069853722_item	2882267	et	4	main
väga	doc_802069853722_item	2882268	et	3	main
tõsiline	doc_802069853722_item	2882269	et	4	main
edasi	doc_802069853722_item	2882272	et	3	main
teada	doc_802069853722_item	2882279	et	3	main
kümnes	doc_802069853722_item	2882281	et	4	main
kus	doc_802069853722_item	2882286	et	3	main
ehitaja	doc_802069853722_item	2882292	et	4	main
eriala	doc_802069853722_item	2882296	et	4	main
ülikoolist	doc_802069853722_item	2882304	et	4	main
ainult	doc_802069853722_item	2882315	et	4	main
mulle	doc_802069853722_item	2882319	et	4	main
väga	doc_802069853722_item	2882321	et	3	main
õppimine	doc_802069853722_item	2882323	et	4	main
ülikoolis	doc_802069853722_item	2882324	et	4	main
oma	doc_802069853722_item	2882330	et	4	main
keeleoskus	doc_802069853722_item	2882331	et	3	main
ja	doc_802069853722_item	2882332	et	3	main
õppida	doc_802069853722_item	2882333	et	3	main
eesti	doc_802069853722_item	2882339	et	4	main
vabariigis	doc_802069853722_item	2882340	et	3	main
keel	doc_802069853722_item	2882345	et	4	main
ja	doc_802069853722_item	2882346	et	3	main
keeles	doc_802069853722_item	2882353	et	4	main
essee	doc_802069853723_item	2882354	et	4	main
mina	doc_802069853723_item	2882370	et	4	main
aktiivne	doc_802069853723_item	2882372	et	3	main
ja	doc_802069853723_item	2882373	et	3	main
palju	doc_802069853723_item	2882380	et	4	main
meeldib	doc_802069853723_item	2882383	et	3	main
korv-	doc_802069853723_item	2882388	et	3	main
käin	doc_802069853723_item	2882392	et	3	main
sellepärast	doc_802069853723_item	2882398	et	3	main
mina	doc_802069853723_item	2882399	et	4	main
minusse	doc_802069853723_item	2882404	et	3	main
iga	doc_802069853723_item	2882411	et	4	main
kes	doc_802069853723_item	2882415	et	4	main
aastal	doc_802069853723_item	2882441	et	3	main
vanavanemad	doc_802069853723_item	2882448	et	4	main
sellepärast	doc_802069853723_item	2882451	et	3	main
ka	doc_802069853723_item	2882454	et	3	main
saada	doc_802069853723_item	2882456	et	4	main
kuulnud	doc_802069853723_item	2882458	et	4	main
et	doc_802069853723_item	2882459	et	3	main
kõige	doc_802069853723_item	2882462	et	4	main
siis	doc_802069853723_item	2882476	et	3	main
õppimine	doc_802069853723_item	2882491	et	4	main
kõrge	doc_802069853723_item	2882497	et	4	main
mulle	doc_802069853723_item	2882500	et	4	main
meeldib	doc_802069853723_item	2882501	et	3	main
eesti	doc_802069853723_item	2882502	et	4	main
keeli	doc_802069853723_item	2882506	et	4	main
õppida	doc_802069853723_item	2882507	et	3	main
eesti	doc_802069853723_item	2882514	et	4	main
küsimus	doc_802069853722_item	2882270	et	4	main
et	doc_802069853722_item	2882274	et	3	main
ehitajaks	doc_802069853722_item	2882277	et	4	main
aga	doc_802069853722_item	2882283	et	3	main
kõrgharidus	doc_802069853722_item	2882288	et	3	main
minu	doc_802069853722_item	2882289	et	3	main
väga	doc_802069853722_item	2882294	et	3	main
midagi	doc_802069853722_item	2882300	et	4	main
olen	doc_802069853722_item	2882305	et	3	main
palju	doc_802069853722_item	2882308	et	4	main
oma	doc_802069853722_item	2882309	et	4	main
sõpradest	doc_802069853722_item	2882310	et	3	main
ning	doc_802069853722_item	2882311	et	3	main
nädal	doc_802069853722_item	2882317	et	3	main
meeldib	doc_802069853722_item	2882322	et	3	main
keele	doc_802069853722_item	2882326	et	4	main
on	doc_802069853722_item	2882343	et	4	main
palju	doc_802069853722_item	2882349	et	4	main
eesti	doc_802069853722_item	2882352	et	4	main
narva	doc_802069853723_item	2882367	et	4	main
pähklimäe	doc_802069853723_item	2882368	et	3	main
gumnaasiumi	doc_802069853723_item	2882369	et	4	main
inimene	doc_802069853723_item	2882375	et	3	main
seetõttu	doc_802069853723_item	2882377	et	3	main
sõpru	doc_802069853723_item	2882381	et	3	main
tegeleda	doc_802069853723_item	2882385	et	3	main
ja	doc_802069853723_item	2882389	et	3	main
mõnikord	doc_802069853723_item	2882391	et	3	main
ujulas	doc_802069853723_item	2882394	et	3	main
meeldib	doc_802069853723_item	2882396	et	3	main
õppida	doc_802069853723_item	2882397	et	3	main
siis	doc_802069853723_item	2882405	et	3	main
inimese	doc_802069853723_item	2882412	et	4	main
asjatundjaks	doc_802069853723_item	2882417	et	3	main
peavad	doc_802069853723_item	2882419	et	4	main
perspektiivne	doc_802069853722_item	2882295	et	3	main
aeg	doc_802069853722_item	2882299	et	3	main
ehitatakse	doc_802069853722_item	2882301	et	3	main
siin	doc_802069853722_item	2882314	et	4	main
eesti	doc_802069853722_item	2882325	et	4	main
seda	doc_802069853722_item	2882334	et	3	main
et	doc_802069853722_item	2882337	et	3	main
eesti	doc_802069853722_item	2882344	et	4	main
suhelda	doc_802069853722_item	2882350	et	4	main
just	doc_802069853722_item	2882351	et	3	main
ülikool	doc_802069853723_item	2882357	et	4	main
minu	doc_802069853723_item	2882358	et	3	main
nimi	doc_802069853723_item	2882359	et	3	main
on	doc_802069853723_item	2882360	et	4	main
eesnimi	doc_802069853723_item	2882361	et	3	main
perekonnanimi	doc_802069853723_item	2882362	et	3	main
sellel	doc_802069853723_item	2882363	et	4	main
aastal	doc_802069853723_item	2882364	et	3	main
mina	doc_802069853723_item	2882365	et	4	main
olen	doc_802069853723_item	2882371	et	3	main
sõbralik	doc_802069853723_item	2882374	et	3	main
ja	doc_802069853723_item	2882376	et	3	main
mul	doc_802069853723_item	2882378	et	3	main
spordiga	doc_802069853723_item	2882384	et	3	main
praegu	doc_802069853723_item	2882386	et	3	main
ka	doc_802069853723_item	2882393	et	3	main
puutub	doc_802069853723_item	2882403	et	3	main
elus	doc_802069853723_item	2882413	et	4	main
tahavad	doc_802069853723_item	2882416	et	3	main
mina	doc_802069853723_item	2882435	et	4	main
õpetajaks	doc_802069853723_item	2882437	et	4	main
otsustasin	doc_802069853723_item	2882442	et	3	main
saada	doc_802069853723_item	2882444	et	4	main
vanemad	doc_802069853723_item	2882446	et	4	main
on	doc_802069853723_item	2882449	et	4	main
on	doc_802069853723_item	2882461	et	4	main
mulle	doc_802069853723_item	2882477	et	4	main
meeldib	doc_802069853723_item	2882478	et	3	main
siin	doc_802069853723_item	2882479	et	4	main
õppida	doc_802069853723_item	2882480	et	3	main
ja	doc_802069853723_item	2882481	et	3	main
elada	doc_802069853723_item	2882482	et	3	main
seal	doc_802069853723_item	2882492	et	4	main
elukogemus	doc_802069853723_item	2882495	et	3	main
tase	doc_802069853723_item	2882499	et	3	main
õppimine	doc_802069853723_item	2882512	et	4	main
keele	doc_802069853723_item	2882531	et	4	main
on	doc_802069853724_item	2882546	et	4	main
kõigil	doc_802069853724_item	2882550	et	4	main
unistused	doc_802069853724_item	2882556	et	4	main
ka	doc_802069853724_item	2882557	et	3	main
kõrgharidust	doc_802069853724_item	2882572	et	4	main
eesnimi	doc_802069853724_item	2882576	et	3	main
olen	doc_802069853724_item	2882578	et	3	main
eluaastast	doc_802069853724_item	2882592	et	4	main
unistust	doc_802069853724_item	2882600	et	4	main
minna	doc_802069853724_item	2882601	et	3	main
siiski	doc_802069853724_item	2882613	et	4	main
mõte	doc_802069853724_item	2882618	et	3	main
töö	doc_802069853724_item	2882634	et	4	main
enda	doc_802069853724_item	2882640	et	4	main
ümber	doc_802069853724_item	2882641	et	3	main
siis	doc_802069853724_item	2882642	et	3	main
ttü	doc_802069853724_item	2882655	et	4	main
sain	doc_802069853724_item	2882663	et	3	main
juba	doc_802069853724_item	2882664	et	3	main
et	doc_802069853724_item	2882666	et	3	main
ainult	doc_802069853724_item	2882670	et	4	main
ja	doc_802069853724_item	2882673	et	3	main
näiteks	doc_802069853724_item	2882677	et	4	main
et	doc_802069853724_item	2882681	et	3	main
saaks	doc_802069853724_item	2882683	et	3	main
ttü	doc_802069853724_item	2882694	et	4	main
hea	doc_802069853724_item	2882695	et	4	main
keele	doc_802069853724_item	2882708	et	4	main
ikka	doc_802069853724_item	2882711	et	4	main
eriala	doc_802069853724_item	2882721	et	4	main
juba	doc_802069853724_item	2882722	et	3	main
mitte	doc_802069853724_item	2882723	et	3	main
vene	doc_802069853724_item	2882724	et	4	main
astusin	doc_802069853723_item	2882400	et	3	main
ülikooli	doc_802069853723_item	2882401	et	4	main
mis	doc_802069853723_item	2882402	et	4	main
et	doc_802069853723_item	2882407	et	3	main
on	doc_802069853723_item	2882409	et	4	main
inimesed	doc_802069853723_item	2882414	et	3	main
mina	doc_802069853723_item	2882423	et	4	main
olen	doc_802069853723_item	2882424	et	3	main
esimese	doc_802069853723_item	2882425	et	3	main
kuursuse	doc_802069853723_item	2882426	et	4	main
ja	doc_802069853723_item	2882447	et	3	main
ingeneerid	doc_802069853723_item	2882450	et	4	main
otsustasin	doc_802069853723_item	2882452	et	3	main
mina	doc_802069853723_item	2882453	et	4	main
inseneeriks	doc_802069853723_item	2882455	et	4	main
olen	doc_802069853723_item	2882457	et	3	main
õppeasutus	doc_802069853723_item	2882465	et	4	main
eestis	doc_802069853723_item	2882466	et	3	main
sellepärast	doc_802069853723_item	2882467	et	3	main
valisin	doc_802069853723_item	2882468	et	3	main
ttü	doc_802069853723_item	2882469	et	4	main
astumiseks	doc_802069853723_item	2882470	et	4	main
kui	doc_802069853723_item	2882471	et	3	main
kirjutada	doc_802069853723_item	2882472	et	3	main
oma	doc_802069853723_item	2882473	et	4	main
muljetest	doc_802069853723_item	2882474	et	3	main
ttü	doc_802069853723_item	2882460	et	4	main
parem	doc_802069853723_item	2882463	et	4	main
ttüst	doc_802069853723_item	2882475	et	4	main
arvates	doc_802069853723_item	2882484	et	4	main
on	doc_802069853723_item	2882486	et	4	main
keele	doc_802069853723_item	2882511	et	4	main
on	doc_802069853723_item	2882516	et	4	main
riigi	doc_802069853723_item	2882517	et	3	main
keel	doc_802069853723_item	2882518	et	4	main
ja	doc_802069853723_item	2882519	et	3	main
jaoks	doc_802069853723_item	2882522	et	4	main
keelt	doc_802069853723_item	2882526	et	4	main
paremini	doc_802069853723_item	2882537	et	4	main
keeli	doc_802069853723_item	2882539	et	4	main
palju	doc_802069853724_item	2882547	et	4	main
neil	doc_802069853724_item	2882551	et	4	main
mul	doc_802069853724_item	2882558	et	3	main
on	doc_802069853724_item	2882560	et	4	main
eesmärgid	doc_802069853724_item	2882561	et	3	main
mida	doc_802069853724_item	2882562	et	4	main
ma	doc_802069853724_item	2882563	et	3	main
tahaksin	doc_802069853724_item	2882564	et	3	main
saavutada	doc_802069853724_item	2882565	et	3	main
elus	doc_802069853724_item	2882566	et	4	main
üks	doc_802069853724_item	2882567	et	3	main
minu	doc_802069853724_item	2882568	et	3	main
eesmärkidest	doc_802069853724_item	2882569	et	3	main
on	doc_802069853724_item	2882570	et	4	main
saada	doc_802069853724_item	2882571	et	4	main
minu	doc_802069853723_item	2882483	et	3	main
annab	doc_802069853723_item	2882493	et	3	main
suur	doc_802069853723_item	2882494	et	3	main
ja	doc_802069853723_item	2882496	et	3	main
õppimise	doc_802069853723_item	2882498	et	4	main
muid	doc_802069853723_item	2882505	et	4	main
sest	doc_802069853723_item	2882513	et	4	main
iga	doc_802069853723_item	2882520	et	4	main
eesti	doc_802069853723_item	2882525	et	4	main
teada	doc_802069853723_item	2882527	et	3	main
mina	doc_802069853723_item	2882528	et	4	main
ootan	doc_802069853723_item	2882529	et	3	main
mina	doc_802069853724_item	2882542	et	4	main
ja	doc_802069853724_item	2882543	et	3	main
erinevaid	doc_802069853724_item	2882548	et	4	main
on	doc_802069853724_item	2882552	et	4	main
on	doc_802069853724_item	2882575	et	4	main
ja	doc_802069853724_item	2882582	et	3	main
olen	doc_802069853724_item	2882593	et	3	main
nende	doc_802069853724_item	2882603	et	4	main
aastate	doc_802069853724_item	2882604	et	3	main
mul	doc_802069853724_item	2882607	et	3	main
isegi	doc_802069853724_item	2882609	et	4	main
hobide	doc_802069853724_item	2882610	et	3	main
õppisin	doc_802069853724_item	2882614	et	3	main
hiljuti	doc_802069853724_item	2882625	et	4	main
erialad	doc_802069853724_item	2882629	et	3	main
igalpool	doc_802069853724_item	2882631	et	4	main
vajatud	doc_802069853724_item	2882632	et	4	main
ja	doc_802069853724_item	2882633	et	3	main
kui	doc_802069853724_item	2882638	et	3	main
vaadata	doc_802069853724_item	2882639	et	4	main
midagi	doc_802069853724_item	2882644	et	4	main
ehitatakse	doc_802069853724_item	2882645	et	3	main
isegi	doc_802069853724_item	2882646	et	4	main
kui	doc_802069853724_item	2882647	et	3	main
võtta	doc_802069853724_item	2882648	et	3	main
väga	doc_802069853724_item	2882657	et	3	main
esimesel	doc_802069853724_item	2882661	et	3	main
ellu	doc_802069853724_item	2882669	et	4	main
kõige	doc_802069853724_item	2882671	et	4	main
otseses	doc_802069853724_item	2882675	et	3	main
võtta	doc_802069853724_item	2882679	et	3	main
väga	doc_802069853724_item	2882686	et	3	main
ülbe	doc_802069853724_item	2882687	et	4	main
olema	doc_802069853724_item	2882691	et	4	main
avaldanud	doc_802069853724_item	2882697	et	4	main
tähtsam	doc_802069853724_item	2882706	et	4	main
oma	doc_802069853724_item	2882720	et	4	main
huvitab	doc_802069853723_item	2882509	et	3	main
eesti	doc_802069853723_item	2882510	et	4	main
keel	doc_802069853723_item	2882515	et	4	main
kodaniku	doc_802069853723_item	2882521	et	3	main
on	doc_802069853723_item	2882523	et	4	main
tähtis	doc_802069853723_item	2882524	et	4	main
eesti	doc_802069853723_item	2882530	et	4	main
loendutelt	doc_802069853723_item	2882532	et	4	main
et	doc_802069853723_item	2882533	et	3	main
nad	doc_802069853723_item	2882534	et	3	main
annavad	doc_802069853723_item	2882535	et	3	main
võimaluse	doc_802069853723_item	2882536	et	3	main
eesti	doc_802069853723_item	2882538	et	4	main
teadma	doc_802069853723_item	2882540	et	3	main
essee	doc_802069853724_item	2882541	et	4	main
ülikool	doc_802069853724_item	2882544	et	4	main
maailmas	doc_802069853724_item	2882545	et	3	main
inimesi	doc_802069853724_item	2882549	et	4	main
omad	doc_802069853724_item	2882553	et	4	main
eesmärgid	doc_802069853724_item	2882554	et	3	main
ja	doc_802069853724_item	2882555	et	3	main
endal	doc_802069853724_item	2882559	et	4	main
minu	doc_802069853724_item	2882573	et	3	main
ma	doc_802069853724_item	2882577	et	3	main
aastat	doc_802069853724_item	2882580	et	3	main
väikesest	doc_802069853724_item	2882584	et	4	main
nimeks	doc_802069853724_item	2882587	et	3	main
on	doc_802069853724_item	2882588	et	4	main
paide	doc_802069853724_item	2882589	et	4	main
juba	doc_802069853724_item	2882590	et	3	main
kuuendast	doc_802069853724_item	2882591	et	3	main
ja	doc_802069853724_item	2882596	et	3	main
ajanud	doc_802069853724_item	2882597	et	4	main
vältel	doc_802069853724_item	2882605	et	4	main
ent	doc_802069853724_item	2882612	et	3	main
minna	doc_802069853724_item	2882619	et	3	main
ehituse	doc_802069853724_item	2882621	et	4	main
inseneriks	doc_802069853724_item	2882622	et	3	main
tuli	doc_802069853724_item	2882623	et	4	main
mul	doc_802069853724_item	2882624	et	3	main
seotud	doc_802069853724_item	2882628	et	4	main
igalpool	doc_802069853724_item	2882643	et	4	main
käivad	doc_802069853724_item	2882652	et	4	main
praegu	doc_802069853724_item	2882653	et	3	main
renoveerimistööd	doc_802069853724_item	2882654	et	4	main
suur	doc_802069853724_item	2882658	et	3	main
kool	doc_802069853724_item	2882659	et	4	main
nädalal	doc_802069853724_item	2882662	et	3	main
aru	doc_802069853724_item	2882665	et	4	main
seda	doc_802069853724_item	2882674	et	3	main
kui	doc_802069853724_item	2882678	et	3	main
süüa	doc_802069853724_item	2882682	et	3	main
kas	doc_802069853724_item	2882685	et	3	main
või	doc_802069853724_item	2882688	et	4	main
kaval	doc_802069853724_item	2882690	et	4	main
üldiselt	doc_802069853724_item	2882692	et	4	main
on	doc_802069853724_item	2882693	et	4	main
inimesed	doc_802069853724_item	2882698	et	3	main
on	doc_802069853724_item	2882699	et	4	main
sõbralikud	doc_802069853724_item	2882700	et	3	main
ja	doc_802069853724_item	2882701	et	3	main
abivalmis	doc_802069853724_item	2882702	et	3	main
kõige	doc_802069853724_item	2882705	et	4	main
et	doc_802069853724_item	2882713	et	3	main
pärast	doc_802069853724_item	2882715	et	4	main
oleksin	doc_802069853724_item	2882716	et	3	main
valmis	doc_802069853724_item	2882717	et	4	main
minna	doc_802069853724_item	2882718	et	3	main
õppima	doc_802069853724_item	2882719	et	3	main
keeles	doc_802069853724_item	2882725	et	4	main
vaid	doc_802069853724_item	2882726	et	3	main
tulen	doc_802069853724_item	2882583	et	3	main
mille	doc_802069853724_item	2882586	et	3	main
sukeldunud	doc_802069853724_item	2882594	et	4	main
kõrgkooli	doc_802069853724_item	2882602	et	4	main
polnud	doc_802069853724_item	2882606	et	3	main
aega	doc_802069853724_item	2882608	et	4	main
jaoks	doc_802069853724_item	2882611	et	4	main
keskmiselt	doc_802069853724_item	2882615	et	4	main
näiteks	doc_802069853724_item	2882649	et	4	main
ttü	doc_802069853724_item	2882650	et	4	main
nimi	doc_802069853724_item	2882574	et	3	main
kaheksateist	doc_802069853724_item	2882579	et	4	main
vana	doc_802069853724_item	2882581	et	4	main
linnast	doc_802069853724_item	2882585	et	4	main
õpikutesse	doc_802069853724_item	2882595	et	3	main
taga	doc_802069853724_item	2882598	et	4	main
oma	doc_802069853724_item	2882599	et	4	main
neljadele	doc_802069853724_item	2882616	et	3	main
viitele	doc_802069853724_item	2882617	et	4	main
õppima	doc_802069853724_item	2882620	et	3	main
sest	doc_802069853724_item	2882626	et	4	main
ehitusega	doc_802069853724_item	2882627	et	4	main
on	doc_802069853724_item	2882630	et	4	main
on	doc_802069853724_item	2882635	et	4	main
koguaeg	doc_802069853724_item	2882636	et	3	main
olemas	doc_802069853724_item	2882637	et	4	main
kus	doc_802069853724_item	2882651	et	3	main
on	doc_802069853724_item	2882656	et	4	main
ja	doc_802069853724_item	2882660	et	3	main
siin	doc_802069853724_item	2882667	et	4	main
jäävad	doc_802069853724_item	2882668	et	4	main
tugevamad	doc_802069853724_item	2882672	et	4	main
mõttes	doc_802069853724_item	2882676	et	3	main
söökla	doc_802069853724_item	2882680	et	4	main
pead	doc_802069853724_item	2882684	et	4	main
väga	doc_802069853724_item	2882689	et	3	main
mulje	doc_802069853724_item	2882696	et	4	main
on	doc_802069853724_item	2882704	et	4	main
eesti	doc_802069853724_item	2882707	et	4	main
ootan	doc_802069853724_item	2882710	et	3	main
seda	doc_802069853724_item	2882712	et	3	main
aasta	doc_802069853724_item	2882714	et	4	main
keeles	doc_802069853724_item	2882728	et	4	main
07777	doc_802069853727_item	2882996	et	2	main
tlvl	doc_802069853727_item	2882999	et	4	main
tartu	doc_802069853727_item	2883015	et	4	main
see	doc_802069853724_item	2882703	et	3	main
loengutest	doc_802069853724_item	2882709	et	4	main
eesti	doc_802069853724_item	2882727	et	4	main
essee	doc_802069853727_item	2882990	et	4	main
ülikool	doc_802069853727_item	2882993	et	4	main
mina	doc_802069853727_item	2882997	et	4	main
lõpetasin	doc_802069853727_item	2882998	et	3	main
tulesin	doc_802069853727_item	2883009	et	4	main
sellel	doc_802069853727_item	2883010	et	4	main
erialal	doc_802069853727_item	2883011	et	3	main
ülikoolisse	doc_802069853727_item	2883016	et	4	main
kes	doc_802069853727_item	2883022	et	4	main
õpivad	doc_802069853727_item	2883023	et	3	main
või	doc_802069853727_item	2883027	et	4	main
selle	doc_802069853727_item	2883030	et	4	main
palju	doc_802069853727_item	2883034	et	4	main
on	doc_802069853727_item	2883041	et	4	main
tundid	doc_802069853727_item	2883046	et	4	main
ja	doc_802069853727_item	2883047	et	3	main
palju	doc_802069853727_item	2883051	et	4	main
ma	doc_802069853727_item	2883058	et	3	main
eesti	doc_802069853727_item	2883060	et	4	main
loengutest	doc_802069853727_item	2883062	et	4	main
ja	doc_802069853727_item	2883063	et	3	main
ööelda	doc_802069853727_item	2883069	et	4	main
praegu	doc_802069853727_item	2883070	et	3	main
mina	doc_802069853728_item	2883090	et	4	main
olen	doc_802069853728_item	2883091	et	3	main
19	doc_802069853728_item	2883092	et	2	main
aastat	doc_802069853728_item	2883093	et	3	main
olen	doc_802069853728_item	2883102	et	3	main
sillamäel	doc_802069853728_item	2883104	et	3	main
aastal	doc_802069853728_item	2883106	et	3	main
kerge	doc_802069853728_item	2883127	et	4	main
selepärast	doc_802069853728_item	2883134	et	4	main
ttü	doc_802069853728_item	2883143	et	4	main
sain	doc_802069853728_item	2883145	et	3	main
töökoht	doc_802069853728_item	2883146	et	3	main
toob	doc_802069853728_item	2883148	et	3	main
palju	doc_802069853728_item	2883149	et	4	main
elan	doc_802069853728_item	2883176	et	3	main
arvan	doc_802069853728_item	2883179	et	3	main
remonti	doc_802069853728_item	2883183	et	4	main
ma	doc_802069853728_item	2883196	et	3	main
keelt	doc_802069853728_item	2883224	et	4	main
mina	doc_802069853729_item	2883226	et	4	main
keskkool	doc_802069853729_item	2883238	et	4	main
ma	doc_802069853729_item	2883239	et	3	main
mina	doc_802069853727_item	2883000	et	4	main
olen	doc_802069853727_item	2883001	et	3	main
18	doc_802069853727_item	2883002	et	2	main
aastat	doc_802069853727_item	2883003	et	3	main
sest	doc_802069853727_item	2883012	et	4	main
füsikale	doc_802069853727_item	2883017	et	4	main
mul	doc_802069853727_item	2883018	et	3	main
palju	doc_802069853727_item	2883020	et	4	main
sõbrat	doc_802069853727_item	2883021	et	4	main
sellel	doc_802069853727_item	2883024	et	4	main
erialal	doc_802069853727_item	2883025	et	3	main
neljandal	doc_802069853727_item	2883028	et	3	main
ma	doc_802069853727_item	2883032	et	3	main
matemaatika	doc_802069853727_item	2883043	et	4	main
ja	doc_802069853727_item	2883044	et	3	main
füsika	doc_802069853727_item	2883045	et	4	main
saan	doc_802069853727_item	2883049	et	4	main
asjad	doc_802069853727_item	2883053	et	3	main
ei	doc_802069853727_item	2883055	et	4	main
keele	doc_802069853727_item	2883061	et	4	main
see	doc_802069853727_item	2883064	et	3	main
pärast	doc_802069853727_item	2883065	et	4	main
essee	doc_802069853728_item	2883086	et	4	main
mina	doc_802069853728_item	2883087	et	4	main
ja	doc_802069853728_item	2883088	et	3	main
perekonnanimi	doc_802069853728_item	2883100	et	3	main
lõpesin	doc_802069853728_item	2883108	et	4	main
sillamäe	doc_802069853728_item	2883109	et	3	main
kannuka	doc_802069853728_item	2883110	et	4	main
ei	doc_802069853728_item	2883119	et	4	main
väga	doc_802069853728_item	2883121	et	3	main
popularne	doc_802069853728_item	2883122	et	4	main
ja	doc_802069853728_item	2883123	et	3	main
arvutid	doc_802069853728_item	2883129	et	4	main
ja	doc_802069853728_item	2883133	et	3	main
muljed	doc_802069853728_item	2883152	et	3	main
vaga	doc_802069853728_item	2883154	et	4	main
on	doc_802069853728_item	2883157	et	4	main
lõbusad	doc_802069853728_item	2883158	et	3	main
ja	doc_802069853728_item	2883159	et	3	main
õpetavad	doc_802069853728_item	2883163	et	4	main
kergesti	doc_802069853728_item	2883164	et	3	main
ja	doc_802069853728_item	2883165	et	3	main
ma	doc_802069853728_item	2883166	et	3	main
mina	doc_802069853727_item	2882991	et	4	main
mina	doc_802069853727_item	2882994	et	4	main
olen	doc_802069853727_item	2882995	et	3	main
ei	doc_802069853727_item	2883013	et	4	main
kolmandal	doc_802069853727_item	2883026	et	3	main
pärast	doc_802069853727_item	2883031	et	4	main
tean	doc_802069853727_item	2883033	et	3	main
sellest	doc_802069853727_item	2883035	et	4	main
teaduskonnast	doc_802069853727_item	2883036	et	4	main
ma	doc_802069853727_item	2883037	et	3	main
loodan	doc_802069853727_item	2883038	et	3	main
palju	doc_802069853727_item	2883042	et	4	main
ma	doc_802069853727_item	2883048	et	3	main
teada	doc_802069853727_item	2883050	et	3	main
uut	doc_802069853727_item	2883052	et	3	main
tea	doc_802069853727_item	2883056	et	4	main
ootan	doc_802069853727_item	2883059	et	3	main
ülikool	doc_802069853728_item	2883089	et	4	main
ma	doc_802069853728_item	2883101	et	3	main
gümnaasiumi	doc_802069853728_item	2883112	et	4	main
ja	doc_802069853728_item	2883113	et	3	main
olen	doc_802069853728_item	2883114	et	3	main
seal	doc_802069853728_item	2883124	et	4	main
on	doc_802069853728_item	2883125	et	4	main
asutama	doc_802069853728_item	2883128	et	4	main
hobby	doc_802069853728_item	2883132	et	4	main
ma	doc_802069853728_item	2883135	et	3	main
valesin	doc_802069853728_item	2883136	et	4	main
it	doc_802069853728_item	2883137	et	4	main
osakond	doc_802069853728_item	2883138	et	3	main
arvan	doc_802069853728_item	2883139	et	3	main
et	doc_802069853728_item	2883140	et	3	main
ma	doc_802069853728_item	2883141	et	3	main
ja	doc_802069853728_item	2883144	et	3	main
raha	doc_802069853728_item	2883150	et	4	main
on	doc_802069853728_item	2883153	et	4	main
optimistlikud	doc_802069853728_item	2883155	et	3	main
lektorid	doc_802069853728_item	2883156	et	3	main
inimesed	doc_802069853728_item	2883161	et	3	main
nad	doc_802069853728_item	2883162	et	3	main
ma	doc_802069853728_item	2883172	et	3	main
olen	doc_802069853728_item	2883173	et	3	main
sillamaelt	doc_802069853728_item	2883174	et	4	main
ühiselamuses	doc_802069853728_item	2883177	et	3	main
et	doc_802069853728_item	2883180	et	3	main
teha	doc_802069853728_item	2883184	et	3	main
eesti	doc_802069853728_item	2883188	et	4	main
riigikeel	doc_802069853728_item	2883191	et	4	main
aga	doc_802069853728_item	2883192	et	3	main
ma	doc_802069853728_item	2883193	et	3	main
olen	doc_802069853728_item	2883194	et	3	main
raske	doc_802069853728_item	2883201	et	4	main
võimalus	doc_802069853728_item	2883209	et	3	main
ja	doc_802069853727_item	2882992	et	3	main
vana	doc_802069853727_item	2883004	et	4	main
ja	doc_802069853727_item	2883005	et	3	main
olen	doc_802069853727_item	2883006	et	3	main
noormees	doc_802069853727_item	2883007	et	4	main
ma	doc_802069853727_item	2883008	et	3	main
aastunud	doc_802069853727_item	2883014	et	4	main
on	doc_802069853727_item	2883019	et	4	main
kursusel	doc_802069853727_item	2883029	et	3	main
sest	doc_802069853727_item	2883039	et	4	main
ttüs	doc_802069853727_item	2883040	et	4	main
ma	doc_802069853727_item	2883054	et	3	main
mida	doc_802069853727_item	2883057	et	4	main
ei	doc_802069853727_item	2883066	et	4	main
saa	doc_802069853727_item	2883067	et	4	main
midagi	doc_802069853727_item	2883068	et	4	main
võib	doc_802069853727_item	2883071	et	3	main
olla	doc_802069853727_item	2883072	et	3	main
tulevikust	doc_802069853727_item	2883073	et	4	main
ma	doc_802069853727_item	2883074	et	3	main
võin	doc_802069853727_item	2883075	et	3	main
öelda	doc_802069853727_item	2883076	et	4	main
midagi	doc_802069853727_item	2883077	et	4	main
aga	doc_802069853727_item	2883078	et	3	main
praegu	doc_802069853727_item	2883079	et	3	main
ei	doc_802069853727_item	2883080	et	4	main
saa	doc_802069853727_item	2883081	et	4	main
kõige	doc_802069853727_item	2883082	et	4	main
paremaks	doc_802069853727_item	2883083	et	4	main
number	doc_802069853727_item	2883084	et	3	main
vana	doc_802069853728_item	2883094	et	4	main
üliõpilane	doc_802069853728_item	2883095	et	3	main
minu	doc_802069853728_item	2883096	et	3	main
nimi	doc_802069853728_item	2883097	et	3	main
on	doc_802069853728_item	2883098	et	4	main
eesnimi	doc_802069853728_item	2883099	et	3	main
sündinud	doc_802069853728_item	2883103	et	4	main
seal	doc_802069853728_item	2883105	et	4	main
ma	doc_802069853728_item	2883107	et	3	main
vastuvõetud	doc_802069853728_item	2883115	et	4	main
ttüs	doc_802069853728_item	2883116	et	4	main
elektroonika	doc_802069853728_item	2883117	et	4	main
ole	doc_802069853728_item	2883120	et	4	main
väga	doc_802069853728_item	2883126	et	3	main
on	doc_802069853728_item	2883130	et	4	main
minu	doc_802069853728_item	2883131	et	3	main
lõpesin	doc_802069853728_item	2883142	et	4	main
mis	doc_802069853728_item	2883147	et	4	main
esimesed	doc_802069853728_item	2883151	et	3	main
arusaamavad	doc_802069853728_item	2883160	et	4	main
aru	doc_802069853728_item	2883168	et	4	main
kõik	doc_802069853728_item	2883170	et	4	main
sest	doc_802069853728_item	2883171	et	4	main
ma	doc_802069853728_item	2883178	et	3	main
võib	doc_802069853728_item	2883182	et	3	main
naabrid	doc_802069853728_item	2883185	et	3	main
venelane	doc_802069853728_item	2883195	et	3	main
on	doc_802069853728_item	2883200	et	4	main
keel	doc_802069853728_item	2883202	et	4	main
õppima	doc_802069853728_item	2883203	et	3	main
sillamäel	doc_802069853728_item	2883204	et	3	main
sest	doc_802069853728_item	2883205	et	4	main
eesti	doc_802069853728_item	2883210	et	4	main
keelt	doc_802069853728_item	2883211	et	4	main
vestelda	doc_802069853728_item	2883212	et	4	main
sooviksin	doc_802069853728_item	2883213	et	3	main
et	doc_802069853728_item	2883214	et	3	main
tallinnas	doc_802069853728_item	2883215	et	4	main
ma	doc_802069853728_item	2883216	et	3	main
sain	doc_802069853728_item	2883217	et	3	main
uued	doc_802069853728_item	2883218	et	3	main
eestlased	doc_802069853728_item	2883219	et	3	main
sõbrad	doc_802069853728_item	2883220	et	3	main
eesti	doc_802069853728_item	2883223	et	4	main
essee	doc_802069853729_item	2883225	et	4	main
ülikool	doc_802069853729_item	2883228	et	4	main
ma	doc_802069853729_item	2883233	et	3	main
olen	doc_802069853729_item	2883234	et	3	main
pärit	doc_802069853729_item	2883235	et	3	main
narvas	doc_802069853729_item	2883236	et	4	main
olla	doc_802069853729_item	2883241	et	3	main
spetsialist	doc_802069853729_item	2883242	et	3	main
ttüs	doc_802069853729_item	2883245	et	4	main
koolis	doc_802069853729_item	2883249	et	4	main
minu	doc_802069853729_item	2883250	et	3	main
sest	doc_802069853729_item	2883257	et	4	main
ma	doc_802069853729_item	2883258	et	3	main
ja	doc_802069853729_item	2883261	et	3	main
ttü	doc_802069853729_item	2883267	et	4	main
palju	doc_802069853729_item	2883271	et	4	main
huvialad	doc_802069853729_item	2883275	et	3	main
ülekoolis	doc_802069853729_item	2883285	et	4	main
ma	doc_802069853729_item	2883286	et	3	main
loodan	doc_802069853729_item	2883287	et	3	main
et	doc_802069853729_item	2883288	et	3	main
see	doc_802069853729_item	2883289	et	3	main
rägina	doc_802069853729_item	2883295	et	3	main
just	doc_802069853730_item	2883324	et	3	main
sobivad	doc_802069853730_item	2883335	et	4	main
ma	doc_802069853730_item	2883336	et	3	main
aru	doc_802069853730_item	2883338	et	4	main
07777	doc_802069853727_item	2883085	et	2	main
kooli	doc_802069853728_item	2883111	et	4	main
eriala	doc_802069853728_item	2883118	et	4	main
saan	doc_802069853728_item	2883167	et	4	main
alati	doc_802069853728_item	2883169	et	4	main
ma	doc_802069853728_item	2883175	et	3	main
seal	doc_802069853728_item	2883181	et	4	main
sõbralikud	doc_802069853728_item	2883187	et	3	main
et	doc_802069853728_item	2883198	et	3	main
see	doc_802069853728_item	2883199	et	3	main
ja	doc_802069853728_item	2883221	et	3	main
ja	doc_802069853729_item	2883227	et	3	main
mina	doc_802069853729_item	2883229	et	4	main
olen	doc_802069853729_item	2883230	et	3	main
eesnimi	doc_802069853729_item	2883231	et	3	main
perekonnanimi	doc_802069853729_item	2883232	et	3	main
sovin	doc_802069853729_item	2883240	et	4	main
ja	doc_802069853729_item	2883243	et	3	main
arvuti	doc_802069853729_item	2883253	et	4	main
süstemi	doc_802069853729_item	2883262	et	4	main
mulle	doc_802069853729_item	2883264	et	4	main
noormehed	doc_802069853729_item	2883272	et	3	main
ma	doc_802069853729_item	2883276	et	3	main
et	doc_802069853729_item	2883278	et	3	main
loengut	doc_802069853729_item	2883281	et	3	main
aitab	doc_802069853729_item	2883282	et	3	main
suhtleda	doc_802069853729_item	2883284	et	4	main
keles	doc_802069853729_item	2883297	et	4	main
essee	doc_802069853730_item	2883298	et	4	main
mina	doc_802069853730_item	2883299	et	4	main
keskkoolis	doc_802069853730_item	2883321	et	4	main
ma	doc_802069853730_item	2883322	et	3	main
tulin	doc_802069853730_item	2883323	et	3	main
pärast	doc_802069853730_item	2883329	et	4	main
et	doc_802069853730_item	2883330	et	3	main
teised	doc_802069853730_item	2883331	et	4	main
erialad	doc_802069853730_item	2883332	et	3	main
arvutiga	doc_802069853730_item	2883339	et	4	main
et	doc_802069853730_item	2883352	et	3	main
väikes	doc_802069853730_item	2883355	et	4	main
koorusd	doc_802069853730_item	2883359	et	4	main
oli	doc_802069853730_item	2883361	et	3	main
lõppeda	doc_802069853730_item	2883364	et	3	main
saada	doc_802069853730_item	2883367	et	4	main
essee	doc_802069853731_item	2883378	et	4	main
ja	doc_802069853731_item	2883380	et	3	main
minu	doc_802069853731_item	2883382	et	3	main
nimi	doc_802069853731_item	2883383	et	3	main
on	doc_802069853731_item	2883384	et	4	main
eesnimi	doc_802069853731_item	2883385	et	3	main
perekonnanimi	doc_802069853731_item	2883386	et	3	main
ma	doc_802069853731_item	2883387	et	3	main
olen	doc_802069853731_item	2883388	et	3	main
õppinud	doc_802069853731_item	2883389	et	4	main
sillamäe	doc_802069853731_item	2883390	et	3	main
on	doc_802069853731_item	2883409	et	4	main
väga	doc_802069853731_item	2883410	et	3	main
elus	doc_802069853731_item	2883413	et	4	main
ttüs	doc_802069853731_item	2883417	et	4	main
siis	doc_802069853731_item	2883424	et	3	main
ma	doc_802069853731_item	2883425	et	3	main
elektroonika	doc_802069853731_item	2883431	et	4	main
ja	doc_802069853731_item	2883432	et	3	main
ma	doc_802069853731_item	2883433	et	3	main
eriala	doc_802069853731_item	2883437	et	4	main
on	doc_802069853731_item	2883455	et	4	main
väga	doc_802069853731_item	2883456	et	3	main
suur	doc_802069853731_item	2883457	et	3	main
kõik	doc_802069853731_item	2883466	et	4	main
lektorit	doc_802069853731_item	2883467	et	3	main
kõikides	doc_802069853731_item	2883473	et	4	main
olin	doc_802069853731_item	2883477	et	3	main
head	doc_802069853731_item	2883479	et	4	main
inimised	doc_802069853731_item	2883480	et	4	main
väga	doc_802069853731_item	2883484	et	3	main
kaa	doc_802069853731_item	2883488	et	4	main
mõtlen	doc_802069853731_item	2883516	et	3	main
ei	doc_802069853731_item	2883519	et	4	main
on	doc_802069853728_item	2883186	et	4	main
keel	doc_802069853728_item	2883189	et	4	main
on	doc_802069853728_item	2883190	et	4	main
arvan	doc_802069853728_item	2883197	et	3	main
seal	doc_802069853728_item	2883206	et	4	main
ei	doc_802069853728_item	2883207	et	4	main
ole	doc_802069853728_item	2883208	et	4	main
õpetan	doc_802069853728_item	2883222	et	3	main
lõpuksin	doc_802069853729_item	2883237	et	4	main
tulin	doc_802069853729_item	2883244	et	3	main
kuidas	doc_802069853729_item	2883246	et	3	main
ma	doc_802069853729_item	2883247	et	3	main
õpisin	doc_802069853729_item	2883248	et	4	main
ja	doc_802069853729_item	2883254	et	3	main
intenet	doc_802069853729_item	2883255	et	4	main
ja	doc_802069853729_item	2883256	et	3	main
arvuti	doc_802069853729_item	2883260	et	4	main
tehnika	doc_802069853729_item	2883263	et	4	main
väga	doc_802069853729_item	2883265	et	3	main
meldib	doc_802069853729_item	2883266	et	4	main
on	doc_802069853729_item	2883270	et	4	main
koos	doc_802069853729_item	2883273	et	4	main
arvan	doc_802069853729_item	2883277	et	3	main
pärast	doc_802069853729_item	2883291	et	4	main
hea	doc_802069853729_item	2883294	et	4	main
ja	doc_802069853730_item	2883300	et	3	main
ülikool	doc_802069853730_item	2883301	et	4	main
mina	doc_802069853730_item	2883302	et	4	main
on	doc_802069853730_item	2883303	et	4	main
eesnimi	doc_802069853730_item	2883304	et	3	main
mina	doc_802069853730_item	2883305	et	4	main
lõpetasin	doc_802069853730_item	2883306	et	3	main
haabersti	doc_802069853730_item	2883307	et	4	main
vene	doc_802069853730_item	2883308	et	4	main
eragünasim	doc_802069853730_item	2883309	et	4	main
seal	doc_802069853730_item	2883310	et	4	main
ma	doc_802069853730_item	2883311	et	3	main
õpetasin	doc_802069853730_item	2883312	et	3	main
viis	doc_802069853730_item	2883313	et	4	main
aasta	doc_802069853730_item	2883314	et	4	main
enam	doc_802069853730_item	2883315	et	4	main
ma	doc_802069853730_item	2883316	et	3	main
õpetasin	doc_802069853730_item	2883317	et	3	main
seitse	doc_802069853730_item	2883318	et	3	main
aasta	doc_802069853730_item	2883319	et	4	main
kuues	doc_802069853730_item	2883320	et	4	main
selle	doc_802069853730_item	2883328	et	4	main
ei	doc_802069853730_item	2883334	et	4	main
minu	doc_802069853730_item	2883341	et	3	main
esimine	doc_802069853730_item	2883342	et	4	main
õppesin	doc_802069853730_item	2883354	et	4	main
ainult	doc_802069853730_item	2883357	et	4	main
seal	doc_802069853730_item	2883360	et	4	main
hea	doc_802069853730_item	2883368	et	4	main
et	doc_802069853730_item	2883370	et	3	main
ma	doc_802069853730_item	2883371	et	3	main
saan	doc_802069853730_item	2883372	et	4	main
töötada	doc_802069853730_item	2883373	et	3	main
heas	doc_802069853730_item	2883374	et	3	main
ja	doc_802069853730_item	2883375	et	3	main
suures	doc_802069853730_item	2883376	et	3	main
huvi	doc_802069853729_item	2883251	et	4	main
oli	doc_802069853729_item	2883252	et	3	main
vali	doc_802069853729_item	2883259	et	4	main
sest	doc_802069853729_item	2883268	et	4	main
seal	doc_802069853729_item	2883269	et	4	main
erinevad	doc_802069853729_item	2883274	et	4	main
loengut	doc_802069853729_item	2883290	et	3	main
ma	doc_802069853729_item	2883292	et	3	main
selle	doc_802069853730_item	2883325	et	4	main
eriala	doc_802069853730_item	2883326	et	4	main
õppid	doc_802069853730_item	2883327	et	4	main
mulle	doc_802069853730_item	2883333	et	4	main
saan	doc_802069853730_item	2883337	et	4	main
parem	doc_802069853730_item	2883340	et	4	main
mulje	doc_802069853730_item	2883343	et	4	main
ttüst	doc_802069853730_item	2883344	et	4	main
oli	doc_802069853730_item	2883345	et	3	main
oi	doc_802069853730_item	2883346	et	3	main
kui	doc_802069853730_item	2883347	et	3	main
suur	doc_802069853730_item	2883348	et	3	main
see	doc_802069853730_item	2883349	et	3	main
ma	doc_802069853730_item	2883353	et	3	main
koolis	doc_802069853730_item	2883356	et	4	main
tahan	doc_802069853730_item	2883363	et	3	main
ülikooli	doc_802069853730_item	2883365	et	4	main
ja	doc_802069853730_item	2883366	et	3	main
haridus	doc_802069853730_item	2883369	et	3	main
ma	doc_802069853731_item	2883395	et	3	main
olen	doc_802069853731_item	2883399	et	3	main
aastat	doc_802069853731_item	2883401	et	3	main
meie	doc_802069853731_item	2883412	et	4	main
ma	doc_802069853731_item	2883414	et	3	main
et	doc_802069853731_item	2883416	et	3	main
sa	doc_802069853731_item	2883418	et	3	main
asutasin	doc_802069853731_item	2883426	et	3	main
mõtlen	doc_802069853731_item	2883434	et	3	main
see	doc_802069853731_item	2883436	et	3	main
toob	doc_802069853731_item	2883438	et	3	main
hea	doc_802069853731_item	2883447	et	4	main
maja	doc_802069853731_item	2883458	et	4	main
aga	doc_802069853731_item	2883459	et	3	main
praegu	doc_802069853731_item	2883460	et	3	main
mulle	doc_802069853731_item	2883461	et	4	main
kui	doc_802069853731_item	2883470	et	3	main
on	doc_802069853731_item	2883471	et	4	main
auditooriumites	doc_802069853731_item	2883474	et	3	main
see	doc_802069853731_item	2883486	et	3	main
et	doc_802069853731_item	2883517	et	3	main
tallinas	doc_802069853731_item	2883529	et	4	main
siis	doc_802069853731_item	2883533	et	3	main
tallinnas	doc_802069853731_item	2883537	et	4	main
ma	doc_802069853731_item	2883538	et	3	main
eesti	doc_802069853731_item	2883541	et	4	main
aitasid	doc_802069853731_item	2883550	et	4	main
ja	doc_802069853732_item	2883556	et	3	main
pärnu	doc_802069853732_item	2883565	et	4	main
8	doc_802069853732_item	2883579	et	2	main
kaitsen	doc_802069853732_item	2883582	et	4	main
sain	doc_802069853732_item	2883591	et	3	main
mõtlen	doc_802069853732_item	2883625	et	3	main
et	doc_802069853732_item	2883637	et	3	main
ja	doc_802069853732_item	2883640	et	3	main
kõrgemalt	doc_802069853732_item	2883644	et	4	main
praegu	doc_802069853732_item	2883646	et	3	main
perekonnanimi	doc_802069853732_item	2883649	et	3	main
eesti	doc_802069853729_item	2883279	et	4	main
keele	doc_802069853729_item	2883280	et	4	main
mulle	doc_802069853729_item	2883283	et	4	main
olla	doc_802069853729_item	2883293	et	3	main
eesti	doc_802069853729_item	2883296	et	4	main
on	doc_802069853730_item	2883350	et	4	main
sellest	doc_802069853730_item	2883351	et	4	main
kaks	doc_802069853730_item	2883358	et	3	main
ma	doc_802069853730_item	2883362	et	3	main
mina	doc_802069853731_item	2883379	et	4	main
koolis	doc_802069853731_item	2883392	et	4	main
vaja	doc_802069853731_item	2883411	et	4	main
võid	doc_802069853731_item	2883419	et	4	main
saada	doc_802069853731_item	2883420	et	4	main
on	doc_802069853731_item	2883430	et	4	main
palju	doc_802069853731_item	2883439	et	4	main
raha	doc_802069853731_item	2883440	et	4	main
ma	doc_802069853731_item	2883441	et	3	main
sooviksin	doc_802069853731_item	2883442	et	3	main
lõpetada	doc_802069853731_item	2883443	et	3	main
diploom	doc_802069853731_item	2883448	et	4	main
mulje	doc_802069853731_item	2883450	et	4	main
et	doc_802069853731_item	2883452	et	3	main
ttü	doc_802069853731_item	2883453	et	4	main
see	doc_802069853731_item	2883454	et	3	main
kõik	doc_802069853731_item	2883462	et	4	main
meeldib	doc_802069853731_item	2883463	et	3	main
arvan	doc_802069853731_item	2883464	et	3	main
et	doc_802069853731_item	2883465	et	3	main
aidata	doc_802069853731_item	2883469	et	4	main
probleemid	doc_802069853731_item	2883472	et	3	main
kus	doc_802069853731_item	2883475	et	3	main
ma	doc_802069853731_item	2883476	et	3	main
õppehooned	doc_802069853731_item	2883481	et	4	main
vanad	doc_802069853731_item	2883485	et	3	main
eesti	doc_802069853731_item	2883521	et	4	main
on	doc_802069853731_item	2883525	et	4	main
vene	doc_802069853731_item	2883526	et	4	main
linn	doc_802069853731_item	2883527	et	3	main
aga	doc_802069853731_item	2883528	et	3	main
eestlasi	doc_802069853731_item	2883532	et	3	main
arvan	doc_802069853731_item	2883535	et	3	main
hea	doc_802069853731_item	2883544	et	4	main
ja	doc_802069853731_item	2883545	et	3	main
sooviksin	doc_802069853731_item	2883546	et	3	main
et	doc_802069853731_item	2883547	et	3	main
lektoorid	doc_802069853731_item	2883548	et	4	main
linnas	doc_802069853732_item	2883563	et	4	main
lõpetasin	doc_802069853732_item	2883564	et	3	main
pärnu	doc_802069853732_item	2883585	et	4	main
1	doc_802069853732_item	2883588	et	2	main
firmas	doc_802069853730_item	2883377	et	3	main
ülikool	doc_802069853731_item	2883381	et	4	main
kannuka	doc_802069853731_item	2883391	et	4	main
lõpitasin	doc_802069853731_item	2883396	et	4	main
ma	doc_802069853731_item	2883398	et	3	main
18	doc_802069853731_item	2883400	et	2	main
tean	doc_802069853731_item	2883415	et	3	main
kõrg	doc_802069853731_item	2883421	et	4	main
haridus	doc_802069853731_item	2883422	et	3	main
ja	doc_802069853731_item	2883423	et	3	main
ttüs	doc_802069853731_item	2883427	et	4	main
minu	doc_802069853731_item	2883428	et	3	main
eriala	doc_802069853731_item	2883429	et	4	main
et	doc_802069853731_item	2883435	et	3	main
ttü	doc_802069853731_item	2883444	et	4	main
ja	doc_802069853731_item	2883445	et	3	main
saada	doc_802069853731_item	2883446	et	4	main
esimine	doc_802069853731_item	2883449	et	4	main
oli	doc_802069853731_item	2883451	et	3	main
võib	doc_802069853731_item	2883468	et	3	main
on	doc_802069853731_item	2883478	et	4	main
ei	doc_802069853731_item	2883482	et	4	main
ole	doc_802069853731_item	2883483	et	4	main
on	doc_802069853731_item	2883487	et	4	main
suur	doc_802069853731_item	2883489	et	3	main
pluss	doc_802069853731_item	2883490	et	3	main
ma	doc_802069853731_item	2883491	et	3	main
tahaksin	doc_802069853731_item	2883492	et	3	main
õppida	doc_802069853731_item	2883493	et	3	main
eesti	doc_802069853731_item	2883494	et	4	main
keel	doc_802069853731_item	2883495	et	4	main
sest	doc_802069853731_item	2883496	et	4	main
et	doc_802069853731_item	2883497	et	3	main
praegu	doc_802069853731_item	2883498	et	3	main
eestis	doc_802069853731_item	2883499	et	3	main
on	doc_802069853731_item	2883500	et	4	main
palju	doc_802069853731_item	2883501	et	4	main
probleeme	doc_802069853731_item	2883502	et	3	main
inimestega	doc_802069853731_item	2883503	et	3	main
kes	doc_802069853731_item	2883504	et	4	main
ei	doc_802069853731_item	2883505	et	4	main
tea	doc_802069853731_item	2883506	et	4	main
eesti	doc_802069853731_item	2883507	et	4	main
keelt	doc_802069853731_item	2883508	et	4	main
mul	doc_802069853731_item	2883509	et	3	main
on	doc_802069853731_item	2883510	et	4	main
kesk	doc_802069853731_item	2883511	et	3	main
tase	doc_802069853731_item	2883512	et	3	main
tunnistus	doc_802069853731_item	2883513	et	4	main
aga	doc_802069853731_item	2883514	et	3	main
ma	doc_802069853731_item	2883515	et	3	main
seal	doc_802069853731_item	2883393	et	4	main
aastal	doc_802069853731_item	2883394	et	3	main
teda	doc_802069853731_item	2883397	et	4	main
vana	doc_802069853731_item	2883402	et	4	main
ma	doc_802069853731_item	2883403	et	3	main
arvasin	doc_802069853731_item	2883404	et	3	main
et	doc_802069853731_item	2883405	et	3	main
praegu	doc_802069853731_item	2883406	et	3	main
kõrg	doc_802069853731_item	2883407	et	4	main
haridus	doc_802069853731_item	2883408	et	3	main
ma	doc_802069853731_item	2883518	et	3	main
keelt	doc_802069853731_item	2883522	et	4	main
see	doc_802069853731_item	2883524	et	3	main
palju	doc_802069853731_item	2883531	et	4	main
võin	doc_802069853731_item	2883539	et	3	main
keel	doc_802069853731_item	2883542	et	4	main
väga	doc_802069853731_item	2883543	et	3	main
mind	doc_802069853731_item	2883551	et	4	main
seda	doc_802069853731_item	2883552	et	3	main
teha	doc_802069853731_item	2883553	et	3	main
essee	doc_802069853732_item	2883554	et	4	main
ülikool	doc_802069853732_item	2883557	et	4	main
mina	doc_802069853732_item	2883558	et	4	main
eesnimi	doc_802069853732_item	2883559	et	3	main
perekonnanimi	doc_802069853732_item	2883560	et	3	main
sündisin	doc_802069853732_item	2883561	et	3	main
pärnu	doc_802069853732_item	2883562	et	4	main
slaavi	doc_802069853732_item	2883566	et	3	main
põhikool	doc_802069853732_item	2883567	et	4	main
sain	doc_802069853732_item	2883574	et	3	main
hariduse	doc_802069853732_item	2883577	et	3	main
kuut	doc_802069853732_item	2883580	et	4	main
eeesti	doc_802069853732_item	2883583	et	4	main
bataljonis	doc_802069853732_item	2883587	et	4	main
tagasi	doc_802069853732_item	2883590	et	3	main
mehatroonika	doc_802069853732_item	2883593	et	4	main
dipploomi	doc_802069853732_item	2883594	et	4	main
täna	doc_802069853732_item	2883595	et	4	main
päevaks	doc_802069853732_item	2883596	et	3	main
töötan	doc_802069853732_item	2883597	et	3	main
auto	doc_802069853732_item	2883598	et	4	main
elektikut	doc_802069853732_item	2883599	et	4	main
ja	doc_802069853732_item	2883600	et	3	main
diaagnosija	doc_802069853732_item	2883601	et	4	main
selle	doc_802069853732_item	2883602	et	4	main
eriala	doc_802069853732_item	2883603	et	4	main
iatb	doc_802069853732_item	2883604	et	4	main
mina	doc_802069853732_item	2883605	et	4	main
valin	doc_802069853732_item	2883606	et	3	main
see	doc_802069853732_item	2883607	et	3	main
pärast	doc_802069853732_item	2883608	et	4	main
et	doc_802069853732_item	2883609	et	3	main
mulle	doc_802069853732_item	2883610	et	4	main
meldivad	doc_802069853732_item	2883611	et	4	main
ned	doc_802069853732_item	2883612	et	4	main
asjad	doc_802069853732_item	2883613	et	3	main
ja	doc_802069853732_item	2883614	et	3	main
ilma	doc_802069853732_item	2883615	et	4	main
kõrg	doc_802069853732_item	2883616	et	4	main
haridusega	doc_802069853732_item	2883617	et	3	main
ma	doc_802069853732_item	2883618	et	3	main
ei	doc_802069853732_item	2883619	et	4	main
tunnen	doc_802069853732_item	2883620	et	3	main
inimine	doc_802069853732_item	2883623	et	4	main
tea	doc_802069853731_item	2883520	et	4	main
sillamäe	doc_802069853731_item	2883523	et	3	main
on	doc_802069853731_item	2883530	et	4	main
ma	doc_802069853731_item	2883534	et	3	main
et	doc_802069853731_item	2883536	et	3	main
õppida	doc_802069853731_item	2883540	et	3	main
ttüs	doc_802069853731_item	2883549	et	4	main
mina	doc_802069853732_item	2883555	et	4	main
peale	doc_802069853732_item	2883568	et	4	main
seda	doc_802069853732_item	2883569	et	3	main
ma	doc_802069853732_item	2883570	et	3	main
käisin	doc_802069853732_item	2883571	et	3	main
õhtukoolis	doc_802069853732_item	2883572	et	4	main
ja	doc_802069853732_item	2883573	et	3	main
seal	doc_802069853732_item	2883575	et	4	main
kesk	doc_802069853732_item	2883576	et	3	main
diploomi	doc_802069853732_item	2883578	et	4	main
ma	doc_802069853732_item	2883581	et	3	main
vabariki	doc_802069853732_item	2883584	et	4	main
sõjaväelase	doc_802069853732_item	2883586	et	3	main
aasta	doc_802069853732_item	2883589	et	4	main
kätte	doc_802069853732_item	2883592	et	4	main
end	doc_802069853732_item	2883621	et	4	main
et	doc_802069853732_item	2883626	et	3	main
ttüst	doc_802069853732_item	2883627	et	4	main
parem	doc_802069853732_item	2883631	et	4	main
ootan	doc_802069853732_item	2883636	et	3	main
gramatikat	doc_802069853732_item	2883639	et	4	main
ttü	doc_802069853734_item	2883805	et	4	main
õpilane	doc_802069853734_item	2883806	et	3	main
lõpetasin	doc_802069853734_item	2883807	et	3	main
narva	doc_802069853734_item	2883808	et	4	main
kõik	doc_802069853734_item	2883823	et	4	main
mu	doc_802069853734_item	2883824	et	3	main
valgevenemaaal	doc_802069853734_item	2883833	et	4	main
narvas	doc_802069853734_item	2883846	et	4	main
see	doc_802069853734_item	2883847	et	3	main
ei	doc_802069853734_item	2883848	et	4	main
nagu	doc_802069853734_item	2883852	et	3	main
miks	doc_802069853734_item	2883867	et	4	main
just	doc_802069853734_item	2883870	et	3	main
võib	doc_802069853734_item	2883874	et	3	main
mina	doc_802069853734_item	2883877	et	4	main
programeerija	doc_802069853734_item	2883881	et	4	main
tulevikus	doc_802069853734_item	2883882	et	4	main
sest	doc_802069853734_item	2883883	et	4	main
ja	doc_802069853734_item	2883888	et	3	main
infotehnoloogia	doc_802069853734_item	2883889	et	4	main
mis	doc_802069853734_item	2883891	et	4	main
mina	doc_802069853734_item	2883892	et	4	main
võin	doc_802069853734_item	2883893	et	3	main
ütlema	doc_802069853734_item	2883894	et	3	main
minu	doc_802069853734_item	2883895	et	3	main
muljast	doc_802069853734_item	2883896	et	3	main
oli	doc_802069853734_item	2883923	et	3	main
minu	doc_802069853734_item	2883930	et	3	main
rühmal	doc_802069853734_item	2883931	et	3	main
loengud	doc_802069853734_item	2883933	et	3	main
ttü	doc_802069853734_item	2883942	et	4	main
taha	doc_802069853734_item	2883948	et	4	main
ütlen	doc_802069853734_item	2883952	et	3	main
minu	doc_802069853734_item	2883954	et	3	main
tooli	doc_802069853734_item	2883962	et	4	main
nägu	doc_802069853732_item	2883622	et	4	main
mina	doc_802069853732_item	2883624	et	4	main
organisemine	doc_802069853732_item	2883628	et	4	main
peab	doc_802069853732_item	2883629	et	4	main
keele	doc_802069853732_item	2883633	et	4	main
ma	doc_802069853732_item	2883635	et	3	main
keele	doc_802069853732_item	2883641	et	4	main
lähevad	doc_802069853732_item	2883643	et	3	main
eesnimi	doc_802069853732_item	2883648	et	3	main
olema	doc_802069853732_item	2883630	et	4	main
eesti	doc_802069853732_item	2883632	et	4	main
loengutest	doc_802069853732_item	2883634	et	4	main
minu	doc_802069853732_item	2883638	et	3	main
oskused	doc_802069853732_item	2883642	et	3	main
nägu	doc_802069853732_item	2883645	et	4	main
essee	doc_802069853734_item	2883797	et	4	main
ülikool	doc_802069853734_item	2883800	et	4	main
mina	doc_802069853734_item	2883801	et	4	main
olen	doc_802069853734_item	2883802	et	3	main
kesklinna	doc_802069853734_item	2883809	et	4	main
elasin	doc_802069853734_item	2883821	et	3	main
olin	doc_802069853734_item	2883831	et	3	main
venemaal	doc_802069853734_item	2883832	et	4	main
elan	doc_802069853734_item	2883839	et	3	main
tallinnas	doc_802069853734_item	2883841	et	4	main
minu	doc_802069853734_item	2883843	et	3	main
elab	doc_802069853734_item	2883845	et	3	main
halb	doc_802069853734_item	2883851	et	3	main
olla	doc_802069853734_item	2883854	et	3	main
korda	doc_802069853734_item	2883856	et	4	main
eriala	doc_802069853734_item	2883872	et	4	main
mina	doc_802069853734_item	2883884	et	4	main
tunnen	doc_802069853734_item	2883885	et	3	main
eest	doc_802069853734_item	2883890	et	4	main
ttü	doc_802069853734_item	2883918	et	4	main
koosneb	doc_802069853734_item	2883919	et	3	main
lugupetumisega	doc_802069853732_item	2883647	et	4	main
aastane	doc_802069853734_item	2883804	et	4	main
mina	doc_802069853734_item	2883812	et	4	main
õppisin	doc_802069853734_item	2883813	et	3	main
12	doc_802069853734_item	2883815	et	2	main
aastad	doc_802069853734_item	2883816	et	3	main
sündis	doc_802069853734_item	2883817	et	3	main
ma	doc_802069853734_item	2883818	et	3	main
narvas	doc_802069853734_item	2883819	et	4	main
ja	doc_802069853734_item	2883820	et	3	main
üheksateist	doc_802069853734_item	2883803	et	4	main
gümnaasiumi	doc_802069853734_item	2883810	et	4	main
kus	doc_802069853734_item	2883811	et	3	main
seal	doc_802069853734_item	2883822	et	4	main
elu	doc_802069853734_item	2883826	et	4	main
mina	doc_802069853734_item	2883827	et	4	main
olin	doc_802069853734_item	2883828	et	3	main
ka	doc_802069853734_item	2883829	et	3	main
välismaal	doc_802069853734_item	2883830	et	4	main
nüüd	doc_802069853734_item	2883837	et	4	main
aga	doc_802069853734_item	2883842	et	3	main
pere	doc_802069853734_item	2883844	et	4	main
ole	doc_802069853734_item	2883849	et	4	main
nii	doc_802069853734_item	2883850	et	3	main
sõidan	doc_802069853734_item	2883864	et	3	main
tagasi	doc_802069853734_item	2883865	et	3	main
tallinnasse	doc_802069853734_item	2883866	et	3	main
tules	doc_802069853734_item	2883869	et	3	main
õppima	doc_802069853734_item	2883873	et	3	main
sest	doc_802069853734_item	2883876	et	4	main
end	doc_802069853734_item	2883879	et	4	main
matemaatika	doc_802069853734_item	2883887	et	4	main
ttüst	doc_802069853734_item	2883897	et	4	main
esimesel	doc_802069853734_item	2883898	et	3	main
leida	doc_802069853734_item	2883903	et	3	main
sest	doc_802069853734_item	2883916	et	4	main
ja	doc_802069853734_item	2883922	et	3	main
ka	doc_802069853734_item	2883924	et	3	main
ka	doc_802069853734_item	2883934	et	3	main
üliõpilas	doc_802069853734_item	2883943	et	4	main
sellest	doc_802069853734_item	2883949	et	4	main
olid	doc_802069853734_item	2883956	et	4	main
kõik	doc_802069853734_item	2883957	et	4	main
mööbel	doc_802069853734_item	2883958	et	3	main
ei	doc_802069853734_item	2883960	et	4	main
oli	doc_802069853734_item	2883961	et	3	main
leidsin	doc_802069853734_item	2883969	et	3	main
eesti	doc_802069853734_item	2883972	et	4	main
keeli	doc_802069853734_item	2883973	et	4	main
kõigepealt	doc_802069853734_item	2883976	et	3	main
essee	doc_802069853735_item	2883992	et	4	main
nimi	doc_802069853735_item	2883997	et	3	main
eesnimi	doc_802069853735_item	2883999	et	3	main
ma	doc_802069853735_item	2884001	et	3	main
ma	doc_802069853735_item	2884006	et	3	main
kesk	doc_802069853735_item	2884021	et	3	main
on	doc_802069853735_item	2884044	et	4	main
sest	doc_802069853735_item	2884058	et	4	main
et	doc_802069853735_item	2884059	et	3	main
koolis	doc_802069853735_item	2884062	et	4	main
programmi	doc_802069853735_item	2884070	et	4	main
tegisime	doc_802069853735_item	2884074	et	4	main
leheküljed	doc_802069853735_item	2884075	et	3	main
kui	doc_802069853735_item	2884076	et	3	main
ttüsse	doc_802069853735_item	2884079	et	4	main
mulle	doc_802069853735_item	2884082	et	4	main
nii	doc_802069853735_item	2884087	et	3	main
aru	doc_802069853735_item	2884096	et	4	main
siin	doc_802069853735_item	2884098	et	4	main
on	doc_802069853735_item	2884099	et	4	main
vaja	doc_802069853735_item	2884102	et	4	main
paha	doc_802069853735_item	2884106	et	4	main
eesti	doc_802069853735_item	2884119	et	4	main
ma	doc_802069853735_item	2884122	et	3	main
eesti	doc_802069853735_item	2884137	et	4	main
essee	doc_802069853736_item	2884139	et	4	main
ülikool	doc_802069853736_item	2884142	et	4	main
minu	doc_802069853736_item	2884143	et	3	main
mina	doc_802069853734_item	2883798	et	4	main
ja	doc_802069853734_item	2883799	et	3	main
kõik	doc_802069853734_item	2883814	et	4	main
väike	doc_802069853734_item	2883825	et	4	main
suomis	doc_802069853734_item	2883834	et	4	main
ja	doc_802069853734_item	2883835	et	3	main
ukrainas	doc_802069853734_item	2883836	et	4	main
ma	doc_802069853734_item	2883838	et	3	main
siin	doc_802069853734_item	2883840	et	4	main
võib	doc_802069853734_item	2883853	et	3	main
esimest	doc_802069853734_item	2883855	et	4	main
näenud	doc_802069853734_item	2883857	et	4	main
sest	doc_802069853734_item	2883858	et	4	main
koolivaheajal	doc_802069853734_item	2883859	et	3	main
sõinad	doc_802069853734_item	2883860	et	4	main
kodu	doc_802069853734_item	2883861	et	4	main
ja	doc_802069853734_item	2883862	et	3	main
pühapäeval	doc_802069853734_item	2883863	et	3	main
mina	doc_802069853734_item	2883868	et	4	main
seda	doc_802069853734_item	2883871	et	3	main
olla	doc_802069853734_item	2883875	et	3	main
näen	doc_802069853734_item	2883878	et	3	main
päeval	doc_802069853734_item	2883899	et	3	main
väga	doc_802069853734_item	2883901	et	3	main
info	doc_802069853734_item	2883904	et	4	main
peamaja	doc_802069853734_item	2883917	et	4	main
korpusedes	doc_802069853734_item	2883921	et	4	main
raske	doc_802069853734_item	2883925	et	4	main
leida	doc_802069853734_item	2883926	et	3	main
tee	doc_802069853734_item	2883927	et	4	main
ruumile	doc_802069853734_item	2883928	et	3	main
huvitav	doc_802069853734_item	2883937	et	4	main
võivad	doc_802069853734_item	2883938	et	4	main
olla	doc_802069853734_item	2883939	et	3	main
minu	doc_802069853734_item	2883940	et	3	main
muljad	doc_802069853734_item	2883941	et	3	main
ei	doc_802069853734_item	2883947	et	4	main
et	doc_802069853734_item	2883953	et	3	main
toas	doc_802069853734_item	2883955	et	3	main
üldse	doc_802069853734_item	2883963	et	3	main
see	doc_802069853734_item	2883964	et	3	main
oli	doc_802069853734_item	2883965	et	3	main
lõbus	doc_802069853734_item	2883966	et	4	main
kuidas	doc_802069853734_item	2883967	et	3	main
ma	doc_802069853734_item	2883968	et	3	main
fakt	doc_802069853734_item	2883971	et	3	main
ainest	doc_802069853734_item	2883974	et	4	main
teha	doc_802069853734_item	2883988	et	3	main
ja	doc_802069853735_item	2883994	et	3	main
on	doc_802069853735_item	2883998	et	4	main
perekonnanimi	doc_802069853735_item	2884000	et	3	main
kümne	doc_802069853735_item	2884004	et	4	main
elan	doc_802069853735_item	2884007	et	3	main
lasnamäel	doc_802069853735_item	2884009	et	3	main
ttüsse	doc_802069853735_item	2884012	et	4	main
lasnamäe	doc_802069853735_item	2884015	et	3	main
kool	doc_802069853735_item	2884023	et	4	main
kahetuhande	doc_802069853735_item	2884026	et	4	main
kuuendal	doc_802069853735_item	2884027	et	3	main
aastal	doc_802069853735_item	2884028	et	3	main
kooli	doc_802069853735_item	2884030	et	4	main
tahaksin	doc_802069853735_item	2884034	et	3	main
ma	doc_802069853735_item	2884037	et	3	main
õppima	doc_802069853735_item	2884040	et	3	main
sõpru	doc_802069853735_item	2884046	et	3	main
ttüs	doc_802069853735_item	2884047	et	4	main
ma	doc_802069853735_item	2884048	et	3	main
meeldivad	doc_802069853735_item	2884068	et	4	main
sõbradega	doc_802069853735_item	2884072	et	4	main
esimesel	doc_802069853735_item	2884080	et	3	main
kõik	doc_802069853735_item	2884084	et	4	main
tudengile	doc_802069853735_item	2884103	et	3	main
koolis	doc_802069853735_item	2884104	et	4	main
eesti	doc_802069853735_item	2884108	et	4	main
õpetaja	doc_802069853735_item	2884117	et	4	main
natukene	doc_802069853735_item	2884124	et	4	main
õppima	doc_802069853735_item	2884125	et	3	main
mina	doc_802069853736_item	2884140	et	4	main
ja	doc_802069853736_item	2884141	et	3	main
see	doc_802069853736_item	2884170	et	3	main
tehnika	doc_802069853736_item	2884177	et	4	main
tulevikus	doc_802069853736_item	2884185	et	4	main
kodulinnas	doc_802069853736_item	2884190	et	4	main
sillamäel	doc_802069853736_item	2884191	et	3	main
on	doc_802069853736_item	2884192	et	4	main
väga	doc_802069853736_item	2884193	et	3	main
tartus	doc_802069853736_item	2884203	et	3	main
isa	doc_802069853736_item	2884213	et	4	main
ma	doc_802069853736_item	2884219	et	3	main
nagu	doc_802069853734_item	2883880	et	3	main
huvi	doc_802069853734_item	2883886	et	4	main
oli	doc_802069853734_item	2883900	et	3	main
raske	doc_802069853734_item	2883902	et	4	main
mis	doc_802069853734_item	2883905	et	4	main
mina	doc_802069853734_item	2883906	et	4	main
pean	doc_802069853734_item	2883907	et	4	main
tegema	doc_802069853734_item	2883908	et	3	main
ja	doc_802069853734_item	2883909	et	3	main
missugused	doc_802069853734_item	2883910	et	3	main
loengud	doc_802069853734_item	2883911	et	3	main
sellel	doc_802069853734_item	2883912	et	4	main
päeval	doc_802069853734_item	2883913	et	3	main
mul	doc_802069853734_item	2883914	et	3	main
oli	doc_802069853734_item	2883915	et	3	main
seitsmes	doc_802069853734_item	2883920	et	4	main
kus	doc_802069853734_item	2883929	et	3	main
on	doc_802069853734_item	2883932	et	4	main
on	doc_802069853734_item	2883935	et	4	main
väga	doc_802069853734_item	2883936	et	3	main
külast	doc_802069853734_item	2883944	et	4	main
vaid	doc_802069853734_item	2883945	et	3	main
ma	doc_802069853734_item	2883946	et	3	main
jutusta	doc_802069853734_item	2883950	et	4	main
ainult	doc_802069853734_item	2883951	et	4	main
aja	doc_802069853734_item	2883959	et	4	main
see	doc_802069853734_item	2883970	et	3	main
ootan	doc_802069853734_item	2883975	et	3	main
see	doc_802069853734_item	2883977	et	3	main
et	doc_802069853734_item	2883978	et	3	main
mul	doc_802069853734_item	2883979	et	3	main
on	doc_802069853734_item	2883980	et	4	main
võimalus	doc_802069853734_item	2883981	et	3	main
suhelda	doc_802069853734_item	2883982	et	4	main
eesti	doc_802069853734_item	2883983	et	4	main
keeles	doc_802069853734_item	2883984	et	4	main
paremaks	doc_802069853734_item	2883985	et	4	main
tulevikus	doc_802069853734_item	2883986	et	4	main
vead	doc_802069853734_item	2883990	et	4	main
ja	doc_802069853734_item	2883987	et	3	main
vähem	doc_802069853734_item	2883989	et	4	main
minu	doc_802069853735_item	2883996	et	3	main
aastane	doc_802069853735_item	2884005	et	4	main
tallinnas	doc_802069853735_item	2884008	et	4	main
vene	doc_802069853735_item	2884016	et	4	main
gümnaasiumis	doc_802069853735_item	2884017	et	3	main
seal	doc_802069853735_item	2884018	et	4	main
ma	doc_802069853735_item	2884019	et	3	main
sain	doc_802069853735_item	2884020	et	3	main
kirjutamises	doc_802069853734_item	2883991	et	4	main
ülikool	doc_802069853735_item	2883995	et	4	main
kaheksateist	doc_802069853735_item	2884003	et	4	main
kuni	doc_802069853735_item	2884010	et	3	main
sain	doc_802069853735_item	2884011	et	3	main
ma	doc_802069853735_item	2884013	et	3	main
õppisin	doc_802069853735_item	2884014	et	3	main
pärast	doc_802069853735_item	2884029	et	4	main
ma	doc_802069853735_item	2884032	et	3	main
väga	doc_802069853735_item	2884033	et	3	main
õppima	doc_802069853735_item	2884036	et	3	main
tahaksin	doc_802069853735_item	2884039	et	3	main
palju	doc_802069853735_item	2884045	et	4	main
äriinfotehnologia	doc_802069853735_item	2884050	et	4	main
eriala	doc_802069853735_item	2884056	et	4	main
õppima	doc_802069853735_item	2884057	et	3	main
oli	doc_802069853735_item	2884061	et	3	main
minu	doc_802069853735_item	2884063	et	3	main
lemik	doc_802069853735_item	2884064	et	4	main
tund	doc_802069853735_item	2884065	et	3	main
mulle	doc_802069853735_item	2884066	et	4	main
väga	doc_802069853735_item	2884067	et	3	main
koos	doc_802069853735_item	2884071	et	4	main
ma	doc_802069853735_item	2884077	et	3	main
tulesin	doc_802069853735_item	2884078	et	4	main
oli	doc_802069853735_item	2884083	et	3	main
aru	doc_802069853735_item	2884085	et	4	main
hoone	doc_802069853735_item	2884089	et	4	main
jane	doc_802069853735_item	2884092	et	4	main
saan	doc_802069853735_item	2884095	et	4	main
mida	doc_802069853735_item	2884101	et	4	main
keel	doc_802069853735_item	2884109	et	4	main
et	doc_802069853735_item	2884111	et	3	main
ttüs	doc_802069853735_item	2884118	et	4	main
loengutel	doc_802069853735_item	2884121	et	4	main
tahan	doc_802069853735_item	2884123	et	3	main
keel	doc_802069853735_item	2884127	et	4	main
sest	doc_802069853735_item	2884128	et	4	main
et	doc_802069853735_item	2884129	et	3	main
ma	doc_802069853735_item	2884130	et	3	main
elan	doc_802069853735_item	2884131	et	3	main
eestis	doc_802069853735_item	2884132	et	3	main
ja	doc_802069853735_item	2884133	et	3	main
ma	doc_802069853735_item	2884134	et	3	main
pean	doc_802069853735_item	2884135	et	4	main
teada	doc_802069853735_item	2884136	et	3	main
on	doc_802069853736_item	2884145	et	4	main
eesnimi	doc_802069853736_item	2884146	et	3	main
ja	doc_802069853736_item	2884147	et	3	main
ma	doc_802069853736_item	2884148	et	3	main
olen	doc_802069853736_item	2884149	et	3	main
19	doc_802069853736_item	2884150	et	2	main
aastat	doc_802069853736_item	2884151	et	3	main
see	doc_802069853736_item	2884158	et	3	main
väga	doc_802069853736_item	2884160	et	3	main
ma	doc_802069853736_item	2884163	et	3	main
võiks	doc_802069853736_item	2884181	et	4	main
kindel	doc_802069853736_item	2884182	et	3	main
olla	doc_802069853736_item	2884183	et	3	main
et	doc_802069853736_item	2884184	et	3	main
tööta	doc_802069853736_item	2884188	et	4	main
minu	doc_802069853736_item	2884189	et	3	main
kõik	doc_802069853736_item	2884198	et	4	main
tallinnas	doc_802069853736_item	2884201	et	4	main
minu	doc_802069853736_item	2884205	et	3	main
automatik	doc_802069853736_item	2884215	et	4	main
aga	doc_802069853736_item	2884216	et	3	main
vanaisa	doc_802069853736_item	2884217	et	4	main
ka	doc_802069853736_item	2884221	et	3	main
saada	doc_802069853736_item	2884223	et	4	main
eest	doc_802069853736_item	2884225	et	4	main
mul	doc_802069853736_item	2884226	et	3	main
keelt	doc_802069853736_item	2884231	et	4	main
teada	doc_802069853736_item	2884232	et	3	main
ma	doc_802069853736_item	2884233	et	3	main
sooviksin	doc_802069853736_item	2884238	et	3	main
parem	doc_802069853736_item	2884241	et	4	main
et	doc_802069853736_item	2884243	et	3	main
võiks	doc_802069853736_item	2884253	et	4	main
teiste	doc_802069853736_item	2884256	et	4	main
estlastega	doc_802069853736_item	2884257	et	4	main
olen	doc_802069853737_item	2884272	et	3	main
mina	doc_802069853735_item	2883993	et	4	main
olen	doc_802069853735_item	2884002	et	3	main
haridus	doc_802069853735_item	2884022	et	3	main
ma	doc_802069853735_item	2884024	et	3	main
lõpetasin	doc_802069853735_item	2884025	et	3	main
lõpetamine	doc_802069853735_item	2884031	et	4	main
edasi	doc_802069853735_item	2884035	et	3	main
väga	doc_802069853735_item	2884038	et	3	main
ttüs	doc_802069853735_item	2884041	et	4	main
siin	doc_802069853735_item	2884042	et	4	main
mul	doc_802069853735_item	2884043	et	3	main
asutasin	doc_802069853735_item	2884049	et	3	main
eriala	doc_802069853735_item	2884051	et	4	main
iabb	doc_802069853735_item	2884052	et	4	main
ma	doc_802069853735_item	2884053	et	3	main
tulesin	doc_802069853735_item	2884054	et	4	main
seda	doc_802069853735_item	2884055	et	3	main
infotehnologia	doc_802069853735_item	2884060	et	4	main
erinevad	doc_802069853735_item	2884069	et	4	main
me	doc_802069853735_item	2884073	et	4	main
kordsel	doc_802069853735_item	2884081	et	3	main
saamut	doc_802069853735_item	2884086	et	4	main
suur	doc_802069853735_item	2884088	et	3	main
et	doc_802069853735_item	2884097	et	3	main
õppisin	doc_802069853735_item	2884107	et	3	main
aasta	doc_802069853735_item	2884113	et	4	main
keele	doc_802069853735_item	2884120	et	4	main
eesti	doc_802069853735_item	2884126	et	4	main
keel	doc_802069853735_item	2884138	et	4	main
vana	doc_802069853736_item	2884152	et	4	main
ma	doc_802069853736_item	2884153	et	3	main
olen	doc_802069853736_item	2884154	et	3	main
ttü-i	doc_802069853736_item	2884155	et	4	main
esmakursuslane	doc_802069853736_item	2884156	et	3	main
on	doc_802069853736_item	2884159	et	4	main
kuna	doc_802069853736_item	2884162	et	3	main
alati	doc_802069853736_item	2884165	et	4	main
tallinnas	doc_802069853736_item	2884166	et	4	main
õppida	doc_802069853736_item	2884167	et	3	main
aga	doc_802069853736_item	2884168	et	3	main
kui	doc_802069853736_item	2884169	et	3	main
ülikool	doc_802069853736_item	2884178	et	4	main
siis	doc_802069853736_item	2884179	et	3	main
ma	doc_802069853736_item	2884180	et	3	main
jää	doc_802069853736_item	2884187	et	4	main
sellepärast	doc_802069853736_item	2884197	et	3	main
noored	doc_802069853736_item	2884199	et	3	main
õppida	doc_802069853736_item	2884204	et	3	main
peaaegu	doc_802069853736_item	2884207	et	3	main
on	doc_802069853736_item	2884209	et	4	main
seotud	doc_802069853736_item	2884210	et	4	main
tehnikaga	doc_802069853736_item	2884211	et	3	main
mu	doc_802069853736_item	2884212	et	3	main
insener	doc_802069853736_item	2884218	et	3	main
sooviksin	doc_802069853736_item	2884220	et	3	main
kõrgharidust	doc_802069853736_item	2884222	et	4	main
eestikeeletase	doc_802069853736_item	2884240	et	3	main
tulevikuses	doc_802069853736_item	2884244	et	4	main
elus	doc_802069853736_item	2884245	et	4	main
mul	doc_802069853736_item	2884246	et	3	main
oleks	doc_802069853736_item	2884247	et	3	main
sellega	doc_802069853736_item	2884248	et	3	main
vabas	doc_802069853736_item	2884254	et	3	main
essee	doc_802069853737_item	2884259	et	4	main
mina	doc_802069853737_item	2884260	et	4	main
narva	doc_802069853737_item	2884274	et	4	main
arvan	doc_802069853737_item	2884278	et	3	main
on	doc_802069853737_item	2884285	et	4	main
ma	doc_802069853737_item	2884295	et	3	main
ujuda	doc_802069853737_item	2884297	et	3	main
nimi	doc_802069853737_item	2884302	et	3	main
õppima	doc_802069853737_item	2884315	et	3	main
võimalusi	doc_802069853737_item	2884330	et	3	main
peab	doc_802069853737_item	2884335	et	4	main
väga	doc_802069853737_item	2884340	et	3	main
meeldis	doc_802069853737_item	2884341	et	3	main
siin	doc_802069853737_item	2884343	et	4	main
väga	doc_802069853737_item	2884345	et	3	main
hea	doc_802069853737_item	2884346	et	4	main
ttüs	doc_802069853737_item	2884362	et	4	main
võimalus	doc_802069853737_item	2884364	et	3	main
interneti	doc_802069853737_item	2884365	et	4	main
palju	doc_802069853735_item	2884090	et	4	main
ruumi	doc_802069853735_item	2884091	et	4	main
pärast	doc_802069853735_item	2884093	et	4	main
ma	doc_802069853735_item	2884094	et	3	main
kõik	doc_802069853735_item	2884100	et	4	main
ma	doc_802069853735_item	2884105	et	3	main
sellepärst	doc_802069853735_item	2884110	et	4	main
iga	doc_802069853735_item	2884112	et	4	main
meil	doc_802069853735_item	2884114	et	4	main
oli	doc_802069853735_item	2884115	et	3	main
uus	doc_802069853735_item	2884116	et	3	main
halvad	doc_802069853736_item	2884194	et	4	main
võimalusi	doc_802069853736_item	2884195	et	3	main
õppimiseks	doc_802069853736_item	2884196	et	4	main
nimi	doc_802069853736_item	2884144	et	3	main
ja	doc_802069853736_item	2884157	et	3	main
tore	doc_802069853736_item	2884161	et	3	main
sooviksin	doc_802069853736_item	2884164	et	3	main
on	doc_802069853736_item	2884171	et	4	main
niisugune	doc_802069853736_item	2884172	et	3	main
kuulus	doc_802069853736_item	2884173	et	4	main
õppeasutus	doc_802069853736_item	2884174	et	4	main
nagu	doc_802069853736_item	2884175	et	3	main
tallinna	doc_802069853736_item	2884176	et	4	main
ei	doc_802069853736_item	2884186	et	4	main
püüavad	doc_802069853736_item	2884200	et	3	main
või	doc_802069853736_item	2884202	et	4	main
on	doc_802069853736_item	2884214	et	4	main
on	doc_802069853736_item	2884227	et	4	main
vaja	doc_802069853736_item	2884228	et	4	main
ootan	doc_802069853736_item	2884234	et	3	main
oma	doc_802069853736_item	2884239	et	4	main
teha	doc_802069853736_item	2884242	et	3	main
vormis	doc_802069853736_item	2884255	et	4	main
suhelda	doc_802069853736_item	2884258	et	4	main
ma	doc_802069853737_item	2884277	et	3	main
hästi	doc_802069853737_item	2884283	et	3	main
arvamus	doc_802069853737_item	2884287	et	3	main
mulle	doc_802069853737_item	2884289	et	4	main
meeldib	doc_802069853737_item	2884290	et	3	main
tegeleda	doc_802069853737_item	2884291	et	3	main
päevitada	doc_802069853737_item	2884298	et	3	main
minu	doc_802069853737_item	2884300	et	3	main
tulin	doc_802069853737_item	2884312	et	3	main
aga	doc_802069853737_item	2884316	et	3	main
tean	doc_802069853737_item	2884318	et	3	main
perekonnas	doc_802069853736_item	2884206	et	4	main
kõik	doc_802069853736_item	2884208	et	4	main
selle	doc_802069853736_item	2884224	et	4	main
kindlasti	doc_802069853736_item	2884229	et	3	main
eesti	doc_802069853736_item	2884230	et	4	main
selle	doc_802069853736_item	2884235	et	4	main
kursustel	doc_802069853736_item	2884236	et	3	main
ma	doc_802069853736_item	2884237	et	3	main
vähem	doc_802069853736_item	2884249	et	4	main
probleeme	doc_802069853736_item	2884250	et	3	main
ja	doc_802069853736_item	2884251	et	3	main
ma	doc_802069853736_item	2884252	et	3	main
ja	doc_802069853737_item	2884261	et	3	main
ülikool	doc_802069853737_item	2884262	et	4	main
minu	doc_802069853737_item	2884263	et	3	main
nimi	doc_802069853737_item	2884264	et	3	main
eesnimi	doc_802069853737_item	2884266	et	3	main
ma	doc_802069853737_item	2884267	et	3	main
on	doc_802069853737_item	2884265	et	4	main
olen	doc_802069853737_item	2884268	et	3	main
pärit	doc_802069853737_item	2884269	et	3	main
narvast	doc_802069853737_item	2884270	et	4	main
ma	doc_802069853737_item	2884271	et	3	main
lõpetanud	doc_802069853737_item	2884273	et	4	main
gümnaasiumi	doc_802069853737_item	2884276	et	4	main
ma	doc_802069853737_item	2884280	et	3	main
eksamid	doc_802069853737_item	2884282	et	3	main
puhkuse	doc_802069853737_item	2884293	et	3	main
armastan	doc_802069853737_item	2884296	et	3	main
ttü-s	doc_802069853737_item	2884299	et	3	main
ma	doc_802069853737_item	2884307	et	3	main
ei	doc_802069853737_item	2884308	et	4	main
ma	doc_802069853737_item	2884311	et	3	main
eriala	doc_802069853737_item	2884314	et	4	main
palju	doc_802069853737_item	2884329	et	4	main
mulle	doc_802069853737_item	2884339	et	4	main
mida	doc_802069853737_item	2884352	et	4	main
tahan	doc_802069853737_item	2884354	et	3	main
esimene	doc_802069853737_item	2884356	et	3	main
on	doc_802069853737_item	2884359	et	4	main
väga	doc_802069853737_item	2884360	et	3	main
hea	doc_802069853737_item	2884361	et	4	main
on	doc_802069853737_item	2884363	et	4	main
keele	doc_802069853737_item	2884373	et	4	main
pareneda	doc_802069853737_item	2884381	et	3	main
keele	doc_802069853737_item	2884384	et	4	main
eesti	doc_802069853737_item	2884390	et	4	main
ma	doc_802069853737_item	2884392	et	3	main
mul	doc_802069853737_item	2884395	et	3	main
vaja	doc_802069853737_item	2884397	et	4	main
hästi	doc_802069853737_item	2884398	et	3	main
teada	doc_802069853737_item	2884399	et	3	main
tasuva	doc_802069853737_item	2884410	et	4	main
meeldib	doc_802069853737_item	2884413	et	3	main
ttü-s	doc_802069853737_item	2884422	et	3	main
mina	doc_802069853738_item	2884424	et	4	main
ja	doc_802069853738_item	2884425	et	3	main
ülikool	doc_802069853738_item	2884426	et	4	main
hea	doc_802069853738_item	2884429	et	4	main
mängib	doc_802069853738_item	2884431	et	3	main
roolli	doc_802069853738_item	2884434	et	4	main
sest	doc_802069853738_item	2884435	et	4	main
ilma	doc_802069853738_item	2884436	et	4	main
hariduseta	doc_802069853738_item	2884437	et	3	main
päris	doc_802069853738_item	2884439	et	4	main
erinevaid	doc_802069853738_item	2884447	et	4	main
kohta	doc_802069853738_item	2884454	et	4	main
kus	doc_802069853738_item	2884455	et	3	main
tehnikast	doc_802069853738_item	2884464	et	4	main
töökoht	doc_802069853738_item	2884470	et	3	main
tehnikaga	doc_802069853738_item	2884477	et	3	main
mina	doc_802069853738_item	2884483	et	4	main
see	doc_802069853738_item	2884489	et	3	main
mis	doc_802069853738_item	2884494	et	4	main
saada	doc_802069853738_item	2884497	et	4	main
on	doc_802069853738_item	2884510	et	4	main
ja	doc_802069853738_item	2884519	et	3	main
inglise	doc_802069853738_item	2884520	et	4	main
pähklimäe	doc_802069853737_item	2884275	et	3	main
et	doc_802069853737_item	2884279	et	3	main
sooritasin	doc_802069853737_item	2884281	et	3	main
minu	doc_802069853737_item	2884286	et	3	main
spordiga	doc_802069853737_item	2884292	et	3	main
eriala	doc_802069853737_item	2884301	et	4	main
on	doc_802069853737_item	2884303	et	4	main
tootearendus	doc_802069853737_item	2884304	et	3	main
ja	doc_802069853737_item	2884305	et	3	main
tootmisteehnika	doc_802069853737_item	2884306	et	4	main
miks	doc_802069853737_item	2884310	et	4	main
et	doc_802069853737_item	2884319	et	3	main
edasi	doc_802069853737_item	2884321	et	3	main
ttü-s	doc_802069853737_item	2884323	et	3	main
meeldib	doc_802069853737_item	2884325	et	3	main
siin	doc_802069853737_item	2884326	et	4	main
ttü-s	doc_802069853737_item	2884327	et	3	main
hästi	doc_802069853737_item	2884332	et	3	main
see	doc_802069853737_item	2884334	et	3	main
olema	doc_802069853737_item	2884336	et	4	main
väga	doc_802069853737_item	2884337	et	3	main
huvitav	doc_802069853737_item	2884338	et	4	main
et	doc_802069853737_item	2884342	et	3	main
on	doc_802069853737_item	2884344	et	4	main
saan	doc_802069853737_item	2884350	et	4	main
valida	doc_802069853737_item	2884351	et	3	main
ttü-st	doc_802069853737_item	2884358	et	3	main
mulle	doc_802069853737_item	2884369	et	4	main
meeldib	doc_802069853737_item	2884370	et	3	main
ka	doc_802069853737_item	2884371	et	3	main
eesti	doc_802069853737_item	2884372	et	4	main
tahan	doc_802069853737_item	2884380	et	3	main
oma	doc_802069853737_item	2884382	et	4	main
tahan	doc_802069853737_item	2884387	et	3	main
rääkida	doc_802069853737_item	2884389	et	3	main
keeles	doc_802069853737_item	2884391	et	4	main
mõistan	doc_802069853737_item	2884393	et	3	main
on	doc_802069853737_item	2884396	et	4	main
mulle	doc_802069853737_item	2884412	et	4	main
kaasaegses	doc_802069853738_item	2884427	et	3	main
väga	doc_802069853738_item	2884432	et	3	main
piisavalt	doc_802069853738_item	2884446	et	4	main
õppida	doc_802069853738_item	2884458	et	3	main
juba	doc_802069853738_item	2884460	et	3	main
lapsepõlvest	doc_802069853738_item	2884461	et	4	main
olin	doc_802069853738_item	2884462	et	3	main
lihtsalt	doc_802069853738_item	2884476	et	4	main
kuuenda	doc_802069853738_item	2884480	et	3	main
lõpetamist	doc_802069853738_item	2884482	et	4	main
tallinna	doc_802069853738_item	2884486	et	4	main
suurem	doc_802069853738_item	2884491	et	4	main
eestis	doc_802069853738_item	2884493	et	3	main
kõrgharidust	doc_802069853738_item	2884498	et	4	main
ole	doc_802069853738_item	2884506	et	4	main
aasta	doc_802069853738_item	2884517	et	4	main
matemaatika	doc_802069853738_item	2884518	et	4	main
olid	doc_802069853738_item	2884523	et	4	main
raske	doc_802069853738_item	2884524	et	4	main
minu	doc_802069853738_item	2884525	et	3	main
sõltus	doc_802069853738_item	2884530	et	4	main
minu	doc_802069853738_item	2884531	et	3	main
sisseastumine	doc_802069853738_item	2884532	et	3	main
olin	doc_802069853738_item	2884533	et	3	main
väga	doc_802069853738_item	2884534	et	3	main
ja	doc_802069853738_item	2884545	et	3	main
huvitav	doc_802069853738_item	2884557	et	4	main
aga	doc_802069853738_item	2884558	et	3	main
mitmessugused	doc_802069853738_item	2884559	et	4	main
probleemid	doc_802069853738_item	2884560	et	3	main
üks	doc_802069853738_item	2884566	et	3	main
minu	doc_802069853738_item	2884568	et	3	main
probleemidest	doc_802069853738_item	2884569	et	3	main
mina	doc_802069853738_item	2884573	et	4	main
elan	doc_802069853738_item	2884574	et	3	main
keele	doc_802069853738_item	2884579	et	4	main
on	doc_802069853738_item	2884582	et	4	main
aitaksid	doc_802069853738_item	2884607	et	4	main
sündinut	doc_802069853739_item	2884619	et	4	main
aastat	doc_802069853739_item	2884622	et	3	main
elasin	doc_802069853739_item	2884623	et	3	main
elan	doc_802069853739_item	2884625	et	3	main
aastat	doc_802069853739_item	2884628	et	3	main
see	doc_802069853737_item	2884284	et	3	main
veel	doc_802069853737_item	2884288	et	4	main
ajal	doc_802069853737_item	2884294	et	4	main
tea	doc_802069853737_item	2884309	et	4	main
oma	doc_802069853737_item	2884313	et	4	main
ma	doc_802069853737_item	2884317	et	3	main
tahan	doc_802069853737_item	2884320	et	3	main
õppida	doc_802069853737_item	2884322	et	3	main
mulle	doc_802069853737_item	2884324	et	4	main
on	doc_802069853737_item	2884328	et	4	main
et	doc_802069853737_item	2884331	et	3	main
õppida	doc_802069853737_item	2884333	et	3	main
spoordihoone	doc_802069853737_item	2884347	et	4	main
ja	doc_802069853737_item	2884348	et	3	main
ma	doc_802069853737_item	2884349	et	3	main
ma	doc_802069853737_item	2884353	et	3	main
minu	doc_802069853737_item	2884355	et	3	main
mulje	doc_802069853737_item	2884357	et	4	main
palju	doc_802069853737_item	2884377	et	4	main
asju	doc_802069853737_item	2884378	et	3	main
ma	doc_802069853737_item	2884379	et	3	main
eesti	doc_802069853737_item	2884383	et	4	main
ma	doc_802069853737_item	2884386	et	3	main
et	doc_802069853737_item	2884394	et	3	main
sest	doc_802069853737_item	2884402	et	4	main
ma	doc_802069853737_item	2884403	et	3	main
elan	doc_802069853737_item	2884404	et	3	main
eestis	doc_802069853737_item	2884405	et	3	main
ja	doc_802069853737_item	2884406	et	3	main
tahan	doc_802069853737_item	2884407	et	3	main
leida	doc_802069853737_item	2884408	et	3	main
hea	doc_802069853737_item	2884409	et	4	main
õppida	doc_802069853737_item	2884414	et	3	main
eesti	doc_802069853737_item	2884415	et	4	main
keelt	doc_802069853737_item	2884416	et	4	main
ma	doc_802069853737_item	2884417	et	3	main
olen	doc_802069853737_item	2884418	et	3	main
rõõmus	doc_802069853737_item	2884419	et	4	main
et	doc_802069853737_item	2884420	et	3	main
õppin	doc_802069853737_item	2884421	et	4	main
maailmas	doc_802069853738_item	2884428	et	3	main
haridus	doc_802069853738_item	2884430	et	3	main
suurt	doc_802069853738_item	2884433	et	3	main
eestis	doc_802069853738_item	2884444	et	3	main
on	doc_802069853738_item	2884445	et	4	main
ta	doc_802069853738_item	2884456	et	4	main
mina	doc_802069853738_item	2884459	et	4	main
ja	doc_802069853738_item	2884465	et	3	main
tahtsin	doc_802069853738_item	2884466	et	3	main
et	doc_802069853738_item	2884467	et	3	main
minu	doc_802069853738_item	2884468	et	3	main
tulevane	doc_802069853738_item	2884469	et	3	main
või	doc_802069853738_item	2884475	et	4	main
narva	doc_802069853738_item	2884479	et	4	main
kooli	doc_802069853738_item	2884481	et	4	main
astuda	doc_802069853738_item	2884485	et	3	main
sest	doc_802069853738_item	2884488	et	4	main
annab	doc_802069853738_item	2884495	et	3	main
soovi	doc_802069853738_item	2884504	et	4	main
ei	doc_802069853738_item	2884505	et	4	main
ülokooli	doc_802069853738_item	2884508	et	4	main
riigieksamid	doc_802069853738_item	2884522	et	3	main
eksamitest	doc_802069853738_item	2884529	et	4	main
sisseastujate	doc_802069853738_item	2884543	et	3	main
ülikoolis	doc_802069853738_item	2884555	et	4	main
oleks	doc_802069853738_item	2884556	et	3	main
arvan	doc_802069853738_item	2884564	et	3	main
et	doc_802069853738_item	2884565	et	3	main
keel	doc_802069853738_item	2884572	et	4	main
eesti	doc_802069853738_item	2884578	et	4	main
aga	doc_802069853738_item	2884581	et	3	main
keelt	doc_802069853738_item	2884586	et	4	main
eesti	doc_802069853738_item	2884598	et	4	main
et	doc_802069853738_item	2884603	et	3	main
olin	doc_802069853739_item	2884618	et	3	main
ja	doc_802069853739_item	2884620	et	3	main
kasutada	doc_802069853737_item	2884366	et	3	main
ja	doc_802069853737_item	2884367	et	3	main
see	doc_802069853737_item	2884368	et	3	main
loengudest	doc_802069853737_item	2884374	et	4	main
ma	doc_802069853737_item	2884375	et	3	main
ootan	doc_802069853737_item	2884376	et	3	main
oskusi	doc_802069853737_item	2884385	et	3	main
paremini	doc_802069853737_item	2884388	et	4	main
tööd	doc_802069853737_item	2884411	et	4	main
essee	doc_802069853738_item	2884423	et	4	main
on	doc_802069853738_item	2884438	et	4	main
raske	doc_802069853738_item	2884440	et	4	main
häid	doc_802069853738_item	2884441	et	3	main
tööd	doc_802069853738_item	2884442	et	4	main
leida	doc_802069853738_item	2884443	et	3	main
ülikooli	doc_802069853738_item	2884448	et	4	main
ja	doc_802069853738_item	2884449	et	3	main
igaüks	doc_802069853738_item	2884450	et	3	main
võib	doc_802069853738_item	2884451	et	3	main
valida	doc_802069853738_item	2884452	et	3	main
endale	doc_802069853738_item	2884453	et	4	main
saab	doc_802069853738_item	2884457	et	3	main
huvitatud	doc_802069853738_item	2884463	et	4	main
pärast	doc_802069853738_item	2884478	et	4	main
otsustasin	doc_802069853738_item	2884484	et	3	main
tehnikaülikooli	doc_802069853738_item	2884487	et	4	main
on	doc_802069853738_item	2884490	et	4	main
ülikool	doc_802069853738_item	2884492	et	4	main
võimalust	doc_802069853738_item	2884496	et	3	main
mis	doc_802069853738_item	2884499	et	4	main
seotud	doc_802069853738_item	2884500	et	4	main
tehnikaga	doc_802069853738_item	2884501	et	3	main
aga	doc_802069853738_item	2884502	et	3	main
suurt	doc_802069853738_item	2884503	et	3	main
piisavalt	doc_802069853738_item	2884507	et	4	main
astumiseks	doc_802069853738_item	2884509	et	4	main
vaja	doc_802069853738_item	2884511	et	4	main
ka	doc_802069853738_item	2884512	et	3	main
eksameid	doc_802069853738_item	2884513	et	3	main
hästi	doc_802069853738_item	2884514	et	3	main
sooritada	doc_802069853738_item	2884515	et	3	main
jaoks	doc_802069853738_item	2884526	et	4	main
aga	doc_802069853738_item	2884527	et	3	main
rõõmus	doc_802069853738_item	2884535	et	4	main
kui	doc_802069853738_item	2884536	et	3	main
teada	doc_802069853738_item	2884537	et	3	main
sain	doc_802069853738_item	2884538	et	3	main
et	doc_802069853738_item	2884539	et	3	main
mu	doc_802069853738_item	2884540	et	3	main
perekonnanimi	doc_802069853738_item	2884541	et	3	main
on	doc_802069853738_item	2884542	et	4	main
pingereas	doc_802069853738_item	2884544	et	3	main
tehnikaülikoolis	doc_802069853738_item	2884550	et	4	main
loodan	doc_802069853738_item	2884551	et	3	main
et	doc_802069853738_item	2884552	et	3	main
selles	doc_802069853738_item	2884554	et	4	main
olemas	doc_802069853738_item	2884563	et	4	main
suurematest	doc_802069853738_item	2884567	et	4	main
on	doc_802069853738_item	2884570	et	4	main
narvas	doc_802069853738_item	2884575	et	4	main
olin	doc_802069853738_item	2884576	et	3	main
õppida	doc_802069853738_item	2884584	et	3	main
ilma	doc_802069853738_item	2884587	et	4	main
praktikuta	doc_802069853738_item	2884588	et	3	main
ma	doc_802069853738_item	2884590	et	3	main
saa	doc_802069853738_item	2884592	et	4	main
hästi	doc_802069853738_item	2884593	et	3	main
õppida	doc_802069853738_item	2884594	et	3	main
ja	doc_802069853738_item	2884595	et	3	main
töötada	doc_802069853738_item	2884596	et	3	main
mind	doc_802069853738_item	2884608	et	4	main
ma	doc_802069853739_item	2884617	et	3	main
eesti	doc_802069853737_item	2884400	et	4	main
keelt	doc_802069853737_item	2884401	et	4	main
oleks	doc_802069853738_item	2884471	et	3	main
seotud	doc_802069853738_item	2884472	et	4	main
autodega	doc_802069853738_item	2884473	et	3	main
lennukitega	doc_802069853738_item	2884474	et	3	main
selle	doc_802069853738_item	2884516	et	4	main
keele	doc_802069853738_item	2884521	et	4	main
sellisest	doc_802069853738_item	2884528	et	4	main
nüüd	doc_802069853738_item	2884546	et	4	main
ma	doc_802069853738_item	2884547	et	3	main
õpin	doc_802069853738_item	2884548	et	3	main
tallinna	doc_802069853738_item	2884549	et	4	main
õppimine	doc_802069853738_item	2884553	et	4	main
on	doc_802069853738_item	2884561	et	4	main
ka	doc_802069853738_item	2884562	et	3	main
eesti	doc_802069853738_item	2884571	et	4	main
käinud	doc_802069853738_item	2884577	et	4	main
koolituskursustele	doc_802069853738_item	2884580	et	3	main
võimatu	doc_802069853738_item	2884583	et	4	main
eesti	doc_802069853738_item	2884585	et	4	main
muidugi	doc_802069853738_item	2884589	et	4	main
ei	doc_802069853738_item	2884591	et	4	main
sellepärast	doc_802069853738_item	2884601	et	3	main
eesti	doc_802069853738_item	2884604	et	4	main
keele	doc_802069853738_item	2884605	et	4	main
tunnid	doc_802069853738_item	2884606	et	3	main
ja	doc_802069853739_item	2884611	et	3	main
ülikool	doc_802069853739_item	2884612	et	4	main
minu	doc_802069853739_item	2884613	et	3	main
nimi	doc_802069853739_item	2884614	et	3	main
on	doc_802069853739_item	2884615	et	4	main
eesnimi	doc_802069853739_item	2884616	et	3	main
kõik	doc_802069853739_item	2884621	et	4	main
neli	doc_802069853739_item	2884627	et	3	main
tallinna	doc_802069853739_item	2884642	et	4	main
tugev	doc_802069853739_item	2884655	et	4	main
saada	doc_802069853739_item	2884660	et	4	main
palju	doc_802069853739_item	2884661	et	4	main
ja	doc_802069853739_item	2884663	et	3	main
ma	doc_802069853739_item	2884664	et	3	main
saan	doc_802069853739_item	2884665	et	4	main
elan	doc_802069853739_item	2884670	et	3	main
ja	doc_802069853739_item	2884672	et	3	main
eesti	doc_802069853739_item	2884679	et	4	main
ja	doc_802069853739_item	2884688	et	3	main
ülikool	doc_802069853740_item	2884698	et	4	main
minu	doc_802069853740_item	2884699	et	3	main
nimi	doc_802069853740_item	2884700	et	3	main
on	doc_802069853740_item	2884701	et	4	main
eesnimi	doc_802069853740_item	2884702	et	3	main
perekonnanimi	doc_802069853740_item	2884703	et	3	main
aastal	doc_802069853740_item	2884705	et	3	main
ma	doc_802069853740_item	2884706	et	3	main
väga	doc_802069853740_item	2884719	et	3	main
noor	doc_802069853740_item	2884720	et	3	main
umbes	doc_802069853740_item	2884721	et	4	main
7	doc_802069853740_item	2884723	et	2	main
aastat	doc_802069853740_item	2884724	et	3	main
erinevat	doc_802069853740_item	2884728	et	4	main
või	doc_802069853740_item	2884737	et	4	main
teine	doc_802069853740_item	2884738	et	3	main
tegima	doc_802069853740_item	2884745	et	4	main
kohal	doc_802069853740_item	2884755	et	4	main
oma	doc_802069853740_item	2884760	et	4	main
ja	doc_802069853740_item	2884764	et	3	main
hobbi	doc_802069853740_item	2884767	et	4	main
ja	doc_802069853740_item	2884773	et	3	main
raske	doc_802069853740_item	2884781	et	4	main
hea	doc_802069853740_item	2884783	et	4	main
hariduse	doc_802069853740_item	2884786	et	3	main
haridus	doc_802069853740_item	2884793	et	3	main
juba	doc_802069853740_item	2884797	et	3	main
meeldib	doc_802069853740_item	2884800	et	3	main
elektroonika	doc_802069853740_item	2884801	et	4	main
ma	doc_802069853740_item	2884803	et	3	main
töösel	doc_802069853740_item	2884806	et	4	main
missugune	doc_802069853740_item	2884807	et	3	main
selle	doc_802069853740_item	2884822	et	4	main
ttü	doc_802069853740_item	2884833	et	4	main
hea	doc_802069853740_item	2884837	et	4	main
ja	doc_802069853740_item	2884845	et	3	main
minule	doc_802069853740_item	2884846	et	3	main
meeldib	doc_802069853740_item	2884848	et	3	main
on	doc_802069853740_item	2884851	et	4	main
on	doc_802069853740_item	2884857	et	4	main
ja	doc_802069853740_item	2884860	et	3	main
veel	doc_802069853740_item	2884866	et	4	main
aga	doc_802069853740_item	2884896	et	3	main
tulen	doc_802069853740_item	2884901	et	3	main
ise	doc_802069853740_item	2884903	et	4	main
minu	doc_802069853740_item	2884906	et	3	main
tulevikus	doc_802069853740_item	2884917	et	4	main
algab	doc_802069853740_item	2884919	et	3	main
ainult	doc_802069853740_item	2884920	et	4	main
ilma	doc_802069853738_item	2884597	et	4	main
keele	doc_802069853738_item	2884599	et	4	main
oskuseta	doc_802069853738_item	2884600	et	3	main
loodan	doc_802069853738_item	2884602	et	3	main
essee	doc_802069853739_item	2884609	et	4	main
mina	doc_802069853739_item	2884610	et	4	main
eestimaal	doc_802069853739_item	2884626	et	4	main
tagasi	doc_802069853739_item	2884629	et	3	main
ma	doc_802069853739_item	2884630	et	3	main
ja	doc_802069853739_item	2884624	et	3	main
tallinna	doc_802069853739_item	2884635	et	4	main
polütehnikumis	doc_802069853739_item	2884636	et	3	main
tpt	doc_802069853739_item	2884638	et	4	main
ma	doc_802069853739_item	2884639	et	3	main
astusin	doc_802069853739_item	2884640	et	3	main
sisse	doc_802069853739_item	2884641	et	4	main
seal	doc_802069853739_item	2884648	et	4	main
ma	doc_802069853739_item	2884649	et	3	main
valisin	doc_802069853739_item	2884650	et	3	main
ttü	doc_802069853739_item	2884651	et	4	main
siin	doc_802069853739_item	2884657	et	4	main
võimalik	doc_802069853739_item	2884659	et	3	main
informatsiooni	doc_802069853739_item	2884662	et	4	main
pean	doc_802069853739_item	2884673	et	4	main
osata	doc_802069853739_item	2884674	et	4	main
keele	doc_802069853739_item	2884680	et	4	main
et	doc_802069853739_item	2884682	et	3	main
minu	doc_802069853739_item	2884683	et	3	main
eesti	doc_802069853739_item	2884684	et	4	main
oskan	doc_802069853739_item	2884690	et	3	main
rühmas	doc_802069853739_item	2884694	et	4	main
essee	doc_802069853740_item	2884695	et	4	main
mustamäe	doc_802069853740_item	2884709	et	3	main
mina	doc_802069853740_item	2884711	et	4	main
olen	doc_802069853740_item	2884712	et	3	main
aastat	doc_802069853740_item	2884714	et	3	main
olen	doc_802069853740_item	2884718	et	3	main
lõpitasin	doc_802069853739_item	2884631	et	4	main
põhikool	doc_802069853739_item	2884632	et	4	main
ja	doc_802069853739_item	2884633	et	3	main
käin	doc_802069853739_item	2884634	et	3	main
tehnikaülikoolis	doc_802069853739_item	2884643	et	4	main
ja	doc_802069853739_item	2884644	et	3	main
praegu	doc_802069853739_item	2884645	et	3	main
hakkan	doc_802069853739_item	2884646	et	3	main
sest	doc_802069853739_item	2884652	et	4	main
see	doc_802069853739_item	2884653	et	3	main
ülikool	doc_802069853739_item	2884656	et	4	main
on	doc_802069853739_item	2884658	et	4	main
heaks	doc_802069853739_item	2884667	et	4	main
programeerijaks	doc_802069853739_item	2884668	et	4	main
ma	doc_802069853739_item	2884669	et	3	main
eetis	doc_802069853739_item	2884671	et	4	main
keel	doc_802069853739_item	2884685	et	4	main
saab	doc_802069853739_item	2884686	et	3	main
mina	doc_802069853740_item	2884696	et	4	main
ja	doc_802069853740_item	2884697	et	3	main
19	doc_802069853740_item	2884713	et	2	main
meeldib	doc_802069853740_item	2884727	et	3	main
mulle	doc_802069853740_item	2884730	et	4	main
oli	doc_802069853740_item	2884731	et	3	main
väga	doc_802069853740_item	2884732	et	3	main
huvitav	doc_802069853740_item	2884733	et	4	main
kuidas	doc_802069853740_item	2884734	et	3	main
töötab	doc_802069853740_item	2884735	et	3	main
veel	doc_802069853740_item	2884740	et	4	main
see	doc_802069853740_item	2884747	et	3	main
on	doc_802069853740_item	2884748	et	4	main
hobi	doc_802069853740_item	2884750	et	4	main
aga	doc_802069853740_item	2884751	et	3	main
ta	doc_802069853740_item	2884752	et	4	main
seisab	doc_802069853740_item	2884753	et	3	main
hobbi	doc_802069853740_item	2884758	et	4	main
see	doc_802069853740_item	2884765	et	3	main
elektroonika	doc_802069853740_item	2884769	et	4	main
erinevat	doc_802069853740_item	2884775	et	4	main
aga	doc_802069853740_item	2884777	et	3	main
ajal	doc_802069853740_item	2884779	et	4	main
saada	doc_802069853740_item	2884782	et	4	main
ja	doc_802069853740_item	2884787	et	3	main
on	doc_802069853740_item	2884789	et	4	main
hea	doc_802069853740_item	2884792	et	4	main
saada	doc_802069853740_item	2884794	et	4	main
ma	doc_802069853740_item	2884796	et	3	main
ja	doc_802069853740_item	2884802	et	3	main
töötada	doc_802069853740_item	2884805	et	3	main
oleks	doc_802069853740_item	2884808	et	3	main
mina	doc_802069853740_item	2884811	et	4	main
on	doc_802069853740_item	2884825	et	4	main
hea	doc_802069853740_item	2884826	et	4	main
kergem	doc_802069853740_item	2884835	et	4	main
mina	doc_802069853740_item	2884839	et	4	main
juba	doc_802069853740_item	2884840	et	3	main
seal	doc_802069853740_item	2884849	et	4	main
ja	doc_802069853740_item	2884853	et	3	main
ilus	doc_802069853740_item	2884854	et	4	main
uesti	doc_802069853740_item	2884859	et	4	main
mulle	doc_802069853740_item	2884867	et	4	main
väga	doc_802069853740_item	2884868	et	3	main
meeldib	doc_802069853740_item	2884869	et	3	main
suhtumine	doc_802069853740_item	2884870	et	4	main
on	doc_802069853740_item	2884910	et	4	main
et	doc_802069853740_item	2884916	et	3	main
eesti	doc_802069853740_item	2884929	et	4	main
keel	doc_802069853740_item	2884946	et	4	main
tean	doc_802069853740_item	2884947	et	3	main
ülikool	doc_802069853741_item	2884951	et	4	main
on	doc_802069853741_item	2884954	et	4	main
ma	doc_802069853741_item	2884957	et	3	main
olen	doc_802069853741_item	2884958	et	3	main
aastad	doc_802069853741_item	2884960	et	3	main
mina	doc_802069853741_item	2884967	et	4	main
olen	doc_802069853741_item	2884968	et	3	main
sportlik	doc_802069853741_item	2884969	et	3	main
hariduseta	doc_802069853741_item	2884992	et	3	main
sellepärast	doc_802069853741_item	2884998	et	3	main
lõpetamist	doc_802069853741_item	2885006	et	4	main
kellena	doc_802069853741_item	2885011	et	3	main
et	doc_802069853741_item	2885020	et	3	main
pärast	doc_802069853739_item	2884637	et	4	main
õpimine	doc_802069853739_item	2884647	et	4	main
on	doc_802069853739_item	2884654	et	4	main
saada	doc_802069853739_item	2884666	et	4	main
keelt	doc_802069853739_item	2884676	et	4	main
ma	doc_802069853739_item	2884677	et	3	main
ootan	doc_802069853739_item	2884678	et	3	main
loengutelt	doc_802069853739_item	2884681	et	4	main
ma	doc_802069853739_item	2884689	et	3	main
eesti	doc_802069853739_item	2884692	et	4	main
tallinna	doc_802069853740_item	2884708	et	4	main
vana	doc_802069853740_item	2884715	et	4	main
ma	doc_802069853740_item	2884717	et	3	main
selline	doc_802069853740_item	2884736	et	4	main
mulle	doc_802069853740_item	2884741	et	4	main
väga	doc_802069853740_item	2884742	et	3	main
meeldib	doc_802069853740_item	2884743	et	3	main
fotot	doc_802069853740_item	2884744	et	3	main
teisel	doc_802069853740_item	2884754	et	4	main
võttab	doc_802069853740_item	2884759	et	4	main
lapsepõlvest	doc_802069853740_item	2884763	et	4	main
pea	doc_802069853740_item	2884766	et	4	main
on	doc_802069853740_item	2884768	et	4	main
parandan	doc_802069853740_item	2884774	et	3	main
ilma	doc_802069853740_item	2884785	et	4	main
ttüs	doc_802069853740_item	2884788	et	4	main
võimalus	doc_802069853740_item	2884790	et	3	main
kui	doc_802069853740_item	2884795	et	3	main
kirjutasin	doc_802069853740_item	2884798	et	3	main
minule	doc_802069853740_item	2884799	et	3	main
tahan	doc_802069853740_item	2884804	et	3	main
tean	doc_802069853740_item	2884812	et	3	main
eesti	doc_802069853739_item	2884675	et	4	main
parem	doc_802069853739_item	2884687	et	4	main
oppida	doc_802069853739_item	2884691	et	4	main
keelne	doc_802069853739_item	2884693	et	3	main
seel	doc_802069853740_item	2884704	et	4	main
lõpetasin	doc_802069853740_item	2884707	et	3	main
reaalgümnaasium	doc_802069853740_item	2884710	et	3	main
kui	doc_802069853740_item	2884716	et	3	main
5	doc_802069853740_item	2884722	et	2	main
mulle	doc_802069853740_item	2884725	et	4	main
väga	doc_802069853740_item	2884726	et	3	main
tehnikat	doc_802069853740_item	2884729	et	3	main
asi	doc_802069853740_item	2884739	et	4	main
ja	doc_802069853740_item	2884746	et	3	main
minu	doc_802069853740_item	2884749	et	3	main
minu	doc_802069853740_item	2884756	et	3	main
pea	doc_802069853740_item	2884757	et	4	main
algus	doc_802069853740_item	2884761	et	4	main
minu	doc_802069853740_item	2884762	et	3	main
mina	doc_802069853740_item	2884770	et	4	main
juba	doc_802069853740_item	2884771	et	3	main
töötan	doc_802069853740_item	2884772	et	3	main
tehnikat	doc_802069853740_item	2884776	et	3	main
meie	doc_802069853740_item	2884778	et	4	main
on	doc_802069853740_item	2884780	et	4	main
töö	doc_802069853740_item	2884784	et	4	main
selline	doc_802069853740_item	2884791	et	4	main
seotud	doc_802069853740_item	2884809	et	4	main
et	doc_802069853740_item	2884813	et	3	main
ttü	doc_802069853740_item	2884814	et	4	main
on	doc_802069853740_item	2884815	et	4	main
kõige	doc_802069853740_item	2884816	et	4	main
vanam	doc_802069853740_item	2884817	et	4	main
tehnika	doc_802069853740_item	2884818	et	4	main
ülikool	doc_802069853740_item	2884819	et	4	main
estis	doc_802069853740_item	2884820	et	4	main
ja	doc_802069853740_item	2884829	et	3	main
inimesele	doc_802069853740_item	2884830	et	3	main
kes	doc_802069853740_item	2884831	et	4	main
lõppetab	doc_802069853740_item	2884832	et	4	main
saada	doc_802069853740_item	2884836	et	4	main
õppisin	doc_802069853740_item	2884841	et	3	main
ttüs	doc_802069853740_item	2884842	et	4	main
üks	doc_802069853740_item	2884843	et	3	main
nädal	doc_802069853740_item	2884844	et	3	main
väga	doc_802069853740_item	2884847	et	3	main
see	doc_802069853740_item	2884850	et	3	main
seal	doc_802069853740_item	2884862	et	4	main
õppilasele	doc_802069853740_item	2884871	et	4	main
tean	doc_802069853740_item	2884904	et	3	main
eesti	doc_802069853740_item	2884907	et	4	main
keele	doc_802069853740_item	2884908	et	4	main
oskus	doc_802069853740_item	2884909	et	3	main
tean	doc_802069853740_item	2884915	et	3	main
õppimine	doc_802069853740_item	2884918	et	4	main
pärast	doc_802069853740_item	2884925	et	4	main
ma	doc_802069853740_item	2884926	et	3	main
tulen	doc_802069853740_item	2884927	et	3	main
lektsionile	doc_802069853740_item	2884936	et	4	main
eesti	doc_802069853740_item	2884939	et	4	main
kui	doc_802069853740_item	2884942	et	3	main
praegu	doc_802069853740_item	2884944	et	3	main
selline	doc_802069853740_item	2884945	et	4	main
minu	doc_802069853741_item	2884952	et	3	main
tallinna	doc_802069853741_item	2884964	et	4	main
mustamäe	doc_802069853741_item	2884965	et	3	main
pean	doc_802069853741_item	2884986	et	4	main
hea	doc_802069853741_item	2884995	et	4	main
tallinna	doc_802069853741_item	2885001	et	4	main
ülikooli	doc_802069853741_item	2885003	et	4	main
ei	doc_802069853741_item	2885008	et	4	main
olen	doc_802069853741_item	2885014	et	3	main
huvitav	doc_802069853741_item	2885022	et	4	main
olla	doc_802069853741_item	2885025	et	3	main
elektroonikaga	doc_802069853740_item	2884810	et	3	main
ja	doc_802069853740_item	2884821	et	3	main
pärast	doc_802069853740_item	2884823	et	4	main
ttüs	doc_802069853740_item	2884824	et	4	main
tehnika	doc_802069853740_item	2884827	et	4	main
haridus	doc_802069853740_item	2884828	et	3	main
on	doc_802069853740_item	2884834	et	4	main
töö	doc_802069853740_item	2884838	et	4	main
suur	doc_802069853740_item	2884852	et	3	main
maja	doc_802069853740_item	2884855	et	4	main
seal	doc_802069853740_item	2884856	et	4	main
palju	doc_802069853740_item	2884858	et	4	main
õppimine	doc_802069853740_item	2884861	et	4	main
on	doc_802069853740_item	2884863	et	4	main
väga	doc_802069853740_item	2884864	et	3	main
hea	doc_802069853740_item	2884865	et	4	main
suhtmine	doc_802069853740_item	2884872	et	4	main
torem	doc_802069853740_item	2884874	et	4	main
kui	doc_802069853740_item	2884875	et	3	main
koolis	doc_802069853740_item	2884876	et	4	main
esimesel	doc_802069853740_item	2884877	et	3	main
päeval	doc_802069853740_item	2884878	et	3	main
kui	doc_802069853740_item	2884879	et	3	main
ma	doc_802069853740_item	2884880	et	3	main
koju	doc_802069853740_item	2884881	et	3	main
tagasin	doc_802069853740_item	2884882	et	3	main
mul	doc_802069853740_item	2884883	et	3	main
oli	doc_802069853740_item	2884884	et	3	main
väga	doc_802069853740_item	2884885	et	3	main
palju	doc_802069853740_item	2884886	et	4	main
imotsioni	doc_802069853740_item	2884887	et	4	main
ja	doc_802069853740_item	2884888	et	3	main
mulle	doc_802069853740_item	2884889	et	4	main
meeldib	doc_802069853740_item	2884890	et	3	main
et	doc_802069853740_item	2884891	et	3	main
ma	doc_802069853740_item	2884892	et	3	main
on	doc_802069853740_item	2884873	et	4	main
keele	doc_802069853740_item	2884898	et	4	main
ma	doc_802069853740_item	2884900	et	3	main
halvas	doc_802069853740_item	2884911	et	4	main
eesti	doc_802069853740_item	2884921	et	4	main
kursudesse	doc_802069853740_item	2884928	et	4	main
mina	doc_802069853740_item	2884932	et	4	main
igasse	doc_802069853740_item	2884935	et	3	main
ja	doc_802069853740_item	2884937	et	3	main
õppida	doc_802069853740_item	2884938	et	3	main
keel	doc_802069853740_item	2884940	et	4	main
mina	doc_802069853741_item	2884949	et	4	main
ja	doc_802069853741_item	2884950	et	3	main
nimi	doc_802069853741_item	2884953	et	3	main
eesnimi	doc_802069853741_item	2884955	et	3	main
19	doc_802069853741_item	2884959	et	2	main
humanitaasium	doc_802069853741_item	2884966	et	4	main
ei	doc_802069853741_item	2884971	et	4	main
saa	doc_802069853741_item	2884972	et	4	main
istuda	doc_802069853741_item	2884973	et	3	main
ühel	doc_802069853741_item	2884974	et	3	main
kohal	doc_802069853741_item	2884975	et	4	main
sest	doc_802069853741_item	2884976	et	4	main
maailmas	doc_802069853741_item	2884977	et	3	main
on	doc_802069853741_item	2884978	et	4	main
nii	doc_802069853741_item	2884979	et	3	main
palju	doc_802069853741_item	2884980	et	4	main
huvitavaid	doc_802069853741_item	2884981	et	4	main
asju	doc_802069853741_item	2884982	et	3	main
mida	doc_802069853741_item	2884983	et	4	main
minu	doc_802069853741_item	2884984	et	3	main
arvamusest	doc_802069853741_item	2884985	et	4	main
tulen	doc_802069853740_item	2884893	et	3	main
ttüse	doc_802069853740_item	2884894	et	4	main
õppima	doc_802069853740_item	2884895	et	3	main
eesti	doc_802069853740_item	2884897	et	4	main
kursustele	doc_802069853740_item	2884899	et	3	main
et	doc_802069853740_item	2884902	et	3	main
et	doc_802069853740_item	2884905	et	3	main
vormis	doc_802069853740_item	2884912	et	4	main
veel	doc_802069853740_item	2884913	et	4	main
ma	doc_802069853740_item	2884914	et	3	main
keeles	doc_802069853740_item	2884922	et	4	main
ja	doc_802069853740_item	2884923	et	3	main
selle	doc_802069853740_item	2884924	et	4	main
keel	doc_802069853740_item	2884930	et	4	main
õppima	doc_802069853740_item	2884931	et	3	main
planerin	doc_802069853740_item	2884933	et	4	main
tulla	doc_802069853740_item	2884934	et	3	main
parem	doc_802069853740_item	2884941	et	4	main
mina	doc_802069853740_item	2884943	et	4	main
essee	doc_802069853741_item	2884948	et	4	main
perekonnanimi	doc_802069853741_item	2884956	et	3	main
vana	doc_802069853741_item	2884961	et	4	main
olen	doc_802069853741_item	2884962	et	3	main
lõpetanud	doc_802069853741_item	2884963	et	4	main
inimene	doc_802069853741_item	2884970	et	3	main
teada	doc_802069853741_item	2884987	et	3	main
mina	doc_802069853741_item	2884988	et	4	main
arvan	doc_802069853741_item	2884989	et	3	main
et	doc_802069853741_item	2884990	et	3	main
kärjääri	doc_802069853741_item	2884996	et	4	main
teha	doc_802069853741_item	2884997	et	3	main
astusin	doc_802069853741_item	2885000	et	3	main
tehnika	doc_802069853741_item	2885002	et	4	main
mina	doc_802069853741_item	2885007	et	4	main
tahan	doc_802069853741_item	2885012	et	3	main
palju	doc_802069853741_item	2885016	et	4	main
aega	doc_802069853741_item	2885017	et	4	main
ja	doc_802069853741_item	2885018	et	3	main
otsustasin	doc_802069853741_item	2885019	et	3	main
head	doc_802069853741_item	2885029	et	4	main
öelda	doc_802069853741_item	2885033	et	4	main
meeldib	doc_802069853741_item	2885043	et	3	main
võin	doc_802069853741_item	2885046	et	3	main
sest	doc_802069853741_item	2885056	et	4	main
kui	doc_802069853741_item	2885057	et	3	main
rohkem	doc_802069853741_item	2885058	et	4	main
loengudega	doc_802069853741_item	2885075	et	4	main
võin	doc_802069853741_item	2885076	et	3	main
laienda	doc_802069853741_item	2885077	et	4	main
narva	doc_802069853742_item	2885098	et	4	main
kesklinna	doc_802069853742_item	2885099	et	4	main
ülikooli	doc_802069853742_item	2885105	et	4	main
ja	doc_802069853742_item	2885106	et	3	main
praegu	doc_802069853742_item	2885107	et	3	main
olem	doc_802069853742_item	2885108	et	3	main
kodu	doc_802069853742_item	2885115	et	4	main
jõesus	doc_802069853742_item	2885118	et	4	main
eriala	doc_802069853742_item	2885126	et	4	main
mis	doc_802069853742_item	2885133	et	4	main
mul	doc_802069853742_item	2885137	et	3	main
projekt	doc_802069853742_item	2885140	et	3	main
sellepärast	doc_802069853742_item	2885141	et	3	main
ma	doc_802069853742_item	2885142	et	3	main
arvan	doc_802069853742_item	2885143	et	3	main
et	doc_802069853742_item	2885144	et	3	main
õppimine	doc_802069853742_item	2885156	et	4	main
mind	doc_802069853742_item	2885159	et	4	main
täpselt	doc_802069853742_item	2885165	et	4	main
kujuneda	doc_802069853742_item	2885166	et	3	main
väga	doc_802069853742_item	2885180	et	3	main
seal	doc_802069853742_item	2885188	et	4	main
rohkem	doc_802069853742_item	2885190	et	4	main
juba	doc_802069853742_item	2885196	et	3	main
ma	doc_802069853742_item	2885198	et	3	main
arvutiks	doc_802069853742_item	2885200	et	4	main
aga	doc_802069853742_item	2885201	et	3	main
tegelen	doc_802069853742_item	2885204	et	3	main
et	doc_802069853742_item	2885208	et	3	main
aitab	doc_802069853742_item	2885210	et	3	main
mind	doc_802069853742_item	2885211	et	4	main
ainest	doc_802069853742_item	2885215	et	4	main
iga	doc_802069853743_item	2885232	et	4	main
ei	doc_802069853741_item	2884993	et	4	main
saa	doc_802069853741_item	2884994	et	4	main
mina	doc_802069853741_item	2884999	et	4	main
teanud	doc_802069853741_item	2885010	et	4	main
ilma	doc_802069853741_item	2884991	et	4	main
pärast	doc_802069853741_item	2885004	et	4	main
kooli	doc_802069853741_item	2885005	et	4	main
täpselt	doc_802069853741_item	2885009	et	4	main
saada	doc_802069853741_item	2885013	et	4	main
mõtlenud	doc_802069853741_item	2885015	et	4	main
väga	doc_802069853741_item	2885021	et	3	main
inseneri	doc_802069853741_item	2885023	et	4	main
ttüst	doc_802069853741_item	2885026	et	4	main
mul	doc_802069853741_item	2885027	et	3	main
on	doc_802069853741_item	2885028	et	4	main
et	doc_802069853741_item	2885034	et	3	main
mulle	doc_802069853741_item	2885036	et	4	main
meeldib	doc_802069853741_item	2885037	et	3	main
elus	doc_802069853741_item	2885038	et	4	main
nii	doc_802069853741_item	2885041	et	3	main
et	doc_802069853741_item	2885045	et	3	main
mida	doc_802069853741_item	2885050	et	4	main
ei	doc_802069853741_item	2885051	et	4	main
seotud	doc_802069853741_item	2885053	et	4	main
minu	doc_802069853741_item	2885054	et	3	main
erialaga	doc_802069853741_item	2885055	et	3	main
seda	doc_802069853741_item	2885060	et	3	main
oma	doc_802069853741_item	2885082	et	4	main
asub	doc_802069853742_item	2885116	et	3	main
see	doc_802069853742_item	2885119	et	3	main
linn	doc_802069853742_item	2885120	et	3	main
tallinnast	doc_802069853742_item	2885122	et	3	main
ma	doc_802069853742_item	2885123	et	3	main
valisin	doc_802069853742_item	2885124	et	3	main
mind	doc_802069853742_item	2885128	et	4	main
huvitab	doc_802069853742_item	2885129	et	3	main
seotud	doc_802069853742_item	2885134	et	4	main
minu	doc_802069853742_item	2885150	et	3	main
jaoks	doc_802069853742_item	2885151	et	4	main
kindlasti	doc_802069853742_item	2885152	et	3	main
ma	doc_802069853742_item	2885153	et	3	main
aitab	doc_802069853742_item	2885158	et	3	main
täna	doc_802069853742_item	2885161	et	4	main
ei	doc_802069853742_item	2885163	et	4	main
ttüst	doc_802069853742_item	2885169	et	4	main
ja	doc_802069853742_item	2885177	et	3	main
nagu	doc_802069853742_item	2885194	et	3	main
ütlesin	doc_802069853742_item	2885197	et	3	main
töö	doc_802069853742_item	2885225	et	4	main
ja	doc_802069853743_item	2885243	et	3	main
on	doc_802069853743_item	2885246	et	4	main
pärit	doc_802069853743_item	2885247	et	3	main
london	doc_802069853743_item	2885254	et	4	main
on	doc_802069853743_item	2885258	et	4	main
kolmkümme	doc_802069853743_item	2885260	et	4	main
aastat	doc_802069853743_item	2885268	et	3	main
1997a	doc_802069853743_item	2885271	et	4	main
tuhande	doc_802069853743_item	2885272	et	3	main
üheksasaja	doc_802069853743_item	2885273	et	4	main
nad	doc_802069853743_item	2885278	et	3	main
esinevad	doc_802069853743_item	2885282	et	4	main
inglismaal	doc_802069853743_item	2885287	et	4	main
neid	doc_802069853743_item	2885290	et	4	main
1990	doc_802069853743_item	2885325	et	2	main
aastal	doc_802069853743_item	2885326	et	3	main
murdma	doc_802069853743_item	2885327	et	3	main
murdatud	doc_802069853743_item	2885328	et	3	main
noor	doc_802069853743_item	2885329	et	3	main
luikede	doc_802069853743_item	2885331	et	3	main
jalaluu	doc_802069853743_item	2885335	et	4	main
ja	doc_802069853743_item	2885336	et	3	main
pidama	doc_802069853743_item	2885337	et	4	main
edule	doc_802069853743_item	2885366	et	3	main
tagasihoidlikku	doc_802069853743_item	2885370	et	4	main
lõuna-aafrikas	doc_802069853743_item	2885398	et	4	main
oks	doc_802069853743_item	2885401	et	3	main
ütelda	doc_802069853743_item	2885412	et	4	main
nad	doc_802069853743_item	2885413	et	3	main
eelistavad	doc_802069853743_item	2885414	et	4	main
päev	doc_802069853743_item	2885417	et	3	main
kaupa	doc_802069853743_item	2885420	et	4	main
harjutus	doc_802069853744_item	2885421	et	4	main
avage	doc_802069853744_item	2885422	et	3	main
numbrid	doc_802069853744_item	2885424	et	3	main
sõnadega	doc_802069853744_item	2885426	et	3	main
õige	doc_802069853744_item	2885428	et	4	main
elektroonikuna	doc_802069853741_item	2885024	et	3	main
muljed	doc_802069853741_item	2885030	et	3	main
ei	doc_802069853741_item	2885031	et	4	main
ei	doc_802069853741_item	2885039	et	4	main
olla	doc_802069853741_item	2885042	et	3	main
ka	doc_802069853741_item	2885048	et	3	main
halbast	doc_802069853741_item	2885062	et	4	main
taha	doc_802069853741_item	2885065	et	4	main
sest	doc_802069853741_item	2885067	et	4	main
inimene	doc_802069853741_item	2885070	et	3	main
et	doc_802069853741_item	2885072	et	3	main
oma	doc_802069853741_item	2885078	et	4	main
silmaringi	doc_802069853741_item	2885079	et	4	main
essee	doc_802069853742_item	2885085	et	4	main
ja	doc_802069853742_item	2885087	et	3	main
mina	doc_802069853742_item	2885089	et	4	main
olen	doc_802069853742_item	2885090	et	3	main
eesnimi	doc_802069853742_item	2885091	et	3	main
perekonnanimi	doc_802069853742_item	2885092	et	3	main
ja	doc_802069853742_item	2885093	et	3	main
selles	doc_802069853742_item	2885094	et	4	main
aastas	doc_802069853742_item	2885095	et	3	main
ma	doc_802069853742_item	2885096	et	3	main
lõpetasin	doc_802069853742_item	2885097	et	3	main
astusin	doc_802069853742_item	2885102	et	3	main
ttü	doc_802069853742_item	2885109	et	4	main
elan	doc_802069853742_item	2885111	et	3	main
aga	doc_802069853742_item	2885113	et	3	main
narva	doc_802069853742_item	2885117	et	4	main
sest	doc_802069853742_item	2885127	et	4	main
arvutid	doc_802069853742_item	2885130	et	4	main
ja	doc_802069853742_item	2885131	et	3	main
nendega	doc_802069853742_item	2885135	et	4	main
internetis	doc_802069853742_item	2885136	et	4	main
eriala	doc_802069853742_item	2885146	et	4	main
väga	doc_802069853742_item	2885148	et	3	main
ttüs	doc_802069853742_item	2885157	et	4	main
tulevikus	doc_802069853742_item	2885160	et	4	main
ma	doc_802069853742_item	2885162	et	3	main
oma	doc_802069853742_item	2885167	et	4	main
muljed	doc_802069853742_item	2885168	et	3	main
üks	doc_802069853742_item	2885175	et	3	main
ülikoolist	doc_802069853742_item	2885179	et	4	main
et	doc_802069853742_item	2885186	et	3	main
meldib	doc_802069853742_item	2885189	et	4	main
õppida	doc_802069853742_item	2885191	et	3	main
koolis	doc_802069853742_item	2885193	et	4	main
programerijaks	doc_802069853742_item	2885205	et	4	main
oodan	doc_802069853742_item	2885207	et	4	main
sellest	doc_802069853742_item	2885214	et	4	main
loodan	doc_802069853742_item	2885218	et	3	main
taha	doc_802069853741_item	2885032	et	4	main
kõik	doc_802069853741_item	2885035	et	4	main
saa	doc_802069853741_item	2885040	et	4	main
seda	doc_802069853741_item	2885044	et	3	main
õppida	doc_802069853741_item	2885047	et	3	main
ei	doc_802069853741_item	2885064	et	4	main
rääkida	doc_802069853741_item	2885066	et	3	main
olen	doc_802069853741_item	2885068	et	3	main
loodan	doc_802069853741_item	2885071	et	3	main
paren	doc_802069853741_item	2885081	et	4	main
gümnasiumi	doc_802069853742_item	2885100	et	4	main
tunnid	doc_802069853741_item	2885049	et	3	main
ole	doc_802069853741_item	2885052	et	4	main
tead	doc_802069853741_item	2885059	et	4	main
parem	doc_802069853741_item	2885061	et	4	main
asjast	doc_802069853741_item	2885063	et	4	main
positiivne	doc_802069853741_item	2885069	et	3	main
eesti	doc_802069853741_item	2885073	et	4	main
keele	doc_802069853741_item	2885074	et	4	main
ja	doc_802069853741_item	2885080	et	3	main
keele	doc_802069853741_item	2885083	et	4	main
oskus	doc_802069853741_item	2885084	et	3	main
mina	doc_802069853742_item	2885086	et	4	main
ülikool	doc_802069853742_item	2885088	et	4	main
suvil	doc_802069853742_item	2885101	et	4	main
tallinna	doc_802069853742_item	2885103	et	4	main
tehnika	doc_802069853742_item	2885104	et	4	main
üliõpilane	doc_802069853742_item	2885110	et	3	main
üliõpilastekülas	doc_802069853742_item	2885112	et	3	main
minu	doc_802069853742_item	2885114	et	3	main
kaugelt	doc_802069853742_item	2885121	et	4	main
äriinfotehnologijat	doc_802069853742_item	2885125	et	4	main
kõik	doc_802069853742_item	2885132	et	4	main
on	doc_802069853742_item	2885138	et	4	main
oma	doc_802069853742_item	2885139	et	4	main
see	doc_802069853742_item	2885145	et	3	main
on	doc_802069853742_item	2885147	et	4	main
kasulik	doc_802069853742_item	2885149	et	3	main
lodan	doc_802069853742_item	2885154	et	4	main
et	doc_802069853742_item	2885155	et	3	main
saa	doc_802069853742_item	2885164	et	4	main
sest	doc_802069853742_item	2885170	et	4	main
ma	doc_802069853742_item	2885171	et	3	main
õpin	doc_802069853742_item	2885172	et	3	main
siis	doc_802069853742_item	2885173	et	3	main
ainult	doc_802069853742_item	2885174	et	4	main
nädal	doc_802069853742_item	2885176	et	3	main
tean	doc_802069853742_item	2885178	et	3	main
vähe	doc_802069853742_item	2885181	et	3	main
aga	doc_802069853742_item	2885182	et	3	main
ma	doc_802069853742_item	2885183	et	3	main
tahan	doc_802069853742_item	2885184	et	3	main
öelda	doc_802069853742_item	2885185	et	4	main
mulle	doc_802069853742_item	2885187	et	4	main
kui	doc_802069853742_item	2885192	et	3	main
ma	doc_802069853742_item	2885195	et	3	main
parem	doc_802069853742_item	2885212	et	4	main
teada	doc_802069853742_item	2885213	et	3	main
ja	doc_802069853742_item	2885216	et	3	main
et	doc_802069853742_item	2885219	et	3	main
ma	doc_802069853742_item	2885221	et	3	main
leida	doc_802069853742_item	2885223	et	3	main
hea	doc_802069853742_item	2885224	et	4	main
harjutus	doc_802069853743_item	2885226	et	4	main
avage	doc_802069853743_item	2885227	et	3	main
sulud	doc_802069853743_item	2885228	et	3	main
numbrid	doc_802069853743_item	2885229	et	3	main
kirjutage	doc_802069853743_item	2885230	et	3	main
sõnadega	doc_802069853743_item	2885231	et	3	main
punkti	doc_802069853743_item	2885237	et	4	main
maailmakuulsad	doc_802069853743_item	2885238	et	3	main
toomas	doc_802069853743_item	2885244	et	3	main
elavad	doc_802069853743_item	2885251	et	4	main
praegu	doc_802069853743_item	2885252	et	3	main
inglismaa	doc_802069853743_item	2885253	et	4	main
kolmkümmend	doc_802069853743_item	2885266	et	4	main
vana	doc_802069853743_item	2885269	et	4	main
alates	doc_802069853743_item	2885270	et	3	main
on	doc_802069853743_item	2885277	et	4	main
ja	doc_802069853743_item	2885281	et	3	main
teatrid	doc_802069853743_item	2885284	et	3	main
armastama	doc_802069853743_item	2885288	et	3	main
tervest	doc_802069853743_item	2885324	et	4	main
järve	doc_802069853743_item	2885332	et	4	main
pidatud	doc_802069853743_item	2885338	et	4	main
toomas	doc_802069853743_item	2885347	et	3	main
otsustanud	doc_802069853743_item	2885349	et	4	main
suurele	doc_802069853743_item	2885365	et	4	main
tagasihoidlik	doc_802069853743_item	2885369	et	3	main
lähiaja	doc_802069853743_item	2885372	et	3	main
on	doc_802069853743_item	2885374	et	4	main
toomas	doc_802069853743_item	2885380	et	3	main
veelgi	doc_802069853743_item	2885384	et	4	main
parem	doc_802069853743_item	2885385	et	4	main
tallinn	doc_802069853743_item	2885392	et	4	main
seejärel	doc_802069853743_item	2885395	et	3	main
lõuna-aafrika	doc_802069853743_item	2885397	et	4	main
kui	doc_802069853743_item	2885399	et	3	main
ja	doc_802069853743_item	2885402	et	3	main
veel	doc_802069853743_item	2885404	et	4	main
oska	doc_802069853743_item	2885409	et	4	main
nad	doc_802069853743_item	2885410	et	3	main
ütlema	doc_802069853743_item	2885411	et	3	main
ühe	doc_802069853743_item	2885418	et	4	main
huvitan	doc_802069853742_item	2885199	et	3	main
samuti	doc_802069853742_item	2885202	et	3	main
ma	doc_802069853742_item	2885203	et	3	main
ja	doc_802069853742_item	2885206	et	3	main
ttü	doc_802069853742_item	2885209	et	4	main
ma	doc_802069853742_item	2885217	et	3	main
tulevikus	doc_802069853742_item	2885220	et	4	main
saan	doc_802069853742_item	2885222	et	4	main
õige	doc_802069853743_item	2885233	et	4	main
vastus	doc_802069853743_item	2885234	et	3	main
annab	doc_802069853743_item	2885235	et	3	main
ühe	doc_802069853743_item	2885236	et	4	main
abielupaar	doc_802069853743_item	2885240	et	4	main
age	doc_802069853743_item	2885241	et	4	main
edur	doc_802069853743_item	2885245	et	4	main
eesti	doc_802069853743_item	2885248	et	4	main
eestist	doc_802069853743_item	2885249	et	3	main
aga	doc_802069853743_item	2885250	et	3	main
inglimaal	doc_802069853743_item	2885255	et	4	main
30	doc_802069853743_item	2885259	et	2	main
kaheksa	doc_802069853743_item	2885267	et	4	main
seitsmes	doc_802069853743_item	2885275	et	4	main
vabakutselise	doc_802069853743_item	2885280	et	4	main
erinevaid	doc_802069853743_item	2885285	et	4	main
väga	doc_802069853743_item	2885291	et	3	main
ning	doc_802069853743_item	2885292	et	3	main
isegi	doc_802069853743_item	2885293	et	4	main
karmid	doc_802069853743_item	2885294	et	4	main
kriitikud	doc_802069853743_item	2885295	et	3	main
suhtuma	doc_802069853743_item	2885296	et	3	main
suhutuvad	doc_802069853743_item	2885297	et	4	main
nendesse	doc_802069853743_item	2885298	et	4	main
hästi	doc_802069853743_item	2885300	et	3	main
üldiselt	doc_802069853743_item	2885299	et	4	main
viimased	doc_802069853743_item	2885301	et	3	main
artiklid	doc_802069853743_item	2885302	et	3	main
räägivad	doc_802069853743_item	2885303	et	3	main
noored	doc_802069853743_item	2885304	et	3	main
noored	doc_802069853743_item	2885305	et	3	main
ainult	doc_802069853743_item	2885306	et	4	main
ülivõrdes	doc_802069853743_item	2885307	et	3	main
kuid	doc_802069853743_item	2885308	et	4	main
kõik	doc_802069853743_item	2885309	et	4	main
pole	doc_802069853743_item	2885310	et	3	main
sugugi	doc_802069853743_item	2885311	et	4	main
alati	doc_802069853743_item	2885312	et	4	main
nii	doc_802069853743_item	2885313	et	3	main
kergelt	doc_802069853743_item	2885314	et	4	main
läinud	doc_802069853743_item	2885315	et	4	main
mõlemal	doc_802069853743_item	2885316	et	3	main
ja	doc_802069853743_item	2885317	et	3	main
agel	doc_802069853743_item	2885319	et	4	main
balletitantsijad	doc_802069853743_item	2885239	et	3	main
oks	doc_802069853743_item	2885242	et	3	main
londonis	doc_802069853743_item	2885256	et	4	main
age	doc_802069853743_item	2885257	et	4	main
aastane	doc_802069853743_item	2885261	et	4	main
ja	doc_802069853743_item	2885262	et	3	main
toomas	doc_802069853743_item	2885263	et	3	main
on	doc_802069853743_item	2885264	et	4	main
32	doc_802069853743_item	2885265	et	2	main
üheksakümend	doc_802069853743_item	2885274	et	4	main
a	doc_802069853743_item	2885276	et	4	main
vabakutseline	doc_802069853743_item	2885279	et	4	main
erinevad	doc_802069853743_item	2885283	et	4	main
teatrid	doc_802069853743_item	2885286	et	3	main
armastatud	doc_802069853743_item	2885289	et	4	main
eriti	doc_802069853743_item	2885318	et	3	main
on	doc_802069853743_item	2885320	et	4	main
olnud	doc_802069853743_item	2885321	et	4	main
probleeme	doc_802069853743_item	2885322	et	3	main
tervis	doc_802069853743_item	2885323	et	3	main
mõnda	doc_802069853743_item	2885339	et	4	main
tantsimisest	doc_802069853743_item	2885341	et	4	main
olema	doc_802069853743_item	2885343	et	4	main
olla	doc_802069853743_item	2885344	et	3	main
age	doc_802069853743_item	2885345	et	4	main
ja	doc_802069853743_item	2885346	et	3	main
tantsijad	doc_802069853743_item	2885368	et	4	main
nende	doc_802069853743_item	2885371	et	4	main
planeerima	doc_802069853743_item	2885376	et	3	main
ja	doc_802069853743_item	2885379	et	3	main
areneda	doc_802069853743_item	2885382	et	3	main
paremad	doc_802069853743_item	2885386	et	4	main
tantsida	doc_802069853743_item	2885387	et	3	main
märtsis	doc_802069853743_item	2885388	et	3	main
tulevad	doc_802069853743_item	2885389	et	4	main
nad	doc_802069853743_item	2885390	et	3	main
tallinna	doc_802069853743_item	2885393	et	4	main
sõidavad	doc_802069853743_item	2885396	et	3	main
sulud	doc_802069853744_item	2885423	et	3	main
ühe	doc_802069853744_item	2885431	et	4	main
maailmakuulsad	doc_802069853744_item	2885433	et	3	main
elavad	doc_802069853744_item	2885446	et	4	main
praegu	doc_802069853744_item	2885447	et	3	main
on	doc_802069853744_item	2885453	et	4	main
30	doc_802069853744_item	2885454	et	2	main
kaks	doc_802069853744_item	2885462	et	3	main
üheksasaja	doc_802069853744_item	2885468	et	4	main
vabakutselised	doc_802069853744_item	2885475	et	4	main
erinevad	doc_802069853744_item	2885478	et	4	main
teatre	doc_802069853744_item	2885481	et	4	main
neid	doc_802069853744_item	2885485	et	4	main
väga	doc_802069853744_item	2885486	et	3	main
ning	doc_802069853744_item	2885487	et	3	main
suhtuma	doc_802069853744_item	2885491	et	3	main
aastal	doc_802069853744_item	2885521	et	3	main
murdma	doc_802069853744_item	2885522	et	3	main
murdis	doc_802069853744_item	2885523	et	3	main
luikede	doc_802069853744_item	2885526	et	3	main
etendus	doc_802069853744_item	2885528	et	4	main
etendusi	doc_802069853744_item	2885529	et	4	main
jalaluu	doc_802069853744_item	2885530	et	4	main
ja	doc_802069853744_item	2885531	et	3	main
pidama	doc_802069853744_item	2885532	et	4	main
pidas	doc_802069853744_item	2885533	et	3	main
ainult	doc_802069853744_item	2885547	et	4	main
teineteisega	doc_802069853744_item	2885548	et	3	main
tehtud	doc_802069853744_item	2885554	et	4	main
vaatamata	doc_802069853744_item	2885559	et	4	main
tagasihoidlikumaks	doc_802069853744_item	2885565	et	4	main
täpselt	doc_802069853744_item	2885570	et	4	main
planeerima	doc_802069853744_item	2885571	et	3	main
ja	doc_802069853744_item	2885578	et	3	main
parem	doc_802069853744_item	2885581	et	4	main
seejärel	doc_802069853744_item	2885590	et	3	main
lõuna-aafrika	doc_802069853744_item	2885592	et	4	main
kaua	doc_802069853744_item	2885595	et	3	main
edur	doc_802069853744_item	2885598	et	4	main
veel	doc_802069853744_item	2885599	et	4	main
tipus	doc_802069853744_item	2885600	et	3	main
suudavad	doc_802069853744_item	2885601	et	3	main
püsida	doc_802069853744_item	2885602	et	3	main
ainult	doc_802069853743_item	2885352	et	4	main
teineteisega	doc_802069853743_item	2885353	et	3	main
paaris	doc_802069853743_item	2885354	et	4	main
kuigi	doc_802069853743_item	2885355	et	3	main
nemad	doc_802069853743_item	2885356	et	3	main
neid	doc_802069853743_item	2885357	et	4	main
on	doc_802069853743_item	2885358	et	4	main
tehtud	doc_802069853743_item	2885359	et	4	main
pakkumisi	doc_802069853743_item	2885360	et	4	main
ka	doc_802069853743_item	2885361	et	3	main
eraldi	doc_802069853743_item	2885362	et	4	main
tantsimiseks	doc_802069853743_item	2885363	et	4	main
naine	doc_802069853743_item	2885330	et	3	main
etendus	doc_802069853743_item	2885333	et	4	main
etendusi	doc_802069853743_item	2885334	et	4	main
aega	doc_802069853743_item	2885340	et	4	main
eemal	doc_802069853743_item	2885342	et	3	main
on	doc_802069853743_item	2885348	et	4	main
tantsima	doc_802069853743_item	2885350	et	3	main
tantsida	doc_802069853743_item	2885351	et	3	main
vaatamata	doc_802069853743_item	2885364	et	4	main
elavad	doc_802069853743_item	2885367	et	4	main
täpselt	doc_802069853743_item	2885375	et	4	main
age	doc_802069853743_item	2885378	et	4	main
ja	doc_802069853743_item	2885383	et	3	main
kaua	doc_802069853743_item	2885400	et	3	main
edur	doc_802069853743_item	2885403	et	4	main
tipus	doc_802069853743_item	2885405	et	3	main
suudavad	doc_802069853743_item	2885406	et	3	main
püsida	doc_802069853743_item	2885407	et	3	main
ei	doc_802069853743_item	2885408	et	4	main
päeva	doc_802069853743_item	2885419	et	4	main
kirjutage	doc_802069853744_item	2885425	et	3	main
iga	doc_802069853744_item	2885427	et	4	main
punkti	doc_802069853744_item	2885432	et	4	main
abielupaar	doc_802069853744_item	2885435	et	4	main
age	doc_802069853744_item	2885436	et	4	main
oks	doc_802069853744_item	2885437	et	3	main
ja	doc_802069853744_item	2885438	et	3	main
toomas	doc_802069853744_item	2885439	et	3	main
pärit	doc_802069853744_item	2885442	et	3	main
on	doc_802069853744_item	2885459	et	4	main
kolmkümend	doc_802069853744_item	2885461	et	4	main
vana	doc_802069853744_item	2885464	et	4	main
alates	doc_802069853744_item	2885465	et	3	main
1997a	doc_802069853744_item	2885466	et	4	main
seitsest	doc_802069853744_item	2885470	et	4	main
nad	doc_802069853744_item	2885473	et	3	main
ja	doc_802069853744_item	2885476	et	3	main
hästi	doc_802069853744_item	2885495	et	3	main
viimased	doc_802069853744_item	2885496	et	3	main
artiklid	doc_802069853744_item	2885497	et	3	main
räägivad	doc_802069853744_item	2885498	et	3	main
noored	doc_802069853744_item	2885499	et	3	main
noorele	doc_802069853744_item	2885500	et	3	main
ainult	doc_802069853744_item	2885501	et	4	main
esinemised	doc_802069853743_item	2885373	et	4	main
planeeris	doc_802069853743_item	2885377	et	3	main
tahavad	doc_802069853743_item	2885381	et	3	main
esinema	doc_802069853743_item	2885391	et	3	main
ja	doc_802069853743_item	2885394	et	3	main
elada	doc_802069853743_item	2885415	et	3	main
üks	doc_802069853743_item	2885416	et	3	main
edur	doc_802069853744_item	2885440	et	4	main
inglismaa	doc_802069853744_item	2885448	et	4	main
kolmekümne	doc_802069853744_item	2885455	et	4	main
aastane	doc_802069853744_item	2885456	et	4	main
ja	doc_802069853744_item	2885457	et	3	main
32	doc_802069853744_item	2885460	et	2	main
aastat	doc_802069853744_item	2885463	et	3	main
üheksakümne	doc_802069853744_item	2885469	et	4	main
on	doc_802069853744_item	2885472	et	4	main
esinevad	doc_802069853744_item	2885477	et	4	main
isegi	doc_802069853744_item	2885488	et	4	main
kriitikud	doc_802069853744_item	2885490	et	3	main
ülivõrdes	doc_802069853744_item	2885502	et	3	main
kuid	doc_802069853744_item	2885503	et	4	main
kõik	doc_802069853744_item	2885504	et	4	main
pole	doc_802069853744_item	2885505	et	3	main
sugugi	doc_802069853744_item	2885506	et	4	main
alati	doc_802069853744_item	2885507	et	4	main
nii	doc_802069853744_item	2885508	et	3	main
kergelt	doc_802069853744_item	2885509	et	4	main
läinud	doc_802069853744_item	2885510	et	4	main
mõlemal	doc_802069853744_item	2885511	et	3	main
ja	doc_802069853744_item	2885512	et	3	main
eriti	doc_802069853744_item	2885513	et	3	main
agel	doc_802069853744_item	2885514	et	4	main
on	doc_802069853744_item	2885515	et	4	main
olnud	doc_802069853744_item	2885516	et	4	main
probleeme	doc_802069853744_item	2885517	et	3	main
tervis	doc_802069853744_item	2885518	et	3	main
tervisega	doc_802069853744_item	2885519	et	3	main
1990	doc_802069853744_item	2885520	et	2	main
noor	doc_802069853744_item	2885524	et	3	main
järve	doc_802069853744_item	2885527	et	4	main
olema	doc_802069853744_item	2885538	et	4	main
toomas	doc_802069853744_item	2885542	et	3	main
pakkumisi	doc_802069853744_item	2885555	et	4	main
ka	doc_802069853744_item	2885556	et	3	main
eraldi	doc_802069853744_item	2885557	et	4	main
on	doc_802069853744_item	2885569	et	4	main
parem	doc_802069853744_item	2885580	et	4	main
märtsis	doc_802069853744_item	2885583	et	3	main
nad	doc_802069853744_item	2885585	et	3	main
kui	doc_802069853744_item	2885594	et	3	main
ja	doc_802069853744_item	2885597	et	3	main
ütlema	doc_802069853744_item	2885606	et	3	main
päev	doc_802069853744_item	2885612	et	3	main
päeva	doc_802069853744_item	2885614	et	4	main
kaupa	doc_802069853744_item	2885615	et	4	main
ühe	doc_802069853745_item	2885626	et	4	main
elavad	doc_802069853745_item	2885641	et	4	main
praegu	doc_802069853745_item	2885642	et	3	main
inglismaal	doc_802069853745_item	2885645	et	4	main
aastane	doc_802069853745_item	2885651	et	4	main
toomas	doc_802069853745_item	2885653	et	3	main
32	doc_802069853745_item	2885655	et	2	main
kolmkümend	doc_802069853745_item	2885656	et	4	main
vastus	doc_802069853744_item	2885429	et	3	main
annab	doc_802069853744_item	2885430	et	3	main
balletitantsijad	doc_802069853744_item	2885434	et	3	main
on	doc_802069853744_item	2885441	et	4	main
eesti	doc_802069853744_item	2885443	et	4	main
eeestis	doc_802069853744_item	2885444	et	4	main
aga	doc_802069853744_item	2885445	et	3	main
london	doc_802069853744_item	2885449	et	4	main
inglismaal	doc_802069853744_item	2885450	et	4	main
londonis	doc_802069853744_item	2885451	et	4	main
age	doc_802069853744_item	2885452	et	4	main
toomas	doc_802069853744_item	2885458	et	3	main
tuhat	doc_802069853744_item	2885467	et	4	main
aastast	doc_802069853744_item	2885471	et	4	main
vabakutseline	doc_802069853744_item	2885474	et	4	main
erinevaid	doc_802069853744_item	2885480	et	4	main
üldiselt	doc_802069853744_item	2885494	et	4	main
olla	doc_802069853744_item	2885539	et	3	main
ja	doc_802069853744_item	2885541	et	3	main
on	doc_802069853744_item	2885543	et	4	main
otsustanud	doc_802069853744_item	2885544	et	4	main
tantsima	doc_802069853744_item	2885545	et	3	main
tantsida	doc_802069853744_item	2885546	et	3	main
on	doc_802069853744_item	2885553	et	4	main
tantsimiseks	doc_802069853744_item	2885558	et	4	main
tantsijad	doc_802069853744_item	2885563	et	4	main
tagasihoidlik	doc_802069853744_item	2885564	et	3	main
areneda	doc_802069853744_item	2885577	et	3	main
tantsida	doc_802069853744_item	2885582	et	3	main
lõuna-aafrikasse	doc_802069853744_item	2885593	et	4	main
oks	doc_802069853744_item	2885596	et	3	main
öelda	doc_802069853744_item	2885607	et	4	main
üks	doc_802069853744_item	2885611	et	3	main
sõnadega	doc_802069853745_item	2885621	et	3	main
punkti	doc_802069853745_item	2885627	et	4	main
maailmakuulsad	doc_802069853745_item	2885628	et	3	main
balletitantsijad	doc_802069853745_item	2885629	et	3	main
on	doc_802069853745_item	2885636	et	4	main
pärit	doc_802069853745_item	2885637	et	3	main
london	doc_802069853745_item	2885644	et	4	main
londonis	doc_802069853745_item	2885646	et	4	main
kolmekümne	doc_802069853745_item	2885650	et	4	main
on	doc_802069853745_item	2885666	et	4	main
vabakutseline	doc_802069853745_item	2885668	et	4	main
ja	doc_802069853745_item	2885670	et	3	main
teatrid	doc_802069853745_item	2885673	et	3	main
armastama	doc_802069853745_item	2885677	et	3	main
üldiselt	doc_802069853745_item	2885688	et	4	main
räägivad	doc_802069853745_item	2885692	et	3	main
kõik	doc_802069853745_item	2885698	et	4	main
pole	doc_802069853745_item	2885699	et	3	main
sugugi	doc_802069853745_item	2885700	et	4	main
pidama	doc_802069853745_item	2885726	et	4	main
tantsimisest	doc_802069853745_item	2885730	et	4	main
olnud	doc_802069853745_item	2885733	et	4	main
paaris	doc_802069853745_item	2885743	et	4	main
kuigi	doc_802069853745_item	2885744	et	3	main
nemad	doc_802069853745_item	2885745	et	3	main
nendele	doc_802069853745_item	2885746	et	4	main
vaatamata	doc_802069853745_item	2885753	et	4	main
planeeritud	doc_802069853745_item	2885766	et	4	main
tahavad	doc_802069853745_item	2885770	et	3	main
veelgi	doc_802069853745_item	2885773	et	4	main
märtsis	doc_802069853745_item	2885777	et	3	main
suudavad	doc_802069853745_item	2885795	et	3	main
püsida	doc_802069853745_item	2885796	et	3	main
ei	doc_802069853745_item	2885797	et	4	main
elada	doc_802069853745_item	2885804	et	3	main
kirjutage	doc_802069853746_item	2885814	et	3	main
õige	doc_802069853746_item	2885817	et	4	main
annab	doc_802069853746_item	2885819	et	3	main
oks	doc_802069853746_item	2885826	et	3	main
ja	doc_802069853746_item	2885827	et	3	main
toomas	doc_802069853746_item	2885828	et	3	main
edur	doc_802069853746_item	2885829	et	4	main
eestis	doc_802069853746_item	2885833	et	3	main
praegu	doc_802069853746_item	2885836	et	3	main
london	doc_802069853746_item	2885838	et	4	main
aastane	doc_802069853746_item	2885845	et	4	main
ja	doc_802069853746_item	2885846	et	3	main
toomas	doc_802069853746_item	2885847	et	3	main
teatrid	doc_802069853744_item	2885479	et	3	main
inglismaal	doc_802069853744_item	2885482	et	4	main
armastama	doc_802069853744_item	2885483	et	3	main
armastatakse	doc_802069853744_item	2885484	et	3	main
karmid	doc_802069853744_item	2885489	et	4	main
suhtusid	doc_802069853744_item	2885492	et	4	main
nendesse	doc_802069853744_item	2885493	et	4	main
naine	doc_802069853744_item	2885525	et	3	main
mõnda	doc_802069853744_item	2885534	et	4	main
aega	doc_802069853744_item	2885535	et	4	main
tantsimisest	doc_802069853744_item	2885536	et	4	main
eemal	doc_802069853744_item	2885537	et	3	main
age	doc_802069853744_item	2885540	et	4	main
paaris	doc_802069853744_item	2885549	et	4	main
kuigi	doc_802069853744_item	2885550	et	3	main
nemad	doc_802069853744_item	2885551	et	3	main
nendele	doc_802069853744_item	2885552	et	4	main
suurele	doc_802069853744_item	2885560	et	4	main
edule	doc_802069853744_item	2885561	et	3	main
elavad	doc_802069853744_item	2885562	et	4	main
nende	doc_802069853744_item	2885566	et	4	main
lähiaja	doc_802069853744_item	2885567	et	3	main
esinemised	doc_802069853744_item	2885568	et	4	main
planeeritud	doc_802069853744_item	2885572	et	4	main
age	doc_802069853744_item	2885573	et	4	main
ja	doc_802069853744_item	2885574	et	3	main
toomas	doc_802069853744_item	2885575	et	3	main
tahavad	doc_802069853744_item	2885576	et	3	main
veelgi	doc_802069853744_item	2885579	et	4	main
tulevad	doc_802069853744_item	2885584	et	4	main
esinema	doc_802069853744_item	2885586	et	3	main
tallinn	doc_802069853744_item	2885587	et	4	main
tallinnale	doc_802069853744_item	2885588	et	4	main
ja	doc_802069853744_item	2885589	et	3	main
ei	doc_802069853744_item	2885603	et	4	main
harjutus	doc_802069853745_item	2885616	et	4	main
avage	doc_802069853745_item	2885617	et	3	main
sulud	doc_802069853745_item	2885618	et	3	main
numbrid	doc_802069853745_item	2885619	et	3	main
kirjutage	doc_802069853745_item	2885620	et	3	main
sõidavad	doc_802069853744_item	2885591	et	3	main
oska	doc_802069853744_item	2885604	et	4	main
nad	doc_802069853744_item	2885605	et	3	main
eelistavad	doc_802069853744_item	2885609	et	4	main
elada	doc_802069853744_item	2885610	et	3	main
ühe	doc_802069853744_item	2885613	et	4	main
abielupaar	doc_802069853745_item	2885630	et	4	main
eesti	doc_802069853745_item	2885638	et	4	main
eestis	doc_802069853745_item	2885639	et	3	main
aga	doc_802069853745_item	2885640	et	3	main
age	doc_802069853745_item	2885647	et	4	main
on	doc_802069853745_item	2885654	et	4	main
vana	doc_802069853745_item	2885659	et	4	main
alates	doc_802069853745_item	2885660	et	3	main
1997a	doc_802069853745_item	2885661	et	4	main
tuhande	doc_802069853745_item	2885662	et	3	main
üheksasaja	doc_802069853745_item	2885663	et	4	main
seitsmendal	doc_802069853745_item	2885665	et	3	main
üheksakümne	doc_802069853745_item	2885664	et	4	main
nad	doc_802069853744_item	2885608	et	3	main
iga	doc_802069853745_item	2885622	et	4	main
õige	doc_802069853745_item	2885623	et	4	main
vastus	doc_802069853745_item	2885624	et	3	main
annab	doc_802069853745_item	2885625	et	3	main
age	doc_802069853745_item	2885631	et	4	main
oks	doc_802069853745_item	2885632	et	3	main
ja	doc_802069853745_item	2885633	et	3	main
toomas	doc_802069853745_item	2885634	et	3	main
edur	doc_802069853745_item	2885635	et	4	main
inglismaa	doc_802069853745_item	2885643	et	4	main
on	doc_802069853745_item	2885648	et	4	main
30	doc_802069853745_item	2885649	et	2	main
ja	doc_802069853745_item	2885652	et	3	main
erinevad	doc_802069853745_item	2885672	et	4	main
neid	doc_802069853745_item	2885679	et	4	main
nendesse	doc_802069853745_item	2885687	et	4	main
ainult	doc_802069853745_item	2885695	et	4	main
ülivõrdes	doc_802069853745_item	2885696	et	3	main
alati	doc_802069853745_item	2885701	et	4	main
nii	doc_802069853745_item	2885702	et	3	main
on	doc_802069853745_item	2885709	et	4	main
olnud	doc_802069853745_item	2885710	et	4	main
1990	doc_802069853745_item	2885714	et	2	main
aastal	doc_802069853745_item	2885715	et	3	main
murdma	doc_802069853745_item	2885716	et	3	main
noor	doc_802069853745_item	2885718	et	3	main
luikede	doc_802069853745_item	2885720	et	3	main
pidab	doc_802069853745_item	2885727	et	4	main
eemal	doc_802069853745_item	2885731	et	3	main
age	doc_802069853745_item	2885734	et	4	main
ja	doc_802069853745_item	2885735	et	3	main
toomas	doc_802069853745_item	2885736	et	3	main
on	doc_802069853745_item	2885737	et	4	main
teineteisega	doc_802069853745_item	2885742	et	3	main
suurele	doc_802069853745_item	2885754	et	4	main
edule	doc_802069853745_item	2885755	et	3	main
nende	doc_802069853745_item	2885760	et	4	main
on	doc_802069853745_item	2885763	et	4	main
ja	doc_802069853745_item	2885768	et	3	main
ja	doc_802069853745_item	2885772	et	3	main
paremeni	doc_802069853745_item	2885775	et	4	main
lõuna-aafrika	doc_802069853745_item	2885786	et	4	main
kui	doc_802069853745_item	2885788	et	3	main
oks	doc_802069853745_item	2885790	et	3	main
ütelda	doc_802069853745_item	2885801	et	4	main
nad	doc_802069853745_item	2885802	et	3	main
sõnadega	doc_802069853746_item	2885815	et	3	main
ühe	doc_802069853746_item	2885820	et	4	main
kaks	doc_802069853745_item	2885657	et	3	main
aastat	doc_802069853745_item	2885658	et	3	main
nad	doc_802069853745_item	2885667	et	3	main
vabakutselised	doc_802069853745_item	2885669	et	4	main
esinevad	doc_802069853745_item	2885671	et	4	main
armastasid	doc_802069853745_item	2885678	et	4	main
karmid	doc_802069853745_item	2885683	et	4	main
kriitikud	doc_802069853745_item	2885684	et	3	main
hästi	doc_802069853745_item	2885689	et	3	main
kuid	doc_802069853745_item	2885697	et	4	main
probleeme	doc_802069853745_item	2885711	et	3	main
tervis	doc_802069853745_item	2885712	et	3	main
tervisega	doc_802069853745_item	2885713	et	3	main
murdab	doc_802069853745_item	2885717	et	4	main
etendus	doc_802069853745_item	2885722	et	4	main
etendusi	doc_802069853745_item	2885723	et	4	main
jalaluu	doc_802069853745_item	2885724	et	4	main
ja	doc_802069853745_item	2885725	et	3	main
mõnda	doc_802069853745_item	2885728	et	4	main
otsustanud	doc_802069853745_item	2885738	et	4	main
tantsima	doc_802069853745_item	2885739	et	3	main
tantsida	doc_802069853745_item	2885740	et	3	main
on	doc_802069853745_item	2885747	et	4	main
tantsimiseks	doc_802069853745_item	2885752	et	4	main
tantsijad	doc_802069853745_item	2885757	et	4	main
tagasihoidlik	doc_802069853745_item	2885758	et	3	main
tagasihoidliku	doc_802069853745_item	2885759	et	3	main
esinemised	doc_802069853745_item	2885762	et	4	main
täpselt	doc_802069853745_item	2885764	et	4	main
planeerima	doc_802069853745_item	2885765	et	3	main
toomas	doc_802069853745_item	2885769	et	3	main
parem	doc_802069853745_item	2885774	et	4	main
tantsida	doc_802069853745_item	2885776	et	3	main
tallinn	doc_802069853745_item	2885781	et	4	main
tallinnasse	doc_802069853745_item	2885782	et	3	main
ja	doc_802069853745_item	2885783	et	3	main
seejärel	doc_802069853745_item	2885784	et	3	main
sõidavad	doc_802069853745_item	2885785	et	3	main
kaua	doc_802069853745_item	2885789	et	3	main
edur	doc_802069853745_item	2885792	et	4	main
veel	doc_802069853745_item	2885793	et	4	main
tipus	doc_802069853745_item	2885794	et	3	main
eelistavad	doc_802069853745_item	2885803	et	4	main
ühe	doc_802069853745_item	2885807	et	4	main
kaupa	doc_802069853745_item	2885809	et	4	main
harjutus	doc_802069853746_item	2885810	et	4	main
avage	doc_802069853746_item	2885811	et	3	main
sulud	doc_802069853746_item	2885812	et	3	main
iga	doc_802069853746_item	2885816	et	4	main
vastus	doc_802069853746_item	2885818	et	3	main
age	doc_802069853746_item	2885825	et	4	main
eesti	doc_802069853746_item	2885832	et	4	main
30	doc_802069853746_item	2885843	et	2	main
kolmekumne	doc_802069853746_item	2885844	et	4	main
kolmküment	doc_802069853746_item	2885850	et	4	main
kaks	doc_802069853746_item	2885851	et	3	main
nad	doc_802069853746_item	2885862	et	3	main
esinevad	doc_802069853746_item	2885866	et	4	main
neid	doc_802069853746_item	2885874	et	4	main
ainult	doc_802069853746_item	2885890	et	4	main
ülivõrdes	doc_802069853746_item	2885891	et	3	main
sugugi	doc_802069853746_item	2885895	et	4	main
kergelt	doc_802069853746_item	2885898	et	4	main
läinud	doc_802069853746_item	2885899	et	4	main
mõlemal	doc_802069853746_item	2885900	et	3	main
ja	doc_802069853746_item	2885901	et	3	main
on	doc_802069853746_item	2885904	et	4	main
1990	doc_802069853746_item	2885909	et	2	main
aastal	doc_802069853746_item	2885910	et	3	main
murdma	doc_802069853746_item	2885911	et	3	main
noor	doc_802069853746_item	2885912	et	3	main
naine	doc_802069853746_item	2885913	et	3	main
luikede	doc_802069853746_item	2885914	et	3	main
jalaluu	doc_802069853746_item	2885917	et	4	main
pidama	doc_802069853746_item	2885919	et	4	main
pidas	doc_802069853746_item	2885920	et	3	main
olema	doc_802069853746_item	2885925	et	4	main
paaris	doc_802069853746_item	2885935	et	4	main
kuigi	doc_802069853746_item	2885936	et	3	main
need	doc_802069853746_item	2885938	et	3	main
eraldi	doc_802069853746_item	2885943	et	4	main
erinevades	doc_802069853745_item	2885674	et	4	main
teatrides	doc_802069853745_item	2885675	et	4	main
inglismaal	doc_802069853745_item	2885676	et	4	main
väga	doc_802069853745_item	2885680	et	3	main
ning	doc_802069853745_item	2885681	et	3	main
artiklid	doc_802069853745_item	2885691	et	3	main
noordest	doc_802069853745_item	2885694	et	4	main
kergelt	doc_802069853745_item	2885703	et	4	main
läinud	doc_802069853745_item	2885704	et	4	main
mõlemal	doc_802069853745_item	2885705	et	3	main
agel	doc_802069853745_item	2885708	et	4	main
järve	doc_802069853745_item	2885721	et	4	main
aega	doc_802069853745_item	2885729	et	4	main
olema	doc_802069853745_item	2885732	et	4	main
ainult	doc_802069853745_item	2885741	et	4	main
tehtud	doc_802069853745_item	2885748	et	4	main
pakkumisi	doc_802069853745_item	2885749	et	4	main
ka	doc_802069853745_item	2885750	et	3	main
eraldi	doc_802069853745_item	2885751	et	4	main
elavad	doc_802069853745_item	2885756	et	4	main
lähiaja	doc_802069853745_item	2885761	et	3	main
age	doc_802069853745_item	2885767	et	4	main
areneda	doc_802069853745_item	2885771	et	3	main
oska	doc_802069853745_item	2885798	et	4	main
nad	doc_802069853745_item	2885799	et	3	main
ütlema	doc_802069853745_item	2885800	et	3	main
üks	doc_802069853745_item	2885805	et	3	main
päeva	doc_802069853745_item	2885808	et	4	main
punkti	doc_802069853746_item	2885821	et	4	main
maailmakuulsad	doc_802069853746_item	2885822	et	3	main
balletitantsijad	doc_802069853746_item	2885823	et	3	main
on	doc_802069853746_item	2885830	et	4	main
pärit	doc_802069853746_item	2885831	et	3	main
inglismaal	doc_802069853746_item	2885839	et	4	main
age	doc_802069853746_item	2885841	et	4	main
on	doc_802069853746_item	2885842	et	4	main
vana	doc_802069853746_item	2885853	et	4	main
1997a	doc_802069853746_item	2885855	et	4	main
tuhat	doc_802069853746_item	2885856	et	4	main
seitsmes	doc_802069853746_item	2885860	et	4	main
vabakutseline	doc_802069853746_item	2885863	et	4	main
teatrid	doc_802069853746_item	2885868	et	3	main
teatrid	doc_802069853746_item	2885870	et	3	main
armastama	doc_802069853746_item	2885872	et	3	main
alati	doc_802069853746_item	2885896	et	4	main
mõnda	doc_802069853746_item	2885921	et	4	main
age	doc_802069853746_item	2885926	et	4	main
ja	doc_802069853746_item	2885927	et	3	main
toomas	doc_802069853746_item	2885928	et	3	main
ainult	doc_802069853746_item	2885933	et	4	main
nemad	doc_802069853746_item	2885937	et	3	main
tantsimiseks	doc_802069853746_item	2885944	et	4	main
tantsijad	doc_802069853746_item	2885949	et	4	main
nende	doc_802069853746_item	2885951	et	4	main
lähiaja	doc_802069853746_item	2885952	et	3	main
esinemised	doc_802069853746_item	2885953	et	4	main
ja	doc_802069853746_item	2885963	et	3	main
tallinn	doc_802069853746_item	2885972	et	4	main
tallinnas	doc_802069853746_item	2885973	et	4	main
kui	doc_802069853746_item	2885979	et	3	main
ja	doc_802069853746_item	2885982	et	3	main
harjutus	doc_802069853747_item	2886001	et	4	main
avage	doc_802069853747_item	2886002	et	3	main
sulud	doc_802069853747_item	2886003	et	3	main
numbrid	doc_802069853747_item	2886004	et	3	main
kirjutage	doc_802069853747_item	2886005	et	3	main
sõnadega	doc_802069853747_item	2886006	et	3	main
abielupaar	doc_802069853747_item	2886015	et	4	main
pärit	doc_802069853747_item	2886022	et	3	main
eesti	doc_802069853747_item	2886023	et	4	main
inglismaal	doc_802069853747_item	2886030	et	4	main
age	doc_802069853747_item	2886032	et	4	main
30	doc_802069853747_item	2886034	et	2	main
kolmekümne	doc_802069853747_item	2886035	et	4	main
kolmekümne	doc_802069853747_item	2886041	et	4	main
alates	doc_802069853747_item	2886045	et	3	main
on	doc_802069853747_item	2886052	et	4	main
nad	doc_802069853747_item	2886053	et	3	main
vabakutseline	doc_802069853747_item	2886054	et	4	main
teatrid	doc_802069853747_item	2886059	et	3	main
teatreid	doc_802069853747_item	2886061	et	3	main
isegi	doc_802069853745_item	2885682	et	4	main
suhtuma	doc_802069853745_item	2885685	et	3	main
suhtusid	doc_802069853745_item	2885686	et	4	main
viimased	doc_802069853745_item	2885690	et	3	main
noored	doc_802069853745_item	2885693	et	3	main
ja	doc_802069853745_item	2885706	et	3	main
eriti	doc_802069853745_item	2885707	et	3	main
naine	doc_802069853745_item	2885719	et	3	main
tulevad	doc_802069853745_item	2885778	et	4	main
nad	doc_802069853745_item	2885779	et	3	main
esinema	doc_802069853745_item	2885780	et	3	main
lõuna-aafrikasse	doc_802069853745_item	2885787	et	4	main
ja	doc_802069853745_item	2885791	et	3	main
päev	doc_802069853745_item	2885806	et	3	main
numbrid	doc_802069853746_item	2885813	et	3	main
abielupaar	doc_802069853746_item	2885824	et	4	main
aga	doc_802069853746_item	2885834	et	3	main
elavad	doc_802069853746_item	2885835	et	4	main
inglismaa	doc_802069853746_item	2885837	et	4	main
london	doc_802069853746_item	2885840	et	4	main
on	doc_802069853746_item	2885848	et	4	main
32	doc_802069853746_item	2885849	et	2	main
üheksasajas	doc_802069853746_item	2885857	et	4	main
kumnes	doc_802069853746_item	2885859	et	4	main
vabakutselised	doc_802069853746_item	2885864	et	4	main
erinevad	doc_802069853746_item	2885867	et	4	main
erinevad	doc_802069853746_item	2885869	et	4	main
väga	doc_802069853746_item	2885875	et	3	main
isegi	doc_802069853746_item	2885877	et	4	main
kriitikud	doc_802069853746_item	2885879	et	3	main
suhtuma	doc_802069853746_item	2885880	et	3	main
suhtuda	doc_802069853746_item	2885881	et	3	main
nendesse	doc_802069853746_item	2885882	et	4	main
nii	doc_802069853746_item	2885897	et	3	main
agel	doc_802069853746_item	2885903	et	4	main
etendus	doc_802069853746_item	2885916	et	4	main
tantsimisest	doc_802069853746_item	2885923	et	4	main
eemal	doc_802069853746_item	2885924	et	3	main
otsustanud	doc_802069853746_item	2885930	et	4	main
tantsima	doc_802069853746_item	2885931	et	3	main
tantsi	doc_802069853746_item	2885932	et	4	main
pakkumisi	doc_802069853746_item	2885941	et	4	main
ka	doc_802069853746_item	2885942	et	3	main
suurele	doc_802069853746_item	2885946	et	4	main
edule	doc_802069853746_item	2885947	et	3	main
tagasihoidlik	doc_802069853746_item	2885950	et	3	main
areneda	doc_802069853746_item	2885962	et	3	main
tulevad	doc_802069853746_item	2885969	et	4	main
nad	doc_802069853746_item	2885970	et	3	main
sõidavad	doc_802069853746_item	2885976	et	3	main
öelda	doc_802069853746_item	2885992	et	4	main
nad	doc_802069853746_item	2885993	et	3	main
eelistavad	doc_802069853746_item	2885994	et	4	main
elada	doc_802069853746_item	2885995	et	3	main
üks	doc_802069853746_item	2885996	et	3	main
päev	doc_802069853746_item	2885997	et	3	main
päeva	doc_802069853746_item	2885999	et	4	main
kaupa	doc_802069853746_item	2886000	et	4	main
punkti	doc_802069853747_item	2886012	et	4	main
maailmakuulsad	doc_802069853747_item	2886013	et	3	main
balletitantsijad	doc_802069853747_item	2886014	et	3	main
aastat	doc_802069853746_item	2885852	et	3	main
alates	doc_802069853746_item	2885854	et	3	main
üheksa	doc_802069853746_item	2885858	et	4	main
on	doc_802069853746_item	2885861	et	4	main
ja	doc_802069853746_item	2885865	et	3	main
üldiselt	doc_802069853746_item	2885883	et	4	main
hästi	doc_802069853746_item	2885884	et	3	main
viimased	doc_802069853746_item	2885885	et	3	main
artiklid	doc_802069853746_item	2885886	et	3	main
räägivad	doc_802069853746_item	2885887	et	3	main
noored	doc_802069853746_item	2885888	et	3	main
noored	doc_802069853746_item	2885889	et	3	main
kõik	doc_802069853746_item	2885893	et	4	main
eriti	doc_802069853746_item	2885902	et	3	main
olnud	doc_802069853746_item	2885905	et	4	main
probleeme	doc_802069853746_item	2885906	et	3	main
tervis	doc_802069853746_item	2885907	et	3	main
terviseks	doc_802069853746_item	2885908	et	3	main
aega	doc_802069853746_item	2885922	et	4	main
on	doc_802069853746_item	2885929	et	4	main
teineteisega	doc_802069853746_item	2885934	et	3	main
on	doc_802069853746_item	2885939	et	4	main
tehtud	doc_802069853746_item	2885940	et	4	main
vaatamata	doc_802069853746_item	2885945	et	4	main
tahavad	doc_802069853746_item	2885961	et	3	main
veelgi	doc_802069853746_item	2885964	et	4	main
parem	doc_802069853746_item	2885965	et	4	main
esinema	doc_802069853746_item	2885971	et	3	main
seejärel	doc_802069853746_item	2885975	et	3	main
lõuna-aafrika	doc_802069853746_item	2885977	et	4	main
kaua	doc_802069853746_item	2885980	et	3	main
veel	doc_802069853746_item	2885984	et	4	main
iga	doc_802069853747_item	2886007	et	4	main
age	doc_802069853747_item	2886016	et	4	main
oks	doc_802069853747_item	2886017	et	3	main
ja	doc_802069853747_item	2886018	et	3	main
toomas	doc_802069853747_item	2886019	et	3	main
elavad	doc_802069853747_item	2886026	et	4	main
aastane	doc_802069853747_item	2886036	et	4	main
aastat	doc_802069853747_item	2886043	et	3	main
1997a	doc_802069853747_item	2886046	et	4	main
tuhande	doc_802069853747_item	2886047	et	3	main
üheksasaja	doc_802069853747_item	2886048	et	4	main
erinevad	doc_802069853747_item	2886058	et	4	main
karmid	doc_802069853747_item	2886069	et	4	main
kriitikud	doc_802069853747_item	2886070	et	3	main
suhtuma	doc_802069853747_item	2886071	et	3	main
suhtuvad	doc_802069853747_item	2886072	et	4	main
räägivad	doc_802069853747_item	2886078	et	3	main
ainult	doc_802069853747_item	2886081	et	4	main
kuid	doc_802069853747_item	2886083	et	4	main
nii	doc_802069853747_item	2886088	et	3	main
ja	doc_802069853747_item	2886121	et	3	main
toomas	doc_802069853747_item	2886122	et	3	main
ainult	doc_802069853747_item	2886127	et	4	main
neid	doc_802069853747_item	2886132	et	4	main
tehtud	doc_802069853747_item	2886134	et	4	main
lähiaja	doc_802069853747_item	2886147	et	3	main
esinemised	doc_802069853747_item	2886148	et	4	main
on	doc_802069853747_item	2886149	et	4	main
tahavad	doc_802069853747_item	2886156	et	3	main
areneda	doc_802069853747_item	2886157	et	3	main
ja	doc_802069853747_item	2886158	et	3	main
esinema	doc_802069853747_item	2886166	et	3	main
lõuna-aafrika	doc_802069853747_item	2886172	et	4	main
lõuna-aafrikasse	doc_802069853747_item	2886173	et	4	main
kui	doc_802069853747_item	2886174	et	3	main
kaua	doc_802069853747_item	2886175	et	3	main
oks	doc_802069853747_item	2886176	et	3	main
ja	doc_802069853747_item	2886177	et	3	main
tipus	doc_802069853747_item	2886180	et	3	main
ei	doc_802069853747_item	2886183	et	4	main
kaupa	doc_802069853747_item	2886195	et	4	main
harjutus	doc_802069853748_item	2886196	et	4	main
avage	doc_802069853748_item	2886197	et	3	main
sulud	doc_802069853748_item	2886198	et	3	main
numbrid	doc_802069853748_item	2886199	et	3	main
kirjutage	doc_802069853748_item	2886200	et	3	main
sõnadega	doc_802069853748_item	2886201	et	3	main
maailmakuulsad	doc_802069853748_item	2886208	et	3	main
age	doc_802069853748_item	2886211	et	4	main
inglismaal	doc_802069853746_item	2885871	et	4	main
armastav	doc_802069853746_item	2885873	et	4	main
ning	doc_802069853746_item	2885876	et	3	main
karmid	doc_802069853746_item	2885878	et	4	main
kuid	doc_802069853746_item	2885892	et	4	main
pole	doc_802069853746_item	2885894	et	3	main
järve	doc_802069853746_item	2885915	et	4	main
ja	doc_802069853746_item	2885918	et	3	main
on	doc_802069853746_item	2885954	et	4	main
täpselt	doc_802069853746_item	2885955	et	4	main
planeerima	doc_802069853746_item	2885956	et	3	main
planeerist	doc_802069853746_item	2885957	et	4	main
age	doc_802069853746_item	2885958	et	4	main
ja	doc_802069853746_item	2885959	et	3	main
toomas	doc_802069853746_item	2885960	et	3	main
elavad	doc_802069853746_item	2885948	et	4	main
parem	doc_802069853746_item	2885966	et	4	main
tantsida	doc_802069853746_item	2885967	et	3	main
märtsis	doc_802069853746_item	2885968	et	3	main
ja	doc_802069853746_item	2885974	et	3	main
lõuna-afrikas	doc_802069853746_item	2885978	et	4	main
edur	doc_802069853746_item	2885983	et	4	main
tipus	doc_802069853746_item	2885985	et	3	main
suudavad	doc_802069853746_item	2885986	et	3	main
püsida	doc_802069853746_item	2885987	et	3	main
ei	doc_802069853746_item	2885988	et	4	main
ühe	doc_802069853746_item	2885998	et	4	main
annab	doc_802069853747_item	2886010	et	3	main
ühe	doc_802069853747_item	2886011	et	4	main
edur	doc_802069853747_item	2886020	et	4	main
aga	doc_802069853747_item	2886025	et	3	main
inglismaa	doc_802069853747_item	2886028	et	4	main
london	doc_802069853747_item	2886029	et	4	main
toomas	doc_802069853747_item	2886038	et	3	main
32	doc_802069853747_item	2886040	et	2	main
kaks	doc_802069853747_item	2886042	et	3	main
vana	doc_802069853747_item	2886044	et	4	main
aastast	doc_802069853747_item	2886051	et	4	main
neid	doc_802069853747_item	2886065	et	4	main
väga	doc_802069853747_item	2886066	et	3	main
üldiselt	doc_802069853747_item	2886074	et	4	main
viimased	doc_802069853747_item	2886076	et	3	main
alati	doc_802069853747_item	2886087	et	4	main
on	doc_802069853747_item	2886095	et	4	main
tervisega	doc_802069853747_item	2886099	et	3	main
on	doc_802069853747_item	2886123	et	4	main
teineteisega	doc_802069853747_item	2886128	et	3	main
nemad	doc_802069853747_item	2886131	et	3	main
pakkumisi	doc_802069853747_item	2886135	et	4	main
ka	doc_802069853747_item	2886136	et	3	main
eraldi	doc_802069853747_item	2886137	et	4	main
elavad	doc_802069853747_item	2886142	et	4	main
tantsijad	doc_802069853747_item	2886143	et	4	main
tagasihoidlik	doc_802069853747_item	2886144	et	3	main
tagasihoidlikul	doc_802069853747_item	2886145	et	3	main
age	doc_802069853747_item	2886153	et	4	main
ja	doc_802069853747_item	2886154	et	3	main
toomas	doc_802069853747_item	2886155	et	3	main
tulevad	doc_802069853747_item	2886164	et	4	main
edur	doc_802069853747_item	2886178	et	4	main
suudavad	doc_802069853747_item	2886181	et	3	main
nad	doc_802069853747_item	2886185	et	3	main
öelda	doc_802069853747_item	2886187	et	4	main
eelistavad	doc_802069853747_item	2886189	et	4	main
päev	doc_802069853747_item	2886192	et	3	main
õige	doc_802069853748_item	2886203	et	4	main
vastus	doc_802069853748_item	2886204	et	3	main
annab	doc_802069853748_item	2886205	et	3	main
ühe	doc_802069853748_item	2886206	et	4	main
abielupaar	doc_802069853748_item	2886210	et	4	main
toomas	doc_802069853748_item	2886214	et	3	main
edur	doc_802069853748_item	2886215	et	4	main
on	doc_802069853748_item	2886216	et	4	main
pärit	doc_802069853748_item	2886217	et	3	main
age	doc_802069853748_item	2886227	et	4	main
1997a	doc_802069853748_item	2886242	et	4	main
tuhad	doc_802069853748_item	2886243	et	3	main
seitsmest	doc_802069853748_item	2886246	et	4	main
vabakutselised	doc_802069853748_item	2886251	et	4	main
kriitikud	doc_802069853748_item	2886266	et	3	main
nendesse	doc_802069853748_item	2886269	et	4	main
räägivad	doc_802069853748_item	2886274	et	3	main
sugugi	doc_802069853748_item	2886282	et	4	main
ainult	doc_802069853748_item	2886323	et	4	main
teineteisega	doc_802069853748_item	2886324	et	3	main
nemad	doc_802069853748_item	2886327	et	3	main
nendele	doc_802069853748_item	2886328	et	4	main
on	doc_802069853748_item	2886329	et	4	main
vaatamata	doc_802069853748_item	2886335	et	4	main
tagasihoidlik	doc_802069853748_item	2886340	et	3	main
tagasihoidlikult	doc_802069853748_item	2886341	et	4	main
nende	doc_802069853748_item	2886342	et	4	main
lähiaja	doc_802069853748_item	2886343	et	3	main
esinema	doc_802069853748_item	2886362	et	3	main
tallinn	doc_802069853748_item	2886363	et	4	main
tallinnasse	doc_802069853748_item	2886364	et	3	main
oks	doc_802069853746_item	2885981	et	3	main
oska	doc_802069853746_item	2885989	et	4	main
nad	doc_802069853746_item	2885990	et	3	main
ütlema	doc_802069853746_item	2885991	et	3	main
õige	doc_802069853747_item	2886008	et	4	main
vastus	doc_802069853747_item	2886009	et	3	main
on	doc_802069853747_item	2886021	et	4	main
eestis	doc_802069853747_item	2886024	et	3	main
praegu	doc_802069853747_item	2886027	et	3	main
londonis	doc_802069853747_item	2886031	et	4	main
on	doc_802069853747_item	2886033	et	4	main
üheksakümne	doc_802069853747_item	2886049	et	4	main
vabakutselised	doc_802069853747_item	2886055	et	4	main
ja	doc_802069853747_item	2886056	et	3	main
ning	doc_802069853747_item	2886067	et	3	main
isegi	doc_802069853747_item	2886068	et	4	main
hästi	doc_802069853747_item	2886075	et	3	main
artiklid	doc_802069853747_item	2886077	et	3	main
kergelt	doc_802069853747_item	2886089	et	4	main
läinud	doc_802069853747_item	2886090	et	4	main
mõlemal	doc_802069853747_item	2886091	et	3	main
olnud	doc_802069853747_item	2886096	et	4	main
murdma	doc_802069853747_item	2886102	et	3	main
murdes	doc_802069853747_item	2886103	et	4	main
noor	doc_802069853747_item	2886104	et	3	main
naine	doc_802069853747_item	2886105	et	3	main
luikede	doc_802069853747_item	2886106	et	3	main
järve	doc_802069853747_item	2886107	et	4	main
etendus	doc_802069853747_item	2886108	et	4	main
etenduses	doc_802069853747_item	2886109	et	4	main
jalaluu	doc_802069853747_item	2886110	et	4	main
ja	doc_802069853747_item	2886111	et	3	main
pidama	doc_802069853747_item	2886112	et	4	main
pidada	doc_802069853747_item	2886113	et	4	main
mõnda	doc_802069853747_item	2886114	et	4	main
aega	doc_802069853747_item	2886115	et	4	main
tantsimisest	doc_802069853747_item	2886116	et	4	main
eemal	doc_802069853747_item	2886117	et	3	main
olema	doc_802069853747_item	2886118	et	4	main
olla	doc_802069853747_item	2886119	et	3	main
age	doc_802069853747_item	2886120	et	4	main
tansi	doc_802069853747_item	2886126	et	4	main
paaris	doc_802069853747_item	2886129	et	4	main
kuigi	doc_802069853747_item	2886130	et	3	main
suurele	doc_802069853747_item	2886140	et	4	main
edule	doc_802069853747_item	2886141	et	3	main
nende	doc_802069853747_item	2886146	et	4	main
planeeritud	doc_802069853747_item	2886152	et	4	main
paremini	doc_802069853747_item	2886161	et	4	main
tantsida	doc_802069853747_item	2886162	et	3	main
märtsis	doc_802069853747_item	2886163	et	3	main
ja	doc_802069853747_item	2886169	et	3	main
seejärel	doc_802069853747_item	2886170	et	3	main
püsida	doc_802069853747_item	2886182	et	3	main
ütlema	doc_802069853747_item	2886186	et	3	main
üks	doc_802069853747_item	2886191	et	3	main
balletitantsijad	doc_802069853748_item	2886209	et	3	main
oks	doc_802069853748_item	2886212	et	3	main
elavad	doc_802069853748_item	2886221	et	4	main
london	doc_802069853748_item	2886224	et	4	main
on	doc_802069853748_item	2886234	et	4	main
kolm	doc_802069853748_item	2886236	et	3	main
kaks	doc_802069853748_item	2886238	et	3	main
ja	doc_802069853747_item	2886037	et	3	main
on	doc_802069853747_item	2886039	et	4	main
seitsmest	doc_802069853747_item	2886050	et	4	main
esinevad	doc_802069853747_item	2886057	et	4	main
erinevaid	doc_802069853747_item	2886060	et	4	main
inglismaal	doc_802069853747_item	2886062	et	4	main
armastama	doc_802069853747_item	2886063	et	3	main
armastavad	doc_802069853747_item	2886064	et	4	main
noored	doc_802069853747_item	2886079	et	3	main
kõik	doc_802069853747_item	2886084	et	4	main
ja	doc_802069853747_item	2886092	et	3	main
eriti	doc_802069853747_item	2886093	et	3	main
probleeme	doc_802069853747_item	2886097	et	3	main
tervis	doc_802069853747_item	2886098	et	3	main
aastal	doc_802069853747_item	2886101	et	3	main
otsustanud	doc_802069853747_item	2886124	et	4	main
tantsima	doc_802069853747_item	2886125	et	3	main
nendesse	doc_802069853747_item	2886073	et	4	main
noorest	doc_802069853747_item	2886080	et	3	main
ülivõrdes	doc_802069853747_item	2886082	et	3	main
pole	doc_802069853747_item	2886085	et	3	main
sugugi	doc_802069853747_item	2886086	et	4	main
agel	doc_802069853747_item	2886094	et	4	main
1990	doc_802069853747_item	2886100	et	2	main
on	doc_802069853747_item	2886133	et	4	main
tantsimiseks	doc_802069853747_item	2886138	et	4	main
vaatamata	doc_802069853747_item	2886139	et	4	main
täpselt	doc_802069853747_item	2886150	et	4	main
planeerima	doc_802069853747_item	2886151	et	3	main
veelgi	doc_802069853747_item	2886159	et	4	main
parem	doc_802069853747_item	2886160	et	4	main
nad	doc_802069853747_item	2886165	et	3	main
tallinn	doc_802069853747_item	2886167	et	4	main
tallinnase	doc_802069853747_item	2886168	et	3	main
sõidavad	doc_802069853747_item	2886171	et	3	main
veel	doc_802069853747_item	2886179	et	4	main
oska	doc_802069853747_item	2886184	et	4	main
nad	doc_802069853747_item	2886188	et	3	main
ühe	doc_802069853747_item	2886193	et	4	main
iga	doc_802069853748_item	2886202	et	4	main
eesti	doc_802069853748_item	2886218	et	4	main
eestist	doc_802069853748_item	2886219	et	3	main
aga	doc_802069853748_item	2886220	et	3	main
on	doc_802069853748_item	2886228	et	4	main
aastane	doc_802069853748_item	2886231	et	4	main
32	doc_802069853748_item	2886235	et	2	main
nad	doc_802069853748_item	2886249	et	3	main
erinevad	doc_802069853748_item	2886254	et	4	main
erinevades	doc_802069853748_item	2886256	et	4	main
inglismaal	doc_802069853748_item	2886258	et	4	main
karmid	doc_802069853748_item	2886265	et	4	main
suhtuvad	doc_802069853748_item	2886268	et	4	main
viimased	doc_802069853748_item	2886272	et	3	main
ainult	doc_802069853748_item	2886277	et	4	main
kergelt	doc_802069853748_item	2886285	et	4	main
elada	doc_802069853747_item	2886190	et	3	main
päeva	doc_802069853747_item	2886194	et	4	main
punkti	doc_802069853748_item	2886207	et	4	main
praegu	doc_802069853748_item	2886222	et	3	main
kolmekümne	doc_802069853748_item	2886230	et	4	main
toomas	doc_802069853748_item	2886233	et	3	main
kümmend	doc_802069853748_item	2886237	et	4	main
üheksakümmend	doc_802069853748_item	2886245	et	4	main
vabakutseline	doc_802069853748_item	2886250	et	4	main
ja	doc_802069853748_item	2886252	et	3	main
üldiselt	doc_802069853748_item	2886270	et	4	main
kõik	doc_802069853748_item	2886280	et	4	main
pole	doc_802069853748_item	2886281	et	3	main
agel	doc_802069853748_item	2886290	et	4	main
on	doc_802069853748_item	2886291	et	4	main
tervisega	doc_802069853748_item	2886295	et	3	main
1990	doc_802069853748_item	2886296	et	2	main
aastal	doc_802069853748_item	2886297	et	3	main
murdma	doc_802069853748_item	2886298	et	3	main
murdis	doc_802069853748_item	2886299	et	3	main
noor	doc_802069853748_item	2886300	et	3	main
naine	doc_802069853748_item	2886301	et	3	main
luikede	doc_802069853748_item	2886302	et	3	main
järve	doc_802069853748_item	2886303	et	4	main
etendus	doc_802069853748_item	2886304	et	4	main
etendusel	doc_802069853748_item	2886305	et	4	main
jalaluu	doc_802069853748_item	2886306	et	4	main
ja	doc_802069853748_item	2886307	et	3	main
pidama	doc_802069853748_item	2886308	et	4	main
pidas	doc_802069853748_item	2886309	et	3	main
mõnda	doc_802069853748_item	2886310	et	4	main
aega	doc_802069853748_item	2886311	et	4	main
tantsimisest	doc_802069853748_item	2886312	et	4	main
eemal	doc_802069853748_item	2886313	et	3	main
olema	doc_802069853748_item	2886314	et	4	main
olnud	doc_802069853748_item	2886315	et	4	main
age	doc_802069853748_item	2886316	et	4	main
ja	doc_802069853748_item	2886317	et	3	main
toomas	doc_802069853748_item	2886318	et	3	main
on	doc_802069853748_item	2886319	et	4	main
otsustanud	doc_802069853748_item	2886320	et	4	main
pakkumisi	doc_802069853748_item	2886331	et	4	main
ka	doc_802069853748_item	2886332	et	3	main
täpselt	doc_802069853748_item	2886346	et	4	main
planeerima	doc_802069853748_item	2886347	et	3	main
planeeritud	doc_802069853748_item	2886348	et	4	main
veelgi	doc_802069853748_item	2886355	et	4	main
lõuna-aafrikast	doc_802069853748_item	2886369	et	4	main
kui	doc_802069853748_item	2886370	et	3	main
numbrid	doc_802069853749_item	2886395	et	3	main
abielupaar	doc_802069853749_item	2886406	et	4	main
london	doc_802069853749_item	2886420	et	4	main
ja	doc_802069853748_item	2886213	et	3	main
inglismaa	doc_802069853748_item	2886223	et	4	main
inglismaal	doc_802069853748_item	2886225	et	4	main
londonis	doc_802069853748_item	2886226	et	4	main
30	doc_802069853748_item	2886229	et	2	main
ja	doc_802069853748_item	2886232	et	3	main
üheksasada	doc_802069853748_item	2886244	et	4	main
on	doc_802069853748_item	2886248	et	4	main
teatrid	doc_802069853748_item	2886255	et	3	main
teatrides	doc_802069853748_item	2886257	et	4	main
armastama	doc_802069853748_item	2886259	et	3	main
armastatakse	doc_802069853748_item	2886260	et	3	main
neid	doc_802069853748_item	2886261	et	4	main
väga	doc_802069853748_item	2886262	et	3	main
ning	doc_802069853748_item	2886263	et	3	main
hästi	doc_802069853748_item	2886271	et	3	main
nooredes	doc_802069853748_item	2886276	et	3	main
ülivõrdes	doc_802069853748_item	2886278	et	3	main
läinud	doc_802069853748_item	2886286	et	4	main
mõlemal	doc_802069853748_item	2886287	et	3	main
ja	doc_802069853748_item	2886288	et	3	main
eriti	doc_802069853748_item	2886289	et	3	main
tantsima	doc_802069853748_item	2886321	et	3	main
paaris	doc_802069853748_item	2886325	et	4	main
kuigi	doc_802069853748_item	2886326	et	3	main
tantsimiseks	doc_802069853748_item	2886334	et	4	main
tantsijad	doc_802069853748_item	2886339	et	4	main
age	doc_802069853748_item	2886349	et	4	main
ja	doc_802069853748_item	2886350	et	3	main
toomas	doc_802069853748_item	2886351	et	3	main
tahavad	doc_802069853748_item	2886352	et	3	main
lõuna-aafrika	doc_802069853748_item	2886368	et	4	main
punkti	doc_802069853749_item	2886403	et	4	main
maailmakuulsad	doc_802069853749_item	2886404	et	3	main
balletitantsijad	doc_802069853749_item	2886405	et	3	main
edur	doc_802069853749_item	2886411	et	4	main
pärit	doc_802069853749_item	2886413	et	3	main
age	doc_802069853749_item	2886423	et	4	main
kolmekümne	doc_802069853749_item	2886432	et	4	main
1997a	doc_802069853749_item	2886437	et	4	main
üheksasada	doc_802069853749_item	2886439	et	4	main
vabakutseline	doc_802069853749_item	2886444	et	4	main
ja	doc_802069853749_item	2886446	et	3	main
teatrides	doc_802069853749_item	2886451	et	4	main
inglismaal	doc_802069853749_item	2886452	et	4	main
nordest	doc_802069853749_item	2886470	et	3	main
ainult	doc_802069853749_item	2886471	et	4	main
ülivõrdes	doc_802069853749_item	2886472	et	3	main
kuid	doc_802069853749_item	2886473	et	4	main
kõik	doc_802069853749_item	2886474	et	4	main
pole	doc_802069853749_item	2886475	et	3	main
sugugi	doc_802069853749_item	2886476	et	4	main
1990	doc_802069853749_item	2886490	et	2	main
jalaluu	doc_802069853749_item	2886500	et	4	main
ja	doc_802069853749_item	2886501	et	3	main
nemad	doc_802069853749_item	2886521	et	3	main
elavad	doc_802069853749_item	2886532	et	4	main
on	doc_802069853749_item	2886539	et	4	main
parem	doc_802069853749_item	2886550	et	4	main
tallinnas	doc_802069853749_item	2886558	et	4	main
ja	doc_802069853749_item	2886559	et	3	main
sõidavad	doc_802069853749_item	2886561	et	3	main
ja	doc_802069853749_item	2886567	et	3	main
nad	doc_802069853749_item	2886575	et	3	main
ühes	doc_802069853749_item	2886583	et	4	main
kaupa	doc_802069853749_item	2886585	et	4	main
punkti	doc_802069853750_item	2886597	et	4	main
maailmakuulsad	doc_802069853750_item	2886598	et	3	main
balletitantsijad	doc_802069853750_item	2886599	et	3	main
eesti	doc_802069853750_item	2886608	et	4	main
eestist	doc_802069853750_item	2886609	et	3	main
aga	doc_802069853750_item	2886610	et	3	main
on	doc_802069853750_item	2886618	et	4	main
30	doc_802069853750_item	2886619	et	2	main
32	doc_802069853750_item	2886625	et	2	main
1997a	doc_802069853750_item	2886631	et	4	main
aastal	doc_802069853750_item	2886632	et	3	main
tuhat	doc_802069853750_item	2886633	et	4	main
vabakutseline	doc_802069853750_item	2886639	et	4	main
vabakutselised	doc_802069853750_item	2886640	et	4	main
ja	doc_802069853750_item	2886641	et	3	main
aastat	doc_802069853748_item	2886239	et	3	main
vana	doc_802069853748_item	2886240	et	4	main
alates	doc_802069853748_item	2886241	et	3	main
aastast	doc_802069853748_item	2886247	et	4	main
esinevad	doc_802069853748_item	2886253	et	4	main
isegi	doc_802069853748_item	2886264	et	4	main
suhtuma	doc_802069853748_item	2886267	et	3	main
artiklid	doc_802069853748_item	2886273	et	3	main
noored	doc_802069853748_item	2886275	et	3	main
kuid	doc_802069853748_item	2886279	et	4	main
alati	doc_802069853748_item	2886283	et	4	main
nii	doc_802069853748_item	2886284	et	3	main
olnud	doc_802069853748_item	2886292	et	4	main
probleeme	doc_802069853748_item	2886293	et	3	main
tervis	doc_802069853748_item	2886294	et	3	main
tantsima	doc_802069853748_item	2886322	et	3	main
eraldi	doc_802069853748_item	2886333	et	4	main
elavad	doc_802069853748_item	2886338	et	4	main
on	doc_802069853748_item	2886345	et	4	main
ja	doc_802069853748_item	2886354	et	3	main
parem	doc_802069853748_item	2886356	et	4	main
tantsida	doc_802069853748_item	2886358	et	3	main
märtsis	doc_802069853748_item	2886359	et	3	main
sõnadega	doc_802069853749_item	2886397	et	3	main
õige	doc_802069853749_item	2886399	et	4	main
vastus	doc_802069853749_item	2886400	et	3	main
annab	doc_802069853749_item	2886401	et	3	main
ühe	doc_802069853749_item	2886402	et	4	main
oks	doc_802069853749_item	2886408	et	3	main
ja	doc_802069853749_item	2886409	et	3	main
elavad	doc_802069853749_item	2886417	et	4	main
praegu	doc_802069853749_item	2886418	et	3	main
inglismaa	doc_802069853749_item	2886419	et	4	main
on	doc_802069853749_item	2886424	et	4	main
kaks	doc_802069853749_item	2886433	et	3	main
alates	doc_802069853749_item	2886436	et	3	main
tühat	doc_802069853749_item	2886438	et	4	main
üheksakümend	doc_802069853749_item	2886440	et	4	main
seitsmendal	doc_802069853749_item	2886441	et	3	main
väga	doc_802069853749_item	2886456	et	3	main
üldiselt	doc_802069853749_item	2886464	et	4	main
hästi	doc_802069853749_item	2886465	et	3	main
viimased	doc_802069853749_item	2886466	et	3	main
artiklid	doc_802069853749_item	2886467	et	3	main
räägivad	doc_802069853749_item	2886468	et	3	main
nii	doc_802069853749_item	2886478	et	3	main
tervis	doc_802069853749_item	2886488	et	3	main
luikede	doc_802069853749_item	2886496	et	3	main
etendus	doc_802069853749_item	2886498	et	4	main
etenduse	doc_802069853749_item	2886499	et	4	main
tehtud	doc_802069853748_item	2886330	et	4	main
suurele	doc_802069853748_item	2886336	et	4	main
edule	doc_802069853748_item	2886337	et	3	main
esinemised	doc_802069853748_item	2886344	et	4	main
areneda	doc_802069853748_item	2886353	et	3	main
parem	doc_802069853748_item	2886357	et	4	main
tulevad	doc_802069853748_item	2886360	et	4	main
nad	doc_802069853748_item	2886361	et	3	main
kaua	doc_802069853748_item	2886371	et	3	main
oks	doc_802069853748_item	2886372	et	3	main
ja	doc_802069853748_item	2886373	et	3	main
edur	doc_802069853748_item	2886374	et	4	main
veel	doc_802069853748_item	2886375	et	4	main
tipus	doc_802069853748_item	2886376	et	3	main
suudavad	doc_802069853748_item	2886377	et	3	main
püsida	doc_802069853748_item	2886378	et	3	main
ei	doc_802069853748_item	2886379	et	4	main
oska	doc_802069853748_item	2886380	et	4	main
nad	doc_802069853748_item	2886381	et	3	main
ütlema	doc_802069853748_item	2886382	et	3	main
ütlema	doc_802069853748_item	2886383	et	3	main
nad	doc_802069853748_item	2886384	et	3	main
eelistavad	doc_802069853748_item	2886385	et	4	main
elada	doc_802069853748_item	2886386	et	3	main
üks	doc_802069853748_item	2886387	et	3	main
päev	doc_802069853748_item	2886388	et	3	main
üks	doc_802069853748_item	2886389	et	3	main
päev	doc_802069853748_item	2886390	et	3	main
kaupa	doc_802069853748_item	2886391	et	4	main
harjutus	doc_802069853749_item	2886392	et	4	main
avage	doc_802069853749_item	2886393	et	3	main
sulud	doc_802069853749_item	2886394	et	3	main
ja	doc_802069853748_item	2886365	et	3	main
seejärel	doc_802069853748_item	2886366	et	3	main
sõidavad	doc_802069853748_item	2886367	et	3	main
age	doc_802069853749_item	2886407	et	4	main
on	doc_802069853749_item	2886412	et	4	main
eesti	doc_802069853749_item	2886414	et	4	main
eestist	doc_802069853749_item	2886415	et	3	main
aga	doc_802069853749_item	2886416	et	3	main
30	doc_802069853749_item	2886425	et	2	main
aastane	doc_802069853749_item	2886427	et	4	main
ja	doc_802069853749_item	2886428	et	3	main
toomas	doc_802069853749_item	2886429	et	3	main
on	doc_802069853749_item	2886430	et	4	main
aastat	doc_802069853749_item	2886434	et	3	main
on	doc_802069853749_item	2886442	et	4	main
erinevad	doc_802069853749_item	2886448	et	4	main
teatrid	doc_802069853749_item	2886449	et	3	main
erinedes	doc_802069853749_item	2886450	et	3	main
armastama	doc_802069853749_item	2886453	et	3	main
kriitikud	doc_802069853749_item	2886460	et	3	main
noored	doc_802069853749_item	2886469	et	3	main
alati	doc_802069853749_item	2886477	et	4	main
olnud	doc_802069853749_item	2886486	et	4	main
probleeme	doc_802069853749_item	2886487	et	3	main
murdma	doc_802069853749_item	2886492	et	3	main
noor	doc_802069853749_item	2886494	et	3	main
pidama	doc_802069853749_item	2886502	et	4	main
pidides	doc_802069853749_item	2886503	et	4	main
ned	doc_802069853749_item	2886522	et	4	main
on	doc_802069853749_item	2886523	et	4	main
tantsijad	doc_802069853749_item	2886533	et	4	main
tagasihoidlik	doc_802069853749_item	2886534	et	3	main
täpselt	doc_802069853749_item	2886540	et	4	main
paremini	doc_802069853749_item	2886551	et	4	main
tallinn	doc_802069853749_item	2886557	et	4	main
üks	doc_802069853749_item	2886581	et	3	main
päev	doc_802069853749_item	2886582	et	3	main
päevas	doc_802069853749_item	2886584	et	3	main
toomas	doc_802069853750_item	2886604	et	3	main
london	doc_802069853750_item	2886614	et	4	main
inglismaal	doc_802069853750_item	2886615	et	4	main
kolmkümend	doc_802069853750_item	2886626	et	4	main
kaks	doc_802069853750_item	2886627	et	3	main
vana	doc_802069853750_item	2886629	et	4	main
inglismaal	doc_802069853750_item	2886647	et	4	main
neid	doc_802069853750_item	2886650	et	4	main
viimased	doc_802069853750_item	2886661	et	3	main
alati	doc_802069853750_item	2886672	et	4	main
on	doc_802069853750_item	2886680	et	4	main
tervis	doc_802069853750_item	2886683	et	3	main
pakkumisi	doc_802069853750_item	2886720	et	4	main
kirjutage	doc_802069853749_item	2886396	et	3	main
iga	doc_802069853749_item	2886398	et	4	main
toomas	doc_802069853749_item	2886410	et	3	main
inglismaal	doc_802069853749_item	2886421	et	4	main
vana	doc_802069853749_item	2886435	et	4	main
nad	doc_802069853749_item	2886443	et	3	main
neid	doc_802069853749_item	2886455	et	4	main
isegi	doc_802069853749_item	2886458	et	4	main
suhtuma	doc_802069853749_item	2886461	et	3	main
kergelt	doc_802069853749_item	2886479	et	4	main
läinud	doc_802069853749_item	2886480	et	4	main
mõlemal	doc_802069853749_item	2886481	et	3	main
ja	doc_802069853749_item	2886482	et	3	main
eriti	doc_802069853749_item	2886483	et	3	main
tervisega	doc_802069853749_item	2886489	et	3	main
murduda	doc_802069853749_item	2886493	et	3	main
naine	doc_802069853749_item	2886495	et	3	main
järve	doc_802069853749_item	2886497	et	4	main
mõnda	doc_802069853749_item	2886504	et	4	main
pakkumisi	doc_802069853749_item	2886525	et	4	main
suurele	doc_802069853749_item	2886530	et	4	main
edule	doc_802069853749_item	2886531	et	3	main
esinemised	doc_802069853749_item	2886538	et	4	main
toomas	doc_802069853749_item	2886545	et	3	main
seejärel	doc_802069853749_item	2886560	et	3	main
lõuna-afrikas	doc_802069853749_item	2886563	et	4	main
kui	doc_802069853749_item	2886564	et	3	main
kaua	doc_802069853749_item	2886565	et	3	main
oks	doc_802069853749_item	2886566	et	3	main
oska	doc_802069853749_item	2886574	et	4	main
nad	doc_802069853749_item	2886578	et	3	main
abielupaar	doc_802069853750_item	2886600	et	4	main
elavad	doc_802069853750_item	2886611	et	4	main
kolmekümne	doc_802069853750_item	2886620	et	4	main
üheksasada	doc_802069853750_item	2886634	et	4	main
teatrid	doc_802069853750_item	2886644	et	3	main
väga	doc_802069853750_item	2886651	et	3	main
üldiselt	doc_802069853750_item	2886659	et	4	main
noored	doc_802069853750_item	2886664	et	3	main
tantsima	doc_802069853750_item	2886711	et	3	main
paaris	doc_802069853750_item	2886714	et	4	main
kuigi	doc_802069853750_item	2886715	et	3	main
nemad	doc_802069853750_item	2886716	et	3	main
tantsimiseks	doc_802069853750_item	2886723	et	4	main
suurele	doc_802069853750_item	2886725	et	4	main
edule	doc_802069853750_item	2886726	et	3	main
esinemised	doc_802069853750_item	2886733	et	4	main
ja	doc_802069853750_item	2886739	et	3	main
ja	doc_802069853750_item	2886743	et	3	main
parem	doc_802069853750_item	2886745	et	4	main
märtsis	doc_802069853750_item	2886748	et	3	main
kaua	doc_802069853750_item	2886760	et	3	main
edur	doc_802069853750_item	2886763	et	4	main
tipus	doc_802069853750_item	2886765	et	3	main
ei	doc_802069853750_item	2886768	et	4	main
oska	doc_802069853750_item	2886769	et	4	main
nad	doc_802069853750_item	2886770	et	3	main
ütlema	doc_802069853750_item	2886771	et	3	main
päev	doc_802069853750_item	2886777	et	3	main
kaupa	doc_802069853750_item	2886780	et	4	main
avage	doc_802069853751_item	2886782	et	3	main
sulud	doc_802069853751_item	2886783	et	3	main
sõnadega	doc_802069853751_item	2886786	et	3	main
vastus	doc_802069853751_item	2886789	et	3	main
ühe	doc_802069853751_item	2886791	et	4	main
balletitantsijad	doc_802069853751_item	2886794	et	3	main
toomas	doc_802069853751_item	2886799	et	3	main
edur	doc_802069853751_item	2886800	et	4	main
pärit	doc_802069853751_item	2886802	et	3	main
eesti	doc_802069853751_item	2886803	et	4	main
eestis	doc_802069853751_item	2886804	et	3	main
aga	doc_802069853751_item	2886805	et	3	main
kolmekümne	doc_802069853751_item	2886815	et	4	main
32	doc_802069853751_item	2886820	et	2	main
vana	doc_802069853751_item	2886824	et	4	main
üheksasaja	doc_802069853751_item	2886828	et	4	main
üheksakümmend	doc_802069853751_item	2886829	et	4	main
nad	doc_802069853751_item	2886832	et	3	main
vabakutseline	doc_802069853751_item	2886833	et	4	main
ja	doc_802069853751_item	2886835	et	3	main
neid	doc_802069853751_item	2886844	et	4	main
londonis	doc_802069853749_item	2886422	et	4	main
kolmekümnendane	doc_802069853749_item	2886426	et	4	main
32	doc_802069853749_item	2886431	et	2	main
vabakutselised	doc_802069853749_item	2886445	et	4	main
esinevad	doc_802069853749_item	2886447	et	4	main
armastas	doc_802069853749_item	2886454	et	3	main
ning	doc_802069853749_item	2886457	et	3	main
karmid	doc_802069853749_item	2886459	et	4	main
suhtlesid	doc_802069853749_item	2886462	et	4	main
nendesse	doc_802069853749_item	2886463	et	4	main
agel	doc_802069853749_item	2886484	et	4	main
on	doc_802069853749_item	2886485	et	4	main
aastal	doc_802069853749_item	2886491	et	3	main
aega	doc_802069853749_item	2886505	et	4	main
tantsimisest	doc_802069853749_item	2886506	et	4	main
eemal	doc_802069853749_item	2886507	et	3	main
olema	doc_802069853749_item	2886508	et	4	main
olla	doc_802069853749_item	2886509	et	3	main
age	doc_802069853749_item	2886510	et	4	main
ja	doc_802069853749_item	2886511	et	3	main
toomas	doc_802069853749_item	2886512	et	3	main
on	doc_802069853749_item	2886513	et	4	main
otsustanud	doc_802069853749_item	2886514	et	4	main
tantsima	doc_802069853749_item	2886515	et	3	main
tansides	doc_802069853749_item	2886516	et	4	main
ainult	doc_802069853749_item	2886517	et	4	main
teineteisega	doc_802069853749_item	2886518	et	3	main
paaris	doc_802069853749_item	2886519	et	4	main
kuigi	doc_802069853749_item	2886520	et	3	main
ka	doc_802069853749_item	2886526	et	3	main
planeerima	doc_802069853749_item	2886541	et	3	main
planerida	doc_802069853749_item	2886542	et	4	main
age	doc_802069853749_item	2886543	et	4	main
ja	doc_802069853749_item	2886544	et	3	main
tahavad	doc_802069853749_item	2886546	et	3	main
areneda	doc_802069853749_item	2886547	et	3	main
ja	doc_802069853749_item	2886548	et	3	main
veelgi	doc_802069853749_item	2886549	et	4	main
ei	doc_802069853749_item	2886573	et	4	main
harjutus	doc_802069853750_item	2886586	et	4	main
avage	doc_802069853750_item	2886587	et	3	main
sulud	doc_802069853750_item	2886588	et	3	main
numbrid	doc_802069853750_item	2886589	et	3	main
kirjutage	doc_802069853750_item	2886590	et	3	main
sõnadega	doc_802069853750_item	2886591	et	3	main
age	doc_802069853750_item	2886601	et	4	main
oks	doc_802069853750_item	2886602	et	3	main
edur	doc_802069853750_item	2886605	et	4	main
on	doc_802069853750_item	2886606	et	4	main
pärit	doc_802069853750_item	2886607	et	3	main
inglismaa	doc_802069853750_item	2886613	et	4	main
londonis	doc_802069853750_item	2886616	et	4	main
age	doc_802069853750_item	2886617	et	4	main
aastane	doc_802069853750_item	2886621	et	4	main
toomas	doc_802069853750_item	2886623	et	3	main
ühiksakümend	doc_802069853750_item	2886635	et	4	main
seitse	doc_802069853750_item	2886636	et	3	main
armastama	doc_802069853750_item	2886648	et	3	main
artiklid	doc_802069853750_item	2886662	et	3	main
noorest	doc_802069853750_item	2886665	et	3	main
nii	doc_802069853750_item	2886673	et	3	main
kergelt	doc_802069853750_item	2886674	et	4	main
eriti	doc_802069853750_item	2886678	et	3	main
probleeme	doc_802069853750_item	2886682	et	3	main
tervisega	doc_802069853750_item	2886684	et	3	main
tehtud	doc_802069853749_item	2886524	et	4	main
eraldi	doc_802069853749_item	2886527	et	4	main
tantsimiseks	doc_802069853749_item	2886528	et	4	main
vaatamata	doc_802069853749_item	2886529	et	4	main
tagasihoidlikut	doc_802069853749_item	2886535	et	4	main
nende	doc_802069853749_item	2886536	et	4	main
lähiaja	doc_802069853749_item	2886537	et	3	main
tantsida	doc_802069853749_item	2886552	et	3	main
märtsis	doc_802069853749_item	2886553	et	3	main
tulevad	doc_802069853749_item	2886554	et	4	main
nad	doc_802069853749_item	2886555	et	3	main
esinema	doc_802069853749_item	2886556	et	3	main
lõuna-aafrika	doc_802069853749_item	2886562	et	4	main
edur	doc_802069853749_item	2886568	et	4	main
veel	doc_802069853749_item	2886569	et	4	main
tipus	doc_802069853749_item	2886570	et	3	main
suudavad	doc_802069853749_item	2886571	et	3	main
püsida	doc_802069853749_item	2886572	et	3	main
ütlema	doc_802069853749_item	2886576	et	3	main
öelda	doc_802069853749_item	2886577	et	4	main
eelistavad	doc_802069853749_item	2886579	et	4	main
elada	doc_802069853749_item	2886580	et	3	main
iga	doc_802069853750_item	2886592	et	4	main
õige	doc_802069853750_item	2886593	et	4	main
vastus	doc_802069853750_item	2886594	et	3	main
annab	doc_802069853750_item	2886595	et	3	main
ühe	doc_802069853750_item	2886596	et	4	main
ja	doc_802069853750_item	2886603	et	3	main
praegu	doc_802069853750_item	2886612	et	3	main
ja	doc_802069853750_item	2886622	et	3	main
on	doc_802069853750_item	2886624	et	4	main
aastat	doc_802069853750_item	2886628	et	3	main
alates	doc_802069853750_item	2886630	et	3	main
on	doc_802069853750_item	2886637	et	4	main
nad	doc_802069853750_item	2886638	et	3	main
esinevad	doc_802069853750_item	2886642	et	4	main
erinevaid	doc_802069853750_item	2886645	et	4	main
teatri	doc_802069853750_item	2886646	et	3	main
ning	doc_802069853750_item	2886652	et	3	main
isegi	doc_802069853750_item	2886653	et	4	main
kriitikud	doc_802069853750_item	2886655	et	3	main
suhtuvad	doc_802069853750_item	2886657	et	4	main
nendesse	doc_802069853750_item	2886658	et	4	main
räägivad	doc_802069853750_item	2886663	et	3	main
ülivõrdes	doc_802069853750_item	2886667	et	3	main
kuid	doc_802069853750_item	2886668	et	4	main
pole	doc_802069853750_item	2886670	et	3	main
sugugi	doc_802069853750_item	2886671	et	4	main
ja	doc_802069853750_item	2886677	et	3	main
olnud	doc_802069853750_item	2886681	et	4	main
1990	doc_802069853750_item	2886685	et	2	main
aastal	doc_802069853750_item	2886686	et	3	main
murdma	doc_802069853750_item	2886687	et	3	main
murdis	doc_802069853750_item	2886688	et	3	main
noor	doc_802069853750_item	2886689	et	3	main
naine	doc_802069853750_item	2886690	et	3	main
luikede	doc_802069853750_item	2886691	et	3	main
järve	doc_802069853750_item	2886692	et	4	main
etendus	doc_802069853750_item	2886693	et	4	main
jalaluu	doc_802069853750_item	2886695	et	4	main
ja	doc_802069853750_item	2886696	et	3	main
etendust	doc_802069853750_item	2886694	et	4	main
pidama	doc_802069853750_item	2886697	et	4	main
pidasid	doc_802069853750_item	2886698	et	4	main
mõnda	doc_802069853750_item	2886699	et	4	main
aega	doc_802069853750_item	2886700	et	4	main
tantsimisest	doc_802069853750_item	2886701	et	4	main
eemal	doc_802069853750_item	2886702	et	3	main
olema	doc_802069853750_item	2886703	et	4	main
olevad	doc_802069853750_item	2886704	et	4	main
age	doc_802069853750_item	2886705	et	4	main
ja	doc_802069853750_item	2886706	et	3	main
toomas	doc_802069853750_item	2886707	et	3	main
on	doc_802069853750_item	2886708	et	4	main
otsustanud	doc_802069853750_item	2886709	et	4	main
erinevad	doc_802069853750_item	2886643	et	4	main
armastavad	doc_802069853750_item	2886649	et	4	main
karmid	doc_802069853750_item	2886654	et	4	main
suhtuma	doc_802069853750_item	2886656	et	3	main
hästi	doc_802069853750_item	2886660	et	3	main
ainult	doc_802069853750_item	2886666	et	4	main
kõik	doc_802069853750_item	2886669	et	4	main
läinud	doc_802069853750_item	2886675	et	4	main
mõlemal	doc_802069853750_item	2886676	et	3	main
agel	doc_802069853750_item	2886679	et	4	main
nad	doc_802069853750_item	2886717	et	3	main
ka	doc_802069853750_item	2886721	et	3	main
tantsijad	doc_802069853750_item	2886728	et	4	main
tagasihoidlik	doc_802069853750_item	2886729	et	3	main
tagasihoidlikult	doc_802069853750_item	2886730	et	4	main
täpselt	doc_802069853750_item	2886735	et	4	main
tahavad	doc_802069853750_item	2886741	et	3	main
veelgi	doc_802069853750_item	2886744	et	4	main
paremini	doc_802069853750_item	2886746	et	4	main
tantsida	doc_802069853750_item	2886747	et	3	main
tulevad	doc_802069853750_item	2886749	et	4	main
nad	doc_802069853750_item	2886750	et	3	main
öelda	doc_802069853750_item	2886772	et	4	main
ühe	doc_802069853750_item	2886778	et	4	main
harjutus	doc_802069853751_item	2886781	et	4	main
kirjutage	doc_802069853751_item	2886785	et	3	main
age	doc_802069853751_item	2886796	et	4	main
london	doc_802069853751_item	2886809	et	4	main
on	doc_802069853751_item	2886813	et	4	main
30	doc_802069853751_item	2886814	et	2	main
aastat	doc_802069853751_item	2886823	et	3	main
erinevad	doc_802069853751_item	2886839	et	4	main
teatrid	doc_802069853751_item	2886840	et	3	main
armastama	doc_802069853751_item	2886842	et	3	main
ning	doc_802069853751_item	2886846	et	3	main
suhtuma	doc_802069853751_item	2886850	et	3	main
noored	doc_802069853751_item	2886858	et	3	main
ainult	doc_802069853751_item	2886860	et	4	main
kergelt	doc_802069853751_item	2886868	et	4	main
läinud	doc_802069853751_item	2886869	et	4	main
mõlemal	doc_802069853751_item	2886870	et	3	main
ja	doc_802069853751_item	2886871	et	3	main
eriti	doc_802069853751_item	2886872	et	3	main
on	doc_802069853751_item	2886912	et	4	main
tantsijad	doc_802069853751_item	2886922	et	4	main
on	doc_802069853751_item	2886928	et	4	main
tahavad	doc_802069853751_item	2886935	et	3	main
tallinn	doc_802069853751_item	2886946	et	4	main
sõidavad	doc_802069853751_item	2886950	et	3	main
lõuna-aafrikas	doc_802069853751_item	2886952	et	4	main
kui	doc_802069853751_item	2886953	et	3	main
kaua	doc_802069853751_item	2886954	et	3	main
ja	doc_802069853751_item	2886956	et	3	main
veel	doc_802069853751_item	2886958	et	4	main
tipus	doc_802069853751_item	2886959	et	3	main
suudavad	doc_802069853751_item	2886960	et	3	main
püsida	doc_802069853751_item	2886961	et	3	main
öelda	doc_802069853751_item	2886966	et	4	main
päev	doc_802069853751_item	2886971	et	3	main
päeva	doc_802069853751_item	2886973	et	4	main
kaupa	doc_802069853751_item	2886974	et	4	main
vana	doc_802069853752_item	2887018	et	4	main
alates	doc_802069853752_item	2887019	et	3	main
1997a	doc_802069853752_item	2887020	et	4	main
uheksasaja	doc_802069853752_item	2887022	et	4	main
üheksakümmend	doc_802069853752_item	2887023	et	4	main
seitse	doc_802069853752_item	2887024	et	3	main
aasta	doc_802069853752_item	2887025	et	4	main
vabakutselised	doc_802069853752_item	2887029	et	4	main
erinevad	doc_802069853752_item	2887032	et	4	main
erinevad	doc_802069853752_item	2887034	et	4	main
teatris	doc_802069853752_item	2887035	et	3	main
inglismaal	doc_802069853752_item	2887036	et	4	main
armastama	doc_802069853752_item	2887037	et	3	main
armastab	doc_802069853752_item	2887038	et	3	main
suhtuma	doc_802069853752_item	2887045	et	3	main
üldiselt	doc_802069853752_item	2887048	et	4	main
alati	doc_802069853752_item	2887061	et	4	main
nii	doc_802069853752_item	2887062	et	3	main
on	doc_802069853752_item	2887069	et	4	main
tervisega	doc_802069853752_item	2887073	et	3	main
tantsima	doc_802069853750_item	2886710	et	3	main
teineteisega	doc_802069853750_item	2886713	et	3	main
on	doc_802069853750_item	2886718	et	4	main
tehtud	doc_802069853750_item	2886719	et	4	main
eraldi	doc_802069853750_item	2886722	et	4	main
vaatamata	doc_802069853750_item	2886724	et	4	main
nende	doc_802069853750_item	2886731	et	4	main
lähiaja	doc_802069853750_item	2886732	et	3	main
planeeritud	doc_802069853750_item	2886737	et	4	main
age	doc_802069853750_item	2886738	et	4	main
oks	doc_802069853750_item	2886761	et	3	main
suudavad	doc_802069853750_item	2886766	et	3	main
eelistavad	doc_802069853750_item	2886774	et	4	main
elada	doc_802069853750_item	2886775	et	3	main
õige	doc_802069853751_item	2886788	et	4	main
annab	doc_802069853751_item	2886790	et	3	main
maailmakuulsad	doc_802069853751_item	2886793	et	3	main
abielupaar	doc_802069853751_item	2886795	et	4	main
praegu	doc_802069853751_item	2886807	et	3	main
inglismaal	doc_802069853751_item	2886810	et	4	main
aastane	doc_802069853751_item	2886816	et	4	main
ja	doc_802069853751_item	2886817	et	3	main
toomas	doc_802069853751_item	2886818	et	3	main
on	doc_802069853751_item	2886819	et	4	main
ainult	doc_802069853750_item	2886712	et	4	main
elavad	doc_802069853750_item	2886727	et	4	main
planeerima	doc_802069853750_item	2886736	et	3	main
areneda	doc_802069853750_item	2886742	et	3	main
päeva	doc_802069853750_item	2886779	et	4	main
oks	doc_802069853751_item	2886797	et	3	main
on	doc_802069853751_item	2886801	et	4	main
inglismaa	doc_802069853751_item	2886808	et	4	main
londonis	doc_802069853751_item	2886811	et	4	main
age	doc_802069853751_item	2886812	et	4	main
kolmkümmend	doc_802069853751_item	2886821	et	4	main
seitsmest	doc_802069853751_item	2886830	et	4	main
vabakutselisid	doc_802069853751_item	2886834	et	4	main
erinevad	doc_802069853751_item	2886837	et	4	main
teatrid	doc_802069853751_item	2886838	et	3	main
karmid	doc_802069853751_item	2886848	et	4	main
artiklid	doc_802069853751_item	2886856	et	3	main
ja	doc_802069853751_item	2886900	et	3	main
pakkumisi	doc_802069853751_item	2886914	et	4	main
ka	doc_802069853751_item	2886915	et	3	main
eraldi	doc_802069853751_item	2886916	et	4	main
suurele	doc_802069853751_item	2886919	et	4	main
on	doc_802069853750_item	2886734	et	4	main
toomas	doc_802069853750_item	2886740	et	3	main
esinema	doc_802069853750_item	2886751	et	3	main
tallinn	doc_802069853750_item	2886752	et	4	main
tallinnal	doc_802069853750_item	2886753	et	4	main
ja	doc_802069853750_item	2886754	et	3	main
sõidavad	doc_802069853750_item	2886756	et	3	main
seejärel	doc_802069853750_item	2886755	et	3	main
lõuna-aafrika	doc_802069853750_item	2886757	et	4	main
lõuna-aafrikal	doc_802069853750_item	2886758	et	4	main
kui	doc_802069853750_item	2886759	et	3	main
ja	doc_802069853750_item	2886762	et	3	main
veel	doc_802069853750_item	2886764	et	4	main
püsida	doc_802069853750_item	2886767	et	3	main
nad	doc_802069853750_item	2886773	et	3	main
üks	doc_802069853750_item	2886776	et	3	main
numbrid	doc_802069853751_item	2886784	et	3	main
iga	doc_802069853751_item	2886787	et	4	main
punkti	doc_802069853751_item	2886792	et	4	main
ja	doc_802069853751_item	2886798	et	3	main
elavad	doc_802069853751_item	2886806	et	4	main
kaks	doc_802069853751_item	2886822	et	3	main
1997a	doc_802069853751_item	2886826	et	4	main
esinevad	doc_802069853751_item	2886836	et	4	main
armastavad	doc_802069853751_item	2886843	et	4	main
hästi	doc_802069853751_item	2886854	et	3	main
on	doc_802069853751_item	2886874	et	4	main
toomas	doc_802069853751_item	2886901	et	3	main
tantsida	doc_802069853751_item	2886905	et	3	main
paaris	doc_802069853751_item	2886908	et	4	main
kuigi	doc_802069853751_item	2886909	et	3	main
nemad	doc_802069853751_item	2886910	et	3	main
nendele	doc_802069853751_item	2886911	et	4	main
tantsimiseks	doc_802069853751_item	2886917	et	4	main
tagasihoidlikult	doc_802069853751_item	2886924	et	4	main
nende	doc_802069853751_item	2886925	et	4	main
lähiaja	doc_802069853751_item	2886926	et	3	main
täpselt	doc_802069853751_item	2886929	et	4	main
areneda	doc_802069853751_item	2886936	et	3	main
veelgi	doc_802069853751_item	2886938	et	4	main
parem	doc_802069853751_item	2886939	et	4	main
tallinnas	doc_802069853751_item	2886947	et	4	main
lõuna-aafrika	doc_802069853751_item	2886951	et	4	main
oks	doc_802069853751_item	2886955	et	3	main
harjutus	doc_802069853752_item	2886975	et	4	main
avage	doc_802069853752_item	2886976	et	3	main
sulud	doc_802069853752_item	2886977	et	3	main
numbrid	doc_802069853752_item	2886978	et	3	main
kirjutage	doc_802069853752_item	2886979	et	3	main
aastat	doc_802069853752_item	2887017	et	3	main
tuhat	doc_802069853752_item	2887021	et	4	main
neid	doc_802069853752_item	2887039	et	4	main
väga	doc_802069853752_item	2887040	et	3	main
karmid	doc_802069853752_item	2887043	et	4	main
sugugi	doc_802069853752_item	2887060	et	4	main
eriti	doc_802069853752_item	2887067	et	3	main
olnud	doc_802069853752_item	2887070	et	4	main
etendus	doc_802069853752_item	2887082	et	4	main
alates	doc_802069853751_item	2886825	et	3	main
ükstuhat	doc_802069853751_item	2886827	et	4	main
on	doc_802069853751_item	2886831	et	4	main
inglismaal	doc_802069853751_item	2886841	et	4	main
väga	doc_802069853751_item	2886845	et	3	main
isegi	doc_802069853751_item	2886847	et	4	main
kriitikud	doc_802069853751_item	2886849	et	3	main
suhtlevad	doc_802069853751_item	2886851	et	4	main
nendesse	doc_802069853751_item	2886852	et	4	main
räägivad	doc_802069853751_item	2886857	et	3	main
noored	doc_802069853751_item	2886859	et	3	main
ülivõrdes	doc_802069853751_item	2886861	et	3	main
kuid	doc_802069853751_item	2886862	et	4	main
sugugi	doc_802069853751_item	2886865	et	4	main
alati	doc_802069853751_item	2886866	et	4	main
nii	doc_802069853751_item	2886867	et	3	main
olnud	doc_802069853751_item	2886875	et	4	main
probleeme	doc_802069853751_item	2886876	et	3	main
tervis	doc_802069853751_item	2886877	et	3	main
tervist	doc_802069853751_item	2886878	et	4	main
1990	doc_802069853751_item	2886879	et	2	main
aastal	doc_802069853751_item	2886880	et	3	main
murdma	doc_802069853751_item	2886881	et	3	main
murdas	doc_802069853751_item	2886882	et	4	main
noor	doc_802069853751_item	2886883	et	3	main
naine	doc_802069853751_item	2886884	et	3	main
luikede	doc_802069853751_item	2886885	et	3	main
järve	doc_802069853751_item	2886886	et	4	main
etendus	doc_802069853751_item	2886887	et	4	main
etenduses	doc_802069853751_item	2886888	et	4	main
jalaluu	doc_802069853751_item	2886889	et	4	main
ja	doc_802069853751_item	2886890	et	3	main
pidama	doc_802069853751_item	2886891	et	4	main
pidas	doc_802069853751_item	2886892	et	3	main
mõnda	doc_802069853751_item	2886893	et	4	main
aega	doc_802069853751_item	2886894	et	4	main
tantsimisest	doc_802069853751_item	2886895	et	4	main
eemal	doc_802069853751_item	2886896	et	3	main
üldiselt	doc_802069853751_item	2886853	et	4	main
viimased	doc_802069853751_item	2886855	et	3	main
kõik	doc_802069853751_item	2886863	et	4	main
pole	doc_802069853751_item	2886864	et	3	main
agel	doc_802069853751_item	2886873	et	4	main
olema	doc_802069853751_item	2886897	et	4	main
oles	doc_802069853751_item	2886898	et	3	main
on	doc_802069853751_item	2886902	et	4	main
tantsima	doc_802069853751_item	2886904	et	3	main
tehtud	doc_802069853751_item	2886913	et	4	main
vaatamata	doc_802069853751_item	2886918	et	4	main
edule	doc_802069853751_item	2886920	et	3	main
elavad	doc_802069853751_item	2886921	et	4	main
tagasihoidlik	doc_802069853751_item	2886923	et	3	main
planeerima	doc_802069853751_item	2886930	et	3	main
ja	doc_802069853751_item	2886933	et	3	main
ja	doc_802069853751_item	2886937	et	3	main
paremini	doc_802069853751_item	2886940	et	4	main
tantsida	doc_802069853751_item	2886941	et	3	main
märtsis	doc_802069853751_item	2886942	et	3	main
ja	doc_802069853751_item	2886948	et	3	main
seejärel	doc_802069853751_item	2886949	et	3	main
nad	doc_802069853751_item	2886967	et	3	main
elada	doc_802069853751_item	2886969	et	3	main
kaks	doc_802069853752_item	2887016	et	3	main
on	doc_802069853752_item	2887026	et	4	main
ja	doc_802069853752_item	2887030	et	3	main
ning	doc_802069853752_item	2887041	et	3	main
suhtusse	doc_802069853752_item	2887046	et	3	main
viimased	doc_802069853752_item	2887050	et	3	main
räägivad	doc_802069853752_item	2887052	et	3	main
noored	doc_802069853752_item	2887054	et	3	main
ülivõrdes	doc_802069853752_item	2887056	et	3	main
agel	doc_802069853752_item	2887068	et	4	main
tervis	doc_802069853752_item	2887072	et	3	main
1990	doc_802069853752_item	2887074	et	2	main
murdma	doc_802069853752_item	2887076	et	3	main
noor	doc_802069853752_item	2887078	et	3	main
naine	doc_802069853752_item	2887079	et	3	main
luikede	doc_802069853752_item	2887080	et	3	main
järve	doc_802069853752_item	2887081	et	4	main
ja	doc_802069853752_item	2887085	et	3	main
esinemised	doc_802069853752_item	2887122	et	4	main
täpselt	doc_802069853752_item	2887124	et	4	main
tulevad	doc_802069853752_item	2887138	et	4	main
edur	doc_802069853752_item	2887152	et	4	main
sõnadega	doc_802069853753_item	2887175	et	3	main
vastus	doc_802069853753_item	2887178	et	3	main
punkti	doc_802069853753_item	2887181	et	4	main
toomas	doc_802069853753_item	2887188	et	3	main
on	doc_802069853753_item	2887190	et	4	main
pärit	doc_802069853753_item	2887191	et	3	main
eestist	doc_802069853753_item	2887193	et	3	main
aga	doc_802069853753_item	2887194	et	3	main
elavad	doc_802069853753_item	2887195	et	4	main
praegu	doc_802069853753_item	2887196	et	3	main
londonis	doc_802069853753_item	2887200	et	4	main
kolmekümne	doc_802069853753_item	2887204	et	4	main
1997a	doc_802069853753_item	2887215	et	4	main
üheksakümend	doc_802069853753_item	2887219	et	4	main
seitse	doc_802069853753_item	2887220	et	3	main
erinevad	doc_802069853753_item	2887227	et	4	main
teatrid	doc_802069853753_item	2887228	et	3	main
karmid	doc_802069853753_item	2887238	et	4	main
kriitikud	doc_802069853753_item	2887239	et	3	main
suhtuma	doc_802069853753_item	2887240	et	3	main
suhtuvad	doc_802069853753_item	2887241	et	4	main
kuid	doc_802069853753_item	2887252	et	4	main
on	doc_802069853753_item	2887264	et	4	main
olnud	doc_802069853753_item	2887265	et	4	main
1990	doc_802069853753_item	2887269	et	2	main
aastal	doc_802069853753_item	2887270	et	3	main
pidama	doc_802069853753_item	2887281	et	4	main
pidasid	doc_802069853753_item	2887282	et	4	main
mõnda	doc_802069853753_item	2887283	et	4	main
planeeritud	doc_802069853753_item	2887321	et	4	main
tahavad	doc_802069853753_item	2887325	et	3	main
areneda	doc_802069853753_item	2887326	et	3	main
esinema	doc_802069853753_item	2887335	et	3	main
tallinn	doc_802069853753_item	2887336	et	4	main
sõidavad	doc_802069853753_item	2887340	et	3	main
age	doc_802069853751_item	2886899	et	4	main
otsustanud	doc_802069853751_item	2886903	et	4	main
ainult	doc_802069853751_item	2886906	et	4	main
teineteisega	doc_802069853751_item	2886907	et	3	main
esinemised	doc_802069853751_item	2886927	et	4	main
tulevad	doc_802069853751_item	2886943	et	4	main
nad	doc_802069853751_item	2886944	et	3	main
esinema	doc_802069853751_item	2886945	et	3	main
ei	doc_802069853751_item	2886962	et	4	main
oska	doc_802069853751_item	2886963	et	4	main
nad	doc_802069853751_item	2886964	et	3	main
eelistavad	doc_802069853751_item	2886968	et	4	main
üks	doc_802069853751_item	2886970	et	3	main
ühe	doc_802069853751_item	2886972	et	4	main
planeeritud	doc_802069853751_item	2886931	et	4	main
age	doc_802069853751_item	2886932	et	4	main
toomas	doc_802069853751_item	2886934	et	3	main
edur	doc_802069853751_item	2886957	et	4	main
ütlema	doc_802069853751_item	2886965	et	3	main
sõnadega	doc_802069853752_item	2886980	et	3	main
iga	doc_802069853752_item	2886981	et	4	main
õige	doc_802069853752_item	2886982	et	4	main
vastus	doc_802069853752_item	2886983	et	3	main
annab	doc_802069853752_item	2886984	et	3	main
ühe	doc_802069853752_item	2886985	et	4	main
punkti	doc_802069853752_item	2886986	et	4	main
maailmakuulsad	doc_802069853752_item	2886987	et	3	main
balletitantsijad	doc_802069853752_item	2886988	et	3	main
abielupaar	doc_802069853752_item	2886989	et	4	main
age	doc_802069853752_item	2886990	et	4	main
oks	doc_802069853752_item	2886991	et	3	main
ja	doc_802069853752_item	2886992	et	3	main
toomas	doc_802069853752_item	2886993	et	3	main
edur	doc_802069853752_item	2886994	et	4	main
on	doc_802069853752_item	2886995	et	4	main
pärit	doc_802069853752_item	2886996	et	3	main
eesti	doc_802069853752_item	2886997	et	4	main
eestis	doc_802069853752_item	2886998	et	3	main
aga	doc_802069853752_item	2886999	et	3	main
elavad	doc_802069853752_item	2887000	et	4	main
praegu	doc_802069853752_item	2887001	et	3	main
inglismaa	doc_802069853752_item	2887002	et	4	main
london	doc_802069853752_item	2887003	et	4	main
inglismaales	doc_802069853752_item	2887004	et	3	main
londonis	doc_802069853752_item	2887005	et	4	main
age	doc_802069853752_item	2887006	et	4	main
on	doc_802069853752_item	2887007	et	4	main
30	doc_802069853752_item	2887008	et	2	main
kolmekümne	doc_802069853752_item	2887009	et	4	main
aastane	doc_802069853752_item	2887010	et	4	main
ja	doc_802069853752_item	2887011	et	3	main
toomas	doc_802069853752_item	2887012	et	3	main
on	doc_802069853752_item	2887013	et	4	main
32	doc_802069853752_item	2887014	et	2	main
kolmkümmend	doc_802069853752_item	2887015	et	4	main
nad	doc_802069853752_item	2887027	et	3	main
esinevad	doc_802069853752_item	2887031	et	4	main
teatrid	doc_802069853752_item	2887033	et	3	main
kriitikud	doc_802069853752_item	2887044	et	3	main
hästi	doc_802069853752_item	2887049	et	3	main
artiklid	doc_802069853752_item	2887051	et	3	main
noored	doc_802069853752_item	2887053	et	3	main
ainult	doc_802069853752_item	2887055	et	4	main
kergelt	doc_802069853752_item	2887063	et	4	main
läinud	doc_802069853752_item	2887064	et	4	main
mõlemal	doc_802069853752_item	2887065	et	3	main
etenduse	doc_802069853752_item	2887083	et	4	main
pidama	doc_802069853752_item	2887086	et	4	main
mõnda	doc_802069853752_item	2887088	et	4	main
aega	doc_802069853752_item	2887089	et	4	main
tantsimisest	doc_802069853752_item	2887090	et	4	main
eemal	doc_802069853752_item	2887091	et	3	main
olema	doc_802069853752_item	2887092	et	4	main
olla	doc_802069853752_item	2887093	et	3	main
age	doc_802069853752_item	2887094	et	4	main
ja	doc_802069853752_item	2887095	et	3	main
toomas	doc_802069853752_item	2887096	et	3	main
on	doc_802069853752_item	2887097	et	4	main
otsustanud	doc_802069853752_item	2887098	et	4	main
tantsima	doc_802069853752_item	2887099	et	3	main
tantsivad	doc_802069853752_item	2887100	et	4	main
ainult	doc_802069853752_item	2887101	et	4	main
teineteisega	doc_802069853752_item	2887102	et	3	main
paaris	doc_802069853752_item	2887103	et	4	main
kuigi	doc_802069853752_item	2887104	et	3	main
nemad	doc_802069853752_item	2887105	et	3	main
nad	doc_802069853752_item	2887106	et	3	main
on	doc_802069853752_item	2887107	et	4	main
tehtud	doc_802069853752_item	2887108	et	4	main
pakkumisi	doc_802069853752_item	2887109	et	4	main
ka	doc_802069853752_item	2887110	et	3	main
eraldi	doc_802069853752_item	2887111	et	4	main
tantsimiseks	doc_802069853752_item	2887112	et	4	main
vaatamata	doc_802069853752_item	2887113	et	4	main
suurele	doc_802069853752_item	2887114	et	4	main
edule	doc_802069853752_item	2887115	et	3	main
elavad	doc_802069853752_item	2887116	et	4	main
tantsijad	doc_802069853752_item	2887117	et	4	main
tagasihoidlik	doc_802069853752_item	2887118	et	3	main
tagasihoidiku	doc_802069853752_item	2887119	et	3	main
nende	doc_802069853752_item	2887120	et	4	main
age	doc_802069853752_item	2887127	et	4	main
ja	doc_802069853752_item	2887128	et	3	main
vabakutseline	doc_802069853752_item	2887028	et	4	main
isegi	doc_802069853752_item	2887042	et	4	main
nendesse	doc_802069853752_item	2887047	et	4	main
kuid	doc_802069853752_item	2887057	et	4	main
kõik	doc_802069853752_item	2887058	et	4	main
pole	doc_802069853752_item	2887059	et	3	main
ja	doc_802069853752_item	2887066	et	3	main
probleeme	doc_802069853752_item	2887071	et	3	main
on	doc_802069853752_item	2887123	et	4	main
planeerima	doc_802069853752_item	2887125	et	3	main
planerivad	doc_802069853752_item	2887126	et	4	main
märtsis	doc_802069853752_item	2887137	et	3	main
tallinn	doc_802069853752_item	2887141	et	4	main
uks	doc_802069853752_item	2887167	et	3	main
iga	doc_802069853753_item	2887176	et	4	main
annab	doc_802069853753_item	2887179	et	3	main
inglismaa	doc_802069853753_item	2887197	et	4	main
aastane	doc_802069853753_item	2887205	et	4	main
32	doc_802069853753_item	2887209	et	2	main
vana	doc_802069853753_item	2887213	et	4	main
tuhat	doc_802069853753_item	2887217	et	4	main
üheksasada	doc_802069853753_item	2887218	et	4	main
erinevaid	doc_802069853753_item	2887229	et	4	main
teatri	doc_802069853753_item	2887230	et	3	main
inglismaal	doc_802069853753_item	2887231	et	4	main
armastama	doc_802069853753_item	2887232	et	3	main
sugugi	doc_802069853753_item	2887255	et	4	main
nii	doc_802069853753_item	2887257	et	3	main
probleeme	doc_802069853753_item	2887266	et	3	main
tervis	doc_802069853753_item	2887267	et	3	main
tervisega	doc_802069853753_item	2887268	et	3	main
murdma	doc_802069853753_item	2887271	et	3	main
luikede	doc_802069853753_item	2887275	et	3	main
aega	doc_802069853753_item	2887284	et	4	main
täpselt	doc_802069853753_item	2887319	et	4	main
seejärel	doc_802069853753_item	2887339	et	3	main
kui	doc_802069853753_item	2887343	et	3	main
ütlema	doc_802069853753_item	2887355	et	3	main
üks	doc_802069853753_item	2887360	et	3	main
aastat	doc_802069853754_item	2887416	et	3	main
vabakutselise	doc_802069853754_item	2887420	et	4	main
inglismaal	doc_802069853754_item	2887427	et	4	main
neid	doc_802069853754_item	2887430	et	4	main
ning	doc_802069853754_item	2887432	et	3	main
karmid	doc_802069853754_item	2887434	et	4	main
suhtuvad	doc_802069853754_item	2887437	et	4	main
hästi	doc_802069853754_item	2887440	et	3	main
räägivad	doc_802069853754_item	2887443	et	3	main
alati	doc_802069853754_item	2887451	et	4	main
nii	doc_802069853754_item	2887452	et	3	main
kergelt	doc_802069853754_item	2887453	et	4	main
etendusi	doc_802069853754_item	2887473	et	4	main
pidama	doc_802069853754_item	2887476	et	4	main
aega	doc_802069853754_item	2887478	et	4	main
age	doc_802069853754_item	2887483	et	4	main
ja	doc_802069853754_item	2887532	et	3	main
eelistavad	doc_802069853754_item	2887552	et	4	main
üks	doc_802069853754_item	2887554	et	3	main
ühe	doc_802069853754_item	2887556	et	4	main
kaupa	doc_802069853754_item	2887558	et	4	main
ja	doc_802069853755_item	2887576	et	3	main
aga	doc_802069853755_item	2887583	et	3	main
praegu	doc_802069853755_item	2887585	et	3	main
inglismaa	doc_802069853755_item	2887586	et	4	main
on	doc_802069853755_item	2887591	et	4	main
30	doc_802069853755_item	2887592	et	2	main
kolmekümne	doc_802069853755_item	2887593	et	4	main
on	doc_802069853755_item	2887606	et	4	main
nad	doc_802069853755_item	2887607	et	3	main
isegi	doc_802069853755_item	2887622	et	4	main
nendesse	doc_802069853755_item	2887627	et	4	main
ja	doc_802069853755_item	2887646	et	3	main
tervis	doc_802069853755_item	2887652	et	3	main
1990	doc_802069853755_item	2887654	et	2	main
age	doc_802069853755_item	2887674	et	4	main
paaris	doc_802069853755_item	2887683	et	4	main
nad	doc_802069853755_item	2887686	et	3	main
tehtud	doc_802069853755_item	2887688	et	4	main
eraldi	doc_802069853755_item	2887691	et	4	main
tantsijad	doc_802069853755_item	2887697	et	4	main
tagasihoidlik	doc_802069853755_item	2887698	et	3	main
aastal	doc_802069853752_item	2887075	et	3	main
murdasib	doc_802069853752_item	2887077	et	4	main
jalaluu	doc_802069853752_item	2887084	et	4	main
pidada	doc_802069853752_item	2887087	et	4	main
lähiaja	doc_802069853752_item	2887121	et	3	main
seejärel	doc_802069853752_item	2887144	et	3	main
sõidavad	doc_802069853752_item	2887145	et	3	main
kaupa	doc_802069853752_item	2887169	et	4	main
kirjutage	doc_802069853753_item	2887174	et	3	main
õige	doc_802069853753_item	2887177	et	4	main
ja	doc_802069853753_item	2887187	et	3	main
london	doc_802069853753_item	2887198	et	4	main
on	doc_802069853753_item	2887202	et	4	main
30	doc_802069853753_item	2887203	et	2	main
on	doc_802069853753_item	2887208	et	4	main
aastal	doc_802069853753_item	2887216	et	3	main
parem	doc_802069853752_item	2887135	et	4	main
tantsida	doc_802069853752_item	2887136	et	3	main
veel	doc_802069853752_item	2887153	et	4	main
tipus	doc_802069853752_item	2887154	et	3	main
suudavad	doc_802069853752_item	2887155	et	3	main
püsida	doc_802069853752_item	2887156	et	3	main
ei	doc_802069853752_item	2887157	et	4	main
oska	doc_802069853752_item	2887158	et	4	main
nad	doc_802069853752_item	2887159	et	3	main
ütlema	doc_802069853752_item	2887160	et	3	main
utle	doc_802069853752_item	2887161	et	4	main
nad	doc_802069853752_item	2887162	et	3	main
eelistavad	doc_802069853752_item	2887163	et	4	main
elada	doc_802069853752_item	2887164	et	3	main
üks	doc_802069853752_item	2887165	et	3	main
päev	doc_802069853752_item	2887166	et	3	main
toomas	doc_802069853752_item	2887129	et	3	main
tahavad	doc_802069853752_item	2887130	et	3	main
areneda	doc_802069853752_item	2887131	et	3	main
ja	doc_802069853752_item	2887132	et	3	main
veelgi	doc_802069853752_item	2887133	et	4	main
parem	doc_802069853752_item	2887134	et	4	main
nad	doc_802069853752_item	2887139	et	3	main
esinema	doc_802069853752_item	2887140	et	3	main
tallinas	doc_802069853752_item	2887142	et	4	main
ja	doc_802069853752_item	2887143	et	3	main
lõuna-aafrika	doc_802069853752_item	2887146	et	4	main
lõuna-afrikas	doc_802069853752_item	2887147	et	4	main
kui	doc_802069853752_item	2887148	et	3	main
kaua	doc_802069853752_item	2887149	et	3	main
oks	doc_802069853752_item	2887150	et	3	main
ja	doc_802069853752_item	2887151	et	3	main
age	doc_802069853753_item	2887185	et	4	main
edur	doc_802069853753_item	2887189	et	4	main
eesti	doc_802069853753_item	2887192	et	4	main
ja	doc_802069853753_item	2887206	et	3	main
kolmkümend	doc_802069853753_item	2887210	et	4	main
aastat	doc_802069853753_item	2887212	et	3	main
alates	doc_802069853753_item	2887214	et	3	main
nad	doc_802069853753_item	2887222	et	3	main
ja	doc_802069853753_item	2887225	et	3	main
esinevad	doc_802069853753_item	2887226	et	4	main
neid	doc_802069853753_item	2887234	et	4	main
väga	doc_802069853753_item	2887235	et	3	main
ning	doc_802069853753_item	2887236	et	3	main
üldiselt	doc_802069853753_item	2887243	et	4	main
hästi	doc_802069853753_item	2887244	et	3	main
viimased	doc_802069853753_item	2887245	et	3	main
artiklid	doc_802069853753_item	2887246	et	3	main
räägivad	doc_802069853753_item	2887247	et	3	main
pole	doc_802069853753_item	2887254	et	3	main
alati	doc_802069853753_item	2887256	et	4	main
naine	doc_802069853753_item	2887274	et	3	main
järve	doc_802069853753_item	2887276	et	4	main
jalaluu	doc_802069853753_item	2887279	et	4	main
ja	doc_802069853753_item	2887280	et	3	main
tantsimisest	doc_802069853753_item	2887285	et	4	main
age	doc_802069853753_item	2887322	et	4	main
ja	doc_802069853753_item	2887323	et	3	main
toomas	doc_802069853753_item	2887324	et	3	main
ja	doc_802069853753_item	2887327	et	3	main
tallinnal	doc_802069853753_item	2887337	et	4	main
oska	doc_802069853753_item	2887353	et	4	main
nad	doc_802069853753_item	2887354	et	3	main
elada	doc_802069853753_item	2887359	et	3	main
päev	doc_802069853753_item	2887361	et	3	main
harjutus	doc_802069853754_item	2887365	et	4	main
avage	doc_802069853754_item	2887366	et	3	main
sulud	doc_802069853754_item	2887367	et	3	main
numbrid	doc_802069853754_item	2887368	et	3	main
kirjutage	doc_802069853754_item	2887369	et	3	main
sõnadega	doc_802069853754_item	2887370	et	3	main
punkti	doc_802069853754_item	2887376	et	4	main
üheksa	doc_802069853754_item	2887413	et	4	main
nad	doc_802069853754_item	2887418	et	3	main
esinevad	doc_802069853754_item	2887422	et	4	main
teatrid	doc_802069853754_item	2887424	et	3	main
teatris	doc_802069853754_item	2887426	et	3	main
sugugi	doc_802069853754_item	2887450	et	4	main
eriti	doc_802069853754_item	2887457	et	3	main
on	doc_802069853754_item	2887459	et	4	main
tervis	doc_802069853754_item	2887462	et	3	main
tervisega	doc_802069853754_item	2887463	et	3	main
aastal	doc_802069853754_item	2887465	et	3	main
murdma	doc_802069853754_item	2887466	et	3	main
murdis	doc_802069853754_item	2887467	et	3	main
noor	doc_802069853754_item	2887468	et	3	main
naine	doc_802069853754_item	2887469	et	3	main
luikede	doc_802069853754_item	2887470	et	3	main
järve	doc_802069853754_item	2887471	et	4	main
ja	doc_802069853754_item	2887475	et	3	main
mõnda	doc_802069853754_item	2887477	et	4	main
tantsimisest	doc_802069853754_item	2887479	et	4	main
eemal	doc_802069853754_item	2887480	et	3	main
ja	doc_802069853754_item	2887484	et	3	main
otsustanud	doc_802069853754_item	2887487	et	4	main
parem	doc_802069853754_item	2887523	et	4	main
seejärel	doc_802069853754_item	2887533	et	3	main
päeva	doc_802069853752_item	2887168	et	4	main
harjutus	doc_802069853753_item	2887170	et	4	main
avage	doc_802069853753_item	2887171	et	3	main
sulud	doc_802069853753_item	2887172	et	3	main
numbrid	doc_802069853753_item	2887173	et	3	main
ühe	doc_802069853753_item	2887180	et	4	main
maailmakuulsad	doc_802069853753_item	2887182	et	3	main
balletitantsijad	doc_802069853753_item	2887183	et	3	main
abielupaar	doc_802069853753_item	2887184	et	4	main
oks	doc_802069853753_item	2887186	et	3	main
inglismaal	doc_802069853753_item	2887199	et	4	main
age	doc_802069853753_item	2887201	et	4	main
toomas	doc_802069853753_item	2887207	et	3	main
kaks	doc_802069853753_item	2887211	et	3	main
isegi	doc_802069853753_item	2887237	et	4	main
noored	doc_802069853753_item	2887248	et	3	main
noorest	doc_802069853753_item	2887249	et	3	main
ainult	doc_802069853753_item	2887250	et	4	main
ülivõrdes	doc_802069853753_item	2887251	et	3	main
agel	doc_802069853753_item	2887263	et	4	main
noor	doc_802069853753_item	2887273	et	3	main
etendus	doc_802069853753_item	2887277	et	4	main
etendust	doc_802069853753_item	2887278	et	4	main
on	doc_802069853753_item	2887221	et	4	main
vabakutseline	doc_802069853753_item	2887223	et	4	main
vabakutselised	doc_802069853753_item	2887224	et	4	main
armastavad	doc_802069853753_item	2887233	et	4	main
nendesse	doc_802069853753_item	2887242	et	4	main
kõik	doc_802069853753_item	2887253	et	4	main
kergelt	doc_802069853753_item	2887258	et	4	main
läinud	doc_802069853753_item	2887259	et	4	main
mõlemal	doc_802069853753_item	2887260	et	3	main
ja	doc_802069853753_item	2887261	et	3	main
eriti	doc_802069853753_item	2887262	et	3	main
murdis	doc_802069853753_item	2887272	et	3	main
eemal	doc_802069853753_item	2887286	et	3	main
olema	doc_802069853753_item	2887287	et	4	main
olevad	doc_802069853753_item	2887288	et	4	main
age	doc_802069853753_item	2887289	et	4	main
ja	doc_802069853753_item	2887290	et	3	main
toomas	doc_802069853753_item	2887291	et	3	main
on	doc_802069853753_item	2887292	et	4	main
otsustanud	doc_802069853753_item	2887293	et	4	main
tantsima	doc_802069853753_item	2887294	et	3	main
tantsima	doc_802069853753_item	2887295	et	3	main
ainult	doc_802069853753_item	2887296	et	4	main
teineteisega	doc_802069853753_item	2887297	et	3	main
paaris	doc_802069853753_item	2887298	et	4	main
kuigi	doc_802069853753_item	2887299	et	3	main
nemad	doc_802069853753_item	2887300	et	3	main
nad	doc_802069853753_item	2887301	et	3	main
on	doc_802069853753_item	2887302	et	4	main
tehtud	doc_802069853753_item	2887303	et	4	main
pakkumisi	doc_802069853753_item	2887304	et	4	main
ka	doc_802069853753_item	2887305	et	3	main
tantsimiseks	doc_802069853753_item	2887307	et	4	main
eraldi	doc_802069853753_item	2887306	et	4	main
vaatamata	doc_802069853753_item	2887308	et	4	main
suurele	doc_802069853753_item	2887309	et	4	main
edule	doc_802069853753_item	2887310	et	3	main
elavad	doc_802069853753_item	2887311	et	4	main
tantsijad	doc_802069853753_item	2887312	et	4	main
tagasihoidlik	doc_802069853753_item	2887313	et	3	main
tagasihoidlikult	doc_802069853753_item	2887314	et	4	main
nende	doc_802069853753_item	2887315	et	4	main
lähiaja	doc_802069853753_item	2887316	et	3	main
esinemised	doc_802069853753_item	2887317	et	4	main
on	doc_802069853753_item	2887318	et	4	main
planeerima	doc_802069853753_item	2887320	et	3	main
veelgi	doc_802069853753_item	2887328	et	4	main
parem	doc_802069853753_item	2887329	et	4	main
ja	doc_802069853753_item	2887338	et	3	main
eelistavad	doc_802069853753_item	2887358	et	4	main
iga	doc_802069853754_item	2887371	et	4	main
maailmakuulsad	doc_802069853754_item	2887377	et	3	main
abielupaar	doc_802069853754_item	2887379	et	4	main
age	doc_802069853754_item	2887380	et	4	main
oks	doc_802069853754_item	2887381	et	3	main
ja	doc_802069853754_item	2887382	et	3	main
toomas	doc_802069853754_item	2887383	et	3	main
on	doc_802069853754_item	2887385	et	4	main
edur	doc_802069853754_item	2887384	et	4	main
pärit	doc_802069853754_item	2887386	et	3	main
eesti	doc_802069853754_item	2887387	et	4	main
eestist	doc_802069853754_item	2887388	et	3	main
aga	doc_802069853754_item	2887389	et	3	main
elavad	doc_802069853754_item	2887390	et	4	main
praegu	doc_802069853754_item	2887391	et	3	main
inglismaa	doc_802069853754_item	2887392	et	4	main
london	doc_802069853754_item	2887393	et	4	main
inglismaal	doc_802069853754_item	2887394	et	4	main
londonis	doc_802069853754_item	2887395	et	4	main
age	doc_802069853754_item	2887396	et	4	main
on	doc_802069853754_item	2887397	et	4	main
30	doc_802069853754_item	2887398	et	2	main
kolmekümne	doc_802069853754_item	2887399	et	4	main
aastane	doc_802069853754_item	2887400	et	4	main
ja	doc_802069853754_item	2887401	et	3	main
toomas	doc_802069853754_item	2887402	et	3	main
on	doc_802069853754_item	2887403	et	4	main
32	doc_802069853754_item	2887404	et	2	main
kolmkümmend	doc_802069853754_item	2887405	et	4	main
kaks	doc_802069853754_item	2887406	et	3	main
aastat	doc_802069853754_item	2887407	et	3	main
vana	doc_802069853754_item	2887408	et	4	main
alates	doc_802069853754_item	2887409	et	3	main
1997a	doc_802069853754_item	2887410	et	4	main
tuhahande	doc_802069853754_item	2887411	et	4	main
üheksasaja	doc_802069853754_item	2887412	et	4	main
paremini	doc_802069853753_item	2887330	et	4	main
tantsida	doc_802069853753_item	2887331	et	3	main
märtsis	doc_802069853753_item	2887332	et	3	main
tulevad	doc_802069853753_item	2887333	et	4	main
nad	doc_802069853753_item	2887334	et	3	main
lõuna-aafrika	doc_802069853753_item	2887341	et	4	main
oks	doc_802069853753_item	2887345	et	3	main
edur	doc_802069853753_item	2887347	et	4	main
ütelda	doc_802069853753_item	2887356	et	4	main
päeva	doc_802069853753_item	2887363	et	4	main
kaupa	doc_802069853753_item	2887364	et	4	main
vastus	doc_802069853754_item	2887373	et	3	main
annab	doc_802069853754_item	2887374	et	3	main
ühe	doc_802069853754_item	2887375	et	4	main
vabakutseline	doc_802069853754_item	2887419	et	4	main
ja	doc_802069853754_item	2887421	et	3	main
erinevates	doc_802069853754_item	2887425	et	4	main
kuid	doc_802069853754_item	2887447	et	4	main
kõik	doc_802069853754_item	2887448	et	4	main
pole	doc_802069853754_item	2887449	et	3	main
mõlemal	doc_802069853754_item	2887455	et	3	main
agel	doc_802069853754_item	2887458	et	4	main
olnud	doc_802069853754_item	2887460	et	4	main
probleeme	doc_802069853754_item	2887461	et	3	main
1990	doc_802069853754_item	2887464	et	2	main
jalaluu	doc_802069853754_item	2887474	et	4	main
olla	doc_802069853754_item	2887482	et	3	main
ja	doc_802069853754_item	2887521	et	3	main
tallinnasse	doc_802069853754_item	2887531	et	3	main
harjutus	doc_802069853755_item	2887559	et	4	main
avage	doc_802069853755_item	2887560	et	3	main
sulud	doc_802069853755_item	2887561	et	3	main
numbrid	doc_802069853755_item	2887562	et	3	main
kirjutage	doc_802069853755_item	2887563	et	3	main
sõnadega	doc_802069853755_item	2887564	et	3	main
ühe	doc_802069853755_item	2887569	et	4	main
punkti	doc_802069853755_item	2887570	et	4	main
maailmakuulsad	doc_802069853755_item	2887571	et	3	main
balletitantsijad	doc_802069853755_item	2887572	et	3	main
abielupaar	doc_802069853755_item	2887573	et	4	main
age	doc_802069853755_item	2887574	et	4	main
oks	doc_802069853755_item	2887575	et	3	main
pärit	doc_802069853755_item	2887580	et	3	main
lõuna-aafrikal	doc_802069853753_item	2887342	et	4	main
kaua	doc_802069853753_item	2887344	et	3	main
ja	doc_802069853753_item	2887346	et	3	main
veel	doc_802069853753_item	2887348	et	4	main
tipus	doc_802069853753_item	2887349	et	3	main
suudavad	doc_802069853753_item	2887350	et	3	main
püsida	doc_802069853753_item	2887351	et	3	main
ei	doc_802069853753_item	2887352	et	4	main
nad	doc_802069853753_item	2887357	et	3	main
ühe	doc_802069853753_item	2887362	et	4	main
õige	doc_802069853754_item	2887372	et	4	main
balletitantsijad	doc_802069853754_item	2887378	et	3	main
kümmend	doc_802069853754_item	2887414	et	4	main
on	doc_802069853754_item	2887417	et	4	main
seitsme	doc_802069853754_item	2887415	et	3	main
erinevad	doc_802069853754_item	2887423	et	4	main
armastama	doc_802069853754_item	2887428	et	3	main
isegi	doc_802069853754_item	2887433	et	4	main
kriitikud	doc_802069853754_item	2887435	et	3	main
suhtuma	doc_802069853754_item	2887436	et	3	main
üldiselt	doc_802069853754_item	2887439	et	4	main
viimased	doc_802069853754_item	2887441	et	3	main
noored	doc_802069853754_item	2887444	et	3	main
ülivõrdes	doc_802069853754_item	2887446	et	3	main
läinud	doc_802069853754_item	2887454	et	4	main
ja	doc_802069853754_item	2887456	et	3	main
on	doc_802069853754_item	2887486	et	4	main
tantsima	doc_802069853754_item	2887488	et	3	main
veelgi	doc_802069853754_item	2887522	et	4	main
paremeni	doc_802069853754_item	2887524	et	4	main
tantsida	doc_802069853754_item	2887525	et	3	main
märtsis	doc_802069853754_item	2887526	et	3	main
tulevad	doc_802069853754_item	2887527	et	4	main
nad	doc_802069853754_item	2887528	et	3	main
esinema	doc_802069853754_item	2887529	et	3	main
sõidavad	doc_802069853754_item	2887534	et	3	main
lõuna-aafrikale	doc_802069853754_item	2887536	et	4	main
ütleda	doc_802069853754_item	2887550	et	4	main
elada	doc_802069853754_item	2887553	et	3	main
iga	doc_802069853755_item	2887565	et	4	main
on	doc_802069853755_item	2887579	et	4	main
eesti	doc_802069853755_item	2887581	et	4	main
elavad	doc_802069853755_item	2887584	et	4	main
london	doc_802069853755_item	2887587	et	4	main
32	doc_802069853755_item	2887598	et	2	main
aastat	doc_802069853755_item	2887601	et	3	main
vabakutsevad	doc_802069853755_item	2887609	et	4	main
ja	doc_802069853755_item	2887610	et	3	main
karmid	doc_802069853755_item	2887623	et	4	main
kõik	doc_802069853755_item	2887638	et	4	main
pole	doc_802069853755_item	2887639	et	3	main
mõlemal	doc_802069853755_item	2887645	et	3	main
olnud	doc_802069853755_item	2887650	et	4	main
tervisega	doc_802069853755_item	2887653	et	3	main
aastal	doc_802069853755_item	2887655	et	3	main
ja	doc_802069853755_item	2887675	et	3	main
toomas	doc_802069853755_item	2887676	et	3	main
on	doc_802069853755_item	2887677	et	4	main
nemad	doc_802069853755_item	2887685	et	3	main
planerimis	doc_802069853755_item	2887706	et	4	main
areneda	doc_802069853755_item	2887711	et	3	main
tipus	doc_802069853755_item	2887734	et	3	main
üks	doc_802069853755_item	2887745	et	3	main
ühe	doc_802069853756_item	2887760	et	4	main
london	doc_802069853756_item	2887780	et	4	main
on	doc_802069853756_item	2887788	et	4	main
32	doc_802069853756_item	2887789	et	2	main
aastat	doc_802069853756_item	2887792	et	3	main
1997a	doc_802069853756_item	2887795	et	4	main
erinevad	doc_802069853756_item	2887807	et	4	main
teatrid	doc_802069853756_item	2887808	et	3	main
teatris	doc_802069853756_item	2887810	et	3	main
ainult	doc_802069853756_item	2887830	et	4	main
kergelt	doc_802069853756_item	2887838	et	4	main
etenda	doc_802069853756_item	2887858	et	4	main
otsustanud	doc_802069853756_item	2887873	et	4	main
tantsima	doc_802069853756_item	2887874	et	3	main
kuigi	doc_802069853756_item	2887879	et	3	main
nemad	doc_802069853756_item	2887881	et	3	main
edule	doc_802069853756_item	2887890	et	3	main
nende	doc_802069853756_item	2887895	et	4	main
lähiaja	doc_802069853756_item	2887896	et	3	main
esinemised	doc_802069853756_item	2887897	et	4	main
age	doc_802069853756_item	2887902	et	4	main
ja	doc_802069853756_item	2887903	et	3	main
toomas	doc_802069853756_item	2887904	et	3	main
tahavad	doc_802069853756_item	2887905	et	3	main
lõuna-aafrika	doc_802069853756_item	2887921	et	4	main
kui	doc_802069853756_item	2887923	et	3	main
ja	doc_802069853756_item	2887926	et	3	main
üks	doc_802069853756_item	2887940	et	3	main
kaupa	doc_802069853756_item	2887944	et	4	main
avage	doc_802069853757_item	2887946	et	3	main
sulud	doc_802069853757_item	2887947	et	3	main
annab	doc_802069853757_item	2887954	et	3	main
armastavad	doc_802069853754_item	2887429	et	4	main
väga	doc_802069853754_item	2887431	et	3	main
nendesse	doc_802069853754_item	2887438	et	4	main
artiklid	doc_802069853754_item	2887442	et	3	main
ainult	doc_802069853754_item	2887445	et	4	main
etendus	doc_802069853754_item	2887472	et	4	main
olema	doc_802069853754_item	2887481	et	4	main
toomas	doc_802069853754_item	2887485	et	3	main
tantsida	doc_802069853754_item	2887489	et	3	main
ainult	doc_802069853754_item	2887490	et	4	main
teineteisega	doc_802069853754_item	2887491	et	3	main
paaris	doc_802069853754_item	2887492	et	4	main
kuigi	doc_802069853754_item	2887493	et	3	main
nemad	doc_802069853754_item	2887494	et	3	main
nendel	doc_802069853754_item	2887495	et	4	main
on	doc_802069853754_item	2887496	et	4	main
tehtud	doc_802069853754_item	2887497	et	4	main
pakkumisi	doc_802069853754_item	2887498	et	4	main
ka	doc_802069853754_item	2887499	et	3	main
eraldi	doc_802069853754_item	2887500	et	4	main
vaatamata	doc_802069853754_item	2887502	et	4	main
suurele	doc_802069853754_item	2887503	et	4	main
edule	doc_802069853754_item	2887504	et	3	main
tantsimiseks	doc_802069853754_item	2887501	et	4	main
elavad	doc_802069853754_item	2887505	et	4	main
tantsijad	doc_802069853754_item	2887506	et	4	main
tagasihoidlik	doc_802069853754_item	2887507	et	3	main
tagasihoidlikult	doc_802069853754_item	2887508	et	4	main
nende	doc_802069853754_item	2887509	et	4	main
lähiaja	doc_802069853754_item	2887510	et	3	main
esinemised	doc_802069853754_item	2887511	et	4	main
on	doc_802069853754_item	2887512	et	4	main
täpselt	doc_802069853754_item	2887513	et	4	main
planeerima	doc_802069853754_item	2887514	et	3	main
planeritud	doc_802069853754_item	2887515	et	4	main
age	doc_802069853754_item	2887516	et	4	main
ja	doc_802069853754_item	2887517	et	3	main
toomas	doc_802069853754_item	2887518	et	3	main
tahavad	doc_802069853754_item	2887519	et	3	main
areneda	doc_802069853754_item	2887520	et	3	main
tallinn	doc_802069853754_item	2887530	et	4	main
ei	doc_802069853754_item	2887546	et	4	main
oska	doc_802069853754_item	2887547	et	4	main
nad	doc_802069853754_item	2887548	et	3	main
ütlema	doc_802069853754_item	2887549	et	3	main
annab	doc_802069853755_item	2887568	et	3	main
edur	doc_802069853755_item	2887578	et	4	main
inglismaal	doc_802069853755_item	2887588	et	4	main
aastane	doc_802069853755_item	2887594	et	4	main
ja	doc_802069853755_item	2887595	et	3	main
toomas	doc_802069853755_item	2887596	et	3	main
kolmkümend	doc_802069853755_item	2887599	et	4	main
vana	doc_802069853755_item	2887602	et	4	main
alates	doc_802069853755_item	2887603	et	3	main
1997a	doc_802069853755_item	2887604	et	4	main
tuhandeüheksasajaüheksakumneseitsmendani	doc_802069853755_item	2887605	et	4	main
esinevad	doc_802069853755_item	2887611	et	4	main
erinevad	doc_802069853755_item	2887612	et	4	main
teatrid	doc_802069853755_item	2887613	et	3	main
erinevaid	doc_802069853755_item	2887614	et	4	main
teatrid	doc_802069853755_item	2887615	et	3	main
inglismaal	doc_802069853755_item	2887616	et	4	main
armastama	doc_802069853755_item	2887617	et	3	main
armastavad	doc_802069853755_item	2887618	et	4	main
neid	doc_802069853755_item	2887619	et	4	main
väga	doc_802069853755_item	2887620	et	3	main
kriitikud	doc_802069853755_item	2887624	et	3	main
suhtuvad	doc_802069853755_item	2887626	et	4	main
üldiselt	doc_802069853755_item	2887628	et	4	main
hästi	doc_802069853755_item	2887629	et	3	main
viimased	doc_802069853755_item	2887630	et	3	main
artiklid	doc_802069853755_item	2887631	et	3	main
räägivad	doc_802069853755_item	2887632	et	3	main
noored	doc_802069853755_item	2887633	et	3	main
noored	doc_802069853755_item	2887634	et	3	main
ainult	doc_802069853755_item	2887635	et	4	main
ülivõrdes	doc_802069853755_item	2887636	et	3	main
sugugi	doc_802069853755_item	2887640	et	4	main
alati	doc_802069853755_item	2887641	et	4	main
nii	doc_802069853755_item	2887642	et	3	main
kergelt	doc_802069853755_item	2887643	et	4	main
eriti	doc_802069853755_item	2887647	et	3	main
noor	doc_802069853755_item	2887658	et	3	main
tantsimiseks	doc_802069853755_item	2887692	et	4	main
nende	doc_802069853755_item	2887700	et	4	main
toomas	doc_802069853755_item	2887709	et	3	main
oska	doc_802069853755_item	2887738	et	4	main
nad	doc_802069853755_item	2887739	et	3	main
ütlema	doc_802069853755_item	2887740	et	3	main
ütlevad	doc_802069853755_item	2887741	et	4	main
elada	doc_802069853755_item	2887744	et	3	main
maailmakuulsad	doc_802069853756_item	2887762	et	3	main
age	doc_802069853756_item	2887781	et	4	main
30	doc_802069853756_item	2887783	et	2	main
kolmekümnendane	doc_802069853756_item	2887784	et	4	main
aastane	doc_802069853756_item	2887785	et	4	main
ja	doc_802069853756_item	2887786	et	3	main
toomas	doc_802069853756_item	2887787	et	3	main
kahendal	doc_802069853756_item	2887791	et	4	main
vana	doc_802069853756_item	2887793	et	4	main
üheksasada	doc_802069853756_item	2887798	et	4	main
nad	doc_802069853756_item	2887802	et	3	main
isegi	doc_802069853756_item	2887817	et	4	main
karmid	doc_802069853756_item	2887818	et	4	main
kriitikud	doc_802069853756_item	2887819	et	3	main
suhtuma	doc_802069853756_item	2887820	et	3	main
lõuna-aafrika	doc_802069853754_item	2887535	et	4	main
kui	doc_802069853754_item	2887537	et	3	main
kaua	doc_802069853754_item	2887538	et	3	main
oks	doc_802069853754_item	2887539	et	3	main
ja	doc_802069853754_item	2887540	et	3	main
edur	doc_802069853754_item	2887541	et	4	main
veel	doc_802069853754_item	2887542	et	4	main
tipus	doc_802069853754_item	2887543	et	3	main
suudavad	doc_802069853754_item	2887544	et	3	main
püsida	doc_802069853754_item	2887545	et	3	main
nad	doc_802069853754_item	2887551	et	3	main
päev	doc_802069853754_item	2887555	et	3	main
päeva	doc_802069853754_item	2887557	et	4	main
õige	doc_802069853755_item	2887566	et	4	main
vastus	doc_802069853755_item	2887567	et	3	main
toomas	doc_802069853755_item	2887577	et	3	main
eestis	doc_802069853755_item	2887582	et	3	main
londonis	doc_802069853755_item	2887589	et	4	main
age	doc_802069853755_item	2887590	et	4	main
on	doc_802069853755_item	2887597	et	4	main
kaks	doc_802069853755_item	2887600	et	3	main
vabakutseline	doc_802069853755_item	2887608	et	4	main
suhtuma	doc_802069853755_item	2887625	et	3	main
agel	doc_802069853755_item	2887648	et	4	main
on	doc_802069853755_item	2887649	et	4	main
probleeme	doc_802069853755_item	2887651	et	3	main
murdma	doc_802069853755_item	2887656	et	3	main
otsustanud	doc_802069853755_item	2887678	et	4	main
tantsima	doc_802069853755_item	2887679	et	3	main
kuigi	doc_802069853755_item	2887684	et	3	main
on	doc_802069853755_item	2887687	et	4	main
pakkumisi	doc_802069853755_item	2887689	et	4	main
ka	doc_802069853755_item	2887690	et	3	main
elavad	doc_802069853755_item	2887696	et	4	main
age	doc_802069853755_item	2887707	et	4	main
ja	doc_802069853755_item	2887708	et	3	main
tulevad	doc_802069853755_item	2887718	et	4	main
nad	doc_802069853755_item	2887719	et	3	main
esinema	doc_802069853755_item	2887720	et	3	main
ning	doc_802069853755_item	2887621	et	3	main
kuid	doc_802069853755_item	2887637	et	4	main
läinud	doc_802069853755_item	2887644	et	4	main
murdub	doc_802069853755_item	2887657	et	3	main
naine	doc_802069853755_item	2887659	et	3	main
luikede	doc_802069853755_item	2887660	et	3	main
järve	doc_802069853755_item	2887661	et	4	main
etendus	doc_802069853755_item	2887662	et	4	main
etendusi	doc_802069853755_item	2887663	et	4	main
jalaluu	doc_802069853755_item	2887664	et	4	main
ja	doc_802069853755_item	2887665	et	3	main
pidama	doc_802069853755_item	2887666	et	4	main
pidama	doc_802069853755_item	2887667	et	4	main
mõnda	doc_802069853755_item	2887668	et	4	main
aega	doc_802069853755_item	2887669	et	4	main
tantsimisest	doc_802069853755_item	2887670	et	4	main
eemal	doc_802069853755_item	2887671	et	3	main
olema	doc_802069853755_item	2887672	et	4	main
on	doc_802069853755_item	2887673	et	4	main
tansijad	doc_802069853755_item	2887680	et	4	main
ainult	doc_802069853755_item	2887681	et	4	main
teineteisega	doc_802069853755_item	2887682	et	3	main
vaatamata	doc_802069853755_item	2887693	et	4	main
suurele	doc_802069853755_item	2887694	et	4	main
edule	doc_802069853755_item	2887695	et	3	main
lähiaja	doc_802069853755_item	2887701	et	3	main
on	doc_802069853755_item	2887703	et	4	main
täpselt	doc_802069853755_item	2887704	et	4	main
planeerima	doc_802069853755_item	2887705	et	3	main
ja	doc_802069853755_item	2887712	et	3	main
parem	doc_802069853755_item	2887714	et	4	main
paremad	doc_802069853755_item	2887715	et	4	main
tantsida	doc_802069853755_item	2887716	et	3	main
märtsis	doc_802069853755_item	2887717	et	3	main
seejärel	doc_802069853755_item	2887724	et	3	main
lõuna-aafrika	doc_802069853755_item	2887726	et	4	main
kui	doc_802069853755_item	2887728	et	3	main
kaua	doc_802069853755_item	2887729	et	3	main
ja	doc_802069853755_item	2887731	et	3	main
suudavad	doc_802069853755_item	2887735	et	3	main
püsida	doc_802069853755_item	2887736	et	3	main
eelistavad	doc_802069853755_item	2887743	et	4	main
päev	doc_802069853755_item	2887746	et	3	main
sulud	doc_802069853756_item	2887752	et	3	main
õige	doc_802069853756_item	2887757	et	4	main
vastus	doc_802069853756_item	2887758	et	3	main
annab	doc_802069853756_item	2887759	et	3	main
london	doc_802069853756_item	2887778	et	4	main
inglismaal	doc_802069853756_item	2887779	et	4	main
kolmkümne	doc_802069853756_item	2887790	et	4	main
üheksakümne	doc_802069853756_item	2887799	et	4	main
on	doc_802069853756_item	2887801	et	4	main
erinevad	doc_802069853756_item	2887809	et	4	main
armastama	doc_802069853756_item	2887812	et	3	main
ning	doc_802069853756_item	2887816	et	3	main
nendesse	doc_802069853756_item	2887822	et	4	main
artiklid	doc_802069853756_item	2887826	et	3	main
räägivad	doc_802069853756_item	2887827	et	3	main
noored	doc_802069853756_item	2887828	et	3	main
nooresed	doc_802069853756_item	2887829	et	4	main
sugugi	doc_802069853756_item	2887835	et	4	main
läinud	doc_802069853756_item	2887839	et	4	main
on	doc_802069853756_item	2887844	et	4	main
tervis	doc_802069853756_item	2887847	et	3	main
naine	doc_802069853756_item	2887854	et	3	main
luikede	doc_802069853756_item	2887855	et	3	main
jalaluu	doc_802069853756_item	2887859	et	4	main
tantsimisest	doc_802069853756_item	2887865	et	4	main
tantsivad	doc_802069853756_item	2887875	et	4	main
tantsimiseks	doc_802069853756_item	2887887	et	4	main
tantsijad	doc_802069853756_item	2887892	et	4	main
planeeritud	doc_802069853756_item	2887901	et	4	main
areneda	doc_802069853756_item	2887906	et	3	main
tagasihoidlikud	doc_802069853755_item	2887699	et	3	main
esinemised	doc_802069853755_item	2887702	et	4	main
tahavad	doc_802069853755_item	2887710	et	3	main
veelgi	doc_802069853755_item	2887713	et	4	main
tallinn	doc_802069853755_item	2887721	et	4	main
ja	doc_802069853755_item	2887723	et	3	main
sõidavad	doc_802069853755_item	2887725	et	3	main
lõuna-aafrikasse	doc_802069853755_item	2887727	et	4	main
oks	doc_802069853755_item	2887730	et	3	main
edur	doc_802069853755_item	2887732	et	4	main
nad	doc_802069853755_item	2887742	et	3	main
ühe	doc_802069853755_item	2887747	et	4	main
kaupa	doc_802069853755_item	2887749	et	4	main
avage	doc_802069853756_item	2887751	et	3	main
balletitantsijad	doc_802069853756_item	2887763	et	3	main
on	doc_802069853756_item	2887782	et	4	main
seitsmendal	doc_802069853756_item	2887800	et	3	main
ülivõrdes	doc_802069853756_item	2887831	et	3	main
kuid	doc_802069853756_item	2887832	et	4	main
kõik	doc_802069853756_item	2887833	et	4	main
pole	doc_802069853756_item	2887834	et	3	main
nii	doc_802069853756_item	2887837	et	3	main
mõlemal	doc_802069853756_item	2887840	et	3	main
1990	doc_802069853756_item	2887849	et	2	main
murdma	doc_802069853756_item	2887851	et	3	main
noor	doc_802069853756_item	2887853	et	3	main
järve	doc_802069853756_item	2887856	et	4	main
etendus	doc_802069853756_item	2887857	et	4	main
pidab	doc_802069853756_item	2887862	et	4	main
eemal	doc_802069853756_item	2887866	et	3	main
ainult	doc_802069853756_item	2887876	et	4	main
teineteisega	doc_802069853756_item	2887877	et	3	main
nemad	doc_802069853756_item	2887880	et	3	main
tehtud	doc_802069853756_item	2887883	et	4	main
ka	doc_802069853756_item	2887885	et	3	main
eraldi	doc_802069853756_item	2887886	et	4	main
suurele	doc_802069853756_item	2887889	et	4	main
lõuna-aafrikale	doc_802069853756_item	2887922	et	4	main
edur	doc_802069853756_item	2887927	et	4	main
veel	doc_802069853756_item	2887928	et	4	main
tipus	doc_802069853756_item	2887929	et	3	main
suudavad	doc_802069853756_item	2887930	et	3	main
püsida	doc_802069853756_item	2887931	et	3	main
eelistavad	doc_802069853756_item	2887938	et	4	main
harjutus	doc_802069853757_item	2887945	et	4	main
maailmakuulsad	doc_802069853757_item	2887957	et	3	main
oks	doc_802069853757_item	2887961	et	3	main
edur	doc_802069853757_item	2887964	et	4	main
pärit	doc_802069853757_item	2887966	et	3	main
eesti	doc_802069853757_item	2887967	et	4	main
eestis	doc_802069853757_item	2887968	et	3	main
aga	doc_802069853757_item	2887969	et	3	main
londonis	doc_802069853757_item	2887975	et	4	main
30	doc_802069853757_item	2887978	et	2	main
üheksasaja	doc_802069853757_item	2887992	et	4	main
seitse	doc_802069853757_item	2887994	et	3	main
ning	doc_802069853757_item	2888010	et	3	main
räägivad	doc_802069853757_item	2888021	et	3	main
pole	doc_802069853757_item	2888028	et	3	main
sugugi	doc_802069853757_item	2888029	et	4	main
nii	doc_802069853757_item	2888031	et	3	main
läinud	doc_802069853757_item	2888033	et	4	main
mõlemal	doc_802069853757_item	2888034	et	3	main
ja	doc_802069853757_item	2888035	et	3	main
eriti	doc_802069853757_item	2888036	et	3	main
murdma	doc_802069853757_item	2888045	et	3	main
luikede	doc_802069853757_item	2888049	et	3	main
etendus	doc_802069853757_item	2888051	et	4	main
etendusi	doc_802069853757_item	2888052	et	4	main
pakkumisi	doc_802069853757_item	2888078	et	4	main
ka	doc_802069853757_item	2888079	et	3	main
eraldi	doc_802069853757_item	2888080	et	4	main
lähiaja	doc_802069853757_item	2888090	et	3	main
planeerida	doc_802069853757_item	2888095	et	3	main
tahavad	doc_802069853757_item	2888099	et	3	main
ja	doc_802069853757_item	2888101	et	3	main
esinema	doc_802069853757_item	2888109	et	3	main
tallinnas	doc_802069853757_item	2888111	et	4	main
veel	doc_802069853757_item	2888122	et	4	main
kaupa	doc_802069853757_item	2888138	et	4	main
sõnadega	doc_802069853758_item	2888144	et	3	main
tallinnasse	doc_802069853755_item	2887722	et	3	main
veel	doc_802069853755_item	2887733	et	4	main
ei	doc_802069853755_item	2887737	et	4	main
päeva	doc_802069853755_item	2887748	et	4	main
harjutus	doc_802069853756_item	2887750	et	4	main
numbrid	doc_802069853756_item	2887753	et	3	main
kirjutage	doc_802069853756_item	2887754	et	3	main
sõnadega	doc_802069853756_item	2887755	et	3	main
iga	doc_802069853756_item	2887756	et	4	main
punkti	doc_802069853756_item	2887761	et	4	main
age	doc_802069853756_item	2887765	et	4	main
abielupaar	doc_802069853756_item	2887764	et	4	main
oks	doc_802069853756_item	2887766	et	3	main
ja	doc_802069853756_item	2887767	et	3	main
toomas	doc_802069853756_item	2887768	et	3	main
edur	doc_802069853756_item	2887769	et	4	main
on	doc_802069853756_item	2887770	et	4	main
pärit	doc_802069853756_item	2887771	et	3	main
eesti	doc_802069853756_item	2887772	et	4	main
eestis	doc_802069853756_item	2887773	et	3	main
aga	doc_802069853756_item	2887774	et	3	main
elavad	doc_802069853756_item	2887775	et	4	main
praegu	doc_802069853756_item	2887776	et	3	main
inglismaa	doc_802069853756_item	2887777	et	4	main
alates	doc_802069853756_item	2887794	et	3	main
üks	doc_802069853756_item	2887796	et	3	main
tuhat	doc_802069853756_item	2887797	et	4	main
vabakutseline	doc_802069853756_item	2887803	et	4	main
vabakutselised	doc_802069853756_item	2887804	et	4	main
ja	doc_802069853756_item	2887805	et	3	main
esinevad	doc_802069853756_item	2887806	et	4	main
inglismaal	doc_802069853756_item	2887811	et	4	main
armastavad	doc_802069853756_item	2887813	et	4	main
neid	doc_802069853756_item	2887814	et	4	main
väga	doc_802069853756_item	2887815	et	3	main
suhtlevad	doc_802069853756_item	2887821	et	4	main
üldiselt	doc_802069853756_item	2887823	et	4	main
hästi	doc_802069853756_item	2887824	et	3	main
viimased	doc_802069853756_item	2887825	et	3	main
ja	doc_802069853756_item	2887841	et	3	main
tervisest	doc_802069853756_item	2887848	et	4	main
aastal	doc_802069853756_item	2887850	et	3	main
pidama	doc_802069853756_item	2887861	et	4	main
mõnda	doc_802069853756_item	2887863	et	4	main
olema	doc_802069853756_item	2887867	et	4	main
pakkumisi	doc_802069853756_item	2887884	et	4	main
vaatamata	doc_802069853756_item	2887888	et	4	main
tagasihoidlijak	doc_802069853756_item	2887894	et	4	main
on	doc_802069853756_item	2887898	et	4	main
nad	doc_802069853756_item	2887934	et	3	main
ütlema	doc_802069853756_item	2887935	et	3	main
nad	doc_802069853756_item	2887937	et	3	main
elada	doc_802069853756_item	2887939	et	3	main
ühe	doc_802069853757_item	2887955	et	4	main
abielupaar	doc_802069853757_item	2887959	et	4	main
toomas	doc_802069853757_item	2887963	et	3	main
on	doc_802069853757_item	2887965	et	4	main
inglismaale	doc_802069853757_item	2887974	et	4	main
on	doc_802069853757_item	2887977	et	4	main
kolmekümne	doc_802069853757_item	2887979	et	4	main
aastane	doc_802069853757_item	2887980	et	4	main
vabakutselised	doc_802069853757_item	2887998	et	4	main
ja	doc_802069853757_item	2887999	et	3	main
armastasis	doc_802069853757_item	2888007	et	4	main
üldiselt	doc_802069853757_item	2888017	et	4	main
hästi	doc_802069853757_item	2888018	et	3	main
viimased	doc_802069853757_item	2888019	et	3	main
artiklid	doc_802069853757_item	2888020	et	3	main
alati	doc_802069853756_item	2887836	et	4	main
eriti	doc_802069853756_item	2887842	et	3	main
agel	doc_802069853756_item	2887843	et	4	main
olnud	doc_802069853756_item	2887845	et	4	main
probleeme	doc_802069853756_item	2887846	et	3	main
murdnud	doc_802069853756_item	2887852	et	4	main
ja	doc_802069853756_item	2887860	et	3	main
aega	doc_802069853756_item	2887864	et	4	main
on	doc_802069853756_item	2887868	et	4	main
age	doc_802069853756_item	2887869	et	4	main
ja	doc_802069853756_item	2887870	et	3	main
toomas	doc_802069853756_item	2887871	et	3	main
on	doc_802069853756_item	2887872	et	4	main
paaris	doc_802069853756_item	2887878	et	4	main
on	doc_802069853756_item	2887882	et	4	main
elavad	doc_802069853756_item	2887891	et	4	main
tagasihoidlik	doc_802069853756_item	2887893	et	3	main
täpselt	doc_802069853756_item	2887899	et	4	main
planeerima	doc_802069853756_item	2887900	et	3	main
ja	doc_802069853756_item	2887907	et	3	main
veelgi	doc_802069853756_item	2887908	et	4	main
parem	doc_802069853756_item	2887909	et	4	main
paremini	doc_802069853756_item	2887910	et	4	main
tantsida	doc_802069853756_item	2887911	et	3	main
märtsis	doc_802069853756_item	2887912	et	3	main
tulevad	doc_802069853756_item	2887913	et	4	main
nad	doc_802069853756_item	2887914	et	3	main
esinema	doc_802069853756_item	2887915	et	3	main
tallinn	doc_802069853756_item	2887916	et	4	main
tallinnas	doc_802069853756_item	2887917	et	4	main
ja	doc_802069853756_item	2887918	et	3	main
seejärel	doc_802069853756_item	2887919	et	3	main
sõidavad	doc_802069853756_item	2887920	et	3	main
kaua	doc_802069853756_item	2887924	et	3	main
oks	doc_802069853756_item	2887925	et	3	main
oska	doc_802069853756_item	2887933	et	4	main
ütelda	doc_802069853756_item	2887936	et	4	main
üks	doc_802069853756_item	2887942	et	3	main
päevas	doc_802069853756_item	2887943	et	3	main
balletitantsijad	doc_802069853757_item	2887958	et	3	main
london	doc_802069853757_item	2887973	et	4	main
toomas	doc_802069853757_item	2887982	et	3	main
on	doc_802069853757_item	2887983	et	4	main
tuhande	doc_802069853757_item	2887991	et	3	main
on	doc_802069853757_item	2887995	et	4	main
nad	doc_802069853757_item	2887996	et	3	main
vabakutseline	doc_802069853757_item	2887997	et	4	main
erinevaid	doc_802069853757_item	2888003	et	4	main
teatreid	doc_802069853757_item	2888004	et	3	main
inglismaal	doc_802069853757_item	2888005	et	4	main
armastama	doc_802069853757_item	2888006	et	3	main
karmid	doc_802069853757_item	2888012	et	4	main
suhtuvad	doc_802069853757_item	2888015	et	4	main
nendesse	doc_802069853757_item	2888016	et	4	main
noori	doc_802069853757_item	2888023	et	3	main
kuid	doc_802069853757_item	2888026	et	4	main
alati	doc_802069853757_item	2888030	et	4	main
kergelt	doc_802069853757_item	2888032	et	4	main
olnud	doc_802069853757_item	2888039	et	4	main
1990	doc_802069853757_item	2888043	et	2	main
mõnda	doc_802069853757_item	2888057	et	4	main
nemade	doc_802069853757_item	2888075	et	4	main
on	doc_802069853757_item	2888076	et	4	main
tantsimiseks	doc_802069853757_item	2888081	et	4	main
suurele	doc_802069853757_item	2888083	et	4	main
edule	doc_802069853757_item	2888084	et	3	main
elavad	doc_802069853757_item	2888085	et	4	main
ei	doc_802069853756_item	2887932	et	4	main
päev	doc_802069853756_item	2887941	et	3	main
numbrid	doc_802069853757_item	2887948	et	3	main
kirjutage	doc_802069853757_item	2887949	et	3	main
sõnadega	doc_802069853757_item	2887950	et	3	main
iga	doc_802069853757_item	2887951	et	4	main
õige	doc_802069853757_item	2887952	et	4	main
vastus	doc_802069853757_item	2887953	et	3	main
punkti	doc_802069853757_item	2887956	et	4	main
age	doc_802069853757_item	2887960	et	4	main
ja	doc_802069853757_item	2887962	et	3	main
inglismaa	doc_802069853757_item	2887972	et	4	main
age	doc_802069853757_item	2887976	et	4	main
1997a	doc_802069853757_item	2887990	et	4	main
üheksakümend	doc_802069853757_item	2887993	et	4	main
erinevad	doc_802069853757_item	2888001	et	4	main
teatrid	doc_802069853757_item	2888002	et	3	main
väga	doc_802069853757_item	2888009	et	3	main
kriitikud	doc_802069853757_item	2888013	et	3	main
ainult	doc_802069853757_item	2888024	et	4	main
on	doc_802069853757_item	2888038	et	4	main
noor	doc_802069853757_item	2888047	et	3	main
naine	doc_802069853757_item	2888048	et	3	main
järve	doc_802069853757_item	2888050	et	4	main
jalaluu	doc_802069853757_item	2888053	et	4	main
ja	doc_802069853757_item	2888054	et	3	main
tehtud	doc_802069853757_item	2888077	et	4	main
täpselt	doc_802069853757_item	2888093	et	4	main
areneda	doc_802069853757_item	2888100	et	3	main
tulevad	doc_802069853757_item	2888107	et	4	main
sõidavad	doc_802069853757_item	2888114	et	3	main
ei	doc_802069853757_item	2888126	et	4	main
nad	doc_802069853757_item	2888128	et	3	main
päeva	doc_802069853757_item	2888137	et	4	main
kirjutage	doc_802069853758_item	2888143	et	3	main
ja	doc_802069853758_item	2888175	et	3	main
toomas	doc_802069853758_item	2888176	et	3	main
kaks	doc_802069853758_item	2888180	et	3	main
vana	doc_802069853758_item	2888182	et	4	main
on	doc_802069853758_item	2888189	et	4	main
nad	doc_802069853758_item	2888190	et	3	main
kuid	doc_802069853758_item	2888220	et	4	main
elavad	doc_802069853757_item	2887970	et	4	main
praegu	doc_802069853757_item	2887971	et	3	main
ja	doc_802069853757_item	2887981	et	3	main
32	doc_802069853757_item	2887984	et	2	main
kahe	doc_802069853757_item	2887985	et	3	main
kolmekümne	doc_802069853757_item	2887986	et	4	main
aastat	doc_802069853757_item	2887987	et	3	main
vana	doc_802069853757_item	2887988	et	4	main
alates	doc_802069853757_item	2887989	et	3	main
esinevad	doc_802069853757_item	2888000	et	4	main
neid	doc_802069853757_item	2888008	et	4	main
isegi	doc_802069853757_item	2888011	et	4	main
suhtuma	doc_802069853757_item	2888014	et	3	main
noored	doc_802069853757_item	2888022	et	3	main
kõik	doc_802069853757_item	2888027	et	4	main
probleeme	doc_802069853757_item	2888040	et	3	main
tervis	doc_802069853757_item	2888041	et	3	main
tervisega	doc_802069853757_item	2888042	et	3	main
aastal	doc_802069853757_item	2888044	et	3	main
pidanud	doc_802069853757_item	2888056	et	4	main
paaris	doc_802069853757_item	2888072	et	4	main
kuigi	doc_802069853757_item	2888073	et	3	main
nemad	doc_802069853757_item	2888074	et	3	main
vaatamata	doc_802069853757_item	2888082	et	4	main
planeerima	doc_802069853757_item	2888094	et	3	main
age	doc_802069853757_item	2888096	et	4	main
toomas	doc_802069853757_item	2888098	et	3	main
veelgi	doc_802069853757_item	2888102	et	4	main
parem	doc_802069853757_item	2888103	et	4	main
paremeni	doc_802069853757_item	2888104	et	4	main
tantsida	doc_802069853757_item	2888105	et	3	main
märtsis	doc_802069853757_item	2888106	et	3	main
tallinn	doc_802069853757_item	2888110	et	4	main
ja	doc_802069853757_item	2888112	et	3	main
seejärel	doc_802069853757_item	2888113	et	3	main
lõuna-aafrika	doc_802069853757_item	2888115	et	4	main
lõuna-aafrikasse	doc_802069853757_item	2888116	et	4	main
kui	doc_802069853757_item	2888117	et	3	main
kaua	doc_802069853757_item	2888118	et	3	main
oks	doc_802069853757_item	2888119	et	3	main
ja	doc_802069853757_item	2888120	et	3	main
ülivõrdes	doc_802069853757_item	2888025	et	3	main
agel	doc_802069853757_item	2888037	et	4	main
murdis	doc_802069853757_item	2888046	et	3	main
pidama	doc_802069853757_item	2888055	et	4	main
aega	doc_802069853757_item	2888058	et	4	main
tantsimisest	doc_802069853757_item	2888059	et	4	main
eemal	doc_802069853757_item	2888060	et	3	main
olema	doc_802069853757_item	2888061	et	4	main
oli	doc_802069853757_item	2888062	et	3	main
age	doc_802069853757_item	2888063	et	4	main
ja	doc_802069853757_item	2888064	et	3	main
toomas	doc_802069853757_item	2888065	et	3	main
on	doc_802069853757_item	2888066	et	4	main
otsustanud	doc_802069853757_item	2888067	et	4	main
tantsima	doc_802069853757_item	2888068	et	3	main
tantsida	doc_802069853757_item	2888069	et	3	main
ainult	doc_802069853757_item	2888070	et	4	main
teineteisega	doc_802069853757_item	2888071	et	3	main
tantsijad	doc_802069853757_item	2888086	et	4	main
tagasihoidlik	doc_802069853757_item	2888087	et	3	main
tagasihoidliku	doc_802069853757_item	2888088	et	3	main
nende	doc_802069853757_item	2888089	et	4	main
on	doc_802069853757_item	2888092	et	4	main
püsida	doc_802069853757_item	2888125	et	3	main
oska	doc_802069853757_item	2888127	et	4	main
päev	doc_802069853757_item	2888135	et	3	main
ühe	doc_802069853757_item	2888136	et	4	main
numbrid	doc_802069853758_item	2888142	et	3	main
iga	doc_802069853758_item	2888145	et	4	main
vastus	doc_802069853758_item	2888147	et	3	main
annab	doc_802069853758_item	2888148	et	3	main
edur	doc_802069853758_item	2888158	et	4	main
on	doc_802069853758_item	2888159	et	4	main
1997a	doc_802069853758_item	2888184	et	4	main
tuhat	doc_802069853758_item	2888185	et	4	main
üheksakümne	doc_802069853758_item	2888187	et	4	main
seitsmest	doc_802069853758_item	2888188	et	4	main
erinevad	doc_802069853758_item	2888195	et	4	main
teatrid	doc_802069853758_item	2888196	et	3	main
inglismaal	doc_802069853758_item	2888199	et	4	main
suhtuvad	doc_802069853758_item	2888209	et	4	main
nendesse	doc_802069853758_item	2888210	et	4	main
alati	doc_802069853758_item	2888224	et	4	main
ja	doc_802069853758_item	2888229	et	3	main
agel	doc_802069853758_item	2888231	et	4	main
pidama	doc_802069853758_item	2888249	et	4	main
tantsimisest	doc_802069853758_item	2888253	et	4	main
eemal	doc_802069853758_item	2888254	et	3	main
olema	doc_802069853758_item	2888255	et	4	main
olla	doc_802069853758_item	2888256	et	3	main
tantsima	doc_802069853758_item	2888262	et	3	main
tantsida	doc_802069853758_item	2888263	et	3	main
nemad	doc_802069853758_item	2888268	et	3	main
nende	doc_802069853758_item	2888283	et	4	main
lähiaja	doc_802069853758_item	2888284	et	3	main
esinemised	doc_802069853758_item	2888285	et	4	main
paremini	doc_802069853758_item	2888298	et	4	main
tantsida	doc_802069853758_item	2888299	et	3	main
märtsis	doc_802069853758_item	2888300	et	3	main
tulevad	doc_802069853758_item	2888301	et	4	main
nad	doc_802069853758_item	2888302	et	3	main
öelda	doc_802069853758_item	2888324	et	4	main
iga	doc_802069853759_item	2888339	et	4	main
vastus	doc_802069853759_item	2888341	et	3	main
balletitantsijad	doc_802069853759_item	2888346	et	3	main
edur	doc_802069853759_item	2888352	et	4	main
on	doc_802069853759_item	2888353	et	4	main
pärit	doc_802069853759_item	2888354	et	3	main
inglismaal	doc_802069853759_item	2888362	et	4	main
vabakutselised	doc_802069853759_item	2888385	et	4	main
armastavad	doc_802069853759_item	2888394	et	4	main
neid	doc_802069853759_item	2888395	et	4	main
väga	doc_802069853759_item	2888396	et	3	main
ning	doc_802069853759_item	2888397	et	3	main
esinemised	doc_802069853757_item	2888091	et	4	main
ja	doc_802069853757_item	2888097	et	3	main
nad	doc_802069853757_item	2888108	et	3	main
edur	doc_802069853757_item	2888121	et	4	main
suudavad	doc_802069853757_item	2888124	et	3	main
ütelda	doc_802069853757_item	2888130	et	4	main
nad	doc_802069853757_item	2888131	et	3	main
harjutus	doc_802069853758_item	2888139	et	4	main
avage	doc_802069853758_item	2888140	et	3	main
abielupaar	doc_802069853758_item	2888153	et	4	main
age	doc_802069853758_item	2888154	et	4	main
oks	doc_802069853758_item	2888155	et	3	main
ja	doc_802069853758_item	2888156	et	3	main
on	doc_802069853758_item	2888177	et	4	main
erinevates	doc_802069853758_item	2888197	et	4	main
armastama	doc_802069853758_item	2888200	et	3	main
neid	doc_802069853758_item	2888202	et	4	main
väga	doc_802069853758_item	2888203	et	3	main
ning	doc_802069853758_item	2888204	et	3	main
isegi	doc_802069853758_item	2888205	et	4	main
karmid	doc_802069853758_item	2888206	et	4	main
kriitikud	doc_802069853758_item	2888207	et	3	main
suhtuma	doc_802069853758_item	2888208	et	3	main
kõik	doc_802069853758_item	2888221	et	4	main
sugugi	doc_802069853758_item	2888223	et	4	main
pidi	doc_802069853758_item	2888250	et	4	main
age	doc_802069853758_item	2888257	et	4	main
ja	doc_802069853758_item	2888258	et	3	main
on	doc_802069853758_item	2888260	et	4	main
paaris	doc_802069853758_item	2888266	et	4	main
on	doc_802069853758_item	2888286	et	4	main
age	doc_802069853758_item	2888290	et	4	main
ja	doc_802069853758_item	2888291	et	3	main
toomas	doc_802069853758_item	2888292	et	3	main
tahavad	doc_802069853758_item	2888293	et	3	main
esinema	doc_802069853758_item	2888303	et	3	main
tallinn	doc_802069853758_item	2888304	et	4	main
tallinnas	doc_802069853758_item	2888305	et	4	main
ja	doc_802069853758_item	2888306	et	3	main
suudavad	doc_802069853758_item	2888318	et	3	main
püsida	doc_802069853758_item	2888319	et	3	main
ei	doc_802069853758_item	2888320	et	4	main
nad	doc_802069853758_item	2888322	et	3	main
eelistavad	doc_802069853758_item	2888326	et	4	main
päev	doc_802069853758_item	2888329	et	3	main
päeva	doc_802069853758_item	2888331	et	4	main
kaupa	doc_802069853758_item	2888332	et	4	main
annab	doc_802069853759_item	2888342	et	3	main
maailmakuulsad	doc_802069853759_item	2888345	et	3	main
eesti	doc_802069853759_item	2888355	et	4	main
eestist	doc_802069853759_item	2888356	et	3	main
aga	doc_802069853759_item	2888357	et	3	main
elavad	doc_802069853759_item	2888358	et	4	main
praegu	doc_802069853759_item	2888359	et	3	main
aastane	doc_802069853759_item	2888368	et	4	main
32	doc_802069853759_item	2888372	et	2	main
üheksakümend	doc_802069853759_item	2888380	et	4	main
on	doc_802069853759_item	2888382	et	4	main
vabakutseline	doc_802069853759_item	2888384	et	4	main
esinevad	doc_802069853759_item	2888387	et	4	main
erinevatest	doc_802069853759_item	2888390	et	4	main
mõlemal	doc_802069853759_item	2888421	et	3	main
mõnda	doc_802069853759_item	2888444	et	4	main
on	doc_802069853759_item	2888453	et	4	main
tehtud	doc_802069853759_item	2888464	et	4	main
edule	doc_802069853759_item	2888471	et	3	main
tantsijad	doc_802069853759_item	2888473	et	4	main
nende	doc_802069853759_item	2888476	et	4	main
lähiaja	doc_802069853759_item	2888477	et	3	main
age	doc_802069853759_item	2888483	et	4	main
ja	doc_802069853759_item	2888484	et	3	main
toomas	doc_802069853759_item	2888485	et	3	main
tahavad	doc_802069853759_item	2888486	et	3	main
areneda	doc_802069853759_item	2888487	et	3	main
ja	doc_802069853759_item	2888488	et	3	main
tallinn	doc_802069853759_item	2888497	et	4	main
tallinnasse	doc_802069853759_item	2888498	et	3	main
ja	doc_802069853759_item	2888499	et	3	main
oks	doc_802069853759_item	2888506	et	3	main
veel	doc_802069853759_item	2888509	et	4	main
ei	doc_802069853759_item	2888513	et	4	main
oska	doc_802069853759_item	2888514	et	4	main
tipus	doc_802069853757_item	2888123	et	3	main
ütlema	doc_802069853757_item	2888129	et	3	main
eelistavad	doc_802069853757_item	2888132	et	4	main
elada	doc_802069853757_item	2888133	et	3	main
üks	doc_802069853757_item	2888134	et	3	main
sulud	doc_802069853758_item	2888141	et	3	main
õige	doc_802069853758_item	2888146	et	4	main
toomas	doc_802069853758_item	2888157	et	3	main
eesti	doc_802069853758_item	2888161	et	4	main
eestist	doc_802069853758_item	2888162	et	3	main
aga	doc_802069853758_item	2888163	et	3	main
elavad	doc_802069853758_item	2888164	et	4	main
praegu	doc_802069853758_item	2888165	et	3	main
inglismaa	doc_802069853758_item	2888166	et	4	main
london	doc_802069853758_item	2888167	et	4	main
inglismaal	doc_802069853758_item	2888168	et	4	main
londonis	doc_802069853758_item	2888169	et	4	main
age	doc_802069853758_item	2888170	et	4	main
on	doc_802069853758_item	2888171	et	4	main
30	doc_802069853758_item	2888172	et	2	main
kolmekümne	doc_802069853758_item	2888173	et	4	main
aastane	doc_802069853758_item	2888174	et	4	main
ühe	doc_802069853758_item	2888149	et	4	main
punkti	doc_802069853758_item	2888150	et	4	main
maailmakuulsad	doc_802069853758_item	2888151	et	3	main
balletitantsijad	doc_802069853758_item	2888152	et	3	main
pärit	doc_802069853758_item	2888160	et	3	main
32	doc_802069853758_item	2888178	et	2	main
üheksasada	doc_802069853758_item	2888186	et	4	main
teatrides	doc_802069853758_item	2888198	et	4	main
armastavad	doc_802069853758_item	2888201	et	4	main
nii	doc_802069853758_item	2888225	et	3	main
läinud	doc_802069853758_item	2888227	et	4	main
luikede	doc_802069853758_item	2888243	et	3	main
teineteisega	doc_802069853758_item	2888265	et	3	main
kuigi	doc_802069853758_item	2888267	et	3	main
planeerima	doc_802069853758_item	2888288	et	3	main
planeeritud	doc_802069853758_item	2888289	et	4	main
areneda	doc_802069853758_item	2888294	et	3	main
ja	doc_802069853758_item	2888295	et	3	main
veelgi	doc_802069853758_item	2888296	et	4	main
veel	doc_802069853758_item	2888316	et	4	main
tipus	doc_802069853758_item	2888317	et	3	main
ütlema	doc_802069853758_item	2888323	et	3	main
elada	doc_802069853758_item	2888327	et	3	main
üks	doc_802069853758_item	2888328	et	3	main
sulud	doc_802069853759_item	2888335	et	3	main
kirjutage	doc_802069853759_item	2888337	et	3	main
ühe	doc_802069853759_item	2888343	et	4	main
age	doc_802069853759_item	2888348	et	4	main
inglismaa	doc_802069853759_item	2888360	et	4	main
londonis	doc_802069853759_item	2888363	et	4	main
toomas	doc_802069853759_item	2888370	et	3	main
on	doc_802069853759_item	2888371	et	4	main
kolmküment	doc_802069853759_item	2888373	et	4	main
kaks	doc_802069853759_item	2888374	et	3	main
aastat	doc_802069853759_item	2888375	et	3	main
vana	doc_802069853759_item	2888376	et	4	main
alates	doc_802069853759_item	2888377	et	3	main
tuhande	doc_802069853759_item	2888378	et	3	main
seitsemdast	doc_802069853759_item	2888381	et	4	main
nad	doc_802069853759_item	2888383	et	3	main
teatrid	doc_802069853759_item	2888389	et	3	main
teatridest	doc_802069853759_item	2888391	et	4	main
agel	doc_802069853759_item	2888424	et	4	main
noor	doc_802069853759_item	2888434	et	3	main
luikede	doc_802069853759_item	2888436	et	3	main
olema	doc_802069853759_item	2888448	et	4	main
olla	doc_802069853759_item	2888449	et	3	main
paaris	doc_802069853759_item	2888459	et	4	main
kuigi	doc_802069853759_item	2888460	et	3	main
nemad	doc_802069853759_item	2888461	et	3	main
eraldi	doc_802069853759_item	2888467	et	4	main
sõidavad	doc_802069853759_item	2888501	et	3	main
kui	doc_802069853759_item	2888504	et	3	main
ja	doc_802069853759_item	2888507	et	3	main
suudavad	doc_802069853759_item	2888511	et	3	main
kolmkümmend	doc_802069853758_item	2888179	et	4	main
aastat	doc_802069853758_item	2888181	et	3	main
alates	doc_802069853758_item	2888183	et	3	main
vabakutseline	doc_802069853758_item	2888191	et	4	main
vabakutselised	doc_802069853758_item	2888192	et	4	main
ja	doc_802069853758_item	2888193	et	3	main
esinevad	doc_802069853758_item	2888194	et	4	main
üldiselt	doc_802069853758_item	2888211	et	4	main
hästi	doc_802069853758_item	2888212	et	3	main
viimased	doc_802069853758_item	2888213	et	3	main
artiklid	doc_802069853758_item	2888214	et	3	main
räägivad	doc_802069853758_item	2888215	et	3	main
noored	doc_802069853758_item	2888216	et	3	main
noortest	doc_802069853758_item	2888217	et	4	main
ainult	doc_802069853758_item	2888218	et	4	main
ülivõrdes	doc_802069853758_item	2888219	et	3	main
pole	doc_802069853758_item	2888222	et	3	main
kergelt	doc_802069853758_item	2888226	et	4	main
mõlemal	doc_802069853758_item	2888228	et	3	main
eriti	doc_802069853758_item	2888230	et	3	main
on	doc_802069853758_item	2888232	et	4	main
järve	doc_802069853758_item	2888244	et	4	main
etenduses	doc_802069853758_item	2888246	et	4	main
jalaluu	doc_802069853758_item	2888247	et	4	main
ja	doc_802069853758_item	2888248	et	3	main
otsustanud	doc_802069853758_item	2888261	et	4	main
täpselt	doc_802069853758_item	2888287	et	4	main
lõuna-aafrikasse	doc_802069853758_item	2888310	et	4	main
kui	doc_802069853758_item	2888311	et	3	main
kaua	doc_802069853758_item	2888312	et	3	main
oks	doc_802069853758_item	2888313	et	3	main
ja	doc_802069853758_item	2888314	et	3	main
edur	doc_802069853758_item	2888315	et	4	main
oska	doc_802069853758_item	2888321	et	4	main
harjutus	doc_802069853759_item	2888333	et	4	main
avage	doc_802069853759_item	2888334	et	3	main
numbrid	doc_802069853759_item	2888336	et	3	main
punkti	doc_802069853759_item	2888344	et	4	main
london	doc_802069853759_item	2888361	et	4	main
age	doc_802069853759_item	2888364	et	4	main
on	doc_802069853759_item	2888365	et	4	main
30	doc_802069853759_item	2888366	et	2	main
ja	doc_802069853759_item	2888369	et	3	main
üheksasaja	doc_802069853759_item	2888379	et	4	main
ja	doc_802069853759_item	2888386	et	3	main
erinevad	doc_802069853759_item	2888388	et	4	main
eriti	doc_802069853759_item	2888423	et	3	main
olnud	doc_802069853759_item	2888426	et	4	main
tervis	doc_802069853759_item	2888428	et	3	main
1990	doc_802069853759_item	2888430	et	2	main
murdus	doc_802069853759_item	2888433	et	3	main
etendus	doc_802069853759_item	2888438	et	4	main
etenduse	doc_802069853759_item	2888439	et	4	main
pidama	doc_802069853759_item	2888442	et	4	main
pidas	doc_802069853759_item	2888443	et	3	main
age	doc_802069853759_item	2888450	et	4	main
ja	doc_802069853759_item	2888451	et	3	main
toomas	doc_802069853759_item	2888452	et	3	main
nad	doc_802069853759_item	2888462	et	3	main
on	doc_802069853759_item	2888463	et	4	main
tantsimiseks	doc_802069853759_item	2888468	et	4	main
esinemised	doc_802069853759_item	2888478	et	4	main
veelgi	doc_802069853759_item	2888489	et	4	main
parem	doc_802069853759_item	2888490	et	4	main
parem	doc_802069853759_item	2888491	et	4	main
tantsida	doc_802069853759_item	2888492	et	3	main
märtsis	doc_802069853759_item	2888493	et	3	main
tulevad	doc_802069853759_item	2888494	et	4	main
nad	doc_802069853759_item	2888495	et	3	main
esinema	doc_802069853759_item	2888496	et	3	main
lõuna-aafrika	doc_802069853759_item	2888502	et	4	main
kaua	doc_802069853759_item	2888505	et	3	main
öelda	doc_802069853759_item	2888517	et	4	main
ühe	doc_802069853759_item	2888523	et	4	main
numbrid	doc_802069853760_item	2888529	et	3	main
maailmakuulsad	doc_802069853760_item	2888538	et	3	main
ja	doc_802069853760_item	2888543	et	3	main
eestist	doc_802069853760_item	2888549	et	3	main
esinevad	doc_802069853760_item	2888577	et	4	main
teatrid	doc_802069853760_item	2888579	et	3	main
inglismaal	doc_802069853760_item	2888580	et	4	main
olnud	doc_802069853758_item	2888233	et	4	main
probleeme	doc_802069853758_item	2888234	et	3	main
tervis	doc_802069853758_item	2888235	et	3	main
tervisega	doc_802069853758_item	2888236	et	3	main
1990	doc_802069853758_item	2888237	et	2	main
aastal	doc_802069853758_item	2888238	et	3	main
murdma	doc_802069853758_item	2888239	et	3	main
murdas	doc_802069853758_item	2888240	et	4	main
noor	doc_802069853758_item	2888241	et	3	main
naine	doc_802069853758_item	2888242	et	3	main
etendus	doc_802069853758_item	2888245	et	4	main
mõnda	doc_802069853758_item	2888251	et	4	main
aega	doc_802069853758_item	2888252	et	4	main
toomas	doc_802069853758_item	2888259	et	3	main
ainult	doc_802069853758_item	2888264	et	4	main
nad	doc_802069853758_item	2888269	et	3	main
on	doc_802069853758_item	2888270	et	4	main
tehtud	doc_802069853758_item	2888271	et	4	main
pakkumisi	doc_802069853758_item	2888272	et	4	main
ka	doc_802069853758_item	2888273	et	3	main
eraldi	doc_802069853758_item	2888274	et	4	main
tantsimiseks	doc_802069853758_item	2888275	et	4	main
vaatamata	doc_802069853758_item	2888276	et	4	main
suurele	doc_802069853758_item	2888277	et	4	main
edule	doc_802069853758_item	2888278	et	3	main
elavad	doc_802069853758_item	2888279	et	4	main
tantsijad	doc_802069853758_item	2888280	et	4	main
tagasihoidlik	doc_802069853758_item	2888281	et	3	main
tagasihoidlikult	doc_802069853758_item	2888282	et	4	main
parem	doc_802069853758_item	2888297	et	4	main
seejärel	doc_802069853758_item	2888307	et	3	main
sõidavad	doc_802069853758_item	2888308	et	3	main
lõuna-aafrika	doc_802069853758_item	2888309	et	4	main
nad	doc_802069853758_item	2888325	et	3	main
ühe	doc_802069853758_item	2888330	et	4	main
sõnadega	doc_802069853759_item	2888338	et	3	main
õige	doc_802069853759_item	2888340	et	4	main
abielupaar	doc_802069853759_item	2888347	et	4	main
oks	doc_802069853759_item	2888349	et	3	main
ja	doc_802069853759_item	2888350	et	3	main
toomas	doc_802069853759_item	2888351	et	3	main
kolmekümne	doc_802069853759_item	2888367	et	4	main
inglismaal	doc_802069853759_item	2888392	et	4	main
armastama	doc_802069853759_item	2888393	et	3	main
isegi	doc_802069853759_item	2888398	et	4	main
karmid	doc_802069853759_item	2888399	et	4	main
kriitikud	doc_802069853759_item	2888400	et	3	main
suhtuma	doc_802069853759_item	2888401	et	3	main
suhtuvad	doc_802069853759_item	2888402	et	4	main
nendesse	doc_802069853759_item	2888403	et	4	main
üldiselt	doc_802069853759_item	2888404	et	4	main
hästi	doc_802069853759_item	2888405	et	3	main
viimased	doc_802069853759_item	2888406	et	3	main
artiklid	doc_802069853759_item	2888407	et	3	main
räägivad	doc_802069853759_item	2888408	et	3	main
noored	doc_802069853759_item	2888409	et	3	main
noortele	doc_802069853759_item	2888410	et	3	main
ainult	doc_802069853759_item	2888411	et	4	main
ülivõrdes	doc_802069853759_item	2888412	et	3	main
kuid	doc_802069853759_item	2888413	et	4	main
kõik	doc_802069853759_item	2888414	et	4	main
pole	doc_802069853759_item	2888415	et	3	main
sugugi	doc_802069853759_item	2888416	et	4	main
alati	doc_802069853759_item	2888417	et	4	main
nii	doc_802069853759_item	2888418	et	3	main
kergelt	doc_802069853759_item	2888419	et	4	main
läinud	doc_802069853759_item	2888420	et	4	main
ja	doc_802069853759_item	2888422	et	3	main
probleeme	doc_802069853759_item	2888427	et	3	main
tervisega	doc_802069853759_item	2888429	et	3	main
murdma	doc_802069853759_item	2888432	et	3	main
järve	doc_802069853759_item	2888437	et	4	main
jalaluu	doc_802069853759_item	2888440	et	4	main
ja	doc_802069853759_item	2888441	et	3	main
otsustanud	doc_802069853759_item	2888454	et	4	main
tantsima	doc_802069853759_item	2888455	et	3	main
tantsida	doc_802069853759_item	2888456	et	3	main
ainult	doc_802069853759_item	2888457	et	4	main
teineteisega	doc_802069853759_item	2888458	et	3	main
suurele	doc_802069853759_item	2888470	et	4	main
elavad	doc_802069853759_item	2888472	et	4	main
tagasihoidlik	doc_802069853759_item	2888474	et	3	main
tagasihoidlikult	doc_802069853759_item	2888475	et	4	main
seejärel	doc_802069853759_item	2888500	et	3	main
nad	doc_802069853759_item	2888518	et	3	main
päev	doc_802069853759_item	2888522	et	3	main
avage	doc_802069853760_item	2888527	et	3	main
sõnadega	doc_802069853760_item	2888531	et	3	main
punkti	doc_802069853760_item	2888537	et	4	main
abielupaar	doc_802069853760_item	2888540	et	4	main
oks	doc_802069853760_item	2888542	et	3	main
on	doc_802069853759_item	2888425	et	4	main
aastal	doc_802069853759_item	2888431	et	3	main
naine	doc_802069853759_item	2888435	et	3	main
aega	doc_802069853759_item	2888445	et	4	main
tantsimisest	doc_802069853759_item	2888446	et	4	main
eemal	doc_802069853759_item	2888447	et	3	main
pakkumisi	doc_802069853759_item	2888465	et	4	main
ka	doc_802069853759_item	2888466	et	3	main
vaatamata	doc_802069853759_item	2888469	et	4	main
on	doc_802069853759_item	2888479	et	4	main
täpselt	doc_802069853759_item	2888480	et	4	main
planeerima	doc_802069853759_item	2888481	et	3	main
planeeritud	doc_802069853759_item	2888482	et	4	main
lõuna-aafrikasse	doc_802069853759_item	2888503	et	4	main
edur	doc_802069853759_item	2888508	et	4	main
tipus	doc_802069853759_item	2888510	et	3	main
püsida	doc_802069853759_item	2888512	et	3	main
eelistavad	doc_802069853759_item	2888519	et	4	main
harjutus	doc_802069853760_item	2888526	et	4	main
kirjutage	doc_802069853760_item	2888530	et	3	main
ühe	doc_802069853760_item	2888536	et	4	main
aga	doc_802069853760_item	2888550	et	3	main
praegu	doc_802069853760_item	2888552	et	3	main
inglismaa	doc_802069853760_item	2888553	et	4	main
london	doc_802069853760_item	2888554	et	4	main
inglismaas	doc_802069853760_item	2888555	et	3	main
on	doc_802069853760_item	2888558	et	4	main
kolmkümmend	doc_802069853760_item	2888566	et	4	main
kaks	doc_802069853760_item	2888567	et	3	main
aastat	doc_802069853760_item	2888568	et	3	main
1997a	doc_802069853760_item	2888571	et	4	main
on	doc_802069853760_item	2888572	et	4	main
nad	doc_802069853760_item	2888573	et	3	main
väga	doc_802069853760_item	2888584	et	3	main
ning	doc_802069853760_item	2888585	et	3	main
isegi	doc_802069853760_item	2888586	et	4	main
artiklid	doc_802069853760_item	2888595	et	3	main
alati	doc_802069853760_item	2888604	et	4	main
nii	doc_802069853760_item	2888605	et	3	main
murdma	doc_802069853760_item	2888619	et	3	main
naine	doc_802069853760_item	2888621	et	3	main
järve	doc_802069853760_item	2888623	et	4	main
olema	doc_802069853760_item	2888632	et	4	main
age	doc_802069853760_item	2888633	et	4	main
ja	doc_802069853760_item	2888634	et	3	main
toomas	doc_802069853760_item	2888635	et	3	main
ainult	doc_802069853760_item	2888639	et	4	main
tehtud	doc_802069853760_item	2888645	et	4	main
tulevad	doc_802069853760_item	2888672	et	4	main
nad	doc_802069853760_item	2888673	et	3	main
esinema	doc_802069853760_item	2888674	et	3	main
lõuna-aafrika	doc_802069853760_item	2888679	et	4	main
kaua	doc_802069853760_item	2888681	et	3	main
ja	doc_802069853760_item	2888683	et	3	main
veel	doc_802069853760_item	2888685	et	4	main
ja	doc_802069853761_item	2888716	et	3	main
pärit	doc_802069853761_item	2888720	et	3	main
aga	doc_802069853761_item	2888723	et	3	main
inglismaa	doc_802069853761_item	2888726	et	4	main
london	doc_802069853761_item	2888727	et	4	main
on	doc_802069853761_item	2888731	et	4	main
aastane	doc_802069853761_item	2888734	et	4	main
kolmkümend	doc_802069853761_item	2888739	et	4	main
kaks	doc_802069853761_item	2888740	et	3	main
aastat	doc_802069853761_item	2888741	et	3	main
on	doc_802069853761_item	2888749	et	4	main
nad	doc_802069853761_item	2888750	et	3	main
ja	doc_802069853761_item	2888753	et	3	main
väga	doc_802069853761_item	2888763	et	3	main
tervis	doc_802069853761_item	2888795	et	3	main
pidama	doc_802069853761_item	2888809	et	4	main
tantsimisest	doc_802069853761_item	2888813	et	4	main
olema	doc_802069853761_item	2888815	et	4	main
on	doc_802069853761_item	2888830	et	4	main
vaatamata	doc_802069853761_item	2888836	et	4	main
lähiaja	doc_802069853761_item	2888844	et	3	main
esinemised	doc_802069853761_item	2888845	et	4	main
esinema	doc_802069853761_item	2888863	et	3	main
tallinn	doc_802069853761_item	2888864	et	4	main
oks	doc_802069853761_item	2888873	et	3	main
veel	doc_802069853761_item	2888876	et	4	main
püsida	doc_802069853761_item	2888879	et	3	main
üks	doc_802069853761_item	2888888	et	3	main
ühe	doc_802069853761_item	2888890	et	4	main
kaupa	doc_802069853761_item	2888892	et	4	main
saada	doc_802069853762_item	2888916	et	4	main
seal	doc_802069853762_item	2888920	et	4	main
ning	doc_802069853762_item	2888940	et	3	main
nad	doc_802069853759_item	2888515	et	3	main
ütlema	doc_802069853759_item	2888516	et	3	main
elada	doc_802069853759_item	2888520	et	3	main
kaupa	doc_802069853759_item	2888525	et	4	main
õige	doc_802069853760_item	2888533	et	4	main
eesti	doc_802069853760_item	2888548	et	4	main
on	doc_802069853760_item	2888564	et	4	main
32	doc_802069853760_item	2888565	et	2	main
vabakutseline	doc_802069853760_item	2888574	et	4	main
karmid	doc_802069853760_item	2888587	et	4	main
kriitikud	doc_802069853760_item	2888588	et	3	main
suhtuma	doc_802069853760_item	2888589	et	3	main
suhtuda	doc_802069853760_item	2888590	et	3	main
räägivad	doc_802069853760_item	2888596	et	3	main
ainult	doc_802069853760_item	2888598	et	4	main
kergelt	doc_802069853760_item	2888606	et	4	main
on	doc_802069853760_item	2888612	et	4	main
tervis	doc_802069853760_item	2888615	et	3	main
ja	doc_802069853760_item	2888626	et	3	main
on	doc_802069853760_item	2888636	et	4	main
tantsima	doc_802069853760_item	2888638	et	3	main
pakkumisi	doc_802069853760_item	2888646	et	4	main
eraldi	doc_802069853760_item	2888648	et	4	main
on	doc_802069853760_item	2888659	et	4	main
age	doc_802069853760_item	2888662	et	4	main
toomas	doc_802069853760_item	2888664	et	3	main
seejärel	doc_802069853760_item	2888677	et	3	main
balletitantsijad	doc_802069853761_item	2888712	et	3	main
abielupaar	doc_802069853761_item	2888713	et	4	main
üks	doc_802069853759_item	2888521	et	3	main
päeva	doc_802069853759_item	2888524	et	4	main
sulud	doc_802069853760_item	2888528	et	3	main
iga	doc_802069853760_item	2888532	et	4	main
vastus	doc_802069853760_item	2888534	et	3	main
annab	doc_802069853760_item	2888535	et	3	main
balletitantsijad	doc_802069853760_item	2888539	et	3	main
age	doc_802069853760_item	2888541	et	4	main
toomas	doc_802069853760_item	2888544	et	3	main
on	doc_802069853760_item	2888546	et	4	main
pärit	doc_802069853760_item	2888547	et	3	main
londonis	doc_802069853760_item	2888556	et	4	main
30	doc_802069853760_item	2888559	et	2	main
vana	doc_802069853760_item	2888569	et	4	main
alates	doc_802069853760_item	2888570	et	3	main
ja	doc_802069853760_item	2888576	et	3	main
armastama	doc_802069853760_item	2888581	et	3	main
armastab	doc_802069853760_item	2888582	et	3	main
neid	doc_802069853760_item	2888583	et	4	main
viimased	doc_802069853760_item	2888594	et	3	main
noored	doc_802069853760_item	2888597	et	3	main
noor	doc_802069853760_item	2888620	et	3	main
etendus	doc_802069853760_item	2888624	et	4	main
jalaluu	doc_802069853760_item	2888625	et	4	main
mõnda	doc_802069853760_item	2888628	et	4	main
teineteisega	doc_802069853760_item	2888640	et	3	main
paaris	doc_802069853760_item	2888641	et	4	main
kuigi	doc_802069853760_item	2888642	et	3	main
nemad	doc_802069853760_item	2888643	et	3	main
on	doc_802069853760_item	2888644	et	4	main
elavad	doc_802069853760_item	2888653	et	4	main
veelgi	doc_802069853760_item	2888668	et	4	main
sõidavad	doc_802069853760_item	2888678	et	3	main
kui	doc_802069853760_item	2888680	et	3	main
oks	doc_802069853760_item	2888682	et	3	main
edur	doc_802069853760_item	2888684	et	4	main
toomas	doc_802069853761_item	2888717	et	3	main
eesti	doc_802069853761_item	2888721	et	4	main
eestis	doc_802069853761_item	2888722	et	3	main
elavad	doc_802069853761_item	2888724	et	4	main
age	doc_802069853761_item	2888730	et	4	main
kolmekümne	doc_802069853761_item	2888733	et	4	main
ja	doc_802069853761_item	2888735	et	3	main
aastal	doc_802069853761_item	2888748	et	3	main
ning	doc_802069853761_item	2888764	et	3	main
karmid	doc_802069853761_item	2888766	et	4	main
kriitikud	doc_802069853761_item	2888767	et	3	main
suhtuma	doc_802069853761_item	2888768	et	3	main
nendesse	doc_802069853761_item	2888770	et	4	main
olnud	doc_802069853761_item	2888793	et	4	main
1990	doc_802069853761_item	2888797	et	2	main
murdis	doc_802069853761_item	2888800	et	3	main
etendus	doc_802069853761_item	2888805	et	4	main
eemal	doc_802069853761_item	2888814	et	3	main
olla	doc_802069853761_item	2888816	et	3	main
toomas	doc_802069853761_item	2888819	et	3	main
on	doc_802069853761_item	2888820	et	4	main
edur	doc_802069853760_item	2888545	et	4	main
elavad	doc_802069853760_item	2888551	et	4	main
age	doc_802069853760_item	2888557	et	4	main
kolmkümmend	doc_802069853760_item	2888560	et	4	main
aastane	doc_802069853760_item	2888561	et	4	main
ja	doc_802069853760_item	2888562	et	3	main
toomas	doc_802069853760_item	2888563	et	3	main
vabakutselinevad	doc_802069853760_item	2888575	et	4	main
erinevad	doc_802069853760_item	2888578	et	4	main
nendesse	doc_802069853760_item	2888591	et	4	main
kuid	doc_802069853760_item	2888600	et	4	main
läinud	doc_802069853760_item	2888607	et	4	main
mõlemal	doc_802069853760_item	2888608	et	3	main
ja	doc_802069853760_item	2888609	et	3	main
eriti	doc_802069853760_item	2888610	et	3	main
probleeme	doc_802069853760_item	2888614	et	3	main
üldiselt	doc_802069853760_item	2888592	et	4	main
hästi	doc_802069853760_item	2888593	et	3	main
ülivõrdes	doc_802069853760_item	2888599	et	3	main
kõik	doc_802069853760_item	2888601	et	4	main
pole	doc_802069853760_item	2888602	et	3	main
sugugi	doc_802069853760_item	2888603	et	4	main
agel	doc_802069853760_item	2888611	et	4	main
olnud	doc_802069853760_item	2888613	et	4	main
tervisiga	doc_802069853760_item	2888616	et	4	main
1990	doc_802069853760_item	2888617	et	2	main
aastal	doc_802069853760_item	2888618	et	3	main
otsustanud	doc_802069853760_item	2888637	et	4	main
suurele	doc_802069853760_item	2888651	et	4	main
edule	doc_802069853760_item	2888652	et	3	main
esinemised	doc_802069853760_item	2888658	et	4	main
planeerima	doc_802069853760_item	2888661	et	3	main
tallinn	doc_802069853760_item	2888675	et	4	main
ja	doc_802069853760_item	2888676	et	3	main
age	doc_802069853761_item	2888714	et	4	main
edur	doc_802069853761_item	2888718	et	4	main
30	doc_802069853761_item	2888732	et	2	main
inglismaal	doc_802069853761_item	2888759	et	4	main
armastama	doc_802069853761_item	2888760	et	3	main
armastavad	doc_802069853761_item	2888761	et	4	main
probleeme	doc_802069853761_item	2888794	et	3	main
aastal	doc_802069853761_item	2888798	et	3	main
naine	doc_802069853761_item	2888802	et	3	main
järve	doc_802069853761_item	2888804	et	4	main
etenduses	doc_802069853761_item	2888806	et	4	main
jalaluu	doc_802069853761_item	2888807	et	4	main
ja	doc_802069853761_item	2888808	et	3	main
aega	doc_802069853761_item	2888812	et	4	main
age	doc_802069853761_item	2888817	et	4	main
ja	doc_802069853761_item	2888818	et	3	main
tantsima	doc_802069853761_item	2888822	et	3	main
ainult	doc_802069853761_item	2888824	et	4	main
pakkumisi	doc_802069853761_item	2888832	et	4	main
ka	doc_802069853761_item	2888833	et	3	main
elavad	doc_802069853761_item	2888839	et	4	main
täpselt	doc_802069853761_item	2888847	et	4	main
planeerima	doc_802069853761_item	2888848	et	3	main
parem	doc_802069853761_item	2888858	et	4	main
märtsis	doc_802069853761_item	2888860	et	3	main
tulevad	doc_802069853761_item	2888861	et	4	main
nad	doc_802069853761_item	2888862	et	3	main
lõuna-aafrikasse	doc_802069853761_item	2888870	et	4	main
kui	doc_802069853761_item	2888871	et	3	main
edur	doc_802069853761_item	2888875	et	4	main
tipus	doc_802069853761_item	2888877	et	3	main
ei	doc_802069853761_item	2888880	et	4	main
oska	doc_802069853761_item	2888881	et	4	main
elada	doc_802069853761_item	2888887	et	3	main
päeva	doc_802069853761_item	2888891	et	4	main
harjutus	doc_802069853762_item	2888893	et	4	main
kirjutage	doc_802069853762_item	2888894	et	3	main
sõna	doc_802069853762_item	2888897	et	4	main
alt	doc_802069853762_item	2888899	et	4	main
punkti	doc_802069853762_item	2888905	et	4	main
millal	doc_802069853762_item	2888907	et	3	main
soovid	doc_802069853762_item	2888909	et	4	main
unusta	doc_802069853762_item	2888910	et	4	main
umbne	doc_802069853762_item	2888911	et	3	main
klassiruum	doc_802069853762_item	2888912	et	3	main
koduõppesüsteem	doc_802069853762_item	2888913	et	3	main
võimaldab	doc_802069853762_item	2888914	et	3	main
sul	doc_802069853762_item	2888915	et	3	main
2	doc_802069853762_item	2888918	et	2	main
ja	doc_802069853762_item	2888922	et	3	main
sa	doc_802069853762_item	2888924	et	3	main
parasjagu	doc_802069853762_item	2888926	et	3	main
mis	doc_802069853762_item	2888933	et	4	main
annab	doc_802069853762_item	2888934	et	3	main
sulle	doc_802069853762_item	2888935	et	3	main
vastavalt	doc_802069853762_item	2888944	et	4	main
individuaalsele	doc_802069853762_item	2888945	et	3	main
4	doc_802069853762_item	2888946	et	2	main
tasemele	doc_802069853762_item	2888947	et	3	main
kontorist	doc_802069853762_item	2888967	et	4	main
igal	doc_802069853762_item	2888971	et	3	main
selle	doc_802069853762_item	2888985	et	4	main
täidetud	doc_802069853762_item	2888988	et	4	main
luikede	doc_802069853760_item	2888622	et	3	main
pidama	doc_802069853760_item	2888627	et	4	main
aega	doc_802069853760_item	2888629	et	4	main
tantsimisest	doc_802069853760_item	2888630	et	4	main
eemal	doc_802069853760_item	2888631	et	3	main
ka	doc_802069853760_item	2888647	et	3	main
tantsimiseks	doc_802069853760_item	2888649	et	4	main
vaatamata	doc_802069853760_item	2888650	et	4	main
tantsijad	doc_802069853760_item	2888654	et	4	main
tagasihoidlik	doc_802069853760_item	2888655	et	3	main
nende	doc_802069853760_item	2888656	et	4	main
lähiaja	doc_802069853760_item	2888657	et	3	main
täpselt	doc_802069853760_item	2888660	et	4	main
ja	doc_802069853760_item	2888663	et	3	main
tahavad	doc_802069853760_item	2888665	et	3	main
areneda	doc_802069853760_item	2888666	et	3	main
ja	doc_802069853760_item	2888667	et	3	main
parem	doc_802069853760_item	2888669	et	4	main
tantsida	doc_802069853760_item	2888670	et	3	main
märtsis	doc_802069853760_item	2888671	et	3	main
tipus	doc_802069853760_item	2888686	et	3	main
suudavad	doc_802069853760_item	2888687	et	3	main
püsida	doc_802069853760_item	2888688	et	3	main
ei	doc_802069853760_item	2888689	et	4	main
oska	doc_802069853760_item	2888690	et	4	main
nad	doc_802069853760_item	2888691	et	3	main
ütlema	doc_802069853760_item	2888692	et	3	main
nad	doc_802069853760_item	2888693	et	3	main
eelistavad	doc_802069853760_item	2888694	et	4	main
elada	doc_802069853760_item	2888695	et	3	main
üks	doc_802069853760_item	2888696	et	3	main
päev	doc_802069853760_item	2888697	et	3	main
kaupa	doc_802069853760_item	2888698	et	4	main
harjutus	doc_802069853761_item	2888699	et	4	main
avage	doc_802069853761_item	2888700	et	3	main
sulud	doc_802069853761_item	2888701	et	3	main
numbrid	doc_802069853761_item	2888702	et	3	main
kirjutage	doc_802069853761_item	2888703	et	3	main
sõnadega	doc_802069853761_item	2888704	et	3	main
iga	doc_802069853761_item	2888705	et	4	main
õige	doc_802069853761_item	2888706	et	4	main
vastus	doc_802069853761_item	2888707	et	3	main
annab	doc_802069853761_item	2888708	et	3	main
ühe	doc_802069853761_item	2888709	et	4	main
punkti	doc_802069853761_item	2888710	et	4	main
maailmakuulsad	doc_802069853761_item	2888711	et	3	main
oks	doc_802069853761_item	2888715	et	3	main
on	doc_802069853761_item	2888719	et	4	main
praegu	doc_802069853761_item	2888725	et	3	main
londonis	doc_802069853761_item	2888729	et	4	main
toomas	doc_802069853761_item	2888736	et	3	main
on	doc_802069853761_item	2888737	et	4	main
32	doc_802069853761_item	2888738	et	2	main
vabakutseline	doc_802069853761_item	2888751	et	4	main
erinevad	doc_802069853761_item	2888755	et	4	main
teatrid	doc_802069853761_item	2888756	et	3	main
üldiselt	doc_802069853761_item	2888771	et	4	main
hästi	doc_802069853761_item	2888772	et	3	main
noor	doc_802069853761_item	2888801	et	3	main
pidi	doc_802069853761_item	2888810	et	4	main
mõnda	doc_802069853761_item	2888811	et	4	main
tantsida	doc_802069853761_item	2888823	et	3	main
teineteisega	doc_802069853761_item	2888825	et	3	main
eraldi	doc_802069853761_item	2888834	et	4	main
tantsijad	doc_802069853761_item	2888840	et	4	main
tagasihoidlik	doc_802069853761_item	2888841	et	3	main
tagasihoidlik	doc_802069853761_item	2888842	et	3	main
planeeritud	doc_802069853761_item	2888849	et	4	main
tallinnas	doc_802069853761_item	2888865	et	4	main
ja	doc_802069853761_item	2888866	et	3	main
seejärel	doc_802069853761_item	2888867	et	3	main
sõidavad	doc_802069853761_item	2888868	et	3	main
ja	doc_802069853761_item	2888874	et	3	main
ütlema	doc_802069853761_item	2888883	et	3	main
päev	doc_802069853761_item	2888889	et	3	main
lünka	doc_802069853762_item	2888895	et	4	main
ühe	doc_802069853762_item	2888904	et	4	main
õpi	doc_802069853762_item	2888906	et	4	main
1	doc_802069853762_item	2888908	et	2	main
kus	doc_802069853762_item	2888921	et	3	main
millal	doc_802069853762_item	2888923	et	3	main
seda	doc_802069853762_item	2888925	et	3	main
käes	doc_802069853762_item	2888928	et	4	main
3	doc_802069853762_item	2888936	et	2	main
vabaduse	doc_802069853762_item	2888937	et	4	main
aeg	doc_802069853762_item	2888948	et	3	main
on	doc_802069853762_item	2888949	et	4	main
raha	doc_802069853762_item	2888950	et	4	main
et	doc_802069853762_item	2888951	et	3	main
seda	doc_802069853762_item	2888952	et	3	main
5	doc_802069853762_item	2888953	et	2	main
kokku	doc_802069853762_item	2888954	et	3	main
panna	doc_802069853762_item	2888955	et	4	main
saad	doc_802069853762_item	2888965	et	4	main
kuul	doc_802069853762_item	2888972	et	4	main
tasud	doc_802069853762_item	2888984	et	4	main
inglismaal	doc_802069853761_item	2888728	et	4	main
vana	doc_802069853761_item	2888742	et	4	main
alates	doc_802069853761_item	2888743	et	3	main
tuhande	doc_802069853761_item	2888744	et	3	main
üheksasaada	doc_802069853761_item	2888745	et	4	main
üheksakümenda	doc_802069853761_item	2888746	et	4	main
seitsmendal	doc_802069853761_item	2888747	et	3	main
vabakutselised	doc_802069853761_item	2888752	et	4	main
esinevad	doc_802069853761_item	2888754	et	4	main
erineva	doc_802069853761_item	2888757	et	4	main
teatrises	doc_802069853761_item	2888758	et	4	main
neid	doc_802069853761_item	2888762	et	4	main
isegi	doc_802069853761_item	2888765	et	4	main
huhtuvad	doc_802069853761_item	2888769	et	4	main
viimased	doc_802069853761_item	2888773	et	3	main
artiklid	doc_802069853761_item	2888774	et	3	main
räägivad	doc_802069853761_item	2888775	et	3	main
noored	doc_802069853761_item	2888776	et	3	main
nooredest	doc_802069853761_item	2888777	et	4	main
ainult	doc_802069853761_item	2888778	et	4	main
ülivõrdes	doc_802069853761_item	2888779	et	3	main
kuid	doc_802069853761_item	2888780	et	4	main
kõik	doc_802069853761_item	2888781	et	4	main
pole	doc_802069853761_item	2888782	et	3	main
sugugi	doc_802069853761_item	2888783	et	4	main
alati	doc_802069853761_item	2888784	et	4	main
nii	doc_802069853761_item	2888785	et	3	main
kergelt	doc_802069853761_item	2888786	et	4	main
läinud	doc_802069853761_item	2888787	et	4	main
mõlemal	doc_802069853761_item	2888788	et	3	main
ja	doc_802069853761_item	2888789	et	3	main
eriti	doc_802069853761_item	2888790	et	3	main
agel	doc_802069853761_item	2888791	et	4	main
on	doc_802069853761_item	2888792	et	4	main
tervisega	doc_802069853761_item	2888796	et	3	main
murdma	doc_802069853761_item	2888799	et	3	main
luikede	doc_802069853761_item	2888803	et	3	main
otsustanud	doc_802069853761_item	2888821	et	4	main
tehtud	doc_802069853761_item	2888831	et	4	main
suurele	doc_802069853761_item	2888837	et	4	main
edule	doc_802069853761_item	2888838	et	3	main
on	doc_802069853761_item	2888846	et	4	main
lõuna-aafrika	doc_802069853761_item	2888869	et	4	main
nad	doc_802069853761_item	2888882	et	3	main
nad	doc_802069853761_item	2888885	et	3	main
sobiv	doc_802069853762_item	2888896	et	4	main
soovid	doc_802069853762_item	2888927	et	4	main
on	doc_802069853762_item	2888929	et	4	main
interaktiivse	doc_802069853762_item	2888930	et	3	main
õppe	doc_802069853762_item	2888931	et	4	main
planeerida	doc_802069853762_item	2888938	et	3	main
aega	doc_802069853762_item	2888939	et	4	main
vaja	doc_802069853762_item	2888957	et	4	main
ka	doc_802069853762_item	2888958	et	3	main
pisut	doc_802069853762_item	2888959	et	3	main
tarkust	doc_802069853762_item	2888960	et	4	main
kui	doc_802069853762_item	2888961	et	3	main
oled	doc_802069853762_item	2888962	et	3	main
kursusele	doc_802069853762_item	2888963	et	3	main
registreerunud	doc_802069853762_item	2888964	et	4	main
lähimast	doc_802069853762_item	2888969	et	4	main
kätte	doc_802069853762_item	2888973	et	4	main
raamatu	doc_802069853762_item	2888975	et	4	main
ja	doc_802069853762_item	2888976	et	3	main
6	doc_802069853762_item	2888978	et	2	main
kättesaamisel	doc_802069853762_item	2888986	et	4	main
soovid	doc_802069853762_item	2889022	et	4	main
soovitad	doc_802069853762_item	2889024	et	3	main
d	doc_802069853762_item	2889025	et	4	main
3	doc_802069853762_item	2889036	et	2	main
hoida	doc_802069853762_item	2889063	et	3	main
6	doc_802069853762_item	2889067	et	2	main
b	doc_802069853762_item	2889070	et	4	main
vaid	doc_802069853762_item	2889071	et	3	main
taga	doc_802069853762_item	2889078	et	4	main
eest	doc_802069853762_item	2889082	et	4	main
d	doc_802069853762_item	2889092	et	4	main
muudab	doc_802069853762_item	2889093	et	3	main
9	doc_802069853762_item	2889094	et	2	main
liikuv	doc_802069853762_item	2889100	et	4	main
10	doc_802069853762_item	2889103	et	2	main
a	doc_802069853762_item	2889104	et	4	main
tulge	doc_802069853762_item	2889105	et	3	main
b	doc_802069853762_item	2889106	et	4	main
käige	doc_802069853762_item	2889107	et	3	main
kirjutage	doc_802069853763_item	2889113	et	3	main
sobiv	doc_802069853763_item	2889115	et	4	main
sõna	doc_802069853763_item	2889116	et	4	main
teksti	doc_802069853763_item	2889117	et	4	main
vastus	doc_802069853763_item	2889121	et	3	main
õpi	doc_802069853763_item	2889125	et	4	main
seal	doc_802069853763_item	2889138	et	4	main
ja	doc_802069853763_item	2889140	et	3	main
parasjagu	doc_802069853763_item	2889144	et	3	main
3	doc_802069853763_item	2889154	et	2	main
panna	doc_802069853763_item	2889173	et	4	main
tagasi	doc_802069853763_item	2889208	et	3	main
õpetaja	doc_802069853763_item	2889209	et	4	main
vaatab	doc_802069853763_item	2889210	et	3	main
ka	doc_802069853763_item	2889219	et	3	main
paaris	doc_802069853761_item	2888826	et	4	main
kuigi	doc_802069853761_item	2888827	et	3	main
nemad	doc_802069853761_item	2888828	et	3	main
nendel	doc_802069853761_item	2888829	et	4	main
tantsimiseks	doc_802069853761_item	2888835	et	4	main
nende	doc_802069853761_item	2888843	et	4	main
age	doc_802069853761_item	2888850	et	4	main
ja	doc_802069853761_item	2888851	et	3	main
toomas	doc_802069853761_item	2888852	et	3	main
tahavad	doc_802069853761_item	2888853	et	3	main
areneda	doc_802069853761_item	2888854	et	3	main
ja	doc_802069853761_item	2888855	et	3	main
veelgi	doc_802069853761_item	2888856	et	4	main
parem	doc_802069853761_item	2888857	et	4	main
tantsida	doc_802069853761_item	2888859	et	3	main
kaua	doc_802069853761_item	2888872	et	3	main
suudavad	doc_802069853761_item	2888878	et	3	main
öelda	doc_802069853761_item	2888884	et	4	main
eelistavad	doc_802069853761_item	2888886	et	4	main
teksti	doc_802069853762_item	2888898	et	4	main
iga	doc_802069853762_item	2888900	et	4	main
õige	doc_802069853762_item	2888901	et	4	main
vastus	doc_802069853762_item	2888902	et	3	main
annab	doc_802069853762_item	2888903	et	3	main
targemaks	doc_802069853762_item	2888917	et	4	main
just	doc_802069853762_item	2888919	et	3	main
ajastu	doc_802069853762_item	2888932	et	4	main
teadmisi	doc_802069853762_item	2888943	et	4	main
on	doc_802069853762_item	2888956	et	4	main
meie	doc_802069853762_item	2888966	et	4	main
postiasutusest	doc_802069853762_item	2888970	et	4	main
õppematerjalid	doc_802069853762_item	2888974	et	3	main
helikasseti	doc_802069853762_item	2888977	et	4	main
ning	doc_802069853762_item	2888979	et	3	main
kodutöö	doc_802069853762_item	2888980	et	4	main
kursuse	doc_802069853762_item	2888981	et	3	main
7	doc_802069853762_item	2888982	et	2	main
kodutöö	doc_802069853762_item	2888989	et	4	main
tagasi	doc_802069853762_item	2888991	et	3	main
õpetaja	doc_802069853762_item	2888992	et	4	main
vaatab	doc_802069853762_item	2888993	et	3	main
selle	doc_802069853762_item	2888994	et	4	main
8	doc_802069853762_item	2888996	et	2	main
parandab	doc_802069853762_item	2888997	et	3	main
üle	doc_802069853762_item	2888995	et	3	main
vead	doc_802069853762_item	2888998	et	4	main
ning	doc_802069853762_item	2888999	et	3	main
vastab	doc_802069853762_item	2889000	et	3	main
vajaduse	doc_802069853762_item	2889001	et	3	main
korral	doc_802069853762_item	2889002	et	4	main
ka	doc_802069853762_item	2889003	et	3	main
tekkinud	doc_802069853762_item	2889004	et	4	main
lisaküsimustele	doc_802069853762_item	2889005	et	4	main
kõik	doc_802069853762_item	2889006	et	4	main
geniaalne	doc_802069853762_item	2889007	et	3	main
on	doc_802069853762_item	2889008	et	4	main
9	doc_802069853762_item	2889009	et	2	main
lihtne	doc_802069853762_item	2889010	et	3	main
10	doc_802069853762_item	2889011	et	2	main
külastage	doc_802069853762_item	2889012	et	3	main
meie	doc_802069853762_item	2889013	et	4	main
virtuaalkodu	doc_802069853762_item	2889014	et	4	main
või	doc_802069853762_item	2889015	et	4	main
postitage	doc_802069853762_item	2889016	et	3	main
kupong	doc_802069853762_item	2889017	et	3	main
1	doc_802069853762_item	2889018	et	2	main
a	doc_802069853762_item	2889019	et	4	main
sobid	doc_802069853762_item	2889020	et	4	main
b	doc_802069853762_item	2889021	et	4	main
c	doc_802069853762_item	2889023	et	4	main
d	doc_802069853762_item	2889034	et	4	main
c	doc_802069853762_item	2889041	et	4	main
varanduse	doc_802069853762_item	2889042	et	3	main
c	doc_802069853762_item	2889072	et	4	main
b	doc_802069853762_item	2889079	et	4	main
c	doc_802069853762_item	2889090	et	4	main
parandab	doc_802069853762_item	2889091	et	3	main
c	doc_802069853762_item	2889108	et	4	main
eelise	doc_802069853762_item	2888941	et	4	main
omandada	doc_802069853762_item	2888942	et	3	main
või	doc_802069853762_item	2888968	et	4	main
eeest	doc_802069853762_item	2888983	et	4	main
saada	doc_802069853762_item	2888987	et	4	main
meile	doc_802069853762_item	2888990	et	4	main
solvud	doc_802069853762_item	2889026	et	3	main
b	doc_802069853762_item	2889030	et	4	main
c	doc_802069853762_item	2889032	et	4	main
kuigi	doc_802069853762_item	2889033	et	3	main
vabanduse	doc_802069853762_item	2889040	et	4	main
4	doc_802069853762_item	2889045	et	2	main
tasule	doc_802069853762_item	2889047	et	3	main
b	doc_802069853762_item	2889048	et	4	main
tasemele	doc_802069853762_item	2889049	et	3	main
tasakesi	doc_802069853762_item	2889051	et	3	main
kokku	doc_802069853762_item	2889065	et	3	main
d	doc_802069853762_item	2889074	et	4	main
et	doc_802069853762_item	2889075	et	3	main
b	doc_802069853762_item	2889088	et	4	main
palub	doc_802069853762_item	2889089	et	3	main
c	doc_802069853762_item	2889099	et	4	main
a	doc_802069853762_item	2889028	et	4	main
just	doc_802069853762_item	2889029	et	3	main
seega	doc_802069853762_item	2889031	et	4	main
d	doc_802069853762_item	2889043	et	4	main
a	doc_802069853762_item	2889046	et	4	main
tasakaalule	doc_802069853762_item	2889053	et	3	main
5	doc_802069853762_item	2889054	et	2	main
a	doc_802069853762_item	2889055	et	4	main
kokku	doc_802069853762_item	2889056	et	3	main
saada	doc_802069853762_item	2889057	et	4	main
b	doc_802069853762_item	2889058	et	4	main
kokku	doc_802069853762_item	2889059	et	3	main
liita	doc_802069853762_item	2889060	et	4	main
c	doc_802069853762_item	2889061	et	4	main
kokku	doc_802069853762_item	2889062	et	3	main
2	doc_802069853762_item	2889027	et	2	main
siiski	doc_802069853762_item	2889035	et	4	main
a	doc_802069853762_item	2889037	et	4	main
vajaduse	doc_802069853762_item	2889038	et	3	main
b	doc_802069853762_item	2889039	et	4	main
vabaduse	doc_802069853762_item	2889044	et	4	main
c	doc_802069853762_item	2889050	et	4	main
d	doc_802069853762_item	2889052	et	4	main
kuid	doc_802069853762_item	2889073	et	4	main
ette	doc_802069853762_item	2889080	et	4	main
a	doc_802069853762_item	2889086	et	4	main
kirjutab	doc_802069853762_item	2889087	et	3	main
liigne	doc_802069853762_item	2889096	et	3	main
b	doc_802069853762_item	2889097	et	4	main
libe	doc_802069853762_item	2889098	et	3	main
d	doc_802069853762_item	2889101	et	4	main
lihtne	doc_802069853762_item	2889102	et	3	main
harjutus	doc_802069853763_item	2889112	et	4	main
iga	doc_802069853763_item	2889119	et	4	main
õige	doc_802069853763_item	2889120	et	4	main
saada	doc_802069853763_item	2889135	et	4	main
seda	doc_802069853763_item	2889143	et	3	main
planeerida	doc_802069853763_item	2889156	et	3	main
ning	doc_802069853763_item	2889158	et	3	main
et	doc_802069853763_item	2889169	et	3	main
5	doc_802069853763_item	2889171	et	2	main
vaja	doc_802069853763_item	2889175	et	4	main
ka	doc_802069853763_item	2889176	et	3	main
lisaküsimustele	doc_802069853763_item	2889221	et	4	main
geniaalne	doc_802069853763_item	2889223	et	3	main
on	doc_802069853763_item	2889224	et	4	main
9	doc_802069853763_item	2889225	et	2	main
b	doc_802069853763_item	2889245	et	4	main
c	doc_802069853763_item	2889256	et	4	main
varanduse	doc_802069853763_item	2889257	et	3	main
c	doc_802069853763_item	2889265	et	4	main
tasakesi	doc_802069853763_item	2889266	et	3	main
d	doc_802069853763_item	2889267	et	4	main
tasakaalule	doc_802069853763_item	2889268	et	3	main
5	doc_802069853763_item	2889269	et	2	main
b	doc_802069853763_item	2889273	et	4	main
d	doc_802069853763_item	2889279	et	4	main
6	doc_802069853763_item	2889282	et	2	main
ning	doc_802069853763_item	2889284	et	3	main
eest	doc_802069853763_item	2889297	et	4	main
d	doc_802069853763_item	2889298	et	4	main
d	doc_802069853763_item	2889307	et	4	main
a	doc_802069853763_item	2889310	et	4	main
b	doc_802069853763_item	2889312	et	4	main
libe	doc_802069853763_item	2889313	et	3	main
c	doc_802069853763_item	2889314	et	4	main
d	doc_802069853762_item	2889064	et	4	main
panna	doc_802069853762_item	2889066	et	4	main
a	doc_802069853762_item	2889068	et	4	main
ning	doc_802069853762_item	2889069	et	3	main
7	doc_802069853762_item	2889076	et	2	main
a	doc_802069853762_item	2889077	et	4	main
c	doc_802069853762_item	2889081	et	4	main
d	doc_802069853762_item	2889083	et	4	main
ees	doc_802069853762_item	2889084	et	4	main
8	doc_802069853762_item	2889085	et	2	main
a	doc_802069853762_item	2889095	et	4	main
d	doc_802069853762_item	2889110	et	4	main
minge	doc_802069853762_item	2889111	et	3	main
lünka	doc_802069853763_item	2889114	et	4	main
ühe	doc_802069853763_item	2889123	et	4	main
targemaks	doc_802069853763_item	2889136	et	4	main
millal	doc_802069853763_item	2889141	et	3	main
käes	doc_802069853763_item	2889146	et	4	main
sulle	doc_802069853763_item	2889153	et	3	main
eelise	doc_802069853763_item	2889159	et	4	main
omandada	doc_802069853763_item	2889160	et	3	main
teadmisi	doc_802069853763_item	2889161	et	4	main
kokku	doc_802069853763_item	2889172	et	3	main
on	doc_802069853763_item	2889174	et	4	main
pisut	doc_802069853763_item	2889177	et	3	main
tarkust	doc_802069853763_item	2889178	et	4	main
kui	doc_802069853763_item	2889179	et	3	main
oled	doc_802069853763_item	2889180	et	3	main
selle	doc_802069853763_item	2889211	et	4	main
üle	doc_802069853763_item	2889212	et	3	main
8	doc_802069853763_item	2889213	et	2	main
korral	doc_802069853763_item	2889218	et	4	main
kõik	doc_802069853763_item	2889222	et	4	main
1	doc_802069853763_item	2889233	et	2	main
a	doc_802069853763_item	2889234	et	4	main
soovid	doc_802069853763_item	2889237	et	4	main
3	doc_802069853763_item	2889251	et	2	main
vabaduse	doc_802069853763_item	2889259	et	4	main
a	doc_802069853763_item	2889270	et	4	main
kokku	doc_802069853763_item	2889271	et	3	main
hoida	doc_802069853763_item	2889278	et	3	main
kuid	doc_802069853763_item	2889288	et	4	main
ette	doc_802069853763_item	2889295	et	4	main
a	doc_802069853763_item	2889301	et	4	main
kirjutab	doc_802069853763_item	2889302	et	3	main
b	doc_802069853763_item	2889303	et	4	main
külastage	doc_802069853763_item	2889324	et	3	main
harjutus	doc_802069853764_item	2889327	et	4	main
õige	doc_802069853764_item	2889335	et	4	main
soovid	doc_802069853764_item	2889343	et	4	main
saada	doc_802069853764_item	2889350	et	4	main
õppe	doc_802069853764_item	2889365	et	4	main
mis	doc_802069853764_item	2889367	et	4	main
teadmisi	doc_802069853764_item	2889377	et	4	main
4	doc_802069853764_item	2889380	et	2	main
tasakalule	doc_802069853764_item	2889381	et	4	main
et	doc_802069853764_item	2889385	et	3	main
kokku	doc_802069853764_item	2889388	et	3	main
tarkust	doc_802069853764_item	2889394	et	4	main
kui	doc_802069853764_item	2889395	et	3	main
oled	doc_802069853764_item	2889396	et	3	main
kursusele	doc_802069853764_item	2889397	et	3	main
kätte	doc_802069853764_item	2889407	et	4	main
õppematerjalid	doc_802069853764_item	2889408	et	3	main
selle	doc_802069853764_item	2889419	et	4	main
kodutöö	doc_802069853764_item	2889423	et	4	main
lisaküsimustele	doc_802069853764_item	2889439	et	4	main
meie	doc_802069853764_item	2889447	et	4	main
a	doc_802069853764_item	2889453	et	4	main
c	doc_802069853764_item	2889475	et	4	main
varanduse	doc_802069853764_item	2889476	et	3	main
c	doc_802069853764_item	2889484	et	4	main
tasakesi	doc_802069853764_item	2889485	et	3	main
a	doc_802069853764_item	2889489	et	4	main
c	doc_802069853764_item	2889495	et	4	main
c	doc_802069853764_item	2889506	et	4	main
eest	doc_802069853764_item	2889516	et	4	main
d	doc_802069853764_item	2889517	et	4	main
a	doc_802069853764_item	2889529	et	4	main
c	doc_802069853764_item	2889533	et	4	main
kirjutage	doc_802069853765_item	2889547	et	3	main
õppe	doc_802069853765_item	2889584	et	4	main
külastage	doc_802069853762_item	2889109	et	3	main
alt	doc_802069853763_item	2889118	et	4	main
annab	doc_802069853763_item	2889122	et	3	main
1	doc_802069853763_item	2889127	et	2	main
unusta	doc_802069853763_item	2889129	et	4	main
umbne	doc_802069853763_item	2889130	et	3	main
klassiruum	doc_802069853763_item	2889131	et	3	main
sul	doc_802069853763_item	2889134	et	3	main
soovid	doc_802069853763_item	2889145	et	4	main
on	doc_802069853763_item	2889147	et	4	main
interaktiivse	doc_802069853763_item	2889148	et	3	main
õppe	doc_802069853763_item	2889149	et	4	main
varanduse	doc_802069853763_item	2889155	et	3	main
aega	doc_802069853763_item	2889157	et	4	main
vastavalt	doc_802069853763_item	2889162	et	4	main
individuaalsele	doc_802069853763_item	2889163	et	3	main
4	doc_802069853763_item	2889164	et	2	main
tasemele	doc_802069853763_item	2889165	et	3	main
aeg	doc_802069853763_item	2889166	et	3	main
vead	doc_802069853763_item	2889214	et	4	main
ning	doc_802069853763_item	2889215	et	3	main
vajaduse	doc_802069853763_item	2889217	et	3	main
tekkinud	doc_802069853763_item	2889220	et	4	main
või	doc_802069853763_item	2889230	et	4	main
postitage	doc_802069853763_item	2889231	et	3	main
kupong	doc_802069853763_item	2889232	et	3	main
b	doc_802069853763_item	2889236	et	4	main
seega	doc_802069853763_item	2889246	et	4	main
c	doc_802069853763_item	2889247	et	4	main
kuigi	doc_802069853763_item	2889248	et	3	main
siiski	doc_802069853763_item	2889250	et	4	main
a	doc_802069853763_item	2889252	et	4	main
vajaduse	doc_802069853763_item	2889253	et	3	main
b	doc_802069853763_item	2889254	et	4	main
vabanduse	doc_802069853763_item	2889255	et	4	main
kokku	doc_802069853763_item	2889274	et	3	main
c	doc_802069853763_item	2889276	et	4	main
panna	doc_802069853763_item	2889281	et	4	main
a	doc_802069853763_item	2889283	et	4	main
b	doc_802069853763_item	2889285	et	4	main
vaid	doc_802069853763_item	2889286	et	3	main
c	doc_802069853763_item	2889287	et	4	main
taga	doc_802069853763_item	2889293	et	4	main
b	doc_802069853763_item	2889294	et	4	main
ees	doc_802069853763_item	2889299	et	4	main
8	doc_802069853763_item	2889300	et	2	main
c	doc_802069853763_item	2889305	et	4	main
muudab	doc_802069853763_item	2889308	et	3	main
liigne	doc_802069853763_item	2889311	et	3	main
liikuv	doc_802069853763_item	2889315	et	4	main
b	doc_802069853763_item	2889321	et	4	main
d	doc_802069853763_item	2889325	et	4	main
lünka	doc_802069853764_item	2889329	et	4	main
ühe	doc_802069853764_item	2889338	et	4	main
unusta	doc_802069853764_item	2889344	et	4	main
sul	doc_802069853764_item	2889349	et	3	main
on	doc_802069853764_item	2889363	et	4	main
on	doc_802069853764_item	2889383	et	4	main
seda	doc_802069853764_item	2889386	et	3	main
liita	doc_802069853764_item	2889389	et	4	main
meie	doc_802069853764_item	2889400	et	4	main
igal	doc_802069853764_item	2889405	et	3	main
kuul	doc_802069853764_item	2889406	et	4	main
ning	doc_802069853764_item	2889413	et	3	main
7	doc_802069853764_item	2889416	et	2	main
täidetud	doc_802069853764_item	2889422	et	4	main
õpetaja	doc_802069853764_item	2889426	et	4	main
8	doc_802069853764_item	2889430	et	2	main
vead	doc_802069853764_item	2889432	et	4	main
on	doc_802069853764_item	2889442	et	4	main
10	doc_802069853764_item	2889445	et	2	main
solvud	doc_802069853764_item	2889460	et	3	main
siiski	doc_802069853764_item	2889469	et	4	main
a	doc_802069853764_item	2889471	et	4	main
vabaduse	doc_802069853764_item	2889478	et	4	main
d	doc_802069853764_item	2889486	et	4	main
saada	doc_802069853764_item	2889491	et	4	main
kokku	doc_802069853764_item	2889493	et	3	main
kokku	doc_802069853764_item	2889496	et	3	main
d	doc_802069853764_item	2889498	et	4	main
kokku	doc_802069853764_item	2889499	et	3	main
panna	doc_802069853764_item	2889500	et	4	main
6	doc_802069853764_item	2889501	et	2	main
punkti	doc_802069853763_item	2889124	et	4	main
millal	doc_802069853763_item	2889126	et	3	main
sobid	doc_802069853763_item	2889128	et	4	main
koduõppesüsteem	doc_802069853763_item	2889132	et	3	main
võimaldab	doc_802069853763_item	2889133	et	3	main
2	doc_802069853763_item	2889137	et	2	main
kus	doc_802069853763_item	2889139	et	3	main
sa	doc_802069853763_item	2889142	et	3	main
ajastu	doc_802069853763_item	2889150	et	4	main
mis	doc_802069853763_item	2889151	et	4	main
annab	doc_802069853763_item	2889152	et	3	main
on	doc_802069853763_item	2889167	et	4	main
raha	doc_802069853763_item	2889168	et	4	main
seda	doc_802069853763_item	2889170	et	3	main
kursusele	doc_802069853763_item	2889181	et	3	main
registreerunud	doc_802069853763_item	2889182	et	4	main
saad	doc_802069853763_item	2889183	et	4	main
meie	doc_802069853763_item	2889184	et	4	main
kontorist	doc_802069853763_item	2889185	et	4	main
või	doc_802069853763_item	2889186	et	4	main
lähimast	doc_802069853763_item	2889187	et	4	main
postiasutusest	doc_802069853763_item	2889188	et	4	main
igal	doc_802069853763_item	2889189	et	3	main
kuul	doc_802069853763_item	2889190	et	4	main
kätte	doc_802069853763_item	2889191	et	4	main
õppematerjalid	doc_802069853763_item	2889192	et	3	main
raamatu	doc_802069853763_item	2889193	et	4	main
ja	doc_802069853763_item	2889194	et	3	main
helikasseti	doc_802069853763_item	2889195	et	4	main
6	doc_802069853763_item	2889196	et	2	main
ning	doc_802069853763_item	2889197	et	3	main
kodutöö	doc_802069853763_item	2889198	et	4	main
kursuse	doc_802069853763_item	2889199	et	3	main
7	doc_802069853763_item	2889200	et	2	main
tasud	doc_802069853763_item	2889201	et	4	main
selle	doc_802069853763_item	2889202	et	4	main
kättesaamisel	doc_802069853763_item	2889203	et	4	main
saada	doc_802069853763_item	2889204	et	4	main
täidetud	doc_802069853763_item	2889205	et	4	main
kodutöö	doc_802069853763_item	2889206	et	4	main
meile	doc_802069853763_item	2889207	et	4	main
vastab	doc_802069853763_item	2889216	et	3	main
virtuaalkodu	doc_802069853763_item	2889229	et	4	main
a	doc_802069853763_item	2889243	et	4	main
just	doc_802069853763_item	2889244	et	3	main
d	doc_802069853763_item	2889249	et	4	main
d	doc_802069853763_item	2889258	et	4	main
kokku	doc_802069853763_item	2889277	et	3	main
kokku	doc_802069853763_item	2889280	et	3	main
d	doc_802069853763_item	2889289	et	4	main
7	doc_802069853763_item	2889291	et	2	main
a	doc_802069853763_item	2889292	et	4	main
palub	doc_802069853763_item	2889304	et	3	main
9	doc_802069853763_item	2889309	et	2	main
lihtne	doc_802069853763_item	2889317	et	3	main
c	doc_802069853763_item	2889323	et	4	main
sõna	doc_802069853764_item	2889331	et	4	main
alt	doc_802069853764_item	2889333	et	4	main
iga	doc_802069853764_item	2889334	et	4	main
vastus	doc_802069853764_item	2889336	et	3	main
koduõppesüsteem	doc_802069853764_item	2889347	et	3	main
võimaldab	doc_802069853764_item	2889348	et	3	main
targemaks	doc_802069853764_item	2889351	et	4	main
ajastu	doc_802069853764_item	2889366	et	4	main
annab	doc_802069853764_item	2889368	et	3	main
3	doc_802069853764_item	2889370	et	2	main
vastavalt	doc_802069853764_item	2889378	et	4	main
individuaalsele	doc_802069853764_item	2889379	et	3	main
5	doc_802069853764_item	2889387	et	2	main
on	doc_802069853764_item	2889390	et	4	main
vaja	doc_802069853764_item	2889391	et	4	main
ka	doc_802069853764_item	2889392	et	3	main
pisut	doc_802069853764_item	2889393	et	3	main
kontorist	doc_802069853764_item	2889401	et	4	main
või	doc_802069853764_item	2889402	et	4	main
ja	doc_802069853764_item	2889410	et	3	main
helikasseti	doc_802069853764_item	2889411	et	4	main
eest	doc_802069853764_item	2889417	et	4	main
tasud	doc_802069853764_item	2889418	et	4	main
saada	doc_802069853764_item	2889421	et	4	main
tekkinud	doc_802069853764_item	2889438	et	4	main
virtuaalkodu	doc_802069853764_item	2889448	et	4	main
1	doc_802069853764_item	2889452	et	2	main
sobid	doc_802069853764_item	2889454	et	4	main
b	doc_802069853764_item	2889464	et	4	main
kuigi	doc_802069853764_item	2889467	et	3	main
3	doc_802069853764_item	2889470	et	2	main
vajaduse	doc_802069853764_item	2889472	et	3	main
4	doc_802069853764_item	2889479	et	2	main
tasakaalule	doc_802069853764_item	2889487	et	3	main
b	doc_802069853764_item	2889504	et	4	main
vaid	doc_802069853764_item	2889505	et	3	main
taga	doc_802069853764_item	2889512	et	4	main
10	doc_802069853763_item	2889226	et	2	main
külastage	doc_802069853763_item	2889227	et	3	main
meie	doc_802069853763_item	2889228	et	4	main
sobid	doc_802069853763_item	2889235	et	4	main
c	doc_802069853763_item	2889238	et	4	main
soovitad	doc_802069853763_item	2889239	et	3	main
d	doc_802069853763_item	2889240	et	4	main
solvud	doc_802069853763_item	2889241	et	3	main
2	doc_802069853763_item	2889242	et	2	main
4	doc_802069853763_item	2889260	et	2	main
a	doc_802069853763_item	2889261	et	4	main
tasule	doc_802069853763_item	2889262	et	3	main
b	doc_802069853763_item	2889263	et	4	main
tasemele	doc_802069853763_item	2889264	et	3	main
saada	doc_802069853763_item	2889272	et	4	main
liita	doc_802069853763_item	2889275	et	4	main
et	doc_802069853763_item	2889290	et	3	main
c	doc_802069853763_item	2889296	et	4	main
parandab	doc_802069853763_item	2889306	et	3	main
d	doc_802069853763_item	2889316	et	4	main
10	doc_802069853763_item	2889318	et	2	main
a	doc_802069853763_item	2889319	et	4	main
tulge	doc_802069853763_item	2889320	et	3	main
käige	doc_802069853763_item	2889322	et	3	main
minge	doc_802069853763_item	2889326	et	3	main
kirjutage	doc_802069853764_item	2889328	et	3	main
sobiv	doc_802069853764_item	2889330	et	4	main
annab	doc_802069853764_item	2889337	et	3	main
punkti	doc_802069853764_item	2889339	et	4	main
õpi	doc_802069853764_item	2889340	et	4	main
millal	doc_802069853764_item	2889341	et	3	main
umbne	doc_802069853764_item	2889345	et	3	main
interaktiivse	doc_802069853764_item	2889364	et	3	main
sulle	doc_802069853764_item	2889369	et	3	main
vabaduse	doc_802069853764_item	2889371	et	4	main
planeerida	doc_802069853764_item	2889372	et	3	main
aega	doc_802069853764_item	2889373	et	4	main
ning	doc_802069853764_item	2889374	et	3	main
aeg	doc_802069853764_item	2889382	et	3	main
registreerunud	doc_802069853764_item	2889398	et	4	main
saad	doc_802069853764_item	2889399	et	4	main
lähimast	doc_802069853764_item	2889403	et	4	main
postiasutusest	doc_802069853764_item	2889404	et	4	main
6	doc_802069853764_item	2889412	et	2	main
kursuse	doc_802069853764_item	2889415	et	3	main
kättesaamisel	doc_802069853764_item	2889420	et	4	main
teksti	doc_802069853764_item	2889332	et	4	main
1	doc_802069853764_item	2889342	et	2	main
klassiruum	doc_802069853764_item	2889346	et	3	main
2	doc_802069853764_item	2889352	et	2	main
just	doc_802069853764_item	2889353	et	3	main
seal	doc_802069853764_item	2889354	et	4	main
kus	doc_802069853764_item	2889355	et	3	main
ja	doc_802069853764_item	2889356	et	3	main
millal	doc_802069853764_item	2889357	et	3	main
sa	doc_802069853764_item	2889358	et	3	main
seda	doc_802069853764_item	2889359	et	3	main
parasjagu	doc_802069853764_item	2889360	et	3	main
soovid	doc_802069853764_item	2889361	et	4	main
käes	doc_802069853764_item	2889362	et	4	main
eelise	doc_802069853764_item	2889375	et	4	main
omandada	doc_802069853764_item	2889376	et	3	main
raha	doc_802069853764_item	2889384	et	4	main
raamatu	doc_802069853764_item	2889409	et	4	main
kodutöö	doc_802069853764_item	2889414	et	4	main
tagasi	doc_802069853764_item	2889425	et	3	main
vaatab	doc_802069853764_item	2889427	et	3	main
kõik	doc_802069853764_item	2889440	et	4	main
geniaalne	doc_802069853764_item	2889441	et	3	main
või	doc_802069853764_item	2889449	et	4	main
kupong	doc_802069853764_item	2889451	et	3	main
d	doc_802069853764_item	2889459	et	4	main
2	doc_802069853764_item	2889461	et	2	main
a	doc_802069853764_item	2889462	et	4	main
just	doc_802069853764_item	2889463	et	3	main
c	doc_802069853764_item	2889466	et	4	main
d	doc_802069853764_item	2889468	et	4	main
d	doc_802069853764_item	2889477	et	4	main
liita	doc_802069853764_item	2889494	et	4	main
hoida	doc_802069853764_item	2889497	et	3	main
kuid	doc_802069853764_item	2889507	et	4	main
b	doc_802069853764_item	2889513	et	4	main
a	doc_802069853764_item	2889520	et	4	main
kirjutab	doc_802069853764_item	2889521	et	3	main
palub	doc_802069853764_item	2889523	et	3	main
parandab	doc_802069853764_item	2889525	et	3	main
d	doc_802069853764_item	2889526	et	4	main
9	doc_802069853764_item	2889528	et	2	main
käige	doc_802069853764_item	2889541	et	3	main
sobiv	doc_802069853765_item	2889549	et	4	main
umbne	doc_802069853765_item	2889564	et	3	main
võimaldab	doc_802069853765_item	2889567	et	3	main
saada	doc_802069853765_item	2889569	et	4	main
2	doc_802069853765_item	2889571	et	2	main
just	doc_802069853765_item	2889572	et	3	main
seal	doc_802069853765_item	2889573	et	4	main
kus	doc_802069853765_item	2889574	et	3	main
ja	doc_802069853765_item	2889575	et	3	main
millal	doc_802069853765_item	2889576	et	3	main
sa	doc_802069853765_item	2889577	et	3	main
seda	doc_802069853765_item	2889578	et	3	main
parasjagu	doc_802069853765_item	2889579	et	3	main
soovid	doc_802069853765_item	2889580	et	4	main
ajastu	doc_802069853765_item	2889585	et	4	main
vastavalt	doc_802069853765_item	2889597	et	4	main
individuaalsele	doc_802069853765_item	2889598	et	3	main
4	doc_802069853765_item	2889599	et	2	main
on	doc_802069853765_item	2889602	et	4	main
hoida	doc_802069853765_item	2889608	et	3	main
saad	doc_802069853765_item	2889618	et	4	main
kodutöö	doc_802069853765_item	2889633	et	4	main
kursuse	doc_802069853765_item	2889634	et	3	main
kättesaamisel	doc_802069853765_item	2889639	et	4	main
8	doc_802069853765_item	2889649	et	2	main
parandab	doc_802069853765_item	2889650	et	3	main
lisaküsimustele	doc_802069853765_item	2889658	et	4	main
geniaalne	doc_802069853765_item	2889660	et	3	main
9	doc_802069853765_item	2889662	et	2	main
lihtne	doc_802069853765_item	2889663	et	3	main
sobid	doc_802069853765_item	2889673	et	4	main
b	doc_802069853765_item	2889674	et	4	main
d	doc_802069853765_item	2889717	et	4	main
panna	doc_802069853765_item	2889719	et	4	main
vaid	doc_802069853765_item	2889724	et	3	main
b	doc_802069853765_item	2889732	et	4	main
a	doc_802069853765_item	2889739	et	4	main
9	doc_802069853765_item	2889747	et	2	main
liikuv	doc_802069853765_item	2889753	et	4	main
harjutus	doc_802069853766_item	2889765	et	4	main
lünka	doc_802069853766_item	2889767	et	4	main
ajastu	doc_802069853766_item	2889804	et	4	main
omandada	doc_802069853766_item	2889814	et	3	main
teadmisi	doc_802069853766_item	2889815	et	4	main
aeg	doc_802069853766_item	2889820	et	3	main
5	doc_802069853766_item	2889825	et	2	main
liita	doc_802069853766_item	2889827	et	4	main
pisut	doc_802069853766_item	2889831	et	3	main
kui	doc_802069853766_item	2889833	et	3	main
tasud	doc_802069853766_item	2889856	et	4	main
kodutöö	doc_802069853766_item	2889861	et	4	main
vaatab	doc_802069853766_item	2889865	et	3	main
üle	doc_802069853766_item	2889867	et	3	main
meile	doc_802069853764_item	2889424	et	4	main
selle	doc_802069853764_item	2889428	et	4	main
üle	doc_802069853764_item	2889429	et	3	main
parandab	doc_802069853764_item	2889431	et	3	main
ning	doc_802069853764_item	2889433	et	3	main
vastab	doc_802069853764_item	2889434	et	3	main
vajaduse	doc_802069853764_item	2889435	et	3	main
korral	doc_802069853764_item	2889436	et	4	main
ka	doc_802069853764_item	2889437	et	3	main
9	doc_802069853764_item	2889443	et	2	main
lihtne	doc_802069853764_item	2889444	et	3	main
külastage	doc_802069853764_item	2889446	et	3	main
postitage	doc_802069853764_item	2889450	et	3	main
b	doc_802069853764_item	2889455	et	4	main
soovid	doc_802069853764_item	2889456	et	4	main
c	doc_802069853764_item	2889457	et	4	main
soovitad	doc_802069853764_item	2889458	et	3	main
seega	doc_802069853764_item	2889465	et	4	main
b	doc_802069853764_item	2889473	et	4	main
vabanduse	doc_802069853764_item	2889474	et	4	main
a	doc_802069853764_item	2889480	et	4	main
tasule	doc_802069853764_item	2889481	et	3	main
b	doc_802069853764_item	2889482	et	4	main
tasemele	doc_802069853764_item	2889483	et	3	main
5	doc_802069853764_item	2889488	et	2	main
kokku	doc_802069853764_item	2889490	et	3	main
b	doc_802069853764_item	2889492	et	4	main
d	doc_802069853764_item	2889508	et	4	main
et	doc_802069853764_item	2889509	et	3	main
7	doc_802069853764_item	2889510	et	2	main
ees	doc_802069853764_item	2889518	et	4	main
8	doc_802069853764_item	2889519	et	2	main
b	doc_802069853764_item	2889522	et	4	main
muudab	doc_802069853764_item	2889527	et	3	main
liikuv	doc_802069853764_item	2889534	et	4	main
d	doc_802069853764_item	2889535	et	4	main
lihtne	doc_802069853764_item	2889536	et	3	main
10	doc_802069853764_item	2889537	et	2	main
a	doc_802069853764_item	2889538	et	4	main
tulge	doc_802069853764_item	2889539	et	3	main
harjutus	doc_802069853765_item	2889546	et	4	main
sõna	doc_802069853765_item	2889550	et	4	main
unusta	doc_802069853765_item	2889563	et	4	main
käes	doc_802069853765_item	2889581	et	4	main
3	doc_802069853765_item	2889589	et	2	main
vajaduse	doc_802069853765_item	2889590	et	3	main
planeerida	doc_802069853765_item	2889591	et	3	main
aega	doc_802069853765_item	2889592	et	4	main
ning	doc_802069853765_item	2889593	et	3	main
aeg	doc_802069853765_item	2889601	et	3	main
raha	doc_802069853765_item	2889603	et	4	main
kokku	doc_802069853765_item	2889607	et	3	main
on	doc_802069853765_item	2889609	et	4	main
vaja	doc_802069853765_item	2889610	et	4	main
ka	doc_802069853765_item	2889611	et	3	main
pisut	doc_802069853765_item	2889612	et	3	main
kontorist	doc_802069853765_item	2889620	et	4	main
või	doc_802069853765_item	2889621	et	4	main
postiasutusest	doc_802069853765_item	2889623	et	4	main
igal	doc_802069853765_item	2889624	et	3	main
kätte	doc_802069853765_item	2889626	et	4	main
tasud	doc_802069853765_item	2889637	et	4	main
selle	doc_802069853765_item	2889638	et	4	main
täidetud	doc_802069853765_item	2889641	et	4	main
meile	doc_802069853765_item	2889643	et	4	main
tagasi	doc_802069853765_item	2889644	et	3	main
või	doc_802069853765_item	2889668	et	4	main
postitage	doc_802069853765_item	2889669	et	3	main
1	doc_802069853765_item	2889671	et	2	main
a	doc_802069853765_item	2889672	et	4	main
c	doc_802069853765_item	2889676	et	4	main
ning	doc_802069853765_item	2889722	et	3	main
7	doc_802069853765_item	2889729	et	2	main
a	doc_802069853765_item	2889730	et	4	main
8	doc_802069853765_item	2889738	et	2	main
b	doc_802069853765_item	2889741	et	4	main
palub	doc_802069853765_item	2889742	et	3	main
c	doc_802069853765_item	2889743	et	4	main
d	doc_802069853765_item	2889763	et	4	main
kirjutage	doc_802069853766_item	2889766	et	3	main
sobiv	doc_802069853766_item	2889768	et	4	main
sõna	doc_802069853766_item	2889769	et	4	main
on	doc_802069853766_item	2889801	et	4	main
aega	doc_802069853766_item	2889811	et	4	main
ning	doc_802069853766_item	2889812	et	3	main
tasemele	doc_802069853766_item	2889819	et	3	main
raha	doc_802069853766_item	2889822	et	4	main
ka	doc_802069853766_item	2889830	et	3	main
registreerunud	doc_802069853766_item	2889836	et	4	main
või	doc_802069853766_item	2889840	et	4	main
kätte	doc_802069853766_item	2889845	et	4	main
helikasseti	doc_802069853766_item	2889849	et	4	main
kättesaamisel	doc_802069853766_item	2889858	et	4	main
tagasi	doc_802069853766_item	2889863	et	3	main
vead	doc_802069853766_item	2889870	et	4	main
ning	doc_802069853766_item	2889871	et	3	main
vastab	doc_802069853766_item	2889872	et	3	main
vajaduse	doc_802069853766_item	2889873	et	3	main
korral	doc_802069853766_item	2889874	et	4	main
a	doc_802069853764_item	2889502	et	4	main
ning	doc_802069853764_item	2889503	et	3	main
a	doc_802069853764_item	2889511	et	4	main
ette	doc_802069853764_item	2889514	et	4	main
c	doc_802069853764_item	2889515	et	4	main
b	doc_802069853764_item	2889531	et	4	main
b	doc_802069853764_item	2889540	et	4	main
c	doc_802069853764_item	2889542	et	4	main
külastage	doc_802069853764_item	2889543	et	3	main
d	doc_802069853764_item	2889544	et	4	main
minge	doc_802069853764_item	2889545	et	3	main
õpi	doc_802069853765_item	2889559	et	4	main
millal	doc_802069853765_item	2889560	et	3	main
klassiruum	doc_802069853765_item	2889565	et	3	main
koduõppesüsteem	doc_802069853765_item	2889566	et	3	main
mis	doc_802069853765_item	2889586	et	4	main
annab	doc_802069853765_item	2889587	et	3	main
sulle	doc_802069853765_item	2889588	et	3	main
tasemele	doc_802069853765_item	2889600	et	3	main
kui	doc_802069853765_item	2889614	et	3	main
oled	doc_802069853765_item	2889615	et	3	main
kursusele	doc_802069853765_item	2889616	et	3	main
registreerunud	doc_802069853765_item	2889617	et	4	main
c	doc_802069853764_item	2889524	et	4	main
liigne	doc_802069853764_item	2889530	et	3	main
libe	doc_802069853764_item	2889532	et	3	main
lünka	doc_802069853765_item	2889548	et	4	main
teksti	doc_802069853765_item	2889551	et	4	main
alt	doc_802069853765_item	2889552	et	4	main
iga	doc_802069853765_item	2889553	et	4	main
õige	doc_802069853765_item	2889554	et	4	main
vastus	doc_802069853765_item	2889555	et	3	main
annab	doc_802069853765_item	2889556	et	3	main
ühe	doc_802069853765_item	2889557	et	4	main
punkti	doc_802069853765_item	2889558	et	4	main
1	doc_802069853765_item	2889561	et	2	main
soovid	doc_802069853765_item	2889562	et	4	main
sul	doc_802069853765_item	2889568	et	3	main
targemaks	doc_802069853765_item	2889570	et	4	main
on	doc_802069853765_item	2889582	et	4	main
interaktiivse	doc_802069853765_item	2889583	et	3	main
eelise	doc_802069853765_item	2889594	et	4	main
omandada	doc_802069853765_item	2889595	et	3	main
tarkust	doc_802069853765_item	2889613	et	4	main
lähimast	doc_802069853765_item	2889622	et	4	main
kuul	doc_802069853765_item	2889625	et	4	main
7	doc_802069853765_item	2889635	et	2	main
eest	doc_802069853765_item	2889636	et	4	main
õpetaja	doc_802069853765_item	2889645	et	4	main
vaatab	doc_802069853765_item	2889646	et	3	main
tekkinud	doc_802069853765_item	2889657	et	4	main
on	doc_802069853765_item	2889661	et	4	main
10	doc_802069853765_item	2889664	et	2	main
tulge	doc_802069853765_item	2889665	et	3	main
meie	doc_802069853765_item	2889666	et	4	main
soovitad	doc_802069853765_item	2889677	et	3	main
solvud	doc_802069853765_item	2889679	et	3	main
b	doc_802069853765_item	2889711	et	4	main
kokku	doc_802069853765_item	2889712	et	3	main
liita	doc_802069853765_item	2889713	et	4	main
kokku	doc_802069853765_item	2889718	et	3	main
teadmisi	doc_802069853765_item	2889596	et	4	main
et	doc_802069853765_item	2889604	et	3	main
seda	doc_802069853765_item	2889605	et	3	main
5	doc_802069853765_item	2889606	et	2	main
meie	doc_802069853765_item	2889619	et	4	main
saada	doc_802069853765_item	2889640	et	4	main
kodutöö	doc_802069853765_item	2889642	et	4	main
vead	doc_802069853765_item	2889651	et	4	main
ning	doc_802069853765_item	2889652	et	3	main
vastab	doc_802069853765_item	2889653	et	3	main
vajaduse	doc_802069853765_item	2889654	et	3	main
korral	doc_802069853765_item	2889655	et	4	main
ka	doc_802069853765_item	2889656	et	3	main
kõik	doc_802069853765_item	2889659	et	4	main
kupong	doc_802069853765_item	2889670	et	3	main
c	doc_802069853765_item	2889714	et	4	main
kokku	doc_802069853765_item	2889715	et	3	main
b	doc_802069853765_item	2889723	et	4	main
d	doc_802069853765_item	2889727	et	4	main
taga	doc_802069853765_item	2889731	et	4	main
d	doc_802069853765_item	2889736	et	4	main
parandab	doc_802069853765_item	2889744	et	3	main
d	doc_802069853765_item	2889754	et	4	main
lihtne	doc_802069853765_item	2889755	et	3	main
a	doc_802069853765_item	2889757	et	4	main
tulge	doc_802069853765_item	2889758	et	3	main
b	doc_802069853765_item	2889759	et	4	main
käige	doc_802069853765_item	2889760	et	3	main
teksti	doc_802069853766_item	2889770	et	4	main
punkti	doc_802069853766_item	2889777	et	4	main
sulle	doc_802069853766_item	2889807	et	3	main
vastavalt	doc_802069853766_item	2889816	et	4	main
individuaalsele	doc_802069853766_item	2889817	et	3	main
on	doc_802069853766_item	2889821	et	4	main
et	doc_802069853766_item	2889823	et	3	main
seda	doc_802069853766_item	2889824	et	3	main
kokku	doc_802069853766_item	2889826	et	3	main
oled	doc_802069853766_item	2889834	et	3	main
kursusele	doc_802069853766_item	2889835	et	3	main
saad	doc_802069853766_item	2889837	et	4	main
meie	doc_802069853766_item	2889838	et	4	main
lähimast	doc_802069853766_item	2889841	et	4	main
postiasutusest	doc_802069853766_item	2889842	et	4	main
igal	doc_802069853766_item	2889843	et	3	main
kuul	doc_802069853766_item	2889844	et	4	main
raamatu	doc_802069853766_item	2889847	et	4	main
selle	doc_802069853766_item	2889857	et	4	main
meile	doc_802069853766_item	2889862	et	4	main
lisaküsimustele	doc_802069853766_item	2889877	et	4	main
tulge	doc_802069853766_item	2889884	et	3	main
tasakaalule	doc_802069853766_item	2889925	et	3	main
5	doc_802069853766_item	2889926	et	2	main
saada	doc_802069853766_item	2889929	et	4	main
c	doc_802069853766_item	2889933	et	4	main
kokku	doc_802069853766_item	2889934	et	3	main
hoida	doc_802069853766_item	2889935	et	3	main
c	doc_802069853766_item	2889944	et	4	main
7	doc_802069853766_item	2889948	et	2	main
b	doc_802069853766_item	2889960	et	4	main
palub	doc_802069853766_item	2889961	et	3	main
c	doc_802069853766_item	2889962	et	4	main
liikuv	doc_802069853766_item	2889972	et	4	main
d	doc_802069853766_item	2889973	et	4	main
lihtne	doc_802069853766_item	2889974	et	3	main
10	doc_802069853766_item	2889975	et	2	main
d	doc_802069853766_item	2889982	et	4	main
lünka	doc_802069853767_item	2889986	et	4	main
õpi	doc_802069853767_item	2889997	et	4	main
sulle	doc_802069853767_item	2890026	et	3	main
vabaduse	doc_802069853767_item	2890028	et	4	main
eelise	doc_802069853767_item	2890032	et	4	main
omandada	doc_802069853767_item	2890033	et	3	main
oled	doc_802069853767_item	2890053	et	3	main
meie	doc_802069853767_item	2890057	et	4	main
igal	doc_802069853767_item	2890062	et	3	main
kodutöö	doc_802069853767_item	2890071	et	4	main
kursuse	doc_802069853767_item	2890072	et	3	main
saada	doc_802069853767_item	2890078	et	4	main
selle	doc_802069853767_item	2890085	et	4	main
üle	doc_802069853767_item	2890086	et	3	main
muudab	doc_802069853767_item	2890088	et	3	main
ning	doc_802069853767_item	2890090	et	3	main
õppematerjalid	doc_802069853765_item	2889627	et	3	main
raamatu	doc_802069853765_item	2889628	et	4	main
ja	doc_802069853765_item	2889629	et	3	main
helikasseti	doc_802069853765_item	2889630	et	4	main
6	doc_802069853765_item	2889631	et	2	main
ning	doc_802069853765_item	2889632	et	3	main
selle	doc_802069853765_item	2889647	et	4	main
üle	doc_802069853765_item	2889648	et	3	main
virtuaalkodu	doc_802069853765_item	2889667	et	4	main
soovid	doc_802069853765_item	2889675	et	4	main
d	doc_802069853765_item	2889678	et	4	main
2	doc_802069853765_item	2889680	et	2	main
a	doc_802069853765_item	2889681	et	4	main
just	doc_802069853765_item	2889682	et	3	main
b	doc_802069853765_item	2889683	et	4	main
seega	doc_802069853765_item	2889684	et	4	main
c	doc_802069853765_item	2889685	et	4	main
kuigi	doc_802069853765_item	2889686	et	3	main
d	doc_802069853765_item	2889687	et	4	main
siiski	doc_802069853765_item	2889688	et	4	main
3	doc_802069853765_item	2889689	et	2	main
a	doc_802069853765_item	2889690	et	4	main
vajaduse	doc_802069853765_item	2889691	et	3	main
b	doc_802069853765_item	2889692	et	4	main
vabanduse	doc_802069853765_item	2889693	et	4	main
c	doc_802069853765_item	2889694	et	4	main
varanduse	doc_802069853765_item	2889695	et	3	main
d	doc_802069853765_item	2889696	et	4	main
vabaduse	doc_802069853765_item	2889697	et	4	main
4	doc_802069853765_item	2889698	et	2	main
a	doc_802069853765_item	2889699	et	4	main
tasule	doc_802069853765_item	2889700	et	3	main
tasemele	doc_802069853765_item	2889702	et	3	main
c	doc_802069853765_item	2889703	et	4	main
tasakesi	doc_802069853765_item	2889704	et	3	main
b	doc_802069853765_item	2889701	et	4	main
d	doc_802069853765_item	2889705	et	4	main
tasakaalule	doc_802069853765_item	2889706	et	3	main
5	doc_802069853765_item	2889707	et	2	main
a	doc_802069853765_item	2889708	et	4	main
kokku	doc_802069853765_item	2889709	et	3	main
saada	doc_802069853765_item	2889710	et	4	main
hoida	doc_802069853765_item	2889716	et	3	main
6	doc_802069853765_item	2889720	et	2	main
a	doc_802069853765_item	2889721	et	4	main
ees	doc_802069853765_item	2889737	et	4	main
d	doc_802069853765_item	2889745	et	4	main
a	doc_802069853765_item	2889748	et	4	main
b	doc_802069853765_item	2889750	et	4	main
libe	doc_802069853765_item	2889751	et	3	main
c	doc_802069853765_item	2889752	et	4	main
c	doc_802069853765_item	2889761	et	4	main
külastage	doc_802069853765_item	2889762	et	3	main
iga	doc_802069853766_item	2889772	et	4	main
interaktiivse	doc_802069853766_item	2889802	et	3	main
õppe	doc_802069853766_item	2889803	et	4	main
eelise	doc_802069853766_item	2889813	et	4	main
c	doc_802069853765_item	2889725	et	4	main
kuid	doc_802069853765_item	2889726	et	4	main
et	doc_802069853765_item	2889728	et	3	main
ette	doc_802069853765_item	2889733	et	4	main
c	doc_802069853765_item	2889734	et	4	main
eest	doc_802069853765_item	2889735	et	4	main
kirjutab	doc_802069853765_item	2889740	et	3	main
muudab	doc_802069853765_item	2889746	et	3	main
liigne	doc_802069853765_item	2889749	et	3	main
10	doc_802069853765_item	2889756	et	2	main
minge	doc_802069853765_item	2889764	et	3	main
alt	doc_802069853766_item	2889771	et	4	main
õige	doc_802069853766_item	2889773	et	4	main
vastus	doc_802069853766_item	2889774	et	3	main
annab	doc_802069853766_item	2889775	et	3	main
ühe	doc_802069853766_item	2889776	et	4	main
õpi	doc_802069853766_item	2889778	et	4	main
millal	doc_802069853766_item	2889779	et	3	main
1	doc_802069853766_item	2889780	et	2	main
soovid	doc_802069853766_item	2889781	et	4	main
unusta	doc_802069853766_item	2889782	et	4	main
umbne	doc_802069853766_item	2889783	et	3	main
klassiruum	doc_802069853766_item	2889784	et	3	main
koduõppesüsteem	doc_802069853766_item	2889785	et	3	main
võimaldab	doc_802069853766_item	2889786	et	3	main
sul	doc_802069853766_item	2889787	et	3	main
saada	doc_802069853766_item	2889788	et	4	main
targemaks	doc_802069853766_item	2889789	et	4	main
2	doc_802069853766_item	2889790	et	2	main
just	doc_802069853766_item	2889791	et	3	main
seal	doc_802069853766_item	2889792	et	4	main
kus	doc_802069853766_item	2889793	et	3	main
ja	doc_802069853766_item	2889794	et	3	main
millal	doc_802069853766_item	2889795	et	3	main
sa	doc_802069853766_item	2889796	et	3	main
seda	doc_802069853766_item	2889797	et	3	main
parasjagu	doc_802069853766_item	2889798	et	3	main
soovid	doc_802069853766_item	2889799	et	4	main
käes	doc_802069853766_item	2889800	et	4	main
mis	doc_802069853766_item	2889805	et	4	main
annab	doc_802069853766_item	2889806	et	3	main
3	doc_802069853766_item	2889808	et	2	main
vabaduse	doc_802069853766_item	2889809	et	4	main
planeerida	doc_802069853766_item	2889810	et	3	main
4	doc_802069853766_item	2889818	et	2	main
vaja	doc_802069853766_item	2889829	et	4	main
kontorist	doc_802069853766_item	2889839	et	4	main
ees	doc_802069853766_item	2889855	et	4	main
täidetud	doc_802069853766_item	2889860	et	4	main
õpetaja	doc_802069853766_item	2889864	et	4	main
selle	doc_802069853766_item	2889866	et	4	main
8	doc_802069853766_item	2889868	et	2	main
kõik	doc_802069853766_item	2889878	et	4	main
geniaalne	doc_802069853766_item	2889879	et	3	main
c	doc_802069853766_item	2889922	et	4	main
tasakesi	doc_802069853766_item	2889923	et	3	main
d	doc_802069853766_item	2889936	et	4	main
kokku	doc_802069853766_item	2889937	et	3	main
kuid	doc_802069853766_item	2889945	et	4	main
a	doc_802069853766_item	2889949	et	4	main
b	doc_802069853766_item	2889951	et	4	main
ette	doc_802069853766_item	2889952	et	4	main
c	doc_802069853766_item	2889971	et	4	main
c	doc_802069853766_item	2889980	et	4	main
külastage	doc_802069853766_item	2889981	et	3	main
alt	doc_802069853767_item	2889990	et	4	main
iga	doc_802069853767_item	2889991	et	4	main
õige	doc_802069853767_item	2889992	et	4	main
vastus	doc_802069853767_item	2889993	et	3	main
annab	doc_802069853767_item	2889994	et	3	main
ühe	doc_802069853767_item	2889995	et	4	main
1	doc_802069853767_item	2889999	et	2	main
mis	doc_802069853767_item	2890024	et	4	main
planeerida	doc_802069853767_item	2890029	et	3	main
ning	doc_802069853767_item	2890031	et	3	main
teadmisi	doc_802069853767_item	2890034	et	4	main
on	doc_802069853767_item	2890040	et	4	main
et	doc_802069853767_item	2890042	et	3	main
saada	doc_802069853767_item	2890046	et	4	main
vaja	doc_802069853767_item	2890048	et	4	main
ka	doc_802069853767_item	2890049	et	3	main
pisut	doc_802069853767_item	2890050	et	3	main
tarkust	doc_802069853767_item	2890051	et	4	main
kui	doc_802069853767_item	2890052	et	3	main
helikasseti	doc_802069853767_item	2890068	et	4	main
6	doc_802069853767_item	2890069	et	2	main
kättesaamisel	doc_802069853767_item	2890077	et	4	main
õpetaja	doc_802069853767_item	2890083	et	4	main
vaatab	doc_802069853767_item	2890084	et	3	main
c	doc_802069853767_item	2890123	et	4	main
3	doc_802069853767_item	2890127	et	2	main
b	doc_802069853767_item	2890130	et	4	main
vabanduse	doc_802069853767_item	2890131	et	4	main
b	doc_802069853767_item	2890139	et	4	main
tasemele	doc_802069853767_item	2890140	et	3	main
b	doc_802069853767_item	2890149	et	4	main
kokku	doc_802069853767_item	2890150	et	3	main
d	doc_802069853767_item	2890155	et	4	main
ning	doc_802069853767_item	2890160	et	3	main
b	doc_802069853767_item	2890161	et	4	main
et	doc_802069853767_item	2890166	et	3	main
c	doc_802069853767_item	2890172	et	4	main
a	doc_802069853767_item	2890186	et	4	main
liigne	doc_802069853767_item	2890187	et	3	main
10	doc_802069853767_item	2890194	et	2	main
minge	doc_802069853767_item	2890202	et	3	main
kirjutage	doc_802069853768_item	2890204	et	3	main
alt	doc_802069853768_item	2890209	et	4	main
umbne	doc_802069853768_item	2890221	et	3	main
2	doc_802069853768_item	2890228	et	2	main
just	doc_802069853768_item	2890229	et	3	main
kus	doc_802069853768_item	2890231	et	3	main
ja	doc_802069853768_item	2890232	et	3	main
millal	doc_802069853768_item	2890233	et	3	main
soovid	doc_802069853768_item	2890237	et	4	main
mis	doc_802069853768_item	2890243	et	4	main
eelise	doc_802069853768_item	2890251	et	4	main
omandada	doc_802069853768_item	2890252	et	3	main
et	doc_802069853768_item	2890261	et	3	main
seda	doc_802069853768_item	2890262	et	3	main
vaja	doc_802069853768_item	2890267	et	4	main
raamatu	doc_802069853768_item	2890285	et	4	main
on	doc_802069853766_item	2889828	et	4	main
tarkust	doc_802069853766_item	2889832	et	4	main
õppematerjalid	doc_802069853766_item	2889846	et	3	main
ja	doc_802069853766_item	2889848	et	3	main
6	doc_802069853766_item	2889850	et	2	main
ning	doc_802069853766_item	2889851	et	3	main
kodutöö	doc_802069853766_item	2889852	et	4	main
kursuse	doc_802069853766_item	2889853	et	3	main
7	doc_802069853766_item	2889854	et	2	main
saada	doc_802069853766_item	2889859	et	4	main
tekkinud	doc_802069853766_item	2889876	et	4	main
10	doc_802069853766_item	2889883	et	2	main
virtuaalkodu	doc_802069853766_item	2889886	et	4	main
või	doc_802069853766_item	2889887	et	4	main
postitage	doc_802069853766_item	2889888	et	3	main
kupong	doc_802069853766_item	2889889	et	3	main
1	doc_802069853766_item	2889890	et	2	main
a	doc_802069853766_item	2889891	et	4	main
sobid	doc_802069853766_item	2889892	et	4	main
b	doc_802069853766_item	2889893	et	4	main
soovid	doc_802069853766_item	2889894	et	4	main
c	doc_802069853766_item	2889895	et	4	main
soovitad	doc_802069853766_item	2889896	et	3	main
d	doc_802069853766_item	2889897	et	4	main
solvud	doc_802069853766_item	2889898	et	3	main
2	doc_802069853766_item	2889899	et	2	main
a	doc_802069853766_item	2889900	et	4	main
just	doc_802069853766_item	2889901	et	3	main
b	doc_802069853766_item	2889902	et	4	main
c	doc_802069853766_item	2889904	et	4	main
kuigi	doc_802069853766_item	2889905	et	3	main
seega	doc_802069853766_item	2889903	et	4	main
d	doc_802069853766_item	2889906	et	4	main
siiski	doc_802069853766_item	2889907	et	4	main
3	doc_802069853766_item	2889908	et	2	main
a	doc_802069853766_item	2889909	et	4	main
vajaduse	doc_802069853766_item	2889910	et	3	main
b	doc_802069853766_item	2889911	et	4	main
vabanduse	doc_802069853766_item	2889912	et	4	main
c	doc_802069853766_item	2889913	et	4	main
varanduse	doc_802069853766_item	2889914	et	3	main
d	doc_802069853766_item	2889915	et	4	main
vabaduse	doc_802069853766_item	2889916	et	4	main
4	doc_802069853766_item	2889917	et	2	main
a	doc_802069853766_item	2889918	et	4	main
tasule	doc_802069853766_item	2889919	et	3	main
b	doc_802069853766_item	2889920	et	4	main
d	doc_802069853766_item	2889924	et	4	main
a	doc_802069853766_item	2889940	et	4	main
ning	doc_802069853766_item	2889941	et	3	main
parandab	doc_802069853766_item	2889869	et	3	main
on	doc_802069853766_item	2889880	et	4	main
9	doc_802069853766_item	2889881	et	2	main
meie	doc_802069853766_item	2889885	et	4	main
a	doc_802069853766_item	2889927	et	4	main
panna	doc_802069853766_item	2889938	et	4	main
6	doc_802069853766_item	2889939	et	2	main
c	doc_802069853766_item	2889953	et	4	main
eest	doc_802069853766_item	2889954	et	4	main
b	doc_802069853766_item	2889969	et	4	main
libe	doc_802069853766_item	2889970	et	3	main
b	doc_802069853766_item	2889978	et	4	main
käige	doc_802069853766_item	2889979	et	3	main
sõna	doc_802069853767_item	2889988	et	4	main
teksti	doc_802069853767_item	2889989	et	4	main
punkti	doc_802069853767_item	2889996	et	4	main
sobid	doc_802069853767_item	2890000	et	4	main
interaktiivse	doc_802069853767_item	2890021	et	3	main
ajastu	doc_802069853767_item	2890023	et	4	main
3	doc_802069853767_item	2890027	et	2	main
aega	doc_802069853767_item	2890030	et	4	main
aeg	doc_802069853767_item	2890039	et	3	main
seda	doc_802069853767_item	2890043	et	3	main
on	doc_802069853767_item	2890047	et	4	main
registreerunud	doc_802069853767_item	2890055	et	4	main
saad	doc_802069853767_item	2890056	et	4	main
kontorist	doc_802069853767_item	2890058	et	4	main
kuul	doc_802069853767_item	2890063	et	4	main
kätte	doc_802069853767_item	2890064	et	4	main
õppematerjalid	doc_802069853767_item	2890065	et	3	main
8	doc_802069853767_item	2890087	et	2	main
vead	doc_802069853767_item	2890089	et	4	main
kuigi	doc_802069853767_item	2890124	et	3	main
a	doc_802069853767_item	2890128	et	4	main
vajaduse	doc_802069853767_item	2890129	et	3	main
d	doc_802069853767_item	2890134	et	4	main
vabaduse	doc_802069853767_item	2890135	et	4	main
tasakesi	doc_802069853767_item	2890142	et	3	main
5	doc_802069853767_item	2890145	et	2	main
hoida	doc_802069853767_item	2890154	et	3	main
c	doc_802069853767_item	2890163	et	4	main
kuid	doc_802069853767_item	2890164	et	4	main
kirjutab	doc_802069853767_item	2890178	et	3	main
c	doc_802069853767_item	2890181	et	4	main
parandab	doc_802069853767_item	2890182	et	3	main
d	doc_802069853767_item	2890183	et	4	main
muudab	doc_802069853767_item	2890184	et	3	main
9	doc_802069853767_item	2890185	et	2	main
tulge	doc_802069853767_item	2890196	et	3	main
b	doc_802069853767_item	2890197	et	4	main
d	doc_802069853767_item	2890201	et	4	main
lünka	doc_802069853768_item	2890205	et	4	main
sobiv	doc_802069853768_item	2890206	et	4	main
iga	doc_802069853768_item	2890210	et	4	main
õige	doc_802069853768_item	2890211	et	4	main
vastus	doc_802069853768_item	2890212	et	3	main
annab	doc_802069853768_item	2890213	et	3	main
millal	doc_802069853768_item	2890217	et	3	main
ka	doc_802069853766_item	2889875	et	3	main
lihtne	doc_802069853766_item	2889882	et	3	main
tasemele	doc_802069853766_item	2889921	et	3	main
kokku	doc_802069853766_item	2889928	et	3	main
b	doc_802069853766_item	2889930	et	4	main
kokku	doc_802069853766_item	2889931	et	3	main
liita	doc_802069853766_item	2889932	et	4	main
b	doc_802069853766_item	2889942	et	4	main
vaid	doc_802069853766_item	2889943	et	3	main
et	doc_802069853766_item	2889947	et	3	main
taga	doc_802069853766_item	2889950	et	4	main
d	doc_802069853766_item	2889955	et	4	main
8	doc_802069853766_item	2889957	et	2	main
a	doc_802069853766_item	2889958	et	4	main
kirjutab	doc_802069853766_item	2889959	et	3	main
harjutus	doc_802069853767_item	2889984	et	4	main
kirjutage	doc_802069853767_item	2889985	et	3	main
sobiv	doc_802069853767_item	2889987	et	4	main
unusta	doc_802069853767_item	2890001	et	4	main
umbne	doc_802069853767_item	2890002	et	3	main
klassiruum	doc_802069853767_item	2890003	et	3	main
koduõppesüsteem	doc_802069853767_item	2890004	et	3	main
võimaldab	doc_802069853767_item	2890005	et	3	main
saada	doc_802069853767_item	2890007	et	4	main
targemaks	doc_802069853767_item	2890008	et	4	main
sul	doc_802069853767_item	2890006	et	3	main
2	doc_802069853767_item	2890009	et	2	main
siiski	doc_802069853767_item	2890010	et	4	main
seal	doc_802069853767_item	2890011	et	4	main
kus	doc_802069853767_item	2890012	et	3	main
ja	doc_802069853767_item	2890013	et	3	main
millal	doc_802069853767_item	2890014	et	3	main
sa	doc_802069853767_item	2890015	et	3	main
seda	doc_802069853767_item	2890016	et	3	main
parasjagu	doc_802069853767_item	2890017	et	3	main
soovid	doc_802069853767_item	2890018	et	4	main
käes	doc_802069853767_item	2890019	et	4	main
on	doc_802069853767_item	2890020	et	4	main
õppe	doc_802069853767_item	2890022	et	4	main
4	doc_802069853767_item	2890037	et	2	main
raha	doc_802069853767_item	2890041	et	4	main
5	doc_802069853767_item	2890044	et	2	main
kursusele	doc_802069853767_item	2890054	et	3	main
lähimast	doc_802069853767_item	2890060	et	4	main
postiasutusest	doc_802069853767_item	2890061	et	4	main
et	doc_802069853767_item	2890070	et	3	main
7	doc_802069853767_item	2890073	et	2	main
taga	doc_802069853767_item	2890074	et	4	main
tasud	doc_802069853767_item	2890075	et	4	main
täidetud	doc_802069853767_item	2890079	et	4	main
kodutöö	doc_802069853767_item	2890080	et	4	main
d	doc_802069853766_item	2889946	et	4	main
ees	doc_802069853766_item	2889956	et	4	main
parandab	doc_802069853766_item	2889963	et	3	main
d	doc_802069853766_item	2889964	et	4	main
muudab	doc_802069853766_item	2889965	et	3	main
9	doc_802069853766_item	2889966	et	2	main
a	doc_802069853766_item	2889967	et	4	main
liigne	doc_802069853766_item	2889968	et	3	main
a	doc_802069853766_item	2889976	et	4	main
tulge	doc_802069853766_item	2889977	et	3	main
minge	doc_802069853766_item	2889983	et	3	main
millal	doc_802069853767_item	2889998	et	3	main
annab	doc_802069853767_item	2890025	et	3	main
vastavalt	doc_802069853767_item	2890035	et	4	main
individuaalsele	doc_802069853767_item	2890036	et	3	main
tasakesi	doc_802069853767_item	2890038	et	3	main
kokku	doc_802069853767_item	2890045	et	3	main
või	doc_802069853767_item	2890059	et	4	main
raamatu	doc_802069853767_item	2890066	et	4	main
ja	doc_802069853767_item	2890067	et	3	main
selle	doc_802069853767_item	2890076	et	4	main
meile	doc_802069853767_item	2890081	et	4	main
tagasi	doc_802069853767_item	2890082	et	3	main
vastab	doc_802069853767_item	2890091	et	3	main
vajaduse	doc_802069853767_item	2890092	et	3	main
korral	doc_802069853767_item	2890093	et	4	main
ka	doc_802069853767_item	2890094	et	3	main
lisaküsimustele	doc_802069853767_item	2890096	et	4	main
tekkinud	doc_802069853767_item	2890095	et	4	main
kõik	doc_802069853767_item	2890097	et	4	main
geniaalne	doc_802069853767_item	2890098	et	3	main
on	doc_802069853767_item	2890099	et	4	main
9	doc_802069853767_item	2890100	et	2	main
lihtne	doc_802069853767_item	2890101	et	3	main
10	doc_802069853767_item	2890102	et	2	main
tulge	doc_802069853767_item	2890103	et	3	main
meie	doc_802069853767_item	2890104	et	4	main
virtuaalkodu	doc_802069853767_item	2890105	et	4	main
või	doc_802069853767_item	2890106	et	4	main
postitage	doc_802069853767_item	2890107	et	3	main
kupong	doc_802069853767_item	2890108	et	3	main
1	doc_802069853767_item	2890109	et	2	main
a	doc_802069853767_item	2890110	et	4	main
sobid	doc_802069853767_item	2890111	et	4	main
b	doc_802069853767_item	2890112	et	4	main
soovid	doc_802069853767_item	2890113	et	4	main
c	doc_802069853767_item	2890114	et	4	main
soovitad	doc_802069853767_item	2890115	et	3	main
d	doc_802069853767_item	2890116	et	4	main
solvud	doc_802069853767_item	2890117	et	3	main
2	doc_802069853767_item	2890118	et	2	main
a	doc_802069853767_item	2890119	et	4	main
just	doc_802069853767_item	2890120	et	3	main
seega	doc_802069853767_item	2890122	et	4	main
c	doc_802069853767_item	2890132	et	4	main
d	doc_802069853767_item	2890143	et	4	main
tasakaalule	doc_802069853767_item	2890144	et	3	main
a	doc_802069853767_item	2890146	et	4	main
kokku	doc_802069853767_item	2890147	et	3	main
saada	doc_802069853767_item	2890148	et	4	main
panna	doc_802069853767_item	2890157	et	4	main
a	doc_802069853767_item	2890159	et	4	main
vaid	doc_802069853767_item	2890162	et	3	main
7	doc_802069853767_item	2890167	et	2	main
d	doc_802069853767_item	2890125	et	4	main
varanduse	doc_802069853767_item	2890133	et	3	main
c	doc_802069853767_item	2890141	et	4	main
liita	doc_802069853767_item	2890151	et	4	main
kokku	doc_802069853767_item	2890156	et	3	main
ette	doc_802069853767_item	2890171	et	4	main
8	doc_802069853767_item	2890176	et	2	main
b	doc_802069853767_item	2890188	et	4	main
libe	doc_802069853767_item	2890189	et	3	main
c	doc_802069853767_item	2890199	et	4	main
külastage	doc_802069853767_item	2890200	et	3	main
ühe	doc_802069853768_item	2890214	et	4	main
1	doc_802069853768_item	2890218	et	2	main
soovib	doc_802069853768_item	2890219	et	3	main
unusta	doc_802069853768_item	2890220	et	4	main
klassiruum	doc_802069853768_item	2890222	et	3	main
võimaldab	doc_802069853768_item	2890224	et	3	main
seda	doc_802069853768_item	2890235	et	3	main
interaktiivse	doc_802069853768_item	2890240	et	3	main
ajastu	doc_802069853768_item	2890242	et	4	main
annab	doc_802069853768_item	2890244	et	3	main
sulle	doc_802069853768_item	2890245	et	3	main
planeerida	doc_802069853768_item	2890248	et	3	main
aega	doc_802069853768_item	2890249	et	4	main
ning	doc_802069853768_item	2890250	et	3	main
on	doc_802069853768_item	2890266	et	4	main
kursusele	doc_802069853768_item	2890273	et	3	main
postiasutusest	doc_802069853768_item	2890280	et	4	main
igal	doc_802069853768_item	2890281	et	3	main
kuul	doc_802069853768_item	2890282	et	4	main
selle	doc_802069853768_item	2890295	et	4	main
meile	doc_802069853768_item	2890300	et	4	main
tagasi	doc_802069853768_item	2890301	et	3	main
kirjutab	doc_802069853768_item	2890307	et	3	main
vead	doc_802069853768_item	2890308	et	4	main
ka	doc_802069853768_item	2890313	et	3	main
10	doc_802069853768_item	2890321	et	2	main
meie	doc_802069853768_item	2890323	et	4	main
soovid	doc_802069853768_item	2890332	et	4	main
vajaduse	doc_802069853768_item	2890348	et	3	main
b	doc_802069853768_item	2890358	et	4	main
tasemele	doc_802069853768_item	2890359	et	3	main
c	doc_802069853768_item	2890360	et	4	main
c	doc_802069853768_item	2890391	et	4	main
b	doc_802069853768_item	2890398	et	4	main
palub	doc_802069853768_item	2890399	et	3	main
a	doc_802069853768_item	2890405	et	4	main
liikuv	doc_802069853768_item	2890410	et	4	main
lihtne	doc_802069853768_item	2890412	et	3	main
minge	doc_802069853768_item	2890421	et	3	main
kirjutage	doc_802069853769_item	2890423	et	3	main
teksti	doc_802069853769_item	2890427	et	4	main
soovid	doc_802069853769_item	2890438	et	4	main
just	doc_802069853769_item	2890448	et	3	main
kus	doc_802069853769_item	2890450	et	3	main
millal	doc_802069853769_item	2890452	et	3	main
seda	doc_802069853769_item	2890454	et	3	main
käes	doc_802069853769_item	2890457	et	4	main
on	doc_802069853769_item	2890458	et	4	main
interaktiivse	doc_802069853769_item	2890459	et	3	main
aeg	doc_802069853769_item	2890477	et	3	main
raha	doc_802069853769_item	2890479	et	4	main
panna	doc_802069853769_item	2890484	et	4	main
on	doc_802069853769_item	2890485	et	4	main
kontorist	doc_802069853769_item	2890496	et	4	main
üle	doc_802069853769_item	2890524	et	3	main
kõik	doc_802069853769_item	2890535	et	4	main
geniaalne	doc_802069853769_item	2890536	et	3	main
kupong	doc_802069853769_item	2890546	et	3	main
soovid	doc_802069853769_item	2890551	et	4	main
soovitad	doc_802069853769_item	2890553	et	3	main
d	doc_802069853769_item	2890554	et	4	main
solvud	doc_802069853769_item	2890555	et	3	main
2	doc_802069853769_item	2890556	et	2	main
c	doc_802069853769_item	2890561	et	4	main
siiski	doc_802069853769_item	2890564	et	4	main
a	doc_802069853769_item	2890566	et	4	main
a	doc_802069853769_item	2890575	et	4	main
tasule	doc_802069853769_item	2890576	et	3	main
b	doc_802069853767_item	2890121	et	4	main
siiski	doc_802069853767_item	2890126	et	4	main
4	doc_802069853767_item	2890136	et	2	main
a	doc_802069853767_item	2890137	et	4	main
tasule	doc_802069853767_item	2890138	et	3	main
c	doc_802069853767_item	2890152	et	4	main
kokku	doc_802069853767_item	2890153	et	3	main
6	doc_802069853767_item	2890158	et	2	main
d	doc_802069853767_item	2890165	et	4	main
a	doc_802069853767_item	2890168	et	4	main
eest	doc_802069853767_item	2890173	et	4	main
d	doc_802069853767_item	2890174	et	4	main
palub	doc_802069853767_item	2890180	et	3	main
a	doc_802069853767_item	2890195	et	4	main
käige	doc_802069853767_item	2890198	et	3	main
sõna	doc_802069853768_item	2890207	et	4	main
teksti	doc_802069853768_item	2890208	et	4	main
punkti	doc_802069853768_item	2890215	et	4	main
parasjagu	doc_802069853768_item	2890236	et	3	main
on	doc_802069853768_item	2890239	et	4	main
teadmisi	doc_802069853768_item	2890253	et	4	main
ka	doc_802069853768_item	2890268	et	3	main
kui	doc_802069853768_item	2890271	et	3	main
registreerunud	doc_802069853768_item	2890274	et	4	main
helikasseti	doc_802069853768_item	2890287	et	4	main
ning	doc_802069853768_item	2890289	et	3	main
kursuse	doc_802069853768_item	2890291	et	3	main
eest	doc_802069853768_item	2890293	et	4	main
tasud	doc_802069853768_item	2890294	et	4	main
täidetud	doc_802069853768_item	2890298	et	4	main
kodutöö	doc_802069853768_item	2890299	et	4	main
8	doc_802069853768_item	2890306	et	2	main
korral	doc_802069853768_item	2890312	et	4	main
9	doc_802069853768_item	2890319	et	2	main
taga	doc_802069853767_item	2890169	et	4	main
b	doc_802069853767_item	2890170	et	4	main
ees	doc_802069853767_item	2890175	et	4	main
a	doc_802069853767_item	2890177	et	4	main
b	doc_802069853767_item	2890179	et	4	main
c	doc_802069853767_item	2890190	et	4	main
liikuv	doc_802069853767_item	2890191	et	4	main
d	doc_802069853767_item	2890192	et	4	main
lihtne	doc_802069853767_item	2890193	et	3	main
harjutus	doc_802069853768_item	2890203	et	4	main
õpi	doc_802069853768_item	2890216	et	4	main
sul	doc_802069853768_item	2890225	et	3	main
targemaks	doc_802069853768_item	2890227	et	4	main
käes	doc_802069853768_item	2890238	et	4	main
vastavalt	doc_802069853768_item	2890254	et	4	main
individuaalsele	doc_802069853768_item	2890255	et	3	main
4	doc_802069853768_item	2890256	et	2	main
on	doc_802069853768_item	2890259	et	4	main
raha	doc_802069853768_item	2890260	et	4	main
5	doc_802069853768_item	2890263	et	2	main
kokku	doc_802069853768_item	2890264	et	3	main
saada	doc_802069853768_item	2890265	et	4	main
saad	doc_802069853768_item	2890275	et	4	main
meie	doc_802069853768_item	2890276	et	4	main
kontorist	doc_802069853768_item	2890277	et	4	main
kätte	doc_802069853768_item	2890283	et	4	main
õppematerjalid	doc_802069853768_item	2890284	et	3	main
6	doc_802069853768_item	2890288	et	2	main
selle	doc_802069853768_item	2890304	et	4	main
kõik	doc_802069853768_item	2890316	et	4	main
virtuaalkodu	doc_802069853768_item	2890324	et	4	main
1	doc_802069853768_item	2890328	et	2	main
sobid	doc_802069853768_item	2890330	et	4	main
b	doc_802069853768_item	2890331	et	4	main
b	doc_802069853768_item	2890349	et	4	main
c	doc_802069853768_item	2890351	et	4	main
varanduse	doc_802069853768_item	2890352	et	3	main
saada	doc_802069853768_item	2890367	et	4	main
kokku	doc_802069853768_item	2890369	et	3	main
ees	doc_802069853768_item	2890394	et	4	main
8	doc_802069853768_item	2890395	et	2	main
a	doc_802069853768_item	2890396	et	4	main
kirjutab	doc_802069853768_item	2890397	et	3	main
d	doc_802069853768_item	2890411	et	4	main
10	doc_802069853768_item	2890413	et	2	main
tulge	doc_802069853768_item	2890415	et	3	main
alt	doc_802069853769_item	2890428	et	4	main
õige	doc_802069853769_item	2890430	et	4	main
vastus	doc_802069853769_item	2890431	et	3	main
võimaldab	doc_802069853769_item	2890443	et	3	main
seal	doc_802069853769_item	2890449	et	4	main
ja	doc_802069853769_item	2890451	et	3	main
sa	doc_802069853769_item	2890453	et	3	main
soovid	doc_802069853769_item	2890456	et	4	main
3	doc_802069853769_item	2890465	et	2	main
eelise	doc_802069853769_item	2890470	et	4	main
vaja	doc_802069853769_item	2890486	et	4	main
selle	doc_802069853769_item	2890523	et	4	main
vead	doc_802069853769_item	2890527	et	4	main
vastab	doc_802069853769_item	2890529	et	3	main
on	doc_802069853769_item	2890537	et	4	main
liigne	doc_802069853769_item	2890539	et	3	main
minge	doc_802069853769_item	2890541	et	3	main
meie	doc_802069853769_item	2890542	et	4	main
virtuaalkodu	doc_802069853769_item	2890543	et	4	main
a	doc_802069853769_item	2890548	et	4	main
b	doc_802069853769_item	2890550	et	4	main
c	doc_802069853769_item	2890552	et	4	main
d	doc_802069853769_item	2890563	et	4	main
kokku	doc_802069853769_item	2890585	et	3	main
kokku	doc_802069853769_item	2890588	et	3	main
liita	doc_802069853769_item	2890589	et	4	main
c	doc_802069853769_item	2890590	et	4	main
c	doc_802069853769_item	2890601	et	4	main
7	doc_802069853769_item	2890605	et	2	main
taga	doc_802069853769_item	2890607	et	4	main
8	doc_802069853769_item	2890614	et	2	main
a	doc_802069853769_item	2890615	et	4	main
kirjutab	doc_802069853769_item	2890616	et	3	main
liikuv	doc_802069853769_item	2890629	et	4	main
10	doc_802069853769_item	2890632	et	2	main
käige	doc_802069853769_item	2890636	et	3	main
külastage	doc_802069853769_item	2890638	et	3	main
koduõppesüsteem	doc_802069853768_item	2890223	et	3	main
saada	doc_802069853768_item	2890226	et	4	main
seal	doc_802069853768_item	2890230	et	4	main
sa	doc_802069853768_item	2890234	et	3	main
õppe	doc_802069853768_item	2890241	et	4	main
3	doc_802069853768_item	2890246	et	2	main
varanduse	doc_802069853768_item	2890247	et	3	main
tasule	doc_802069853768_item	2890257	et	3	main
aeg	doc_802069853768_item	2890258	et	3	main
pisut	doc_802069853768_item	2890269	et	3	main
tarkust	doc_802069853768_item	2890270	et	4	main
oled	doc_802069853768_item	2890272	et	3	main
või	doc_802069853768_item	2890278	et	4	main
lähimast	doc_802069853768_item	2890279	et	4	main
ja	doc_802069853768_item	2890286	et	3	main
kodutöö	doc_802069853768_item	2890290	et	4	main
7	doc_802069853768_item	2890292	et	2	main
saada	doc_802069853768_item	2890297	et	4	main
vaatab	doc_802069853768_item	2890303	et	3	main
üle	doc_802069853768_item	2890305	et	3	main
ning	doc_802069853768_item	2890309	et	3	main
vastab	doc_802069853768_item	2890310	et	3	main
geniaalne	doc_802069853768_item	2890317	et	3	main
on	doc_802069853768_item	2890318	et	4	main
liikuv	doc_802069853768_item	2890320	et	4	main
minge	doc_802069853768_item	2890322	et	3	main
postitage	doc_802069853768_item	2890326	et	3	main
b	doc_802069853768_item	2890340	et	4	main
seega	doc_802069853768_item	2890341	et	4	main
c	doc_802069853768_item	2890342	et	4	main
kuigi	doc_802069853768_item	2890343	et	3	main
d	doc_802069853768_item	2890344	et	4	main
d	doc_802069853768_item	2890353	et	4	main
vabaduse	doc_802069853768_item	2890354	et	4	main
4	doc_802069853768_item	2890355	et	2	main
5	doc_802069853768_item	2890364	et	2	main
a	doc_802069853768_item	2890365	et	4	main
kokku	doc_802069853768_item	2890366	et	3	main
d	doc_802069853768_item	2890393	et	4	main
d	doc_802069853768_item	2890402	et	4	main
9	doc_802069853768_item	2890404	et	2	main
libe	doc_802069853768_item	2890408	et	3	main
a	doc_802069853768_item	2890414	et	4	main
b	doc_802069853768_item	2890416	et	4	main
käige	doc_802069853768_item	2890417	et	3	main
c	doc_802069853768_item	2890418	et	4	main
harjutus	doc_802069853769_item	2890422	et	4	main
annab	doc_802069853769_item	2890432	et	3	main
unusta	doc_802069853769_item	2890439	et	4	main
umbne	doc_802069853769_item	2890440	et	3	main
klassiruum	doc_802069853769_item	2890441	et	3	main
sul	doc_802069853769_item	2890444	et	3	main
õppe	doc_802069853769_item	2890460	et	4	main
vabaduse	doc_802069853769_item	2890466	et	4	main
tasemele	doc_802069853769_item	2890476	et	3	main
et	doc_802069853769_item	2890480	et	3	main
seda	doc_802069853769_item	2890481	et	3	main
kokku	doc_802069853769_item	2890483	et	3	main
pisut	doc_802069853769_item	2890488	et	3	main
registreerunud	doc_802069853769_item	2890493	et	4	main
lähimast	doc_802069853769_item	2890498	et	4	main
8	doc_802069853769_item	2890525	et	2	main
korral	doc_802069853769_item	2890531	et	4	main
9	doc_802069853769_item	2890538	et	2	main
sobid	doc_802069853769_item	2890549	et	4	main
a	doc_802069853769_item	2890557	et	4	main
just	doc_802069853769_item	2890558	et	3	main
vajaduse	doc_802069853769_item	2890567	et	3	main
vabanduse	doc_802069853769_item	2890569	et	4	main
varanduse	doc_802069853769_item	2890571	et	3	main
tasemele	doc_802069853769_item	2890578	et	3	main
c	doc_802069853769_item	2890579	et	4	main
tasakesi	doc_802069853769_item	2890580	et	3	main
saada	doc_802069853769_item	2890586	et	4	main
a	doc_802069853769_item	2890597	et	4	main
ning	doc_802069853769_item	2890598	et	3	main
b	doc_802069853769_item	2890599	et	4	main
vaid	doc_802069853769_item	2890600	et	3	main
et	doc_802069853769_item	2890604	et	3	main
d	doc_802069853769_item	2890612	et	4	main
kättesaamisel	doc_802069853768_item	2890296	et	4	main
õpetaja	doc_802069853768_item	2890302	et	4	main
vajaduse	doc_802069853768_item	2890311	et	3	main
tekkinud	doc_802069853768_item	2890314	et	4	main
lisaküsimustele	doc_802069853768_item	2890315	et	4	main
või	doc_802069853768_item	2890325	et	4	main
a	doc_802069853768_item	2890329	et	4	main
a	doc_802069853768_item	2890347	et	4	main
vabanduse	doc_802069853768_item	2890350	et	4	main
tasakesi	doc_802069853768_item	2890361	et	3	main
d	doc_802069853768_item	2890362	et	4	main
tasakaalule	doc_802069853768_item	2890363	et	3	main
b	doc_802069853768_item	2890368	et	4	main
eest	doc_802069853768_item	2890392	et	4	main
c	doc_802069853768_item	2890400	et	4	main
parandab	doc_802069853768_item	2890401	et	3	main
liigne	doc_802069853768_item	2890406	et	3	main
c	doc_802069853768_item	2890409	et	4	main
lünka	doc_802069853769_item	2890424	et	4	main
õpi	doc_802069853769_item	2890435	et	4	main
millal	doc_802069853769_item	2890436	et	3	main
1	doc_802069853769_item	2890437	et	2	main
2	doc_802069853769_item	2890447	et	2	main
parasjagu	doc_802069853769_item	2890455	et	3	main
planeerida	doc_802069853769_item	2890467	et	3	main
ning	doc_802069853769_item	2890469	et	3	main
omandada	doc_802069853769_item	2890471	et	3	main
teadmisi	doc_802069853769_item	2890472	et	4	main
vastavalt	doc_802069853769_item	2890473	et	4	main
individuaalsele	doc_802069853769_item	2890474	et	3	main
4	doc_802069853769_item	2890475	et	2	main
ka	doc_802069853769_item	2890487	et	3	main
kui	doc_802069853769_item	2890490	et	3	main
kursusele	doc_802069853769_item	2890492	et	3	main
saad	doc_802069853769_item	2890494	et	4	main
meie	doc_802069853769_item	2890495	et	4	main
vaatab	doc_802069853769_item	2890522	et	3	main
parandab	doc_802069853769_item	2890526	et	3	main
vajaduse	doc_802069853769_item	2890530	et	3	main
ka	doc_802069853769_item	2890532	et	3	main
tekkinud	doc_802069853769_item	2890533	et	4	main
10	doc_802069853769_item	2890540	et	2	main
1	doc_802069853769_item	2890547	et	2	main
b	doc_802069853769_item	2890559	et	4	main
seega	doc_802069853769_item	2890560	et	4	main
vabaduse	doc_802069853769_item	2890573	et	4	main
4	doc_802069853769_item	2890574	et	2	main
a	doc_802069853769_item	2890584	et	4	main
b	doc_802069853769_item	2890587	et	4	main
d	doc_802069853769_item	2890603	et	4	main
eest	doc_802069853769_item	2890611	et	4	main
9	doc_802069853769_item	2890623	et	2	main
b	doc_802069853769_item	2890626	et	4	main
c	doc_802069853769_item	2890628	et	4	main
lünka	doc_802069853770_item	2890643	et	4	main
klassiruum	doc_802069853770_item	2890660	et	3	main
saada	doc_802069853770_item	2890664	et	4	main
sa	doc_802069853770_item	2890672	et	3	main
ajastu	doc_802069853770_item	2890680	et	4	main
teadmisi	doc_802069853770_item	2890691	et	4	main
et	doc_802069853770_item	2890699	et	3	main
registreerunud	doc_802069853770_item	2890712	et	4	main
6	doc_802069853770_item	2890726	et	2	main
kodutöö	doc_802069853770_item	2890728	et	4	main
kättesaamisel	doc_802069853770_item	2890734	et	4	main
vaatab	doc_802069853770_item	2890741	et	3	main
kõik	doc_802069853770_item	2890754	et	4	main
geniaalne	doc_802069853770_item	2890755	et	3	main
b	doc_802069853770_item	2890769	et	4	main
a	doc_802069853770_item	2890803	et	4	main
kokku	doc_802069853770_item	2890804	et	3	main
saada	doc_802069853770_item	2890805	et	4	main
d	doc_802069853770_item	2890812	et	4	main
kokku	doc_802069853770_item	2890813	et	3	main
panna	doc_802069853770_item	2890814	et	4	main
vaid	doc_802069853770_item	2890819	et	3	main
c	doc_802069853770_item	2890820	et	4	main
kuid	doc_802069853770_item	2890821	et	4	main
7	doc_802069853770_item	2890824	et	2	main
eest	doc_802069853770_item	2890830	et	4	main
palub	doc_802069853770_item	2890837	et	3	main
d	doc_802069853770_item	2890840	et	4	main
kupong	doc_802069853768_item	2890327	et	3	main
c	doc_802069853768_item	2890333	et	4	main
soovitad	doc_802069853768_item	2890334	et	3	main
d	doc_802069853768_item	2890335	et	4	main
solvud	doc_802069853768_item	2890336	et	3	main
2	doc_802069853768_item	2890337	et	2	main
a	doc_802069853768_item	2890338	et	4	main
just	doc_802069853768_item	2890339	et	3	main
siiski	doc_802069853768_item	2890345	et	4	main
3	doc_802069853768_item	2890346	et	2	main
a	doc_802069853768_item	2890356	et	4	main
tasule	doc_802069853768_item	2890357	et	3	main
liita	doc_802069853768_item	2890370	et	4	main
c	doc_802069853768_item	2890371	et	4	main
kokku	doc_802069853768_item	2890372	et	3	main
hoida	doc_802069853768_item	2890373	et	3	main
d	doc_802069853768_item	2890374	et	4	main
kokku	doc_802069853768_item	2890375	et	3	main
panna	doc_802069853768_item	2890376	et	4	main
6	doc_802069853768_item	2890377	et	2	main
a	doc_802069853768_item	2890378	et	4	main
ning	doc_802069853768_item	2890379	et	3	main
b	doc_802069853768_item	2890380	et	4	main
vaid	doc_802069853768_item	2890381	et	3	main
c	doc_802069853768_item	2890382	et	4	main
kuid	doc_802069853768_item	2890383	et	4	main
d	doc_802069853768_item	2890384	et	4	main
et	doc_802069853768_item	2890385	et	3	main
7	doc_802069853768_item	2890386	et	2	main
a	doc_802069853768_item	2890387	et	4	main
taga	doc_802069853768_item	2890388	et	4	main
b	doc_802069853768_item	2890389	et	4	main
ette	doc_802069853768_item	2890390	et	4	main
muudab	doc_802069853768_item	2890403	et	3	main
b	doc_802069853768_item	2890407	et	4	main
külastage	doc_802069853768_item	2890419	et	3	main
d	doc_802069853768_item	2890420	et	4	main
sobiv	doc_802069853769_item	2890425	et	4	main
sõna	doc_802069853769_item	2890426	et	4	main
iga	doc_802069853769_item	2890429	et	4	main
ühe	doc_802069853769_item	2890433	et	4	main
punkti	doc_802069853769_item	2890434	et	4	main
koduõppesüsteem	doc_802069853769_item	2890442	et	3	main
saada	doc_802069853769_item	2890445	et	4	main
targemaks	doc_802069853769_item	2890446	et	4	main
ajastu	doc_802069853769_item	2890461	et	4	main
mis	doc_802069853769_item	2890462	et	4	main
annab	doc_802069853769_item	2890463	et	3	main
sulle	doc_802069853769_item	2890464	et	3	main
aega	doc_802069853769_item	2890468	et	4	main
on	doc_802069853769_item	2890478	et	4	main
5	doc_802069853769_item	2890482	et	2	main
tarkust	doc_802069853769_item	2890489	et	4	main
oled	doc_802069853769_item	2890491	et	3	main
või	doc_802069853769_item	2890497	et	4	main
postiasutusest	doc_802069853769_item	2890499	et	4	main
igal	doc_802069853769_item	2890500	et	3	main
kuul	doc_802069853769_item	2890501	et	4	main
kätte	doc_802069853769_item	2890502	et	4	main
õppematerjalid	doc_802069853769_item	2890503	et	3	main
raamatu	doc_802069853769_item	2890504	et	4	main
ja	doc_802069853769_item	2890505	et	3	main
helikasseti	doc_802069853769_item	2890506	et	4	main
6	doc_802069853769_item	2890507	et	2	main
ning	doc_802069853769_item	2890508	et	3	main
kodutöö	doc_802069853769_item	2890509	et	4	main
kursuse	doc_802069853769_item	2890510	et	3	main
7	doc_802069853769_item	2890511	et	2	main
ees	doc_802069853769_item	2890512	et	4	main
tasud	doc_802069853769_item	2890513	et	4	main
selle	doc_802069853769_item	2890514	et	4	main
kättesaamisel	doc_802069853769_item	2890515	et	4	main
saada	doc_802069853769_item	2890516	et	4	main
täidetud	doc_802069853769_item	2890517	et	4	main
kodutöö	doc_802069853769_item	2890518	et	4	main
meile	doc_802069853769_item	2890519	et	4	main
tagasi	doc_802069853769_item	2890520	et	3	main
õpetaja	doc_802069853769_item	2890521	et	4	main
ning	doc_802069853769_item	2890528	et	3	main
lisaküsimustele	doc_802069853769_item	2890534	et	4	main
või	doc_802069853769_item	2890544	et	4	main
postitage	doc_802069853769_item	2890545	et	3	main
kuigi	doc_802069853769_item	2890562	et	3	main
3	doc_802069853769_item	2890565	et	2	main
b	doc_802069853769_item	2890568	et	4	main
c	doc_802069853769_item	2890570	et	4	main
d	doc_802069853769_item	2890572	et	4	main
d	doc_802069853769_item	2890581	et	4	main
tasakaalule	doc_802069853769_item	2890582	et	3	main
5	doc_802069853769_item	2890583	et	2	main
panna	doc_802069853769_item	2890595	et	4	main
6	doc_802069853769_item	2890596	et	2	main
c	doc_802069853769_item	2890610	et	4	main
b	doc_802069853769_item	2890617	et	4	main
palub	doc_802069853769_item	2890618	et	3	main
c	doc_802069853769_item	2890619	et	4	main
parandab	doc_802069853769_item	2890620	et	3	main
tulge	doc_802069853769_item	2890634	et	3	main
sobiv	doc_802069853770_item	2890644	et	4	main
iga	doc_802069853770_item	2890648	et	4	main
unusta	doc_802069853770_item	2890658	et	4	main
koduõppesüsteem	doc_802069853770_item	2890661	et	3	main
targemaks	doc_802069853770_item	2890665	et	4	main
vastavalt	doc_802069853770_item	2890692	et	4	main
4	doc_802069853770_item	2890694	et	2	main
tasemele	doc_802069853770_item	2890695	et	3	main
aeg	doc_802069853770_item	2890696	et	3	main
on	doc_802069853770_item	2890697	et	4	main
kokku	doc_802069853770_item	2890702	et	3	main
saada	doc_802069853770_item	2890703	et	4	main
vaja	doc_802069853770_item	2890705	et	4	main
ka	doc_802069853770_item	2890706	et	3	main
kätte	doc_802069853770_item	2890721	et	4	main
raamatu	doc_802069853770_item	2890723	et	4	main
8	doc_802069853770_item	2890744	et	2	main
vead	doc_802069853770_item	2890746	et	4	main
on	doc_802069853770_item	2890756	et	4	main
9	doc_802069853770_item	2890757	et	2	main
meie	doc_802069853770_item	2890761	et	4	main
või	doc_802069853770_item	2890763	et	4	main
1	doc_802069853770_item	2890766	et	2	main
c	doc_802069853770_item	2890771	et	4	main
d	doc_802069853770_item	2890773	et	4	main
solvud	doc_802069853770_item	2890774	et	3	main
liita	doc_802069853770_item	2890808	et	4	main
ning	doc_802069853770_item	2890817	et	3	main
b	doc_802069853769_item	2890577	et	4	main
kokku	doc_802069853769_item	2890591	et	3	main
hoida	doc_802069853769_item	2890592	et	3	main
d	doc_802069853769_item	2890593	et	4	main
kokku	doc_802069853769_item	2890594	et	3	main
kuid	doc_802069853769_item	2890602	et	4	main
a	doc_802069853769_item	2890606	et	4	main
b	doc_802069853769_item	2890608	et	4	main
ette	doc_802069853769_item	2890609	et	4	main
ees	doc_802069853769_item	2890613	et	4	main
muudab	doc_802069853769_item	2890622	et	3	main
a	doc_802069853769_item	2890633	et	4	main
d	doc_802069853769_item	2890639	et	4	main
minge	doc_802069853769_item	2890640	et	3	main
harjutus	doc_802069853770_item	2890641	et	4	main
kirjutage	doc_802069853770_item	2890642	et	3	main
vastus	doc_802069853770_item	2890650	et	3	main
ühe	doc_802069853770_item	2890652	et	4	main
õpi	doc_802069853770_item	2890654	et	4	main
sobid	doc_802069853770_item	2890657	et	4	main
seal	doc_802069853770_item	2890668	et	4	main
kus	doc_802069853770_item	2890669	et	3	main
millal	doc_802069853770_item	2890671	et	3	main
käes	doc_802069853770_item	2890676	et	4	main
3	doc_802069853770_item	2890684	et	2	main
individuaalsele	doc_802069853770_item	2890693	et	3	main
seda	doc_802069853770_item	2890700	et	3	main
d	doc_802069853769_item	2890621	et	4	main
a	doc_802069853769_item	2890624	et	4	main
liigne	doc_802069853769_item	2890625	et	3	main
libe	doc_802069853769_item	2890627	et	3	main
d	doc_802069853769_item	2890630	et	4	main
lihtne	doc_802069853769_item	2890631	et	3	main
b	doc_802069853769_item	2890635	et	4	main
c	doc_802069853769_item	2890637	et	4	main
sõna	doc_802069853770_item	2890645	et	4	main
õige	doc_802069853770_item	2890649	et	4	main
umbne	doc_802069853770_item	2890659	et	3	main
võimaldab	doc_802069853770_item	2890662	et	3	main
kuigi	doc_802069853770_item	2890667	et	3	main
ja	doc_802069853770_item	2890670	et	3	main
seda	doc_802069853770_item	2890673	et	3	main
soovid	doc_802069853770_item	2890675	et	4	main
on	doc_802069853770_item	2890677	et	4	main
interaktiivse	doc_802069853770_item	2890678	et	3	main
õppe	doc_802069853770_item	2890679	et	4	main
eelise	doc_802069853770_item	2890689	et	4	main
omandada	doc_802069853770_item	2890690	et	3	main
raha	doc_802069853770_item	2890698	et	4	main
on	doc_802069853770_item	2890704	et	4	main
pisut	doc_802069853770_item	2890707	et	3	main
tarkust	doc_802069853770_item	2890708	et	4	main
kui	doc_802069853770_item	2890709	et	3	main
oled	doc_802069853770_item	2890710	et	3	main
kursusele	doc_802069853770_item	2890711	et	3	main
saad	doc_802069853770_item	2890713	et	4	main
meie	doc_802069853770_item	2890714	et	4	main
kontorist	doc_802069853770_item	2890715	et	4	main
või	doc_802069853770_item	2890716	et	4	main
lähimast	doc_802069853770_item	2890717	et	4	main
postiasutusest	doc_802069853770_item	2890718	et	4	main
igal	doc_802069853770_item	2890719	et	3	main
kuul	doc_802069853770_item	2890720	et	4	main
õppematerjalid	doc_802069853770_item	2890722	et	3	main
kuid	doc_802069853770_item	2890727	et	4	main
kursuse	doc_802069853770_item	2890729	et	3	main
ette	doc_802069853770_item	2890731	et	4	main
õpetaja	doc_802069853770_item	2890740	et	4	main
ning	doc_802069853770_item	2890747	et	3	main
vajaduse	doc_802069853770_item	2890749	et	3	main
ka	doc_802069853770_item	2890751	et	3	main
lisaküsimustele	doc_802069853770_item	2890753	et	4	main
tulge	doc_802069853770_item	2890760	et	3	main
soovid	doc_802069853770_item	2890770	et	4	main
5	doc_802069853770_item	2890802	et	2	main
kokku	doc_802069853770_item	2890810	et	3	main
hoida	doc_802069853770_item	2890811	et	3	main
b	doc_802069853770_item	2890818	et	4	main
b	doc_802069853770_item	2890827	et	4	main
ees	doc_802069853770_item	2890832	et	4	main
8	doc_802069853770_item	2890833	et	2	main
9	doc_802069853770_item	2890842	et	2	main
a	doc_802069853770_item	2890852	et	4	main
c	doc_802069853770_item	2890856	et	4	main
teksti	doc_802069853771_item	2890865	et	4	main
vastus	doc_802069853771_item	2890869	et	3	main
koduõppesüsteem	doc_802069853771_item	2890880	et	3	main
sul	doc_802069853771_item	2890882	et	3	main
targemaks	doc_802069853771_item	2890884	et	4	main
interaktiivse	doc_802069853771_item	2890897	et	3	main
õppe	doc_802069853771_item	2890898	et	4	main
planeerida	doc_802069853771_item	2890905	et	3	main
eelise	doc_802069853771_item	2890908	et	4	main
omandada	doc_802069853771_item	2890909	et	3	main
teadmisi	doc_802069853771_item	2890910	et	4	main
seda	doc_802069853771_item	2890919	et	3	main
vaja	doc_802069853771_item	2890924	et	4	main
kui	doc_802069853771_item	2890928	et	3	main
meie	doc_802069853771_item	2890933	et	4	main
kuul	doc_802069853771_item	2890939	et	4	main
ees	doc_802069853771_item	2890950	et	4	main
teksti	doc_802069853770_item	2890646	et	4	main
alt	doc_802069853770_item	2890647	et	4	main
annab	doc_802069853770_item	2890651	et	3	main
punkti	doc_802069853770_item	2890653	et	4	main
millal	doc_802069853770_item	2890655	et	3	main
1	doc_802069853770_item	2890656	et	2	main
sul	doc_802069853770_item	2890663	et	3	main
2	doc_802069853770_item	2890666	et	2	main
parasjagu	doc_802069853770_item	2890674	et	3	main
mis	doc_802069853770_item	2890681	et	4	main
annab	doc_802069853770_item	2890682	et	3	main
sulle	doc_802069853770_item	2890683	et	3	main
vabaduse	doc_802069853770_item	2890685	et	4	main
planeerida	doc_802069853770_item	2890686	et	3	main
aega	doc_802069853770_item	2890687	et	4	main
ning	doc_802069853770_item	2890688	et	3	main
5	doc_802069853770_item	2890701	et	2	main
ja	doc_802069853770_item	2890724	et	3	main
helikasseti	doc_802069853770_item	2890725	et	4	main
saada	doc_802069853770_item	2890735	et	4	main
kodutöö	doc_802069853770_item	2890737	et	4	main
meile	doc_802069853770_item	2890738	et	4	main
tagasi	doc_802069853770_item	2890739	et	3	main
üle	doc_802069853770_item	2890743	et	3	main
parandab	doc_802069853770_item	2890745	et	3	main
lihtne	doc_802069853770_item	2890758	et	3	main
virtuaalkodu	doc_802069853770_item	2890762	et	4	main
postitage	doc_802069853770_item	2890764	et	3	main
soovitad	doc_802069853770_item	2890772	et	3	main
2	doc_802069853770_item	2890775	et	2	main
c	doc_802069853770_item	2890809	et	4	main
ette	doc_802069853770_item	2890828	et	4	main
b	doc_802069853770_item	2890836	et	4	main
parandab	doc_802069853770_item	2890839	et	3	main
ühe	doc_802069853771_item	2890871	et	4	main
klassiruum	doc_802069853771_item	2890879	et	3	main
saada	doc_802069853771_item	2890883	et	4	main
millal	doc_802069853771_item	2890890	et	3	main
sa	doc_802069853771_item	2890891	et	3	main
seda	doc_802069853771_item	2890892	et	3	main
parasjagu	doc_802069853771_item	2890893	et	3	main
soovid	doc_802069853771_item	2890894	et	4	main
ajastu	doc_802069853771_item	2890899	et	4	main
sulle	doc_802069853771_item	2890902	et	3	main
vajaduse	doc_802069853771_item	2890904	et	3	main
aega	doc_802069853771_item	2890906	et	4	main
7	doc_802069853770_item	2890730	et	2	main
tasud	doc_802069853770_item	2890732	et	4	main
selle	doc_802069853770_item	2890733	et	4	main
täidetud	doc_802069853770_item	2890736	et	4	main
selle	doc_802069853770_item	2890742	et	4	main
vastab	doc_802069853770_item	2890748	et	3	main
korral	doc_802069853770_item	2890750	et	4	main
tekkinud	doc_802069853770_item	2890752	et	4	main
10	doc_802069853770_item	2890759	et	2	main
kupong	doc_802069853770_item	2890765	et	3	main
a	doc_802069853770_item	2890767	et	4	main
sobid	doc_802069853770_item	2890768	et	4	main
a	doc_802069853770_item	2890776	et	4	main
just	doc_802069853770_item	2890777	et	3	main
b	doc_802069853770_item	2890778	et	4	main
seega	doc_802069853770_item	2890779	et	4	main
c	doc_802069853770_item	2890780	et	4	main
kuigi	doc_802069853770_item	2890781	et	3	main
d	doc_802069853770_item	2890782	et	4	main
siiski	doc_802069853770_item	2890783	et	4	main
3	doc_802069853770_item	2890784	et	2	main
a	doc_802069853770_item	2890785	et	4	main
vajaduse	doc_802069853770_item	2890786	et	3	main
b	doc_802069853770_item	2890787	et	4	main
vabanduse	doc_802069853770_item	2890788	et	4	main
c	doc_802069853770_item	2890789	et	4	main
varanduse	doc_802069853770_item	2890790	et	3	main
d	doc_802069853770_item	2890791	et	4	main
vabaduse	doc_802069853770_item	2890792	et	4	main
4	doc_802069853770_item	2890793	et	2	main
a	doc_802069853770_item	2890794	et	4	main
tasule	doc_802069853770_item	2890795	et	3	main
b	doc_802069853770_item	2890796	et	4	main
tasemele	doc_802069853770_item	2890797	et	3	main
c	doc_802069853770_item	2890798	et	4	main
tasakesi	doc_802069853770_item	2890799	et	3	main
tasakaalule	doc_802069853770_item	2890801	et	3	main
d	doc_802069853770_item	2890800	et	4	main
b	doc_802069853770_item	2890806	et	4	main
kokku	doc_802069853770_item	2890807	et	3	main
6	doc_802069853770_item	2890815	et	2	main
a	doc_802069853770_item	2890816	et	4	main
c	doc_802069853770_item	2890829	et	4	main
a	doc_802069853770_item	2890834	et	4	main
c	doc_802069853770_item	2890838	et	4	main
a	doc_802069853770_item	2890843	et	4	main
b	doc_802069853770_item	2890845	et	4	main
d	doc_802069853770_item	2890849	et	4	main
lihtne	doc_802069853770_item	2890850	et	3	main
10	doc_802069853770_item	2890851	et	2	main
käige	doc_802069853770_item	2890855	et	3	main
iga	doc_802069853771_item	2890867	et	4	main
unusta	doc_802069853771_item	2890877	et	4	main
käes	doc_802069853771_item	2890895	et	4	main
vastavalt	doc_802069853771_item	2890911	et	4	main
individuaalsele	doc_802069853771_item	2890912	et	3	main
4	doc_802069853771_item	2890913	et	2	main
tasule	doc_802069853771_item	2890914	et	3	main
aeg	doc_802069853771_item	2890915	et	3	main
5	doc_802069853771_item	2890920	et	2	main
panna	doc_802069853771_item	2890922	et	4	main
pisut	doc_802069853771_item	2890926	et	3	main
oled	doc_802069853771_item	2890929	et	3	main
või	doc_802069853771_item	2890935	et	4	main
raamatu	doc_802069853771_item	2890942	et	4	main
ja	doc_802069853771_item	2890943	et	3	main
kursuse	doc_802069853771_item	2890948	et	3	main
selle	doc_802069853771_item	2890952	et	4	main
kättesaamisel	doc_802069853771_item	2890953	et	4	main
saada	doc_802069853771_item	2890954	et	4	main
tekkinud	doc_802069853771_item	2890971	et	4	main
on	doc_802069853771_item	2890975	et	4	main
9	doc_802069853771_item	2890976	et	2	main
liigne	doc_802069853771_item	2890977	et	3	main
10	doc_802069853771_item	2890978	et	2	main
tulge	doc_802069853771_item	2890979	et	3	main
1	doc_802069853771_item	2890985	et	2	main
seega	doc_802069853771_item	2890998	et	4	main
vabaduse	doc_802069853771_item	2891011	et	4	main
4	doc_802069853771_item	2891012	et	2	main
a	doc_802069853771_item	2891022	et	4	main
saada	doc_802069853771_item	2891024	et	4	main
6	doc_802069853771_item	2891034	et	2	main
7	doc_802069853771_item	2891043	et	2	main
muudab	doc_802069853771_item	2891060	et	3	main
b	doc_802069853771_item	2891064	et	4	main
b	doc_802069853771_item	2891073	et	4	main
teksti	doc_802069853772_item	2891084	et	4	main
3	doc_802069853772_item	2891122	et	2	main
d	doc_802069853770_item	2890822	et	4	main
et	doc_802069853770_item	2890823	et	3	main
a	doc_802069853770_item	2890825	et	4	main
taga	doc_802069853770_item	2890826	et	4	main
d	doc_802069853770_item	2890831	et	4	main
kirjutab	doc_802069853770_item	2890835	et	3	main
muudab	doc_802069853770_item	2890841	et	3	main
libe	doc_802069853770_item	2890846	et	3	main
c	doc_802069853770_item	2890847	et	4	main
liikuv	doc_802069853770_item	2890848	et	4	main
tulge	doc_802069853770_item	2890853	et	3	main
külastage	doc_802069853770_item	2890857	et	3	main
d	doc_802069853770_item	2890858	et	4	main
minge	doc_802069853770_item	2890859	et	3	main
harjutus	doc_802069853771_item	2890860	et	4	main
kirjutage	doc_802069853771_item	2890861	et	3	main
lünka	doc_802069853771_item	2890862	et	4	main
sobiv	doc_802069853771_item	2890863	et	4	main
liigne	doc_802069853770_item	2890844	et	3	main
b	doc_802069853770_item	2890854	et	4	main
sõna	doc_802069853771_item	2890864	et	4	main
õige	doc_802069853771_item	2890868	et	4	main
õpi	doc_802069853771_item	2890873	et	4	main
millal	doc_802069853771_item	2890874	et	3	main
umbne	doc_802069853771_item	2890878	et	3	main
2	doc_802069853771_item	2890885	et	2	main
kuigi	doc_802069853771_item	2890886	et	3	main
seal	doc_802069853771_item	2890887	et	4	main
kus	doc_802069853771_item	2890888	et	3	main
ja	doc_802069853771_item	2890889	et	3	main
annab	doc_802069853771_item	2890901	et	3	main
3	doc_802069853771_item	2890903	et	2	main
ning	doc_802069853771_item	2890907	et	3	main
et	doc_802069853771_item	2890918	et	3	main
kokku	doc_802069853771_item	2890921	et	3	main
registreerunud	doc_802069853771_item	2890931	et	4	main
saad	doc_802069853771_item	2890932	et	4	main
lähimast	doc_802069853771_item	2890936	et	4	main
postiasutusest	doc_802069853771_item	2890937	et	4	main
igal	doc_802069853771_item	2890938	et	3	main
kuid	doc_802069853771_item	2890946	et	4	main
täidetud	doc_802069853771_item	2890955	et	4	main
lisaküsimustele	doc_802069853771_item	2890972	et	4	main
kõik	doc_802069853771_item	2890973	et	4	main
geniaalne	doc_802069853771_item	2890974	et	3	main
kupong	doc_802069853771_item	2890984	et	3	main
sobid	doc_802069853771_item	2890987	et	4	main
d	doc_802069853771_item	2891001	et	4	main
a	doc_802069853771_item	2891013	et	4	main
tasule	doc_802069853771_item	2891014	et	3	main
c	doc_802069853771_item	2891028	et	4	main
c	doc_802069853771_item	2891039	et	4	main
c	doc_802069853771_item	2891048	et	4	main
eest	doc_802069853771_item	2891049	et	4	main
d	doc_802069853771_item	2891050	et	4	main
ees	doc_802069853771_item	2891051	et	4	main
8	doc_802069853771_item	2891052	et	2	main
parandab	doc_802069853771_item	2891058	et	3	main
a	doc_802069853771_item	2891062	et	4	main
libe	doc_802069853771_item	2891065	et	3	main
minge	doc_802069853771_item	2891078	et	3	main
kirjutage	doc_802069853772_item	2891080	et	3	main
4	doc_802069853772_item	2891132	et	2	main
hoida	doc_802069853772_item	2891141	et	3	main
tarkust	doc_802069853772_item	2891146	et	4	main
kursusele	doc_802069853772_item	2891149	et	3	main
selle	doc_802069853772_item	2891171	et	4	main
meile	doc_802069853772_item	2891176	et	4	main
korral	doc_802069853772_item	2891188	et	4	main
9	doc_802069853772_item	2891195	et	2	main
c	doc_802069853772_item	2891209	et	4	main
soovitad	doc_802069853772_item	2891210	et	3	main
c	doc_802069853772_item	2891218	et	4	main
kuigi	doc_802069853772_item	2891219	et	3	main
vajaduse	doc_802069853772_item	2891224	et	3	main
kokku	doc_802069853772_item	2891245	et	3	main
kokku	doc_802069853772_item	2891248	et	3	main
d	doc_802069853772_item	2891250	et	4	main
kokku	doc_802069853772_item	2891251	et	3	main
panna	doc_802069853772_item	2891252	et	4	main
6	doc_802069853772_item	2891253	et	2	main
a	doc_802069853772_item	2891263	et	4	main
b	doc_802069853772_item	2891265	et	4	main
ette	doc_802069853772_item	2891266	et	4	main
eest	doc_802069853772_item	2891268	et	4	main
c	doc_802069853772_item	2891276	et	4	main
parandab	doc_802069853772_item	2891277	et	3	main
d	doc_802069853772_item	2891278	et	4	main
9	doc_802069853772_item	2891280	et	2	main
libe	doc_802069853772_item	2891284	et	3	main
liikuv	doc_802069853772_item	2891286	et	4	main
lünka	doc_802069853773_item	2891300	et	4	main
iga	doc_802069853773_item	2891305	et	4	main
vastus	doc_802069853773_item	2891307	et	3	main
ühe	doc_802069853773_item	2891309	et	4	main
punkti	doc_802069853773_item	2891310	et	4	main
koduõppesüsteem	doc_802069853773_item	2891318	et	3	main
sa	doc_802069853773_item	2891329	et	3	main
käes	doc_802069853773_item	2891333	et	4	main
annab	doc_802069853773_item	2891339	et	3	main
alt	doc_802069853771_item	2890866	et	4	main
annab	doc_802069853771_item	2890870	et	3	main
punkti	doc_802069853771_item	2890872	et	4	main
1	doc_802069853771_item	2890875	et	2	main
soovid	doc_802069853771_item	2890876	et	4	main
võimaldab	doc_802069853771_item	2890881	et	3	main
on	doc_802069853771_item	2890896	et	4	main
mis	doc_802069853771_item	2890900	et	4	main
on	doc_802069853771_item	2890916	et	4	main
raha	doc_802069853771_item	2890917	et	4	main
on	doc_802069853771_item	2890923	et	4	main
kontorist	doc_802069853771_item	2890934	et	4	main
kätte	doc_802069853771_item	2890940	et	4	main
õppematerjalid	doc_802069853771_item	2890941	et	3	main
kodutöö	doc_802069853771_item	2890947	et	4	main
tasud	doc_802069853771_item	2890951	et	4	main
korral	doc_802069853771_item	2890969	et	4	main
meie	doc_802069853771_item	2890980	et	4	main
virtuaalkodu	doc_802069853771_item	2890981	et	4	main
või	doc_802069853771_item	2890982	et	4	main
postitage	doc_802069853771_item	2890983	et	3	main
a	doc_802069853771_item	2890986	et	4	main
soovitad	doc_802069853771_item	2890991	et	3	main
solvud	doc_802069853771_item	2890993	et	3	main
a	doc_802069853771_item	2890995	et	4	main
just	doc_802069853771_item	2890996	et	3	main
b	doc_802069853771_item	2890997	et	4	main
vabanduse	doc_802069853771_item	2891007	et	4	main
5	doc_802069853771_item	2891021	et	2	main
kokku	doc_802069853771_item	2891029	et	3	main
hoida	doc_802069853771_item	2891030	et	3	main
d	doc_802069853771_item	2891031	et	4	main
kokku	doc_802069853771_item	2891032	et	3	main
panna	doc_802069853771_item	2891033	et	4	main
et	doc_802069853771_item	2891042	et	3	main
b	doc_802069853771_item	2891055	et	4	main
palub	doc_802069853771_item	2891056	et	3	main
c	doc_802069853771_item	2891057	et	4	main
d	doc_802069853771_item	2891068	et	4	main
lihtne	doc_802069853771_item	2891069	et	3	main
d	doc_802069853771_item	2891077	et	4	main
lünka	doc_802069853772_item	2891081	et	4	main
õige	doc_802069853772_item	2891087	et	4	main
vastus	doc_802069853772_item	2891088	et	3	main
annab	doc_802069853772_item	2891089	et	3	main
sulle	doc_802069853772_item	2891121	et	3	main
vabanduse	doc_802069853772_item	2891123	et	4	main
aega	doc_802069853772_item	2891125	et	4	main
ning	doc_802069853772_item	2891126	et	3	main
teadmisi	doc_802069853772_item	2891129	et	4	main
on	doc_802069853772_item	2891135	et	4	main
5	doc_802069853772_item	2891139	et	2	main
pisut	doc_802069853772_item	2891145	et	3	main
kui	doc_802069853772_item	2891147	et	3	main
oled	doc_802069853772_item	2891148	et	3	main
tasud	doc_802069853772_item	2891170	et	4	main
kodutöö	doc_802069853772_item	2891175	et	4	main
vaatab	doc_802069853772_item	2891179	et	3	main
üle	doc_802069853772_item	2891181	et	3	main
ka	doc_802069853772_item	2891189	et	3	main
lisaküsimustele	doc_802069853772_item	2891191	et	4	main
10	doc_802069853772_item	2891197	et	2	main
meie	doc_802069853772_item	2891199	et	4	main
d	doc_802069853772_item	2891211	et	4	main
solvud	doc_802069853772_item	2891212	et	3	main
2	doc_802069853772_item	2891213	et	2	main
d	doc_802069853772_item	2891220	et	4	main
ka	doc_802069853771_item	2890925	et	3	main
tarkust	doc_802069853771_item	2890927	et	4	main
kursusele	doc_802069853771_item	2890930	et	3	main
helikasseti	doc_802069853771_item	2890944	et	4	main
6	doc_802069853771_item	2890945	et	2	main
7	doc_802069853771_item	2890949	et	2	main
meile	doc_802069853771_item	2890957	et	4	main
tagasi	doc_802069853771_item	2890958	et	3	main
õpetaja	doc_802069853771_item	2890959	et	4	main
vaatab	doc_802069853771_item	2890960	et	3	main
selle	doc_802069853771_item	2890961	et	4	main
üle	doc_802069853771_item	2890962	et	3	main
8	doc_802069853771_item	2890963	et	2	main
palub	doc_802069853771_item	2890964	et	3	main
vead	doc_802069853771_item	2890965	et	4	main
ning	doc_802069853771_item	2890966	et	3	main
vastab	doc_802069853771_item	2890967	et	3	main
vajaduse	doc_802069853771_item	2890968	et	3	main
kodutöö	doc_802069853771_item	2890956	et	4	main
ka	doc_802069853771_item	2890970	et	3	main
soovid	doc_802069853771_item	2890989	et	4	main
c	doc_802069853771_item	2890999	et	4	main
kuigi	doc_802069853771_item	2891000	et	3	main
b	doc_802069853771_item	2891006	et	4	main
c	doc_802069853771_item	2891008	et	4	main
varanduse	doc_802069853771_item	2891009	et	3	main
d	doc_802069853771_item	2891010	et	4	main
b	doc_802069853771_item	2891025	et	4	main
kokku	doc_802069853771_item	2891026	et	3	main
liita	doc_802069853771_item	2891027	et	4	main
a	doc_802069853771_item	2891035	et	4	main
ning	doc_802069853771_item	2891036	et	3	main
b	doc_802069853771_item	2891037	et	4	main
vaid	doc_802069853771_item	2891038	et	3	main
d	doc_802069853771_item	2891041	et	4	main
taga	doc_802069853771_item	2891045	et	4	main
9	doc_802069853771_item	2891061	et	2	main
10	doc_802069853771_item	2891070	et	2	main
a	doc_802069853771_item	2891071	et	4	main
tulge	doc_802069853771_item	2891072	et	3	main
käige	doc_802069853771_item	2891074	et	3	main
c	doc_802069853771_item	2891075	et	4	main
külastage	doc_802069853771_item	2891076	et	3	main
harjutus	doc_802069853772_item	2891079	et	4	main
alt	doc_802069853772_item	2891085	et	4	main
iga	doc_802069853772_item	2891086	et	4	main
vastavalt	doc_802069853772_item	2891130	et	4	main
individuaalsele	doc_802069853772_item	2891131	et	3	main
et	doc_802069853772_item	2891137	et	3	main
on	doc_802069853772_item	2891142	et	4	main
ka	doc_802069853772_item	2891144	et	3	main
registreerunud	doc_802069853772_item	2891150	et	4	main
saad	doc_802069853772_item	2891151	et	4	main
6	doc_802069853772_item	2891164	et	2	main
ning	doc_802069853772_item	2891165	et	3	main
kättesaamisel	doc_802069853772_item	2891172	et	4	main
tagasi	doc_802069853772_item	2891177	et	3	main
ning	doc_802069853772_item	2891185	et	3	main
on	doc_802069853772_item	2891194	et	4	main
lihtne	doc_802069853772_item	2891196	et	3	main
a	doc_802069853772_item	2891205	et	4	main
a	doc_802069853772_item	2891214	et	4	main
just	doc_802069853772_item	2891215	et	3	main
b	doc_802069853772_item	2891216	et	4	main
seega	doc_802069853772_item	2891217	et	4	main
3	doc_802069853772_item	2891222	et	2	main
c	doc_802069853772_item	2891227	et	4	main
tasakesi	doc_802069853772_item	2891237	et	3	main
d	doc_802069853772_item	2891238	et	4	main
tasakaalule	doc_802069853772_item	2891239	et	3	main
5	doc_802069853772_item	2891240	et	2	main
b	doc_802069853772_item	2891244	et	4	main
a	doc_802069853772_item	2891254	et	4	main
ning	doc_802069853772_item	2891255	et	3	main
et	doc_802069853772_item	2891261	et	3	main
taga	doc_802069853772_item	2891264	et	4	main
d	doc_802069853772_item	2891269	et	4	main
a	doc_802069853772_item	2891272	et	4	main
kirjutab	doc_802069853772_item	2891273	et	3	main
a	doc_802069853772_item	2891290	et	4	main
tulge	doc_802069853772_item	2891291	et	3	main
kirjutage	doc_802069853773_item	2891299	et	3	main
sõna	doc_802069853773_item	2891302	et	4	main
teksti	doc_802069853773_item	2891303	et	4	main
klassiruum	doc_802069853773_item	2891317	et	3	main
targemaks	doc_802069853773_item	2891322	et	4	main
kuigi	doc_802069853773_item	2891324	et	3	main
seal	doc_802069853773_item	2891325	et	4	main
millal	doc_802069853773_item	2891328	et	3	main
vabaduse	doc_802069853773_item	2891342	et	4	main
individuaalsele	doc_802069853773_item	2891350	et	3	main
kursusele	doc_802069853773_item	2891368	et	3	main
saad	doc_802069853773_item	2891370	et	4	main
igal	doc_802069853773_item	2891376	et	3	main
helikasseti	doc_802069853773_item	2891382	et	4	main
b	doc_802069853771_item	2890988	et	4	main
c	doc_802069853771_item	2890990	et	4	main
d	doc_802069853771_item	2890992	et	4	main
2	doc_802069853771_item	2890994	et	2	main
siiski	doc_802069853771_item	2891002	et	4	main
3	doc_802069853771_item	2891003	et	2	main
a	doc_802069853771_item	2891004	et	4	main
vajaduse	doc_802069853771_item	2891005	et	3	main
b	doc_802069853771_item	2891015	et	4	main
tasemele	doc_802069853771_item	2891016	et	3	main
c	doc_802069853771_item	2891017	et	4	main
tasakesi	doc_802069853771_item	2891018	et	3	main
d	doc_802069853771_item	2891019	et	4	main
tasakaalule	doc_802069853771_item	2891020	et	3	main
kokku	doc_802069853771_item	2891023	et	3	main
kuid	doc_802069853771_item	2891040	et	4	main
a	doc_802069853771_item	2891044	et	4	main
b	doc_802069853771_item	2891046	et	4	main
ette	doc_802069853771_item	2891047	et	4	main
a	doc_802069853771_item	2891053	et	4	main
kirjutab	doc_802069853771_item	2891054	et	3	main
d	doc_802069853771_item	2891059	et	4	main
liigne	doc_802069853771_item	2891063	et	3	main
c	doc_802069853771_item	2891066	et	4	main
liikuv	doc_802069853771_item	2891067	et	4	main
sobiv	doc_802069853772_item	2891082	et	4	main
sõna	doc_802069853772_item	2891083	et	4	main
ühe	doc_802069853772_item	2891090	et	4	main
punkti	doc_802069853772_item	2891091	et	4	main
õpi	doc_802069853772_item	2891092	et	4	main
millal	doc_802069853772_item	2891093	et	3	main
1	doc_802069853772_item	2891094	et	2	main
solvud	doc_802069853772_item	2891095	et	3	main
unusta	doc_802069853772_item	2891096	et	4	main
umbne	doc_802069853772_item	2891097	et	3	main
klassiruum	doc_802069853772_item	2891098	et	3	main
võimaldab	doc_802069853772_item	2891100	et	3	main
koduõppesüsteem	doc_802069853772_item	2891099	et	3	main
sul	doc_802069853772_item	2891101	et	3	main
saada	doc_802069853772_item	2891102	et	4	main
targemaks	doc_802069853772_item	2891103	et	4	main
2	doc_802069853772_item	2891104	et	2	main
kuigi	doc_802069853772_item	2891105	et	3	main
seal	doc_802069853772_item	2891106	et	4	main
kus	doc_802069853772_item	2891107	et	3	main
ja	doc_802069853772_item	2891108	et	3	main
millal	doc_802069853772_item	2891109	et	3	main
sa	doc_802069853772_item	2891110	et	3	main
seda	doc_802069853772_item	2891111	et	3	main
parasjagu	doc_802069853772_item	2891112	et	3	main
soovid	doc_802069853772_item	2891113	et	4	main
käes	doc_802069853772_item	2891114	et	4	main
on	doc_802069853772_item	2891115	et	4	main
interaktiivse	doc_802069853772_item	2891116	et	3	main
õppe	doc_802069853772_item	2891117	et	4	main
ajastu	doc_802069853772_item	2891118	et	4	main
mis	doc_802069853772_item	2891119	et	4	main
annab	doc_802069853772_item	2891120	et	3	main
planeerida	doc_802069853772_item	2891124	et	3	main
eelise	doc_802069853772_item	2891127	et	4	main
omandada	doc_802069853772_item	2891128	et	3	main
aeg	doc_802069853772_item	2891134	et	3	main
raha	doc_802069853772_item	2891136	et	4	main
seda	doc_802069853772_item	2891138	et	3	main
vaja	doc_802069853772_item	2891143	et	4	main
tasamele	doc_802069853772_item	2891133	et	4	main
kokku	doc_802069853772_item	2891140	et	3	main
meie	doc_802069853772_item	2891152	et	4	main
kontorist	doc_802069853772_item	2891153	et	4	main
või	doc_802069853772_item	2891154	et	4	main
lähimast	doc_802069853772_item	2891155	et	4	main
postiasutusest	doc_802069853772_item	2891156	et	4	main
igal	doc_802069853772_item	2891157	et	3	main
kuul	doc_802069853772_item	2891158	et	4	main
kätte	doc_802069853772_item	2891159	et	4	main
õppematerjalid	doc_802069853772_item	2891160	et	3	main
raamatu	doc_802069853772_item	2891161	et	4	main
ja	doc_802069853772_item	2891162	et	3	main
helikasseti	doc_802069853772_item	2891163	et	4	main
kodutöö	doc_802069853772_item	2891166	et	4	main
kursuse	doc_802069853772_item	2891167	et	3	main
7	doc_802069853772_item	2891168	et	2	main
saada	doc_802069853772_item	2891173	et	4	main
vastab	doc_802069853772_item	2891186	et	3	main
vajaduse	doc_802069853772_item	2891187	et	3	main
tulge	doc_802069853772_item	2891198	et	3	main
virtuaalkodu	doc_802069853772_item	2891200	et	4	main
või	doc_802069853772_item	2891201	et	4	main
postitage	doc_802069853772_item	2891202	et	3	main
kupong	doc_802069853772_item	2891203	et	3	main
sobid	doc_802069853772_item	2891206	et	4	main
soovid	doc_802069853772_item	2891208	et	4	main
siiski	doc_802069853772_item	2891221	et	4	main
a	doc_802069853772_item	2891232	et	4	main
b	doc_802069853772_item	2891234	et	4	main
tasemele	doc_802069853772_item	2891235	et	3	main
c	doc_802069853772_item	2891236	et	4	main
liita	doc_802069853772_item	2891246	et	4	main
c	doc_802069853772_item	2891247	et	4	main
b	doc_802069853772_item	2891256	et	4	main
c	doc_802069853772_item	2891258	et	4	main
kuid	doc_802069853772_item	2891259	et	4	main
d	doc_802069853772_item	2891260	et	4	main
ees	doc_802069853772_item	2891270	et	4	main
8	doc_802069853772_item	2891271	et	2	main
muudab	doc_802069853772_item	2891279	et	3	main
b	doc_802069853772_item	2891283	et	4	main
c	doc_802069853772_item	2891285	et	4	main
d	doc_802069853772_item	2891287	et	4	main
lihtne	doc_802069853772_item	2891288	et	3	main
10	doc_802069853772_item	2891289	et	2	main
harjutus	doc_802069853773_item	2891298	et	4	main
sobiv	doc_802069853773_item	2891301	et	4	main
õige	doc_802069853773_item	2891306	et	4	main
annab	doc_802069853773_item	2891308	et	3	main
seda	doc_802069853773_item	2891330	et	3	main
soovid	doc_802069853773_item	2891332	et	4	main
on	doc_802069853773_item	2891334	et	4	main
interaktiivse	doc_802069853773_item	2891335	et	3	main
õppe	doc_802069853773_item	2891336	et	4	main
vastavalt	doc_802069853773_item	2891349	et	4	main
4	doc_802069853773_item	2891351	et	2	main
tasemele	doc_802069853773_item	2891352	et	3	main
aeg	doc_802069853773_item	2891353	et	3	main
on	doc_802069853773_item	2891354	et	4	main
vaja	doc_802069853773_item	2891362	et	4	main
ka	doc_802069853773_item	2891363	et	3	main
pisut	doc_802069853773_item	2891364	et	3	main
kontorist	doc_802069853773_item	2891372	et	4	main
kuul	doc_802069853773_item	2891377	et	4	main
raamatu	doc_802069853773_item	2891380	et	4	main
6	doc_802069853773_item	2891383	et	2	main
kuid	doc_802069853773_item	2891384	et	4	main
kodutöö	doc_802069853773_item	2891385	et	4	main
a	doc_802069853773_item	2891424	et	4	main
sobid	doc_802069853773_item	2891425	et	4	main
b	doc_802069853773_item	2891426	et	4	main
b	doc_802069853773_item	2891435	et	4	main
seega	doc_802069853773_item	2891436	et	4	main
liita	doc_802069853773_item	2891465	et	4	main
d	doc_802069853773_item	2891469	et	4	main
panna	doc_802069853773_item	2891471	et	4	main
a	doc_802069853773_item	2891473	et	4	main
a	doc_802069853773_item	2891491	et	4	main
kirjutab	doc_802069853773_item	2891492	et	3	main
b	doc_802069853773_item	2891493	et	4	main
palub	doc_802069853773_item	2891494	et	3	main
libe	doc_802069853773_item	2891503	et	3	main
c	doc_802069853773_item	2891504	et	4	main
sobid	doc_802069853774_item	2891533	et	4	main
seal	doc_802069853774_item	2891544	et	4	main
kus	doc_802069853774_item	2891545	et	3	main
käes	doc_802069853774_item	2891552	et	4	main
raha	doc_802069853774_item	2891574	et	4	main
et	doc_802069853774_item	2891575	et	3	main
seda	doc_802069853774_item	2891576	et	3	main
lähimast	doc_802069853774_item	2891593	et	4	main
helikasseti	doc_802069853774_item	2891601	et	4	main
6	doc_802069853774_item	2891602	et	2	main
et	doc_802069853774_item	2891603	et	3	main
tasud	doc_802069853774_item	2891608	et	4	main
saada	doc_802069853774_item	2891611	et	4	main
eest	doc_802069853772_item	2891169	et	4	main
täidetud	doc_802069853772_item	2891174	et	4	main
õpetaja	doc_802069853772_item	2891178	et	4	main
selle	doc_802069853772_item	2891180	et	4	main
8	doc_802069853772_item	2891182	et	2	main
parandab	doc_802069853772_item	2891183	et	3	main
vead	doc_802069853772_item	2891184	et	4	main
tekkinud	doc_802069853772_item	2891190	et	4	main
kõik	doc_802069853772_item	2891192	et	4	main
geniaalne	doc_802069853772_item	2891193	et	3	main
1	doc_802069853772_item	2891204	et	2	main
b	doc_802069853772_item	2891207	et	4	main
a	doc_802069853772_item	2891223	et	4	main
vabanduse	doc_802069853772_item	2891226	et	4	main
varanduse	doc_802069853772_item	2891228	et	3	main
d	doc_802069853772_item	2891229	et	4	main
vabaduse	doc_802069853772_item	2891230	et	4	main
4	doc_802069853772_item	2891231	et	2	main
a	doc_802069853772_item	2891241	et	4	main
kokku	doc_802069853772_item	2891242	et	3	main
c	doc_802069853772_item	2891267	et	4	main
b	doc_802069853772_item	2891274	et	4	main
palub	doc_802069853772_item	2891275	et	3	main
a	doc_802069853772_item	2891281	et	4	main
c	doc_802069853772_item	2891294	et	4	main
külastage	doc_802069853772_item	2891295	et	3	main
d	doc_802069853772_item	2891296	et	4	main
minge	doc_802069853772_item	2891297	et	3	main
sobid	doc_802069853773_item	2891314	et	4	main
unusta	doc_802069853773_item	2891315	et	4	main
umbne	doc_802069853773_item	2891316	et	3	main
2	doc_802069853773_item	2891323	et	2	main
parasjagu	doc_802069853773_item	2891331	et	3	main
mis	doc_802069853773_item	2891338	et	4	main
3	doc_802069853773_item	2891341	et	2	main
planeerida	doc_802069853773_item	2891343	et	3	main
5	doc_802069853773_item	2891358	et	2	main
kokku	doc_802069853773_item	2891359	et	3	main
saada	doc_802069853773_item	2891360	et	4	main
kui	doc_802069853773_item	2891366	et	3	main
või	doc_802069853773_item	2891373	et	4	main
postiasutusest	doc_802069853773_item	2891375	et	4	main
õppematerjalid	doc_802069853773_item	2891379	et	3	main
kupong	doc_802069853773_item	2891422	et	3	main
siiski	doc_802069853773_item	2891440	et	4	main
3	doc_802069853773_item	2891441	et	2	main
vabanduse	doc_802069853773_item	2891445	et	4	main
d	doc_802069853773_item	2891448	et	4	main
4	doc_802069853773_item	2891450	et	2	main
a	doc_802069853773_item	2891451	et	4	main
tasule	doc_802069853773_item	2891452	et	3	main
c	doc_802069853773_item	2891455	et	4	main
a	doc_802069853773_item	2891460	et	4	main
kokku	doc_802069853773_item	2891461	et	3	main
saada	doc_802069853773_item	2891462	et	4	main
hoida	doc_802069853773_item	2891468	et	3	main
kokku	doc_802069853773_item	2891470	et	3	main
d	doc_802069853773_item	2891479	et	4	main
et	doc_802069853773_item	2891480	et	3	main
7	doc_802069853773_item	2891481	et	2	main
a	doc_802069853773_item	2891482	et	4	main
c	doc_802069853773_item	2891486	et	4	main
d	doc_802069853773_item	2891488	et	4	main
ees	doc_802069853773_item	2891489	et	4	main
8	doc_802069853773_item	2891490	et	2	main
a	doc_802069853773_item	2891500	et	4	main
liigne	doc_802069853773_item	2891501	et	3	main
sõna	doc_802069853774_item	2891521	et	4	main
õige	doc_802069853774_item	2891525	et	4	main
annab	doc_802069853774_item	2891527	et	3	main
sul	doc_802069853774_item	2891539	et	3	main
sa	doc_802069853774_item	2891548	et	3	main
parasjagu	doc_802069853774_item	2891550	et	3	main
annab	doc_802069853774_item	2891558	et	3	main
saada	doc_802069853774_item	2891579	et	4	main
on	doc_802069853774_item	2891580	et	4	main
vaja	doc_802069853774_item	2891581	et	4	main
ka	doc_802069853774_item	2891582	et	3	main
saad	doc_802069853774_item	2891589	et	4	main
7	doc_802069853774_item	2891606	et	2	main
tekkinud	doc_802069853774_item	2891628	et	4	main
geniaalne	doc_802069853774_item	2891631	et	3	main
b	doc_802069853772_item	2891225	et	4	main
tasule	doc_802069853772_item	2891233	et	3	main
saada	doc_802069853772_item	2891243	et	4	main
hoida	doc_802069853772_item	2891249	et	3	main
vaid	doc_802069853772_item	2891257	et	3	main
7	doc_802069853772_item	2891262	et	2	main
liigne	doc_802069853772_item	2891282	et	3	main
b	doc_802069853772_item	2891292	et	4	main
käige	doc_802069853772_item	2891293	et	3	main
alt	doc_802069853773_item	2891304	et	4	main
õpi	doc_802069853773_item	2891311	et	4	main
millal	doc_802069853773_item	2891312	et	3	main
1	doc_802069853773_item	2891313	et	2	main
võimaldab	doc_802069853773_item	2891319	et	3	main
sul	doc_802069853773_item	2891320	et	3	main
saada	doc_802069853773_item	2891321	et	4	main
kus	doc_802069853773_item	2891326	et	3	main
ja	doc_802069853773_item	2891327	et	3	main
ajastu	doc_802069853773_item	2891337	et	4	main
teadmisi	doc_802069853773_item	2891348	et	4	main
on	doc_802069853773_item	2891361	et	4	main
oled	doc_802069853773_item	2891367	et	3	main
meie	doc_802069853773_item	2891371	et	4	main
lähimast	doc_802069853773_item	2891374	et	4	main
ja	doc_802069853773_item	2891381	et	3	main
kursuse	doc_802069853773_item	2891386	et	3	main
7	doc_802069853773_item	2891387	et	2	main
ette	doc_802069853773_item	2891388	et	4	main
tasud	doc_802069853773_item	2891389	et	4	main
selle	doc_802069853773_item	2891390	et	4	main
kättesaamisel	doc_802069853773_item	2891391	et	4	main
saada	doc_802069853773_item	2891392	et	4	main
täidetud	doc_802069853773_item	2891393	et	4	main
kodutöö	doc_802069853773_item	2891394	et	4	main
meile	doc_802069853773_item	2891395	et	4	main
tagasi	doc_802069853773_item	2891396	et	3	main
õpetaja	doc_802069853773_item	2891397	et	4	main
vaatab	doc_802069853773_item	2891398	et	3	main
selle	doc_802069853773_item	2891399	et	4	main
üle	doc_802069853773_item	2891400	et	3	main
8	doc_802069853773_item	2891401	et	2	main
palub	doc_802069853773_item	2891402	et	3	main
vead	doc_802069853773_item	2891403	et	4	main
ning	doc_802069853773_item	2891404	et	3	main
vastab	doc_802069853773_item	2891405	et	3	main
vajaduse	doc_802069853773_item	2891406	et	3	main
korral	doc_802069853773_item	2891407	et	4	main
ka	doc_802069853773_item	2891408	et	3	main
tekkinud	doc_802069853773_item	2891409	et	4	main
lisaküsimustele	doc_802069853773_item	2891410	et	4	main
kõik	doc_802069853773_item	2891411	et	4	main
geniaalne	doc_802069853773_item	2891412	et	3	main
on	doc_802069853773_item	2891413	et	4	main
9	doc_802069853773_item	2891414	et	2	main
lihtne	doc_802069853773_item	2891415	et	3	main
10	doc_802069853773_item	2891416	et	2	main
tulge	doc_802069853773_item	2891417	et	3	main
meie	doc_802069853773_item	2891418	et	4	main
virtuaalkodu	doc_802069853773_item	2891419	et	4	main
või	doc_802069853773_item	2891420	et	4	main
soovid	doc_802069853773_item	2891427	et	4	main
solvud	doc_802069853773_item	2891431	et	3	main
sulle	doc_802069853773_item	2891340	et	3	main
aega	doc_802069853773_item	2891344	et	4	main
ning	doc_802069853773_item	2891345	et	3	main
eelise	doc_802069853773_item	2891346	et	4	main
omandada	doc_802069853773_item	2891347	et	3	main
raha	doc_802069853773_item	2891355	et	4	main
et	doc_802069853773_item	2891356	et	3	main
seda	doc_802069853773_item	2891357	et	3	main
tarkust	doc_802069853773_item	2891365	et	4	main
registreerunud	doc_802069853773_item	2891369	et	4	main
kätte	doc_802069853773_item	2891378	et	4	main
postitage	doc_802069853773_item	2891421	et	3	main
c	doc_802069853773_item	2891428	et	4	main
2	doc_802069853773_item	2891432	et	2	main
just	doc_802069853773_item	2891434	et	3	main
a	doc_802069853773_item	2891442	et	4	main
vajaduse	doc_802069853773_item	2891443	et	3	main
tasemele	doc_802069853773_item	2891454	et	3	main
tasakesi	doc_802069853773_item	2891456	et	3	main
tasakaalule	doc_802069853773_item	2891458	et	3	main
kokku	doc_802069853773_item	2891467	et	3	main
kuid	doc_802069853773_item	2891478	et	4	main
ette	doc_802069853773_item	2891485	et	4	main
c	doc_802069853773_item	2891495	et	4	main
parandab	doc_802069853773_item	2891496	et	3	main
d	doc_802069853773_item	2891497	et	4	main
muudab	doc_802069853773_item	2891498	et	3	main
9	doc_802069853773_item	2891499	et	2	main
liikuv	doc_802069853773_item	2891505	et	4	main
lihtne	doc_802069853773_item	2891507	et	3	main
teksti	doc_802069853774_item	2891522	et	4	main
unusta	doc_802069853774_item	2891534	et	4	main
umbne	doc_802069853774_item	2891535	et	3	main
klassiruum	doc_802069853774_item	2891536	et	3	main
koduõppesüsteem	doc_802069853774_item	2891537	et	3	main
saada	doc_802069853774_item	2891540	et	4	main
targemaks	doc_802069853774_item	2891541	et	4	main
2	doc_802069853774_item	2891542	et	2	main
kuigi	doc_802069853774_item	2891543	et	3	main
ja	doc_802069853774_item	2891546	et	3	main
soovid	doc_802069853774_item	2891551	et	4	main
on	doc_802069853774_item	2891553	et	4	main
interaktiivse	doc_802069853774_item	2891554	et	3	main
õppe	doc_802069853774_item	2891555	et	4	main
sulle	doc_802069853774_item	2891559	et	3	main
kontorist	doc_802069853774_item	2891591	et	4	main
või	doc_802069853774_item	2891592	et	4	main
kodutöö	doc_802069853774_item	2891604	et	4	main
kursuse	doc_802069853774_item	2891605	et	3	main
kodutöö	doc_802069853774_item	2891613	et	4	main
kirjutab	doc_802069853774_item	2891621	et	3	main
ning	doc_802069853774_item	2891623	et	3	main
korral	doc_802069853774_item	2891626	et	4	main
10	doc_802069853774_item	2891635	et	2	main
sobid	doc_802069853774_item	2891644	et	4	main
kuigi	doc_802069853774_item	2891657	et	3	main
a	doc_802069853774_item	2891661	et	4	main
vajaduse	doc_802069853774_item	2891662	et	3	main
d	doc_802069853774_item	2891667	et	4	main
eest	doc_802069853774_item	2891706	et	4	main
c	doc_802069853774_item	2891714	et	4	main
parandab	doc_802069853774_item	2891715	et	3	main
c	doc_802069853774_item	2891723	et	4	main
sobiv	doc_802069853775_item	2891739	et	4	main
õige	doc_802069853775_item	2891744	et	4	main
vastus	doc_802069853775_item	2891745	et	3	main
punkti	doc_802069853775_item	2891748	et	4	main
millal	doc_802069853775_item	2891750	et	3	main
kus	doc_802069853775_item	2891764	et	3	main
sa	doc_802069853775_item	2891767	et	3	main
ning	doc_802069853775_item	2891783	et	3	main
1	doc_802069853773_item	2891423	et	2	main
soovitad	doc_802069853773_item	2891429	et	3	main
d	doc_802069853773_item	2891430	et	4	main
c	doc_802069853773_item	2891437	et	4	main
kuigi	doc_802069853773_item	2891438	et	3	main
d	doc_802069853773_item	2891439	et	4	main
c	doc_802069853773_item	2891446	et	4	main
b	doc_802069853773_item	2891453	et	4	main
d	doc_802069853773_item	2891457	et	4	main
5	doc_802069853773_item	2891459	et	2	main
c	doc_802069853773_item	2891466	et	4	main
6	doc_802069853773_item	2891472	et	2	main
ning	doc_802069853773_item	2891474	et	3	main
b	doc_802069853773_item	2891475	et	4	main
vaid	doc_802069853773_item	2891476	et	3	main
taga	doc_802069853773_item	2891483	et	4	main
b	doc_802069853773_item	2891502	et	4	main
d	doc_802069853773_item	2891506	et	4	main
10	doc_802069853773_item	2891508	et	2	main
a	doc_802069853773_item	2891509	et	4	main
tulge	doc_802069853773_item	2891510	et	3	main
b	doc_802069853773_item	2891511	et	4	main
käige	doc_802069853773_item	2891512	et	3	main
c	doc_802069853773_item	2891513	et	4	main
külastage	doc_802069853773_item	2891514	et	3	main
d	doc_802069853773_item	2891515	et	4	main
minge	doc_802069853773_item	2891516	et	3	main
harjutus	doc_802069853774_item	2891517	et	4	main
kirjutage	doc_802069853774_item	2891518	et	3	main
lünka	doc_802069853774_item	2891519	et	4	main
sobiv	doc_802069853774_item	2891520	et	4	main
a	doc_802069853773_item	2891433	et	4	main
b	doc_802069853773_item	2891444	et	4	main
varanduse	doc_802069853773_item	2891447	et	3	main
vabaduse	doc_802069853773_item	2891449	et	4	main
b	doc_802069853773_item	2891463	et	4	main
kokku	doc_802069853773_item	2891464	et	3	main
c	doc_802069853773_item	2891477	et	4	main
b	doc_802069853773_item	2891484	et	4	main
eest	doc_802069853773_item	2891487	et	4	main
alt	doc_802069853774_item	2891523	et	4	main
vastus	doc_802069853774_item	2891526	et	3	main
ühe	doc_802069853774_item	2891528	et	4	main
võimaldab	doc_802069853774_item	2891538	et	3	main
millal	doc_802069853774_item	2891547	et	3	main
on	doc_802069853774_item	2891573	et	4	main
5	doc_802069853774_item	2891577	et	2	main
registreerunud	doc_802069853774_item	2891588	et	4	main
meie	doc_802069853774_item	2891590	et	4	main
kuul	doc_802069853774_item	2891596	et	4	main
õppematerjalid	doc_802069853774_item	2891598	et	3	main
eest	doc_802069853774_item	2891607	et	4	main
meile	doc_802069853774_item	2891614	et	4	main
õpetaja	doc_802069853774_item	2891616	et	4	main
vaatab	doc_802069853774_item	2891617	et	3	main
selle	doc_802069853774_item	2891618	et	4	main
üle	doc_802069853774_item	2891619	et	3	main
8	doc_802069853774_item	2891620	et	2	main
iga	doc_802069853774_item	2891524	et	4	main
punkti	doc_802069853774_item	2891529	et	4	main
õpi	doc_802069853774_item	2891530	et	4	main
millal	doc_802069853774_item	2891531	et	3	main
1	doc_802069853774_item	2891532	et	2	main
seda	doc_802069853774_item	2891549	et	3	main
ajastu	doc_802069853774_item	2891556	et	4	main
mis	doc_802069853774_item	2891557	et	4	main
3	doc_802069853774_item	2891560	et	2	main
vabaduse	doc_802069853774_item	2891561	et	4	main
planeerida	doc_802069853774_item	2891562	et	3	main
aega	doc_802069853774_item	2891563	et	4	main
ning	doc_802069853774_item	2891564	et	3	main
eelise	doc_802069853774_item	2891565	et	4	main
omandada	doc_802069853774_item	2891566	et	3	main
teadmisi	doc_802069853774_item	2891567	et	4	main
vastavalt	doc_802069853774_item	2891568	et	4	main
individuaalsele	doc_802069853774_item	2891569	et	3	main
4	doc_802069853774_item	2891570	et	2	main
tasemele	doc_802069853774_item	2891571	et	3	main
aeg	doc_802069853774_item	2891572	et	3	main
kokku	doc_802069853774_item	2891578	et	3	main
pisut	doc_802069853774_item	2891583	et	3	main
tarkust	doc_802069853774_item	2891584	et	4	main
kui	doc_802069853774_item	2891585	et	3	main
oled	doc_802069853774_item	2891586	et	3	main
kursusele	doc_802069853774_item	2891587	et	3	main
postiasutusest	doc_802069853774_item	2891594	et	4	main
igal	doc_802069853774_item	2891595	et	3	main
kätte	doc_802069853774_item	2891597	et	4	main
raamatu	doc_802069853774_item	2891599	et	4	main
ja	doc_802069853774_item	2891600	et	3	main
selle	doc_802069853774_item	2891609	et	4	main
kättesaamisel	doc_802069853774_item	2891610	et	4	main
täidetud	doc_802069853774_item	2891612	et	4	main
kõik	doc_802069853774_item	2891630	et	4	main
b	doc_802069853774_item	2891645	et	4	main
a	doc_802069853774_item	2891652	et	4	main
d	doc_802069853774_item	2891658	et	4	main
3	doc_802069853774_item	2891660	et	2	main
b	doc_802069853774_item	2891663	et	4	main
vabanduse	doc_802069853774_item	2891664	et	4	main
vabaduse	doc_802069853774_item	2891668	et	4	main
c	doc_802069853774_item	2891674	et	4	main
tasakesi	doc_802069853774_item	2891675	et	3	main
a	doc_802069853774_item	2891701	et	4	main
ees	doc_802069853774_item	2891708	et	4	main
8	doc_802069853774_item	2891709	et	2	main
a	doc_802069853774_item	2891710	et	4	main
liigne	doc_802069853774_item	2891720	et	3	main
b	doc_802069853774_item	2891721	et	4	main
liikuv	doc_802069853774_item	2891724	et	4	main
d	doc_802069853774_item	2891725	et	4	main
lihtne	doc_802069853774_item	2891726	et	3	main
b	doc_802069853774_item	2891730	et	4	main
sõna	doc_802069853775_item	2891740	et	4	main
teksti	doc_802069853775_item	2891741	et	4	main
alt	doc_802069853775_item	2891742	et	4	main
ühe	doc_802069853775_item	2891747	et	4	main
sul	doc_802069853775_item	2891758	et	3	main
ja	doc_802069853775_item	2891765	et	3	main
millal	doc_802069853775_item	2891766	et	3	main
soovid	doc_802069853775_item	2891770	et	4	main
on	doc_802069853775_item	2891772	et	4	main
mis	doc_802069853775_item	2891776	et	4	main
3	doc_802069853775_item	2891779	et	2	main
vastavalt	doc_802069853775_item	2891787	et	4	main
individuaalsele	doc_802069853775_item	2891788	et	3	main
4	doc_802069853775_item	2891789	et	2	main
6	doc_802069853775_item	2891821	et	2	main
saada	doc_802069853775_item	2891830	et	4	main
täidetud	doc_802069853775_item	2891831	et	4	main
8	doc_802069853775_item	2891839	et	2	main
parandab	doc_802069853775_item	2891840	et	3	main
vead	doc_802069853775_item	2891841	et	4	main
ning	doc_802069853775_item	2891842	et	3	main
vajaduse	doc_802069853775_item	2891844	et	3	main
lisaküsimustele	doc_802069853775_item	2891848	et	4	main
geniaalne	doc_802069853775_item	2891850	et	3	main
on	doc_802069853775_item	2891851	et	4	main
10	doc_802069853775_item	2891854	et	2	main
b	doc_802069853775_item	2891873	et	4	main
a	doc_802069853775_item	2891880	et	4	main
vabanduse	doc_802069853775_item	2891883	et	4	main
varanduse	doc_802069853775_item	2891885	et	3	main
d	doc_802069853775_item	2891886	et	4	main
vabaduse	doc_802069853775_item	2891887	et	4	main
4	doc_802069853775_item	2891888	et	2	main
a	doc_802069853775_item	2891889	et	4	main
tasule	doc_802069853775_item	2891890	et	3	main
kokku	doc_802069853775_item	2891902	et	3	main
liita	doc_802069853775_item	2891903	et	4	main
kokku	doc_802069853775_item	2891905	et	3	main
d	doc_802069853775_item	2891907	et	4	main
kokku	doc_802069853775_item	2891908	et	3	main
panna	doc_802069853775_item	2891909	et	4	main
6	doc_802069853775_item	2891910	et	2	main
tagasi	doc_802069853774_item	2891615	et	3	main
vead	doc_802069853774_item	2891622	et	4	main
vajaduse	doc_802069853774_item	2891625	et	3	main
ka	doc_802069853774_item	2891627	et	3	main
9	doc_802069853774_item	2891633	et	2	main
meie	doc_802069853774_item	2891637	et	4	main
virtuaalkodu	doc_802069853774_item	2891638	et	4	main
1	doc_802069853774_item	2891642	et	2	main
a	doc_802069853774_item	2891643	et	4	main
d	doc_802069853774_item	2891649	et	4	main
solvud	doc_802069853774_item	2891650	et	3	main
2	doc_802069853774_item	2891651	et	2	main
b	doc_802069853774_item	2891654	et	4	main
4	doc_802069853774_item	2891669	et	2	main
b	doc_802069853774_item	2891672	et	4	main
d	doc_802069853774_item	2891707	et	4	main
d	doc_802069853774_item	2891716	et	4	main
muudab	doc_802069853774_item	2891717	et	3	main
9	doc_802069853774_item	2891718	et	2	main
10	doc_802069853774_item	2891727	et	2	main
tulge	doc_802069853774_item	2891729	et	3	main
käige	doc_802069853774_item	2891731	et	3	main
minge	doc_802069853774_item	2891735	et	3	main
harjutus	doc_802069853775_item	2891736	et	4	main
kirjutage	doc_802069853775_item	2891737	et	3	main
lünka	doc_802069853775_item	2891738	et	4	main
iga	doc_802069853775_item	2891743	et	4	main
umbne	doc_802069853775_item	2891754	et	3	main
klassiruum	doc_802069853775_item	2891755	et	3	main
koduõppesüsteem	doc_802069853775_item	2891756	et	3	main
parasjagu	doc_802069853775_item	2891769	et	3	main
ajastu	doc_802069853775_item	2891775	et	4	main
annab	doc_802069853775_item	2891777	et	3	main
omandada	doc_802069853775_item	2891785	et	3	main
teadmisi	doc_802069853775_item	2891786	et	4	main
7	doc_802069853775_item	2891825	et	2	main
selle	doc_802069853775_item	2891837	et	4	main
üle	doc_802069853775_item	2891838	et	3	main
ka	doc_802069853775_item	2891846	et	3	main
9	doc_802069853775_item	2891852	et	2	main
lihtne	doc_802069853775_item	2891853	et	3	main
minge	doc_802069853775_item	2891855	et	3	main
meie	doc_802069853775_item	2891856	et	4	main
sobid	doc_802069853775_item	2891863	et	4	main
c	doc_802069853775_item	2891866	et	4	main
soovitad	doc_802069853775_item	2891867	et	3	main
d	doc_802069853775_item	2891868	et	4	main
solvud	doc_802069853775_item	2891869	et	3	main
2	doc_802069853775_item	2891870	et	2	main
saada	doc_802069853775_item	2891900	et	4	main
c	doc_802069853775_item	2891904	et	4	main
vaid	doc_802069853775_item	2891914	et	3	main
eest	doc_802069853775_item	2891925	et	4	main
d	doc_802069853775_item	2891935	et	4	main
muudab	doc_802069853775_item	2891936	et	3	main
a	doc_802069853775_item	2891938	et	4	main
liigne	doc_802069853775_item	2891939	et	3	main
b	doc_802069853775_item	2891940	et	4	main
libe	doc_802069853775_item	2891941	et	3	main
käige	doc_802069853775_item	2891950	et	3	main
harjutus	doc_802069853776_item	2891955	et	4	main
lünka	doc_802069853776_item	2891957	et	4	main
sobiv	doc_802069853776_item	2891958	et	4	main
sõna	doc_802069853776_item	2891959	et	4	main
iga	doc_802069853776_item	2891962	et	4	main
õige	doc_802069853776_item	2891963	et	4	main
umbne	doc_802069853776_item	2891973	et	3	main
mis	doc_802069853776_item	2891995	et	4	main
annab	doc_802069853776_item	2891996	et	3	main
sulle	doc_802069853776_item	2891997	et	3	main
3	doc_802069853776_item	2891998	et	2	main
vastavalt	doc_802069853776_item	2892006	et	4	main
individuaalsele	doc_802069853776_item	2892007	et	3	main
vastab	doc_802069853774_item	2891624	et	3	main
lisaküsimustele	doc_802069853774_item	2891629	et	4	main
on	doc_802069853774_item	2891632	et	4	main
tulge	doc_802069853774_item	2891636	et	3	main
või	doc_802069853774_item	2891639	et	4	main
postitage	doc_802069853774_item	2891640	et	3	main
kupong	doc_802069853774_item	2891641	et	3	main
just	doc_802069853774_item	2891653	et	3	main
c	doc_802069853774_item	2891656	et	4	main
siiski	doc_802069853774_item	2891659	et	4	main
c	doc_802069853774_item	2891665	et	4	main
varanduse	doc_802069853774_item	2891666	et	3	main
tasemele	doc_802069853774_item	2891673	et	3	main
d	doc_802069853774_item	2891676	et	4	main
tasakaalule	doc_802069853774_item	2891677	et	3	main
5	doc_802069853774_item	2891678	et	2	main
a	doc_802069853774_item	2891679	et	4	main
kokku	doc_802069853774_item	2891680	et	3	main
saada	doc_802069853774_item	2891681	et	4	main
b	doc_802069853774_item	2891682	et	4	main
kokku	doc_802069853774_item	2891683	et	3	main
liita	doc_802069853774_item	2891684	et	4	main
kokku	doc_802069853774_item	2891686	et	3	main
hoida	doc_802069853774_item	2891687	et	3	main
c	doc_802069853774_item	2891685	et	4	main
d	doc_802069853774_item	2891688	et	4	main
kokku	doc_802069853774_item	2891689	et	3	main
panna	doc_802069853774_item	2891690	et	4	main
6	doc_802069853774_item	2891691	et	2	main
a	doc_802069853774_item	2891692	et	4	main
ning	doc_802069853774_item	2891693	et	3	main
b	doc_802069853774_item	2891694	et	4	main
vaid	doc_802069853774_item	2891695	et	3	main
c	doc_802069853774_item	2891696	et	4	main
kuid	doc_802069853774_item	2891697	et	4	main
d	doc_802069853774_item	2891698	et	4	main
et	doc_802069853774_item	2891699	et	3	main
7	doc_802069853774_item	2891700	et	2	main
lihtne	doc_802069853774_item	2891634	et	3	main
soovid	doc_802069853774_item	2891646	et	4	main
c	doc_802069853774_item	2891647	et	4	main
soovitad	doc_802069853774_item	2891648	et	3	main
seega	doc_802069853774_item	2891655	et	4	main
a	doc_802069853774_item	2891670	et	4	main
tasule	doc_802069853774_item	2891671	et	3	main
taga	doc_802069853774_item	2891702	et	4	main
ette	doc_802069853774_item	2891704	et	4	main
c	doc_802069853774_item	2891705	et	4	main
kirjutab	doc_802069853774_item	2891711	et	3	main
b	doc_802069853774_item	2891712	et	4	main
palub	doc_802069853774_item	2891713	et	3	main
b	doc_802069853774_item	2891703	et	4	main
a	doc_802069853774_item	2891719	et	4	main
libe	doc_802069853774_item	2891722	et	3	main
a	doc_802069853774_item	2891728	et	4	main
külastage	doc_802069853774_item	2891733	et	3	main
d	doc_802069853774_item	2891734	et	4	main
annab	doc_802069853775_item	2891746	et	3	main
õpi	doc_802069853775_item	2891749	et	4	main
1	doc_802069853775_item	2891751	et	2	main
soovid	doc_802069853775_item	2891752	et	4	main
saada	doc_802069853775_item	2891759	et	4	main
targemaks	doc_802069853775_item	2891760	et	4	main
just	doc_802069853775_item	2891762	et	3	main
seal	doc_802069853775_item	2891763	et	4	main
seda	doc_802069853775_item	2891768	et	3	main
käes	doc_802069853775_item	2891771	et	4	main
interaktiivse	doc_802069853775_item	2891773	et	3	main
õppe	doc_802069853775_item	2891774	et	4	main
sulle	doc_802069853775_item	2891778	et	3	main
vabaduse	doc_802069853775_item	2891780	et	4	main
planeerida	doc_802069853775_item	2891781	et	3	main
aega	doc_802069853775_item	2891782	et	4	main
eelise	doc_802069853775_item	2891784	et	4	main
kuid	doc_802069853775_item	2891822	et	4	main
õpetaja	doc_802069853775_item	2891835	et	4	main
vaatab	doc_802069853775_item	2891836	et	3	main
korral	doc_802069853775_item	2891845	et	4	main
virtuaalkodu	doc_802069853775_item	2891857	et	4	main
või	doc_802069853775_item	2891858	et	4	main
postitage	doc_802069853775_item	2891859	et	3	main
kupong	doc_802069853775_item	2891860	et	3	main
1	doc_802069853775_item	2891861	et	2	main
b	doc_802069853775_item	2891864	et	4	main
seega	doc_802069853775_item	2891874	et	4	main
vajaduse	doc_802069853775_item	2891881	et	3	main
b	doc_802069853775_item	2891891	et	4	main
tasemele	doc_802069853775_item	2891892	et	3	main
c	doc_802069853775_item	2891893	et	4	main
hoida	doc_802069853775_item	2891906	et	3	main
ette	doc_802069853775_item	2891923	et	4	main
d	doc_802069853775_item	2891926	et	4	main
c	doc_802069853775_item	2891933	et	4	main
liikuv	doc_802069853775_item	2891943	et	4	main
d	doc_802069853775_item	2891953	et	4	main
alt	doc_802069853776_item	2891961	et	4	main
ühe	doc_802069853776_item	2891966	et	4	main
punkti	doc_802069853776_item	2891967	et	4	main
1	doc_802069853776_item	2891970	et	2	main
klassiruum	doc_802069853776_item	2891974	et	3	main
sul	doc_802069853776_item	2891977	et	3	main
käes	doc_802069853776_item	2891990	et	4	main
interaktiivse	doc_802069853776_item	2891992	et	3	main
õppe	doc_802069853776_item	2891993	et	4	main
aega	doc_802069853776_item	2892001	et	4	main
ning	doc_802069853776_item	2892002	et	3	main
eelise	doc_802069853776_item	2892003	et	4	main
omandada	doc_802069853776_item	2892004	et	3	main
teadmisi	doc_802069853776_item	2892005	et	4	main
saad	doc_802069853776_item	2892027	et	4	main
või	doc_802069853776_item	2892030	et	4	main
kuul	doc_802069853776_item	2892034	et	4	main
raamatu	doc_802069853776_item	2892037	et	4	main
ja	doc_802069853776_item	2892038	et	3	main
6	doc_802069853776_item	2892040	et	2	main
ning	doc_802069853776_item	2892041	et	3	main
kodutöö	doc_802069853776_item	2892042	et	4	main
kursuse	doc_802069853776_item	2892043	et	3	main
7	doc_802069853776_item	2892044	et	2	main
selle	doc_802069853776_item	2892047	et	4	main
meile	doc_802069853776_item	2892052	et	4	main
selle	doc_802069853776_item	2892056	et	4	main
üle	doc_802069853776_item	2892057	et	3	main
vead	doc_802069853776_item	2892060	et	4	main
ning	doc_802069853776_item	2892061	et	3	main
a	doc_802069853776_item	2892081	et	4	main
soovid	doc_802069853776_item	2892084	et	4	main
d	doc_802069853776_item	2892096	et	4	main
siiski	doc_802069853776_item	2892097	et	4	main
c	doc_802069853776_item	2892123	et	4	main
vaid	doc_802069853776_item	2892133	et	3	main
7	doc_802069853776_item	2892138	et	2	main
b	doc_802069853776_item	2892141	et	4	main
ette	doc_802069853776_item	2892142	et	4	main
c	doc_802069853774_item	2891732	et	4	main
unusta	doc_802069853775_item	2891753	et	4	main
võimaldab	doc_802069853775_item	2891757	et	3	main
2	doc_802069853775_item	2891761	et	2	main
tasule	doc_802069853775_item	2891790	et	3	main
aeg	doc_802069853775_item	2891791	et	3	main
on	doc_802069853775_item	2891792	et	4	main
raha	doc_802069853775_item	2891793	et	4	main
et	doc_802069853775_item	2891794	et	3	main
seda	doc_802069853775_item	2891795	et	3	main
5	doc_802069853775_item	2891796	et	2	main
kokku	doc_802069853775_item	2891797	et	3	main
hoida	doc_802069853775_item	2891798	et	3	main
on	doc_802069853775_item	2891799	et	4	main
vaja	doc_802069853775_item	2891800	et	4	main
pisut	doc_802069853775_item	2891802	et	3	main
tarkust	doc_802069853775_item	2891803	et	4	main
kui	doc_802069853775_item	2891804	et	3	main
oled	doc_802069853775_item	2891805	et	3	main
ka	doc_802069853775_item	2891801	et	3	main
kursusele	doc_802069853775_item	2891806	et	3	main
registreerunud	doc_802069853775_item	2891807	et	4	main
saad	doc_802069853775_item	2891808	et	4	main
meie	doc_802069853775_item	2891809	et	4	main
kontorist	doc_802069853775_item	2891810	et	4	main
või	doc_802069853775_item	2891811	et	4	main
lähimast	doc_802069853775_item	2891812	et	4	main
postiasutusest	doc_802069853775_item	2891813	et	4	main
igal	doc_802069853775_item	2891814	et	3	main
kuul	doc_802069853775_item	2891815	et	4	main
kätte	doc_802069853775_item	2891816	et	4	main
õppematerjalid	doc_802069853775_item	2891817	et	3	main
raamatu	doc_802069853775_item	2891818	et	4	main
ja	doc_802069853775_item	2891819	et	3	main
helikasseti	doc_802069853775_item	2891820	et	4	main
kursuse	doc_802069853775_item	2891824	et	3	main
tasud	doc_802069853775_item	2891827	et	4	main
vastab	doc_802069853775_item	2891843	et	3	main
a	doc_802069853775_item	2891862	et	4	main
soovid	doc_802069853775_item	2891865	et	4	main
c	doc_802069853775_item	2891875	et	4	main
kuigi	doc_802069853775_item	2891876	et	3	main
d	doc_802069853775_item	2891877	et	4	main
b	doc_802069853775_item	2891882	et	4	main
c	doc_802069853775_item	2891884	et	4	main
tasakesi	doc_802069853775_item	2891894	et	3	main
d	doc_802069853775_item	2891895	et	4	main
tasakaalule	doc_802069853775_item	2891896	et	3	main
5	doc_802069853775_item	2891897	et	2	main
b	doc_802069853775_item	2891901	et	4	main
b	doc_802069853775_item	2891913	et	4	main
kodutöö	doc_802069853775_item	2891823	et	4	main
eest	doc_802069853775_item	2891826	et	4	main
selle	doc_802069853775_item	2891828	et	4	main
kättesaamisel	doc_802069853775_item	2891829	et	4	main
kodutöö	doc_802069853775_item	2891832	et	4	main
meile	doc_802069853775_item	2891833	et	4	main
tagasi	doc_802069853775_item	2891834	et	3	main
tekkinud	doc_802069853775_item	2891847	et	4	main
kõik	doc_802069853775_item	2891849	et	4	main
a	doc_802069853775_item	2891871	et	4	main
just	doc_802069853775_item	2891872	et	3	main
siiski	doc_802069853775_item	2891878	et	4	main
3	doc_802069853775_item	2891879	et	2	main
a	doc_802069853775_item	2891898	et	4	main
kokku	doc_802069853775_item	2891899	et	3	main
a	doc_802069853775_item	2891911	et	4	main
ning	doc_802069853775_item	2891912	et	3	main
c	doc_802069853775_item	2891915	et	4	main
kuid	doc_802069853775_item	2891916	et	4	main
d	doc_802069853775_item	2891917	et	4	main
et	doc_802069853775_item	2891918	et	3	main
7	doc_802069853775_item	2891919	et	2	main
a	doc_802069853775_item	2891920	et	4	main
taga	doc_802069853775_item	2891921	et	4	main
parandab	doc_802069853775_item	2891934	et	3	main
9	doc_802069853775_item	2891937	et	2	main
d	doc_802069853775_item	2891944	et	4	main
lihtne	doc_802069853775_item	2891945	et	3	main
10	doc_802069853775_item	2891946	et	2	main
c	doc_802069853775_item	2891951	et	4	main
annab	doc_802069853776_item	2891965	et	3	main
koduõppesüsteem	doc_802069853776_item	2891975	et	3	main
targemaks	doc_802069853776_item	2891979	et	4	main
just	doc_802069853776_item	2891981	et	3	main
seal	doc_802069853776_item	2891982	et	4	main
millal	doc_802069853776_item	2891985	et	3	main
sa	doc_802069853776_item	2891986	et	3	main
seda	doc_802069853776_item	2891987	et	3	main
parasjagu	doc_802069853776_item	2891988	et	3	main
soovid	doc_802069853776_item	2891989	et	4	main
ajastu	doc_802069853776_item	2891994	et	4	main
tarkust	doc_802069853776_item	2892022	et	4	main
kursusele	doc_802069853776_item	2892025	et	3	main
kätte	doc_802069853776_item	2892035	et	4	main
õppematerjalid	doc_802069853776_item	2892036	et	3	main
tasud	doc_802069853776_item	2892046	et	4	main
täidetud	doc_802069853776_item	2892050	et	4	main
tekkinud	doc_802069853776_item	2892066	et	4	main
lisaküsimustele	doc_802069853776_item	2892067	et	4	main
virtuaalkodu	doc_802069853776_item	2892076	et	4	main
või	doc_802069853776_item	2892077	et	4	main
postitage	doc_802069853776_item	2892078	et	3	main
kupong	doc_802069853776_item	2892079	et	3	main
1	doc_802069853776_item	2892080	et	2	main
c	doc_802069853776_item	2892085	et	4	main
2	doc_802069853776_item	2892089	et	2	main
seega	doc_802069853776_item	2892093	et	4	main
c	doc_802069853776_item	2892103	et	4	main
varanduse	doc_802069853776_item	2892104	et	3	main
kokku	doc_802069853776_item	2892121	et	3	main
c	doc_802069853776_item	2892134	et	4	main
kuid	doc_802069853776_item	2892135	et	4	main
a	doc_802069853776_item	2892139	et	4	main
eest	doc_802069853776_item	2892144	et	4	main
a	doc_802069853776_item	2892148	et	4	main
punkti	doc_802069853777_item	2892186	et	4	main
umbne	doc_802069853777_item	2892192	et	3	main
koduõppesüsteem	doc_802069853777_item	2892194	et	3	main
soovid	doc_802069853777_item	2892208	et	4	main
sulle	doc_802069853777_item	2892216	et	3	main
aega	doc_802069853777_item	2892220	et	4	main
ning	doc_802069853777_item	2892221	et	3	main
5	doc_802069853777_item	2892234	et	2	main
vaja	doc_802069853777_item	2892238	et	4	main
pisut	doc_802069853777_item	2892240	et	3	main
oled	doc_802069853777_item	2892243	et	3	main
b	doc_802069853775_item	2891922	et	4	main
8	doc_802069853775_item	2891928	et	2	main
a	doc_802069853775_item	2891929	et	4	main
kirjutab	doc_802069853775_item	2891930	et	3	main
b	doc_802069853775_item	2891931	et	4	main
palub	doc_802069853775_item	2891932	et	3	main
c	doc_802069853775_item	2891942	et	4	main
külastage	doc_802069853775_item	2891952	et	3	main
minge	doc_802069853775_item	2891954	et	3	main
teksti	doc_802069853776_item	2891960	et	4	main
soovitad	doc_802069853776_item	2891971	et	3	main
saada	doc_802069853776_item	2891978	et	4	main
kus	doc_802069853776_item	2891983	et	3	main
ja	doc_802069853776_item	2891984	et	3	main
on	doc_802069853776_item	2891991	et	4	main
tasemele	doc_802069853776_item	2892009	et	3	main
aeg	doc_802069853776_item	2892010	et	3	main
on	doc_802069853776_item	2892011	et	4	main
raha	doc_802069853776_item	2892012	et	4	main
et	doc_802069853776_item	2892013	et	3	main
seda	doc_802069853776_item	2892014	et	3	main
5	doc_802069853776_item	2892015	et	2	main
kokku	doc_802069853776_item	2892016	et	3	main
hoida	doc_802069853776_item	2892017	et	3	main
on	doc_802069853776_item	2892018	et	4	main
vaja	doc_802069853776_item	2892019	et	4	main
ka	doc_802069853776_item	2892020	et	3	main
kui	doc_802069853776_item	2892023	et	3	main
lähimast	doc_802069853776_item	2892031	et	4	main
postiasutusest	doc_802069853776_item	2892032	et	4	main
igal	doc_802069853776_item	2892033	et	3	main
helikasseti	doc_802069853776_item	2892039	et	4	main
kodutöö	doc_802069853776_item	2892051	et	4	main
õpetaja	doc_802069853776_item	2892054	et	4	main
b	doc_802069853776_item	2892083	et	4	main
d	doc_802069853776_item	2892087	et	4	main
vabanduse	doc_802069853776_item	2892102	et	4	main
a	doc_802069853776_item	2892130	et	4	main
ning	doc_802069853776_item	2892131	et	3	main
et	doc_802069853776_item	2892137	et	3	main
taga	doc_802069853776_item	2892140	et	4	main
ees	doc_802069853776_item	2892146	et	4	main
b	doc_802069853776_item	2892150	et	4	main
palub	doc_802069853776_item	2892151	et	3	main
c	doc_802069853776_item	2892152	et	4	main
parandab	doc_802069853776_item	2892153	et	3	main
d	doc_802069853776_item	2892154	et	4	main
muudab	doc_802069853776_item	2892155	et	3	main
9	doc_802069853776_item	2892156	et	2	main
õpi	doc_802069853777_item	2892187	et	4	main
millal	doc_802069853777_item	2892188	et	3	main
sobib	doc_802069853777_item	2892190	et	3	main
võimaldab	doc_802069853777_item	2892195	et	3	main
saada	doc_802069853777_item	2892197	et	4	main
2	doc_802069853777_item	2892199	et	2	main
just	doc_802069853777_item	2892200	et	3	main
seal	doc_802069853777_item	2892201	et	4	main
parasjagu	doc_802069853777_item	2892207	et	3	main
on	doc_802069853777_item	2892210	et	4	main
interaktiivse	doc_802069853777_item	2892211	et	3	main
ajastu	doc_802069853777_item	2892213	et	4	main
vajaduse	doc_802069853777_item	2892218	et	3	main
c	doc_802069853775_item	2891924	et	4	main
ees	doc_802069853775_item	2891927	et	4	main
a	doc_802069853775_item	2891947	et	4	main
tulge	doc_802069853775_item	2891948	et	3	main
b	doc_802069853775_item	2891949	et	4	main
kirjutage	doc_802069853776_item	2891956	et	3	main
vastus	doc_802069853776_item	2891964	et	3	main
õpi	doc_802069853776_item	2891968	et	4	main
millal	doc_802069853776_item	2891969	et	3	main
unusta	doc_802069853776_item	2891972	et	4	main
võimaldab	doc_802069853776_item	2891976	et	3	main
2	doc_802069853776_item	2891980	et	2	main
vabaduse	doc_802069853776_item	2891999	et	4	main
planeerida	doc_802069853776_item	2892000	et	3	main
4	doc_802069853776_item	2892008	et	2	main
pisut	doc_802069853776_item	2892021	et	3	main
registreerunud	doc_802069853776_item	2892026	et	4	main
meie	doc_802069853776_item	2892028	et	4	main
kontorist	doc_802069853776_item	2892029	et	4	main
kättesaamisel	doc_802069853776_item	2892048	et	4	main
tagasi	doc_802069853776_item	2892053	et	3	main
vaatab	doc_802069853776_item	2892055	et	3	main
8	doc_802069853776_item	2892058	et	2	main
parandab	doc_802069853776_item	2892059	et	3	main
kõik	doc_802069853776_item	2892068	et	4	main
geniaalne	doc_802069853776_item	2892069	et	3	main
on	doc_802069853776_item	2892070	et	4	main
9	doc_802069853776_item	2892071	et	2	main
lihtne	doc_802069853776_item	2892072	et	3	main
soovitad	doc_802069853776_item	2892086	et	3	main
solvud	doc_802069853776_item	2892088	et	3	main
a	doc_802069853776_item	2892090	et	4	main
just	doc_802069853776_item	2892091	et	3	main
b	doc_802069853776_item	2892092	et	4	main
3	doc_802069853776_item	2892098	et	2	main
a	doc_802069853776_item	2892099	et	4	main
vajaduse	doc_802069853776_item	2892100	et	3	main
b	doc_802069853776_item	2892101	et	4	main
d	doc_802069853776_item	2892105	et	4	main
vabaduse	doc_802069853776_item	2892106	et	4	main
4	doc_802069853776_item	2892107	et	2	main
oled	doc_802069853776_item	2892024	et	3	main
ette	doc_802069853776_item	2892045	et	4	main
saada	doc_802069853776_item	2892049	et	4	main
vastab	doc_802069853776_item	2892062	et	3	main
vajaduse	doc_802069853776_item	2892063	et	3	main
korral	doc_802069853776_item	2892064	et	4	main
ka	doc_802069853776_item	2892065	et	3	main
10	doc_802069853776_item	2892073	et	2	main
tulge	doc_802069853776_item	2892074	et	3	main
meie	doc_802069853776_item	2892075	et	4	main
sobid	doc_802069853776_item	2892082	et	4	main
c	doc_802069853776_item	2892094	et	4	main
kuigi	doc_802069853776_item	2892095	et	3	main
a	doc_802069853776_item	2892108	et	4	main
tasule	doc_802069853776_item	2892109	et	3	main
b	doc_802069853776_item	2892110	et	4	main
tasemele	doc_802069853776_item	2892111	et	3	main
c	doc_802069853776_item	2892112	et	4	main
tasakesi	doc_802069853776_item	2892113	et	3	main
d	doc_802069853776_item	2892114	et	4	main
5	doc_802069853776_item	2892116	et	2	main
tasakaalule	doc_802069853776_item	2892115	et	3	main
a	doc_802069853776_item	2892117	et	4	main
kokku	doc_802069853776_item	2892118	et	3	main
saada	doc_802069853776_item	2892119	et	4	main
b	doc_802069853776_item	2892120	et	4	main
liita	doc_802069853776_item	2892122	et	4	main
kokku	doc_802069853776_item	2892124	et	3	main
hoida	doc_802069853776_item	2892125	et	3	main
d	doc_802069853776_item	2892126	et	4	main
kokku	doc_802069853776_item	2892127	et	3	main
panna	doc_802069853776_item	2892128	et	4	main
6	doc_802069853776_item	2892129	et	2	main
d	doc_802069853776_item	2892136	et	4	main
d	doc_802069853776_item	2892145	et	4	main
b	doc_802069853776_item	2892159	et	4	main
liikuv	doc_802069853776_item	2892162	et	4	main
vastus	doc_802069853777_item	2892183	et	3	main
annab	doc_802069853777_item	2892184	et	3	main
ühe	doc_802069853777_item	2892185	et	4	main
kus	doc_802069853777_item	2892202	et	3	main
ja	doc_802069853777_item	2892203	et	3	main
millal	doc_802069853777_item	2892204	et	3	main
sa	doc_802069853777_item	2892205	et	3	main
seda	doc_802069853777_item	2892206	et	3	main
käes	doc_802069853777_item	2892209	et	4	main
mis	doc_802069853777_item	2892214	et	4	main
kokku	doc_802069853777_item	2892235	et	3	main
kontorist	doc_802069853777_item	2892248	et	4	main
kätte	doc_802069853777_item	2892254	et	4	main
raamatu	doc_802069853777_item	2892256	et	4	main
kodutöö	doc_802069853777_item	2892270	et	4	main
vaatab	doc_802069853777_item	2892274	et	3	main
üle	doc_802069853777_item	2892276	et	3	main
kõik	doc_802069853777_item	2892287	et	4	main
geniaalne	doc_802069853777_item	2892288	et	3	main
on	doc_802069853777_item	2892289	et	4	main
meie	doc_802069853777_item	2892294	et	4	main
või	doc_802069853777_item	2892296	et	4	main
postitage	doc_802069853777_item	2892297	et	3	main
c	doc_802069853777_item	2892304	et	4	main
soovitad	doc_802069853777_item	2892305	et	3	main
d	doc_802069853777_item	2892306	et	4	main
2	doc_802069853777_item	2892308	et	2	main
c	doc_802069853777_item	2892322	et	4	main
b	doc_802069853777_item	2892329	et	4	main
liita	doc_802069853777_item	2892341	et	4	main
c	doc_802069853777_item	2892342	et	4	main
kokku	doc_802069853777_item	2892343	et	3	main
d	doc_802069853777_item	2892345	et	4	main
a	doc_802069853777_item	2892349	et	4	main
et	doc_802069853777_item	2892356	et	3	main
c	doc_802069853777_item	2892362	et	4	main
soovid	doc_802069853778_item	2892427	et	4	main
b	doc_802069853776_item	2892132	et	4	main
c	doc_802069853776_item	2892143	et	4	main
a	doc_802069853776_item	2892157	et	4	main
liigne	doc_802069853776_item	2892158	et	3	main
c	doc_802069853776_item	2892161	et	4	main
d	doc_802069853776_item	2892163	et	4	main
lihtne	doc_802069853776_item	2892164	et	3	main
10	doc_802069853776_item	2892165	et	2	main
a	doc_802069853776_item	2892166	et	4	main
tulge	doc_802069853776_item	2892167	et	3	main
b	doc_802069853776_item	2892168	et	4	main
käige	doc_802069853776_item	2892169	et	3	main
c	doc_802069853776_item	2892170	et	4	main
külastage	doc_802069853776_item	2892171	et	3	main
d	doc_802069853776_item	2892172	et	4	main
minge	doc_802069853776_item	2892173	et	3	main
harjutus	doc_802069853777_item	2892174	et	4	main
kirjutage	doc_802069853777_item	2892175	et	3	main
lünka	doc_802069853777_item	2892176	et	4	main
sobiv	doc_802069853777_item	2892177	et	4	main
sõna	doc_802069853777_item	2892178	et	4	main
teksti	doc_802069853777_item	2892179	et	4	main
alt	doc_802069853777_item	2892180	et	4	main
iga	doc_802069853777_item	2892181	et	4	main
8	doc_802069853776_item	2892147	et	2	main
kirjutab	doc_802069853776_item	2892149	et	3	main
libe	doc_802069853776_item	2892160	et	3	main
1	doc_802069853777_item	2892189	et	2	main
klassiruum	doc_802069853777_item	2892193	et	3	main
õppe	doc_802069853777_item	2892212	et	4	main
3	doc_802069853777_item	2892217	et	2	main
raha	doc_802069853777_item	2892231	et	4	main
et	doc_802069853777_item	2892232	et	3	main
seda	doc_802069853777_item	2892233	et	3	main
meie	doc_802069853777_item	2892247	et	4	main
igal	doc_802069853777_item	2892252	et	3	main
tasud	doc_802069853777_item	2892265	et	4	main
selle	doc_802069853777_item	2892266	et	4	main
õpetaja	doc_802069853777_item	2892273	et	4	main
lihtne	doc_802069853777_item	2892278	et	3	main
1	doc_802069853777_item	2892299	et	2	main
a	doc_802069853777_item	2892300	et	4	main
sobid	doc_802069853777_item	2892301	et	4	main
b	doc_802069853777_item	2892302	et	4	main
vabanduse	doc_802069853777_item	2892321	et	4	main
tasule	doc_802069853777_item	2892328	et	3	main
c	doc_802069853777_item	2892331	et	4	main
d	doc_802069853777_item	2892333	et	4	main
tasakaalule	doc_802069853777_item	2892334	et	3	main
kokku	doc_802069853777_item	2892340	et	3	main
kokku	doc_802069853777_item	2892346	et	3	main
d	doc_802069853777_item	2892355	et	4	main
7	doc_802069853777_item	2892357	et	2	main
a	doc_802069853777_item	2892358	et	4	main
eest	doc_802069853777_item	2892363	et	4	main
ees	doc_802069853777_item	2892365	et	4	main
d	doc_802069853777_item	2892373	et	4	main
muudab	doc_802069853777_item	2892374	et	3	main
9	doc_802069853777_item	2892375	et	2	main
a	doc_802069853777_item	2892376	et	4	main
b	doc_802069853777_item	2892378	et	4	main
libe	doc_802069853777_item	2892379	et	3	main
c	doc_802069853777_item	2892380	et	4	main
10	doc_802069853777_item	2892384	et	2	main
kus	doc_802069853778_item	2892421	et	3	main
millal	doc_802069853778_item	2892423	et	3	main
seda	doc_802069853778_item	2892425	et	3	main
raha	doc_802069853778_item	2892450	et	4	main
et	doc_802069853778_item	2892451	et	3	main
oled	doc_802069853778_item	2892462	et	3	main
7	doc_802069853778_item	2892482	et	2	main
selle	doc_802069853778_item	2892485	et	4	main
kättesaamisel	doc_802069853778_item	2892486	et	4	main
vead	doc_802069853778_item	2892498	et	4	main
korral	doc_802069853778_item	2892502	et	4	main
tekkinud	doc_802069853778_item	2892504	et	4	main
lisaküsimustele	doc_802069853778_item	2892505	et	4	main
solvud	doc_802069853778_item	2892526	et	3	main
just	doc_802069853778_item	2892529	et	3	main
siiski	doc_802069853778_item	2892535	et	4	main
b	doc_802069853778_item	2892548	et	4	main
hoida	doc_802069853778_item	2892563	et	3	main
kokku	doc_802069853778_item	2892565	et	3	main
6	doc_802069853778_item	2892567	et	2	main
a	doc_802069853778_item	2892577	et	4	main
ette	doc_802069853778_item	2892580	et	4	main
ees	doc_802069853778_item	2892584	et	4	main
targemaks	doc_802069853779_item	2892636	et	4	main
on	doc_802069853779_item	2892648	et	4	main
ajastu	doc_802069853779_item	2892651	et	4	main
mis	doc_802069853779_item	2892652	et	4	main
vabaduse	doc_802069853779_item	2892656	et	4	main
eelise	doc_802069853779_item	2892660	et	4	main
vastavalt	doc_802069853779_item	2892663	et	4	main
raha	doc_802069853779_item	2892669	et	4	main
et	doc_802069853779_item	2892670	et	3	main
seda	doc_802069853779_item	2892671	et	3	main
5	doc_802069853779_item	2892672	et	2	main
kokku	doc_802069853779_item	2892673	et	3	main
hoida	doc_802069853779_item	2892674	et	3	main
on	doc_802069853779_item	2892675	et	4	main
oled	doc_802069853779_item	2892681	et	3	main
kätte	doc_802069853779_item	2892692	et	4	main
õppematerjalid	doc_802069853779_item	2892693	et	3	main
raamatu	doc_802069853779_item	2892694	et	4	main
ja	doc_802069853779_item	2892695	et	3	main
tasud	doc_802069853779_item	2892703	et	4	main
õige	doc_802069853777_item	2892182	et	4	main
unusta	doc_802069853777_item	2892191	et	4	main
sul	doc_802069853777_item	2892196	et	3	main
targemaks	doc_802069853777_item	2892198	et	4	main
annab	doc_802069853777_item	2892215	et	3	main
planeerida	doc_802069853777_item	2892219	et	3	main
omandada	doc_802069853777_item	2892223	et	3	main
vastavalt	doc_802069853777_item	2892225	et	4	main
4	doc_802069853777_item	2892227	et	2	main
tasemele	doc_802069853777_item	2892228	et	3	main
aeg	doc_802069853777_item	2892229	et	3	main
on	doc_802069853777_item	2892230	et	4	main
on	doc_802069853777_item	2892237	et	4	main
kursusele	doc_802069853777_item	2892244	et	3	main
lähimast	doc_802069853777_item	2892250	et	4	main
kuul	doc_802069853777_item	2892253	et	4	main
õppematerjalid	doc_802069853777_item	2892255	et	3	main
helikasseti	doc_802069853777_item	2892258	et	4	main
kättesaamisel	doc_802069853777_item	2892267	et	4	main
meile	doc_802069853777_item	2892271	et	4	main
vead	doc_802069853777_item	2892279	et	4	main
vastab	doc_802069853777_item	2892281	et	3	main
korral	doc_802069853777_item	2892283	et	4	main
ka	doc_802069853777_item	2892284	et	3	main
tekkinud	doc_802069853777_item	2892285	et	4	main
10	doc_802069853777_item	2892292	et	2	main
soovid	doc_802069853777_item	2892303	et	4	main
d	doc_802069853777_item	2892324	et	4	main
vabaduse	doc_802069853777_item	2892325	et	4	main
kokku	doc_802069853777_item	2892337	et	3	main
hoida	doc_802069853777_item	2892344	et	3	main
6	doc_802069853777_item	2892348	et	2	main
ning	doc_802069853777_item	2892350	et	3	main
c	doc_802069853777_item	2892353	et	4	main
b	doc_802069853777_item	2892360	et	4	main
c	doc_802069853777_item	2892371	et	4	main
parandab	doc_802069853777_item	2892372	et	3	main
liikuv	doc_802069853777_item	2892381	et	4	main
eelise	doc_802069853777_item	2892222	et	4	main
teadmisi	doc_802069853777_item	2892224	et	4	main
individuaalsele	doc_802069853777_item	2892226	et	3	main
hoida	doc_802069853777_item	2892236	et	3	main
ka	doc_802069853777_item	2892239	et	3	main
tarkust	doc_802069853777_item	2892241	et	4	main
kui	doc_802069853777_item	2892242	et	3	main
või	doc_802069853777_item	2892249	et	4	main
kursuse	doc_802069853777_item	2892262	et	3	main
saada	doc_802069853777_item	2892268	et	4	main
tagasi	doc_802069853777_item	2892272	et	3	main
8	doc_802069853777_item	2892277	et	2	main
9	doc_802069853777_item	2892290	et	2	main
lihtne	doc_802069853777_item	2892291	et	3	main
solvud	doc_802069853777_item	2892307	et	3	main
a	doc_802069853777_item	2892309	et	4	main
just	doc_802069853777_item	2892310	et	3	main
b	doc_802069853777_item	2892311	et	4	main
seega	doc_802069853777_item	2892312	et	4	main
c	doc_802069853777_item	2892313	et	4	main
kuigi	doc_802069853777_item	2892314	et	3	main
d	doc_802069853777_item	2892315	et	4	main
siiski	doc_802069853777_item	2892316	et	4	main
3	doc_802069853777_item	2892317	et	2	main
a	doc_802069853777_item	2892318	et	4	main
vajaduse	doc_802069853777_item	2892319	et	3	main
b	doc_802069853777_item	2892320	et	4	main
a	doc_802069853777_item	2892327	et	4	main
b	doc_802069853777_item	2892339	et	4	main
kuid	doc_802069853777_item	2892354	et	4	main
ette	doc_802069853777_item	2892361	et	4	main
d	doc_802069853777_item	2892364	et	4	main
8	doc_802069853777_item	2892366	et	2	main
a	doc_802069853777_item	2892367	et	4	main
kirjutab	doc_802069853777_item	2892368	et	3	main
b	doc_802069853777_item	2892369	et	4	main
palub	doc_802069853777_item	2892370	et	3	main
d	doc_802069853777_item	2892382	et	4	main
a	doc_802069853777_item	2892385	et	4	main
parasjagu	doc_802069853778_item	2892426	et	3	main
ajastu	doc_802069853778_item	2892432	et	4	main
mis	doc_802069853778_item	2892433	et	4	main
vabanduse	doc_802069853778_item	2892437	et	4	main
ning	doc_802069853778_item	2892440	et	3	main
omandada	doc_802069853778_item	2892442	et	3	main
5	doc_802069853778_item	2892453	et	2	main
vaja	doc_802069853778_item	2892457	et	4	main
raamatu	doc_802069853778_item	2892475	et	4	main
saada	doc_802069853778_item	2892487	et	4	main
selle	doc_802069853778_item	2892494	et	4	main
üle	doc_802069853778_item	2892495	et	3	main
8	doc_802069853778_item	2892496	et	2	main
parandab	doc_802069853778_item	2892497	et	3	main
on	doc_802069853778_item	2892508	et	4	main
9	doc_802069853778_item	2892509	et	2	main
10	doc_802069853778_item	2892511	et	2	main
tulge	doc_802069853778_item	2892512	et	3	main
virtuaalkodu	doc_802069853778_item	2892514	et	4	main
või	doc_802069853778_item	2892515	et	4	main
postitage	doc_802069853778_item	2892516	et	3	main
kupong	doc_802069853778_item	2892517	et	3	main
2	doc_802069853778_item	2892527	et	2	main
a	doc_802069853778_item	2892537	et	4	main
vajaduse	doc_802069853778_item	2892538	et	3	main
b	doc_802069853778_item	2892539	et	4	main
vabanduse	doc_802069853778_item	2892540	et	4	main
vabaduse	doc_802069853778_item	2892544	et	4	main
a	doc_802069853778_item	2892546	et	4	main
saada	doc_802069853778_item	2892557	et	4	main
b	doc_802069853778_item	2892558	et	4	main
kokku	doc_802069853778_item	2892559	et	3	main
liita	doc_802069853778_item	2892560	et	4	main
d	doc_802069853778_item	2892564	et	4	main
d	doc_802069853778_item	2892574	et	4	main
registreerunud	doc_802069853777_item	2892245	et	4	main
saad	doc_802069853777_item	2892246	et	4	main
postiasutusest	doc_802069853777_item	2892251	et	4	main
ja	doc_802069853777_item	2892257	et	3	main
6	doc_802069853777_item	2892259	et	2	main
ning	doc_802069853777_item	2892260	et	3	main
kodutöö	doc_802069853777_item	2892261	et	4	main
7	doc_802069853777_item	2892263	et	2	main
ees	doc_802069853777_item	2892264	et	4	main
täidetud	doc_802069853777_item	2892269	et	4	main
selle	doc_802069853777_item	2892275	et	4	main
ning	doc_802069853777_item	2892280	et	3	main
vajaduse	doc_802069853777_item	2892282	et	3	main
lisaküsimustele	doc_802069853777_item	2892286	et	4	main
minge	doc_802069853777_item	2892293	et	3	main
virtuaalkodu	doc_802069853777_item	2892295	et	4	main
kupong	doc_802069853777_item	2892298	et	3	main
varanduse	doc_802069853777_item	2892323	et	3	main
4	doc_802069853777_item	2892326	et	2	main
tasemele	doc_802069853777_item	2892330	et	3	main
tasakesi	doc_802069853777_item	2892332	et	3	main
5	doc_802069853777_item	2892335	et	2	main
a	doc_802069853777_item	2892336	et	4	main
saada	doc_802069853777_item	2892338	et	4	main
panna	doc_802069853777_item	2892347	et	4	main
b	doc_802069853777_item	2892351	et	4	main
vaid	doc_802069853777_item	2892352	et	3	main
taga	doc_802069853777_item	2892359	et	4	main
liigne	doc_802069853777_item	2892377	et	3	main
lihtne	doc_802069853777_item	2892383	et	3	main
tulge	doc_802069853777_item	2892386	et	3	main
b	doc_802069853777_item	2892387	et	4	main
käige	doc_802069853777_item	2892388	et	3	main
c	doc_802069853777_item	2892389	et	4	main
külastage	doc_802069853777_item	2892390	et	3	main
d	doc_802069853777_item	2892391	et	4	main
minge	doc_802069853777_item	2892392	et	3	main
harjutus	doc_802069853778_item	2892393	et	4	main
kirjutage	doc_802069853778_item	2892394	et	3	main
lünka	doc_802069853778_item	2892395	et	4	main
sobiv	doc_802069853778_item	2892396	et	4	main
sõna	doc_802069853778_item	2892397	et	4	main
teksti	doc_802069853778_item	2892398	et	4	main
alt	doc_802069853778_item	2892399	et	4	main
iga	doc_802069853778_item	2892400	et	4	main
õige	doc_802069853778_item	2892401	et	4	main
vastus	doc_802069853778_item	2892402	et	3	main
annab	doc_802069853778_item	2892403	et	3	main
ühe	doc_802069853778_item	2892404	et	4	main
punkti	doc_802069853778_item	2892405	et	4	main
õpi	doc_802069853778_item	2892406	et	4	main
millal	doc_802069853778_item	2892407	et	3	main
1	doc_802069853778_item	2892408	et	2	main
sobid	doc_802069853778_item	2892409	et	4	main
unusta	doc_802069853778_item	2892410	et	4	main
umbne	doc_802069853778_item	2892411	et	3	main
klassiruum	doc_802069853778_item	2892412	et	3	main
koduõppesüsteem	doc_802069853778_item	2892413	et	3	main
võimaldab	doc_802069853778_item	2892414	et	3	main
sul	doc_802069853778_item	2892415	et	3	main
saada	doc_802069853778_item	2892416	et	4	main
targemaks	doc_802069853778_item	2892417	et	4	main
2	doc_802069853778_item	2892418	et	2	main
just	doc_802069853778_item	2892419	et	3	main
seal	doc_802069853778_item	2892420	et	4	main
annab	doc_802069853778_item	2892434	et	3	main
eelise	doc_802069853778_item	2892441	et	4	main
teadmisi	doc_802069853778_item	2892443	et	4	main
vastavalt	doc_802069853778_item	2892444	et	4	main
individuaalsele	doc_802069853778_item	2892445	et	3	main
4	doc_802069853778_item	2892446	et	2	main
tasule	doc_802069853778_item	2892447	et	3	main
aeg	doc_802069853778_item	2892448	et	3	main
kokku	doc_802069853778_item	2892454	et	3	main
on	doc_802069853778_item	2892456	et	4	main
ka	doc_802069853778_item	2892458	et	3	main
pisut	doc_802069853778_item	2892459	et	3	main
tarkust	doc_802069853778_item	2892460	et	4	main
kui	doc_802069853778_item	2892461	et	3	main
registreerunud	doc_802069853778_item	2892464	et	4	main
saad	doc_802069853778_item	2892465	et	4	main
kontorist	doc_802069853778_item	2892467	et	4	main
meie	doc_802069853778_item	2892466	et	4	main
või	doc_802069853778_item	2892468	et	4	main
lähimast	doc_802069853778_item	2892469	et	4	main
postiasutusest	doc_802069853778_item	2892470	et	4	main
igal	doc_802069853778_item	2892471	et	3	main
kuul	doc_802069853778_item	2892472	et	4	main
kätte	doc_802069853778_item	2892473	et	4	main
õppematerjalid	doc_802069853778_item	2892474	et	3	main
ja	doc_802069853778_item	2892422	et	3	main
sa	doc_802069853778_item	2892424	et	3	main
käes	doc_802069853778_item	2892428	et	4	main
sulle	doc_802069853778_item	2892435	et	3	main
on	doc_802069853778_item	2892449	et	4	main
seda	doc_802069853778_item	2892452	et	3	main
kursusele	doc_802069853778_item	2892463	et	3	main
kodutöö	doc_802069853778_item	2892480	et	4	main
meile	doc_802069853778_item	2892490	et	4	main
tagasi	doc_802069853778_item	2892491	et	3	main
õpetaja	doc_802069853778_item	2892492	et	4	main
vaatab	doc_802069853778_item	2892493	et	3	main
vajaduse	doc_802069853778_item	2892501	et	3	main
lihtne	doc_802069853778_item	2892510	et	3	main
sobid	doc_802069853778_item	2892520	et	4	main
on	doc_802069853778_item	2892429	et	4	main
interaktiivse	doc_802069853778_item	2892430	et	3	main
õppe	doc_802069853778_item	2892431	et	4	main
3	doc_802069853778_item	2892436	et	2	main
planeerida	doc_802069853778_item	2892438	et	3	main
aega	doc_802069853778_item	2892439	et	4	main
panna	doc_802069853778_item	2892455	et	4	main
ja	doc_802069853778_item	2892476	et	3	main
helikasseti	doc_802069853778_item	2892477	et	4	main
6	doc_802069853778_item	2892478	et	2	main
vaid	doc_802069853778_item	2892479	et	3	main
ees	doc_802069853778_item	2892483	et	4	main
tasud	doc_802069853778_item	2892484	et	4	main
täidetud	doc_802069853778_item	2892488	et	4	main
kodutöö	doc_802069853778_item	2892489	et	4	main
ning	doc_802069853778_item	2892499	et	3	main
ka	doc_802069853778_item	2892503	et	3	main
kõik	doc_802069853778_item	2892506	et	4	main
geniaalne	doc_802069853778_item	2892507	et	3	main
1	doc_802069853778_item	2892518	et	2	main
a	doc_802069853778_item	2892519	et	4	main
d	doc_802069853778_item	2892525	et	4	main
3	doc_802069853778_item	2892536	et	2	main
d	doc_802069853778_item	2892543	et	4	main
a	doc_802069853778_item	2892555	et	4	main
kokku	doc_802069853778_item	2892556	et	3	main
kokku	doc_802069853778_item	2892562	et	3	main
kuid	doc_802069853778_item	2892573	et	4	main
d	doc_802069853778_item	2892583	et	4	main
a	doc_802069853778_item	2892586	et	4	main
b	doc_802069853778_item	2892588	et	4	main
ühe	doc_802069853779_item	2892623	et	4	main
õpi	doc_802069853779_item	2892625	et	4	main
seal	doc_802069853779_item	2892639	et	4	main
kus	doc_802069853779_item	2892640	et	3	main
ja	doc_802069853779_item	2892641	et	3	main
millal	doc_802069853779_item	2892642	et	3	main
sa	doc_802069853779_item	2892643	et	3	main
seda	doc_802069853779_item	2892644	et	3	main
parasjagu	doc_802069853779_item	2892645	et	3	main
3	doc_802069853779_item	2892655	et	2	main
kui	doc_802069853779_item	2892680	et	3	main
saad	doc_802069853779_item	2892684	et	4	main
kontorist	doc_802069853779_item	2892686	et	4	main
igal	doc_802069853779_item	2892690	et	3	main
kodutöö	doc_802069853779_item	2892699	et	4	main
7	doc_802069853779_item	2892701	et	2	main
ees	doc_802069853779_item	2892702	et	4	main
selle	doc_802069853779_item	2892704	et	4	main
kättesaamisel	doc_802069853779_item	2892705	et	4	main
tekkinud	doc_802069853779_item	2892723	et	4	main
a	doc_802069853779_item	2892738	et	4	main
d	doc_802069853779_item	2892744	et	4	main
a	doc_802069853779_item	2892747	et	4	main
b	doc_802069853779_item	2892749	et	4	main
siiski	doc_802069853779_item	2892754	et	4	main
d	doc_802069853779_item	2892762	et	4	main
vabaduse	doc_802069853779_item	2892763	et	4	main
4	doc_802069853779_item	2892764	et	2	main
5	doc_802069853779_item	2892773	et	2	main
a	doc_802069853779_item	2892774	et	4	main
kokku	doc_802069853779_item	2892775	et	3	main
liita	doc_802069853779_item	2892779	et	4	main
kokku	doc_802069853779_item	2892781	et	3	main
c	doc_802069853779_item	2892791	et	4	main
kuid	doc_802069853779_item	2892792	et	4	main
d	doc_802069853779_item	2892793	et	4	main
et	doc_802069853779_item	2892794	et	3	main
7	doc_802069853779_item	2892795	et	2	main
b	doc_802069853779_item	2892798	et	4	main
c	doc_802069853779_item	2892800	et	4	main
eest	doc_802069853779_item	2892801	et	4	main
kursuse	doc_802069853778_item	2892481	et	3	main
vastab	doc_802069853778_item	2892500	et	3	main
meie	doc_802069853778_item	2892513	et	4	main
b	doc_802069853778_item	2892521	et	4	main
c	doc_802069853778_item	2892523	et	4	main
soovitad	doc_802069853778_item	2892524	et	3	main
d	doc_802069853778_item	2892534	et	4	main
c	doc_802069853778_item	2892541	et	4	main
varanduse	doc_802069853778_item	2892542	et	3	main
4	doc_802069853778_item	2892545	et	2	main
tasule	doc_802069853778_item	2892547	et	3	main
c	doc_802069853778_item	2892550	et	4	main
tasakesi	doc_802069853778_item	2892551	et	3	main
d	doc_802069853778_item	2892552	et	4	main
tasakaalule	doc_802069853778_item	2892553	et	3	main
5	doc_802069853778_item	2892554	et	2	main
c	doc_802069853778_item	2892561	et	4	main
panna	doc_802069853778_item	2892566	et	4	main
a	doc_802069853778_item	2892568	et	4	main
ning	doc_802069853778_item	2892569	et	3	main
b	doc_802069853778_item	2892570	et	4	main
vaid	doc_802069853778_item	2892571	et	3	main
c	doc_802069853778_item	2892572	et	4	main
taga	doc_802069853778_item	2892578	et	4	main
8	doc_802069853778_item	2892585	et	2	main
kirjutab	doc_802069853778_item	2892587	et	3	main
vastus	doc_802069853779_item	2892621	et	3	main
saada	doc_802069853779_item	2892635	et	4	main
2	doc_802069853779_item	2892637	et	2	main
siiski	doc_802069853779_item	2892638	et	4	main
käes	doc_802069853779_item	2892647	et	4	main
õppe	doc_802069853779_item	2892650	et	4	main
annab	doc_802069853779_item	2892653	et	3	main
aega	doc_802069853779_item	2892658	et	4	main
ning	doc_802069853779_item	2892659	et	3	main
vaja	doc_802069853779_item	2892676	et	4	main
pisut	doc_802069853779_item	2892678	et	3	main
lähimast	doc_802069853779_item	2892688	et	4	main
kursuse	doc_802069853779_item	2892700	et	3	main
saada	doc_802069853779_item	2892706	et	4	main
kodutöö	doc_802069853779_item	2892708	et	4	main
lisaküsimustele	doc_802069853779_item	2892724	et	4	main
on	doc_802069853779_item	2892727	et	4	main
10	doc_802069853779_item	2892730	et	2	main
meie	doc_802069853779_item	2892732	et	4	main
soovitad	doc_802069853779_item	2892743	et	3	main
2	doc_802069853779_item	2892746	et	2	main
3	doc_802069853779_item	2892755	et	2	main
a	doc_802069853779_item	2892756	et	4	main
vajaduse	doc_802069853779_item	2892757	et	3	main
b	doc_802069853779_item	2892758	et	4	main
a	doc_802069853779_item	2892765	et	4	main
tasule	doc_802069853779_item	2892766	et	3	main
b	doc_802069853779_item	2892767	et	4	main
tasemele	doc_802069853779_item	2892768	et	3	main
b	doc_802069853779_item	2892777	et	4	main
c	doc_802069853779_item	2892780	et	4	main
hoida	doc_802069853779_item	2892782	et	3	main
taga	doc_802069853779_item	2892797	et	4	main
tulge	doc_802069853779_item	2892824	et	3	main
alt	doc_802069853780_item	2892837	et	4	main
iga	doc_802069853780_item	2892838	et	4	main
1	doc_802069853780_item	2892846	et	2	main
soovid	doc_802069853780_item	2892847	et	4	main
millal	doc_802069853780_item	2892861	et	3	main
eelise	doc_802069853780_item	2892879	et	4	main
individuaalsele	doc_802069853780_item	2892883	et	3	main
tarkust	doc_802069853780_item	2892898	et	4	main
registreerunud	doc_802069853780_item	2892902	et	4	main
lähimast	doc_802069853780_item	2892907	et	4	main
ees	doc_802069853780_item	2892921	et	4	main
kättesaamisel	doc_802069853780_item	2892924	et	4	main
õpetaja	doc_802069853780_item	2892930	et	4	main
vaatab	doc_802069853780_item	2892931	et	3	main
ka	doc_802069853780_item	2892941	et	3	main
10	doc_802069853780_item	2892949	et	2	main
meie	doc_802069853780_item	2892951	et	4	main
või	doc_802069853780_item	2892953	et	4	main
postitage	doc_802069853780_item	2892954	et	3	main
kupong	doc_802069853780_item	2892955	et	3	main
1	doc_802069853780_item	2892956	et	2	main
c	doc_802069853780_item	2892961	et	4	main
soovid	doc_802069853778_item	2892522	et	4	main
a	doc_802069853778_item	2892528	et	4	main
b	doc_802069853778_item	2892530	et	4	main
seega	doc_802069853778_item	2892531	et	4	main
c	doc_802069853778_item	2892532	et	4	main
kuigi	doc_802069853778_item	2892533	et	3	main
tasemele	doc_802069853778_item	2892549	et	3	main
b	doc_802069853778_item	2892579	et	4	main
c	doc_802069853778_item	2892581	et	4	main
eest	doc_802069853778_item	2892582	et	4	main
palub	doc_802069853778_item	2892589	et	3	main
parandab	doc_802069853778_item	2892591	et	3	main
c	doc_802069853778_item	2892590	et	4	main
d	doc_802069853778_item	2892592	et	4	main
muudab	doc_802069853778_item	2892593	et	3	main
9	doc_802069853778_item	2892594	et	2	main
a	doc_802069853778_item	2892595	et	4	main
liigne	doc_802069853778_item	2892596	et	3	main
b	doc_802069853778_item	2892597	et	4	main
libe	doc_802069853778_item	2892598	et	3	main
c	doc_802069853778_item	2892599	et	4	main
liikuv	doc_802069853778_item	2892600	et	4	main
d	doc_802069853778_item	2892601	et	4	main
lihtne	doc_802069853778_item	2892602	et	3	main
10	doc_802069853778_item	2892603	et	2	main
a	doc_802069853778_item	2892604	et	4	main
tulge	doc_802069853778_item	2892605	et	3	main
b	doc_802069853778_item	2892606	et	4	main
käige	doc_802069853778_item	2892607	et	3	main
c	doc_802069853778_item	2892608	et	4	main
külastage	doc_802069853778_item	2892609	et	3	main
d	doc_802069853778_item	2892610	et	4	main
minge	doc_802069853778_item	2892611	et	3	main
harjutus	doc_802069853779_item	2892612	et	4	main
kirjutage	doc_802069853779_item	2892613	et	3	main
lünka	doc_802069853779_item	2892614	et	4	main
sobiv	doc_802069853779_item	2892615	et	4	main
sõna	doc_802069853779_item	2892616	et	4	main
teksti	doc_802069853779_item	2892617	et	4	main
alt	doc_802069853779_item	2892618	et	4	main
iga	doc_802069853779_item	2892619	et	4	main
õige	doc_802069853779_item	2892620	et	4	main
et	doc_802069853778_item	2892575	et	3	main
7	doc_802069853778_item	2892576	et	2	main
annab	doc_802069853779_item	2892622	et	3	main
soovid	doc_802069853779_item	2892646	et	4	main
omandada	doc_802069853779_item	2892661	et	3	main
individuaalsele	doc_802069853779_item	2892664	et	3	main
ka	doc_802069853779_item	2892677	et	3	main
tarkust	doc_802069853779_item	2892679	et	4	main
meile	doc_802069853779_item	2892709	et	4	main
tagasi	doc_802069853779_item	2892710	et	3	main
korral	doc_802069853779_item	2892721	et	4	main
virtuaalkodu	doc_802069853779_item	2892733	et	4	main
või	doc_802069853779_item	2892734	et	4	main
postitage	doc_802069853779_item	2892735	et	3	main
kupong	doc_802069853779_item	2892736	et	3	main
1	doc_802069853779_item	2892737	et	2	main
soovid	doc_802069853779_item	2892741	et	4	main
solvud	doc_802069853779_item	2892745	et	3	main
just	doc_802069853779_item	2892748	et	3	main
seega	doc_802069853779_item	2892750	et	4	main
c	doc_802069853779_item	2892751	et	4	main
kuigi	doc_802069853779_item	2892752	et	3	main
vabanduse	doc_802069853779_item	2892759	et	4	main
saada	doc_802069853779_item	2892776	et	4	main
b	doc_802069853779_item	2892789	et	4	main
vaid	doc_802069853779_item	2892790	et	3	main
10	doc_802069853779_item	2892822	et	2	main
c	doc_802069853779_item	2892827	et	4	main
teksti	doc_802069853780_item	2892836	et	4	main
õpi	doc_802069853780_item	2892844	et	4	main
millal	doc_802069853780_item	2892845	et	3	main
2	doc_802069853780_item	2892856	et	2	main
just	doc_802069853780_item	2892857	et	3	main
seal	doc_802069853780_item	2892858	et	4	main
kus	doc_802069853780_item	2892859	et	3	main
ja	doc_802069853780_item	2892860	et	3	main
planeerida	doc_802069853780_item	2892876	et	3	main
teadmisi	doc_802069853780_item	2892881	et	4	main
vastavalt	doc_802069853780_item	2892882	et	4	main
4	doc_802069853780_item	2892884	et	2	main
tasemele	doc_802069853780_item	2892885	et	3	main
aeg	doc_802069853780_item	2892886	et	3	main
kontorist	doc_802069853780_item	2892905	et	4	main
saada	doc_802069853780_item	2892925	et	4	main
selle	doc_802069853780_item	2892932	et	4	main
üle	doc_802069853780_item	2892933	et	3	main
on	doc_802069853780_item	2892946	et	4	main
sobid	doc_802069853780_item	2892958	et	4	main
b	doc_802069853780_item	2892959	et	4	main
a	doc_802069853780_item	2892966	et	4	main
c	doc_802069853780_item	2892979	et	4	main
vabaduse	doc_802069853780_item	2892982	et	4	main
a	doc_802069853780_item	2892984	et	4	main
tasemele	doc_802069853780_item	2892987	et	3	main
b	doc_802069853780_item	2892996	et	4	main
sul	doc_802069853779_item	2892634	et	3	main
punkti	doc_802069853779_item	2892624	et	4	main
millal	doc_802069853779_item	2892626	et	3	main
1	doc_802069853779_item	2892627	et	2	main
soovitad	doc_802069853779_item	2892628	et	3	main
unusta	doc_802069853779_item	2892629	et	4	main
umbne	doc_802069853779_item	2892630	et	3	main
klassiruum	doc_802069853779_item	2892631	et	3	main
koduõppesüsteem	doc_802069853779_item	2892632	et	3	main
võimaldab	doc_802069853779_item	2892633	et	3	main
interaktiivse	doc_802069853779_item	2892649	et	3	main
sulle	doc_802069853779_item	2892654	et	3	main
planeerida	doc_802069853779_item	2892657	et	3	main
teadmisi	doc_802069853779_item	2892662	et	4	main
4	doc_802069853779_item	2892665	et	2	main
tasemele	doc_802069853779_item	2892666	et	3	main
aeg	doc_802069853779_item	2892667	et	3	main
on	doc_802069853779_item	2892668	et	4	main
kursusele	doc_802069853779_item	2892682	et	3	main
registreerunud	doc_802069853779_item	2892683	et	4	main
meie	doc_802069853779_item	2892685	et	4	main
või	doc_802069853779_item	2892687	et	4	main
postiasutusest	doc_802069853779_item	2892689	et	4	main
kuul	doc_802069853779_item	2892691	et	4	main
helikasseti	doc_802069853779_item	2892696	et	4	main
6	doc_802069853779_item	2892697	et	2	main
vaid	doc_802069853779_item	2892698	et	3	main
õpetaja	doc_802069853779_item	2892711	et	4	main
vaatab	doc_802069853779_item	2892712	et	3	main
selle	doc_802069853779_item	2892713	et	4	main
üle	doc_802069853779_item	2892714	et	3	main
8	doc_802069853779_item	2892715	et	2	main
parandab	doc_802069853779_item	2892716	et	3	main
vead	doc_802069853779_item	2892717	et	4	main
ning	doc_802069853779_item	2892718	et	3	main
vastab	doc_802069853779_item	2892719	et	3	main
vajaduse	doc_802069853779_item	2892720	et	3	main
kõik	doc_802069853779_item	2892725	et	4	main
geniaalne	doc_802069853779_item	2892726	et	3	main
lihtne	doc_802069853779_item	2892729	et	3	main
sobid	doc_802069853779_item	2892739	et	4	main
c	doc_802069853779_item	2892742	et	4	main
d	doc_802069853779_item	2892753	et	4	main
c	doc_802069853779_item	2892760	et	4	main
varanduse	doc_802069853779_item	2892761	et	3	main
c	doc_802069853779_item	2892769	et	4	main
tasakesi	doc_802069853779_item	2892770	et	3	main
kokku	doc_802069853779_item	2892778	et	3	main
d	doc_802069853779_item	2892783	et	4	main
kokku	doc_802069853779_item	2892784	et	3	main
panna	doc_802069853779_item	2892785	et	4	main
6	doc_802069853779_item	2892786	et	2	main
d	doc_802069853779_item	2892802	et	4	main
b	doc_802069853779_item	2892825	et	4	main
käige	doc_802069853779_item	2892826	et	3	main
külastage	doc_802069853779_item	2892828	et	3	main
minge	doc_802069853779_item	2892830	et	3	main
harjutus	doc_802069853780_item	2892831	et	4	main
kirjutage	doc_802069853780_item	2892832	et	3	main
lünka	doc_802069853780_item	2892833	et	4	main
punkti	doc_802069853780_item	2892843	et	4	main
võimaldab	doc_802069853780_item	2892852	et	3	main
sa	doc_802069853780_item	2892862	et	3	main
soovid	doc_802069853780_item	2892865	et	4	main
on	doc_802069853780_item	2892867	et	4	main
interaktiivse	doc_802069853780_item	2892868	et	3	main
õppe	doc_802069853780_item	2892869	et	4	main
annab	doc_802069853780_item	2892872	et	3	main
3	doc_802069853780_item	2892874	et	2	main
on	doc_802069853780_item	2892894	et	4	main
oled	doc_802069853780_item	2892900	et	3	main
või	doc_802069853780_item	2892906	et	4	main
postiasutusest	doc_802069853780_item	2892908	et	4	main
täidetud	doc_802069853779_item	2892707	et	4	main
ka	doc_802069853779_item	2892722	et	3	main
9	doc_802069853779_item	2892728	et	2	main
külastage	doc_802069853779_item	2892731	et	3	main
b	doc_802069853779_item	2892740	et	4	main
d	doc_802069853779_item	2892771	et	4	main
tasakaalule	doc_802069853779_item	2892772	et	3	main
a	doc_802069853779_item	2892787	et	4	main
ning	doc_802069853779_item	2892788	et	3	main
a	doc_802069853779_item	2892796	et	4	main
ette	doc_802069853779_item	2892799	et	4	main
ees	doc_802069853779_item	2892803	et	4	main
8	doc_802069853779_item	2892804	et	2	main
a	doc_802069853779_item	2892805	et	4	main
kirjutab	doc_802069853779_item	2892806	et	3	main
b	doc_802069853779_item	2892807	et	4	main
palub	doc_802069853779_item	2892808	et	3	main
c	doc_802069853779_item	2892809	et	4	main
parandab	doc_802069853779_item	2892810	et	3	main
d	doc_802069853779_item	2892811	et	4	main
muudab	doc_802069853779_item	2892812	et	3	main
9	doc_802069853779_item	2892813	et	2	main
a	doc_802069853779_item	2892814	et	4	main
liigne	doc_802069853779_item	2892815	et	3	main
b	doc_802069853779_item	2892816	et	4	main
libe	doc_802069853779_item	2892817	et	3	main
c	doc_802069853779_item	2892818	et	4	main
liikuv	doc_802069853779_item	2892819	et	4	main
d	doc_802069853779_item	2892820	et	4	main
lihtne	doc_802069853779_item	2892821	et	3	main
d	doc_802069853779_item	2892829	et	4	main
sõna	doc_802069853780_item	2892835	et	4	main
vastus	doc_802069853780_item	2892840	et	3	main
annab	doc_802069853780_item	2892841	et	3	main
ühe	doc_802069853780_item	2892842	et	4	main
umbne	doc_802069853780_item	2892849	et	3	main
klassiruum	doc_802069853780_item	2892850	et	3	main
sul	doc_802069853780_item	2892853	et	3	main
seda	doc_802069853780_item	2892863	et	3	main
ajastu	doc_802069853780_item	2892870	et	4	main
omandada	doc_802069853780_item	2892880	et	3	main
on	doc_802069853780_item	2892887	et	4	main
raha	doc_802069853780_item	2892888	et	4	main
et	doc_802069853780_item	2892889	et	3	main
seda	doc_802069853780_item	2892890	et	3	main
5	doc_802069853780_item	2892891	et	2	main
kokku	doc_802069853780_item	2892892	et	3	main
hoida	doc_802069853780_item	2892893	et	3	main
kui	doc_802069853780_item	2892899	et	3	main
kursusele	doc_802069853780_item	2892901	et	3	main
saad	doc_802069853780_item	2892903	et	4	main
meie	doc_802069853780_item	2892904	et	4	main
raamatu	doc_802069853780_item	2892913	et	4	main
täidetud	doc_802069853780_item	2892926	et	4	main
8	doc_802069853780_item	2892934	et	2	main
parandab	doc_802069853780_item	2892935	et	3	main
vead	doc_802069853780_item	2892936	et	4	main
ning	doc_802069853780_item	2892937	et	3	main
vastab	doc_802069853780_item	2892938	et	3	main
vajaduse	doc_802069853780_item	2892939	et	3	main
9	doc_802069853780_item	2892947	et	2	main
virtuaalkodu	doc_802069853780_item	2892952	et	4	main
a	doc_802069853780_item	2892957	et	4	main
siiski	doc_802069853780_item	2892973	et	4	main
3	doc_802069853780_item	2892974	et	2	main
a	doc_802069853780_item	2892975	et	4	main
a	doc_802069853779_item	2892823	et	4	main
sobiv	doc_802069853780_item	2892834	et	4	main
õige	doc_802069853780_item	2892839	et	4	main
unusta	doc_802069853780_item	2892848	et	4	main
koduõppesüsteem	doc_802069853780_item	2892851	et	3	main
saada	doc_802069853780_item	2892854	et	4	main
targemaks	doc_802069853780_item	2892855	et	4	main
parasjagu	doc_802069853780_item	2892864	et	3	main
käes	doc_802069853780_item	2892866	et	4	main
mis	doc_802069853780_item	2892871	et	4	main
sulle	doc_802069853780_item	2892873	et	3	main
varanduse	doc_802069853780_item	2892875	et	3	main
aega	doc_802069853780_item	2892877	et	4	main
ning	doc_802069853780_item	2892878	et	3	main
vaja	doc_802069853780_item	2892895	et	4	main
ka	doc_802069853780_item	2892896	et	3	main
pisut	doc_802069853780_item	2892897	et	3	main
ja	doc_802069853780_item	2892914	et	3	main
helikasseti	doc_802069853780_item	2892915	et	4	main
6	doc_802069853780_item	2892916	et	2	main
ning	doc_802069853780_item	2892917	et	3	main
kodutöö	doc_802069853780_item	2892918	et	4	main
kursuse	doc_802069853780_item	2892919	et	3	main
7	doc_802069853780_item	2892920	et	2	main
tasud	doc_802069853780_item	2892922	et	4	main
selle	doc_802069853780_item	2892923	et	4	main
kodutöö	doc_802069853780_item	2892927	et	4	main
meile	doc_802069853780_item	2892928	et	4	main
tagasi	doc_802069853780_item	2892929	et	3	main
korral	doc_802069853780_item	2892940	et	4	main
kõik	doc_802069853780_item	2892944	et	4	main
geniaalne	doc_802069853780_item	2892945	et	3	main
lihtne	doc_802069853780_item	2892948	et	3	main
soovid	doc_802069853780_item	2892960	et	4	main
just	doc_802069853780_item	2892967	et	3	main
seega	doc_802069853780_item	2892969	et	4	main
c	doc_802069853780_item	2892970	et	4	main
kuigi	doc_802069853780_item	2892971	et	3	main
vabanduse	doc_802069853780_item	2892978	et	4	main
b	doc_802069853780_item	2892986	et	4	main
tasakaalule	doc_802069853780_item	2892991	et	3	main
a	doc_802069853780_item	2892993	et	4	main
kokku	doc_802069853780_item	2892994	et	3	main
liita	doc_802069853780_item	2892998	et	4	main
c	doc_802069853780_item	2893028	et	4	main
parandab	doc_802069853780_item	2893029	et	3	main
d	doc_802069853780_item	2893030	et	4	main
muudab	doc_802069853780_item	2893031	et	3	main
b	doc_802069853780_item	2893035	et	4	main
libe	doc_802069853780_item	2893036	et	3	main
liikuv	doc_802069853780_item	2893038	et	4	main
a	doc_802069853780_item	2893042	et	4	main
tulge	doc_802069853780_item	2893043	et	3	main
käige	doc_802069853780_item	2893045	et	3	main
igal	doc_802069853780_item	2892909	et	3	main
kuul	doc_802069853780_item	2892910	et	4	main
kätte	doc_802069853780_item	2892911	et	4	main
õppematerjalid	doc_802069853780_item	2892912	et	3	main
tekkinud	doc_802069853780_item	2892942	et	4	main
lisaküsimustele	doc_802069853780_item	2892943	et	4	main
tulge	doc_802069853780_item	2892950	et	3	main
d	doc_802069853780_item	2892972	et	4	main
d	doc_802069853780_item	2892981	et	4	main
c	doc_802069853780_item	2892988	et	4	main
tasakesi	doc_802069853780_item	2892989	et	3	main
d	doc_802069853780_item	2892990	et	4	main
5	doc_802069853780_item	2892992	et	2	main
c	doc_802069853780_item	2892999	et	4	main
kokku	doc_802069853780_item	2893000	et	3	main
hoida	doc_802069853780_item	2893001	et	3	main
d	doc_802069853780_item	2893002	et	4	main
kokku	doc_802069853780_item	2893003	et	3	main
6	doc_802069853780_item	2893005	et	2	main
panna	doc_802069853780_item	2893004	et	4	main
a	doc_802069853780_item	2893006	et	4	main
ning	doc_802069853780_item	2893007	et	3	main
b	doc_802069853780_item	2893008	et	4	main
vaid	doc_802069853780_item	2893009	et	3	main
c	doc_802069853780_item	2893010	et	4	main
kuid	doc_802069853780_item	2893011	et	4	main
d	doc_802069853780_item	2893012	et	4	main
et	doc_802069853780_item	2893013	et	3	main
7	doc_802069853780_item	2893014	et	2	main
a	doc_802069853780_item	2893015	et	4	main
taga	doc_802069853780_item	2893016	et	4	main
b	doc_802069853780_item	2893017	et	4	main
ette	doc_802069853780_item	2893018	et	4	main
c	doc_802069853780_item	2893019	et	4	main
eest	doc_802069853780_item	2893020	et	4	main
lihtne	doc_802069853780_item	2893040	et	3	main
soovitad	doc_802069853780_item	2892962	et	3	main
d	doc_802069853780_item	2892963	et	4	main
solvud	doc_802069853780_item	2892964	et	3	main
2	doc_802069853780_item	2892965	et	2	main
b	doc_802069853780_item	2892968	et	4	main
vajaduse	doc_802069853780_item	2892976	et	3	main
b	doc_802069853780_item	2892977	et	4	main
kokku	doc_802069853780_item	2892997	et	3	main
ees	doc_802069853780_item	2893022	et	4	main
a	doc_802069853780_item	2893024	et	4	main
kirjutab	doc_802069853780_item	2893025	et	3	main
a	doc_802069853780_item	2893033	et	4	main
c	doc_802069853780_item	2893037	et	4	main
d	doc_802069853780_item	2893039	et	4	main
c	doc_802069853780_item	2893046	et	4	main
külastage	doc_802069853780_item	2893047	et	3	main
pidu	doc_802069853782_item	2893184	et	4	main
ja	doc_802069853782_item	2893193	et	3	main
võib	doc_802069853782_item	2893195	et	3	main
tervist	doc_802069853782_item	2893232	et	4	main
õnne	doc_802069853782_item	2893242	et	4	main
nagu	doc_802069853782_item	2893243	et	3	main
soovivad	doc_802069853782_item	2893244	et	4	main
oodata	doc_802069853782_item	2893252	et	4	main
aga	doc_802069853782_item	2893256	et	3	main
sõbrad	doc_802069853782_item	2893276	et	3	main
ja	doc_802069853782_item	2893293	et	3	main
rasked	doc_802069853783_item	2893322	et	3	main
tõsiselt	doc_802069853783_item	2893331	et	4	main
kõigepealt	doc_802069853783_item	2893337	et	3	main
hästi	doc_802069853783_item	2893344	et	3	main
tahan	doc_802069853783_item	2893352	et	3	main
mis	doc_802069853783_item	2893362	et	4	main
ma	doc_802069853783_item	2893365	et	3	main
aast	doc_802069853783_item	2893369	et	4	main
peab	doc_802069853783_item	2893370	et	4	main
huvitavam	doc_802069853783_item	2893372	et	4	main
olema	doc_802069853783_item	2893382	et	4	main
on	doc_802069853783_item	2893385	et	4	main
praegu	doc_802069853783_item	2893401	et	3	main
aastal	doc_802069853783_item	2893415	et	3	main
ülikoolis	doc_802069853783_item	2893425	et	4	main
see	doc_802069853783_item	2893426	et	3	main
on	doc_802069853783_item	2893427	et	4	main
aastas	doc_802069853784_item	2893441	et	3	main
saaksin	doc_802069853784_item	2893444	et	3	main
mull	doc_802069853784_item	2893449	et	3	main
vähem	doc_802069853784_item	2893463	et	4	main
kui	doc_802069853784_item	2893464	et	3	main
veel	doc_802069853784_item	2893470	et	4	main
ma	doc_802069853784_item	2893474	et	3	main
varanduse	doc_802069853780_item	2892980	et	3	main
4	doc_802069853780_item	2892983	et	2	main
tasule	doc_802069853780_item	2892985	et	3	main
saada	doc_802069853780_item	2892995	et	4	main
d	doc_802069853780_item	2893021	et	4	main
9	doc_802069853780_item	2893032	et	2	main
essee	doc_802069853782_item	2893177	et	4	main
mida	doc_802069853782_item	2893178	et	4	main
ma	doc_802069853782_item	2893179	et	3	main
ootan	doc_802069853782_item	2893180	et	3	main
uuelt	doc_802069853782_item	2893181	et	4	main
aastalt	doc_802069853782_item	2893182	et	3	main
see	doc_802069853782_item	2893183	et	3	main
kiiresti	doc_802069853782_item	2893192	et	3	main
mida	doc_802069853782_item	2893194	et	4	main
oodata	doc_802069853782_item	2893196	et	4	main
edasi	doc_802069853782_item	2893197	et	3	main
keegi	doc_802069853782_item	2893198	et	4	main
ei	doc_802069853782_item	2893199	et	4	main
see	doc_802069853782_item	2893210	et	3	main
on	doc_802069853782_item	2893235	et	4	main
üldse	doc_802069853782_item	2893237	et	3	main
elus	doc_802069853782_item	2893238	et	4	main
ja	doc_802069853782_item	2893239	et	3	main
teisele	doc_802069853782_item	2893248	et	4	main
igaks	doc_802069853782_item	2893249	et	3	main
peoks	doc_802069853782_item	2893250	et	4	main
võib	doc_802069853782_item	2893251	et	3	main
surt	doc_802069853782_item	2893254	et	4	main
on	doc_802069853782_item	2893259	et	4	main
võib	doc_802069853782_item	2893262	et	3	main
ainult	doc_802069853782_item	2893264	et	4	main
seda	doc_802069853782_item	2893265	et	3	main
et	doc_802069853782_item	2893266	et	3	main
mu	doc_802069853782_item	2893267	et	3	main
neju	doc_802069853782_item	2893268	et	4	main
armastaks	doc_802069853782_item	2893269	et	3	main
toimub	doc_802069853782_item	2893290	et	3	main
lõbusalt	doc_802069853782_item	2893292	et	4	main
mida	doc_802069853783_item	2893299	et	4	main
sest	doc_802069853783_item	2893324	et	4	main
ma	doc_802069853783_item	2893326	et	3	main
tahan	doc_802069853783_item	2893327	et	3	main
väga	doc_802069853783_item	2893328	et	3	main
kui	doc_802069853783_item	2893335	et	3	main
õppida	doc_802069853783_item	2893341	et	3	main
sellest	doc_802069853783_item	2893345	et	4	main
vaja	doc_802069853783_item	2893347	et	4	main
või	doc_802069853783_item	2893360	et	4	main
kõigidega	doc_802069853783_item	2893361	et	4	main
et	doc_802069853783_item	2893367	et	3	main
olema	doc_802069853783_item	2893371	et	4	main
toredam	doc_802069853783_item	2893374	et	4	main
aastal	doc_802069853783_item	2893378	et	3	main
vanem	doc_802069853783_item	2893381	et	4	main
veebruaril	doc_802069853783_item	2893383	et	3	main
8	doc_802069853780_item	2893023	et	2	main
b	doc_802069853780_item	2893026	et	4	main
palub	doc_802069853780_item	2893027	et	3	main
liigne	doc_802069853780_item	2893034	et	3	main
10	doc_802069853780_item	2893041	et	2	main
b	doc_802069853780_item	2893044	et	4	main
d	doc_802069853780_item	2893048	et	4	main
minge	doc_802069853780_item	2893049	et	3	main
on	doc_802069853782_item	2893185	et	4	main
tihti	doc_802069853782_item	2893190	et	3	main
mina	doc_802069853782_item	2893202	et	4	main
ootan	doc_802069853782_item	2893203	et	3	main
uuelt	doc_802069853782_item	2893204	et	4	main
aastalt	doc_802069853782_item	2893205	et	3	main
hästi	doc_802069853782_item	2893206	et	3	main
sooritanud	doc_802069853782_item	2893207	et	4	main
eksamit	doc_802069853782_item	2893208	et	3	main
on	doc_802069853782_item	2893211	et	4	main
kui	doc_802069853782_item	2893221	et	3	main
halvasti	doc_802069853782_item	2893223	et	3	main
eksamit	doc_802069853782_item	2893225	et	3	main
sest	doc_802069853782_item	2893233	et	4	main
oluline	doc_802069853782_item	2893236	et	4	main
juba	doc_802069853782_item	2893258	et	3	main
siis	doc_802069853782_item	2893261	et	3	main
oodata	doc_802069853782_item	2893263	et	4	main
jäävad	doc_802069853782_item	2893277	et	4	main
sõbradena	doc_802069853782_item	2893278	et	4	main
ja	doc_802069853782_item	2893279	et	3	main
seda	doc_802069853782_item	2893280	et	3	main
ma	doc_802069853782_item	2893281	et	3	main
ootan	doc_802069853782_item	2893282	et	3	main
uuelt	doc_802069853782_item	2893283	et	4	main
aastalt	doc_802069853782_item	2893284	et	3	main
ma	doc_802069853782_item	2893285	et	3	main
loodan	doc_802069853782_item	2893286	et	3	main
et	doc_802069853782_item	2893287	et	3	main
see	doc_802069853782_item	2893288	et	3	main
ma	doc_802069853783_item	2893338	et	3	main
õppida	doc_802069853783_item	2893343	et	3	main
on	doc_802069853783_item	2893346	et	4	main
tahan	doc_802069853783_item	2893357	et	3	main
arvutiga	doc_802069853783_item	2893359	et	4	main
arvutisüsteemidega	doc_802069853783_item	2893364	et	3	main
ärgmine	doc_802069853783_item	2893368	et	4	main
eelmine	doc_802069853783_item	2893376	et	3	main
ma	doc_802069853783_item	2893392	et	3	main
süünnipäev	doc_802069853783_item	2893396	et	4	main
huvitavam	doc_802069853783_item	2893398	et	4	main
veel	doc_802069853783_item	2893403	et	4	main
ei	doc_802069853783_item	2893404	et	4	main
mida	doc_802069853783_item	2893406	et	4	main
täpselt	doc_802069853783_item	2893407	et	4	main
ma	doc_802069853783_item	2893408	et	3	main
tahan	doc_802069853783_item	2893409	et	3	main
valmistada	doc_802069853783_item	2893410	et	3	main
kui	doc_802069853783_item	2893411	et	3	main
hästi	doc_802069853783_item	2893412	et	3	main
kurs	doc_802069853783_item	2893420	et	4	main
lõppetada	doc_802069853783_item	2893421	et	4	main
minu	doc_802069853783_item	2893428	et	3	main
jaoks	doc_802069853783_item	2893429	et	4	main
probleem	doc_802069853783_item	2893432	et	3	main
minu	doc_802069853784_item	2893434	et	3	main
minu	doc_802069853784_item	2893436	et	3	main
surem	doc_802069853784_item	2893438	et	4	main
soov	doc_802069853784_item	2893439	et	3	main
et	doc_802069853784_item	2893442	et	3	main
palju	doc_802069853784_item	2893452	et	4	main
soovid	doc_802069853784_item	2893453	et	4	main
tahan	doc_802069853784_item	2893456	et	3	main
töö	doc_802069853784_item	2893458	et	4	main
kus	doc_802069853784_item	2893459	et	3	main
palk	doc_802069853784_item	2893460	et	3	main
väga	doc_802069853782_item	2893186	et	3	main
tore	doc_802069853782_item	2893187	et	3	main
aga	doc_802069853782_item	2893188	et	3	main
toimub	doc_802069853782_item	2893189	et	3	main
väga	doc_802069853782_item	2893212	et	3	main
oluline	doc_802069853782_item	2893213	et	4	main
asi	doc_802069853782_item	2893214	et	4	main
kurb	doc_802069853782_item	2893215	et	3	main
on	doc_802069853782_item	2893216	et	4	main
tõdeda	doc_802069853782_item	2893217	et	3	main
aga	doc_802069853782_item	2893218	et	3	main
tõsi	doc_802069853782_item	2893219	et	4	main
et	doc_802069853782_item	2893220	et	3	main
mina	doc_802069853782_item	2893222	et	4	main
võiks	doc_802069853782_item	2893227	et	4	main
eksmatrikuleerida	doc_802069853782_item	2893228	et	3	main
veel	doc_802069853782_item	2893229	et	4	main
ootan	doc_802069853782_item	2893230	et	3	main
häid	doc_802069853782_item	2893231	et	3	main
kõik	doc_802069853782_item	2893245	et	4	main
üks	doc_802069853782_item	2893247	et	3	main
armastust	doc_802069853782_item	2893255	et	4	main
mind	doc_802069853782_item	2893270	et	4	main
edasi	doc_802069853782_item	2893271	et	3	main
väga	doc_802069853782_item	2893291	et	3	main
me	doc_802069853782_item	2893294	et	4	main
jätame	doc_802069853782_item	2893295	et	3	main
meelde	doc_802069853782_item	2893296	et	3	main
seda	doc_802069853782_item	2893297	et	3	main
essee	doc_802069853783_item	2893298	et	4	main
väga	doc_802069853783_item	2893321	et	3	main
küsimused	doc_802069853783_item	2893323	et	4	main
et	doc_802069853783_item	2893325	et	3	main
palju	doc_802069853783_item	2893329	et	4	main
aga	doc_802069853783_item	2893330	et	3	main
juhtus	doc_802069853783_item	2893336	et	3	main
ja	doc_802069853783_item	2893342	et	3	main
töötada	doc_802069853783_item	2893358	et	3	main
ju	doc_802069853783_item	2893373	et	3	main
ma	doc_802069853783_item	2893379	et	3	main
olema	doc_802069853783_item	2893391	et	4	main
väga	doc_802069853783_item	2893393	et	3	main
pidustada	doc_802069853783_item	2893399	et	4	main
ma	doc_802069853783_item	2893402	et	3	main
tea	doc_802069853783_item	2893405	et	4	main
on	doc_802069853783_item	2893416	et	4	main
vaja	doc_802069853783_item	2893417	et	4	main
kõigepealt	doc_802069853783_item	2893418	et	3	main
teine	doc_802069853783_item	2893419	et	3	main
või	doc_802069853783_item	2893422	et	4	main
lihtsalt	doc_802069853783_item	2893423	et	4	main
jaada	doc_802069853783_item	2893424	et	4	main
kõige	doc_802069853783_item	2893430	et	4	main
ma	doc_802069853784_item	2893443	et	3	main
kõik	doc_802069853784_item	2893445	et	4	main
sooritama	doc_802069853784_item	2893447	et	3	main
aga	doc_802069853784_item	2893448	et	3	main
on	doc_802069853784_item	2893450	et	4	main
krooni	doc_802069853784_item	2893467	et	4	main
mull	doc_802069853784_item	2893468	et	3	main
ei	doc_802069853784_item	2893480	et	4	main
on	doc_802069853784_item	2893488	et	4	main
väga	doc_802069853782_item	2893191	et	3	main
tea	doc_802069853782_item	2893200	et	4	main
näiteks	doc_802069853782_item	2893201	et	4	main
sest	doc_802069853782_item	2893209	et	4	main
sooritan	doc_802069853782_item	2893224	et	3	main
mind	doc_802069853782_item	2893226	et	4	main
see	doc_802069853782_item	2893234	et	3	main
muidugi	doc_802069853782_item	2893240	et	4	main
palju	doc_802069853782_item	2893241	et	4	main
inimesed	doc_802069853782_item	2893246	et	3	main
ka	doc_802069853782_item	2893253	et	3	main
see	doc_802069853782_item	2893257	et	3	main
ja	doc_802069853782_item	2893260	et	3	main
tähtis	doc_802069853782_item	2893272	et	4	main
ka	doc_802069853782_item	2893273	et	3	main
see	doc_802069853782_item	2893274	et	3	main
et	doc_802069853782_item	2893275	et	3	main
pidu	doc_802069853782_item	2893289	et	4	main
ma	doc_802069853783_item	2893300	et	3	main
ootan	doc_802069853783_item	2893301	et	3	main
uuelt	doc_802069853783_item	2893302	et	4	main
aastalt	doc_802069853783_item	2893303	et	3	main
varsti	doc_802069853783_item	2893304	et	3	main
on	doc_802069853783_item	2893305	et	4	main
2007	doc_802069853783_item	2893306	et	2	main
aast	doc_802069853783_item	2893307	et	4	main
mida	doc_802069853783_item	2893308	et	4	main
ma	doc_802069853783_item	2893309	et	3	main
ootan	doc_802069853783_item	2893310	et	3	main
mida	doc_802069853783_item	2893311	et	4	main
tahan	doc_802069853783_item	2893312	et	3	main
vaadata	doc_802069853783_item	2893313	et	4	main
sellel	doc_802069853783_item	2893314	et	4	main
ma	doc_802069853783_item	2893316	et	3	main
aastal	doc_802069853783_item	2893315	et	3	main
mõtlen	doc_802069853783_item	2893317	et	3	main
et	doc_802069853783_item	2893318	et	3	main
need	doc_802069853783_item	2893319	et	3	main
on	doc_802069853783_item	2893320	et	4	main
kõik	doc_802069853783_item	2893332	et	4	main
hakkab	doc_802069853783_item	2893333	et	3	main
tulema	doc_802069853783_item	2893334	et	4	main
tahan	doc_802069853783_item	2893339	et	3	main
edasi	doc_802069853783_item	2893340	et	3	main
palju	doc_802069853783_item	2893348	et	4	main
töötada	doc_802069853783_item	2893349	et	3	main
ennast	doc_802069853783_item	2893350	et	4	main
veel	doc_802069853783_item	2893351	et	4	main
hea	doc_802069853783_item	2893353	et	4	main
tööd	doc_802069853783_item	2893354	et	4	main
leida	doc_802069853783_item	2893355	et	3	main
ma	doc_802069853783_item	2893356	et	3	main
seotud	doc_802069853783_item	2893363	et	4	main
loodan	doc_802069853783_item	2893366	et	3	main
kui	doc_802069853783_item	2893375	et	3	main
uuel	doc_802069853783_item	2893377	et	3	main
hakkan	doc_802069853783_item	2893380	et	3	main
mul	doc_802069853783_item	2893384	et	3	main
sünnipäev	doc_802069853783_item	2893386	et	3	main
mul	doc_802069853783_item	2893387	et	3	main
hakkab	doc_802069853783_item	2893388	et	3	main
kakskümmend	doc_802069853783_item	2893389	et	4	main
aastat	doc_802069853783_item	2893390	et	3	main
see	doc_802069853783_item	2893395	et	3	main
kõige	doc_802069853783_item	2893397	et	4	main
aga	doc_802069853783_item	2893400	et	3	main
mõtelda	doc_802069853783_item	2893413	et	4	main
uuel	doc_802069853783_item	2893414	et	3	main
essee	doc_802069853784_item	2893433	et	4	main
veel	doc_802069853784_item	2893451	et	4	main
näideks	doc_802069853784_item	2893454	et	3	main
ma	doc_802069853784_item	2893455	et	3	main
tuhat	doc_802069853784_item	2893466	et	4	main
palju	doc_802069853784_item	2893471	et	4	main
aga	doc_802069853784_item	2893473	et	3	main
ole	doc_802069853784_item	2893481	et	4	main
ebausklik	doc_802069853784_item	2893482	et	3	main
essee	doc_802069853787_item	2893729	et	4	main
minu	doc_802069853787_item	2893730	et	3	main
uusaastasoovid	doc_802069853787_item	2893731	et	3	main
meie	doc_802069853787_item	2893732	et	4	main
väikesel	doc_802069853787_item	2893733	et	4	main
ma	doc_802069853787_item	2893739	et	3	main
lähedal	doc_802069853787_item	2893747	et	4	main
koht	doc_802069853787_item	2893749	et	3	main
aga	doc_802069853787_item	2893760	et	3	main
kaunis	doc_802069853787_item	2893788	et	4	main
park	doc_802069853787_item	2893789	et	3	main
pärnad	doc_802069853787_item	2893793	et	3	main
kuused	doc_802069853787_item	2893797	et	4	main
tumeroheline	doc_802069853787_item	2893802	et	4	main
mets	doc_802069853787_item	2893803	et	3	main
sõita	doc_802069853787_item	2893812	et	3	main
ja	doc_802069853787_item	2893825	et	3	main
puud	doc_802069853787_item	2893827	et	4	main
millal	doc_802069853787_item	2893841	et	3	main
essee	doc_802069853788_item	2893849	et	4	main
meelde	doc_802069853788_item	2893864	et	3	main
on	doc_802069853788_item	2893865	et	4	main
kas	doc_802069853788_item	2893866	et	3	main
aga	doc_802069853788_item	2893879	et	3	main
tahan	doc_802069853783_item	2893394	et	3	main
tähtsam	doc_802069853783_item	2893431	et	4	main
uusaastasoovid	doc_802069853784_item	2893435	et	3	main
kõige	doc_802069853784_item	2893437	et	4	main
uues	doc_802069853784_item	2893440	et	3	main
eksamid	doc_802069853784_item	2893446	et	3	main
leija	doc_802069853784_item	2893457	et	4	main
mitte	doc_802069853784_item	2893462	et	3	main
viisteist	doc_802069853784_item	2893465	et	4	main
nendes	doc_802069853784_item	2893477	et	4	main
kirjutada	doc_802069853784_item	2893478	et	3	main
ma	doc_802069853784_item	2893479	et	3	main
pärast	doc_802069853784_item	2893485	et	4	main
et	doc_802069853784_item	2893486	et	3	main
see	doc_802069853784_item	2893487	et	3	main
on	doc_802069853784_item	2893461	et	4	main
on	doc_802069853784_item	2893469	et	4	main
soovid	doc_802069853784_item	2893472	et	4	main
ei	doc_802069853784_item	2893475	et	4	main
taha	doc_802069853784_item	2893476	et	4	main
ainult	doc_802069853784_item	2893483	et	4	main
selle	doc_802069853784_item	2893484	et	4	main
on	doc_802069853787_item	2893735	et	4	main
püha	doc_802069853787_item	2893742	et	4	main
asub	doc_802069853787_item	2893750	et	3	main
kus	doc_802069853787_item	2893790	et	3	main
ja	doc_802069853787_item	2893796	et	3	main
pool	doc_802069853787_item	2893799	et	4	main
ja	doc_802069853787_item	2893801	et	3	main
suvel	doc_802069853787_item	2893804	et	3	main
seal	doc_802069853787_item	2893805	et	4	main
oli	doc_802069853787_item	2893806	et	3	main
tore	doc_802069853787_item	2893807	et	3	main
või	doc_802069853787_item	2893813	et	4	main
püüda	doc_802069853787_item	2893815	et	3	main
talvel	doc_802069853787_item	2893817	et	4	main
peab	doc_802069853787_item	2893819	et	4	main
olema	doc_802069853787_item	2893820	et	4	main
isiklik	doc_802069853784_item	2893489	et	3	main
eestimaal	doc_802069853787_item	2893734	et	4	main
sõita	doc_802069853787_item	2893741	et	3	main
järves	doc_802069853787_item	2893743	et	4	main
mis	doc_802069853787_item	2893744	et	4	main
asub	doc_802069853787_item	2893745	et	3	main
keskel	doc_802069853787_item	2893753	et	3	main
mina	doc_802069853787_item	2893756	et	4	main
pool	doc_802069853787_item	2893786	et	4	main
on	doc_802069853787_item	2893787	et	4	main
kasvavad	doc_802069853787_item	2893791	et	4	main
männid	doc_802069853787_item	2893795	et	3	main
puhata	doc_802069853787_item	2893808	et	4	main
päevitada	doc_802069853787_item	2893809	et	3	main
ujuda	doc_802069853787_item	2893810	et	3	main
aga	doc_802069853787_item	2893816	et	3	main
seal	doc_802069853787_item	2893818	et	4	main
lund	doc_802069853787_item	2893822	et	3	main
vara	doc_802069853787_item	2893832	et	4	main
sest	doc_802069853787_item	2893835	et	4	main
ma	doc_802069853787_item	2893839	et	3	main
katab	doc_802069853787_item	2893843	et	3	main
lumesõjat	doc_802069853787_item	2893848	et	4	main
ma	doc_802069853788_item	2893851	et	3	main
aastal	doc_802069853788_item	2893856	et	3	main
tuli	doc_802069853788_item	2893863	et	4	main
heaid	doc_802069853788_item	2893877	et	4	main
mul	doc_802069853788_item	2893886	et	3	main
on	doc_802069853788_item	2893892	et	4	main
vajavad	doc_802069853788_item	2893894	et	4	main
palju	doc_802069853788_item	2893895	et	4	main
teadusi	doc_802069853788_item	2893896	et	3	main
teine	doc_802069853788_item	2893897	et	3	main
eest	doc_802069853788_item	2893907	et	4	main
aastal	doc_802069853788_item	2893917	et	3	main
otepää	doc_802069853787_item	2893746	et	4	main
aastal	doc_802069853787_item	2893755	et	3	main
olin	doc_802069853787_item	2893758	et	3	main
see	doc_802069853787_item	2893761	et	3	main
suvel	doc_802069853787_item	2893763	et	3	main
siis	doc_802069853787_item	2893764	et	3	main
ma	doc_802069853787_item	2893765	et	3	main
tahan	doc_802069853787_item	2893766	et	3	main
sõita	doc_802069853787_item	2893767	et	3	main
talvel	doc_802069853787_item	2893768	et	4	main
minu	doc_802069853787_item	2893769	et	3	main
arvates	doc_802069853787_item	2893770	et	4	main
talvel	doc_802069853787_item	2893771	et	4	main
peab	doc_802069853787_item	2893772	et	4	main
olema	doc_802069853787_item	2893773	et	4	main
parim	doc_802069853787_item	2893774	et	4	main
kui	doc_802069853787_item	2893775	et	3	main
suvel	doc_802069853787_item	2893776	et	3	main
sest	doc_802069853787_item	2893777	et	4	main
lemmik	doc_802069853787_item	2893779	et	3	main
minu	doc_802069853787_item	2893778	et	3	main
aasta	doc_802069853787_item	2893780	et	4	main
aeg	doc_802069853787_item	2893781	et	3	main
on	doc_802069853787_item	2893782	et	4	main
talv	doc_802069853787_item	2893783	et	3	main
palju	doc_802069853787_item	2893736	et	4	main
kauneid	doc_802069853787_item	2893737	et	3	main
kohti	doc_802069853787_item	2893738	et	4	main
tahan	doc_802069853787_item	2893740	et	3	main
see	doc_802069853787_item	2893748	et	3	main
maalilise	doc_802069853787_item	2893751	et	4	main
looduse	doc_802069853787_item	2893752	et	4	main
eelmisel	doc_802069853787_item	2893754	et	3	main
juba	doc_802069853787_item	2893757	et	3	main
seal	doc_802069853787_item	2893759	et	4	main
oli	doc_802069853787_item	2893762	et	3	main
seal	doc_802069853787_item	2893784	et	4	main
ühel	doc_802069853787_item	2893785	et	3	main
tammed	doc_802069853787_item	2893794	et	3	main
teisel	doc_802069853787_item	2893798	et	4	main
mäed	doc_802069853787_item	2893800	et	3	main
see	doc_802069853787_item	2893828	et	3	main
väga	doc_802069853787_item	2893829	et	3	main
vara	doc_802069853787_item	2893836	et	4	main
läheb	doc_802069853787_item	2893837	et	3	main
maad	doc_802069853787_item	2893844	et	4	main
mida	doc_802069853788_item	2893850	et	4	main
aastalt	doc_802069853788_item	2893854	et	3	main
võibolla	doc_802069853788_item	2893857	et	4	main
muutusi	doc_802069853788_item	2893859	et	4	main
esimene	doc_802069853788_item	2893860	et	3	main
asi	doc_802069853788_item	2893861	et	4	main
mis	doc_802069853788_item	2893862	et	4	main
sain	doc_802069853788_item	2893868	et	3	main
hästi	doc_802069853788_item	2893870	et	3	main
või	doc_802069853788_item	2893872	et	4	main
mitte	doc_802069853788_item	2893873	et	3	main
muidugi	doc_802069853788_item	2893874	et	4	main
ootan	doc_802069853788_item	2893876	et	3	main
tulemusi	doc_802069853788_item	2893878	et	4	main
see	doc_802069853788_item	2893880	et	3	main
raske	doc_802069853788_item	2893883	et	4	main
et	doc_802069853788_item	2893885	et	3	main
eksamit	doc_802069853788_item	2893889	et	3	main
nad	doc_802069853788_item	2893891	et	3	main
asi	doc_802069853788_item	2893898	et	4	main
või	doc_802069853788_item	2893908	et	4	main
ma	doc_802069853788_item	2893909	et	3	main
iraakis	doc_802069853788_item	2893925	et	4	main
siri	doc_802069853788_item	2893949	et	4	main
ei	doc_802069853788_item	2893951	et	4	main
tee	doc_802069853788_item	2893952	et	4	main
mida	doc_802069853788_item	2893953	et	4	main
kahe	doc_802069853788_item	2893957	et	3	main
ootan	doc_802069853789_item	2893967	et	3	main
kristust	doc_802069853789_item	2893978	et	3	main
on	doc_802069853789_item	2893981	et	4	main
inimkond	doc_802069853789_item	2893982	et	3	main
aita	doc_802069853789_item	2893989	et	4	main
paljudest	doc_802069853789_item	2893992	et	3	main
eelkõige	doc_802069853789_item	2894002	et	3	main
sooviksin	doc_802069853789_item	2894004	et	3	main
see	doc_802069853789_item	2894007	et	3	main
ma	doc_802069853789_item	2894018	et	3	main
seitsmelt	doc_802069853789_item	2894022	et	3	main
plaanisid	doc_802069853789_item	2894026	et	4	main
minu	doc_802069853789_item	2894031	et	3	main
eesmärk	doc_802069853789_item	2894033	et	3	main
et	doc_802069853789_item	2894040	et	3	main
linnas	doc_802069853789_item	2894064	et	4	main
olen	doc_802069853789_item	2894065	et	3	main
mul	doc_802069853789_item	2894079	et	3	main
meie	doc_802069853789_item	2894109	et	4	main
tulevik	doc_802069853789_item	2894110	et	3	main
minu	doc_802069853789_item	2894111	et	3	main
pärast	doc_802069853790_item	2894119	et	4	main
kased	doc_802069853787_item	2893792	et	3	main
paadiga	doc_802069853787_item	2893811	et	3	main
kala	doc_802069853787_item	2893814	et	4	main
palju	doc_802069853787_item	2893821	et	4	main
kõrged	doc_802069853787_item	2893823	et	3	main
läheb	doc_802069853787_item	2893833	et	3	main
pimedaks	doc_802069853787_item	2893834	et	3	main
armastan	doc_802069853787_item	2893840	et	3	main
lumi	doc_802069853787_item	2893842	et	3	main
veel	doc_802069853787_item	2893845	et	4	main
mulle	doc_802069853787_item	2893846	et	4	main
meeldib	doc_802069853787_item	2893847	et	3	main
uuelt	doc_802069853788_item	2893853	et	4	main
ma	doc_802069853788_item	2893867	et	3	main
võib	doc_802069853788_item	2893881	et	3	main
olla	doc_802069853788_item	2893882	et	3	main
teha	doc_802069853788_item	2893884	et	3	main
on	doc_802069853788_item	2893887	et	4	main
ja	doc_802069853788_item	2893890	et	3	main
on	doc_802069853788_item	2893899	et	4	main
laptop	doc_802069853788_item	2893900	et	4	main
mille	doc_802069853788_item	2893901	et	3	main
ma	doc_802069853788_item	2893902	et	3	main
võin	doc_802069853788_item	2893903	et	3	main
saada	doc_802069853788_item	2893904	et	4	main
võin	doc_802069853788_item	2893910	et	3	main
seda	doc_802069853788_item	2893911	et	3	main
kauplusest	doc_802069853788_item	2893912	et	4	main
kui	doc_802069853788_item	2893923	et	3	main
on	doc_802069853788_item	2893926	et	4	main
et	doc_802069853788_item	2893928	et	3	main
targuks	doc_802069853788_item	2893931	et	3	main
saavad	doc_802069853788_item	2893932	et	4	main
ja	doc_802069853788_item	2893933	et	3	main
taha	doc_802069853788_item	2893941	et	4	main
et	doc_802069853788_item	2893942	et	3	main
uus	doc_802069853788_item	2893943	et	3	main
aasta	doc_802069853788_item	2893960	et	4	main
tulnud	doc_802069853788_item	2893962	et	4	main
veel	doc_802069853788_item	2893963	et	4	main
on	doc_802069853789_item	2893971	et	4	main
kahe	doc_802069853789_item	2893973	et	3	main
pärast	doc_802069853789_item	2893977	et	4	main
aastaks	doc_802069853789_item	2893980	et	4	main
tehnoloogiliselt	doc_802069853789_item	2893983	et	4	main
tugev	doc_802069853789_item	2893984	et	4	main
ei	doc_802069853789_item	2893988	et	4	main
konfliktid	doc_802069853789_item	2893996	et	3	main
teised	doc_802069853789_item	2894001	et	4	main
isiklikult	doc_802069853789_item	2894015	et	4	main
minu	doc_802069853789_item	2894016	et	3	main
jaoks	doc_802069853789_item	2894017	et	4	main
ootan	doc_802069853789_item	2894019	et	3	main
aastalt	doc_802069853789_item	2894023	et	3	main
praegu	doc_802069853789_item	2894029	et	3	main
loodan	doc_802069853789_item	2894039	et	3	main
viib	doc_802069853789_item	2894043	et	3	main
edu	doc_802069853789_item	2894045	et	4	main
hariduses	doc_802069853789_item	2894046	et	3	main
aasta	doc_802069853789_item	2894047	et	4	main
kaks	doc_802069853789_item	2894048	et	3	main
veendunud	doc_802069853789_item	2894066	et	4	main
et	doc_802069853789_item	2894067	et	3	main
juba	doc_802069853789_item	2894068	et	3	main
aastal	doc_802069853789_item	2894070	et	3	main
nimetada	doc_802069853789_item	2894073	et	3	main
kodulinnaks	doc_802069853789_item	2894077	et	3	main
ilmuvad	doc_802069853789_item	2894080	et	4	main
on	doc_802069853790_item	2894125	et	4	main
sellest	doc_802069853790_item	2894131	et	4	main
et	doc_802069853790_item	2894139	et	3	main
kõik	doc_802069853790_item	2894142	et	4	main
aasta	doc_802069853790_item	2894144	et	4	main
probleemid	doc_802069853790_item	2894145	et	3	main
jäi	doc_802069853790_item	2894146	et	3	main
taga	doc_802069853790_item	2894147	et	4	main
ja	doc_802069853790_item	2894148	et	3	main
aitaksid	doc_802069853790_item	2894162	et	4	main
jätkada	doc_802069853790_item	2894164	et	4	main
kõik	doc_802069853790_item	2894174	et	4	main
usu	doc_802069853791_item	2894188	et	4	main
ma	doc_802069853791_item	2894191	et	3	main
lumekanged	doc_802069853787_item	2893824	et	3	main
lummined	doc_802069853787_item	2893826	et	4	main
ilus	doc_802069853787_item	2893830	et	4	main
talvel	doc_802069853787_item	2893831	et	4	main
ilusam	doc_802069853787_item	2893838	et	4	main
ootan	doc_802069853788_item	2893852	et	3	main
uuel	doc_802069853788_item	2893855	et	3	main
palju	doc_802069853788_item	2893858	et	4	main
eksamid	doc_802069853788_item	2893869	et	3	main
teha	doc_802069853788_item	2893871	et	3	main
ma	doc_802069853788_item	2893875	et	3	main
kõik	doc_802069853788_item	2893893	et	4	main
tulemuste	doc_802069853788_item	2893906	et	4	main
uuel	doc_802069853788_item	2893916	et	3	main
ole	doc_802069853788_item	2893919	et	4	main
uut	doc_802069853788_item	2893920	et	3	main
konflikte	doc_802069853788_item	2893921	et	3	main
praegu	doc_802069853788_item	2893924	et	3	main
kõik	doc_802069853788_item	2893936	et	4	main
saavad	doc_802069853788_item	2893937	et	4	main
sõbralikuks	doc_802069853788_item	2893938	et	3	main
ma	doc_802069853788_item	2893939	et	3	main
ei	doc_802069853788_item	2893940	et	4	main
maha	doc_802069853788_item	2893946	et	4	main
öelda	doc_802069853788_item	2893955	et	4	main
kaheksanda	doc_802069853788_item	2893959	et	3	main
ei	doc_802069853788_item	2893961	et	4	main
aastalt	doc_802069853789_item	2893968	et	3	main
arenenud	doc_802069853789_item	2893985	et	4	main
seda	doc_802069853789_item	2893990	et	3	main
probleemidest	doc_802069853789_item	2893993	et	3	main
erinevad	doc_802069853789_item	2893997	et	4	main
katastroofid	doc_802069853789_item	2893998	et	3	main
ja	doc_802069853789_item	2893999	et	3	main
mina	doc_802069853789_item	2894003	et	4	main
inimkonnale	doc_802069853789_item	2894005	et	4	main
aasta	doc_802069853789_item	2894008	et	4	main
oleks	doc_802069853789_item	2894009	et	3	main
rahulikum	doc_802069853789_item	2894010	et	4	main
ja	doc_802069853789_item	2894011	et	3	main
kahe	doc_802069853789_item	2894020	et	3	main
oma	doc_802069853789_item	2894025	et	4	main
õppimises	doc_802069853789_item	2894037	et	4	main
tuhat	doc_802069853789_item	2894049	et	4	main
seitse	doc_802069853789_item	2894050	et	3	main
kodu	doc_802069853789_item	2894058	et	4	main
sellel	doc_802069853789_item	2894069	et	4	main
ma	doc_802069853789_item	2894071	et	3	main
tallinn	doc_802069853789_item	2894074	et	4	main
oma	doc_802069853789_item	2894075	et	4	main
kus	doc_802069853789_item	2894078	et	3	main
kuid	doc_802069853789_item	2894108	et	4	main
meilt	doc_802069853789_item	2894115	et	3	main
essee	doc_802069853790_item	2894116	et	4	main
minu	doc_802069853790_item	2894117	et	3	main
ilusat	doc_802069853790_item	2894134	et	3	main
ja	doc_802069853790_item	2894135	et	3	main
soovin	doc_802069853790_item	2894138	et	3	main
uuega	doc_802069853790_item	2894154	et	3	main
ma	doc_802069853790_item	2894156	et	3	main
uskun	doc_802069853790_item	2894157	et	4	main
et	doc_802069853790_item	2894158	et	3	main
mulle	doc_802069853790_item	2894163	et	4	main
ttüs	doc_802069853790_item	2894166	et	4	main
ma	doc_802069853790_item	2894168	et	3	main
elad	doc_802069853790_item	2894170	et	3	main
aitah	doc_802069853790_item	2894175	et	4	main
jõuluvanaisale	doc_802069853791_item	2894189	et	3	main
ei	doc_802069853791_item	2894192	et	4	main
kirjutama	doc_802069853791_item	2894194	et	3	main
inimesed	doc_802069853791_item	2894205	et	3	main
ei	doc_802069853791_item	2894206	et	4	main
geomeetriaga	doc_802069853791_item	2894221	et	3	main
füüsikaga	doc_802069853791_item	2894223	et	3	main
tehe	doc_802069853791_item	2894227	et	3	main
minu	doc_802069853791_item	2894237	et	3	main
ma	doc_802069853791_item	2894242	et	3	main
pole	doc_802069853791_item	2894245	et	3	main
me	doc_802069853791_item	2894254	et	4	main
praegu	doc_802069853791_item	2894257	et	3	main
on	doc_802069853791_item	2894259	et	4	main
neli	doc_802069853788_item	2893888	et	3	main
hea	doc_802069853788_item	2893905	et	4	main
oosta	doc_802069853788_item	2893913	et	4	main
ootan	doc_802069853788_item	2893914	et	3	main
et	doc_802069853788_item	2893915	et	3	main
ei	doc_802069853788_item	2893918	et	4	main
kõik	doc_802069853788_item	2893929	et	4	main
kogu	doc_802069853788_item	2893934	et	4	main
maaimas	doc_802069853788_item	2893935	et	3	main
ja	doc_802069853788_item	2893947	et	3	main
veel	doc_802069853788_item	2893954	et	4	main
essee	doc_802069853789_item	2893964	et	4	main
seitse	doc_802069853789_item	2893970	et	3	main
seitsmes	doc_802069853789_item	2893975	et	4	main
aasta	doc_802069853789_item	2893976	et	4	main
selleks	doc_802069853789_item	2893979	et	4	main
kuid	doc_802069853789_item	2893986	et	4	main
see	doc_802069853789_item	2893987	et	3	main
näiteks	doc_802069853789_item	2893994	et	4	main
õnnelikum	doc_802069853789_item	2894012	et	4	main
kui	doc_802069853789_item	2894013	et	3	main
eelmised	doc_802069853789_item	2894014	et	3	main
nii	doc_802069853788_item	2893922	et	3	main
ootan	doc_802069853788_item	2893927	et	3	main
poliitikud	doc_802069853788_item	2893930	et	3	main
sõdu	doc_802069853788_item	2893944	et	3	main
tuli	doc_802069853788_item	2893945	et	4	main
inimesed	doc_802069853788_item	2893948	et	3	main
ma	doc_802069853788_item	2893950	et	3	main
sellepärast	doc_802069853788_item	2893956	et	3	main
tuhande	doc_802069853788_item	2893958	et	3	main
mida	doc_802069853789_item	2893965	et	4	main
ma	doc_802069853789_item	2893966	et	3	main
kakstuhat	doc_802069853789_item	2893969	et	4	main
alanud	doc_802069853789_item	2893972	et	4	main
tuhande	doc_802069853789_item	2893974	et	3	main
vältida	doc_802069853789_item	2893991	et	3	main
sõjad	doc_802069853789_item	2893995	et	3	main
paljud	doc_802069853789_item	2894000	et	3	main
et	doc_802069853789_item	2894006	et	3	main
tuhande	doc_802069853789_item	2894021	et	3	main
elusse	doc_802069853789_item	2894027	et	3	main
on	doc_802069853789_item	2894034	et	4	main
heade	doc_802069853789_item	2894035	et	3	main
tulemuste	doc_802069853789_item	2894036	et	4	main
see	doc_802069853789_item	2894041	et	3	main
on	doc_802069853789_item	2894051	et	4	main
esimene	doc_802069853789_item	2894052	et	3	main
aasta	doc_802069853789_item	2894053	et	4	main
kaugemal	doc_802069853789_item	2894059	et	4	main
võrras	doc_802069853789_item	2894061	et	4	main
teiseks	doc_802069853789_item	2894076	et	4	main
arvates	doc_802069853789_item	2894112	et	4	main
uus-aastassoovid	doc_802069853790_item	2894118	et	4	main
kuu	doc_802069853790_item	2894121	et	4	main
ja	doc_802069853790_item	2894123	et	3	main
maailmas	doc_802069853790_item	2894124	et	3	main
uus-aasta	doc_802069853790_item	2894126	et	4	main
peost	doc_802069853790_item	2894132	et	4	main
uus	doc_802069853790_item	2894149	et	3	main
minu	doc_802069853790_item	2894159	et	3	main
ülikooli	doc_802069853790_item	2894160	et	4	main
tulemused	doc_802069853790_item	2894161	et	3	main
essee	doc_802069853791_item	2894176	et	4	main
aastal	doc_802069853791_item	2894180	et	3	main
pidasin	doc_802069853791_item	2894182	et	3	main
kahekümnes	doc_802069853791_item	2894184	et	4	main
sünniaeg	doc_802069853791_item	2894185	et	3	main
ei	doc_802069853791_item	2894187	et	4	main
sest	doc_802069853791_item	2894190	et	4	main
alga	doc_802069853791_item	2894193	et	4	main
oma	doc_802069853791_item	2894202	et	4	main
reaalsus	doc_802069853791_item	2894204	et	4	main
ole	doc_802069853791_item	2894207	et	4	main
sest	doc_802069853791_item	2894209	et	4	main
minu	doc_802069853791_item	2894210	et	3	main
ma	doc_802069853791_item	2894225	et	3	main
proovin	doc_802069853791_item	2894226	et	3	main
võimalik	doc_802069853791_item	2894229	et	3	main
mul	doc_802069853791_item	2894231	et	3	main
võimalus	doc_802069853791_item	2894233	et	3	main
minna	doc_802069853791_item	2894234	et	3	main
raske	doc_802069853791_item	2894252	et	4	main
kõik	doc_802069853791_item	2894253	et	4	main
väga	doc_802069853791_item	2894290	et	3	main
sõida	doc_802069853791_item	2894295	et	4	main
kus	doc_802069853791_item	2894297	et	3	main
õpeb	doc_802069853791_item	2894298	et	4	main
minu	doc_802069853791_item	2894299	et	3	main
inimesed	doc_802069853791_item	2894310	et	3	main
aga	doc_802069853791_item	2894317	et	3	main
ma	doc_802069853791_item	2894324	et	3	main
on	doc_802069853791_item	2894331	et	4	main
üks	doc_802069853791_item	2894332	et	3	main
problem	doc_802069853791_item	2894333	et	4	main
kodanik	doc_802069853791_item	2894338	et	3	main
ja	doc_802069853791_item	2894339	et	3	main
mul	doc_802069853791_item	2894340	et	3	main
kulutama	doc_802069853791_item	2894345	et	4	main
väga	doc_802069853791_item	2894353	et	3	main
teised	doc_802069853791_item	2894355	et	4	main
soovid	doc_802069853791_item	2894356	et	4	main
aga	doc_802069853791_item	2894357	et	3	main
või	doc_802069853791_item	2894362	et	4	main
elu	doc_802069853791_item	2894370	et	4	main
kõik	doc_802069853791_item	2894378	et	4	main
ola	doc_802069853791_item	2894382	et	4	main
kasulik	doc_802069853791_item	2894383	et	3	main
uusaastasoovid	doc_802069853792_item	2894387	et	3	main
võimalust	doc_802069853789_item	2894024	et	3	main
viia	doc_802069853789_item	2894028	et	3	main
on	doc_802069853789_item	2894030	et	4	main
tähtsaim	doc_802069853789_item	2894032	et	4	main
saavutamine	doc_802069853789_item	2894038	et	4	main
aasta	doc_802069853789_item	2894042	et	4	main
mulle	doc_802069853789_item	2894044	et	4	main
millal	doc_802069853789_item	2894054	et	3	main
ma	doc_802069853789_item	2894055	et	3	main
elan	doc_802069853789_item	2894056	et	3	main
oma	doc_802069853789_item	2894057	et	4	main
veel	doc_802069853789_item	2894060	et	4	main
minu	doc_802069853789_item	2894062	et	3	main
jaoks	doc_802069853789_item	2894063	et	4	main
võin	doc_802069853789_item	2894072	et	3	main
palju	doc_802069853789_item	2894081	et	4	main
sõpru	doc_802069853789_item	2894082	et	3	main
ja	doc_802069853789_item	2894083	et	3	main
tuttavaid	doc_802069853789_item	2894084	et	3	main
lemmikkohti	doc_802069853789_item	2894085	et	4	main
loodan	doc_802069853789_item	2894086	et	3	main
et	doc_802069853789_item	2894087	et	3	main
kahetuhande	doc_802069853789_item	2894088	et	4	main
seitsme	doc_802069853789_item	2894089	et	3	main
aasta	doc_802069853789_item	2894090	et	4	main
lõppus	doc_802069853789_item	2894091	et	4	main
ma	doc_802069853789_item	2894092	et	3	main
saan	doc_802069853789_item	2894093	et	4	main
öelda	doc_802069853789_item	2894094	et	4	main
et	doc_802069853789_item	2894095	et	3	main
see	doc_802069853789_item	2894096	et	3	main
aeg	doc_802069853789_item	2894097	et	3	main
on	doc_802069853789_item	2894098	et	4	main
nii	doc_802069853789_item	2894099	et	3	main
möödunud	doc_802069853789_item	2894100	et	4	main
nagu	doc_802069853789_item	2894101	et	3	main
ma	doc_802069853789_item	2894102	et	3	main
olen	doc_802069853789_item	2894103	et	3	main
võib-olla	doc_802069853789_item	2894105	et	3	main
plaaneerinud	doc_802069853789_item	2894104	et	4	main
isegi	doc_802069853789_item	2894106	et	4	main
parem	doc_802069853789_item	2894107	et	4	main
sõltub	doc_802069853789_item	2894113	et	3	main
ainult	doc_802069853789_item	2894114	et	4	main
ühe	doc_802069853790_item	2894120	et	4	main
pidu	doc_802069853790_item	2894127	et	4	main
ja	doc_802069853790_item	2894128	et	3	main
kõik	doc_802069853790_item	2894129	et	4	main
midagi	doc_802069853790_item	2894133	et	4	main
jargmiseks	doc_802069853790_item	2894140	et	4	main
seitsmene	doc_802069853790_item	2894151	et	4	main
algas	doc_802069853790_item	2894153	et	3	main
lehege	doc_802069853790_item	2894155	et	4	main
ma	doc_802069853790_item	2894172	et	3	main
minu	doc_802069853791_item	2894177	et	3	main
ma	doc_802069853791_item	2894181	et	3	main
oma	doc_802069853791_item	2894183	et	4	main
ma	doc_802069853791_item	2894186	et	3	main
teha	doc_802069853791_item	2894201	et	3	main
soovid	doc_802069853791_item	2894203	et	4	main
ja	doc_802069853791_item	2894224	et	3	main
esimene	doc_802069853791_item	2894236	et	3	main
on	doc_802069853791_item	2894239	et	4	main
eksamid	doc_802069853791_item	2894241	et	3	main
et	doc_802069853791_item	2894244	et	3	main
raha	doc_802069853791_item	2894261	et	4	main
on	doc_802069853791_item	2894289	et	4	main
tahan	doc_802069853791_item	2894294	et	3	main
parem	doc_802069853791_item	2894300	et	4	main
sõber	doc_802069853791_item	2894301	et	3	main
ja	doc_802069853791_item	2894302	et	3	main
elab	doc_802069853791_item	2894303	et	3	main
teine	doc_802069853791_item	2894304	et	3	main
sõber	doc_802069853791_item	2894305	et	3	main
nad	doc_802069853791_item	2894306	et	3	main
ma	doc_802069853791_item	2894311	et	3	main
kirjutada	doc_802069853791_item	2894313	et	3	main
mul	doc_802069853791_item	2894318	et	3	main
kirjutada	doc_802069853791_item	2894320	et	3	main
palju	doc_802069853791_item	2894322	et	4	main
ja	doc_802069853791_item	2894323	et	3	main
ei	doc_802069853791_item	2894325	et	4	main
näe	doc_802069853791_item	2894326	et	4	main
nende	doc_802069853791_item	2894327	et	4	main
on	doc_802069853791_item	2894335	et	4	main
raha	doc_802069853791_item	2894344	et	4	main
jt	doc_802069853791_item	2894349	et	4	main
mul	doc_802069853791_item	2894351	et	3	main
rumalad	doc_802069853791_item	2894363	et	3	main
võib	doc_802069853791_item	2894381	et	3	main
essee	doc_802069853792_item	2894385	et	4	main
esimene	doc_802069853792_item	2894388	et	3	main
kõik	doc_802069853792_item	2894392	et	4	main
ülikoolis	doc_802069853792_item	2894394	et	4	main
saab	doc_802069853792_item	2894446	et	3	main
üheksas	doc_802069853792_item	2894448	et	4	main
tahan	doc_802069853792_item	2894449	et	3	main
korter	doc_802069853792_item	2894450	et	3	main
new	doc_802069853792_item	2894451	et	4	main
meil	doc_802069853790_item	2894122	et	4	main
ootavad	doc_802069853790_item	2894130	et	4	main
erilist	doc_802069853790_item	2894136	et	4	main
ma	doc_802069853790_item	2894137	et	3	main
aastas	doc_802069853790_item	2894141	et	3	main
selle	doc_802069853790_item	2894143	et	4	main
kahetuhande	doc_802069853790_item	2894150	et	4	main
aasta	doc_802069853790_item	2894152	et	4	main
õppimist	doc_802069853790_item	2894165	et	4	main
et	doc_802069853790_item	2894167	et	3	main
saaksin	doc_802069853790_item	2894169	et	3	main
kui	doc_802069853790_item	2894171	et	3	main
tahan	doc_802069853790_item	2894173	et	3	main
uusaastasoovid	doc_802069853791_item	2894178	et	3	main
sellel	doc_802069853791_item	2894179	et	4	main
oma	doc_802069853791_item	2894195	et	4	main
soovid	doc_802069853791_item	2894196	et	4	main
temale	doc_802069853791_item	2894197	et	3	main
ainult	doc_802069853791_item	2894198	et	4	main
ma	doc_802069853791_item	2894199	et	3	main
soovid	doc_802069853791_item	2894211	et	4	main
ei	doc_802069853791_item	2894212	et	4	main
ole	doc_802069853791_item	2894213	et	4	main
ebarealse	doc_802069853791_item	2894214	et	4	main
praegu	doc_802069853791_item	2894215	et	3	main
mul	doc_802069853791_item	2894216	et	3	main
väga	doc_802069853791_item	2894218	et	3	main
on	doc_802069853791_item	2894217	et	4	main
halb	doc_802069853791_item	2894219	et	3	main
kujutav	doc_802069853791_item	2894220	et	4	main
võin	doc_802069853791_item	2894200	et	3	main
võlured	doc_802069853791_item	2894208	et	4	main
kõik	doc_802069853791_item	2894228	et	4	main
oli	doc_802069853791_item	2894232	et	3	main
eksamile	doc_802069853791_item	2894235	et	3	main
sooritanud	doc_802069853791_item	2894240	et	4	main
arvan	doc_802069853791_item	2894243	et	3	main
mina	doc_802069853791_item	2894246	et	4	main
tahab	doc_802069853791_item	2894247	et	3	main
seda	doc_802069853791_item	2894248	et	3	main
ja	doc_802069853791_item	2894249	et	3	main
sest	doc_802069853791_item	2894250	et	4	main
tuleb	doc_802069853791_item	2894251	et	3	main
teame	doc_802069853791_item	2894255	et	3	main
summa	doc_802069853791_item	2894282	et	4	main
see	doc_802069853791_item	2894287	et	3	main
ka	doc_802069853791_item	2894292	et	3	main
venemaale	doc_802069853791_item	2894296	et	4	main
palju	doc_802069853791_item	2894314	et	4	main
tuleb	doc_802069853791_item	2894319	et	3	main
väga	doc_802069853791_item	2894321	et	3	main
erinevadele	doc_802069853791_item	2894346	et	4	main
on	doc_802069853791_item	2894352	et	4	main
palju	doc_802069853791_item	2894354	et	4	main
ebarealsed	doc_802069853791_item	2894361	et	4	main
ma	doc_802069853791_item	2894365	et	3	main
muutused	doc_802069853791_item	2894371	et	4	main
soovid	doc_802069853791_item	2894379	et	4	main
minu	doc_802069853792_item	2894386	et	3	main
sooritada	doc_802069853792_item	2894391	et	3	main
palk	doc_802069853792_item	2894427	et	3	main
viies	doc_802069853792_item	2894428	et	4	main
tahan	doc_802069853792_item	2894429	et	3	main
kuldroleks	doc_802069853792_item	2894430	et	4	main
et	doc_802069853792_item	2894437	et	3	main
j	doc_802069853792_item	2894453	et	4	main
jõulu	doc_802069853792_item	2894455	et	4	main
täitunud	doc_802069853792_item	2894457	et	4	main
soovid	doc_802069853792_item	2894458	et	4	main
et	doc_802069853794_item	2894564	et	3	main
selles	doc_802069853794_item	2894573	et	4	main
aastas	doc_802069853794_item	2894574	et	3	main
ma	doc_802069853794_item	2894575	et	3	main
õppin	doc_802069853794_item	2894576	et	4	main
ttü-s	doc_802069853794_item	2894577	et	3	main
ja	doc_802069853794_item	2894578	et	3	main
mull	doc_802069853794_item	2894584	et	3	main
ole	doc_802069853794_item	2894586	et	4	main
mõlkid	doc_802069853794_item	2894587	et	4	main
kõik	doc_802069853794_item	2894603	et	4	main
läheks	doc_802069853794_item	2894604	et	3	main
hästi	doc_802069853794_item	2894605	et	3	main
essee	doc_802069853796_item	2894725	et	4	main
kalis	doc_802069853796_item	2894728	et	3	main
miinu	doc_802069853796_item	2894730	et	4	main
eesti	doc_802069853796_item	2894740	et	4	main
keelis	doc_802069853796_item	2894741	et	3	main
ja	doc_802069853796_item	2894742	et	3	main
oleks	doc_802069853796_item	2894743	et	3	main
arvestus	doc_802069853796_item	2894745	et	4	main
veel	doc_802069853796_item	2894747	et	4	main
last	doc_802069853796_item	2894757	et	4	main
ootan	doc_802069853797_item	2894773	et	3	main
ja	doc_802069853791_item	2894222	et	3	main
sest	doc_802069853791_item	2894230	et	4	main
soov	doc_802069853791_item	2894238	et	3	main
et	doc_802069853791_item	2894256	et	3	main
maailmas	doc_802069853791_item	2894258	et	3	main
tähtseim	doc_802069853791_item	2894260	et	3	main
see	doc_802069853791_item	2894262	et	3	main
ole	doc_802069853791_item	2894264	et	4	main
minu	doc_802069853791_item	2894265	et	3	main
arvamus	doc_802069853791_item	2894266	et	3	main
teine	doc_802069853791_item	2894267	et	3	main
minu	doc_802069853791_item	2894268	et	3	main
soov	doc_802069853791_item	2894269	et	3	main
on	doc_802069853791_item	2894270	et	4	main
ei	doc_802069853791_item	2894263	et	4	main
see	doc_802069853791_item	2894271	et	3	main
et	doc_802069853791_item	2894272	et	3	main
mul	doc_802069853791_item	2894273	et	3	main
oli	doc_802069853791_item	2894274	et	3	main
stüpeendia	doc_802069853791_item	2894275	et	4	main
ülikoolis	doc_802069853791_item	2894276	et	4	main
see	doc_802069853791_item	2894277	et	3	main
ei	doc_802069853791_item	2894278	et	4	main
ole	doc_802069853791_item	2894279	et	4	main
väga	doc_802069853791_item	2894280	et	3	main
suur	doc_802069853791_item	2894281	et	3	main
aga	doc_802069853791_item	2894283	et	3	main
arvan	doc_802069853791_item	2894285	et	3	main
summa	doc_802069853791_item	2894288	et	4	main
kasulik	doc_802069853791_item	2894291	et	3	main
võin	doc_802069853791_item	2894312	et	3	main
positiivsed	doc_802069853791_item	2894315	et	3	main
ma	doc_802069853791_item	2894284	et	3	main
et	doc_802069853791_item	2894286	et	3	main
ma	doc_802069853791_item	2894293	et	3	main
on	doc_802069853791_item	2894307	et	4	main
väga	doc_802069853791_item	2894308	et	3	main
hea	doc_802069853791_item	2894309	et	4	main
omadussõnad	doc_802069853791_item	2894316	et	3	main
ammu	doc_802069853791_item	2894328	et	4	main
aga	doc_802069853791_item	2894329	et	3	main
sul	doc_802069853791_item	2894330	et	3	main
eesti	doc_802069853791_item	2894336	et	4	main
vabariigi	doc_802069853791_item	2894337	et	3	main
on	doc_802069853791_item	2894341	et	4	main
muidugi	doc_802069853791_item	2894350	et	4	main
ja	doc_802069853791_item	2894364	et	3	main
ei	doc_802069853791_item	2894366	et	4	main
kõik	doc_802069853791_item	2894368	et	4	main
jargmisel	doc_802069853791_item	2894372	et	4	main
aastal	doc_802069853791_item	2894373	et	3	main
ja	doc_802069853791_item	2894374	et	3	main
ei	doc_802069853791_item	2894375	et	4	main
millised	doc_802069853791_item	2894380	et	3	main
minule	doc_802069853791_item	2894384	et	3	main
tahan	doc_802069853792_item	2894390	et	3	main
sest	doc_802069853792_item	2894395	et	4	main
neljas	doc_802069853792_item	2894421	et	4	main
kuues	doc_802069853792_item	2894431	et	4	main
tahan	doc_802069853792_item	2894432	et	3	main
punane	doc_802069853792_item	2894433	et	4	main
diplom	doc_802069853792_item	2894434	et	3	main
mailmaas	doc_802069853792_item	2894438	et	4	main
ole	doc_802069853792_item	2894440	et	4	main
kaheksas	doc_802069853792_item	2894442	et	4	main
tahan	doc_802069853792_item	2894443	et	3	main
et	doc_802069853792_item	2894444	et	3	main
küttus	doc_802069853792_item	2894445	et	4	main
odavam	doc_802069853792_item	2894447	et	4	main
kallis	doc_802069853792_item	2894454	et	4	main
vana	doc_802069853792_item	2894456	et	4	main
ma	doc_802069853794_item	2894562	et	3	main
tulevik	doc_802069853794_item	2894565	et	3	main
on	doc_802069853794_item	2894568	et	4	main
parem	doc_802069853794_item	2894569	et	4	main
kui	doc_802069853794_item	2894570	et	3	main
ülikoolis	doc_802069853794_item	2894588	et	4	main
ma	doc_802069853794_item	2894589	et	3	main
soovin	doc_802069853794_item	2894590	et	3	main
kõigile	doc_802069853794_item	2894594	et	4	main
et	doc_802069853794_item	2894597	et	3	main
arvestused	doc_802069853794_item	2894599	et	4	main
oli	doc_802069853794_item	2894600	et	3	main
mina	doc_802069853791_item	2894334	et	4	main
vaja	doc_802069853791_item	2894342	et	4	main
palju	doc_802069853791_item	2894343	et	4	main
viisidele	doc_802069853791_item	2894347	et	3	main
regestratsionidele	doc_802069853791_item	2894348	et	4	main
neid	doc_802069853791_item	2894358	et	4	main
on	doc_802069853791_item	2894359	et	4	main
või	doc_802069853791_item	2894360	et	4	main
tea	doc_802069853791_item	2894367	et	4	main
oma	doc_802069853791_item	2894369	et	4	main
saa	doc_802069853791_item	2894376	et	4	main
teada	doc_802069853791_item	2894377	et	3	main
tahan	doc_802069853792_item	2894397	et	3	main
õpida	doc_802069853792_item	2894398	et	4	main
ülikoolis	doc_802069853792_item	2894399	et	4	main
edasi	doc_802069853792_item	2894400	et	3	main
teine	doc_802069853792_item	2894401	et	3	main
tahan	doc_802069853792_item	2894402	et	3	main
et	doc_802069853792_item	2894403	et	3	main
meies	doc_802069853792_item	2894404	et	4	main
ühislamuses	doc_802069853792_item	2894405	et	4	main
teeb	doc_802069853792_item	2894406	et	3	main
remont	doc_802069853792_item	2894407	et	3	main
ja	doc_802069853792_item	2894408	et	3	main
oleks	doc_802069853792_item	2894409	et	3	main
hea	doc_802069853792_item	2894410	et	4	main
et	doc_802069853792_item	2894411	et	3	main
igas	doc_802069853792_item	2894412	et	3	main
koruses	doc_802069853792_item	2894413	et	4	main
on	doc_802069853792_item	2894414	et	4	main
saun	doc_802069853792_item	2894415	et	3	main
kolmas	doc_802069853792_item	2894416	et	3	main
tahan	doc_802069853792_item	2894417	et	3	main
väga	doc_802069853792_item	2894418	et	3	main
ilus	doc_802069853792_item	2894419	et	4	main
auto	doc_802069853792_item	2894420	et	4	main
ma	doc_802069853792_item	2894389	et	3	main
eksameid	doc_802069853792_item	2894393	et	3	main
ma	doc_802069853792_item	2894396	et	3	main
tahan	doc_802069853792_item	2894422	et	3	main
suur	doc_802069853792_item	2894426	et	3	main
ei	doc_802069853792_item	2894439	et	4	main
sõda	doc_802069853792_item	2894441	et	4	main
jorkis	doc_802069853792_item	2894452	et	4	main
uusaastasoovid	doc_802069853794_item	2894561	et	3	main
sest	doc_802069853794_item	2894572	et	4	main
et	doc_802069853794_item	2894581	et	3	main
aastas	doc_802069853794_item	2894583	et	3	main
aastat	doc_802069853794_item	2894593	et	3	main
ma	doc_802069853794_item	2894595	et	3	main
hea	doc_802069853792_item	2894423	et	4	main
töökoht	doc_802069853792_item	2894424	et	3	main
ja	doc_802069853792_item	2894425	et	3	main
seitmes	doc_802069853792_item	2894435	et	4	main
tahan	doc_802069853792_item	2894436	et	3	main
j	doc_802069853792_item	2894459	et	4	main
uskun	doc_802069853794_item	2894563	et	4	main
uus	doc_802069853794_item	2894566	et	3	main
uskun	doc_802069853794_item	2894580	et	4	main
head	doc_802069853794_item	2894591	et	4	main
uus	doc_802069853794_item	2894592	et	3	main
las	doc_802069853794_item	2894606	et	4	main
soovid	doc_802069853794_item	2894608	et	4	main
miinu	doc_802069853796_item	2894726	et	4	main
uusaastasoovid	doc_802069853796_item	2894727	et	3	main
lihne	doc_802069853796_item	2894735	et	4	main
ma	doc_802069853796_item	2894736	et	3	main
unistus	doc_802069853796_item	2894755	et	4	main
ma	doc_802069853796_item	2894761	et	3	main
laheks	doc_802069853796_item	2894764	et	4	main
aga	doc_802069853796_item	2894766	et	3	main
arvestus	doc_802069853796_item	2894767	et	4	main
võib	doc_802069853796_item	2894768	et	3	main
aastas	doc_802069853797_item	2894787	et	3	main
essee	doc_802069853794_item	2894559	et	4	main
minu	doc_802069853794_item	2894560	et	3	main
aasta	doc_802069853794_item	2894567	et	4	main
möödunud	doc_802069853794_item	2894571	et	4	main
ma	doc_802069853794_item	2894579	et	3	main
tulevik	doc_802069853794_item	2894582	et	3	main
ei	doc_802069853794_item	2894585	et	4	main
tahan	doc_802069853794_item	2894596	et	3	main
kõik	doc_802069853794_item	2894598	et	4	main
sooritatud	doc_802069853794_item	2894601	et	4	main
ja	doc_802069853794_item	2894602	et	3	main
kõik	doc_802069853794_item	2894607	et	4	main
täituvad	doc_802069853794_item	2894609	et	4	main
j	doc_802069853794_item	2894610	et	4	main
soovid	doc_802069853796_item	2894732	et	4	main
väga	doc_802069853796_item	2894734	et	3	main
tahan	doc_802069853796_item	2894737	et	3	main
arvestus	doc_802069853796_item	2894739	et	4	main
ma	doc_802069853796_item	2894748	et	3	main
jõuluvana	doc_802069853796_item	2894751	et	4	main
õnnelikut	doc_802069853796_item	2894760	et	4	main
kõik	doc_802069853796_item	2894763	et	4	main
hasti	doc_802069853796_item	2894765	et	4	main
mida	doc_802069853797_item	2894771	et	4	main
ma	doc_802069853797_item	2894772	et	3	main
algab	doc_802069853797_item	2894779	et	3	main
veel	doc_802069853797_item	2894837	et	4	main
tahaks	doc_802069853797_item	2894842	et	3	main
puhata	doc_802069853797_item	2894844	et	4	main
vanaema	doc_802069853797_item	2894845	et	4	main
imiline	doc_802069853796_item	2894738	et	4	main
tore	doc_802069853796_item	2894744	et	3	main
maatanalüsis	doc_802069853796_item	2894746	et	4	main
tahan	doc_802069853796_item	2894749	et	3	main
sookoladi	doc_802069853796_item	2894750	et	4	main
on	doc_802069853796_item	2894753	et	4	main
samuti	doc_802069853796_item	2894756	et	3	main
kõik	doc_802069853796_item	2894758	et	4	main
oli	doc_802069853796_item	2894759	et	3	main
tenenda	doc_802069853796_item	2894769	et	4	main
kõik	doc_802069853797_item	2894785	et	4	main
aega	doc_802069853797_item	2894831	et	4	main
on	doc_802069853797_item	2894838	et	4	main
aastast	doc_802069853797_item	2894850	et	4	main
see	doc_802069853798_item	2894866	et	3	main
väga	doc_802069853798_item	2894870	et	3	main
sest	doc_802069853798_item	2894872	et	4	main
ülikoolis	doc_802069853798_item	2894880	et	4	main
ja	doc_802069853798_item	2894889	et	3	main
kõike	doc_802069853798_item	2894893	et	4	main
periood	doc_802069853798_item	2894898	et	3	main
on	doc_802069853798_item	2894906	et	4	main
ülikoolis	doc_802069853798_item	2894910	et	4	main
palja	doc_802069853798_item	2894912	et	3	main
siin	doc_802069853798_item	2894916	et	4	main
simmestri	doc_802069853798_item	2894933	et	4	main
veel	doc_802069853798_item	2894934	et	4	main
ma	doc_802069853798_item	2894935	et	3	main
tahaksin	doc_802069853798_item	2894936	et	3	main
leida	doc_802069853798_item	2894937	et	3	main
aastal	doc_802069853798_item	2894941	et	3	main
suurt	doc_802069853798_item	2894944	et	3	main
osa	doc_802069853798_item	2894945	et	4	main
kui	doc_802069853798_item	2894958	et	3	main
ma	doc_802069853798_item	2894959	et	3	main
mitte	doc_802069853798_item	2894987	et	3	main
õpitaja	doc_802069853796_item	2894729	et	4	main
uusaasta	doc_802069853796_item	2894731	et	4	main
on	doc_802069853796_item	2894733	et	4	main
see	doc_802069853796_item	2894752	et	3	main
lapse	doc_802069853796_item	2894754	et	4	main
tahan	doc_802069853796_item	2894762	et	3	main
essee	doc_802069853797_item	2894770	et	4	main
aasta	doc_802069853797_item	2894778	et	4	main
on	doc_802069853797_item	2894781	et	4	main
selles	doc_802069853797_item	2894786	et	4	main
on	doc_802069853797_item	2894788	et	4	main
hästi	doc_802069853797_item	2894789	et	3	main
on	doc_802069853797_item	2894790	et	4	main
küll	doc_802069853797_item	2894791	et	4	main
loodan	doc_802069853797_item	2894792	et	3	main
et	doc_802069853797_item	2894793	et	3	main
järgmine	doc_802069853797_item	2894794	et	3	main
aasta	doc_802069853797_item	2894795	et	4	main
on	doc_802069853797_item	2894796	et	4	main
parem	doc_802069853797_item	2894797	et	4	main
kui	doc_802069853797_item	2894798	et	3	main
eelmine	doc_802069853797_item	2894799	et	3	main
esiteks	doc_802069853797_item	2894800	et	3	main
tahaks	doc_802069853797_item	2894801	et	3	main
sooritada	doc_802069853797_item	2894802	et	3	main
eksami	doc_802069853797_item	2894804	et	3	main
ja	doc_802069853797_item	2894805	et	3	main
kõiki	doc_802069853797_item	2894803	et	4	main
saada	doc_802069853797_item	2894806	et	4	main
häid	doc_802069853797_item	2894807	et	3	main
tulemusi	doc_802069853797_item	2894808	et	4	main
õppimine	doc_802069853797_item	2894809	et	4	main
on	doc_802069853797_item	2894810	et	4	main
väga	doc_802069853797_item	2894811	et	3	main
tähtis	doc_802069853797_item	2894812	et	4	main
ja	doc_802069853797_item	2894813	et	3	main
kõigepealt	doc_802069853797_item	2894814	et	3	main
tahaks	doc_802069853797_item	2894815	et	3	main
et	doc_802069853797_item	2894816	et	3	main
õpe	doc_802069853797_item	2894817	et	3	main
on	doc_802069853797_item	2894818	et	4	main
kergem	doc_802069853797_item	2894819	et	4	main
veel	doc_802069853797_item	2894820	et	4	main
tahan	doc_802069853797_item	2894821	et	3	main
uus	doc_802069853797_item	2894823	et	3	main
kasu	doc_802069853797_item	2894825	et	4	main
planeerima	doc_802069853797_item	2894829	et	3	main
oma	doc_802069853797_item	2894830	et	4	main
uuest	doc_802069853797_item	2894774	et	3	main
aastast	doc_802069853797_item	2894775	et	4	main
kui	doc_802069853797_item	2894776	et	3	main
uus	doc_802069853797_item	2894777	et	3	main
alati	doc_802069853797_item	2894780	et	4	main
selline	doc_802069853797_item	2894782	et	4	main
tunne	doc_802069853797_item	2894783	et	4	main
et	doc_802069853797_item	2894784	et	3	main
et	doc_802069853797_item	2894822	et	3	main
aasta	doc_802069853797_item	2894824	et	4	main
toob	doc_802069853797_item	2894826	et	3	main
ma	doc_802069853797_item	2894827	et	3	main
hakkan	doc_802069853797_item	2894828	et	3	main
parem	doc_802069853797_item	2894832	et	4	main
kõik	doc_802069853797_item	2894834	et	4	main
suvel	doc_802069853797_item	2894841	et	3	main
kõike	doc_802069853797_item	2894851	et	4	main
lõppenud	doc_802069853798_item	2894876	et	4	main
õpin	doc_802069853798_item	2894879	et	3	main
võõrlinnas	doc_802069853798_item	2894881	et	4	main
sõbra	doc_802069853798_item	2894887	et	3	main
õppimine	doc_802069853798_item	2894907	et	4	main
ttü-s	doc_802069853798_item	2894908	et	3	main
on	doc_802069853798_item	2894926	et	4	main
immatrikuleerida	doc_802069853798_item	2894927	et	3	main
ja	doc_802069853798_item	2894928	et	3	main
armastust	doc_802069853798_item	2894939	et	4	main
hõivab	doc_802069853798_item	2894943	et	3	main
ei	doc_802069853798_item	2894950	et	4	main
näe	doc_802069853798_item	2894951	et	4	main
seda	doc_802069853798_item	2894952	et	3	main
et	doc_802069853798_item	2894957	et	3	main
kui	doc_802069853798_item	2894975	et	3	main
ausalt	doc_802069853798_item	2894977	et	4	main
ei	doc_802069853798_item	2894979	et	4	main
aastaas	doc_802069853798_item	2895021	et	4	main
2007	doc_802069853799_item	2895031	et	2	main
oli	doc_802069853799_item	2895034	et	3	main
jõulut	doc_802069853799_item	2895039	et	4	main
sii	doc_802069853799_item	2895043	et	4	main
kingituseks	doc_802069853799_item	2895047	et	4	main
õpisin	doc_802069853799_item	2895051	et	4	main
gümnaasiumis	doc_802069853799_item	2895052	et	3	main
uus	doc_802069853799_item	2895053	et	3	main
hea	doc_802069853799_item	2895085	et	4	main
uue	doc_802069853799_item	2895086	et	3	main
asja	doc_802069853799_item	2895087	et	4	main
esimeks	doc_802069853799_item	2895091	et	4	main
ootan	doc_802069853799_item	2895093	et	3	main
ma	doc_802069853799_item	2895099	et	3	main
mulle	doc_802069853799_item	2895110	et	4	main
arvan	doc_802069853799_item	2895120	et	3	main
et	doc_802069853799_item	2895121	et	3	main
üliõpilase	doc_802069853799_item	2895125	et	3	main
teiseks	doc_802069853799_item	2895127	et	4	main
ma	doc_802069853799_item	2895128	et	3	main
töötada	doc_802069853799_item	2895131	et	3	main
taha	doc_802069853799_item	2895148	et	4	main
tahan	doc_802069853799_item	2895159	et	3	main
korteris	doc_802069853799_item	2895174	et	3	main
korteris	doc_802069853799_item	2895178	et	3	main
mugavam	doc_802069853799_item	2895180	et	4	main
lõbusam	doc_802069853799_item	2895186	et	4	main
viga	doc_802069853799_item	2895190	et	4	main
ei	doc_802069853799_item	2895195	et	4	main
on	doc_802069853799_item	2895203	et	4	main
on	doc_802069853799_item	2895207	et	4	main
elama	doc_802069853799_item	2895211	et	3	main
parem	doc_802069853799_item	2895212	et	4	main
tahan	doc_802069853799_item	2895215	et	3	main
ootan	doc_802069853799_item	2895226	et	3	main
ootan	doc_802069853800_item	2895237	et	3	main
2007	doc_802069853800_item	2895239	et	2	main
ma	doc_802069853800_item	2895241	et	3	main
kõikidelt	doc_802069853800_item	2895251	et	4	main
ühised	doc_802069853800_item	2895255	et	3	main
rahulikust	doc_802069853800_item	2895260	et	4	main
tervist	doc_802069853800_item	2895270	et	4	main
kõige	doc_802069853800_item	2895273	et	4	main
tähtsam	doc_802069853800_item	2895274	et	4	main
eksamisession	doc_802069853800_item	2895310	et	4	main
esimene	doc_802069853800_item	2895312	et	3	main
et	doc_802069853797_item	2894833	et	3	main
oleks	doc_802069853797_item	2894835	et	3	main
korras	doc_802069853797_item	2894836	et	4	main
ja	doc_802069853797_item	2894853	et	3	main
loodan	doc_802069853797_item	2894854	et	3	main
et	doc_802069853797_item	2894855	et	3	main
ma	doc_802069853797_item	2894856	et	3	main
saan	doc_802069853797_item	2894857	et	4	main
seda	doc_802069853797_item	2894858	et	3	main
kõik	doc_802069853797_item	2894859	et	4	main
teha	doc_802069853797_item	2894860	et	3	main
essee	doc_802069853798_item	2894861	et	4	main
mida	doc_802069853798_item	2894862	et	4	main
ootan	doc_802069853798_item	2894863	et	3	main
a	doc_802069853798_item	2894864	et	4	main
2007-st	doc_802069853798_item	2894865	et	3	main
vaja	doc_802069853797_item	2894839	et	4	main
puhkus	doc_802069853797_item	2894840	et	3	main
hästi	doc_802069853797_item	2894843	et	3	main
juures	doc_802069853797_item	2894846	et	4	main
ühesõnaga	doc_802069853797_item	2894847	et	3	main
ootan	doc_802069853797_item	2894848	et	3	main
uuest	doc_802069853797_item	2894849	et	3	main
head	doc_802069853797_item	2894852	et	4	main
aasta	doc_802069853798_item	2894867	et	4	main
raske	doc_802069853798_item	2894871	et	4	main
et	doc_802069853798_item	2894873	et	3	main
põhikool	doc_802069853798_item	2894874	et	4	main
praegu	doc_802069853798_item	2894882	et	3	main
mul	doc_802069853798_item	2894883	et	3	main
on	doc_802069853798_item	2894884	et	4	main
veel	doc_802069853798_item	2894885	et	4	main
pean	doc_802069853798_item	2894891	et	4	main
elus	doc_802069853798_item	2894900	et	4	main
õppimine	doc_802069853798_item	2894909	et	4	main
raskem	doc_802069853798_item	2894913	et	4	main
kui	doc_802069853798_item	2894914	et	3	main
koolis	doc_802069853798_item	2894915	et	4	main
lõpetada	doc_802069853798_item	2894929	et	3	main
oma	doc_802069853798_item	2894938	et	4	main
armastus	doc_802069853798_item	2894942	et	4	main
ilma	doc_802069853798_item	2894953	et	4	main
armastuseta	doc_802069853798_item	2894954	et	4	main
armastatut	doc_802069853798_item	2894961	et	4	main
naist	doc_802069853798_item	2894962	et	3	main
mu	doc_802069853798_item	2894963	et	3	main
elu	doc_802069853798_item	2894964	et	4	main
oleks	doc_802069853798_item	2894965	et	3	main
värvilisem	doc_802069853798_item	2894966	et	4	main
kui	doc_802069853798_item	2894967	et	3	main
praegu	doc_802069853798_item	2894968	et	3	main
ja	doc_802069853798_item	2894969	et	3	main
siis	doc_802069853798_item	2894970	et	3	main
ma	doc_802069853798_item	2894971	et	3	main
tahaksin	doc_802069853798_item	2894972	et	3	main
elust	doc_802069853798_item	2894973	et	3	main
rohkem	doc_802069853798_item	2894974	et	4	main
praegu	doc_802069853798_item	2894976	et	3	main
ma	doc_802069853798_item	2894978	et	3	main
tea	doc_802069853798_item	2894980	et	4	main
mida	doc_802069853798_item	2894981	et	4	main
ma	doc_802069853798_item	2894982	et	3	main
tahaksin	doc_802069853798_item	2894983	et	3	main
taha	doc_802069853798_item	2894986	et	4	main
ja	doc_802069853798_item	2894989	et	3	main
seda	doc_802069853798_item	2895024	et	3	main
kui	doc_802069853799_item	2895032	et	3	main
väikeks	doc_802069853799_item	2895035	et	4	main
poisiks	doc_802069853799_item	2895036	et	3	main
ootasin	doc_802069853799_item	2895038	et	3	main
ja	doc_802069853799_item	2895040	et	3	main
ja	doc_802069853799_item	2895055	et	3	main
suureks	doc_802069853799_item	2895059	et	4	main
piduks	doc_802069853799_item	2895060	et	3	main
eksamisessioon	doc_802069853799_item	2895095	et	3	main
hästi	doc_802069853799_item	2895097	et	3	main
võin	doc_802069853799_item	2895100	et	3	main
selles	doc_802069853799_item	2895111	et	4	main
aastas	doc_802069853799_item	2895112	et	3	main
ja	doc_802069853799_item	2895113	et	3	main
peab	doc_802069853798_item	2894868	et	4	main
on	doc_802069853798_item	2894875	et	4	main
ja	doc_802069853798_item	2894888	et	3	main
teha	doc_802069853798_item	2894892	et	3	main
ise	doc_802069853798_item	2894894	et	4	main
see	doc_802069853798_item	2894895	et	3	main
on	doc_802069853798_item	2894896	et	4	main
tähtsam	doc_802069853798_item	2894902	et	4	main
probleem	doc_802069853798_item	2894903	et	3	main
minu	doc_802069853798_item	2894904	et	3	main
jaoks	doc_802069853798_item	2894905	et	4	main
on	doc_802069853798_item	2894911	et	4	main
ainult	doc_802069853798_item	2894919	et	4	main
minust	doc_802069853798_item	2894920	et	3	main
olla	doc_802069853798_item	2894869	et	3	main
ja	doc_802069853798_item	2894877	et	3	main
ma	doc_802069853798_item	2894878	et	3	main
vähe	doc_802069853798_item	2894886	et	3	main
ma	doc_802069853798_item	2894890	et	3	main
raske	doc_802069853798_item	2894897	et	4	main
minu	doc_802069853798_item	2894899	et	3	main
kõige	doc_802069853798_item	2894901	et	4	main
kõik	doc_802069853798_item	2894917	et	4	main
sõltub	doc_802069853798_item	2894918	et	3	main
suurem	doc_802069853798_item	2894922	et	4	main
selle	doc_802069853798_item	2894924	et	4	main
sügi-	doc_802069853798_item	2894930	et	4	main
ja	doc_802069853798_item	2894931	et	3	main
kevade	doc_802069853798_item	2894932	et	4	main
minu	doc_802069853798_item	2894946	et	3	main
ma	doc_802069853798_item	2894949	et	3	main
olen	doc_802069853798_item	2894955	et	3	main
ei	doc_802069853798_item	2894985	et	4	main
leian	doc_802069853798_item	2895023	et	3	main
kõike	doc_802069853798_item	2895025	et	4	main
essee	doc_802069853799_item	2895026	et	4	main
mida	doc_802069853799_item	2895027	et	4	main
ma	doc_802069853799_item	2895028	et	3	main
ootan	doc_802069853799_item	2895029	et	3	main
ma	doc_802069853799_item	2895033	et	3	main
armastasin	doc_802069853799_item	2895044	et	3	main
asja	doc_802069853799_item	2895046	et	4	main
saama	doc_802069853799_item	2895048	et	4	main
kui	doc_802069853799_item	2895049	et	3	main
ma	doc_802069853799_item	2895050	et	3	main
ülikoolis	doc_802069853799_item	2895080	et	4	main
ja	doc_802069853799_item	2895081	et	3	main
muidugi	doc_802069853799_item	2895082	et	4	main
ootan	doc_802069853799_item	2895083	et	3	main
mingi	doc_802069853799_item	2895084	et	4	main
aastas	doc_802069853799_item	2895090	et	3	main
teises	doc_802069853799_item	2895102	et	4	main
olulisem	doc_802069853799_item	2895109	et	4	main
ma	doc_802069853799_item	2895119	et	3	main
vanemadega	doc_802069853799_item	2895136	et	4	main
probleemit	doc_802069853799_item	2895141	et	4	main
nüüd	doc_802069853799_item	2895143	et	4	main
sõltuma	doc_802069853799_item	2895150	et	3	main
jutustada	doc_802069853799_item	2895160	et	3	main
sellest	doc_802069853799_item	2895161	et	4	main
astusin	doc_802069853799_item	2895165	et	3	main
ülikoolisse	doc_802069853799_item	2895166	et	4	main
mul	doc_802069853799_item	2895167	et	3	main
ühiselamuses	doc_802069853799_item	2895182	et	3	main
on	doc_802069853799_item	2895183	et	4	main
see	doc_802069853799_item	2895187	et	3	main
suur	doc_802069853799_item	2895189	et	3	main
õppimine	doc_802069853799_item	2895191	et	4	main
ülikoolis	doc_802069853799_item	2895192	et	4	main
nüüd	doc_802069853799_item	2895199	et	4	main
ma	doc_802069853799_item	2895200	et	3	main
tean	doc_802069853799_item	2895201	et	3	main
õppimine	doc_802069853799_item	2895204	et	4	main
ütelda	doc_802069853799_item	2895216	et	4	main
et	doc_802069853799_item	2895217	et	3	main
ma	doc_802069853799_item	2895218	et	3	main
ei	doc_802069853799_item	2895219	et	4	main
mingi	doc_802069853799_item	2895221	et	4	main
õnn	doc_802069853799_item	2895223	et	3	main
ainult	doc_802069853799_item	2895229	et	4	main
asja	doc_802069853799_item	2895230	et	4	main
et	doc_802069853799_item	2895231	et	3	main
võin	doc_802069853799_item	2895232	et	3	main
saavutada	doc_802069853799_item	2895233	et	3	main
essee	doc_802069853800_item	2895234	et	4	main
aastalt	doc_802069853800_item	2895243	et	3	main
ja	doc_802069853800_item	2895262	et	3	main
õnne	doc_802069853800_item	2895265	et	4	main
rahulikust	doc_802069853800_item	2895266	et	4	main
tervis	doc_802069853800_item	2895271	et	3	main
on	doc_802069853800_item	2895272	et	4	main
on	doc_802069853800_item	2895315	et	4	main
õppida	doc_802069853800_item	2895318	et	3	main
kõige	doc_802069853798_item	2894921	et	4	main
soov	doc_802069853798_item	2894923	et	3	main
pärast	doc_802069853798_item	2894925	et	4	main
sell	doc_802069853798_item	2894940	et	3	main
elus	doc_802069853798_item	2894947	et	4	main
ja	doc_802069853798_item	2894948	et	3	main
kindel	doc_802069853798_item	2894956	et	3	main
leidaksin	doc_802069853798_item	2894960	et	4	main
tavaliset	doc_802069853798_item	2894984	et	4	main
mida	doc_802069853798_item	2894988	et	4	main
unustan	doc_802069853798_item	2894990	et	3	main
et	doc_802069853798_item	2894991	et	3	main
mul	doc_802069853798_item	2894992	et	3	main
oleks	doc_802069853798_item	2894993	et	3	main
ta	doc_802069853798_item	2894994	et	4	main
lupus	doc_802069853798_item	2894995	et	4	main
tahaksin	doc_802069853798_item	2894996	et	3	main
öelda	doc_802069853798_item	2894997	et	4	main
et	doc_802069853798_item	2894998	et	3	main
tahaksin	doc_802069853798_item	2894999	et	3	main
esiteks	doc_802069853798_item	2895000	et	3	main
et	doc_802069853798_item	2895001	et	3	main
oleks	doc_802069853798_item	2895002	et	3	main
edu	doc_802069853798_item	2895003	et	4	main
õppimises	doc_802069853798_item	2895004	et	4	main
ja	doc_802069853798_item	2895005	et	3	main
teiseks	doc_802069853798_item	2895006	et	4	main
minu	doc_802069853798_item	2895007	et	3	main
isiklikus	doc_802069853798_item	2895008	et	4	main
elus	doc_802069853798_item	2895009	et	4	main
see	doc_802069853798_item	2895010	et	3	main
on	doc_802069853798_item	2895011	et	4	main
kõige	doc_802069853798_item	2895012	et	4	main
suuremad	doc_802069853798_item	2895013	et	4	main
soovitused	doc_802069853798_item	2895014	et	4	main
ja	doc_802069853798_item	2895015	et	3	main
ma	doc_802069853798_item	2895016	et	3	main
loodan	doc_802069853798_item	2895017	et	3	main
et	doc_802069853798_item	2895018	et	3	main
sellel	doc_802069853798_item	2895019	et	4	main
2007	doc_802069853798_item	2895020	et	2	main
ma	doc_802069853799_item	2895037	et	3	main
aastat	doc_802069853799_item	2895042	et	3	main
mingi	doc_802069853799_item	2895045	et	4	main
jõulud	doc_802069853799_item	2895056	et	3	main
ei	doc_802069853799_item	2895057	et	4	main
oli	doc_802069853799_item	2895058	et	3	main
selles	doc_802069853799_item	2895088	et	4	main
ma	doc_802069853799_item	2895092	et	3	main
ja	doc_802069853799_item	2895098	et	3	main
õpida	doc_802069853799_item	2895101	et	4	main
tallinna	doc_802069853799_item	2895104	et	4	main
ma	doc_802069853798_item	2895022	et	3	main
a	doc_802069853799_item	2895030	et	4	main
uut	doc_802069853799_item	2895041	et	3	main
aasta	doc_802069853799_item	2895054	et	4	main
mulle	doc_802069853799_item	2895061	et	4	main
aga	doc_802069853799_item	2895062	et	3	main
ma	doc_802069853799_item	2895063	et	3	main
armastasin	doc_802069853799_item	2895064	et	3	main
sõbradega	doc_802069853799_item	2895065	et	4	main
pidama	doc_802069853799_item	2895066	et	4	main
aga	doc_802069853799_item	2895067	et	3	main
sellel	doc_802069853799_item	2895068	et	4	main
aastas	doc_802069853799_item	2895069	et	3	main
see	doc_802069853799_item	2895070	et	3	main
on	doc_802069853799_item	2895071	et	4	main
suurem	doc_802069853799_item	2895072	et	4	main
kui	doc_802069853799_item	2895074	et	3	main
oli	doc_802069853799_item	2895075	et	3	main
minevikus	doc_802069853799_item	2895076	et	3	main
pidu	doc_802069853799_item	2895073	et	4	main
sest	doc_802069853799_item	2895077	et	4	main
ma	doc_802069853799_item	2895078	et	3	main
õpin	doc_802069853799_item	2895079	et	3	main
2007	doc_802069853799_item	2895089	et	2	main
et	doc_802069853799_item	2895094	et	3	main
lõpetab	doc_802069853799_item	2895096	et	3	main
semestris	doc_802069853799_item	2895103	et	3	main
tehnikaülikoolis	doc_802069853799_item	2895105	et	4	main
kõige	doc_802069853799_item	2895108	et	4	main
kõige	doc_802069853799_item	2895115	et	4	main
suurem	doc_802069853799_item	2895116	et	4	main
soov	doc_802069853799_item	2895117	et	3	main
ja	doc_802069853799_item	2895118	et	3	main
soov	doc_802069853799_item	2895126	et	3	main
tahan	doc_802069853799_item	2895129	et	3	main
ka	doc_802069853799_item	2895130	et	3	main
teises	doc_802069853799_item	2895132	et	4	main
semestris	doc_802069853799_item	2895133	et	3	main
kui	doc_802069853799_item	2895134	et	3	main
elasin	doc_802069853799_item	2895135	et	3	main
olnud	doc_802069853799_item	2895139	et	4	main
aga	doc_802069853799_item	2895142	et	3	main
elasin	doc_802069853799_item	2895144	et	3	main
üksikult	doc_802069853799_item	2895145	et	4	main
ja	doc_802069853799_item	2895146	et	3	main
ei	doc_802069853799_item	2895147	et	4	main
ühiselamust	doc_802069853799_item	2895157	et	4	main
või	doc_802069853799_item	2895173	et	4	main
mõtlesin	doc_802069853799_item	2895176	et	3	main
ja	doc_802069853799_item	2895185	et	3	main
oli	doc_802069853799_item	2895188	et	3	main
mis	doc_802069853799_item	2895202	et	4	main
ja	doc_802069853799_item	2895205	et	3	main
j	doc_802069853799_item	2895213	et	4	main
kokkuvõtteks	doc_802069853799_item	2895214	et	3	main
ja	doc_802069853799_item	2895225	et	3	main
2007	doc_802069853799_item	2895228	et	2	main
ma	doc_802069853800_item	2895236	et	3	main
aastalt	doc_802069853800_item	2895238	et	3	main
mida	doc_802069853800_item	2895240	et	4	main
ootan	doc_802069853800_item	2895242	et	3	main
on	doc_802069853800_item	2895246	et	4	main
küsimus	doc_802069853800_item	2895248	et	4	main
minu	doc_802069853800_item	2895249	et	3	main
arvates	doc_802069853800_item	2895250	et	4	main
kõigepealt	doc_802069853800_item	2895269	et	3	main
tänapäeval	doc_802069853800_item	2895313	et	3	main
tasuta	doc_802069853800_item	2895319	et	4	main
järgmisel	doc_802069853802_item	2895528	et	3	main
sõita	doc_802069853802_item	2895542	et	3	main
välismaale	doc_802069853802_item	2895543	et	4	main
puhkama	doc_802069853802_item	2895547	et	3	main
ei	doc_802069853802_item	2895558	et	4	main
mäleta	doc_802069853802_item	2895559	et	4	main
millal	doc_802069853802_item	2895560	et	3	main
ma	doc_802069853802_item	2895561	et	3	main
viimati	doc_802069853802_item	2895562	et	3	main
ajast	doc_802069853802_item	2895575	et	4	main
praegu	doc_802069853802_item	2895577	et	3	main
aastal	doc_802069853802_item	2895584	et	3	main
õppimisega	doc_802069853802_item	2895585	et	4	main
kui	doc_802069853802_item	2895587	et	3	main
mul	doc_802069853802_item	2895591	et	3	main
see	doc_802069853799_item	2895106	et	3	main
on	doc_802069853799_item	2895107	et	4	main
minu	doc_802069853799_item	2895114	et	3	main
on	doc_802069853799_item	2895123	et	4	main
iga	doc_802069853799_item	2895124	et	4	main
ei	doc_802069853799_item	2895138	et	4	main
kolmaks	doc_802069853799_item	2895152	et	4	main
ma	doc_802069853799_item	2895153	et	3	main
tahan	doc_802069853799_item	2895154	et	3	main
sõita	doc_802069853799_item	2895155	et	3	main
oli	doc_802069853799_item	2895168	et	3	main
valik	doc_802069853799_item	2895169	et	3	main
kas	doc_802069853799_item	2895170	et	3	main
elada	doc_802069853799_item	2895171	et	3	main
ühiselamuses	doc_802069853799_item	2895172	et	3	main
esimesel	doc_802069853799_item	2895193	et	3	main
andis	doc_802069853799_item	2895196	et	3	main
oota	doc_802069853799_item	2895220	et	4	main
globaalse	doc_802069853799_item	2895222	et	3	main
mida	doc_802069853800_item	2895235	et	4	main
see	doc_802069853800_item	2895245	et	3	main
aastalt	doc_802069853800_item	2895252	et	3	main
ootab	doc_802069853800_item	2895254	et	3	main
õnne	doc_802069853800_item	2895257	et	4	main
edu	doc_802069853800_item	2895261	et	4	main
tahaks	doc_802069853800_item	2895264	et	3	main
sest	doc_802069853800_item	2895275	et	4	main
terviseta	doc_802069853800_item	2895276	et	3	main
inimene	doc_802069853800_item	2895277	et	3	main
siht	doc_802069853800_item	2895317	et	3	main
mida	doc_802069853802_item	2895486	et	4	main
see	doc_802069853799_item	2895122	et	3	main
raha	doc_802069853799_item	2895137	et	4	main
mingi	doc_802069853799_item	2895140	et	4	main
nendest	doc_802069853799_item	2895149	et	4	main
ja	doc_802069853799_item	2895151	et	3	main
tudengi	doc_802069853799_item	2895156	et	3	main
korterisse	doc_802069853799_item	2895158	et	3	main
põhjalikult	doc_802069853799_item	2895162	et	4	main
kui	doc_802069853799_item	2895163	et	3	main
ma	doc_802069853799_item	2895164	et	3	main
ma	doc_802069853799_item	2895175	et	3	main
et	doc_802069853799_item	2895177	et	3	main
on	doc_802069853799_item	2895179	et	4	main
aga	doc_802069853799_item	2895181	et	3	main
huvitavam	doc_802069853799_item	2895184	et	4	main
semestril	doc_802069853799_item	2895194	et	3	main
aega	doc_802069853799_item	2895197	et	4	main
meelelahetusele	doc_802069853799_item	2895198	et	4	main
mis	doc_802069853799_item	2895206	et	4	main
ühiselamus	doc_802069853799_item	2895208	et	4	main
ja	doc_802069853799_item	2895209	et	3	main
tahan	doc_802069853799_item	2895210	et	3	main
igaühele	doc_802069853799_item	2895224	et	3	main
aastast	doc_802069853799_item	2895227	et	4	main
2007	doc_802069853800_item	2895244	et	2	main
huvitav	doc_802069853800_item	2895247	et	4	main
inimene	doc_802069853800_item	2895253	et	3	main
asjad	doc_802069853800_item	2895256	et	3	main
raha	doc_802069853800_item	2895258	et	4	main
tervist	doc_802069853800_item	2895259	et	4	main
mina	doc_802069853800_item	2895263	et	4	main
edu	doc_802069853800_item	2895267	et	4	main
ja	doc_802069853800_item	2895268	et	3	main
ei	doc_802069853800_item	2895278	et	4	main
saa	doc_802069853800_item	2895279	et	4	main
mitte	doc_802069853800_item	2895280	et	3	main
migadi	doc_802069853800_item	2895281	et	4	main
teha	doc_802069853800_item	2895282	et	3	main
mina	doc_802069853800_item	2895283	et	4	main
tahaksin	doc_802069853800_item	2895284	et	3	main
mitte	doc_802069853800_item	2895285	et	3	main
ainult	doc_802069853800_item	2895286	et	4	main
tervist	doc_802069853800_item	2895287	et	4	main
minu	doc_802069853800_item	2895288	et	3	main
jaoks	doc_802069853800_item	2895289	et	4	main
minu	doc_802069853800_item	2895291	et	3	main
vaid	doc_802069853800_item	2895290	et	3	main
sugulaste	doc_802069853800_item	2895292	et	4	main
ja	doc_802069853800_item	2895293	et	3	main
sõprade	doc_802069853800_item	2895294	et	3	main
jaoks	doc_802069853800_item	2895295	et	4	main
veel	doc_802069853800_item	2895296	et	4	main
ootaksin	doc_802069853800_item	2895297	et	3	main
edu	doc_802069853800_item	2895298	et	4	main
eksami	doc_802069853800_item	2895299	et	3	main
jaoks	doc_802069853800_item	2895300	et	4	main
praegu	doc_802069853800_item	2895301	et	3	main
see	doc_802069853800_item	2895302	et	3	main
on	doc_802069853800_item	2895303	et	4	main
väga	doc_802069853800_item	2895304	et	3	main
oluline	doc_802069853800_item	2895305	et	4	main
minuks	doc_802069853800_item	2895306	et	3	main
sellepärast	doc_802069853800_item	2895307	et	3	main
et	doc_802069853800_item	2895308	et	3	main
see	doc_802069853800_item	2895309	et	3	main
on	doc_802069853800_item	2895311	et	4	main
mul	doc_802069853800_item	2895314	et	3	main
kohas	doc_802069853800_item	2895320	et	4	main
essee	doc_802069853802_item	2895485	et	4	main
loodan	doc_802069853802_item	2895526	et	3	main
võib	doc_802069853802_item	2895565	et	3	main
aga	doc_802069853802_item	2895570	et	3	main
ma	doc_802069853802_item	2895578	et	3	main
järgmisel	doc_802069853802_item	2895583	et	3	main
ja	doc_802069853802_item	2895586	et	3	main
on	doc_802069853802_item	2895592	et	4	main
tahaksin	doc_802069853802_item	2895593	et	3	main
remonti	doc_802069853802_item	2895595	et	4	main
inimisel	doc_802069853802_item	2895606	et	4	main
on	doc_802069853802_item	2895607	et	4	main
temale	doc_802069853802_item	2895612	et	3	main
võimalik	doc_802069853802_item	2895614	et	3	main
väga	doc_802069853803_item	2895621	et	3	main
on	doc_802069853803_item	2895631	et	4	main
väga	doc_802069853803_item	2895632	et	3	main
2007	doc_802069853803_item	2895641	et	2	main
aastal	doc_802069853803_item	2895642	et	3	main
tahan	doc_802069853803_item	2895644	et	3	main
palju	doc_802069853803_item	2895655	et	4	main
essee	doc_802069853805_item	2895754	et	4	main
on	doc_802069853805_item	2895761	et	4	main
sellel	doc_802069853805_item	2895782	et	4	main
aastal	doc_802069853805_item	2895783	et	3	main
mõelda	doc_802069853805_item	2895790	et	4	main
uues	doc_802069853805_item	2895794	et	3	main
ma	doc_802069853805_item	2895798	et	3	main
et	doc_802069853805_item	2895801	et	3	main
ülikool	doc_802069853805_item	2895804	et	4	main
ja	doc_802069853805_item	2895805	et	3	main
üks	doc_802069853800_item	2895316	et	3	main
palga	doc_802069853802_item	2895524	et	3	main
et	doc_802069853802_item	2895527	et	3	main
oleks	doc_802069853802_item	2895530	et	3	main
vaba	doc_802069853802_item	2895532	et	4	main
suhtlemisele	doc_802069853802_item	2895538	et	4	main
oleks	doc_802069853802_item	2895539	et	3	main
olin	doc_802069853802_item	2895563	et	3	main
tegelema	doc_802069853802_item	2895568	et	3	main
minu	doc_802069853802_item	2895573	et	3	main
kuidas	doc_802069853802_item	2895581	et	3	main
palju	doc_802069853802_item	2895588	et	4	main
vaba	doc_802069853802_item	2895589	et	4	main
oma	doc_802069853802_item	2895596	et	4	main
majal	doc_802069853802_item	2895597	et	3	main
juba	doc_802069853802_item	2895598	et	3	main
teine	doc_802069853802_item	2895599	et	3	main
aasta	doc_802069853802_item	2895600	et	4	main
suur	doc_802069853802_item	2895608	et	3	main
on	doc_802069853802_item	2895613	et	4	main
ma	doc_802069853802_item	2895487	et	3	main
ootan	doc_802069853802_item	2895488	et	3	main
aastast	doc_802069853802_item	2895489	et	4	main
2007	doc_802069853802_item	2895490	et	2	main
kõigepealt	doc_802069853802_item	2895491	et	3	main
2007	doc_802069853802_item	2895493	et	2	main
aastast	doc_802069853802_item	2895492	et	4	main
ma	doc_802069853802_item	2895494	et	3	main
ootan	doc_802069853802_item	2895495	et	3	main
edukat	doc_802069853802_item	2895496	et	3	main
õppimist	doc_802069853802_item	2895497	et	4	main
et	doc_802069853802_item	2895498	et	3	main
mul	doc_802069853802_item	2895499	et	3	main
ei	doc_802069853802_item	2895500	et	4	main
ole	doc_802069853802_item	2895501	et	4	main
probleeme	doc_802069853802_item	2895502	et	3	main
eksamitega	doc_802069853802_item	2895503	et	3	main
sest	doc_802069853802_item	2895504	et	4	main
tulevikus	doc_802069853802_item	2895505	et	4	main
tahan	doc_802069853802_item	2895506	et	3	main
saada	doc_802069853802_item	2895507	et	4	main
inseneeriks	doc_802069853802_item	2895508	et	4	main
ja	doc_802069853802_item	2895509	et	3	main
pean	doc_802069853802_item	2895510	et	4	main
kõik	doc_802069853802_item	2895511	et	4	main
aineid	doc_802069853802_item	2895512	et	3	main
hästi	doc_802069853802_item	2895513	et	3	main
õppima	doc_802069853802_item	2895514	et	3	main
tahaksin	doc_802069853802_item	2895515	et	3	main
leia	doc_802069853802_item	2895516	et	4	main
uut	doc_802069853802_item	2895517	et	3	main
töökohta	doc_802069853802_item	2895518	et	4	main
praegu	doc_802069853802_item	2895519	et	3	main
meie	doc_802069853802_item	2895520	et	4	main
firmas	doc_802069853802_item	2895521	et	3	main
probleemid	doc_802069853802_item	2895523	et	3	main
aastal	doc_802069853802_item	2895529	et	3	main
rohkem	doc_802069853802_item	2895531	et	4	main
aja	doc_802069853802_item	2895533	et	4	main
puhkamisele	doc_802069853802_item	2895534	et	4	main
ja	doc_802069853802_item	2895535	et	3	main
ka	doc_802069853802_item	2895540	et	3	main
hea	doc_802069853802_item	2895541	et	4	main
lihtsalt	doc_802069853802_item	2895546	et	4	main
väga	doc_802069853802_item	2895548	et	3	main
vaadata	doc_802069853802_item	2895550	et	4	main
kuidas	doc_802069853802_item	2895551	et	3	main
inimesed	doc_802069853802_item	2895552	et	3	main
olla	doc_802069853802_item	2895566	et	3	main
hakkan	doc_802069853802_item	2895567	et	3	main
spordiga	doc_802069853802_item	2895569	et	3	main
see	doc_802069853802_item	2895571	et	3	main
läheb	doc_802069853802_item	2895582	et	3	main
ei	doc_802069853802_item	2895601	et	4	main
soov	doc_802069853802_item	2895609	et	3	main
kõik	doc_802069853802_item	2895611	et	4	main
essee	doc_802069853803_item	2895615	et	4	main
minu	doc_802069853803_item	2895616	et	3	main
uusaastasoovid	doc_802069853803_item	2895617	et	3	main
uus	doc_802069853803_item	2895618	et	3	main
aasta	doc_802069853803_item	2895619	et	4	main
2006a	doc_802069853803_item	2895640	et	4	main
ma	doc_802069853803_item	2895643	et	3	main
targemaks	doc_802069853803_item	2895647	et	4	main
ttüs	doc_802069853803_item	2895649	et	4	main
jõudu	doc_802069853803_item	2895656	et	4	main
on	doc_802069853802_item	2895522	et	4	main
saamisega	doc_802069853802_item	2895525	et	4	main
oma	doc_802069853802_item	2895536	et	4	main
sõbradega	doc_802069853802_item	2895537	et	4	main
töötama	doc_802069853802_item	2895544	et	3	main
või	doc_802069853802_item	2895545	et	4	main
huvitav	doc_802069853802_item	2895549	et	4	main
elavad	doc_802069853802_item	2895553	et	4	main
teistes	doc_802069853802_item	2895554	et	4	main
riikides	doc_802069853802_item	2895555	et	3	main
ma	doc_802069853802_item	2895556	et	3	main
juba	doc_802069853802_item	2895557	et	3	main
välismaal	doc_802069853802_item	2895564	et	4	main
sõltub	doc_802069853802_item	2895572	et	3	main
vaba	doc_802069853802_item	2895574	et	4	main
aga	doc_802069853802_item	2895576	et	3	main
ei	doc_802069853802_item	2895579	et	4	main
tea	doc_802069853802_item	2895580	et	4	main
aja	doc_802069853802_item	2895590	et	4	main
lõpetada	doc_802069853802_item	2895594	et	3	main
on	doc_802069853803_item	2895620	et	4	main
jõua	doc_802069853802_item	2895602	et	4	main
seda	doc_802069853802_item	2895603	et	3	main
teha	doc_802069853802_item	2895604	et	3	main
kui	doc_802069853802_item	2895605	et	3	main
siis	doc_802069853802_item	2895610	et	3	main
oluline	doc_802069853803_item	2895622	et	4	main
kõigele	doc_802069853803_item	2895624	et	4	main
kui	doc_802069853803_item	2895639	et	3	main
saada	doc_802069853803_item	2895645	et	4	main
nõub	doc_802069853803_item	2895654	et	4	main
mida	doc_802069853805_item	2895755	et	4	main
ma	doc_802069853805_item	2895756	et	3	main
ootan	doc_802069853805_item	2895757	et	3	main
uuel	doc_802069853805_item	2895758	et	3	main
aastal	doc_802069853805_item	2895759	et	3	main
palju	doc_802069853805_item	2895784	et	4	main
asju	doc_802069853805_item	2895785	et	3	main
ära	doc_802069853805_item	2895789	et	4	main
mitte	doc_802069853805_item	2895809	et	3	main
it	doc_802069853805_item	2895819	et	4	main
teaduskond	doc_802069853805_item	2895820	et	3	main
ma	doc_802069853805_item	2895823	et	3	main
sain	doc_802069853805_item	2895824	et	3	main
huvitav	doc_802069853805_item	2895837	et	4	main
esimisel	doc_802069853805_item	2895840	et	4	main
oli	doc_802069853805_item	2895845	et	3	main
ja	doc_802069853805_item	2895853	et	3	main
nissugused	doc_802069853805_item	2895865	et	4	main
ülikool	doc_802069853805_item	2895867	et	4	main
selles	doc_802069853805_item	2895870	et	4	main
ja	doc_802069853805_item	2895874	et	3	main
mina	doc_802069853806_item	2895921	et	4	main
pidu	doc_802069853803_item	2895623	et	4	main
inimesele	doc_802069853803_item	2895625	et	3	main
meeldib	doc_802069853803_item	2895626	et	3	main
see	doc_802069853803_item	2895627	et	3	main
pidu	doc_802069853803_item	2895628	et	4	main
see	doc_802069853803_item	2895629	et	3	main
aeg	doc_802069853803_item	2895630	et	3	main
raske	doc_802069853803_item	2895652	et	4	main
ja	doc_802069853803_item	2895653	et	3	main
imeline	doc_802069853803_item	2895633	et	4	main
ma	doc_802069853803_item	2895634	et	3	main
loodan	doc_802069853803_item	2895635	et	3	main
et	doc_802069853803_item	2895636	et	3	main
tuleb	doc_802069853803_item	2895637	et	3	main
parem	doc_802069853803_item	2895638	et	4	main
natukene	doc_802069853803_item	2895646	et	4	main
õpimine	doc_802069853803_item	2895648	et	4	main
on	doc_802069853803_item	2895650	et	4	main
väga	doc_802069853803_item	2895651	et	3	main
2006	doc_802069853805_item	2895760	et	2	main
muutunud	doc_802069853805_item	2895786	et	4	main
ootab	doc_802069853805_item	2895792	et	3	main
eriala	doc_802069853805_item	2895817	et	4	main
ja	doc_802069853805_item	2895818	et	3	main
töö	doc_802069853805_item	2895827	et	4	main
näiteks	doc_802069853805_item	2895851	et	4	main
kõi	doc_802069853805_item	2895859	et	4	main
see	doc_802069853805_item	2895860	et	3	main
tähendab	doc_802069853805_item	2895861	et	3	main
minu	doc_802069853805_item	2895862	et	3	main
eesmärgid	doc_802069853805_item	2895863	et	3	main
lõpetama	doc_802069853805_item	2895866	et	4	main
töötama	doc_802069853805_item	2895869	et	3	main
võimalus	doc_802069853805_item	2895878	et	3	main
on	doc_802069853805_item	2895891	et	4	main
minu	doc_802069853805_item	2895892	et	3	main
koi	doc_802069853805_item	2895893	et	4	main
eesmärgid	doc_802069853805_item	2895894	et	3	main
tea	doc_802069853806_item	2895925	et	4	main
ma	doc_802069853806_item	2895926	et	3	main
iga	doc_802069853806_item	2895930	et	4	main
inimene	doc_802069853806_item	2895931	et	3	main
ootan	doc_802069853806_item	2895932	et	3	main
unistused	doc_802069853806_item	2895942	et	4	main
tahan	doc_802069853806_item	2895943	et	3	main
hästi	doc_802069853806_item	2895944	et	3	main
eksaamid	doc_802069853806_item	2895945	et	3	main
endale	doc_802069853806_item	2895955	et	4	main
kõik	doc_802069853806_item	2895969	et	4	main
oli	doc_802069853806_item	2895979	et	3	main
palju	doc_802069853806_item	2895980	et	4	main
ootan	doc_802069853806_item	2895984	et	3	main
oma	doc_802069853806_item	2895988	et	4	main
vaadata	doc_802069853806_item	2896003	et	4	main
madridi	doc_802069853806_item	2896004	et	4	main
välismaal	doc_802069853806_item	2896017	et	4	main
sõnaga	doc_802069853806_item	2896019	et	3	main
on	doc_802069853806_item	2896021	et	4	main
mida	doc_802069853807_item	2896036	et	4	main
ma	doc_802069853807_item	2896037	et	3	main
ootan	doc_802069853807_item	2896038	et	3	main
ma	doc_802069853807_item	2896042	et	3	main
eest	doc_802069853807_item	2896055	et	4	main
võib	doc_802069853807_item	2896056	et	3	main
olla	doc_802069853807_item	2896057	et	3	main
esimesest	doc_802069853807_item	2896058	et	3	main
lõpetada	doc_802069853807_item	2896059	et	3	main
hästi	doc_802069853807_item	2896060	et	3	main
esimene	doc_802069853807_item	2896061	et	3	main
välismaal	doc_802069853807_item	2896088	et	4	main
kus	doc_802069853807_item	2896089	et	3	main
ma	doc_802069853807_item	2896090	et	3	main
firmast	doc_802069853808_item	2896121	et	4	main
mul	doc_802069853808_item	2896130	et	3	main
sõber	doc_802069853808_item	2896132	et	3	main
ta	doc_802069853808_item	2896137	et	4	main
tahan	doc_802069853808_item	2896141	et	3	main
korteris	doc_802069853808_item	2896144	et	3	main
suvel	doc_802069853808_item	2896165	et	3	main
tahan	doc_802069853808_item	2896171	et	3	main
vabariigid	doc_802069853808_item	2896174	et	3	main
mulle	doc_802069853808_item	2896181	et	4	main
sõida	doc_802069853808_item	2896185	et	4	main
hea	doc_802069853805_item	2895779	et	4	main
aasta	doc_802069853805_item	2895780	et	4	main
aga	doc_802069853805_item	2895781	et	3	main
aga	doc_802069853805_item	2895788	et	3	main
aastas	doc_802069853805_item	2895795	et	3	main
mida	doc_802069853805_item	2895797	et	4	main
loodan	doc_802069853805_item	2895800	et	3	main
lõpetan	doc_802069853805_item	2895803	et	3	main
aga	doc_802069853805_item	2895808	et	3	main
spetsialistiga	doc_802069853805_item	2895811	et	3	main
ei	doc_802069853805_item	2895814	et	4	main
meeldi	doc_802069853805_item	2895815	et	4	main
minu	doc_802069853805_item	2895816	et	3	main
et	doc_802069853805_item	2895822	et	3	main
leidma	doc_802069853805_item	2895825	et	3	main
et	doc_802069853805_item	2895828	et	3	main
oli	doc_802069853805_item	2895830	et	3	main
kui	doc_802069853805_item	2895832	et	3	main
palk	doc_802069853805_item	2895834	et	3	main
nii	doc_802069853805_item	2895835	et	3	main
aga	doc_802069853805_item	2895839	et	3	main
kohal	doc_802069853805_item	2895841	et	4	main
tahan	doc_802069853805_item	2895842	et	3	main
et	doc_802069853805_item	2895843	et	3	main
see	doc_802069853805_item	2895844	et	3	main
bio	doc_802069853805_item	2895852	et	4	main
ja	doc_802069853805_item	2895856	et	3	main
on	doc_802069853805_item	2895864	et	4	main
meeldib	doc_802069853805_item	2895873	et	3	main
kui	doc_802069853805_item	2895875	et	3	main
ja	doc_802069853805_item	2895881	et	3	main
võib	doc_802069853805_item	2895882	et	3	main
olla	doc_802069853805_item	2895883	et	3	main
algama	doc_802069853805_item	2895884	et	3	main
armastust	doc_802069853806_item	2895933	et	4	main
sõbrad	doc_802069853806_item	2895968	et	3	main
terved	doc_802069853806_item	2895971	et	4	main
nendel	doc_802069853806_item	2895972	et	4	main
saaks	doc_802069853806_item	2895986	et	3	main
ja	doc_802069853806_item	2895990	et	3	main
ootan	doc_802069853806_item	2895998	et	3	main
et	doc_802069853806_item	2895999	et	3	main
saaks	doc_802069853806_item	2896000	et	3	main
sõida	doc_802069853806_item	2896001	et	4	main
hispaaniasse	doc_802069853806_item	2896002	et	4	main
barcelona	doc_802069853806_item	2896006	et	4	main
ühe	doc_802069853806_item	2896018	et	4	main
vastu	doc_802069853806_item	2896026	et	3	main
nad	doc_802069853806_item	2896032	et	3	main
reaalseks	doc_802069853806_item	2896034	et	4	main
ma	doc_802069853807_item	2896046	et	3	main
kurs	doc_802069853807_item	2896062	et	4	main
kui	doc_802069853807_item	2896063	et	3	main
palju	doc_802069853807_item	2896074	et	4	main
õppida	doc_802069853807_item	2896076	et	3	main
puhkan	doc_802069853807_item	2896091	et	3	main
kõik	doc_802069853807_item	2896098	et	4	main
oli	doc_802069853807_item	2896099	et	3	main
hästi	doc_802069853807_item	2896100	et	3	main
mida	doc_802069853808_item	2896104	et	4	main
aastas	doc_802069853808_item	2896123	et	3	main
türgisse	doc_802069853808_item	2896126	et	4	main
selleparast	doc_802069853808_item	2896128	et	3	main
on	doc_802069853808_item	2896131	et	4	main
kutsub	doc_802069853808_item	2896138	et	3	main
ma	doc_802069853808_item	2896140	et	3	main
elada	doc_802069853808_item	2896154	et	3	main
suvel	doc_802069853808_item	2896156	et	3	main
mul	doc_802069853808_item	2896157	et	3	main
olin	doc_802069853808_item	2896167	et	3	main
aga	doc_802069853808_item	2896169	et	3	main
vaadata	doc_802069853808_item	2896172	et	4	main
minu	doc_802069853808_item	2896175	et	3	main
ei	doc_802069853808_item	2896182	et	4	main
auto	doc_802069853808_item	2896189	et	4	main
peaaegu	doc_802069853805_item	2895762	et	3	main
l	doc_802069853805_item	2895763	et	4	main
õppenud	doc_802069853805_item	2895764	et	4	main
palju	doc_802069853805_item	2895765	et	4	main
oli	doc_802069853805_item	2895766	et	3	main
tehtud	doc_802069853805_item	2895767	et	4	main
ja	doc_802069853805_item	2895768	et	3	main
palju	doc_802069853805_item	2895769	et	4	main
võib	doc_802069853805_item	2895770	et	3	main
olla	doc_802069853805_item	2895771	et	3	main
mitte	doc_802069853805_item	2895772	et	3	main
ma	doc_802069853805_item	2895773	et	3	main
ei	doc_802069853805_item	2895774	et	4	main
ütle	doc_802069853805_item	2895775	et	4	main
et	doc_802069853805_item	2895776	et	3	main
see	doc_802069853805_item	2895777	et	3	main
oli	doc_802069853805_item	2895778	et	3	main
sooviksin	doc_802069853805_item	2895787	et	3	main
mis	doc_802069853805_item	2895791	et	4	main
minust	doc_802069853805_item	2895793	et	3	main
ja	doc_802069853805_item	2895796	et	3	main
ootan	doc_802069853805_item	2895799	et	3	main
ma	doc_802069853805_item	2895802	et	3	main
it	doc_802069853805_item	2895810	et	4	main
mulle	doc_802069853805_item	2895812	et	4	main
algan	doc_802069853805_item	2895806	et	3	main
töötada	doc_802069853805_item	2895807	et	3	main
üldse	doc_802069853805_item	2895813	et	3	main
loodan	doc_802069853805_item	2895821	et	3	main
nissugune	doc_802069853805_item	2895826	et	4	main
kui	doc_802069853805_item	2895836	et	3	main
protsess	doc_802069853805_item	2895838	et	3	main
töö	doc_802069853805_item	2895846	et	4	main
organilise	doc_802069853805_item	2895849	et	4	main
töidega	doc_802069853805_item	2895850	et	4	main
organiline	doc_802069853805_item	2895854	et	4	main
piimatoid	doc_802069853805_item	2895855	et	4	main
teised	doc_802069853805_item	2895857	et	4	main
toiduained	doc_802069853805_item	2895858	et	3	main
tööles	doc_802069853805_item	2895871	et	4	main
on	doc_802069853805_item	2895877	et	4	main
laulda	doc_802069853805_item	2895880	et	4	main
uuel	doc_802069853805_item	2895885	et	3	main
uusi	doc_802069853806_item	2895934	et	3	main
sõpru	doc_802069853806_item	2895935	et	3	main
õnnelikkust	doc_802069853806_item	2895936	et	4	main
on	doc_802069853806_item	2895939	et	4	main
sooritada	doc_802069853806_item	2895946	et	3	main
ootan	doc_802069853806_item	2895951	et	3	main
kõik	doc_802069853806_item	2895973	et	4	main
läks	doc_802069853806_item	2895974	et	3	main
hästi	doc_802069853806_item	2895975	et	3	main
ja	doc_802069853806_item	2895976	et	3	main
et	doc_802069853806_item	2895977	et	3	main
nüüd	doc_802069853806_item	2895983	et	4	main
ammu	doc_802069853806_item	2895996	et	4	main
näinud	doc_802069853806_item	2895997	et	4	main
ja	doc_802069853806_item	2896005	et	3	main
tänavad	doc_802069853806_item	2896007	et	4	main
et	doc_802069853806_item	2896009	et	3	main
uusi	doc_802069853806_item	2896011	et	3	main
kui	doc_802069853806_item	2896013	et	3	main
nii	doc_802069853806_item	2896015	et	3	main
mul	doc_802069853806_item	2896020	et	3	main
ainult	doc_802069853806_item	2896029	et	4	main
et	doc_802069853806_item	2896031	et	3	main
uuelt	doc_802069853807_item	2896039	et	4	main
aastalt	doc_802069853807_item	2896040	et	3	main
ei	doc_802069853807_item	2896043	et	4	main
mida	doc_802069853807_item	2896045	et	4	main
tahan	doc_802069853807_item	2896065	et	3	main
ootan	doc_802069853807_item	2896070	et	3	main
mul	doc_802069853807_item	2896072	et	3	main
et	doc_802069853807_item	2896097	et	3	main
uuel	doc_802069853807_item	2896101	et	3	main
tahan	doc_802069853808_item	2896124	et	3	main
et	doc_802069853808_item	2896129	et	3	main
ja	doc_802069853808_item	2896136	et	3	main
aga	doc_802069853808_item	2896151	et	3	main
tuneesiasse	doc_802069853808_item	2896162	et	4	main
minna	doc_802069853808_item	2896163	et	3	main
eelmisel	doc_802069853808_item	2896164	et	3	main
mõned	doc_802069853808_item	2896173	et	3	main
unistus	doc_802069853808_item	2896176	et	4	main
on	doc_802069853808_item	2896177	et	4	main
meeldi	doc_802069853808_item	2896183	et	4	main
on	doc_802069853808_item	2896187	et	4	main
olemas	doc_802069853808_item	2896188	et	4	main
ma	doc_802069853809_item	2896209	et	3	main
ootan	doc_802069853809_item	2896210	et	3	main
uuelt	doc_802069853809_item	2896211	et	4	main
aastalt	doc_802069853809_item	2896212	et	3	main
uus	doc_802069853809_item	2896213	et	3	main
seal	doc_802069853805_item	2895829	et	4	main
nii	doc_802069853805_item	2895831	et	3	main
hea	doc_802069853805_item	2895833	et	4	main
mis	doc_802069853805_item	2895847	et	4	main
seotatud	doc_802069853805_item	2895848	et	4	main
algama	doc_802069853805_item	2895868	et	3	main
mis	doc_802069853805_item	2895872	et	4	main
mul	doc_802069853805_item	2895876	et	3	main
jatkama	doc_802069853805_item	2895879	et	4	main
bandil	doc_802069853805_item	2895886	et	4	main
laulda	doc_802069853805_item	2895887	et	4	main
loodan	doc_802069853805_item	2895888	et	3	main
et	doc_802069853805_item	2895889	et	3	main
see	doc_802069853805_item	2895890	et	3	main
mis	doc_802069853805_item	2895895	et	4	main
ma	doc_802069853805_item	2895896	et	3	main
sain	doc_802069853805_item	2895897	et	3	main
meelde	doc_802069853805_item	2895898	et	3	main
tulena	doc_802069853805_item	2895899	et	3	main
essee	doc_802069853806_item	2895900	et	4	main
mida	doc_802069853806_item	2895901	et	4	main
ma	doc_802069853806_item	2895902	et	3	main
ootan	doc_802069853806_item	2895903	et	3	main
uuest	doc_802069853806_item	2895904	et	3	main
aastast	doc_802069853806_item	2895905	et	4	main
see	doc_802069853806_item	2895906	et	3	main
on	doc_802069853806_item	2895907	et	4	main
päris	doc_802069853806_item	2895908	et	4	main
huvitav	doc_802069853806_item	2895909	et	4	main
küsimus	doc_802069853806_item	2895910	et	4	main
mida	doc_802069853806_item	2895911	et	4	main
ma	doc_802069853806_item	2895912	et	3	main
ootan	doc_802069853806_item	2895913	et	3	main
ootan	doc_802069853806_item	2895914	et	3	main
2007	doc_802069853806_item	2895915	et	2	main
aastast	doc_802069853806_item	2895916	et	4	main
kui	doc_802069853806_item	2895917	et	3	main
tõesti	doc_802069853806_item	2895918	et	3	main
ütelda	doc_802069853806_item	2895919	et	4	main
siis	doc_802069853806_item	2895920	et	3	main
üldse	doc_802069853806_item	2895923	et	3	main
ka	doc_802069853806_item	2895937	et	3	main
oma	doc_802069853806_item	2895940	et	4	main
väiksed	doc_802069853806_item	2895941	et	4	main
veedada	doc_802069853806_item	2895948	et	4	main
vaheaeg	doc_802069853806_item	2895950	et	3	main
saan	doc_802069853806_item	2895954	et	4	main
motorattast	doc_802069853806_item	2895956	et	4	main
osta	doc_802069853806_item	2895957	et	4	main
olid	doc_802069853806_item	2895970	et	4	main
huvitavam	doc_802069853806_item	2895981	et	4	main
kui	doc_802069853806_item	2895982	et	3	main
külastada	doc_802069853806_item	2895987	et	3	main
vanaema	doc_802069853806_item	2895989	et	4	main
vanaisa	doc_802069853806_item	2895991	et	4	main
venemaal	doc_802069853806_item	2895992	et	4	main
ka	doc_802069853806_item	2896016	et	3	main
seda	doc_802069853806_item	2895922	et	3	main
ei	doc_802069853806_item	2895924	et	4	main
arvan	doc_802069853806_item	2895927	et	3	main
et	doc_802069853806_item	2895928	et	3	main
nagu	doc_802069853806_item	2895929	et	3	main
mul	doc_802069853806_item	2895938	et	3	main
hästi	doc_802069853806_item	2895947	et	3	main
oma	doc_802069853806_item	2895949	et	4	main
et	doc_802069853806_item	2895952	et	3	main
juba	doc_802069853806_item	2895953	et	3	main
milleks	doc_802069853806_item	2895958	et	4	main
mina	doc_802069853806_item	2895959	et	4	main
unistan	doc_802069853806_item	2895960	et	3	main
palju	doc_802069853806_item	2895961	et	4	main
aega	doc_802069853806_item	2895962	et	4	main
tahan	doc_802069853806_item	2895963	et	3	main
et	doc_802069853806_item	2895964	et	3	main
minu	doc_802069853806_item	2895965	et	3	main
perekond	doc_802069853806_item	2895966	et	3	main
minu	doc_802069853806_item	2895967	et	3	main
elu	doc_802069853806_item	2895978	et	4	main
et	doc_802069853806_item	2895985	et	3	main
sest	doc_802069853806_item	2895993	et	4	main
pole	doc_802069853806_item	2895994	et	3	main
need	doc_802069853806_item	2895995	et	3	main
ootan	doc_802069853806_item	2896008	et	3	main
leian	doc_802069853806_item	2896010	et	3	main
sõpru	doc_802069853806_item	2896012	et	3	main
eestis	doc_802069853806_item	2896014	et	3	main
ja	doc_802069853806_item	2896027	et	3	main
unistada	doc_802069853806_item	2896030	et	3	main
ootan	doc_802069853807_item	2896047	et	3	main
aastal	doc_802069853807_item	2896049	et	3	main
ma	doc_802069853807_item	2896051	et	3	main
mõtle	doc_802069853807_item	2896053	et	4	main
selle	doc_802069853807_item	2896054	et	4	main
lõpetad	doc_802069853807_item	2896066	et	3	main
siis	doc_802069853807_item	2896068	et	3	main
on	doc_802069853807_item	2896073	et	4	main
suvel	doc_802069853807_item	2896077	et	3	main
tahan	doc_802069853807_item	2896079	et	3	main
puhata	doc_802069853807_item	2896081	et	4	main
ja	doc_802069853807_item	2896082	et	3	main
koos	doc_802069853807_item	2896092	et	4	main
ja	doc_802069853807_item	2896095	et	3	main
veel	doc_802069853807_item	2896096	et	4	main
aastal	doc_802069853807_item	2896102	et	3	main
essee	doc_802069853808_item	2896103	et	4	main
ma	doc_802069853808_item	2896125	et	3	main
minna	doc_802069853808_item	2896127	et	3	main
kes	doc_802069853808_item	2896133	et	4	main
elab	doc_802069853808_item	2896134	et	3	main
türgis	doc_802069853808_item	2896135	et	4	main
mind	doc_802069853808_item	2896139	et	4	main
uues	doc_802069853808_item	2896143	et	3	main
müstamäes	doc_802069853808_item	2896150	et	4	main
ma	doc_802069853808_item	2896152	et	3	main
ma	doc_802069853808_item	2896166	et	3	main
seal	doc_802069853808_item	2896168	et	4	main
ma	doc_802069853808_item	2896170	et	3	main
et	doc_802069853808_item	2896180	et	3	main
bussis	doc_802069853808_item	2896184	et	3	main
ole	doc_802069853808_item	2896192	et	4	main
juhiluba	doc_802069853808_item	2896193	et	4	main
see	doc_802069853808_item	2896194	et	3	main
on	doc_802069853808_item	2896195	et	4	main
väga	doc_802069853808_item	2896196	et	3	main
kurb	doc_802069853808_item	2896197	et	3	main
ma	doc_802069853808_item	2896198	et	3	main
loodan	doc_802069853808_item	2896199	et	3	main
et	doc_802069853808_item	2896200	et	3	main
on	doc_802069853808_item	2896203	et	4	main
palju	doc_802069853809_item	2896215	et	4	main
inimesed	doc_802069853809_item	2896216	et	3	main
ootavad	doc_802069853809_item	2896217	et	4	main
et	doc_802069853809_item	2896218	et	3	main
uuel	doc_802069853809_item	2896219	et	3	main
ei	doc_802069853809_item	2896224	et	4	main
ootama	doc_802069853809_item	2896249	et	3	main
midagi	doc_802069853809_item	2896251	et	4	main
stabiilne	doc_802069853809_item	2896257	et	3	main
kõikidel	doc_802069853809_item	2896259	et	4	main
keda	doc_802069853809_item	2896260	et	4	main
ma	doc_802069853809_item	2896261	et	3	main
tean	doc_802069853809_item	2896262	et	3	main
elu	doc_802069853809_item	2896263	et	4	main
olla	doc_802069853809_item	2896269	et	3	main
et	doc_802069853809_item	2896270	et	3	main
mida	doc_802069853809_item	2896284	et	4	main
ma	doc_802069853809_item	2896285	et	3	main
lund	doc_802069853809_item	2896296	et	3	main
on	doc_802069853809_item	2896305	et	4	main
ei	doc_802069853809_item	2896310	et	4	main
meeldi	doc_802069853809_item	2896311	et	4	main
välja	doc_802069853809_item	2896316	et	4	main
suvilasse	doc_802069853809_item	2896317	et	4	main
palju	doc_802069853806_item	2896022	et	4	main
lootusi	doc_802069853806_item	2896023	et	4	main
uue	doc_802069853806_item	2896024	et	3	main
aasta	doc_802069853806_item	2896025	et	4	main
võiks	doc_802069853806_item	2896028	et	4	main
tulid	doc_802069853806_item	2896033	et	4	main
essee	doc_802069853807_item	2896035	et	4	main
täpselt	doc_802069853807_item	2896041	et	4	main
tea	doc_802069853807_item	2896044	et	4	main
uuelt	doc_802069853807_item	2896048	et	4	main
aga	doc_802069853807_item	2896050	et	3	main
ei	doc_802069853807_item	2896052	et	4	main
ma	doc_802069853807_item	2896064	et	3	main
hasti	doc_802069853807_item	2896067	et	4	main
ma	doc_802069853807_item	2896069	et	3	main
et	doc_802069853807_item	2896071	et	3	main
jõudu	doc_802069853807_item	2896075	et	4	main
ma	doc_802069853807_item	2896078	et	3	main
hasti	doc_802069853807_item	2896080	et	4	main
natuke	doc_802069853807_item	2896083	et	4	main
töötada	doc_802069853807_item	2896084	et	3	main
võib	doc_802069853807_item	2896085	et	3	main
olla	doc_802069853807_item	2896086	et	3	main
sõidan	doc_802069853807_item	2896087	et	3	main
minu	doc_802069853807_item	2896093	et	3	main
neijuga	doc_802069853807_item	2896094	et	4	main
ma	doc_802069853808_item	2896105	et	3	main
ootan	doc_802069853808_item	2896106	et	3	main
uues	doc_802069853808_item	2896107	et	3	main
aastas	doc_802069853808_item	2896108	et	3	main
uues	doc_802069853808_item	2896109	et	3	main
aastas	doc_802069853808_item	2896110	et	3	main
ma	doc_802069853808_item	2896111	et	3	main
ootan	doc_802069853808_item	2896112	et	3	main
palju	doc_802069853808_item	2896113	et	4	main
asju	doc_802069853808_item	2896114	et	3	main
ma	doc_802069853808_item	2896115	et	3	main
tahan	doc_802069853808_item	2896116	et	3	main
töötada	doc_802069853808_item	2896117	et	3	main
tegivderektorina	doc_802069853808_item	2896118	et	4	main
minu	doc_802069853808_item	2896119	et	3	main
mehest	doc_802069853808_item	2896120	et	4	main
uues	doc_802069853808_item	2896122	et	3	main
elada	doc_802069853808_item	2896142	et	3	main
sellepärast	doc_802069853808_item	2896145	et	3	main
et	doc_802069853808_item	2896146	et	3	main
minu	doc_802069853808_item	2896147	et	3	main
korter	doc_802069853808_item	2896148	et	3	main
asub	doc_802069853808_item	2896149	et	3	main
tahan	doc_802069853808_item	2896153	et	3	main
piritas	doc_802069853808_item	2896155	et	4	main
on	doc_802069853808_item	2896158	et	4	main
plaanis	doc_802069853808_item	2896159	et	4	main
kreekasse	doc_802069853808_item	2896160	et	4	main
või	doc_802069853808_item	2896161	et	4	main
juhiluba	doc_802069853808_item	2896178	et	4	main
sellepärast	doc_802069853808_item	2896179	et	3	main
ei	doc_802069853808_item	2896191	et	4	main
mida	doc_802069853809_item	2896208	et	4	main
aastal	doc_802069853809_item	2896220	et	3	main
seda	doc_802069853809_item	2896222	et	3	main
ma	doc_802069853809_item	2896228	et	3	main
sõpru	doc_802069853809_item	2896237	et	3	main
auto	doc_802069853809_item	2896239	et	4	main
ja	doc_802069853809_item	2896240	et	3	main
arvuti	doc_802069853809_item	2896241	et	4	main
et	doc_802069853809_item	2896242	et	3	main
teha	doc_802069853809_item	2896243	et	3	main
mitte	doc_802069853809_item	2896250	et	3	main
tahan	doc_802069853809_item	2896252	et	3	main
oleks	doc_802069853809_item	2896264	et	3	main
hea	doc_802069853809_item	2896265	et	4	main
ja	doc_802069853809_item	2896266	et	3	main
ainult	doc_802069853809_item	2896275	et	4	main
ühe	doc_802069853809_item	2896276	et	4	main
see	doc_802069853809_item	2896280	et	3	main
sjukune	doc_802069853809_item	2896282	et	4	main
asi	doc_802069853809_item	2896283	et	4	main
öelda	doc_802069853809_item	2896290	et	4	main
võib	doc_802069853809_item	2896291	et	3	main
olla	doc_802069853809_item	2896292	et	3	main
et	doc_802069853809_item	2896293	et	3	main
ma	doc_802069853809_item	2896294	et	3	main
ootan	doc_802069853809_item	2896295	et	3	main
ei	doc_802069853809_item	2896301	et	4	main
see	doc_802069853809_item	2896304	et	3	main
linnast	doc_802069853809_item	2896315	et	4	main
seal	doc_802069853809_item	2896321	et	4	main
vaadata	doc_802069853809_item	2896323	et	4	main
kuidas	doc_802069853809_item	2896324	et	3	main
ootan	doc_802069853810_item	2896353	et	3	main
ma	doc_802069853810_item	2896356	et	3	main
ma	doc_802069853810_item	2896359	et	3	main
et	doc_802069853810_item	2896363	et	3	main
uuel	doc_802069853810_item	2896364	et	3	main
aastal	doc_802069853810_item	2896365	et	3	main
tutvustan	doc_802069853810_item	2896366	et	3	main
uue	doc_802069853810_item	2896367	et	3	main
sest	doc_802069853810_item	2896373	et	4	main
ma	doc_802069853810_item	2896374	et	3	main
ei	doc_802069853810_item	2896375	et	4	main
kingitatakse	doc_802069853810_item	2896392	et	4	main
tahan	doc_802069853810_item	2896397	et	3	main
inglismaa	doc_802069853810_item	2896399	et	4	main
praktikeerida	doc_802069853810_item	2896401	et	4	main
ma	doc_802069853810_item	2896404	et	3	main
mitte	doc_802069853810_item	2896410	et	3	main
semptembrist	doc_802069853810_item	2896440	et	4	main
aasta	doc_802069853811_item	2896447	et	4	main
kahjuks	doc_802069853811_item	2896457	et	4	main
täitunud	doc_802069853811_item	2896458	et	4	main
uus	doc_802069853811_item	2896479	et	3	main
oleks	doc_802069853811_item	2896490	et	3	main
saaksin	doc_802069853811_item	2896493	et	3	main
on	doc_802069853811_item	2896498	et	4	main
vaja	doc_802069853811_item	2896499	et	4	main
praegu	doc_802069853811_item	2896500	et	3	main
palju	doc_802069853811_item	2896501	et	4	main
kõikide	doc_802069853811_item	2896508	et	4	main
toime	doc_802069853811_item	2896510	et	4	main
tahaks	doc_802069853811_item	2896511	et	3	main
ka	doc_802069853811_item	2896512	et	3	main
jääda	doc_802069853811_item	2896513	et	4	main
aitab	doc_802069853811_item	2896538	et	3	main
mul	doc_802069853811_item	2896547	et	3	main
tean	doc_802069853811_item	2896555	et	3	main
on	doc_802069853811_item	2896565	et	4	main
veel	doc_802069853811_item	2896570	et	4	main
kuhugi	doc_802069853811_item	2896571	et	4	main
puhkama	doc_802069853811_item	2896572	et	3	main
kooli	doc_802069853811_item	2896622	et	4	main
mul	doc_802069853808_item	2896186	et	3	main
aasta	doc_802069853808_item	2896202	et	4	main
parem	doc_802069853808_item	2896204	et	4	main
kui	doc_802069853808_item	2896205	et	3	main
eelmine	doc_802069853808_item	2896206	et	3	main
essee	doc_802069853809_item	2896207	et	4	main
toimub	doc_802069853809_item	2896221	et	3	main
aga	doc_802069853809_item	2896227	et	3	main
ei	doc_802069853809_item	2896229	et	4	main
mitte	doc_802069853809_item	2896231	et	3	main
midagi	doc_802069853809_item	2896232	et	4	main
häit	doc_802069853809_item	2896236	et	4	main
kodutööd	doc_802069853809_item	2896244	et	4	main
võin	doc_802069853809_item	2896248	et	3	main
ainult	doc_802069853809_item	2896253	et	4	main
et	doc_802069853809_item	2896254	et	3	main
kõik	doc_802069853809_item	2896255	et	4	main
oleks	doc_802069853809_item	2896256	et	3	main
et	doc_802069853809_item	2896258	et	3	main
rõõmus	doc_802069853809_item	2896267	et	4	main
ma	doc_802069853809_item	2896271	et	3	main
uuelt	doc_802069853809_item	2896273	et	4	main
asja	doc_802069853809_item	2896278	et	4	main
on	doc_802069853809_item	2896281	et	4	main
ole	doc_802069853809_item	2896302	et	4	main
sügis	doc_802069853809_item	2896306	et	3	main
sügis	doc_802069853809_item	2896308	et	3	main
ültse	doc_802069853809_item	2896312	et	4	main
tahan	doc_802069853809_item	2896313	et	3	main
sõita	doc_802069853809_item	2896314	et	3	main
aga	doc_802069853809_item	2896336	et	3	main
väga	doc_802069853809_item	2896339	et	3	main
ja	doc_802069853809_item	2896341	et	3	main
võib	doc_802069853809_item	2896346	et	3	main
sõbradega	doc_802069853810_item	2896368	et	4	main
taha	doc_802069853810_item	2896376	et	4	main
vanemad	doc_802069853810_item	2896379	et	4	main
maksasid	doc_802069853810_item	2896380	et	3	main
eest	doc_802069853810_item	2896382	et	4	main
mul	doc_802069853810_item	2896385	et	3	main
rohkem	doc_802069853810_item	2896387	et	4	main
suvel	doc_802069853810_item	2896396	et	3	main
külastada	doc_802069853810_item	2896398	et	3	main
tea	doc_802069853810_item	2896406	et	4	main
mina	doc_802069853810_item	2896407	et	4	main
ei	doc_802069853810_item	2896408	et	4	main
pea	doc_802069853810_item	2896430	et	4	main
ootama	doc_802069853810_item	2896431	et	3	main
uuelt	doc_802069853810_item	2896432	et	4	main
aastalt	doc_802069853810_item	2896433	et	3	main
essee	doc_802069853811_item	2896441	et	4	main
2006	doc_802069853811_item	2896448	et	2	main
lõpule	doc_802069853811_item	2896451	et	3	main
sooritan	doc_802069853811_item	2896485	et	3	main
hästi	doc_802069853811_item	2896489	et	3	main
hea	doc_802069853811_item	2896491	et	4	main
kui	doc_802069853811_item	2896492	et	3	main
ja	doc_802069853811_item	2896503	et	3	main
tulin	doc_802069853811_item	2896507	et	3	main
käima	doc_802069853811_item	2896521	et	4	main
oma	doc_802069853811_item	2896524	et	4	main
teadmisi	doc_802069853811_item	2896527	et	4	main
seotud	doc_802069853811_item	2896532	et	4	main
minu	doc_802069853811_item	2896533	et	3	main
erialaga	doc_802069853811_item	2896534	et	3	main
loodan	doc_802069853811_item	2896535	et	3	main
et	doc_802069853811_item	2896536	et	3	main
mis	doc_802069853811_item	2896544	et	4	main
pole	doc_802069853811_item	2896548	et	3	main
mingeid	doc_802069853811_item	2896551	et	3	main
minna	doc_802069853811_item	2896554	et	3	main
kindlasti	doc_802069853811_item	2896559	et	3	main
juuli	doc_802069853811_item	2896561	et	4	main
lõpus	doc_802069853811_item	2896562	et	4	main
perekonna	doc_802069853811_item	2896567	et	4	main
tahaks	doc_802069853811_item	2896569	et	3	main
praegu	doc_802069853811_item	2896575	et	3	main
öelda	doc_802069853811_item	2896578	et	4	main
erinevaid	doc_802069853811_item	2896591	et	4	main
seotud	doc_802069853811_item	2896621	et	4	main
jõudis	doc_802069853811_item	2896627	et	3	main
lõpule	doc_802069853811_item	2896628	et	3	main
aga	doc_802069853808_item	2896190	et	3	main
uus	doc_802069853808_item	2896201	et	3	main
aasta	doc_802069853809_item	2896214	et	4	main
mida	doc_802069853809_item	2896223	et	4	main
toimunud	doc_802069853809_item	2896225	et	4	main
mul	doc_802069853809_item	2896233	et	3	main
on	doc_802069853809_item	2896234	et	4	main
oma	doc_802069853809_item	2896238	et	4	main
mida	doc_802069853809_item	2896245	et	4	main
ma	doc_802069853809_item	2896247	et	3	main
võib	doc_802069853809_item	2896268	et	3	main
ootan	doc_802069853809_item	2896272	et	3	main
aastalt	doc_802069853809_item	2896274	et	3	main
aga	doc_802069853809_item	2896279	et	3	main
taha	doc_802069853809_item	2896287	et	4	main
mitte	doc_802069853809_item	2896288	et	3	main
keegile	doc_802069853809_item	2896289	et	4	main
talve	doc_802069853809_item	2896298	et	4	main
mulle	doc_802069853809_item	2896309	et	4	main
ja	doc_802069853809_item	2896322	et	3	main
vabandage	doc_802069853809_item	2896329	et	3	main
et	doc_802069853809_item	2896330	et	3	main
sjukune	doc_802069853809_item	2896333	et	4	main
veel	doc_802069853809_item	2896345	et	4	main
kirjutada	doc_802069853809_item	2896347	et	3	main
mida	doc_802069853810_item	2896351	et	4	main
aastalt	doc_802069853810_item	2896355	et	3	main
loodan	doc_802069853810_item	2896357	et	3	main
soritan	doc_802069853810_item	2896360	et	4	main
eksameid	doc_802069853810_item	2896361	et	3	main
hästi	doc_802069853810_item	2896362	et	3	main
leidan	doc_802069853810_item	2896370	et	4	main
töökohta	doc_802069853810_item	2896372	et	4	main
et	doc_802069853810_item	2896377	et	3	main
minu	doc_802069853810_item	2896378	et	3	main
tahan	doc_802069853810_item	2896383	et	3	main
et	doc_802069853810_item	2896384	et	3	main
autot	doc_802069853810_item	2896395	et	3	main
rääkimises	doc_802069853810_item	2896402	et	4	main
ainult	doc_802069853810_item	2896421	et	4	main
hakkan	doc_802069853810_item	2896423	et	3	main
mitte	doc_802069853810_item	2896434	et	3	main
midagi	doc_802069853810_item	2896435	et	4	main
mida	doc_802069853811_item	2896442	et	4	main
ma	doc_802069853811_item	2896443	et	3	main
ootan	doc_802069853811_item	2896444	et	3	main
mõned	doc_802069853811_item	2896452	et	3	main
ja	doc_802069853811_item	2896454	et	3	main
ootused	doc_802069853811_item	2896455	et	3	main
eksamisessioonist	doc_802069853811_item	2896482	et	3	main
õppida	doc_802069853811_item	2896502	et	3	main
õppeainetega	doc_802069853811_item	2896509	et	3	main
kui	doc_802069853811_item	2896516	et	3	main
avaneb	doc_802069853811_item	2896518	et	3	main
praktikal	doc_802069853811_item	2896520	et	3	main
mingil	doc_802069853811_item	2896528	et	4	main
töökohal	doc_802069853811_item	2896529	et	4	main
praktika	doc_802069853811_item	2896537	et	4	main
mul	doc_802069853811_item	2896539	et	3	main
puutub	doc_802069853811_item	2896545	et	3	main
mitte	doc_802069853811_item	2896550	et	3	main
ideeid	doc_802069853811_item	2896552	et	4	main
kuhu	doc_802069853811_item	2896553	et	3	main
ukrainasse	doc_802069853811_item	2896560	et	4	main
sest	doc_802069853811_item	2896563	et	4	main
see	doc_802069853811_item	2896564	et	3	main
minna	doc_802069853811_item	2896573	et	3	main
või	doc_802069853811_item	2896583	et	4	main
aasta	doc_802069853811_item	2896585	et	4	main
2006	doc_802069853811_item	2896586	et	2	main
oli	doc_802069853811_item	2896587	et	3	main
natuke	doc_802069853811_item	2896648	et	4	main
omaette	doc_802069853811_item	2896651	et	3	main
tulevikus	doc_802069853811_item	2896655	et	4	main
veel	doc_802069853811_item	2896657	et	4	main
vaatame	doc_802069853811_item	2896666	et	3	main
mulle	doc_802069853811_item	2896669	et	4	main
järgmine	doc_802069853811_item	2896670	et	3	main
alati	doc_802069853811_item	2896697	et	4	main
siis	doc_802069853811_item	2896701	et	3	main
isegi	doc_802069853811_item	2896703	et	4	main
vabariigi	doc_804074096014_item	2896722	et	3	main
eelmisel	doc_802069853809_item	2896226	et	3	main
otta	doc_802069853809_item	2896230	et	4	main
palju	doc_802069853809_item	2896235	et	4	main
veel	doc_802069853809_item	2896246	et	4	main
pisikest	doc_802069853809_item	2896277	et	4	main
ei	doc_802069853809_item	2896286	et	4	main
sest	doc_802069853809_item	2896297	et	4	main
ilma	doc_802069853809_item	2896299	et	4	main
lunda	doc_802069853809_item	2896300	et	4	main
talve	doc_802069853809_item	2896303	et	4	main
aga	doc_802069853809_item	2896307	et	3	main
ja	doc_802069853809_item	2896318	et	3	main
ainult	doc_802069853809_item	2896319	et	4	main
olla	doc_802069853809_item	2896320	et	3	main
lund	doc_802069853809_item	2896325	et	3	main
sajab	doc_802069853809_item	2896326	et	3	main
ps	doc_802069853809_item	2896327	et	4	main
palun	doc_802069853809_item	2896328	et	3	main
mul	doc_802069853809_item	2896331	et	3	main
olen	doc_802069853809_item	2896338	et	3	main
väsinud	doc_802069853809_item	2896340	et	4	main
ei	doc_802069853809_item	2896342	et	4	main
tea	doc_802069853809_item	2896343	et	4	main
mida	doc_802069853809_item	2896344	et	4	main
essee	doc_802069853810_item	2896350	et	4	main
ma	doc_802069853810_item	2896352	et	3	main
uuelt	doc_802069853810_item	2896354	et	4	main
et	doc_802069853810_item	2896358	et	3	main
oleks	doc_802069853810_item	2896386	et	3	main
sularaha	doc_802069853810_item	2896388	et	4	main
loodan	doc_802069853810_item	2896389	et	3	main
et	doc_802069853810_item	2896390	et	3	main
vanemad	doc_802069853810_item	2896391	et	4	main
praegu	doc_802069853810_item	2896403	et	3	main
ei	doc_802069853810_item	2896405	et	4	main
on	doc_802069853809_item	2896332	et	4	main
kurb	doc_802069853809_item	2896334	et	3	main
esse	doc_802069853809_item	2896335	et	3	main
ma	doc_802069853809_item	2896337	et	3	main
j	doc_802069853809_item	2896348	et	4	main
l	doc_802069853809_item	2896349	et	4	main
et	doc_802069853810_item	2896369	et	3	main
hea	doc_802069853810_item	2896371	et	4	main
minu	doc_802069853810_item	2896381	et	3	main
mulle	doc_802069853810_item	2896393	et	4	main
uut	doc_802069853810_item	2896394	et	3	main
et	doc_802069853810_item	2896400	et	3	main
oota	doc_802069853810_item	2896409	et	4	main
midagi	doc_802069853810_item	2896411	et	4	main
uuelt	doc_802069853810_item	2896412	et	4	main
aastalt	doc_802069853810_item	2896413	et	3	main
kõik	doc_802069853810_item	2896414	et	4	main
sõltub	doc_802069853810_item	2896415	et	3	main
eksamitest	doc_802069853810_item	2896416	et	4	main
vaatan	doc_802069853810_item	2896417	et	3	main
kuidas	doc_802069853810_item	2896418	et	3	main
soritan	doc_802069853810_item	2896419	et	4	main
ja	doc_802069853810_item	2896420	et	3	main
pärast	doc_802069853810_item	2896422	et	4	main
soritan	doc_802069853810_item	2896426	et	4	main
halvasti	doc_802069853810_item	2896427	et	3	main
siis	doc_802069853810_item	2896428	et	3	main
hea	doc_802069853810_item	2896436	et	4	main
vaatan	doc_802069853810_item	2896437	et	3	main
uuelt	doc_802069853811_item	2896445	et	4	main
aastalt	doc_802069853811_item	2896446	et	3	main
läheneb	doc_802069853811_item	2896449	et	3	main
unistused	doc_802069853811_item	2896453	et	4	main
pole	doc_802069853811_item	2896456	et	3	main
lase	doc_802069853811_item	2896463	et	4	main
nukrutseda	doc_802069853811_item	2896464	et	3	main
et	doc_802069853811_item	2896484	et	3	main
eksameid	doc_802069853811_item	2896487	et	3	main
selleks	doc_802069853811_item	2896497	et	4	main
endale	doc_802069853811_item	2896505	et	4	main
riigieelarvelisel	doc_802069853811_item	2896514	et	4	main
kindlasti	doc_802069853811_item	2896523	et	3	main
jõudu	doc_802069853811_item	2896525	et	4	main
ja	doc_802069853811_item	2896526	et	3	main
on	doc_802069853811_item	2896531	et	4	main
sukelduda	doc_802069853811_item	2896543	et	3	main
puhkust	doc_802069853811_item	2896546	et	4	main
praegu	doc_802069853811_item	2896549	et	3	main
täpselt	doc_802069853811_item	2896556	et	4	main
sõidan	doc_802069853811_item	2896558	et	3	main
minu	doc_802069853811_item	2896566	et	3	main
traditsioon	doc_802069853811_item	2896568	et	3	main
kuid	doc_802069853811_item	2896574	et	4	main
raske	doc_802069853811_item	2896588	et	4	main
see	doc_802069853811_item	2896589	et	3	main
oli	doc_802069853811_item	2896590	et	3	main
õppimine	doc_802069853811_item	2896634	et	4	main
ootan	doc_802069853811_item	2896635	et	3	main
uuelt	doc_802069853811_item	2896636	et	4	main
aastalt	doc_802069853811_item	2896637	et	3	main
seda	doc_802069853811_item	2896638	et	3	main
et	doc_802069853811_item	2896639	et	3	main
see	doc_802069853811_item	2896640	et	3	main
on	doc_802069853811_item	2896641	et	4	main
enne	doc_802069853811_item	2896650	et	4	main
elamist	doc_802069853811_item	2896652	et	4	main
tean	doc_802069853811_item	2896653	et	3	main
et	doc_802069853811_item	2896654	et	3	main
tuleb	doc_802069853811_item	2896656	et	3	main
nendeks	doc_802069853811_item	2896665	et	4	main
toob	doc_802069853811_item	2896668	et	3	main
edu	doc_802069853811_item	2896680	et	4	main
planeerida	doc_802069853810_item	2896424	et	3	main
kui	doc_802069853810_item	2896425	et	3	main
ei	doc_802069853810_item	2896429	et	4	main
pärast	doc_802069853810_item	2896438	et	4	main
20	doc_802069853810_item	2896439	et	2	main
juba	doc_802069853811_item	2896450	et	3	main
kuid	doc_802069853811_item	2896459	et	4	main
reibas	doc_802069853811_item	2896460	et	3	main
jõulumeeleolu	doc_802069853811_item	2896461	et	4	main
ei	doc_802069853811_item	2896462	et	4	main
aegapidi	doc_802069853811_item	2896465	et	3	main
koostan	doc_802069853811_item	2896466	et	3	main
ma	doc_802069853811_item	2896467	et	3	main
erinevaid	doc_802069853811_item	2896468	et	4	main
plaane	doc_802069853811_item	2896469	et	3	main
järgmiseks	doc_802069853811_item	2896470	et	3	main
aastaks	doc_802069853811_item	2896471	et	4	main
praegu	doc_802069853811_item	2896472	et	3	main
esimesel	doc_802069853811_item	2896473	et	3	main
kohal	doc_802069853811_item	2896474	et	4	main
on	doc_802069853811_item	2896475	et	4	main
mul	doc_802069853811_item	2896476	et	3	main
õppimine	doc_802069853811_item	2896477	et	4	main
ülikoolis	doc_802069853811_item	2896478	et	4	main
aasta	doc_802069853811_item	2896480	et	4	main
algab	doc_802069853811_item	2896481	et	3	main
loodan	doc_802069853811_item	2896483	et	3	main
kõiki	doc_802069853811_item	2896486	et	4	main
väga	doc_802069853811_item	2896488	et	3	main
iga	doc_802069853811_item	2896494	et	4	main
kuu	doc_802069853811_item	2896495	et	4	main
stipendiumit	doc_802069853811_item	2896496	et	3	main
tõestada	doc_802069853811_item	2896504	et	3	main
et	doc_802069853811_item	2896506	et	3	main
kohal	doc_802069853811_item	2896515	et	4	main
kevadel	doc_802069853811_item	2896517	et	4	main
võimalus	doc_802069853811_item	2896519	et	3	main
proovin	doc_802069853811_item	2896522	et	3	main
mis	doc_802069853811_item	2896530	et	4	main
veel	doc_802069853811_item	2896540	et	4	main
sügavalt	doc_802069853811_item	2896541	et	4	main
õppetöösse	doc_802069853811_item	2896542	et	3	main
et	doc_802069853811_item	2896557	et	3	main
on	doc_802069853811_item	2896576	et	4	main
raske	doc_802069853811_item	2896577	et	4	main
kas	doc_802069853811_item	2896579	et	3	main
täitub	doc_802069853811_item	2896580	et	3	main
see	doc_802069853811_item	2896581	et	3	main
soov	doc_802069853811_item	2896582	et	3	main
mitte	doc_802069853811_item	2896584	et	3	main
sündmusi	doc_802069853811_item	2896592	et	3	main
täis	doc_802069853811_item	2896593	et	4	main
oli	doc_802069853811_item	2896594	et	3	main
nii	doc_802069853811_item	2896595	et	3	main
halba	doc_802069853811_item	2896596	et	4	main
kui	doc_802069853811_item	2896597	et	3	main
ka	doc_802069853811_item	2896598	et	3	main
head	doc_802069853811_item	2896599	et	4	main
ma	doc_802069853811_item	2896600	et	3	main
tean	doc_802069853811_item	2896601	et	3	main
et	doc_802069853811_item	2896602	et	3	main
õnnetusi	doc_802069853811_item	2896603	et	4	main
on	doc_802069853811_item	2896604	et	4	main
raske	doc_802069853811_item	2896605	et	4	main
vältida	doc_802069853811_item	2896606	et	3	main
kuid	doc_802069853811_item	2896607	et	4	main
loodan	doc_802069853811_item	2896608	et	3	main
et	doc_802069853811_item	2896609	et	3	main
tulevikus	doc_802069853811_item	2896610	et	4	main
on	doc_802069853811_item	2896611	et	4	main
neid	doc_802069853811_item	2896612	et	4	main
vähem	doc_802069853811_item	2896613	et	4	main
see	doc_802069853811_item	2896614	et	3	main
aasta	doc_802069853811_item	2896615	et	4	main
oli	doc_802069853811_item	2896616	et	3	main
liiga	doc_802069853811_item	2896617	et	4	main
pingeline	doc_802069853811_item	2896618	et	4	main
sest	doc_802069853811_item	2896619	et	4	main
oli	doc_802069853811_item	2896620	et	3	main
üks	doc_802069853811_item	2896624	et	3	main
palju	doc_802069853811_item	2896658	et	4	main
raskeid	doc_802069853811_item	2896659	et	3	main
katsumusi	doc_802069853811_item	2896660	et	3	main
ja	doc_802069853811_item	2896661	et	3	main
seepärast	doc_802069853811_item	2896662	et	3	main
valmistun	doc_802069853811_item	2896663	et	3	main
mõttes	doc_802069853811_item	2896664	et	3	main
mida	doc_802069853811_item	2896667	et	4	main
mind	doc_802069853811_item	2896675	et	4	main
tulevikus	doc_802069853811_item	2896676	et	4	main
tahaks	doc_802069853811_item	2896677	et	3	main
kõikidele	doc_802069853811_item	2896678	et	4	main
elus	doc_802069853811_item	2896682	et	4	main
aastal	doc_802069853811_item	2896685	et	3	main
seda	doc_802069853811_item	2896689	et	3	main
igaüks	doc_802069853811_item	2896691	et	3	main
endasse	doc_802069853811_item	2896693	et	4	main
ja	doc_802069853811_item	2896694	et	3	main
oma	doc_802069853811_item	2896695	et	4	main
võidusse	doc_802069853811_item	2896696	et	4	main
ainult	doc_802069853811_item	2896700	et	4	main
kultuurielu	doc_804074096014_item	2896714	et	4	main
2	doc_804074096014_item	2896715	et	2	main
sotsialistlik	doc_804074096014_item	2896716	et	3	main
kui	doc_804074096014_item	2896718	et	3	main
realism	doc_804074096014_item	2896717	et	3	main
kirjandusvool	doc_804074096014_item	2896719	et	4	main
1	doc_804074096014_item	2896720	et	2	main
aja	doc_804074096014_item	2896730	et	4	main
jööksul	doc_804074096014_item	2896731	et	4	main
eesti	doc_804074096014_item	2896737	et	4	main
rahvas	doc_804074096014_item	2896738	et	4	main
püüdis	doc_804074096014_item	2896739	et	3	main
ja	doc_804074096014_item	2896746	et	3	main
arendadi	doc_804074096014_item	2896750	et	4	main
kõikidel	doc_804074096014_item	2896752	et	4	main
oli	doc_804074096014_item	2896753	et	3	main
õppimine	doc_804074096014_item	2896763	et	4	main
eestis	doc_804074096014_item	2896766	et	3	main
loodut	doc_804074096014_item	2896778	et	4	main
õpetajate	doc_804074096014_item	2896779	et	4	main
selts	doc_804074096014_item	2896780	et	3	main
kirjanike	doc_804074096014_item	2896781	et	3	main
isegi	doc_804074096014_item	2896822	et	4	main
kinodes	doc_804074096014_item	2896831	et	3	main
märgata	doc_804074096014_item	2896834	et	4	main
veel	doc_804074096014_item	2896844	et	4	main
noor	doc_804074096014_item	2896845	et	3	main
oli	doc_804074096014_item	2896847	et	3	main
tuli	doc_804074096014_item	2896861	et	4	main
nüüd	doc_804074096014_item	2896867	et	4	main
haridust	doc_804074096014_item	2896870	et	4	main
omas	doc_804074096014_item	2896871	et	4	main
keeles	doc_804074096014_item	2896872	et	4	main
1945	doc_804074096014_item	2896873	et	2	main
aastal	doc_804074096014_item	2896874	et	3	main
nõukogulike	doc_804074096014_item	2896881	et	3	main
perekondadest	doc_804074096014_item	2896920	et	3	main
nüüd	doc_804074096014_item	2896930	et	4	main
kirjanike	doc_804074096014_item	2896936	et	3	main
suur	doc_804074096014_item	2896939	et	3	main
toimub	doc_804074096014_item	2896941	et	3	main
terror	doc_804074096014_item	2896952	et	3	main
keelati	doc_804074096014_item	2896955	et	4	main
voole	doc_804074096014_item	2896957	et	4	main
ev	doc_804074096014_item	2896965	et	4	main
2	doc_804074096014_item	2896967	et	2	main
1970ndate	doc_819690035128_item	2897009	et	4	main
kellel	doc_819690035128_item	2897013	et	4	main
on	doc_819690035128_item	2897014	et	4	main
või	doc_819690035128_item	2897021	et	4	main
tammsaare	doc_819690035128_item	2897023	et	3	main
ma	doc_819690035128_item	2897024	et	3	main
põhjendage	doc_819690035128_item	2897027	et	3	main
lõpetamisega	doc_802069853811_item	2896623	et	4	main
suur	doc_802069853811_item	2896625	et	3	main
ajavahemik	doc_802069853811_item	2896626	et	3	main
puhata	doc_802069853811_item	2896649	et	4	main
ootavad	doc_802069853811_item	2896674	et	4	main
ja	doc_802069853811_item	2896681	et	3	main
järgmisel	doc_802069853811_item	2896684	et	3	main
ja	doc_802069853811_item	2896686	et	3	main
uskuma	doc_802069853811_item	2896698	et	3	main
võimatut	doc_802069853811_item	2896704	et	4	main
saavutada	doc_802069853811_item	2896705	et	3	main
maal	doc_804074096014_item	2896736	et	4	main
arendada	doc_804074096014_item	2896745	et	3	main
koolis	doc_804074096014_item	2896757	et	4	main
seltsid	doc_804074096014_item	2896776	et	4	main
oli	doc_804074096014_item	2896777	et	3	main
kultuuri	doc_804074096014_item	2896785	et	4	main
mängis	doc_804074096014_item	2896788	et	3	main
käis	doc_804074096014_item	2896829	et	4	main
teadlastest	doc_804074096014_item	2896851	et	3	main
keeleteadust	doc_804074096014_item	2896857	et	4	main
kutsuti	doc_804074096014_item	2896858	et	3	main
spetsialiste	doc_804074096014_item	2896859	et	3	main
välismaalt	doc_804074096014_item	2896860	et	3	main
oluliselt	doc_804074096014_item	2896878	et	4	main
järgi	doc_804074096014_item	2896883	et	4	main
ja	doc_802069853811_item	2896629	et	3	main
algas	doc_802069853811_item	2896630	et	3	main
uus	doc_802069853811_item	2896631	et	3	main
eluperiood	doc_802069853811_item	2896632	et	3	main
ülikoolis	doc_802069853811_item	2896633	et	4	main
rahulikum	doc_802069853811_item	2896642	et	4	main
kui	doc_802069853811_item	2896643	et	3	main
kõik	doc_802069853811_item	2896644	et	4	main
eelmised	doc_802069853811_item	2896645	et	3	main
aastad	doc_802069853811_item	2896646	et	3	main
tahaks	doc_802069853811_item	2896647	et	3	main
aasta	doc_802069853811_item	2896671	et	4	main
millised	doc_802069853811_item	2896672	et	3	main
üllatused	doc_802069853811_item	2896673	et	4	main
soovida	doc_802069853811_item	2896679	et	4	main
ensv	doc_804074096014_item	2896712	et	4	main
pärastsõjajärgset	doc_804074096014_item	2896713	et	3	main
eesti	doc_804074096014_item	2896721	et	4	main
ajal	doc_804074096014_item	2896723	et	4	main
kultuuriline	doc_804074096014_item	2896724	et	4	main
kasv	doc_804074096014_item	2896725	et	3	main
oli	doc_804074096014_item	2896726	et	3	main
valitsesid	doc_804074096014_item	2896732	et	4	main
kõike	doc_804074096014_item	2896740	et	4	main
teha	doc_804074096014_item	2896741	et	3	main
et	doc_804074096014_item	2896742	et	3	main
teha	doc_804074096014_item	2896747	et	3	main
nüüd	doc_804074096014_item	2896754	et	4	main
3haruline	doc_804074096014_item	2896762	et	4	main
prestiižseks	doc_804074096014_item	2896765	et	2	main
väga	doc_804074096014_item	2896768	et	3	main
palju	doc_804074096014_item	2896769	et	4	main
teised	doc_804074096014_item	2896784	et	4	main
teaduses	doc_804074096014_item	2896832	et	3	main
ka	doc_804074096014_item	2896835	et	3	main
oli	doc_804074096014_item	2896838	et	3	main
tunda	doc_804074096014_item	2896848	et	3	main
eesti	doc_804074096014_item	2896852	et	4	main
terminoloogiast	doc_804074096014_item	2896854	et	3	main
püüdi	doc_804074096014_item	2896855	et	4	main
arendada	doc_804074096014_item	2896856	et	3	main
pisirahvastel	doc_804074096014_item	2896865	et	4	main
oli	doc_804074096014_item	2896866	et	3	main
saada	doc_804074096014_item	2896869	et	4	main
arenes	doc_804074096014_item	2896880	et	3	main
ja	doc_804074096014_item	2896918	et	3	main
aga	doc_804074096014_item	2896921	et	3	main
ka	doc_804074096014_item	2896923	et	3	main
linnas	doc_804074096014_item	2896931	et	4	main
toimus	doc_804074096014_item	2896938	et	3	main
raamatu	doc_804074096014_item	2896943	et	4	main
osa	doc_804074096014_item	2896946	et	4	main
ideoloogiline	doc_804074096014_item	2896951	et	4	main
kultuuri	doc_804074096014_item	2896959	et	4	main
arendamine	doc_804074096014_item	2896960	et	4	main
oli	doc_804074096014_item	2896961	et	3	main
ajaga	doc_804074096014_item	2896966	et	3	main
sotsialistlik	doc_804074096014_item	2896968	et	3	main
nõukogude	doc_804074096014_item	2896999	et	3	main
eesti	doc_819690035128_item	2897010	et	4	main
erikal	doc_819690035128_item	2897020	et	4	main
vedamist	doc_802069853811_item	2896683	et	4	main
tuletama	doc_802069853811_item	2896687	et	3	main
meelde	doc_802069853811_item	2896688	et	3	main
et	doc_802069853811_item	2896690	et	3	main
peab	doc_802069853811_item	2896692	et	4	main
ja	doc_802069853811_item	2896699	et	3	main
saab	doc_802069853811_item	2896702	et	3	main
kontrolltöö	doc_804074096014_item	2896706	et	4	main
1	doc_804074096014_item	2896707	et	2	main
võrrelge	doc_804074096014_item	2896708	et	3	main
ev	doc_804074096014_item	2896709	et	4	main
aegset	doc_804074096014_item	2896710	et	3	main
ja	doc_804074096014_item	2896711	et	3	main
pika	doc_804074096014_item	2896729	et	4	main
kultuuri	doc_804074096014_item	2896744	et	4	main
võimalik	doc_804074096014_item	2896755	et	3	main
eesti	doc_804074096014_item	2896758	et	4	main
keeles	doc_804074096014_item	2896759	et	4	main
koolisüsteem	doc_804074096014_item	2896760	et	3	main
oli	doc_804074096014_item	2896761	et	3	main
muutus	doc_804074096014_item	2896764	et	4	main
oli	doc_804074096014_item	2896767	et	3	main
tollaste	doc_804074096014_item	2896773	et	3	main
euroopaga	doc_804074096014_item	2896774	et	3	main
kujunesid	doc_804074096014_item	2896775	et	4	main
liit	doc_804074096014_item	2896782	et	3	main
see	doc_804074096014_item	2896787	et	3	main
suurt	doc_804074096014_item	2896789	et	3	main
rolli	doc_804074096014_item	2896790	et	4	main
riik	doc_804074096014_item	2896791	et	3	main
andis	doc_804074096014_item	2896792	et	3	main
kultuuriga	doc_804074096014_item	2896793	et	4	main
tegelevatele	doc_804074096014_item	2896794	et	4	main
inimestele	doc_804074096014_item	2896795	et	3	main
küllaltki	doc_804074096014_item	2896796	et	4	main
suurt	doc_804074096014_item	2896797	et	3	main
ruumi	doc_804074096014_item	2896798	et	4	main
tegutsemiseks	doc_804074096014_item	2896799	et	4	main
eriti	doc_804074096014_item	2896800	et	3	main
püüdliketele	doc_804074096014_item	2896801	et	4	main
anti	doc_804074096014_item	2896802	et	3	main
preemijaid	doc_804074096014_item	2896803	et	4	main
ja	doc_804074096014_item	2896804	et	3	main
saadeti	doc_804074096014_item	2896805	et	3	main
välismaale	doc_804074096014_item	2896806	et	4	main
õpima	doc_804074096014_item	2896807	et	4	main
riik	doc_804074096014_item	2896808	et	3	main
igatepidi	doc_804074096014_item	2896809	et	4	main
soodustas	doc_804074096014_item	2896810	et	3	main
kultuuri	doc_804074096014_item	2896811	et	4	main
arengut	doc_804074096014_item	2896812	et	3	main
väga	doc_804074096014_item	2896813	et	3	main
tähtsateks	doc_804074096014_item	2896814	et	3	main
said	doc_804074096014_item	2896815	et	4	main
kinod	doc_804074096014_item	2896816	et	3	main
ja	doc_804074096014_item	2896817	et	3	main
teatred	doc_804074096014_item	2896818	et	4	main
igas	doc_804074096014_item	2896819	et	3	main
linnas	doc_804074096014_item	2896820	et	4	main
suurtemas	doc_804074096014_item	2896823	et	3	main
külades	doc_804074096014_item	2896824	et	3	main
oli	doc_804074096014_item	2896825	et	3	main
küllatki	doc_804074096014_item	2896727	et	4	main
suur	doc_804074096014_item	2896728	et	3	main
nüüd	doc_804074096014_item	2896733	et	4	main
eestlased	doc_804074096014_item	2896734	et	3	main
omal	doc_804074096014_item	2896735	et	3	main
oma	doc_804074096014_item	2896743	et	4	main
seda	doc_804074096014_item	2896748	et	3	main
omapäraseks	doc_804074096014_item	2896749	et	4	main
haridust	doc_804074096014_item	2896751	et	4	main
õpida	doc_804074096014_item	2896756	et	4	main
haritlasi	doc_804074096014_item	2896770	et	3	main
inimesi	doc_804074096014_item	2896771	et	4	main
võrreldes	doc_804074096014_item	2896772	et	3	main
ja	doc_804074096014_item	2896783	et	3	main
arenemisel	doc_804074096014_item	2896786	et	4	main
ja	doc_804074096014_item	2896821	et	3	main
oma	doc_804074096014_item	2896826	et	4	main
palju	doc_804074096014_item	2896830	et	4	main
kasvu	doc_804074096014_item	2896836	et	4	main
kuigi	doc_804074096014_item	2896837	et	3	main
ja	doc_804074096014_item	2896846	et	3	main
puudu	doc_804074096014_item	2896849	et	4	main
keelest	doc_804074096014_item	2896853	et	4	main
väherahvuste	doc_804074096014_item	2896863	et	3	main
seadus	doc_804074096014_item	2896864	et	4	main
võimalik	doc_804074096014_item	2896868	et	3	main
eesti	doc_804074096014_item	2896876	et	4	main
kultuur	doc_804074096014_item	2896877	et	3	main
olid	doc_804074096014_item	2896884	et	4	main
keelatud	doc_804074096014_item	2896885	et	4	main
kõik	doc_804074096014_item	2896886	et	4	main
seltsid	doc_804074096014_item	2896887	et	4	main
paljud	doc_804074096014_item	2896888	et	3	main
väljaanned	doc_804074096014_item	2896889	et	4	main
olid	doc_804074096014_item	2896890	et	4	main
samuti	doc_804074096014_item	2896891	et	3	main
keelatud	doc_804074096014_item	2896892	et	4	main
kõik	doc_804074096014_item	2896893	et	4	main
oli	doc_804074096014_item	2896894	et	3	main
riigi	doc_804074096014_item	2896895	et	3	main
kontrolli	doc_804074096014_item	2896896	et	4	main
all	doc_804074096014_item	2896897	et	3	main
said	doc_804074096014_item	2896898	et	4	main
kannatada	doc_804074096014_item	2896899	et	3	main
ka	doc_804074096014_item	2896900	et	3	main
eesti	doc_804074096014_item	2896901	et	4	main
koolid	doc_804074096014_item	2896902	et	3	main
venestumis	doc_804074096014_item	2896903	et	4	main
poliitika	doc_804074096014_item	2896904	et	4	main
raske	doc_804074096014_item	2896905	et	4	main
oli	doc_804074096014_item	2896906	et	3	main
ka	doc_804074096014_item	2896907	et	3	main
endistest	doc_804074096014_item	2896908	et	4	main
perekondadest	doc_804074096014_item	2896910	et	3	main
lastel	doc_804074096014_item	2896911	et	4	main
sest	doc_804074096014_item	2896912	et	4	main
rikadest	doc_804074096014_item	2896909	et	4	main
kooli	doc_804074096014_item	2896913	et	4	main
võtmisel	doc_804074096014_item	2896914	et	4	main
eelistati	doc_804074096014_item	2896915	et	4	main
lapsi	doc_804074096014_item	2896916	et	4	main
töö-	doc_804074096014_item	2896917	et	4	main
teater	doc_804074096014_item	2896827	et	3	main
rahvas	doc_804074096014_item	2896828	et	4	main
oli	doc_804074096014_item	2896833	et	3	main
palju	doc_804074096014_item	2896839	et	4	main
probleeme	doc_804074096014_item	2896840	et	3	main
sest	doc_804074096014_item	2896841	et	4	main
riik	doc_804074096014_item	2896842	et	3	main
oli	doc_804074096014_item	2896843	et	3	main
eesti	doc_804074096014_item	2896850	et	4	main
välja	doc_804074096014_item	2896862	et	4	main
muutus	doc_804074096014_item	2896875	et	4	main
ta	doc_804074096014_item	2896879	et	4	main
kultuurmudeli	doc_804074096014_item	2896882	et	3	main
hetki	doc_804074096014_item	2896925	et	4	main
said	doc_804074096014_item	2896928	et	4	main
õpida	doc_804074096014_item	2896929	et	4	main
pansione	doc_804074096014_item	2896935	et	3	main
ilukirjandusest	doc_804074096014_item	2896947	et	4	main
oli	doc_804074096014_item	2896948	et	3	main
ära	doc_804074096014_item	2896949	et	4	main
oli	doc_804074096014_item	2896953	et	3	main
palju	doc_804074096014_item	2896956	et	4	main
piiratud	doc_804074096014_item	2896963	et	4	main
kolhoodest	doc_804074096014_item	2896975	et	4	main
korra	doc_804074096014_item	2897000	et	4	main
vastu	doc_804074096014_item	2897001	et	3	main
hävitati	doc_804074096014_item	2897002	et	3	main
kontrolltöö	doc_819690035128_item	2897003	et	4	main
1	doc_819690035128_item	2897004	et	2	main
2	doc_819690035128_item	2897012	et	2	main
teie	doc_819690035128_item	2897015	et	4	main
oskaril	doc_819690035128_item	2897022	et	4	main
armastasin	doc_819690035128_item	2897025	et	3	main
sakslast	doc_819690035128_item	2897026	et	3	main
1	doc_819690035128_item	2897028	et	2	main
algas	doc_819690035128_item	2897030	et	3	main
eesti	doc_819690035128_item	2897031	et	4	main
nsv-s	doc_819690035128_item	2897032	et	3	main
suur	doc_819690035128_item	2897033	et	3	main
viidi	doc_819690035128_item	2897037	et	4	main
nsvl-st	doc_819690035128_item	2897039	et	3	main
eestis	doc_819690035128_item	2897041	et	3	main
grandioosne	doc_819690035128_item	2897050	et	3	main
ja	doc_819690035128_item	2897051	et	3	main
ajal	doc_819690035128_item	2897054	et	4	main
ei	doc_819690035128_item	2897055	et	4	main
see	doc_819690035128_item	2897063	et	3	main
ei	doc_819690035128_item	2897071	et	4	main
olnud	doc_819690035128_item	2897072	et	4	main
ratsionalistlik	doc_819690035128_item	2897073	et	3	main
ja	doc_819690035128_item	2897074	et	3	main
sellega	doc_819690035128_item	2897075	et	3	main
ei	doc_819690035128_item	2897084	et	4	main
soojus	doc_819690035128_item	2897091	et	4	main
elektrijaam	doc_819690035128_item	2897092	et	3	main
põlevkivi	doc_819690035128_item	2897093	et	4	main
kõik	doc_819690035128_item	2897097	et	4	main
jaoks	doc_819690035128_item	2897106	et	4	main
selleks	doc_819690035128_item	2897114	et	4	main
eestisse	doc_819690035128_item	2897122	et	4	main
paljud	doc_819690035128_item	2897124	et	3	main
nsvl	doc_819690035128_item	2897125	et	4	main
suur	doc_819690035128_item	2897133	et	3	main
iga	doc_819690035128_item	2897135	et	4	main
aastane	doc_819690035128_item	2897136	et	4	main
1970ndate	doc_819690035128_item	2897142	et	4	main
osakaal	doc_819690035128_item	2897144	et	3	main
eestis	doc_819690035128_item	2897146	et	3	main
loodushoiu	doc_819690035128_item	2897154	et	3	main
looduse	doc_819690035128_item	2897161	et	4	main
maavarade	doc_819690035128_item	2897163	et	3	main
1974	doc_819690035128_item	2897165	et	2	main
a	doc_819690035128_item	2897166	et	4	main
eestis	doc_819690035128_item	2897169	et	3	main
lahemaa	doc_819690035128_item	2897174	et	4	main
rahvuspark	doc_819690035128_item	2897175	et	3	main
majandus	doc_819690035128_item	2897176	et	4	main
ei	doc_819690035128_item	2897177	et	4	main
palju	doc_819690035128_item	2897181	et	4	main
seda	doc_819690035128_item	2897216	et	3	main
situatsioon	doc_819690035128_item	2897219	et	3	main
vaesematest	doc_804074096014_item	2896919	et	4	main
lapsed	doc_804074096014_item	2896927	et	3	main
jaoks	doc_804074096014_item	2896933	et	4	main
ehitati	doc_804074096014_item	2896934	et	3	main
põletatud	doc_804074096014_item	2896950	et	4	main
eesti	doc_804074096014_item	2896958	et	4	main
tunduvalt	doc_804074096014_item	2896962	et	4	main
sammud	doc_804074096014_item	2896971	et	4	main
kirjanduses	doc_804074096014_item	2896972	et	3	main
hakkati	doc_804074096014_item	2896973	et	3	main
kirjutama	doc_804074096014_item	2896974	et	3	main
majanduse	doc_819690035128_item	2897005	et	4	main
ja	doc_819690035128_item	2897006	et	3	main
loodushoiu	doc_819690035128_item	2897007	et	3	main
vastasseis	doc_819690035128_item	2897008	et	3	main
arvates	doc_819690035128_item	2897016	et	4	main
suuremad	doc_819690035128_item	2897017	et	4	main
identiteediprobleemid	doc_819690035128_item	2897018	et	3	main
kas	doc_819690035128_item	2897019	et	3	main
kaevandamine	doc_819690035128_item	2897035	et	4	main
sisse	doc_819690035128_item	2897038	et	4	main
suur	doc_819690035128_item	2897043	et	3	main
massiline	doc_819690035128_item	2897045	et	4	main
sissevool	doc_819690035128_item	2897046	et	4	main
välismaalasi	doc_819690035128_item	2897047	et	3	main
kaevandamine	doc_819690035128_item	2897048	et	4	main
oli	doc_819690035128_item	2897049	et	3	main
ei	doc_819690035128_item	2897058	et	4	main
loodusvarad	doc_819690035128_item	2897077	et	3	main
tühistati	doc_819690035128_item	2897080	et	3	main
sama	doc_819690035128_item	2897082	et	4	main
siis	doc_819690035128_item	2897086	et	3	main
olla	doc_819690035128_item	2897095	et	3	main
kasutati	doc_819690035128_item	2897100	et	4	main
ehitamiseks	doc_819690035128_item	2897102	et	4	main
teiste	doc_819690035128_item	2897104	et	4	main
vajaduste	doc_819690035128_item	2897105	et	4	main
nii	doc_819690035128_item	2897111	et	3	main
palju	doc_819690035128_item	2897112	et	4	main
kaevandata	doc_819690035128_item	2897113	et	3	main
hakkas	doc_819690035128_item	2897152	et	3	main
hakkasid	doc_819690035128_item	2897157	et	4	main
rohkem	doc_819690035128_item	2897158	et	4	main
mõtlema	doc_819690035128_item	2897159	et	3	main
esimene	doc_819690035128_item	2897168	et	3	main
ka	doc_819690035128_item	2897171	et	3	main
anti	doc_819690035128_item	2897214	et	3	main
teha	doc_819690035128_item	2897217	et	3	main
viis	doc_819690035128_item	2897220	et	4	main
mina	doc_819690035128_item	2897232	et	4	main
sulle	doc_819690035128_item	2897233	et	3	main
muidugi	doc_819690035128_item	2897234	et	4	main
ja	doc_819690035128_item	2897240	et	3	main
hakkas	doc_819690035128_item	2897241	et	3	main
natuke	doc_819690035128_item	2897242	et	4	main
muutunud	doc_819690035128_item	2897249	et	4	main
oskaril	doc_819690035128_item	2897254	et	4	main
kui	doc_819690035128_item	2897255	et	3	main
ka	doc_819690035128_item	2897256	et	3	main
erikal	doc_819690035128_item	2897257	et	4	main
ta	doc_819690035128_item	2897263	et	4	main
ja	doc_819690035128_item	2897267	et	3	main
perekond	doc_819690035128_item	2897282	et	3	main
ta	doc_819690035128_item	2897289	et	4	main
üldse	doc_819690035128_item	2897290	et	3	main
ei	doc_819690035128_item	2897291	et	4	main
tea	doc_819690035128_item	2897292	et	4	main
talle	doc_819690035128_item	2897297	et	4	main
elada	doc_819690035128_item	2897299	et	3	main
armastab	doc_819690035128_item	2897301	et	3	main
eestlasest	doc_819690035128_item	2897302	et	3	main
töötas	doc_819690035128_item	2897322	et	3	main
nõu	doc_819690035128_item	2897329	et	4	main
anda	doc_819690035128_item	2897330	et	3	main
tema	doc_819690035128_item	2897331	et	4	main
ja	doc_819690035128_item	2897332	et	3	main
nägid	doc_819690035128_item	2897340	et	4	main
on	doc_819690035128_item	2897356	et	4	main
mu	doc_819690035128_item	2897357	et	3	main
arvates	doc_819690035128_item	2897358	et	4	main
juhus	doc_819690035128_item	2897361	et	4	main
oli	doc_804074096014_item	2896922	et	3	main
häid	doc_804074096014_item	2896924	et	3	main
maa	doc_804074096014_item	2896926	et	4	main
nende	doc_804074096014_item	2896932	et	4	main
liidus	doc_804074096014_item	2896937	et	4	main
puhastus	doc_804074096014_item	2896940	et	4	main
suur	doc_804074096014_item	2896942	et	3	main
hävitamine	doc_804074096014_item	2896944	et	4	main
suur	doc_804074096014_item	2896945	et	3	main
suur	doc_804074096014_item	2896954	et	3	main
võrreldes	doc_804074096014_item	2896964	et	3	main
realismjätis	doc_804074096014_item	2896969	et	4	main
tunduvad	doc_804074096014_item	2896970	et	4	main
ja	doc_804074096014_item	2896976	et	3	main
sovhoosidest	doc_804074096014_item	2896977	et	3	main
d	doc_804074096014_item	2896978	et	4	main
vaarandi	doc_804074096014_item	2896979	et	4	main
suund	doc_804074096014_item	2896980	et	3	main
oli	doc_804074096014_item	2896981	et	3	main
helge	doc_804074096014_item	2896982	et	4	main
tuleviku	doc_804074096014_item	2896983	et	4	main
poole	doc_804074096014_item	2896984	et	4	main
ei	doc_804074096014_item	2896985	et	4	main
tunnistatut	doc_804074096014_item	2896986	et	4	main
negatiivset	doc_804074096014_item	2896987	et	3	main
kirjanikut	doc_804074096014_item	2896988	et	4	main
oli	doc_804074096014_item	2896989	et	3	main
väga	doc_804074096014_item	2896990	et	3	main
range	doc_804074096014_item	2896991	et	4	main
tsensuur	doc_804074096014_item	2896992	et	3	main
need	doc_804074096014_item	2896993	et	3	main
raamatuid	doc_804074096014_item	2896994	et	3	main
kus	doc_804074096014_item	2896995	et	3	main
vähemaltki	doc_804074096014_item	2896996	et	4	main
oli	doc_804074096014_item	2896997	et	3	main
midagi	doc_804074096014_item	2896998	et	4	main
nsv-s	doc_819690035128_item	2897011	et	3	main
põlevkivi	doc_819690035128_item	2897034	et	4	main
mõelnud	doc_819690035128_item	2897056	et	4	main
ja	doc_819690035128_item	2897057	et	3	main
pärast	doc_819690035128_item	2897066	et	4	main
millised	doc_819690035128_item	2897067	et	3	main
eesti	doc_819690035128_item	2897076	et	4	main
peaaegu	doc_819690035128_item	2897079	et	3	main
kui	doc_819690035128_item	2897081	et	3	main
tegevus	doc_819690035128_item	2897083	et	4	main
1973	doc_819690035128_item	2897087	et	2	main
ehitatakse	doc_819690035128_item	2897089	et	3	main
peaaegu	doc_819690035128_item	2897096	et	3	main
ei	doc_819690035128_item	2897108	et	4	main
ka	doc_819690035128_item	2897116	et	3	main
tööle	doc_819690035128_item	2897117	et	3	main
võtta	doc_819690035128_item	2897118	et	3	main
emmigreerisid	doc_819690035128_item	2897123	et	4	main
erinevates	doc_819690035128_item	2897126	et	4	main
kohtades	doc_819690035128_item	2897127	et	3	main
sissevool	doc_819690035128_item	2897137	et	4	main
oli	doc_819690035128_item	2897138	et	3	main
10000	doc_819690035128_item	2897139	et	2	main
inimest	doc_819690035128_item	2897140	et	3	main
33	doc_819690035128_item	2897148	et	2	main
vastasseis	doc_819690035128_item	2897155	et	3	main
säilitamisest	doc_819690035128_item	2897164	et	4	main
baltikumis	doc_819690035128_item	2897172	et	4	main
korras	doc_819690035128_item	2897179	et	4	main
sellele	doc_819690035128_item	2897221	et	4	main
turg	doc_819690035128_item	2897228	et	3	main
ei	doc_819690035128_item	2897236	et	4	main
ei	doc_819690035128_item	2897248	et	4	main
minu	doc_819690035128_item	2897251	et	3	main
on	doc_819690035128_item	2897261	et	4	main
perekonnast	doc_819690035128_item	2897266	et	4	main
põhjendattud	doc_819690035128_item	2897273	et	4	main
et	doc_819690035128_item	2897280	et	3	main
tähtsuse	doc_819690035128_item	2897287	et	4	main
mida	doc_819690035128_item	2897293	et	4	main
teha	doc_819690035128_item	2897294	et	3	main
ta	doc_819690035128_item	2897300	et	4	main
poissi	doc_819690035128_item	2897303	et	4	main
ta	doc_819690035128_item	2897321	et	4	main
tuutorina	doc_819690035128_item	2897323	et	4	main
perekonnas	doc_819690035128_item	2897324	et	4	main
kus	doc_819690035128_item	2897325	et	3	main
kõik	doc_819690035128_item	2897326	et	4	main
oskari	doc_819690035128_item	2897333	et	4	main
üle	doc_819690035128_item	2897334	et	3	main
mõnikord	doc_819690035128_item	2897335	et	3	main
ka	doc_819690035128_item	2897336	et	3	main
toimub	doc_819690035128_item	2897344	et	3	main
kuid	doc_819690035128_item	2897345	et	4	main
inimesed	doc_819690035128_item	2897347	et	3	main
noormehena	doc_819690035128_item	2897391	et	3	main
ta	doc_819690035128_item	2897392	et	4	main
kao	doc_819690035128_item	2897396	et	4	main
ajal	doc_819690035128_item	2897415	et	4	main
ma	doc_819690035128_item	2897432	et	3	main
finalli	doc_819690035128_item	2897442	et	4	main
kuid	doc_819690035128_item	2897443	et	4	main
siiski	doc_819690035128_item	2897444	et	4	main
peamiseks	doc_819690035128_item	2897445	et	3	main
süütjaks	doc_819690035128_item	2897446	et	4	main
ma	doc_819690035128_item	2897447	et	3	main
kartused	doc_819690035128_item	2897467	et	3	main
hävitasid	doc_819690035128_item	2897472	et	4	main
majanduse	doc_819690035129_item	2897475	et	4	main
nsv-s	doc_819690035129_item	2897481	et	3	main
suuremad	doc_819690035129_item	2897487	et	4	main
hakkas	doc_819690035129_item	2897523	et	3	main
selle	doc_819690035129_item	2897535	et	4	main
põhjuseks	doc_819690035129_item	2897536	et	3	main
on	doc_819690035129_item	2897537	et	4	main
vajad	doc_819690035129_item	2897548	et	4	main
töölisi	doc_819690035129_item	2897549	et	3	main
eestlane	doc_819690035129_item	2897550	et	3	main
narva	doc_819690035129_item	2897560	et	4	main
sillamäe	doc_819690035129_item	2897561	et	3	main
vene	doc_819690035129_item	2897566	et	4	main
tööliseid	doc_819690035128_item	2897036	et	3	main
1970ndatel	doc_819690035128_item	2897029	et	4	main
ja	doc_819690035128_item	2897040	et	3	main
oli	doc_819690035128_item	2897042	et	3	main
nn	doc_819690035128_item	2897044	et	4	main
tol	doc_819690035128_item	2897053	et	3	main
toob	doc_819690035128_item	2897064	et	3	main
saakd	doc_819690035128_item	2897094	et	4	main
põlevkivi	doc_819690035128_item	2897099	et	4	main
majade	doc_819690035128_item	2897101	et	3	main
ja	doc_819690035128_item	2897103	et	3	main
tuli	doc_819690035128_item	2897115	et	4	main
töölisi	doc_819690035128_item	2897121	et	3	main
muulaste	doc_819690035128_item	2897129	et	4	main
nii	doc_819690035128_item	2897132	et	3	main
seega	doc_819690035128_item	2897141	et	4	main
suur	doc_819690035128_item	2897153	et	3	main
rohelised	doc_819690035128_item	2897156	et	4	main
eestimaa	doc_819690035128_item	2897160	et	4	main
avati	doc_819690035128_item	2897167	et	3	main
ja	doc_819690035128_item	2897170	et	3	main
rahvuspark	doc_819690035128_item	2897173	et	3	main
ka	doc_819690035128_item	2897180	et	3	main
tegutsema	doc_819690035128_item	2897224	et	3	main
laua	doc_819690035128_item	2897226	et	3	main
sina	doc_819690035128_item	2897229	et	4	main
mulle	doc_819690035128_item	2897230	et	4	main
ja	doc_819690035128_item	2897231	et	3	main
olnud	doc_819690035128_item	2897237	et	4	main
sellega	doc_819690035128_item	2897238	et	3	main
ajal	doc_819690035128_item	2897246	et	4	main
arvates	doc_819690035128_item	2897252	et	4	main
on	doc_819690035128_item	2897258	et	4	main
identiteediprobleemid	doc_819690035128_item	2897259	et	3	main
on	doc_819690035128_item	2897264	et	4	main
tema	doc_819690035128_item	2897268	et	4	main
minu	doc_819690035128_item	2897271	et	3	main
peab	doc_819690035128_item	2897277	et	4	main
mõtlema	doc_819690035128_item	2897278	et	3	main
sellest	doc_819690035128_item	2897279	et	4	main
jätis	doc_819690035128_item	2897283	et	4	main
keegi	doc_819690035128_item	2897052	et	4	main
arvestatud	doc_819690035128_item	2897059	et	4	main
sellega	doc_819690035128_item	2897060	et	3	main
millised	doc_819690035128_item	2897061	et	3	main
tulemused	doc_819690035128_item	2897062	et	3	main
eestise	doc_819690035128_item	2897065	et	4	main
ökoloogilised	doc_819690035128_item	2897068	et	4	main
probleemid	doc_819690035128_item	2897069	et	3	main
kaevandamine	doc_819690035128_item	2897070	et	4	main
maavarad9	doc_819690035128_item	2897078	et	3	main
lõpeks	doc_819690035128_item	2897085	et	4	main
a	doc_819690035128_item	2897088	et	4	main
balti	doc_819690035128_item	2897090	et	3	main
kaendatud	doc_819690035128_item	2897098	et	4	main
kuid	doc_819690035128_item	2897107	et	4	main
olnud	doc_819690035128_item	2897109	et	4	main
vajalik	doc_819690035128_item	2897110	et	3	main
palju	doc_819690035128_item	2897119	et	4	main
inimesi	doc_819690035128_item	2897120	et	4	main
elanud	doc_819690035128_item	2897128	et	4	main
migratsioon	doc_819690035128_item	2897130	et	3	main
oli	doc_819690035128_item	2897131	et	3	main
et	doc_819690035128_item	2897134	et	3	main
lõpus	doc_819690035128_item	2897143	et	4	main
muulasi	doc_819690035128_item	2897145	et	4	main
oli	doc_819690035128_item	2897147	et	3	main
kõike	doc_819690035128_item	2897149	et	4	main
selle	doc_819690035128_item	2897150	et	4	main
tulemusega	doc_819690035128_item	2897151	et	3	main
ja	doc_819690035128_item	2897162	et	3	main
olnud	doc_819690035128_item	2897178	et	4	main
tooteid	doc_819690035128_item	2897182	et	4	main
ei	doc_819690035128_item	2897183	et	4	main
olnud	doc_819690035128_item	2897184	et	4	main
lihtsalt	doc_819690035128_item	2897185	et	4	main
võimalik	doc_819690035128_item	2897186	et	3	main
kauplustes	doc_819690035128_item	2897187	et	4	main
leida	doc_819690035128_item	2897188	et	3	main
inimestel	doc_819690035128_item	2897189	et	3	main
oli	doc_819690035128_item	2897190	et	3	main
raha	doc_819690035128_item	2897191	et	4	main
kuid	doc_819690035128_item	2897192	et	4	main
selleks	doc_819690035128_item	2897193	et	4	main
et	doc_819690035128_item	2897194	et	3	main
osta	doc_819690035128_item	2897195	et	4	main
midagi	doc_819690035128_item	2897196	et	4	main
defitsiitset	doc_819690035128_item	2897197	et	3	main
oli	doc_819690035128_item	2897198	et	3	main
vaja	doc_819690035128_item	2897199	et	4	main
oodata	doc_819690035128_item	2897200	et	4	main
mõne	doc_819690035128_item	2897201	et	3	main
aja	doc_819690035128_item	2897202	et	4	main
näiteks	doc_819690035128_item	2897203	et	4	main
et	doc_819690035128_item	2897204	et	3	main
osta	doc_819690035128_item	2897205	et	4	main
auto	doc_819690035128_item	2897206	et	4	main
või	doc_819690035128_item	2897207	et	4	main
jääkappi	doc_819690035128_item	2897208	et	4	main
pidi	doc_819690035128_item	2897209	et	4	main
saama	doc_819690035128_item	2897210	et	4	main
luba	doc_819690035128_item	2897211	et	4	main
millega	doc_819690035128_item	2897212	et	3	main
sulle	doc_819690035128_item	2897213	et	3	main
võimalust	doc_819690035128_item	2897215	et	3	main
niisugune	doc_819690035128_item	2897218	et	3	main
et	doc_819690035128_item	2897222	et	3	main
hakkas	doc_819690035128_item	2897223	et	3	main
nn	doc_819690035128_item	2897225	et	4	main
aluna	doc_819690035128_item	2897227	et	3	main
rahvas	doc_819690035128_item	2897235	et	4	main
paranes	doc_819690035128_item	2897243	et	3	main
kuid	doc_819690035128_item	2897244	et	4	main
samal	doc_819690035128_item	2897245	et	3	main
2	doc_819690035128_item	2897250	et	2	main
erika	doc_819690035128_item	2897260	et	4	main
rikast	doc_819690035128_item	2897265	et	4	main
kartused	doc_819690035128_item	2897269	et	3	main
meelest	doc_819690035128_item	2897272	et	4	main
mingil	doc_819690035128_item	2897274	et	4	main
moel	doc_819690035128_item	2897275	et	4	main
alguses	doc_819690035128_item	2897288	et	4	main
ja	doc_819690035128_item	2897295	et	3	main
edasi	doc_819690035128_item	2897298	et	3	main
tahtsid	doc_819690035128_item	2897327	et	4	main
naeratakse	doc_819690035128_item	2897337	et	4	main
mis	doc_819690035128_item	2897341	et	4	main
oskariga	doc_819690035128_item	2897355	et	4	main
fortepiano	doc_819690035128_item	2897385	et	4	main
ja	doc_819690035128_item	2897386	et	3	main
imetles	doc_819690035128_item	2897387	et	3	main
seda	doc_819690035128_item	2897388	et	3	main
olles	doc_819690035128_item	2897389	et	3	main
juba	doc_819690035128_item	2897390	et	3	main
kõike	doc_819690035128_item	2897410	et	4	main
kartrused	doc_819690035128_item	2897419	et	4	main
ja	doc_819690035128_item	2897420	et	3	main
mingil	doc_819690035128_item	2897421	et	4	main
ka	doc_819690035128_item	2897423	et	3	main
ei	doc_819690035128_item	2897430	et	4	main
et	doc_819690035128_item	2897435	et	3	main
välised	doc_819690035128_item	2897437	et	4	main
veel	doc_819690035128_item	2897462	et	4	main
kaua	doc_819690035128_item	2897463	et	3	main
elada	doc_819690035128_item	2897464	et	3	main
kuid	doc_819690035128_item	2897465	et	4	main
sisemised	doc_819690035128_item	2897466	et	3	main
kontrolltöö	doc_819690035129_item	2897473	et	4	main
eesti	doc_819690035129_item	2897480	et	4	main
kellel	doc_819690035129_item	2897483	et	4	main
kas	doc_819690035129_item	2897489	et	3	main
või	doc_819690035129_item	2897491	et	4	main
see	doc_819690035129_item	2897522	et	3	main
paratamatult	doc_819690035129_item	2897524	et	4	main
siinset	doc_819690035129_item	2897526	et	3	main
protsessid	doc_819690035129_item	2897542	et	4	main
1973	doc_819690035129_item	2897543	et	2	main
mis	doc_819690035129_item	2897547	et	4	main
kaevandusse	doc_819690035129_item	2897551	et	4	main
tööle	doc_819690035129_item	2897552	et	3	main
ei	doc_819690035129_item	2897553	et	4	main
kohtla-järvel	doc_819690035129_item	2897556	et	4	main
laienevad	doc_819690035129_item	2897557	et	4	main
järve	doc_819690035129_item	2897563	et	4	main
piirkonnad	doc_819690035129_item	2897564	et	4	main
kujunevad	doc_819690035129_item	2897565	et	4	main
takistusi	doc_819690035129_item	2897570	et	4	main
pärast	doc_819690035129_item	2897571	et	4	main
asumisel	doc_819690035129_item	2897575	et	4	main
n-ö	doc_819690035129_item	2897577	et	4	main
sissepääs	doc_819690035129_item	2897583	et	3	main
nt	doc_819690035129_item	2897586	et	4	main
küllakutse	doc_819690035129_item	2897599	et	4	main
olema	doc_819690035129_item	2897602	et	4	main
jätku	doc_819690035129_item	2897623	et	4	main
vett	doc_819690035129_item	2897625	et	3	main
hakkas	doc_819690035129_item	2897626	et	3	main
mis	doc_819690035129_item	2897638	et	4	main
poolt	doc_819690035129_item	2897644	et	4	main
tööd	doc_819690035129_item	2897658	et	4	main
uueks	doc_819690035129_item	2897664	et	3	main
letialune	doc_819690035129_item	2897667	et	4	main
oli	doc_819690035129_item	2897677	et	3	main
arvastatav	doc_819690035129_item	2897678	et	4	main
ühiskonna	doc_819690035129_item	2897680	et	4	main
rahul	doc_819690035128_item	2897239	et	4	main
peaaegu	doc_819690035128_item	2897247	et	3	main
nii	doc_819690035128_item	2897253	et	3	main
sakslanna	doc_819690035128_item	2897262	et	4	main
on	doc_819690035128_item	2897270	et	4	main
ta	doc_819690035128_item	2897276	et	4	main
ta	doc_819690035128_item	2897281	et	4	main
oma	doc_819690035128_item	2897284	et	4	main
nime	doc_819690035128_item	2897285	et	4	main
ja	doc_819690035128_item	2897286	et	3	main
kuidas	doc_819690035128_item	2897296	et	3	main
ja	doc_819690035128_item	2897304	et	3	main
samal	doc_819690035128_item	2897305	et	3	main
ajal	doc_819690035128_item	2897306	et	4	main
hoolitseb	doc_819690035128_item	2897307	et	3	main
sellest	doc_819690035128_item	2897308	et	4	main
mida	doc_819690035128_item	2897309	et	4	main
see	doc_819690035128_item	2897310	et	3	main
armastus	doc_819690035128_item	2897311	et	4	main
toob	doc_819690035128_item	2897312	et	3	main
kuidas	doc_819690035128_item	2897313	et	3	main
ta	doc_819690035128_item	2897314	et	4	main
ütleb	doc_819690035128_item	2897315	et	3	main
oma	doc_819690035128_item	2897316	et	4	main
vanaisale	doc_819690035128_item	2897317	et	3	main
et	doc_819690035128_item	2897318	et	3	main
tahab	doc_819690035128_item	2897319	et	3	main
abielluda	doc_819690035128_item	2897320	et	3	main
kõik	doc_819690035128_item	2897339	et	4	main
nende	doc_819690035128_item	2897342	et	4	main
noored	doc_819690035128_item	2897346	et	3	main
selle	doc_819690035128_item	2897351	et	4	main
perekonnaliikmetele	doc_819690035128_item	2897352	et	3	main
võimalust	doc_819690035128_item	2897353	et	3	main
fantaseerida	doc_819690035128_item	2897354	et	3	main
palju	doc_819690035128_item	2897359	et	4	main
ta	doc_819690035128_item	2897379	et	4	main
mängis	doc_819690035128_item	2897380	et	3	main
kuskile	doc_819690035128_item	2897394	et	4	main
oskar	doc_819690035128_item	2897407	et	4	main
erikaga	doc_819690035128_item	2897412	et	4	main
elada	doc_819690035128_item	2897413	et	3	main
samal	doc_819690035128_item	2897414	et	3	main
ta	doc_819690035128_item	2897428	et	4	main
saa	doc_819690035128_item	2897431	et	4	main
mõjutasid	doc_819690035128_item	2897439	et	4	main
ja	doc_819690035128_item	2897451	et	3	main
erika	doc_819690035128_item	2897452	et	4	main
nende	doc_819690035128_item	2897453	et	4	main
kõike	doc_819690035128_item	2897470	et	4	main
seda	doc_819690035128_item	2897471	et	3	main
1	doc_819690035129_item	2897474	et	2	main
ja	doc_819690035129_item	2897476	et	3	main
loodushoiu	doc_819690035129_item	2897477	et	3	main
vastasseis	doc_819690035129_item	2897478	et	3	main
2	doc_819690035129_item	2897482	et	2	main
on	doc_819690035129_item	2897484	et	4	main
teie	doc_819690035129_item	2897485	et	4	main
identiteediprobleemid	doc_819690035129_item	2897488	et	3	main
rahvastiku	doc_819690035129_item	2897527	et	3	main
koosseisu	doc_819690035129_item	2897528	et	4	main
197980	doc_819690035129_item	2897529	et	2	main
a-ks	doc_819690035129_item	2897530	et	3	main
on	doc_819690035129_item	2897531	et	4	main
ida-virumaal	doc_819690035129_item	2897540	et	4	main
talle	doc_819690035128_item	2897328	et	4	main
seal	doc_819690035128_item	2897338	et	4	main
vahel	doc_819690035128_item	2897343	et	4	main
ei	doc_819690035128_item	2897348	et	4	main
tahtnud	doc_819690035128_item	2897349	et	4	main
anda	doc_819690035128_item	2897350	et	3	main
raskem	doc_819690035128_item	2897360	et	4	main
ta	doc_819690035128_item	2897362	et	4	main
juba	doc_819690035128_item	2897363	et	3	main
oma	doc_819690035128_item	2897364	et	4	main
lapsepõlvest	doc_819690035128_item	2897365	et	4	main
armunud	doc_819690035128_item	2897366	et	4	main
eerikast	doc_819690035128_item	2897367	et	4	main
ja	doc_819690035128_item	2897368	et	3	main
juba	doc_819690035128_item	2897369	et	3	main
sellest	doc_819690035128_item	2897370	et	4	main
ajal	doc_819690035128_item	2897371	et	4	main
tal	doc_819690035128_item	2897372	et	3	main
on	doc_819690035128_item	2897373	et	4	main
mälestused	doc_819690035128_item	2897374	et	4	main
temast	doc_819690035128_item	2897375	et	3	main
ta	doc_819690035128_item	2897376	et	4	main
nägi	doc_819690035128_item	2897377	et	3	main
kui	doc_819690035128_item	2897378	et	3	main
lapsena	doc_819690035128_item	2897381	et	3	main
valges	doc_819690035128_item	2897382	et	4	main
ilusas	doc_819690035128_item	2897383	et	3	main
kleidis	doc_819690035128_item	2897384	et	3	main
ei	doc_819690035128_item	2897395	et	4	main
poolt	doc_819690035128_item	2897398	et	4	main
on	doc_819690035128_item	2897408	et	4	main
valmis	doc_819690035128_item	2897409	et	4	main
temas	doc_819690035128_item	2897416	et	3	main
on	doc_819690035128_item	2897417	et	4	main
suured	doc_819690035128_item	2897418	et	3	main
moel	doc_819690035128_item	2897422	et	4	main
endaga	doc_819690035128_item	2897424	et	4	main
rahulolematus	doc_819690035128_item	2897425	et	4	main
millest	doc_819690035128_item	2897426	et	3	main
pääseda	doc_819690035128_item	2897427	et	3	main
olen	doc_819690035128_item	2897433	et	3	main
oskari	doc_819690035128_item	2897450	et	4	main
võis	doc_819690035128_item	2897461	et	4	main
identiteediprobleemid	doc_819690035128_item	2897469	et	3	main
1970ndate	doc_819690035129_item	2897479	et	4	main
4000	doc_819690035129_item	2897521	et	2	main
eestlaste	doc_819690035129_item	2897532	et	4	main
osakaal	doc_819690035129_item	2897533	et	3	main
64	doc_819690035129_item	2897534	et	2	main
toimunud	doc_819690035129_item	2897541	et	4	main
balit	doc_819690035129_item	2897545	et	4	main
soojuselektrijaam	doc_819690035129_item	2897546	et	3	main
tahtnud	doc_819690035129_item	2897554	et	4	main
keelseteks	doc_819690035129_item	2897567	et	4	main
elama	doc_819690035129_item	2897574	et	3	main
linnad	doc_819690035129_item	2897579	et	3	main
põhielanikel	doc_819690035129_item	2897584	et	3	main
loksa	doc_819690035129_item	2897590	et	4	main
pääses	doc_819690035129_item	2897592	et	4	main
ei	doc_819690035129_item	2897595	et	4	main
saanud	doc_819690035129_item	2897596	et	4	main
saanud	doc_819690035129_item	2897605	et	4	main
üldse	doc_819690035129_item	2897606	et	3	main
et	doc_819690035129_item	2897621	et	3	main
kruusa	doc_819690035129_item	2897628	et	4	main
ja	doc_819690035129_item	2897629	et	3	main
eestlastele	doc_819690035129_item	2897639	et	4	main
tehti	doc_819690035129_item	2897645	et	3	main
eestis	doc_819690035129_item	2897646	et	3	main
näidismajandeid	doc_819690035129_item	2897647	et	3	main
ettevõtteid	doc_819690035129_item	2897648	et	3	main
mis	doc_819690035129_item	2897649	et	4	main
väikseid	doc_819690035129_item	2897652	et	4	main
sai	doc_819690035129_item	2897654	et	4	main
see	doc_819690035129_item	2897661	et	3	main
kaupa	doc_819690035129_item	2897672	et	4	main
müüjatel	doc_819690035129_item	2897676	et	4	main
positsioon	doc_819690035129_item	2897679	et	3	main
kunagi	doc_819690035129_item	2897681	et	3	main
asju	doc_819690035129_item	2897692	et	3	main
mida	doc_819690035129_item	2897728	et	4	main
ta	doc_819690035129_item	2897729	et	4	main
tahab	doc_819690035129_item	2897730	et	3	main
elust	doc_819690035129_item	2897731	et	3	main
aga	doc_819690035129_item	2897732	et	3	main
erika	doc_819690035129_item	2897733	et	4	main
tahtis	doc_819690035129_item	2897734	et	3	main
oskarit	doc_819690035129_item	2897741	et	4	main
ära	doc_819690035129_item	2897745	et	4	main
viimasel	doc_819690035129_item	2897747	et	3	main
armastus	doc_819690035128_item	2897393	et	4	main
ühelt	doc_819690035128_item	2897397	et	3	main
ta	doc_819690035128_item	2897399	et	4	main
tunded	doc_819690035128_item	2897400	et	3	main
on	doc_819690035128_item	2897401	et	4	main
nii	doc_819690035128_item	2897402	et	3	main
ilusad	doc_819690035128_item	2897403	et	3	main
ja	doc_819690035128_item	2897404	et	3	main
tõsised	doc_819690035128_item	2897405	et	4	main
et	doc_819690035128_item	2897406	et	3	main
tehaet	doc_819690035128_item	2897411	et	4	main
siiski	doc_819690035128_item	2897429	et	4	main
kindel	doc_819690035128_item	2897434	et	3	main
ka	doc_819690035128_item	2897436	et	3	main
faktorid	doc_819690035128_item	2897438	et	3	main
selle	doc_819690035128_item	2897440	et	4	main
loo	doc_819690035128_item	2897441	et	4	main
nimetaksin	doc_819690035128_item	2897448	et	3	main
neid	doc_819690035128_item	2897449	et	4	main
armastus	doc_819690035128_item	2897454	et	4	main
oli	doc_819690035128_item	2897455	et	3	main
nii	doc_819690035128_item	2897456	et	3	main
suur	doc_819690035128_item	2897457	et	3	main
ja	doc_819690035128_item	2897458	et	3	main
tõeline	doc_819690035128_item	2897459	et	4	main
et	doc_819690035128_item	2897460	et	3	main
ja	doc_819690035128_item	2897468	et	3	main
arvates	doc_819690035129_item	2897486	et	4	main
erikal	doc_819690035129_item	2897490	et	4	main
oskaril	doc_819690035129_item	2897492	et	4	main
tammsaare	doc_819690035129_item	2897493	et	3	main
ma	doc_819690035129_item	2897494	et	3	main
armastasin	doc_819690035129_item	2897495	et	3	main
sakslast	doc_819690035129_item	2897496	et	3	main
põhjendage	doc_819690035129_item	2897497	et	3	main
1	doc_819690035129_item	2897498	et	2	main
al	doc_819690035129_item	2897499	et	4	main
1970	doc_819690035129_item	2897500	et	2	main
a-st	doc_819690035129_item	2897501	et	3	main
sab	doc_819690035129_item	2897502	et	4	main
iseloomulikuks	doc_819690035129_item	2897503	et	3	main
järjest	doc_819690035129_item	2897504	et	4	main
suurenev	doc_819690035129_item	2897505	et	4	main
migrantide	doc_819690035129_item	2897506	et	3	main
vool	doc_819690035129_item	2897507	et	4	main
eestisse	doc_819690035129_item	2897508	et	4	main
aastas	doc_819690035129_item	2897509	et	3	main
lisandus	doc_819690035129_item	2897510	et	4	main
ka	doc_819690035129_item	2897511	et	3	main
10000	doc_819690035129_item	2897512	et	2	main
inimest	doc_819690035129_item	2897513	et	3	main
migratsiooni	doc_819690035129_item	2897514	et	4	main
teel	doc_819690035129_item	2897515	et	4	main
loomulik	doc_819690035129_item	2897516	et	3	main
iive	doc_819690035129_item	2897517	et	3	main
eestlastel	doc_819690035129_item	2897518	et	4	main
2500	doc_819690035129_item	2897519	et	2	main
muulastel	doc_819690035129_item	2897520	et	4	main
mõjutama	doc_819690035129_item	2897525	et	4	main
lääne-	doc_819690035129_item	2897538	et	4	main
ja	doc_819690035129_item	2897539	et	3	main
loodi	doc_819690035129_item	2897544	et	4	main
põlevkivi	doc_819690035129_item	2897558	et	4	main
kaevandused	doc_819690035129_item	2897559	et	4	main
linnadesse	doc_819690035129_item	2897581	et	3	main
saartele	doc_819690035129_item	2897591	et	3	main
niisama	doc_819690035129_item	2897594	et	3	main
vms	doc_819690035129_item	2897600	et	4	main
1974	doc_819690035129_item	2897607	et	2	main
mood	doc_819690035129_item	2897608	et	3	main
rahvuspark	doc_819690035129_item	2897610	et	3	main
esimene	doc_819690035129_item	2897611	et	3	main
nsvl-s	doc_819690035129_item	2897612	et	3	main
lahemaa	doc_819690035129_item	2897609	et	4	main
loodust	doc_819690035129_item	2897613	et	4	main
pidsi	doc_819690035129_item	2897614	et	4	main
kaitsma	doc_819690035129_item	2897615	et	3	main
hakkama	doc_819690035129_item	2897616	et	3	main
päästma	doc_819690035129_item	2897617	et	3	main
hävinemisest	doc_819690035129_item	2897618	et	4	main
tekkis	doc_819690035129_item	2897619	et	3	main
hirm	doc_819690035129_item	2897620	et	3	main
mõtlematult	doc_819690035129_item	2897634	et	4	main
hävinesid	doc_819690035129_item	2897635	et	4	main
mõned	doc_819690035129_item	2897636	et	3	main
allikakopad	doc_819690035129_item	2897637	et	3	main
teiselt	doc_819690035129_item	2897643	et	4	main
justkui	doc_819690035129_item	2897651	et	3	main
riigid	doc_819690035129_item	2897653	et	3	main
koju	doc_819690035129_item	2897660	et	3	main
eenstiiliks	doc_819690035129_item	2897663	et	4	main
sai	doc_819690035129_item	2897673	et	4	main
teistega	doc_819690035129_item	2897674	et	4	main
ei	doc_819690035129_item	2897682	et	4	main
võinud	doc_819690035129_item	2897683	et	4	main
teada	doc_819690035129_item	2897684	et	3	main
millal	doc_819690035129_item	2897685	et	3	main
tuleb	doc_819690035129_item	2897686	et	3	main
uus	doc_819690035129_item	2897687	et	3	main
kaup	doc_819690035129_item	2897688	et	3	main
osteti	doc_819690035129_item	2897689	et	3	main
et	doc_819690035129_item	2897724	et	3	main
nad	doc_819690035129_item	2897743	et	3	main
jooksma	doc_819690035129_item	2897746	et	3	main
meie	doc_819690035129_item	2897758	et	4	main
võib	doc_819690035129_item	2897760	et	3	main
situatsioon	doc_819690035129_item	2897763	et	3	main
aseda	doc_819690035129_item	2897555	et	4	main
kohtla	doc_819690035129_item	2897562	et	4	main
eestlastele	doc_819690035129_item	2897568	et	4	main
tehakse	doc_819690035129_item	2897569	et	3	main
narva	doc_819690035129_item	2897573	et	4	main
olid	doc_819690035129_item	2897576	et	4	main
teatud	doc_819690035129_item	2897580	et	4	main
erilubadega	doc_819690035129_item	2897593	et	3	main
keegi	doc_819690035129_item	2897598	et	4	main
sõda	doc_819690035129_item	2897572	et	4	main
kinnised	doc_819690035129_item	2897578	et	4	main
oli	doc_819690035129_item	2897582	et	3	main
keelatud	doc_819690035129_item	2897585	et	4	main
sillamäe	doc_819690035129_item	2897587	et	3	main
narva	doc_819690035129_item	2897588	et	4	main
paldiski	doc_819690035129_item	2897589	et	4	main
sinna	doc_819690035129_item	2897597	et	3	main
pidi	doc_819690035129_item	2897601	et	4	main
ruhnu	doc_819690035129_item	2897603	et	4	main
ei	doc_819690035129_item	2897604	et	4	main
ei	doc_819690035129_item	2897622	et	4	main
puhast	doc_819690035129_item	2897624	et	3	main
nappima	doc_819690035129_item	2897627	et	3	main
liiva	doc_819690035129_item	2897630	et	4	main
seda	doc_819690035129_item	2897631	et	3	main
hakati	doc_819690035129_item	2897632	et	3	main
kaevandama	doc_819690035129_item	2897633	et	3	main
olid	doc_819690035129_item	2897640	et	4	main
toodi	doc_819690035129_item	2897659	et	4	main
fenomeniks	doc_819690035129_item	2897665	et	3	main
saada	doc_819690035129_item	2897670	et	4	main
olevat	doc_819690035129_item	2897671	et	4	main
teadnud	doc_819690035129_item	2897727	et	4	main
erika	doc_819690035129_item	2897738	et	4	main
armastas	doc_819690035129_item	2897739	et	3	main
on	doc_819690035129_item	2897752	et	4	main
meie	doc_819690035129_item	2897753	et	4	main
ajal	doc_819690035129_item	2897754	et	4	main
ajal	doc_819690035129_item	2897759	et	4	main
niisugune	doc_819690035129_item	2897762	et	3	main
essee	doc_820667236802_item	2897982	et	4	main
hästi	doc_820667236802_item	2897984	et	3	main
eesti	doc_820667236802_item	2897988	et	4	main
filmis	doc_820667236802_item	2897990	et	4	main
lugu	doc_820667236802_item	2897992	et	4	main
jaoks	doc_820667236802_item	2898001	et	4	main
pärast	doc_820667236802_item	2898005	et	4	main
rahutused	doc_820667236802_item	2898009	et	4	main
suurt	doc_820667236802_item	2898025	et	3	main
töötajad	doc_820667236802_item	2898032	et	4	main
sündmustest	doc_820667236802_item	2898043	et	4	main
nii	doc_820667236802_item	2898044	et	3	main
eestis	doc_820667236802_item	2898045	et	3	main
poliitiline	doc_820667236802_item	2898054	et	3	main
taheti	doc_820667236802_item	2898060	et	3	main
sõduritega	doc_820667236802_item	2898076	et	3	main
infoedastamise	doc_820667236802_item	2898078	et	3	main
punktide	doc_820667236802_item	2898079	et	3	main
vastu	doc_820667236802_item	2898118	et	3	main
lõppude	doc_820667236802_item	2898120	et	4	main
ja	doc_820667236802_item	2898135	et	3	main
televisiooni	doc_820667236802_item	2898136	et	4	main
saalis	doc_820667236802_item	2898149	et	4	main
oli	doc_820667236802_item	2898150	et	3	main
õhkkond	doc_820667236802_item	2898151	et	3	main
ajalooliselt	doc_819690035129_item	2897641	et	4	main
pühad	doc_819690035129_item	2897642	et	3	main
olid	doc_819690035129_item	2897650	et	4	main
kombeks	doc_819690035129_item	2897655	et	4	main
riigilt	doc_819690035129_item	2897656	et	3	main
näppamine	doc_819690035129_item	2897657	et	4	main
kujunes	doc_819690035129_item	2897662	et	3	main
sai	doc_819690035129_item	2897666	et	4	main
kaubandus	doc_819690035129_item	2897668	et	3	main
vähe	doc_819690035129_item	2897669	et	3	main
vahetada	doc_819690035129_item	2897675	et	3	main
palju	doc_819690035129_item	2897690	et	4	main
mõttetuid	doc_819690035129_item	2897691	et	4	main
delikatess	doc_819690035129_item	2897693	et	3	main
oli	doc_819690035129_item	2897694	et	3	main
heeringas	doc_819690035129_item	2897695	et	4	main
wc	doc_819690035129_item	2897696	et	4	main
2	doc_819690035129_item	2897698	et	2	main
mulle	doc_819690035129_item	2897699	et	4	main
meeldis	doc_819690035129_item	2897700	et	3	main
see	doc_819690035129_item	2897701	et	3	main
romaan	doc_819690035129_item	2897702	et	3	main
väga	doc_819690035129_item	2897703	et	3	main
paberit	doc_819690035129_item	2897697	et	3	main
see	doc_819690035129_item	2897704	et	3	main
on	doc_819690035129_item	2897705	et	4	main
armastusest	doc_819690035129_item	2897706	et	4	main
film	doc_819690035129_item	2897707	et	3	main
mulle	doc_819690035129_item	2897708	et	4	main
tundub	doc_819690035129_item	2897709	et	3	main
et	doc_819690035129_item	2897710	et	3	main
identiteediprobleemid	doc_819690035129_item	2897711	et	3	main
on	doc_819690035129_item	2897712	et	4	main
nii	doc_819690035129_item	2897713	et	3	main
erikal	doc_819690035129_item	2897714	et	4	main
kui	doc_819690035129_item	2897715	et	3	main
ka	doc_819690035129_item	2897716	et	3	main
oskaril	doc_819690035129_item	2897717	et	4	main
võib	doc_819690035129_item	2897718	et	3	main
olla	doc_819690035129_item	2897719	et	3	main
oskaril	doc_819690035129_item	2897720	et	4	main
mulle	doc_819690035129_item	2897722	et	4	main
tundub	doc_819690035129_item	2897723	et	3	main
väga	doc_819690035129_item	2897740	et	3	main
tahtsid	doc_819690035129_item	2897744	et	4	main
hetkel	doc_819690035129_item	2897748	et	4	main
oskar	doc_819690035129_item	2897749	et	4	main
keeldus	doc_819690035129_item	2897750	et	3	main
ka	doc_819690035129_item	2897755	et	3	main
raske	doc_819690035129_item	2897756	et	4	main
ja	doc_819690035129_item	2897757	et	3	main
juhtuda	doc_819690035129_item	2897761	et	3	main
rohkem	doc_819690035129_item	2897721	et	4	main
ta	doc_819690035129_item	2897725	et	4	main
ei	doc_819690035129_item	2897726	et	4	main
ainult	doc_819690035129_item	2897735	et	4	main
abielluda	doc_819690035129_item	2897736	et	3	main
temaga	doc_819690035129_item	2897737	et	3	main
ja	doc_819690035129_item	2897742	et	3	main
elu	doc_819690035129_item	2897751	et	4	main
filmis	doc_820667236802_item	2897987	et	4	main
on	doc_820667236802_item	2897999	et	4	main
selle	doc_820667236802_item	2898004	et	4	main
puutuvad	doc_820667236802_item	2898010	et	4	main
eestit	doc_820667236802_item	2898012	et	3	main
on	doc_820667236802_item	2898014	et	4	main
nsv-liidus	doc_820667236802_item	2898015	et	4	main
on	doc_820667236802_item	2898029	et	4	main
eesti	doc_820667236802_item	2898030	et	4	main
täpset	doc_820667236802_item	2898040	et	3	main
ka	doc_820667236802_item	2898047	et	3	main
selles	doc_820667236802_item	2898058	et	4	main
tema	doc_820667236802_item	2898063	et	4	main
ajal	doc_820667236802_item	2898071	et	4	main
vene	doc_820667236802_item	2898075	et	4	main
mis	doc_820667236802_item	2898085	et	4	main
iseseisvumisdeklaratsiooni	doc_820667236802_item	2898117	et	4	main
võtmist	doc_820667236802_item	2898119	et	4	main
teletorni	doc_820667236802_item	2897991	et	4	main
tegevus	doc_820667236802_item	2897993	et	4	main
toimub	doc_820667236802_item	2897994	et	3	main
1991	doc_820667236802_item	2897995	et	2	main
raske	doc_820667236802_item	2898002	et	4	main
aeg	doc_820667236802_item	2898003	et	3	main
et	doc_820667236802_item	2898006	et	3	main
ka	doc_820667236802_item	2898011	et	3	main
raadio	doc_820667236802_item	2898016	et	4	main
kui	doc_820667236802_item	2898017	et	3	main
riigiringhääl	doc_820667236802_item	2898018	et	3	main
ja	doc_820667236802_item	2898019	et	3	main
tõsiset	doc_820667236802_item	2898038	et	4	main
ja	doc_820667236802_item	2898039	et	3	main
kui	doc_820667236802_item	2898046	et	3	main
venemaal	doc_820667236802_item	2898050	et	4	main
et	doc_820667236802_item	2898059	et	3	main
ja	doc_820667236802_item	2898062	et	3	main
poliitika	doc_820667236802_item	2898064	et	4	main
asemel	doc_820667236802_item	2898065	et	4	main
asustama	doc_820667236802_item	2898066	et	3	main
jälle	doc_820667236802_item	2898067	et	3	main
kommunistlik	doc_820667236802_item	2898068	et	3	main
on	doc_820667236802_item	2898082	et	4	main
kui	doc_820667236802_item	2897983	et	3	main
kajastusid	doc_820667236802_item	2897985	et	4	main
selles	doc_820667236802_item	2897986	et	4	main
taasiseseisvumissündmused	doc_820667236802_item	2897989	et	3	main
eesti	doc_820667236802_item	2898000	et	4	main
venemaa	doc_820667236802_item	2898007	et	4	main
mis	doc_820667236802_item	2898013	et	4	main
mängivad	doc_820667236802_item	2898021	et	4	main
ajal	doc_820667236802_item	2898023	et	4	main
eriti	doc_820667236802_item	2898024	et	3	main
televisiooni	doc_820667236802_item	2898031	et	4	main
informatsiooni	doc_820667236802_item	2898041	et	4	main
kõikidest	doc_820667236802_item	2898042	et	4	main
välismaal	doc_820667236802_item	2898048	et	4	main
algas	doc_820667236802_item	2898053	et	3	main
kriis	doc_820667236802_item	2898055	et	3	main
rezhiim	doc_820667236802_item	2898069	et	4	main
samal	doc_820667236802_item	2898070	et	3	main
filmist	doc_820667236802_item	2898081	et	4	main
mõjus	doc_820667236802_item	2898114	et	4	main
kiirustas	doc_820667236802_item	2898116	et	3	main
lõpuks	doc_820667236802_item	2898121	et	4	main
deklaratsiooni	doc_820667236802_item	2898123	et	4	main
võeti	doc_820667236802_item	2898124	et	3	main
vastu	doc_820667236802_item	2898125	et	3	main
töötajad	doc_820667236802_item	2898137	et	4	main
vaadata	doc_820667236802_item	2898145	et	4	main
seda	doc_820667236802_item	2898146	et	3	main
oli	doc_820667236802_item	2898164	et	3	main
1100	doc_820667236802_item	2898167	et	2	main
jõudis	doc_820667236802_item	2898170	et	3	main
kokkuleppele	doc_820667236802_item	2898171	et	3	main
eesti	doc_820667236802_item	2898172	et	4	main
venelased	doc_820667236802_item	2898180	et	3	main
tallinnast	doc_820667236802_item	2898182	et	3	main
nendele	doc_820667236802_item	2898184	et	4	main
kes	doc_820667236802_item	2898185	et	4	main
et	doc_820667236802_item	2898197	et	3	main
selgelt	doc_820667236802_item	2898200	et	4	main
veel	doc_820667236802_item	2898209	et	4	main
üheks	doc_820667236802_item	2898210	et	3	main
toompealt	doc_820667236803_item	2898236	et	3	main
paimla	doc_820667236803_item	2898247	et	4	main
luuletuses	doc_820667236803_item	2898248	et	4	main
toimus	doc_820667236803_item	2898251	et	3	main
balti	doc_820667236803_item	2898255	et	3	main
jaoks	doc_820667236803_item	2898257	et	4	main
3	doc_820667236803_item	2898259	et	2	main
eesti	doc_820667236803_item	2898260	et	4	main
aja-	doc_820667236803_item	2898261	et	4	main
ja	doc_820667236803_item	2898262	et	3	main
toimunud	doc_820667236803_item	2898286	et	4	main
kuritegusid	doc_820667236803_item	2898291	et	4	main
kõik	doc_820667236803_item	2898292	et	4	main
tema	doc_820667236803_item	2898293	et	4	main
tagasi	doc_820667236803_item	2898302	et	3	main
kes	doc_820667236803_item	2898306	et	4	main
1940	doc_820667236803_item	2898309	et	2	main
said	doc_820667236803_item	2898311	et	4	main
nüüd	doc_820667236803_item	2898312	et	4	main
aasta	doc_820667236802_item	2897996	et	4	main
augustil	doc_820667236802_item	2897997	et	3	main
see	doc_820667236802_item	2897998	et	3	main
poliitilised	doc_820667236802_item	2898008	et	3	main
televisioon	doc_820667236802_item	2898020	et	4	main
tol	doc_820667236802_item	2898022	et	3	main
rolli	doc_820667236802_item	2898026	et	4	main
filmi	doc_820667236802_item	2898027	et	4	main
peategelased	doc_820667236802_item	2898028	et	3	main
kelle	doc_820667236802_item	2898033	et	4	main
peaülesanneks	doc_820667236802_item	2898034	et	3	main
oli	doc_820667236802_item	2898035	et	3	main
anda	doc_820667236802_item	2898036	et	3	main
rahvale	doc_820667236802_item	2898037	et	3	main
tegelikult	doc_820667236802_item	2898049	et	4	main
tol	doc_820667236802_item	2898051	et	3	main
ajal	doc_820667236802_item	2898052	et	4	main
mis	doc_820667236802_item	2898056	et	4	main
seisnes	doc_820667236802_item	2898057	et	3	main
mgorbatshovi	doc_820667236802_item	2898061	et	4	main
eestisse	doc_820667236802_item	2898072	et	4	main
tulid	doc_820667236802_item	2898073	et	4	main
tankid	doc_820667236802_item	2898074	et	3	main
oluliste	doc_820667236802_item	2898077	et	4	main
okkupeerimiseks	doc_820667236802_item	2898080	et	4	main
hästi	doc_820667236802_item	2898083	et	3	main
linnas	doc_820667236802_item	2898087	et	4	main
inimestega	doc_820667236802_item	2898088	et	3	main
ja	doc_820667236802_item	2898089	et	3	main
nende	doc_820667236802_item	2898090	et	4	main
reaktsioon	doc_820667236802_item	2898091	et	3	main
rahva	doc_820667236802_item	2898092	et	3	main
seos	doc_820667236802_item	2898093	et	3	main
oli	doc_820667236802_item	2898094	et	3	main
paanika	doc_820667236802_item	2898095	et	4	main
mis	doc_820667236802_item	2898096	et	4	main
oli	doc_820667236802_item	2898097	et	3	main
seotud	doc_820667236802_item	2898098	et	4	main
sõjalise	doc_820667236802_item	2898099	et	4	main
olukorraga	doc_820667236802_item	2898100	et	3	main
ma	doc_820667236802_item	2898101	et	3	main
arvan	doc_820667236802_item	2898102	et	3	main
et	doc_820667236802_item	2898103	et	3	main
teletorni	doc_820667236802_item	2898104	et	4	main
rünnak	doc_820667236802_item	2898105	et	3	main
oli	doc_820667236802_item	2898106	et	3	main
taasiseseisvumisaja	doc_820667236802_item	2898107	et	3	main
olulisemaks	doc_820667236802_item	2898108	et	4	main
sündmuseks	doc_820667236802_item	2898109	et	3	main
selle	doc_820667236802_item	2898110	et	4	main
pärast	doc_820667236802_item	2898111	et	4	main
et	doc_820667236802_item	2898112	et	3	main
see	doc_820667236802_item	2898113	et	3	main
näha	doc_820667236802_item	2898084	et	3	main
toimus	doc_820667236802_item	2898086	et	3	main
riigikogus	doc_820667236802_item	2898133	et	4	main
hääletamine	doc_820667236802_item	2898134	et	4	main
kõik	doc_820667236802_item	2898142	et	4	main
eestis	doc_820667236802_item	2898143	et	3	main
saaksid	doc_820667236802_item	2898144	et	4	main
saame	doc_820667236802_item	2898156	et	4	main
oluline	doc_820667236802_item	2898159	et	4	main
seisukohalt	doc_820667236802_item	2898161	et	4	main
päev	doc_820667236802_item	2898162	et	3	main
tuldi	doc_820667236802_item	2898188	et	3	main
öeldi	doc_820667236802_item	2898190	et	3	main
kõik	doc_820667236802_item	2898205	et	4	main
need	doc_820667236802_item	2898206	et	3	main
ei	doc_820667236803_item	2898222	et	4	main
sest	doc_820667236803_item	2898228	et	4	main
nii	doc_820667236803_item	2898235	et	3	main
gediminasest	doc_820667236803_item	2898238	et	4	main
sisendab	doc_820667236803_item	2898240	et	3	main
hirmu	doc_820667236803_item	2898241	et	4	main
see	doc_820667236803_item	2898242	et	3	main
ahel	doc_820667236803_item	2898243	et	3	main
millisest	doc_820667236803_item	2898244	et	3	main
sündmusest	doc_820667236803_item	2898245	et	4	main
kõneldakse	doc_820667236803_item	2898246	et	3	main
kultuurilugu	doc_820667236803_item	2898263	et	4	main
tunnistati	doc_820667236803_item	2898295	et	4	main
inimesed	doc_820667236803_item	2898297	et	3	main
olid	doc_820667236803_item	2898299	et	4	main
represseeritud	doc_820667236803_item	2898300	et	4	main
tulema	doc_820667236803_item	2898303	et	4	main
näiteks	doc_820667236803_item	2898304	et	4	main
vabalt	doc_820667236803_item	2898313	et	4	main
tegutseda	doc_820667236803_item	2898314	et	3	main
teater	doc_820667236803_item	2898315	et	3	main
laiendus	doc_820667236803_item	2898328	et	4	main
teatud	doc_820667236803_item	2898339	et	4	main
näiteks	doc_820667236803_item	2898344	et	4	main
filme	doc_820667236803_item	2898348	et	3	main
idealistlikult	doc_820667236803_item	2898351	et	4	main
luuletus	doc_820667236803_item	2898361	et	4	main
ühe	doc_820667236803_item	2898363	et	4	main
tallinnast	doc_820667236803_item	2898387	et	3	main
hoides	doc_820667236803_item	2898389	et	4	main
käest	doc_820667236803_item	2898390	et	4	main
kinni	doc_820667236803_item	2898391	et	3	main
nii	doc_820667236803_item	2898392	et	3	main
nad	doc_820667236803_item	2898393	et	3	main
rezhiimi	doc_820667236803_item	2898398	et	4	main
olid	doc_820667236803_item	2898404	et	4	main
ajad	doc_820667236803_item	2898407	et	4	main
riikides	doc_820667236803_item	2898409	et	3	main
oli	doc_820667236803_item	2898410	et	3	main
majanduslik	doc_820667236803_item	2898411	et	3	main
kriis	doc_820667236803_item	2898412	et	3	main
kõik	doc_820667236803_item	2898413	et	4	main
oli	doc_820667236803_item	2898414	et	3	main
halb	doc_820667236803_item	2898415	et	3	main
ja	doc_820667236803_item	2898416	et	3	main
inimesed	doc_820667236803_item	2898417	et	3	main
sellepärast	doc_820667236803_item	2898424	et	3	main
moskvale	doc_820667236803_item	2898435	et	4	main
need	doc_820667236803_item	2898456	et	3	main
elu	doc_820667236803_item	2898459	et	4	main
seadus	doc_820667236803_item	2898469	et	4	main
kus	doc_820667236803_item	2898470	et	3	main
ta	doc_820667236803_item	2898471	et	4	main
joovad	doc_820667236803_item	2898475	et	4	main
aga	doc_820667236803_item	2898477	et	3	main
rämpsu	doc_820667236803_item	2898483	et	4	main
villand	doc_820667236803_item	2898485	et	4	main
parem	doc_820667236803_item	2898522	et	4	main
on	doc_820667236803_item	2898526	et	4	main
rahul	doc_820667236803_item	2898527	et	4	main
on	doc_820667236803_item	2898543	et	4	main
erinevatest	doc_820667236803_item	2898544	et	4	main
lugudest	doc_820667236803_item	2898545	et	3	main
räägivad	doc_820667236803_item	2898553	et	3	main
libahundis	doc_820667236803_item	2898555	et	3	main
et	doc_820667236803_item	2898564	et	3	main
ja	doc_820667236802_item	2898115	et	3	main
kohal	doc_820667236802_item	2898140	et	4	main
et	doc_820667236802_item	2898141	et	3	main
ajal	doc_820667236802_item	2898148	et	4	main
kui	doc_820667236802_item	2898158	et	3	main
see	doc_820667236802_item	2898163	et	3	main
riigikogus	doc_820667236802_item	2898168	et	4	main
delegatsioon	doc_820667236802_item	2898169	et	3	main
käes	doc_820667236802_item	2898179	et	4	main
teletorni	doc_820667236802_item	2898187	et	4	main
ja	doc_820667236802_item	2898189	et	3	main
rünnak	doc_820667236802_item	2898192	et	3	main
läbi	doc_820667236802_item	2898194	et	4	main
filmis	doc_820667236802_item	2898198	et	4	main
eesti	doc_820667236802_item	2898208	et	4	main
kauge	doc_820667236803_item	2898224	et	4	main
ega	doc_820667236803_item	2898226	et	3	main
aga	doc_820667236803_item	2898234	et	3	main
kui	doc_820667236803_item	2898237	et	3	main
riikide	doc_820667236803_item	2898256	et	3	main
tähendas	doc_820667236803_item	2898258	et	3	main
moskvas	doc_820667236803_item	2898285	et	4	main
kritiseeris	doc_820667236803_item	2898289	et	3	main
kes	doc_820667236803_item	2898298	et	4	main
kirjanikud	doc_820667236803_item	2898305	et	3	main
aastatel	doc_820667236803_item	2898310	et	4	main
said	doc_820667236803_item	2898322	et	4	main
tulla	doc_820667236803_item	2898324	et	3	main
kultuuriline	doc_820667236803_item	2898327	et	4	main
vabaduse	doc_820667236803_item	2898333	et	4	main
aga	doc_820667236803_item	2898334	et	3	main
nagu	doc_820667236803_item	2898335	et	3	main
teada	doc_820667236803_item	2898336	et	3	main
sel	doc_820667236803_item	2898337	et	3	main
oli	doc_820667236803_item	2898338	et	3	main
teatreitesse	doc_820667236803_item	2898356	et	4	main
ja	doc_820667236803_item	2898357	et	3	main
kinodesse	doc_820667236803_item	2898358	et	3	main
2	doc_820667236803_item	2898359	et	2	main
see	doc_820667236803_item	2898360	et	3	main
räägib	doc_820667236803_item	2898362	et	3	main
väga	doc_820667236803_item	2898364	et	3	main
tähtsast	doc_820667236803_item	2898365	et	3	main
meelt	doc_820667236803_item	2898396	et	4	main
olid	doc_820667236803_item	2898400	et	4	main
need	doc_820667236803_item	2898403	et	3	main
saada	doc_820667236803_item	2898419	et	4	main
iseseisvaks	doc_820667236803_item	2898420	et	3	main
julge	doc_820667236803_item	2898433	et	4	main
meeleavaldus	doc_820667236803_item	2898434	et	3	main
nn	doc_820667236803_item	2898447	et	4	main
gorbatsev	doc_820667236803_item	2898453	et	4	main
arvas	doc_820667236803_item	2898454	et	3	main
teevad	doc_820667236803_item	2898458	et	3	main
paremaks	doc_820667236803_item	2898460	et	4	main
aga	doc_820667236803_item	2898461	et	3	main
nii	doc_820667236803_item	2898462	et	3	main
see	doc_820667236803_item	2898463	et	3	main
ei	doc_820667236803_item	2898464	et	4	main
iga	doc_820667236803_item	2898481	et	4	main
neile	doc_820667236803_item	2898490	et	4	main
oma	doc_820667236803_item	2898492	et	4	main
päevast	doc_820667236803_item	2898494	et	4	main
elu	doc_820667236803_item	2898495	et	4	main
filme	doc_820667236803_item	2898535	et	3	main
tehakse	doc_820667236803_item	2898536	et	3	main
asjast	doc_820667236803_item	2898538	et	4	main
väga	doc_820667236803_item	2898539	et	3	main
näiteks	doc_820667236803_item	2898546	et	4	main
libahunt	doc_820667236803_item	2898548	et	3	main
ja	doc_820667236803_item	2898549	et	3	main
ma	doc_820667236803_item	2898550	et	3	main
neiu	doc_820667236803_item	2898557	et	4	main
ühe	doc_820667236803_item	2898559	et	4	main
teda	doc_820667236803_item	2898565	et	4	main
tüdrukut	doc_820667236803_item	2898582	et	3	main
raha	doc_820667236803_item	2898591	et	4	main
ja	doc_820667236803_item	2898592	et	3	main
ta	doc_820667236803_item	2898593	et	4	main
need	doc_820667236803_item	2898602	et	3	main
filmid	doc_820667236803_item	2898603	et	4	main
öelda	doc_820667236803_item	2898605	et	4	main
tol	doc_820667236802_item	2898130	et	3	main
selle	doc_820667236802_item	2898122	et	4	main
1991	doc_820667236802_item	2898126	et	2	main
aasta	doc_820667236802_item	2898127	et	4	main
20	doc_820667236802_item	2898128	et	2	main
augustil	doc_820667236802_item	2898129	et	3	main
päeval	doc_820667236802_item	2898131	et	3	main
toimus	doc_820667236802_item	2898132	et	3	main
olid	doc_820667236802_item	2898138	et	4	main
ka	doc_820667236802_item	2898139	et	3	main
hääletamise	doc_820667236802_item	2898147	et	4	main
me	doc_820667236802_item	2898155	et	4	main
ajaloo	doc_820667236802_item	2898160	et	4	main
eestlaste	doc_820667236802_item	2898178	et	4	main
läksid	doc_820667236802_item	2898181	et	4	main
ära	doc_820667236802_item	2898183	et	4	main
et	doc_820667236802_item	2898191	et	3	main
on	doc_820667236802_item	2898193	et	4	main
ma	doc_820667236802_item	2898195	et	3	main
olid	doc_820667236802_item	2898207	et	4	main
võiduks	doc_820667236802_item	2898211	et	4	main
kontrolltöö	doc_820667236803_item	2898212	et	4	main
1	doc_820667236803_item	2898213	et	2	main
1960	doc_820667236803_item	2898214	et	2	main
aastate	doc_820667236803_item	2898215	et	3	main
nn	doc_820667236803_item	2898216	et	4	main
sulaperioodi	doc_820667236803_item	2898217	et	4	main
eesti	doc_820667236803_item	2898218	et	4	main
kultuuri	doc_820667236803_item	2898219	et	4	main
üldiseloomustus	doc_820667236803_item	2898220	et	4	main
väga	doc_820667236802_item	2898152	et	3	main
pingne	doc_820667236802_item	2898153	et	3	main
filmist	doc_820667236802_item	2898154	et	4	main
teada	doc_820667236802_item	2898157	et	3	main
kell	doc_820667236802_item	2898165	et	3	main
umbes	doc_820667236802_item	2898166	et	4	main
sai	doc_820667236802_item	2898173	et	4	main
iseseisvaks	doc_820667236802_item	2898174	et	3	main
ka	doc_820667236802_item	2898175	et	3	main
teletorn	doc_820667236802_item	2898176	et	3	main
jäi	doc_820667236802_item	2898177	et	3	main
kaitsid	doc_820667236802_item	2898186	et	4	main
arvan	doc_820667236802_item	2898196	et	3	main
väga	doc_820667236802_item	2898199	et	3	main
kajastuvad	doc_820667236802_item	2898201	et	4	main
eesti	doc_820667236802_item	2898202	et	4	main
taasiseseisvumissündmused	doc_820667236802_item	2898203	et	3	main
ja	doc_820667236802_item	2898204	et	3	main
2	doc_820667236803_item	2898221	et	2	main
korea	doc_820667236803_item	2898225	et	4	main
vahel	doc_820667236803_item	2898233	et	4	main
millal	doc_820667236803_item	2898249	et	3	main
see	doc_820667236803_item	2898250	et	3	main
mida	doc_820667236803_item	2898253	et	4	main
natuke	doc_820667236803_item	2898281	et	4	main
paremaks	doc_820667236803_item	2898282	et	4	main
1956	doc_820667236803_item	2898283	et	2	main
aastal	doc_820667236803_item	2898284	et	3	main
hrutshjev	doc_820667236803_item	2898288	et	4	main
stalini	doc_820667236803_item	2898290	et	4	main
ebaõiglaseks	doc_820667236803_item	2898296	et	3	main
keelatud	doc_820667236803_item	2898308	et	4	main
paljud	doc_820667236803_item	2898318	et	3	main
teised	doc_820667236803_item	2898319	et	4	main
kultuurilised	doc_820667236803_item	2898320	et	4	main
aima	doc_820667236803_item	2898223	et	4	main
hiina	doc_820667236803_item	2898227	et	3	main
paelast	doc_820667236803_item	2898229	et	4	main
me	doc_820667236803_item	2898230	et	4	main
balti	doc_820667236803_item	2898231	et	3	main
pealinnade	doc_820667236803_item	2898232	et	3	main
moskvale	doc_820667236803_item	2898239	et	4	main
ja	doc_820667236803_item	2898252	et	3	main
see	doc_820667236803_item	2898254	et	3	main
filmis	doc_820667236803_item	2898264	et	4	main
esmajoones	doc_820667236803_item	2898265	et	3	main
loengutes	doc_820667236803_item	2898266	et	4	main
vaadatud	doc_820667236803_item	2898267	et	4	main
filmide	doc_820667236803_item	2898268	et	3	main
põhjal	doc_820667236803_item	2898269	et	4	main
vastused	doc_820667236803_item	2898270	et	3	main
1	doc_820667236803_item	2898271	et	2	main
nagu	doc_820667236803_item	2898272	et	3	main
tead	doc_820667236803_item	2898273	et	4	main
1953	doc_820667236803_item	2898274	et	2	main
aastal	doc_820667236803_item	2898275	et	3	main
suri	doc_820667236803_item	2898276	et	3	main
stalin	doc_820667236803_item	2898277	et	4	main
ja	doc_820667236803_item	2898278	et	3	main
aeg	doc_820667236803_item	2898279	et	3	main
muutus	doc_820667236803_item	2898280	et	4	main
plenumil	doc_820667236803_item	2898287	et	4	main
kuritegusid	doc_820667236803_item	2898294	et	4	main
hakkasid	doc_820667236803_item	2898301	et	4	main
olid	doc_820667236803_item	2898307	et	4	main
kino	doc_820667236803_item	2898316	et	4	main
ja	doc_820667236803_item	2898317	et	3	main
organisatsioonid	doc_820667236803_item	2898321	et	3	main
välja	doc_820667236803_item	2898323	et	4	main
vabadus	doc_820667236803_item	2898340	et	4	main
kinodes	doc_820667236803_item	2898345	et	3	main
mis	doc_820667236803_item	2898349	et	4	main
massilised	doc_820667236803_item	2898354	et	4	main
käigud	doc_820667236803_item	2898355	et	3	main
oma	doc_820667236803_item	2898395	et	4	main
vastu	doc_820667236803_item	2898399	et	3	main
rasked	doc_820667236803_item	2898406	et	3	main
tahtsid	doc_820667236803_item	2898418	et	4	main
nad	doc_820667236803_item	2898421	et	3	main
et	doc_820667236803_item	2898425	et	3	main
neid	doc_820667236803_item	2898426	et	4	main
tähele	doc_820667236803_item	2898428	et	3	main
ei	doc_820667236803_item	2898437	et	4	main
tõttu	doc_820667236803_item	2898446	et	4	main
tegid	doc_820667236803_item	2898449	et	4	main
olnud	doc_820667236803_item	2898465	et	4	main
näiteks	doc_820667236803_item	2898466	et	4	main
nn	doc_820667236803_item	2898467	et	4	main
kuiv	doc_820667236803_item	2898468	et	3	main
inimesed	doc_820667236803_item	2898474	et	3	main
inimesed	doc_820667236803_item	2898478	et	3	main
ütleb	doc_820667236803_item	2898489	et	3	main
inimesed	doc_820667236803_item	2898497	et	3	main
palju	doc_820667236803_item	2898521	et	4	main
ja	doc_820667236803_item	2898523	et	3	main
need	doc_820667236803_item	2898524	et	3	main
inimesed	doc_820667236803_item	2898525	et	3	main
ei	doc_820667236803_item	2898530	et	4	main
ole	doc_820667236803_item	2898531	et	4	main
nõukogude	doc_820667236803_item	2898532	et	3	main
liidus	doc_820667236803_item	2898533	et	4	main
3	doc_820667236803_item	2898534	et	2	main
armastusest	doc_820667236803_item	2898554	et	4	main
üks	doc_820667236803_item	2898556	et	3	main
armastas	doc_820667236803_item	2898558	et	3	main
peati	doc_820667236803_item	2898566	et	4	main
imelikus	doc_820667236803_item	2898567	et	4	main
armastusest	doc_820667236803_item	2898579	et	4	main
aga	doc_820667236803_item	2898583	et	3	main
pärast	doc_820667236803_item	2898585	et	4	main
ei	doc_820667236803_item	2898589	et	4	main
olnud	doc_820667236803_item	2898590	et	4	main
ei	doc_820667236803_item	2898597	et	4	main
olla	doc_820667236803_item	2898601	et	3	main
võib	doc_820667236803_item	2898604	et	3	main
on	doc_820667236803_item	2898606	et	4	main
tehtud	doc_820667236803_item	2898607	et	4	main
ei	doc_820667236803_item	2898613	et	4	main
mis	doc_820667236803_item	2898622	et	4	main
paremina	doc_820667236803_item	2898628	et	4	main
kui	doc_820667236803_item	2898629	et	3	main
mingid	doc_820667236803_item	2898630	et	4	main
armastuse	doc_820667236803_item	2898631	et	4	main
koordis	doc_820667236803_item	2898636	et	4	main
ja	doc_820667236803_item	2898637	et	3	main
eesti	doc_820667236803_item	2898638	et	4	main
paremad	doc_820667236803_item	2898644	et	4	main
näidendid	doc_820667236803_item	2898645	et	3	main
esimene	doc_820667236803_item	2898646	et	3	main
räägib	doc_820667236803_item	2898647	et	3	main
kõik	doc_820667236803_item	2898655	et	4	main
tulid	doc_820667236803_item	2898697	et	4	main
tema	doc_820667236803_item	2898704	et	4	main
neil	doc_820667236803_item	2898714	et	4	main
on	doc_820667236803_item	2898719	et	4	main
kõigest	doc_820667236803_item	2898740	et	4	main
tõelised	doc_820667236803_item	2898749	et	4	main
mitte	doc_820667236803_item	2898750	et	3	main
aga	doc_820667236803_item	2898751	et	3	main
välja	doc_820667236803_item	2898752	et	4	main
kõik	doc_820667236803_item	2898329	et	4	main
kultuurilooinimesed	doc_820667236803_item	2898330	et	3	main
said	doc_820667236803_item	2898331	et	4	main
sest	doc_820667236803_item	2898341	et	4	main
kõike	doc_820667236803_item	2898342	et	4	main
kontrolliti	doc_820667236803_item	2898343	et	3	main
ainult	doc_820667236803_item	2898347	et	4	main
sündmusest	doc_820667236803_item	2898366	et	4	main
eesti	doc_820667236803_item	2898367	et	4	main
ajaloos	doc_820667236803_item	2898368	et	4	main
nn	doc_820667236803_item	2898369	et	4	main
balti	doc_820667236803_item	2898370	et	3	main
kett	doc_820667236803_item	2898371	et	4	main
1989	doc_820667236803_item	2898372	et	2	main
aastal	doc_820667236803_item	2898373	et	3	main
see	doc_820667236803_item	2898374	et	3	main
oli	doc_820667236803_item	2898375	et	3	main
selline	doc_820667236803_item	2898376	et	4	main
sündmus	doc_820667236803_item	2898377	et	3	main
kus	doc_820667236803_item	2898378	et	3	main
balti	doc_820667236803_item	2898380	et	3	main
riikide	doc_820667236803_item	2898381	et	3	main
elanikud	doc_820667236803_item	2898382	et	3	main
3-me	doc_820667236803_item	2898379	et	4	main
seisid	doc_820667236803_item	2898383	et	4	main
keset	doc_820667236803_item	2898384	et	4	main
teed	doc_820667236803_item	2898385	et	4	main
alates	doc_820667236803_item	2898386	et	3	main
avalikusesse	doc_820667236803_item	2898325	et	4	main
toimus	doc_820667236803_item	2898326	et	3	main
suurema	doc_820667236803_item	2898332	et	4	main
näidati	doc_820667236803_item	2898346	et	3	main
olid	doc_820667236803_item	2898350	et	4	main
õiged	doc_820667236803_item	2898352	et	3	main
toimusid	doc_820667236803_item	2898353	et	4	main
1980-ndate	doc_820667236803_item	2898401	et	4	main
lõpud	doc_820667236803_item	2898402	et	3	main
sest	doc_820667236803_item	2898408	et	4	main
seda	doc_820667236803_item	2898423	et	3	main
kes	doc_820667236803_item	2898436	et	4	main
seaduste	doc_820667236803_item	2898445	et	4	main
olukorda	doc_820667236803_item	2898450	et	4	main
halvemaks	doc_820667236803_item	2898452	et	4	main
et	doc_820667236803_item	2898455	et	3	main
uuendused	doc_820667236803_item	2898457	et	4	main
lootis	doc_820667236803_item	2898472	et	3	main
sugust	doc_820667236803_item	2898482	et	3	main
elada	doc_820667236803_item	2898496	et	3	main
et	doc_820667236803_item	2898528	et	3	main
filmid	doc_820667236803_item	2898547	et	4	main
armastasin	doc_820667236803_item	2898551	et	3	main
sakslast	doc_820667236803_item	2898552	et	3	main
tõttu	doc_820667236803_item	2898563	et	4	main
selle	doc_820667236803_item	2898584	et	4	main
et	doc_820667236803_item	2898586	et	3	main
mehel	doc_820667236803_item	2898588	et	3	main
saanud	doc_820667236803_item	2898598	et	4	main
klassikalisele	doc_820667236803_item	2898608	et	4	main
nende	doc_820667236803_item	2898611	et	4	main
kajastavad	doc_820667236803_item	2898623	et	4	main
paremina	doc_820667236803_item	2898624	et	4	main
eesti	doc_820667236803_item	2898625	et	4	main
valgus	doc_820667236803_item	2898635	et	4	main
ajal	doc_820667236803_item	2898654	et	4	main
olla	doc_820667236803_item	2898662	et	3	main
õigele	doc_820667236803_item	2898671	et	3	main
sest	doc_820667236803_item	2898703	et	4	main
lõpuks	doc_820667236803_item	2898713	et	4	main
kaitsta	doc_820667236803_item	2898717	et	4	main
kõrge	doc_820667236803_item	2898723	et	4	main
kultuur	doc_820667236803_item	2898725	et	3	main
tahaks	doc_820667236803_item	2898731	et	3	main
meie	doc_820667236803_item	2898743	et	4	main
mõeldud	doc_820667236803_item	2898753	et	4	main
isiklikku	doc_826196946514_item	2898928	et	4	main
oma	doc_826196946514_item	2898933	et	4	main
päritolust	doc_826196946514_item	2898934	et	3	main
ustav	doc_826196946514_item	2898945	et	4	main
elu	doc_826196946514_item	2898954	et	4	main
mittesakslastega	doc_826196946514_item	2898955	et	3	main
tundub	doc_826196946514_item	2898956	et	3	main
et	doc_826196946514_item	2898957	et	3	main
mida	doc_826196946514_item	2898965	et	4	main
ise	doc_826196946514_item	2898973	et	4	main
ei	doc_826196946514_item	2898974	et	4	main
mõne	doc_826196946514_item	2898987	et	3	main
aja	doc_826196946514_item	2898988	et	4	main
selget	doc_826196946514_item	2898998	et	3	main
kas	doc_826196946514_item	2899000	et	3	main
teda	doc_826196946514_item	2899012	et	4	main
oskar	doc_826196946514_item	2899016	et	4	main
ta	doc_826196946514_item	2899018	et	4	main
nagu	doc_826196946514_item	2899019	et	3	main
vilnuseni	doc_820667236803_item	2898388	et	4	main
avaldasid	doc_820667236803_item	2898394	et	4	main
nõukogude	doc_820667236803_item	2898397	et	3	main
väga	doc_820667236803_item	2898405	et	3	main
tegid	doc_820667236803_item	2898422	et	4	main
paneksid	doc_820667236803_item	2898427	et	4	main
teised	doc_820667236803_item	2898429	et	4	main
inimesed	doc_820667236803_item	2898430	et	3	main
see	doc_820667236803_item	2898431	et	3	main
oli	doc_820667236803_item	2898432	et	3	main
tahtnud	doc_820667236803_item	2898438	et	4	main
et	doc_820667236803_item	2898439	et	3	main
balti	doc_820667236803_item	2898440	et	3	main
riigid	doc_820667236803_item	2898441	et	3	main
muutuksid	doc_820667236803_item	2898442	et	4	main
iseseisvaks	doc_820667236803_item	2898443	et	3	main
gorbatsovi	doc_820667236803_item	2898444	et	4	main
uuendused	doc_820667236803_item	2898448	et	4	main
veelgi	doc_820667236803_item	2898451	et	4	main
et	doc_820667236803_item	2898473	et	3	main
vähem	doc_820667236803_item	2898476	et	4	main
hakkasid	doc_820667236803_item	2898479	et	4	main
jooma	doc_820667236803_item	2898480	et	4	main
oli	doc_820667236803_item	2898484	et	3	main
sellest	doc_820667236803_item	2898486	et	4	main
et	doc_820667236803_item	2898487	et	3	main
moskva	doc_820667236803_item	2898488	et	4	main
kuidas	doc_820667236803_item	2898491	et	3	main
iga	doc_820667236803_item	2898493	et	4	main
tahtsid	doc_820667236803_item	2898498	et	4	main
olla	doc_820667236803_item	2898499	et	3	main
kõiges	doc_820667236803_item	2898501	et	4	main
vabad	doc_820667236803_item	2898500	et	3	main
see	doc_820667236803_item	2898502	et	3	main
kett	doc_820667236803_item	2898503	et	4	main
oli	doc_820667236803_item	2898504	et	3	main
julge	doc_820667236803_item	2898505	et	4	main
samm	doc_820667236803_item	2898506	et	3	main
selle	doc_820667236803_item	2898507	et	4	main
saavutamises	doc_820667236803_item	2898508	et	4	main
lõppude	doc_820667236803_item	2898509	et	4	main
lõpuks	doc_820667236803_item	2898510	et	4	main
need	doc_820667236803_item	2898511	et	3	main
3	doc_820667236803_item	2898512	et	2	main
riiki	doc_820667236803_item	2898513	et	4	main
said	doc_820667236803_item	2898514	et	4	main
vabaks	doc_820667236803_item	2898515	et	3	main
ja	doc_820667236803_item	2898516	et	3	main
nüüd	doc_820667236803_item	2898517	et	4	main
nende	doc_820667236803_item	2898518	et	4	main
olukord	doc_820667236803_item	2898519	et	3	main
on	doc_820667236803_item	2898520	et	4	main
nad	doc_820667236803_item	2898529	et	3	main
igast	doc_820667236803_item	2898537	et	3	main
palju	doc_820667236803_item	2898540	et	4	main
ja	doc_820667236803_item	2898541	et	3	main
nad	doc_820667236803_item	2898542	et	3	main
poissi	doc_820667236803_item	2898560	et	4	main
aga	doc_820667236803_item	2898561	et	3	main
see	doc_820667236803_item	2898562	et	3	main
saanud	doc_820667236803_item	2898571	et	4	main
olla	doc_820667236803_item	2898572	et	3	main
õnnelik	doc_820667236803_item	2898573	et	3	main
ma	doc_820667236803_item	2898574	et	3	main
armastasin	doc_820667236803_item	2898575	et	3	main
sakslast	doc_820667236803_item	2898576	et	3	main
ka	doc_820667236803_item	2898577	et	3	main
räägib	doc_820667236803_item	2898578	et	3	main
armastas	doc_820667236803_item	2898581	et	3	main
nad	doc_820667236803_item	2898599	et	3	main
olla	doc_820667236803_item	2898615	et	3	main
ükskõikne	doc_820667236803_item	2898616	et	3	main
on	doc_820667236803_item	2898617	et	4	main
aga	doc_820667236803_item	2898618	et	3	main
ka	doc_820667236803_item	2898619	et	3	main
teise	doc_820667236803_item	2898620	et	4	main
nõiaks	doc_820667236803_item	2898568	et	3	main
ta	doc_820667236803_item	2898569	et	4	main
ei	doc_820667236803_item	2898570	et	4	main
noormees	doc_820667236803_item	2898580	et	4	main
noor	doc_820667236803_item	2898587	et	3	main
ei	doc_820667236803_item	2898594	et	4	main
olnud	doc_820667236803_item	2898595	et	4	main
sakslane	doc_820667236803_item	2898596	et	3	main
koos	doc_820667236803_item	2898600	et	4	main
teemale	doc_820667236803_item	2898609	et	4	main
peale	doc_820667236803_item	2898612	et	4	main
saa	doc_820667236803_item	2898614	et	4	main
kultuuri	doc_820667236803_item	2898626	et	4	main
filmid	doc_820667236803_item	2898632	et	4	main
need	doc_820667236803_item	2898633	et	3	main
on	doc_820667236803_item	2898634	et	4	main
sellest	doc_820667236803_item	2898648	et	4	main
kui	doc_820667236803_item	2898649	et	3	main
hea	doc_820667236803_item	2898650	et	4	main
on	doc_820667236803_item	2898651	et	4	main
kolhoos	doc_820667236803_item	2898652	et	3	main
põhimõtteliselt	doc_820667236803_item	2898669	et	4	main
suunatud	doc_820667236803_item	2898670	et	4	main
toimus	doc_820667236803_item	2898693	et	3	main
ja	doc_820667236803_item	2898695	et	3	main
eestlased	doc_820667236803_item	2898699	et	3	main
kaitsta	doc_820667236803_item	2898701	et	4	main
mis	doc_820667236803_item	2898709	et	4	main
toimub	doc_820667236803_item	2898710	et	3	main
eestis	doc_820667236803_item	2898711	et	3	main
torni	doc_820667236803_item	2898716	et	4	main
näited	doc_820667236803_item	2898721	et	3	main
on	doc_820667236803_item	2898724	et	4	main
ja	doc_820667236803_item	2898730	et	3	main
mis	doc_820667236803_item	2898741	et	4	main
toimub	doc_820667236803_item	2898742	et	3	main
ja	doc_820667236803_item	2898610	et	3	main
filme	doc_820667236803_item	2898621	et	3	main
need	doc_820667236803_item	2898641	et	3	main
filmid	doc_820667236803_item	2898656	et	4	main
olema	doc_820667236803_item	2898658	et	4	main
ja	doc_820667236803_item	2898660	et	3	main
vastupanelikud	doc_820667236803_item	2898663	et	3	main
teele	doc_820667236803_item	2898672	et	3	main
putsh	doc_820667236803_item	2898694	et	4	main
eestis	doc_820667236803_item	2898696	et	3	main
tankid	doc_820667236803_item	2898698	et	3	main
tahtsid	doc_820667236803_item	2898700	et	4	main
kaudu	doc_820667236803_item	2898705	et	3	main
välisriigid	doc_820667236803_item	2898706	et	3	main
saaksid	doc_820667236803_item	2898707	et	4	main
teada	doc_820667236803_item	2898708	et	3	main
õnnestus	doc_820667236803_item	2898715	et	4	main
head	doc_820667236803_item	2898720	et	4	main
kui	doc_820667236803_item	2898722	et	3	main
elu	doc_820667236803_item	2898627	et	4	main
teletorni	doc_820667236803_item	2898639	et	4	main
lugu	doc_820667236803_item	2898640	et	4	main
filmid	doc_820667236803_item	2898642	et	4	main
on	doc_820667236803_item	2898643	et	4	main
nõukogude	doc_820667236803_item	2898653	et	3	main
pidid	doc_820667236803_item	2898657	et	4	main
õiged	doc_820667236803_item	2898659	et	3	main
mitte	doc_820667236803_item	2898661	et	3	main
moskvale	doc_820667236803_item	2898664	et	4	main
tol	doc_820667236803_item	2898665	et	3	main
ajal	doc_820667236803_item	2898666	et	4	main
kultuur	doc_820667236803_item	2898667	et	3	main
oli	doc_820667236803_item	2898668	et	3	main
see	doc_820667236803_item	2898673	et	3	main
tähendas	doc_820667236803_item	2898674	et	3	main
tsensuuri	doc_820667236803_item	2898675	et	4	main
teine	doc_820667236803_item	2898676	et	3	main
film	doc_820667236803_item	2898677	et	3	main
aga	doc_820667236803_item	2898678	et	3	main
on	doc_820667236803_item	2898679	et	4	main
ajalooline	doc_820667236803_item	2898680	et	4	main
see	doc_820667236803_item	2898681	et	3	main
on	doc_820667236803_item	2898682	et	4	main
tehtus	doc_820667236803_item	2898683	et	4	main
pärisjuhtunud	doc_820667236803_item	2898684	et	3	main
sündmustel	doc_820667236803_item	2898685	et	3	main
see	doc_820667236803_item	2898686	et	3	main
film	doc_820667236803_item	2898687	et	3	main
räägib	doc_820667236803_item	2898688	et	3	main
sellest	doc_820667236803_item	2898689	et	4	main
ajast	doc_820667236803_item	2898690	et	4	main
kui	doc_820667236803_item	2898691	et	3	main
moskvas	doc_820667236803_item	2898692	et	4	main
teletorni	doc_820667236803_item	2898702	et	4	main
lõppude	doc_820667236803_item	2898712	et	4	main
filmid	doc_820667236803_item	2898718	et	4	main
või	doc_820667236803_item	2898726	et	4	main
ajalugu	doc_820667236803_item	2898727	et	4	main
meile	doc_820667236803_item	2898739	et	4	main
identiteediprobleemid	doc_826196946514_item	2898922	et	3	main
on	doc_826196946514_item	2898923	et	4	main
erikal	doc_826196946514_item	2898925	et	4	main
tal	doc_826196946514_item	2898926	et	3	main
polnud	doc_826196946514_item	2898927	et	3	main
täielikult	doc_826196946514_item	2898932	et	4	main
oma	doc_826196946514_item	2898946	et	4	main
erika	doc_826196946514_item	2898949	et	4	main
erika	doc_826196946514_item	2898958	et	4	main
naine	doc_826196946514_item	2898961	et	3	main
võib	doc_826196946514_item	2898963	et	3	main
ta	doc_826196946514_item	2898977	et	4	main
pigem	doc_826196946514_item	2898978	et	3	main
on	doc_826196946514_item	2898979	et	4	main
kas	doc_826196946514_item	2898980	et	3	main
sakslane	doc_826196946514_item	2898981	et	3	main
või	doc_826196946514_item	2898982	et	4	main
eestlane	doc_826196946514_item	2898983	et	3	main
kindlat	doc_826196946514_item	2898996	et	3	main
mõistust	doc_826196946514_item	2898999	et	4	main
kodus	doc_826196946514_item	2899008	et	4	main
poole	doc_826196946514_item	2899014	et	4	main
teistele	doc_826196946514_item	2899017	et	4	main
mingist	doc_820667236803_item	2898728	et	4	main
ajavahemikust	doc_820667236803_item	2898729	et	4	main
loota	doc_820667236803_item	2898732	et	4	main
et	doc_820667236803_item	2898733	et	3	main
koguaeg	doc_820667236803_item	2898734	et	3	main
tehakse	doc_820667236803_item	2898735	et	3	main
filme	doc_820667236803_item	2898736	et	3	main
mis	doc_820667236803_item	2898737	et	4	main
räägivad	doc_820667236803_item	2898738	et	3	main
elus	doc_820667236803_item	2898744	et	4	main
ja	doc_820667236803_item	2898745	et	3	main
et	doc_820667236803_item	2898746	et	3	main
nad	doc_820667236803_item	2898747	et	3	main
oleksid	doc_820667236803_item	2898748	et	4	main
suuremad	doc_826196946514_item	2898921	et	4	main
vabadust	doc_826196946514_item	2898929	et	4	main
ideaalidele	doc_826196946514_item	2898948	et	3	main
erika	doc_826196946514_item	2898972	et	4	main
kes	doc_826196946514_item	2898976	et	4	main
pärast	doc_826196946514_item	2898989	et	4	main
ja	doc_826196946514_item	2898990	et	3	main
see	doc_826196946514_item	2898991	et	3	main
näitab	doc_826196946514_item	2898992	et	3	main
et	doc_826196946514_item	2898993	et	3	main
tal	doc_826196946514_item	2898994	et	3	main
ristmikule	doc_826196946514_item	2899021	et	4	main
sest	doc_826196946514_item	2899035	et	4	main
oskar	doc_826196946514_item	2899036	et	4	main
jättis	doc_826196946514_item	2899037	et	3	main
et	doc_826196946514_item	2899056	et	3	main
kõrval	doc_826196946514_item	2899071	et	4	main
nagu	doc_826196946514_item	2899080	et	3	main
1	doc_826196946514_item	2899082	et	2	main
suuremaks	doc_826196946514_item	2899084	et	4	main
probleemiks	doc_826196946514_item	2899085	et	4	main
eestist	doc_826196946514_item	2899095	et	3	main
põlevkivi	doc_826196946514_item	2899098	et	4	main
öelda	doc_826196946514_item	2899100	et	4	main
et	doc_826196946514_item	2899101	et	3	main
eesti	doc_826196946514_item	2899102	et	4	main
varustas	doc_826196946514_item	2899103	et	3	main
energiaga	doc_826196946514_item	2899104	et	3	main
kaevandama	doc_826196946514_item	2899113	et	3	main
probleemiks	doc_826196946514_item	2899127	et	4	main
võib	doc_826196946514_item	2899128	et	3	main
peeta	doc_826196946514_item	2899129	et	4	main
neid	doc_826196946514_item	2899134	et	4	main
kasutati	doc_826196946514_item	2899135	et	4	main
veel	doc_826196946514_item	2899142	et	4	main
võõraste	doc_826196946514_item	2899147	et	4	main
toomine	doc_826196946514_item	2899152	et	4	main
maisi	doc_826196946514_item	2899159	et	4	main
rikkumisele	doc_826196946514_item	2899181	et	4	main
on	doc_826196946514_item	2899210	et	4	main
jaoks	doc_826196946514_item	2899214	et	4	main
said	doc_826196946514_item	2899226	et	4	main
ilmuma	doc_826196946514_item	2899232	et	3	main
looduskaitsjate	doc_826196946514_item	2899233	et	3	main
ühingud	doc_826196946514_item	2899234	et	3	main
1	doc_833156154878_item	2899236	et	2	main
eesti	doc_833156154878_item	2899238	et	4	main
arheoloogiline	doc_833156154878_item	2899242	et	4	main
tähendus	doc_833156154878_item	2899244	et	4	main
sellelt	doc_833156154878_item	2899282	et	4	main
kiviaeg	doc_833156154878_item	2899289	et	3	main
jahimeeste	doc_833156154878_item	2899292	et	4	main
metsaandide	doc_833156154878_item	2899294	et	3	main
niisugused	doc_833156154878_item	2899301	et	3	main
mehed	doc_833156154878_item	2899310	et	3	main
kitse	doc_833156154878_item	2899313	et	4	main
puust	doc_833156154878_item	2899320	et	4	main
kivist	doc_833156154878_item	2899323	et	4	main
väiksemaid	doc_833156154878_item	2899324	et	4	main
tööriistu	doc_833156154878_item	2899325	et	3	main
tehtud	doc_833156154878_item	2899335	et	4	main
ehitistes	doc_833156154878_item	2899336	et	3	main
kontrolltöö	doc_826196946514_item	2898893	et	4	main
1	doc_826196946514_item	2898894	et	2	main
majanduse	doc_826196946514_item	2898895	et	4	main
ja	doc_826196946514_item	2898896	et	3	main
loodushoiu	doc_826196946514_item	2898897	et	3	main
vastasseis	doc_826196946514_item	2898898	et	3	main
1970ndate	doc_826196946514_item	2898899	et	4	main
eesti	doc_826196946514_item	2898900	et	4	main
nsv-s	doc_826196946514_item	2898901	et	3	main
2	doc_826196946514_item	2898902	et	2	main
kellel	doc_826196946514_item	2898903	et	4	main
on	doc_826196946514_item	2898904	et	4	main
teie	doc_826196946514_item	2898905	et	4	main
arvates	doc_826196946514_item	2898906	et	4	main
suuremad	doc_826196946514_item	2898907	et	4	main
identiteediprobleemid	doc_826196946514_item	2898908	et	3	main
kas	doc_826196946514_item	2898909	et	3	main
erikal	doc_826196946514_item	2898910	et	4	main
või	doc_826196946514_item	2898911	et	4	main
oskaril	doc_826196946514_item	2898912	et	4	main
tammsaare	doc_826196946514_item	2898913	et	3	main
ma	doc_826196946514_item	2898914	et	3	main
armastasin	doc_826196946514_item	2898915	et	3	main
sakslast	doc_826196946514_item	2898916	et	3	main
põhjendage	doc_826196946514_item	2898917	et	3	main
2	doc_826196946514_item	2898918	et	2	main
minu	doc_826196946514_item	2898919	et	3	main
arvates	doc_826196946514_item	2898920	et	4	main
siiski	doc_826196946514_item	2898924	et	4	main
ta	doc_826196946514_item	2898930	et	4	main
sõltus	doc_826196946514_item	2898931	et	4	main
erika	doc_826196946514_item	2898935	et	4	main
oli	doc_826196946514_item	2898936	et	3	main
takista	doc_826196946514_item	2898940	et	4	main
sakslane	doc_826196946514_item	2898937	et	3	main
ja	doc_826196946514_item	2898938	et	3	main
see	doc_826196946514_item	2898939	et	3	main
ta	doc_826196946514_item	2898941	et	4	main
suhteid	doc_826196946514_item	2898942	et	3	main
oskariga	doc_826196946514_item	2898943	et	4	main
olles	doc_826196946514_item	2898944	et	3	main
isa	doc_826196946514_item	2898947	et	4	main
ei	doc_826196946514_item	2898950	et	4	main
tahtnud	doc_826196946514_item	2898951	et	4	main
siduda	doc_826196946514_item	2898952	et	3	main
polnud	doc_826196946514_item	2898959	et	3	main
kes	doc_826196946514_item	2898962	et	4	main
teha	doc_826196946514_item	2898964	et	3	main
ise	doc_826196946514_item	2898966	et	4	main
tahab	doc_826196946514_item	2898967	et	3	main
ja	doc_826196946514_item	2898968	et	3	main
peab	doc_826196946514_item	2898969	et	4	main
õigeks	doc_826196946514_item	2898970	et	3	main
teadnud	doc_826196946514_item	2898975	et	4	main
polnud	doc_826196946514_item	2898995	et	3	main
ta	doc_826196946514_item	2899001	et	4	main
üldse	doc_826196946514_item	2899002	et	3	main
tahab	doc_826196946514_item	2899003	et	3	main
tulevikus	doc_826196946514_item	2899004	et	4	main
peeta	doc_826196946514_item	2899005	et	4	main
kaldus	doc_826196946514_item	2899011	et	4	main
aga	doc_826196946514_item	2899015	et	3	main
ja	doc_826196946514_item	2899022	et	3	main
polnud	doc_826196946514_item	2899023	et	3	main
kuhu	doc_826196946514_item	2899025	et	3	main
minna	doc_826196946514_item	2899027	et	3	main
need	doc_826196946514_item	2899029	et	3	main
probleemid	doc_826196946514_item	2899030	et	3	main
tulevikku	doc_826196946514_item	2899033	et	4	main
maha	doc_826196946514_item	2899039	et	4	main
mõeldes	doc_826196946514_item	2899040	et	3	main
et	doc_826196946514_item	2899041	et	3	main
niiviisi	doc_826196946514_item	2899042	et	3	main
rahulikult	doc_826196946514_item	2899049	et	4	main
elada	doc_826196946514_item	2899050	et	3	main
arvan	doc_826196946514_item	2899055	et	3	main
identiteediprobleemid	doc_826196946514_item	2899057	et	3	main
sai	doc_826196946514_item	2899086	et	4	main
aastatel	doc_826196946514_item	2899091	et	4	main
kui	doc_826196946514_item	2899092	et	3	main
mahus	doc_826196946514_item	2899097	et	3	main
võib	doc_826196946514_item	2899099	et	3	main
kogu	doc_826196946514_item	2899105	et	4	main
suured	doc_826196946514_item	2899121	et	3	main
asusid	doc_826196946514_item	2899123	et	4	main
liiva	doc_826196946514_item	2899130	et	4	main
ja	doc_826196946514_item	2899131	et	3	main
kruusi	doc_826196946514_item	2899132	et	4	main
taimede	doc_826196946514_item	2899150	et	4	main
hruštšovi	doc_826196946514_item	2899154	et	2	main
põldudele	doc_826196946514_item	2899157	et	3	main
märksamaks	doc_826196946514_item	2899163	et	4	main
teisi	doc_826196946514_item	2899170	et	4	main
loomi	doc_826196946514_item	2899171	et	4	main
see	doc_826196946514_item	2899172	et	3	main
ja	doc_826196946514_item	2899182	et	3	main
vähenemist	doc_826196946514_item	2899221	et	4	main
mõustus	doc_826196946514_item	2899223	et	4	main
sest	doc_826196946514_item	2899224	et	4	main
agressivset	doc_826196946514_item	2899227	et	4	main
kontrolltöö	doc_833156154878_item	2899235	et	4	main
1	doc_833156154878_item	2899245	et	2	main
pulli	doc_833156154878_item	2899254	et	4	main
esimene	doc_833156154878_item	2899256	et	3	main
aa	doc_833156154878_item	2899270	et	3	main
saadi	doc_833156154878_item	2899283	et	4	main
oli	doc_833156154878_item	2899290	et	3	main
pärit	doc_833156154878_item	2899300	et	3	main
küttisid	doc_833156154878_item	2899309	et	4	main
kobrast	doc_833156154878_item	2899315	et	4	main
ja	doc_833156154878_item	2899317	et	3	main
jahiriistu	doc_833156154878_item	2899318	et	3	main
savist	doc_833156154878_item	2899321	et	4	main
ja	doc_833156154878_item	2899329	et	3	main
moodustasid	doc_833156154878_item	2899344	et	4	main
toitu	doc_833156154878_item	2899353	et	4	main
oma	doc_826196946514_item	2898953	et	4	main
iseseisev	doc_826196946514_item	2898960	et	3	main
tegelikult	doc_826196946514_item	2898971	et	4	main
ta	doc_826196946514_item	2898984	et	4	main
hakkas	doc_826196946514_item	2898985	et	3	main
kahtlema	doc_826196946514_item	2898986	et	3	main
ja	doc_826196946514_item	2898997	et	3	main
ennast	doc_826196946514_item	2899006	et	4	main
sakslaseks	doc_826196946514_item	2899007	et	3	main
istuv	doc_826196946514_item	2899009	et	4	main
isa	doc_826196946514_item	2899010	et	4	main
ühele	doc_826196946514_item	2899013	et	3	main
edasi	doc_826196946514_item	2899026	et	3	main
ja	doc_826196946514_item	2899028	et	3	main
parem	doc_826196946514_item	2899044	et	4	main
ja	doc_826196946514_item	2899045	et	3	main
nüüd	doc_826196946514_item	2899046	et	4	main
ennast	doc_826196946514_item	2899053	et	4	main
on	doc_826196946514_item	2899058	et	4	main
keel	doc_826196946514_item	2899077	et	4	main
ekoloogia	doc_826196946514_item	2899087	et	4	main
tasakaalu	doc_826196946514_item	2899088	et	4	main
nõudis	doc_826196946514_item	2899094	et	3	main
selleäärseid	doc_826196946514_item	2899109	et	3	main
liiga	doc_826196946514_item	2899114	et	4	main
mis	doc_826196946514_item	2899116	et	4	main
eriti	doc_826196946514_item	2899120	et	3	main
nappardumist	doc_826196946514_item	2899133	et	4	main
ära	doc_826196946514_item	2899141	et	4	main
loodusele	doc_826196946514_item	2899146	et	4	main
sisse	doc_826196946514_item	2899151	et	4	main
on	doc_826196946514_item	2899160	et	4	main
selle	doc_826196946514_item	2899161	et	4	main
kõige	doc_826196946514_item	2899162	et	4	main
on	doc_826196946514_item	2899173	et	4	main
sest	doc_826196946514_item	2899176	et	4	main
see	doc_826196946514_item	2899177	et	3	main
viib	doc_826196946514_item	2899178	et	3	main
loodusliku	doc_826196946514_item	2899179	et	3	main
tasakaalu	doc_826196946514_item	2899180	et	4	main
aktiviseerumisele	doc_826196946514_item	2899207	et	4	main
ohtlik	doc_826196946514_item	2899212	et	3	main
mahu	doc_826196946514_item	2899220	et	4	main
astus	doc_826196946514_item	2899020	et	3	main
elu	doc_826196946514_item	2899034	et	4	main
on	doc_826196946514_item	2899043	et	4	main
ta	doc_826196946514_item	2899051	et	4	main
leiab	doc_826196946514_item	2899052	et	3	main
keele	doc_826196946514_item	2899070	et	4	main
ka	doc_826196946514_item	2899074	et	3	main
mingi	doc_826196946514_item	2899075	et	4	main
teine	doc_826196946514_item	2899076	et	3	main
moskva	doc_826196946514_item	2899093	et	4	main
leningradi	doc_826196946514_item	2899106	et	4	main
oblastit	doc_826196946514_item	2899107	et	3	main
rajoone	doc_826196946514_item	2899110	et	3	main
hakati	doc_826196946514_item	2899112	et	3	main
intensiivselt	doc_826196946514_item	2899115	et	4	main
põhjustas	doc_826196946514_item	2899117	et	3	main
ekoloogilisi	doc_826196946514_item	2899118	et	4	main
probleeme	doc_826196946514_item	2899119	et	3	main
kindel	doc_826196946514_item	2899024	et	3	main
rikkusid	doc_826196946514_item	2899031	et	4	main
ta	doc_826196946514_item	2899032	et	4	main
ta	doc_826196946514_item	2899038	et	4	main
erika	doc_826196946514_item	2899047	et	4	main
saab	doc_826196946514_item	2899048	et	3	main
ma	doc_826196946514_item	2899054	et	3	main
alati	doc_826196946514_item	2899059	et	4	main
ja	doc_826196946514_item	2899060	et	3	main
igalühel	doc_826196946514_item	2899061	et	3	main
eriti	doc_826196946514_item	2899062	et	3	main
tihti	doc_826196946514_item	2899063	et	3	main
juhtub	doc_826196946514_item	2899064	et	3	main
see	doc_826196946514_item	2899065	et	3	main
olukord	doc_826196946514_item	2899066	et	3	main
riikides	doc_826196946514_item	2899067	et	3	main
kus	doc_826196946514_item	2899068	et	3	main
riikliku	doc_826196946514_item	2899069	et	3	main
saab	doc_826196946514_item	2899072	et	3	main
leviku	doc_826196946514_item	2899073	et	3	main
ja	doc_826196946514_item	2899078	et	3	main
rahvus	doc_826196946514_item	2899079	et	3	main
eestis	doc_826196946514_item	2899081	et	3	main
kõige	doc_826196946514_item	2899083	et	4	main
rikkus	doc_826196946514_item	2899089	et	4	main
70ndatel	doc_826196946514_item	2899090	et	4	main
suures	doc_826196946514_item	2899096	et	3	main
ja	doc_826196946514_item	2899108	et	3	main
põlevkivi	doc_826196946514_item	2899111	et	4	main
võib	doc_826196946514_item	2899143	et	3	main
nimetada	doc_826196946514_item	2899144	et	3	main
eesti	doc_826196946514_item	2899145	et	4	main
ja	doc_826196946514_item	2899149	et	3	main
levitada	doc_826196946514_item	2899156	et	3	main
eestis	doc_826196946514_item	2899158	et	3	main
ohtlik	doc_826196946514_item	2899175	et	3	main
väga	doc_826196946514_item	2899211	et	3	main
keskkonna	doc_826196946514_item	2899213	et	3	main
ja	doc_826196946514_item	2899215	et	3	main
looduskaitsjad	doc_826196946514_item	2899216	et	3	main
nõudsid	doc_826196946514_item	2899217	et	4	main
selle	doc_826196946514_item	2899218	et	4	main
kaevandamise	doc_826196946514_item	2899219	et	4	main
valitsus	doc_826196946514_item	2899222	et	4	main
vormi	doc_826196946514_item	2899228	et	4	main
peale	doc_826196946514_item	2899229	et	4	main
seda	doc_826196946514_item	2899230	et	3	main
territooriumil	doc_833156154878_item	2899239	et	3	main
7500	doc_833156154878_item	2899246	et	2	main
ekr	doc_833156154878_item	2899248	et	4	main
küla	doc_833156154878_item	2899255	et	4	main
olid	doc_833156154878_item	2899273	et	4	main
põhjapõtraküttid	doc_833156154878_item	2899274	et	4	main
liha	doc_833156154878_item	2899284	et	4	main
nahka	doc_833156154878_item	2899285	et	4	main
ja	doc_833156154878_item	2899286	et	3	main
kalastajate	doc_833156154878_item	2899291	et	4	main
ja	doc_833156154878_item	2899293	et	3	main
korjajate	doc_833156154878_item	2899295	et	4	main
õitsenguaeg	doc_833156154878_item	2899296	et	4	main
tolt	doc_833156154878_item	2899297	et	3	main
siig	doc_833156154878_item	2899304	et	3	main
hauk	doc_833156154878_item	2899305	et	4	main
peale	doc_833156154878_item	2899307	et	4	main
põhjapõtra	doc_833156154878_item	2899308	et	4	main
valmistati	doc_833156154878_item	2899319	et	4	main
kvartsist	doc_833156154878_item	2899330	et	4	main
elati	doc_833156154878_item	2899331	et	3	main
puitkodades	doc_833156154878_item	2899332	et	3	main
koonusekujulistes	doc_833156154878_item	2899333	et	4	main
puuokstest	doc_833156154878_item	2899334	et	3	main
kodukondadega	doc_833156154878_item	2899345	et	4	main
püstkoja	doc_833156154878_item	2899346	et	3	main
keskel	doc_833156154878_item	2899347	et	3	main
ajal	doc_833156154878_item	2899355	et	4	main
oli	doc_833156154878_item	2899356	et	3	main
väga	doc_833156154878_item	2899357	et	3	main
keeruline	doc_833156154878_item	2899358	et	4	main
hoolisid	doc_833156154878_item	2899362	et	4	main
keha	doc_833156154878_item	2899364	et	4	main
surnuid	doc_833156154878_item	2899366	et	4	main
vahel	doc_833156154878_item	2899370	et	4	main
ja	doc_833156154878_item	2899379	et	3	main
esimene	doc_833156154878_item	2899421	et	3	main
narva	doc_833156154878_item	2899431	et	4	main
ja	doc_833156154878_item	2899444	et	3	main
2500-2200	doc_833156154878_item	2899447	et	2	main
nööri	doc_833156154878_item	2899471	et	4	main
muutusid	doc_833156154878_item	2899512	et	4	main
matmiskombed	doc_833156154878_item	2899513	et	3	main
maeti	doc_833156154878_item	2899514	et	3	main
inimgrupile	doc_833156154878_item	2899534	et	3	main
arheoloogiliste	doc_833156154878_item	2899543	et	4	main
kontrolltöö	doc_833156154879_item	2899546	et	4	main
vanem	doc_833156154879_item	2899562	et	4	main
iv	doc_833156154879_item	2899571	et	4	main
mesoliitikumi	doc_833156154879_item	2899592	et	4	main
ajal	doc_833156154879_item	2899593	et	4	main
võib	doc_833156154879_item	2899626	et	3	main
juurikaid	doc_833156154879_item	2899638	et	4	main
kaevandused	doc_826196946514_item	2899122	et	4	main
põhja-eestis	doc_826196946514_item	2899124	et	3	main
teiseks	doc_826196946514_item	2899125	et	4	main
suuremaks	doc_826196946514_item	2899126	et	4	main
mõtlematule	doc_826196946514_item	2899136	et	4	main
ja	doc_826196946514_item	2899137	et	3	main
varsti	doc_826196946514_item	2899138	et	3	main
varad	doc_826196946514_item	2899139	et	3	main
lõppesid	doc_826196946514_item	2899140	et	4	main
loomade	doc_826196946514_item	2899148	et	4	main
metsadesse	doc_826196946514_item	2899153	et	3	main
proov	doc_826196946514_item	2899155	et	3	main
näteks	doc_826196946514_item	2899164	et	4	main
veel	doc_826196946514_item	2899165	et	4	main
prooviti	doc_826196946514_item	2899166	et	3	main
sisse	doc_826196946514_item	2899167	et	4	main
tooma	doc_826196946514_item	2899168	et	3	main
kobrast	doc_826196946514_item	2899169	et	4	main
väga	doc_826196946514_item	2899174	et	3	main
järelikult	doc_826196946514_item	2899183	et	3	main
teiste	doc_826196946514_item	2899184	et	4	main
loomade	doc_826196946514_item	2899185	et	4	main
ja	doc_826196946514_item	2899186	et	3	main
väljasuremisele	doc_826196946514_item	2899188	et	3	main
olid	doc_826196946514_item	2899189	et	4	main
taimede	doc_826196946514_item	2899187	et	4	main
ka	doc_826196946514_item	2899190	et	3	main
teised	doc_826196946514_item	2899191	et	4	main
väiksemad	doc_826196946514_item	2899192	et	4	main
probleemid	doc_826196946514_item	2899193	et	3	main
nagu	doc_826196946514_item	2899194	et	3	main
mineraalvee	doc_826196946514_item	2899195	et	3	main
puudumine	doc_826196946514_item	2899196	et	4	main
70ndate	doc_826196946514_item	2899197	et	4	main
lõpus	doc_826196946514_item	2899198	et	4	main
hakati	doc_826196946514_item	2899199	et	3	main
eestis	doc_826196946514_item	2899200	et	3	main
kaevandama	doc_826196946514_item	2899201	et	3	main
fosforiiti	doc_826196946514_item	2899202	et	4	main
oli	doc_826196946514_item	2899204	et	3	main
see	doc_826196946514_item	2899203	et	3	main
põhjuseks	doc_826196946514_item	2899205	et	3	main
looduskaitsjate	doc_826196946514_item	2899206	et	3	main
fosforiidi	doc_826196946514_item	2899208	et	4	main
kaevandamine	doc_826196946514_item	2899209	et	4	main
protestid	doc_826196946514_item	2899225	et	4	main
hakkasid	doc_826196946514_item	2899231	et	4	main
2	doc_833156154878_item	2899240	et	2	main
lähedal	doc_833156154878_item	2899253	et	4	main
asula	doc_833156154878_item	2899257	et	4	main
eesti	doc_833156154878_item	2899258	et	4	main
ekr	doc_833156154878_item	2899271	et	4	main
oli	doc_833156154878_item	2899276	et	3	main
tol	doc_833156154878_item	2899277	et	3	main
ajalt	doc_833156154878_item	2899298	et	4	main
kalanimetused	doc_833156154878_item	2899302	et	4	main
ka	doc_833156154878_item	2899311	et	3	main
tulekivist	doc_833156154878_item	2899328	et	4	main
püstkoda	doc_833156154878_item	2899343	et	4	main
peal	doc_833156154878_item	2899351	et	4	main
küpsetati	doc_833156154878_item	2899352	et	3	main
süsteem	doc_833156154878_item	2899360	et	3	main
maeti	doc_833156154878_item	2899367	et	3	main
asula	doc_833156154878_item	2899368	et	4	main
territooriumile	doc_833156154878_item	2899369	et	3	main
väikeseid	doc_833156154878_item	2899377	et	4	main
tööriistu	doc_833156154878_item	2899378	et	3	main
loomakujukesi	doc_833156154878_item	2899381	et	4	main
tol	doc_833156154878_item	2899383	et	3	main
kiviaeg	doc_833156154878_item	2899237	et	3	main
mõiste	doc_833156154878_item	2899241	et	4	main
kultuur	doc_833156154878_item	2899243	et	3	main
a	doc_833156154878_item	2899247	et	4	main
pärnu	doc_833156154878_item	2899249	et	4	main
jõe	doc_833156154878_item	2899250	et	3	main
kaldal	doc_833156154878_item	2899251	et	3	main
sindi	doc_833156154878_item	2899252	et	4	main
territooriumil	doc_833156154878_item	2899259	et	3	main
tähendab	doc_833156154878_item	2899260	et	3	main
eesti	doc_833156154878_item	2899261	et	4	main
territooriumile	doc_833156154878_item	2899262	et	3	main
asusid	doc_833156154878_item	2899263	et	4	main
esimesed	doc_833156154878_item	2899264	et	3	main
inimesed	doc_833156154878_item	2899265	et	3	main
ainult	doc_833156154878_item	2899266	et	4	main
mesoliitikumis	doc_833156154878_item	2899267	et	3	main
7500	doc_833156154878_item	2899268	et	2	main
3000	doc_833156154878_item	2899269	et	2	main
nad	doc_833156154878_item	2899272	et	3	main
põder	doc_833156154878_item	2899275	et	3	main
ajal	doc_833156154878_item	2899278	et	4	main
väga	doc_833156154878_item	2899279	et	3	main
hea	doc_833156154878_item	2899280	et	4	main
saak	doc_833156154878_item	2899281	et	3	main
rasva	doc_833156154878_item	2899287	et	4	main
keskmine	doc_833156154878_item	2899288	et	3	main
on	doc_833156154878_item	2899299	et	4	main
nagu	doc_833156154878_item	2899303	et	3	main
rääbis	doc_833156154878_item	2899306	et	3	main
metssiga	doc_833156154878_item	2899312	et	4	main
ja	doc_833156154878_item	2899314	et	3	main
töö-	doc_833156154878_item	2899316	et	4	main
ja	doc_833156154878_item	2899322	et	3	main
tehti	doc_833156154878_item	2899326	et	3	main
isegi	doc_833156154878_item	2899327	et	4	main
asus	doc_833156154878_item	2899348	et	4	main
isegi	doc_833156154878_item	2899371	et	4	main
püstkoja	doc_833156154878_item	2899372	et	3	main
põranda	doc_833156154878_item	2899373	et	3	main
alla	doc_833156154878_item	2899374	et	3	main
ajal	doc_833156154878_item	2899384	et	4	main
oli	doc_833156154878_item	2899385	et	3	main
ja	doc_833156154878_item	2899388	et	3	main
amuletidel	doc_833156154878_item	2899389	et	4	main
eriti	doc_833156154878_item	2899390	et	3	main
päikesekivist	doc_833156154878_item	2899391	et	4	main
oli	doc_833156154878_item	2899392	et	3	main
suur	doc_833156154878_item	2899393	et	3	main
tähendus	doc_833156154878_item	2899394	et	4	main
merevaiku	doc_833156154878_item	2899395	et	4	main
pandi	doc_833156154878_item	2899396	et	4	main
isegi	doc_833156154878_item	2899397	et	4	main
surnu	doc_833156154878_item	2899398	et	4	main
inimese	doc_833156154878_item	2899399	et	4	main
silmadele	doc_833156154878_item	2899400	et	3	main
surnuid	doc_833156154878_item	2899401	et	4	main
maeti	doc_833156154878_item	2899402	et	3	main
asendis	doc_833156154878_item	2899403	et	3	main
nagu	doc_833156154878_item	2899404	et	3	main
ta	doc_833156154878_item	2899405	et	4	main
magab	doc_833156154878_item	2899406	et	3	main
sest	doc_833156154878_item	2899407	et	4	main
surm	doc_833156154878_item	2899408	et	3	main
oli	doc_833156154878_item	2899409	et	3	main
kindel	doc_833156154878_item	2899410	et	3	main
ja	doc_833156154878_item	2899411	et	3	main
tavaline	doc_833156154878_item	2899412	et	4	main
asi	doc_833156154878_item	2899413	et	4	main
vanem	doc_833156154878_item	2899414	et	4	main
kiviaeg	doc_833156154878_item	2899415	et	3	main
e	doc_833156154878_item	2899416	et	4	main
neoliitikum	doc_833156154878_item	2899417	et	3	main
3000-2500	doc_833156154878_item	2899418	et	2	main
aa	doc_833156154878_item	2899419	et	3	main
ekr	doc_833156154878_item	2899420	et	4	main
pool	doc_833156154878_item	2899422	et	4	main
tegelema	doc_833156154878_item	2899425	et	3	main
kiviputru	doc_833156154878_item	2899442	et	4	main
geomeetriliste	doc_833156154878_item	2899454	et	4	main
kujunditega	doc_833156154878_item	2899455	et	3	main
ja	doc_833156154878_item	2899456	et	3	main
ühes	doc_833156154878_item	2899337	et	4	main
püstkojas	doc_833156154878_item	2899338	et	3	main
elas	doc_833156154878_item	2899339	et	3	main
4-10	doc_833156154878_item	2899340	et	2	main
inimest	doc_833156154878_item	2899341	et	3	main
10-70	doc_833156154878_item	2899342	et	2	main
kolle	doc_833156154878_item	2899349	et	4	main
mille	doc_833156154878_item	2899350	et	3	main
usundite	doc_833156154878_item	2899359	et	3	main
eest	doc_833156154878_item	2899365	et	4	main
pandi	doc_833156154878_item	2899376	et	4	main
keraamika	doc_833156154878_item	2899429	et	4	main
tüüp	doc_833156154878_item	2899430	et	3	main
sisse	doc_833156154878_item	2899440	et	4	main
segati	doc_833156154878_item	2899441	et	3	main
kammkeraamika	doc_833156154878_item	2899446	et	4	main
põhjaga	doc_833156154878_item	2899451	et	3	main
kammi	doc_833156154878_item	2899458	et	4	main
abil	doc_833156154878_item	2899459	et	4	main
e	doc_833156154878_item	2899462	et	4	main
2200	doc_833156154878_item	2899465	et	2	main
natuke	doc_833156154878_item	2899495	et	4	main
tegelema	doc_833156154878_item	2899496	et	3	main
põllumajandusega	doc_833156154878_item	2899497	et	3	main
see	doc_833156154878_item	2899498	et	3	main
oli	doc_833156154878_item	2899499	et	3	main
väga	doc_833156154878_item	2899500	et	3	main
primitiivsed	doc_833156154878_item	2899506	et	3	main
peale	doc_833156154878_item	2899516	et	4	main
suurte	doc_833156154878_item	2899517	et	3	main
kividega	doc_833156154878_item	2899518	et	3	main
keskele	doc_833156154878_item	2899522	et	3	main
arheoloogiline	doc_833156154878_item	2899531	et	4	main
kultuur	doc_833156154878_item	2899532	et	3	main
ühele	doc_833156154878_item	2899533	et	3	main
on	doc_833156154878_item	2899540	et	4	main
kindlaks	doc_833156154878_item	2899541	et	3	main
kaevandamiste	doc_833156154878_item	2899544	et	4	main
mõiste	doc_833156154879_item	2899552	et	4	main
kultuur	doc_833156154879_item	2899554	et	3	main
1	doc_833156154879_item	2899556	et	2	main
kiviaega	doc_833156154879_item	2899557	et	4	main
võib	doc_833156154879_item	2899558	et	3	main
periodiseerida	doc_833156154879_item	2899559	et	3	main
paleoliitikum	doc_833156154879_item	2899560	et	3	main
ehk	doc_833156154879_item	2899561	et	3	main
ekr	doc_833156154879_item	2899570	et	4	main
keskmine	doc_833156154879_item	2899575	et	3	main
neoliitikum	doc_833156154879_item	2899577	et	3	main
aastatuhat	doc_833156154879_item	2899579	et	4	main
kiviaeg	doc_833156154879_item	2899585	et	3	main
tol	doc_833156154878_item	2899354	et	3	main
inimesed	doc_833156154878_item	2899361	et	3	main
surnu	doc_833156154878_item	2899363	et	4	main
hauda	doc_833156154878_item	2899375	et	4	main
mingi	doc_833156154878_item	2899380	et	4	main
sest	doc_833156154878_item	2899382	et	4	main
animistlik	doc_833156154878_item	2899386	et	3	main
usund	doc_833156154878_item	2899387	et	3	main
inimesed	doc_833156154878_item	2899423	et	3	main
keraamikaga	doc_833156154878_item	2899426	et	3	main
keraamika	doc_833156154878_item	2899432	et	4	main
3000-2200	doc_833156154878_item	2899433	et	2	main
aa	doc_833156154878_item	2899434	et	3	main
ekr	doc_833156154878_item	2899435	et	4	main
taimi	doc_833156154878_item	2899445	et	4	main
keraamikatüüp	doc_833156154878_item	2899449	et	4	main
terava	doc_833156154878_item	2899450	et	3	main
tehtud	doc_833156154878_item	2899457	et	4	main
nöörkeraamika	doc_833156154878_item	2899461	et	4	main
venekirveste	doc_833156154878_item	2899463	et	4	main
kultuur	doc_833156154878_item	2899464	et	3	main
olid	doc_833156154878_item	2899469	et	4	main
kaunistatud	doc_833156154878_item	2899470	et	4	main
raske	doc_833156154878_item	2899501	et	4	main
maa	doc_833156154878_item	2899515	et	4	main
selle	doc_833156154878_item	2899525	et	4	main
ümber	doc_833156154878_item	2899526	et	3	main
kõiki	doc_833156154878_item	2899527	et	4	main
teisi	doc_833156154878_item	2899528	et	4	main
pereliikmeid	doc_833156154878_item	2899529	et	3	main
2	doc_833156154878_item	2899530	et	2	main
usund	doc_833156154878_item	2899537	et	3	main
mis	doc_833156154878_item	2899539	et	4	main
viii	doc_833156154879_item	2899564	et	4	main
ekr	doc_833156154879_item	2899566	et	4	main
ekr	doc_833156154879_item	2899573	et	4	main
atek	doc_833156154879_item	2899582	et	4	main
ehk	doc_833156154879_item	2899583	et	3	main
alal	doc_833156154879_item	2899588	et	4	main
tekkis	doc_833156154879_item	2899589	et	3	main
elu	doc_833156154879_item	2899590	et	4	main
alles	doc_833156154879_item	2899591	et	3	main
jäänud	doc_833156154879_item	2899621	et	4	main
kultuurikihti	doc_833156154879_item	2899623	et	4	main
valdavalt	doc_833156154879_item	2899635	et	4	main
marju	doc_833156154879_item	2899636	et	3	main
pulli	doc_833156154879_item	2899666	et	4	main
põhjal	doc_833156154879_item	2899673	et	4	main
võib	doc_833156154879_item	2899674	et	3	main
väita	doc_833156154879_item	2899675	et	4	main
et	doc_833156154879_item	2899676	et	3	main
10	doc_833156154879_item	2899680	et	2	main
e	doc_833156154879_item	2899685	et	4	main
kultuurikiht	doc_833156154879_item	2899702	et	3	main
on	doc_833156154879_item	2899703	et	4	main
märksa	doc_833156154879_item	2899704	et	3	main
keraamika	doc_833156154879_item	2899710	et	4	main
kasutuselevõtt	doc_833156154879_item	2899711	et	3	main
vi	doc_833156154879_item	2899712	et	4	main
hakkasid	doc_833156154878_item	2899424	et	4	main
kõige	doc_833156154878_item	2899427	et	4	main
vanem	doc_833156154878_item	2899428	et	4	main
tehti	doc_833156154878_item	2899436	et	3	main
jämedast	doc_833156154878_item	2899437	et	3	main
savist	doc_833156154878_item	2899438	et	4	main
kuhu	doc_833156154878_item	2899439	et	3	main
teokarpe	doc_833156154878_item	2899443	et	4	main
järgmine	doc_833156154878_item	2899448	et	3	main
pajad	doc_833156154878_item	2899452	et	4	main
kaunistatud	doc_833156154878_item	2899453	et	4	main
aukudega	doc_833156154878_item	2899460	et	3	main
ekr	doc_833156154878_item	2899467	et	4	main
pajad	doc_833156154878_item	2899468	et	4	main
tehtud	doc_833156154878_item	2899473	et	4	main
mustriga	doc_833156154878_item	2899474	et	3	main
venekirvestel	doc_833156154878_item	2899475	et	4	main
oli	doc_833156154878_item	2899476	et	3	main
suur	doc_833156154878_item	2899477	et	3	main
tähtsus	doc_833156154878_item	2899478	et	4	main
neid	doc_833156154878_item	2899479	et	4	main
isegi	doc_833156154878_item	2899480	et	4	main
ohverdati	doc_833156154878_item	2899481	et	3	main
võhandu	doc_833156154878_item	2899482	et	4	main
jõe	doc_833156154878_item	2899483	et	3	main
põhjal	doc_833156154878_item	2899484	et	4	main
on	doc_833156154878_item	2899485	et	4	main
mõned	doc_833156154878_item	2899487	et	3	main
leitud	doc_833156154878_item	2899486	et	4	main
venekirved	doc_833156154878_item	2899488	et	3	main
neoliitikumi	doc_833156154878_item	2899489	et	4	main
aja	doc_833156154878_item	2899490	et	4	main
teisel	doc_833156154878_item	2899491	et	4	main
pool	doc_833156154878_item	2899492	et	4	main
inimesed	doc_833156154878_item	2899493	et	3	main
hakkasid	doc_833156154878_item	2899494	et	4	main
a	doc_833156154878_item	2899466	et	4	main
abil	doc_833156154878_item	2899472	et	4	main
teha	doc_833156154878_item	2899502	et	3	main
olid	doc_833156154878_item	2899505	et	4	main
inimesed	doc_833156154878_item	2899507	et	3	main
pandud	doc_833156154878_item	2899520	et	4	main
haua	doc_833156154878_item	2899521	et	3	main
pereisa	doc_833156154878_item	2899524	et	4	main
iseloomulik	doc_833156154878_item	2899535	et	3	main
kombed	doc_833156154878_item	2899538	et	3	main
tehtud	doc_833156154878_item	2899542	et	4	main
käigul	doc_833156154878_item	2899545	et	3	main
1	doc_833156154879_item	2899547	et	2	main
kiviaeg	doc_833156154879_item	2899548	et	3	main
eesti	doc_833156154879_item	2899549	et	4	main
territooriumil	doc_833156154879_item	2899550	et	3	main
arheoloogiline	doc_833156154879_item	2899553	et	4	main
tähendus	doc_833156154879_item	2899555	et	4	main
ix	doc_833156154879_item	2899568	et	4	main
at	doc_833156154879_item	2899569	et	4	main
at	doc_833156154879_item	2899572	et	4	main
iii	doc_833156154879_item	2899578	et	4	main
noorem	doc_833156154879_item	2899584	et	4	main
praeguse	doc_833156154879_item	2899586	et	3	main
eestis	doc_833156154879_item	2899625	et	3	main
tegeldi	doc_833156154879_item	2899628	et	3	main
soogiks	doc_833156154879_item	2899640	et	4	main
praktiliselt	doc_833156154879_item	2899641	et	4	main
püüti	doc_833156154879_item	2899656	et	3	main
pärit	doc_833156154879_item	2899662	et	3	main
eesti	doc_833156154879_item	2899677	et	4	main
neoliitikum	doc_833156154879_item	2899684	et	3	main
kiviaeg	doc_833156154879_item	2899687	et	3	main
sest	doc_833156154879_item	2899698	et	4	main
sel	doc_833156154879_item	2899699	et	3	main
neoliitikumi	doc_833156154879_item	2899706	et	4	main
levis	doc_833156154879_item	2899714	et	4	main
ning	doc_833156154879_item	2899720	et	3	main
selle	doc_833156154879_item	2899736	et	4	main
tunnuseks	doc_833156154879_item	2899737	et	3	main
oli	doc_833156154879_item	2899738	et	3	main
on	doc_833156154879_item	2899751	et	4	main
eestile	doc_833156154879_item	2899752	et	3	main
sel	doc_833156154879_item	2899753	et	3	main
ajal	doc_833156154879_item	2899754	et	4	main
omane	doc_833156154879_item	2899755	et	3	main
neoliitikumis	doc_833156154879_item	2899756	et	3	main
domineeris	doc_833156154879_item	2899757	et	3	main
kuid	doc_833156154879_item	2899765	et	4	main
hakati	doc_833156154879_item	2899766	et	3	main
kasutama	doc_833156154879_item	2899767	et	3	main
algelist	doc_833156154879_item	2899768	et	4	main
kõplapõllundust	doc_833156154879_item	2899769	et	4	main
tööriistad	doc_833156154879_item	2899770	et	3	main
tehti	doc_833156154879_item	2899771	et	3	main
sel	doc_833156154879_item	2899772	et	3	main
kasvatati	doc_833156154879_item	2899779	et	3	main
olnud	doc_833156154879_item	2899786	et	4	main
kasutati	doc_833156154879_item	2899795	et	4	main
püstkodades	doc_833156154879_item	2899798	et	3	main
oli	doc_833156154879_item	2899800	et	3	main
100	doc_833156154879_item	2899802	et	2	main
inimest	doc_833156154879_item	2899803	et	3	main
ka	doc_833156154879_item	2899818	et	3	main
alal	doc_833156154879_item	2899820	et	4	main
maeti	doc_833156154879_item	2899828	et	3	main
isegi	doc_833156154879_item	2899831	et	4	main
alla	doc_833156154879_item	2899833	et	3	main
väljaspool	doc_833156154879_item	2899840	et	3	main
magamisasendit	doc_833156154879_item	2899845	et	3	main
kaasa	doc_833156154879_item	2899848	et	4	main
kujukesi	doc_833156154879_item	2899851	et	4	main
ning	doc_833156154879_item	2899852	et	3	main
animeeritud	doc_833156154879_item	2899853	et	4	main
kujusid	doc_833156154879_item	2899854	et	3	main
usuti	doc_833156154879_item	2899855	et	3	main
elusse	doc_833156154879_item	2899856	et	3	main
perioodi	doc_833156154879_item	2899866	et	4	main
oli	doc_833156154879_item	2899868	et	3	main
puudus	doc_833156154879_item	2899884	et	4	main
ka	doc_833156154879_item	2899888	et	3	main
sest	doc_833156154878_item	2899503	et	4	main
tööriistad	doc_833156154878_item	2899504	et	3	main
eelistasid	doc_833156154878_item	2899508	et	4	main
elama	doc_833156154878_item	2899509	et	3	main
veekogude	doc_833156154878_item	2899510	et	3	main
ääres	doc_833156154878_item	2899511	et	4	main
ümber	doc_833156154878_item	2899519	et	3	main
maeti	doc_833156154878_item	2899523	et	3	main
eluviis	doc_833156154878_item	2899536	et	3	main
2	doc_833156154879_item	2899551	et	2	main
kiviaeg	doc_833156154879_item	2899563	et	3	main
at	doc_833156154879_item	2899565	et	4	main
mesoliitikum	doc_833156154879_item	2899567	et	3	main
ehk	doc_833156154879_item	2899574	et	3	main
kiviaeg	doc_833156154879_item	2899576	et	3	main
ekr	doc_833156154879_item	2899580	et	4	main
ii	doc_833156154879_item	2899581	et	4	main
eesti	doc_833156154879_item	2899587	et	4	main
arheoloogilise	doc_833156154879_item	2899594	et	4	main
kultuuri	doc_833156154879_item	2899595	et	4	main
poolest	doc_833156154879_item	2899596	et	4	main
kuulus	doc_833156154879_item	2899597	et	4	main
eesti	doc_833156154879_item	2899598	et	4	main
mesoliitikumi	doc_833156154879_item	2899599	et	4	main
ajal	doc_833156154879_item	2899600	et	4	main
kunda	doc_833156154879_item	2899601	et	4	main
kultuurisse	doc_833156154879_item	2899602	et	3	main
tunnuseks	doc_833156154879_item	2899603	et	3	main
on	doc_833156154879_item	2899604	et	4	main
luust	doc_833156154879_item	2899605	et	4	main
ja	doc_833156154879_item	2899606	et	3	main
savist	doc_833156154879_item	2899607	et	4	main
asjad	doc_833156154879_item	2899608	et	3	main
paleoliitikumi	doc_833156154879_item	2899609	et	4	main
ajal	doc_833156154879_item	2899610	et	4	main
eestis	doc_833156154879_item	2899611	et	3	main
inimasustus	doc_833156154879_item	2899612	et	3	main
puudus	doc_833156154879_item	2899613	et	4	main
kuigi	doc_833156154879_item	2899614	et	3	main
baltimaades	doc_833156154879_item	2899615	et	4	main
eriti	doc_833156154879_item	2899616	et	3	main
leedus	doc_833156154879_item	2899617	et	4	main
leiti	doc_833156154879_item	2899618	et	3	main
muistsetelt	doc_833156154879_item	2899619	et	3	main
inimestel	doc_833156154879_item	2899620	et	3	main
mesoliitikumit	doc_833156154879_item	2899624	et	4	main
kalanduse	doc_833156154879_item	2899630	et	3	main
koriluse	doc_833156154879_item	2899631	et	4	main
ning	doc_833156154879_item	2899632	et	3	main
küttimisega	doc_833156154879_item	2899633	et	4	main
korjati	doc_833156154879_item	2899634	et	3	main
ei	doc_833156154879_item	2899642	et	4	main
luust	doc_833156154879_item	2899645	et	4	main
kivist	doc_833156154879_item	2899647	et	4	main
valmistatud	doc_833156154879_item	2899648	et	4	main
nooleotsiga	doc_833156154879_item	2899649	et	4	main
ning	doc_833156154879_item	2899650	et	3	main
on	doc_833156154879_item	2899661	et	4	main
asula	doc_833156154879_item	2899665	et	4	main
asula	doc_833156154879_item	2899667	et	4	main
pärnu	doc_833156154879_item	2899668	et	4	main
jõe	doc_833156154879_item	2899669	et	3	main
õhukesi	doc_833156154879_item	2899622	et	4	main
iseloomustada	doc_833156154879_item	2899627	et	4	main
praktiliselt	doc_833156154879_item	2899629	et	4	main
ja	doc_833156154879_item	2899637	et	3	main
tarvitatud	doc_833156154879_item	2899643	et	4	main
ning	doc_833156154879_item	2899646	et	3	main
puust	doc_833156154879_item	2899651	et	4	main
vibudega	doc_833156154879_item	2899652	et	3	main
põtru	doc_833156154879_item	2899653	et	3	main
ning	doc_833156154879_item	2899654	et	3	main
harpuunidega	doc_833156154879_item	2899655	et	3	main
seeni	doc_833156154879_item	2899639	et	3	main
kütiti	doc_833156154879_item	2899644	et	3	main
kalu	doc_833156154879_item	2899657	et	4	main
ning	doc_833156154879_item	2899658	et	3	main
hülgeid	doc_833156154879_item	2899659	et	3	main
eesti	doc_833156154879_item	2899663	et	4	main
esimene	doc_833156154879_item	2899664	et	3	main
leidude	doc_833156154879_item	2899672	et	4	main
000	doc_833156154879_item	2899681	et	2	main
noorem	doc_833156154879_item	2899686	et	4	main
võib	doc_833156154879_item	2899690	et	3	main
palju	doc_833156154879_item	2899692	et	4	main
iseloomusta	doc_833156154879_item	2899694	et	4	main
kui	doc_833156154879_item	2899695	et	3	main
ajal	doc_833156154879_item	2899700	et	4	main
kammkeraamika	doc_833156154879_item	2899715	et	4	main
kammivajutistega	doc_833156154879_item	2899716	et	4	main
koonuselise	doc_833156154879_item	2899717	et	4	main
iii	doc_833156154879_item	2899721	et	4	main
ekr	doc_833156154879_item	2899723	et	4	main
muistsed	doc_833156154879_item	2899729	et	3	main
jämedast	doc_833156154879_item	2899739	et	3	main
valmistatud	doc_833156154879_item	2899743	et	4	main
veel	doc_833156154879_item	2899758	et	4	main
amestav	doc_833156154879_item	2899760	et	4	main
eluviis	doc_833156154879_item	2899761	et	3	main
küttimine	doc_833156154879_item	2899762	et	4	main
tulekivist	doc_833156154879_item	2899776	et	4	main
toiduallikas	doc_833156154879_item	2899788	et	4	main
kütiti	doc_833156154879_item	2899789	et	3	main
sarnanesid	doc_833156154879_item	2899806	et	4	main
mongoliidide	doc_833156154879_item	2899807	et	3	main
ja	doc_833156154879_item	2899808	et	3	main
europiidide	doc_833156154879_item	2899809	et	3	main
segainimestega	doc_833156154879_item	2899810	et	3	main
sarnanesid	doc_833156154879_item	2899813	et	4	main
eesti	doc_833156154879_item	2899819	et	4	main
inimesi	doc_833156154879_item	2899829	et	4	main
kultuuri	doc_833156154879_item	2899835	et	4	main
levimisel	doc_833156154879_item	2899836	et	4	main
maeti	doc_833156154879_item	2899837	et	3	main
pandi	doc_833156154879_item	2899847	et	4	main
tööriistu	doc_833156154879_item	2899849	et	3	main
kiviaega	doc_833156154879_item	2899859	et	4	main
eestis	doc_833156154879_item	2899860	et	3	main
suhteliselt	doc_833156154879_item	2899864	et	4	main
ajaloos	doc_833156154879_item	2899871	et	4	main
põhjuseks	doc_833156154879_item	2899873	et	3	main
ei	doc_833156154879_item	2899880	et	4	main
motiiv	doc_833156154879_item	2899886	et	3	main
oma	doc_836620486402_item	2899938	et	4	main
lihtsalt	doc_836620486402_item	2899955	et	4	main
ise	doc_836620486402_item	2899963	et	4	main
noored	doc_836620486402_item	2899964	et	3	main
tegur	doc_836620486402_item	2899972	et	3	main
paremaks	doc_836620486402_item	2899975	et	4	main
on	doc_836620486402_item	2899978	et	4	main
ja	doc_836620486402_item	2899983	et	3	main
võimalust	doc_836620486402_item	2899986	et	3	main
parem	doc_836620486402_item	2899989	et	4	main
süüa	doc_836620486402_item	2899990	et	3	main
ja	doc_836620486402_item	2899991	et	3	main
hoolida	doc_836620486402_item	2899992	et	3	main
oma	doc_836620486402_item	2899993	et	4	main
keskealistel	doc_836620486402_item	2900001	et	4	main
on	doc_836620486402_item	2900032	et	4	main
on	doc_836620486402_item	2900038	et	4	main
mis	doc_836620486402_item	2900041	et	4	main
rasva	doc_836620486402_item	2900050	et	4	main
valgu	doc_836620486402_item	2900051	et	4	main
vitamiine	doc_836620486402_item	2900052	et	3	main
sisaldab	doc_836620486402_item	2900053	et	3	main
100	doc_836620486402_item	2900054	et	2	main
gr	doc_836620486402_item	2900055	et	4	main
keskealisedel	doc_836620486402_item	2900058	et	4	main
juba	doc_836620486402_item	2900060	et	3	main
süüa	doc_836620486402_item	2900067	et	3	main
üks	doc_836620486402_item	2900069	et	3	main
liigne	doc_836620486402_item	2900071	et	3	main
kaal	doc_836620486402_item	2900072	et	3	main
raha	doc_836620486402_item	2900079	et	4	main
mesoliitikumist	doc_833156154879_item	2899660	et	4	main
lähedal	doc_833156154879_item	2899670	et	4	main
selle	doc_833156154879_item	2899671	et	4	main
kultuur	doc_833156154879_item	2899678	et	3	main
aastat	doc_833156154879_item	2899682	et	3	main
sellel	doc_833156154879_item	2899688	et	4	main
eestit	doc_833156154879_item	2899691	et	3	main
paremini	doc_833156154879_item	2899693	et	4	main
näiteks	doc_833156154879_item	2899696	et	4	main
leitud	doc_833156154879_item	2899701	et	4	main
tähtsamaks	doc_833156154879_item	2899707	et	4	main
tunnuseks	doc_833156154879_item	2899708	et	3	main
oli	doc_833156154879_item	2899709	et	3	main
nöörkeraamika	doc_833156154879_item	2899725	et	4	main
nöörivajutistega	doc_833156154879_item	2899726	et	3	main
eestlased	doc_833156154879_item	2899730	et	3	main
tol	doc_833156154879_item	2899732	et	3	main
ajajärgul	doc_833156154879_item	2899733	et	3	main
narva	doc_833156154879_item	2899734	et	4	main
kultuuri	doc_833156154879_item	2899735	et	4	main
teokarpidest	doc_833156154879_item	2899742	et	3	main
nõud	doc_833156154879_item	2899744	et	3	main
venekirve	doc_833156154879_item	2899746	et	3	main
pooside	doc_833156154879_item	2899748	et	3	main
kirvedega	doc_833156154879_item	2899750	et	4	main
valdavalt	doc_833156154879_item	2899759	et	4	main
kivist	doc_833156154879_item	2899775	et	4	main
põldude	doc_833156154879_item	2899778	et	4	main
nisu	doc_833156154879_item	2899780	et	4	main
peamine	doc_833156154879_item	2899787	et	3	main
metstarvast	doc_833156154879_item	2899791	et	4	main
hüljeste	doc_833156154879_item	2899793	et	3	main
elati	doc_833156154879_item	2899797	et	3	main
noorkeraamika	doc_833156154879_item	2899811	et	4	main
omapärased	doc_833156154879_item	2899822	et	4	main
veel	doc_833156154879_item	2899830	et	4	main
külast	doc_833156154879_item	2899839	et	4	main
matmisel	doc_833156154879_item	2899841	et	4	main
püüti	doc_833156154879_item	2899842	et	3	main
matkida	doc_833156154879_item	2899843	et	3	main
inimeste	doc_833156154879_item	2899844	et	3	main
surma	doc_833156154879_item	2899858	et	4	main
kui	doc_833156154879_item	2899863	et	3	main
suhteline	doc_833156154879_item	2899877	et	4	main
seega	doc_833156154879_item	2899883	et	4	main
asustus	doc_833156154879_item	2899890	et	4	main
enne	doc_833156154879_item	2899921	et	4	main
kammkeraamika	doc_833156154879_item	2899929	et	4	main
kunda	doc_833156154879_item	2899933	et	4	main
kultuur	doc_833156154879_item	2899934	et	3	main
kui	doc_836620486402_item	2899941	et	3	main
keskealised	doc_836620486402_item	2899942	et	4	main
et	doc_836620486402_item	2899946	et	3	main
hoolivad	doc_836620486402_item	2899949	et	4	main
tervisest	doc_836620486402_item	2899951	et	4	main
keskealised	doc_836620486402_item	2899954	et	4	main
tegeleda	doc_836620486402_item	2899960	et	3	main
selle	doc_836620486402_item	2899961	et	4	main
vaadake	doc_836620486402_item	2899962	et	3	main
jõusaalis	doc_836620486402_item	2899968	et	3	main
see	doc_836620486402_item	2899971	et	3	main
tänavu	doc_836620486402_item	2899976	et	3	main
on	doc_836620486402_item	2899981	et	4	main
on	doc_836620486402_item	2899985	et	4	main
rohkem	doc_836620486402_item	2899987	et	4	main
puhata	doc_836620486402_item	2900024	et	4	main
teine	doc_836620486402_item	2900025	et	3	main
arvates	doc_836620486402_item	2900028	et	4	main
parem	doc_836620486402_item	2900029	et	4	main
toitmisest	doc_836620486402_item	2900036	et	4	main
ja	doc_836620486402_item	2900040	et	3	main
halb	doc_836620486402_item	2900043	et	3	main
on	doc_836620486402_item	2900059	et	4	main
steereotüüp	doc_836620486402_item	2900061	et	4	main
midaja	doc_836620486402_item	2900062	et	4	main
kui	doc_836620486402_item	2900063	et	3	main
rohkem	doc_836620486402_item	2900074	et	4	main
on	doc_836620486402_item	2900078	et	4	main
narkomaania	doc_836620486402_item	2900088	et	4	main
igapäevane	doc_836620486402_item	2900090	et	4	main
ja	doc_836620486402_item	2900092	et	3	main
on	doc_833156154879_item	2899679	et	4	main
vana	doc_833156154879_item	2899683	et	4	main
ajajärgul	doc_833156154879_item	2899689	et	3	main
mesoliitikul	doc_833156154879_item	2899697	et	4	main
paksem	doc_833156154879_item	2899705	et	4	main
atekr	doc_833156154879_item	2899713	et	4	main
alusega	doc_833156154879_item	2899718	et	4	main
nõud	doc_833156154879_item	2899719	et	3	main
koonusekujulised	doc_833156154879_item	2899727	et	4	main
savinõud	doc_833156154879_item	2899728	et	3	main
kuulusid	doc_833156154879_item	2899731	et	4	main
savist	doc_833156154879_item	2899740	et	4	main
kultuur	doc_833156154879_item	2899747	et	3	main
kujuliste	doc_833156154879_item	2899749	et	4	main
kalastamine	doc_833156154879_item	2899763	et	4	main
ajal	doc_833156154879_item	2899773	et	4	main
see	doc_833156154879_item	2899784	et	3	main
ei	doc_833156154879_item	2899785	et	4	main
karusid	doc_833156154879_item	2899792	et	3	main
valgusallikana	doc_833156154879_item	2899796	et	4	main
kogukonnas	doc_833156154879_item	2899799	et	4	main
umbes	doc_833156154879_item	2899801	et	4	main
kammkeraamika	doc_833156154879_item	2899804	et	4	main
inimesed	doc_833156154879_item	2899805	et	3	main
inimesed	doc_833156154879_item	2899812	et	3	main
indoeurooplastega	doc_833156154879_item	2899814	et	3	main
üheks	doc_833156154879_item	2899816	et	3	main
olid	doc_833156154879_item	2899821	et	4	main
matmiskombed	doc_833156154879_item	2899823	et	3	main
iv	doc_833156154879_item	2899824	et	4	main
aasta	doc_833156154879_item	2899825	et	4	main
tuhandel	doc_833156154879_item	2899826	et	3	main
surnuid	doc_833156154879_item	2899838	et	4	main
surnutele	doc_833156154879_item	2899846	et	4	main
ehteid	doc_833156154879_item	2899850	et	3	main
võib	doc_833156154879_item	2899861	et	3	main
rahulikku	doc_833156154879_item	2899865	et	4	main
eesti	doc_833156154879_item	2899870	et	4	main
selle	doc_833156154879_item	2899872	et	4	main
oli	doc_833156154879_item	2899874	et	3	main
osaliselt	doc_833156154879_item	2899875	et	4	main
varanduse	doc_833156154879_item	2899876	et	3	main
tekkinud	doc_833156154879_item	2899881	et	4	main
ja	doc_833156154879_item	2899882	et	3	main
sõjaks	doc_833156154879_item	2899887	et	3	main
inimeste	doc_833156154879_item	2899889	et	3	main
arheoloogilistest	doc_833156154879_item	2899925	et	4	main
kultuuridest	doc_833156154879_item	2899926	et	3	main
narva	doc_833156154879_item	2899927	et	4	main
kultuur	doc_833156154879_item	2899928	et	3	main
tänapäeva	doc_836620486402_item	2899935	et	4	main
noored	doc_836620486402_item	2899936	et	3	main
hoolivad	doc_836620486402_item	2899937	et	4	main
mina	doc_836620486402_item	2899943	et	4	main
olen	doc_836620486402_item	2899944	et	3	main
tänapäeva	doc_836620486402_item	2899947	et	4	main
rohkem	doc_836620486402_item	2899952	et	4	main
kui	doc_836620486402_item	2899953	et	3	main
muudatab	doc_836620486402_item	2899973	et	4	main
noored	doc_836620486402_item	2899977	et	3	main
raha	doc_836620486402_item	2899982	et	4	main
välimusest	doc_836620486402_item	2899995	et	4	main
noortel	doc_836620486402_item	2899996	et	3	main
on	doc_836620486402_item	2899997	et	4	main
aktiivsem	doc_836620486402_item	2899998	et	4	main
ja	doc_836620486402_item	2900022	et	3	main
hea	doc_836620486402_item	2900039	et	4	main
palju	doc_836620486402_item	2900049	et	4	main
aga	doc_836620486402_item	2900057	et	3	main
veel	doc_836620486402_item	2900068	et	4	main
probleem	doc_836620486402_item	2900070	et	3	main
võimalusi	doc_836620486402_item	2900075	et	3	main
aega	doc_836620486402_item	2900081	et	4	main
edasi	doc_836620486402_item	2900094	et	3	main
tugevasti	doc_836620486402_item	2900097	et	3	main
mõjutab	doc_836620486403_item	2900127	et	3	main
ma	doc_836620486403_item	2900132	et	3	main
et	doc_836620486403_item	2900134	et	3	main
elu	doc_836620486403_item	2900141	et	4	main
eri-	doc_836620486403_item	2900149	et	4	main
inglise	doc_836620486403_item	2900159	et	4	main
at	doc_833156154879_item	2899722	et	4	main
levis	doc_833156154879_item	2899724	et	4	main
ja	doc_833156154879_item	2899741	et	3	main
ka	doc_833156154879_item	2899745	et	3	main
korilus	doc_833156154879_item	2899764	et	4	main
valdavalt	doc_833156154879_item	2899774	et	4	main
lelistellkividest	doc_833156154879_item	2899777	et	4	main
hirssi	doc_833156154879_item	2899781	et	4	main
otri	doc_833156154879_item	2899782	et	3	main
kuid	doc_833156154879_item	2899783	et	4	main
põtru	doc_833156154879_item	2899790	et	3	main
rasva	doc_833156154879_item	2899794	et	4	main
neoliitikumi	doc_833156154879_item	2899815	et	4	main
tunnuseks	doc_833156154879_item	2899817	et	3	main
ekr	doc_833156154879_item	2899827	et	4	main
püstkodade	doc_833156154879_item	2899832	et	3	main
nöörkeraamika	doc_833156154879_item	2899834	et	4	main
pärast	doc_833156154879_item	2899857	et	4	main
iseloomustada	doc_833156154879_item	2899862	et	4	main
sõdu	doc_833156154879_item	2899867	et	3	main
vähe	doc_833156154879_item	2899869	et	3	main
nappus	doc_833156154879_item	2899878	et	4	main
söögiülejääke	doc_833156154879_item	2899879	et	4	main
otsene	doc_833156154879_item	2899885	et	3	main
oli	doc_833156154879_item	2899891	et	3	main
hõre	doc_833156154879_item	2899892	et	3	main
mida	doc_833156154879_item	2899893	et	4	main
rikkamaks	doc_833156154879_item	2899894	et	4	main
ja	doc_833156154879_item	2899895	et	3	main
osavamaks	doc_833156154879_item	2899896	et	4	main
sai	doc_833156154879_item	2899897	et	4	main
inimene	doc_833156154879_item	2899898	et	3	main
seda	doc_833156154879_item	2899899	et	3	main
sõjakamaks	doc_833156154879_item	2899900	et	4	main
ta	doc_833156154879_item	2899901	et	4	main
muutus	doc_833156154879_item	2899902	et	4	main
2	doc_833156154879_item	2899903	et	2	main
arheoloogiline	doc_833156154879_item	2899904	et	4	main
kultuur	doc_833156154879_item	2899905	et	3	main
arheoloogilistel	doc_833156154879_item	2899906	et	4	main
leidudel	doc_833156154879_item	2899907	et	3	main
muististel	doc_833156154879_item	2899908	et	3	main
põhinev	doc_833156154879_item	2899909	et	4	main
eri	doc_833156154879_item	2899910	et	4	main
rahvaste	doc_833156154879_item	2899911	et	4	main
kultuuriline	doc_833156154879_item	2899912	et	4	main
ning	doc_833156154879_item	2899913	et	3	main
materiaalne	doc_833156154879_item	2899914	et	3	main
kultuur	doc_833156154879_item	2899915	et	3	main
arheoloogiline	doc_833156154879_item	2899916	et	4	main
kultuur	doc_833156154879_item	2899917	et	3	main
on	doc_833156154879_item	2899918	et	4	main
omane	doc_833156154879_item	2899919	et	3	main
ajaloole	doc_833156154879_item	2899920	et	4	main
nöörkeraamika	doc_833156154879_item	2899931	et	4	main
tervisest	doc_836620486402_item	2899939	et	4	main
rohkem	doc_836620486402_item	2899940	et	4	main
oma	doc_836620486402_item	2899950	et	4	main
nendel	doc_836620486402_item	2899956	et	4	main
on	doc_836620486402_item	2899957	et	4	main
rohkem	doc_836620486402_item	2899958	et	4	main
võimalusi	doc_836620486402_item	2899959	et	3	main
ujulas	doc_836620486402_item	2899967	et	3	main
äriinimesed	doc_836620486402_item	2899979	et	3	main
nendel	doc_836620486402_item	2899980	et	4	main
kirja	doc_833156154879_item	2899922	et	4	main
kasutuselevõttu	doc_833156154879_item	2899923	et	4	main
näided	doc_833156154879_item	2899924	et	4	main
kultuur	doc_833156154879_item	2899930	et	3	main
kultuur	doc_833156154879_item	2899932	et	3	main
nõus	doc_836620486402_item	2899945	et	4	main
noored	doc_836620486402_item	2899948	et	3	main
käivad	doc_836620486402_item	2899965	et	4	main
treningudel	doc_836620486402_item	2899966	et	4	main
tegelevad	doc_836620486402_item	2899969	et	4	main
aeroobika	doc_836620486402_item	2899970	et	4	main
tervise	doc_836620486402_item	2899974	et	3	main
sellest	doc_836620486402_item	2899984	et	4	main
liigutada	doc_836620486402_item	2899988	et	3	main
kui	doc_836620486402_item	2900000	et	3	main
kui	doc_836620486402_item	2900002	et	3	main
veel	doc_836620486402_item	2900003	et	4	main
ei	doc_836620486402_item	2900004	et	4	main
ole	doc_836620486402_item	2900005	et	4	main
peret	doc_836620486402_item	2900006	et	3	main
ja	doc_836620486402_item	2900007	et	3	main
lapsi	doc_836620486402_item	2900008	et	4	main
siis	doc_836620486402_item	2900009	et	3	main
võib	doc_836620486402_item	2900010	et	3	main
käia	doc_836620486402_item	2900011	et	4	main
välismaal	doc_836620486402_item	2900012	et	4	main
ja	doc_836620486402_item	2900013	et	3	main
talvel	doc_836620486402_item	2900014	et	4	main
kui	doc_836620486402_item	2900015	et	3	main
meil	doc_836620486402_item	2900016	et	4	main
on	doc_836620486402_item	2900017	et	4	main
külm	doc_836620486402_item	2900018	et	3	main
ja	doc_836620486402_item	2900019	et	3	main
lürts	doc_836620486402_item	2900020	et	4	main
päevitada	doc_836620486402_item	2900021	et	3	main
natukene	doc_836620486402_item	2900023	et	4	main
tegur	doc_836620486402_item	2900026	et	3	main
minu	doc_836620486402_item	2900027	et	3	main
palju	doc_836620486402_item	2900033	et	4	main
infot	doc_836620486402_item	2900034	et	3	main
tervislikkust	doc_836620486402_item	2900035	et	4	main
on	doc_836620486402_item	2900042	et	4	main
iga	doc_836620486402_item	2900044	et	4	main
toite	doc_836620486402_item	2900045	et	4	main
palju	doc_836620486402_item	2900064	et	4	main
vaja	doc_836620486402_item	2900066	et	4	main
seda	doc_836620486402_item	2900076	et	3	main
on	doc_836620486402_item	2900080	et	4	main
vaid	doc_836620486402_item	2900082	et	3	main
medalil	doc_836620486402_item	2900083	et	3	main
ka	doc_836620486402_item	2900085	et	3	main
alkogoolism	doc_836620486402_item	2900089	et	4	main
stress	doc_836620486402_item	2900091	et	3	main
väga	doc_836620486402_item	2900096	et	3	main
kontrolltöö	doc_836620486403_item	2900125	et	4	main
kõige	doc_836620486403_item	2900130	et	4	main
inimenele	doc_836620486403_item	2900144	et	4	main
on	doc_836620486403_item	2900146	et	4	main
kõrg	doc_836620486403_item	2900147	et	4	main
kergem	doc_836620486403_item	2900152	et	4	main
tööd	doc_836620486403_item	2900153	et	4	main
leida	doc_836620486403_item	2900154	et	3	main
kui	doc_836620486403_item	2900155	et	3	main
kehast	doc_836620486402_item	2899994	et	4	main
puhkus	doc_836620486402_item	2899999	et	3	main
toitmine	doc_836620486402_item	2900030	et	4	main
praegu	doc_836620486402_item	2900031	et	3	main
mis	doc_836620486402_item	2900037	et	4	main
on	doc_836620486402_item	2900046	et	4	main
kirjatanud	doc_836620486402_item	2900047	et	3	main
kui	doc_836620486402_item	2900048	et	3	main
toite	doc_836620486402_item	2900056	et	4	main
on	doc_836620486402_item	2900065	et	4	main
noortel	doc_836620486402_item	2900073	et	3	main
alandada	doc_836620486402_item	2900077	et	3	main
on	doc_836620486402_item	2900084	et	4	main
külg	doc_836620486402_item	2900087	et	3	main
nii	doc_836620486402_item	2900093	et	3	main
see	doc_836620486402_item	2900095	et	3	main
tervise	doc_836620486402_item	2900099	et	3	main
halvaks	doc_836620486402_item	2900101	et	4	main
kohe	doc_836620486402_item	2900102	et	4	main
mulle	doc_836620486402_item	2900103	et	4	main
tundub	doc_836620486402_item	2900104	et	3	main
nii	doc_836620486402_item	2900105	et	3	main
aga	doc_836620486402_item	2900106	et	3	main
hiljem	doc_836620486402_item	2900107	et	3	main
võib	doc_836620486402_item	2900108	et	3	main
olla	doc_836620486402_item	2900109	et	3	main
ma	doc_836620486402_item	2900110	et	3	main
muudan	doc_836620486402_item	2900111	et	3	main
oma	doc_836620486402_item	2900112	et	4	main
arvumust	doc_836620486402_item	2900113	et	3	main
loomulikult	doc_836620486402_item	2900114	et	4	main
et	doc_836620486402_item	2900115	et	3	main
teised	doc_836620486402_item	2900116	et	4	main
inimesed	doc_836620486402_item	2900117	et	3	main
mõtlevad	doc_836620486402_item	2900118	et	4	main
vastupidi	doc_836620486402_item	2900119	et	3	main
nendel	doc_836620486402_item	2900120	et	4	main
olla	doc_836620486402_item	2900122	et	3	main
argumente	doc_836620486402_item	2900124	et	3	main
mis	doc_836620486403_item	2900126	et	4	main
või	doc_836620486403_item	2900148	et	4	main
soome	doc_836620486403_item	2900160	et	3	main
see	doc_836620486403_item	2900165	et	3	main
temas	doc_836620486403_item	2900170	et	3	main
rohkem	doc_836620486403_item	2900175	et	4	main
võimalust	doc_836620486403_item	2900176	et	3	main
ja	doc_836620486403_item	2900189	et	3	main
iseloom	doc_836620486403_item	2900193	et	3	main
ega	doc_836620486403_item	2900195	et	3	main
veini	doc_836620486403_item	2900197	et	4	main
jooma	doc_836620486403_item	2900198	et	4	main
kas	doc_836620486403_item	2900199	et	3	main
igal	doc_836620486403_item	2900200	et	3	main
inimesel	doc_836620486403_item	2900201	et	3	main
omanike	doc_836620486403_item	2900228	et	3	main
varem	doc_836620486403_item	2900240	et	4	main
ainult	doc_836620486403_item	2900256	et	4	main
kui	doc_836620486403_item	2900268	et	3	main
tõeliselt	doc_836620486403_item	2900269	et	4	main
ma	doc_836620486403_item	2900271	et	3	main
olema	doc_836620486403_item	2900278	et	4	main
mobiiltelefon	doc_836620486403_item	2900279	et	3	main
väga	doc_836620486403_item	2900280	et	3	main
tihti	doc_836620486403_item	2900281	et	3	main
teine	doc_836620486402_item	2900086	et	3	main
peale	doc_836620486402_item	2900100	et	4	main
võivad	doc_836620486402_item	2900121	et	4	main
oma	doc_836620486402_item	2900123	et	4	main
inimese	doc_836620486403_item	2900128	et	4	main
haridus	doc_836620486403_item	2900135	et	3	main
raha	doc_836620486403_item	2900137	et	4	main
mõjutavad	doc_836620486403_item	2900140	et	4	main
kõige	doc_836620486403_item	2900142	et	4	main
haridus	doc_836620486403_item	2900150	et	3	main
oskab	doc_836620486403_item	2900157	et	3	main
siis	doc_836620486403_item	2900164	et	3	main
on	doc_836620486403_item	2900166	et	4	main
suur	doc_836620486403_item	2900168	et	3	main
õppida	doc_836620486403_item	2900178	et	3	main
haridust	doc_836620486403_item	2900180	et	4	main
rahata	doc_836620486403_item	2900182	et	4	main
on	doc_836620486403_item	2900221	et	4	main
arv	doc_836620486403_item	2900223	et	3	main
ka	doc_836620486403_item	2900225	et	3	main
mobiiltelefooni	doc_836620486403_item	2900227	et	4	main
telefoni	doc_836620486403_item	2900231	et	4	main
näiteks	doc_836620486403_item	2900241	et	4	main
teineteiste	doc_836620486403_item	2900249	et	4	main
ei	doc_836620486403_item	2900272	et	4	main
et	doc_836620486403_item	2900274	et	3	main
inimesel	doc_836620486403_item	2900276	et	3	main
peab	doc_836620486403_item	2900277	et	4	main
asi	doc_836620486403_item	2900299	et	4	main
tööl	doc_836620486403_item	2900300	et	3	main
aga	doc_836620486403_item	2900303	et	3	main
olema	doc_836620486403_item	2900305	et	4	main
nn	doc_836620486403_item	2900306	et	4	main
kuritegusid	doc_836620486404_item	2900316	et	4	main
kõrgem	doc_836620486404_item	2900318	et	4	main
seda	doc_836620486404_item	2900334	et	3	main
kõigepealt	doc_836620486404_item	2900344	et	3	main
seda	doc_836620486404_item	2900348	et	3	main
tahavad	doc_836620486404_item	2900355	et	3	main
nende	doc_836620486404_item	2900368	et	4	main
kõigil	doc_836620486404_item	2900379	et	4	main
on	doc_836620486404_item	2900380	et	4	main
pärast	doc_836620486404_item	2900389	et	4	main
mõjub	doc_836620486402_item	2900098	et	3	main
elu	doc_836620486403_item	2900129	et	4	main
rohkem	doc_836620486403_item	2900131	et	4	main
arvan	doc_836620486403_item	2900133	et	3	main
iseloom	doc_836620486403_item	2900136	et	3	main
ja	doc_836620486403_item	2900138	et	3	main
keelteoskumine	doc_836620486403_item	2900139	et	4	main
rohkem	doc_836620486403_item	2900143	et	4	main
kellel	doc_836620486403_item	2900145	et	4	main
on	doc_836620486403_item	2900151	et	4	main
ta	doc_836620486403_item	2900156	et	4	main
või	doc_836620486403_item	2900161	et	4	main
elus	doc_836620486403_item	2900171	et	4	main
rahaga	doc_836620486403_item	2900173	et	4	main
on	doc_836620486403_item	2900174	et	4	main
end	doc_836620486403_item	2900185	et	4	main
teine	doc_836620486403_item	2900186	et	3	main
sordi	doc_836620486403_item	2900187	et	4	main
inimeseks	doc_836620486403_item	2900188	et	3	main
tugev	doc_836620486403_item	2900192	et	4	main
hakkata	doc_836620486403_item	2900196	et	4	main
peab	doc_836620486403_item	2900202	et	4	main
olema	doc_836620486403_item	2900203	et	4	main
mobiiltelefon	doc_836620486403_item	2900204	et	3	main
ma	doc_836620486403_item	2900205	et	3	main
vaatasin	doc_836620486403_item	2900206	et	3	main
üht	doc_836620486403_item	2900207	et	3	main
poliitikasaadet	doc_836620486403_item	2900208	et	3	main
ja	doc_836620486403_item	2900209	et	3	main
teadsin	doc_836620486403_item	2900210	et	3	main
et	doc_836620486403_item	2900211	et	3	main
mobiiltelefon	doc_836620486403_item	2900212	et	3	main
on	doc_836620486403_item	2900213	et	4	main
eesti	doc_836620486403_item	2900215	et	4	main
elanikutel	doc_836620486403_item	2900216	et	4	main
60	doc_836620486403_item	2900214	et	2	main
ma	doc_836620486403_item	2900217	et	3	main
arvan	doc_836620486403_item	2900218	et	3	main
et	doc_836620486403_item	2900219	et	3	main
see	doc_836620486403_item	2900220	et	3	main
eesti	doc_836620486403_item	2900158	et	4	main
keelt	doc_836620486403_item	2900163	et	4	main
veel	doc_836620486403_item	2900167	et	4	main
võõrkeelt	doc_836620486403_item	2900177	et	4	main
tunned	doc_836620486403_item	2900184	et	3	main
on	doc_836620486403_item	2900190	et	4	main
suur	doc_836620486403_item	2900222	et	3	main
sekka	doc_836620486403_item	2900229	et	3	main
kasutamine	doc_836620486403_item	2900232	et	4	main
väga	doc_836620486403_item	2900234	et	3	main
ja	doc_836620486403_item	2900236	et	3	main
kaardid	doc_836620486403_item	2900246	et	3	main
me	doc_836620486403_item	2900247	et	4	main
helistame	doc_836620486403_item	2900248	et	3	main
tasuta	doc_836620486403_item	2900250	et	4	main
kahjuks	doc_836620486403_item	2900252	et	4	main
et	doc_836620486403_item	2900253	et	3	main
nad	doc_836620486403_item	2900291	et	3	main
tihti	doc_836620486403_item	2900292	et	3	main
on	doc_836620486403_item	2900297	et	4	main
peab	doc_836620486403_item	2900304	et	4	main
etikeet	doc_836620486403_item	2900308	et	4	main
vähem	doc_836620486404_item	2900314	et	4	main
kõrgem	doc_836620486404_item	2900331	et	4	main
palju	doc_836620486404_item	2900341	et	4	main
ei	doc_836620486404_item	2900350	et	4	main
ja	doc_836620486404_item	2900353	et	3	main
läks	doc_836620486404_item	2900359	et	3	main
paremaks	doc_836620486404_item	2900360	et	4	main
aga	doc_836620486404_item	2900361	et	3	main
nad	doc_836620486404_item	2900362	et	3	main
on	doc_836620486404_item	2900367	et	4	main
nad	doc_836620486404_item	2900370	et	3	main
on	doc_836620486404_item	2900371	et	4	main
nii	doc_836620486404_item	2900372	et	3	main
samad	doc_836620486404_item	2900373	et	3	main
inimised	doc_836620486404_item	2900374	et	4	main
ja	doc_836620486404_item	2900375	et	3	main
ma	doc_836620486404_item	2900376	et	3	main
ja	doc_836620486404_item	2900388	et	3	main
näes	doc_836620486404_item	2900421	et	4	main
riik	doc_836620486404_item	2900423	et	3	main
andma	doc_836620486404_item	2900425	et	3	main
inimised	doc_836620486404_item	2900431	et	4	main
mõned	doc_836620486404_item	2900440	et	3	main
mitte	doc_836620486404_item	2900444	et	3	main
peavad	doc_836620486404_item	2900453	et	4	main
kui	doc_836620486404_item	2900458	et	3	main
on	doc_836620486404_item	2900480	et	4	main
majad	doc_836620486404_item	2900486	et	3	main
on	doc_836620486404_item	2900490	et	4	main
kaitse	doc_836620486404_item	2900492	et	4	main
on	doc_836620486404_item	2900504	et	4	main
see	doc_836620486404_item	2900505	et	3	main
kõrgem	doc_836620486404_item	2900508	et	4	main
on	doc_836620486404_item	2900509	et	4	main
meie	doc_836620486404_item	2900510	et	4	main
elatustase	doc_836620486404_item	2900511	et	3	main
seda	doc_836620486404_item	2900512	et	3	main
kõne	doc_836620486405_item	2900519	et	4	main
uuel	doc_836620486405_item	2900528	et	3	main
õppeaastal	doc_836620486405_item	2900529	et	3	main
ma	doc_836620486405_item	2900530	et	3	main
soovin	doc_836620486405_item	2900531	et	3	main
teid	doc_836620486405_item	2900541	et	4	main
alg-	doc_836620486405_item	2900551	et	3	main
klassides	doc_836620486405_item	2900554	et	3	main
kasvatus	doc_836620486405_item	2900564	et	4	main
et	doc_836620486405_item	2900569	et	3	main
arvestused	doc_836620486405_item	2900570	et	4	main
paremeni	doc_836620486405_item	2900572	et	4	main
kui	doc_836620486405_item	2900573	et	3	main
hinnad	doc_836620486405_item	2900574	et	3	main
olen	doc_836620486405_item	2900575	et	3	main
kindel	doc_836620486405_item	2900576	et	3	main
et	doc_836620486405_item	2900577	et	3	main
see	doc_836620486405_item	2900578	et	3	main
reform	doc_836620486405_item	2900579	et	3	main
sobib	doc_836620486405_item	2900580	et	3	main
ka	doc_836620486405_item	2900581	et	3	main
õpilastele	doc_836620486405_item	2900582	et	4	main
õpilaste	doc_836620486405_item	2900587	et	4	main
saksa	doc_836620486403_item	2900162	et	4	main
pluss	doc_836620486403_item	2900169	et	3	main
aga	doc_836620486403_item	2900172	et	3	main
ja	doc_836620486403_item	2900179	et	3	main
saada	doc_836620486403_item	2900181	et	4	main
inimene	doc_836620486403_item	2900183	et	3	main
vaja	doc_836620486403_item	2900191	et	4	main
et	doc_836620486403_item	2900194	et	3	main
mina	doc_836620486403_item	2900224	et	4	main
praegu	doc_836620486403_item	2900230	et	3	main
mugav	doc_836620486403_item	2900235	et	3	main
minu	doc_836620486403_item	2900242	et	3	main
perel	doc_836620486403_item	2900243	et	3	main
on	doc_836620486403_item	2900244	et	4	main
tore	doc_836620486403_item	2900251	et	3	main
see	doc_836620486403_item	2900254	et	3	main
on	doc_836620486403_item	2900255	et	4	main
olleks	doc_836620486403_item	2900264	et	4	main
mobiiltelefon	doc_836620486403_item	2900265	et	3	main
zen	doc_836620486403_item	2900266	et	4	main
kaardiga	doc_836620486403_item	2900267	et	3	main
moodi	doc_836620486403_item	2900295	et	4	main
telefon	doc_836620486403_item	2900296	et	3	main
kodus	doc_836620486403_item	2900302	et	4	main
mida	doc_836620486404_item	2900309	et	4	main
kõrgem	doc_836620486404_item	2900310	et	4	main
on	doc_836620486404_item	2900311	et	4	main
elatustase	doc_836620486404_item	2900312	et	3	main
seda	doc_836620486404_item	2900313	et	3	main
elatustase	doc_836620486404_item	2900333	et	3	main
kuritegusid	doc_836620486404_item	2900337	et	4	main
kuritegijaid	doc_836620486404_item	2900342	et	3	main
ole	doc_836620486404_item	2900351	et	4	main
raha	doc_836620486404_item	2900352	et	4	main
nad	doc_836620486404_item	2900354	et	3	main
nende	doc_836620486404_item	2900357	et	4	main
elu	doc_836620486404_item	2900358	et	4	main
kõik	doc_836620486404_item	2900366	et	4	main
hea	doc_836620486404_item	2900386	et	4	main
haridusega	doc_836620486404_item	2900387	et	3	main
ülikoolis	doc_836620486404_item	2900434	et	4	main
ja	doc_836620486404_item	2900439	et	3	main
ei	doc_836620486404_item	2900441	et	4	main
õppida	doc_836620486404_item	2900443	et	3	main
inimised	doc_836620486404_item	2900451	et	4	main
kõigil	doc_836620486404_item	2900452	et	4	main
tingimused	doc_836620486404_item	2900456	et	3	main
oma	doc_836620486404_item	2900477	et	4	main
korterit	doc_836620486404_item	2900478	et	3	main
tänapäeval	doc_836620486404_item	2900479	et	3	main
kes	doc_836620486404_item	2900483	et	4	main
ja	doc_836620486404_item	2900487	et	3	main
käes	doc_836620486404_item	2900501	et	4	main
ja	doc_836620486404_item	2900502	et	3	main
tõesti	doc_836620486404_item	2900503	et	3	main
vähem	doc_836620486404_item	2900513	et	4	main
lugupeetud	doc_836620486405_item	2900520	et	4	main
kuulun	doc_836620486403_item	2900226	et	3	main
on	doc_836620486403_item	2900233	et	4	main
natukene	doc_836620486403_item	2900237	et	4	main
odavam	doc_836620486403_item	2900238	et	4	main
nagu	doc_836620486403_item	2900239	et	3	main
zen	doc_836620486403_item	2900245	et	4	main
suve	doc_836620486403_item	2900257	et	4	main
lõpuni	doc_836620486403_item	2900258	et	3	main
niisuguse	doc_836620486403_item	2900259	et	3	main
hetkel	doc_836620486403_item	2900260	et	4	main
tahaksin	doc_836620486403_item	2900261	et	3	main
et	doc_836620486403_item	2900262	et	3	main
igal	doc_836620486403_item	2900263	et	3	main
räägida	doc_836620486403_item	2900270	et	4	main
arva	doc_836620486403_item	2900273	et	4	main
igal	doc_836620486403_item	2900275	et	3	main
ei	doc_836620486403_item	2900288	et	4	main
helistavad	doc_836620486403_item	2900293	et	4	main
jama	doc_836620486403_item	2900294	et	4	main
vajalik	doc_836620486403_item	2900298	et	3	main
ja	doc_836620486403_item	2900301	et	3	main
telefoni	doc_836620486403_item	2900307	et	4	main
seda	doc_836620486404_item	2900321	et	3	main
on	doc_836620486404_item	2900323	et	4	main
kuritegusid	doc_836620486404_item	2900324	et	4	main
ma	doc_836620486404_item	2900325	et	3	main
olen	doc_836620486404_item	2900326	et	3	main
nõus	doc_836620486404_item	2900327	et	4	main
sellega	doc_836620486404_item	2900328	et	3	main
et	doc_836620486404_item	2900329	et	3	main
kui	doc_836620486404_item	2900330	et	3	main
vähem	doc_836620486404_item	2900335	et	4	main
on	doc_836620486404_item	2900336	et	4	main
miks	doc_836620486404_item	2900338	et	4	main
on	doc_836620486404_item	2900339	et	4	main
nii	doc_836620486404_item	2900340	et	3	main
et	doc_836620486404_item	2900345	et	3	main
kes	doc_836620486404_item	2900347	et	4	main
et	doc_836620486404_item	2900356	et	3	main
arvan	doc_836620486404_item	2900377	et	3	main
samad	doc_836620486404_item	2900381	et	3	main
täna	doc_836620486404_item	2900383	et	4	main
tähtis	doc_836620486404_item	2900384	et	4	main
olla	doc_836620486404_item	2900385	et	3	main
võib	doc_836620486404_item	2900390	et	3	main
head	doc_836620486404_item	2900391	et	4	main
meie	doc_836620486404_item	2900422	et	4	main
aga	doc_836620486404_item	2900435	et	3	main
haridus	doc_836620486404_item	2900436	et	3	main
saa	doc_836620486404_item	2900449	et	4	main
olema	doc_836620486404_item	2900454	et	4	main
kuritegijad	doc_836620486404_item	2900459	et	3	main
või	doc_836620486404_item	2900474	et	4	main
palju	doc_836620486404_item	2900481	et	4	main
kaitseb	doc_836620486404_item	2900484	et	4	main
meie	doc_836620486404_item	2900488	et	4	main
tahan	doc_836620486404_item	2900495	et	3	main
et	doc_836620486404_item	2900506	et	3	main
kui	doc_836620486404_item	2900507	et	3	main
kuritegusid	doc_836620486404_item	2900515	et	4	main
ja	doc_836620486404_item	2900516	et	3	main
kuritegujad	doc_836620486404_item	2900517	et	4	main
koolidirektori	doc_836620486405_item	2900518	et	3	main
paljus	doc_836620486405_item	2900533	et	4	main
mõned	doc_836620486405_item	2900545	et	3	main
vanematedes	doc_836620486405_item	2900553	et	4	main
me	doc_836620486405_item	2900555	et	4	main
ei	doc_836620486405_item	2900556	et	4	main
panda	doc_836620486405_item	2900557	et	4	main
hindeid	doc_836620486405_item	2900558	et	3	main
järgmisele	doc_836620486405_item	2900559	et	3	main
koolis	doc_836620486405_item	2900598	et	4	main
et	doc_836620486405_item	2900604	et	3	main
segab	doc_836620486403_item	2900282	et	3	main
ta	doc_836620486403_item	2900283	et	4	main
läheb	doc_836620486403_item	2900284	et	3	main
rikki	doc_836620486403_item	2900285	et	3	main
ja	doc_836620486403_item	2900286	et	3	main
lapsed	doc_836620486403_item	2900287	et	3	main
oska	doc_836620486403_item	2900289	et	4	main
kasutada	doc_836620486403_item	2900290	et	3	main
on	doc_836620486404_item	2900315	et	4	main
mida	doc_836620486404_item	2900317	et	4	main
on	doc_836620486404_item	2900319	et	4	main
elatustase	doc_836620486404_item	2900320	et	3	main
vähem	doc_836620486404_item	2900322	et	4	main
on	doc_836620486404_item	2900332	et	4	main
tänapäeval	doc_836620486404_item	2900343	et	3	main
inimistel	doc_836620486404_item	2900346	et	4	main
teeb	doc_836620486404_item	2900349	et	3	main
ei	doc_836620486404_item	2900363	et	4	main
mõistavad	doc_836620486404_item	2900364	et	3	main
et	doc_836620486404_item	2900365	et	3	main
käes	doc_836620486404_item	2900369	et	4	main
et	doc_836620486404_item	2900378	et	3	main
tingimused	doc_836620486404_item	2900382	et	3	main
tööd	doc_836620486404_item	2900392	et	4	main
leidma	doc_836620486404_item	2900393	et	3	main
tavaliselt	doc_836620486404_item	2900394	et	4	main
kuritegijad	doc_836620486404_item	2900395	et	3	main
on	doc_836620486404_item	2900396	et	4	main
lapsed	doc_836620486404_item	2900397	et	3	main
vaesest	doc_836620486404_item	2900398	et	4	main
perekonnast	doc_836620486404_item	2900399	et	4	main
sellepärast	doc_836620486404_item	2900400	et	3	main
nendel	doc_836620486404_item	2900401	et	4	main
ei	doc_836620486404_item	2900402	et	4	main
ole	doc_836620486404_item	2900403	et	4	main
eelised	doc_836620486404_item	2900404	et	4	main
ja	doc_836620486404_item	2900405	et	3	main
nad	doc_836620486404_item	2900406	et	3	main
proovivad	doc_836620486404_item	2900407	et	4	main
kelmuma	doc_836620486404_item	2900408	et	4	main
kui	doc_836620486404_item	2900409	et	3	main
nad	doc_836620486404_item	2900410	et	3	main
kasvavad	doc_836620486404_item	2900411	et	4	main
nad	doc_836620486404_item	2900412	et	3	main
on	doc_836620486404_item	2900413	et	4	main
juba	doc_836620486404_item	2900414	et	3	main
kuritegijad	doc_836620486404_item	2900415	et	3	main
kes	doc_836620486404_item	2900416	et	4	main
on	doc_836620486404_item	2900417	et	4	main
täiesti	doc_836620486404_item	2900418	et	3	main
ohtlikudbr	doc_836620486404_item	2900419	et	4	main
teises	doc_836620486404_item	2900420	et	4	main
head	doc_836620486404_item	2900427	et	4	main
tingimused	doc_836620486404_item	2900428	et	3	main
näiteks	doc_836620486404_item	2900429	et	4	main
kõik	doc_836620486404_item	2900430	et	4	main
on	doc_836620486404_item	2900437	et	4	main
saavad	doc_836620486404_item	2900442	et	4	main
mingil	doc_836620486404_item	2900445	et	4	main
juhul	doc_836620486404_item	2900446	et	3	main
riik	doc_836620486404_item	2900447	et	3	main
ei	doc_836620486404_item	2900448	et	4	main
aga	doc_836620486404_item	2900457	et	3	main
õues	doc_836620486404_item	2900475	et	4	main
kaitsma	doc_836620486404_item	2900476	et	3	main
peab	doc_836620486404_item	2900424	et	4	main
kõigile	doc_836620486404_item	2900426	et	4	main
peavad	doc_836620486404_item	2900432	et	4	main
õppima	doc_836620486404_item	2900433	et	3	main
tasuline	doc_836620486404_item	2900438	et	4	main
diskrimineerida	doc_836620486404_item	2900450	et	3	main
samad	doc_836620486404_item	2900455	et	3	main
teevad	doc_836620486404_item	2900460	et	3	main
oma	doc_836620486404_item	2900461	et	4	main
asi	doc_836620486404_item	2900462	et	4	main
me	doc_836620486404_item	2900463	et	4	main
peame	doc_836620486404_item	2900464	et	4	main
kaitsma	doc_836620486404_item	2900465	et	3	main
ennast	doc_836620486404_item	2900466	et	4	main
näiteks	doc_836620486404_item	2900467	et	4	main
peame	doc_836620486404_item	2900468	et	4	main
hoidma	doc_836620486404_item	2900469	et	3	main
korralikult	doc_836620486404_item	2900470	et	4	main
oma	doc_836620486404_item	2900471	et	4	main
asjad	doc_836620486404_item	2900472	et	3	main
transpordis	doc_836620486404_item	2900473	et	3	main
firmad	doc_836620486404_item	2900482	et	3	main
kodu	doc_836620486404_item	2900489	et	4	main
all	doc_836620486404_item	2900493	et	3	main
kirjutada	doc_836620486404_item	2900496	et	3	main
et	doc_836620486404_item	2900497	et	3	main
kõik	doc_836620486404_item	2900498	et	4	main
on	doc_836620486404_item	2900514	et	4	main
mul	doc_836620486405_item	2900522	et	3	main
suur	doc_836620486405_item	2900524	et	3	main
rõõm	doc_836620486405_item	2900525	et	3	main
õppekava	doc_836620486405_item	2900543	et	4	main
et	doc_836620486405_item	2900550	et	3	main
minu	doc_836620486405_item	2900567	et	3	main
arvan	doc_836620486405_item	2900585	et	3	main
sellel	doc_836620486405_item	2900595	et	4	main
järgmisel	doc_836620486405_item	2900605	et	3	main
arutleme	doc_836620486405_item	2900608	et	3	main
õpilased	doc_836620486405_item	2900621	et	3	main
kodus	doc_836620486405_item	2900623	et	4	main
taga	doc_836620486405_item	2900625	et	4	main
ilma	doc_836620486405_item	2900626	et	4	main
võimalik	doc_836620486405_item	2900638	et	3	main
kui	doc_836620486405_item	2900640	et	3	main
õpilastel	doc_836620486405_item	2900642	et	4	main
ja	doc_836620486405_item	2900646	et	3	main
teadmised	doc_836620486405_item	2900648	et	4	main
õpilastele	doc_836620486405_item	2900659	et	4	main
kohustusliku	doc_836620486405_item	2900660	et	3	main
koolivorm	doc_836620486405_item	2900661	et	3	main
muudatusest	doc_836620486405_item	2900684	et	4	main
kui	doc_836620486405_item	2900685	et	3	main
tekivad	doc_836620486405_item	2900686	et	3	main
problemid	doc_836620486405_item	2900687	et	4	main
erakorras	doc_836620486405_item	2900690	et	3	main
koolipingidest	doc_836620486405_item	2900694	et	3	main
klassis	doc_836620486405_item	2900697	et	3	main
koolipinke	doc_836620486405_item	2900700	et	4	main
on	doc_836620486405_item	2900701	et	4	main
väga	doc_836620486405_item	2900702	et	3	main
halb	doc_836620486405_item	2900703	et	3	main
ja	doc_836620486405_item	2900704	et	3	main
ebareaalne	doc_836620486405_item	2900705	et	3	main
ma	doc_836620486405_item	2900706	et	3	main
ei	doc_836620486405_item	2900707	et	4	main
klasside	doc_836620486405_item	2900722	et	3	main
korterid	doc_836620486404_item	2900485	et	3	main
alati	doc_836620486404_item	2900491	et	4	main
ma	doc_836620486404_item	2900494	et	3	main
on	doc_836620486404_item	2900499	et	4	main
meie	doc_836620486404_item	2900500	et	4	main
kollegid	doc_836620486405_item	2900521	et	4	main
on	doc_836620486405_item	2900523	et	4	main
tervitada	doc_836620486405_item	2900526	et	3	main
teid	doc_836620486405_item	2900527	et	4	main
teile	doc_836620486405_item	2900532	et	4	main
uut	doc_836620486405_item	2900542	et	3	main
otsustasin	doc_836620486405_item	2900549	et	3	main
ja	doc_836620486405_item	2900552	et	3	main
õppeainedele	doc_836620486405_item	2900560	et	4	main
tööõpetus	doc_836620486405_item	2900562	et	3	main
arvates	doc_836620486405_item	2900568	et	4	main
on	doc_836620486405_item	2900571	et	4	main
pakkumine	doc_836620486405_item	2900588	et	4	main
sest	doc_836620486405_item	2900594	et	4	main
õpetajad	doc_836620486405_item	2900601	et	4	main
ma	doc_836620486405_item	2900602	et	3	main
küsimust	doc_836620486405_item	2900610	et	4	main
on	doc_836620486405_item	2900629	et	4	main
keeruline	doc_836620486405_item	2900630	et	4	main
ole	doc_836620486405_item	2900635	et	4	main
arvutit	doc_836620486405_item	2900636	et	3	main
igal	doc_836620486405_item	2900641	et	3	main
on	doc_836620486405_item	2900643	et	4	main
küsimus	doc_836620486405_item	2900654	et	4	main
otsustatakse	doc_836620486405_item	2900655	et	3	main
ma	doc_836620486405_item	2900656	et	3	main
pakun	doc_836620486405_item	2900657	et	3	main
ja	doc_836620486405_item	2900671	et	3	main
küsimus	doc_836620486405_item	2900692	et	4	main
sellest	doc_836620486405_item	2900709	et	4	main
ma	doc_836620486405_item	2900711	et	3	main
öelda	doc_836620486405_item	2900713	et	4	main
ma	doc_836620486405_item	2900715	et	3	main
juhatajadeks	doc_836620486405_item	2900723	et	4	main
ja	doc_836620486405_item	2900724	et	3	main
aineõpetajaks	doc_836620486405_item	2900725	et	3	main
koostasin	doc_836620486405_item	2900727	et	3	main
ka	doc_836620486405_item	2900728	et	3	main
ainekava	doc_836620486405_item	2900730	et	4	main
milliga	doc_836620486405_item	2900731	et	4	main
küsimused	doc_836620486405_item	2900737	et	4	main
ootan	doc_836620486405_item	2900739	et	3	main
kabinetisbr	doc_836620486405_item	2900741	et	4	main
kui	doc_836620486405_item	2900742	et	3	main
käesoleval	doc_836620486405_item	2900743	et	3	main
ajal	doc_836620486405_item	2900744	et	4	main
ei	doc_836620486405_item	2900746	et	4	main
kõne	doc_836620486406_item	2900757	et	4	main
minu	doc_836620486407_item	2900768	et	3	main
minibuss	doc_836620486407_item	2900772	et	3	main
pööras	doc_836620486407_item	2900784	et	4	main
ristmikul	doc_836620486407_item	2900796	et	4	main
ma	doc_836620486407_item	2900797	et	3	main
pidurdasin	doc_836620486407_item	2900798	et	3	main
sõitis	doc_836620486407_item	2900803	et	3	main
otse	doc_836620486407_item	2900806	et	4	main
ei	doc_836620486407_item	2900808	et	4	main
normaalset	doc_836620486407_item	2900818	et	3	main
mis	doc_836620486407_item	2900823	et	4	main
ja	doc_836620486407_item	2900825	et	3	main
juhatajale	doc_836620486408_item	2900834	et	4	main
x	doc_836620486408_item	2900841	et	4	main
kahjuks	doc_836620486408_item	2900847	et	4	main
kaupa	doc_836620486408_item	2900851	et	4	main
märkasin	doc_836620486408_item	2900855	et	3	main
ei	doc_836620486408_item	2900858	et	4	main
miksri	doc_836620486408_item	2900860	et	4	main
on	doc_836620486408_item	2900862	et	4	main
350	doc_836620486408_item	2900863	et	2	main
krooni	doc_836620486408_item	2900866	et	4	main
mina	doc_836620486408_item	2900867	et	4	main
pöördasin	doc_836620486408_item	2900868	et	4	main
müüja	doc_836620486408_item	2900869	et	4	main
selle	doc_836620486408_item	2900873	et	4	main
ta	doc_836620486408_item	2900876	et	4	main
ei	doc_836620486408_item	2900877	et	4	main
tahtnud	doc_836620486408_item	2900878	et	4	main
edusid	doc_836620486405_item	2900534	et	3	main
teie	doc_836620486405_item	2900535	et	4	main
töös	doc_836620486405_item	2900536	et	3	main
lubage	doc_836620486405_item	2900537	et	3	main
palun	doc_836620486405_item	2900538	et	3	main
mulle	doc_836620486405_item	2900539	et	4	main
esiteks	doc_836620486405_item	2900547	et	3	main
tutvustada	doc_836620486405_item	2900540	et	3	main
ja	doc_836620486405_item	2900544	et	3	main
muudatused	doc_836620486405_item	2900546	et	3	main
ma	doc_836620486405_item	2900548	et	3	main
musikaõpetus	doc_836620486405_item	2900561	et	4	main
kehaline	doc_836620486405_item	2900563	et	4	main
ja	doc_836620486405_item	2900565	et	3	main
joonistamine	doc_836620486405_item	2900566	et	4	main
teiseks	doc_836620486405_item	2900583	et	4	main
ma	doc_836620486405_item	2900584	et	3	main
et	doc_836620486405_item	2900586	et	3	main
õpetajate	doc_836620486405_item	2900590	et	4	main
valimist	doc_836620486405_item	2900591	et	4	main
on	doc_836620486405_item	2900592	et	4	main
ebareaalne	doc_836620486405_item	2900593	et	3	main
puuduvad	doc_836620486405_item	2900599	et	4	main
mõned	doc_836620486405_item	2900600	et	3	main
aastal	doc_836620486405_item	2900606	et	3	main
ma	doc_836620486405_item	2900607	et	3	main
sellest	doc_836620486405_item	2900609	et	4	main
ja	doc_836620486405_item	2900611	et	3	main
vastame	doc_836620486405_item	2900612	et	3	main
õpilastele	doc_836620486405_item	2900613	et	4	main
ma	doc_836620486405_item	2900614	et	3	main
vaatasin	doc_836620486405_item	2900615	et	3	main
ka	doc_836620486405_item	2900616	et	3	main
küsimust	doc_836620486405_item	2900617	et	4	main
kus	doc_836620486405_item	2900618	et	3	main
õpivad	doc_836620486405_item	2900622	et	3	main
arvuti	doc_836620486405_item	2900624	et	4	main
küsimus	doc_836620486405_item	2900631	et	4	main
mõnedel	doc_836620486405_item	2900632	et	3	main
arvuti	doc_836620486405_item	2900644	et	4	main
nende	doc_836620486405_item	2900647	et	4	main
on	doc_836620486405_item	2900649	et	4	main
arvan	doc_836620486405_item	2900663	et	3	main
teevad	doc_836620486405_item	2900666	et	3	main
õpilased	doc_836620486405_item	2900668	et	3	main
klassikoosolekuid	doc_836620486405_item	2900678	et	3	main
vanematega	doc_836620486405_item	2900679	et	4	main
andma	doc_836620486405_item	2900680	et	3	main
ja	doc_836620486405_item	2900681	et	3	main
jutustama	doc_836620486405_item	2900682	et	3	main
meie	doc_836620486405_item	2900683	et	4	main
ei	doc_836620486405_item	2900698	et	4	main
mõtelda	doc_836620486405_item	2900710	et	4	main
et	doc_836620486405_item	2900714	et	3	main
võite	doc_836620486405_item	2900733	et	4	main
tutvustada	doc_836620486405_item	2900734	et	3	main
ma	doc_836620486405_item	2900738	et	3	main
auto	doc_836620486407_item	2900769	et	4	main
kõrval	doc_836620486407_item	2900775	et	4	main
minibuss	doc_836620486407_item	2900777	et	3	main
paremale	doc_836620486407_item	2900786	et	4	main
ja	doc_836620486407_item	2900787	et	3	main
põgenes	doc_836620486407_item	2900788	et	3	main
kiirust	doc_836620486407_item	2900810	et	4	main
oranž	doc_836620486407_item	2900814	et	2	main
koeraomanik	doc_836620486407_item	2900820	et	3	main
juhtus	doc_836620486407_item	2900824	et	3	main
kutsus	doc_836620486407_item	2900826	et	4	main
politsei	doc_836620486407_item	2900827	et	4	main
ja	doc_836620486407_item	2900828	et	3	main
kiirabi	doc_836620486407_item	2900829	et	4	main
kaebus	doc_836620486408_item	2900830	et	3	main
p	doc_836620486408_item	2900835	et	4	main
yyy	doc_836620486408_item	2900842	et	4	main
ostsin	doc_836620486408_item	2900843	et	3	main
müüja	doc_836620486408_item	2900848	et	4	main
kodus	doc_836620486408_item	2900853	et	4	main
kolmsada	doc_836620486408_item	2900864	et	4	main
kellelt	doc_836620486408_item	2900871	et	4	main
ostsin	doc_836620486408_item	2900872	et	3	main
aidata	doc_836620486408_item	2900880	et	4	main
mul	doc_836620486408_item	2900881	et	3	main
on	doc_836620486408_item	2900882	et	4	main
olemas	doc_836620486408_item	2900883	et	4	main
ja	doc_836620486408_item	2900885	et	3	main
et	doc_836620486408_item	2900891	et	3	main
kooli	doc_836620486405_item	2900589	et	4	main
aastal	doc_836620486405_item	2900596	et	3	main
meie	doc_836620486405_item	2900597	et	4	main
mõtlen	doc_836620486405_item	2900603	et	3	main
pakkuti	doc_836620486405_item	2900619	et	4	main
et	doc_836620486405_item	2900620	et	3	main
see	doc_836620486405_item	2900628	et	3	main
õpilastel	doc_836620486405_item	2900633	et	4	main
rohkem	doc_836620486405_item	2900650	et	4	main
kui	doc_836620486405_item	2900651	et	3	main
praegu	doc_836620486405_item	2900652	et	3	main
see	doc_836620486405_item	2900653	et	3	main
et	doc_836620486405_item	2900664	et	3	main
koolivorm	doc_836620486405_item	2900665	et	3	main
meie	doc_836620486405_item	2900667	et	4	main
viisakad	doc_836620486405_item	2900670	et	4	main
õpetajad	doc_836620486405_item	2900676	et	4	main
otsustame	doc_836620486405_item	2900689	et	3	main
sõltub	doc_836620486405_item	2900693	et	3	main
mõte	doc_836620486405_item	2900695	et	3	main
taha	doc_836620486405_item	2900708	et	4	main
te	doc_836620486405_item	2900732	et	4	main
on	doc_836620486405_item	2900736	et	4	main
otse	doc_836620486407_item	2900767	et	4	main
jalgrattur	doc_836620486407_item	2900773	et	3	main
teel	doc_836620486407_item	2900776	et	4	main
otse	doc_836620486407_item	2900779	et	4	main
jalgratturile	doc_836620486407_item	2900780	et	3	main
ja	doc_836620486407_item	2900781	et	3	main
minibuss	doc_836620486407_item	2900782	et	3	main
sündmuskohalt	doc_836620486407_item	2900789	et	4	main
kui	doc_836620486407_item	2900790	et	3	main
ma	doc_836620486407_item	2900791	et	3	main
nägin	doc_836620486407_item	2900792	et	3	main
jalgratturit	doc_836620486407_item	2900793	et	3	main
kes	doc_836620486407_item	2900794	et	4	main
lamas	doc_836620486407_item	2900795	et	3	main
aga	doc_836620486407_item	2900800	et	3	main
auto	doc_836620486407_item	2900802	et	4	main
minu	doc_836620486407_item	2900804	et	3	main
auto	doc_836620486407_item	2900805	et	4	main
ma	doc_836620486407_item	2900807	et	3	main
ei	doc_836620486407_item	2900816	et	4	main
hoida	doc_836620486407_item	2900817	et	3	main
pikivahet	doc_836620486407_item	2900819	et	3	main
seda	doc_836620486407_item	2900822	et	3	main
hr	doc_836620486408_item	2900837	et	4	main
urmas	doc_836620486408_item	2900838	et	3	main
mets	doc_836620486408_item	2900839	et	3	main
mina	doc_836620486408_item	2900840	et	4	main
miksri	doc_836620486408_item	2900846	et	4	main
kontrollinud	doc_836620486408_item	2900850	et	4	main
aga	doc_836620486408_item	2900854	et	3	main
et	doc_836620486408_item	2900856	et	3	main
tööta	doc_836620486408_item	2900859	et	4	main
hind	doc_836620486408_item	2900861	et	3	main
poole	doc_836620486408_item	2900870	et	4	main
miksri	doc_836620486408_item	2900874	et	4	main
vaid	doc_836620486408_item	2900875	et	3	main
kestab	doc_836620486408_item	2900888	et	4	main
tahtsin	doc_836620486408_item	2900889	et	3	main
öelda	doc_836620486408_item	2900890	et	4	main
te	doc_836620486408_item	2900893	et	4	main
koju	doc_836620486408_item	2900921	et	3	main
nõus	doc_836620486408_item	2900928	et	4	main
miksri	doc_836620486408_item	2900930	et	4	main
p	doc_836620486408_item	2900934	et	4	main
kõige	doc_836620486409_item	2900956	et	4	main
kõik	doc_836620486409_item	2900960	et	4	main
mida	doc_836620486409_item	2900961	et	4	main
meie	doc_836620486409_item	2900962	et	4	main
ümbritseb	doc_836620486409_item	2900963	et	3	main
mis	doc_836620486409_item	2900970	et	4	main
hästi	doc_836620486409_item	2900973	et	3	main
sinule	doc_836620486409_item	2900975	et	3	main
suhtled	doc_836620486409_item	2900988	et	3	main
ja	doc_836620486409_item	2900998	et	3	main
ja	doc_836620486409_item	2901002	et	3	main
midagi	doc_836620486409_item	2901043	et	4	main
unustad	doc_836620486409_item	2901053	et	3	main
kuidas	doc_836620486409_item	2901062	et	3	main
hakkama	doc_836620486409_item	2901066	et	3	main
õpetajata	doc_836620486405_item	2900627	et	4	main
ei	doc_836620486405_item	2900634	et	4	main
kodus	doc_836620486405_item	2900637	et	4	main
tulemusel	doc_836620486405_item	2900639	et	3	main
kodus	doc_836620486405_item	2900645	et	4	main
algklasside	doc_836620486405_item	2900658	et	3	main
ma	doc_836620486405_item	2900662	et	3	main
korralikud	doc_836620486405_item	2900669	et	3	main
distsiplineeritud	doc_836620486405_item	2900672	et	4	main
septembri	doc_836620486405_item	2900673	et	3	main
algusel	doc_836620486405_item	2900674	et	4	main
algklasside	doc_836620486405_item	2900675	et	3	main
peavad	doc_836620486405_item	2900677	et	4	main
me	doc_836620486405_item	2900688	et	4	main
viimane	doc_836620486405_item	2900691	et	3	main
et	doc_836620486405_item	2900696	et	3	main
ole	doc_836620486405_item	2900699	et	4	main
tahan	doc_836620486405_item	2900712	et	3	main
tegin	doc_836620486405_item	2900716	et	3	main
käskkirja	doc_836620486405_item	2900717	et	4	main
kus	doc_836620486405_item	2900718	et	3	main
ma	doc_836620486405_item	2900719	et	3	main
määrasin	doc_836620486405_item	2900720	et	3	main
teil	doc_836620486405_item	2900745	et	4	main
ole	doc_836620486405_item	2900747	et	4	main
ma	doc_836620486405_item	2900749	et	3	main
oma	doc_836620486405_item	2900751	et	4	main
ma	doc_836620486407_item	2900765	et	3	main
ees	doc_836620486407_item	2900770	et	4	main
kõrvalteele	doc_836620486407_item	2900785	et	4	main
oranži	doc_836620486407_item	2900801	et	2	main
ma	doc_836620486407_item	2900811	et	3	main
arvan	doc_836620486407_item	2900812	et	3	main
et	doc_836620486407_item	2900813	et	3	main
auto	doc_836620486407_item	2900815	et	4	main
nägi	doc_836620486407_item	2900821	et	3	main
yyy	doc_836620486408_item	2900832	et	4	main
kaubamaja	doc_836620486408_item	2900833	et	4	main
kauplusest	doc_836620486408_item	2900845	et	4	main
see	doc_836620486408_item	2900857	et	3	main
kui	doc_836620486408_item	2900922	et	3	main
oleksin	doc_836620486408_item	2900927	et	3	main
p	doc_836620486408_item	2900937	et	4	main
2003	doc_836620486408_item	2900940	et	2	main
elu	doc_836620486409_item	2900946	et	4	main
inimese	doc_836620486409_item	2900953	et	4	main
rohkem	doc_836620486409_item	2900957	et	4	main
ühiskond	doc_836620486409_item	2900959	et	3	main
käid	doc_836620486409_item	2900966	et	3	main
ja	doc_836620486409_item	2900968	et	3	main
kõik	doc_836620486409_item	2900969	et	4	main
mida	doc_836620486409_item	2900977	et	4	main
õpetajad	doc_836620486409_item	2900978	et	4	main
mida	doc_836620486409_item	2900981	et	4	main
sa	doc_836620486409_item	2900982	et	3	main
seal	doc_836620486409_item	2900984	et	4	main
sa	doc_836620486409_item	2900987	et	3	main
ongi	doc_836620486409_item	2900991	et	4	main
ühiskond	doc_836620486409_item	2900994	et	3	main
me	doc_836620486409_item	2900999	et	4	main
selle	doc_836620486409_item	2901024	et	4	main
et	doc_836620486409_item	2901026	et	3	main
on	doc_836620486409_item	2901028	et	4	main
ja	doc_836620486409_item	2901031	et	3	main
päeval	doc_836620486409_item	2901034	et	3	main
situatsioon	doc_836620486409_item	2901037	et	3	main
tähtis	doc_836620486409_item	2901044	et	4	main
tihti	doc_836620486409_item	2901049	et	3	main
võttid	doc_836620486409_item	2901055	et	4	main
veel	doc_836620486409_item	2901060	et	4	main
siis	doc_836620486409_item	2901064	et	3	main
aga	doc_836620486409_item	2901069	et	3	main
sa	doc_836620486409_item	2901071	et	3	main
peale	doc_836620486410_item	2901121	et	4	main
ei	doc_836620486410_item	2901129	et	4	main
jne	doc_836620486410_item	2901135	et	4	main
selle	doc_836620486410_item	2901136	et	4	main
arengut	doc_836620486410_item	2901141	et	3	main
vanemate	doc_836620486405_item	2900721	et	4	main
ma	doc_836620486405_item	2900726	et	3	main
uue	doc_836620486405_item	2900729	et	3	main
kellel	doc_836620486405_item	2900735	et	4	main
oma	doc_836620486405_item	2900740	et	4	main
küsimusi	doc_836620486405_item	2900748	et	4	main
lõpetan	doc_836620486405_item	2900750	et	3	main
aruanne	doc_836620486405_item	2900752	et	4	main
ja	doc_836620486405_item	2900753	et	3	main
tänan	doc_836620486405_item	2900754	et	3	main
teid	doc_836620486405_item	2900755	et	4	main
direktori	doc_836620486406_item	2900756	et	3	main
liiklusõnnetuse	doc_836620486407_item	2900758	et	4	main
kirjeldus	doc_836620486407_item	2900759	et	4	main
mina	doc_836620486407_item	2900760	et	4	main
olen	doc_836620486407_item	2900761	et	3	main
auto	doc_836620486407_item	2900762	et	4	main
b	doc_836620486407_item	2900763	et	4	main
juht	doc_836620486407_item	2900764	et	3	main
sõitsin	doc_836620486407_item	2900766	et	3	main
sõitis	doc_836620486407_item	2900771	et	3	main
sõitis	doc_836620486407_item	2900774	et	3	main
sõitis	doc_836620486407_item	2900778	et	3	main
kohe	doc_836620486407_item	2900783	et	4	main
järsult	doc_836620486407_item	2900799	et	4	main
ületanud	doc_836620486407_item	2900809	et	4	main
xxx	doc_836620486408_item	2900831	et	4	main
lugupeetud	doc_836620486408_item	2900836	et	4	main
teie	doc_836620486408_item	2900844	et	4	main
ei	doc_836620486408_item	2900849	et	4	main
kohe	doc_836620486408_item	2900852	et	4	main
viiskümmend	doc_836620486408_item	2900865	et	4	main
garantii	doc_836620486408_item	2900886	et	4	main
veel	doc_836620486408_item	2900887	et	4	main
mind	doc_836620486408_item	2900896	et	4	main
siis	doc_836620486408_item	2900897	et	3	main
ma	doc_836620486408_item	2900898	et	3	main
pöördan	doc_836620486408_item	2900899	et	4	main
tarbijakaitse	doc_836620486408_item	2900900	et	4	main
ameti	doc_836620486408_item	2900901	et	3	main
poole	doc_836620486408_item	2900902	et	4	main
ma	doc_836620486408_item	2900903	et	3	main
ostsin	doc_836620486408_item	2900904	et	3	main
miksri	doc_836620486408_item	2900905	et	4	main
10	doc_836620486408_item	2900906	et	2	main
12	doc_836620486408_item	2900907	et	2	main
03	doc_836620486408_item	2900908	et	2	main
aga	doc_836620486408_item	2900909	et	3	main
on	doc_836620486408_item	2900911	et	4	main
15	doc_836620486408_item	2900912	et	2	main
12	doc_836620486408_item	2900913	et	2	main
täna	doc_836620486408_item	2900910	et	4	main
03	doc_836620486408_item	2900914	et	2	main
ma	doc_836620486408_item	2900915	et	3	main
märkasin	doc_836620486408_item	2900916	et	3	main
seda	doc_836620486408_item	2900917	et	3	main
kohe	doc_836620486408_item	2900918	et	4	main
kui	doc_836620486408_item	2900919	et	3	main
tulin	doc_836620486408_item	2900920	et	3	main
võimalik	doc_836620486408_item	2900925	et	3	main
kodutel	doc_836620486408_item	2900935	et	4	main
11111111	doc_836620486408_item	2900936	et	2	main
mis	doc_836620486409_item	2900943	et	4	main
ma	doc_836620486409_item	2900949	et	3	main
elu	doc_836620486409_item	2900954	et	4	main
näiteks	doc_836620486409_item	2900964	et	4	main
ütlevad	doc_836620486409_item	2900979	et	4	main
ja	doc_836620486409_item	2900985	et	3	main
meie	doc_836620486409_item	2900992	et	4	main
elu	doc_836620486409_item	2900993	et	4	main
mõjutab	doc_836620486409_item	2900995	et	3	main
inimese	doc_836620486409_item	2900996	et	4	main
mõjutame	doc_836620486409_item	2901000	et	3	main
ühiskonnale	doc_836620486409_item	2901001	et	4	main
ei	doc_836620486409_item	2901003	et	4	main
peab	doc_836620486409_item	2901021	et	4	main
pärast	doc_836620486409_item	2901025	et	4	main
see	doc_836620486409_item	2901027	et	3	main
väga	doc_836620486409_item	2901029	et	3	main
kasulik	doc_836620486409_item	2901032	et	3	main
juhtub	doc_836620486409_item	2901035	et	3	main
et	doc_836620486409_item	2901038	et	3	main
või	doc_836620486409_item	2901046	et	4	main
küsida	doc_836620486409_item	2901048	et	3	main
mind	doc_836620486408_item	2900879	et	4	main
ostutšek	doc_836620486408_item	2900884	et	2	main
kui	doc_836620486408_item	2900892	et	3	main
ei	doc_836620486408_item	2900894	et	4	main
aita	doc_836620486408_item	2900895	et	4	main
teil	doc_836620486408_item	2900923	et	4	main
ma	doc_836620486408_item	2900926	et	3	main
vahetada	doc_836620486408_item	2900929	et	3	main
ümber	doc_836620486408_item	2900931	et	3	main
15	doc_836620486408_item	2900938	et	2	main
inimese	doc_836620486409_item	2900945	et	4	main
kõige	doc_836620486409_item	2900947	et	4	main
arvan	doc_836620486409_item	2900950	et	3	main
iga	doc_836620486409_item	2900952	et	4	main
toimub	doc_836620486409_item	2900972	et	3	main
mõjutab	doc_836620486409_item	2900974	et	3	main
kõik	doc_836620486409_item	2900976	et	4	main
kellega	doc_836620486409_item	2900986	et	3	main
saa	doc_836620486409_item	2901004	et	4	main
olla	doc_836620486409_item	2901005	et	3	main
on	doc_836620486408_item	2900924	et	4	main
lugupidamisega	doc_836620486408_item	2900932	et	3	main
xyyy	doc_836620486408_item	2900933	et	4	main
12	doc_836620486408_item	2900939	et	2	main
p	doc_836620486408_item	2900941	et	4	main
kontrolltöö	doc_836620486409_item	2900942	et	4	main
mõjutab	doc_836620486409_item	2900944	et	3	main
rohkem	doc_836620486409_item	2900948	et	4	main
et	doc_836620486409_item	2900951	et	3	main
mõjutab	doc_836620486409_item	2900955	et	3	main
meie	doc_836620486409_item	2900958	et	4	main
sa	doc_836620486409_item	2900965	et	3	main
koolis	doc_836620486409_item	2900967	et	4	main
seal	doc_836620486409_item	2900971	et	4	main
kõik	doc_836620486409_item	2900980	et	4	main
näed	doc_836620486409_item	2900983	et	3	main
ja	doc_836620486409_item	2900989	et	3	main
see	doc_836620486409_item	2900990	et	3	main
elu	doc_836620486409_item	2900997	et	4	main
kuidagi	doc_836620486409_item	2901006	et	3	main
teisiti	doc_836620486409_item	2901007	et	3	main
kas	doc_836620486409_item	2901008	et	3	main
igal	doc_836620486409_item	2901009	et	3	main
inimesel	doc_836620486409_item	2901010	et	3	main
peab	doc_836620486409_item	2901011	et	4	main
olema	doc_836620486409_item	2901012	et	4	main
mobiiltelefon	doc_836620486409_item	2901013	et	3	main
jah	doc_836620486409_item	2901014	et	3	main
ma	doc_836620486409_item	2901015	et	3	main
arvan	doc_836620486409_item	2901016	et	3	main
et	doc_836620486409_item	2901017	et	3	main
tõenäoliselt	doc_836620486409_item	2901018	et	4	main
igal	doc_836620486409_item	2901019	et	3	main
inimesel	doc_836620486409_item	2901020	et	3	main
olema	doc_836620486409_item	2901022	et	4	main
midagi	doc_836620486409_item	2901047	et	4	main
et	doc_836620486409_item	2901051	et	3	main
midagi	doc_836620486409_item	2901059	et	4	main
saad	doc_836620486409_item	2901065	et	4	main
ilma	doc_836620486409_item	2901067	et	4	main
mobiiltelefonita	doc_836620486409_item	2901068	et	3	main
selle	doc_836620486410_item	2901112	et	4	main
millidega	doc_836620486410_item	2901127	et	4	main
arstid	doc_836620486410_item	2901128	et	4	main
pärast	doc_836620486410_item	2901137	et	4	main
inimesed	doc_836620486410_item	2901138	et	3	main
meie	doc_836620486410_item	2901148	et	4	main
ikka	doc_836620486410_item	2901152	et	4	main
kõik	doc_836620486410_item	2901159	et	4	main
nii	doc_836620486410_item	2901164	et	3	main
on	doc_836620486410_item	2901179	et	4	main
raske	doc_836620486410_item	2901181	et	4	main
elu	doc_836620486410_item	2901182	et	4	main
püüavad	doc_836620486410_item	2901188	et	3	main
ajal	doc_836620486410_item	2901198	et	4	main
partnereid	doc_836620486410_item	2901223	et	3	main
loodud	doc_836620486410_item	2901233	et	4	main
suhetest	doc_836620486410_item	2901234	et	3	main
selles	doc_836620486410_item	2901238	et	4	main
meil	doc_836620486410_item	2901253	et	4	main
mõtlen	doc_836620486410_item	2901274	et	3	main
jgaüks	doc_836620486410_item	2901280	et	4	main
saavutab	doc_836620486410_item	2901281	et	3	main
oma	doc_836620486410_item	2901283	et	4	main
ise	doc_836620486410_item	2901285	et	4	main
tegur	doc_836620486410_item	2901322	et	3	main
sinu	doc_836620486410_item	2901342	et	3	main
mobiiltelefon	doc_836620486409_item	2901023	et	3	main
mugav	doc_836620486409_item	2901030	et	3	main
igal	doc_836620486409_item	2901033	et	3	main
niisuguse	doc_836620486409_item	2901036	et	3	main
on	doc_836620486409_item	2901039	et	4	main
vaja	doc_836620486409_item	2901040	et	4	main
helistada	doc_836620486409_item	2901041	et	3	main
ja	doc_836620486409_item	2901042	et	3	main
öelda	doc_836620486409_item	2901045	et	4	main
sa	doc_836620486409_item	2901063	et	3	main
võid	doc_836620486409_item	2901079	et	4	main
helistada	doc_836620486409_item	2901080	et	3	main
ja	doc_836620486409_item	2901081	et	3	main
inimestega	doc_836620486409_item	2901082	et	3	main
kokku	doc_836620486409_item	2901083	et	3	main
lepida	doc_836620486409_item	2901084	et	4	main
millest	doc_836620486410_item	2901085	et	3	main
sõltub	doc_836620486410_item	2901086	et	3	main
eluiga	doc_836620486410_item	2901087	et	4	main
millest	doc_836620486410_item	2901088	et	3	main
sõltub	doc_836620486410_item	2901089	et	3	main
eluiga	doc_836620486410_item	2901090	et	4	main
p	doc_836620486410_item	2901091	et	4	main
minu	doc_836620486410_item	2901092	et	3	main
arvates	doc_836620486410_item	2901093	et	4	main
eluiga	doc_836620486410_item	2901094	et	4	main
sõltub	doc_836620486410_item	2901095	et	3	main
meditsiini	doc_836620486410_item	2901096	et	4	main
arengust	doc_836620486410_item	2901097	et	3	main
jõukust	doc_836620486410_item	2901098	et	4	main
arstiabi	doc_836620486410_item	2901099	et	4	main
kättesaadavust	doc_836620486410_item	2901100	et	4	main
ja	doc_836620486410_item	2901101	et	3	main
suhtedest	doc_836620486410_item	2901102	et	4	main
teiste	doc_836620486410_item	2901103	et	4	main
inimestega	doc_836620486410_item	2901104	et	3	main
meditsiini	doc_836620486410_item	2901105	et	4	main
areng	doc_836620486410_item	2901106	et	3	main
on	doc_836620486410_item	2901107	et	4	main
väga	doc_836620486410_item	2901108	et	3	main
tähtis	doc_836620486410_item	2901109	et	4	main
meie	doc_836620486410_item	2901110	et	4	main
jaoks	doc_836620486410_item	2901111	et	4	main
juhtub	doc_836620486409_item	2901050	et	3	main
sa	doc_836620486409_item	2901052	et	3	main
oma	doc_836620486409_item	2901054	et	4	main
kaasas	doc_836620486409_item	2901056	et	4	main
võtta	doc_836620486409_item	2901057	et	3	main
või	doc_836620486409_item	2901058	et	4	main
ja	doc_836620486409_item	2901061	et	3	main
mobiiltelefoniga	doc_836620486409_item	2901070	et	4	main
võid	doc_836620486409_item	2901072	et	4	main
rahul	doc_836620486409_item	2901073	et	4	main
olla	doc_836620486409_item	2901074	et	3	main
pärast	doc_836620486410_item	2901113	et	4	main
et	doc_836620486410_item	2901114	et	3	main
peaaegu	doc_836620486410_item	2901115	et	3	main
igal	doc_836620486410_item	2901116	et	3	main
aastal	doc_836620486410_item	2901117	et	3	main
ilmuvad	doc_836620486410_item	2901118	et	4	main
uued	doc_836620486410_item	2901119	et	3	main
haigused	doc_836620486410_item	2901120	et	4	main
maailmas	doc_836620486410_item	2901123	et	3	main
võitelda	doc_836620486410_item	2901131	et	4	main
nõuavad	doc_836620486410_item	2901139	et	4	main
arstiabi	doc_836620486410_item	2901142	et	4	main
tähtis	doc_836620486410_item	2901147	et	4	main
kui	doc_836620486410_item	2901162	et	3	main
lapsed	doc_836620486410_item	2901165	et	3	main
pärast	doc_836620486410_item	2901167	et	4	main
kõigil	doc_836620486410_item	2901168	et	4	main
arstiabi	doc_836620486410_item	2901175	et	4	main
kätte	doc_836620486410_item	2901176	et	4	main
raha	doc_836620486410_item	2901183	et	4	main
on	doc_836620486410_item	2901191	et	4	main
elada	doc_836620486410_item	2901194	et	3	main
meil	doc_836620486410_item	2901225	et	4	main
suhted	doc_836620486410_item	2901227	et	3	main
teiste	doc_836620486410_item	2901228	et	4	main
inimestega	doc_836620486410_item	2901229	et	3	main
igaüks	doc_836620486410_item	2901236	et	3	main
ei	doc_836620486410_item	2901240	et	4	main
on	doc_836620486410_item	2901249	et	4	main
väga	doc_836620486410_item	2901250	et	3	main
tähtis	doc_836620486410_item	2901251	et	4	main
et	doc_836620486410_item	2901252	et	3	main
teiste	doc_836620486410_item	2901256	et	4	main
minu	doc_836620486410_item	2901258	et	3	main
arvamus	doc_836620486410_item	2901259	et	3	main
see	doc_836620486410_item	2901261	et	3	main
eelnevad	doc_836620486410_item	2901272	et	4	main
pärilikkusel	doc_836620486410_item	2901276	et	4	main
mingit	doc_836620486410_item	2901278	et	3	main
tähtis	doc_836620486410_item	2901287	et	4	main
tema	doc_836620486410_item	2901288	et	4	main
kasvatus	doc_836620486410_item	2901289	et	4	main
vaid	doc_836620486410_item	2901290	et	3	main
kooli-	doc_836620486410_item	2901323	et	4	main
või	doc_836620486410_item	2901324	et	4	main
ülikooli	doc_836620486410_item	2901325	et	4	main
haridus	doc_836620486410_item	2901326	et	3	main
aitab	doc_836620486410_item	2901327	et	3	main
peame	doc_836620486410_item	2901335	et	4	main
et	doc_836620486410_item	2901349	et	3	main
jäävad	doc_836620486410_item	2901352	et	4	main
kõik	doc_836620486410_item	2901354	et	4	main
võib-olla	doc_836620486410_item	2901360	et	3	main
kõrgemaile	doc_836620486410_item	2901366	et	4	main
ma	doc_836620486410_item	2901368	et	3	main
me	doc_836620486410_item	2901382	et	4	main
ju	doc_836620486410_item	2901383	et	3	main
on	doc_836620486410_item	2901394	et	4	main
imelik	doc_836620486410_item	2901395	et	3	main
asi	doc_836620486410_item	2901396	et	4	main
elus	doc_836620486410_item	2901402	et	4	main
tähtis	doc_836620486410_item	2901405	et	4	main
meditsiniabi	doc_836620486411_item	2901424	et	4	main
teeb	doc_836620486411_item	2901425	et	3	main
meditsini	doc_836620486411_item	2901432	et	3	main
sest	doc_836620486411_item	2901440	et	4	main
on	doc_836620486411_item	2901444	et	4	main
sugulased	doc_836620486411_item	2901446	et	3	main
on	doc_836620486411_item	2901457	et	4	main
meie	doc_836620486411_item	2901460	et	4	main
haritud	doc_836620486411_item	2901462	et	4	main
sest	doc_836620486409_item	2901075	et	4	main
igal	doc_836620486409_item	2901076	et	3	main
momendil	doc_836620486409_item	2901077	et	3	main
sa	doc_836620486409_item	2901078	et	3	main
selle	doc_836620486410_item	2901122	et	4	main
on	doc_836620486410_item	2901124	et	4	main
ka	doc_836620486410_item	2901125	et	3	main
haigused	doc_836620486410_item	2901126	et	4	main
nagu	doc_836620486410_item	2901132	et	3	main
vähk	doc_836620486410_item	2901134	et	3	main
meditsiini	doc_836620486410_item	2901140	et	4	main
kättesaadavus	doc_836620486410_item	2901143	et	4	main
on	doc_836620486410_item	2901144	et	4	main
ka	doc_836620486410_item	2901145	et	3	main
väga	doc_836620486410_item	2901146	et	3	main
on	doc_836620486410_item	2901151	et	4	main
esimene	doc_836620486410_item	2901153	et	3	main
inimesed	doc_836620486410_item	2901160	et	3	main
selle	doc_836620486410_item	2901166	et	4	main
peab	doc_836620486410_item	2901169	et	4	main
saadabr	doc_836620486410_item	2901177	et	4	main
praegu	doc_836620486410_item	2901178	et	3	main
valitsevad	doc_836620486410_item	2901184	et	4	main
maailmaga	doc_836620486410_item	2901185	et	3	main
raha	doc_836620486410_item	2901190	et	4	main
on	doc_836620486410_item	2901199	et	4	main
jõukus	doc_836620486410_item	2901200	et	4	main
väga	doc_836620486410_item	2901201	et	3	main
oluline	doc_836620486410_item	2901202	et	4	main
asi	doc_836620486410_item	2901203	et	4	main
keegi	doc_836620486410_item	2901204	et	4	main
ei	doc_836620486410_item	2901205	et	4	main
taha	doc_836620486410_item	2901206	et	4	main
vaeseks	doc_836620486410_item	2901207	et	4	main
olla	doc_836620486410_item	2901208	et	3	main
kui	doc_836620486410_item	2901209	et	3	main
me	doc_836620486410_item	2901210	et	4	main
sündime	doc_836620486410_item	2901211	et	4	main
me	doc_836620486410_item	2901212	et	4	main
suhtleme	doc_836620486410_item	2901213	et	3	main
emaga	doc_836620486410_item	2901214	et	3	main
kui	doc_836620486410_item	2901215	et	3	main
me	doc_836620486410_item	2901216	et	4	main
kasvame	doc_836620486410_item	2901217	et	3	main
leiame	doc_836620486410_item	2901218	et	3	main
sõpru	doc_836620486410_item	2901219	et	3	main
tööl	doc_836620486410_item	2901220	et	3	main
me	doc_836620486410_item	2901221	et	4	main
siis	doc_836620486410_item	2901224	et	3	main
ilmuvad	doc_836620486410_item	2901226	et	4	main
inimestega	doc_836620486410_item	2901235	et	3	main
õnnetu	doc_836620486410_item	2901247	et	4	main
elu	doc_836620486410_item	2901248	et	4	main
oleks	doc_836620486410_item	2901254	et	3	main
inimestegabr	doc_836620486410_item	2901257	et	4	main
on	doc_836620486410_item	2901260	et	4	main
pärilikkus	doc_836620486410_item	2901262	et	4	main
keskkond	doc_836620486410_item	2901263	et	3	main
haridustase	doc_836620486410_item	2901264	et	3	main
ja	doc_836620486410_item	2901265	et	3	main
nagu	doc_836620486410_item	2901271	et	3	main
ma	doc_836620486410_item	2901273	et	3	main
tähtsust	doc_836620486410_item	2901279	et	4	main
midagi	doc_836620486410_item	2901282	et	4	main
saa	doc_836620486410_item	2901130	et	4	main
aids	doc_836620486410_item	2901133	et	4	main
elus	doc_836620486410_item	2901149	et	4	main
see	doc_836620486410_item	2901150	et	3	main
asi	doc_836620486410_item	2901154	et	4	main
mida	doc_836620486410_item	2901155	et	4	main
täiskasvanud	doc_836620486410_item	2901163	et	4	main
kiiresti	doc_836620486410_item	2901174	et	3	main
kõik	doc_836620486410_item	2901186	et	4	main
inimsed	doc_836620486410_item	2901187	et	4	main
teha	doc_836620486410_item	2901189	et	3	main
raske	doc_836620486410_item	2901193	et	4	main
meie	doc_836620486410_item	2901197	et	4	main
on	doc_836620486410_item	2901232	et	4	main
on	doc_836620486410_item	2901246	et	4	main
mõtlemine	doc_836620486410_item	2901266	et	4	main
mitte	doc_836620486410_item	2901267	et	3	main
nii	doc_836620486410_item	2901268	et	3	main
olulised	doc_836620486410_item	2901269	et	4	main
tegurit	doc_836620486410_item	2901270	et	3	main
et	doc_836620486410_item	2901275	et	3	main
pole	doc_836620486410_item	2901277	et	3	main
on	doc_836620486410_item	2901286	et	4	main
oluline	doc_836620486410_item	2901321	et	4	main
saada	doc_836620486410_item	2901330	et	4	main
targemaks	doc_836620486410_item	2901331	et	4	main
aga	doc_836620486410_item	2901332	et	3	main
ei	doc_836620486410_item	2901347	et	4	main
tähenda	doc_836620486410_item	2901348	et	4	main
peavad	doc_836620486410_item	2901355	et	4	main
lugema	doc_836620486410_item	2901356	et	4	main
tõsta	doc_836620486410_item	2901364	et	4	main
haridustaseme	doc_836620486410_item	2901365	et	3	main
oluline	doc_836620486410_item	2901376	et	4	main
sõltu	doc_836620486410_item	2901380	et	4	main
palju	doc_836620486410_item	2901381	et	4	main
tea	doc_836620486410_item	2901385	et	4	main
meie	doc_836620486410_item	2901406	et	4	main
jaoks	doc_836620486410_item	2901407	et	4	main
nõuab	doc_836620486410_item	2901156	et	3	main
iga	doc_836620486410_item	2901157	et	4	main
inimene	doc_836620486410_item	2901158	et	3	main
haigestuvad	doc_836620486410_item	2901161	et	4	main
olema	doc_836620486410_item	2901170	et	4	main
võimalus	doc_836620486410_item	2901171	et	3	main
lihtsalt	doc_836620486410_item	2901172	et	4	main
ja	doc_836620486410_item	2901173	et	3	main
väga	doc_836620486410_item	2901180	et	3	main
väga	doc_836620486410_item	2901192	et	3	main
ilma	doc_836620486410_item	2901195	et	4	main
rahata	doc_836620486410_item	2901196	et	4	main
leiame	doc_836620486410_item	2901222	et	3	main
meie	doc_836620486410_item	2901230	et	4	main
maailm	doc_836620486410_item	2901231	et	3	main
vajab	doc_836620486410_item	2901237	et	3	main
me	doc_836620486410_item	2901239	et	4	main
saa	doc_836620486410_item	2901241	et	4	main
elada	doc_836620486410_item	2901242	et	3	main
üksinda	doc_836620486410_item	2901243	et	4	main
üksindus	doc_836620486410_item	2901244	et	3	main
see	doc_836620486410_item	2901245	et	3	main
suhted	doc_836620486410_item	2901255	et	3	main
mitte	doc_836620486410_item	2901291	et	3	main
pärilikkus	doc_836620486410_item	2901292	et	4	main
keskkonna	doc_836620486410_item	2901293	et	3	main
öeldes	doc_836620486410_item	2901294	et	3	main
tahaksin	doc_836620486410_item	2901295	et	3	main
märkida	doc_836620486410_item	2901296	et	4	main
et	doc_836620486410_item	2901297	et	3	main
iga	doc_836620486410_item	2901298	et	4	main
valib	doc_836620486410_item	2901300	et	3	main
inimene	doc_836620486410_item	2901299	et	3	main
see	doc_836620486410_item	2901301	et	3	main
keskkond	doc_836620486410_item	2901302	et	3	main
milles	doc_836620486410_item	2901303	et	3	main
ta	doc_836620486410_item	2901304	et	4	main
tahab	doc_836620486410_item	2901305	et	3	main
elada	doc_836620486410_item	2901306	et	3	main
milles	doc_836620486410_item	2901307	et	3	main
talle	doc_836620486410_item	2901308	et	4	main
meeldib	doc_836620486410_item	2901309	et	3	main
elada	doc_836620486410_item	2901310	et	3	main
ja	doc_836620486410_item	2901311	et	3	main
suhelda	doc_836620486410_item	2901312	et	4	main
ka	doc_836620486410_item	2901313	et	3	main
ma	doc_836620486410_item	2901314	et	3	main
mõtlen	doc_836620486410_item	2901315	et	3	main
et	doc_836620486410_item	2901316	et	3	main
haridustase	doc_836620486410_item	2901317	et	3	main
on	doc_836620486410_item	2901318	et	4	main
mitte	doc_836620486410_item	2901319	et	3	main
eriti	doc_836620486410_item	2901320	et	3	main
elus	doc_836620486410_item	2901284	et	4	main
meile	doc_836620486410_item	2901328	et	4	main
täiustama	doc_836620486410_item	2901333	et	3	main
ise	doc_836620486410_item	2901336	et	4	main
iga	doc_836620486410_item	2901337	et	4	main
päev	doc_836620486410_item	2901338	et	3	main
ja	doc_836620486410_item	2901339	et	3	main
kui	doc_836620486410_item	2901340	et	3	main
haridustase	doc_836620486410_item	2901341	et	3	main
kõik	doc_836620486410_item	2901350	et	4	main
rumalaks	doc_836620486410_item	2901353	et	3	main
siis	doc_836620486410_item	2901359	et	3	main
saame	doc_836620486410_item	2901363	et	4	main
et	doc_836620486410_item	2901370	et	3	main
tegur	doc_836620486410_item	2901377	et	3	main
sest	doc_836620486410_item	2901392	et	4	main
on	doc_836620486410_item	2901408	et	4	main
et	doc_836620486411_item	2901422	et	3	main
arengust	doc_836620486411_item	2901433	et	3	main
on	doc_836620486411_item	2901436	et	4	main
et	doc_836620486411_item	2901441	et	3	main
elus	doc_836620486411_item	2901461	et	4	main
mõjutab	doc_836620486411_item	2901484	et	3	main
tervistebr	doc_836620486411_item	2901487	et	4	main
aga	doc_836620486411_item	2901508	et	3	main
ole	doc_836620486411_item	2901512	et	4	main
vaja	doc_836620486411_item	2901513	et	4	main
inimestega	doc_836620486411_item	2901522	et	3	main
tema	doc_836620486411_item	2901535	et	4	main
ei	doc_836620486411_item	2901536	et	4	main
aru	doc_836620486411_item	2901552	et	4	main
elu	doc_836620486411_item	2901563	et	4	main
as	doc_836620486412_item	2901566	et	4	main
päeva	doc_836620486412_item	2901569	et	4	main
musta	doc_836620486412_item	2901584	et	4	main
töökonkursil	doc_836620486413_item	2901630	et	3	main
xxxxx	doc_836620486413_item	2901633	et	4	main
perekonnanimi	doc_836620486413_item	2901634	et	3	main
tere	doc_836620486413_item	2901642	et	3	main
osalesite	doc_836620486413_item	2901648	et	3	main
pärast	doc_836620486413_item	2901660	et	4	main
et	doc_836620486413_item	2901661	et	3	main
teil	doc_836620486413_item	2901662	et	4	main
ole	doc_836620486413_item	2901664	et	4	main
saksa	doc_836620486413_item	2901665	et	4	main
keele	doc_836620486413_item	2901666	et	4	main
aastal	doc_836620486413_item	2901674	et	3	main
te	doc_836620486413_item	2901677	et	4	main
meie	doc_836620486413_item	2901680	et	4	main
15	doc_836620486413_item	2901683	et	2	main
seletuskiri	doc_836620486414_item	2901686	et	3	main
minu	doc_836620486414_item	2901688	et	3	main
on	doc_836620486414_item	2901690	et	4	main
ma	doc_836620486414_item	2901693	et	3	main
03	doc_836620486414_item	2901709	et	2	main
oli	doc_836620486414_item	2901723	et	3	main
kell	doc_836620486414_item	2901725	et	3	main
mina	doc_836620486414_item	2901727	et	4	main
läksin	doc_836620486414_item	2901728	et	3	main
olnud	doc_836620486414_item	2901734	et	4	main
äkki	doc_836620486414_item	2901735	et	3	main
ma	doc_836620486414_item	2901736	et	3	main
kuulsin	doc_836620486414_item	2901737	et	3	main
sammud	doc_836620486414_item	2901738	et	4	main
minu	doc_836620486414_item	2901739	et	3	main
ma	doc_836620486414_item	2901745	et	3	main
pärast	doc_836620486414_item	2901759	et	4	main
minu	doc_836620486414_item	2901762	et	3	main
ma	doc_836620486414_item	2901788	et	3	main
karjuma	doc_836620486414_item	2901790	et	3	main
kuulsis	doc_836620486414_item	2901792	et	4	main
hirmus	doc_836620486414_item	2901798	et	4	main
jooksis	doc_836620486414_item	2901800	et	4	main
olulised	doc_836620486414_item	2901802	et	4	main
mehel	doc_836620486414_item	2901804	et	3	main
habe	doc_836620486414_item	2901814	et	3	main
elustiilist	doc_836620486415_item	2901818	et	4	main
inimese	doc_836620486415_item	2901819	et	4	main
ainult	doc_836620486410_item	2901329	et	4	main
me	doc_836620486410_item	2901334	et	4	main
rohkem	doc_836620486410_item	2901357	et	4	main
me	doc_836620486410_item	2901361	et	4	main
astele	doc_836620486410_item	2901367	et	4	main
arvan	doc_836620486410_item	2901369	et	3	main
mõtlemine	doc_836620486410_item	2901371	et	4	main
on	doc_836620486410_item	2901372	et	4	main
ka	doc_836620486410_item	2901373	et	3	main
mitte	doc_836620486410_item	2901374	et	3	main
eriti	doc_836620486410_item	2901375	et	3	main
mõtlemisest	doc_836620486410_item	2901378	et	4	main
ei	doc_836620486410_item	2901379	et	4	main
ei	doc_836620486410_item	2901384	et	4	main
mis	doc_836620486410_item	2901386	et	4	main
võib	doc_836620486410_item	2901387	et	3	main
juhtuda	doc_836620486410_item	2901388	et	3	main
homme	doc_836620486410_item	2901389	et	3	main
või	doc_836620486410_item	2901390	et	4	main
ülehomme	doc_836620486410_item	2901391	et	3	main
iga	doc_836620486410_item	2901397	et	4	main
päev	doc_836620486410_item	2901398	et	3	main
ja	doc_836620486410_item	2901403	et	3	main
tegutsemine	doc_836620486410_item	2901409	et	4	main
meditsini	doc_836620486411_item	2901414	et	3	main
areng	doc_836620486411_item	2901415	et	3	main
muidugi	doc_836620486411_item	2901416	et	4	main
see	doc_836620486411_item	2901417	et	3	main
on	doc_836620486411_item	2901418	et	4	main
väga	doc_836620486411_item	2901419	et	3	main
oluline	doc_836620486411_item	2901420	et	4	main
elu	doc_836620486411_item	2901430	et	4	main
sõltub	doc_836620486411_item	2901431	et	3	main
perekond	doc_836620486411_item	2901434	et	3	main
see	doc_836620486411_item	2901435	et	3	main
ka	doc_836620486411_item	2901437	et	3	main
oluline	doc_836620486411_item	2901439	et	4	main
on	doc_836620486411_item	2901453	et	4	main
pühabr	doc_836620486411_item	2901454	et	4	main
haridustase	doc_836620486411_item	2901455	et	3	main
haridustase	doc_836620486411_item	2901456	et	3	main
oluline	doc_836620486411_item	2901459	et	4	main
ebaoluline	doc_836620486411_item	2901494	et	4	main
kui	doc_836620486411_item	2901495	et	3	main
inimesel	doc_836620486411_item	2901496	et	3	main
oli	doc_836620486411_item	2901497	et	3	main
töökoht	doc_836620486411_item	2901501	et	3	main
ta	doc_836620486411_item	2901505	et	4	main
oli	doc_836620486411_item	2901506	et	3	main
õnnelik	doc_836620486411_item	2901507	et	3	main
on	doc_836620486411_item	2901517	et	4	main
niisamuti	doc_836620486411_item	2901518	et	3	main
õnnelik	doc_836620486411_item	2901519	et	3	main
suhted	doc_836620486411_item	2901520	et	3	main
on	doc_836620486411_item	2901524	et	4	main
et	doc_836620486411_item	2901527	et	3	main
inimesel	doc_836620486411_item	2901528	et	3	main
võivad	doc_836620486411_item	2901530	et	4	main
olla	doc_836620486411_item	2901531	et	3	main
tõsiseltbr	doc_836620486411_item	2901539	et	4	main
poliitiline	doc_836620486411_item	2901540	et	3	main
olukord	doc_836620486411_item	2901541	et	3	main
ma	doc_836620486411_item	2901542	et	3	main
arvan	doc_836620486411_item	2901543	et	3	main
et	doc_836620486411_item	2901544	et	3	main
see	doc_836620486411_item	2901545	et	3	main
sai	doc_836620486411_item	2901551	et	4	main
mitte	doc_836620486411_item	2901554	et	3	main
midagi	doc_836620486411_item	2901555	et	4	main
et	doc_836620486411_item	2901558	et	3	main
ei	doc_836620486411_item	2901560	et	4	main
kaebus	doc_836620486412_item	2901565	et	3	main
selver	doc_836620486412_item	2901567	et	4	main
detsembril	doc_836620486412_item	2901572	et	3	main
a	doc_836620486412_item	2901574	et	4	main
riigis	doc_836620486410_item	2901343	et	3	main
on	doc_836620486410_item	2901344	et	4	main
halb	doc_836620486410_item	2901345	et	3	main
see	doc_836620486410_item	2901346	et	3	main
inimesed	doc_836620486410_item	2901351	et	3	main
raamatuid	doc_836620486410_item	2901358	et	3	main
ise	doc_836620486410_item	2901362	et	4	main
elu	doc_836620486410_item	2901393	et	4	main
kõik	doc_836620486410_item	2901399	et	4	main
muutub	doc_836620486410_item	2901400	et	3	main
meie	doc_836620486410_item	2901401	et	4	main
kõige	doc_836620486410_item	2901404	et	4	main
p	doc_836620486410_item	2901410	et	4	main
mis	doc_836620486411_item	2901411	et	4	main
mõjutab	doc_836620486411_item	2901412	et	3	main
eluiga	doc_836620486411_item	2901413	et	4	main
sest	doc_836620486411_item	2901421	et	4	main
elu	doc_836620486411_item	2901427	et	4	main
pikkem	doc_836620486411_item	2901428	et	4	main
meie	doc_836620486411_item	2901429	et	4	main
need	doc_836620486411_item	2901442	et	3	main
inimesed	doc_836620486411_item	2901443	et	3	main
meie	doc_836620486411_item	2901445	et	4	main
me	doc_836620486411_item	2901448	et	4	main
armastame	doc_836620486411_item	2901449	et	3	main
väga	doc_836620486411_item	2901458	et	3	main
hea	doc_836620486411_item	2901498	et	4	main
armsam	doc_836620486411_item	2901502	et	4	main
sest	doc_836620486411_item	2901514	et	4	main
et	doc_836620486411_item	2901515	et	3	main
erinevad	doc_836620486411_item	2901532	et	4	main
suhted	doc_836620486411_item	2901533	et	3	main
aga	doc_836620486411_item	2901534	et	3	main
on	doc_836620486411_item	2901546	et	4	main
ma	doc_836620486411_item	2901556	et	3	main
poliitika	doc_836620486411_item	2901559	et	4	main
tee	doc_836620486411_item	2901561	et	4	main
meie	doc_836620486411_item	2901562	et	4	main
tagasi	doc_836620486412_item	2901570	et	3	main
teie	doc_836620486412_item	2901576	et	4	main
villane	doc_836620486412_item	2901586	et	4	main
220	doc_836620486412_item	2901589	et	2	main
raha	doc_836620486412_item	2901622	et	4	main
krooni	doc_836620486412_item	2901624	et	4	main
12	doc_836620486412_item	2901626	et	2	main
a	doc_836620486412_item	2901628	et	4	main
vastus	doc_836620486413_item	2901629	et	3	main
xxxxxx	doc_836620486413_item	2901632	et	4	main
eesnimi	doc_836620486413_item	2901635	et	3	main
as	doc_836620486413_item	2901637	et	4	main
peep	doc_836620486413_item	2901643	et	4	main
teile	doc_836620486413_item	2901652	et	4	main
te	doc_836620486413_item	2901655	et	4	main
ei	doc_836620486413_item	2901656	et	4	main
oskust	doc_836620486413_item	2901667	et	3	main
kui	doc_836620486413_item	2901668	et	3	main
keelt	doc_836620486413_item	2901672	et	4	main
see	doc_836620486413_item	2901673	et	3	main
järgmisel	doc_836620486413_item	2901675	et	3	main
2003	doc_836620486413_item	2901685	et	2	main
seletuskiri	doc_836620486414_item	2901687	et	3	main
1983	doc_836620486414_item	2901698	et	2	main
kasei	doc_836620486414_item	2901703	et	4	main
täpne	doc_836620486414_item	2901706	et	3	main
2003	doc_836620486414_item	2901710	et	2	main
üksi	doc_836620486414_item	2901729	et	4	main
ja	doc_836620486414_item	2901730	et	3	main
ümber	doc_836620486414_item	2901744	et	3	main
nägin	doc_836620486414_item	2901746	et	3	main
ja	doc_836620486414_item	2901750	et	3	main
hakkasin	doc_836620486414_item	2901789	et	3	main
naine	doc_836620486414_item	2901791	et	3	main
mind	doc_836620486414_item	2901793	et	4	main
ja	doc_836620486414_item	2901794	et	3	main
kutsus	doc_836620486414_item	2901795	et	4	main
ära	doc_836620486414_item	2901801	et	4	main
oli	doc_836620486414_item	2901805	et	3	main
mustad	doc_836620486414_item	2901809	et	4	main
oli	doc_836620486414_item	2901813	et	3	main
sõltub	doc_836620486415_item	2901817	et	3	main
elustiilist	doc_836620486415_item	2901822	et	4	main
rääkida	doc_836620486415_item	2901826	et	3	main
elustiil	doc_836620486415_item	2901836	et	4	main
ainult	doc_836620486411_item	2901423	et	4	main
meie	doc_836620486411_item	2901426	et	4	main
väga	doc_836620486411_item	2901438	et	3	main
ja	doc_836620486411_item	2901447	et	3	main
neid	doc_836620486411_item	2901450	et	4	main
perekond	doc_836620486411_item	2901451	et	3	main
see	doc_836620486411_item	2901452	et	3	main
on	doc_836620486411_item	2901464	et	4	main
hea	doc_836620486411_item	2901465	et	4	main
amet	doc_836620486411_item	2901466	et	3	main
ja	doc_836620486411_item	2901467	et	3	main
hea	doc_836620486411_item	2901468	et	4	main
palk	doc_836620486411_item	2901469	et	3	main
haridustase	doc_836620486411_item	2901470	et	3	main
see	doc_836620486411_item	2901471	et	3	main
on	doc_836620486411_item	2901472	et	4	main
palju	doc_836620486411_item	2901473	et	4	main
võimalusi	doc_836620486411_item	2901474	et	3	main
toitumine	doc_836620486411_item	2901475	et	4	main
see	doc_836620486411_item	2901476	et	3	main
on	doc_836620486411_item	2901477	et	4	main
ka	doc_836620486411_item	2901478	et	3	main
oluline	doc_836620486411_item	2901479	et	4	main
õige	doc_836620486411_item	2901480	et	4	main
ja	doc_836620486411_item	2901481	et	3	main
tervislik	doc_836620486411_item	2901482	et	3	main
inimesel	doc_836620486411_item	2901463	et	3	main
meeleolu	doc_836620486411_item	2901485	et	4	main
tervis	doc_836620486411_item	2901499	et	3	main
jõukus	doc_836620486411_item	2901509	et	4	main
ei	doc_836620486411_item	2901511	et	4	main
ebaoluline	doc_836620486411_item	2901547	et	4	main
kuigi	doc_836620486411_item	2901548	et	3	main
ma	doc_836620486411_item	2901549	et	3	main
ei	doc_836620486411_item	2901550	et	4	main
mõtlen	doc_836620486411_item	2901557	et	3	main
5	doc_836620486412_item	2901568	et	2	main
10	doc_836620486412_item	2901571	et	2	main
ostsin	doc_836620486412_item	2901575	et	3	main
poest	doc_836620486412_item	2901577	et	4	main
mis	doc_836620486412_item	2901578	et	4	main
asub	doc_836620486412_item	2901579	et	3	main
riieteosakonnast	doc_836620486412_item	2901583	et	4	main
maksis	doc_836620486412_item	2901588	et	4	main
pärnu	doc_836620486413_item	2901638	et	4	main
mnt	doc_836620486413_item	2901639	et	4	main
10	doc_836620486413_item	2901644	et	2	main
pääsenud	doc_836620486413_item	2901657	et	4	main
konkursil	doc_836620486413_item	2901658	et	3	main
ei	doc_836620486413_item	2901663	et	4	main
tulla	doc_836620486413_item	2901679	et	3	main
firmasse	doc_836620486413_item	2901681	et	3	main
töötama	doc_836620486413_item	2901682	et	3	main
12	doc_836620486413_item	2901684	et	2	main
sündinud	doc_836620486414_item	2901695	et	4	main
a	doc_836620486414_item	2901699	et	4	main
aadress	doc_836620486414_item	2901701	et	3	main
see	doc_836620486414_item	2901722	et	3	main
keegi	doc_836620486414_item	2901732	et	4	main
ei	doc_836620486414_item	2901733	et	4	main
pöörasin	doc_836620486414_item	2901743	et	3	main
meest	doc_836620486414_item	2901747	et	4	main
nahajopis	doc_836620486414_item	2901749	et	3	main
püksides	doc_836620486414_item	2901752	et	3	main
märkis	doc_836620486414_item	2901754	et	3	main
et	doc_836620486414_item	2901755	et	3	main
ma	doc_836620486414_item	2901756	et	3	main
pööran	doc_836620486414_item	2901757	et	3	main
selle	doc_836620486414_item	2901758	et	4	main
ja	doc_836620486414_item	2901799	et	3	main
tume	doc_836620486414_item	2901806	et	3	main
ja	doc_836620486414_item	2901811	et	3	main
inimese	doc_836620486415_item	2901815	et	4	main
inimese	doc_836620486415_item	2901842	et	4	main
vaba	doc_836620486415_item	2901847	et	4	main
mõtlemist	doc_836620486415_item	2901852	et	4	main
inimene	doc_836620486415_item	2901855	et	3	main
olema	doc_836620486415_item	2901857	et	4	main
et	doc_836620486415_item	2901859	et	3	main
on	doc_836620486415_item	2901861	et	4	main
kogu	doc_836620486415_item	2901866	et	4	main
aeg	doc_836620486415_item	2901867	et	3	main
tulevik	doc_836620486415_item	2901874	et	3	main
seadusi	doc_836620486415_item	2901886	et	3	main
järgida	doc_836620486415_item	2901891	et	3	main
mõista	doc_836620486415_item	2901893	et	4	main
igaüks	doc_836620486415_item	2901895	et	3	main
peab	doc_836620486415_item	2901896	et	4	main
kindel	doc_836620486415_item	2901905	et	3	main
see	doc_836620486415_item	2901922	et	3	main
toitumine	doc_836620486411_item	2901483	et	4	main
ja	doc_836620486411_item	2901486	et	3	main
jõukus	doc_836620486411_item	2901488	et	4	main
ma	doc_836620486411_item	2901489	et	3	main
mõtlen	doc_836620486411_item	2901490	et	3	main
et	doc_836620486411_item	2901491	et	3	main
see	doc_836620486411_item	2901492	et	3	main
on	doc_836620486411_item	2901493	et	4	main
hea	doc_836620486411_item	2901500	et	4	main
pere	doc_836620486411_item	2901503	et	4	main
sest	doc_836620486411_item	2901504	et	4	main
temale	doc_836620486411_item	2901510	et	3	main
ta	doc_836620486411_item	2901516	et	4	main
see	doc_836620486411_item	2901523	et	3	main
teiste	doc_836620486411_item	2901521	et	4	main
ebaoluline	doc_836620486411_item	2901525	et	4	main
sellepärast	doc_836620486411_item	2901526	et	3	main
tööl	doc_836620486411_item	2901529	et	3	main
pea	doc_836620486411_item	2901537	et	4	main
võtma	doc_836620486411_item	2901538	et	3	main
selle	doc_836620486411_item	2901553	et	4	main
parem	doc_836620486411_item	2901564	et	4	main
2003	doc_836620486412_item	2901573	et	2	main
pärnu	doc_836620486412_item	2901580	et	4	main
mnt	doc_836620486412_item	2901581	et	4	main
238a	doc_836620486412_item	2901582	et	4	main
krooni	doc_836620486412_item	2901590	et	4	main
kandsin	doc_836620486412_item	2901591	et	3	main
mütsi	doc_836620486412_item	2901592	et	4	main
4	doc_836620486412_item	2901593	et	2	main
päeva	doc_836620486412_item	2901594	et	4	main
õues	doc_836620486412_item	2901595	et	4	main
oli	doc_836620486412_item	2901596	et	3	main
vihm	doc_836620486412_item	2901597	et	3	main
ja	doc_836620486412_item	2901598	et	3	main
müts	doc_836620486412_item	2901599	et	4	main
sai	doc_836620486412_item	2901600	et	4	main
märjaks	doc_836620486412_item	2901601	et	3	main
kui	doc_836620486412_item	2901602	et	3	main
müts	doc_836620486412_item	2901603	et	4	main
kuivas	doc_836620486412_item	2901604	et	4	main
ära	doc_836620486412_item	2901605	et	4	main
nägin	doc_836620486412_item	2901606	et	3	main
et	doc_836620486412_item	2901607	et	3	main
müts	doc_836620486412_item	2901608	et	4	main
muutus	doc_836620486412_item	2901609	et	4	main
värvi	doc_836620486412_item	2901610	et	4	main
ta	doc_836620486412_item	2901611	et	4	main
halliks	doc_836620486412_item	2901613	et	4	main
sai	doc_836620486412_item	2901612	et	4	main
ja	doc_836620486412_item	2901614	et	3	main
tõmbas	doc_836620486412_item	2901615	et	3	main
kokku	doc_836620486412_item	2901616	et	3	main
tahaksin	doc_836620486412_item	2901617	et	3	main
et	doc_836620486412_item	2901618	et	3	main
te	doc_836620486412_item	2901619	et	4	main
tagastaksite	doc_836620486412_item	2901620	et	3	main
mütsi	doc_836620486412_item	2901585	et	4	main
müts	doc_836620486412_item	2901587	et	4	main
mulle	doc_836620486412_item	2901621	et	4	main
osalenule	doc_836620486413_item	2901631	et	4	main
pärnu	doc_836620486413_item	2901636	et	4	main
2003	doc_836620486413_item	2901646	et	2	main
te	doc_836620486413_item	2901647	et	4	main
töökonkursil	doc_836620486413_item	2901649	et	3	main
tahan	doc_836620486413_item	2901651	et	3	main
ütelda	doc_836620486413_item	2901653	et	4	main
et	doc_836620486413_item	2901654	et	3	main
saate	doc_836620486413_item	2901678	et	4	main
05	doc_836620486414_item	2901697	et	2	main
toimumisaeg	doc_836620486414_item	2901707	et	3	main
umbes	doc_836620486414_item	2901711	et	4	main
tänaval	doc_836620486414_item	2901721	et	4	main
umbes	doc_836620486414_item	2901724	et	4	main
1900	doc_836620486414_item	2901726	et	2	main
ma	doc_836620486414_item	2901742	et	3	main
musta	doc_836620486414_item	2901748	et	4	main
mustades	doc_836620486414_item	2901751	et	3	main
ta	doc_836620486414_item	2901753	et	4	main
ta	doc_836620486414_item	2901760	et	4	main
jooksis	doc_836620486414_item	2901761	et	4	main
juurde	doc_836620486414_item	2901763	et	4	main
kui	doc_836620486414_item	2901787	et	3	main
rööviha	doc_836620486414_item	2901797	et	4	main
detailid	doc_836620486414_item	2901803	et	3	main
müts	doc_836620486414_item	2901808	et	4	main
tal	doc_836620486414_item	2901812	et	3	main
tervis	doc_836620486415_item	2901816	et	3	main
p	doc_836620486415_item	2901823	et	4	main
selleks	doc_836620486415_item	2901824	et	4	main
et	doc_836620486415_item	2901825	et	3	main
sellel	doc_836620486415_item	2901827	et	4	main
teemal	doc_836620486415_item	2901828	et	3	main
tuleb	doc_836620486415_item	2901829	et	3	main
kõigepealt	doc_836620486415_item	2901830	et	3	main
otsustada	doc_836620486415_item	2901831	et	3	main
arvates	doc_836620486415_item	2901839	et	4	main
see	doc_836620486415_item	2901840	et	3	main
tähendab	doc_836620486415_item	2901841	et	3	main
iga	doc_836620486415_item	2901854	et	4	main
peab	doc_836620486415_item	2901856	et	4	main
teadlik	doc_836620486415_item	2901858	et	3	main
loodusest	doc_836620486415_item	2901864	et	4	main
ja	doc_836620486415_item	2901869	et	3	main
sõltub	doc_836620486415_item	2901872	et	3	main
tahab	doc_836620486415_item	2901877	et	3	main
edukalt	doc_836620486415_item	2901879	et	4	main
ta	doc_836620486415_item	2901880	et	4	main
mitte	doc_836620486415_item	2901887	et	3	main
õnnelikult	doc_836620486415_item	2901901	et	4	main
kui	doc_836620486415_item	2901902	et	3	main
on	doc_836620486415_item	2901923	et	4	main
toiduga	doc_836620486415_item	2901928	et	3	main
peaksime	doc_836620486415_item	2901929	et	4	main
süsivesikud	doc_836620486415_item	2901936	et	3	main
mineraalained	doc_836620486415_item	2901938	et	3	main
tähelepanelik	doc_836620486415_item	2901951	et	4	main
siis	doc_836620486415_item	2901952	et	3	main
peab	doc_836620486415_item	2901973	et	4	main
töötama	doc_836620486415_item	2901974	et	3	main
see	doc_836620486415_item	2901975	et	3	main
töö	doc_836620486415_item	2901979	et	4	main
saab	doc_836620486415_item	2901982	et	3	main
kui	doc_836620486415_item	2902000	et	3	main
nagu	doc_836620486415_item	2902004	et	3	main
et	doc_836620486415_item	2902018	et	3	main
on	doc_836620486415_item	2902027	et	4	main
kasulik	doc_836620486415_item	2902028	et	3	main
kõikidele	doc_836620486415_item	2902029	et	4	main
aja	doc_836620486415_item	2902035	et	4	main
veetmisest	doc_836620486415_item	2902036	et	4	main
tegevusi	doc_836620486415_item	2902040	et	4	main
et	doc_836620486415_item	2902044	et	3	main
auto	doc_842434202394_item	2902052	et	4	main
minu	doc_842434202394_item	2902053	et	3	main
ta	doc_842434202394_item	2902072	et	4	main
jäoks	doc_842434202394_item	2902075	et	4	main
mugavalt	doc_842434202394_item	2902077	et	4	main
oli	doc_842434202394_item	2902083	et	3	main
220	doc_836620486412_item	2901623	et	2	main
15	doc_836620486412_item	2901625	et	2	main
2003	doc_836620486412_item	2901627	et	2	main
118	doc_836620486413_item	2901640	et	2	main
b	doc_836620486413_item	2901641	et	4	main
05	doc_836620486413_item	2901645	et	2	main
mina	doc_836620486413_item	2901650	et	4	main
selle	doc_836620486413_item	2901659	et	4	main
te	doc_836620486413_item	2901669	et	4	main
õpite	doc_836620486413_item	2901670	et	3	main
saksa	doc_836620486413_item	2901671	et	4	main
aastal	doc_836620486413_item	2901676	et	3	main
nimi	doc_836620486414_item	2901689	et	3	main
eesnimi	doc_836620486414_item	2901691	et	3	main
perekonnanimi	doc_836620486414_item	2901692	et	3	main
olen	doc_836620486414_item	2901694	et	3	main
18	doc_836620486414_item	2901696	et	2	main
minu	doc_836620486414_item	2901700	et	3	main
on	doc_836620486414_item	2901702	et	4	main
11-44	doc_836620486414_item	2901704	et	2	main
sündmuse	doc_836620486414_item	2901705	et	3	main
10	doc_836620486414_item	2901708	et	2	main
kell	doc_836620486414_item	2901712	et	3	main
1900	doc_836620486414_item	2901713	et	2	main
läksin	doc_836620486414_item	2901715	et	3	main
töölt	doc_836620486414_item	2901716	et	3	main
koju	doc_836620486414_item	2901717	et	3	main
läbi	doc_836620486414_item	2901718	et	4	main
mina	doc_836620486414_item	2901714	et	4	main
vanalinna	doc_836620486414_item	2901719	et	4	main
pika	doc_836620486414_item	2901720	et	4	main
tänaval	doc_836620486414_item	2901731	et	4	main
taga	doc_836620486414_item	2901740	et	4	main
kui	doc_836620486414_item	2901741	et	3	main
ja	doc_836620486414_item	2901764	et	3	main
püüdis	doc_836620486414_item	2901765	et	3	main
oma	doc_836620486414_item	2901766	et	4	main
kotti	doc_836620486414_item	2901767	et	4	main
käest	doc_836620486414_item	2901768	et	4	main
ära	doc_836620486414_item	2901769	et	4	main
võtta	doc_836620486414_item	2901770	et	3	main
ma	doc_836620486414_item	2901771	et	3	main
hakkasin	doc_836620486414_item	2901772	et	3	main
kaklema	doc_836620486414_item	2901773	et	3	main
temaga	doc_836620486414_item	2901774	et	3	main
aga	doc_836620486414_item	2901775	et	3	main
ta	doc_836620486414_item	2901776	et	4	main
oli	doc_836620486414_item	2901777	et	3	main
väga	doc_836620486414_item	2901778	et	3	main
tugev	doc_836620486414_item	2901779	et	4	main
üks	doc_836620486414_item	2901780	et	3	main
naine	doc_836620486414_item	2901781	et	3	main
läks	doc_836620486414_item	2901782	et	3	main
kaugel	doc_836620486414_item	2901783	et	4	main
minu	doc_836620486414_item	2901784	et	3	main
ja	doc_836620486414_item	2901786	et	3	main
ees	doc_836620486414_item	2901785	et	4	main
politseid	doc_836620486414_item	2901796	et	4	main
sinine	doc_836620486414_item	2901807	et	4	main
prillid	doc_836620486414_item	2901810	et	3	main
tervis	doc_836620486415_item	2901820	et	3	main
mida	doc_836620486415_item	2901832	et	4	main
me	doc_836620486415_item	2901833	et	4	main
mõistame	doc_836620486415_item	2901834	et	3	main
sõna	doc_836620486415_item	2901835	et	4	main
toitumist	doc_836620486415_item	2901844	et	4	main
aja	doc_836620486415_item	2901848	et	4	main
arutleme	doc_836620486415_item	2901851	et	3	main
väike	doc_836620486415_item	2901862	et	4	main
areneb	doc_836620486415_item	2901868	et	3	main
maailma	doc_836620486415_item	2901873	et	4	main
kui	doc_836620486415_item	2901875	et	3	main
rikkuda	doc_836620486415_item	2901888	et	3	main
aga	doc_836620486415_item	2901890	et	3	main
et	doc_836620486415_item	2901894	et	3	main
inimene	doc_836620486415_item	2901903	et	3	main
on	doc_836620486415_item	2901904	et	4	main
tähendab	doc_836620486415_item	2901921	et	3	main
toitumine	doc_836620486415_item	2901927	et	4	main
täisväärtusliku	doc_836620486415_item	2901933	et	3	main
iseenast	doc_836620486415_item	2901956	et	4	main
on	doc_836620486415_item	2901964	et	4	main
aga	doc_836620486415_item	2901966	et	3	main
eest	doc_836620486415_item	2901991	et	4	main
mailmas	doc_836620486415_item	2901999	et	4	main
räägime	doc_836620486415_item	2902002	et	3	main
tegurist	doc_836620486415_item	2902006	et	4	main
inimesele	doc_836620486415_item	2902015	et	3	main
loominguline	doc_836620486415_item	2902021	et	4	main
annab	doc_836620486415_item	2902023	et	3	main
head	doc_836620486415_item	2902024	et	4	main
inimestelebr	doc_836620486415_item	2902030	et	4	main
neljandaks	doc_836620486415_item	2902031	et	4	main
tasub	doc_836620486415_item	2902032	et	3	main
mainida	doc_836620486415_item	2902033	et	3	main
on	doc_836620486415_item	2902038	et	4	main
küsimusele	doc_842434202394_item	2902049	et	4	main
minu	doc_842434202394_item	2902074	et	3	main
ma	doc_842434202394_item	2902079	et	3	main
autoses	doc_842434202394_item	2902082	et	4	main
mind	doc_842434202394_item	2902094	et	4	main
väga	doc_842434202394_item	2902095	et	3	main
meeldib	doc_842434202394_item	2902096	et	3	main
arvan	doc_842434202394_item	2902106	et	3	main
auto	doc_842434202394_item	2902109	et	4	main
ka	doc_842434202394_item	2902111	et	3	main
jaoks	doc_842434202394_item	2902114	et	4	main
sõltub	doc_836620486415_item	2901821	et	3	main
mõtlemist	doc_836620486415_item	2901843	et	4	main
veetmist	doc_836620486415_item	2901849	et	4	main
tingimata	doc_836620486415_item	2901853	et	4	main
osa	doc_836620486415_item	2901863	et	4	main
inimesest	doc_836620486415_item	2901871	et	3	main
looduse	doc_836620486415_item	2901884	et	4	main
arengu	doc_836620486415_item	2901885	et	3	main
neid	doc_836620486415_item	2901889	et	4	main
tasub	doc_836620486415_item	2901892	et	3	main
olema	doc_836620486415_item	2901897	et	4	main
mõtes	doc_836620486415_item	2901907	et	4	main
siis	doc_836620486415_item	2901908	et	3	main
ta	doc_836620486415_item	2901909	et	4	main
kindlasti	doc_836620486415_item	2901910	et	3	main
mõtleb	doc_836620486415_item	2901911	et	3	main
tervislikust	doc_836620486415_item	2901912	et	4	main
toitumist	doc_836620486415_item	2901913	et	4	main
see	doc_836620486415_item	2901914	et	3	main
on	doc_836620486415_item	2901915	et	4	main
teine	doc_836620486415_item	2901916	et	3	main
tegur	doc_836620486415_item	2901917	et	3	main
elustiilis	doc_836620486415_item	2901918	et	3	main
mida	doc_836620486415_item	2901919	et	4	main
see	doc_836620486415_item	2901920	et	3	main
mitmekesine	doc_836620486415_item	2901924	et	4	main
ja	doc_836620486415_item	2901925	et	3	main
regulaarne	doc_836620486415_item	2901926	et	3	main
kõik	doc_836620486415_item	2901932	et	4	main
rasvad	doc_836620486415_item	2901935	et	4	main
tasub	doc_836620486415_item	2901940	et	3	main
aga	doc_836620486415_item	2901942	et	3	main
kuulata	doc_836620486415_item	2901955	et	4	main
saada	doc_836620486415_item	2901958	et	4	main
oma	doc_836620486415_item	2901959	et	4	main
aru	doc_836620486415_item	2901962	et	4	main
raske	doc_836620486415_item	2901965	et	4	main
on	doc_836620486415_item	2901967	et	4	main
kolmandaks	doc_836620486415_item	2901969	et	4	main
räägime	doc_836620486415_item	2901970	et	3	main
töötamisest	doc_836620486415_item	2901971	et	4	main
inimene	doc_836620486415_item	2901972	et	3	main
inimene	doc_836620486415_item	2901981	et	3	main
maksta	doc_836620486415_item	2901992	et	4	main
õppida	doc_836620486415_item	2901993	et	3	main
reisida	doc_836620486415_item	2901994	et	3	main
jne	doc_836620486415_item	2901995	et	4	main
ühesõnaga	doc_836620486415_item	2901996	et	3	main
elada	doc_836620486415_item	2901997	et	3	main
me	doc_836620486415_item	2902001	et	4	main
elustiilist	doc_836620486415_item	2902003	et	4	main
tervise	doc_836620486415_item	2902005	et	3	main
siis	doc_836620486415_item	2902007	et	3	main
on	doc_836620486415_item	2902008	et	4	main
hädavajalik	doc_836620486415_item	2902009	et	3	main
rõhutada	doc_836620486415_item	2902010	et	3	main
et	doc_836620486415_item	2902011	et	3	main
töö	doc_836620486415_item	2902022	et	4	main
tulemust	doc_836620486415_item	2902025	et	4	main
ja	doc_836620486415_item	2902026	et	3	main
vaba	doc_836620486415_item	2902034	et	4	main
palju-palju	doc_836620486415_item	2902039	et	4	main
võib	doc_836620486415_item	2902042	et	3	main
tugevdada	doc_836620486415_item	2902045	et	3	main
tervist	doc_836620486415_item	2902047	et	4	main
vastus	doc_842434202394_item	2902048	et	3	main
on	doc_842434202394_item	2902056	et	4	main
all	doc_836620486415_item	2901837	et	3	main
minu	doc_836620486415_item	2901838	et	3	main
töötamist	doc_836620486415_item	2901845	et	4	main
ja	doc_836620486415_item	2901846	et	3	main
alguses	doc_836620486415_item	2901850	et	4	main
ta	doc_836620486415_item	2901860	et	4	main
mis	doc_836620486415_item	2901865	et	4	main
igast	doc_836620486415_item	2901870	et	3	main
inimene	doc_836620486415_item	2901876	et	3	main
elada	doc_836620486415_item	2901878	et	3	main
peab	doc_836620486415_item	2901881	et	4	main
kõigepealt	doc_836620486415_item	2901882	et	3	main
tunnetama	doc_836620486415_item	2901883	et	3	main
terve	doc_836620486415_item	2901898	et	4	main
et	doc_836620486415_item	2901899	et	3	main
elada	doc_836620486415_item	2901900	et	3	main
selles	doc_836620486415_item	2901906	et	4	main
ikka	doc_836620486415_item	2901930	et	4	main
valgud	doc_836620486415_item	2901934	et	4	main
eelistada	doc_836620486415_item	2901939	et	3	main
taimetoitu	doc_836620486415_item	2901941	et	4	main
ikkagi	doc_836620486415_item	2901943	et	4	main
see	doc_836620486415_item	2901944	et	3	main
on	doc_836620486415_item	2901945	et	4	main
individuaalne	doc_836620486415_item	2901946	et	3	main
ja	doc_836620486415_item	2901947	et	3	main
kui	doc_836620486415_item	2901948	et	3	main
inimene	doc_836620486415_item	2901949	et	3	main
on	doc_836620486415_item	2901950	et	4	main
ta	doc_836620486415_item	2901953	et	4	main
ja	doc_836620486415_item	2901957	et	3	main
organismi	doc_836620486415_item	2901960	et	4	main
see	doc_836620486415_item	2901963	et	3	main
võimalik	doc_836620486415_item	2901968	et	3	main
maine	doc_836620486415_item	2901977	et	4	main
seadus	doc_836620486415_item	2901978	et	4	main
raha	doc_836620486415_item	2901983	et	4	main
abil	doc_836620486415_item	2901985	et	4	main
ta	doc_836620486415_item	2901986	et	4	main
võib	doc_836620486415_item	2901987	et	3	main
toituda	doc_836620486415_item	2901988	et	3	main
riietuda	doc_836620486415_item	2901989	et	3	main
korteri	doc_836620486415_item	2901990	et	3	main
töötamine	doc_836620486415_item	2902012	et	4	main
rõõmu	doc_836620486415_item	2902016	et	4	main
teatavasti	doc_836620486415_item	2902017	et	3	main
saama	doc_836620486415_item	2901931	et	4	main
vitamiinid	doc_836620486415_item	2901937	et	3	main
oskab	doc_836620486415_item	2901954	et	3	main
vajadust	doc_836620486415_item	2901961	et	4	main
on	doc_836620486415_item	2901976	et	4	main
eest	doc_836620486415_item	2901980	et	4	main
mille	doc_836620486415_item	2901984	et	3	main
kaasaegses	doc_836620486415_item	2901998	et	3	main
peab	doc_836620486415_item	2902013	et	4	main
tooma	doc_836620486415_item	2902014	et	3	main
huvitav	doc_836620486415_item	2902019	et	4	main
põnev	doc_836620486415_item	2902020	et	3	main
siin	doc_836620486415_item	2902037	et	4	main
mis	doc_836620486415_item	2902041	et	4	main
unistus	doc_842434202394_item	2902054	et	4	main
see	doc_842434202394_item	2902055	et	3	main
kiirus	doc_842434202394_item	2902087	et	4	main
millal	doc_842434202394_item	2902103	et	3	main
harjutus	doc_842434202398_item	2902443	et	4	main
kui	doc_842434202398_item	2902446	et	3	main
t	doc_842434202398_item	2902450	et	4	main
olid	doc_842434202398_item	2902487	et	4	main
ajanud	doc_842434202398_item	2902497	et	4	main
teda	doc_842434202398_item	2902498	et	4	main
üles	doc_842434202398_item	2902499	et	3	main
jätta	doc_842434202399_item	2902509	et	3	main
sellepärast	doc_842434202399_item	2902510	et	3	main
et	doc_842434202399_item	2902511	et	3	main
vihm	doc_842434202399_item	2902512	et	3	main
on	doc_842434202399_item	2902514	et	4	main
vesi	doc_842434202399_item	2902517	et	4	main
pakuda	doc_836620486415_item	2902043	et	4	main
oma	doc_836620486415_item	2902046	et	4	main
minu	doc_842434202394_item	2902050	et	3	main
unistuste	doc_842434202394_item	2902051	et	4	main
auto	doc_842434202394_item	2902057	et	4	main
valge	doc_842434202394_item	2902058	et	4	main
värvus	doc_842434202394_item	2902059	et	4	main
mulle	doc_842434202394_item	2902060	et	4	main
väga	doc_842434202394_item	2902061	et	3	main
meeldib	doc_842434202394_item	2902062	et	3	main
audi	doc_842434202394_item	2902063	et	3	main
eriti	doc_842434202394_item	2902064	et	3	main
audi	doc_842434202394_item	2902065	et	3	main
ac	doc_842434202394_item	2902066	et	4	main
temal	doc_842434202394_item	2902067	et	3	main
on	doc_842434202394_item	2902068	et	4	main
palju	doc_842434202394_item	2902069	et	4	main
koht	doc_842434202394_item	2902070	et	3	main
ja	doc_842434202394_item	2902071	et	3	main
on	doc_842434202394_item	2902073	et	4	main
tahan	doc_842434202394_item	2902080	et	3	main
katuseluuk	doc_842434202394_item	2902084	et	3	main
auto	doc_842434202394_item	2902090	et	4	main
mis	doc_842434202394_item	2902093	et	4	main
väga	doc_842434202394_item	2902100	et	3	main
ilus	doc_842434202394_item	2902101	et	4	main
eriti	doc_842434202394_item	2902102	et	3	main
väga	doc_842434202394_item	2902076	et	3	main
eriti	doc_842434202394_item	2902078	et	3	main
sest	doc_842434202394_item	2902081	et	4	main
armastan	doc_842434202394_item	2902086	et	3	main
aga	doc_842434202394_item	2902088	et	3	main
see	doc_842434202394_item	2902097	et	3	main
sõitab	doc_842434202394_item	2902104	et	4	main
et	doc_842434202394_item	2902107	et	3	main
mugavalt	doc_842434202394_item	2902112	et	4	main
pere	doc_842434202394_item	2902113	et	4	main
ma	doc_842434202394_item	2902085	et	3	main
see	doc_842434202394_item	2902089	et	3	main
sõitab	doc_842434202394_item	2902091	et	4	main
kiiresti	doc_842434202394_item	2902092	et	3	main
auto	doc_842434202394_item	2902098	et	4	main
on	doc_842434202394_item	2902099	et	4	main
ma	doc_842434202394_item	2902105	et	3	main
see	doc_842434202394_item	2902108	et	3	main
on	doc_842434202394_item	2902110	et	4	main
teema	doc_842434202398_item	2902445	et	4	main
kõrvaltoas	doc_842434202398_item	2902477	et	4	main
norskamini	doc_842434202398_item	2902478	et	4	main
ja	doc_842434202398_item	2902479	et	3	main
hakkas	doc_842434202398_item	2902480	et	3	main
nabrimeest	doc_842434202398_item	2902494	et	4	main
kui	doc_842434202398_item	2902495	et	3	main
et	doc_842434202398_item	2902502	et	3	main
kätte	doc_842434202399_item	2902505	et	4	main
ei	doc_842434202399_item	2902506	et	4	main
see	doc_842434202399_item	2902513	et	3	main
vesi	doc_842434202399_item	2902515	et	4	main
aga	doc_842434202399_item	2902516	et	3	main
tuleb	doc_842434202399_item	2902520	et	3	main
laste	doc_842434202399_item	2902521	et	4	main
emal	doc_842434202399_item	2902523	et	3	main
hoida	doc_842434202399_item	2902524	et	3	main
võib	doc_842434202399_item	2902528	et	3	main
neid	doc_842434202399_item	2902529	et	4	main
travmeerida	doc_842434202399_item	2902530	et	4	main
aga	doc_842434202399_item	2902531	et	3	main
samuti	doc_842434202399_item	2902532	et	3	main
võib	doc_842434202399_item	2902533	et	3	main
tekkida	doc_842434202399_item	2902534	et	3	main
koormata	doc_842434202399_item	2902540	et	4	main
sellepärast	doc_842434202399_item	2902541	et	3	main
et	doc_842434202399_item	2902542	et	3	main
nad	doc_842434202399_item	2902543	et	3	main
sutades	doc_842434202399_item	2902548	et	4	main
peab	doc_842434202399_item	2902549	et	4	main
ja	doc_842434202399_item	2902552	et	3	main
see	doc_842434202399_item	2902557	et	3	main
ohutus	doc_842434202399_item	2902564	et	4	main
juhised	doc_842434202399_item	2902565	et	3	main
töötama	doc_842434202399_item	2902575	et	3	main
tööõnnetus	doc_842434202399_item	2902602	et	4	main
vaja	doc_842434202399_item	2902606	et	4	main
õõ	doc_842434202398_item	2902451	et	4	main
kartma	doc_842434202398_item	2902481	et	3	main
ja	doc_842434202398_item	2902482	et	3	main
kutsus	doc_842434202398_item	2902483	et	4	main
naabri	doc_842434202398_item	2902484	et	3	main
kui	doc_842434202398_item	2902485	et	3	main
nad	doc_842434202398_item	2902486	et	3	main
vaatanud	doc_842434202398_item	2902488	et	4	main
tuppase	doc_842434202398_item	2902489	et	4	main
tohi	doc_842434202399_item	2902507	et	4	main
elektrijuht	doc_842434202399_item	2902518	et	3	main
elektritööriista	doc_842434202399_item	2902536	et	4	main
õigesti	doc_842434202399_item	2902550	et	3	main
tolmukaitset	doc_842434202399_item	2902553	et	4	main
tervist	doc_842434202399_item	2902559	et	4	main
töötaja	doc_842434202399_item	2902561	et	4	main
alati	doc_842434202399_item	2902569	et	4	main
puhtana	doc_842434202399_item	2902570	et	3	main
sellepärast	doc_842434202399_item	2902571	et	3	main
et	doc_842434202399_item	2902572	et	3	main
tööriistaga	doc_842434202399_item	2902573	et	3	main
mingil	doc_842434202399_item	2902577	et	4	main
tohi	doc_842434202399_item	2902580	et	4	main
sellepärast	doc_842434202399_item	2902585	et	3	main
jälgida	doc_842434202399_item	2902592	et	3	main
ei	doc_842434202399_item	2902595	et	4	main
ohutus	doc_842434202399_item	2902621	et	4	main
tohi	doc_842434202400_item	2902627	et	4	main
elektritööriista	doc_842434202400_item	2902628	et	4	main
jätta	doc_842434202400_item	2902629	et	3	main
sellepärast	doc_842434202400_item	2902630	et	3	main
et	doc_842434202400_item	2902631	et	3	main
läbi	doc_842434202400_item	2902638	et	4	main
2	doc_842434202400_item	2902640	et	2	main
koormata	doc_842434202400_item	2902657	et	4	main
peab	doc_842434202400_item	2902672	et	4	main
õigesti	doc_842434202400_item	2902673	et	3	main
tööriista	doc_842434202400_item	2902685	et	4	main
puhtama	doc_842434202400_item	2902689	et	4	main
pärast	doc_842434202400_item	2902691	et	4	main
et	doc_842434202400_item	2902692	et	3	main
korras	doc_842434202400_item	2902693	et	4	main
6	doc_842434202400_item	2902698	et	2	main
ei	doc_842434202400_item	2902702	et	4	main
jälgida	doc_842434202400_item	2902721	et	3	main
tööriist	doc_842434202400_item	2902723	et	3	main
töötajat	doc_842434202400_item	2902730	et	4	main
vigastada	doc_842434202400_item	2902731	et	3	main
kasutada	doc_842434202400_item	2902735	et	3	main
lisaosi	doc_842434202400_item	2902738	et	4	main
sellepärast	doc_842434202400_item	2902739	et	3	main
neljateistkümnes	doc_842434202398_item	2902444	et	4	main
härra	doc_842434202398_item	2902447	et	4	main
oli	doc_842434202398_item	2902449	et	3	main
lõpetanud	doc_842434202398_item	2902452	et	4	main
sõitis	doc_842434202398_item	2902453	et	3	main
ta	doc_842434202398_item	2902454	et	4	main
koju	doc_842434202398_item	2902455	et	3	main
kui	doc_842434202398_item	2902456	et	3	main
oli	doc_842434202398_item	2902457	et	3	main
oli	doc_842434202398_item	2902475	et	3	main
siis	doc_842434202398_item	2902490	et	3	main
nägid	doc_842434202398_item	2902491	et	4	main
diivanil	doc_842434202398_item	2902492	et	3	main
magavad	doc_842434202398_item	2902493	et	4	main
naabrimees	doc_842434202398_item	2902500	et	4	main
ütles	doc_842434202398_item	2902501	et	3	main
elektritööriista	doc_842434202399_item	2902508	et	4	main
tööõnnetus	doc_842434202399_item	2902535	et	4	main
võivad	doc_842434202399_item	2902544	et	4	main
lõhkuda	doc_842434202399_item	2902545	et	3	main
töörista	doc_842434202399_item	2902546	et	4	main
kandma	doc_842434202399_item	2902554	et	3	main
peab	doc_842434202399_item	2902562	et	4	main
meeldiv	doc_842434202399_item	2902574	et	4	main
võib	doc_842434202399_item	2902587	et	3	main
elektrilöök	doc_842434202399_item	2902589	et	3	main
tööriist	doc_842434202399_item	2902594	et	3	main
käivituks	doc_842434202399_item	2902596	et	3	main
jaoks	doc_842434202399_item	2902604	et	4	main
harjutus	doc_842434202400_item	2902622	et	4	main
vihma	doc_842434202400_item	2902624	et	4	main
ei	doc_842434202400_item	2902626	et	4	main
eest	doc_842434202400_item	2902644	et	4	main
eemal	doc_842434202400_item	2902645	et	3	main
x	doc_842434202398_item	2902448	et	4	main
lahti	doc_842434202398_item	2902458	et	4	main
ust	doc_842434202398_item	2902459	et	4	main
märkanud	doc_842434202398_item	2902460	et	4	main
räägis	doc_842434202398_item	2902461	et	3	main
naabrida	doc_842434202398_item	2902462	et	4	main
kui	doc_842434202398_item	2902463	et	3	main
x	doc_842434202398_item	2902464	et	4	main
oli	doc_842434202398_item	2902465	et	3	main
leinud	doc_842434202398_item	2902466	et	4	main
suur	doc_842434202398_item	2902467	et	3	main
spordikoti	doc_842434202398_item	2902468	et	3	main
politseisse	doc_842434202398_item	2902470	et	3	main
helistas	doc_842434202398_item	2902469	et	3	main
seda	doc_842434202398_item	2902472	et	3	main
pärast	doc_842434202398_item	2902471	et	4	main
mister	doc_842434202398_item	2902473	et	3	main
x	doc_842434202398_item	2902474	et	4	main
kuulnud	doc_842434202398_item	2902476	et	4	main
olid	doc_842434202398_item	2902496	et	4	main
harjutus	doc_842434202399_item	2902503	et	4	main
vihma	doc_842434202399_item	2902504	et	4	main
elektritööriista	doc_842434202399_item	2902519	et	4	main
eest	doc_842434202399_item	2902522	et	4	main
sellepärast	doc_842434202399_item	2902525	et	3	main
et	doc_842434202399_item	2902526	et	3	main
tohi	doc_842434202399_item	2902538	et	4	main
üle	doc_842434202399_item	2902539	et	3	main
ka	doc_842434202399_item	2902547	et	3	main
riietuma	doc_842434202399_item	2902551	et	3	main
et	doc_842434202399_item	2902556	et	3	main
järgida	doc_842434202399_item	2902563	et	3	main
mitte	doc_842434202399_item	2902576	et	3	main
juhtmest	doc_842434202399_item	2902583	et	4	main
hoides	doc_842434202399_item	2902584	et	4	main
tekkida	doc_842434202399_item	2902588	et	3	main
on	doc_842434202399_item	2902591	et	4	main
see	doc_842434202399_item	2902603	et	3	main
on	doc_842434202399_item	2902605	et	4	main
vesi	doc_842434202400_item	2902632	et	4	main
saab	doc_842434202400_item	2902633	et	3	main
laps	doc_842434202400_item	2902649	et	4	main
võib	doc_842434202400_item	2902650	et	3	main
vigastada	doc_842434202400_item	2902651	et	3	main
3	doc_842434202400_item	2902652	et	2	main
ja	doc_842434202400_item	2902665	et	3	main
riist	doc_842434202400_item	2902666	et	3	main
läheb	doc_842434202400_item	2902667	et	3	main
katki	doc_842434202400_item	2902668	et	4	main
4	doc_842434202400_item	2902669	et	2	main
elektriilöögi	doc_842434202400_item	2902682	et	4	main
saada	doc_842434202400_item	2902683	et	4	main
hoitud	doc_842434202400_item	2902694	et	4	main
mingil	doc_842434202400_item	2902700	et	4	main
tohi	doc_842434202400_item	2902703	et	4	main
ei	doc_842434202400_item	2902724	et	4	main
sellepärast	doc_842434202400_item	2902727	et	3	main
võib	doc_842434202400_item	2902729	et	3	main
8	doc_842434202400_item	2902732	et	2	main
olulisim	doc_842434202403_item	2902962	et	4	main
tingimus	doc_842434202403_item	2902963	et	4	main
stratosfääri	doc_842434202403_item	2903001	et	4	main
kõrgustel	doc_842434202403_item	2903003	et	4	main
kuid	doc_842434202403_item	2903004	et	4	main
ei	doc_842434202403_item	2903007	et	4	main
atmosfäärist	doc_842434202403_item	2903013	et	4	main
mida	doc_842434202403_item	2903028	et	4	main
lainepikkus	doc_842434202403_item	2903032	et	4	main
on	doc_842434202403_item	2903035	et	4	main
seda	doc_842434202403_item	2903044	et	3	main
mida	doc_842434202403_item	2903053	et	4	main
tuntakse	doc_842434202403_item	2903054	et	3	main
see	doc_842434202399_item	2902527	et	3	main
ei	doc_842434202399_item	2902537	et	4	main
sellepärast	doc_842434202399_item	2902555	et	3	main
kaitseb	doc_842434202399_item	2902558	et	4	main
iga	doc_842434202399_item	2902560	et	4	main
tööriista	doc_842434202399_item	2902566	et	4	main
peab	doc_842434202399_item	2902567	et	4	main
hoidma	doc_842434202399_item	2902568	et	3	main
juhul	doc_842434202399_item	2902578	et	3	main
ei	doc_842434202399_item	2902579	et	4	main
rööriista	doc_842434202399_item	2902581	et	4	main
kanda	doc_842434202399_item	2902582	et	4	main
et	doc_842434202399_item	2902586	et	3	main
vajalik	doc_842434202399_item	2902590	et	3	main
et	doc_842434202399_item	2902593	et	3	main
tahtmatult	doc_842434202399_item	2902597	et	4	main
sellepärast	doc_842434202399_item	2902598	et	3	main
et	doc_842434202399_item	2902599	et	3	main
võib	doc_842434202399_item	2902600	et	3	main
juhtuda	doc_842434202399_item	2902601	et	3	main
tarvitada	doc_842434202399_item	2902607	et	3	main
kaitseseade	doc_842434202399_item	2902608	et	4	main
te	doc_842434202399_item	2902609	et	4	main
võite	doc_842434202399_item	2902610	et	4	main
kasutada	doc_842434202399_item	2902611	et	3	main
ainult	doc_842434202399_item	2902612	et	4	main
spetsiaalseid	doc_842434202399_item	2902613	et	3	main
lisaosi	doc_842434202399_item	2902614	et	4	main
sellepärast	doc_842434202399_item	2902615	et	3	main
et	doc_842434202399_item	2902616	et	3	main
on	doc_842434202399_item	2902617	et	4	main
vaja	doc_842434202399_item	2902618	et	4	main
tagada	doc_842434202399_item	2902619	et	3	main
oma	doc_842434202399_item	2902620	et	4	main
kätte	doc_842434202400_item	2902625	et	4	main
võib	doc_842434202400_item	2902637	et	3	main
elektritööriista	doc_842434202400_item	2902653	et	4	main
ei	doc_842434202400_item	2902654	et	4	main
tööriista	doc_842434202400_item	2902670	et	4	main
kasutades	doc_842434202400_item	2902671	et	3	main
tolmu	doc_842434202400_item	2902676	et	4	main
selle	doc_842434202400_item	2902690	et	4	main
mitte	doc_842434202400_item	2902699	et	3	main
kaivituks	doc_842434202400_item	2902725	et	4	main
tahtmatult	doc_842434202400_item	2902726	et	4	main
et	doc_842434202400_item	2902728	et	3	main
võite	doc_842434202400_item	2902734	et	4	main
ainult	doc_842434202400_item	2902736	et	4	main
1	doc_842434202400_item	2902623	et	2	main
sisse	doc_842434202400_item	2902634	et	4	main
ja	doc_842434202400_item	2902635	et	3	main
töörist	doc_842434202400_item	2902636	et	3	main
põlema	doc_842434202400_item	2902639	et	4	main
elektritööriista	doc_842434202400_item	2902641	et	4	main
tuleb	doc_842434202400_item	2902642	et	3	main
laste	doc_842434202400_item	2902643	et	4	main
tohi	doc_842434202400_item	2902655	et	4	main
selle	doc_842434202400_item	2902658	et	4	main
riietuma	doc_842434202400_item	2902674	et	3	main
kaitset	doc_842434202400_item	2902677	et	4	main
võib	doc_842434202400_item	2902681	et	3	main
5	doc_842434202400_item	2902684	et	2	main
peab	doc_842434202400_item	2902686	et	4	main
hoidma	doc_842434202400_item	2902687	et	3	main
tööriista	doc_842434202400_item	2902695	et	4	main
juhul	doc_842434202400_item	2902701	et	3	main
tööriist	doc_842434202400_item	2902704	et	3	main
kanda	doc_842434202400_item	2902705	et	4	main
juhtmest	doc_842434202400_item	2902706	et	4	main
hoides	doc_842434202400_item	2902707	et	4	main
sellepärast	doc_842434202400_item	2902708	et	3	main
et	doc_842434202400_item	2902709	et	3	main
juhtmed	doc_842434202400_item	2902710	et	3	main
võib	doc_842434202400_item	2902711	et	3	main
vigastada	doc_842434202400_item	2902712	et	3	main
ja	doc_842434202400_item	2902713	et	3	main
töörist	doc_842434202400_item	2902714	et	3	main
ei	doc_842434202400_item	2902715	et	4	main
töötama	doc_842434202400_item	2902717	et	3	main
7	doc_842434202400_item	2902718	et	2	main
vajalik	doc_842434202400_item	2902719	et	3	main
on	doc_842434202400_item	2902720	et	4	main
hakka	doc_842434202400_item	2902716	et	4	main
hoida	doc_842434202400_item	2902646	et	3	main
sellepärast	doc_842434202400_item	2902647	et	3	main
et	doc_842434202400_item	2902648	et	3	main
üle	doc_842434202400_item	2902656	et	3	main
pärast	doc_842434202400_item	2902659	et	4	main
et	doc_842434202400_item	2902660	et	3	main
võib	doc_842434202400_item	2902661	et	3	main
juhtuda	doc_842434202400_item	2902662	et	3	main
elektri	doc_842434202400_item	2902663	et	3	main
katkestus	doc_842434202400_item	2902664	et	4	main
ja	doc_842434202400_item	2902675	et	3	main
kandma	doc_842434202400_item	2902678	et	3	main
sellepärast	doc_842434202400_item	2902679	et	3	main
et	doc_842434202400_item	2902680	et	3	main
alati	doc_842434202400_item	2902688	et	4	main
eluiga	doc_842434202400_item	2902696	et	4	main
pikeneb	doc_842434202400_item	2902697	et	3	main
et	doc_842434202400_item	2902722	et	3	main
vigastust	doc_842434202400_item	2902743	et	4	main
te	doc_842434202400_item	2902733	et	4	main
spetsiaalseid	doc_842434202400_item	2902737	et	3	main
et	doc_842434202400_item	2902740	et	3	main
vältida	doc_842434202400_item	2902741	et	3	main
tööriista	doc_842434202400_item	2902742	et	4	main
essee	doc_842434202403_item	2902958	et	4	main
on	doc_842434202403_item	2902960	et	4	main
mis	doc_842434202403_item	2902970	et	4	main
on	doc_842434202403_item	2902971	et	4	main
õrn	doc_842434202403_item	2902972	et	3	main
muutub	doc_842434202403_item	2903000	et	3	main
eri	doc_842434202403_item	2903002	et	4	main
hulk	doc_842434202403_item	2903006	et	3	main
ühte	doc_842434202403_item	2903010	et	4	main
ümbritsevast	doc_842434202403_item	2903012	et	4	main
kõige	doc_842434202403_item	2903015	et	4	main
tihedam	doc_842434202403_item	2903016	et	4	main
maa	doc_842434202403_item	2902966	et	4	main
efektiivse	doc_842434202403_item	2902968	et	3	main
kihi	doc_842434202403_item	2902997	et	3	main
sajatuhandikku	doc_842434202403_item	2903011	et	4	main
see	doc_842434202403_item	2903014	et	3	main
kogu	doc_842434202403_item	2903023	et	4	main
on	doc_842434202403_item	2903030	et	4	main
kõigele	doc_842434202403_item	2903041	et	4	main
elavale	doc_842434202403_item	2903042	et	4	main
ning	doc_842434202403_item	2903043	et	3	main
on	doc_842434202403_item	2903058	et	4	main
ja	doc_842434202403_item	2903070	et	3	main
peegeldatud	doc_842434202403_item	2903072	et	4	main
uv-a	doc_842434202403_item	2903076	et	4	main
keskmise	doc_842434202403_item	2903090	et	3	main
kiirgus	doc_842434202403_item	2903092	et	4	main
uv-b	doc_842434202403_item	2903093	et	4	main
on	doc_842434202403_item	2903095	et	4	main
surmav	doc_842434202403_item	2903097	et	4	main
kuid	doc_842434202403_item	2903098	et	4	main
sellest	doc_842434202403_item	2903103	et	4	main
osoonikiht	doc_842434202403_item	2903105	et	3	main
peegeldab	doc_842434202403_item	2903107	et	3	main
kahjustamine	doc_842434202403_item	2903113	et	4	main
toob	doc_842434202403_item	2903114	et	3	main
uv-b	doc_842434202403_item	2903116	et	4	main
kiirguse	doc_842434202403_item	2903117	et	3	main
mõju	doc_842434202403_item	2903122	et	4	main
ka	doc_842434202403_item	2903137	et	3	main
viimastel	doc_842434202403_item	2903141	et	3	main
kahjuliku	doc_842434202403_item	2903144	et	3	main
uv-b	doc_842434202403_item	2903162	et	4	main
millised	doc_842434202404_item	2903176	et	3	main
summa	doc_842434202404_item	2903221	et	4	main
nii	doc_842434202404_item	2903225	et	3	main
töövõtjaid	doc_842434202404_item	2903226	et	3	main
kui	doc_842434202404_item	2903227	et	3	main
ka	doc_842434202404_item	2903228	et	3	main
tööandjaid	doc_842434202404_item	2903229	et	3	main
varjama	doc_842434202404_item	2903230	et	3	main
väljamakstavat	doc_842434202404_item	2903231	et	3	main
tulu	doc_842434202404_item	2903232	et	4	main
ning	doc_842434202404_item	2903233	et	3	main
tegutsema	doc_842434202404_item	2903234	et	3	main
kohustused	doc_842434202404_item	2903241	et	4	main
1	doc_842434202404_item	2903242	et	2	main
5	doc_842434202404_item	2903252	et	2	main
võlad	doc_842434202404_item	2903254	et	3	main
dividendivõlad	doc_842434202404_item	2903256	et	3	main
6	doc_842434202404_item	2903258	et	2	main
1	doc_842434202404_item	2903261	et	2	main
tegurit	doc_842434202404_item	2903265	et	3	main
1	doc_842434202404_item	2903267	et	2	main
partner	doc_842434202404_item	2903269	et	3	main
võib	doc_842434202404_item	2903278	et	3	main
osoonkiht	doc_842434202403_item	2902959	et	4	main
elutegevuseks	doc_842434202403_item	2902961	et	4	main
osoon	doc_842434202403_item	2902964	et	3	main
ümber	doc_842434202403_item	2902967	et	3	main
kaitsekilbi	doc_842434202403_item	2902969	et	3	main
osooni	doc_842434202403_item	2902998	et	4	main
ületa	doc_842434202403_item	2903008	et	4	main
atmosfääris	doc_842434202403_item	2903017	et	3	main
asuvatest	doc_842434202403_item	2903018	et	4	main
filtritest	doc_842434202403_item	2903019	et	3	main
peegeldab	doc_842434202403_item	2903020	et	3	main
tagasi	doc_842434202403_item	2903021	et	3	main
ultraviolettkiirguse	doc_842434202403_item	2903031	et	3	main
põhjustada	doc_842434202403_item	2903040	et	3	main
nime	doc_842434202403_item	2903056	et	4	main
all	doc_842434202403_item	2903057	et	3	main
surmavalt	doc_842434202403_item	2903061	et	4	main
õnneks	doc_842434202403_item	2903065	et	4	main
neeldunud	doc_842434202403_item	2903069	et	4	main
pikema	doc_842434202403_item	2903073	et	4	main
lainepikkusega	doc_842434202403_item	2903074	et	4	main
ultraviolettkiirgus	doc_842434202403_item	2903075	et	3	main
osoonikiht	doc_842434202403_item	2903083	et	3	main
jääb	doc_842434202403_item	2903089	et	3	main
lainepikkusega	doc_842434202403_item	2903091	et	4	main
mis	doc_842434202403_item	2903094	et	4	main
ka	doc_842434202403_item	2903102	et	3	main
neelab	doc_842434202403_item	2903104	et	3	main
või	doc_842434202403_item	2903106	et	4	main
suurema	doc_842434202403_item	2903109	et	4	main
osa	doc_842434202403_item	2903110	et	4	main
igasugune	doc_842434202403_item	2903111	et	3	main
kaasa	doc_842434202403_item	2903115	et	4	main
isegi	doc_842434202403_item	2903123	et	4	main
jäävad	doc_842434202403_item	2903127	et	4	main
kiirguse	doc_842434202403_item	2903129	et	3	main
võib	doc_842434202403_item	2903131	et	3	main
asuv	doc_842434202403_item	2903134	et	4	main
aerosoolid	doc_842434202403_item	2903138	et	4	main
ja	doc_842434202403_item	2903139	et	3	main
pilved	doc_842434202403_item	2903140	et	3	main
aastakümnetel	doc_842434202403_item	2903142	et	4	main
maani	doc_842434202403_item	2903146	et	3	main
puhastada	doc_842434202403_item	2903153	et	3	main
meie	doc_842434202403_item	2903154	et	4	main
atmosfäär	doc_842434202403_item	2903155	et	3	main
heitgaasidest	doc_842434202403_item	2903156	et	3	main
kannab	doc_842434202403_item	2903157	et	3	main
vilja	doc_842434202403_item	2903158	et	4	main
see	doc_842434202403_item	2903159	et	3	main
kiirguse	doc_842434202403_item	2903163	et	3	main
essee	doc_842434202404_item	2903173	et	4	main
eksaam	doc_842434202404_item	2903174	et	3	main
1	doc_842434202404_item	2903175	et	2	main
suur	doc_842434202404_item	2903212	et	3	main
töövõtja	doc_842434202404_item	2903218	et	4	main
saadava	doc_842434202404_item	2903220	et	4	main
3	doc_842434202404_item	2903247	et	2	main
4	doc_842434202404_item	2903250	et	2	main
maksuvõlad	doc_842434202404_item	2903251	et	3	main
lühiajalised	doc_842434202404_item	2903259	et	4	main
eraldised	doc_842434202404_item	2903260	et	4	main
oma	doc_842434202404_item	2903274	et	4	main
moodustab	doc_842434202403_item	2902965	et	3	main
ja	doc_842434202403_item	2902973	et	3	main
kergesti	doc_842434202403_item	2902974	et	3	main
purustatav	doc_842434202403_item	2902975	et	4	main
see	doc_842434202403_item	2902976	et	3	main
paikneb	doc_842434202403_item	2902977	et	3	main
20	doc_842434202403_item	2902978	et	2	main
kuni	doc_842434202403_item	2902979	et	3	main
kõrgusel	doc_842434202403_item	2902980	et	4	main
stratosfääris	doc_842434202403_item	2902981	et	3	main
nõnda	doc_842434202403_item	2902982	et	3	main
hõreda	doc_842434202403_item	2902983	et	3	main
kihina	doc_842434202403_item	2902984	et	4	main
et	doc_842434202403_item	2902985	et	3	main
kogutuna	doc_842434202403_item	2902986	et	4	main
kokku	doc_842434202403_item	2902987	et	3	main
ühele	doc_842434202403_item	2902988	et	3	main
kõrgusele	doc_842434202403_item	2902989	et	4	main
moodustaks	doc_842434202403_item	2902990	et	3	main
ta	doc_842434202403_item	2902991	et	4	main
maa	doc_842434202403_item	2902992	et	4	main
ümber	doc_842434202403_item	2902993	et	3	main
mõne	doc_842434202403_item	2902994	et	3	main
sentimeetri	doc_842434202403_item	2902995	et	3	main
paksuse	doc_842434202403_item	2902996	et	4	main
kontsentratsioon	doc_842434202403_item	2902999	et	3	main
tema	doc_842434202403_item	2903005	et	4	main
kunagi	doc_842434202403_item	2903009	et	3	main
praktiliselt	doc_842434202403_item	2903022	et	4	main
päikeselt	doc_842434202403_item	2903024	et	4	main
tuleva	doc_842434202403_item	2903025	et	4	main
kahjuliku	doc_842434202403_item	2903026	et	3	main
ultraviolettkiirguse	doc_842434202403_item	2903027	et	3	main
ta	doc_842434202403_item	2903038	et	4	main
võib	doc_842434202403_item	2903039	et	3	main
suhteliselt	doc_842434202403_item	2903049	et	4	main
lühikese	doc_842434202403_item	2903050	et	4	main
praktiliselt	doc_842434202403_item	2903066	et	4	main
täies	doc_842434202403_item	2903067	et	3	main
ulatuses	doc_842434202403_item	2903068	et	4	main
laseb	doc_842434202403_item	2903082	et	3	main
nende	doc_842434202403_item	2903087	et	4	main
siiski	doc_842434202403_item	2903099	et	4	main
ohtlik	doc_842434202403_item	2903100	et	3	main
ning	doc_842434202403_item	2903101	et	3	main
osoonikihi	doc_842434202403_item	2903112	et	3	main
hulga	doc_842434202403_item	2903118	et	4	main
lühem	doc_842434202403_item	2903029	et	4	main
seda	doc_842434202403_item	2903033	et	3	main
suurem	doc_842434202403_item	2903034	et	4	main
kahju	doc_842434202403_item	2903036	et	4	main
mida	doc_842434202403_item	2903037	et	4	main
paremini	doc_842434202403_item	2903045	et	4	main
neelab	doc_842434202403_item	2903046	et	3	main
teda	doc_842434202403_item	2903047	et	4	main
osoonikiht	doc_842434202403_item	2903048	et	3	main
lainepikkusega	doc_842434202403_item	2903051	et	4	main
ultraviolettkiirgus	doc_842434202403_item	2903052	et	3	main
uv-c	doc_842434202403_item	2903055	et	4	main
kõigele	doc_842434202403_item	2903059	et	4	main
tagasi	doc_842434202403_item	2903071	et	3	main
selle	doc_842434202403_item	2903081	et	4	main
täielikult	doc_842434202403_item	2903085	et	4	main
tagasi	doc_842434202403_item	2903108	et	3	main
ja	doc_842434202403_item	2903120	et	3	main
negatiivse	doc_842434202403_item	2903121	et	3	main
tegurid	doc_842434202403_item	2903126	et	3	main
hulka	doc_842434202403_item	2903130	et	4	main
troposfääris	doc_842434202403_item	2903133	et	4	main
kiirguse	doc_842434202403_item	2903145	et	3	main
vähendanud	doc_842434202403_item	2903148	et	4	main
kaitse	doc_842434202403_item	2903160	et	4	main
on	doc_842434202404_item	2903177	et	4	main
tööandja	doc_842434202404_item	2903214	et	4	main
poolt	doc_842434202404_item	2903215	et	4	main
väljamakstava	doc_842434202404_item	2903216	et	3	main
ja	doc_842434202404_item	2903217	et	3	main
poolt	doc_842434202404_item	2903219	et	4	main
elavale	doc_842434202403_item	2903060	et	4	main
kahjulik	doc_842434202403_item	2903062	et	3	main
kuid	doc_842434202403_item	2903063	et	4	main
osoonikihis	doc_842434202403_item	2903064	et	3	main
on	doc_842434202403_item	2903077	et	4	main
suhteliselt	doc_842434202403_item	2903078	et	4	main
kahjutu	doc_842434202403_item	2903079	et	4	main
ning	doc_842434202403_item	2903080	et	3	main
peaaegu	doc_842434202403_item	2903084	et	3	main
läbi	doc_842434202403_item	2903086	et	4	main
vahele	doc_842434202403_item	2903088	et	4	main
vähem	doc_842434202403_item	2903096	et	4	main
suurenemise	doc_842434202403_item	2903119	et	4	main
kui	doc_842434202403_item	2903124	et	3	main
piirata	doc_842434202403_item	2903132	et	4	main
osoon	doc_842434202403_item	2903135	et	3	main
ning	doc_842434202403_item	2903136	et	3	main
jõudmist	doc_842434202403_item	2903147	et	4	main
õhusaaste	doc_842434202403_item	2903149	et	4	main
kuid	doc_842434202403_item	2903150	et	4	main
kui	doc_842434202403_item	2903151	et	3	main
hulga	doc_842434202403_item	2903164	et	4	main
on	doc_842434202403_item	2903166	et	4	main
osoonikihi	doc_842434202403_item	2903169	et	3	main
aktiivse	doc_842434202403_item	2903170	et	3	main
lagunemise	doc_842434202403_item	2903171	et	4	main
tsoonis	doc_842434202403_item	2903172	et	3	main
miinused	doc_842434202404_item	2903179	et	3	main
tingib	doc_842434202404_item	2903211	et	3	main
vahel	doc_842434202404_item	2903222	et	4	main
mis	doc_842434202404_item	2903223	et	4	main
sunnib	doc_842434202404_item	2903224	et	3	main
lühiajalised	doc_842434202404_item	2903240	et	4	main
2	doc_842434202404_item	2903244	et	2	main
5	doc_842434202404_item	2903262	et	2	main
miks	doc_842434202404_item	2903266	et	4	main
ebaaus	doc_842434202404_item	2903268	et	4	main
ta	doc_842434202404_item	2903271	et	4	main
võib	doc_842434202404_item	2903272	et	3	main
petta	doc_842434202404_item	2903273	et	3	main
asjades	doc_842434202404_item	2903277	et	3	main
varastada	doc_842434202404_item	2903279	et	3	main
2	doc_842434202404_item	2903282	et	2	main
millises	doc_842434202404_item	2903317	et	3	main
oodavam	doc_842434202404_item	2903321	et	4	main
kvaliteetsem	doc_842434202404_item	2903323	et	4	main
1	doc_842434202404_item	2903324	et	2	main
mis	doc_842434202404_item	2903325	et	4	main
pangalaen	doc_842434202404_item	2903331	et	3	main
on	doc_842434202404_item	2903332	et	4	main
ettevõtjale	doc_842434202404_item	2903337	et	3	main
tingimused	doc_842434202404_item	2903339	et	3	main
tehing	doc_842434202404_item	2903348	et	3	main
kalli	doc_842434202404_item	2903352	et	3	main
aga	doc_842434202404_item	2903354	et	3	main
selle	doc_842434202404_item	2903356	et	4	main
osade	doc_842434202404_item	2903358	et	3	main
omandiõigus	doc_842434202404_item	2903366	et	4	main
pärast	doc_842434202404_item	2903368	et	4	main
tasumist	doc_842434202404_item	2903371	et	4	main
muud	doc_842434202403_item	2903125	et	4	main
samaks	doc_842434202403_item	2903128	et	3	main
on	doc_842434202403_item	2903143	et	4	main
pingutus	doc_842434202403_item	2903152	et	4	main
kaob	doc_842434202403_item	2903161	et	3	main
suurenemist	doc_842434202403_item	2903165	et	4	main
märgitud	doc_842434202403_item	2903167	et	4	main
ka	doc_842434202403_item	2903168	et	3	main
tulumaksu	doc_842434202404_item	2903178	et	4	main
tulumaksu	doc_842434202404_item	2903180	et	4	main
negatiivseks	doc_842434202404_item	2903181	et	3	main
küljeks	doc_842434202404_item	2903182	et	3	main
peetakse	doc_842434202404_item	2903183	et	3	main
tema	doc_842434202404_item	2903184	et	4	main
teostamise	doc_842434202404_item	2903185	et	4	main
ja	doc_842434202404_item	2903186	et	3	main
haldamise	doc_842434202404_item	2903187	et	4	main
äärmist	doc_842434202404_item	2903188	et	3	main
keerukust	doc_842434202404_item	2903189	et	4	main
maksukohuslasi	doc_842434202404_item	2903190	et	4	main
on	doc_842434202404_item	2903191	et	4	main
palju	doc_842434202404_item	2903192	et	4	main
süsteem	doc_842434202404_item	2903193	et	3	main
on	doc_842434202404_item	2903194	et	4	main
keeruline	doc_842434202404_item	2903195	et	4	main
selle	doc_842434202404_item	2903196	et	4	main
käigushoidmine	doc_842434202404_item	2903197	et	3	main
on	doc_842434202404_item	2903198	et	4	main
kallis	doc_842434202404_item	2903199	et	4	main
tulumaksu	doc_842434202404_item	2903200	et	4	main
halvaks	doc_842434202404_item	2903201	et	4	main
küljeks	doc_842434202404_item	2903202	et	3	main
loetakse	doc_842434202404_item	2903203	et	3	main
ka	doc_842434202404_item	2903204	et	3	main
tema	doc_842434202404_item	2903205	et	4	main
negatiivset	doc_842434202404_item	2903206	et	3	main
mõju	doc_842434202404_item	2903207	et	4	main
tööjõu	doc_842434202404_item	2903208	et	3	main
palkamisele	doc_842434202404_item	2903209	et	4	main
mille	doc_842434202404_item	2903210	et	3	main
vahe	doc_842434202404_item	2903213	et	4	main
n-ö	doc_842434202404_item	2903235	et	4	main
1	doc_842434202404_item	2903237	et	2	main
millised	doc_842434202404_item	2903238	et	3	main
on	doc_842434202404_item	2903239	et	4	main
ettemaksed	doc_842434202404_item	2903246	et	3	main
võlad	doc_842434202404_item	2903248	et	3	main
viitvõlad	doc_842434202404_item	2903253	et	3	main
intressivõlad	doc_842434202404_item	2903257	et	3	main
toode	doc_842434202404_item	2903318	et	3	main
uuem	doc_842434202404_item	2903320	et	4	main
annab	doc_842434202404_item	2903336	et	3	main
ja	doc_842434202404_item	2903340	et	3	main
tagastada	doc_842434202404_item	2903344	et	3	main
ostab	doc_842434202404_item	2903351	et	3	main
kohe	doc_842434202404_item	2903362	et	4	main
makse	doc_842434202404_item	2903370	et	4	main
poollegaalselt	doc_842434202404_item	2903236	et	4	main
võlakohustused	doc_842434202404_item	2903243	et	3	main
ostjate	doc_842434202404_item	2903245	et	4	main
tarnijatele	doc_842434202404_item	2903249	et	4	main
töövõtjatele	doc_842434202404_item	2903255	et	3	main
firmat	doc_842434202404_item	2903263	et	3	main
ohustavat	doc_842434202404_item	2903264	et	4	main
sest	doc_842434202404_item	2903270	et	4	main
mingis	doc_842434202404_item	2903276	et	4	main
firma	doc_842434202404_item	2903280	et	4	main
turu	doc_842434202404_item	2903283	et	3	main
muutumine	doc_842434202404_item	2903284	et	4	main
firma	doc_842434202404_item	2903285	et	4	main
võib	doc_842434202404_item	2903286	et	3	main
pankrotti	doc_842434202404_item	2903287	et	4	main
minna	doc_842434202404_item	2903288	et	3	main
3	doc_842434202404_item	2903289	et	2	main
panga	doc_842434202404_item	2903290	et	3	main
pankrot	doc_842434202404_item	2903291	et	3	main
kõik	doc_842434202404_item	2903292	et	4	main
firmas	doc_842434202404_item	2903293	et	3	main
raha	doc_842434202404_item	2903294	et	4	main
on	doc_842434202404_item	2903295	et	4	main
kusagil	doc_842434202404_item	2903296	et	3	main
olema	doc_842434202404_item	2903297	et	4	main
4	doc_842434202404_item	2903298	et	2	main
looduskatastroofid	doc_842434202404_item	2903299	et	3	main
võivad	doc_842434202404_item	2903300	et	4	main
puruneda	doc_842434202404_item	2903301	et	3	main
hoone	doc_842434202404_item	2903302	et	4	main
kus	doc_842434202404_item	2903303	et	3	main
on	doc_842434202404_item	2903304	et	4	main
firma	doc_842434202404_item	2903305	et	4	main
väärtuspabereid	doc_842434202404_item	2903306	et	3	main
dokumentid	doc_842434202404_item	2903307	et	4	main
ja	doc_842434202404_item	2903308	et	3	main
ne	doc_842434202404_item	2903309	et	4	main
5	doc_842434202404_item	2903310	et	2	main
konkurents	doc_842434202404_item	2903311	et	3	main
kui	doc_842434202404_item	2903312	et	3	main
turul	doc_842434202404_item	2903313	et	3	main
tekkib	doc_842434202404_item	2903314	et	3	main
uus	doc_842434202404_item	2903315	et	3	main
partnerid	doc_842434202404_item	2903275	et	3	main
raha	doc_842434202404_item	2903281	et	4	main
on	doc_842434202404_item	2903319	et	4	main
firma	doc_842434202404_item	2903316	et	4	main
vahe	doc_842434202404_item	2903326	et	4	main
pank	doc_842434202404_item	2903335	et	3	main
teatud	doc_842434202404_item	2903338	et	4	main
mis	doc_842434202404_item	2903341	et	4	main
tähtajaks	doc_842434202404_item	2903343	et	3	main
aga	doc_842434202404_item	2903345	et	3	main
on	doc_842434202404_item	2903347	et	4	main
eest	doc_842434202404_item	2903357	et	4	main
on	doc_842434202404_item	2903327	et	4	main
laenud	doc_842434202404_item	2903328	et	4	main
ja	doc_842434202404_item	2903329	et	3	main
liisingud	doc_842434202404_item	2903330	et	3	main
tuleb	doc_842434202404_item	2903342	et	3	main
liising	doc_842434202404_item	2903346	et	3	main
firma	doc_842434202404_item	2903350	et	4	main
kaupa	doc_842434202404_item	2903359	et	4	main
kasutusõigus	doc_842434202404_item	2903360	et	4	main
tuleb	doc_842434202404_item	2903361	et	3	main
liisingulepingu	doc_842434202404_item	2903364	et	3	main
või	doc_842434202404_item	2903322	et	4	main
raha	doc_842434202404_item	2903333	et	4	main
mille	doc_842434202404_item	2903334	et	3	main
millega	doc_842434202404_item	2903349	et	3	main
põhivahendi	doc_842434202404_item	2903353	et	3	main
maksab	doc_842434202404_item	2903355	et	3	main
pärast	doc_842434202404_item	2903363	et	4	main
sõlmimist	doc_842434202404_item	2903365	et	4	main
aga	doc_842434202404_item	2903367	et	3	main
viimase	doc_842434202404_item	2903369	et	3	main
viikingiaeg	doc_854846908872_item	2904482	et	3	main
2	doc_854846908872_item	2904485	et	2	main
1	doc_854846908872_item	2904489	et	2	main
muistsete	doc_854846908872_item	2904492	et	3	main
tol	doc_854846908872_item	2904495	et	3	main
asjade	doc_854846908872_item	2904506	et	3	main
koduloomi	doc_854846908872_item	2904512	et	4	main
kasutati	doc_854846908872_item	2904514	et	4	main
1	doc_854846908872_item	2904529	et	2	main
sõjalisi	doc_854846908872_item	2904540	et	4	main
konflikte	doc_854846908872_item	2904541	et	3	main
9-10s	doc_854846908872_item	2904542	et	3	main
tekkis	doc_854846908872_item	2904543	et	3	main
asustus	doc_854846908872_item	2904547	et	4	main
inimesed	doc_854846908872_item	2904577	et	3	main
olid	doc_854846908872_item	2904584	et	4	main
ader	doc_854846908872_item	2904591	et	3	main
siia	doc_854846908872_item	2904592	et	4	main
levis	doc_854846908872_item	2904610	et	4	main
ka	doc_854846908872_item	2904611	et	3	main
sõnaraamat	doc_854846908872_item	2904612	et	3	main
väga	doc_854846908872_item	2904613	et	3	main
tähtsaksedeks	doc_854846908872_item	2904614	et	4	main
kalmed	doc_854846908872_item	2904620	et	3	main
inimesed	doc_854846908872_item	2904621	et	3	main
loodusel	doc_854846908872_item	2904624	et	4	main
tekkisid	doc_854846908872_item	2904634	et	4	main
praeguste	doc_854846908872_item	2904635	et	3	main
tuli	doc_854846908872_item	2904645	et	4	main
1	doc_854846908872_item	2904650	et	2	main
leitud	doc_854846908872_item	2904653	et	4	main
võõramaiseid	doc_854846908872_item	2904655	et	4	main
münte	doc_854846908872_item	2904656	et	3	main
seetõttu	doc_854846908872_item	2904657	et	3	main
viikingiaeg	doc_854846908872_item	2904490	et	3	main
hõbedas	doc_854846908872_item	2904502	et	3	main
toimub	doc_854846908872_item	2904517	et	3	main
intensiivne	doc_854846908872_item	2904518	et	3	main
1	doc_854846908872_item	2904481	et	2	main
territooriumil	doc_854846908872_item	2904484	et	3	main
mõiste	doc_854846908872_item	2904486	et	4	main
tähendus	doc_854846908872_item	2904488	et	4	main
skandinaavia	doc_854846908872_item	2904493	et	4	main
ajal	doc_854846908872_item	2904496	et	4	main
kõige	doc_854846908872_item	2904497	et	4	main
loomade	doc_854846908872_item	2904504	et	4	main
kõige	doc_854846908872_item	2904508	et	4	main
oli	doc_854846908872_item	2904510	et	3	main
hobune	doc_854846908872_item	2904511	et	4	main
palju	doc_854846908872_item	2904515	et	4	main
kauplemine	doc_854846908872_item	2904519	et	4	main
mett	doc_854846908872_item	2904522	et	4	main
oli	doc_854846908872_item	2904524	et	3	main
juba	doc_854846908872_item	2904525	et	3	main
kujunevad	doc_854846908872_item	2904530	et	4	main
slaavi	doc_854846908872_item	2904546	et	3	main
hakkasid	doc_854846908872_item	2904549	et	4	main
slaavlastega	doc_854846908872_item	2904550	et	3	main
tekkima	doc_854846908872_item	2904551	et	3	main
ka	doc_854846908872_item	2904552	et	3	main
konflikte	doc_854846908872_item	2904553	et	3	main
ei	doc_854846908872_item	2904573	et	4	main
toodi	doc_854846908872_item	2904593	et	4	main
potikedrad	doc_854846908872_item	2904594	et	3	main
ümber	doc_854846908872_item	2904603	et	3	main
ja	doc_854846908872_item	2904606	et	3	main
hiljemal	doc_854846908872_item	2904608	et	4	main
ajal	doc_854846908872_item	2904609	et	4	main
et	doc_854846908872_item	2904623	et	3	main
on	doc_854846908872_item	2904625	et	4	main
eriline	doc_854846908872_item	2904626	et	4	main
võim	doc_854846908872_item	2904627	et	3	main
maakundade	doc_854846908872_item	2904636	et	4	main
piirid	doc_854846908872_item	2904637	et	3	main
see	doc_854846908872_item	2904638	et	3	main
oli	doc_854846908872_item	2904639	et	3	main
kasutusele	doc_854846908872_item	2904646	et	4	main
eestis	doc_854846908872_item	2904651	et	3	main
2	doc_854846908872_item	2904666	et	2	main
kontrolltöö	doc_854846908873_item	2904677	et	4	main
territooriumil	doc_854846908873_item	2904681	et	3	main
viikingiaeg	doc_854846908873_item	2904686	et	3	main
pkr	doc_854846908873_item	2904691	et	4	main
maksti	doc_854846908873_item	2904721	et	3	main
sellel	doc_854846908873_item	2904739	et	4	main
sellest	doc_854846908873_item	2904747	et	4	main
räägitakse	doc_854846908873_item	2904748	et	3	main
saagades	doc_854846908873_item	2904749	et	3	main
ajaloosündusdest	doc_854846908873_item	2904755	et	4	main
1030	doc_854846908873_item	2904760	et	2	main
rajab	doc_854846908873_item	2904766	et	3	main
9-10	doc_854846908873_item	2904778	et	2	main
järve	doc_854846908873_item	2904781	et	4	main
tekivad	doc_854846908873_item	2904783	et	3	main
slaavi	doc_854846908873_item	2904784	et	3	main
asulad	doc_854846908873_item	2904785	et	3	main
mis	doc_854846908873_item	2904791	et	4	main
tuleb	doc_854846908873_item	2904792	et	3	main
ka	doc_854846908873_item	2904793	et	3	main
vajalikud	doc_854846908873_item	2904822	et	3	main
siis	doc_854846908873_item	2904825	et	3	main
kasvatamisega	doc_854846908873_item	2904829	et	4	main
väärtuslikum	doc_854846908872_item	2904498	et	4	main
metall	doc_854846908872_item	2904499	et	3	main
oli	doc_854846908872_item	2904500	et	3	main
hõbe	doc_854846908872_item	2904501	et	3	main
arvutati	doc_854846908872_item	2904503	et	4	main
hinde	doc_854846908872_item	2904507	et	4	main
kallim	doc_854846908872_item	2904509	et	4	main
rohkem	doc_854846908872_item	2904516	et	4	main
orje	doc_854846908872_item	2904523	et	3	main
saada	doc_854846908872_item	2904527	et	4	main
mõisad	doc_854846908872_item	2904531	et	3	main
pärandama	doc_854846908872_item	2904534	et	3	main
ka	doc_854846908872_item	2904537	et	3	main
ääres	doc_854846908872_item	2904545	et	4	main
ajaga	doc_854846908872_item	2904548	et	3	main
tänapäevase	doc_854846908872_item	2904554	et	4	main
tartu	doc_854846908872_item	2904555	et	4	main
asukaid	doc_854846908872_item	2904566	et	4	main
maksaksid	doc_854846908872_item	2904570	et	4	main
rahvusele	doc_854846908872_item	2904576	et	3	main
juba	doc_854846908872_item	2904585	et	3	main
ja	doc_854846908872_item	2904587	et	3	main
mugavamad	doc_854846908872_item	2904588	et	4	main
kirved	doc_854846908872_item	2904589	et	3	main
saagid	doc_854846908872_item	2904590	et	3	main
mis	doc_854846908872_item	2904602	et	4	main
jne	doc_854846908872_item	2904607	et	4	main
inimese	doc_854846908872_item	2904616	et	4	main
matused	doc_854846908872_item	2904617	et	3	main
juba	doc_854846908872_item	2904618	et	3	main
olid	doc_854846908872_item	2904619	et	4	main
uskusid	doc_854846908872_item	2904622	et	4	main
allikad	doc_854846908872_item	2904631	et	3	main
ja	doc_854846908872_item	2904632	et	3	main
jne	doc_854846908872_item	2904633	et	4	main
uus	doc_854846908872_item	2904647	et	3	main
läbi	doc_854846908872_item	2904661	et	4	main
eesti	doc_854846908872_item	2904662	et	4	main
muinasaeg	doc_854846908872_item	2904667	et	3	main
mis	doc_854846908872_item	2904669	et	4	main
viikingiaeg	doc_854846908873_item	2904679	et	3	main
eesti	doc_854846908873_item	2904680	et	4	main
2	doc_854846908873_item	2904682	et	2	main
territooriumil	doc_854846908873_item	2904689	et	3	main
ajal	doc_854846908873_item	2904740	et	4	main
oli	doc_854846908873_item	2904741	et	3	main
palju	doc_854846908873_item	2904742	et	4	main
esimene	doc_854846908873_item	2904756	et	3	main
sellel	doc_854846908873_item	2904762	et	4	main
ajal	doc_854846908873_item	2904763	et	4	main
linna	doc_854846908873_item	2904767	et	4	main
tugipunktiks	doc_854846908873_item	2904773	et	4	main
millest	doc_854846908873_item	2904774	et	3	main
kirjutatakse	doc_854846908873_item	2904775	et	3	main
ka	doc_854846908873_item	2904776	et	3	main
peipsi	doc_854846908873_item	2904780	et	4	main
ääres	doc_854846908873_item	2904782	et	4	main
irboska	doc_854846908873_item	2904786	et	4	main
eesti	doc_854846908873_item	2904794	et	4	main
tulevad	doc_854846908873_item	2904797	et	4	main
kontrolltöö	doc_854846908872_item	2904480	et	4	main
eesti	doc_854846908872_item	2904483	et	4	main
muinasaeg	doc_854846908872_item	2904487	et	3	main
800-1050	doc_854846908872_item	2904491	et	2	main
retked	doc_854846908872_item	2904494	et	3	main
ja	doc_854846908872_item	2904505	et	3	main
juba	doc_854846908872_item	2904513	et	3	main
müüdi	doc_854846908872_item	2904520	et	4	main
karusnahku	doc_854846908872_item	2904521	et	3	main
välismaariideid	doc_854846908872_item	2904528	et	3	main
hakkatakse	doc_854846908872_item	2904533	et	4	main
oli	doc_854846908872_item	2904536	et	3	main
meeldinud	doc_854846908872_item	2904574	et	4	main
kohaliku	doc_854846908872_item	2904575	et	3	main
tegelesid	doc_854846908872_item	2904578	et	4	main
palju	doc_854846908872_item	2904579	et	4	main
käsitööga	doc_854846908872_item	2904580	et	3	main
ja	doc_854846908872_item	2904581	et	3	main
tööriistad	doc_854846908872_item	2904583	et	3	main
paremad	doc_854846908872_item	2904586	et	4	main
hakkasid	doc_854846908872_item	2904595	et	4	main
levima	doc_854846908872_item	2904596	et	3	main
saagid-	doc_854846908872_item	2904597	et	3	main
laulud	doc_854846908872_item	2904598	et	3	main
kus	doc_854846908872_item	2904599	et	3	main
jutustati	doc_854846908872_item	2904600	et	3	main
sellest	doc_854846908872_item	2904601	et	4	main
sõjadest	doc_854846908872_item	2904605	et	4	main
said	doc_854846908872_item	2904615	et	4	main
olid	doc_854846908872_item	2904628	et	4	main
pühad	doc_854846908872_item	2904629	et	3	main
seotud	doc_854846908872_item	2904640	et	4	main
ka	doc_854846908872_item	2904641	et	3	main
loodesega	doc_854846908872_item	2904642	et	4	main
ja	doc_854846908872_item	2904643	et	3	main
kliimaga	doc_854846908872_item	2904644	et	3	main
kaalu	doc_854846908872_item	2904648	et	4	main
öölda	doc_854846908872_item	2904659	et	4	main
et	doc_854846908872_item	2904660	et	3	main
kaubateed	doc_854846908872_item	2904665	et	4	main
kõik	doc_854846908872_item	2904668	et	4	main
oli	doc_854846908872_item	2904670	et	3	main
ekr	doc_854846908872_item	2904671	et	4	main
inimese	doc_854846908872_item	2904672	et	4	main
algne	doc_854846908872_item	2904673	et	3	main
areng	doc_854846908872_item	2904674	et	3	main
kiviaeg	doc_854846908872_item	2904675	et	3	main
pronksiaeg	doc_854846908872_item	2904676	et	3	main
kes	doc_854846908873_item	2904695	et	4	main
maksis	doc_854846908873_item	2904727	et	4	main
250-300gr	doc_854846908873_item	2904728	et	4	main
hõbedat	doc_854846908873_item	2904729	et	3	main
orjatar	doc_854846908873_item	2904730	et	3	main
gr	doc_854846908873_item	2904732	et	4	main
300	doc_854846908873_item	2904736	et	2	main
gr	doc_854846908873_item	2904737	et	4	main
hõbedat	doc_854846908873_item	2904738	et	3	main
kontlikte	doc_854846908873_item	2904744	et	4	main
eriti	doc_854846908873_item	2904745	et	3	main
skandinaavlastega	doc_854846908873_item	2904746	et	3	main
suur	doc_854846908873_item	2904757	et	3	main
sõjakontlikt	doc_854846908873_item	2904758	et	4	main
aastal	doc_854846908873_item	2904761	et	3	main
jurjev	doc_854846908873_item	2904768	et	4	main
esimeseks	doc_854846908873_item	2904771	et	3	main
slavlasttel	doc_854846908873_item	2904787	et	4	main
territooriumi	doc_854846908873_item	2904795	et	4	main
kallid	doc_854846908873_item	2904824	et	3	main
rohkem	doc_854846908873_item	2904832	et	4	main
veekogude	doc_854846908873_item	2904833	et	3	main
head	doc_854846908873_item	2904839	et	4	main
kirves	doc_854846908873_item	2904859	et	4	main
ka	doc_854846908873_item	2904864	et	3	main
areneda	doc_854846908873_item	2904866	et	3	main
üle	doc_854846908873_item	2904869	et	3	main
kestab	doc_854846908873_item	2904887	et	4	main
kuni	doc_854846908873_item	2904888	et	3	main
eesti	doc_855437674538_item	2904894	et	4	main
soodustas	doc_855437674538_item	2904898	et	3	main
eestlaste	doc_855437674538_item	2904901	et	4	main
võimalik	doc_854846908872_item	2904526	et	3	main
maa	doc_854846908872_item	2904532	et	4	main
aga	doc_854846908872_item	2904535	et	3	main
palju	doc_854846908872_item	2904538	et	4	main
röövimisi	doc_854846908872_item	2904539	et	4	main
peipsi	doc_854846908872_item	2904544	et	4	main
kohapeal	doc_854846908872_item	2904556	et	3	main
asutasid	doc_854846908872_item	2904557	et	4	main
jaroslav	doc_854846908872_item	2904558	et	4	main
tark	doc_854846908872_item	2904559	et	3	main
nad	doc_854846908872_item	2904560	et	3	main
jurjevi	doc_854846908872_item	2904561	et	4	main
slaavlased	doc_854846908872_item	2904562	et	3	main
tahtsid	doc_854846908872_item	2904563	et	4	main
et	doc_854846908872_item	2904564	et	3	main
siinseid	doc_854846908872_item	2904565	et	3	main
ka	doc_854846908872_item	2904568	et	3	main
neile	doc_854846908872_item	2904567	et	4	main
maksu	doc_854846908872_item	2904569	et	4	main
mis	doc_854846908872_item	2904571	et	4	main
ilmselt	doc_854846908872_item	2904572	et	4	main
põllumajandusega	doc_854846908872_item	2904582	et	3	main
toimus	doc_854846908872_item	2904604	et	3	main
puud	doc_854846908872_item	2904630	et	4	main
süsteem	doc_854846908872_item	2904649	et	3	main
on	doc_854846908872_item	2904652	et	4	main
palju	doc_854846908872_item	2904654	et	4	main
läksid	doc_854846908872_item	2904663	et	4	main
paljud	doc_854846908872_item	2904664	et	3	main
mõiste	doc_854846908873_item	2904683	et	4	main
muinasaeg	doc_854846908873_item	2904684	et	3	main
tähendus	doc_854846908873_item	2904685	et	4	main
oli	doc_854846908873_item	2904687	et	3	main
800-1050	doc_854846908873_item	2904690	et	2	main
vikingid	doc_854846908873_item	2904692	et	4	main
olid	doc_854846908873_item	2904693	et	4	main
kaupmehed	doc_854846908873_item	2904694	et	3	main
kauplesid	doc_854846908873_item	2904696	et	4	main
eestlastega	doc_854846908873_item	2904697	et	4	main
toodeks	doc_854846908873_item	2904698	et	3	main
oli	doc_854846908873_item	2904699	et	3	main
mesi	doc_854846908873_item	2904700	et	4	main
vaht	doc_854846908873_item	2904701	et	3	main
orjed	doc_854846908873_item	2904702	et	4	main
ehted	doc_854846908873_item	2904703	et	3	main
koduloomad	doc_854846908873_item	2904704	et	3	main
kõige	doc_854846908873_item	2904705	et	4	main
väärtuslikum	doc_854846908873_item	2904706	et	4	main
metall	doc_854846908873_item	2904707	et	3	main
oli	doc_854846908873_item	2904708	et	3	main
hõbe	doc_854846908873_item	2904709	et	3	main
eesti	doc_854846908873_item	2904710	et	4	main
territooriumil	doc_854846908873_item	2904711	et	3	main
on	doc_854846908873_item	2904712	et	4	main
leitud	doc_854846908873_item	2904713	et	4	main
hõbe	doc_854846908873_item	2904714	et	3	main
münte	doc_854846908873_item	2904715	et	3	main
mis	doc_854846908873_item	2904716	et	4	main
kuuluvad	doc_854846908873_item	2904717	et	4	main
sellele	doc_854846908873_item	2904718	et	4	main
ajale	doc_854846908873_item	2904719	et	3	main
hõbega	doc_854846908873_item	2904720	et	4	main
toodete	doc_854846908873_item	2904723	et	3	main
nt	doc_854846908873_item	2904725	et	4	main
200	doc_854846908873_item	2904731	et	2	main
h	doc_854846908873_item	2904733	et	4	main
aga	doc_854846908873_item	2904734	et	3	main
org	doc_854846908873_item	2904735	et	3	main
sõjalisi	doc_854846908873_item	2904743	et	4	main
tähtsadest	doc_854846908873_item	2904754	et	4	main
oli	doc_854846908873_item	2904759	et	3	main
see	doc_854846908873_item	2904769	et	3	main
vene	doc_854846908873_item	2904772	et	4	main
kroonikas	doc_854846908873_item	2904777	et	3	main
on	doc_854846908873_item	2904788	et	4	main
koduloomade	doc_854846908873_item	2904828	et	4	main
palju	doc_854846908873_item	2904838	et	4	main
oskasid	doc_854846908873_item	2904842	et	4	main
need	doc_854846908873_item	2904861	et	3	main
võib	doc_854846908872_item	2904658	et	3	main
1	doc_854846908873_item	2904678	et	2	main
eesti	doc_854846908873_item	2904688	et	4	main
kõige	doc_854846908873_item	2904722	et	4	main
eest	doc_854846908873_item	2904724	et	4	main
hobune	doc_854846908873_item	2904726	et	4	main
pikemad	doc_854846908873_item	2904750	et	4	main
lugulaulud	doc_854846908873_item	2904751	et	3	main
kus	doc_854846908873_item	2904752	et	3	main
räägitakse	doc_854846908873_item	2904753	et	3	main
jaroslav	doc_854846908873_item	2904764	et	4	main
tark	doc_854846908873_item	2904765	et	3	main
sai	doc_854846908873_item	2904770	et	4	main
sajandil	doc_854846908873_item	2904779	et	3	main
kasutusel	doc_854846908873_item	2904789	et	4	main
kaalusüsteem	doc_854846908873_item	2904790	et	3	main
sellest	doc_854846908873_item	2904796	et	4	main
ka	doc_854846908873_item	2904798	et	3	main
mõned	doc_854846908873_item	2904799	et	3	main
sõnad	doc_854846908873_item	2904800	et	4	main
nt	doc_854846908873_item	2904801	et	4	main
besmen	doc_854846908873_item	2904802	et	4	main
kaal	doc_854846908873_item	2904803	et	3	main
eestlased	doc_854846908873_item	2904804	et	3	main
ise	doc_854846908873_item	2904805	et	4	main
olid	doc_854846908873_item	2904806	et	4	main
ka	doc_854846908873_item	2904807	et	3	main
sõjaliselt	doc_854846908873_item	2904808	et	4	main
aga	doc_854846908873_item	2904810	et	3	main
aktiivsed	doc_854846908873_item	2904809	et	3	main
lääne	doc_854846908873_item	2904811	et	4	main
suhtes	doc_854846908873_item	2904812	et	4	main
on	doc_854846908873_item	2904813	et	4	main
leitud	doc_854846908873_item	2904814	et	4	main
palju	doc_854846908873_item	2904815	et	4	main
araabia	doc_854846908873_item	2904816	et	4	main
münte	doc_854846908873_item	2904817	et	3	main
kuna	doc_854846908873_item	2904818	et	3	main
hobuloomad	doc_854846908873_item	2904819	et	3	main
olid	doc_854846908873_item	2904820	et	4	main
väga	doc_854846908873_item	2904821	et	3	main
tegelesid	doc_854846908873_item	2904827	et	4	main
juba	doc_854846908873_item	2904843	et	3	main
pronksi	doc_854846908873_item	2904844	et	4	main
metalli	doc_854846908873_item	2904846	et	4	main
töödelda	doc_854846908873_item	2904847	et	4	main
ja	doc_854846908873_item	2904848	et	3	main
suulata	doc_854846908873_item	2904849	et	4	main
seetõttu	doc_854846908873_item	2904850	et	3	main
tööriistad	doc_854846908873_item	2904851	et	3	main
tööriistad	doc_854846908873_item	2904862	et	3	main
põllumajandust	doc_854846908873_item	2904865	et	3	main
rikkamad	doc_854846908873_item	2904876	et	4	main
ja	doc_854846908873_item	2904877	et	3	main
kristluse	doc_854846908873_item	2904889	et	4	main
tulekutrauaaja	doc_854846908873_item	2904890	et	4	main
lõpuni	doc_854846908873_item	2904891	et	3	main
1	doc_855437674538_item	2904896	et	2	main
soodustas	doc_855437674538_item	2904913	et	3	main
talupoegade	doc_855437674538_item	2904914	et	3	main
ja	doc_855437674538_item	2904921	et	3	main
muinasusund	doc_855437674538_item	2904924	et	3	main
ja	doc_854846908873_item	2904823	et	3	main
paljud	doc_854846908873_item	2904826	et	3	main
juures	doc_854846908873_item	2904834	et	4	main
seal	doc_854846908873_item	2904835	et	4	main
kus	doc_854846908873_item	2904836	et	3	main
saab	doc_854846908873_item	2904837	et	3	main
heina	doc_854846908873_item	2904840	et	4	main
olid	doc_854846908873_item	2904852	et	4	main
juba	doc_854846908873_item	2904853	et	3	main
paremad	doc_854846908873_item	2904854	et	4	main
tugev	doc_854846908873_item	2904855	et	4	main
teraga	doc_854846908873_item	2904856	et	3	main
nt	doc_854846908873_item	2904857	et	4	main
sirp	doc_854846908873_item	2904858	et	3	main
olid	doc_854846908873_item	2904875	et	4	main
tahtsid	doc_854846908873_item	2904879	et	4	main
oma	doc_854846908873_item	2904881	et	4	main
kontrolltöö	doc_855437674538_item	2904892	et	4	main
muinasusundi	doc_855437674538_item	2904899	et	3	main
1	doc_855437674538_item	2904908	et	2	main
muinasusundi	doc_855437674538_item	2904909	et	3	main
säilimist	doc_855437674538_item	2904910	et	4	main
mõisnikud	doc_855437674538_item	2904917	et	3	main
jäid	doc_855437674538_item	2904918	et	4	main
kultuuri	doc_855437674538_item	2904920	et	4	main
traditsioonilise	doc_855437674538_item	2904919	et	4	main
ristiusu	doc_855437674538_item	2904934	et	3	main
nende	doc_855437674538_item	2904936	et	4	main
vähesest	doc_855437674538_item	2904937	et	3	main
liikuvusest	doc_855437674538_item	2904938	et	4	main
põllumajanduslikel	doc_855437674538_item	2904939	et	3	main
kombeid	doc_855437674538_item	2904942	et	4	main
jäi	doc_855437674538_item	2904943	et	3	main
püsima	doc_855437674538_item	2904944	et	3	main
19saj	doc_855437674538_item	2904945	et	4	main
hulka	doc_855437674538_item	2904958	et	4	main
pühapaikude	doc_855437674538_item	2904972	et	4	main
austamine	doc_855437674538_item	2904973	et	4	main
elus	doc_855437674538_item	2904982	et	4	main
külaelanikud	doc_855437674538_item	2905027	et	3	main
eestlaste	doc_855437674538_item	2905032	et	4	main
kombed	doc_855437674538_item	2905050	et	3	main
hansa	doc_855437674538_item	2905059	et	4	main
liit	doc_855437674538_item	2905060	et	3	main
linnade	doc_855437674538_item	2905061	et	3	main
kuulusid	doc_855437674538_item	2905064	et	4	main
preisimaa	doc_855437674538_item	2905069	et	4	main
tartu	doc_855437674538_item	2905077	et	4	main
tegutses	doc_855437674538_item	2905082	et	3	main
sajandini	doc_855437674538_item	2905086	et	3	main
kehtestati	doc_860756017853_item	2905126	et	3	main
tsensuuri	doc_860756017853_item	2905127	et	4	main
kultuuritegelaste	doc_860756017853_item	2905128	et	3	main
elu	doc_860756017853_item	2905139	et	4	main
tuua	doc_860756017853_item	2905147	et	3	main
nn	doc_860756017853_item	2905150	et	4	main
inimesed	doc_860756017853_item	2905193	et	3	main
ei	doc_860756017853_item	2905202	et	4	main
ei	doc_860756017853_item	2905209	et	4	main
rohkem	doc_860756017853_item	2905230	et	4	main
proosa	doc_860756017853_item	2905236	et	4	main
m	doc_860756017853_item	2905246	et	4	main
traat	doc_860756017853_item	2905247	et	3	main
ja	doc_860756017853_item	2905248	et	3	main
teatris	doc_860756017853_item	2905263	et	3	main
j	doc_860756017853_item	2905272	et	4	main
ü	doc_860756017853_item	2905274	et	4	main
vilimaa	doc_860756017853_item	2905275	et	4	main
ja	doc_860756017853_item	2905276	et	3	main
lavastajad	doc_860756017853_item	2905281	et	4	main
laius	doc_860756017853_item	2905286	et	4	main
müür	doc_860756017853_item	2905287	et	3	main
ja	doc_860756017853_item	2905288	et	3	main
k	doc_860756017853_item	2905289	et	4	main
kiisk	doc_860756017853_item	2905290	et	3	main
k	doc_860756017853_item	2905294	et	4	main
valge	doc_860756017853_item	2905296	et	4	main
laev	doc_860756017853_item	2905297	et	3	main
inimesed	doc_854846908873_item	2904830	et	3	main
elasid	doc_854846908873_item	2904831	et	4	main
inimesed	doc_854846908873_item	2904841	et	3	main
ja	doc_854846908873_item	2904845	et	3	main
oder	doc_854846908873_item	2904860	et	3	main
aitasid	doc_854846908873_item	2904863	et	4	main
vilja	doc_854846908873_item	2904867	et	4	main
pärast	doc_854846908873_item	2904871	et	4	main
seda	doc_854846908873_item	2904872	et	3	main
müüdi	doc_854846908873_item	2904873	et	4	main
inimesed	doc_854846908873_item	2904874	et	3	main
kaitsta	doc_854846908873_item	2904880	et	4	main
kultuuriloost	doc_855437674538_item	2904895	et	4	main
hansa	doc_855437674538_item	2904906	et	4	main
liit	doc_855437674538_item	2904907	et	3	main
külaelanikud	doc_855437674538_item	2904916	et	3	main
säilitajateks	doc_855437674538_item	2904923	et	4	main
raskesti	doc_855437674538_item	2904933	et	3	main
eesti	doc_855437674538_item	2904946	et	4	main
talupoegkond	doc_855437674538_item	2904947	et	3	main
võttis	doc_855437674538_item	2904948	et	3	main
pühakultuse	doc_855437674538_item	2904951	et	3	main
surnute	doc_855437674538_item	2904960	et	4	main
austamine	doc_855437674538_item	2904961	et	4	main
pandi	doc_855437674538_item	2904963	et	4	main
kaas	doc_855437674538_item	2904964	et	3	main
tööriistu	doc_855437674538_item	2904965	et	3	main
ja	doc_855437674538_item	2904966	et	3	main
ehteid	doc_855437674538_item	2904967	et	3	main
vajalikud	doc_855437674538_item	2904968	et	3	main
tagapoolseks	doc_855437674538_item	2904969	et	4	main
eluks	doc_855437674538_item	2904970	et	3	main
allikate	doc_855437674538_item	2904971	et	3	main
kuna	doc_855437674538_item	2904976	et	3	main
armastanud	doc_855437674538_item	2904979	et	4	main
kõik	doc_855437674538_item	2904983	et	4	main
linnaelanikud	doc_855437674538_item	2905023	et	3	main
eestlased	doc_855437674538_item	2905025	et	3	main
seas	doc_855437674538_item	2905033	et	4	main
mis	doc_855437674538_item	2905041	et	4	main
anti	doc_855437674538_item	2905042	et	3	main
edasi	doc_855437674538_item	2905043	et	3	main
säilitasid	doc_855437674538_item	2905048	et	4	main
jne	doc_855437674538_item	2905052	et	4	main
madalmaaa	doc_855437674538_item	2905066	et	4	main
linnad	doc_855437674538_item	2905070	et	3	main
liidus	doc_855437674538_item	2905074	et	4	main
olid	doc_855437674538_item	2905075	et	4	main
hansa	doc_855437674538_item	2905080	et	4	main
16	doc_855437674538_item	2905085	et	2	main
tähtsamaid	doc_855437674538_item	2905088	et	4	main
kontrolltöö	doc_860756017853_item	2905090	et	4	main
loomulikult	doc_860756017853_item	2905121	et	4	main
see	doc_860756017853_item	2905123	et	3	main
ka	doc_860756017853_item	2905124	et	3	main
kultuurielus	doc_860756017853_item	2905125	et	4	main
ja	doc_860756017853_item	2905133	et	3	main
ilma	doc_860756017853_item	2905140	et	4	main
said	doc_860756017853_item	2905155	et	4	main
kokku	doc_860756017853_item	2905156	et	3	main
noored	doc_860756017853_item	2905157	et	3	main
kultuuritegelased	doc_860756017853_item	2905158	et	3	main
nüüdsest	doc_860756017853_item	2905159	et	3	main
alates	doc_860756017853_item	2905160	et	3	main
oli	doc_860756017853_item	2905161	et	3	main
võimalik	doc_860756017853_item	2905162	et	3	main
kes	doc_860756017853_item	2905183	et	4	main
madrus	doc_860756017853_item	2905187	et	3	main
pääsesid	doc_860756017853_item	2905189	et	4	main
nõukogudele	doc_860756017853_item	2905191	et	3	main
seda	doc_860756017853_item	2905194	et	3	main
seisaku	doc_860756017853_item	2905198	et	4	main
kuid	doc_860756017853_item	2905200	et	4	main
öelda	doc_860756017853_item	2905204	et	4	main
et	doc_860756017853_item	2905205	et	3	main
üldine	doc_860756017853_item	2905212	et	4	main
tase	doc_860756017853_item	2905216	et	3	main
oli	doc_860756017853_item	2905217	et	3	main
stabiilne	doc_860756017853_item	2905219	et	3	main
ja	doc_860756017853_item	2905220	et	3	main
kõrge	doc_860756017853_item	2905221	et	4	main
oli	doc_854846908873_item	2904868	et	3	main
mille	doc_854846908873_item	2904870	et	3	main
loomulikult	doc_854846908873_item	2904878	et	4	main
varat	doc_854846908873_item	2904882	et	4	main
2	doc_854846908873_item	2904883	et	2	main
muinasaeg	doc_854846908873_item	2904884	et	3	main
ajavahemik	doc_854846908873_item	2904885	et	3	main
mis	doc_854846908873_item	2904886	et	4	main
kontrolltöö	doc_855437674538_item	2904893	et	4	main
mis	doc_855437674538_item	2904897	et	4	main
säilimist	doc_855437674538_item	2904900	et	4	main
2	doc_855437674538_item	2904903	et	2	main
eestlaste	doc_855437674538_item	2904911	et	4	main
juures	doc_855437674538_item	2904902	et	4	main
mis	doc_855437674538_item	2904904	et	4	main
oli	doc_855437674538_item	2904905	et	3	main
juures	doc_855437674538_item	2904912	et	4	main
iseloom	doc_855437674538_item	2904915	et	3	main
muinasusundi	doc_855437674538_item	2904922	et	3	main
säilitas	doc_855437674538_item	2904925	et	3	main
juures	doc_855437674538_item	2904927	et	4	main
sellepärast	doc_855437674538_item	2904928	et	3	main
et	doc_855437674538_item	2904929	et	3	main
põhjustel	doc_855437674538_item	2904940	et	3	main
kõigepealt	doc_855437674538_item	2904949	et	3	main
ja	doc_855437674538_item	2904952	et	3	main
seda	doc_855437674538_item	2904954	et	3	main
rahvatraditsiooniga	doc_855437674538_item	2904956	et	3	main
liivlased	doc_855437674538_item	2904977	et	3	main
soodustas	doc_855437674538_item	2904985	et	3	main
muinasusundi	doc_855437674538_item	2904986	et	3	main
liivimaal	doc_855437674538_item	2905021	et	4	main
talupojad	doc_855437674538_item	2905026	et	4	main
talupojad	doc_855437674538_item	2905028	et	4	main
kuulusid	doc_855437674538_item	2905029	et	4	main
olid	doc_855437674538_item	2905034	et	4	main
populaarsed	doc_855437674538_item	2905035	et	3	main
põlvest	doc_855437674538_item	2905044	et	4	main
säilis	doc_855437674538_item	2905054	et	4	main
põlisrahva	doc_855437674538_item	2905055	et	3	main
etnilise	doc_855437674538_item	2905056	et	3	main
eripära	doc_855437674538_item	2905057	et	4	main
2	doc_855437674538_item	2905058	et	2	main
põhja-saksa	doc_855437674538_item	2905065	et	4	main
tallinn	doc_855437674538_item	2905076	et	4	main
liit	doc_855437674538_item	2905081	et	3	main
kaupmeeste	doc_855437674538_item	2905087	et	4	main
linnad	doc_855437674538_item	2905089	et	3	main
1	doc_860756017853_item	2905091	et	2	main
kultuurielu	doc_860756017853_item	2905092	et	4	main
võtsid	doc_855437674538_item	2904931	et	4	main
väga	doc_855437674538_item	2904932	et	3	main
vastu	doc_855437674538_item	2904935	et	3	main
üle	doc_855437674538_item	2904950	et	3	main
kokku	doc_855437674538_item	2904955	et	3	main
rahvatraditsioonide	doc_855437674538_item	2904957	et	3	main
säilis	doc_855437674538_item	2904974	et	4	main
ei	doc_855437674538_item	2904978	et	4	main
muutusi	doc_855437674538_item	2904980	et	4	main
oma	doc_855437674538_item	2904981	et	4	main
eestlaste	doc_855437674538_item	2904988	et	4	main
juures	doc_855437674538_item	2904989	et	4	main
eestlased	doc_855437674538_item	2904990	et	3	main
kaua	doc_855437674538_item	2904991	et	3	main
aega	doc_855437674538_item	2904992	et	4	main
ei	doc_855437674538_item	2904993	et	4	main
tahtnud	doc_855437674538_item	2904994	et	4	main
võtta	doc_855437674538_item	2904995	et	3	main
ristiusu	doc_855437674538_item	2904996	et	3	main
vastu	doc_855437674538_item	2904997	et	3	main
nad	doc_855437674538_item	2904998	et	3	main
isegi	doc_855437674538_item	2904999	et	4	main
aastal	doc_855437674538_item	2905001	et	3	main
alustasid	doc_855437674538_item	2905002	et	4	main
1343	doc_855437674538_item	2905000	et	2	main
vabadussõda	doc_855437674538_item	2905003	et	4	main
oma	doc_855437674538_item	2905004	et	4	main
õiguste	doc_855437674538_item	2905005	et	4	main
eest	doc_855437674538_item	2905006	et	4	main
kuid	doc_855437674538_item	2905007	et	4	main
kaotasid	doc_855437674538_item	2905008	et	4	main
1345	doc_855437674538_item	2905009	et	2	main
aastal	doc_855437674538_item	2905010	et	3	main
kuna	doc_855437674538_item	2905011	et	3	main
talupojad	doc_855437674538_item	2905012	et	4	main
elasid	doc_855437674538_item	2905013	et	4	main
koguaeg	doc_855437674538_item	2905014	et	3	main
maal	doc_855437674538_item	2905015	et	4	main
peamiselt	doc_855437674538_item	2905016	et	4	main
suurperedena	doc_855437674538_item	2905017	et	3	main
külas	doc_855437674538_item	2905018	et	3	main
keskajal	doc_855437674538_item	2905019	et	3	main
elasid	doc_855437674538_item	2905020	et	4	main
madalama	doc_855437674538_item	2905030	et	4	main
sälmid	doc_855437674538_item	2905036	et	4	main
põlve	doc_855437674538_item	2905045	et	4	main
muinasusundi	doc_855437674538_item	2905049	et	3	main
tavasid	doc_855437674538_item	2905051	et	3	main
maal	doc_855437674538_item	2905053	et	4	main
eestlaste	doc_855437674538_item	2904926	et	4	main
talupojad	doc_855437674538_item	2904930	et	4	main
enamik	doc_855437674538_item	2904941	et	3	main
sobtas	doc_855437674538_item	2904953	et	4	main
kuulusid	doc_855437674538_item	2904959	et	4	main
surnuile	doc_855437674538_item	2904962	et	4	main
edasi	doc_855437674538_item	2904975	et	3	main
see	doc_855437674538_item	2904984	et	3	main
säilimist	doc_855437674538_item	2904987	et	4	main
sakslased	doc_855437674538_item	2905022	et	3	main
ja	doc_855437674538_item	2905024	et	3	main
klassi	doc_855437674538_item	2905031	et	4	main
relikviiad	doc_855437674538_item	2905037	et	4	main
rahvapärimused	doc_855437674538_item	2905038	et	3	main
ja	doc_855437674538_item	2905039	et	3	main
elukogumised	doc_855437674538_item	2905040	et	4	main
selle	doc_855437674538_item	2905046	et	4	main
abil	doc_855437674538_item	2905047	et	4	main
liit	doc_855437674538_item	2905062	et	3	main
ja	doc_855437674538_item	2905068	et	3	main
praegusest	doc_855437674538_item	2905071	et	3	main
hansa	doc_855437674538_item	2905073	et	4	main
13	doc_855437674538_item	2905083	et	2	main
1970ndate	doc_860756017853_item	2905093	et	4	main
eesti	doc_860756017853_item	2905094	et	4	main
nsvs	doc_860756017853_item	2905095	et	4	main
2	doc_860756017853_item	2905096	et	2	main
valgus	doc_860756017853_item	2905097	et	4	main
koordis	doc_860756017853_item	2905098	et	4	main
kui	doc_860756017853_item	2905099	et	3	main
sotsialistliku	doc_860756017853_item	2905100	et	3	main
realismi	doc_860756017853_item	2905101	et	4	main
musternäidis	doc_860756017853_item	2905102	et	4	main
1	doc_860756017853_item	2905103	et	2	main
1968	doc_860756017853_item	2905104	et	2	main
a	doc_860756017853_item	2905105	et	4	main
sündmused	doc_860756017853_item	2905106	et	3	main
tšehhoslovaakias	doc_860756017853_item	2905107	et	2	main
mõjusid	doc_860756017853_item	2905108	et	4	main
kõikide	doc_860756017853_item	2905109	et	4	main
väikede	doc_860756017853_item	2905110	et	4	main
nsv-liidu	doc_860756017853_item	2905111	et	3	main
riikide	doc_860756017853_item	2905112	et	3	main
staatust	doc_860756017853_item	2905113	et	3	main
hakkas	doc_860756017853_item	2905114	et	3	main
tasapisi	doc_860756017853_item	2905115	et	3	main
levima	doc_860756017853_item	2905116	et	3	main
diktatuuri	doc_860756017853_item	2905117	et	4	main
kõikides	doc_860756017853_item	2905119	et	4	main
valdkondades	doc_860756017853_item	2905120	et	3	main
süvenemine	doc_860756017853_item	2905118	et	4	main
vahel	doc_860756017853_item	2905129	et	4	main
hakkas	doc_860756017853_item	2905130	et	3	main
diktaadita	doc_860756017853_item	2905141	et	3	main
1968	doc_860756017853_item	2905148	et	2	main
lavakeelu	doc_860756017853_item	2905164	et	3	main
varem	doc_860756017853_item	2905185	et	4	main
lojaalsed	doc_860756017853_item	2905192	et	3	main
perioodi	doc_860756017853_item	2905195	et	4	main
saa	doc_860756017853_item	2905203	et	4	main
arenenud	doc_860756017853_item	2905210	et	4	main
vastupidi	doc_860756017853_item	2905211	et	3	main
kuhu	doc_855437674538_item	2905063	et	3	main
liivimaa	doc_855437674538_item	2905067	et	4	main
eestist	doc_855437674538_item	2905072	et	3	main
narva	doc_855437674538_item	2905078	et	4	main
uus-pärnu	doc_855437674538_item	2905079	et	4	main
saj-st	doc_855437674538_item	2905084	et	3	main
levima	doc_860756017853_item	2905131	et	3	main
väljapääsmatuse	doc_860756017853_item	2905134	et	3	main
on	doc_860756017853_item	2905142	et	4	main
võimatu	doc_860756017853_item	2905143	et	4	main
üheks	doc_860756017853_item	2905144	et	3	main
näidiseks	doc_860756017853_item	2905145	et	3	main
a	doc_860756017853_item	2905149	et	4	main
tartu	doc_860756017853_item	2905151	et	4	main
sügist	doc_860756017853_item	2905152	et	3	main
üürituse	doc_860756017853_item	2905153	et	4	main
kus	doc_860756017853_item	2905154	et	3	main
oli	doc_860756017853_item	2905184	et	3	main
tavaline	doc_860756017853_item	2905186	et	4	main
tuntakse	doc_860756017853_item	2905196	et	3	main
aega	doc_860756017853_item	2905199	et	4	main
siiski	doc_860756017853_item	2905201	et	4	main
ajal	doc_860756017853_item	2905207	et	4	main
kultuur	doc_860756017853_item	2905208	et	3	main
ja	doc_860756017853_item	2905214	et	3	main
ikkagi	doc_860756017853_item	2905218	et	4	main
luule	doc_860756017853_item	2905231	et	4	main
siin	doc_860756017853_item	2905237	et	4	main
j	doc_860756017853_item	2905249	et	4	main
kino	doc_860756017853_item	2905260	et	4	main
endiselt	doc_860756017853_item	2905262	et	4	main
palju	doc_860756017853_item	2905265	et	4	main
toomingu	doc_860756017853_item	2905273	et	4	main
kino	doc_860756017853_item	2905280	et	4	main
töötas	doc_860756017853_item	2905293	et	3	main
ka	doc_860756017853_item	2905321	et	3	main
vaatamata	doc_860756017853_item	2905340	et	4	main
lääne	doc_860756017853_item	2905346	et	4	main
populaarsed	doc_860756017853_item	2905368	et	3	main
brežnevi	doc_860756017853_item	2905370	et	2	main
surma	doc_860756017853_item	2905371	et	4	main
võimule	doc_860756017853_item	2905372	et	3	main
tuli	doc_860756017853_item	2905373	et	4	main
alates	doc_860756017853_item	2905378	et	3	main
saab	doc_860756017853_item	2905379	et	3	main
stagnaperioodist	doc_860756017853_item	2905383	et	3	main
sest	doc_860756017853_item	2905438	et	4	main
tegelikult	doc_860756017853_item	2905446	et	4	main
üks	doc_860756017853_item	2905447	et	3	main
siis	doc_860756017853_item	2905458	et	3	main
aus	doc_860756017853_item	2905466	et	4	main
2	doc_860756017854_item	2905473	et	2	main
valgus	doc_860756017854_item	2905474	et	4	main
realismi	doc_860756017854_item	2905478	et	4	main
musternäidis	doc_860756017854_item	2905479	et	4	main
kultuurielu	doc_860756017854_item	2905481	et	4	main
are	doc_860756017854_item	2905488	et	3	main
kirjandus	doc_860756017854_item	2905489	et	3	main
muusika	doc_860756017854_item	2905490	et	4	main
ja	doc_860756017854_item	2905491	et	3	main
filmikunst	doc_860756017854_item	2905492	et	3	main
massiteava	doc_860756017854_item	2905493	et	4	main
armastasid	doc_860756017854_item	2905496	et	4	main
teatris	doc_860756017854_item	2905498	et	3	main
teisest	doc_860756017854_item	2905524	et	4	main
kõige	doc_860756017854_item	2905536	et	4	main
viimane	doc_860756017854_item	2905547	et	3	main
kordis	doc_860756017854_item	2905550	et	4	main
kirjanduses	doc_860756017854_item	2905551	et	3	main
said	doc_860756017854_item	2905552	et	4	main
proosakirjandusest	doc_860756017854_item	2905561	et	4	main
katku	doc_860756017854_item	2905571	et	4	main
vahel	doc_860756017854_item	2905572	et	4	main
kuid	doc_860756017854_item	2905573	et	4	main
tegi	doc_860756017854_item	2905607	et	4	main
tuntud	doc_860756017854_item	2905616	et	4	main
rezissör	doc_860756017854_item	2905618	et	4	main
muusika	doc_860756017854_item	2905630	et	4	main
arengule	doc_860756017854_item	2905631	et	3	main
paljud	doc_860756017854_item	2905632	et	3	main
teosed	doc_860756017854_item	2905633	et	3	main
kajastus	doc_860756017853_item	2905122	et	4	main
pessimis	doc_860756017853_item	2905132	et	4	main
tunne	doc_860756017853_item	2905135	et	4	main
sai	doc_860756017853_item	2905136	et	4	main
selgeks	doc_860756017853_item	2905137	et	3	main
et	doc_860756017853_item	2905138	et	3	main
võib	doc_860756017853_item	2905146	et	3	main
saada	doc_860756017853_item	2905163	et	4	main
ka	doc_860756017853_item	2905165	et	3	main
süütu	doc_860756017853_item	2905166	et	4	main
tegude	doc_860756017853_item	2905167	et	3	main
tartu	doc_860756017853_item	2905169	et	4	main
eest	doc_860756017853_item	2905168	et	4	main
ülikooli	doc_860756017853_item	2905170	et	4	main
rektoriks	doc_860756017853_item	2905171	et	3	main
oli	doc_860756017853_item	2905172	et	3	main
määratud	doc_860756017853_item	2905173	et	4	main
a	doc_860756017853_item	2905174	et	4	main
kroop	doc_860756017853_item	2905175	et	3	main
kellel	doc_860756017853_item	2905176	et	4	main
tegelikult	doc_860756017853_item	2905177	et	4	main
ei	doc_860756017853_item	2905178	et	4	main
olnud	doc_860756017853_item	2905179	et	4	main
vastavat	doc_860756017853_item	2905180	et	4	main
haridust	doc_860756017853_item	2905181	et	4	main
ja	doc_860756017853_item	2905182	et	3	main
nomenklatuuri	doc_860756017853_item	2905188	et	4	main
ainult	doc_860756017853_item	2905190	et	4	main
kui	doc_860756017853_item	2905197	et	3	main
sellel	doc_860756017853_item	2905206	et	4	main
kujutava-	doc_860756017853_item	2905213	et	4	main
helikunsti	doc_860756017853_item	2905215	et	4	main
sama	doc_860756017853_item	2905222	et	4	main
ka	doc_860756017853_item	2905224	et	3	main
siis	doc_860756017853_item	2905232	et	3	main
1970ndates	doc_860756017853_item	2905233	et	4	main
tuleb	doc_860756017853_item	2905238	et	3	main
kindlasti	doc_860756017853_item	2905239	et	3	main
nimetada	doc_860756017853_item	2905240	et	3	main
selliseid	doc_860756017853_item	2905241	et	4	main
pöörati	doc_860756017853_item	2905251	et	3	main
teater	doc_860756017853_item	2905258	et	3	main
lavastused	doc_860756017853_item	2905278	et	4	main
juba	doc_860756017853_item	2905283	et	3	main
1960ndates	doc_860756017853_item	2905284	et	4	main
kino	doc_860756017853_item	2905291	et	4	main
komissarov	doc_860756017853_item	2905295	et	4	main
muulased	doc_860756017853_item	2905325	et	4	main
on	doc_860756017853_item	2905331	et	4	main
võimalik	doc_860756017853_item	2905332	et	3	main
ja	doc_860756017853_item	2905333	et	3	main
arvasid	doc_860756017853_item	2905334	et	4	main
see	doc_860756017853_item	2905336	et	3	main
on	doc_860756017853_item	2905337	et	4	main
sellele	doc_860756017853_item	2905341	et	4	main
kultuuriareaaliga	doc_860756017853_item	2905347	et	3	main
üsna	doc_860756017853_item	2905351	et	3	main
pärast	doc_860756017853_item	2905369	et	4	main
ja	doc_860756017853_item	2905375	et	3	main
täielikusest	doc_860756017853_item	2905382	et	4	main
sotsialistliku	doc_860756017853_item	2905385	et	3	main
kino	doc_860756017853_item	2905425	et	4	main
aga	doc_860756017853_item	2905432	et	3	main
teadsid	doc_860756017853_item	2905439	et	4	main
et	doc_860756017853_item	2905440	et	3	main
kõik	doc_860756017853_item	2905441	et	4	main
mõeldis	doc_860756017853_item	2905449	et	3	main
ise	doc_860756017853_item	2905453	et	4	main
seda	doc_860756017853_item	2905455	et	3	main
näinud	doc_860756017853_item	2905457	et	4	main
mul	doc_860756017853_item	2905459	et	3	main
raske	doc_860756017853_item	2905462	et	4	main
kui	doc_860756017854_item	2905476	et	3	main
1	doc_860756017854_item	2905480	et	2	main
1970ndate	doc_860756017854_item	2905482	et	4	main
näidati	doc_860756017854_item	2905522	et	3	main
neist	doc_860756017854_item	2905535	et	4	main
lutsu	doc_860756017854_item	2905540	et	4	main
tehtud	doc_860756017854_item	2905543	et	4	main
kevade	doc_860756017854_item	2905546	et	4	main
valgus	doc_860756017854_item	2905549	et	4	main
under	doc_860756017854_item	2905556	et	4	main
k	doc_860756017854_item	2905557	et	4	main
lepik	doc_860756017854_item	2905558	et	3	main
i	doc_860756017854_item	2905559	et	4	main
oli	doc_860756017854_item	2905562	et	3	main
lugeda	doc_860756017854_item	2905564	et	3	main
romaane	doc_860756017854_item	2905566	et	3	main
nt	doc_860756017854_item	2905567	et	4	main
toimus	doc_860756017854_item	2905602	et	3	main
eest	doc_860756017854_item	2905603	et	4	main
tegelema	doc_860756017854_item	2905612	et	3	main
filmikunstiga	doc_860756017854_item	2905613	et	4	main
oli	doc_860756017854_item	2905614	et	3	main
samuti	doc_860756017854_item	2905615	et	3	main
filmikunsti	doc_860756017854_item	2905628	et	4	main
ja	doc_860756017854_item	2905629	et	3	main
eesti	doc_860756017854_item	2905637	et	4	main
ja	doc_860756017854_item	2905641	et	3	main
realismi	doc_860756017854_item	2905656	et	4	main
realismi	doc_860756017854_item	2905666	et	4	main
meile	doc_860756017854_item	2905671	et	4	main
tollest	doc_860756017854_item	2905673	et	4	main
ajast	doc_860756017854_item	2905674	et	4	main
sotsialistlik	doc_860756017854_item	2905675	et	3	main
realism	doc_860756017854_item	2905676	et	3	main
tollest	doc_860756017854_item	2905694	et	4	main
lähtekohad	doc_860756017854_item	2905698	et	4	main
filmis	doc_860756017854_item	2905703	et	4	main
realismi	doc_860756017854_item	2905709	et	4	main
tunnus	doc_860756017854_item	2905710	et	3	main
kommunistlik	doc_860756017854_item	2905711	et	3	main
kirjanduse	doc_860756017853_item	2905225	et	3	main
1960ndates	doc_860756017853_item	2905228	et	4	main
kirjutati	doc_860756017853_item	2905229	et	3	main
populaarseks	doc_860756017853_item	2905235	et	4	main
olid	doc_860756017853_item	2905245	et	4	main
kroos	doc_860756017853_item	2905250	et	4	main
rahvusliku	doc_860756017853_item	2905254	et	3	main
ja	doc_860756017853_item	2905259	et	3	main
töötasid	doc_860756017853_item	2905261	et	4	main
käis	doc_860756017853_item	2905264	et	4	main
inimesi	doc_860756017853_item	2905266	et	4	main
eriti	doc_860756017853_item	2905267	et	3	main
eestlasi	doc_860756017853_item	2905268	et	3	main
olid	doc_860756017853_item	2905269	et	4	main
väga	doc_860756017853_item	2905270	et	3	main
populaarsed	doc_860756017853_item	2905271	et	3	main
eesti	doc_860756017853_item	2905279	et	4	main
l	doc_860756017853_item	2905285	et	4	main
režissöörina	doc_860756017853_item	2905292	et	2	main
metskapten	doc_860756017853_item	2905298	et	3	main
kinos	doc_860756017853_item	2905299	et	3	main
aga	doc_860756017853_item	2905300	et	3	main
rohkem	doc_860756017853_item	2905301	et	4	main
käisid	doc_860756017853_item	2905302	et	4	main
muulased	doc_860756017853_item	2905303	et	4	main
tollal	doc_860756017853_item	2905304	et	3	main
oli	doc_860756017853_item	2905305	et	3	main
väga	doc_860756017853_item	2905306	et	3	main
populaarne	doc_860756017853_item	2905307	et	3	main
televisioon	doc_860756017853_item	2905308	et	4	main
eriti	doc_860756017853_item	2905309	et	3	main
meelelahutuslikud	doc_860756017853_item	2905310	et	3	main
saaded	doc_860756017853_item	2905311	et	4	main
ja	doc_860756017853_item	2905312	et	3	main
televiktoriinid	doc_860756017853_item	2905313	et	3	main
horoskoop	doc_860756017853_item	2905314	et	3	main
kaks	doc_860756017853_item	2905315	et	3	main
takti	doc_860756017853_item	2905316	et	4	main
ette	doc_860756017853_item	2905317	et	4	main
jne	doc_860756017853_item	2905318	et	4	main
põhja-eestis	doc_860756017853_item	2905319	et	3	main
vaadeti	doc_860756017853_item	2905320	et	4	main
soome	doc_860756017853_item	2905322	et	3	main
kuigi	doc_860756017853_item	2905324	et	3	main
ei	doc_860756017853_item	2905326	et	4	main
uskunud	doc_860756017853_item	2905327	et	4	main
et	doc_860756017853_item	2905328	et	3	main
et	doc_860756017853_item	2905335	et	3	main
siiski	doc_860756017853_item	2905343	et	4	main
kuigi	doc_860756017853_item	2905348	et	3	main
muutus	doc_860756017853_item	2905350	et	4	main
toimusid	doc_860756017853_item	2905361	et	4	main
teatud	doc_860756017853_item	2905362	et	4	main
muutused	doc_860756017853_item	2905363	et	4	main
aga	doc_860756017853_item	2905364	et	3	main
džässifestivalid	doc_860756017853_item	2905365	et	2	main
a-st	doc_860756017853_item	2905377	et	3	main
rääkida	doc_860756017853_item	2905380	et	3	main
käib	doc_860756017853_item	2905223	et	3	main
kohta	doc_860756017853_item	2905226	et	4	main
kui	doc_860756017853_item	2905227	et	3	main
sai	doc_860756017853_item	2905234	et	4	main
autoreid	doc_860756017853_item	2905242	et	4	main
nagu	doc_860756017853_item	2905243	et	3	main
need	doc_860756017853_item	2905244	et	3	main
suur	doc_860756017853_item	2905252	et	3	main
tähelepanu	doc_860756017853_item	2905253	et	4	main
ajaloo	doc_860756017853_item	2905255	et	4	main
vastu	doc_860756017853_item	2905256	et	3	main
ka	doc_860756017853_item	2905257	et	3	main
murdmaa	doc_860756017853_item	2905277	et	4	main
debuteerisid	doc_860756017853_item	2905282	et	4	main
selline	doc_860756017853_item	2905329	et	4	main
elu	doc_860756017853_item	2905330	et	4	main
püüti	doc_860756017853_item	2905342	et	3	main
hoida	doc_860756017853_item	2905345	et	3	main
see	doc_860756017853_item	2905349	et	3	main
keeruliseks	doc_860756017853_item	2905352	et	4	main
asjaks	doc_860756017853_item	2905353	et	3	main
aktiviseerusid	doc_860756017853_item	2905354	et	4	main
dissidendid	doc_860756017853_item	2905355	et	3	main
40	doc_860756017853_item	2905356	et	2	main
kiri	doc_860756017853_item	2905357	et	3	main
olid	doc_860756017853_item	2905366	et	4	main
andropov	doc_860756017853_item	2905374	et	4	main
oli	doc_860756017853_item	2905388	et	3	main
ülistada	doc_860756017853_item	2905389	et	3	main
hakkama	doc_860756017853_item	2905390	et	3	main
tekkinud	doc_860756017853_item	2905391	et	4	main
olukorda	doc_860756017853_item	2905392	et	4	main
kõik	doc_860756017853_item	2905393	et	4	main
pidid	doc_860756017853_item	2905394	et	4	main
mõtlema	doc_860756017853_item	2905395	et	3	main
et	doc_860756017853_item	2905396	et	3	main
elu	doc_860756017853_item	2905397	et	4	main
areneb	doc_860756017853_item	2905398	et	3	main
demokraatlikul	doc_860756017853_item	2905399	et	3	main
viisil	doc_860756017853_item	2905400	et	4	main
optimistlik	doc_860756017853_item	2905401	et	3	main
konflikt	doc_860756017853_item	2905402	et	3	main
seisnes	doc_860756017853_item	2905403	et	3	main
hea	doc_860756017853_item	2905404	et	4	main
ja	doc_860756017853_item	2905405	et	3	main
parema	doc_860756017853_item	2905406	et	4	main
vahel	doc_860756017853_item	2905407	et	4	main
kehtis	doc_860756017853_item	2905408	et	3	main
range	doc_860756017853_item	2905409	et	4	main
tsensuur	doc_860756017853_item	2905410	et	3	main
kõik	doc_860756017853_item	2905411	et	4	main
elu	doc_860756017853_item	2905412	et	4	main
peegeldavad	doc_860756017853_item	2905413	et	4	main
valdkonnad	doc_860756017853_item	2905414	et	4	main
kirjandus	doc_860756017853_item	2905415	et	3	main
kino	doc_860756017853_item	2905416	et	4	main
muusika	doc_860756017853_item	2905417	et	4	main
ja	doc_860756017853_item	2905418	et	3	main
teatri	doc_860756017853_item	2905419	et	3	main
lavastused	doc_860756017853_item	2905420	et	4	main
pidid	doc_860756017853_item	2905421	et	4	main
mudelile	doc_860756017853_item	2905424	et	3	main
televisiooni	doc_860756017853_item	2905323	et	4	main
lihtsalt	doc_860756017853_item	2905338	et	4	main
propaganda	doc_860756017853_item	2905339	et	4	main
sidet	doc_860756017853_item	2905344	et	4	main
pravdale	doc_860756017853_item	2905358	et	4	main
ka	doc_860756017853_item	2905359	et	3	main
muusikas	doc_860756017853_item	2905360	et	3	main
endiselt	doc_860756017853_item	2905367	et	4	main
1983	doc_860756017853_item	2905376	et	2	main
juba	doc_860756017853_item	2905381	et	3	main
2	doc_860756017853_item	2905384	et	2	main
vastama	doc_860756017853_item	2905422	et	3	main
sotsialistlikule	doc_860756017853_item	2905423	et	3	main
seda	doc_860756017853_item	2905433	et	3	main
välja	doc_860756017853_item	2905448	et	4	main
aga	doc_860756017853_item	2905450	et	3	main
pole	doc_860756017853_item	2905454	et	3	main
filmi	doc_860756017853_item	2905456	et	4	main
on	doc_860756017853_item	2905460	et	4	main
kontrolltöö	doc_860756017854_item	2905467	et	4	main
1	doc_860756017854_item	2905468	et	2	main
kultuurielu	doc_860756017854_item	2905469	et	4	main
koordis	doc_860756017854_item	2905475	et	4	main
nsvs	doc_860756017854_item	2905484	et	4	main
hakkasid	doc_860756017854_item	2905485	et	4	main
arenema	doc_860756017854_item	2905486	et	3	main
suurt	doc_860756017854_item	2905487	et	3	main
eestlased	doc_860756017854_item	2905495	et	3	main
realismi	doc_860756017853_item	2905386	et	4	main
ülesandeks	doc_860756017853_item	2905387	et	4	main
ongi	doc_860756017853_item	2905428	et	4	main
selle	doc_860756017853_item	2905429	et	4	main
näidiseks	doc_860756017853_item	2905430	et	3	main
eestlased	doc_860756017853_item	2905431	et	3	main
filmi	doc_860756017853_item	2905434	et	4	main
eriti	doc_860756017853_item	2905435	et	3	main
ei	doc_860756017853_item	2905436	et	4	main
mis	doc_860756017853_item	2905442	et	4	main
kuna	doc_860756017853_item	2905451	et	3	main
nsvs	doc_860756017854_item	2905472	et	4	main
eesti	doc_860756017854_item	2905483	et	4	main
kuid	doc_860756017854_item	2905499	et	4	main
muulased	doc_860756017854_item	2905500	et	4	main
kinos	doc_860756017854_item	2905501	et	3	main
1970ndal	doc_860756017854_item	2905502	et	4	main
olid	doc_860756017854_item	2905503	et	4	main
raamatud	doc_860756017854_item	2905504	et	4	main
kättesaadavad	doc_860756017854_item	2905505	et	3	main
ja	doc_860756017854_item	2905506	et	3	main
odava	doc_860756017854_item	2905507	et	3	main
ostei	doc_860756017854_item	2905509	et	4	main
palju	doc_860756017854_item	2905508	et	4	main
ja	doc_860756017854_item	2905510	et	3	main
loeti	doc_860756017854_item	2905511	et	3	main
raamatuid	doc_860756017854_item	2905512	et	3	main
ajalehti	doc_860756017854_item	2905513	et	4	main
samuti	doc_860756017854_item	2905514	et	3	main
põhja-eestis	doc_860756017854_item	2905515	et	3	main
oli	doc_860756017854_item	2905516	et	3	main
populaarsed	doc_860756017854_item	2905517	et	3	main
soome	doc_860756017854_item	2905518	et	3	main
telesaateid	doc_860756017854_item	2905519	et	3	main
sest	doc_860756017854_item	2905520	et	4	main
seal	doc_860756017854_item	2905521	et	4	main
elu	doc_860756017854_item	2905523	et	4	main
paremast	doc_860756017854_item	2905526	et	4	main
uudiseid	doc_860756017854_item	2905529	et	3	main
tuntumad	doc_860756017854_item	2905537	et	4	main
on	doc_860756017854_item	2905538	et	4	main
teose	doc_860756017854_item	2905541	et	3	main
reliikvia	doc_860756017854_item	2905548	et	4	main
maria	doc_860756017854_item	2905555	et	4	main
kolme	doc_860756017854_item	2905570	et	4	main
esimest	doc_860756017854_item	2905600	et	4	main
kes	doc_860756017854_item	2905609	et	4	main
hiljem	doc_860756017854_item	2905610	et	3	main
hakkas	doc_860756017854_item	2905611	et	3	main
filmi	doc_860756017854_item	2905617	et	4	main
kultuurielu	doc_860756017854_item	2905619	et	4	main
1970ndatel	doc_860756017854_item	2905620	et	4	main
valgus	doc_860756017853_item	2905426	et	4	main
koordis	doc_860756017853_item	2905427	et	4	main
vaadanud	doc_860756017853_item	2905437	et	4	main
seal	doc_860756017853_item	2905443	et	4	main
näidatakse	doc_860756017853_item	2905444	et	3	main
oli	doc_860756017853_item	2905445	et	3	main
ma	doc_860756017853_item	2905452	et	3	main
väga	doc_860756017853_item	2905461	et	3	main
seda	doc_860756017853_item	2905463	et	3	main
komenteerima	doc_860756017853_item	2905464	et	4	main
vähemalt	doc_860756017853_item	2905465	et	4	main
1970ndate	doc_860756017854_item	2905470	et	4	main
eesti	doc_860756017854_item	2905471	et	4	main
sotsialistliku	doc_860756017854_item	2905477	et	3	main
jne	doc_860756017854_item	2905494	et	4	main
käis	doc_860756017854_item	2905497	et	4	main
küljest	doc_860756017854_item	2905525	et	4	main
samuti	doc_860756017854_item	2905527	et	3	main
vaadati	doc_860756017854_item	2905528	et	3	main
1970ndatel	doc_860756017854_item	2905530	et	4	main
tehti	doc_860756017854_item	2905531	et	3	main
palju	doc_860756017854_item	2905532	et	4	main
põhjal	doc_860756017854_item	2905542	et	4	main
kruusemendi	doc_860756017854_item	2905544	et	4	main
film	doc_860756017854_item	2905545	et	3	main
luuletajad	doc_860756017854_item	2905554	et	4	main
ivask	doc_860756017854_item	2905560	et	4	main
korda	doc_860756017854_item	2905601	et	4	main
nsvs	doc_860756017854_item	2905604	et	4	main
džassfestival	doc_860756017854_item	2905605	et	2	main
lavaetendusi	doc_860756017854_item	2905606	et	3	main
aastatel	doc_860756017854_item	2905621	et	4	main
nsvs	doc_860756017854_item	2905623	et	4	main
avaldas	doc_860756017854_item	2905624	et	3	main
mõju	doc_860756017854_item	2905625	et	4	main
edasisele	doc_860756017854_item	2905626	et	3	main
on	doc_860756017854_item	2905635	et	4	main
neid	doc_860756017854_item	2905639	et	4	main
elu	doc_860756017854_item	2905648	et	4	main
eesti	doc_860756017854_item	2905649	et	4	main
valgus	doc_860756017854_item	2905659	et	4	main
ajal	doc_860756017854_item	2905667	et	4	main
ning	doc_860756017854_item	2905668	et	3	main
kunstivool	doc_860756017854_item	2905678	et	4	main
martistlikud	doc_860756017854_item	2905680	et	4	main
valgus	doc_860756017854_item	2905690	et	4	main
sotsialismist	doc_860756017854_item	2905701	et	4	main
on	doc_860756017854_item	2905706	et	4	main
realismi	doc_860756017855_item	2905728	et	4	main
populaarseks	doc_860756017855_item	2905735	et	4	main
ja	doc_860756017855_item	2905736	et	3	main
lastesadeid	doc_860756017855_item	2905742	et	4	main
reklaame	doc_860756017855_item	2905743	et	3	main
viktoriinimänge	doc_860756017855_item	2905744	et	3	main
kooskäimine	doc_860756017855_item	2905752	et	4	main
ole	doc_860756017855_item	2905756	et	4	main
moes	doc_860756017855_item	2905758	et	3	main
eelistavad	doc_860756017855_item	2905760	et	4	main
televiisori	doc_860756017855_item	2905761	et	4	main
televisiooni	doc_860756017855_item	2905766	et	4	main
tegelased	doc_860756017855_item	2905767	et	3	main
uno	doc_860756017855_item	2905771	et	4	main
jaoks	doc_860756017855_item	2905815	et	4	main
oli	doc_860756017855_item	2905827	et	3	main
keelatud	doc_860756017855_item	2905828	et	4	main
tõlgitud	doc_860756017855_item	2905837	et	4	main
soodustas	doc_860756017855_item	2905841	et	3	main
kirjutamist	doc_860756017855_item	2905844	et	4	main
oli	doc_860756017855_item	2905846	et	3	main
olema	doc_860756017855_item	2905852	et	4	main
keelati	doc_860756017855_item	2905858	et	4	main
sest	doc_860756017855_item	2905860	et	4	main
lauljad	doc_860756017855_item	2905861	et	4	main
muudatus	doc_860756017855_item	2905870	et	4	main
vahetati	doc_860756017855_item	2905873	et	4	main
uus	doc_860756017855_item	2905875	et	3	main
rektor	doc_860756017855_item	2905876	et	3	main
oli	doc_860756017855_item	2905877	et	3	main
ta	doc_860756017855_item	2905880	et	4	main
oli	doc_860756017855_item	2905881	et	3	main
meremees	doc_860756017855_item	2905882	et	4	main
eesti	doc_860756017854_item	2905533	et	4	main
filme	doc_860756017854_item	2905534	et	3	main
o	doc_860756017854_item	2905539	et	4	main
tuntuks	doc_860756017854_item	2905553	et	4	main
võimalik	doc_860756017854_item	2905563	et	3	main
ajaloolisi	doc_860756017854_item	2905565	et	4	main
j	doc_860756017854_item	2905568	et	4	main
kross	doc_860756017854_item	2905569	et	3	main
kõige	doc_860756017854_item	2905574	et	4	main
iseloomulikum	doc_860756017854_item	2905575	et	4	main
oli	doc_860756017854_item	2905576	et	3	main
sel	doc_860756017854_item	2905577	et	3	main
perioodil	doc_860756017854_item	2905578	et	3	main
luule	doc_860756017854_item	2905579	et	4	main
kirjutamine	doc_860756017854_item	2905580	et	4	main
luuletajad	doc_860756017854_item	2905581	et	4	main
rummo	doc_860756017854_item	2905582	et	4	main
triik	doc_860756017854_item	2905583	et	4	main
tuntud	doc_860756017854_item	2905584	et	4	main
teos	doc_860756017854_item	2905585	et	4	main
mäeküla	doc_860756017854_item	2905586	et	4	main
piimamees	doc_860756017854_item	2905587	et	4	main
eesti	doc_860756017854_item	2905588	et	4	main
nsvs	doc_860756017854_item	2905589	et	4	main
hakati	doc_860756017854_item	2905590	et	3	main
korraldama	doc_860756017854_item	2905591	et	3	main
esimesi	doc_860756017854_item	2905592	et	4	main
lauluvõistlusi	doc_860756017854_item	2905593	et	3	main
nii	doc_860756017854_item	2905594	et	3	main
moortele	doc_860756017854_item	2905595	et	4	main
kui	doc_860756017854_item	2905596	et	3	main
lastele	doc_860756017854_item	2905597	et	4	main
1970ndatel	doc_860756017854_item	2905598	et	4	main
aastal	doc_860756017854_item	2905599	et	3	main
komissarov	doc_860756017854_item	2905608	et	4	main
kunsti	doc_860756017854_item	2905627	et	4	main
läinud	doc_860756017854_item	2905636	et	4	main
loetakse	doc_860756017854_item	2905640	et	3	main
nad	doc_860756017854_item	2905643	et	3	main
paremini	doc_860756017854_item	2905645	et	4	main
iseloomustavad	doc_860756017854_item	2905646	et	4	main
2	doc_860756017854_item	2905651	et	2	main
valgus	doc_860756017854_item	2905652	et	4	main
näidimuster	doc_860756017854_item	2905657	et	4	main
kordis	doc_860756017854_item	2905660	et	4	main
käsitlenud	doc_860756017854_item	2905683	et	4	main
nii	doc_860756017854_item	2905684	et	3	main
nimetatud	doc_860756017854_item	2905685	et	4	main
loomingumeetodina	doc_860756017854_item	2905686	et	3	main
samamoodi	doc_860756017854_item	2905687	et	3	main
on	doc_860756017854_item	2905688	et	4	main
film	doc_860756017854_item	2905689	et	3	main
ajast	doc_860756017854_item	2905695	et	4	main
sotsialistliku	doc_860756017854_item	2905696	et	3	main
valgus	doc_860756017854_item	2905704	et	4	main
eesti	doc_860756017854_item	2905622	et	4	main
kultuuriajalukku	doc_860756017854_item	2905638	et	4	main
eestlaste	doc_860756017854_item	2905647	et	4	main
koordis	doc_860756017854_item	2905653	et	4	main
kui	doc_860756017854_item	2905654	et	3	main
sotsialistliku	doc_860756017854_item	2905655	et	3	main
sündmusi	doc_860756017854_item	2905662	et	3	main
sotsialistliku	doc_860756017854_item	2905665	et	3	main
see	doc_860756017854_item	2905669	et	3	main
on	doc_860756017854_item	2905677	et	4	main
on	doc_860756017854_item	2905682	et	4	main
realismi	doc_860756017854_item	2905697	et	4	main
pärinevad	doc_860756017854_item	2905699	et	4	main
utoplikust	doc_860756017854_item	2905700	et	4	main
koordis	doc_860756017854_item	2905705	et	4	main
rahvalikkus	doc_860756017854_item	2905713	et	4	main
ja	doc_860756017854_item	2905714	et	3	main
tegelikkuse	doc_860756017854_item	2905715	et	4	main
tõetruu	doc_860756017854_item	2905716	et	4	main
kontrolltöö	doc_860756017855_item	2905717	et	4	main
1	doc_860756017855_item	2905718	et	2	main
kultuurielu	doc_860756017855_item	2905719	et	4	main
1970ndate	doc_860756017855_item	2905720	et	4	main
musternäidis	doc_860756017855_item	2905729	et	4	main
oluliseks	doc_860756017855_item	2905737	et	4	main
ja	doc_860756017855_item	2905753	et	3	main
inimesed	doc_860756017855_item	2905759	et	3	main
1970	doc_860756017855_item	2905773	et	2	main
lava	doc_860756017855_item	2905814	et	4	main
popmuusika	doc_860756017855_item	2905826	et	4	main
võõrkeeles	doc_860756017855_item	2905833	et	4	main
kõik	doc_860756017855_item	2905834	et	4	main
pidi	doc_860756017855_item	2905835	et	4	main
eesti	doc_860756017855_item	2905838	et	4	main
oma	doc_860756017855_item	2905842	et	4	main
pidi	doc_860756017855_item	2905851	et	4	main
esinesid	doc_860756017855_item	2905862	et	4	main
tähtis	doc_860756017855_item	2905869	et	4	main
tü	doc_860756017855_item	2905872	et	4	main
rektorit	doc_860756017855_item	2905874	et	3	main
nõrga	doc_860756017855_item	2905878	et	3	main
jaoks	doc_860756017855_item	2905895	et	4	main
vene	doc_860756017855_item	2905933	et	4	main
haridusprogramm	doc_860756017855_item	2905934	et	3	main
eesti	doc_860756017855_item	2905948	et	4	main
koolides	doc_860756017855_item	2905949	et	3	main
õpiti	doc_860756017855_item	2905950	et	3	main
palju	doc_860756017855_item	2905951	et	4	main
nädalas	doc_860756017855_item	2905954	et	3	main
uus	doc_860756017855_item	2905972	et	3	main
labor	doc_860756017855_item	2905975	et	3	main
lauristin	doc_860756017855_item	2905981	et	4	main
kiiresti	doc_860756017855_item	2905984	et	3	main
70-ndatel	doc_860756017855_item	2905999	et	4	main
osta	doc_860756017855_item	2906006	et	4	main
said	doc_860756017855_item	2906028	et	4	main
a	doc_860756017855_item	2906040	et	4	main
andsid	doc_860756017855_item	2906050	et	4	main
eestlastel	doc_860756017855_item	2906051	et	4	main
võimaluse	doc_860756017855_item	2906052	et	3	main
soome	doc_860756017855_item	2906062	et	3	main
eestisse	doc_860756017855_item	2906075	et	4	main
mundi	doc_860756017855_item	2906085	et	4	main
rääkida	doc_860756017855_item	2906090	et	3	main
kirjutasid	doc_860756017855_item	2906105	et	4	main
olid	doc_860756017855_item	2906109	et	4	main
teosed	doc_860756017855_item	2906120	et	3	main
nt	doc_860756017855_item	2906137	et	4	main
ja	doc_860756017855_item	2906148	et	3	main
levinud	doc_860756017855_item	2906166	et	4	main
ajal	doc_860756017855_item	2906177	et	4	main
filmid	doc_860756017854_item	2905634	et	4	main
vaadatakse	doc_860756017854_item	2905642	et	3	main
kõige	doc_860756017854_item	2905644	et	4	main
nsvs	doc_860756017854_item	2905650	et	4	main
film	doc_860756017854_item	2905658	et	3	main
kajastab	doc_860756017854_item	2905661	et	3	main
mis	doc_860756017854_item	2905663	et	4	main
toimusid	doc_860756017854_item	2905664	et	4	main
annab	doc_860756017854_item	2905670	et	3	main
ettekujutuse	doc_860756017854_item	2905672	et	4	main
mida	doc_860756017854_item	2905679	et	4	main
kunstiteadlased	doc_860756017854_item	2905681	et	3	main
koordis	doc_860756017854_item	2905691	et	4	main
hea	doc_860756017854_item	2905692	et	4	main
näide	doc_860756017854_item	2905693	et	3	main
lenililt	doc_860756017854_item	2905702	et	4	main
näidatud	doc_860756017854_item	2905707	et	4	main
sotsialistliku	doc_860756017854_item	2905708	et	3	main
2	doc_860756017855_item	2905723	et	2	main
teleke	doc_860756017855_item	2905745	et	4	main
teleteatrilastusi	doc_860756017855_item	2905746	et	3	main
see	doc_860756017855_item	2905747	et	3	main
tendents	doc_860756017855_item	2905748	et	3	main
nõrgeneb	doc_860756017855_item	2905749	et	3	main
eesti	doc_860756017855_item	2905750	et	4	main
kultuurüritused	doc_860756017855_item	2905754	et	3	main
enam	doc_860756017855_item	2905757	et	4	main
aja	doc_860756017855_item	2905764	et	4	main
tuntud	doc_860756017855_item	2905765	et	4	main
valdo	doc_860756017855_item	2905769	et	4	main
pant	doc_860756017855_item	2905770	et	3	main
sest	doc_860756017855_item	2905778	et	4	main
arenes	doc_860756017855_item	2905780	et	3	main
mis	doc_860756017855_item	2905810	et	4	main
läbimõeldud	doc_860756017855_item	2905816	et	4	main
kirjutati	doc_860756017855_item	2905817	et	3	main
palju	doc_860756017855_item	2905818	et	4	main
klassikalise	doc_860756017855_item	2905822	et	4	main
lähedased	doc_860756017855_item	2905824	et	3	main
põhiliselt	doc_860756017855_item	2905830	et	4	main
oli	doc_860756017855_item	2905831	et	3	main
olema	doc_860756017855_item	2905836	et	4	main
keelati	doc_860756017855_item	2905848	et	4	main
näiteks	doc_860756017855_item	2905859	et	4	main
et	doc_860756017855_item	2905871	et	3	main
pärast	doc_860756017855_item	2905887	et	4	main
ei	doc_860756017855_item	2905890	et	4	main
eriti	doc_860756017855_item	2905892	et	3	main
hariduse	doc_860756017855_item	2905924	et	3	main
võiks	doc_860756017855_item	2905926	et	4	main
ka	doc_860756017855_item	2905928	et	3	main
see	doc_860756017855_item	2905929	et	3	main
et	doc_860756017855_item	2905930	et	3	main
eesti	doc_860756017855_item	2905931	et	4	main
ja	doc_860756017855_item	2905932	et	3	main
langenud	doc_860756017855_item	2905936	et	4	main
10	doc_860756017855_item	2905941	et	2	main
aga	doc_860756017855_item	2905943	et	3	main
keelt	doc_860756017855_item	2905953	et	4	main
vene	doc_860756017855_item	2905958	et	4	main
eesti	doc_860756017855_item	2905962	et	4	main
ja	doc_860756017855_item	2905963	et	3	main
ajal	doc_860756017855_item	2905971	et	4	main
sotsioloogia	doc_860756017855_item	2905974	et	4	main
väga	doc_860756017855_item	2905983	et	3	main
ja	doc_860756017855_item	2905989	et	3	main
aastatel	doc_860756017855_item	2906000	et	4	main
paranes	doc_860756017855_item	2906001	et	3	main
inimeste	doc_860756017855_item	2906002	et	3	main
järelmaksuga	doc_860756017855_item	2906007	et	3	main
luksuskaubadele	doc_860756017855_item	2906014	et	4	main
külmkapp	doc_860756017855_item	2906016	et	3	main
1973	doc_860756017855_item	2906033	et	2	main
1	doc_860756017855_item	2906036	et	2	main
keelne	doc_860756017855_item	2906043	et	3	main
vaadata	doc_860756017855_item	2906067	et	4	main
mis	doc_860756017855_item	2906073	et	4	main
toob	doc_860756017855_item	2906074	et	3	main
valutakauplusi	doc_860756017855_item	2906083	et	4	main
kus	doc_860756017855_item	2906084	et	3	main
kui	doc_860756017855_item	2906089	et	3	main
parteilisus	doc_860756017854_item	2905712	et	4	main
eesti	doc_860756017855_item	2905721	et	4	main
valgus	doc_860756017855_item	2905724	et	4	main
koordis	doc_860756017855_item	2905725	et	4	main
kui	doc_860756017855_item	2905726	et	3	main
sotsialistliku	doc_860756017855_item	2905727	et	3	main
kultuurielus	doc_860756017855_item	2905733	et	4	main
saab	doc_860756017855_item	2905734	et	3	main
huvitavaid	doc_860756017855_item	2905741	et	4	main
ei	doc_860756017855_item	2905755	et	4	main
selle	doc_860756017855_item	2905763	et	4	main
on	doc_860756017855_item	2905768	et	4	main
alates	doc_860756017855_item	2905774	et	3	main
migratsioon	doc_860756017855_item	2905776	et	3	main
ei	doc_860756017855_item	2905811	et	4	main
muusika	doc_860756017855_item	2905823	et	4	main
kerge	doc_860756017855_item	2905825	et	4	main
ta	doc_860756017855_item	2905832	et	4	main
improviseerimine	doc_860756017855_item	2905849	et	4	main
esinemine	doc_860756017855_item	2905850	et	4	main
erinevates	doc_860756017855_item	2905863	et	4	main
riietes	doc_860756017855_item	2905864	et	3	main
haridusega	doc_860756017855_item	2905879	et	3	main
teema	doc_860756017855_item	2905888	et	4	main
näiteks	doc_860756017855_item	2905896	et	4	main
medõe	doc_860756017855_item	2905922	et	3	main
ei	doc_860756017855_item	2905935	et	4	main
koolis	doc_860756017855_item	2905939	et	4	main
a	doc_860756017855_item	2905942	et	4	main
vene	doc_860756017855_item	2905944	et	4	main
koolis	doc_860756017855_item	2905945	et	4	main
11	doc_860756017855_item	2905946	et	2	main
aastad	doc_860756017855_item	2905947	et	3	main
4	doc_860756017855_item	2905956	et	2	main
vähem	doc_860756017855_item	2905966	et	4	main
näiteks	doc_860756017855_item	2905978	et	4	main
vooglaid	doc_860756017855_item	2905979	et	3	main
nende	doc_860756017855_item	2905985	et	4	main
keelatud	doc_860756017855_item	2905988	et	4	main
asutus	doc_860756017855_item	2905990	et	4	main
pandi	doc_860756017855_item	2905991	et	4	main
kinni	doc_860756017855_item	2905992	et	3	main
ei	doc_860756017855_item	2905995	et	4	main
vaibad	doc_860756017855_item	2906008	et	3	main
võimalik	doc_860756017855_item	2906011	et	3	main
erisoodustused	doc_860756017855_item	2906013	et	3	main
nsvs	doc_860756017855_item	2905722	et	4	main
1	doc_860756017855_item	2905730	et	2	main
1970ndate	doc_860756017855_item	2905731	et	4	main
eestinsv	doc_860756017855_item	2905732	et	4	main
etv	doc_860756017855_item	2905738	et	4	main
tehakse	doc_860756017855_item	2905739	et	3	main
palju	doc_860756017855_item	2905740	et	4	main
kultuurielu	doc_860756017855_item	2905751	et	4	main
vaatamist	doc_860756017855_item	2905762	et	4	main
leiis	doc_860756017855_item	2905772	et	4	main
tõuseb	doc_860756017855_item	2905775	et	3	main
eestisse	doc_860756017855_item	2905777	et	4	main
majandus	doc_860756017855_item	2905779	et	4	main
kaevandused	doc_860756017855_item	2905781	et	4	main
näiteks	doc_860756017855_item	2905782	et	4	main
ja	doc_860756017855_item	2905783	et	3	main
riigile	doc_860756017855_item	2905784	et	3	main
oli	doc_860756017855_item	2905785	et	3	main
vaja	doc_860756017855_item	2905786	et	4	main
kvalititseeritud	doc_860756017855_item	2905787	et	4	main
tööjõudu	doc_860756017855_item	2905788	et	4	main
see	doc_860756017855_item	2905789	et	3	main
et	doc_860756017855_item	2905790	et	3	main
eestis	doc_860756017855_item	2905791	et	3	main
oli	doc_860756017855_item	2905792	et	3	main
suur	doc_860756017855_item	2905793	et	3	main
protsent	doc_860756017855_item	2905794	et	3	main
muulasi	doc_860756017855_item	2905795	et	4	main
mõjutas	doc_860756017855_item	2905796	et	3	main
ka	doc_860756017855_item	2905797	et	3	main
kultuurielu	doc_860756017855_item	2905798	et	4	main
muusikaelus	doc_860756017855_item	2905799	et	4	main
aktiviseeris	doc_860756017855_item	2905800	et	3	main
folkloori	doc_860756017855_item	2905801	et	4	main
liikumine	doc_860756017855_item	2905802	et	4	main
tekkisid	doc_860756017855_item	2905803	et	4	main
uued	doc_860756017855_item	2905804	et	3	main
ansamblid	doc_860756017855_item	2905805	et	3	main
nagu	doc_860756017855_item	2905806	et	3	main
neid	doc_860756017855_item	2905807	et	4	main
iseloomustas	doc_860756017855_item	2905808	et	3	main
audentsus	doc_860756017855_item	2905809	et	4	main
olnud	doc_860756017855_item	2905812	et	4	main
spetsialselt	doc_860756017855_item	2905813	et	4	main
külakopelle	doc_860756017855_item	2905819	et	4	main
mis	doc_860756017855_item	2905820	et	4	main
olid	doc_860756017855_item	2905821	et	4	main
sest	doc_860756017855_item	2905829	et	4	main
keelde	doc_860756017855_item	2905839	et	4	main
see	doc_860756017855_item	2905840	et	3	main
muusika	doc_860756017855_item	2905843	et	4	main
lavatsensuur	doc_860756017855_item	2905845	et	3	main
suur	doc_860756017855_item	2905847	et	3	main
kindla	doc_860756017855_item	2905853	et	3	main
kava	doc_860756017855_item	2905854	et	4	main
järgi	doc_860756017855_item	2905855	et	4	main
ansambel	doc_860756017855_item	2905856	et	3	main
hellero	doc_860756017855_item	2905857	et	4	main
kultuurielus	doc_860756017855_item	2905865	et	4	main
oli	doc_860756017855_item	2905866	et	3	main
ka	doc_860756017855_item	2905867	et	3	main
selline	doc_860756017855_item	2905868	et	4	main
seelle	doc_860756017855_item	2905886	et	4	main
uuendused	doc_860756017855_item	2905889	et	4	main
olnud	doc_860756017855_item	2905891	et	4	main
tü	doc_860756017855_item	2905894	et	4	main
hinnet	doc_860756017855_item	2905897	et	3	main
pandi	doc_860756017855_item	2905898	et	4	main
selle	doc_860756017855_item	2905899	et	4	main
järgi	doc_860756017855_item	2905900	et	4	main
kuidas	doc_860756017855_item	2905901	et	3	main
tudeng	doc_860756017855_item	2905902	et	3	main
loengutel	doc_860756017855_item	2905903	et	4	main
oli	doc_860756017855_item	2905904	et	3	main
käinud	doc_860756017855_item	2905905	et	4	main
kõik	doc_860756017855_item	2905906	et	4	main
poisid	doc_860756017855_item	2905907	et	4	main
õpingu	doc_860756017855_item	2905908	et	3	main
sees	doc_860756017855_item	2905909	et	4	main
pidid	doc_860756017855_item	2905910	et	4	main
tegema	doc_860756017855_item	2905911	et	3	main
sõjaväelise	doc_860756017855_item	2905912	et	4	main
ettevalmistuseksami	doc_860756017855_item	2905913	et	3	main
muidu	doc_860756017855_item	2905914	et	3	main
edasi	doc_860756017855_item	2905915	et	3	main
õppida	doc_860756017855_item	2905916	et	3	main
ei	doc_860756017855_item	2905917	et	4	main
saa	doc_860756017855_item	2905918	et	4	main
tüdrukud	doc_860756017855_item	2905919	et	3	main
pidid	doc_860756017855_item	2905920	et	4	main
ja	doc_860756017855_item	2905883	et	3	main
võib	doc_860756017855_item	2905884	et	3	main
olla	doc_860756017855_item	2905885	et	3	main
kasulikut	doc_860756017855_item	2905893	et	4	main
läbima	doc_860756017855_item	2905921	et	4	main
kursused	doc_860756017855_item	2905923	et	3	main
kokku	doc_860756017855_item	2905937	et	3	main
oli	doc_860756017855_item	2905955	et	3	main
tundi	doc_860756017855_item	2905957	et	4	main
keelt	doc_860756017855_item	2905959	et	4	main
võrreldes	doc_860756017855_item	2905960	et	3	main
sellega	doc_860756017855_item	2905961	et	3	main
sellel	doc_860756017855_item	2905970	et	4	main
asutus	doc_860756017855_item	2905973	et	4	main
seal	doc_860756017855_item	2905976	et	4	main
töötasid	doc_860756017855_item	2905977	et	4	main
aga	doc_860756017855_item	2905982	et	3	main
töö	doc_860756017855_item	2905986	et	4	main
oli	doc_860756017855_item	2905987	et	3	main
ta	doc_860756017855_item	2905994	et	4	main
olnud	doc_860756017855_item	2905996	et	4	main
vastuvõttav	doc_860756017855_item	2905997	et	4	main
nl-le	doc_860756017855_item	2905998	et	3	main
võis	doc_860756017855_item	2906005	et	4	main
oli	doc_860756017855_item	2906010	et	3	main
saada	doc_860756017855_item	2906012	et	4	main
mõttetu	doc_860756017855_item	2906022	et	4	main
kanda	doc_860756017855_item	2906029	et	4	main
püksid	doc_860756017855_item	2906030	et	3	main
nagu	doc_860756017855_item	2906031	et	3	main
koolivorm	doc_860756017855_item	2906032	et	3	main
trükitis	doc_860756017855_item	2906038	et	4	main
tunda	doc_860756017855_item	2906053	et	3	main
televisioon	doc_860756017855_item	2906063	et	4	main
mida	doc_860756017855_item	2906064	et	4	main
põhja-eestlased	doc_860756017855_item	2906065	et	3	main
said	doc_860756017855_item	2906066	et	4	main
hakab	doc_860756017855_item	2906069	et	4	main
hotell	doc_860756017855_item	2906080	et	3	main
ja	doc_860756017855_item	2906081	et	3	main
palju	doc_860756017855_item	2906082	et	4	main
käsitöösuveniire	doc_860756017855_item	2906088	et	3	main
öelda	doc_860756017855_item	2906095	et	4	main
et	doc_860756017855_item	2906096	et	3	main
paljud	doc_860756017855_item	2906097	et	3	main
eesti	doc_860756017855_item	2906098	et	4	main
kirjanikud	doc_860756017855_item	2906099	et	3	main
k	doc_860756017855_item	2906113	et	4	main
lepik	doc_860756017855_item	2906114	et	3	main
tuntumaid	doc_860756017855_item	2906119	et	4	main
kohta	doc_860756017855_item	2905925	et	4	main
lisada	doc_860756017855_item	2905927	et	3	main
eesti	doc_860756017855_item	2905938	et	4	main
õpiti	doc_860756017855_item	2905940	et	3	main
vene	doc_860756017855_item	2905952	et	4	main
võõrkeelt	doc_860756017855_item	2905964	et	4	main
oli	doc_860756017855_item	2905965	et	3	main
2	doc_860756017855_item	2905967	et	2	main
tundi	doc_860756017855_item	2905968	et	4	main
avati	doc_860756017855_item	2905969	et	3	main
m	doc_860756017855_item	2905980	et	4	main
sest	doc_860756017855_item	2905993	et	4	main
heaolu	doc_860756017855_item	2906003	et	4	main
tarbekaupa	doc_860756017855_item	2906004	et	4	main
diivanid	doc_860756017855_item	2906009	et	3	main
auto	doc_860756017855_item	2906015	et	4	main
samal	doc_860756017855_item	2906017	et	3	main
ajal	doc_860756017855_item	2906018	et	4	main
toodeti	doc_860756017855_item	2906019	et	3	main
ka	doc_860756017855_item	2906020	et	3	main
palju	doc_860756017855_item	2906021	et	4	main
asju	doc_860756017855_item	2906023	et	3	main
märke	doc_860756017855_item	2906025	et	4	main
1972-73	doc_860756017855_item	2906026	et	2	main
tüdrukud	doc_860756017855_item	2906027	et	3	main
koomiksiline	doc_860756017855_item	2906037	et	4	main
ilmus	doc_860756017855_item	2906041	et	4	main
avameelselt	doc_860756017855_item	2906045	et	4	main
väikesed	doc_860756017855_item	2906048	et	4	main
muudatused	doc_860756017855_item	2906049	et	3	main
70ndatel	doc_860756017855_item	2906068	et	4	main
töötama	doc_860756017855_item	2906070	et	3	main
helsingi-tallinna	doc_860756017855_item	2906071	et	4	main
laevaliin	doc_860756017855_item	2906072	et	3	main
viru	doc_860756017855_item	2906079	et	4	main
rahva	doc_860756017855_item	2906087	et	3	main
aastate	doc_860756017855_item	2906092	et	3	main
võib	doc_860756017855_item	2906094	et	3	main
välismaal	doc_860756017855_item	2906103	et	4	main
ja	doc_860756017855_item	2906104	et	3	main
väliseesti	doc_860756017855_item	2906107	et	4	main
m	doc_860756017855_item	2906115	et	4	main
under	doc_860756017855_item	2906116	et	4	main
olid	doc_860756017855_item	2906121	et	4	main
tuuline	doc_860756017855_item	2906124	et	3	main
rand	doc_860756017855_item	2906125	et	3	main
m	doc_860756017855_item	2906126	et	4	main
traat	doc_860756017855_item	2906127	et	3	main
režissöörid	doc_860756017855_item	2906143	et	2	main
laius	doc_860756017855_item	2906147	et	4	main
k	doc_860756017855_item	2906149	et	4	main
nl	doc_860756017855_item	2906167	et	4	main
elada	doc_860756017855_item	2906178	et	3	main
tegelevad	doc_860756017855_item	2906185	et	4	main
sotsialistlikku	doc_860756017855_item	2906190	et	4	main
suhtutakse	doc_860756017855_item	2906191	et	3	main
nt	doc_860756017855_item	2906024	et	4	main
a	doc_860756017855_item	2906034	et	4	main
avati	doc_860756017855_item	2906035	et	3	main
1970	doc_860756017855_item	2906039	et	2	main
eesti	doc_860756017855_item	2906042	et	4	main
raamat	doc_860756017855_item	2906044	et	3	main
abielust	doc_860756017855_item	2906046	et	3	main
need	doc_860756017855_item	2906047	et	3	main
ennast	doc_860756017855_item	2906054	et	4	main
rohkem	doc_860756017855_item	2906055	et	4	main
lääne	doc_860756017855_item	2906056	et	4	main
rahvana	doc_860756017855_item	2906057	et	3	main
suurt	doc_860756017855_item	2906058	et	3	main
mõju	doc_860756017855_item	2906059	et	4	main
avaldas	doc_860756017855_item	2906060	et	3	main
kindlasti	doc_860756017855_item	2906061	et	3	main
palju	doc_860756017855_item	2906076	et	4	main
turiste	doc_860756017855_item	2906077	et	3	main
avati	doc_860756017855_item	2906078	et	3	main
eesti	doc_860756017855_item	2906086	et	4	main
olid	doc_860756017855_item	2906100	et	4	main
sellel	doc_860756017855_item	2906101	et	4	main
ajal	doc_860756017855_item	2906102	et	4	main
seal	doc_860756017855_item	2906106	et	4	main
kirjanikud	doc_860756017855_item	2906108	et	3	main
nt	doc_860756017855_item	2906110	et	4	main
selle	doc_860756017855_item	2906117	et	4	main
inger	doc_860756017855_item	2906128	et	4	main
härala	doc_860756017855_item	2906129	et	4	main
elulood	doc_860756017855_item	2906130	et	4	main
romaanide	doc_860756017855_item	2906131	et	3	main
hullumeesus	doc_860756017855_item	2906140	et	4	main
olid	doc_860756017855_item	2906144	et	4	main
millised	doc_860756017855_item	2906179	et	3	main
70ndate	doc_860756017855_item	2906091	et	4	main
kirjandusest	doc_860756017855_item	2906093	et	4	main
j	doc_860756017855_item	2906111	et	4	main
vask	doc_860756017855_item	2906112	et	3	main
aja	doc_860756017855_item	2906118	et	4	main
a	doc_860756017855_item	2906122	et	4	main
hint	doc_860756017855_item	2906123	et	4	main
järdi	doc_860756017855_item	2906132	et	4	main
tehti	doc_860756017855_item	2906133	et	3	main
ka	doc_860756017855_item	2906134	et	3	main
palju	doc_860756017855_item	2906135	et	4	main
filme	doc_860756017855_item	2906136	et	3	main
tuntud	doc_860756017855_item	2906141	et	4	main
l	doc_860756017855_item	2906146	et	4	main
2	doc_860756017855_item	2906151	et	2	main
valgus	doc_860756017855_item	2906152	et	4	main
kunstis	doc_860756017855_item	2906168	et	3	main
filmikunstis	doc_860756017855_item	2906169	et	3	main
kirjanduses	doc_860756017855_item	2906170	et	3	main
muusikasseal	doc_860756017855_item	2906171	et	4	main
näidatakse	doc_860756017855_item	2906172	et	3	main
kuidas	doc_860756017855_item	2906173	et	3	main
peab	doc_860756017855_item	2906174	et	4	main
võib	doc_860756017855_item	2906175	et	3	main
sotsialismi	doc_860756017855_item	2906176	et	4	main
peavad	doc_860756017855_item	2906181	et	4	main
olema	doc_860756017855_item	2906182	et	4	main
nad	doc_860756017855_item	2906184	et	3	main
ja	doc_860756017855_item	2906186	et	3	main
kuidas	doc_860756017855_item	2906187	et	3	main
sellesse	doc_860756017855_item	2906188	et	4	main
sõimusse	doc_860756017855_item	2906189	et	3	main
k	doc_860756017855_item	2906138	et	4	main
kiisk	doc_860756017855_item	2906139	et	3	main
eesti	doc_860756017855_item	2906142	et	4	main
ka	doc_860756017855_item	2906145	et	3	main
komissarov	doc_860756017855_item	2906150	et	4	main
koordis	doc_860756017855_item	2906153	et	4	main
on	doc_860756017855_item	2906154	et	4	main
kindlasti	doc_860756017855_item	2906155	et	3	main
väga	doc_860756017855_item	2906156	et	3	main
hea	doc_860756017855_item	2906157	et	4	main
näidis	doc_860756017855_item	2906158	et	4	main
sellest	doc_860756017855_item	2906159	et	4	main
kuidas	doc_860756017855_item	2906160	et	3	main
sotsialistlik	doc_860756017855_item	2906161	et	3	main
realism	doc_860756017855_item	2906162	et	3	main
oli	doc_860756017855_item	2906163	et	3	main
väga	doc_860756017855_item	2906164	et	3	main
laualt	doc_860756017855_item	2906165	et	4	main
inimesed	doc_860756017855_item	2906180	et	3	main
millega	doc_860756017855_item	2906183	et	3	main
migratsiooni	doc_860756017857_item	2906337	et	4	main
ja	doc_860756017857_item	2906346	et	3	main
põhikooli	doc_860756017857_item	2906353	et	4	main
õpilastele	doc_860756017857_item	2906354	et	4	main
nimetada	doc_860756017857_item	2906369	et	3	main
jooned	doc_860756017857_item	2906374	et	3	main
tagasi	doc_860756017857_item	2906380	et	3	main
esialgu	doc_860756017857_item	2906381	et	3	main
kasv	doc_860756017857_item	2906383	et	3	main
ja	doc_860756017857_item	2906384	et	3	main
olukord	doc_860756017857_item	2906385	et	3	main
järgult	doc_860756017857_item	2906394	et	3	main
ole	doc_860756017857_item	2906402	et	4	main
võimalik	doc_860756017857_item	2906403	et	3	main
püütakse	doc_860756017857_item	2906404	et	3	main
arendada	doc_860756017857_item	2906405	et	3	main
elektri-toodangut	doc_860756017857_item	2906408	et	3	main
saab	doc_860756017857_item	2906413	et	3	main
ehitatakse	doc_860756017857_item	2906416	et	3	main
tehaseid	doc_860756017857_item	2906418	et	3	main
püütakse	doc_860756017857_item	2906419	et	3	main
1	doc_860756017857_item	2906334	et	2	main
kevade	doc_860756017857_item	2906344	et	4	main
kas	doc_860756017857_item	2906345	et	3	main
kuidas	doc_860756017857_item	2906347	et	3	main
õppevahendiks	doc_860756017857_item	2906351	et	3	main
aega	doc_860756017857_item	2906367	et	4	main
saab	doc_860756017857_item	2906368	et	3	main
iseloomulikud	doc_860756017857_item	2906377	et	3	main
tulid	doc_860756017857_item	2906379	et	4	main
järg	doc_860756017857_item	2906393	et	3	main
palju	doc_860756017857_item	2906397	et	4	main
praktiliselt	doc_860756017857_item	2906399	et	4	main
teha	doc_860756017857_item	2906400	et	3	main
nafta-	doc_860756017857_item	2906406	et	4	main
toimub	doc_860756017857_item	2906409	et	3	main
maal	doc_860756017857_item	2906412	et	4	main
väga	doc_860756017857_item	2906414	et	3	main
kõrgele	doc_860756017857_item	2906421	et	4	main
käib	doc_860756017857_item	2906436	et	3	main
nafta-	doc_860756017857_item	2906447	et	4	main
eestisse	doc_860756017857_item	2906457	et	4	main
toimub	doc_860756017857_item	2906458	et	3	main
kiire	doc_860756017857_item	2906459	et	4	main
töötama	doc_860756017857_item	2906469	et	3	main
suurenesid	doc_860756017857_item	2906479	et	4	main
omavahelised	doc_860756017857_item	2906480	et	4	main
probleemid	doc_860756017857_item	2906481	et	3	main
töölised	doc_860756017857_item	2906494	et	3	main
regioonid	doc_860756017857_item	2906499	et	3	main
asuvad	doc_860756017857_item	2906501	et	4	main
näiteks	doc_860756017857_item	2906520	et	4	main
majanduse	doc_860756017857_item	2906335	et	4	main
seosed	doc_860756017857_item	2906338	et	3	main
1970ndate	doc_860756017857_item	2906339	et	4	main
eesti	doc_860756017857_item	2906340	et	4	main
nsv-s	doc_860756017857_item	2906341	et	3	main
2	doc_860756017857_item	2906342	et	2	main
see	doc_860756017857_item	2906349	et	3	main
aastaid	doc_860756017857_item	2906356	et	4	main
nimetatakse	doc_860756017857_item	2906357	et	3	main
stagnatsiooniperioodiks	doc_860756017857_item	2906358	et	3	main
1968	doc_860756017857_item	2906359	et	2	main
ka	doc_860756017857_item	2906370	et	3	main
sest	doc_860756017857_item	2906372	et	4	main
mis	doc_860756017857_item	2906375	et	4	main
langes	doc_860756017857_item	2906392	et	4	main
ja	doc_860756017857_item	2906407	et	3	main
urbaniseerumine	doc_860756017857_item	2906410	et	4	main
jõuda	doc_860756017857_item	2906420	et	3	main
kuidas	doc_860756017857_item	2906433	et	3	main
ei	doc_860756017857_item	2906438	et	4	main
spetsialiste	doc_860756017857_item	2906440	et	3	main
ja	doc_860756017857_item	2906441	et	3	main
haritlase	doc_860756017857_item	2906442	et	3	main
selleks	doc_860756017857_item	2906443	et	4	main
et	doc_860756017857_item	2906444	et	3	main
arendada	doc_860756017857_item	2906445	et	3	main
valdkondi	doc_860756017857_item	2906453	et	4	main
suunatakse	doc_860756017857_item	2906455	et	4	main
midagi	doc_860756017857_item	2906471	et	4	main
ei	doc_860756017857_item	2906488	et	4	main
paldiski	doc_860756017857_item	2906491	et	4	main
sattuvad	doc_860756017857_item	2906493	et	4	main
on	doc_860756017857_item	2906496	et	4	main
olemas	doc_860756017857_item	2906497	et	4	main
saa	doc_860756017857_item	2906509	et	4	main
liikuda	doc_860756017857_item	2906510	et	3	main
omal	doc_860756017857_item	2906511	et	3	main
nägu	doc_860756017857_item	2906514	et	4	main
on	doc_860756017857_item	2906517	et	4	main
omapärased	doc_860756017857_item	2906518	et	4	main
tsoonid	doc_860756017857_item	2906519	et	3	main
ja	doc_860756017857_item	2906522	et	3	main
ruhnu	doc_860756017857_item	2906523	et	4	main
saarele	doc_860756017857_item	2906524	et	3	main
polnud	doc_860756017857_item	2906525	et	3	main
üldse	doc_860756017857_item	2906526	et	3	main
võimalik	doc_860756017857_item	2906527	et	3	main
sai	doc_860756017857_item	2906532	et	4	main
saamist	doc_860756017857_item	2906539	et	4	main
sinna	doc_860756017857_item	2906542	et	3	main
oli	doc_860756017857_item	2906544	et	3	main
omapärane	doc_860756017857_item	2906549	et	4	main
migratsioon	doc_860756017857_item	2906550	et	3	main
ka	doc_860756017857_item	2906552	et	3	main
pool	doc_860756017857_item	2906554	et	4	main
eestis	doc_860756017857_item	2906555	et	3	main
seal	doc_860756017857_item	2906584	et	4	main
kooli	doc_860756017857_item	2906596	et	4	main
saab	doc_860756017857_item	2906604	et	3	main
ka	doc_860756017857_item	2906605	et	3	main
traditsioonidest	doc_860756017857_item	2906608	et	3	main
saab	doc_860756017857_item	2906609	et	3	main
näha	doc_860756017857_item	2906610	et	3	main
kuidas	doc_860756017857_item	2906611	et	3	main
ristitakse	doc_860756017857_item	2906612	et	4	main
last	doc_860756017857_item	2906613	et	4	main
peetkase	doc_860756017857_item	2906614	et	3	main
tavalise	doc_860756017857_item	2906627	et	4	main
süsteemist	doc_860756017857_item	2906635	et	4	main
on	doc_860756017857_item	2906653	et	4	main
parem	doc_860756017857_item	2906665	et	4	main
kontrolltöö	doc_860756017857_item	2906333	et	4	main
ja	doc_860756017857_item	2906336	et	3	main
film	doc_860756017857_item	2906350	et	3	main
mitte-eestlastest	doc_860756017857_item	2906352	et	4	main
70	doc_860756017857_item	2906355	et	2	main
sulaperiood	doc_860756017857_item	2906361	et	3	main
ja	doc_860756017857_item	2906362	et	3	main
võimule	doc_860756017857_item	2906363	et	3	main
tuli	doc_860756017857_item	2906364	et	4	main
brežnev	doc_860756017857_item	2906365	et	2	main
seda	doc_860756017857_item	2906366	et	3	main
taasstalinismiks	doc_860756017857_item	2906371	et	4	main
paljud	doc_860756017857_item	2906373	et	3	main
olid	doc_860756017857_item	2906376	et	4	main
stalinismile	doc_860756017857_item	2906378	et	4	main
majanduse	doc_860756017857_item	2906382	et	4	main
oli	doc_860756017857_item	2906386	et	3	main
sama	doc_860756017857_item	2906387	et	4	main
riik	doc_860756017857_item	2906395	et	3	main
nõuab	doc_860756017857_item	2906396	et	3	main
mida	doc_860756017857_item	2906398	et	4	main
ei	doc_860756017857_item	2906401	et	4	main
elu	doc_860756017857_item	2906411	et	4	main
raskeks	doc_860756017857_item	2906415	et	3	main
juurde	doc_860756017857_item	2906417	et	4	main
majanduslikule	doc_860756017857_item	2906422	et	3	main
nsv-s	doc_860756017857_item	2906434	et	3	main
põlevkivi	doc_860756017857_item	2906446	et	4	main
ja	doc_860756017857_item	2906448	et	3	main
elektritööstust	doc_860756017857_item	2906449	et	4	main
ja	doc_860756017857_item	2906450	et	3	main
venelaste	doc_860756017857_item	2906474	et	4	main
arv	doc_860756017857_item	2906475	et	3	main
kinnised	doc_860756017857_item	2906483	et	4	main
linnad	doc_860756017857_item	2906484	et	3	main
kuhu	doc_860756017857_item	2906485	et	3	main
eestlased	doc_860756017857_item	2906486	et	3	main
üldse	doc_860756017857_item	2906487	et	3	main
ainult	doc_860756017857_item	2906503	et	4	main
saadetud	doc_860756017857_item	2906505	et	4	main
nii	doc_860756017857_item	2906513	et	3	main
nad	doc_860756017857_item	2906515	et	3	main
tahavad	doc_860756017857_item	2906516	et	3	main
pääseda	doc_860756017857_item	2906528	et	3	main
spetsiaalse	doc_860756017857_item	2906534	et	3	main
minna	doc_860756017857_item	2906536	et	3	main
suunati	doc_860756017857_item	2906540	et	4	main
inimest	doc_860756017857_item	2906541	et	3	main
toimus	doc_860756017857_item	2906551	et	3	main
on	doc_860756017857_item	2906577	et	4	main
talumeeste	doc_860756017857_item	2906580	et	4	main
kuidas	doc_860756017857_item	2906588	et	3	main
tol	doc_860756017857_item	2906589	et	3	main
omavahelised	doc_860756017857_item	2906600	et	4	main
eesti	doc_860756017857_item	2906607	et	4	main
nii	doc_860756017857_item	2906618	et	3	main
vene	doc_860756017857_item	2906619	et	4	main
kui	doc_860756017857_item	2906620	et	3	main
omad	doc_860756017857_item	2906623	et	4	main
hea	doc_860756017857_item	2906625	et	4	main
ja	doc_860756017857_item	2906630	et	3	main
ka	doc_860756017857_item	2906633	et	3	main
isegi	doc_860756017857_item	2906639	et	4	main
huvitavad	doc_860756017857_item	2906640	et	4	main
pisiasjad	doc_860756017857_item	2906642	et	3	main
nägu	doc_860756017857_item	2906643	et	4	main
hea	doc_860756017857_item	2906654	et	4	main
võrrelda	doc_860756017857_item	2906671	et	4	main
tollaste	doc_860756017857_item	2906672	et	3	main
koolielu	doc_860756017857_item	2906676	et	4	main
kruusemendilutsu	doc_860756017857_item	2906343	et	4	main
sobiks	doc_860756017857_item	2906348	et	4	main
lõppes	doc_860756017857_item	2906360	et	4	main
mis	doc_860756017857_item	2906388	et	4	main
sulaajal	doc_860756017857_item	2906389	et	3	main
aastatega	doc_860756017857_item	2906390	et	3	main
juurdekasv	doc_860756017857_item	2906391	et	3	main
tasemele	doc_860756017857_item	2906423	et	3	main
ei	doc_860756017857_item	2906426	et	4	main
õnnestu	doc_860756017857_item	2906427	et	4	main
eestist	doc_860756017857_item	2906428	et	3	main
elu	doc_860756017857_item	2906435	et	4	main
teisi	doc_860756017857_item	2906452	et	4	main
teadmata	doc_860756017857_item	2906470	et	4	main
kohalikusest	doc_860756017857_item	2906472	et	4	main
rahvast	doc_860756017857_item	2906473	et	4	main
ilmuvad	doc_860756017857_item	2906482	et	4	main
pääse	doc_860756017857_item	2906489	et	4	main
terved	doc_860756017857_item	2906498	et	4	main
elama	doc_860756017857_item	2906502	et	3	main
maal	doc_860756017857_item	2906512	et	4	main
kihnu	doc_860756017857_item	2906521	et	4	main
olid	doc_860756017857_item	2906529	et	4	main
kohad	doc_860756017857_item	2906530	et	4	main
vaja	doc_860756017857_item	2906546	et	4	main
et	doc_860756017857_item	2906548	et	3	main
sees	doc_860756017857_item	2906553	et	4	main
2	doc_860756017857_item	2906556	et	2	main
ma	doc_860756017857_item	2906557	et	3	main
arvan	doc_860756017857_item	2906558	et	3	main
et	doc_860756017857_item	2906559	et	3	main
on	doc_860756017857_item	2906585	et	4	main
hästi	doc_860756017857_item	2906586	et	3	main
näha	doc_860756017857_item	2906587	et	3	main
kord	doc_860756017857_item	2906597	et	4	main
selles	doc_860756017857_item	2906602	et	4	main
pühi	doc_860756017857_item	2906616	et	4	main
lapsed	doc_860756017857_item	2906617	et	3	main
eesti	doc_860756017857_item	2906622	et	4	main
saavad	doc_860756017857_item	2906624	et	4	main
elust	doc_860756017857_item	2906629	et	3	main
ja	doc_860756017857_item	2906632	et	3	main
kooli	doc_860756017857_item	2906634	et	4	main
minu	doc_860756017857_item	2906636	et	3	main
sellised	doc_860756017857_item	2906641	et	4	main
kooli	doc_860756017857_item	2906649	et	4	main
töötajate	doc_860756017857_item	2906650	et	4	main
vahel	doc_860756017857_item	2906651	et	4	main
see	doc_860756017857_item	2906652	et	3	main
lõbus	doc_860756017857_item	2906655	et	4	main
film	doc_860756017857_item	2906656	et	3	main
mis	doc_860756017857_item	2906657	et	4	main
on	doc_860756017857_item	2906658	et	4	main
väga	doc_860756017857_item	2906659	et	3	main
õpetlik	doc_860756017857_item	2906660	et	3	main
võib-olla	doc_860756017857_item	2906661	et	3	main
vene	doc_860756017857_item	2906662	et	4	main
lapsed	doc_860756017857_item	2906663	et	3	main
mõista	doc_860756017857_item	2906666	et	4	main
eesti	doc_860756017857_item	2906667	et	4	main
kultuuri	doc_860756017857_item	2906668	et	4	main
saab	doc_860756017857_item	2906669	et	3	main
ka	doc_860756017857_item	2906670	et	3	main
laste	doc_860756017857_item	2906675	et	4	main
kuigi	doc_860756017857_item	2906424	et	3	main
see	doc_860756017857_item	2906425	et	3	main
tahetakse	doc_860756017857_item	2906429	et	4	main
teha	doc_860756017857_item	2906430	et	3	main
näidet	doc_860756017857_item	2906431	et	3	main
euroopale	doc_860756017857_item	2906432	et	3	main
siin	doc_860756017857_item	2906437	et	4	main
jätku	doc_860756017857_item	2906439	et	4	main
ka	doc_860756017857_item	2906451	et	3	main
venemaalt	doc_860756017857_item	2906454	et	3	main
tööjõud	doc_860756017857_item	2906456	et	4	main
välismaalaste	doc_860756017857_item	2906460	et	4	main
venelaste	doc_860756017857_item	2906461	et	4	main
arvu	doc_860756017857_item	2906462	et	4	main
kasv	doc_860756017857_item	2906463	et	3	main
nad	doc_860756017857_item	2906464	et	3	main
asuvad	doc_860756017857_item	2906465	et	4	main
siia	doc_860756017857_item	2906466	et	4	main
elama	doc_860756017857_item	2906467	et	3	main
ja	doc_860756017857_item	2906468	et	3	main
suurenes	doc_860756017857_item	2906476	et	4	main
ja	doc_860756017857_item	2906477	et	3	main
ka	doc_860756017857_item	2906478	et	3	main
sillamäe	doc_860756017857_item	2906490	et	3	main
sinna	doc_860756017857_item	2906492	et	3	main
venemaalt	doc_860756017857_item	2906495	et	3	main
kus	doc_860756017857_item	2906500	et	3	main
nsvliidust	doc_860756017857_item	2906504	et	4	main
töötajad	doc_860756017857_item	2906506	et	4	main
eestlased	doc_860756017857_item	2906507	et	3	main
ei	doc_860756017857_item	2906508	et	4	main
kuhu	doc_860756017857_item	2906531	et	3	main
pärast	doc_860756017857_item	2906537	et	4	main
ameti	doc_860756017857_item	2906538	et	3	main
kuhu	doc_860756017857_item	2906543	et	3	main
kirjeldatud	doc_860756017857_item	2906578	et	4	main
ja	doc_860756017857_item	2906581	et	3	main
kooilaste	doc_860756017857_item	2906582	et	4	main
elu	doc_860756017857_item	2906583	et	4	main
koolis	doc_860756017857_item	2906591	et	4	main
õpetati	doc_860756017857_item	2906592	et	3	main
milline	doc_860756017857_item	2906593	et	3	main
suhted	doc_860756017857_item	2906598	et	3	main
filmis	doc_860756017857_item	2906603	et	4	main
talviseid	doc_860756017857_item	2906615	et	4	main
ettekujutuse	doc_860756017857_item	2906626	et	4	main
probleemidest	doc_860756017857_item	2906631	et	3	main
jaoks	doc_860756017857_item	2906637	et	4	main
riietus	doc_860756017857_item	2906644	et	4	main
saavad	doc_860756017857_item	2906664	et	4	main
pidid	doc_862226128015_item	2906823	et	4	main
põgenikena	doc_862226128015_item	2906825	et	3	main
vana	doc_862226128015_item	2906827	et	4	main
maailm	doc_862226128015_item	2906828	et	3	main
ei	doc_862226128015_item	2906829	et	4	main
kuid	doc_862226128015_item	2906834	et	4	main
varsti	doc_862226128015_item	2906835	et	3	main
eestisse	doc_862226128015_item	2906842	et	4	main
sajandil	doc_862226128015_item	2906846	et	3	main
misjonäär	doc_862226128015_item	2906848	et	4	main
tulid	doc_862226128015_item	2906859	et	4	main
ka	doc_862226128015_item	2906860	et	3	main
sajandil	doc_862226128015_item	2906863	et	3	main
ristiretked	doc_862226128015_item	2906865	et	3	main
elasid	doc_862226128015_item	2906873	et	4	main
elas	doc_862226128015_item	2906879	et	3	main
nüüd	doc_862226128015_item	2906897	et	4	main
ainult	doc_860756017857_item	2906533	et	4	main
loaga	doc_860756017857_item	2906535	et	4	main
teda	doc_860756017857_item	2906545	et	4	main
nii	doc_860756017857_item	2906547	et	3	main
lutsu	doc_860756017857_item	2906560	et	4	main
kevad	doc_860756017857_item	2906561	et	3	main
sobiks	doc_860756017857_item	2906562	et	4	main
väga	doc_860756017857_item	2906563	et	3	main
hästi	doc_860756017857_item	2906564	et	3	main
õppevahendiks	doc_860756017857_item	2906565	et	3	main
põhikooli	doc_860756017857_item	2906566	et	4	main
õpilastele	doc_860756017857_item	2906567	et	4	main
aga	doc_860756017857_item	2906568	et	3	main
mitte	doc_860756017857_item	2906569	et	3	main
ainult	doc_860756017857_item	2906570	et	4	main
mitte-eestlastele	doc_860756017857_item	2906571	et	4	main
õpilastele	doc_860756017857_item	2906572	et	4	main
aga	doc_860756017857_item	2906573	et	3	main
ka	doc_860756017857_item	2906574	et	3	main
eestlasele	doc_860756017857_item	2906575	et	3	main
filmis	doc_860756017857_item	2906576	et	4	main
eesti	doc_860756017857_item	2906579	et	4	main
ajal	doc_860756017857_item	2906590	et	4	main
oli	doc_860756017857_item	2906594	et	3	main
sisene	doc_860756017857_item	2906595	et	4	main
sakslastega	doc_860756017857_item	2906599	et	3	main
probleemid	doc_860756017857_item	2906601	et	3	main
ettekujutuse	doc_860756017857_item	2906606	et	4	main
ka	doc_860756017857_item	2906621	et	3	main
rahva	doc_860756017857_item	2906628	et	3	main
olid	doc_860756017857_item	2906638	et	4	main
koolimaja	doc_860756017857_item	2906645	et	4	main
suhted	doc_860756017857_item	2906646	et	3	main
õpilaste	doc_860756017857_item	2906647	et	4	main
ja	doc_860756017857_item	2906648	et	3	main
ja	doc_860756017857_item	2906673	et	3	main
tänaste	doc_860756017857_item	2906674	et	3	main
veel	doc_862226128015_item	2906831	et	4	main
roomast	doc_862226128015_item	2906836	et	4	main
sai	doc_862226128015_item	2906837	et	4	main
tuli	doc_862226128015_item	2906843	et	4	main
esimene	doc_862226128015_item	2906847	et	3	main
oli	doc_862226128015_item	2906849	et	3	main
meinchard	doc_862226128015_item	2906850	et	4	main
hakkati	doc_862226128015_item	2906851	et	3	main
ehitama	doc_862226128015_item	2906852	et	4	main
eestisse	doc_862226128015_item	2906858	et	4	main
kuid	doc_862226128015_item	2906871	et	4	main
nendes	doc_862226128015_item	2906872	et	4	main
oli	doc_862226128015_item	2906882	et	3	main
kiht	doc_862226128015_item	2906884	et	3	main
talupojad	doc_862226128015_item	2906886	et	4	main
pidid	doc_862226128015_item	2906887	et	4	main
oma	doc_862226128015_item	2906895	et	4	main
kohustuslik	doc_862226128015_item	2906899	et	3	main
ristida	doc_862226128015_item	2906901	et	4	main
alates	doc_862226128015_item	2906903	et	3	main
teenistused	doc_862226128015_item	2906921	et	3	main
ainult	doc_862226128015_item	2906923	et	4	main
ladina	doc_862226128015_item	2906924	et	4	main
aru	doc_862226128015_item	2906932	et	4	main
linnades	doc_862226128015_item	2906943	et	3	main
kirikuid	doc_862226128015_item	2906945	et	4	main
vanimad	doc_862226128015_item	2906947	et	3	main
tallinna	doc_862226128015_item	2906948	et	4	main
kirikud	doc_862226128015_item	2906949	et	3	main
kirik	doc_862226128015_item	2906956	et	3	main
pühapäeval	doc_862226128015_item	2906958	et	3	main
kirikus	doc_862226128015_item	2906961	et	3	main
ka	doc_862226128015_item	2906973	et	3	main
et	doc_862226128015_item	2906978	et	3	main
saanud	doc_862226128015_item	2906988	et	4	main
enamik	doc_862226128015_item	2906989	et	3	main
kes	doc_862226128015_item	2907002	et	4	main
kontrolltöö	doc_862226128015_item	2906805	et	4	main
1	doc_862226128015_item	2906806	et	2	main
ristiusustamise	doc_862226128015_item	2906807	et	3	main
mõjud	doc_862226128015_item	2906808	et	4	main
eesti	doc_862226128015_item	2906809	et	4	main
ühiskonnakorraldusele	doc_862226128015_item	2906810	et	3	main
1316	doc_862226128015_item	2906811	et	2	main
sajandil	doc_862226128015_item	2906812	et	3	main
2	doc_862226128015_item	2906813	et	2	main
mida	doc_862226128015_item	2906814	et	4	main
tähendab	doc_862226128015_item	2906815	et	3	main
reformatsioon	doc_862226128015_item	2906816	et	3	main
1	doc_862226128015_item	2906817	et	2	main
ristiusk	doc_862226128015_item	2906818	et	3	main
ilmus	doc_862226128015_item	2906819	et	4	main
roomas	doc_862226128015_item	2906820	et	4	main
esimesed	doc_862226128015_item	2906821	et	3	main
valmis	doc_862226128015_item	2906832	et	4	main
maailma	doc_862226128015_item	2906838	et	4	main
katoliikliku	doc_862226128015_item	2906839	et	3	main
kiriku	doc_862226128015_item	2906840	et	3	main
keskus	doc_862226128015_item	2906841	et	3	main
12	doc_862226128015_item	2906845	et	2	main
alguses	doc_862226128015_item	2906854	et	4	main
koos	doc_862226128015_item	2906856	et	4	main
13	doc_862226128015_item	2906862	et	2	main
nüüd	doc_862226128015_item	2906866	et	4	main
hakkasid	doc_862226128015_item	2906867	et	4	main
ilmuma	doc_862226128015_item	2906868	et	3	main
olnud	doc_862226128015_item	2906830	et	4	main
väikseid	doc_862226128015_item	2906855	et	4	main
algasid	doc_862226128015_item	2906864	et	4	main
maal	doc_862226128015_item	2906880	et	4	main
madalam	doc_862226128015_item	2906883	et	4	main
linnas	doc_862226128015_item	2906885	et	4	main
kirikule	doc_862226128015_item	2906891	et	3	main
nad	doc_862226128015_item	2906893	et	3	main
keelati	doc_862226128015_item	2906909	et	4	main
ka	doc_862226128015_item	2906910	et	3	main
ka	doc_862226128015_item	2906940	et	3	main
ehitati	doc_862226128015_item	2906944	et	3	main
kõige	doc_862226128015_item	2906946	et	4	main
ja	doc_862226128015_item	2906954	et	3	main
käisid	doc_862226128015_item	2906960	et	4	main
rikkamad	doc_862226128015_item	2906962	et	4	main
maale	doc_862226128015_item	2906974	et	4	main
ma	doc_862226128015_item	2906976	et	3	main
sõnast	doc_862226128015_item	2906980	et	4	main
oli	doc_862226128015_item	2906981	et	3	main
vähe	doc_862226128015_item	2906982	et	3	main
kasu	doc_862226128015_item	2906983	et	4	main
algaja	doc_862226128015_item	2906998	et	4	main
oli	doc_862226128015_item	2906999	et	3	main
1517	doc_862226128015_item	2907007	et	2	main
aastal	doc_862226128015_item	2907008	et	3	main
saksamaal	doc_862226128015_item	2907009	et	4	main
olulisem	doc_862226128015_item	2907011	et	4	main
oli	doc_862226128015_item	2907013	et	3	main
see	doc_862226128015_item	2907014	et	3	main
et	doc_862226128015_item	2907015	et	3	main
nüüd	doc_862226128015_item	2907016	et	4	main
jumala	doc_862226128015_item	2907017	et	3	main
nii	doc_862226128015_item	2907029	et	3	main
rikkas	doc_862226128015_item	2907030	et	4	main
aastal	doc_862226128015_item	2907035	et	3	main
tõi	doc_862226128015_item	2907037	et	3	main
ka	doc_862226128015_item	2907039	et	3	main
hakkasid	doc_862226128015_item	2907042	et	4	main
muudatused	doc_862226128016_item	2907065	et	3	main
tähendab	doc_862226128016_item	2907072	et	3	main
1	doc_862226128016_item	2907075	et	2	main
korraldatud	doc_862226128016_item	2907091	et	4	main
valimised	doc_862226128016_item	2907092	et	4	main
rahvarinne	doc_862226128016_item	2907094	et	3	main
isamaa	doc_862226128016_item	2907097	et	4	main
seda	doc_862226128016_item	2907098	et	3	main
valitsust	doc_862226128016_item	2907099	et	4	main
juhtis	doc_862226128016_item	2907100	et	3	main
mart	doc_862226128016_item	2907101	et	3	main
laar	doc_862226128016_item	2907102	et	3	main
pärast	doc_862226128016_item	2907109	et	4	main
varanduslik	doc_862226128016_item	2907119	et	3	main
kristlased	doc_862226128015_item	2906822	et	3	main
elama	doc_862226128015_item	2906824	et	3	main
sest	doc_862226128015_item	2906826	et	4	main
muutuma	doc_862226128015_item	2906833	et	4	main
ristiusk	doc_862226128015_item	2906844	et	3	main
kirikuid	doc_862226128015_item	2906853	et	4	main
ristiusuga	doc_862226128015_item	2906857	et	3	main
vallutajad	doc_862226128015_item	2906861	et	4	main
eesti	doc_862226128015_item	2906876	et	4	main
rahvas	doc_862226128015_item	2906877	et	4	main
kas	doc_862226128015_item	2906878	et	3	main
nüüd	doc_862226128015_item	2906888	et	4	main
maksma	doc_862226128015_item	2906889	et	3	main
kümnist	doc_862226128015_item	2906890	et	3	main
samuti	doc_862226128015_item	2906892	et	3	main
oli	doc_862226128015_item	2906898	et	3	main
11	doc_862226128015_item	2906904	et	2	main
matmist	doc_862226128015_item	2906911	et	4	main
ma	doc_862226128015_item	2906912	et	3	main
peale	doc_862226128015_item	2906913	et	4	main
mis	doc_862226128015_item	2906914	et	4	main
oli	doc_862226128015_item	2906915	et	3	main
eestis	doc_862226128015_item	2906916	et	3	main
väga	doc_862226128015_item	2906917	et	3	main
levinud	doc_862226128015_item	2906918	et	4	main
kuid	doc_862226128015_item	2906919	et	4	main
jumala	doc_862226128015_item	2906920	et	3	main
saanud	doc_862226128015_item	2906930	et	4	main
nendest	doc_862226128015_item	2906931	et	4	main
pühitsema	doc_862226128015_item	2906936	et	3	main
vett	doc_862226128015_item	2906937	et	3	main
piima	doc_862226128015_item	2906938	et	4	main
ja	doc_862226128015_item	2906939	et	3	main
on	doc_862226128015_item	2906950	et	4	main
toomkirik	doc_862226128015_item	2906951	et	3	main
pühavaimu	doc_862226128015_item	2906955	et	4	main
inimesed	doc_862226128015_item	2906959	et	3	main
neist	doc_862226128015_item	2906963	et	4	main
andsid	doc_862226128015_item	2906964	et	4	main
ka	doc_862226128015_item	2906965	et	3	main
ei	doc_862226128015_item	2906987	et	4	main
martin	doc_862226128015_item	2907000	et	4	main
enam	doc_862226128015_item	2907028	et	4	main
1521	doc_862226128015_item	2907034	et	2	main
sõna	doc_862226128015_item	2907048	et	4	main
kontrolltöö	doc_862226128016_item	2907061	et	4	main
aastal	doc_862226128016_item	2907081	et	3	main
eesti	doc_862226128016_item	2907086	et	4	main
esimest	doc_862226128016_item	2907103	et	4	main
taasiseseisvunud	doc_862226128016_item	2907107	et	4	main
ii	doc_862226128016_item	2907110	et	4	main
kõige	doc_862226128016_item	2907121	et	4	main
ja	doc_862226128016_item	2907128	et	3	main
riik	doc_862226128016_item	2907130	et	3	main
midagi	doc_862226128016_item	2907134	et	4	main
ka	doc_862226128016_item	2907136	et	3	main
eestil	doc_862226128016_item	2907138	et	3	main
1994	doc_862226128016_item	2907142	et	2	main
ta	doc_862226128016_item	2907159	et	4	main
valitsuse	doc_862226128016_item	2907166	et	4	main
ja	doc_862226128016_item	2907168	et	3	main
stabiliseerida	doc_862226128016_item	2907172	et	3	main
terve	doc_862226128016_item	2907177	et	4	main
tornis	doc_862226128016_item	2907190	et	3	main
peale	doc_862226128016_item	2907198	et	4	main
rahareformi	doc_862226128016_item	2907199	et	4	main
uuendustega	doc_862226128016_item	2907214	et	4	main
enne	doc_862226128016_item	2907229	et	4	main
bensiini	doc_862226128016_item	2907234	et	4	main
ei	doc_862226128016_item	2907235	et	4	main
nüüd	doc_862226128016_item	2907241	et	4	main
ka	doc_862226128016_item	2907261	et	3	main
suured	doc_862226128015_item	2906869	et	3	main
linnad	doc_862226128015_item	2906870	et	3	main
enamasti	doc_862226128015_item	2906874	et	4	main
vallutajad	doc_862226128015_item	2906875	et	4	main
või	doc_862226128015_item	2906881	et	4	main
kaotasid	doc_862226128015_item	2906894	et	4	main
vabaduse	doc_862226128015_item	2906896	et	4	main
last	doc_862226128015_item	2906900	et	4	main
ja	doc_862226128015_item	2906902	et	3	main
eluaastast	doc_862226128015_item	2906905	et	4	main
õpetati	doc_862226128015_item	2906906	et	3	main
lastele	doc_862226128015_item	2906907	et	4	main
piiblit	doc_862226128015_item	2906908	et	3	main
olid	doc_862226128015_item	2906922	et	4	main
keeles	doc_862226128015_item	2906925	et	4	main
nii	doc_862226128015_item	2906926	et	3	main
et	doc_862226128015_item	2906927	et	3	main
eestlased	doc_862226128015_item	2906928	et	3	main
talupojad	doc_862226128015_item	2906933	et	4	main
muid	doc_862226128015_item	2906941	et	4	main
kirik	doc_862226128015_item	2906953	et	3	main
sest	doc_862226128015_item	2906984	et	4	main
kuni	doc_862226128015_item	2906985	et	3	main
reformatsioonini	doc_862226128015_item	2906986	et	3	main
sellest	doc_862226128015_item	2906991	et	4	main
2	doc_862226128015_item	2906993	et	2	main
reformatsioon	doc_862226128015_item	2906994	et	3	main
kiriku	doc_862226128015_item	2906995	et	3	main
nõudmine	doc_862226128015_item	2906996	et	4	main
selle	doc_862226128015_item	2906997	et	4	main
elas	doc_862226128015_item	2907003	et	3	main
saksamaal	doc_862226128015_item	2907004	et	4	main
reformatsioon	doc_862226128015_item	2907005	et	3	main
algas	doc_862226128015_item	2907006	et	3	main
muutus	doc_862226128015_item	2907012	et	4	main
läbi	doc_862226128015_item	2907021	et	4	main
emakeeles	doc_862226128015_item	2907023	et	4	main
ja	doc_862226128015_item	2907024	et	3	main
eestisse	doc_862226128015_item	2907031	et	4	main
kaasa	doc_862226128015_item	2907038	et	4	main
esimesed	doc_862226128015_item	2907049	et	3	main
ja	doc_862226128016_item	2907064	et	3	main
mida	doc_862226128016_item	2907071	et	4	main
revolutsioon	doc_862226128016_item	2907074	et	3	main
eesti	doc_862226128016_item	2907076	et	4	main
kuulutati	doc_862226128016_item	2907077	et	4	main
taasiseseisvaks	doc_862226128016_item	2907078	et	3	main
2008	doc_862226128016_item	2907079	et	2	main
1991	doc_862226128016_item	2907080	et	2	main
ülemnõukogu	doc_862226128016_item	2907090	et	4	main
võitis	doc_862226128016_item	2907093	et	3	main
korda	doc_862226128016_item	2907104	et	4	main
toimusidki	doc_862226128016_item	2907105	et	4	main
1992	doc_862226128016_item	2907113	et	2	main
seisud	doc_862226128016_item	2907123	et	3	main
olid	doc_862226128016_item	2907124	et	4	main
ei	doc_862226128016_item	2907131	et	4	main
suurenes	doc_862226128016_item	2907135	et	4	main
oli	doc_862226128016_item	2907139	et	3	main
see	doc_862226128016_item	2907140	et	3	main
aastal	doc_862226128016_item	2907141	et	3	main
tegi	doc_862226128016_item	2907145	et	4	main
muret	doc_862226128016_item	2907146	et	3	main
ka	doc_862226128016_item	2907147	et	3	main
e	doc_862226128016_item	2907156	et	4	main
savisaar	doc_862226128016_item	2907157	et	3	main
a	doc_862226128016_item	2907158	et	4	main
majandusolukord	doc_862226128016_item	2907171	et	3	main
lehvib	doc_862226128016_item	2907191	et	3	main
ka	doc_862226128016_item	2907195	et	3	main
põhiseadus	doc_862226128016_item	2907197	et	4	main
niinimetatud	doc_862226128016_item	2907201	et	3	main
uut	doc_862226128016_item	2907202	et	3	main
uus	doc_862226128016_item	2907215	et	3	main
kasvas	doc_862226128016_item	2907221	et	3	main
suur	doc_862226128016_item	2907232	et	3	main
jäid	doc_862226128016_item	2907239	et	4	main
külmaks	doc_862226128016_item	2907240	et	4	main
polnud	doc_862226128016_item	2907244	et	3	main
kõigel	doc_862226128016_item	2907251	et	4	main
vene	doc_862226128016_item	2907260	et	4	main
raha	doc_862226128016_item	2907272	et	4	main
ei	doc_862226128015_item	2906929	et	4	main
käisid	doc_862226128015_item	2906934	et	4	main
kirikus	doc_862226128015_item	2906935	et	3	main
asju	doc_862226128015_item	2906942	et	3	main
oleviste	doc_862226128015_item	2906952	et	4	main
igal	doc_862226128015_item	2906957	et	3	main
raha	doc_862226128015_item	2906966	et	4	main
kirikule	doc_862226128015_item	2906967	et	3	main
näiteks	doc_862226128015_item	2906968	et	4	main
pühavaimu	doc_862226128015_item	2906969	et	4	main
kirikule	doc_862226128015_item	2906970	et	3	main
mõnikord	doc_862226128015_item	2906971	et	3	main
andi	doc_862226128015_item	2906972	et	4	main
kuid	doc_862226128015_item	2906975	et	4	main
arvan	doc_862226128015_item	2906977	et	3	main
jumala	doc_862226128015_item	2906979	et	3	main
inimesi	doc_862226128015_item	2906990	et	4	main
aru	doc_862226128015_item	2906992	et	4	main
luther	doc_862226128015_item	2907001	et	4	main
kõige	doc_862226128015_item	2907010	et	4	main
teenistus	doc_862226128015_item	2907018	et	3	main
pidi	doc_862226128015_item	2907019	et	4	main
olema	doc_862226128015_item	2907020	et	4	main
olnud	doc_862226128015_item	2907027	et	4	main
reformatsioon	doc_862226128015_item	2907033	et	3	main
reformatsioon	doc_862226128015_item	2907036	et	3	main
kirjanduse	doc_862226128015_item	2907041	et	3	main
ilmuma	doc_862226128015_item	2907043	et	3	main
esimesed	doc_862226128015_item	2907044	et	3	main
eestikeelsed	doc_862226128015_item	2907045	et	3	main
raamatud	doc_862226128015_item	2907046	et	4	main
jumala	doc_862226128015_item	2907047	et	3	main
kes	doc_862226128015_item	2907051	et	4	main
1	doc_862226128016_item	2907062	et	2	main
muutused	doc_862226128016_item	2907063	et	4	main
taasiseseisvunud	doc_862226128016_item	2907066	et	4	main
eesti	doc_862226128016_item	2907067	et	4	main
poliitilises	doc_862226128016_item	2907068	et	3	main
esimesena	doc_862226128016_item	2907082	et	3	main
võeti	doc_862226128016_item	2907083	et	3	main
vastu	doc_862226128016_item	2907084	et	3	main
rahareform	doc_862226128016_item	2907085	et	3	main
kroon	doc_862226128016_item	2907087	et	3	main
1992	doc_862226128016_item	2907088	et	2	main
valimisliiduga	doc_862226128016_item	2907096	et	3	main
valimised	doc_862226128016_item	2907106	et	4	main
uuendustega	doc_862226128016_item	2907114	et	4	main
langus	doc_862226128016_item	2907117	et	4	main
ebavõrdsus	doc_862226128016_item	2907120	et	4	main
lastega	doc_862226128016_item	2907126	et	3	main
suurt	doc_862226128016_item	2907133	et	3	main
pidi	doc_862226128016_item	2907160	et	4	main
hoopis	doc_862226128016_item	2907161	et	3	main
lahkuma	doc_862226128016_item	2907162	et	3	main
aitama	doc_862226128016_item	2907164	et	3	main
suudeti	doc_862226128016_item	2907170	et	3	main
vastu	doc_862226128016_item	2907176	et	3	main
läbi	doc_862226128016_item	2907182	et	4	main
ka	doc_862226128016_item	2907183	et	3	main
keelereform	doc_862226128016_item	2907184	et	3	main
saab	doc_862226128016_item	2907185	et	3	main
rääkida	doc_862226128016_item	2907186	et	3	main
hermanni	doc_862226128016_item	2907189	et	4	main
võeti	doc_862226128016_item	2907193	et	3	main
kaob	doc_862226128016_item	2907200	et	3	main
turg	doc_862226128016_item	2907203	et	3	main
täituvad	doc_862226128016_item	2907205	et	4	main
suurenes	doc_862226128016_item	2907208	et	4	main
ka	doc_862226128016_item	2907209	et	3	main
majanduskasv	doc_862226128016_item	2907210	et	3	main
seda	doc_862226128016_item	2907211	et	3	main
poliitika	doc_862226128016_item	2907216	et	4	main
järsult	doc_862226128016_item	2907220	et	4	main
osa	doc_862226128016_item	2907223	et	4	main
eestist	doc_862226128016_item	2907224	et	3	main
ka	doc_862226128016_item	2907226	et	3	main
jätkunud	doc_862226128016_item	2907236	et	4	main
seda	doc_862226128016_item	2907242	et	3	main
viidud	doc_862226128015_item	2907022	et	4	main
kirik	doc_862226128015_item	2907025	et	3	main
ei	doc_862226128015_item	2907026	et	4	main
jõudis	doc_862226128015_item	2907032	et	3	main
emakeele	doc_862226128015_item	2907040	et	4	main
kirikuõpetajad	doc_862226128015_item	2907050	et	3	main
teadsid	doc_862226128015_item	2907052	et	4	main
eesti	doc_862226128015_item	2907053	et	4	main
keelt	doc_862226128015_item	2907054	et	4	main
ja	doc_862226128015_item	2907055	et	3	main
üldse	doc_862226128015_item	2907056	et	3	main
eesti	doc_862226128015_item	2907057	et	4	main
keel	doc_862226128015_item	2907058	et	4	main
hakkas	doc_862226128015_item	2907059	et	3	main
levima	doc_862226128015_item	2907060	et	3	main
elus	doc_862226128016_item	2907069	et	4	main
2	doc_862226128016_item	2907070	et	2	main
laulev	doc_862226128016_item	2907073	et	4	main
eesti	doc_862226128016_item	2907089	et	4	main
eesotsas	doc_862226128016_item	2907095	et	4	main
eestis	doc_862226128016_item	2907108	et	3	main
maailmasõda	doc_862226128016_item	2907111	et	4	main
aastal	doc_862226128016_item	2907112	et	3	main
kaasnes	doc_862226128016_item	2907115	et	3	main
elatustaseme	doc_862226128016_item	2907116	et	3	main
ning	doc_862226128016_item	2907118	et	3	main
hullemas	doc_862226128016_item	2907122	et	4	main
noored	doc_862226128016_item	2907125	et	3	main
teinud	doc_862226128016_item	2907132	et	4	main
tööpuudus	doc_862226128016_item	2907137	et	3	main
19	doc_862226128016_item	2907143	et	2	main
rahvale	doc_862226128016_item	2907144	et	3	main
üha	doc_862226128016_item	2907148	et	3	main
tagasi	doc_862226128016_item	2907163	et	3	main
vahetus	doc_862226128016_item	2907167	et	4	main
liberaliseerimine	doc_862226128016_item	2907174	et	4	main
riigikeelest	doc_862226128016_item	2907187	et	4	main
rahvuslipp	doc_862226128016_item	2907192	et	3	main
kauplused	doc_862226128016_item	2907204	et	3	main
kaubaga	doc_862226128016_item	2907206	et	3	main
järsult	doc_862226128016_item	2907207	et	4	main
põllumajanduse	doc_862226128016_item	2907218	et	3	main
pered	doc_862226128016_item	2907127	et	3	main
pensionärid	doc_862226128016_item	2907129	et	3	main
suurenev	doc_862226128016_item	2907149	et	4	main
kuritegevus	doc_862226128016_item	2907150	et	4	main
ja	doc_862226128016_item	2907151	et	3	main
korruptsioon	doc_862226128016_item	2907152	et	3	main
olukorda	doc_862226128016_item	2907153	et	4	main
püüdis	doc_862226128016_item	2907154	et	3	main
parandada	doc_862226128016_item	2907155	et	3	main
toimus	doc_862226128016_item	2907165	et	3	main
riigis	doc_862226128016_item	2907169	et	3	main
toimus	doc_862226128016_item	2907173	et	3	main
võeti	doc_862226128016_item	2907175	et	3	main
hulk	doc_862226128016_item	2907178	et	3	main
baasseadusi	doc_862226128016_item	2907179	et	3	main
ning	doc_862226128016_item	2907180	et	3	main
viidi	doc_862226128016_item	2907181	et	4	main
pika	doc_862226128016_item	2907188	et	4	main
vastu	doc_862226128016_item	2907194	et	3	main
uus	doc_862226128016_item	2907196	et	3	main
seoses	doc_862226128016_item	2907212	et	4	main
siis	doc_862226128016_item	2907213	et	3	main
vähenes	doc_862226128016_item	2907217	et	3	main
osa	doc_862226128016_item	2907219	et	4	main
teeninduse	doc_862226128016_item	2907222	et	4	main
lahkusid	doc_862226128016_item	2907225	et	4	main
vene	doc_862226128016_item	2907227	et	4	main
sõjaväeüksused	doc_862226128016_item	2907228	et	3	main
terved	doc_862226128016_item	2907237	et	4	main
elamurajoonid	doc_862226128016_item	2907238	et	3	main
suhteline	doc_862226128016_item	2907249	et	4	main
ja	doc_862226128016_item	2907250	et	3	main
e	doc_862226128016_item	2907258	et	4	main
siis	doc_862226128016_item	2907259	et	3	main
ajal	doc_862226128016_item	2907269	et	4	main
oli	doc_862226128016_item	2907270	et	3	main
kaubapuudus	doc_862226128016_item	2907271	et	3	main
toimuvaga	doc_862226128016_item	2907298	et	4	main
vene	doc_862226128016_item	2907306	et	4	main
keel	doc_862226128016_item	2907307	et	4	main
siis	doc_862226128016_item	2907309	et	3	main
suhtluskeel	doc_862226128016_item	2907312	et	4	main
aastal	doc_862226128016_item	2907313	et	3	main
1989	doc_862226128016_item	2907314	et	2	main
toimus	doc_862226128016_item	2907315	et	3	main
esitati	doc_862226128016_item	2907318	et	4	main
kommunismivastase	doc_862226128016_item	2907328	et	4	main
2	doc_862226128017_item	2907336	et	2	main
1	doc_862226128017_item	2907343	et	2	main
protsess	doc_862226128017_item	2907346	et	3	main
80-ndate	doc_862226128017_item	2907349	et	4	main
aastate	doc_862226128017_item	2907350	et	3	main
lõpus	doc_862226128017_item	2907351	et	4	main
see	doc_862226128017_item	2907352	et	3	main
oli	doc_862226128017_item	2907353	et	3	main
protsess	doc_862226128017_item	2907354	et	3	main
mille	doc_862226128017_item	2907355	et	3	main
nsvl-st	doc_862226128017_item	2907365	et	3	main
detsembrikuus	doc_862226128017_item	2907366	et	3	main
avaldati	doc_862226128017_item	2907367	et	3	main
molotov-ribentropi	doc_862226128017_item	2907368	et	4	main
pakt	doc_862226128017_item	2907369	et	3	main
veebruaris	doc_862226128017_item	2907370	et	3	main
eesti	doc_862226128017_item	2907378	et	4	main
kõigele	doc_862226128017_item	2907381	et	4	main
aitas	doc_862226128017_item	2907383	et	3	main
suveräänsust	doc_862226128017_item	2907384	et	4	main
nsvl-st	doc_862226128017_item	2907385	et	3	main
korraldas	doc_862226128017_item	2907395	et	3	main
eraldatamiseks	doc_862226128017_item	2907424	et	4	main
nsvl-st	doc_862226128017_item	2907425	et	3	main
teleris	doc_862226128017_item	2907426	et	3	main
oli	doc_862226128017_item	2907427	et	3	main
näha	doc_862226128017_item	2907429	et	3	main
mis	doc_862226128017_item	2907438	et	4	main
toetasid	doc_862226128017_item	2907439	et	4	main
gorbatšovi	doc_862226128017_item	2907440	et	2	main
tahask	doc_862226128017_item	2907443	et	4	main
võib	doc_862226128017_item	2907447	et	3	main
oleks	doc_862226128017_item	2907450	et	3	main
tõuke	doc_862226128017_item	2907458	et	4	main
ja	doc_862226128017_item	2907459	et	3	main
aitas	doc_862226128017_item	2907463	et	3	main
võidelda	doc_862226128017_item	2907472	et	4	main
2	doc_862226128017_item	2907477	et	2	main
gorbatšovi	doc_862226128017_item	2907480	et	2	main
ajal	doc_862226128017_item	2907482	et	4	main
ja	doc_862226128017_item	2907483	et	3	main
lõpetas	doc_862226128017_item	2907484	et	3	main
eesti	doc_862226128017_item	2907530	et	4	main
taasiseseisvumist	doc_862226128016_item	2907230	et	3	main
oli	doc_862226128016_item	2907231	et	3	main
elektrikriis	doc_862226128016_item	2907233	et	3	main
probleemi	doc_862226128016_item	2907243	et	4	main
ikka	doc_862226128016_item	2907246	et	4	main
on	doc_862226128016_item	2907252	et	4	main
kaks	doc_862226128016_item	2907253	et	3	main
otsa	doc_862226128016_item	2907254	et	4	main
nii	doc_862226128016_item	2907255	et	3	main
ka	doc_862226128016_item	2907256	et	3	main
90ndatel	doc_862226128016_item	2907257	et	4	main
eesti	doc_862226128016_item	2907262	et	4	main
ja	doc_862226128016_item	2907265	et	3	main
inimestel	doc_862226128016_item	2907273	et	3	main
aga	doc_862226128016_item	2907274	et	3	main
oli	doc_862226128016_item	2907275	et	3	main
nüüd	doc_862226128016_item	2907276	et	4	main
on	doc_862226128016_item	2907277	et	4	main
kaupa	doc_862226128016_item	2907278	et	4	main
ülearugi	doc_862226128016_item	2907279	et	3	main
raha	doc_862226128016_item	2907280	et	4	main
aga	doc_862226128016_item	2907281	et	3	main
pole	doc_862226128016_item	2907282	et	3	main
nii	doc_862226128016_item	2907283	et	3	main
palju	doc_862226128016_item	2907284	et	4	main
2	doc_862226128016_item	2907285	et	2	main
laulev	doc_862226128016_item	2907286	et	4	main
revolutsioon	doc_862226128016_item	2907287	et	3	main
see	doc_862226128016_item	2907288	et	3	main
oli	doc_862226128016_item	2907289	et	3	main
enne	doc_862226128016_item	2907290	et	4	main
eesti	doc_862226128016_item	2907291	et	4	main
taasiseseisvumist	doc_862226128016_item	2907292	et	3	main
kui	doc_862226128016_item	2907293	et	3	main
nagu	doc_862226128016_item	2907245	et	3	main
on	doc_862226128016_item	2907247	et	4	main
kõik	doc_862226128016_item	2907248	et	4	main
aja	doc_862226128016_item	2907263	et	4	main
oli	doc_862226128016_item	2907308	et	3	main
kus	doc_862226128016_item	2907317	et	3	main
isamaalisi	doc_862226128016_item	2907319	et	4	main
laule	doc_862226128016_item	2907321	et	4	main
eesti	doc_862226128017_item	2907334	et	4	main
tähendavad	doc_862226128017_item	2907338	et	4	main
glasnost	doc_862226128017_item	2907340	et	4	main
ja	doc_862226128017_item	2907341	et	3	main
eestlastest	doc_862226128017_item	2907357	et	4	main
rahvas	doc_862226128017_item	2907358	et	4	main
ja	doc_862226128017_item	2907359	et	3	main
tahtsid	doc_862226128017_item	2907362	et	4	main
pikk-hermanile	doc_862226128017_item	2907372	et	4	main
sinine-must-valge	doc_862226128017_item	2907373	et	4	main
lipp	doc_862226128017_item	2907374	et	3	main
ja	doc_862226128017_item	2907375	et	3	main
nsvl-st	doc_862226128017_item	2907380	et	3	main
sellele	doc_862226128017_item	2907382	et	4	main
kõigele	doc_862226128017_item	2907386	et	4	main
ja	doc_862226128017_item	2907409	et	3	main
ja	doc_862226128017_item	2907421	et	3	main
eesti	doc_862226128017_item	2907423	et	4	main
võimalik	doc_862226128017_item	2907428	et	3	main
saadet	doc_862226128017_item	2907430	et	3	main
mis	doc_862226128017_item	2907431	et	4	main
öelda	doc_862226128017_item	2907444	et	4	main
olla	doc_862226128017_item	2907448	et	3	main
eesi	doc_862226128017_item	2907452	et	4	main
vabariigiks	doc_862226128017_item	2907453	et	3	main
saada	doc_862226128017_item	2907454	et	4	main
see	doc_862226128017_item	2907455	et	3	main
oli	doc_862226128017_item	2907456	et	3	main
nagu	doc_862226128017_item	2907457	et	3	main
see	doc_862226128017_item	2907462	et	3	main
eesti	doc_862226128017_item	2907471	et	4	main
vabariigiks	doc_862226128017_item	2907476	et	3	main
perestroika	doc_862226128017_item	2907478	et	4	main
erinevaid	doc_862226128017_item	2907521	et	4	main
mis	doc_862226128017_item	2907541	et	4	main
on	doc_862226128017_item	2907559	et	4	main
mis	doc_862226128017_item	2907563	et	4	main
uue	doc_862226128017_item	2907570	et	3	main
režiimi	doc_862226128017_item	2907578	et	2	main
et	doc_862226128017_item	2907588	et	3	main
1	doc_862226128018_item	2907627	et	2	main
rahvarinde	doc_862226128018_item	2907628	et	4	main
roll	doc_862226128018_item	2907629	et	3	main
rahvus-meelsed	doc_862226128018_item	2907645	et	3	main
luulsas	doc_862226128018_item	2907656	et	4	main
telesaates	doc_862226128018_item	2907657	et	3	main
mõtleme	doc_862226128018_item	2907658	et	3	main
veel	doc_862226128018_item	2907659	et	4	main
titme	doc_862226128018_item	2907672	et	4	main
mis	doc_862226128018_item	2907675	et	4	main
nsvl-st	doc_862226128018_item	2907679	et	3	main
rr	doc_862226128018_item	2907680	et	4	main
t	doc_862226128018_item	2907724	et	4	main
kes	doc_862226128018_item	2907733	et	4	main
alustas	doc_862226128018_item	2907734	et	3	main
reforme	doc_862226128018_item	2907735	et	3	main
iseseisev	doc_862226128018_item	2907736	et	3	main
ja	doc_862226128018_item	2907738	et	3	main
omanikele	doc_862226128018_item	2907740	et	3	main
juhti	doc_862226128018_item	2907747	et	4	main
2	doc_862226128018_item	2907757	et	2	main
oli	doc_862226128018_item	2907762	et	3	main
edasi	doc_862226128018_item	2907775	et	3	main
saa	doc_862226128018_item	2907778	et	4	main
alustas	doc_862226128018_item	2907780	et	3	main
reforme	doc_862226128018_item	2907781	et	3	main
keelde	doc_862226128018_item	2907785	et	4	main
saanud	doc_862226128018_item	2907800	et	4	main
raudne	doc_862226128018_item	2907821	et	3	main
g	doc_862226128018_item	2907828	et	4	main
lihtsalt	doc_862226128018_item	2907839	et	4	main
eesti	doc_862226128019_item	2907853	et	4	main
taasiseseivumisprotsessis	doc_862226128019_item	2907854	et	4	main
2	doc_862226128019_item	2907855	et	2	main
head	doc_862226128016_item	2907264	et	4	main
halvad	doc_862226128016_item	2907266	et	4	main
küljed	doc_862226128016_item	2907267	et	3	main
vene	doc_862226128016_item	2907268	et	4	main
inimesed	doc_862226128016_item	2907294	et	3	main
polnud	doc_862226128016_item	2907295	et	3	main
riigis	doc_862226128016_item	2907297	et	3	main
nimelt	doc_862226128016_item	2907299	et	4	main
kardeti	doc_862226128016_item	2907300	et	3	main
nsvl	doc_862226128016_item	2907301	et	4	main
nö	doc_862226128016_item	2907310	et	4	main
rahvusvaheline	doc_862226128016_item	2907311	et	4	main
eesti	doc_862226128016_item	2907320	et	4	main
ja	doc_862226128016_item	2907322	et	3	main
pahameeleprotesti	doc_862226128016_item	2907329	et	4	main
kontrolltöö	doc_862226128017_item	2907330	et	4	main
1	doc_862226128017_item	2907331	et	2	main
taasiseseivumisprotsessis	doc_862226128017_item	2907335	et	4	main
mida	doc_862226128017_item	2907337	et	4	main
käigus	doc_862226128017_item	2907356	et	4	main
muulased	doc_862226128017_item	2907361	et	4	main
saada	doc_862226128017_item	2907363	et	4	main
iseseisvuse	doc_862226128017_item	2907364	et	4	main
maikuus	doc_862226128017_item	2907376	et	3	main
kuulutati	doc_862226128017_item	2907377	et	4	main
sellele	doc_862226128017_item	2907387	et	4	main
aitas	doc_862226128017_item	2907388	et	3	main
soovi	doc_862226128017_item	2907422	et	4	main
olid	doc_862226128017_item	2907435	et	4	main
vastukaaluks	doc_862226128017_item	2907436	et	3	main
nendele	doc_862226128017_item	2907437	et	4	main
lõpetuseks	doc_862226128017_item	2907442	et	4	main
ka	doc_862226128017_item	2907464	et	3	main
koos	doc_862226128017_item	2907466	et	4	main
ja	doc_862226128017_item	2907468	et	3	main
õigus	doc_862226128017_item	2907473	et	4	main
võimule	doc_862226128017_item	2907523	et	3	main
poliitikud	doc_862226128017_item	2907527	et	3	main
jeltsini	doc_862226128017_item	2907528	et	4	main
sai	doc_862226128017_item	2907534	et	4	main
öelda	doc_862226128017_item	2907556	et	4	main
et	doc_862226128017_item	2907557	et	3	main
tõlgitud	doc_862226128017_item	2907562	et	4	main
et	doc_862226128017_item	2907567	et	3	main
reziimi	doc_862226128017_item	2907571	et	4	main
või	doc_862226128017_item	2907573	et	4	main
isegi	doc_862226128017_item	2907574	et	4	main
parem	doc_862226128017_item	2907575	et	4	main
anti	doc_862226128017_item	2907590	et	3	main
mitmeid	doc_862226128017_item	2907599	et	4	main
fakte	doc_862226128017_item	2907600	et	3	main
molotov-ribentropi	doc_862226128017_item	2907602	et	4	main
pakt	doc_862226128017_item	2907603	et	3	main
ja	doc_862226128017_item	2907604	et	3	main
dokumente	doc_862226128017_item	2907605	et	3	main
seega	doc_862226128017_item	2907606	et	4	main
kaasnes	doc_862226128017_item	2907607	et	3	main
ka	doc_862226128017_item	2907608	et	3	main
rahva	doc_862226128017_item	2907609	et	3	main
enesetundmise	doc_862226128017_item	2907610	et	3	main
kõrgendamine	doc_862226128017_item	2907611	et	4	main
rajamiseks	doc_862226128017_item	2907625	et	4	main
kontrolltöö	doc_862226128018_item	2907626	et	4	main
mida	doc_862226128018_item	2907633	et	4	main
tähendavad	doc_862226128018_item	2907634	et	4	main
mõisted	doc_862226128018_item	2907635	et	3	main
idee	doc_862226128018_item	2907647	et	4	main
luua	doc_862226128018_item	2907649	et	4	main
e	doc_862226128018_item	2907651	et	4	main
savisaarelt	doc_862226128018_item	2907652	et	3	main
ta	doc_862226128018_item	2907653	et	4	main
esitas	doc_862226128018_item	2907654	et	3	main
savisaarest	doc_862226128018_item	2907660	et	4	main
esialgu	doc_862226128018_item	2907665	et	3	main
rahva	doc_862226128018_item	2907713	et	3	main
toetusele	doc_862226128018_item	2907715	et	4	main
parraleelselt	doc_862226128018_item	2907719	et	4	main
tegutses	doc_862226128018_item	2907720	et	3	main
rahul	doc_862226128016_item	2907296	et	4	main
liikmesriikide	doc_862226128016_item	2907303	et	3	main
laulupidu	doc_862226128016_item	2907316	et	4	main
väiksemate	doc_862226128016_item	2907302	et	4	main
rahvuskeele	doc_862226128016_item	2907304	et	4	main
kadumist	doc_862226128016_item	2907305	et	4	main
ridade	doc_862226128016_item	2907323	et	3	main
võis	doc_862226128016_item	2907325	et	4	main
rahvarinde	doc_862226128017_item	2907332	et	4	main
perestroika	doc_862226128017_item	2907342	et	4	main
taasisesesvumise	doc_862226128017_item	2907345	et	4	main
juba	doc_862226128017_item	2907348	et	3	main
ka	doc_862226128017_item	2907360	et	3	main
suveräänsus	doc_862226128017_item	2907379	et	4	main
kaasa	doc_862226128017_item	2907389	et	4	main
väga	doc_862226128017_item	2907390	et	3	main
suurel	doc_862226128017_item	2907391	et	3	main
määral	doc_862226128017_item	2907392	et	3	main
rahvarinne	doc_862226128017_item	2907393	et	3	main
igasuguseid	doc_862226128017_item	2907396	et	3	main
vahelt	doc_862226128016_item	2907324	et	4	main
välja	doc_862226128016_item	2907326	et	4	main
lugeda	doc_862226128016_item	2907327	et	3	main
roll	doc_862226128017_item	2907333	et	3	main
mõisted	doc_862226128017_item	2907339	et	3	main
eesti	doc_862226128017_item	2907344	et	4	main
algas	doc_862226128017_item	2907347	et	3	main
pandi	doc_862226128017_item	2907371	et	4	main
rahvarinne	doc_862226128017_item	2907394	et	3	main
koosolekuid	doc_862226128017_item	2907397	et	3	main
hääletusi	doc_862226128017_item	2907398	et	4	main
ja	doc_862226128017_item	2907399	et	3	main
kontserti	doc_862226128017_item	2907400	et	4	main
eesti	doc_862226128017_item	2907401	et	4	main
taasiseisvumise	doc_862226128017_item	2907402	et	4	main
toetamiseks	doc_862226128017_item	2907403	et	4	main
rahvarinne	doc_862226128017_item	2907404	et	3	main
toetas	doc_862226128017_item	2907405	et	3	main
eestimaal	doc_862226128017_item	2907406	et	4	main
elav	doc_862226128017_item	2907407	et	4	main
rahvas	doc_862226128017_item	2907408	et	4	main
ka	doc_862226128017_item	2907410	et	3	main
poliitikud	doc_862226128017_item	2907411	et	3	main
nt	doc_862226128017_item	2907412	et	4	main
savisaar	doc_862226128017_item	2907413	et	3	main
erinevad	doc_862226128017_item	2907414	et	4	main
kultuuritegelased	doc_862226128017_item	2907415	et	3	main
ja	doc_862226128017_item	2907416	et	3	main
poliitikud	doc_862226128017_item	2907417	et	3	main
avaldasid	doc_862226128017_item	2907418	et	4	main
oma	doc_862226128017_item	2907419	et	4	main
arvamust	doc_862226128017_item	2907420	et	3	main
toetasid	doc_862226128017_item	2907432	et	4	main
rahvarinnet	doc_862226128017_item	2907433	et	3	main
ja	doc_862226128017_item	2907434	et	3	main
et	doc_862226128017_item	2907445	et	3	main
rahvarinnete	doc_862226128017_item	2907446	et	3	main
ei	doc_862226128017_item	2907449	et	4	main
võimalik	doc_862226128017_item	2907451	et	3	main
jõud	doc_862226128017_item	2907461	et	4	main
rahva	doc_862226128017_item	2907465	et	3	main
oma	doc_862226128017_item	2907469	et	4	main
õiguste	doc_862226128017_item	2907470	et	4	main
iseseisvaks	doc_862226128017_item	2907475	et	3	main
võimu	doc_862226128017_item	2907481	et	4	main
poliitika	doc_862226128017_item	2907441	et	4	main
kaasaaitav	doc_862226128017_item	2907460	et	4	main
panna	doc_862226128017_item	2907467	et	4	main
olla	doc_862226128017_item	2907474	et	3	main
toimus	doc_862226128017_item	2907479	et	3	main
seda	doc_862226128017_item	2907485	et	3	main
uus	doc_862226128017_item	2907486	et	3	main
venemaa	doc_862226128017_item	2907487	et	4	main
president	doc_862226128017_item	2907488	et	3	main
jeltsin	doc_862226128017_item	2907490	et	4	main
vladimir	doc_862226128017_item	2907489	et	4	main
perestroika	doc_862226128017_item	2907491	et	4	main
tähendas	doc_862226128017_item	2907492	et	3	main
uue	doc_862226128017_item	2907493	et	3	main
riigisüsteemi	doc_862226128017_item	2907494	et	4	main
loomist	doc_862226128017_item	2907495	et	4	main
80-ndate	doc_862226128017_item	2907496	et	4	main
lõpus	doc_862226128017_item	2907497	et	4	main
ja	doc_862226128017_item	2907498	et	3	main
90-ndate	doc_862226128017_item	2907499	et	4	main
alguses	doc_862226128017_item	2907500	et	4	main
toimunud	doc_862226128017_item	2907501	et	4	main
muudatused	doc_862226128017_item	2907502	et	3	main
1	doc_862226128017_item	2907503	et	2	main
eraldasid	doc_862226128017_item	2907504	et	4	main
nsv-st	doc_862226128017_item	2907505	et	3	main
eestimaa	doc_862226128017_item	2907506	et	4	main
läti	doc_862226128017_item	2907507	et	4	main
leedu	doc_862226128017_item	2907508	et	4	main
jne	doc_862226128017_item	2907509	et	4	main
2	doc_862226128017_item	2907510	et	2	main
nsvl	doc_862226128017_item	2907511	et	4	main
hävenemine	doc_862226128017_item	2907512	et	4	main
ja	doc_862226128017_item	2907513	et	3	main
venemaa	doc_862226128017_item	2907514	et	4	main
loomine	doc_862226128017_item	2907515	et	4	main
need	doc_862226128017_item	2907516	et	3	main
kaks	doc_862226128017_item	2907517	et	3	main
teod	doc_862226128017_item	2907518	et	4	main
tõid	doc_862226128017_item	2907519	et	4	main
palju	doc_862226128017_item	2907520	et	4	main
ümberkorraldusi	doc_862226128017_item	2907522	et	3	main
tulid	doc_862226128017_item	2907524	et	4	main
demokraatlik	doc_862226128017_item	2907525	et	3	main
vaatega	doc_862226128017_item	2907526	et	3	main
eesotsas	doc_862226128017_item	2907529	et	4	main
e	doc_862226128017_item	2907535	et	4	main
savisaar	doc_862226128017_item	2907536	et	3	main
eestis	doc_862226128017_item	2907537	et	3	main
kehtestati	doc_862226128017_item	2907538	et	3	main
uus	doc_862226128017_item	2907539	et	3	main
rahaühik	doc_862226128017_item	2907540	et	3	main
suundamine	doc_862226128017_item	2907548	et	4	main
ka	doc_862226128017_item	2907549	et	3	main
läände	doc_862226128017_item	2907550	et	3	main
haridussüsteemi	doc_862226128017_item	2907551	et	4	main
ümberkorraldamine	doc_862226128017_item	2907552	et	3	main
ümberajamine	doc_862226128017_item	2907560	et	4	main
ma	doc_862226128017_item	2907564	et	3	main
öeda	doc_862226128017_item	2907576	et	4	main
uue	doc_862226128017_item	2907577	et	3	main
glasnost	doc_862226128017_item	2907584	et	4	main
see	doc_862226128017_item	2907585	et	3	main
tähendab	doc_862226128017_item	2907586	et	3	main
seda	doc_862226128017_item	2907587	et	3	main
mis	doc_862226128017_item	2907594	et	4	main
avalikustati	doc_862226128017_item	2907598	et	3	main
nt	doc_862226128017_item	2907601	et	4	main
varem	doc_862226128017_item	2907615	et	4	main
keelatud	doc_862226128017_item	2907616	et	4	main
seltsid	doc_862226128017_item	2907617	et	4	main
ja	doc_862226128017_item	2907618	et	3	main
organisatsioonid	doc_862226128017_item	2907619	et	3	main
rahvas	doc_862226128017_item	2907620	et	4	main
massiprganisatsioon	doc_862226128018_item	2907642	et	4	main
kuhu	doc_862226128018_item	2907643	et	3	main
koondusid	doc_862226128018_item	2907644	et	4	main
eesti	doc_862226128018_item	2907670	et	4	main
made	doc_862226128018_item	2907671	et	3	main
loodi	doc_862226128018_item	2907681	et	4	main
et	doc_862226128018_item	2907682	et	3	main
toetada	doc_862226128018_item	2907683	et	3	main
gorbatšovi	doc_862226128018_item	2907684	et	2	main
kodanike	doc_862226128018_item	2907722	et	3	main
hiljem	doc_862226128018_item	2907726	et	3	main
savisaarest	doc_862226128018_item	2907728	et	4	main
esimene	doc_862226128018_item	2907729	et	3	main
taasiseseisvunud	doc_862226128018_item	2907730	et	4	main
õigusjärgsetele	doc_862226128018_item	2907739	et	3	main
koos	doc_862226128018_item	2907746	et	4	main
sini-must-valge	doc_862226128018_item	2907756	et	4	main
leidis	doc_862226128018_item	2907772	et	4	main
et	doc_862226128018_item	2907773	et	3	main
nii	doc_862226128018_item	2907774	et	3	main
ümberehitamine	doc_862226128018_item	2907783	et	3	main
tõlgiti	doc_862226128018_item	2907786	et	3	main
senisest	doc_862226128018_item	2907789	et	3	main
alkoholipoliitika	doc_862226128018_item	2907791	et	4	main
mis	doc_862226128018_item	2907792	et	4	main
enam	doc_862226128018_item	2907798	et	4	main
esipresidendiks	doc_862226128017_item	2907531	et	4	main
tol	doc_862226128017_item	2907532	et	3	main
sai	doc_862226128017_item	2907542	et	4	main
jne	doc_862226128017_item	2907553	et	4	main
ühesõnaga	doc_862226128017_item	2907554	et	3	main
võib	doc_862226128017_item	2907555	et	3	main
otseselt	doc_862226128017_item	2907561	et	4	main
seletaks	doc_862226128017_item	2907565	et	3	main
on	doc_862226128017_item	2907569	et	4	main
kehtestamine	doc_862226128017_item	2907572	et	4	main
loomine	doc_862226128017_item	2907579	et	4	main
rahvale	doc_862226128017_item	2907589	et	3	main
teada	doc_862226128017_item	2907592	et	3	main
tõesti	doc_862226128017_item	2907595	et	3	main
toimus	doc_862226128017_item	2907596	et	3	main
riigis	doc_862226128017_item	2907597	et	3	main
ajal	doc_862226128017_item	2907533	et	4	main
nimetuse	doc_862226128017_item	2907543	et	4	main
kroon	doc_862226128017_item	2907544	et	3	main
majanduse	doc_862226128017_item	2907545	et	4	main
ümberkorraldamine	doc_862226128017_item	2907546	et	3	main
ja	doc_862226128017_item	2907547	et	3	main
perestroika	doc_862226128017_item	2907558	et	4	main
nii	doc_862226128017_item	2907566	et	3	main
see	doc_862226128017_item	2907568	et	3	main
kestva	doc_862226128017_item	2907580	et	4	main
korra	doc_862226128017_item	2907581	et	4	main
ümberkorraldamise	doc_862226128017_item	2907582	et	3	main
teel	doc_862226128017_item	2907583	et	4	main
võimalust	doc_862226128017_item	2907591	et	3	main
sellest	doc_862226128017_item	2907593	et	4	main
hakkasid	doc_862226128017_item	2907612	et	4	main
tegutsema	doc_862226128017_item	2907613	et	3	main
mõned	doc_862226128017_item	2907614	et	3	main
hääletusõigus	doc_862226128017_item	2907622	et	4	main
oma	doc_862226128017_item	2907623	et	4	main
tuleviku	doc_862226128017_item	2907624	et	4	main
glasnost	doc_862226128018_item	2907636	et	4	main
ja	doc_862226128018_item	2907637	et	3	main
perestroika	doc_862226128018_item	2907638	et	4	main
inimesed	doc_862226128018_item	2907646	et	3	main
selle	doc_862226128018_item	2907655	et	4	main
sai	doc_862226128018_item	2907661	et	4	main
pr-i	doc_862226128018_item	2907663	et	4	main
pakuti	doc_862226128018_item	2907666	et	3	main
kallas	doc_862226128018_item	2907673	et	4	main
rr-	doc_862226128018_item	2907685	et	4	main
suurele	doc_862226128018_item	2907714	et	4	main
laulev	doc_862226128018_item	2907716	et	4	main
revolutsioon	doc_862226128018_item	2907717	et	3	main
rr-ga	doc_862226128018_item	2907718	et	3	main
komitee	doc_862226128018_item	2907723	et	4	main
sai	doc_862226128018_item	2907727	et	4	main
ühtustunde	doc_862226128018_item	2907745	et	4	main
välja	doc_862226128018_item	2907755	et	4	main
võimule	doc_862226128018_item	2907760	et	3	main
nsvl-halb	doc_862226128018_item	2907763	et	3	main
doturimine	doc_862226128018_item	2907765	et	4	main
g	doc_862226128018_item	2907771	et	4	main
ei	doc_862226128018_item	2907777	et	4	main
kui	doc_862226128018_item	2907787	et	3	main
olukorda	doc_862226128018_item	2907795	et	4	main
sest	doc_862226128018_item	2907796	et	4	main
viina	doc_862226128018_item	2907797	et	4	main
hakkas	doc_862226128018_item	2907823	et	3	main
lootis	doc_862226128018_item	2907827	et	3	main
oma	doc_862226128018_item	2907829	et	4	main
kutmist	doc_862226128018_item	2907830	et	4	main
õnnestunud	doc_862226128018_item	2907844	et	4	main
alguse	doc_862226128018_item	2907845	et	3	main
rahvarinde	doc_862226128019_item	2907851	et	4	main
roll	doc_862226128019_item	2907852	et	3	main
mõisted	doc_862226128019_item	2907858	et	3	main
1986	doc_862226128019_item	2907863	et	2	main
juhtus	doc_862226128019_item	2907867	et	3	main
eesti	doc_862226128019_item	2907870	et	4	main
saatma	doc_862226128019_item	2907873	et	3	main
surid	doc_862226128019_item	2907883	et	4	main
afganistanis	doc_862226128019_item	2907884	et	4	main
sai	doc_862226128019_item	2907887	et	4	main
rahvas	doc_862226128019_item	2907889	et	4	main
et	doc_862226128019_item	2907891	et	3	main
avalikkus	doc_862226128019_item	2907901	et	4	main
uute	doc_862226128019_item	2907905	et	3	main
mõiste	doc_862226128019_item	2907914	et	4	main
ajal	doc_862226128019_item	2907919	et	4	main
tekks	doc_862226128019_item	2907930	et	4	main
eesmärgiks	doc_862226128019_item	2907940	et	3	main
iseseisvuse	doc_862226128019_item	2907943	et	4	main
püüti	doc_862226128019_item	2907949	et	3	main
tõestada	doc_862226128019_item	2907950	et	3	main
molotov-ribbentroppi	doc_862226128019_item	2907951	et	4	main
venemaa	doc_862226128019_item	2907957	et	4	main
öeseti	doc_862226128019_item	2907961	et	4	main
selleks	doc_862226128019_item	2907965	et	4	main
et	doc_862226128019_item	2907966	et	3	main
kuulata	doc_862226128019_item	2907969	et	4	main
sai	doc_862226128017_item	2907621	et	4	main
eesti	doc_862226128018_item	2907630	et	4	main
taasiseseivumisprotsessis	doc_862226128018_item	2907631	et	4	main
2	doc_862226128018_item	2907632	et	2	main
1	doc_862226128018_item	2907639	et	2	main
rr	doc_862226128018_item	2907640	et	4	main
oli	doc_862226128018_item	2907641	et	3	main
rr	doc_862226128018_item	2907648	et	4	main
tuli	doc_862226128018_item	2907650	et	4	main
hiljem	doc_862226128018_item	2907662	et	3	main
juht	doc_862226128018_item	2907664	et	3	main
välja	doc_862226128018_item	2907667	et	4	main
ime	doc_862226128018_item	2907668	et	4	main
isemajandav	doc_862226128018_item	2907669	et	3	main
savisaar	doc_862226128018_item	2907674	et	3	main
taotlse	doc_862226128018_item	2907676	et	4	main
majanduslikku	doc_862226128018_item	2907677	et	4	main
autonoomiat	doc_862226128018_item	2907678	et	3	main
i	doc_862226128018_item	2907686	et	4	main
vastasseis	doc_862226128018_item	2907687	et	3	main
interrindega	doc_862226128018_item	2907688	et	3	main
vanameelsete	doc_862226128018_item	2907689	et	3	main
moodustatud	doc_862226128018_item	2907690	et	4	main
ühendus	doc_862226128018_item	2907691	et	4	main
kuhu	doc_862226128018_item	2907692	et	3	main
kuulusid	doc_862226128018_item	2907693	et	4	main
lihtrahvas	doc_862226128018_item	2907694	et	4	main
töölised	doc_862226128018_item	2907695	et	3	main
enamik	doc_862226128018_item	2907696	et	3	main
neist	doc_862226128018_item	2907697	et	4	main
venelased	doc_862226128018_item	2907698	et	3	main
nõudsid	doc_862226128018_item	2907699	et	4	main
et	doc_862226128018_item	2907700	et	3	main
nsvl	doc_862226128018_item	2907701	et	4	main
lammutamine	doc_862226128018_item	2907702	et	4	main
peatataks	doc_862226128018_item	2907703	et	4	main
rr	doc_862226128018_item	2907704	et	4	main
andis	doc_862226128018_item	2907705	et	3	main
põhilise	doc_862226128018_item	2907706	et	3	main
tõkke	doc_862226128018_item	2907707	et	3	main
taasiseseivumises	doc_862226128018_item	2907708	et	4	main
kujunes	doc_862226128018_item	2907709	et	3	main
nii	doc_862226128018_item	2907710	et	3	main
võimsaks	doc_862226128018_item	2907711	et	3	main
tänu	doc_862226128018_item	2907712	et	4	main
eesti	doc_862226128018_item	2907731	et	4	main
peaminister	doc_862226128018_item	2907732	et	3	main
rr	doc_862226128018_item	2907743	et	4	main
tekitas	doc_862226128018_item	2907744	et	3	main
toodi	doc_862226128018_item	2907754	et	4	main
gorbatšov	doc_862226128018_item	2907759	et	2	main
pidev	doc_862226128018_item	2907764	et	3	main
viis	doc_862226128018_item	2907766	et	4	main
toiduainete	doc_862226128018_item	2907767	et	3	main
ja	doc_862226128018_item	2907768	et	3	main
tarbekaupade	doc_862226128018_item	2907769	et	3	main
kriisini	doc_862226128018_item	2907770	et	3	main
perestroika	doc_862226128018_item	2907782	et	4	main
tegelikult	doc_862226128018_item	2907793	et	4	main
halvendas	doc_862226128018_item	2907794	et	3	main
ei	doc_862226128018_item	2907799	et	4	main
mis	doc_862226128018_item	2907804	et	4	main
sisaldas	doc_862226128018_item	2907805	et	3	main
piiritust	doc_862226128018_item	2907806	et	4	main
olmekuviin	doc_862226128018_item	2907807	et	4	main
annoll	doc_862226128018_item	2907808	et	4	main
odavad	doc_862226128018_item	2907809	et	3	main
adekolonnid	doc_862226128018_item	2907810	et	4	main
g	doc_862226128018_item	2907811	et	4	main
uue	doc_862226128018_item	2907812	et	3	main
poliitika	doc_862226128018_item	2907813	et	4	main
hulka	doc_862226128018_item	2907814	et	4	main
kuulus	doc_862226128018_item	2907815	et	4	main
ka	doc_862226128018_item	2907816	et	3	main
suhete	doc_862226128018_item	2907817	et	3	main
taastamine	doc_862226128018_item	2907818	et	4	main
lääne	doc_862226128018_item	2907819	et	4	main
riikigeda	doc_862226128018_item	2907820	et	4	main
tasapisi	doc_862226128018_item	2907824	et	3	main
siiski	doc_862226128018_item	2907826	et	4	main
kommunism	doc_862226128018_item	2907835	et	3	main
sai	doc_862226128018_item	2907846	et	4	main
nsvl	doc_862226128018_item	2907847	et	4	main
katastroof	doc_862226128019_item	2907868	et	3	main
mehi	doc_862226128019_item	2907871	et	3	main
hakkati	doc_862226128019_item	2907872	et	3	main
poisid	doc_862226128019_item	2907880	et	4	main
ja	doc_862226128019_item	2907881	et	3	main
mehed	doc_862226128019_item	2907882	et	3	main
aru	doc_862226128019_item	2907890	et	4	main
eest	doc_862226128019_item	2907896	et	4	main
võidelda	doc_862226128019_item	2907897	et	4	main
hakkati	doc_862226128019_item	2907902	et	3	main
kaevanduste	doc_862226128019_item	2907907	et	4	main
tekkimiste	doc_862226128019_item	2907908	et	4	main
vastu	doc_862226128019_item	2907909	et	3	main
korraldati	doc_862226128019_item	2907910	et	3	main
rahvalikkused	doc_862226128019_item	2907911	et	4	main
isemajandav	doc_862226128019_item	2907916	et	3	main
tekkis	doc_862226128019_item	2907920	et	3	main
muinaskogude	doc_862226128019_item	2907922	et	3	main
selts	doc_862226128019_item	2907923	et	3	main
hakkasid	doc_862226128019_item	2907925	et	4	main
paremasse	doc_862226128019_item	2907927	et	4	main
tulevikku	doc_862226128019_item	2907928	et	4	main
hiljem	doc_862226128019_item	2907929	et	3	main
idee	doc_862226128019_item	2907933	et	4	main
pidada	doc_862226128019_item	2907937	et	4	main
savisaari	doc_862226128019_item	2907938	et	3	main
eesti	doc_862226128019_item	2907942	et	4	main
ka	doc_862226128018_item	2907721	et	3	main
kelam	doc_862226128018_item	2907725	et	4	main
eelarve	doc_862226128018_item	2907737	et	4	main
vara	doc_862226128018_item	2907741	et	4	main
tagastamine	doc_862226128018_item	2907742	et	4	main
süsteemi	doc_862226128018_item	2907748	et	4	main
vastu	doc_862226128018_item	2907749	et	3	main
astuda	doc_862226128018_item	2907750	et	3	main
korraldati	doc_862226128018_item	2907751	et	3	main
rahvakogunemisi	doc_862226128018_item	2907752	et	3	main
miitinguid	doc_862226128018_item	2907753	et	3	main
kui	doc_862226128018_item	2907758	et	3	main
tuli	doc_862226128018_item	2907761	et	4	main
minna	doc_862226128018_item	2907776	et	3	main
ja	doc_862226128018_item	2907779	et	3	main
eesti	doc_862226128018_item	2907784	et	4	main
nutmine	doc_862226128018_item	2907788	et	4	main
rangem	doc_862226128018_item	2907790	et	4	main
hakati	doc_862226128018_item	2907801	et	3	main
jooma	doc_862226128018_item	2907802	et	4	main
kõike	doc_862226128018_item	2907803	et	4	main
langema	doc_862226128018_item	2907825	et	3	main
nii	doc_862226128018_item	2907833	et	3	main
et	doc_862226128018_item	2907834	et	3	main
säilib	doc_862226128018_item	2907836	et	3	main
võtab	doc_862226128018_item	2907838	et	3	main
uue	doc_862226128018_item	2907840	et	3	main
kuju	doc_862226128018_item	2907841	et	4	main
see	doc_862226128018_item	2907842	et	3	main
ei	doc_862226128018_item	2907843	et	4	main
kontrolltöö	doc_862226128019_item	2907849	et	4	main
1	doc_862226128019_item	2907850	et	2	main
tähendavad	doc_862226128019_item	2907857	et	4	main
ja	doc_862226128019_item	2907869	et	3	main
aja	doc_862226128019_item	2907878	et	4	main
võõravõimude	doc_862226128019_item	2907885	et	3	main
eesti	doc_862226128019_item	2907888	et	4	main
nõrgenes	doc_862226128019_item	2907898	et	3	main
tsensuur	doc_862226128019_item	2907899	et	3	main
tegema	doc_862226128019_item	2907904	et	3	main
tekkis	doc_862226128019_item	2907913	et	3	main
eesti	doc_862226128019_item	2907917	et	4	main
uskuma	doc_862226128019_item	2907926	et	3	main
rahvarinne	doc_862226128019_item	2907932	et	3	main
rajajaks	doc_862226128019_item	2907935	et	4	main
juuridilist	doc_862226128019_item	2907953	et	4	main
olemasolu	doc_862226128019_item	2907960	et	4	main
ansamblite	doc_862226128019_item	2907974	et	3	main
ettendus	doc_862226128019_item	2907975	et	4	main
ja	doc_862226128019_item	2907982	et	3	main
tunda	doc_862226128019_item	2907983	et	3	main
rr	doc_862226128019_item	2907986	et	4	main
gorbatšov	doc_862226128019_item	2908022	et	2	main
see	doc_862226128019_item	2908031	et	3	main
seotud	doc_862226128019_item	2908033	et	4	main
majanduslikku	doc_862226128019_item	2908034	et	4	main
kiiremas	doc_862226128019_item	2908044	et	4	main
varjata	doc_862226128019_item	2908049	et	4	main
olemasolu	doc_862226128019_item	2908051	et	4	main
ei	doc_862226128019_item	2908053	et	4	main
olnud	doc_862226128019_item	2908054	et	4	main
ta	doc_862226128019_item	2908063	et	4	main
rohkem	doc_862226128019_item	2908066	et	4	main
samal	doc_862226128019_item	2908068	et	3	main
valdkondi	doc_862226128019_item	2908083	et	4	main
oli	doc_862226128019_item	2908089	et	3	main
eesriie	doc_862226128018_item	2907822	et	3	main
läbi	doc_862226128018_item	2907831	et	4	main
viia	doc_862226128018_item	2907832	et	3	main
see	doc_862226128018_item	2907837	et	3	main
lagunemine	doc_862226128018_item	2907848	et	4	main
mida	doc_862226128019_item	2907856	et	4	main
ja	doc_862226128019_item	2907860	et	3	main
1	doc_862226128019_item	2907862	et	2	main
siis	doc_862226128019_item	2907864	et	3	main
kui	doc_862226128019_item	2907865	et	3	main
eesti	doc_862226128019_item	2907879	et	4	main
vabaduse	doc_862226128019_item	2907895	et	4	main
midagi	doc_862226128019_item	2907903	et	4	main
fosvoriiti	doc_862226128019_item	2907906	et	4	main
ime	doc_862226128019_item	2907915	et	4	main
glasnost	doc_862226128019_item	2907859	et	4	main
perestroika	doc_862226128019_item	2907861	et	4	main
tšernobolis	doc_862226128019_item	2907866	et	2	main
sinna	doc_862226128019_item	2907874	et	3	main
tagajargade	doc_862226128019_item	2907875	et	4	main
likvideerimiseks	doc_862226128019_item	2907876	et	4	main
samal	doc_862226128019_item	2907877	et	3	main
eest	doc_862226128019_item	2907886	et	4	main
tuli	doc_862226128019_item	2907892	et	4	main
õige	doc_862226128019_item	2907893	et	4	main
aega	doc_862226128019_item	2907894	et	4	main
surenev	doc_862226128019_item	2907900	et	4	main
kogumised	doc_862226128019_item	2907912	et	4	main
samal	doc_862226128019_item	2907918	et	3	main
eesti	doc_862226128019_item	2907921	et	4	main
inimesed	doc_862226128019_item	2907924	et	3	main
seltsi	doc_862226128019_item	2907934	et	4	main
saab	doc_862226128019_item	2907936	et	3	main
nende	doc_862226128019_item	2907939	et	4	main
õigust	doc_862226128019_item	2907954	et	4	main
kuigi	doc_862226128019_item	2907955	et	3	main
nõukogude	doc_862226128019_item	2907956	et	3	main
olla	doc_862226128019_item	2907967	et	3	main
laule	doc_862226128019_item	2907971	et	4	main
ja	doc_862226128019_item	2907972	et	3	main
eest	doc_862226128019_item	2907981	et	4	main
ka	doc_862226128019_item	2907984	et	3	main
ühistunnet	doc_862226128019_item	2907985	et	3	main
palju	doc_862226128019_item	2907988	et	4	main
temaga	doc_862226128019_item	2908023	et	3	main
perestroika	doc_862226128019_item	2908030	et	4	main
mida	doc_862226128019_item	2908041	et	4	main
samal	doc_862226128019_item	2908047	et	3	main
nii	doc_862226128019_item	2908056	et	3	main
mulje	doc_862226128019_item	2908060	et	4	main
et	doc_862226128019_item	2908061	et	3	main
nüd	doc_862226128019_item	2908062	et	4	main
pooed	doc_862226128019_item	2908073	et	4	main
rr	doc_862226128019_item	2907931	et	4	main
oli	doc_862226128019_item	2907941	et	3	main
pakti	doc_862226128019_item	2907952	et	4	main
eitas	doc_862226128019_item	2907958	et	3	main
kogunes	doc_862226128019_item	2907962	et	3	main
koos	doc_862226128019_item	2907968	et	4	main
rahva	doc_862226128019_item	2907970	et	3	main
oma	doc_862226128019_item	2907979	et	4	main
rahva	doc_862226128019_item	2907980	et	3	main
selles	doc_862226128019_item	2907989	et	4	main
suunas	doc_862226128019_item	2907990	et	4	main
et	doc_862226128019_item	2907991	et	3	main
taastada	doc_862226128019_item	2907992	et	3	main
eesti	doc_862226128019_item	2907993	et	4	main
sümboolikat	doc_862226128019_item	2907994	et	3	main
korraldati	doc_862226128019_item	2907995	et	3	main
oma	doc_862226128019_item	2907996	et	4	main
valimised	doc_862226128019_item	2907997	et	4	main
pärast	doc_862226128019_item	2907998	et	4	main
paljud	doc_862226128019_item	2907999	et	3	main
noored	doc_862226128019_item	2908000	et	3	main
poliitikud	doc_862226128019_item	2908001	et	3	main
kes	doc_862226128019_item	2908002	et	4	main
juhendasid	doc_862226128019_item	2908003	et	4	main
rahvarinnet	doc_862226128019_item	2908004	et	3	main
tegid	doc_862226128019_item	2908005	et	4	main
ka	doc_862226128019_item	2908006	et	3	main
ka	doc_862226128019_item	2908007	et	3	main
palju	doc_862226128019_item	2908008	et	4	main
juba	doc_862226128019_item	2908009	et	3	main
iseseisvas	doc_862226128019_item	2908010	et	3	main
eestis	doc_862226128019_item	2908011	et	3	main
nendest	doc_862226128019_item	2908012	et	4	main
kasvas	doc_862226128019_item	2908013	et	3	main
välja	doc_862226128019_item	2908014	et	4	main
isamaaliidu	doc_862226128019_item	2908015	et	4	main
partei	doc_862226128019_item	2908016	et	4	main
2	doc_862226128019_item	2908017	et	2	main
1985	doc_862226128019_item	2908018	et	2	main
tuli	doc_862226128019_item	2908019	et	4	main
võimule	doc_862226128019_item	2908020	et	3	main
m	doc_862226128019_item	2908021	et	4	main
tulid	doc_862226128019_item	2908024	et	4	main
mõisted	doc_862226128019_item	2908026	et	3	main
hukkuga	doc_862226128019_item	2908035	et	4	main
nõukogude	doc_862226128019_item	2908036	et	3	main
korras	doc_862226128019_item	2908045	et	4	main
nüüd	doc_862226128019_item	2908055	et	4	main
range	doc_862226128019_item	2908057	et	4	main
taastamine	doc_862226128019_item	2907944	et	4	main
nad	doc_862226128019_item	2907945	et	3	main
korraldasid	doc_862226128019_item	2907946	et	4	main
igasugused	doc_862226128019_item	2907947	et	3	main
kokkutulekud	doc_862226128019_item	2907948	et	3	main
selle	doc_862226128019_item	2907959	et	4	main
rahvas	doc_862226128019_item	2907963	et	4	main
lauluvaljakul	doc_862226128019_item	2907964	et	4	main
vaadata	doc_862226128019_item	2907973	et	4	main
uhkust	doc_862226128019_item	2907977	et	4	main
eest	doc_862226128019_item	2907978	et	4	main
töötas	doc_862226128019_item	2907987	et	3	main
tunda	doc_862226128019_item	2907976	et	3	main
oli	doc_862226128019_item	2908032	et	3	main
tuli	doc_862226128019_item	2908042	et	4	main
parata	doc_862226128019_item	2908043	et	3	main
ka	doc_862226128019_item	2908048	et	3	main
saab	doc_862226128019_item	2908064	et	3	main
informatsiooni	doc_862226128019_item	2908067	et	4	main
ajal	doc_862226128019_item	2908069	et	4	main
olukord	doc_862226128019_item	2908070	et	3	main
oli	doc_862226128019_item	2908071	et	3	main
raske	doc_862226128019_item	2908084	et	4	main
oli	doc_862226128019_item	2908085	et	3	main
sellised	doc_862226128019_item	2908025	et	4	main
nagu	doc_862226128019_item	2908027	et	3	main
glasnost	doc_862226128019_item	2908028	et	4	main
ja	doc_862226128019_item	2908029	et	3	main
venemaal	doc_862226128019_item	2908037	et	4	main
oli	doc_862226128019_item	2908038	et	3	main
majanduslik	doc_862226128019_item	2908039	et	3	main
kriis	doc_862226128019_item	2908040	et	3	main
ja	doc_862226128019_item	2908046	et	3	main
selle	doc_862226128019_item	2908050	et	4	main
tsensuur	doc_862226128019_item	2908052	et	3	main
tekkis	doc_862226128019_item	2908059	et	3	main
hulga	doc_862226128019_item	2908065	et	4	main
olid	doc_862226128019_item	2908074	et	4	main
tühjad	doc_862226128019_item	2908075	et	3	main
kuigi	doc_862226128019_item	2908076	et	3	main
raha	doc_862226128019_item	2908077	et	4	main
inimestel	doc_862226128019_item	2908078	et	3	main
oli	doc_862226128019_item	2908079	et	3	main
riik	doc_862226128019_item	2908080	et	3	main
doteeris	doc_862226128019_item	2908081	et	4	main
näiteks	doc_862226128019_item	2908087	et	4	main
raamatuid	doc_862226128019_item	2908088	et	3	main
propagandat	doc_862226128019_item	2908091	et	3	main
näiteks	doc_862226128019_item	2908092	et	4	main
olid	doc_862226128019_item	2908093	et	4	main
teatud	doc_862226128019_item	2908094	et	4	main
propaganda	doc_862226128019_item	2908095	et	4	main
brošuurid	doc_862226128019_item	2908096	et	2	main
mida	doc_862226128019_item	2908097	et	4	main
pidid	doc_862226128019_item	2908098	et	4	main
isegi	doc_862226128019_item	2908099	et	4	main
lapsed	doc_862226128019_item	2908100	et	3	main
koolis	doc_862226128019_item	2908101	et	4	main
lugema	doc_862226128019_item	2908102	et	4	main
perestroika	doc_862226128019_item	2908103	et	4	main
lõppes	doc_862226128019_item	2908104	et	4	main
nõukogude	doc_862226128019_item	2908105	et	3	main
venemaa	doc_862226128019_item	2908106	et	4	main
lagunemisega	doc_862226128019_item	2908107	et	4	main
inimestel	doc_862226128019_item	2908058	et	3	main
raske	doc_862226128019_item	2908072	et	4	main
palju	doc_862226128019_item	2908082	et	4	main
saada	doc_862226128019_item	2908086	et	4	main
palju	doc_862226128019_item	2908090	et	4	main
kultuurielu	doc_866101568973_item	2908415	et	4	main
oli	doc_866101568973_item	2908416	et	3	main
peamiseks	doc_866101568973_item	2908420	et	3	main
jpm	doc_866101568973_item	2908429	et	4	main
taasavati	doc_866101568973_item	2908430	et	3	main
1919a	doc_866101568973_item	2908433	et	4	main
kuulsuse	doc_866101568973_item	2908442	et	4	main
astronoomid	doc_866101568973_item	2908443	et	3	main
ka	doc_866101568973_item	2908452	et	3	main
arv	doc_866101568973_item	2908454	et	3	main
urbaniseerumisega	doc_866101568973_item	2908467	et	4	main
on	doc_866101568973_item	2908483	et	4	main
alkoholi	doc_866101568973_item	2908491	et	4	main
veel	doc_866101568973_item	2908494	et	4	main
eesti	doc_866101568973_item	2908506	et	4	main
keele	doc_866101568973_item	2908511	et	4	main
eesti	doc_866101568973_item	2908515	et	4	main
keele	doc_866101568973_item	2908516	et	4	main
ja	doc_866101568973_item	2908517	et	3	main
teadlasi	doc_866101568973_item	2908519	et	3	main
suunatud	doc_866101568973_item	2908417	et	4	main
eesti	doc_866101568973_item	2908422	et	4	main
ilmus	doc_866101568973_item	2908424	et	4	main
väga	doc_866101568973_item	2908425	et	3	main
palju	doc_866101568973_item	2908426	et	4	main
kirjandeid	doc_866101568973_item	2908427	et	3	main
haridus	doc_866101568973_item	2908428	et	3	main
teadused	doc_866101568973_item	2908435	et	3	main
geograafid	doc_866101568973_item	2908444	et	4	main
suurenema	doc_866101568973_item	2908456	et	3	main
linnastus	doc_866101568973_item	2908458	et	4	main
maal	doc_866101568973_item	2908463	et	4	main
nüüd	doc_866101568973_item	2908465	et	4	main
seoses	doc_866101568973_item	2908466	et	4	main
linna	doc_866101568973_item	2908471	et	4	main
kirjanike	doc_866101568973_item	2908477	et	3	main
selts	doc_866101568973_item	2908478	et	3	main
jne	doc_866101568973_item	2908481	et	4	main
mis	doc_866101568973_item	2908482	et	4	main
tuli	doc_866101568973_item	2908488	et	4	main
tubakatoodete	doc_866101568973_item	2908489	et	3	main
ja	doc_866101568973_item	2908490	et	3	main
prostitutsioonist	doc_866101568973_item	2908496	et	3	main
oli	doc_866101568973_item	2908498	et	3	main
ajal	doc_866101568973_item	2908500	et	4	main
legaalne	doc_866101568973_item	2908501	et	3	main
entsüklopeedia	doc_866101568973_item	2908507	et	4	main
teaduskond	doc_866101568973_item	2908512	et	3	main
väiksed	doc_866101568973_item	2908521	et	4	main
keeles	doc_866101568973_item	2908535	et	4	main
esimestel	doc_866101568973_item	2908544	et	4	main
millest	doc_866101568973_item	2908548	et	3	main
tegelesid	doc_866101568973_item	2908551	et	4	main
kuid	doc_866101568973_item	2908555	et	4	main
järgnevad	doc_866101568973_item	2908556	et	4	main
aastad	doc_866101568973_item	2908557	et	3	main
kultuurielu	doc_866101568973_item	2908558	et	4	main
juba	doc_866101568973_item	2908559	et	3	main
hakas	doc_866101568973_item	2908560	et	4	main
ajal	doc_866101568973_item	2908574	et	4	main
oli	doc_866101568973_item	2908575	et	3	main
režiimi	doc_866101568973_item	2908589	et	2	main
teadlased	doc_866101568973_item	2908591	et	3	main
kirjanikud	doc_866101568973_item	2908593	et	3	main
pandi	doc_866101568973_item	2908596	et	4	main
arenema	doc_866101568973_item	2908608	et	3	main
realism	doc_866101568973_item	2908623	et	3	main
ei	doc_866101568973_item	2908630	et	4	main
tundub	doc_866101568973_item	2908636	et	3	main
palju	doc_866101568973_item	2908646	et	4	main
elustiili	doc_866101568973_item	2908651	et	4	main
nendele	doc_866101568973_item	2908655	et	4	main
nsv	doc_866101568973_item	2908661	et	4	main
hea	doc_866101568973_item	2908665	et	4	main
raamatute	doc_86991684127_item	2908698	et	3	main
me	doc_86991684127_item	2908700	et	4	main
võime	doc_86991684127_item	2908701	et	4	main
kontrolltöö	doc_866101568973_item	2908398	et	4	main
1	doc_866101568973_item	2908399	et	2	main
võrrelge	doc_866101568973_item	2908400	et	3	main
ev	doc_866101568973_item	2908401	et	4	main
aegset	doc_866101568973_item	2908402	et	3	main
ensv	doc_866101568973_item	2908404	et	4	main
ja	doc_866101568973_item	2908403	et	3	main
pärastsõjajärgset	doc_866101568973_item	2908405	et	3	main
kultuurielu	doc_866101568973_item	2908406	et	4	main
2	doc_866101568973_item	2908407	et	2	main
sotsialistlik	doc_866101568973_item	2908408	et	3	main
realism	doc_866101568973_item	2908409	et	3	main
kui	doc_866101568973_item	2908410	et	3	main
kirjandusvool	doc_866101568973_item	2908411	et	4	main
1	doc_866101568973_item	2908412	et	2	main
ev	doc_866101568973_item	2908413	et	4	main
ajal	doc_866101568973_item	2908414	et	4	main
ja	doc_866101568973_item	2908419	et	3	main
arenemine	doc_866101568973_item	2908423	et	4	main
ülikool	doc_866101568973_item	2908432	et	4	main
eestlastest	doc_866101568973_item	2908438	et	4	main
teadlased	doc_866101568973_item	2908439	et	3	main
jne	doc_866101568973_item	2908445	et	4	main
eestis	doc_866101568973_item	2908446	et	3	main
avati	doc_866101568973_item	2908447	et	3	main
teatreid	doc_866101568973_item	2908448	et	3	main
hakati	doc_866101568973_item	2908449	et	3	main
näitlejaid	doc_866101568973_item	2908451	et	4	main
hakas	doc_866101568973_item	2908455	et	4	main
varem	doc_866101568973_item	2908459	et	4	main
toimos	doc_866101568973_item	2908461	et	4	main
rohkesti	doc_866101568973_item	2908462	et	3	main
kultuurielu	doc_866101568973_item	2908470	et	4	main
huvitav	doc_866101568973_item	2908484	et	4	main
et	doc_866101568973_item	2908485	et	3	main
müügist	doc_866101568973_item	2908492	et	3	main
ka	doc_866101568973_item	2908495	et	3	main
ilmus	doc_866101568973_item	2908504	et	4	main
esimene	doc_866101568973_item	2908505	et	3	main
kultuuri	doc_866101568973_item	2908518	et	4	main
kuid	doc_866101568973_item	2908520	et	4	main
rahvused	doc_866101568973_item	2908522	et	3	main
aastatel	doc_866101568973_item	2908545	et	4	main
taastamisega	doc_866101568973_item	2908554	et	4	main
ennast	doc_866101568973_item	2908561	et	4	main
näitama	doc_866101568973_item	2908562	et	3	main
ja	doc_866101568973_item	2908563	et	3	main
see	doc_866101568973_item	2908564	et	3	main
muutunud	doc_866101568973_item	2908568	et	4	main
mis	doc_866101568973_item	2908570	et	4	main
ilmunud	doc_866101568973_item	2908572	et	4	main
ev	doc_866101568973_item	2908573	et	4	main
kultuur	doc_866101568973_item	2908579	et	3	main
mudeli	doc_866101568973_item	2908583	et	3	main
pidi	doc_866101568973_item	2908586	et	4	main
ühe	doc_866101568973_item	2908602	et	4	main
sõnaga	doc_866101568973_item	2908603	et	3	main
kõik	doc_866101568973_item	2908604	et	4	main
ja	doc_866101568973_item	2908607	et	3	main
olnud	doc_866101568973_item	2908631	et	4	main
kohta	doc_866101568973_item	2908632	et	4	main
olnud	doc_866101568973_item	2908642	et	4	main
öeldud	doc_866101568973_item	2908643	et	4	main
suund	doc_866101568973_item	2908653	et	3	main
selles	doc_866101568973_item	2908657	et	4	main
kirjanduses	doc_866101568973_item	2908658	et	3	main
ei	doc_866101568973_item	2908659	et	4	main
oli	doc_866101568973_item	2908664	et	3	main
ja	doc_866101568973_item	2908666	et	3	main
maailma	doc_86991684127_item	2908694	et	4	main
järgi	doc_86991684127_item	2908699	et	4	main
muutus	doc_86991684127_item	2908704	et	4	main
oli	doc_86991684127_item	2908710	et	3	main
eile	doc_86991684127_item	2908711	et	3	main
ja	doc_86991684127_item	2908712	et	3	main
milline	doc_86991684127_item	2908713	et	3	main
on	doc_86991684127_item	2908714	et	4	main
kultuur	doc_86991684127_item	2908720	et	3	main
aga	doc_86991684127_item	2908722	et	3	main
ööelda	doc_86991684127_item	2908727	et	4	main
seostub	doc_86991684127_item	2908730	et	3	main
kirjandusega	doc_86991684127_item	2908732	et	3	main
kohal	doc_86991684127_item	2908741	et	4	main
kirjandusega	doc_86991684127_item	2908742	et	3	main
seisab	doc_86991684127_item	2908743	et	3	main
mis	doc_872470917318_item	2908751	et	4	main
põletati	doc_872470917318_item	2908757	et	3	main
arenemisele	doc_866101568973_item	2908418	et	4	main
oli	doc_866101568973_item	2908421	et	3	main
paljud	doc_866101568973_item	2908434	et	3	main
arenema	doc_866101568973_item	2908437	et	3	main
kultuur	doc_866101568973_item	2908457	et	3	main
kuid	doc_866101568973_item	2908464	et	4	main
tol	doc_866101568973_item	2908472	et	3	main
ajal	doc_866101568973_item	2908473	et	4	main
seltsid	doc_866101568973_item	2908476	et	4	main
naiste	doc_866101568973_item	2908479	et	3	main
kultuurielu	doc_866101568973_item	2908486	et	4	main
finanseerimine	doc_866101568973_item	2908487	et	4	main
ajal	doc_866101568973_item	2908503	et	4	main
eesti	doc_866101568973_item	2908510	et	4	main
oli	doc_866101568973_item	2908523	et	3	main
seltse	doc_866101568973_item	2908527	et	3	main
oli	doc_866101568973_item	2908529	et	3	main
saada	doc_866101568973_item	2908531	et	4	main
algul	doc_866101568973_item	2908540	et	4	main
väga	doc_866101568973_item	2908541	et	3	main
raske	doc_866101568973_item	2908542	et	4	main
ja	doc_866101568973_item	2908543	et	3	main
kultuuri	doc_866101568973_item	2908547	et	4	main
oli	doc_866101568973_item	2908565	et	3	main
kirjandus	doc_866101568973_item	2908569	et	3	main
oli	doc_866101568973_item	2908571	et	3	main
pidi	doc_866101568973_item	2908580	et	4	main
arenema	doc_866101568973_item	2908581	et	3	main
sotsialistliku	doc_866101568973_item	2908582	et	3	main
paljud	doc_866101568973_item	2908590	et	3	main
olema	doc_866101568973_item	2908606	et	4	main
tartu	doc_866101568973_item	2908431	et	4	main
hakasid	doc_866101568973_item	2908436	et	4	main
said	doc_866101568973_item	2908440	et	4	main
rahvusvahelise	doc_866101568973_item	2908441	et	4	main
koolitama	doc_866101568973_item	2908450	et	3	main
kinomajade	doc_866101568973_item	2908453	et	3	main
kultuurielu	doc_866101568973_item	2908460	et	4	main
kolis	doc_866101568973_item	2908468	et	4	main
ka	doc_866101568973_item	2908469	et	3	main
tegutsesid	doc_866101568973_item	2908474	et	4	main
kõikvõimalikud	doc_866101568973_item	2908475	et	3	main
selts	doc_866101568973_item	2908480	et	3	main
ja	doc_866101568973_item	2908493	et	3	main
mis	doc_866101568973_item	2908497	et	4	main
tol	doc_866101568973_item	2908499	et	3	main
ev	doc_866101568973_item	2908502	et	4	main
tüs	doc_866101568973_item	2908508	et	4	main
avati	doc_866101568973_item	2908509	et	3	main
hakati	doc_866101568973_item	2908513	et	3	main
koolitama	doc_866101568973_item	2908514	et	3	main
võimelised	doc_866101568973_item	2908524	et	4	main
oma	doc_866101568973_item	2908526	et	4	main
moodustama	doc_866101568973_item	2908528	et	3	main
ensv	doc_866101568973_item	2908536	et	4	main
pärastsõjajärgne	doc_866101568973_item	2908537	et	3	main
elu	doc_866101568973_item	2908538	et	4	main
polnudki	doc_866101568973_item	2908546	et	3	main
juba	doc_866101568973_item	2908566	et	3	main
keelatud	doc_866101568973_item	2908577	et	4	main
üldse	doc_866101568973_item	2908578	et	3	main
esile	doc_866101568973_item	2908585	et	3	main
tõstma	doc_866101568973_item	2908587	et	3	main
represeeriti	doc_866101568973_item	2908594	et	4	main
paljud	doc_866101568973_item	2908598	et	3	main
algas	doc_866101568973_item	2908600	et	3	main
venestumispoliitika	doc_866101568973_item	2908601	et	4	main
sotsialistlik	doc_866101568973_item	2908622	et	3	main
oli	doc_866101568973_item	2908624	et	3	main
sotsialismi	doc_866101568973_item	2908626	et	4	main
ületamisele	doc_866101568973_item	2908627	et	4	main
sotsialistlikus	doc_866101568973_item	2908628	et	4	main
kirjanduses	doc_866101568973_item	2908629	et	3	main
kriitikale	doc_866101568973_item	2908634	et	3	main
küll	doc_866101568973_item	2908637	et	4	main
sest	doc_866101568973_item	2908639	et	4	main
seal	doc_866101568973_item	2908640	et	4	main
ei	doc_866101568973_item	2908641	et	4	main
inimesi	doc_866101568973_item	2908647	et	4	main
pärast	doc_866101568973_item	2908652	et	4	main
miinustest	doc_866101568973_item	2908662	et	4	main
sest	doc_86991684127_item	2908696	et	4	main
kultuur	doc_86991684127_item	2908707	et	3	main
ta	doc_86991684127_item	2908715	et	4	main
tänapäeval	doc_86991684127_item	2908717	et	3	main
eesti	doc_86991684127_item	2908719	et	4	main
eesti	doc_86991684127_item	2908737	et	4	main
on	doc_872470917318_item	2908752	et	4	main
alepõllundus	doc_872470917318_item	2908753	et	3	main
viljakus	doc_872470917318_item	2908768	et	4	main
langes	doc_872470917318_item	2908769	et	4	main
kasvatati	doc_872470917318_item	2908770	et	3	main
uus	doc_872470917318_item	2908771	et	3	main
võsa	doc_872470917318_item	2908772	et	4	main
aasta	doc_872470917318_item	2908775	et	4	main
näiteks	doc_872470917318_item	2908785	et	4	main
eluta	doc_872470917318_item	2908786	et	3	main
loodusel	doc_872470917318_item	2908787	et	4	main
kividel	doc_872470917318_item	2908792	et	3	main
surnute	doc_872470917318_item	2908795	et	4	main
esivanemate	doc_872470917318_item	2908796	et	4	main
ka	doc_866101568973_item	2908525	et	3	main
võimalik	doc_866101568973_item	2908530	et	3	main
algkooli	doc_866101568973_item	2908532	et	4	main
hariduse	doc_866101568973_item	2908533	et	3	main
oma	doc_866101568973_item	2908534	et	4	main
oli	doc_866101568973_item	2908539	et	3	main
rääkida	doc_866101568973_item	2908549	et	3	main
inimesed	doc_866101568973_item	2908550	et	3	main
oma	doc_866101568973_item	2908552	et	4	main
vara	doc_866101568973_item	2908553	et	4	main
pisut	doc_866101568973_item	2908567	et	3	main
nüüd	doc_866101568973_item	2908576	et	4	main
järgi	doc_866101568973_item	2908584	et	4	main
nõukogude	doc_866101568973_item	2908588	et	3	main
ja	doc_866101568973_item	2908592	et	3	main
siiberisse	doc_866101568973_item	2908595	et	3	main
kinni	doc_866101568973_item	2908597	et	3	main
seltsid	doc_866101568973_item	2908599	et	4	main
pidi	doc_866101568973_item	2908605	et	4	main
moskva	doc_866101568973_item	2908610	et	4	main
tahtis	doc_866101568973_item	2908611	et	3	main
nagu	doc_866101568973_item	2908609	et	3	main
ja	doc_866101568973_item	2908612	et	3	main
muidugi	doc_866101568973_item	2908613	et	4	main
vähesed	doc_866101568973_item	2908614	et	3	main
vaidlesid	doc_866101568973_item	2908615	et	4	main
selle	doc_866101568973_item	2908616	et	4	main
vastu	doc_866101568973_item	2908617	et	3	main
sest	doc_866101568973_item	2908618	et	4	main
kardeti	doc_866101568973_item	2908619	et	3	main
arreteerimist	doc_866101568973_item	2908620	et	4	main
2	doc_866101568973_item	2908621	et	2	main
see	doc_866101568973_item	2908635	et	3	main
sellest	doc_866101568973_item	2908644	et	4	main
kui	doc_866101568973_item	2908645	et	3	main
selle	doc_866101568973_item	2908650	et	4	main
kirjutatud	doc_866101568973_item	2908660	et	4	main
et	doc_86991684127_item	2908697	et	3	main
mingi	doc_86991684127_item	2908705	et	4	main
paraegu	doc_86991684127_item	2908716	et	4	main
kui	doc_86991684127_item	2908721	et	3	main
rääkida	doc_86991684127_item	2908723	et	3	main
kultuurist	doc_86991684127_item	2908725	et	3	main
kuulamisel	doc_86991684127_item	2908739	et	4	main
ühel	doc_86991684127_item	2908740	et	3	main
mets	doc_872470917318_item	2908755	et	3	main
maha	doc_872470917318_item	2908758	et	4	main
kogu	doc_872470917318_item	2908778	et	4	main
loodusel	doc_872470917318_item	2908790	et	4	main
on	doc_872470917318_item	2908793	et	4	main
põhiliselt	doc_872470917318_item	2908824	et	4	main
vilja	doc_872470917318_item	2908827	et	4	main
liha	doc_872470917318_item	2908829	et	4	main
ka	doc_872470917318_item	2908830	et	3	main
ehteid	doc_872470917318_item	2908831	et	3	main
ning	doc_872470917318_item	2908832	et	3	main
vahel	doc_872470917318_item	2908833	et	4	main
põletusmatus	doc_872470917318_item	2908845	et	3	main
lõppes	doc_872470917318_item	2908848	et	4	main
e	doc_872470917318_item	2908851	et	4	main
esivanematega	doc_872470917318_item	2908869	et	4	main
kalmistupühad	doc_872470917318_item	2908870	et	3	main
viidud	doc_872470917318_item	2908879	et	4	main
tervisele	doc_872470917318_item	2908886	et	3	main
seda	doc_872470917318_item	2908889	et	3	main
jumalad	doc_872470917318_item	2908900	et	3	main
usuti	doc_872470917318_item	2908902	et	3	main
arvates	doc_872470917318_item	2908913	et	4	main
suunatud	doc_866101568973_item	2908625	et	4	main
režiimi	doc_866101568973_item	2908633	et	2	main
utoopiliselt	doc_866101568973_item	2908638	et	4	main
on	doc_866101568973_item	2908648	et	4	main
kannatanud	doc_866101568973_item	2908649	et	4	main
oli	doc_866101568973_item	2908654	et	3	main
tulevikule	doc_866101568973_item	2908656	et	4	main
kõik	doc_866101568973_item	2908663	et	4	main
ees	doc_866101568973_item	2908667	et	4	main
kõiki	doc_866101568973_item	2908668	et	4	main
ootas	doc_866101568973_item	2908669	et	3	main
kommunism	doc_866101568973_item	2908670	et	3	main
vastus	doc_86991684127_item	2908671	et	3	main
küsimusele	doc_86991684127_item	2908672	et	4	main
i	doc_86991684127_item	2908673	et	4	main
kultuur	doc_86991684127_item	2908674	et	3	main
kui	doc_86991684127_item	2908675	et	3	main
me	doc_86991684127_item	2908676	et	4	main
kuulame	doc_86991684127_item	2908677	et	4	main
sõna	doc_86991684127_item	2908678	et	4	main
kultuur	doc_86991684127_item	2908679	et	3	main
erinevad	doc_86991684127_item	2908680	et	4	main
inimesed	doc_86991684127_item	2908681	et	3	main
seletavad	doc_86991684127_item	2908682	et	4	main
seda	doc_86991684127_item	2908683	et	3	main
erinevalt	doc_86991684127_item	2908684	et	4	main
kui	doc_86991684127_item	2908685	et	3	main
näiteks	doc_86991684127_item	2908686	et	4	main
mina	doc_86991684127_item	2908687	et	4	main
kuulen	doc_86991684127_item	2908688	et	3	main
sõna	doc_86991684127_item	2908689	et	4	main
kultuur	doc_86991684127_item	2908690	et	3	main
mina	doc_86991684127_item	2908691	et	4	main
hakkan	doc_86991684127_item	2908692	et	3	main
mõtlema	doc_86991684127_item	2908693	et	3	main
kultuurist	doc_86991684127_item	2908695	et	3	main
riiga	doc_86991684127_item	2908706	et	4	main
ta	doc_86991684127_item	2908709	et	4	main
ii	doc_86991684127_item	2908718	et	4	main
näha	doc_86991684127_item	2908702	et	3	main
kuidas	doc_86991684127_item	2908703	et	3	main
milline	doc_86991684127_item	2908708	et	3	main
eesti	doc_86991684127_item	2908724	et	4	main
võin	doc_86991684127_item	2908726	et	3	main
kultuuri	doc_86991684127_item	2908738	et	4	main
eestlaste	doc_872470917318_item	2908747	et	4	main
muinasusundi	doc_872470917318_item	2908748	et	3	main
üldiseloomustus	doc_872470917318_item	2908749	et	4	main
2	doc_872470917318_item	2908750	et	2	main
raiuti	doc_872470917318_item	2908756	et	3	main
jäi	doc_872470917318_item	2908760	et	3	main
kasutati	doc_872470917318_item	2908762	et	4	main
ainult	doc_872470917318_item	2908763	et	4	main
paar	doc_872470917318_item	2908764	et	3	main
aastat	doc_872470917318_item	2908765	et	3	main
protsessi	doc_872470917318_item	2908779	et	4	main
1	doc_872470917318_item	2908780	et	2	main
iseloomulik	doc_872470917318_item	2908781	et	3	main
et	doc_872470917318_item	2908784	et	3	main
puudel	doc_872470917318_item	2908791	et	4	main
hing	doc_872470917318_item	2908794	et	3	main
kõrval	doc_872470917318_item	2908799	et	4	main
ohverdati	doc_872470917318_item	2908825	et	3	main
loomi	doc_872470917318_item	2908834	et	4	main
ka	doc_872470917318_item	2908835	et	3	main
ohverdamisega	doc_872470917318_item	2908836	et	4	main
kaasnes	doc_872470917318_item	2908837	et	3	main
maagia	doc_872470917318_item	2908838	et	4	main
kuni	doc_872470917318_item	2908839	et	3	main
13	doc_872470917318_item	2908840	et	2	main
põletatult	doc_872470917318_item	2908844	et	4	main
toitu	doc_872470917318_item	2908858	et	4	main
oad	doc_872470917318_item	2908859	et	3	main
herned	doc_872470917318_item	2908860	et	3	main
kuni	doc_872470917318_item	2908862	et	3	main
puudele	doc_872470917318_item	2908871	et	4	main
värvilisi	doc_872470917318_item	2908873	et	4	main
paelu	doc_872470917318_item	2908874	et	4	main
juurtele	doc_872470917318_item	2908875	et	3	main
valati	doc_872470917318_item	2908876	et	3	main
ja	doc_872470917318_item	2908881	et	3	main
allikavee	doc_872470917318_item	2908883	et	3	main
mõjub	doc_872470917318_item	2908885	et	3	main
usuti	doc_872470917318_item	2908888	et	3	main
tekkisid	doc_872470917318_item	2908898	et	4	main
ka	doc_872470917318_item	2908899	et	3	main
uskusid	doc_872470917318_item	2908904	et	4	main
taarat	doc_872470917318_item	2908905	et	3	main
majanduslik	doc_872470917318_item	2908908	et	3	main
heast	doc_872470917318_item	2908914	et	3	main
et	doc_86991684127_item	2908728	et	3	main
ta	doc_86991684127_item	2908729	et	4	main
mul	doc_86991684127_item	2908731	et	3	main
ka	doc_86991684127_item	2908733	et	3	main
raske	doc_86991684127_item	2908734	et	4	main
seda	doc_86991684127_item	2908735	et	3	main
seletada	doc_86991684127_item	2908736	et	3	main
muusika	doc_86991684127_item	2908744	et	4	main
kontrolltöö	doc_872470917318_item	2908745	et	4	main
1	doc_872470917318_item	2908746	et	2	main
2	doc_872470917318_item	2908754	et	2	main
mõnekümne	doc_872470917318_item	2908774	et	4	main
pärast	doc_872470917318_item	2908776	et	4	main
korrati	doc_872470917318_item	2908777	et	4	main
ja	doc_872470917318_item	2908788	et	3	main
elus	doc_872470917318_item	2908789	et	4	main
hinge	doc_872470917318_item	2908798	et	4	main
oli	doc_872470917318_item	2908800	et	3	main
tähtis	doc_872470917318_item	2908801	et	4	main
ka	doc_872470917318_item	2908802	et	3	main
vägi	doc_872470917318_item	2908803	et	3	main
elus	doc_872470917318_item	2908804	et	4	main
eluta	doc_872470917318_item	2908805	et	3	main
looduses	doc_872470917318_item	2908806	et	4	main
puid	doc_872470917318_item	2908807	et	3	main
kive	doc_872470917318_item	2908808	et	3	main
allikaid	doc_872470917318_item	2908809	et	3	main
hakati	doc_872470917318_item	2908810	et	3	main
pühaks	doc_872470917318_item	2908811	et	3	main
pidama	doc_872470917318_item	2908812	et	4	main
sest	doc_872470917318_item	2908813	et	4	main
usuti	doc_872470917318_item	2908814	et	3	main
et	doc_872470917318_item	2908815	et	3	main
neil	doc_872470917318_item	2908816	et	4	main
on	doc_872470917318_item	2908817	et	4	main
suur	doc_872470917318_item	2908818	et	3	main
vägi	doc_872470917318_item	2908819	et	3	main
levinud	doc_872470917318_item	2908820	et	4	main
loodusobjektidele	doc_872470917318_item	2908823	et	3	main
inimesi	doc_872470917318_item	2908843	et	4	main
jm	doc_872470917318_item	2908861	et	4	main
on	doc_872470917318_item	2908865	et	4	main
surnud	doc_872470917318_item	2908868	et	4	main
ohvrijooki	doc_872470917318_item	2908877	et	4	main
allikaveele	doc_872470917318_item	2908878	et	3	main
valvavad	doc_872470917318_item	2908894	et	4	main
ja	doc_872470917318_item	2908895	et	3	main
eestlased	doc_872470917318_item	2908903	et	3	main
edu	doc_872470917318_item	2908906	et	4	main
õnn	doc_872470917318_item	2908909	et	3	main
tuhk	doc_872470917318_item	2908759	et	3	main
väetiseks	doc_872470917318_item	2908761	et	3	main
kuni	doc_872470917318_item	2908766	et	3	main
mulla	doc_872470917318_item	2908767	et	4	main
peale	doc_872470917318_item	2908773	et	4	main
animism	doc_872470917318_item	2908782	et	3	main
usuti	doc_872470917318_item	2908783	et	3	main
austamine	doc_872470917318_item	2908797	et	4	main
oli	doc_872470917318_item	2908821	et	3	main
villa	doc_872470917318_item	2908826	et	4	main
leiba	doc_872470917318_item	2908828	et	4	main
saj	doc_872470917318_item	2908841	et	4	main
maeti	doc_872470917318_item	2908842	et	3	main
see	doc_872470917318_item	2908849	et	3	main
muistsed	doc_872470917318_item	2908852	et	3	main
seal	doc_872470917318_item	2908854	et	4	main
tänase	doc_872470917318_item	2908863	et	3	main
selle	doc_872470917318_item	2908882	et	4	main
joomine	doc_872470917318_item	2908884	et	4	main
hästi	doc_872470917318_item	2908887	et	3	main
veel	doc_872470917318_item	2908890	et	4	main
usuti	doc_872470917318_item	2908891	et	3	main
et	doc_872470917318_item	2908892	et	3	main
loodust	doc_872470917318_item	2908893	et	4	main
keda	doc_872470917318_item	2908901	et	4	main
ja	doc_872470917318_item	2908907	et	3	main
sõltus	doc_872470917318_item	2908910	et	4	main
muistsete	doc_872470917318_item	2908911	et	3	main
eestlaste	doc_872470917318_item	2908912	et	4	main
oli	doc_872470917318_item	2908921	et	3	main
kontrolltöö	doc_872470917320_item	2909070	et	4	main
1	doc_872470917320_item	2909071	et	2	main
eestlaste	doc_872470917320_item	2909072	et	4	main
muinasusundi	doc_872470917320_item	2909073	et	3	main
13saj	doc_872470917320_item	2909090	et	4	main
on	doc_872470917320_item	2909101	et	4	main
inimesi	doc_872470917320_item	2909113	et	4	main
maeti	doc_872470917320_item	2909114	et	3	main
ka	doc_872470917320_item	2909115	et	3	main
maa	doc_872470917320_item	2909125	et	4	main
alla	doc_872470917320_item	2909126	et	3	main
vaid	doc_872470917320_item	2909127	et	3	main
pandi	doc_872470917320_item	2909128	et	4	main
ümber	doc_872470917320_item	2909129	et	3	main
näiteks	doc_872470917320_item	2909137	et	4	main
kirikus	doc_872470917320_item	2909138	et	3	main
juuakse	doc_872470917320_item	2909139	et	3	main
allikavett	doc_872470917320_item	2909140	et	3	main
saanud	doc_872470917320_item	2909149	et	4	main
mille	doc_872470917320_item	2909165	et	3	main
hakksid	doc_872470917320_item	2909170	et	4	main
rändmungad	doc_872470917320_item	2909172	et	3	main
nad	doc_872470917320_item	2909173	et	3	main
rääkisid	doc_872470917320_item	2909174	et	4	main
inimestele	doc_872470917320_item	2909175	et	3	main
rajuti	doc_872470917320_item	2909204	et	4	main
põletati	doc_872470917320_item	2909208	et	3	main
see	doc_872470917320_item	2909209	et	3	main
maa	doc_872470917320_item	2909210	et	4	main
nende	doc_872470917320_item	2909220	et	4	main
ohverdamine	doc_872470917318_item	2908822	et	4	main
peale	doc_872470917318_item	2908846	et	4	main
ristiusustamist	doc_872470917318_item	2908847	et	3	main
kalmed	doc_872470917318_item	2908850	et	3	main
matusepaigad	doc_872470917318_item	2908853	et	3	main
ohverdati	doc_872470917318_item	2908855	et	3	main
surnute	doc_872470917318_item	2908856	et	4	main
hingedele	doc_872470917318_item	2908857	et	3	main
päevani	doc_872470917318_item	2908864	et	3	main
eestlastel	doc_872470917318_item	2908866	et	4	main
kokkukuuluvus	doc_872470917318_item	2908867	et	4	main
ohverdati	doc_872470917318_item	2908872	et	3	main
hõberaha	doc_872470917318_item	2908880	et	4	main
kaitsevad	doc_872470917318_item	2908896	et	4	main
vaimud	doc_872470917318_item	2908897	et	3	main
läbisaamisest	doc_872470917318_item	2908915	et	4	main
surnud	doc_872470917318_item	2908916	et	4	main
esivanematega	doc_872470917318_item	2908917	et	4	main
kõige	doc_872470917318_item	2908918	et	4	main
tugevamaks	doc_872470917318_item	2908919	et	4	main
loodusjõuks	doc_872470917318_item	2908920	et	3	main
äike	doc_872470917318_item	2908922	et	3	main
üldiseloomustus	doc_872470917320_item	2909074	et	4	main
2	doc_872470917320_item	2909075	et	2	main
austati	doc_872470917320_item	2909082	et	3	main
põletusmatused	doc_872470917320_item	2909092	et	3	main
maetud	doc_872470917320_item	2909102	et	4	main
ka	doc_872470917320_item	2909103	et	3	main
koos	doc_872470917320_item	2909104	et	4	main
inimesega	doc_872470917320_item	2909105	et	3	main
ehted	doc_872470917320_item	2909106	et	3	main
tööriistad	doc_872470917320_item	2909107	et	3	main
varandus	doc_872470917320_item	2909108	et	3	main
lõuna-eestis	doc_872470917320_item	2909109	et	3	main
maeti	doc_872470917320_item	2909110	et	3	main
inimesi	doc_872470917320_item	2909111	et	4	main
inimest	doc_872470917320_item	2909122	et	3	main
maetud	doc_872470917320_item	2909124	et	4	main
millesegi	doc_872470917320_item	2909136	et	4	main
sümbol	doc_872470917320_item	2909153	et	3	main
palju	doc_872470917320_item	2909163	et	4	main
peal	doc_872470917320_item	2909166	et	4	main
on	doc_872470917320_item	2909167	et	4	main
algul	doc_872470917320_item	2909203	et	4	main
mets	doc_872470917320_item	2909205	et	3	main
maha	doc_872470917320_item	2909206	et	4	main
siis	doc_872470917320_item	2909207	et	3	main
seda	doc_872470917320_item	2909213	et	3	main
sinna	doc_872470917320_item	2909215	et	3	main
1	doc_872470917320_item	2909079	et	2	main
kõige	doc_872470917320_item	2909080	et	4	main
pealt	doc_872470917320_item	2909081	et	4	main
inimesi	doc_872470917320_item	2909084	et	4	main
ei	doc_872470917320_item	2909086	et	4	main
eestis	doc_872470917320_item	2909121	et	3	main
siiamaani	doc_872470917320_item	2909132	et	3	main
et	doc_872470917320_item	2909143	et	3	main
parandab	doc_872470917320_item	2909145	et	3	main
silmanägemise	doc_872470917320_item	2909146	et	3	main
ristist	doc_872470917320_item	2909147	et	4	main
on	doc_872470917320_item	2909148	et	4	main
kannatuse	doc_872470917320_item	2909152	et	4	main
on	doc_872470917320_item	2909155	et	4	main
ka	doc_872470917320_item	2909157	et	3	main
surmasümbol	doc_872470917320_item	2909158	et	3	main
rist	doc_872470917320_item	2909168	et	3	main
tulema	doc_872470917320_item	2909171	et	4	main
2	doc_872470917320_item	2909202	et	2	main
peale	doc_872470917320_item	2909212	et	4	main
tehti	doc_872470917320_item	2909214	et	3	main
see	doc_872470917320_item	2909217	et	3	main
vilja	doc_872470917320_item	2909224	et	4	main
muinasusundi	doc_872470917321_item	2909236	et	3	main
üldiseloomustus	doc_872470917321_item	2909237	et	4	main
2	doc_872470917321_item	2909238	et	2	main
mis	doc_872470917320_item	2909076	et	4	main
tohtinud	doc_872470917320_item	2909087	et	4	main
rääkida	doc_872470917320_item	2909088	et	3	main
halvasti	doc_872470917320_item	2909089	et	3	main
ohverdanud	doc_872470917320_item	2909097	et	4	main
ube	doc_872470917320_item	2909098	et	3	main
ja	doc_872470917320_item	2909099	et	3	main
herneid	doc_872470917320_item	2909100	et	3	main
liivakääpadesse	doc_872470917320_item	2909112	et	4	main
ei	doc_872470917320_item	2909123	et	4	main
on	doc_872470917320_item	2909133	et	4	main
jäänud	doc_872470917320_item	2909134	et	4	main
usk	doc_872470917320_item	2909135	et	3	main
allikavesi	doc_872470917320_item	2909144	et	4	main
sümbol	doc_872470917320_item	2909151	et	3	main
haudasi	doc_872470917320_item	2909164	et	3	main
ja	doc_872470917320_item	2909211	et	3	main
lina	doc_872470917320_item	2909227	et	4	main
kanep	doc_872470917320_item	2909228	et	3	main
tuder	doc_872470917320_item	2909230	et	3	main
väärtuslik	doc_872470917320_item	2909231	et	3	main
on	doc_872470917321_item	2909240	et	4	main
ning	doc_872470917321_item	2909245	et	3	main
arva	doc_872470917321_item	2909247	et	4	main
veendunud	doc_872470917321_item	2909249	et	4	main
et	doc_872470917321_item	2909250	et	3	main
arheoloogilisi	doc_872470917321_item	2909256	et	4	main
selle	doc_872470917321_item	2909258	et	4	main
on	doc_872470917321_item	2909260	et	4	main
päris	doc_872470917321_item	2909261	et	4	main
jões	doc_872470917321_item	2909272	et	3	main
see	doc_872470917321_item	2909276	et	3	main
et	doc_872470917321_item	2909278	et	3	main
ei	doc_872470917321_item	2909280	et	4	main
tähendusega	doc_872470917321_item	2909287	et	4	main
ohverdati	doc_872470917321_item	2909290	et	3	main
saada	doc_872470917321_item	2909294	et	4	main
saaki	doc_872470917321_item	2909296	et	4	main
millelt	doc_872470917321_item	2909300	et	3	main
infot	doc_872470917321_item	2909321	et	3	main
kaasa	doc_872470917321_item	2909327	et	4	main
ja	doc_872470917321_item	2909329	et	3	main
ole	doc_872470917321_item	2909336	et	4	main
tuntud	doc_872470917321_item	2909337	et	4	main
vaid	doc_872470917321_item	2909341	et	3	main
ka	doc_872470917321_item	2909342	et	3	main
oma	doc_872470917321_item	2909352	et	4	main
jaoks	doc_872470917321_item	2909359	et	4	main
selle	doc_872470917321_item	2909362	et	4	main
kohale	doc_872470917321_item	2909370	et	4	main
muistsed	doc_872470917321_item	2909376	et	3	main
panid	doc_872470917321_item	2909378	et	4	main
veel	doc_872470917321_item	2909413	et	4	main
suuri	doc_872470917321_item	2909422	et	3	main
surnutele	doc_872470917321_item	2909425	et	4	main
vilju	doc_872470917321_item	2909427	et	4	main
esimesed	doc_872470917321_item	2909431	et	3	main
on	doc_872470917320_item	2909077	et	4	main
alepõllundus	doc_872470917320_item	2909078	et	3	main
surnuid	doc_872470917320_item	2909083	et	4	main
nendest	doc_872470917320_item	2909085	et	4	main
tuli	doc_872470917320_item	2909091	et	4	main
matuste	doc_872470917320_item	2909093	et	3	main
ajal	doc_872470917320_item	2909094	et	4	main
inimesed	doc_872470917320_item	2909095	et	3	main
on	doc_872470917320_item	2909096	et	4	main
kivikalmedesse	doc_872470917320_item	2909116	et	4	main
kivikalmed	doc_872470917320_item	2909117	et	3	main
on	doc_872470917320_item	2909118	et	4	main
leitud	doc_872470917320_item	2909119	et	4	main
ka	doc_872470917320_item	2909120	et	3	main
teda	doc_872470917320_item	2909130	et	4	main
kive	doc_872470917320_item	2909131	et	3	main
puhasvesi	doc_872470917320_item	2909141	et	4	main
usuti	doc_872470917320_item	2909142	et	3	main
kiriku	doc_872470917320_item	2909150	et	3	main
sellest	doc_872470917320_item	2909154	et	4	main
saanud	doc_872470917320_item	2909156	et	4	main
tänapäeva	doc_872470917320_item	2909159	et	4	main
kalmistul	doc_872470917320_item	2909160	et	3	main
võib	doc_872470917320_item	2909161	et	3	main
näha	doc_872470917320_item	2909162	et	3	main
lõuna-eestist	doc_872470917320_item	2909169	et	3	main
usundist	doc_872470917320_item	2909176	et	3	main
ja	doc_872470917320_item	2909177	et	3	main
millesse	doc_872470917320_item	2909178	et	3	main
usuvad	doc_872470917320_item	2909179	et	3	main
inimesed	doc_872470917320_item	2909180	et	3	main
teistes	doc_872470917320_item	2909181	et	4	main
kohtades	doc_872470917320_item	2909182	et	3	main
inimesed	doc_872470917320_item	2909183	et	3	main
ususid	doc_872470917320_item	2909184	et	4	main
ka	doc_872470917320_item	2909185	et	3	main
sellesse	doc_872470917320_item	2909186	et	4	main
et	doc_872470917320_item	2909187	et	3	main
loodus	doc_872470917320_item	2909188	et	4	main
elab	doc_872470917320_item	2909189	et	3	main
samat	doc_872470917320_item	2909190	et	4	main
moodi	doc_872470917320_item	2909191	et	4	main
nagu	doc_872470917320_item	2909192	et	3	main
nemad	doc_872470917320_item	2909193	et	3	main
et	doc_872470917320_item	2909194	et	3	main
loodusel	doc_872470917320_item	2909195	et	4	main
on	doc_872470917320_item	2909196	et	4	main
hing	doc_872470917320_item	2909197	et	3	main
mõnedel	doc_872470917320_item	2909198	et	3	main
oli	doc_872470917320_item	2909199	et	3	main
usk	doc_872470917320_item	2909200	et	3	main
maagiasse	doc_872470917320_item	2909201	et	4	main
põlludel	doc_872470917320_item	2909221	et	4	main
sai	doc_872470917320_item	2909222	et	4	main
kasvatada	doc_872470917320_item	2909223	et	3	main
oder	doc_872470917320_item	2909225	et	3	main
nisu	doc_872470917320_item	2909226	et	4	main
eestlaste	doc_872470917321_item	2909235	et	4	main
alepõllundus	doc_872470917321_item	2909241	et	3	main
ajaloolased	doc_872470917321_item	2909246	et	3	main
sapiens	doc_872470917321_item	2909252	et	4	main
homo	doc_872470917321_item	2909254	et	4	main
kohta	doc_872470917321_item	2909259	et	4	main
palju	doc_872470917321_item	2909274	et	4	main
sirpe	doc_872470917321_item	2909275	et	3	main
tähendab	doc_872470917321_item	2909277	et	3	main
sirp	doc_872470917321_item	2909279	et	3	main
ese	doc_872470917321_item	2909288	et	3	main
arvatavasti	doc_872470917321_item	2909289	et	3	main
vanem	doc_872470917321_item	2909297	et	4	main
põld	doc_872470917320_item	2909216	et	3	main
ongi	doc_872470917320_item	2909218	et	4	main
alepõllundus	doc_872470917320_item	2909219	et	3	main
hirss	doc_872470917320_item	2909229	et	3	main
õlitaim	doc_872470917320_item	2909232	et	3	main
1	doc_872470917321_item	2909234	et	2	main
paljud	doc_872470917321_item	2909243	et	3	main
tõendeid	doc_872470917321_item	2909257	et	3	main
nii	doc_872470917321_item	2909263	et	3	main
ka	doc_872470917321_item	2909266	et	3	main
arheoloogilised	doc_872470917321_item	2909268	et	4	main
leiud	doc_872470917321_item	2909269	et	3	main
näiteks	doc_872470917321_item	2909270	et	4	main
võhandu	doc_872470917321_item	2909271	et	4	main
olnud	doc_872470917321_item	2909281	et	4	main
ainult	doc_872470917321_item	2909282	et	4	main
töövahend	doc_872470917321_item	2909283	et	3	main
sirpe	doc_872470917321_item	2909291	et	3	main
pronksiaeg	doc_872470917321_item	2909298	et	3	main
võib	doc_872470917321_item	2909322	et	3	main
inimestele	doc_872470917321_item	2909325	et	3	main
anti	doc_872470917321_item	2909326	et	3	main
ehteid	doc_872470917321_item	2909330	et	3	main
ajast	doc_872470917321_item	2909340	et	4	main
kaasa	doc_872470917321_item	2909347	et	4	main
ristikujulisi	doc_872470917321_item	2909348	et	4	main
ehteid	doc_872470917321_item	2909349	et	3	main
mis	doc_872470917321_item	2909350	et	4	main
ja	doc_872470917321_item	2909364	et	3	main
eesmärgiga	doc_872470917321_item	2909373	et	3	main
tööriistu	doc_872470917321_item	2909381	et	3	main
auke	doc_872470917321_item	2909412	et	4	main
ja	doc_872470917321_item	2909419	et	3	main
jne	doc_872470917321_item	2909424	et	4	main
ohverdati	doc_872470917321_item	2909426	et	3	main
religioonist	doc_872470917321_item	2909434	et	3	main
tekkima	doc_872470917321_item	2909436	et	3	main
alates	doc_872470917321_item	2909447	et	3	main
tänapäevalgi	doc_872470917321_item	2909476	et	4	main
ehtisid	doc_872470917321_item	2909497	et	4	main
puid	doc_872470917321_item	2909498	et	3	main
paeladega	doc_872470917321_item	2909499	et	4	main
oli	doc_872470917321_item	2909504	et	3	main
rauaajal	doc_872470917321_item	2909506	et	3	main
siis	doc_872470917321_item	2909509	et	3	main
kontrolltöö	doc_872470917321_item	2909233	et	4	main
mis	doc_872470917321_item	2909239	et	4	main
arheoloogid	doc_872470917321_item	2909244	et	3	main
on	doc_872470917321_item	2909248	et	4	main
homo	doc_872470917321_item	2909251	et	4	main
religiosusega	doc_872470917321_item	2909255	et	4	main
palju	doc_872470917321_item	2909262	et	4	main
matmiskombed	doc_872470917321_item	2909264	et	3	main
teised	doc_872470917321_item	2909267	et	4	main
leiti	doc_872470917321_item	2909273	et	3	main
maagilise	doc_872470917321_item	2909286	et	4	main
selleks	doc_872470917321_item	2909292	et	4	main
et	doc_872470917321_item	2909293	et	3	main
paremat	doc_872470917321_item	2909295	et	4	main
paluti	doc_872470917321_item	2909301	et	3	main
ja	doc_872470917321_item	2909303	et	3	main
abi	doc_872470917321_item	2909304	et	4	main
oli	doc_872470917321_item	2909305	et	3	main
äike	doc_872470917321_item	2909306	et	3	main
väga	doc_872470917321_item	2909307	et	3	main
iseloomustavaks	doc_872470917321_item	2909308	et	4	main
jooneks	doc_872470917321_item	2909309	et	3	main
oli	doc_872470917321_item	2909310	et	3	main
see	doc_872470917321_item	2909311	et	3	main
et	doc_872470917321_item	2909312	et	3	main
muistsed	doc_872470917321_item	2909313	et	3	main
eestlased	doc_872470917321_item	2909314	et	3	main
austasid	doc_872470917321_item	2909315	et	4	main
oma	doc_872470917321_item	2909316	et	4	main
surnuid	doc_872470917321_item	2909317	et	4	main
esivanemaid	doc_872470917321_item	2909318	et	4	main
väga	doc_872470917321_item	2909319	et	3	main
palju	doc_872470917321_item	2909320	et	4	main
saada	doc_872470917321_item	2909323	et	4	main
matmispaikadelt	doc_872470917321_item	2909324	et	3	main
kristlaste	doc_872470917321_item	2909339	et	3	main
varem	doc_872470917321_item	2909343	et	4	main
on	doc_872470917321_item	2909344	et	4	main
kindlat	doc_872470917321_item	2909353	et	3	main
tähendus	doc_872470917321_item	2909356	et	4	main
pandi	doc_872470917321_item	2909368	et	4	main
et	doc_872470917321_item	2909375	et	3	main
kaasa	doc_872470917321_item	2909380	et	4	main
ole	doc_872470917321_item	2909415	et	4	main
teada	doc_872470917321_item	2909416	et	3	main
1	doc_872470917321_item	2909242	et	2	main
võrdub	doc_872470917321_item	2909253	et	3	main
kui	doc_872470917321_item	2909265	et	3	main
kuid	doc_872470917321_item	2909284	et	4	main
ka	doc_872470917321_item	2909285	et	3	main
loodusjõud	doc_872470917321_item	2909299	et	4	main
jõudu	doc_872470917321_item	2909302	et	4	main
tööriistu	doc_872470917321_item	2909328	et	3	main
maagilise	doc_872470917321_item	2909331	et	4	main
tähendusega	doc_872470917321_item	2909332	et	4	main
ainult	doc_872470917321_item	2909338	et	4	main
pandud	doc_872470917321_item	2909345	et	4	main
omasid	doc_872470917321_item	2909351	et	4	main
eestlaste	doc_872470917321_item	2909358	et	4	main
maagilistesse	doc_872470917321_item	2909363	et	4	main
tervendavatesse	doc_872470917321_item	2909365	et	4	main
toimedesse	doc_872470917321_item	2909366	et	3	main
surnutele	doc_872470917321_item	2909367	et	4	main
see	doc_872470917321_item	2909374	et	3	main
surnutele	doc_872470917321_item	2909379	et	4	main
mis	doc_872470917321_item	2909417	et	4	main
põhjusega	doc_872470917321_item	2909418	et	3	main
eesmärgiga	doc_872470917321_item	2909421	et	3	main
viitab	doc_872470917321_item	2909428	et	3	main
allikad	doc_872470917321_item	2909432	et	3	main
on	doc_872470917321_item	2909448	et	4	main
leitud	doc_872470917321_item	2909450	et	4	main
ehteid	doc_872470917321_item	2909452	et	3	main
matmiskombed	doc_872470917321_item	2909456	et	3	main
mingit	doc_872470917321_item	2909458	et	3	main
ümbritsetud	doc_872470917321_item	2909466	et	4	main
tähendama	doc_872470917321_item	2909470	et	3	main
see	doc_872470917321_item	2909472	et	3	main
omamoodi	doc_872470917321_item	2909474	et	3	main
kaitstud	doc_872470917321_item	2909475	et	4	main
kuuse	doc_872470917321_item	2909485	et	4	main
see	doc_872470917321_item	2909487	et	3	main
põllunduse	doc_872470917321_item	2909502	et	3	main
9-13	doc_872470917321_item	2909507	et	2	main
tegevusala	doc_872470917321_item	2909518	et	4	main
millele	doc_872470917321_item	2909519	et	3	main
tähelepanu	doc_872470917321_item	2909522	et	4	main
põld	doc_872470917321_item	2909540	et	3	main
kasvatatud	doc_872470917321_item	2909563	et	4	main
üks	doc_872470917321_item	2909564	et	3	main
veel	doc_872470917321_item	2909572	et	4	main
olen	doc_873901597503_item	2909758	et	3	main
mida	doc_873901597503_item	2909761	et	4	main
reisinud	doc_873901597503_item	2909768	et	4	main
on	doc_873901597503_item	2909774	et	4	main
2000	doc_873901597503_item	2909780	et	2	main
oli	doc_873901597503_item	2909784	et	3	main
sõidan	doc_873901597503_item	2909837	et	3	main
mul	doc_873901597503_item	2909841	et	3	main
teada	doc_873901597503_item	2909844	et	3	main
kuidas	doc_873901597503_item	2909845	et	3	main
midagi	doc_873901597503_item	2909856	et	4	main
tahan	doc_873901597503_item	2909878	et	3	main
näiteks	doc_872470917321_item	2909333	et	4	main
rist	doc_872470917321_item	2909334	et	3	main
ei	doc_872470917321_item	2909335	et	4	main
surnutele	doc_872470917321_item	2909346	et	4	main
tähendust	doc_872470917321_item	2909354	et	4	main
suur	doc_872470917321_item	2909355	et	3	main
oli	doc_872470917321_item	2909357	et	3	main
merevaigul	doc_872470917321_item	2909360	et	3	main
usuti	doc_872470917321_item	2909361	et	3	main
silmade	doc_872470917321_item	2909369	et	3	main
merevaigu	doc_872470917321_item	2909371	et	3	main
tervendava	doc_872470917321_item	2909372	et	4	main
eestlased	doc_872470917321_item	2909377	et	3	main
ja	doc_872470917321_item	2909382	et	3	main
ehteid	doc_872470917321_item	2909383	et	3	main
et	doc_872470917321_item	2909385	et	3	main
tähendab	doc_872470917321_item	2909384	et	3	main
usuti	doc_872470917321_item	2909386	et	3	main
maavälisse	doc_872470917321_item	2909387	et	4	main
kus	doc_872470917321_item	2909389	et	3	main
ellu	doc_872470917321_item	2909388	et	4	main
tõenäoliselt	doc_872470917321_item	2909390	et	4	main
oleks	doc_872470917321_item	2909391	et	3	main
vaja	doc_872470917321_item	2909392	et	4	main
läinud	doc_872470917321_item	2909393	et	4	main
nii	doc_872470917321_item	2909394	et	3	main
ehteid	doc_872470917321_item	2909395	et	3	main
mis	doc_872470917321_item	2909396	et	4	main
aitasid	doc_872470917321_item	2909397	et	4	main
kurja	doc_872470917321_item	2909398	et	4	main
eest	doc_872470917321_item	2909400	et	4	main
kui	doc_872470917321_item	2909401	et	3	main
jõu	doc_872470917321_item	2909399	et	3	main
tööriistu	doc_872470917321_item	2909402	et	3	main
töövahendeid	doc_872470917321_item	2909403	et	3	main
peeti	doc_872470917321_item	2909404	et	4	main
tähtsaks	doc_872470917321_item	2909406	et	4	main
loodusjõude	doc_872470917321_item	2909407	et	3	main
suuri	doc_872470917321_item	2909408	et	3	main
kive	doc_872470917321_item	2909409	et	3	main
väga	doc_872470917321_item	2909405	et	3	main
millestesse	doc_872470917321_item	2909410	et	4	main
tehti	doc_872470917321_item	2909411	et	3	main
ei	doc_872470917321_item	2909414	et	4	main
mis	doc_872470917321_item	2909420	et	4	main
puid	doc_872470917321_item	2909423	et	3	main
esivanemate	doc_872470917321_item	2909429	et	4	main
hakkavad	doc_872470917321_item	2909435	et	4	main
vikingi	doc_872470917321_item	2909437	et	4	main
rändavatelt	doc_872470917321_item	2909442	et	4	main
religiooni	doc_872470917321_item	2909443	et	4	main
ajast	doc_872470917321_item	2909446	et	4	main
rohkesti	doc_872470917321_item	2909449	et	3	main
ristikujulisi	doc_872470917321_item	2909451	et	4	main
ka	doc_872470917321_item	2909454	et	3	main
kannavad	doc_872470917321_item	2909457	et	3	main
usuga	doc_872470917321_item	2909459	et	3	main
kividega	doc_872470917321_item	2909467	et	3	main
ju	doc_872470917321_item	2909469	et	3	main
on	doc_872470917321_item	2909473	et	4	main
kombeid	doc_872470917321_item	2909481	et	4	main
näiteks	doc_872470917321_item	2909482	et	4	main
jõulude	doc_872470917321_item	2909483	et	3	main
ehtimine	doc_872470917321_item	2909486	et	4	main
jne	doc_872470917321_item	2909500	et	4	main
2	doc_872470917321_item	2909501	et	2	main
muinasinimesed	doc_872470917321_item	2909511	et	3	main
rohkesti	doc_872470917321_item	2909512	et	3	main
selle	doc_872470917321_item	2909532	et	4	main
oli	doc_872470917321_item	2909537	et	3	main
oli	doc_872470917321_item	2909541	et	3	main
septembris	doc_872470917321_item	2909555	et	3	main
et	doc_872470917321_item	2909574	et	3	main
vilja	doc_872470917321_item	2909581	et	4	main
kasvatati	doc_872470917321_item	2909582	et	3	main
ka	doc_872470917321_item	2909583	et	3	main
lugupidamisele	doc_872470917321_item	2909430	et	3	main
mungadelt	doc_872470917321_item	2909441	et	4	main
sellest	doc_872470917321_item	2909445	et	4	main
arvatavasti	doc_872470917321_item	2909453	et	3	main
esimesed	doc_872470917321_item	2909455	et	3	main
seotud	doc_872470917321_item	2909460	et	4	main
tähendust	doc_872470917321_item	2909461	et	4	main
see	doc_872470917321_item	2909462	et	3	main
et	doc_872470917321_item	2909463	et	3	main
matmispaik	doc_872470917321_item	2909464	et	3	main
me	doc_872470917321_item	2909477	et	4	main
kasutame	doc_872470917321_item	2909478	et	3	main
ajal	doc_872470917321_item	2909484	et	4	main
ei	doc_872470917321_item	2909488	et	4	main
tule	doc_872470917321_item	2909489	et	4	main
kristlaste	doc_872470917321_item	2909490	et	3	main
usundist	doc_872470917321_item	2909491	et	3	main
keskmisel	doc_872470917321_item	2909505	et	3	main
saj	doc_872470917321_item	2909508	et	4	main
toitusid	doc_872470917321_item	2909510	et	4	main
viljast	doc_872470917321_item	2909513	et	4	main
kalapüügist	doc_872470917321_item	2909514	et	3	main
ning	doc_872470917321_item	2909515	et	3	main
jahtimisest	doc_872470917321_item	2909516	et	4	main
pöörati	doc_872470917321_item	2909520	et	3	main
tunnuseks	doc_872470917321_item	2909533	et	3	main
oli	doc_872470917321_item	2909534	et	3	main
see	doc_872470917321_item	2909535	et	3	main
et	doc_872470917321_item	2909536	et	3	main
kolmeks	doc_872470917321_item	2909543	et	4	main
suverukkist	doc_872470917321_item	2909548	et	4	main
teisel	doc_872470917321_item	2909549	et	4	main
aasta	doc_872470917321_item	2909565	et	4	main
teada	doc_872470917321_item	2909573	et	3	main
oskasid	doc_872470917321_item	2909577	et	4	main
jahut	doc_872470917321_item	2909579	et	4	main
käinud	doc_873901597503_item	2909759	et	4	main
olen	doc_873901597503_item	2909762	et	3	main
näinud	doc_873901597503_item	2909763	et	4	main
oma	doc_873901597503_item	2909764	et	4	main
reisida	doc_873901597503_item	2909769	et	3	main
ja	doc_873901597503_item	2909779	et	3	main
see	doc_873901597503_item	2909783	et	3	main
väga	doc_873901597503_item	2909785	et	3	main
ma	doc_873901597503_item	2909787	et	3	main
seal	doc_873901597503_item	2909789	et	4	main
ei	doc_873901597503_item	2909796	et	4	main
oma	doc_873901597503_item	2909808	et	4	main
italiasse	doc_873901597503_item	2909810	et	4	main
ja	doc_873901597503_item	2909811	et	3	main
kristlaste	doc_872470917321_item	2909433	et	3	main
aja	doc_872470917321_item	2909438	et	4	main
lõpus	doc_872470917321_item	2909439	et	4	main
800-1030aa	doc_872470917321_item	2909440	et	3	main
levitajatelt	doc_872470917321_item	2909444	et	4	main
oli	doc_872470917321_item	2909465	et	3	main
pidi	doc_872470917321_item	2909468	et	4	main
et	doc_872470917321_item	2909471	et	3	main
mõnesid	doc_872470917321_item	2909479	et	3	main
muistseestlaste	doc_872470917321_item	2909480	et	4	main
vaid	doc_872470917321_item	2909492	et	3	main
muinasaja	doc_872470917321_item	2909493	et	3	main
religioonist	doc_872470917321_item	2909494	et	3	main
kus	doc_872470917321_item	2909495	et	3	main
inimesed	doc_872470917321_item	2909496	et	3	main
tipphetk	doc_872470917321_item	2909503	et	3	main
kuid	doc_872470917321_item	2909517	et	4	main
suuremat	doc_872470917321_item	2909521	et	4	main
põlluharimine	doc_872470917321_item	2909524	et	3	main
teada	doc_872470917321_item	2909526	et	3	main
et	doc_872470917321_item	2909527	et	3	main
sel	doc_872470917321_item	2909528	et	3	main
kasutusel	doc_872470917321_item	2909538	et	4	main
talverukkist	doc_872470917321_item	2909550	et	4	main
seda	doc_872470917321_item	2909551	et	3	main
istutati	doc_872470917321_item	2909552	et	3	main
augustis	doc_872470917321_item	2909553	et	3	main
või	doc_872470917321_item	2909554	et	4	main
koosneski	doc_872470917321_item	2909568	et	3	main
alepõllundus	doc_872470917321_item	2909569	et	3	main
inimesed	doc_872470917321_item	2909576	et	3	main
ja	doc_873901597503_item	2909760	et	3	main
mulle	doc_873901597503_item	2909770	et	4	main
see	doc_873901597503_item	2909773	et	3	main
minu	doc_873901597503_item	2909775	et	3	main
huviala	doc_873901597503_item	2909776	et	4	main
koolis	doc_873901597503_item	2909793	et	4	main
suusatamas	doc_873901597503_item	2909813	et	3	main
siis	doc_873901597503_item	2909840	et	3	main
sõpru	doc_873901597503_item	2909852	et	3	main
nendest	doc_873901597503_item	2909855	et	4	main
jooksul	doc_873901597503_item	2909871	et	4	main
saavad	doc_873901597504_item	2909922	et	4	main
möödunud	doc_873901597504_item	2909930	et	4	main
kievis	doc_873901597504_item	2909941	et	4	main
need	doc_873901597504_item	2909942	et	3	main
on	doc_873901597504_item	2909943	et	4	main
ilusad	doc_873901597504_item	2909944	et	3	main
linnad	doc_873901597504_item	2909945	et	3	main
kievis	doc_873901597504_item	2909946	et	4	main
linn	doc_873901597504_item	2909954	et	3	main
seal	doc_873901597504_item	2909957	et	4	main
soe	doc_873901597504_item	2910018	et	4	main
oli	doc_872470917321_item	2909523	et	3	main
on	doc_872470917321_item	2909525	et	4	main
ajal	doc_872470917321_item	2909529	et	4	main
tekkis	doc_872470917321_item	2909530	et	3	main
alepõllundus	doc_872470917321_item	2909531	et	3	main
kolmeväljasüsteem	doc_872470917321_item	2909539	et	3	main
jaotatud	doc_872470917321_item	2909542	et	4	main
osaks	doc_872470917321_item	2909544	et	3	main
ning	doc_872470917321_item	2909545	et	3	main
esimesel	doc_872470917321_item	2909546	et	3	main
kasvatati	doc_872470917321_item	2909547	et	3	main
ja	doc_872470917321_item	2909556	et	3	main
ühte	doc_872470917321_item	2909557	et	4	main
osat	doc_872470917321_item	2909558	et	4	main
jäeti	doc_872470917321_item	2909559	et	3	main
puhkama	doc_872470917321_item	2909560	et	3	main
seal	doc_872470917321_item	2909561	et	4	main
ei	doc_872470917321_item	2909562	et	4	main
midagi	doc_872470917321_item	2909566	et	4	main
sellest	doc_872470917321_item	2909567	et	4	main
muidu	doc_872470917321_item	2909570	et	3	main
on	doc_872470917321_item	2909571	et	4	main
tolleaegsed	doc_872470917321_item	2909575	et	3	main
teha	doc_872470917321_item	2909578	et	3	main
ja	doc_872470917321_item	2909580	et	3	main
linade	doc_872470917321_item	2909584	et	3	main
tegemiseks	doc_872470917321_item	2909585	et	4	main
essee	doc_873901597503_item	2909756	et	4	main
kus	doc_873901597503_item	2909757	et	3	main
palju	doc_873901597503_item	2909767	et	4	main
väga	doc_873901597503_item	2909772	et	3	main
elus	doc_873901597503_item	2909765	et	4	main
olen	doc_873901597503_item	2909766	et	3	main
meeldib	doc_873901597503_item	2909771	et	3	main
aastal	doc_873901597503_item	2909777	et	3	main
lendasin	doc_873901597503_item	2909781	et	3	main
elasin	doc_873901597503_item	2909788	et	3	main
perekonnas	doc_873901597503_item	2909790	et	4	main
ja	doc_873901597503_item	2909791	et	3	main
käisin	doc_873901597503_item	2909792	et	3	main
aga	doc_873901597503_item	2909794	et	3	main
mulle	doc_873901597503_item	2909798	et	4	main
üldse	doc_873901597503_item	2909799	et	3	main
arvan	doc_873901597503_item	2909800	et	3	main
et	doc_873901597503_item	2909801	et	3	main
see	doc_873901597503_item	2909802	et	3	main
on	doc_873901597503_item	2909803	et	4	main
igav	doc_873901597503_item	2909804	et	3	main
eelmisel	doc_873901597503_item	2909805	et	3	main
aastal	doc_873901597503_item	2909806	et	3	main
käisin	doc_873901597503_item	2909807	et	3	main
kaks	doc_873901597503_item	2909816	et	3	main
mulle	doc_873901597503_item	2909818	et	4	main
1995	doc_873901597503_item	2909778	et	2	main
usa-sse	doc_873901597503_item	2909782	et	3	main
põnev	doc_873901597503_item	2909786	et	3	main
ameerika	doc_873901597503_item	2909795	et	3	main
meeldinud	doc_873901597503_item	2909797	et	4	main
perekonnaga	doc_873901597503_item	2909809	et	4	main
veetsime	doc_873901597503_item	2909814	et	3	main
aga	doc_873901597503_item	2909821	et	3	main
vennale	doc_873901597503_item	2909824	et	3	main
snowboardiga	doc_873901597503_item	2909826	et	4	main
arvan	doc_873901597503_item	2909828	et	3	main
see	doc_873901597503_item	2909830	et	3	main
on	doc_873901597503_item	2909842	et	4	main
huvitav	doc_873901597503_item	2909843	et	4	main
teised	doc_873901597503_item	2909846	et	4	main
inimesed	doc_873901597503_item	2909847	et	3	main
elavad	doc_873901597503_item	2909848	et	4	main
mulle	doc_873901597503_item	2909849	et	4	main
meeldib	doc_873901597503_item	2909850	et	3	main
uued	doc_873901597503_item	2909851	et	3	main
ja	doc_873901597503_item	2909854	et	3	main
uurida	doc_873901597503_item	2909858	et	3	main
sügisel	doc_873901597503_item	2909860	et	3	main
egiptusesse	doc_873901597503_item	2909862	et	4	main
seal	doc_873901597503_item	2909864	et	4	main
ja	doc_873901597503_item	2909868	et	3	main
puhkasin	doc_873901597503_item	2909869	et	3	main
kuu	doc_873901597503_item	2909870	et	4	main
kultuurist	doc_873901597503_item	2909873	et	3	main
teada	doc_873901597503_item	2909876	et	3	main
käinud	doc_873901597504_item	2909912	et	4	main
ja	doc_873901597504_item	2909913	et	3	main
mida	doc_873901597504_item	2909914	et	4	main
arhitektuurist	doc_873901597504_item	2909929	et	3	main
võimalus	doc_873901597504_item	2909934	et	3	main
odessa	doc_873901597504_item	2909951	et	4	main
kuroortne	doc_873901597504_item	2909953	et	4	main
õnnelikud	doc_873901597504_item	2909962	et	3	main
mina	doc_873901597504_item	2909964	et	4	main
vesi	doc_873901597504_item	2909977	et	4	main
rannades	doc_873901597504_item	2910008	et	4	main
õues	doc_873901597504_item	2910011	et	4	main
lähedal	doc_873901597504_item	2910013	et	4	main
ja	doc_873901597504_item	2910015	et	3	main
ei	doc_873901597504_item	2910021	et	4	main
ja	doc_873901597504_item	2910030	et	3	main
riietunud	doc_873901597504_item	2910050	et	4	main
maitsekalt	doc_873901597504_item	2910053	et	4	main
odessa	doc_873901597504_item	2910057	et	4	main
huumori	doc_873901597504_item	2910059	et	3	main
seal	doc_873901597504_item	2910061	et	4	main
paljud	doc_873901597504_item	2910063	et	3	main
ma	doc_873901597504_item	2910075	et	3	main
muuseumid	doc_873901597504_item	2910081	et	3	main
aru	doc_873901597504_item	2910089	et	4	main
kunstis	doc_873901597504_item	2910093	et	3	main
on	doc_873901597504_item	2910095	et	4	main
väga	doc_873901597504_item	2910096	et	3	main
huvitav	doc_873901597504_item	2910097	et	4	main
kui	doc_873901597504_item	2910098	et	3	main
sul	doc_873901597504_item	2910099	et	3	main
peterbuuris	doc_873901597504_item	2910126	et	4	main
on	doc_873901597504_item	2910127	et	4	main
jookseb	doc_873901597504_item	2910133	et	3	main
kiiresti	doc_873901597504_item	2910135	et	3	main
suvel	doc_873901597504_item	2910151	et	3	main
lõpuks	doc_873901597504_item	2910159	et	4	main
meil	doc_873901597504_item	2910169	et	4	main
mulle	doc_873901597504_item	2910176	et	4	main
käinud	doc_873901597505_item	2910183	et	4	main
ja	doc_873901597505_item	2910184	et	3	main
mu	doc_873901597505_item	2910230	et	3	main
sõber	doc_873901597505_item	2910231	et	3	main
elab	doc_873901597505_item	2910232	et	3	main
seal	doc_873901597505_item	2910233	et	4	main
me	doc_873901597505_item	2910234	et	4	main
oli	doc_873901597505_item	2910242	et	3	main
ermitaži	doc_873901597505_item	2910247	et	2	main
juurde	doc_873901597505_item	2910267	et	4	main
pushkinis	doc_873901597505_item	2910270	et	4	main
see	doc_873901597505_item	2910271	et	3	main
niisugusest	doc_873901597505_item	2910283	et	3	main
austriasse	doc_873901597503_item	2909812	et	3	main
seal	doc_873901597503_item	2909815	et	4	main
nädalat	doc_873901597503_item	2909817	et	3	main
meeldib	doc_873901597503_item	2909819	et	3	main
suusatama	doc_873901597503_item	2909820	et	3	main
vanem	doc_873901597503_item	2909823	et	4	main
on	doc_873901597503_item	2909831	et	4	main
ka	doc_873901597503_item	2909832	et	3	main
väga	doc_873901597503_item	2909833	et	3	main
huvitav	doc_873901597503_item	2909834	et	4	main
kui	doc_873901597503_item	2909835	et	3	main
ma	doc_873901597503_item	2909836	et	3	main
maadele	doc_873901597503_item	2909839	et	4	main
teha	doc_873901597503_item	2909853	et	3	main
eelmisel	doc_873901597503_item	2909859	et	3	main
käisin	doc_873901597503_item	2909861	et	3	main
leidsin	doc_873901597503_item	2909863	et	3	main
palju	doc_873901597503_item	2909865	et	4	main
uut	doc_873901597503_item	2909866	et	3	main
sõpru	doc_873901597503_item	2909867	et	3	main
egiptuse	doc_873901597503_item	2909872	et	4	main
palju	doc_873901597503_item	2909875	et	4	main
minu	doc_873901597503_item	2909822	et	3	main
meeldib	doc_873901597503_item	2909825	et	3	main
sõita	doc_873901597503_item	2909827	et	3	main
et	doc_873901597503_item	2909829	et	3	main
teistele	doc_873901597503_item	2909838	et	4	main
uut	doc_873901597503_item	2909857	et	3	main
sain	doc_873901597503_item	2909874	et	3	main
ja	doc_873901597503_item	2909877	et	3	main
veel	doc_873901597503_item	2909879	et	4	main
kord	doc_873901597503_item	2909880	et	4	main
seal	doc_873901597503_item	2909881	et	4	main
käima	doc_873901597503_item	2909882	et	4	main
ma	doc_873901597503_item	2909883	et	3	main
olen	doc_873901597503_item	2909884	et	3	main
palju	doc_873901597503_item	2909885	et	4	main
oma	doc_873901597503_item	2909886	et	4	main
elus	doc_873901597503_item	2909887	et	4	main
näinud	doc_873901597503_item	2909888	et	4	main
ja	doc_873901597503_item	2909889	et	3	main
reisinud	doc_873901597503_item	2909890	et	4	main
mul	doc_873901597503_item	2909891	et	3	main
on	doc_873901597503_item	2909892	et	4	main
väga	doc_873901597503_item	2909893	et	3	main
palju	doc_873901597503_item	2909894	et	4	main
sõpru	doc_873901597503_item	2909895	et	3	main
erinevatest	doc_873901597503_item	2909896	et	4	main
riikidest	doc_873901597503_item	2909897	et	3	main
aga	doc_873901597503_item	2909898	et	3	main
ma	doc_873901597503_item	2909899	et	3	main
olen	doc_873901597503_item	2909900	et	3	main
kindel	doc_873901597503_item	2909901	et	3	main
et	doc_873901597503_item	2909902	et	3	main
minu	doc_873901597503_item	2909903	et	3	main
kodumaa	doc_873901597503_item	2909904	et	4	main
ja	doc_873901597503_item	2909905	et	3	main
perekond	doc_873901597503_item	2909906	et	3	main
on	doc_873901597503_item	2909907	et	4	main
parimad	doc_873901597503_item	2909908	et	4	main
essee	doc_873901597504_item	2909909	et	4	main
kus	doc_873901597504_item	2909910	et	3	main
olen	doc_873901597504_item	2909911	et	3	main
olen	doc_873901597504_item	2909915	et	3	main
mul	doc_873901597504_item	2909932	et	3	main
sõida	doc_873901597504_item	2909936	et	4	main
mina	doc_873901597504_item	2909937	et	4	main
olin	doc_873901597504_item	2909938	et	3	main
on	doc_873901597504_item	2909952	et	4	main
on	doc_873901597504_item	2909971	et	4	main
kivised	doc_873901597504_item	2909972	et	4	main
rannad	doc_873901597504_item	2909973	et	3	main
ja	doc_873901597504_item	2909974	et	3	main
väga	doc_873901597504_item	2909975	et	3	main
meres	doc_873901597504_item	2909979	et	3	main
saime	doc_873901597504_item	2910010	et	3	main
mere	doc_873901597504_item	2910012	et	3	main
tantsida	doc_873901597504_item	2910014	et	3	main
oli	doc_873901597504_item	2910017	et	3	main
kohti	doc_873901597504_item	2910029	et	4	main
mina	doc_873901597504_item	2910031	et	4	main
ja	doc_873901597504_item	2910052	et	3	main
ja	doc_873901597504_item	2910054	et	3	main
on	doc_873901597504_item	2910058	et	4	main
linn	doc_873901597504_item	2910069	et	3	main
peterbuurisse	doc_873901597504_item	2910077	et	4	main
paljud	doc_873901597504_item	2910080	et	3	main
ermitaž	doc_873901597504_item	2910083	et	2	main
praegu	doc_873901597504_item	2910086	et	3	main
rohkem	doc_873901597504_item	2910090	et	4	main
on	doc_873901597504_item	2910122	et	4	main
väga	doc_873901597504_item	2910128	et	3	main
aeg	doc_873901597504_item	2910132	et	3	main
väga	doc_873901597504_item	2910134	et	3	main
ta	doc_873901597504_item	2910144	et	4	main
saime	doc_873901597504_item	2910153	et	3	main
seda	doc_873901597504_item	2910155	et	3	main
ilu	doc_873901597504_item	2910156	et	4	main
hea	doc_873901597504_item	2910157	et	4	main
on	doc_873901597504_item	2910164	et	4	main
palju	doc_873901597504_item	2910165	et	4	main
on	doc_873901597504_item	2910170	et	4	main
ja	doc_873901597504_item	2910174	et	3	main
kui	doc_873901597505_item	2910221	et	3	main
lõpetasid	doc_873901597505_item	2910224	et	4	main
ma	doc_873901597505_item	2910225	et	3	main
läksin	doc_873901597505_item	2910226	et	3	main
palju	doc_873901597505_item	2910235	et	4	main
halb	doc_873901597505_item	2910243	et	3	main
siis	doc_873901597505_item	2910245	et	3	main
parem	doc_873901597505_item	2910258	et	4	main
et	doc_873901597505_item	2910259	et	3	main
olla	doc_873901597505_item	2910260	et	3	main
vanemata	doc_873901597505_item	2910263	et	4	main
elab	doc_873901597505_item	2910269	et	3	main
ilus	doc_873901597505_item	2910276	et	4	main
oli	doc_873901597505_item	2910291	et	3	main
et	doc_873901597505_item	2910295	et	3	main
asutada	doc_873901597505_item	2910296	et	3	main
ma	doc_873901597505_item	2910328	et	3	main
vanaema	doc_873901597505_item	2910332	et	4	main
suve	doc_873901597505_item	2910341	et	4	main
iga	doc_873901597505_item	2910352	et	4	main
päev	doc_873901597505_item	2910353	et	3	main
oleme	doc_873901597505_item	2910354	et	3	main
lahti	doc_873901597505_item	2910360	et	4	main
rannal	doc_873901597505_item	2910361	et	3	main
üks	doc_873901597505_item	2910366	et	3	main
huvitavalt	doc_873901597505_item	2910377	et	4	main
ei	doc_873901597505_item	2910385	et	4	main
polnud	doc_873901597505_item	2910393	et	3	main
väga	doc_873901597505_item	2910398	et	3	main
ja	doc_873901597506_item	2910411	et	3	main
olen	doc_873901597506_item	2910413	et	3	main
maalesõide	doc_873901597506_item	2910422	et	4	main
suvilas	doc_873901597506_item	2910425	et	3	main
ajal	doc_873901597506_item	2910434	et	4	main
spordikarjäär	doc_873901597506_item	2910435	et	3	main
nädalavahetusel	doc_873901597506_item	2910443	et	4	main
mitte	doc_873901597506_item	2910448	et	3	main
ainult	doc_873901597506_item	2910449	et	4	main
sõit	doc_873901597506_item	2910467	et	3	main
igaveseks	doc_873901597506_item	2910471	et	4	main
rahvusvaheline	doc_873901597506_item	2910474	et	4	main
öine	doc_873901597506_item	2910485	et	4	main
näinud	doc_873901597504_item	2909916	et	4	main
inimesed	doc_873901597504_item	2909917	et	3	main
kes	doc_873901597504_item	2909918	et	4	main
reisivad	doc_873901597504_item	2909919	et	4	main
tihti	doc_873901597504_item	2909920	et	3	main
nad	doc_873901597504_item	2909921	et	3	main
jutustada	doc_873901597504_item	2909924	et	3	main
kultuurist	doc_873901597504_item	2909927	et	3	main
loodusest	doc_873901597504_item	2909928	et	4	main
ukrainasse	doc_873901597504_item	2909935	et	4	main
odessas	doc_873901597504_item	2909939	et	4	main
ja	doc_873901597504_item	2909940	et	3	main
on	doc_873901597504_item	2909947	et	4	main
arhitektuur	doc_873901597504_item	2909949	et	3	main
ma	doc_873901597504_item	2909955	et	3	main
2	doc_873901597504_item	2909958	et	2	main
need	doc_873901597504_item	2909960	et	3	main
nädalad	doc_873901597504_item	2909963	et	3	main
suplesin	doc_873901597504_item	2909965	et	3	main
must	doc_873901597504_item	2909966	et	4	main
seal	doc_873901597504_item	2909970	et	4	main
oli	doc_873901597504_item	2909978	et	3	main
ma	doc_873901597504_item	2910020	et	3	main
palju	doc_873901597504_item	2910027	et	4	main
ilusaid	doc_873901597504_item	2910028	et	3	main
armastan	doc_873901597504_item	2910033	et	3	main
linna	doc_873901597504_item	2910035	et	4	main
inimesed	doc_873901597504_item	2910038	et	3	main
kes	doc_873901597504_item	2910039	et	4	main
eredad	doc_873901597504_item	2910047	et	3	main
ilusalt	doc_873901597504_item	2910051	et	4	main
on	doc_873901597504_item	2910062	et	4	main
peterburg	doc_873901597504_item	2910072	et	4	main
igal	doc_873901597504_item	2910073	et	3	main
aastal	doc_873901597504_item	2910074	et	3	main
mina	doc_873901597504_item	2910078	et	4	main
ma	doc_873901597504_item	2910087	et	3	main
mõned	doc_873901597504_item	2910091	et	3	main
inimesi	doc_873901597504_item	2910125	et	4	main
hooned	doc_873901597504_item	2910131	et	4	main
petergoffisse	doc_873901597504_item	2910146	et	4	main
sõitma	doc_873901597504_item	2910147	et	3	main
eriti	doc_873901597504_item	2910148	et	3	main
meelega	doc_873901597504_item	2910158	et	4	main
öelda	doc_873901597504_item	2910161	et	4	main
et	doc_873901597504_item	2910162	et	3	main
ka	doc_873901597504_item	2910168	et	3	main
ilus	doc_873901597504_item	2910172	et	4	main
mida	doc_873901597505_item	2910185	et	4	main
seal	doc_873901597505_item	2910229	et	4	main
seal	doc_873901597505_item	2910248	et	4	main
kõik	doc_873901597505_item	2910250	et	4	main
on	doc_873901597505_item	2910257	et	4	main
peterburi	doc_873901597505_item	2910273	et	4	main
lähedal	doc_873901597505_item	2910274	et	4	main
oli	doc_873901597505_item	2910275	et	3	main
suure	doc_873901597505_item	2910284	et	3	main
mul	doc_873901597505_item	2910290	et	3	main
vaja	doc_873901597505_item	2910292	et	4	main
tallinna	doc_873901597505_item	2910294	et	4	main
palju	doc_873901597504_item	2909923	et	4	main
erinevatest	doc_873901597504_item	2909925	et	4	main
inimestest	doc_873901597504_item	2909926	et	3	main
suvel	doc_873901597504_item	2909931	et	3	main
oli	doc_873901597504_item	2909933	et	3	main
ilus	doc_873901597504_item	2909948	et	4	main
aga	doc_873901597504_item	2909950	et	3	main
elasin	doc_873901597504_item	2909956	et	3	main
nädalat	doc_873901597504_item	2909959	et	3	main
olid	doc_873901597504_item	2909961	et	4	main
meres	doc_873901597504_item	2909967	et	3	main
ja	doc_873901597504_item	2909968	et	3	main
päevitasin	doc_873901597504_item	2909969	et	3	main
soe	doc_873901597504_item	2909976	et	4	main
kuidas	doc_873901597504_item	2909980	et	3	main
jalutasin	doc_873901597504_item	2909982	et	3	main
ma	doc_873901597504_item	2909981	et	3	main
mööda	doc_873901597504_item	2909983	et	4	main
õue	doc_873901597504_item	2909984	et	4	main
odessas	doc_873901597504_item	2909985	et	4	main
ma	doc_873901597504_item	2909986	et	3	main
sain	doc_873901597504_item	2909987	et	3	main
majade	doc_873901597504_item	2909988	et	3	main
seinades	doc_873901597504_item	2909989	et	3	main
viinamarja	doc_873901597504_item	2909990	et	4	main
kiš-miš	doc_873901597504_item	2909991	et	2	main
näidata	doc_873901597504_item	2909992	et	4	main
ja	doc_873901597504_item	2909993	et	3	main
süüa	doc_873901597504_item	2909994	et	3	main
ta	doc_873901597504_item	2909995	et	4	main
oli	doc_873901597504_item	2909996	et	3	main
väga	doc_873901597504_item	2909997	et	3	main
maitsev	doc_873901597504_item	2909998	et	4	main
ma	doc_873901597504_item	2909999	et	3	main
olen	doc_873901597504_item	2910000	et	3	main
imestanud	doc_873901597504_item	2910001	et	4	main
see	doc_873901597504_item	2910002	et	3	main
oli	doc_873901597504_item	2910003	et	3	main
tore	doc_873901597504_item	2910004	et	3	main
kui	doc_873901597504_item	2910005	et	3	main
öökluubid	doc_873901597504_item	2910006	et	4	main
olid	doc_873901597504_item	2910007	et	4	main
me	doc_873901597504_item	2910009	et	4	main
ilm	doc_873901597504_item	2910016	et	3	main
alati	doc_873901597504_item	2910019	et	4	main
uskuda	doc_873901597504_item	2910023	et	3	main
mina	doc_873901597504_item	2910025	et	4	main
külastasin	doc_873901597504_item	2910026	et	3	main
väga	doc_873901597504_item	2910032	et	3	main
elavad	doc_873901597504_item	2910040	et	4	main
odessas	doc_873901597504_item	2910041	et	4	main
nad	doc_873901597504_item	2910042	et	3	main
on	doc_873901597504_item	2910043	et	4	main
ja	doc_873901597504_item	2910046	et	3	main
on	doc_873901597504_item	2910049	et	4	main
naeravad	doc_873901597504_item	2910056	et	3	main
linn	doc_873901597504_item	2910060	et	3	main
on	doc_873901597504_item	2910070	et	4	main
sankt	doc_873901597504_item	2910071	et	4	main
sõidan	doc_873901597504_item	2910076	et	3	main
külastasin	doc_873901597504_item	2910079	et	3	main
ja	doc_873901597504_item	2910082	et	3	main
et	doc_873901597504_item	2910085	et	3	main
saan	doc_873901597504_item	2910088	et	4	main
asjad	doc_873901597504_item	2910092	et	3	main
see	doc_873901597504_item	2910094	et	3	main
on	doc_873901597504_item	2910100	et	4	main
mõned	doc_873901597504_item	2910101	et	3	main
teadused	doc_873901597504_item	2910102	et	3	main
peterbuuris	doc_873901597504_item	2910103	et	4	main
on	doc_873901597504_item	2910104	et	4	main
väga	doc_873901597504_item	2910105	et	3	main
aktiivne	doc_873901597504_item	2910106	et	3	main
elu	doc_873901597504_item	2910107	et	4	main
me	doc_873901597504_item	2910108	et	4	main
seda	doc_873901597504_item	2910110	et	3	main
saime	doc_873901597504_item	2910109	et	3	main
näidata	doc_873901597504_item	2910111	et	4	main
et	doc_873901597504_item	2910112	et	3	main
see	doc_873901597504_item	2910113	et	3	main
pole	doc_873901597504_item	2910114	et	3	main
olulist	doc_873901597504_item	2910115	et	4	main
päev	doc_873901597504_item	2910116	et	3	main
või	doc_873901597504_item	2910117	et	4	main
öö	doc_873901597504_item	2910118	et	4	main
on	doc_873901597504_item	2910119	et	4	main
õues	doc_873901597504_item	2910120	et	4	main
seal	doc_873901597504_item	2910121	et	4	main
alati	doc_873901597504_item	2910123	et	4	main
palju	doc_873901597504_item	2910124	et	4	main
ilusad	doc_873901597504_item	2910129	et	3	main
suures	doc_873901597504_item	2910137	et	3	main
kui	doc_873901597504_item	2910139	et	3	main
inimene	doc_873901597504_item	2910140	et	3	main
külastab	doc_873901597504_item	2910141	et	3	main
peterburg	doc_873901597504_item	2910142	et	4	main
siis	doc_873901597504_item	2910143	et	3	main
kevadel	doc_873901597504_item	2910149	et	4	main
toredaid	doc_873901597504_item	2910166	et	3	main
loodus	doc_873901597504_item	2910173	et	4	main
sellest	doc_873901597504_item	2910175	et	4	main
meeldib	doc_873901597504_item	2910177	et	3	main
autoga	doc_873901597504_item	2910178	et	3	main
reisida	doc_873901597504_item	2910179	et	3	main
essee	doc_873901597505_item	2910180	et	4	main
kus	doc_873901597505_item	2910181	et	3	main
olen	doc_873901597505_item	2910182	et	3	main
saanud	doc_873901597504_item	2910022	et	4	main
sellesse	doc_873901597504_item	2910024	et	4	main
seda	doc_873901597504_item	2910034	et	3	main
mulle	doc_873901597504_item	2910036	et	4	main
meeldisid	doc_873901597504_item	2910037	et	4	main
väga	doc_873901597504_item	2910044	et	3	main
ilusad	doc_873901597504_item	2910045	et	3	main
nad	doc_873901597504_item	2910048	et	3	main
kõik	doc_873901597504_item	2910055	et	4	main
huumoristid	doc_873901597504_item	2910064	et	4	main
aga	doc_873901597504_item	2910065	et	3	main
venemaal	doc_873901597504_item	2910066	et	4	main
minu	doc_873901597504_item	2910067	et	3	main
lemmik	doc_873901597504_item	2910068	et	3	main
sellepärast	doc_873901597504_item	2910084	et	3	main
arhitektuurilised	doc_873901597504_item	2910130	et	4	main
selles	doc_873901597504_item	2910136	et	4	main
linnas	doc_873901597504_item	2910138	et	4	main
peab	doc_873901597504_item	2910145	et	4	main
või	doc_873901597504_item	2910150	et	4	main
me	doc_873901597504_item	2910152	et	4	main
näidata	doc_873901597504_item	2910154	et	4	main
tahaksin	doc_873901597504_item	2910160	et	3	main
eestis	doc_873901597504_item	2910163	et	3	main
kohti	doc_873901597504_item	2910167	et	4	main
väga	doc_873901597504_item	2910171	et	3	main
olen	doc_873901597505_item	2910186	et	3	main
näinud	doc_873901597505_item	2910187	et	4	main
suvi	doc_873901597505_item	2910188	et	3	main
on	doc_873901597505_item	2910189	et	4	main
mu	doc_873901597505_item	2910190	et	3	main
lemmik	doc_873901597505_item	2910191	et	3	main
aastaaeg	doc_873901597505_item	2910192	et	3	main
sest	doc_873901597505_item	2910193	et	4	main
alati	doc_873901597505_item	2910194	et	4	main
olen	doc_873901597505_item	2910195	et	3	main
vaba	doc_873901597505_item	2910196	et	4	main
ja	doc_873901597505_item	2910197	et	3	main
juhtub	doc_873901597505_item	2910198	et	3	main
midagi	doc_873901597505_item	2910199	et	4	main
huvitav	doc_873901597505_item	2910200	et	4	main
igal	doc_873901597505_item	2910201	et	3	main
suvel	doc_873901597505_item	2910202	et	3	main
ma	doc_873901597505_item	2910203	et	3	main
reisisin	doc_873901597505_item	2910204	et	3	main
aga	doc_873901597505_item	2910205	et	3	main
sel	doc_873901597505_item	2910206	et	3	main
suvel	doc_873901597505_item	2910207	et	3	main
polnud	doc_873901597505_item	2910208	et	3	main
nii	doc_873901597505_item	2910209	et	3	main
aega	doc_873901597505_item	2910211	et	4	main
selleks	doc_873901597505_item	2910212	et	4	main
ja	doc_873901597505_item	2910213	et	3	main
üldse	doc_873901597505_item	2910214	et	3	main
palju	doc_873901597505_item	2910210	et	4	main
soovi	doc_873901597505_item	2910215	et	4	main
sest	doc_873901597505_item	2910216	et	4	main
olin	doc_873901597505_item	2910217	et	3	main
väsinud	doc_873901597505_item	2910218	et	4	main
koolist	doc_873901597505_item	2910219	et	4	main
algas	doc_873901597505_item	2910220	et	3	main
eksamid	doc_873901597505_item	2910223	et	3	main
venemaale	doc_873901597505_item	2910227	et	4	main
peterburisse	doc_873901597505_item	2910228	et	4	main
kõik	doc_873901597505_item	2910222	et	4	main
pargides	doc_873901597505_item	2910237	et	4	main
ja	doc_873901597505_item	2910238	et	3	main
neva	doc_873901597505_item	2910239	et	4	main
rannas	doc_873901597505_item	2910240	et	3	main
kui	doc_873901597505_item	2910241	et	3	main
läksime	doc_873901597505_item	2910246	et	3	main
mulle	doc_873901597505_item	2910249	et	4	main
meeldib	doc_873901597505_item	2910251	et	3	main
sest	doc_873901597505_item	2910252	et	4	main
olin	doc_873901597505_item	2910253	et	3	main
seal	doc_873901597505_item	2910261	et	4	main
pärast	doc_873901597505_item	2910264	et	4	main
sõitsin	doc_873901597505_item	2910265	et	3	main
onu	doc_873901597505_item	2910266	et	4	main
oleme	doc_873901597505_item	2910279	et	3	main
ladoga	doc_873901597505_item	2910281	et	4	main
juulil	doc_873901597505_item	2910289	et	3	main
et	doc_873901597505_item	2910304	et	3	main
puhata	doc_873901597505_item	2910305	et	4	main
ja	doc_873901597505_item	2910306	et	3	main
näha	doc_873901597505_item	2910307	et	3	main
midagi	doc_873901597505_item	2910308	et	4	main
käisin	doc_873901597505_item	2910309	et	3	main
vana	doc_873901597505_item	2910310	et	4	main
linnas	doc_873901597505_item	2910311	et	4	main
ja	doc_873901597505_item	2910312	et	3	main
piiritas	doc_873901597505_item	2910313	et	4	main
oli	doc_873901597505_item	2910314	et	3	main
väga	doc_873901597505_item	2910315	et	3	main
tore	doc_873901597505_item	2910316	et	3	main
sest	doc_873901597505_item	2910317	et	4	main
nägisin	doc_873901597505_item	2910318	et	4	main
seda	doc_873901597505_item	2910319	et	3	main
esimest	doc_873901597505_item	2910320	et	4	main
otsustasin	doc_873901597505_item	2910329	et	3	main
maale	doc_873901597505_item	2910331	et	4	main
juurde	doc_873901597505_item	2910333	et	4	main
mis	doc_873901597505_item	2910334	et	4	main
asub	doc_873901597505_item	2910335	et	3	main
maal	doc_873901597505_item	2910342	et	4	main
parimad	doc_873901597505_item	2910346	et	4	main
alati	doc_873901597505_item	2910349	et	4	main
on	doc_873901597505_item	2910350	et	4	main
rõõmus	doc_873901597505_item	2910351	et	4	main
ja	doc_873901597505_item	2910371	et	3	main
aga	doc_873901597505_item	2910378	et	3	main
minna	doc_873901597505_item	2910382	et	3	main
ema	doc_873901597505_item	2910388	et	4	main
olen	doc_873901597505_item	2910389	et	3	main
aga	doc_873901597505_item	2910396	et	3	main
mu	doc_873901597505_item	2910402	et	3	main
veel	doc_873901597505_item	2910404	et	4	main
kus	doc_873901597506_item	2910408	et	3	main
jalatsime	doc_873901597505_item	2910236	et	4	main
ilm	doc_873901597505_item	2910244	et	3	main
üksi	doc_873901597505_item	2910254	et	4	main
ja	doc_873901597505_item	2910255	et	3	main
see	doc_873901597505_item	2910256	et	3	main
ilma	doc_873901597505_item	2910262	et	4	main
ta	doc_873901597505_item	2910268	et	4	main
on	doc_873901597505_item	2910272	et	4	main
ilm	doc_873901597505_item	2910277	et	3	main
ja	doc_873901597505_item	2910278	et	3	main
käinud	doc_873901597505_item	2910280	et	4	main
järvel	doc_873901597505_item	2910282	et	4	main
järve	doc_873901597505_item	2910285	et	4	main
polnud	doc_873901597505_item	2910287	et	3	main
käinud	doc_873901597505_item	2910325	et	4	main
siin	doc_873901597505_item	2910326	et	4	main
kõik	doc_873901597505_item	2910344	et	4	main
kellega	doc_873901597505_item	2910348	et	3	main
valge	doc_873901597505_item	2910356	et	4	main
järvel	doc_873901597505_item	2910357	et	4	main
või	doc_873901597505_item	2910358	et	4	main
soome	doc_873901597505_item	2910359	et	3	main
päevatasime	doc_873901597505_item	2910365	et	4	main
jalutasin	doc_873901597505_item	2910368	et	3	main
olen	doc_873901597505_item	2910372	et	3	main
kardanud	doc_873901597505_item	2910390	et	4	main
kuigi	doc_873901597505_item	2910391	et	3	main
mis	doc_873901597505_item	2910400	et	4	main
essee	doc_873901597506_item	2910407	et	4	main
näinud	doc_873901597506_item	2910414	et	4	main
mõeldes	doc_873901597506_item	2910415	et	3	main
enda	doc_873901597506_item	2910416	et	4	main
minevikust	doc_873901597506_item	2910417	et	3	main
meenutan	doc_873901597506_item	2910418	et	3	main
spordilaagreid	doc_873901597506_item	2910421	et	3	main
võistlustantsule	doc_873901597506_item	2910436	et	3	main
8	doc_873901597506_item	2910439	et	2	main
erinevates	doc_873901597506_item	2910450	et	4	main
rohkem	doc_873901597506_item	2910457	et	4	main
aega	doc_873901597506_item	2910458	et	4	main
veetsin	doc_873901597506_item	2910459	et	3	main
jäi	doc_873901597506_item	2910468	et	3	main
võistlus	doc_873901597506_item	2910475	et	3	main
oli	doc_873901597506_item	2910478	et	3	main
praha	doc_873901597506_item	2910486	et	4	main
oli	doc_873901597506_item	2910489	et	3	main
tantsuklubiga	doc_873901597506_item	2910500	et	3	main
riikides	doc_873901597506_item	2910505	et	3	main
koolis	doc_873901597506_item	2910513	et	4	main
tänu	doc_873901597506_item	2910526	et	4	main
ema	doc_873901597506_item	2910529	et	4	main
sõbrale	doc_873901597506_item	2910530	et	3	main
aardeid	doc_873901597506_item	2910552	et	3	main
vaadata	doc_873901597506_item	2910553	et	4	main
kõige	doc_873901597506_item	2910568	et	4	main
kellele	doc_873901597506_item	2910579	et	4	main
ka	doc_873901597506_item	2910589	et	3	main
ma	doc_873901597506_item	2910592	et	3	main
läbi	doc_873901597506_item	2910607	et	4	main
ukrainlased	doc_873901597506_item	2910613	et	3	main
on	doc_873901597506_item	2910628	et	4	main
omad	doc_873901597506_item	2910638	et	4	main
kuid	doc_873901597506_item	2910642	et	4	main
mind	doc_873901597506_item	2910648	et	4	main
kultuuriga	doc_873901597506_item	2910669	et	4	main
romaan	doc_873901597507_item	2910675	et	3	main
on	doc_873901597507_item	2910678	et	4	main
esimene	doc_873901597507_item	2910679	et	3	main
euroopa	doc_873901597507_item	2910680	et	4	main
tasemele	doc_873901597507_item	2910681	et	3	main
küündinud	doc_873901597507_item	2910682	et	4	main
kuueteistkümnendal	doc_873901597507_item	2910688	et	4	main
romaani	doc_873901597507_item	2910690	et	4	main
romaan	doc_873901597507_item	2910695	et	3	main
on	doc_873901597507_item	2910696	et	4	main
kes	doc_873901597507_item	2910713	et	4	main
kõik	doc_873901597507_item	2910728	et	4	main
nad	doc_873901597507_item	2910734	et	3	main
mõtlevad	doc_873901597507_item	2910735	et	4	main
et	doc_873901597507_item	2910736	et	3	main
raha	doc_873901597507_item	2910737	et	4	main
kõige	doc_873901597507_item	2910739	et	4	main
veel	doc_873901597505_item	2910286	et	4	main
näinud	doc_873901597505_item	2910288	et	4	main
minna	doc_873901597505_item	2910293	et	3	main
ülikooli	doc_873901597505_item	2910297	et	4	main
ma	doc_873901597505_item	2910298	et	3	main
tegin	doc_873901597505_item	2910299	et	3	main
seda	doc_873901597505_item	2910300	et	3	main
ja	doc_873901597505_item	2910301	et	3	main
jäin	doc_873901597505_item	2910302	et	3	main
siin	doc_873901597505_item	2910303	et	4	main
korda	doc_873901597505_item	2910321	et	4	main
tihti	doc_873901597505_item	2910323	et	3	main
olen	doc_873901597505_item	2910324	et	3	main
augustis	doc_873901597505_item	2910327	et	3	main
seal	doc_873901597505_item	2910337	et	4	main
ma	doc_873901597505_item	2910338	et	3	main
on	doc_873901597505_item	2910343	et	4	main
ja	doc_873901597505_item	2910364	et	3	main
kord	doc_873901597505_item	2910367	et	4	main
üksi	doc_873901597505_item	2910369	et	4	main
metsas	doc_873901597505_item	2910370	et	3	main
näinud	doc_873901597505_item	2910373	et	4	main
karupoja	doc_873901597505_item	2910374	et	4	main
mul	doc_873901597505_item	2910375	et	3	main
oli	doc_873901597505_item	2910376	et	3	main
et	doc_873901597505_item	2910380	et	3	main
välja	doc_873901597505_item	2910383	et	4	main
peaegu	doc_873901597505_item	2910392	et	4	main
käinud	doc_873901597505_item	2910394	et	4	main
näinud	doc_873901597505_item	2910397	et	4	main
jäätab	doc_873901597505_item	2910401	et	3	main
olen	doc_873901597506_item	2910409	et	3	main
lõbusat	doc_873901597506_item	2910419	et	3	main
lapsepõlve	doc_873901597506_item	2910420	et	4	main
arust	doc_873901597506_item	2910427	et	4	main
jaoks	doc_873901597506_item	2910431	et	4	main
oli	doc_873901597506_item	2910432	et	3	main
tol	doc_873901597506_item	2910433	et	3	main
ma	doc_873901597506_item	2910437	et	3	main
pühendasin	doc_873901597506_item	2910438	et	3	main
igal	doc_873901597506_item	2910442	et	3	main
olid	doc_873901597506_item	2910444	et	4	main
vaid	doc_873901597506_item	2910453	et	3	main
ka	doc_873901597506_item	2910454	et	3	main
välismaal	doc_873901597506_item	2910455	et	4	main
linnas	doc_873901597506_item	2910463	et	4	main
jalutamas	doc_873901597506_item	2910464	et	3	main
kuid	doc_873901597506_item	2910465	et	4	main
mulle	doc_873901597506_item	2910469	et	4	main
oli	doc_873901597506_item	2910473	et	3	main
tšehhis	doc_873901597506_item	2910476	et	2	main
mis	doc_873901597506_item	2910488	et	4	main
tähti	doc_873901597506_item	2910496	et	4	main
särasid	doc_873901597506_item	2910497	et	4	main
ka	doc_873901597506_item	2910503	et	3	main
meie	doc_873901597506_item	2910514	et	4	main
mitte	doc_873901597505_item	2910322	et	3	main
minna	doc_873901597505_item	2910330	et	3	main
venemaal	doc_873901597505_item	2910336	et	4	main
olen	doc_873901597505_item	2910339	et	3	main
iga	doc_873901597505_item	2910340	et	4	main
mu	doc_873901597505_item	2910345	et	3	main
sõbrad	doc_873901597505_item	2910347	et	3	main
käinud	doc_873901597505_item	2910355	et	4	main
seal	doc_873901597505_item	2910362	et	4	main
suplesime	doc_873901597505_item	2910363	et	3	main
otsustasin	doc_873901597505_item	2910379	et	3	main
parem	doc_873901597505_item	2910381	et	4	main
et	doc_873901597505_item	2910384	et	3	main
kohtu	doc_873901597505_item	2910386	et	4	main
ta	doc_873901597505_item	2910387	et	4	main
kuskil	doc_873901597505_item	2910395	et	3	main
palju	doc_873901597505_item	2910399	et	4	main
mälus	doc_873901597505_item	2910403	et	4	main
palju	doc_873901597505_item	2910405	et	4	main
aega	doc_873901597505_item	2910406	et	4	main
käinud	doc_873901597506_item	2910410	et	4	main
mida	doc_873901597506_item	2910412	et	4	main
minu	doc_873901597506_item	2910426	et	3	main
kõige	doc_873901597506_item	2910428	et	4	main
tähtsam	doc_873901597506_item	2910429	et	4	main
minu	doc_873901597506_item	2910430	et	3	main
aastat	doc_873901597506_item	2910440	et	3	main
eesti	doc_873901597506_item	2910451	et	4	main
linnades	doc_873901597506_item	2910452	et	3	main
ma	doc_873901597506_item	2910460	et	3	main
spordisaalis	doc_873901597506_item	2910461	et	3	main
mitte	doc_873901597506_item	2910462	et	3	main
see	doc_873901597506_item	2910472	et	3	main
jäänud	doc_873901597506_item	2910484	et	4	main
imekaunis	doc_873901597506_item	2910490	et	4	main
tunne	doc_873901597506_item	2910492	et	4	main
nagu	doc_873901597506_item	2910493	et	3	main
tuhat	doc_873901597506_item	2910494	et	4	main
olin	doc_873901597506_item	2910501	et	3	main
lätis	doc_873901597506_item	2910506	et	4	main
leedus	doc_873901597506_item	2910507	et	4	main
poolas	doc_873901597506_item	2910508	et	4	main
ermitaaži	doc_873901597506_item	2910534	et	2	main
kuldehed	doc_873901597506_item	2910542	et	4	main
neid	doc_873901597506_item	2910551	et	4	main
ema	doc_873901597506_item	2910555	et	4	main
ja	doc_873901597506_item	2910559	et	3	main
külastamine	doc_873901597506_item	2910573	et	4	main
inimest	doc_873901597506_item	2910578	et	3	main
ei	doc_873901597506_item	2910580	et	4	main
meeldinud	doc_873901597506_item	2910581	et	4	main
kohtadest	doc_873901597506_item	2910590	et	3	main
olin	doc_873901597506_item	2910593	et	3	main
minu	doc_873901597506_item	2910596	et	3	main
leedu	doc_873901597506_item	2910609	et	4	main
ja	doc_873901597506_item	2910610	et	3	main
on	doc_873901597506_item	2910614	et	4	main
inimesed	doc_873901597506_item	2910617	et	3	main
armastavad	doc_873901597506_item	2910619	et	4	main
oma	doc_873901597506_item	2910620	et	4	main
toredaid	doc_873901597506_item	2910423	et	3	main
suvesid	doc_873901597506_item	2910424	et	3	main
peaaegu	doc_873901597506_item	2910441	et	3	main
võistlused	doc_873901597506_item	2910445	et	3	main
mis	doc_873901597506_item	2910446	et	4	main
toimusid	doc_873901597506_item	2910447	et	4	main
kahjuks	doc_873901597506_item	2910456	et	4	main
üks	doc_873901597506_item	2910466	et	3	main
meelde	doc_873901597506_item	2910470	et	3	main
meil	doc_873901597506_item	2910477	et	4	main
tellitud	doc_873901597506_item	2910479	et	4	main
ekskursioon	doc_873901597506_item	2910480	et	3	main
eriti	doc_873901597506_item	2910481	et	3	main
on	doc_873901597506_item	2910482	et	4	main
meelde	doc_873901597506_item	2910483	et	3	main
oli	doc_873901597506_item	2910491	et	3	main
ma	doc_873901597506_item	2910502	et	3	main
teistes	doc_873901597506_item	2910504	et	4	main
iga	doc_873901597506_item	2910512	et	4	main
gümnaasiumis	doc_873901597506_item	2910515	et	3	main
korraldati	doc_873901597506_item	2910516	et	3	main
erinevaid	doc_873901597506_item	2910517	et	4	main
reise	doc_873901597506_item	2910518	et	3	main
kõige	doc_873901597506_item	2910519	et	4	main
huvitavamad	doc_873901597506_item	2910520	et	4	main
reisid	doc_873901597506_item	2910522	et	4	main
peterburi	doc_873901597506_item	2910523	et	4	main
ja	doc_873901597506_item	2910524	et	3	main
riiasse	doc_873901597506_item	2910525	et	4	main
külastada	doc_873901597506_item	2910533	et	3	main
tsaari	doc_873901597506_item	2910540	et	4	main
kuldnõud	doc_873901597506_item	2910543	et	3	main
jne	doc_873901597506_item	2910544	et	4	main
väga	doc_873901597506_item	2910545	et	3	main
raske	doc_873901597506_item	2910546	et	4	main
kuid	doc_873901597506_item	2910554	et	4	main
mulle	doc_873901597506_item	2910561	et	4	main
venemaa	doc_873901597506_item	2910564	et	4	main
eliit	doc_873901597506_item	2910565	et	3	main
riias	doc_873901597506_item	2910566	et	4	main
aga	doc_873901597506_item	2910567	et	3	main
et	doc_873901597506_item	2910575	et	3	main
ühtegi	doc_873901597506_item	2910577	et	4	main
ja	doc_873901597506_item	2910584	et	3	main
aega	doc_873901597506_item	2910585	et	4	main
veeta	doc_873901597506_item	2910586	et	4	main
tahaks	doc_873901597506_item	2910587	et	3	main
jutustada	doc_873901597506_item	2910588	et	3	main
kus	doc_873901597506_item	2910591	et	3	main
oma	doc_873901597506_item	2910594	et	4	main
isa	doc_873901597506_item	2910597	et	4	main
on	doc_873901597506_item	2910598	et	4	main
pärit	doc_873901597506_item	2910599	et	3	main
ukrainast	doc_873901597506_item	2910600	et	4	main
seepärast	doc_873901597506_item	2910601	et	3	main
igal	doc_873901597506_item	2910602	et	3	main
suvel	doc_873901597506_item	2910603	et	3	main
poola	doc_873901597506_item	2910611	et	4	main
väga	doc_873901597506_item	2910615	et	3	main
lahked	doc_873901597506_item	2910616	et	3	main
kes	doc_873901597506_item	2910618	et	4	main
eesti	doc_873901597506_item	2910622	et	4	main
elu	doc_873901597506_item	2910623	et	4	main
erineb	doc_873901597506_item	2910624	et	3	main
teisel	doc_873901597506_item	2910634	et	4	main
planeedil	doc_873901597506_item	2910635	et	3	main
kus	doc_873901597506_item	2910636	et	3	main
kombed	doc_873901597506_item	2910641	et	3	main
ma	doc_873901597506_item	2910643	et	3	main
õnnelik	doc_873901597506_item	2910646	et	3	main
kindel	doc_873901597506_item	2910655	et	3	main
ma	doc_873901597506_item	2910658	et	3	main
essee	doc_873901597507_item	2910670	et	4	main
piimamees	doc_873901597507_item	2910692	et	4	main
populaarne	doc_873901597507_item	2910697	et	3	main
sild	doc_873901597506_item	2910487	et	3	main
hõbedaid	doc_873901597506_item	2910495	et	3	main
mustal	doc_873901597506_item	2910498	et	3	main
taustal	doc_873901597506_item	2910499	et	3	main
saksamaal	doc_873901597506_item	2910509	et	4	main
soomes	doc_873901597506_item	2910510	et	4	main
nagu	doc_873901597506_item	2910511	et	3	main
ühele	doc_873901597506_item	2910527	et	3	main
minu	doc_873901597506_item	2910528	et	3	main
ma	doc_873901597506_item	2910531	et	3	main
kuldruumi	doc_873901597506_item	2910535	et	4	main
olid	doc_873901597506_item	2910537	et	4	main
perekonna	doc_873901597506_item	2910541	et	4	main
et	doc_873901597506_item	2910550	et	3	main
sõber	doc_873901597506_item	2910556	et	3	main
selle	doc_873901597506_item	2910558	et	4	main
näitas	doc_873901597506_item	2910560	et	3	main
kuidas	doc_873901597506_item	2910562	et	3	main
elas	doc_873901597506_item	2910563	et	3	main
restorani	doc_873901597506_item	2910572	et	4	main
pole	doc_873901597506_item	2910576	et	3	main
perekonnaga	doc_873901597506_item	2910595	et	4	main
läti	doc_873901597506_item	2910608	et	4	main
reeglid	doc_873901597506_item	2910639	et	3	main
olen	doc_873901597506_item	2910644	et	3	main
et	doc_873901597506_item	2910656	et	3	main
mäeküla	doc_873901597507_item	2910671	et	4	main
piimamees	doc_873901597507_item	2910672	et	4	main
eesti	doc_873901597507_item	2910683	et	4	main
kirjanik	doc_873901597507_item	2910684	et	3	main
kirjutas	doc_873901597507_item	2910685	et	3	main
tuhande	doc_873901597507_item	2910686	et	3	main
aga	doc_873901597507_item	2910693	et	3	main
ka	doc_873901597507_item	2910698	et	3	main
me	doc_873901597507_item	2910701	et	4	main
saame	doc_873901597507_item	2910702	et	4	main
nimetada	doc_873901597507_item	2910703	et	3	main
seda	doc_873901597507_item	2910704	et	3	main
kohtuvad	doc_873901597507_item	2910710	et	4	main
noored	doc_873901597507_item	2910711	et	3	main
isik	doc_873901597507_item	2910717	et	3	main
mõted	doc_873901597507_item	2910720	et	4	main
saada	doc_873901597507_item	2910732	et	4	main
me	doc_873901597507_item	2910745	et	4	main
näeme	doc_873901597507_item	2910746	et	3	main
et	doc_873901597507_item	2910747	et	3	main
tõesti	doc_873901597507_item	2910770	et	3	main
kellel	doc_873901597507_item	2910772	et	4	main
palju	doc_873901597507_item	2910774	et	4	main
ta	doc_873901597507_item	2910815	et	4	main
tema	doc_873901597507_item	2910819	et	4	main
olid	doc_873901597506_item	2910521	et	4	main
sain	doc_873901597506_item	2910532	et	3	main
kus	doc_873901597506_item	2910536	et	3	main
eksponeeritud	doc_873901597506_item	2910538	et	4	main
venemaa	doc_873901597506_item	2910539	et	4	main
on	doc_873901597506_item	2910547	et	4	main
saada	doc_873901597506_item	2910548	et	4	main
luba	doc_873901597506_item	2910549	et	4	main
sai	doc_873901597506_item	2910557	et	4	main
meeldivam	doc_873901597506_item	2910569	et	4	main
oli	doc_873901597506_item	2910570	et	3	main
lido	doc_873901597506_item	2910571	et	4	main
arvan	doc_873901597506_item	2910574	et	3	main
seal	doc_873901597506_item	2910582	et	4	main
süüa	doc_873901597506_item	2910583	et	3	main
me	doc_873901597506_item	2910604	et	4	main
sõidame	doc_873901597506_item	2910605	et	3	main
autoga	doc_873901597506_item	2910606	et	3	main
ukrainasse	doc_873901597506_item	2910612	et	4	main
maad	doc_873901597506_item	2910621	et	4	main
ukraina	doc_873901597506_item	2910625	et	4	main
elust	doc_873901597506_item	2910626	et	3	main
mõnikord	doc_873901597506_item	2910627	et	3	main
on	doc_873901597506_item	2910637	et	4	main
alati	doc_873901597506_item	2910649	et	4	main
ja	doc_873901597506_item	2910651	et	3	main
armastatakse	doc_873901597506_item	2910652	et	3	main
olen	doc_873901597506_item	2910654	et	3	main
veel	doc_873901597506_item	2910660	et	4	main
eduard	doc_873901597507_item	2910676	et	4	main
üheksasaja	doc_873901597507_item	2910687	et	4	main
mäeküla	doc_873901597507_item	2910691	et	4	main
romaani	doc_873901597507_item	2910705	et	4	main
nagu	doc_873901597507_item	2910716	et	3	main
nende	doc_873901597507_item	2910719	et	4	main
selline	doc_873901597506_item	2910629	et	4	main
tunne	doc_873901597506_item	2910630	et	4	main
et	doc_873901597506_item	2910631	et	3	main
ma	doc_873901597506_item	2910632	et	3	main
olen	doc_873901597506_item	2910633	et	3	main
ja	doc_873901597506_item	2910640	et	3	main
väga	doc_873901597506_item	2910645	et	3	main
et	doc_873901597506_item	2910647	et	3	main
oodatakse	doc_873901597506_item	2910650	et	3	main
seal	doc_873901597506_item	2910653	et	4	main
tulevikus	doc_873901597506_item	2910657	et	4	main
külastan	doc_873901597506_item	2910659	et	3	main
palju	doc_873901597506_item	2910661	et	4	main
riike	doc_873901597506_item	2910662	et	3	main
ja	doc_873901597506_item	2910663	et	3	main
tutvun	doc_873901597506_item	2910664	et	3	main
teiste	doc_873901597506_item	2910665	et	4	main
inimeste	doc_873901597506_item	2910666	et	3	main
elustiiliga	doc_873901597506_item	2910667	et	3	main
ja	doc_873901597506_item	2910668	et	3	main
on	doc_873901597507_item	2910673	et	4	main
realistlik	doc_873901597507_item	2910674	et	3	main
vilde	doc_873901597507_item	2910677	et	4	main
aastal	doc_873901597507_item	2910689	et	3	main
see	doc_873901597507_item	2910694	et	3	main
realistikuks	doc_873901597507_item	2910706	et	4	main
kõigepealt	doc_873901597507_item	2910707	et	3	main
inimesed	doc_873901597507_item	2910712	et	3	main
ja	doc_873901597507_item	2910718	et	3	main
on	doc_873901597507_item	2910721	et	4	main
tõnu	doc_873901597507_item	2910724	et	4	main
tähtis	doc_873901597507_item	2910740	et	4	main
on	doc_873901597507_item	2910749	et	4	main
südametes	doc_873901597507_item	2910759	et	4	main
elab	doc_873901597507_item	2910760	et	3	main
armastus	doc_873901597507_item	2910761	et	4	main
neid	doc_873901597507_item	2910765	et	4	main
kui	doc_873901597507_item	2910766	et	3	main
riikasteks	doc_873901597507_item	2910767	et	4	main
nii	doc_873901597507_item	2910768	et	3	main
raha	doc_873901597507_item	2910775	et	4	main
tõnu	doc_873901597507_item	2910809	et	4	main
keda	doc_873901597507_item	2910824	et	4	main
raha	doc_873901597507_item	2910837	et	4	main
näiteks	doc_873901597507_item	2910846	et	4	main
ametnikud	doc_873901597507_item	2910847	et	3	main
rikkad	doc_873901597507_item	2910850	et	4	main
ja	doc_873901597507_item	2910867	et	3	main
nad	doc_873901597507_item	2910876	et	3	main
rohkem	doc_873901597507_item	2910878	et	4	main
on	doc_873901597507_item	2910882	et	4	main
elus	doc_873901597507_item	2910892	et	4	main
seda	doc_873901597507_item	2910896	et	3	main
jääma	doc_873901597507_item	2910903	et	4	main
on	doc_873901597507_item	2910919	et	4	main
noor	doc_873901597507_item	2910920	et	3	main
tänapäeval	doc_873901597507_item	2910699	et	3	main
ja	doc_873901597507_item	2910700	et	3	main
meie	doc_873901597507_item	2910708	et	4	main
elus	doc_873901597507_item	2910709	et	4	main
ei	doc_873901597507_item	2910714	et	4	main
kujuta	doc_873901597507_item	2910715	et	4	main
nagu	doc_873901597507_item	2910723	et	3	main
elu	doc_873901597507_item	2910729	et	4	main
tahavad	doc_873901597507_item	2910730	et	3	main
riikaks	doc_873901597507_item	2910731	et	4	main
on	doc_873901597507_item	2910738	et	4	main
kõige	doc_873901597507_item	2910754	et	4	main
kallis	doc_873901597507_item	2910755	et	4	main
tunne	doc_873901597507_item	2910756	et	4	main
kui	doc_873901597507_item	2910757	et	3	main
õnnelikkudeks	doc_873901597507_item	2910769	et	3	main
seda	doc_873901597507_item	2910811	et	3	main
saanud	doc_873901597507_item	2910813	et	4	main
oli	doc_873901597507_item	2910816	et	3	main
naine	doc_873901597507_item	2910822	et	3	main
ta	doc_873901597507_item	2910825	et	4	main
armastas	doc_873901597507_item	2910826	et	3	main
aga	doc_873901597507_item	2910827	et	3	main
rikkus	doc_873901597507_item	2910828	et	4	main
oli	doc_873901597507_item	2910829	et	3	main
ta	doc_873901597507_item	2910835	et	4	main
eelistas	doc_873901597507_item	2910836	et	3	main
saanud	doc_873901597507_item	2910843	et	4	main
õnnelikuks	doc_873901597507_item	2910844	et	3	main
tänapäeval	doc_873901597507_item	2910845	et	3	main
hinge	doc_873901597507_item	2910866	et	4	main
inimesed	doc_873901597507_item	2910871	et	3	main
lihtsalt	doc_873901597507_item	2910874	et	4	main
on	doc_873901597507_item	2910877	et	4	main
õnnelikud	doc_873901597507_item	2910879	et	3	main
sest	doc_873901597507_item	2910880	et	4	main
nende	doc_873901597507_item	2910891	et	4	main
iga	doc_873901597507_item	2910899	et	4	main
inimene	doc_873901597507_item	2910900	et	3	main
hakkab	doc_873901597507_item	2910901	et	3	main
mõtlikuks	doc_873901597507_item	2910902	et	3	main
elus	doc_873901597507_item	2910905	et	4	main
ma	doc_873901597507_item	2910906	et	3	main
arvan	doc_873901597507_item	2910907	et	3	main
et	doc_873901597507_item	2910908	et	3	main
rohkem	doc_873901597507_item	2910911	et	4	main
sellest	doc_873901597507_item	2910914	et	4	main
ja	doc_873901597507_item	2910921	et	3	main
ainult	doc_873901597507_item	2910923	et	4	main
elama	doc_873901597507_item	2910925	et	3	main
loota	doc_873901597507_item	2910936	et	4	main
et	doc_873901597507_item	2910937	et	3	main
meie	doc_873901597507_item	2910938	et	4	main
nagu	doc_873901597507_item	2910943	et	3	main
tegelane	doc_873901597508_item	2910953	et	3	main
ta	doc_873901597508_item	2910962	et	4	main
maanaine	doc_873901597508_item	2910964	et	4	main
ei	doc_873901597508_item	2910970	et	4	main
sõltuvad	doc_873901597508_item	2910975	et	4	main
kuid	doc_873901597508_item	2910977	et	4	main
sellega	doc_873901597508_item	2910985	et	3	main
naistega	doc_873901597508_item	2910989	et	3	main
ma	doc_873901597508_item	2910991	et	3	main
eduard	doc_873901597508_item	2910994	et	4	main
aimas	doc_873901597508_item	2910996	et	4	main
tänapäevast	doc_873901597508_item	2910997	et	4	main
mari	doc_873901597508_item	2911000	et	4	main
julge	doc_873901597508_item	2911002	et	4	main
uhke	doc_873901597508_item	2911005	et	4	main
noor	doc_873901597508_item	2911006	et	3	main
naine	doc_873901597508_item	2911007	et	3	main
kuula	doc_873901597508_item	2911010	et	4	main
sellisel	doc_873901597508_item	2911025	et	4	main
võib	doc_873901597508_item	2911030	et	3	main
mari	doc_873901597508_item	2911033	et	4	main
ei	doc_873901597508_item	2911048	et	4	main
marile	doc_873901597508_item	2911053	et	3	main
see	doc_873901597508_item	2911057	et	3	main
alluvad	doc_873901597508_item	2911068	et	4	main
aga	doc_873901597508_item	2911079	et	3	main
ole	doc_873901597508_item	2911082	et	4	main
niimoodi	doc_873901597508_item	2911090	et	3	main
samad	doc_873901597507_item	2910722	et	3	main
mõted	doc_873901597507_item	2910725	et	4	main
palju	doc_873901597507_item	2910726	et	4	main
inimesi	doc_873901597507_item	2910727	et	4	main
ja	doc_873901597507_item	2910733	et	3	main
me	doc_873901597507_item	2910762	et	4	main
inimesed	doc_873901597507_item	2910771	et	3	main
ole	doc_873901597507_item	2910777	et	4	main
ei	doc_873901597507_item	2910776	et	4	main
õnnelikud	doc_873901597507_item	2910778	et	3	main
sest	doc_873901597507_item	2910779	et	4	main
täna	doc_873901597507_item	2910780	et	4	main
nendel	doc_873901597507_item	2910781	et	4	main
on	doc_873901597507_item	2910782	et	4	main
raha	doc_873901597507_item	2910783	et	4	main
aga	doc_873901597507_item	2910784	et	3	main
homme	doc_873901597507_item	2910785	et	3	main
võib	doc_873901597507_item	2910786	et	3	main
ei	doc_873901597507_item	2910787	et	4	main
ole	doc_873901597507_item	2910788	et	4	main
aga	doc_873901597507_item	2910789	et	3	main
kui	doc_873901597507_item	2910790	et	3	main
inimesed	doc_873901597507_item	2910791	et	3	main
armastavad	doc_873901597507_item	2910792	et	4	main
teineteist	doc_873901597507_item	2910793	et	4	main
nad	doc_873901597507_item	2910794	et	3	main
õnnelikud	doc_873901597507_item	2910796	et	3	main
on	doc_873901597507_item	2910795	et	4	main
kõik	doc_873901597507_item	2910797	et	4	main
elu	doc_873901597507_item	2910798	et	4	main
ja	doc_873901597507_item	2910799	et	3	main
seda	doc_873901597507_item	2910800	et	3	main
tahtis	doc_873901597507_item	2910801	et	3	main
rääkida	doc_873901597507_item	2910802	et	3	main
eduard	doc_873901597507_item	2910803	et	4	main
vilde	doc_873901597507_item	2910804	et	4	main
ka	doc_873901597507_item	2910805	et	3	main
tema	doc_873901597507_item	2910806	et	4	main
väärtus	doc_873901597507_item	2910741	et	3	main
elus	doc_873901597507_item	2910742	et	4	main
aga	doc_873901597507_item	2910743	et	3	main
filmis	doc_873901597507_item	2910744	et	4	main
see	doc_873901597507_item	2910748	et	3	main
vale	doc_873901597507_item	2910750	et	4	main
mõte	doc_873901597507_item	2910751	et	3	main
armastus	doc_873901597507_item	2910752	et	4	main
on	doc_873901597507_item	2910753	et	4	main
inimeste	doc_873901597507_item	2910758	et	3	main
saame	doc_873901597507_item	2910763	et	4	main
nimetada	doc_873901597507_item	2910764	et	3	main
on	doc_873901597507_item	2910773	et	4	main
kahjuks	doc_873901597507_item	2910810	et	4	main
vaine	doc_873901597507_item	2910817	et	3	main
mari	doc_873901597507_item	2910823	et	4	main
tähtis	doc_873901597507_item	2910833	et	4	main
ja	doc_873901597507_item	2910834	et	3	main
ei	doc_873901597507_item	2910842	et	4	main
on	doc_873901597507_item	2910849	et	4	main
kui	doc_873901597507_item	2910864	et	3	main
palju	doc_873901597507_item	2910883	et	4	main
lapsi	doc_873901597507_item	2910884	et	4	main
nad	doc_873901597507_item	2910885	et	3	main
armastavad	doc_873901597507_item	2910886	et	4	main
pärast	doc_873901597507_item	2910895	et	4	main
peavad	doc_873901597507_item	2910910	et	4	main
filmi	doc_873901597507_item	2910913	et	4	main
mõttest	doc_873901597507_item	2910915	et	4	main
sest	doc_873901597507_item	2910916	et	4	main
kui	doc_873901597507_item	2910917	et	3	main
inimene	doc_873901597507_item	2910918	et	3	main
ainult	doc_873901597507_item	2910930	et	4	main
kujuneb	doc_873901597507_item	2910931	et	3	main
võib	doc_873901597507_item	2910932	et	3	main
muuta	doc_873901597507_item	2910933	et	4	main
ma	doc_873901597507_item	2910934	et	3	main
tahan	doc_873901597507_item	2910935	et	3	main
vähem	doc_873901597507_item	2910941	et	4	main
tänapäevane	doc_873901597508_item	2910948	et	4	main
naine	doc_873901597508_item	2910949	et	3	main
on	doc_873901597508_item	2910963	et	4	main
ja	doc_873901597508_item	2910965	et	3	main
nad	doc_873901597508_item	2910969	et	3	main
naist	doc_873901597508_item	2910998	et	3	main
teeb	doc_873901597508_item	2911013	et	3	main
ise	doc_873901597508_item	2911016	et	4	main
naised	doc_873901597508_item	2911020	et	3	main
sellel	doc_873901597508_item	2911021	et	4	main
ei	doc_873901597508_item	2911023	et	4	main
pea	doc_873901597508_item	2911024	et	4	main
mees	doc_873901597508_item	2911029	et	4	main
karistada	doc_873901597508_item	2911032	et	3	main
ei	doc_873901597508_item	2911034	et	4	main
karda	doc_873901597508_item	2911035	et	4	main
prillupi	doc_873901597508_item	2911039	et	4	main
sõltu	doc_873901597508_item	2911049	et	4	main
oma	doc_873901597508_item	2911050	et	4	main
teevad	doc_873901597508_item	2911055	et	3	main
töö	doc_873901597508_item	2911058	et	4	main
mida	doc_873901597508_item	2911059	et	4	main
käskivad	doc_873901597508_item	2911062	et	4	main
kardavad	doc_873901597508_item	2911064	et	4	main
tol	doc_873901597508_item	2911070	et	3	main
ajal	doc_873901597508_item	2911071	et	4	main
mitte	doc_873901597508_item	2911072	et	3	main
harva	doc_873901597508_item	2911073	et	4	main
juhtus	doc_873901597508_item	2911074	et	3	main
et	doc_873901597508_item	2911075	et	3	main
mehed	doc_873901597508_item	2911076	et	3	main
löösid	doc_873901597508_item	2911077	et	4	main
naisi	doc_873901597508_item	2911078	et	3	main
lööda	doc_873901597508_item	2911087	et	3	main
naine	doc_873901597508_item	2911092	et	3	main
toitu	doc_873901597508_item	2911125	et	4	main
maja	doc_873901597508_item	2911128	et	4	main
ta	doc_873901597508_item	2911131	et	4	main
ja	doc_873901597508_item	2911148	et	3	main
nii	doc_873901597508_item	2911154	et	3	main
teeb	doc_873901597508_item	2911156	et	3	main
piimamees	doc_873901597509_item	2911161	et	4	main
romaan	doc_873901597509_item	2911174	et	3	main
pea	doc_873901597507_item	2910807	et	4	main
tegelane	doc_873901597507_item	2910808	et	3	main
ei	doc_873901597507_item	2910812	et	4	main
aru	doc_873901597507_item	2910814	et	4	main
aga	doc_873901597507_item	2910818	et	3	main
kõrval	doc_873901597507_item	2910820	et	4	main
oli	doc_873901597507_item	2910821	et	3	main
tema	doc_873901597507_item	2910830	et	4	main
kui	doc_873901597507_item	2910838	et	3	main
mari	doc_873901597507_item	2910839	et	4	main
aga	doc_873901597507_item	2910840	et	3	main
ta	doc_873901597507_item	2910841	et	4	main
kes	doc_873901597507_item	2910848	et	4	main
uhke	doc_873901597507_item	2910862	et	4	main
inimeste	doc_873901597507_item	2910865	et	3	main
väärikust	doc_873901597507_item	2910868	et	4	main
aga	doc_873901597507_item	2910869	et	3	main
vaised	doc_873901597507_item	2910870	et	4	main
kes	doc_873901597507_item	2910872	et	4	main
on	doc_873901597507_item	2910873	et	4	main
töötajad	doc_873901597507_item	2910875	et	4	main
tähtis	doc_873901597507_item	2910890	et	4	main
on	doc_873901597507_item	2910893	et	4	main
vaatamist	doc_873901597507_item	2910898	et	4	main
väärtustest	doc_873901597507_item	2910904	et	4	main
noored	doc_873901597507_item	2910909	et	3	main
vaatama	doc_873901597507_item	2910912	et	3	main
on	doc_873901597507_item	2910940	et	4	main
mari	doc_873901597508_item	2910946	et	4	main
ja	doc_873901597508_item	2910947	et	3	main
on	doc_873901597508_item	2910951	et	4	main
ja	doc_873901597508_item	2910974	et	3	main
mõisnikust	doc_873901597508_item	2910976	et	3	main
lugupidada	doc_873901597508_item	2910983	et	4	main
on	doc_873901597508_item	2910987	et	4	main
sarnane	doc_873901597508_item	2910990	et	4	main
et	doc_873901597508_item	2910993	et	3	main
on	doc_873901597508_item	2911001	et	4	main
isekas	doc_873901597508_item	2911003	et	4	main
ja	doc_873901597508_item	2911004	et	3	main
keegi	doc_873901597508_item	2911011	et	4	main
ja	doc_873901597508_item	2911012	et	3	main
mida	doc_873901597508_item	2911015	et	4	main
teha	doc_873901597508_item	2911018	et	3	main
sest	doc_873901597508_item	2911028	et	4	main
teda	doc_873901597508_item	2911031	et	4	main
oma	doc_873901597508_item	2911036	et	4	main
ja	doc_873901597508_item	2911040	et	3	main
naised	doc_873901597508_item	2911054	et	3	main
kõik	doc_873901597508_item	2911056	et	4	main
nad	doc_873901597508_item	2911063	et	3	main
oma	doc_873901597508_item	2911065	et	4	main
meeste	doc_873901597508_item	2911066	et	4	main
ja	doc_873901597508_item	2911067	et	3	main
see	doc_873901597508_item	2911083	et	3	main
varem	doc_873901597508_item	2911088	et	4	main
ta	doc_873901597508_item	2911122	et	4	main
elus	doc_873901597507_item	2910831	et	4	main
kõige	doc_873901597507_item	2910832	et	4	main
aga	doc_873901597507_item	2910851	et	3	main
nad	doc_873901597507_item	2910852	et	3	main
on	doc_873901597507_item	2910853	et	4	main
õnnetud	doc_873901597507_item	2910854	et	4	main
sest	doc_873901597507_item	2910855	et	4	main
nende	doc_873901597507_item	2910856	et	4	main
naised	doc_873901597507_item	2910857	et	3	main
armastavad	doc_873901597507_item	2910858	et	4	main
nende	doc_873901597507_item	2910859	et	4	main
raha	doc_873901597507_item	2910860	et	4	main
ja	doc_873901597507_item	2910861	et	3	main
elu	doc_873901597507_item	2910863	et	4	main
nendel	doc_873901597507_item	2910881	et	4	main
teineteist	doc_873901597507_item	2910887	et	4	main
ja	doc_873901597507_item	2910888	et	3	main
kõige	doc_873901597507_item	2910889	et	4	main
pere	doc_873901597507_item	2910894	et	4	main
filmi	doc_873901597507_item	2910897	et	4	main
hakkab	doc_873901597507_item	2910924	et	3	main
ja	doc_873901597507_item	2910926	et	3	main
inimesi	doc_873901597507_item	2910942	et	4	main
mari	doc_873901597508_item	2910950	et	4	main
tõnu	doc_873901597508_item	2910966	et	4	main
prillupi	doc_873901597508_item	2910967	et	4	main
naine	doc_873901597508_item	2910968	et	3	main
vaba	doc_873901597508_item	2910972	et	4	main
selles	doc_873901597508_item	2910978	et	4	main
mari	doc_873901597508_item	2910980	et	4	main
oskab	doc_873901597508_item	2910981	et	3	main
ta	doc_873901597508_item	2910986	et	4	main
tänapäevastega	doc_873901597508_item	2910988	et	4	main
arvan	doc_873901597508_item	2910992	et	3	main
ta	doc_873901597508_item	2911008	et	4	main
moel	doc_873901597508_item	2911026	et	4	main
mehe	doc_873901597508_item	2911037	et	3	main
ta	doc_873901597508_item	2911041	et	4	main
teda	doc_873901597508_item	2911043	et	4	main
sõlmatu	doc_873901597508_item	2911044	et	3	main
mehest	doc_873901597508_item	2911051	et	4	main
kaaslased	doc_873901597508_item	2911052	et	3	main
mehed	doc_873901597508_item	2911061	et	3	main
mari	doc_873901597508_item	2911080	et	4	main
keda	doc_873901597508_item	2911084	et	4	main
mees	doc_873901597508_item	2911085	et	4	main
võib	doc_873901597508_item	2911086	et	3	main
oska	doc_873901597508_item	2911124	et	4	main
ja	doc_873901597508_item	2911127	et	3	main
ta	doc_873901597508_item	2911143	et	4	main
от	doc_873901597508_item	2911150	et	2	main
ja	doc_873901597508_item	2911153	et	3	main
ta	doc_873901597508_item	2911155	et	4	main
mäeküla	doc_873901597509_item	2911160	et	4	main
on	doc_873901597509_item	2911162	et	4	main
psühholoogiline	doc_873901597509_item	2911163	et	4	main
romaan	doc_873901597509_item	2911164	et	3	main
ma	doc_873901597509_item	2911165	et	3	main
mõtlen	doc_873901597509_item	2911166	et	3	main
et	doc_873901597509_item	2911167	et	3	main
ja	doc_873901597509_item	2911172	et	3	main
eesti	doc_873901597509_item	2911182	et	4	main
psühhologiline	doc_873901597509_item	2911199	et	4	main
areng	doc_873901597509_item	2911200	et	3	main
eduard	doc_873901597509_item	2911211	et	4	main
luba	doc_873901597509_item	2911228	et	4	main
end	doc_873901597509_item	2911230	et	4	main
kasutada	doc_873901597509_item	2911231	et	3	main
ja	doc_873901597509_item	2911232	et	3	main
tahab	doc_873901597509_item	2911233	et	3	main
olla	doc_873901597509_item	2911234	et	3	main
iseseisev	doc_873901597509_item	2911235	et	3	main
mari	doc_873901597509_item	2911236	et	4	main
tahan	doc_873901597509_item	2911242	et	3	main
olla	doc_873901597509_item	2911244	et	3	main
samuti	doc_873901597509_item	2911251	et	3	main
tõeline	doc_873901597509_item	2911259	et	4	main
olemus	doc_873901597509_item	2911260	et	3	main
mäeküla	doc_873901597509_item	2911264	et	4	main
on	doc_873901597509_item	2911266	et	4	main
kujutatud	doc_873901597509_item	2911267	et	4	main
praktilisest	doc_873901597509_item	2911321	et	3	main
maha	doc_873901597509_item	2911324	et	4	main
oma	doc_873901597509_item	2911325	et	4	main
inimväärikuse	doc_873901597509_item	2911328	et	4	main
eduard	doc_873901597509_item	2911331	et	4	main
on	doc_873901597509_item	2911334	et	4	main
käitumist	doc_873901597509_item	2911338	et	4	main
piimamees	doc_873901597509_item	2911345	et	4	main
piimamees	doc_873901597510_item	2911353	et	4	main
me	doc_873901597510_item	2911358	et	4	main
väga	doc_873901597510_item	2911368	et	3	main
perest	doc_873901597510_item	2911378	et	4	main
südametunnistus	doc_873901597510_item	2911409	et	3	main
oska	doc_873901597510_item	2911429	et	4	main
ta	doc_873901597507_item	2910922	et	4	main
tema	doc_873901597507_item	2910927	et	4	main
maailmavaade	doc_873901597507_item	2910928	et	3	main
mis	doc_873901597507_item	2910929	et	4	main
elus	doc_873901597507_item	2910939	et	4	main
tõnu	doc_873901597507_item	2910944	et	4	main
essee	doc_873901597508_item	2910945	et	4	main
pea	doc_873901597508_item	2910952	et	4	main
eduardi	doc_873901597508_item	2910954	et	4	main
vilde	doc_873901597508_item	2910955	et	4	main
romaanis	doc_873901597508_item	2910956	et	3	main
mille	doc_873901597508_item	2910957	et	3	main
nimi	doc_873901597508_item	2910958	et	3	main
on	doc_873901597508_item	2910959	et	4	main
mäeküla	doc_873901597508_item	2910960	et	4	main
piimamees	doc_873901597508_item	2910961	et	4	main
ole	doc_873901597508_item	2910971	et	4	main
inimesed	doc_873901597508_item	2910973	et	3	main
elus	doc_873901597508_item	2910979	et	4	main
enda	doc_873901597508_item	2910982	et	4	main
ja	doc_873901597508_item	2910984	et	3	main
vilde	doc_873901597508_item	2910995	et	4	main
isikut	doc_873901597508_item	2910999	et	3	main
ei	doc_873901597508_item	2911009	et	4	main
nii	doc_873901597508_item	2911014	et	3	main
tahab	doc_873901597508_item	2911017	et	3	main
aga	doc_873901597508_item	2911019	et	3	main
ajal	doc_873901597508_item	2911022	et	4	main
käituma	doc_873901597508_item	2911027	et	3	main
tõnu	doc_873901597508_item	2911038	et	4	main
on	doc_873901597508_item	2911042	et	4	main
nagu	doc_873901597508_item	2911045	et	3	main
tänapäevased	doc_873901597508_item	2911046	et	4	main
naised	doc_873901597508_item	2911047	et	3	main
nende	doc_873901597508_item	2911060	et	4	main
nendele	doc_873901597508_item	2911069	et	4	main
ei	doc_873901597508_item	2911081	et	4	main
oli	doc_873901597508_item	2911089	et	3	main
et	doc_873901597508_item	2911091	et	3	main
oli	doc_873901597508_item	2911093	et	3	main
kodukolle	doc_873901597508_item	2911094	et	4	main
hoidja	doc_873901597508_item	2911095	et	4	main
aga	doc_873901597508_item	2911096	et	3	main
mees	doc_873901597508_item	2911097	et	4	main
on	doc_873901597508_item	2911098	et	4	main
perekonna	doc_873901597508_item	2911099	et	4	main
kaitsja	doc_873901597508_item	2911100	et	4	main
tänapäevasel	doc_873901597508_item	2911101	et	4	main
on	doc_873901597508_item	2911102	et	4	main
kõik	doc_873901597508_item	2911103	et	4	main
vastupidi	doc_873901597508_item	2911104	et	3	main
mari	doc_873901597508_item	2911105	et	4	main
ei	doc_873901597508_item	2911106	et	4	main
olnud	doc_873901597508_item	2911107	et	4	main
kodukolle	doc_873901597508_item	2911108	et	4	main
hoidja	doc_873901597508_item	2911109	et	4	main
vaatamata	doc_873901597508_item	2911110	et	4	main
et	doc_873901597508_item	2911111	et	3	main
lapsed	doc_873901597508_item	2911112	et	3	main
armastasid	doc_873901597508_item	2911113	et	4	main
teda	doc_873901597508_item	2911114	et	4	main
teda	doc_873901597508_item	2911115	et	4	main
ja	doc_873901597508_item	2911116	et	3	main
marile	doc_873901597508_item	2911117	et	3	main
meeldis	doc_873901597508_item	2911118	et	3	main
nendega	doc_873901597508_item	2911119	et	4	main
mängida	doc_873901597508_item	2911120	et	3	main
ei	doc_873901597508_item	2911123	et	4	main
valmistada	doc_873901597508_item	2911126	et	3	main
eest	doc_873901597508_item	2911129	et	4	main
mõisavana	doc_873901597508_item	2911136	et	4	main
hirmustab	doc_873901597508_item	2911137	et	4	main
maris	doc_873901597508_item	2911138	et	3	main
seisneb	doc_873901597508_item	2911139	et	3	main
tahab	doc_873901597508_item	2911144	et	3	main
sõltuda	doc_873901597508_item	2911152	et	3	main
mäeküla	doc_873901597509_item	2911168	et	4	main
talupoja	doc_873901597509_item	2911183	et	4	main
tema	doc_873901597509_item	2911185	et	4	main
naisest	doc_873901597509_item	2911186	et	3	main
ja	doc_873901597509_item	2911189	et	3	main
hoolitseda	doc_873901597508_item	2911130	et	3	main
ei	doc_873901597508_item	2911132	et	4	main
tänapäevase	doc_873901597508_item	2911140	et	4	main
naise	doc_873901597508_item	2911141	et	3	main
prototüüp	doc_873901597508_item	2911142	et	3	main
elada	doc_873901597508_item	2911145	et	3	main
töötada	doc_873901597508_item	2911147	et	3	main
vastuoksa	doc_873901597508_item	2911121	et	3	main
teinud	doc_873901597508_item	2911133	et	4	main
see	doc_873901597508_item	2911134	et	3	main
mis	doc_873901597508_item	2911135	et	4	main
linnas	doc_873901597508_item	2911146	et	4	main
ни	doc_873901597508_item	2911149	et	2	main
essee	doc_873901597509_item	2911159	et	4	main
on	doc_873901597509_item	2911170	et	4	main
meisterlik	doc_873901597509_item	2911171	et	3	main
vilde	doc_873901597509_item	2911176	et	4	main
kirjutas	doc_873901597509_item	2911179	et	3	main
teoses	doc_873901597509_item	2911181	et	3	main
ja	doc_873901597509_item	2911187	et	3	main
nende	doc_873901597509_item	2911190	et	4	main
mäeküla	doc_873901597509_item	2911192	et	4	main
suurepäraselt	doc_873901597509_item	2911195	et	4	main
teose	doc_873901597509_item	2911197	et	3	main
mis	doc_873901597509_item	2911204	et	4	main
hinges	doc_873901597509_item	2911207	et	4	main
kogu	doc_873901597509_item	2911208	et	4	main
ka	doc_873901597509_item	2911214	et	3	main
peategelase	doc_873901597509_item	2911216	et	3	main
kõige	doc_873901597509_item	2911238	et	4	main
varblane	doc_873901597509_item	2911245	et	3	main
selline	doc_873901597509_item	2911248	et	4	main
on	doc_873901597509_item	2911250	et	4	main
oma	doc_873901597509_item	2911258	et	4	main
võimu	doc_873901597509_item	2911268	et	4	main
ka	doc_873901597509_item	2911275	et	3	main
vaised	doc_873901597509_item	2911281	et	4	main
sellel	doc_873901597509_item	2911284	et	4	main
kujutatud	doc_873901597509_item	2911335	et	4	main
ja	doc_873901597509_item	2911339	et	3	main
essee	doc_873901597510_item	2911351	et	4	main
mäeküla	doc_873901597510_item	2911352	et	4	main
romaan	doc_873901597510_item	2911356	et	3	main
on	doc_873901597510_item	2911366	et	4	main
eesti	doc_873901597510_item	2911376	et	4	main
elab	doc_873901597510_item	2911380	et	3	main
armastus	doc_873901597510_item	2911412	et	4	main
on	doc_873901597510_item	2911422	et	4	main
ja	doc_873901597510_item	2911424	et	3	main
inimene	doc_873901597510_item	2911426	et	3	main
kes	doc_873901597510_item	2911427	et	4	main
ta	doc_873901597510_item	2911434	et	4	main
elab	doc_873901597510_item	2911435	et	3	main
loodab	doc_873901597510_item	2911439	et	3	main
unistus	doc_873901597510_item	2911442	et	4	main
oma	doc_873901597510_item	2911443	et	4	main
maast	doc_873901597510_item	2911444	et	3	main
täitub	doc_873901597510_item	2911445	et	3	main
aga	doc_873901597510_item	2911446	et	3	main
samal	doc_873901597510_item	2911447	et	3	main
ajal	doc_873901597510_item	2911448	et	4	main
mari	doc_873901597510_item	2911458	et	4	main
on	doc_873901597510_item	2911459	et	4	main
energiline	doc_873901597510_item	2911462	et	3	main
inimene	doc_873901597510_item	2911463	et	3	main
tegud	doc_873901597510_item	2911481	et	4	main
kui	doc_873901597510_item	2911482	et	3	main
ja	doc_873901597510_item	2911487	et	3	main
käitumine	doc_873901597510_item	2911500	et	4	main
pinges	doc_873901597510_item	2911508	et	4	main
kui	doc_873901597510_item	2911509	et	3	main
on	doc_873901597510_item	2911515	et	4	main
uskuda	doc_873901597510_item	2911517	et	3	main
et	doc_873901597510_item	2911518	et	3	main
mees	doc_873901597510_item	2911519	et	4	main
võib	doc_873901597510_item	2911520	et	3	main
кого	doc_873901597508_item	2911151	et	2	main
romaani	doc_873901597508_item	2911157	et	4	main
lõppes	doc_873901597508_item	2911158	et	4	main
piimamees	doc_873901597509_item	2911169	et	4	main
psühholoogiline	doc_873901597509_item	2911173	et	4	main
eduard	doc_873901597509_item	2911175	et	4	main
väga	doc_873901597509_item	2911177	et	3	main
oma	doc_873901597509_item	2911180	et	4	main
elust	doc_873901597509_item	2911184	et	3	main
mõisnikust	doc_873901597509_item	2911188	et	3	main
on	doc_873901597509_item	2911194	et	4	main
muutusi	doc_873901597509_item	2911203	et	4	main
prillupi	doc_873901597509_item	2911206	et	4	main
romaani	doc_873901597509_item	2911209	et	4	main
kestel	doc_873901597509_item	2911210	et	4	main
teise	doc_873901597509_item	2911215	et	4	main
on	doc_873901597509_item	2911221	et	4	main
hästi	doc_873901597509_item	2911178	et	3	main
piimamehes	doc_873901597509_item	2911193	et	3	main
kujutatud	doc_873901597509_item	2911196	et	4	main
kangelaste	doc_873901597509_item	2911198	et	4	main
kirjeldab	doc_873901597509_item	2911213	et	3	main
mari	doc_873901597509_item	2911220	et	4	main
julge	doc_873901597509_item	2911224	et	4	main
meestel	doc_873901597509_item	2911229	et	4	main
paremini	doc_873901597509_item	2911239	et	4	main
mitte	doc_873901597509_item	2911246	et	3	main
väljend	doc_873901597509_item	2911249	et	3	main
psühholoogiline	doc_873901597509_item	2911252	et	4	main
selle	doc_873901597509_item	2911253	et	4	main
lausega	doc_873901597509_item	2911254	et	3	main
avaldub	doc_873901597509_item	2911255	et	3	main
ka	doc_873901597509_item	2911256	et	3	main
eduard	doc_873901597509_item	2911261	et	4	main
poole	doc_873901597509_item	2911269	et	4	main
aru	doc_873901597509_item	2911278	et	4	main
kuidas	doc_873901597509_item	2911279	et	3	main
elasid	doc_873901597509_item	2911280	et	4	main
suhetest	doc_873901597509_item	2911191	et	3	main
me	doc_873901597509_item	2911201	et	4	main
näeme	doc_873901597509_item	2911202	et	3	main
toimuvad	doc_873901597509_item	2911205	et	4	main
vilde	doc_873901597509_item	2911212	et	4	main
mari	doc_873901597509_item	2911217	et	4	main
psüühilisi	doc_873901597509_item	2911218	et	3	main
läbielamisi	doc_873901597509_item	2911219	et	3	main
enesekindel	doc_873901597509_item	2911222	et	3	main
ja	doc_873901597509_item	2911223	et	3	main
noornaine	doc_873901597509_item	2911225	et	3	main
lause	doc_873901597509_item	2911240	et	4	main
ma	doc_873901597509_item	2911241	et	3	main
linnas	doc_873901597509_item	2911243	et	4	main
mari	doc_873901597509_item	2911257	et	4	main
romaanis	doc_873901597509_item	2911263	et	3	main
piimamees	doc_873901597509_item	2911265	et	4	main
mõistnik	doc_873901597509_item	2911271	et	4	main
ja	doc_873901597509_item	2911272	et	3	main
naabertalude	doc_873901597509_item	2911273	et	3	main
elanikud	doc_873901597509_item	2911274	et	3	main
me	doc_873901597509_item	2911276	et	4	main
linnas	doc_873901597509_item	2911283	et	4	main
naese	doc_873901597509_item	2911326	et	4	main
südametunnistuse	doc_873901597509_item	2911330	et	3	main
vilde	doc_873901597509_item	2911332	et	4	main
karakteri	doc_873901597509_item	2911337	et	3	main
arengut	doc_873901597509_item	2911340	et	3	main
mäeküla	doc_873901597509_item	2911344	et	4	main
näinud	doc_873901597510_item	2911360	et	4	main
mäeküla	doc_873901597510_item	2911362	et	4	main
piimamees	doc_873901597510_item	2911363	et	4	main
ja	doc_873901597510_item	2911364	et	3	main
see	doc_873901597510_item	2911365	et	3	main
see	doc_873901597510_item	2911373	et	3	main
räägib	doc_873901597510_item	2911374	et	3	main
ühest	doc_873901597510_item	2911375	et	4	main
tõnu	doc_873901597510_item	2911420	et	4	main
kes	doc_873901597509_item	2911226	et	4	main
ei	doc_873901597509_item	2911227	et	4	main
iseloomustab	doc_873901597509_item	2911237	et	4	main
kanaarilind	doc_873901597509_item	2911247	et	3	main
vilde	doc_873901597509_item	2911262	et	4	main
püüdlev	doc_873901597509_item	2911270	et	4	main
saame	doc_873901597509_item	2911277	et	4	main
inimesed	doc_873901597509_item	2911282	et	3	main
ajal	doc_873901597509_item	2911285	et	4	main
autor	doc_873901597509_item	2911286	et	3	main
on	doc_873901597509_item	2911287	et	4	main
kasutatud	doc_873901597509_item	2911288	et	4	main
rikast	doc_873901597509_item	2911289	et	4	main
sõnavara	doc_873901597509_item	2911290	et	4	main
nii	doc_873901597509_item	2911291	et	3	main
olukordade	doc_873901597509_item	2911292	et	3	main
tunnete	doc_873901597509_item	2911293	et	4	main
ja	doc_873901597509_item	2911294	et	3	main
välimuse	doc_873901597509_item	2911295	et	3	main
kirjeldamisel	doc_873901597509_item	2911296	et	4	main
dialoogid	doc_873901597509_item	2911297	et	3	main
ja	doc_873901597509_item	2911298	et	3	main
monoloogid	doc_873901597509_item	2911299	et	4	main
huvitavad	doc_873901597509_item	2911301	et	4	main
on	doc_873901597509_item	2911300	et	4	main
ja	doc_873901597509_item	2911302	et	3	main
kaasahaaravad	doc_873901597509_item	2911303	et	3	main
raamatu	doc_873901597509_item	2911304	et	4	main
põhiidee	doc_873901597509_item	2911305	et	4	main
seisneb	doc_873901597509_item	2911306	et	3	main
prillupi	doc_873901597509_item	2911307	et	4	main
läbielamiste	doc_873901597509_item	2911308	et	3	main
kujutamises	doc_873901597509_item	2911309	et	4	main
tal	doc_873901597509_item	2911310	et	3	main
oli	doc_873901597509_item	2911311	et	3	main
suur	doc_873901597509_item	2911312	et	3	main
unistus	doc_873901597509_item	2911313	et	4	main
et	doc_873901597509_item	2911314	et	3	main
oma	doc_873901597509_item	2911315	et	4	main
karvasuse	doc_873901597509_item	2911316	et	4	main
tõttu	doc_873901597509_item	2911317	et	4	main
rikkaks	doc_873901597509_item	2911318	et	4	main
saada	doc_873901597509_item	2911319	et	4	main
aga	doc_873901597509_item	2911320	et	3	main
müüs	doc_873901597509_item	2911322	et	4	main
kaotas	doc_873901597509_item	2911327	et	3	main
ta	doc_873901597509_item	2911323	et	4	main
romaanis	doc_873901597509_item	2911333	et	3	main
kolme	doc_873901597509_item	2911336	et	4	main
see	doc_873901597509_item	2911341	et	3	main
et	doc_873901597509_item	2911343	et	3	main
on	doc_873901597509_item	2911346	et	4	main
tõesti	doc_873901597509_item	2911347	et	3	main
meisterlik	doc_873901597509_item	2911348	et	3	main
psühholoogiline	doc_873901597509_item	2911349	et	4	main
romaan	doc_873901597509_item	2911350	et	3	main
psüholoogiline	doc_873901597510_item	2911355	et	4	main
viimati	doc_873901597510_item	2911357	et	3	main
filmi	doc_873901597510_item	2911361	et	4	main
jäänud	doc_873901597510_item	2911367	et	4	main
vaesest	doc_873901597510_item	2911377	et	4	main
tavalist	doc_873901597510_item	2911381	et	4	main
elu	doc_873901597510_item	2911382	et	4	main
olulisem	doc_873901597510_item	2911384	et	4	main
kõige	doc_873901597510_item	2911383	et	4	main
selles	doc_873901597510_item	2911385	et	4	main
romaanis	doc_873901597510_item	2911386	et	3	main
on	doc_873901597510_item	2911387	et	4	main
inimeste	doc_873901597510_item	2911388	et	3	main
tegud	doc_873901597510_item	2911389	et	4	main
ja	doc_873901597510_item	2911390	et	3	main
tunded	doc_873901597510_item	2911391	et	3	main
autor	doc_873901597510_item	2911392	et	3	main
näitas	doc_873901597510_item	2911393	et	3	main
seda	doc_873901597510_item	2911394	et	3	main
nii	doc_873901597510_item	2911395	et	3	main
eredalt	doc_873901597510_item	2911396	et	4	main
et	doc_873901597510_item	2911397	et	3	main
see	doc_873901597510_item	2911398	et	3	main
tõesti	doc_873901597510_item	2911399	et	3	main
paneb	doc_873901597510_item	2911400	et	3	main
mõtlema	doc_873901597510_item	2911401	et	3	main
tõsisest	doc_873901597510_item	2911402	et	4	main
asjadest	doc_873901597510_item	2911403	et	3	main
nagu	doc_873901597510_item	2911404	et	3	main
naise	doc_873901597510_item	2911405	et	3	main
kohus	doc_873901597510_item	2911406	et	4	main
vaimne	doc_873901597510_item	2911407	et	3	main
ja	doc_873901597509_item	2911329	et	3	main
kinnitab	doc_873901597509_item	2911342	et	3	main
on	doc_873901597510_item	2911354	et	4	main
oleme	doc_873901597510_item	2911359	et	3	main
erinevaid	doc_873901597510_item	2911369	et	4	main
aga	doc_873901597510_item	2911370	et	3	main
tugevaid	doc_873901597510_item	2911371	et	4	main
muljeid	doc_873901597510_item	2911372	et	3	main
mis	doc_873901597510_item	2911379	et	4	main
jõud	doc_873901597510_item	2911408	et	4	main
isegi	doc_873901597510_item	2911411	et	4	main
romaanis	doc_873901597510_item	2911413	et	3	main
prillup	doc_873901597510_item	2911421	et	4	main
haletsemisväärne	doc_873901597510_item	2911423	et	4	main
nõrk	doc_873901597510_item	2911425	et	3	main
mees	doc_873901597510_item	2911433	et	4	main
ja	doc_873901597510_item	2911438	et	3	main
tema	doc_873901597510_item	2911441	et	4	main
ta	doc_873901597510_item	2911483	et	4	main
elu	doc_873901597510_item	2911488	et	4	main
et	doc_873901597510_item	2911489	et	3	main
nende	doc_873901597510_item	2911499	et	4	main
von	doc_873901597510_item	2911502	et	4	main
koha	doc_873901597510_item	2911512	et	4	main
see	doc_873901597510_item	2911514	et	3	main
raske	doc_873901597510_item	2911516	et	4	main
nii	doc_873901597510_item	2911530	et	3	main
kiredalt	doc_873901597510_item	2911531	et	4	main
tahta	doc_873901597510_item	2911532	et	3	main
ja	doc_873901597510_item	2911533	et	3	main
see	doc_873901597510_item	2911534	et	3	main
ole	doc_873901597510_item	2911536	et	4	main
peab	doc_873901597510_item	2911540	et	4	main
see	doc_873901597510_item	2911551	et	3	main
on	doc_873901597510_item	2911552	et	4	main
kindel	doc_873901597510_item	2911553	et	3	main
sellist	doc_873901597510_item	2911568	et	4	main
naist	doc_873901597510_item	2911569	et	3	main
nagu	doc_873901597510_item	2911570	et	3	main
mari	doc_873901597510_item	2911571	et	4	main
kelle	doc_873901597510_item	2911578	et	4	main
on	doc_873901597510_item	2911580	et	4	main
tema	doc_873901597510_item	2911581	et	4	main
seisund	doc_873901597510_item	2911582	et	3	main
on	doc_873901597510_item	2911596	et	4	main
jõud	doc_873901597510_item	2911597	et	4	main
kõik	doc_873901597510_item	2911598	et	4	main
oma	doc_873901597510_item	2911599	et	4	main
tundeid	doc_873901597510_item	2911600	et	3	main
näidatud	doc_873901597510_item	2911607	et	4	main
mis	doc_873901597510_item	2911612	et	4	main
perekonnas	doc_873901597510_item	2911616	et	4	main
ja	doc_873901597510_item	2911410	et	3	main
võreldatakse	doc_873901597510_item	2911414	et	4	main
kaks	doc_873901597510_item	2911415	et	3	main
inimest	doc_873901597510_item	2911416	et	3	main
marit	doc_873901597510_item	2911417	et	3	main
ja	doc_873901597510_item	2911418	et	3	main
tõnu	doc_873901597510_item	2911419	et	4	main
ei	doc_873901597510_item	2911428	et	4	main
halli	doc_873901597510_item	2911436	et	4	main
tema	doc_873901597510_item	2911456	et	4	main
tema	doc_873901597510_item	2911480	et	4	main
noorust	doc_873901597510_item	2911486	et	4	main
hoolitsema	doc_873901597510_item	2911490	et	4	main
hämmastab	doc_873901597510_item	2911498	et	3	main
ulrich	doc_873901597510_item	2911501	et	4	main
kremeri	doc_873901597510_item	2911503	et	4	main
olukorras	doc_873901597510_item	2911504	et	3	main
tegelased	doc_873901597510_item	2911505	et	3	main
hoiavad	doc_873901597510_item	2911506	et	3	main
meid	doc_873901597510_item	2911507	et	4	main
lahendab	doc_873901597510_item	2911510	et	3	main
probleem	doc_873901597510_item	2911513	et	3	main
passiivne	doc_873901597510_item	2911524	et	3	main
ja	doc_873901597510_item	2911526	et	3	main
samal	doc_873901597510_item	2911527	et	3	main
midagi	doc_873901597510_item	2911529	et	4	main
lahendama	doc_873901597510_item	2911543	et	3	main
ja	doc_873901597510_item	2911544	et	3	main
end	doc_873901597510_item	2911545	et	4	main
ohverdama	doc_873901597510_item	2911546	et	3	main
et	doc_873901597510_item	2911547	et	3	main
prillup	doc_873901597510_item	2911556	et	4	main
ta	doc_873901597510_item	2911562	et	4	main
sai	doc_873901597510_item	2911563	et	4	main
ei	doc_873901597510_item	2911565	et	4	main
kes	doc_873901597510_item	2911572	et	4	main
laste	doc_873901597510_item	2911575	et	4	main
ja	doc_873901597510_item	2911577	et	3	main
teha	doc_873901597510_item	2911593	et	3	main
maril	doc_873901597510_item	2911595	et	3	main
hoida	doc_873901597510_item	2911602	et	3	main
romaanis	doc_873901597510_item	2911604	et	3	main
psüholoogia	doc_873901597510_item	2911609	et	4	main
toimuda	doc_873901597510_item	2911614	et	3	main
olla	doc_873901597510_item	2911621	et	3	main
on	doc_873901597510_item	2911631	et	4	main
tohi	doc_873901597510_item	2911635	et	4	main
ja	doc_873901597510_item	2911639	et	3	main
vaja	doc_873901597510_item	2911641	et	4	main
kuulata	doc_873901597510_item	2911642	et	4	main
mis	doc_873901597510_item	2911647	et	4	main
mäeküla	doc_873901597511_item	2911651	et	4	main
piimamees	doc_873901597511_item	2911660	et	4	main
on	doc_873901597511_item	2911669	et	4	main
tegelaste	doc_873901597511_item	2911670	et	3	main
nende	doc_873901597511_item	2911672	et	4	main
psüholoogia	doc_873901597511_item	2911674	et	4	main
kuidas	doc_873901597511_item	2911678	et	3	main
muretsevad	doc_873901597511_item	2911680	et	4	main
plaanil	doc_873901597511_item	2911692	et	3	main
prillupi	doc_873901597511_item	2911696	et	4	main
me	doc_873901597511_item	2911698	et	4	main
võime	doc_873901597511_item	2911699	et	4	main
jälgida	doc_873901597511_item	2911700	et	3	main
tema	doc_873901597511_item	2911703	et	4	main
tõnu	doc_873901597511_item	2911705	et	4	main
oli	doc_873901597511_item	2911706	et	3	main
tema	doc_873901597511_item	2911717	et	4	main
oli	doc_873901597511_item	2911720	et	3	main
kitsas	doc_873901597511_item	2911722	et	4	main
ei	doc_873901597511_item	2911724	et	4	main
ta	doc_873901597511_item	2911738	et	4	main
kardis	doc_873901597511_item	2911739	et	3	main
selle	doc_873901597511_item	2911742	et	4	main
mõisnik	doc_873901597511_item	2911743	et	3	main
tegi	doc_873901597511_item	2911744	et	4	main
ulrich	doc_873901597511_item	2911751	et	4	main
kreemeri	doc_873901597511_item	2911753	et	4	main
koha	doc_873901597511_item	2911761	et	4	main
tõnu	doc_873901597511_item	2911765	et	4	main
austus	doc_873901597511_item	2911775	et	4	main
mõisa	doc_873901597511_item	2911777	et	3	main
käituda	doc_873901597510_item	2911430	et	3	main
nagu	doc_873901597510_item	2911431	et	3	main
tõeline	doc_873901597510_item	2911432	et	4	main
elu	doc_873901597510_item	2911437	et	4	main
ei	doc_873901597510_item	2911449	et	4	main
tee	doc_873901597510_item	2911450	et	4	main
mitte	doc_873901597510_item	2911451	et	3	main
midagi	doc_873901597510_item	2911452	et	4	main
et	doc_873901597510_item	2911453	et	3	main
see	doc_873901597510_item	2911454	et	3	main
juhtuks	doc_873901597510_item	2911455	et	4	main
oskab	doc_873901597510_item	2911465	et	3	main
kõike	doc_873901597510_item	2911466	et	4	main
teha	doc_873901597510_item	2911467	et	3	main
ja	doc_873901597510_item	2911468	et	3	main
suhtleb	doc_873901597510_item	2911469	et	3	main
inimestega	doc_873901597510_item	2911470	et	3	main
kergesti	doc_873901597510_item	2911471	et	3	main
samal	doc_873901597510_item	2911472	et	3	main
ajal	doc_873901597510_item	2911473	et	4	main
ta	doc_873901597510_item	2911474	et	4	main
on	doc_873901597510_item	2911475	et	4	main
väga	doc_873901597510_item	2911476	et	3	main
tugev	doc_873901597510_item	2911477	et	4	main
seda	doc_873901597510_item	2911478	et	3	main
näitavad	doc_873901597510_item	2911479	et	4	main
et	doc_873901597510_item	2911440	et	3	main
naine	doc_873901597510_item	2911457	et	3	main
noor	doc_873901597510_item	2911460	et	3	main
ja	doc_873901597510_item	2911461	et	3	main
kes	doc_873901597510_item	2911464	et	4	main
oma	doc_873901597510_item	2911485	et	4	main
oma	doc_873901597510_item	2911491	et	4	main
õe	doc_873901597510_item	2911492	et	4	main
laste	doc_873901597510_item	2911493	et	4	main
aus	doc_873901597510_item	2911537	et	4	main
kahtlusi	doc_873901597510_item	2911542	et	4	main
et	doc_873901597510_item	2911554	et	3	main
ole	doc_873901597510_item	2911558	et	4	main
väärt	doc_873901597510_item	2911559	et	4	main
seda	doc_873901597510_item	2911560	et	3	main
ole	doc_873901597510_item	2911566	et	4	main
hoolitseb	doc_873901597510_item	2911573	et	3	main
eest	doc_873901597510_item	2911576	et	4	main
käes	doc_873901597510_item	2911579	et	4	main
on	doc_873901597510_item	2911588	et	4	main
ja	doc_873901597510_item	2911594	et	3	main
selles	doc_873901597510_item	2911603	et	4	main
ja	doc_873901597510_item	2911610	et	3	main
tavalises	doc_873901597510_item	2911615	et	4	main
ei	doc_873901597510_item	2911625	et	4	main
teisi	doc_873901597510_item	2911637	et	4	main
on	doc_873901597510_item	2911640	et	4	main
toimub	doc_873901597510_item	2911648	et	3	main
mäeküla	doc_873901597511_item	2911659	et	4	main
ees	doc_873901597511_item	2911667	et	4	main
me	doc_873901597511_item	2911675	et	4	main
näha	doc_873901597511_item	2911677	et	3	main
tegelased	doc_873901597511_item	2911679	et	3	main
kardavad	doc_873901597511_item	2911681	et	4	main
kahtlevad	doc_873901597511_item	2911682	et	4	main
on	doc_873901597511_item	2911689	et	4	main
aga	doc_873901597511_item	2911690	et	3	main
näiteks	doc_873901597511_item	2911693	et	4	main
romaanis	doc_873901597511_item	2911697	et	3	main
hädas	doc_873901597511_item	2911707	et	3	main
ja	doc_873901597511_item	2911708	et	3	main
suri	doc_873901597511_item	2911711	et	3	main
naine	doc_873901597511_item	2911712	et	3	main
tal	doc_873901597511_item	2911713	et	3	main
polnud	doc_873901597511_item	2911714	et	3	main
midagi	doc_873901597511_item	2911728	et	4	main
tähtsat	doc_873901597511_item	2911729	et	3	main
ja	doc_873901597511_item	2911741	et	3	main
pakkus	doc_873901597511_item	2911746	et	3	main
naine	doc_873901597511_item	2911748	et	3	main
käib	doc_873901597511_item	2911749	et	3	main
aga	doc_873901597511_item	2911755	et	3	main
seda	doc_873901597511_item	2911763	et	3	main
hinges	doc_873901597511_item	2911766	et	4	main
raha	doc_873901597511_item	2911774	et	4	main
ta	doc_873901597511_item	2911780	et	4	main
inimene	doc_873901597511_item	2911790	et	3	main
tal	doc_873901597511_item	2911791	et	3	main
hakkab	doc_873901597511_item	2911826	et	3	main
sai	doc_873901597511_item	2911830	et	4	main
naine	doc_873901597511_item	2911833	et	3	main
kodus	doc_873901597511_item	2911834	et	4	main
hinges	doc_873901597511_item	2911842	et	4	main
on	doc_873901597511_item	2911843	et	4	main
mõisniku	doc_873901597511_item	2911850	et	3	main
ära	doc_873901597511_item	2911853	et	4	main
ei	doc_873901597511_item	2911864	et	4	main
saanud	doc_873901597511_item	2911865	et	4	main
parem	doc_873901597511_item	2911877	et	4	main
kui	doc_873901597511_item	2911878	et	3	main
tema	doc_873901597511_item	2911885	et	4	main
juurde	doc_873901597511_item	2911894	et	4	main
ei	doc_873901597511_item	2911896	et	4	main
mari	doc_873901597511_item	2911922	et	4	main
tõnu	doc_873901597511_item	2911934	et	4	main
tema	doc_873901597511_item	2911943	et	4	main
jaoks	doc_873901597511_item	2911944	et	4	main
aus	doc_873901597511_item	2911945	et	4	main
tähtis	doc_873901597511_item	2911948	et	4	main
raha	doc_873901597511_item	2911951	et	4	main
tõnu	doc_873901597511_item	2911954	et	4	main
mari	doc_873901597511_item	2911956	et	4	main
mõisniku	doc_873901597511_item	2911958	et	3	main
ohverdas	doc_873901597510_item	2911484	et	3	main
eest	doc_873901597510_item	2911494	et	4	main
aga	doc_873901597510_item	2911495	et	3	main
kõige	doc_873901597510_item	2911496	et	4	main
rohkem	doc_873901597510_item	2911497	et	4	main
piimamehe	doc_873901597510_item	2911511	et	3	main
nii	doc_873901597510_item	2911521	et	3	main
ja	doc_873901597510_item	2911523	et	3	main
olla	doc_873901597510_item	2911525	et	3	main
ajal	doc_873901597510_item	2911528	et	4	main
et	doc_873901597510_item	2911538	et	3	main
rikkaks	doc_873901597510_item	2911549	et	4	main
teha	doc_873901597510_item	2911550	et	3	main
mida	doc_873901597510_item	2911561	et	4	main
väärt	doc_873901597510_item	2911567	et	4	main
see	doc_873901597510_item	2911583	et	3	main
on	doc_873901597510_item	2911584	et	4	main
jultumus	doc_873901597510_item	2911589	et	4	main
mari	doc_873901597510_item	2911590	et	4	main
etteheiteid	doc_873901597510_item	2911592	et	3	main
inimeste	doc_873901597510_item	2911608	et	3	main
võivad	doc_873901597510_item	2911613	et	4	main
et	doc_873901597510_item	2911623	et	3	main
alati	doc_873901597510_item	2911627	et	4	main
olulisem	doc_873901597510_item	2911630	et	4	main
see	doc_873901597510_item	2911632	et	3	main
ei	doc_873901597510_item	2911634	et	4	main
kasutada	doc_873901597510_item	2911636	et	3	main
ja	doc_873901597510_item	2911646	et	3	main
on	doc_873901597511_item	2911661	et	4	main
selles	doc_873901597511_item	2911665	et	4	main
plaanil	doc_873901597511_item	2911668	et	3	main
tundmused	doc_873901597511_item	2911671	et	3	main
valikude	doc_873901597511_item	2911673	et	3	main
võime	doc_873901597511_item	2911676	et	4	main
nende	doc_873901597511_item	2911685	et	4	main
hingedes	doc_873901597511_item	2911686	et	3	main
tegevus	doc_873901597511_item	2911687	et	4	main
roomaanis	doc_873901597511_item	2911688	et	4	main
toon	doc_873901597511_item	2911694	et	4	main
rõõmu	doc_873901597511_item	2911715	et	4	main
tal	doc_873901597511_item	2911723	et	3	main
ainult	doc_873901597511_item	2911731	et	4	main
raha	doc_873901597511_item	2911732	et	4	main
tõnu	doc_873901597511_item	2911733	et	4	main
oli	doc_873901597511_item	2911734	et	3	main
nõrk	doc_873901597511_item	2911735	et	3	main
inimene	doc_873901597511_item	2911736	et	3	main
tõnu	doc_873901597511_item	2911747	et	4	main
von	doc_873901597511_item	2911752	et	4	main
juurde	doc_873901597511_item	2911754	et	4	main
tõnu	doc_873901597511_item	2911756	et	4	main
siis	doc_873901597511_item	2911757	et	3	main
saab	doc_873901597511_item	2911758	et	3	main
rääkimist	doc_873901597511_item	2911764	et	4	main
tõimub	doc_873901597511_item	2911767	et	4	main
võistlus	doc_873901597511_item	2911768	et	3	main
ta	doc_873901597511_item	2911769	et	4	main
kahtleb	doc_873901597511_item	2911770	et	3	main
kas	doc_873901597511_item	2911771	et	3	main
või	doc_873901597511_item	2911773	et	4	main
oma	doc_873901597511_item	2911776	et	4	main
nõrk	doc_873901597511_item	2911789	et	3	main
tõnu	doc_873901597511_item	2911825	et	4	main
ta	doc_873901597511_item	2911829	et	4	main
aru	doc_873901597511_item	2911831	et	4	main
et	doc_873901597511_item	2911832	et	3	main
armukadedus	doc_873901597511_item	2911839	et	4	main
jälle	doc_873901597511_item	2911840	et	3	main
tõnu	doc_873901597511_item	2911841	et	4	main
või	doc_873901597511_item	2911847	et	4	main
võtta	doc_873901597511_item	2911852	et	3	main
marit	doc_873901597511_item	2911854	et	3	main
ei	doc_873901597511_item	2911856	et	4	main
suri	doc_873901597511_item	2911870	et	3	main
aru	doc_873901597511_item	2911873	et	4	main
mari	doc_873901597511_item	2911875	et	4	main
on	doc_873901597511_item	2911876	et	4	main
mari	doc_873901597511_item	2911883	et	4	main
hinges	doc_873901597511_item	2911884	et	4	main
kuri	doc_873901597511_item	2911889	et	4	main
minna	doc_873901597511_item	2911892	et	3	main
kõhklev	doc_873901597510_item	2911522	et	4	main
ei	doc_873901597510_item	2911535	et	4	main
naine	doc_873901597510_item	2911539	et	3	main
tema	doc_873901597510_item	2911541	et	4	main
teda	doc_873901597510_item	2911548	et	4	main
tõnu	doc_873901597510_item	2911555	et	4	main
ei	doc_873901597510_item	2911557	et	4	main
ja	doc_873901597510_item	2911564	et	3	main
tema	doc_873901597510_item	2911574	et	4	main
üllatav	doc_873901597510_item	2911585	et	4	main
et	doc_873901597510_item	2911586	et	3	main
tõnul	doc_873901597510_item	2911587	et	4	main
kohta	doc_873901597510_item	2911591	et	4	main
endas	doc_873901597510_item	2911601	et	4	main
on	doc_873901597510_item	2911605	et	4	main
hästi	doc_873901597510_item	2911606	et	3	main
kired	doc_873901597510_item	2911611	et	4	main
kui	doc_873901597510_item	2911617	et	3	main
erinevad	doc_873901597510_item	2911618	et	4	main
võivad	doc_873901597510_item	2911619	et	4	main
inimesed	doc_873901597510_item	2911620	et	3	main
ja	doc_873901597510_item	2911622	et	3	main
õiglane	doc_873901597510_item	2911628	et	3	main
mida	doc_873901597510_item	2911643	et	4	main
süda	doc_873901597510_item	2911644	et	3	main
ütleb	doc_873901597510_item	2911645	et	3	main
hinges	doc_873901597510_item	2911649	et	4	main
psüholoogiline	doc_873901597511_item	2911663	et	4	main
romaan	doc_873901597511_item	2911664	et	3	main
romaanis	doc_873901597511_item	2911666	et	3	main
tõnu	doc_873901597511_item	2911695	et	4	main
muutused	doc_873901597511_item	2911702	et	4	main
maailm	doc_873901597511_item	2911719	et	3	main
väga	doc_873901597511_item	2911721	et	3	main
olnud	doc_873901597511_item	2911725	et	4	main
elus	doc_873901597511_item	2911726	et	4	main
mitte	doc_873901597511_item	2911727	et	3	main
ärgpüks	doc_873901597511_item	2911737	et	4	main
mäeküla	doc_873901597511_item	2911759	et	4	main
piimamehe	doc_873901597511_item	2911760	et	3	main
ja	doc_873901597511_item	2911778	et	3	main
sest	doc_873901597511_item	2911785	et	4	main
väga	doc_873901597511_item	2911788	et	3	main
oli	doc_873901597511_item	2911792	et	3	main
ja	doc_873901597511_item	2911821	et	3	main
vahel	doc_873901597511_item	2911823	et	4	main
marit	doc_873901597511_item	2911828	et	3	main
ta	doc_873901597511_item	2911861	et	4	main
teha	doc_873901597511_item	2911867	et	3	main
lõppuni	doc_873901597511_item	2911868	et	3	main
ta	doc_873901597511_item	2911869	et	4	main
raha	doc_873901597511_item	2911879	et	4	main
südas	doc_873901597511_item	2911886	et	4	main
ka	doc_873901597511_item	2911888	et	3	main
võistlus	doc_873901597511_item	2911890	et	3	main
tegi	doc_873901597511_item	2911921	et	4	main
annab	doc_873901597511_item	2911923	et	3	main
ei	doc_873901597511_item	2911930	et	4	main
taha	doc_873901597511_item	2911931	et	4	main
tudev	doc_873901597511_item	2911941	et	4	main
on	doc_873901597511_item	2911946	et	4	main
kui	doc_873901597511_item	2911950	et	3	main
kui	doc_873901597511_item	2911953	et	3	main
suri	doc_873901597511_item	2911955	et	3	main
mida	doc_873901597511_item	2911964	et	4	main
tahtis	doc_873901597511_item	2911965	et	3	main
ta	doc_873901597511_item	2911966	et	4	main
tõi	doc_873901597511_item	2911967	et	3	main
ja	doc_873901597511_item	2911971	et	3	main
romaanis	doc_873901597511_item	2911973	et	3	main
piimamees	doc_873901597511_item	2911975	et	4	main
vahel	doc_873901597511_item	2911983	et	4	main
kuidas	doc_873901597511_item	2911984	et	3	main
need	doc_873901597511_item	2911985	et	3	main
muutuvad	doc_873901597511_item	2911986	et	4	main
kuidas	doc_873901597511_item	2911988	et	3	main
essee	doc_873901597512_item	2911997	et	4	main
lapsed	doc_873901597512_item	2912029	et	3	main
saatus	doc_873901597510_item	2911624	et	3	main
ole	doc_873901597510_item	2911626	et	4	main
kõige	doc_873901597510_item	2911629	et	4	main
et	doc_873901597510_item	2911633	et	3	main
inimesi	doc_873901597510_item	2911638	et	4	main
essee	doc_873901597511_item	2911650	et	4	main
on	doc_873901597511_item	2911653	et	4	main
piimamees	doc_873901597511_item	2911652	et	4	main
psüholoogiline	doc_873901597511_item	2911654	et	4	main
romaan	doc_873901597511_item	2911655	et	3	main
mina	doc_873901597511_item	2911656	et	4	main
arvan	doc_873901597511_item	2911657	et	3	main
et	doc_873901597511_item	2911658	et	3	main
küll	doc_873901597511_item	2911662	et	4	main
mis	doc_873901597511_item	2911683	et	4	main
toimub	doc_873901597511_item	2911684	et	3	main
taga	doc_873901597511_item	2911691	et	4	main
kõik	doc_873901597511_item	2911701	et	4	main
hinges	doc_873901597511_item	2911704	et	4	main
vilitsuses	doc_873901597511_item	2911709	et	4	main
temal	doc_873901597511_item	2911710	et	3	main
elus	doc_873901597511_item	2911716	et	4	main
hingeline	doc_873901597511_item	2911718	et	4	main
vaid	doc_873901597511_item	2911730	et	3	main
mõisniku	doc_873901597511_item	2911740	et	3	main
tõnule	doc_873901597511_item	2911745	et	4	main
ööseti	doc_873901597511_item	2911750	et	3	main
pärast	doc_873901597511_item	2911762	et	4	main
mari	doc_873901597511_item	2911772	et	4	main
valib	doc_873901597511_item	2911781	et	3	main
ta	doc_873901597511_item	2911786	et	4	main
madalad	doc_873901597511_item	2911793	et	3	main
soovid	doc_873901597511_item	2911794	et	4	main
ja	doc_873901597511_item	2911795	et	3	main
sellest	doc_873901597511_item	2911797	et	4	main
mis	doc_873901597511_item	2911796	et	4	main
tuli	doc_873901597511_item	2911798	et	4	main
enne	doc_873901597511_item	2911799	et	4	main
lepengut	doc_873901597511_item	2911800	et	4	main
tõnu	doc_873901597511_item	2911801	et	4	main
koduses	doc_873901597511_item	2911802	et	4	main
oli	doc_873901597511_item	2911803	et	3	main
rahu	doc_873901597511_item	2911804	et	4	main
tal	doc_873901597511_item	2911805	et	3	main
oli	doc_873901597511_item	2911806	et	3	main
vestluskaaslane	doc_873901597511_item	2911807	et	3	main
aga	doc_873901597511_item	2911808	et	3	main
nüd	doc_873901597511_item	2911809	et	4	main
konfliktid	doc_873901597511_item	2911810	et	3	main
nutt	doc_873901597511_item	2911811	et	3	main
pingeline	doc_873901597511_item	2911812	et	4	main
tuju	doc_873901597511_item	2911813	et	4	main
me	doc_873901597511_item	2911814	et	4	main
võime	doc_873901597511_item	2911815	et	4	main
näha	doc_873901597511_item	2911816	et	3	main
kuidas	doc_873901597511_item	2911817	et	3	main
muutuvad	doc_873901597511_item	2911818	et	4	main
suhted	doc_873901597511_item	2911819	et	3	main
mari	doc_873901597511_item	2911820	et	4	main
nüüd	doc_873901597511_item	2911824	et	4	main
on	doc_873901597511_item	2911835	et	4	main
ära	doc_873901597511_item	2911848	et	4	main
minna	doc_873901597511_item	2911849	et	3	main
julgeks	doc_873901597511_item	2911862	et	4	main
aga	doc_873901597511_item	2911863	et	3	main
aga	doc_873901597511_item	2911871	et	3	main
et	doc_873901597511_item	2911874	et	3	main
aga	doc_873901597511_item	2911880	et	3	main
ees	doc_873901597511_item	2911898	et	4	main
enam	doc_873901597511_item	2911929	et	4	main
rääkida	doc_873901597511_item	2911933	et	3	main
sai	doc_873901597511_item	2911935	et	4	main
naine	doc_873901597511_item	2911942	et	3	main
ja	doc_873901597511_item	2911952	et	3	main
talle	doc_873901597511_item	2911962	et	4	main
hingesse	doc_873901597511_item	2911969	et	4	main
suhted	doc_873901597511_item	2911981	et	3	main
mida	doc_873901597511_item	2911779	et	4	main
ta	doc_873901597511_item	2911782	et	4	main
valib	doc_873901597511_item	2911783	et	3	main
raha	doc_873901597511_item	2911784	et	4	main
on	doc_873901597511_item	2911787	et	4	main
tõnu	doc_873901597511_item	2911822	et	4	main
hindama	doc_873901597511_item	2911827	et	3	main
parem	doc_873901597511_item	2911836	et	4	main
tal	doc_873901597511_item	2911837	et	3	main
ärkas	doc_873901597511_item	2911838	et	3	main
võstlus	doc_873901597511_item	2911844	et	4	main
kas	doc_873901597511_item	2911845	et	3	main
minna	doc_873901597511_item	2911846	et	3	main
juurde	doc_873901597511_item	2911851	et	4	main
või	doc_873901597511_item	2911855	et	4	main
kas	doc_873901597511_item	2911857	et	3	main
ta	doc_873901597511_item	2911858	et	4	main
julgeb	doc_873901597511_item	2911859	et	3	main
jah	doc_873901597511_item	2911860	et	3	main
kõik	doc_873901597511_item	2911866	et	4	main
sai	doc_873901597511_item	2911872	et	4	main
mis	doc_873901597511_item	2911881	et	4	main
toimub	doc_873901597511_item	2911882	et	3	main
oli	doc_873901597511_item	2911887	et	3	main
kas	doc_873901597511_item	2911891	et	3	main
mõisniku	doc_873901597511_item	2911893	et	3	main
või	doc_873901597511_item	2911895	et	4	main
tema	doc_873901597511_item	2911897	et	4	main
seisis	doc_873901597511_item	2911899	et	4	main
raske	doc_873901597511_item	2911900	et	4	main
küsimus	doc_873901597511_item	2911901	et	4	main
tal	doc_873901597511_item	2911902	et	3	main
oli	doc_873901597511_item	2911903	et	3	main
väga	doc_873901597511_item	2911904	et	3	main
raske	doc_873901597511_item	2911905	et	4	main
valik	doc_873901597511_item	2911906	et	3	main
mari	doc_873901597511_item	2911907	et	4	main
oli	doc_873901597511_item	2911908	et	3	main
uhke	doc_873901597511_item	2911909	et	4	main
ebaloomulik	doc_873901597511_item	2911910	et	3	main
julge	doc_873901597511_item	2911911	et	4	main
talle	doc_873901597511_item	2911912	et	4	main
oli	doc_873901597511_item	2911913	et	3	main
väga	doc_873901597511_item	2911914	et	3	main
raske	doc_873901597511_item	2911915	et	4	main
teha	doc_873901597511_item	2911916	et	3	main
seda	doc_873901597511_item	2911917	et	3	main
sammu	doc_873901597511_item	2911918	et	4	main
aga	doc_873901597511_item	2911919	et	3	main
ta	doc_873901597511_item	2911920	et	4	main
ta	doc_873901597511_item	2911928	et	4	main
tõnuga	doc_873901597511_item	2911932	et	4	main
temale	doc_873901597511_item	2911936	et	3	main
väga	doc_873901597511_item	2911947	et	3	main
tähtsam	doc_873901597511_item	2911949	et	4	main
tuli	doc_873901597511_item	2911957	et	4	main
valgus	doc_873901597511_item	2911970	et	4	main
arenevad	doc_873901597511_item	2911980	et	4	main
inimeste	doc_873901597511_item	2911982	et	3	main
inimesed	doc_873901597511_item	2911990	et	3	main
piimamees	doc_873901597511_item	2911992	et	4	main
teda	doc_873901597512_item	2912028	et	4	main
õnnelikult	doc_873901597512_item	2912033	et	4	main
mari	doc_873901597512_item	2912034	et	4	main
hea	doc_873901597512_item	2912036	et	4	main
end	doc_873901597511_item	2911924	et	4	main
ohvriks	doc_873901597511_item	2911925	et	3	main
pärast	doc_873901597511_item	2911926	et	4	main
seda	doc_873901597511_item	2911927	et	3	main
võrraks	doc_873901597511_item	2911937	et	4	main
mari	doc_873901597511_item	2911938	et	4	main
on	doc_873901597511_item	2911939	et	4	main
väga	doc_873901597511_item	2911940	et	3	main
kõik	doc_873901597511_item	2911963	et	4	main
rahu	doc_873901597511_item	2911972	et	4	main
mäeküla	doc_873901597511_item	2911974	et	4	main
me	doc_873901597511_item	2911976	et	4	main
ja	doc_873901597511_item	2911987	et	3	main
mari	doc_873901597512_item	2911998	et	4	main
ja	doc_873901597512_item	2911999	et	3	main
tänapäevane	doc_873901597512_item	2912000	et	4	main
naine	doc_873901597512_item	2912001	et	3	main
mari	doc_873901597512_item	2912002	et	4	main
heasüdamlik	doc_873901597512_item	2912004	et	3	main
lõbus	doc_873901597512_item	2912005	et	4	main
ja	doc_873901597512_item	2912006	et	3	main
hellatundeline	doc_873901597512_item	2912007	et	4	main
inimene	doc_873901597512_item	2912008	et	3	main
ta	doc_873901597512_item	2912009	et	4	main
soovib	doc_873901597512_item	2912010	et	3	main
olla	doc_873901597512_item	2912011	et	3	main
iseseisev	doc_873901597512_item	2912012	et	3	main
aga	doc_873901597512_item	2912013	et	3	main
ohverdab	doc_873901597512_item	2912015	et	3	main
ta	doc_873901597512_item	2912014	et	4	main
endaga	doc_873901597512_item	2912016	et	4	main
oma	doc_873901597512_item	2912017	et	4	main
pärast	doc_873901597512_item	2912019	et	4	main
pere	doc_873901597512_item	2912018	et	4	main
ta	doc_873901597512_item	2912020	et	4	main
juurde	doc_873901597511_item	2911959	et	4	main
ja	doc_873901597511_item	2911960	et	3	main
ütles	doc_873901597511_item	2911961	et	3	main
oma	doc_873901597511_item	2911968	et	4	main
võime	doc_873901597511_item	2911977	et	4	main
näha	doc_873901597511_item	2911978	et	3	main
kuidas	doc_873901597511_item	2911979	et	3	main
kindlasti	doc_873901597511_item	2911994	et	3	main
psüholoogiline	doc_873901597511_item	2911995	et	4	main
romaan	doc_873901597511_item	2911996	et	3	main
on	doc_873901597512_item	2912003	et	4	main
kahetse	doc_873901597512_item	2912022	et	4	main
ja	doc_873901597512_item	2912030	et	3	main
hoiab	doc_873901597512_item	2912039	et	3	main
samal	doc_873901597512_item	2912042	et	3	main
laste	doc_873901597512_item	2912045	et	4	main
eest	doc_873901597512_item	2912046	et	4	main
on	doc_873901597512_item	2912071	et	4	main
juba	doc_873901597512_item	2912072	et	3	main
mari	doc_873901597512_item	2912075	et	4	main
aru	doc_873901597512_item	2912085	et	4	main
et	doc_873901597512_item	2912086	et	3	main
see	doc_873901597512_item	2912087	et	3	main
paneb	doc_873901597512_item	2912111	et	3	main
ei	doc_873901597512_item	2912121	et	4	main
armastuse	doc_873901597512_item	2912131	et	4	main
tõttu	doc_873901597512_item	2912132	et	4	main
raha	doc_873901597512_item	2912137	et	4	main
ma	doc_873901597512_item	2912138	et	3	main
arvan	doc_873901597512_item	2912139	et	3	main
muretsevad	doc_873901597512_item	2912147	et	4	main
oma	doc_873901597512_item	2912149	et	4	main
hüvangi	doc_873901597512_item	2912150	et	3	main
pärast	doc_873901597512_item	2912151	et	4	main
minu	doc_873901597512_item	2912152	et	3	main
abikaasa	doc_873901597512_item	2912159	et	4	main
näide	doc_873901597512_item	2912160	et	3	main
abi	doc_873901597512_item	2912170	et	4	main
kutsuvad	doc_873901597512_item	2912175	et	4	main
minu	doc_873901597512_item	2912176	et	3	main
tänapäevane	doc_873901597513_item	2912181	et	4	main
ta	doc_873901597513_item	2912187	et	4	main
midagi	doc_873901597513_item	2912223	et	4	main
vihane	doc_873901597513_item	2912233	et	4	main
eest	doc_873901597513_item	2912247	et	4	main
me	doc_873901597513_item	2912254	et	4	main
on	doc_873901597513_item	2912283	et	4	main
väga	doc_873901597513_item	2912284	et	3	main
sarnane	doc_873901597513_item	2912285	et	4	main
mariga	doc_873901597513_item	2912286	et	3	main
uhke	doc_873901597513_item	2912290	et	4	main
tänapäevane	doc_873901597513_item	2912294	et	4	main
esimeselt	doc_873901597513_item	2912297	et	3	main
ei	doc_873901597513_item	2912301	et	4	main
mari	doc_873901597513_item	2912309	et	4	main
oskab	doc_873901597513_item	2912314	et	3	main
mäeküla	doc_873901597514_item	2912341	et	4	main
eduard	doc_873901597514_item	2912349	et	4	main
vilde	doc_873901597514_item	2912350	et	4	main
loomingus	doc_873901597514_item	2912351	et	3	main
mäeküla	doc_873901597514_item	2912357	et	4	main
sellist	doc_873901597514_item	2912359	et	4	main
kirjutades	doc_873901597514_item	2912361	et	3	main
huvitas	doc_873901597514_item	2912362	et	3	main
vildet	doc_873901597514_item	2912363	et	4	main
inimeste	doc_873901597514_item	2912364	et	3	main
kirjeldanud	doc_873901597514_item	2912375	et	4	main
urick	doc_873901597514_item	2912381	et	4	main
ametit	doc_873901597514_item	2912390	et	3	main
ei	doc_873901597514_item	2912433	et	4	main
mari	doc_873901597514_item	2912439	et	4	main
on	doc_873901597514_item	2912440	et	4	main
ta	doc_873901597514_item	2912442	et	4	main
küljest	doc_873901597514_item	2912451	et	4	main
mis	doc_873901597514_item	2912460	et	4	main
seisukohalt	doc_873901597514_item	2912462	et	4	main
annab	doc_873901597514_item	2912463	et	3	main
lugupidamist	doc_873901597514_item	2912464	et	3	main
võimu	doc_873901597514_item	2912466	et	4	main
palju	doc_873901597514_item	2912471	et	4	main
ja	doc_873901597514_item	2912486	et	3	main
on	doc_873901597514_item	2912488	et	4	main
muutuvad	doc_873901597511_item	2911989	et	4	main
mäeküla	doc_873901597511_item	2911991	et	4	main
on	doc_873901597511_item	2911993	et	4	main
ei	doc_873901597512_item	2912021	et	4	main
iseenda	doc_873901597512_item	2912023	et	3	main
elasid	doc_873901597512_item	2912032	et	4	main
on	doc_873901597512_item	2912035	et	4	main
ta	doc_873901597512_item	2912038	et	4	main
majandus	doc_873901597512_item	2912040	et	4	main
ja	doc_873901597512_item	2912041	et	3	main
mees	doc_873901597512_item	2912065	et	4	main
tegu	doc_873901597512_item	2912068	et	4	main
uhke	doc_873901597512_item	2912081	et	4	main
pere	doc_873901597512_item	2912092	et	4	main
linna	doc_873901597512_item	2912106	et	4	main
elama	doc_873901597512_item	2912107	et	3	main
praegu	doc_873901597512_item	2912108	et	3	main
naiste	doc_873901597512_item	2912109	et	3	main
ennast	doc_873901597512_item	2912119	et	4	main
ja	doc_873901597512_item	2912120	et	3	main
oma	doc_873901597512_item	2912123	et	4	main
neid	doc_873901597512_item	2912126	et	4	main
tähtsam	doc_873901597512_item	2912134	et	4	main
praegu	doc_873901597512_item	2912141	et	3	main
mari	doc_873901597512_item	2912154	et	4	main
sõltumatust	doc_873901597512_item	2912163	et	4	main
mari	doc_873901597512_item	2912166	et	4	main
seda	doc_873901597512_item	2912168	et	3	main
ilma	doc_873901597512_item	2912169	et	4	main
mari	doc_873901597513_item	2912179	et	4	main
ja	doc_873901597513_item	2912180	et	3	main
noor	doc_873901597513_item	2912185	et	3	main
rääkida	doc_873901597513_item	2912222	et	3	main
oma	doc_873901597513_item	2912224	et	4	main
meeste	doc_873901597513_item	2912225	et	4	main
vastu	doc_873901597513_item	2912226	et	3	main
aga	doc_873901597513_item	2912227	et	3	main
tõsine	doc_873901597513_item	2912231	et	4	main
naine	doc_873901597513_item	2912234	et	3	main
ta	doc_873901597513_item	2912248	et	4	main
nägime	doc_873901597513_item	2912255	et	3	main
et	doc_873901597513_item	2912260	et	3	main
naine	doc_873901597513_item	2912282	et	3	main
iseseisvune	doc_873901597513_item	2912292	et	4	main
eest	doc_873901597513_item	2912299	et	4	main
ohverda	doc_873901597513_item	2912302	et	4	main
holitsema	doc_873901597513_item	2912315	et	4	main
lapsi	doc_873901597513_item	2912320	et	4	main
ise	doc_873901597513_item	2912326	et	4	main
talle	doc_873901597513_item	2912327	et	4	main
keedagi	doc_873901597513_item	2912331	et	4	main
on	doc_873901597513_item	2912337	et	4	main
väga	doc_873901597513_item	2912338	et	3	main
sarnased	doc_873901597513_item	2912339	et	4	main
on	doc_873901597514_item	2912343	et	4	main
psühholoogiline	doc_873901597514_item	2912344	et	4	main
romaan	doc_873901597514_item	2912345	et	3	main
psühholoogilise	doc_873901597514_item	2912346	et	4	main
näitab	doc_873901597514_item	2912352	et	3	main
teiste	doc_873901597514_item	2912353	et	4	main
teoste	doc_873901597514_item	2912354	et	3	main
käitumispsühholoogia	doc_873901597514_item	2912365	et	4	main
suhteid	doc_873901597514_item	2912379	et	3	main
ta	doc_873901597512_item	2912024	et	4	main
ainult	doc_873901597512_item	2912025	et	4	main
tahab	doc_873901597512_item	2912026	et	3	main
et	doc_873901597512_item	2912027	et	3	main
abikaasa	doc_873901597512_item	2912031	et	4	main
hoolitseb	doc_873901597512_item	2912044	et	3	main
ja	doc_873901597512_item	2912051	et	3	main
tähtsaks	doc_873901597512_item	2912052	et	4	main
meheks	doc_873901597512_item	2912053	et	3	main
saada	doc_873901597512_item	2912054	et	4	main
ta	doc_873901597512_item	2912055	et	4	main
tahab	doc_873901597512_item	2912056	et	3	main
perenaine	doc_873901597512_item	2912037	et	3	main
ajal	doc_873901597512_item	2912043	et	4	main
elu	doc_873901597512_item	2912058	et	4	main
ja	doc_873901597512_item	2912060	et	3	main
annab	doc_873901597512_item	2912061	et	3	main
marit	doc_873901597512_item	2912062	et	3	main
oma	doc_873901597512_item	2912067	et	4	main
liiga	doc_873901597512_item	2912073	et	4	main
hilja	doc_873901597512_item	2912074	et	3	main
aga	doc_873901597512_item	2912082	et	3	main
ta	doc_873901597512_item	2912083	et	4	main
saab	doc_873901597512_item	2912084	et	3	main
oli	doc_873901597512_item	2912093	et	3	main
mari	doc_873901597512_item	2912095	et	4	main
ta	doc_873901597512_item	2912100	et	4	main
põgeneb	doc_873901597512_item	2912101	et	3	main
mõisniku	doc_873901597512_item	2912102	et	3	main
juurest	doc_873901597512_item	2912103	et	4	main
ainult	doc_873901597512_item	2912118	et	4	main
muretse	doc_873901597512_item	2912122	et	4	main
probleemidest	doc_873901597512_item	2912125	et	3	main
naised	doc_873901597512_item	2912127	et	3	main
tihti	doc_873901597512_item	2912128	et	3	main
abielluvad	doc_873901597512_item	2912129	et	4	main
mitte	doc_873901597512_item	2912130	et	3	main
neile	doc_873901597512_item	2912135	et	4	main
nad	doc_873901597512_item	2912146	et	3	main
ainult	doc_873901597512_item	2912148	et	4	main
on	doc_873901597512_item	2912155	et	4	main
ideaalne	doc_873901597512_item	2912156	et	3	main
ema	doc_873901597512_item	2912157	et	4	main
ja	doc_873901597512_item	2912158	et	3	main
ja	doc_873901597512_item	2912164	et	3	main
austus	doc_873901597512_item	2912177	et	4	main
naine	doc_873901597513_item	2912182	et	3	main
naine	doc_873901597513_item	2912186	et	3	main
surnud	doc_873901597513_item	2912191	et	4	main
prillup	doc_873901597512_item	2912047	et	4	main
tahab	doc_873901597512_item	2912048	et	3	main
väga	doc_873901597512_item	2912049	et	3	main
rikkaks	doc_873901597512_item	2912050	et	4	main
oma	doc_873901597512_item	2912057	et	4	main
muutma	doc_873901597512_item	2912059	et	3	main
mõisnikule	doc_873901597512_item	2912063	et	3	main
pärast	doc_873901597512_item	2912064	et	4	main
on	doc_873901597512_item	2912080	et	4	main
on	doc_873901597512_item	2912088	et	4	main
üksnes	doc_873901597512_item	2912089	et	3	main
võimalus	doc_873901597512_item	2912090	et	3	main
et	doc_873901597512_item	2912091	et	3	main
õnne	doc_873901597512_item	2912094	et	4	main
soovib	doc_873901597512_item	2912096	et	3	main
olla	doc_873901597512_item	2912097	et	3	main
iseseisev	doc_873901597512_item	2912098	et	3	main
seepärast	doc_873901597512_item	2912099	et	3	main
enamik	doc_873901597512_item	2912110	et	3	main
kareeri	doc_873901597512_item	2912113	et	4	main
kohale	doc_873901597512_item	2912115	et	4	main
nad	doc_873901597512_item	2912116	et	3	main
mõtlevad	doc_873901597512_item	2912117	et	4	main
pere	doc_873901597512_item	2912124	et	4	main
kõige	doc_873901597512_item	2912133	et	4	main
et	doc_873901597512_item	2912140	et	3	main
naised	doc_873901597512_item	2912143	et	3	main
kõik	doc_873901597512_item	2912171	et	4	main
teda	doc_873901597512_item	2912172	et	4	main
essee	doc_873901597513_item	2912178	et	4	main
on	doc_873901597513_item	2912184	et	4	main
tõnu	doc_873901597513_item	2912189	et	4	main
prillupi	doc_873901597513_item	2912190	et	4	main
lubakse	doc_873901597513_item	2912221	et	4	main
ja	doc_873901597513_item	2912232	et	3	main
ta	doc_873901597513_item	2912235	et	4	main
vastu	doc_873901597513_item	2912241	et	3	main
ei	doc_873901597513_item	2912243	et	4	main
enda	doc_873901597513_item	2912245	et	4	main
raha	doc_873901597513_item	2912246	et	4	main
ennast	doc_873901597513_item	2912250	et	4	main
kui	doc_873901597513_item	2912251	et	3	main
inimesest	doc_873901597513_item	2912252	et	3	main
aga	doc_873901597513_item	2912253	et	3	main
ta	doc_873901597513_item	2912257	et	4	main
tänapäevane	doc_873901597513_item	2912281	et	4	main
on	doc_873901597513_item	2912288	et	4	main
julge	doc_873901597513_item	2912289	et	4	main
hoolitseb	doc_873901597513_item	2912296	et	3	main
enda	doc_873901597513_item	2912298	et	4	main
tugev	doc_873901597513_item	2912311	et	4	main
ise	doc_873901597513_item	2912316	et	4	main
oma	doc_873901597513_item	2912319	et	4	main
eest	doc_873901597513_item	2912321	et	4	main
ta	doc_873901597513_item	2912322	et	4	main
ei	doc_873901597513_item	2912328	et	4	main
abi	doc_873901597513_item	2912332	et	4	main
ma	doc_873901597513_item	2912333	et	3	main
mõtlen	doc_873901597513_item	2912334	et	3	main
et	doc_873901597513_item	2912335	et	3	main
essee	doc_873901597514_item	2912340	et	4	main
kasvu	doc_873901597514_item	2912348	et	4	main
romaan	doc_873901597514_item	2912356	et	3	main
seostatuna	doc_873901597514_item	2912366	et	4	main
armastus-	doc_873901597514_item	2912367	et	4	main
ja	doc_873901597514_item	2912368	et	3	main
tõnu	doc_873901597514_item	2912385	et	4	main
tulutoovat	doc_873901597514_item	2912388	et	3	main
õige	doc_873901597514_item	2912430	et	4	main
alandlik	doc_873901597514_item	2912436	et	3	main
ja	doc_873901597514_item	2912446	et	3	main
tõnu	doc_873901597514_item	2912452	et	4	main
tõnu	doc_873901597514_item	2912467	et	4	main
teose	doc_873901597514_item	2912469	et	3	main
jooksul	doc_873901597514_item	2912470	et	4	main
raha	doc_873901597514_item	2912477	et	4	main
siis	doc_873901597514_item	2912478	et	3	main
lõpu	doc_873901597514_item	2912479	et	3	main
poole	doc_873901597514_item	2912480	et	4	main
ta	doc_873901597514_item	2912481	et	4	main
lõpuks	doc_873901597514_item	2912493	et	4	main
tähtis	doc_873901597514_item	2912501	et	4	main
kahetseb	doc_873901597512_item	2912066	et	3	main
kuid	doc_873901597512_item	2912069	et	4	main
selleks	doc_873901597512_item	2912070	et	4	main
peab	doc_873901597512_item	2912076	et	4	main
sellega	doc_873901597512_item	2912077	et	3	main
leppima	doc_873901597512_item	2912078	et	3	main
mari	doc_873901597512_item	2912079	et	4	main
koos	doc_873901597512_item	2912104	et	4	main
lastega	doc_873901597512_item	2912105	et	3	main
oma	doc_873901597512_item	2912112	et	4	main
esimesele	doc_873901597512_item	2912114	et	3	main
on	doc_873901597512_item	2912136	et	4	main
palju	doc_873901597512_item	2912142	et	4	main
on	doc_873901597512_item	2912144	et	4	main
enesearmastajad	doc_873901597512_item	2912145	et	3	main
jaoks	doc_873901597512_item	2912153	et	4	main
ta	doc_873901597512_item	2912161	et	4	main
unustas	doc_873901597512_item	2912162	et	3	main
vabadust	doc_873901597512_item	2912165	et	4	main
sai	doc_873901597512_item	2912167	et	4	main
teod	doc_873901597512_item	2912173	et	4	main
välja	doc_873901597512_item	2912174	et	4	main
mari	doc_873901597513_item	2912183	et	4	main
on	doc_873901597513_item	2912188	et	4	main
naiste	doc_873901597513_item	2912192	et	3	main
õde	doc_873901597513_item	2912193	et	4	main
ta	doc_873901597513_item	2912194	et	4	main
on	doc_873901597513_item	2912195	et	4	main
teine	doc_873901597513_item	2912196	et	3	main
tõnu	doc_873901597513_item	2912197	et	4	main
naine	doc_873901597513_item	2912198	et	3	main
ja	doc_873901597513_item	2912199	et	3	main
hoolitseb	doc_873901597513_item	2912200	et	3	main
tema	doc_873901597513_item	2912201	et	4	main
laste	doc_873901597513_item	2912202	et	4	main
eest	doc_873901597513_item	2912203	et	4	main
ta	doc_873901597513_item	2912204	et	4	main
on	doc_873901597513_item	2912205	et	4	main
elav	doc_873901597513_item	2912206	et	4	main
ja	doc_873901597513_item	2912207	et	3	main
elarõõmus	doc_873901597513_item	2912208	et	4	main
südamlik	doc_873901597513_item	2912209	et	3	main
ja	doc_873901597513_item	2912210	et	3	main
tagasihoidlik	doc_873901597513_item	2912211	et	3	main
ta	doc_873901597513_item	2912212	et	4	main
uue	doc_873901597513_item	2912214	et	3	main
on	doc_873901597513_item	2912213	et	4	main
aja	doc_873901597513_item	2912215	et	4	main
sellel	doc_873901597513_item	2912217	et	4	main
naine	doc_873901597513_item	2912216	et	3	main
ajal	doc_873901597513_item	2912218	et	4	main
naistele	doc_873901597513_item	2912219	et	3	main
ei	doc_873901597513_item	2912220	et	4	main
mari	doc_873901597513_item	2912228	et	4	main
on	doc_873901597513_item	2912229	et	4	main
uhke	doc_873901597513_item	2912230	et	4	main
julgis	doc_873901597513_item	2912236	et	4	main
tõnule	doc_873901597513_item	2912237	et	4	main
ohverdas	doc_873901597513_item	2912258	et	3	main
ja	doc_873901597513_item	2912300	et	3	main
end	doc_873901597513_item	2912303	et	4	main
kellelgi	doc_873901597513_item	2912304	et	4	main
ja	doc_873901597513_item	2912312	et	3	main
enda	doc_873901597513_item	2912317	et	4	main
oskab	doc_873901597513_item	2912323	et	3	main
ja	doc_873901597513_item	2912238	et	3	main
mõistnikule	doc_873901597513_item	2912239	et	4	main
rääkida	doc_873901597513_item	2912240	et	3	main
ta	doc_873901597513_item	2912242	et	4	main
müüa	doc_873901597513_item	2912244	et	3	main
hihhab	doc_873901597513_item	2912249	et	4	main
et	doc_873901597513_item	2912256	et	3	main
end	doc_873901597513_item	2912259	et	4	main
tõnu	doc_873901597513_item	2912261	et	4	main
sai	doc_873901597513_item	2912262	et	4	main
see	doc_873901597513_item	2912263	et	3	main
töö	doc_873901597513_item	2912264	et	4	main
ja	doc_873901597513_item	2912265	et	3	main
palju	doc_873901597513_item	2912266	et	4	main
ma	doc_873901597513_item	2912268	et	3	main
ei	doc_873901597513_item	2912269	et	4	main
raha	doc_873901597513_item	2912267	et	4	main
et	doc_873901597513_item	2912271	et	3	main
marile	doc_873901597513_item	2912272	et	3	main
see	doc_873901597513_item	2912273	et	3	main
meeldis	doc_873901597513_item	2912274	et	3	main
aga	doc_873901597513_item	2912275	et	3	main
mõtle	doc_873901597513_item	2912270	et	4	main
ta	doc_873901597513_item	2912276	et	4	main
teeb	doc_873901597513_item	2912277	et	3	main
seda	doc_873901597513_item	2912278	et	3	main
minu	doc_873901597513_item	2912279	et	3	main
arvates	doc_873901597513_item	2912280	et	4	main
ta	doc_873901597513_item	2912287	et	4	main
ja	doc_873901597513_item	2912291	et	3	main
aga	doc_873901597513_item	2912293	et	3	main
naine	doc_873901597513_item	2912295	et	3	main
tänapäevane	doc_873901597513_item	2912305	et	4	main
naine	doc_873901597513_item	2912306	et	3	main
kui	doc_873901597513_item	2912307	et	3	main
ka	doc_873901597513_item	2912308	et	3	main
on	doc_873901597513_item	2912310	et	4	main
ta	doc_873901597513_item	2912313	et	4	main
ja	doc_873901597513_item	2912318	et	3	main
tee	doc_873901597513_item	2912324	et	4	main
raha	doc_873901597513_item	2912325	et	4	main
vaja	doc_873901597513_item	2912330	et	4	main
piimamees	doc_873901597514_item	2912342	et	4	main
teost	doc_873901597514_item	2912360	et	4	main
ühiskonnaelu	doc_873901597514_item	2912369	et	4	main
probleemidega	doc_873901597514_item	2912370	et	3	main
romaanis	doc_873901597514_item	2912371	et	3	main
vilde	doc_873901597514_item	2912373	et	4	main
talupoja	doc_873901597514_item	2912376	et	4	main
mõisniku	doc_873901597514_item	2912378	et	3	main
mõisnik	doc_873901597514_item	2912380	et	3	main
prillupile	doc_873901597514_item	2912386	et	4	main
kui	doc_873901597514_item	2912391	et	3	main
prillup	doc_873901597514_item	2912392	et	4	main
nõustub	doc_873901597514_item	2912393	et	3	main
oma	doc_873901597514_item	2912394	et	4	main
noort	doc_873901597514_item	2912395	et	3	main
naist	doc_873901597514_item	2912396	et	3	main
temaga	doc_873901597514_item	2912397	et	3	main
jagama	doc_873901597514_item	2912398	et	3	main
prillup	doc_873901597514_item	2912399	et	4	main
tahab	doc_873901597514_item	2912400	et	3	main
väga	doc_873901597514_item	2912401	et	3	main
rikkaks	doc_873901597514_item	2912402	et	4	main
ja	doc_873901597514_item	2912403	et	3	main
tähtsaks	doc_873901597514_item	2912404	et	4	main
meheks	doc_873901597514_item	2912405	et	3	main
saada	doc_873901597514_item	2912406	et	4	main
seetõttu	doc_873901597514_item	2912407	et	3	main
näeb	doc_873901597514_item	2912408	et	3	main
ta	doc_873901597514_item	2912409	et	4	main
mari	doc_873901597514_item	2912410	et	4	main
vaid	doc_873901597514_item	2912411	et	3	main
vahendina	doc_873901597514_item	2912412	et	3	main
selle	doc_873901597514_item	2912413	et	4	main
saavutamisel	doc_873901597514_item	2912414	et	4	main
prillupit	doc_873901597514_item	2912415	et	4	main
ei	doc_873901597514_item	2912416	et	4	main
huvitanud	doc_873901597514_item	2912417	et	4	main
naise	doc_873901597514_item	2912418	et	3	main
õnn	doc_873901597514_item	2912419	et	3	main
ega	doc_873901597514_item	2912420	et	3	main
tunded	doc_873901597514_item	2912421	et	3	main
ajal	doc_873901597514_item	2912424	et	4	main
ta	doc_873901597514_item	2912425	et	4	main
tõnu	doc_873901597514_item	2912434	et	4	main
on	doc_873901597514_item	2912435	et	4	main
teisest	doc_873901597514_item	2912450	et	4	main
rahast	doc_873901597514_item	2912459	et	4	main
armastus	doc_873901597514_item	2912485	et	4	main
ole	doc_873901597513_item	2912329	et	4	main
nad	doc_873901597513_item	2912336	et	3	main
realismi	doc_873901597514_item	2912347	et	4	main
hulgas	doc_873901597514_item	2912355	et	4	main
piimamees	doc_873901597514_item	2912358	et	4	main
e	doc_873901597514_item	2912372	et	4	main
on	doc_873901597514_item	2912374	et	4	main
ja	doc_873901597514_item	2912377	et	3	main
von	doc_873901597514_item	2912382	et	4	main
kremer	doc_873901597514_item	2912383	et	4	main
pakkus	doc_873901597514_item	2912384	et	3	main
lepinguga	doc_873901597514_item	2912387	et	3	main
piimamehe	doc_873901597514_item	2912389	et	3	main
kahtleb	doc_873901597514_item	2912426	et	3	main
kas	doc_873901597514_item	2912427	et	3	main
see	doc_873901597514_item	2912428	et	3	main
on	doc_873901597514_item	2912429	et	4	main
küljest	doc_873901597514_item	2912438	et	4	main
kena	doc_873901597514_item	2912441	et	4	main
on	doc_873901597514_item	2912443	et	4	main
naine	doc_873901597514_item	2912445	et	3	main
lapsi	doc_873901597514_item	2912448	et	4	main
kuid	doc_873901597514_item	2912449	et	4	main
oma	doc_873901597514_item	2912454	et	4	main
tulevasest	doc_873901597514_item	2912455	et	4	main
tähtsast	doc_873901597514_item	2912456	et	3	main
ametist	doc_873901597514_item	2912457	et	3	main
ja	doc_873901597514_item	2912458	et	3	main
muutub	doc_873901597514_item	2912468	et	3	main
ainult	doc_873901597514_item	2912476	et	4	main
tuleks	doc_873901597514_item	2912491	et	4	main
hoida	doc_873901597514_item	2912492	et	3	main
raha	doc_873901597514_item	2912499	et	4	main
ega	doc_873901597514_item	2912500	et	3	main
ta	doc_873901597514_item	2912521	et	4	main
kaotanud	doc_873901597514_item	2912523	et	4	main
peaaegu	doc_873901597514_item	2912524	et	3	main
ta	doc_873901597514_item	2912529	et	4	main
poole	doc_873901597514_item	2912532	et	4	main
mari	doc_873901597514_item	2912535	et	4	main
irvitavad	doc_873901597514_item	2912542	et	4	main
äri	doc_873901597514_item	2912546	et	4	main
taipas	doc_873901597514_item	2912555	et	3	main
et	doc_873901597514_item	2912560	et	3	main
oleks	doc_873901597514_item	2912562	et	3	main
hilja	doc_873901597514_item	2912568	et	3	main
kremeri	doc_873901597514_item	2912612	et	4	main
pakkumise	doc_873901597514_item	2912613	et	4	main
kohta	doc_873901597514_item	2912614	et	4	main
midagi	doc_873901597514_item	2912618	et	4	main
et	doc_873901597514_item	2912628	et	3	main
psühholoogiline	doc_873901597514_item	2912631	et	4	main
mari	doc_873901597514_item	2912638	et	4	main
ütles	doc_873901597514_item	2912643	et	3	main
kindlalt	doc_873901597514_item	2912644	et	4	main
varblane	doc_873901597514_item	2912648	et	3	main
kanaarilind	doc_873901597514_item	2912651	et	3	main
varblane	doc_873901597514_item	2912652	et	3	main
psühholoogiline	doc_873901597514_item	2912660	et	4	main
on	doc_873901597514_item	2912678	et	4	main
eduard	doc_873901597514_item	2912681	et	4	main
mäeküla	doc_873901597514_item	2912684	et	4	main
piimamees	doc_873901597514_item	2912685	et	4	main
arengut	doc_873901597514_item	2912692	et	3	main
ta	doc_873901597514_item	2912693	et	4	main
meile	doc_873901597514_item	2912697	et	4	main
ette	doc_873901597514_item	2912700	et	4	main
maalida	doc_873901597514_item	2912701	et	3	main
erinuvusi	doc_873901597515_item	2912723	et	4	main
talus	doc_873901597515_item	2912726	et	4	main
ajal	doc_873901597515_item	2912741	et	4	main
naised	doc_873901597515_item	2912742	et	3	main
aga	doc_873901597515_item	2912749	et	3	main
erinevus	doc_873901597515_item	2912752	et	4	main
perepea	doc_873901597515_item	2912784	et	4	main
kõike	doc_873901597515_item	2912792	et	4	main
aga	doc_873901597515_item	2912796	et	3	main
kuulata	doc_873901597515_item	2912800	et	4	main
ei	doc_873901597515_item	2912805	et	4	main
seda	doc_873901597515_item	2912807	et	3	main
teha	doc_873901597515_item	2912815	et	3	main
ta	doc_873901597515_item	2912821	et	4	main
kuid	doc_873901597514_item	2912422	et	4	main
samal	doc_873901597514_item	2912423	et	3	main
vajalik	doc_873901597514_item	2912431	et	3	main
või	doc_873901597514_item	2912432	et	4	main
esimesest	doc_873901597514_item	2912437	et	3	main
hea	doc_873901597514_item	2912444	et	4	main
armastab	doc_873901597514_item	2912447	et	3	main
unistab	doc_873901597514_item	2912453	et	3	main
tema	doc_873901597514_item	2912461	et	4	main
ja	doc_873901597514_item	2912465	et	3	main
kui	doc_873901597514_item	2912472	et	3	main
ta	doc_873901597514_item	2912473	et	4	main
alguses	doc_873901597514_item	2912474	et	4	main
hindab	doc_873901597514_item	2912475	et	3	main
mõistis	doc_873901597514_item	2912482	et	4	main
et	doc_873901597514_item	2912483	et	3	main
ka	doc_873901597514_item	2912484	et	3	main
abikaasa	doc_873901597514_item	2912487	et	4	main
saab	doc_873901597514_item	2912495	et	3	main
aru	doc_873901597514_item	2912496	et	4	main
et	doc_873901597514_item	2912497	et	3	main
kuid	doc_873901597514_item	2912510	et	4	main
juba	doc_873901597514_item	2912511	et	3	main
hilja	doc_873901597514_item	2912512	et	3	main
aru	doc_873901597514_item	2912515	et	4	main
viga	doc_873901597514_item	2912517	et	4	main
ainult	doc_873901597514_item	2912518	et	4	main
siis	doc_873901597514_item	2912519	et	3	main
kui	doc_873901597514_item	2912520	et	3	main
väärtused	doc_873901597514_item	2912489	et	3	main
mida	doc_873901597514_item	2912490	et	4	main
ei	doc_873901597514_item	2912498	et	4	main
või	doc_873901597514_item	2912504	et	4	main
rahuga	doc_873901597514_item	2912506	et	3	main
ja	doc_873901597514_item	2912508	et	3	main
hinges	doc_873901597514_item	2912509	et	4	main
tähtis	doc_873901597514_item	2912528	et	4	main
lugupidamise	doc_873901597514_item	2912531	et	3	main
on	doc_873901597514_item	2912538	et	4	main
viimane	doc_873901597514_item	2912539	et	3	main
närts	doc_873901597514_item	2912540	et	4	main
mehed	doc_873901597514_item	2912541	et	3	main
enne	doc_873901597514_item	2912564	et	4	main
psühholoogiline	doc_873901597514_item	2912576	et	4	main
kuju	doc_873901597514_item	2912607	et	4	main
teoses	doc_873901597514_item	2912608	et	3	main
kui	doc_873901597514_item	2912609	et	3	main
tõnu	doc_873901597514_item	2912610	et	4	main
räägib	doc_873901597514_item	2912611	et	3	main
räägi	doc_873901597514_item	2912616	et	4	main
ta	doc_873901597514_item	2912619	et	4	main
tema	doc_873901597514_item	2912622	et	4	main
on	doc_873901597514_item	2912625	et	4	main
ei	doc_873901597514_item	2912636	et	4	main
mehele	doc_873901597514_item	2912640	et	3	main
selline	doc_873901597514_item	2912656	et	4	main
sõltumatust	doc_873901597514_item	2912664	et	4	main
ma	doc_873901597514_item	2912672	et	3	main
võin	doc_873901597514_item	2912673	et	3	main
õelda	doc_873901597514_item	2912674	et	4	main
et	doc_873901597514_item	2912675	et	3	main
on	doc_873901597514_item	2912686	et	4	main
on	doc_873901597514_item	2912694	et	4	main
ta	doc_873901597514_item	2912494	et	4	main
ei	doc_873901597514_item	2912503	et	4	main
kodus	doc_873901597514_item	2912507	et	4	main
saab	doc_873901597514_item	2912514	et	3	main
oma	doc_873901597514_item	2912516	et	4	main
talle	doc_873901597514_item	2912527	et	4	main
püüdsib	doc_873901597514_item	2912530	et	4	main
silmas	doc_873901597514_item	2912536	et	4	main
tema	doc_873901597514_item	2912543	et	4	main
käi	doc_873901597514_item	2912548	et	4	main
piima	doc_873901597514_item	2912550	et	4	main
osta	doc_873901597514_item	2912552	et	4	main
kui	doc_873901597514_item	2912553	et	3	main
oma	doc_873901597514_item	2912556	et	4	main
viga	doc_873901597514_item	2912557	et	4	main
tahtis	doc_873901597514_item	2912559	et	3	main
kõik	doc_873901597514_item	2912561	et	4	main
ei	doc_873901597514_item	2912570	et	4	main
räägitakse	doc_873901597514_item	2912571	et	3	main
vaid	doc_873901597514_item	2912572	et	3	main
räägib	doc_873901597514_item	2912604	et	3	main
mari	doc_873901597514_item	2912606	et	4	main
see	doc_873901597514_item	2912624	et	3	main
prillup	doc_873901597514_item	2912634	et	4	main
kellelegi	doc_873901597514_item	2912639	et	4	main
ma	doc_873901597514_item	2912645	et	3	main
väljend	doc_873901597514_item	2912657	et	3	main
on	doc_873901597514_item	2912658	et	4	main
samuti	doc_873901597514_item	2912659	et	3	main
hindas	doc_873901597514_item	2912662	et	3	main
ja	doc_873901597514_item	2912665	et	3	main
ise	doc_873901597514_item	2912668	et	4	main
see	doc_873901597514_item	2912676	et	3	main
teos	doc_873901597514_item	2912677	et	4	main
romaan	doc_873901597514_item	2912680	et	3	main
kujutatud	doc_873901597514_item	2912687	et	4	main
püüdnud	doc_873901597514_item	2912695	et	4	main
pildi	doc_873901597514_item	2912698	et	4	main
19	doc_873901597515_item	2912727	et	2	main
vaatamata	doc_873901597515_item	2912729	et	4	main
ei	doc_873901597515_item	2912756	et	4	main
karjääri	doc_873901597515_item	2912766	et	4	main
võrreldan	doc_873901597515_item	2912768	et	4	main
mees	doc_873901597515_item	2912782	et	4	main
oli	doc_873901597515_item	2912783	et	3	main
ta	doc_873901597515_item	2912794	et	4	main
ei	doc_873901597515_item	2912798	et	4	main
tõnu	doc_873901597515_item	2912801	et	4	main
ka	doc_873901597515_item	2912802	et	3	main
taha	doc_873901597515_item	2912814	et	4	main
mida	doc_873901597515_item	2912817	et	4	main
mees	doc_873901597515_item	2912818	et	4	main
räägib	doc_873901597515_item	2912819	et	3	main
amet	doc_873901597514_item	2912502	et	3	main
asennata	doc_873901597514_item	2912505	et	4	main
ta	doc_873901597514_item	2912513	et	4	main
kõik	doc_873901597514_item	2912525	et	4	main
mis	doc_873901597514_item	2912526	et	4	main
kuid	doc_873901597514_item	2912533	et	4	main
nüüd	doc_873901597514_item	2912534	et	4	main
üle	doc_873901597514_item	2912544	et	3	main
tema	doc_873901597514_item	2912545	et	4	main
ei	doc_873901597514_item	2912547	et	4	main
ei	doc_873901597514_item	2912551	et	4	main
on	doc_873901597514_item	2912566	et	4	main
juba	doc_873901597514_item	2912567	et	3	main
ilmekalt	doc_873901597514_item	2912605	et	4	main
ei	doc_873901597514_item	2912615	et	4	main
viskab	doc_873901597514_item	2912620	et	3	main
seeni	doc_873901597514_item	2912621	et	3	main
näkku	doc_873901597514_item	2912623	et	3	main
näide	doc_873901597514_item	2912627	et	3	main
see	doc_873901597514_item	2912629	et	3	main
kui	doc_873901597514_item	2912633	et	3	main
suri	doc_873901597514_item	2912635	et	3	main
ta	doc_873901597514_item	2912642	et	4	main
linnas	doc_873901597514_item	2912647	et	4	main
mitte	doc_873901597514_item	2912650	et	3	main
täielikku	doc_873901597514_item	2912654	et	4	main
vabadust	doc_873901597514_item	2912655	et	4	main
vabadust	doc_873901597514_item	2912663	et	4	main
enese	doc_873901597514_item	2912666	et	4	main
eest	doc_873901597514_item	2912667	et	4	main
tänu	doc_873901597514_item	2912671	et	4	main
psühholoogiline	doc_873901597514_item	2912679	et	4	main
vilde	doc_873901597514_item	2912682	et	4	main
romaanis	doc_873901597514_item	2912683	et	3	main
aga	doc_873901597515_item	2912721	et	3	main
mari	doc_873901597515_item	2912724	et	4	main
et	doc_873901597515_item	2912732	et	3	main
istuvad	doc_873901597515_item	2912743	et	4	main
kojus	doc_873901597515_item	2912744	et	4	main
ja	doc_873901597515_item	2912745	et	3	main
hoiavad	doc_873901597515_item	2912746	et	3	main
laste	doc_873901597515_item	2912747	et	4	main
taha	doc_873901597515_item	2912757	et	4	main
istuda	doc_873901597515_item	2912758	et	3	main
kui	doc_873901597515_item	2912767	et	3	main
naine	doc_873901597515_item	2912786	et	3	main
mida	doc_873901597515_item	2912793	et	4	main
mari	doc_873901597515_item	2912797	et	4	main
seda	doc_873901597515_item	2912816	et	3	main
teha	doc_873901597515_item	2912823	et	3	main
oma	doc_873901597515_item	2912836	et	4	main
pere	doc_873901597515_item	2912837	et	4	main
laste	doc_873901597515_item	2912838	et	4	main
keda	doc_873901597515_item	2912841	et	4	main
armastab	doc_873901597515_item	2912843	et	3	main
elavad	doc_873901597515_item	2912868	et	4	main
on	doc_873901597516_item	2912875	et	4	main
niisugune	doc_873901597516_item	2912876	et	3	main
neid	doc_873901597516_item	2912898	et	4	main
sõbrad	doc_873901597516_item	2912899	et	3	main
me	doc_873901597516_item	2912904	et	4	main
pärast	doc_873901597516_item	2912910	et	4	main
hulka	doc_873901597516_item	2912913	et	4	main
ta	doc_873901597516_item	2912914	et	4	main
tahab	doc_873901597516_item	2912915	et	3	main
oma	doc_873901597516_item	2912930	et	4	main
ta	doc_873901597516_item	2912940	et	4	main
võib	doc_873901597516_item	2912941	et	3	main
ka	doc_873901597516_item	2912942	et	3	main
kui	doc_873901597516_item	2912947	et	3	main
head	doc_873901597516_item	2912950	et	4	main
heaks	doc_873901597516_item	2912955	et	4	main
see	doc_873901597516_item	2912956	et	3	main
tähtis	doc_873901597516_item	2912959	et	4	main
et	doc_873901597516_item	2912964	et	3	main
oma	doc_873901597516_item	2912967	et	4	main
sepad	doc_873901597516_item	2912969	et	3	main
ta	doc_873901597517_item	2912983	et	4	main
on	doc_873901597517_item	2912984	et	4	main
peale	doc_873901597517_item	2913025	et	4	main
tänapäevas	doc_873901597517_item	2913027	et	3	main
mari	doc_873901597517_item	2913036	et	4	main
tihti	doc_873901597517_item	2913043	et	3	main
oli	doc_873901597514_item	2912522	et	3	main
ta	doc_873901597514_item	2912537	et	4	main
hästi	doc_873901597514_item	2912549	et	3	main
ta	doc_873901597514_item	2912554	et	4	main
ja	doc_873901597514_item	2912558	et	3	main
nagu	doc_873901597514_item	2912563	et	3	main
siis	doc_873901597514_item	2912565	et	3	main
sellest	doc_873901597514_item	2912569	et	4	main
kui	doc_873901597514_item	2912573	et	3	main
see	doc_873901597514_item	2912574	et	3	main
on	doc_873901597514_item	2912575	et	4	main
romaan	doc_873901597514_item	2912577	et	3	main
me	doc_873901597514_item	2912578	et	4	main
saame	doc_873901597514_item	2912579	et	4	main
seda	doc_873901597514_item	2912580	et	3	main
ise	doc_873901597514_item	2912581	et	4	main
aru	doc_873901597514_item	2912582	et	4	main
mitte	doc_873901597514_item	2912583	et	3	main
lihtsalt	doc_873901597514_item	2912584	et	4	main
niisama	doc_873901597514_item	2912585	et	3	main
enne	doc_873901597514_item	2912586	et	4	main
kui	doc_873901597514_item	2912587	et	3	main
ta	doc_873901597514_item	2912588	et	4	main
jõudis	doc_873901597514_item	2912589	et	3	main
oma	doc_873901597514_item	2912590	et	4	main
viga	doc_873901597514_item	2912591	et	4	main
parandama	doc_873901597514_item	2912592	et	3	main
hakata	doc_873901597514_item	2912593	et	4	main
ta	doc_873901597514_item	2912594	et	4	main
suri	doc_873901597514_item	2912595	et	3	main
külmus	doc_873901597514_item	2912596	et	4	main
surnuks	doc_873901597514_item	2912597	et	4	main
et	doc_873901597514_item	2912598	et	3	main
mäeküla	doc_873901597514_item	2912599	et	4	main
piimamees	doc_873901597514_item	2912600	et	4	main
on	doc_873901597514_item	2912601	et	4	main
psühholoogiline	doc_873901597514_item	2912602	et	4	main
romaan	doc_873901597514_item	2912603	et	3	main
mari	doc_873901597514_item	2912617	et	4	main
kujukas	doc_873901597514_item	2912626	et	4	main
on	doc_873901597514_item	2912630	et	4	main
romaan	doc_873901597514_item	2912632	et	3	main
nõustunud	doc_873901597514_item	2912637	et	4	main
minema	doc_873901597514_item	2912641	et	3	main
tahan	doc_873901597514_item	2912646	et	3	main
olla	doc_873901597514_item	2912649	et	3	main
tähendab	doc_873901597514_item	2912653	et	3	main
mari	doc_873901597514_item	2912661	et	4	main
otsustamist	doc_873901597514_item	2912669	et	4	main
selle	doc_873901597514_item	2912670	et	4	main
kolme	doc_873901597514_item	2912688	et	4	main
karakteri	doc_873901597514_item	2912689	et	3	main
käitumist	doc_873901597514_item	2912690	et	4	main
ja	doc_873901597514_item	2912691	et	3	main
kõik	doc_873901597514_item	2912696	et	4	main
silmi	doc_873901597514_item	2912699	et	4	main
ning	doc_873901597514_item	2912702	et	3	main
panna	doc_873901597514_item	2912703	et	4	main
mõtlema	doc_873901597514_item	2912704	et	3	main
essee	doc_873901597515_item	2912705	et	4	main
m	doc_873901597515_item	2912706	et	4	main
ari	doc_873901597515_item	2912707	et	4	main
ja	doc_873901597515_item	2912708	et	3	main
tänapäevane	doc_873901597515_item	2912709	et	4	main
naine	doc_873901597515_item	2912710	et	3	main
kui	doc_873901597515_item	2912711	et	3	main
ma	doc_873901597515_item	2912712	et	3	main
võrreldan	doc_873901597515_item	2912713	et	4	main
mari	doc_873901597515_item	2912714	et	4	main
tänapäevase	doc_873901597515_item	2912715	et	4	main
naisega	doc_873901597515_item	2912716	et	3	main
ma	doc_873901597515_item	2912717	et	3	main
leidsin	doc_873901597515_item	2912718	et	3	main
palju	doc_873901597515_item	2912719	et	4	main
sarnsi	doc_873901597515_item	2912720	et	4	main
mõtlen	doc_873901597515_item	2912731	et	3	main
naine	doc_873901597515_item	2912734	et	3	main
mari	doc_873901597515_item	2912736	et	4	main
siin	doc_873901597515_item	2912750	et	4	main
kojus	doc_873901597515_item	2912759	et	4	main
nad	doc_873901597515_item	2912760	et	3	main
tahavad	doc_873901597515_item	2912761	et	3	main
teeninda	doc_873901597515_item	2912762	et	4	main
ja	doc_873901597515_item	2912785	et	3	main
peas	doc_873901597515_item	2912787	et	4	main
meest	doc_873901597515_item	2912789	et	4	main
teha	doc_873901597515_item	2912791	et	3	main
ütles	doc_873901597515_item	2912795	et	3	main
tänapäevana	doc_873901597515_item	2912803	et	3	main
see	doc_873901597515_item	2912824	et	3	main
mari	doc_873901597515_item	2912827	et	4	main
tänapäevaste	doc_873901597515_item	2912828	et	4	main
naistega	doc_873901597515_item	2912829	et	3	main
mari	doc_873901597515_item	2912830	et	4	main
nagu	doc_873901597515_item	2912831	et	3	main
ei	doc_873901597515_item	2912850	et	4	main
ole	doc_873901597515_item	2912863	et	4	main
vajalik	doc_873901597515_item	2912864	et	3	main
mis	doc_873901597515_item	2912865	et	4	main
sajandil	doc_873901597515_item	2912866	et	3	main
nad	doc_873901597515_item	2912867	et	3	main
õnne	doc_873901597516_item	2912873	et	4	main
ka	doc_873901597515_item	2912722	et	3	main
elas	doc_873901597515_item	2912725	et	3	main
sajandil	doc_873901597515_item	2912728	et	3	main
sellele	doc_873901597515_item	2912730	et	4	main
tänapäevane	doc_873901597515_item	2912733	et	4	main
ja	doc_873901597515_item	2912735	et	3	main
on	doc_873901597515_item	2912737	et	4	main
sarnased	doc_873901597515_item	2912738	et	4	main
nagu	doc_873901597515_item	2912739	et	3	main
tol	doc_873901597515_item	2912740	et	3	main
eest	doc_873901597515_item	2912748	et	4	main
on	doc_873901597515_item	2912751	et	4	main
paljud	doc_873901597515_item	2912753	et	3	main
tänapäevased	doc_873901597515_item	2912754	et	4	main
naised	doc_873901597515_item	2912755	et	3	main
raha	doc_873901597515_item	2912763	et	4	main
ja	doc_873901597515_item	2912764	et	3	main
teha	doc_873901597515_item	2912765	et	3	main
mariga	doc_873901597515_item	2912769	et	3	main
siis	doc_873901597515_item	2912770	et	3	main
näen	doc_873901597515_item	2912771	et	3	main
et	doc_873901597515_item	2912772	et	3	main
talle	doc_873901597515_item	2912773	et	4	main
ei	doc_873901597515_item	2912774	et	4	main
ole	doc_873901597515_item	2912775	et	4	main
väga	doc_873901597515_item	2912776	et	3	main
vajalik	doc_873901597515_item	2912777	et	3	main
teeninda	doc_873901597515_item	2912778	et	4	main
raha	doc_873901597515_item	2912779	et	4	main
19	doc_873901597515_item	2912780	et	2	main
sajandil	doc_873901597515_item	2912781	et	3	main
kuulata	doc_873901597515_item	2912788	et	4	main
ja	doc_873901597515_item	2912790	et	3	main
tahtnud	doc_873901597515_item	2912799	et	4	main
naine	doc_873901597515_item	2912804	et	3	main
teha	doc_873901597515_item	2912806	et	3	main
mida	doc_873901597515_item	2912808	et	4	main
ütleb	doc_873901597515_item	2912809	et	3	main
mees	doc_873901597515_item	2912810	et	4	main
kui	doc_873901597515_item	2912811	et	3	main
naine	doc_873901597515_item	2912812	et	3	main
ei	doc_873901597515_item	2912813	et	4	main
siis	doc_873901597515_item	2912820	et	3	main
tänapaevane	doc_873901597515_item	2912832	et	4	main
naine	doc_873901597515_item	2912833	et	3	main
tahtis	doc_873901597515_item	2912834	et	3	main
elada	doc_873901597515_item	2912835	et	3	main
ja	doc_873901597515_item	2912839	et	3	main
ta	doc_873901597515_item	2912842	et	4	main
kes	doc_873901597515_item	2912845	et	4	main
armastab	doc_873901597515_item	2912846	et	3	main
alati	doc_873901597515_item	2912859	et	4	main
ei	doc_873901597515_item	2912862	et	4	main
oma	doc_873901597516_item	2912872	et	4	main
ütlen	doc_873901597516_item	2912886	et	3	main
sa	doc_873901597516_item	2912889	et	3	main
et	doc_873901597516_item	2912906	et	3	main
iga	doc_873901597516_item	2912918	et	4	main
näiteks	doc_873901597516_item	2912934	et	4	main
kui	doc_873901597516_item	2912935	et	3	main
inimene	doc_873901597516_item	2912936	et	3	main
suhtleb	doc_873901597516_item	2912937	et	3	main
ebahea	doc_873901597516_item	2912938	et	4	main
inimestega	doc_873901597516_item	2912939	et	3	main
vastas	doc_873901597516_item	2912946	et	4	main
mari	doc_873901597517_item	2912975	et	4	main
noor	doc_873901597517_item	2912977	et	3	main
tal	doc_873901597517_item	2912978	et	3	main
on	doc_873901597517_item	2912979	et	4	main
väga	doc_873901597517_item	2912985	et	3	main
muutlik	doc_873901597517_item	2912986	et	3	main
ei	doc_873901597515_item	2912822	et	4	main
on	doc_873901597515_item	2912825	et	4	main
sarnas	doc_873901597515_item	2912826	et	3	main
mehega	doc_873901597515_item	2912840	et	3	main
ja	doc_873901597515_item	2912844	et	3	main
teda	doc_873901597515_item	2912847	et	4	main
aga	doc_873901597515_item	2912848	et	3	main
olnud	doc_873901597515_item	2912851	et	4	main
armastav	doc_873901597515_item	2912852	et	4	main
naine	doc_873901597515_item	2912853	et	3	main
ma	doc_873901597515_item	2912854	et	3	main
mõtlen	doc_873901597515_item	2912855	et	3	main
et	doc_873901597515_item	2912856	et	3	main
ta	doc_873901597515_item	2912849	et	4	main
on	doc_873901597515_item	2912858	et	4	main
ja	doc_873901597515_item	2912861	et	3	main
on	doc_873901597516_item	2912871	et	4	main
vanasõna	doc_873901597516_item	2912877	et	4	main
mulle	doc_873901597516_item	2912879	et	4	main
kes	doc_873901597516_item	2912880	et	4	main
kes	doc_873901597516_item	2912888	et	4	main
me	doc_873901597516_item	2912892	et	4	main
särnased	doc_873901597516_item	2912901	et	4	main
veel	doc_873901597516_item	2912902	et	4	main
teame	doc_873901597516_item	2912905	et	3	main
otsustab	doc_873901597516_item	2912908	et	3	main
missuguse	doc_873901597516_item	2912911	et	3	main
inimeste	doc_873901597516_item	2912912	et	3	main
inimene	doc_873901597516_item	2912919	et	3	main
inimesed	doc_873901597515_item	2912857	et	3	main
sarnased	doc_873901597515_item	2912860	et	4	main
essee	doc_873901597516_item	2912869	et	4	main
igaüks	doc_873901597516_item	2912870	et	3	main
on	doc_873901597516_item	2912881	et	4	main
su	doc_873901597516_item	2912882	et	3	main
sõbrad	doc_873901597516_item	2912883	et	3	main
ja	doc_873901597516_item	2912884	et	3	main
ma	doc_873901597516_item	2912885	et	3	main
on	doc_873901597516_item	2912900	et	4	main
oma	doc_873901597516_item	2912909	et	4	main
otsustab	doc_873901597516_item	2912920	et	3	main
missuguses	doc_873901597516_item	2912921	et	3	main
hulgas	doc_873901597516_item	2912923	et	4	main
enda	doc_873901597516_item	2912925	et	4	main
inimeseks	doc_873901597516_item	2912945	et	3	main
on	doc_873901597516_item	2912949	et	4	main
sõbrad	doc_873901597516_item	2912951	et	3	main
ta	doc_873901597516_item	2912952	et	4	main
ka	doc_873901597516_item	2912953	et	3	main
muutub	doc_873901597516_item	2912954	et	3	main
inemestele	doc_873901597516_item	2912962	et	4	main
mäletada	doc_873901597516_item	2912963	et	3	main
nad	doc_873901597516_item	2912965	et	3	main
jõudu	doc_873901597517_item	2912981	et	4	main
aga	doc_873901597517_item	2912982	et	3	main
oma	doc_873901597517_item	2913022	et	4	main
võib	doc_873901597517_item	2913028	et	3	main
öelda	doc_873901597517_item	2913030	et	4	main
et	doc_873901597517_item	2913033	et	3	main
sellised	doc_873901597517_item	2913039	et	4	main
inimestele	doc_873901597517_item	2913058	et	3	main
sajandil	doc_873901597518_item	2913082	et	3	main
ta	doc_873901597518_item	2913095	et	4	main
oli	doc_873901597518_item	2913096	et	3	main
kes	doc_873901597518_item	2913099	et	4	main
pärast	doc_873901597518_item	2913102	et	4	main
muutusid	doc_873901597518_item	2913103	et	4	main
ja	doc_873901597518_item	2913104	et	3	main
said	doc_873901597518_item	2913105	et	4	main
on	doc_873901597518_item	2913141	et	4	main
sõda	doc_873901597518_item	2913149	et	4	main
ja	doc_873901597518_item	2913150	et	3	main
ka	doc_873901597518_item	2913155	et	3	main
ilut	doc_873901597518_item	2913157	et	4	main
püüavad	doc_873901597518_item	2913161	et	3	main
ilusad	doc_873901597518_item	2913162	et	3	main
olla	doc_873901597518_item	2913163	et	3	main
mari	doc_873901597518_item	2913164	et	4	main
rõõmus	doc_873901597518_item	2913174	et	4	main
näeb	doc_873901597518_item	2913178	et	3	main
kogu	doc_873901597518_item	2913180	et	4	main
lastega	doc_873901597518_item	2913182	et	3	main
ja	doc_873901597518_item	2913217	et	3	main
nagu	doc_873901597518_item	2913219	et	3	main
julgeb	doc_873901597518_item	2913222	et	3	main
vajalikuks	doc_873901597518_item	2913227	et	3	main
mida	doc_873901597518_item	2913231	et	4	main
on	doc_873901597518_item	2913236	et	4	main
parem	doc_873901597518_item	2913237	et	4	main
teha	doc_873901597518_item	2913238	et	3	main
ühesõnaga	doc_873901597518_item	2913239	et	3	main
tore	doc_873901597518_item	2913243	et	3	main
naine	doc_873901597518_item	2913244	et	3	main
tavaline	doc_873901597518_item	2913246	et	4	main
omamoodne	doc_873901597518_item	2913248	et	3	main
ta	doc_873901597518_item	2913249	et	4	main
on	doc_873901597518_item	2913250	et	4	main
on	doc_873901597518_item	2913267	et	4	main
ta	doc_873901597518_item	2913273	et	4	main
egoistlik	doc_873901597518_item	2913274	et	3	main
ning	doc_873901597518_item	2913275	et	3	main
mängivad	doc_873901597519_item	2913313	et	4	main
kremer	doc_873901597519_item	2913321	et	4	main
on	doc_873901597519_item	2913323	et	4	main
enesekindel	doc_873901597519_item	2913324	et	3	main
noor	doc_873901597519_item	2913325	et	3	main
kes	doc_873901597519_item	2913327	et	4	main
mari	doc_873901597519_item	2913337	et	4	main
rikkaks	doc_873901597519_item	2913343	et	4	main
sõlmivad	doc_873901597519_item	2913352	et	4	main
lepingu	doc_873901597519_item	2913353	et	3	main
sepp	doc_873901597516_item	2912874	et	3	main
ütle	doc_873901597516_item	2912878	et	4	main
sulle	doc_873901597516_item	2912887	et	3	main
oled	doc_873901597516_item	2912890	et	3	main
seetõttu	doc_873901597516_item	2912891	et	3	main
võime	doc_873901597516_item	2912893	et	4	main
öelda	doc_873901597516_item	2912894	et	4	main
et	doc_873901597516_item	2912895	et	3	main
inimesed	doc_873901597516_item	2912896	et	3	main
ja	doc_873901597516_item	2912897	et	3	main
me	doc_873901597516_item	2912903	et	4	main
igaüks	doc_873901597516_item	2912907	et	3	main
suhelda	doc_873901597516_item	2912916	et	4	main
järelikult	doc_873901597516_item	2912917	et	3	main
inimeste	doc_873901597516_item	2912922	et	3	main
elutee	doc_873901597516_item	2912931	et	4	main
ja	doc_873901597516_item	2912932	et	3	main
õnnetee	doc_873901597516_item	2912933	et	4	main
saada	doc_873901597516_item	2912943	et	4	main
niisuguse	doc_873901597516_item	2912944	et	3	main
väga	doc_873901597516_item	2912958	et	3	main
noor	doc_873901597516_item	2912961	et	3	main
on	doc_873901597516_item	2912966	et	4	main
õnne	doc_873901597516_item	2912968	et	4	main
essee	doc_873901597517_item	2912970	et	4	main
mari	doc_873901597517_item	2912971	et	4	main
ja	doc_873901597517_item	2912972	et	3	main
tänapäevane	doc_873901597517_item	2912973	et	4	main
on	doc_873901597517_item	2912976	et	4	main
palju	doc_873901597517_item	2912980	et	4	main
elu	doc_873901597517_item	2913023	et	4	main
ka	doc_873901597517_item	2913029	et	3	main
maailmas	doc_873901597517_item	2913038	et	3	main
väga	doc_873901597517_item	2913042	et	3	main
peres	doc_873901597517_item	2913046	et	3	main
arvan	doc_873901597517_item	2913049	et	3	main
see	doc_873901597517_item	2913051	et	3	main
on	doc_873901597517_item	2913053	et	4	main
eriti	doc_873901597517_item	2913056	et	3	main
mari	doc_873901597518_item	2913060	et	4	main
on	doc_873901597518_item	2913084	et	4	main
oma	doc_873901597518_item	2913092	et	4	main
aja	doc_873901597518_item	2913093	et	4	main
naine	doc_873901597518_item	2913094	et	3	main
business-womanideks	doc_873901597518_item	2913106	et	4	main
äri-naisteks	doc_873901597518_item	2913107	et	3	main
huvitav	doc_873901597518_item	2913111	et	4	main
on	doc_873901597518_item	2913115	et	4	main
ja	doc_873901597518_item	2913118	et	3	main
ta	doc_873901597518_item	2913130	et	4	main
suhteliselt	doc_873901597518_item	2913132	et	4	main
ja	doc_873901597518_item	2913134	et	3	main
naiste	doc_873901597518_item	2913139	et	3	main
pärast	doc_873901597518_item	2913140	et	4	main
konfliktid	doc_873901597518_item	2913143	et	3	main
sõjad	doc_873901597518_item	2913145	et	3	main
edasi	doc_873901597518_item	2913152	et	3	main
välja	doc_873901597518_item	2913177	et	4	main
mängib	doc_873901597518_item	2913179	et	3	main
aga	doc_873901597518_item	2913183	et	3	main
kartlik	doc_873901597518_item	2913216	et	3	main
rääkida	doc_873901597518_item	2913223	et	3	main
millest	doc_873901597518_item	2913225	et	3	main
teeb	doc_873901597518_item	2913229	et	3	main
mari	doc_873901597518_item	2913240	et	4	main
xviii	doc_873901597518_item	2913251	et	4	main
sajandi	doc_873901597518_item	2913252	et	3	main
tavalised	doc_873901597518_item	2913261	et	4	main
aga	doc_873901597518_item	2913263	et	3	main
võreldes	doc_873901597518_item	2913264	et	4	main
tänapäevase	doc_873901597518_item	2913265	et	4	main
naisega	doc_873901597518_item	2913266	et	3	main
mõistniku	doc_873901597519_item	2913310	et	4	main
suhteid	doc_873901597519_item	2913311	et	3	main
pearooli	doc_873901597519_item	2913312	et	4	main
inimest	doc_873901597519_item	2913315	et	3	main
tõnu	doc_873901597519_item	2913317	et	4	main
ja	doc_873901597519_item	2913319	et	3	main
parun	doc_873901597519_item	2913320	et	3	main
tõnu	doc_873901597519_item	2913334	et	4	main
on	doc_873901597519_item	2913335	et	4	main
elu	doc_873901597519_item	2913340	et	4	main
arenema	doc_873901597516_item	2912924	et	3	main
loomulikult	doc_873901597516_item	2912926	et	4	main
ta	doc_873901597516_item	2912927	et	4	main
ka	doc_873901597516_item	2912928	et	3	main
moodustab	doc_873901597516_item	2912929	et	3	main
inimesel	doc_873901597516_item	2912948	et	3	main
on	doc_873901597516_item	2912957	et	4	main
eriti	doc_873901597516_item	2912960	et	3	main
naine	doc_873901597517_item	2912974	et	3	main
naine	doc_873901597517_item	2912987	et	3	main
tema	doc_873901597517_item	2912988	et	4	main
ebamuretsev	doc_873901597517_item	2912989	et	3	main
käitumine	doc_873901597517_item	2912990	et	4	main
teeb	doc_873901597517_item	2912991	et	3	main
kannatusi	doc_873901597517_item	2912992	et	4	main
paljudele	doc_873901597517_item	2912993	et	3	main
inimestele	doc_873901597517_item	2912994	et	3	main
tõnule	doc_873901597517_item	2912995	et	4	main
von	doc_873901597517_item	2912996	et	4	main
kremerele	doc_873901597517_item	2912997	et	4	main
juhanule	doc_873901597517_item	2912998	et	4	main
tema	doc_873901597517_item	2912999	et	4	main
õe	doc_873901597517_item	2913000	et	4	main
lapsele	doc_873901597517_item	2913001	et	4	main
aga	doc_873901597517_item	2913002	et	3	main
see	doc_873901597517_item	2913003	et	3	main
ei	doc_873901597517_item	2913004	et	4	main
muretseb	doc_873901597517_item	2913005	et	3	main
teda	doc_873901597517_item	2913006	et	4	main
ta	doc_873901597517_item	2913007	et	4	main
on	doc_873901597517_item	2913008	et	4	main
halb	doc_873901597517_item	2913009	et	3	main
perenaine	doc_873901597517_item	2913010	et	3	main
kõik	doc_873901597517_item	2913011	et	4	main
tema	doc_873901597517_item	2913012	et	4	main
katsumused	doc_873901597517_item	2913013	et	3	main
on	doc_873901597517_item	2913014	et	4	main
lühiajalised	doc_873901597517_item	2913015	et	4	main
lõppus	doc_873901597517_item	2913016	et	4	main
mari	doc_873901597517_item	2913017	et	4	main
lahkub	doc_873901597517_item	2913018	et	3	main
talu	doc_873901597517_item	2913019	et	4	main
ja	doc_873901597517_item	2913020	et	3	main
alustab	doc_873901597517_item	2913021	et	3	main
kahjuks	doc_873901597517_item	2913026	et	4	main
mõnides	doc_873901597517_item	2913031	et	4	main
naisest	doc_873901597517_item	2913032	et	3	main
ta	doc_873901597517_item	2913034	et	4	main
otsast	doc_873901597517_item	2913024	et	4	main
kaasaagses	doc_873901597517_item	2913037	et	4	main
on	doc_873901597517_item	2913041	et	4	main
kohtuvad	doc_873901597517_item	2913044	et	4	main
seetõttu	doc_873901597517_item	2913047	et	3	main
naine	doc_873901597518_item	2913063	et	3	main
ma	doc_873901597518_item	2913064	et	3	main
arvan	doc_873901597518_item	2913065	et	3	main
et	doc_873901597518_item	2913066	et	3	main
mari	doc_873901597518_item	2913067	et	4	main
oli	doc_873901597518_item	2913068	et	3	main
üks	doc_873901597518_item	2913069	et	3	main
nendest	doc_873901597518_item	2913070	et	4	main
naistest	doc_873901597518_item	2913071	et	4	main
keda	doc_873901597518_item	2913072	et	4	main
oli	doc_873901597518_item	2913073	et	3	main
väga	doc_873901597518_item	2913074	et	3	main
raske	doc_873901597518_item	2913075	et	4	main
leida	doc_873901597518_item	2913076	et	3	main
ja	doc_873901597518_item	2913077	et	3	main
harva	doc_873901597518_item	2913078	et	4	main
näha	doc_873901597518_item	2913079	et	3	main
siis	doc_873901597518_item	2913080	et	3	main
xviii	doc_873901597518_item	2913081	et	4	main
on	doc_873901597517_item	2913035	et	4	main
probleemid	doc_873901597517_item	2913040	et	3	main
noores	doc_873901597517_item	2913045	et	3	main
ma	doc_873901597517_item	2913048	et	3	main
et	doc_873901597517_item	2913050	et	3	main
film	doc_873901597517_item	2913052	et	3	main
väga	doc_873901597517_item	2913054	et	3	main
kasulik	doc_873901597517_item	2913055	et	3	main
essee	doc_873901597518_item	2913059	et	4	main
ja	doc_873901597518_item	2913061	et	3	main
tänapäevane	doc_873901597518_item	2913062	et	4	main
aga	doc_873901597518_item	2913085	et	3	main
mari	doc_873901597518_item	2913090	et	4	main
üks	doc_873901597518_item	2913097	et	3	main
sajandi	doc_873901597518_item	2913101	et	3	main
mari	doc_873901597518_item	2913108	et	4	main
on	doc_873901597518_item	2913109	et	4	main
väga	doc_873901597518_item	2913110	et	3	main
tal	doc_873901597518_item	2913119	et	3	main
noore	doc_873901597517_item	2913057	et	3	main
nüüd	doc_873901597518_item	2913083	et	4	main
kõik	doc_873901597518_item	2913087	et	4	main
niisugused	doc_873901597518_item	2913089	et	3	main
polnud	doc_873901597518_item	2913091	et	3	main
nendest	doc_873901597518_item	2913098	et	4	main
kahe	doc_873901597518_item	2913100	et	3	main
karakter	doc_873901597518_item	2913112	et	3	main
ta	doc_873901597518_item	2913114	et	4	main
väga	doc_873901597518_item	2913116	et	3	main
iseseisev	doc_873901597518_item	2913117	et	3	main
tahe	doc_873901597518_item	2913123	et	4	main
ka	doc_873901597518_item	2913125	et	3	main
mehed	doc_873901597518_item	2913127	et	3	main
võiksid	doc_873901597518_item	2913128	et	4	main
kadestada	doc_873901597518_item	2913129	et	3	main
juhtunud	doc_873901597518_item	2913146	et	4	main
näiteks	doc_873901597518_item	2913147	et	4	main
nii	doc_873901597518_item	2913151	et	3	main
on	doc_873901597518_item	2913165	et	4	main
sellest	doc_873901597518_item	2913224	et	4	main
peetub	doc_873901597518_item	2913226	et	3	main
rääkida	doc_873901597518_item	2913228	et	3	main
peab	doc_873901597518_item	2913232	et	4	main
ja	doc_873901597518_item	2913233	et	3	main
et	doc_873901597518_item	2913235	et	3	main
väga	doc_873901597518_item	2913242	et	3	main
tänapäevase	doc_873901597518_item	2913253	et	4	main
on	doc_873901597518_item	2913260	et	4	main
nüüd	doc_873901597518_item	2913262	et	4	main
ta	doc_873901597518_item	2913268	et	4	main
ei	doc_873901597519_item	2913328	et	4	main
ole	doc_873901597519_item	2913329	et	4	main
kogu	doc_873901597519_item	2913339	et	4	main
hukatus	doc_873901597519_item	2913345	et	4	main
saabub	doc_873901597519_item	2913346	et	3	main
kui	doc_873901597519_item	2913348	et	3	main
prillup	doc_873901597519_item	2913349	et	4	main
öösel	doc_873901597519_item	2913355	et	4	main
võimalus	doc_873901597519_item	2913364	et	3	main
teenida	doc_873901597519_item	2913366	et	3	main
kui	doc_873901597519_item	2913367	et	3	main
tõnu	doc_873901597519_item	2913368	et	4	main
ka	doc_873901597519_item	2913369	et	3	main
piimamehena	doc_873901597519_item	2913370	et	3	main
see	doc_873901597519_item	2913375	et	3	main
kui	doc_873901597519_item	2913378	et	3	main
üks	doc_873901597519_item	2913379	et	3	main
talle	doc_873901597519_item	2913388	et	4	main
tähtis	doc_873901597519_item	2913389	et	4	main
suure	doc_873901597519_item	2913425	et	3	main
sõlmides	doc_873901597519_item	2913430	et	4	main
aga	doc_873901597519_item	2913431	et	3	main
oli	doc_873901597519_item	2913432	et	3	main
juba	doc_873901597519_item	2913433	et	3	main
hilja	doc_873901597519_item	2913434	et	3	main
see	doc_873901597519_item	2913435	et	3	main
teos	doc_873901597519_item	2913436	et	4	main
õpetab	doc_873901597519_item	2913437	et	3	main
hindama	doc_873901597519_item	2913442	et	3	main
mida	doc_873901597519_item	2913444	et	4	main
kirjutatud	doc_873901597520_item	2913458	et	4	main
saja	doc_873901597520_item	2913460	et	4	main
alguses	doc_873901597520_item	2913461	et	4	main
aga	doc_873901597520_item	2913462	et	3	main
et	doc_873901597520_item	2913467	et	3	main
tänapäevaseid	doc_873901597520_item	2913477	et	4	main
ja	doc_873901597520_item	2913478	et	3	main
peategelane	doc_873901597520_item	2913482	et	3	main
luba	doc_873901597520_item	2913495	et	4	main
teha	doc_873901597520_item	2913521	et	3	main
kuula	doc_873901597520_item	2913527	et	4	main
näiteks	doc_873901597520_item	2913529	et	4	main
ei	doc_873901597520_item	2913531	et	4	main
saada	doc_873901597520_item	2913544	et	4	main
ta	doc_873901597520_item	2913545	et	4	main
aga	doc_873901597520_item	2913551	et	3	main
tal	doc_873901597520_item	2913552	et	3	main
ei	doc_873901597520_item	2913553	et	4	main
marit	doc_873901597520_item	2913559	et	3	main
nagu	doc_873901597520_item	2913560	et	3	main
tänapäevast	doc_873901597520_item	2913561	et	4	main
peaaegu	doc_873901597518_item	2913086	et	3	main
naised	doc_873901597518_item	2913088	et	3	main
romaanis	doc_873901597518_item	2913113	et	3	main
on	doc_873901597518_item	2913120	et	4	main
nii	doc_873901597518_item	2913121	et	3	main
mõned	doc_873901597518_item	2913126	et	3	main
oskab	doc_873901597518_item	2913135	et	3	main
trojani	doc_873901597518_item	2913148	et	4	main
tänapäevased	doc_873901597518_item	2913153	et	4	main
peetuvad	doc_873901597518_item	2913156	et	4	main
väga	doc_873901597518_item	2913158	et	3	main
tähtsaks	doc_873901597518_item	2913159	et	4	main
ja	doc_873901597518_item	2913160	et	3	main
ka	doc_873901597518_item	2913166	et	3	main
lapse-moodi	doc_873901597518_item	2913168	et	4	main
mõttes	doc_873901597518_item	2913170	et	3	main
et	doc_873901597518_item	2913171	et	3	main
ta	doc_873901597518_item	2913172	et	4	main
muuretu	doc_873901597518_item	2913176	et	4	main
aeg	doc_873901597518_item	2913181	et	3	main
tagasihoidlik	doc_873901597518_item	2913218	et	3	main
tugev	doc_873901597518_item	2913122	et	4	main
et	doc_873901597518_item	2913124	et	3	main
on	doc_873901597518_item	2913131	et	4	main
ilus	doc_873901597518_item	2913133	et	4	main
meestele	doc_873901597518_item	2913136	et	4	main
meeldida	doc_873901597518_item	2913137	et	3	main
niisuguste	doc_873901597518_item	2913138	et	3	main
alati	doc_873901597518_item	2913142	et	4	main
ja	doc_873901597518_item	2913144	et	3	main
naised	doc_873901597518_item	2913154	et	3	main
natukene	doc_873901597518_item	2913167	et	4	main
selles	doc_873901597518_item	2913169	et	4	main
alati	doc_873901597518_item	2913173	et	4	main
ja	doc_873901597518_item	2913175	et	3	main
ta	doc_873901597518_item	2913184	et	4	main
on	doc_873901597518_item	2913185	et	4	main
ka	doc_873901597518_item	2913186	et	3	main
tark	doc_873901597518_item	2913187	et	3	main
ning	doc_873901597518_item	2913188	et	3	main
julge	doc_873901597518_item	2913189	et	4	main
ta	doc_873901597518_item	2913190	et	4	main
oskab	doc_873901597518_item	2913191	et	3	main
mõelda	doc_873901597518_item	2913192	et	4	main
mitte	doc_873901597518_item	2913193	et	3	main
ainult	doc_873901597518_item	2913194	et	4	main
iseennast	doc_873901597518_item	2913195	et	3	main
aga	doc_873901597518_item	2913196	et	3	main
teistest	doc_873901597518_item	2913197	et	4	main
ka	doc_873901597518_item	2913198	et	3	main
saab	doc_873901597518_item	2913199	et	3	main
ta	doc_873901597518_item	2913200	et	4	main
aru	doc_873901597518_item	2913201	et	4	main
et	doc_873901597518_item	2913202	et	3	main
kui	doc_873901597518_item	2913203	et	3	main
midagi	doc_873901597518_item	2913204	et	4	main
temast	doc_873901597518_item	2913205	et	3	main
sõltub	doc_873901597518_item	2913206	et	3	main
peab	doc_873901597518_item	2913207	et	4	main
ta	doc_873901597518_item	2913208	et	4	main
seda	doc_873901597518_item	2913209	et	3	main
tegema	doc_873901597518_item	2913210	et	3	main
igal	doc_873901597518_item	2913211	et	3	main
juhul	doc_873901597518_item	2913212	et	3	main
ta	doc_873901597518_item	2913213	et	4	main
pole	doc_873901597518_item	2913214	et	3	main
nii	doc_873901597518_item	2913215	et	3	main
kõik	doc_873901597518_item	2913220	et	4	main
teised	doc_873901597518_item	2913221	et	4	main
aga	doc_873901597518_item	2913247	et	3	main
naise	doc_873901597518_item	2913254	et	3	main
prototüüp	doc_873901597518_item	2913255	et	3	main
sest	doc_873901597518_item	2913256	et	4	main
iseloomujooned	doc_873901597518_item	2913259	et	3	main
on	doc_873901597518_item	2913276	et	4	main
mis	doc_873901597518_item	2913280	et	4	main
mari	doc_873901597519_item	2913316	et	4	main
prillup	doc_873901597519_item	2913318	et	4	main
seda	doc_873901597518_item	2913230	et	3	main
arvab	doc_873901597518_item	2913234	et	3	main
on	doc_873901597518_item	2913241	et	4	main
mitte	doc_873901597518_item	2913245	et	3	main
kõik	doc_873901597518_item	2913257	et	4	main
need	doc_873901597518_item	2913258	et	3	main
veelgi	doc_873901597518_item	2913269	et	4	main
parem	doc_873901597518_item	2913270	et	4	main
sest	doc_873901597518_item	2913271	et	4	main
pole	doc_873901597518_item	2913272	et	3	main
lahke	doc_873901597518_item	2913277	et	4	main
ja	doc_873901597518_item	2913278	et	3	main
heasüdamlik	doc_873901597518_item	2913279	et	3	main
on	doc_873901597518_item	2913281	et	4	main
täna	doc_873901597518_item	2913282	et	4	main
päeval	doc_873901597518_item	2913283	et	3	main
harv	doc_873901597518_item	2913284	et	3	main
vot	doc_873901597518_item	2913285	et	3	main
niisugune	doc_873901597518_item	2913286	et	3	main
ongi	doc_873901597518_item	2913287	et	4	main
mari	doc_873901597518_item	2913288	et	4	main
võreldes	doc_873901597518_item	2913289	et	4	main
tänapäevase	doc_873901597518_item	2913290	et	4	main
naisega	doc_873901597518_item	2913291	et	3	main
essee	doc_873901597519_item	2913292	et	4	main
mäeküla	doc_873901597519_item	2913293	et	4	main
piimamees	doc_873901597519_item	2913294	et	4	main
on	doc_873901597519_item	2913295	et	4	main
realistlik	doc_873901597519_item	2913296	et	3	main
romaan	doc_873901597519_item	2913297	et	3	main
romaan	doc_873901597519_item	2913298	et	3	main
mäeküla	doc_873901597519_item	2913299	et	4	main
piimamees	doc_873901597519_item	2913300	et	4	main
on	doc_873901597519_item	2913301	et	4	main
psüholoogiline	doc_873901597519_item	2913302	et	4	main
teos	doc_873901597519_item	2913303	et	4	main
selles	doc_873901597519_item	2913304	et	4	main
romaanis	doc_873901597519_item	2913305	et	3	main
on	doc_873901597519_item	2913306	et	4	main
kirjeldatud	doc_873901597519_item	2913307	et	4	main
talupoja	doc_873901597519_item	2913308	et	4	main
ja	doc_873901597519_item	2913309	et	3	main
kolm	doc_873901597519_item	2913314	et	3	main
mari	doc_873901597519_item	2913322	et	4	main
naine	doc_873901597519_item	2913326	et	3	main
meestel	doc_873901597519_item	2913331	et	4	main
end	doc_873901597519_item	2913332	et	4	main
käsutada	doc_873901597519_item	2913333	et	3	main
mees	doc_873901597519_item	2913338	et	4	main
saada	doc_873901597519_item	2913344	et	4	main
olema	doc_873901597519_item	2913358	et	4	main
prillupil	doc_873901597519_item	2913362	et	4	main
ilmub	doc_873901597519_item	2913363	et	3	main
raha	doc_873901597519_item	2913365	et	4	main
läbi	doc_873901597519_item	2913371	et	4	main
kohale	doc_873901597519_item	2913423	et	4	main
ta	doc_873901597519_item	2913427	et	4	main
lepingut	doc_873901597519_item	2913429	et	3	main
on	doc_873901597519_item	2913440	et	4	main
ja	doc_873901597520_item	2913453	et	3	main
oli	doc_873901597520_item	2913457	et	3	main
ütelda	doc_873901597520_item	2913466	et	4	main
tegelased	doc_873901597520_item	2913468	et	3	main
kes	doc_873901597520_item	2913469	et	4	main
mäeküla	doc_873901597520_item	2913473	et	4	main
ei	doc_873901597520_item	2913475	et	4	main
ole	doc_873901597520_item	2913476	et	4	main
vilde	doc_873901597520_item	2913480	et	4	main
mari	doc_873901597520_item	2913484	et	4	main
mari	doc_873901597520_item	2913485	et	4	main
mõtted	doc_873901597520_item	2913486	et	3	main
ja	doc_873901597520_item	2913487	et	3	main
usu	doc_873901597520_item	2913488	et	4	main
amoraalne	doc_873901597520_item	2913525	et	3	main
mõistnikule	doc_873901597520_item	2913533	et	4	main
marit	doc_873901597520_item	2913538	et	3	main
pakub	doc_873901597520_item	2913540	et	3	main
mäeküla	doc_873901597520_item	2913542	et	4	main
piimameheks	doc_873901597520_item	2913543	et	3	main
kremerile	doc_873901597520_item	2913548	et	4	main
tulla	doc_873901597520_item	2913549	et	3	main
võimalikust	doc_873901597520_item	2913556	et	4	main
see	doc_873901597520_item	2913557	et	3	main
ei	doc_873901597520_item	2913567	et	4	main
mitte	doc_873901597520_item	2913574	et	3	main
mida	doc_873901597520_item	2913577	et	4	main
mari	doc_873901597520_item	2913622	et	4	main
oma	doc_873901597520_item	2913629	et	4	main
ütelda	doc_873901597520_item	2913641	et	4	main
et	doc_873901597520_item	2913642	et	3	main
essee	doc_873901597521_item	2913647	et	4	main
ta	doc_873901597521_item	2913661	et	4	main
pidada	doc_873901597521_item	2913671	et	4	main
rikkast	doc_873901597521_item	2913677	et	4	main
olla	doc_873901597521_item	2913678	et	3	main
kremeri	doc_873901597521_item	2913681	et	4	main
prillupi	doc_873901597521_item	2913683	et	4	main
müüa	doc_873901597521_item	2913690	et	3	main
marit	doc_873901597521_item	2913692	et	3	main
aimugi	doc_873901597521_item	2913695	et	4	main
koatab	doc_873901597521_item	2913703	et	4	main
kohe	doc_873901597521_item	2913712	et	4	main
pärast	doc_873901597521_item	2913729	et	4	main
otsus	doc_873901597521_item	2913733	et	3	main
võib	doc_873901597521_item	2913735	et	3	main
jääta	doc_873901597521_item	2913736	et	4	main
või	doc_873901597521_item	2913739	et	4	main
linna	doc_873901597521_item	2913741	et	4	main
see	doc_873901597521_item	2913745	et	3	main
tal	doc_873901597521_item	2913749	et	3	main
raske	doc_873901597521_item	2913763	et	4	main
on	doc_873901597521_item	2913764	et	4	main
naised	doc_873901597521_item	2913768	et	3	main
aga	doc_873901597522_item	2913809	et	3	main
ole	doc_873901597522_item	2913812	et	4	main
nii	doc_873901597522_item	2913814	et	3	main
mari	doc_873901597522_item	2913817	et	4	main
nagu	doc_873901597522_item	2913818	et	3	main
elab	doc_873901597522_item	2913819	et	3	main
tulevikus	doc_873901597522_item	2913820	et	4	main
lubanud	doc_873901597519_item	2913330	et	4	main
õnnetu	doc_873901597519_item	2913336	et	4	main
ta	doc_873901597519_item	2913341	et	4	main
tahtis	doc_873901597519_item	2913342	et	3	main
ja	doc_873901597519_item	2913350	et	3	main
kremer	doc_873901597519_item	2913351	et	4	main
mari	doc_873901597519_item	2913356	et	4	main
põrub	doc_873901597519_item	2913372	et	3	main
kõik	doc_873901597519_item	2913376	et	4	main
kõik	doc_873901597519_item	2913386	et	4	main
saab	doc_873901597519_item	2913392	et	3	main
kõik	doc_873901597519_item	2913393	et	4	main
aru	doc_873901597519_item	2913394	et	4	main
hakkab	doc_873901597519_item	2913395	et	3	main
siis	doc_873901597519_item	2913396	et	3	main
üha	doc_873901597519_item	2913397	et	3	main
rohkem	doc_873901597519_item	2913398	et	4	main
jooma	doc_873901597519_item	2913399	et	4	main
mäeküla	doc_873901597519_item	2913400	et	4	main
piimamees	doc_873901597519_item	2913401	et	4	main
on	doc_873901597519_item	2913402	et	4	main
realistlik	doc_873901597519_item	2913403	et	3	main
romaan	doc_873901597519_item	2913404	et	3	main
mis	doc_873901597519_item	2913405	et	4	main
võiks	doc_873901597519_item	2913406	et	4	main
tegutseda	doc_873901597519_item	2913407	et	3	main
tänapäevalgi	doc_873901597519_item	2913408	et	4	main
tänapäevadel	doc_873901597519_item	2913409	et	3	main
on	doc_873901597519_item	2913410	et	4	main
palju	doc_873901597519_item	2913411	et	4	main
samasuguseid	doc_873901597519_item	2913412	et	3	main
juhti	doc_873901597519_item	2913413	et	4	main
sest	doc_873901597519_item	2913414	et	4	main
kõige	doc_873901597519_item	2913415	et	4	main
tähtsam	doc_873901597519_item	2913416	et	4	main
rooli	doc_873901597519_item	2913417	et	4	main
mängivad	doc_873901597519_item	2913418	et	4	main
raha	doc_873901597519_item	2913419	et	4	main
pärast	doc_873901597519_item	2913420	et	4	main
millise	doc_873901597519_item	2913424	et	3	main
tegi	doc_873901597519_item	2913428	et	4	main
vaja	doc_873901597519_item	2913441	et	4	main
see	doc_873901597519_item	2913443	et	3	main
mari	doc_873901597520_item	2913452	et	4	main
romaan	doc_873901597520_item	2913456	et	3	main
me	doc_873901597520_item	2913463	et	4	main
on	doc_873901597520_item	2913470	et	4	main
on	doc_873901597520_item	2913489	et	4	main
kaasaeglased	doc_873901597520_item	2913490	et	3	main
meie	doc_873901597520_item	2913491	et	4	main
sest	doc_873901597520_item	2913522	et	4	main
see	doc_873901597520_item	2913523	et	3	main
tule	doc_873901597520_item	2913532	et	4	main
siis	doc_873901597519_item	2913347	et	3	main
et	doc_873901597519_item	2913354	et	3	main
peab	doc_873901597519_item	2913357	et	4	main
kremeriga	doc_873901597519_item	2913359	et	4	main
selle	doc_873901597519_item	2913360	et	4	main
tundub	doc_873901597519_item	2913374	et	3	main
kohutav	doc_873901597519_item	2913380	et	4	main
mis	doc_873901597519_item	2913387	et	4	main
vastu	doc_873901597519_item	2913361	et	3	main
siis	doc_873901597519_item	2913373	et	3	main
talle	doc_873901597519_item	2913377	et	4	main
unenägu	doc_873901597519_item	2913381	et	4	main
prillup	doc_873901597519_item	2913382	et	4	main
oli	doc_873901597519_item	2913383	et	3	main
kaotanud	doc_873901597519_item	2913384	et	4	main
peaaegu	doc_873901597519_item	2913385	et	3	main
kui	doc_873901597519_item	2913390	et	3	main
ta	doc_873901597519_item	2913391	et	4	main
tõnule	doc_873901597519_item	2913421	et	4	main
vea	doc_873901597519_item	2913426	et	4	main
meid	doc_873901597519_item	2913438	et	4	main
meil	doc_873901597519_item	2913445	et	4	main
on	doc_873901597519_item	2913446	et	4	main
aga	doc_873901597519_item	2913447	et	3	main
mitte	doc_873901597519_item	2913448	et	3	main
unistama	doc_873901597519_item	2913449	et	3	main
rikkusest	doc_873901597519_item	2913450	et	4	main
tänapäevane	doc_873901597520_item	2913454	et	4	main
ei	doc_873901597520_item	2913464	et	4	main
kujutatud	doc_873901597520_item	2913471	et	4	main
pimamees	doc_873901597520_item	2913474	et	4	main
romaanis	doc_873901597520_item	2913481	et	3	main
jõuab	doc_873901597519_item	2913422	et	3	main
et	doc_873901597519_item	2913439	et	3	main
essee	doc_873901597520_item	2913451	et	4	main
naine	doc_873901597520_item	2913455	et	3	main
xx	doc_873901597520_item	2913459	et	4	main
saa	doc_873901597520_item	2913465	et	4	main
romaanis	doc_873901597520_item	2913472	et	3	main
aktuaalseid	doc_873901597520_item	2913479	et	3	main
on	doc_873901597520_item	2913483	et	4	main
ajas	doc_873901597520_item	2913492	et	4	main
naine	doc_873901597520_item	2913493	et	3	main
ei	doc_873901597520_item	2913494	et	4	main
kedagi	doc_873901597520_item	2913496	et	4	main
talle	doc_873901597520_item	2913497	et	4	main
ütelda	doc_873901597520_item	2913498	et	4	main
mida	doc_873901597520_item	2913499	et	4	main
teha	doc_873901597520_item	2913500	et	3	main
ja	doc_873901597520_item	2913501	et	3	main
mari	doc_873901597520_item	2913502	et	4	main
ka	doc_873901597520_item	2913503	et	3	main
ei	doc_873901597520_item	2913504	et	4	main
luba	doc_873901597520_item	2913505	et	4	main
tõnu	doc_873901597520_item	2913506	et	4	main
ja	doc_873901597520_item	2913507	et	3	main
ulrich	doc_873901597520_item	2913508	et	4	main
von	doc_873901597520_item	2913509	et	4	main
kremer	doc_873901597520_item	2913510	et	4	main
püüavad	doc_873901597520_item	2913511	et	3	main
marit	doc_873901597520_item	2913512	et	3	main
juhatada	doc_873901597520_item	2913513	et	3	main
aga	doc_873901597520_item	2913514	et	3	main
mari	doc_873901597520_item	2913515	et	4	main
mõtleb	doc_873901597520_item	2913516	et	3	main
et	doc_873901597520_item	2913517	et	3	main
saa	doc_873901597520_item	2913519	et	4	main
seda	doc_873901597520_item	2913520	et	3	main
ei	doc_873901597520_item	2913518	et	4	main
ja	doc_873901597520_item	2913526	et	3	main
ta	doc_873901597520_item	2913530	et	4	main
lõppus	doc_873901597520_item	2913550	et	4	main
iseloomustab	doc_873901597520_item	2913558	et	4	main
osa	doc_873901597520_item	2913565	et	4	main
või	doc_873901597520_item	2913573	et	4	main
aga	doc_873901597520_item	2913615	et	3	main
tõnut	doc_873901597520_item	2913618	et	4	main
ja	doc_873901597520_item	2913619	et	3	main
lastest	doc_873901597520_item	2913620	et	4	main
on	doc_873901597520_item	2913524	et	4	main
neid	doc_873901597520_item	2913528	et	4	main
kuidas	doc_873901597520_item	2913534	et	3	main
kremer	doc_873901597520_item	2913536	et	4	main
ja	doc_873901597520_item	2913539	et	3	main
on	doc_873901597520_item	2913546	et	4	main
ole	doc_873901597520_item	2913554	et	4	main
naist	doc_873901597520_item	2913566	et	3	main
ja	doc_873901597520_item	2913575	et	3	main
tahavad	doc_873901597520_item	2913579	et	3	main
ja	doc_873901597520_item	2913580	et	3	main
mida	doc_873901597520_item	2913581	et	4	main
on	doc_873901597520_item	2913582	et	4	main
nendale	doc_873901597520_item	2913583	et	4	main
kasulik	doc_873901597520_item	2913584	et	3	main
aga	doc_873901597520_item	2913585	et	3	main
mari	doc_873901597520_item	2913586	et	4	main
kardab	doc_873901597520_item	2913587	et	4	main
pattu	doc_873901597520_item	2913588	et	4	main
aga	doc_873901597520_item	2913589	et	3	main
see	doc_873901597520_item	2913590	et	3	main
ei	doc_873901597520_item	2913591	et	4	main
tähenda	doc_873901597520_item	2913592	et	4	main
et	doc_873901597520_item	2913593	et	3	main
mari	doc_873901597520_item	2913594	et	4	main
ei	doc_873901597520_item	2913595	et	4	main
ole	doc_873901597520_item	2913596	et	4	main
tänapäevane	doc_873901597520_item	2913597	et	4	main
sest	doc_873901597520_item	2913598	et	4	main
tema	doc_873901597520_item	2913599	et	4	main
tegevused	doc_873901597520_item	2913600	et	4	main
on	doc_873901597520_item	2913601	et	4	main
paremad	doc_873901597520_item	2913602	et	4	main
ja	doc_873901597520_item	2913603	et	3	main
õiged	doc_873901597520_item	2913604	et	3	main
mari	doc_873901597520_item	2913605	et	4	main
on	doc_873901597520_item	2913606	et	4	main
noor	doc_873901597520_item	2913607	et	3	main
naine	doc_873901597520_item	2913608	et	3	main
meie	doc_873901597520_item	2913609	et	4	main
ajal	doc_873901597520_item	2913610	et	4	main
von	doc_873901597520_item	2913535	et	4	main
kutsub	doc_873901597520_item	2913537	et	3	main
tõnule	doc_873901597520_item	2913541	et	4	main
nõus	doc_873901597520_item	2913547	et	4	main
teist	doc_873901597520_item	2913555	et	4	main
suurem	doc_873901597520_item	2913564	et	4	main
kui	doc_873901597520_item	2913569	et	3	main
mari	doc_873901597520_item	2913616	et	4	main
me	doc_873901597520_item	2913639	et	4	main
tänapäevane	doc_873901597520_item	2913645	et	4	main
naine	doc_873901597520_item	2913646	et	3	main
romaanis	doc_873901597521_item	2913652	et	3	main
mari	doc_873901597521_item	2913655	et	4	main
noor	doc_873901597521_item	2913657	et	3	main
veidi	doc_873901597521_item	2913658	et	3	main
salapärane	doc_873901597521_item	2913659	et	4	main
naine	doc_873901597521_item	2913660	et	3	main
lugu	doc_873901597521_item	2913670	et	4	main
prillup	doc_873901597521_item	2913675	et	4	main
tahab	doc_873901597521_item	2913676	et	3	main
ümber	doc_873901597521_item	2913686	et	3	main
prillupile	doc_873901597521_item	2913689	et	4	main
temale	doc_873901597521_item	2913691	et	3	main
ja	doc_873901597521_item	2913702	et	3	main
ja	doc_873901597521_item	2913705	et	3	main
tunnistuse	doc_873901597521_item	2913707	et	4	main
ei	doc_873901597521_item	2913709	et	4	main
soovinud	doc_873901597521_item	2913710	et	4	main
minna	doc_873901597521_item	2913711	et	3	main
ei	doc_873901597521_item	2913721	et	4	main
ta	doc_873901597521_item	2913723	et	4	main
prillupi	doc_873901597521_item	2913730	et	4	main
kindel	doc_873901597521_item	2913732	et	3	main
juurde	doc_873901597521_item	2913738	et	4	main
sõidab	doc_873901597521_item	2913743	et	3	main
ta	doc_873901597521_item	2913755	et	4	main
on	doc_873901597521_item	2913756	et	4	main
nagu	doc_873901597521_item	2913758	et	3	main
ta	doc_873901597521_item	2913759	et	4	main
teada	doc_873901597521_item	2913765	et	3	main
tavaline	doc_873901597522_item	2913807	et	4	main
sest	doc_873901597522_item	2913821	et	4	main
on	doc_873901597522_item	2913823	et	4	main
on	doc_873901597522_item	2913837	et	4	main
see	doc_873901597522_item	2913838	et	3	main
et	doc_873901597522_item	2913839	et	3	main
mari	doc_873901597522_item	2913840	et	4	main
olid	doc_873901597522_item	2913853	et	4	main
tagasihoidlikud	doc_873901597522_item	2913855	et	3	main
vaiksed	doc_873901597522_item	2913857	et	3	main
ei	doc_873901597522_item	2913859	et	4	main
suhelda	doc_873901597522_item	2913871	et	4	main
kui	doc_873901597522_item	2913872	et	3	main
missugused	doc_873901597522_item	2913879	et	3	main
meeldi	doc_873901597522_item	2913882	et	4	main
nägu	doc_873901597522_item	2913893	et	4	main
perede	doc_873901597522_item	2913900	et	3	main
ei	doc_873901597522_item	2913906	et	4	main
meeldi	doc_873901597522_item	2913907	et	4	main
naist	doc_873901597520_item	2913562	et	3	main
tänapäeval	doc_873901597520_item	2913563	et	3	main
mõtle	doc_873901597520_item	2913568	et	4	main
tegevus	doc_873901597520_item	2913570	et	4	main
on	doc_873901597520_item	2913571	et	4	main
patt	doc_873901597520_item	2913572	et	3	main
teevad	doc_873901597520_item	2913576	et	3	main
nad	doc_873901597520_item	2913578	et	3	main
ainult	doc_873901597520_item	2913613	et	4	main
sest	doc_873901597520_item	2913621	et	4	main
on	doc_873901597520_item	2913623	et	4	main
julge	doc_873901597520_item	2913624	et	4	main
ja	doc_873901597520_item	2913625	et	3	main
arvamus	doc_873901597520_item	2913630	et	3	main
on	doc_873901597520_item	2913632	et	4	main
endale	doc_873901597520_item	2913636	et	4	main
hinda	doc_873901597520_item	2913637	et	4	main
sellepärast	doc_873901597520_item	2913638	et	3	main
on	doc_873901597520_item	2913644	et	4	main
mari	doc_873901597521_item	2913648	et	4	main
ja	doc_873901597521_item	2913649	et	3	main
tänapäeva	doc_873901597521_item	2913650	et	4	main
naine	doc_873901597521_item	2913651	et	3	main
piimamees	doc_873901597521_item	2913654	et	4	main
on	doc_873901597521_item	2913656	et	4	main
ta	doc_873901597521_item	2913667	et	4	main
põhitegevus	doc_873901597521_item	2913679	et	4	main
kremer	doc_873901597521_item	2913687	et	4	main
pole	doc_873901597521_item	2913694	et	3	main
et	doc_873901597521_item	2913696	et	3	main
ta	doc_873901597521_item	2913697	et	4	main
müüb	doc_873901597521_item	2913698	et	3	main
mari	doc_873901597521_item	2913708	et	4	main
armasta	doc_873901597521_item	2913722	et	4	main
kremeri	doc_873901597521_item	2913737	et	4	main
sõidama	doc_873901597521_item	2913740	et	4	main
linna	doc_873901597521_item	2913744	et	4	main
räägib	doc_873901597521_item	2913746	et	3	main
sellest	doc_873901597521_item	2913747	et	4	main
armastab	doc_873901597521_item	2913753	et	3	main
on	doc_873901597521_item	2913760	et	4	main
ja	doc_873901597521_item	2913761	et	3	main
kõik	doc_873901597521_item	2913766	et	4	main
arvates	doc_873901597521_item	2913770	et	4	main
samasugused	doc_873901597521_item	2913772	et	3	main
keegi	doc_873901597521_item	2913775	et	4	main
ei	doc_873901597522_item	2913811	et	4	main
tänapäevane	doc_873901597522_item	2913825	et	4	main
tänapäevane	doc_873901597522_item	2913842	et	4	main
oma	doc_873901597522_item	2913845	et	4	main
õiguste	doc_873901597522_item	2913846	et	4	main
eest	doc_873901597522_item	2913847	et	4	main
naised	doc_873901597522_item	2913848	et	3	main
tema	doc_873901597522_item	2913851	et	4	main
saanud	doc_873901597522_item	2913860	et	4	main
mehega	doc_873901597522_item	2913862	et	3	main
ei	doc_873901597522_item	2913866	et	4	main
tõnule	doc_873901597522_item	2913868	et	4	main
halvasti	doc_873901597522_item	2913869	et	3	main
temaga	doc_873901597522_item	2913870	et	3	main
asjud	doc_873901597522_item	2913878	et	4	main
ei	doc_873901597522_item	2913881	et	4	main
ta	doc_873901597522_item	2913883	et	4	main
uhke	doc_873901597522_item	2913890	et	4	main
eest	doc_873901597522_item	2913901	et	4	main
et	doc_873901597522_item	2913924	et	3	main
pere	doc_873901597522_item	2913926	et	4	main
selles	doc_873901597522_item	2913935	et	4	main
peres	doc_873901597522_item	2913936	et	3	main
on	doc_873901597522_item	2913945	et	4	main
tark	doc_873901597522_item	2913946	et	3	main
ja	doc_873901597522_item	2913947	et	3	main
on	doc_873901597522_item	2913953	et	4	main
iga	doc_873901597522_item	2913955	et	4	main
kui	doc_873901597522_item	2913957	et	3	main
ta	doc_873901597522_item	2913958	et	4	main
räägib	doc_873901597522_item	2913959	et	3	main
temal	doc_873901597522_item	2913967	et	3	main
ajal	doc_873901597522_item	2913968	et	4	main
nii	doc_873901597522_item	2913971	et	3	main
sest	doc_873901597522_item	2913973	et	4	main
mõelda	doc_873901597522_item	2913978	et	4	main
nejud	doc_873901597520_item	2913611	et	4	main
mõtlevad	doc_873901597520_item	2913612	et	4	main
ennast	doc_873901597520_item	2913614	et	4	main
hoiab	doc_873901597520_item	2913617	et	3	main
lahke	doc_873901597520_item	2913626	et	4	main
maril	doc_873901597520_item	2913627	et	3	main
ta	doc_873901597520_item	2913631	et	4	main
tark	doc_873901597520_item	2913633	et	3	main
ja	doc_873901597520_item	2913634	et	3	main
teab	doc_873901597520_item	2913635	et	3	main
ta	doc_873901597520_item	2913643	et	4	main
mäeküla	doc_873901597521_item	2913653	et	4	main
on	doc_873901597521_item	2913662	et	4	main
ka	doc_873901597521_item	2913663	et	3	main
väga	doc_873901597521_item	2913664	et	3	main
enesekindel	doc_873901597521_item	2913665	et	3	main
ja	doc_873901597521_item	2913666	et	3	main
oskab	doc_873901597521_item	2913668	et	3	main
endast	doc_873901597521_item	2913669	et	4	main
tõnu	doc_873901597521_item	2913674	et	4	main
toimus	doc_873901597521_item	2913680	et	3	main
ja	doc_873901597521_item	2913682	et	3	main
sõlmitud	doc_873901597521_item	2913684	et	4	main
pakkus	doc_873901597521_item	2913688	et	3	main
tal	doc_873901597521_item	2913693	et	3	main
maha	doc_873901597521_item	2913699	et	4	main
südame	doc_873901597521_item	2913706	et	3	main
on	doc_873901597520_item	2913628	et	4	main
saame	doc_873901597520_item	2913640	et	4	main
tema	doc_873901597521_item	2913672	et	4	main
mees	doc_873901597521_item	2913673	et	4	main
lepingu	doc_873901597521_item	2913685	et	3	main
oma	doc_873901597521_item	2913700	et	4	main
naise	doc_873901597521_item	2913701	et	3	main
inimväärikuse	doc_873901597521_item	2913704	et	4	main
kremeri	doc_873901597521_item	2913713	et	4	main
juurde	doc_873901597521_item	2913714	et	4	main
marile	doc_873901597521_item	2913715	et	3	main
küll	doc_873901597521_item	2913716	et	4	main
kremer	doc_873901597521_item	2913717	et	4	main
meeldib	doc_873901597521_item	2913718	et	3	main
aga	doc_873901597521_item	2913719	et	3	main
lõpuks	doc_873901597521_item	2913720	et	4	main
kumbagi	doc_873901597521_item	2913724	et	4	main
mis	doc_873901597521_item	2913726	et	4	main
ta	doc_873901597521_item	2913742	et	4	main
et	doc_873901597521_item	2913748	et	3	main
on	doc_873901597521_item	2913750	et	4	main
eneseväärikus	doc_873901597521_item	2913751	et	4	main
vabadust	doc_873901597521_item	2913754	et	4	main
selline	doc_873901597521_item	2913757	et	4	main
minu	doc_873901597521_item	2913769	et	3	main
on	doc_873901597521_item	2913771	et	4	main
kui	doc_873901597521_item	2913773	et	3	main
elas	doc_873901597521_item	2913797	et	3	main
see	doc_873901597522_item	2913810	et	3	main
mõtlen	doc_873901597522_item	2913815	et	3	main
ma	doc_873901597522_item	2913827	et	3	main
naine	doc_873901597522_item	2913843	et	3	main
kes	doc_873901597522_item	2913849	et	4	main
ajal	doc_873901597522_item	2913852	et	4	main
ja	doc_873901597522_item	2913856	et	3	main
nad	doc_873901597522_item	2913858	et	3	main
aga	doc_873901597522_item	2913864	et	3	main
tõnu	doc_873901597522_item	2913873	et	4	main
talle	doc_873901597522_item	2913880	et	4	main
vaid	doc_873901597522_item	2913886	et	3	main
ja	doc_873901597522_item	2913891	et	3	main
koike	doc_873901597522_item	2913898	et	4	main
võivad	doc_873901597522_item	2913921	et	4	main
mehest	doc_873901597522_item	2913934	et	4	main
mari	doc_873901597522_item	2913944	et	4	main
tal	doc_873901597522_item	2913952	et	3	main
tavalised	doc_873901597522_item	2913963	et	4	main
olnud	doc_873901597522_item	2913976	et	4	main
ja	doc_873901597522_item	2913985	et	3	main
marile	doc_873901597522_item	2913989	et	3	main
ei	doc_873901597522_item	2913990	et	4	main
ja	doc_873901597522_item	2913999	et	3	main
mida	doc_873901597522_item	2914002	et	4	main
tahab	doc_873901597522_item	2914004	et	3	main
on	doc_873901597522_item	2914010	et	4	main
ja	doc_873901597522_item	2914012	et	3	main
mees	doc_873901597522_item	2914021	et	4	main
on	doc_873901597522_item	2914025	et	4	main
naised	doc_873901597522_item	2914035	et	3	main
mari	doc_873901597523_item	2914046	et	4	main
tänapäevane	doc_873901597523_item	2914057	et	4	main
naine	doc_873901597523_item	2914058	et	3	main
ja	doc_873901597523_item	2914059	et	3	main
leida	doc_873901597523_item	2914060	et	3	main
oli	doc_873901597523_item	2914064	et	3	main
elas	doc_873901597523_item	2914067	et	3	main
19	doc_873901597523_item	2914069	et	2	main
saanud	doc_873901597523_item	2914075	et	4	main
niisuguselt	doc_873901597523_item	2914090	et	4	main
lähedases	doc_873901597523_item	2914123	et	3	main
aga	doc_873901597523_item	2914125	et	3	main
oli	doc_873901597523_item	2914127	et	3	main
olen	doc_873901597523_item	2914132	et	3	main
ta	doc_873901597523_item	2914135	et	4	main
tegi	doc_873901597523_item	2914136	et	4	main
pere	doc_873901597523_item	2914143	et	4	main
meest	doc_873901597521_item	2913725	et	4	main
tõttu	doc_873901597521_item	2913727	et	4	main
sünnib	doc_873901597521_item	2913728	et	3	main
surma	doc_873901597521_item	2913731	et	4	main
mari	doc_873901597521_item	2913734	et	4	main
ta	doc_873901597521_item	2913752	et	4	main
liiga	doc_873901597521_item	2913762	et	4	main
tänapäeva	doc_873901597521_item	2913767	et	4	main
mari	doc_873901597521_item	2913774	et	4	main
ei	doc_873901597521_item	2913776	et	4	main
taha	doc_873901597521_item	2913777	et	4	main
teisele	doc_873901597521_item	2913778	et	4	main
alluma	doc_873901597521_item	2913779	et	3	main
ja	doc_873901597521_item	2913780	et	3	main
kõik	doc_873901597521_item	2913781	et	4	main
tahavad	doc_873901597521_item	2913782	et	3	main
vaba	doc_873901597521_item	2913783	et	4	main
olla	doc_873901597521_item	2913784	et	3	main
ta	doc_873901597521_item	2913785	et	4	main
oli	doc_873901597521_item	2913786	et	3	main
julge	doc_873901597521_item	2913787	et	4	main
ja	doc_873901597521_item	2913788	et	3	main
see	doc_873901597521_item	2913789	et	3	main
teeb	doc_873901597521_item	2913790	et	3	main
marit	doc_873901597521_item	2913791	et	3	main
eripäraset	doc_873901597521_item	2913792	et	4	main
selles	doc_873901597521_item	2913793	et	4	main
ajas	doc_873901597521_item	2913794	et	4	main
millises	doc_873901597521_item	2913795	et	3	main
ta	doc_873901597521_item	2913796	et	4	main
essee	doc_873901597522_item	2913798	et	4	main
mari	doc_873901597522_item	2913799	et	4	main
ja	doc_873901597522_item	2913800	et	3	main
tänapäevane	doc_873901597522_item	2913801	et	4	main
naine	doc_873901597522_item	2913802	et	3	main
mari	doc_873901597522_item	2913803	et	4	main
näeb	doc_873901597522_item	2913804	et	3	main
välja	doc_873901597522_item	2913805	et	4	main
nägu	doc_873901597522_item	2913806	et	4	main
talutüdruk	doc_873901597522_item	2913808	et	3	main
päris	doc_873901597522_item	2913813	et	4	main
et	doc_873901597522_item	2913816	et	3	main
ta	doc_873901597522_item	2913822	et	4	main
nagu	doc_873901597522_item	2913824	et	3	main
võin	doc_873901597522_item	2913828	et	3	main
mitu	doc_873901597522_item	2913830	et	4	main
põhjusi	doc_873901597522_item	2913831	et	3	main
ma	doc_873901597522_item	2913833	et	3	main
mõtlen	doc_873901597522_item	2913834	et	3	main
nii	doc_873901597522_item	2913835	et	3	main
eesimene	doc_873901597522_item	2913836	et	4	main
elasid	doc_873901597522_item	2913850	et	4	main
väga	doc_873901597522_item	2913854	et	3	main
vaidlema	doc_873901597522_item	2913863	et	3	main
sundib	doc_873901597522_item	2913874	et	4	main
sest	doc_873901597522_item	2913887	et	4	main
ta	doc_873901597522_item	2913888	et	4	main
on	doc_873901597522_item	2913889	et	4	main
tänapäevane	doc_873901597522_item	2913894	et	4	main
naine	doc_873901597522_item	2913895	et	3	main
mari	doc_873901597522_item	2913896	et	4	main
teeb	doc_873901597522_item	2913897	et	3	main
teha	doc_873901597522_item	2913922	et	3	main
päevadel	doc_873901597522_item	2913930	et	3	main
mari	doc_873901597522_item	2913937	et	4	main
mitte	doc_873901597522_item	2913941	et	3	main
naised	doc_873901597522_item	2913964	et	3	main
kes	doc_873901597522_item	2913965	et	4	main
olnud	doc_873901597522_item	2913970	et	4	main
nendele	doc_873901597522_item	2913974	et	4	main
ei	doc_873901597522_item	2913975	et	4	main
palju	doc_873901597522_item	2913979	et	4	main
meeldinud	doc_873901597522_item	2913991	et	4	main
eest	doc_873901597522_item	2913998	et	4	main
ta	doc_873901597522_item	2914009	et	4	main
teda	doc_873901597522_item	2914023	et	4	main
omapärane	doc_873901597522_item	2914027	et	4	main
vapper	doc_873901597522_item	2914031	et	3	main
tänapaevased	doc_873901597522_item	2914034	et	3	main
ta	doc_873901597522_item	2914036	et	4	main
essee	doc_873901597523_item	2914045	et	4	main
tänapäevane	doc_873901597523_item	2914048	et	4	main
ma	doc_873901597523_item	2914050	et	3	main
võib	doc_873901597523_item	2914053	et	3	main
talutüdruk	doc_873901597523_item	2914065	et	3	main
kes	doc_873901597523_item	2914066	et	4	main
talus	doc_873901597523_item	2914068	et	4	main
sajandil	doc_873901597523_item	2914070	et	3	main
sellel	doc_873901597523_item	2914071	et	4	main
mitte	doc_873901597523_item	2914076	et	3	main
midagi	doc_873901597523_item	2914077	et	4	main
ütelda	doc_873901597523_item	2914078	et	4	main
mehele	doc_873901597523_item	2914079	et	3	main
ja	doc_873901597523_item	2914080	et	3	main
käes	doc_873901597523_item	2914085	et	4	main
ei	doc_873901597523_item	2914088	et	4	main
ole	doc_873901597523_item	2914089	et	4	main
temaga	doc_873901597523_item	2914122	et	3	main
lapsed	doc_873901597523_item	2914131	et	3	main
kindel	doc_873901597523_item	2914133	et	3	main
et	doc_873901597523_item	2914134	et	3	main
midagi	doc_873901597523_item	2914151	et	4	main
üldse	doc_873901597523_item	2914152	et	3	main
ja	doc_873901597523_item	2914157	et	3	main
beeta	doc_873901597523_item	2914163	et	4	main
temaga	doc_873901597523_item	2914165	et	3	main
suhelda	doc_873901597523_item	2914167	et	4	main
ta	doc_873901597523_item	2914168	et	4	main
mõtles	doc_873901597523_item	2914200	et	3	main
aga	doc_873901597523_item	2914203	et	3	main
armasta	doc_873901597523_item	2914209	et	4	main
oli	doc_873901597523_item	2914212	et	3	main
mari	doc_873901597524_item	2914241	et	4	main
eesti	doc_873901597524_item	2914245	et	4	main
me	doc_873901597524_item	2914248	et	4	main
filmi	doc_873901597524_item	2914254	et	4	main
aastat	doc_873901597524_item	2914264	et	3	main
on	doc_873901597524_item	2914268	et	4	main
imelikult	doc_873901597524_item	2914269	et	4	main
sarnane	doc_873901597524_item	2914270	et	4	main
eesiplaanil	doc_873901597524_item	2914279	et	4	main
naine	doc_873901597522_item	2913826	et	3	main
nimetada	doc_873901597522_item	2913829	et	3	main
miks	doc_873901597522_item	2913832	et	4	main
nägu	doc_873901597522_item	2913841	et	4	main
voidleb	doc_873901597522_item	2913844	et	4	main
oma	doc_873901597522_item	2913861	et	4	main
mari	doc_873901597522_item	2913865	et	4	main
luba	doc_873901597522_item	2913867	et	4	main
teda	doc_873901597522_item	2913875	et	4	main
teha	doc_873901597522_item	2913876	et	3	main
niisugused	doc_873901597522_item	2913877	et	3	main
ei	doc_873901597522_item	2913884	et	4	main
ole	doc_873901597522_item	2913885	et	4	main
vaper	doc_873901597522_item	2913892	et	4	main
oma	doc_873901597522_item	2913899	et	4	main
ta	doc_873901597522_item	2913902	et	4	main
teeb	doc_873901597522_item	2913903	et	3	main
mida	doc_873901597522_item	2913904	et	4	main
talle	doc_873901597522_item	2913905	et	4	main
et	doc_873901597522_item	2913908	et	3	main
tema	doc_873901597522_item	2913909	et	4	main
lapsed	doc_873901597522_item	2913910	et	3	main
ja	doc_873901597522_item	2913911	et	3	main
tema	doc_873901597522_item	2913912	et	4	main
mees	doc_873901597522_item	2913913	et	4	main
võiksid	doc_873901597522_item	2913914	et	4	main
hasti	doc_873901597522_item	2913915	et	4	main
elaga	doc_873901597522_item	2913916	et	4	main
ja	doc_873901597522_item	2913917	et	3	main
süüatänapäevased	doc_873901597522_item	2913918	et	4	main
naised	doc_873901597522_item	2913919	et	3	main
kaa	doc_873901597522_item	2913920	et	4	main
kõike	doc_873901597522_item	2913923	et	4	main
oleks	doc_873901597522_item	2913927	et	3	main
mari	doc_873901597522_item	2913929	et	4	main
hoolitseb	doc_873901597522_item	2913938	et	3	main
peredest	doc_873901597522_item	2913939	et	3	main
tõnu	doc_873901597522_item	2913942	et	4	main
veel	doc_873901597522_item	2913943	et	4	main
naine	doc_873901597522_item	2913951	et	3	main
elasid	doc_873901597522_item	2913966	et	4	main
targad	doc_873901597522_item	2913972	et	3	main
nad	doc_873901597522_item	2913980	et	3	main
teha	doc_873901597522_item	2913984	et	3	main
laste	doc_873901597522_item	2913986	et	4	main
hoolitseda	doc_873901597522_item	2913988	et	3	main
olla	doc_873901597522_item	2913992	et	3	main
näisega	doc_873901597522_item	2913994	et	4	main
kes	doc_873901597522_item	2913995	et	4	main
sõltub	doc_873901597522_item	2913996	et	3	main
mehe	doc_873901597522_item	2913997	et	3	main
peab	doc_873901597522_item	2914000	et	4	main
ta	doc_873901597522_item	2914017	et	4	main
kuulaks	doc_873901597522_item	2914022	et	4	main
uhke	doc_873901597522_item	2914028	et	4	main
koike	doc_873901597522_item	2914039	et	4	main
pere	doc_873901597522_item	2914042	et	4	main
elaks	doc_873901597522_item	2914043	et	3	main
palju	doc_873901597523_item	2914061	et	4	main
olema	doc_873901597523_item	2914082	et	4	main
see	doc_873901597523_item	2914087	et	3	main
oli	doc_873901597523_item	2914121	et	3	main
niisuguselt	doc_873901597523_item	2914137	et	4	main
tõnu	doc_873901597523_item	2914159	et	4	main
mari	doc_873901597523_item	2914172	et	4	main
nagu	doc_873901597523_item	2914173	et	3	main
nägu	doc_873901597523_item	2914195	et	4	main
teda	doc_873901597523_item	2914210	et	4	main
tark	doc_873901597523_item	2914214	et	3	main
ta	doc_873901597523_item	2914219	et	4	main
nende	doc_873901597522_item	2913925	et	4	main
õnnelik	doc_873901597522_item	2913928	et	3	main
kõik	doc_873901597522_item	2913931	et	4	main
pidi	doc_873901597522_item	2913932	et	4	main
sõltuma	doc_873901597522_item	2913933	et	3	main
aga	doc_873901597522_item	2913940	et	3	main
uhke	doc_873901597522_item	2913948	et	4	main
nagu	doc_873901597522_item	2913949	et	3	main
tanapäevane	doc_873901597522_item	2913950	et	4	main
õigus	doc_873901597522_item	2913954	et	4	main
kord	doc_873901597522_item	2913956	et	4	main
tõnuga	doc_873901597522_item	2913960	et	4	main
mõtlen	doc_873901597522_item	2913961	et	3	main
et	doc_873901597522_item	2913962	et	3	main
ei	doc_873901597522_item	2913969	et	4	main
vaja	doc_873901597522_item	2913977	et	4	main
elasid	doc_873901597522_item	2913981	et	4	main
ainult	doc_873901597522_item	2913993	et	4	main
teha	doc_873901597522_item	2914001	et	3	main
aga	doc_873901597522_item	2914005	et	3	main
et	doc_873901597522_item	2914008	et	3	main
ema	doc_873901597522_item	2914011	et	4	main
näine	doc_873901597522_item	2914013	et	4	main
nagu	doc_873901597522_item	2914014	et	3	main
tanapäevane	doc_873901597522_item	2914015	et	4	main
naine	doc_873901597522_item	2914016	et	3	main
väga	doc_873901597522_item	2914026	et	3	main
nagu	doc_873901597522_item	2914033	et	3	main
hästi	doc_873901597522_item	2914044	et	3	main
et	doc_873901597523_item	2914052	et	3	main
sarnasi	doc_873901597523_item	2914062	et	4	main
ei	doc_873901597523_item	2914074	et	4	main
peaks	doc_873901597523_item	2914081	et	4	main
mehe	doc_873901597523_item	2914084	et	3	main
praegu	doc_873901597523_item	2914086	et	3	main
väga	doc_873901597523_item	2914093	et	3	main
et	doc_873901597522_item	2913982	et	3	main
süüa	doc_873901597522_item	2913983	et	3	main
eest	doc_873901597522_item	2913987	et	4	main
ta	doc_873901597522_item	2914003	et	4	main
talle	doc_873901597522_item	2914006	et	4	main
meeldib	doc_873901597522_item	2914007	et	3	main
ainult	doc_873901597522_item	2914018	et	4	main
tahab	doc_873901597522_item	2914019	et	3	main
et	doc_873901597522_item	2914020	et	3	main
mari	doc_873901597522_item	2914024	et	4	main
tark	doc_873901597522_item	2914029	et	3	main
ja	doc_873901597522_item	2914030	et	3	main
naine	doc_873901597522_item	2914032	et	3	main
võib	doc_873901597522_item	2914037	et	3	main
teha	doc_873901597522_item	2914038	et	3	main
et	doc_873901597522_item	2914040	et	3	main
tema	doc_873901597522_item	2914041	et	4	main
kui	doc_873901597523_item	2914047	et	3	main
naine	doc_873901597523_item	2914049	et	3	main
arvan	doc_873901597523_item	2914051	et	3	main
võrrelda	doc_873901597523_item	2914054	et	4	main
mari	doc_873901597523_item	2914055	et	4	main
ja	doc_873901597523_item	2914056	et	3	main
mari	doc_873901597523_item	2914063	et	4	main
ajal	doc_873901597523_item	2914072	et	4	main
naine	doc_873901597523_item	2914073	et	3	main
täiesti	doc_873901597523_item	2914083	et	3	main
mari	doc_873901597523_item	2914091	et	4	main
oli	doc_873901597523_item	2914092	et	3	main
rõõmus	doc_873901597523_item	2914094	et	4	main
lõõbus	doc_873901597523_item	2914095	et	4	main
naine	doc_873901597523_item	2914096	et	3	main
ta	doc_873901597523_item	2914097	et	4	main
suhtles	doc_873901597523_item	2914098	et	3	main
vabalt	doc_873901597523_item	2914099	et	4	main
mehedega	doc_873901597523_item	2914100	et	4	main
ei	doc_873901597523_item	2914101	et	4	main
kardanud	doc_873901597523_item	2914102	et	4	main
mitte	doc_873901597523_item	2914103	et	3	main
midagi	doc_873901597523_item	2914104	et	4	main
19-sajandi	doc_873901597523_item	2914105	et	3	main
naine	doc_873901597523_item	2914106	et	3	main
tohi	doc_873901597523_item	2914108	et	4	main
ei	doc_873901597523_item	2914107	et	4	main
üldse	doc_873901597523_item	2914109	et	3	main
vaadata	doc_873901597523_item	2914110	et	4	main
erinevatele	doc_873901597523_item	2914111	et	4	main
mehedele	doc_873901597523_item	2914112	et	4	main
aga	doc_873901597523_item	2914113	et	3	main
mari	doc_873901597523_item	2914114	et	4	main
mitte	doc_873901597523_item	2914115	et	3	main
ainult	doc_873901597523_item	2914116	et	4	main
suhtles	doc_873901597523_item	2914117	et	3	main
mõisnikuga	doc_873901597523_item	2914118	et	3	main
vaid	doc_873901597523_item	2914119	et	3	main
ka	doc_873901597523_item	2914120	et	3	main
suhtes	doc_873901597523_item	2914124	et	4	main
sest	doc_873901597523_item	2914138	et	4	main
lapsed	doc_873901597523_item	2914148	et	3	main
saaksid	doc_873901597523_item	2914149	et	4	main
süüa	doc_873901597523_item	2914150	et	3	main
mari	doc_873901597523_item	2914161	et	4	main
oma	doc_873901597523_item	2914170	et	4	main
hind	doc_873901597523_item	2914171	et	3	main
temal	doc_873901597523_item	2914126	et	3	main
oma	doc_873901597523_item	2914128	et	4	main
perekond	doc_873901597523_item	2914129	et	3	main
ja	doc_873901597523_item	2914130	et	3	main
ta	doc_873901597523_item	2914139	et	4	main
tahab	doc_873901597523_item	2914140	et	3	main
et	doc_873901597523_item	2914141	et	3	main
tema	doc_873901597523_item	2914142	et	4	main
tal	doc_873901597523_item	2914153	et	3	main
oli	doc_873901597523_item	2914154	et	3	main
valik	doc_873901597523_item	2914155	et	3	main
mõisniku	doc_873901597523_item	2914156	et	3	main
poolt	doc_873901597523_item	2914160	et	4	main
teas	doc_873901597523_item	2914169	et	4	main
tavaline	doc_873901597523_item	2914174	et	4	main
talutüdruk	doc_873901597523_item	2914175	et	3	main
peaks	doc_873901597523_item	2914176	et	4	main
istuma	doc_873901597523_item	2914177	et	3	main
koodus	doc_873901597523_item	2914178	et	4	main
kasvatama	doc_873901597523_item	2914179	et	4	main
lapsi	doc_873901597523_item	2914180	et	4	main
ja	doc_873901597523_item	2914181	et	3	main
armastama	doc_873901597523_item	2914182	et	3	main
oma	doc_873901597523_item	2914183	et	4	main
abikaasa	doc_873901597523_item	2914184	et	4	main
aga	doc_873901597523_item	2914185	et	3	main
ta	doc_873901597523_item	2914186	et	4	main
alati	doc_873901597523_item	2914187	et	4	main
tahtis	doc_873901597523_item	2914188	et	3	main
elada	doc_873901597523_item	2914189	et	3	main
linnas	doc_873901597523_item	2914190	et	4	main
ja	doc_873901597523_item	2914191	et	3	main
saama	doc_873901597523_item	2914192	et	4	main
kõigi	doc_873901597523_item	2914193	et	4	main
elurõõmu	doc_873901597523_item	2914194	et	4	main
oli	doc_873901597523_item	2914144	et	3	main
õnnelik	doc_873901597523_item	2914145	et	3	main
ja	doc_873901597523_item	2914146	et	3	main
tema	doc_873901597523_item	2914147	et	4	main
abikaasa	doc_873901597523_item	2914158	et	4	main
ei	doc_873901597523_item	2914162	et	4	main
tõnule	doc_873901597523_item	2914164	et	4	main
halvasti	doc_873901597523_item	2914166	et	3	main
tänapäevane	doc_873901597523_item	2914196	et	4	main
naine	doc_873901597523_item	2914197	et	3	main
oma	doc_873901597523_item	2914201	et	4	main
oma	doc_873901597523_item	2914205	et	4	main
abikaasast	doc_873901597523_item	2914206	et	4	main
ta	doc_873901597523_item	2914207	et	4	main
väga	doc_873901597523_item	2914213	et	3	main
tegib	doc_873901597523_item	2914220	et	4	main
märi	doc_873901597523_item	2914235	et	4	main
oli	doc_873901597523_item	2914236	et	3	main
nägu	doc_873901597523_item	2914237	et	4	main
ja	doc_873901597524_item	2914242	et	3	main
naine	doc_873901597524_item	2914244	et	3	main
selle	doc_873901597524_item	2914253	et	4	main
umbes	doc_873901597524_item	2914262	et	4	main
30	doc_873901597524_item	2914263	et	2	main
mari	doc_873901597524_item	2914267	et	4	main
mari	doc_873901597524_item	2914278	et	4	main
teha	doc_873901597524_item	2914285	et	3	main
mida	doc_873901597524_item	2914287	et	4	main
hästi	doc_873901597524_item	2914295	et	3	main
mari	doc_873901597524_item	2914325	et	4	main
kõigipealt	doc_873901597523_item	2914198	et	4	main
ei	doc_873901597523_item	2914208	et	4	main
mari	doc_873901597523_item	2914211	et	4	main
uhtne	doc_873901597523_item	2914215	et	4	main
oma	doc_873901597523_item	2914217	et	4	main
elus	doc_873901597523_item	2914218	et	4	main
mari	doc_873901597523_item	2914199	et	4	main
lapsest	doc_873901597523_item	2914202	et	4	main
mitte	doc_873901597523_item	2914204	et	3	main
naine	doc_873901597523_item	2914216	et	3	main
kõik	doc_873901597523_item	2914230	et	4	main
tegevused	doc_873901597523_item	2914232	et	4	main
näitavad	doc_873901597523_item	2914233	et	4	main
et	doc_873901597523_item	2914234	et	3	main
kirjanduse	doc_873901597524_item	2914246	et	3	main
vaatasime	doc_873901597524_item	2914249	et	3	main
peategelane	doc_873901597524_item	2914255	et	3	main
on	doc_873901597524_item	2914256	et	4	main
noor	doc_873901597524_item	2914257	et	3	main
naine	doc_873901597524_item	2914258	et	3	main
mari	doc_873901597524_item	2914259	et	4	main
tagasi	doc_873901597524_item	2914265	et	3	main
sellest	doc_873901597524_item	2914276	et	4	main
et	doc_873901597524_item	2914277	et	3	main
selleks	doc_873901597524_item	2914288	et	4	main
et	doc_873901597524_item	2914289	et	3	main
mehel	doc_873901597524_item	2914291	et	3	main
sõltub	doc_873901597524_item	2914322	et	3	main
nendest	doc_873901597524_item	2914323	et	4	main
käi	doc_873901597524_item	2914331	et	4	main
mees	doc_873901597524_item	2914334	et	4	main
ela	doc_873901597524_item	2914341	et	4	main
rikkalikult	doc_873901597524_item	2914342	et	4	main
see	doc_873901597524_item	2914343	et	3	main
töö	doc_873901597524_item	2914344	et	4	main
võimalust	doc_873901597524_item	2914357	et	3	main
mõisnikule	doc_873901597524_item	2914360	et	3	main
on	doc_873901597524_item	2914362	et	4	main
omapärane	doc_873901597524_item	2914363	et	4	main
töö	doc_873901597524_item	2914364	et	4	main
tihti	doc_873901597524_item	2914368	et	3	main
et	doc_873901597524_item	2914406	et	3	main
isegi	doc_873901597524_item	2914407	et	4	main
mehe	doc_873901597524_item	2914408	et	3	main
linna	doc_873901597524_item	2914413	et	4	main
ja	doc_873901597524_item	2914418	et	3	main
tänapäevane	doc_873901597525_item	2914424	et	4	main
kui	doc_873901597525_item	2914426	et	3	main
võrreldan	doc_873901597525_item	2914428	et	4	main
talumees	doc_873901597525_item	2914438	et	4	main
kes	doc_873901597525_item	2914439	et	4	main
elas	doc_873901597525_item	2914440	et	3	main
talus	doc_873901597525_item	2914441	et	4	main
19	doc_873901597525_item	2914442	et	2	main
sajandil	doc_873901597525_item	2914443	et	3	main
mees	doc_873901597525_item	2914450	et	4	main
meeldivad	doc_873901597525_item	2914458	et	4	main
raha	doc_873901597525_item	2914459	et	4	main
raha	doc_873901597525_item	2914465	et	4	main
suurem	doc_873901597525_item	2914467	et	4	main
osa	doc_873901597525_item	2914468	et	4	main
mehele	doc_873901597525_item	2914473	et	3	main
tänapäevase	doc_873901597525_item	2914507	et	4	main
mis	doc_873901597525_item	2914519	et	4	main
aga	doc_873901597525_item	2914522	et	3	main
maari	doc_873901597525_item	2914532	et	4	main
meest	doc_873901597525_item	2914536	et	4	main
ole	doc_873901597525_item	2914546	et	4	main
ei	doc_873901597525_item	2914554	et	4	main
ei	doc_873901597525_item	2914562	et	4	main
sündida	doc_873901597525_item	2914565	et	3	main
sai	doc_873901597525_item	2914568	et	4	main
ta	doc_873901597525_item	2914570	et	4	main
purjuks	doc_873901597525_item	2914588	et	4	main
siga	doc_873901597525_item	2914590	et	4	main
aega	doc_873901597526_item	2914639	et	4	main
ja	doc_873901597526_item	2914640	et	3	main
paljud	doc_873901597526_item	2914641	et	3	main
neist	doc_873901597526_item	2914642	et	4	main
kerged	doc_873901597526_item	2914646	et	3	main
meeldivad	doc_873901597526_item	2914648	et	4	main
toidukauplustes	doc_873901597526_item	2914654	et	4	main
ostavad	doc_873901597526_item	2914656	et	3	main
aia	doc_873901597526_item	2914660	et	4	main
eelistavad	doc_873901597526_item	2914665	et	4	main
lähedal	doc_873901597526_item	2914673	et	4	main
käia	doc_873901597526_item	2914682	et	4	main
kaupluses	doc_873901597526_item	2914683	et	3	main
et	doc_873901597523_item	2914222	et	3	main
pere	doc_873901597523_item	2914224	et	4	main
hästi	doc_873901597523_item	2914226	et	3	main
et	doc_873901597523_item	2914229	et	3	main
tunnis	doc_873901597524_item	2914247	et	3	main
pimamees	doc_873901597524_item	2914252	et	4	main
tegevus	doc_873901597524_item	2914260	et	4	main
toimub	doc_873901597524_item	2914261	et	3	main
tänapäevase	doc_873901597524_item	2914271	et	4	main
naisega	doc_873901597524_item	2914272	et	3	main
seda	doc_873901597524_item	2914273	et	3	main
võib	doc_873901597524_item	2914274	et	3	main
kinnitada	doc_873901597524_item	2914275	et	3	main
ja	doc_873901597524_item	2914282	et	3	main
lastel	doc_873901597524_item	2914293	et	4	main
elada	doc_873901597524_item	2914296	et	3	main
vaatamata	doc_873901597524_item	2914297	et	4	main
seda	doc_873901597524_item	2914298	et	3	main
et	doc_873901597524_item	2914299	et	3	main
mari	doc_873901597524_item	2914300	et	4	main
on	doc_873901597524_item	2914301	et	4	main
päris	doc_873901597524_item	2914302	et	4	main
uhke	doc_873901597524_item	2914303	et	4	main
ta	doc_873901597524_item	2914304	et	4	main
nõustab	doc_873901597524_item	2914305	et	3	main
mõisnikule	doc_873901597524_item	2914306	et	3	main
juurde	doc_873901597524_item	2914307	et	4	main
käia	doc_873901597524_item	2914308	et	4	main
tänapäeval	doc_873901597524_item	2914309	et	3	main
on	doc_873901597524_item	2914310	et	4	main
palju	doc_873901597524_item	2914311	et	4	main
naisi	doc_873901597524_item	2914312	et	3	main
kes	doc_873901597524_item	2914313	et	4	main
tegevad	doc_873901597524_item	2914314	et	4	main
samasuguseid	doc_873901597524_item	2914315	et	3	main
asju	doc_873901597524_item	2914316	et	3	main
nad	doc_873901597524_item	2914317	et	3	main
saavad	doc_873901597524_item	2914318	et	4	main
aru	doc_873901597524_item	2914319	et	4	main
et	doc_873901597524_item	2914320	et	3	main
teab	doc_873901597524_item	2914326	et	3	main
et	doc_873901597524_item	2914327	et	3	main
kui	doc_873901597524_item	2914328	et	3	main
siis	doc_873901597524_item	2914332	et	3	main
ei	doc_873901597524_item	2914335	et	4	main
sada	doc_873901597524_item	2914336	et	4	main
piimameheks	doc_873901597524_item	2914337	et	3	main
ja	doc_873901597524_item	2914338	et	3	main
nad	doc_873901597524_item	2914339	et	3	main
ei	doc_873901597524_item	2914340	et	4	main
kõik	doc_873901597524_item	2914346	et	4	main
mõtleb	doc_873901597524_item	2914351	et	3	main
lastest	doc_873901597524_item	2914352	et	4	main
ka	doc_873901597524_item	2914353	et	3	main
uus	doc_873901597524_item	2914354	et	3	main
töö	doc_873901597524_item	2914355	et	4	main
tänapäeval	doc_873901597524_item	2914367	et	3	main
ööpäeviti	doc_873901597524_item	2914371	et	4	main
kõik	doc_873901597523_item	2914221	et	4	main
tema	doc_873901597523_item	2914223	et	4	main
elab	doc_873901597523_item	2914225	et	3	main
ma	doc_873901597523_item	2914227	et	3	main
arvan	doc_873901597523_item	2914228	et	3	main
neid	doc_873901597523_item	2914231	et	4	main
tänapäevane	doc_873901597523_item	2914238	et	4	main
naine	doc_873901597523_item	2914239	et	3	main
essee	doc_873901597524_item	2914240	et	4	main
tänapäevane	doc_873901597524_item	2914243	et	4	main
filmi	doc_873901597524_item	2914250	et	4	main
mäeküla	doc_873901597524_item	2914251	et	4	main
aga	doc_873901597524_item	2914266	et	3	main
ta	doc_873901597524_item	2914283	et	4	main
ükskõik	doc_873901597524_item	2914286	et	3	main
oma	doc_873901597524_item	2914290	et	4	main
ja	doc_873901597524_item	2914292	et	3	main
aitama	doc_873901597524_item	2914294	et	3	main
tema	doc_873901597524_item	2914333	et	4	main
jaoks	doc_873901597524_item	2914349	et	4	main
naine	doc_873901597524_item	2914369	et	3	main
töötab	doc_873901597524_item	2914370	et	3	main
tulevikus	doc_873901597524_item	2914403	et	4	main
näeme	doc_873901597524_item	2914405	et	3	main
surma	doc_873901597524_item	2914409	et	4	main
kus	doc_873901597524_item	2914414	et	3	main
ootab	doc_873901597524_item	2914416	et	3	main
raske	doc_873901597524_item	2914419	et	4	main
elu	doc_873901597524_item	2914420	et	4	main
on	doc_873901597524_item	2914280	et	4	main
perekond	doc_873901597524_item	2914281	et	3	main
võib	doc_873901597524_item	2914284	et	3	main
kõik	doc_873901597524_item	2914321	et	4	main
nii	doc_873901597524_item	2914324	et	3	main
ta	doc_873901597524_item	2914329	et	4	main
on	doc_873901597524_item	2914345	et	4	main
ta	doc_873901597524_item	2914350	et	4	main
käimine	doc_873901597524_item	2914361	et	4	main
kõik	doc_873901597524_item	2914401	et	4	main
ta	doc_873901597524_item	2914411	et	4	main
läheb	doc_873901597524_item	2914412	et	3	main
ta	doc_873901597524_item	2914415	et	4	main
uus	doc_873901597524_item	2914417	et	3	main
essee	doc_873901597525_item	2914421	et	4	main
tõnu	doc_873901597525_item	2914436	et	4	main
on	doc_873901597525_item	2914437	et	4	main
tänapäevane	doc_873901597525_item	2914449	et	4	main
tõnu	doc_873901597525_item	2914452	et	4	main
väga	doc_873901597525_item	2914454	et	3	main
ja	doc_873901597525_item	2914460	et	3	main
elus	doc_873901597525_item	2914470	et	4	main
ka	doc_873901597525_item	2914471	et	3	main
sada	doc_873901597525_item	2914501	et	4	main
mehega	doc_873901597525_item	2914508	et	3	main
oli	doc_873901597525_item	2914513	et	3	main
kõike	doc_873901597525_item	2914518	et	4	main
räägis	doc_873901597525_item	2914521	et	3	main
oma	doc_873901597525_item	2914535	et	4	main
tänapäevane	doc_873901597525_item	2914538	et	4	main
mees	doc_873901597525_item	2914550	et	4	main
räägi	doc_873901597525_item	2914559	et	4	main
siis	doc_873901597525_item	2914560	et	3	main
sa	doc_873901597525_item	2914561	et	3	main
tõnu	doc_873901597525_item	2914567	et	4	main
uhke	doc_873901597525_item	2914572	et	4	main
õnnelik	doc_873901597525_item	2914574	et	3	main
tõnu-piimamees	doc_873901597525_item	2914575	et	4	main
koos	doc_873901597525_item	2914577	et	4	main
sõbraga	doc_873901597525_item	2914578	et	3	main
baaris	doc_873901597525_item	2914579	et	3	main
istuda	doc_873901597525_item	2914580	et	3	main
ja	doc_873901597525_item	2914581	et	3	main
õlut	doc_873901597525_item	2914582	et	3	main
juua	doc_873901597525_item	2914583	et	3	main
väga	doc_873901597525_item	2914584	et	3	main
tihti	doc_873901597525_item	2914585	et	3	main
tõnu	doc_873901597525_item	2914586	et	4	main
oli	doc_873901597525_item	2914587	et	3	main
veel	doc_873901597526_item	2914629	et	4	main
kõik	doc_873901597526_item	2914630	et	4	main
kahjuks	doc_873901597526_item	2914635	et	4	main
iga	doc_873901597526_item	2914651	et	4	main
vorsti	doc_873901597526_item	2914663	et	4	main
asuvad	doc_873901597526_item	2914669	et	4	main
kodu	doc_873901597526_item	2914670	et	4	main
või	doc_873901597526_item	2914671	et	4	main
mis	doc_873901597526_item	2914684	et	4	main
kodu	doc_873901597526_item	2914687	et	4	main
meeldi	doc_873901597526_item	2914723	et	4	main
palju	doc_873901597526_item	2914727	et	4	main
väljapandud	doc_873901597526_item	2914729	et	4	main
vaadata	doc_873901597526_item	2914734	et	4	main
peredes	doc_873901597526_item	2914742	et	3	main
oma	doc_873901597526_item	2914744	et	4	main
aiad	doc_873901597526_item	2914745	et	4	main
vabal	doc_873901597526_item	2914746	et	3	main
askeldada	doc_873901597526_item	2914755	et	3	main
aedvilju	doc_873901597526_item	2914760	et	3	main
on	doc_873901597526_item	2914775	et	4	main
arvan	doc_873901597526_item	2914789	et	3	main
ei	doc_873901597526_item	2914793	et	4	main
tänapäevased	doc_873901597526_item	2914798	et	4	main
ühel	doc_873901597526_item	2914803	et	3	main
tema	doc_873901597526_item	2914809	et	4	main
tema	doc_873901597526_item	2914819	et	4	main
perel	doc_873901597526_item	2914820	et	3	main
ei	doc_873901597524_item	2914330	et	4	main
tema	doc_873901597524_item	2914347	et	4	main
mehe	doc_873901597524_item	2914348	et	3	main
annab	doc_873901597524_item	2914356	et	3	main
nendel	doc_873901597524_item	2914358	et	4	main
õppida	doc_873901597524_item	2914359	et	3	main
mari	doc_873901597524_item	2914365	et	4	main
jaoks	doc_873901597524_item	2914366	et	4	main
lalstel	doc_873901597524_item	2914374	et	4	main
oleks	doc_873901597524_item	2914375	et	3	main
kõht	doc_873901597524_item	2914376	et	3	main
täis	doc_873901597524_item	2914377	et	4	main
ja	doc_873901597524_item	2914378	et	3	main
nad	doc_873901597524_item	2914379	et	3	main
võiks	doc_873901597524_item	2914380	et	4	main
õppida	doc_873901597524_item	2914381	et	3	main
hea	doc_873901597524_item	2914382	et	4	main
haridus	doc_873901597524_item	2914383	et	3	main
garanteerib	doc_873901597524_item	2914384	et	3	main
et	doc_873901597524_item	2914385	et	3	main
tulevikus	doc_873901597524_item	2914386	et	4	main
ei	doc_873901597524_item	2914387	et	4	main
tuli	doc_873901597524_item	2914388	et	4	main
nii	doc_873901597524_item	2914389	et	3	main
palju	doc_873901597524_item	2914390	et	4	main
ja	doc_873901597524_item	2914391	et	3	main
raske	doc_873901597524_item	2914392	et	4	main
töötada	doc_873901597524_item	2914393	et	3	main
iga	doc_873901597524_item	2914394	et	4	main
soovib	doc_873901597524_item	2914396	et	3	main
et	doc_873901597524_item	2914397	et	3	main
tema	doc_873901597524_item	2914398	et	4	main
ema	doc_873901597524_item	2914395	et	4	main
lastel	doc_873901597524_item	2914399	et	4	main
oleks	doc_873901597524_item	2914400	et	3	main
selleks	doc_873901597524_item	2914372	et	4	main
et	doc_873901597524_item	2914373	et	3	main
hästi	doc_873901597524_item	2914402	et	3	main
me	doc_873901597524_item	2914404	et	4	main
mees	doc_873901597525_item	2914425	et	4	main
tänapäevase	doc_873901597525_item	2914430	et	4	main
mehega	doc_873901597525_item	2914431	et	3	main
ma	doc_873901597525_item	2914432	et	3	main
leidsin	doc_873901597525_item	2914433	et	3	main
palju	doc_873901597525_item	2914434	et	4	main
sarnest	doc_873901597525_item	2914435	et	3	main
et	doc_873901597525_item	2914448	et	3	main
tõnu	doc_873901597525_item	2914469	et	4	main
rikkaks	doc_873901597525_item	2914502	et	4	main
suhtles	doc_873901597525_item	2914503	et	3	main
naisega	doc_873901597525_item	2914504	et	3	main
võrrelda	doc_873901597525_item	2914505	et	4	main
tõnu	doc_873901597525_item	2914506	et	4	main
sajandil	doc_873901597525_item	2914511	et	3	main
mees	doc_873901597525_item	2914512	et	4	main
perepea	doc_873901597525_item	2914514	et	4	main
ja	doc_873901597525_item	2914515	et	3	main
näine	doc_873901597525_item	2914516	et	4	main
kuulas	doc_873901597525_item	2914517	et	3	main
tõnu	doc_873901597525_item	2914523	et	4	main
niisugune	doc_873901597525_item	2914525	et	3	main
kes	doc_873901597525_item	2914527	et	4	main
ei	doc_873901597525_item	2914528	et	4	main
oli	doc_873901597525_item	2914529	et	3	main
kuula	doc_873901597525_item	2914534	et	4	main
mees	doc_873901597525_item	2914539	et	4	main
ei	doc_873901597525_item	2914545	et	4	main
kuulata	doc_873901597525_item	2914548	et	4	main
mis	doc_873901597525_item	2914549	et	4	main
mida	doc_873901597525_item	2914557	et	4	main
sa	doc_873901597525_item	2914558	et	3	main
teda	doc_873901597525_item	2914564	et	4	main
oli	doc_873901597525_item	2914571	et	3	main
ja	doc_873901597525_item	2914573	et	3	main
ka	doc_873901597525_item	2914591	et	3	main
naistest	doc_873901597526_item	2914623	et	4	main
kodutööd	doc_873901597526_item	2914631	et	4	main
naise	doc_873901597526_item	2914632	et	3	main
õlgadele	doc_873901597526_item	2914633	et	3	main
ei	doc_873901597526_item	2914643	et	4	main
tänapäevased	doc_873901597526_item	2914649	et	4	main
naised	doc_873901597526_item	2914650	et	3	main
päev	doc_873901597526_item	2914652	et	3	main
käivad	doc_873901597526_item	2914653	et	4	main
töökoha	doc_873901597526_item	2914672	et	4	main
ise	doc_873901597526_item	2914680	et	4	main
eelistan	doc_873901597526_item	2914681	et	3	main
minu	doc_873901597526_item	2914686	et	3	main
narva	doc_873901597526_item	2914719	et	4	main
pärast	doc_873901597524_item	2914410	et	4	main
tõnu	doc_873901597525_item	2914422	et	4	main
ma	doc_873901597525_item	2914427	et	3	main
tõnu	doc_873901597525_item	2914429	et	4	main
mõtlen	doc_873901597525_item	2914447	et	3	main
ja	doc_873901597525_item	2914451	et	3	main
on	doc_873901597525_item	2914453	et	4	main
ta	doc_873901597525_item	2914461	et	4	main
tahtis	doc_873901597525_item	2914462	et	3	main
saada	doc_873901597525_item	2914463	et	4	main
mängivad	doc_873901597525_item	2914466	et	4	main
ka	doc_873901597525_item	2914509	et	3	main
ja	doc_873901597525_item	2914423	et	3	main
vaatamata	doc_873901597525_item	2914444	et	4	main
sellele	doc_873901597525_item	2914445	et	4	main
ma	doc_873901597525_item	2914446	et	3	main
sarnased	doc_873901597525_item	2914455	et	4	main
tõnule	doc_873901597525_item	2914456	et	4	main
väga	doc_873901597525_item	2914457	et	3	main
rikkaks	doc_873901597525_item	2914464	et	4	main
tänapäevase	doc_873901597525_item	2914472	et	4	main
on	doc_873901597525_item	2914474	et	4	main
väga	doc_873901597525_item	2914475	et	3	main
vaja	doc_873901597525_item	2914476	et	4	main
et	doc_873901597525_item	2914477	et	3	main
tal	doc_873901597525_item	2914478	et	3	main
on	doc_873901597525_item	2914479	et	4	main
raha	doc_873901597525_item	2914480	et	4	main
sest	doc_873901597525_item	2914481	et	4	main
tänaelu	doc_873901597525_item	2914482	et	4	main
on	doc_873901597525_item	2914483	et	4	main
raske	doc_873901597525_item	2914484	et	4	main
ja	doc_873901597525_item	2914485	et	3	main
ja	doc_873901597525_item	2914487	et	3	main
inimene	doc_873901597525_item	2914488	et	3	main
ei	doc_873901597525_item	2914489	et	4	main
kallis	doc_873901597525_item	2914486	et	4	main
oska	doc_873901597525_item	2914490	et	4	main
elada	doc_873901597525_item	2914491	et	3	main
rahata	doc_873901597525_item	2914492	et	4	main
tõnu	doc_873901597525_item	2914493	et	4	main
ja	doc_873901597525_item	2914494	et	3	main
ka	doc_873901597525_item	2914495	et	3	main
tänapäevane	doc_873901597525_item	2914496	et	4	main
teeb	doc_873901597525_item	2914498	et	3	main
mees	doc_873901597525_item	2914497	et	4	main
kõike	doc_873901597525_item	2914499	et	4	main
et	doc_873901597525_item	2914500	et	3	main
19	doc_873901597525_item	2914510	et	2	main
mees	doc_873901597525_item	2914520	et	4	main
oli	doc_873901597525_item	2914524	et	3	main
mees	doc_873901597525_item	2914526	et	4	main
ei	doc_873901597525_item	2914533	et	4	main
ka	doc_873901597525_item	2914537	et	3	main
ole	doc_873901597525_item	2914541	et	4	main
ja	doc_873901597525_item	2914543	et	3	main
täna	doc_873901597525_item	2914544	et	4	main
räägi	doc_873901597525_item	2914551	et	4	main
kui	doc_873901597525_item	2914552	et	3	main
naine	doc_873901597525_item	2914553	et	3	main
kui	doc_873901597525_item	2914566	et	3	main
piimameheks	doc_873901597525_item	2914569	et	3	main
nagu	doc_873901597525_item	2914589	et	3	main
kuri	doc_873901597525_item	2914530	et	4	main
abikaasa	doc_873901597525_item	2914531	et	4	main
ei	doc_873901597525_item	2914540	et	4	main
kuri	doc_873901597525_item	2914542	et	4	main
vaja	doc_873901597525_item	2914547	et	4	main
taha	doc_873901597525_item	2914555	et	4	main
teha	doc_873901597525_item	2914556	et	3	main
saa	doc_873901597525_item	2914563	et	4	main
armastas	doc_873901597525_item	2914576	et	3	main
tänapäevase	doc_873901597525_item	2914592	et	4	main
mehele	doc_873901597525_item	2914593	et	3	main
meeldib	doc_873901597525_item	2914594	et	3	main
alkohooli	doc_873901597525_item	2914595	et	3	main
sisse	doc_873901597525_item	2914596	et	4	main
võtma	doc_873901597525_item	2914597	et	3	main
ma	doc_873901597525_item	2914598	et	3	main
mõtlen	doc_873901597525_item	2914599	et	3	main
et	doc_873901597525_item	2914600	et	3	main
inimesed	doc_873901597525_item	2914601	et	3	main
on	doc_873901597525_item	2914602	et	4	main
alati	doc_873901597525_item	2914603	et	4	main
väga	doc_873901597525_item	2914604	et	3	main
sarnased	doc_873901597525_item	2914605	et	4	main
vaatamata	doc_873901597525_item	2914606	et	4	main
sellele	doc_873901597525_item	2914607	et	4	main
et	doc_873901597525_item	2914608	et	3	main
nad	doc_873901597525_item	2914609	et	3	main
elavad	doc_873901597525_item	2914610	et	4	main
erineval	doc_873901597525_item	2914611	et	4	main
sajandil	doc_873901597525_item	2914612	et	3	main
essee	doc_873901597526_item	2914613	et	4	main
mari	doc_873901597526_item	2914614	et	4	main
ja	doc_873901597526_item	2914615	et	3	main
tänapäevane	doc_873901597526_item	2914616	et	4	main
naine	doc_873901597526_item	2914617	et	3	main
kõigepealt	doc_873901597526_item	2914618	et	3	main
ma	doc_873901597526_item	2914619	et	3	main
tahaksin	doc_873901597526_item	2914620	et	3	main
rääkida	doc_873901597526_item	2914621	et	3	main
tänapäevased	doc_873901597526_item	2914625	et	4	main
naised	doc_873901597526_item	2914626	et	3	main
veeretatakse	doc_873901597526_item	2914634	et	3	main
palju	doc_873901597526_item	2914638	et	4	main
ega	doc_873901597526_item	2914647	et	3	main
kust	doc_873901597526_item	2914655	et	4	main
toiduaineid	doc_873901597526_item	2914658	et	3	main
leiba	doc_873901597526_item	2914659	et	4	main
naised	doc_873901597526_item	2914664	et	3	main
käia	doc_873901597526_item	2914666	et	4	main
kauplustes	doc_873901597526_item	2914667	et	4	main
sest	doc_873901597526_item	2914674	et	4	main
turg	doc_873901597526_item	2914720	et	3	main
saa	doc_873901597526_item	2914732	et	4	main
tänapäevasetest	doc_873901597526_item	2914622	et	4	main
mõned	doc_873901597526_item	2914624	et	3	main
töötavad	doc_873901597526_item	2914627	et	4	main
ja	doc_873901597526_item	2914628	et	3	main
kodutööd	doc_873901597526_item	2914636	et	4	main
nõuavad	doc_873901597526_item	2914637	et	4	main
ole	doc_873901597526_item	2914644	et	4	main
kaugeltki	doc_873901597526_item	2914645	et	4	main
hädavajalikke	doc_873901597526_item	2914657	et	3	main
piima	doc_873901597526_item	2914661	et	4	main
juustu	doc_873901597526_item	2914662	et	4	main
mis	doc_873901597526_item	2914668	et	4	main
see	doc_873901597526_item	2914675	et	3	main
on	doc_873901597526_item	2914676	et	4	main
väga	doc_873901597526_item	2914677	et	3	main
mugav	doc_873901597526_item	2914678	et	3	main
mina	doc_873901597526_item	2914679	et	4	main
asub	doc_873901597526_item	2914685	et	3	main
lähedal	doc_873901597526_item	2914688	et	4	main
ma	doc_873901597526_item	2914689	et	3	main
tean	doc_873901597526_item	2914690	et	3	main
et	doc_873901597526_item	2914691	et	3	main
laupäeviti	doc_873901597526_item	2914692	et	4	main
või	doc_873901597526_item	2914693	et	4	main
pühapäeviti	doc_873901597526_item	2914694	et	4	main
käivad	doc_873901597526_item	2914695	et	4	main
mõned	doc_873901597526_item	2914696	et	3	main
naised	doc_873901597526_item	2914697	et	3	main
ka	doc_873901597526_item	2914698	et	3	main
turul	doc_873901597526_item	2914699	et	3	main
sest	doc_873901597526_item	2914700	et	4	main
tooted	doc_873901597526_item	2914701	et	3	main
seal	doc_873901597526_item	2914702	et	4	main
on	doc_873901597526_item	2914703	et	4	main
odavam	doc_873901597526_item	2914704	et	4	main
ja	doc_873901597526_item	2914705	et	3	main
värskem	doc_873901597526_item	2914706	et	4	main
ostavad	doc_873901597526_item	2914707	et	3	main
sealt	doc_873901597526_item	2914708	et	4	main
liha	doc_873901597526_item	2914709	et	4	main
kartuleid	doc_873901597526_item	2914710	et	3	main
ja	doc_873901597526_item	2914711	et	3	main
aedvilju	doc_873901597526_item	2914712	et	3	main
mõnikord	doc_873901597526_item	2914713	et	3	main
ka	doc_873901597526_item	2914714	et	3	main
riideid	doc_873901597526_item	2914715	et	3	main
ja	doc_873901597526_item	2914716	et	3	main
jalatseid	doc_873901597526_item	2914717	et	4	main
mulle	doc_873901597526_item	2914718	et	4	main
eriti	doc_873901597526_item	2914721	et	3	main
rahvast	doc_873901597526_item	2914724	et	4	main
on	doc_873901597526_item	2914725	et	4	main
trügitakse	doc_873901597526_item	2914728	et	3	main
kaupu	doc_873901597526_item	2914730	et	3	main
tegelikult	doc_873901597526_item	2914735	et	4	main
ajal	doc_873901597526_item	2914747	et	4	main
meeldib	doc_873901597526_item	2914748	et	3	main
mõningatele	doc_873901597526_item	2914749	et	3	main
teha	doc_873901597526_item	2914753	et	3	main
ei	doc_873901597526_item	2914722	et	4	main
käimine	doc_873901597526_item	2914738	et	4	main
on	doc_873901597526_item	2914743	et	4	main
naistele	doc_873901597526_item	2914751	et	3	main
nagu	doc_873901597526_item	2914761	et	3	main
kurke	doc_873901597526_item	2914763	et	3	main
ja	doc_873901597526_item	2914780	et	3	main
telefon	doc_873901597526_item	2914784	et	3	main
et	doc_873901597526_item	2914790	et	3	main
naised	doc_873901597526_item	2914792	et	3	main
looda	doc_873901597526_item	2914794	et	4	main
meestele	doc_873901597526_item	2914795	et	4	main
mehed	doc_873901597526_item	2914799	et	3	main
näiteks	doc_873901597526_item	2914802	et	4	main
minu	doc_873901597526_item	2914804	et	3	main
on	doc_873901597526_item	2914806	et	4	main
abikaasa	doc_873901597526_item	2914807	et	4	main
jäi	doc_873901597526_item	2914811	et	3	main
tagasi	doc_873901597526_item	2914814	et	3	main
ja	doc_873901597526_item	2914816	et	3	main
see	doc_873901597526_item	2914823	et	3	main
loodab	doc_873901597526_item	2914833	et	3	main
on	doc_873901597526_item	2914838	et	4	main
nagu	doc_873901597526_item	2914849	et	3	main
tänapäevane	doc_873901597526_item	2914850	et	4	main
ta	doc_873901597526_item	2914852	et	4	main
väga	doc_873901597526_item	2914854	et	3	main
sõltumatu	doc_873901597526_item	2914855	et	4	main
ainult	doc_873901597526_item	2914866	et	4	main
kui	doc_873901597526_item	2914873	et	3	main
ta	doc_873901597526_item	2914881	et	4	main
tahtis	doc_873901597526_item	2914882	et	3	main
ja	doc_873901597526_item	2914885	et	3	main
sest	doc_873901597526_item	2914899	et	4	main
lapse	doc_873901597526_item	2914900	et	4	main
väga	doc_873901597526_item	2914904	et	3	main
vaja	doc_873901597526_item	2914907	et	4	main
eriline	doc_873901597526_item	2914930	et	4	main
kätte	doc_873901597527_item	2914942	et	4	main
on	doc_873901597527_item	2914945	et	4	main
et	doc_873901597527_item	2914947	et	3	main
on	doc_873901597527_item	2914949	et	4	main
levinud	doc_873901597527_item	2914951	et	4	main
narkomaania	doc_873901597527_item	2914953	et	4	main
suurimaks	doc_873901597527_item	2914963	et	4	main
puutunud	doc_873901597527_item	2914978	et	4	main
või	doc_873901597527_item	2914981	et	4	main
sellest	doc_873901597527_item	2914986	et	4	main
mida	doc_873901597527_item	2915000	et	4	main
kool	doc_873901597527_item	2915002	et	4	main
tõesti	doc_873901597527_item	2915009	et	3	main
väga	doc_873901597527_item	2915011	et	3	main
muljed	doc_873901597527_item	2915015	et	3	main
positiivsed	doc_873901597527_item	2915018	et	3	main
autori	doc_873901597527_item	2915022	et	3	main
olen	doc_873901597527_item	2915025	et	3	main
et	doc_873901597527_item	2915027	et	3	main
see	doc_873901597527_item	2915036	et	3	main
nii	doc_873901597527_item	2915040	et	3	main
maailm	doc_873901597527_item	2915047	et	3	main
ametlik	doc_873901597528_item	2915051	et	3	main
ajalehest	doc_873901597528_item	2915062	et	4	main
te	doc_873901597528_item	2915067	et	4	main
korteri	doc_873901597528_item	2915069	et	3	main
osta	doc_873901597528_item	2915073	et	4	main
lisa	doc_873901597528_item	2915077	et	4	main
esiteks	doc_873901597528_item	2915088	et	3	main
teada	doc_873901597528_item	2915091	et	3	main
ka	doc_873901597528_item	2915096	et	3	main
on	doc_873901597528_item	2915101	et	4	main
peab	doc_873901597528_item	2915109	et	4	main
maksma	doc_873901597528_item	2915111	et	3	main
või	doc_873901597528_item	2915112	et	4	main
milles	doc_873901597528_item	2915121	et	3	main
või	doc_873901597528_item	2915132	et	4	main
on	doc_873901597528_item	2915145	et	4	main
eesnimi	doc_873901597528_item	2915154	et	3	main
väga	doc_873901597526_item	2914726	et	3	main
ei	doc_873901597526_item	2914731	et	4	main
küllaltki	doc_873901597526_item	2914739	et	4	main
aiatööd	doc_873901597526_item	2914752	et	4	main
aias	doc_873901597526_item	2914754	et	4	main
kasvatavad	doc_873901597526_item	2914757	et	4	main
igasuguseid	doc_873901597526_item	2914759	et	3	main
lilli	doc_873901597526_item	2914767	et	4	main
ube	doc_873901597526_item	2914769	et	3	main
naised	doc_873901597526_item	2914771	et	3	main
elavad	doc_873901597526_item	2914772	et	4	main
majades	doc_873901597526_item	2914773	et	3	main
kus	doc_873901597526_item	2914774	et	3	main
külm	doc_873901597526_item	2914781	et	3	main
elektripliit	doc_873901597526_item	2914783	et	3	main
lift	doc_873901597526_item	2914785	et	3	main
ja	doc_873901597526_item	2914786	et	3	main
ma	doc_873901597526_item	2914788	et	3	main
sest	doc_873901597526_item	2914796	et	4	main
nõrgad	doc_873901597526_item	2914801	et	3	main
abikaasa	doc_873901597526_item	2914810	et	4	main
materiaalsed	doc_873901597526_item	2914821	et	3	main
ei	doc_873901597526_item	2914825	et	4	main
tööd	doc_873901597526_item	2914827	et	4	main
iseendale	doc_873901597526_item	2914835	et	3	main
naised	doc_873901597526_item	2914837	et	3	main
väga	doc_873901597526_item	2914839	et	3	main
romaanist	doc_873901597526_item	2914847	et	3	main
elada	doc_873901597526_item	2914858	et	3	main
loodab	doc_873901597526_item	2914865	et	3	main
iseendale	doc_873901597526_item	2914867	et	3	main
aga	doc_873901597526_item	2914868	et	3	main
mari	doc_873901597526_item	2914869	et	4	main
tänapäevane	doc_873901597526_item	2914874	et	4	main
naine	doc_873901597526_item	2914875	et	3	main
mari	doc_873901597526_item	2914876	et	4	main
võttis	doc_873901597526_item	2914877	et	3	main
see	doc_873901597526_item	2914902	et	3	main
on	doc_873901597526_item	2914906	et	4	main
ma	doc_873901597526_item	2914922	et	3	main
ütelda	doc_873901597526_item	2914924	et	4	main
lugesin	doc_873901597527_item	2914936	et	3	main
vägivald	doc_873901597527_item	2914948	et	3	main
laiemalt	doc_873901597527_item	2914950	et	4	main
kui	doc_873901597527_item	2914952	et	3	main
ise	doc_873901597527_item	2914961	et	4	main
peavad	doc_873901597527_item	2914962	et	4	main
õpilastest	doc_873901597527_item	2914977	et	4	main
koolivägivallaga	doc_873901597527_item	2914979	et	3	main
ühel	doc_873901597527_item	2914980	et	3	main
räägitakse	doc_873901597527_item	2914989	et	3	main
on	doc_873901597527_item	2914991	et	4	main
mida	doc_873901597527_item	2914993	et	4	main
saaksid	doc_873901597527_item	2914994	et	4	main
õpilased	doc_873901597527_item	2914995	et	3	main
koolivägivalla	doc_873901597527_item	2914996	et	3	main
vastu	doc_873901597527_item	2914997	et	3	main
teha	doc_873901597527_item	2914998	et	3	main
ja	doc_873901597527_item	2914999	et	3	main
arvan	doc_873901597527_item	2915005	et	3	main
nõuanned	doc_873901597527_item	2915008	et	4	main
on	doc_873901597527_item	2915010	et	4	main
koolielus	doc_873901597527_item	2915013	et	4	main
minu	doc_873901597527_item	2915014	et	3	main
nõus	doc_873901597527_item	2915026	et	4	main
hirmutas	doc_873901597527_item	2915035	et	3	main
et	doc_873901597527_item	2915037	et	3	main
pakute	doc_873901597528_item	2915068	et	3	main
seda	doc_873901597528_item	2915074	et	3	main
ma	doc_873901597528_item	2915075	et	3	main
küsimustele	doc_873901597528_item	2915087	et	4	main
kui	doc_873901597528_item	2915092	et	3	main
veel	doc_873901597528_item	2915104	et	4	main
kas	doc_873901597528_item	2915108	et	3	main
tahan	doc_873901597528_item	2915115	et	3	main
kui	doc_873901597528_item	2915117	et	3	main
korter	doc_873901597528_item	2915122	et	3	main
korrusel	doc_873901597528_item	2915125	et	3	main
kas	doc_873901597528_item	2915128	et	3	main
on	doc_873901597528_item	2915130	et	4	main
on	doc_873901597528_item	2915137	et	4	main
kõik	doc_873901597528_item	2915146	et	4	main
korralikult	doc_873901597526_item	2914733	et	4	main
on	doc_873901597526_item	2914736	et	4	main
turul	doc_873901597526_item	2914737	et	3	main
väsitav	doc_873901597526_item	2914740	et	4	main
mõningates	doc_873901597526_item	2914741	et	3	main
tänapäevastele	doc_873901597526_item	2914750	et	4	main
porgandeid	doc_873901597526_item	2914764	et	3	main
tilli	doc_873901597526_item	2914766	et	4	main
mugavused	doc_873901597526_item	2914777	et	4	main
keskküte	doc_873901597526_item	2914778	et	3	main
tänapäevased	doc_873901597526_item	2914791	et	4	main
mõned	doc_873901597526_item	2914797	et	3	main
tuttaval	doc_873901597526_item	2914805	et	4	main
umbes	doc_873901597526_item	2914812	et	4	main
mees	doc_873901597526_item	2914824	et	4	main
otsi	doc_873901597526_item	2914826	et	4	main
ja	doc_873901597526_item	2914828	et	3	main
ei	doc_873901597526_item	2914829	et	4	main
ainult	doc_873901597526_item	2914834	et	4	main
wilde	doc_873901597526_item	2914846	et	4	main
tahab	doc_873901597526_item	2914857	et	3	main
linnas	doc_873901597526_item	2914859	et	4	main
kus	doc_873901597526_item	2914860	et	3	main
on	doc_873901597526_item	2914861	et	4	main
on	doc_873901597526_item	2914870	et	4	main
vaeslapse	doc_873901597526_item	2914878	et	4	main
iga	doc_873901597526_item	2914894	et	4	main
ei	doc_873901597526_item	2914895	et	4	main
saaks	doc_873901597526_item	2914896	et	3	main
on	doc_873901597526_item	2914903	et	4	main
tahan	doc_873901597526_item	2914923	et	3	main
et	doc_873901597526_item	2914925	et	3	main
igas	doc_873901597526_item	2914926	et	3	main
inimeses	doc_873901597526_item	2914927	et	3	main
essee	doc_873901597527_item	2914933	et	4	main
koolivägivald	doc_873901597527_item	2914934	et	3	main
artikli	doc_873901597527_item	2914937	et	3	main
kirjutatud	doc_873901597527_item	2914946	et	4	main
suitsetamine	doc_873901597527_item	2914954	et	4	main
mind	doc_873901597527_item	2914957	et	4	main
üllatas	doc_873901597527_item	2914958	et	3	main
et	doc_873901597527_item	2914959	et	3	main
teisel	doc_873901597527_item	2914982	et	4	main
kujul	doc_873901597527_item	2914983	et	4	main
siis	doc_873901597527_item	2914984	et	3	main
miks	doc_873901597527_item	2914985	et	4	main
kirjutatud	doc_873901597527_item	2914992	et	4	main
teha	doc_873901597527_item	2915003	et	3	main
kasulikud	doc_873901597527_item	2915012	et	3	main
nad	doc_873901597526_item	2914756	et	3	main
seal	doc_873901597526_item	2914758	et	4	main
tomateid	doc_873901597526_item	2914762	et	3	main
kapsaid	doc_873901597526_item	2914765	et	3	main
ja	doc_873901597526_item	2914768	et	3	main
tänapäevased	doc_873901597526_item	2914770	et	4	main
kõik	doc_873901597526_item	2914776	et	4	main
soe	doc_873901597526_item	2914779	et	4	main
vesi	doc_873901597526_item	2914782	et	4	main
prügišaht	doc_873901597526_item	2914787	et	2	main
on	doc_873901597526_item	2914800	et	4	main
kahjuks	doc_873901597526_item	2914808	et	4	main
aasta	doc_873901597526_item	2914813	et	4	main
töötuks	doc_873901597526_item	2914815	et	4	main
nüüd	doc_873901597526_item	2914817	et	4	main
on	doc_873901597526_item	2914818	et	4	main
probleemid	doc_873901597526_item	2914822	et	3	main
naine	doc_873901597526_item	2914832	et	3	main
tänapäevased	doc_873901597526_item	2914836	et	4	main
sõltumatud	doc_873901597526_item	2914840	et	4	main
ma	doc_873901597526_item	2914841	et	3	main
arvan	doc_873901597526_item	2914842	et	3	main
et	doc_873901597526_item	2914843	et	3	main
mari	doc_873901597526_item	2914844	et	4	main
on	doc_873901597526_item	2914848	et	4	main
ta	doc_873901597526_item	2914856	et	4	main
siiski	doc_873901597526_item	2914871	et	4	main
sest	doc_873901597526_item	2914880	et	4	main
neid	doc_873901597526_item	2914883	et	4	main
neid	doc_873901597526_item	2914886	et	4	main
kasvatada	doc_873901597526_item	2914887	et	3	main
ma	doc_873901597526_item	2914888	et	3	main
arvan	doc_873901597526_item	2914889	et	3	main
et	doc_873901597526_item	2914890	et	3	main
tänapäevane	doc_873901597526_item	2914891	et	4	main
naine	doc_873901597526_item	2914892	et	3	main
mitte	doc_873901597526_item	2914893	et	3	main
kasvatamine	doc_873901597526_item	2914901	et	4	main
lõpus	doc_873901597526_item	2914921	et	4	main
tee	doc_873901597526_item	2914830	et	4	main
kodutöid	doc_873901597526_item	2914831	et	3	main
eduard	doc_873901597526_item	2914845	et	4	main
naine	doc_873901597526_item	2914851	et	3	main
on	doc_873901597526_item	2914853	et	4	main
kõik	doc_873901597526_item	2914862	et	4	main
mugavused	doc_873901597526_item	2914863	et	4	main
mari	doc_873901597526_item	2914864	et	4	main
suursugusem	doc_873901597526_item	2914872	et	4	main
endale	doc_873901597526_item	2914879	et	4	main
aidata	doc_873901597526_item	2914884	et	4	main
seda	doc_873901597526_item	2914897	et	3	main
teha	doc_873901597526_item	2914898	et	3	main
raske	doc_873901597526_item	2914905	et	4	main
palju	doc_873901597526_item	2914908	et	4	main
kannatuset	doc_873901597526_item	2914909	et	4	main
aega	doc_873901597526_item	2914910	et	4	main
ja	doc_873901597526_item	2914911	et	3	main
vahendeid	doc_873901597526_item	2914912	et	3	main
ma	doc_873901597526_item	2914913	et	3	main
arvan	doc_873901597526_item	2914914	et	3	main
et	doc_873901597526_item	2914915	et	3	main
mari	doc_873901597526_item	2914916	et	4	main
on	doc_873901597526_item	2914917	et	4	main
väga	doc_873901597526_item	2914918	et	3	main
tore	doc_873901597526_item	2914919	et	3	main
naine	doc_873901597526_item	2914920	et	3	main
ja	doc_873901597526_item	2914931	et	3	main
hea	doc_873901597526_item	2914932	et	4	main
internetist	doc_873901597527_item	2914943	et	4	main
nii	doc_873901597527_item	2914987	et	3	main
et	doc_873901597527_item	2915006	et	3	main
on	doc_873901597527_item	2915017	et	4	main
mulle	doc_873901597527_item	2915020	et	4	main
teema	doc_873901597527_item	2915023	et	4	main
teema	doc_873901597527_item	2915028	et	4	main
on	doc_873901597527_item	2915029	et	4	main
levinud	doc_873901597527_item	2915042	et	4	main
tänapäevane	doc_873901597527_item	2915046	et	4	main
julm	doc_873901597527_item	2915050	et	3	main
aga	doc_873901597528_item	2915070	et	3	main
maksab	doc_873901597528_item	2915094	et	3	main
korter	doc_873901597528_item	2915095	et	3	main
huvitab	doc_873901597528_item	2915098	et	3	main
kas	doc_873901597528_item	2915099	et	3	main
teil	doc_873901597528_item	2915100	et	4	main
tahaksin	doc_873901597528_item	2915106	et	3	main
vana	doc_873901597528_item	2915118	et	4	main
maja	doc_873901597528_item	2915120	et	4	main
asub	doc_873901597528_item	2915123	et	3	main
korter	doc_873901597528_item	2915127	et	3	main
plats	doc_873901597528_item	2915143	et	4	main
need	doc_873901597528_item	2915144	et	3	main
eest	doc_873901597528_item	2915153	et	4	main
2	doc_873901597528_item	2915158	et	2	main
telefon	doc_873901597528_item	2915160	et	3	main
on	doc_873901597526_item	2914928	et	4	main
midagi	doc_873901597526_item	2914929	et	4	main
ma	doc_873901597527_item	2914935	et	3	main
koolivägivallast	doc_873901597527_item	2914938	et	4	main
artikkel	doc_873901597527_item	2914939	et	3	main
sattus	doc_873901597527_item	2914940	et	3	main
mulle	doc_873901597527_item	2914941	et	4	main
tekstis	doc_873901597527_item	2914944	et	3	main
ja	doc_873901597527_item	2914955	et	3	main
alkohol	doc_873901597527_item	2914956	et	3	main
õpilased	doc_873901597527_item	2914960	et	3	main
kooliprobleemiks	doc_873901597527_item	2914964	et	4	main
vägivalda	doc_873901597527_item	2914965	et	4	main
ka	doc_873901597527_item	2914966	et	3	main
mind	doc_873901597527_item	2914967	et	4	main
hämmastas	doc_873901597527_item	2914968	et	3	main
et	doc_873901597527_item	2914969	et	3	main
lastekaitse	doc_873901597527_item	2914970	et	4	main
liidu	doc_873901597527_item	2914971	et	3	main
projekti	doc_873901597527_item	2914972	et	4	main
andmeil	doc_873901597527_item	2914973	et	3	main
on	doc_873901597527_item	2914974	et	4	main
65	doc_873901597527_item	2914975	et	2	main
põhikooli	doc_873901597527_item	2914976	et	4	main
vähe	doc_873901597527_item	2914988	et	3	main
artiklis	doc_873901597527_item	2914990	et	3	main
saaks	doc_873901597527_item	2915001	et	3	main
ma	doc_873901597527_item	2915004	et	3	main
need	doc_873901597527_item	2915007	et	3	main
tekstist	doc_873901597527_item	2915016	et	3	main
sest	doc_873901597527_item	2915019	et	4	main
meeldis	doc_873901597527_item	2915021	et	3	main
valik	doc_873901597527_item	2915024	et	3	main
aga	doc_873901597527_item	2915033	et	3	main
mind	doc_873901597527_item	2915034	et	4	main
vägivald	doc_873901597527_item	2915038	et	3	main
laiemalt	doc_873901597527_item	2915041	et	4	main
ja	doc_873901597527_item	2915043	et	3	main
see	doc_873901597527_item	2915044	et	3	main
on	doc_873901597527_item	2915048	et	4	main
nii	doc_873901597527_item	2915049	et	3	main
kiri	doc_873901597528_item	2915052	et	3	main
et	doc_873901597528_item	2915072	et	3	main
nii	doc_873901597528_item	2915082	et	3	main
kena	doc_873901597528_item	2915083	et	4	main
et	doc_873901597528_item	2915084	et	3	main
vastaksite	doc_873901597528_item	2915085	et	3	main
minu	doc_873901597528_item	2915086	et	3	main
palju	doc_873901597528_item	2915093	et	4	main
mind	doc_873901597528_item	2915097	et	4	main
ma	doc_873901597528_item	2915105	et	3	main
teiseks	doc_873901597528_item	2915114	et	4	main
on	doc_873901597528_item	2915119	et	4	main
visklev	doc_873901597527_item	2915030	et	4	main
ja	doc_873901597527_item	2915031	et	3	main
aktuaalne	doc_873901597527_item	2915032	et	3	main
on	doc_873901597527_item	2915039	et	4	main
et	doc_873901597527_item	2915045	et	3	main
järelpärimine	doc_873901597528_item	2915053	et	3	main
xxx	doc_873901597528_item	2915054	et	4	main
kinnisvara	doc_873901597528_item	2915055	et	4	main
as	doc_873901597528_item	2915056	et	4	main
maakler	doc_873901597528_item	2915057	et	3	main
eesnimi	doc_873901597528_item	2915058	et	3	main
perekonnanimi	doc_873901597528_item	2915059	et	3	main
tere	doc_873901597528_item	2915060	et	3	main
lugesin	doc_873901597528_item	2915061	et	3	main
postimees	doc_873901597528_item	2915063	et	4	main
teie	doc_873901597528_item	2915064	et	4	main
kuulutust	doc_873901597528_item	2915065	et	4	main
kus	doc_873901597528_item	2915066	et	3	main
selleks	doc_873901597528_item	2915071	et	4	main
vajan	doc_873901597528_item	2915076	et	3	main
infot	doc_873901597528_item	2915078	et	3	main
kas	doc_873901597528_item	2915079	et	3	main
te	doc_873901597528_item	2915080	et	4	main
oleksite	doc_873901597528_item	2915081	et	3	main
ma	doc_873901597528_item	2915089	et	3	main
tahaksin	doc_873901597528_item	2915090	et	3	main
järelmaksu	doc_873901597528_item	2915102	et	4	main
võimalus	doc_873901597528_item	2915103	et	3	main
küsida	doc_873901597528_item	2915107	et	3	main
sularahaga	doc_873901597528_item	2915110	et	4	main
ei	doc_873901597528_item	2915113	et	4	main
huvituda	doc_873901597528_item	2915116	et	3	main
asub	doc_873901597528_item	2915126	et	3	main
vajab	doc_873901597528_item	2915133	et	3	main
missugused	doc_873901597528_item	2915135	et	3	main
kas	doc_873901597528_item	2915138	et	3	main
õues	doc_873901597528_item	2915140	et	4	main
on	doc_873901597528_item	2915141	et	4	main
perekonnanimi	doc_873901597528_item	2915155	et	3	main
372	doc_873901597528_item	2915161	et	2	main
et	doc_873901597531_item	2915490	et	3	main
sellised	doc_873901597531_item	2915500	et	4	main
probleemid	doc_873901597531_item	2915501	et	3	main
mitmendal	doc_873901597528_item	2915124	et	3	main
korter	doc_873901597528_item	2915129	et	3	main
uus	doc_873901597528_item	2915131	et	3	main
remondist	doc_873901597528_item	2915134	et	3	main
mugavused	doc_873901597528_item	2915136	et	4	main
maja	doc_873901597528_item	2915139	et	4	main
laste	doc_873901597528_item	2915142	et	4	main
timuti	doc_873901597528_item	2915156	et	3	main
narva	doc_873901597528_item	2915159	et	4	main
120704	doc_873901597528_item	2915163	et	2	main
minu	doc_873901597528_item	2915147	et	3	main
küsimused	doc_873901597528_item	2915148	et	4	main
praegu	doc_873901597528_item	2915149	et	3	main
aegsasti	doc_873901597528_item	2915150	et	3	main
tänan	doc_873901597528_item	2915151	et	3	main
vastuste	doc_873901597528_item	2915152	et	4	main
1	doc_873901597528_item	2915157	et	2	main
56565656	doc_873901597528_item	2915162	et	2	main
see	doc_873901597531_item	2915491	et	3	main
ole	doc_873901597531_item	2915493	et	4	main
lihtne	doc_873901597531_item	2915494	et	3	main
mida	doc_873901597531_item	2915502	et	4	main
osta	doc_873901597531_item	2915503	et	4	main
minu	doc_873901597531_item	2915508	et	3	main
sünnipäev	doc_873901597531_item	2915517	et	3	main
varsti	doc_873901597531_item	2915469	et	3	main
tuleb	doc_873901597531_item	2915470	et	3	main
jõuluaeg	doc_873901597531_item	2915471	et	3	main
kõige	doc_873901597531_item	2915472	et	4	main
aeg	doc_873901597531_item	2915474	et	3	main
ilusam	doc_873901597531_item	2915473	et	4	main
talvel	doc_873901597531_item	2915475	et	4	main
kõik	doc_873901597531_item	2915476	et	4	main
on	doc_873901597531_item	2915477	et	4	main
rõõmus	doc_873901597531_item	2915478	et	4	main
kõigil	doc_873901597531_item	2915479	et	4	main
on	doc_873901597531_item	2915480	et	4	main
hea	doc_873901597531_item	2915481	et	4	main
tuju	doc_873901597531_item	2915482	et	4	main
tuleb	doc_873901597531_item	2915483	et	3	main
aeg	doc_873901597531_item	2915484	et	3	main
osta	doc_873901597531_item	2915485	et	4	main
kingitused	doc_873901597531_item	2915486	et	4	main
essee	doc_873901597531_item	2915466	et	4	main
minu	doc_873901597531_item	2915467	et	3	main
jõulumõtted	doc_873901597531_item	2915468	et	3	main
ja	doc_873901597531_item	2915487	et	3	main
mul	doc_873901597531_item	2915495	et	3	main
või	doc_873901597531_item	2915504	et	4	main
on	doc_873901597531_item	2915516	et	4	main
ja	doc_873901597531_item	2915525	et	3	main
ajas	doc_873901597531_item	2915539	et	4	main
kuhugi	doc_873901597531_item	2915542	et	4	main
sõita	doc_873901597531_item	2915543	et	3	main
näiteks	doc_873901597531_item	2915544	et	4	main
soome	doc_873901597531_item	2915545	et	3	main
suusabaasile	doc_873901597531_item	2915546	et	3	main
see	doc_873901597531_item	2915547	et	3	main
ei	doc_873901597531_item	2915555	et	4	main
aga	doc_873901597531_item	2915587	et	3	main
kui	doc_873901597531_item	2915594	et	3	main
kõige	doc_873901597531_item	2915602	et	4	main
parem	doc_873901597531_item	2915603	et	4	main
kingitus	doc_873901597531_item	2915604	et	4	main
olin	doc_873901597531_item	2915610	et	3	main
ja	doc_873901597531_item	2915612	et	3	main
öölda	doc_873901597531_item	2915614	et	4	main
seal	doc_873901597531_item	2915616	et	4	main
meelelahutused	doc_873901597531_item	2915619	et	4	main
jagavad	doc_873901597531_item	2915621	et	4	main
seal	doc_873901597531_item	2915624	et	4	main
ka	doc_873901597531_item	2915625	et	3	main
mangisime	doc_873901597531_item	2915631	et	4	main
ka	doc_873901597531_item	2915632	et	3	main
öölda	doc_873901597531_item	2915635	et	4	main
väike	doc_873901597531_item	2915643	et	4	main
koos	doc_873901597531_item	2915654	et	4	main
essee	doc_873901597532_item	2915667	et	4	main
minu	doc_873901597532_item	2915668	et	3	main
jõulumõtted	doc_873901597532_item	2915669	et	3	main
see	doc_873901597532_item	2915670	et	3	main
parandada	doc_873901597532_item	2915678	et	3	main
kirjuta	doc_873901597532_item	2915682	et	4	main
arvan	doc_873901597531_item	2915489	et	3	main
aga	doc_873901597531_item	2915507	et	3	main
kingitused	doc_873901597531_item	2915524	et	4	main
et	doc_873901597531_item	2915526	et	3	main
tea	doc_873901597531_item	2915532	et	4	main
on	doc_873901597531_item	2915548	et	4	main
minu	doc_873901597531_item	2915549	et	3	main
nagu	doc_873901597531_item	2915581	et	3	main
sõda	doc_873901597531_item	2915582	et	4	main
j	doc_873901597531_item	2915583	et	4	main
õppima	doc_873901597531_item	2915588	et	3	main
et	doc_873901597531_item	2915593	et	3	main
eksami	doc_873901597531_item	2915595	et	3	main
ma	doc_873901597531_item	2915488	et	3	main
ei	doc_873901597531_item	2915492	et	4	main
on	doc_873901597531_item	2915496	et	4	main
igal	doc_873901597531_item	2915497	et	3	main
aastal	doc_873901597531_item	2915498	et	3	main
tekkivad	doc_873901597531_item	2915499	et	4	main
mida	doc_873901597531_item	2915505	et	4	main
jaoks	doc_873901597531_item	2915509	et	4	main
aeg	doc_873901597531_item	2915511	et	3	main
paremini	doc_873901597531_item	2915513	et	4	main
sest	doc_873901597531_item	2915514	et	4	main
mul	doc_873901597531_item	2915515	et	3	main
seitsmendal	doc_873901597531_item	2915519	et	3	main
palju	doc_873901597531_item	2915528	et	4	main
ei	doc_873901597531_item	2915531	et	4	main
tahaks	doc_873901597531_item	2915540	et	3	main
unistus	doc_873901597531_item	2915550	et	4	main
tohi	doc_873901597531_item	2915556	et	4	main
raske	doc_873901597531_item	2915563	et	4	main
periiod	doc_873901597531_item	2915564	et	4	main
on	doc_873901597531_item	2915585	et	4	main
hästi	doc_873901597531_item	2915586	et	3	main
on	doc_873901597531_item	2915589	et	4	main
vaja	doc_873901597531_item	2915590	et	4	main
on	doc_873901597531_item	2915597	et	4	main
enam	doc_873901597531_item	2915598	et	4	main
vaatame	doc_873901597531_item	2915605	et	3	main
mida	doc_873901597531_item	2915606	et	4	main
tuleb	doc_873901597531_item	2915607	et	3	main
naiteks	doc_873901597531_item	2915620	et	4	main
kusk	doc_873901597531_item	2915627	et	4	main
kõige	doc_873901597531_item	2915645	et	4	main
oli	doc_873901597531_item	2915648	et	3	main
kuske	doc_873901597531_item	2915650	et	3	main
see	doc_873901597531_item	2915652	et	3	main
vaadata	doc_873901597531_item	2915656	et	4	main
toimub	doc_873901597531_item	2915658	et	3	main
ja	doc_873901597531_item	2915660	et	3	main
tähis	doc_873901597532_item	2915674	et	4	main
ülekoolis	doc_873901597532_item	2915675	et	4	main
ma	doc_873901597532_item	2915676	et	3	main
pean	doc_873901597532_item	2915677	et	4	main
tööd	doc_873901597532_item	2915680	et	4	main
teha	doc_873901597531_item	2915506	et	3	main
see	doc_873901597531_item	2915510	et	3	main
veel	doc_873901597531_item	2915512	et	4	main
kahekümne	doc_873901597531_item	2915518	et	4	main
detsembril	doc_873901597531_item	2915520	et	3	main
ja	doc_873901597531_item	2915521	et	3	main
ootan	doc_873901597531_item	2915523	et	3	main
tulevad	doc_873901597531_item	2915527	et	4	main
selles	doc_873901597531_item	2915538	et	4	main
muidugi	doc_873901597531_item	2915541	et	4	main
kõik	doc_873901597531_item	2915551	et	4	main
on	doc_873901597531_item	2915552	et	4	main
tore	doc_873901597531_item	2915553	et	3	main
aga	doc_873901597531_item	2915554	et	3	main
et	doc_873901597531_item	2915558	et	3	main
pärast	doc_873901597531_item	2915559	et	4	main
on	doc_873901597531_item	2915580	et	4	main
ka	doc_873901597531_item	2915591	et	3	main
tulimused	doc_873901597531_item	2915596	et	4	main
vähem	doc_873901597531_item	2915599	et	4	main
siis	doc_873901597531_item	2915600	et	3	main
see	doc_873901597531_item	2915601	et	3	main
jaanuaris	doc_873901597531_item	2915608	et	3	main
sõjaväes	doc_873901597531_item	2915611	et	3	main
et	doc_873901597531_item	2915615	et	3	main
ka	doc_873901597531_item	2915617	et	3	main
teevad	doc_873901597531_item	2915618	et	3	main
kommi	doc_873901597531_item	2915622	et	4	main
j	doc_873901597531_item	2915623	et	4	main
ja	doc_873901597531_item	2915628	et	3	main
saan	doc_873901597531_item	2915634	et	4	main
on	doc_873901597531_item	2915638	et	4	main
siis	doc_873901597531_item	2915644	et	3	main
asi	doc_873901597531_item	2915647	et	4	main
kaunistama	doc_873901597531_item	2915649	et	3	main
ootome	doc_873901597531_item	2915651	et	4	main
tahaks	doc_873901597531_item	2915655	et	3	main
tallinnas	doc_873901597531_item	2915659	et	4	main
oled	doc_873901597532_item	2915672	et	3	main
ja	doc_873901597532_item	2915681	et	3	main
arved	doc_873901597532_item	2915683	et	3	main
algab	doc_873901597532_item	2915685	et	3	main
ma	doc_873901597531_item	2915522	et	3	main
sõpru	doc_873901597531_item	2915529	et	3	main
ma	doc_873901597531_item	2915530	et	3	main
veel	doc_873901597531_item	2915533	et	4	main
kus	doc_873901597531_item	2915534	et	3	main
ma	doc_873901597531_item	2915535	et	3	main
tahan	doc_873901597531_item	2915536	et	3	main
olla	doc_873901597531_item	2915537	et	3	main
unustada	doc_873901597531_item	2915557	et	3	main
seda	doc_873901597531_item	2915560	et	3	main
tuleb	doc_873901597531_item	2915561	et	3	main
väga	doc_873901597531_item	2915562	et	3	main
esimine	doc_873901597531_item	2915565	et	4	main
seesija	doc_873901597531_item	2915566	et	4	main
ma	doc_873901597531_item	2915567	et	3	main
ei	doc_873901597531_item	2915568	et	4	main
tea	doc_873901597531_item	2915569	et	4	main
veel	doc_873901597531_item	2915570	et	4	main
kardan	doc_873901597531_item	2915571	et	4	main
või	doc_873901597531_item	2915572	et	4	main
ei	doc_873901597531_item	2915573	et	4	main
karda	doc_873901597531_item	2915574	et	4	main
seda	doc_873901597531_item	2915575	et	3	main
aga	doc_873901597531_item	2915576	et	3	main
arvan	doc_873901597531_item	2915577	et	3	main
et	doc_873901597531_item	2915578	et	3	main
see	doc_873901597531_item	2915579	et	3	main
puhkema	doc_873901597531_item	2915584	et	4	main
arvan	doc_873901597531_item	2915592	et	3	main
mina	doc_873901597531_item	2915609	et	4	main
tahan	doc_873901597531_item	2915613	et	3	main
olemas	doc_873901597531_item	2915626	et	4	main
lumesõda	doc_873901597531_item	2915633	et	4	main
et	doc_873901597531_item	2915636	et	3	main
oli	doc_873901597531_item	2915642	et	3	main
aeg	doc_873901597531_item	2915653	et	3	main
ttüs	doc_873901597531_item	2915661	et	4	main
et	doc_873901597531_item	2915663	et	3	main
huvitav	doc_873901597531_item	2915666	et	4	main
januaris	doc_873901597532_item	2915684	et	4	main
päris	doc_873901597531_item	2915629	et	4	main
ilus	doc_873901597531_item	2915630	et	4	main
kodus	doc_873901597531_item	2915637	et	4	main
kindlasti	doc_873901597531_item	2915639	et	3	main
parem	doc_873901597531_item	2915640	et	4	main
kui	doc_873901597531_item	2915641	et	3	main
esimine	doc_873901597531_item	2915646	et	4	main
mis	doc_873901597531_item	2915657	et	4	main
arvan	doc_873901597531_item	2915662	et	3	main
peab	doc_873901597531_item	2915664	et	4	main
olema	doc_873901597531_item	2915665	et	4	main
kuu	doc_873901597532_item	2915671	et	4	main
väga	doc_873901597532_item	2915673	et	3	main
mõned	doc_873901597532_item	2915679	et	3	main
sess	doc_873901597532_item	2915686	et	3	main
ja	doc_873901597532_item	2915687	et	3	main
see	doc_873901597532_item	2915688	et	3	main
on	doc_873901597532_item	2915689	et	4	main
stress	doc_873901597532_item	2915690	et	3	main
ma	doc_873901597532_item	2915691	et	3	main
pean	doc_873901597532_item	2915692	et	4	main
palju	doc_873901597532_item	2915693	et	4	main
tegema	doc_873901597532_item	2915694	et	3	main
sest	doc_873901597532_item	2915695	et	4	main
ma	doc_873901597532_item	2915696	et	3	main
tahan	doc_873901597532_item	2915697	et	3	main
õppida	doc_873901597532_item	2915698	et	3	main
teisel	doc_873901597532_item	2915699	et	4	main
kursustel	doc_873901597532_item	2915700	et	3	main
ülekoolis	doc_873901597532_item	2915701	et	4	main
aga	doc_873901597532_item	2915702	et	3	main
mul	doc_873901597532_item	2915703	et	3	main
on	doc_873901597532_item	2915704	et	4	main
ka	doc_873901597532_item	2915705	et	3	main
haa	doc_873901597532_item	2915706	et	3	main
mõtted	doc_873901597532_item	2915707	et	3	main
et	doc_873901597532_item	2915708	et	3	main
detsembis	doc_873901597532_item	2915709	et	4	main
on	doc_873901597532_item	2915710	et	4	main
uusaastat	doc_873901597532_item	2915711	et	3	main
ja	doc_873901597532_item	2915712	et	3	main
jõulud	doc_873901597532_item	2915713	et	3	main
mulle	doc_873901597538_item	2916252	et	4	main
jõuele	doc_873901597538_item	2916284	et	4	main
ma	doc_873901597538_item	2916285	et	3	main
tean	doc_873901597538_item	2916286	et	3	main
et	doc_873901597538_item	2916287	et	3	main
see	doc_873901597538_item	2916288	et	3	main
pidu	doc_873901597538_item	2916289	et	4	main
tähtis	doc_873901597538_item	2916292	et	4	main
eestlane	doc_873901597538_item	2916293	et	3	main
jõue	doc_873901597538_item	2916297	et	4	main
võib	doc_873901597538_item	2916304	et	3	main
tula	doc_873901597538_item	2916306	et	4	main
külas	doc_873901597538_item	2916308	et	3	main
otan	doc_873901597538_item	2916317	et	4	main
on	doc_873901597538_item	2916322	et	4	main
pidu	doc_873901597538_item	2916324	et	4	main
essee	doc_873901597539_item	2916325	et	4	main
essee	doc_873901597538_item	2916249	et	4	main
meeldib	doc_873901597538_item	2916254	et	3	main
ükskõik	doc_873901597538_item	2916258	et	3	main
tähistama	doc_873901597538_item	2916260	et	3	main
pidu	doc_873901597538_item	2916262	et	4	main
kingitus	doc_873901597538_item	2916283	et	4	main
jaoks	doc_873901597538_item	2916294	et	4	main
sest	doc_873901597538_item	2916295	et	4	main
see	doc_873901597538_item	2916296	et	3	main
et	doc_873901597538_item	2916303	et	3	main
kellegi	doc_873901597538_item	2916307	et	4	main
seal	doc_873901597538_item	2916310	et	4	main
koos	doc_873901597538_item	2916311	et	4	main
sõpradega	doc_873901597538_item	2916312	et	3	main
minu	doc_873901597538_item	2916250	et	3	main
uut	doc_873901597538_item	2916255	et	3	main
aga	doc_873901597538_item	2916257	et	3	main
on	doc_873901597538_item	2916280	et	4	main
on	doc_873901597538_item	2916298	et	4	main
ja	doc_873901597538_item	2916309	et	3	main
uut	doc_873901597538_item	2916318	et	3	main
see	doc_873901597538_item	2916321	et	3	main
lõbusam	doc_873901597538_item	2916323	et	4	main
jõulu	doc_873901597539_item	2916330	et	4	main
ei	doc_873901597539_item	2916331	et	4	main
selleks	doc_873901597539_item	2916349	et	4	main
pidu	doc_873901597539_item	2916351	et	4	main
aga	doc_873901597539_item	2916359	et	3	main
uus	doc_873901597539_item	2916360	et	3	main
aasta	doc_873901597539_item	2916361	et	4	main
hetkel	doc_873901597539_item	2916375	et	4	main
kuidas	doc_873901597539_item	2916376	et	3	main
aga	doc_873901597539_item	2916377	et	3	main
olen	doc_873901597539_item	2916378	et	3	main
kindel	doc_873901597539_item	2916379	et	3	main
et	doc_873901597539_item	2916380	et	3	main
see	doc_873901597539_item	2916381	et	3	main
juhtub	doc_873901597539_item	2916382	et	3	main
pean	doc_873901597539_item	2916390	et	4	main
uus	doc_873901597539_item	2916399	et	3	main
on	doc_873901597539_item	2916401	et	4	main
vodkat	doc_873901597539_item	2916408	et	3	main
j	doc_873901597539_item	2916411	et	4	main
öösel	doc_873901597539_item	2916415	et	4	main
lähevad	doc_873901597539_item	2916422	et	3	main
sinna	doc_873901597539_item	2916424	et	3	main
ja	doc_873901597539_item	2916430	et	3	main
pärast	doc_873901597539_item	2916433	et	4	main
hommik	doc_873901597539_item	2916434	et	3	main
tuleb	doc_873901597539_item	2916435	et	3	main
õnnelikud	doc_873901597539_item	2916440	et	3	main
mis	doc_873901597539_item	2916447	et	4	main
jattis	doc_873901597539_item	2916448	et	4	main
pärast	doc_873901597539_item	2916455	et	4	main
hea	doc_873901597539_item	2916458	et	4	main
uus	doc_873901597539_item	2916467	et	3	main
lemmik	doc_873901597539_item	2916472	et	3	main
j	doc_873901597539_item	2916474	et	4	main
jõuemõtted	doc_873901597538_item	2916251	et	4	main
rohkem	doc_873901597538_item	2916253	et	4	main
aasta	doc_873901597538_item	2916256	et	4	main
me	doc_873901597538_item	2916259	et	4	main
kõige	doc_873901597538_item	2916281	et	4	main
parem	doc_873901597538_item	2916282	et	4	main
väga	doc_873901597538_item	2916291	et	3	main
mõtlen	doc_873901597538_item	2916302	et	3	main
nii	doc_873901597539_item	2916333	et	3	main
minuks	doc_873901597539_item	2916336	et	3	main
jõulu	doc_873901597539_item	2916347	et	4	main
ajal	doc_873901597539_item	2916348	et	4	main
rohkem	doc_873901597539_item	2916355	et	4	main
raha	doc_873901597539_item	2916356	et	4	main
maksatakse	doc_873901597539_item	2916357	et	3	main
j	doc_873901597539_item	2916358	et	4	main
lemmikum	doc_873901597539_item	2916365	et	4	main
ma	doc_873901597539_item	2916369	et	3	main
hulgas	doc_873901597539_item	2916386	et	4	main
aga	doc_873901597539_item	2916398	et	3	main
kui	doc_873901597539_item	2916416	et	3	main
kõik	doc_873901597539_item	2916417	et	4	main
juba	doc_873901597539_item	2916418	et	3	main
kõik	doc_873901597539_item	2916421	et	4	main
vanalinna	doc_873901597539_item	2916423	et	4	main
palju	doc_873901597539_item	2916426	et	4	main
rahvast	doc_873901597539_item	2916427	et	4	main
kõikidel	doc_873901597539_item	2916436	et	4	main
võitlema	doc_873901597539_item	2916443	et	3	main
joovad	doc_873901597539_item	2916450	et	4	main
vimas	doc_873901597539_item	2916451	et	4	main
alkoholi	doc_873901597539_item	2916452	et	4	main
paari	doc_873901597539_item	2916453	et	4	main
on	doc_873901597539_item	2916462	et	4	main
pidu	doc_873901597539_item	2916473	et	4	main
jõulumõtte	doc_873901597542_item	2916721	et	3	main
see	doc_873901597538_item	2916261	et	3	main
ma	doc_873901597538_item	2916263	et	3	main
tähistan	doc_873901597538_item	2916264	et	3	main
jõue	doc_873901597538_item	2916265	et	4	main
koos	doc_873901597538_item	2916266	et	4	main
ema	doc_873901597538_item	2916267	et	4	main
ja	doc_873901597538_item	2916268	et	3	main
isaga	doc_873901597538_item	2916269	et	3	main
aga	doc_873901597538_item	2916270	et	3	main
sellel	doc_873901597538_item	2916271	et	4	main
aastal	doc_873901597538_item	2916272	et	3	main
mulle	doc_873901597538_item	2916273	et	4	main
vaja	doc_873901597538_item	2916274	et	4	main
soritada	doc_873901597538_item	2916275	et	4	main
kõik	doc_873901597538_item	2916276	et	4	main
arvestused	doc_873901597538_item	2916277	et	4	main
ja	doc_873901597538_item	2916278	et	3	main
see	doc_873901597538_item	2916279	et	3	main
on	doc_873901597538_item	2916290	et	4	main
katoline	doc_873901597538_item	2916299	et	4	main
praegu	doc_873901597538_item	2916300	et	3	main
ma	doc_873901597538_item	2916301	et	3	main
olla	doc_873901597538_item	2916305	et	3	main
jõua	doc_873901597538_item	2916313	et	4	main
õlut	doc_873901597538_item	2916314	et	3	main
niisama	doc_873901597538_item	2916315	et	3	main
ma	doc_873901597538_item	2916316	et	3	main
aasta	doc_873901597538_item	2916319	et	4	main
sest	doc_873901597538_item	2916320	et	4	main
jõulu	doc_873901597539_item	2916327	et	4	main
mõtted	doc_873901597539_item	2916328	et	3	main
kõigepealt	doc_873901597539_item	2916329	et	3	main
suur	doc_873901597539_item	2916334	et	3	main
pidutsenud	doc_873901597539_item	2916342	et	4	main
sel	doc_873901597539_item	2916343	et	3	main
annaks	doc_873901597539_item	2916352	et	4	main
mingi	doc_873901597539_item	2916353	et	4	main
kasu	doc_873901597539_item	2916354	et	4	main
on	doc_873901597539_item	2916362	et	4	main
minu	doc_873901597539_item	2916363	et	3	main
pidu	doc_873901597539_item	2916366	et	4	main
ja	doc_873901597539_item	2916367	et	3	main
pidutsen	doc_873901597539_item	2916370	et	3	main
nagu	doc_873901597539_item	2916383	et	3	main
soprade	doc_873901597539_item	2916385	et	4	main
lõbuses	doc_873901597539_item	2916388	et	3	main
atmosfääris	doc_873901597539_item	2916389	et	3	main
vodkat	doc_873901597539_item	2916393	et	3	main
seda	doc_873901597539_item	2916397	et	3	main
pidu	doc_873901597539_item	2916404	et	4	main
et	doc_873901597539_item	2916405	et	3	main
saavad	doc_873901597539_item	2916419	et	4	main
kus	doc_873901597539_item	2916425	et	3	main
muusika	doc_873901597539_item	2916429	et	4	main
on	doc_873901597539_item	2916437	et	4	main
rohelised	doc_873901597539_item	2916438	et	4	main
hakkavad	doc_873901597539_item	2916442	et	4	main
pohmakaga	doc_873901597539_item	2916444	et	4	main
pidust	doc_873901597539_item	2916449	et	4	main
on	doc_873901597539_item	2916457	et	4	main
meel	doc_873901597539_item	2916459	et	4	main
ja	doc_873901597539_item	2916460	et	3	main
kõik	doc_873901597539_item	2916461	et	4	main
aasta	doc_873901597539_item	2916468	et	4	main
on	doc_873901597539_item	2916469	et	4	main
minu	doc_873901597539_item	2916470	et	3	main
ole	doc_873901597539_item	2916332	et	4	main
pidu	doc_873901597539_item	2916335	et	4	main
ma	doc_873901597539_item	2916337	et	3	main
talvel	doc_873901597539_item	2916344	et	4	main
tahaks	doc_873901597539_item	2916345	et	3	main
töötada	doc_873901597539_item	2916346	et	3	main
minu	doc_873901597539_item	2916326	et	3	main
ei	doc_873901597539_item	2916338	et	4	main
ole	doc_873901597539_item	2916339	et	4	main
seda	doc_873901597539_item	2916340	et	3	main
kunagi	doc_873901597539_item	2916341	et	3	main
ja	doc_873901597539_item	2916387	et	3	main
siis	doc_873901597539_item	2916391	et	3	main
ma	doc_873901597539_item	2916395	et	3	main
tahtis	doc_873901597539_item	2916403	et	3	main
ikka	doc_873901597539_item	2916406	et	4	main
kord	doc_873901597539_item	2916409	et	4	main
purjuseks	doc_873901597539_item	2916420	et	4	main
et	doc_873901597539_item	2916350	et	3	main
kõige	doc_873901597539_item	2916364	et	4	main
seda	doc_873901597539_item	2916368	et	3	main
kohustuslikult	doc_873901597539_item	2916371	et	4	main
ma	doc_873901597539_item	2916372	et	3	main
ei	doc_873901597539_item	2916373	et	4	main
tea	doc_873901597539_item	2916374	et	4	main
alati	doc_873901597539_item	2916384	et	4	main
ikka	doc_873901597539_item	2916392	et	4	main
jõua	doc_873901597539_item	2916394	et	4	main
vihkan	doc_873901597539_item	2916396	et	3	main
aasta	doc_873901597539_item	2916400	et	4	main
nii	doc_873901597539_item	2916402	et	3	main
joon	doc_873901597539_item	2916407	et	4	main
aastas	doc_873901597539_item	2916410	et	3	main
olen	doc_873901597539_item	2916412	et	3	main
kindel	doc_873901597539_item	2916413	et	3	main
et	doc_873901597539_item	2916414	et	3	main
mängib	doc_873901597539_item	2916428	et	3	main
taevas	doc_873901597539_item	2916431	et	4	main
põleb	doc_873901597539_item	2916432	et	3	main
aga	doc_873901597539_item	2916439	et	3	main
söövad	doc_873901597539_item	2916445	et	4	main
seda	doc_873901597539_item	2916446	et	3	main
kõikidel	doc_873901597539_item	2916456	et	4	main
valmid	doc_873901597539_item	2916463	et	4	main
teha	doc_873901597539_item	2916464	et	3	main
midagi	doc_873901597539_item	2916465	et	4	main
suurepäärase	doc_873901597539_item	2916466	et	3	main
arvan	doc_873901597542_item	2916727	et	3	main
meeldib	doc_873901597542_item	2916730	et	3	main
kui	doc_873901597542_item	2916744	et	3	main
12	doc_873901597542_item	2916748	et	2	main
ole	doc_873901597542_item	2916754	et	4	main
võin	doc_873901597542_item	2916758	et	3	main
laplandiasse	doc_873901597542_item	2916778	et	4	main
seal	doc_873901597542_item	2916781	et	4	main
seal	doc_873901597542_item	2916783	et	4	main
oli	doc_873901597542_item	2916785	et	3	main
suur	doc_873901597542_item	2916786	et	3	main
lumelinn	doc_873901597542_item	2916787	et	3	main
teate	doc_873901597542_item	2916822	et	4	main
see	doc_873901597542_item	2916824	et	3	main
aeg	doc_873901597542_item	2916825	et	3	main
on	doc_873901597542_item	2916826	et	4	main
väga	doc_873901597542_item	2916827	et	3	main
algavad	doc_873901597542_item	2916833	et	4	main
eksameid	doc_873901597542_item	2916834	et	3	main
väga	doc_873901597542_item	2916835	et	3	main
raskeid	doc_873901597542_item	2916836	et	3	main
eksameid	doc_873901597542_item	2916837	et	3	main
jääks	doc_873901597542_item	2916868	et	4	main
üks	doc_873901597542_item	2916875	et	3	main
nägud	doc_873901597539_item	2916441	et	4	main
tundi	doc_873901597539_item	2916454	et	4	main
kõige	doc_873901597539_item	2916471	et	4	main
jõulu	doc_873901597542_item	2916722	et	4	main
on	doc_873901597542_item	2916723	et	4	main
raskusi	doc_873901597542_item	2916739	et	4	main
on	doc_873901597542_item	2916740	et	4	main
eelmisel	doc_873901597542_item	2916745	et	3	main
õpin	doc_873901597542_item	2916747	et	3	main
mul	doc_873901597542_item	2916752	et	3	main
päev	doc_873901597542_item	2916760	et	3	main
koos	doc_873901597542_item	2916762	et	4	main
perega	doc_873901597542_item	2916764	et	3	main
turistid	doc_873901597542_item	2916795	et	3	main
et	doc_873901597542_item	2916801	et	3	main
jaanuari	doc_873901597542_item	2916831	et	4	main
algus	doc_873901597542_item	2916832	et	4	main
päevad	doc_873901597542_item	2916846	et	3	main
on	doc_873901597542_item	2916873	et	4	main
soov	doc_873901597542_item	2916878	et	3	main
minu	doc_873901597543_item	2916880	et	3	main
aga	doc_873901597543_item	2916910	et	3	main
ole	doc_873901597543_item	2916913	et	4	main
jõulu	doc_873901597543_item	2916914	et	4	main
rõõmsast	doc_873901597543_item	2916917	et	3	main
ei	doc_873901597543_item	2916923	et	4	main
selle	doc_873901597543_item	2916925	et	4	main
on	doc_873901597543_item	2916930	et	4	main
jõulu	doc_873901597543_item	2916943	et	4	main
söök	doc_873901597543_item	2916944	et	3	main
ole	doc_873901597543_item	2916956	et	4	main
ja	doc_873901597543_item	2916958	et	3	main
jõulu	doc_873901597543_item	2916959	et	4	main
kust	doc_873901597543_item	2916987	et	4	main
aeg	doc_873901597543_item	2916993	et	3	main
endast	doc_873901597543_item	2916995	et	4	main
mõttede	doc_873901597543_item	2917014	et	4	main
mõtted	doc_873901597543_item	2917023	et	3	main
nagu	doc_873901597543_item	2917026	et	3	main
ikkagi	doc_873901597543_item	2917028	et	4	main
viis	doc_873901597543_item	2917029	et	4	main
on	doc_873901597543_item	2917038	et	4	main
laplandias	doc_873901597543_item	2917042	et	4	main
et	doc_873901597543_item	2917046	et	3	main
peavad	doc_873901597543_item	2917049	et	4	main
ikkagi	doc_873901597543_item	2917051	et	4	main
on	doc_873901597543_item	2917065	et	4	main
tore	doc_873901597542_item	2916725	et	3	main
pidu	doc_873901597542_item	2916726	et	4	main
kõikidele	doc_873901597542_item	2916729	et	4	main
see	doc_873901597542_item	2916731	et	3	main
sest	doc_873901597542_item	2916733	et	4	main
nad	doc_873901597542_item	2916734	et	3	main
olemas	doc_873901597542_item	2916741	et	4	main
ainult	doc_873901597542_item	2916742	et	4	main
siis	doc_873901597542_item	2916750	et	3	main
mingeid	doc_873901597542_item	2916755	et	3	main
kogu	doc_873901597542_item	2916759	et	4	main
jalutada	doc_873901597542_item	2916761	et	3	main
sõidasin	doc_873901597542_item	2916777	et	4	main
kõik	doc_873901597542_item	2916794	et	4	main
jalutavad	doc_873901597542_item	2916796	et	4	main
nii	doc_873901597542_item	2916799	et	3	main
essee	doc_873901597542_item	2916720	et	4	main
et	doc_873901597542_item	2916728	et	3	main
päev	doc_873901597542_item	2916732	et	3	main
võivad	doc_873901597542_item	2916735	et	4	main
hästi	doc_873901597542_item	2916736	et	3	main
aega	doc_873901597542_item	2916737	et	4	main
aastal	doc_873901597542_item	2916746	et	3	main
ei	doc_873901597542_item	2916753	et	4	main
probleeme	doc_873901597542_item	2916756	et	3	main
kolm	doc_873901597542_item	2916774	et	3	main
aastat	doc_873901597542_item	2916775	et	3	main
ja	doc_873901597542_item	2916779	et	3	main
jõuluvanu	doc_873901597542_item	2916782	et	3	main
oli	doc_873901597542_item	2916798	et	3	main
ma	doc_873901597542_item	2916802	et	3	main
olen	doc_873901597542_item	2916803	et	3	main
väga	doc_873901597542_item	2916804	et	3	main
onnelik	doc_873901597542_item	2916805	et	4	main
aga	doc_873901597542_item	2916806	et	3	main
missugused	doc_873901597542_item	2916807	et	3	main
jõulud	doc_873901597542_item	2916808	et	3	main
on	doc_873901597542_item	2916809	et	4	main
sel	doc_873901597542_item	2916810	et	3	main
aastal	doc_873901597542_item	2916811	et	3	main
väga	doc_873901597542_item	2916812	et	3	main
raske	doc_873901597542_item	2916813	et	4	main
vastata	doc_873901597542_item	2916814	et	4	main
sest	doc_873901597542_item	2916815	et	4	main
ma	doc_873901597542_item	2916816	et	3	main
olen	doc_873901597542_item	2916817	et	3	main
tudeng	doc_873901597542_item	2916818	et	3	main
ja	doc_873901597542_item	2916819	et	3	main
kuidas	doc_873901597542_item	2916820	et	3	main
te	doc_873901597542_item	2916821	et	4	main
jõulude	doc_873901597542_item	2916845	et	3	main
see	doc_873901597542_item	2916849	et	3	main
kaks	doc_873901597542_item	2916851	et	3	main
või	doc_873901597542_item	2916853	et	4	main
tagasi	doc_873901597542_item	2916856	et	3	main
et	doc_873901597542_item	2916859	et	3	main
praegu	doc_873901597542_item	2916871	et	3	main
see	doc_873901597542_item	2916872	et	3	main
essee	doc_873901597543_item	2916879	et	4	main
jõulumõttet	doc_873901597543_item	2916881	et	4	main
ja	doc_873901597543_item	2916918	et	3	main
et	doc_873901597543_item	2916921	et	3	main
ja	doc_873901597543_item	2916941	et	3	main
aru	doc_873901597543_item	2916951	et	4	main
saada	doc_873901597543_item	2916952	et	4	main
katolikline	doc_873901597543_item	2916976	et	4	main
jõulu	doc_873901597543_item	2916977	et	4	main
pea	doc_873901597543_item	2916981	et	4	main
probleme	doc_873901597543_item	2916984	et	4	main
leida	doc_873901597543_item	2916991	et	3	main
kõik	doc_873901597543_item	2916997	et	4	main
õppimise	doc_873901597543_item	2916999	et	4	main
eest	doc_873901597543_item	2917000	et	4	main
ja	doc_873901597543_item	2917001	et	3	main
kuidas	doc_873901597543_item	2917002	et	3	main
sooritada	doc_873901597543_item	2917003	et	3	main
eksamid	doc_873901597543_item	2917004	et	3	main
ja	doc_873901597543_item	2917005	et	3	main
saada	doc_873901597543_item	2917006	et	4	main
ole	doc_873901597543_item	2917011	et	4	main
väga	doc_873901597542_item	2916724	et	3	main
veeta	doc_873901597542_item	2916738	et	4	main
tudengitel	doc_873901597542_item	2916743	et	3	main
klassil	doc_873901597542_item	2916749	et	3	main
jõuludel	doc_873901597542_item	2916751	et	3	main
ma	doc_873901597542_item	2916757	et	3	main
oma	doc_873901597542_item	2916763	et	4	main
olema	doc_873901597542_item	2916765	et	4	main
sõpradega	doc_873901597542_item	2916766	et	3	main
vestlema	doc_873901597542_item	2916767	et	3	main
ühesõnaga	doc_873901597542_item	2916768	et	3	main
ma	doc_873901597542_item	2916769	et	3	main
ootasin	doc_873901597542_item	2916770	et	3	main
jõulusid	doc_873901597542_item	2916771	et	3	main
mäletan	doc_873901597542_item	2916772	et	3	main
kui	doc_873901597542_item	2916773	et	3	main
tagasi	doc_873901597542_item	2916776	et	3	main
näen	doc_873901597542_item	2916780	et	3	main
veel	doc_873901597542_item	2916784	et	4	main
kus	doc_873901597542_item	2916788	et	3	main
need	doc_873901597542_item	2916789	et	3	main
jõuluvanad	doc_873901597542_item	2916790	et	3	main
elavad	doc_873901597542_item	2916791	et	4	main
ja	doc_873901597542_item	2916792	et	3	main
kus	doc_873901597542_item	2916793	et	3	main
kõik	doc_873901597542_item	2916797	et	4	main
tore	doc_873901597542_item	2916800	et	3	main
jaoks	doc_873901597542_item	2916830	et	4	main
ei	doc_873901597542_item	2916842	et	4	main
saa	doc_873901597542_item	2916843	et	4	main
hästi	doc_873901597542_item	2916844	et	3	main
oli	doc_873901597542_item	2916850	et	3	main
kolm	doc_873901597542_item	2916852	et	3	main
neli	doc_873901597542_item	2916854	et	3	main
aastat	doc_873901597542_item	2916855	et	3	main
ainult	doc_873901597542_item	2916858	et	4	main
ttüs	doc_873901597542_item	2916869	et	4	main
õppima	doc_873901597542_item	2916870	et	3	main
ja	doc_873901597542_item	2916876	et	3	main
otsivad	doc_873901597543_item	2916906	et	4	main
ja	doc_873901597543_item	2916907	et	3	main
kingituseid	doc_873901597543_item	2916909	et	4	main
mul	doc_873901597543_item	2916911	et	3	main
et	doc_873901597542_item	2916823	et	3	main
raske	doc_873901597542_item	2916828	et	4	main
tudengi	doc_873901597542_item	2916829	et	3	main
mul	doc_873901597542_item	2916838	et	3	main
tundub	doc_873901597542_item	2916839	et	3	main
et	doc_873901597542_item	2916840	et	3	main
ma	doc_873901597542_item	2916841	et	3	main
veeta	doc_873901597542_item	2916847	et	4	main
nagu	doc_873901597542_item	2916848	et	3	main
tahtsin	doc_873901597542_item	2916857	et	3	main
pärast	doc_873901597542_item	2916860	et	4	main
jõulud	doc_873901597542_item	2916861	et	3	main
mina	doc_873901597542_item	2916862	et	4	main
sooritaksin	doc_873901597542_item	2916863	et	3	main
kõik	doc_873901597542_item	2916864	et	4	main
eksameid	doc_873901597542_item	2916865	et	3	main
hästi	doc_873901597542_item	2916866	et	3	main
ja	doc_873901597542_item	2916867	et	3	main
minu	doc_873901597542_item	2916874	et	3	main
varsti	doc_873901597543_item	2916882	et	3	main
eestisse	doc_873901597543_item	2916883	et	4	main
tuleb	doc_873901597543_item	2916884	et	3	main
jõulu	doc_873901597543_item	2916885	et	4	main
ja	doc_873901597543_item	2916886	et	3	main
paljude	doc_873901597543_item	2916887	et	3	main
inimeste	doc_873901597543_item	2916888	et	3	main
eest	doc_873901597543_item	2916889	et	4	main
see	doc_873901597543_item	2916890	et	3	main
tähendab	doc_873901597543_item	2916891	et	3	main
et	doc_873901597543_item	2916892	et	3	main
nende	doc_873901597543_item	2916893	et	4	main
lemmiku	doc_873901597543_item	2916894	et	3	main
ja	doc_873901597543_item	2916895	et	3	main
tähtsaim	doc_873901597543_item	2916896	et	4	main
pidu	doc_873901597543_item	2916897	et	4	main
varsti	doc_873901597543_item	2916898	et	3	main
toimub	doc_873901597543_item	2916899	et	3	main
kõik	doc_873901597543_item	2916900	et	4	main
katoliklised	doc_873901597543_item	2916901	et	4	main
pidetsevad	doc_873901597543_item	2916902	et	4	main
oma	doc_873901597543_item	2916903	et	4	main
peapidu	doc_873901597543_item	2916904	et	4	main
paljud	doc_873901597543_item	2916905	et	3	main
suur	doc_873901597542_item	2916877	et	3	main
ostavad	doc_873901597543_item	2916908	et	3	main
meleolu	doc_873901597543_item	2916915	et	4	main
sellepärast	doc_873901597543_item	2916920	et	3	main
poole	doc_873901597543_item	2916928	et	4	main
see	doc_873901597543_item	2916929	et	3	main
kõik	doc_873901597543_item	2916934	et	4	main
istuvad	doc_873901597543_item	2916936	et	4	main
kõik	doc_873901597543_item	2916937	et	4	main
söövad	doc_873901597543_item	2916942	et	4	main
ja	doc_873901597543_item	2916945	et	3	main
viin	doc_873901597543_item	2916947	et	4	main
mul	doc_873901597543_item	2916948	et	3	main
on	doc_873901597543_item	2916949	et	4	main
mõttet	doc_873901597543_item	2916978	et	4	main
nagu	doc_873901597543_item	2916986	et	3	main
vaba	doc_873901597543_item	2916992	et	4	main
oma	doc_873901597543_item	2916994	et	4	main
arvestused	doc_873901597543_item	2917007	et	4	main
praegu	doc_873901597543_item	2917008	et	3	main
jõulu	doc_873901597543_item	2917013	et	4	main
tekkisid	doc_873901597543_item	2917021	et	4	main
eest	doc_873901597543_item	2917025	et	4	main
kuus	doc_873901597543_item	2917031	et	4	main
aastat	doc_873901597543_item	2917032	et	3	main
tagasi	doc_873901597543_item	2917033	et	3	main
uskusin	doc_873901597543_item	2917035	et	3	main
ja	doc_873901597543_item	2917040	et	3	main
arvan	doc_873901597543_item	2917045	et	3	main
meie	doc_873901597543_item	2917063	et	4	main
unistama	doc_873901597543_item	2917070	et	3	main
ole	doc_873901597543_item	2917072	et	4	main
kahjulik	doc_873901597543_item	2917073	et	3	main
ei	doc_873901597543_item	2916912	et	4	main
pole	doc_873901597543_item	2916916	et	3	main
soovitused	doc_873901597543_item	2916919	et	4	main
pidetsun	doc_873901597543_item	2916924	et	4	main
peo	doc_873901597543_item	2916926	et	4	main
minu	doc_873901597543_item	2916927	et	3	main
päev	doc_873901597543_item	2916932	et	3	main
koos	doc_873901597543_item	2916938	et	4	main
laua	doc_873901597543_item	2916939	et	3	main
taga	doc_873901597543_item	2916940	et	4	main
joovad	doc_873901597543_item	2916946	et	4	main
miks	doc_873901597543_item	2916953	et	4	main
mul	doc_873901597543_item	2916954	et	3	main
soovitused	doc_873901597543_item	2916957	et	4	main
on	doc_873901597543_item	2916975	et	4	main
vastu	doc_873901597543_item	2916979	et	3	main
täis	doc_873901597543_item	2916985	et	4	main
praegu	doc_873901597543_item	2916996	et	3	main
mõttet	doc_873901597543_item	2916998	et	4	main
peas	doc_873901597543_item	2917009	et	4	main
ei	doc_873901597543_item	2917010	et	4	main
mul	doc_873901597543_item	2917020	et	3	main
või	doc_873901597543_item	2917030	et	4	main
jõuluvana	doc_873901597543_item	2917037	et	4	main
olemas	doc_873901597543_item	2917039	et	4	main
elab	doc_873901597543_item	2917041	et	3	main
kokkuvõtteks	doc_873901597543_item	2917043	et	3	main
ma	doc_873901597543_item	2917044	et	3	main
jõulu	doc_873901597543_item	2917047	et	4	main
üheks	doc_873901597543_item	2917052	et	3	main
tuld	doc_873901597543_item	2917068	et	3	main
sellepärast	doc_873901597543_item	2917069	et	3	main
rõõmus	doc_873901597546_item	2917391	et	4	main
ma	doc_873901597546_item	2917421	et	3	main
päeval	doc_873901597546_item	2917439	et	3	main
ma	doc_873901597543_item	2916922	et	3	main
tavaline	doc_873901597543_item	2916931	et	4	main
kuidas	doc_873901597543_item	2916933	et	3	main
perekonnad	doc_873901597543_item	2916935	et	4	main
raske	doc_873901597543_item	2916950	et	4	main
ei	doc_873901597543_item	2916955	et	4	main
meeleolu	doc_873901597543_item	2916960	et	4	main
võib	doc_873901597543_item	2916961	et	3	main
olla	doc_873901597543_item	2916962	et	3	main
see	doc_873901597543_item	2916963	et	3	main
on	doc_873901597543_item	2916964	et	4	main
seotud	doc_873901597543_item	2916965	et	4	main
minu	doc_873901597543_item	2916966	et	3	main
perega	doc_873901597543_item	2916967	et	3	main
meie	doc_873901597543_item	2916968	et	4	main
peres	doc_873901597543_item	2916969	et	3	main
jõulu	doc_873901597543_item	2916970	et	4	main
ei	doc_873901597543_item	2916971	et	4	main
pidetsuvad	doc_873901597543_item	2916972	et	4	main
sellepärast	doc_873901597543_item	2916973	et	3	main
see	doc_873901597543_item	2916974	et	3	main
minu	doc_873901597543_item	2916980	et	3	main
on	doc_873901597543_item	2916982	et	4	main
teise	doc_873901597543_item	2916983	et	4	main
võta	doc_873901597543_item	2916988	et	4	main
raha	doc_873901597543_item	2916989	et	4	main
kus	doc_873901597543_item	2916990	et	3	main
eest	doc_873901597543_item	2917015	et	4	main
aga	doc_873901597543_item	2917016	et	3	main
ma	doc_873901597543_item	2917017	et	3	main
soovitan	doc_873901597543_item	2917018	et	3	main
et	doc_873901597543_item	2917019	et	3	main
ruumi	doc_873901597543_item	2917012	et	4	main
kingituse	doc_873901597543_item	2917024	et	4	main
lapsepõlves	doc_873901597543_item	2917027	et	4	main
ma	doc_873901597543_item	2917034	et	3	main
et	doc_873901597543_item	2917036	et	3	main
tekkima	doc_873901597543_item	2917050	et	3	main
päevak	doc_873901597543_item	2917053	et	3	main
või	doc_873901597543_item	2917054	et	4	main
üheks	doc_873901597543_item	2917055	et	3	main
tunniks	doc_873901597543_item	2917056	et	3	main
et	doc_873901597543_item	2917057	et	3	main
kingitada	doc_873901597543_item	2917058	et	4	main
rõõmu	doc_873901597543_item	2917059	et	4	main
mõttet	doc_873901597543_item	2917064	et	4	main
ei	doc_873901597543_item	2917071	et	4	main
pole	doc_873901597546_item	2917398	et	3	main
oma	doc_873901597546_item	2917424	et	4	main
toovad	doc_873901597546_item	2917437	et	4	main
jõulu	doc_873901597543_item	2917022	et	4	main
mõtted	doc_873901597543_item	2917048	et	3	main
oma	doc_873901597543_item	2917060	et	4	main
südamele	doc_873901597543_item	2917061	et	3	main
eest	doc_873901597543_item	2917062	et	4	main
vabem	doc_873901597543_item	2917066	et	4	main
kui	doc_873901597543_item	2917067	et	3	main
essee	doc_873901597546_item	2917384	et	4	main
jõulumõtte	doc_873901597546_item	2917385	et	3	main
jõulud	doc_873901597546_item	2917386	et	3	main
on	doc_873901597546_item	2917387	et	4	main
väga	doc_873901597546_item	2917388	et	3	main
tore	doc_873901597546_item	2917389	et	3	main
ja	doc_873901597546_item	2917390	et	3	main
inimest	doc_873901597546_item	2917399	et	3	main
kodus	doc_873901597546_item	2917423	et	4	main
kõigede	doc_873901597546_item	2917426	et	4	main
jaoks	doc_873901597546_item	2917428	et	4	main
detsember	doc_873901597546_item	2917429	et	3	main
kõige	doc_873901597546_item	2917431	et	4	main
kuu	doc_873901597546_item	2917433	et	4	main
kingitusi	doc_873901597546_item	2917441	et	4	main
kommid	doc_873901597546_item	2917442	et	3	main
mandariinid	doc_873901597546_item	2917443	et	3	main
küpsised	doc_873901597546_item	2917444	et	3	main
ja	doc_873901597546_item	2917445	et	3	main
on	doc_873901597546_item	2917450	et	4	main
perepidu	doc_873901597546_item	2917458	et	4	main
perekond	doc_873901597546_item	2917459	et	3	main
kiirikus	doc_873901597546_item	2917461	et	3	main
pidu	doc_873901597546_item	2917392	et	4	main
ma	doc_873901597546_item	2917393	et	3	main
maailmas	doc_873901597546_item	2917397	et	3	main
kellele	doc_873901597546_item	2917400	et	4	main
ei	doc_873901597546_item	2917401	et	4	main
meeldi	doc_873901597546_item	2917402	et	4	main
seda	doc_873901597546_item	2917403	et	3	main
pidu	doc_873901597546_item	2917404	et	4	main
jõuludega	doc_873901597546_item	2917405	et	3	main
mul	doc_873901597546_item	2917406	et	3	main
on	doc_873901597546_item	2917407	et	4	main
seotud	doc_873901597546_item	2917408	et	4	main
kõige	doc_873901597546_item	2917409	et	4	main
paremad	doc_873901597546_item	2917410	et	4	main
tunned	doc_873901597546_item	2917411	et	3	main
minu	doc_873901597546_item	2917412	et	3	main
tuju	doc_873901597546_item	2917413	et	4	main
parem	doc_873901597546_item	2917414	et	4	main
kui	doc_873901597546_item	2917415	et	3	main
tavaliselt	doc_873901597546_item	2917416	et	4	main
palju	doc_873901597546_item	2917417	et	4	main
probleemide	doc_873901597546_item	2917418	et	3	main
nägemata	doc_873901597546_item	2917419	et	4	main
jõulupäevadel	doc_873901597546_item	2917420	et	3	main
perega	doc_873901597546_item	2917425	et	3	main
väekesi	doc_873901597546_item	2917440	et	4	main
on	doc_873901597546_item	2917457	et	4	main
olen	doc_873901597546_item	2917394	et	3	main
kindel	doc_873901597546_item	2917395	et	3	main
et	doc_873901597546_item	2917396	et	3	main
olen	doc_873901597546_item	2917422	et	3	main
lastede	doc_873901597546_item	2917427	et	4	main
on	doc_873901597546_item	2917430	et	4	main
unistatud	doc_873901597546_item	2917432	et	4	main
aastast	doc_873901597546_item	2917434	et	4	main
kuna	doc_873901597546_item	2917435	et	3	main
päkapikud	doc_873901597546_item	2917436	et	4	main
igal	doc_873901597546_item	2917438	et	3	main
muidugi	doc_873901597546_item	2917446	et	4	main
mänguasjad	doc_873901597546_item	2917447	et	3	main
inimese	doc_873901597546_item	2917448	et	4	main
ümber	doc_873901597546_item	2917449	et	3	main
kõik	doc_873901597546_item	2917451	et	4	main
läheb	doc_873901597546_item	2917460	et	3	main
ilus	doc_873901597546_item	2917452	et	4	main
linnad	doc_873901597546_item	2917453	et	3	main
on	doc_873901597546_item	2917454	et	4	main
pidu	doc_873901597548_item	2917648	et	4	main
sai	doc_873901597548_item	2917650	et	4	main
pidu	doc_873901597548_item	2917676	et	4	main
see	doc_873901597548_item	2917682	et	3	main
pidu	doc_873901597548_item	2917684	et	4	main
mis	doc_873901597548_item	2917685	et	4	main
ja	doc_873901597548_item	2917688	et	3	main
uuel	doc_873901597548_item	2917702	et	3	main
šampus	doc_873901597548_item	2917706	et	2	main
minu	doc_873901597549_item	2917708	et	3	main
jõulumõtted	doc_873901597549_item	2917709	et	3	main
jõulud	doc_873901597549_item	2917710	et	3	main
eestis	doc_873901597549_item	2917711	et	3	main
hea	doc_873901597549_item	2917722	et	4	main
meelega	doc_873901597549_item	2917723	et	4	main
kahekümne	doc_873901597549_item	2917727	et	4	main
kesklinnas	doc_873901597549_item	2917730	et	4	main
pidu	doc_873901597549_item	2917750	et	4	main
kingitusi	doc_873901597549_item	2917756	et	4	main
nad	doc_873901597549_item	2917757	et	3	main
natuke	doc_873901597549_item	2917768	et	4	main
viga	doc_873901597549_item	2917803	et	4	main
peame	doc_873901597549_item	2917810	et	4	main
eriala	doc_873901597549_item	2917811	et	4	main
saada	doc_873901597549_item	2917812	et	4	main
ja	doc_873901597549_item	2917813	et	3	main
lõpetuteks	doc_873901597549_item	2917819	et	4	main
tahan	doc_873901597549_item	2917823	et	3	main
kingitus	doc_873901597549_item	2917826	et	4	main
eksamid	doc_873901597549_item	2917828	et	3	main
ja	doc_873901597549_item	2917830	et	3	main
eksamil	doc_873901597549_item	2917832	et	3	main
õpitajale	doc_873901597549_item	2917846	et	4	main
õnne	doc_873901597549_item	2917849	et	4	main
jõulud	doc_873901597550_item	2917854	et	3	main
algavad	doc_873901597550_item	2917856	et	4	main
nagu	doc_873901597550_item	2917859	et	3	main
suurtest	doc_873901597550_item	2917866	et	4	main
peodest	doc_873901597550_item	2917867	et	3	main
mulle	doc_873901597550_item	2917868	et	4	main
väga	doc_873901597550_item	2917869	et	3	main
meeldib	doc_873901597550_item	2917870	et	3	main
sel	doc_873901597550_item	2917871	et	3	main
päeval	doc_873901597550_item	2917872	et	3	main
jalutada	doc_873901597550_item	2917873	et	3	main
sellepärast	doc_873901597550_item	2917876	et	3	main
ostavad	doc_873901597550_item	2917881	et	3	main
hilinevad	doc_873901597550_item	2917883	et	4	main
kaunistatud	doc_873901597550_item	2917892	et	4	main
tavalisel	doc_873901597550_item	2917893	et	4	main
sel	doc_873901597550_item	2917894	et	3	main
soe	doc_873901597550_item	2917904	et	4	main
kaunistatud	doc_873901597546_item	2917455	et	4	main
jõulud	doc_873901597546_item	2917456	et	3	main
essee	doc_873901597548_item	2917640	et	4	main
jõulu	doc_873901597548_item	2917641	et	4	main
mõtted	doc_873901597548_item	2917642	et	3	main
vanemand	doc_873901597548_item	2917652	et	3	main
jõuad	doc_873901597548_item	2917653	et	3	main
alkohooli	doc_873901597548_item	2917654	et	3	main
kõik	doc_873901597548_item	2917655	et	4	main
sugulased	doc_873901597548_item	2917656	et	3	main
tulevad	doc_873901597548_item	2917657	et	4	main
tuju	doc_873901597548_item	2917661	et	4	main
kõik	doc_873901597548_item	2917662	et	4	main
ostavad	doc_873901597548_item	2917663	et	3	main
ruumis	doc_873901597548_item	2917669	et	4	main
palju	doc_873901597548_item	2917671	et	4	main
künlaid	doc_873901597548_item	2917672	et	4	main
aga	doc_873901597548_item	2917677	et	3	main
on	doc_873901597548_item	2917683	et	4	main
kõikidel	doc_873901597548_item	2917687	et	4	main
on	doc_873901597548_item	2917690	et	4	main
väga	doc_873901597548_item	2917691	et	3	main
tore	doc_873901597548_item	2917692	et	3	main
kõik	doc_873901597548_item	2917704	et	4	main
essee	doc_873901597549_item	2917707	et	4	main
see	doc_873901597549_item	2917725	et	3	main
detsembril	doc_873901597549_item	2917729	et	3	main
seisab	doc_873901597549_item	2917731	et	3	main
kaunistatud	doc_873901597549_item	2917732	et	4	main
kusk	doc_873901597549_item	2917733	et	4	main
ja	doc_873901597549_item	2917734	et	3	main
eesti	doc_873901597549_item	2917739	et	4	main
jaoks	doc_873901597549_item	2917743	et	4	main
sest	doc_873901597549_item	2917751	et	4	main
et	doc_873901597549_item	2917752	et	3	main
nendele	doc_873901597549_item	2917753	et	4	main
väga	doc_873901597549_item	2917759	et	3	main
rõõmsad	doc_873901597549_item	2917760	et	3	main
ttüs	doc_873901597549_item	2917763	et	4	main
noh	doc_873901597549_item	2917799	et	3	main
pole	doc_873901597549_item	2917802	et	3	main
meie	doc_873901597549_item	2917804	et	4	main
aeg	doc_873901597549_item	2917805	et	3	main
tuleb	doc_873901597549_item	2917806	et	3	main
aga	doc_873901597549_item	2917807	et	3	main
praegu	doc_873901597549_item	2917808	et	3	main
eesnimi	doc_873901597549_item	2917814	et	3	main
lapsi	doc_873901597548_item	2917649	et	4	main
on	doc_873901597548_item	2917659	et	4	main
rõõmus	doc_873901597548_item	2917660	et	4	main
on	doc_873901597548_item	2917666	et	4	main
on	doc_873901597548_item	2917670	et	4	main
armastan	doc_873901597548_item	2917679	et	3	main
uue	doc_873901597548_item	2917680	et	3	main
lõbus	doc_873901597548_item	2917694	et	4	main
pärast	doc_873901597548_item	2917695	et	4	main
uus	doc_873901597548_item	2917696	et	3	main
pida	doc_873901597548_item	2917701	et	4	main
päev	doc_873901597549_item	2917726	et	3	main
ka	doc_873901597549_item	2917740	et	3	main
väikede	doc_873901597549_item	2917741	et	4	main
on	doc_873901597549_item	2917745	et	4	main
eriti	doc_873901597549_item	2917746	et	3	main
oluline	doc_873901597549_item	2917747	et	4	main
ja	doc_873901597549_item	2917748	et	3	main
kinkitakse	doc_873901597549_item	2917754	et	4	main
palju	doc_873901597549_item	2917755	et	4	main
meil	doc_873901597549_item	2917762	et	4	main
on	doc_873901597549_item	2917764	et	4	main
samma	doc_873901597549_item	2917765	et	3	main
pidu	doc_873901597549_item	2917766	et	4	main
endale	doc_873901597549_item	2917824	et	4	main
lahke	doc_873901597549_item	2917834	et	4	main
kõikidele	doc_873901597549_item	2917837	et	4	main
õpilastele	doc_873901597549_item	2917838	et	4	main
keele	doc_873901597549_item	2917845	et	4	main
essee	doc_873901597550_item	2917853	et	4	main
jõulud	doc_873901597550_item	2917855	et	3	main
midagi	doc_873901597550_item	2917880	et	4	main
raekojaplatsi	doc_873901597550_item	2917884	et	4	main
suur	doc_873901597550_item	2917887	et	3	main
ehte	doc_873901597550_item	2917921	et	3	main
panen	doc_873901597550_item	2917926	et	3	main
jõulupuu	doc_873901597550_item	2917927	et	4	main
all	doc_873901597550_item	2917928	et	3	main
jõulud	doc_873901597550_item	2917929	et	3	main
aga	doc_873901597550_item	2917936	et	3	main
kõikidel	doc_873901597550_item	2917949	et	4	main
kõik	doc_873901597550_item	2917952	et	4	main
soovid	doc_873901597550_item	2917953	et	4	main
katoliklane	doc_873901597548_item	2917647	et	4	main
kõikidel	doc_873901597548_item	2917658	et	4	main
jõulupuu	doc_873901597548_item	2917664	et	4	main
jõulupuu	doc_873901597548_item	2917667	et	4	main
jõulu	doc_873901597548_item	2917673	et	4	main
ma	doc_873901597548_item	2917678	et	3	main
pidutsevad	doc_873901597548_item	2917686	et	4	main
aasta	doc_873901597548_item	2917697	et	4	main
tuleb	doc_873901597548_item	2917698	et	3	main
vene	doc_873901597548_item	2917699	et	4	main
aastal	doc_873901597548_item	2917703	et	3	main
juuad	doc_873901597548_item	2917705	et	4	main
mina	doc_873901597549_item	2917721	et	4	main
ootan	doc_873901597549_item	2917724	et	3	main
neljandal	doc_873901597549_item	2917728	et	3	main
tallinn	doc_873901597549_item	2917736	et	4	main
ja	doc_873901597549_item	2917737	et	3	main
muidugi	doc_873901597549_item	2917738	et	4	main
laste	doc_873901597549_item	2917742	et	4	main
see	doc_873901597549_item	2917744	et	3	main
on	doc_873901597549_item	2917758	et	4	main
aga	doc_873901597549_item	2917761	et	3	main
omapärane	doc_873901597549_item	2917769	et	4	main
see	doc_873901597549_item	2917800	et	3	main
on	doc_873901597549_item	2917801	et	4	main
ja	doc_873901597549_item	2917818	et	3	main
öelda	doc_873901597549_item	2917821	et	4	main
tudengidele	doc_873901597549_item	2917839	et	4	main
ttüs	doc_873901597549_item	2917847	et	4	main
ja	doc_873901597549_item	2917850	et	3	main
23	doc_873901597550_item	2917857	et	2	main
taen	doc_873901597550_item	2917861	et	4	main
see	doc_873901597550_item	2917863	et	3	main
üks	doc_873901597550_item	2917865	et	3	main
linnas	doc_873901597550_item	2917875	et	4	main
et	doc_873901597550_item	2917877	et	3	main
jooksevad	doc_873901597550_item	2917879	et	4	main
kuhugi	doc_873901597550_item	2917882	et	4	main
jõulupuu	doc_873901597550_item	2917888	et	4	main
väikesed	doc_873901597550_item	2917890	et	4	main
teed	doc_873901597550_item	2917891	et	4	main
on	doc_873901597550_item	2917897	et	4	main
väga	doc_873901597550_item	2917898	et	3	main
külm	doc_873901597550_item	2917899	et	3	main
aga	doc_873901597550_item	2917900	et	3	main
kodus	doc_873901597550_item	2917901	et	4	main
ma	doc_873901597550_item	2917922	et	3	main
rõõmus	doc_873901597550_item	2917934	et	4	main
pidu	doc_873901597550_item	2917941	et	4	main
minu	doc_873901597550_item	2917945	et	3	main
et	doc_873901597550_item	2917948	et	3	main
sel	doc_873901597550_item	2917950	et	3	main
jõul	doc_873901597548_item	2917643	et	4	main
on	doc_873901597548_item	2917644	et	4	main
väga	doc_873901597548_item	2917645	et	3	main
tore	doc_873901597548_item	2917646	et	3	main
kingitusi	doc_873901597548_item	2917651	et	4	main
kodus	doc_873901597548_item	2917665	et	4	main
lõhn	doc_873901597548_item	2917668	et	3	main
on	doc_873901597548_item	2917674	et	4	main
tore	doc_873901597548_item	2917675	et	3	main
aasta	doc_873901597548_item	2917681	et	4	main
see	doc_873901597548_item	2917689	et	3	main
ja	doc_873901597548_item	2917693	et	3	main
jõulu	doc_873901597548_item	2917700	et	4	main
see	doc_873901597549_item	2917712	et	3	main
on	doc_873901597549_item	2917713	et	4	main
väga	doc_873901597549_item	2917714	et	3	main
huvitav	doc_873901597549_item	2917715	et	4	main
ja	doc_873901597549_item	2917716	et	3	main
väga	doc_873901597549_item	2917717	et	3	main
ilus	doc_873901597549_item	2917718	et	4	main
pidu	doc_873901597549_item	2917719	et	4	main
ja	doc_873901597549_item	2917720	et	3	main
kõik	doc_873901597549_item	2917735	et	4	main
surepärane	doc_873901597549_item	2917749	et	4	main
ainult	doc_873901597549_item	2917767	et	4	main
meil	doc_873901597549_item	2917770	et	4	main
on	doc_873901597549_item	2917771	et	4	main
sessioon	doc_873901597549_item	2917772	et	3	main
me	doc_873901597549_item	2917773	et	4	main
peame	doc_873901597549_item	2917774	et	4	main
eksameid	doc_873901597549_item	2917775	et	3	main
kirjutama	doc_873901597549_item	2917776	et	3	main
aga	doc_873901597549_item	2917777	et	3	main
eksam	doc_873901597549_item	2917778	et	3	main
tudengi	doc_873901597549_item	2917779	et	3	main
jaoks	doc_873901597549_item	2917780	et	4	main
see	doc_873901597549_item	2917781	et	3	main
on	doc_873901597549_item	2917782	et	4	main
alati	doc_873901597549_item	2917783	et	4	main
pidu	doc_873901597549_item	2917784	et	4	main
muidugi	doc_873901597549_item	2917785	et	4	main
see	doc_873901597549_item	2917786	et	3	main
on	doc_873901597549_item	2917787	et	4	main
väga	doc_873901597549_item	2917788	et	3	main
halvasti	doc_873901597549_item	2917789	et	3	main
et	doc_873901597549_item	2917790	et	3	main
me	doc_873901597549_item	2917791	et	4	main
tudengid	doc_873901597549_item	2917792	et	3	main
ei	doc_873901597549_item	2917793	et	4	main
võime	doc_873901597549_item	2917794	et	4	main
hästi	doc_873901597549_item	2917795	et	3	main
oma	doc_873901597549_item	2917796	et	4	main
vaheaeg	doc_873901597549_item	2917797	et	3	main
veeta	doc_873901597549_item	2917798	et	4	main
me	doc_873901597549_item	2917809	et	4	main
perekonnanimi	doc_873901597549_item	2917815	et	3	main
ootab	doc_873901597549_item	2917816	et	3	main
meid	doc_873901597549_item	2917817	et	4	main
tahan	doc_873901597549_item	2917820	et	3	main
et	doc_873901597549_item	2917822	et	3	main
perekonnanimi	doc_873901597549_item	2917831	et	3	main
tahan	doc_873901597549_item	2917836	et	3	main
aga	doc_873901597549_item	2917841	et	3	main
minu	doc_873901597549_item	2917843	et	3	main
palju	doc_873901597549_item	2917848	et	4	main
jõulud	doc_873901597549_item	2917852	et	3	main
keskel	doc_873901597550_item	2917885	et	3	main
seisab	doc_873901597550_item	2917886	et	3	main
on	doc_873901597550_item	2917902	et	4	main
kingitusi	doc_873901597550_item	2917924	et	4	main
pidu	doc_873901597550_item	2917935	et	4	main
et	doc_873901597552_item	2918108	et	3	main
detsembrist	doc_873901597552_item	2918111	et	3	main
niisugune	doc_873901597549_item	2917825	et	3	main
et	doc_873901597549_item	2917827	et	3	main
sooritasin	doc_873901597549_item	2917829	et	3	main
oli	doc_873901597549_item	2917833	et	3	main
ja	doc_873901597549_item	2917835	et	3	main
õpetajatele	doc_873901597549_item	2917840	et	4	main
alati	doc_873901597549_item	2917842	et	4	main
eesti	doc_873901597549_item	2917844	et	4	main
head	doc_873901597549_item	2917851	et	4	main
detsembril	doc_873901597550_item	2917858	et	3	main
ma	doc_873901597550_item	2917860	et	3	main
eestis	doc_873901597550_item	2917862	et	3	main
on	doc_873901597550_item	2917864	et	4	main
vana	doc_873901597550_item	2917874	et	4	main
kõik	doc_873901597550_item	2917878	et	4	main
kõik	doc_873901597550_item	2917889	et	4	main
ajal	doc_873901597550_item	2917895	et	4	main
õues	doc_873901597550_item	2917896	et	4	main
väga	doc_873901597550_item	2917903	et	3	main
sellepärast	doc_873901597550_item	2917905	et	3	main
ema	doc_873901597550_item	2917907	et	4	main
küpsitab	doc_873901597550_item	2917908	et	4	main
et	doc_873901597550_item	2917906	et	3	main
piparkoogi	doc_873901597550_item	2917909	et	4	main
minu	doc_873901597550_item	2917910	et	3	main
väike	doc_873901597550_item	2917911	et	4	main
õde	doc_873901597550_item	2917912	et	4	main
kaunistab	doc_873901597550_item	2917913	et	3	main
kõik	doc_873901597550_item	2917914	et	4	main
kohad	doc_873901597550_item	2917915	et	4	main
kodus	doc_873901597550_item	2917916	et	4	main
kus	doc_873901597550_item	2917917	et	3	main
veel	doc_873901597550_item	2917918	et	4	main
ei	doc_873901597550_item	2917919	et	4	main
ole	doc_873901597550_item	2917920	et	4	main
pakkin	doc_873901597550_item	2917923	et	4	main
ja	doc_873901597550_item	2917925	et	3	main
on	doc_873901597550_item	2917930	et	4	main
väga	doc_873901597550_item	2917931	et	3	main
tore	doc_873901597550_item	2917932	et	3	main
ja	doc_873901597550_item	2917933	et	3	main
väga	doc_873901597550_item	2917937	et	3	main
see	doc_873901597550_item	2917940	et	3	main
lõpetab	doc_873901597550_item	2917942	et	3	main
kiiresti	doc_873901597550_item	2917944	et	3	main
suurim	doc_873901597550_item	2917946	et	3	main
päeval	doc_873901597550_item	2917951	et	3	main
kahju	doc_873901597550_item	2917938	et	4	main
et	doc_873901597550_item	2917939	et	3	main
väga	doc_873901597550_item	2917943	et	3	main
soov	doc_873901597550_item	2917947	et	3	main
taituksid	doc_873901597550_item	2917954	et	3	main
essee	doc_873901597552_item	2918098	et	4	main
jõulumõted	doc_873901597552_item	2918100	et	4	main
ilus	doc_873901597552_item	2918124	et	4	main
kaunistatud	doc_873901597552_item	2918125	et	4	main
kusk	doc_873901597552_item	2918129	et	4	main
vanalinnas	doc_873901597552_item	2918130	et	4	main
on	doc_873901597552_item	2918134	et	4	main
ja	doc_873901597552_item	2918137	et	3	main
usulik	doc_873901597552_item	2918151	et	4	main
et	doc_873901597552_item	2918162	et	3	main
jaanuarist	doc_873901597552_item	2918164	et	3	main
tahan	doc_873901597552_item	2918182	et	3	main
minu	doc_873901597552_item	2918099	et	3	main
on	doc_873901597552_item	2918113	et	4	main
väike	doc_873901597552_item	2918114	et	4	main
jõuluvaheaeg	doc_873901597552_item	2918115	et	3	main
jõulupäevad	doc_873901597552_item	2918116	et	3	main
on	doc_873901597552_item	2918117	et	4	main
väga	doc_873901597552_item	2918118	et	3	main
huvitavad	doc_873901597552_item	2918119	et	4	main
päevad	doc_873901597552_item	2918120	et	3	main
linn	doc_873901597552_item	2918122	et	3	main
väga	doc_873901597552_item	2918135	et	3	main
pidulik	doc_873901597552_item	2918138	et	3	main
inimesed	doc_873901597552_item	2918140	et	3	main
ja	doc_873901597552_item	2918143	et	3	main
teineteisele	doc_873901597552_item	2918145	et	3	main
see	doc_873901597552_item	2918147	et	3	main
on	doc_873901597552_item	2918148	et	4	main
suur	doc_873901597552_item	2918149	et	3	main
ole	doc_873901597552_item	2918159	et	4	main
sellepärast	doc_873901597552_item	2918161	et	3	main
kahest	doc_873901597552_item	2918163	et	4	main
kõik	doc_873901597552_item	2918183	et	4	main
kirjutada	doc_873901597552_item	2918186	et	3	main
ma	doc_873901597552_item	2918188	et	3	main
see	doc_873901597552_item	2918194	et	3	main
on	doc_873901597552_item	2918195	et	4	main
kingitus	doc_873901597552_item	2918198	et	4	main
essee	doc_873901597554_item	2918302	et	4	main
minu	doc_873901597554_item	2918303	et	3	main
jõulumõtted	doc_873901597554_item	2918304	et	3	main
tahaks	doc_873901597554_item	2918306	et	3	main
talv	doc_873901597554_item	2918309	et	3	main
kui	doc_873901597554_item	2918314	et	3	main
peres	doc_873901597554_item	2918325	et	3	main
et	doc_873901597554_item	2918343	et	3	main
eksamid	doc_873901597554_item	2918344	et	3	main
mõtlen	doc_873901597554_item	2918347	et	3	main
paljud	doc_873901597554_item	2918349	et	3	main
muidugi	doc_873901597554_item	2918358	et	4	main
juhul	doc_873901597554_item	2918370	et	3	main
pere	doc_873901597554_item	2918378	et	4	main
kahju	doc_873901597554_item	2918388	et	4	main
et	doc_873901597554_item	2918389	et	3	main
varsti	doc_873901597552_item	2918101	et	3	main
on	doc_873901597552_item	2918102	et	4	main
jõulupühad	doc_873901597552_item	2918103	et	3	main
ma	doc_873901597552_item	2918104	et	3	main
ootan	doc_873901597552_item	2918105	et	3	main
neid	doc_873901597552_item	2918106	et	4	main
sellepärast	doc_873901597552_item	2918107	et	3	main
teisest	doc_873901597552_item	2918110	et	4	main
jalutavad	doc_873901597552_item	2918131	et	4	main
päkapikud	doc_873901597552_item	2918132	et	4	main
pidu	doc_873901597552_item	2918150	et	4	main
sellel	doc_873901597552_item	2918154	et	4	main
minust	doc_873901597552_item	2918156	et	3	main
jõulupäeevad	doc_873901597552_item	2918157	et	4	main
eksameid	doc_873901597552_item	2918184	et	3	main
füüsika	doc_873901597552_item	2918190	et	4	main
5	doc_873901597552_item	2918192	et	2	main
kõige	doc_873901597552_item	2918196	et	4	main
kahekümne	doc_873901597552_item	2918109	et	4	main
meil	doc_873901597552_item	2918112	et	4	main
meie	doc_873901597552_item	2918121	et	4	main
on	doc_873901597552_item	2918123	et	4	main
on	doc_873901597552_item	2918127	et	4	main
ostavad	doc_873901597552_item	2918141	et	3	main
inimestel	doc_873901597552_item	2918152	et	3	main
aastal	doc_873901597552_item	2918155	et	3	main
pidu	doc_873901597552_item	2918160	et	4	main
ma	doc_873901597552_item	2918181	et	3	main
on	doc_873901597554_item	2918310	et	4	main
meie	doc_873901597554_item	2918324	et	4	main
peod	doc_873901597554_item	2918333	et	4	main
õpin	doc_873901597554_item	2918336	et	3	main
ülikoolis	doc_873901597554_item	2918337	et	4	main
ja	doc_873901597554_item	2918338	et	3	main
minu	doc_873901597554_item	2918339	et	3	main
kõige	doc_873901597554_item	2918340	et	4	main
sooritada	doc_873901597554_item	2918346	et	3	main
ma	doc_873901597554_item	2918359	et	3	main
saa	doc_873901597554_item	2918361	et	4	main
kaunistamist	doc_873901597554_item	2918364	et	4	main
on	doc_873901597554_item	2918366	et	4	main
kõige	doc_873901597554_item	2918367	et	4	main
oma	doc_873901597554_item	2918383	et	4	main
sõpradega	doc_873901597554_item	2918384	et	3	main
kohtuda	doc_873901597554_item	2918385	et	3	main
ole	doc_873901597554_item	2918392	et	4	main
nii	doc_873901597554_item	2918393	et	3	main
aastat	doc_873901597554_item	2918422	et	3	main
jõulumõtted	doc_873901597555_item	2918425	et	3	main
jõulu	doc_873901597555_item	2918428	et	4	main
kõige	doc_873901597555_item	2918429	et	4	main
aeg	doc_873901597555_item	2918433	et	3	main
kõikidel	doc_873901597555_item	2918434	et	4	main
ajal	doc_873901597555_item	2918441	et	4	main
kojus	doc_873901597555_item	2918447	et	4	main
ei	doc_873901597555_item	2918457	et	4	main
kus	doc_873901597555_item	2918461	et	3	main
kuhu	doc_873901597555_item	2918463	et	3	main
tean	doc_873901597555_item	2918467	et	3	main
peal	doc_873901597555_item	2918489	et	4	main
taga	doc_873901597555_item	2918494	et	4	main
räägime	doc_873901597555_item	2918496	et	3	main
ära	doc_873901597555_item	2918497	et	4	main
me	doc_873901597555_item	2918509	et	4	main
jõulumõtted	doc_873901597556_item	2918522	et	3	main
ma	doc_873901597556_item	2918523	et	3	main
väga	doc_873901597556_item	2918528	et	3	main
talv	doc_873901597556_item	2918547	et	3	main
toimub	doc_873901597556_item	2918548	et	3	main
millal	doc_873901597556_item	2918552	et	3	main
sajab	doc_873901597556_item	2918554	et	3	main
meeldib	doc_873901597556_item	2918563	et	3	main
uisutada	doc_873901597556_item	2918567	et	3	main
pühapäeval	doc_873901597556_item	2918573	et	3	main
saan	doc_873901597556_item	2918576	et	4	main
kesklinnas	doc_873901597552_item	2918126	et	4	main
suur	doc_873901597552_item	2918128	et	3	main
kõigil	doc_873901597552_item	2918133	et	4	main
hea	doc_873901597552_item	2918136	et	4	main
tuju	doc_873901597552_item	2918139	et	4	main
kingitused	doc_873901597552_item	2918142	et	4	main
kinkivad	doc_873901597552_item	2918144	et	4	main
jõulu	doc_873901597552_item	2918146	et	4	main
aga	doc_873901597552_item	2918153	et	3	main
ei	doc_873901597552_item	2918158	et	4	main
mul	doc_873901597552_item	2918165	et	3	main
algab	doc_873901597552_item	2918166	et	3	main
sessia	doc_873901597552_item	2918167	et	4	main
ja	doc_873901597552_item	2918168	et	3	main
terve	doc_873901597552_item	2918169	et	4	main
nädal	doc_873901597552_item	2918170	et	3	main
ma	doc_873901597552_item	2918171	et	3	main
kavatsen	doc_873901597552_item	2918172	et	3	main
õppida	doc_873901597552_item	2918173	et	3	main
matemaatiline	doc_873901597552_item	2918174	et	3	main
analüüsit	doc_873901597552_item	2918175	et	4	main
kujutav	doc_873901597552_item	2918176	et	4	main
geomeetriat	doc_873901597552_item	2918177	et	3	main
lineaaralgebrat	doc_873901597552_item	2918178	et	4	main
ja	doc_873901597552_item	2918179	et	3	main
füüsikat	doc_873901597552_item	2918180	et	3	main
hästi	doc_873901597552_item	2918185	et	3	main
kui	doc_873901597552_item	2918187	et	3	main
sain	doc_873901597552_item	2918189	et	3	main
eksamis	doc_873901597552_item	2918191	et	3	main
siis	doc_873901597552_item	2918193	et	3	main
esiteks	doc_873901597554_item	2918305	et	3	main
minu	doc_873901597554_item	2918311	et	3	main
aastaaeg	doc_873901597554_item	2918313	et	3	main
ja	doc_873901597554_item	2918321	et	3	main
rohkem	doc_873901597554_item	2918330	et	4	main
kui	doc_873901597554_item	2918331	et	3	main
teised	doc_873901597554_item	2918332	et	4	main
olulisem	doc_873901597554_item	2918341	et	4	main
on	doc_873901597554_item	2918351	et	4	main
nõus	doc_873901597554_item	2918353	et	4	main
jõulunädalas	doc_873901597554_item	2918354	et	3	main
ei	doc_873901597554_item	2918360	et	4	main
kuuse	doc_873901597554_item	2918363	et	4	main
see	doc_873901597554_item	2918365	et	3	main
tulevad	doc_873901597554_item	2918372	et	4	main
ringis	doc_873901597554_item	2918379	et	4	main
pärast	doc_873901597554_item	2918380	et	4	main
aga	doc_873901597554_item	2918381	et	3	main
soovin	doc_873901597554_item	2918382	et	3	main
praegu	doc_873901597554_item	2918390	et	3	main
ei	doc_873901597554_item	2918391	et	4	main
essee	doc_873901597555_item	2918423	et	4	main
tuleb	doc_873901597555_item	2918427	et	3	main
parem	doc_873901597555_item	2918432	et	4	main
on	doc_873901597555_item	2918438	et	4	main
kuuske	doc_873901597555_item	2918445	et	4	main
ja	doc_873901597555_item	2918446	et	3	main
teda	doc_873901597555_item	2918450	et	4	main
on	doc_873901597555_item	2918452	et	4	main
mul	doc_873901597555_item	2918453	et	3	main
jõulumõtted	doc_873901597555_item	2918454	et	3	main
ma	doc_873901597555_item	2918455	et	3	main
ja	doc_873901597555_item	2918462	et	3	main
aga	doc_873901597555_item	2918466	et	3	main
et	doc_873901597555_item	2918468	et	3	main
pereringis	doc_873901597555_item	2918472	et	3	main
esiteks	doc_873901597555_item	2918473	et	3	main
sõidan	doc_873901597555_item	2918475	et	3	main
laua	doc_873901597555_item	2918488	et	3	main
on	doc_873901597555_item	2918490	et	4	main
lähen	doc_873901597555_item	2918502	et	3	main
siis	doc_873901597555_item	2918504	et	3	main
kohtun	doc_873901597555_item	2918505	et	3	main
sõpradega	doc_873901597555_item	2918507	et	3	main
arvan	doc_873901597556_item	2918524	et	3	main
ma	doc_873901597556_item	2918534	et	3	main
tahaksin	doc_873901597556_item	2918535	et	3	main
öelda	doc_873901597556_item	2918536	et	4	main
et	doc_873901597556_item	2918537	et	3	main
talv	doc_873901597556_item	2918538	et	3	main
ootan	doc_873901597556_item	2918545	et	3	main
talvel	doc_873901597556_item	2918582	et	4	main
sellele	doc_873901597556_item	2918589	et	4	main
talvel	doc_873901597556_item	2918590	et	4	main
oma	doc_873901597556_item	2918607	et	4	main
ajal	doc_873901597556_item	2918612	et	4	main
me	doc_873901597556_item	2918613	et	4	main
teineteist	doc_873901597556_item	2918619	et	4	main
üldse	doc_873901597556_item	2918621	et	3	main
hea	doc_873901597556_item	2918625	et	4	main
essee	doc_873901597557_item	2918637	et	4	main
2006	doc_873901597557_item	2918644	et	2	main
lõpetab	doc_873901597557_item	2918648	et	3	main
parem	doc_873901597552_item	2918197	et	4	main
mulle	doc_873901597552_item	2918199	et	4	main
jõulule	doc_873901597552_item	2918200	et	3	main
ja	doc_873901597552_item	2918201	et	3	main
uue	doc_873901597552_item	2918202	et	3	main
aastale	doc_873901597552_item	2918203	et	3	main
öelda	doc_873901597554_item	2918307	et	4	main
lemmik	doc_873901597554_item	2918312	et	3	main
on	doc_873901597554_item	2918315	et	4	main
jõulut	doc_873901597554_item	2918317	et	4	main
kuuske	doc_873901597554_item	2918322	et	4	main
kõik	doc_873901597554_item	2918326	et	4	main
jõulu	doc_873901597554_item	2918328	et	4	main
palju	doc_873901597554_item	2918329	et	4	main
jõulumõte	doc_873901597554_item	2918342	et	3	main
et	doc_873901597554_item	2918348	et	3	main
üliõpilased	doc_873901597554_item	2918350	et	3	main
minuga	doc_873901597554_item	2918352	et	3	main
hakan	doc_873901597554_item	2918355	et	4	main
eksamiteks	doc_873901597554_item	2918356	et	3	main
valmistuma	doc_873901597554_item	2918357	et	3	main
igal	doc_873901597554_item	2918369	et	3	main
peod	doc_873901597554_item	2918374	et	4	main
hakan	doc_873901597554_item	2918375	et	4	main
tähistama	doc_873901597554_item	2918376	et	3	main
neid	doc_873901597554_item	2918377	et	4	main
küll	doc_873901597554_item	2918386	et	4	main
ilusam	doc_873901597555_item	2918430	et	4	main
rõõmus	doc_873901597555_item	2918439	et	4	main
kaunistavad	doc_873901597555_item	2918449	et	4	main
millised	doc_873901597555_item	2918451	et	3	main
sest	doc_873901597555_item	2918459	et	4	main
seda	doc_873901597555_item	2918469	et	3	main
meil	doc_873901597555_item	2918487	et	4	main
toitusi	doc_873901597555_item	2918492	et	4	main
läinud	doc_873901597555_item	2918498	et	4	main
ja	doc_873901597555_item	2918508	et	3	main
et	doc_873901597554_item	2918308	et	3	main
tore	doc_873901597554_item	2918316	et	3	main
oodata	doc_873901597554_item	2918318	et	4	main
kingitusi	doc_873901597554_item	2918319	et	4	main
teha	doc_873901597554_item	2918320	et	3	main
ostada	doc_873901597554_item	2918323	et	4	main
armastavad	doc_873901597554_item	2918327	et	4	main
praegu	doc_873901597554_item	2918334	et	3	main
ma	doc_873901597554_item	2918335	et	3	main
hästi	doc_873901597554_item	2918345	et	3	main
unustada	doc_873901597554_item	2918362	et	3	main
mõnusam	doc_873901597554_item	2918368	et	4	main
esimesed	doc_873901597554_item	2918371	et	3	main
toredad	doc_873901597554_item	2918373	et	3	main
on	doc_873901597554_item	2918387	et	4	main
palju	doc_873901597554_item	2918394	et	4	main
ilusaid	doc_873901597554_item	2918395	et	3	main
jõulumõtteid	doc_873901597554_item	2918396	et	3	main
näiteks	doc_873901597554_item	2918397	et	4	main
minu	doc_873901597554_item	2918398	et	3	main
lapsepõlves	doc_873901597554_item	2918399	et	4	main
ma	doc_873901597554_item	2918400	et	3	main
unistasin	doc_873901597554_item	2918401	et	3	main
jõuluvana	doc_873901597554_item	2918402	et	4	main
näha	doc_873901597554_item	2918403	et	3	main
praegu	doc_873901597554_item	2918404	et	3	main
aga	doc_873901597554_item	2918405	et	3	main
tean	doc_873901597554_item	2918406	et	3	main
et	doc_873901597554_item	2918407	et	3	main
see	doc_873901597554_item	2918408	et	3	main
ei	doc_873901597554_item	2918409	et	4	main
ole	doc_873901597554_item	2918410	et	4	main
võimalik	doc_873901597554_item	2918411	et	3	main
j	doc_873901597554_item	2918412	et	4	main
lõpuks	doc_873901597554_item	2918413	et	4	main
ütlen	doc_873901597554_item	2918414	et	3	main
kõikidele	doc_873901597554_item	2918415	et	4	main
üliõpilasele	doc_873901597554_item	2918416	et	3	main
head	doc_873901597554_item	2918417	et	4	main
põrumist	doc_873901597554_item	2918418	et	4	main
ja	doc_873901597554_item	2918419	et	3	main
head	doc_873901597554_item	2918420	et	4	main
uut	doc_873901597554_item	2918421	et	3	main
minu	doc_873901597555_item	2918424	et	3	main
varsti	doc_873901597555_item	2918426	et	3	main
kõik	doc_873901597555_item	2918437	et	4	main
kõik	doc_873901597555_item	2918442	et	4	main
inimesed	doc_873901597555_item	2918443	et	3	main
ostavad	doc_873901597555_item	2918444	et	3	main
et	doc_873901597555_item	2918460	et	3	main
lähen	doc_873901597555_item	2918465	et	3	main
tähistatakse	doc_873901597555_item	2918471	et	3	main
kui	doc_873901597555_item	2918477	et	3	main
lõpetab	doc_873901597555_item	2918478	et	3	main
semester	doc_873901597555_item	2918479	et	3	main
ja	doc_873901597555_item	2918480	et	3	main
ma	doc_873901597555_item	2918481	et	3	main
aitan	doc_873901597555_item	2918482	et	3	main
emal	doc_873901597555_item	2918483	et	3	main
koduseid	doc_873901597555_item	2918484	et	4	main
ja	doc_873901597555_item	2918431	et	3	main
on	doc_873901597555_item	2918435	et	4	main
jõulutuju	doc_873901597555_item	2918436	et	4	main
sellel	doc_873901597555_item	2918440	et	4	main
nad	doc_873901597555_item	2918448	et	3	main
täpselt	doc_873901597555_item	2918456	et	4	main
tea	doc_873901597555_item	2918458	et	4	main
ma	doc_873901597555_item	2918464	et	3	main
pidu	doc_873901597555_item	2918470	et	4	main
ma	doc_873901597555_item	2918474	et	3	main
kojju	doc_873901597555_item	2918476	et	4	main
palju	doc_873901597555_item	2918491	et	4	main
aastast	doc_873901597555_item	2918499	et	4	main
ma	doc_873901597555_item	2918501	et	3	main
käime	doc_873901597555_item	2918510	et	4	main
suusatamas	doc_873901597555_item	2918511	et	3	main
või	doc_873901597555_item	2918512	et	4	main
uisutamas	doc_873901597555_item	2918513	et	3	main
või	doc_873901597555_item	2918514	et	4	main
täpselt	doc_873901597555_item	2918515	et	4	main
mängime	doc_873901597555_item	2918516	et	3	main
lolli	doc_873901597555_item	2918517	et	4	main
mängime	doc_873901597555_item	2918518	et	3	main
lumesõda	doc_873901597555_item	2918519	et	4	main
essee	doc_873901597556_item	2918520	et	4	main
et	doc_873901597556_item	2918525	et	3	main
lõbus	doc_873901597556_item	2918529	et	4	main
ilus	doc_873901597556_item	2918531	et	4	main
esiteks	doc_873901597556_item	2918533	et	3	main
on	doc_873901597556_item	2918539	et	4	main
minu	doc_873901597556_item	2918540	et	3	main
lemmik	doc_873901597556_item	2918541	et	3	main
aastaaeg	doc_873901597556_item	2918542	et	3	main
millal	doc_873901597556_item	2918546	et	3	main
mulle	doc_873901597556_item	2918549	et	4	main
meeldib	doc_873901597556_item	2918551	et	3	main
lumi	doc_873901597556_item	2918553	et	3	main
ja	doc_873901597556_item	2918555	et	3	main
on	doc_873901597556_item	2918557	et	4	main
väga	doc_873901597556_item	2918558	et	3	main
suur	doc_873901597556_item	2918559	et	3	main
lumehang	doc_873901597556_item	2918560	et	3	main
kelgutada	doc_873901597556_item	2918564	et	3	main
ja	doc_873901597556_item	2918566	et	3	main
loodus	doc_873901597556_item	2918578	et	4	main
minu	doc_873901597556_item	2918583	et	3	main
on	doc_873901597556_item	2918591	et	4	main
õnnelik	doc_873901597556_item	2918592	et	3	main
pidu	doc_873901597556_item	2918593	et	4	main
on	doc_873901597556_item	2918600	et	4	main
tore	doc_873901597556_item	2918602	et	3	main
mina	doc_873901597556_item	2918604	et	4	main
võin	doc_873901597556_item	2918605	et	3	main
koos	doc_873901597556_item	2918606	et	4	main
võime	doc_873901597556_item	2918614	et	4	main
öelda	doc_873901597556_item	2918620	et	4	main
väga	doc_873901597556_item	2918624	et	3	main
õnnelik	doc_873901597556_item	2918626	et	3	main
jäi	doc_873901597557_item	2918640	et	3	main
aasta	doc_873901597557_item	2918643	et	4	main
kooli	doc_873901597557_item	2918661	et	4	main
rohkem	doc_873901597557_item	2918673	et	4	main
veel	doc_873901597557_item	2918674	et	4	main
ttüsse	doc_873901597557_item	2918679	et	4	main
see	doc_873901597557_item	2918680	et	3	main
on	doc_873901597557_item	2918681	et	4	main
äärde	doc_873901597557_item	2918725	et	4	main
väga	doc_873901597557_item	2918729	et	3	main
arvan	doc_873901597557_item	2918731	et	3	main
poolest	doc_873901597558_item	2918744	et	4	main
jäi	doc_873901597558_item	2918745	et	3	main
töid	doc_873901597555_item	2918485	et	3	main
teha	doc_873901597555_item	2918486	et	3	main
laua	doc_873901597555_item	2918493	et	3	main
me	doc_873901597555_item	2918495	et	4	main
kui	doc_873901597555_item	2918500	et	3	main
tänavale	doc_873901597555_item	2918503	et	4	main
oma	doc_873901597555_item	2918506	et	4	main
minu	doc_873901597556_item	2918521	et	3	main
jõulud	doc_873901597556_item	2918526	et	3	main
eriti	doc_873901597556_item	2918550	et	3	main
maal	doc_873901597556_item	2918556	et	4	main
varem	doc_873901597556_item	2918561	et	4	main
suutatada	doc_873901597556_item	2918565	et	4	main
tavaliselt	doc_873901597556_item	2918568	et	4	main
igal	doc_873901597556_item	2918572	et	3	main
ma	doc_873901597556_item	2918575	et	3	main
ja	doc_873901597556_item	2918579	et	3	main
õnne	doc_873901597556_item	2918584	et	4	main
tunnetab	doc_873901597556_item	2918586	et	3	main
jõulu	doc_873901597556_item	2918595	et	4	main
ajal	doc_873901597556_item	2918596	et	4	main
kinkitakse	doc_873901597556_item	2918597	et	4	main
peolaua	doc_873901597556_item	2918609	et	3	main
sellel	doc_873901597556_item	2918611	et	4	main
oma	doc_873901597556_item	2918616	et	4	main
mõtted	doc_873901597556_item	2918617	et	3	main
soovitused	doc_873901597556_item	2918618	et	4	main
jäi	doc_873901597556_item	2918623	et	3	main
mille	doc_873901597557_item	2918638	et	3	main
poolest	doc_873901597557_item	2918639	et	4	main
mulle	doc_873901597557_item	2918641	et	4	main
meeleks	doc_873901597557_item	2918642	et	3	main
aasta	doc_873901597557_item	2918646	et	4	main
aasta	doc_873901597557_item	2918650	et	4	main
huvitav	doc_873901597557_item	2918653	et	4	main
ja	doc_873901597557_item	2918654	et	3	main
meeldis	doc_873901597557_item	2918655	et	3	main
mulle	doc_873901597557_item	2918656	et	4	main
olin	doc_873901597557_item	2918663	et	3	main
et	doc_873901597557_item	2918667	et	3	main
sest	doc_873901597557_item	2918683	et	4	main
ma	doc_873901597557_item	2918684	et	3	main
tahtsin	doc_873901597557_item	2918685	et	3	main
sõbraga	doc_873901597557_item	2918721	et	3	main
tallinnas	doc_873901597557_item	2918726	et	4	main
et	doc_873901597557_item	2918732	et	3	main
on	doc_873901597557_item	2918735	et	4	main
ka	doc_873901597557_item	2918736	et	3	main
nii	doc_873901597557_item	2918737	et	3	main
nagu	doc_873901597557_item	2918739	et	3	main
mulle	doc_873901597558_item	2918746	et	4	main
meelde	doc_873901597558_item	2918747	et	3	main
aasta	doc_873901597558_item	2918748	et	4	main
2006	doc_873901597558_item	2918749	et	2	main
2006	doc_873901597558_item	2918750	et	2	main
huvitav	doc_873901597558_item	2918754	et	4	main
õnnelikud	doc_873901597558_item	2918762	et	3	main
hiilgavad	doc_873901597558_item	2918765	et	4	main
momendid	doc_873901597558_item	2918766	et	3	main
olin	doc_873901597558_item	2918775	et	3	main
oli	doc_873901597558_item	2918823	et	3	main
tallinna	doc_873901597558_item	2918829	et	4	main
väga	doc_873901597558_item	2918833	et	3	main
minu	doc_873901597558_item	2918838	et	3	main
ja	doc_873901597558_item	2918849	et	3	main
kuidas	doc_873901597558_item	2918850	et	3	main
näitas	doc_873901597558_item	2918852	et	3	main
väga	doc_873901597558_item	2918857	et	3	main
kõik	doc_873901597558_item	2918859	et	4	main
oli	doc_873901597558_item	2918860	et	3	main
tõit	doc_873901597559_item	2918885	et	4	main
ööelda	doc_873901597559_item	2918886	et	4	main
meeldi	doc_873901597559_item	2918889	et	4	main
2006	doc_873901597559_item	2918895	et	2	main
midagi	doc_873901597559_item	2918897	et	4	main
saame	doc_873901597559_item	2918902	et	4	main
aastal	doc_873901597559_item	2918922	et	3	main
katastrofid	doc_873901597559_item	2918926	et	4	main
ja	doc_873901597559_item	2918927	et	3	main
asub	doc_873901597559_item	2918952	et	3	main
poolest	doc_873901597560_item	2918958	et	4	main
mulle	doc_873901597560_item	2918960	et	4	main
on	doc_873901597556_item	2918527	et	4	main
ja	doc_873901597556_item	2918530	et	3	main
pidu	doc_873901597556_item	2918532	et	4	main
mina	doc_873901597556_item	2918543	et	4	main
alati	doc_873901597556_item	2918544	et	4	main
mulle	doc_873901597556_item	2918562	et	4	main
ma	doc_873901597556_item	2918569	et	3	main
suusatan	doc_873901597556_item	2918570	et	3	main
metsas	doc_873901597556_item	2918571	et	3	main
metsas	doc_873901597556_item	2918574	et	3	main
loomad	doc_873901597556_item	2918580	et	3	main
ei	doc_873901597556_item	2918585	et	4	main
liisaks	doc_873901597556_item	2918588	et	4	main
see	doc_873901597556_item	2918599	et	3	main
jõulupeol	doc_873901597556_item	2918603	et	4	main
vanematega	doc_873901597556_item	2918608	et	4	main
kõik	doc_873901597556_item	2918615	et	4	main
ilus	doc_873901597556_item	2918577	et	4	main
näha	doc_873901597556_item	2918581	et	3	main
piire	doc_873901597556_item	2918587	et	4	main
jõulu	doc_873901597556_item	2918594	et	4	main
kingitusi	doc_873901597556_item	2918598	et	4	main
väga	doc_873901597556_item	2918601	et	3	main
all	doc_873901597556_item	2918610	et	3	main
armsam	doc_873901597556_item	2918628	et	4	main
minu	doc_873901597556_item	2918630	et	3	main
eest	doc_873901597556_item	2918631	et	4	main
praegu	doc_873901597557_item	2918645	et	3	main
2006	doc_873901597557_item	2918647	et	2	main
see	doc_873901597557_item	2918649	et	3	main
oli	doc_873901597557_item	2918651	et	3	main
ma	doc_873901597557_item	2918662	et	3	main
pea	doc_873901597557_item	2918670	et	4	main
siia	doc_873901597557_item	2918672	et	4	main
hea	doc_873901597557_item	2918682	et	4	main
jõulu	doc_873901597556_item	2918622	et	4	main
ja	doc_873901597556_item	2918627	et	3	main
pidu	doc_873901597556_item	2918629	et	4	main
ps	doc_873901597556_item	2918632	et	4	main
head	doc_873901597556_item	2918633	et	4	main
jõulud	doc_873901597556_item	2918634	et	3	main
olete	doc_873901597556_item	2918635	et	3	main
õnnelikud	doc_873901597556_item	2918636	et	3	main
sellel	doc_873901597557_item	2918657	et	4	main
aastal	doc_873901597557_item	2918658	et	3	main
ma	doc_873901597557_item	2918659	et	3	main
lõpetasin	doc_873901597557_item	2918660	et	3	main
rõõm	doc_873901597557_item	2918665	et	3	main
sellepärast	doc_873901597557_item	2918666	et	3	main
ei	doc_873901597557_item	2918669	et	4	main
käima	doc_873901597557_item	2918671	et	4	main
õppida	doc_873901597557_item	2918686	et	3	main
siin	doc_873901597557_item	2918687	et	4	main
suvel	doc_873901597557_item	2918688	et	3	main
sõitsin	doc_873901597557_item	2918690	et	3	main
pärnusse	doc_873901597557_item	2918691	et	4	main
puhkama	doc_873901597557_item	2918692	et	3	main
pärnus	doc_873901597557_item	2918693	et	3	main
oli	doc_873901597557_item	2918694	et	3	main
väga	doc_873901597557_item	2918695	et	3	main
hea	doc_873901597557_item	2918696	et	4	main
ilm	doc_873901597557_item	2918697	et	3	main
vihma	doc_873901597557_item	2918698	et	4	main
ei	doc_873901597557_item	2918699	et	4	main
oli	doc_873901597557_item	2918700	et	3	main
päike	doc_873901597557_item	2918701	et	3	main
paistis	doc_873901597557_item	2918702	et	3	main
ja	doc_873901597557_item	2918703	et	3	main
mere	doc_873901597557_item	2918704	et	3	main
oli	doc_873901597557_item	2918705	et	3	main
nii	doc_873901597557_item	2918706	et	3	main
soe	doc_873901597557_item	2918707	et	4	main
ma	doc_873901597557_item	2918709	et	3	main
sest	doc_873901597557_item	2918708	et	4	main
ei	doc_873901597557_item	2918710	et	4	main
tahtnud	doc_873901597557_item	2918711	et	4	main
välja	doc_873901597557_item	2918712	et	4	main
minna	doc_873901597557_item	2918713	et	3	main
suvel	doc_873901597557_item	2918714	et	3	main
kui	doc_873901597557_item	2918715	et	3	main
ma	doc_873901597557_item	2918716	et	3	main
olin	doc_873901597557_item	2918717	et	3	main
tallinnas	doc_873901597557_item	2918718	et	4	main
mina	doc_873901597557_item	2918719	et	4	main
koos	doc_873901597557_item	2918720	et	4	main
sõitsin	doc_873901597557_item	2918723	et	3	main
ka	doc_873901597557_item	2918728	et	3	main
väga	doc_873901597557_item	2918652	et	3	main
väga	doc_873901597557_item	2918664	et	3	main
ma	doc_873901597557_item	2918668	et	3	main
ma	doc_873901597557_item	2918675	et	3	main
astusin	doc_873901597557_item	2918676	et	3	main
sel	doc_873901597557_item	2918677	et	3	main
aastal	doc_873901597557_item	2918678	et	3	main
ma	doc_873901597557_item	2918689	et	3	main
ka	doc_873901597557_item	2918722	et	3	main
essee	doc_873901597558_item	2918742	et	4	main
mille	doc_873901597558_item	2918743	et	3	main
aasta	doc_873901597558_item	2918751	et	4	main
palju	doc_873901597558_item	2918772	et	4	main
see	doc_873901597558_item	2918824	et	3	main
tehnika	doc_873901597558_item	2918830	et	4	main
huvitav	doc_873901597558_item	2918834	et	4	main
keele	doc_873901597558_item	2918840	et	4	main
oskus	doc_873901597558_item	2918841	et	3	main
ei	doc_873901597558_item	2918842	et	4	main
lühike	doc_873901597558_item	2918854	et	4	main
kõik	doc_873901597558_item	2918855	et	4	main
kiiresti	doc_873901597558_item	2918858	et	3	main
hea	doc_873901597558_item	2918861	et	4	main
aga	doc_873901597558_item	2918862	et	3	main
midagi	doc_873901597558_item	2918865	et	4	main
uuel	doc_873901597558_item	2918872	et	3	main
mille	doc_873901597559_item	2918878	et	3	main
poolest	doc_873901597559_item	2918879	et	4	main
mulle	doc_873901597559_item	2918887	et	4	main
oli	doc_873901597559_item	2918923	et	3	main
surid	doc_873901597559_item	2918928	et	4	main
väga	doc_873901597559_item	2918929	et	3	main
palju	doc_873901597559_item	2918930	et	4	main
meie	doc_873901597559_item	2918943	et	4	main
riigis	doc_873901597559_item	2918944	et	3	main
on	doc_873901597559_item	2918945	et	4	main
ebastabiilne	doc_873901597559_item	2918946	et	3	main
inimeste	doc_873901597559_item	2918947	et	3	main
elutase	doc_873901597559_item	2918948	et	3	main
ja	doc_873901597559_item	2918949	et	3	main
sotsiaalne	doc_873901597559_item	2918950	et	3	main
essee	doc_873901597560_item	2918956	et	4	main
meelde	doc_873901597560_item	2918961	et	3	main
2006	doc_873901597560_item	2918963	et	2	main
läheb	doc_873901597560_item	2918964	et	3	main
aasta	doc_873901597560_item	2918973	et	4	main
minu	doc_873901597560_item	2918974	et	3	main
jaoks	doc_873901597560_item	2918975	et	4	main
oli	doc_873901597560_item	2918976	et	3	main
tähtis	doc_873901597560_item	2918977	et	4	main
ja	doc_873901597560_item	2918978	et	3	main
jatas	doc_873901597560_item	2918979	et	4	main
oluline	doc_873901597560_item	2919011	et	4	main
juba	doc_873901597560_item	2919019	et	3	main
kümnendas	doc_873901597560_item	2919020	et	3	main
klassis	doc_873901597560_item	2919021	et	3	main
ttu	doc_873901597560_item	2919025	et	4	main
teasin	doc_873901597560_item	2919028	et	4	main
et	doc_873901597560_item	2919029	et	3	main
kõik	doc_873901597560_item	2919030	et	4	main
sõltub	doc_873901597560_item	2919031	et	3	main
sms	doc_873901597560_item	2919041	et	4	main
eksamid	doc_873901597560_item	2919044	et	3	main
sooritanud	doc_873901597560_item	2919047	et	4	main
juulikult	doc_873901597560_item	2919048	et	3	main
selle	doc_873901597560_item	2919049	et	4	main
ülikool	doc_873901597560_item	2919058	et	4	main
mulle	doc_873901597560_item	2919062	et	4	main
sel	doc_873901597560_item	2919064	et	3	main
vanaema	doc_873901597560_item	2919072	et	4	main
seal	doc_873901597560_item	2919076	et	4	main
pärast	doc_873901597560_item	2919080	et	4	main
soidsin	doc_873901597560_item	2919081	et	4	main
naljas	doc_873901597560_item	2919087	et	3	main
me	doc_873901597560_item	2919091	et	4	main
jalutada	doc_873901597560_item	2919093	et	3	main
läti	doc_873901597560_item	2919094	et	4	main
aasta	doc_873901597560_item	2919121	et	4	main
veel	doc_873901597560_item	2919123	et	4	main
parem	doc_873901597560_item	2919124	et	4	main
ma	doc_873901597561_item	2919138	et	3	main
see	doc_873901597561_item	2919149	et	3	main
mere	doc_873901597557_item	2918724	et	3	main
oli	doc_873901597557_item	2918727	et	3	main
aasta	doc_873901597557_item	2918733	et	4	main
oli	doc_873901597558_item	2918752	et	3	main
meeldejätmiv	doc_873901597558_item	2918756	et	4	main
sellel	doc_873901597558_item	2918758	et	4	main
aastal	doc_873901597558_item	2918759	et	3	main
palju	doc_873901597558_item	2918761	et	4	main
asjad	doc_873901597558_item	2918763	et	3	main
sankt-peterburgis	doc_873901597558_item	2918777	et	4	main
ilus	doc_873901597558_item	2918785	et	4	main
see	doc_873901597558_item	2918786	et	3	main
linn	doc_873901597558_item	2918787	et	3	main
väga	doc_873901597558_item	2918788	et	3	main
suur	doc_873901597558_item	2918789	et	3	main
mulje	doc_873901597558_item	2918790	et	4	main
oli	doc_873901597558_item	2918791	et	3	main
millal	doc_873901597558_item	2918792	et	3	main
ma	doc_873901597558_item	2918793	et	3	main
vaatasin	doc_873901597558_item	2918794	et	3	main
silla	doc_873901597558_item	2918795	et	3	main
lahtivõtmine	doc_873901597558_item	2918796	et	3	main
suvel	doc_873901597558_item	2918797	et	3	main
ma	doc_873901597558_item	2918798	et	3	main
töötasin	doc_873901597558_item	2918799	et	3	main
välismaal	doc_873901597558_item	2918800	et	4	main
inglismaal	doc_873901597558_item	2918801	et	4	main
seal	doc_873901597558_item	2918802	et	4	main
ma	doc_873901597558_item	2918803	et	3	main
olen	doc_873901597558_item	2918804	et	3	main
tegelenud	doc_873901597558_item	2918805	et	4	main
hotelliteeninduses	doc_873901597558_item	2918806	et	3	main
see	doc_873901597558_item	2918807	et	3	main
periood	doc_873901597558_item	2918808	et	3	main
oli	doc_873901597558_item	2918809	et	3	main
mitte	doc_873901597558_item	2918810	et	3	main
väga	doc_873901597558_item	2918811	et	3	main
huvitav	doc_873901597558_item	2918812	et	4	main
aga	doc_873901597558_item	2918813	et	3	main
oli	doc_873901597558_item	2918814	et	3	main
kasulik	doc_873901597558_item	2918815	et	3	main
minu	doc_873901597558_item	2918816	et	3	main
jaoks	doc_873901597558_item	2918817	et	4	main
minu	doc_873901597558_item	2918818	et	3	main
suur	doc_873901597558_item	2918819	et	3	main
saavutus	doc_873901597558_item	2918820	et	4	main
huvitav	doc_873901597557_item	2918730	et	4	main
2007	doc_873901597557_item	2918734	et	2	main
huvitav	doc_873901597557_item	2918738	et	4	main
aasta	doc_873901597557_item	2918740	et	4	main
2006	doc_873901597557_item	2918741	et	2	main
juhtusid	doc_873901597558_item	2918760	et	4	main
reisin	doc_873901597558_item	2918773	et	3	main
et	doc_873901597558_item	2918825	et	3	main
astusin	doc_873901597558_item	2918828	et	3	main
õppida	doc_873901597558_item	2918836	et	3	main
tahakse	doc_873901597558_item	2918864	et	4	main
paremat	doc_873901597558_item	2918866	et	4	main
seda	doc_873901597558_item	2918867	et	3	main
ma	doc_873901597558_item	2918868	et	3	main
soovin	doc_873901597558_item	2918869	et	3	main
ja	doc_873901597558_item	2918870	et	3	main
ootan	doc_873901597558_item	2918871	et	3	main
see	doc_873901597559_item	2918890	et	3	main
ma	doc_873901597559_item	2918893	et	3	main
huvitavat	doc_873901597559_item	2918900	et	4	main
väga	doc_873901597558_item	2918753	et	3	main
ja	doc_873901597558_item	2918755	et	3	main
aasta	doc_873901597558_item	2918757	et	4	main
olid	doc_873901597558_item	2918764	et	4	main
kahe	doc_873901597558_item	2918767	et	3	main
tuhande	doc_873901597558_item	2918768	et	3	main
kuuendal	doc_873901597558_item	2918769	et	3	main
aastal	doc_873901597558_item	2918770	et	3	main
mina	doc_873901597558_item	2918771	et	4	main
ma	doc_873901597558_item	2918774	et	3	main
venemaal	doc_873901597558_item	2918776	et	4	main
seal	doc_873901597558_item	2918778	et	4	main
ma	doc_873901597558_item	2918779	et	3	main
olen	doc_873901597558_item	2918780	et	3	main
imestatud	doc_873901597558_item	2918781	et	4	main
kui	doc_873901597558_item	2918782	et	3	main
suur	doc_873901597558_item	2918783	et	3	main
ja	doc_873901597558_item	2918784	et	3	main
aastal	doc_873901597558_item	2918822	et	3	main
ülikooli	doc_873901597558_item	2918831	et	4	main
mulle	doc_873901597558_item	2918832	et	4	main
ole	doc_873901597558_item	2918843	et	4	main
hea	doc_873901597558_item	2918844	et	4	main
2006	doc_873901597558_item	2918845	et	2	main
aasta	doc_873901597558_item	2918846	et	4	main
oli	doc_873901597558_item	2918847	et	3	main
positiivne	doc_873901597558_item	2918848	et	3	main
mind	doc_873901597558_item	2918851	et	4	main
alati	doc_873901597558_item	2918863	et	4	main
head	doc_873901597558_item	2918874	et	4	main
aastat	doc_873901597558_item	2918876	et	3	main
jäi	doc_873901597559_item	2918880	et	3	main
mulle	doc_873901597559_item	2918881	et	4	main
meelde	doc_873901597559_item	2918882	et	3	main
aasta	doc_873901597559_item	2918883	et	4	main
2006	doc_873901597559_item	2918884	et	2	main
aastat	doc_873901597559_item	2918891	et	3	main
selel	doc_873901597559_item	2918921	et	4	main
palju	doc_873901597559_item	2918925	et	4	main
probleemid	doc_873901597559_item	2918941	et	3	main
tasu	doc_873901597559_item	2918951	et	4	main
keskmisest	doc_873901597559_item	2918953	et	3	main
madalam	doc_873901597559_item	2918955	et	4	main
koera	doc_873901597560_item	2918966	et	4	main
kuues	doc_873901597560_item	2918970	et	4	main
aasta	doc_873901597560_item	2918971	et	4	main
see	doc_873901597560_item	2918972	et	3	main
mulle	doc_873901597560_item	2918980	et	4	main
asi	doc_873901597560_item	2919012	et	4	main
oli	doc_873901597560_item	2919014	et	3	main
minu	doc_873901597560_item	2919015	et	3	main
eksami	doc_873901597560_item	2919032	et	3	main
tulemustest	doc_873901597560_item	2919033	et	4	main
et	doc_873901597560_item	2919042	et	3	main
mina	doc_873901597560_item	2919051	et	4	main
õpin	doc_873901597560_item	2919052	et	3	main
meelde	doc_873901597560_item	2919063	et	3	main
mina	doc_873901597560_item	2919066	et	4	main
olin	doc_873901597560_item	2919067	et	3	main
kolmases	doc_873901597560_item	2919068	et	4	main
riikides	doc_873901597560_item	2919069	et	3	main
juunis	doc_873901597560_item	2919070	et	3	main
oli	doc_873901597560_item	2919075	et	3	main
nädal	doc_873901597560_item	2919077	et	3	main
minu	doc_873901597560_item	2919083	et	3	main
ja	doc_873901597560_item	2919086	et	3	main
et	doc_873901597560_item	2919089	et	3	main
essee	doc_873901597561_item	2919125	et	4	main
mille	doc_873901597561_item	2919126	et	3	main
sellel	doc_873901597561_item	2919133	et	4	main
lõpetasin	doc_873901597561_item	2919136	et	3	main
õpisin	doc_873901597561_item	2919139	et	4	main
koolis	doc_873901597561_item	2919140	et	4	main
kaheksateist	doc_873901597561_item	2919141	et	4	main
aastat	doc_873901597561_item	2919142	et	3	main
ja	doc_873901597561_item	2919143	et	3	main
kui	doc_873901597561_item	2919144	et	3	main
mulle	doc_873901597561_item	2919150	et	4	main
ja	doc_873901597561_item	2919166	et	3	main
ja	doc_873901597561_item	2919168	et	3	main
ttüs	doc_873901597561_item	2919171	et	4	main
ülikoolis	doc_873901597561_item	2919181	et	4	main
sellel	doc_873901597558_item	2918821	et	4	main
septembris	doc_873901597558_item	2918826	et	3	main
ma	doc_873901597558_item	2918827	et	3	main
siin	doc_873901597558_item	2918835	et	4	main
tõsi	doc_873901597558_item	2918837	et	4	main
eesti	doc_873901597558_item	2918839	et	4	main
väga	doc_873901597558_item	2918853	et	3	main
läks	doc_873901597558_item	2918856	et	3	main
aastal	doc_873901597558_item	2918873	et	3	main
uut	doc_873901597558_item	2918875	et	3	main
essee	doc_873901597559_item	2918877	et	4	main
ei	doc_873901597559_item	2918888	et	4	main
sest	doc_873901597559_item	2918892	et	4	main
ootasin	doc_873901597559_item	2918894	et	3	main
aastast	doc_873901597559_item	2918896	et	4	main
ebatavalist	doc_873901597559_item	2918898	et	4	main
ja	doc_873901597559_item	2918899	et	3	main
me	doc_873901597559_item	2918901	et	4	main
ka	doc_873901597559_item	2918903	et	3	main
võtta	doc_873901597559_item	2918904	et	3	main
niisuguseid	doc_873901597559_item	2918905	et	3	main
globaalseid	doc_873901597559_item	2918906	et	3	main
küsimusi	doc_873901597559_item	2918907	et	4	main
nagu	doc_873901597559_item	2918908	et	3	main
me	doc_873901597559_item	2918909	et	4	main
juba	doc_873901597559_item	2918910	et	3	main
teame	doc_873901597559_item	2918911	et	3	main
et	doc_873901597559_item	2918912	et	3	main
meie	doc_873901597559_item	2918913	et	4	main
maailm	doc_873901597559_item	2918914	et	3	main
tänapäevases	doc_873901597559_item	2918915	et	4	main
elus	doc_873901597559_item	2918916	et	4	main
on	doc_873901597559_item	2918917	et	4	main
ebastabiilne	doc_873901597559_item	2918918	et	3	main
ja	doc_873901597559_item	2918919	et	3	main
rahutu	doc_873901597559_item	2918920	et	4	main
liiga	doc_873901597559_item	2918924	et	4	main
palju	doc_873901597559_item	2918940	et	4	main
tasemest	doc_873901597559_item	2918954	et	3	main
meelde	doc_873901597560_item	2918982	et	3	main
ttu	doc_873901597560_item	2919017	et	4	main
otsustasin	doc_873901597560_item	2919023	et	3	main
ülikooli	doc_873901597560_item	2919026	et	4	main
aga	doc_873901597560_item	2919027	et	3	main
kui	doc_873901597560_item	2919039	et	3	main
sain	doc_873901597560_item	2919040	et	3	main
kõik	doc_873901597560_item	2919043	et	4	main
on	doc_873901597560_item	2919045	et	4	main
muidugi	doc_873901597560_item	2919055	et	4	main
pole	doc_873901597560_item	2919056	et	3	main
eksamid	doc_873901597560_item	2919060	et	3	main
sõidsin	doc_873901597560_item	2919071	et	4	main
moskvasse	doc_873901597560_item	2919074	et	4	main
kohe	doc_873901597560_item	2919079	et	4	main
temaga	doc_873901597560_item	2919090	et	3	main
sõidsime	doc_873901597560_item	2919092	et	4	main
ma	doc_873901597561_item	2919135	et	3	main
viimane	doc_873901597561_item	2919147	et	3	main
ma	doc_873901597561_item	2919163	et	3	main
ma	doc_873901597561_item	2919169	et	3	main
astusin	doc_873901597561_item	2919173	et	3	main
aga	doc_873901597561_item	2919182	et	3	main
mõtlen	doc_873901597561_item	2919184	et	3	main
sõpradest	doc_873901597561_item	2919186	et	3	main
inimesid	doc_873901597559_item	2918931	et	4	main
ma	doc_873901597559_item	2918932	et	3	main
elan	doc_873901597559_item	2918933	et	3	main
eestis	doc_873901597559_item	2918934	et	3	main
ja	doc_873901597559_item	2918935	et	3	main
eestis	doc_873901597559_item	2918936	et	3	main
oli	doc_873901597559_item	2918937	et	3	main
ka	doc_873901597559_item	2918938	et	3	main
väga	doc_873901597559_item	2918939	et	3	main
elu	doc_873901597559_item	2918942	et	4	main
mille	doc_873901597560_item	2918957	et	3	main
jäi	doc_873901597560_item	2918959	et	3	main
aasta	doc_873901597560_item	2918962	et	4	main
lõpuni	doc_873901597560_item	2918965	et	3	main
aasta	doc_873901597560_item	2918967	et	4	main
kahe	doc_873901597560_item	2918968	et	3	main
tuhande	doc_873901597560_item	2918969	et	3	main
esmakordselt	doc_873901597560_item	2918983	et	4	main
mind	doc_873901597560_item	2918984	et	4	main
lõpetasin	doc_873901597560_item	2918985	et	3	main
kooli	doc_873901597560_item	2918986	et	4	main
ja	doc_873901597560_item	2918987	et	3	main
sain	doc_873901597560_item	2918988	et	3	main
tunnistust	doc_873901597560_item	2918989	et	4	main
ma	doc_873901597560_item	2918990	et	3	main
ei	doc_873901597560_item	2918991	et	4	main
saa	doc_873901597560_item	2918992	et	4	main
ütelda	doc_873901597560_item	2918993	et	4	main
et	doc_873901597560_item	2918994	et	3	main
riigieksamid	doc_873901597560_item	2918995	et	3	main
olid	doc_873901597560_item	2918996	et	4	main
väga	doc_873901597560_item	2918997	et	3	main
rasked	doc_873901597560_item	2918998	et	3	main
aga	doc_873901597560_item	2918999	et	3	main
täpselt	doc_873901597560_item	2919000	et	4	main
tean	doc_873901597560_item	2919001	et	3	main
et	doc_873901597560_item	2919002	et	3	main
see	doc_873901597560_item	2919003	et	3	main
oli	doc_873901597560_item	2919004	et	3	main
kõige	doc_873901597560_item	2919005	et	4	main
närvilisem	doc_873901597560_item	2919006	et	4	main
aeg	doc_873901597560_item	2919007	et	3	main
minu	doc_873901597560_item	2919008	et	3	main
elus	doc_873901597560_item	2919009	et	4	main
teine	doc_873901597560_item	2919010	et	3	main
palju	doc_873901597560_item	2918981	et	4	main
ülikoolis	doc_873901597560_item	2919018	et	4	main
suvel	doc_873901597560_item	2919013	et	3	main
vastuvõtt	doc_873901597560_item	2919016	et	3	main
mina	doc_873901597560_item	2919022	et	4	main
õnnelikum	doc_873901597560_item	2919035	et	4	main
päev	doc_873901597560_item	2919036	et	3	main
oli	doc_873901597560_item	2919037	et	3	main
siis	doc_873901597560_item	2919038	et	3	main
hästi	doc_873901597560_item	2919046	et	3	main
ttu	doc_873901597560_item	2919053	et	4	main
ülikoolis	doc_873901597560_item	2919054	et	4	main
ja	doc_873901597560_item	2919059	et	3	main
jätasid	doc_873901597560_item	2919061	et	4	main
suvel	doc_873901597560_item	2919065	et	3	main
leeduse	doc_873901597560_item	2919082	et	4	main
juurde	doc_873901597560_item	2919085	et	4	main
asi	doc_873901597560_item	2919088	et	4	main
juba	doc_873901597560_item	2919095	et	3	main
tema	doc_873901597560_item	2919096	et	4	main
sõbraga	doc_873901597560_item	2919097	et	3	main
poolest	doc_873901597561_item	2919127	et	4	main
jai	doc_873901597561_item	2919128	et	4	main
mulle	doc_873901597561_item	2919129	et	4	main
meelde	doc_873901597561_item	2919130	et	3	main
aasta	doc_873901597561_item	2919131	et	4	main
2006	doc_873901597561_item	2919132	et	2	main
oli	doc_873901597561_item	2919146	et	3	main
meelde	doc_873901597561_item	2919151	et	3	main
minu	doc_873901597561_item	2919172	et	3	main
selle	doc_873901597561_item	2919175	et	4	main
meelde	doc_873901597561_item	2919177	et	3	main
täna	doc_873901597561_item	2919178	et	4	main
ma	doc_873901597561_item	2919179	et	3	main
õpetan	doc_873901597561_item	2919180	et	3	main
lõpetasin	doc_873901597561_item	2919191	et	3	main
meeskonnast	doc_873901597561_item	2919203	et	4	main
palju	doc_873901597561_item	2919204	et	4	main
oli	doc_873901597561_item	2919206	et	3	main
et	doc_873901597561_item	2919211	et	3	main
kõige	doc_873901597561_item	2919214	et	4	main
mille	doc_873901597562_item	2919216	et	3	main
astuda	doc_873901597560_item	2919024	et	3	main
kõige	doc_873901597560_item	2919034	et	4	main
pärast	doc_873901597560_item	2919050	et	4	main
ainult	doc_873901597560_item	2919057	et	4	main
juurde	doc_873901597560_item	2919073	et	4	main
ja	doc_873901597560_item	2919078	et	3	main
sõbra	doc_873901597560_item	2919084	et	3	main
ühe	doc_873901597560_item	2919098	et	4	main
sõnaga	doc_873901597560_item	2919099	et	3	main
see	doc_873901597560_item	2919100	et	3	main
oli	doc_873901597560_item	2919101	et	3	main
matk	doc_873901597560_item	2919103	et	3	main
lõbus	doc_873901597560_item	2919102	et	4	main
praegu	doc_873901597560_item	2919104	et	3	main
aga	doc_873901597560_item	2919105	et	3	main
ootan	doc_873901597560_item	2919106	et	3	main
2007	doc_873901597560_item	2919107	et	2	main
aastat	doc_873901597560_item	2919108	et	3	main
ja	doc_873901597560_item	2919109	et	3	main
vaatamata	doc_873901597560_item	2919110	et	4	main
et	doc_873901597560_item	2919111	et	3	main
see	doc_873901597560_item	2919112	et	3	main
oli	doc_873901597560_item	2919113	et	3	main
tore	doc_873901597560_item	2919114	et	3	main
ja	doc_873901597560_item	2919115	et	3	main
huvitav	doc_873901597560_item	2919116	et	4	main
aasta	doc_873901597560_item	2919117	et	4	main
loodan	doc_873901597560_item	2919118	et	3	main
et	doc_873901597560_item	2919119	et	3	main
järgmine	doc_873901597560_item	2919120	et	3	main
on	doc_873901597560_item	2919122	et	4	main
aastal	doc_873901597561_item	2919134	et	3	main
kool	doc_873901597561_item	2919137	et	4	main
neil	doc_873901597561_item	2919145	et	4	main
tund	doc_873901597561_item	2919148	et	3	main
ma	doc_873901597561_item	2919154	et	3	main
laksin	doc_873901597561_item	2919155	et	3	main
töötada	doc_873901597561_item	2919156	et	3	main
kõige	doc_873901597561_item	2919157	et	4	main
kooli	doc_873901597561_item	2919153	et	4	main
juuni	doc_873901597561_item	2919158	et	4	main
ma	doc_873901597561_item	2919159	et	3	main
mõtlesin	doc_873901597561_item	2919160	et	3	main
kuhu	doc_873901597561_item	2919161	et	3	main
astuda	doc_873901597561_item	2919162	et	3	main
pärast	doc_873901597561_item	2919152	et	4	main
astusin	doc_873901597561_item	2919164	et	3	main
ttüs	doc_873901597561_item	2919165	et	4	main
ma	doc_873901597561_item	2919190	et	3	main
ma	doc_873901597561_item	2919194	et	3	main
käsipalli	doc_873901597561_item	2919196	et	4	main
palju	doc_873901597561_item	2919198	et	4	main
mõtlesin	doc_873901597561_item	2919199	et	3	main
aastal	doc_873901597561_item	2919208	et	3	main
ma	doc_873901597561_item	2919212	et	3	main
see	doc_873901597562_item	2919225	et	3	main
oli	doc_873901597562_item	2919238	et	3	main
ja	doc_873901597562_item	2919246	et	3	main
venemaal	doc_873901597562_item	2919284	et	4	main
hommikuni	doc_873901597562_item	2919300	et	4	main
sel	doc_873901597562_item	2919301	et	3	main
aastal	doc_873901597562_item	2919302	et	3	main
pärnus	doc_873901597562_item	2919311	et	3	main
veepargis	doc_873901597562_item	2919312	et	3	main
oli	doc_873901597562_item	2919323	et	3	main
eestikodaniku	doc_873901597562_item	2919328	et	3	main
et	doc_873901597562_item	2919330	et	3	main
nüüd	doc_873901597562_item	2919331	et	4	main
euroopas	doc_873901597562_item	2919334	et	3	main
kurb	doc_873901597562_item	2919336	et	3	main
oli	doc_873901597562_item	2919338	et	3	main
sel	doc_873901597562_item	2919339	et	3	main
aastal	doc_873901597562_item	2919340	et	3	main
vanaema	doc_873901597562_item	2919343	et	4	main
liiga	doc_873901597562_item	2919351	et	4	main
rohkem	doc_873901597562_item	2919360	et	4	main
kui	doc_873901597562_item	2919362	et	3	main
poolest	doc_873901597563_item	2919373	et	4	main
see	doc_873901597563_item	2919379	et	3	main
2006	doc_873901597563_item	2919382	et	2	main
sellel	doc_873901597563_item	2919392	et	4	main
koolilõpetajadele	doc_873901597563_item	2919422	et	4	main
lõppetamist	doc_873901597563_item	2919432	et	4	main
oli	doc_873901597563_item	2919433	et	3	main
oli	doc_873901597563_item	2919447	et	3	main
sellest	doc_873901597563_item	2919449	et	4	main
mulle	doc_873901597563_item	2919451	et	4	main
tudengite	doc_873901597563_item	2919457	et	3	main
suvi	doc_873901597563_item	2919460	et	3	main
mulle	doc_873901597563_item	2919462	et	4	main
parem	doc_873901597563_item	2919463	et	4	main
ma	doc_873901597563_item	2919466	et	3	main
esimene	doc_873901597563_item	2919468	et	3	main
ülikoolis	doc_873901597563_item	2919470	et	4	main
kus	doc_873901597563_item	2919471	et	3	main
meeldiv	doc_873901597563_item	2919475	et	4	main
uued	doc_873901597563_item	2919481	et	3	main
väga	doc_873901597563_item	2919485	et	3	main
ülikooli	doc_873901597563_item	2919487	et	4	main
hea	doc_873901597563_item	2919493	et	4	main
ma	doc_873901597563_item	2919500	et	3	main
tttks	doc_873901597561_item	2919167	et	4	main
läksin	doc_873901597561_item	2919170	et	3	main
ttüs	doc_873901597561_item	2919174	et	4	main
mulle	doc_873901597561_item	2919176	et	4	main
ma	doc_873901597561_item	2919183	et	3	main
omadest	doc_873901597561_item	2919185	et	3	main
koolist	doc_873901597561_item	2919187	et	4	main
spordiga	doc_873901597561_item	2919193	et	3	main
tegelen	doc_873901597561_item	2919195	et	3	main
ma	doc_873901597561_item	2919197	et	3	main
võistusest	doc_873901597561_item	2919201	et	4	main
sellel	doc_873901597561_item	2919207	et	4	main
ma	doc_873901597561_item	2919209	et	3	main
mäletan	doc_873901597561_item	2919213	et	3	main
aasta	doc_873901597562_item	2919221	et	4	main
oli	doc_873901597562_item	2919227	et	3	main
lõbus	doc_873901597562_item	2919229	et	4	main
õppimine	doc_873901597562_item	2919244	et	4	main
mu	doc_873901597562_item	2919249	et	3	main
seal	doc_873901597562_item	2919286	et	4	main
väga	doc_873901597562_item	2919288	et	3	main
ma	doc_873901597562_item	2919291	et	3	main
öösel	doc_873901597562_item	2919299	et	4	main
reisin	doc_873901597562_item	2919303	et	3	main
eestis	doc_873901597562_item	2919304	et	3	main
ka	doc_873901597562_item	2919305	et	3	main
väga	doc_873901597562_item	2919306	et	3	main
palju	doc_873901597562_item	2919307	et	4	main
jalutasin	doc_873901597562_item	2919308	et	3	main
sain	doc_873901597562_item	2919319	et	3	main
et	doc_873901597562_item	2919321	et	3	main
ka	doc_873901597562_item	2919327	et	3	main
passi	doc_873901597562_item	2919329	et	4	main
mu	doc_873901597562_item	2919342	et	3	main
venemaal	doc_873901597562_item	2919346	et	4	main
me	doc_873901597562_item	2919348	et	4	main
töökoht	doc_873901597562_item	2919355	et	3	main
et	doc_873901597562_item	2919356	et	3	main
teenin	doc_873901597562_item	2919357	et	3	main
praegu	doc_873901597562_item	2919358	et	3	main
taskuraha	doc_873901597562_item	2919361	et	4	main
varem	doc_873901597562_item	2919363	et	4	main
lõppkokkuvõttes	doc_873901597562_item	2919364	et	3	main
see	doc_873901597562_item	2919365	et	3	main
aasta	doc_873901597562_item	2919366	et	4	main
oli	doc_873901597562_item	2919367	et	3	main
hea	doc_873901597562_item	2919368	et	4	main
minu	doc_873901597562_item	2919369	et	3	main
melde	doc_873901597563_item	2919376	et	4	main
aasta	doc_873901597563_item	2919380	et	4	main
väga	doc_873901597563_item	2919384	et	3	main
kõigdest	doc_873901597563_item	2919388	et	4	main
see	doc_873901597563_item	2919423	et	3	main
jäi	doc_873901597563_item	2919427	et	3	main
melde	doc_873901597563_item	2919429	et	4	main
pärast	doc_873901597563_item	2919430	et	4	main
ei	doc_873901597563_item	2919452	et	4	main
suve	doc_873901597563_item	2919464	et	4	main
päevast	doc_873901597563_item	2919477	et	4	main
õppetamise	doc_873901597563_item	2919479	et	4	main
sööklad	doc_873901597563_item	2919491	et	3	main
kohvik	doc_873901597563_item	2919494	et	3	main
see	doc_873901597563_item	2919496	et	3	main
sellel	doc_873901597561_item	2919188	et	4	main
aastal	doc_873901597561_item	2919189	et	3	main
omadest	doc_873901597561_item	2919200	et	3	main
omades	doc_873901597561_item	2919202	et	4	main
arvan	doc_873901597561_item	2919210	et	3	main
2006	doc_873901597562_item	2919222	et	2	main
kõik	doc_873901597562_item	2919237	et	4	main
koolis	doc_873901597562_item	2919245	et	4	main
ja	doc_873901597562_item	2919251	et	3	main
nii	doc_873901597562_item	2919279	et	3	main
pisikene	doc_873901597562_item	2919280	et	3	main
suvel	doc_873901597562_item	2919281	et	3	main
ma	doc_873901597562_item	2919282	et	3	main
päevitusin	doc_873901597562_item	2919294	et	3	main
järves	doc_873901597562_item	2919315	et	4	main
aastal	doc_873901597562_item	2919317	et	3	main
juhiload	doc_873901597562_item	2919320	et	4	main
raske	doc_873901597562_item	2919325	et	4	main
sain	doc_873901597562_item	2919326	et	3	main
üks	doc_873901597562_item	2919335	et	3	main
asi	doc_873901597562_item	2919337	et	4	main
elas	doc_873901597562_item	2919345	et	3	main
harva	doc_873901597562_item	2919352	et	4	main
leidsin	doc_873901597562_item	2919353	et	3	main
uus	doc_873901597562_item	2919354	et	3	main
aasta	doc_873901597563_item	2919377	et	4	main
aasta	doc_873901597563_item	2919381	et	4	main
ja	doc_873901597563_item	2919386	et	3	main
üks	doc_873901597563_item	2919387	et	3	main
meeldejaatmisest	doc_873901597563_item	2919389	et	4	main
minu	doc_873901597563_item	2919390	et	3	main
pidud	doc_873901597563_item	2919421	et	3	main
aeg	doc_873901597563_item	2919424	et	3	main
küll	doc_873901597563_item	2919426	et	4	main
kooli	doc_873901597563_item	2919431	et	4	main
ülikoolis	doc_873901597563_item	2919440	et	4	main
et	doc_873901597563_item	2919441	et	3	main
ma	doc_873901597563_item	2919442	et	3	main
tulen	doc_873901597563_item	2919443	et	3	main
pidu	doc_873901597563_item	2919448	et	4	main
olnud	doc_873901597563_item	2919453	et	4	main
oma	doc_873901597563_item	2919456	et	4	main
oli	doc_873901597563_item	2919473	et	3	main
kollektiiv	doc_873901597563_item	2919484	et	3	main
suur	doc_873901597563_item	2919486	et	3	main
hoone	doc_873901597563_item	2919488	et	4	main
hea	doc_873901597563_item	2919489	et	4	main
spordikeskus	doc_873901597563_item	2919490	et	3	main
unistan	doc_873901597563_item	2919501	et	3	main
tegelema	doc_873901597561_item	2919192	et	3	main
head	doc_873901597561_item	2919205	et	4	main
essee	doc_873901597562_item	2919215	et	4	main
poolest	doc_873901597562_item	2919217	et	4	main
mul	doc_873901597562_item	2919218	et	3	main
tuleb	doc_873901597562_item	2919219	et	3	main
meelde	doc_873901597562_item	2919220	et	3	main
jaoks	doc_873901597562_item	2919224	et	4	main
aasta	doc_873901597562_item	2919226	et	4	main
väga	doc_873901597562_item	2919228	et	3	main
ta	doc_873901597562_item	2919230	et	4	main
alustas	doc_873901597562_item	2919231	et	3	main
mitte	doc_873901597562_item	2919232	et	3	main
väga	doc_873901597562_item	2919233	et	3	main
hästi	doc_873901597562_item	2919234	et	3	main
aga	doc_873901597562_item	2919235	et	3	main
pärast	doc_873901597562_item	2919236	et	4	main
hästi	doc_873901597562_item	2919248	et	3	main
kooli-	doc_873901597562_item	2919250	et	4	main
riigieksamid	doc_873901597562_item	2919252	et	3	main
aastal	doc_873901597562_item	2919254	et	3	main
ma	doc_873901597562_item	2919255	et	3	main
astusin	doc_873901597562_item	2919256	et	3	main
sisse	doc_873901597562_item	2919257	et	4	main
ülikoolisse	doc_873901597562_item	2919258	et	4	main
mu	doc_873901597562_item	2919259	et	3	main
vennal	doc_873901597562_item	2919260	et	3	main
sündis	doc_873901597562_item	2919261	et	3	main
novembri	doc_873901597562_item	2919262	et	3	main
olin	doc_873901597562_item	2919283	et	3	main
oli	doc_873901597562_item	2919287	et	3	main
ilm	doc_873901597562_item	2919290	et	3	main
järvedes	doc_873901597562_item	2919293	et	3	main
jalutasin	doc_873901597562_item	2919296	et	3	main
olin	doc_873901597562_item	2919310	et	3	main
viitna	doc_873901597562_item	2919314	et	4	main
sel	doc_873901597562_item	2919316	et	3	main
see	doc_873901597562_item	2919322	et	3	main
võin	doc_873901597562_item	2919332	et	3	main
reisida	doc_873901597562_item	2919333	et	3	main
teineteist	doc_873901597562_item	2919350	et	4	main
jaoks	doc_873901597562_item	2919370	et	4	main
essee	doc_873901597563_item	2919371	et	4	main
mille	doc_873901597563_item	2919372	et	3	main
2006	doc_873901597563_item	2919378	et	2	main
on	doc_873901597563_item	2919383	et	4	main
oluline	doc_873901597563_item	2919385	et	4	main
ülikooli	doc_873901597563_item	2919435	et	4	main
kui	doc_873901597563_item	2919436	et	3	main
ma	doc_873901597563_item	2919437	et	3	main
sai	doc_873901597563_item	2919438	et	4	main
vastus	doc_873901597563_item	2919439	et	3	main
ttüsse	doc_873901597563_item	2919445	et	4	main
vaja	doc_873901597563_item	2919454	et	4	main
mõtleda	doc_873901597563_item	2919455	et	4	main
ja	doc_873901597563_item	2919459	et	3	main
sai	doc_873901597563_item	2919461	et	4	main
lõppetuses	doc_873901597563_item	2919465	et	4	main
olin	doc_873901597563_item	2919467	et	3	main
mulle	doc_873901597563_item	2919472	et	4	main
uus	doc_873901597563_item	2919478	et	3	main
süsteem	doc_873901597563_item	2919480	et	3	main
õpetajad	doc_873901597563_item	2919482	et	4	main
uus	doc_873901597563_item	2919483	et	3	main
muljed	doc_873901597563_item	2919499	et	3	main
minu	doc_873901597562_item	2919223	et	3	main
korras	doc_873901597562_item	2919239	et	4	main
sellel	doc_873901597562_item	2919240	et	4	main
aastal	doc_873901597562_item	2919241	et	3	main
ma	doc_873901597562_item	2919242	et	3	main
lõpetasin	doc_873901597562_item	2919243	et	3	main
sooritasin	doc_873901597562_item	2919247	et	3	main
sellel	doc_873901597562_item	2919253	et	4	main
kuus	doc_873901597562_item	2919263	et	4	main
pojake	doc_873901597562_item	2919264	et	4	main
see	doc_873901597562_item	2919265	et	3	main
oli	doc_873901597562_item	2919266	et	3	main
suurepärane	doc_873901597562_item	2919267	et	4	main
uudis	doc_873901597562_item	2919268	et	3	main
minu	doc_873901597562_item	2919269	et	3	main
jaoks	doc_873901597562_item	2919270	et	4	main
et	doc_873901597562_item	2919271	et	3	main
praegu	doc_873901597562_item	2919272	et	3	main
mul	doc_873901597562_item	2919273	et	3	main
on	doc_873901597562_item	2919274	et	4	main
vennapoeg	doc_873901597562_item	2919275	et	3	main
praegu	doc_873901597562_item	2919276	et	3	main
ta	doc_873901597562_item	2919277	et	4	main
on	doc_873901597562_item	2919278	et	4	main
ja	doc_873901597562_item	2919285	et	3	main
soe	doc_873901597562_item	2919289	et	4	main
suplesin	doc_873901597562_item	2919292	et	3	main
ja	doc_873901597562_item	2919295	et	3	main
oma	doc_873901597562_item	2919297	et	4	main
sõpradega	doc_873901597562_item	2919298	et	3	main
narvas	doc_873901597562_item	2919309	et	4	main
suplesin	doc_873901597562_item	2919313	et	3	main
ma	doc_873901597562_item	2919318	et	3	main
väga	doc_873901597562_item	2919324	et	3	main
suri	doc_873901597562_item	2919341	et	3	main
ta	doc_873901597562_item	2919344	et	4	main
sest	doc_873901597562_item	2919347	et	4	main
nägesime	doc_873901597562_item	2919349	et	4	main
natuke	doc_873901597562_item	2919359	et	4	main
jäi	doc_873901597563_item	2919374	et	3	main
mulle	doc_873901597563_item	2919375	et	4	main
elus	doc_873901597563_item	2919391	et	4	main
ma	doc_873901597563_item	2919394	et	3	main
aastal	doc_873901597563_item	2919393	et	3	main
lõpetasin	doc_873901597563_item	2919395	et	3	main
kooli	doc_873901597563_item	2919396	et	4	main
sai	doc_873901597563_item	2919397	et	4	main
tudengiks	doc_873901597563_item	2919398	et	3	main
selle	doc_873901597563_item	2919399	et	4	main
aasta	doc_873901597563_item	2919400	et	4	main
suvi	doc_873901597563_item	2919401	et	3	main
oli	doc_873901597563_item	2919402	et	3	main
väga	doc_873901597563_item	2919403	et	3	main
tore	doc_873901597563_item	2919404	et	3	main
ja	doc_873901597563_item	2919405	et	3	main
jäi	doc_873901597563_item	2919406	et	3	main
meeles	doc_873901597563_item	2919407	et	3	main
ka	doc_873901597563_item	2919408	et	3	main
aasta	doc_873901597563_item	2919409	et	4	main
alguses	doc_873901597563_item	2919410	et	4	main
kevadel	doc_873901597563_item	2919411	et	4	main
oli	doc_873901597563_item	2919412	et	3	main
kooli	doc_873901597563_item	2919413	et	4	main
lõpetamine	doc_873901597563_item	2919414	et	4	main
meil	doc_873901597563_item	2919415	et	4	main
oli	doc_873901597563_item	2919416	et	3	main
eksaamid	doc_873901597563_item	2919417	et	3	main
väljalaste	doc_873901597563_item	2919418	et	4	main
õht	doc_873901597563_item	2919419	et	4	main
erinevad	doc_873901597563_item	2919420	et	4	main
on	doc_873901597563_item	2919425	et	4	main
mulle	doc_873901597563_item	2919428	et	4	main
asutumine	doc_873901597563_item	2919434	et	4	main
õppima	doc_873901597563_item	2919444	et	3	main
mul	doc_873901597563_item	2919446	et	3	main
minutist	doc_873901597563_item	2919450	et	4	main
tulevikust	doc_873901597563_item	2919458	et	4	main
kord	doc_873901597563_item	2919469	et	4	main
väga	doc_873901597563_item	2919474	et	3	main
esimesest	doc_873901597563_item	2919476	et	3	main
nagu	doc_873901597563_item	2919492	et	3	main
kõik	doc_873901597563_item	2919495	et	4	main
avalas	doc_873901597563_item	2919497	et	3	main
mulle	doc_873901597563_item	2919498	et	4	main
mulle	doc_873901597565_item	2919669	et	4	main
meelde	doc_873901597565_item	2919670	et	3	main
huvitavaid	doc_873901597565_item	2919679	et	4	main
sellel	doc_873901597565_item	2919681	et	4	main
lõpetasin	doc_873901597565_item	2919684	et	3	main
oli	doc_873901597565_item	2919675	et	3	main
inlise	doc_873901597565_item	2919723	et	4	main
keeles	doc_873901597565_item	2919733	et	4	main
järgmisel	doc_873901597565_item	2919734	et	3	main
aastal	doc_873901597565_item	2919735	et	3	main
tahan	doc_873901597565_item	2919737	et	3	main
ma	doc_873901597565_item	2919742	et	3	main
praegu	doc_873901597565_item	2919766	et	3	main
mul	doc_873901597565_item	2919767	et	3	main
on	doc_873901597565_item	2919768	et	4	main
väga	doc_873901597565_item	2919769	et	3	main
ma	doc_873901597565_item	2919772	et	3	main
et	doc_873901597565_item	2919774	et	3	main
aasta	doc_873901597565_item	2919776	et	4	main
oli	doc_873901597565_item	2919777	et	3	main
väga	doc_873901597565_item	2919778	et	3	main
meelde	doc_873901597565_item	2919779	et	3	main
jääv	doc_873901597565_item	2919780	et	4	main
ja	doc_873901597565_item	2919781	et	3	main
aastat	doc_873901597565_item	2919788	et	3	main
essee	doc_873901597566_item	2919791	et	4	main
väga	doc_873901597566_item	2919801	et	3	main
rõõmus	doc_873901597566_item	2919803	et	4	main
tugev	doc_873901597566_item	2919807	et	4	main
lõpupidu	doc_873901597566_item	2919818	et	4	main
raskem	doc_873901597566_item	2919828	et	4	main
eksamide	doc_873901597566_item	2919831	et	4	main
ajal	doc_873901597566_item	2919832	et	4	main
me	doc_873901597566_item	2919844	et	4	main
pärast	doc_873901597566_item	2919848	et	4	main
tuli	doc_873901597566_item	2919853	et	4	main
kelleks	doc_873901597566_item	2919858	et	4	main
tahaksin	doc_873901597566_item	2919860	et	3	main
peal	doc_873901597566_item	2919863	et	4	main
oli	doc_873901597566_item	2919864	et	3	main
revolutsioon	doc_873901597566_item	2919865	et	3	main
ja	doc_873901597566_item	2919866	et	3	main
ma	doc_873901597566_item	2919867	et	3	main
ei	doc_873901597566_item	2919868	et	4	main
ei	doc_873901597566_item	2919902	et	4	main
olnud	doc_873901597566_item	2919903	et	4	main
tagasi	doc_873901597566_item	2919907	et	3	main
et	doc_873901597566_item	2919927	et	3	main
ma	doc_873901597566_item	2919928	et	3	main
ma	doc_873901597566_item	2919932	et	3	main
õpingukorraldusele	doc_873901597566_item	2919951	et	3	main
loeng	doc_873901597566_item	2919956	et	3	main
väga	doc_873901597566_item	2919959	et	3	main
sain	doc_873901597566_item	2919962	et	3	main
kellega	doc_873901597566_item	2919976	et	3	main
sa	doc_873901597566_item	2919984	et	3	main
kohtusin	doc_873901597566_item	2919989	et	4	main
ma	doc_873901597566_item	2920026	et	3	main
palju	doc_873901597566_item	2920028	et	4	main
õpin	doc_873901597566_item	2920032	et	3	main
aasta	doc_873901597565_item	2919671	et	4	main
2006	doc_873901597565_item	2919672	et	2	main
2006	doc_873901597565_item	2919673	et	2	main
v	doc_873901597565_item	2919676	et	4	main
aastal	doc_873901597565_item	2919682	et	3	main
keel	doc_873901597565_item	2919724	et	4	main
on	doc_873901597565_item	2919726	et	4	main
aastal	doc_873901597565_item	2919761	et	3	main
tuttvusin	doc_873901597565_item	2919763	et	4	main
inimesiga	doc_873901597565_item	2919765	et	4	main
sõpru	doc_873901597565_item	2919771	et	3	main
seline	doc_873901597565_item	2919775	et	4	main
järgmine	doc_873901597565_item	2919787	et	3	main
parem	doc_873901597565_item	2919790	et	4	main
mille	doc_873901597566_item	2919792	et	3	main
huvitav	doc_873901597566_item	2919802	et	4	main
meil	doc_873901597566_item	2919814	et	4	main
oli	doc_873901597566_item	2919815	et	3	main
väga	doc_873901597566_item	2919816	et	3	main
kõigil	doc_873901597566_item	2919823	et	4	main
meeldinud	doc_873901597566_item	2919825	et	4	main
lõpupidu	doc_873901597566_item	2919826	et	4	main
sooritasid	doc_873901597566_item	2919836	et	4	main
eksamide	doc_873901597566_item	2919838	et	4	main
olid	doc_873901597566_item	2919840	et	4	main
tähtsamad	doc_873901597566_item	2919841	et	4	main
sellepärast	doc_873901597566_item	2919842	et	3	main
et	doc_873901597566_item	2919843	et	3	main
ülikooli	doc_873901597566_item	2919850	et	4	main
küsimus	doc_873901597566_item	2919854	et	4	main
ma	doc_873901597566_item	2919859	et	3	main
teadnud	doc_873901597566_item	2919869	et	4	main
see	doc_873901597566_item	2919923	et	3	main
ma	doc_873901597566_item	2919939	et	3	main
see	doc_873901597566_item	2919952	et	3	main
ma	doc_873901597566_item	2919961	et	3	main
uuede	doc_873901597566_item	2919964	et	4	main
kõik	doc_873901597566_item	2919966	et	4	main
õppisin	doc_873901597566_item	2919978	et	3	main
tead	doc_873901597566_item	2919985	et	4	main
sõpru	doc_873901597566_item	2919991	et	3	main
mulle	doc_873901597566_item	2919996	et	4	main
praegu	doc_873901597566_item	2920025	et	3	main
tean	doc_873901597566_item	2920027	et	3	main
ülikoolist	doc_873901597566_item	2920029	et	4	main
kus	doc_873901597566_item	2920030	et	3	main
ma	doc_873901597566_item	2920031	et	3	main
see	doc_873901597566_item	2920033	et	3	main
on	doc_873901597566_item	2920034	et	4	main
ma	doc_873901597566_item	2920044	et	3	main
kogu	doc_873901597566_item	2920046	et	4	main
see	doc_873901597566_item	2920048	et	3	main
oli	doc_873901597566_item	2920049	et	3	main
töö	doc_873901597566_item	2920052	et	4	main
ja	doc_873901597566_item	2920053	et	3	main
väga	doc_873901597566_item	2920054	et	3	main
huvitav	doc_873901597566_item	2920055	et	4	main
ja	doc_873901597566_item	2920056	et	3	main
ma	doc_873901597566_item	2920057	et	3	main
oli	doc_873901597566_item	2920065	et	3	main
kogemus	doc_873901597566_item	2920069	et	3	main
merevaigu	doc_873901597566_item	2920072	et	3	main
palju	doc_873901597566_item	2920077	et	4	main
suhelda	doc_873901597566_item	2920079	et	4	main
elus	doc_873901597566_item	2920094	et	4	main
aasta	doc_873901597567_item	2920101	et	4	main
minu	doc_873901597567_item	2920114	et	3	main
raske	doc_873901597567_item	2920124	et	4	main
kahe	doc_873901597567_item	2920125	et	3	main
väga	doc_873901597567_item	2920130	et	3	main
näiteks	doc_873901597567_item	2920133	et	4	main
jalgpalli	doc_873901597567_item	2920134	et	4	main
oli	doc_873901597567_item	2920142	et	3	main
veel	doc_873901597567_item	2920154	et	4	main
sel	doc_873901597567_item	2920155	et	3	main
essee	doc_873901597565_item	2919665	et	4	main
aastal	doc_873901597565_item	2919674	et	3	main
palju	doc_873901597565_item	2919678	et	4	main
töötasin	doc_873901597565_item	2919692	et	3	main
suveniiri	doc_873901597565_item	2919693	et	4	main
kaupluses	doc_873901597565_item	2919694	et	3	main
praegu	doc_873901597565_item	2919695	et	3	main
ma	doc_873901597565_item	2919696	et	3	main
töötan	doc_873901597565_item	2919697	et	3	main
seal	doc_873901597565_item	2919698	et	4	main
ka	doc_873901597565_item	2919699	et	3	main
ma	doc_873901597565_item	2919700	et	3	main
töötan	doc_873901597565_item	2919701	et	3	main
müüjana	doc_873901597565_item	2919702	et	4	main
mulle	doc_873901597565_item	2919703	et	4	main
väga	doc_873901597565_item	2919704	et	3	main
meeldib	doc_873901597565_item	2919705	et	3	main
töötada	doc_873901597565_item	2919706	et	3	main
seal	doc_873901597565_item	2919707	et	4	main
selle	doc_873901597565_item	2919708	et	4	main
pärast	doc_873901597565_item	2919709	et	4	main
et	doc_873901597565_item	2919710	et	3	main
seal	doc_873901597565_item	2919711	et	4	main
on	doc_873901597565_item	2919712	et	4	main
väga	doc_873901597565_item	2919713	et	3	main
palju	doc_873901597565_item	2919714	et	4	main
inimesi	doc_873901597565_item	2919715	et	4	main
nad	doc_873901597565_item	2919716	et	3	main
rägivad	doc_873901597565_item	2919717	et	4	main
mitmes	doc_873901597565_item	2919718	et	4	main
keeles	doc_873901597565_item	2919719	et	4	main
mulle	doc_873901597565_item	2919720	et	4	main
väga	doc_873901597565_item	2919721	et	3	main
seal	doc_873901597565_item	2919725	et	4	main
palju	doc_873901597565_item	2919728	et	4	main
kes	doc_873901597565_item	2919730	et	4	main
londonisse	doc_873901597565_item	2919738	et	4	main
sõita	doc_873901597565_item	2919739	et	3	main
ja	doc_873901597565_item	2919740	et	3	main
praegu	doc_873901597565_item	2919741	et	3	main
keel	doc_873901597565_item	2919745	et	4	main
väga	doc_873901597565_item	2919750	et	3	main
hea	doc_873901597565_item	2919751	et	4	main
mille	doc_873901597565_item	2919666	et	3	main
poolest	doc_873901597565_item	2919667	et	4	main
jäi	doc_873901597565_item	2919668	et	3	main
äga	doc_873901597565_item	2919677	et	4	main
asju	doc_873901597565_item	2919680	et	3	main
ma	doc_873901597565_item	2919683	et	3	main
kool	doc_873901597565_item	2919685	et	4	main
ja	doc_873901597565_item	2919686	et	3	main
astusin	doc_873901597565_item	2919687	et	3	main
ttü-s	doc_873901597565_item	2919688	et	3	main
sellel	doc_873901597565_item	2919689	et	4	main
suvel	doc_873901597565_item	2919690	et	3	main
ma	doc_873901597565_item	2919691	et	3	main
meeldib	doc_873901597565_item	2919722	et	3	main
väga	doc_873901597565_item	2919727	et	3	main
inimesi	doc_873901597565_item	2919729	et	4	main
ma	doc_873901597565_item	2919736	et	3	main
inglise	doc_873901597565_item	2919744	et	4	main
veel	doc_873901597565_item	2919759	et	4	main
arvan	doc_873901597565_item	2919773	et	3	main
poolest	doc_873901597566_item	2919793	et	4	main
jäi	doc_873901597566_item	2919794	et	3	main
mulle	doc_873901597566_item	2919795	et	4	main
meelde	doc_873901597566_item	2919796	et	3	main
aasta	doc_873901597566_item	2919804	et	4	main
ja	doc_873901597566_item	2919805	et	3	main
väga	doc_873901597566_item	2919806	et	3	main
sellel	doc_873901597566_item	2919809	et	4	main
aastal	doc_873901597566_item	2919810	et	3	main
ma	doc_873901597566_item	2919811	et	3	main
kõik	doc_873901597566_item	2919819	et	4	main
olid	doc_873901597566_item	2919820	et	4	main
rägivad	doc_873901597565_item	2919731	et	4	main
inglise	doc_873901597565_item	2919732	et	4	main
õpin	doc_873901597565_item	2919743	et	3	main
sellel	doc_873901597565_item	2919746	et	4	main
aastal	doc_873901597565_item	2919747	et	3	main
suvel	doc_873901597565_item	2919748	et	3	main
oli	doc_873901597565_item	2919749	et	3	main
ilm	doc_873901597565_item	2919752	et	3	main
ja	doc_873901597565_item	2919753	et	3	main
ma	doc_873901597565_item	2919754	et	3	main
tihti	doc_873901597565_item	2919755	et	3	main
sõitsin	doc_873901597565_item	2919756	et	3	main
mere	doc_873901597565_item	2919757	et	3	main
jurde	doc_873901597565_item	2919758	et	4	main
ma	doc_873901597565_item	2919762	et	3	main
palju	doc_873901597565_item	2919764	et	4	main
et	doc_873901597565_item	2919786	et	3	main
2006	doc_873901597566_item	2919799	et	2	main
oli	doc_873901597566_item	2919800	et	3	main
hea	doc_873901597566_item	2919817	et	4	main
ja	doc_873901597566_item	2919822	et	3	main
kõige	doc_873901597566_item	2919827	et	4	main
period	doc_873901597566_item	2919829	et	4	main
oli	doc_873901597566_item	2919830	et	3	main
aga	doc_873901597566_item	2919835	et	3	main
tulemused	doc_873901597566_item	2919839	et	3	main
peame	doc_873901597566_item	2919845	et	4	main
ja	doc_873901597566_item	2919847	et	3	main
astuma	doc_873901597566_item	2919849	et	3	main
ja	doc_873901597566_item	2919851	et	3	main
õppima	doc_873901597566_item	2919856	et	3	main
minu	doc_873901597566_item	2919862	et	3	main
mis	doc_873901597566_item	2919870	et	4	main
meil	doc_873901597566_item	2919901	et	4	main
kolm	doc_873901597566_item	2919905	et	3	main
ma	doc_873901597566_item	2919908	et	3	main
tallinna	doc_873901597566_item	2919910	et	4	main
ülikooli	doc_873901597566_item	2919912	et	4	main
astuda	doc_873901597566_item	2919913	et	3	main
siis	doc_873901597566_item	2919914	et	3	main
ma	doc_873901597566_item	2919915	et	3	main
tulin	doc_873901597566_item	2919916	et	3	main
ja	doc_873901597566_item	2919917	et	3	main
andsin	doc_873901597566_item	2919918	et	3	main
dokumendid	doc_873901597566_item	2919919	et	3	main
ja	doc_873901597566_item	2919920	et	3	main
tulid	doc_873901597566_item	2919938	et	4	main
saanud	doc_873901597566_item	2919941	et	4	main
see	doc_873901597566_item	2919944	et	3	main
minu	doc_873901597566_item	2919954	et	3	main
esimene	doc_873901597566_item	2919955	et	3	main
mulle	doc_873901597566_item	2919957	et	4	main
gruppis	doc_873901597566_item	2919972	et	4	main
oli	doc_873901597566_item	2919973	et	3	main
minu	doc_873901597566_item	2919974	et	3	main
see	doc_873901597566_item	2919980	et	3	main
kui	doc_873901597566_item	2919983	et	3	main
kedagi	doc_873901597566_item	2919986	et	4	main
ülikoolis	doc_873901597566_item	2919987	et	4	main
ma	doc_873901597566_item	2919988	et	3	main
algas	doc_873901597566_item	2919995	et	3	main
minu	doc_873901597566_item	2920021	et	3	main
veel	doc_873901597566_item	2920024	et	4	main
ja	doc_873901597566_item	2920037	et	3	main
palju	doc_873901597566_item	2920040	et	4	main
aeg	doc_873901597566_item	2920047	et	3	main
minu	doc_873901597566_item	2920050	et	3	main
sõbrad	doc_873901597566_item	2920060	et	3	main
see	doc_873901597566_item	2920064	et	3	main
töötasin	doc_873901597566_item	2920071	et	3	main
sain	doc_873901597566_item	2920076	et	3	main
kasulik	doc_873901597566_item	2920083	et	3	main
tähtis	doc_873901597566_item	2920088	et	4	main
poolest	doc_873901597567_item	2920097	et	4	main
see	doc_873901597567_item	2920108	et	3	main
oli	doc_873901597567_item	2920109	et	3	main
sellel	doc_873901597565_item	2919760	et	4	main
palju	doc_873901597565_item	2919770	et	4	main
huvitav	doc_873901597565_item	2919782	et	4	main
aga	doc_873901597565_item	2919783	et	3	main
ma	doc_873901597565_item	2919784	et	3	main
loodan	doc_873901597565_item	2919785	et	3	main
tuleb	doc_873901597565_item	2919789	et	3	main
aasta	doc_873901597566_item	2919797	et	4	main
2006	doc_873901597566_item	2919798	et	2	main
ka	doc_873901597566_item	2919808	et	3	main
lõpetasin	doc_873901597566_item	2919812	et	3	main
kooli	doc_873901597566_item	2919813	et	4	main
lõbusad	doc_873901597566_item	2919821	et	3	main
on	doc_873901597566_item	2919824	et	4	main
need	doc_873901597566_item	2919837	et	3	main
siis	doc_873901597566_item	2919852	et	3	main
minna	doc_873901597566_item	2919857	et	3	main
saada	doc_873901597566_item	2919861	et	4	main
vastust	doc_873901597566_item	2919922	et	4	main
raske	doc_873901597566_item	2919925	et	4	main
tundma	doc_873901597566_item	2919930	et	3	main
et	doc_873901597566_item	2919931	et	3	main
väga	doc_873901597566_item	2919934	et	3	main
ttü-s	doc_873901597566_item	2919935	et	3	main
tulemused	doc_873901597566_item	2919937	et	3	main
aga	doc_873901597566_item	2919943	et	3	main
oli	doc_873901597566_item	2919945	et	3	main
õige	doc_873901597566_item	2919946	et	4	main
augusti	doc_873901597566_item	2919947	et	3	main
lõppus	doc_873901597566_item	2919948	et	4	main
ma	doc_873901597566_item	2919949	et	3	main
läksin	doc_873901597566_item	2919950	et	3	main
meeldis	doc_873901597566_item	2919958	et	3	main
ttü-s	doc_873901597566_item	2919960	et	3	main
sõbranna	doc_873901597566_item	2919975	et	4	main
ma	doc_873901597566_item	2919977	et	3	main
on	doc_873901597566_item	2919981	et	4	main
palju	doc_873901597566_item	2919990	et	4	main
uus	doc_873901597566_item	2919993	et	3	main
elu	doc_873901597566_item	2919994	et	4	main
aeg	doc_873901597566_item	2920023	et	3	main
ma	doc_873901597566_item	2920038	et	3	main
suvel	doc_873901597566_item	2920042	et	3	main
sain	doc_873901597566_item	2920058	et	3	main
töö	doc_873901597566_item	2920062	et	4	main
veel	doc_873901597566_item	2920067	et	4	main
üks	doc_873901597566_item	2920068	et	3	main
ja	doc_873901597566_item	2920074	et	3	main
oli	doc_873901597566_item	2920081	et	3	main
väga	doc_873901597566_item	2920082	et	3	main
aasta	doc_873901597566_item	2920085	et	4	main
aasta	doc_873901597566_item	2920089	et	4	main
ja	doc_873901597566_item	2920090	et	3	main
mille	doc_873901597567_item	2920096	et	3	main
mulle	doc_873901597567_item	2920099	et	4	main
huvitav	doc_873901597567_item	2920111	et	4	main
ja	doc_873901597567_item	2920112	et	3	main
maailma	doc_873901597567_item	2920135	et	4	main
võistlus	doc_873901597567_item	2920136	et	3	main
kus	doc_873901597567_item	2920137	et	3	main
meistriks	doc_873901597567_item	2920138	et	3	main
sai	doc_873901597567_item	2920139	et	4	main
milioni	doc_873901597567_item	2920152	et	4	main
inimestega	doc_873901597567_item	2920153	et	3	main
kool	doc_873901597567_item	2920159	et	4	main
kindel	doc_873901597567_item	2920165	et	3	main
väga	doc_873901597567_item	2920169	et	3	main
ma	doc_873901597567_item	2920172	et	3	main
et	doc_873901597567_item	2920179	et	3	main
inimesed	doc_873901597567_item	2920183	et	3	main
aastal	doc_873901597567_item	2920186	et	3	main
oma	doc_873901597567_item	2920189	et	4	main
aasta	doc_873901597567_item	2920208	et	4	main
oli	doc_873901597567_item	2920219	et	3	main
meelde	doc_873901597567_item	2920225	et	3	main
essee	doc_873901597568_item	2920227	et	4	main
mille	doc_873901597568_item	2920228	et	3	main
aasta	doc_873901597568_item	2920233	et	4	main
toimusid	doc_873901597568_item	2920237	et	4	main
asjad	doc_873901597568_item	2920239	et	3	main
sellepärast	doc_873901597568_item	2920245	et	3	main
suvel	doc_873901597568_item	2920248	et	3	main
kõik	doc_873901597566_item	2919833	et	4	main
kardasid	doc_873901597566_item	2919834	et	4	main
sooritama	doc_873901597566_item	2919846	et	3	main
kuhu	doc_873901597566_item	2919855	et	3	main
on	doc_873901597566_item	2919871	et	4	main
parem	doc_873901597566_item	2919872	et	4	main
ja	doc_873901597566_item	2919873	et	3	main
mida	doc_873901597566_item	2919874	et	4	main
mulle	doc_873901597566_item	2919875	et	4	main
meeldib	doc_873901597566_item	2919876	et	3	main
aga	doc_873901597566_item	2919877	et	3	main
pärast	doc_873901597566_item	2919878	et	4	main
eksameid	doc_873901597566_item	2919879	et	3	main
tuli	doc_873901597566_item	2919880	et	4	main
lõpupidu	doc_873901597566_item	2919881	et	4	main
mis	doc_873901597566_item	2919882	et	4	main
me	doc_873901597566_item	2919883	et	4	main
ootasime	doc_873901597566_item	2919884	et	3	main
palju	doc_873901597566_item	2919885	et	4	main
aega	doc_873901597566_item	2919886	et	4	main
kahjuks	doc_873901597566_item	2919887	et	4	main
pärast	doc_873901597566_item	2919888	et	4	main
pidu	doc_873901597566_item	2919889	et	4	main
me	doc_873901597566_item	2919890	et	4	main
peame	doc_873901597566_item	2919891	et	4	main
mõtlema	doc_873901597566_item	2919892	et	3	main
õppimisest	doc_873901597566_item	2919893	et	4	main
aga	doc_873901597566_item	2919894	et	3	main
oli	doc_873901597566_item	2919895	et	3	main
suvi	doc_873901597566_item	2919896	et	3	main
kõik	doc_873901597566_item	2919897	et	4	main
tahtsid	doc_873901597566_item	2919898	et	4	main
puhkuda	doc_873901597566_item	2919899	et	4	main
aga	doc_873901597566_item	2919900	et	3	main
aega	doc_873901597566_item	2919904	et	4	main
aastat	doc_873901597566_item	2919906	et	3	main
tahtsin	doc_873901597566_item	2919909	et	3	main
tehnika	doc_873901597566_item	2919911	et	4	main
ootasin	doc_873901597566_item	2919921	et	3	main
oli	doc_873901597566_item	2919924	et	3	main
sellepärast	doc_873901597566_item	2919926	et	3	main
alustasin	doc_873901597566_item	2919929	et	3	main
tahtsin	doc_873901597566_item	2919933	et	3	main
õppida	doc_873901597566_item	2919936	et	3	main
ei	doc_873901597566_item	2919940	et	4	main
uskuda	doc_873901597566_item	2919942	et	3	main
oli	doc_873901597566_item	2919953	et	3	main
tuttavaks	doc_873901597566_item	2919963	et	4	main
kaaslastega	doc_873901597566_item	2919965	et	4	main
on	doc_873901597566_item	2919967	et	4	main
targad	doc_873901597566_item	2919968	et	3	main
ja	doc_873901597566_item	2919969	et	3	main
ilusad	doc_873901597566_item	2919970	et	3	main
inimesed	doc_873901597566_item	2919971	et	3	main
koolis	doc_873901597566_item	2919979	et	4	main
hea	doc_873901597566_item	2919982	et	4	main
siis	doc_873901597566_item	2919992	et	3	main
meeldis	doc_873901597566_item	2919997	et	3	main
see	doc_873901597566_item	2919998	et	3	main
elu	doc_873901597566_item	2919999	et	4	main
aga	doc_873901597566_item	2920000	et	3	main
ma	doc_873901597566_item	2920001	et	3	main
jäin	doc_873901597566_item	2920002	et	3	main
väga	doc_873901597566_item	2920003	et	3	main
meelde	doc_873901597566_item	2920004	et	3	main
suvi	doc_873901597566_item	2920005	et	3	main
2006	doc_873901597566_item	2920006	et	2	main
sellepärast	doc_873901597566_item	2920007	et	3	main
et	doc_873901597566_item	2920008	et	3	main
see	doc_873901597566_item	2920009	et	3	main
ei	doc_873901597566_item	2920010	et	4	main
olnud	doc_873901597566_item	2920011	et	4	main
rahulikult	doc_873901597566_item	2920012	et	4	main
mõnikord	doc_873901597566_item	2920013	et	3	main
ma	doc_873901597566_item	2920014	et	3	main
mõtlesin	doc_873901597566_item	2920015	et	3	main
koolist	doc_873901597566_item	2920016	et	4	main
seest	doc_873901597566_item	2920017	et	3	main
et	doc_873901597566_item	2920018	et	3	main
see	doc_873901597566_item	2920019	et	3	main
oli	doc_873901597566_item	2920020	et	3	main
lemmik	doc_873901597566_item	2920022	et	3	main
kõik	doc_873901597566_item	2920035	et	4	main
uus	doc_873901597566_item	2920036	et	3	main
sain	doc_873901597566_item	2920039	et	3	main
2006-l	doc_873901597566_item	2920043	et	3	main
uued	doc_873901597566_item	2920059	et	3	main
kaupluses	doc_873901597566_item	2920073	et	3	main
keeltes	doc_873901597566_item	2920078	et	3	main
see	doc_873901597566_item	2920080	et	3	main
2006	doc_873901597566_item	2920084	et	2	main
oli	doc_873901597566_item	2920086	et	3	main
väga	doc_873901597566_item	2920087	et	3	main
essee	doc_873901597567_item	2920095	et	4	main
jäi	doc_873901597567_item	2920098	et	3	main
meelde	doc_873901597567_item	2920100	et	3	main
2006	doc_873901597567_item	2920102	et	2	main
mulle	doc_873901597567_item	2920103	et	4	main
jäi	doc_873901597567_item	2920104	et	3	main
meelde	doc_873901597567_item	2920105	et	3	main
arengu	doc_873901597567_item	2920115	et	3	main
aasta	doc_873901597567_item	2920117	et	4	main
vaatamata	doc_873901597567_item	2920118	et	4	main
sellele	doc_873901597567_item	2920119	et	4	main
et	doc_873901597567_item	2920120	et	3	main
aasta	doc_873901597567_item	2920121	et	4	main
oli	doc_873901597567_item	2920123	et	3	main
väga	doc_873901597567_item	2920143	et	3	main
ma	doc_873901597567_item	2920148	et	3	main
lõpetasin	doc_873901597567_item	2920158	et	3	main
see	doc_873901597567_item	2920167	et	3	main
uue	doc_873901597567_item	2920174	et	3	main
ma	doc_873901597567_item	2920177	et	3	main
suvel	doc_873901597567_item	2920184	et	3	main
ma	doc_873901597567_item	2920187	et	3	main
armastab	doc_873901597567_item	2920201	et	3	main
armastan	doc_873901597567_item	2920205	et	3	main
mina	doc_873901597567_item	2920206	et	4	main
kogu	doc_873901597567_item	2920207	et	4	main
ja	doc_873901597567_item	2920213	et	3	main
mulle	doc_873901597567_item	2920215	et	4	main
informatsiooni	doc_873901597566_item	2920041	et	4	main
töötasin	doc_873901597566_item	2920045	et	3	main
esimene	doc_873901597566_item	2920051	et	3	main
ja	doc_873901597566_item	2920061	et	3	main
klienditega	doc_873901597566_item	2920063	et	4	main
nagu	doc_873901597566_item	2920066	et	3	main
ma	doc_873901597566_item	2920070	et	3	main
ma	doc_873901597566_item	2920075	et	3	main
midagi	doc_873901597566_item	2920091	et	4	main
uus	doc_873901597566_item	2920092	et	3	main
minu	doc_873901597566_item	2920093	et	3	main
aasta	doc_873901597567_item	2920106	et	4	main
2006	doc_873901597567_item	2920107	et	2	main
väga	doc_873901597567_item	2920110	et	3	main
kasulik	doc_873901597567_item	2920113	et	3	main
jaoks	doc_873901597567_item	2920116	et	4	main
palju	doc_873901597567_item	2920131	et	4	main
see	doc_873901597567_item	2920141	et	3	main
aeg	doc_873901597567_item	2920145	et	3	main
kus	doc_873901597567_item	2920147	et	3	main
ja	doc_873901597567_item	2920160	et	3	main
ma	doc_873901597567_item	2920163	et	3	main
et	doc_873901597567_item	2920166	et	3	main
inimesega	doc_873901597567_item	2920175	et	3	main
nad	doc_873901597567_item	2920180	et	3	main
toredat	doc_873901597567_item	2920182	et	3	main
2006	doc_873901597567_item	2920185	et	2	main
kes	doc_873901597567_item	2920200	et	4	main
õpetasin	doc_873901597567_item	2920211	et	3	main
mulle	doc_873901597568_item	2920231	et	4	main
2006-ndal	doc_873901597568_item	2920235	et	4	main
palju	doc_873901597568_item	2920238	et	4	main
aasta	doc_873901597568_item	2920240	et	4	main
2006	doc_873901597568_item	2920241	et	2	main
jäi	doc_873901597568_item	2920242	et	3	main
et	doc_873901597568_item	2920246	et	3	main
oli	doc_873901597568_item	2920255	et	3	main
huvitav	doc_873901597568_item	2920257	et	4	main
sõpradega	doc_873901597568_item	2920281	et	3	main
ja	doc_873901597568_item	2920282	et	3	main
uurisin	doc_873901597568_item	2920283	et	3	main
palju	doc_873901597568_item	2920284	et	4	main
seal	doc_873901597568_item	2920295	et	4	main
kaks	doc_873901597568_item	2920296	et	3	main
nädalat	doc_873901597568_item	2920297	et	3	main
on	doc_873901597568_item	2920304	et	4	main
seal	doc_873901597568_item	2920305	et	4	main
huvitavad	doc_873901597568_item	2920306	et	4	main
kaks	doc_873901597568_item	2920308	et	3	main
mis	doc_873901597568_item	2920317	et	4	main
jäi	doc_873901597568_item	2920318	et	3	main
aastal	doc_873901597568_item	2920321	et	3	main
george	doc_873901597568_item	2920327	et	4	main
tuli	doc_873901597568_item	2920330	et	4	main
suletud	doc_873901597568_item	2920337	et	4	main
ja	doc_873901597568_item	2920338	et	3	main
autoga	doc_873901597568_item	2920339	et	3	main
ei	doc_873901597568_item	2920340	et	4	main
see	doc_873901597568_item	2920345	et	3	main
poolest	doc_873901597569_item	2920386	et	4	main
jäi	doc_873901597569_item	2920387	et	3	main
mulle	doc_873901597569_item	2920388	et	4	main
meelde	doc_873901597569_item	2920389	et	3	main
me	doc_873901597569_item	2920395	et	4	main
vaatame	doc_873901597569_item	2920396	et	3	main
mis	doc_873901597569_item	2920399	et	4	main
neil	doc_873901597569_item	2920408	et	4	main
oli	doc_873901597569_item	2920409	et	3	main
kõik	doc_873901597569_item	2920410	et	4	main
olla	doc_873901597569_item	2920416	et	3	main
jaoks	doc_873901597569_item	2920420	et	4	main
olnud	doc_873901597569_item	2920424	et	4	main
ja	doc_873901597569_item	2920427	et	3	main
sel	doc_873901597569_item	2920429	et	3	main
satusin	doc_873901597569_item	2920432	et	4	main
haiglase	doc_873901597569_item	2920433	et	4	main
mul	doc_873901597569_item	2920434	et	3	main
oli	doc_873901597569_item	2920435	et	3	main
kodus	doc_873901597569_item	2920443	et	4	main
istuma	doc_873901597569_item	2920444	et	3	main
kuid	doc_873901597569_item	2920445	et	4	main
ma	doc_873901597569_item	2920446	et	3	main
olen	doc_873901597569_item	2920447	et	3	main
algus	doc_873901597567_item	2920122	et	4	main
tuhande	doc_873901597567_item	2920126	et	3	main
kuuendal	doc_873901597567_item	2920127	et	3	main
aastal	doc_873901597567_item	2920128	et	3	main
oli	doc_873901597567_item	2920129	et	3	main
üritusi	doc_873901597567_item	2920132	et	4	main
italia	doc_873901597567_item	2920140	et	4	main
huvitav	doc_873901597567_item	2920144	et	4	main
saksamaal	doc_873901597567_item	2920146	et	4	main
puhkasin	doc_873901597567_item	2920149	et	3	main
koos	doc_873901597567_item	2920150	et	4	main
mitu	doc_873901597567_item	2920151	et	4	main
on	doc_873901597567_item	2920168	et	4	main
tähtis	doc_873901597567_item	2920170	et	4	main
tutvusin	doc_873901597567_item	2920173	et	3	main
arvan	doc_873901597567_item	2920178	et	3	main
on	doc_873901597567_item	2920198	et	4	main
inimene	doc_873901597567_item	2920199	et	3	main
ja	doc_873901597567_item	2920203	et	3	main
ma	doc_873901597567_item	2920210	et	3	main
et	doc_873901597567_item	2920217	et	3	main
see	doc_873901597567_item	2920218	et	3	main
meelde	doc_873901597568_item	2920232	et	3	main
aastal	doc_873901597568_item	2920236	et	3	main
meelde	doc_873901597568_item	2920244	et	3	main
ja	doc_873901597568_item	2920258	et	3	main
uuega	doc_873901597568_item	2920280	et	3	main
uut	doc_873901597568_item	2920285	et	3	main
huvitavat	doc_873901597568_item	2920286	et	4	main
asju	doc_873901597568_item	2920287	et	3	main
veebruaris	doc_873901597568_item	2920288	et	3	main
lendasin	doc_873901597568_item	2920289	et	3	main
itaalias	doc_873901597568_item	2920298	et	4	main
sest	doc_873901597568_item	2920302	et	4	main
inimesed	doc_873901597568_item	2920303	et	3	main
asi	doc_873901597568_item	2920316	et	4	main
eestisse	doc_873901597568_item	2920326	et	4	main
linnas	doc_873901597568_item	2920343	et	4	main
mulle	doc_873901597568_item	2920347	et	4	main
ma	doc_873901597568_item	2920349	et	3	main
aasta	doc_873901597569_item	2920390	et	4	main
üle	doc_873901597569_item	2920397	et	3	main
arvavad	doc_873901597569_item	2920406	et	4	main
et	doc_873901597569_item	2920407	et	3	main
arvavad	doc_873901597569_item	2920413	et	4	main
et	doc_873901597569_item	2920414	et	3	main
võiks	doc_873901597569_item	2920415	et	4	main
aasta	doc_873901597569_item	2920421	et	4	main
oparatsioon	doc_873901597569_item	2920436	et	4	main
peale	doc_873901597569_item	2920437	et	4	main
et	doc_873901597569_item	2920449	et	3	main
olukorras	doc_873901597569_item	2920452	et	3	main
saksakeelt	doc_873901597569_item	2920461	et	4	main
sain	doc_873901597569_item	2920462	et	3	main
lugeda	doc_873901597569_item	2920463	et	3	main
läbi	doc_873901597569_item	2920464	et	4	main
täpselt	doc_873901597569_item	2920510	et	4	main
lapsepõlves	doc_873901597569_item	2920516	et	4	main
palju	doc_873901597569_item	2920521	et	4	main
see	doc_873901597569_item	2920523	et	3	main
aastal	doc_873901597567_item	2920156	et	3	main
ma	doc_873901597567_item	2920157	et	3	main
astusin	doc_873901597567_item	2920161	et	3	main
ülikooli	doc_873901597567_item	2920162	et	4	main
olen	doc_873901597567_item	2920164	et	3	main
ülikoolis	doc_873901597567_item	2920171	et	4	main
ja	doc_873901597567_item	2920176	et	3	main
on	doc_873901597567_item	2920181	et	4	main
leidan	doc_873901597567_item	2920188	et	4	main
armastuse	doc_873901597567_item	2920190	et	4	main
ma	doc_873901597567_item	2920191	et	3	main
olen	doc_873901597567_item	2920192	et	3	main
väga	doc_873901597567_item	2920193	et	3	main
õnnelik	doc_873901597567_item	2920194	et	3	main
et	doc_873901597567_item	2920195	et	3	main
minu	doc_873901597567_item	2920196	et	3	main
elus	doc_873901597567_item	2920197	et	4	main
mind	doc_873901597567_item	2920202	et	4	main
keda	doc_873901597567_item	2920204	et	4	main
jooksul	doc_873901597567_item	2920209	et	4	main
töötasin	doc_873901597567_item	2920212	et	3	main
arendasin	doc_873901597567_item	2920214	et	3	main
tundub	doc_873901597567_item	2920216	et	3	main
positiivne	doc_873901597567_item	2920220	et	3	main
ja	doc_873901597567_item	2920222	et	3	main
ma	doc_873901597567_item	2920223	et	3	main
ta	doc_873901597567_item	2920226	et	4	main
poolest	doc_873901597568_item	2920229	et	4	main
jäi	doc_873901597568_item	2920230	et	3	main
2006	doc_873901597568_item	2920234	et	2	main
mulle	doc_873901597568_item	2920243	et	4	main
sellel	doc_873901597568_item	2920247	et	4	main
oli	doc_873901597568_item	2920249	et	3	main
maailma	doc_873901597568_item	2920250	et	4	main
põnev	doc_873901597568_item	2920259	et	3	main
oma	doc_873901597568_item	2920290	et	4	main
meeldis	doc_873901597568_item	2920299	et	3	main
need	doc_873901597568_item	2920307	et	3	main
nädalad	doc_873901597568_item	2920309	et	3	main
mulle	doc_873901597568_item	2920319	et	4	main
aasta	doc_873901597567_item	2920221	et	4	main
jäi	doc_873901597567_item	2920224	et	3	main
see	doc_873901597568_item	2920254	et	3	main
meeldib	doc_873901597568_item	2920261	et	3	main
jalgpall	doc_873901597568_item	2920262	et	3	main
väga	doc_873901597568_item	2920263	et	3	main
aasta	doc_873901597568_item	2920264	et	4	main
algus	doc_873901597568_item	2920265	et	4	main
oli	doc_873901597568_item	2920266	et	3	main
raske	doc_873901597568_item	2920267	et	4	main
vaatamata	doc_873901597568_item	2920268	et	4	main
sellele	doc_873901597568_item	2920269	et	4	main
oli	doc_873901597568_item	2920270	et	3	main
see	doc_873901597568_item	2920271	et	3	main
aasta	doc_873901597568_item	2920272	et	4	main
huvitav	doc_873901597568_item	2920273	et	4	main
kodus	doc_873901597568_item	2920274	et	4	main
polnud	doc_873901597568_item	2920275	et	3	main
palju	doc_873901597568_item	2920276	et	4	main
probleeme	doc_873901597568_item	2920277	et	3	main
tutvusin	doc_873901597568_item	2920278	et	3	main
palju	doc_873901597568_item	2920279	et	4	main
jalgpalli	doc_873901597568_item	2920251	et	4	main
turniir	doc_873901597568_item	2920252	et	3	main
saksamaal	doc_873901597568_item	2920253	et	4	main
väga	doc_873901597568_item	2920256	et	3	main
mulle	doc_873901597568_item	2920260	et	4	main
itaaliasse	doc_873901597568_item	2920292	et	4	main
suusatamas	doc_873901597568_item	2920293	et	3	main
veetsime	doc_873901597568_item	2920294	et	3	main
mulle	doc_873901597568_item	2920300	et	4	main
väga	doc_873901597568_item	2920301	et	3	main
jäid	doc_873901597568_item	2920310	et	4	main
mulle	doc_873901597568_item	2920311	et	4	main
meelde	doc_873901597568_item	2920312	et	3	main
meelde	doc_873901597568_item	2920320	et	3	main
on	doc_873901597568_item	2920323	et	4	main
kõik	doc_873901597568_item	2920334	et	4	main
teed	doc_873901597568_item	2920335	et	4	main
olid	doc_873901597568_item	2920336	et	4	main
jäi	doc_873901597568_item	2920346	et	3	main
meelde	doc_873901597568_item	2920348	et	3	main
aastal	doc_873901597568_item	2920362	et	3	main
arendan	doc_873901597568_item	2920382	et	3	main
kõik	doc_873901597569_item	2920398	et	4	main
meiega	doc_873901597569_item	2920400	et	4	main
juhtus	doc_873901597569_item	2920401	et	3	main
selle	doc_873901597569_item	2920402	et	4	main
parem	doc_873901597569_item	2920418	et	4	main
2006	doc_873901597569_item	2920422	et	2	main
kindel	doc_873901597569_item	2920448	et	3	main
head	doc_873901597569_item	2920456	et	4	main
mina	doc_873901597569_item	2920457	et	4	main
näiteks	doc_873901597569_item	2920458	et	4	main
hakkasin	doc_873901597569_item	2920459	et	3	main
ravimis	doc_873901597569_item	2920467	et	4	main
kursus	doc_873901597569_item	2920468	et	3	main
sisaldas	doc_873901597569_item	2920469	et	3	main
ka	doc_873901597569_item	2920470	et	3	main
ujumis	doc_873901597569_item	2920471	et	3	main
inimese	doc_873901597569_item	2920498	et	4	main
mida	doc_873901597569_item	2920511	et	4	main
halba	doc_873901597569_item	2920517	et	4	main
juhtub	doc_873901597569_item	2920518	et	3	main
vanematega	doc_873901597568_item	2920291	et	4	main
sellel	doc_873901597568_item	2920313	et	4	main
aastal	doc_873901597568_item	2920314	et	3	main
kolmas	doc_873901597568_item	2920315	et	3	main
usa-presidenti	doc_873901597568_item	2920324	et	4	main
w	doc_873901597568_item	2920328	et	4	main
bush	doc_873901597568_item	2920329	et	4	main
eestisse	doc_873901597568_item	2920331	et	4	main
kaheks	doc_873901597568_item	2920332	et	4	main
päevaks	doc_873901597568_item	2920333	et	3	main
sõita	doc_873901597568_item	2920344	et	3	main
arvan	doc_873901597568_item	2920350	et	3	main
et	doc_873901597568_item	2920351	et	3	main
sellel	doc_873901597568_item	2920352	et	4	main
aastal	doc_873901597568_item	2920353	et	3	main
polnud	doc_873901597568_item	2920354	et	3	main
palju	doc_873901597568_item	2920355	et	4	main
asju	doc_873901597568_item	2920356	et	3	main
juhtunud	doc_873901597568_item	2920357	et	4	main
ma	doc_873901597568_item	2920358	et	3	main
arvan	doc_873901597568_item	2920359	et	3	main
et	doc_873901597568_item	2920360	et	3	main
2006	doc_873901597569_item	2920391	et	2	main
iga	doc_873901597569_item	2920392	et	4	main
aasta	doc_873901597569_item	2920403	et	4	main
suurepärane	doc_873901597569_item	2920411	et	4	main
ka	doc_873901597569_item	2920417	et	3	main
minu	doc_873901597569_item	2920419	et	3	main
2006	doc_873901597568_item	2920322	et	2	main
visiit	doc_873901597568_item	2920325	et	3	main
saanud	doc_873901597568_item	2920341	et	4	main
ma	doc_873901597568_item	2920342	et	3	main
järgmise	doc_873901597568_item	2920361	et	3	main
toimuvad	doc_873901597568_item	2920363	et	4	main
rohkem	doc_873901597568_item	2920364	et	4	main
üritusi	doc_873901597568_item	2920365	et	4	main
minu	doc_873901597568_item	2920366	et	3	main
elus	doc_873901597568_item	2920367	et	4	main
loodan	doc_873901597568_item	2920368	et	3	main
et	doc_873901597568_item	2920369	et	3	main
juhtuvad	doc_873901597568_item	2920370	et	4	main
ainult	doc_873901597568_item	2920371	et	4	main
head	doc_873901597568_item	2920372	et	4	main
üritused	doc_873901597568_item	2920373	et	4	main
loodan	doc_873901597568_item	2920374	et	3	main
et	doc_873901597568_item	2920375	et	3	main
aastal	doc_873901597568_item	2920376	et	3	main
2007	doc_873901597568_item	2920377	et	2	main
leian	doc_873901597568_item	2920378	et	3	main
head	doc_873901597568_item	2920379	et	4	main
tööd	doc_873901597568_item	2920380	et	4	main
ja	doc_873901597568_item	2920381	et	3	main
positiivselt	doc_873901597568_item	2920383	et	4	main
essee	doc_873901597569_item	2920384	et	4	main
mille	doc_873901597569_item	2920385	et	3	main
aasta	doc_873901597569_item	2920393	et	4	main
lõpus	doc_873901597569_item	2920394	et	4	main
jooksul	doc_873901597569_item	2920404	et	4	main
mõned	doc_873901597569_item	2920405	et	3	main
teised	doc_873901597569_item	2920412	et	4	main
kõige	doc_873901597569_item	2920425	et	4	main
aastal	doc_873901597569_item	2920430	et	3	main
isegi	doc_873901597569_item	2920450	et	4	main
midagi	doc_873901597569_item	2920455	et	4	main
nüüd	doc_873901597569_item	2920473	et	4	main
ma	doc_873901597569_item	2920474	et	3	main
ainult	doc_873901597569_item	2920501	et	4	main
mälestused	doc_873901597569_item	2920503	et	4	main
ma	doc_873901597569_item	2920504	et	3	main
usun	doc_873901597569_item	2920505	et	3	main
seda	doc_873901597569_item	2920506	et	3	main
sest	doc_873901597569_item	2920507	et	4	main
ma	doc_873901597569_item	2920508	et	3	main
mäletan	doc_873901597569_item	2920509	et	3	main
minuga	doc_873901597569_item	2920514	et	3	main
juhtunud	doc_873901597569_item	2920515	et	4	main
päris	doc_873901597569_item	2920520	et	4	main
ei	doc_873901597569_item	2920423	et	4	main
parem	doc_873901597569_item	2920426	et	4	main
edukam	doc_873901597569_item	2920428	et	4	main
ma	doc_873901597569_item	2920431	et	3	main
seda	doc_873901597569_item	2920438	et	3	main
ma	doc_873901597569_item	2920439	et	3	main
pidin	doc_873901597569_item	2920440	et	3	main
pool	doc_873901597569_item	2920441	et	4	main
aastat	doc_873901597569_item	2920442	et	3	main
selles	doc_873901597569_item	2920451	et	4	main
võib	doc_873901597569_item	2920453	et	3	main
õpima	doc_873901597569_item	2920460	et	4	main
treeninguid	doc_873901597569_item	2920472	et	4	main
käin	doc_873901597569_item	2920475	et	3	main
ujulas	doc_873901597569_item	2920476	et	3	main
kolm	doc_873901597569_item	2920477	et	3	main
korda	doc_873901597569_item	2920478	et	4	main
nädalas	doc_873901597569_item	2920479	et	3	main
nii	doc_873901597569_item	2920480	et	3	main
et	doc_873901597569_item	2920481	et	3	main
võib	doc_873901597569_item	2920482	et	3	main
öelda	doc_873901597569_item	2920483	et	4	main
et	doc_873901597569_item	2920484	et	3	main
see	doc_873901597569_item	2920485	et	3	main
tõi	doc_873901597569_item	2920487	et	3	main
aasta	doc_873901597569_item	2920486	et	4	main
mulle	doc_873901597569_item	2920488	et	4	main
võrdselt	doc_873901597569_item	2920489	et	4	main
head	doc_873901597569_item	2920490	et	4	main
ja	doc_873901597569_item	2920491	et	3	main
halva	doc_873901597569_item	2920492	et	4	main
räägitakse	doc_873901597569_item	2920493	et	3	main
et	doc_873901597569_item	2920494	et	3	main
mõned	doc_873901597569_item	2920495	et	3	main
aastad	doc_873901597569_item	2920496	et	3	main
hiljem	doc_873901597569_item	2920497	et	3	main
leida	doc_873901597569_item	2920454	et	3	main
palju	doc_873901597569_item	2920465	et	4	main
raamatuid	doc_873901597569_item	2920466	et	3	main
mälus	doc_873901597569_item	2920499	et	4	main
head	doc_873901597569_item	2920502	et	4	main
on	doc_873901597569_item	2920513	et	4	main
jäävad	doc_873901597569_item	2920500	et	4	main
head	doc_873901597569_item	2920512	et	4	main
meiega	doc_873901597569_item	2920519	et	4	main
ja	doc_873901597569_item	2920522	et	3	main
ei	doc_873901597569_item	2920524	et	4	main
ole	doc_873901597569_item	2920525	et	4	main
väärt	doc_873901597569_item	2920526	et	4	main
seda	doc_873901597569_item	2920527	et	3	main
meelde	doc_873901597569_item	2920528	et	3	main
jätma	doc_873901597569_item	2920529	et	3	main
tänapäeva	doc_881412446069_item	2921162	et	4	main
maailmas	doc_881412446069_item	2921163	et	3	main
väga	doc_881412446069_item	2921164	et	3	main
ning	doc_881412446069_item	2921169	et	3	main
probleemidest	doc_881412446069_item	2921170	et	3	main
on	doc_881412446069_item	2921172	et	4	main
eluviisiga	doc_881412446069_item	2921177	et	4	main
tean	doc_881412446069_item	2921178	et	3	main
ikkagi	doc_881412446069_item	2921179	et	4	main
et	doc_881412446069_item	2921180	et	3	main
need	doc_881412446069_item	2921181	et	3	main
probleemid	doc_881412446069_item	2921182	et	3	main
palju	doc_881412446069_item	2921165	et	4	main
räägitakse	doc_881412446069_item	2921166	et	3	main
ökoloogiast	doc_881412446069_item	2921167	et	3	main
meie	doc_881412446069_item	2921176	et	4	main
raiska	doc_881412446069_item	2921190	et	4	main
oluline	doc_881412446069_item	2921240	et	4	main
inimesed	doc_881412446069_item	2921243	et	3	main
ajalehes	doc_881412446069_item	2921248	et	3	main
mina	doc_881412446069_item	2921251	et	4	main
minul	doc_881412446069_item	2921266	et	3	main
arusaamatultvastu	doc_881412446069_item	2921267	et	4	main
ehkki	doc_881412446069_item	2921274	et	3	main
originaalsed	doc_881412446069_item	2921276	et	3	main
kasu	doc_881412446069_item	2921278	et	4	main
tavaline	doc_881412446069_item	2921285	et	4	main
aga	doc_881412446069_item	2921288	et	3	main
aastal	doc_881412446069_item	2921302	et	3	main
näiteks	doc_881412446069_item	2921316	et	4	main
ümbrikud	doc_881412446069_item	2921321	et	4	main
mitu	doc_881412446069_item	2921323	et	4	main
pean	doc_881412446069_item	2921327	et	4	main
kauplusest	doc_881412446069_item	2921329	et	4	main
õlut	doc_881412446069_item	2921330	et	3	main
mille	doc_881412446069_item	2921331	et	3	main
maitse	doc_881412446069_item	2921332	et	4	main
minule	doc_881412446069_item	2921333	et	3	main
üldse	doc_881412446069_item	2921334	et	3	main
parem	doc_881412446069_item	2921340	et	4	main
selle	doc_881412446069_item	2921344	et	4	main
kaupluses	doc_881412446069_item	2921350	et	3	main
mõtle	doc_881412446069_item	2921353	et	4	main
sellest	doc_881412446069_item	2921354	et	4	main
missugust	doc_881412446069_item	2921355	et	3	main
vihikut	doc_881412446069_item	2921356	et	3	main
itaaliast	doc_881412446069_item	2921386	et	4	main
miks	doc_881412446069_item	2921394	et	4	main
kui	doc_881412446069_item	2921398	et	3	main
inimesed	doc_881412446069_item	2921419	et	3	main
selle	doc_881412446069_item	2921424	et	4	main
need	doc_881412446069_item	2921429	et	3	main
nii	doc_881412446069_item	2921437	et	3	main
hullud	doc_881412446069_item	2921438	et	4	main
midagi	doc_881412446069_item	2921441	et	4	main
öko	doc_881412446069_item	2921160	et	4	main
loodusega	doc_881412446069_item	2921174	et	4	main
ning	doc_881412446069_item	2921175	et	3	main
on	doc_881412446069_item	2921183	et	4	main
mina	doc_881412446069_item	2921191	et	4	main
otsa	doc_881412446069_item	2921236	et	4	main
et	doc_881412446069_item	2921237	et	3	main
keskkond	doc_881412446069_item	2921238	et	3	main
niimodi	doc_881412446069_item	2921246	et	4	main
postimees	doc_881412446069_item	2921249	et	4	main
ideed	doc_881412446069_item	2921270	et	4	main
mitte	doc_881412446069_item	2921275	et	3	main
mina	doc_881412446069_item	2921282	et	4	main
elan	doc_881412446069_item	2921283	et	3	main
nagu	doc_881412446069_item	2921284	et	3	main
noor	doc_881412446069_item	2921286	et	3	main
meie	doc_881412446069_item	2921290	et	4	main
ei	doc_881412446069_item	2921293	et	4	main
aru	doc_881412446069_item	2921312	et	4	main
kuidas	doc_881412446069_item	2921313	et	3	main
elada	doc_881412446069_item	2921314	et	3	main
teisiti	doc_881412446069_item	2921315	et	3	main
meeldi	doc_881412446069_item	2921336	et	4	main
sellega	doc_881412446069_item	2921342	et	3	main
on	doc_881412446069_item	2921346	et	4	main
vaja	doc_881412446069_item	2921347	et	4	main
ostan	doc_881412446069_item	2921357	et	3	main
minule	doc_881412446069_item	2921362	et	3	main
parem	doc_881412446069_item	2921397	et	4	main
vaid	doc_881412446069_item	2921401	et	3	main
öeldes	doc_881412446069_item	2921408	et	3	main
rohkeem	doc_881412446069_item	2921411	et	4	main
meetodid	doc_881412446069_item	2921412	et	3	main
mis	doc_881412446069_item	2921413	et	4	main
prakteeritakse	doc_881412446069_item	2921414	et	4	main
euroopas	doc_881412446069_item	2921415	et	3	main
ning	doc_881412446069_item	2921416	et	3	main
teavad	doc_881412446069_item	2921420	et	3	main
ja	doc_881412446069_item	2921422	et	3	main
ei	doc_881412446069_item	2921435	et	4	main
essee	doc_881412446069_item	2921158	et	4	main
minu	doc_881412446069_item	2921159	et	3	main
väga	doc_881412446069_item	2921184	et	3	main
aga	doc_881412446069_item	2921186	et	3	main
sellele	doc_881412446069_item	2921188	et	4	main
ei	doc_881412446069_item	2921189	et	4	main
on	doc_881412446069_item	2921221	et	4	main
kõigil	doc_881412446069_item	2921223	et	4	main
säästa	doc_881412446069_item	2921232	et	4	main
et	doc_881412446069_item	2921233	et	3	main
on	doc_881412446069_item	2921239	et	4	main
elada	doc_881412446069_item	2921247	et	3	main
tunnistama	doc_881412446069_item	2921269	et	3	main
on	doc_881412446069_item	2921271	et	4	main
ju	doc_881412446069_item	2921272	et	3	main
toredad	doc_881412446069_item	2921273	et	3	main
ja	doc_881412446069_item	2921277	et	3	main
nendes	doc_881412446069_item	2921279	et	4	main
on	doc_881412446069_item	2921280	et	4	main
vähe	doc_881412446069_item	2921281	et	3	main
aja	doc_881412446069_item	2921291	et	4	main
noored	doc_881412446069_item	2921292	et	3	main
mõtle	doc_881412446069_item	2921294	et	4	main
sellest	doc_881412446069_item	2921295	et	4	main
me	doc_881412446069_item	2921303	et	4	main
elame	doc_881412446069_item	2921304	et	3	main
ühe	doc_881412446069_item	2921305	et	4	main
päevaga	doc_881412446069_item	2921306	et	3	main
tõsiselt	doc_881412446069_item	2921309	et	4	main
pean	doc_881412446069_item	2921319	et	4	main
kasutada	doc_881412446069_item	2921320	et	3	main
elu	doc_881412446069_item	2921161	et	4	main
keskkonnakaitsest	doc_881412446069_item	2921168	et	4	main
mis	doc_881412446069_item	2921171	et	4	main
seotud	doc_881412446069_item	2921173	et	4	main
olulised	doc_881412446069_item	2921185	et	4	main
ise	doc_881412446069_item	2921187	et	4	main
palju	doc_881412446069_item	2921192	et	4	main
oma	doc_881412446069_item	2921193	et	4	main
tänapäeva	doc_881412446069_item	2921195	et	4	main
aega	doc_881412446069_item	2921194	et	4	main
inimene	doc_881412446069_item	2921196	et	3	main
säästab	doc_881412446069_item	2921197	et	3	main
iga	doc_881412446069_item	2921198	et	4	main
päev	doc_881412446069_item	2921199	et	3	main
peamiselt	doc_881412446069_item	2921200	et	4	main
säästetakse	doc_881412446069_item	2921201	et	3	main
aega	doc_881412446069_item	2921202	et	4	main
kui	doc_881412446069_item	2921203	et	3	main
õnnestub	doc_881412446069_item	2921204	et	3	main
siis	doc_881412446069_item	2921205	et	3	main
raha	doc_881412446069_item	2921206	et	4	main
igal	doc_881412446069_item	2921207	et	3	main
sammul	doc_881412446069_item	2921208	et	4	main
ja	doc_881412446069_item	2921209	et	3	main
pidevalt	doc_881412446069_item	2921210	et	4	main
säästev	doc_881412446069_item	2921211	et	4	main
mõtteviis	doc_881412446069_item	2921212	et	3	main
vaieldav	doc_881412446069_item	2921213	et	4	main
kui	doc_881412446069_item	2921214	et	3	main
mitte	doc_881412446069_item	2921215	et	3	main
ütelda	doc_881412446069_item	2921216	et	4	main
kaugel	doc_881412446069_item	2921217	et	4	main
sellest	doc_881412446069_item	2921218	et	4	main
roheline	doc_881412446069_item	2921219	et	4	main
mõtteviis	doc_881412446069_item	2921220	et	3	main
me	doc_881412446069_item	2921226	et	4	main
oleme	doc_881412446069_item	2921227	et	3	main
nõus	doc_881412446069_item	2921228	et	4	main
et	doc_881412446069_item	2921229	et	3	main
loodust	doc_881412446069_item	2921230	et	4	main
tuleb	doc_881412446069_item	2921231	et	3	main
tänapäeva	doc_881412446069_item	2921242	et	4	main
ei	doc_881412446069_item	2921244	et	4	main
taha	doc_881412446069_item	2921245	et	4	main
lugesin	doc_881412446069_item	2921250	et	3	main
mitu	doc_881412446069_item	2921252	et	4	main
nädalat	doc_881412446069_item	2921253	et	3	main
pean	doc_881412446069_item	2921268	et	4	main
inimene	doc_881412446069_item	2921287	et	3	main
meil	doc_881412446069_item	2921222	et	4	main
südames	doc_881412446069_item	2921224	et	3	main
kõik	doc_881412446069_item	2921225	et	4	main
energia	doc_881412446069_item	2921234	et	4	main
saab	doc_881412446069_item	2921235	et	3	main
aga	doc_881412446069_item	2921241	et	3	main
tagasi	doc_881412446069_item	2921254	et	3	main
ühe	doc_881412446069_item	2921255	et	4	main
artikli	doc_881412446069_item	2921256	et	3	main
kus	doc_881412446069_item	2921257	et	3	main
räägitskse	doc_881412446069_item	2921258	et	4	main
ühe	doc_881412446069_item	2921259	et	4	main
perekonna	doc_881412446069_item	2921260	et	4	main
öko	doc_881412446069_item	2921261	et	4	main
elust	doc_881412446069_item	2921262	et	3	main
palju	doc_881412446069_item	2921263	et	4	main
sellest	doc_881412446069_item	2921264	et	4	main
jäi	doc_881412446069_item	2921265	et	3	main
mis	doc_881412446069_item	2921296	et	4	main
ootab	doc_881412446069_item	2921297	et	3	main
ja	doc_881412446069_item	2921307	et	3	main
ei	doc_881412446069_item	2921310	et	4	main
saa	doc_881412446069_item	2921311	et	4	main
et	doc_881412446069_item	2921343	et	3	main
tranporteerimiseks	doc_881412446069_item	2921345	et	4	main
bensiini	doc_881412446069_item	2921349	et	4	main
ei	doc_881412446069_item	2921352	et	4	main
seda	doc_881412446069_item	2921360	et	3	main
lihtsalt	doc_881412446069_item	2921388	et	4	main
mõelda	doc_881412446069_item	2921392	et	4	main
kartul	doc_881412446069_item	2921395	et	3	main
sellest	doc_881412446069_item	2921402	et	4	main
on	doc_881412446069_item	2921404	et	4	main
lihtsam	doc_881412446069_item	2921405	et	4	main
valmistada	doc_881412446069_item	2921406	et	3	main
hoolitsevad	doc_881412446069_item	2921423	et	4	main
eest	doc_881412446069_item	2921425	et	4	main
rohkem	doc_881412446069_item	2921426	et	4	main
kui	doc_881412446069_item	2921427	et	3	main
sorteerivad	doc_881412446069_item	2921430	et	4	main
on	doc_881412446069_item	2921446	et	4	main
liiga	doc_881412446069_item	2921453	et	4	main
noor	doc_881412446069_item	2921454	et	3	main
jaoks	doc_881412446069_item	2921456	et	4	main
ei	doc_881412446069_item	2921465	et	4	main
tegele	doc_881412446069_item	2921466	et	4	main
kodus	doc_881412446069_item	2921471	et	4	main
pesutänavatel	doc_881412446069_item	2921480	et	4	main
rohlem	doc_881412446069_item	2921488	et	4	main
kõik	doc_881412446069_item	2921490	et	4	main
poest	doc_881412446069_item	2921530	et	4	main
nii	doc_881412446069_item	2921531	et	3	main
tooteid	doc_881412446069_item	2921539	et	4	main
hoida	doc_881412446069_item	2921540	et	3	main
kokku	doc_881412446069_item	2921541	et	3	main
elektrit	doc_881412446069_item	2921542	et	3	main
vett	doc_881412446069_item	2921543	et	3	main
et	doc_881412446069_item	2921548	et	3	main
juba	doc_881412446069_item	2921560	et	3	main
informatsioonist	doc_881412446069_item	2921562	et	3	main
kuid	doc_881412446069_item	2921565	et	4	main
see	doc_881412446069_item	2921566	et	3	main
teema	doc_881412446069_item	2921567	et	4	main
neid	doc_881412446069_item	2921578	et	4	main
vähe	doc_881412446069_item	2921580	et	3	main
ei	doc_881412446069_item	2921582	et	4	main
muuta	doc_881412446069_item	2921583	et	4	main
paljud	doc_881412446069_item	2921289	et	3	main
meid	doc_881412446069_item	2921298	et	4	main
järgmisel	doc_881412446069_item	2921299	et	3	main
või	doc_881412446069_item	2921300	et	4	main
ülejärgmisel	doc_881412446069_item	2921301	et	3	main
mina	doc_881412446069_item	2921308	et	4	main
miks	doc_881412446069_item	2921317	et	4	main
ma	doc_881412446069_item	2921318	et	3	main
veel	doc_881412446069_item	2921322	et	4	main
korda	doc_881412446069_item	2921324	et	4	main
miks	doc_881412446069_item	2921326	et	4	main
kuid	doc_881412446069_item	2921337	et	4	main
see	doc_881412446069_item	2921338	et	3	main
on	doc_881412446069_item	2921339	et	4	main
vähem	doc_881412446069_item	2921348	et	4	main
mina	doc_881412446069_item	2921351	et	4	main
valin	doc_881412446069_item	2921359	et	3	main
meeldib	doc_881412446069_item	2921364	et	3	main
ja	doc_881412446069_item	2921365	et	3	main
ole	doc_881412446069_item	2921390	et	4	main
aega	doc_881412446069_item	2921391	et	4	main
on	doc_881412446069_item	2921396	et	4	main
mõtlen	doc_881412446069_item	2921400	et	3	main
mida	doc_881412446069_item	2921403	et	4	main
meeldivad	doc_881412446069_item	2921409	et	4	main
minule	doc_881412446069_item	2921410	et	3	main
seal	doc_881412446069_item	2921418	et	4	main
ökoloogiast	doc_881412446069_item	2921421	et	3	main
siin	doc_881412446069_item	2921428	et	4	main
oma	doc_881412446069_item	2921431	et	4	main
prüügi	doc_881412446069_item	2921432	et	4	main
ega	doc_881412446069_item	2921433	et	3	main
need	doc_881412446069_item	2921434	et	3	main
et	doc_881412446069_item	2921439	et	3	main
naftast	doc_881412446069_item	2921448	et	4	main
elada	doc_881412446069_item	2921459	et	3	main
näiteks	doc_881412446069_item	2921467	et	4	main
ainult	doc_881412446069_item	2921479	et	4	main
me	doc_881412446069_item	2921484	et	4	main
tegele	doc_881412446069_item	2921486	et	4	main
sellega	doc_881412446069_item	2921487	et	3	main
tekkisid	doc_881412446069_item	2921494	et	4	main
mitte	doc_881412446069_item	2921495	et	3	main
oma	doc_881412446069_item	2921523	et	4	main
ei	doc_881412446069_item	2921526	et	4	main
meie	doc_881412446069_item	2921549	et	4	main
kirjutavad	doc_881412446069_item	2921553	et	4	main
on	doc_881412446069_item	2921559	et	4	main
nii	doc_881412446069_item	2921563	et	3	main
nende	doc_881412446069_item	2921584	et	4	main
või	doc_881412446069_item	2921325	et	4	main
valida	doc_881412446069_item	2921328	et	3	main
ei	doc_881412446069_item	2921335	et	4	main
ainult	doc_881412446069_item	2921341	et	4	main
aga	doc_881412446069_item	2921358	et	3	main
mida	doc_881412446069_item	2921361	et	4	main
rohkem	doc_881412446069_item	2921363	et	4	main
soobib	doc_881412446069_item	2921366	et	4	main
sama	doc_881412446069_item	2921367	et	4	main
asi	doc_881412446069_item	2921368	et	4	main
on	doc_881412446069_item	2921369	et	4	main
toiduga	doc_881412446069_item	2921370	et	3	main
valin	doc_881412446069_item	2921371	et	3	main
just	doc_881412446069_item	2921372	et	3	main
need	doc_881412446069_item	2921373	et	3	main
toiduained	doc_881412446069_item	2921374	et	3	main
mis	doc_881412446069_item	2921375	et	4	main
tahan	doc_881412446069_item	2921376	et	3	main
ning	doc_881412446069_item	2921377	et	3	main
mõtle	doc_881412446069_item	2921379	et	4	main
kust	doc_881412446069_item	2921380	et	4	main
ei	doc_881412446069_item	2921378	et	4	main
on	doc_881412446069_item	2921381	et	4	main
need	doc_881412446069_item	2921382	et	3	main
toodetud	doc_881412446069_item	2921383	et	4	main
austraaliast	doc_881412446069_item	2921384	et	4	main
või	doc_881412446069_item	2921385	et	4	main
mul	doc_881412446069_item	2921387	et	3	main
ei	doc_881412446069_item	2921389	et	4	main
sellest	doc_881412446069_item	2921393	et	4	main
riis	doc_881412446069_item	2921399	et	3	main
ausalt	doc_881412446069_item	2921407	et	4	main
ameerikas	doc_881412446069_item	2921417	et	4	main
ole	doc_881412446069_item	2921436	et	4	main
osta	doc_881412446069_item	2921440	et	4	main
ilma	doc_881412446069_item	2921442	et	4	main
võiks	doc_881412446069_item	2921449	et	4	main
olla	doc_881412446069_item	2921450	et	3	main
selle	doc_881412446069_item	2921455	et	4	main
et	doc_881412446069_item	2921457	et	3	main
kuid	doc_881412446069_item	2921460	et	4	main
minu	doc_881412446069_item	2921461	et	3	main
perekonnas	doc_881412446069_item	2921462	et	4	main
pudelid	doc_881412446069_item	2921468	et	3	main
mis	doc_881412446069_item	2921469	et	4	main
kuu	doc_881412446069_item	2921472	et	4	main
joolsul	doc_881412446069_item	2921473	et	4	main
toome	doc_881412446069_item	2921474	et	4	main
normaalne	doc_881412446069_item	2921483	et	3	main
mina	doc_881412446069_item	2921498	et	4	main
lihtsalt	doc_881412446069_item	2921499	et	4	main
ei	doc_881412446069_item	2921500	et	4	main
usu	doc_881412446069_item	2921501	et	4	main
et	doc_881412446069_item	2921502	et	3	main
minu	doc_881412446069_item	2921503	et	3	main
tegevus	doc_881412446069_item	2921504	et	4	main
midagi	doc_881412446069_item	2921505	et	4	main
muutub	doc_881412446069_item	2921506	et	3	main
lõpuks	doc_881412446069_item	2921507	et	4	main
saan	doc_881412446069_item	2921508	et	4	main
öelda	doc_881412446069_item	2921509	et	4	main
et	doc_881412446069_item	2921510	et	3	main
inimesele	doc_881412446069_item	2921512	et	3	main
tänapäeva	doc_881412446069_item	2921511	et	4	main
tuleb	doc_881412446069_item	2921513	et	3	main
iga	doc_881412446069_item	2921514	et	4	main
kord	doc_881412446069_item	2921515	et	4	main
valida	doc_881412446069_item	2921516	et	3	main
mida	doc_881412446069_item	2921517	et	4	main
säästa	doc_881412446069_item	2921518	et	4	main
kas	doc_881412446069_item	2921519	et	3	main
energiat	doc_881412446069_item	2921520	et	3	main
vett	doc_881412446069_item	2921521	et	3	main
kahjuks	doc_881412446069_item	2921525	et	4	main
ole	doc_881412446069_item	2921527	et	4	main
võimalik	doc_881412446069_item	2921528	et	3	main
võta	doc_881412446069_item	2921529	et	4	main
kohalikke	doc_881412446069_item	2921538	et	4	main
arvamust	doc_881412446069_item	2921547	et	3	main
teadlased	doc_881412446069_item	2921551	et	3	main
on	doc_881412446069_item	2921568	et	4	main
elustiili	doc_881412446069_item	2921575	et	4	main
muutma	doc_881412446069_item	2921576	et	3	main
on	doc_881412446069_item	2921579	et	4	main
midagi	doc_881412446069_item	2921587	et	4	main
pakendit	doc_881412446069_item	2921443	et	3	main
sest	doc_881412446069_item	2921444	et	4	main
pakend	doc_881412446069_item	2921445	et	3	main
mina	doc_881412446069_item	2921451	et	4	main
olen	doc_881412446069_item	2921452	et	3	main
keegi	doc_881412446069_item	2921463	et	4	main
sellega	doc_881412446069_item	2921464	et	3	main
kogunevad	doc_881412446069_item	2921470	et	4	main
on	doc_881412446069_item	2921482	et	4	main
sest	doc_881412446069_item	2921489	et	4	main
ökoloogiaga	doc_881412446069_item	2921491	et	3	main
seotud	doc_881412446069_item	2921492	et	4	main
täna	doc_881412446069_item	2921496	et	4	main
ja	doc_881412446069_item	2921497	et	3	main
tehtud	doc_881412446069_item	2921447	et	4	main
niimodi	doc_881412446069_item	2921458	et	4	main
automaadile	doc_881412446069_item	2921475	et	4	main
ning	doc_881412446069_item	2921476	et	3	main
autot	doc_881412446069_item	2921477	et	3	main
peseme	doc_881412446069_item	2921478	et	3	main
see	doc_881412446069_item	2921481	et	3	main
ei	doc_881412446069_item	2921485	et	4	main
probleemid	doc_881412446069_item	2921493	et	3	main
või	doc_881412446069_item	2921522	et	4	main
palju	doc_881412446069_item	2921532	et	4	main
kilekotte	doc_881412446069_item	2921533	et	3	main
jne	doc_881412446069_item	2921544	et	4	main
lugesin	doc_881412446069_item	2921545	et	3	main
aja	doc_881412446069_item	2921550	et	4	main
räägivad	doc_881412446069_item	2921552	et	3	main
liiga	doc_881412446069_item	2921555	et	4	main
sellest	doc_881412446069_item	2921561	et	4	main
meie	doc_881412446069_item	2921569	et	4	main
ega	doc_881412446069_item	2921577	et	3	main
ja	doc_881412446069_item	2921581	et	3	main
me	doc_881412446069_item	2921588	et	4	main
aega	doc_881412446069_item	2921524	et	4	main
sõida	doc_881412446069_item	2921534	et	4	main
jalgrattaga	doc_881412446069_item	2921535	et	3	main
tarbida	doc_881412446069_item	2921536	et	3	main
ainult	doc_881412446069_item	2921537	et	4	main
internetist	doc_881412446069_item	2921546	et	4	main
ökoloogiast	doc_881412446069_item	2921554	et	3	main
palju	doc_881412446069_item	2921556	et	4	main
et	doc_881412446069_item	2921557	et	3	main
inimesed	doc_881412446069_item	2921558	et	3	main
väsinud	doc_881412446069_item	2921564	et	4	main
ajal	doc_881412446069_item	2921570	et	4	main
populaarne	doc_881412446069_item	2921571	et	3	main
proovivad	doc_881412446069_item	2921572	et	4	main
mõned	doc_881412446069_item	2921573	et	3	main
oma	doc_881412446069_item	2921574	et	4	main
tegevus	doc_881412446069_item	2921585	et	4	main
mitte	doc_881412446069_item	2921586	et	3	main
oleme	doc_881412446069_item	2921589	et	3	main
juba	doc_881412446069_item	2921590	et	3	main
harjunud	doc_881412446069_item	2921591	et	4	main
oma	doc_881412446069_item	2921592	et	4	main
eluviisiga	doc_881412446069_item	2921593	et	4	main
ning	doc_881412446069_item	2921594	et	3	main
oleme	doc_881412446069_item	2921595	et	3	main
liiga	doc_881412446069_item	2921596	et	4	main
laised	doc_881412446069_item	2921597	et	4	main
et	doc_881412446069_item	2921598	et	3	main
hakkama	doc_881412446069_item	2921599	et	3	main
teistmoodi	doc_881412446069_item	2921600	et	3	main
mõtlema	doc_881412446069_item	2921601	et	3	main
ja	doc_881412446069_item	2921602	et	3	main
elama	doc_881412446069_item	2921603	et	3	main
niimodi	doc_881412446069_item	2921604	et	4	main
on	doc_881412446069_item	2921605	et	4	main
mugavam	doc_881412446069_item	2921606	et	4	main
mina	doc_881412446069_item	2921607	et	4	main
elan	doc_881412446069_item	2921608	et	3	main
ainulad	doc_881412446069_item	2921609	et	4	main
üks	doc_881412446069_item	2921610	et	3	main
kord	doc_881412446069_item	2921611	et	4	main
selle	doc_881412446069_item	2921612	et	4	main
pärast	doc_881412446069_item	2921613	et	4	main
lihtsalt	doc_881412446069_item	2921614	et	4	main
ei	doc_881412446069_item	2921615	et	4	main
taha	doc_881412446069_item	2921616	et	4	main
oma	doc_881412446069_item	2921617	et	4	main
elus	doc_881412446069_item	2921618	et	4	main
midagi	doc_881412446069_item	2921619	et	4	main
muuta	doc_881412446069_item	2921620	et	4	main
ökoelu	doc_881412446073_item	2922431	et	4	main
inimene	doc_881412446073_item	2922432	et	3	main
ajast	doc_881412446073_item	2922439	et	4	main
saama	doc_881412446073_item	2922455	et	4	main
tuld	doc_881412446073_item	2922456	et	3	main
enda	doc_881412446073_item	2922465	et	4	main
hõimugeda	doc_881412446073_item	2922469	et	4	main
vastastikuse	doc_881412446073_item	2922476	et	4	main
käituma	doc_881412446073_item	2922505	et	3	main
tänapäeval	doc_881412446073_item	2922514	et	3	main
pühadasteotav	doc_881412446073_item	2922516	et	4	main
suhtumine	doc_881412446073_item	2922518	et	4	main
maavarade	doc_881412446073_item	2922519	et	3	main
kohta	doc_881412446073_item	2922520	et	4	main
ja	doc_881412446073_item	2922433	et	3	main
tihedalt	doc_881412446073_item	2922436	et	4	main
seotud	doc_881412446073_item	2922437	et	4	main
aga	doc_881412446073_item	2922446	et	3	main
möödus	doc_881412446073_item	2922448	et	3	main
arenes	doc_881412446073_item	2922450	et	3	main
looma	doc_881412446073_item	2922459	et	4	main
inimene	doc_881412446073_item	2922461	et	3	main
eiste	doc_881412446073_item	2922468	et	4	main
ka	doc_881412446073_item	2922471	et	3	main
agressiivselt	doc_881412446073_item	2922506	et	4	main
ole	doc_881412446073_item	2922508	et	4	main
saladus	doc_881412446073_item	2922509	et	3	main
kui	doc_881412446073_item	2922510	et	3	main
kahjulikult	doc_881412446073_item	2922511	et	4	main
inimene	doc_881412446073_item	2922512	et	3	main
katastroofilise	doc_881412446073_item	2922523	et	4	main
ju	doc_881412446073_item	2922533	et	3	main
kopsud	doc_881412446073_item	2922535	et	4	main
vähenemisi	doc_881412446073_item	2922539	et	4	main
ja	doc_881412446073_item	2922540	et	3	main
isegi	doc_881412446073_item	2922541	et	4	main
kuhu	doc_881412446073_item	2922547	et	3	main
puhtad	doc_881412446073_item	2922550	et	3	main
allikad	doc_881412446073_item	2922551	et	3	main
essee	doc_881412446073_item	2922429	et	4	main
minu	doc_881412446073_item	2922430	et	3	main
ammust	doc_881412446073_item	2922438	et	4	main
ümbritsevast	doc_881412446073_item	2922444	et	4	main
aeg	doc_881412446073_item	2922447	et	3	main
inimene	doc_881412446073_item	2922449	et	3	main
temaaju	doc_881412446073_item	2922451	et	4	main
õppisid	doc_881412446073_item	2922454	et	4	main
elamuid	doc_881412446073_item	2922458	et	3	main
ainult	doc_881412446073_item	2922463	et	4	main
võitles	doc_881412446073_item	2922464	et	3	main
ka	doc_881412446073_item	2922473	et	3	main
avaldub	doc_881412446073_item	2922515	et	3	main
kasutuslik	doc_881412446073_item	2922517	et	4	main
rajutakse	doc_881412446073_item	2922527	et	3	main
hiilgavad	doc_881412446073_item	2922528	et	4	main
on	doc_881412446073_item	2922532	et	4	main
erinevades	doc_881412446073_item	2922543	et	4	main
ohtlik	doc_881412446073_item	2922558	et	3	main
ainult	doc_881412446073_item	2922560	et	4	main
suppelda	doc_881412446073_item	2922564	et	4	main
õhku	doc_881412446073_item	2922566	et	4	main
seisab	doc_881412446073_item	2922574	et	3	main
isegi	doc_881412446073_item	2922577	et	4	main
tähte	doc_881412446073_item	2922578	et	4	main
näha	doc_881412446073_item	2922581	et	3	main
lohutab	doc_881412446073_item	2922583	et	3	main
et	doc_881412446073_item	2922584	et	3	main
alad	doc_881412446073_item	2922590	et	3	main
tsivilsatsioon	doc_881412446073_item	2922592	et	4	main
näiteks	doc_881412446073_item	2922597	et	4	main
tulles	doc_881412446073_item	2922598	et	4	main
mis	doc_881412446073_item	2922605	et	4	main
maavaraseid	doc_881412446073_item	2922621	et	4	main
see	doc_881412446073_item	2922623	et	3	main
päike	doc_881412446073_item	2922636	et	3	main
mõõn	doc_881412446073_item	2922640	et	3	main
mulje	doc_881412446073_item	2922642	et	4	main
kõik	doc_881412446073_item	2922643	et	4	main
on	doc_881412446073_item	2922644	et	4	main
väljast	doc_881412446073_item	2922652	et	4	main
vähe	doc_881412446073_item	2922664	et	3	main
oma	doc_881412446073_item	2922666	et	4	main
keskkonast	doc_881412446073_item	2922668	et	4	main
tahaks	doc_881412446073_item	2922669	et	3	main
et	doc_881412446073_item	2922672	et	3	main
väga	doc_881412446073_item	2922675	et	3	main
hoolikalt	doc_881412446073_item	2922676	et	4	main
loodusesse	doc_881412446073_item	2922678	et	4	main
seda	doc_881412446073_item	2922679	et	3	main
saab	doc_881412446073_item	2922680	et	3	main
muinasjutte	doc_881412446073_item	2922683	et	3	main
müüte	doc_881412446073_item	2922684	et	4	main
ja	doc_881412446073_item	2922687	et	3	main
ja	doc_881412446073_item	2922723	et	3	main
armastama	doc_881412446073_item	2922726	et	3	main
arutamine	doc_881412446073_item	2922734	et	4	main
nendest	doc_881412446073_item	2922742	et	4	main
prügi	doc_881412446073_item	2922752	et	4	main
maha	doc_881412446073_item	2922753	et	4	main
õues	doc_881412446073_item	2922754	et	4	main
mul	doc_881412446073_item	2922761	et	3	main
autoga	doc_881412446073_item	2922766	et	3	main
kasutada	doc_881412446073_item	2922768	et	3	main
on	doc_881412446073_item	2922775	et	4	main
neid	doc_881412446073_item	2922779	et	4	main
ole	doc_881412446073_item	2922782	et	4	main
et	doc_881412446073_item	2922783	et	3	main
on	doc_881412446073_item	2922435	et	4	main
ürgsed	doc_881412446073_item	2922440	et	3	main
inimesed	doc_881412446073_item	2922441	et	3	main
keskkonnast	doc_881412446073_item	2922445	et	4	main
täiustus	doc_881412446073_item	2922452	et	4	main
inimesed	doc_881412446073_item	2922453	et	3	main
eest	doc_881412446073_item	2922467	et	4	main
loodust	doc_881412446073_item	2922474	et	4	main
vallutada	doc_881412446073_item	2922475	et	3	main
mõju	doc_881412446073_item	2922477	et	4	main
ei	doc_881412446073_item	2922507	et	4	main
võib	doc_881412446073_item	2922521	et	3	main
aga	doc_881412446073_item	2922530	et	3	main
hukutamisi	doc_881412446073_item	2922542	et	4	main
ja	doc_881412446073_item	2922545	et	3	main
on	doc_881412446073_item	2922548	et	4	main
on	doc_881412446073_item	2922557	et	4	main
mitte	doc_881412446073_item	2922559	et	3	main
vaid	doc_881412446073_item	2922562	et	3	main
ka	doc_881412446073_item	2922563	et	3	main
jäätmed	doc_881412446073_item	2922572	et	3	main
kohal	doc_881412446073_item	2922576	et	4	main
ole	doc_881412446073_item	2922580	et	4	main
õhku	doc_881412446073_item	2922604	et	4	main
ja	doc_881412446073_item	2922622	et	3	main
ammu	doc_881412446073_item	2922629	et	4	main
tuul	doc_881412446073_item	2922637	et	3	main
tõus	doc_881412446073_item	2922638	et	4	main
elada	doc_881412446073_item	2922650	et	3	main
ta	doc_881412446073_item	2922653	et	4	main
maal	doc_881412446073_item	2922655	et	4	main
nii	doc_881412446073_item	2922663	et	3	main
elu	doc_881412446073_item	2922667	et	4	main
inimesed	doc_881412446073_item	2922674	et	3	main
loomadest	doc_881412446073_item	2922722	et	3	main
austama	doc_881412446073_item	2922728	et	3	main
loodust	doc_881412446073_item	2922729	et	4	main
lapsi	doc_881412446073_item	2922730	et	4	main
õpib	doc_881412446073_item	2922731	et	3	main
läheb	doc_881412446073_item	2922735	et	3	main
aga	doc_881412446073_item	2922737	et	3	main
jah	doc_881412446073_item	2922745	et	3	main
kuid	doc_881412446073_item	2922755	et	4	main
iga	doc_881412446073_item	2922763	et	4	main
või	doc_881412446073_item	2922767	et	4	main
ühistransporti	doc_881412446073_item	2922769	et	4	main
osta	doc_881412446073_item	2922770	et	4	main
või	doc_881412446073_item	2922778	et	4	main
üldse	doc_881412446073_item	2922780	et	3	main
ei	doc_881412446073_item	2922781	et	4	main
elu	doc_881412446073_item	2922793	et	4	main
nõudmised	doc_881412446073_item	2922794	et	4	main
ökoelu	doc_881412446074_item	2922800	et	4	main
minu	doc_881412446074_item	2922804	et	3	main
mind	doc_881412446074_item	2922806	et	4	main
muretseb	doc_881412446074_item	2922808	et	3	main
öko	doc_881412446074_item	2922812	et	4	main
probleemi	doc_881412446074_item	2922813	et	4	main
sest	doc_881412446074_item	2922829	et	4	main
raisata	doc_881412446074_item	2922834	et	4	main
isegi	doc_881412446074_item	2922844	et	4	main
paber	doc_881412446074_item	2922847	et	3	main
loodus	doc_881412446073_item	2922434	et	4	main
sõltusid	doc_881412446073_item	2922442	et	4	main
täielikult	doc_881412446073_item	2922443	et	4	main
ehitama	doc_881412446073_item	2922457	et	4	main
tööristu	doc_881412446073_item	2922460	et	4	main
mitte	doc_881412446073_item	2922462	et	3	main
koha	doc_881412446073_item	2922466	et	4	main
vaid	doc_881412446073_item	2922470	et	3	main
kavatses	doc_881412446073_item	2922472	et	3	main
küsimus	doc_881412446073_item	2922478	et	4	main
on	doc_881412446073_item	2922479	et	4	main
aktuaalne	doc_881412446073_item	2922480	et	3	main
ka	doc_881412446073_item	2922481	et	3	main
täna	doc_881412446073_item	2922482	et	4	main
proklameerides	doc_881412446073_item	2922483	et	4	main
end	doc_881412446073_item	2922484	et	4	main
eluolendik	doc_881412446073_item	2922485	et	4	main
kuningaks	doc_881412446073_item	2922486	et	3	main
inimene	doc_881412446073_item	2922487	et	3	main
unustas	doc_881412446073_item	2922488	et	3	main
et	doc_881412446073_item	2922489	et	3	main
ta	doc_881412446073_item	2922490	et	4	main
ise	doc_881412446073_item	2922491	et	4	main
on	doc_881412446073_item	2922492	et	4	main
looduse	doc_881412446073_item	2922493	et	4	main
osa	doc_881412446073_item	2922494	et	4	main
selle	doc_881412446073_item	2922495	et	4	main
loome	doc_881412446073_item	2922496	et	4	main
krooniks	doc_881412446073_item	2922497	et	4	main
ja	doc_881412446073_item	2922498	et	3	main
selle	doc_881412446073_item	2922499	et	4	main
asemel	doc_881412446073_item	2922500	et	4	main
et	doc_881412446073_item	2922501	et	3	main
olla	doc_881412446073_item	2922502	et	3	main
tänulik	doc_881412446073_item	2922503	et	3	main
jätkab	doc_881412446073_item	2922504	et	3	main
tegevus	doc_881412446073_item	2922513	et	4	main
metsapindalad	doc_881412446073_item	2922529	et	3	main
planeedi	doc_881412446073_item	2922534	et	3	main
nende	doc_881412446073_item	2922536	et	4	main
põhjustab	doc_881412446073_item	2922538	et	3	main
looma-	doc_881412446073_item	2922544	et	4	main
ning	doc_881412446073_item	2922555	et	3	main
selles	doc_881412446073_item	2922565	et	4	main
mürgistavad	doc_881412446073_item	2922567	et	4	main
tehaste	doc_881412446073_item	2922571	et	3	main
sudu	doc_881412446073_item	2922573	et	4	main
linnade	doc_881412446073_item	2922575	et	3	main
veel	doc_881412446073_item	2922587	et	4	main
ei	doc_881412446073_item	2922593	et	4	main
ole	doc_881412446073_item	2922594	et	4	main
puutunud	doc_881412446073_item	2922596	et	4	main
naudime	doc_881412446073_item	2922602	et	3	main
on	doc_881412446073_item	2922624	et	4	main
räägivad	doc_881412446073_item	2922630	et	3	main
energia	doc_881412446073_item	2922632	et	4	main
ja	doc_881412446073_item	2922639	et	3	main
vilju	doc_881412446073_item	2922658	et	4	main
joob	doc_881412446073_item	2922659	et	3	main
selle	doc_881412446073_item	2922660	et	4	main
vett	doc_881412446073_item	2922661	et	3	main
ja	doc_881412446073_item	2922662	et	3	main
hoolib	doc_881412446073_item	2922665	et	3	main
suhtusid	doc_881412446073_item	2922677	et	4	main
teades	doc_881412446073_item	2922682	et	4	main
laude	doc_881412446073_item	2922686	et	3	main
hoolitseda	doc_881412446073_item	2922721	et	3	main
elureeglitest	doc_881412446073_item	2922743	et	4	main
kinni	doc_881412446073_item	2922744	et	3	main
ei	doc_881412446073_item	2922747	et	4	main
sõita	doc_881412446073_item	2922765	et	3	main
elu	doc_881412446073_item	2922786	et	4	main
mugavam	doc_881412446073_item	2922787	et	4	main
kasutan	doc_881412446073_item	2922788	et	3	main
liiga	doc_881412446073_item	2922789	et	4	main
kas	doc_881412446073_item	2922795	et	3	main
nii	doc_881412446073_item	2922797	et	3	main
küll	doc_881412446074_item	2922807	et	4	main
mitte	doc_881412446074_item	2922814	et	3	main
asi	doc_881412446074_item	2922821	et	4	main
prügi	doc_881412446074_item	2922839	et	4	main
mul	doc_881412446074_item	2922842	et	3	main
leian	doc_881412446074_item	2922853	et	3	main
saaks	doc_881412446074_item	2922856	et	3	main
ära	doc_881412446074_item	2922857	et	4	main
klaasist	doc_881412446074_item	2922870	et	4	main
ma	doc_881412446074_item	2922871	et	3	main
tekkib	doc_881412446074_item	2922880	et	3	main
nädala	doc_881412446074_item	2922922	et	3	main
tulnud	doc_881412446074_item	2922924	et	4	main
reklaamid	doc_881412446074_item	2922925	et	4	main
11	doc_881412446074_item	2922927	et	2	main
see	doc_881412446074_item	2922928	et	3	main
ilma	doc_881412446074_item	2922934	et	4	main
nii	doc_881412446074_item	2922937	et	3	main
raklaami	doc_881412446074_item	2922939	et	4	main
kord	doc_881412446074_item	2922940	et	4	main
on	doc_881412446074_item	2922946	et	4	main
olen	doc_881412446074_item	2922954	et	3	main
olema	doc_881412446074_item	2922964	et	4	main
ei	doc_881412446074_item	2922969	et	4	main
ole	doc_881412446074_item	2922970	et	4	main
kodumaist	doc_881412446074_item	2923000	et	4	main
see	doc_881412446074_item	2923001	et	3	main
on	doc_881412446074_item	2923002	et	4	main
järgmised	doc_881412446074_item	2923032	et	3	main
inimesed	doc_881412446074_item	2923033	et	3	main
tulevad	doc_881412446074_item	2923034	et	4	main
ka	doc_881412446074_item	2923035	et	3	main
proobleem	doc_881412446074_item	2923040	et	4	main
ilusti	doc_881412446074_item	2923060	et	3	main
iks	doc_881412446074_item	2923065	et	3	main
hirmsasti	doc_881412446074_item	2923068	et	3	main
jama	doc_881412446074_item	2923071	et	4	main
tahan	doc_881412446074_item	2923073	et	3	main
kuid	doc_881412446074_item	2923074	et	4	main
kujutage	doc_881412446074_item	2923075	et	3	main
soe	doc_881412446074_item	2923091	et	4	main
aasta	doc_881412446073_item	2922526	et	4	main
tekkitada	doc_881412446073_item	2922522	et	4	main
tagajärge	doc_881412446073_item	2922524	et	4	main
iga	doc_881412446073_item	2922525	et	4	main
metsad	doc_881412446073_item	2922531	et	3	main
hävitamine	doc_881412446073_item	2922537	et	4	main
taimeliikides	doc_881412446073_item	2922546	et	3	main
kadunud	doc_881412446073_item	2922549	et	4	main
miljonide	doc_881412446073_item	2922568	et	4	main
autode	doc_881412446073_item	2922569	et	3	main
ekoloogiliselt	doc_881412446073_item	2922588	et	4	main
puhtad	doc_881412446073_item	2922589	et	3	main
mis	doc_881412446073_item	2922591	et	4	main
lõhestatud	doc_881412446073_item	2922607	et	4	main
taimede	doc_881412446073_item	2922608	et	4	main
lõhnaga	doc_881412446073_item	2922609	et	3	main
inimene	doc_881412446073_item	2922610	et	3	main
unustab	doc_881412446073_item	2922611	et	3	main
et	doc_881412446073_item	2922612	et	3	main
planeedi	doc_881412446073_item	2922613	et	3	main
resursid	doc_881412446073_item	2922614	et	4	main
kunagi	doc_881412446073_item	2922615	et	3	main
lõppevad	doc_881412446073_item	2922616	et	4	main
ja	doc_881412446073_item	2922617	et	3	main
jätkab	doc_881412446073_item	2922618	et	3	main
röövellikult	doc_881412446073_item	2922619	et	4	main
hankima	doc_881412446073_item	2922620	et	3	main
kui	doc_881412446073_item	2922626	et	3	main
juba	doc_881412446073_item	2922628	et	3	main
et	doc_881412446073_item	2922631	et	3	main
saab	doc_881412446073_item	2922633	et	3	main
ka	doc_881412446073_item	2922634	et	3	main
teisiti	doc_881412446073_item	2922635	et	3	main
unustanud	doc_881412446073_item	2922645	et	4	main
et	doc_881412446073_item	2922646	et	3	main
inimene	doc_881412446073_item	2922647	et	3	main
loodust	doc_881412446073_item	2922651	et	4	main
elab	doc_881412446073_item	2922654	et	3	main
sööb	doc_881412446073_item	2922656	et	3	main
selle	doc_881412446073_item	2922657	et	4	main
tuletada	doc_881412446073_item	2922670	et	3	main
iigsuses	doc_881412446073_item	2922673	et	4	main
väita	doc_881412446073_item	2922681	et	4	main
legende	doc_881412446073_item	2922685	et	3	main
jäägid	doc_881412446073_item	2922552	et	3	main
visatakse	doc_881412446073_item	2922553	et	3	main
vette	doc_881412446073_item	2922554	et	3	main
seda	doc_881412446073_item	2922556	et	3	main
juua	doc_881412446073_item	2922561	et	3	main
gassid	doc_881412446073_item	2922570	et	4	main
ei	doc_881412446073_item	2922579	et	4	main
öösiti	doc_881412446073_item	2922582	et	4	main
on	doc_881412446073_item	2922585	et	4	main
jäänud	doc_881412446073_item	2922586	et	4	main
veel	doc_881412446073_item	2922595	et	4	main
lahemaa	doc_881412446073_item	2922599	et	4	main
rahvuspargi	doc_881412446073_item	2922600	et	3	main
me	doc_881412446073_item	2922601	et	4	main
puhta	doc_881412446073_item	2922603	et	4	main
on	doc_881412446073_item	2922606	et	4	main
siis	doc_881412446073_item	2922625	et	3	main
teadlased	doc_881412446073_item	2922627	et	3	main
tekkib	doc_881412446073_item	2922641	et	3	main
ei	doc_881412446073_item	2922648	et	4	main
saa	doc_881412446073_item	2922649	et	4	main
meelde	doc_881412446073_item	2922671	et	3	main
rahvatarkuseid	doc_881412446073_item	2922688	et	4	main
on	doc_881412446073_item	2922689	et	4	main
väga	doc_881412446073_item	2922690	et	3	main
tähtis	doc_881412446073_item	2922691	et	4	main
et	doc_881412446073_item	2922692	et	3	main
tänapäeva	doc_881412446073_item	2922693	et	4	main
lapsed	doc_881412446073_item	2922694	et	3	main
ka	doc_881412446073_item	2922695	et	3	main
saaksid	doc_881412446073_item	2922696	et	4	main
osaleda	doc_881412446073_item	2922697	et	3	main
selles	doc_881412446073_item	2922698	et	4	main
varamuses	doc_881412446073_item	2922699	et	4	main
ja	doc_881412446073_item	2922700	et	3	main
ma	doc_881412446073_item	2922701	et	3	main
arvan	doc_881412446073_item	2922702	et	3	main
et	doc_881412446073_item	2922703	et	3	main
pea	doc_881412446073_item	2922704	et	4	main
rolli	doc_881412446073_item	2922705	et	4	main
selles	doc_881412446073_item	2922706	et	4	main
mängib	doc_881412446073_item	2922707	et	3	main
pere	doc_881412446073_item	2922708	et	4	main
ja	doc_881412446073_item	2922709	et	3	main
kool	doc_881412446073_item	2922710	et	4	main
lapsepõlves	doc_881412446073_item	2922711	et	4	main
vanemad	doc_881412446073_item	2922712	et	4	main
tutvustavad	doc_881412446073_item	2922713	et	4	main
lastele	doc_881412446073_item	2922714	et	4	main
õmbritsevad	doc_881412446073_item	2922715	et	4	main
keskkonna	doc_881412446073_item	2922716	et	3	main
õppitavad	doc_881412446073_item	2922717	et	4	main
hoolikalt	doc_881412446073_item	2922718	et	4	main
sellesse	doc_881412446073_item	2922719	et	4	main
suhtuda	doc_881412446073_item	2922720	et	3	main
ja	doc_881412446073_item	2922727	et	3	main
kergesti	doc_881412446073_item	2922736	et	3	main
kas	doc_881412446073_item	2922738	et	3	main
ise	doc_881412446073_item	2922740	et	4	main
ma	doc_881412446073_item	2922746	et	3	main
vaevalt	doc_881412446073_item	2922756	et	4	main
see	doc_881412446073_item	2922757	et	3	main
kompenseerib	doc_881412446073_item	2922758	et	3	main
seda	doc_881412446073_item	2922759	et	3	main
mida	doc_881412446073_item	2922760	et	4	main
taimedest	doc_881412446073_item	2922724	et	4	main
koolis	doc_881412446073_item	2922725	et	4	main
loodusteadus	doc_881412446073_item	2922732	et	4	main
niisugune	doc_881412446073_item	2922733	et	3	main
mina	doc_881412446073_item	2922739	et	4	main
pean	doc_881412446073_item	2922741	et	4	main
raiu	doc_881412446073_item	2922748	et	4	main
puid	doc_881412446073_item	2922749	et	3	main
ningei	doc_881412446073_item	2922750	et	4	main
aja	doc_881412446073_item	2922751	et	4	main
teha	doc_881412446073_item	2922762	et	3	main
tatlustootteis	doc_881412446073_item	2922771	et	4	main
välismaalt	doc_881412446073_item	2922772	et	3	main
oma	doc_881412446073_item	2922785	et	4	main
elekroenergiat	doc_881412446073_item	2922791	et	4	main
kaasaegse	doc_881412446073_item	2922792	et	3	main
ongi	doc_881412446073_item	2922796	et	4	main
essee	doc_881412446074_item	2922798	et	4	main
minu	doc_881412446074_item	2922799	et	3	main
alustan	doc_881412446074_item	2922801	et	3	main
ökoelu	doc_881412446074_item	2922805	et	4	main
sest	doc_881412446074_item	2922809	et	4	main
globalne	doc_881412446074_item	2922811	et	4	main
arusaamine	doc_881412446074_item	2922815	et	4	main
inimeste	doc_881412446074_item	2922816	et	3	main
näiteks	doc_881412446074_item	2922822	et	4	main
ei	doc_881412446074_item	2922830	et	4	main
selleks	doc_881412446074_item	2922835	et	4	main
on	doc_881412446074_item	2922843	et	4	main
iganes	doc_881412446074_item	2922850	et	4	main
visata	doc_881412446074_item	2922858	et	4	main
et	doc_881412446074_item	2922859	et	3	main
rohkem	doc_881412446074_item	2922863	et	4	main
kahju	doc_881412446074_item	2922864	et	4	main
pudelid	doc_881412446074_item	2922866	et	3	main
kas	doc_881412446074_item	2922867	et	3	main
plastmassist	doc_881412446074_item	2922868	et	3	main
või	doc_881412446074_item	2922869	et	4	main
kui	doc_881412446074_item	2922875	et	3	main
ma	doc_881412446074_item	2922876	et	3	main
olen	doc_881412446074_item	2922877	et	3	main
poes	doc_881412446074_item	2922878	et	3	main
selline	doc_881412446074_item	2922882	et	4	main
et	doc_881412446074_item	2922884	et	3	main
selle	doc_881412446074_item	2922885	et	4	main
pakendi	doc_881412446074_item	2922886	et	3	main
jooksul	doc_881412446074_item	2922923	et	4	main
kuus	doc_881412446074_item	2922941	et	4	main
see	doc_881412446074_item	2922947	et	3	main
kui	doc_881412446074_item	2922953	et	3	main
poes	doc_881412446074_item	2922955	et	3	main
kilekoti	doc_881412446074_item	2922957	et	3	main
ma	doc_881412446074_item	2922965	et	3	main
see	doc_881412446074_item	2922968	et	3	main
kõik	doc_881412446074_item	2922973	et	4	main
on	doc_881412446074_item	2922997	et	4	main
lihtsalt	doc_881412446074_item	2923003	et	4	main
loodussäästule	doc_881412446074_item	2923004	et	3	main
kasulik	doc_881412446074_item	2923005	et	3	main
ja	doc_881412446074_item	2923006	et	3	main
ei	doc_881412446074_item	2923014	et	4	main
sisalda	doc_881412446074_item	2923015	et	4	main
need	doc_881412446074_item	2923016	et	3	main
säilitusaineid	doc_881412446074_item	2923017	et	3	main
kui	doc_881412446074_item	2923018	et	3	main
ma	doc_881412446074_item	2923019	et	3	main
puhkan	doc_881412446074_item	2923020	et	3	main
päev	doc_881412446073_item	2922764	et	3	main
eestimaised	doc_881412446073_item	2922773	et	4	main
toidud	doc_881412446073_item	2922774	et	3	main
kas	doc_881412446073_item	2922776	et	3	main
kallim	doc_881412446073_item	2922777	et	4	main
sellest	doc_881412446074_item	2922802	et	4	main
see	doc_881412446074_item	2922810	et	3	main
on	doc_881412446074_item	2922818	et	4	main
mõned	doc_881412446074_item	2922823	et	3	main
viskavad	doc_881412446074_item	2922825	et	4	main
viitsi	doc_881412446074_item	2922831	et	4	main
natuke	doc_881412446074_item	2922832	et	4	main
et	doc_881412446074_item	2922836	et	3	main
viia	doc_881412446074_item	2922837	et	3	main
see	doc_881412446074_item	2922838	et	3	main
prügikasti	doc_881412446074_item	2922840	et	4	main
kui	doc_881412446074_item	2922841	et	3	main
mina	doc_881412446074_item	2922851	et	4	main
küll	doc_881412446074_item	2922852	et	4	main
koha	doc_881412446074_item	2922854	et	4	main
kus	doc_881412446074_item	2922855	et	3	main
teha	doc_881412446074_item	2922862	et	3	main
kõik	doc_881412446074_item	2922865	et	4	main
punkti	doc_881412446074_item	2922874	et	4	main
mul	doc_881412446074_item	2922879	et	3	main
tunne	doc_881412446074_item	2922883	et	4	main
asemel	doc_881412446074_item	2922887	et	4	main
piima	doc_881412446074_item	2922893	et	4	main
pudelites	doc_881412446074_item	2922895	et	3	main
et	doc_881412446074_item	2922896	et	3	main
teha	doc_881412446073_item	2922784	et	3	main
palju	doc_881412446073_item	2922790	et	4	main
et	doc_881412446074_item	2922803	et	3	main
jaoks	doc_881412446074_item	2922817	et	4	main
päris	doc_881412446074_item	2922819	et	4	main
hirmus	doc_881412446074_item	2922820	et	4	main
indiviidumid	doc_881412446074_item	2922824	et	4	main
prügi	doc_881412446074_item	2922826	et	4	main
läbi	doc_881412446074_item	2922827	et	4	main
akna	doc_881412446074_item	2922828	et	3	main
aega	doc_881412446074_item	2922833	et	4	main
taskus	doc_881412446074_item	2922845	et	3	main
väike	doc_881412446074_item	2922846	et	4	main
või	doc_881412446074_item	2922848	et	4	main
mis	doc_881412446074_item	2922849	et	4	main
mitte	doc_881412446074_item	2922861	et	3	main
mõnikord	doc_881412446074_item	2922881	et	3	main
varem	doc_881412446074_item	2922892	et	4	main
müüdi	doc_881412446074_item	2922894	et	4	main
looduse	doc_881412446074_item	2922897	et	4	main
mitte	doc_881412446074_item	2922898	et	3	main
saastama	doc_881412446074_item	2922899	et	3	main
ühesõnaga	doc_881412446074_item	2922900	et	3	main
liiga	doc_881412446074_item	2922901	et	4	main
palju	doc_881412446074_item	2922902	et	4	main
pakendeid	doc_881412446074_item	2922903	et	3	main
mida	doc_881412446074_item	2922904	et	4	main
ei	doc_881412446074_item	2922905	et	4	main
ole	doc_881412446074_item	2922906	et	4	main
vaja	doc_881412446074_item	2922907	et	4	main
päev	doc_881412446074_item	2922908	et	3	main
üksteist	doc_881412446074_item	2922910	et	4	main
postkasti	doc_881412446074_item	2922909	et	4	main
reklaami	doc_881412446074_item	2922911	et	4	main
tuleb	doc_881412446074_item	2922912	et	3	main
rekordarv	doc_881412446074_item	2922913	et	3	main
reklaame	doc_881412446074_item	2922914	et	3	main
neli	doc_881412446074_item	2922915	et	3	main
lehekest	doc_881412446074_item	2922916	et	4	main
kõik	doc_881412446074_item	2922917	et	4	main
heal	doc_881412446074_item	2922918	et	3	main
paberil	doc_881412446074_item	2922919	et	3	main
loen	doc_881412446074_item	2922920	et	3	main
kokku	doc_881412446074_item	2922926	et	3	main
on	doc_881412446074_item	2922929	et	4	main
paberi	doc_881412446074_item	2922930	et	3	main
selleta	doc_881412446074_item	2922935	et	3	main
palju	doc_881412446074_item	2922938	et	4	main
räägites	doc_881412446074_item	2922945	et	4	main
probleem	doc_881412446074_item	2922949	et	3	main
ole	doc_881412446074_item	2922961	et	4	main
aga	doc_881412446074_item	2922962	et	3	main
aga	doc_881412446074_item	2922972	et	3	main
eastimaine	doc_881412446074_item	2923007	et	4	main
toit	doc_881412446074_item	2923008	et	3	main
sest	doc_881412446074_item	2923011	et	4	main
tõenäosusega	doc_881412446074_item	2923013	et	3	main
sest	doc_881412446074_item	2923031	et	4	main
auto	doc_881412446074_item	2923045	et	4	main
nii	doc_881412446074_item	2923067	et	3	main
endale	doc_881412446074_item	2923069	et	4	main
te	doc_881412446074_item	2923082	et	4	main
sõita	doc_881412446074_item	2923094	et	3	main
ja	doc_881412446074_item	2923101	et	3	main
loodusele	doc_881412446074_item	2922860	et	4	main
viin	doc_881412446074_item	2922872	et	4	main
taara	doc_881412446074_item	2922873	et	4	main
võiks	doc_881412446074_item	2922888	et	4	main
olla	doc_881412446074_item	2922889	et	3	main
pudel	doc_881412446074_item	2922890	et	3	main
nagu	doc_881412446074_item	2922891	et	3	main
kahe	doc_881412446074_item	2922921	et	3	main
võiks	doc_881412446074_item	2922932	et	4	main
ju	doc_881412446074_item	2922933	et	3	main
mina	doc_881412446074_item	2922950	et	4	main
igakord	doc_881412446074_item	2922952	et	3	main
uue	doc_881412446074_item	2922956	et	3	main
kaasas	doc_881412446074_item	2922959	et	4	main
peaks	doc_881412446074_item	2922963	et	4	main
tean	doc_881412446074_item	2922966	et	3	main
et	doc_881412446074_item	2922967	et	3	main
on	doc_881412446074_item	2923009	et	4	main
suurema	doc_881412446074_item	2923012	et	4	main
teeme	doc_881412446074_item	2923028	et	3	main
korda	doc_881412446074_item	2923030	et	4	main
on	doc_881412446074_item	2923038	et	4	main
põhiline	doc_881412446074_item	2923039	et	3	main
autoga	doc_881412446074_item	2923044	et	3	main
võtab	doc_881412446074_item	2923046	et	3	main
artikli	doc_881412446074_item	2923056	et	3	main
koju	doc_881412446074_item	2923058	et	3	main
päris	doc_881412446074_item	2923059	et	4	main
m	doc_881412446074_item	2923064	et	4	main
endale	doc_881412446074_item	2923076	et	4	main
vaid	doc_881412446074_item	2923077	et	3	main
ette	doc_881412446074_item	2923078	et	4	main
seda	doc_881412446074_item	2923079	et	3	main
õnnist	doc_881412446074_item	2923080	et	4	main
enam	doc_881412446074_item	2923085	et	4	main
kunagi	doc_881412446074_item	2923086	et	3	main
riideid	doc_881412446074_item	2923087	et	3	main
alati	doc_881412446074_item	2923090	et	4	main
raadiokanalit	doc_881412446074_item	2923100	et	3	main
istuda	doc_881412446074_item	2923104	et	3	main
teil	doc_881412446074_item	2923114	et	4	main
pinkidel	doc_881412446074_item	2923124	et	3	main
lösutava	doc_881412446074_item	2923125	et	4	main
kamba	doc_881412446074_item	2923127	et	3	main
astu	doc_881412446074_item	2923132	et	4	main
oma	doc_881412446074_item	2923133	et	4	main
jõuad	doc_881412446074_item	2923153	et	3	main
võttes	doc_881412446074_item	2923155	et	4	main
kokku	doc_881412446074_item	2923156	et	3	main
aga	doc_881412446074_item	2923162	et	3	main
midagi	doc_881412446074_item	2923165	et	4	main
teha	doc_881412446074_item	2923166	et	3	main
loodust	doc_881412446074_item	2923170	et	4	main
peab	doc_881412446074_item	2923173	et	4	main
sellest	doc_881412446074_item	2923176	et	4	main
ootab	doc_881412446074_item	2923180	et	3	main
lapsi	doc_881412446074_item	2923189	et	4	main
raiskamine	doc_881412446074_item	2922931	et	4	main
milleks	doc_881412446074_item	2922936	et	4	main
on	doc_881412446074_item	2922942	et	4	main
piisavalt	doc_881412446074_item	2922943	et	4	main
kilekottidest	doc_881412446074_item	2922944	et	3	main
tõsine	doc_881412446074_item	2922948	et	4	main
ostan	doc_881412446074_item	2922951	et	3	main
sest	doc_881412446074_item	2922958	et	4	main
ie	doc_881412446074_item	2922960	et	4	main
õige	doc_881412446074_item	2922971	et	4	main
kätte	doc_881412446074_item	2922974	et	4	main
ei	doc_881412446074_item	2922975	et	4	main
mahu	doc_881412446074_item	2922976	et	4	main
pean	doc_881412446074_item	2922977	et	4	main
ikka	doc_881412446074_item	2922978	et	4	main
taskus	doc_881412446074_item	2922979	et	3	main
ühe	doc_881412446074_item	2922980	et	4	main
koti	doc_881412446074_item	2922981	et	3	main
omama	doc_881412446074_item	2922982	et	4	main
siis	doc_881412446074_item	2922983	et	3	main
läheb	doc_881412446074_item	2922984	et	3	main
paksuks	doc_881412446074_item	2922985	et	4	main
nali	doc_881412446074_item	2922986	et	3	main
kui	doc_881412446074_item	2922987	et	3	main
ajan	doc_881412446074_item	2922988	et	3	main
habet	doc_881412446074_item	2922989	et	3	main
siis	doc_881412446074_item	2922990	et	3	main
püüan	doc_881412446074_item	2922991	et	3	main
raisata	doc_881412446074_item	2922992	et	4	main
vett	doc_881412446074_item	2922993	et	3	main
nii	doc_881412446074_item	2922994	et	3	main
vähe	doc_881412446074_item	2922995	et	3	main
kui	doc_881412446074_item	2922996	et	3	main
võimalik	doc_881412446074_item	2922998	et	3	main
ostan	doc_881412446074_item	2922999	et	3	main
parim	doc_881412446074_item	2923010	et	4	main
looduses	doc_881412446074_item	2923021	et	4	main
ennem	doc_881412446074_item	2923023	et	4	main
seda	doc_881412446074_item	2923024	et	3	main
kui	doc_881412446074_item	2923025	et	3	main
sõidame	doc_881412446074_item	2923026	et	3	main
minema	doc_881412446074_item	2923027	et	3	main
kõik	doc_881412446074_item	2923029	et	4	main
nüüd	doc_881412446074_item	2923037	et	4	main
mis	doc_881412446074_item	2923041	et	4	main
raha	doc_881412446074_item	2923049	et	4	main
ühs	doc_881412446074_item	2923050	et	4	main
autor	doc_881412446074_item	2923051	et	3	main
riina	doc_881412446074_item	2923052	et	4	main
kirjutas	doc_881412446074_item	2923054	et	3	main
postimehes	doc_881412446074_item	2923055	et	3	main
küsis	doc_881412446074_item	2923062	et	3	main
ta	doc_881412446074_item	2923066	et	4	main
kaela	doc_881412446074_item	2923072	et	4	main
pilti	doc_881412446074_item	2923081	et	4	main
määri	doc_881412446074_item	2923084	et	4	main
teil	doc_881412446074_item	2923088	et	4	main
on	doc_881412446074_item	2923089	et	4	main
te	doc_881412446074_item	2923095	et	4	main
pea	doc_881412446074_item	2923097	et	4	main
kuulama	doc_881412446074_item	2923098	et	3	main
soovimatut	doc_881412446074_item	2923099	et	4	main
saate	doc_881412446074_item	2923102	et	4	main
te	doc_881412446074_item	2923105	et	4	main
hingematva	doc_881412446074_item	2923110	et	3	main
maksma	doc_881412446074_item	2923122	et	3	main
sõidurõõmu	doc_881412446074_item	2923128	et	4	main
ei	doc_881412446074_item	2923131	et	4	main
kunagi	doc_881412446074_item	2923135	et	3	main
kuseloiku	doc_881412446074_item	2923136	et	4	main
autoga	doc_881412446074_item	2923152	et	3	main
ma	doc_881412446074_item	2923163	et	3	main
suurest	doc_881412446074_item	2923177	et	4	main
meid	doc_881412446074_item	2923186	et	4	main
vaid	doc_881412446074_item	2923187	et	3	main
nad	doc_881412446074_item	2923191	et	3	main
elaksid	doc_881412446074_item	2923192	et	4	main
sellega	doc_881412446075_item	2923222	et	3	main
ja	doc_881412446075_item	2923225	et	3	main
kasutame	doc_881412446075_item	2923255	et	3	main
energiaallikaid	doc_881412446075_item	2923257	et	3	main
nafta	doc_881412446075_item	2923259	et	4	main
rast	doc_881412446075_item	2923264	et	4	main
lihtsam	doc_881412446075_item	2923268	et	4	main
meie	doc_881412446075_item	2923269	et	4	main
energia	doc_881412446075_item	2923273	et	4	main
tootmisel	doc_881412446075_item	2923274	et	4	main
valikut	doc_881412446075_item	2923284	et	3	main
sest	doc_881412446075_item	2923285	et	4	main
on	doc_881412446075_item	2923287	et	4	main
paljud	doc_881412446075_item	2923291	et	3	main
kutsuvad	doc_881412446075_item	2923293	et	4	main
nende	doc_881412446075_item	2923307	et	4	main
kütusekulu	doc_881412446075_item	2923315	et	4	main
co2	doc_881412446075_item	2923316	et	4	main
on	doc_881412446075_item	2923317	et	4	main
umbes	doc_881412446075_item	2923318	et	4	main
500	doc_881412446075_item	2923319	et	2	main
arvan	doc_881412446075_item	2923322	et	3	main
nemad	doc_881412446075_item	2923324	et	3	main
saa	doc_881412446075_item	2923338	et	4	main
kuidas	doc_881412446075_item	2923347	et	3	main
auto	doc_881412446075_item	2923351	et	4	main
keskonna	doc_881412446075_item	2923357	et	4	main
võimalust	doc_881412446075_item	2923372	et	3	main
aparatuuri	doc_881412446075_item	2923375	et	4	main
kasutab	doc_881412446075_item	2923377	et	3	main
päikeseenergiat	doc_881412446075_item	2923378	et	3	main
pole	doc_881412446075_item	2923379	et	3	main
võimalust	doc_881412446075_item	2923380	et	3	main
hind	doc_881412446075_item	2923381	et	3	main
on	doc_881412446075_item	2923382	et	4	main
90	doc_881412446075_item	2923390	et	2	main
ja	doc_881412446075_item	2923397	et	3	main
jätkub	doc_881412446075_item	2923399	et	3	main
kuni	doc_881412446075_item	2923402	et	3	main
mingi	doc_881412446075_item	2923404	et	4	main
siis	doc_881412446074_item	2923022	et	3	main
puhata	doc_881412446074_item	2923036	et	4	main
on	doc_881412446074_item	2923042	et	4	main
seotud	doc_881412446074_item	2923043	et	4	main
päris	doc_881412446074_item	2923047	et	4	main
palju	doc_881412446074_item	2923048	et	4	main
luik	doc_881412446074_item	2923053	et	3	main
loomavaguniga	doc_881412446074_item	2923057	et	4	main
ta	doc_881412446074_item	2923061	et	4	main
et	doc_881412446074_item	2923063	et	3	main
seda	doc_881412446074_item	2923070	et	3	main
ei	doc_881412446074_item	2923083	et	4	main
mõnus	doc_881412446074_item	2923093	et	4	main
isegi	doc_881412446074_item	2923106	et	4	main
ei	doc_881412446074_item	2923115	et	4	main
peate	doc_881412446074_item	2923121	et	4	main
ka	doc_881412446074_item	2923123	et	3	main
minu	doc_881412446074_item	2923138	et	3	main
arust	doc_881412446074_item	2923139	et	4	main
otsustada	doc_881412446074_item	2923148	et	3	main
kas	doc_881412446074_item	2923149	et	3	main
ökoelu	doc_881412446074_item	2923158	et	4	main
ei	doc_881412446074_item	2923159	et	4	main
ei	doc_881412446074_item	2923168	et	4	main
säästa	doc_881412446074_item	2923169	et	4	main
meie	doc_881412446074_item	2923188	et	4	main
on	doc_881412446075_item	2923221	et	4	main
spetsialistid	doc_881412446075_item	2923224	et	3	main
ütlevad	doc_881412446075_item	2923227	et	4	main
meile	doc_881412446075_item	2923228	et	4	main
kuidas	doc_881412446075_item	2923229	et	3	main
kasutasa	doc_881412446075_item	2923242	et	4	main
taastumatuid	doc_881412446075_item	2923243	et	4	main
energiaallikaid	doc_881412446075_item	2923244	et	3	main
tõepoolest	doc_881412446075_item	2923253	et	3	main
ä	doc_881412446075_item	2923263	et	4	main
riigis	doc_881412446075_item	2923270	et	3	main
osakaal	doc_881412446075_item	2923272	et	3	main
reostab	doc_881412446075_item	2923279	et	3	main
meil	doc_881412446075_item	2923282	et	4	main
lõpetada	doc_881412446075_item	2923294	et	3	main
millega	doc_881412446075_item	2923299	et	3	main
nad	doc_881412446075_item	2923300	et	3	main
mootori	doc_881412446075_item	2923308	et	3	main
math	doc_881412446075_item	2923309	et	4	main
elavad	doc_881412446075_item	2923330	et	4	main
öelda	doc_881412446075_item	2923339	et	4	main
on	doc_881412446075_item	2923342	et	4	main
mulle	doc_881412446075_item	2923348	et	4	main
sõidab	doc_881412446075_item	2923352	et	3	main
reostab	doc_881412446075_item	2923356	et	3	main
ei	doc_881412446075_item	2923369	et	4	main
valida	doc_881412446075_item	2923373	et	3	main
kõrge	doc_881412446075_item	2923384	et	4	main
olen	doc_881412446075_item	2923385	et	3	main
kindel	doc_881412446075_item	2923386	et	3	main
loomulikult	doc_881412446075_item	2923407	et	4	main
meie	doc_881412446075_item	2923412	et	4	main
ja	doc_881412446075_item	2923417	et	3	main
ainult	doc_881412446075_item	2923419	et	4	main
ja	doc_881412446074_item	2923092	et	3	main
ei	doc_881412446074_item	2923096	et	4	main
ei	doc_881412446074_item	2923107	et	4	main
enam	doc_881412446074_item	2923109	et	4	main
haisu	doc_881412446074_item	2923111	et	4	main
peale	doc_881412446074_item	2923112	et	4	main
ja	doc_881412446074_item	2923113	et	3	main
alati	doc_881412446074_item	2923103	et	4	main
mõtle	doc_881412446074_item	2923108	et	4	main
teki	doc_881412446074_item	2923116	et	4	main
enam	doc_881412446074_item	2923117	et	4	main
kunagi	doc_881412446074_item	2923118	et	3	main
tunnet	doc_881412446074_item	2923119	et	3	main
et	doc_881412446074_item	2923120	et	3	main
eest	doc_881412446074_item	2923129	et	4	main
te	doc_881412446074_item	2923130	et	4	main
autos	doc_881412446074_item	2923134	et	3	main
httpwwwpostimeesee011004esilehtarvamus146156php	doc_881412446074_item	2923137	et	4	main
tuleb	doc_881412446074_item	2923140	et	3	main
lihtsalt	doc_881412446074_item	2923141	et	4	main
arvestada	doc_881412446074_item	2923142	et	3	main
olukorraga	doc_881412446074_item	2923143	et	3	main
milles	doc_881412446074_item	2923144	et	3	main
oled	doc_881412446074_item	2923146	et	3	main
jälgsi	doc_881412446074_item	2923150	et	4	main
või	doc_881412446074_item	2923151	et	4	main
kohale	doc_881412446074_item	2923154	et	4	main
minu	doc_881412446074_item	2923157	et	3	main
ja	doc_881412446074_item	2923171	et	3	main
probleemist	doc_881412446074_item	2923178	et	4	main
mis	doc_881412446074_item	2923179	et	4	main
on	doc_881412446075_item	2923230	et	4	main
näiteks	doc_881412446075_item	2923245	et	4	main
hüdroenergiat	doc_881412446075_item	2923246	et	3	main
meie	doc_881412446075_item	2923254	et	4	main
p	doc_881412446075_item	2923262	et	4	main
umbes	doc_881412446075_item	2923276	et	4	main
91	doc_881412446075_item	2923277	et	2	main
see	doc_881412446075_item	2923278	et	3	main
ökoloogiat	doc_881412446075_item	2923280	et	3	main
aga	doc_881412446075_item	2923281	et	3	main
energiaallikas	doc_881412446075_item	2923290	et	4	main
poolitikud	doc_881412446075_item	2923292	et	3	main
saatama	doc_881412446075_item	2923295	et	4	main
loodust	doc_881412446075_item	2923296	et	4	main
tavaliselt	doc_881412446075_item	2923302	et	4	main
d	doc_881412446075_item	2923304	et	4	main
ja	doc_881412446075_item	2923305	et	3	main
mercedesid	doc_881412446075_item	2923306	et	4	main
vähemalt	doc_881412446075_item	2923311	et	4	main
liitrit	doc_881412446075_item	2923313	et	3	main
gkm	doc_881412446075_item	2923320	et	4	main
asotsiaalide	doc_881412446074_item	2923126	et	4	main
sa	doc_881412446074_item	2923145	et	3	main
ja	doc_881412446074_item	2923147	et	3	main
ole	doc_881412446074_item	2923160	et	4	main
ideaalne	doc_881412446074_item	2923161	et	3	main
püüan	doc_881412446074_item	2923164	et	3	main
selleks	doc_881412446074_item	2923167	et	4	main
igaüks	doc_881412446074_item	2923172	et	3	main
natuke	doc_881412446074_item	2923174	et	4	main
mõtlema	doc_881412446074_item	2923175	et	3	main
meid	doc_881412446074_item	2923181	et	4	main
tulevikus	doc_881412446074_item	2923182	et	4	main
võib	doc_881412446074_item	2923183	et	3	main
olla	doc_881412446074_item	2923184	et	3	main
mitte	doc_881412446074_item	2923185	et	3	main
et	doc_881412446074_item	2923190	et	3	main
sama	doc_881412446074_item	2923193	et	4	main
hästi	doc_881412446074_item	2923194	et	3	main
kui	doc_881412446074_item	2923195	et	3	main
meie	doc_881412446074_item	2923196	et	4	main
essee	doc_881412446075_item	2923197	et	4	main
minu	doc_881412446075_item	2923198	et	3	main
ökoelu	doc_881412446075_item	2923199	et	4	main
selles	doc_881412446075_item	2923200	et	4	main
essees	doc_881412446075_item	2923201	et	3	main
tahan	doc_881412446075_item	2923202	et	3	main
kirjutada	doc_881412446075_item	2923203	et	3	main
ökoelust	doc_881412446075_item	2923204	et	3	main
ja	doc_881412446075_item	2923205	et	3	main
proovin	doc_881412446075_item	2923206	et	3	main
kirjeldada	doc_881412446075_item	2923207	et	3	main
oma	doc_881412446075_item	2923208	et	4	main
elu	doc_881412446075_item	2923209	et	4	main
praegu	doc_881412446075_item	2923210	et	3	main
terve	doc_881412446075_item	2923211	et	4	main
euroopas	doc_881412446075_item	2923212	et	3	main
kõige	doc_881412446075_item	2923213	et	4	main
populaarsem	doc_881412446075_item	2923214	et	4	main
teema	doc_881412446075_item	2923215	et	4	main
on	doc_881412446075_item	2923216	et	4	main
ökoloogia	doc_881412446075_item	2923217	et	4	main
ja	doc_881412446075_item	2923218	et	3	main
kõik	doc_881412446075_item	2923219	et	4	main
mis	doc_881412446075_item	2923220	et	4	main
seotatud	doc_881412446075_item	2923223	et	4	main
professorid	doc_881412446075_item	2923226	et	3	main
mida	doc_881412446075_item	2923233	et	4	main
süüa	doc_881412446075_item	2923234	et	3	main
millega	doc_881412446075_item	2923235	et	3	main
sõita	doc_881412446075_item	2923236	et	3	main
ja	doc_881412446075_item	2923237	et	3	main
nii	doc_881412446075_item	2923238	et	3	main
edasi	doc_881412446075_item	2923239	et	3	main
teadlased	doc_881412446075_item	2923240	et	3	main
pakuvad	doc_881412446075_item	2923241	et	3	main
taastumatuid	doc_881412446075_item	2923256	et	4	main
maagaas	doc_881412446075_item	2923258	et	3	main
vaja	doc_881412446075_item	2923231	et	4	main
elada	doc_881412446075_item	2923232	et	3	main
tuuleenergiat	doc_881412446075_item	2923247	et	3	main
ja	doc_881412446075_item	2923248	et	3	main
päikeseenergiat	doc_881412446075_item	2923249	et	3	main
aga	doc_881412446075_item	2923250	et	3	main
mis	doc_881412446075_item	2923251	et	4	main
toimub	doc_881412446075_item	2923252	et	3	main
miks	doc_881412446075_item	2923260	et	4	main
selle	doc_881412446075_item	2923261	et	4	main
on	doc_881412446075_item	2923267	et	4	main
põlevkivi	doc_881412446075_item	2923271	et	4	main
vaatame	doc_881412446075_item	2923298	et	3	main
sõidavad	doc_881412446075_item	2923301	et	3	main
bmw	doc_881412446075_item	2923303	et	4	main
30	doc_881412446075_item	2923312	et	2	main
ja	doc_881412446075_item	2923314	et	3	main
mina	doc_881412446075_item	2923321	et	4	main
peavad	doc_881412446075_item	2923326	et	4	main
siis	doc_881412446075_item	2923333	et	3	main
et	doc_881412446075_item	2923340	et	3	main
minu	doc_881412446075_item	2923350	et	3	main
see	doc_881412446075_item	2923355	et	3	main
mulle	doc_881412446075_item	2923371	et	4	main
liiga	doc_881412446075_item	2923383	et	4	main
inimest	doc_881412446075_item	2923391	et	3	main
nii	doc_881412446075_item	2923393	et	3	main
nad	doc_881412446075_item	2923395	et	3	main
kaua	doc_881412446075_item	2923401	et	3	main
juhtub	doc_881412446075_item	2923403	et	3	main
ma	doc_881412446075_item	2923408	et	3	main
õigesti	doc_881412446075_item	2923416	et	3	main
kasutama	doc_881412446075_item	2923418	et	3	main
taastuvaid	doc_881412446075_item	2923420	et	4	main
minu	doc_881412446076_item	2923425	et	3	main
rohkemja	doc_881412446076_item	2923431	et	4	main
rohkem	doc_881412446076_item	2923432	et	4	main
keskonnasäästlikule	doc_881412446076_item	2923435	et	4	main
kuna	doc_881412446076_item	2923438	et	3	main
eest	doc_881412446076_item	2923443	et	4	main
ma	doc_881412446076_item	2923445	et	3	main
ei	doc_881412446076_item	2923446	et	4	main
eriline	doc_881412446076_item	2923453	et	4	main
eriti	doc_881412446076_item	2923455	et	3	main
mingi	doc_881412446076_item	2923499	et	4	main
tavaline	doc_881412446076_item	2923502	et	4	main
ja	doc_881412446076_item	2923506	et	3	main
niisama	doc_881412446076_item	2923511	et	3	main
kui	doc_881412446076_item	2923513	et	3	main
oleks	doc_881412446076_item	2923515	et	3	main
auto	doc_881412446076_item	2923517	et	4	main
ma	doc_881412446076_item	2923524	et	3	main
biokütuse	doc_881412446076_item	2923525	et	3	main
rohkem	doc_881412446076_item	2923528	et	4	main
kuid	doc_881412446076_item	2923530	et	4	main
on	doc_881412446076_item	2923540	et	4	main
ei	doc_881412446076_item	2923545	et	4	main
viiakuid	doc_881412446076_item	2923566	et	4	main
on	doc_881412446076_item	2923597	et	4	main
praegu	doc_881412446076_item	2923598	et	3	main
postil	doc_881412446076_item	2923602	et	3	main
tulevas	doc_881412446076_item	2923619	et	4	main
ma	doc_881412446076_item	2923621	et	3	main
uusi	doc_881412446076_item	2923623	et	3	main
rakendada	doc_881412446076_item	2923625	et	3	main
minu	doc_881412446076_item	2923629	et	3	main
keskonnakaitse	doc_881412446076_item	2923632	et	4	main
päaev	doc_881412446076_item	2923635	et	4	main
propageerimine	doc_881412446076_item	2923637	et	4	main
toob	doc_881412446076_item	2923638	et	3	main
inimkonna	doc_881412446076_item	2923639	et	4	main
sama	doc_881412446076_item	2923650	et	4	main
hästi	doc_881412446076_item	2923651	et	3	main
täna	doc_881412446076_item	2923653	et	4	main
hiljem	doc_881412446076_item	2923656	et	3	main
kõik	doc_881412446076_item	2923662	et	4	main
inimesed	doc_881412446076_item	2923663	et	3	main
suurem	doc_881412446077_item	2923668	et	4	main
osa	doc_881412446077_item	2923669	et	4	main
maaelanikust	doc_881412446077_item	2923670	et	3	main
alateadlikult	doc_881412446077_item	2923679	et	4	main
näideks	doc_881412446077_item	2923680	et	3	main
käitumise	doc_881412446077_item	2923682	et	4	main
et	doc_881412446077_item	2923686	et	3	main
viskavad	doc_881412446077_item	2923695	et	4	main
on	doc_881412446077_item	2923709	et	4	main
võimalik	doc_881412446077_item	2923710	et	3	main
eeldada	doc_881412446077_item	2923711	et	3	main
iseseisvalt	doc_881412446077_item	2923730	et	4	main
eriliselt	doc_881412446077_item	2923743	et	4	main
et	doc_881412446075_item	2923265	et	3	main
see	doc_881412446075_item	2923266	et	3	main
on	doc_881412446075_item	2923275	et	4	main
pole	doc_881412446075_item	2923283	et	3	main
see	doc_881412446075_item	2923286	et	3	main
ainsus	doc_881412446075_item	2923288	et	4	main
effektiivne	doc_881412446075_item	2923289	et	4	main
aga	doc_881412446075_item	2923297	et	3	main
on	doc_881412446075_item	2923310	et	4	main
et	doc_881412446075_item	2923323	et	3	main
alguseks	doc_881412446075_item	2923325	et	4	main
vaatama	doc_881412446075_item	2923327	et	3	main
kuidas	doc_881412446075_item	2923328	et	3	main
ise	doc_881412446075_item	2923329	et	4	main
ainult	doc_881412446075_item	2923332	et	4	main
nõustama	doc_881412446075_item	2923335	et	3	main
mina	doc_881412446075_item	2923336	et	4	main
ei	doc_881412446075_item	2923337	et	4	main
meeldib	doc_881412446075_item	2923349	et	3	main
diisli	doc_881412446075_item	2923353	et	3	main
anna	doc_881412446075_item	2923370	et	4	main
rohkem	doc_881412446075_item	2923388	et	4	main
elavad	doc_881412446075_item	2923392	et	4	main
see	doc_881412446075_item	2923398	et	3	main
nii	doc_881412446075_item	2923400	et	3	main
loodan	doc_881412446075_item	2923409	et	3	main
varsti	doc_881412446075_item	2923413	et	3	main
hakkame	doc_881412446075_item	2923414	et	3	main
essee	doc_881412446076_item	2923424	et	4	main
kuna	doc_881412446076_item	2923427	et	3	main
püüan	doc_881412446076_item	2923439	et	3	main
hoolitseda	doc_881412446076_item	2923441	et	3	main
on	doc_881412446076_item	2923469	et	4	main
ammu	doc_881412446076_item	2923471	et	4	main
panditaarana	doc_881412446076_item	2923481	et	3	main
on	doc_881412446076_item	2923483	et	4	main
nii	doc_881412446076_item	2923485	et	3	main
ka	doc_881412446076_item	2923488	et	3	main
minule	doc_881412446076_item	2923489	et	3	main
iga	doc_881412446076_item	2923491	et	4	main
armastab	doc_881412446076_item	2923493	et	3	main
looduses	doc_881412446076_item	2923494	et	4	main
suvel	doc_881412446076_item	2923495	et	3	main
viibida	doc_881412446076_item	2923496	et	3	main
kamina	doc_881412446076_item	2923497	et	3	main
pole	doc_881412446076_item	2923498	et	3	main
plastik	doc_881412446076_item	2923503	et	3	main
püüa	doc_881412446076_item	2923507	et	4	main
seda	doc_881412446076_item	2923510	et	3	main
kahjuks	doc_881412446076_item	2923531	et	4	main
mida	doc_881412446076_item	2923543	et	4	main
tuleb	doc_881412446076_item	2923551	et	3	main
seda	doc_881412446076_item	2923552	et	3	main
teha	doc_881412446076_item	2923553	et	3	main
pean	doc_881412446076_item	2923554	et	4	main
mõistlikum	doc_881412446076_item	2923567	et	4	main
oleks	doc_881412446076_item	2923568	et	3	main
anda	doc_881412446076_item	2923569	et	3	main
seda	doc_881412446076_item	2923570	et	3	main
igal	doc_881412446076_item	2923601	et	3	main
ülikoolis	doc_881412446076_item	2923603	et	4	main
erilise	doc_881412446076_item	2923605	et	4	main
erialagaet	doc_881412446076_item	2923620	et	4	main
ja	doc_881412446075_item	2923331	et	3	main
midagi	doc_881412446075_item	2923334	et	4	main
mul	doc_881412446075_item	2923341	et	3	main
ökoelu	doc_881412446075_item	2923343	et	4	main
ma	doc_881412446075_item	2923344	et	3	main
elan	doc_881412446075_item	2923345	et	3	main
nii	doc_881412446075_item	2923346	et	3	main
kütusega	doc_881412446075_item	2923354	et	3	main
rohkem	doc_881412446075_item	2923358	et	4	main
kui	doc_881412446075_item	2923359	et	3	main
bensiin	doc_881412446075_item	2923360	et	3	main
aga	doc_881412446075_item	2923361	et	3	main
kasulikum	doc_881412446075_item	2923362	et	4	main
kasutan	doc_881412446075_item	2923363	et	3	main
taastumatuid	doc_881412446075_item	2923364	et	4	main
energiaallikaid	doc_881412446075_item	2923365	et	3	main
sest	doc_881412446075_item	2923366	et	4	main
eesti	doc_881412446075_item	2923367	et	4	main
energia	doc_881412446075_item	2923368	et	4	main
osta	doc_881412446075_item	2923374	et	4	main
mis	doc_881412446075_item	2923376	et	4	main
et	doc_881412446075_item	2923387	et	3	main
kui	doc_881412446075_item	2923389	et	3	main
nagu	doc_881412446075_item	2923394	et	3	main
tahavad	doc_881412446075_item	2923396	et	3	main
maailma	doc_881412446075_item	2923405	et	4	main
katastroof	doc_881412446075_item	2923406	et	3	main
kõik	doc_881412446075_item	2923411	et	4	main
elama	doc_881412446075_item	2923415	et	3	main
tähelepanu	doc_881412446076_item	2923433	et	4	main
eluviisile	doc_881412446076_item	2923436	et	3	main
ka	doc_881412446076_item	2923440	et	3	main
ole	doc_881412446076_item	2923460	et	4	main
prügiämbressevaid	doc_881412446076_item	2923478	et	4	main
anan	doc_881412446076_item	2923479	et	4	main
tagasi	doc_881412446076_item	2923480	et	3	main
teiseks	doc_881412446076_item	2923490	et	4	main
meist	doc_881412446076_item	2923492	et	3	main
et	doc_881412446076_item	2923501	et	3	main
ei	doc_881412446076_item	2923504	et	4	main
jäta	doc_881412446076_item	2923509	et	4	main
valiksin	doc_881412446076_item	2923523	et	3	main
see	doc_881412446076_item	2923526	et	3	main
mitte	doc_881412446076_item	2923532	et	3	main
minu	doc_881412446076_item	2923533	et	3	main
rahakottiloodan	doc_881412446076_item	2923534	et	4	main
ma	doc_881412446076_item	2923544	et	3	main
tee	doc_881412446076_item	2923546	et	4	main
pidevalt	doc_881412446076_item	2923547	et	4	main
aga	doc_881412446076_item	2923548	et	3	main
aeg	doc_881412446076_item	2923549	et	3	main
külmkapide	doc_881412446076_item	2923556	et	4	main
kindlasti	doc_881412446076_item	2923561	et	3	main
võimalik	doc_881412446076_item	2923562	et	3	main
ümbertöötlemisele	doc_881412446076_item	2923571	et	3	main
toon	doc_881412446076_item	2923572	et	4	main
keskonnasäästliku	doc_881412446076_item	2923610	et	4	main
tootmist	doc_881412446076_item	2923611	et	4	main
ehitamist	doc_881412446076_item	2923613	et	4	main
on	doc_881412446076_item	2923615	et	4	main
otselt	doc_881412446076_item	2923616	et	3	main
seotud	doc_881412446076_item	2923617	et	4	main
minu	doc_881412446076_item	2923618	et	3	main
kasvab	doc_881412446076_item	2923631	et	3	main
tähtsus	doc_881412446076_item	2923633	et	4	main
teadvusi	doc_881412446076_item	2923640	et	4	main
on	doc_881412446076_item	2923642	et	4	main
sellest	doc_881412446076_item	2923660	et	4	main
ei	doc_881412446077_item	2923671	et	4	main
aru	doc_881412446077_item	2923674	et	4	main
hävitavad	doc_881412446077_item	2923677	et	4	main
olla	doc_881412446077_item	2923684	et	3	main
asemel	doc_881412446077_item	2923689	et	4	main
ei	doc_881412446077_item	2923702	et	4	main
võimalik	doc_881412446077_item	2923704	et	3	main
rohkem	doc_881412446077_item	2923721	et	4	main
rohkem	doc_881412446077_item	2923723	et	4	main
tulevikkus	doc_881412446077_item	2923728	et	4	main
peavad	doc_881412446077_item	2923733	et	4	main
sellel	doc_881412446077_item	2923744	et	4	main
teise	doc_881412446077_item	2923751	et	4	main
sõnadega	doc_881412446077_item	2923752	et	3	main
kõik	doc_881412446077_item	2923754	et	4	main
miks	doc_881412446077_item	2923758	et	4	main
ma	doc_881412446077_item	2923759	et	3	main
peavad	doc_881412446077_item	2923781	et	4	main
inimesed	doc_881412446077_item	2923806	et	3	main
arv	doc_881412446077_item	2923808	et	3	main
mina	doc_881412446077_item	2923815	et	4	main
maha	doc_881412446077_item	2923822	et	4	main
ajamata	doc_881412446077_item	2923823	et	4	main
kui	doc_881412446077_item	2923824	et	3	main
ka	doc_881412446077_item	2923825	et	3	main
jälgivad	doc_881412446077_item	2923826	et	4	main
ja	doc_881412446077_item	2923831	et	3	main
kadunud	doc_881412446077_item	2923833	et	4	main
loomad	doc_881412446077_item	2923834	et	3	main
toitu	doc_881412446077_item	2923849	et	4	main
ja	doc_881412446077_item	2923851	et	3	main
olemas	doc_881412446077_item	2923858	et	4	main
palju	doc_881412446077_item	2923859	et	4	main
et	doc_881412446075_item	2923410	et	3	main
energiaallikaid	doc_881412446075_item	2923421	et	3	main
optimist	doc_881412446075_item	2923423	et	3	main
ökoelu	doc_881412446076_item	2923426	et	4	main
tänapäeval	doc_881412446076_item	2923428	et	3	main
üha	doc_881412446076_item	2923429	et	3	main
ja	doc_881412446076_item	2923430	et	3	main
keskkonna	doc_881412446076_item	2923442	et	3	main
kuid	doc_881412446076_item	2923444	et	4	main
näiteks	doc_881412446076_item	2923461	et	4	main
mis	doc_881412446076_item	2923462	et	4	main
puudutab	doc_881412446076_item	2923463	et	3	main
minu	doc_881412446076_item	2923464	et	3	main
olmeelu	doc_881412446076_item	2923465	et	4	main
siis	doc_881412446076_item	2923466	et	3	main
minu	doc_881412446076_item	2923467	et	3	main
harjumuseks	doc_881412446076_item	2923468	et	4	main
saanud	doc_881412446076_item	2923472	et	4	main
prügi	doc_881412446076_item	2923473	et	4	main
sorteeriminepudeleid	doc_881412446076_item	2923474	et	4	main
sellest	doc_881412446076_item	2923482	et	4	main
langune	doc_881412446076_item	2923505	et	4	main
vedelema	doc_881412446076_item	2923512	et	4	main
mul	doc_881412446076_item	2923514	et	3	main
ome	doc_881412446076_item	2923516	et	4	main
ja	doc_881412446076_item	2923518	et	3	main
oleks	doc_881412446076_item	2923519	et	3	main
kütesevaliku	doc_881412446076_item	2923520	et	4	main
siis	doc_881412446076_item	2923522	et	3	main
olen	doc_881412446075_item	2923422	et	3	main
pööratakse	doc_881412446076_item	2923434	et	3	main
siis	doc_881412446076_item	2923437	et	3	main
saa	doc_881412446076_item	2923447	et	4	main
öelda	doc_881412446076_item	2923448	et	4	main
et	doc_881412446076_item	2923449	et	3	main
minust	doc_881412446076_item	2923450	et	3	main
on	doc_881412446076_item	2923451	et	4	main
mingi	doc_881412446076_item	2923452	et	4	main
kasu	doc_881412446076_item	2923454	et	4	main
kahju	doc_881412446076_item	2923456	et	4	main
minust	doc_881412446076_item	2923457	et	3	main
ka	doc_881412446076_item	2923458	et	3	main
ei	doc_881412446076_item	2923459	et	4	main
juba	doc_881412446076_item	2923470	et	3	main
ei	doc_881412446076_item	2923475	et	4	main
viska	doc_881412446076_item	2923476	et	4	main
mina	doc_881412446076_item	2923477	et	4	main
kasu	doc_881412446076_item	2923484	et	4	main
keskonnale	doc_881412446076_item	2923486	et	4	main
kui	doc_881412446076_item	2923487	et	3	main
erandtean	doc_881412446076_item	2923500	et	4	main
mitte	doc_881412446076_item	2923508	et	3	main
võimalus	doc_881412446076_item	2923521	et	3	main
et	doc_881412446076_item	2923535	et	3	main
hinnad	doc_881412446076_item	2923537	et	3	main
ka	doc_881412446076_item	2923539	et	3	main
asjad	doc_881412446076_item	2923542	et	3	main
silmas	doc_881412446076_item	2923555	et	4	main
gaasiplitide	doc_881412446076_item	2923558	et	4	main
on	doc_881412446076_item	2923560	et	4	main
prügikastid	doc_881412446076_item	2923599	et	3	main
puudutavad	doc_881412446076_item	2923609	et	4	main
mis	doc_881412446076_item	2923614	et	4	main
viia	doc_881412446076_item	2923628	et	3	main
arust	doc_881412446076_item	2923630	et	4	main
kui	doc_881412446076_item	2923652	et	3	main
loodan	doc_881412446076_item	2923654	et	3	main
või	doc_881412446076_item	2923657	et	4	main
varem	doc_881412446076_item	2923658	et	4	main
saavad	doc_881412446076_item	2923659	et	4	main
sellel	doc_881412446076_item	2923664	et	4	main
planedil	doc_881412446076_item	2923665	et	4	main
ökoelu	doc_881412446077_item	2923667	et	4	main
loodust	doc_881412446077_item	2923673	et	4	main
ja	doc_881412446077_item	2923676	et	3	main
teda	doc_881412446077_item	2923678	et	4	main
see	doc_881412446077_item	2923685	et	3	main
prügikasti	doc_881412446077_item	2923692	et	4	main
viskama	doc_881412446077_item	2923693	et	3	main
nad	doc_881412446077_item	2923694	et	3	main
nii	doc_881412446077_item	2923701	et	3	main
esimene	doc_881412446077_item	2923712	et	3	main
inimlaiskus	doc_881412446077_item	2923716	et	4	main
läbimurre	doc_881412446077_item	2923718	et	4	main
sajandis	doc_881412446077_item	2923719	et	3	main
inimesed	doc_881412446077_item	2923720	et	3	main
võib	doc_881412446077_item	2923727	et	3	main
nad	doc_881412446077_item	2923732	et	3	main
nuppu	doc_881412446077_item	2923735	et	4	main
teine	doc_881412446077_item	2923737	et	3	main
olla	doc_881412446077_item	2923740	et	3	main
kasvatamise	doc_881412446077_item	2923741	et	4	main
harjusid	doc_881412446077_item	2923747	et	4	main
olemas	doc_881412446077_item	2923777	et	4	main
rohkem	doc_881412446077_item	2923810	et	4	main
kui	doc_881412446077_item	2923811	et	3	main
nende	doc_881412446077_item	2923812	et	4	main
pidavad	doc_881412446077_item	2923817	et	4	main
korda	doc_881412446077_item	2923818	et	4	main
et	doc_881412446077_item	2923827	et	3	main
raiuti	doc_881412446077_item	2923829	et	3	main
ramatuses	doc_881412446077_item	2923838	et	4	main
kas	doc_881412446077_item	2923839	et	3	main
ainult	doc_881412446077_item	2923853	et	4	main
ohtlik	doc_881412446077_item	2923872	et	3	main
aastade	doc_881412446077_item	2923882	et	4	main
aga	doc_881412446077_item	2923884	et	3	main
või	doc_881412446077_item	2923887	et	4	main
võib	doc_881412446077_item	2923892	et	3	main
ma	doc_881412446077_item	2923931	et	3	main
et	doc_881412446077_item	2923933	et	3	main
mõtega	doc_881412446077_item	2923935	et	4	main
ma	doc_881412446077_item	2923936	et	3	main
pean	doc_881412446077_item	2923937	et	4	main
inimestele	doc_881412446077_item	2923942	et	3	main
ela	doc_881412446077_item	2923952	et	4	main
kultuuriloost	doc_887959124398_item	2923957	et	4	main
mida	doc_887959124398_item	2923959	et	4	main
tähendab	doc_887959124398_item	2923960	et	3	main
saastaks	doc_881412446076_item	2923527	et	4	main
ökosüsteemi	doc_881412446076_item	2923529	et	4	main
tulevikus	doc_881412446076_item	2923536	et	4	main
langevad	doc_881412446076_item	2923538	et	4	main
üksikud	doc_881412446076_item	2923541	et	3	main
ajalt	doc_881412446076_item	2923550	et	4	main
ja	doc_881412446076_item	2923557	et	3	main
ümbertöötlemist	doc_881412446076_item	2923559	et	3	main
seda	doc_881412446076_item	2923563	et	3	main
lihsalt	doc_881412446076_item	2923564	et	4	main
prügilasse	doc_881412446076_item	2923565	et	4	main
ühe	doc_881412446076_item	2923573	et	4	main
näide	doc_881412446076_item	2923574	et	3	main
igapäevases	doc_881412446076_item	2923575	et	4	main
elus	doc_881412446076_item	2923576	et	4	main
kui	doc_881412446076_item	2923577	et	3	main
ma	doc_881412446076_item	2923578	et	3	main
pesen	doc_881412446076_item	2923579	et	3	main
hambaid	doc_881412446076_item	2923580	et	3	main
siis	doc_881412446076_item	2923581	et	3	main
lülitan	doc_881412446076_item	2923582	et	3	main
vett	doc_881412446076_item	2923583	et	3	main
et	doc_881412446076_item	2923584	et	3	main
ei	doc_881412446076_item	2923585	et	4	main
raisaks	doc_881412446076_item	2923586	et	3	main
lisavett	doc_881412446076_item	2923587	et	3	main
tänaval	doc_881412446076_item	2923588	et	4	main
ma	doc_881412446076_item	2923589	et	3	main
kunagi	doc_881412446076_item	2923590	et	3	main
ei	doc_881412446076_item	2923591	et	4	main
viska	doc_881412446076_item	2923592	et	4	main
pabereid	doc_881412446076_item	2923593	et	3	main
pudeleid	doc_881412446076_item	2923594	et	3	main
maha	doc_881412446076_item	2923595	et	4	main
õnneks	doc_881412446076_item	2923596	et	4	main
peaaegu	doc_881412446076_item	2923600	et	3	main
ma	doc_881412446076_item	2923604	et	3	main
huuviga	doc_881412446076_item	2923606	et	4	main
õpin	doc_881412446076_item	2923607	et	3	main
ainedmis	doc_881412446076_item	2923608	et	4	main
ja	doc_881412446076_item	2923612	et	3	main
ja	doc_881412446076_item	2923626	et	3	main
sele	doc_881412446076_item	2923636	et	4	main
et	doc_881412446076_item	2923641	et	3	main
hoolitseda	doc_881412446076_item	2923644	et	3	main
ökoloogia	doc_881412446076_item	2923645	et	4	main
eest	doc_881412446076_item	2923646	et	4	main
et	doc_881412446076_item	2923647	et	3	main
homme	doc_881412446076_item	2923648	et	3	main
elaks	doc_881412446076_item	2923649	et	3	main
essee	doc_881412446077_item	2923666	et	4	main
selle	doc_881412446077_item	2923681	et	4	main
võib	doc_881412446077_item	2923683	et	3	main
selle	doc_881412446077_item	2923688	et	4	main
et	doc_881412446077_item	2923690	et	3	main
prahti	doc_881412446077_item	2923691	et	4	main
saada	doc_881412446077_item	2923707	et	4	main
aga	doc_881412446077_item	2923708	et	3	main
võib	doc_881412446077_item	2923714	et	3	main
arvavad	doc_881412446077_item	2923724	et	4	main
et	doc_881412446077_item	2923725	et	3	main
toimuda	doc_881412446077_item	2923729	et	3	main
ainult	doc_881412446077_item	2923734	et	4	main
puudumine	doc_881412446077_item	2923742	et	4	main
teha	doc_881412446077_item	2923748	et	3	main
prahti	doc_881412446077_item	2923756	et	4	main
maha	doc_881412446077_item	2923757	et	4	main
prügikasti	doc_881412446077_item	2923763	et	4	main
millega	doc_881412446077_item	2923764	et	3	main
ma	doc_881412446077_item	2923765	et	3	main
olen	doc_881412446077_item	2923766	et	3	main
teised	doc_881412446077_item	2923769	et	4	main
paljud	doc_881412446077_item	2923771	et	3	main
loodavad	doc_881412446077_item	2923773	et	4	main
koristajad	doc_881412446077_item	2923778	et	4	main
kellest	doc_881412446077_item	2923813	et	4	main
rääkis	doc_881412446077_item	2923814	et	3	main
mitte	doc_881412446077_item	2923819	et	3	main
ei	doc_881412446077_item	2923832	et	4	main
on	doc_881412446077_item	2923842	et	4	main
ökoelu	doc_881412446077_item	2923843	et	4	main
ökoelule	doc_881412446077_item	2923844	et	3	main
ka	doc_881412446077_item	2923845	et	3	main
sõltub	doc_881412446077_item	2923846	et	3	main
normaalse	doc_881412446077_item	2923847	et	3	main
ökoloogilise	doc_881412446077_item	2923848	et	4	main
ei	doc_881412446077_item	2923864	et	4	main
täielikkult	doc_881412446077_item	2923866	et	4	main
olla	doc_881412446077_item	2923871	et	3	main
endale	doc_881412446077_item	2923874	et	4	main
kes	doc_881412446077_item	2923876	et	4	main
täiskasvanutele	doc_881412446077_item	2923878	et	3	main
paar-kolm	doc_881412446077_item	2923881	et	3	main
pärast	doc_881412446077_item	2923883	et	4	main
toimuda	doc_881412446077_item	2923893	et	3	main
geen	doc_881412446077_item	2923895	et	3	main
fantastilise	doc_881412446077_item	2923921	et	4	main
peatuma	doc_881412446077_item	2923938	et	4	main
ja	doc_881412446077_item	2923939	et	3	main
ökoeluga	doc_881412446077_item	2923953	et	3	main
kontrolltöö	doc_887959124398_item	2923954	et	4	main
kontrolltöö	doc_887959124398_item	2923955	et	4	main
1	doc_887959124398_item	2923958	et	2	main
2	doc_887959124398_item	2923963	et	2	main
millega	doc_887959124398_item	2923964	et	3	main
tegeles	doc_887959124398_item	2923965	et	3	main
õpetatud	doc_887959124398_item	2923966	et	4	main
nende	doc_887959124398_item	2923983	et	4	main
huviobjektiks	doc_887959124398_item	2923984	et	3	main
õpetatud	doc_887959124398_item	2923991	et	4	main
ta	doc_887959124398_item	2924022	et	4	main
kalevipoja	doc_887959124398_item	2924030	et	4	main
ettekandena	doc_887959124398_item	2924034	et	3	main
seltsis	doc_887959124398_item	2924037	et	4	main
aastal	doc_887959124398_item	2924042	et	3	main
üle	doc_887959124398_item	2924049	et	3	main
saaks	doc_881412446076_item	2923622	et	3	main
tehnoloogiaid	doc_881412446076_item	2923624	et	3	main
ellu	doc_881412446076_item	2923627	et	4	main
iga	doc_881412446076_item	2923634	et	4	main
vaja	doc_881412446076_item	2923643	et	4	main
et	doc_881412446076_item	2923655	et	3	main
aru	doc_881412446076_item	2923661	et	4	main
saa	doc_881412446077_item	2923672	et	4	main
saada	doc_881412446077_item	2923675	et	4	main
inimesed	doc_881412446077_item	2923687	et	3	main
prahti	doc_881412446077_item	2923696	et	4	main
maha	doc_881412446077_item	2923697	et	4	main
miks	doc_881412446077_item	2923698	et	4	main
nad	doc_881412446077_item	2923699	et	3	main
teevad	doc_881412446077_item	2923700	et	3	main
ole	doc_881412446077_item	2923703	et	4	main
küsimuseta	doc_881412446077_item	2923705	et	4	main
aru	doc_881412446077_item	2923706	et	4	main
võimalus	doc_881412446077_item	2923713	et	3	main
olla	doc_881412446077_item	2923715	et	3	main
tehnoloogilise	doc_881412446077_item	2923717	et	4	main
ja	doc_881412446077_item	2923722	et	3	main
kõik	doc_881412446077_item	2923726	et	4	main
aga	doc_881412446077_item	2923731	et	3	main
vajutama	doc_881412446077_item	2923736	et	4	main
põhjus	doc_881412446077_item	2923738	et	4	main
võib	doc_881412446077_item	2923739	et	3	main
inimestel	doc_881412446077_item	2923745	et	3	main
kes	doc_881412446077_item	2923746	et	4	main
teised	doc_881412446077_item	2923750	et	4	main
nii	doc_881412446077_item	2923753	et	3	main
viskavad	doc_881412446077_item	2923755	et	4	main
pean	doc_881412446077_item	2923760	et	4	main
viskada	doc_881412446077_item	2923761	et	4	main
seda	doc_881412446077_item	2923762	et	3	main
kui	doc_881412446077_item	2923768	et	3	main
ka	doc_881412446077_item	2923770	et	3	main
võib-olla	doc_881412446077_item	2923772	et	3	main
koristajale	doc_881412446077_item	2923774	et	4	main
kui	doc_881412446077_item	2923775	et	3	main
on	doc_881412446077_item	2923776	et	4	main
nad	doc_881412446077_item	2923780	et	3	main
puhtust	doc_881412446077_item	2923783	et	4	main
hoidma	doc_881412446077_item	2923784	et	3	main
aga	doc_881412446077_item	2923785	et	3	main
koristajad	doc_881412446077_item	2923786	et	4	main
ka	doc_881412446077_item	2923787	et	3	main
inimesed	doc_881412446077_item	2923788	et	3	main
misjuures	doc_881412446077_item	2923789	et	3	main
samasuguse	doc_881412446077_item	2923790	et	3	main
statusega	doc_881412446077_item	2923791	et	4	main
miks	doc_881412446077_item	2923792	et	4	main
nad	doc_881412446077_item	2923793	et	3	main
alati	doc_881412446077_item	2923795	et	4	main
teiste	doc_881412446077_item	2923796	et	4	main
peavad	doc_881412446077_item	2923794	et	4	main
eest	doc_881412446077_item	2923797	et	4	main
koristama	doc_881412446077_item	2923798	et	3	main
nad	doc_881412446077_item	2923799	et	3	main
pole	doc_881412446077_item	2923800	et	3	main
orjad	doc_881412446077_item	2923801	et	4	main
ja	doc_881412446077_item	2923802	et	3	main
pole	doc_881412446077_item	2923803	et	3	main
teenistuses	doc_881412446077_item	2923804	et	3	main
teised	doc_881412446077_item	2923805	et	4	main
kui	doc_881412446077_item	2923749	et	3	main
halvem	doc_881412446077_item	2923767	et	4	main
siis	doc_881412446077_item	2923779	et	3	main
tänavate	doc_881412446077_item	2923782	et	4	main
kelle	doc_881412446077_item	2923807	et	4	main
on	doc_881412446077_item	2923809	et	4	main
varem	doc_881412446077_item	2923816	et	4	main
ainult	doc_881412446077_item	2923820	et	4	main
prahti	doc_881412446077_item	2923821	et	4	main
ei	doc_881412446077_item	2923828	et	4	main
metsa	doc_881412446077_item	2923830	et	4	main
kes	doc_881412446077_item	2923835	et	4	main
asuvad	doc_881412446077_item	2923836	et	4	main
punases	doc_881412446077_item	2923837	et	4	main
toitmine	doc_881412446077_item	2923850	et	4	main
mitte	doc_881412446077_item	2923852	et	3	main
keskkonnast	doc_881412446077_item	2923854	et	4	main
hoolitsemine	doc_881412446077_item	2923855	et	4	main
praegu	doc_881412446077_item	2923856	et	3	main
toite	doc_881412446077_item	2923861	et	4	main
mille	doc_881412446077_item	2923862	et	3	main
ja	doc_881412446077_item	2923868	et	3	main
sellepärast	doc_881412446077_item	2923869	et	3	main
suurustele	doc_881412446077_item	2923879	et	4	main
kogu	doc_881412446077_item	2923928	et	4	main
selle	doc_881412446077_item	2923934	et	4	main
võimalus	doc_881412446077_item	2923941	et	3	main
ei	doc_881412446077_item	2923951	et	4	main
eesti	doc_887959124398_item	2923956	et	4	main
kuulusid	doc_887959124398_item	2923972	et	4	main
2	doc_887959124398_item	2923973	et	2	main
algatusel	doc_887959124398_item	2923982	et	4	main
ja	doc_887959124398_item	2923989	et	3	main
kultuur	doc_887959124398_item	2923990	et	3	main
eeskujuks	doc_887959124398_item	2924021	et	3	main
võttis	doc_887959124398_item	2924023	et	3	main
kalevala	doc_887959124398_item	2924027	et	4	main
esitas	doc_887959124398_item	2924032	et	3	main
pärast	doc_887959124398_item	2924038	et	4	main
kalevipja	doc_887959124398_item	2924043	et	4	main
ões-i	doc_887959124398_item	2924046	et	4	main
kreutzwald	doc_887959124398_item	2924050	et	4	main
eeposest	doc_887959124398_item	2924052	et	4	main
sai	doc_887959124398_item	2924053	et	4	main
ja	doc_887959124398_item	2924057	et	3	main
väga	doc_887959124398_item	2924060	et	3	main
mis	doc_887959124398_item	2924071	et	4	main
populaarsed	doc_887959124398_item	2924078	et	3	main
kuid	doc_887959124398_item	2924095	et	4	main
kreutzwald	doc_887959124398_item	2924102	et	4	main
nad	doc_887959124398_item	2924122	et	3	main
kõrgem-ametnikud	doc_887959124398_item	2924124	et	3	main
ka	doc_887959124398_item	2924127	et	3	main
olid	doc_887959124398_item	2924128	et	4	main
tahtis	doc_887959124398_item	2924137	et	3	main
olnud	doc_887959124398_item	2924141	et	4	main
tema	doc_887959124398_item	2924142	et	4	main
tsaari	doc_887959124398_item	2924146	et	4	main
ta	doc_887959124398_item	2924156	et	4	main
viis	doc_887959124398_item	2924157	et	4	main
läbi	doc_887959124398_item	2924158	et	4	main
reformi	doc_887959124398_item	2924160	et	4	main
baltisakslaste	doc_887959124398_item	2924161	et	4	main
privileegid	doc_887959124398_item	2924162	et	3	main
inglise	doc_897182025870_item	2924200	et	4	main
on	doc_897182025870_item	2924202	et	4	main
väga	doc_897182025870_item	2924203	et	3	main
välismaal	doc_897182025870_item	2924216	et	4	main
ma	doc_897182025870_item	2924217	et	3	main
sooviksin	doc_897182025870_item	2924218	et	3	main
õppida	doc_897182025870_item	2924219	et	3	main
paremini	doc_897182025870_item	2924226	et	4	main
4kus	doc_897182025870_item	2924230	et	3	main
edasi	doc_897182025870_item	2924232	et	3	main
sooviksin	doc_897182025870_item	2924235	et	3	main
on	doc_897182025870_item	2924241	et	4	main
noored	doc_897182025870_item	2924264	et	3	main
sest	doc_897182025870_item	2924274	et	4	main
nad	doc_897182025870_item	2924275	et	3	main
kõrg	doc_897182025871_item	2924288	et	4	main
missugused	doc_897182025871_item	2924291	et	3	main
3	doc_897182025871_item	2924303	et	2	main
sest	doc_897182025871_item	2924315	et	4	main
õppida	doc_897182025871_item	2924324	et	3	main
planeerin	doc_897182025871_item	2924326	et	3	main
õppida	doc_897182025871_item	2924327	et	3	main
ja	doc_897182025871_item	2924334	et	3	main
ainult	doc_881412446077_item	2923840	et	4	main
see	doc_881412446077_item	2923841	et	3	main
on	doc_881412446077_item	2923857	et	4	main
mõjutus	doc_881412446077_item	2923863	et	4	main
kanatibuid	doc_881412446077_item	2923875	et	4	main
mitte	doc_881412446077_item	2923880	et	3	main
kolma	doc_881412446077_item	2923888	et	4	main
kuude	doc_881412446077_item	2923889	et	4	main
pärast	doc_881412446077_item	2923890	et	4	main
kui	doc_881412446077_item	2923894	et	3	main
läheb	doc_881412446077_item	2923896	et	3	main
inimesele	doc_881412446077_item	2923897	et	3	main
kes	doc_881412446077_item	2923898	et	4	main
sõi	doc_881412446077_item	2923899	et	3	main
täiskasvanu	doc_881412446077_item	2923901	et	4	main
selle	doc_881412446077_item	2923900	et	4	main
kanatibu	doc_881412446077_item	2923902	et	4	main
edasi	doc_881412446077_item	2923903	et	3	main
mida	doc_881412446077_item	2923904	et	4	main
saab	doc_881412446077_item	2923905	et	3	main
maakeraga	doc_881412446077_item	2923906	et	3	main
kui	doc_881412446077_item	2923907	et	3	main
inimesed	doc_881412446077_item	2923909	et	3	main
kõik	doc_881412446077_item	2923908	et	4	main
hakkavad	doc_881412446077_item	2923910	et	4	main
suurendada	doc_881412446077_item	2923911	et	3	main
eba	doc_881412446077_item	2923912	et	4	main
päevatega	doc_881412446077_item	2923913	et	4	main
kui	doc_881412446077_item	2923914	et	3	main
tundidega	doc_881412446077_item	2923915	et	3	main
kui	doc_881412446077_item	2923916	et	3	main
see	doc_881412446077_item	2923917	et	3	main
ei	doc_881412446077_item	2923918	et	4	main
saa	doc_881412446077_item	2923919	et	4	main
uue	doc_881412446077_item	2923920	et	3	main
filmi	doc_881412446077_item	2923922	et	4	main
sündmustikuks	doc_881412446077_item	2923923	et	4	main
olla	doc_881412446077_item	2923924	et	3	main
siis	doc_881412446077_item	2923925	et	3	main
täpselt	doc_881412446077_item	2923926	et	4	main
saab	doc_881412446077_item	2923927	et	3	main
maailma	doc_881412446077_item	2923929	et	4	main
aru	doc_881412446077_item	2923943	et	4	main
kõik	doc_881412446077_item	2923945	et	4	main
hirm	doc_881412446077_item	2923946	et	3	main
mis	doc_881412446077_item	2923947	et	4	main
võib	doc_881412446077_item	2923948	et	3	main
pärineda	doc_881412446077_item	2923949	et	3	main
kui	doc_881412446077_item	2923950	et	3	main
eesti	doc_887959124398_item	2923967	et	4	main
rajatud	doc_887959124398_item	2923978	et	4	main
1838	doc_887959124398_item	2923979	et	2	main
aastal	doc_887959124398_item	2923980	et	3	main
faelhmani	doc_887959124398_item	2923981	et	4	main
maa	doc_887959124398_item	2923988	et	4	main
geenimuudetuid	doc_881412446077_item	2923860	et	4	main
ole	doc_881412446077_item	2923865	et	4	main
uuritud	doc_881412446077_item	2923867	et	4	main
võib	doc_881412446077_item	2923870	et	3	main
kujutlete	doc_881412446077_item	2923873	et	3	main
kasvavad	doc_881412446077_item	2923877	et	4	main
ainult	doc_881412446077_item	2923885	et	4	main
kahe	doc_881412446077_item	2923886	et	3	main
mida	doc_881412446077_item	2923891	et	4	main
katastroofiks	doc_881412446077_item	2923930	et	4	main
arvan	doc_881412446077_item	2923932	et	3	main
andma	doc_881412446077_item	2923940	et	3	main
saada	doc_881412446077_item	2923944	et	4	main
selts	doc_887959124398_item	2923968	et	3	main
ja	doc_887959124398_item	2923969	et	3	main
kes	doc_887959124398_item	2923970	et	4	main
sinna	doc_887959124398_item	2923971	et	3	main
nende	doc_887959124398_item	2923987	et	4	main
eesti	doc_887959124398_item	2923992	et	4	main
eesmärgiks	doc_887959124398_item	2923994	et	3	main
seltsi	doc_887959124398_item	2923993	et	4	main
oli	doc_887959124398_item	2923995	et	3	main
rahvakultuuri	doc_887959124398_item	2923996	et	4	main
uurimine	doc_887959124398_item	2923997	et	4	main
rahvalaulude	doc_887959124398_item	2923998	et	3	main
ja	doc_887959124398_item	2923999	et	3	main
mustendite	doc_887959124398_item	2924000	et	4	main
kogumine	doc_887959124398_item	2924001	et	4	main
ning	doc_887959124398_item	2924002	et	3	main
valgustuskirjanduse	doc_887959124398_item	2924003	et	3	main
valja	doc_887959124398_item	2924004	et	3	main
andmine	doc_887959124398_item	2924005	et	4	main
ões	doc_887959124398_item	2924006	et	4	main
koosnes	doc_887959124398_item	2924007	et	3	main
üliõpelastest	doc_887959124398_item	2924008	et	4	main
haritsastest	doc_887959124398_item	2924009	et	4	main
sel	doc_887959124398_item	2924010	et	3	main
ajal	doc_887959124398_item	2924011	et	4	main
faelhmanil	doc_887959124398_item	2924012	et	4	main
tekkis	doc_887959124398_item	2924013	et	3	main
mõtte	doc_887959124398_item	2924014	et	3	main
kirjutada	doc_887959124398_item	2924015	et	3	main
tema	doc_887959124398_item	2924016	et	4	main
müütide	doc_887959124398_item	2924017	et	3	main
kõrval	doc_887959124398_item	2924018	et	4	main
eepos	doc_887959124398_item	2924020	et	3	main
kalevipoja	doc_887959124398_item	2924019	et	4	main
länrotti	doc_887959124398_item	2924024	et	4	main
ning	doc_887959124398_item	2924028	et	3	main
faelhman	doc_887959124398_item	2924033	et	4	main
õpetatud	doc_887959124398_item	2924035	et	4	main
surma	doc_887959124398_item	2924040	et	4	main
eepose	doc_887959124398_item	2924044	et	3	main
eesti	doc_887959124398_item	2924054	et	4	main
rahva	doc_887959124398_item	2924055	et	3	main
kultuuri	doc_887959124398_item	2924058	et	4	main
välja	doc_887959124398_item	2924068	et	4	main
olid	doc_887959124398_item	2924072	et	4	main
sees	doc_887959124398_item	2924080	et	4	main
olid	doc_887959124398_item	2924082	et	4	main
ajalooga	doc_887959124398_item	2924094	et	4	main
kuulusid	doc_887959124398_item	2924100	et	4	main
balti	doc_887959124398_item	2923961	et	3	main
erikord	doc_887959124398_item	2923962	et	3	main
õpetatud	doc_887959124398_item	2923974	et	4	main
eesti	doc_887959124398_item	2923975	et	4	main
selts	doc_887959124398_item	2923976	et	3	main
oli	doc_887959124398_item	2923977	et	3	main
said	doc_887959124398_item	2923985	et	4	main
eestlased	doc_887959124398_item	2923986	et	3	main
soome	doc_887959124398_item	2924025	et	3	main
oma	doc_887959124398_item	2924029	et	4	main
eesti	doc_887959124398_item	2924036	et	4	main
1850	doc_887959124398_item	2924041	et	2	main
ettepanekul	doc_887959124398_item	2924047	et	3	main
oli	doc_887959124398_item	2924062	et	3	main
ões-i	doc_887959124398_item	2924064	et	4	main
valgustustegevus	doc_887959124398_item	2924065	et	4	main
näiteks	doc_887959124398_item	2924066	et	4	main
õpetliku	doc_887959124398_item	2924073	et	3	main
nad	doc_887959124398_item	2924075	et	3	main
sest	doc_887959124398_item	2924081	et	4	main
odavad	doc_887959124398_item	2924083	et	3	main
sellega	doc_887959124398_item	2924085	et	3	main
ões	doc_887959124398_item	2924087	et	4	main
eesti	doc_887959124398_item	2924090	et	4	main
rahva	doc_887959124398_item	2924091	et	3	main
kultuuri	doc_887959124398_item	2924092	et	4	main
selle	doc_887959124398_item	2924097	et	4	main
arenemisega	doc_887959124398_item	2924098	et	4	main
sinna	doc_887959124398_item	2924099	et	3	main
koidula	doc_887959124398_item	2924104	et	4	main
eepose	doc_887959124398_item	2924026	et	3	main
visandid	doc_887959124398_item	2924031	et	3	main
tema	doc_887959124398_item	2924039	et	4	main
koostamise	doc_887959124398_item	2924045	et	4	main
võttis	doc_887959124398_item	2924048	et	3	main
sellest	doc_887959124398_item	2924051	et	4	main
tähtis	doc_887959124398_item	2924061	et	4	main
anti	doc_887959124398_item	2924067	et	3	main
palju	doc_887959124398_item	2924069	et	4	main
sisuga	doc_887959124398_item	2924074	et	3	main
väga	doc_887959124398_item	2924077	et	3	main
uurimisega	doc_887959124398_item	2924093	et	4	main
hurt	doc_887959124398_item	2924105	et	3	main
j	doc_887959124398_item	2924106	et	4	main
köler	doc_887959124398_item	2924107	et	4	main
jt	doc_887959124398_item	2924108	et	4	main
1	doc_887959124398_item	2924109	et	2	main
balti	doc_887959124398_item	2924110	et	3	main
erikord	doc_887959124398_item	2924111	et	3	main
sinna	doc_887959124398_item	2924112	et	3	main
kuulusid	doc_887959124398_item	2924113	et	4	main
baltisakslased	doc_887959124398_item	2924114	et	3	main
pärast	doc_887959124398_item	2924115	et	4	main
põhja	doc_887959124398_item	2924116	et	4	main
sõda	doc_887959124398_item	2924117	et	4	main
nende	doc_887959124398_item	2924118	et	4	main
privileegid	doc_887959124398_item	2924119	et	3	main
säilisid	doc_887959124398_item	2924120	et	4	main
maaomand	doc_887959124398_item	2924121	et	3	main
säilis	doc_887959124398_item	2924132	et	4	main
peeter	doc_887959124398_item	2924133	et	3	main
nad	doc_887959124398_item	2924139	et	3	main
kuid	doc_887959124398_item	2924150	et	4	main
ii	doc_887959124398_item	2924152	et	4	main
muutus	doc_887959124398_item	2924155	et	4	main
vähenesid	doc_887959124398_item	2924163	et	4	main
katariina	doc_887959124398_item	2924169	et	4	main
vaba	doc_897182025870_item	2924208	et	4	main
on	doc_897182025870_item	2924211	et	4	main
elu	doc_887959124398_item	2924056	et	4	main
sümbol	doc_887959124398_item	2924059	et	3	main
ka	doc_887959124398_item	2924063	et	3	main
kalendreid	doc_887959124398_item	2924070	et	3	main
olid	doc_887959124398_item	2924076	et	4	main
rahva	doc_887959124398_item	2924079	et	3	main
ja	doc_887959124398_item	2924084	et	3	main
kättesaadavad	doc_887959124398_item	2924086	et	3	main
tegeles	doc_887959124398_item	2924088	et	3	main
nii	doc_887959124398_item	2924089	et	3	main
ka	doc_887959124398_item	2924096	et	3	main
jannsen	doc_887959124398_item	2924103	et	4	main
linnakodanikest	doc_887959124398_item	2924126	et	3	main
baltisakslased	doc_887959124398_item	2924129	et	3	main
nende	doc_887959124398_item	2924130	et	4	main
privileegid	doc_887959124398_item	2924131	et	3	main
et	doc_887959124398_item	2924138	et	3	main
vene	doc_887959124398_item	2924145	et	4	main
reformid	doc_887959124398_item	2924147	et	4	main
toetusid	doc_887959124398_item	2924148	et	4	main
katariina	doc_887959124398_item	2924151	et	4	main
valitsusajal	doc_887959124398_item	2924153	et	3	main
olukord	doc_887959124398_item	2924154	et	3	main
ikka	doc_887959124398_item	2924165	et	4	main
ii	doc_887959124398_item	2924170	et	4	main
surma	doc_887959124398_item	2924171	et	4	main
ole	doc_897182025870_item	2924207	et	4	main
3kus	doc_897182025870_item	2924210	et	3	main
parem	doc_897182025870_item	2924212	et	4	main
õppida	doc_897182025870_item	2924213	et	3	main
eestis	doc_897182025870_item	2924214	et	3	main
või	doc_897182025870_item	2924215	et	4	main
õppida	doc_897182025870_item	2924236	et	3	main
sillamäes	doc_897182025870_item	2924238	et	3	main
hea	doc_897182025870_item	2924242	et	4	main
ülikoolis	doc_897182025870_item	2924243	et	4	main
tänapäeval	doc_897182025870_item	2924263	et	3	main
noored	doc_897182025870_item	2924271	et	3	main
tulekust	doc_897182025870_item	2924278	et	4	main
saada	doc_897182025871_item	2924287	et	4	main
2	doc_897182025871_item	2924290	et	2	main
omandada	doc_897182025871_item	2924302	et	3	main
on	doc_897182025871_item	2924305	et	4	main
õppida	doc_897182025871_item	2924307	et	3	main
seal	doc_897182025871_item	2924316	et	4	main
kus	doc_897182025871_item	2924321	et	3	main
edasi	doc_897182025871_item	2924323	et	3	main
tahan	doc_897182025871_item	2924331	et	3	main
elada	doc_897182025871_item	2924332	et	3	main
seal	doc_897182025871_item	2924333	et	4	main
omandada	doc_897182025871_item	2924342	et	3	main
tulevikus	doc_897182025871_item	2924345	et	4	main
huvitava	doc_897182025871_item	2924349	et	4	main
et	doc_897182025871_item	2924361	et	3	main
sest	doc_897182025871_item	2924363	et	4	main
tahavad	doc_897182025871_item	2924365	et	3	main
mängivad	doc_897182025872_item	2924382	et	4	main
sa	doc_897182025872_item	2924416	et	3	main
praegu	doc_897182025872_item	2924418	et	3	main
faelhman	doc_887959124398_item	2924101	et	4	main
olid	doc_887959124398_item	2924123	et	4	main
enamik	doc_887959124398_item	2924125	et	3	main
ta	doc_887959124398_item	2924136	et	4	main
ei	doc_887959124398_item	2924140	et	4	main
vastu	doc_887959124398_item	2924143	et	3	main
uue	doc_887959124398_item	2924159	et	3	main
kuid	doc_887959124398_item	2924164	et	4	main
ja	doc_897182025870_item	2924199	et	3	main
eestissest	doc_897182025870_item	2924220	et	3	main
ma	doc_897182025870_item	2924222	et	3	main
tahaksin	doc_897182025870_item	2924223	et	3	main
tallinnaset	doc_897182025870_item	2924225	et	3	main
eesti	doc_897182025870_item	2924228	et	4	main
õppida	doc_897182025870_item	2924233	et	3	main
ülikoolis	doc_897182025870_item	2924237	et	4	main
minu	doc_897182025870_item	2924246	et	3	main
vend	doc_897182025870_item	2924247	et	3	main
5miks	doc_897182025870_item	2924248	et	4	main
arvavad	doc_897182025870_item	2924276	et	4	main
küsimusele	doc_897182025871_item	2924280	et	4	main
ma	doc_897182025871_item	2924283	et	3	main
õppeinformatsiooni	doc_897182025871_item	2924297	et	4	main
ja	doc_897182025871_item	2924298	et	3	main
see	doc_897182025871_item	2924299	et	3	main
on	doc_897182025871_item	2924300	et	4	main
kus	doc_897182025871_item	2924304	et	3	main
parem	doc_897182025871_item	2924306	et	4	main
või	doc_897182025871_item	2924309	et	4	main
välismaal	doc_897182025871_item	2924310	et	4	main
ma	doc_897182025871_item	2924311	et	3	main
eelistan	doc_897182025871_item	2924312	et	3	main
õppida	doc_897182025871_item	2924313	et	3	main
kõik	doc_897182025871_item	2924317	et	4	main
4	doc_897182025871_item	2924320	et	2	main
sooviksid	doc_897182025871_item	2924322	et	4	main
miks	doc_897182025871_item	2924325	et	4	main
irimaas	doc_897182025871_item	2924329	et	4	main
5	doc_897182025871_item	2924337	et	2	main
miks	doc_897182025871_item	2924338	et	4	main
haridust	doc_897182025871_item	2924341	et	4	main
sest	doc_897182025871_item	2924344	et	4	main
see	doc_897182025871_item	2924346	et	3	main
annab	doc_897182025871_item	2924347	et	3	main
mulle	doc_897182025871_item	2924348	et	4	main
tänapäeva	doc_897182025871_item	2924356	et	4	main
arvan	doc_897182025871_item	2924360	et	3	main
väärtustavad	doc_897182025871_item	2924362	et	4	main
elada	doc_897182025871_item	2924366	et	3	main
pärast	doc_897182025872_item	2924410	et	4	main
ma	doc_897182025872_item	2924411	et	3	main
armastan	doc_897182025872_item	2924412	et	3	main
õppida	doc_897182025872_item	2924413	et	3	main
2	doc_897182025872_item	2924414	et	2	main
sest	doc_897182025872_item	2924423	et	4	main
saan	doc_897182025872_item	2924426	et	4	main
on	doc_897182025872_item	2924429	et	4	main
minu	doc_897182025872_item	2924430	et	3	main
õppida	doc_897182025872_item	2924458	et	3	main
tulemused	doc_897182025872_item	2924461	et	3	main
oli	doc_897182025872_item	2924475	et	3	main
uusi	doc_897182025872_item	2924494	et	3	main
ja	doc_897182025872_item	2924496	et	3	main
vabalt	doc_897182025872_item	2924505	et	4	main
sinu	doc_897182025872_item	2924511	et	3	main
peamised	doc_897182025872_item	2924512	et	3	main
koolis	doc_897182025872_item	2924514	et	4	main
6	doc_897182025872_item	2924522	et	2	main
hindeid	doc_897182025872_item	2924532	et	3	main
eksamite	doc_897182025872_item	2924533	et	3	main
jaoks	doc_897182025872_item	2924534	et	4	main
astuda	doc_897182025872_item	2924536	et	3	main
kõigepealt	doc_897182025872_item	2924548	et	3	main
see	doc_897182025872_item	2924549	et	3	main
on	doc_897182025872_item	2924550	et	4	main
suur	doc_897182025872_item	2924551	et	3	main
soov	doc_897182025872_item	2924552	et	3	main
õppida	doc_897182025872_item	2924553	et	3	main
arvan	doc_897182025872_item	2924554	et	3	main
ja	doc_897182025872_item	2924561	et	3	main
ei	doc_897182025872_item	2924563	et	4	main
tulevikus	doc_897182025872_item	2924573	et	4	main
i	doc_887959124398_item	2924134	et	4	main
sellega	doc_887959124398_item	2924135	et	3	main
kuna	doc_887959124398_item	2924144	et	3	main
euroopale	doc_887959124398_item	2924149	et	3	main
säilisid	doc_887959124398_item	2924166	et	4	main
ning	doc_887959124398_item	2924167	et	3	main
pärast	doc_887959124398_item	2924168	et	4	main
kõik	doc_887959124398_item	2924172	et	4	main
muutus	doc_887959124398_item	2924173	et	4	main
tagasi	doc_887959124398_item	2924174	et	3	main
nagu	doc_887959124398_item	2924175	et	3	main
oli	doc_887959124398_item	2924176	et	3	main
enne	doc_887959124398_item	2924177	et	4	main
vastus	doc_897182025870_item	2924178	et	3	main
küsimusele	doc_897182025870_item	2924179	et	4	main
1miks	doc_897182025870_item	2924180	et	4	main
ma	doc_897182025870_item	2924181	et	3	main
õpin	doc_897182025870_item	2924182	et	3	main
ma	doc_897182025870_item	2924183	et	3	main
õpin	doc_897182025870_item	2924184	et	3	main
sest	doc_897182025870_item	2924185	et	4	main
see	doc_897182025870_item	2924186	et	3	main
on	doc_897182025870_item	2924187	et	4	main
vaja	doc_897182025870_item	2924188	et	4	main
tulevikus	doc_897182025870_item	2924189	et	4	main
2misugused	doc_897182025870_item	2924190	et	4	main
raskused	doc_897182025870_item	2924191	et	4	main
on	doc_897182025870_item	2924192	et	4	main
õppetöös	doc_897182025870_item	2924193	et	3	main
ma	doc_897182025870_item	2924194	et	3	main
tean	doc_897182025870_item	2924195	et	3	main
halvasti	doc_897182025870_item	2924196	et	3	main
eest	doc_897182025870_item	2924197	et	4	main
keelt	doc_897182025870_item	2924198	et	4	main
keeltma	doc_897182025870_item	2924201	et	4	main
laisk	doc_897182025870_item	2924204	et	3	main
mul	doc_897182025870_item	2924205	et	3	main
ei	doc_897182025870_item	2924206	et	4	main
aega	doc_897182025870_item	2924209	et	4	main
tulevikus	doc_897182025870_item	2924221	et	4	main
elada	doc_897182025870_item	2924224	et	3	main
keelt	doc_897182025870_item	2924229	et	4	main
sooviksid	doc_897182025870_item	2924231	et	4	main
ma	doc_897182025870_item	2924234	et	3	main
sest	doc_897182025870_item	2924239	et	4	main
seal	doc_897182025870_item	2924240	et	4	main
hea	doc_897182025870_item	2924260	et	4	main
6kas	doc_897182025870_item	2924262	et	3	main
haridust	doc_897182025870_item	2924266	et	4	main
arvan	doc_897182025870_item	2924268	et	3	main
et	doc_897182025870_item	2924269	et	3	main
tänapäeval	doc_897182025870_item	2924270	et	3	main
oma	doc_897182025870_item	2924277	et	4	main
1	doc_897182025871_item	2924281	et	2	main
miks	doc_897182025871_item	2924282	et	4	main
palju	doc_897182025871_item	2924295	et	4	main
uusi	doc_897182025871_item	2924296	et	3	main
välismaal	doc_897182025871_item	2924314	et	4	main
soobib	doc_897182025871_item	2924318	et	4	main
välismaal	doc_897182025871_item	2924328	et	4	main
kõrg	doc_897182025871_item	2924340	et	4	main
palga	doc_897182025871_item	2924353	et	3	main
haridust	doc_897182025871_item	2924359	et	4	main
sest	doc_897182025872_item	2924378	et	4	main
õpid	doc_897182025872_item	2924417	et	4	main
ma	doc_897182025872_item	2924419	et	3	main
tähtis	doc_897182025872_item	2924434	et	4	main
kui	doc_897182025872_item	2924435	et	3	main
käin	doc_897182025872_item	2924436	et	3	main
eksamid	doc_897182025872_item	2924443	et	3	main
õppumist	doc_897182025872_item	2924448	et	4	main
kuidas	doc_897182025872_item	2924450	et	3	main
varem	doc_897182025872_item	2924452	et	4	main
õppisid	doc_897182025872_item	2924453	et	4	main
sest	doc_897182025872_item	2924467	et	4	main
üheksandas	doc_897182025872_item	2924468	et	3	main
klassis	doc_897182025872_item	2924469	et	3	main
oli	doc_897182025872_item	2924470	et	3	main
koormus	doc_897182025872_item	2924474	et	4	main
mis	doc_897182025872_item	2924478	et	4	main
sinu	doc_897182025872_item	2924481	et	3	main
jaoks	doc_897182025872_item	2924482	et	4	main
õppetöös	doc_897182025872_item	2924483	et	3	main
minu	doc_897182025872_item	2924484	et	3	main
tundidel	doc_897182025872_item	2924491	et	3	main
pärast	doc_897182025872_item	2924497	et	4	main
võiks	doc_897182025872_item	2924499	et	4	main
kasutama	doc_897182025872_item	2924500	et	3	main
on	doc_897182025872_item	2924510	et	4	main
õppe-eesmärgid	doc_897182025872_item	2924513	et	3	main
hinded	doc_897182025872_item	2924516	et	3	main
uued	doc_897182025872_item	2924517	et	3	main
teadmised	doc_897182025872_item	2924518	et	4	main
ja	doc_897182025872_item	2924519	et	3	main
ülesanded	doc_897182025872_item	2924524	et	3	main
enda	doc_897182025872_item	2924526	et	4	main
leida	doc_897182025872_item	2924540	et	3	main
tööd	doc_897182025872_item	2924542	et	4	main
mis	doc_897182025872_item	2924544	et	4	main
mõjutab	doc_897182025872_item	2924545	et	3	main
väga	doc_897182025872_item	2924557	et	3	main
keegi	doc_897182025872_item	2924560	et	4	main
8	doc_897182025872_item	2924567	et	2	main
kuidas	doc_897182025872_item	2924568	et	3	main
sa	doc_897182025872_item	2924569	et	3	main
oma	doc_897182025872_item	2924571	et	4	main
ülikoolis	doc_897182025872_item	2924581	et	4	main
olla	doc_897182025873_item	2924621	et	3	main
2	doc_897182025873_item	2924634	et	2	main
sa	doc_897182025873_item	2924636	et	3	main
õpid	doc_897182025873_item	2924637	et	4	main
ma	doc_897182025873_item	2924639	et	3	main
arvan	doc_897182025873_item	2924640	et	3	main
praegu	doc_897182025873_item	2924644	et	3	main
õppida	doc_897182025873_item	2924649	et	3	main
osata	doc_897182025870_item	2924227	et	4	main
seal	doc_897182025870_item	2924244	et	4	main
õpib	doc_897182025870_item	2924245	et	3	main
soovid	doc_897182025870_item	2924249	et	4	main
kõrkharidust	doc_897182025870_item	2924250	et	4	main
omandada	doc_897182025870_item	2924251	et	3	main
ma	doc_897182025870_item	2924252	et	3	main
soovin	doc_897182025870_item	2924253	et	3	main
omandada	doc_897182025870_item	2924254	et	3	main
kõrkharidust	doc_897182025870_item	2924255	et	4	main
sest	doc_897182025870_item	2924256	et	4	main
ma	doc_897182025870_item	2924257	et	3	main
tahan	doc_897182025870_item	2924258	et	3	main
leida	doc_897182025870_item	2924259	et	3	main
töö	doc_897182025870_item	2924261	et	4	main
väärtustavad	doc_897182025870_item	2924265	et	4	main
ma	doc_897182025870_item	2924267	et	3	main
väärtustavad	doc_897182025870_item	2924272	et	4	main
haridust	doc_897182025870_item	2924273	et	4	main
vastus	doc_897182025871_item	2924279	et	3	main
õpin	doc_897182025871_item	2924284	et	3	main
sest	doc_897182025871_item	2924285	et	4	main
tahaksin	doc_897182025871_item	2924286	et	3	main
haridust	doc_897182025871_item	2924289	et	4	main
raskused	doc_897182025871_item	2924292	et	4	main
on	doc_897182025871_item	2924293	et	4	main
õppetöös	doc_897182025871_item	2924294	et	3	main
raske	doc_897182025871_item	2924301	et	4	main
eestis	doc_897182025871_item	2924308	et	3	main
mulle	doc_897182025871_item	2924319	et	4	main
sest	doc_897182025871_item	2924330	et	4	main
soovid	doc_897182025871_item	2924339	et	4	main
töö	doc_897182025871_item	2924350	et	4	main
ja	doc_897182025871_item	2924351	et	3	main
kas	doc_897182025871_item	2924355	et	3	main
väärtustavad	doc_897182025871_item	2924358	et	4	main
vastus	doc_897182025872_item	2924368	et	3	main
1	doc_897182025872_item	2924370	et	2	main
miks	doc_897182025872_item	2924371	et	4	main
ma	doc_897182025872_item	2924372	et	3	main
tahan	doc_897182025872_item	2924373	et	3	main
õppida	doc_897182025872_item	2924374	et	3	main
ma	doc_897182025872_item	2924375	et	3	main
tahan	doc_897182025872_item	2924376	et	3	main
õppida	doc_897182025872_item	2924377	et	3	main
maailmas	doc_897182025872_item	2924380	et	3	main
teadmised	doc_897182025872_item	2924381	et	4	main
väga	doc_897182025872_item	2924383	et	3	main
suurt	doc_897182025872_item	2924384	et	3	main
rooli	doc_897182025872_item	2924385	et	4	main
iga	doc_897182025872_item	2924386	et	4	main
inimene	doc_897182025872_item	2924387	et	3	main
peab	doc_897182025872_item	2924388	et	4	main
teadma	doc_897182025872_item	2924389	et	3	main
palju	doc_897182025872_item	2924390	et	4	main
et	doc_897182025872_item	2924391	et	3	main
olla	doc_897182025872_item	2924392	et	3	main
edukassee	doc_897182025872_item	2924393	et	4	main
tähendab	doc_897182025872_item	2924394	et	3	main
õppida	doc_897182025872_item	2924395	et	3	main
ülikoolis	doc_897182025872_item	2924396	et	4	main
pärast	doc_897182025872_item	2924398	et	4	main
töötama	doc_897182025872_item	2924399	et	3	main
heas	doc_897182025872_item	2924400	et	3	main
ja	doc_897182025872_item	2924397	et	3	main
firmis	doc_897182025872_item	2924401	et	4	main
ka	doc_897182025872_item	2924402	et	3	main
see	doc_897182025872_item	2924403	et	3	main
on	doc_897182025872_item	2924404	et	4	main
huvitav	doc_897182025872_item	2924405	et	4	main
minu	doc_897182025872_item	2924406	et	3	main
jaoks	doc_897182025872_item	2924407	et	4	main
ja	doc_897182025872_item	2924408	et	3	main
selle	doc_897182025872_item	2924409	et	4	main
saada	doc_897182025871_item	2924335	et	4	main
haridust	doc_897182025871_item	2924336	et	4	main
soovin	doc_897182025871_item	2924343	et	3	main
suur	doc_897182025871_item	2924352	et	3	main
6	doc_897182025871_item	2924354	et	2	main
noored	doc_897182025871_item	2924357	et	3	main
nad	doc_897182025871_item	2924364	et	3	main
külusus	doc_897182025871_item	2924367	et	4	main
küsimusele	doc_897182025872_item	2924369	et	4	main
tänapäevaeses	doc_897182025872_item	2924379	et	4	main
kuidas	doc_897182025872_item	2924415	et	3	main
püüan	doc_897182025872_item	2924420	et	3	main
hästi	doc_897182025872_item	2924422	et	3	main
millised	doc_897182025872_item	2924425	et	3	main
12	doc_897182025872_item	2924427	et	2	main
klassis	doc_897182025872_item	2924428	et	3	main
ülikooliska	doc_897182025872_item	2924437	et	4	main
õpin	doc_897182025872_item	2924438	et	3	main
hästi	doc_897182025872_item	2924439	et	3	main
mais	doc_897182025872_item	2924441	et	4	main
varem	doc_897182025872_item	2924454	et	4	main
ka	doc_897182025872_item	2924456	et	3	main
kergem	doc_897182025872_item	2924471	et	4	main
õppida	doc_897182025872_item	2924472	et	3	main
väike	doc_897182025872_item	2924476	et	4	main
on	doc_897182025872_item	2924479	et	4	main
peamine	doc_897182025872_item	2924480	et	3	main
on	doc_897182025872_item	2924488	et	4	main
see	doc_897182025872_item	2924489	et	3	main
et	doc_897182025872_item	2924490	et	3	main
eesti	doc_897182025872_item	2924506	et	4	main
missugused	doc_897182025872_item	2924509	et	3	main
saada	doc_897182025872_item	2924530	et	4	main
häid	doc_897182025872_item	2924531	et	3	main
ja	doc_897182025872_item	2924538	et	3	main
kui	doc_897182025872_item	2924555	et	3	main
siis	doc_897182025872_item	2924559	et	3	main
midagi	doc_897182025872_item	2924562	et	4	main
või	doc_897182025872_item	2924564	et	4	main
segada	doc_897182025872_item	2924565	et	3	main
tulevikus	doc_897182025872_item	2924574	et	4	main
planeerin	doc_897182025872_item	2924575	et	3	main
õppida	doc_897182025872_item	2924576	et	3	main
tartu-	doc_897182025872_item	2924577	et	4	main
tallinna	doc_897182025872_item	2924579	et	4	main
tehnika	doc_897182025872_item	2924580	et	4	main
veel	doc_897182025872_item	2924582	et	4	main
kooli	doc_897182025873_item	2924622	et	4	main
lähevad	doc_897182025873_item	2924624	et	3	main
alati	doc_897182025873_item	2924625	et	4	main
vaja	doc_897182025873_item	2924626	et	4	main
elus	doc_897182025873_item	2924633	et	4	main
kuidas	doc_897182025873_item	2924635	et	3	main
praegu	doc_897182025873_item	2924638	et	3	main
et	doc_897182025873_item	2924641	et	3	main
õpin	doc_897182025873_item	2924643	et	3	main
alati	doc_897182025873_item	2924648	et	4	main
igal	doc_897182025873_item	2924652	et	3	main
kõik	doc_897182025873_item	2924659	et	4	main
ma	doc_897182025873_item	2924661	et	3	main
saan	doc_897182025873_item	2924669	et	4	main
öelda	doc_897182025873_item	2924670	et	4	main
on	doc_897182025873_item	2924707	et	4	main
tee	doc_897182025873_item	2924718	et	4	main
on	doc_897182025872_item	2924433	et	4	main
algavad	doc_897182025872_item	2924442	et	4	main
tulemused	doc_897182025872_item	2924445	et	3	main
nende	doc_897182025872_item	2924444	et	4	main
sõltuvad	doc_897182025872_item	2924446	et	4	main
õppida	doc_897182025872_item	2924421	et	3	main
hinded	doc_897182025872_item	2924424	et	3	main
tunnistuses	doc_897182025872_item	2924431	et	4	main
see	doc_897182025872_item	2924432	et	3	main
sest	doc_897182025872_item	2924440	et	4	main
mina	doc_897182025872_item	2924455	et	4	main
minu	doc_897182025872_item	2924460	et	3	main
olid	doc_897182025872_item	2924462	et	4	main
head	doc_897182025872_item	2924463	et	4	main
vaid	doc_897182025872_item	2924464	et	3	main
parem	doc_897182025872_item	2924465	et	4	main
arvan	doc_897182025872_item	2924466	et	3	main
jaoks	doc_897182025872_item	2924485	et	4	main
kõige	doc_897182025872_item	2924486	et	4	main
tähtis	doc_897182025872_item	2924487	et	4	main
saaks	doc_897182025872_item	2924493	et	3	main
keelt	doc_897182025872_item	2924507	et	4	main
ülikoolis	doc_897182025872_item	2924521	et	4	main
sa	doc_897182025872_item	2924525	et	3	main
jaoks	doc_897182025872_item	2924527	et	4	main
püstitasid	doc_897182025872_item	2924528	et	4	main
tahan	doc_897182025872_item	2924529	et	3	main
ülikoolis	doc_897182025872_item	2924537	et	4	main
häid	doc_897182025872_item	2924541	et	3	main
inimene	doc_897182025872_item	2924556	et	3	main
või	doc_897182025872_item	2924578	et	4	main
tahan	doc_897182025872_item	2924583	et	3	main
omandada	doc_897182025872_item	2924585	et	3	main
minu	doc_897182025872_item	2924447	et	3	main
3	doc_897182025872_item	2924449	et	2	main
sa	doc_897182025872_item	2924451	et	3	main
püüdsin	doc_897182025872_item	2924457	et	3	main
hästi	doc_897182025872_item	2924459	et	3	main
sest	doc_897182025872_item	2924473	et	4	main
4	doc_897182025872_item	2924477	et	2	main
ma	doc_897182025872_item	2924492	et	3	main
teadmisi	doc_897182025872_item	2924495	et	4	main
seda	doc_897182025872_item	2924498	et	3	main
neid	doc_897182025872_item	2924501	et	4	main
oma	doc_897182025872_item	2924502	et	4	main
elus	doc_897182025872_item	2924503	et	4	main
rääkima	doc_897182025872_item	2924504	et	3	main
5	doc_897182025872_item	2924508	et	2	main
head	doc_897182025872_item	2924515	et	4	main
õppimine	doc_897182025872_item	2924520	et	4	main
missugused	doc_897182025872_item	2924523	et	3	main
sisse	doc_897182025872_item	2924535	et	4	main
pärast	doc_897182025872_item	2924539	et	4	main
7	doc_897182025872_item	2924543	et	2	main
sinu	doc_897182025872_item	2924546	et	3	main
õppetööd	doc_897182025872_item	2924547	et	4	main
tahab	doc_897182025872_item	2924558	et	3	main
teda	doc_897182025872_item	2924566	et	4	main
näed	doc_897182025872_item	2924570	et	3	main
õpinguid	doc_897182025872_item	2924572	et	3	main
saksa	doc_897182025872_item	2924586	et	4	main
keelt	doc_897182025872_item	2924587	et	4	main
vastus	doc_897182025873_item	2924588	et	3	main
küsimusele	doc_897182025873_item	2924589	et	4	main
küsimused	doc_897182025873_item	2924590	et	4	main
1	doc_897182025873_item	2924591	et	2	main
miks	doc_897182025873_item	2924592	et	4	main
ma	doc_897182025873_item	2924593	et	3	main
tahan	doc_897182025873_item	2924594	et	3	main
õppida	doc_897182025873_item	2924595	et	3	main
ma	doc_897182025873_item	2924596	et	3	main
tahan	doc_897182025873_item	2924597	et	3	main
õppida	doc_897182025873_item	2924598	et	3	main
sest	doc_897182025873_item	2924599	et	4	main
mul	doc_897182025873_item	2924600	et	3	main
on	doc_897182025873_item	2924601	et	4	main
vaja	doc_897182025873_item	2924602	et	4	main
head	doc_897182025873_item	2924603	et	4	main
haridust	doc_897182025873_item	2924604	et	4	main
väga	doc_897182025873_item	2924606	et	3	main
et	doc_897182025873_item	2924605	et	3	main
hea	doc_897182025873_item	2924607	et	4	main
tööd	doc_897182025873_item	2924608	et	4	main
leida	doc_897182025873_item	2924609	et	3	main
ma	doc_897182025873_item	2924610	et	3	main
tahan	doc_897182025873_item	2924611	et	3	main
õppida	doc_897182025873_item	2924612	et	3	main
sest	doc_897182025873_item	2924613	et	4	main
ma	doc_897182025873_item	2924614	et	3	main
tahan	doc_897182025873_item	2924615	et	3	main
hästi	doc_897182025873_item	2924616	et	3	main
kooli	doc_897182025873_item	2924617	et	4	main
lõppetada	doc_897182025873_item	2924618	et	4	main
ja	doc_897182025873_item	2924619	et	3	main
tark	doc_897182025873_item	2924620	et	3	main
teadmised	doc_897182025873_item	2924623	et	4	main
meie	doc_897182025873_item	2924632	et	4	main
tulevikus	doc_897182025872_item	2924584	et	4	main
sest	doc_897182025873_item	2924627	et	4	main
need	doc_897182025873_item	2924628	et	3	main
on	doc_897182025873_item	2924629	et	4	main
algud	doc_897182025873_item	2924630	et	3	main
teadmised	doc_897182025873_item	2924631	et	4	main
proovin	doc_897182025873_item	2924647	et	3	main
teha	doc_897182025873_item	2924658	et	3	main
saan	doc_897182025873_item	2924662	et	4	main
3	doc_897182025873_item	2924663	et	2	main
kuidas	doc_897182025873_item	2924664	et	3	main
sa	doc_897182025873_item	2924665	et	3	main
varem	doc_897182025873_item	2924666	et	4	main
soov	doc_897182025873_item	2924708	et	3	main
seda	doc_897182025873_item	2924719	et	3	main
ja	doc_897182025873_item	2924720	et	3	main
inimesel	doc_897182025873_item	2924726	et	3	main
5	doc_897182025873_item	2924733	et	2	main
missugused	doc_897182025873_item	2924734	et	3	main
on	doc_897182025873_item	2924735	et	4	main
sinu	doc_897182025873_item	2924736	et	3	main
peamised	doc_897182025873_item	2924737	et	3	main
õppe-eesmärgid	doc_897182025873_item	2924738	et	3	main
minu	doc_897182025873_item	2924739	et	3	main
peamised	doc_897182025873_item	2924740	et	3	main
eesmärgid	doc_897182025873_item	2924741	et	3	main
on	doc_897182025873_item	2924742	et	4	main
püstitasid	doc_897182025873_item	2924759	et	4	main
minu	doc_897182025873_item	2924760	et	3	main
peamine	doc_897182025873_item	2924761	et	3	main
õppetööd	doc_897182025873_item	2924776	et	4	main
mõjutab	doc_897182025873_item	2924777	et	3	main
minu	doc_897182025873_item	2924778	et	3	main
ümbrus	doc_897182025873_item	2924779	et	3	main
minu	doc_897182025873_item	2924794	et	3	main
on	doc_897182025873_item	2924805	et	4	main
seda	doc_897182025873_item	2924806	et	3	main
vaja	doc_897182025873_item	2924807	et	4	main
kuidas	doc_897182025873_item	2924809	et	3	main
sa	doc_897182025873_item	2924810	et	3	main
tahaks	doc_897182025873_item	2924816	et	3	main
ülikoolis	doc_897182025873_item	2924821	et	4	main
ei	doc_897182025873_item	2924824	et	4	main
küsimusele	doc_899326610084_item	2924842	et	4	main
te	doc_899326610084_item	2924845	et	4	main
mõtlete	doc_899326610084_item	2924846	et	3	main
sõna	doc_899326610084_item	2924849	et	4	main
kultuur	doc_899326610084_item	2924850	et	3	main
mingisugune	doc_899326610084_item	2924851	et	3	main
kultuur	doc_899326610084_item	2924852	et	3	main
on	doc_899326610084_item	2924853	et	4	main
igal	doc_899326610084_item	2924854	et	3	main
rahval	doc_899326610084_item	2924855	et	3	main
üldiselt	doc_899326610084_item	2924856	et	4	main
mahukas	doc_899326610084_item	2924861	et	4	main
kombest	doc_899326610084_item	2924864	et	4	main
ajaloost	doc_899326610084_item	2924865	et	4	main
teistest	doc_899326610084_item	2924869	et	4	main
asjadest	doc_899326610084_item	2924870	et	3	main
ma	doc_899326610084_item	2924871	et	3	main
teada	doc_899326610084_item	2924877	et	3	main
meelde	doc_899326610084_item	2924918	et	3	main
kohe	doc_899326610084_item	2924920	et	4	main
nende	doc_899326610084_item	2924933	et	4	main
kultuuris	doc_899326610084_item	2924934	et	3	main
tea	doc_899326610084_item	2924943	et	4	main
öelda	doc_899326610084_item	2924950	et	4	main
te	doc_899326610085_item	2924956	et	4	main
kui	doc_899326610085_item	2924958	et	3	main
te	doc_899326610085_item	2924968	et	4	main
kuulate	doc_899326610085_item	2924969	et	3	main
fraasi	doc_899326610085_item	2924970	et	4	main
kultuur	doc_899326610085_item	2924975	et	3	main
on	doc_899326610085_item	2925010	et	4	main
see	doc_899326610085_item	2925011	et	3	main
aeg	doc_899326610085_item	2925020	et	3	main
on	doc_899326610085_item	2925038	et	4	main
seisis	doc_899326610085_item	2925057	et	4	main
on	doc_899326610085_item	2925060	et	4	main
omapärane	doc_899326610085_item	2925062	et	4	main
teada	doc_899326610085_item	2925064	et	3	main
natuke	doc_899326610085_item	2925066	et	4	main
ma	doc_897182025873_item	2924642	et	3	main
hästi	doc_897182025873_item	2924645	et	3	main
kuulan	doc_897182025873_item	2924650	et	3	main
tunnil	doc_897182025873_item	2924653	et	3	main
ma	doc_897182025873_item	2924673	et	3	main
halvem	doc_897182025873_item	2924675	et	4	main
kui	doc_897182025873_item	2924676	et	3	main
praegu	doc_897182025873_item	2924677	et	3	main
ma	doc_897182025873_item	2924678	et	3	main
ei	doc_897182025873_item	2924679	et	4	main
tehtud	doc_897182025873_item	2924680	et	4	main
tihti	doc_897182025873_item	2924681	et	3	main
koduülesandeid	doc_897182025873_item	2924682	et	3	main
et	doc_897182025873_item	2924683	et	3	main
tahtnud	doc_897182025873_item	2924684	et	4	main
tähelepanekult	doc_897182025873_item	2924685	et	3	main
olla	doc_897182025873_item	2924686	et	3	main
ma	doc_897182025873_item	2924687	et	3	main
ei	doc_897182025873_item	2924688	et	4	main
saanud	doc_897182025873_item	2924689	et	4	main
aru	doc_897182025873_item	2924690	et	4	main
et	doc_897182025873_item	2924691	et	3	main
kool	doc_897182025873_item	2924692	et	4	main
on	doc_897182025873_item	2924693	et	4	main
mul	doc_897182025873_item	2924694	et	3	main
vaja	doc_897182025873_item	2924695	et	4	main
4	doc_897182025873_item	2924696	et	2	main
mis	doc_897182025873_item	2924697	et	4	main
on	doc_897182025873_item	2924698	et	4	main
peamine	doc_897182025873_item	2924699	et	3	main
sinu	doc_897182025873_item	2924700	et	3	main
jaoks	doc_897182025873_item	2924701	et	4	main
õppetöös	doc_897182025873_item	2924702	et	3	main
minu	doc_897182025873_item	2924703	et	3	main
jaoks	doc_897182025873_item	2924704	et	4	main
peamine	doc_897182025873_item	2924705	et	3	main
õppetöös	doc_897182025873_item	2924706	et	3	main
ma	doc_897182025873_item	2924646	et	3	main
õpetajat	doc_897182025873_item	2924651	et	4	main
teen	doc_897182025873_item	2924654	et	3	main
ja	doc_897182025873_item	2924656	et	3	main
õppisid	doc_897182025873_item	2924667	et	4	main
ma	doc_897182025873_item	2924668	et	3	main
varem	doc_897182025873_item	2924672	et	4	main
õppisin	doc_897182025873_item	2924674	et	3	main
õppida	doc_897182025873_item	2924709	et	3	main
ei	doc_897182025873_item	2924712	et	4	main
ei	doc_897182025873_item	2924717	et	4	main
ta	doc_897182025873_item	2924721	et	4	main
enda	doc_897182025873_item	2924757	et	4	main
jaoks	doc_897182025873_item	2924758	et	4	main
õppetööd	doc_897182025873_item	2924774	et	4	main
minu	doc_897182025873_item	2924775	et	3	main
ja	doc_897182025873_item	2924782	et	3	main
minu	doc_897182025873_item	2924783	et	3	main
midagi	doc_897182025873_item	2924785	et	4	main
küll	doc_897182025873_item	2924787	et	4	main
on	doc_897182025873_item	2924788	et	4	main
juures	doc_897182025873_item	2924795	et	4	main
8	doc_897182025873_item	2924808	et	2	main
näed	doc_897182025873_item	2924811	et	3	main
sõita	doc_897182025873_item	2924818	et	3	main
seal	doc_897182025873_item	2924820	et	4	main
ma	doc_897182025873_item	2924823	et	3	main
keda	doc_897182025873_item	2924827	et	4	main
kuulate	doc_899326610084_item	2924848	et	3	main
väga	doc_899326610084_item	2924860	et	3	main
koosneb	doc_899326610084_item	2924863	et	3	main
ei	doc_899326610084_item	2924912	et	4	main
tea	doc_899326610084_item	2924913	et	4	main
seda	doc_899326610084_item	2924914	et	3	main
hästi	doc_899326610084_item	2924915	et	3	main
aga	doc_899326610084_item	2924916	et	3	main
ja	doc_899326610084_item	2924922	et	3	main
mul	doc_899326610084_item	2924925	et	3	main
tantsisid	doc_899326610084_item	2924930	et	4	main
laulsid	doc_899326610084_item	2924932	et	4	main
saa	doc_899326610084_item	2924948	et	4	main
küsimusele	doc_899326610085_item	2924953	et	4	main
kuulate	doc_899326610085_item	2924960	et	3	main
kultuur	doc_899326610085_item	2924962	et	3	main
te	doc_899326610085_item	2924965	et	4	main
mõtlete	doc_899326610085_item	2924966	et	3	main
kui	doc_899326610085_item	2924967	et	3	main
1	doc_899326610085_item	2924973	et	2	main
minu	doc_899326610085_item	2924976	et	3	main
mis	doc_899326610085_item	2925012	et	4	main
on	doc_899326610085_item	2925018	et	4	main
väike	doc_899326610085_item	2925027	et	4	main
riik	doc_899326610085_item	2925028	et	3	main
ja	doc_899326610085_item	2925029	et	3	main
meie	doc_899326610085_item	2925030	et	4	main
segu	doc_899326610085_item	2925039	et	4	main
kultuur	doc_899326610085_item	2925040	et	3	main
eestlased	doc_899326610085_item	2925041	et	3	main
tihti	doc_899326610085_item	2925042	et	3	main
kiiresti	doc_899326610085_item	2925050	et	3	main
areneb	doc_899326610085_item	2925051	et	3	main
xxxxxx	doc_901133458138_item	2925075	et	4	main
perekond	doc_901133458138_item	2925086	et	3	main
ma	doc_901133458138_item	2925087	et	3	main
12	doc_901133458138_item	2925099	et	2	main
põhjus	doc_901133458138_item	2925107	et	4	main
teine	doc_901133458138_item	2925115	et	3	main
huvijad	doc_901133458138_item	2925127	et	4	main
tekste	doc_901133458138_item	2925128	et	3	main
natuke	doc_901133458138_item	2925147	et	4	main
kauga	doc_901133458138_item	2925157	et	4	main
sellel	doc_901133458138_item	2925166	et	4	main
ma	doc_901133458138_item	2925168	et	3	main
koduülesandeid	doc_897182025873_item	2924655	et	3	main
proovin	doc_897182025873_item	2924657	et	3	main
mida	doc_897182025873_item	2924660	et	4	main
et	doc_897182025873_item	2924671	et	3	main
kui	doc_897182025873_item	2924710	et	3	main
taha	doc_897182025873_item	2924713	et	4	main
õppida	doc_897182025873_item	2924714	et	3	main
siis	doc_897182025873_item	2924715	et	3	main
ta	doc_897182025873_item	2924716	et	4	main
saab	doc_897182025873_item	2924722	et	3	main
mitte	doc_897182025873_item	2924723	et	3	main
teha	doc_897182025873_item	2924725	et	3	main
peab	doc_897182025873_item	2924727	et	4	main
huvi	doc_897182025873_item	2924728	et	4	main
olla	doc_897182025873_item	2924729	et	3	main
head	doc_897182025873_item	2924744	et	4	main
sooritada	doc_897182025873_item	2924747	et	3	main
edasi	doc_897182025873_item	2924751	et	3	main
6	doc_897182025873_item	2924753	et	2	main
missugused	doc_897182025873_item	2924754	et	3	main
ülesanne	doc_897182025873_item	2924762	et	4	main
minu	doc_897182025873_item	2924780	et	3	main
teha	doc_897182025873_item	2924786	et	3	main
oleks	doc_897182025873_item	2924792	et	3	main
näiteks	doc_897182025873_item	2924796	et	4	main
kes	doc_897182025873_item	2924799	et	4	main
ma	doc_897182025873_item	2924815	et	3	main
tea	doc_897182025873_item	2924825	et	4	main
veel	doc_897182025873_item	2924826	et	4	main
ma	doc_897182025873_item	2924828	et	3	main
aga	doc_897182025873_item	2924832	et	3	main
ma	doc_897182025873_item	2924833	et	3	main
tean	doc_897182025873_item	2924834	et	3	main
täpselt	doc_897182025873_item	2924835	et	4	main
et	doc_897182025873_item	2924836	et	3	main
ma	doc_897182025873_item	2924837	et	3	main
tahan	doc_897182025873_item	2924838	et	3	main
edasi	doc_897182025873_item	2924839	et	3	main
õppida	doc_897182025873_item	2924840	et	3	main
vastus	doc_899326610084_item	2924841	et	3	main
mida	doc_899326610084_item	2924844	et	4	main
kui	doc_899326610084_item	2924847	et	3	main
kultuur	doc_899326610084_item	2924858	et	3	main
on	doc_899326610084_item	2924859	et	4	main
see	doc_899326610084_item	2924862	et	3	main
et	doc_899326610084_item	2924873	et	3	main
peab	doc_899326610084_item	2924876	et	4	main
oma	doc_899326610084_item	2924878	et	4	main
laulupeod	doc_899326610084_item	2924924	et	4	main
tundub	doc_899326610084_item	2924926	et	3	main
on	doc_899326610084_item	2924935	et	4	main
palju	doc_899326610084_item	2924936	et	4	main
traditsioone	doc_899326610084_item	2924937	et	3	main
ja	doc_899326610084_item	2924938	et	3	main
sellest	doc_899326610084_item	2924951	et	4	main
vastus	doc_899326610085_item	2924952	et	3	main
eesti	doc_899326610085_item	2924971	et	4	main
inimene	doc_897182025873_item	2924711	et	3	main
head	doc_897182025873_item	2924730	et	4	main
haridust	doc_897182025873_item	2924731	et	4	main
saada	doc_897182025873_item	2924743	et	4	main
haridust	doc_897182025873_item	2924746	et	4	main
õppida	doc_897182025873_item	2924750	et	3	main
ülikoolis	doc_897182025873_item	2924752	et	4	main
ülesanded	doc_897182025873_item	2924755	et	3	main
sa	doc_897182025873_item	2924756	et	3	main
on	doc_897182025873_item	2924763	et	4	main
eksame	doc_897182025873_item	2924764	et	4	main
hästi	doc_897182025873_item	2924765	et	3	main
sooritada	doc_897182025873_item	2924766	et	3	main
ja	doc_897182025873_item	2924767	et	3	main
ära	doc_897182025873_item	2924768	et	4	main
sõita	doc_897182025873_item	2924769	et	3	main
vaja	doc_897182025873_item	2924789	et	4	main
et	doc_897182025873_item	2924790	et	3	main
alati	doc_897182025873_item	2924793	et	4	main
mind	doc_897182025873_item	2924801	et	4	main
aidata	doc_897182025873_item	2924802	et	4	main
kui	doc_897182025873_item	2924803	et	3	main
mul	doc_897182025873_item	2924804	et	3	main
tulevikus	doc_897182025873_item	2924814	et	4	main
midagi	doc_897182025873_item	2924724	et	4	main
saada	doc_897182025873_item	2924732	et	4	main
kooli	doc_897182025873_item	2924745	et	4	main
eksameid	doc_897182025873_item	2924748	et	3	main
ja	doc_897182025873_item	2924749	et	3	main
7	doc_897182025873_item	2924770	et	2	main
mis	doc_897182025873_item	2924771	et	4	main
mõjutab	doc_897182025873_item	2924772	et	3	main
sinu	doc_897182025873_item	2924773	et	3	main
tuju	doc_897182025873_item	2924781	et	4	main
soov	doc_897182025873_item	2924784	et	3	main
keegi	doc_897182025873_item	2924791	et	4	main
minu	doc_897182025873_item	2924797	et	3	main
ema	doc_897182025873_item	2924798	et	4	main
saaks	doc_897182025873_item	2924800	et	3	main
oma	doc_897182025873_item	2924812	et	4	main
õpenguid	doc_897182025873_item	2924813	et	4	main
saksamaale	doc_897182025873_item	2924817	et	4	main
ja	doc_897182025873_item	2924819	et	3	main
tulevikus	doc_897182025873_item	2924829	et	4	main
tahan	doc_897182025873_item	2924830	et	3	main
olla	doc_897182025873_item	2924831	et	3	main
arvan	doc_899326610084_item	2924872	et	3	main
inimene	doc_899326610084_item	2924875	et	3	main
minu	doc_899326610084_item	2924917	et	3	main
õppida	doc_897182025873_item	2924822	et	3	main
1	doc_899326610084_item	2924843	et	2	main
sõna	doc_899326610084_item	2924857	et	4	main
traditsioonidest	doc_899326610084_item	2924866	et	3	main
ja	doc_899326610084_item	2924867	et	3	main
paljudest	doc_899326610084_item	2924868	et	3	main
iga	doc_899326610084_item	2924874	et	4	main
kultuurit	doc_899326610084_item	2924879	et	4	main
aga	doc_899326610084_item	2924880	et	3	main
kahjuks	doc_899326610084_item	2924881	et	4	main
vähesed	doc_899326610084_item	2924882	et	3	main
meist	doc_899326610084_item	2924883	et	3	main
seda	doc_899326610084_item	2924884	et	3	main
tunnevad	doc_899326610084_item	2924885	et	3	main
2	doc_899326610084_item	2924886	et	2	main
eesti	doc_899326610084_item	2924887	et	4	main
kultuur	doc_899326610084_item	2924888	et	3	main
kui	doc_899326610084_item	2924889	et	3	main
ma	doc_899326610084_item	2924890	et	3	main
kuulan	doc_899326610084_item	2924891	et	3	main
sõnaühend	doc_899326610084_item	2924892	et	3	main
eesti	doc_899326610084_item	2924893	et	4	main
kultuur	doc_899326610084_item	2924894	et	3	main
ma	doc_899326610084_item	2924895	et	3	main
mõtlen	doc_899326610084_item	2924896	et	3	main
sellest	doc_899326610084_item	2924897	et	4	main
et	doc_899326610084_item	2924898	et	3	main
igal	doc_899326610084_item	2924899	et	3	main
rahval	doc_899326610084_item	2924900	et	3	main
on	doc_899326610084_item	2924901	et	4	main
oma	doc_899326610084_item	2924902	et	4	main
kultuur	doc_899326610084_item	2924903	et	3	main
ja	doc_899326610084_item	2924904	et	3	main
eestlastel	doc_899326610084_item	2924905	et	4	main
ka	doc_899326610084_item	2924906	et	3	main
on	doc_899326610084_item	2924907	et	4	main
oma	doc_899326610084_item	2924908	et	4	main
ajalooline	doc_899326610084_item	2924909	et	4	main
kultuur	doc_899326610084_item	2924910	et	3	main
ma	doc_899326610084_item	2924911	et	3	main
tulevad	doc_899326610084_item	2924919	et	4	main
rahvatantsud	doc_899326610084_item	2924921	et	3	main
rahvariided	doc_899326610084_item	2924923	et	3	main
eestlased	doc_899326610084_item	2924928	et	3	main
neid	doc_899326610084_item	2924944	et	4	main
hästi	doc_899326610084_item	2924945	et	3	main
ja	doc_899326610084_item	2924946	et	3	main
ei	doc_899326610084_item	2924947	et	4	main
mida	doc_899326610085_item	2924955	et	4	main
mõtlete	doc_899326610085_item	2924957	et	3	main
te	doc_899326610085_item	2924959	et	4	main
sõna	doc_899326610085_item	2924961	et	4	main
2	doc_899326610085_item	2924963	et	2	main
mida	doc_899326610085_item	2924964	et	4	main
kultuur	doc_899326610085_item	2924972	et	3	main
ei	doc_899326610085_item	2925013	et	4	main
saa	doc_899326610085_item	2925014	et	4	main
puutuda	doc_899326610085_item	2925015	et	3	main
vaid	doc_899326610085_item	2925016	et	3	main
kogu	doc_899326610085_item	2925019	et	4	main
2	doc_899326610085_item	2925022	et	2	main
kultuur	doc_899326610085_item	2925031	et	3	main
ka	doc_899326610085_item	2925032	et	3	main
ei	doc_899326610085_item	2925033	et	4	main
ole	doc_899326610085_item	2925034	et	4	main
suur	doc_899326610085_item	2925035	et	3	main
eesti	doc_899326610085_item	2925036	et	4	main
kultuur	doc_899326610085_item	2925037	et	3	main
midagi	doc_899326610085_item	2925046	et	4	main
aja	doc_899326610085_item	2925054	et	4	main
millal	doc_899326610085_item	2925055	et	3	main
see	doc_899326610085_item	2925056	et	3	main
väga	doc_899326610085_item	2925061	et	3	main
uus	doc_901133458138_item	2925068	et	3	main
tere	doc_901133458138_item	2925070	et	3	main
õpetaja	doc_901133458138_item	2925071	et	4	main
nimi	doc_901133458138_item	2925073	et	3	main
olen	doc_901133458138_item	2925077	et	3	main
vana	doc_901133458138_item	2925080	et	4	main
tähtsam	doc_901133458138_item	2925082	et	4	main
minu	doc_901133458138_item	2925083	et	3	main
elus	doc_901133458138_item	2925084	et	4	main
keelt	doc_901133458138_item	2925096	et	4	main
õppinud	doc_901133458138_item	2925103	et	4	main
on	doc_901133458138_item	2925112	et	4	main
põhjus	doc_901133458138_item	2925116	et	4	main
on	doc_901133458138_item	2925117	et	4	main
jutustavad	doc_901133458138_item	2925118	et	4	main
eesti	doc_901133458138_item	2925122	et	4	main
keelt	doc_901133458138_item	2925123	et	4	main
vaja	doc_901133458138_item	2925124	et	4	main
et	doc_901133458138_item	2925125	et	3	main
lugeda	doc_901133458138_item	2925126	et	3	main
et	doc_901133458138_item	2925148	et	3	main
kestma	doc_901133458138_item	2925158	et	3	main
kursid	doc_901133458138_item	2925159	et	3	main
mittu	doc_901133458138_item	2925161	et	4	main
kursusel	doc_901133458138_item	2925167	et	3	main
hea	doc_901133458138_item	2925171	et	4	main
keel	doc_901133458138_item	2925173	et	4	main
lugupidamisega	doc_901133458138_item	2925174	et	3	main
et	doc_899326610084_item	2924927	et	3	main
alati	doc_899326610084_item	2924929	et	4	main
ja	doc_899326610084_item	2924931	et	3	main
kombesid	doc_899326610084_item	2924939	et	4	main
aga	doc_899326610084_item	2924940	et	3	main
ma	doc_899326610084_item	2924941	et	3	main
ei	doc_899326610084_item	2924942	et	4	main
palju	doc_899326610084_item	2924949	et	4	main
1	doc_899326610085_item	2924954	et	2	main
kultuur	doc_899326610085_item	2924974	et	3	main
jaoks	doc_899326610085_item	2924977	et	4	main
hea	doc_899326610085_item	2924978	et	4	main
käitumine	doc_899326610085_item	2924979	et	4	main
hea	doc_899326610085_item	2924980	et	4	main
suhtlemine	doc_899326610085_item	2924981	et	4	main
kultuur	doc_899326610085_item	2924982	et	3	main
kogu	doc_899326610085_item	2924983	et	4	main
aeg	doc_899326610085_item	2924984	et	3	main
areneb	doc_899326610085_item	2924985	et	3	main
aga	doc_899326610085_item	2924986	et	3	main
see	doc_899326610085_item	2924987	et	3	main
arenemine	doc_899326610085_item	2924988	et	4	main
mitte	doc_899326610085_item	2924989	et	3	main
kogu	doc_899326610085_item	2924990	et	4	main
aeg	doc_899326610085_item	2924991	et	3	main
liigub	doc_899326610085_item	2924992	et	3	main
paremale	doc_899326610085_item	2924993	et	4	main
poole	doc_899326610085_item	2924994	et	4	main
kultuur	doc_899326610085_item	2924995	et	3	main
see	doc_899326610085_item	2924996	et	3	main
on	doc_899326610085_item	2924997	et	4	main
see	doc_899326610085_item	2924998	et	3	main
mis	doc_899326610085_item	2924999	et	4	main
jaanud	doc_899326610085_item	2925000	et	4	main
meile	doc_899326610085_item	2925001	et	4	main
meie	doc_899326610085_item	2925002	et	4	main
vanematest	doc_899326610085_item	2925003	et	4	main
ja	doc_899326610085_item	2925004	et	3	main
mis	doc_899326610085_item	2925005	et	4	main
me	doc_899326610085_item	2925006	et	4	main
anname	doc_899326610085_item	2925007	et	3	main
edasi	doc_899326610085_item	2925008	et	3	main
kultuur	doc_899326610085_item	2925009	et	3	main
see	doc_899326610085_item	2925017	et	3	main
tuntav	doc_899326610085_item	2925021	et	4	main
kultuur	doc_899326610085_item	2925024	et	3	main
kultuur	doc_899326610085_item	2925049	et	3	main
eesti	doc_899326610085_item	2925058	et	4	main
sellest	doc_899326610085_item	2925065	et	4	main
on	doc_901133458138_item	2925074	et	4	main
ma	doc_901133458138_item	2925076	et	3	main
on	doc_901133458138_item	2925085	et	4	main
armastan	doc_901133458138_item	2925088	et	3	main
oma	doc_901133458138_item	2925091	et	4	main
sõpraga	doc_901133458138_item	2925092	et	4	main
ja	doc_901133458138_item	2925093	et	3	main
puhkada	doc_901133458138_item	2925094	et	4	main
olen	doc_901133458138_item	2925097	et	3	main
aastat	doc_901133458138_item	2925100	et	3	main
olen	doc_901133458138_item	2925102	et	3	main
inglisi	doc_901133458138_item	2925104	et	4	main
minu	doc_901133458138_item	2925113	et	3	main
soov	doc_901133458138_item	2925114	et	3	main
on	doc_901133458138_item	2925121	et	4	main
nii	doc_901133458138_item	2925131	et	3	main
ma	doc_901133458138_item	2925133	et	3	main
kuulata	doc_901133458138_item	2925135	et	4	main
raadiot	doc_901133458138_item	2925136	et	3	main
ei	doc_901133458138_item	2925149	et	4	main
aru	doc_901133458138_item	2925151	et	4	main
eestlased	doc_901133458138_item	2925152	et	3	main
ma	doc_901133458138_item	2925153	et	3	main
tahaksin	doc_901133458138_item	2925154	et	3	main
teada	doc_901133458138_item	2925155	et	3	main
loodan	doc_901133458138_item	2925164	et	3	main
minu	doc_901133458140_item	2925281	et	3	main
töö	doc_901133458140_item	2925282	et	4	main
laheb	doc_901133458140_item	2925283	et	4	main
ole	doc_901133458140_item	2925295	et	4	main
minu	doc_901133458140_item	2925298	et	3	main
tagasihoidlik	doc_901133458140_item	2925301	et	3	main
ole	doc_901133458140_item	2925309	et	4	main
mul	doc_901133458140_item	2925315	et	3	main
on	doc_901133458140_item	2925323	et	4	main
meel	doc_901133458140_item	2925325	et	4	main
juhusti	doc_901133458140_item	2925337	et	4	main
ma	doc_901133458140_item	2925339	et	3	main
inimise	doc_901133458141_item	2925348	et	4	main
tegurid	doc_901133458141_item	2925360	et	3	main
elu	doc_901133458141_item	2925362	et	4	main
lapsele	doc_901133458141_item	2925369	et	4	main
lapsepõlves	doc_901133458141_item	2925370	et	4	main
teised	doc_901133458141_item	2925378	et	4	main
veel	doc_901133458141_item	2925379	et	4	main
elab	doc_901133458141_item	2925393	et	3	main
sellepärast	doc_901133458141_item	2925421	et	3	main
elukutse	doc_901133458141_item	2925423	et	4	main
on	doc_901133458141_item	2925426	et	4	main
oleks	doc_901133458141_item	2925439	et	3	main
tema	doc_901133458141_item	2925447	et	4	main
hea	doc_901133458141_item	2925449	et	4	main
ka	doc_901133458141_item	2925462	et	3	main
on	doc_901133458141_item	2925465	et	4	main
temaks	doc_901133458141_item	2925469	et	3	main
parem	doc_901133458141_item	2925472	et	4	main
raske	doc_901133458141_item	2925489	et	4	main
temaks	doc_901133458141_item	2925499	et	3	main
tähtkuju	doc_901133458141_item	2925502	et	4	main
inimese	doc_901133458141_item	2925507	et	4	main
elu	doc_901133458141_item	2925508	et	4	main
sellepärast	doc_901133458141_item	2925509	et	3	main
eesti	doc_899326610085_item	2925023	et	4	main
eesti	doc_899326610085_item	2925025	et	4	main
on	doc_899326610085_item	2925026	et	4	main
laenavad	doc_899326610085_item	2925043	et	4	main
teistest	doc_899326610085_item	2925044	et	4	main
kultuuridest	doc_899326610085_item	2925045	et	3	main
endale	doc_899326610085_item	2925047	et	4	main
eesti	doc_899326610085_item	2925048	et	4	main
peale	doc_899326610085_item	2925052	et	4	main
nõukogumise	doc_899326610085_item	2925053	et	4	main
kultuur	doc_899326610085_item	2925059	et	3	main
tahaks	doc_899326610085_item	2925063	et	3	main
rohkem	doc_899326610085_item	2925067	et	4	main
minu	doc_901133458138_item	2925072	et	3	main
19	doc_901133458138_item	2925078	et	2	main
jalutada	doc_901133458138_item	2925090	et	3	main
õppinud	doc_901133458138_item	2925098	et	4	main
varem	doc_901133458138_item	2925101	et	4	main
keel	doc_901133458138_item	2925105	et	4	main
esimene	doc_901133458138_item	2925106	et	3	main
miks	doc_901133458138_item	2925108	et	4	main
tulin	doc_901133458138_item	2925109	et	3	main
sellele	doc_901133458138_item	2925110	et	4	main
kursusele	doc_901133458138_item	2925111	et	3	main
ramatuid	doc_901133458138_item	2925129	et	4	main
edasi	doc_901133458138_item	2925132	et	3	main
kardan	doc_901133458138_item	2925146	et	4	main
nädalas	doc_901133458138_item	2925163	et	3	main
väga	doc_901133458138_item	2925170	et	3	main
harjutus	doc_901133458140_item	2925266	et	4	main
ostsin	doc_901133458140_item	2925268	et	3	main
sootsalt	doc_901133458140_item	2925270	et	4	main
see	doc_901133458140_item	2925277	et	3	main
suur	doc_901133458140_item	2925279	et	3	main
maht	doc_901133458140_item	2925280	et	3	main
tulekahju	doc_901133458140_item	2925288	et	4	main
mul	doc_901133458140_item	2925289	et	3	main
rohkem	doc_901133458140_item	2925307	et	4	main
infot	doc_901133458140_item	2925312	et	3	main
kirja	doc_901133458140_item	2925313	et	4	main
oli	doc_901133458140_item	2925316	et	3	main
et	doc_901133458140_item	2925321	et	3	main
sõnu	doc_901133458140_item	2925331	et	4	main
tuleb	doc_901133458140_item	2925332	et	3	main
ootame	doc_901133458140_item	2925335	et	3	main
kui	doc_901133458140_item	2925338	et	3	main
kõige	doc_901133458141_item	2925350	et	4	main
ma	doc_901133458141_item	2925354	et	3	main
mõjutab	doc_901133458141_item	2925357	et	3	main
ja	doc_901133458141_item	2925377	et	3	main
sünnib	doc_901133458141_item	2925391	et	3	main
ja	doc_901133458141_item	2925395	et	3	main
dokument	doc_901133458138_item	2925069	et	3	main
aastat	doc_901133458138_item	2925079	et	3	main
kõige	doc_901133458138_item	2925081	et	4	main
majusid	doc_901133458138_item	2925089	et	4	main
eesti	doc_901133458138_item	2925095	et	4	main
vanemad	doc_901133458138_item	2925119	et	4	main
mul	doc_901133458138_item	2925120	et	3	main
ja	doc_901133458138_item	2925130	et	3	main
tahan	doc_901133458138_item	2925134	et	3	main
ma	doc_901133458138_item	2925137	et	3	main
tahan	doc_901133458138_item	2925138	et	3	main
rääkida	doc_901133458138_item	2925139	et	3	main
eestlasega	doc_901133458138_item	2925140	et	3	main
ma	doc_901133458138_item	2925141	et	3	main
tahan	doc_901133458138_item	2925142	et	3	main
kirjutad	doc_901133458138_item	2925143	et	3	main
dokumendit	doc_901133458138_item	2925144	et	4	main
ma	doc_901133458138_item	2925145	et	3	main
saa	doc_901133458138_item	2925150	et	4	main
kui	doc_901133458138_item	2925156	et	3	main
ja	doc_901133458138_item	2925160	et	3	main
kord	doc_901133458138_item	2925162	et	4	main
et	doc_901133458138_item	2925165	et	3	main
õppin	doc_901133458138_item	2925169	et	4	main
eesti	doc_901133458138_item	2925172	et	4	main
pükseid	doc_901133458140_item	2925269	et	4	main
ma	doc_901133458140_item	2925271	et	3	main
käitun	doc_901133458140_item	2925272	et	3	main
on	doc_901133458140_item	2925275	et	4	main
paevikut	doc_901133458140_item	2925273	et	4	main
tagakaas	doc_901133458140_item	2925274	et	3	main
korusel	doc_901133458140_item	2925286	et	4	main
tekis	doc_901133458140_item	2925287	et	3	main
ei	doc_901133458140_item	2925294	et	4	main
tütart	doc_901133458140_item	2925297	et	3	main
ei	doc_901133458140_item	2925308	et	4	main
noogutan	doc_901133458140_item	2925320	et	3	main
mul	doc_901133458140_item	2925322	et	3	main
hääldata	doc_901133458140_item	2925334	et	3	main
mis	doc_901133458141_item	2925346	et	4	main
span	doc_901133458141_item	2925352	et	4	main
väga	doc_901133458141_item	2925358	et	3	main
tema	doc_901133458141_item	2925371	et	4	main
valib	doc_901133458141_item	2925372	et	3	main
mulle	doc_901133458141_item	2925380	et	4	main
tundub	doc_901133458141_item	2925381	et	3	main
et	doc_901133458141_item	2925382	et	3	main
mõjutab	doc_901133458141_item	2925383	et	3	main
sünnikoht	doc_901133458141_item	2925384	et	3	main
ja	doc_901133458141_item	2925385	et	3	main
elukoht	doc_901133458141_item	2925386	et	3	main
sellepärast	doc_901133458141_item	2925387	et	3	main
et	doc_901133458141_item	2925388	et	3	main
kui	doc_901133458141_item	2925389	et	3	main
vaja	doc_901133458141_item	2925427	et	4	main
kui	doc_901133458141_item	2925428	et	3	main
inimene	doc_901133458141_item	2925429	et	3	main
kutsekoolis	doc_901133458141_item	2925434	et	4	main
töötanud	doc_901133458141_item	2925440	et	4	main
tööle	doc_901133458141_item	2925442	et	3	main
veel	doc_901133458141_item	2925458	et	4	main
välimus	doc_901133458141_item	2925459	et	3	main
natukese	doc_901133458141_item	2925460	et	4	main
oleb	doc_901133458141_item	2925470	et	4	main
temaga	doc_901133458141_item	2925487	et	3	main
inimene	doc_901133458141_item	2925492	et	3	main
on	doc_901133458141_item	2925494	et	4	main
väga	doc_901133458141_item	2925495	et	3	main
lihtsalt	doc_901133458141_item	2925496	et	4	main
iseloom	doc_901133458141_item	2925497	et	3	main
mõjuta	doc_901133458141_item	2925506	et	4	main
span	doc_901133458141_item	2925517	et	4	main
minu	doc_901133458141_item	2925518	et	3	main
kui	doc_901133458141_item	2925520	et	3	main
tugev	doc_901133458141_item	2925524	et	4	main
et	doc_901133458141_item	2925532	et	3	main
meie	doc_901133458141_item	2925534	et	4	main
ajas	doc_901133458141_item	2925535	et	4	main
ilma	doc_901133458141_item	2925536	et	4	main
rahaga	doc_901133458141_item	2925543	et	4	main
kui	doc_901133458141_item	2925549	et	3	main
span	doc_901133458141_item	2925567	et	4	main
on	doc_901133458141_item	2925569	et	4	main
siiski	doc_901133458141_item	2925571	et	4	main
inimene	doc_901133458141_item	2925572	et	3	main
elus	doc_901133458141_item	2925573	et	4	main
kes	doc_901133458141_item	2925577	et	4	main
ma	doc_901133458140_item	2925267	et	3	main
korda	doc_901133458140_item	2925284	et	4	main
kaheksandal	doc_901133458140_item	2925285	et	3	main
inspiratsioni	doc_901133458140_item	2925292	et	4	main
mul	doc_901133458140_item	2925293	et	3	main
loomingeist	doc_901133458140_item	2925296	et	3	main
õde	doc_901133458140_item	2925299	et	4	main
ei	doc_901133458140_item	2925302	et	4	main
soovi	doc_901133458140_item	2925303	et	4	main
rohkem	doc_901133458140_item	2925304	et	4	main
sirvitada	doc_901133458140_item	2925305	et	4	main
panema	doc_901133458140_item	2925314	et	3	main
edukast	doc_901133458140_item	2925317	et	4	main
õde	doc_901133458140_item	2925318	et	4	main
ma	doc_901133458140_item	2925319	et	3	main
hea	doc_901133458140_item	2925324	et	4	main
aitasin	doc_901133458140_item	2925326	et	3	main
vanaemal	doc_901133458140_item	2925327	et	3	main
tänavat	doc_901133458140_item	2925328	et	4	main
üle	doc_901133458140_item	2925329	et	3	main
minna	doc_901133458140_item	2925330	et	3	main
sobivat	doc_901133458140_item	2925336	et	4	main
siis	doc_901133458140_item	2925341	et	3	main
maha	doc_901133458140_item	2925343	et	4	main
dokument	doc_901133458141_item	2925345	et	3	main
mõjutab	doc_901133458141_item	2925347	et	3	main
elu	doc_901133458141_item	2925349	et	4	main
span	doc_901133458141_item	2925353	et	4	main
vanemad	doc_901133458141_item	2925368	et	4	main
kool	doc_901133458141_item	2925376	et	4	main
ja	doc_901133458141_item	2925392	et	3	main
linnas	doc_901133458141_item	2925394	et	4	main
õpinud	doc_901133458141_item	2925431	et	4	main
siis	doc_901133458141_item	2925437	et	3	main
ei	doc_901133458141_item	2925438	et	4	main
aga	doc_901133458141_item	2925445	et	3	main
mõjutab	doc_901133458141_item	2925461	et	3	main
siis	doc_901133458141_item	2925468	et	3	main
raske	doc_901133458141_item	2925483	et	4	main
iseloom	doc_901133458141_item	2925484	et	3	main
siis	doc_901133458141_item	2925485	et	3	main
suhelda	doc_901133458141_item	2925486	et	4	main
ja	doc_901133458141_item	2925498	et	3	main
usu	doc_901133458141_item	2925513	et	4	main
ja	doc_901133458141_item	2925515	et	3	main
ausalt	doc_901133458141_item	2925522	et	4	main
tundub	doc_901133458141_item	2925531	et	3	main
rahata	doc_901133458141_item	2925537	et	4	main
sellepärast	doc_901133458141_item	2925540	et	3	main
või	doc_901133458141_item	2925542	et	4	main
kõike	doc_901133458141_item	2925545	et	4	main
elama	doc_901133458141_item	2925546	et	3	main
mulle	doc_901133458141_item	2925563	et	4	main
tundub	doc_901133458141_item	2925564	et	3	main
on	doc_901133458141_item	2925574	et	4	main
katki	doc_901133458140_item	2925276	et	4	main
on	doc_901133458140_item	2925278	et	4	main
ei	doc_901133458140_item	2925290	et	4	main
ole	doc_901133458140_item	2925291	et	4	main
on	doc_901133458140_item	2925300	et	4	main
puudujääki	doc_901133458140_item	2925306	et	4	main
eestis	doc_901133458140_item	2925310	et	3	main
pean	doc_901133458140_item	2925311	et	4	main
õigesti	doc_901133458140_item	2925333	et	3	main
saan	doc_901133458140_item	2925340	et	4	main
kirjutan	doc_901133458140_item	2925342	et	3	main
uus	doc_901133458141_item	2925344	et	3	main
rohkem	doc_901133458141_item	2925351	et	4	main
arvan	doc_901133458141_item	2925355	et	3	main
et	doc_901133458141_item	2925356	et	3	main
palju	doc_901133458141_item	2925359	et	4	main
inimese	doc_901133458141_item	2925361	et	4	main
mulle	doc_901133458141_item	2925363	et	4	main
tundub	doc_901133458141_item	2925364	et	3	main
et	doc_901133458141_item	2925365	et	3	main
esiteks	doc_901133458141_item	2925366	et	3	main
mõjutab	doc_901133458141_item	2925367	et	3	main
teda	doc_901133458141_item	2925373	et	4	main
riided	doc_901133458141_item	2925374	et	3	main
lasteaed	doc_901133458141_item	2925375	et	3	main
inimene	doc_901133458141_item	2925390	et	3	main
isegi	doc_901133458141_item	2925396	et	4	main
siis	doc_901133458141_item	2925398	et	3	main
pealinnas	doc_901133458141_item	2925397	et	4	main
on	doc_901133458141_item	2925399	et	4	main
tema	doc_901133458141_item	2925400	et	4	main
enam	doc_901133458141_item	2925401	et	4	main
arenenud	doc_901133458141_item	2925402	et	4	main
kui	doc_901133458141_item	2925403	et	3	main
sünniks	doc_901133458141_item	2925404	et	4	main
tema	doc_901133458141_item	2925405	et	4	main
maal	doc_901133458141_item	2925406	et	4	main
tema	doc_901133458141_item	2925407	et	4	main
oleb	doc_901133458141_item	2925408	et	4	main
teama	doc_901133458141_item	2925409	et	4	main
rohkem	doc_901133458141_item	2925410	et	4	main
linnaelu	doc_901133458141_item	2925411	et	4	main
ja	doc_901133458141_item	2925412	et	3	main
askelduste	doc_901133458141_item	2925413	et	4	main
kohta	doc_901133458141_item	2925414	et	4	main
tulevikus	doc_901133458141_item	2925415	et	4	main
mulle	doc_901133458141_item	2925416	et	4	main
tundub	doc_901133458141_item	2925417	et	3	main
et	doc_901133458141_item	2925418	et	3	main
mõjutab	doc_901133458141_item	2925419	et	3	main
haridus	doc_901133458141_item	2925420	et	3	main
et	doc_901133458141_item	2925422	et	3	main
valikul	doc_901133458141_item	2925424	et	3	main
tema	doc_901133458141_item	2925425	et	4	main
ülikoolis	doc_901133458141_item	2925432	et	4	main
või	doc_901133458141_item	2925433	et	4	main
hea	doc_901133458141_item	2925441	et	4	main
kõrge	doc_901133458141_item	2925443	et	4	main
palgaga	doc_901133458141_item	2925444	et	3	main
kui	doc_901133458141_item	2925446	et	3	main
palgaga	doc_901133458141_item	2925457	et	3	main
inimene	doc_901133458141_item	2925464	et	3	main
suhe	doc_901133458141_item	2925471	et	3	main
iseloom	doc_901133458141_item	2925473	et	3	main
ka	doc_901133458141_item	2925475	et	3	main
ei	doc_901133458141_item	2925430	et	4	main
või	doc_901133458141_item	2925435	et	4	main
polütehnikumis	doc_901133458141_item	2925436	et	3	main
saab	doc_901133458141_item	2925448	et	3	main
elukutse	doc_901133458141_item	2925450	et	4	main
siis	doc_901133458141_item	2925451	et	3	main
oleb	doc_901133458141_item	2925452	et	4	main
tema	doc_901133458141_item	2925453	et	4	main
töötama	doc_901133458141_item	2925454	et	3	main
tööle	doc_901133458141_item	2925455	et	3	main
kõrge	doc_901133458141_item	2925456	et	4	main
kui	doc_901133458141_item	2925463	et	3	main
meeldiva	doc_901133458141_item	2925466	et	4	main
välimusega	doc_901133458141_item	2925467	et	3	main
mõjutab	doc_901133458141_item	2925474	et	3	main
aga	doc_901133458141_item	2925476	et	3	main
mitte	doc_901133458141_item	2925478	et	3	main
mõnikord	doc_901133458141_item	2925488	et	3	main
on	doc_901133458141_item	2925491	et	4	main
kellel	doc_901133458141_item	2925493	et	4	main
siirutab	doc_901133458141_item	2925500	et	3	main
meelest	doc_901133458141_item	2925504	et	4	main
ei	doc_901133458141_item	2925505	et	4	main
ma	doc_901133458141_item	2925511	et	3	main
on	doc_901133458141_item	2925477	et	4	main
palju	doc_901133458141_item	2925479	et	4	main
kui	doc_901133458141_item	2925480	et	3	main
inimene	doc_901133458141_item	2925481	et	3	main
on	doc_901133458141_item	2925482	et	4	main
aga	doc_901133458141_item	2925490	et	3	main
inimeseid	doc_901133458141_item	2925501	et	4	main
minu	doc_901133458141_item	2925503	et	3	main
ei	doc_901133458141_item	2925512	et	4	main
räägitakse	doc_901133458141_item	2925521	et	3	main
väga	doc_901133458141_item	2925523	et	3	main
raha	doc_901133458141_item	2925526	et	4	main
eriti	doc_901133458141_item	2925527	et	3	main
on	doc_901133458141_item	2925528	et	4	main
praegu	doc_901133458141_item	2925529	et	3	main
halbu	doc_901133458141_item	2925539	et	3	main
õpima	doc_901133458141_item	2925548	et	4	main
tahad	doc_901133458141_item	2925551	et	3	main
ja	doc_901133458141_item	2925553	et	3	main
kuigi	doc_901133458141_item	2925555	et	3	main
on	doc_901133458141_item	2925558	et	4	main
õnn	doc_901133458141_item	2925559	et	3	main
räägivad	doc_901133458141_item	2925560	et	3	main
palju	doc_901133458141_item	2925561	et	4	main
inimesed	doc_901133458141_item	2925562	et	3	main
kõik	doc_901133458141_item	2925570	et	4	main
span	doc_901133458141_item	2925581	et	4	main
arvan	doc_901133458143_item	2925702	et	3	main
sa	doc_901133458143_item	2925708	et	3	main
et	doc_901133458141_item	2925510	et	3	main
horoskopisse	doc_901133458141_item	2925514	et	4	main
tähtkujusse	doc_901133458141_item	2925516	et	3	main
meelest	doc_901133458141_item	2925519	et	4	main
mulle	doc_901133458141_item	2925530	et	4	main
on	doc_901133458141_item	2925533	et	4	main
sa	doc_901133458141_item	2925550	et	3	main
reisima	doc_901133458141_item	2925552	et	3	main
teised	doc_901133458141_item	2925554	et	4	main
rahas	doc_901133458141_item	2925557	et	4	main
vastupidi	doc_901133458141_item	2925566	et	3	main
nii	doc_901133458141_item	2925568	et	3	main
palju	doc_901133458141_item	2925575	et	4	main
teguri	doc_901133458141_item	2925576	et	3	main
tema	doc_901133458141_item	2925579	et	4	main
ma	doc_901133458143_item	2925701	et	3	main
ole	doc_901133458143_item	2925705	et	4	main
koolis	doc_901133458143_item	2925710	et	4	main
aga	doc_901133458143_item	2925711	et	3	main
kuidas	doc_901133458143_item	2925712	et	3	main
sa	doc_901133458143_item	2925713	et	3	main
tulid	doc_901133458143_item	2925714	et	4	main
tahtis	doc_901133458143_item	2925725	et	3	main
kuidas	doc_901133458143_item	2925727	et	3	main
leidsid	doc_901133458143_item	2925729	et	4	main
kudas	doc_901133458143_item	2925789	et	4	main
ei	doc_901133458143_item	2925795	et	4	main
on	doc_901133458143_item	2925810	et	4	main
jäägi	doc_901133458145_item	2925877	et	4	main
da	doc_901133458145_item	2925879	et	4	main
maht	doc_901133458145_item	2925914	et	3	main
kujundus	doc_901133458145_item	2925920	et	4	main
mõjutab	doc_901133458141_item	2925525	et	3	main
väga	doc_901133458141_item	2925538	et	3	main
et	doc_901133458141_item	2925541	et	3	main
teha	doc_901133458141_item	2925544	et	3	main
hästi	doc_901133458141_item	2925547	et	3	main
mitte	doc_901133458141_item	2925556	et	3	main
on	doc_901133458141_item	2925565	et	4	main
mõjutab	doc_901133458141_item	2925578	et	3	main
elu	doc_901133458141_item	2925580	et	4	main
sünnikoht	doc_901133458143_item	2925703	et	3	main
kuidas	doc_901133458143_item	2925707	et	3	main
õppid	doc_901133458143_item	2925709	et	4	main
siis	doc_901133458143_item	2925716	et	3	main
vaatab	doc_901133458143_item	2925717	et	3	main
kust	doc_901133458143_item	2925718	et	4	main
päras	doc_901133458143_item	2925719	et	3	main
sa	doc_901133458143_item	2925720	et	3	main
paremat	doc_901133458143_item	2925732	et	4	main
sõbra	doc_901133458143_item	2925733	et	3	main
sa	doc_901133458143_item	2925742	et	3	main
halvasti	doc_901133458143_item	2925744	et	3	main
väga	doc_901133458143_item	2925752	et	3	main
ei	doc_901133458143_item	2925761	et	4	main
tähtis	doc_901133458143_item	2925788	et	4	main
raha	doc_901133458143_item	2925793	et	4	main
ja	doc_901133458143_item	2925794	et	3	main
vaja	doc_901133458143_item	2925808	et	4	main
see	doc_901133458143_item	2925809	et	3	main
span	doc_901133458143_item	2925815	et	4	main
harjutus	doc_901133458145_item	2925871	et	4	main
tagasihoidlik	doc_901133458145_item	2925872	et	3	main
minna	doc_901133458145_item	2925911	et	3	main
ut	doc_901133458145_item	2925916	et	4	main
t	doc_901133458145_item	2925918	et	4	main
kujundust	doc_901133458145_item	2925922	et	4	main
inspiratsion	doc_901133458145_item	2925926	et	4	main
jahaks	doc_901133458145_item	2925937	et	4	main
tulemus	doc_901133458145_item	2925939	et	3	main
kõige	doc_901133458146_item	2925952	et	4	main
esimene	doc_901133458146_item	2925979	et	3	main
miks	doc_901133458146_item	2925981	et	4	main
sellele	doc_901133458146_item	2925983	et	4	main
kursusele	doc_901133458146_item	2925984	et	3	main
on	doc_901133458146_item	2925985	et	4	main
minu	doc_901133458146_item	2925986	et	3	main
soov	doc_901133458146_item	2925987	et	3	main
omandada	doc_901133458146_item	2925988	et	3	main
põhjus	doc_901133458146_item	2925992	et	4	main
et	doc_901133458146_item	2925994	et	3	main
vaja	doc_901133458146_item	2926011	et	4	main
lugeda	doc_901133458146_item	2926013	et	3	main
ajalehte	doc_901133458146_item	2926015	et	4	main
kuulata	doc_901133458146_item	2926018	et	4	main
eestlastega	doc_901133458146_item	2926027	et	4	main
et	doc_901133458146_item	2926028	et	3	main
siis	doc_901133458146_item	2926029	et	3	main
minu	doc_901133458146_item	2926030	et	3	main
eesti	doc_901133458146_item	2926031	et	4	main
ei	doc_901133458146_item	2926053	et	4	main
tea	doc_901133458146_item	2926054	et	4	main
me	doc_901133458146_item	2926061	et	4	main
tundides	doc_901133458146_item	2926066	et	3	main
et	doc_901133458146_item	2926068	et	3	main
pärast	doc_901133458146_item	2926069	et	4	main
minu	doc_901133458146_item	2926070	et	3	main
parem	doc_901133458146_item	2926074	et	4	main
uus	doc_901133458143_item	2925699	et	3	main
vaja	doc_901133458143_item	2925706	et	4	main
tööd	doc_901133458143_item	2925715	et	4	main
on	doc_901133458143_item	2925723	et	4	main
sa	doc_901133458143_item	2925728	et	3	main
palju	doc_901133458143_item	2925730	et	4	main
ja	doc_901133458143_item	2925731	et	3	main
sule	doc_901133458143_item	2925740	et	4	main
hea	doc_901133458143_item	2925746	et	4	main
nõus	doc_901133458143_item	2925747	et	4	main
tahtis	doc_901133458143_item	2925753	et	3	main
on	doc_901133458143_item	2925782	et	4	main
on	doc_901133458143_item	2925791	et	4	main
palju	doc_901133458143_item	2925792	et	4	main
sulle	doc_901133458143_item	2925801	et	3	main
raha	doc_901133458143_item	2925805	et	4	main
dokument	doc_901133458143_item	2925700	et	3	main
ei	doc_901133458143_item	2925704	et	4	main
sõbrad	doc_901133458143_item	2925722	et	3	main
väga	doc_901133458143_item	2925724	et	3	main
siis	doc_901133458143_item	2925734	et	3	main
sinu	doc_901133458143_item	2925735	et	3	main
elu	doc_901133458143_item	2925736	et	4	main
lihtsem	doc_901133458143_item	2925737	et	4	main
nad	doc_901133458143_item	2925738	et	3	main
aitavad	doc_901133458143_item	2925739	et	4	main
tunnub	doc_901133458143_item	2925743	et	4	main
on	doc_901133458143_item	2925751	et	4	main
inimese	doc_901133458143_item	2925756	et	4	main
tahtis	doc_901133458143_item	2925773	et	3	main
aga	doc_901133458143_item	2925774	et	3	main
kuidas	doc_901133458143_item	2925775	et	3	main
sa	doc_901133458143_item	2925776	et	3	main
töötab	doc_901133458143_item	2925777	et	3	main
koos	doc_901133458143_item	2925778	et	4	main
inimesega	doc_901133458143_item	2925779	et	3	main
siis	doc_901133458143_item	2925780	et	3	main
välimus	doc_901133458143_item	2925781	et	3	main
tähtis	doc_901133458143_item	2925783	et	4	main
haridus	doc_901133458143_item	2925784	et	3	main
see	doc_901133458143_item	2925785	et	3	main
sull	doc_901133458143_item	2925790	et	4	main
ole	doc_901133458143_item	2925796	et	4	main
ainult	doc_901133458143_item	2925811	et	4	main
paberit	doc_901133458143_item	2925812	et	3	main
span	doc_901133458143_item	2925813	et	4	main
ut	doc_901133458145_item	2925874	et	4	main
jäagi	doc_901133458145_item	2925876	et	4	main
vahva	doc_901133458145_item	2925919	et	4	main
se	doc_901133458145_item	2925930	et	4	main
st	doc_901133458145_item	2925931	et	3	main
juhuks	doc_901133458145_item	2925938	et	3	main
uus	doc_901133458146_item	2925942	et	3	main
tere	doc_901133458146_item	2925944	et	3	main
elus	doc_901133458146_item	2925955	et	4	main
ja	doc_901133458146_item	2925965	et	3	main
esti	doc_901133458146_item	2925967	et	4	main
sillamäe	doc_901133458146_item	2925976	et	3	main
teine	doc_901133458146_item	2925991	et	3	main
on	doc_901133458146_item	2925993	et	4	main
raadio	doc_901133458146_item	2926019	et	4	main
saateid	doc_901133458146_item	2926020	et	3	main
oled	doc_901133458143_item	2925721	et	3	main
elus	doc_901133458143_item	2925726	et	4	main
kuidas	doc_901133458143_item	2925741	et	3	main
anavad	doc_901133458143_item	2925745	et	4	main
span	doc_901133458143_item	2925748	et	4	main
välimus	doc_901133458143_item	2925749	et	3	main
see	doc_901133458143_item	2925750	et	3	main
inimesele	doc_901133458143_item	2925754	et	3	main
kudas	doc_901133458143_item	2925755	et	4	main
tootab	doc_901133458143_item	2925757	et	4	main
üksinda	doc_901133458143_item	2925758	et	4	main
siis	doc_901133458143_item	2925759	et	3	main
välimus	doc_901133458143_item	2925760	et	3	main
ole	doc_901133458143_item	2925762	et	4	main
tähtis	doc_901133458143_item	2925763	et	4	main
naiteks	doc_901133458143_item	2925764	et	4	main
minu	doc_901133458143_item	2925765	et	3	main
isa	doc_901133458143_item	2925766	et	4	main
juhtub	doc_901133458143_item	2925767	et	3	main
auto	doc_901133458143_item	2925768	et	4	main
ja	doc_901133458143_item	2925769	et	3	main
valimus	doc_901133458143_item	2925770	et	4	main
ei	doc_901133458143_item	2925771	et	4	main
ole	doc_901133458143_item	2925772	et	4	main
on	doc_901133458143_item	2925786	et	4	main
kõige	doc_901133458143_item	2925787	et	4	main
haridus	doc_901133458143_item	2925797	et	3	main
see	doc_901133458143_item	2925798	et	3	main
ei	doc_901133458143_item	2925799	et	4	main
aitab	doc_901133458143_item	2925800	et	3	main
span	doc_901133458143_item	2925802	et	4	main
ma	doc_901133458143_item	2925803	et	3	main
arvan	doc_901133458143_item	2925804	et	3	main
ei	doc_901133458143_item	2925806	et	4	main
ole	doc_901133458143_item	2925807	et	4	main
span	doc_901133458143_item	2925814	et	4	main
u	doc_901133458145_item	2925873	et	4	main
üle	doc_901133458145_item	2925913	et	3	main
da	doc_901133458145_item	2925924	et	4	main
i	doc_901133458145_item	2925927	et	4	main
it	doc_901133458145_item	2925928	et	4	main
tulemuse	doc_901133458145_item	2925940	et	3	main
xxxxx	doc_901133458146_item	2925949	et	4	main
olen	doc_901133458146_item	2925950	et	3	main
õpilane	doc_901133458146_item	2925951	et	3	main
õppimine	doc_901133458146_item	2925960	et	4	main
ma	doc_901133458146_item	2925961	et	3	main
armastan	doc_901133458146_item	2925962	et	3	main
õppida	doc_901133458146_item	2925963	et	3	main
loodust	doc_901133458146_item	2925966	et	4	main
õppinud	doc_901133458146_item	2925975	et	4	main
koolis	doc_901133458146_item	2925978	et	4	main
haridus	doc_901133458146_item	2925990	et	3	main
mulle	doc_901133458146_item	2925995	et	4	main
meeldib	doc_901133458146_item	2925996	et	3	main
loodus	doc_901133458146_item	2925997	et	4	main
ja	doc_901133458146_item	2925998	et	3	main
ma	doc_901133458146_item	2925999	et	3	main
tahan	doc_901133458146_item	2926000	et	3	main
et	doc_901133458146_item	2926001	et	3	main
eesti	doc_901133458146_item	2926009	et	4	main
eesti	doc_901133458146_item	2926040	et	4	main
natuke	doc_901133458146_item	2926051	et	4	main
et	doc_901133458146_item	2926052	et	3	main
reegleid	doc_901133458146_item	2926056	et	3	main
eesti	doc_901133458146_item	2926071	et	4	main
keel	doc_901133458146_item	2926072	et	4	main
спокойный	doc_901133458147_item	2926082	et	2	main
дефецит	doc_901133458147_item	2926085	et	2	main
tekkima	doc_901133458147_item	2926087	et	3	main
5	doc_901133458147_item	2926093	et	2	main
утрястись	doc_901133458147_item	2926096	et	2	main
9	doc_901133458147_item	2926108	et	2	main
постановка	doc_901133458147_item	2926123	et	2	main
sirvima	doc_901133458147_item	2926126	et	3	main
15	doc_901133458147_item	2926128	et	2	main
вдохновение	doc_901133458147_item	2926130	et	2	main
18	doc_901133458147_item	2926137	et	2	main
выгодно	doc_901133458147_item	2926139	et	2	main
juhuks	doc_901133458147_item	2926143	et	3	main
случаи	doc_901133458147_item	2926146	et	2	main
результат	doc_901133458147_item	2926148	et	2	main
kui	doc_901133458147_item	2926150	et	3	main
rääkida	doc_901133458147_item	2926156	et	3	main
midagi	doc_901133458147_item	2926158	et	4	main
käju	doc_901133458147_item	2926167	et	4	main
inimesed	doc_901133458147_item	2926176	et	3	main
edukas	doc_901133458147_item	2926183	et	4	main
mis	doc_901133458148_item	2926187	et	4	main
span	doc_901133458148_item	2926194	et	4	main
paljud	doc_901133458148_item	2926195	et	3	main
tema	doc_901133458148_item	2926205	et	4	main
elu	doc_901133458148_item	2926206	et	4	main
puudujääk	doc_901133458145_item	2925875	et	3	main
tekkima	doc_901133458145_item	2925878	et	3	main
tekkin	doc_901133458145_item	2925880	et	3	main
kirja	doc_901133458145_item	2925881	et	4	main
panema	doc_901133458145_item	2925882	et	3	main
kirja	doc_901133458145_item	2925883	et	4	main
panna	doc_901133458145_item	2925884	et	4	main
panen	doc_901133458145_item	2925885	et	3	main
kirja	doc_901133458145_item	2925886	et	4	main
korda	doc_901133458145_item	2925887	et	4	main
minema	doc_901133458145_item	2925888	et	3	main
korda	doc_901133458145_item	2925889	et	4	main
minna	doc_901133458145_item	2925890	et	3	main
lähen	doc_901133458145_item	2925891	et	3	main
korda	doc_901133458145_item	2925892	et	4	main
edukas	doc_901133458145_item	2925893	et	4	main
e	doc_901133458145_item	2925894	et	4	main
st	doc_901133458145_item	2925895	et	3	main
maha	doc_901133458145_item	2925896	et	4	main
kirjutama	doc_901133458145_item	2925897	et	3	main
kirjutada	doc_901133458145_item	2925898	et	3	main
maha	doc_901133458145_item	2925899	et	4	main
kirjutan	doc_901133458145_item	2925900	et	3	main
maha	doc_901133458145_item	2925901	et	4	main
nalja	doc_901133458145_item	2925902	et	4	main
heitma	doc_901133458145_item	2925903	et	3	main
heita	doc_901133458145_item	2925904	et	3	main
nalja	doc_901133458145_item	2925905	et	4	main
heidan	doc_901133458145_item	2925906	et	3	main
nalja	doc_901133458145_item	2925907	et	4	main
üle	doc_901133458145_item	2925908	et	3	main
minema	doc_901133458145_item	2925909	et	3	main
üle	doc_901133458145_item	2925910	et	3	main
lähen	doc_901133458145_item	2925912	et	3	main
u	doc_901133458145_item	2925915	et	4	main
tüttu	doc_901133458145_item	2925917	et	4	main
sirvima	doc_901133458145_item	2925923	et	3	main
keruline	doc_901133458145_item	2925929	et	4	main
põhjendusse	doc_901133458145_item	2925936	et	4	main
õpitaja	doc_901133458146_item	2925945	et	4	main
minu	doc_901133458146_item	2925946	et	3	main
nimi	doc_901133458146_item	2925947	et	3	main
on	doc_901133458146_item	2925948	et	4	main
on	doc_901133458146_item	2925956	et	4	main
minu	doc_901133458146_item	2925957	et	3	main
perekond	doc_901133458146_item	2925958	et	3	main
ja	doc_901133458146_item	2925959	et	3	main
varem	doc_901133458146_item	2925973	et	4	main
olen	doc_901133458146_item	2925974	et	3	main
kannuka	doc_901133458146_item	2925977	et	4	main
põhjus	doc_901133458146_item	2925980	et	4	main
tulin	doc_901133458146_item	2925982	et	3	main
kõik	doc_901133458146_item	2926002	et	4	main
see	doc_901133458146_item	2926003	et	3	main
oleks	doc_901133458146_item	2926004	et	3	main
kelt	doc_901133458146_item	2926010	et	3	main
et	doc_901133458146_item	2926012	et	3	main
eesti	doc_901133458146_item	2926014	et	4	main
ma	doc_901133458146_item	2926016	et	3	main
tahan	doc_901133458146_item	2926017	et	3	main
on	doc_901133458146_item	2926024	et	4	main
vaja	doc_901133458146_item	2926025	et	4	main
rääkida	doc_901133458146_item	2926026	et	3	main
sõnu	doc_901133458146_item	2926038	et	4	main
õigesti	doc_901133458146_item	2926039	et	3	main
kardan	doc_901133458146_item	2926050	et	4	main
grammatika	doc_901133458146_item	2926055	et	4	main
kas	doc_901133458146_item	2926060	et	3	main
hakkame	doc_901133458146_item	2926062	et	3	main
eesti	doc_901133458146_item	2926064	et	4	main
oodan	doc_901133458146_item	2926067	et	4	main
tagasihoidlik	doc_901133458147_item	2926081	et	3	main
2	doc_901133458147_item	2926083	et	2	main
4	doc_901133458147_item	2926089	et	2	main
записать	doc_901133458147_item	2926092	et	2	main
korda	doc_901133458147_item	2926094	et	4	main
minema	doc_901133458147_item	2926095	et	3	main
6	doc_901133458147_item	2926097	et	2	main
edukas	doc_901133458147_item	2926098	et	4	main
успешный	doc_901133458147_item	2926099	et	2	main
7	doc_901133458147_item	2926100	et	2	main
паразить	doc_901133458147_item	2926111	et	2	main
объем	doc_901133458147_item	2926114	et	2	main
kujunduse	doc_901133458145_item	2925921	et	4	main
n	doc_901133458145_item	2925925	et	4	main
viis	doc_901133458145_item	2925932	et	4	main
e	doc_901133458145_item	2925933	et	4	main
st	doc_901133458145_item	2925934	et	3	main
põhjendus	doc_901133458145_item	2925935	et	4	main
tulemust	doc_901133458145_item	2925941	et	4	main
dokument	doc_901133458146_item	2925943	et	3	main
tähtsan	doc_901133458146_item	2925953	et	4	main
minu	doc_901133458146_item	2925954	et	3	main
keele	doc_901133458146_item	2925964	et	4	main
keelt	doc_901133458146_item	2925968	et	4	main
olen	doc_901133458146_item	2925969	et	3	main
õppinud	doc_901133458146_item	2925970	et	4	main
kümme	doc_901133458146_item	2925971	et	3	main
aastat	doc_901133458146_item	2925972	et	3	main
kõrgem	doc_901133458146_item	2925989	et	4	main
kaitse	doc_901133458146_item	2926005	et	4	main
all	doc_901133458146_item	2926006	et	3	main
mul	doc_901133458146_item	2926007	et	3	main
on	doc_901133458146_item	2926008	et	4	main
eesti	doc_901133458146_item	2926021	et	4	main
mul	doc_901133458146_item	2926023	et	3	main
keel	doc_901133458146_item	2926032	et	4	main
oleks	doc_901133458146_item	2926033	et	3	main
keeles	doc_901133458146_item	2926041	et	4	main
ma	doc_901133458146_item	2926042	et	3	main
loodan	doc_901133458146_item	2926043	et	3	main
et	doc_901133458146_item	2926044	et	3	main
me	doc_901133458146_item	2926045	et	4	main
tegeleme	doc_901133458146_item	2926046	et	3	main
ma	doc_901133458146_item	2926057	et	3	main
lugupidamisega	doc_901133458146_item	2926075	et	3	main
xxxxxx	doc_901133458146_item	2926077	et	4	main
3	doc_901133458147_item	2926086	et	2	main
шутить	doc_901133458147_item	2926107	et	2	main
üle	doc_901133458147_item	2926109	et	3	main
11	doc_901133458147_item	2926115	et	2	main
13	doc_901133458147_item	2926121	et	2	main
представление	doc_901133458147_item	2926124	et	2	main
листать	doc_901133458147_item	2926127	et	2	main
16	doc_901133458147_item	2926131	et	2	main
сложный	doc_901133458147_item	2926133	et	2	main
tõsine	doc_901133458147_item	2926172	et	4	main
kui	doc_901133458147_item	2926175	et	3	main
alati	doc_901133458147_item	2926179	et	4	main
mõjutavad	doc_901133458148_item	2926188	et	4	main
elu	doc_901133458148_item	2926190	et	4	main
kõige	doc_901133458148_item	2926191	et	4	main
tegurid	doc_901133458148_item	2926196	et	3	main
mõjutavad	doc_901133458148_item	2926197	et	4	main
meie	doc_901133458148_item	2926198	et	4	main
sõltub	doc_901133458148_item	2926207	et	3	main
elus	doc_901133458148_item	2926213	et	4	main
ootamatus	doc_901133458148_item	2926229	et	4	main
midagi	doc_901133458148_item	2926240	et	4	main
tunnen	doc_901133458148_item	2926245	et	3	main
inimestele	doc_901133458148_item	2926247	et	3	main
isikuomadused	doc_901133458148_item	2926283	et	4	main
kui	doc_901133458148_item	2926284	et	3	main
on	doc_901133458148_item	2926293	et	4	main
on	doc_901133458148_item	2926303	et	4	main
kena	doc_901133458148_item	2926304	et	4	main
minu	doc_901133458148_item	2926309	et	3	main
positiivset	doc_901133458148_item	2926317	et	3	main
asi	doc_901133458148_item	2926329	et	4	main
nagu	doc_901133458148_item	2926336	et	3	main
välimuse	doc_901133458148_item	2926339	et	3	main
ei	doc_901133458148_item	2926360	et	4	main
on	doc_901133458148_item	2926402	et	4	main
uus	doc_901133458149_item	2926404	et	3	main
rohkem	doc_901133458149_item	2926411	et	4	main
span	doc_901133458149_item	2926412	et	4	main
span	doc_901133458149_item	2926413	et	4	main
ma	doc_901133458149_item	2926414	et	3	main
arvan	doc_901133458149_item	2926415	et	3	main
et	doc_901133458149_item	2926416	et	3	main
väga	doc_901133458149_item	2926425	et	3	main
ole	doc_901133458149_item	2926429	et	4	main
osa	doc_901133458149_item	2926432	et	4	main
sinu	doc_901133458149_item	2926433	et	3	main
sinu	doc_901133458149_item	2926442	et	3	main
sarnane	doc_901133458149_item	2926455	et	4	main
vanemad	doc_901133458149_item	2926456	et	4	main
keeles	doc_901133458146_item	2926022	et	4	main
parem	doc_901133458146_item	2926034	et	4	main
ma	doc_901133458146_item	2926035	et	3	main
tahan	doc_901133458146_item	2926036	et	3	main
kirjutada	doc_901133458146_item	2926037	et	3	main
põhjalikult	doc_901133458146_item	2926047	et	4	main
grammatikaga	doc_901133458146_item	2926048	et	3	main
ma	doc_901133458146_item	2926049	et	3	main
tahaksin	doc_901133458146_item	2926058	et	3	main
teada	doc_901133458146_item	2926059	et	3	main
kuulama	doc_901133458146_item	2926063	et	3	main
saateid	doc_901133458146_item	2926065	et	3	main
oleks	doc_901133458146_item	2926073	et	3	main
xxxxx	doc_901133458146_item	2926076	et	4	main
uus	doc_901133458147_item	2926078	et	3	main
1	doc_901133458147_item	2926080	et	2	main
puudujakk	doc_901133458147_item	2926084	et	3	main
kirja	doc_901133458147_item	2926090	et	4	main
maha	doc_901133458147_item	2926101	et	4	main
kirjutama	doc_901133458147_item	2926102	et	3	main
списывать	doc_901133458147_item	2926103	et	2	main
8	doc_901133458147_item	2926104	et	2	main
10	doc_901133458147_item	2926112	et	2	main
надоедливый	doc_901133458147_item	2926117	et	2	main
12	doc_901133458147_item	2926118	et	2	main
vahva	doc_901133458147_item	2926119	et	4	main
храбрый	doc_901133458147_item	2926120	et	2	main
kujundus	doc_901133458147_item	2926122	et	4	main
манера	doc_901133458147_item	2926136	et	2	main
tüttu	doc_901133458147_item	2926163	et	4	main
2	doc_901133458147_item	2926164	et	2	main
ma	doc_901133458147_item	2926165	et	3	main
ei	doc_901133458147_item	2926166	et	4	main
palju	doc_901133458147_item	2926177	et	4	main
ta	doc_901133458147_item	2926180	et	4	main
oleb	doc_901133458147_item	2926181	et	4	main
elust	doc_901133458147_item	2926182	et	3	main
inimeste	doc_901133458148_item	2926189	et	3	main
näiteks	doc_901133458148_item	2926210	et	4	main
elu	doc_901133458148_item	2926220	et	4	main
dokument	doc_901133458147_item	2926079	et	3	main
явится	doc_901133458147_item	2926088	et	2	main
panema	doc_901133458147_item	2926091	et	3	main
nalja	doc_901133458147_item	2926105	et	4	main
heitma	doc_901133458147_item	2926106	et	3	main
minema	doc_901133458147_item	2926110	et	3	main
maht	doc_901133458147_item	2926113	et	3	main
tüttu	doc_901133458147_item	2926116	et	4	main
viis	doc_901133458147_item	2926135	et	4	main
põhjendus	doc_901133458147_item	2926140	et	4	main
igaks	doc_901133458147_item	2926142	et	3	main
во	doc_901133458147_item	2926144	et	2	main
1	doc_901133458147_item	2926149	et	2	main
ta	doc_901133458147_item	2926160	et	4	main
oli	doc_901133458147_item	2926161	et	3	main
väga	doc_901133458147_item	2926162	et	3	main
väga	doc_901133458147_item	2926171	et	3	main
põhjendused	doc_901133458147_item	2926173	et	4	main
uus	doc_901133458148_item	2926184	et	3	main
dokument	doc_901133458148_item	2926185	et	3	main
rohkem	doc_901133458148_item	2926192	et	4	main
elu	doc_901133458148_item	2926199	et	4	main
inimene	doc_901133458148_item	2926200	et	3	main
ikka	doc_901133458148_item	2926201	et	4	main
elab	doc_901133458148_item	2926202	et	3	main
nii	doc_901133458148_item	2926203	et	3	main
et	doc_901133458148_item	2926204	et	3	main
erinevatest	doc_901133458148_item	2926208	et	4	main
asjaolutest	doc_901133458148_item	2926209	et	3	main
heaks	doc_901133458148_item	2926221	et	4	main
halvaks	doc_901133458148_item	2926223	et	4	main
mulle	doc_901133458148_item	2926224	et	4	main
meeldib	doc_901133458148_item	2926225	et	3	main
kui	doc_901133458148_item	2926226	et	3	main
juhtub	doc_901133458148_item	2926227	et	3	main
milline	doc_901133458148_item	2926228	et	3	main
on	doc_901133458148_item	2926249	et	4	main
et	doc_901133458148_item	2926255	et	3	main
märka	doc_901133458148_item	2926258	et	4	main
suure	doc_901133458148_item	2926271	et	3	main
meie	doc_901133458148_item	2926273	et	4	main
elus	doc_901133458148_item	2926274	et	4	main
on	doc_901133458148_item	2926278	et	4	main
ka	doc_901133458148_item	2926279	et	3	main
mis	doc_901133458148_item	2926292	et	4	main
teist	doc_901133458148_item	2926299	et	4	main
ligi	doc_901133458148_item	2926300	et	3	main
ei	doc_901133458148_item	2926306	et	4	main
ütlevad	doc_901133458148_item	2926319	et	4	main
tähtis	doc_901133458148_item	2926328	et	4	main
nii	doc_901133458148_item	2926335	et	3	main
võtavad	doc_901133458148_item	2926338	et	3	main
hea	doc_901133458148_item	2926352	et	4	main
pole	doc_901133458148_item	2926355	et	3	main
teda	doc_901133458148_item	2926359	et	4	main
võieti	doc_901133458148_item	2926361	et	4	main
kesta	doc_901133458148_item	2926367	et	4	main
olemas	doc_901133458148_item	2926397	et	4	main
elu	doc_901133458149_item	2926409	et	4	main
inimese	doc_901133458149_item	2926417	et	4	main
mõned	doc_901133458149_item	2926422	et	3	main
on	doc_901133458149_item	2926424	et	4	main
elu	doc_901133458149_item	2926434	et	4	main
olla	doc_901133458149_item	2926445	et	3	main
aga	doc_901133458149_item	2926449	et	3	main
elu	doc_901133458149_item	2926457	et	4	main
teine	doc_901133458149_item	2926458	et	3	main
tegur	doc_901133458149_item	2926459	et	3	main
teame	doc_901133458149_item	2926469	et	3	main
sõber	doc_901133458149_item	2926471	et	3	main
essee	doc_901133458150_item	2926507	et	4	main
inimese	doc_901133458150_item	2926510	et	4	main
elu	doc_901133458150_item	2926521	et	4	main
sõbrad	doc_901133458150_item	2926525	et	3	main
on	doc_901133458150_item	2926532	et	4	main
tähtsem	doc_901133458150_item	2926535	et	4	main
elu	doc_901133458150_item	2926537	et	4	main
sul	doc_901133458150_item	2926539	et	3	main
probleemid	doc_901133458150_item	2926541	et	3	main
sinule	doc_901133458150_item	2926545	et	3	main
vaga	doc_901133458150_item	2926551	et	4	main
on	doc_901133458150_item	2926555	et	4	main
ja	doc_901133458150_item	2926563	et	3	main
14	doc_901133458147_item	2926125	et	2	main
inspiratsion	doc_901133458147_item	2926129	et	4	main
keruline	doc_901133458147_item	2926132	et	4	main
17	doc_901133458147_item	2926134	et	2	main
soodsalt	doc_901133458147_item	2926138	et	4	main
причина	doc_901133458147_item	2926141	et	2	main
всяком	doc_901133458147_item	2926145	et	2	main
tulemus	doc_901133458147_item	2926147	et	3	main
inimene	doc_901133458147_item	2926151	et	3	main
palju	doc_901133458147_item	2926152	et	4	main
rääkida	doc_901133458147_item	2926153	et	3	main
ja	doc_901133458147_item	2926154	et	3	main
ei	doc_901133458147_item	2926155	et	4	main
mitte	doc_901133458147_item	2926157	et	3	main
tõsine	doc_901133458147_item	2926159	et	4	main
kujundus	doc_901133458147_item	2926168	et	4	main
sellepärast	doc_901133458147_item	2926169	et	3	main
mul	doc_901133458147_item	2926170	et	3	main
3	doc_901133458147_item	2926174	et	2	main
töötab	doc_901133458147_item	2926178	et	3	main
tegurid	doc_901133458148_item	2926186	et	3	main
span	doc_901133458148_item	2926193	et	4	main
minu	doc_901133458148_item	2926212	et	3	main
oli	doc_901133458148_item	2926214	et	3	main
palju	doc_901133458148_item	2926215	et	4	main
juhuseid	doc_901133458148_item	2926216	et	3	main
mis	doc_901133458148_item	2926217	et	4	main
minu	doc_901133458148_item	2926230	et	3	main
uut	doc_901133458148_item	2926241	et	3	main
kaasa	doc_901133458148_item	2926246	et	4	main
ühetaoline	doc_901133458148_item	2926250	et	3	main
tihti	doc_901133458148_item	2926252	et	3	main
juhtub	doc_901133458148_item	2926253	et	3	main
mängib	doc_901133458148_item	2926270	et	3	main
rolli	doc_901133458148_item	2926272	et	4	main
span	doc_901133458148_item	2926275	et	4	main
väga	doc_901133458148_item	2926276	et	3	main
inimese	doc_901133458148_item	2926280	et	4	main
iseloom	doc_901133458148_item	2926281	et	3	main
tema	doc_901133458148_item	2926282	et	4	main
väga	doc_901133458148_item	2926294	et	3	main
kiitle	doc_901133458148_item	2926307	et	4	main
aga	doc_901133458148_item	2926308	et	3	main
ütlevad	doc_901133458148_item	2926311	et	4	main
eneergiat	doc_901133458148_item	2926318	et	4	main
juhus	doc_901133458148_item	2926211	et	4	main
muutusid	doc_901133458148_item	2926218	et	4	main
minu	doc_901133458148_item	2926219	et	3	main
või	doc_901133458148_item	2926222	et	4	main
nende	doc_901133458148_item	2926234	et	4	main
tänul	doc_901133458148_item	2926235	et	3	main
iga	doc_901133458148_item	2926236	et	4	main
päev	doc_901133458148_item	2926237	et	3	main
ma	doc_901133458148_item	2926238	et	3	main
ootan	doc_901133458148_item	2926239	et	3	main
mina	doc_901133458148_item	2926243	et	4	main
me	doc_901133458148_item	2926256	et	4	main
tähtis	doc_901133458148_item	2926277	et	4	main
neid	doc_901133458148_item	2926291	et	4	main
inimene	doc_901133458148_item	2926297	et	3	main
tõmbab	doc_901133458148_item	2926298	et	3	main
temaga	doc_901133458148_item	2926301	et	3	main
suhtlemine	doc_901133458148_item	2926302	et	4	main
sõbrad	doc_901133458148_item	2926310	et	3	main
minuga	doc_901133458148_item	2926313	et	3	main
suhtlemisest	doc_901133458148_item	2926314	et	4	main
nad	doc_901133458148_item	2926315	et	3	main
saavad	doc_901133458148_item	2926316	et	4	main
et	doc_901133458148_item	2926321	et	3	main
naeratusega	doc_901133458148_item	2926325	et	4	main
veel	doc_901133458148_item	2926327	et	4	main
vanaajadest	doc_901133458148_item	2926333	et	4	main
oli	doc_901133458148_item	2926334	et	3	main
vanasõnas	doc_901133458148_item	2926337	et	3	main
aga	doc_901133458148_item	2926341	et	3	main
tarkuse	doc_901133458148_item	2926343	et	4	main
mitu	doc_901133458148_item	2926347	et	4	main
situatsiooni	doc_901133458148_item	2926348	et	4	main
millal	doc_901133458148_item	2926349	et	3	main
inimene	doc_901133458148_item	2926350	et	3	main
oli	doc_901133458148_item	2926351	et	3	main
tööle	doc_901133458148_item	2926362	et	3	main
sest	doc_901133458148_item	2926363	et	4	main
ainult	doc_901133458148_item	2926366	et	4	main
tööandja	doc_901133458148_item	2926368	et	4	main
rohkem	doc_901133458148_item	2926395	et	4	main
situatsioonid	doc_901133458148_item	2926401	et	3	main
kõige	doc_901133458149_item	2926410	et	4	main
elu	doc_901133458149_item	2926418	et	4	main
mõjutab	doc_901133458149_item	2926419	et	3	main
mõni	doc_901133458149_item	2926420	et	3	main
tegurit	doc_901133458149_item	2926421	et	3	main
näideks	doc_901133458149_item	2926430	et	3	main
teie	doc_901133458149_item	2926435	et	4	main
vanemad	doc_901133458149_item	2926436	et	4	main
püüavad	doc_901133458149_item	2926437	et	3	main
mõjutab	doc_901133458149_item	2926438	et	3	main
sinu	doc_901133458149_item	2926439	et	3	main
see	doc_901133458149_item	2926446	et	3	main
hea	doc_901133458149_item	2926448	et	4	main
mõned	doc_901133458149_item	2926450	et	3	main
inimese	doc_901133458149_item	2926462	et	4	main
arvan	doc_901133458149_item	2926465	et	3	main
me	doc_901133458149_item	2926468	et	4	main
et	doc_901133458149_item	2926470	et	3	main
rohkem	doc_901133458150_item	2926513	et	4	main
ma	doc_901133458150_item	2926514	et	3	main
mõtlen	doc_901133458150_item	2926515	et	3	main
et	doc_901133458150_item	2926516	et	3	main
ka	doc_901133458150_item	2926533	et	3	main
väga	doc_901133458150_item	2926534	et	3	main
inimiseks	doc_901133458150_item	2926548	et	4	main
on	doc_901133458150_item	2926550	et	4	main
tähtsem	doc_901133458150_item	2926552	et	4	main
kui	doc_901133458150_item	2926553	et	3	main
sul	doc_901133458150_item	2926554	et	3	main
otsa	doc_901133458150_item	2926561	et	4	main
hästi	doc_901133458150_item	2926562	et	3	main
inimisele	doc_901133458150_item	2926569	et	4	main
on	doc_901133458150_item	2926570	et	4	main
raha	doc_901133458150_item	2926573	et	4	main
väga	doc_901133458150_item	2926622	et	3	main
et	doc_901133458150_item	2926632	et	3	main
kui	doc_901133458150_item	2926638	et	3	main
meie	doc_901133458150_item	2926651	et	4	main
elus	doc_901133458150_item	2926652	et	4	main
sul	doc_901133458150_item	2926654	et	3	main
elu	doc_901133458148_item	2926231	et	4	main
pole	doc_901133458148_item	2926232	et	3	main
igav	doc_901133458148_item	2926233	et	3	main
ja	doc_901133458148_item	2926242	et	3	main
tõsiselt	doc_901133458148_item	2926244	et	4	main
kellel	doc_901133458148_item	2926248	et	4	main
elu	doc_901133458148_item	2926251	et	4	main
nii	doc_901133458148_item	2926254	et	3	main
ei	doc_901133458148_item	2926257	et	4	main
aga	doc_901133458148_item	2926260	et	3	main
midagi	doc_901133458148_item	2926259	et	4	main
hiljem	doc_901133458148_item	2926261	et	3	main
me	doc_901133458148_item	2926262	et	4	main
analiseerime	doc_901133458148_item	2926263	et	4	main
sündmuseid	doc_901133458148_item	2926264	et	3	main
ja	doc_901133458148_item	2926265	et	3	main
otsustame	doc_901133458148_item	2926266	et	3	main
lõpuks	doc_901133458148_item	2926267	et	4	main
et	doc_901133458148_item	2926268	et	3	main
juhus	doc_901133458148_item	2926269	et	4	main
inimene	doc_901133458148_item	2926285	et	3	main
oskab	doc_901133458148_item	2926286	et	3	main
suhelda	doc_901133458148_item	2926287	et	4	main
omab	doc_901133458148_item	2926288	et	3	main
sõpru	doc_901133458148_item	2926289	et	3	main
austab	doc_901133458148_item	2926290	et	3	main
oluline	doc_901133458148_item	2926295	et	4	main
selline	doc_901133458148_item	2926296	et	4	main
mina	doc_901133458148_item	2926305	et	4	main
et	doc_901133458148_item	2926312	et	3	main
veel	doc_901133458148_item	2926320	et	4	main
ma	doc_901133458148_item	2926322	et	3	main
neid	doc_901133458148_item	2926324	et	4	main
span	doc_901133458148_item	2926326	et	4	main
on	doc_901133458148_item	2926330	et	4	main
saatavad	doc_901133458148_item	2926342	et	3	main
järgi	doc_901133458148_item	2926344	et	4	main
ma	doc_901133458148_item	2926345	et	3	main
tean	doc_901133458148_item	2926346	et	3	main
aga	doc_901133458148_item	2926354	et	3	main
välimusega	doc_901133458148_item	2926357	et	3	main
ja	doc_901133458148_item	2926358	et	3	main
nägi	doc_901133458148_item	2926365	et	3	main
andnud	doc_901133458148_item	2926370	et	4	main
šablooni	doc_901133458148_item	2926399	et	2	main
kõik	doc_901133458148_item	2926400	et	4	main
erinevad	doc_901133458148_item	2926403	et	4	main
dokument	doc_901133458149_item	2926405	et	3	main
mis	doc_901133458149_item	2926406	et	4	main
mõjutab	doc_901133458149_item	2926407	et	3	main
inimese	doc_901133458149_item	2926408	et	4	main
nakatun	doc_901133458148_item	2926323	et	3	main
välimus	doc_901133458148_item	2926331	et	3	main
sest	doc_901133458148_item	2926332	et	4	main
vastu	doc_901133458148_item	2926340	et	3	main
spetsialist	doc_901133458148_item	2926353	et	3	main
ilusa	doc_901133458148_item	2926356	et	3	main
tööandja	doc_901133458148_item	2926364	et	4	main
ei	doc_901133458148_item	2926369	et	4	main
inimesele	doc_901133458148_item	2926371	et	3	main
võimalust	doc_901133458148_item	2926372	et	3	main
näidata	doc_901133458148_item	2926373	et	4	main
oma	doc_901133458148_item	2926374	et	4	main
oskuseid	doc_901133458148_item	2926375	et	3	main
vot	doc_901133458148_item	2926376	et	3	main
nii	doc_901133458148_item	2926377	et	3	main
juhtub	doc_901133458148_item	2926378	et	3	main
meie	doc_901133458148_item	2926379	et	4	main
elus	doc_901133458148_item	2926380	et	4	main
span	doc_901133458148_item	2926381	et	4	main
igal	doc_901133458148_item	2926382	et	3	main
inimesel	doc_901133458148_item	2926383	et	3	main
on	doc_901133458148_item	2926384	et	4	main
oma	doc_901133458148_item	2926385	et	4	main
reeglid	doc_901133458148_item	2926386	et	3	main
ja	doc_901133458148_item	2926387	et	3	main
oma	doc_901133458148_item	2926388	et	4	main
arvamus	doc_901133458148_item	2926389	et	3	main
mis	doc_901133458148_item	2926390	et	4	main
mõjutab	doc_901133458148_item	2926391	et	3	main
tema	doc_901133458148_item	2926392	et	4	main
kõige	doc_901133458148_item	2926394	et	4	main
elu	doc_901133458148_item	2926393	et	4	main
pole	doc_901133458148_item	2926396	et	3	main
ühtset	doc_901133458148_item	2926398	et	3	main
tegurit	doc_901133458149_item	2926423	et	3	main
teised	doc_901133458149_item	2926427	et	4	main
ei	doc_901133458149_item	2926428	et	4	main
kõrgem	doc_901133458149_item	2926431	et	4	main
elu	doc_901133458149_item	2926440	et	4	main
ja	doc_901133458149_item	2926441	et	3	main
otsus	doc_901133458149_item	2926443	et	3	main
on	doc_901133458149_item	2926447	et	4	main
vanemad	doc_901133458149_item	2926451	et	4	main
püüavad	doc_901133458149_item	2926452	et	3	main
tegema	doc_901133458149_item	2926453	et	3	main
lasteelu	doc_901133458149_item	2926454	et	4	main
missugune	doc_901133458149_item	2926460	et	3	main
elu	doc_901133458149_item	2926463	et	4	main
ma	doc_901133458149_item	2926464	et	3	main
raha	doc_901133458149_item	2926505	et	4	main
mõjutab	doc_901133458150_item	2926509	et	3	main
rohkem	doc_901133458150_item	2926518	et	4	main
mõjutab	doc_901133458150_item	2926519	et	3	main
tähtsam	doc_901133458149_item	2926426	et	4	main
võib	doc_901133458149_item	2926444	et	3	main
mõjutab	doc_901133458149_item	2926461	et	3	main
sõbrad	doc_901133458149_item	2926466	et	3	main
alati	doc_901133458149_item	2926472	et	4	main
sõber	doc_901133458149_item	2926474	et	3	main
annab	doc_901133458149_item	2926475	et	3	main
hea	doc_901133458149_item	2926476	et	4	main
aitab	doc_901133458149_item	2926473	et	3	main
nõu	doc_901133458149_item	2926477	et	4	main
aga	doc_901133458149_item	2926478	et	3	main
me	doc_901133458149_item	2926479	et	4	main
kokku	doc_901133458149_item	2926480	et	3	main
puutume	doc_901133458149_item	2926481	et	4	main
inimesed	doc_901133458149_item	2926482	et	3	main
mis	doc_901133458149_item	2926483	et	4	main
püüavad	doc_901133458149_item	2926484	et	3	main
suruma	doc_901133458149_item	2926485	et	3	main
sinu	doc_901133458149_item	2926486	et	3	main
arvamus	doc_901133458149_item	2926488	et	3	main
span	doc_901133458149_item	2926489	et	4	main
oma	doc_901133458149_item	2926487	et	4	main
ja	doc_901133458149_item	2926490	et	3	main
ma	doc_901133458149_item	2926491	et	3	main
arvan	doc_901133458149_item	2926492	et	3	main
et	doc_901133458149_item	2926493	et	3	main
kõige	doc_901133458149_item	2926494	et	4	main
tähtsam	doc_901133458149_item	2926495	et	4	main
tegur	doc_901133458149_item	2926496	et	3	main
mis	doc_901133458149_item	2926497	et	4	main
mõjutab	doc_901133458149_item	2926498	et	3	main
inimese	doc_901133458149_item	2926499	et	4	main
elu	doc_901133458149_item	2926500	et	4	main
kõige	doc_901133458149_item	2926501	et	4	main
mis	doc_901133458149_item	2926467	et	4	main
rohkem	doc_901133458149_item	2926502	et	4	main
see	doc_901133458149_item	2926503	et	3	main
on	doc_901133458149_item	2926504	et	4	main
mis	doc_901133458150_item	2926508	et	4	main
elu	doc_901133458150_item	2926511	et	4	main
kõige	doc_901133458150_item	2926512	et	4	main
inimese	doc_901133458150_item	2926520	et	4	main
inimise	doc_901133458150_item	2926529	et	4	main
inimise	doc_901133458150_item	2926536	et	4	main
haridus	doc_901133458150_item	2926549	et	3	main
sa	doc_901133458150_item	2926559	et	3	main
töö	doc_901133458150_item	2926567	et	4	main
igale	doc_901133458150_item	2926568	et	3	main
väga	doc_901133458150_item	2926576	et	3	main
palju	doc_901133458150_item	2926583	et	4	main
ajal	doc_901133458150_item	2926619	et	4	main
karjäär	doc_901133458150_item	2926620	et	3	main
ma	doc_901133458150_item	2926630	et	3	main
raha	doc_901133458150_item	2926645	et	4	main
osa	doc_901133458150_item	2926650	et	4	main
kui	doc_901133458150_item	2926653	et	3	main
on	doc_901133458151_item	2926665	et	4	main
haritud	doc_901133458151_item	2926669	et	4	main
tavaliselt	doc_901133458151_item	2926672	et	4	main
nõus	doc_901133458151_item	2926681	et	4	main
on	doc_901133458151_item	2926701	et	4	main
raha	doc_901133458151_item	2926723	et	4	main
on	doc_901133458151_item	2926726	et	4	main
raha	doc_901133458151_item	2926727	et	4	main
siis	doc_901133458151_item	2926728	et	3	main
span	doc_901133458151_item	2926733	et	4	main
liiga	doc_901133458151_item	2926738	et	4	main
sõltub	doc_901133458151_item	2926740	et	3	main
perekonnanimest	doc_901133458151_item	2926742	et	3	main
isegi	doc_901133458151_item	2926755	et	4	main
kui	doc_901133458151_item	2926756	et	3	main
sul	doc_901133458151_item	2926757	et	3	main
näiteks	doc_901133458151_item	2926769	et	4	main
sa	doc_901133458151_item	2926772	et	3	main
oled	doc_901133458151_item	2926774	et	3	main
meeldi	doc_901133458151_item	2926788	et	4	main
kõiki	doc_901133458151_item	2926791	et	4	main
visa	doc_901133458151_item	2926830	et	4	main
siis	doc_901133458151_item	2926831	et	3	main
kõik	doc_901133458151_item	2926832	et	4	main
sul	doc_901133458151_item	2926833	et	3	main
ma	doc_901133458152_item	2926844	et	3	main
kõike	doc_901133458152_item	2926847	et	4	main
tähtsamaid	doc_901133458152_item	2926848	et	4	main
mõjutavad	doc_901133458152_item	2926853	et	4	main
ta	doc_901133458152_item	2926867	et	4	main
hakkab	doc_901133458152_item	2926868	et	3	main
ja	doc_901133458152_item	2926898	et	3	main
ja	doc_901133458152_item	2926906	et	3	main
tähtis	doc_901133458152_item	2926909	et	4	main
asi	doc_901133458152_item	2926910	et	4	main
karjari	doc_901133458152_item	2926915	et	4	main
oma	doc_901133458152_item	2926930	et	4	main
blokki	doc_901133458152_item	2926935	et	4	main
eriti	doc_901133458152_item	2926936	et	3	main
sama	doc_901133458152_item	2926939	et	4	main
on	doc_901133458152_item	2926941	et	4	main
on	doc_901133458152_item	2926952	et	4	main
inimesel	doc_901133458152_item	2926964	et	3	main
ta	doc_901133458152_item	2926969	et	4	main
veel	doc_901133458152_item	2926981	et	4	main
mis	doc_901133458152_item	2926984	et	4	main
mõjutab	doc_901133458152_item	2926985	et	3	main
perekonna	doc_901133458152_item	2926986	et	4	main
loomiseks	doc_901133458152_item	2926987	et	4	main
ja	doc_901133458152_item	2926988	et	3	main
raske	doc_901133458152_item	2926993	et	4	main
mõjutavad	doc_901133458152_item	2926997	et	4	main
tegurit	doc_901133458152_item	2926999	et	3	main
ja	doc_901133458152_item	2927000	et	3	main
kõik	doc_901133458152_item	2927001	et	4	main
kõige	doc_901133458153_item	2927011	et	4	main
span	doc_901133458153_item	2927013	et	4	main
span	doc_901133458153_item	2927014	et	4	main
ma	doc_901133458153_item	2927015	et	3	main
mõtlen	doc_901133458153_item	2927016	et	3	main
peab	doc_901133458153_item	2927035	et	4	main
span	doc_901133458149_item	2926506	et	4	main
kõige	doc_901133458150_item	2926517	et	4	main
on	doc_901133458150_item	2926522	et	4	main
tema	doc_901133458150_item	2926523	et	4	main
tegused	doc_901133458150_item	2926524	et	3	main
on	doc_901133458150_item	2926526	et	4	main
väga	doc_901133458150_item	2926527	et	3	main
tähtemad	doc_901133458150_item	2926528	et	3	main
vanemad	doc_901133458150_item	2926531	et	4	main
siis	doc_901133458150_item	2926542	et	3	main
eluse	doc_901133458150_item	2926546	et	3	main
igaks	doc_901133458150_item	2926547	et	3	main
haridus	doc_901133458150_item	2926557	et	3	main
peaks	doc_901133458150_item	2926560	et	4	main
hea	doc_901133458150_item	2926564	et	4	main
ja	doc_901133458150_item	2926565	et	3	main
huvitav	doc_901133458150_item	2926566	et	4	main
ka	doc_901133458150_item	2926575	et	3	main
inimise	doc_901133458150_item	2926578	et	4	main
tähtis	doc_901133458150_item	2926623	et	4	main
elu	doc_901133458150_item	2926626	et	4	main
on	doc_901133458150_item	2926627	et	4	main
väga	doc_901133458150_item	2926628	et	3	main
kohaks	doc_901133458150_item	2926634	et	4	main
olla	doc_901133458150_item	2926636	et	3	main
aga	doc_901133458150_item	2926646	et	3	main
raha	doc_901133458150_item	2926647	et	4	main
luua	doc_901133458150_item	2926661	et	4	main
uus	doc_901133458151_item	2926662	et	3	main
dokument	doc_901133458151_item	2926663	et	3	main
haridus	doc_901133458151_item	2926664	et	3	main
tähtis	doc_901133458151_item	2926667	et	4	main
parema	doc_901133458151_item	2926674	et	4	main
haridus	doc_901133458151_item	2926683	et	3	main
riigis	doc_901133458151_item	2926690	et	3	main
süsteem	doc_901133458151_item	2926693	et	3	main
on	doc_901133458151_item	2926696	et	4	main
palju	doc_901133458151_item	2926697	et	4	main
tutvusi	doc_901133458151_item	2926698	et	3	main
siis	doc_901133458151_item	2926699	et	3	main
sul	doc_901133458151_item	2926700	et	3	main
ei	doc_901133458151_item	2926729	et	4	main
ole	doc_901133458151_item	2926730	et	4	main
arvan	doc_901133458151_item	2926736	et	3	main
kui	doc_901133458151_item	2926744	et	3	main
oled	doc_901133458151_item	2926746	et	3	main
on	doc_901133458151_item	2926750	et	4	main
oskus	doc_901133458151_item	2926761	et	3	main
hea	doc_901133458151_item	2926764	et	4	main
hea	doc_901133458151_item	2926775	et	4	main
paremas	doc_901133458151_item	2926777	et	4	main
et	doc_901133458151_item	2926785	et	3	main
venelasi	doc_901133458151_item	2926789	et	3	main
hea	doc_901133458151_item	2926822	et	4	main
span	doc_901133458151_item	2926823	et	4	main
ma	doc_901133458151_item	2926824	et	3	main
arvan	doc_901133458151_item	2926825	et	3	main
kui	doc_901133458151_item	2926826	et	3	main
inimene	doc_901133458151_item	2926827	et	3	main
on	doc_901133458151_item	2926828	et	4	main
väga	doc_901133458151_item	2926829	et	3	main
haridus	doc_901133458151_item	2926837	et	3	main
parem	doc_901133458151_item	2926839	et	4	main
on	doc_901133458152_item	2926856	et	4	main
tegur	doc_901133458152_item	2926864	et	3	main
on	doc_901133458152_item	2926865	et	4	main
haridus	doc_901133458152_item	2926897	et	3	main
on	doc_901133458152_item	2926900	et	4	main
tegur	doc_901133458152_item	2926902	et	3	main
üks	doc_901133458152_item	2926908	et	3	main
elu	doc_901133458150_item	2926530	et	4	main
kui	doc_901133458150_item	2926538	et	3	main
on	doc_901133458150_item	2926540	et	4	main
nad	doc_901133458150_item	2926543	et	3	main
aitab	doc_901133458150_item	2926544	et	3	main
hea	doc_901133458150_item	2926556	et	4	main
siis	doc_901133458150_item	2926558	et	3	main
on	doc_901133458150_item	2926574	et	4	main
tahtsem	doc_901133458150_item	2926577	et	4	main
elu	doc_901133458150_item	2926579	et	4	main
kui	doc_901133458150_item	2926580	et	3	main
sul	doc_901133458150_item	2926581	et	3	main
on	doc_901133458150_item	2926582	et	4	main
raha	doc_901133458150_item	2926584	et	4	main
siis	doc_901133458150_item	2926585	et	3	main
sa	doc_901133458150_item	2926586	et	3	main
võib	doc_901133458150_item	2926587	et	3	main
teha	doc_901133458150_item	2926588	et	3	main
mida	doc_901133458150_item	2926589	et	4	main
sa	doc_901133458150_item	2926590	et	3	main
tahaks	doc_901133458150_item	2926591	et	3	main
kui	doc_901133458150_item	2926592	et	3	main
sul	doc_901133458150_item	2926593	et	3	main
on	doc_901133458150_item	2926594	et	4	main
palju	doc_901133458150_item	2926595	et	4	main
raha	doc_901133458150_item	2926596	et	4	main
siis	doc_901133458150_item	2926597	et	3	main
sul	doc_901133458150_item	2926598	et	3	main
on	doc_901133458150_item	2926599	et	4	main
palju	doc_901133458150_item	2926600	et	4	main
probleemid	doc_901133458150_item	2926601	et	3	main
meie	doc_901133458150_item	2926602	et	4	main
ajaks	doc_901133458150_item	2926603	et	4	main
me	doc_901133458150_item	2926604	et	4	main
elame	doc_901133458150_item	2926605	et	3	main
nagu	doc_901133458150_item	2926606	et	3	main
loomad	doc_901133458150_item	2926607	et	3	main
kui	doc_901133458150_item	2926608	et	3	main
sa	doc_901133458150_item	2926609	et	3	main
on	doc_901133458150_item	2926610	et	4	main
tarkus	doc_901133458150_item	2926611	et	4	main
ja	doc_901133458150_item	2926612	et	3	main
siis	doc_901133458150_item	2926614	et	3	main
tugev	doc_901133458150_item	2926613	et	4	main
sa	doc_901133458150_item	2926615	et	3	main
elaks	doc_901133458150_item	2926616	et	3	main
ise	doc_901133458150_item	2926571	et	4	main
iseloom	doc_901133458150_item	2926572	et	3	main
hästi	doc_901133458150_item	2926617	et	3	main
meie	doc_901133458150_item	2926618	et	4	main
raske	doc_901133458150_item	2926629	et	4	main
mõtlen	doc_901133458150_item	2926631	et	3	main
sul	doc_901133458150_item	2926639	et	3	main
on	doc_901133458150_item	2926644	et	4	main
on	doc_901133458150_item	2926648	et	4	main
span	doc_901133458151_item	2926676	et	4	main
ma	doc_901133458151_item	2926677	et	3	main
olen	doc_901133458151_item	2926678	et	3	main
sellega	doc_901133458151_item	2926679	et	3	main
osaliselt	doc_901133458151_item	2926680	et	4	main
ei	doc_901133458151_item	2926684	et	4	main
meie	doc_901133458151_item	2926689	et	4	main
järgmine	doc_901133458151_item	2926692	et	3	main
sul	doc_901133458151_item	2926695	et	3	main
sul	doc_901133458151_item	2926721	et	3	main
aga	doc_901133458151_item	2926724	et	3	main
kui	doc_901133458151_item	2926725	et	3	main
probleemi	doc_901133458151_item	2926732	et	4	main
näiteks	doc_901133458151_item	2926743	et	4	main
on	doc_901133458151_item	2926758	et	4	main
eesti	doc_901133458151_item	2926759	et	4	main
väga	doc_901133458151_item	2926763	et	3	main
aga	doc_901133458151_item	2926765	et	3	main
sa	doc_901133458151_item	2926767	et	3	main
tamm	doc_901133458151_item	2926770	et	3	main
juba	doc_901133458151_item	2926773	et	3	main
spetsialist	doc_901133458151_item	2926776	et	3	main
töökohas	doc_901133458151_item	2926778	et	4	main
see	doc_901133458151_item	2926779	et	3	main
on	doc_901133458151_item	2926780	et	4	main
minu	doc_901133458151_item	2926781	et	3	main
arvamus	doc_901133458151_item	2926782	et	3	main
ei	doc_901133458151_item	2926787	et	4	main
on	doc_901133458150_item	2926621	et	4	main
sellepärast	doc_901133458150_item	2926624	et	3	main
et	doc_901133458150_item	2926625	et	3	main
esimeseks	doc_901133458150_item	2926633	et	3	main
peaks	doc_901133458150_item	2926635	et	4	main
karjäär	doc_901133458150_item	2926637	et	3	main
on	doc_901133458150_item	2926640	et	4	main
karjää	doc_901133458150_item	2926641	et	4	main
siis	doc_901133458150_item	2926642	et	3	main
sul	doc_901133458150_item	2926643	et	3	main
tähtis	doc_901133458150_item	2926649	et	4	main
on	doc_901133458150_item	2926655	et	4	main
väga	doc_901133458151_item	2926666	et	3	main
inimene	doc_901133458151_item	2926670	et	3	main
sest	doc_901133458151_item	2926682	et	4	main
ole	doc_901133458151_item	2926685	et	4	main
kõige	doc_901133458151_item	2926686	et	4	main
tähtsam	doc_901133458151_item	2926687	et	4	main
rohkem	doc_901133458151_item	2926702	et	4	main
võimalusi	doc_901133458151_item	2926703	et	3	main
parema	doc_901133458151_item	2926704	et	4	main
töökoha	doc_901133458151_item	2926705	et	4	main
saada	doc_901133458151_item	2926706	et	4	main
näiteks	doc_901133458151_item	2926707	et	4	main
kui	doc_901133458151_item	2926708	et	3	main
sinu	doc_901133458151_item	2926709	et	3	main
isa	doc_901133458151_item	2926710	et	4	main
on	doc_901133458151_item	2926711	et	4	main
suure	doc_901133458151_item	2926712	et	3	main
riidekaupluse	doc_901133458151_item	2926713	et	3	main
direktor	doc_901133458151_item	2926714	et	3	main
sa	doc_901133458151_item	2926716	et	3	main
siis	doc_901133458151_item	2926715	et	3	main
oled	doc_901133458151_item	2926717	et	3	main
inimene	doc_901133458151_item	2926719	et	3	main
sest	doc_901133458151_item	2926720	et	4	main
lugupeetud	doc_901133458151_item	2926718	et	4	main
on	doc_901133458151_item	2926722	et	4	main
rohkem	doc_901133458151_item	2926731	et	4	main
et	doc_901133458151_item	2926737	et	3	main
siis	doc_901133458151_item	2926748	et	3	main
on	doc_901133458151_item	2926762	et	4	main
kui	doc_901133458151_item	2926766	et	3	main
oled	doc_901133458151_item	2926768	et	3	main
siis	doc_901133458151_item	2926771	et	3	main
tundub	doc_901133458151_item	2926784	et	3	main
eestlastele	doc_901133458151_item	2926786	et	4	main
olema	doc_901133458151_item	2926821	et	4	main
peab	doc_901133458151_item	2926834	et	4	main
ja	doc_901133458151_item	2926838	et	3	main
töökoht	doc_901133458151_item	2926840	et	3	main
dokument	doc_901133458152_item	2926843	et	3	main
arvan	doc_901133458152_item	2926845	et	3	main
et	doc_901133458152_item	2926846	et	3	main
tarkus	doc_901133458152_item	2926857	et	4	main
haridus	doc_901133458152_item	2926858	et	3	main
tarkus	doc_901133458152_item	2926866	et	4	main
nii	doc_901133458152_item	2926891	et	3	main
edasi	doc_901133458152_item	2926892	et	3	main
see	doc_901133458152_item	2926893	et	3	main
aitab	doc_901133458152_item	2926894	et	3	main
inimesel	doc_901133458152_item	2926904	et	3	main
veel	doc_901133458152_item	2926907	et	4	main
raha	doc_901133458150_item	2926656	et	4	main
siis	doc_901133458150_item	2926657	et	3	main
sa	doc_901133458150_item	2926658	et	3	main
võib	doc_901133458150_item	2926659	et	3	main
perekonna	doc_901133458150_item	2926660	et	4	main
sest	doc_901133458151_item	2926668	et	4	main
saab	doc_901133458151_item	2926671	et	3	main
ka	doc_901133458151_item	2926673	et	3	main
töökoha	doc_901133458151_item	2926675	et	4	main
tegur	doc_901133458151_item	2926688	et	3	main
on	doc_901133458151_item	2926691	et	4	main
kui	doc_901133458151_item	2926694	et	3	main
veel	doc_901133458151_item	2926734	et	4	main
ma	doc_901133458151_item	2926735	et	3	main
palju	doc_901133458151_item	2926739	et	4	main
sinu	doc_901133458151_item	2926741	et	3	main
sa	doc_901133458151_item	2926745	et	3	main
dubtšova	doc_901133458151_item	2926747	et	2	main
sul	doc_901133458151_item	2926749	et	3	main
vähem	doc_901133458151_item	2926751	et	4	main
võimalusi	doc_901133458151_item	2926752	et	3	main
saada	doc_901133458151_item	2926753	et	4	main
töökoha	doc_901133458151_item	2926754	et	4	main
keele	doc_901133458151_item	2926760	et	4	main
mulle	doc_901133458151_item	2926783	et	4	main
mitte	doc_901133458151_item	2926790	et	3	main
aga	doc_901133458151_item	2926792	et	3	main
mõni	doc_901133458151_item	2926793	et	3	main
span	doc_901133458151_item	2926794	et	4	main
suur	doc_901133458151_item	2926795	et	3	main
roll	doc_901133458151_item	2926796	et	3	main
mängib	doc_901133458151_item	2926797	et	3	main
elus	doc_901133458151_item	2926798	et	4	main
juhus	doc_901133458151_item	2926799	et	4	main
on	doc_901133458151_item	2926800	et	4	main
edukad	doc_901133458151_item	2926801	et	3	main
inimesed	doc_901133458151_item	2926802	et	3	main
kellele	doc_901133458151_item	2926803	et	4	main
õnnustamine	doc_901133458151_item	2926804	et	4	main
muheleb	doc_901133458151_item	2926805	et	3	main
ikka	doc_901133458151_item	2926806	et	4	main
span	doc_901133458151_item	2926807	et	4	main
inimese	doc_901133458151_item	2926808	et	4	main
iseloom	doc_901133458151_item	2926809	et	3	main
ka	doc_901133458151_item	2926811	et	3	main
väga	doc_901133458151_item	2926812	et	3	main
tähtis	doc_901133458151_item	2926813	et	4	main
sa	doc_901133458151_item	2926814	et	3	main
on	doc_901133458151_item	2926810	et	4	main
pead	doc_901133458151_item	2926815	et	4	main
kontakti	doc_901133458151_item	2926816	et	4	main
käia	doc_901133458151_item	2926817	et	4	main
teisega	doc_901133458151_item	2926818	et	4	main
suhtlemisoskus	doc_901133458151_item	2926819	et	3	main
peab	doc_901133458151_item	2926820	et	4	main
olema	doc_901133458151_item	2926835	et	4	main
span	doc_901133458151_item	2926841	et	4	main
uus	doc_901133458152_item	2926842	et	3	main
milliseid	doc_901133458152_item	2926852	et	3	main
vanemad	doc_901133458152_item	2926859	et	4	main
rahvus	doc_901133458152_item	2926860	et	3	main
raha	doc_901133458152_item	2926861	et	4	main
saada	doc_901133458152_item	2926895	et	4	main
hea	doc_901133458152_item	2926896	et	4	main
eriala	doc_901133458152_item	2926911	et	4	main
hästi	doc_901133458151_item	2926836	et	3	main
sõnad	doc_901133458152_item	2926849	et	4	main
selles	doc_901133458152_item	2926850	et	4	main
nimekirjas	doc_901133458152_item	2926851	et	3	main
töö	doc_901133458152_item	2926854	et	4	main
saamiseks	doc_901133458152_item	2926855	et	4	main
span	doc_901133458152_item	2926862	et	4	main
esimene	doc_901133458152_item	2926863	et	3	main
mõjutama	doc_901133458152_item	2926869	et	4	main
juba	doc_901133458152_item	2926870	et	3	main
lapsepõlves	doc_901133458152_item	2926871	et	4	main
sellel	doc_901133458152_item	2926872	et	4	main
ajal	doc_901133458152_item	2926873	et	4	main
inimene	doc_901133458152_item	2926874	et	3	main
kui	doc_901133458152_item	2926875	et	3	main
ta	doc_901133458152_item	2926876	et	4	main
on	doc_901133458152_item	2926877	et	4	main
tark	doc_901133458152_item	2926878	et	3	main
võib	doc_901133458152_item	2926879	et	3	main
teha	doc_901133458152_item	2926880	et	3	main
hea	doc_901133458152_item	2926881	et	4	main
otsus	doc_901133458152_item	2926882	et	3	main
kuidas	doc_901133458152_item	2926883	et	3	main
temale	doc_901133458152_item	2926884	et	3	main
õppida	doc_901133458152_item	2926885	et	3	main
kuidas	doc_901133458152_item	2926886	et	3	main
temale	doc_901133458152_item	2926887	et	3	main
suhelda	doc_901133458152_item	2926888	et	4	main
inimesega	doc_901133458152_item	2926889	et	3	main
ja	doc_901133458152_item	2926890	et	3	main
see	doc_901133458152_item	2926899	et	3	main
teine	doc_901133458152_item	2926901	et	3	main
kui	doc_901133458152_item	2926903	et	3	main
kõrgharidus	doc_901133458152_item	2926905	et	3	main
pakkub	doc_901133458152_item	2926913	et	4	main
töö	doc_901133458152_item	2926914	et	4	main
span	doc_901133458152_item	2926922	et	4	main
tee	doc_901133458152_item	2926931	et	4	main
head	doc_901133458152_item	2926937	et	4	main
mõju	doc_901133458152_item	2926951	et	4	main
öelda	doc_901133458152_item	2926957	et	4	main
see	doc_901133458152_item	2926958	et	3	main
et	doc_901133458152_item	2926959	et	3	main
raha	doc_901133458152_item	2926960	et	4	main
katalisaator	doc_901133458152_item	2926962	et	4	main
kui	doc_901133458152_item	2926963	et	3	main
elus	doc_901133458152_item	2926978	et	4	main
aga	doc_901133458152_item	2926979	et	3	main
on	doc_901133458152_item	2926980	et	4	main
sõbrade	doc_901133458152_item	2926989	et	4	main
minu	doc_901133458152_item	2926994	et	3	main
siis	doc_901133458152_item	2926996	et	3	main
tuhat	doc_901133458152_item	2926998	et	4	main
mis	doc_901133458153_item	2927007	et	4	main
mõjutab	doc_901133458153_item	2927008	et	3	main
inimese	doc_901133458153_item	2927009	et	4	main
rohkem	doc_901133458153_item	2927012	et	4	main
ise	doc_901133458153_item	2927045	et	4	main
otsustada	doc_901133458153_item	2927046	et	3	main
mis	doc_901133458153_item	2927047	et	4	main
tema	doc_901133458153_item	2927054	et	4	main
lugu	doc_901133458153_item	2927060	et	4	main
peavad	doc_901133458153_item	2927061	et	4	main
minu	doc_901133458153_item	2927062	et	3	main
minu	doc_901133458153_item	2927097	et	3	main
vanemad	doc_901133458153_item	2927098	et	4	main
ja	doc_901133458153_item	2927099	et	3	main
sugulased	doc_901133458153_item	2927100	et	3	main
tark	doc_901133458153_item	2927109	et	3	main
inimene	doc_901133458153_item	2927110	et	3	main
töö	doc_901133458153_item	2927113	et	4	main
kui	doc_901133458153_item	2927114	et	3	main
rumal	doc_901133458153_item	2927115	et	3	main
span	doc_901133458153_item	2927116	et	4	main
span	doc_901133458153_item	2927129	et	4	main
elu	doc_901133458153_item	2927131	et	4	main
span	doc_901133458153_item	2927137	et	4	main
tere	doc_901133458154_item	2927140	et	3	main
minu	doc_901133458154_item	2927142	et	3	main
tähtsam	doc_901133458154_item	2927152	et	4	main
minu	doc_901133458154_item	2927153	et	3	main
elus	doc_901133458154_item	2927154	et	4	main
armastan	doc_901133458154_item	2927158	et	3	main
aastat	doc_901133458154_item	2927168	et	3	main
aru	doc_901133458154_item	2927181	et	4	main
keelest	doc_901133458154_item	2927184	et	4	main
põhjus	doc_901133458154_item	2927186	et	4	main
mul	doc_901133458154_item	2927190	et	3	main
rääkida	doc_901133458154_item	2927224	et	3	main
tahan	doc_901133458154_item	2927229	et	3	main
kirjutada	doc_901133458154_item	2927230	et	3	main
ja	doc_901133458154_item	2927232	et	3	main
loodan	doc_901133458154_item	2927235	et	3	main
loodan	doc_901133458154_item	2927257	et	3	main
dokument	doc_901133458155_item	2927266	et	3	main
minu	doc_901133458155_item	2927274	et	3	main
inimese	doc_901133458155_item	2927277	et	4	main
elu	doc_901133458155_item	2927278	et	4	main
kuid	doc_901133458155_item	2927301	et	4	main
head	doc_901133458155_item	2927302	et	4	main
raha	doc_901133458155_item	2927312	et	4	main
paha	doc_901133458155_item	2927319	et	4	main
mida	doc_901133458152_item	2926912	et	4	main
piisav	doc_901133458152_item	2926920	et	4	main
kolmas	doc_901133458152_item	2926923	et	3	main
tegur	doc_901133458152_item	2926924	et	3	main
aitavad	doc_901133458152_item	2926928	et	4	main
leida	doc_901133458152_item	2926929	et	3	main
ei	doc_901133458152_item	2926934	et	4	main
tegur	doc_901133458152_item	2926943	et	3	main
on	doc_901133458152_item	2926946	et	4	main
kiirem	doc_901133458152_item	2926968	et	4	main
väga	doc_901133458152_item	2926992	et	3	main
tähtis	doc_901133458152_item	2927003	et	4	main
oma	doc_901133458153_item	2927026	et	4	main
lapsele	doc_901133458153_item	2927027	et	4	main
kui	doc_901133458153_item	2927028	et	3	main
ta	doc_901133458153_item	2927029	et	4	main
mõned	doc_901133458153_item	2927038	et	3	main
vanemad	doc_901133458153_item	2927039	et	4	main
arvavad	doc_901133458153_item	2927040	et	4	main
et	doc_901133458153_item	2927041	et	3	main
minu	doc_901133458153_item	2927056	et	3	main
span	doc_901133458153_item	2927064	et	4	main
meelest	doc_901133458153_item	2927066	et	4	main
inimese	doc_901133458153_item	2927070	et	4	main
elu	doc_901133458153_item	2927071	et	4	main
näiteks	doc_901133458153_item	2927072	et	4	main
ma	doc_901133458153_item	2927073	et	3	main
armastan	doc_901133458153_item	2927074	et	3	main
igatsen	doc_901133458153_item	2927102	et	3	main
kiiresti	doc_901133458153_item	2927111	et	3	main
iseloomust	doc_901133458153_item	2927120	et	4	main
ta	doc_901133458153_item	2927126	et	4	main
oleks	doc_901133458153_item	2927127	et	3	main
ümbrus	doc_901133458153_item	2927136	et	3	main
vana	doc_901133458154_item	2927150	et	4	main
eesti	doc_901133458154_item	2927163	et	4	main
5	doc_901133458154_item	2927167	et	2	main
varem	doc_901133458154_item	2927169	et	4	main
on	doc_901133458154_item	2927179	et	4	main
paremini	doc_901133458154_item	2927180	et	4	main
on	doc_901133458154_item	2927187	et	4	main
kõnet	doc_901133458154_item	2927221	et	3	main
eestlastega	doc_901133458154_item	2927225	et	4	main
et	doc_901133458154_item	2927236	et	3	main
põhjalikult	doc_901133458154_item	2927239	et	4	main
ma	doc_901133458154_item	2927241	et	3	main
kardan	doc_901133458154_item	2927242	et	4	main
tahaksin	doc_901133458154_item	2927251	et	3	main
palju	doc_901133458154_item	2927254	et	4	main
tunde	doc_901133458154_item	2927255	et	4	main
et	doc_901133458154_item	2927258	et	3	main
xxxxxxx	doc_901133458154_item	2927264	et	4	main
uus	doc_901133458155_item	2927265	et	3	main
meeles	doc_901133458155_item	2927275	et	3	main
tegureid	doc_901133458155_item	2927281	et	4	main
haridus	doc_901133458155_item	2927282	et	3	main
on	doc_901133458155_item	2927283	et	4	main
haritud	doc_901133458155_item	2927287	et	4	main
tavaliselt	doc_901133458155_item	2927290	et	4	main
tuttavad	doc_901133458155_item	2927303	et	4	main
sõbrad	doc_901133458155_item	2927304	et	3	main
kes	doc_901133458155_item	2927305	et	4	main
mõjutav	doc_901133458155_item	2927313	et	4	main
raha	doc_901133458155_item	2927317	et	4	main
sest	doc_901133458155_item	2927321	et	4	main
kõike	doc_901133458155_item	2927323	et	4	main
julge	doc_901133458155_item	2927337	et	4	main
abivalmis	doc_901133458155_item	2927338	et	3	main
meeles	doc_901133458155_item	2927343	et	3	main
span	doc_901133458155_item	2927346	et	4	main
mõjub	doc_901133458155_item	2927349	et	3	main
mingi	doc_901133458155_item	2927354	et	4	main
mida	doc_901133458155_item	2927359	et	4	main
tõustmisega	doc_901133458152_item	2926916	et	4	main
ja	doc_901133458152_item	2926917	et	3	main
millisel	doc_901133458152_item	2926918	et	3	main
on	doc_901133458152_item	2926919	et	4	main
palk	doc_901133458152_item	2926921	et	3	main
elus	doc_901133458152_item	2926932	et	4	main
otsuseid	doc_901133458152_item	2926938	et	3	main
rahvus	doc_901133458152_item	2926944	et	3	main
suurem	doc_901133458152_item	2926953	et	4	main
span	doc_901133458152_item	2926954	et	4	main
on	doc_901133458152_item	2926961	et	4	main
rohkem	doc_901133458152_item	2926965	et	4	main
raha	doc_901133458152_item	2926966	et	4	main
siis	doc_901133458152_item	2926967	et	3	main
laheneb	doc_901133458152_item	2926970	et	3	main
probleemid	doc_901133458152_item	2926972	et	3	main
töö	doc_901133458152_item	2926974	et	4	main
perekond	doc_901133458152_item	2926982	et	3	main
saamiseks	doc_901133458152_item	2926990	et	4	main
põhjendama	doc_901133458152_item	2926991	et	3	main
arvates	doc_901133458152_item	2926995	et	4	main
span	doc_901133458152_item	2927004	et	4	main
uus	doc_901133458153_item	2927005	et	3	main
dokument	doc_901133458153_item	2927006	et	3	main
kõige	doc_901133458153_item	2927022	et	4	main
soovitavad	doc_901133458153_item	2927025	et	4	main
nende	doc_901133458153_item	2927042	et	4	main
laps	doc_901133458153_item	2927043	et	4	main
tahab	doc_901133458153_item	2927049	et	3	main
elust	doc_901133458153_item	2927050	et	3	main
ja	doc_901133458153_item	2927051	et	3	main
ei	doc_901133458153_item	2927052	et	4	main
ema	doc_901133458153_item	2927057	et	4	main
isa	doc_901133458153_item	2927059	et	4	main
mõjutab	doc_901133458153_item	2927069	et	3	main
nende	doc_901133458153_item	2927103	et	4	main
span	doc_901133458153_item	2927105	et	4	main
elu	doc_901133458153_item	2927118	et	4	main
sõltub	doc_901133458153_item	2927119	et	3	main
peab	doc_901133458153_item	2927122	et	4	main
inimese	doc_901133458153_item	2927130	et	4	main
mõjutab	doc_901133458153_item	2927132	et	3	main
kõige	doc_901133458154_item	2927151	et	4	main
on	doc_901133458154_item	2927155	et	4	main
ma	doc_901133458154_item	2927157	et	3	main
kõige	doc_901133458154_item	2927159	et	4	main
rohkem	doc_901133458154_item	2927160	et	4	main
suhelda	doc_901133458154_item	2927161	et	4	main
inimestega	doc_901133458154_item	2927162	et	3	main
õppinud	doc_901133458154_item	2927166	et	4	main
olen	doc_901133458154_item	2927170	et	3	main
emakeelt	doc_901133458154_item	2927172	et	4	main
sellele	doc_901133458154_item	2927177	et	4	main
kursusele	doc_901133458154_item	2927178	et	3	main
eesti	doc_901133458154_item	2927183	et	4	main
selles	doc_901133458154_item	2927188	et	4	main
on	doc_901133458154_item	2927191	et	4	main
on	doc_901133458152_item	2926925	et	4	main
vanemaid	doc_901133458152_item	2926926	et	4	main
nad	doc_901133458152_item	2926927	et	3	main
või	doc_901133458152_item	2926933	et	4	main
asi	doc_901133458152_item	2926940	et	4	main
neljas	doc_901133458152_item	2926942	et	4	main
siin	doc_901133458152_item	2926945	et	4	main
erinevus	doc_901133458152_item	2926947	et	4	main
selles	doc_901133458152_item	2926948	et	4	main
et	doc_901133458152_item	2926949	et	3	main
rahvuse	doc_901133458152_item	2926950	et	3	main
rahast	doc_901133458152_item	2926955	et	4	main
võib	doc_901133458152_item	2926956	et	3	main
oma	doc_901133458152_item	2926971	et	4	main
span	doc_901133458152_item	2926973	et	4	main
on	doc_901133458152_item	2926975	et	4	main
tähtis	doc_901133458152_item	2926976	et	4	main
asi	doc_901133458152_item	2926977	et	4	main
sõbrad	doc_901133458152_item	2926983	et	3	main
on	doc_901133458152_item	2927002	et	4	main
elu	doc_901133458153_item	2927010	et	4	main
et	doc_901133458153_item	2927017	et	3	main
vanemad	doc_901133458153_item	2927018	et	4	main
mõjutavad	doc_901133458153_item	2927019	et	4	main
inimese	doc_901133458153_item	2927020	et	4	main
elu	doc_901133458153_item	2927021	et	4	main
rohkem	doc_901133458153_item	2927023	et	4	main
nad	doc_901133458153_item	2927024	et	3	main
peab	doc_901133458153_item	2927030	et	4	main
elada	doc_901133458153_item	2927031	et	3	main
ja	doc_901133458153_item	2927032	et	3	main
kus	doc_901133458153_item	2927033	et	3	main
ta	doc_901133458153_item	2927034	et	4	main
ta	doc_901133458153_item	2927048	et	4	main
ellu	doc_901133458153_item	2927055	et	4	main
arvamusi	doc_901133458153_item	2927063	et	3	main
minu	doc_901133458153_item	2927065	et	3	main
sünnikoht	doc_901133458153_item	2927067	et	3	main
ka	doc_901133458153_item	2927068	et	3	main
minu	doc_901133458153_item	2927075	et	3	main
linn	doc_901133458153_item	2927076	et	3	main
ja	doc_901133458153_item	2927077	et	3	main
tahaksin	doc_901133458153_item	2927078	et	3	main
õppida	doc_901133458153_item	2927079	et	3	main
ja	doc_901133458153_item	2927080	et	3	main
elada	doc_901133458153_item	2927081	et	3	main
narvas	doc_901133458153_item	2927082	et	4	main
aga	doc_901133458153_item	2927083	et	3	main
praegu	doc_901133458153_item	2927084	et	3	main
ma	doc_901133458153_item	2927085	et	3	main
õpin	doc_901133458153_item	2927086	et	3	main
kohtla-järves	doc_901133458153_item	2927087	et	4	main
sellepärast	doc_901133458153_item	2927088	et	3	main
ei	doc_901133458153_item	2927090	et	4	main
narvas	doc_901133458153_item	2927089	et	4	main
ole	doc_901133458153_item	2927091	et	4	main
minu	doc_901133458153_item	2927092	et	3	main
lemmikku	doc_901133458153_item	2927093	et	4	main
elukutset	doc_901133458153_item	2927094	et	3	main
narvas	doc_901133458153_item	2927095	et	4	main
elavad	doc_901133458153_item	2927096	et	4	main
õppida	doc_901133458153_item	2927036	et	3	main
aga	doc_901133458153_item	2927037	et	3	main
või	doc_901133458153_item	2927044	et	4	main
sekku	doc_901133458153_item	2927053	et	4	main
ja	doc_901133458153_item	2927058	et	3	main
ja	doc_901133458153_item	2927101	et	3	main
järel	doc_901133458153_item	2927104	et	4	main
tarkus	doc_901133458153_item	2927106	et	4	main
mõjutab	doc_901133458153_item	2927107	et	3	main
elu	doc_901133458153_item	2927108	et	4	main
leiab	doc_901133458153_item	2927112	et	3	main
inimese	doc_901133458153_item	2927117	et	4	main
ta	doc_901133458153_item	2927121	et	4	main
olema	doc_901133458153_item	2927123	et	4	main
sihikinel	doc_901133458153_item	2927124	et	4	main
et	doc_901133458153_item	2927125	et	3	main
tema	doc_901133458153_item	2927135	et	4	main
õpetaja	doc_901133458154_item	2927141	et	4	main
xxxxxxx	doc_901133458154_item	2927146	et	4	main
olen	doc_901133458154_item	2927147	et	3	main
19	doc_901133458154_item	2927148	et	2	main
aastat	doc_901133458154_item	2927149	et	3	main
olen	doc_901133458154_item	2927165	et	3	main
õppinud	doc_901133458154_item	2927171	et	4	main
esimene	doc_901133458154_item	2927173	et	3	main
põhjus	doc_901133458154_item	2927174	et	4	main
et	doc_901133458154_item	2927189	et	3	main
tahan	doc_901133458154_item	2927223	et	3	main
olukordades	doc_901133458154_item	2927227	et	3	main
ma	doc_901133458154_item	2927234	et	3	main
natuke	doc_901133458154_item	2927243	et	4	main
et	doc_901133458154_item	2927244	et	3	main
span	doc_901133458155_item	2927272	et	4	main
palju	doc_901133458155_item	2927280	et	4	main
tähtis	doc_901133458155_item	2927285	et	4	main
inimesed	doc_901133458155_item	2927288	et	3	main
parimad	doc_901133458155_item	2927291	et	4	main
töökohad	doc_901133458155_item	2927292	et	4	main
vaid	doc_901133458155_item	2927293	et	3	main
mitte	doc_901133458155_item	2927294	et	3	main
haridus	doc_901133458155_item	2927295	et	3	main
mõjub	doc_901133458155_item	2927296	et	3	main
et	doc_901133458155_item	2927297	et	3	main
saada	doc_901133458155_item	2927298	et	4	main
aidata	doc_901133458155_item	2927307	et	4	main
saada	doc_901133458155_item	2927308	et	4	main
hea	doc_901133458155_item	2927309	et	4	main
töökoht	doc_901133458155_item	2927310	et	3	main
inimese	doc_901133458155_item	2927314	et	4	main
vaja	doc_901133458155_item	2927326	et	4	main
maksta	doc_901133458155_item	2927327	et	4	main
on	doc_901133458155_item	2927336	et	4	main
minu	doc_901133458155_item	2927342	et	3	main
ka	doc_901133458155_item	2927348	et	3	main
tea	doc_901133458155_item	2927358	et	4	main
span	doc_901133458155_item	2927366	et	4	main
edukas	doc_901133458153_item	2927128	et	4	main
kõik	doc_901133458153_item	2927133	et	4	main
mida	doc_901133458153_item	2927134	et	4	main
uus	doc_901133458154_item	2927138	et	3	main
dokument	doc_901133458154_item	2927139	et	3	main
nimi	doc_901133458154_item	2927143	et	3	main
on	doc_901133458154_item	2927144	et	4	main
xxxxxxxx	doc_901133458154_item	2927145	et	4	main
õpimine	doc_901133458154_item	2927156	et	4	main
keelt	doc_901133458154_item	2927164	et	4	main
miks	doc_901133458154_item	2927175	et	4	main
tulin	doc_901133458154_item	2927176	et	3	main
saada	doc_901133458154_item	2927182	et	4	main
teine	doc_901133458154_item	2927185	et	3	main
palju	doc_901133458154_item	2927192	et	4	main
eestlase	doc_901133458154_item	2927193	et	3	main
sõpru	doc_901133458154_item	2927194	et	3	main
ja	doc_901133458154_item	2927195	et	3	main
ma	doc_901133458154_item	2927196	et	3	main
tahan	doc_901133458154_item	2927197	et	3	main
nendega	doc_901133458154_item	2927198	et	4	main
suhelda	doc_901133458154_item	2927199	et	4	main
mul	doc_901133458154_item	2927200	et	3	main
on	doc_901133458154_item	2927201	et	4	main
eesti	doc_901133458154_item	2927202	et	4	main
keelt	doc_901133458154_item	2927203	et	4	main
vaja	doc_901133458154_item	2927204	et	4	main
et	doc_901133458154_item	2927205	et	3	main
lugeda	doc_901133458154_item	2927206	et	3	main
ilukirjanduse	doc_901133458154_item	2927207	et	3	main
ja	doc_901133458154_item	2927208	et	3	main
muud	doc_901133458154_item	2927209	et	4	main
eesti	doc_901133458154_item	2927210	et	4	main
raamatuid	doc_901133458154_item	2927211	et	3	main
mul	doc_901133458154_item	2927212	et	3	main
on	doc_901133458154_item	2927213	et	4	main
vaja	doc_901133458154_item	2927214	et	4	main
kuulamist	doc_901133458154_item	2927215	et	4	main
sest	doc_901133458154_item	2927216	et	4	main
ma	doc_901133458154_item	2927217	et	3	main
tahan	doc_901133458154_item	2927218	et	3	main
kuulda	doc_901133458154_item	2927219	et	4	main
eesti	doc_901133458154_item	2927220	et	4	main
ma	doc_901133458154_item	2927222	et	3	main
ma	doc_901133458154_item	2927228	et	3	main
me	doc_901133458154_item	2927237	et	4	main
ma	doc_901133458154_item	2927245	et	3	main
aru	doc_901133458154_item	2927248	et	4	main
ma	doc_901133458154_item	2927250	et	3	main
kui	doc_901133458154_item	2927253	et	3	main
nädalas	doc_901133458154_item	2927256	et	3	main
on	doc_901133458154_item	2927259	et	4	main
huvitavad	doc_901133458154_item	2927260	et	4	main
tegurid	doc_901133458155_item	2927267	et	3	main
erinevates	doc_901133458154_item	2927226	et	4	main
ilusasti	doc_901133458154_item	2927231	et	3	main
õigesti	doc_901133458154_item	2927233	et	3	main
tegeleme	doc_901133458154_item	2927238	et	3	main
rääkimisega	doc_901133458154_item	2927240	et	4	main
ei	doc_901133458154_item	2927246	et	4	main
saa	doc_901133458154_item	2927247	et	4	main
õpetajat	doc_901133458154_item	2927249	et	4	main
teada	doc_901133458154_item	2927252	et	3	main
tunde	doc_901133458154_item	2927261	et	4	main
lugupidamisega	doc_901133458154_item	2927262	et	3	main
xxxxxxxx	doc_901133458154_item	2927263	et	4	main
mis	doc_901133458155_item	2927268	et	4	main
inimese	doc_901133458155_item	2927270	et	4	main
span	doc_901133458155_item	2927273	et	4	main
et	doc_901133458155_item	2927276	et	3	main
et	doc_901133458155_item	2927286	et	3	main
span	doc_901133458155_item	2927311	et	4	main
ilma	doc_901133458155_item	2927316	et	4	main
praegu	doc_901133458155_item	2927322	et	3	main
ta	doc_901133458155_item	2927335	et	4	main
temale	doc_901133458155_item	2927341	et	3	main
elus	doc_901133458155_item	2927345	et	4	main
saatus	doc_901133458155_item	2927347	et	3	main
inimese	doc_901133458155_item	2927350	et	4	main
elu	doc_901133458155_item	2927351	et	4	main
ei	doc_901133458155_item	2927357	et	4	main
uus	doc_901133458157_item	2927472	et	3	main
a	doc_901133458157_item	2927474	et	4	main
rikkis	doc_901133458157_item	2927478	et	3	main
see	doc_901133458157_item	2927480	et	3	main
tekkis	doc_901133458157_item	2927487	et	3	main
mis	doc_901133458157_item	2927489	et	4	main
tulekahju	doc_901133458157_item	2927491	et	4	main
c	doc_901133458157_item	2927493	et	4	main
kulu	doc_901133458157_item	2927511	et	4	main
elektriloenduri	doc_901133458157_item	2927513	et	3	main
jätke	doc_901133458157_item	2927516	et	4	main
spetsialistidele	doc_901133458157_item	2927519	et	3	main
span	doc_901133458157_item	2927526	et	4	main
võtage	doc_901133458157_item	2927528	et	4	main
panna	doc_901133458157_item	2927538	et	4	main
ärge	doc_901133458157_item	2927556	et	3	main
taldrikud	doc_901133458157_item	2927559	et	3	main
teie	doc_901133458157_item	2927570	et	4	main
süüa	doc_901133458157_item	2927571	et	3	main
mida	doc_901133458157_item	2927581	et	4	main
te	doc_901133458157_item	2927582	et	4	main
või	doc_901133458157_item	2927585	et	4	main
söögiristad	doc_901133458157_item	2927601	et	4	main
mikrolaenu	doc_901133458157_item	2927605	et	4	main
ahi	doc_901133458157_item	2927606	et	4	main
tühjalt	doc_901133458157_item	2927607	et	4	main
2	doc_901133458158_item	2927621	et	2	main
käivitusnupp	doc_901133458158_item	2927634	et	3	main
alla	doc_901133458158_item	2927635	et	3	main
5	doc_901133458158_item	2927637	et	2	main
häälestage	doc_901133458158_item	2927638	et	3	main
teleprogrammid	doc_901133458158_item	2927639	et	3	main
span	doc_901133458158_item	2927640	et	4	main
6	doc_901133458158_item	2927641	et	2	main
kui	doc_901133458158_item	2927642	et	3	main
teleprogrammid	doc_901133458158_item	2927643	et	3	main
häälestatud	doc_901133458158_item	2927644	et	4	main
siis	doc_901133458158_item	2927645	et	3	main
saate	doc_901133458158_item	2927646	et	4	main
eest	doc_901133458158_item	2927654	et	4	main
mõjutavad	doc_901133458155_item	2927269	et	4	main
elu	doc_901133458155_item	2927271	et	4	main
mõjutavad	doc_901133458155_item	2927279	et	4	main
väga	doc_901133458155_item	2927284	et	3	main
saavad	doc_901133458155_item	2927289	et	4	main
hea	doc_901133458155_item	2927299	et	4	main
töökoht	doc_901133458155_item	2927300	et	3	main
võivad	doc_901133458155_item	2927306	et	4	main
elu	doc_901133458155_item	2927315	et	4	main
on	doc_901133458155_item	2927318	et	4	main
elada	doc_901133458155_item	2927320	et	3	main
eest	doc_901133458155_item	2927324	et	4	main
on	doc_901133458155_item	2927325	et	4	main
elu	doc_901133458155_item	2927333	et	4	main
kui	doc_901133458155_item	2927334	et	3	main
vastutav	doc_901133458155_item	2927339	et	4	main
kava	doc_901133458155_item	2927340	et	4	main
elu	doc_901133458155_item	2927352	et	4	main
leidad	doc_901133458155_item	2927361	et	4	main
ja	doc_901133458155_item	2927362	et	3	main
sa	doc_901133458155_item	2927364	et	3	main
kaotad	doc_901133458155_item	2927365	et	3	main
dokument	doc_901133458157_item	2927473	et	3	main
ärge	doc_901133458157_item	2927475	et	3	main
kasutage	doc_901133458157_item	2927477	et	3	main
juhtmes	doc_901133458157_item	2927485	et	3	main
span	doc_901133458157_item	2927492	et	4	main
ärge	doc_901133458157_item	2927504	et	3	main
kasutage	doc_901133458157_item	2927505	et	3	main
mobiiltelefoni	doc_901133458157_item	2927506	et	4	main
tanklas	doc_901133458157_item	2927507	et	3	main
elektrienergia	doc_901133458157_item	2927510	et	4	main
span	doc_901133458155_item	2927328	et	4	main
iseloom	doc_901133458155_item	2927329	et	3	main
ka	doc_901133458155_item	2927330	et	3	main
mõjub	doc_901133458155_item	2927331	et	3	main
inimese	doc_901133458155_item	2927332	et	4	main
kergem	doc_901133458155_item	2927344	et	4	main
on	doc_901133458155_item	2927353	et	4	main
loterii	doc_901133458155_item	2927355	et	4	main
sa	doc_901133458155_item	2927356	et	3	main
sa	doc_901133458155_item	2927360	et	3	main
mida	doc_901133458155_item	2927363	et	4	main
b	doc_901133458157_item	2927484	et	4	main
uhendada	doc_901133458157_item	2927488	et	4	main
on	doc_901133458157_item	2927496	et	4	main
väga	doc_901133458157_item	2927497	et	3	main
võimsus	doc_901133458157_item	2927498	et	4	main
d	doc_901133458157_item	2927503	et	4	main
suuremad	doc_901133458157_item	2927517	et	4	main
ahi	doc_901133458157_item	2927529	et	4	main
eest	doc_901133458157_item	2927531	et	4	main
te	doc_901133458157_item	2927536	et	4	main
tahate	doc_901133458157_item	2927537	et	3	main
ei	doc_901133458157_item	2927541	et	4	main
niiskust	doc_901133458157_item	2927543	et	4	main
ja	doc_901133458157_item	2927544	et	3	main
kuumust	doc_901133458157_item	2927545	et	4	main
valige	doc_901133458157_item	2927563	et	3	main
kell	doc_901133458157_item	2927564	et	3	main
kui	doc_901133458157_item	2927565	et	3	main
rohkem	doc_901133458157_item	2927566	et	4	main
span	doc_901133458157_item	2927572	et	4	main
peapanelli	doc_901133458157_item	2927573	et	4	main
veel	doc_901133458157_item	2927575	et	4	main
te	doc_901133458157_item	2927579	et	4	main
sulatama	doc_901133458157_item	2927587	et	4	main
või	doc_901133458157_item	2927588	et	4	main
soojendama	doc_901133458157_item	2927589	et	3	main
arge	doc_901133458157_item	2927593	et	3	main
pange	doc_901133458157_item	2927594	et	4	main
ahjusse	doc_901133458157_item	2927597	et	3	main
savine	doc_901133458157_item	2927600	et	4	main
span	doc_901133458158_item	2927613	et	4	main
karbist	doc_901133458158_item	2927618	et	3	main
kunagi	doc_901133458157_item	2927476	et	3	main
elektriseadet	doc_901133458157_item	2927479	et	4	main
on	doc_901133458157_item	2927486	et	4	main
see	doc_901133458157_item	2927494	et	3	main
elektripirn	doc_901133458157_item	2927495	et	3	main
selle	doc_901133458157_item	2927499	et	4	main
laualambi	doc_901133458157_item	2927500	et	3	main
span	doc_901133458157_item	2927508	et	4	main
span	doc_901133458157_item	2927514	et	4	main
f	doc_901133458157_item	2927515	et	4	main
elektritööd	doc_901133458157_item	2927518	et	4	main
span	doc_901133458157_item	2927520	et	4	main
span	doc_901133458157_item	2927532	et	4	main
valige	doc_901133458157_item	2927533	et	3	main
kuhu	doc_901133458157_item	2927535	et	3	main
span	doc_901133458157_item	2927546	et	4	main
pistke	doc_901133458157_item	2927547	et	3	main
seinakontakti	doc_901133458157_item	2927549	et	4	main
ja	doc_901133458157_item	2927560	et	3	main
lusikad	doc_901133458157_item	2927561	et	3	main
sega	doc_901133458157_item	2927567	et	4	main
kuumi	doc_901133458157_item	2927568	et	4	main
oli	doc_901133458157_item	2927569	et	3	main
on	doc_901133458157_item	2927574	et	4	main
temaga	doc_901133458157_item	2927578	et	3	main
valige	doc_901133458157_item	2927580	et	3	main
teha	doc_901133458157_item	2927584	et	3	main
üles	doc_901133458157_item	2927586	et	3	main
või	doc_901133458157_item	2927590	et	4	main
span	doc_901133458157_item	2927602	et	4	main
arge	doc_901133458157_item	2927603	et	3	main
pange	doc_901133458157_item	2927604	et	4	main
uus	doc_901133458158_item	2927610	et	3	main
1	doc_901133458158_item	2927615	et	2	main
võtke	doc_901133458158_item	2927616	et	3	main
välja	doc_901133458158_item	2927619	et	4	main
span	doc_901133458158_item	2927620	et	4	main
on	doc_901133458157_item	2927481	et	4	main
eluohtlik	doc_901133458157_item	2927482	et	3	main
span	doc_901133458157_item	2927483	et	4	main
tekib	doc_901133458157_item	2927490	et	3	main
jaoks	doc_901133458157_item	2927501	et	4	main
span	doc_901133458157_item	2927502	et	4	main
e	doc_901133458157_item	2927509	et	4	main
mõõdab	doc_901133458157_item	2927512	et	3	main
span	doc_901133458157_item	2927522	et	4	main
mikrolaenu	doc_901133458157_item	2927523	et	4	main
span	doc_901133458157_item	2927527	et	4	main
paki	doc_901133458157_item	2927530	et	4	main
koht	doc_901133458157_item	2927534	et	3	main
kus	doc_901133458157_item	2927540	et	3	main
ole	doc_901133458157_item	2927542	et	4	main
metall	doc_901133458157_item	2927558	et	3	main
span	doc_901133458157_item	2927562	et	4	main
regulaator	doc_901133458157_item	2927576	et	3	main
võimsuse	doc_901133458157_item	2927577	et	4	main
span	doc_901133458157_item	2927592	et	4	main
munad	doc_901133458157_item	2927595	et	3	main
koduloomad	doc_901133458157_item	2927596	et	3	main
tööle	doc_901133458157_item	2927608	et	3	main
span	doc_901133458157_item	2927609	et	4	main
dokument	doc_901133458158_item	2927611	et	3	main
telerit	doc_901133458158_item	2927623	et	3	main
peale	doc_901133458158_item	2927625	et	4	main
3	doc_901133458158_item	2927627	et	2	main
nb	doc_901133458158_item	2927650	et	4	main
1	doc_901133458158_item	2927651	et	2	main
rikkis	doc_901133458160_item	2927797	et	3	main
see	doc_901133458160_item	2927799	et	3	main
eluohtlik	doc_901133458160_item	2927801	et	3	main
tanklas	doc_901133458160_item	2927826	et	3	main
5	doc_901133458160_item	2927828	et	2	main
kohvikeetja	doc_901133458160_item	2927842	et	4	main
kasutusjuhend	doc_901133458160_item	2927843	et	3	main
span	doc_901133458160_item	2927851	et	4	main
2	doc_901133458160_item	2927852	et	2	main
valige	doc_901133458160_item	2927853	et	3	main
koht	doc_901133458160_item	2927854	et	3	main
kohvikeetjasse	doc_901133458160_item	2927868	et	3	main
4	doc_901133458160_item	2927870	et	2	main
5	doc_901133458160_item	2927875	et	2	main
kohvi	doc_901133458160_item	2927892	et	4	main
jätke	doc_901133458160_item	2927896	et	4	main
kohvimaasin	doc_901133458160_item	2927915	et	4	main
ära	doc_901133458160_item	2927916	et	4	main
valmis	doc_901133458160_item	2927922	et	4	main
span	doc_901133458160_item	2927923	et	4	main
peske	doc_901133458160_item	2927925	et	3	main
в	doc_901133458161_item	2927938	et	2	main
mis	doc_901133458161_item	2927944	et	4	main
on	doc_901133458161_item	2927958	et	4	main
kindlus	doc_901133458161_item	2927963	et	4	main
ma	doc_901133458161_item	2927967	et	3	main
korteri	doc_901133458161_item	2927974	et	3	main
2	doc_901133458161_item	2927983	et	2	main
sinu	doc_901133458161_item	2927986	et	3	main
span	doc_901133458157_item	2927521	et	4	main
ahi	doc_901133458157_item	2927524	et	4	main
kasutusjuhend	doc_901133458157_item	2927525	et	3	main
ja	doc_901133458157_item	2927539	et	3	main
pistik	doc_901133458157_item	2927548	et	3	main
span	doc_901133458157_item	2927550	et	4	main
pange	doc_901133458157_item	2927551	et	4	main
söök	doc_901133458157_item	2927552	et	3	main
taldrikul	doc_901133458157_item	2927553	et	3	main
ahjusse	doc_901133458157_item	2927554	et	3	main
span	doc_901133458157_item	2927555	et	4	main
kasutage	doc_901133458157_item	2927557	et	3	main
tahate	doc_901133458157_item	2927583	et	3	main
grill	doc_901133458157_item	2927591	et	3	main
span	doc_901133458157_item	2927598	et	4	main
asutage	doc_901133458157_item	2927599	et	3	main
telerit	doc_901133458158_item	2927612	et	3	main
span	doc_901133458158_item	2927614	et	4	main
telerit	doc_901133458158_item	2927617	et	3	main
span	doc_901133458158_item	2927631	et	4	main
4	doc_901133458158_item	2927632	et	2	main
vajutage	doc_901133458158_item	2927633	et	3	main
vaadate	doc_901133458158_item	2927647	et	4	main
telerit	doc_901133458158_item	2927648	et	3	main
hotke	doc_901133458158_item	2927652	et	4	main
2	doc_901133458158_item	2927656	et	2	main
ärge	doc_901133458158_item	2927657	et	3	main
ärge	doc_901133458160_item	2927795	et	3	main
elektrisedmeid	doc_901133458160_item	2927798	et	4	main
on	doc_901133458160_item	2927800	et	4	main
4	doc_901133458160_item	2927822	et	2	main
kasutage	doc_901133458160_item	2927824	et	3	main
span	doc_901133458160_item	2927827	et	4	main
6	doc_901133458160_item	2927833	et	2	main
suuremad	doc_901133458160_item	2927835	et	4	main
elektritööd	doc_901133458160_item	2927836	et	4	main
span	doc_901133458160_item	2927839	et	4	main
kohvikeetja	doc_901133458160_item	2927847	et	4	main
span	doc_901133458160_item	2927869	et	4	main
pange	doc_901133458160_item	2927871	et	4	main
vesi	doc_901133458160_item	2927872	et	4	main
span	doc_901133458160_item	2927900	et	4	main
kui	doc_901133458160_item	2927902	et	3	main
on	doc_901133458160_item	2927904	et	4	main
vähe	doc_901133458160_item	2927905	et	3	main
lisage	doc_901133458160_item	2927906	et	3	main
palun	doc_901133458160_item	2927907	et	3	main
juurde	doc_901133458160_item	2927908	et	4	main
span	doc_901133458160_item	2927909	et	4	main
10	doc_901133458160_item	2927910	et	2	main
teie	doc_901133458160_item	2927919	et	4	main
laua	doc_901133458158_item	2927624	et	3	main
span	doc_901133458158_item	2927626	et	4	main
pistke	doc_901133458158_item	2927628	et	3	main
pistik	doc_901133458158_item	2927629	et	3	main
seinakontakti	doc_901133458158_item	2927630	et	4	main
span	doc_901133458158_item	2927655	et	4	main
krimustage	doc_901133458158_item	2927658	et	4	main
kineskoopi	doc_901133458158_item	2927659	et	4	main
span	doc_901133458158_item	2927660	et	4	main
pange	doc_901133458158_item	2927622	et	4	main
span	doc_901133458158_item	2927636	et	4	main
span	doc_901133458158_item	2927649	et	4	main
vee	doc_901133458158_item	2927653	et	3	main
dokument	doc_901133458160_item	2927793	et	3	main
kasutage	doc_901133458160_item	2927796	et	3	main
1	doc_901133458160_item	2927794	et	2	main
elektriarvesti	doc_901133458160_item	2927831	et	4	main
asjatundja	doc_901133458160_item	2927837	et	4	main
paki	doc_901133458160_item	2927848	et	4	main
seest	doc_901133458160_item	2927849	et	3	main
välja	doc_901133458160_item	2927850	et	4	main
8	doc_901133458160_item	2927894	et	2	main
kohvikeetajat	doc_901133458160_item	2927897	et	4	main
ilma	doc_901133458160_item	2927898	et	4	main
järelevalveta	doc_901133458160_item	2927899	et	3	main
9	doc_901133458160_item	2927901	et	2	main
pärast	doc_901133458160_item	2927911	et	4	main
lõppemist	doc_901133458160_item	2927913	et	4	main
lülitage	doc_901133458160_item	2927914	et	3	main
kohv	doc_901133458160_item	2927920	et	3	main
on	doc_901133458160_item	2927921	et	4	main
12	doc_901133458160_item	2927924	et	2	main
kohvimaasin	doc_901133458160_item	2927926	et	4	main
puhtaks	doc_901133458160_item	2927927	et	3	main
vasta	doc_901133458161_item	2927935	et	4	main
järgmistele	doc_901133458161_item	2927936	et	3	main
kodulinnast	doc_901133458161_item	2927943	et	4	main
sinu	doc_901133458161_item	2927946	et	3	main
pime	doc_901133458161_item	2927965	et	3	main
asub	doc_901133458161_item	2927977	et	3	main
в	doc_901133458161_item	2927982	et	2	main
on	doc_901133458161_item	2927994	et	4	main
väike	doc_901133458161_item	2927995	et	4	main
perekond	doc_901133458161_item	2927996	et	3	main
ma	doc_901133458161_item	2927997	et	3	main
ja	doc_901133458161_item	2927998	et	3	main
minu	doc_901133458161_item	2927999	et	3	main
õppin	doc_901133458161_item	2928003	et	4	main
ja	doc_901133458161_item	2928005	et	3	main
mina	doc_901133458161_item	2928006	et	4	main
в	doc_901133458161_item	2928010	et	2	main
mul	doc_901133458161_item	2928042	et	3	main
ei	doc_901133458161_item	2928043	et	4	main
kuulata	doc_901133458161_item	2928049	et	4	main
elab	doc_901133458161_item	2928059	et	3	main
p	doc_901133458162_item	2928071	et	4	main
sinu	doc_901133458162_item	2928115	et	3	main
p	doc_901133458162_item	2928120	et	4	main
p	doc_901133458162_item	2928123	et	4	main
elan	doc_901133458162_item	2928138	et	3	main
maja	doc_901133458162_item	2928140	et	4	main
ei	doc_901133458162_item	2928142	et	4	main
ole	doc_901133458162_item	2928143	et	4	main
suur	doc_901133458162_item	2928145	et	3	main
em	doc_901133458162_item	2928152	et	4	main
в	doc_901133458162_item	2928160	et	2	main
milline	doc_901133458162_item	2928163	et	3	main
span	doc_901133458162_item	2928167	et	4	main
p	doc_901133458162_item	2928168	et	4	main
в	doc_901133458162_item	2928177	et	2	main
millega	doc_901133458162_item	2928179	et	3	main
p	doc_901133458162_item	2928223	et	4	main
langetkas	doc_901133458162_item	2928225	et	4	main
on	doc_901133458162_item	2928227	et	4	main
mis	doc_901133458162_item	2928230	et	4	main
on	doc_901133458162_item	2928231	et	4	main
sinu	doc_901133458162_item	2928232	et	3	main
sгјua	doc_901133458162_item	2928249	et	2	main
uus	doc_901133458160_item	2927792	et	3	main
span	doc_901133458160_item	2927802	et	4	main
2	doc_901133458160_item	2927803	et	2	main
juhtmes	doc_901133458160_item	2927804	et	3	main
tekkis	doc_901133458160_item	2927805	et	3	main
lühis	doc_901133458160_item	2927806	et	4	main
mis	doc_901133458160_item	2927807	et	4	main
põhjustab	doc_901133458160_item	2927808	et	3	main
tulekahju	doc_901133458160_item	2927809	et	4	main
span	doc_901133458160_item	2927810	et	4	main
3	doc_901133458160_item	2927811	et	2	main
see	doc_901133458160_item	2927812	et	3	main
pirn	doc_901133458160_item	2927813	et	3	main
on	doc_901133458160_item	2927814	et	4	main
selle	doc_901133458160_item	2927815	et	4	main
laua	doc_901133458160_item	2927816	et	3	main
lambi	doc_901133458160_item	2927817	et	4	main
jaoks	doc_901133458160_item	2927818	et	4	main
liiga	doc_901133458160_item	2927819	et	4	main
võimsas	doc_901133458160_item	2927820	et	3	main
span	doc_901133458160_item	2927821	et	4	main
mobiiltelefoni	doc_901133458160_item	2927825	et	4	main
mõõdab	doc_901133458160_item	2927830	et	3	main
span	doc_901133458160_item	2927832	et	4	main
hooleks	doc_901133458160_item	2927838	et	3	main
span	doc_901133458160_item	2927840	et	4	main
span	doc_901133458160_item	2927841	et	4	main
kohvikeetjat	doc_901133458160_item	2927856	et	3	main
span	doc_901133458160_item	2927874	et	4	main
pistik	doc_901133458160_item	2927877	et	3	main
span	doc_901133458160_item	2927879	et	4	main
span	doc_901133458160_item	2927917	et	4	main
11	doc_901133458160_item	2927918	et	2	main
13	doc_901133458160_item	2927929	et	2	main
meeldiv	doc_901133458160_item	2927930	et	4	main
söögilisu	doc_901133458160_item	2927931	et	4	main
span	doc_901133458160_item	2927932	et	4	main
uus	doc_901133458161_item	2927933	et	3	main
dokument	doc_901133458161_item	2927934	et	3	main
ärge	doc_901133458160_item	2927823	et	3	main
elektrikulu	doc_901133458160_item	2927829	et	4	main
jätke	doc_901133458160_item	2927834	et	4	main
span	doc_901133458160_item	2927844	et	4	main
1	doc_901133458160_item	2927845	et	2	main
võtke	doc_901133458160_item	2927846	et	3	main
kuhu	doc_901133458160_item	2927855	et	3	main
panna	doc_901133458160_item	2927857	et	4	main
parim	doc_901133458160_item	2927858	et	4	main
on	doc_901133458160_item	2927860	et	4	main
laual	doc_901133458160_item	2927861	et	3	main
koht	doc_901133458160_item	2927859	et	3	main
seinakontakdi	doc_901133458160_item	2927862	et	4	main
kõrval	doc_901133458160_item	2927863	et	4	main
span	doc_901133458160_item	2927864	et	4	main
3	doc_901133458160_item	2927865	et	2	main
pange	doc_901133458160_item	2927866	et	4	main
kohv	doc_901133458160_item	2927867	et	3	main
kohvikeetjasse	doc_901133458160_item	2927873	et	3	main
pistke	doc_901133458160_item	2927876	et	3	main
seinakontakti	doc_901133458160_item	2927878	et	4	main
6	doc_901133458160_item	2927880	et	2	main
vajutage	doc_901133458160_item	2927881	et	3	main
käivitusnupp	doc_901133458160_item	2927882	et	3	main
alla	doc_901133458160_item	2927883	et	3	main
span	doc_901133458160_item	2927884	et	4	main
7	doc_901133458160_item	2927885	et	2	main
oodake	doc_901133458160_item	2927886	et	3	main
15-20	doc_901133458160_item	2927887	et	2	main
minutit	doc_901133458160_item	2927888	et	3	main
kuni	doc_901133458160_item	2927889	et	3	main
kohvimaasin	doc_901133458160_item	2927890	et	4	main
valmistab	doc_901133458160_item	2927891	et	3	main
span	doc_901133458160_item	2927893	et	4	main
ärge	doc_901133458160_item	2927895	et	3	main
vett	doc_901133458160_item	2927903	et	3	main
töö	doc_901133458160_item	2927912	et	4	main
span	doc_901133458160_item	2927928	et	4	main
küsimustele	doc_901133458161_item	2927937	et	4	main
1	doc_901133458161_item	2927939	et	2	main
kirjuta	doc_901133458161_item	2927940	et	4	main
on	doc_901133458161_item	2927945	et	4	main
в	doc_901133458161_item	2927955	et	2	main
aed	doc_901133458161_item	2927966	et	3	main
elan	doc_901133458161_item	2927968	et	3	main
on	doc_901133458161_item	2927972	et	4	main
kahetoas	doc_901133458161_item	2927973	et	3	main
puud	doc_901133458161_item	2927976	et	4	main
milline	doc_901133458161_item	2927984	et	3	main
pois	doc_901133458161_item	2928002	et	3	main
sul	doc_901133458161_item	2928019	et	3	main
mingeid	doc_901133458161_item	2928021	et	3	main
sinu	doc_901133458161_item	2928025	et	3	main
kus	doc_901133458161_item	2928027	et	3	main
sa	doc_901133458161_item	2928028	et	3	main
suvel	doc_901133458161_item	2928029	et	3	main
puhkad	doc_901133458161_item	2928030	et	3	main
в	doc_901133458161_item	2928031	et	2	main
vaadata	doc_901133458161_item	2928040	et	4	main
telerit	doc_901133458161_item	2928041	et	3	main
muusikat	doc_901133458161_item	2928050	et	3	main
minu	doc_901133458161_item	2928057	et	3	main
dokument	doc_901133458162_item	2928063	et	3	main
kгјsimustele	doc_901133458162_item	2928066	et	2	main
p	doc_901133458162_item	2928068	et	4	main
kirjuta	doc_901133458162_item	2928080	et	4	main
ja	doc_901133458162_item	2928117	et	3	main
span	doc_901133458162_item	2928119	et	4	main
classmsonormalspan	doc_901133458162_item	2928121	et	4	main
ilus	doc_901133458162_item	2928128	et	4	main
linn	doc_901133458162_item	2928129	et	3	main
meie	doc_901133458162_item	2928130	et	4	main
aed	doc_901133458162_item	2928136	et	3	main
eriti	doc_901133458162_item	2928144	et	3	main
korter	doc_901133458162_item	2928146	et	3	main
maja	doc_901133458162_item	2928147	et	4	main
в	doc_901133458162_item	2928153	et	2	main
classmsonormalspan	doc_901133458162_item	2928156	et	4	main
в	doc_901133458162_item	2928158	et	2	main
в	doc_901133458162_item	2928176	et	2	main
span	doc_901133458162_item	2928178	et	4	main
tegelevad	doc_901133458162_item	2928180	et	4	main
sinu	doc_901133458162_item	2928181	et	3	main
pereliikmed	doc_901133458162_item	2928182	et	3	main
span	doc_901133458162_item	2928183	et	4	main
oma	doc_901133458161_item	2927942	et	4	main
kodulinnas	doc_901133458161_item	2927947	et	4	main
huvitavat	doc_901133458161_item	2927948	et	4	main
missugune	doc_901133458161_item	2927949	et	3	main
on	doc_901133458161_item	2927950	et	4	main
sinu	doc_901133458161_item	2927951	et	3	main
kodu	doc_901133458161_item	2927952	et	4	main
ja	doc_901133458161_item	2927953	et	3	main
koduümbrus	doc_901133458161_item	2927954	et	3	main
midagi	doc_901133458161_item	2927941	et	4	main
linn	doc_901133458161_item	2927957	et	3	main
ilus	doc_901133458161_item	2927959	et	4	main
meie	doc_901133458161_item	2927960	et	4	main
linnas	doc_901133458161_item	2927961	et	4	main
loss	doc_901133458161_item	2927964	et	3	main
maja	doc_901133458161_item	2927970	et	4	main
lilled	doc_901133458161_item	2927975	et	3	main
maja	doc_901133458161_item	2927978	et	4	main
ääres	doc_901133458161_item	2927979	et	4	main
väga	doc_901133458161_item	2927980	et	3	main
pois	doc_901133458161_item	2928000	et	3	main
praegu	doc_901133458161_item	2928007	et	3	main
lähen	doc_901133458161_item	2928008	et	3	main
kursussell	doc_901133458161_item	2928009	et	3	main
3	doc_901133458161_item	2928011	et	2	main
mida	doc_901133458161_item	2928012	et	4	main
sulle	doc_901133458161_item	2928013	et	3	main
meeldib	doc_901133458161_item	2928014	et	3	main
vabal	doc_901133458161_item	2928015	et	3	main
ajal	doc_901133458161_item	2928016	et	4	main
teha	doc_901133458161_item	2928017	et	3	main
minu	doc_901133458161_item	2927956	et	3	main
on	doc_901133458161_item	2927962	et	4	main
üheksakorrossel	doc_901133458161_item	2927969	et	4	main
mul	doc_901133458161_item	2927971	et	3	main
ilus	doc_901133458161_item	2927981	et	4	main
on	doc_901133458161_item	2927985	et	4	main
perekond	doc_901133458161_item	2927987	et	3	main
tegelevad	doc_901133458161_item	2927989	et	4	main
pereliikmed	doc_901133458161_item	2927991	et	3	main
mul	doc_901133458161_item	2927993	et	3	main
minu	doc_901133458161_item	2928001	et	3	main
koolis	doc_901133458161_item	2928004	et	4	main
kas	doc_901133458161_item	2928018	et	3	main
mis	doc_901133458161_item	2928023	et	4	main
ole	doc_901133458161_item	2928044	et	4	main
hobisid	doc_901133458161_item	2928045	et	3	main
minu	doc_901133458161_item	2928046	et	3	main
lemmiktegevus	doc_901133458161_item	2928047	et	4	main
reisida	doc_901133458161_item	2928052	et	3	main
puhkan	doc_901133458161_item	2928054	et	3	main
narva-jõesusse	doc_901133458161_item	2928056	et	3	main
meeldib	doc_901133458161_item	2928058	et	3	main
ääres	doc_901133458161_item	2928061	et	4	main
jгrgmistele	doc_901133458162_item	2928065	et	2	main
span	doc_901133458162_item	2928067	et	4	main
p	doc_901133458162_item	2928072	et	4	main
classmsonormalspan	doc_901133458162_item	2928073	et	4	main
langet1spanв	doc_901133458162_item	2928074	et	2	main
в	doc_901133458162_item	2928075	et	2	main
в	doc_901133458162_item	2928078	et	2	main
kodu	doc_901133458162_item	2928116	et	4	main
langetemnarva	doc_901133458162_item	2928126	et	4	main
on	doc_901133458162_item	2928127	et	4	main
linnas	doc_901133458162_item	2928131	et	4	main
loss	doc_901133458162_item	2928134	et	3	main
гјheksakorrassel	doc_901133458162_item	2928139	et	2	main
puud	doc_901133458162_item	2928150	et	4	main
jгјгјres	doc_901133458162_item	2928151	et	2	main
classmsonormalspan	doc_901133458162_item	2928169	et	4	main
в	doc_901133458162_item	2928171	et	2	main
в	doc_901133458162_item	2928173	et	2	main
teha	doc_901133458162_item	2928221	et	3	main
p	doc_901133458162_item	2928234	et	4	main
suvel	doc_901133458162_item	2928238	et	3	main
p	doc_901133458162_item	2928240	et	4	main
langetв	doc_901133458162_item	2928242	et	2	main
kooki	doc_901133458162_item	2928252	et	4	main
ja	doc_901133458162_item	2928253	et	3	main
ei	doc_901133458162_item	2928257	et	4	main
ole	doc_901133458162_item	2928258	et	4	main
hobisid	doc_901133458162_item	2928259	et	3	main
minu	doc_901133458162_item	2928260	et	3	main
teha	doc_901133458162_item	2928264	et	3	main
ma	doc_901133458162_item	2928268	et	3	main
minu	doc_901133458162_item	2928272	et	3	main
paevitamap	doc_901133458162_item	2928274	et	4	main
langetв	doc_901133458162_item	2928277	et	2	main
span	doc_901133458162_item	2928279	et	4	main
millega	doc_901133458161_item	2927988	et	3	main
sinu	doc_901133458161_item	2927990	et	3	main
в	doc_901133458161_item	2927992	et	2	main
on	doc_901133458161_item	2928020	et	4	main
hobisid	doc_901133458161_item	2928022	et	3	main
aega	doc_901133458161_item	2928035	et	4	main
lugeda	doc_901133458161_item	2928036	et	3	main
raamatud	doc_901133458161_item	2928037	et	4	main
kududa	doc_901133458161_item	2928038	et	3	main
ja	doc_901133458161_item	2928039	et	3	main
on	doc_901133458161_item	2928048	et	4	main
ja	doc_901133458161_item	2928051	et	3	main
suvel	doc_901133458161_item	2928055	et	3	main
meri	doc_901133458161_item	2928060	et	3	main
uus	doc_901133458162_item	2928062	et	3	main
vasta	doc_901133458162_item	2928064	et	4	main
в	doc_901133458162_item	2928077	et	2	main
missugune	doc_901133458162_item	2928113	et	3	main
koduгјmbrus	doc_901133458162_item	2928118	et	2	main
on	doc_901133458161_item	2928024	et	4	main
lemmiktegevus	doc_901133458161_item	2928026	et	4	main
mulle	doc_901133458161_item	2928032	et	4	main
meeldib	doc_901133458161_item	2928033	et	3	main
vaba	doc_901133458161_item	2928034	et	4	main
ma	doc_901133458161_item	2928053	et	3	main
classmsonormalspan	doc_901133458162_item	2928069	et	4	main
langetв	doc_901133458162_item	2928070	et	2	main
в	doc_901133458162_item	2928076	et	2	main
span	doc_901133458162_item	2928079	et	4	main
midagi	doc_901133458162_item	2928081	et	4	main
oma	doc_901133458162_item	2928082	et	4	main
kodulinnast	doc_901133458162_item	2928083	et	4	main
span	doc_901133458162_item	2928084	et	4	main
p	doc_901133458162_item	2928085	et	4	main
classmsonormalspan	doc_901133458162_item	2928086	et	4	main
langetspanв	doc_901133458162_item	2928087	et	2	main
в	doc_901133458162_item	2928088	et	2	main
в	doc_901133458162_item	2928090	et	2	main
в	doc_901133458162_item	2928089	et	2	main
в	doc_901133458162_item	2928091	et	2	main
в	doc_901133458162_item	2928092	et	2	main
в	doc_901133458162_item	2928093	et	2	main
в	doc_901133458162_item	2928094	et	2	main
span	doc_901133458162_item	2928095	et	4	main
mis	doc_901133458162_item	2928096	et	4	main
sinu	doc_901133458162_item	2928098	et	3	main
on	doc_901133458162_item	2928097	et	4	main
kodulinnas	doc_901133458162_item	2928099	et	4	main
huvitavat	doc_901133458162_item	2928100	et	4	main
span	doc_901133458162_item	2928101	et	4	main
p	doc_901133458162_item	2928102	et	4	main
classmsonormalspan	doc_901133458162_item	2928103	et	4	main
langetspanв	doc_901133458162_item	2928104	et	2	main
в	doc_901133458162_item	2928105	et	2	main
в	doc_901133458162_item	2928106	et	2	main
в	doc_901133458162_item	2928107	et	2	main
в	doc_901133458162_item	2928108	et	2	main
в	doc_901133458162_item	2928109	et	2	main
в	doc_901133458162_item	2928110	et	2	main
в	doc_901133458162_item	2928111	et	2	main
span	doc_901133458162_item	2928112	et	4	main
on	doc_901133458162_item	2928114	et	4	main
langetв	doc_901133458162_item	2928122	et	2	main
p	doc_901133458162_item	2928124	et	4	main
classmsobodytextspan	doc_901133458162_item	2928125	et	4	main
kindlus	doc_901133458162_item	2928133	et	4	main
pime	doc_901133458162_item	2928135	et	3	main
mul	doc_901133458162_item	2928141	et	3	main
palju	doc_901133458162_item	2928149	et	4	main
span	doc_901133458162_item	2928154	et	4	main
p	doc_901133458162_item	2928155	et	4	main
в	doc_901133458162_item	2928159	et	2	main
span	doc_901133458162_item	2928162	et	4	main
on	doc_901133458162_item	2928164	et	4	main
sinu	doc_901133458162_item	2928165	et	3	main
perekond	doc_901133458162_item	2928166	et	3	main
в	doc_901133458162_item	2928175	et	2	main
span	doc_901133458162_item	2928222	et	4	main
hobisid	doc_901133458162_item	2928229	et	3	main
lemmiktegevusp	doc_901133458162_item	2928233	et	4	main
sa	doc_901133458162_item	2928237	et	3	main
p	doc_901133458162_item	2928244	et	4	main
lemmiktegevus	doc_901133458162_item	2928261	et	4	main
гјksi	doc_901133458162_item	2928267	et	2	main
puhkan	doc_901133458162_item	2928269	et	3	main
narva-jгµessuse	doc_901133458162_item	2928271	et	2	main
meldib	doc_901133458162_item	2928273	et	4	main
classmsonormalspan	doc_901133458162_item	2928276	et	4	main
on	doc_901133458162_item	2928132	et	4	main
ma	doc_901133458162_item	2928137	et	3	main
on	doc_901133458162_item	2928148	et	4	main
langet2spanв	doc_901133458162_item	2928157	et	2	main
в	doc_901133458162_item	2928161	et	2	main
langetspanв	doc_901133458162_item	2928170	et	2	main
в	doc_901133458162_item	2928172	et	2	main
в	doc_901133458162_item	2928174	et	2	main
p	doc_901133458162_item	2928184	et	4	main
classmsonormalspan	doc_901133458162_item	2928185	et	4	main
langetв	doc_901133458162_item	2928186	et	2	main
p	doc_901133458162_item	2928187	et	4	main
p	doc_901133458162_item	2928188	et	4	main
classmsobodytextspan	doc_901133458162_item	2928189	et	4	main
langetemmul	doc_901133458162_item	2928190	et	4	main
on	doc_901133458162_item	2928191	et	4	main
vгike	doc_901133458162_item	2928192	et	2	main
perekond	doc_901133458162_item	2928193	et	3	main
ma	doc_901133458162_item	2928194	et	3	main
ja	doc_901133458162_item	2928195	et	3	main
kaks	doc_901133458162_item	2928196	et	3	main
poega	doc_901133458162_item	2928197	et	4	main
minu	doc_901133458162_item	2928198	et	3	main
poega	doc_901133458162_item	2928199	et	4	main
гµppinud	doc_901133458162_item	2928200	et	2	main
koolis	doc_901133458162_item	2928201	et	4	main
mine	doc_901133458162_item	2928202	et	3	main
lгhen	doc_901133458162_item	2928203	et	2	main
kursusel	doc_901133458162_item	2928204	et	3	main
em	doc_901133458162_item	2928205	et	4	main
в	doc_901133458162_item	2928206	et	2	main
span	doc_901133458162_item	2928207	et	4	main
p	doc_901133458162_item	2928208	et	4	main
classmsonormalspan	doc_901133458162_item	2928209	et	4	main
langet3spanв	doc_901133458162_item	2928210	et	2	main
в	doc_901133458162_item	2928211	et	2	main
в	doc_901133458162_item	2928212	et	2	main
в	doc_901133458162_item	2928213	et	2	main
в	doc_901133458162_item	2928214	et	2	main
span	doc_901133458162_item	2928215	et	4	main
mida	doc_901133458162_item	2928216	et	4	main
sulle	doc_901133458162_item	2928217	et	3	main
meeldib	doc_901133458162_item	2928218	et	3	main
vabal	doc_901133458162_item	2928219	et	3	main
ajal	doc_901133458162_item	2928220	et	4	main
classmsonormalspan	doc_901133458162_item	2928224	et	4	main
sul	doc_901133458162_item	2928226	et	3	main
mingeid	doc_901133458162_item	2928228	et	3	main
langetkus	doc_901133458162_item	2928236	et	4	main
p	doc_901133458162_item	2928243	et	4	main
classmsonormalispan	doc_901133458162_item	2928245	et	4	main
langetmulle	doc_901133458162_item	2928246	et	4	main
meeldib	doc_901133458162_item	2928247	et	3	main
teha	doc_901133458162_item	2928250	et	3	main
lugeda	doc_901133458162_item	2928254	et	3	main
mul	doc_901133458162_item	2928256	et	3	main
sгјгјa	doc_901133458162_item	2928263	et	2	main
ja	doc_901133458162_item	2928265	et	3	main
suvel	doc_901133458162_item	2928270	et	3	main
classmsonormalspan	doc_901133458162_item	2928235	et	4	main
puhkadp	doc_901133458162_item	2928239	et	4	main
classmsonormalspan	doc_901133458162_item	2928241	et	4	main
гµmmelda	doc_901133458162_item	2928248	et	2	main
kгјpsetada	doc_901133458162_item	2928251	et	2	main
raamatud	doc_901133458162_item	2928255	et	4	main
on	doc_901133458162_item	2928262	et	4	main
jalutada	doc_901133458162_item	2928266	et	3	main
p	doc_901133458162_item	2928275	et	4	main
p	doc_901133458162_item	2928278	et	4	main
uus	doc_901133458168_item	2929088	et	3	main
järgmistele	doc_901133458168_item	2929091	et	3	main
mis	doc_901133458168_item	2929098	et	4	main
küsimustele	doc_901133458168_item	2929092	et	4	main
on	doc_901133458168_item	2929099	et	4	main
sinu	doc_901133458168_item	2929100	et	3	main
kodulinnas	doc_901133458168_item	2929101	et	4	main
huvitavat	doc_901133458168_item	2929102	et	4	main
monumentit	doc_901133458168_item	2929121	et	4	main
bastioni	doc_901133458168_item	2929123	et	4	main
narvas	doc_901133458168_item	2929124	et	4	main
lillid	doc_901133458168_item	2929128	et	3	main
korruseline	doc_901133458168_item	2929136	et	4	main
minu	doc_901133458168_item	2929137	et	3	main
kõrval	doc_901133458168_item	2929141	et	4	main
pereliikmed	doc_901133458168_item	2929158	et	3	main
on	doc_901133458168_item	2929164	et	4	main
abikaasa	doc_901133458168_item	2929166	et	4	main
tütar	doc_901133458168_item	2929167	et	3	main
mull	doc_901133458168_item	2929168	et	3	main
on	doc_901133458168_item	2929169	et	4	main
kirjuta	doc_901133458168_item	2929094	et	4	main
on	doc_901133458168_item	2929104	et	4	main
kasvavad	doc_901133458168_item	2929125	et	4	main
ta	doc_901133458168_item	2929133	et	4	main
on	doc_901133458168_item	2929134	et	4	main
metsa	doc_901133458168_item	2929140	et	4	main
ees	doc_901133458168_item	2929143	et	4	main
on	doc_901133458168_item	2929144	et	4	main
taga	doc_901133458168_item	2929147	et	4	main
on	doc_901133458168_item	2929148	et	4	main
mets	doc_901133458168_item	2929149	et	3	main
2	doc_901133458168_item	2929150	et	2	main
milline	doc_901133458168_item	2929151	et	3	main
on	doc_901133458168_item	2929152	et	4	main
sinu	doc_901133458168_item	2929153	et	3	main
perekond	doc_901133458168_item	2929154	et	3	main
millega	doc_901133458168_item	2929155	et	3	main
abikaasa	doc_901133458168_item	2929170	et	4	main
tema	doc_901133458168_item	2929171	et	4	main
nimi	doc_901133458168_item	2929172	et	3	main
raudteel	doc_901133458168_item	2929178	et	3	main
tütar	doc_901133458168_item	2929182	et	3	main
paju	doc_901133458168_item	2929185	et	4	main
kaheksa	doc_901133458168_item	2929187	et	4	main
sul	doc_901133458168_item	2929200	et	3	main
on	doc_901133458168_item	2929201	et	4	main
sõidata	doc_901133458168_item	2929224	et	4	main
loodusse	doc_901133458168_item	2929225	et	4	main
minu	doc_901133458168_item	2929226	et	3	main
puhkan	doc_901133458168_item	2929233	et	3	main
kodulinnast	doc_901133458169_item	2929244	et	4	main
mis	doc_901133458169_item	2929245	et	4	main
dokument	doc_901133458168_item	2929089	et	3	main
kodulinnast	doc_901133458168_item	2929097	et	4	main
missugune	doc_901133458168_item	2929103	et	3	main
puud	doc_901133458168_item	2929127	et	4	main
minu	doc_901133458168_item	2929129	et	3	main
on	doc_901133458168_item	2929131	et	4	main
maja	doc_901133458168_item	2929146	et	4	main
tegelevad	doc_901133458168_item	2929156	et	4	main
mul	doc_901133458168_item	2929159	et	3	main
väike	doc_901133458168_item	2929161	et	4	main
eesti	doc_901133458168_item	2929177	et	4	main
tööta	doc_901133458168_item	2929191	et	4	main
3	doc_901133458168_item	2929192	et	2	main
hobisid	doc_901133458168_item	2929203	et	3	main
hobi	doc_901133458168_item	2929227	et	4	main
on	doc_901133458168_item	2929228	et	4	main
tikkida	doc_901133458168_item	2929229	et	4	main
fitnes	doc_901133458168_item	2929230	et	4	main
suvel	doc_901133458168_item	2929231	et	3	main
ma	doc_901133458168_item	2929232	et	3	main
oma	doc_901133458169_item	2929243	et	4	main
huvitavat	doc_901133458169_item	2929249	et	4	main
missugune	doc_901133458169_item	2929250	et	3	main
on	doc_901133458169_item	2929251	et	4	main
asub	doc_901133458169_item	2929258	et	3	main
narva	doc_901133458169_item	2929264	et	4	main
minu	doc_901133458169_item	2929272	et	3	main
roheline	doc_901133458169_item	2929281	et	4	main
ajaloomuuseum	doc_901133458169_item	2929282	et	3	main
tänaval	doc_901133458169_item	2929293	et	4	main
mul	doc_901133458169_item	2929309	et	3	main
on	doc_901133458169_item	2929310	et	4	main
vasta	doc_901133458168_item	2929090	et	4	main
1	doc_901133458168_item	2929093	et	2	main
midagi	doc_901133458168_item	2929095	et	4	main
oma	doc_901133458168_item	2929096	et	4	main
sinu	doc_901133458168_item	2929105	et	3	main
kodu	doc_901133458168_item	2929106	et	4	main
ja	doc_901133458168_item	2929107	et	3	main
koduümbrus	doc_901133458168_item	2929108	et	3	main
mulle	doc_901133458168_item	2929109	et	4	main
meeldib	doc_901133458168_item	2929110	et	3	main
minu	doc_901133458168_item	2929111	et	3	main
kodulinn	doc_901133458168_item	2929112	et	3	main
ta	doc_901133458168_item	2929113	et	4	main
on	doc_901133458168_item	2929114	et	4	main
ilus	doc_901133458168_item	2929115	et	4	main
narvas	doc_901133458168_item	2929116	et	4	main
on	doc_901133458168_item	2929117	et	4	main
ajaloomuuseum	doc_901133458168_item	2929118	et	3	main
kindluses	doc_901133458168_item	2929119	et	4	main
kunstigaleriis	doc_901133458168_item	2929120	et	3	main
üheksa	doc_901133458168_item	2929135	et	4	main
elumaja	doc_901133458168_item	2929145	et	4	main
ta	doc_901133458168_item	2929163	et	4	main
on	doc_901133458168_item	2929173	et	4	main
on	doc_901133458168_item	2929181	et	4	main
koolis	doc_901133458168_item	2929186	et	4	main
klassis	doc_901133458168_item	2929188	et	3	main
ma	doc_901133458168_item	2929189	et	3	main
ei	doc_901133458168_item	2929190	et	4	main
mingeid	doc_901133458168_item	2929202	et	3	main
päevitada	doc_901133458168_item	2929221	et	3	main
fitnes	doc_901133458168_item	2929223	et	4	main
venemaal	doc_901133458168_item	2929234	et	4	main
järgmistele	doc_901133458169_item	2929238	et	3	main
linn	doc_901133458169_item	2929271	et	3	main
narva	doc_901133458169_item	2929279	et	4	main
kindluses	doc_901133458169_item	2929284	et	4	main
2	doc_901133458169_item	2929287	et	2	main
kodu	doc_901133458169_item	2929289	et	4	main
aadress	doc_901133458169_item	2929290	et	3	main
on	doc_901133458169_item	2929291	et	4	main
elan	doc_901133458169_item	2929302	et	3	main
kolmetoalises	doc_901133458169_item	2929307	et	4	main
juures	doc_901133458169_item	2929321	et	4	main
on	doc_901133458169_item	2929324	et	4	main
millega	doc_901133458169_item	2929327	et	3	main
tegelevad	doc_901133458169_item	2929328	et	4	main
sinu	doc_901133458169_item	2929329	et	3	main
pereliikmed	doc_901133458169_item	2929330	et	3	main
minu	doc_901133458169_item	2929331	et	3	main
on	doc_901133458169_item	2929333	et	4	main
vaike	doc_901133458169_item	2929334	et	3	main
kaheksakümne	doc_901133458169_item	2929346	et	4	main
laps	doc_901133458169_item	2929365	et	4	main
glooria	doc_901133458168_item	2929122	et	4	main
palju	doc_901133458168_item	2929126	et	4	main
kodu	doc_901133458168_item	2929130	et	4	main
suur	doc_901133458168_item	2929132	et	3	main
maja	doc_901133458168_item	2929138	et	4	main
asub	doc_901133458168_item	2929139	et	3	main
maja	doc_901133458168_item	2929142	et	4	main
sinu	doc_901133458168_item	2929157	et	3	main
on	doc_901133458168_item	2929160	et	4	main
perekond	doc_901133458168_item	2929162	et	3	main
mina	doc_901133458168_item	2929165	et	4	main
xxxxx	doc_901133458168_item	2929174	et	4	main
vedurijuhina	doc_901133458168_item	2929179	et	3	main
xxxxxxxx	doc_901133458168_item	2929183	et	4	main
mida	doc_901133458168_item	2929193	et	4	main
sulle	doc_901133458168_item	2929194	et	3	main
mis	doc_901133458168_item	2929204	et	4	main
sinu	doc_901133458168_item	2929206	et	3	main
on	doc_901133458168_item	2929205	et	4	main
lemmiktegevus	doc_901133458168_item	2929207	et	4	main
kus	doc_901133458168_item	2929208	et	3	main
sa	doc_901133458168_item	2929209	et	3	main
suvel	doc_901133458168_item	2929210	et	3	main
puhkad	doc_901133458168_item	2929211	et	3	main
mulle	doc_901133458168_item	2929212	et	4	main
meeldib	doc_901133458168_item	2929213	et	3	main
tikkida	doc_901133458168_item	2929214	et	4	main
loeda	doc_901133458168_item	2929215	et	4	main
raamatut	doc_901133458168_item	2929216	et	3	main
süüa	doc_901133458168_item	2929217	et	3	main
teha	doc_901133458168_item	2929218	et	3	main
küpsetada	doc_901133458168_item	2929219	et	3	main
supelda	doc_901133458168_item	2929220	et	4	main
ta	doc_901133458168_item	2929175	et	4	main
töötad	doc_901133458168_item	2929176	et	3	main
mul	doc_901133458168_item	2929180	et	3	main
õpib	doc_901133458168_item	2929184	et	3	main
meeldib	doc_901133458168_item	2929195	et	3	main
vabal	doc_901133458168_item	2929196	et	3	main
ajal	doc_901133458168_item	2929197	et	4	main
teha	doc_901133458168_item	2929198	et	3	main
kas	doc_901133458168_item	2929199	et	3	main
uus	doc_901133458169_item	2929235	et	3	main
1	doc_901133458169_item	2929240	et	2	main
kirde-eestis	doc_901133458169_item	2929263	et	3	main
ääres	doc_901133458169_item	2929267	et	4	main
on	doc_901133458169_item	2929274	et	4	main
lossi	doc_901133458169_item	2929276	et	4	main
on	doc_901133458169_item	2929280	et	4	main
ja	doc_901133458169_item	2929285	et	3	main
kunstigalerii	doc_901133458169_item	2929286	et	4	main
minu	doc_901133458169_item	2929288	et	3	main
viisteist	doc_901133458169_item	2929296	et	4	main
ma	doc_901133458169_item	2929297	et	3	main
majas	doc_901133458169_item	2929300	et	3	main
neljandal	doc_901133458169_item	2929303	et	3	main
korrusel	doc_901133458169_item	2929308	et	3	main
kolm	doc_901133458169_item	2929311	et	3	main
tuba	doc_901133458169_item	2929312	et	4	main
minu	doc_901133458169_item	2929313	et	3	main
majas	doc_901133458169_item	2929314	et	3	main
sinu	doc_901133458169_item	2929325	et	3	main
perekond	doc_901133458169_item	2929332	et	3	main
üheksasaja	doc_901133458169_item	2929345	et	4	main
minu	doc_901133458169_item	2929349	et	3	main
on	doc_901133458169_item	2929352	et	4	main
üks	doc_901133458169_item	2929364	et	3	main
üks	doc_901133458169_item	2929368	et	3	main
üheteistkümnes	doc_901133458169_item	2929377	et	4	main
klassis	doc_901133458169_item	2929378	et	3	main
tütar	doc_901133458169_item	2929380	et	3	main
kolmeteistkumnendal	doc_901133458169_item	2929382	et	4	main
üheksasaja	doc_901133458169_item	2929385	et	4	main
ma	doc_901133458169_item	2929389	et	3	main
natuki	doc_901133458169_item	2929406	et	4	main
mul	doc_901133458169_item	2929408	et	3	main
on	doc_901133458169_item	2929409	et	4	main
xxxxx	doc_901133458169_item	2929415	et	4	main
sulle	doc_901133458169_item	2929418	et	3	main
ajal	doc_901133458169_item	2929421	et	4	main
sul	doc_901133458169_item	2929424	et	3	main
mingeid	doc_901133458169_item	2929426	et	3	main
hobisid	doc_901133458169_item	2929427	et	3	main
suvel	doc_901133458169_item	2929434	et	3	main
mulle	doc_901133458169_item	2929436	et	4	main
pereda	doc_901133458169_item	2929439	et	4	main
õppida	doc_901133458169_item	2929440	et	3	main
eesti	doc_901133458169_item	2929441	et	4	main
telerit	doc_901133458169_item	2929446	et	3	main
ei	doc_901133458169_item	2929456	et	4	main
hobi	doc_901133458169_item	2929458	et	4	main
uus	doc_901133458170_item	2929459	et	3	main
dokument	doc_901133458170_item	2929460	et	3	main
järgmistele	doc_901133458170_item	2929462	et	3	main
küsimustele	doc_901133458170_item	2929463	et	4	main
oma	doc_901133458170_item	2929469	et	4	main
sinu	doc_901133458170_item	2929474	et	3	main
span	doc_901133458170_item	2929477	et	4	main
span	doc_901133458170_item	2929484	et	4	main
minu	doc_901133458170_item	2929488	et	3	main
metsa	doc_901133458170_item	2929530	et	4	main
valge	doc_901133458170_item	2929550	et	4	main
puhas	doc_901133458170_item	2929551	et	3	main
päikeseline	doc_901133458170_item	2929552	et	3	main
perekond	doc_901133458170_item	2929559	et	3	main
millega	doc_901133458170_item	2929561	et	3	main
sinu	doc_901133458170_item	2929563	et	3	main
mul	doc_901133458170_item	2929571	et	3	main
on	doc_901133458170_item	2929572	et	4	main
ema	doc_901133458170_item	2929573	et	4	main
ema	doc_901133458170_item	2929577	et	4	main
span	doc_901133458170_item	2929615	et	4	main
on	doc_901133458170_item	2929622	et	4	main
mulle	doc_901133458170_item	2929632	et	4	main
meeldib	doc_901133458170_item	2929633	et	3	main
käia	doc_901133458168_item	2929222	et	4	main
dokument	doc_901133458169_item	2929236	et	3	main
vasta	doc_901133458169_item	2929237	et	4	main
küsimustele	doc_901133458169_item	2929239	et	4	main
kirjuta	doc_901133458169_item	2929241	et	4	main
midagi	doc_901133458169_item	2929242	et	4	main
on	doc_901133458169_item	2929246	et	4	main
sinu	doc_901133458169_item	2929247	et	3	main
kodulinnas	doc_901133458169_item	2929248	et	4	main
kodu	doc_901133458169_item	2929253	et	4	main
ja	doc_901133458169_item	2929254	et	3	main
koduümbrus	doc_901133458169_item	2929255	et	3	main
1	doc_901133458169_item	2929256	et	2	main
narva	doc_901133458169_item	2929257	et	4	main
sinu	doc_901133458169_item	2929252	et	3	main
ida-viru	doc_901133458169_item	2929259	et	4	main
maakonnas	doc_901133458169_item	2929260	et	4	main
asub	doc_901133458169_item	2929265	et	3	main
jõe	doc_901133458169_item	2929266	et	3	main
see	doc_901133458169_item	2929268	et	3	main
ilus	doc_901133458169_item	2929270	et	4	main
on	doc_901133458169_item	2929283	et	4	main
üheksateist	doc_901133458169_item	2929294	et	4	main
korter	doc_901133458169_item	2929295	et	3	main
üheksakorruselises	doc_901133458169_item	2929299	et	4	main
ma	doc_901133458169_item	2929305	et	3	main
juures	doc_901133458169_item	2929315	et	4	main
asub	doc_901133458169_item	2929316	et	3	main
lasteaeg	doc_901133458169_item	2929317	et	3	main
pood	doc_901133458169_item	2929318	et	4	main
asub	doc_901133458169_item	2929319	et	3	main
2	doc_901133458169_item	2929322	et	2	main
ma	doc_901133458169_item	2929338	et	3	main
abielus	doc_901133458169_item	2929340	et	4	main
ma	doc_901133458169_item	2929341	et	3	main
abiellusin	doc_901133458169_item	2929342	et	3	main
narvas	doc_901133458169_item	2929343	et	4	main
tuhande	doc_901133458169_item	2929344	et	3	main
astal	doc_901133458169_item	2929348	et	4	main
mul	doc_901133458169_item	2929366	et	3	main
tütar	doc_901133458169_item	2929369	et	3	main
ta	doc_901133458169_item	2929370	et	4	main
kuuendas	doc_901133458169_item	2929375	et	3	main
sündis	doc_901133458169_item	2929381	et	3	main
veebruaril	doc_901133458169_item	2929383	et	3	main
tuhande	doc_901133458169_item	2929384	et	3	main
kuuendal	doc_901133458169_item	2929387	et	3	main
töötasin	doc_901133458169_item	2929390	et	3	main
praegu	doc_901133458169_item	2929393	et	3	main
keelt	doc_901133458169_item	2929401	et	4	main
ma	doc_901133458169_item	2929402	et	3	main
saan	doc_901133458169_item	2929403	et	4	main
keelest	doc_901133458169_item	2929405	et	4	main
on	doc_901133458169_item	2929414	et	4	main
mida	doc_901133458169_item	2929417	et	4	main
meeldib	doc_901133458169_item	2929419	et	3	main
teha	doc_901133458169_item	2929422	et	3	main
kas	doc_901133458169_item	2929423	et	3	main
lemmiktegevus	doc_901133458169_item	2929431	et	4	main
puhkad	doc_901133458169_item	2929435	et	3	main
meeldib	doc_901133458169_item	2929437	et	3	main
raamatut	doc_901133458169_item	2929444	et	3	main
toolilli	doc_901133458169_item	2929448	et	4	main
jõe	doc_901133458169_item	2929453	et	3	main
vasta	doc_901133458170_item	2929461	et	4	main
midagi	doc_901133458170_item	2929468	et	4	main
on	doc_901133458170_item	2929473	et	4	main
huvitavat	doc_901133458170_item	2929476	et	4	main
kodu	doc_901133458170_item	2929481	et	4	main
meeldib	doc_901133458170_item	2929487	et	3	main
on	doc_901133458170_item	2929491	et	4	main
ta	doc_901133458170_item	2929523	et	4	main
on	doc_901133458170_item	2929524	et	4	main
viie	doc_901133458170_item	2929525	et	3	main
korruseline	doc_901133458170_item	2929526	et	4	main
minu	doc_901133458170_item	2929527	et	3	main
kõrval	doc_901133458170_item	2929531	et	4	main
ees	doc_901133458170_item	2929533	et	4	main
on	doc_901133458170_item	2929538	et	4	main
span	doc_901133458170_item	2929553	et	4	main
pereliikmed	doc_901133458170_item	2929564	et	3	main
span	doc_901133458170_item	2929566	et	4	main
mul	doc_901133458170_item	2929567	et	3	main
on	doc_901133458170_item	2929578	et	4	main
sulle	doc_901133458170_item	2929610	et	3	main
meeldib	doc_901133458170_item	2929611	et	3	main
vabal	doc_901133458170_item	2929612	et	3	main
mis	doc_901133458170_item	2929621	et	4	main
sinu	doc_901133458170_item	2929623	et	3	main
raamatut	doc_901133458170_item	2929639	et	3	main
lilli	doc_901133458170_item	2929641	et	4	main
päevitada	doc_901133458170_item	2929651	et	3	main
puhkan	doc_901133458170_item	2929655	et	3	main
järgmistele	doc_901133458171_item	2929664	et	3	main
1	doc_901133458171_item	2929666	et	2	main
kirjuta	doc_901133458171_item	2929667	et	4	main
narva	doc_901133458169_item	2929261	et	4	main
asub	doc_901133458169_item	2929262	et	3	main
on	doc_901133458169_item	2929269	et	4	main
kodulinnas	doc_901133458169_item	2929273	et	4	main
huvitavat	doc_901133458169_item	2929275	et	4	main
jõgi	doc_901133458169_item	2929277	et	3	main
park	doc_901133458169_item	2929278	et	3	main
roostee	doc_901133458169_item	2929292	et	4	main
elan	doc_901133458169_item	2929298	et	3	main
ma	doc_901133458169_item	2929301	et	3	main
korrusel	doc_901133458169_item	2929304	et	3	main
elan	doc_901133458169_item	2929306	et	3	main
maja	doc_901133458169_item	2929320	et	4	main
me	doc_901133458169_item	2929335	et	4	main
elame	doc_901133458169_item	2929336	et	3	main
kolmekesi	doc_901133458169_item	2929337	et	3	main
kolmandal	doc_901133458169_item	2929347	et	3	main
xxxx	doc_901133458169_item	2929373	et	4	main
astal	doc_901133458169_item	2929388	et	4	main
aru	doc_901133458169_item	2929407	et	4	main
on	doc_901133458169_item	2929425	et	4	main
mis	doc_901133458169_item	2929428	et	4	main
on	doc_901133458169_item	2929429	et	4	main
sinu	doc_901133458169_item	2929430	et	3	main
tegeleda	doc_901133458169_item	2929438	et	3	main
vaadata	doc_901133458169_item	2929445	et	4	main
kasvatada	doc_901133458169_item	2929447	et	3	main
korjata	doc_901133458169_item	2929449	et	4	main
saaki	doc_901133458169_item	2929450	et	4	main
ma	doc_901133458169_item	2929451	et	3	main
ääres	doc_901133458169_item	2929454	et	4	main
ole	doc_901133458169_item	2929457	et	4	main
span	doc_901133458170_item	2929471	et	4	main
kodulinnas	doc_901133458170_item	2929475	et	4	main
sinu	doc_901133458170_item	2929480	et	3	main
ja	doc_901133458170_item	2929482	et	3	main
mulle	doc_901133458170_item	2929486	et	4	main
kodulinn	doc_901133458170_item	2929489	et	3	main
see	doc_901133458170_item	2929490	et	3	main
narva	doc_901133458170_item	2929492	et	4	main
narva	doc_901133458170_item	2929493	et	4	main
asub	doc_901133458170_item	2929494	et	3	main
suur	doc_901133458170_item	2929521	et	3	main
maja	doc_901133458170_item	2929532	et	4	main
taga	doc_901133458170_item	2929537	et	4	main
on	doc_901133458170_item	2929541	et	4	main
korter	doc_901133458170_item	2929543	et	3	main
30	doc_901133458170_item	2929545	et	2	main
ruutmeetrit	doc_901133458170_item	2929546	et	3	main
ta	doc_901133458170_item	2929547	et	4	main
on	doc_901133458170_item	2929548	et	4	main
suur	doc_901133458170_item	2929549	et	3	main
sinu	doc_901133458170_item	2929558	et	3	main
õde	doc_901133458170_item	2929575	et	4	main
milline	doc_901133458169_item	2929323	et	3	main
perekond	doc_901133458169_item	2929326	et	3	main
olen	doc_901133458169_item	2929339	et	3	main
abikaasa	doc_901133458169_item	2929350	et	4	main
nimi	doc_901133458169_item	2929351	et	3	main
xxxxxxx	doc_901133458169_item	2929353	et	4	main
tal	doc_901133458169_item	2929354	et	3	main
on	doc_901133458169_item	2929355	et	4	main
keskeriharidus	doc_901133458169_item	2929356	et	3	main
ta	doc_901133458169_item	2929357	et	4	main
töötab	doc_901133458169_item	2929358	et	3	main
firmas	doc_901133458169_item	2929359	et	3	main
xxx	doc_901133458169_item	2929360	et	4	main
xxxxxxx	doc_901133458169_item	2929361	et	4	main
mul	doc_901133458169_item	2929362	et	3	main
on	doc_901133458169_item	2929363	et	4	main
on	doc_901133458169_item	2929367	et	4	main
õppib	doc_901133458169_item	2929374	et	4	main
kaheksakümne	doc_901133458169_item	2929386	et	4	main
kontrolörina	doc_901133458169_item	2929392	et	3	main
ole	doc_901133458169_item	2929396	et	4	main
eesti	doc_901133458169_item	2929404	et	4	main
on	doc_901133458169_item	2929371	et	4	main
xxxx	doc_901133458169_item	2929372	et	4	main
koolis	doc_901133458169_item	2929376	et	4	main
minu	doc_901133458169_item	2929379	et	3	main
xxxxxxxxxx	doc_901133458169_item	2929391	et	4	main
mul	doc_901133458169_item	2929394	et	3	main
ei	doc_901133458169_item	2929395	et	4	main
tööd	doc_901133458169_item	2929397	et	4	main
ma	doc_901133458169_item	2929398	et	3	main
õpin	doc_901133458169_item	2929399	et	3	main
eesti	doc_901133458169_item	2929400	et	4	main
kass	doc_901133458169_item	2929410	et	3	main
minu	doc_901133458169_item	2929411	et	3	main
kassi	doc_901133458169_item	2929412	et	4	main
nimi	doc_901133458169_item	2929413	et	3	main
3	doc_901133458169_item	2929416	et	2	main
vabal	doc_901133458169_item	2929420	et	3	main
keelt	doc_901133458169_item	2929442	et	4	main
lugeda	doc_901133458169_item	2929443	et	3	main
span	doc_901133458170_item	2929464	et	4	main
kodulinnast	doc_901133458170_item	2929470	et	4	main
missugune	doc_901133458170_item	2929478	et	3	main
koduümbrus	doc_901133458170_item	2929483	et	3	main
kus	doc_901133458169_item	2929432	et	3	main
sa	doc_901133458169_item	2929433	et	3	main
puhkan	doc_901133458169_item	2929452	et	3	main
mul	doc_901133458169_item	2929455	et	3	main
span	doc_901133458170_item	2929465	et	4	main
1	doc_901133458170_item	2929466	et	2	main
kirjuta	doc_901133458170_item	2929467	et	4	main
mis	doc_901133458170_item	2929472	et	4	main
on	doc_901133458170_item	2929479	et	4	main
span	doc_901133458170_item	2929485	et	4	main
jõe	doc_901133458170_item	2929495	et	3	main
ääres	doc_901133458170_item	2929496	et	4	main
narvas	doc_901133458170_item	2929497	et	4	main
on	doc_901133458170_item	2929498	et	4	main
lukk	doc_901133458170_item	2929499	et	3	main
narva	doc_901133458170_item	2929500	et	4	main
on	doc_901133458170_item	2929501	et	4	main
ilus	doc_901133458170_item	2929502	et	4	main
suur	doc_901133458170_item	2929503	et	3	main
roheline	doc_901133458170_item	2929504	et	4	main
narvas	doc_901133458170_item	2929505	et	4	main
on	doc_901133458170_item	2929506	et	4	main
ajaloomuuseum	doc_901133458170_item	2929507	et	3	main
kindluses	doc_901133458170_item	2929508	et	4	main
kunstigalerii	doc_901133458170_item	2929509	et	4	main
monumentit	doc_901133458170_item	2929510	et	4	main
glooria	doc_901133458170_item	2929511	et	4	main
bastioni	doc_901133458170_item	2929512	et	4	main
narvas	doc_901133458170_item	2929513	et	4	main
kasvavad	doc_901133458170_item	2929514	et	4	main
palju	doc_901133458170_item	2929515	et	4	main
lilled	doc_901133458170_item	2929516	et	3	main
puud	doc_901133458170_item	2929517	et	4	main
minu	doc_901133458170_item	2929518	et	3	main
kodu	doc_901133458170_item	2929519	et	4	main
on	doc_901133458170_item	2929520	et	4	main
maja	doc_901133458170_item	2929528	et	4	main
maja	doc_901133458170_item	2929536	et	4	main
mul	doc_901133458170_item	2929540	et	3	main
ühetoaline	doc_901133458170_item	2929542	et	4	main
milline	doc_901133458170_item	2929556	et	3	main
on	doc_901133458170_item	2929557	et	4	main
span	doc_901133458170_item	2929565	et	4	main
ei	doc_901133458170_item	2929568	et	4	main
isa	doc_901133458170_item	2929574	et	4	main
medõde	doc_901133458170_item	2929579	et	4	main
ta	doc_901133458170_item	2929580	et	4	main
kas	doc_901133458170_item	2929616	et	3	main
sul	doc_901133458170_item	2929617	et	3	main
on	doc_901133458170_item	2929618	et	4	main
mingeid	doc_901133458170_item	2929619	et	3	main
hobisid	doc_901133458170_item	2929620	et	3	main
span	doc_901133458170_item	2929630	et	4	main
tantsida	doc_901133458170_item	2929637	et	3	main
istuda	doc_901133458170_item	2929640	et	3	main
hobid	doc_901133458170_item	2929643	et	3	main
valge	doc_901133458170_item	2929522	et	4	main
asub	doc_901133458170_item	2929529	et	3	main
on	doc_901133458170_item	2929534	et	4	main
elumaja	doc_901133458170_item	2929535	et	4	main
poodi	doc_901133458170_item	2929539	et	4	main
kokku	doc_901133458170_item	2929544	et	3	main
span	doc_901133458170_item	2929554	et	4	main
2	doc_901133458170_item	2929555	et	2	main
span	doc_901133458170_item	2929560	et	4	main
tegelevad	doc_901133458170_item	2929562	et	4	main
ole	doc_901133458170_item	2929569	et	4	main
perekonna	doc_901133458170_item	2929570	et	4	main
minu	doc_901133458170_item	2929576	et	3	main
töötab	doc_901133458170_item	2929581	et	3	main
lasteaias	doc_901133458170_item	2929582	et	4	main
minu	doc_901133458170_item	2929583	et	3	main
isa	doc_901133458170_item	2929584	et	4	main
on	doc_901133458170_item	2929585	et	4	main
elektrik	doc_901133458170_item	2929586	et	3	main
ta	doc_901133458170_item	2929587	et	4	main
töötab	doc_901133458170_item	2929588	et	3	main
eesti	doc_901133458170_item	2929589	et	4	main
elektrijaamas	doc_901133458170_item	2929590	et	3	main
minu	doc_901133458170_item	2929591	et	3	main
õde	doc_901133458170_item	2929592	et	4	main
on	doc_901133458170_item	2929593	et	4	main
väike	doc_901133458170_item	2929594	et	4	main
ta	doc_901133458170_item	2929595	et	4	main
on	doc_901133458170_item	2929596	et	4	main
õpilane	doc_901133458170_item	2929597	et	3	main
praegu	doc_901133458170_item	2929598	et	3	main
ma	doc_901133458170_item	2929599	et	3	main
ei	doc_901133458170_item	2929600	et	4	main
tööta	doc_901133458170_item	2929601	et	4	main
ma	doc_901133458170_item	2929602	et	3	main
õpin	doc_901133458170_item	2929603	et	3	main
kea	doc_901133458170_item	2929604	et	4	main
koolis	doc_901133458170_item	2929605	et	4	main
hotellitenindajana	doc_901133458170_item	2929606	et	4	main
span	doc_901133458170_item	2929607	et	4	main
3	doc_901133458170_item	2929608	et	2	main
mida	doc_901133458170_item	2929609	et	4	main
ajal	doc_901133458170_item	2929613	et	4	main
teha	doc_901133458170_item	2929614	et	3	main
span	doc_901133458170_item	2929631	et	4	main
loeda	doc_901133458170_item	2929638	et	4	main
ma	doc_901133458170_item	2929654	et	3	main
span	doc_901133458170_item	2929659	et	4	main
span	doc_901133458170_item	2929660	et	4	main
uus	doc_901133458171_item	2929661	et	3	main
dokument	doc_901133458171_item	2929662	et	3	main
midagi	doc_901133458171_item	2929668	et	4	main
on	doc_901133458171_item	2929672	et	4	main
huvitavat	doc_901133458171_item	2929675	et	4	main
narova	doc_901133458171_item	2929690	et	4	main
jõe	doc_901133458171_item	2929691	et	3	main
ääres	doc_901133458171_item	2929692	et	4	main
on	doc_901133458171_item	2929698	et	4	main
raekoja	doc_901133458171_item	2929699	et	3	main
veel	doc_901133458171_item	2929705	et	4	main
monumentit	doc_901133458171_item	2929711	et	4	main
korruseline	doc_901133458171_item	2929718	et	4	main
tuba	doc_901133458171_item	2929724	et	4	main
on	doc_901133458171_item	2929726	et	4	main
kõrval	doc_901133458171_item	2929729	et	4	main
maja	doc_901133458171_item	2929738	et	4	main
vanalinnas	doc_901133458171_item	2929740	et	4	main
sinu	doc_901133458171_item	2929744	et	3	main
abikaasa	doc_901133458171_item	2929757	et	4	main
poeg	doc_901133458171_item	2929758	et	3	main
ja	doc_901133458171_item	2929759	et	3	main
minu	doc_901133458171_item	2929760	et	3	main
veel	doc_901133458171_item	2929771	et	4	main
käib	doc_901133458171_item	2929772	et	3	main
tööta	doc_901133458171_item	2929782	et	4	main
ma	doc_901133458171_item	2929783	et	3	main
on	doc_901133458171_item	2929787	et	4	main
ja	doc_901133458171_item	2929789	et	3	main
mulle	doc_901133458171_item	2929821	et	4	main
vähe	doc_901133458171_item	2929827	et	3	main
mul	doc_901133458171_item	2929830	et	3	main
ei	doc_901133458171_item	2929831	et	4	main
span	doc_901133458172_item	2929839	et	4	main
kodulinnas	doc_901133458172_item	2929850	et	4	main
väike	doc_901133458172_item	2929864	et	4	main
on	doc_901133458172_item	2929871	et	4	main
ääres	doc_901133458172_item	2929906	et	4	main
sinu	doc_901133458172_item	2929916	et	3	main
minu	doc_901133458172_item	2929920	et	3	main
on	doc_901133458172_item	2929922	et	4	main
väike	doc_901133458172_item	2929923	et	4	main
mina	doc_901133458172_item	2929924	et	4	main
tallinnas	doc_901133458172_item	2929934	et	4	main
minu	doc_901133458172_item	2929935	et	3	main
töötavad	doc_901133458172_item	2929939	et	4	main
suvelasse	doc_901133458172_item	2929948	et	4	main
seal	doc_901133458172_item	2929949	et	4	main
suhtlen	doc_901133458172_item	2929959	et	3	main
span	doc_901133458172_item	2929962	et	4	main
on	doc_901133458172_item	2929973	et	4	main
hobisid	doc_901133458172_item	2929975	et	3	main
lemmiktegevus	doc_901133458172_item	2929979	et	4	main
sa	doc_901133458172_item	2929982	et	3	main
span	doc_901133458172_item	2929985	et	4	main
span	doc_901133458172_item	2929986	et	4	main
lemmiktegevus	doc_901133458170_item	2929624	et	4	main
span	doc_901133458170_item	2929625	et	4	main
kus	doc_901133458170_item	2929626	et	3	main
sa	doc_901133458170_item	2929627	et	3	main
suvel	doc_901133458170_item	2929628	et	3	main
puhkad	doc_901133458170_item	2929629	et	3	main
saunasse	doc_901133458170_item	2929636	et	3	main
limmiktegevus	doc_901133458170_item	2929648	et	4	main
on	doc_901133458170_item	2929649	et	4	main
ujuda	doc_901133458170_item	2929650	et	3	main
joonistada	doc_901133458170_item	2929634	et	3	main
käia	doc_901133458170_item	2929635	et	4	main
minu	doc_901133458170_item	2929642	et	3	main
on	doc_901133458170_item	2929644	et	4	main
span	doc_901133458170_item	2929652	et	4	main
narvas	doc_901133458170_item	2929656	et	4	main
narva-jõesuus	doc_901133458170_item	2929658	et	3	main
oma	doc_901133458171_item	2929669	et	4	main
sinu	doc_901133458171_item	2929673	et	3	main
missugune	doc_901133458171_item	2929676	et	3	main
on	doc_901133458171_item	2929677	et	4	main
sinu	doc_901133458171_item	2929678	et	3	main
narva	doc_901133458171_item	2929686	et	4	main
asub	doc_901133458171_item	2929687	et	3	main
narva	doc_901133458171_item	2929693	et	4	main
plats	doc_901133458171_item	2929700	et	4	main
mulle	doc_901133458171_item	2929712	et	4	main
korter	doc_901133458171_item	2929722	et	3	main
muusika	doc_901133458171_item	2929731	et	4	main
hambakliinik	doc_901133458171_item	2929733	et	3	main
kunstigalerii	doc_901133458171_item	2929735	et	4	main
2	doc_901133458171_item	2929741	et	2	main
on	doc_901133458171_item	2929743	et	4	main
tegelevad	doc_901133458171_item	2929747	et	4	main
pereliikmed	doc_901133458171_item	2929749	et	3	main
on	doc_901133458171_item	2929751	et	4	main
perekond	doc_901133458171_item	2929753	et	3	main
on	doc_901133458171_item	2929755	et	4	main
nimi	doc_901133458171_item	2929763	et	3	main
lasteaegs	doc_901133458171_item	2929773	et	4	main
töötad	doc_901133458171_item	2929776	et	3	main
on	doc_901133458171_item	2929778	et	4	main
mida	doc_901133458171_item	2929793	et	4	main
mõnikord	doc_901133458171_item	2929823	et	3	main
vaba	doc_901133458171_item	2929828	et	4	main
aega	doc_901133458171_item	2929829	et	4	main
ole	doc_901133458171_item	2929832	et	4	main
span	doc_901133458172_item	2929840	et	4	main
1	doc_901133458172_item	2929841	et	2	main
kodulinnast	doc_901133458172_item	2929845	et	4	main
span	doc_901133458172_item	2929852	et	4	main
missugune	doc_901133458172_item	2929853	et	3	main
on	doc_901133458172_item	2929854	et	4	main
sinu	doc_901133458172_item	2929855	et	3	main
kodu	doc_901133458172_item	2929856	et	4	main
ja	doc_901133458172_item	2929857	et	3	main
koduümbrus	doc_901133458172_item	2929858	et	3	main
span	doc_901133458172_item	2929859	et	4	main
ja	doc_901133458172_item	2929865	et	3	main
siin	doc_901133458172_item	2929867	et	4	main
mul	doc_901133458172_item	2929899	et	3	main
on	doc_901133458172_item	2929910	et	4	main
sinu	doc_901133458172_item	2929911	et	3	main
perekond	doc_901133458172_item	2929912	et	3	main
millega	doc_901133458172_item	2929914	et	3	main
tegelevad	doc_901133458172_item	2929915	et	4	main
isa	doc_901133458172_item	2929938	et	4	main
ei	doc_901133458172_item	2929942	et	4	main
palju	doc_901133458172_item	2929951	et	4	main
ajal	doc_901133458172_item	2929968	et	4	main
teha	doc_901133458172_item	2929969	et	3	main
span	doc_901133458172_item	2929970	et	4	main
kas	doc_901133458172_item	2929971	et	3	main
sul	doc_901133458172_item	2929972	et	3	main
mulle	doc_901133458172_item	2929987	et	4	main
meeldib	doc_901133458172_item	2929988	et	3	main
lugeda	doc_901133458172_item	2929989	et	3	main
raamatut	doc_901133458172_item	2929990	et	3	main
ja	doc_901133458172_item	2929991	et	3	main
kosmetoloogia	doc_901133458170_item	2929645	et	4	main
span	doc_901133458170_item	2929646	et	4	main
minu	doc_901133458170_item	2929647	et	3	main
vasta	doc_901133458171_item	2929663	et	4	main
kodulinnast	doc_901133458171_item	2929670	et	4	main
mis	doc_901133458171_item	2929671	et	4	main
on	doc_901133458171_item	2929684	et	4	main
narva	doc_901133458171_item	2929685	et	4	main
narvas	doc_901133458171_item	2929697	et	4	main
palju	doc_901133458171_item	2929703	et	4	main
bastionid	doc_901133458171_item	2929704	et	3	main
kindluses	doc_901133458171_item	2929710	et	4	main
kolma	doc_901133458171_item	2929717	et	4	main
on	doc_901133458171_item	2929720	et	4	main
ta	doc_901133458171_item	2929725	et	4	main
on	doc_901133458171_item	2929730	et	4	main
kooli	doc_901133458171_item	2929732	et	4	main
lasteaeg	doc_901133458171_item	2929734	et	3	main
pimeaeg	doc_901133458171_item	2929736	et	3	main
milline	doc_901133458171_item	2929742	et	3	main
perekond	doc_901133458171_item	2929745	et	3	main
sinu	doc_901133458171_item	2929748	et	3	main
suur	doc_901133458171_item	2929752	et	3	main
on	doc_901133458171_item	2929764	et	4	main
ta	doc_901133458171_item	2929766	et	4	main
töötad	doc_901133458171_item	2929767	et	3	main
eesti	doc_901133458171_item	2929768	et	4	main
õppin	doc_901133458171_item	2929784	et	4	main
suvel	doc_901133458170_item	2929653	et	3	main
või	doc_901133458170_item	2929657	et	4	main
küsimustele	doc_901133458171_item	2929665	et	4	main
kodulinnas	doc_901133458171_item	2929674	et	4	main
kodu	doc_901133458171_item	2929679	et	4	main
ja	doc_901133458171_item	2929680	et	3	main
koduümbrus	doc_901133458171_item	2929681	et	3	main
minu	doc_901133458171_item	2929682	et	3	main
ida-viru	doc_901133458171_item	2929688	et	4	main
on	doc_901133458171_item	2929694	et	4	main
kindlus	doc_901133458171_item	2929701	et	4	main
on	doc_901133458171_item	2929706	et	4	main
kunstigalerii	doc_901133458171_item	2929707	et	4	main
ajaloomuuseum	doc_901133458171_item	2929708	et	3	main
meldib	doc_901133458171_item	2929713	et	4	main
mul	doc_901133458171_item	2929719	et	3	main
suur	doc_901133458171_item	2929721	et	3	main
kolm	doc_901133458171_item	2929723	et	3	main
maja	doc_901133458171_item	2929728	et	4	main
asub	doc_901133458171_item	2929739	et	3	main
mina	doc_901133458171_item	2929756	et	4	main
energijas	doc_901133458171_item	2929769	et	4	main
poeg	doc_901133458171_item	2929770	et	3	main
ema	doc_901133458171_item	2929775	et	4	main
ta	doc_901133458171_item	2929777	et	4	main
raamatupidajana	doc_901133458171_item	2929779	et	3	main
ma	doc_901133458171_item	2929780	et	3	main
ei	doc_901133458171_item	2929781	et	4	main
mul	doc_901133458171_item	2929786	et	3	main
sõbralik	doc_901133458171_item	2929788	et	3	main
hea	doc_901133458171_item	2929790	et	4	main
3	doc_901133458171_item	2929792	et	2	main
hobi	doc_901133458171_item	2929833	et	4	main
uus	doc_901133458172_item	2929834	et	3	main
dokument	doc_901133458172_item	2929835	et	3	main
kirjuta	doc_901133458172_item	2929842	et	4	main
huvitavat	doc_901133458172_item	2929851	et	4	main
span	doc_901133458172_item	2929860	et	4	main
minu	doc_901133458172_item	2929861	et	3	main
linn	doc_901133458172_item	2929862	et	3	main
meil	doc_901133458172_item	2929870	et	4	main
span	doc_901133458172_item	2929907	et	4	main
2	doc_901133458172_item	2929908	et	2	main
milline	doc_901133458172_item	2929909	et	3	main
pereliikmed	doc_901133458172_item	2929917	et	3	main
ema	doc_901133458172_item	2929925	et	4	main
isa	doc_901133458172_item	2929926	et	4	main
ja	doc_901133458172_item	2929927	et	3	main
me	doc_901133458172_item	2929946	et	4	main
elame	doc_901133458172_item	2929947	et	3	main
tööd	doc_901133458172_item	2929952	et	4	main
ma	doc_901133458172_item	2929954	et	3	main
õpin	doc_901133458172_item	2929955	et	3	main
eesti	doc_901133458172_item	2929956	et	4	main
sinu	doc_901133458172_item	2929978	et	3	main
kus	doc_901133458172_item	2929981	et	3	main
suvel	doc_901133458172_item	2929983	et	3	main
puhkad	doc_901133458172_item	2929984	et	3	main
mulle	doc_901133458172_item	2929995	et	4	main
kodulinnast	doc_901133458171_item	2929683	et	4	main
maakonnas	doc_901133458171_item	2929689	et	4	main
ilus	doc_901133458171_item	2929695	et	4	main
linn	doc_901133458171_item	2929696	et	3	main
hermani	doc_901133458171_item	2929702	et	4	main
on	doc_901133458171_item	2929709	et	4	main
narva	doc_901133458171_item	2929714	et	4	main
ma	doc_901133458171_item	2929715	et	3	main
elan	doc_901133458171_item	2929716	et	3	main
mugav	doc_901133458171_item	2929727	et	3	main
minu	doc_901133458171_item	2929737	et	3	main
millega	doc_901133458171_item	2929746	et	3	main
mul	doc_901133458171_item	2929750	et	3	main
ta	doc_901133458171_item	2929754	et	4	main
ema	doc_901133458171_item	2929761	et	4	main
abikasa	doc_901133458171_item	2929762	et	4	main
xxxxxxx	doc_901133458171_item	2929765	et	4	main
minu	doc_901133458171_item	2929774	et	3	main
kursusel	doc_901133458171_item	2929785	et	3	main
pere	doc_901133458171_item	2929791	et	4	main
sulle	doc_901133458171_item	2929794	et	3	main
meeldib	doc_901133458171_item	2929795	et	3	main
vabal	doc_901133458171_item	2929796	et	3	main
ajal	doc_901133458171_item	2929797	et	4	main
teha	doc_901133458171_item	2929798	et	3	main
kas	doc_901133458171_item	2929799	et	3	main
sul	doc_901133458171_item	2929800	et	3	main
on	doc_901133458171_item	2929801	et	4	main
mingeid	doc_901133458171_item	2929802	et	3	main
hobisid	doc_901133458171_item	2929803	et	3	main
mis	doc_901133458171_item	2929804	et	4	main
on	doc_901133458171_item	2929805	et	4	main
sinu	doc_901133458171_item	2929806	et	3	main
lemmiktegevus	doc_901133458171_item	2929807	et	4	main
kus	doc_901133458171_item	2929808	et	3	main
sa	doc_901133458171_item	2929809	et	3	main
suvel	doc_901133458171_item	2929810	et	3	main
puhkad	doc_901133458171_item	2929811	et	3	main
suvel	doc_901133458171_item	2929812	et	3	main
ma	doc_901133458171_item	2929813	et	3	main
puhkan	doc_901133458171_item	2929814	et	3	main
suuvilasse	doc_901133458171_item	2929815	et	4	main
perega	doc_901133458171_item	2929816	et	3	main
meile	doc_901133458171_item	2929817	et	4	main
meeldib	doc_901133458171_item	2929818	et	3	main
supelda	doc_901133458171_item	2929819	et	4	main
päevetada	doc_901133458171_item	2929820	et	4	main
meeldib	doc_901133458171_item	2929822	et	3	main
küpsetada	doc_901133458171_item	2929824	et	3	main
on	doc_901133458171_item	2929826	et	4	main
midagi	doc_901133458172_item	2929843	et	4	main
on	doc_901133458172_item	2929863	et	4	main
suur	doc_901133458172_item	2929872	et	3	main
ja	doc_901133458172_item	2929874	et	3	main
ma	doc_901133458172_item	2929903	et	3	main
span	doc_901133458172_item	2929919	et	4	main
pere	doc_901133458172_item	2929921	et	4	main
vend	doc_901133458172_item	2929928	et	3	main
me	doc_901133458172_item	2929929	et	4	main
elame	doc_901133458172_item	2929930	et	3	main
narvas	doc_901133458172_item	2929931	et	4	main
vend	doc_901133458172_item	2929932	et	3	main
elab	doc_901133458172_item	2929933	et	3	main
kohe	doc_901133458172_item	2929940	et	4	main
mul	doc_901133458172_item	2929941	et	3	main
ole	doc_901133458172_item	2929943	et	4	main
mul	doc_901133458171_item	2929825	et	3	main
vasta	doc_901133458172_item	2929836	et	4	main
järgmistele	doc_901133458172_item	2929837	et	3	main
küsimustele	doc_901133458172_item	2929838	et	4	main
oma	doc_901133458172_item	2929844	et	4	main
span	doc_901133458172_item	2929846	et	4	main
mis	doc_901133458172_item	2929847	et	4	main
on	doc_901133458172_item	2929848	et	4	main
sinu	doc_901133458172_item	2929849	et	3	main
ilus	doc_901133458172_item	2929866	et	4	main
palju	doc_901133458172_item	2929868	et	4	main
huvitavat	doc_901133458172_item	2929869	et	4	main
kindlus	doc_901133458172_item	2929873	et	4	main
ilus	doc_901133458172_item	2929875	et	4	main
park	doc_901133458172_item	2929876	et	3	main
narvas	doc_901133458172_item	2929877	et	4	main
on	doc_901133458172_item	2929878	et	4	main
monument	doc_901133458172_item	2929879	et	3	main
saksaliiv	doc_901133458172_item	2929880	et	3	main
vestervalli	doc_901133458172_item	2929881	et	4	main
tänaval	doc_901133458172_item	2929882	et	4	main
on	doc_901133458172_item	2929883	et	4	main
kunstigalerii	doc_901133458172_item	2929884	et	4	main
meil	doc_901133458172_item	2929885	et	4	main
on	doc_901133458172_item	2929886	et	4	main
ajaloomuuseum	doc_901133458172_item	2929887	et	3	main
ta	doc_901133458172_item	2929888	et	4	main
asub	doc_901133458172_item	2929889	et	3	main
kindluses	doc_901133458172_item	2929890	et	4	main
narva	doc_901133458172_item	2929891	et	4	main
asub	doc_901133458172_item	2929892	et	3	main
jõe	doc_901133458172_item	2929893	et	3	main
ääres	doc_901133458172_item	2929894	et	4	main
mul	doc_901133458172_item	2929895	et	3	main
on	doc_901133458172_item	2929896	et	4	main
suur	doc_901133458172_item	2929897	et	3	main
korter	doc_901133458172_item	2929898	et	3	main
on	doc_901133458172_item	2929900	et	4	main
kolm	doc_901133458172_item	2929901	et	3	main
tuba	doc_901133458172_item	2929902	et	4	main
elan	doc_901133458172_item	2929904	et	3	main
linnas	doc_901133458172_item	2929905	et	4	main
span	doc_901133458172_item	2929913	et	4	main
span	doc_901133458172_item	2929918	et	4	main
ema	doc_901133458172_item	2929936	et	4	main
ja	doc_901133458172_item	2929937	et	3	main
keelt	doc_901133458172_item	2929957	et	4	main
ja	doc_901133458172_item	2929958	et	3	main
keeles	doc_901133458172_item	2929961	et	4	main
3	doc_901133458172_item	2929963	et	2	main
mida	doc_901133458172_item	2929964	et	4	main
sulle	doc_901133458172_item	2929965	et	3	main
meeldib	doc_901133458172_item	2929966	et	3	main
vabal	doc_901133458172_item	2929967	et	3	main
on	doc_901133458172_item	2929977	et	4	main
span	doc_901133458172_item	2929980	et	4	main
meeldib	doc_901133458172_item	2929996	et	3	main
jalutada	doc_901133458172_item	2929997	et	3	main
suvel	doc_901133458172_item	2929998	et	3	main
ma	doc_901133458172_item	2929999	et	3	main
puhkan	doc_901133458172_item	2930000	et	3	main
juulis	doc_901133458172_item	2930001	et	3	main
ma	doc_901133458172_item	2930002	et	3	main
korjan	doc_901133458172_item	2930003	et	3	main
marju	doc_901133458172_item	2930004	et	3	main
suvelasse	doc_901133458172_item	2930005	et	4	main
ma	doc_901133458172_item	2930006	et	3	main
päevitan	doc_901133458172_item	2930007	et	3	main
suvelasse	doc_901133458172_item	2930009	et	4	main
kevadel	doc_901133458172_item	2930008	et	4	main
ma	doc_901133458172_item	2930010	et	3	main
istutan	doc_901133458172_item	2930011	et	3	main
lilli	doc_901133458172_item	2930012	et	4	main
span	doc_901133458172_item	2930013	et	4	main
tööd	doc_901133458172_item	2929944	et	4	main
suvel	doc_901133458172_item	2929945	et	3	main
alati	doc_901133458172_item	2929950	et	4	main
kohe	doc_901133458172_item	2929953	et	4	main
eesti	doc_901133458172_item	2929960	et	4	main
mingeid	doc_901133458172_item	2929974	et	3	main
mis	doc_901133458172_item	2929976	et	4	main
kuulata	doc_901133458172_item	2929992	et	4	main
muusikat	doc_901133458172_item	2929993	et	3	main
suvel	doc_901133458172_item	2929994	et	3	main
dokument	doc_901133458175_item	2930370	et	3	main
järgmistele	doc_901133458175_item	2930372	et	3	main
oma	doc_901133458175_item	2930379	et	4	main
mis	doc_901133458175_item	2930382	et	4	main
on	doc_901133458175_item	2930383	et	4	main
sinu	doc_901133458175_item	2930384	et	3	main
mina	doc_901133458175_item	2930396	et	4	main
narva	doc_901133458175_item	2930400	et	4	main
on	doc_901133458175_item	2930401	et	4	main
minu	doc_901133458175_item	2930402	et	3	main
ilus	doc_901133458175_item	2930423	et	4	main
uus	doc_901133458175_item	2930369	et	3	main
span	doc_901133458175_item	2930375	et	4	main
kirjuta	doc_901133458175_item	2930377	et	4	main
span	doc_901133458175_item	2930395	et	4	main
ma	doc_901133458175_item	2930436	et	3	main
elan	doc_901133458175_item	2930437	et	3	main
vanematega	doc_901133458175_item	2930438	et	4	main
elan	doc_901133458175_item	2930443	et	3	main
elan	doc_901133458175_item	2930447	et	3	main
elutoas	doc_901133458175_item	2930465	et	3	main
voodi	doc_901133458175_item	2930479	et	4	main
laud	doc_901133458175_item	2930480	et	4	main
heele	doc_901133458175_item	2930488	et	4	main
ja	doc_901133458175_item	2930490	et	3	main
on	doc_901133458175_item	2930492	et	4	main
kodu	doc_901133458175_item	2930500	et	4	main
ümbruses	doc_901133458175_item	2930501	et	3	main
ja	doc_901133458175_item	2930504	et	3	main
minu	doc_901133458175_item	2930506	et	3	main
2	doc_901133458175_item	2930512	et	2	main
milline	doc_901133458175_item	2930513	et	3	main
pereliikmed	doc_901133458175_item	2930521	et	3	main
perekonnas	doc_901133458175_item	2930529	et	4	main
oli	doc_901133458175_item	2930536	et	3	main
ei	doc_901133458175_item	2930563	et	4	main
mida	doc_901133458175_item	2930571	et	4	main
sulle	doc_901133458175_item	2930572	et	3	main
meeldib	doc_901133458175_item	2930573	et	3	main
vabal	doc_901133458175_item	2930574	et	3	main
on	doc_901133458175_item	2930584	et	4	main
sinu	doc_901133458175_item	2930585	et	3	main
ma	doc_901133458175_item	2930627	et	3	main
span	doc_901133458175_item	2930374	et	4	main
midagi	doc_901133458175_item	2930378	et	4	main
span	doc_901133458175_item	2930381	et	4	main
missugune	doc_901133458175_item	2930388	et	3	main
sündinud	doc_901133458175_item	2930398	et	4	main
span	doc_901133458175_item	2930435	et	4	main
ma	doc_901133458175_item	2930442	et	3	main
majas	doc_901133458175_item	2930445	et	3	main
on	doc_901133458175_item	2930463	et	4	main
remont	doc_901133458175_item	2930464	et	3	main
lamp	doc_901133458175_item	2930467	et	3	main
diivan	doc_901133458175_item	2930470	et	3	main
laud	doc_901133458175_item	2930474	et	4	main
magamistoas	doc_901133458175_item	2930475	et	3	main
on	doc_901133458175_item	2930476	et	4	main
arvuti	doc_901133458175_item	2930477	et	4	main
muusikakeskus	doc_901133458175_item	2930478	et	3	main
ja	doc_901133458175_item	2930487	et	3	main
vanituba	doc_901133458175_item	2930489	et	4	main
ja	doc_901133458175_item	2930498	et	3	main
pesimasin	doc_901133458175_item	2930499	et	4	main
mänguväljak	doc_901133458175_item	2930503	et	3	main
toidukauplus	doc_901133458175_item	2930505	et	3	main
sinu	doc_901133458175_item	2930520	et	3	main
ema	doc_901133458175_item	2930531	et	4	main
aga	doc_901133458175_item	2930538	et	3	main
head	doc_901133458175_item	2930547	et	4	main
huvitavad	doc_901133458175_item	2930548	et	4	main
inimesed	doc_901133458175_item	2930549	et	3	main
minu	doc_901133458175_item	2930550	et	3	main
jaoks	doc_901133458175_item	2930551	et	4	main
nad	doc_901133458175_item	2930552	et	3	main
vanemad	doc_901133458175_item	2930557	et	4	main
pensionäärid	doc_901133458175_item	2930559	et	4	main
töötab	doc_901133458175_item	2930567	et	3	main
span	doc_901133458175_item	2930568	et	4	main
span	doc_901133458175_item	2930577	et	4	main
vasta	doc_901133458175_item	2930371	et	4	main
1	doc_901133458175_item	2930376	et	2	main
kodulinnast	doc_901133458175_item	2930380	et	4	main
huvitavat	doc_901133458175_item	2930386	et	4	main
span	doc_901133458175_item	2930387	et	4	main
on	doc_901133458175_item	2930389	et	4	main
sinu	doc_901133458175_item	2930390	et	3	main
kodu	doc_901133458175_item	2930391	et	4	main
ja	doc_901133458175_item	2930392	et	3	main
koduümbrus	doc_901133458175_item	2930393	et	3	main
olen	doc_901133458175_item	2930397	et	3	main
narvas	doc_901133458175_item	2930399	et	4	main
kodulinn	doc_901133458175_item	2930403	et	3	main
mulle	doc_901133458175_item	2930404	et	4	main
meeldib	doc_901133458175_item	2930405	et	3	main
siin	doc_901133458175_item	2930406	et	4	main
elada	doc_901133458175_item	2930407	et	3	main
narva	doc_901133458175_item	2930408	et	4	main
on	doc_901133458175_item	2930409	et	4	main
väike	doc_901133458175_item	2930410	et	4	main
linn	doc_901133458175_item	2930411	et	3	main
aga	doc_901133458175_item	2930412	et	3	main
siin	doc_901133458175_item	2930413	et	4	main
väga	doc_901133458175_item	2930414	et	3	main
tore	doc_901133458175_item	2930415	et	3	main
minu	doc_901133458175_item	2930416	et	3	main
kodulinnas	doc_901133458175_item	2930417	et	4	main
kõik	doc_901133458175_item	2930418	et	4	main
huvitavat	doc_901133458175_item	2930419	et	4	main
narvas	doc_901133458175_item	2930420	et	4	main
küsimustele	doc_901133458175_item	2930373	et	4	main
kodulinnas	doc_901133458175_item	2930385	et	4	main
span	doc_901133458175_item	2930394	et	4	main
on	doc_901133458175_item	2930421	et	4	main
ja	doc_901133458175_item	2930426	et	3	main
nii	doc_901133458175_item	2930427	et	3	main
narva	doc_901133458175_item	2930431	et	4	main
seesama	doc_901133458175_item	2930432	et	3	main
tore	doc_901133458175_item	2930433	et	3	main
linn	doc_901133458175_item	2930434	et	3	main
telliskivimaja	doc_901133458175_item	2930441	et	4	main
viiekorruselises	doc_901133458175_item	2930444	et	4	main
korrusel	doc_901133458175_item	2930449	et	3	main
viiekümnendas	doc_901133458175_item	2930450	et	4	main
teler	doc_901133458175_item	2930468	et	3	main
ja	doc_901133458175_item	2930472	et	3	main
on	doc_901133458175_item	2930495	et	4	main
on	doc_901133458175_item	2930502	et	4	main
kodu	doc_901133458175_item	2930507	et	4	main
tegelevad	doc_901133458175_item	2930519	et	4	main
span	doc_901133458175_item	2930522	et	4	main
span	doc_901133458175_item	2930523	et	4	main
on	doc_901133458175_item	2930530	et	4	main
vend	doc_901133458175_item	2930537	et	3	main
on	doc_901133458175_item	2930540	et	4	main
surnud	doc_901133458175_item	2930541	et	4	main
ma	doc_901133458175_item	2930542	et	3	main
on	doc_901133458175_item	2930553	et	4	main
tööta	doc_901133458175_item	2930564	et	4	main
aga	doc_901133458175_item	2930565	et	3	main
ajal	doc_901133458175_item	2930575	et	4	main
teha	doc_901133458175_item	2930576	et	3	main
lemmiktegevus	doc_901133458175_item	2930586	et	4	main
mulle	doc_901133458175_item	2930616	et	4	main
meeldib	doc_901133458175_item	2930617	et	3	main
mängida	doc_901133458175_item	2930618	et	3	main
võrkpalli	doc_901133458175_item	2930619	et	4	main
korvpalli	doc_901133458175_item	2930621	et	4	main
minu	doc_901133458175_item	2930623	et	3	main
lemmiktegevus	doc_901133458175_item	2930624	et	4	main
mul	doc_901133458175_item	2930631	et	3	main
puhkan	doc_901133458175_item	2930637	et	3	main
seal	doc_901133458175_item	2930638	et	4	main
mõnikord	doc_901133458175_item	2930639	et	3	main
ma	doc_901133458175_item	2930640	et	3	main
sõidan	doc_901133458175_item	2930641	et	3	main
uus	doc_901133458177_item	2930786	et	3	main
siin	doc_901133458177_item	2930821	et	4	main
väga	doc_901133458177_item	2930823	et	3	main
asuvad	doc_901133458177_item	2930829	et	4	main
maja	doc_901133458177_item	2930843	et	4	main
ilus	doc_901133458177_item	2930850	et	4	main
kasvavad	doc_901133458177_item	2930852	et	4	main
millega	doc_901133458177_item	2930864	et	3	main
ole	doc_901133458177_item	2930873	et	4	main
narva	doc_901133458177_item	2930886	et	4	main
ta	doc_901133458177_item	2930888	et	4	main
on	doc_901133458177_item	2930889	et	4	main
autojuht	doc_901133458177_item	2930890	et	3	main
minu	doc_901133458177_item	2930891	et	3	main
kakskümmend	doc_901133458177_item	2930897	et	4	main
aastat	doc_901133458177_item	2930899	et	3	main
ole	doc_901133458177_item	2930907	et	4	main
sulle	doc_901133458177_item	2930922	et	3	main
span	doc_901133458177_item	2930943	et	4	main
narva-jõusel	doc_901133458177_item	2930956	et	4	main
rannas	doc_901133458177_item	2930963	et	3	main
koduümbrus	doc_901133458178_item	2930985	et	3	main
on	doc_901133458178_item	2930990	et	4	main
loss	doc_901133458175_item	2930422	et	3	main
pime	doc_901133458175_item	2930424	et	3	main
kolmandal	doc_901133458175_item	2930448	et	3	main
korteris	doc_901133458175_item	2930451	et	3	main
ma	doc_901133458175_item	2930452	et	3	main
kahetoalises	doc_901133458175_item	2930454	et	4	main
korteris	doc_901133458175_item	2930455	et	3	main
minu	doc_901133458175_item	2930456	et	3	main
köök	doc_901133458175_item	2930457	et	3	main
on	doc_901133458175_item	2930458	et	4	main
keskmine	doc_901133458175_item	2930459	et	3	main
köögis	doc_901133458175_item	2930460	et	3	main
elan	doc_901133458175_item	2930453	et	3	main
aed	doc_901133458175_item	2930425	et	3	main
edasi	doc_901133458175_item	2930428	et	3	main
minu	doc_901133458175_item	2930429	et	3	main
jaoks	doc_901133458175_item	2930430	et	4	main
meil	doc_901133458175_item	2930439	et	4	main
on	doc_901133458175_item	2930440	et	4	main
ma	doc_901133458175_item	2930446	et	3	main
vaip	doc_901133458175_item	2930469	et	3	main
väike	doc_901133458175_item	2930473	et	4	main
on	doc_901133458175_item	2930485	et	4	main
koos	doc_901133458175_item	2930493	et	4	main
dushikabiin	doc_901133458175_item	2930496	et	4	main
valamu	doc_901133458175_item	2930497	et	4	main
on	doc_901133458175_item	2930508	et	4	main
ilus	doc_901133458175_item	2930509	et	4	main
span	doc_901133458175_item	2930510	et	4	main
span	doc_901133458175_item	2930511	et	4	main
praegu	doc_901133458175_item	2930461	et	3	main
mul	doc_901133458175_item	2930462	et	3	main
on	doc_901133458175_item	2930466	et	4	main
kapp	doc_901133458175_item	2930471	et	3	main
ja	doc_901133458175_item	2930481	et	3	main
kapp	doc_901133458175_item	2930482	et	3	main
esik	doc_901133458175_item	2930483	et	3	main
mul	doc_901133458175_item	2930484	et	3	main
suur	doc_901133458175_item	2930486	et	3	main
wc	doc_901133458175_item	2930491	et	4	main
seal	doc_901133458175_item	2930494	et	4	main
on	doc_901133458175_item	2930514	et	4	main
sinu	doc_901133458175_item	2930515	et	3	main
perekond	doc_901133458175_item	2930516	et	3	main
span	doc_901133458175_item	2930517	et	4	main
millega	doc_901133458175_item	2930518	et	3	main
minu	doc_901133458175_item	2930524	et	3	main
on	doc_901133458175_item	2930526	et	4	main
isa	doc_901133458175_item	2930532	et	4	main
ja	doc_901133458175_item	2930533	et	3	main
minu	doc_901133458175_item	2930556	et	3	main
isa	doc_901133458175_item	2930566	et	4	main
perekond	doc_901133458175_item	2930525	et	3	main
väike	doc_901133458175_item	2930527	et	4	main
minu	doc_901133458175_item	2930528	et	3	main
mina	doc_901133458175_item	2930534	et	4	main
mul	doc_901133458175_item	2930535	et	3	main
ta	doc_901133458175_item	2930539	et	4	main
mõtlen	doc_901133458175_item	2930543	et	3	main
et	doc_901133458175_item	2930544	et	3	main
minu	doc_901133458175_item	2930545	et	3	main
vanemad	doc_901133458175_item	2930546	et	4	main
head	doc_901133458175_item	2930554	et	4	main
sõbrad	doc_901133458175_item	2930555	et	3	main
on	doc_901133458175_item	2930558	et	4	main
praegu	doc_901133458175_item	2930560	et	3	main
minu	doc_901133458175_item	2930561	et	3	main
ema	doc_901133458175_item	2930562	et	4	main
span	doc_901133458175_item	2930569	et	4	main
3	doc_901133458175_item	2930570	et	2	main
mis	doc_901133458175_item	2930583	et	4	main
span	doc_901133458175_item	2930587	et	4	main
kus	doc_901133458175_item	2930588	et	3	main
sa	doc_901133458175_item	2930589	et	3	main
suvel	doc_901133458175_item	2930590	et	3	main
puhkad	doc_901133458175_item	2930591	et	3	main
span	doc_901133458175_item	2930592	et	4	main
span	doc_901133458175_item	2930593	et	4	main
vabal	doc_901133458175_item	2930594	et	3	main
ajal	doc_901133458175_item	2930595	et	4	main
ma	doc_901133458175_item	2930596	et	3	main
vaatan	doc_901133458175_item	2930597	et	3	main
telerit	doc_901133458175_item	2930598	et	3	main
kuulan	doc_901133458175_item	2930599	et	3	main
raadiot	doc_901133458175_item	2930600	et	3	main
mulle	doc_901133458175_item	2930602	et	4	main
tavaliselt	doc_901133458175_item	2930601	et	4	main
meeldib	doc_901133458175_item	2930603	et	3	main
jalutada	doc_901133458175_item	2930604	et	3	main
loeda	doc_901133458175_item	2930605	et	4	main
raamatuid	doc_901133458175_item	2930606	et	3	main
mina	doc_901133458175_item	2930607	et	4	main
olen	doc_901133458175_item	2930608	et	3	main
optimistlik	doc_901133458175_item	2930609	et	3	main
inimene	doc_901133458175_item	2930610	et	3	main
span	doc_901133458175_item	2930611	et	4	main
minu	doc_901133458175_item	2930612	et	3	main
hobbi	doc_901133458175_item	2930613	et	4	main
on	doc_901133458175_item	2930614	et	4	main
sport	doc_901133458175_item	2930615	et	3	main
ja	doc_901133458175_item	2930620	et	3	main
kas	doc_901133458175_item	2930578	et	3	main
sul	doc_901133458175_item	2930579	et	3	main
on	doc_901133458175_item	2930580	et	4	main
mingeid	doc_901133458175_item	2930581	et	3	main
hobisid	doc_901133458175_item	2930582	et	3	main
muusika	doc_901133458175_item	2930626	et	4	main
tavaliselt	doc_901133458175_item	2930635	et	4	main
ma	doc_901133458175_item	2930636	et	3	main
vasta	doc_901133458177_item	2930788	et	4	main
õe	doc_901133458177_item	2930827	et	4	main
kaldal	doc_901133458177_item	2930828	et	3	main
ja	doc_901133458177_item	2930831	et	3	main
ta	doc_901133458177_item	2930838	et	4	main
minu	doc_901133458177_item	2930842	et	3	main
viis	doc_901133458177_item	2930845	et	4	main
koduümbrus	doc_901133458177_item	2930847	et	3	main
span	doc_901133458177_item	2930857	et	4	main
span	doc_901133458177_item	2930869	et	4	main
minu	doc_901133458177_item	2930870	et	3	main
perekond	doc_901133458177_item	2930871	et	3	main
abikaasa	doc_901133458177_item	2930884	et	4	main
töötab	doc_901133458177_item	2930885	et	3	main
ei	doc_901133458177_item	2930906	et	4	main
ajal	doc_901133458177_item	2930925	et	4	main
sul	doc_901133458177_item	2930929	et	3	main
mingeid	doc_901133458177_item	2930931	et	3	main
sinu	doc_901133458177_item	2930935	et	3	main
lemmiktegevus	doc_901133458177_item	2930936	et	4	main
sa	doc_901133458177_item	2930939	et	3	main
suvel	doc_901133458177_item	2930940	et	3	main
puhkad	doc_901133458177_item	2930941	et	3	main
span	doc_901133458177_item	2930942	et	4	main
töötab	doc_901133458177_item	2930948	et	3	main
supelda	doc_901133458177_item	2930959	et	4	main
meres	doc_901133458177_item	2930960	et	3	main
ja	doc_901133458177_item	2930961	et	3	main
span	doc_901133458177_item	2930964	et	4	main
ma	doc_901133458178_item	2930986	et	3	main
narvas	doc_901133458178_item	2930988	et	4	main
narvas	doc_901133458178_item	2930996	et	4	main
pime	doc_901133458178_item	2930998	et	3	main
aed	doc_901133458178_item	2930999	et	3	main
lifti	doc_901133458178_item	2931011	et	4	main
ma	doc_901133458178_item	2931012	et	3	main
elan	doc_901133458178_item	2931013	et	3	main
loodusse	doc_901133458175_item	2930642	et	4	main
telgidega	doc_901133458175_item	2930643	et	3	main
sõbradega	doc_901133458175_item	2930644	et	4	main
span	doc_901133458175_item	2930622	et	4	main
on	doc_901133458175_item	2930625	et	4	main
suvikodu	doc_901133458175_item	2930633	et	4	main
suvel	doc_901133458175_item	2930634	et	3	main
span	doc_901133458175_item	2930645	et	4	main
vene	doc_901133458177_item	2930830	et	4	main
eesti	doc_901133458177_item	2930832	et	4	main
span	doc_901133458177_item	2930834	et	4	main
kolmetoalinekorter	doc_901133458177_item	2930837	et	4	main
neljandal	doc_901133458177_item	2930840	et	3	main
korrusel	doc_901133458177_item	2930841	et	3	main
on	doc_901133458177_item	2930844	et	4	main
2	doc_901133458177_item	2930858	et	2	main
milline	doc_901133458177_item	2930859	et	3	main
on	doc_901133458177_item	2930860	et	4	main
sinu	doc_901133458177_item	2930861	et	3	main
perekond	doc_901133458177_item	2930862	et	3	main
ei	doc_901133458177_item	2930872	et	4	main
on	doc_901133458177_item	2930876	et	4	main
minu	doc_901133458177_item	2930878	et	3	main
poeg	doc_901133458177_item	2930880	et	3	main
ja	doc_901133458177_item	2930881	et	3	main
tüttar	doc_901133458177_item	2930882	et	4	main
minu	doc_901133458177_item	2930883	et	3	main
poeg	doc_901133458177_item	2930892	et	3	main
on	doc_901133458177_item	2930896	et	4	main
väga	doc_901133458177_item	2930908	et	3	main
suur	doc_901133458177_item	2930909	et	3	main
tal	doc_901133458177_item	2930910	et	3	main
mida	doc_901133458177_item	2930921	et	4	main
meeldib	doc_901133458177_item	2930923	et	3	main
on	doc_901133458177_item	2930934	et	4	main
aias	doc_901133458177_item	2930949	et	4	main
suvel	doc_901133458177_item	2930951	et	3	main
puhkame	doc_901133458177_item	2930955	et	3	main
meile	doc_901133458177_item	2930957	et	4	main
meeldib	doc_901133458177_item	2930958	et	3	main
uus	doc_901133458178_item	2930965	et	3	main
ja	doc_901133458178_item	2930984	et	3	main
meie	doc_901133458178_item	2931007	et	4	main
majas	doc_901133458178_item	2931008	et	3	main
korrusel	doc_901133458178_item	2931015	et	3	main
number	doc_901133458178_item	2931019	et	3	main
tualett	doc_901133458178_item	2931027	et	3	main
köögis	doc_901133458178_item	2931034	et	3	main
on	doc_901133458178_item	2931035	et	4	main
aken	doc_901133458178_item	2931037	et	3	main
külmik	doc_901133458178_item	2931039	et	3	main
elutoas	doc_901133458178_item	2931041	et	3	main
teler	doc_901133458178_item	2931043	et	3	main
diivan	doc_901133458178_item	2931044	et	3	main
tugitoolid	doc_901133458178_item	2931045	et	3	main
maja	doc_901133458178_item	2931051	et	4	main
tegelevad	doc_901133458178_item	2931064	et	4	main
nimi	doc_901133458178_item	2931077	et	3	main
vana	doc_901133458178_item	2931096	et	4	main
armastan	doc_901133458175_item	2930628	et	3	main
laulda	doc_901133458175_item	2930629	et	4	main
span	doc_901133458175_item	2930630	et	4	main
on	doc_901133458175_item	2930632	et	4	main
järgmistele	doc_901133458177_item	2930789	et	3	main
küsimustele	doc_901133458177_item	2930790	et	4	main
span	doc_901133458177_item	2930791	et	4	main
span	doc_901133458177_item	2930792	et	4	main
1	doc_901133458177_item	2930793	et	2	main
kirjuta	doc_901133458177_item	2930794	et	4	main
midagi	doc_901133458177_item	2930795	et	4	main
oma	doc_901133458177_item	2930796	et	4	main
kodulinnast	doc_901133458177_item	2930797	et	4	main
span	doc_901133458177_item	2930798	et	4	main
mis	doc_901133458177_item	2930799	et	4	main
on	doc_901133458177_item	2930800	et	4	main
sinu	doc_901133458177_item	2930801	et	3	main
kodulinnas	doc_901133458177_item	2930802	et	4	main
huvitavat	doc_901133458177_item	2930803	et	4	main
span	doc_901133458177_item	2930804	et	4	main
missugune	doc_901133458177_item	2930805	et	3	main
on	doc_901133458177_item	2930806	et	4	main
sinu	doc_901133458177_item	2930807	et	3	main
kodu	doc_901133458177_item	2930808	et	4	main
ja	doc_901133458177_item	2930809	et	3	main
koduümbrus	doc_901133458177_item	2930810	et	3	main
span	doc_901133458177_item	2930811	et	4	main
span	doc_901133458177_item	2930812	et	4	main
minu	doc_901133458177_item	2930813	et	3	main
kodulinn	doc_901133458177_item	2930814	et	3	main
on	doc_901133458177_item	2930815	et	4	main
narva	doc_901133458177_item	2930816	et	4	main
ta	doc_901133458177_item	2930817	et	4	main
asub	doc_901133458177_item	2930818	et	3	main
rajajoonis	doc_901133458177_item	2930819	et	4	main
venemaaga	doc_901133458177_item	2930820	et	3	main
dokument	doc_901133458177_item	2930787	et	3	main
on	doc_901133458177_item	2930822	et	4	main
tugevused	doc_901133458177_item	2930833	et	4	main
mul	doc_901133458177_item	2930835	et	3	main
on	doc_901133458177_item	2930836	et	4	main
on	doc_901133458177_item	2930848	et	4	main
vaga	doc_901133458177_item	2930849	et	4	main
span	doc_901133458177_item	2930863	et	4	main
suur	doc_901133458177_item	2930874	et	3	main
mina	doc_901133458177_item	2930877	et	4	main
karjääris	doc_901133458177_item	2930887	et	3	main
on	doc_901133458177_item	2930893	et	4	main
tal	doc_901133458177_item	2930895	et	3	main
neli	doc_901133458177_item	2930898	et	3	main
vana	doc_901133458177_item	2930900	et	4	main
ta	doc_901133458177_item	2930901	et	4	main
ka	doc_901133458177_item	2930902	et	3	main
töötab	doc_901133458177_item	2930903	et	3	main
minu	doc_901133458177_item	2930904	et	3	main
teha	doc_901133458177_item	2930926	et	3	main
kas	doc_901133458177_item	2930928	et	3	main
on	doc_901133458177_item	2930930	et	4	main
mis	doc_901133458177_item	2930933	et	4	main
span	doc_901133458177_item	2930937	et	4	main
kus	doc_901133458177_item	2930938	et	3	main
ajal	doc_901133458177_item	2930947	et	4	main
aga	doc_901133458177_item	2930950	et	3	main
päevitada	doc_901133458177_item	2930962	et	3	main
elan	doc_901133458178_item	2930987	et	3	main
see	doc_901133458178_item	2930989	et	3	main
väga	doc_901133458178_item	2930991	et	3	main
ei	doc_901133458178_item	2931009	et	4	main
elan	doc_901133458178_item	2931017	et	3	main
meie	doc_901133458178_item	2931021	et	4	main
on	doc_901133458178_item	2931023	et	4	main
kaks	doc_901133458178_item	2931024	et	3	main
tuba	doc_901133458178_item	2931025	et	4	main
esik	doc_901133458178_item	2931026	et	3	main
mul	doc_901133458178_item	2931030	et	3	main
meie	doc_901133458178_item	2931047	et	4	main
koduümbrus	doc_901133458178_item	2931048	et	3	main
on	doc_901133458178_item	2931049	et	4	main
lilled	doc_901133458178_item	2931057	et	3	main
on	doc_901133458178_item	2931060	et	4	main
sinu	doc_901133458178_item	2931061	et	3	main
perekond	doc_901133458178_item	2931062	et	3	main
millega	doc_901133458178_item	2931063	et	3	main
ja	doc_901133458178_item	2931074	et	3	main
laps	doc_901133458178_item	2931075	et	4	main
abikaasa	doc_901133458178_item	2931076	et	4	main
on	doc_901133458178_item	2931078	et	4	main
xxxxxx	doc_901133458178_item	2931079	et	4	main
24	doc_901133458178_item	2931082	et	2	main
xxxxxx	doc_901133458178_item	2931085	et	4	main
lapse	doc_901133458178_item	2931088	et	4	main
lasteaias	doc_901133458178_item	2931099	et	4	main
ma	doc_901133458178_item	2931100	et	3	main
olen	doc_901133458178_item	2931101	et	3	main
vana	doc_901133458178_item	2931104	et	4	main
varem	doc_901133458178_item	2931105	et	4	main
kursusel	doc_901133458178_item	2931113	et	3	main
meeldib	doc_901133458178_item	2931117	et	3	main
hobisid	doc_901133458178_item	2931125	et	3	main
vabal	doc_901133458178_item	2931136	et	3	main
hobi	doc_901133458178_item	2931148	et	4	main
kodus	doc_901133458178_item	2931155	et	4	main
kohas	doc_901133458178_item	2931166	et	4	main
ilus	doc_901133458177_item	2930824	et	4	main
õgi	doc_901133458177_item	2930825	et	4	main
ja	doc_901133458177_item	2930826	et	3	main
asub	doc_901133458177_item	2930839	et	3	main
korruse	doc_901133458177_item	2930846	et	3	main
seal	doc_901133458177_item	2930851	et	4	main
puud	doc_901133458177_item	2930853	et	4	main
ja	doc_901133458177_item	2930854	et	3	main
lilled	doc_901133458177_item	2930855	et	3	main
span	doc_901133458177_item	2930856	et	4	main
tegelevad	doc_901133458177_item	2930865	et	4	main
sinu	doc_901133458177_item	2930866	et	3	main
pereliikmed	doc_901133458177_item	2930867	et	3	main
span	doc_901133458177_item	2930868	et	4	main
see	doc_901133458177_item	2930875	et	3	main
abikaasa	doc_901133458177_item	2930879	et	4	main
suur	doc_901133458177_item	2930894	et	3	main
tüttar	doc_901133458177_item	2930905	et	4	main
on	doc_901133458177_item	2930911	et	4	main
seitseteist	doc_901133458177_item	2930912	et	4	main
aastat	doc_901133458177_item	2930913	et	3	main
vana	doc_901133458177_item	2930914	et	4	main
ta	doc_901133458177_item	2930915	et	4	main
õppib	doc_901133458177_item	2930916	et	4	main
koolis	doc_901133458177_item	2930917	et	4	main
span	doc_901133458177_item	2930918	et	4	main
span	doc_901133458177_item	2930919	et	4	main
3	doc_901133458177_item	2930920	et	2	main
vabal	doc_901133458177_item	2930924	et	3	main
span	doc_901133458177_item	2930927	et	4	main
hobisid	doc_901133458177_item	2930932	et	3	main
mule	doc_901133458177_item	2930944	et	4	main
meeldib	doc_901133458177_item	2930945	et	3	main
vabal	doc_901133458177_item	2930946	et	3	main
me	doc_901133458177_item	2930952	et	4	main
koos	doc_901133458177_item	2930953	et	4	main
perega	doc_901133458177_item	2930954	et	3	main
dokument	doc_901133458178_item	2930966	et	3	main
vasta	doc_901133458178_item	2930967	et	4	main
järgmistele	doc_901133458178_item	2930968	et	3	main
küsimustele	doc_901133458178_item	2930969	et	4	main
1	doc_901133458178_item	2930970	et	2	main
kirjuta	doc_901133458178_item	2930971	et	4	main
midagi	doc_901133458178_item	2930972	et	4	main
oma	doc_901133458178_item	2930973	et	4	main
kodulinnast	doc_901133458178_item	2930974	et	4	main
mis	doc_901133458178_item	2930975	et	4	main
on	doc_901133458178_item	2930976	et	4	main
sinu	doc_901133458178_item	2930977	et	3	main
kodulinnas	doc_901133458178_item	2930978	et	4	main
huvitavat	doc_901133458178_item	2930979	et	4	main
missugune	doc_901133458178_item	2930980	et	3	main
on	doc_901133458178_item	2930981	et	4	main
sinu	doc_901133458178_item	2930982	et	3	main
kodu	doc_901133458178_item	2930983	et	4	main
ilus	doc_901133458178_item	2930992	et	4	main
ja	doc_901133458178_item	2930993	et	3	main
on	doc_901133458178_item	2930997	et	4	main
ole	doc_901133458178_item	2931010	et	4	main
ma	doc_901133458178_item	2931016	et	3	main
70	doc_901133458178_item	2931020	et	2	main
korteris	doc_901133458178_item	2931022	et	3	main
köök	doc_901133458178_item	2931029	et	3	main
keskmine	doc_901133458178_item	2931032	et	3	main
uks	doc_901133458178_item	2931038	et	3	main
meie	doc_901133458178_item	2931040	et	4	main
on	doc_901133458178_item	2931042	et	4	main
diivanilaud	doc_901133458178_item	2931046	et	4	main
ees	doc_901133458178_item	2931052	et	4	main
asub	doc_901133458178_item	2931053	et	3	main
lasteaed	doc_901133458178_item	2931054	et	3	main
sinu	doc_901133458178_item	2931065	et	3	main
abikaasa	doc_901133458178_item	2931073	et	4	main
ta	doc_901133458178_item	2931080	et	4	main
vabrikus	doc_901133458178_item	2931087	et	3	main
ma	doc_901133458178_item	2931106	et	3	main
3	doc_901133458178_item	2931114	et	2	main
sulle	doc_901133458178_item	2931116	et	3	main
mingeid	doc_901133458178_item	2931124	et	3	main
lemmiktegevus	doc_901133458178_item	2931129	et	4	main
kus	doc_901133458178_item	2931130	et	3	main
sa	doc_901133458178_item	2931131	et	3	main
huvitav	doc_901133458178_item	2931147	et	4	main
me	doc_901133458178_item	2931175	et	4	main
ujume	doc_901133458178_item	2931176	et	3	main
vasta	doc_901133458179_item	2931180	et	4	main
1	doc_901133458179_item	2931183	et	2	main
kodulinnast	doc_901133458179_item	2931187	et	4	main
on	doc_901133458179_item	2931189	et	4	main
koduümbrus	doc_901133458179_item	2931198	et	3	main
teenindusmaja	doc_901133458179_item	2931221	et	4	main
elan	doc_901133458179_item	2931223	et	3	main
ei	doc_901133458179_item	2931228	et	4	main
elutuba	doc_901133458179_item	2931236	et	4	main
umbes	doc_901133458179_item	2931238	et	4	main
ruuttmeetrit	doc_901133458179_item	2931240	et	4	main
vanematega	doc_901133458179_item	2931254	et	4	main
mul	doc_901133458179_item	2931257	et	3	main
üürikorter	doc_901133458179_item	2931259	et	3	main
vanematel	doc_901133458179_item	2931260	et	4	main
suur	doc_901133458179_item	2931278	et	3	main
on	doc_901133458179_item	2931286	et	4	main
sinu	doc_901133458179_item	2931287	et	3	main
nimi	doc_901133458179_item	2931298	et	3	main
ta	doc_901133458179_item	2931302	et	4	main
töötab	doc_901133458179_item	2931308	et	3	main
mul	doc_901133458179_item	2931310	et	3	main
ema	doc_901133458179_item	2931312	et	4	main
koduperenaine	doc_901133458179_item	2931319	et	3	main
isa	doc_901133458179_item	2931320	et	4	main
roheline	doc_901133458178_item	2930994	et	4	main
linn	doc_901133458178_item	2930995	et	3	main
kindlus	doc_901133458178_item	2931000	et	4	main
ja	doc_901133458178_item	2931001	et	3	main
park	doc_901133458178_item	2931002	et	3	main
ma	doc_901133458178_item	2931003	et	3	main
elan	doc_901133458178_item	2931004	et	3	main
neljakorruselises	doc_901133458178_item	2931005	et	4	main
majas	doc_901133458178_item	2931006	et	3	main
neljandal	doc_901133458178_item	2931014	et	3	main
korteris	doc_901133458178_item	2931018	et	3	main
köök	doc_901133458178_item	2931033	et	3	main
üks	doc_901133458178_item	2931036	et	3	main
ilus	doc_901133458178_item	2931050	et	4	main
milline	doc_901133458178_item	2931059	et	3	main
meie	doc_901133458178_item	2931067	et	4	main
on	doc_901133458178_item	2931069	et	4	main
töötab	doc_901133458178_item	2931086	et	3	main
on	doc_901133458178_item	2931090	et	4	main
ta	doc_901133458178_item	2931092	et	4	main
on	doc_901133458178_item	2931093	et	4	main
19	doc_901133458178_item	2931094	et	2	main
aastat	doc_901133458178_item	2931095	et	3	main
baaris	doc_901133458178_item	2931108	et	3	main
mulle	doc_901133458178_item	2931134	et	4	main
töötada	doc_901133458178_item	2931140	et	3	main
ja	doc_901133458178_item	2931142	et	3	main
raamatud	doc_901133458178_item	2931144	et	4	main
mul	doc_901133458178_item	2931145	et	3	main
on	doc_901133458178_item	2931146	et	4	main
mul	doc_901133458178_item	2931154	et	3	main
palju	doc_901133458178_item	2931157	et	4	main
lilled	doc_901133458178_item	2931158	et	3	main
suvel	doc_901133458178_item	2931159	et	3	main
ma	doc_901133458178_item	2931160	et	3	main
puhkan	doc_901133458178_item	2931161	et	3	main
suvekodus	doc_901133458178_item	2931162	et	3	main
asub	doc_901133458178_item	2931164	et	3	main
uus	doc_901133458179_item	2931178	et	3	main
midagi	doc_901133458179_item	2931185	et	4	main
kodu	doc_901133458179_item	2931196	et	4	main
ja	doc_901133458179_item	2931197	et	3	main
vannituba	doc_901133458178_item	2931028	et	4	main
on	doc_901133458178_item	2931031	et	4	main
puud	doc_901133458178_item	2931055	et	4	main
ja	doc_901133458178_item	2931056	et	3	main
2	doc_901133458178_item	2931058	et	2	main
pereliikmed	doc_901133458178_item	2931066	et	3	main
perekonnas	doc_901133458178_item	2931068	et	4	main
kolm	doc_901133458178_item	2931070	et	3	main
inemest	doc_901133458178_item	2931071	et	4	main
mina	doc_901133458178_item	2931072	et	4	main
on	doc_901133458178_item	2931081	et	4	main
aastat	doc_901133458178_item	2931083	et	3	main
vana	doc_901133458178_item	2931084	et	4	main
nimi	doc_901133458178_item	2931089	et	3	main
xxxxxx	doc_901133458178_item	2931091	et	4	main
käib	doc_901133458178_item	2931098	et	3	main
22	doc_901133458178_item	2931102	et	2	main
aastat	doc_901133458178_item	2931103	et	3	main
aga	doc_901133458178_item	2931109	et	3	main
praegu	doc_901133458178_item	2931110	et	3	main
õpin	doc_901133458178_item	2931112	et	3	main
vabal	doc_901133458178_item	2931118	et	3	main
ajal	doc_901133458178_item	2931119	et	4	main
teha	doc_901133458178_item	2931120	et	3	main
kas	doc_901133458178_item	2931121	et	3	main
on	doc_901133458178_item	2931123	et	4	main
on	doc_901133458178_item	2931127	et	4	main
sinu	doc_901133458178_item	2931128	et	3	main
suvel	doc_901133458178_item	2931132	et	3	main
puhkad	doc_901133458178_item	2931133	et	3	main
ajal	doc_901133458178_item	2931137	et	4	main
lastega	doc_901133458178_item	2931139	et	3	main
arvutiga	doc_901133458178_item	2931141	et	4	main
lugeda	doc_901133458178_item	2931143	et	3	main
lilled	doc_901133458178_item	2931153	et	3	main
on	doc_901133458178_item	2931156	et	4	main
meres	doc_901133458178_item	2931177	et	3	main
oma	doc_901133458179_item	2931186	et	4	main
sinu	doc_901133458179_item	2931190	et	3	main
huvitavat	doc_901133458179_item	2931192	et	4	main
missugune	doc_901133458179_item	2931193	et	3	main
tahaksin	doc_901133458179_item	2931234	et	3	main
20	doc_901133458179_item	2931239	et	2	main
siin	doc_901133458179_item	2931241	et	4	main
diivan	doc_901133458179_item	2931243	et	3	main
ja	doc_901133458179_item	2931250	et	3	main
elan	doc_901133458179_item	2931253	et	3	main
sinu	doc_901133458179_item	2931291	et	3	main
pereliikmed	doc_901133458179_item	2931292	et	3	main
ma	doc_901133458179_item	2931293	et	3	main
olen	doc_901133458179_item	2931294	et	3	main
abielus	doc_901133458179_item	2931295	et	4	main
minu	doc_901133458179_item	2931296	et	3	main
on	doc_901133458179_item	2931299	et	4	main
praegu	doc_901133458179_item	2931301	et	3	main
elab	doc_901133458179_item	2931303	et	3	main
ja	doc_901133458179_item	2931304	et	3	main
töötab	doc_901133458179_item	2931305	et	3	main
on	doc_901133458179_item	2931318	et	4	main
minu	doc_901133458179_item	2931324	et	3	main
on	doc_901133458179_item	2931326	et	4	main
abielus	doc_901133458179_item	2931328	et	4	main
mida	doc_901133458179_item	2931339	et	4	main
ajal	doc_901133458179_item	2931343	et	4	main
on	doc_901133458179_item	2931347	et	4	main
ma	doc_901133458179_item	2931365	et	3	main
eriti	doc_901133458179_item	2931370	et	3	main
ajaloolise	doc_901133458179_item	2931373	et	4	main
romaane	doc_901133458179_item	2931375	et	3	main
telikat	doc_901133458179_item	2931392	et	4	main
kõige	doc_901133458179_item	2931393	et	4	main
mõnda	doc_901133458179_item	2931398	et	4	main
kuulan	doc_901133458179_item	2931402	et	3	main
raadio	doc_901133458179_item	2931410	et	4	main
mängib	doc_901133458179_item	2931411	et	3	main
minu	doc_901133458179_item	2931412	et	3	main
kodus	doc_901133458179_item	2931413	et	4	main
nii-öelda	doc_901133458179_item	2931414	et	3	main
ka	doc_901133458179_item	2931422	et	3	main
tihti	doc_901133458179_item	2931424	et	3	main
xxxxxx	doc_901133458178_item	2931097	et	4	main
töötasin	doc_901133458178_item	2931107	et	3	main
ma	doc_901133458178_item	2931111	et	3	main
mida	doc_901133458178_item	2931115	et	4	main
sul	doc_901133458178_item	2931122	et	3	main
mis	doc_901133458178_item	2931126	et	4	main
meeldib	doc_901133458178_item	2931135	et	3	main
mängida	doc_901133458178_item	2931138	et	3	main
mulle	doc_901133458178_item	2931149	et	4	main
väga	doc_901133458178_item	2931150	et	3	main
meeldib	doc_901133458178_item	2931151	et	3	main
istuda	doc_901133458178_item	2931152	et	3	main
suvekodu	doc_901133458178_item	2931163	et	4	main
ilusas	doc_901133458178_item	2931165	et	3	main
ma	doc_901133458178_item	2931168	et	3	main
puhkan	doc_901133458178_item	2931169	et	3	main
abikaasaga	doc_901133458178_item	2931170	et	3	main
ja	doc_901133458178_item	2931171	et	3	main
lastega	doc_901133458178_item	2931172	et	3	main
aga	doc_901133458178_item	2931173	et	3	main
veel	doc_901133458178_item	2931174	et	4	main
järgmistele	doc_901133458179_item	2931181	et	3	main
küsimustele	doc_901133458179_item	2931182	et	4	main
kirjuta	doc_901133458179_item	2931184	et	4	main
mis	doc_901133458179_item	2931188	et	4	main
kodulinnas	doc_901133458179_item	2931191	et	4	main
ma	doc_901133458179_item	2931199	et	3	main
elan	doc_901133458179_item	2931200	et	3	main
üheksakorruselises	doc_901133458179_item	2931201	et	4	main
telliskivimajas	doc_901133458179_item	2931202	et	4	main
ma	doc_901133458179_item	2931203	et	3	main
elan	doc_901133458179_item	2931204	et	3	main
kolmandal	doc_901133458179_item	2931205	et	3	main
korrusel	doc_901133458179_item	2931206	et	3	main
minu	doc_901133458179_item	2931207	et	3	main
maja	doc_901133458179_item	2931208	et	4	main
asub	doc_901133458179_item	2931209	et	3	main
siimani	doc_901133458179_item	2931210	et	4	main
tänaval	doc_901133458179_item	2931211	et	4	main
minu	doc_901133458179_item	2931212	et	3	main
maja	doc_901133458179_item	2931213	et	4	main
ees	doc_901133458179_item	2931214	et	4	main
on	doc_901133458179_item	2931215	et	4	main
kauplus	doc_901133458179_item	2931216	et	3	main
sampo	doc_901133458179_item	2931217	et	4	main
ja	doc_901133458179_item	2931218	et	3	main
lähedal	doc_901133458179_item	2931219	et	4	main
on	doc_901133458179_item	2931220	et	4	main
kolmetoalises	doc_901133458179_item	2931224	et	4	main
minu	doc_901133458179_item	2931226	et	3	main
korter	doc_901133458179_item	2931227	et	3	main
ole	doc_901133458179_item	2931229	et	4	main
nii	doc_901133458179_item	2931230	et	3	main
suur	doc_901133458179_item	2931231	et	3	main
kui	doc_901133458179_item	2931232	et	3	main
ma	doc_901133458179_item	2931233	et	3	main
on	doc_901133458179_item	2931237	et	4	main
tugitooli	doc_901133458179_item	2931245	et	4	main
sektsioonkapp	doc_901133458179_item	2931247	et	4	main
teler	doc_901133458179_item	2931248	et	3	main
muusikakeskus	doc_901133458179_item	2931251	et	3	main
ja	doc_901133458179_item	2931280	et	3	main
noorem	doc_901133458179_item	2931315	et	4	main
vend	doc_901133458179_item	2931316	et	3	main
seal	doc_901133458178_item	2931167	et	4	main
dokument	doc_901133458179_item	2931179	et	3	main
on	doc_901133458179_item	2931194	et	4	main
sinu	doc_901133458179_item	2931195	et	3	main
minu	doc_901133458179_item	2931235	et	3	main
on	doc_901133458179_item	2931242	et	4	main
aga	doc_901133458179_item	2931255	et	3	main
on	doc_901133458179_item	2931277	et	4	main
kivimaja	doc_901133458179_item	2931279	et	4	main
aed	doc_901133458179_item	2931282	et	3	main
milline	doc_901133458179_item	2931285	et	3	main
perekond	doc_901133458179_item	2931288	et	3	main
millega	doc_901133458179_item	2931289	et	3	main
tegelevad	doc_901133458179_item	2931290	et	4	main
tallinnas	doc_901133458179_item	2931306	et	4	main
ema	doc_901133458179_item	2931317	et	4	main
ehitusfirmas	doc_901133458179_item	2931322	et	3	main
arvuti	doc_901133458179_item	2931335	et	4	main
müüja	doc_901133458179_item	2931336	et	4	main
kas	doc_901133458179_item	2931345	et	3	main
lemmiktegevis	doc_901133458179_item	2931364	et	3	main
loen	doc_901133458179_item	2931367	et	3	main
lugeda	doc_901133458179_item	2931372	et	3	main
vaadata	doc_901133458179_item	2931390	et	4	main
ka	doc_901133458179_item	2931391	et	3	main
ma	doc_901133458179_item	2931401	et	3	main
päev	doc_901133458179_item	2931404	et	3	main
meeldib	doc_901133458179_item	2931406	et	3	main
ega	doc_901133458179_item	2931416	et	3	main
ma	doc_901133458179_item	2931420	et	3	main
abikaasa	doc_901133458179_item	2931428	et	4	main
üldiselt	doc_901133458179_item	2931454	et	4	main
mul	doc_901133458179_item	2931455	et	3	main
on	doc_901133458179_item	2931456	et	4	main
sinu	doc_901133458180_item	2931483	et	3	main
ilus	doc_901133458180_item	2931494	et	4	main
siin	doc_901133458180_item	2931496	et	4	main
narva	doc_901133458180_item	2931498	et	4	main
jõgi	doc_901133458180_item	2931499	et	3	main
herman	doc_901133458180_item	2931500	et	4	main
loss	doc_901133458180_item	2931501	et	3	main
ma	doc_901133458180_item	2931510	et	3	main
koolis	doc_901133458180_item	2931513	et	4	main
ma	doc_901133458180_item	2931520	et	3	main
majas	doc_901133458180_item	2931523	et	3	main
asub	doc_901133458180_item	2931526	et	3	main
ole	doc_901133458180_item	2931531	et	4	main
väga	doc_901133458180_item	2931532	et	3	main
ta	doc_901133458180_item	2931534	et	4	main
ole	doc_901133458180_item	2931540	et	4	main
akna	doc_901133458180_item	2931549	et	3	main
milline	doc_901133458180_item	2931556	et	3	main
millega	doc_901133458180_item	2931560	et	3	main
pereliikmed	doc_901133458180_item	2931563	et	3	main
laulavad	doc_901133458180_item	2931601	et	4	main
emal	doc_901133458180_item	2931602	et	3	main
sulle	doc_901133458180_item	2931612	et	3	main
ajal	doc_901133458180_item	2931615	et	4	main
mingeid	doc_901133458180_item	2931620	et	3	main
hobisid	doc_901133458180_item	2931621	et	3	main
on	doc_901133458180_item	2931623	et	4	main
lemmiktegevus	doc_901133458180_item	2931625	et	4	main
sa	doc_901133458180_item	2931627	et	3	main
meeldib	doc_901133458180_item	2931633	et	3	main
minu	doc_901133458180_item	2931638	et	3	main
hobid	doc_901133458180_item	2931639	et	3	main
iga	doc_901133458180_item	2931647	et	4	main
suvel	doc_901133458180_item	2931648	et	3	main
aasovi	doc_901133458180_item	2931651	et	4	main
sinu	doc_901133458181_item	2931668	et	3	main
kodulinnas	doc_901133458181_item	2931669	et	4	main
narvas	doc_901133458181_item	2931684	et	4	main
näiteks	doc_901133458181_item	2931689	et	4	main
loss	doc_901133458181_item	2931691	et	3	main
pime	doc_901133458181_item	2931693	et	3	main
span	doc_901133458181_item	2931695	et	4	main
elan	doc_901133458181_item	2931697	et	3	main
mul	doc_901133458181_item	2931702	et	3	main
on	doc_901133458181_item	2931718	et	4	main
nõud	doc_901133458181_item	2931719	et	3	main
gaasipliit	doc_901133458181_item	2931720	et	3	main
külmik	doc_901133458181_item	2931721	et	3	main
ma	doc_901133458179_item	2931222	et	3	main
korteris	doc_901133458179_item	2931225	et	3	main
2	doc_901133458179_item	2931244	et	2	main
raamaturiiulid	doc_901133458179_item	2931246	et	3	main
videomakk	doc_901133458179_item	2931249	et	3	main
ma	doc_901133458179_item	2931252	et	3	main
tallinnas	doc_901133458179_item	2931256	et	4	main
on	doc_901133458179_item	2931258	et	4	main
on	doc_901133458179_item	2931261	et	4	main
ka	doc_901133458179_item	2931262	et	3	main
suvila	doc_901133458179_item	2931263	et	4	main
ta	doc_901133458179_item	2931264	et	4	main
asub	doc_901133458179_item	2931265	et	3	main
mere	doc_901133458179_item	2931266	et	3	main
ääres	doc_901133458179_item	2931267	et	4	main
see	doc_901133458179_item	2931268	et	3	main
on	doc_901133458179_item	2931269	et	4	main
ilus	doc_901133458179_item	2931270	et	4	main
kaunis	doc_901133458179_item	2931271	et	4	main
vaikne	doc_901133458179_item	2931272	et	3	main
ja	doc_901133458179_item	2931273	et	3	main
hubane	doc_901133458179_item	2931274	et	3	main
koht	doc_901133458179_item	2931275	et	3	main
siin	doc_901133458179_item	2931276	et	4	main
ilus	doc_901133458179_item	2931281	et	4	main
puudega	doc_901133458179_item	2931283	et	4	main
2	doc_901133458179_item	2931284	et	2	main
abikaasa	doc_901133458179_item	2931297	et	4	main
xxxxxx	doc_901133458179_item	2931300	et	4	main
ta	doc_901133458179_item	2931307	et	4	main
ehitusfirmas	doc_901133458179_item	2931309	et	3	main
on	doc_901133458179_item	2931311	et	4	main
isa	doc_901133458179_item	2931313	et	4	main
ja	doc_901133458179_item	2931314	et	3	main
juba	doc_901133458179_item	2931327	et	3	main
tal	doc_901133458179_item	2931329	et	3	main
on	doc_901133458179_item	2931330	et	4	main
konsultaandina	doc_901133458179_item	2931337	et	4	main
3	doc_901133458179_item	2931338	et	2	main
sul	doc_901133458179_item	2931346	et	3	main
erinevaid	doc_901133458179_item	2931368	et	4	main
armastan	doc_901133458179_item	2931371	et	3	main
sisuga	doc_901133458179_item	2931374	et	3	main
mul	doc_901133458179_item	2931376	et	3	main
palju	doc_901133458179_item	2931379	et	4	main
ma	doc_901133458179_item	2931381	et	3	main
loen	doc_901133458179_item	2931382	et	3	main
ka	doc_901133458179_item	2931383	et	3	main
ajalehti	doc_901133458179_item	2931384	et	4	main
ja	doc_901133458179_item	2931385	et	3	main
rohkem	doc_901133458179_item	2931394	et	4	main
armastan	doc_901133458179_item	2931395	et	3	main
ma	doc_901133458179_item	2931396	et	3	main
vaadata	doc_901133458179_item	2931397	et	4	main
iga	doc_901133458179_item	2931403	et	4	main
rohkem	doc_901133458179_item	2931405	et	4	main
minu	doc_901133458179_item	2931418	et	3	main
vend	doc_901133458179_item	2931325	et	3	main
väike	doc_901133458179_item	2931331	et	4	main
tütar	doc_901133458179_item	2931332	et	3	main
meeldib	doc_901133458179_item	2931341	et	3	main
mingeid	doc_901133458179_item	2931348	et	3	main
hobisid	doc_901133458179_item	2931349	et	3	main
mis	doc_901133458179_item	2931350	et	4	main
on	doc_901133458179_item	2931351	et	4	main
sinu	doc_901133458179_item	2931352	et	3	main
töötab	doc_901133458179_item	2931321	et	3	main
töödejuhatajana	doc_901133458179_item	2931323	et	3	main
ta	doc_901133458179_item	2931333	et	4	main
töötab	doc_901133458179_item	2931334	et	3	main
sulle	doc_901133458179_item	2931340	et	3	main
vabal	doc_901133458179_item	2931342	et	3	main
teha	doc_901133458179_item	2931344	et	3	main
lemmiktegevus	doc_901133458179_item	2931353	et	4	main
kus	doc_901133458179_item	2931354	et	3	main
suvel	doc_901133458179_item	2931356	et	3	main
meelsasti	doc_901133458179_item	2931366	et	3	main
kodus	doc_901133458179_item	2931378	et	4	main
raamatuid	doc_901133458179_item	2931380	et	3	main
komöödiat	doc_901133458179_item	2931399	et	3	main
mulle	doc_901133458179_item	2931407	et	4	main
kerge	doc_901133458179_item	2931408	et	4	main
taustaks	doc_901133458179_item	2931415	et	3	main
toimetusi	doc_901133458179_item	2931419	et	4	main
armastan	doc_901133458179_item	2931421	et	3	main
minu	doc_901133458179_item	2931427	et	3	main
diskol	doc_901133458179_item	2931430	et	4	main
tantsuõhtul	doc_901133458179_item	2931431	et	3	main
suvel	doc_901133458179_item	2931432	et	3	main
mulle	doc_901133458179_item	2931433	et	4	main
eriti	doc_901133458179_item	2931434	et	3	main
suvelas	doc_901133458179_item	2931437	et	4	main
mere	doc_901133458179_item	2931438	et	3	main
või	doc_901133458179_item	2931445	et	4	main
vasta	doc_901133458180_item	2931468	et	4	main
on	doc_901133458180_item	2931492	et	4	main
aed	doc_901133458180_item	2931504	et	3	main
manufaktuur	doc_901133458180_item	2931506	et	3	main
õppinud	doc_901133458180_item	2931512	et	4	main
praegu	doc_901133458180_item	2931514	et	3	main
karu	doc_901133458180_item	2931518	et	4	main
elan	doc_901133458180_item	2931521	et	3	main
minu	doc_901133458180_item	2931524	et	3	main
viiendal	doc_901133458180_item	2931527	et	3	main
korter	doc_901133458180_item	2931529	et	3	main
kodu	doc_901133458180_item	2931537	et	4	main
palju	doc_901133458180_item	2931547	et	4	main
on	doc_901133458180_item	2931551	et	4	main
lasteaed	doc_901133458180_item	2931554	et	3	main
sinu	doc_901133458180_item	2931558	et	3	main
suur	doc_901133458180_item	2931568	et	3	main
on	doc_901133458180_item	2931603	et	4	main
vabal	doc_901133458180_item	2931614	et	3	main
sul	doc_901133458180_item	2931618	et	3	main
sa	doc_901133458179_item	2931355	et	3	main
puhkad	doc_901133458179_item	2931357	et	3	main
ma	doc_901133458179_item	2931358	et	3	main
armastan	doc_901133458179_item	2931359	et	3	main
lugeda	doc_901133458179_item	2931360	et	3	main
see	doc_901133458179_item	2931361	et	3	main
on	doc_901133458179_item	2931362	et	4	main
minu	doc_901133458179_item	2931363	et	3	main
raamatuid	doc_901133458179_item	2931369	et	3	main
on	doc_901133458179_item	2931377	et	4	main
ajakirju	doc_901133458179_item	2931386	et	4	main
õhtul	doc_901133458179_item	2931387	et	3	main
mulle	doc_901133458179_item	2931388	et	4	main
meeldib	doc_901133458179_item	2931389	et	3	main
muusikat	doc_901133458179_item	2931400	et	3	main
muusika	doc_901133458179_item	2931409	et	4	main
sega	doc_901133458179_item	2931417	et	4	main
tantsida	doc_901133458179_item	2931423	et	3	main
ja	doc_901133458179_item	2931426	et	3	main
supelda	doc_901133458179_item	2931444	et	4	main
õhku	doc_901133458179_item	2931453	et	4	main
koduümbrus	doc_901133458180_item	2931486	et	3	main
kodulinn	doc_901133458180_item	2931488	et	3	main
väga	doc_901133458180_item	2931493	et	3	main
on	doc_901133458180_item	2931497	et	4	main
krenholmi	doc_901133458180_item	2931505	et	4	main
olen	doc_901133458180_item	2931511	et	3	main
ma	doc_901133458180_item	2931515	et	3	main
elan	doc_901133458180_item	2931516	et	3	main
narvas	doc_901133458180_item	2931517	et	4	main
mina	doc_901133458179_item	2931425	et	4	main
käime	doc_901133458179_item	2931429	et	4	main
puhata	doc_901133458179_item	2931436	et	4	main
ääres	doc_901133458179_item	2931439	et	4	main
siin	doc_901133458179_item	2931440	et	4	main
ma	doc_901133458179_item	2931441	et	3	main
võin	doc_901133458179_item	2931442	et	3	main
päevitada	doc_901133458179_item	2931443	et	3	main
värsket	doc_901133458179_item	2931452	et	4	main
mind	doc_901133458179_item	2931461	et	4	main
huvitab	doc_901133458179_item	2931462	et	3	main
kõige	doc_901133458179_item	2931463	et	4	main
rohkem	doc_901133458179_item	2931464	et	4	main
kellega	doc_901133458179_item	2931465	et	3	main
uus	doc_901133458180_item	2931466	et	3	main
dokument	doc_901133458180_item	2931467	et	3	main
järgmistele	doc_901133458180_item	2931469	et	3	main
küsimustele	doc_901133458180_item	2931470	et	4	main
1	doc_901133458180_item	2931471	et	2	main
kirjuta	doc_901133458180_item	2931472	et	4	main
midagi	doc_901133458180_item	2931473	et	4	main
oma	doc_901133458180_item	2931474	et	4	main
kodulinnast	doc_901133458180_item	2931475	et	4	main
mis	doc_901133458180_item	2931476	et	4	main
on	doc_901133458180_item	2931477	et	4	main
sinu	doc_901133458180_item	2931478	et	3	main
kodulinnas	doc_901133458180_item	2931479	et	4	main
huvitavat	doc_901133458180_item	2931480	et	4	main
missugune	doc_901133458180_item	2931481	et	3	main
on	doc_901133458180_item	2931482	et	4	main
meeldib	doc_901133458179_item	2931435	et	3	main
lihtsalt	doc_901133458179_item	2931446	et	4	main
jalutada	doc_901133458179_item	2931447	et	3	main
mere	doc_901133458179_item	2931448	et	3	main
kaldal	doc_901133458179_item	2931449	et	3	main
ja	doc_901133458179_item	2931450	et	3	main
hingata	doc_901133458179_item	2931451	et	4	main
ükskõik	doc_901133458179_item	2931457	et	3	main
kus	doc_901133458179_item	2931458	et	3	main
ma	doc_901133458179_item	2931459	et	3	main
puhkan	doc_901133458179_item	2931460	et	3	main
narva	doc_901133458180_item	2931490	et	4	main
narva	doc_901133458180_item	2931491	et	4	main
raekoda	doc_901133458180_item	2931502	et	4	main
pime	doc_901133458180_item	2931503	et	3	main
üheksakorruselises	doc_901133458180_item	2931522	et	4	main
korter	doc_901133458180_item	2931525	et	3	main
korrusel	doc_901133458180_item	2931528	et	3	main
on	doc_901133458180_item	2931535	et	4	main
ümbruses	doc_901133458180_item	2931538	et	3	main
ilus	doc_901133458180_item	2931542	et	4	main
selle	doc_901133458180_item	2931543	et	4	main
on	doc_901133458180_item	2931546	et	4	main
mets	doc_901133458180_item	2931552	et	3	main
ja	doc_901133458180_item	2931553	et	3	main
minu	doc_901133458180_item	2931564	et	3	main
perekond	doc_901133458180_item	2931565	et	3	main
ema	doc_901133458180_item	2931570	et	4	main
elegaantne	doc_901133458180_item	2931604	et	4	main
naine	doc_901133458180_item	2931605	et	3	main
pühapäeval	doc_901133458180_item	2931606	et	3	main
nad	doc_901133458180_item	2931607	et	3	main
sõidavad	doc_901133458180_item	2931608	et	3	main
suuvilas	doc_901133458180_item	2931609	et	4	main
3	doc_901133458180_item	2931610	et	2	main
meeldib	doc_901133458180_item	2931613	et	3	main
mis	doc_901133458180_item	2931622	et	4	main
mulle	doc_901133458180_item	2931632	et	4	main
vaatada	doc_901133458180_item	2931635	et	4	main
joonistamine	doc_901133458180_item	2931641	et	4	main
saksakeel	doc_901133458180_item	2931642	et	4	main
minu	doc_901133458180_item	2931643	et	3	main
ma	doc_901133458180_item	2931649	et	3	main
meeres	doc_901133458180_item	2931652	et	3	main
huvitavat	doc_901133458181_item	2931670	et	4	main
narvast	doc_901133458181_item	2931683	et	4	main
aed	doc_901133458181_item	2931694	et	3	main
ma	doc_901133458181_item	2931696	et	3	main
ei	doc_901133458181_item	2931707	et	4	main
väga	doc_901133458181_item	2931709	et	3	main
suur	doc_901133458181_item	2931710	et	3	main
vannituba	doc_901133458181_item	2931711	et	4	main
ja	doc_901133458181_item	2931712	et	3	main
tualett	doc_901133458181_item	2931713	et	3	main
on	doc_901133458181_item	2931714	et	4	main
valamu	doc_901133458181_item	2931723	et	4	main
mugavused	doc_901133458181_item	2931732	et	4	main
on	doc_901133458181_item	2931745	et	4	main
span	doc_901133458181_item	2931755	et	4	main
span	doc_901133458181_item	2931761	et	4	main
millega	doc_901133458181_item	2931762	et	3	main
pereliikmed	doc_901133458181_item	2931765	et	3	main
põrandad	doc_901133458181_item	2931782	et	3	main
kastama	doc_901133458181_item	2931787	et	4	main
kauplustes	doc_901133458181_item	2931792	et	4	main
turul	doc_901133458181_item	2931794	et	3	main
viib	doc_901133458181_item	2931799	et	3	main
remonti	doc_901133458181_item	2931803	et	4	main
ta	doc_901133458181_item	2931812	et	4	main
prügiämbrit	doc_901133458181_item	2931816	et	3	main
span	doc_901133458181_item	2931819	et	4	main
mingeid	doc_901133458181_item	2931831	et	3	main
hobisid	doc_901133458181_item	2931832	et	3	main
on	doc_901133458181_item	2931834	et	4	main
sinu	doc_901133458181_item	2931835	et	3	main
lemmiktegevus	doc_901133458181_item	2931836	et	4	main
span	doc_901133458181_item	2931837	et	4	main
kus	doc_901133458181_item	2931838	et	3	main
sa	doc_901133458181_item	2931839	et	3	main
suvel	doc_901133458181_item	2931840	et	3	main
puhkad	doc_901133458181_item	2931841	et	3	main
ei	doc_901133458181_item	2931845	et	4	main
kodu	doc_901133458180_item	2931484	et	4	main
ja	doc_901133458180_item	2931485	et	3	main
minu	doc_901133458180_item	2931487	et	3	main
on	doc_901133458180_item	2931489	et	4	main
linn	doc_901133458180_item	2931495	et	3	main
eesti-vene	doc_901133458180_item	2931507	et	4	main
tolliamet	doc_901133458180_item	2931508	et	3	main
narvas	doc_901133458180_item	2931509	et	4	main
tänaval	doc_901133458180_item	2931519	et	4	main
väga	doc_901133458180_item	2931541	et	3	main
pärast	doc_901133458180_item	2931544	et	4	main
et	doc_901133458180_item	2931545	et	3	main
all	doc_901133458180_item	2931550	et	3	main
2	doc_901133458180_item	2931555	et	2	main
ole	doc_901133458180_item	2931567	et	4	main
isa	doc_901133458180_item	2931572	et	4	main
ema	doc_901133458180_item	2931573	et	4	main
isa	doc_901133458180_item	2931599	et	4	main
hästi	doc_901133458180_item	2931600	et	3	main
mida	doc_901133458180_item	2931611	et	4	main
teha	doc_901133458180_item	2931616	et	3	main
on	doc_901133458180_item	2931619	et	4	main
ajal	doc_901133458180_item	2931631	et	4	main
telerit	doc_901133458180_item	2931636	et	3	main
on	doc_901133458180_item	2931640	et	4	main
kudumine	doc_901133458180_item	2931646	et	4	main
span	doc_901133458181_item	2931679	et	4	main
ma	doc_901133458181_item	2931680	et	3	main
olen	doc_901133458181_item	2931681	et	3	main
pärit	doc_901133458181_item	2931682	et	3	main
kohad	doc_901133458181_item	2931688	et	4	main
ja	doc_901133458181_item	2931692	et	3	main
kolmandal	doc_901133458181_item	2931700	et	3	main
korrusel	doc_901133458181_item	2931701	et	3	main
on	doc_901133458181_item	2931703	et	4	main
kolmetoaline	doc_901133458181_item	2931704	et	4	main
korter	doc_901133458181_item	2931705	et	3	main
köök	doc_901133458181_item	2931706	et	3	main
ei	doc_901133458180_item	2931530	et	4	main
suur	doc_901133458180_item	2931533	et	3	main
kahetoaline	doc_901133458180_item	2931536	et	4	main
ei	doc_901133458180_item	2931539	et	4	main
prahti	doc_901133458180_item	2931548	et	4	main
on	doc_901133458180_item	2931557	et	4	main
perekond	doc_901133458180_item	2931559	et	3	main
tegelevad	doc_901133458180_item	2931561	et	4	main
sinu	doc_901133458180_item	2931562	et	3	main
ei	doc_901133458180_item	2931566	et	4	main
mina	doc_901133458180_item	2931569	et	4	main
ja	doc_901133458180_item	2931571	et	3	main
nimi	doc_901133458180_item	2931574	et	3	main
on	doc_901133458180_item	2931575	et	4	main
xxxxxxx	doc_901133458180_item	2931576	et	4	main
ta	doc_901133458180_item	2931577	et	4	main
väga	doc_901133458180_item	2931579	et	3	main
ilus	doc_901133458180_item	2931580	et	4	main
ema	doc_901133458180_item	2931581	et	4	main
töötab	doc_901133458180_item	2931582	et	3	main
on	doc_901133458180_item	2931578	et	4	main
haiglas	doc_901133458180_item	2931583	et	3	main
ta	doc_901133458180_item	2931584	et	4	main
on	doc_901133458180_item	2931585	et	4	main
arst	doc_901133458180_item	2931586	et	3	main
isa	doc_901133458180_item	2931587	et	4	main
nimi	doc_901133458180_item	2931588	et	3	main
on	doc_901133458180_item	2931589	et	4	main
xxxxxxxx	doc_901133458180_item	2931590	et	4	main
isa	doc_901133458180_item	2931591	et	4	main
töötab	doc_901133458180_item	2931592	et	3	main
politseis	doc_901133458180_item	2931593	et	3	main
ta	doc_901133458180_item	2931594	et	4	main
on	doc_901133458180_item	2931595	et	4	main
konstebel	doc_901133458180_item	2931596	et	4	main
ema	doc_901133458180_item	2931597	et	4	main
ja	doc_901133458180_item	2931598	et	3	main
kas	doc_901133458180_item	2931617	et	3	main
sinu	doc_901133458180_item	2931624	et	3	main
kus	doc_901133458180_item	2931626	et	3	main
suvel	doc_901133458180_item	2931628	et	3	main
puhkad	doc_901133458180_item	2931629	et	3	main
vabal	doc_901133458180_item	2931630	et	3	main
lemmiktegevus	doc_901133458180_item	2931644	et	4	main
puhkan	doc_901133458180_item	2931650	et	3	main
dokument	doc_901133458181_item	2931654	et	3	main
on	doc_901133458181_item	2931667	et	4	main
span	doc_901133458181_item	2931671	et	4	main
on	doc_901133458181_item	2931673	et	4	main
span	doc_901133458181_item	2931678	et	4	main
palju	doc_901133458181_item	2931686	et	4	main
ilusad	doc_901133458181_item	2931687	et	3	main
narva	doc_901133458181_item	2931690	et	4	main
eraldi	doc_901133458181_item	2931715	et	4	main
köögis	doc_901133458181_item	2931716	et	3	main
mul	doc_901133458181_item	2931717	et	3	main
ja	doc_901133458181_item	2931722	et	3	main
üks	doc_901133458181_item	2931724	et	3	main
ja	doc_901133458181_item	2931726	et	3	main
toolid	doc_901133458181_item	2931727	et	3	main
meie	doc_901133458181_item	2931728	et	4	main
majas	doc_901133458181_item	2931729	et	3	main
külm	doc_901133458181_item	2931733	et	3	main
gaas	doc_901133458181_item	2931737	et	3	main
meie	doc_901133458181_item	2931739	et	4	main
on	doc_901133458181_item	2931741	et	4	main
all	doc_901133458181_item	2931748	et	3	main
lilled	doc_901133458181_item	2931750	et	3	main
põõsad	doc_901133458181_item	2931753	et	3	main
span	doc_901133458181_item	2931754	et	4	main
milline	doc_901133458181_item	2931757	et	3	main
sinu	doc_901133458181_item	2931759	et	3	main
triigima	doc_901133458181_item	2931785	et	4	main
toitu	doc_901133458181_item	2931790	et	4	main
ja	doc_901133458181_item	2931793	et	3	main
sõber	doc_901133458181_item	2931796	et	3	main
korteriüüri	doc_901133458181_item	2931798	et	4	main
teleri	doc_901133458181_item	2931800	et	3	main
remondib	doc_901133458181_item	2931804	et	3	main
vajanduse	doc_901133458181_item	2931806	et	4	main
span	doc_901133458181_item	2931818	et	4	main
3	doc_901133458181_item	2931820	et	2	main
sul	doc_901133458181_item	2931829	et	3	main
mis	doc_901133458181_item	2931833	et	4	main
span	doc_901133458181_item	2931843	et	4	main
seal	doc_901133458181_item	2931854	et	4	main
on	doc_901133458181_item	2931855	et	4	main
suurepärane	doc_901133458181_item	2931856	et	4	main
ei	doc_901133458181_item	2931862	et	4	main
vihmased	doc_901133458181_item	2931864	et	4	main
on	doc_901133458181_item	2931873	et	4	main
või	doc_901133458181_item	2931881	et	4	main
joonistada	doc_901133458180_item	2931634	et	3	main
tantsida	doc_901133458180_item	2931637	et	3	main
on	doc_901133458180_item	2931645	et	4	main
uus	doc_901133458181_item	2931653	et	3	main
vasta	doc_901133458181_item	2931655	et	4	main
järgmistele	doc_901133458181_item	2931656	et	3	main
küsimustele	doc_901133458181_item	2931657	et	4	main
span	doc_901133458181_item	2931658	et	4	main
span	doc_901133458181_item	2931659	et	4	main
1	doc_901133458181_item	2931660	et	2	main
kirjuta	doc_901133458181_item	2931661	et	4	main
oma	doc_901133458181_item	2931663	et	4	main
midagi	doc_901133458181_item	2931662	et	4	main
kodulinnast	doc_901133458181_item	2931664	et	4	main
span	doc_901133458181_item	2931665	et	4	main
mis	doc_901133458181_item	2931666	et	4	main
missugune	doc_901133458181_item	2931672	et	3	main
sinu	doc_901133458181_item	2931674	et	3	main
kodu	doc_901133458181_item	2931675	et	4	main
ja	doc_901133458181_item	2931676	et	3	main
koduümbrus	doc_901133458181_item	2931677	et	3	main
on	doc_901133458181_item	2931685	et	4	main
viiekorruselises	doc_901133458181_item	2931698	et	4	main
majas	doc_901133458181_item	2931699	et	3	main
ole	doc_901133458181_item	2931708	et	4	main
ees	doc_901133458181_item	2931744	et	4	main
2	doc_901133458181_item	2931756	et	2	main
perekond	doc_901133458181_item	2931760	et	3	main
tolmu	doc_901133458181_item	2931784	et	4	main
videomaki	doc_901133458181_item	2931802	et	3	main
autot	doc_901133458181_item	2931805	et	3	main
veel	doc_901133458181_item	2931811	et	4	main
klopib	doc_901133458181_item	2931813	et	3	main
välja	doc_901133458181_item	2931817	et	4	main
meeldib	doc_901133458181_item	2931823	et	3	main
vabal	doc_901133458181_item	2931824	et	3	main
kas	doc_901133458181_item	2931828	et	3	main
span	doc_901133458181_item	2931842	et	4	main
mul	doc_901133458181_item	2931844	et	3	main
loodus	doc_901133458181_item	2931857	et	4	main
ole	doc_901133458181_item	2931863	et	4	main
ja	doc_901133458181_item	2931865	et	3	main
saame	doc_901133458181_item	2931866	et	4	main
päevitada	doc_901133458181_item	2931867	et	3	main
õhtul	doc_901133458181_item	2931868	et	3	main
veel	doc_901133458181_item	2931883	et	4	main
meeldib	doc_901133458181_item	2931885	et	3	main
mere	doc_901133458181_item	2931887	et	3	main
kodu	doc_901133458182_item	2931919	et	4	main
ja	doc_901133458182_item	2931920	et	3	main
elan	doc_901133458182_item	2931925	et	3	main
narvas	doc_901133458182_item	2931926	et	4	main
kahetoalises	doc_901133458182_item	2931937	et	4	main
on	doc_901133458182_item	2931940	et	4	main
vann	doc_901133458182_item	2931944	et	3	main
meil	doc_901133458182_item	2931964	et	4	main
elutoas	doc_901133458182_item	2931965	et	3	main
ja	doc_901133458182_item	2931989	et	3	main
pool	doc_901133458182_item	2931996	et	4	main
pool	doc_901133458182_item	2931999	et	4	main
minu	doc_901133458182_item	2932004	et	3	main
elada	doc_901133458182_item	2932014	et	3	main
me	doc_901133458182_item	2932030	et	4	main
jalutame	doc_901133458182_item	2932031	et	3	main
meie	doc_901133458182_item	2932032	et	4	main
tütrega	doc_901133458182_item	2932033	et	3	main
ole	doc_901133458182_item	2932044	et	4	main
praegu	doc_901133458182_item	2932045	et	3	main
ma	doc_901133458182_item	2932063	et	3	main
vanematega	doc_901133458182_item	2932066	et	4	main
poiss	doc_901133458182_item	2932074	et	3	main
vabaabielus	doc_901133458182_item	2932077	et	4	main
mul	doc_901133458182_item	2932125	et	3	main
narvas	doc_901133458182_item	2932132	et	4	main
meie	doc_901133458182_item	2932140	et	4	main
tütar	doc_901133458182_item	2932141	et	3	main
span	doc_901133458182_item	2932151	et	4	main
teha	doc_901133458182_item	2932159	et	3	main
on	doc_901133458182_item	2932163	et	4	main
mis	doc_901133458182_item	2932166	et	4	main
on	doc_901133458182_item	2932178	et	4	main
suustada	doc_901133458182_item	2932192	et	4	main
ja	doc_901133458182_item	2932193	et	3	main
ma	doc_901133458182_item	2932201	et	3	main
kodus	doc_901133458182_item	2932203	et	4	main
korterit	doc_901133458182_item	2932223	et	3	main
süüa	doc_901133458182_item	2932231	et	3	main
sõpraga	doc_901133458182_item	2932236	et	4	main
reisida	doc_901133458182_item	2932238	et	3	main
ilusat	doc_901133458182_item	2932239	et	3	main
me	doc_901133458182_item	2932241	et	4	main
kuulame	doc_901133458182_item	2932242	et	4	main
muusikat	doc_901133458182_item	2932243	et	3	main
ma	doc_901133458182_item	2932244	et	3	main
armastan	doc_901133458182_item	2932245	et	3	main
jalutada	doc_901133458182_item	2932246	et	3	main
vasta	doc_901133458183_item	2932277	et	4	main
span	doc_901133458183_item	2932281	et	4	main
oma	doc_901133458183_item	2932285	et	4	main
kõik	doc_901133458181_item	2931731	et	4	main
soe	doc_901133458181_item	2931735	et	4	main
koduümbrus	doc_901133458181_item	2931740	et	3	main
ilus	doc_901133458181_item	2931742	et	4	main
maja	doc_901133458181_item	2931743	et	4	main
akna	doc_901133458181_item	2931747	et	3	main
ja	doc_901133458181_item	2931751	et	3	main
puud	doc_901133458181_item	2931752	et	4	main
on	doc_901133458181_item	2931758	et	4	main
tegelevad	doc_901133458181_item	2931763	et	4	main
sinu	doc_901133458181_item	2931764	et	3	main
span	doc_901133458181_item	2931766	et	4	main
span	doc_901133458181_item	2931767	et	4	main
meie	doc_901133458181_item	2931768	et	4	main
perekonnas	doc_901133458181_item	2931769	et	4	main
on	doc_901133458181_item	2931770	et	4	main
kaks	doc_901133458181_item	2931771	et	3	main
inimest	doc_901133458181_item	2931772	et	3	main
veel	doc_901133458181_item	2931773	et	4	main
meil	doc_901133458181_item	2931774	et	4	main
on	doc_901133458181_item	2931775	et	4	main
kass	doc_901133458181_item	2931776	et	3	main
minu	doc_901133458181_item	2931777	et	3	main
kohustus	doc_901133458181_item	2931778	et	4	main
on	doc_901133458181_item	2931779	et	4	main
pesema	doc_901133458181_item	2931780	et	3	main
nõud	doc_901133458181_item	2931781	et	3	main
laud	doc_901133458181_item	2931725	et	4	main
on	doc_901133458181_item	2931730	et	4	main
ja	doc_901133458181_item	2931734	et	3	main
vesi	doc_901133458181_item	2931736	et	4	main
keskküte	doc_901133458181_item	2931738	et	3	main
lastemänguväljak	doc_901133458181_item	2931746	et	3	main
kasvavad	doc_901133458181_item	2931749	et	4	main
võtama	doc_901133458181_item	2931783	et	4	main
lilli	doc_901133458181_item	2931788	et	4	main
valmistama	doc_901133458181_item	2931789	et	3	main
käima	doc_901133458181_item	2931791	et	4	main
minu	doc_901133458181_item	2931795	et	3	main
maksab	doc_901133458181_item	2931797	et	3	main
maki	doc_901133458181_item	2931801	et	3	main
vaipu	doc_901133458181_item	2931814	et	3	main
pesu	doc_901133458181_item	2931786	et	4	main
korral	doc_901133458181_item	2931807	et	4	main
käib	doc_901133458181_item	2931808	et	3	main
mitmesugustes	doc_901133458181_item	2931809	et	3	main
ametiasutustes	doc_901133458181_item	2931810	et	4	main
viib	doc_901133458181_item	2931815	et	3	main
mida	doc_901133458181_item	2931821	et	4	main
sulle	doc_901133458181_item	2931822	et	3	main
teha	doc_901133458181_item	2931826	et	3	main
span	doc_901133458181_item	2931827	et	4	main
meeldib	doc_901133458181_item	2931850	et	3	main
käime	doc_901133458181_item	2931870	et	4	main
saunasse	doc_901133458181_item	2931871	et	3	main
see	doc_901133458181_item	2931872	et	3	main
koduümbrus	doc_901133458182_item	2931921	et	3	main
span	doc_901133458182_item	2931923	et	4	main
lifti	doc_901133458182_item	2931932	et	4	main
ma	doc_901133458182_item	2931933	et	3	main
elan	doc_901133458182_item	2931934	et	3	main
esik	doc_901133458182_item	2931941	et	3	main
ja	doc_901133458182_item	2931943	et	3	main
on	doc_901133458182_item	2931956	et	4	main
seinakapp	doc_901133458182_item	2931958	et	3	main
gaasipliit	doc_901133458182_item	2931960	et	3	main
diivani	doc_901133458182_item	2931972	et	4	main
seksioonikapp	doc_901133458182_item	2931974	et	4	main
vaip	doc_901133458182_item	2931976	et	3	main
riidekapp	doc_901133458182_item	2931979	et	3	main
magamistoas	doc_901133458182_item	2931982	et	3	main
lai	doc_901133458182_item	2931984	et	3	main
riidekapp	doc_901133458182_item	2931986	et	3	main
diivan	doc_901133458182_item	2931988	et	3	main
raamaturiiul	doc_901133458182_item	2931990	et	4	main
koduümbrus	doc_901133458182_item	2931991	et	3	main
ilus	doc_901133458182_item	2931994	et	4	main
ela	doc_901133458182_item	2932007	et	4	main
meilega	doc_901133458182_item	2932008	et	4	main
nad	doc_901133458182_item	2932009	et	3	main
on	doc_901133458182_item	2932017	et	4	main
linn	doc_901133458182_item	2932019	et	3	main
on	doc_901133458182_item	2932021	et	4	main
loos	doc_901133458182_item	2932023	et	4	main
mulle	doc_901133458182_item	2932024	et	4	main
meeldib	doc_901133458182_item	2932025	et	3	main
jalutada	doc_901133458182_item	2932026	et	3	main
kodulinnas	doc_901133458182_item	2932037	et	4	main
huvitavat	doc_901133458182_item	2932040	et	4	main
span	doc_901133458182_item	2932055	et	4	main
millega	doc_901133458182_item	2932056	et	3	main
span	doc_901133458182_item	2932060	et	4	main
span	doc_901133458182_item	2932061	et	4	main
praegu	doc_901133458182_item	2932062	et	3	main
tallinnas	doc_901133458182_item	2932082	et	4	main
need	doc_901133458182_item	2932083	et	3	main
õe	doc_901133458182_item	2932129	et	4	main
perekond	doc_901133458182_item	2932130	et	3	main
elab	doc_901133458182_item	2932131	et	3	main
nädalavahetust	doc_901133458182_item	2932139	et	4	main
tähelepanelik	doc_901133458182_item	2932150	et	4	main
vabal	doc_901133458182_item	2932157	et	3	main
kas	doc_901133458182_item	2932161	et	3	main
mingeid	doc_901133458182_item	2932164	et	3	main
sa	doc_901133458182_item	2932172	et	3	main
span	doc_901133458182_item	2932175	et	4	main
span	doc_901133458182_item	2932176	et	4	main
mul	doc_901133458182_item	2932177	et	3	main
narva	doc_901133458182_item	2932185	et	4	main
päikest	doc_901133458182_item	2932187	et	4	main
võtta	doc_901133458182_item	2932188	et	3	main
tuuline	doc_901133458182_item	2932200	et	3	main
turism	doc_901133458182_item	2932232	et	3	main
vana	doc_901133458182_item	2932247	et	4	main
linnas	doc_901133458182_item	2932248	et	4	main
lähme	doc_901133458182_item	2932253	et	3	main
vanematega	doc_901133458182_item	2932273	et	4	main
span	doc_901133458183_item	2932280	et	4	main
kirjuta	doc_901133458183_item	2932283	et	4	main
huvitavat	doc_901133458183_item	2932293	et	4	main
span	doc_901133458183_item	2932294	et	4	main
minu	doc_901133458183_item	2932304	et	3	main
vaatamisväärsus	doc_901133458183_item	2932315	et	4	main
on	doc_901133458183_item	2932316	et	4	main
ajal	doc_901133458181_item	2931825	et	4	main
on	doc_901133458181_item	2931830	et	4	main
aga	doc_901133458181_item	2931848	et	3	main
mulle	doc_901133458181_item	2931849	et	4	main
sõidata	doc_901133458181_item	2931851	et	4	main
suvilasse	doc_901133458181_item	2931852	et	4	main
suvel	doc_901133458181_item	2931853	et	3	main
ja	doc_901133458181_item	2931858	et	3	main
hea	doc_901133458181_item	2931859	et	4	main
õhk	doc_901133458181_item	2931860	et	3	main
ilmad	doc_901133458181_item	2931861	et	3	main
tõesti	doc_901133458181_item	2931874	et	3	main
tore	doc_901133458181_item	2931875	et	3	main
teeme	doc_901133458181_item	2931876	et	3	main
lõket	doc_901133458181_item	2931877	et	4	main
ja	doc_901133458181_item	2931878	et	3	main
praadime	doc_901133458181_item	2931879	et	4	main
mulle	doc_901133458181_item	2931884	et	4	main
ääres	doc_901133458181_item	2931888	et	4	main
käia	doc_901133458181_item	2931889	et	4	main
metsas	doc_901133458181_item	2931890	et	3	main
ja	doc_901133458181_item	2931891	et	3	main
korjata	doc_901133458181_item	2931892	et	4	main
marju	doc_901133458181_item	2931893	et	3	main
ja	doc_901133458181_item	2931894	et	3	main
seeni	doc_901133458181_item	2931895	et	3	main
span	doc_901133458181_item	2931896	et	4	main
uus	doc_901133458182_item	2931897	et	3	main
dokument	doc_901133458182_item	2931898	et	3	main
vasta	doc_901133458182_item	2931899	et	4	main
järgmistele	doc_901133458182_item	2931900	et	3	main
küsimustele	doc_901133458182_item	2931901	et	4	main
span	doc_901133458182_item	2931902	et	4	main
span	doc_901133458182_item	2931903	et	4	main
1	doc_901133458182_item	2931904	et	2	main
kirjuta	doc_901133458182_item	2931905	et	4	main
midagi	doc_901133458182_item	2931906	et	4	main
oma	doc_901133458182_item	2931907	et	4	main
kodulinnast	doc_901133458182_item	2931908	et	4	main
span	doc_901133458182_item	2931909	et	4	main
mis	doc_901133458182_item	2931910	et	4	main
on	doc_901133458182_item	2931911	et	4	main
sinu	doc_901133458182_item	2931912	et	3	main
kodulinnas	doc_901133458182_item	2931913	et	4	main
huvitavat	doc_901133458182_item	2931914	et	4	main
span	doc_901133458182_item	2931915	et	4	main
missugune	doc_901133458182_item	2931916	et	3	main
on	doc_901133458182_item	2931917	et	4	main
sinu	doc_901133458182_item	2931918	et	3	main
ole	doc_901133458181_item	2931846	et	4	main
hobisid	doc_901133458181_item	2931847	et	3	main
me	doc_901133458181_item	2931869	et	4	main
vorstike	doc_901133458181_item	2931880	et	4	main
šašlõkki	doc_901133458181_item	2931882	et	2	main
sõidata	doc_901133458181_item	2931886	et	4	main
ei	doc_901133458182_item	2931930	et	4	main
korrusel	doc_901133458182_item	2931936	et	3	main
korteris	doc_901133458182_item	2931938	et	3	main
köögis	doc_901133458182_item	2931955	et	3	main
on	doc_901133458182_item	2931966	et	4	main
diivan	doc_901133458182_item	2931967	et	3	main
seinalamp	doc_901133458182_item	2931968	et	3	main
tv	doc_901133458182_item	2931969	et	4	main
kaks	doc_901133458182_item	2931970	et	3	main
laud	doc_901133458182_item	2931973	et	4	main
põrandal	doc_901133458182_item	2931975	et	3	main
vaip	doc_901133458182_item	2931978	et	3	main
diivan	doc_901133458182_item	2931981	et	3	main
voodi	doc_901133458182_item	2931985	et	4	main
ei	doc_901133458182_item	2931992	et	4	main
teisel	doc_901133458182_item	2931998	et	4	main
vanemad	doc_901133458182_item	2932005	et	4	main
ei	doc_901133458182_item	2932006	et	4	main
armastan	doc_901133458182_item	2932013	et	3	main
narva	doc_901133458182_item	2932016	et	4	main
narva	doc_901133458182_item	2932022	et	4	main
nädalavahetust	doc_901133458182_item	2932029	et	4	main
looseni	doc_901133458182_item	2932035	et	4	main
minu	doc_901133458182_item	2932036	et	3	main
väga	doc_901133458182_item	2932039	et	3	main
vaba	doc_901133458182_item	2932046	et	4	main
ajal	doc_901133458182_item	2932047	et	4	main
span	doc_901133458182_item	2932048	et	4	main
span	doc_901133458182_item	2932049	et	4	main
2	doc_901133458182_item	2932050	et	2	main
milline	doc_901133458182_item	2932051	et	3	main
pereliikmed	doc_901133458182_item	2932059	et	3	main
on	doc_901133458182_item	2932068	et	4	main
kolm	doc_901133458182_item	2932069	et	3	main
kaks	doc_901133458182_item	2932071	et	3	main
ja	doc_901133458182_item	2932073	et	3	main
ma	doc_901133458182_item	2932075	et	3	main
olen	doc_901133458182_item	2932076	et	3	main
minu	doc_901133458182_item	2932078	et	3	main
vanemad	doc_901133458182_item	2932079	et	4	main
lapsed	doc_901133458182_item	2932080	et	3	main
elavad	doc_901133458182_item	2932081	et	4	main
kolm	doc_901133458182_item	2932122	et	3	main
tagasi	doc_901133458182_item	2932124	et	3	main
on	doc_901133458182_item	2932126	et	4	main
vanem	doc_901133458182_item	2932127	et	4	main
õde	doc_901133458182_item	2932128	et	4	main
span	doc_901133458182_item	2932152	et	4	main
3	doc_901133458182_item	2932153	et	2	main
ajal	doc_901133458182_item	2932158	et	4	main
sul	doc_901133458182_item	2932162	et	3	main
suvel	doc_901133458182_item	2932173	et	3	main
suvel	doc_901133458182_item	2932181	et	3	main
mulle	doc_901133458182_item	2932182	et	4	main
meeldib	doc_901133458182_item	2932183	et	3	main
ujuda	doc_901133458182_item	2932184	et	3	main
uistada	doc_901133458182_item	2932194	et	4	main
ja	doc_901133458182_item	2932199	et	3	main
pesen	doc_901133458182_item	2932224	et	3	main
valmistamine	doc_901133458182_item	2932230	et	4	main
puhkada	doc_901133458182_item	2932235	et	4	main
me	doc_901133458182_item	2932252	et	4	main
meeldib	doc_901133458182_item	2932266	et	3	main
järgmistele	doc_901133458183_item	2932278	et	3	main
küsimustele	doc_901133458183_item	2932279	et	4	main
1	doc_901133458183_item	2932282	et	2	main
midagi	doc_901133458183_item	2932284	et	4	main
1	doc_901133458183_item	2932288	et	2	main
2	doc_901133458183_item	2932295	et	2	main
sinu	doc_901133458183_item	2932298	et	3	main
narva	doc_901133458183_item	2932307	et	4	main
on	doc_901133458183_item	2932309	et	4	main
meie	doc_901133458183_item	2932313	et	4	main
peamine	doc_901133458183_item	2932314	et	3	main
ja	doc_901133458183_item	2932321	et	3	main
on	doc_901133458183_item	2932325	et	4	main
ole	doc_901133458182_item	2931931	et	4	main
elutuba	doc_901133458182_item	2931947	et	4	main
ja	doc_901133458182_item	2931948	et	3	main
magamistuba	doc_901133458182_item	2931949	et	4	main
mull	doc_901133458182_item	2931950	et	3	main
on	doc_901133458182_item	2931951	et	4	main
väike	doc_901133458182_item	2931952	et	4	main
köök	doc_901133458182_item	2931953	et	3	main
meil	doc_901133458182_item	2931954	et	4	main
span	doc_901133458182_item	2931922	et	4	main
ma	doc_901133458182_item	2931924	et	3	main
telliskivimajas	doc_901133458182_item	2931927	et	4	main
minu	doc_901133458182_item	2931928	et	3	main
majas	doc_901133458182_item	2931929	et	3	main
teisel	doc_901133458182_item	2931935	et	4	main
korteris	doc_901133458182_item	2931939	et	3	main
tualett	doc_901133458182_item	2931942	et	3	main
on	doc_901133458182_item	2931945	et	4	main
koos	doc_901133458182_item	2931946	et	4	main
kolm	doc_901133458182_item	2931961	et	3	main
ühel	doc_901133458182_item	2931995	et	3	main
väike	doc_901133458182_item	2932018	et	4	main
siin	doc_901133458182_item	2932020	et	4	main
seal	doc_901133458182_item	2932027	et	4	main
iga	doc_901133458182_item	2932028	et	4	main
on	doc_901133458182_item	2932038	et	4	main
kahjuks	doc_901133458182_item	2932041	et	4	main
ei	doc_901133458182_item	2932043	et	4	main
tegelevad	doc_901133458182_item	2932057	et	4	main
sinu	doc_901133458182_item	2932058	et	3	main
narvas	doc_901133458182_item	2932065	et	4	main
mul	doc_901133458182_item	2932067	et	3	main
last	doc_901133458182_item	2932070	et	4	main
surnud	doc_901133458182_item	2932121	et	4	main
aastat	doc_901133458182_item	2932123	et	3	main
ka	doc_901133458182_item	2932133	et	3	main
mulle	doc_901133458182_item	2932134	et	4	main
meeldib	doc_901133458182_item	2932135	et	3	main
tulla	doc_901133458182_item	2932136	et	3	main
õest	doc_901133458182_item	2932137	et	4	main
külla	doc_901133458182_item	2932138	et	4	main
õde	doc_901133458182_item	2932145	et	4	main
on	doc_901133458182_item	2932146	et	4	main
sõbralik	doc_901133458182_item	2932147	et	3	main
südamlik	doc_901133458182_item	2932148	et	3	main
ja	doc_901133458182_item	2932149	et	3	main
meeldib	doc_901133458182_item	2932156	et	3	main
hobisid	doc_901133458182_item	2932165	et	3	main
on	doc_901133458182_item	2932167	et	4	main
sinu	doc_901133458182_item	2932168	et	3	main
lemmiktegevus	doc_901133458182_item	2932169	et	4	main
palju	doc_901133458182_item	2932179	et	4	main
sõbrannad	doc_901133458182_item	2932180	et	3	main
jõges	doc_901133458182_item	2932186	et	4	main
talvel	doc_901133458182_item	2932189	et	4	main
mulle	doc_901133458182_item	2932190	et	4	main
meeldib	doc_901133458182_item	2932191	et	3	main
süüa	doc_901133458182_item	2932221	et	3	main
minu	doc_901133458182_item	2932225	et	3	main
on	doc_901133458182_item	2932227	et	4	main
kudumine	doc_901133458182_item	2932228	et	4	main
joonistamine	doc_901133458182_item	2932229	et	4	main
armastan	doc_901133458182_item	2932234	et	3	main
loodus	doc_901133458182_item	2932237	et	4	main
kohtad	doc_901133458182_item	2932240	et	3	main
sõidata	doc_901133458182_item	2932250	et	4	main
narva-jõesuusse	doc_901133458182_item	2932251	et	3	main
mängida	doc_901133458182_item	2932267	et	3	main
võrkpalli	doc_901133458182_item	2932268	et	4	main
suvel	doc_901133458182_item	2932269	et	3	main
ma	doc_901133458182_item	2932270	et	3	main
puhkan	doc_901133458182_item	2932271	et	3	main
suvemajas	doc_901133458182_item	2932272	et	3	main
kodulinnas	doc_901133458183_item	2932292	et	4	main
span	doc_901133458183_item	2932303	et	4	main
ja	doc_901133458183_item	2932323	et	3	main
meil	doc_901133458183_item	2932329	et	4	main
park	doc_901133458183_item	2932336	et	3	main
rootsi	doc_901133458183_item	2932361	et	4	main
ole	doc_901133458183_item	2932376	et	4	main
puud	doc_901133458183_item	2932381	et	4	main
akna	doc_901133458183_item	2932382	et	3	main
all	doc_901133458183_item	2932383	et	3	main
juures	doc_901133458183_item	2932387	et	4	main
span	doc_901133458183_item	2932391	et	4	main
külmik	doc_901133458182_item	2931957	et	3	main
lõunalaud	doc_901133458182_item	2931959	et	4	main
tooli	doc_901133458182_item	2931962	et	4	main
valamu	doc_901133458182_item	2931963	et	4	main
tugitooli	doc_901133458182_item	2931971	et	4	main
seina	doc_901133458182_item	2931977	et	4	main
ja	doc_901133458182_item	2931980	et	3	main
on	doc_901133458182_item	2931983	et	4	main
ja	doc_901133458182_item	2931987	et	3	main
ole	doc_901133458182_item	2931993	et	4	main
tänav	doc_901133458182_item	2931997	et	4	main
spordiklubi	doc_901133458182_item	2932000	et	4	main
ja	doc_901133458182_item	2932001	et	3	main
mänguväljak	doc_901133458182_item	2932002	et	3	main
praegu	doc_901133458182_item	2932003	et	3	main
elavad	doc_901133458182_item	2932010	et	4	main
suvekodus	doc_901133458182_item	2932011	et	3	main
ma	doc_901133458182_item	2932012	et	3	main
narvas	doc_901133458182_item	2932015	et	4	main
kojust	doc_901133458182_item	2932034	et	4	main
ma	doc_901133458182_item	2932042	et	3	main
on	doc_901133458182_item	2932052	et	4	main
sinu	doc_901133458182_item	2932053	et	3	main
perekond	doc_901133458182_item	2932054	et	3	main
elan	doc_901133458182_item	2932064	et	3	main
tüdrukut	doc_901133458182_item	2932072	et	3	main
käivad	doc_901133458182_item	2932084	et	4	main
veel	doc_901133458182_item	2932085	et	4	main
kooli	doc_901133458182_item	2932086	et	4	main
minu	doc_901133458182_item	2932087	et	3	main
tütarlaps	doc_901133458182_item	2932088	et	4	main
käib	doc_901133458182_item	2932089	et	3	main
lasteaias	doc_901133458182_item	2932090	et	4	main
ta	doc_901133458182_item	2932091	et	4	main
on	doc_901133458182_item	2932092	et	4	main
kolmeaastane	doc_901133458182_item	2932093	et	4	main
minu	doc_901133458182_item	2932094	et	3	main
vanemad	doc_901133458182_item	2932095	et	4	main
elavad	doc_901133458182_item	2932096	et	4	main
suvekodus	doc_901133458182_item	2932097	et	3	main
kevadel	doc_901133458182_item	2932098	et	4	main
ja	doc_901133458182_item	2932099	et	3	main
suvel	doc_901133458182_item	2932100	et	3	main
suvekodu	doc_901133458182_item	2932101	et	4	main
asub	doc_901133458182_item	2932102	et	3	main
kaugel	doc_901133458182_item	2932103	et	4	main
jaanilinnas	doc_901133458182_item	2932104	et	4	main
minu	doc_901133458182_item	2932105	et	3	main
vanemad	doc_901133458182_item	2932106	et	4	main
on	doc_901133458182_item	2932107	et	4	main
pensionärid	doc_901133458182_item	2932108	et	3	main
ümbruses	doc_901133458182_item	2932109	et	3	main
suvemaja	doc_901133458182_item	2932110	et	4	main
on	doc_901133458182_item	2932111	et	4	main
väga	doc_901133458182_item	2932112	et	3	main
ilus	doc_901133458182_item	2932113	et	4	main
span	doc_901133458182_item	2932114	et	4	main
mul	doc_901133458182_item	2932115	et	3	main
oli	doc_901133458182_item	2932116	et	3	main
noorem	doc_901133458182_item	2932117	et	4	main
vend	doc_901133458182_item	2932118	et	3	main
ta	doc_901133458182_item	2932119	et	4	main
oli	doc_901133458182_item	2932120	et	3	main
mangib	doc_901133458182_item	2932142	et	4	main
õetütrega	doc_901133458182_item	2932143	et	3	main
minu	doc_901133458182_item	2932144	et	3	main
mida	doc_901133458182_item	2932154	et	4	main
sulle	doc_901133458182_item	2932155	et	3	main
span	doc_901133458182_item	2932160	et	4	main
span	doc_901133458182_item	2932170	et	4	main
kus	doc_901133458182_item	2932171	et	3	main
puhkad	doc_901133458182_item	2932174	et	3	main
kui	doc_901133458182_item	2932195	et	3	main
ilm	doc_901133458182_item	2932196	et	3	main
on	doc_901133458182_item	2932197	et	4	main
vihmane	doc_901133458182_item	2932198	et	4	main
jäin	doc_901133458182_item	2932202	et	3	main
ma	doc_901133458182_item	2932204	et	3	main
vaatan	doc_901133458182_item	2932205	et	3	main
televiisorit	doc_901133458182_item	2932206	et	3	main
loen	doc_901133458182_item	2932207	et	3	main
raamatut	doc_901133458182_item	2932208	et	3	main
kuulan	doc_901133458182_item	2932209	et	3	main
radiot	doc_901133458182_item	2932210	et	4	main
ja	doc_901133458182_item	2932211	et	3	main
mängin	doc_901133458182_item	2932212	et	3	main
meie	doc_901133458182_item	2932213	et	4	main
tütrega	doc_901133458182_item	2932214	et	3	main
ma	doc_901133458182_item	2932215	et	3	main
pean	doc_901133458182_item	2932216	et	4	main
töötama	doc_901133458182_item	2932217	et	3	main
kodus	doc_901133458182_item	2932218	et	4	main
tavaliselt	doc_901133458182_item	2932219	et	4	main
valmistan	doc_901133458182_item	2932220	et	3	main
koristan	doc_901133458182_item	2932222	et	3	main
hobbi	doc_901133458182_item	2932226	et	4	main
ma	doc_901133458182_item	2932233	et	3	main
tallinnas	doc_901133458182_item	2932249	et	4	main
tütrega	doc_901133458182_item	2932254	et	3	main
koos	doc_901133458182_item	2932255	et	4	main
narva	doc_901133458182_item	2932256	et	4	main
lossi	doc_901133458182_item	2932257	et	4	main
ma	doc_901133458182_item	2932258	et	3	main
armastan	doc_901133458182_item	2932259	et	3	main
vaadata	doc_901133458182_item	2932260	et	4	main
uut	doc_901133458182_item	2932261	et	3	main
näitust	doc_901133458182_item	2932262	et	4	main
huvitavad	doc_901133458182_item	2932263	et	4	main
kino	doc_901133458182_item	2932264	et	4	main
mulle	doc_901133458182_item	2932265	et	4	main
span	doc_901133458182_item	2932274	et	4	main
uus	doc_901133458183_item	2932275	et	3	main
dokument	doc_901133458183_item	2932276	et	3	main
kodulinnast	doc_901133458183_item	2932286	et	4	main
span	doc_901133458183_item	2932287	et	4	main
mis	doc_901133458183_item	2932289	et	4	main
on	doc_901133458183_item	2932290	et	4	main
sinu	doc_901133458183_item	2932291	et	3	main
missugune	doc_901133458183_item	2932296	et	3	main
kodu	doc_901133458183_item	2932299	et	4	main
ja	doc_901133458183_item	2932300	et	3	main
koduümbrus	doc_901133458183_item	2932301	et	3	main
span	doc_901133458183_item	2932302	et	4	main
on	doc_901133458183_item	2932306	et	4	main
narva	doc_901133458183_item	2932308	et	4	main
väga	doc_901133458183_item	2932310	et	3	main
ilus	doc_901133458183_item	2932311	et	4	main
linn	doc_901133458183_item	2932312	et	3	main
ilus	doc_901133458183_item	2932322	et	4	main
huvitav	doc_901133458183_item	2932326	et	4	main
pime	doc_901133458183_item	2932331	et	3	main
on	doc_901133458183_item	2932335	et	4	main
ja	doc_901133458183_item	2932341	et	3	main
pime	doc_901133458183_item	2932343	et	3	main
on	doc_901133458183_item	2932350	et	4	main
ka	doc_901133458183_item	2932351	et	3	main
liivarand	doc_901133458183_item	2932352	et	3	main
kus	doc_901133458183_item	2932353	et	3	main
me	doc_901133458183_item	2932354	et	4	main
span	doc_901133458183_item	2932367	et	4	main
meie	doc_901133458183_item	2932373	et	4	main
majas	doc_901133458183_item	2932374	et	3	main
ei	doc_901133458183_item	2932375	et	4	main
kasvavad	doc_901133458183_item	2932380	et	4	main
staadion	doc_901133458183_item	2932389	et	3	main
milline	doc_901133458183_item	2932393	et	3	main
sinu	doc_901133458183_item	2932395	et	3	main
töötab	doc_901133458183_item	2932421	et	3	main
ja	doc_901133458183_item	2932429	et	3	main
abivalmis	doc_901133458183_item	2932430	et	3	main
küsin	doc_901133458183_item	2932433	et	3	main
me	doc_901133458183_item	2932445	et	4	main
suhtleme	doc_901133458183_item	2932446	et	3	main
mitte	doc_901133458183_item	2932447	et	3	main
sõbrad	doc_901133458183_item	2932455	et	3	main
ja	doc_901133458183_item	2932458	et	3	main
ka	doc_901133458183_item	2932463	et	3	main
sõbrad	doc_901133458183_item	2932466	et	3	main
span	doc_901133458183_item	2932467	et	4	main
sul	doc_901133458183_item	2932478	et	3	main
on	doc_901133458183_item	2932479	et	4	main
hobisid	doc_901133458183_item	2932481	et	3	main
mis	doc_901133458183_item	2932482	et	4	main
on	doc_901133458183_item	2932483	et	4	main
sinu	doc_901133458183_item	2932484	et	3	main
span	doc_901133458183_item	2932491	et	4	main
span	doc_901133458183_item	2932492	et	4	main
vaatan	doc_901133458183_item	2932496	et	3	main
ujumine	doc_901133458183_item	2932506	et	4	main
joonistan	doc_901133458183_item	2932521	et	3	main
minu	doc_901133458183_item	2932524	et	3	main
ole	doc_901133458183_item	2932538	et	4	main
vasta	doc_901133458184_item	2932562	et	4	main
järgmistele	doc_901133458184_item	2932563	et	3	main
küsimustele	doc_901133458184_item	2932564	et	4	main
linnas	doc_901133458184_item	2932590	et	4	main
korrusel	doc_901133458184_item	2932601	et	3	main
korter	doc_901133458184_item	2932605	et	3	main
korteris	doc_901133458184_item	2932607	et	3	main
külm	doc_901133458184_item	2932609	et	3	main
asub	doc_901133458184_item	2932611	et	3	main
maja	doc_901133458184_item	2932612	et	4	main
on	doc_901133458184_item	2932616	et	4	main
esimesel	doc_901133458184_item	2932618	et	3	main
on	doc_901133458183_item	2932297	et	4	main
kodulinn	doc_901133458183_item	2932305	et	3	main
tal	doc_901133458183_item	2932324	et	3	main
aed	doc_901133458183_item	2932332	et	3	main
see	doc_901133458183_item	2932334	et	3	main
seal	doc_901133458183_item	2932337	et	4	main
puhata	doc_901133458183_item	2932342	et	4	main
lõvi	doc_901133458183_item	2932362	et	4	main
see	doc_901133458183_item	2932363	et	3	main
span	doc_901133458183_item	2932368	et	4	main
elan	doc_901133458183_item	2932370	et	3	main
lifti	doc_901133458183_item	2932377	et	4	main
on	doc_901133458183_item	2932384	et	4	main
lilled	doc_901133458183_item	2932385	et	3	main
span	doc_901133458183_item	2932390	et	4	main
2	doc_901133458183_item	2932392	et	2	main
on	doc_901133458183_item	2932394	et	4	main
span	doc_901133458183_item	2932397	et	4	main
millega	doc_901133458183_item	2932398	et	3	main
tegelevad	doc_901133458183_item	2932399	et	4	main
hea	doc_901133458183_item	2932428	et	4	main
ma	doc_901133458183_item	2932432	et	3	main
mul	doc_901133458183_item	2932453	et	3	main
oma	doc_901133458183_item	2932456	et	4	main
ja	doc_901133458183_item	2932460	et	3	main
mida	doc_901133458183_item	2932470	et	4	main
sulle	doc_901133458183_item	2932471	et	3	main
meeldib	doc_901133458183_item	2932472	et	3	main
vabal	doc_901133458183_item	2932473	et	3	main
ajal	doc_901133458183_item	2932474	et	4	main
span	doc_901133458183_item	2932486	et	4	main
kus	doc_901133458183_item	2932487	et	3	main
sa	doc_901133458183_item	2932488	et	3	main
suvel	doc_901133458183_item	2932489	et	3	main
ajal	doc_901133458183_item	2932494	et	4	main
telerit	doc_901133458183_item	2932497	et	3	main
jalutan	doc_901133458183_item	2932500	et	3	main
loss	doc_901133458183_item	2932317	et	3	main
ta	doc_901133458183_item	2932318	et	4	main
on	doc_901133458183_item	2932319	et	4	main
suur	doc_901133458183_item	2932320	et	3	main
veel	doc_901133458183_item	2932328	et	4	main
jalutada	doc_901133458183_item	2932340	et	3	main
aia	doc_901133458183_item	2932344	et	4	main
on	doc_901133458183_item	2932364	et	4	main
ka	doc_901133458183_item	2932365	et	3	main
ma	doc_901133458183_item	2932369	et	3	main
maja	doc_901133458183_item	2932386	et	4	main
sinu	doc_901133458183_item	2932400	et	3	main
pereliikmed	doc_901133458183_item	2932401	et	3	main
span	doc_901133458183_item	2932402	et	4	main
span	doc_901133458183_item	2932403	et	4	main
minu	doc_901133458183_item	2932404	et	3	main
perekond	doc_901133458183_item	2932405	et	3	main
on	doc_901133458183_item	2932406	et	4	main
väga	doc_901133458183_item	2932407	et	3	main
väike	doc_901133458183_item	2932408	et	4	main
see	doc_901133458183_item	2932409	et	3	main
on	doc_901133458183_item	2932410	et	4	main
minu	doc_901133458183_item	2932411	et	3	main
ja	doc_901133458183_item	2932413	et	3	main
ema	doc_901133458183_item	2932412	et	4	main
mina	doc_901133458183_item	2932414	et	4	main
praegu	doc_901133458183_item	2932415	et	3	main
ma	doc_901133458183_item	2932416	et	3	main
käin	doc_901133458183_item	2932417	et	3	main
kursusel	doc_901133458183_item	2932418	et	3	main
minu	doc_901133458183_item	2932419	et	3	main
ema	doc_901133458183_item	2932420	et	4	main
minu	doc_901133458183_item	2932423	et	3	main
tihti	doc_901133458183_item	2932431	et	3	main
temal	doc_901133458183_item	2932434	et	3	main
kahjuks	doc_901133458183_item	2932444	et	4	main
tihti	doc_901133458183_item	2932448	et	3	main
huvid	doc_901133458183_item	2932457	et	3	main
temal	doc_901133458183_item	2932461	et	3	main
oma	doc_901133458183_item	2932464	et	4	main
elu	doc_901133458183_item	2932465	et	4	main
teha	doc_901133458183_item	2932475	et	3	main
vabal	doc_901133458183_item	2932493	et	3	main
muusikat	doc_901133458183_item	2932499	et	3	main
kahjuks	doc_901133458183_item	2932507	et	4	main
ma	doc_901133458183_item	2932509	et	3	main
ma	doc_901133458183_item	2932522	et	3	main
seinal	doc_901133458183_item	2932528	et	3	main
juures	doc_901133458183_item	2932535	et	4	main
me	doc_901133458183_item	2932546	et	4	main
sõidame	doc_901133458183_item	2932547	et	3	main
sinna	doc_901133458183_item	2932548	et	3	main
ilus	doc_901133458183_item	2932553	et	4	main
mulle	doc_901133458183_item	2932555	et	4	main
väga	doc_901133458183_item	2932556	et	3	main
meeldib	doc_901133458183_item	2932557	et	3	main
1	doc_901133458184_item	2932565	et	2	main
kirjuta	doc_901133458184_item	2932566	et	4	main
huvitav	doc_901133458184_item	2932588	et	4	main
ajalugu	doc_901133458184_item	2932589	et	4	main
ma	doc_901133458184_item	2932596	et	3	main
viiekorruselises	doc_901133458184_item	2932598	et	4	main
majas	doc_901133458184_item	2932599	et	3	main
esimesel	doc_901133458184_item	2932600	et	3	main
on	doc_901133458184_item	2932603	et	4	main
korter	doc_901133458184_item	2932610	et	3	main
ajalugu	doc_901133458183_item	2932327	et	4	main
on	doc_901133458183_item	2932330	et	4	main
ühesõnaga	doc_901133458183_item	2932333	et	3	main
me	doc_901133458183_item	2932338	et	4	main
võime	doc_901133458183_item	2932339	et	4	main
juures	doc_901133458183_item	2932345	et	4	main
asub	doc_901133458183_item	2932346	et	3	main
narova	doc_901133458183_item	2932347	et	4	main
jõgi	doc_901133458183_item	2932348	et	3	main
siin	doc_901133458183_item	2932349	et	4	main
päevitame	doc_901133458183_item	2932355	et	3	main
ja	doc_901133458183_item	2932356	et	3	main
ujume	doc_901133458183_item	2932357	et	3	main
ranna	doc_901133458183_item	2932358	et	3	main
lähedal	doc_901133458183_item	2932359	et	4	main
asub	doc_901133458183_item	2932360	et	3	main
vaatamisväärsus	doc_901133458183_item	2932366	et	4	main
viiekorruselises	doc_901133458183_item	2932371	et	4	main
majas	doc_901133458183_item	2932372	et	3	main
maja	doc_901133458183_item	2932378	et	4	main
kõrval	doc_901133458183_item	2932379	et	4	main
asub	doc_901133458183_item	2932388	et	3	main
perekond	doc_901133458183_item	2932396	et	3	main
vaabrikus	doc_901133458183_item	2932422	et	4	main
ema	doc_901133458183_item	2932424	et	4	main
lõbus	doc_901133458183_item	2932427	et	4	main
mõnikord	doc_901133458183_item	2932436	et	3	main
käime	doc_901133458183_item	2932438	et	4	main
koos	doc_901133458183_item	2932439	et	4	main
poes	doc_901133458183_item	2932440	et	3	main
kui	doc_901133458183_item	2932449	et	3	main
tahaksin	doc_901133458183_item	2932451	et	3	main
meelelahutused	doc_901133458183_item	2932459	et	4	main
on	doc_901133458183_item	2932462	et	4	main
kas	doc_901133458183_item	2932477	et	3	main
lemmiktegevus	doc_901133458183_item	2932485	et	4	main
kuulan	doc_901133458183_item	2932498	et	3	main
sõbradega	doc_901133458183_item	2932502	et	4	main
minu	doc_901133458183_item	2932503	et	3	main
hobi	doc_901133458183_item	2932504	et	4	main
praegu	doc_901133458183_item	2932508	et	3	main
sõbranna	doc_901133458183_item	2932534	et	4	main
aga	doc_901133458183_item	2932540	et	3	main
isal	doc_901133458183_item	2932542	et	3	main
seal	doc_901133458183_item	2932549	et	4	main
ja	doc_901133458183_item	2932552	et	3	main
ning	doc_901133458183_item	2932554	et	3	main
seal	doc_901133458183_item	2932558	et	4	main
span	doc_901133458183_item	2932559	et	4	main
vastus	doc_901133458184_item	2932560	et	3	main
elan	doc_901133458184_item	2932597	et	3	main
minul	doc_901133458184_item	2932602	et	3	main
teisel	doc_901133458184_item	2932624	et	4	main
on	doc_901133458184_item	2932633	et	4	main
sinu	doc_901133458184_item	2932634	et	3	main
perekond	doc_901133458184_item	2932635	et	3	main
millega	doc_901133458184_item	2932636	et	3	main
pereliikmed	doc_901133458184_item	2932639	et	3	main
üksinda	doc_901133458184_item	2932642	et	4	main
on	doc_901133458184_item	2932645	et	4	main
praegu	doc_901133458184_item	2932647	et	3	main
aleksej	doc_901133458184_item	2932657	et	4	main
temal	doc_901133458184_item	2932658	et	3	main
on	doc_901133458184_item	2932667	et	4	main
on	doc_901133458184_item	2932675	et	4	main
aga	doc_901133458184_item	2932686	et	3	main
on	doc_901133458184_item	2932699	et	4	main
mingeid	doc_901133458184_item	2932700	et	3	main
hobisid	doc_901133458184_item	2932701	et	3	main
mis	doc_901133458184_item	2932702	et	4	main
vaja	doc_901133458184_item	2932723	et	4	main
äripäeva	doc_901133458184_item	2932726	et	4	main
sealt	doc_901133458184_item	2932732	et	4	main
prognoosit	doc_901133458184_item	2932734	et	4	main
ja	doc_901133458184_item	2932735	et	3	main
meeldib	doc_901133458184_item	2932740	et	3	main
süüa	doc_901133458184_item	2932746	et	3	main
meeldib	doc_901133458184_item	2932748	et	3	main
mere	doc_901133458184_item	2932750	et	3	main
käia	doc_901133458184_item	2932752	et	4	main
saunasse	doc_901133458184_item	2932753	et	3	main
seal	doc_901133458184_item	2932760	et	4	main
on	doc_901133458183_item	2932425	et	4	main
väga	doc_901133458183_item	2932426	et	3	main
nõu	doc_901133458183_item	2932435	et	4	main
me	doc_901133458183_item	2932437	et	4	main
või	doc_901133458183_item	2932441	et	4	main
teeme	doc_901133458183_item	2932442	et	3	main
süüa	doc_901133458183_item	2932443	et	3	main
ma	doc_901133458183_item	2932450	et	3	main
sest	doc_901133458183_item	2932452	et	4	main
on	doc_901133458183_item	2932454	et	4	main
span	doc_901133458183_item	2932468	et	4	main
3	doc_901133458183_item	2932469	et	2	main
span	doc_901133458183_item	2932476	et	4	main
mingeid	doc_901133458183_item	2932480	et	3	main
puhkad	doc_901133458183_item	2932490	et	3	main
ma	doc_901133458183_item	2932495	et	3	main
oma	doc_901133458183_item	2932501	et	4	main
on	doc_901133458183_item	2932505	et	4	main
ei	doc_901133458183_item	2932510	et	4	main
uju	doc_901133458183_item	2932511	et	4	main
aga	doc_901133458183_item	2932512	et	3	main
suvel	doc_901133458183_item	2932513	et	3	main
alati	doc_901133458183_item	2932514	et	4	main
ujulas	doc_901133458183_item	2932516	et	3	main
käin	doc_901133458183_item	2932515	et	3	main
minu	doc_901133458183_item	2932517	et	3	main
lemmiktegevus	doc_901133458183_item	2932518	et	4	main
on	doc_901133458183_item	2932519	et	4	main
joonistamine	doc_901133458183_item	2932520	et	4	main
tihti	doc_901133458183_item	2932523	et	3	main
mõni	doc_901133458183_item	2932526	et	3	main
span	doc_901133458183_item	2932529	et	4	main
suvel	doc_901133458183_item	2932530	et	3	main
ma	doc_901133458183_item	2932531	et	3	main
puhkan	doc_901133458183_item	2932532	et	3	main
oma	doc_901133458183_item	2932533	et	4	main
ei	doc_901133458183_item	2932537	et	4	main
tema	doc_901133458183_item	2932541	et	4	main
on	doc_901133458183_item	2932550	et	4	main
vaikne	doc_901133458183_item	2932551	et	3	main
küsimusele	doc_901133458184_item	2932561	et	4	main
ja	doc_901133458184_item	2932593	et	3	main
kindlus	doc_901133458184_item	2932594	et	4	main
pimeaed	doc_901133458184_item	2932595	et	3	main
kahetoaline	doc_901133458184_item	2932604	et	4	main
minu	doc_901133458184_item	2932606	et	3	main
on	doc_901133458184_item	2932608	et	4	main
keskkool	doc_901133458184_item	2932622	et	4	main
pool	doc_901133458184_item	2932625	et	4	main
park	doc_901133458184_item	2932627	et	3	main
seal	doc_901133458184_item	2932628	et	4	main
elan	doc_901133458184_item	2932641	et	3	main
aga	doc_901133458184_item	2932643	et	3	main
vanem	doc_901133458184_item	2932655	et	4	main
on	doc_901133458184_item	2932659	et	4	main
pere	doc_901133458184_item	2932661	et	4	main
abikaasa	doc_901133458184_item	2932662	et	4	main
eesnimi	doc_901133458184_item	2932663	et	3	main
tütar	doc_901133458184_item	2932664	et	3	main
eesnimi	doc_901133458184_item	2932665	et	3	main
poeg	doc_901133458184_item	2932672	et	3	main
viis	doc_901133458184_item	2932676	et	4	main
vana	doc_901133458184_item	2932678	et	4	main
minul	doc_901133458184_item	2932683	et	3	main
elame	doc_901133458184_item	2932688	et	3	main
mulle	doc_901133458184_item	2932712	et	4	main
on	doc_901133458184_item	2932722	et	4	main
majanduse	doc_901133458184_item	2932733	et	4	main
valuuta	doc_901133458184_item	2932736	et	4	main
kursid	doc_901133458184_item	2932737	et	3	main
tordi	doc_901133458184_item	2932742	et	3	main
ääres	doc_901133458184_item	2932751	et	4	main
joonistused	doc_901133458183_item	2932525	et	4	main
rippuvad	doc_901133458183_item	2932527	et	4	main
meil	doc_901133458183_item	2932536	et	4	main
suvilat	doc_901133458183_item	2932539	et	3	main
on	doc_901133458183_item	2932543	et	4	main
talu	doc_901133458183_item	2932544	et	4	main
ja	doc_901133458183_item	2932545	et	3	main
midagi	doc_901133458184_item	2932567	et	4	main
oma	doc_901133458184_item	2932568	et	4	main
kodulinnast	doc_901133458184_item	2932569	et	4	main
mis	doc_901133458184_item	2932570	et	4	main
on	doc_901133458184_item	2932571	et	4	main
sinu	doc_901133458184_item	2932572	et	3	main
kodulinnas	doc_901133458184_item	2932573	et	4	main
huvitavat	doc_901133458184_item	2932574	et	4	main
missugune	doc_901133458184_item	2932575	et	3	main
on	doc_901133458184_item	2932576	et	4	main
sinu	doc_901133458184_item	2932577	et	3	main
kodu	doc_901133458184_item	2932578	et	4	main
ja	doc_901133458184_item	2932579	et	3	main
koduümbrus	doc_901133458184_item	2932580	et	3	main
minu	doc_901133458184_item	2932581	et	3	main
kodulinn	doc_901133458184_item	2932582	et	3	main
on	doc_901133458184_item	2932583	et	4	main
narva	doc_901133458184_item	2932584	et	4	main
meie	doc_901133458184_item	2932585	et	4	main
linnal	doc_901133458184_item	2932586	et	3	main
on	doc_901133458184_item	2932587	et	4	main
on	doc_901133458184_item	2932591	et	4	main
loss	doc_901133458184_item	2932592	et	3	main
nurgal	doc_901133458184_item	2932613	et	3	main
ümbrus	doc_901133458184_item	2932615	et	3	main
pool	doc_901133458184_item	2932619	et	4	main
asub	doc_901133458184_item	2932620	et	3	main
6	doc_901133458184_item	2932621	et	2	main
on	doc_901133458184_item	2932626	et	4	main
tegelevad	doc_901133458184_item	2932637	et	4	main
sinu	doc_901133458184_item	2932638	et	3	main
külas	doc_901133458184_item	2932650	et	3	main
novgorodi	doc_901133458184_item	2932651	et	4	main
oblastis	doc_901133458184_item	2932652	et	3	main
minul	doc_901133458184_item	2932653	et	3	main
ta	doc_901133458184_item	2932666	et	4	main
eesnimi	doc_901133458184_item	2932673	et	3	main
aastat	doc_901133458184_item	2932677	et	3	main
minu	doc_901133458184_item	2932679	et	3	main
on	doc_901133458184_item	2932684	et	4	main
eraldi	doc_901133458184_item	2932689	et	4	main
mida	doc_901133458184_item	2932691	et	4	main
sulle	doc_901133458184_item	2932692	et	3	main
meeldib	doc_901133458184_item	2932693	et	3	main
vabal	doc_901133458184_item	2932694	et	3	main
ajal	doc_901133458184_item	2932695	et	4	main
teha	doc_901133458184_item	2932696	et	3	main
kas	doc_901133458184_item	2932697	et	3	main
sul	doc_901133458184_item	2932698	et	3	main
vabal	doc_901133458184_item	2932710	et	3	main
vedomosti	doc_901133458184_item	2932729	et	4	main
vaatan	doc_901133458184_item	2932731	et	3	main
ja	doc_901133458184_item	2932743	et	3	main
teha	doc_901133458184_item	2932744	et	3	main
mulle	doc_901133458184_item	2932747	et	4	main
jalutada	doc_901133458184_item	2932749	et	3	main
külasse	doc_901133458184_item	2932759	et	3	main
mulle	doc_901133458184_item	2932788	et	4	main
kodu	doc_901133458184_item	2932614	et	4	main
ilus	doc_901133458184_item	2932617	et	4	main
kastaanid	doc_901133458184_item	2932630	et	4	main
2	doc_901133458184_item	2932631	et	2	main
milline	doc_901133458184_item	2932632	et	3	main
mina	doc_901133458184_item	2932640	et	4	main
minul	doc_901133458184_item	2932644	et	3	main
on	doc_901133458184_item	2932654	et	4	main
oma	doc_901133458184_item	2932660	et	4	main
aastat	doc_901133458184_item	2932669	et	3	main
vana	doc_901133458184_item	2932670	et	4	main
ja	doc_901133458184_item	2932671	et	3	main
surnud	doc_901133458184_item	2932682	et	4	main
ajal	doc_901133458184_item	2932711	et	4	main
aga	doc_901133458184_item	2932623	et	3	main
kasvavad	doc_901133458184_item	2932629	et	4	main
isa	doc_901133458184_item	2932646	et	4	main
ta	doc_901133458184_item	2932648	et	4	main
elab	doc_901133458184_item	2932649	et	3	main
vend	doc_901133458184_item	2932656	et	3	main
kolmteist	doc_901133458184_item	2932668	et	4	main
ta	doc_901133458184_item	2932674	et	4	main
ema	doc_901133458184_item	2932680	et	4	main
on	doc_901133458184_item	2932681	et	4	main
sõber	doc_901133458184_item	2932685	et	3	main
me	doc_901133458184_item	2932687	et	4	main
3	doc_901133458184_item	2932690	et	2	main
on	doc_901133458184_item	2932703	et	4	main
sinu	doc_901133458184_item	2932704	et	3	main
lemmiktegevus	doc_901133458184_item	2932705	et	4	main
kus	doc_901133458184_item	2932706	et	3	main
sa	doc_901133458184_item	2932707	et	3	main
suvel	doc_901133458184_item	2932708	et	3	main
puhkad	doc_901133458184_item	2932709	et	3	main
meeldib	doc_901133458184_item	2932713	et	3	main
lugeda	doc_901133458184_item	2932714	et	3	main
tavaliselt	doc_901133458184_item	2932715	et	4	main
ma	doc_901133458184_item	2932716	et	3	main
loen	doc_901133458184_item	2932717	et	3	main
raamatuid	doc_901133458184_item	2932718	et	3	main
aga	doc_901133458184_item	2932719	et	3	main
kui	doc_901133458184_item	2932720	et	3	main
mul	doc_901133458184_item	2932721	et	3	main
ma	doc_901133458184_item	2932724	et	3	main
loen	doc_901133458184_item	2932725	et	3	main
ja	doc_901133458184_item	2932727	et	3	main
delovõe	doc_901133458184_item	2932728	et	4	main
veel	doc_901133458184_item	2932738	et	4	main
mulle	doc_901133458184_item	2932739	et	4	main
küpsetada	doc_901133458184_item	2932741	et	3	main
räägida	doc_901133458184_item	2932754	et	4	main
reisida	doc_901133458184_item	2932776	et	3	main
seal	doc_901133458184_item	2932782	et	4	main
kurde-eestis	doc_901133458185_item	2932821	et	3	main
millega	doc_901133458185_item	2932838	et	3	main
on	doc_901133458185_item	2932851	et	4	main
ja	doc_901133458185_item	2932859	et	3	main
tütre	doc_901133458185_item	2932861	et	3	main
on	doc_901133458185_item	2932863	et	4	main
mida	doc_901133458185_item	2932886	et	4	main
ajal	doc_901133458185_item	2932890	et	4	main
mulle	doc_901133458185_item	2932905	et	4	main
meeldib	doc_901133458185_item	2932906	et	3	main
töötama	doc_901133458185_item	2932917	et	3	main
span	doc_901133458186_item	2932923	et	4	main
midagi	doc_901133458186_item	2932927	et	4	main
on	doc_901133458186_item	2932938	et	4	main
ja	doc_901133458186_item	2932941	et	3	main
narvas	doc_901133458186_item	2932952	et	4	main
kaitse	doc_901133458186_item	2932957	et	4	main
alla	doc_901133458186_item	2932958	et	3	main
arhitektuurimälestisi	doc_901133458186_item	2932960	et	3	main
span	doc_901133458186_item	2932965	et	4	main
span	doc_901133458186_item	2932966	et	4	main
2	doc_901133458186_item	2932967	et	2	main
milline	doc_901133458186_item	2932968	et	3	main
lemmiktegevus	doc_901133458186_item	2933006	et	4	main
meeldib	doc_901133458186_item	2933015	et	3	main
psühholoogia	doc_901133458186_item	2933016	et	4	main
mittetraditsiooniline	doc_901133458186_item	2933017	et	4	main
meditsiin	doc_901133458186_item	2933018	et	3	main
jalgrattaga	doc_901133458186_item	2933022	et	3	main
vasta	doc_901133458187_item	2933026	et	4	main
span	doc_901133458187_item	2933029	et	4	main
span	doc_901133458187_item	2933030	et	4	main
1	doc_901133458187_item	2933031	et	2	main
span	doc_901133458187_item	2933036	et	4	main
huvitavat	doc_901133458187_item	2933041	et	4	main
ma	doc_901133458184_item	2932730	et	3	main
midagi	doc_901133458184_item	2932745	et	4	main
sõbradega	doc_901133458184_item	2932755	et	4	main
suvel	doc_901133458184_item	2932756	et	3	main
ma	doc_901133458184_item	2932757	et	3	main
sõidan	doc_901133458184_item	2932758	et	3	main
järv	doc_901133458184_item	2932765	et	3	main
samuti	doc_901133458184_item	2932768	et	3	main
päevitama	doc_901133458184_item	2932771	et	3	main
kord	doc_901133458184_item	2932778	et	4	main
stpeterburgis	doc_901133458184_item	2932781	et	4	main
väga	doc_901133458184_item	2932783	et	3	main
ilusad	doc_901133458184_item	2932784	et	3	main
pargid	doc_901133458184_item	2932785	et	4	main
kirikud	doc_901133458184_item	2932786	et	3	main
meeldib	doc_901133458184_item	2932789	et	3	main
teed	doc_901133458184_item	2932790	et	4	main
vastus	doc_901133458185_item	2932791	et	3	main
küsimusele	doc_901133458185_item	2932792	et	4	main
vasta	doc_901133458185_item	2932793	et	4	main
järgmistele	doc_901133458185_item	2932794	et	3	main
küsimustele	doc_901133458185_item	2932795	et	4	main
1	doc_901133458185_item	2932796	et	2	main
kirjuta	doc_901133458185_item	2932797	et	4	main
midagi	doc_901133458185_item	2932798	et	4	main
oma	doc_901133458185_item	2932799	et	4	main
kodulinnast	doc_901133458185_item	2932800	et	4	main
mis	doc_901133458185_item	2932801	et	4	main
on	doc_901133458185_item	2932802	et	4	main
sinu	doc_901133458185_item	2932803	et	3	main
kodulinnas	doc_901133458185_item	2932804	et	4	main
huvitavat	doc_901133458185_item	2932805	et	4	main
missugune	doc_901133458185_item	2932806	et	3	main
on	doc_901133458185_item	2932807	et	4	main
sinu	doc_901133458185_item	2932808	et	3	main
kodu	doc_901133458185_item	2932809	et	4	main
ja	doc_901133458185_item	2932810	et	3	main
koduümbrus	doc_901133458185_item	2932811	et	3	main
ma	doc_901133458185_item	2932812	et	3	main
elan	doc_901133458185_item	2932813	et	3	main
narvas	doc_901133458185_item	2932814	et	4	main
narva	doc_901133458185_item	2932815	et	4	main
on	doc_901133458185_item	2932816	et	4	main
vana	doc_901133458185_item	2932817	et	4	main
linn	doc_901133458185_item	2932818	et	3	main
narva	doc_901133458185_item	2932819	et	4	main
asub	doc_901133458185_item	2932820	et	3	main
narvas	doc_901133458185_item	2932829	et	4	main
abikaasa	doc_901133458185_item	2932846	et	4	main
nimi	doc_901133458185_item	2932847	et	3	main
on	doc_901133458184_item	2932761	et	4	main
ilus	doc_901133458184_item	2932763	et	4	main
ja	doc_901133458184_item	2932766	et	3	main
ma	doc_901133458184_item	2932769	et	3	main
ma	doc_901133458184_item	2932779	et	3	main
olin	doc_901133458184_item	2932780	et	3	main
lossid	doc_901133458184_item	2932787	et	4	main
on	doc_901133458185_item	2932823	et	4	main
on	doc_901133458185_item	2932835	et	4	main
sinu	doc_901133458185_item	2932836	et	3	main
perekond	doc_901133458185_item	2932837	et	3	main
ta	doc_901133458185_item	2932850	et	4	main
last	doc_901133458185_item	2932857	et	4	main
nimi	doc_901133458185_item	2932862	et	3	main
poja	doc_901133458185_item	2932865	et	4	main
sulle	doc_901133458185_item	2932887	et	3	main
teha	doc_901133458185_item	2932891	et	3	main
sul	doc_901133458185_item	2932893	et	3	main
hobisid	doc_901133458185_item	2932896	et	3	main
eesti	doc_901133458185_item	2932908	et	4	main
keel	doc_901133458185_item	2932909	et	4	main
ma	doc_901133458185_item	2932916	et	3	main
vasta	doc_901133458186_item	2932920	et	4	main
küsimustele	doc_901133458186_item	2932922	et	4	main
kirjuta	doc_901133458186_item	2932926	et	4	main
span	doc_901133458186_item	2932930	et	4	main
sinu	doc_901133458186_item	2932933	et	3	main
huvitavat	doc_901133458186_item	2932935	et	4	main
kodu	doc_901133458186_item	2932940	et	4	main
koduümbrus	doc_901133458186_item	2932942	et	3	main
narvas	doc_901133458186_item	2932953	et	4	main
võetud	doc_901133458186_item	2932959	et	4	main
keskaegne	doc_901133458186_item	2932961	et	3	main
kindlusemüürid	doc_901133458186_item	2932963	et	3	main
on	doc_901133458186_item	2933004	et	4	main
sinu	doc_901133458186_item	2933005	et	3	main
suvel	doc_901133458186_item	2933010	et	3	main
puhkad	doc_901133458186_item	2933011	et	3	main
kodulinnast	doc_901133458187_item	2933035	et	4	main
koduümbrus	doc_901133458187_item	2933048	et	3	main
span	doc_901133458187_item	2933049	et	4	main
on	doc_901133458187_item	2933064	et	4	main
kunstikool	doc_901133458187_item	2933068	et	4	main
koduümbrus	doc_901133458187_item	2933077	et	3	main
asub	doc_901133458187_item	2933078	et	3	main
bussijaam	doc_901133458187_item	2933084	et	3	main
on	doc_901133458187_item	2933089	et	4	main
sinu	doc_901133458187_item	2933090	et	3	main
perekond	doc_901133458187_item	2933091	et	3	main
span	doc_901133458187_item	2933098	et	4	main
väga	doc_901133458184_item	2932762	et	3	main
suur	doc_901133458184_item	2932764	et	3	main
mäed	doc_901133458184_item	2932767	et	3	main
sõidan	doc_901133458184_item	2932770	et	3	main
narva-jõesuhu	doc_901133458184_item	2932772	et	3	main
veel	doc_901133458184_item	2932773	et	4	main
mulle	doc_901133458184_item	2932774	et	4	main
meeldib	doc_901133458184_item	2932775	et	3	main
viimane	doc_901133458184_item	2932777	et	3	main
narva	doc_901133458185_item	2932822	et	4	main
ilus	doc_901133458185_item	2932824	et	4	main
linn	doc_901133458185_item	2932825	et	3	main
ma	doc_901133458185_item	2932826	et	3	main
olen	doc_901133458185_item	2932827	et	3	main
sündinud	doc_901133458185_item	2932828	et	4	main
tegelevad	doc_901133458185_item	2932839	et	4	main
sinu	doc_901133458185_item	2932840	et	3	main
pereliikmed	doc_901133458185_item	2932841	et	3	main
ma	doc_901133458185_item	2932842	et	3	main
olen	doc_901133458185_item	2932843	et	3	main
abielus	doc_901133458185_item	2932844	et	4	main
minu	doc_901133458185_item	2932845	et	3	main
viiskumne	doc_901133458185_item	2932852	et	4	main
on	doc_901133458185_item	2932855	et	4	main
tütar	doc_901133458185_item	2932858	et	3	main
meeldib	doc_901133458185_item	2932888	et	3	main
mingeid	doc_901133458185_item	2932895	et	3	main
puhkad	doc_901133458185_item	2932904	et	3	main
õppidata	doc_901133458185_item	2932907	et	4	main
suvel	doc_901133458185_item	2932915	et	3	main
uus	doc_901133458186_item	2932918	et	3	main
ma	doc_901133458185_item	2932830	et	3	main
armastan	doc_901133458185_item	2932831	et	3	main
kodulinna	doc_901133458185_item	2932832	et	4	main
2	doc_901133458185_item	2932833	et	2	main
milline	doc_901133458185_item	2932834	et	3	main
on	doc_901133458185_item	2932848	et	4	main
eesnimi	doc_901133458185_item	2932849	et	3	main
meil	doc_901133458185_item	2932854	et	4	main
poeg	doc_901133458185_item	2932860	et	3	main
eesnimi	doc_901133458185_item	2932864	et	3	main
on	doc_901133458185_item	2932867	et	4	main
nimi	doc_901133458185_item	2932866	et	3	main
eesnimi	doc_901133458185_item	2932868	et	3	main
tütar	doc_901133458185_item	2932869	et	3	main
tööb	doc_901133458185_item	2932870	et	4	main
baaris	doc_901133458185_item	2932871	et	3	main
aga	doc_901133458185_item	2932872	et	3	main
poeg	doc_901133458185_item	2932873	et	3	main
käib	doc_901133458185_item	2932874	et	3	main
koolis	doc_901133458185_item	2932875	et	4	main
minu	doc_901133458185_item	2932876	et	3	main
on	doc_901133458185_item	2932878	et	4	main
pensionär	doc_901133458185_item	2932879	et	3	main
minu	doc_901133458185_item	2932880	et	3	main
mees	doc_901133458185_item	2932877	et	4	main
korteris	doc_901133458185_item	2932881	et	3	main
on	doc_901133458185_item	2932882	et	4	main
2	doc_901133458185_item	2932883	et	2	main
tuba	doc_901133458185_item	2932884	et	4	main
aastane	doc_901133458185_item	2932853	et	4	main
kaks	doc_901133458185_item	2932856	et	3	main
vabal	doc_901133458185_item	2932889	et	3	main
kas	doc_901133458185_item	2932892	et	3	main
on	doc_901133458185_item	2932894	et	4	main
mis	doc_901133458185_item	2932897	et	4	main
kirikusse	doc_901133458185_item	2932913	et	4	main
dokument	doc_901133458186_item	2932919	et	3	main
span	doc_901133458186_item	2932924	et	4	main
kodulinnast	doc_901133458186_item	2932929	et	4	main
on	doc_901133458186_item	2932932	et	4	main
kodulinnas	doc_901133458186_item	2932934	et	4	main
sinu	doc_901133458186_item	2932939	et	3	main
span	doc_901133458186_item	2932943	et	4	main
span	doc_901133458186_item	2932944	et	4	main
elan	doc_901133458186_item	2932946	et	3	main
olen	doc_901133458186_item	2932948	et	3	main
sündinud	doc_901133458186_item	2932949	et	4	main
ja	doc_901133458186_item	2932950	et	3	main
riikliku	doc_901133458186_item	2932956	et	3	main
span	doc_901133458186_item	2933007	et	4	main
span	doc_901133458186_item	2933023	et	4	main
kirjuta	doc_901133458187_item	2933032	et	4	main
mis	doc_901133458187_item	2933037	et	4	main
span	doc_901133458187_item	2933050	et	4	main
minu	doc_901133458187_item	2933051	et	3	main
linna	doc_901133458187_item	2933058	et	4	main
sillamäe	doc_901133458187_item	2933059	et	3	main
asub	doc_901133458187_item	2933060	et	3	main
meri	doc_901133458187_item	2933061	et	3	main
ajaloomuuseum	doc_901133458187_item	2933066	et	3	main
sillamäe	doc_901133458187_item	2933069	et	3	main
noor	doc_901133458187_item	2933071	et	3	main
kodu	doc_901133458187_item	2933075	et	4	main
millega	doc_901133458187_item	2933093	et	3	main
pereliikmed	doc_901133458187_item	2933096	et	3	main
sul	doc_901133458187_item	2933123	et	3	main
mis	doc_901133458187_item	2933127	et	4	main
sinu	doc_901133458187_item	2933129	et	3	main
lemmiktegevus	doc_901133458187_item	2933130	et	4	main
mulle	doc_901133458187_item	2933138	et	4	main
meeldib	doc_901133458187_item	2933139	et	3	main
lugema	doc_901133458187_item	2933140	et	4	main
ja	doc_901133458187_item	2933141	et	3	main
on	doc_901133458187_item	2933145	et	4	main
lemmiktegevus	doc_901133458187_item	2933149	et	4	main
et	doc_901133458189_item	2933272	et	3	main
narva	doc_901133458189_item	2933279	et	4	main
vaatamisväärsusi	doc_901133458189_item	2933280	et	4	main
sa	doc_901133458189_item	2933281	et	3	main
kus	doc_901133458189_item	2933285	et	3	main
tegite	doc_901133458189_item	2933289	et	3	main
kuidas	doc_901133458189_item	2933291	et	3	main
neile	doc_901133458189_item	2933292	et	4	main
narvas	doc_901133458189_item	2933293	et	4	main
meeldis	doc_901133458189_item	2933294	et	3	main
käisid	doc_901133458189_item	2933326	et	4	main
sugulased	doc_901133458189_item	2933328	et	3	main
tädi	doc_901133458189_item	2933330	et	4	main
neile	doc_901133458189_item	2933337	et	4	main
3	doc_901133458185_item	2932885	et	2	main
on	doc_901133458185_item	2932898	et	4	main
sinu	doc_901133458185_item	2932899	et	3	main
lemmiktegevus	doc_901133458185_item	2932900	et	4	main
kus	doc_901133458185_item	2932901	et	3	main
sa	doc_901133458185_item	2932902	et	3	main
suvel	doc_901133458185_item	2932903	et	3	main
mulle	doc_901133458185_item	2932910	et	4	main
meeldib	doc_901133458185_item	2932911	et	3	main
lahedata	doc_901133458185_item	2932912	et	3	main
sööma	doc_901133458185_item	2932914	et	4	main
järgmistele	doc_901133458186_item	2932921	et	3	main
oma	doc_901133458186_item	2932928	et	4	main
span	doc_901133458186_item	2932936	et	4	main
ma	doc_901133458186_item	2932945	et	3	main
narvas	doc_901133458186_item	2932947	et	4	main
asub	doc_901133458186_item	2932954	et	3	main
palju	doc_901133458186_item	2932955	et	4	main
raekoda	doc_901133458186_item	2932964	et	4	main
on	doc_901133458186_item	2932969	et	4	main
sinu	doc_901133458186_item	2932970	et	3	main
perekond	doc_901133458186_item	2932971	et	3	main
mingeid	doc_901133458186_item	2933001	et	3	main
hobisid	doc_901133458186_item	2933002	et	3	main
mis	doc_901133458186_item	2933003	et	4	main
sa	doc_901133458186_item	2933009	et	3	main
span	doc_901133458186_item	2933012	et	4	main
span	doc_901133458186_item	2933013	et	4	main
mille	doc_901133458186_item	2933014	et	3	main
uus	doc_901133458187_item	2933024	et	3	main
järgmistele	doc_901133458187_item	2933027	et	3	main
küsimustele	doc_901133458187_item	2933028	et	4	main
on	doc_901133458187_item	2933038	et	4	main
sinu	doc_901133458187_item	2933039	et	3	main
kodu	doc_901133458187_item	2933046	et	4	main
ja	doc_901133458187_item	2933047	et	3	main
on	doc_901133458187_item	2933056	et	4	main
väike	doc_901133458187_item	2933057	et	4	main
span	doc_901133458187_item	2933073	et	4	main
väike	doc_901133458187_item	2933081	et	4	main
jõgi	doc_901133458187_item	2933082	et	3	main
span	doc_901133458187_item	2933092	et	4	main
sinu	doc_901133458187_item	2933095	et	3	main
mingeid	doc_901133458187_item	2933125	et	3	main
span	doc_901133458187_item	2933136	et	4	main
span	doc_901133458187_item	2933137	et	4	main
ja	doc_901133458187_item	2933144	et	3	main
neile	doc_901133458189_item	2933282	et	4	main
käisite	doc_901133458189_item	2933287	et	3	main
tahan	doc_901133458189_item	2933321	et	3	main
onu	doc_901133458189_item	2933332	et	4	main
ma	doc_901133458189_item	2933336	et	3	main
näitasin	doc_901133458189_item	2933338	et	3	main
vaatamisväärsusi	doc_901133458189_item	2933341	et	4	main
ja	doc_901133458189_item	2933345	et	3	main
näitasime	doc_901133458189_item	2933346	et	3	main
me	doc_901133458189_item	2933352	et	4	main
kindlus	doc_901133458189_item	2933355	et	4	main
1	doc_901133458186_item	2932925	et	2	main
mis	doc_901133458186_item	2932931	et	4	main
missugune	doc_901133458186_item	2932937	et	3	main
kasvanud	doc_901133458186_item	2932951	et	4	main
loss	doc_901133458186_item	2932962	et	3	main
span	doc_901133458186_item	2932972	et	4	main
millega	doc_901133458186_item	2932973	et	3	main
tegelevad	doc_901133458186_item	2932974	et	4	main
sinu	doc_901133458186_item	2932975	et	3	main
pereliikmed	doc_901133458186_item	2932976	et	3	main
span	doc_901133458186_item	2932977	et	4	main
span	doc_901133458186_item	2932978	et	4	main
abiellusin	doc_901133458186_item	2932979	et	3	main
hiljuti	doc_901133458186_item	2932980	et	4	main
meil	doc_901133458186_item	2932981	et	4	main
ei	doc_901133458186_item	2932982	et	4	main
ole	doc_901133458186_item	2932983	et	4	main
veel	doc_901133458186_item	2932984	et	4	main
lapsi	doc_901133458186_item	2932985	et	4	main
abikaasa	doc_901133458186_item	2932986	et	4	main
igor	doc_901133458186_item	2932987	et	4	main
span	doc_901133458186_item	2932988	et	4	main
span	doc_901133458186_item	2932989	et	4	main
3	doc_901133458186_item	2932990	et	2	main
mida	doc_901133458186_item	2932991	et	4	main
sulle	doc_901133458186_item	2932992	et	3	main
meeldib	doc_901133458186_item	2932993	et	3	main
vabal	doc_901133458186_item	2932994	et	3	main
ajal	doc_901133458186_item	2932995	et	4	main
teha	doc_901133458186_item	2932996	et	3	main
span	doc_901133458186_item	2932997	et	4	main
kas	doc_901133458186_item	2932998	et	3	main
sul	doc_901133458186_item	2932999	et	3	main
on	doc_901133458186_item	2933000	et	4	main
kus	doc_901133458186_item	2933008	et	3	main
juuksuritöö	doc_901133458186_item	2933019	et	4	main
meeldib	doc_901133458186_item	2933020	et	3	main
väga	doc_901133458186_item	2933021	et	3	main
dokument	doc_901133458187_item	2933025	et	3	main
midagi	doc_901133458187_item	2933033	et	4	main
oma	doc_901133458187_item	2933034	et	4	main
kodulinnas	doc_901133458187_item	2933040	et	4	main
span	doc_901133458187_item	2933042	et	4	main
missugune	doc_901133458187_item	2933043	et	3	main
on	doc_901133458187_item	2933044	et	4	main
sinu	doc_901133458187_item	2933045	et	3	main
on	doc_901133458187_item	2933053	et	4	main
sillamäe	doc_901133458187_item	2933054	et	3	main
sillamäe	doc_901133458187_item	2933055	et	3	main
ja	doc_901133458187_item	2933067	et	3	main
linn	doc_901133458187_item	2933072	et	3	main
minu	doc_901133458187_item	2933074	et	3	main
ja	doc_901133458187_item	2933080	et	3	main
nii	doc_901133458187_item	2933083	et	3	main
span	doc_901133458187_item	2933086	et	4	main
milline	doc_901133458187_item	2933088	et	3	main
tegelevad	doc_901133458187_item	2933094	et	4	main
span	doc_901133458187_item	2933097	et	4	main
minu	doc_901133458187_item	2933099	et	3	main
perekond	doc_901133458187_item	2933100	et	3	main
ei	doc_901133458187_item	2933101	et	4	main
väga	doc_901133458187_item	2933102	et	3	main
suur	doc_901133458187_item	2933103	et	3	main
mul	doc_901133458187_item	2933104	et	3	main
on	doc_901133458187_item	2933105	et	4	main
kaks	doc_901133458187_item	2933106	et	3	main
last	doc_901133458187_item	2933107	et	4	main
ma	doc_901133458187_item	2933108	et	3	main
armastin	doc_901133458187_item	2933109	et	4	main
oma	doc_901133458187_item	2933110	et	4	main
lapsed	doc_901133458187_item	2933111	et	3	main
span	doc_901133458187_item	2933112	et	4	main
3	doc_901133458187_item	2933114	et	2	main
span	doc_901133458187_item	2933113	et	4	main
mida	doc_901133458187_item	2933115	et	4	main
sulle	doc_901133458187_item	2933116	et	3	main
meeldib	doc_901133458187_item	2933117	et	3	main
vabal	doc_901133458187_item	2933118	et	3	main
ajal	doc_901133458187_item	2933119	et	4	main
teha	doc_901133458187_item	2933120	et	3	main
span	doc_901133458187_item	2933121	et	4	main
hobisid	doc_901133458187_item	2933126	et	3	main
on	doc_901133458187_item	2933128	et	4	main
span	doc_901133458187_item	2933131	et	4	main
kus	doc_901133458187_item	2933132	et	3	main
sa	doc_901133458187_item	2933133	et	3	main
suvel	doc_901133458187_item	2933134	et	3	main
puhkad	doc_901133458187_item	2933135	et	3	main
kujutama	doc_901133458187_item	2933142	et	3	main
hobi	doc_901133458187_item	2933147	et	4	main
ma	doc_901133458187_item	2933150	et	3	main
puhkan	doc_901133458187_item	2933151	et	3	main
suvel	doc_901133458187_item	2933152	et	3	main
peipsijarv	doc_901133458187_item	2933153	et	4	main
kodulinnas	doc_901133458187_item	2933052	et	4	main
kõrval	doc_901133458187_item	2933062	et	4	main
siis	doc_901133458187_item	2933063	et	3	main
väike	doc_901133458187_item	2933065	et	4	main
on	doc_901133458187_item	2933070	et	4	main
ja	doc_901133458187_item	2933076	et	3	main
kasesalu	doc_901133458187_item	2933079	et	4	main
span	doc_901133458187_item	2933085	et	4	main
2	doc_901133458187_item	2933087	et	2	main
kas	doc_901133458187_item	2933122	et	3	main
siis	doc_901133458187_item	2933143	et	3	main
minu	doc_901133458187_item	2933146	et	3	main
nii	doc_901133458187_item	2933148	et	3	main
kirjuta	doc_901133458189_item	2933268	et	4	main
oma	doc_901133458189_item	2933269	et	4	main
sõbrale	doc_901133458189_item	2933270	et	3	main
kiri	doc_901133458189_item	2933271	et	3	main
sul	doc_901133458189_item	2933273	et	3	main
näitasid	doc_901133458189_item	2933283	et	4	main
rääkida	doc_901133458189_item	2933322	et	3	main
külas	doc_901133458189_item	2933327	et	3	main
ja	doc_901133458189_item	2933334	et	3	main
ja	doc_901133458189_item	2933349	et	3	main
skuulptuurid	doc_901133458189_item	2933350	et	4	main
pärast	doc_901133458189_item	2933351	et	4	main
hermanikindlus	doc_901133458189_item	2933354	et	4	main
neile	doc_901133458189_item	2933356	et	4	main
meeldis	doc_901133458189_item	2933358	et	3	main
käisime	doc_901133458189_item	2933375	et	3	main
me	doc_901133458189_item	2933379	et	4	main
sõitsime	doc_901133458189_item	2933380	et	3	main
poolt	doc_901133458189_item	2933411	et	4	main
kiri	doc_901133458190_item	2933421	et	3	main
sõbrale	doc_901133458190_item	2933425	et	3	main
kursustel	doc_901133458190_item	2933433	et	3	main
et	doc_901133458190_item	2933436	et	3	main
lähete	doc_901133458190_item	2933438	et	4	main
kirjuta	doc_901133458190_item	2933440	et	4	main
mis	doc_901133458190_item	2933445	et	4	main
firma	doc_901133458190_item	2933446	et	4	main
see	doc_901133458190_item	2933447	et	3	main
xxxxx	doc_901133458190_item	2933455	et	4	main
sain	doc_901133458190_item	2933456	et	3	main
kätte	doc_901133458190_item	2933457	et	4	main
sinu	doc_901133458190_item	2933458	et	3	main
kõik	doc_901133458190_item	2933465	et	4	main
tead	doc_901133458190_item	2933480	et	4	main
juba	doc_901133458190_item	2933493	et	3	main
asjaajamist	doc_901133458190_item	2933497	et	4	main
alused	doc_901133458190_item	2933523	et	4	main
väike	doc_901133458190_item	2933539	et	4	main
toidupood	doc_901133458190_item	2933540	et	3	main
leppime	doc_901133458190_item	2933546	et	4	main
head	doc_901133458190_item	2933574	et	4	main
on	doc_901133458187_item	2933124	et	4	main
ääres	doc_901133458187_item	2933154	et	4	main
span	doc_901133458187_item	2933155	et	4	main
käisid	doc_901133458189_item	2933274	et	4	main
kirjuta	doc_901133458189_item	2933277	et	4	main
te	doc_901133458189_item	2933286	et	4	main
ja	doc_901133458189_item	2933290	et	3	main
uus	doc_901133458189_item	2933266	et	3	main
dokument	doc_901133458189_item	2933267	et	3	main
külas	doc_901133458189_item	2933275	et	3	main
sugulased	doc_901133458189_item	2933276	et	3	main
missuguseid	doc_901133458189_item	2933278	et	3	main
kirjuta	doc_901133458189_item	2933284	et	4	main
mida	doc_901133458189_item	2933288	et	4	main
kirja	doc_901133458189_item	2933295	et	4	main
pikkus	doc_901133458189_item	2933296	et	4	main
kuni	doc_901133458189_item	2933297	et	3	main
100	doc_901133458189_item	2933298	et	2	main
sõna	doc_901133458189_item	2933299	et	4	main
tere	doc_901133458189_item	2933300	et	3	main
minu	doc_901133458189_item	2933301	et	3	main
kallis	doc_901133458189_item	2933302	et	4	main
sõbranna	doc_901133458189_item	2933303	et	4	main
olga	doc_901133458189_item	2933304	et	4	main
kuidas	doc_901133458189_item	2933305	et	3	main
läheb	doc_901133458189_item	2933306	et	3	main
miks	doc_901133458189_item	2933307	et	4	main
sa	doc_901133458189_item	2933308	et	3	main
pole	doc_901133458189_item	2933309	et	3	main
nii	doc_901133458189_item	2933310	et	3	main
kirjutanud	doc_901133458189_item	2933312	et	4	main
ammu	doc_901133458189_item	2933311	et	4	main
ma	doc_901133458189_item	2933313	et	3	main
elan	doc_901133458189_item	2933314	et	3	main
hästi	doc_901133458189_item	2933315	et	3	main
mul	doc_901133458189_item	2933316	et	3	main
on	doc_901133458189_item	2933317	et	4	main
kõik	doc_901133458189_item	2933318	et	4	main
korras	doc_901133458189_item	2933319	et	4	main
ma	doc_901133458189_item	2933320	et	3	main
sulle	doc_901133458189_item	2933323	et	3	main
mul	doc_901133458189_item	2933325	et	3	main
minu	doc_901133458189_item	2933329	et	3	main
ja	doc_901133458189_item	2933331	et	3	main
huvitava	doc_901133458189_item	2933362	et	4	main
sõitsib	doc_901133458189_item	2933370	et	4	main
tivoli	doc_901133458189_item	2933371	et	4	main
park	doc_901133458189_item	2933372	et	3	main
me	doc_901133458189_item	2933373	et	4	main
veerema	doc_901133458189_item	2933376	et	4	main
head	doc_901133458189_item	2933414	et	4	main
käid	doc_901133458190_item	2933427	et	3	main
sa	doc_901133458190_item	2933432	et	3	main
kirja	doc_901133458190_item	2933459	et	4	main
väga	doc_901133458190_item	2933460	et	3	main
meeldiv	doc_901133458190_item	2933461	et	4	main
uudise	doc_901133458190_item	2933471	et	3	main
ma	doc_901133458190_item	2933473	et	3	main
kliendi	doc_901133458190_item	2933475	et	3	main
ma	doc_901133458190_item	2933482	et	3	main
olen	doc_901133458190_item	2933483	et	3	main
ettevõtluse	doc_901133458190_item	2933522	et	3	main
ett	doc_901133458189_item	2933324	et	3	main
onupoeg	doc_901133458189_item	2933333	et	3	main
onutütar	doc_901133458189_item	2933335	et	3	main
narva	doc_901133458189_item	2933340	et	4	main
me	doc_901133458189_item	2933342	et	4	main
käisime	doc_901133458189_item	2933343	et	3	main
kunstigaaleriis	doc_901133458189_item	2933344	et	3	main
iidned	doc_901133458189_item	2933347	et	4	main
käisime	doc_901133458189_item	2933353	et	3	main
ekskursiooni	doc_901133458189_item	2933363	et	4	main
õhtul	doc_901133458189_item	2933364	et	3	main
tumeaes	doc_901133458189_item	2933367	et	4	main
eile	doc_901133458189_item	2933368	et	3	main
linnas	doc_901133458189_item	2933369	et	4	main
sugulasega	doc_901133458189_item	2933374	et	3	main
uiutasime	doc_901133458189_item	2933382	et	4	main
meeres	doc_901133458189_item	2933383	et	3	main
narvas	doc_901133458189_item	2933384	et	4	main
neile	doc_901133458189_item	2933385	et	4	main
meeldis	doc_901133458189_item	2933386	et	3	main
kõik	doc_901133458189_item	2933387	et	4	main
galeeri	doc_901133458189_item	2933388	et	4	main
kindlus	doc_901133458189_item	2933389	et	4	main
ja	doc_901133458189_item	2933390	et	3	main
teine	doc_901133458189_item	2933391	et	3	main
sellega	doc_901133458189_item	2933392	et	3	main
lõpetan	doc_901133458189_item	2933393	et	3	main
sõita	doc_901133458189_item	2933394	et	3	main
ja	doc_901133458189_item	2933395	et	3	main
sina	doc_901133458189_item	2933396	et	4	main
minul	doc_901133458189_item	2933397	et	3	main
kõik	doc_901133458189_item	2933398	et	4	main
sa	doc_901133458189_item	2933399	et	3	main
näitad	doc_901133458189_item	2933400	et	3	main
mis	doc_901133458189_item	2933401	et	4	main
sul	doc_901133458189_item	2933402	et	3	main
uudist	doc_901133458189_item	2933403	et	3	main
ootan	doc_901133458189_item	2933404	et	3	main
sinu	doc_901133458189_item	2933405	et	3	main
vastust	doc_901133458189_item	2933406	et	4	main
kirjuta	doc_901133458189_item	2933407	et	4	main
ruttu	doc_901133458189_item	2933408	et	4	main
tervita	doc_901133458189_item	2933409	et	4	main
minu	doc_901133458189_item	2933410	et	3	main
missuguseid	doc_901133458189_item	2933339	et	3	main
piildid	doc_901133458189_item	2933348	et	4	main
väga	doc_901133458189_item	2933357	et	3	main
nendele	doc_901133458189_item	2933360	et	4	main
teesid	doc_901133458189_item	2933361	et	4	main
me	doc_901133458189_item	2933365	et	4	main
käisime	doc_901133458189_item	2933366	et	3	main
kiikil	doc_901133458189_item	2933377	et	4	main
pärast	doc_901133458189_item	2933378	et	4	main
narva-jõesuu	doc_901133458189_item	2933381	et	4	main
aega	doc_901133458189_item	2933415	et	4	main
sõbranna	doc_901133458189_item	2933417	et	4	main
oma	doc_901133458190_item	2933423	et	4	main
eestlasest	doc_901133458190_item	2933424	et	3	main
mida	doc_901133458190_item	2933431	et	4	main
õpid	doc_901133458190_item	2933434	et	4	main
ja	doc_901133458190_item	2933435	et	3	main
varsti	doc_901133458190_item	2933437	et	3	main
kuhu	doc_901133458190_item	2933441	et	3	main
praktikale	doc_901133458190_item	2933443	et	3	main
seal	doc_901133458190_item	2933451	et	4	main
tegema	doc_901133458190_item	2933452	et	3	main
hakkad	doc_901133458190_item	2933453	et	3	main
et	doc_901133458190_item	2933462	et	3	main
aga	doc_901133458190_item	2933467	et	3	main
kirjutan	doc_901133458190_item	2933469	et	3	main
praegu	doc_901133458190_item	2933472	et	3	main
teenindaja	doc_901133458190_item	2933476	et	4	main
kursustel	doc_901133458190_item	2933477	et	3	main
sa	doc_901133458190_item	2933478	et	3	main
ju	doc_901133458190_item	2933479	et	3	main
praegu	doc_901133458190_item	2933485	et	3	main
tööhõiveamet	doc_901133458190_item	2933487	et	3	main
me	doc_901133458190_item	2933491	et	4	main
arvutit	doc_901133458190_item	2933494	et	3	main
ka	doc_901133458190_item	2933525	et	3	main
käiss	doc_901133458190_item	2933527	et	4	main
kodu	doc_901133458190_item	2933536	et	4	main
ma	doc_901133458190_item	2933542	et	3	main
töötan	doc_901133458190_item	2933552	et	3	main
poolteist	doc_901133458190_item	2933554	et	4	main
kui	doc_901133458190_item	2933556	et	3	main
töötan	doc_901133458190_item	2933557	et	3	main
hästi	doc_901133458190_item	2933558	et	3	main
siis	doc_901133458190_item	2933559	et	3	main
võib	doc_901133458190_item	2933560	et	3	main
olla	doc_901133458190_item	2933561	et	3	main
ta	doc_901133458190_item	2933562	et	4	main
võtab	doc_901133458190_item	2933563	et	3	main
praktikat	doc_901133458190_item	2933567	et	3	main
mul	doc_901133458190_item	2933569	et	3	main
ja	doc_901133458192_item	2933725	et	3	main
et	doc_901133458192_item	2933726	et	3	main
praktikale	doc_901133458192_item	2933729	et	3	main
lähed	doc_901133458192_item	2933734	et	3	main
on	doc_901133458192_item	2933738	et	4	main
hakkad	doc_901133458192_item	2933743	et	3	main
kursusest	doc_901133458192_item	2933750	et	4	main
ma	doc_901133458192_item	2933752	et	3	main
kindlus	doc_901133458189_item	2933359	et	4	main
sinu	doc_901133458189_item	2933416	et	3	main
xxxxxxx	doc_901133458189_item	2933418	et	4	main
uus	doc_901133458190_item	2933419	et	3	main
dokument	doc_901133458190_item	2933420	et	3	main
oma	doc_901133458189_item	2933412	et	4	main
abikaasat	doc_901133458189_item	2933413	et	3	main
praegu	doc_901133458190_item	2933428	et	3	main
kursustel	doc_901133458190_item	2933429	et	3	main
praktikale	doc_901133458190_item	2933439	et	3	main
sa	doc_901133458190_item	2933442	et	3	main
lähed	doc_901133458190_item	2933444	et	3	main
tere	doc_901133458190_item	2933454	et	3	main
sul	doc_901133458190_item	2933463	et	3	main
hästi	doc_901133458190_item	2933466	et	3	main
nüüd	doc_901133458190_item	2933468	et	4	main
ühe	doc_901133458190_item	2933470	et	4	main
käin	doc_901133458190_item	2933474	et	3	main
aga	doc_901133458190_item	2933486	et	3	main
organiseeris	doc_901133458190_item	2933488	et	3	main
kursusteid	doc_901133458190_item	2933490	et	3	main
õppisime	doc_901133458190_item	2933492	et	3	main
eesti	doc_901133458190_item	2933495	et	4	main
keelt	doc_901133458190_item	2933496	et	4	main
aga	doc_901133458190_item	2933521	et	3	main
tore	doc_901133458190_item	2933530	et	3	main
inimene	doc_901133458190_item	2933531	et	3	main
praktikale	doc_901133458190_item	2933534	et	3	main
kõrval	doc_901133458190_item	2933537	et	4	main
on	doc_901133458190_item	2933538	et	4	main
praktikale	doc_901133458190_item	2933545	et	3	main
mind	doc_901133458190_item	2933564	et	4	main
kõike	doc_901133458190_item	2933573	et	4	main
xxxxx	doc_901133458190_item	2933576	et	4	main
õpid	doc_901133458192_item	2933724	et	4	main
firma	doc_901133458192_item	2933736	et	4	main
sa	doc_901133458192_item	2933740	et	3	main
tere	doc_901133458192_item	2933744	et	3	main
oma	doc_901133458192_item	2933749	et	4	main
praegu	doc_901133458192_item	2933751	et	3	main
käin	doc_901133458192_item	2933753	et	3	main
pealkiri	doc_901133458192_item	2933756	et	3	main
veel	doc_901133458192_item	2933761	et	4	main
inimisi	doc_901133458192_item	2933764	et	4	main
arvan	doc_901133458192_item	2933766	et	3	main
et	doc_901133458192_item	2933767	et	3	main
nad	doc_901133458192_item	2933768	et	3	main
sühtlime	doc_901133458192_item	2933774	et	4	main
me	doc_901133458192_item	2933784	et	4	main
õppisime	doc_901133458192_item	2933785	et	3	main
turundus	doc_901133458192_item	2933792	et	3	main
palju	doc_901133458192_item	2933795	et	4	main
muud	doc_901133458192_item	2933796	et	4	main
istun	doc_901133458192_item	2933799	et	3	main
kirjuta	doc_901133458190_item	2933422	et	4	main
et	doc_901133458190_item	2933426	et	3	main
kirjuta	doc_901133458190_item	2933430	et	4	main
on	doc_901133458190_item	2933448	et	4	main
mida	doc_901133458190_item	2933449	et	4	main
sa	doc_901133458190_item	2933450	et	3	main
on	doc_901133458190_item	2933464	et	4	main
et	doc_901133458190_item	2933481	et	3	main
töötu	doc_901133458190_item	2933484	et	4	main
need	doc_901133458190_item	2933489	et	3	main
tarbijakaitsest	doc_901133458190_item	2933498	et	4	main
esmaabit	doc_901133458190_item	2933499	et	4	main
müüki	doc_901133458190_item	2933500	et	4	main
ja	doc_901133458190_item	2933501	et	3	main
turundust	doc_901133458190_item	2933502	et	3	main
ettevõtluse	doc_901133458190_item	2933503	et	3	main
alust	doc_901133458190_item	2933504	et	4	main
kõige	doc_901133458190_item	2933505	et	4	main
rohkem	doc_901133458190_item	2933506	et	4	main
mulle	doc_901133458190_item	2933507	et	4	main
meeldis	doc_901133458190_item	2933508	et	3	main
arvutit	doc_901133458190_item	2933509	et	3	main
ja	doc_901133458190_item	2933510	et	3	main
keelt	doc_901133458190_item	2933512	et	4	main
nüüd	doc_901133458190_item	2933513	et	4	main
ma	doc_901133458190_item	2933514	et	3	main
eesti	doc_901133458190_item	2933511	et	4	main
saan	doc_901133458190_item	2933515	et	4	main
kirjutada	doc_901133458190_item	2933516	et	3	main
sulle	doc_901133458190_item	2933517	et	3	main
eesti	doc_901133458190_item	2933518	et	4	main
keele	doc_901133458190_item	2933519	et	4	main
kirja	doc_901133458190_item	2933520	et	4	main
väga	doc_901133458190_item	2933529	et	3	main
läheme	doc_901133458190_item	2933533	et	3	main
minu	doc_901133458190_item	2933535	et	3	main
siia	doc_901133458190_item	2933541	et	4	main
sooviksin	doc_901133458190_item	2933543	et	3	main
peremehega	doc_901133458190_item	2933547	et	3	main
kokku	doc_901133458190_item	2933548	et	3	main
ja	doc_901133458190_item	2933549	et	3	main
meeldis	doc_901133458190_item	2933524	et	3	main
enn	doc_901133458190_item	2933526	et	4	main
õpetab	doc_901133458190_item	2933528	et	3	main
varsti	doc_901133458190_item	2933532	et	3	main
minema	doc_901133458190_item	2933544	et	3	main
siis	doc_901133458190_item	2933550	et	3	main
kuut	doc_901133458190_item	2933555	et	4	main
pärast	doc_901133458190_item	2933566	et	4	main
rohkem	doc_901133458190_item	2933568	et	4	main
ei	doc_901133458190_item	2933571	et	4	main
ole	doc_901133458190_item	2933572	et	4	main
mida	doc_901133458192_item	2933721	et	4	main
kirjuta	doc_901133458192_item	2933730	et	4	main
praktikale	doc_901133458192_item	2933733	et	3	main
mis	doc_901133458192_item	2933735	et	4	main
tegema	doc_901133458192_item	2933742	et	3	main
kirjutada	doc_901133458192_item	2933747	et	3	main
koik	doc_901133458192_item	2933770	et	4	main
head	doc_901133458192_item	2933771	et	4	main
praktikale	doc_901133458192_item	2933821	et	3	main
ma	doc_901133458192_item	2933823	et	3	main
kliendiga	doc_901133458192_item	2933825	et	3	main
10-kroonise	doc_910290104792_item	2933840	et	4	main
rahatähe	doc_910290104792_item	2933841	et	3	main
panus	doc_910290104792_item	2933856	et	4	main
kujutatud	doc_910290104792_item	2933865	et	4	main
eesti	doc_910290104792_item	2933884	et	4	main
rahvale	doc_910290104792_item	2933885	et	3	main
1864	doc_910290104792_item	2933886	et	2	main
tihedat	doc_910290104792_item	2933922	et	3	main
vahel	doc_910290104792_item	2933929	et	4	main
tekkisid	doc_910290104792_item	2933930	et	4	main
konfliktid	doc_910290104792_item	2933931	et	3	main
jakobson	doc_910290104792_item	2933936	et	4	main
et	doc_910290104792_item	2933944	et	3	main
olnud	doc_910290104792_item	2933957	et	4	main
sellega	doc_910290104792_item	2933958	et	3	main
ja	doc_910290104792_item	2933970	et	3	main
oli	doc_910290104792_item	2933982	et	3	main
põhimõttet	doc_910290104792_item	2933984	et	4	main
kohal	doc_910290104792_item	2933991	et	4	main
suunatud	doc_910290104792_item	2934004	et	4	main
ning	doc_910290104792_item	2934007	et	3	main
venemaal	doc_910290104792_item	2934009	et	4	main
ma	doc_901133458190_item	2933551	et	3	main
müüjana	doc_901133458190_item	2933553	et	4	main
tööle	doc_901133458190_item	2933565	et	3	main
uudiseid	doc_901133458190_item	2933570	et	3	main
21112003	doc_901133458190_item	2933575	et	2	main
kiri	doc_901133458192_item	2933711	et	3	main
kirjuta	doc_901133458192_item	2933712	et	4	main
oma	doc_901133458192_item	2933713	et	4	main
eestlasest	doc_901133458192_item	2933714	et	3	main
sõbrale	doc_901133458192_item	2933715	et	3	main
et	doc_901133458192_item	2933716	et	3	main
käid	doc_901133458192_item	2933717	et	3	main
praegu	doc_901133458192_item	2933718	et	3	main
kursustel	doc_901133458192_item	2933719	et	3	main
kirjuta	doc_901133458192_item	2933720	et	4	main
kursustel	doc_901133458192_item	2933723	et	3	main
lähete	doc_901133458192_item	2933728	et	4	main
see	doc_901133458192_item	2933737	et	3	main
elina	doc_901133458192_item	2933745	et	4	main
tahan	doc_901133458192_item	2933746	et	3	main
koos	doc_901133458192_item	2933760	et	4	main
me	doc_901133458192_item	2933772	et	4	main
palju	doc_901133458192_item	2933782	et	4	main
kirja	doc_901133458192_item	2933807	et	4	main
seal	doc_901133458192_item	2933822	et	4	main
head	doc_901133458192_item	2933827	et	4	main
aega	doc_901133458192_item	2933828	et	4	main
1	doc_910290104792_item	2933833	et	2	main
milline	doc_910290104792_item	2933834	et	3	main
ärkamisaja	doc_910290104792_item	2933835	et	3	main
kultuuritegelane	doc_910290104792_item	2933836	et	3	main
on	doc_910290104792_item	2933837	et	4	main
mida	doc_910290104792_item	2933843	et	4	main
kes	doc_910290104792_item	2933849	et	4	main
nende	doc_910290104792_item	2933855	et	4	main
1	doc_910290104792_item	2933859	et	2	main
eesti	doc_910290104792_item	2933860	et	4	main
10-kroonise	doc_910290104792_item	2933861	et	4	main
rahatähe	doc_910290104792_item	2933862	et	3	main
jakob	doc_910290104792_item	2933866	et	4	main
hurt	doc_910290104792_item	2933867	et	3	main
aleksandrikooli	doc_910290104792_item	2933871	et	4	main
liikumise	doc_910290104792_item	2933872	et	4	main
liidriks	doc_910290104792_item	2933873	et	3	main
väga	doc_910290104792_item	2933877	et	3	main
oluline	doc_910290104792_item	2933878	et	4	main
a	doc_910290104792_item	2933887	et	4	main
eesti	doc_910290104792_item	2933893	et	4	main
kus	doc_910290104792_item	2933895	et	3	main
koostööd	doc_910290104792_item	2933923	et	4	main
hakkas	doc_910290104792_item	2933935	et	3	main
mis	doc_910290104792_item	2933941	et	4	main
ei	doc_910290104792_item	2933956	et	4	main
meelest	doc_910290104792_item	2933963	et	4	main
religioon	doc_910290104792_item	2933964	et	3	main
oli	doc_910290104792_item	2933965	et	3	main
väga	doc_910290104792_item	2933966	et	3	main
lõhe	doc_910290104792_item	2933979	et	4	main
mille	doc_910290104792_item	2933980	et	3	main
kultuur	doc_910290104792_item	2933988	et	3	main
pöörde	doc_910290104792_item	2933999	et	3	main
saavutamine	doc_910290104792_item	2934000	et	4	main
j	doc_910290104792_item	2934001	et	4	main
hurt	doc_910290104792_item	2934002	et	3	main
oli	doc_910290104792_item	2934003	et	3	main
ei	doc_910290104792_item	2934018	et	4	main
ajalehes	doc_910290104792_item	2934022	et	3	main
j	doc_910290104792_item	2934023	et	4	main
eesti	doc_910290104792_item	2934038	et	4	main
kultuuris	doc_910290104792_item	2934045	et	3	main
selles	doc_910290104792_item	2934047	et	4	main
parandada	doc_910290104792_item	2934049	et	3	main
tuntuimaid	doc_910290104792_item	2934052	et	4	main
neist	doc_910290104792_item	2934053	et	4	main
oli	doc_910290104792_item	2934054	et	3	main
kes	doc_910290104792_item	2934060	et	4	main
et	doc_910290104792_item	2934064	et	3	main
kirjutas	doc_910290104792_item	2934069	et	3	main
korda	doc_910290104792_item	2934075	et	4	main
arvates	doc_910290104792_item	2934087	et	4	main
eesti	doc_910290104792_item	2934097	et	4	main
kontrolltöö	doc_910290104793_item	2934110	et	4	main
eesti	doc_910290104793_item	2934119	et	4	main
peal	doc_910290104793_item	2934122	et	4	main
teate	doc_910290104793_item	2934127	et	4	main
panus	doc_910290104793_item	2934136	et	4	main
sa	doc_901133458192_item	2933722	et	3	main
varsti	doc_901133458192_item	2933727	et	3	main
kuhu	doc_901133458192_item	2933731	et	3	main
sa	doc_901133458192_item	2933732	et	3	main
mida	doc_901133458192_item	2933739	et	4	main
seal	doc_901133458192_item	2933741	et	4	main
sinule	doc_901133458192_item	2933748	et	3	main
kursusel	doc_901133458192_item	2933754	et	3	main
on	doc_901133458192_item	2933757	et	4	main
klienditenindaja	doc_901133458192_item	2933758	et	4	main
minuga	doc_901133458192_item	2933759	et	3	main
käivad	doc_901133458192_item	2933762	et	4	main
ma	doc_901133458192_item	2933765	et	3	main
on	doc_901133458192_item	2933769	et	4	main
ja	doc_901133458192_item	2933775	et	3	main
õppime	doc_901133458192_item	2933776	et	4	main
sellel	doc_901133458192_item	2933777	et	4	main
kursusel	doc_901133458192_item	2933778	et	3	main
ma	doc_901133458192_item	2933779	et	3	main
sain	doc_901133458192_item	2933780	et	3	main
teada	doc_901133458192_item	2933781	et	3	main
arvuti	doc_901133458192_item	2933786	et	4	main
müük	doc_901133458192_item	2933789	et	3	main
ja	doc_901133458192_item	2933790	et	3	main
vee	doc_901133458192_item	2933794	et	3	main
ma	doc_901133458192_item	2933798	et	3	main
millal	doc_901133458192_item	2933808	et	3	main
kursused	doc_901133458192_item	2933809	et	3	main
lõppetavav	doc_901133458192_item	2933810	et	4	main
ma	doc_901133458192_item	2933811	et	3	main
lahen	doc_901133458192_item	2933812	et	4	main
praktikale	doc_901133458192_item	2933813	et	3	main
ma	doc_901133458192_item	2933814	et	3	main
arvan	doc_901133458192_item	2933815	et	3	main
et	doc_901133458192_item	2933816	et	3	main
ma	doc_901133458192_item	2933817	et	3	main
lähen	doc_901133458192_item	2933818	et	3	main
ilu	doc_901133458192_item	2933819	et	4	main
salongis	doc_901133458192_item	2933820	et	3	main
kontrolltöö	doc_910290104792_item	2933830	et	4	main
eesti	doc_910290104792_item	2933839	et	4	main
tema	doc_910290104792_item	2933845	et	4	main
milline	doc_910290104792_item	2933853	et	3	main
kultuurilukku	doc_910290104792_item	2933858	et	4	main
on	doc_910290104792_item	2933864	et	4	main
1839-1907	doc_910290104792_item	2933868	et	2	main
oli	doc_910290104792_item	2933870	et	3	main
meelest	doc_910290104792_item	2933876	et	4	main
oli	doc_910290104792_item	2933879	et	3	main
vaimnekultuur	doc_910290104792_item	2933880	et	4	main
ja	doc_910290104792_item	2933881	et	3	main
rahvaluule	doc_910290104792_item	2933882	et	4	main
tagasiandmine	doc_910290104792_item	2933883	et	3	main
ajalehte	doc_910290104792_item	2933892	et	4	main
see	doc_901133458192_item	2933755	et	3	main
palju	doc_901133458192_item	2933763	et	4	main
palju	doc_901133458192_item	2933773	et	4	main
huvitavat	doc_901133458192_item	2933783	et	4	main
psüholoogijat	doc_901133458192_item	2933787	et	4	main
esmaabijat	doc_901133458192_item	2933788	et	4	main
aktiivne	doc_901133458192_item	2933791	et	3	main
ja	doc_901133458192_item	2933793	et	3	main
praigu	doc_901133458192_item	2933797	et	4	main
keele	doc_901133458192_item	2933801	et	4	main
kontrolltöö	doc_910290104792_item	2933829	et	4	main
kujutatud	doc_910290104792_item	2933838	et	4	main
te	doc_910290104792_item	2933844	et	4	main
olid	doc_910290104792_item	2933850	et	4	main
estofiilid	doc_910290104792_item	2933851	et	3	main
ja	doc_910290104792_item	2933852	et	3	main
peal	doc_910290104792_item	2933863	et	4	main
kes	doc_910290104792_item	2933869	et	4	main
hurda	doc_910290104792_item	2933875	et	3	main
hakkas	doc_910290104792_item	2933889	et	3	main
välja	doc_910290104792_item	2933890	et	4	main
andma	doc_910290104792_item	2933891	et	3	main
postimees	doc_910290104792_item	2933894	et	4	main
nende	doc_910290104792_item	2933928	et	4	main
välja	doc_910290104792_item	2933937	et	4	main
äratas	doc_910290104792_item	2933945	et	3	main
oma	doc_910290104792_item	2933948	et	4	main
eest	doc_910290104792_item	2933950	et	4	main
kritiseeris	doc_910290104792_item	2933951	et	3	main
ka	doc_910290104792_item	2933952	et	3	main
kirikut	doc_910290104792_item	2933953	et	3	main
sest	doc_910290104792_item	2933961	et	4	main
tähtis	doc_910290104792_item	2933967	et	4	main
vastaspervedel	doc_910290104792_item	2933981	et	3	main
2	doc_910290104792_item	2933983	et	2	main
jaoks	doc_910290104792_item	2933987	et	4	main
esimesel	doc_910290104792_item	2933990	et	3	main
arvates	doc_910290104792_item	2933993	et	4	main
kõige	doc_910290104792_item	2933994	et	4	main
jakobsoni	doc_910290104792_item	2934011	et	4	main
ta	doc_910290104792_item	2934013	et	4	main
hurt	doc_910290104792_item	2934024	et	3	main
panuse	doc_910290104792_item	2934027	et	3	main
kes	doc_910290104792_item	2934036	et	4	main
rahva	doc_910290104792_item	2934044	et	3	main
j	doc_910290104792_item	2934055	et	4	main
merkel	doc_910290104792_item	2934068	et	4	main
raamatu	doc_910290104792_item	2934070	et	4	main
muinasajast	doc_910290104792_item	2934072	et	4	main
ristitamine	doc_910290104792_item	2934080	et	4	main
oli	doc_910290104792_item	2934081	et	3	main
võib	doc_910290104792_item	2934088	et	3	main
pidada	doc_910290104792_item	2934090	et	4	main
sest	doc_910290104792_item	2934092	et	4	main
siinsete	doc_910290104792_item	2934095	et	4	main
inimestele	doc_910290104792_item	2934096	et	3	main
laiendas	doc_910290104792_item	2934103	et	3	main
mõjutas	doc_910290104792_item	2934107	et	3	main
10-kroonise	doc_910290104793_item	2934120	et	4	main
eesti	doc_901133458192_item	2933800	et	4	main
eksamenisse	doc_901133458192_item	2933802	et	4	main
ja	doc_901133458192_item	2933803	et	3	main
välja	doc_901133458192_item	2933804	et	4	main
mõtlen	doc_901133458192_item	2933805	et	3	main
sinule	doc_901133458192_item	2933806	et	3	main
hakkan	doc_901133458192_item	2933824	et	3	main
sühtlema	doc_901133458192_item	2933826	et	4	main
eesti	doc_910290104792_item	2933831	et	4	main
kultuuriloost	doc_910290104792_item	2933832	et	4	main
peal	doc_910290104792_item	2933842	et	4	main
tegevusest	doc_910290104792_item	2933846	et	4	main
teate	doc_910290104792_item	2933847	et	4	main
2	doc_910290104792_item	2933848	et	2	main
oli	doc_910290104792_item	2933854	et	3	main
eesti	doc_910290104792_item	2933857	et	4	main
j	doc_910290104792_item	2933874	et	4	main
jannsen	doc_910290104792_item	2933888	et	4	main
töötas	doc_910290104792_item	2933896	et	3	main
nii	doc_910290104792_item	2933897	et	3	main
hurt	doc_910290104792_item	2933898	et	3	main
kui	doc_910290104792_item	2933899	et	3	main
ka	doc_910290104792_item	2933900	et	3	main
c	doc_910290104792_item	2933901	et	4	main
r	doc_910290104792_item	2933902	et	4	main
jakobson	doc_910290104792_item	2933903	et	4	main
kuid	doc_910290104792_item	2933904	et	4	main
jannsen	doc_910290104792_item	2933905	et	4	main
suunatud	doc_910290104792_item	2933907	et	4	main
oli	doc_910290104792_item	2933906	et	3	main
ajalehe	doc_910290104792_item	2933908	et	3	main
juurest	doc_910290104792_item	2933909	et	4	main
eemaldama	doc_910290104792_item	2933910	et	3	main
neid	doc_910290104792_item	2933911	et	4	main
mõlemaid	doc_910290104792_item	2933912	et	3	main
nii	doc_910290104792_item	2933913	et	3	main
sattusid	doc_910290104792_item	2933914	et	4	main
jakobson	doc_910290104792_item	2933915	et	4	main
ja	doc_910290104792_item	2933916	et	3	main
hurt	doc_910290104792_item	2933917	et	3	main
ajalehe	doc_910290104792_item	2933918	et	3	main
väljapoole	doc_910290104792_item	2933919	et	3	main
mis	doc_910290104792_item	2933920	et	4	main
tingis	doc_910290104792_item	2933921	et	3	main
kuid	doc_910290104792_item	2933926	et	4	main
ka	doc_910290104792_item	2933927	et	3	main
a	doc_910290104792_item	2933934	et	4	main
sakala	doc_910290104792_item	2933939	et	4	main
ajalehte	doc_910290104792_item	2933940	et	4	main
lisaks	doc_910290104792_item	2933942	et	4	main
rahvast	doc_910290104792_item	2933946	et	4	main
võitlusele	doc_910290104792_item	2933947	et	3	main
kuidagi	doc_910290104792_item	2933959	et	3	main
nõus	doc_910290104792_item	2933960	et	4	main
säilitamiseks	doc_910290104792_item	2933969	et	4	main
määrav	doc_910290104792_item	2933972	et	4	main
j	doc_910290104792_item	2933985	et	4	main
jakobsoni	doc_910290104792_item	2933992	et	4	main
sotsiaal-majandusliku	doc_910290104792_item	2933998	et	3	main
eestist	doc_910290104792_item	2934005	et	3	main
pärast	doc_910290104792_item	2934010	et	4	main
epigrammi	doc_910290104792_item	2934015	et	4	main
kuid	doc_910290104792_item	2934016	et	4	main
nende	doc_910290104792_item	2933924	et	4	main
vahel	doc_910290104792_item	2933925	et	4	main
nimelt	doc_910290104792_item	2933932	et	4	main
1878	doc_910290104792_item	2933933	et	2	main
andma	doc_910290104792_item	2933938	et	3	main
sellele	doc_910290104792_item	2933943	et	4	main
õiguste	doc_910290104792_item	2933949	et	4	main
j	doc_910290104792_item	2933954	et	4	main
hurt	doc_910290104792_item	2933955	et	3	main
tema	doc_910290104792_item	2933962	et	4	main
kõlbluse	doc_910290104792_item	2933968	et	4	main
vaimuelu	doc_910290104792_item	2933971	et	4	main
jõud	doc_910290104792_item	2933973	et	4	main
nii	doc_910290104792_item	2933974	et	3	main
tekkis	doc_910290104792_item	2933975	et	3	main
rahvuse	doc_910290104792_item	2933976	et	3	main
liikumises	doc_910290104792_item	2933977	et	4	main
suur	doc_910290104792_item	2933978	et	3	main
hurda	doc_910290104792_item	2933986	et	3	main
oli	doc_910290104792_item	2933989	et	3	main
tähtsam	doc_910290104792_item	2933995	et	4	main
oli	doc_910290104792_item	2933996	et	3	main
aga	doc_910290104792_item	2933997	et	3	main
lahkuda	doc_910290104792_item	2934006	et	3	main
töötas	doc_910290104792_item	2934008	et	3	main
surma	doc_910290104792_item	2934012	et	4	main
kirjutas	doc_910290104792_item	2934014	et	3	main
olnud	doc_910290104792_item	2934019	et	4	main
avaldatud	doc_910290104792_item	2934020	et	4	main
kultuuri	doc_910290104792_item	2934029	et	4	main
2	doc_910290104792_item	2934031	et	2	main
eestofilid	doc_910290104792_item	2934032	et	4	main
olid	doc_910290104792_item	2934033	et	4	main
need	doc_910290104792_item	2934034	et	3	main
inimesed	doc_910290104792_item	2934035	et	3	main
keelest	doc_910290104792_item	2934041	et	4	main
et	doc_910290104792_item	2934048	et	3	main
talupoegade	doc_910290104792_item	2934050	et	3	main
peetri	doc_910290104792_item	2934057	et	3	main
hakkasid	doc_910290104792_item	2934062	et	4	main
pärisorjuslikkorda	doc_910290104792_item	2934065	et	4	main
eesti	doc_910290104792_item	2934071	et	4	main
kus	doc_910290104792_item	2934073	et	3	main
esimest	doc_910290104792_item	2934074	et	4	main
rahva	doc_910290104792_item	2934082	et	3	main
jaoks	doc_910290104792_item	2934083	et	4	main
suur	doc_910290104792_item	2934084	et	3	main
estofiilideks	doc_910290104792_item	2934091	et	3	main
inimeste	doc_910290104792_item	2934104	et	3	main
eestofile	doc_910290104792_item	2934106	et	4	main
valgustusfilosoofia	doc_910290104792_item	2934108	et	4	main
kontrolltöö	doc_910290104793_item	2934109	et	4	main
tegevusest	doc_910290104793_item	2934126	et	4	main
hurt	doc_910290104793_item	2934141	et	3	main
tegevus	doc_910290104793_item	2934149	et	4	main
hurt	doc_910290104793_item	2934161	et	3	main
koostööd	doc_910290104793_item	2934166	et	4	main
aleksandrikooli	doc_910290104793_item	2934174	et	4	main
liikumise	doc_910290104793_item	2934175	et	4	main
liider	doc_910290104793_item	2934176	et	3	main
jakobson	doc_910290104793_item	2934177	et	4	main
mängis	doc_910290104793_item	2934178	et	3	main
ärkamisajas	doc_910290104793_item	2934179	et	3	main
tähtsat	doc_910290104793_item	2934180	et	3	main
j	doc_910290104793_item	2934183	et	4	main
koostöö	doc_910290104793_item	2934187	et	4	main
kontrolli	doc_910290104793_item	2934189	et	4	main
all	doc_910290104793_item	2934190	et	3	main
eesti	doc_910290104793_item	2934196	et	4	main
eestlaste	doc_910290104793_item	2934201	et	4	main
st	doc_910290104793_item	2934203	et	3	main
öelda	doc_910290104793_item	2934214	et	4	main
seista	doc_910290104793_item	2934219	et	4	main
ühendamisele	doc_910290104793_item	2934224	et	4	main
eestlastele	doc_910290104793_item	2934225	et	4	main
vaid	doc_910290104793_item	2934226	et	3	main
arendada	doc_910290104793_item	2934227	et	3	main
pooldanud	doc_910290104793_item	2934233	et	4	main
palju	doc_910290104793_item	2934241	et	4	main
see	doc_910290104792_item	2934017	et	3	main
isegi	doc_910290104792_item	2934021	et	4	main
arengule	doc_910290104792_item	2934030	et	3	main
ajaloost	doc_910290104792_item	2934039	et	4	main
ja	doc_910290104792_item	2934040	et	3	main
huvitatud	doc_910290104792_item	2934043	et	4	main
ning	doc_910290104792_item	2934046	et	3	main
cr	doc_910290104792_item	2934056	et	4	main
merkel	doc_910290104792_item	2934059	et	4	main
esimestena	doc_910290104792_item	2934061	et	3	main
likvideerida	doc_910290104792_item	2934067	et	3	main
oli	doc_910290104792_item	2934076	et	3	main
õnnetus	doc_910290104792_item	2934085	et	4	main
nemad	doc_910290104792_item	2934093	et	3	main
kirjutasid	doc_910290104792_item	2934094	et	4	main
silmaringi	doc_910290104792_item	2934105	et	4	main
1	doc_910290104793_item	2934113	et	2	main
milline	doc_910290104793_item	2934114	et	3	main
ärkamisaja	doc_910290104793_item	2934115	et	3	main
kultuuritegelane	doc_910290104793_item	2934116	et	3	main
on	doc_910290104793_item	2934117	et	4	main
kujutatud	doc_910290104793_item	2934118	et	4	main
rahatähe	doc_910290104793_item	2934121	et	3	main
mida	doc_910290104793_item	2934123	et	4	main
kes	doc_910290104793_item	2934129	et	4	main
olid	doc_910290104793_item	2934130	et	4	main
estofiilid	doc_910290104793_item	2934131	et	3	main
ja	doc_910290104793_item	2934132	et	3	main
milline	doc_910290104793_item	2934133	et	3	main
oli	doc_910290104793_item	2934134	et	3	main
on	doc_910290104793_item	2934142	et	4	main
eesti	doc_910290104793_item	2934144	et	4	main
ta	doc_910290104793_item	2934148	et	4	main
rahvaluule	doc_910290104793_item	2934154	et	4	main
ja	doc_910290104793_item	2934155	et	3	main
j	doc_910290104793_item	2934160	et	4	main
sai	doc_910290104793_item	2934173	et	4	main
rolli	doc_910290104793_item	2934181	et	4	main
hurt	doc_910290104793_item	2934184	et	3	main
tegi	doc_910290104793_item	2934185	et	4	main
temaga	doc_910290104793_item	2934186	et	3	main
hurda	doc_910290104793_item	2934188	et	3	main
komitee	doc_910290104793_item	2934194	et	4	main
ja	doc_910290104793_item	2934195	et	3	main
kultuuri	doc_910290104793_item	2934202	et	4	main
eesti	doc_910290104793_item	2934205	et	4	main
hurt	doc_910290104793_item	2934216	et	3	main
vene	doc_910290104793_item	2934220	et	4	main
oma	doc_910290104793_item	2934228	et	4	main
rahva	doc_910290104793_item	2934229	et	3	main
oli	doc_910290104793_item	2934240	et	3	main
ja	doc_910290104793_item	2934247	et	3	main
kuna	doc_910290104793_item	2934250	et	3	main
tänu	doc_910290104793_item	2934262	et	4	main
ja	doc_910290104793_item	2934267	et	3	main
hurt	doc_910290104793_item	2934270	et	3	main
tuntud	doc_910290104793_item	2934272	et	4	main
kultuuritegelane	doc_910290104793_item	2934273	et	3	main
eesti	doc_910290104793_item	2934274	et	4	main
pani	doc_910290104793_item	2934277	et	4	main
sellele	doc_910290104793_item	2934279	et	4	main
võrrelda	doc_919500587377_item	2934330	et	4	main
kaks	doc_919500587377_item	2934331	et	3	main
äripäev	doc_919500587377_item	2934336	et	3	main
lahendust	doc_919500587377_item	2934344	et	4	main
järgi	doc_919500587377_item	2934347	et	4	main
liigendusvõtted	doc_919500587377_item	2934354	et	4	main
kiri	doc_919500587377_item	2934355	et	3	main
eest	doc_919500587377_item	2934364	et	4	main
16märts	doc_919500587377_item	2934374	et	3	main
mehed	doc_919500587377_item	2934400	et	3	main
lehekülge	doc_919500587377_item	2934405	et	4	main
kus	doc_919500587377_item	2934406	et	3	main
see	doc_919500587377_item	2934407	et	3	main
uudis	doc_919500587377_item	2934408	et	3	main
on	doc_919500587377_item	2934414	et	4	main
ole	doc_919500587377_item	2934424	et	4	main
ka	doc_919500587377_item	2934429	et	3	main
fotod	doc_919500587377_item	2934430	et	3	main
natukene	doc_919500587377_item	2934437	et	4	main
jaotus	doc_919500587377_item	2934444	et	4	main
nimetab	doc_919500587377_item	2934445	et	3	main
tegi	doc_910290104792_item	2934025	et	4	main
suure	doc_910290104792_item	2934026	et	3	main
eesti	doc_910290104792_item	2934028	et	4	main
hoolitsesid	doc_910290104792_item	2934037	et	4	main
olid	doc_910290104792_item	2934042	et	4	main
elu	doc_910290104792_item	2934051	et	4	main
ja	doc_910290104792_item	2934058	et	3	main
rääkima	doc_910290104792_item	2934063	et	3	main
tuleb	doc_910290104792_item	2934066	et	3	main
mainitud	doc_910290104792_item	2934077	et	4	main
et	doc_910290104792_item	2934078	et	3	main
vägivalgne	doc_910290104792_item	2934079	et	4	main
minu	doc_910290104792_item	2934086	et	3	main
baltisakslasi	doc_910290104792_item	2934089	et	3	main
keeles	doc_910290104792_item	2934098	et	4	main
mis	doc_910290104792_item	2934099	et	4	main
haritas	doc_910290104792_item	2934100	et	4	main
rahva	doc_910290104792_item	2934101	et	3	main
ja	doc_910290104792_item	2934102	et	3	main
eesti	doc_910290104793_item	2934111	et	4	main
kultuuriloost	doc_910290104793_item	2934112	et	4	main
te	doc_910290104793_item	2934124	et	4	main
tema	doc_910290104793_item	2934125	et	4	main
nende	doc_910290104793_item	2934135	et	4	main
jakob	doc_910290104793_item	2934140	et	4	main
on	doc_910290104793_item	2934150	et	4	main
seotud	doc_910290104793_item	2934151	et	4	main
oli	doc_910290104793_item	2934162	et	3	main
ja	doc_910290104793_item	2934182	et	3	main
eesti	doc_910290104793_item	2934192	et	4	main
arendas	doc_910290104793_item	2934200	et	3	main
hariduse	doc_910290104793_item	2934204	et	3	main
keele	doc_910290104793_item	2934206	et	4	main
samuti	doc_910290104793_item	2934207	et	3	main
kirjakeele	doc_910290104793_item	2934208	et	4	main
ja	doc_910290104793_item	2934209	et	3	main
vastu	doc_910290104793_item	2934218	et	3	main
saksa	doc_910290104793_item	2934222	et	4	main
allutamist	doc_910290104793_item	2934236	et	4	main
vene	doc_910290104793_item	2934237	et	4	main
ärkamisajas	doc_910290104793_item	2934275	et	3	main
aluse	doc_910290104793_item	2934278	et	4	main
huvieesti	doc_910290104793_item	2934286	et	4	main
keele	doc_910290104793_item	2934317	et	4	main
grammatikat	doc_910290104793_item	2934318	et	3	main
ajalehte	doc_919500587377_item	2934332	et	4	main
sl	doc_919500587377_item	2934333	et	4	main
õhtuleht	doc_919500587377_item	2934334	et	3	main
hea	doc_919500587377_item	2934339	et	4	main
kriteeriumite	doc_919500587377_item	2934346	et	3	main
ma	doc_919500587377_item	2934358	et	3	main
võtsin	doc_919500587377_item	2934359	et	3	main
kaks	doc_919500587377_item	2934360	et	3	main
õhtuleht	doc_919500587377_item	2934372	et	3	main
reede	doc_919500587377_item	2934373	et	4	main
lugeda	doc_919500587377_item	2934412	et	3	main
esitatud	doc_919500587377_item	2934416	et	4	main
rubriigidesei	doc_919500587377_item	2934423	et	4	main
lehekülge	doc_919500587377_item	2934426	et	4	main
sest	doc_919500587377_item	2934438	et	4	main
see	doc_919500587377_item	2934439	et	3	main
mingid	doc_919500587377_item	2934453	et	4	main
sündmused	doc_919500587377_item	2934454	et	3	main
ja	doc_919500587377_item	2934475	et	3	main
on	doc_919500587377_item	2934505	et	4	main
nii	doc_919500587377_item	2934513	et	3	main
välismaal	doc_919500587377_item	2934517	et	4	main
nelle-liis	doc_919500587377_item	2934522	et	3	main
tuleb	doc_919500587377_item	2934525	et	3	main
seda	doc_919500587377_item	2934539	et	3	main
võiks	doc_919500587377_item	2934552	et	4	main
üldiselt	doc_919500587377_item	2934561	et	4	main
kodust	doc_919500587377_item	2934575	et	4	main
kodu	doc_919500587377_item	2934579	et	4	main
välismaal	doc_919500587377_item	2934617	et	4	main
rubriigiga	doc_919500587377_item	2934622	et	3	main
leheküljel	doc_919500587377_item	2934624	et	3	main
uudised	doc_919500587377_item	2934626	et	3	main
on	doc_919500587377_item	2934637	et	4	main
on	doc_919500587377_item	2934641	et	4	main
palju	doc_919500587377_item	2934643	et	4	main
2	doc_910290104793_item	2934128	et	2	main
eesti	doc_910290104793_item	2934137	et	4	main
kultuurilukku	doc_910290104793_item	2934138	et	4	main
1	doc_910290104793_item	2934139	et	2	main
kujutatud	doc_910290104793_item	2934143	et	4	main
10-kroonise	doc_910290104793_item	2934145	et	4	main
rahatähe	doc_910290104793_item	2934146	et	3	main
peal	doc_910290104793_item	2934147	et	4	main
rahva	doc_910290104793_item	2934152	et	3	main
vaimuvara	doc_910290104793_item	2934153	et	4	main
rahvale	doc_910290104793_item	2934159	et	3	main
ja	doc_910290104793_item	2934164	et	3	main
on	doc_910290104793_item	2934168	et	4	main
teada	doc_910290104793_item	2934169	et	3	main
et	doc_910290104793_item	2934170	et	3	main
samuti	doc_910290104793_item	2934171	et	3	main
temast	doc_910290104793_item	2934172	et	3	main
aleksandrikooli	doc_910290104793_item	2934193	et	4	main
ta	doc_910290104793_item	2934199	et	4	main
et	doc_910290104793_item	2934215	et	3	main
ja	doc_910290104793_item	2934221	et	3	main
ajaloo	doc_910290104793_item	2934156	et	4	main
teadmiste	doc_910290104793_item	2934157	et	4	main
üleandmisega	doc_910290104793_item	2934158	et	3	main
keeleteadlane	doc_910290104793_item	2934163	et	3	main
tegi	doc_910290104793_item	2934165	et	4	main
kreutzwaldiga	doc_910290104793_item	2934167	et	4	main
tegutsesid	doc_910290104793_item	2934191	et	4	main
kirjameeste	doc_910290104793_item	2934197	et	4	main
selts	doc_910290104793_item	2934198	et	3	main
rahva	doc_910290104793_item	2934210	et	3	main
vaimu	doc_910290104793_item	2934211	et	4	main
arengut	doc_910290104793_item	2934212	et	3	main
võib	doc_910290104793_item	2934213	et	3	main
püüdis	doc_910290104793_item	2934217	et	3	main
kultuuri	doc_910290104793_item	2934223	et	4	main
eesti	doc_910290104793_item	2934234	et	4	main
hariduse	doc_910290104793_item	2934238	et	3	main
tegevuste	doc_910290104793_item	2934248	et	4	main
eesti	doc_910290104793_item	2934251	et	4	main
kirjameeste	doc_910290104793_item	2934252	et	4	main
selts	doc_910290104793_item	2934253	et	3	main
oli	doc_910290104793_item	2934254	et	3	main
eesti	doc_910290104793_item	2934265	et	4	main
jakob	doc_910290104793_item	2934269	et	4	main
on	doc_910290104793_item	2934271	et	4	main
kirjakeelt	doc_910290104793_item	2934319	et	4	main
mille	doc_910290104793_item	2934320	et	3	main
kultuuri	doc_910290104793_item	2934230	et	4	main
ta	doc_910290104793_item	2934231	et	4	main
ei	doc_910290104793_item	2934232	et	4	main
koolisüsteemi	doc_910290104793_item	2934235	et	4	main
hurdal	doc_910290104793_item	2934239	et	3	main
pooldajaid	doc_910290104793_item	2934242	et	4	main
tema	doc_910290104793_item	2934245	et	4	main
huvide	doc_910290104793_item	2934246	et	3	main
eest	doc_910290104793_item	2934249	et	4	main
temale	doc_910290104793_item	2934263	et	3	main
arenes	doc_910290104793_item	2934264	et	3	main
haridus	doc_910290104793_item	2934268	et	3	main
ajal	doc_910290104793_item	2934280	et	4	main
2	doc_910290104793_item	2934281	et	2	main
estofiilid	doc_910290104793_item	2934282	et	3	main
balti-sakslased	doc_910290104793_item	2934283	et	3	main
kes	doc_910290104793_item	2934284	et	4	main
kultuurielu	doc_910290104793_item	2934287	et	4	main
vastu	doc_910290104793_item	2934288	et	3	main
nende	doc_910290104793_item	2934289	et	4	main
panus	doc_910290104793_item	2934290	et	4	main
eesti	doc_910290104793_item	2934291	et	4	main
kultuurilukku	doc_910290104793_item	2934292	et	4	main
oli	doc_910290104793_item	2934293	et	3	main
selline	doc_910290104793_item	2934294	et	4	main
et	doc_910290104793_item	2934295	et	3	main
nad	doc_910290104793_item	2934296	et	3	main
ise	doc_910290104793_item	2934297	et	4	main
õpisid	doc_910290104793_item	2934298	et	4	main
eesti	doc_910290104793_item	2934299	et	4	main
keelt	doc_910290104793_item	2934300	et	4	main
sest	doc_910290104793_item	2934301	et	4	main
kardsid	doc_910290104793_item	2934302	et	4	main
konkurentsi	doc_910290104793_item	2934303	et	4	main
eestlaste	doc_910290104793_item	2934304	et	4	main
seast	doc_910290104793_item	2934305	et	4	main
samuti	doc_910290104793_item	2934306	et	3	main
nad	doc_910290104793_item	2934307	et	3	main
arendasid	doc_910290104793_item	2934308	et	4	main
eesti	doc_910290104793_item	2934309	et	4	main
keele	doc_910290104793_item	2934310	et	4	main
ja	doc_910290104793_item	2934311	et	3	main
hariduse	doc_910290104793_item	2934312	et	3	main
kultuuri	doc_910290104793_item	2934313	et	4	main
estofiilid	doc_910290104793_item	2934314	et	3	main
uurisid	doc_910290104793_item	2934315	et	4	main
eesti	doc_910290104793_item	2934316	et	4	main
kes	doc_910290104793_item	2934243	et	4	main
seisid	doc_910290104793_item	2934244	et	4	main
allutatud	doc_910290104793_item	2934255	et	4	main
hurdale	doc_910290104793_item	2934256	et	3	main
siis	doc_910290104793_item	2934257	et	3	main
võib	doc_910290104793_item	2934258	et	3	main
öelda	doc_910290104793_item	2934259	et	4	main
et	doc_910290104793_item	2934260	et	3	main
just	doc_910290104793_item	2934261	et	3	main
keel	doc_910290104793_item	2934266	et	4	main
kes	doc_910290104793_item	2934276	et	4	main
tundsid	doc_910290104793_item	2934285	et	4	main
poolest	doc_910290104793_item	2934321	et	4	main
saksa	doc_910290104793_item	2934323	et	4	main
on	doc_919500587377_item	2934338	et	4	main
nende	doc_919500587377_item	2934340	et	4	main
kujundust	doc_919500587377_item	2934341	et	4	main
ja	doc_919500587377_item	2934342	et	3	main
tehnilist	doc_919500587377_item	2934343	et	3	main
veerulaius	doc_919500587377_item	2934352	et	4	main
veerupikkus	doc_919500587377_item	2934353	et	4	main
sl	doc_919500587377_item	2934371	et	4	main
edasi	doc_919500587377_item	2934410	et	3	main
läbi	doc_919500587377_item	2934411	et	4	main
esilehel	doc_919500587377_item	2934413	et	3	main
peauudise	doc_919500587377_item	2934417	et	3	main
ja	doc_919500587377_item	2934421	et	3	main
kuivõrd	doc_919500587377_item	2934337	et	3	main
ülesehitus	doc_919500587377_item	2934349	et	4	main
üldilme	doc_919500587377_item	2934350	et	4	main
esileht	doc_919500587377_item	2934351	et	3	main
keelekasutus	doc_919500587377_item	2934357	et	4	main
numbrit	doc_919500587377_item	2934361	et	3	main
märtsi	doc_919500587377_item	2934363	et	4	main
ja	doc_919500587377_item	2934365	et	3	main
kaks	doc_919500587377_item	2934366	et	3	main
21	doc_919500587377_item	2934368	et	2	main
2007	doc_919500587377_item	2934375	et	2	main
tiraaž	doc_919500587377_item	2934376	et	2	main
on	doc_919500587377_item	2934377	et	4	main
63	doc_919500587377_item	2934378	et	2	main
236	doc_919500587377_item	2934379	et	2	main
eksemplarit	doc_919500587377_item	2934380	et	4	main
esilehel	doc_919500587377_item	2934381	et	3	main
on	doc_919500587377_item	2934382	et	4	main
suur	doc_919500587377_item	2934383	et	3	main
pilt	doc_919500587377_item	2934384	et	3	main
purustatud	doc_919500587377_item	2934385	et	4	main
autokaitserauda	doc_919500587377_item	2934386	et	4	main
ning	doc_919500587377_item	2934387	et	3	main
pealkiri	doc_919500587377_item	2934388	et	3	main
kättemaks	doc_919500587377_item	2934389	et	4	main
või	doc_919500587377_item	2934390	et	4	main
enneolematu	doc_919500587377_item	2934391	et	4	main
julmus	doc_919500587377_item	2934392	et	4	main
autoavariisse	doc_919500587377_item	2934393	et	4	main
sattunud	doc_919500587377_item	2934394	et	4	main
turvamehe	doc_919500587377_item	2934395	et	3	main
peksid	doc_919500587377_item	2934396	et	4	main
teises	doc_919500587377_item	2934397	et	4	main
autos	doc_919500587377_item	2934398	et	3	main
sõitnud	doc_919500587377_item	2934399	et	4	main
erineb	doc_910290104793_item	2934322	et	3	main
keelest	doc_910290104793_item	2934324	et	4	main
referaat	doc_919500587377_item	2934325	et	3	main
selles	doc_919500587377_item	2934326	et	4	main
töös	doc_919500587377_item	2934327	et	3	main
ma	doc_919500587377_item	2934328	et	3	main
proovin	doc_919500587377_item	2934329	et	3	main
ja	doc_919500587377_item	2934335	et	3	main
järgmiste	doc_919500587377_item	2934345	et	3	main
ajalehe	doc_919500587377_item	2934348	et	3	main
ilustratsioonid	doc_919500587377_item	2934356	et	4	main
16	doc_919500587377_item	2934362	et	2	main
numbrit	doc_919500587377_item	2934367	et	3	main
märtsi	doc_919500587377_item	2934369	et	4	main
eest	doc_919500587377_item	2934370	et	4	main
sandiks	doc_919500587377_item	2934401	et	4	main
miskipärast	doc_919500587377_item	2934402	et	3	main
ei	doc_919500587377_item	2934403	et	4	main
viita	doc_919500587377_item	2934404	et	4	main
elu	doc_919500587377_item	2934418	et	4	main
on	doc_919500587377_item	2934440	et	4	main
lehekülge	doc_919500587377_item	2934463	et	4	main
välismaalt	doc_919500587377_item	2934464	et	3	main
esitatud	doc_919500587377_item	2934467	et	4	main
artikkel	doc_919500587377_item	2934469	et	3	main
tuntud	doc_919500587377_item	2934511	et	4	main
inimestest	doc_919500587377_item	2934512	et	3	main
eestis	doc_919500587377_item	2934514	et	3	main
edasi	doc_919500587377_item	2934524	et	3	main
rubriik	doc_919500587377_item	2934526	et	3	main
mis	doc_919500587377_item	2934527	et	4	main
pühendab	doc_919500587377_item	2934528	et	3	main
naistele	doc_919500587377_item	2934529	et	3	main
ka	doc_919500587377_item	2934532	et	3	main
naiseks	doc_919500587377_item	2934533	et	3	main
milles	doc_919500587377_item	2934534	et	3	main
ära	doc_919500587377_item	2934545	et	4	main
täna	doc_919500587377_item	2934548	et	4	main
meeldejäävad	doc_919500587377_item	2934555	et	3	main
ristsõna	doc_919500587377_item	2934557	et	4	main
esitatud	doc_919500587377_item	2934563	et	4	main
mida	doc_919500587377_item	2934572	et	4	main
teid	doc_919500587377_item	2934573	et	4	main
nii	doc_919500587377_item	2934613	et	3	main
ka	doc_919500587377_item	2934616	et	3	main
on	doc_919500587377_item	2934620	et	4	main
lehekülge	doc_919500587377_item	2934639	et	4	main
ajalehes	doc_919500587377_item	2934640	et	3	main
liiga	doc_919500587377_item	2934642	et	4	main
on	doc_919500587377_item	2934646	et	4	main
tähelepanu	doc_919500587377_item	2934653	et	4	main
reklaami	doc_919500587377_item	2934657	et	4	main
ainult	doc_919500587377_item	2934660	et	4	main
on	doc_919500587377_item	2934669	et	4	main
ebaühtlaseltveerupikkus	doc_919500587377_item	2934722	et	4	main
on	doc_919500587377_item	2934723	et	4	main
peamiselt	doc_919500587377_item	2934724	et	4	main
keskne	doc_919500587377_item	2934725	et	3	main
alguses	doc_919500587377_item	2934730	et	4	main
lehekülje	doc_919500587377_item	2934733	et	3	main
see	doc_919500587377_item	2934735	et	3	main
pikkuses	doc_919500587377_item	2934753	et	4	main
lugemist	doc_919500587377_item	2934760	et	4	main
jaganud	doc_919500587377_item	2934764	et	4	main
kiri	doc_919500587377_item	2934767	et	3	main
keskne	doc_919500587377_item	2934769	et	3	main
pealkirjad	doc_919500587377_item	2934770	et	3	main
on	doc_919500587377_item	2934771	et	4	main
kasutatakse	doc_919500587377_item	2934778	et	3	main
umbes	doc_919500587377_item	2934780	et	4	main
erinevaid	doc_919500587377_item	2934782	et	4	main
kirje	doc_919500587377_item	2934783	et	4	main
ja	doc_919500587377_item	2934788	et	3	main
allkirjad	doc_919500587377_item	2934789	et	3	main
keel	doc_919500587377_item	2934792	et	4	main
eest	doc_919500587377_item	2934821	et	4	main
hea	doc_919500587377_item	2934824	et	4	main
uudise	doc_919500587377_item	2934825	et	3	main
materjal	doc_919500587377_item	2934826	et	3	main
miinuseks	doc_919500587377_item	2934827	et	3	main
on	doc_919500587377_item	2934835	et	4	main
võiks	doc_919500587377_item	2934409	et	4	main
ka	doc_919500587377_item	2934415	et	3	main
uudised	doc_919500587377_item	2934419	et	3	main
sport	doc_919500587377_item	2934420	et	3	main
naine	doc_919500587377_item	2934422	et	3	main
uudisi	doc_919500587377_item	2934433	et	4	main
ajalehe	doc_919500587377_item	2934434	et	3	main
nimetus	doc_919500587377_item	2934435	et	4	main
kaob	doc_919500587377_item	2934436	et	3	main
tähtedega	doc_919500587377_item	2934442	et	4	main
esimene	doc_919500587377_item	2934443	et	3	main
poliitika	doc_919500587377_item	2934452	et	4	main
on	doc_919500587377_item	2934466	et	4	main
ning	doc_919500587377_item	2934470	et	3	main
uudised	doc_919500587377_item	2934472	et	3	main
venemaalt	doc_919500587377_item	2934473	et	3	main
suurbritaaniast	doc_919500587377_item	2934474	et	4	main
selles	doc_919500587377_item	2934503	et	4	main
klassi	doc_919500587377_item	2934507	et	4	main
kui	doc_919500587377_item	2934515	et	3	main
intervjuu	doc_919500587377_item	2934519	et	4	main
eesti	doc_919500587377_item	2934520	et	4	main
tuleb	doc_919500587377_item	2934540	et	3	main
rubriik	doc_919500587377_item	2934542	et	3	main
võib	doc_919500587377_item	2934544	et	3	main
televisooris	doc_919500587377_item	2934554	et	4	main
kuulutustega	doc_919500587377_item	2934570	et	4	main
leida	doc_919500587377_item	2934577	et	3	main
esitatud	doc_919500587377_item	2934584	et	4	main
lehekülg	doc_919500587377_item	2934619	et	3	main
tuntud	doc_919500587377_item	2934630	et	4	main
nii	doc_919500587377_item	2934631	et	3	main
ka	doc_919500587377_item	2934634	et	3	main
minevikus	doc_919500587377_item	2934635	et	3	main
pärast	doc_919500587377_item	2934661	et	4	main
seda	doc_919500587377_item	2934662	et	3	main
artikli	doc_919500587377_item	2934663	et	3	main
tekst	doc_919500587377_item	2934674	et	3	main
on	doc_919500587377_item	2934678	et	4	main
kohati	doc_919500587377_item	2934714	et	4	main
mõnedes	doc_919500587377_item	2934715	et	3	main
umbes	doc_919500587377_item	2934726	et	4	main
kuskil	doc_919500587377_item	2934727	et	3	main
ja	doc_919500587377_item	2934731	et	3	main
ja	doc_919500587377_item	2934743	et	3	main
ei	doc_919500587377_item	2934754	et	4	main
panne	doc_919500587377_item	2934755	et	3	main
kokku	doc_919500587377_item	2934756	et	3	main
raskendab	doc_919500587377_item	2934759	et	3	main
on	doc_919500587377_item	2934768	et	4	main
rasvakiri	doc_919500587377_item	2934777	et	3	main
5-6	doc_919500587377_item	2934781	et	2	main
on	doc_919500587377_item	2934793	et	4	main
lugemise	doc_919500587377_item	2934795	et	4	main
jaoks	doc_919500587377_item	2934796	et	4	main
artikli	doc_919500587377_item	2934797	et	3	main
pealkirjad	doc_919500587377_item	2934798	et	3	main
võiks	doc_919500587377_item	2934828	et	4	main
nimetada	doc_919500587377_item	2934829	et	3	main
et	doc_919500587377_item	2934830	et	3	main
pärast	doc_919500587377_item	2934831	et	4	main
äripäev	doc_919500587377_item	2934841	et	3	main
2007	doc_919500587377_item	2934845	et	2	main
moodsama	doc_919500587377_item	2934852	et	4	main
väljanägemise	doc_919500587377_item	2934853	et	3	main
tulid	doc_919500587377_item	2934860	et	4	main
lühiinfo	doc_919500587377_item	2934867	et	4	main
pilt	doc_919500587377_item	2934878	et	3	main
ajalehe	doc_919500587377_item	2934883	et	3	main
ja	doc_919500587377_item	2934890	et	3	main
pealtpoolt	doc_919500587377_item	2934891	et	3	main
ajalehe	doc_919500587377_item	2934902	et	3	main
kaob	doc_919500587377_item	2934908	et	3	main
lehel	doc_919500587377_item	2934912	et	3	main
päeva	doc_919500587377_item	2934916	et	4	main
5	doc_919500587377_item	2934920	et	2	main
on	doc_919500587377_item	2934928	et	4	main
jaotus	doc_919500587377_item	2934934	et	4	main
luubi	doc_919500587377_item	2934935	et	3	main
neli	doc_919500587377_item	2934943	et	3	main
tuleb	doc_919500587377_item	2934946	et	3	main
ka	doc_919500587377_item	2934425	et	3	main
on	doc_919500587377_item	2934427	et	4	main
lisatud	doc_919500587377_item	2934428	et	4	main
mis	doc_919500587377_item	2934431	et	4	main
täiendavad	doc_919500587377_item	2934432	et	4	main
väikse	doc_919500587377_item	2934441	et	4	main
eesti	doc_919500587377_item	2934450	et	4	main
uudised	doc_919500587377_item	2934451	et	3	main
viis	doc_919500587377_item	2934458	et	4	main
lehekülge	doc_919500587377_item	2934459	et	4	main
edasi	doc_919500587377_item	2934460	et	3	main
tuleb	doc_919500587377_item	2934461	et	3	main
kaks	doc_919500587377_item	2934462	et	3	main
hiinast	doc_919500587377_item	2934476	et	4	main
peamiselt	doc_919500587377_item	2934477	et	4	main
nad	doc_919500587377_item	2934478	et	3	main
on	doc_919500587377_item	2934479	et	4	main
ülevaatlikud	doc_919500587377_item	2934480	et	3	main
edasi	doc_919500587377_item	2934481	et	3	main
tuleb	doc_919500587377_item	2934482	et	3	main
arvamuse	doc_919500587377_item	2934483	et	3	main
jaotus	doc_919500587377_item	2934484	et	4	main
ainult	doc_919500587377_item	2934485	et	4	main
üks	doc_919500587377_item	2934486	et	3	main
lehekülg	doc_919500587377_item	2934487	et	3	main
ja	doc_919500587377_item	2934488	et	3	main
artiklit	doc_919500587377_item	2934490	et	3	main
selles	doc_919500587377_item	2934491	et	4	main
neli	doc_919500587377_item	2934489	et	3	main
osas	doc_919500587377_item	2934492	et	4	main
on	doc_919500587377_item	2934493	et	4	main
esitatud	doc_919500587377_item	2934494	et	4	main
inimese	doc_919500587377_item	2934495	et	4	main
arutlused	doc_919500587377_item	2934496	et	4	main
anntud	doc_919500587377_item	2934497	et	4	main
probleemidest	doc_919500587377_item	2934498	et	3	main
seda	doc_919500587377_item	2934500	et	3	main
uudised	doc_919500587377_item	2934446	et	3	main
milles	doc_919500587377_item	2934447	et	3	main
on	doc_919500587377_item	2934448	et	4	main
peamiselt	doc_919500587377_item	2934449	et	4	main
kõik	doc_919500587377_item	2934455	et	4	main
kokku	doc_919500587377_item	2934456	et	3	main
on	doc_919500587377_item	2934457	et	4	main
kuigi	doc_919500587377_item	2934465	et	3	main
üks	doc_919500587377_item	2934468	et	3	main
lühikesed	doc_919500587377_item	2934471	et	4	main
tuleb	doc_919500587377_item	2934501	et	3	main
elu	doc_919500587377_item	2934502	et	4	main
jaotuses	doc_919500587377_item	2934504	et	4	main
artikkel	doc_919500587377_item	2934506	et	3	main
filmist	doc_919500587377_item	2934508	et	4	main
ka	doc_919500587377_item	2934516	et	3	main
ning	doc_919500587377_item	2934518	et	3	main
pärast	doc_919500587377_item	2934499	et	4	main
lühikesed	doc_919500587377_item	2934509	et	4	main
uudised	doc_919500587377_item	2934510	et	3	main
laulja	doc_919500587377_item	2934521	et	4	main
vaiksooga	doc_919500587377_item	2934523	et	4	main
ning	doc_919500587377_item	2934530	et	3	main
nimetab	doc_919500587377_item	2934531	et	3	main
räägitakse	doc_919500587377_item	2934535	et	3	main
valulistest	doc_919500587377_item	2934536	et	4	main
probleemidest	doc_919500587377_item	2934537	et	3	main
pärast	doc_919500587377_item	2934538	et	4	main
tunda	doc_919500587377_item	2934546	et	3	main
vaadata	doc_919500587377_item	2934553	et	4	main
kõik	doc_919500587377_item	2934571	et	4	main
võib	doc_919500587377_item	2934576	et	3	main
oma	doc_919500587377_item	2934578	et	4	main
rubriigis	doc_919500587377_item	2934580	et	3	main
üheksal	doc_919500587377_item	2934581	et	3	main
leheküljel	doc_919500587377_item	2934582	et	3	main
on	doc_919500587377_item	2934583	et	4	main
eestis	doc_919500587377_item	2934614	et	3	main
viimane	doc_919500587377_item	2934618	et	3	main
täna	doc_919500587377_item	2934541	et	4	main
milles	doc_919500587377_item	2934543	et	3	main
kellele	doc_919500587377_item	2934547	et	4	main
on	doc_919500587377_item	2934549	et	4	main
sünnipäev	doc_919500587377_item	2934550	et	3	main
mida	doc_919500587377_item	2934551	et	4	main
päevad	doc_919500587377_item	2934556	et	3	main
horoskoop	doc_919500587377_item	2934558	et	3	main
ilm	doc_919500587377_item	2934559	et	3	main
anektootid	doc_919500587377_item	2934560	et	4	main
on	doc_919500587377_item	2934562	et	4	main
meelelahutused	doc_919500587377_item	2934564	et	4	main
ning	doc_919500587377_item	2934565	et	3	main
on	doc_919500587377_item	2934566	et	4	main
ka	doc_919500587377_item	2934567	et	3	main
üks	doc_919500587377_item	2934568	et	3	main
lehekülg	doc_919500587377_item	2934569	et	3	main
huvitab	doc_919500587377_item	2934574	et	3	main
mingid	doc_919500587377_item	2934585	et	4	main
üritused	doc_919500587377_item	2934586	et	4	main
näited	doc_919500587377_item	2934587	et	3	main
ja	doc_919500587377_item	2934588	et	3	main
kodukujundamise	doc_919500587377_item	2934589	et	3	main
lahendused	doc_919500587377_item	2934590	et	4	main
ja	doc_919500587377_item	2934591	et	3	main
nii	doc_919500587377_item	2934592	et	3	main
edasipärast	doc_919500587377_item	2934593	et	4	main
seda	doc_919500587377_item	2934594	et	3	main
tuleb	doc_919500587377_item	2934595	et	3	main
kaks	doc_919500587377_item	2934596	et	3	main
lehekülge	doc_919500587377_item	2934597	et	4	main
kultuur	doc_919500587377_item	2934598	et	3	main
ja	doc_919500587377_item	2934599	et	3	main
meelelahutus	doc_919500587377_item	2934600	et	4	main
kino	doc_919500587377_item	2934601	et	4	main
teater	doc_919500587377_item	2934602	et	3	main
kontserdid	doc_919500587377_item	2934603	et	3	main
veel	doc_919500587377_item	2934604	et	4	main
on	doc_919500587377_item	2934605	et	4	main
esitatud	doc_919500587377_item	2934606	et	4	main
neli	doc_919500587377_item	2934607	et	3	main
lehekülge	doc_919500587377_item	2934608	et	4	main
sport	doc_919500587377_item	2934609	et	3	main
peauudised	doc_919500587377_item	2934610	et	3	main
spordi	doc_919500587377_item	2934611	et	4	main
maailmas	doc_919500587377_item	2934612	et	3	main
kui	doc_919500587377_item	2934615	et	3	main
elu	doc_919500587377_item	2934621	et	4	main
sellel	doc_919500587377_item	2934623	et	4	main
on	doc_919500587377_item	2934625	et	4	main
tuntud	doc_919500587377_item	2934627	et	4	main
inimeste	doc_919500587377_item	2934628	et	3	main
elust	doc_919500587377_item	2934629	et	3	main
36	doc_919500587377_item	2934638	et	2	main
lehekülg	doc_919500587377_item	2934649	et	3	main
reklaamis	doc_919500587377_item	2934650	et	4	main
seetõttu	doc_919500587377_item	2934651	et	3	main
lülitub	doc_919500587377_item	2934654	et	3	main
peal	doc_919500587377_item	2934664	et	4	main
fotod	doc_919500587377_item	2934665	et	3	main
infograafika	doc_919500587377_item	2934666	et	4	main
ja	doc_919500587377_item	2934667	et	3	main
illustratsioonid	doc_919500587377_item	2934668	et	3	main
ajalehes	doc_919500587377_item	2934670	et	3	main
loetavamad	doc_919500587377_item	2934672	et	4	main
seejäral	doc_919500587377_item	2934675	et	4	main
illustratsioon	doc_919500587377_item	2934679	et	3	main
vaid	doc_919500587377_item	2934713	et	3	main
kirjutanud	doc_919500587377_item	2934721	et	4	main
algab	doc_919500587377_item	2934729	et	3	main
lõpus	doc_919500587377_item	2934734	et	4	main
pikkust	doc_919500587377_item	2934741	et	4	main
reklaamist	doc_919500587377_item	2934744	et	4	main
et	doc_919500587377_item	2934746	et	3	main
on	doc_919500587377_item	2934763	et	4	main
ribaks	doc_919500587377_item	2934766	et	3	main
trükitud	doc_919500587377_item	2934772	et	4	main
suurte	doc_919500587377_item	2934773	et	3	main
on	doc_919500587377_item	2934784	et	4	main
illustratsiooni	doc_919500587377_item	2934790	et	4	main
tingimata	doc_919500587377_item	2934836	et	4	main
mustad	doc_919500587377_item	2934837	et	4	main
kuna	doc_919500587377_item	2934838	et	3	main
nädalavahetus	doc_919500587377_item	2934842	et	4	main
sai	doc_919500587377_item	2934854	et	4	main
teemade	doc_919500587377_item	2934858	et	4	main
nende	doc_919500587377_item	2934865	et	4	main
suuremat	doc_919500587377_item	2934868	et	4	main
on	doc_919500587377_item	2934870	et	4	main
lugude	doc_919500587377_item	2934872	et	3	main
hierarhiale	doc_919500587377_item	2934873	et	3	main
esilehel	doc_919500587377_item	2934874	et	3	main
on	doc_919500587377_item	2934875	et	4	main
ka	doc_919500587377_item	2934876	et	3	main
on	doc_919500587377_item	2934880	et	4	main
suurte	doc_919500587377_item	2934887	et	3	main
alt-	doc_919500587377_item	2934889	et	4	main
on	doc_919500587377_item	2934892	et	4	main
algus	doc_919500587377_item	2934897	et	4	main
ning	doc_919500587377_item	2934898	et	3	main
on	doc_919500587377_item	2934899	et	4	main
paigutab	doc_919500587377_item	2934904	et	3	main
teisel	doc_919500587377_item	2934911	et	4	main
edasi	doc_919500587377_item	2934922	et	3	main
uudised	doc_919500587377_item	2934925	et	3	main
pärast	doc_919500587377_item	2934931	et	4	main
seda	doc_919500587377_item	2934932	et	3	main
peamiselt	doc_919500587377_item	2934941	et	4	main
pühendanud	doc_919500587377_item	2934950	et	4	main
eestlastele	doc_919500587377_item	2934951	et	4	main
tegelastele	doc_919500587377_item	2934952	et	3	main
antud	doc_919500587377_item	2934953	et	4	main
rain	doc_919500587377_item	2934955	et	4	main
tolkale	doc_919500587377_item	2934956	et	4	main
ja	doc_919500587377_item	2934957	et	3	main
seda	doc_919500587377_item	2934963	et	3	main
vaatluse	doc_919500587377_item	2934965	et	3	main
on	doc_919500587377_item	2934969	et	4	main
esitatud	doc_919500587377_item	2934970	et	4	main
peauudiste	doc_919500587377_item	2934971	et	3	main
ülevaade	doc_919500587377_item	2934972	et	3	main
börs	doc_919500587377_item	2934982	et	3	main
ka	doc_919500587377_item	2935021	et	3	main
lisamine	doc_919500587377_item	2935023	et	4	main
tutvuda	doc_919500587377_item	2935026	et	3	main
võiks	doc_919500587377_item	2935031	et	4	main
tänapäeval	doc_919500587377_item	2934632	et	3	main
kui	doc_919500587377_item	2934633	et	3	main
kokku	doc_919500587377_item	2934636	et	3	main
isagi	doc_919500587377_item	2934647	et	4	main
terve	doc_919500587377_item	2934648	et	4	main
igas	doc_919500587377_item	2934676	et	3	main
artiklis	doc_919500587377_item	2934677	et	3	main
nii	doc_919500587377_item	2934680	et	3	main
suured	doc_919500587377_item	2934681	et	3	main
kui	doc_919500587377_item	2934682	et	3	main
ka	doc_919500587377_item	2934683	et	3	main
väiksed	doc_919500587377_item	2934684	et	4	main
mõnikord	doc_919500587377_item	2934685	et	3	main
on	doc_919500587377_item	2934686	et	4	main
neid	doc_919500587377_item	2934687	et	4	main
liiga	doc_919500587377_item	2934688	et	4	main
palju	doc_919500587377_item	2934689	et	4	main
mõned	doc_919500587377_item	2934690	et	3	main
illustratsioonid	doc_919500587377_item	2934691	et	3	main
on	doc_919500587377_item	2934692	et	4	main
pandud	doc_919500587377_item	2934693	et	4	main
teksti	doc_919500587377_item	2934694	et	4	main
keskes	doc_919500587377_item	2934695	et	4	main
see	doc_919500587377_item	2934696	et	3	main
takistab	doc_919500587377_item	2934697	et	3	main
natukene	doc_919500587377_item	2934698	et	4	main
lugemisele	doc_919500587377_item	2934699	et	4	main
mõned	doc_919500587377_item	2934700	et	3	main
piltid	doc_919500587377_item	2934701	et	4	main
on	doc_919500587377_item	2934702	et	4	main
kommenteeritud	doc_919500587377_item	2934703	et	4	main
veerulaius	doc_919500587377_item	2934704	et	4	main
on	doc_919500587377_item	2934705	et	4	main
peamiselt	doc_919500587377_item	2934706	et	4	main
on	doc_919500587377_item	2934707	et	4	main
olemas	doc_919500587377_item	2934708	et	4	main
range	doc_919500587377_item	2934709	et	4	main
veerujagaminelaius	doc_919500587377_item	2934710	et	4	main
on	doc_919500587377_item	2934711	et	4	main
ühesugune	doc_919500587377_item	2934712	et	3	main
reklaamid	doc_919500587377_item	2934644	et	4	main
mõnikord	doc_919500587377_item	2934645	et	3	main
lugeja	doc_919500587377_item	2934652	et	4	main
ümber	doc_919500587377_item	2934655	et	3	main
kirju	doc_919500587377_item	2934656	et	4	main
peal	doc_919500587377_item	2934658	et	4	main
ning	doc_919500587377_item	2934659	et	3	main
palju	doc_919500587377_item	2934671	et	4	main
kui	doc_919500587377_item	2934673	et	3	main
artiklides	doc_919500587377_item	2934716	et	4	main
on	doc_919500587377_item	2934717	et	4	main
parem	doc_919500587377_item	2934718	et	4	main
veerg	doc_919500587377_item	2934728	et	3	main
lõpeb	doc_919500587377_item	2934732	et	4	main
on	doc_919500587377_item	2934736	et	4	main
umbes	doc_919500587377_item	2934737	et	4	main
illustratsioonist	doc_919500587377_item	2934742	et	3	main
seetõttu	doc_919500587377_item	2934745	et	3	main
seda	doc_919500587377_item	2934747	et	3	main
tuleb	doc_919500587377_item	2934749	et	3	main
ajalehte	doc_919500587377_item	2934751	et	4	main
pooleks	doc_919500587377_item	2934757	et	4	main
see	doc_919500587377_item	2934758	et	3	main
uudised	doc_919500587377_item	2934762	et	3	main
juures	doc_919500587377_item	2934791	et	4	main
arusaadav	doc_919500587377_item	2934794	et	4	main
lugemist	doc_919500587377_item	2934832	et	4	main
ajaleht	doc_919500587377_item	2934839	et	3	main
muutis	doc_919500587377_item	2934847	et	3	main
kardinaalselt	doc_919500587377_item	2934849	et	4	main
algusesse	doc_919500587377_item	2934859	et	4	main
kõrvale	doc_919500587377_item	2934866	et	4	main
suur	doc_919500587377_item	2934877	et	3	main
keskne	doc_919500587377_item	2934882	et	3	main
konflikt	doc_919500587377_item	2934885	et	3	main
teiste	doc_919500587377_item	2934895	et	4	main
nimetus	doc_919500587377_item	2934903	et	4	main
vasakule	doc_919500587377_item	2934906	et	4	main
üldisel	doc_919500587377_item	2934909	et	3	main
päeva	doc_919500587377_item	2934921	et	4	main
kaheksa	doc_919500587377_item	2934929	et	4	main
nimetuse	doc_919500587377_item	2934937	et	4	main
all	doc_919500587377_item	2934938	et	3	main
see	doc_919500587377_item	2934939	et	3	main
on	doc_919500587377_item	2934940	et	4	main
lehekülge	doc_919500587377_item	2934944	et	4	main
portree	doc_919500587377_item	2934947	et	4	main
lehekülge	doc_919500587377_item	2934961	et	4	main
esitatud	doc_919500587377_item	2934979	et	4	main
on	doc_919500587377_item	2935019	et	4	main
pealina	doc_919500587377_item	2935027	et	4	main
kultuurielu	doc_919500587377_item	2935028	et	4	main
uudistega	doc_919500587377_item	2935029	et	3	main
kuhu	doc_919500587377_item	2935030	et	3	main
ajaleht	doc_919500587377_item	2935040	et	3	main
ning	doc_919500587377_item	2935046	et	3	main
24	doc_919500587377_item	2935050	et	2	main
lehekülge	doc_919500587377_item	2935051	et	4	main
on	doc_919500587377_item	2935067	et	4	main
kuueni	doc_919500587377_item	2935072	et	4	main
uudised	doc_919500587377_item	2935076	et	3	main
on	doc_919500587377_item	2935084	et	4	main
on	doc_919500587377_item	2935121	et	4	main
nende	doc_919500587377_item	2935123	et	4	main
alla	doc_919500587377_item	2935124	et	3	main
illustratsioonid	doc_919500587377_item	2935131	et	3	main
mustas	doc_919500587377_item	2935134	et	4	main
muutusid	doc_919500587377_item	2935137	et	4	main
põhiteksti	doc_919500587377_item	2935141	et	4	main
kujunduses	doc_919500587377_item	2935145	et	4	main
blond	doc_919500587377_item	2935147	et	3	main
ja	doc_919500587377_item	2935156	et	3	main
allteema	doc_919500587377_item	2935159	et	4	main
täidanud	doc_919500587377_item	2935161	et	4	main
poolpaksu	doc_919500587377_item	2935162	et	4	main
kirjaga	doc_919500587377_item	2935163	et	3	main
olemas	doc_919500587377_item	2935165	et	4	main
on	doc_919500587377_item	2935175	et	4	main
kirjutanud	doc_919500587377_item	2935176	et	4	main
suurte	doc_919500587377_item	2935177	et	3	main
vaid	doc_919500587377_item	2935236	et	3	main
külg	doc_919500587377_item	2934719	et	3	main
on	doc_919500587377_item	2934720	et	4	main
kõik	doc_919500587377_item	2934738	et	4	main
sõltub	doc_919500587377_item	2934739	et	3	main
artikli	doc_919500587377_item	2934740	et	3	main
lugeda	doc_919500587377_item	2934748	et	3	main
hoia	doc_919500587377_item	2934750	et	4	main
kogu	doc_919500587377_item	2934752	et	4	main
kõik	doc_919500587377_item	2934761	et	4	main
mustaks	doc_919500587377_item	2934765	et	4	main
tähtedega	doc_919500587377_item	2934774	et	4	main
ning	doc_919500587377_item	2934775	et	3	main
kasutatakse	doc_919500587377_item	2934776	et	3	main
ka	doc_919500587377_item	2934779	et	3	main
olemas	doc_919500587377_item	2934785	et	4	main
punased	doc_919500587377_item	2934786	et	4	main
pealdisid	doc_919500587377_item	2934787	et	4	main
on	doc_919500587377_item	2934799	et	4	main
hästi	doc_919500587377_item	2934800	et	3	main
sõnastanud	doc_919500587377_item	2934801	et	4	main
kuskil	doc_919500587377_item	2934802	et	3	main
muidugi	doc_919500587377_item	2934803	et	4	main
võiks	doc_919500587377_item	2934804	et	4	main
midagi	doc_919500587377_item	2934805	et	4	main
toimetada	doc_919500587377_item	2934806	et	3	main
või	doc_919500587377_item	2934807	et	4	main
lisada	doc_919500587377_item	2934808	et	3	main
laused	doc_919500587377_item	2934809	et	3	main
on	doc_919500587377_item	2934810	et	4	main
kesksed	doc_919500587377_item	2934811	et	3	main
peamiselt	doc_919500587377_item	2934812	et	4	main
ajaleht	doc_919500587377_item	2934813	et	3	main
on	doc_919500587377_item	2934814	et	4	main
hästi	doc_919500587377_item	2934815	et	3	main
kujundanud	doc_919500587377_item	2934816	et	4	main
palju	doc_919500587377_item	2934817	et	4	main
illustratsioone	doc_919500587377_item	2934818	et	3	main
lühikese	doc_919500587377_item	2934819	et	4	main
tähtaja	doc_919500587377_item	2934820	et	3	main
on	doc_919500587377_item	2934822	et	4	main
ülesvõtnud	doc_919500587377_item	2934823	et	4	main
teie	doc_919500587377_item	2934833	et	4	main
käed	doc_919500587377_item	2934834	et	3	main
märts	doc_919500587377_item	2934844	et	3	main
määrdub	doc_919500587377_item	2934840	et	3	main
1618	doc_919500587377_item	2934843	et	2	main
äripäev	doc_919500587377_item	2934846	et	3	main
päris	doc_919500587377_item	2934848	et	4	main
oma	doc_919500587377_item	2934850	et	4	main
kujundust	doc_919500587377_item	2934851	et	4	main
ka	doc_919500587377_item	2934855	et	3	main
see	doc_919500587377_item	2934879	et	3	main
vist	doc_919500587377_item	2934881	et	4	main
tähtedega	doc_919500587377_item	2934888	et	4	main
esitatud	doc_919500587377_item	2934893	et	4	main
ka	doc_919500587377_item	2934894	et	3	main
leheküljed	doc_919500587377_item	2934901	et	3	main
ümber	doc_919500587377_item	2934905	et	3	main
plaanil	doc_919500587377_item	2934910	et	3	main
on	doc_919500587377_item	2934913	et	4	main
eest	doc_919500587377_item	2934917	et	4	main
ning	doc_919500587377_item	2934918	et	3	main
nimetatakse	doc_919500587377_item	2934919	et	3	main
on	doc_919500587377_item	2934923	et	4	main
äripäeva	doc_919500587377_item	2934856	et	4	main
logo	doc_919500587377_item	2934857	et	4	main
kasutusele	doc_919500587377_item	2934861	et	4	main
suured	doc_919500587377_item	2934862	et	3	main
päised	doc_919500587377_item	2934863	et	4	main
ja	doc_919500587377_item	2934864	et	3	main
rõhku	doc_919500587377_item	2934869	et	4	main
pandud	doc_919500587377_item	2934871	et	4	main
teema	doc_919500587377_item	2934884	et	4	main
kirjutatakse	doc_919500587377_item	2934886	et	3	main
uudiste	doc_919500587377_item	2934896	et	3	main
viitanud	doc_919500587377_item	2934900	et	4	main
ning	doc_919500587377_item	2934907	et	3	main
ülevaade	doc_919500587377_item	2934914	et	3	main
viie	doc_919500587377_item	2934915	et	3	main
eesti	doc_919500587377_item	2934924	et	4	main
kõik	doc_919500587377_item	2934926	et	4	main
kokku	doc_919500587377_item	2934927	et	3	main
on	doc_919500587377_item	2934933	et	4	main
finantsuudised	doc_919500587377_item	2934942	et	3	main
edasi	doc_919500587377_item	2934945	et	3	main
mis	doc_919500587377_item	2934948	et	4	main
juhul	doc_919500587377_item	2934954	et	3	main
tuleb	doc_919500587377_item	2934964	et	3	main
lehekülge	doc_919500587377_item	2934967	et	4	main
puhkepäeva	doc_919500587377_item	2935022	et	4	main
milles	doc_919500587377_item	2935024	et	3	main
võib	doc_919500587377_item	2935025	et	3	main
ole	doc_919500587377_item	2935037	et	4	main
veerust	doc_919500587377_item	2935073	et	4	main
kohtades	doc_919500587377_item	2935075	et	3	main
on	doc_919500587377_item	2935077	et	4	main
alati	doc_919500587377_item	2935122	et	4	main
aga	doc_919500587377_item	2935125	et	3	main
mitte	doc_919500587377_item	2935126	et	3	main
kõikides	doc_919500587377_item	2935127	et	4	main
illustratsioonides	doc_919500587377_item	2935128	et	3	main
kõik	doc_919500587377_item	2935138	et	4	main
kasutavad	doc_919500587377_item	2935139	et	4	main
ajalehes	doc_919500587377_item	2935148	et	3	main
on	doc_919500587377_item	2935153	et	4	main
suure	doc_919500587377_item	2935157	et	3	main
on	doc_919500587377_item	2935160	et	4	main
värvid	doc_919500587377_item	2935172	et	4	main
pealkirjad	doc_919500587377_item	2935174	et	3	main
jõukohane	doc_919500587377_item	2935182	et	4	main
ja	doc_919500587377_item	2935187	et	3	main
lehekülge	doc_919500587377_item	2934930	et	4	main
all	doc_919500587377_item	2934936	et	3	main
maimikale	doc_919500587377_item	2934959	et	4	main
kaks	doc_919500587377_item	2934960	et	3	main
pärast	doc_919500587377_item	2934962	et	4	main
neli	doc_919500587377_item	2934966	et	3	main
mis	doc_919500587377_item	2934973	et	4	main
eestisveel	doc_919500587377_item	2934975	et	4	main
on	doc_919500587377_item	2934978	et	4	main
erinevad	doc_919500587377_item	2934983	et	4	main
grafikud	doc_919500587377_item	2934984	et	4	main
börsid	doc_919500587377_item	2934985	et	3	main
indeksid	doc_919500587377_item	2934986	et	3	main
investitsioonilised	doc_919500587377_item	2934987	et	4	main
fondid	doc_919500587377_item	2934988	et	3	main
valuutakursid	doc_919500587377_item	2934989	et	3	main
viimastest	doc_919500587377_item	2934991	et	3	main
auto	doc_919500587377_item	2934990	et	4	main
uudisasjadest	doc_919500587377_item	2934992	et	3	main
uudised	doc_919500587377_item	2934993	et	3	main
tervis	doc_919500587377_item	2934994	et	3	main
noored	doc_919500587377_item	2934995	et	3	main
õpingud	doc_919500587377_item	2934996	et	3	main
karjäär	doc_919500587377_item	2934998	et	3	main
ajaleht	doc_919500587377_item	2934999	et	3	main
lõpetab	doc_919500587377_item	2935000	et	3	main
arvamuse	doc_919500587377_item	2935001	et	3	main
rubriigiga	doc_919500587377_item	2935002	et	3	main
raha	doc_919500587377_item	2934997	et	4	main
milles	doc_919500587377_item	2935003	et	3	main
on	doc_919500587377_item	2935004	et	4	main
esitatud	doc_919500587377_item	2935005	et	4	main
toimetuse	doc_919500587377_item	2935006	et	4	main
seisukohad	doc_919500587377_item	2935007	et	4	main
ja	doc_919500587377_item	2935008	et	3	main
kommentaarid	doc_919500587377_item	2935009	et	3	main
viimasel	doc_919500587377_item	2935010	et	3	main
leheküljel	doc_919500587377_item	2935011	et	3	main
on	doc_919500587377_item	2935012	et	4	main
seda	doc_919500587377_item	2935013	et	3	main
mida	doc_919500587377_item	2935014	et	4	main
tuleb	doc_919500587377_item	2935015	et	3	main
välja	doc_919500587377_item	2935016	et	4	main
on	doc_919500587377_item	2934949	et	4	main
andres	doc_919500587377_item	2934958	et	4	main
milles	doc_919500587377_item	2934968	et	3	main
toimuvad	doc_919500587377_item	2934974	et	4	main
selles	doc_919500587377_item	2934976	et	4	main
numbris	doc_919500587377_item	2934977	et	3	main
järgmised	doc_919500587377_item	2934980	et	3	main
rubriigid	doc_919500587377_item	2934981	et	3	main
numbris	doc_919500587377_item	2935018	et	3	main
olemas	doc_919500587377_item	2935020	et	4	main
järgmises	doc_919500587377_item	2935017	et	3	main
minna	doc_919500587377_item	2935032	et	3	main
liiga	doc_919500587377_item	2935038	et	4	main
lehekülge	doc_919500587377_item	2935045	et	4	main
on	doc_919500587377_item	2935048	et	4	main
kokku	doc_919500587377_item	2935049	et	3	main
mõnedes	doc_919500587377_item	2935054	et	3	main
on	doc_919500587377_item	2935064	et	4	main
ebamugav	doc_919500587377_item	2935065	et	3	main
joondega	doc_919500587377_item	2935080	et	4	main
kuskil	doc_919500587377_item	2935081	et	3	main
punktiiriga	doc_919500587377_item	2935082	et	4	main
kuskil	doc_919500587377_item	2935083	et	3	main
jaganud	doc_919500587377_item	2935085	et	4	main
jälle	doc_919500587377_item	2935087	et	3	main
on	doc_919500587377_item	2935088	et	4	main
on	doc_919500587377_item	2935129	et	4	main
kirjastiilid	doc_919500587377_item	2935140	et	3	main
kirjasuurused	doc_919500587377_item	2935151	et	4	main
pealkiri	doc_919500587377_item	2935152	et	3	main
kirjaga	doc_919500587377_item	2935158	et	3	main
range	doc_919500587377_item	2935166	et	4	main
mustad	doc_919500587377_item	2935171	et	4	main
jaotuse	doc_919500587377_item	2935173	et	4	main
keel	doc_919500587377_item	2935180	et	4	main
tekstid	doc_919500587377_item	2935184	et	3	main
lühikesed	doc_919500587377_item	2935186	et	4	main
majanduslikud	doc_919500587377_item	2935222	et	3	main
on	doc_919500587377_item	2935225	et	4	main
määrdub	doc_919500587377_item	2935235	et	3	main
ülejäänudelt	doc_919500587377_item	2935241	et	4	main
on	doc_919500587377_item	2935246	et	4	main
tõsine	doc_919500587377_item	2935251	et	4	main
ajaleht	doc_919500587377_item	2935252	et	3	main
öelda	doc_919500587377_item	2935263	et	4	main
on	doc_919500587377_item	2935266	et	4	main
olemas	doc_919500587377_item	2935275	et	4	main
lisand	doc_919500587377_item	2935276	et	3	main
juurde	doc_919500587377_item	2935279	et	4	main
õhtuleht	doc_919500587377_item	2935281	et	3	main
ning	doc_919500587377_item	2935294	et	3	main
suurte	doc_919500587377_item	2935295	et	3	main
valgete	doc_919500587377_item	2935296	et	4	main
tähtedega	doc_919500587377_item	2935297	et	4	main
tappis	doc_919500587377_item	2935302	et	4	main
vaevalt	doc_919500587377_item	2935305	et	4	main
läbi	doc_919500587377_item	2935321	et	4	main
järelikult	doc_919500587377_item	2935326	et	3	main
alguses	doc_919500587377_item	2935328	et	4	main
alt	doc_919500587377_item	2935329	et	4	main
kujundus	doc_919500587377_item	2935335	et	4	main
soovib	doc_919500587377_item	2935336	et	3	main
viivita	doc_919500587377_item	2935343	et	4	main
peal	doc_919500587377_item	2935345	et	4	main
kaua	doc_919500587377_item	2935346	et	3	main
pealt	doc_919500587377_item	2935347	et	4	main
kitaariga	doc_919500587377_item	2935359	et	4	main
tähte	doc_919500587377_item	2935365	et	4	main
järelikult	doc_919500587377_item	2935366	et	3	main
ebaõnnestunud	doc_919500587377_item	2935367	et	4	main
6	doc_919500587377_item	2935375	et	2	main
lk	doc_919500587377_item	2935376	et	4	main
kaotada	doc_919500587377_item	2935428	et	3	main
palju	doc_919500587377_item	2935432	et	4	main
huvitavaks	doc_919500587377_item	2935441	et	4	main
ja	doc_919500587377_item	2935442	et	3	main
mitmekesiseks	doc_919500587377_item	2935443	et	4	main
mõnedes	doc_919500587377_item	2935451	et	3	main
kõigidel	doc_919500587377_item	2935460	et	4	main
kujutanud	doc_919500587377_item	2935469	et	4	main
siluett	doc_919500587377_item	2935471	et	3	main
ning	doc_919500587377_item	2935472	et	3	main
ebaühtlaselt	doc_919500587377_item	2935475	et	4	main
mõnedel	doc_919500587377_item	2935476	et	3	main
leheküljedel	doc_919500587377_item	2935477	et	4	main
on	doc_919500587377_item	2935478	et	4	main
jälle	doc_919500587377_item	2935479	et	3	main
paigutamine	doc_919500587377_item	2935482	et	4	main
veerusepikkus	doc_919500587377_item	2935504	et	4	main
on	doc_919500587377_item	2935522	et	4	main
pigem	doc_919500587377_item	2935523	et	3	main
vaadata	doc_919500587377_item	2935034	et	4	main
äri	doc_919500587377_item	2935039	et	4	main
äripäevas	doc_919500587377_item	2935041	et	3	main
on	doc_919500587377_item	2935042	et	4	main
36	doc_919500587377_item	2935044	et	2	main
on	doc_919500587377_item	2935053	et	4	main
on	doc_919500587377_item	2935056	et	4	main
pikk	doc_919500587377_item	2935058	et	4	main
lehekülje	doc_919500587377_item	2935059	et	3	main
algusest	doc_919500587377_item	2935060	et	4	main
kuni	doc_919500587377_item	2935061	et	3	main
lõpuni	doc_919500587377_item	2935062	et	3	main
see	doc_919500587377_item	2935063	et	3	main
leheküljel	doc_919500587377_item	2935068	et	3	main
kolmest	doc_919500587377_item	2935070	et	4	main
mõnedes	doc_919500587377_item	2935074	et	3	main
jaganud	doc_919500587377_item	2935078	et	4	main
üldmusta	doc_919500587377_item	2935079	et	4	main
kuidagi	doc_919500587377_item	2935086	et	3	main
väga	doc_919500587377_item	2935089	et	3	main
reklaame	doc_919500587377_item	2935091	et	3	main
vaid	doc_919500587377_item	2935092	et	3	main
vähem	doc_919500587377_item	2935093	et	4	main
kui	doc_919500587377_item	2935094	et	3	main
sl	doc_919500587377_item	2935095	et	4	main
õhtulehes	doc_919500587377_item	2935096	et	3	main
reklaam	doc_919500587377_item	2935097	et	3	main
ei	doc_919500587377_item	2935098	et	4	main
ole	doc_919500587377_item	2935099	et	4	main
nii	doc_919500587377_item	2935100	et	3	main
silmatorkav	doc_919500587377_item	2935101	et	4	main
ja	doc_919500587377_item	2935102	et	3	main
kirju	doc_919500587377_item	2935103	et	4	main
peamiselt	doc_919500587377_item	2935104	et	4	main
on	doc_919500587377_item	2935105	et	4	main
artiklid	doc_919500587377_item	2935106	et	3	main
koos	doc_919500587377_item	2935107	et	4	main
illustratsionidega	doc_919500587377_item	2935108	et	4	main
vaid	doc_919500587377_item	2935109	et	3	main
mitte	doc_919500587377_item	2935110	et	3	main
kõik	doc_919500587377_item	2935111	et	4	main
nad	doc_919500587377_item	2935112	et	3	main
on	doc_919500587377_item	2935113	et	4	main
väga	doc_919500587377_item	2935114	et	3	main
suured	doc_919500587377_item	2935115	et	3	main
ning	doc_919500587377_item	2935116	et	3	main
alati	doc_919500587377_item	2935117	et	4	main
asuvad	doc_919500587377_item	2935118	et	4	main
pealt	doc_919500587377_item	2935119	et	4	main
kommentaar	doc_919500587377_item	2935120	et	3	main
on	doc_919500587377_item	2935132	et	4	main
uues	doc_919500587377_item	2935144	et	3	main
arnhem	doc_919500587377_item	2935146	et	4	main
on	doc_919500587377_item	2935149	et	4	main
mida	doc_919500587377_item	2935033	et	4	main
see	doc_919500587377_item	2935035	et	3	main
ei	doc_919500587377_item	2935036	et	4	main
kokku	doc_919500587377_item	2935043	et	3	main
puhepäevas	doc_919500587377_item	2935047	et	4	main
veerusepikkus	doc_919500587377_item	2935052	et	4	main
kohtades	doc_919500587377_item	2935055	et	3	main
liiga	doc_919500587377_item	2935057	et	4	main
veeruselaius	doc_919500587377_item	2935066	et	4	main
on	doc_919500587377_item	2935069	et	4	main
kuni	doc_919500587377_item	2935071	et	3	main
palju	doc_919500587377_item	2935090	et	4	main
kommentaarid	doc_919500587377_item	2935130	et	3	main
osutanud	doc_919500587377_item	2935133	et	4	main
raamis	doc_919500587377_item	2935135	et	4	main
ajalehes	doc_919500587377_item	2935136	et	3	main
kitjaks	doc_919500587377_item	2935142	et	4	main
on	doc_919500587377_item	2935143	et	4	main
kirjutanud	doc_919500587377_item	2935154	et	4	main
veerusjaotus	doc_919500587377_item	2935167	et	4	main
kasutatakse	doc_919500587377_item	2935168	et	3	main
hallid	doc_919500587377_item	2935169	et	4	main
ja	doc_919500587377_item	2935170	et	3	main
tähtedega	doc_919500587377_item	2935179	et	4	main
arusaamiseks	doc_919500587377_item	2935183	et	4	main
otsimist-leidmist	doc_919500587377_item	2935189	et	4	main
pakkuvatest	doc_919500587377_item	2935190	et	4	main
külgedest	doc_919500587377_item	2935191	et	4	main
on	doc_919500587377_item	2935192	et	4	main
võimatu	doc_919500587377_item	2935193	et	4	main
üle	doc_919500587377_item	2935194	et	3	main
vaadata	doc_919500587377_item	2935195	et	4	main
pealkirjad	doc_919500587377_item	2935196	et	3	main
on	doc_919500587377_item	2935197	et	4	main
selged	doc_919500587377_item	2935198	et	3	main
peamiselt	doc_919500587377_item	2935199	et	4	main
ajaleht	doc_919500587377_item	2935200	et	3	main
on	doc_919500587377_item	2935201	et	4	main
määranud	doc_919500587377_item	2935202	et	4	main
ärile	doc_919500587377_item	2935203	et	3	main
inimestele	doc_919500587377_item	2935204	et	3	main
seejärel	doc_919500587377_item	2935205	et	3	main
lugejate	doc_919500587377_item	2935206	et	4	main
ring	doc_919500587377_item	2935207	et	3	main
on	doc_919500587377_item	2935208	et	4	main
kitsendanud	doc_919500587377_item	2935209	et	4	main
mitte	doc_919500587377_item	2935210	et	3	main
kõikidele	doc_919500587377_item	2935211	et	4	main
see	doc_919500587377_item	2935212	et	3	main
on	doc_919500587377_item	2935213	et	4	main
huvitav	doc_919500587377_item	2935214	et	4	main
kuna	doc_919500587377_item	2935215	et	3	main
siin	doc_919500587377_item	2935216	et	4	main
on	doc_919500587377_item	2935217	et	4	main
esitatud	doc_919500587377_item	2935218	et	4	main
peamiselt	doc_919500587377_item	2935219	et	4	main
poliitilised	doc_919500587377_item	2935220	et	3	main
hind	doc_919500587377_item	2935224	et	3	main
ka	doc_919500587377_item	2935226	et	3	main
mitte	doc_919500587377_item	2935228	et	3	main
kõikidele	doc_919500587377_item	2935229	et	4	main
valged	doc_919500587377_item	2935247	et	3	main
erinevad	doc_919500587377_item	2935150	et	4	main
paksu	doc_919500587377_item	2935155	et	4	main
on	doc_919500587377_item	2935164	et	4	main
hallide	doc_919500587377_item	2935178	et	4	main
on	doc_919500587377_item	2935181	et	4	main
on	doc_919500587377_item	2935185	et	4	main
informatiivsed	doc_919500587377_item	2935188	et	3	main
ja	doc_919500587377_item	2935221	et	3	main
uudised	doc_919500587377_item	2935223	et	3	main
vastuvõetav	doc_919500587377_item	2935227	et	4	main
soovitajatele	doc_919500587377_item	2935230	et	4	main
nagu	doc_919500587377_item	2935231	et	3	main
vähem	doc_919500587377_item	2935238	et	4	main
erineb	doc_919500587377_item	2935240	et	3	main
kuna	doc_919500587377_item	2935242	et	3	main
kõik	doc_919500587377_item	2935244	et	4	main
ajalehed	doc_919500587377_item	2935245	et	3	main
tõsilistele	doc_919500587377_item	2935253	et	4	main
äripäev	doc_919500587377_item	2935265	et	3	main
seal	doc_919500587377_item	2935269	et	4	main
tiraaž	doc_919500587377_item	2935285	et	2	main
106	doc_919500587377_item	2935288	et	2	main
mehe	doc_919500587377_item	2935303	et	3	main
tähtedega	doc_919500587377_item	2935307	et	4	main
on	doc_919500587377_item	2935312	et	4	main
mõistatus	doc_919500587377_item	2935313	et	4	main
see	doc_919500587377_item	2935314	et	3	main
kõlab	doc_919500587377_item	2935315	et	3	main
lugeda	doc_919500587377_item	2935322	et	3	main
airbaltic	doc_919500587377_item	2935331	et	4	main
firma	doc_919500587377_item	2935332	et	4	main
reklaam	doc_919500587377_item	2935333	et	3	main
reklaami	doc_919500587377_item	2935334	et	4	main
pilk	doc_919500587377_item	2935341	et	3	main
nende	doc_919500587377_item	2935344	et	4	main
esitatud	doc_919500587377_item	2935349	et	4	main
uudiste	doc_919500587377_item	2935351	et	3	main
algus	doc_919500587377_item	2935352	et	4	main
millega	doc_919500587377_item	2935353	et	3	main
võib	doc_919500587377_item	2935354	et	3	main
tutvuda	doc_919500587377_item	2935355	et	3	main
edasi	doc_919500587377_item	2935356	et	3	main
tanel	doc_919500587377_item	2935357	et	4	main
varjab	doc_919500587377_item	2935361	et	3	main
paigutamine	doc_919500587377_item	2935369	et	4	main
2	doc_919500587377_item	2935381	et	2	main
5	doc_919500587377_item	2935384	et	2	main
kuulutused	doc_919500587377_item	2935388	et	4	main
1	doc_919500587377_item	2935389	et	2	main
lk	doc_919500587377_item	2935390	et	4	main
sl	doc_919500587377_item	2935232	et	4	main
õhtuleht	doc_919500587377_item	2935233	et	3	main
äripäev	doc_919500587377_item	2935234	et	3	main
natuke	doc_919500587377_item	2935237	et	4	main
tavaliselt	doc_919500587377_item	2935243	et	4	main
üldiselt	doc_919500587377_item	2935248	et	4	main
on	doc_919500587377_item	2935250	et	4	main
kui	doc_919500587377_item	2935255	et	3	main
võrrelda	doc_919500587377_item	2935256	et	4	main
ajalehe	doc_919500587377_item	2935258	et	3	main
kujunduse	doc_919500587377_item	2935259	et	4	main
parem	doc_919500587377_item	2935260	et	4	main
siis	doc_919500587377_item	2935261	et	3	main
milline	doc_919500587377_item	2935257	et	3	main
võiks	doc_919500587377_item	2935262	et	4	main
et	doc_919500587377_item	2935264	et	3	main
paberivärv	doc_919500587377_item	2935239	et	3	main
inimestele	doc_919500587377_item	2935254	et	3	main
parem	doc_919500587377_item	2935267	et	4	main
rohkem	doc_919500587377_item	2935271	et	4	main
lehekülge	doc_919500587377_item	2935272	et	4	main
ja	doc_919500587377_item	2935273	et	3	main
on	doc_919500587377_item	2935298	et	4	main
ning	doc_919500587377_item	2935304	et	3	main
kuidas	doc_919500587377_item	2935308	et	3	main
mees	doc_919500587377_item	2935309	et	4	main
sattus	doc_919500587377_item	2935311	et	3	main
on	doc_919500587377_item	2935330	et	4	main
soovida	doc_919500587377_item	2935337	et	4	main
ei	doc_919500587377_item	2935342	et	4	main
padari	doc_919500587377_item	2935358	et	4	main
on	doc_919500587377_item	2935372	et	4	main
järgmised	doc_919500587377_item	2935373	et	3	main
uudised	doc_919500587377_item	2935374	et	3	main
2	doc_919500587377_item	2935378	et	2	main
arvamus	doc_919500587377_item	2935380	et	3	main
elu	doc_919500587377_item	2935383	et	4	main
lk	doc_919500587377_item	2935385	et	4	main
mn	doc_919500587377_item	2935386	et	4	main
asuda	doc_919500587377_item	2935422	et	3	main
oma	doc_919500587377_item	2935429	et	4	main
vajavad	doc_919500587377_item	2935450	et	4	main
ise	doc_919500587377_item	2935457	et	4	main
piirid	doc_919500587377_item	2935465	et	3	main
ebaõnnestunud	doc_919500587377_item	2935480	et	4	main
ole	doc_919500587377_item	2935484	et	4	main
erinev	doc_919500587377_item	2935493	et	4	main
4	doc_919500587377_item	2935494	et	2	main
45	doc_919500587377_item	2935495	et	2	main
kuskil	doc_919500587377_item	2935496	et	3	main
on	doc_919500587377_item	2935498	et	4	main
kirjutanud	doc_919500587377_item	2935499	et	4	main
painutuse	doc_919500587377_item	2935500	et	4	main
fotost	doc_919500587377_item	2935510	et	3	main
nende	doc_919500587377_item	2935511	et	4	main
ajalehe	doc_919500587377_item	2935530	et	3	main
suuruseid	doc_919500587377_item	2935536	et	4	main
mitmekesisuse	doc_919500587377_item	2935537	et	4	main
suurte	doc_919500587377_item	2935539	et	3	main
on	doc_919500587377_item	2935541	et	4	main
keel	doc_919500587377_item	2935549	et	4	main
elav	doc_919500587377_item	2935562	et	4	main
äripäevaga	doc_919500587377_item	2935563	et	3	main
selge	doc_919500587377_item	2935567	et	4	main
kohe	doc_919500587377_item	2935569	et	4	main
ja	doc_919500587377_item	2935583	et	3	main
on	doc_919500587377_item	2935595	et	4	main
see	doc_919500587377_item	2935249	et	3	main
kuna	doc_919500587377_item	2935268	et	3	main
on	doc_919500587377_item	2935270	et	4	main
spetsiaalselt	doc_919500587377_item	2935277	et	4	main
sl	doc_919500587377_item	2935280	et	4	main
kolmapäev	doc_919500587377_item	2935282	et	3	main
märts	doc_919500587377_item	2935284	et	3	main
65	doc_919500587377_item	2935287	et	2	main
ajalehe	doc_919500587377_item	2935289	et	3	main
on	doc_919500587377_item	2935291	et	4	main
suur	doc_919500587377_item	2935292	et	3	main
foto	doc_919500587377_item	2935293	et	4	main
palgikoorija	doc_919500587377_item	2935301	et	4	main
vähem	doc_919500587377_item	2935306	et	4	main
masinasse	doc_919500587377_item	2935310	et	4	main
seda	doc_919500587377_item	2935323	et	3	main
ning	doc_919500587377_item	2935325	et	3	main
seetõttu	doc_919500587377_item	2935339	et	3	main
lugeja	doc_919500587377_item	2935340	et	4	main
on	doc_919500587377_item	2935348	et	4	main
foto	doc_919500587377_item	2935360	et	4	main
ajalehe	doc_919500587377_item	2935362	et	3	main
kaht	doc_919500587377_item	2935363	et	3	main
esimest	doc_919500587377_item	2935364	et	4	main
ajalehe	doc_919500587377_item	2935370	et	3	main
jaotused	doc_919500587377_item	2935371	et	4	main
välismaa	doc_919500587377_item	2935377	et	4	main
1lk	doc_919500587377_item	2935387	et	4	main
äripäevas	doc_919500587377_item	2935423	et	3	main
see	doc_919500587377_item	2935425	et	3	main
äristiil	doc_919500587377_item	2935430	et	3	main
väga	doc_919500587377_item	2935431	et	3	main
rohkem	doc_919500587377_item	2935434	et	4	main
kui	doc_919500587377_item	2935435	et	3	main
äripäevas	doc_919500587377_item	2935436	et	3	main
see	doc_919500587377_item	2935437	et	3	main
suurem	doc_919500587377_item	2935444	et	4	main
foto	doc_919500587377_item	2935455	et	4	main
artikklit	doc_919500587377_item	2935458	et	4	main
mitte	doc_919500587377_item	2935459	et	3	main
tekst	doc_919500587377_item	2935497	et	3	main
vahel	doc_919500587377_item	2935503	et	4	main
pikkus	doc_919500587377_item	2935512	et	4	main
peamiselt	doc_919500587377_item	2935514	et	4	main
10	doc_919500587377_item	2935516	et	2	main
mõned	doc_919500587377_item	2935517	et	3	main
nind	doc_919500587377_item	2935521	et	4	main
vertikaalsed	doc_919500587377_item	2935526	et	3	main
kiri	doc_919500587377_item	2935527	et	3	main
jaoks	doc_919500587377_item	2935531	et	4	main
erinevad	doc_919500587377_item	2935534	et	4	main
punased	doc_919500587377_item	2935547	et	4	main
värvid	doc_919500587377_item	2935548	et	4	main
lihtne	doc_919500587377_item	2935551	et	3	main
ajalehestiil	doc_919500587377_item	2935572	et	3	main
oma	doc_919500587377_item	2935576	et	4	main
on	doc_919500587377_item	2935580	et	4	main
pigem	doc_919500587377_item	2935581	et	3	main
suunatud	doc_919500587377_item	2935587	et	4	main
äri	doc_919500587377_item	2935588	et	4	main
ja	doc_919500587377_item	2935589	et	3	main
siis	doc_919500587377_item	2935592	et	3	main
sl	doc_919500587377_item	2935593	et	4	main
lihtne	doc_919500587377_item	2935597	et	3	main
näo	doc_919500587377_item	2935624	et	3	main
ajalehe	doc_919500587377_item	2935637	et	3	main
tehtud	doc_919500587377_item	2935650	et	4	main
pealkiri	doc_919500587377_item	2935651	et	3	main
inimese	doc_919500587377_item	2935661	et	4	main
lugeja	doc_919500587377_item	2935669	et	4	main
5	doc_919500587377_item	2935675	et	2	main
uus	doc_919500587377_item	2935678	et	3	main
lk	doc_919500587377_item	2935696	et	4	main
2	doc_919500587377_item	2935704	et	2	main
lehekülg	doc_919500587377_item	2935707	et	3	main
lugeda	doc_919500587377_item	2935714	et	3	main
leheküljel	doc_919500587377_item	2935720	et	3	main
on	doc_919500587377_item	2935721	et	4	main
artikkel	doc_919500587377_item	2935725	et	3	main
halensi	doc_919500587377_item	2935726	et	4	main
mis	doc_919500587377_item	2935728	et	4	main
sisene	doc_919500587377_item	2935730	et	4	main
on	doc_919500587377_item	2935274	et	4	main
reede	doc_919500587377_item	2935278	et	4	main
21	doc_919500587377_item	2935283	et	2	main
on	doc_919500587377_item	2935286	et	4	main
keskes	doc_919500587377_item	2935290	et	4	main
kirjutanud	doc_919500587377_item	2935299	et	4	main
pealkiri	doc_919500587377_item	2935300	et	3	main
intrigeerivalt	doc_919500587377_item	2935316	et	4	main
seetõttu	doc_919500587377_item	2935317	et	3	main
tekkib	doc_919500587377_item	2935318	et	3	main
soove	doc_919500587377_item	2935319	et	3	main
et	doc_919500587377_item	2935320	et	3	main
edasi	doc_919500587377_item	2935324	et	3	main
osta	doc_919500587377_item	2935327	et	4	main
paremat	doc_919500587377_item	2935338	et	4	main
kolme	doc_919500587377_item	2935350	et	4	main
foto	doc_919500587377_item	2935368	et	4	main
lk	doc_919500587377_item	2935379	et	4	main
lk	doc_919500587377_item	2935382	et	4	main
täna	doc_919500587377_item	2935391	et	4	main
2	doc_919500587377_item	2935392	et	2	main
lk	doc_919500587377_item	2935393	et	4	main
kultuur	doc_919500587377_item	2935394	et	3	main
ja	doc_919500587377_item	2935395	et	3	main
meelelahutus	doc_919500587377_item	2935396	et	4	main
2	doc_919500587377_item	2935397	et	2	main
sport	doc_919500587377_item	2935399	et	3	main
4	doc_919500587377_item	2935400	et	2	main
lk	doc_919500587377_item	2935398	et	4	main
lk	doc_919500587377_item	2935401	et	4	main
viimasel	doc_919500587377_item	2935402	et	3	main
leheküljel	doc_919500587377_item	2935403	et	3	main
on	doc_919500587377_item	2935404	et	4	main
suur	doc_919500587377_item	2935405	et	3	main
ristsõna	doc_919500587377_item	2935406	et	4	main
ajalehes	doc_919500587377_item	2935407	et	3	main
on	doc_919500587377_item	2935408	et	4	main
reklaami	doc_919500587377_item	2935409	et	4	main
rohkus	doc_919500587377_item	2935410	et	4	main
mis	doc_919500587377_item	2935411	et	4	main
erineb	doc_919500587377_item	2935412	et	3	main
äripäeva	doc_919500587377_item	2935413	et	4	main
ajalehe	doc_919500587377_item	2935414	et	3	main
reklaamist	doc_919500587377_item	2935415	et	4	main
võib	doc_919500587377_item	2935416	et	3	main
olla	doc_919500587377_item	2935417	et	3	main
mitte	doc_919500587377_item	2935418	et	3	main
iga	doc_919500587377_item	2935419	et	4	main
reklaam	doc_919500587377_item	2935420	et	3	main
saab	doc_919500587377_item	2935421	et	3	main
kuna	doc_919500587377_item	2935424	et	3	main
ajaleht	doc_919500587377_item	2935426	et	3	main
elavaks	doc_919500587377_item	2935440	et	4	main
kui	doc_919500587377_item	2935456	et	3	main
asub	doc_919500587377_item	2935474	et	3	main
veeruselaius	doc_919500587377_item	2935490	et	4	main
on	doc_919500587377_item	2935491	et	4	main
üsna	doc_919500587377_item	2935492	et	3	main
alt	doc_919500587377_item	2935501	et	4	main
varieerib	doc_919500587377_item	2935505	et	3	main
ka	doc_919500587377_item	2935506	et	3	main
artikli	doc_919500587377_item	2935507	et	3	main
suurust	doc_919500587377_item	2935508	et	4	main
ja	doc_919500587377_item	2935509	et	3	main
võib	doc_919500587377_item	2935427	et	3	main
illustratsioone	doc_919500587377_item	2935433	et	3	main
teeb	doc_919500587377_item	2935438	et	3	main
ajalehte	doc_919500587377_item	2935439	et	4	main
osa	doc_919500587377_item	2935445	et	4	main
fotosid	doc_919500587377_item	2935446	et	3	main
illustratsioone-	doc_919500587377_item	2935447	et	3	main
ja	doc_919500587377_item	2935448	et	3	main
graafikat	doc_919500587377_item	2935449	et	3	main
artiklides	doc_919500587377_item	2935452	et	4	main
on	doc_919500587377_item	2935453	et	4	main
rohkem	doc_919500587377_item	2935454	et	4	main
fotodel	doc_919500587377_item	2935461	et	3	main
on	doc_919500587377_item	2935462	et	4	main
raamid	doc_919500587377_item	2935463	et	4	main
ja	doc_919500587377_item	2935464	et	3	main
mõnedes	doc_919500587377_item	2935466	et	3	main
kohtades	doc_919500587377_item	2935467	et	3	main
on	doc_919500587377_item	2935468	et	4	main
inimese	doc_919500587377_item	2935470	et	4	main
tekst	doc_919500587377_item	2935473	et	3	main
foto	doc_919500587377_item	2935481	et	4	main
ei	doc_919500587377_item	2935483	et	4	main
selge	doc_919500587377_item	2935485	et	4	main
reeglit	doc_919500587377_item	2935486	et	3	main
kleepivad	doc_919500587377_item	2935487	et	4	main
kuhu	doc_919500587377_item	2935488	et	3	main
tahavad	doc_919500587377_item	2935489	et	3	main
foto	doc_919500587377_item	2935502	et	4	main
asuvad	doc_919500587377_item	2935519	et	4	main
jaoks	doc_919500587377_item	2935538	et	4	main
tähtedega	doc_919500587377_item	2935540	et	4	main
mustad	doc_919500587377_item	2935545	et	4	main
arusaamise	doc_919500587377_item	2935552	et	4	main
jaoks	doc_919500587377_item	2935555	et	4	main
see	doc_919500587377_item	2935565	et	3	main
range	doc_919500587377_item	2935582	et	4	main
äristiil	doc_919500587377_item	2935584	et	3	main
hõivatud	doc_919500587377_item	2935590	et	4	main
inimeste	doc_919500587377_item	2935591	et	3	main
pigem	doc_919500587377_item	2935596	et	3	main
foto	doc_919500587377_item	2935622	et	4	main
on	doc_919500587377_item	2935625	et	4	main
sulgenud	doc_919500587377_item	2935626	et	4	main
esitatud	doc_919500587377_item	2935630	et	4	main
valuutikursusid	doc_919500587377_item	2935631	et	4	main
minutit	doc_919500587377_item	2935676	et	3	main
on	doc_919500587377_item	2935680	et	4	main
alguses	doc_919500587377_item	2935682	et	4	main
mis	doc_919500587377_item	2935683	et	4	main
pakub	doc_919500587377_item	2935684	et	3	main
valikut	doc_919500587377_item	2935685	et	3	main
viimase	doc_919500587377_item	2935686	et	3	main
hinnangust	doc_919500587377_item	2935691	et	3	main
5	doc_919500587377_item	2935695	et	2	main
lk	doc_919500587377_item	2935699	et	4	main
lk	doc_919500587377_item	2935702	et	4	main
läbi	doc_919500587377_item	2935713	et	4	main
selle	doc_919500587377_item	2935715	et	4	main
nädala	doc_919500587377_item	2935716	et	3	main
ka	doc_919500587377_item	2935722	et	3	main
üks	doc_919500587377_item	2935724	et	3	main
pühendanud	doc_919500587377_item	2935744	et	4	main
reklaamile	doc_919500587377_item	2935745	et	3	main
pooolleheküljel	doc_919500587377_item	2935749	et	4	main
väiksemad	doc_919500587377_item	2935752	et	4	main
olemas	doc_919500587377_item	2935764	et	4	main
paigutamine	doc_919500587377_item	2935788	et	4	main
artikli	doc_919500587377_item	2935794	et	3	main
see	doc_919500587377_item	2935797	et	3	main
on	doc_919500587377_item	2935798	et	4	main
umbes	doc_919500587377_item	2935799	et	4	main
vaid	doc_919500587377_item	2935800	et	3	main
15st	doc_919500587377_item	2935806	et	3	main
palju	doc_919500587377_item	2935815	et	4	main
nendel	doc_919500587377_item	2935816	et	4	main
on	doc_919500587377_item	2935817	et	4	main
reklaame	doc_919500587377_item	2935818	et	3	main
fotosid	doc_919500587377_item	2935819	et	3	main
ja	doc_919500587377_item	2935820	et	3	main
on	doc_919500587377_item	2935513	et	4	main
6	doc_919500587377_item	2935515	et	2	main
uudised	doc_919500587377_item	2935518	et	3	main
pealt	doc_919500587377_item	2935520	et	4	main
kasutatakse	doc_919500587377_item	2935532	et	3	main
kirja	doc_919500587377_item	2935535	et	4	main
kasutatakse	doc_919500587377_item	2935544	et	3	main
ja	doc_919500587377_item	2935546	et	3	main
ja	doc_919500587377_item	2935553	et	3	main
lugemise	doc_919500587377_item	2935554	et	4	main
laused	doc_919500587377_item	2935556	et	3	main
võrreldes	doc_919500587377_item	2935564	et	3	main
märgatav	doc_919500587377_item	2935571	et	4	main
toimetus	doc_919500587377_item	2935574	et	4	main
järgib	doc_919500587377_item	2935575	et	3	main
reeglit	doc_919500587377_item	2935577	et	3	main
kui	doc_919500587377_item	2935578	et	3	main
äripäevas	doc_919500587377_item	2935579	et	3	main
õhtuleht	doc_919500587377_item	2935594	et	3	main
lähim	doc_919500587377_item	2935599	et	4	main
rahvaste	doc_919500587377_item	2935600	et	4	main
juurde	doc_919500587377_item	2935601	et	4	main
selles	doc_919500587377_item	2935602	et	4	main
ajalehes	doc_919500587377_item	2935603	et	3	main
võib	doc_919500587377_item	2935604	et	3	main
läbi	doc_919500587377_item	2935605	et	4	main
lugeda	doc_919500587377_item	2935606	et	3	main
isegi	doc_919500587377_item	2935607	et	4	main
kuulujutteid	doc_919500587377_item	2935609	et	4	main
mingeid	doc_919500587377_item	2935608	et	3	main
informatsiooni	doc_919500587377_item	2935610	et	4	main
valik	doc_919500587377_item	2935611	et	3	main
on	doc_919500587377_item	2935612	et	4	main
ka	doc_919500587377_item	2935613	et	3	main
huvitav	doc_919500587377_item	2935614	et	4	main
äripäev	doc_919500587377_item	2935615	et	3	main
kolmapäev	doc_919500587377_item	2935616	et	3	main
21märts	doc_919500587377_item	2935617	et	3	main
ajalehe	doc_919500587377_item	2935618	et	3	main
keskes	doc_919500587377_item	2935619	et	4	main
on	doc_919500587377_item	2935620	et	4	main
peaministri	doc_919500587377_item	2935621	et	3	main
kelle	doc_919500587377_item	2935623	et	4	main
pealt	doc_919500587377_item	2935628	et	4	main
on	doc_919500587377_item	2935629	et	4	main
trükitud	doc_919500587377_item	2935636	et	4	main
ja	doc_919500587377_item	2935639	et	3	main
mis	doc_919500587377_item	2935641	et	4	main
läbi	doc_919500587377_item	2935644	et	4	main
lugeda	doc_919500587377_item	2935645	et	3	main
suurte	doc_919500587377_item	2935646	et	3	main
mustade	doc_919500587377_item	2935647	et	3	main
tähtedega	doc_919500587377_item	2935648	et	4	main
kujutusega	doc_919500587377_item	2935662	et	4	main
on	doc_919500587377_item	2935664	et	4	main
ühesugune	doc_919500587377_item	2935666	et	3	main
ei	doc_919500587377_item	2935667	et	4	main
ja	doc_919500587377_item	2935689	et	3	main
äripäeva	doc_919500587377_item	2935690	et	4	main
tegijatele	doc_919500587377_item	2935693	et	4	main
5	doc_919500587377_item	2935698	et	2	main
5	doc_919500587377_item	2935701	et	2	main
lk	doc_919500587377_item	2935705	et	4	main
horisontaalsed	doc_919500587377_item	2935524	et	3	main
kui	doc_919500587377_item	2935525	et	3	main
on	doc_919500587377_item	2935528	et	4	main
standartne	doc_919500587377_item	2935529	et	4	main
ka	doc_919500587377_item	2935533	et	3	main
kirjutanud	doc_919500587377_item	2935542	et	4	main
pealkirjad	doc_919500587377_item	2935543	et	3	main
on	doc_919500587377_item	2935550	et	4	main
on	doc_919500587377_item	2935557	et	4	main
kesksed	doc_919500587377_item	2935558	et	3	main
ajaleht	doc_919500587377_item	2935559	et	3	main
on	doc_919500587377_item	2935560	et	4	main
väga	doc_919500587377_item	2935561	et	3	main
ongi	doc_919500587377_item	2935566	et	4	main
kuna	doc_919500587377_item	2935568	et	3	main
on	doc_919500587377_item	2935570	et	4	main
iga	doc_919500587377_item	2935573	et	4	main
mis	doc_919500587377_item	2935585	et	4	main
on	doc_919500587377_item	2935586	et	4	main
ja	doc_919500587377_item	2935598	et	3	main
alt	doc_919500587377_item	2935632	et	4	main
parema	doc_919500587377_item	2935633	et	4	main
äärega	doc_919500587377_item	2935634	et	3	main
jaotused	doc_919500587377_item	2935638	et	4	main
on	doc_919500587377_item	2935649	et	4	main
foto	doc_919500587377_item	2935660	et	4	main
esileht	doc_919500587377_item	2935663	et	3	main
liiga	doc_919500587377_item	2935665	et	4	main
tähelepanu	doc_919500587377_item	2935670	et	4	main
ajalehes	doc_919500587377_item	2935671	et	3	main
on	doc_919500587377_item	2935672	et	4	main
järgmised	doc_919500587377_item	2935673	et	3	main
hetke	doc_919500587377_item	2935687	et	4	main
uudistest	doc_919500587377_item	2935688	et	4	main
päeva	doc_919500587377_item	2935692	et	4	main
uudis	doc_919500587377_item	2935694	et	3	main
mida	doc_919500587377_item	2935711	et	4	main
võib	doc_919500587377_item	2935712	et	3	main
euromüntiks	doc_919500587377_item	2935627	et	4	main
on	doc_919500587377_item	2935635	et	4	main
peauudised	doc_919500587377_item	2935640	et	3	main
võib	doc_919500587377_item	2935642	et	3	main
nendes	doc_919500587377_item	2935643	et	4	main
liitumiskava	doc_919500587377_item	2935652	et	4	main
pole	doc_919500587377_item	2935653	et	3	main
ega	doc_919500587377_item	2935654	et	3	main
tule	doc_919500587377_item	2935655	et	4	main
esilehel	doc_919500587377_item	2935656	et	3	main
on	doc_919500587377_item	2935657	et	4	main
ka	doc_919500587377_item	2935658	et	3	main
kaks	doc_919500587377_item	2935659	et	3	main
köida	doc_919500587377_item	2935668	et	4	main
jaotused	doc_919500587377_item	2935674	et	4	main
päris	doc_919500587377_item	2935677	et	4	main
rubriik	doc_919500587377_item	2935679	et	3	main
lehe	doc_919500587377_item	2935681	et	3	main
börs	doc_919500587377_item	2935697	et	3	main
ehitus	doc_919500587377_item	2935700	et	4	main
arvamus	doc_919500587377_item	2935703	et	3	main
pühendanud	doc_919500587377_item	2935709	et	4	main
sellele	doc_919500587377_item	2935710	et	4	main
järgmistes	doc_919500587377_item	2935717	et	3	main
väljaandmistes	doc_919500587377_item	2935718	et	3	main
esitatud	doc_919500587377_item	2935723	et	4	main
ei	doc_919500587377_item	2935729	et	4	main
veel	doc_919500587377_item	2935751	et	4	main
reklaamid	doc_919500587377_item	2935753	et	4	main
ajalehes	doc_919500587377_item	2935754	et	3	main
on	doc_919500587377_item	2935755	et	4	main
tehtud	doc_919500587377_item	2935761	et	4	main
kommentaarid	doc_919500587377_item	2935762	et	3	main
aru	doc_919500587377_item	2935783	et	4	main
lugemist	doc_919500587377_item	2935791	et	4	main
veerusepikkus	doc_919500587377_item	2935792	et	4	main
varieerib	doc_919500587377_item	2935793	et	3	main
peamiselt	doc_919500587377_item	2935796	et	4	main
pikem	doc_919500587377_item	2935804	et	4	main
näiteks	doc_919500587377_item	2935805	et	4	main
kuni	doc_919500587377_item	2935807	et	3	main
20ni	doc_919500587377_item	2935808	et	4	main
umbes	doc_919500587377_item	2935825	et	4	main
milles	doc_919500587377_item	2935832	et	3	main
uudiste	doc_919500587377_item	2935840	et	3	main
on	doc_919500587377_item	2935845	et	4	main
eristanud	doc_919500587377_item	2935881	et	4	main
tähtedega	doc_919500587377_item	2935885	et	4	main
mitu	doc_919500587377_item	2935887	et	4	main
igavalt	doc_919500587377_item	2935895	et	4	main
kõik	doc_919500587377_item	2935898	et	4	main
pealkirjad	doc_919500587377_item	2935905	et	3	main
on	doc_919500587377_item	2935906	et	4	main
üsna	doc_919500587377_item	2935907	et	3	main
ole	doc_919500587377_item	2935914	et	4	main
ja	doc_919500587377_item	2935927	et	3	main
on	doc_919500587377_item	2935939	et	4	main
lisandid	doc_919500587377_item	2935943	et	3	main
huvitavaks	doc_919500587377_item	2935946	et	4	main
valimine	doc_919500587377_item	2935948	et	4	main
reeglit	doc_919500587377_item	2935962	et	3	main
et	doc_919500587377_item	2935987	et	3	main
lugejale	doc_919500587377_item	2935990	et	4	main
kujundaja	doc_919500587377_item	2935993	et	4	main
ju	doc_919500587377_item	2935994	et	3	main
kuid	doc_919500587377_item	2935999	et	4	main
märka	doc_919500587377_item	2936003	et	4	main
töö	doc_919500587377_item	2936008	et	4	main
kümnesse	doc_919500587377_item	2936010	et	4	main
elegantne	doc_919500587377_item	2936011	et	3	main
täpne	doc_919500587377_item	2936017	et	3	main
arukas	doc_919500587377_item	2936019	et	4	main
viimane	doc_919500587377_item	2935706	et	3	main
on	doc_919500587377_item	2935708	et	4	main
sellel	doc_919500587377_item	2935719	et	4	main
kataloogifirmast	doc_919500587377_item	2935727	et	4	main
kõik	doc_919500587377_item	2935733	et	4	main
kolm	doc_919500587377_item	2935740	et	3	main
ei	doc_919500587377_item	2935746	et	4	main
või	doc_919500587377_item	2935750	et	4	main
mille	doc_919500587377_item	2935758	et	3	main
paremini	doc_919500587377_item	2935782	et	4	main
sega	doc_919500587377_item	2935790	et	4	main
suurust	doc_919500587377_item	2935795	et	4	main
jälle	doc_919500587377_item	2935812	et	3	main
standartne	doc_919500587377_item	2935824	et	4	main
artikkel	doc_919500587377_item	2935829	et	3	main
reeglitest	doc_919500587377_item	2935837	et	4	main
jaganud	doc_919500587377_item	2935846	et	4	main
peamiselt	doc_919500587377_item	2935850	et	4	main
leheküljel	doc_919500587377_item	2935851	et	3	main
võtab	doc_919500587377_item	2935852	et	3	main
peamine	doc_919500587377_item	2935856	et	3	main
on	doc_919500587377_item	2935860	et	4	main
pärast	doc_919500587377_item	2935865	et	4	main
lühikesemat	doc_919500587377_item	2935874	et	4	main
paksude	doc_919500587377_item	2935882	et	4	main
suurte	doc_919500587377_item	2935884	et	3	main
kasutatakse	doc_919500587377_item	2935886	et	3	main
kirja	doc_919500587377_item	2935888	et	4	main
variantid	doc_919500587377_item	2935889	et	4	main
et	doc_919500587377_item	2935890	et	3	main
ajaleht	doc_919500587377_item	2935891	et	3	main
välja	doc_919500587377_item	2935894	et	4	main
raske	doc_919500587377_item	2935915	et	4	main
kesksete	doc_919500587377_item	2935921	et	4	main
muidugi	doc_919500587377_item	2935923	et	4	main
võiks	doc_919500587377_item	2935924	et	4	main
kujundamine	doc_919500587377_item	2935931	et	4	main
erinevad	doc_919500587377_item	2935940	et	4	main
ka	doc_919500587377_item	2935952	et	3	main
vaimustada	doc_919500587377_item	2935998	et	3	main
ei	doc_919500587377_item	2936002	et	4	main
ole	doc_919500587377_item	2936006	et	4	main
veeruõhu	doc_919500587377_item	2936016	et	3	main
hea	doc_919500587377_item	2936030	et	4	main
usaldust	doc_919500587377_item	2936038	et	4	main
selle	doc_919500587377_item	2936044	et	4	main
välja	doc_919500587377_item	2936048	et	4	main
näeb	doc_919500587377_item	2936049	et	3	main
ka	doc_919500587377_item	2936060	et	3	main
sl	doc_919500587377_item	2936065	et	4	main
õhtuleht	doc_919500587377_item	2936066	et	3	main
kujundusega	doc_919500587377_item	2936071	et	4	main
ajalehest	doc_919500587377_item	2936073	et	4	main
sissejuhatus	doc_919500587378_item	2936075	et	4	main
võtsin	doc_919500587378_item	2936079	et	3	main
16	doc_919500587378_item	2936083	et	2	main
märtsi	doc_919500587378_item	2936086	et	4	main
valge	doc_919500587378_item	2936106	et	4	main
ja	doc_919500587378_item	2936107	et	3	main
teda	doc_919500587378_item	2936108	et	4	main
müüjakse	doc_919500587378_item	2936109	et	4	main
tekkis	doc_919500587378_item	2936122	et	3	main
tekkinud	doc_919500587378_item	2936131	et	4	main
ajalehe	doc_919500587378_item	2936137	et	3	main
äripäeva	doc_919500587378_item	2936145	et	4	main
allpool	doc_919500587378_item	2936163	et	3	main
lühiuudiste	doc_919500587378_item	2936184	et	3	main
väga	doc_919500587378_item	2936193	et	3	main
keskenduda	doc_919500587378_item	2936195	et	3	main
võimatu	doc_919500587378_item	2936203	et	4	main
leida	doc_919500587378_item	2936204	et	3	main
oluline	doc_919500587378_item	2936205	et	4	main
erinevus	doc_919500587378_item	2936206	et	4	main
jaotustesse	doc_919500587377_item	2935732	et	4	main
on	doc_919500587377_item	2935735	et	4	main
24	doc_919500587377_item	2935737	et	2	main
nendest	doc_919500587377_item	2935739	et	4	main
arvestades	doc_919500587377_item	2935747	et	3	main
illustratsiooni	doc_919500587377_item	2935756	et	4	main
rohkus	doc_919500587377_item	2935757	et	4	main
juurde	doc_919500587377_item	2935759	et	4	main
on	doc_919500587377_item	2935760	et	4	main
nii	doc_919500587377_item	2935765	et	3	main
suured	doc_919500587377_item	2935766	et	3	main
kesksed	doc_919500587377_item	2935767	et	3	main
väiksed	doc_919500587377_item	2935768	et	4	main
kui	doc_919500587377_item	2935769	et	3	main
ka	doc_919500587377_item	2935770	et	3	main
mustad	doc_919500587377_item	2935771	et	4	main
ja	doc_919500587377_item	2935772	et	3	main
värvilised	doc_919500587377_item	2935773	et	4	main
fotod	doc_919500587377_item	2935774	et	3	main
kõik	doc_919500587377_item	2935775	et	4	main
fotod	doc_919500587377_item	2935776	et	3	main
lisand	doc_919500587377_item	2935778	et	3	main
artiklide	doc_919500587377_item	2935779	et	4	main
juurde	doc_919500587377_item	2935780	et	4	main
on	doc_919500587377_item	2935777	et	4	main
aitavad	doc_919500587377_item	2935781	et	4	main
eelloendanud	doc_919500587377_item	2935731	et	3	main
kokku	doc_919500587377_item	2935734	et	3	main
ajalehes	doc_919500587377_item	2935736	et	3	main
lehekülge	doc_919500587377_item	2935738	et	4	main
lehekülge	doc_919500587377_item	2935741	et	4	main
on	doc_919500587377_item	2935742	et	4	main
täielikult	doc_919500587377_item	2935743	et	4	main
reklaame	doc_919500587377_item	2935748	et	3	main
on	doc_919500587377_item	2935763	et	4	main
saada	doc_919500587377_item	2935784	et	4	main
artikli	doc_919500587377_item	2935785	et	3	main
olemus	doc_919500587377_item	2935786	et	3	main
foto	doc_919500587377_item	2935787	et	4	main
olemas	doc_919500587377_item	2935802	et	4	main
ka	doc_919500587377_item	2935803	et	3	main
kõik	doc_919500587377_item	2935810	et	4	main
sõltub	doc_919500587377_item	2935811	et	3	main
on	doc_919500587377_item	2935823	et	4	main
arvamuse	doc_919500587377_item	2935830	et	3	main
erand	doc_919500587377_item	2935838	et	3	main
lühikene	doc_919500587377_item	2935839	et	4	main
ülevaade	doc_919500587377_item	2935841	et	3	main
peenikeste	doc_919500587377_item	2935847	et	4	main
üldmustade	doc_919500587377_item	2935848	et	3	main
joonedeks	doc_919500587377_item	2935849	et	4	main
sisse	doc_919500587377_item	2935854	et	4	main
tähtis	doc_919500587377_item	2935858	et	4	main
suuruse	doc_919500587377_item	2935862	et	4	main
järgi	doc_919500587377_item	2935863	et	4	main
artiklit	doc_919500587377_item	2935875	et	3	main
on	doc_919500587377_item	2935877	et	4	main
ja	doc_919500587377_item	2935883	et	3	main
näe	doc_919500587377_item	2935893	et	4	main
viided	doc_919500587377_item	2935900	et	4	main
on	doc_919500587377_item	2935901	et	4	main
silmatorkavad	doc_919500587377_item	2935908	et	3	main
tähelepanu	doc_919500587377_item	2935911	et	4	main
ei	doc_919500587377_item	2935789	et	4	main
on	doc_919500587377_item	2935801	et	4	main
cm	doc_919500587377_item	2935809	et	4	main
leheküljest	doc_919500587377_item	2935813	et	4	main
kui	doc_919500587377_item	2935814	et	3	main
artikleid	doc_919500587377_item	2935821	et	3	main
vaid	doc_919500587377_item	2935826	et	3	main
üks	doc_919500587377_item	2935828	et	3	main
veeruselaius	doc_919500587377_item	2935833	et	4	main
see	doc_919500587377_item	2935835	et	3	main
paikneb	doc_919500587377_item	2935842	et	3	main
uudised	doc_919500587377_item	2935844	et	3	main
ja	doc_919500587377_item	2935857	et	3	main
uudis	doc_919500587377_item	2935859	et	3	main
suur	doc_919500587377_item	2935861	et	3	main
seda	doc_919500587377_item	2935866	et	3	main
mingi	doc_919500587377_item	2935868	et	4	main
reklaam	doc_919500587377_item	2935869	et	3	main
või	doc_919500587377_item	2935870	et	4	main
ruum	doc_919500587377_item	2935871	et	3	main
kiri	doc_919500587377_item	2935876	et	3	main
standaartne	doc_919500587377_item	2935878	et	4	main
pealkirjad	doc_919500587377_item	2935879	et	3	main
on	doc_919500587377_item	2935880	et	4	main
ja	doc_919500587377_item	2935896	et	3	main
ühesuguselt	doc_919500587377_item	2935897	et	4	main
allikate	doc_919500587377_item	2935899	et	3	main
lugeja	doc_919500587377_item	2935910	et	4	main
keel	doc_919500587377_item	2935912	et	4	main
ei	doc_919500587377_item	2935913	et	4	main
pikkusega	doc_919500587377_item	2935922	et	4	main
kuid	doc_919500587377_item	2935938	et	4	main
ja	doc_919500587377_item	2935942	et	3	main
oleks	doc_919500587377_item	2935945	et	3	main
informatsiooni	doc_919500587377_item	2935947	et	4	main
on	doc_919500587377_item	2935949	et	4	main
olemas	doc_919500587377_item	2935958	et	4	main
ka	doc_919500587377_item	2935959	et	3	main
need	doc_919500587377_item	2935964	et	3	main
öelda	doc_919500587377_item	2935986	et	4	main
tehakse	doc_919500587377_item	2935989	et	3	main
võib	doc_919500587377_item	2935992	et	3	main
oma	doc_919500587377_item	2935995	et	4	main
tööst	doc_919500587377_item	2935996	et	3	main
kui	doc_919500587377_item	2936000	et	3	main
lugeja	doc_919500587377_item	2936004	et	4	main
täpne	doc_919500587377_item	2936013	et	3	main
jälgimine	doc_919500587377_item	2936018	et	4	main
värvikasutus	doc_919500587377_item	2936020	et	4	main
ajalehekujunduse	doc_919500587377_item	2936023	et	3	main
kitjutamine	doc_919500587377_item	2936031	et	4	main
aega	doc_919500587377_item	2936033	et	4	main
ja	doc_919500587377_item	2936034	et	3	main
vilumust	doc_919500587377_item	2936035	et	4	main
otsustavad	doc_919500587377_item	2936040	et	4	main
ajalehe	doc_919500587377_item	2936041	et	3	main
üle	doc_919500587377_item	2936042	et	3	main
järgi	doc_919500587377_item	2936045	et	4	main
eeldavad	doc_919500587377_item	2936057	et	4	main
ja	doc_919500587377_item	2936067	et	3	main
on	doc_919500587377_item	2936069	et	4	main
eesti	doc_919500587377_item	2936072	et	4	main
neli	doc_919500587378_item	2936080	et	3	main
võrdluseks	doc_919500587378_item	2936082	et	3	main
õhtulehe	doc_919500587378_item	2936088	et	3	main
27	doc_919500587378_item	2936090	et	2	main
30	doc_919500587378_item	2936092	et	2	main
märtsi	doc_919500587378_item	2936093	et	4	main
sl	doc_919500587378_item	2936099	et	4	main
õhtuleht	doc_919500587378_item	2936100	et	3	main
sest	doc_919500587378_item	2936101	et	4	main
kaupluses	doc_919500587378_item	2936111	et	3	main
imelik	doc_919500587378_item	2936121	et	3	main
selline	doc_919500587378_item	2936123	et	4	main
et	doc_919500587378_item	2936125	et	3	main
suured	doc_919500587378_item	2936134	et	3	main
ostmisega	doc_919500587378_item	2936138	et	4	main
isegi	doc_919500587378_item	2936139	et	4	main
ei	doc_919500587378_item	2936146	et	4	main
olnud	doc_919500587378_item	2936147	et	4	main
mõlemates	doc_919500587378_item	2936148	et	3	main
alati	doc_919500587378_item	2936158	et	4	main
veeruselaius	doc_919500587377_item	2935822	et	4	main
on	doc_919500587377_item	2935827	et	4	main
jaotuses	doc_919500587377_item	2935831	et	4	main
on	doc_919500587377_item	2935834	et	4	main
on	doc_919500587377_item	2935836	et	4	main
laiuses	doc_919500587377_item	2935843	et	4	main
kohti	doc_919500587377_item	2935853	et	4	main
mingi	doc_919500587377_item	2935855	et	4	main
ning	doc_919500587377_item	2935864	et	3	main
paiknetakse	doc_919500587377_item	2935867	et	3	main
täidetakse	doc_919500587377_item	2935872	et	4	main
pigem	doc_919500587377_item	2935873	et	3	main
ei	doc_919500587377_item	2935892	et	4	main
tehtud	doc_919500587377_item	2935902	et	4	main
paksudega	doc_919500587377_item	2935903	et	3	main
tähtedega	doc_919500587377_item	2935904	et	4	main
köidavad	doc_919500587377_item	2935909	et	3	main
on	doc_919500587377_item	2935916	et	4	main
jõukohane	doc_919500587377_item	2935917	et	4	main
arusaamiseks	doc_919500587377_item	2935918	et	4	main
laused	doc_919500587377_item	2935919	et	3	main
on	doc_919500587377_item	2935920	et	4	main
lisada	doc_919500587377_item	2935928	et	3	main
ajalehe	doc_919500587377_item	2935930	et	3	main
erine	doc_919500587377_item	2935933	et	4	main
põrmugi	doc_919500587377_item	2935935	et	4	main
reede	doc_919500587377_item	2935936	et	4	main
numbrilt	doc_919500587377_item	2935937	et	3	main
rubriigid	doc_919500587377_item	2935941	et	3	main
hea	doc_919500587377_item	2935950	et	4	main
ja	doc_919500587377_item	2935951	et	3	main
huvitav	doc_919500587377_item	2935953	et	4	main
määratud	doc_919500587377_item	2935954	et	4	main
inimestele	doc_919500587377_item	2935955	et	3	main
ajalehel	doc_919500587377_item	2935956	et	3	main
on	doc_919500587377_item	2935957	et	4	main
ning	doc_919500587377_item	2935963	et	3	main
ajalehe	doc_919500587377_item	2935988	et	3	main
küll	doc_919500587377_item	2935997	et	4	main
kujundaja	doc_919500587377_item	2936007	et	4	main
läinud	doc_919500587377_item	2936009	et	4	main
ja	doc_919500587377_item	2936012	et	3	main
ja	doc_919500587377_item	2936015	et	3	main
need	doc_919500587377_item	2936021	et	3	main
kindlad	doc_919500587377_item	2936024	et	3	main
nõuab	doc_919500587377_item	2936032	et	3	main
ka	doc_919500587377_item	2936043	et	3	main
kuidas	doc_919500587377_item	2936046	et	3	main
see	doc_919500587377_item	2936047	et	3	main
kui	doc_919500587377_item	2936050	et	3	main
väljanägemine	doc_919500587377_item	2936051	et	3	main
on	doc_919500587377_item	2936052	et	4	main
korralik	doc_919500587377_item	2936053	et	3	main
täpne	doc_919500587377_item	2936054	et	3	main
ja	doc_919500587377_item	2936055	et	3	main
kompetentne	doc_919500587377_item	2936056	et	3	main
lugejad	doc_919500587377_item	2936058	et	4	main
ma	doc_919500587378_item	2936078	et	3	main
märtsi	doc_919500587378_item	2936091	et	4	main
äripäeva	doc_919500587378_item	2936094	et	4	main
lehekülgede	doc_919500587378_item	2936102	et	4	main
värv	doc_919500587378_item	2936103	et	3	main
oli	doc_919500587378_item	2936104	et	3	main
sellega	doc_919500587378_item	2936116	et	3	main
et	doc_919500587378_item	2936117	et	3	main
midagi	doc_919500587377_item	2935925	et	4	main
toimetada	doc_919500587377_item	2935926	et	3	main
põhimõttes	doc_919500587377_item	2935929	et	3	main
ei	doc_919500587377_item	2935932	et	4	main
mitte	doc_919500587377_item	2935934	et	3	main
et	doc_919500587377_item	2935944	et	3	main
oma	doc_919500587377_item	2935960	et	4	main
määratud	doc_919500587377_item	2935961	et	4	main
järgitakse	doc_919500587377_item	2935965	et	4	main
igas	doc_919500587377_item	2935966	et	3	main
numbris	doc_919500587377_item	2935967	et	3	main
number	doc_919500587377_item	2935969	et	3	main
kolmapäeva	doc_919500587377_item	2935968	et	4	main
on	doc_919500587377_item	2935970	et	4	main
parem	doc_919500587377_item	2935971	et	4	main
sl	doc_919500587377_item	2935972	et	4	main
õhtulehel	doc_919500587377_item	2935973	et	3	main
kuna	doc_919500587377_item	2935974	et	3	main
siin	doc_919500587377_item	2935975	et	4	main
on	doc_919500587377_item	2935976	et	4	main
pigem	doc_919500587377_item	2935977	et	3	main
informattivsem	doc_919500587377_item	2935978	et	4	main
ja	doc_919500587377_item	2935979	et	3	main
huvitavam	doc_919500587377_item	2935980	et	4	main
kui	doc_919500587377_item	2935981	et	3	main
äripäevas	doc_919500587377_item	2935982	et	3	main
kokkuvõttes	doc_919500587377_item	2935983	et	3	main
ma	doc_919500587377_item	2935984	et	3	main
tahaks	doc_919500587377_item	2935985	et	3	main
seega	doc_919500587377_item	2935991	et	4	main
seda	doc_919500587377_item	2936001	et	3	main
ei	doc_919500587377_item	2936005	et	4	main
tüpograafia	doc_919500587377_item	2936014	et	4	main
on	doc_919500587377_item	2936022	et	4	main
hea	doc_919500587377_item	2936026	et	4	main
lugejad	doc_919500587377_item	2936039	et	4	main
et	doc_919500587377_item	2936059	et	3	main
kompetentne	doc_919500587377_item	2936063	et	3	main
märtsi	doc_919500587378_item	2936084	et	4	main
alguses	doc_919500587378_item	2936095	et	4	main
mul	doc_919500587378_item	2936096	et	3	main
meeldis	doc_919500587378_item	2936097	et	3	main
rohkem	doc_919500587378_item	2936098	et	4	main
tavaline	doc_919500587378_item	2936105	et	4	main
iga	doc_919500587378_item	2936110	et	4	main
äripäev	doc_919500587378_item	2936112	et	3	main
meeldinud	doc_919500587378_item	2936114	et	4	main
ilme	doc_919500587378_item	2936124	et	4	main
on	doc_919500587378_item	2936127	et	4	main
kuueaasta	doc_919500587378_item	2936128	et	4	main
vanune	doc_919500587378_item	2936129	et	3	main
ajaleht	doc_919500587378_item	2936130	et	3	main
selle	doc_919500587378_item	2936136	et	4	main
asuvas	doc_919500587378_item	2936143	et	4	main
osa	doc_919500587378_item	2936156	et	4	main
ja	doc_919500587378_item	2936160	et	3	main
osa	doc_919500587378_item	2936162	et	4	main
sarnaselt	doc_919500587378_item	2936166	et	4	main
horisontaalselt	doc_919500587378_item	2936168	et	4	main
need	doc_919500587378_item	2936169	et	3	main
vaid	doc_919500587378_item	2936176	et	3	main
üks	doc_919500587378_item	2936179	et	3	main
sl	doc_919500587378_item	2936182	et	4	main
veerus	doc_919500587378_item	2936185	et	4	main
märkanud	doc_919500587378_item	2936187	et	4	main
huvitava	doc_919500587378_item	2936196	et	4	main
sind	doc_919500587378_item	2936197	et	4	main
lihtsalt	doc_919500587378_item	2936202	et	4	main
ka	doc_919500587378_item	2936208	et	3	main
see	doc_919500587378_item	2936209	et	3	main
et	doc_919500587378_item	2936210	et	3	main
sl	doc_919500587378_item	2936211	et	4	main
õhtulehel	doc_919500587378_item	2936212	et	3	main
ülesehitus	doc_919500587378_item	2936225	et	4	main
liigendatud	doc_919500587378_item	2936229	et	4	main
nädalõpulood	doc_919500587378_item	2936246	et	4	main
vabameelsemalt	doc_919500587378_item	2936247	et	4	main
ajalehtedes	doc_919500587378_item	2936249	et	4	main
reklaamileheküljed	doc_919500587378_item	2936250	et	3	main
toimetuse	doc_919500587378_item	2936252	et	4	main
leheküljed	doc_919500587378_item	2936254	et	3	main
koondatud	doc_919500587378_item	2936257	et	4	main
on	doc_919500587378_item	2936262	et	4	main
siin	doc_919500587378_item	2936287	et	4	main
telekava	doc_919500587378_item	2936291	et	4	main
mõlemates	doc_919500587378_item	2936297	et	3	main
võib	doc_919500587378_item	2936299	et	3	main
kohata	doc_919500587378_item	2936300	et	4	main
kõvade	doc_919500587378_item	2936301	et	3	main
lugudega	doc_919500587378_item	2936302	et	3	main
vabamalt	doc_919500587378_item	2936328	et	4	main
lehes	doc_919500587378_item	2936341	et	3	main
ja	doc_919500587378_item	2936343	et	3	main
kolumnistide	doc_919500587378_item	2936361	et	4	main
kujunduselt	doc_919500587378_item	2936382	et	4	main
teine	doc_919500587378_item	2936383	et	3	main
läbivalt	doc_919500587378_item	2936389	et	4	main
börsiinfo	doc_919500587378_item	2936402	et	4	main
saab	doc_919500587378_item	2936404	et	3	main
ainult	doc_919500587378_item	2936406	et	4	main
on	doc_919500587378_item	2936410	et	4	main
ja	doc_919500587378_item	2936414	et	3	main
põhimõtselt	doc_919500587378_item	2936429	et	4	main
siin	doc_919500587378_item	2936441	et	4	main
vertikaalne	doc_919500587378_item	2936443	et	3	main
õhtulehes	doc_919500587378_item	2936447	et	3	main
alused	doc_919500587377_item	2936025	et	4	main
kujundus	doc_919500587377_item	2936027	et	4	main
nagu	doc_919500587377_item	2936028	et	3	main
ka	doc_919500587377_item	2936029	et	3	main
kuid	doc_919500587377_item	2936036	et	4	main
tõstab	doc_919500587377_item	2936037	et	3	main
sisu	doc_919500587377_item	2936061	et	4	main
on	doc_919500587377_item	2936062	et	4	main
ajalehed	doc_919500587377_item	2936064	et	3	main
äripäev	doc_919500587377_item	2936068	et	3	main
hea	doc_919500587377_item	2936070	et	4	main
referaat	doc_919500587378_item	2936074	et	3	main
uurimistöö	doc_919500587378_item	2936076	et	4	main
tegemiseks	doc_919500587378_item	2936077	et	4	main
ajalehte	doc_919500587378_item	2936081	et	4	main
27	doc_919500587378_item	2936085	et	2	main
sl	doc_919500587378_item	2936087	et	4	main
ja	doc_919500587378_item	2936089	et	3	main
ei	doc_919500587378_item	2936113	et	4	main
kohe	doc_919500587378_item	2936115	et	4	main
paberi	doc_919500587378_item	2936118	et	3	main
värv	doc_919500587378_item	2936119	et	3	main
oli	doc_919500587378_item	2936120	et	3	main
ka	doc_919500587378_item	2936132	et	3	main
päris	doc_919500587378_item	2936133	et	4	main
tallinna	doc_919500587378_item	2936140	et	4	main
ülikooli	doc_919500587378_item	2936141	et	4	main
juures	doc_919500587378_item	2936142	et	4	main
ajalehtede	doc_919500587378_item	2936149	et	4	main
asub	doc_919500587378_item	2936157	et	3	main
üleval	doc_919500587378_item	2936159	et	4	main
teine	doc_919500587378_item	2936161	et	3	main
on	doc_919500587378_item	2936165	et	4	main
kujundatud	doc_919500587378_item	2936167	et	4	main
on	doc_919500587378_item	2936177	et	4	main
erinevus	doc_919500587378_item	2936181	et	4	main
teemale	doc_919500587378_item	2936198	et	4	main
seda	doc_919500587378_item	2936200	et	3	main
on	doc_919500587378_item	2936201	et	4	main
on	doc_919500587378_item	2936207	et	4	main
mõlemad	doc_919500587378_item	2936226	et	3	main
on	doc_919500587378_item	2936234	et	4	main
erinevalt	doc_919500587378_item	2936236	et	4	main
poliitika	doc_919500587378_item	2936238	et	4	main
meelelahutusosakonnad	doc_919500587378_item	2936243	et	4	main
sport	doc_919500587378_item	2936244	et	3	main
kultuur	doc_919500587378_item	2936245	et	3	main
materjaliga	doc_919500587378_item	2936253	et	3	main
ole	doc_919500587378_item	2936256	et	4	main
paigaldatud	doc_919500587378_item	2936263	et	4	main
mis	doc_919500587378_item	2936265	et	4	main
lugemise	doc_919500587378_item	2936267	et	4	main
õhtulehes	doc_919500587378_item	2936270	et	3	main
kaksikleheküljele	doc_919500587378_item	2936280	et	3	main
see	doc_919500587378_item	2936282	et	3	main
saab	doc_919500587378_item	2936290	et	3	main
mis	doc_919500587378_item	2936294	et	4	main
kujundusest	doc_919500587378_item	2936321	et	4	main
kujundus	doc_919500587378_item	2936324	et	4	main
on	doc_919500587378_item	2936325	et	4	main
ja	doc_919500587378_item	2936330	et	3	main
ei	doc_919500587378_item	2936335	et	4	main
püsiv	doc_919500587378_item	2936337	et	4	main
vaid	doc_919500587378_item	2936338	et	3	main
nad	doc_919500587378_item	2936339	et	3	main
nende	doc_919500587378_item	2936344	et	4	main
sama	doc_919500587378_item	2936348	et	4	main
on	doc_919500587378_item	2936352	et	4	main
toimetajate	doc_919500587378_item	2936360	et	4	main
suurem	doc_919500587378_item	2936387	et	4	main
kiri	doc_919500587378_item	2936388	et	3	main
on	doc_919500587378_item	2936390	et	4	main
märgata	doc_919500587378_item	2936392	et	4	main
on	doc_919500587378_item	2936395	et	4	main
paigutatud	doc_919500587378_item	2936396	et	4	main
välimistes	doc_919500587378_item	2936398	et	3	main
servades	doc_919500587378_item	2936399	et	3	main
äripäevas	doc_919500587378_item	2936407	et	3	main
börs	doc_919500587378_item	2936418	et	3	main
jagatud	doc_919500587378_item	2936420	et	4	main
rahaturgkaubad	doc_919500587378_item	2936423	et	4	main
kujundus	doc_919500587378_item	2936428	et	4	main
informatsiooni	doc_919500587378_item	2936439	et	4	main
valdab	doc_919500587378_item	2936442	et	3	main
selle	doc_919500587378_item	2936452	et	4	main
see	doc_919500587378_item	2936126	et	3	main
probleemid	doc_919500587378_item	2936135	et	3	main
kioskis	doc_919500587378_item	2936144	et	3	main
on	doc_919500587378_item	2936150	et	4	main
olemas	doc_919500587378_item	2936151	et	4	main
esilehel	doc_919500587378_item	2936152	et	3	main
lugusid	doc_919500587378_item	2936153	et	3	main
mille	doc_919500587378_item	2936154	et	3	main
üks	doc_919500587378_item	2936155	et	3	main
ja	doc_919500587378_item	2936164	et	3	main
komentaarid	doc_919500587378_item	2936175	et	4	main
ka	doc_919500587378_item	2936178	et	3	main
oluline	doc_919500587378_item	2936180	et	4	main
leheküljede	doc_919500587378_item	2936188	et	4	main
numbrit	doc_919500587378_item	2936189	et	3	main
ning	doc_919500587378_item	2936190	et	3	main
on	doc_919500587378_item	2936192	et	4	main
igapäevane	doc_919500587378_item	2936213	et	4	main
tiraaz	doc_919500587378_item	2936214	et	4	main
on	doc_919500587378_item	2936215	et	4	main
märgatud	doc_919500587378_item	2936216	et	4	main
esilehel	doc_919500587378_item	2936217	et	3	main
vaid	doc_919500587378_item	2936218	et	3	main
äripäevas	doc_919500587378_item	2936219	et	3	main
tiraazi	doc_919500587378_item	2936220	et	4	main
ajalehed	doc_919500587378_item	2936227	et	3	main
on	doc_919500587378_item	2936228	et	4	main
erinevad	doc_919500587378_item	2936232	et	4	main
kujundatud	doc_919500587378_item	2936235	et	4	main
info-osakonnad	doc_919500587378_item	2936237	et	4	main
neutralselt	doc_919500587378_item	2936242	et	4	main
ja	doc_919500587378_item	2936251	et	3	main
ühte	doc_919500587378_item	2936258	et	4	main
kohta	doc_919500587378_item	2936259	et	4	main
kokku	doc_919500587378_item	2936260	et	3	main
ja	doc_919500587378_item	2936261	et	3	main
teeb	doc_919500587378_item	2936266	et	3	main
horoskoop	doc_919500587378_item	2936272	et	3	main
on	doc_919500587378_item	2936276	et	4	main
oleks	doc_919500587378_item	2936283	et	3	main
äripäevas	doc_919500587378_item	2936289	et	3	main
on	doc_919500587378_item	2936295	et	4	main
ajalehtedes	doc_919500587378_item	2936298	et	4	main
kõvade	doc_919500587378_item	2936308	et	3	main
regulaarselt	doc_919500587378_item	2936342	et	4	main
kõige	doc_919500587378_item	2936353	et	4	main
lugejate	doc_919500587378_item	2936362	et	4	main
pealkiri	doc_919500587378_item	2936384	et	3	main
teine	doc_919500587378_item	2936385	et	3	main
veerulaius	doc_919500587378_item	2936386	et	4	main
kasutanud	doc_919500587378_item	2936411	et	4	main
alaosakondadeks	doc_919500587378_item	2936421	et	3	main
selle	doc_919500587378_item	2936426	et	4	main
leida	doc_919500587378_item	2936437	et	3	main
otsiva	doc_919500587378_item	2936438	et	4	main
diagrammist	doc_919500587378_item	2936440	et	4	main
siin	doc_919500587378_item	2936455	et	4	main
hästi	doc_919500587378_item	2936456	et	3	main
palju	doc_919500587378_item	2936457	et	4	main
on	doc_919500587378_item	2936463	et	4	main
noored	doc_919500587378_item	2936474	et	3	main
kultuuri	doc_919500587378_item	2936477	et	4	main
vastu	doc_919500587378_item	2936478	et	3	main
kultuuritekstid	doc_919500587378_item	2936485	et	3	main
ja	doc_919500587378_item	2936486	et	3	main
palju	doc_919500587378_item	2936487	et	4	main
huvitavaid	doc_919500587378_item	2936489	et	4	main
fotosid	doc_919500587378_item	2936490	et	3	main
seda	doc_919500587378_item	2936492	et	3	main
on	doc_919500587378_item	2936170	et	4	main
artiklireklaamid	doc_919500587378_item	2936171	et	3	main
lühiuudiste	doc_919500587378_item	2936172	et	3	main
veerg	doc_919500587378_item	2936173	et	3	main
ja	doc_919500587378_item	2936174	et	3	main
õhtulehe	doc_919500587378_item	2936183	et	3	main
ei	doc_919500587378_item	2936186	et	4	main
seepärast	doc_919500587378_item	2936191	et	3	main
raske	doc_919500587378_item	2936194	et	4	main
sest	doc_919500587378_item	2936199	et	4	main
kohta	doc_919500587378_item	2936221	et	4	main
leidu	doc_919500587378_item	2936224	et	4	main
osakonnad	doc_919500587378_item	2936233	et	4	main
majandus	doc_919500587378_item	2936239	et	4	main
ei	doc_919500587378_item	2936255	et	4	main
vahelduvalt	doc_919500587378_item	2936264	et	4	main
ilmateade	doc_919500587378_item	2936271	et	4	main
raadio-	doc_919500587378_item	2936273	et	4	main
paigutatud	doc_919500587378_item	2936277	et	4	main
ajalehe	doc_919500587378_item	2936278	et	3	main
keskmisele	doc_919500587378_item	2936279	et	3	main
nagu	doc_919500587378_item	2936281	et	3	main
kõige	doc_919500587378_item	2936284	et	4	main
tähtsam	doc_919500587378_item	2936285	et	4	main
informatsioon	doc_919500587378_item	2936286	et	3	main
nädalalõpulisas	doc_919500587378_item	2936293	et	3	main
loogilisem	doc_919500587378_item	2936296	et	4	main
osakondi	doc_919500587378_item	2936303	et	4	main
ja	doc_919500587378_item	2936304	et	3	main
pehmete	doc_919500587378_item	2936305	et	3	main
lugudega	doc_919500587378_item	2936306	et	3	main
vabameelsem	doc_919500587378_item	2936326	et	4	main
kasutatakse	doc_919500587378_item	2936327	et	3	main
erinevaid	doc_919500587378_item	2936331	et	4	main
kirju	doc_919500587378_item	2936332	et	4	main
ilmuvad	doc_919500587378_item	2936340	et	4	main
on	doc_919500587378_item	2936346	et	4	main
staatilisem	doc_919500587378_item	2936354	et	4	main
lehekülg	doc_919500587378_item	2936355	et	3	main
ajalehtedes	doc_919500587378_item	2936356	et	4	main
ning	doc_919500587378_item	2936357	et	3	main
sisaldab	doc_919500587378_item	2936358	et	3	main
ja	doc_919500587378_item	2936363	et	3	main
hea	doc_919500587378_item	2936376	et	4	main
eristada	doc_919500587378_item	2936377	et	3	main
lehekülg	doc_919500587378_item	2936379	et	3	main
uudistelehekülgedest	doc_919500587378_item	2936380	et	4	main
ka	doc_919500587378_item	2936381	et	3	main
lehes	doc_919500587378_item	2936391	et	3	main
et	doc_919500587378_item	2936393	et	3	main
lehe	doc_919500587378_item	2936397	et	3	main
olevatesse	doc_919500587378_item	2936400	et	4	main
veergudesse	doc_919500587378_item	2936401	et	3	main
leida	doc_919500587378_item	2936405	et	3	main
liigendamiseks	doc_919500587378_item	2936412	et	4	main
on	doc_919500587378_item	2936419	et	4	main
investeerimine	doc_919500587378_item	2936422	et	4	main
pension	doc_919500587378_item	2936425	et	3	main
osakonna	doc_919500587378_item	2936427	et	4	main
muutumatuks	doc_919500587378_item	2936431	et	4	main
et	doc_919500587378_item	2936433	et	3	main
lugeja	doc_919500587378_item	2936434	et	4	main
saaks	doc_919500587378_item	2936435	et	3	main
kiiresti	doc_919500587378_item	2936436	et	3	main
kujundus	doc_919500587378_item	2936444	et	4	main
sl	doc_919500587378_item	2936446	et	4	main
ei	doc_919500587378_item	2936449	et	4	main
vaid	doc_919500587378_item	2936451	et	3	main
väike	doc_919500587378_item	2936464	et	4	main
hea	doc_919500587378_item	2936471	et	4	main
lahendus	doc_919500587378_item	2936472	et	4	main
et	doc_919500587378_item	2936473	et	3	main
huvi	doc_919500587378_item	2936476	et	4	main
äripäevas	doc_919500587378_item	2936479	et	3	main
on	doc_919500587378_item	2936480	et	4	main
vastupidi	doc_919500587378_item	2936481	et	3	main
suuri	doc_919500587378_item	2936488	et	3	main
edukalt	doc_919500587378_item	2936522	et	4	main
ja	doc_919500587378_item	2936525	et	3	main
meelelahutuse	doc_919500587378_item	2936526	et	4	main
osakond	doc_919500587378_item	2936527	et	3	main
informatsiooni	doc_919500587378_item	2936222	et	4	main
ei	doc_919500587378_item	2936223	et	4	main
temaatilisteks	doc_919500587378_item	2936230	et	4	main
osakondadeks	doc_919500587378_item	2936231	et	3	main
on	doc_919500587378_item	2936240	et	4	main
kujundatud	doc_919500587378_item	2936241	et	4	main
mõlemates	doc_919500587378_item	2936248	et	3	main
huvitavamaks	doc_919500587378_item	2936268	et	4	main
sl	doc_919500587378_item	2936269	et	4	main
ja	doc_919500587378_item	2936274	et	3	main
telekavad	doc_919500587378_item	2936275	et	3	main
ajalehes	doc_919500587378_item	2936288	et	3	main
leida	doc_919500587378_item	2936292	et	3	main
osakondi	doc_919500587378_item	2936307	et	4	main
lugudega	doc_919500587378_item	2936309	et	3	main
osakondade	doc_919500587378_item	2936310	et	3	main
kujundus	doc_919500587378_item	2936311	et	4	main
on	doc_919500587378_item	2936312	et	4	main
rangem	doc_919500587378_item	2936313	et	4	main
reeglipärane	doc_919500587378_item	2936314	et	4	main
ja	doc_919500587378_item	2936315	et	3	main
lihtne	doc_919500587378_item	2936316	et	3	main
ning	doc_919500587378_item	2936317	et	3	main
ei	doc_919500587378_item	2936318	et	4	main
erine	doc_919500587378_item	2936319	et	4	main
uudiste	doc_919500587378_item	2936320	et	3	main
kergete	doc_919500587378_item	2936322	et	4	main
osakondade	doc_919500587378_item	2936323	et	3	main
fotosid	doc_919500587378_item	2936329	et	3	main
osakondade	doc_919500587378_item	2936333	et	3	main
maht	doc_919500587378_item	2936334	et	3	main
ole	doc_919500587378_item	2936336	et	4	main
järjestus	doc_919500587378_item	2936345	et	4	main
alati	doc_919500587378_item	2936347	et	4	main
toimetuse	doc_919500587378_item	2936349	et	4	main
lehekülg	doc_919500587378_item	2936350	et	3	main
see	doc_919500587378_item	2936351	et	3	main
päevast-päeva	doc_919500587378_item	2936359	et	4	main
karikaturistide	doc_919500587378_item	2936364	et	4	main
arvamusi	doc_919500587378_item	2936365	et	3	main
mõlemates	doc_919500587378_item	2936366	et	3	main
ajalehtedes	doc_919500587378_item	2936367	et	4	main
sel	doc_919500587378_item	2936368	et	3	main
leheküljel	doc_919500587378_item	2936369	et	3	main
domineerib	doc_919500587378_item	2936370	et	3	main
arvamus	doc_919500587378_item	2936371	et	3	main
mitte	doc_919500587378_item	2936372	et	3	main
fakt	doc_919500587378_item	2936373	et	3	main
ja	doc_919500587378_item	2936374	et	3	main
on	doc_919500587378_item	2936375	et	4	main
toimetuse	doc_919500587378_item	2936378	et	4	main
lühiuudised	doc_919500587378_item	2936394	et	3	main
börsiinfot	doc_919500587378_item	2936403	et	3	main
selles	doc_919500587378_item	2936408	et	4	main
osas	doc_919500587378_item	2936409	et	4	main
tiiteltähti	doc_919500587378_item	2936413	et	4	main
paremaks	doc_919500587378_item	2936415	et	4	main
eraldamiseks	doc_919500587378_item	2936416	et	4	main
jooni	doc_919500587378_item	2936417	et	4	main
ja	doc_919500587378_item	2936424	et	3	main
jääb	doc_919500587378_item	2936430	et	3	main
selleks	doc_919500587378_item	2936432	et	4	main
kultuuriosakond	doc_919500587378_item	2936445	et	3	main
kultuuritekste	doc_919500587378_item	2936448	et	3	main
ole	doc_919500587378_item	2936450	et	4	main
fotosi	doc_919500587378_item	2936458	et	4	main
ja	doc_919500587378_item	2936459	et	3	main
arvates	doc_919500587378_item	2936467	et	4	main
tunneksid	doc_919500587378_item	2936475	et	4	main
pikad	doc_919500587378_item	2936484	et	4	main
osakonda	doc_919500587378_item	2936493	et	4	main
saab	doc_919500587378_item	2936494	et	3	main
leida	doc_919500587378_item	2936495	et	3	main
nädalalõpulisas	doc_919500587378_item	2936496	et	3	main
see	doc_919500587378_item	2936497	et	3	main
osakond	doc_919500587378_item	2936498	et	3	main
liigendatud	doc_919500587378_item	2936500	et	4	main
alaosakondadeks	doc_919500587378_item	2936501	et	3	main
teater	doc_919500587378_item	2936502	et	3	main
on	doc_919500587378_item	2936499	et	4	main
konsert	doc_919500587378_item	2936503	et	4	main
kino	doc_919500587378_item	2936504	et	4	main
näitus	doc_919500587378_item	2936505	et	3	main
ja	doc_919500587378_item	2936506	et	3	main
vaba	doc_919500587378_item	2936507	et	4	main
aeg	doc_919500587378_item	2936508	et	3	main
see	doc_919500587378_item	2936509	et	3	main
osakond	doc_919500587378_item	2936510	et	3	main
on	doc_919500587378_item	2936511	et	4	main
väga	doc_919500587378_item	2936512	et	3	main
mahukas	doc_919500587378_item	2936513	et	4	main
ja	doc_919500587378_item	2936514	et	3	main
kergesti	doc_919500587378_item	2936515	et	3	main
loetav	doc_919500587378_item	2936516	et	4	main
spordiosakond	doc_919500587378_item	2936517	et	3	main
sl	doc_919500587378_item	2936518	et	4	main
õhtulehes	doc_919500587378_item	2936519	et	3	main
on	doc_919500587378_item	2936520	et	4	main
väga	doc_919500587378_item	2936521	et	3	main
on	doc_919500587378_item	2936532	et	4	main
teemaga	doc_919500587378_item	2936533	et	3	main
individuaalne	doc_919500587378_item	2936539	et	3	main
sl	doc_919500587378_item	2936544	et	4	main
kujundus	doc_919500587378_item	2936552	et	4	main
peegeldab	doc_919500587378_item	2936553	et	3	main
spordi	doc_919500587378_item	2936554	et	4	main
on	doc_919500587378_item	2936557	et	4	main
neid	doc_919500587378_item	2936581	et	4	main
leida	doc_919500587378_item	2936582	et	3	main
spordi	doc_919500587378_item	2936590	et	4	main
leidnud	doc_919500587378_item	2936595	et	4	main
kujundus	doc_919500587378_item	2936606	et	4	main
asemel	doc_919500587378_item	2936453	et	4	main
kujundusi	doc_919500587378_item	2936460	et	4	main
mille	doc_919500587378_item	2936461	et	3	main
tekst	doc_919500587378_item	2936465	et	3	main
on	doc_919500587378_item	2936468	et	4	main
see	doc_919500587378_item	2936469	et	3	main
väga	doc_919500587378_item	2936470	et	3	main
on	doc_919500587378_item	2936483	et	4	main
sellepärast	doc_919500587378_item	2936491	et	3	main
paigutatud	doc_919500587378_item	2936523	et	4	main
kultuuri	doc_919500587378_item	2936524	et	4	main
sobiv	doc_919500587378_item	2936534	et	4	main
dramatismi	doc_919500587378_item	2936555	et	4	main
siluett-fotod	doc_919500587378_item	2936559	et	3	main
pealkirjad	doc_919500587378_item	2936563	et	3	main
kaks	doc_919500587378_item	2936565	et	3	main
suuremad	doc_919500587378_item	2936567	et	4	main
kui	doc_919500587378_item	2936568	et	3	main
selles	doc_919500587378_item	2936583	et	4	main
ajalehes	doc_919500587378_item	2936584	et	3	main
palju	doc_919500587378_item	2936589	et	4	main
üldse	doc_919500587378_item	2936593	et	3	main
olla	doc_919500587378_item	2936602	et	3	main
näiteks	doc_919500587378_item	2936603	et	4	main
ka	doc_919500587378_item	2936604	et	3	main
nädalalõpulisas	doc_919500587378_item	2936605	et	3	main
ja	doc_919500587378_item	2936625	et	3	main
mõlemates	doc_919500587378_item	2936633	et	3	main
ajalehtedes	doc_919500587378_item	2936634	et	4	main
erinevad	doc_919500587378_item	2936641	et	4	main
trükikirjad	doc_919500587378_item	2936642	et	3	main
ja	doc_919500587378_item	2936647	et	3	main
sl	doc_919500587378_item	2936650	et	4	main
on	doc_919500587378_item	2936652	et	4	main
märgitud	doc_919500587378_item	2936683	et	4	main
kõikide	doc_919500587378_item	2936717	et	4	main
osakondade	doc_919500587378_item	2936718	et	3	main
nimed	doc_919500587378_item	2936719	et	3	main
kujundatud	doc_919500587378_item	2936720	et	4	main
on	doc_919500587378_item	2936454	et	4	main
peal	doc_919500587378_item	2936462	et	4	main
minu	doc_919500587378_item	2936466	et	3	main
siin	doc_919500587378_item	2936482	et	4	main
ja	doc_919500587378_item	2936535	et	3	main
samas	doc_919500587378_item	2936536	et	4	main
ka	doc_919500587378_item	2936537	et	3	main
tegi	doc_919500587378_item	2936546	et	4	main
panuse	doc_919500587378_item	2936547	et	3	main
pikematele	doc_919500587378_item	2936548	et	4	main
lugudele	doc_919500587378_item	2936549	et	3	main
aga	doc_919500587378_item	2936550	et	3	main
nende	doc_919500587378_item	2936551	et	4	main
suured	doc_919500587378_item	2936560	et	3	main
fotod	doc_919500587378_item	2936562	et	3	main
spordi	doc_919500587378_item	2936571	et	4	main
osakond	doc_919500587378_item	2936572	et	3	main
lehekülgedel	doc_919500587378_item	2936575	et	4	main
nii	doc_919500587378_item	2936576	et	3	main
et	doc_919500587378_item	2936577	et	3	main
ma	doc_919500587378_item	2936585	et	3	main
ei	doc_919500587378_item	2936586	et	4	main
kohtanud	doc_919500587378_item	2936587	et	4	main
statistikat	doc_919500587378_item	2936591	et	3	main
see	doc_919500587378_item	2936599	et	3	main
teiste	doc_919500587378_item	2936628	et	4	main
ajalehtede	doc_919500587378_item	2936629	et	4	main
seas	doc_919500587378_item	2936630	et	4	main
erinevaid	doc_919500587378_item	2936637	et	4	main
kujundusvahendeid	doc_919500587378_item	2936638	et	3	main
nagu	doc_919500587378_item	2936639	et	3	main
ruum	doc_919500587378_item	2936649	et	3	main
oma	doc_919500587378_item	2936656	et	4	main
värv	doc_919500587378_item	2936657	et	3	main
mis	doc_919500587378_item	2936658	et	4	main
on	doc_919500587378_item	2936659	et	4	main
toimetaja	doc_919500587378_item	2936669	et	4	main
juhataja	doc_919500587378_item	2936671	et	4	main
nimi	doc_919500587378_item	2936672	et	3	main
ja	doc_919500587378_item	2936674	et	3	main
telefoninumber	doc_919500587378_item	2936675	et	3	main
osakond	doc_919500587378_item	2936678	et	3	main
ja	doc_919500587378_item	2936684	et	3	main
nende	doc_919500587378_item	2936726	et	4	main
saab	doc_919500587378_item	2936734	et	3	main
toimetaja	doc_919500587378_item	2936736	et	4	main
telefoni	doc_919500587378_item	2936739	et	4	main
sl	doc_919500587378_item	2936753	et	4	main
see	doc_919500587378_item	2936782	et	3	main
lehekülge	doc_919500587378_item	2936785	et	4	main
ja	doc_919500587378_item	2936788	et	3	main
asub	doc_919500587378_item	2936792	et	3	main
vasakus	doc_919500587378_item	2936798	et	4	main
on	doc_919500587378_item	2936804	et	4	main
muutub	doc_919500587378_item	2936810	et	3	main
sl	doc_919500587378_item	2936820	et	4	main
märkab	doc_919500587378_item	2936822	et	3	main
reklaami	doc_919500587378_item	2936824	et	4	main
lugemist	doc_919500587378_item	2936829	et	4	main
on	doc_919500587378_item	2936838	et	4	main
kõik	doc_919500587378_item	2936839	et	4	main
tunne	doc_919500587378_item	2936852	et	4	main
siin	doc_919500587378_item	2936854	et	4	main
põhjal	doc_919500587378_item	2936863	et	4	main
rahutu	doc_919500587378_item	2936864	et	4	main
pealiskaudse	doc_919500587378_item	2936866	et	3	main
vanamoelisem	doc_919500587378_item	2936877	et	4	main
ja	doc_919500587378_item	2936878	et	3	main
lehekujundus	doc_919500587378_item	2936880	et	3	main
on	doc_919500587378_item	2936881	et	4	main
selge	doc_919500587378_item	2936883	et	4	main
ja	doc_919500587378_item	2936884	et	3	main
ühetähenduslik	doc_919500587378_item	2936885	et	3	main
mis	doc_919500587378_item	2936886	et	4	main
ja	doc_919500587378_item	2936893	et	3	main
tunda	doc_919500587378_item	2936930	et	3	main
pea	doc_919500587378_item	2936941	et	4	main
kuju	doc_919500587378_item	2936945	et	4	main
on	doc_919500587378_item	2936948	et	4	main
kasutatud	doc_919500587378_item	2936949	et	4	main
suure	doc_919500587378_item	2936950	et	3	main
sellega	doc_919500587378_item	2936984	et	3	main
kujundus	doc_919500587378_item	2936531	et	4	main
piisavalt	doc_919500587378_item	2936538	et	4	main
lehe	doc_919500587378_item	2936542	et	3	main
ka	doc_919500587378_item	2936556	et	3	main
kasutatud	doc_919500587378_item	2936558	et	4	main
on	doc_919500587378_item	2936564	et	4	main
astet	doc_919500587378_item	2936566	et	4	main
teistel	doc_919500587378_item	2936569	et	4	main
meestel	doc_919500587378_item	2936578	et	4	main
oleks	doc_919500587378_item	2936579	et	3	main
mugavam	doc_919500587378_item	2936580	et	4	main
eriti	doc_919500587378_item	2936588	et	3	main
aga	doc_919500587378_item	2936598	et	3	main
üldilme	doc_919500587378_item	2936607	et	4	main
sl	doc_919500587378_item	2936608	et	4	main
õhtuleht	doc_919500587378_item	2936609	et	3	main
rõhutab	doc_919500587378_item	2936610	et	3	main
rohkem	doc_919500587378_item	2936611	et	4	main
horisontaalset	doc_919500587378_item	2936612	et	3	main
kujundust	doc_919500587378_item	2936613	et	4	main
aga	doc_919500587378_item	2936614	et	3	main
äripäev	doc_919500587378_item	2936615	et	3	main
vertikaalset	doc_919500587378_item	2936616	et	3	main
kujundust	doc_919500587378_item	2936617	et	4	main
vertikaalne	doc_919500587378_item	2936619	et	3	main
kujundus	doc_919500587378_item	2936620	et	4	main
selline	doc_919500587378_item	2936618	et	4	main
teeb	doc_919500587378_item	2936621	et	3	main
võimalikult	doc_919500587378_item	2936623	et	4	main
muutab	doc_919500587378_item	2936626	et	4	main
äripäeva	doc_919500587378_item	2936627	et	4	main
visuaalselt	doc_919500587378_item	2936631	et	4	main
äratuntavaks	doc_919500587378_item	2936632	et	3	main
näiteks	doc_919500587378_item	2936640	et	4	main
raamid	doc_919500587378_item	2936646	et	4	main
õhtulehes	doc_919500587378_item	2936651	et	3	main
temaatilistel	doc_919500587378_item	2936654	et	4	main
osakonnal	doc_919500587378_item	2936655	et	4	main
näiteks	doc_919500587378_item	2936676	et	4	main
on	doc_919500587378_item	2936679	et	4	main
punase	doc_919500587378_item	2936681	et	4	main
värviga	doc_919500587378_item	2936682	et	4	main
ja	doc_919500587378_item	2936722	et	3	main
peal	doc_919500587378_item	2936727	et	4	main
joon	doc_919500587378_item	2936731	et	4	main
ja	doc_919500587378_item	2936740	et	3	main
e-posti	doc_919500587378_item	2936741	et	4	main
elementideks	doc_919500587378_item	2936748	et	3	main
õhtulehe	doc_919500587378_item	2936754	et	3	main
on	doc_919500587378_item	2936756	et	4	main
lehe	doc_919500587378_item	2936758	et	3	main
vasakule	doc_919500587378_item	2936761	et	4	main
vaid	doc_919500587378_item	2936762	et	3	main
parema	doc_919500587378_item	2936786	et	4	main
sl	doc_919500587378_item	2936789	et	4	main
ka	doc_919500587378_item	2936793	et	3	main
antud	doc_919500587378_item	2936807	et	4	main
korraks	doc_919500587378_item	2936818	et	4	main
sirvib	doc_919500587378_item	2936819	et	3	main
leheküljes	doc_919500587378_item	2936826	et	3	main
väga	doc_919500587378_item	2936830	et	3	main
kohale	doc_919500587378_item	2936836	et	4	main
silma	doc_919500587378_item	2936848	et	4	main
ja	doc_919500587378_item	2936849	et	3	main
tekkib	doc_919500587378_item	2936850	et	3	main
oleks	doc_919500587378_item	2936855	et	3	main
vähem	doc_919500587378_item	2936858	et	4	main
sl	doc_919500587378_item	2936859	et	4	main
ja	doc_919500587378_item	2936528	et	3	main
sport	doc_919500587378_item	2936529	et	3	main
osakondade	doc_919500587378_item	2936530	et	3	main
mis	doc_919500587378_item	2936540	et	4	main
muudab	doc_919500587378_item	2936541	et	3	main
huvitamaks	doc_919500587378_item	2936543	et	3	main
õhtuleht	doc_919500587378_item	2936545	et	3	main
aktiivsed	doc_919500587378_item	2936561	et	3	main
lehekülgedel	doc_919500587378_item	2936570	et	4	main
asub	doc_919500587378_item	2936573	et	3	main
viimastel	doc_919500587378_item	2936574	et	3	main
äripäevas	doc_919500587378_item	2936592	et	3	main
ei	doc_919500587378_item	2936594	et	4	main
spordi	doc_919500587378_item	2936596	et	4	main
osakonda	doc_919500587378_item	2936597	et	4	main
võiks	doc_919500587378_item	2936600	et	4	main
ikkagi	doc_919500587378_item	2936601	et	4	main
on	doc_919500587378_item	2936635	et	4	main
erinevad	doc_919500587378_item	2936643	et	4	main
tühi	doc_919500587378_item	2936648	et	3	main
igal	doc_919500587378_item	2936653	et	3	main
kasutatud	doc_919500587378_item	2936660	et	4	main
ka	doc_919500587378_item	2936661	et	3	main
nende	doc_919500587378_item	2936662	et	4	main
osakondade	doc_919500587378_item	2936663	et	3	main
päismikes	doc_919500587378_item	2936664	et	3	main
kirjas	doc_919500587378_item	2936666	et	4	main
osakonna	doc_919500587378_item	2936667	et	4	main
nimi	doc_919500587378_item	2936668	et	3	main
uudiste	doc_919500587378_item	2936677	et	3	main
alati	doc_919500587378_item	2936680	et	4	main
elu	doc_919500587378_item	2936685	et	4	main
kollase	doc_919500587378_item	2936686	et	4	main
värviga	doc_919500587378_item	2936687	et	4	main
selline	doc_919500587378_item	2936688	et	4	main
värviline	doc_919500587378_item	2936689	et	4	main
kujundus	doc_919500587378_item	2936690	et	4	main
kutsub	doc_919500587378_item	2936691	et	3	main
võimalikult	doc_919500587378_item	2936692	et	4	main
paljusid	doc_919500587378_item	2936693	et	3	main
inimesi	doc_919500587378_item	2936694	et	4	main
tekste	doc_919500587378_item	2936695	et	3	main
lugema	doc_919500587378_item	2936696	et	4	main
ja	doc_919500587378_item	2936697	et	3	main
pilte	doc_919500587378_item	2936698	et	3	main
vaatama	doc_919500587378_item	2936699	et	3	main
selles	doc_919500587378_item	2936700	et	4	main
ajalehes	doc_919500587378_item	2936701	et	3	main
iga	doc_919500587378_item	2936702	et	4	main
temaatilise	doc_919500587378_item	2936703	et	4	main
osakonna	doc_919500587378_item	2936704	et	4	main
nimi	doc_919500587378_item	2936705	et	3	main
on	doc_919500587378_item	2936706	et	4	main
kujundatud	doc_919500587378_item	2936707	et	4	main
raamis	doc_919500587378_item	2936708	et	4	main
ja	doc_919500587378_item	2936709	et	3	main
on	doc_919500587378_item	2936710	et	4	main
väga	doc_919500587378_item	2936711	et	3	main
põnev	doc_919500587378_item	2936712	et	3	main
samal	doc_919500587378_item	2936713	et	3	main
ajal	doc_919500587378_item	2936714	et	4	main
äripäevas	doc_919500587378_item	2936715	et	3	main
on	doc_919500587378_item	2936716	et	4	main
lugemine	doc_919500587378_item	2936622	et	4	main
mugavaks	doc_919500587378_item	2936624	et	3	main
kasutatud	doc_919500587378_item	2936636	et	4	main
värvid	doc_919500587378_item	2936644	et	4	main
jooned	doc_919500587378_item	2936645	et	3	main
kus	doc_919500587378_item	2936665	et	3	main
või	doc_919500587378_item	2936670	et	4	main
e-post	doc_919500587378_item	2936673	et	3	main
saama	doc_919500587378_item	2936723	et	4	main
halli	doc_919500587378_item	2936724	et	4	main
on	doc_919500587378_item	2936728	et	4	main
paks	doc_919500587378_item	2936729	et	3	main
aadressi	doc_919500587378_item	2936742	et	4	main
kujunduselemendid	doc_919500587378_item	2936743	et	3	main
on	doc_919500587378_item	2936750	et	4	main
erinevalt	doc_919500587378_item	2936752	et	4	main
ülaserva	doc_919500587378_item	2936759	et	4	main
joondusega	doc_919500587378_item	2936760	et	4	main
üleval	doc_919500587378_item	2936783	et	4	main
õhtulehes	doc_919500587378_item	2936790	et	3	main
kuupäevarida	doc_919500587378_item	2936791	et	4	main
lehekülje	doc_919500587378_item	2936797	et	3	main
küll	doc_919500587378_item	2936808	et	4	main
aga	doc_919500587378_item	2936809	et	3	main
kujundus	doc_919500587378_item	2936814	et	4	main
kes	doc_919500587378_item	2936816	et	4	main
lihtsalt	doc_919500587378_item	2936817	et	4	main
õhtulehe	doc_919500587378_item	2936821	et	3	main
kohe	doc_919500587378_item	2936823	et	4	main
iga	doc_919500587378_item	2936825	et	4	main
sest	doc_919500587378_item	2936831	et	4	main
on	doc_919500587378_item	2936833	et	4	main
mis	doc_919500587378_item	2936840	et	4	main
torka	doc_919500587378_item	2936847	et	4	main
sellene	doc_919500587378_item	2936851	et	4	main
nagu	doc_919500587378_item	2936853	et	3	main
seda	doc_919500587378_item	2936856	et	3	main
mulje	doc_919500587378_item	2936867	et	4	main
küllaltki	doc_919500587378_item	2936869	et	4	main
usaldusväärsem	doc_919500587378_item	2936876	et	4	main
mille	doc_919500587378_item	2936732	et	3	main
leida	doc_919500587378_item	2936735	et	3	main
nime	doc_919500587378_item	2936737	et	4	main
kontakt	doc_919500587378_item	2936738	et	3	main
muutuvateks	doc_919500587378_item	2936747	et	4	main
äripäevas	doc_919500587378_item	2936763	et	3	main
asub	doc_919500587378_item	2936764	et	3	main
ta	doc_919500587378_item	2936765	et	4	main
veidi	doc_919500587378_item	2936766	et	3	main
madalamal	doc_919500587378_item	2936767	et	4	main
ning	doc_919500587378_item	2936768	et	3	main
on	doc_919500587378_item	2936769	et	4	main
joondatud	doc_919500587378_item	2936770	et	4	main
rõhuga	doc_919500587378_item	2936771	et	3	main
keskele	doc_919500587378_item	2936772	et	3	main
erinevust	doc_919500587378_item	2936773	et	4	main
võib	doc_919500587378_item	2936774	et	3	main
märgata	doc_919500587378_item	2936775	et	4	main
ka	doc_919500587378_item	2936776	et	3	main
kuupäevarea	doc_919500587378_item	2936777	et	3	main
asetusel	doc_919500587378_item	2936778	et	4	main
äripäevas	doc_919500587378_item	2936779	et	3	main
on	doc_919500587378_item	2936780	et	4	main
paigutatud	doc_919500587378_item	2936781	et	4	main
ühe	doc_919500587378_item	2936721	et	4	main
värviga	doc_919500587378_item	2936725	et	4	main
horisontaalne	doc_919500587378_item	2936730	et	3	main
peal	doc_919500587378_item	2936733	et	4	main
jagunevad	doc_919500587378_item	2936744	et	4	main
püsiosaks	doc_919500587378_item	2936745	et	3	main
ja	doc_919500587378_item	2936746	et	3	main
püsiosad	doc_919500587378_item	2936749	et	3	main
paigutatud	doc_919500587378_item	2936751	et	4	main
päis	doc_919500587378_item	2936755	et	4	main
paigutatud	doc_919500587378_item	2936757	et	4	main
iga	doc_919500587378_item	2936784	et	4	main
servale	doc_919500587378_item	2936787	et	3	main
üleval	doc_919500587378_item	2936794	et	4	main
vaid	doc_919500587378_item	2936795	et	3	main
iga	doc_919500587378_item	2936796	et	4	main
servas	doc_919500587378_item	2936799	et	4	main
hulk	doc_919500587378_item	2936801	et	3	main
ja	doc_919500587378_item	2936802	et	3	main
iga	doc_919500587378_item	2936811	et	4	main
päev	doc_919500587378_item	2936812	et	3	main
lugeja	doc_919500587378_item	2936815	et	4	main
raskendab	doc_919500587378_item	2936828	et	3	main
see	doc_919500587378_item	2936832	et	3	main
paigaldatud	doc_919500587378_item	2936834	et	4	main
vale	doc_919500587378_item	2936835	et	4	main
puutub	doc_919500587378_item	2936841	et	3	main
reklaami	doc_919500587378_item	2936842	et	4	main
tehtud	doc_919500587378_item	2936843	et	4	main
arukalt	doc_919500587378_item	2936844	et	4	main
see	doc_919500587378_item	2936845	et	3	main
ei	doc_919500587378_item	2936846	et	4	main
esikaane	doc_919500587378_item	2936862	et	4	main
isegi	doc_919500587378_item	2936865	et	4	main
on	doc_919500587378_item	2936868	et	4	main
seevastu	doc_919500587378_item	2936871	et	3	main
äripäev	doc_919500587378_item	2936872	et	3	main
on	doc_919500587378_item	2936873	et	4	main
kõikidel	doc_919500587378_item	2936888	et	4	main
olulist	doc_919500587378_item	2936891	et	4	main
infot	doc_919500587378_item	2936892	et	3	main
äripäev	doc_919500587378_item	2936896	et	3	main
sisu	doc_919500587378_item	2936925	et	4	main
et	doc_919500587378_item	2936932	et	3	main
esilehele	doc_919500587378_item	2936933	et	4	main
iga	doc_919500587378_item	2936935	et	4	main
kord	doc_919500587378_item	2936936	et	4	main
suur	doc_919500587378_item	2936937	et	3	main
vaid	doc_919500587378_item	2936946	et	3	main
sl	doc_919500587378_item	2936954	et	4	main
õhtulehe	doc_919500587378_item	2936955	et	3	main
lehtedest	doc_919500587378_item	2936982	et	4	main
ja	doc_919500587378_item	2936983	et	3	main
eelmisest	doc_919500587378_item	2936990	et	3	main
saada	doc_919500587378_item	2936997	et	4	main
mis	doc_919500587378_item	2936998	et	4	main
numbrit	doc_919500587378_item	2936999	et	3	main
äripäeva	doc_919500587378_item	2937004	et	4	main
ära	doc_919500587378_item	2937007	et	4	main
ta	doc_919500587378_item	2937022	et	4	main
on	doc_919500587378_item	2937023	et	4	main
punasel	doc_919500587378_item	2937024	et	4	main
foonil	doc_919500587378_item	2937025	et	3	main
tavaliselt	doc_919500587378_item	2937031	et	4	main
inimese	doc_919500587378_item	2937032	et	4	main
kujuga	doc_919500587378_item	2937033	et	3	main
eelmisest	doc_919500587378_item	2937042	et	3	main
pealkirja	doc_919500587378_item	2937045	et	4	main
ja	doc_919500587378_item	2937048	et	3	main
iga	doc_919500587378_item	2937050	et	4	main
ajalehe	doc_919500587378_item	2937051	et	3	main
õhtulehet	doc_919500587378_item	2937057	et	4	main
rõhutab	doc_919500587378_item	2937058	et	3	main
pealkirja	doc_919500587378_item	2937059	et	4	main
mitte	doc_919500587378_item	2937060	et	3	main
artikli	doc_919500587378_item	2937061	et	3	main
sisu	doc_919500587378_item	2937062	et	4	main
on	doc_919500587378_item	2937073	et	4	main
paigaldatud	doc_919500587378_item	2937074	et	4	main
mis	doc_919500587378_item	2937080	et	4	main
tavapärasuse	doc_919500587378_item	2937083	et	4	main
uued	doc_919500587378_item	2937088	et	3	main
reklaami	doc_919500587378_item	2936800	et	4	main
asukoht	doc_919500587378_item	2936803	et	3	main
samuti	doc_919500587378_item	2936805	et	3	main
ette	doc_919500587378_item	2936806	et	4	main
reklaami	doc_919500587378_item	2936813	et	4	main
mis	doc_919500587378_item	2936827	et	4	main
äripäevas	doc_919500587378_item	2936837	et	3	main
oluliselt	doc_919500587378_item	2936857	et	4	main
silmatorkav	doc_919500587378_item	2936870	et	4	main
tema	doc_919500587378_item	2936879	et	4	main
kiiresti	doc_919500587378_item	2936889	et	3	main
jätab	doc_919500587378_item	2936897	et	3	main
esikülje	doc_919500587378_item	2936898	et	3	main
põhjal	doc_919500587378_item	2936899	et	4	main
sisukama	doc_919500587378_item	2936900	et	4	main
mulje	doc_919500587378_item	2936901	et	4	main
sl	doc_919500587378_item	2936902	et	4	main
õhtuleht	doc_919500587378_item	2936903	et	3	main
on	doc_919500587378_item	2936904	et	4	main
palju	doc_919500587378_item	2936905	et	4	main
õhulisem	doc_919500587378_item	2936906	et	4	main
rohkem	doc_919500587378_item	2936907	et	4	main
tühja	doc_919500587378_item	2936908	et	4	main
ruumi	doc_919500587378_item	2936909	et	4	main
suurem	doc_919500587378_item	2936910	et	4	main
reklaam	doc_919500587378_item	2936911	et	3	main
esiküljed	doc_919500587378_item	2936912	et	3	main
ja	doc_919500587378_item	2936913	et	3	main
kaksikleheküljed	doc_919500587378_item	2936914	et	3	main
esikülg	doc_919500587378_item	2936915	et	3	main
mõlemate	doc_919500587378_item	2936916	et	3	main
ajalehtede	doc_919500587378_item	2936917	et	4	main
esikülg	doc_919500587378_item	2936918	et	3	main
identifitseerib	doc_919500587378_item	2936919	et	3	main
oma	doc_919500587378_item	2936920	et	4	main
ajalehe	doc_919500587378_item	2936921	et	3	main
teatab	doc_919500587378_item	2936923	et	3	main
sellepärast	doc_919500587378_item	2936931	et	3	main
foto	doc_919500587378_item	2936938	et	4	main
see	doc_919500587378_item	2936939	et	3	main
inimese	doc_919500587378_item	2936944	et	4	main
alati	doc_919500587378_item	2936947	et	4	main
numbril	doc_919500587378_item	2936956	et	3	main
on	doc_919500587378_item	2936957	et	4	main
ja	doc_919500587378_item	2936960	et	3	main
erinevad	doc_919500587378_item	2936986	et	4	main
annab	doc_919500587378_item	2936992	et	3	main
hea	doc_919500587378_item	2936994	et	4	main
võimaluse	doc_919500587378_item	2936995	et	3	main
aru	doc_919500587378_item	2936996	et	4	main
veel	doc_919500587378_item	2937002	et	4	main
järgi	doc_919500587378_item	2937013	et	4	main
samuti	doc_919500587378_item	2937014	et	3	main
ka	doc_919500587378_item	2937015	et	3	main
ajalehe	doc_919500587378_item	2937016	et	3	main
nimetuse	doc_919500587378_item	2937017	et	4	main
õhtuleht	doc_919500587378_item	2936860	et	3	main
jätab	doc_919500587378_item	2936861	et	3	main
tunduvalt	doc_919500587378_item	2936874	et	4	main
ratsionaalsem	doc_919500587378_item	2936875	et	4	main
lihtne	doc_919500587378_item	2936882	et	3	main
aitab	doc_919500587378_item	2936887	et	3	main
leida	doc_919500587378_item	2936890	et	3	main
orienteeruda	doc_919500587378_item	2936894	et	3	main
lehes	doc_919500587378_item	2936895	et	3	main
ja	doc_919500587378_item	2936922	et	3	main
sl	doc_919500587378_item	2936926	et	4	main
õhtulehe	doc_919500587378_item	2936927	et	3	main
saab	doc_919500587378_item	2936928	et	3	main
pannakse	doc_919500587378_item	2936934	et	3	main
olema	doc_919500587378_item	2936942	et	4	main
alati	doc_919500587378_item	2936943	et	4	main
pealkirja	doc_919500587378_item	2936952	et	4	main
ühel	doc_919500587378_item	2936953	et	3	main
pilt	doc_919500587378_item	2936959	et	3	main
selle	doc_919500587378_item	2936961	et	4	main
peal	doc_919500587378_item	2936962	et	4	main
teiste	doc_919500587378_item	2936987	et	4	main
esilehed	doc_919500587378_item	2936989	et	3	main
selle	doc_919500587378_item	2937009	et	4	main
ajalehe	doc_919500587378_item	2937010	et	3	main
paberi	doc_919500587378_item	2937011	et	3	main
kuju	doc_919500587378_item	2937018	et	4	main
sest	doc_919500587378_item	2937021	et	4	main
on	doc_919500587378_item	2937035	et	4	main
seotud	doc_919500587378_item	2937036	et	4	main
poliitikaga	doc_919500587378_item	2937037	et	3	main
muutub	doc_919500587378_item	2937044	et	3	main
stiil	doc_919500587378_item	2937049	et	3	main
artiklireklaamid	doc_919500587378_item	2937052	et	3	main
on	doc_919500587378_item	2937053	et	4	main
äripäeva	doc_919500587378_item	2937063	et	4	main
ikkagi	doc_919500587378_item	2937066	et	4	main
rohkem	doc_919500587378_item	2937067	et	4	main
uudiste	doc_919500587378_item	2937068	et	3	main
lühikesi	doc_919500587378_item	2937069	et	4	main
kokkuvõtteid	doc_919500587378_item	2937070	et	3	main
need	doc_919500587378_item	2937071	et	3	main
artiklireklaamid	doc_919500587378_item	2937072	et	3	main
nö	doc_919500587378_item	2937078	et	4	main
kuigi	doc_919500587378_item	2937084	et	3	main
ka	doc_919500587378_item	2937092	et	3	main
samuti	doc_919500587378_item	2937107	et	3	main
vahel	doc_919500587378_item	2937127	et	4	main
nädala	doc_919500587378_item	2937128	et	3	main
ajalehtedes	doc_919500587378_item	2937142	et	4	main
klammerdatud	doc_919500587378_item	2937145	et	4	main
et	doc_919500587378_item	2937149	et	3	main
märkida	doc_919500587378_item	2937165	et	4	main
et	doc_919500587378_item	2937166	et	3	main
jätkukoht	doc_919500587378_item	2937170	et	3	main
tähed	doc_919500587378_item	2937178	et	3	main
panna	doc_919500587378_item	2937219	et	4	main
pearõhulisele	doc_919500587378_item	2937221	et	4	main
poole	doc_919500587378_item	2937223	et	4	main
ja	doc_919500587378_item	2937224	et	3	main
on	doc_919500587378_item	2937233	et	4	main
on	doc_919500587378_item	2937244	et	4	main
reklaam	doc_919500587378_item	2937249	et	3	main
tänapäevased	doc_919500587378_item	2937252	et	4	main
vastakleheküljed	doc_919500587378_item	2937255	et	4	main
on	doc_919500587378_item	2937256	et	4	main
tervikuks	doc_919500587378_item	2937258	et	4	main
leheküljele	doc_919500587378_item	2937268	et	3	main
on	doc_919500587378_item	2937269	et	4	main
pandud	doc_919500587378_item	2937270	et	4	main
jäänud	doc_919500587378_item	2937276	et	4	main
välisservadesse	doc_919500587378_item	2937277	et	3	main
veerulaius	doc_919500587378_item	2937286	et	4	main
ja	doc_919500587378_item	2937288	et	3	main
õhtulehes	doc_919500587378_item	2937290	et	3	main
10	doc_919500587378_item	2937295	et	2	main
loetavuse	doc_919500587378_item	2937297	et	4	main
seisukohast	doc_919500587378_item	2937298	et	4	main
õhtulehes	doc_919500587378_item	2937327	et	3	main
kitsam	doc_919500587378_item	2937341	et	4	main
uudistel	doc_919500587378_item	2937343	et	3	main
lehe	doc_919500587378_item	2936924	et	3	main
ära	doc_919500587378_item	2936929	et	4	main
ei	doc_919500587378_item	2936940	et	4	main
tähelist	doc_919500587378_item	2936951	et	4	main
tume	doc_919500587378_item	2936958	et	3	main
on	doc_919500587378_item	2936963	et	4	main
valgete	doc_919500587378_item	2936964	et	4	main
tähtedega	doc_919500587378_item	2936965	et	4	main
pealkiri	doc_919500587378_item	2936966	et	3	main
teises	doc_919500587378_item	2936967	et	4	main
numbris	doc_919500587378_item	2936968	et	3	main
on	doc_919500587378_item	2936969	et	4	main
kasutatud	doc_919500587378_item	2936970	et	4	main
sama	doc_919500587378_item	2936971	et	4	main
kontrasti	doc_919500587378_item	2936972	et	4	main
aga	doc_919500587378_item	2936973	et	3	main
seda	doc_919500587378_item	2936974	et	3	main
hoopis	doc_919500587378_item	2936975	et	3	main
vastupidi	doc_919500587378_item	2936976	et	3	main
sl	doc_919500587378_item	2936977	et	4	main
õhtuleht	doc_919500587378_item	2936978	et	3	main
eristub	doc_919500587378_item	2936979	et	3	main
sellega	doc_919500587378_item	2936980	et	3	main
teistest	doc_919500587378_item	2936981	et	4	main
seoses	doc_919500587378_item	2936985	et	4	main
numbrite	doc_919500587378_item	2936988	et	3	main
mis	doc_919500587378_item	2936991	et	4	main
lugejale	doc_919500587378_item	2936993	et	4	main
ta	doc_919500587378_item	2937000	et	4	main
pole	doc_919500587378_item	2937001	et	3	main
saab	doc_919500587378_item	2937005	et	3	main
värvi	doc_919500587378_item	2937012	et	4	main
torkab	doc_919500587378_item	2937019	et	3	main
äripäeva	doc_919500587378_item	2937026	et	4	main
esilehel	doc_919500587378_item	2937027	et	3	main
on	doc_919500587378_item	2937028	et	4	main
suur	doc_919500587378_item	2937029	et	3	main
numbritest	doc_919500587378_item	2937043	et	4	main
kujundatud	doc_919500587378_item	2937055	et	4	main
sl	doc_919500587378_item	2937056	et	4	main
on	doc_919500587378_item	2937065	et	4	main
raami	doc_919500587378_item	2937079	et	4	main
esitatud	doc_919500587378_item	2937093	et	4	main
paigaldatud	doc_919500587378_item	2937104	et	4	main
lugenud	doc_919500587378_item	2937003	et	4	main
kohe	doc_919500587378_item	2937006	et	4	main
tuntuda	doc_919500587378_item	2937008	et	4	main
silma	doc_919500587378_item	2937020	et	4	main
kes	doc_919500587378_item	2937034	et	4	main
värv	doc_919500587378_item	2937046	et	3	main
annab	doc_919500587378_item	2937081	et	3	main
on	doc_919500587378_item	2937091	et	4	main
ajalehtede	doc_919500587378_item	2937094	et	4	main
nimetused	doc_919500587378_item	2937095	et	4	main
mis	doc_919500587378_item	2937096	et	4	main
uudistest	doc_919500587378_item	2937099	et	4	main
üleval	doc_919500587378_item	2937121	et	4	main
tähtega	doc_919500587378_item	2937125	et	4	main
lehe	doc_919500587378_item	2937126	et	3	main
mitte	doc_919500587378_item	2937136	et	3	main
seotud	doc_919500587378_item	2937137	et	4	main
ja	doc_919500587378_item	2937138	et	3	main
jätkukoht	doc_919500587378_item	2937150	et	3	main
ei	doc_919500587378_item	2937151	et	4	main
lõhu	doc_919500587378_item	2937152	et	4	main
ühtegi	doc_919500587378_item	2937154	et	4	main
jälgida	doc_919500587378_item	2937157	et	3	main
äripäevas	doc_919500587378_item	2937167	et	3	main
vaid	doc_919500587378_item	2937172	et	3	main
õhtulehel	doc_919500587378_item	2937174	et	3	main
on	doc_919500587378_item	2937175	et	4	main
paljudes	doc_919500587378_item	2937176	et	3	main
jätkukohtades	doc_919500587378_item	2937177	et	3	main
jagatud	doc_919500587378_item	2937179	et	4	main
mis	doc_919500587378_item	2937181	et	4	main
aeg	doc_919500587378_item	2937218	et	3	main
vasakule	doc_919500587378_item	2937229	et	4	main
sest	doc_919500587378_item	2937238	et	4	main
saa	doc_919500587378_item	2937240	et	4	main
aru	doc_919500587378_item	2937242	et	4	main
selles	doc_919500587378_item	2937246	et	4	main
kujundatud	doc_919500587378_item	2937257	et	4	main
fotoreportaazid	doc_919500587378_item	2937267	et	4	main
veerud	doc_919500587378_item	2937274	et	4	main
veerud	doc_919500587378_item	2937285	et	4	main
äripäevas	doc_919500587378_item	2937287	et	3	main
sl	doc_919500587378_item	2937289	et	4	main
põhilise	doc_919500587378_item	2937293	et	3	main
sellised	doc_919500587378_item	2937300	et	4	main
kohata	doc_919500587378_item	2937321	et	4	main
ka	doc_919500587378_item	2937325	et	3	main
mõlemad	doc_919500587378_item	2937328	et	3	main
kasutavad	doc_919500587378_item	2937330	et	4	main
varieerimist	doc_919500587378_item	2937332	et	4	main
nii	doc_919500587378_item	2937333	et	3	main
et	doc_919500587378_item	2937334	et	3	main
varieerivad	doc_919500587378_item	2937335	et	4	main
on	doc_919500587378_item	2937349	et	4	main
kui	doc_919500587378_item	2937364	et	3	main
lühikesed	doc_919500587378_item	2937399	et	4	main
märkamatud	doc_919500587378_item	2937402	et	4	main
seepärast	doc_919500587378_item	2937403	et	3	main
pikad	doc_919500587378_item	2937411	et	4	main
foto	doc_919500587378_item	2937030	et	4	main
iga	doc_919500587378_item	2937038	et	4	main
number	doc_919500587378_item	2937039	et	3	main
eristub	doc_919500587378_item	2937040	et	3	main
ka	doc_919500587378_item	2937041	et	3	main
suurus	doc_919500587378_item	2937047	et	4	main
erinevalt	doc_919500587378_item	2937054	et	4	main
esilehel	doc_919500587378_item	2937064	et	3	main
sarnaselt	doc_919500587378_item	2937075	et	4	main
ja	doc_919500587378_item	2937076	et	3	main
loovad	doc_919500587378_item	2937077	et	4	main
leheküljele	doc_919500587378_item	2937082	et	3	main
iga	doc_919500587378_item	2937085	et	4	main
päev	doc_919500587378_item	2937086	et	3	main
on	doc_919500587378_item	2937087	et	4	main
eraldatud	doc_919500587378_item	2937098	et	4	main
on	doc_919500587378_item	2937102	et	4	main
alati	doc_919500587378_item	2937103	et	4	main
samale	doc_919500587378_item	2937105	et	3	main
sl	doc_919500587378_item	2937108	et	4	main
meelitab	doc_919500587378_item	2937110	et	3	main
lugejat	doc_919500587378_item	2937111	et	4	main
sissepoole	doc_919500587378_item	2937112	et	3	main
õhtuleht	doc_919500587378_item	2937109	et	3	main
vaatama	doc_919500587378_item	2937113	et	3	main
näiteks	doc_919500587378_item	2937114	et	4	main
sellega	doc_919500587378_item	2937115	et	3	main
et	doc_919500587378_item	2937116	et	3	main
reedese	doc_919500587378_item	2937117	et	4	main
numbri	doc_919500587378_item	2937118	et	3	main
esilehel	doc_919500587378_item	2937119	et	3	main
on	doc_919500587378_item	2937120	et	4	main
telekava	doc_919500587378_item	2937129	et	4	main
kaksiklehekülg	doc_919500587378_item	2937130	et	3	main
sl	doc_919500587378_item	2937131	et	4	main
õhtulehes	doc_919500587378_item	2937132	et	3	main
vastakleheküljele	doc_919500587378_item	2937133	et	4	main
pannakse	doc_919500587378_item	2937134	et	3	main
omavahel	doc_919500587378_item	2937135	et	3	main
on	doc_919500587378_item	2937143	et	4	main
ja	doc_919500587378_item	2937146	et	3	main
öelda	doc_919500587378_item	2937148	et	4	main
kui	doc_919500587378_item	2937156	et	3	main
lehekülje	doc_919500587378_item	2937159	et	3	main
asuks	doc_919500587378_item	2937161	et	4	main
veeruvahes	doc_919500587378_item	2937162	et	4	main
siis	doc_919500587378_item	2937163	et	3	main
tahaks	doc_919500587378_item	2937164	et	3	main
jääb	doc_919500587378_item	2937168	et	3	main
pooleks	doc_919500587378_item	2937180	et	4	main
reklaam	doc_919500587378_item	2937220	et	3	main
mis	doc_919500587378_item	2937243	et	4	main
ajalehes	doc_919500587378_item	2937247	et	3	main
ikkagi	doc_919500587378_item	2937251	et	4	main
uudised	doc_919500587378_item	2937253	et	3	main
on	doc_919500587378_item	2937261	et	4	main
pandud	doc_919500587378_item	2937263	et	4	main
suured	doc_919500587378_item	2937264	et	3	main
samateemalised	doc_919500587378_item	2937271	et	4	main
ja	doc_919500587378_item	2937278	et	3	main
sellega	doc_919500587378_item	2937279	et	3	main
nad	doc_919500587378_item	2937280	et	3	main
moodustavad	doc_919500587378_item	2937281	et	4	main
leheküljele	doc_919500587378_item	2937282	et	3	main
kasutatud	doc_919500587378_item	2937292	et	4	main
cic	doc_919500587378_item	2937296	et	4	main
nii	doc_919500587378_item	2937322	et	3	main
äripäevas	doc_919500587378_item	2937323	et	3	main
uudised	doc_919500587378_item	2937089	et	3	main
esilehtedel	doc_919500587378_item	2937090	et	4	main
on	doc_919500587378_item	2937097	et	4	main
selgelt	doc_919500587378_item	2937100	et	4	main
ja	doc_919500587378_item	2937101	et	3	main
kohale	doc_919500587378_item	2937106	et	4	main
alati	doc_919500587378_item	2937122	et	4	main
trükitud	doc_919500587378_item	2937123	et	4	main
suurte	doc_919500587378_item	2937124	et	3	main
lood	doc_919500587378_item	2937140	et	4	main
mõlemates	doc_919500587378_item	2937141	et	3	main
võib	doc_919500587378_item	2937147	et	3	main
sõnavahesse	doc_919500587378_item	2937171	et	4	main
sl	doc_919500587378_item	2937173	et	4	main
poole	doc_919500587378_item	2937230	et	4	main
selles	doc_919500587378_item	2937231	et	4	main
olukorras	doc_919500587378_item	2937232	et	3	main
ei	doc_919500587378_item	2937239	et	4	main
olulisem	doc_919500587378_item	2937245	et	4	main
kas	doc_919500587378_item	2937248	et	3	main
sinna	doc_919500587378_item	2937260	et	3	main
edukalt	doc_919500587378_item	2937262	et	4	main
intervjuud	doc_919500587378_item	2937265	et	4	main
ja	doc_919500587378_item	2937266	et	3	main
lood	doc_919500587378_item	2937272	et	4	main
lühiuudiste	doc_919500587378_item	2937273	et	3	main
omamoodi	doc_919500587378_item	2937283	et	3	main
on	doc_919500587378_item	2937299	et	4	main
eriteemalised	doc_919500587378_item	2937139	et	4	main
lehed	doc_919500587378_item	2937144	et	3	main
fotodel	doc_919500587378_item	2937153	et	3	main
detaili	doc_919500587378_item	2937155	et	4	main
et	doc_919500587378_item	2937158	et	3	main
jätkukoht	doc_919500587378_item	2937160	et	3	main
pealkirja	doc_919500587378_item	2937169	et	4	main
sobib	doc_919500587378_item	2937182	et	3	main
ka	doc_919500587378_item	2937183	et	3	main
lugemiseks	doc_919500587378_item	2937184	et	4	main
kuid	doc_919500587378_item	2937185	et	4	main
natuke	doc_919500587378_item	2937186	et	4	main
raskendab	doc_919500587378_item	2937187	et	3	main
seda	doc_919500587378_item	2937188	et	3	main
kui	doc_919500587378_item	2937189	et	3	main
rääkida	doc_919500587378_item	2937190	et	3	main
kaksiklehekülje	doc_919500587378_item	2937191	et	3	main
vaatamisjärjekorrast	doc_919500587378_item	2937192	et	4	main
siis	doc_919500587378_item	2937193	et	3	main
tavaliselt	doc_919500587378_item	2937194	et	4	main
langeb	doc_919500587378_item	2937195	et	3	main
pilk	doc_919500587378_item	2937196	et	3	main
esmalt	doc_919500587378_item	2937197	et	3	main
parempoolse	doc_919500587378_item	2937198	et	3	main
keskmisele	doc_919500587378_item	2937199	et	3	main
elemendile	doc_919500587378_item	2937200	et	3	main
siis	doc_919500587378_item	2937201	et	3	main
tuleb	doc_919500587378_item	2937202	et	3	main
välja	doc_919500587378_item	2937203	et	4	main
et	doc_919500587378_item	2937204	et	3	main
sl	doc_919500587378_item	2937205	et	4	main
õhtulehel	doc_919500587378_item	2937206	et	3	main
nendeks	doc_919500587378_item	2937207	et	4	main
elementideks	doc_919500587378_item	2937208	et	3	main
on	doc_919500587378_item	2937209	et	4	main
reklaam	doc_919500587378_item	2937210	et	3	main
minu	doc_919500587378_item	2937211	et	3	main
jaoks	doc_919500587378_item	2937212	et	4	main
on	doc_919500587378_item	2937213	et	4	main
see	doc_919500587378_item	2937214	et	3	main
mõttetu	doc_919500587378_item	2937215	et	4	main
strateegia	doc_919500587378_item	2937216	et	4	main
kogu	doc_919500587378_item	2937217	et	4	main
paremale	doc_919500587378_item	2937222	et	4	main
jätta	doc_919500587378_item	2937225	et	3	main
tähtsam	doc_919500587378_item	2937226	et	4	main
informatsioon	doc_919500587378_item	2937227	et	3	main
siis	doc_919500587378_item	2937228	et	3	main
raske	doc_919500587378_item	2937234	et	4	main
jälgida	doc_919500587378_item	2937235	et	3	main
põhi	doc_919500587378_item	2937236	et	3	main
uudiseid	doc_919500587378_item	2937237	et	3	main
lihtsalt	doc_919500587378_item	2937241	et	4	main
või	doc_919500587378_item	2937250	et	4	main
äripäevas	doc_919500587378_item	2937254	et	3	main
ja	doc_919500587378_item	2937259	et	3	main
on	doc_919500587378_item	2937275	et	4	main
raami	doc_919500587378_item	2937284	et	4	main
on	doc_919500587378_item	2937291	et	4	main
veerulaiusena	doc_919500587378_item	2937294	et	4	main
veerud	doc_919500587378_item	2937301	et	4	main
liiga	doc_919500587378_item	2937302	et	4	main
kitsad	doc_919500587378_item	2937303	et	3	main
kuid	doc_919500587378_item	2937304	et	4	main
samal	doc_919500587378_item	2937305	et	3	main
ajal	doc_919500587378_item	2937306	et	4	main
selline	doc_919500587378_item	2937307	et	4	main
veerulaius	doc_919500587378_item	2937308	et	4	main
annab	doc_919500587378_item	2937309	et	3	main
võimaluse	doc_919500587378_item	2937310	et	3	main
lihtsalt	doc_919500587378_item	2937311	et	4	main
kaks	doc_919500587378_item	2937312	et	3	main
veergu	doc_919500587378_item	2937313	et	4	main
kokku	doc_919500587378_item	2937314	et	3	main
lükata	doc_919500587378_item	2937315	et	4	main
kahte	doc_919500587378_item	2937316	et	4	main
kokkulükatud	doc_919500587378_item	2937317	et	4	main
veergu	doc_919500587378_item	2937318	et	4	main
võib	doc_919500587378_item	2937319	et	3	main
harva	doc_919500587378_item	2937320	et	4	main
kui	doc_919500587378_item	2937324	et	3	main
veerulaiust	doc_919500587378_item	2937336	et	4	main
on	doc_919500587378_item	2937340	et	4	main
kitsam	doc_919500587378_item	2937350	et	4	main
uudistel	doc_919500587378_item	2937353	et	3	main
üks	doc_919500587378_item	2937367	et	3	main
kasutatakse	doc_919500587378_item	2937371	et	3	main
veerud	doc_919500587378_item	2937400	et	4	main
on	doc_919500587378_item	2937401	et	4	main
veerud	doc_919500587378_item	2937412	et	4	main
neid	doc_919500587378_item	2937416	et	4	main
äripäev	doc_919500587378_item	2937420	et	3	main
veerud	doc_919500587378_item	2937429	et	4	main
alati	doc_919500587378_item	2937440	et	4	main
sirgete	doc_919500587378_item	2937442	et	4	main
osakonna	doc_919500587378_item	2937447	et	4	main
taandatud	doc_919500587378_item	2937454	et	4	main
kares	doc_919500587378_item	2937455	et	4	main
ümber	doc_919500587378_item	2937456	et	3	main
foto	doc_919500587378_item	2937457	et	4	main
panna	doc_919500587378_item	2937465	et	4	main
lehe	doc_919500587378_item	2937467	et	3	main
keskele	doc_919500587378_item	2937468	et	3	main
aitab	doc_919500587378_item	2937469	et	3	main
sl	doc_919500587378_item	2937326	et	4	main
ajalehed	doc_919500587378_item	2937329	et	3	main
veerulaiuse	doc_919500587378_item	2937331	et	4	main
sl	doc_919500587378_item	2937338	et	4	main
kasutuses	doc_919500587378_item	2937352	et	4	main
ja	doc_919500587378_item	2937354	et	3	main
veerupikkus	doc_919500587378_item	2937363	et	4	main
ja	doc_919500587378_item	2937369	et	3	main
numbrist	doc_919500587378_item	2937372	et	3	main
siis	doc_919500587378_item	2937374	et	3	main
veerupikkuse	doc_919500587378_item	2937375	et	4	main
valik	doc_919500587378_item	2937376	et	3	main
on	doc_919500587378_item	2937377	et	4	main
iga	doc_919500587378_item	2937378	et	4	main
konkreetse	doc_919500587378_item	2937379	et	3	main
lehekülje	doc_919500587378_item	2937380	et	3	main
kujundamise	doc_919500587378_item	2937381	et	4	main
probleem	doc_919500587378_item	2937382	et	3	main
ideaalne	doc_919500587378_item	2937383	et	3	main
veerupikkus	doc_919500587378_item	2937384	et	4	main
on	doc_919500587378_item	2937385	et	4	main
5	doc_919500587378_item	2937386	et	2	main
konkreetse	doc_919500587378_item	2937387	et	3	main
loo	doc_919500587378_item	2937388	et	4	main
veerupikkuse	doc_919500587378_item	2937389	et	4	main
otsustamisel	doc_919500587378_item	2937390	et	4	main
tähtis	doc_919500587378_item	2937392	et	4	main
on	doc_919500587378_item	2937391	et	4	main
mõjur	doc_919500587378_item	2937393	et	3	main
mulje	doc_919500587378_item	2937394	et	4	main
mille	doc_919500587378_item	2937395	et	3	main
veerud	doc_919500587378_item	2937396	et	4	main
jätavad	doc_919500587378_item	2937397	et	3	main
liiga	doc_919500587378_item	2937398	et	4	main
osakonniti	doc_919500587378_item	2937337	et	4	main
õhtulehes	doc_919500587378_item	2937339	et	3	main
veerg	doc_919500587378_item	2937342	et	3	main
laiem	doc_919500587378_item	2937345	et	4	main
naise	doc_919500587378_item	2937346	et	3	main
osakonnal	doc_919500587378_item	2937347	et	4	main
äripäevas	doc_919500587378_item	2937348	et	3	main
osakonnas	doc_919500587378_item	2937362	et	4	main
veerulaius	doc_919500587378_item	2937365	et	4	main
kord	doc_919500587378_item	2937368	et	4	main
seda	doc_919500587378_item	2937370	et	3	main
pikki	doc_919500587378_item	2937406	et	4	main
veerusid	doc_919500587378_item	2937407	et	3	main
igavad	doc_919500587378_item	2937413	et	3	main
on	doc_919500587378_item	2937417	et	4	main
raske	doc_919500587378_item	2937418	et	4	main
lugeda	doc_919500587378_item	2937419	et	3	main
kasutab	doc_919500587378_item	2937421	et	3	main
ja	doc_919500587378_item	2937431	et	3	main
tervikuna	doc_919500587378_item	2937432	et	3	main
tekst	doc_919500587378_item	2937433	et	3	main
tuntub	doc_919500587378_item	2937434	et	4	main
kolonidenna	doc_919500587378_item	2937443	et	4	main
muudab	doc_919500587378_item	2937445	et	3	main
on	doc_919500587378_item	2937452	et	4	main
mis	doc_919500587378_item	2937458	et	4	main
lisab	doc_919500587378_item	2937459	et	3	main
lubab	doc_919500587378_item	2937464	et	3	main
suuruses	doc_919500587378_item	2937480	et	4	main
ei	doc_919500587378_item	2937482	et	4	main
nad	doc_919500587378_item	2937484	et	3	main
teksti	doc_919500587378_item	2937503	et	4	main
ja	doc_919500587378_item	2937504	et	3	main
cic	doc_919500587378_item	2937510	et	4	main
ühes	doc_919500587378_item	2937514	et	4	main
kohas	doc_919500587378_item	2937515	et	4	main
tühja	doc_919500587378_item	2937521	et	4	main
jätta	doc_919500587378_item	2937523	et	3	main
mõndades	doc_919500587378_item	2937527	et	4	main
kasutatud	doc_919500587378_item	2937529	et	4	main
tiiteltähti	doc_919500587378_item	2937531	et	4	main
hallis	doc_919500587378_item	2937538	et	4	main
kirjas	doc_919500587378_item	2937539	et	4	main
ja	doc_919500587378_item	2937540	et	3	main
on	doc_919500587378_item	2937546	et	4	main
kergetes	doc_919500587378_item	2937548	et	4	main
suurus	doc_919500587378_item	2937551	et	4	main
kindel	doc_919500587378_item	2937553	et	3	main
arv	doc_919500587378_item	2937554	et	3	main
ridu	doc_919500587378_item	2937555	et	3	main
kasutatud	doc_919500587378_item	2937567	et	4	main
kujunduselemendina	doc_919500587378_item	2937568	et	3	main
sama	doc_919500587378_item	2937608	et	4	main
kiri	doc_919500587378_item	2937615	et	3	main
äripäeva	doc_919500587378_item	2937617	et	4	main
lugemise	doc_919500587378_item	2937618	et	4	main
teeb	doc_919500587378_item	2937619	et	3	main
võimalikult	doc_919500587378_item	2937620	et	4	main
ja	doc_919500587378_item	2937344	et	3	main
veerg	doc_919500587378_item	2937351	et	3	main
laiemat	doc_919500587378_item	2937355	et	4	main
veergu	doc_919500587378_item	2937356	et	4	main
võib	doc_919500587378_item	2937357	et	3	main
leida	doc_919500587378_item	2937358	et	3	main
toimetuse	doc_919500587378_item	2937359	et	4	main
leheküljel	doc_919500587378_item	2937360	et	3	main
arvamuse	doc_919500587378_item	2937361	et	3	main
otsustatakse	doc_919500587378_item	2937366	et	3	main
numbrisse	doc_919500587378_item	2937373	et	3	main
mõlemad	doc_919500587378_item	2937405	et	3	main
sl	doc_919500587378_item	2937408	et	4	main
õhtulehes	doc_919500587378_item	2937409	et	3	main
on	doc_919500587378_item	2937410	et	4	main
ja	doc_919500587378_item	2937415	et	3	main
loo	doc_919500587378_item	2937424	et	4	main
juures	doc_919500587378_item	2937425	et	4	main
ja	doc_919500587378_item	2937426	et	3	main
seetõttu	doc_919500587378_item	2937427	et	3	main
lühem	doc_919500587378_item	2937435	et	4	main
mõne	doc_919500587378_item	2937446	et	3	main
igavaks	doc_919500587378_item	2937449	et	4	main
veerud	doc_919500587378_item	2937453	et	4	main
elavust	doc_919500587378_item	2937461	et	4	main
jäävad	doc_919500587378_item	2937496	et	4	main
illustratsiooni	doc_919500587378_item	2937505	et	4	main
vahele	doc_919500587378_item	2937520	et	4	main
kasutavad	doc_919500587378_item	2937404	et	4	main
hallid	doc_919500587378_item	2937414	et	4	main
tulevad	doc_919500587378_item	2937428	et	4	main
kaarladu	doc_919500587378_item	2937436	et	4	main
äripäevas	doc_919500587378_item	2937437	et	3	main
on	doc_919500587378_item	2937438	et	4	main
mis	doc_919500587378_item	2937444	et	4	main
ajalehes	doc_919500587378_item	2937448	et	3	main
võte	doc_919500587378_item	2937463	et	3	main
optimalses	doc_919500587378_item	2937479	et	4	main
veerulaiused	doc_919500587378_item	2937487	et	4	main
see	doc_919500587378_item	2937488	et	3	main
muudab	doc_919500587378_item	2937489	et	3	main
on	doc_919500587378_item	2937501	et	4	main
jäänud	doc_919500587378_item	2937507	et	4	main
toimetajad	doc_919500587378_item	2937516	et	4	main
vist	doc_919500587378_item	2937517	et	4	main
unustasid	doc_919500587378_item	2937518	et	4	main
ruumi	doc_919500587378_item	2937522	et	4	main
on	doc_919500587378_item	2937535	et	4	main
suuremas	doc_919500587378_item	2937537	et	4	main
teksti	doc_919500587378_item	2937543	et	4	main
sisse	doc_919500587378_item	2937544	et	4	main
tiiteltäht	doc_919500587378_item	2937545	et	3	main
õhtulehes	doc_919500587378_item	2937559	et	3	main
ei	doc_919500587378_item	2937562	et	4	main
nendega	doc_919500587378_item	2937570	et	4	main
on	doc_919500587378_item	2937571	et	4	main
üks	doc_919500587378_item	2937572	et	3	main
tekst	doc_919500587378_item	2937573	et	3	main
on	doc_919500587378_item	2937604	et	4	main
see	doc_919500587378_item	2937605	et	3	main
üks	doc_919500587378_item	2937606	et	3	main
ja	doc_919500587378_item	2937607	et	3	main
halvasti	doc_919500587378_item	2937613	et	3	main
stiil	doc_919500587378_item	2937616	et	3	main
mõlemates	doc_919500587378_item	2937625	et	3	main
on	doc_919500587378_item	2937627	et	4	main
on	doc_919500587378_item	2937632	et	4	main
tähtevahe	doc_919500587378_item	2937633	et	4	main
välja	doc_919500587378_item	2937641	et	4	main
artiklite	doc_919500587378_item	2937642	et	3	main
artikli	doc_919500587378_item	2937652	et	3	main
või	doc_919500587378_item	2937657	et	4	main
küsimuste	doc_919500587378_item	2937659	et	4	main
mõlemates	doc_919500587378_item	2937661	et	3	main
märgatavad	doc_919500587378_item	2937671	et	4	main
sl	doc_919500587378_item	2937675	et	4	main
äripäeva	doc_919500587378_item	2937679	et	4	main
pealkirjast	doc_919500587378_item	2937690	et	4	main
võib	doc_919500587378_item	2937694	et	3	main
on	doc_919500587378_item	2937698	et	4	main
kohtades	doc_919500587378_item	2937703	et	3	main
teksti	doc_919500587378_item	2937708	et	4	main
suurusele	doc_919500587378_item	2937710	et	4	main
näiteks	doc_919500587378_item	2937711	et	4	main
peatuma	doc_919500587378_item	2937743	et	4	main
nad	doc_919500587378_item	2937750	et	3	main
ka	doc_919500587378_item	2937753	et	3	main
on	doc_919500587378_item	2937755	et	4	main
kasutamiskõlblikud	doc_919500587378_item	2937756	et	3	main
sobiva	doc_919500587378_item	2937757	et	4	main
hea	doc_919500587378_item	2937761	et	4	main
sama	doc_919500587378_item	2937766	et	4	main
äripäeva	doc_919500587378_item	2937768	et	4	main
kohta	doc_919500587378_item	2937769	et	4	main
kvaliteetsed	doc_919500587378_item	2937776	et	3	main
mõned	doc_919500587378_item	2937777	et	3	main
nendest	doc_919500587378_item	2937778	et	4	main
mõned	doc_919500587378_item	2937782	et	3	main
ei	doc_919500587378_item	2937789	et	4	main
lugeja	doc_919500587378_item	2937791	et	4	main
mis	doc_919500587378_item	2937824	et	4	main
tekstis	doc_919500587378_item	2937825	et	3	main
mitte	doc_919500587378_item	2937829	et	3	main
mitte	doc_919500587378_item	2937844	et	3	main
rohkem	doc_919500587378_item	2937855	et	4	main
aga	doc_919500587378_item	2937860	et	3	main
ning	doc_919500587378_item	2937864	et	3	main
ei	doc_919500587378_item	2937869	et	4	main
anna	doc_919500587378_item	2937870	et	4	main
mingit	doc_919500587378_item	2937871	et	3	main
rohkem	doc_919500587378_item	2937422	et	4	main
ühe	doc_919500587378_item	2937423	et	4	main
väiksemad	doc_919500587378_item	2937430	et	4	main
veerud	doc_919500587378_item	2937439	et	4	main
kulgenud	doc_919500587378_item	2937441	et	4	main
sl	doc_919500587378_item	2937450	et	4	main
õhtulehes	doc_919500587378_item	2937451	et	3	main
lehekülgedele	doc_919500587378_item	2937460	et	4	main
see	doc_919500587378_item	2937462	et	3	main
illustratsiooni	doc_919500587378_item	2937466	et	4	main
tihedamalt	doc_919500587378_item	2937473	et	4	main
liituda	doc_919500587378_item	2937474	et	3	main
laseb	doc_919500587378_item	2937475	et	3	main
illustratsioone	doc_919500587378_item	2937476	et	3	main
kasutada	doc_919500587378_item	2937477	et	3	main
nende	doc_919500587378_item	2937478	et	4	main
sl	doc_919500587378_item	2937490	et	4	main
õhtulehe	doc_919500587378_item	2937491	et	3	main
huvitavamaks	doc_919500587378_item	2937492	et	4	main
ja	doc_919500587378_item	2937493	et	3	main
sellised	doc_919500587378_item	2937494	et	4	main
artiklid	doc_919500587378_item	2937495	et	3	main
paremini	doc_919500587378_item	2937497	et	4	main
tavaliselt	doc_919500587378_item	2937502	et	4	main
vähemalt	doc_919500587378_item	2937508	et	4	main
1	doc_919500587378_item	2937509	et	2	main
ruumi	doc_919500587378_item	2937512	et	4	main
vaid	doc_919500587378_item	2937513	et	3	main
nenede	doc_919500587378_item	2937519	et	4	main
liigendusvõtted	doc_919500587378_item	2937524	et	4	main
kohtades	doc_919500587378_item	2937528	et	3	main
esimene	doc_919500587378_item	2937533	et	3	main
on	doc_919500587378_item	2937552	et	4	main
rida	doc_919500587378_item	2937557	et	4	main
sl	doc_919500587378_item	2937558	et	4	main
liigendamiseks	doc_919500587378_item	2937561	et	4	main
kasutada	doc_919500587378_item	2937563	et	3	main
mõlemates	doc_919500587378_item	2937564	et	3	main
ajalehtedes	doc_919500587378_item	2937565	et	4	main
lugu	doc_919500587378_item	2937609	et	4	main
kuna	doc_919500587378_item	2937610	et	3	main
joon	doc_919500587378_item	2937611	et	4	main
märgatav	doc_919500587378_item	2937614	et	4	main
hästi	doc_919500587378_item	2937622	et	3	main
ajalehtedes	doc_919500587378_item	2937626	et	4	main
sobiv	doc_919500587378_item	2937628	et	4	main
reavahe	doc_919500587378_item	2937629	et	4	main
on	doc_919500587378_item	2937634	et	4	main
suurem	doc_919500587378_item	2937635	et	4	main
ja	doc_919500587378_item	2937636	et	3	main
seepärast	doc_919500587378_item	2937637	et	3	main
kiri	doc_919500587378_item	2937638	et	3	main
näeb	doc_919500587378_item	2937639	et	3	main
erinevate	doc_919500587378_item	2937653	et	4	main
esiletõstmisel	doc_919500587378_item	2937660	et	3	main
kohendatud	doc_919500587378_item	2937683	et	4	main
teiene	doc_919500587378_item	2937688	et	4	main
osa	doc_919500587378_item	2937689	et	4	main
allpool	doc_919500587378_item	2937692	et	3	main
kui	doc_919500587378_item	2937696	et	3	main
jagatud	doc_919500587378_item	2937699	et	4	main
mitmele	doc_919500587378_item	2937700	et	4	main
lehele	doc_919500587378_item	2937701	et	3	main
ei	doc_919500587378_item	2937706	et	4	main
suurusega	doc_919500587378_item	2937715	et	4	main
20	doc_919500587378_item	2937716	et	2	main
punktilise	doc_919500587378_item	2937722	et	4	main
siiski	doc_919500587378_item	2937730	et	4	main
illustratsioonid	doc_919500587378_item	2937734	et	3	main
õhtulehe	doc_919500587378_item	2937736	et	3	main
suunaga	doc_919500587378_item	2937758	et	4	main
ei	doc_919500587378_item	2937764	et	4	main
on	doc_919500587378_item	2937779	et	4	main
liiga	doc_919500587378_item	2937783	et	4	main
ka	doc_919500587378_item	2937788	et	3	main
ärata	doc_919500587378_item	2937790	et	4	main
pildil	doc_919500587378_item	2937470	et	3	main
ja	doc_919500587378_item	2937471	et	3	main
sõnadel	doc_919500587378_item	2937472	et	3	main
siis	doc_919500587378_item	2937481	et	3	main
pea	doc_919500587378_item	2937483	et	4	main
olema	doc_919500587378_item	2937485	et	4	main
täpselt	doc_919500587378_item	2937486	et	4	main
meeles	doc_919500587378_item	2937498	et	3	main
sl	doc_919500587378_item	2937499	et	4	main
õhtulehes	doc_919500587378_item	2937500	et	3	main
vahele	doc_919500587378_item	2937506	et	4	main
tühja	doc_919500587378_item	2937511	et	4	main
äripäevas	doc_919500587378_item	2937525	et	3	main
lõigu	doc_919500587378_item	2937532	et	4	main
on	doc_919500587378_item	2937541	et	4	main
upputanud	doc_919500587378_item	2937542	et	4	main
tiiteltähe	doc_919500587378_item	2937550	et	3	main
3	doc_919500587378_item	2937556	et	2	main
tiiteltähti	doc_919500587378_item	2937560	et	4	main
jooni	doc_919500587378_item	2937569	et	4	main
loetav	doc_919500587378_item	2937623	et	4	main
kuid	doc_919500587378_item	2937630	et	4	main
kirja	doc_919500587378_item	2937650	et	4	main
osade	doc_919500587378_item	2937654	et	3	main
on	doc_919500587378_item	2937669	et	4	main
hästi	doc_919500587378_item	2937670	et	3	main
kui	doc_919500587378_item	2937677	et	3	main
ei	doc_919500587378_item	2937681	et	4	main
ole	doc_919500587378_item	2937682	et	4	main
näha	doc_919500587378_item	2937695	et	3	main
suurus	doc_919500587378_item	2937705	et	4	main
aga	doc_919500587378_item	2937717	et	3	main
tekst	doc_919500587378_item	2937718	et	3	main
ise	doc_919500587378_item	2937719	et	4	main
oli	doc_919500587378_item	2937720	et	3	main
kuid	doc_919500587378_item	2937724	et	4	main
minu	doc_919500587378_item	2937725	et	3	main
arvates	doc_919500587378_item	2937726	et	4	main
loogilisem	doc_919500587378_item	2937727	et	4	main
oleks	doc_919500587378_item	2937728	et	3	main
kasutada	doc_919500587378_item	2937729	et	3	main
suurusega	doc_919500587378_item	2937732	et	4	main
fotod	doc_919500587378_item	2937745	et	3	main
infot	doc_919500587378_item	2937747	et	3	main
sellega	doc_919500587378_item	2937749	et	3	main
teksti	doc_919500587378_item	2937752	et	4	main
nad	doc_919500587378_item	2937754	et	3	main
kvaliteediga	doc_919500587378_item	2937762	et	3	main
öelda	doc_919500587378_item	2937767	et	4	main
ei	doc_919500587378_item	2937774	et	4	main
ole	doc_919500587378_item	2937775	et	4	main
heledad	doc_919500587378_item	2937784	et	3	main
nad	doc_919500587378_item	2937787	et	3	main
näitavad	doc_919500587378_item	2937821	et	4	main
ikka	doc_919500587378_item	2937822	et	4	main
seda	doc_919500587378_item	2937823	et	3	main
on	doc_919500587378_item	2937826	et	4	main
meeldib	doc_919500587378_item	2937833	et	3	main
õhtulehe	doc_919500587378_item	2937835	et	3	main
keskse	doc_919500587378_item	2937839	et	3	main
nagu	doc_919500587378_item	2937848	et	3	main
taustaks	doc_919500587378_item	2937867	et	3	main
ja	doc_919500587378_item	2937868	et	3	main
öelda	doc_919500587378_item	2937875	et	4	main
lõigatud	doc_919500587378_item	2937885	et	4	main
mulje	doc_919500587378_item	2937889	et	4	main
inimestel	doc_919500587378_item	2937891	et	3	main
on	doc_919500587378_item	2937892	et	4	main
puudu	doc_919500587378_item	2937895	et	4	main
ajalehtedes	doc_919500587378_item	2937897	et	4	main
äripäevas	doc_919500587378_item	2937922	et	3	main
paigutatud	doc_919500587378_item	2937929	et	4	main
pildi	doc_919500587378_item	2937941	et	4	main
alla	doc_919500587378_item	2937942	et	3	main
ei	doc_919500587378_item	2937945	et	4	main
sa	doc_919500587378_item	2937946	et	3	main
terviklikult	doc_919500587378_item	2937947	et	4	main
kui	doc_919500587378_item	2937953	et	3	main
sl	doc_919500587378_item	2937955	et	4	main
foto	doc_919500587378_item	2937959	et	4	main
korda	doc_919500587378_item	2937961	et	4	main
on	doc_919500587378_item	2937969	et	4	main
on	doc_919500587378_item	2937526	et	4	main
liigendamiseks	doc_919500587378_item	2937530	et	4	main
täht	doc_919500587378_item	2937534	et	3	main
trükkitud	doc_919500587378_item	2937536	et	4	main
kasutatud	doc_919500587378_item	2937547	et	4	main
lugudes	doc_919500587378_item	2937549	et	3	main
on	doc_919500587378_item	2937566	et	4	main
teisest	doc_919500587378_item	2937574	et	4	main
eristatud	doc_919500587378_item	2937575	et	4	main
äripäevas	doc_919500587378_item	2937576	et	3	main
on	doc_919500587378_item	2937577	et	4	main
paksed	doc_919500587378_item	2937578	et	4	main
hallid	doc_919500587378_item	2937579	et	4	main
jooned	doc_919500587378_item	2937580	et	3	main
ja	doc_919500587378_item	2937581	et	3	main
sl	doc_919500587378_item	2937582	et	4	main
õhtulehes	doc_919500587378_item	2937583	et	3	main
on	doc_919500587378_item	2937584	et	4	main
peened	doc_919500587378_item	2937585	et	3	main
mustad	doc_919500587378_item	2937586	et	4	main
jooned	doc_919500587378_item	2937587	et	3	main
kui	doc_919500587378_item	2937588	et	3	main
vaadates	doc_919500587378_item	2937589	et	3	main
sl	doc_919500587378_item	2937590	et	4	main
õhtulehte	doc_919500587378_item	2937591	et	4	main
siis	doc_919500587378_item	2937592	et	3	main
vahest	doc_919500587378_item	2937593	et	4	main
ei	doc_919500587378_item	2937594	et	4	main
saa	doc_919500587378_item	2937595	et	4	main
aru	doc_919500587378_item	2937596	et	4	main
kas	doc_919500587378_item	2937597	et	3	main
lehele	doc_919500587378_item	2937598	et	3	main
on	doc_919500587378_item	2937599	et	4	main
erinevad	doc_919500587378_item	2937600	et	4	main
artiklid	doc_919500587378_item	2937601	et	3	main
paigutatud	doc_919500587378_item	2937602	et	4	main
või	doc_919500587378_item	2937603	et	4	main
on	doc_919500587378_item	2937612	et	4	main
mugavaks	doc_919500587378_item	2937621	et	3	main
äripäevas	doc_919500587378_item	2937631	et	3	main
paremini	doc_919500587378_item	2937640	et	4	main
sees	doc_919500587378_item	2937643	et	4	main
kasutatakse	doc_919500587378_item	2937651	et	3	main
pealkirjades	doc_919500587378_item	2937655	et	3	main
intervjuudes	doc_919500587378_item	2937658	et	3	main
ajalehtedes	doc_919500587378_item	2937662	et	4	main
pealkirjad	doc_919500587378_item	2937664	et	3	main
paigutatud	doc_919500587378_item	2937665	et	4	main
kohtadesse	doc_919500587378_item	2937666	et	3	main
kus	doc_919500587378_item	2937667	et	3	main
nad	doc_919500587378_item	2937668	et	3	main
arusaadavad	doc_919500587378_item	2937673	et	3	main
nii	doc_919500587378_item	2937674	et	3	main
õhtulehe	doc_919500587378_item	2937676	et	3	main
ka	doc_919500587378_item	2937678	et	3	main
pealkirjad	doc_919500587378_item	2937680	et	3	main
ühe	doc_919500587378_item	2937684	et	4	main
horisontaalse	doc_919500587378_item	2937685	et	3	main
joonega	doc_919500587378_item	2937686	et	3	main
ja	doc_919500587378_item	2937687	et	3	main
jookseb	doc_919500587378_item	2937691	et	3	main
artikkel	doc_919500587378_item	2937697	et	3	main
pealkirja	doc_919500587378_item	2937712	et	4	main
tekst	doc_919500587378_item	2937713	et	3	main
oli	doc_919500587378_item	2937714	et	3	main
10	doc_919500587378_item	2937721	et	2	main
tekst	doc_919500587378_item	2937731	et	3	main
fotod	doc_919500587378_item	2937737	et	3	main
huvi	doc_919500587378_item	2937739	et	4	main
ja	doc_919500587378_item	2937740	et	3	main
sunnivad	doc_919500587378_item	2937741	et	3	main
lugejat	doc_919500587378_item	2937742	et	4	main
need	doc_919500587378_item	2937744	et	3	main
täiendavad	doc_919500587378_item	2937751	et	4	main
kahjuks	doc_919500587378_item	2937763	et	4	main
sest	doc_919500587378_item	2937770	et	4	main
siin	doc_919500587378_item	2937771	et	4	main
need	doc_919500587378_item	2937772	et	3	main
liiga	doc_919500587378_item	2937780	et	4	main
ja	doc_919500587378_item	2937785	et	3	main
seda	doc_919500587378_item	2937830	et	3	main
peategelasi	doc_919500587378_item	2937842	et	3	main
mingit	doc_919500587378_item	2937845	et	3	main
fotodega	doc_919500587378_item	2937858	et	3	main
jätavad	doc_919500587378_item	2937861	et	3	main
mulje	doc_919500587378_item	2937863	et	4	main
äripäevas	doc_919500587378_item	2937877	et	3	main
enamik	doc_919500587378_item	2937879	et	3	main
portreedest	doc_919500587378_item	2937881	et	4	main
ja	doc_919500587378_item	2937886	et	3	main
siluett-fotosid	doc_919500587378_item	2937900	et	3	main
teised	doc_919500587378_item	2937902	et	4	main
kirjatekst	doc_919500587378_item	2937624	et	3	main
on	doc_919500587378_item	2937644	et	4	main
kasutatud	doc_919500587378_item	2937645	et	4	main
ühe	doc_919500587378_item	2937646	et	4	main
suurusega	doc_919500587378_item	2937647	et	4	main
kirja	doc_919500587378_item	2937648	et	4	main
rasvast	doc_919500587378_item	2937649	et	4	main
kapslides	doc_919500587378_item	2937656	et	4	main
on	doc_919500587378_item	2937663	et	4	main
ja	doc_919500587378_item	2937672	et	3	main
seda	doc_919500587378_item	2937693	et	3	main
mõndades	doc_919500587378_item	2937702	et	4	main
pealkirjade	doc_919500587378_item	2937704	et	3	main
vastanud	doc_919500587378_item	2937707	et	4	main
kirja	doc_919500587378_item	2937709	et	4	main
kirjaga	doc_919500587378_item	2937723	et	3	main
12	doc_919500587378_item	2937733	et	2	main
sl	doc_919500587378_item	2937735	et	4	main
äratavad	doc_919500587378_item	2937738	et	4	main
annavad	doc_919500587378_item	2937746	et	3	main
ja	doc_919500587378_item	2937748	et	3	main
ja	doc_919500587378_item	2937759	et	3	main
on	doc_919500587378_item	2937760	et	4	main
saa	doc_919500587378_item	2937765	et	4	main
fotod	doc_919500587378_item	2937773	et	3	main
tumedad	doc_919500587378_item	2937781	et	3	main
seepärast	doc_919500587378_item	2937786	et	3	main
huvi	doc_919500587378_item	2937792	et	4	main
mõlemates	doc_919500587378_item	2937793	et	3	main
ajalehtedes	doc_919500587378_item	2937794	et	4	main
valdavad	doc_919500587378_item	2937795	et	4	main
dokumentaalfotod	doc_919500587378_item	2937796	et	3	main
palju	doc_919500587378_item	2937797	et	4	main
sündmusfotosid	doc_919500587378_item	2937798	et	3	main
saab	doc_919500587378_item	2937799	et	3	main
leida	doc_919500587378_item	2937800	et	3	main
sl	doc_919500587378_item	2937801	et	4	main
õhtulehe	doc_919500587378_item	2937802	et	3	main
spordi	doc_919500587378_item	2937803	et	4	main
osakonnas	doc_919500587378_item	2937804	et	4	main
siin	doc_919500587378_item	2937805	et	4	main
on	doc_919500587378_item	2937806	et	4	main
valitud	doc_919500587378_item	2937807	et	4	main
küllaltki	doc_919500587378_item	2937808	et	4	main
head	doc_919500587378_item	2937809	et	4	main
pildid	doc_919500587378_item	2937810	et	3	main
dünaamilised	doc_919500587378_item	2937811	et	3	main
ja	doc_919500587378_item	2937812	et	3	main
enamuses	doc_919500587378_item	2937813	et	4	main
spontaansed	doc_919500587378_item	2937814	et	3	main
need	doc_919500587378_item	2937815	et	3	main
fotod	doc_919500587378_item	2937816	et	3	main
annavad	doc_919500587378_item	2937817	et	3	main
leheküljele	doc_919500587378_item	2937818	et	3	main
liikuvust	doc_919500587378_item	2937819	et	4	main
ja	doc_919500587378_item	2937820	et	3	main
oluline	doc_919500587378_item	2937827	et	4	main
mis	doc_919500587378_item	2937831	et	4	main
annavad	doc_919500587378_item	2937837	et	3	main
sündmuse	doc_919500587378_item	2937840	et	3	main
suvalist	doc_919500587378_item	2937846	et	4	main
lavastatud	doc_919500587378_item	2937856	et	4	main
poseeritud	doc_919500587378_item	2937857	et	4	main
mis	doc_919500587378_item	2937859	et	4	main
informatsiooni	doc_919500587378_item	2937872	et	4	main
veel	doc_919500587378_item	2937873	et	4	main
tahaks	doc_919500587378_item	2937874	et	3	main
aga	doc_919500587378_item	2937828	et	3	main
fotograafile	doc_919500587378_item	2937832	et	4	main
sl	doc_919500587378_item	2937834	et	4	main
fotod	doc_919500587378_item	2937836	et	3	main
edasi	doc_919500587378_item	2937838	et	3	main
sõlm-momente	doc_919500587378_item	2937841	et	3	main
tegutsemas	doc_919500587378_item	2937843	et	3	main
ajahetke	doc_919500587378_item	2937847	et	4	main
see	doc_919500587378_item	2937849	et	3	main
tehtud	doc_919500587378_item	2937850	et	4	main
äripäevas	doc_919500587378_item	2937851	et	3	main
äripäevas	doc_919500587378_item	2937852	et	3	main
saab	doc_919500587378_item	2937853	et	3	main
tutvuda	doc_919500587378_item	2937854	et	3	main
ebausutava	doc_919500587378_item	2937862	et	4	main
muutuvad	doc_919500587378_item	2937865	et	4	main
kergesti	doc_919500587378_item	2937866	et	3	main
ära	doc_919500587378_item	2937884	et	4	main
pead	doc_919500587378_item	2937894	et	4	main
siluett-fotosid	doc_919500587378_item	2937910	et	3	main
kuid	doc_919500587378_item	2937911	et	4	main
neid	doc_919500587378_item	2937912	et	4	main
ei	doc_919500587378_item	2937913	et	4	main
pakku	doc_919500587378_item	2937914	et	4	main
rohkem	doc_919500587378_item	2937915	et	4	main
lugejatele	doc_919500587378_item	2937916	et	4	main
vaid	doc_919500587378_item	2937917	et	3	main
vastupidi	doc_919500587378_item	2937918	et	3	main
tõukavad	doc_919500587378_item	2937919	et	4	main
nad	doc_919500587378_item	2937920	et	3	main
on	doc_919500587378_item	2937923	et	4	main
iga	doc_919500587378_item	2937924	et	4	main
siluett-foto	doc_919500587378_item	2937930	et	4	main
ronib	doc_919500587378_item	2937933	et	3	main
peale	doc_919500587378_item	2937935	et	4	main
pealkirjade	doc_919500587378_item	2937937	et	3	main
jäävad	doc_919500587378_item	2937940	et	4	main
et	doc_919500587378_item	2937944	et	3	main
äripäevas	doc_919500587378_item	2937952	et	3	main
ka	doc_919500587378_item	2937954	et	3	main
ükski	doc_919500587378_item	2937958	et	4	main
räägi	doc_919500587378_item	2937965	et	4	main
tekstile	doc_919500587378_item	2937966	et	3	main
vastu	doc_919500587378_item	2937967	et	3	main
ja	doc_919500587378_item	2937973	et	3	main
seotud	doc_919500587378_item	2937986	et	4	main
olemas	doc_919500587378_item	2937995	et	4	main
peaaegu	doc_919500587378_item	2937996	et	3	main
kõikidel	doc_919500587378_item	2937997	et	4	main
piltidel	doc_919500587378_item	2937998	et	3	main
ainult	doc_919500587378_item	2937999	et	4	main
terviku	doc_919500587378_item	2938008	et	3	main
mõistetavad	doc_919500587378_item	2938018	et	4	main
juuresolevat	doc_919500587378_item	2938021	et	3	main
on	doc_919500587378_item	2938031	et	4	main
5-realise	doc_919500587378_item	2938042	et	4	main
laiuselt	doc_919500587378_item	2938050	et	4	main
püsiv	doc_919500587378_item	2938063	et	4	main
polyglot	doc_919500587378_item	2938094	et	4	main
popstaar	doc_919500587378_item	2938095	et	3	main
sl	doc_919500587378_item	2938104	et	4	main
õhtulehes	doc_919500587378_item	2938105	et	3	main
on	doc_919500587378_item	2938106	et	4	main
näha	doc_919500587378_item	2938107	et	3	main
et	doc_919500587378_item	2938108	et	3	main
ja	doc_919500587378_item	2938111	et	3	main
pealkiri	doc_919500587378_item	2938121	et	3	main
soojal	doc_919500587378_item	2938124	et	3	main
maal	doc_919500587378_item	2938125	et	4	main
midagi	doc_919500587378_item	2938127	et	4	main
et	doc_919500587378_item	2937876	et	3	main
jääb	doc_919500587378_item	2937887	et	3	main
et	doc_919500587378_item	2937890	et	3	main
pool	doc_919500587378_item	2937893	et	4	main
peale	doc_919500587378_item	2937899	et	4	main
palju	doc_919500587378_item	2937909	et	4	main
mis	doc_919500587378_item	2937931	et	4	main
tihtipeale	doc_919500587378_item	2937932	et	3	main
nii	doc_919500587378_item	2937943	et	3	main
lugeda	doc_919500587378_item	2937950	et	3	main
õhtulehes	doc_919500587378_item	2937956	et	3	main
ei	doc_919500587378_item	2937964	et	4	main
tekstiga	doc_919500587378_item	2937972	et	3	main
sobib	doc_919500587378_item	2937976	et	3	main
on	doc_919500587378_item	2937981	et	4	main
poole	doc_919500587378_item	2937988	et	4	main
ja	doc_919500587378_item	2937989	et	3	main
iseseisva	doc_919500587378_item	2938007	et	3	main
ei	doc_919500587378_item	2938010	et	4	main
korda	doc_919500587378_item	2938011	et	4	main
pealkirjas	doc_919500587378_item	2938012	et	3	main
ega	doc_919500587378_item	2938013	et	3	main
kapslis	doc_919500587378_item	2938014	et	3	main
lugematafotoallkirjades	doc_919500587378_item	2938023	et	4	main
informatsioon	doc_919500587378_item	2938025	et	3	main
harva	doc_919500587378_item	2938034	et	4	main
asuvad	doc_919500587378_item	2938045	et	4	main
on	doc_919500587378_item	2938053	et	4	main
mõned	doc_919500587378_item	2938054	et	3	main
allkirjad	doc_919500587378_item	2938055	et	3	main
koht	doc_919500587378_item	2938064	et	3	main
foto	doc_919500587378_item	2938065	et	4	main
all	doc_919500587378_item	2938066	et	3	main
laotud	doc_919500587378_item	2938071	et	4	main
state	doc_919500587378_item	2938096	et	4	main
universityst	doc_919500587378_item	2938097	et	4	main
paremaks	doc_919500587378_item	2938103	et	4	main
poliitikud	doc_919500587378_item	2938122	et	3	main
veergu	doc_919500587378_item	2938137	et	4	main
saanud	doc_919500587378_item	2938140	et	4	main
sest	doc_919500587378_item	2938145	et	4	main
oli	doc_919500587378_item	2938147	et	3	main
mingit	doc_919500587378_item	2938154	et	3	main
leidsin	doc_919500587378_item	2938157	et	3	main
selles	doc_919500587378_item	2938158	et	4	main
lehes	doc_919500587378_item	2938159	et	3	main
et	doc_919500587378_item	2938160	et	3	main
pealkiri	doc_919500587378_item	2938161	et	3	main
ei	doc_919500587378_item	2938162	et	4	main
mis	doc_919500587378_item	2938165	et	4	main
artikli	doc_919500587378_item	2938167	et	3	main
piiireeet	doc_919500587378_item	2938173	et	4	main
kati	doc_919500587378_item	2938174	et	3	main
jaoks	doc_919500587378_item	2938210	et	4	main
vaatamata	doc_919500587378_item	2938215	et	4	main
on	doc_919500587378_item	2938229	et	4	main
mugavam	doc_919500587378_item	2938230	et	4	main
lugeda	doc_919500587378_item	2938231	et	3	main
äripäev	doc_919500587378_item	2938232	et	3	main
pärast	doc_919500587378_item	2938247	et	4	main
teiseks	doc_919500587378_item	2938256	et	4	main
mõndades	doc_919500587378_item	2938257	et	4	main
piltide	doc_919500587378_item	2938259	et	3	main
kvaliteet	doc_919500587378_item	2938260	et	3	main
on	doc_919500587378_item	2938261	et	4	main
halb	doc_919500587378_item	2938262	et	3	main
lugeda	doc_919500587378_item	2938268	et	3	main
pärast	doc_919500587378_item	2938269	et	4	main
õhulise	doc_919500587378_item	2938274	et	4	main
ajalehe	doc_919500587378_item	2938276	et	3	main
selles	doc_919500587378_item	2938278	et	4	main
ajalehes	doc_919500587378_item	2938279	et	3	main
reklaam	doc_919500587378_item	2938281	et	3	main
ma	doc_919500587378_item	2938328	et	3	main
hea	doc_919500587378_item	2938331	et	4	main
lehekujundamise	doc_919500587378_item	2938332	et	3	main
pärast	doc_919500587378_item	2938333	et	4	main
referaat	doc_919500587379_item	2938334	et	3	main
uurimiseks	doc_919500587379_item	2938335	et	4	main
ma	doc_919500587379_item	2938336	et	3	main
valisin	doc_919500587379_item	2938337	et	3	main
on	doc_919500587378_item	2937878	et	4	main
inimeste	doc_919500587378_item	2937880	et	3	main
ülevalt	doc_919500587378_item	2937882	et	4	main
osa	doc_919500587378_item	2937883	et	4	main
selline	doc_919500587378_item	2937888	et	4	main
mõlemates	doc_919500587378_item	2937896	et	3	main
on	doc_919500587378_item	2937898	et	4	main
kõik	doc_919500587378_item	2937901	et	4	main
on	doc_919500587378_item	2937903	et	4	main
nelinurksed	doc_919500587378_item	2937904	et	3	main
äripäevas	doc_919500587378_item	2937905	et	3	main
võib	doc_919500587378_item	2937906	et	3	main
leida	doc_919500587378_item	2937907	et	3	main
tohutult	doc_919500587378_item	2937908	et	4	main
eemale	doc_919500587378_item	2937921	et	3	main
ja	doc_919500587378_item	2937936	et	3	main
tähed	doc_919500587378_item	2937939	et	3	main
mitte	doc_919500587378_item	2937957	et	3	main
ei	doc_919500587378_item	2937960	et	4	main
fotod	doc_919500587378_item	2937968	et	3	main
nende	doc_919500587378_item	2937974	et	4	main
suunatud	doc_919500587378_item	2937982	et	4	main
pilguga	doc_919500587378_item	2937984	et	3	main
fotoallkirjad	doc_919500587378_item	2937993	et	3	main
on	doc_919500587378_item	2937994	et	4	main
need	doc_919500587378_item	2938002	et	3	main
puuduvad	doc_919500587378_item	2938003	et	4	main
enamik	doc_919500587378_item	2938004	et	3	main
fotoallkirjadest	doc_919500587378_item	2938005	et	3	main
on	doc_919500587378_item	2938017	et	4	main
osakonna	doc_919500587378_item	2937925	et	4	main
juures	doc_919500587378_item	2937926	et	4	main
samal	doc_919500587378_item	2937927	et	3	main
real	doc_919500587378_item	2937928	et	3	main
pealkirja	doc_919500587378_item	2937934	et	4	main
viimased	doc_919500587378_item	2937938	et	3	main
sõna	doc_919500587378_item	2937948	et	4	main
välja	doc_919500587378_item	2937949	et	4	main
nii	doc_919500587378_item	2937951	et	3	main
teineteist	doc_919500587378_item	2937962	et	4	main
ja	doc_919500587378_item	2937963	et	3	main
seotud	doc_919500587378_item	2937971	et	4	main
asendiga	doc_919500587378_item	2937978	et	3	main
vaataja	doc_919500587378_item	2937983	et	4	main
nendega	doc_919500587378_item	2937985	et	4	main
tekstide	doc_919500587378_item	2937987	et	3	main
moodustavad	doc_919500587378_item	2938006	et	4	main
ja	doc_919500587378_item	2938009	et	3	main
ka	doc_919500587378_item	2938019	et	3	main
lugu	doc_919500587378_item	2938022	et	4	main
pikkus	doc_919500587378_item	2938030	et	4	main
sl	doc_919500587378_item	2938037	et	4	main
õhtulehes	doc_919500587378_item	2938038	et	3	main
võib	doc_919500587378_item	2938039	et	3	main
aga	doc_919500587378_item	2938040	et	3	main
leida	doc_919500587378_item	2938041	et	3	main
sl	doc_919500587378_item	2938051	et	4	main
paigutatud	doc_919500587378_item	2938056	et	4	main
fotost	doc_919500587378_item	2938057	et	3	main
paremal	doc_919500587378_item	2938058	et	4	main
paremal	doc_919500587378_item	2938067	et	4	main
ei	doc_919500587378_item	2938099	et	4	main
pealkiri	doc_919500587378_item	2938109	et	3	main
tekst	doc_919500587378_item	2938112	et	3	main
omavahel	doc_919500587378_item	2938115	et	3	main
näiteks	doc_919500587378_item	2938117	et	4	main
ja	doc_919500587378_item	2938126	et	3	main
ma	doc_919500587378_item	2938138	et	3	main
ka	doc_919500587378_item	2938141	et	3	main
fotoga	doc_919500587378_item	2938144	et	3	main
tehtud	doc_919500587378_item	2938148	et	4	main
egiptuses	doc_919500587378_item	2938149	et	4	main
ja	doc_919500587378_item	2938150	et	3	main
anna	doc_919500587378_item	2938163	et	4	main
kujundatud	doc_919500587378_item	2938213	et	4	main
kujundus	doc_919500587378_item	2938221	et	4	main
veenitab	doc_919500587378_item	2938224	et	4	main
näeb	doc_919500587378_item	2938233	et	3	main
välja	doc_919500587378_item	2938234	et	4	main
teiselt	doc_919500587378_item	2938239	et	4	main
poolt	doc_919500587378_item	2938240	et	4	main
esiteks	doc_919500587378_item	2938248	et	3	main
on	doc_919500587378_item	2938249	et	4	main
pead	doc_919500587378_item	2938254	et	4	main
tappab	doc_919500587378_item	2938265	et	4	main
jätab	doc_919500587378_item	2938273	et	3	main
kohale	doc_919500587378_item	2938286	et	4	main
sisaldavad	doc_919500587378_item	2938324	et	4	main
äripäeva	doc_919500587378_item	2938330	et	4	main
et	doc_919500587379_item	2938344	et	3	main
paremini	doc_919500587379_item	2938346	et	4	main
ja	doc_919500587379_item	2938347	et	3	main
neid	doc_919500587379_item	2938349	et	4	main
teine-	doc_919500587379_item	2938361	et	3	main
nimbrit	doc_919500587379_item	2938363	et	4	main
õhtulehe	doc_919500587379_item	2938368	et	3	main
püüan	doc_919500587379_item	2938398	et	3	main
hinde	doc_919500587379_item	2938416	et	4	main
selliste	doc_919500587379_item	2938419	et	4	main
ajalehtede	doc_919500587379_item	2938420	et	4	main
plussid	doc_919500587379_item	2938421	et	3	main
visuaalselt	doc_919500587378_item	2937970	et	4	main
suund	doc_919500587378_item	2937975	et	3	main
tema	doc_919500587378_item	2937977	et	4	main
plokis	doc_919500587378_item	2937979	et	3	main
fotod	doc_919500587378_item	2937980	et	3	main
lehekülgede	doc_919500587378_item	2937990	et	4	main
sisse	doc_919500587378_item	2937991	et	4	main
fotoallikad	doc_919500587378_item	2937992	et	3	main
väiksemal	doc_919500587378_item	2938000	et	4	main
siluett-fotol	doc_919500587378_item	2938001	et	3	main
öeldut	doc_919500587378_item	2938015	et	4	main
nad	doc_919500587378_item	2938016	et	3	main
ilma	doc_919500587378_item	2938020	et	4	main
2	doc_919500587378_item	2938032	et	2	main
rida	doc_919500587378_item	2938033	et	4	main
allkirja	doc_919500587378_item	2938043	et	4	main
fotoallkirjad	doc_919500587378_item	2938044	et	3	main
foto	doc_919500587378_item	2938049	et	4	main
õhtulehes	doc_919500587378_item	2938052	et	3	main
nime	doc_919500587378_item	2938060	et	4	main
jaoks	doc_919500587378_item	2938061	et	4	main
on	doc_919500587378_item	2938062	et	4	main
fotograafi	doc_919500587378_item	2938068	et	4	main
nimi	doc_919500587378_item	2938069	et	3	main
on	doc_919500587378_item	2938070	et	4	main
ei	doc_919500587378_item	2938113	et	4	main
kokku	doc_919500587378_item	2938116	et	3	main
ühel	doc_919500587378_item	2938118	et	3	main
sisalduv	doc_919500587378_item	2938024	et	4	main
on	doc_919500587378_item	2938026	et	4	main
korrektne	doc_919500587378_item	2938027	et	3	main
äripäevas	doc_919500587378_item	2938028	et	3	main
fotoallkirja	doc_919500587378_item	2938029	et	4	main
3	doc_919500587378_item	2938035	et	2	main
rida	doc_919500587378_item	2938036	et	4	main
enamasti	doc_919500587378_item	2938046	et	4	main
fotode	doc_919500587378_item	2938047	et	3	main
all	doc_919500587378_item	2938048	et	3	main
fotograafi	doc_919500587378_item	2938059	et	4	main
fotoallkirjaga	doc_919500587378_item	2938072	et	3	main
samas	doc_919500587378_item	2938073	et	4	main
kirjas	doc_919500587378_item	2938074	et	4	main
ainult	doc_919500587378_item	2938075	et	4	main
väiksemas	doc_919500587378_item	2938076	et	4	main
keelekasutus	doc_919500587378_item	2938077	et	4	main
artiklites	doc_919500587378_item	2938078	et	3	main
leiduvad	doc_919500587378_item	2938079	et	4	main
ka	doc_919500587378_item	2938080	et	3	main
mõned	doc_919500587378_item	2938081	et	3	main
trükivead	doc_919500587378_item	2938082	et	3	main
mis	doc_919500587378_item	2938083	et	4	main
kergesti	doc_919500587378_item	2938085	et	3	main
paistavad	doc_919500587378_item	2938084	et	3	main
silma	doc_919500587378_item	2938086	et	4	main
samuti	doc_919500587378_item	2938087	et	3	main
õhtuleht	doc_919500587378_item	2938089	et	3	main
kasutab	doc_919500587378_item	2938090	et	3	main
liiga	doc_919500587378_item	2938091	et	4	main
sl	doc_919500587378_item	2938088	et	4	main
palju	doc_919500587378_item	2938092	et	4	main
võõrsõnu	doc_919500587378_item	2938093	et	3	main
mis	doc_919500587378_item	2938098	et	4	main
tee	doc_919500587378_item	2938100	et	4	main
ajalehe	doc_919500587378_item	2938101	et	3	main
keelekasutust	doc_919500587378_item	2938102	et	4	main
fotod	doc_919500587378_item	2938110	et	3	main
sobi	doc_919500587378_item	2938114	et	4	main
uudisel	doc_919500587378_item	2938119	et	3	main
oli	doc_919500587378_item	2938120	et	3	main
kosuvad	doc_919500587378_item	2938123	et	4	main
artiklit	doc_919500587378_item	2938130	et	3	main
oli	doc_919500587378_item	2938131	et	3	main
kirjutatud	doc_919500587378_item	2938134	et	4	main
suusapuhkusest	doc_919500587378_item	2938135	et	4	main
seda	doc_919500587378_item	2938136	et	3	main
ei	doc_919500587378_item	2938139	et	4	main
foto	doc_919500587378_item	2938146	et	4	main
samuti	doc_919500587378_item	2938156	et	3	main
teada	doc_919500587378_item	2938164	et	3	main
kokkuvõtte	doc_919500587378_item	2938204	et	4	main
äripäev	doc_919500587378_item	2938212	et	3	main
ajalehte	doc_919500587378_item	2938228	et	4	main
mulje	doc_919500587378_item	2938244	et	4	main
fotode	doc_919500587378_item	2938245	et	3	main
kujundamise	doc_919500587378_item	2938246	et	4	main
pool	doc_919500587378_item	2938253	et	4	main
kohe	doc_919500587378_item	2938264	et	4	main
õhtuleht	doc_919500587378_item	2938272	et	3	main
sisuga	doc_919500587378_item	2938275	et	3	main
vale	doc_919500587378_item	2938285	et	4	main
lehe	doc_919500587378_item	2938292	et	3	main
keset	doc_919500587378_item	2938129	et	4	main
terve	doc_919500587378_item	2938132	et	4	main
veerg	doc_919500587378_item	2938133	et	3	main
seostada	doc_919500587378_item	2938142	et	3	main
pole	doc_919500587378_item	2938152	et	3	main
ju	doc_919500587378_item	2938153	et	3	main
keskne	doc_919500587378_item	2938168	et	3	main
näiteks	doc_919500587378_item	2938170	et	4	main
le	doc_919500587378_item	2938175	et	4	main
jess	doc_919500587378_item	2938176	et	4	main
on	doc_919500587378_item	2938177	et	4	main
järjest	doc_919500587378_item	2938178	et	4	main
kasutatud	doc_919500587378_item	2938179	et	4	main
sõnad	doc_919500587378_item	2938180	et	4	main
mis	doc_919500587378_item	2938181	et	4	main
ei	doc_919500587378_item	2938182	et	4	main
sisalda	doc_919500587378_item	2938183	et	4	main
mingit	doc_919500587378_item	2938184	et	3	main
informatsiooni	doc_919500587378_item	2938185	et	4	main
ja	doc_919500587378_item	2938186	et	3	main
ei	doc_919500587378_item	2938187	et	4	main
tõmba	doc_919500587378_item	2938188	et	4	main
lugejate	doc_919500587378_item	2938189	et	4	main
tähelepanu	doc_919500587378_item	2938190	et	4	main
fotost	doc_919500587378_item	2938191	et	3	main
ei	doc_919500587378_item	2938192	et	4	main
saanud	doc_919500587378_item	2938193	et	4	main
ka	doc_919500587378_item	2938194	et	3	main
kuidagi	doc_919500587378_item	2938195	et	3	main
aru	doc_919500587378_item	2938196	et	4	main
et	doc_919500587378_item	2938197	et	3	main
selles	doc_919500587378_item	2938198	et	4	main
artiklis	doc_919500587378_item	2938199	et	3	main
on	doc_919500587378_item	2938200	et	4	main
jutt	doc_919500587378_item	2938201	et	3	main
vanilla	doc_919500587378_item	2938202	et	4	main
pärast	doc_919500587378_item	2938128	et	4	main
isegi	doc_919500587378_item	2938143	et	4	main
seal	doc_919500587378_item	2938151	et	4	main
suusatamist	doc_919500587378_item	2938155	et	4	main
on	doc_919500587378_item	2938166	et	4	main
teema	doc_919500587378_item	2938169	et	4	main
pealkirjas	doc_919500587378_item	2938171	et	3	main
lenna	doc_919500587378_item	2938172	et	4	main
on	doc_919500587378_item	2938211	et	4	main
paremini	doc_919500587378_item	2938214	et	4	main
sellele	doc_919500587378_item	2938216	et	4	main
see	doc_919500587378_item	2938223	et	3	main
usaldusväärsem	doc_919500587378_item	2938237	et	4	main
kuid	doc_919500587378_item	2938238	et	4	main
portreedes	doc_919500587378_item	2938252	et	4	main
puudu	doc_919500587378_item	2938255	et	4	main
tahtmise	doc_919500587378_item	2938266	et	4	main
edasi	doc_919500587378_item	2938267	et	3	main
sl	doc_919500587378_item	2938271	et	4	main
ja	doc_919500587378_item	2938282	et	3	main
isegi	doc_919500587378_item	2938283	et	4	main
tema	doc_919500587378_item	2938284	et	4	main
õigel	doc_919500587378_item	2938321	et	3	main
ja	doc_919500587378_item	2938323	et	3	main
sõlm-momendi	doc_919500587378_item	2938325	et	3	main
ise	doc_919500587378_item	2938326	et	4	main
endale	doc_919500587378_item	2938327	et	4	main
ja	doc_919500587379_item	2938341	et	3	main
võrrelda	doc_919500587379_item	2938351	et	4	main
numbrit	doc_919500587379_item	2938355	et	3	main
üks-	doc_919500587379_item	2938357	et	3	main
ja	doc_919500587379_item	2938364	et	3	main
kaks	doc_919500587379_item	2938365	et	3	main
nädalavahetuse	doc_919500587379_item	2938370	et	4	main
materjali	doc_919500587379_item	2938394	et	4	main
struktuuri	doc_919500587379_item	2938407	et	4	main
ning	doc_919500587379_item	2938408	et	3	main
siis	doc_919500587379_item	2938409	et	3	main
võrdlen	doc_919500587379_item	2938410	et	3	main
neid	doc_919500587379_item	2938411	et	4	main
miinused	doc_919500587379_item	2938423	et	3	main
nädalavahetus	doc_919500587379_item	2938425	et	4	main
märts	doc_919500587379_item	2938427	et	3	main
märts	doc_919500587379_item	2938431	et	3	main
nädalavahetus	doc_919500587379_item	2938436	et	4	main
teisest	doc_919500587379_item	2938439	et	4	main
kirjutatud	doc_919500587379_item	2938450	et	4	main
kujundatud	doc_919500587379_item	2938460	et	4	main
arusaadav	doc_919500587379_item	2938477	et	4	main
erineb	doc_919500587379_item	2938483	et	3	main
tõsiste	doc_919500587379_item	2938493	et	4	main
asjadega	doc_919500587379_item	2938494	et	3	main
näiteks	doc_919500587379_item	2938495	et	4	main
või	doc_919500587379_item	2938497	et	4	main
ka	doc_919500587379_item	2938509	et	3	main
maailma	doc_919500587379_item	2938510	et	4	main
kirjutatud	doc_919500587379_item	2938530	et	4	main
nädalapäev	doc_919500587379_item	2938531	et	3	main
kuupäev	doc_919500587379_item	2938532	et	3	main
kõrval	doc_919500587379_item	2938550	et	4	main
igal	doc_919500587379_item	2938560	et	3	main
alates	doc_919500587379_item	2938562	et	3	main
on	doc_919500587379_item	2938566	et	4	main
kasutatud	doc_919500587379_item	2938567	et	4	main
on	doc_919500587379_item	2938608	et	4	main
paikneb	doc_919500587379_item	2938612	et	3	main
leheküljel	doc_919500587379_item	2938615	et	3	main
seepärast	doc_919500587379_item	2938617	et	3	main
ninjast	doc_919500587378_item	2938203	et	4	main
lõppuks	doc_919500587378_item	2938205	et	3	main
tahan	doc_919500587378_item	2938206	et	3	main
öelda	doc_919500587378_item	2938207	et	4	main
et	doc_919500587378_item	2938208	et	3	main
minu	doc_919500587378_item	2938209	et	3	main
et	doc_919500587378_item	2938217	et	3	main
äripäevas	doc_919500587378_item	2938218	et	3	main
on	doc_919500587378_item	2938219	et	4	main
vertikaalne	doc_919500587378_item	2938220	et	3	main
ja	doc_919500587378_item	2938222	et	3	main
natuke	doc_919500587378_item	2938225	et	4	main
lehekülge	doc_919500587378_item	2938226	et	4	main
seda	doc_919500587378_item	2938227	et	3	main
ratsionaalsem	doc_919500587378_item	2938235	et	4	main
ja	doc_919500587378_item	2938236	et	3	main
ta	doc_919500587378_item	2938241	et	4	main
jätab	doc_919500587378_item	2938242	et	3	main
negatiivse	doc_919500587378_item	2938243	et	3	main
kõikides	doc_919500587378_item	2938250	et	4	main
inimeste	doc_919500587378_item	2938251	et	3	main
kohtades	doc_919500587378_item	2938258	et	3	main
mis	doc_919500587378_item	2938263	et	4	main
võrdlemisest	doc_919500587378_item	2938270	et	4	main
mulje	doc_919500587378_item	2938277	et	4	main
ärritab	doc_919500587378_item	2938280	et	3	main
paigutamine	doc_919500587378_item	2938287	et	4	main
ei	doc_919500587378_item	2938288	et	4	main
meeldi	doc_919500587378_item	2938289	et	4	main
ka	doc_919500587378_item	2938290	et	3	main
viimase	doc_919500587378_item	2938291	et	3	main
vormistamine	doc_919500587378_item	2938293	et	4	main
sinna	doc_919500587378_item	2938294	et	3	main
on	doc_919500587378_item	2938295	et	4	main
pandud	doc_919500587378_item	2938296	et	4	main
suur	doc_919500587378_item	2938297	et	3	main
reportaaz	doc_919500587378_item	2938298	et	4	main
ja	doc_919500587378_item	2938299	et	3	main
seepärast	doc_919500587378_item	2938300	et	3	main
tekkib	doc_919500587378_item	2938301	et	3	main
selline	doc_919500587378_item	2938302	et	4	main
tunne	doc_919500587378_item	2938303	et	4	main
et	doc_919500587378_item	2938304	et	3	main
see	doc_919500587378_item	2938305	et	3	main
ajaleht	doc_919500587378_item	2938306	et	3	main
on	doc_919500587378_item	2938307	et	4	main
lõppmatu	doc_919500587378_item	2938308	et	4	main
sl	doc_919500587378_item	2938309	et	4	main
õhtulehe	doc_919500587378_item	2938310	et	3	main
positiivseks	doc_919500587378_item	2938311	et	3	main
küljeks	doc_919500587378_item	2938312	et	3	main
on	doc_919500587378_item	2938313	et	4	main
fotod	doc_919500587378_item	2938314	et	3	main
kõik	doc_919500587378_item	2938315	et	4	main
fotod	doc_919500587378_item	2938316	et	3	main
on	doc_919500587378_item	2938317	et	4	main
tõesti	doc_919500587378_item	2938318	et	3	main
huvitavad	doc_919500587378_item	2938319	et	4	main
tehtud	doc_919500587378_item	2938320	et	4	main
sl	doc_919500587379_item	2938342	et	4	main
sl	doc_919500587379_item	2938367	et	4	main
üks-	doc_919500587379_item	2938369	et	3	main
ma	doc_919500587379_item	2938397	et	3	main
ajal	doc_919500587378_item	2938322	et	4	main
valin	doc_919500587378_item	2938329	et	3	main
lihtsam	doc_919500587379_item	2938348	et	4	main
omavahel	doc_919500587379_item	2938350	et	3	main
ma	doc_919500587379_item	2938352	et	3	main
võttsin	doc_919500587379_item	2938353	et	4	main
kaks	doc_919500587379_item	2938354	et	3	main
numbrit	doc_919500587379_item	2938366	et	3	main
numbrit	doc_919500587379_item	2938371	et	3	main
ja	doc_919500587379_item	2938372	et	3	main
teine	doc_919500587379_item	2938373	et	3	main
teisipäeva	doc_919500587379_item	2938374	et	4	main
numrit	doc_919500587379_item	2938375	et	4	main
minu	doc_919500587379_item	2938376	et	3	main
uurimistöö	doc_919500587379_item	2938377	et	4	main
eesmärk	doc_919500587379_item	2938378	et	3	main
on	doc_919500587379_item	2938379	et	4	main
võrrelda	doc_919500587379_item	2938380	et	4	main
ajalehte	doc_919500587379_item	2938381	et	4	main
omavahel	doc_919500587379_item	2938382	et	3	main
ning	doc_919500587379_item	2938383	et	3	main
mitte	doc_919500587379_item	2938384	et	3	main
ainult	doc_919500587379_item	2938385	et	4	main
leida	doc_919500587379_item	2938386	et	3	main
erinevusi	doc_919500587379_item	2938387	et	4	main
vaid	doc_919500587379_item	2938388	et	3	main
ka	doc_919500587379_item	2938389	et	3	main
analüüsida	doc_919500587379_item	2938390	et	3	main
ajalehtede	doc_919500587379_item	2938391	et	4	main
ülesehitust	doc_919500587379_item	2938392	et	4	main
õppitud	doc_919500587379_item	2938393	et	4	main
kaks	doc_919500587379_item	2938338	et	3	main
ajalehte	doc_919500587379_item	2938339	et	4	main
äripäev	doc_919500587379_item	2938340	et	3	main
õhtuleht	doc_919500587379_item	2938343	et	3	main
oleks	doc_919500587379_item	2938345	et	3	main
äripäevalehe	doc_919500587379_item	2938356	et	3	main
nädalavahetuse	doc_919500587379_item	2938358	et	4	main
numbrit	doc_919500587379_item	2938359	et	3	main
ja	doc_919500587379_item	2938360	et	3	main
esmaspäeva	doc_919500587379_item	2938362	et	4	main
põhjal	doc_919500587379_item	2938395	et	4	main
põhjalikult	doc_919500587379_item	2938399	et	4	main
pärast	doc_919500587379_item	2938405	et	4	main
õhtulehe	doc_919500587379_item	2938406	et	3	main
mis	doc_919500587379_item	2938417	et	4	main
911	doc_919500587379_item	2938426	et	2	main
ja	doc_919500587379_item	2938428	et	3	main
esmaspäev	doc_919500587379_item	2938429	et	3	main
eraldavad	doc_919500587379_item	2938437	et	4	main
esilehel	doc_919500587379_item	2938441	et	3	main
ajalehepea	doc_919500587379_item	2938443	et	4	main
aga	doc_919500587379_item	2938455	et	3	main
tähed	doc_919500587379_item	2938464	et	3	main
äp	doc_919500587379_item	2938465	et	4	main
ja	doc_919500587379_item	2938466	et	3	main
tähelepanu	doc_919500587379_item	2938474	et	4	main
äripäev	doc_919500587379_item	2938486	et	3	main
ettenähtud	doc_919500587379_item	2938488	et	4	main
inimeste	doc_919500587379_item	2938489	et	3	main
jaoks	doc_919500587379_item	2938490	et	4	main
kuid	doc_919500587379_item	2938508	et	4	main
allasurutud	doc_919500587379_item	2938516	et	4	main
esialgu	doc_919500587379_item	2938396	et	3	main
kirjeldada	doc_919500587379_item	2938400	et	3	main
omavahel	doc_919500587379_item	2938412	et	3	main
ja	doc_919500587379_item	2938413	et	3	main
annan	doc_919500587379_item	2938414	et	3	main
12	doc_919500587379_item	2938430	et	2	main
äripäev	doc_919500587379_item	2938433	et	3	main
isegi	doc_919500587379_item	2938442	et	4	main
päise	doc_919500587379_item	2938444	et	4	main
on	doc_919500587379_item	2938449	et	4	main
punases	doc_919500587379_item	2938453	et	4	main
äripäeva	doc_919500587379_item	2938456	et	4	main
nädalavahetuse	doc_919500587379_item	2938457	et	4	main
väljaannes	doc_919500587379_item	2938458	et	3	main
kõrval	doc_919500587379_item	2938467	et	4	main
number	doc_919500587379_item	2938468	et	3	main
2	doc_919500587379_item	2938469	et	2	main
see	doc_919500587379_item	2938470	et	3	main
ning	doc_919500587379_item	2938475	et	3	main
et	doc_919500587379_item	2938478	et	3	main
omaette	doc_919500587379_item	2938484	et	3	main
mis	doc_919500587379_item	2938504	et	4	main
toimub	doc_919500587379_item	2938505	et	3	main
lõbusam	doc_919500587379_item	2938523	et	4	main
äripäeva	doc_919500587379_item	2938526	et	4	main
ajalehe	doc_919500587379_item	2938537	et	3	main
punasel	doc_919500587379_item	2938544	et	4	main
valgete	doc_919500587379_item	2938546	et	4	main
veebiadress	doc_919500587379_item	2938548	et	4	main
ja	doc_919500587379_item	2938549	et	3	main
võib	doc_919500587379_item	2938557	et	3	main
kellast	doc_919500587379_item	2938564	et	4	main
võib	doc_919500587379_item	2938591	et	3	main
tavaline	doc_919500587379_item	2938595	et	4	main
rasvase	doc_919500587379_item	2938598	et	4	main
kirjaga	doc_919500587379_item	2938599	et	3	main
see	doc_919500587379_item	2938600	et	3	main
toimub	doc_919500587379_item	2938601	et	3	main
nii	doc_919500587379_item	2938602	et	3	main
et	doc_919500587379_item	2938603	et	3	main
kõige	doc_919500587379_item	2938604	et	4	main
rasvases	doc_919500587379_item	2938610	et	4	main
4	doc_919500587379_item	2938629	et	2	main
hall	doc_919500587379_item	2938632	et	4	main
ja	doc_919500587379_item	2938634	et	3	main
äripäevas	doc_919500587379_item	2938640	et	3	main
on	doc_919500587379_item	2938641	et	4	main
veel	doc_919500587379_item	2938642	et	4	main
helesinist	doc_919500587379_item	2938646	et	4	main
värvi	doc_919500587379_item	2938647	et	4	main
väga	doc_919500587379_item	2938648	et	3	main
värvi	doc_919500587379_item	2938654	et	4	main
see	doc_919500587379_item	2938676	et	3	main
on	doc_919500587379_item	2938702	et	4	main
ka	doc_919500587379_item	2938703	et	3	main
äripäeva	doc_919500587379_item	2938401	et	4	main
ajalehe	doc_919500587379_item	2938402	et	3	main
struktuuri	doc_919500587379_item	2938403	et	4	main
siis	doc_919500587379_item	2938404	et	3	main
oma	doc_919500587379_item	2938415	et	4	main
on	doc_919500587379_item	2938418	et	4	main
äripäev	doc_919500587379_item	2938424	et	3	main
ja	doc_919500587379_item	2938434	et	3	main
üks	doc_919500587379_item	2938438	et	3	main
juba	doc_919500587379_item	2938440	et	3	main
kirjutamise	doc_919500587379_item	2938445	et	4	main
viisil	doc_919500587379_item	2938446	et	4	main
mõlemad	doc_919500587379_item	2938447	et	3	main
pealkirjad	doc_919500587379_item	2938448	et	3	main
on	doc_919500587379_item	2938459	et	4	main
erinevus	doc_919500587379_item	2938471	et	4	main
köidab	doc_919500587379_item	2938472	et	3	main
kohe	doc_919500587379_item	2938473	et	4	main
on	doc_919500587379_item	2938476	et	4	main
ajalehtede	doc_919500587379_item	2938479	et	4	main
natukene	doc_919500587379_item	2938482	et	4	main
tegelevad	doc_919500587379_item	2938492	et	4	main
või	doc_919500587379_item	2938499	et	4	main
nii	doc_919500587379_item	2938506	et	3	main
eesti	doc_919500587379_item	2938507	et	4	main
on	doc_919500587379_item	2938515	et	4	main
nädalavahetuse	doc_919500587379_item	2938517	et	4	main
natukene	doc_919500587379_item	2938522	et	4	main
väljaanne	doc_919500587379_item	2938533	et	4	main
hind	doc_919500587379_item	2938536	et	3	main
ribal	doc_919500587379_item	2938545	et	3	main
huvitav	doc_919500587379_item	2938554	et	4	main
informatsioon	doc_919500587379_item	2938555	et	3	main
mis	doc_919500587379_item	2938556	et	4	main
veebis	doc_919500587379_item	2938559	et	4	main
päeval	doc_919500587379_item	2938561	et	3	main
mis	doc_919500587379_item	2938607	et	4	main
kirjas	doc_919500587379_item	2938611	et	4	main
ja	doc_919500587379_item	2938616	et	3	main
esimene	doc_919500587379_item	2938618	et	3	main
avanedes	doc_919500587379_item	2938620	et	3	main
valge	doc_919500587379_item	2938635	et	4	main
arvesse	doc_919500587379_item	2938636	et	4	main
ja	doc_919500587379_item	2938645	et	3	main
minu	doc_919500587379_item	2938650	et	3	main
arvates	doc_919500587379_item	2938651	et	4	main
kasutatakse	doc_919500587379_item	2938652	et	3	main
köidab	doc_919500587379_item	2938656	et	3	main
väga	doc_919500587379_item	2938657	et	3	main
lugejate	doc_919500587379_item	2938659	et	4	main
et	doc_919500587379_item	2938666	et	3	main
on	doc_919500587379_item	2938686	et	4	main
lugeda	doc_919500587379_item	2938695	et	3	main
punase	doc_919500587379_item	2938697	et	4	main
nt	doc_919500587379_item	2938707	et	4	main
uudised	doc_919500587379_item	2938708	et	3	main
ka	doc_919500587379_item	2938721	et	3	main
punase	doc_919500587379_item	2938723	et	4	main
värviga	doc_919500587379_item	2938724	et	4	main
nagu	doc_919500587379_item	2938725	et	3	main
vaatlus	doc_919500587379_item	2938726	et	3	main
nädalavahetuse	doc_919500587379_item	2938732	et	4	main
osas	doc_919500587379_item	2938735	et	4	main
veel	doc_919500587379_item	2938737	et	4	main
hall	doc_919500587379_item	2938745	et	4	main
kirjas	doc_919500587379_item	2938746	et	4	main
ja	doc_919500587379_item	2938747	et	3	main
ja	doc_919500587379_item	2938756	et	3	main
on	doc_919500587379_item	2938760	et	4	main
osa	doc_919500587379_item	2938769	et	4	main
valdkonna	doc_919500587379_item	2938776	et	4	main
kohas	doc_919500587379_item	2938782	et	4	main
lehekülgedel	doc_919500587379_item	2938788	et	4	main
tõsise	doc_919500587379_item	2938789	et	4	main
artikliga	doc_919500587379_item	2938790	et	3	main
leheküljel	doc_919500587379_item	2938793	et	3	main
paiknes	doc_919500587379_item	2938797	et	3	main
kohvimasina	doc_919500587379_item	2938798	et	3	main
eritähelepanu	doc_919500587379_item	2938818	et	4	main
ajalehes	doc_919500587379_item	2938819	et	3	main
fotosid	doc_919500587379_item	2938824	et	3	main
mis	doc_919500587379_item	2938827	et	4	main
ja	doc_919500587379_item	2938422	et	3	main
2007	doc_919500587379_item	2938432	et	2	main
äripäev	doc_919500587379_item	2938435	et	3	main
valgete	doc_919500587379_item	2938451	et	4	main
tähtedega	doc_919500587379_item	2938452	et	4	main
ribas	doc_919500587379_item	2938454	et	3	main
ainult	doc_919500587379_item	2938461	et	4	main
kaks	doc_919500587379_item	2938462	et	3	main
esimesed	doc_919500587379_item	2938463	et	3	main
sisu	doc_919500587379_item	2938480	et	4	main
on	doc_919500587379_item	2938481	et	4	main
ajaleht	doc_919500587379_item	2938485	et	3	main
on	doc_919500587379_item	2938487	et	4	main
kes	doc_919500587379_item	2938491	et	4	main
äriga	doc_919500587379_item	2938496	et	3	main
majandusega	doc_919500587379_item	2938498	et	4	main
lihtsalt	doc_919500587379_item	2938500	et	4	main
tahavad	doc_919500587379_item	2938501	et	3	main
olla	doc_919500587379_item	2938502	et	3	main
kursis	doc_919500587379_item	2938503	et	3	main
majanduses	doc_919500587379_item	2938511	et	4	main
seepärast	doc_919500587379_item	2938512	et	3	main
ajalehe	doc_919500587379_item	2938513	et	3	main
stiil	doc_919500587379_item	2938514	et	3	main
väljaannes	doc_919500587379_item	2938518	et	3	main
on	doc_919500587379_item	2938519	et	4	main
aga	doc_919500587379_item	2938520	et	3	main
stiil	doc_919500587379_item	2938521	et	3	main
ja	doc_919500587379_item	2938524	et	3	main
number	doc_919500587379_item	2938534	et	3	main
ja	doc_919500587379_item	2938535	et	3	main
alamisel	doc_919500587379_item	2938538	et	4	main
vasakul	doc_919500587379_item	2938539	et	4	main
serval	doc_919500587379_item	2938540	et	3	main
on	doc_919500587379_item	2938541	et	4	main
veel	doc_919500587379_item	2938543	et	4	main
hallil	doc_919500587379_item	2938551	et	4	main
ribal	doc_919500587379_item	2938552	et	3	main
lugeda	doc_919500587379_item	2938558	et	3	main
1200	doc_919500587379_item	2938563	et	2	main
ajalehes	doc_919500587379_item	2938565	et	3	main
erinevaid	doc_919500587379_item	2938569	et	4	main
näha	doc_919500587379_item	2938592	et	3	main
kuidas	doc_919500587379_item	2938594	et	3	main
kiri	doc_919500587379_item	2938596	et	3	main
varieerib	doc_919500587379_item	2938597	et	3	main
kirjutatud	doc_919500587379_item	2938609	et	4	main
lehekulje	doc_919500587379_item	2938621	et	4	main
väga	doc_919500587379_item	2938623	et	3	main
hajameelne	doc_919500587379_item	2938624	et	3	main
kohal	doc_919500587379_item	2938626	et	4	main
natukene	doc_919500587379_item	2938643	et	4	main
palju	doc_919500587379_item	2938649	et	4	main
see	doc_919500587379_item	2938655	et	3	main
hästi	doc_919500587379_item	2938658	et	3	main
tähelepanu	doc_919500587379_item	2938660	et	4	main
ja	doc_919500587379_item	2938661	et	3	main
teeb	doc_919500587379_item	2938662	et	3	main
natukene	doc_919500587379_item	2938663	et	4	main
ei	doc_919500587379_item	2938667	et	4	main
igav	doc_919500587379_item	2938669	et	3	main
väsitav	doc_919500587379_item	2938671	et	4	main
samal	doc_919500587379_item	2938674	et	3	main
paigutatud	doc_919500587379_item	2938687	et	4	main
tähtsamate	doc_919500587379_item	2938688	et	4	main
lugude	doc_919500587379_item	2938689	et	3	main
artiklireklaamid	doc_919500587379_item	2938690	et	3	main
mille	doc_919500587379_item	2938691	et	3	main
järg	doc_919500587379_item	2938692	et	3	main
märgistatud	doc_919500587379_item	2938696	et	4	main
värviga	doc_919500587379_item	2938698	et	4	main
leheküljel	doc_919500587379_item	2938699	et	3	main
punase	doc_919500587379_item	2938700	et	4	main
kirjaga	doc_919500587379_item	2938701	et	3	main
börs	doc_919500587379_item	2938709	et	3	main
koolitus	doc_919500587379_item	2938728	et	4	main
tööstus	doc_919500587379_item	2938729	et	3	main
uudise	doc_919500587379_item	2938734	et	3	main
eredam	doc_919500587379_item	2938525	et	4	main
päise	doc_919500587379_item	2938527	et	4	main
all	doc_919500587379_item	2938528	et	3	main
on	doc_919500587379_item	2938529	et	4	main
kirjutatud	doc_919500587379_item	2938542	et	4	main
tähtedega	doc_919500587379_item	2938547	et	4	main
uus	doc_919500587379_item	2938553	et	3	main
palju	doc_919500587379_item	2938568	et	4	main
kujundusvahendeid	doc_919500587379_item	2938570	et	3	main
erinevad	doc_919500587379_item	2938571	et	4	main
jooned	doc_919500587379_item	2938572	et	3	main
raamid	doc_919500587379_item	2938573	et	4	main
võib	doc_919500587379_item	2938574	et	3	main
kohtada	doc_919500587379_item	2938575	et	4	main
palju	doc_919500587379_item	2938576	et	4	main
erinevaid	doc_919500587379_item	2938577	et	4	main
trükikirja	doc_919500587379_item	2938578	et	4	main
suuruseid	doc_919500587379_item	2938579	et	4	main
pealkirja	doc_919500587379_item	2938580	et	4	main
trükikirja	doc_919500587379_item	2938581	et	4	main
stiil	doc_919500587379_item	2938582	et	3	main
erineb	doc_919500587379_item	2938583	et	3	main
samuti	doc_919500587379_item	2938584	et	3	main
järgnevast	doc_919500587379_item	2938585	et	4	main
tekstist	doc_919500587379_item	2938586	et	3	main
igal	doc_919500587379_item	2938587	et	3	main
leheküljel	doc_919500587379_item	2938588	et	3	main
leheküljel	doc_919500587379_item	2938590	et	3	main
äripäeva	doc_919500587379_item	2938589	et	4	main
et	doc_919500587379_item	2938593	et	3	main
tähtsam	doc_919500587379_item	2938605	et	4	main
informatsioon	doc_919500587379_item	2938606	et	3	main
erinevates	doc_919500587379_item	2938613	et	4	main
kohtades	doc_919500587379_item	2938614	et	3	main
pilk	doc_919500587379_item	2938619	et	3	main
rohkem	doc_919500587379_item	2938628	et	4	main
punane	doc_919500587379_item	2938631	et	4	main
must	doc_919500587379_item	2938633	et	4	main
nädalavahetuse	doc_919500587379_item	2938639	et	4	main
punast	doc_919500587379_item	2938653	et	4	main
nii	doc_919500587379_item	2938665	et	3	main
hakkaks	doc_919500587379_item	2938668	et	3	main
ja	doc_919500587379_item	2938670	et	3	main
lugeda	doc_919500587379_item	2938672	et	3	main
ajal	doc_919500587379_item	2938675	et	4	main
ja	doc_919500587379_item	2938680	et	3	main
stiil	doc_919500587379_item	2938681	et	3	main
jääbki	doc_919500587379_item	2938682	et	3	main
allasurutud	doc_919500587379_item	2938683	et	4	main
päevalehe	doc_919500587379_item	2938684	et	3	main
esiküljele	doc_919500587379_item	2938685	et	3	main
lõppuni	doc_919500587379_item	2938694	et	3	main
ajalehe	doc_919500587379_item	2938705	et	3	main
osad	doc_919500587379_item	2938706	et	3	main
auto	doc_919500587379_item	2938710	et	4	main
noored	doc_919500587379_item	2938711	et	3	main
arvamus	doc_919500587379_item	2938712	et	3	main
ärgipäevases	doc_919500587379_item	2938713	et	4	main
äripäevas	doc_919500587379_item	2938714	et	3	main
märgistatud	doc_919500587379_item	2938722	et	4	main
kinnisvara	doc_919500587379_item	2938727	et	4	main
äripäevas	doc_919500587379_item	2938733	et	3	main
kirjutatud	doc_919500587379_item	2938742	et	4	main
suures	doc_919500587379_item	2938743	et	3	main
rasvases	doc_919500587379_item	2938744	et	4	main
portree	doc_919500587379_item	2938755	et	4	main
vaatlus	doc_919500587379_item	2938757	et	3	main
ajalehes	doc_919500587379_item	2938759	et	3	main
palju	doc_919500587379_item	2938761	et	4	main
isegi	doc_919500587379_item	2938766	et	4	main
võib	doc_919500587379_item	2938771	et	3	main
erinevaid	doc_919500587379_item	2938773	et	4	main
erinevate	doc_919500587379_item	2938775	et	4	main
ristu	doc_919500587379_item	2938787	et	4	main
tõsises	doc_919500587379_item	2938802	et	4	main
ajalehes	doc_919500587379_item	2938803	et	3	main
nagu	doc_919500587379_item	2938804	et	3	main
äripäevas	doc_919500587379_item	2938805	et	3	main
koondada	doc_919500587379_item	2938808	et	3	main
äripäevas	doc_919500587379_item	2938811	et	3	main
ka	doc_919500587379_item	2938813	et	3	main
pilte	doc_919500587379_item	2938815	et	3	main
on	doc_919500587379_item	2938622	et	4	main
ajalehes	doc_919500587379_item	2938625	et	3	main
on	doc_919500587379_item	2938627	et	4	main
põhivärvi	doc_919500587379_item	2938630	et	4	main
võtmata	doc_919500587379_item	2938637	et	4	main
reklaami	doc_919500587379_item	2938638	et	4	main
sinist	doc_919500587379_item	2938644	et	4	main
eredam	doc_919500587379_item	2938664	et	4	main
kuigi	doc_919500587379_item	2938673	et	3	main
ei	doc_919500587379_item	2938677	et	4	main
ületa	doc_919500587379_item	2938678	et	4	main
piiri	doc_919500587379_item	2938679	et	4	main
võib	doc_919500587379_item	2938693	et	3	main
märgistatud	doc_919500587379_item	2938704	et	4	main
on	doc_919500587379_item	2938715	et	4	main
veel	doc_919500587379_item	2938716	et	4	main
niisugused	doc_919500587379_item	2938717	et	3	main
osad	doc_919500587379_item	2938718	et	3	main
mis	doc_919500587379_item	2938719	et	4	main
on	doc_919500587379_item	2938720	et	4	main
reklaam	doc_919500587379_item	2938731	et	3	main
võib	doc_919500587379_item	2938736	et	3	main
leida	doc_919500587379_item	2938738	et	3	main
äripäeva	doc_919500587379_item	2938758	et	4	main
eraldanud	doc_919500587379_item	2938763	et	4	main
reklaami	doc_919500587379_item	2938764	et	4	main
jaoks	doc_919500587379_item	2938765	et	4	main
kus	doc_919500587379_item	2938770	et	3	main
on	doc_919500587379_item	2938779	et	4	main
all	doc_919500587379_item	2938796	et	3	main
niisiguses	doc_919500587379_item	2938801	et	4	main
reklaami	doc_919500587379_item	2938807	et	4	main
peale	doc_919500587379_item	2938809	et	4	main
palju	doc_919500587379_item	2938814	et	4	main
mis	doc_919500587379_item	2938816	et	4	main
dünaamiliseid	doc_919500587379_item	2938823	et	4	main
sündmusfotosid	doc_919500587379_item	2938826	et	3	main
sadama	doc_919500587379_item	2938841	et	4	main
see	doc_919500587379_item	2938862	et	3	main
mis	doc_919500587379_item	2938866	et	4	main
on	doc_919500587379_item	2938871	et	4	main
palju	doc_919500587379_item	2938872	et	4	main
eriti	doc_919500587379_item	2938873	et	3	main
juttu	doc_919500587379_item	2938887	et	4	main
paljud	doc_919500587379_item	2938888	et	3	main
need	doc_919500587379_item	2938889	et	3	main
sest	doc_919500587379_item	2938896	et	4	main
portreedest	doc_919500587379_item	2938899	et	4	main
jääb	doc_919500587379_item	2938905	et	3	main
palju	doc_919500587379_item	2938919	et	4	main
diagramme	doc_919500587379_item	2938921	et	3	main
artikkleid	doc_919500587379_item	2938923	et	4	main
võib	doc_919500587379_item	2938925	et	3	main
palju	doc_919500587379_item	2938927	et	4	main
arve	doc_919500587379_item	2938928	et	4	main
ja	doc_919500587379_item	2938929	et	3	main
numbreid	doc_919500587379_item	2938930	et	3	main
ajalehes	doc_919500587379_item	2938931	et	3	main
ka	doc_919500587379_item	2938935	et	3	main
kohtada	doc_919500587379_item	2938936	et	4	main
arvete	doc_919500587379_item	2938949	et	4	main
diagrammide	doc_919500587379_item	2938951	et	3	main
meeldis	doc_919500587379_item	2938955	et	3	main
nad	doc_919500587379_item	2938967	et	3	main
palju	doc_919500587379_item	2939016	et	4	main
sisalda	doc_919500587379_item	2939023	et	4	main
ja	doc_919500587379_item	2939026	et	3	main
sisaldavad	doc_919500587379_item	2939036	et	4	main
veerupikkus	doc_919500587379_item	2939042	et	4	main
ühel	doc_919500587379_item	2939046	et	3	main
väikesed	doc_919500587379_item	2939051	et	4	main
ühelt	doc_919500587379_item	2939055	et	3	main
vajalikke	doc_919500587379_item	2939060	et	3	main
minu	doc_919500587379_item	2939062	et	3	main
kes	doc_919500587379_item	2939072	et	4	main
esilehel	doc_919500587379_item	2939121	et	3	main
ja	doc_919500587379_item	2938730	et	3	main
paigaldanud	doc_919500587379_item	2938748	et	4	main
vertikaalselt	doc_919500587379_item	2938749	et	4	main
need	doc_919500587379_item	2938750	et	3	main
allosad	doc_919500587379_item	2938751	et	3	main
on	doc_919500587379_item	2938752	et	4	main
luubi	doc_919500587379_item	2938753	et	3	main
all	doc_919500587379_item	2938754	et	3	main
allosad	doc_919500587379_item	2938739	et	3	main
mis	doc_919500587379_item	2938740	et	4	main
on	doc_919500587379_item	2938741	et	4	main
leida	doc_919500587379_item	2938772	et	3	main
reklaame	doc_919500587379_item	2938774	et	3	main
jaokspeamiselt	doc_919500587379_item	2938777	et	4	main
reklaam	doc_919500587379_item	2938778	et	3	main
nii	doc_919500587379_item	2938783	et	3	main
et	doc_919500587379_item	2938784	et	3	main
see	doc_919500587379_item	2938785	et	3	main
ei	doc_919500587379_item	2938786	et	4	main
ühel	doc_919500587379_item	2938792	et	3	main
artikli	doc_919500587379_item	2938795	et	3	main
kuigi	doc_919500587379_item	2938800	et	3	main
võiks	doc_919500587379_item	2938806	et	4	main
väärivad	doc_919500587379_item	2938817	et	4	main
väga	doc_919500587379_item	2938821	et	3	main
ehk	doc_919500587379_item	2938825	et	3	main
ajalehe	doc_919500587379_item	2938831	et	3	main
paljud	doc_919500587379_item	2938833	et	3	main
ehitiseid	doc_919500587379_item	2938840	et	4	main
rohkem	doc_919500587379_item	2938845	et	4	main
võib	doc_919500587379_item	2938846	et	3	main
leida	doc_919500587379_item	2938847	et	3	main
mugavas	doc_919500587379_item	2938864	et	3	main
puudutab	doc_919500587379_item	2938867	et	3	main
siis	doc_919500587379_item	2938869	et	3	main
palju	doc_919500587379_item	2938875	et	4	main
väikeseid	doc_919500587379_item	2938876	et	4	main
inimeste	doc_919500587379_item	2938877	et	3	main
portreefotosid	doc_919500587379_item	2938878	et	3	main
oma	doc_919500587379_item	2938881	et	4	main
väikesed	doc_919500587379_item	2938890	et	4	main
portreefotod	doc_919500587379_item	2938891	et	3	main
enamik	doc_919500587379_item	2938897	et	3	main
ülevalt	doc_919500587379_item	2938900	et	4	main
osa	doc_919500587379_item	2938901	et	4	main
ära	doc_919500587379_item	2938902	et	4	main
selline	doc_919500587379_item	2938906	et	4	main
et	doc_919500587379_item	2938908	et	3	main
peale	doc_919500587379_item	2938914	et	4	main
fotode	doc_919500587379_item	2938915	et	3	main
ajalehes	doc_919500587379_item	2938916	et	3	main
poliitikute	doc_919500587379_item	2938938	et	3	main
ja	doc_919500587379_item	2938939	et	3	main
ja	doc_919500587379_item	2938950	et	3	main
on	doc_919500587379_item	2938961	et	4	main
nähtavad	doc_919500587379_item	2938964	et	4	main
igal	doc_919500587379_item	2938969	et	3	main
majanduslikke	doc_919500587379_item	2939007	et	3	main
ja	doc_919500587379_item	2939009	et	3	main
nii	doc_919500587379_item	2939011	et	3	main
ma	doc_919500587379_item	2939013	et	3	main
ütlesin	doc_919500587379_item	2939015	et	3	main
arve	doc_919500587379_item	2939017	et	4	main
omaette	doc_919500587379_item	2939018	et	3	main
laused	doc_919500587379_item	2939019	et	3	main
lugeda	doc_919500587379_item	2939029	et	3	main
enamik	doc_919500587379_item	2939030	et	3	main
artikleid	doc_919500587379_item	2939031	et	3	main
on	doc_919500587379_item	2939032	et	4	main
ka	doc_919500587379_item	2939033	et	3	main
lakoonilised	doc_919500587379_item	2939034	et	3	main
otstarbelist	doc_919500587379_item	2939038	et	4	main
informatsiooni	doc_919500587379_item	2939039	et	4	main
küllaltki	doc_919500587379_item	2939044	et	4	main
võivad	doc_919500587379_item	2939048	et	4	main
tehtud	doc_919500587379_item	2939068	et	4	main
eriti	doc_919500587379_item	2939069	et	3	main
alati	doc_919500587379_item	2939074	et	4	main
kinni	doc_919500587379_item	2939075	et	3	main
ja	doc_919500587379_item	2939076	et	3	main
valisin	doc_919500587379_item	2939103	et	3	main
ja	doc_919500587379_item	2939114	et	3	main
erinevad	doc_919500587379_item	2939117	et	4	main
mõlemad	doc_919500587379_item	2939118	et	3	main
õhtulehed	doc_919500587379_item	2939119	et	3	main
juba	doc_919500587379_item	2939120	et	3	main
on	doc_919500587379_item	2939138	et	4	main
kirjutatud	doc_919500587379_item	2939139	et	4	main
nädalavahetuse	doc_919500587379_item	2939145	et	4	main
ruumi	doc_919500587379_item	2938762	et	4	main
on	doc_919500587379_item	2938767	et	4	main
spetsiaalne	doc_919500587379_item	2938768	et	3	main
paigutatud	doc_919500587379_item	2938780	et	4	main
ühes	doc_919500587379_item	2938781	et	4	main
ainult	doc_919500587379_item	2938791	et	4	main
tõsise	doc_919500587379_item	2938794	et	4	main
reklaam	doc_919500587379_item	2938799	et	3	main
reklaami	doc_919500587379_item	2938810	et	4	main
on	doc_919500587379_item	2938812	et	4	main
on	doc_919500587379_item	2938820	et	4	main
vähe	doc_919500587379_item	2938822	et	3	main
on	doc_919500587379_item	2938828	et	4	main
haruldane	doc_919500587379_item	2938830	et	3	main
jaoks	doc_919500587379_item	2938832	et	4	main
on	doc_919500587379_item	2938835	et	4	main
objektfotod	doc_919500587379_item	2938836	et	4	main
näha	doc_919500587379_item	2938839	et	3	main
jt	doc_919500587379_item	2938842	et	4	main
portreefotosidühesõnaga	doc_919500587379_item	2938849	et	4	main
kohas	doc_919500587379_item	2938865	et	4	main
avaldavad	doc_919500587379_item	2938880	et	4	main
või	doc_919500587379_item	2938883	et	4	main
kellest	doc_919500587379_item	2938884	et	4	main
on	doc_919500587379_item	2938885	et	4	main
artiklis	doc_919500587379_item	2938886	et	3	main
arvetes	doc_919500587379_item	2938895	et	4	main
pead	doc_919500587379_item	2938912	et	4	main
puudu	doc_919500587379_item	2938913	et	4	main
erinevaid	doc_919500587379_item	2938920	et	4	main
väga	doc_919500587379_item	2938829	et	3	main
ajalehes	doc_919500587379_item	2938850	et	3	main
domineerivad	doc_919500587379_item	2938851	et	4	main
staatilised	doc_919500587379_item	2938852	et	3	main
fotod	doc_919500587379_item	2938853	et	3	main
igal	doc_919500587379_item	2938854	et	3	main
fotol	doc_919500587379_item	2938855	et	3	main
on	doc_919500587379_item	2938856	et	4	main
olemas	doc_919500587379_item	2938857	et	4	main
pealkiri	doc_919500587379_item	2938858	et	3	main
kuigi	doc_919500587379_item	2938859	et	3	main
fotod	doc_919500587379_item	2938834	et	3	main
kus	doc_919500587379_item	2938837	et	3	main
võib	doc_919500587379_item	2938838	et	3	main
ja	doc_919500587379_item	2938843	et	3	main
kõige	doc_919500587379_item	2938844	et	4	main
ajalehest	doc_919500587379_item	2938848	et	4	main
mitte	doc_919500587379_item	2938860	et	3	main
on	doc_919500587379_item	2938874	et	4	main
on	doc_919500587379_item	2938892	et	4	main
ebaõnnestunud	doc_919500587379_item	2938893	et	4	main
minu	doc_919500587379_item	2938894	et	3	main
ja	doc_919500587379_item	2938904	et	3	main
inimesel	doc_919500587379_item	2938909	et	3	main
on	doc_919500587379_item	2938917	et	4	main
küllaltki	doc_919500587379_item	2938918	et	4	main
ärimeeste	doc_919500587379_item	2938940	et	4	main
tsitaate	doc_919500587379_item	2938941	et	3	main
mis	doc_919500587379_item	2938942	et	4	main
teeb	doc_919500587379_item	2938943	et	3	main
väga	doc_919500587379_item	2938962	et	3	main
leidavad	doc_919500587379_item	2938966	et	3	main
lugemiseks	doc_919500587379_item	2939002	et	4	main
kasutatakse	doc_919500587379_item	2939004	et	3	main
ja	doc_919500587379_item	2939006	et	3	main
mõisteid	doc_919500587379_item	2939008	et	3	main
alati	doc_919500587379_item	2938861	et	4	main
paikneb	doc_919500587379_item	2938863	et	3	main
portreefotosid	doc_919500587379_item	2938868	et	3	main
neid	doc_919500587379_item	2938870	et	4	main
kes	doc_919500587379_item	2938879	et	4	main
arvamust	doc_919500587379_item	2938882	et	3	main
inimeste	doc_919500587379_item	2938898	et	3	main
lõigatud	doc_919500587379_item	2938903	et	4	main
mulje	doc_919500587379_item	2938907	et	4	main
on	doc_919500587379_item	2938910	et	4	main
pool	doc_919500587379_item	2938911	et	4	main
ja	doc_919500587379_item	2938922	et	3	main
kus	doc_919500587379_item	2938924	et	3	main
leida	doc_919500587379_item	2938926	et	3	main
igal	doc_919500587379_item	2938932	et	3	main
leheküljel	doc_919500587379_item	2938933	et	3	main
saab	doc_919500587379_item	2938934	et	3	main
selle	doc_919500587379_item	2938944	et	4	main
ajalehe	doc_919500587379_item	2938945	et	3	main
mitte	doc_919500587379_item	2938946	et	3	main
nii	doc_919500587379_item	2938947	et	3	main
kõhn	doc_919500587379_item	2938948	et	3	main
hulgas	doc_919500587379_item	2938952	et	4	main
väga	doc_919500587379_item	2938954	et	3	main
veel	doc_919500587379_item	2938956	et	4	main
see	doc_919500587379_item	2938957	et	3	main
et	doc_919500587379_item	2938958	et	3	main
toimetajate	doc_919500587379_item	2938959	et	4	main
andmed	doc_919500587379_item	2938960	et	3	main
ja	doc_919500587379_item	2938965	et	3	main
asuvad	doc_919500587379_item	2938968	et	4	main
leheküljel	doc_919500587379_item	2938970	et	3	main
kohas	doc_919500587379_item	2938972	et	4	main
kuid	doc_919500587379_item	2939003	et	4	main
poliitilisi	doc_919500587379_item	2939005	et	3	main
kohtub	doc_919500587379_item	2939010	et	3	main
nagu	doc_919500587379_item	2939012	et	3	main
juba	doc_919500587379_item	2939014	et	3	main
lakoonilised	doc_919500587379_item	2939021	et	3	main
mis	doc_919500587379_item	2939035	et	4	main
veerulaius	doc_919500587379_item	2939040	et	4	main
ja	doc_919500587379_item	2939041	et	3	main
väikesed	doc_919500587379_item	2939045	et	4	main
5-6	doc_919500587379_item	2939050	et	2	main
nii	doc_919500587379_item	2939053	et	3	main
leheküljelt	doc_919500587379_item	2939056	et	3	main
palju	doc_919500587379_item	2939059	et	4	main
arvates	doc_919500587379_item	2939063	et	4	main
see	doc_919500587379_item	2939064	et	3	main
on	doc_919500587379_item	2939065	et	4	main
väga	doc_919500587379_item	2939066	et	3	main
mugav	doc_919500587379_item	2939067	et	3	main
on	doc_919500587379_item	2939073	et	4	main
äripaev	doc_919500587379_item	2939115	et	4	main
nädalavahetus	doc_919500587379_item	2939116	et	4	main
palju	doc_919500587379_item	2938937	et	4	main
mulle	doc_919500587379_item	2938953	et	4	main
hästi	doc_919500587379_item	2938963	et	3	main
ühes	doc_919500587379_item	2938971	et	4	main
lehekülje	doc_919500587379_item	2938973	et	3	main
ülemal	doc_919500587379_item	2938974	et	3	main
vasakul	doc_919500587379_item	2938975	et	4	main
või	doc_919500587379_item	2938976	et	4	main
paremal	doc_919500587379_item	2938977	et	4	main
serval	doc_919500587379_item	2938978	et	3	main
rasvase	doc_919500587379_item	2938979	et	4	main
kirjaga	doc_919500587379_item	2938980	et	3	main
on	doc_919500587379_item	2938981	et	4	main
kirjutatud	doc_919500587379_item	2938982	et	4	main
toimetaja	doc_919500587379_item	2938983	et	4	main
nimi	doc_919500587379_item	2938984	et	3	main
ja	doc_919500587379_item	2938985	et	3	main
perekonnanimi	doc_919500587379_item	2938986	et	3	main
telefoninumber	doc_919500587379_item	2938987	et	3	main
ja	doc_919500587379_item	2938988	et	3	main
e-maili	doc_919500587379_item	2938989	et	4	main
aadress	doc_919500587379_item	2938990	et	3	main
mis	doc_919500587379_item	2938991	et	4	main
puudutab	doc_919500587379_item	2938992	et	3	main
keelekasutust	doc_919500587379_item	2938993	et	4	main
siis	doc_919500587379_item	2938994	et	3	main
stiil	doc_919500587379_item	2938995	et	3	main
on	doc_919500587379_item	2938996	et	4	main
allasurutud	doc_919500587379_item	2938997	et	4	main
artiklid	doc_919500587379_item	2938998	et	3	main
ei	doc_919500587379_item	2938999	et	4	main
ole	doc_919500587379_item	2939000	et	4	main
raske	doc_919500587379_item	2939001	et	4	main
on	doc_919500587379_item	2939020	et	4	main
ei	doc_919500587379_item	2939022	et	4	main
ainult	doc_919500587379_item	2939037	et	4	main
leida	doc_919500587379_item	2939058	et	3	main
ärimeeste	doc_919500587379_item	2939070	et	4	main
jaoks	doc_919500587379_item	2939071	et	4	main
nädalavahetus	doc_919500587379_item	2939106	et	4	main
ja	doc_919500587379_item	2939107	et	3	main
sl	doc_919500587379_item	2939108	et	4	main
õhtulehe	doc_919500587379_item	2939109	et	3	main
teisipäev	doc_919500587379_item	2939110	et	3	main
nii	doc_919500587379_item	2939111	et	3	main
nagu	doc_919500587379_item	2939112	et	3	main
äripäev	doc_919500587379_item	2939113	et	3	main
õhtuleht	doc_919500587379_item	2939146	et	3	main
on	doc_919500587379_item	2939147	et	4	main
kuupäev	doc_919500587379_item	2939157	et	3	main
hind	doc_919500587379_item	2939158	et	3	main
eestis	doc_919500587379_item	2939159	et	3	main
ja	doc_919500587379_item	2939160	et	3	main
hind	doc_919500587379_item	2939161	et	3	main
soomes	doc_919500587379_item	2939162	et	4	main
meelest	doc_919500587379_item	2939179	et	4	main
see	doc_919500587379_item	2939180	et	3	main
artikli	doc_919500587379_item	2939190	et	3	main
võib	doc_919500587379_item	2939193	et	3	main
ka	doc_919500587379_item	2939206	et	3	main
punastes	doc_919500587379_item	2939217	et	4	main
raamides	doc_919500587379_item	2939218	et	4	main
need	doc_919500587379_item	2939219	et	3	main
artikli	doc_919500587379_item	2939220	et	3	main
liigseid	doc_919500587379_item	2939024	et	3	main
sõnu	doc_919500587379_item	2939025	et	4	main
ei	doc_919500587379_item	2939027	et	4	main
pinguta	doc_919500587379_item	2939028	et	4	main
on	doc_919500587379_item	2939043	et	4	main
leheküljel	doc_919500587379_item	2939047	et	3	main
mahtuda	doc_919500587379_item	2939049	et	3	main
artiklid	doc_919500587379_item	2939052	et	3	main
et	doc_919500587379_item	2939054	et	3	main
võib	doc_919500587379_item	2939057	et	3	main
informatsiooni	doc_919500587379_item	2939061	et	4	main
ei	doc_919500587379_item	2939077	et	4	main
ole	doc_919500587379_item	2939078	et	4	main
palju	doc_919500587379_item	2939079	et	4	main
aega	doc_919500587379_item	2939080	et	4	main
liigse	doc_919500587379_item	2939081	et	3	main
lugemise	doc_919500587379_item	2939082	et	4	main
jaoks	doc_919500587379_item	2939083	et	4	main
kuigi	doc_919500587379_item	2939084	et	3	main
tahavad	doc_919500587379_item	2939085	et	3	main
olla	doc_919500587379_item	2939086	et	3	main
kursis	doc_919500587379_item	2939087	et	3	main
mis	doc_919500587379_item	2939088	et	4	main
toimub	doc_919500587379_item	2939089	et	3	main
nende	doc_919500587379_item	2939090	et	4	main
tegemisvaldkonnas	doc_919500587379_item	2939091	et	4	main
sl	doc_919500587379_item	2939092	et	4	main
õhtuleht	doc_919500587379_item	2939093	et	3	main
nädalavahetus	doc_919500587379_item	2939094	et	4	main
10	doc_919500587379_item	2939095	et	2	main
märts	doc_919500587379_item	2939096	et	3	main
ja	doc_919500587379_item	2939097	et	3	main
teisipäev	doc_919500587379_item	2939098	et	3	main
20	doc_919500587379_item	2939099	et	2	main
märts	doc_919500587379_item	2939100	et	3	main
2007	doc_919500587379_item	2939101	et	2	main
ma	doc_919500587379_item	2939102	et	3	main
sl	doc_919500587379_item	2939104	et	4	main
õhtulehe	doc_919500587379_item	2939105	et	3	main
üks	doc_919500587379_item	2939122	et	3	main
ajalehepea	doc_919500587379_item	2939124	et	4	main
nii	doc_919500587379_item	2939132	et	3	main
suur	doc_919500587379_item	2939133	et	3	main
ja	doc_919500587379_item	2939134	et	3	main
märkav	doc_919500587379_item	2939135	et	4	main
tähtedega	doc_919500587379_item	2939141	et	4	main
olnud	doc_919500587379_item	2939175	et	4	main
äripäevas	doc_919500587379_item	2939176	et	3	main
aga	doc_919500587379_item	2939177	et	3	main
minu	doc_919500587379_item	2939178	et	3	main
kujundatud	doc_919500587379_item	2939185	et	4	main
tähtsam	doc_919500587379_item	2939189	et	4	main
nii	doc_919500587379_item	2939197	et	3	main
selle	doc_919500587379_item	2939200	et	4	main
teiste	doc_919500587379_item	2939207	et	4	main
kujundatud	doc_919500587379_item	2939216	et	4	main
millest	doc_919500587379_item	2939229	et	3	main
võib	doc_919500587379_item	2939232	et	3	main
uudised	doc_919500587379_item	2939236	et	3	main
jne	doc_919500587379_item	2939238	et	4	main
allpool	doc_919500587379_item	2939240	et	3	main
peale	doc_919500587379_item	2939245	et	4	main
ja	doc_919500587379_item	2939250	et	3	main
tekkinud	doc_919500587379_item	2939257	et	4	main
äripäevas	doc_919500587379_item	2939261	et	3	main
lehe	doc_919500587379_item	2939264	et	3	main
erinevaid	doc_919500587379_item	2939286	et	4	main
värve	doc_919500587379_item	2939287	et	3	main
kuigi	doc_919500587379_item	2939288	et	3	main
esilehel	doc_919500587379_item	2939289	et	3	main
värvid	doc_919500587379_item	2939295	et	4	main
esilehe	doc_919500587379_item	2939296	et	3	main
teeb	doc_919500587379_item	2939297	et	3	main
eredaks	doc_919500587379_item	2939298	et	3	main
sinises	doc_919500587379_item	2939306	et	4	main
punases	doc_919500587379_item	2939308	et	4	main
värvides	doc_919500587379_item	2939309	et	4	main
jagunenud	doc_919500587379_item	2939320	et	4	main
osaga	doc_919500587379_item	2939325	et	3	main
tähtedega	doc_919500587379_item	2939332	et	4	main
suurel	doc_919500587379_item	2939333	et	3	main
edasi	doc_919500587379_item	2939336	et	3	main
punaste	doc_919500587379_item	2939345	et	4	main
valgete	doc_919500587379_item	2939354	et	4	main
tähtedega	doc_919500587379_item	2939355	et	4	main
osa	doc_919500587379_item	2939356	et	4	main
auto	doc_919500587379_item	2939371	et	4	main
sama	doc_919500587379_item	2939372	et	4	main
lavastatud	doc_919500587379_item	2939415	et	4	main
peaaegu	doc_919500587379_item	2939418	et	3	main
on	doc_919500587379_item	2939421	et	4	main
mis	doc_919500587379_item	2939423	et	4	main
võtab	doc_919500587379_item	2939439	et	3	main
see	doc_919500587379_item	2939459	et	3	main
eemale	doc_919500587379_item	2939461	et	3	main
fotol	doc_919500587379_item	2939465	et	3	main
olemas	doc_919500587379_item	2939467	et	4	main
küllatki	doc_919500587379_item	2939492	et	4	main
plokk-kirja	doc_919500587379_item	2939494	et	4	main
eriti	doc_919500587379_item	2939495	et	3	main
informatsiooni	doc_919500587379_item	2939497	et	4	main
eristamiseks	doc_919500587379_item	2939498	et	4	main
kirjutatud	doc_919500587379_item	2939501	et	4	main
aga	doc_919500587379_item	2939509	et	3	main
kui	doc_919500587379_item	2939517	et	3	main
see	doc_919500587379_item	2939518	et	3	main
on	doc_919500587379_item	2939519	et	4	main
olemas	doc_919500587379_item	2939520	et	4	main
see	doc_919500587379_item	2939521	et	3	main
ole	doc_919500587379_item	2939523	et	4	main
mis	doc_919500587379_item	2939534	et	4	main
stiil	doc_919500587379_item	2939542	et	3	main
kasutatakse	doc_919500587379_item	2939543	et	3	main
palju	doc_919500587379_item	2939544	et	4	main
sissejuhatava	doc_919500587379_item	2939545	et	3	main
kõnet	doc_919500587379_item	2939546	et	3	main
ja	doc_919500587379_item	2939547	et	3	main
kõnet	doc_919500587379_item	2939549	et	3	main
ei	doc_919500587379_item	2939558	et	4	main
erinevus	doc_919500587379_item	2939129	et	4	main
ei	doc_919500587379_item	2939130	et	4	main
ole	doc_919500587379_item	2939131	et	4	main
valgete	doc_919500587379_item	2939140	et	4	main
kirjutatud	doc_919500587379_item	2939148	et	4	main
vastupidi	doc_919500587379_item	2939149	et	3	main
punaste	doc_919500587379_item	2939150	et	4	main
tähtedega	doc_919500587379_item	2939151	et	4	main
valges	doc_919500587379_item	2939152	et	4	main
teisest	doc_919500587379_item	2939123	et	4	main
kirjutamise	doc_919500587379_item	2939125	et	4	main
viisil	doc_919500587379_item	2939126	et	4	main
aga	doc_919500587379_item	2939127	et	3	main
see	doc_919500587379_item	2939128	et	3	main
ärgipäevane	doc_919500587379_item	2939136	et	4	main
õhtuleht	doc_919500587379_item	2939137	et	3	main
punasel	doc_919500587379_item	2939142	et	4	main
ribal	doc_919500587379_item	2939143	et	3	main
ja	doc_919500587379_item	2939144	et	3	main
all	doc_919500587379_item	2939154	et	3	main
on	doc_919500587379_item	2939155	et	4	main
veel	doc_919500587379_item	2939163	et	4	main
on	doc_919500587379_item	2939169	et	4	main
on	doc_919500587379_item	2939181	et	4	main
keskpunktis	doc_919500587379_item	2939183	et	3	main
on	doc_919500587379_item	2939184	et	4	main
ja	doc_919500587379_item	2939188	et	3	main
selles	doc_919500587379_item	2939195	et	4	main
äripäevas	doc_919500587379_item	2939199	et	3	main
suure	doc_919500587379_item	2939201	et	3	main
artikli	doc_919500587379_item	2939202	et	3	main
reklaami	doc_919500587379_item	2939203	et	4	main
all	doc_919500587379_item	2939204	et	3	main
artiklite	doc_919500587379_item	2939208	et	3	main
kuid	doc_919500587379_item	2939210	et	4	main
kirjutatud	doc_919500587379_item	2939228	et	4	main
artikli	doc_919500587379_item	2939234	et	3	main
veebi	doc_919500587379_item	2939246	et	4	main
hellistada	doc_919500587379_item	2939255	et	4	main
puhul	doc_919500587379_item	2939259	et	4	main
mida	doc_919500587379_item	2939260	et	4	main
kasutatud	doc_919500587379_item	2939267	et	4	main
trükikirju	doc_919500587379_item	2939270	et	4	main
äripäev	doc_919500587379_item	2939281	et	3	main
kasutatud	doc_919500587379_item	2939284	et	4	main
palju	doc_919500587379_item	2939285	et	4	main
punane	doc_919500587379_item	2939292	et	4	main
ja	doc_919500587379_item	2939293	et	3	main
sinine	doc_919500587379_item	2939294	et	4	main
et	doc_919500587379_item	2939301	et	3	main
on	doc_919500587379_item	2939304	et	4	main
kujundatud	doc_919500587379_item	2939305	et	4	main
natuke	doc_919500587379_item	2939321	et	4	main
alustab	doc_919500587379_item	2939323	et	3	main
uudised	doc_919500587379_item	2939326	et	3	main
teisel	doc_919500587379_item	2939339	et	4	main
arvamus	doc_919500587379_item	2939357	et	3	main
hallil	doc_919500587379_item	2939358	et	4	main
ribal	doc_919500587379_item	2939359	et	3	main
edasi	doc_919500587379_item	2939360	et	3	main
samamoodi	doc_919500587379_item	2939361	et	3	main
kollasel	doc_919500587379_item	2939364	et	4	main
osa	doc_919500587379_item	2939366	et	4	main
rohelisel	doc_919500587379_item	2939368	et	4	main
ribal	doc_919500587379_item	2939369	et	3	main
värvi	doc_919500587379_item	2939373	et	4	main
mis	doc_919500587379_item	2939407	et	4	main
teevad	doc_919500587379_item	2939408	et	3	main
ajalehe	doc_919500587379_item	2939409	et	3	main
dünaamiliseks	doc_919500587379_item	2939410	et	3	main
võib	doc_919500587379_item	2939411	et	3	main
leida	doc_919500587379_item	2939412	et	3	main
ka	doc_919500587379_item	2939413	et	3	main
hästi	doc_919500587379_item	2939414	et	3	main
ja	doc_919500587379_item	2939417	et	3	main
leheküljel	doc_919500587379_item	2939420	et	3	main
fotosuurust	doc_919500587379_item	2939425	et	4	main
siis	doc_919500587379_item	2939426	et	3	main
neist	doc_919500587379_item	2939428	et	4	main
on	doc_919500587379_item	2939435	et	4	main
et	doc_919500587379_item	2939438	et	3	main
kaksiklehekülgedest	doc_919500587379_item	2939441	et	4	main
vaatades	doc_919500587379_item	2939442	et	4	main
võib	doc_919500587379_item	2939447	et	3	main
on	doc_919500587379_item	2939450	et	4	main
huvi	doc_919500587379_item	2939454	et	4	main
vastupidi-	doc_919500587379_item	2939458	et	3	main
mitte	doc_919500587379_item	2939463	et	3	main
igal	doc_919500587379_item	2939464	et	3	main
on	doc_919500587379_item	2939500	et	4	main
päise	doc_919500587379_item	2939153	et	4	main
on	doc_919500587379_item	2939164	et	4	main
suure	doc_919500587379_item	2939165	et	3	main
tähtedega	doc_919500587379_item	2939166	et	4	main
päeva	doc_919500587379_item	2939170	et	4	main
tiraaž	doc_919500587379_item	2939172	et	2	main
kõige	doc_919500587379_item	2939186	et	4	main
huvitavam	doc_919500587379_item	2939187	et	4	main
paiknevad	doc_919500587379_item	2939205	et	4	main
reklaamid	doc_919500587379_item	2939209	et	4	main
nad	doc_919500587379_item	2939211	et	3	main
on	doc_919500587379_item	2939212	et	4	main
palju	doc_919500587379_item	2939213	et	4	main
sisaldavad	doc_919500587379_item	2939222	et	4	main
selle	doc_919500587379_item	2939233	et	4	main
leida	doc_919500587379_item	2939235	et	3	main
ribal	doc_919500587379_item	2939244	et	3	main
veel	doc_919500587379_item	2939248	et	4	main
erinevaid	doc_919500587379_item	2939268	et	4	main
on	doc_919500587379_item	2939283	et	4	main
domineerivad	doc_919500587379_item	2939291	et	4	main
see	doc_919500587379_item	2939300	et	3	main
ja	doc_919500587379_item	2939307	et	3	main
omavahel	doc_919500587379_item	2939316	et	3	main
on	doc_919500587379_item	2939328	et	4	main
ja	doc_919500587379_item	2939350	et	3	main
jälle	doc_919500587379_item	2939352	et	3	main
ribal	doc_919500587379_item	2939365	et	3	main
tarbija	doc_919500587379_item	2939367	et	4	main
osa	doc_919500587379_item	2939370	et	4	main
ribal	doc_919500587379_item	2939374	et	3	main
ja	doc_919500587379_item	2939375	et	3	main
võib	doc_919500587379_item	2939404	et	3	main
leida	doc_919500587379_item	2939405	et	3	main
sündmusfotosid	doc_919500587379_item	2939406	et	3	main
kirjutatud	doc_919500587379_item	2939156	et	4	main
kirjutatud	doc_919500587379_item	2939167	et	4	main
missugune	doc_919500587379_item	2939168	et	3	main
väljaanne	doc_919500587379_item	2939171	et	4	main
mida	doc_919500587379_item	2939173	et	4	main
ei	doc_919500587379_item	2939174	et	4	main
tähtis	doc_919500587379_item	2939182	et	4	main
reklaam	doc_919500587379_item	2939191	et	3	main
mis	doc_919500587379_item	2939192	et	4	main
lugeda	doc_919500587379_item	2939194	et	3	main
ajalehes	doc_919500587379_item	2939196	et	3	main
nagu	doc_919500587379_item	2939198	et	3	main
väiksem	doc_919500587379_item	2939214	et	4	main
ja	doc_919500587379_item	2939215	et	3	main
reklaamid	doc_919500587379_item	2939221	et	4	main
fotosid	doc_919500587379_item	2939223	et	3	main
ajalehe	doc_919500587379_item	2939230	et	3	main
punasel	doc_919500587379_item	2939243	et	4	main
kujundusvahendeid	doc_919500587379_item	2939269	et	3	main
rohkem	doc_919500587379_item	2939290	et	4	main
ajalehe	doc_919500587379_item	2939302	et	3	main
köide	doc_919500587379_item	2939303	et	4	main
vahelduvad	doc_919500587379_item	2939315	et	4	main
ajalehte	doc_919500587379_item	2939317	et	4	main
on	doc_919500587379_item	2939319	et	4	main
artiklipealkirja	doc_919500587379_item	2939224	et	4	main
ning	doc_919500587379_item	2939225	et	3	main
allpool	doc_919500587379_item	2939226	et	3	main
on	doc_919500587379_item	2939227	et	4	main
osast	doc_919500587379_item	2939231	et	4	main
sport	doc_919500587379_item	2939237	et	3	main
ajalehe	doc_919500587379_item	2939239	et	3	main
on	doc_919500587379_item	2939241	et	4	main
kirjutatud	doc_919500587379_item	2939242	et	4	main
aadressi	doc_919500587379_item	2939247	et	4	main
vihjetelefon	doc_919500587379_item	2939249	et	3	main
2	doc_919500587379_item	2939251	et	2	main
telefoninumbrit	doc_919500587379_item	2939252	et	3	main
kuhu	doc_919500587379_item	2939253	et	3	main
võib	doc_919500587379_item	2939254	et	3	main
kojukande	doc_919500587379_item	2939256	et	4	main
probleemide	doc_919500587379_item	2939258	et	3	main
ei	doc_919500587379_item	2939262	et	4	main
olnud	doc_919500587379_item	2939263	et	4	main
kujunduses	doc_919500587379_item	2939265	et	4	main
on	doc_919500587379_item	2939266	et	4	main
värve	doc_919500587379_item	2939271	et	3	main
jooni	doc_919500587379_item	2939272	et	4	main
ja	doc_919500587379_item	2939273	et	3	main
tühja	doc_919500587379_item	2939274	et	4	main
ruumi	doc_919500587379_item	2939275	et	4	main
õhtuajaleht	doc_919500587379_item	2939276	et	3	main
on	doc_919500587379_item	2939277	et	4	main
palju	doc_919500587379_item	2939278	et	4	main
eredam	doc_919500587379_item	2939279	et	4	main
kui	doc_919500587379_item	2939280	et	3	main
siin	doc_919500587379_item	2939282	et	4	main
veel	doc_919500587379_item	2939299	et	4	main
nii	doc_919500587379_item	2939310	et	3	main
et	doc_919500587379_item	2939311	et	3	main
need	doc_919500587379_item	2939312	et	3	main
sinised-punased	doc_919500587379_item	2939313	et	4	main
ribad	doc_919500587379_item	2939314	et	3	main
osad	doc_919500587379_item	2939318	et	3	main
segaselt	doc_919500587379_item	2939322	et	4	main
mis	doc_919500587379_item	2939327	et	4	main
kirjutatud	doc_919500587379_item	2939329	et	4	main
suurte	doc_919500587379_item	2939330	et	3	main
valgete	doc_919500587379_item	2939331	et	4	main
aga	doc_919500587379_item	2939337	et	3	main
leheküljel	doc_919500587379_item	2939340	et	3	main
tähtedega	doc_919500587379_item	2939346	et	4	main
uudised	doc_919500587379_item	2939347	et	3	main
reklaam	doc_919500587379_item	2939349	et	3	main
siis	doc_919500587379_item	2939351	et	3	main
suure	doc_919500587379_item	2939353	et	3	main
elu	doc_919500587379_item	2939363	et	4	main
osa	doc_919500587379_item	2939376	et	4	main
portreefotosid	doc_919500587379_item	2939416	et	3	main
igal	doc_919500587379_item	2939419	et	3	main
siluett-fotod	doc_919500587379_item	2939422	et	3	main
puudutab	doc_919500587379_item	2939424	et	3	main
suurus	doc_919500587379_item	2939434	et	4	main
nii	doc_919500587379_item	2939436	et	3	main
suur	doc_919500587379_item	2939437	et	3	main
peaaegu	doc_919500587379_item	2939440	et	3	main
siluett-fotosid	doc_919500587379_item	2939444	et	3	main
idee	doc_919500587379_item	2939449	et	4	main
selles	doc_919500587379_item	2939451	et	4	main
et	doc_919500587379_item	2939452	et	3	main
äratada	doc_919500587379_item	2939453	et	3	main
peletab	doc_919500587379_item	2939462	et	3	main
veergud	doc_919500587379_item	2939489	et	4	main
palju	doc_919500587379_item	2939493	et	4	main
palju	doc_919500587379_item	2939507	et	4	main
leidnud	doc_919500587379_item	2939512	et	4	main
ajaleht	doc_919500587379_item	2939324	et	3	main
punasel	doc_919500587379_item	2939334	et	4	main
ribal	doc_919500587379_item	2939335	et	3	main
igal	doc_919500587379_item	2939338	et	3	main
on	doc_919500587379_item	2939341	et	4	main
kirjutatud	doc_919500587379_item	2939342	et	4	main
ülemal	doc_919500587379_item	2939343	et	3	main
serval	doc_919500587379_item	2939344	et	3	main
edasi	doc_919500587379_item	2939348	et	3	main
osa	doc_919500587379_item	2939362	et	4	main
täna	doc_919500587379_item	2939377	et	4	main
sinisel-rohelisel	doc_919500587379_item	2939378	et	4	main
ribal	doc_919500587379_item	2939379	et	3	main
õhtuajalehes	doc_919500587379_item	2939380	et	3	main
on	doc_919500587379_item	2939381	et	4	main
väga	doc_919500587379_item	2939382	et	3	main
palju	doc_919500587379_item	2939383	et	4	main
pilte	doc_919500587379_item	2939384	et	3	main
enamik	doc_919500587379_item	2939385	et	3	main
neist	doc_919500587379_item	2939386	et	4	main
on	doc_919500587379_item	2939387	et	4	main
koomilised	doc_919500587379_item	2939388	et	3	main
ja	doc_919500587379_item	2939389	et	3	main
karikatuurid	doc_919500587379_item	2939390	et	4	main
mis	doc_919500587379_item	2939391	et	4	main
puudutab	doc_919500587379_item	2939392	et	3	main
fotosid	doc_919500587379_item	2939393	et	3	main
siis	doc_919500587379_item	2939394	et	3	main
õhtulehes	doc_919500587379_item	2939395	et	3	main
neid	doc_919500587379_item	2939396	et	4	main
on	doc_919500587379_item	2939397	et	4	main
küllaltki	doc_919500587379_item	2939398	et	4	main
palju	doc_919500587379_item	2939399	et	4	main
ja	doc_919500587379_item	2939400	et	3	main
erinevaid	doc_919500587379_item	2939401	et	4	main
stiili	doc_919500587379_item	2939402	et	4	main
siin	doc_919500587379_item	2939403	et	4	main
palju	doc_919500587379_item	2939427	et	4	main
on	doc_919500587379_item	2939429	et	4	main
ebaõnnestunud	doc_919500587379_item	2939430	et	4	main
fotode	doc_919500587379_item	2939433	et	3	main
hiigelsuuri	doc_919500587379_item	2939443	et	3	main
see	doc_919500587379_item	2939445	et	3	main
lugemiseks	doc_919500587379_item	2939455	et	4	main
aga	doc_919500587379_item	2939456	et	3	main
natukene	doc_919500587379_item	2939460	et	4	main
allkiri	doc_919500587379_item	2939468	et	3	main
ning	doc_919500587379_item	2939469	et	3	main
paljudel	doc_919500587379_item	2939470	et	3	main
fotodel	doc_919500587379_item	2939471	et	3	main
üldse	doc_919500587379_item	2939472	et	3	main
ei	doc_919500587379_item	2939473	et	4	main
ole	doc_919500587379_item	2939474	et	4	main
fotoallikaid	doc_919500587379_item	2939475	et	3	main
ajalehe	doc_919500587379_item	2939476	et	3	main
veerulaius	doc_919500587379_item	2939477	et	4	main
ja	doc_919500587379_item	2939478	et	3	main
veerupikkus	doc_919500587379_item	2939479	et	4	main
on	doc_919500587379_item	2939480	et	4	main
minu	doc_919500587379_item	2939481	et	3	main
meelest	doc_919500587379_item	2939482	et	4	main
normaalsed	doc_919500587379_item	2939483	et	3	main
lugedes	doc_919500587379_item	2939484	et	3	main
silmad	doc_919500587379_item	2939485	et	4	main
ei	doc_919500587379_item	2939486	et	4	main
ja	doc_919500587379_item	2939431	et	3	main
paljude	doc_919500587379_item	2939432	et	3	main
hirmutab	doc_919500587379_item	2939446	et	3	main
olla	doc_919500587379_item	2939448	et	3	main
osutus	doc_919500587379_item	2939457	et	4	main
on	doc_919500587379_item	2939466	et	4	main
väsita	doc_919500587379_item	2939487	et	4	main
ja	doc_919500587379_item	2939488	et	3	main
tähtist	doc_919500587379_item	2939496	et	4	main
on	doc_919500587379_item	2939506	et	4	main
ma	doc_919500587379_item	2939510	et	3	main
ei	doc_919500587379_item	2939522	et	4	main
palju	doc_919500587379_item	2939528	et	4	main
üles	doc_919500587379_item	2939532	et	3	main
õhtuajalehes	doc_919500587379_item	2939538	et	3	main
rohkem	doc_919500587379_item	2939540	et	4	main
palju	doc_919500587379_item	2939553	et	4	main
hüüdsõnu	doc_919500587379_item	2939556	et	3	main
enda	doc_919500587379_item	2939586	et	4	main
sl	doc_919500587379_item	2939596	et	4	main
esialgu	doc_919500587379_item	2939601	et	3	main
on	doc_919500587379_item	2939604	et	4	main
keele	doc_919500587379_item	2939610	et	4	main
on	doc_919500587379_item	2939616	et	4	main
inimeste	doc_919500587379_item	2939618	et	3	main
majanduse	doc_919500587379_item	2939623	et	4	main
poliitika	doc_919500587379_item	2939625	et	4	main
valdkonnas	doc_919500587379_item	2939626	et	4	main
selle	doc_919500587379_item	2939632	et	4	main
jaoks	doc_919500587379_item	2939643	et	4	main
või	doc_919500587379_item	2939648	et	4	main
sl	doc_919500587379_item	2939652	et	4	main
ka	doc_919500587379_item	2939656	et	3	main
artikleid	doc_919500587379_item	2939658	et	3	main
ajaviide	doc_919500587379_item	2939667	et	3	main
nii	doc_919500587379_item	2939721	et	3	main
äripäevas	doc_919500587379_item	2939723	et	3	main
on	doc_919500587379_item	2939725	et	4	main
isegi	doc_919500587379_item	2939728	et	4	main
see	doc_919500587379_item	2939736	et	3	main
et	doc_919500587379_item	2939737	et	3	main
on	doc_919500587379_item	2939744	et	4	main
palju	doc_919500587379_item	2939745	et	4	main
informatsiooni	doc_919500587379_item	2939746	et	4	main
mille	doc_919500587379_item	2939747	et	3	main
ei	doc_919500587379_item	2939750	et	4	main
kirjutatud	doc_919500587379_item	2939757	et	4	main
mida	doc_919500587379_item	2939763	et	4	main
eksisteerib	doc_919500587379_item	2939770	et	3	main
struktuur	doc_919500587379_item	2939772	et	3	main
igal	doc_919500587379_item	2939773	et	3	main
trükkitud	doc_919500587379_item	2939788	et	4	main
fotod	doc_919500587379_item	2939789	et	3	main
veergu	doc_919500587379_item	2939828	et	4	main
seepärast	doc_919500587379_item	2939829	et	3	main
veerud	doc_919500587379_item	2939830	et	4	main
võrreldes	doc_919500587379_item	2939839	et	3	main
ajalehte	doc_919500587379_item	2939841	et	4	main
ma	doc_919500587379_item	2939842	et	3	main
tegin	doc_919500587379_item	2939843	et	3	main
järeldust	doc_919500587379_item	2939844	et	4	main
et	doc_919500587379_item	2939845	et	3	main
erinevad	doc_919500587379_item	2939850	et	4	main
ei	doc_919500587379_item	2939861	et	4	main
saa	doc_919500587379_item	2939862	et	4	main
jõudu	doc_919500587379_item	2939888	et	4	main
rakendatud	doc_919500587379_item	2939890	et	4	main
tähtis	doc_919500587380_item	2939895	et	4	main
vaatamata	doc_919500587380_item	2939900	et	4	main
sellele	doc_919500587380_item	2939901	et	4	main
on	doc_919500587380_item	2939905	et	4	main
tasemel	doc_919500587380_item	2939913	et	3	main
ostavad	doc_919500587380_item	2939915	et	3	main
ning	doc_919500587380_item	2939923	et	3	main
on	doc_919500587380_item	2939935	et	4	main
minu	doc_919500587380_item	2939948	et	3	main
õhtulehe	doc_919500587380_item	2939955	et	3	main
numbrid	doc_919500587380_item	2939957	et	3	main
on	doc_919500587380_item	2939959	et	4	main
alustan	doc_919500587380_item	2939974	et	3	main
sellest	doc_919500587380_item	2939975	et	4	main
et	doc_919500587380_item	2939976	et	3	main
varieerivad	doc_919500587379_item	2939490	et	4	main
kasutatakse	doc_919500587379_item	2939491	et	3	main
mis	doc_919500587379_item	2939499	et	4	main
telefoninumbreid	doc_919500587379_item	2939508	et	3	main
isegi	doc_919500587379_item	2939516	et	4	main
vaja	doc_919500587379_item	2939527	et	4	main
neid	doc_919500587379_item	2939531	et	4	main
puudutab	doc_919500587379_item	2939535	et	3	main
siis	doc_919500587379_item	2939537	et	3	main
kasutatakse	doc_919500587379_item	2939552	et	3	main
ja	doc_919500587379_item	2939555	et	3	main
mis	doc_919500587379_item	2939557	et	4	main
leida	doc_919500587379_item	2939581	et	3	main
jaoks	doc_919500587379_item	2939587	et	4	main
analüüs	doc_919500587379_item	2939588	et	3	main
olen	doc_919500587379_item	2939589	et	3	main
võrreldanud	doc_919500587379_item	2939590	et	4	main
kaks	doc_919500587379_item	2939591	et	3	main
erinevat	doc_919500587379_item	2939592	et	4	main
ajalehte	doc_919500587379_item	2939593	et	4	main
äripäev	doc_919500587379_item	2939594	et	3	main
ja	doc_919500587379_item	2939595	et	3	main
on	doc_919500587379_item	2939598	et	4	main
stiilid	doc_919500587379_item	2939611	et	4	main
või	doc_919500587379_item	2939627	et	4	main
huvi	doc_919500587379_item	2939631	et	4	main
sest	doc_919500587379_item	2939634	et	4	main
artiklides	doc_919500587379_item	2939636	et	4	main
ole	doc_919500587379_item	2939645	et	4	main
nii	doc_919500587379_item	2939646	et	3	main
mitte	doc_919500587379_item	2939650	et	3	main
meelest	doc_919500587379_item	2939662	et	4	main
mõeldud	doc_919500587379_item	2939666	et	4	main
kujundeidvärvilisi	doc_919500587379_item	2939712	et	4	main
kastemis	doc_919500587379_item	2939713	et	4	main
teevad	doc_919500587379_item	2939714	et	3	main
selle	doc_919500587379_item	2939715	et	4	main
liiga	doc_919500587379_item	2939729	et	4	main
on	doc_919500587379_item	2939735	et	4	main
arvates	doc_919500587379_item	2939749	et	4	main
mis	doc_919500587379_item	2939759	et	4	main
mõtetud	doc_919500587379_item	2939761	et	4	main
ajal	doc_919500587379_item	2939768	et	4	main
äripäevas	doc_919500587379_item	2939769	et	3	main
ei	doc_919500587379_item	2939779	et	4	main
tühja	doc_919500587379_item	2939782	et	4	main
ei	doc_919500587379_item	2939792	et	4	main
et	doc_919500587379_item	2939822	et	3	main
kokkuvõte	doc_919500587379_item	2939838	et	3	main
küllaltki	doc_919500587379_item	2939849	et	4	main
on	doc_919500587379_item	2939853	et	4	main
milline	doc_919500587379_item	2939864	et	3	main
ajaleht	doc_919500587379_item	2939865	et	3	main
ajaleht	doc_919500587380_item	2939893	et	3	main
infoallikas	doc_919500587380_item	2939896	et	4	main
meie	doc_919500587380_item	2939897	et	4	main
et	doc_919500587380_item	2939902	et	3	main
kasutusel	doc_919500587380_item	2939907	et	4	main
on	doc_919500587380_item	2939911	et	4	main
erinevad	doc_919500587380_item	2939932	et	4	main
ja	doc_919500587380_item	2939933	et	3	main
igaüks	doc_919500587380_item	2939934	et	3	main
tahaks	doc_919500587380_item	2939940	et	3	main
ajalehte	doc_919500587380_item	2939944	et	4	main
õhtuleht	doc_919500587380_item	2939947	et	3	main
poolt	doc_919500587380_item	2939949	et	4	main
valitud	doc_919500587380_item	2939950	et	4	main
ajalehed	doc_919500587380_item	2939951	et	3	main
on	doc_919500587380_item	2939952	et	4	main
märtsil	doc_919500587380_item	2939965	et	3	main
selles	doc_919500587380_item	2939966	et	4	main
uurimuses	doc_919500587380_item	2939967	et	3	main
hakkan	doc_919500587380_item	2939968	et	3	main
neid	doc_919500587380_item	2939971	et	4	main
ajalehte	doc_919500587380_item	2939972	et	4	main
kõigepealt	doc_919500587380_item	2939973	et	3	main
rubriigid	doc_919500587380_item	2939985	et	3	main
ja	doc_919500587380_item	2939986	et	3	main
osakonnad	doc_919500587380_item	2939987	et	4	main
etappina	doc_919500587380_item	2939989	et	4	main
mul	doc_919500587380_item	2939991	et	3	main
üldised	doc_919500587380_item	2940022	et	3	main
rasvase	doc_919500587379_item	2939502	et	4	main
punase	doc_919500587379_item	2939503	et	4	main
kirjaga	doc_919500587379_item	2939504	et	3	main
õhtulehes	doc_919500587379_item	2939505	et	3	main
ei	doc_919500587379_item	2939511	et	4	main
ühtegi	doc_919500587379_item	2939513	et	4	main
toimetaja	doc_919500587379_item	2939514	et	4	main
andmeid	doc_919500587379_item	2939515	et	3	main
märkav	doc_919500587379_item	2939524	et	4	main
ja	doc_919500587379_item	2939525	et	3	main
on	doc_919500587379_item	2939526	et	4	main
lehitseda	doc_919500587379_item	2939529	et	3	main
jutustav	doc_919500587379_item	2939541	et	4	main
artiklides	doc_919500587379_item	2939551	et	4	main
huvitavat	doc_919500587379_item	2939583	et	4	main
kasulikku	doc_919500587379_item	2939585	et	4	main
õhtuleht	doc_919500587379_item	2939597	et	3	main
täitsa	doc_919500587379_item	2939599	et	3	main
seepärast	doc_919500587379_item	2939609	et	3	main
äripäev	doc_919500587379_item	2939615	et	3	main
jaoks	doc_919500587379_item	2939619	et	4	main
kellel	doc_919500587379_item	2939620	et	4	main
et	doc_919500587379_item	2939530	et	3	main
leida	doc_919500587379_item	2939533	et	3	main
keelekasutust	doc_919500587379_item	2939536	et	4	main
on	doc_919500587379_item	2939539	et	4	main
otse	doc_919500587379_item	2939548	et	4	main
mõnedes	doc_919500587379_item	2939550	et	3	main
sõnu	doc_919500587379_item	2939554	et	4	main
vastata	doc_919500587379_item	2939559	et	4	main
see	doc_919500587379_item	2939561	et	3	main
mõeldud	doc_919500587379_item	2939564	et	4	main
inimeste	doc_919500587379_item	2939565	et	3	main
jaoks	doc_919500587379_item	2939566	et	4	main
kes	doc_919500587379_item	2939567	et	4	main
tahavad	doc_919500587379_item	2939568	et	3	main
lihtsalt	doc_919500587379_item	2939569	et	4	main
teada	doc_919500587379_item	2939570	et	3	main
saada	doc_919500587379_item	2939571	et	4	main
uudist	doc_919500587379_item	2939572	et	3	main
mis	doc_919500587379_item	2939573	et	4	main
ei	doc_919500587379_item	2939574	et	4	main
ole	doc_919500587379_item	2939575	et	4	main
nii	doc_919500587379_item	2939576	et	3	main
aktuaalne	doc_919500587379_item	2939577	et	3	main
ja	doc_919500587379_item	2939578	et	3	main
tähtis	doc_919500587379_item	2939579	et	4	main
kirjakeelele	doc_919500587379_item	2939560	et	4	main
ajaleht	doc_919500587379_item	2939562	et	3	main
on	doc_919500587379_item	2939563	et	4	main
ning	doc_919500587379_item	2939580	et	3	main
midagi	doc_919500587379_item	2939582	et	4	main
ja	doc_919500587379_item	2939584	et	3	main
need	doc_919500587379_item	2939602	et	3	main
ajalehed	doc_919500587379_item	2939603	et	3	main
jaoks	doc_919500587379_item	2939608	et	4	main
teisest	doc_919500587379_item	2939614	et	4	main
mõeldud	doc_919500587379_item	2939617	et	4	main
on	doc_919500587379_item	2939621	et	4	main
ja	doc_919500587379_item	2939624	et	3	main
nad	doc_919500587379_item	2939629	et	3	main
vastu	doc_919500587379_item	2939633	et	3	main
ei	doc_919500587379_item	2939644	et	4	main
lõppuni	doc_919500587379_item	2939649	et	3	main
arusaadavad	doc_919500587379_item	2939651	et	3	main
kuid	doc_919500587379_item	2939659	et	4	main
rohkem	doc_919500587379_item	2939660	et	4	main
minu	doc_919500587379_item	2939661	et	3	main
on	doc_919500587379_item	2939665	et	4	main
on	doc_919500587379_item	2939704	et	4	main
ajalehe	doc_919500587379_item	2939716	et	3	main
lõbusam	doc_919500587379_item	2939717	et	4	main
ja	doc_919500587379_item	2939718	et	3	main
köidavad	doc_919500587379_item	2939719	et	3	main
ei	doc_919500587379_item	2939733	et	4	main
küllaltki	doc_919500587379_item	2939739	et	4	main
on	doc_919500587379_item	2939755	et	4	main
pooleldi	doc_919500587379_item	2939756	et	3	main
loe	doc_919500587379_item	2939766	et	4	main
samal	doc_919500587379_item	2939767	et	3	main
informatsiooni	doc_919500587379_item	2939778	et	4	main
isegi	doc_919500587379_item	2939781	et	4	main
ruumi	doc_919500587379_item	2939783	et	4	main
artiklid	doc_919500587379_item	2939784	et	3	main
erinevad	doc_919500587379_item	2939600	et	4	main
mõeldud	doc_919500587379_item	2939605	et	4	main
erinevate	doc_919500587379_item	2939606	et	4	main
rahvakihide	doc_919500587379_item	2939607	et	4	main
erinevad	doc_919500587379_item	2939612	et	4	main
üks	doc_919500587379_item	2939613	et	3	main
kogemus	doc_919500587379_item	2939622	et	3	main
tunnevad	doc_919500587379_item	2939630	et	3	main
mõnedes	doc_919500587379_item	2939635	et	3	main
kasutatakse	doc_919500587379_item	2939637	et	3	main
spetsiifilised	doc_919500587379_item	2939638	et	3	main
diagrammid	doc_919500587379_item	2939639	et	3	main
mis	doc_919500587379_item	2939640	et	4	main
huvitav	doc_919500587379_item	2939647	et	4	main
õhtuajalehes	doc_919500587379_item	2939653	et	3	main
leida	doc_919500587379_item	2939655	et	3	main
ajaleht	doc_919500587379_item	2939664	et	3	main
artiklid	doc_919500587379_item	2939669	et	3	main
meeldinud	doc_919500587379_item	2939734	et	4	main
ruumi	doc_919500587379_item	2939742	et	4	main
ning	doc_919500587379_item	2939743	et	3	main
teisipäevases	doc_919500587379_item	2939753	et	4	main
õhtulehes	doc_919500587379_item	2939754	et	3	main
on	doc_919500587379_item	2939760	et	4	main
ja	doc_919500587379_item	2939762	et	3	main
keegi	doc_919500587379_item	2939764	et	4	main
ei	doc_919500587379_item	2939765	et	4	main
on	doc_919500587379_item	2939775	et	4	main
väga	doc_919500587379_item	2939776	et	3	main
palju	doc_919500587379_item	2939777	et	4	main
on	doc_919500587379_item	2939785	et	4	main
hästi	doc_919500587379_item	2939786	et	3	main
tihedalt	doc_919500587379_item	2939787	et	4	main
mõlemadel	doc_919500587379_item	2939823	et	4	main
ajalehtedel	doc_919500587379_item	2939824	et	4	main
on	doc_919500587379_item	2939825	et	4	main
kasutatud	doc_919500587379_item	2939826	et	4	main
lühemad	doc_919500587379_item	2939832	et	4	main
ja	doc_919500587379_item	2939833	et	3	main
tekst	doc_919500587379_item	2939834	et	3	main
tundub	doc_919500587379_item	2939835	et	3	main
ja	doc_919500587379_item	2939851	et	3	main
palju	doc_919500587379_item	2939854	et	4	main
aspekte	doc_919500587379_item	2939855	et	3	main
mille	doc_919500587379_item	2939856	et	3	main
öelda	doc_919500587379_item	2939863	et	4	main
viimased	doc_919500587380_item	2939921	et	3	main
lihtsalt	doc_919500587380_item	2939924	et	4	main
nautida	doc_919500587380_item	2939927	et	3	main
lugemist	doc_919500587380_item	2939928	et	4	main
kõik	doc_919500587380_item	2939929	et	4	main
ajalehed	doc_919500587380_item	2939930	et	3	main
omamoodi	doc_919500587380_item	2939936	et	3	main
ma	doc_919500587380_item	2939941	et	3	main
kaks	doc_919500587380_item	2939943	et	3	main
äripäev	doc_919500587380_item	2939945	et	3	main
ja	doc_919500587380_item	2939954	et	3	main
reedesed	doc_919500587380_item	2939956	et	4	main
ma	doc_919500587380_item	2939969	et	3	main
järmise	doc_919500587380_item	2939988	et	4	main
on	doc_919500587380_item	2939990	et	4	main
on	doc_919500587380_item	2940021	et	4	main
osakonnad	doc_919500587380_item	2940023	et	4	main
olemas	doc_919500587380_item	2940024	et	4	main
uudised	doc_919500587380_item	2940025	et	3	main
saab	doc_919500587380_item	2940036	et	3	main
välismaa	doc_919500587380_item	2940044	et	4	main
kuulutused	doc_919500587380_item	2940048	et	4	main
sport	doc_919500587380_item	2940049	et	3	main
leida	doc_919500587380_item	2940052	et	3	main
eraldi	doc_919500587380_item	2940062	et	4	main
väljaanne	doc_919500587380_item	2940064	et	4	main
mis	doc_919500587380_item	2940065	et	4	main
on	doc_919500587380_item	2940066	et	4	main
ühes	doc_919500587380_item	2940071	et	4	main
õhtulehes	doc_919500587380_item	2940103	et	3	main
liiga	doc_919500587380_item	2940114	et	4	main
pikemaks	doc_919500587380_item	2940115	et	4	main
olev	doc_919500587380_item	2940122	et	4	main
öelda	doc_919500587380_item	2940136	et	4	main
trükkitud	doc_919500587380_item	2940140	et	4	main
vähemalt	doc_919500587379_item	2939628	et	4	main
teiste	doc_919500587379_item	2939641	et	4	main
inimeste	doc_919500587379_item	2939642	et	3	main
võib	doc_919500587379_item	2939654	et	3	main
tõsiseid	doc_919500587379_item	2939657	et	4	main
see	doc_919500587379_item	2939663	et	3	main
jaoks	doc_919500587379_item	2939668	et	4	main
on	doc_919500587379_item	2939670	et	4	main
lihtsad	doc_919500587379_item	2939671	et	3	main
arusaadavad	doc_919500587379_item	2939672	et	3	main
ja	doc_919500587379_item	2939673	et	3	main
palju	doc_919500587379_item	2939674	et	4	main
tähelepanu	doc_919500587379_item	2939675	et	4	main
pühendatakse	doc_919500587379_item	2939676	et	3	main
elanikkonna	doc_919500587379_item	2939677	et	3	main
elule	doc_919500587379_item	2939678	et	3	main
paljud	doc_919500587379_item	2939679	et	3	main
artiklid	doc_919500587379_item	2939680	et	3	main
õhtulehes	doc_919500587379_item	2939681	et	3	main
on	doc_919500587379_item	2939682	et	4	main
kuulsustest	doc_919500587379_item	2939683	et	4	main
ja	doc_919500587379_item	2939684	et	3	main
poliitikutest	doc_919500587379_item	2939685	et	4	main
seepärast	doc_919500587379_item	2939686	et	3	main
paljud	doc_919500587379_item	2939687	et	3	main
uudised	doc_919500587379_item	2939688	et	3	main
ei	doc_919500587379_item	2939689	et	4	main
ole	doc_919500587379_item	2939690	et	4	main
sajaprotsendiliselt	doc_919500587379_item	2939691	et	4	main
tõepärased	doc_919500587379_item	2939692	et	4	main
mis	doc_919500587379_item	2939693	et	4	main
puudutab	doc_919500587379_item	2939694	et	3	main
ajalehtede	doc_919500587379_item	2939695	et	4	main
kujundust	doc_919500587379_item	2939696	et	4	main
siis	doc_919500587379_item	2939697	et	3	main
nagu	doc_919500587379_item	2939698	et	3	main
ma	doc_919500587379_item	2939699	et	3	main
olen	doc_919500587379_item	2939700	et	3	main
juba	doc_919500587379_item	2939701	et	3	main
maininud	doc_919500587379_item	2939702	et	4	main
õhtuleht	doc_919500587379_item	2939703	et	3	main
eredam	doc_919500587379_item	2939705	et	4	main
kui	doc_919500587379_item	2939706	et	3	main
äripäev	doc_919500587379_item	2939707	et	3	main
võib	doc_919500587379_item	2939708	et	3	main
leida	doc_919500587379_item	2939709	et	3	main
rohkem	doc_919500587379_item	2939710	et	4	main
spetsiifilisi	doc_919500587379_item	2939711	et	3	main
tähelepanu	doc_919500587379_item	2939720	et	4	main
nagi	doc_919500587379_item	2939722	et	4	main
õhtulehes	doc_919500587379_item	2939724	et	3	main
palju	doc_919500587379_item	2939726	et	4	main
reklaame	doc_919500587379_item	2939727	et	3	main
palju	doc_919500587379_item	2939730	et	4	main
mis	doc_919500587379_item	2939731	et	4	main
mulle	doc_919500587379_item	2939732	et	4	main
õhtulehes	doc_919500587379_item	2939738	et	3	main
palju	doc_919500587379_item	2939740	et	4	main
tühja	doc_919500587379_item	2939741	et	4	main
minu	doc_919500587379_item	2939748	et	3	main
loeta	doc_919500587379_item	2939751	et	4	main
näiteks	doc_919500587379_item	2939752	et	4	main
koomiksid	doc_919500587379_item	2939758	et	3	main
range	doc_919500587379_item	2939771	et	4	main
leheküljel	doc_919500587379_item	2939774	et	3	main
ole	doc_919500587379_item	2939780	et	4	main
mõlemades	doc_919500587379_item	2939790	et	4	main
ajalehtedes	doc_919500587379_item	2939791	et	4	main
ole	doc_919500587379_item	2939793	et	4	main
hästi	doc_919500587379_item	2939794	et	3	main
õnnestunud	doc_919500587379_item	2939795	et	4	main
eriti	doc_919500587379_item	2939796	et	3	main
mulle	doc_919500587379_item	2939797	et	4	main
üldse	doc_919500587379_item	2939798	et	3	main
ei	doc_919500587379_item	2939799	et	4	main
meeldinud	doc_919500587379_item	2939800	et	4	main
fotosid	doc_919500587379_item	2939801	et	3	main
õhtujalehes	doc_919500587379_item	2939802	et	4	main
kus	doc_919500587379_item	2939803	et	3	main
õudsalt	doc_919500587379_item	2939804	et	4	main
suured	doc_919500587379_item	2939805	et	3	main
fotod	doc_919500587379_item	2939806	et	3	main
ületavad	doc_919500587379_item	2939807	et	4	main
raami	doc_919500587379_item	2939808	et	4	main
piiri	doc_919500587379_item	2939809	et	4	main
palju	doc_919500587379_item	2939810	et	4	main
parem	doc_919500587379_item	2939811	et	4	main
on	doc_919500587379_item	2939812	et	4	main
ka	doc_919500587379_item	2939813	et	3	main
äripäeva	doc_919500587379_item	2939814	et	4	main
paberi	doc_919500587379_item	2939815	et	3	main
kvaliteet	doc_919500587379_item	2939816	et	3	main
mis	doc_919500587379_item	2939817	et	4	main
mulle	doc_919500587379_item	2939818	et	4	main
meeldis	doc_919500587379_item	2939819	et	3	main
on	doc_919500587379_item	2939820	et	4	main
see	doc_919500587379_item	2939821	et	3	main
tulevad	doc_919500587379_item	2939831	et	4	main
mõlemad	doc_919500587379_item	2939846	et	3	main
ajalehed	doc_919500587379_item	2939847	et	3	main
on	doc_919500587379_item	2939848	et	4	main
võiks	doc_919500587379_item	2939857	et	4	main
palju	doc_919500587379_item	2939827	et	4	main
lühem	doc_919500587379_item	2939836	et	4	main
tervikuna	doc_919500587379_item	2939837	et	3	main
kaks	doc_919500587379_item	2939840	et	3	main
neil	doc_919500587379_item	2939852	et	4	main
on	doc_919500587379_item	2939866	et	4	main
parem	doc_919500587379_item	2939867	et	4	main
milline-	doc_919500587379_item	2939868	et	3	main
halvem	doc_919500587379_item	2939869	et	4	main
sest	doc_919500587379_item	2939870	et	4	main
nad	doc_919500587379_item	2939871	et	3	main
on	doc_919500587379_item	2939872	et	4	main
erinevatest	doc_919500587379_item	2939873	et	4	main
valdkondadest	doc_919500587379_item	2939874	et	3	main
kuigi	doc_919500587379_item	2939875	et	3	main
ma	doc_919500587379_item	2939876	et	3	main
võin	doc_919500587379_item	2939877	et	3	main
öelda	doc_919500587379_item	2939878	et	4	main
et	doc_919500587379_item	2939879	et	3	main
minu	doc_919500587379_item	2939880	et	3	main
meelest	doc_919500587379_item	2939881	et	4	main
äripäev	doc_919500587379_item	2939882	et	3	main
on	doc_919500587379_item	2939883	et	4	main
tehtud	doc_919500587379_item	2939884	et	4	main
ausameelselt	doc_919500587379_item	2939885	et	4	main
ja	doc_919500587379_item	2939886	et	3	main
rohkem	doc_919500587379_item	2939887	et	4	main
omavahel	doc_919500587379_item	2939858	et	3	main
võrrelda	doc_919500587379_item	2939859	et	4	main
ma	doc_919500587379_item	2939860	et	3	main
on	doc_919500587379_item	2939889	et	4	main
on	doc_919500587380_item	2939894	et	4	main
maailmas	doc_919500587380_item	2939904	et	3	main
heal	doc_919500587380_item	2939912	et	3	main
ja	doc_919500587380_item	2939916	et	3	main
ajalehte	doc_919500587380_item	2939918	et	4	main
et	doc_919500587380_item	2939919	et	3	main
saada	doc_919500587380_item	2939920	et	4	main
sisule	doc_919500587379_item	2939891	et	3	main
referaat	doc_919500587380_item	2939892	et	3	main
tänapäevases	doc_919500587380_item	2939898	et	4	main
alus	doc_919500587380_item	2939899	et	4	main
praeguses	doc_919500587380_item	2939903	et	3	main
meil	doc_919500587380_item	2939906	et	4	main
erinevad	doc_919500587380_item	2939908	et	4	main
infoallikad	doc_919500587380_item	2939909	et	3	main
ajalehed	doc_919500587380_item	2939910	et	3	main
inimsed	doc_919500587380_item	2939914	et	4	main
tellivad	doc_919500587380_item	2939917	et	4	main
uudised	doc_919500587380_item	2939922	et	3	main
selleks	doc_919500587380_item	2939925	et	4	main
et	doc_919500587380_item	2939926	et	3	main
hea	doc_919500587380_item	2939937	et	4	main
töös	doc_919500587380_item	2939939	et	3	main
analüüsida	doc_919500587380_item	2939942	et	3	main
ja	doc_919500587380_item	2939946	et	3	main
äripäeva	doc_919500587380_item	2939953	et	4	main
mis	doc_919500587380_item	2939958	et	4	main
võrdlema	doc_919500587380_item	2939970	et	3	main
kiirjutan	doc_919500587380_item	2939982	et	4	main
ajalehe	doc_919500587380_item	2939983	et	3	main
ülesehitusest	doc_919500587380_item	2939984	et	4	main
mitmesugused	doc_919500587380_item	2940034	et	3	main
leida	doc_919500587380_item	2940037	et	3	main
kodu	doc_919500587380_item	2940042	et	4	main
elamus	doc_919500587380_item	2940059	et	4	main
sündmus	doc_919500587380_item	2940060	et	3	main
sisse	doc_919500587380_item	2940069	et	4	main
mis	doc_919500587380_item	2940079	et	4	main
pangadest	doc_919500587380_item	2940089	et	4	main
rahaturust	doc_919500587380_item	2940090	et	3	main
investeerimisest	doc_919500587380_item	2940092	et	4	main
tervis	doc_919500587380_item	2940094	et	3	main
noored	doc_919500587380_item	2940095	et	3	main
asuv	doc_919500587380_item	2940104	et	4	main
osakond	doc_919500587380_item	2940105	et	3	main
mille	doc_919500587380_item	2940106	et	3	main
nimeks	doc_919500587380_item	2940107	et	3	main
on	doc_919500587380_item	2940108	et	4	main
läinud	doc_919500587380_item	2940129	et	4	main
parim	doc_919500587380_item	2940148	et	4	main
variant	doc_919500587380_item	2940149	et	3	main
oleksid	doc_919500587380_item	2940157	et	4	main
trükkitud	doc_919500587380_item	2940164	et	4	main
asi	doc_919500587380_item	2940194	et	4	main
ja	doc_919500587380_item	2940195	et	3	main
kindlasti	doc_919500587380_item	2940196	et	3	main
peaks	doc_919500587380_item	2940197	et	4	main
olema	doc_919500587380_item	2940198	et	4	main
hakkab	doc_919500587380_item	2940203	et	3	main
on	doc_919500587380_item	2940207	et	4	main
on	doc_919500587380_item	2940218	et	4	main
lehel	doc_919500587380_item	2940224	et	3	main
reklaam	doc_919500587380_item	2940226	et	3	main
mingi	doc_919500587380_item	2940252	et	4	main
mis	doc_919500587380_item	2940254	et	4	main
selle	doc_919500587380_item	2940256	et	4	main
auto	doc_919500587380_item	2940260	et	4	main
uudiste	doc_919500587380_item	2940268	et	3	main
nagu	doc_919500587380_item	2940270	et	3	main
ongi	doc_919500587380_item	2940272	et	4	main
numbris	doc_919500587380_item	2940274	et	3	main
osakondade	doc_919500587380_item	2940275	et	3	main
järgmised	doc_919500587380_item	2940286	et	3	main
on	doc_919500587380_item	2940322	et	4	main
see	doc_919500587380_item	2940324	et	3	main
üsna	doc_919500587380_item	2940328	et	3	main
kujutatud	doc_919500587380_item	2940330	et	4	main
repotraazid	doc_919500587380_item	2940331	et	4	main
ning	doc_919500587380_item	2940335	et	3	main
on	doc_919500587380_item	2940337	et	4	main
pildid	doc_919500587380_item	2940342	et	3	main
piisavalt	doc_919500587380_item	2940344	et	4	main
peegeldavad	doc_919500587380_item	2940347	et	4	main
üks	doc_919500587380_item	2940356	et	3	main
lühikesed	doc_919500587380_item	2940374	et	4	main
aga	doc_919500587380_item	2940375	et	3	main
mõne	doc_919500587380_item	2940377	et	3	main
mis	doc_919500587380_item	2940379	et	4	main
on	doc_919500587380_item	2939931	et	4	main
selles	doc_919500587380_item	2939938	et	4	main
ilmunud	doc_919500587380_item	2939960	et	4	main
16	doc_919500587380_item	2939961	et	2	main
märtsil	doc_919500587380_item	2939962	et	3	main
ja	doc_919500587380_item	2939963	et	3	main
23	doc_919500587380_item	2939964	et	2	main
läbi	doc_919500587380_item	2939980	et	4	main
ning	doc_919500587380_item	2939981	et	3	main
plaanis	doc_919500587380_item	2939992	et	4	main
analüüsida	doc_919500587380_item	2939993	et	3	main
ajalehtede	doc_919500587380_item	2939994	et	4	main
ehk	doc_919500587380_item	2939996	et	3	main
üldilme	doc_919500587380_item	2939995	et	4	main
kujundust	doc_919500587380_item	2939997	et	4	main
kirja	doc_919500587380_item	2939998	et	4	main
illustratsioone	doc_919500587380_item	2939999	et	3	main
keelekasutust	doc_919500587380_item	2940000	et	4	main
ajalehe	doc_919500587380_item	2940002	et	3	main
jt	doc_919500587380_item	2940001	et	4	main
ülesehitus	doc_919500587380_item	2940003	et	4	main
nii	doc_919500587380_item	2940004	et	3	main
äripäev	doc_919500587380_item	2940005	et	3	main
kui	doc_919500587380_item	2940006	et	3	main
ka	doc_919500587380_item	2940007	et	3	main
õhtuleht	doc_919500587380_item	2940008	et	3	main
on	doc_919500587380_item	2940009	et	4	main
omamoodi	doc_919500587380_item	2940010	et	3	main
huvitavad	doc_919500587380_item	2940011	et	4	main
osakonnad	doc_919500587380_item	2940012	et	4	main
on	doc_919500587380_item	2940013	et	4	main
osad	doc_919500587380_item	2940014	et	3	main
milleks	doc_919500587380_item	2940015	et	4	main
ajaleht	doc_919500587380_item	2940016	et	3	main
on	doc_919500587380_item	2940017	et	4	main
jagatud	doc_919500587380_item	2940018	et	4	main
igas	doc_919500587380_item	2940019	et	3	main
ajalehes	doc_919500587380_item	2940020	et	3	main
vaatan	doc_919500587380_item	2939977	et	3	main
need	doc_919500587380_item	2939978	et	3	main
ajalehed	doc_919500587380_item	2939979	et	3	main
põhjalikumalt	doc_919500587380_item	2940029	et	4	main
siis	doc_919500587380_item	2940030	et	3	main
õhtulehes	doc_919500587380_item	2940035	et	3	main
järgmised	doc_919500587380_item	2940038	et	3	main
oma	doc_919500587380_item	2940041	et	4	main
ja	doc_919500587380_item	2940046	et	3	main
äripäevas	doc_919500587380_item	2940050	et	3	main
järgmised	doc_919500587380_item	2940053	et	3	main
trükkitatud	doc_919500587380_item	2940063	et	4	main
pandud	doc_919500587380_item	2940067	et	4	main
ajalehe	doc_919500587380_item	2940068	et	3	main
numbris	doc_919500587380_item	2940073	et	3	main
eraldi	doc_919500587380_item	2940076	et	4	main
pandud	doc_919500587380_item	2940081	et	4	main
ajalehe	doc_919500587380_item	2940082	et	3	main
sisse	doc_919500587380_item	2940083	et	4	main
jaotatud	doc_919500587380_item	2940101	et	4	main
vaid	doc_919500587380_item	2940102	et	3	main
meelest	doc_919500587380_item	2940113	et	4	main
osakond	doc_919500587380_item	2940123	et	3	main
turism	doc_919500587380_item	2940124	et	3	main
kui	doc_919500587380_item	2940130	et	3	main
rääkida	doc_919500587380_item	2940131	et	3	main
äripäevast	doc_919500587380_item	2940132	et	4	main
et	doc_919500587380_item	2940138	et	3	main
osakonnad	doc_919500587380_item	2940141	et	4	main
ja	doc_919500587380_item	2940143	et	3	main
eraldi	doc_919500587380_item	2940162	et	4	main
eraldi	doc_919500587380_item	2940163	et	4	main
märkasin	doc_919500587380_item	2940212	et	3	main
ma	doc_919500587380_item	2940213	et	3	main
seda	doc_919500587380_item	2940214	et	3	main
et	doc_919500587380_item	2940215	et	3	main
igas	doc_919500587380_item	2940216	et	3	main
reklaami	doc_919500587380_item	2940221	et	4	main
mis	doc_919500587380_item	2940227	et	4	main
on	doc_919500587380_item	2940228	et	4	main
aal	doc_919500587380_item	2940234	et	4	main
vastaks	doc_919500587380_item	2940255	et	3	main
osakonna	doc_919500587380_item	2940257	et	4	main
teemale	doc_919500587380_item	2940258	et	4	main
teisel	doc_919500587380_item	2940266	et	4	main
teised	doc_919500587380_item	2940031	et	4	main
osakonnad	doc_919500587380_item	2940032	et	4	main
naine	doc_919500587380_item	2940040	et	3	main
film	doc_919500587380_item	2940043	et	3	main
meelelahutus	doc_919500587380_item	2940047	et	4	main
saab	doc_919500587380_item	2940051	et	3	main
osakonnad	doc_919500587380_item	2940054	et	4	main
portree	doc_919500587380_item	2940055	et	4	main
luubi	doc_919500587380_item	2940056	et	3	main
all	doc_919500587380_item	2940057	et	3	main
vaatlus	doc_919500587380_item	2940058	et	3	main
äripäeva	doc_919500587380_item	2940072	et	4	main
ka	doc_919500587380_item	2940075	et	3	main
trükkitatud	doc_919500587380_item	2940077	et	4	main
väljaanne	doc_919500587380_item	2940078	et	4	main
börs	doc_919500587380_item	2940084	et	3	main
osakond	doc_919500587380_item	2940085	et	3	main
kus	doc_919500587380_item	2940086	et	3	main
on	doc_919500587380_item	2940087	et	4	main
jutud	doc_919500587380_item	2940088	et	3	main
auto	doc_919500587380_item	2940093	et	4	main
ajalehtedes	doc_919500587380_item	2940097	et	4	main
on	doc_919500587380_item	2940098	et	4	main
oma	doc_919500587380_item	2940109	et	4	main
rohkem	doc_919500587380_item	2940116	et	4	main
kui	doc_919500587380_item	2940117	et	3	main
3	doc_919500587380_item	2940118	et	2	main
lehekülge	doc_919500587380_item	2940119	et	4	main
äripäeva	doc_919500587380_item	2940120	et	4	main
arvamus	doc_919500587380_item	2940026	et	3	main
kui	doc_919500587380_item	2940027	et	3	main
vaadata	doc_919500587380_item	2940028	et	4	main
on	doc_919500587380_item	2940033	et	4	main
osakonnad	doc_919500587380_item	2940039	et	4	main
kultuur	doc_919500587380_item	2940045	et	3	main
puhkepäev	doc_919500587380_item	2940061	et	3	main
turism	doc_919500587380_item	2940070	et	3	main
on	doc_919500587380_item	2940074	et	4	main
on	doc_919500587380_item	2940080	et	4	main
ning	doc_919500587380_item	2940091	et	3	main
mõlemates	doc_919500587380_item	2940096	et	3	main
osakonnad	doc_919500587380_item	2940099	et	4	main
hästi	doc_919500587380_item	2940100	et	3	main
kodu	doc_919500587380_item	2940110	et	4	main
läheb	doc_919500587380_item	2940111	et	3	main
minu	doc_919500587380_item	2940112	et	3	main
ajalehes	doc_919500587380_item	2940121	et	3	main
on	doc_919500587380_item	2940125	et	4	main
siis	doc_919500587380_item	2940133	et	3	main
kohe	doc_919500587380_item	2940134	et	4	main
tahaks	doc_919500587380_item	2940135	et	3	main
eraldi	doc_919500587380_item	2940139	et	4	main
turism	doc_919500587380_item	2940142	et	3	main
minu	doc_919500587380_item	2940150	et	3	main
arvates	doc_919500587380_item	2940151	et	4	main
oleks	doc_919500587380_item	2940152	et	3	main
parem	doc_919500587380_item	2940153	et	4	main
kõik	doc_919500587380_item	2940155	et	4	main
osakonnad	doc_919500587380_item	2940156	et	4	main
sisse	doc_919500587380_item	2940160	et	4	main
pole	doc_919500587380_item	2940166	et	3	main
mugavad	doc_919500587380_item	2940167	et	3	main
meelest	doc_919500587380_item	2940190	et	4	main
reklaam	doc_919500587380_item	2940191	et	3	main
kui	doc_919500587380_item	2940205	et	3	main
paigutatud	doc_919500587380_item	2940229	et	4	main
lehe	doc_919500587380_item	2940235	et	3	main
lhe	doc_919500587380_item	2940237	et	4	main
küljelt	doc_919500587380_item	2940238	et	3	main
äripäevas	doc_919500587380_item	2940239	et	3	main
on	doc_919500587380_item	2940240	et	4	main
seda	doc_919500587380_item	2940241	et	3	main
olkes	doc_919500587380_item	2940251	et	4	main
näiteks	doc_919500587380_item	2940259	et	4	main
lood	doc_919500587380_item	2940278	et	4	main
omakorda	doc_919500587380_item	2940279	et	3	main
koondada	doc_919500587380_item	2940280	et	3	main
rubriikidesse	doc_919500587380_item	2940281	et	3	main
õhtulehe	doc_919500587380_item	2940282	et	3	main
uurides	doc_919500587380_item	2940283	et	4	main
märkasin	doc_919500587380_item	2940284	et	3	main
riik	doc_919500587380_item	2940288	et	3	main
õhtulehes	doc_919500587380_item	2940321	et	3	main
hästi	doc_919500587380_item	2940329	et	3	main
on	doc_919500587380_item	2940343	et	4	main
suured	doc_919500587380_item	2940345	et	3	main
ning	doc_919500587380_item	2940346	et	3	main
on	doc_919500587380_item	2940355	et	4	main
kujundus	doc_919500587380_item	2940383	et	4	main
lugejale	doc_919500587380_item	2940390	et	4	main
ja	doc_919500587380_item	2940393	et	3	main
tekstikirja	doc_919500587380_item	2940400	et	4	main
pealkirjade	doc_919500587380_item	2940401	et	3	main
loetav	doc_919500587380_item	2940417	et	4	main
mulle	doc_919500587380_item	2940436	et	4	main
täiega	doc_919500587380_item	2940437	et	3	main
ei	doc_919500587380_item	2940438	et	4	main
on	doc_919500587380_item	2940443	et	4	main
nn	doc_919500587380_item	2940445	et	4	main
tekst	doc_919500587380_item	2940457	et	3	main
paremini	doc_919500587380_item	2940459	et	4	main
stiilis	doc_919500587380_item	2940466	et	4	main
pealkirja	doc_919500587380_item	2940473	et	4	main
sama	doc_919500587380_item	2940475	et	4	main
on	doc_919500587380_item	2940489	et	4	main
eraldamiseks	doc_919500587380_item	2940542	et	4	main
lihtsus	doc_919500587380_item	2940549	et	4	main
pealkirjad	doc_919500587380_item	2940551	et	3	main
on	doc_919500587380_item	2940555	et	4	main
aktsia	doc_919500587380_item	2940571	et	4	main
hinnataseme	doc_919500587380_item	2940572	et	3	main
ka	doc_919500587380_item	2940126	et	3	main
liiga	doc_919500587380_item	2940127	et	4	main
pikaks	doc_919500587380_item	2940128	et	4	main
seda	doc_919500587380_item	2940137	et	3	main
puhkepäevad	doc_919500587380_item	2940144	et	3	main
ole	doc_919500587380_item	2940146	et	4	main
kõige	doc_919500587380_item	2940147	et	4	main
kui	doc_919500587380_item	2940154	et	3	main
osakonnad	doc_919500587380_item	2940165	et	4	main
lugemise	doc_919500587380_item	2940168	et	4	main
ajal	doc_919500587380_item	2940169	et	4	main
ning	doc_919500587380_item	2940170	et	3	main
need	doc_919500587380_item	2940171	et	3	main
vahelehed	doc_919500587380_item	2940172	et	3	main
langevad	doc_919500587380_item	2940173	et	4	main
kogu	doc_919500587380_item	2940174	et	4	main
aeg	doc_919500587380_item	2940175	et	3	main
ajalehest	doc_919500587380_item	2940176	et	4	main
välja	doc_919500587380_item	2940177	et	4	main
lisaks	doc_919500587380_item	2940178	et	4	main
sellele	doc_919500587380_item	2940179	et	4	main
igas	doc_919500587380_item	2940180	et	3	main
ajalehes	doc_919500587380_item	2940181	et	3	main
igas	doc_919500587380_item	2940182	et	3	main
osakonnas	doc_919500587380_item	2940183	et	4	main
on	doc_919500587380_item	2940184	et	4	main
liiga	doc_919500587380_item	2940185	et	4	main
palju	doc_919500587380_item	2940186	et	4	main
erinevaid	doc_919500587380_item	2940187	et	4	main
reklaame	doc_919500587380_item	2940188	et	3	main
ei	doc_919500587380_item	2940145	et	4	main
kirjutatud	doc_919500587380_item	2940158	et	4	main
ajalehe	doc_919500587380_item	2940159	et	3	main
mitte	doc_919500587380_item	2940161	et	3	main
hea	doc_919500587380_item	2940193	et	4	main
ärritama	doc_919500587380_item	2940204	et	3	main
st	doc_919500587380_item	2940222	et	3	main
erinevates	doc_919500587380_item	2940230	et	4	main
lehe	doc_919500587380_item	2940231	et	3	main
osades	doc_919500587380_item	2940232	et	3	main
parem	doc_919500587380_item	2940247	et	4	main
kui	doc_919500587380_item	2940248	et	3	main
igas	doc_919500587380_item	2940249	et	3	main
osakonnas	doc_919500587380_item	2940250	et	4	main
osakonnas	doc_919500587380_item	2940261	et	4	main
oleks	doc_919500587380_item	2940262	et	3	main
autode	doc_919500587380_item	2940263	et	3	main
reklaam	doc_919500587380_item	2940264	et	3	main
osakonnas	doc_919500587380_item	2940269	et	4	main
see	doc_919500587380_item	2940271	et	3	main
äripäeva	doc_919500587380_item	2940273	et	4	main
sees	doc_919500587380_item	2940276	et	4	main
võib	doc_919500587380_item	2940277	et	3	main
rubriigid	doc_919500587380_item	2940287	et	3	main
on	doc_919500587380_item	2940332	et	4	main
uudised	doc_919500587380_item	2940339	et	3	main
intervjuud	doc_919500587380_item	2940341	et	4	main
dramatismi	doc_919500587380_item	2940349	et	4	main
tavaliselt	doc_919500587380_item	2940350	et	4	main
igas	doc_919500587380_item	2940351	et	3	main
õhtulehes	doc_919500587380_item	2940352	et	3	main
spordi	doc_919500587380_item	2940353	et	4	main
spordi	doc_919500587380_item	2940370	et	4	main
uudised	doc_919500587380_item	2940371	et	3	main
pildiga	doc_919500587380_item	2940378	et	3	main
vastuvõetavasse	doc_919500587380_item	2940392	et	3	main
kujundus	doc_919500587380_item	2940397	et	4	main
jt	doc_919500587380_item	2940406	et	4	main
lehekujundus	doc_919500587380_item	2940407	et	3	main
lihtne	doc_919500587380_item	2940410	et	3	main
tekstikiri	doc_919500587380_item	2940413	et	3	main
olema	doc_919500587380_item	2940415	et	4	main
hästi	doc_919500587380_item	2940416	et	3	main
õelda	doc_919500587380_item	2940433	et	4	main
et	doc_919500587380_item	2940435	et	3	main
äripäev	doc_919500587380_item	2940442	et	3	main
trükkitud	doc_919500587380_item	2940444	et	4	main
heleroosal	doc_919500587380_item	2940446	et	4	main
paberil	doc_919500587380_item	2940447	et	3	main
minu	doc_919500587380_item	2940448	et	3	main
arvates	doc_919500587380_item	2940449	et	4	main
ajalehe	doc_919500587380_item	2940450	et	3	main
kirjutatud	doc_919500587380_item	2940456	et	4	main
loetav	doc_919500587380_item	2940460	et	4	main
ajalehed	doc_919500587380_item	2940461	et	3	main
kujundatakse	doc_919500587380_item	2940462	et	3	main
tavaliselt	doc_919500587380_item	2940463	et	4	main
paika	doc_919500587380_item	2940469	et	4	main
mida	doc_919500587380_item	2940522	et	4	main
paremaks	doc_919500587380_item	2940541	et	4	main
kõige	doc_919500587380_item	2940544	et	4	main
tähtsam	doc_919500587380_item	2940545	et	4	main
kõik	doc_919500587380_item	2940550	et	4	main
punast	doc_919500587380_item	2940556	et	4	main
värvi	doc_919500587380_item	2940557	et	4	main
ning	doc_919500587380_item	2940558	et	3	main
lugeja	doc_919500587380_item	2940559	et	4	main
saab	doc_919500587380_item	2940560	et	3	main
kergesti	doc_919500587380_item	2940561	et	3	main
orienteeruda	doc_919500587380_item	2940562	et	3	main
sel	doc_919500587380_item	2940563	et	3	main
lehel	doc_919500587380_item	2940564	et	3	main
ning	doc_919500587380_item	2940565	et	3	main
kiiresti	doc_919500587380_item	2940566	et	3	main
leida	doc_919500587380_item	2940567	et	3	main
üldiselt	doc_919500587380_item	2940573	et	4	main
nii	doc_919500587380_item	2940574	et	3	main
kui	doc_919500587380_item	2940576	et	3	main
on	doc_919500587380_item	2940586	et	4	main
artikleid	doc_919500587380_item	2940591	et	3	main
kasuta	doc_919500587380_item	2940627	et	4	main
minu	doc_919500587380_item	2940189	et	3	main
on	doc_919500587380_item	2940192	et	4	main
igas	doc_919500587380_item	2940199	et	3	main
ajalehes	doc_919500587380_item	2940200	et	3	main
vaid	doc_919500587380_item	2940201	et	3	main
see	doc_919500587380_item	2940202	et	3	main
reklaami	doc_919500587380_item	2940206	et	4	main
liiga	doc_919500587380_item	2940208	et	4	main
palju	doc_919500587380_item	2940209	et	4	main
vaadates	doc_919500587380_item	2940210	et	3	main
õhtulehe	doc_919500587380_item	2940211	et	3	main
osakonnas	doc_919500587380_item	2940217	et	4	main
liga	doc_919500587380_item	2940219	et	4	main
palju	doc_919500587380_item	2940220	et	4	main
igal	doc_919500587380_item	2940223	et	3	main
on	doc_919500587380_item	2940225	et	4	main
lehe	doc_919500587380_item	2940233	et	3	main
üleval	doc_919500587380_item	2940236	et	4	main
vähem	doc_919500587380_item	2940242	et	4	main
ma	doc_919500587380_item	2940243	et	3	main
arvan	doc_919500587380_item	2940244	et	3	main
et	doc_919500587380_item	2940245	et	3	main
oleks	doc_919500587380_item	2940246	et	3	main
reklaam	doc_919500587380_item	2940253	et	3	main
mitte	doc_919500587380_item	2940265	et	3	main
lehel	doc_919500587380_item	2940267	et	3	main
ma	doc_919500587380_item	2940285	et	3	main
krimi	doc_919500587380_item	2940289	et	4	main
ilmateade	doc_919500587380_item	2940290	et	4	main
jt	doc_919500587380_item	2940291	et	4	main
äripäevas	doc_919500587380_item	2940292	et	3	main
on	doc_919500587380_item	2940293	et	4	main
erinevates	doc_919500587380_item	2940294	et	4	main
osakondades	doc_919500587380_item	2940295	et	3	main
rubriigid	doc_919500587380_item	2940297	et	3	main
transport	doc_919500587380_item	2940298	et	3	main
erinevad	doc_919500587380_item	2940296	et	4	main
internet	doc_919500587380_item	2940299	et	4	main
poliitika	doc_919500587380_item	2940300	et	4	main
turva	doc_919500587380_item	2940301	et	4	main
õpingud	doc_919500587380_item	2940302	et	3	main
raha	doc_919500587380_item	2940303	et	4	main
karjäär	doc_919500587380_item	2940304	et	3	main
jt	doc_919500587380_item	2940305	et	4	main
ei	doc_919500587380_item	2940306	et	4	main
sa	doc_919500587380_item	2940307	et	3	main
mitte	doc_919500587380_item	2940308	et	3	main
mainida	doc_919500587380_item	2940309	et	3	main
ka	doc_919500587380_item	2940310	et	3	main
seda	doc_919500587380_item	2940311	et	3	main
et	doc_919500587380_item	2940312	et	3	main
äripäevas	doc_919500587380_item	2940313	et	3	main
puudub	doc_919500587380_item	2940314	et	3	main
spordi	doc_919500587380_item	2940315	et	4	main
osakond	doc_919500587380_item	2940316	et	3	main
ning	doc_919500587380_item	2940317	et	3	main
sellesse	doc_919500587380_item	2940318	et	4	main
kuluvad	doc_919500587380_item	2940319	et	4	main
rubriigid	doc_919500587380_item	2940320	et	3	main
aga	doc_919500587380_item	2940323	et	3	main
osakond	doc_919500587380_item	2940325	et	3	main
olemas	doc_919500587380_item	2940326	et	4	main
ning	doc_919500587380_item	2940327	et	3	main
huvitavad	doc_919500587380_item	2940334	et	4	main
küllaltki	doc_919500587380_item	2940333	et	4	main
enamasti	doc_919500587380_item	2940336	et	4	main
kirjas	doc_919500587380_item	2940338	et	4	main
mitte	doc_919500587380_item	2940340	et	3	main
või	doc_919500587380_item	2940357	et	4	main
kaks	doc_919500587380_item	2940358	et	3	main
peamist	doc_919500587380_item	2940359	et	3	main
uudist	doc_919500587380_item	2940360	et	3	main
mis	doc_919500587380_item	2940361	et	4	main
on	doc_919500587380_item	2940362	et	4	main
konkreetselt	doc_919500587380_item	2940363	et	4	main
kirjeldatud	doc_919500587380_item	2940364	et	4	main
ning	doc_919500587380_item	2940365	et	3	main
kindlasti	doc_919500587380_item	2940366	et	3	main
suure	doc_919500587380_item	2940367	et	3	main
fotoga	doc_919500587380_item	2940368	et	3	main
teised	doc_919500587380_item	2940369	et	4	main
spordi	doc_919500587380_item	2940348	et	4	main
osakonnas	doc_919500587380_item	2940354	et	4	main
hästi	doc_919500587380_item	2940373	et	3	main
ikkagi	doc_919500587380_item	2940376	et	4	main
kujundus	doc_919500587380_item	2940385	et	4	main
kergesti	doc_919500587380_item	2940391	et	3	main
sobivase	doc_919500587380_item	2940395	et	4	main
peab	doc_919500587380_item	2940408	et	4	main
selge	doc_919500587380_item	2940412	et	4	main
peavad	doc_919500587380_item	2940419	et	4	main
lajusega	doc_919500587380_item	2940422	et	4	main
seda	doc_919500587380_item	2940434	et	3	main
et	doc_919500587380_item	2940441	et	3	main
valge	doc_919500587380_item	2940453	et	4	main
on	doc_919500587380_item	2940458	et	4	main
kasutatakse	doc_919500587380_item	2940467	et	3	main
kord	doc_919500587380_item	2940468	et	4	main
tüüpe	doc_919500587380_item	2940474	et	3	main
liigendamiseks	doc_919500587380_item	2940538	et	4	main
ja	doc_919500587380_item	2940540	et	3	main
jooni	doc_919500587380_item	2940543	et	4	main
pankade	doc_919500587380_item	2940553	et	3	main
otsitava	doc_919500587380_item	2940568	et	4	main
informstsiooni	doc_919500587380_item	2940569	et	4	main
õhtulehes	doc_919500587380_item	2940575	et	3	main
mis	doc_919500587380_item	2940589	et	4	main
silmade	doc_919500587380_item	2940593	et	3	main
on	doc_919500587380_item	2940599	et	4	main
värvi	doc_919500587380_item	2940610	et	4	main
tiiteltäht	doc_919500587380_item	2940611	et	3	main
õhtuleht	doc_919500587380_item	2940622	et	3	main
mis	doc_919500587380_item	2940637	et	4	main
on	doc_919500587380_item	2940646	et	4	main
olulisi	doc_919500587380_item	2940647	et	4	main
kasutusel	doc_919500587380_item	2940654	et	4	main
esiletõstmisviisid	doc_919500587380_item	2940655	et	3	main
ning	doc_919500587380_item	2940664	et	3	main
abil	doc_919500587380_item	2940671	et	4	main
seda	doc_919500587380_item	2940672	et	3	main
mõlemates	doc_919500587380_item	2940675	et	3	main
hästi	doc_919500587380_item	2940680	et	3	main
suured	doc_919500587380_item	2940681	et	3	main
õhtulehel	doc_919500587380_item	2940683	et	3	main
need	doc_919500587380_item	2940685	et	3	main
meelest	doc_919500587380_item	2940701	et	4	main
mõnedel	doc_919500587380_item	2940703	et	3	main
pealkirjad	doc_919500587380_item	2940709	et	3	main
ruumi	doc_919500587380_item	2940716	et	4	main
all	doc_919500587380_item	2940721	et	3	main
et	doc_919500587380_item	2940726	et	3	main
on	doc_919500587380_item	2940728	et	4	main
palju	doc_919500587380_item	2940730	et	4	main
hoopis	doc_919500587380_item	2940737	et	3	main
leidnud	doc_919500587380_item	2940743	et	4	main
lood	doc_919500587380_item	2940752	et	4	main
suuri	doc_919500587380_item	2940754	et	3	main
lühikesed-	doc_919500587380_item	2940756	et	4	main
musta	doc_919500587380_item	2940764	et	4	main
värvi	doc_919500587380_item	2940771	et	4	main
selle	doc_919500587380_item	2940778	et	4	main
võin	doc_919500587380_item	2940823	et	3	main
et	doc_919500587380_item	2940826	et	3	main
son	doc_919500587380_item	2940847	et	4	main
ei	doc_919500587380_item	2940850	et	4	main
liiga	doc_919500587380_item	2940852	et	4	main
lai	doc_919500587380_item	2940853	et	3	main
ei	doc_919500587380_item	2940856	et	4	main
liiga	doc_919500587380_item	2940858	et	4	main
kirjaks	doc_919500587380_item	2940859	et	4	main
mõned	doc_919500587380_item	2940860	et	3	main
artiklid	doc_919500587380_item	2940861	et	3	main
silma	doc_919500587380_item	2940869	et	4	main
ning	doc_919500587380_item	2940870	et	3	main
lehtedel	doc_919500587380_item	2940896	et	4	main
ei	doc_919500587380_item	2940903	et	4	main
arvamus	doc_919500587380_item	2940924	et	3	main
ajalehe	doc_919500587380_item	2940926	et	3	main
muuta	doc_919500587380_item	2940941	et	4	main
see	doc_919500587380_item	2940944	et	3	main
et	doc_919500587380_item	2940946	et	3	main
peab	doc_919500587380_item	2940948	et	4	main
et	doc_919500587380_item	2940964	et	3	main
on	doc_919500587380_item	2940372	et	4	main
ajalehe	doc_919500587380_item	2940384	et	3	main
on	doc_919500587380_item	2940386	et	4	main
ajalehe	doc_919500587380_item	2940387	et	3	main
sisu	doc_919500587380_item	2940388	et	4	main
sisuga	doc_919500587380_item	2940394	et	3	main
vormi	doc_919500587380_item	2940396	et	4	main
näitab	doc_919500587380_item	2940398	et	3	main
meile	doc_919500587380_item	2940399	et	4	main
veerud	doc_919500587380_item	2940418	et	4	main
paraja	doc_919500587380_item	2940421	et	3	main
ja	doc_919500587380_item	2940423	et	3	main
võrrelda	doc_919500587380_item	2940426	et	4	main
õhtulehe	doc_919500587380_item	2940427	et	3	main
ja	doc_919500587380_item	2940428	et	3	main
äripäeva	doc_919500587380_item	2940429	et	4	main
omavahel	doc_919500587380_item	2940430	et	3	main
siis	doc_919500587380_item	2940431	et	3	main
võin	doc_919500587380_item	2940432	et	3	main
see	doc_919500587380_item	2940440	et	3	main
läbivalt	doc_919500587380_item	2940464	et	4	main
pandud	doc_919500587380_item	2940470	et	4	main
tüüpi	doc_919500587380_item	2940476	et	4	main
kujundusega	doc_919500587380_item	2940477	et	4	main
lehekülgi	doc_919500587380_item	2940478	et	4	main
nii	doc_919500587380_item	2940479	et	3	main
see	doc_919500587380_item	2940480	et	3	main
toimubki	doc_919500587380_item	2940481	et	3	main
mõlemates	doc_919500587380_item	2940482	et	3	main
ajalehtedes	doc_919500587380_item	2940483	et	4	main
nii	doc_919500587380_item	2940484	et	3	main
õhtulehes	doc_919500587380_item	2940485	et	3	main
kui	doc_919500587380_item	2940486	et	3	main
ka	doc_919500587380_item	2940487	et	3	main
äripäevas	doc_919500587380_item	2940488	et	3	main
kohad	doc_919500587380_item	2940521	et	4	main
saab	doc_919500587380_item	2940523	et	3	main
turism	doc_919500587380_item	2940527	et	3	main
börsiinfot	doc_919500587380_item	2940528	et	3	main
leida	doc_919500587380_item	2940530	et	3	main
õhtulehes	doc_919500587380_item	2940532	et	3	main
kasutatakse	doc_919500587380_item	2940537	et	3	main
tiiteltähti	doc_919500587380_item	2940539	et	4	main
kujunduse	doc_919500587380_item	2940548	et	4	main
nimed	doc_919500587380_item	2940554	et	3	main
näiteks	doc_919500587380_item	2940570	et	4	main
ka	doc_919500587380_item	2940577	et	3	main
tavaline	doc_919500587380_item	2940584	et	4	main
kasutusel	doc_919500587380_item	2940585	et	4	main
muutub	doc_919500587380_item	2940590	et	3	main
jaoks	doc_919500587380_item	2940594	et	4	main
ajal	doc_919500587380_item	2940596	et	4	main
peamiselt	doc_919500587380_item	2940597	et	4	main
teeb	doc_919500587380_item	2940380	et	3	main
uudise	doc_919500587380_item	2940381	et	3	main
huvitavamaks	doc_919500587380_item	2940382	et	4	main
korrastamine	doc_919500587380_item	2940389	et	4	main
kirja	doc_919500587380_item	2940402	et	4	main
lehekülgede	doc_919500587380_item	2940403	et	4	main
ülesehituse	doc_919500587380_item	2940404	et	3	main
värve	doc_919500587380_item	2940405	et	3	main
olema	doc_919500587380_item	2940409	et	4	main
ja	doc_919500587380_item	2940411	et	3	main
peaks	doc_919500587380_item	2940414	et	4	main
olema	doc_919500587380_item	2940420	et	4	main
pikkusega	doc_919500587380_item	2940424	et	4	main
kui	doc_919500587380_item	2940425	et	3	main
meeldi	doc_919500587380_item	2940439	et	4	main
standaartne	doc_919500587380_item	2940451	et	4	main
värv-	doc_919500587380_item	2940452	et	3	main
valgel	doc_919500587380_item	2940454	et	4	main
paberil	doc_919500587380_item	2940455	et	3	main
ühes	doc_919500587380_item	2940465	et	4	main
kirja-	doc_919500587380_item	2940471	et	4	main
ja	doc_919500587380_item	2940472	et	3	main
objektiivsed	doc_919500587380_item	2940490	et	3	main
ja	doc_919500587380_item	2940491	et	3	main
mõjutavad	doc_919500587380_item	2940492	et	4	main
paljusid	doc_919500587380_item	2940493	et	3	main
lugejaid	doc_919500587380_item	2940494	et	4	main
lood	doc_919500587380_item	2940495	et	4	main
nn	doc_919500587380_item	2940496	et	4	main
uudised	doc_919500587380_item	2940497	et	3	main
artiklid	doc_919500587380_item	2940498	et	3	main
ülevaated	doc_919500587380_item	2940499	et	3	main
majandusest	doc_919500587380_item	2940500	et	4	main
ja	doc_919500587380_item	2940501	et	3	main
poliitikast	doc_919500587380_item	2940502	et	4	main
igas	doc_919500587380_item	2940503	et	3	main
ajalehes	doc_919500587380_item	2940504	et	3	main
saab	doc_919500587380_item	2940505	et	3	main
ka	doc_919500587380_item	2940506	et	3	main
leida	doc_919500587380_item	2940507	et	3	main
teise	doc_919500587380_item	2940508	et	4	main
rühma	doc_919500587380_item	2940509	et	4	main
lood	doc_919500587380_item	2940510	et	4	main
nn	doc_919500587380_item	2940511	et	4	main
kultuur	doc_919500587380_item	2940512	et	3	main
mood	doc_919500587380_item	2940513	et	3	main
mida	doc_919500587380_item	2940514	et	4	main
saab	doc_919500587380_item	2940515	et	3	main
leida	doc_919500587380_item	2940516	et	3	main
õhtulehe	doc_919500587380_item	2940517	et	3	main
osakonnas	doc_919500587380_item	2940518	et	4	main
naine	doc_919500587380_item	2940519	et	3	main
huvitavad	doc_919500587380_item	2940520	et	4	main
leida	doc_919500587380_item	2940524	et	3	main
äripäevas	doc_919500587380_item	2940525	et	3	main
osakonnas	doc_919500587380_item	2940526	et	4	main
saab	doc_919500587380_item	2940529	et	3	main
äripäevas	doc_919500587380_item	2940531	et	3	main
aga	doc_919500587380_item	2940533	et	3	main
see	doc_919500587380_item	2940534	et	3	main
puudub	doc_919500587380_item	2940535	et	3	main
äripäevas	doc_919500587380_item	2940536	et	3	main
on	doc_919500587380_item	2940546	et	4	main
siis	doc_919500587380_item	2940547	et	3	main
ja	doc_919500587380_item	2940552	et	3	main
valitud	doc_919500587380_item	2940579	et	4	main
suurus	doc_919500587380_item	2940581	et	4	main
on	doc_919500587380_item	2940582	et	4	main
üsna	doc_919500587380_item	2940583	et	3	main
tähte	doc_919500587380_item	2940588	et	4	main
mugavamaks	doc_919500587380_item	2940592	et	4	main
lugemise	doc_919500587380_item	2940595	et	4	main
musta	doc_919500587380_item	2940600	et	4	main
värvi	doc_919500587380_item	2940601	et	4	main
vaid	doc_919500587380_item	2940602	et	3	main
mõned	doc_919500587380_item	2940603	et	3	main
fraasid	doc_919500587380_item	2940604	et	3	main
pealkirjad	doc_919500587380_item	2940605	et	3	main
ning	doc_919500587380_item	2940606	et	3	main
katkendid	doc_919500587380_item	2940607	et	3	main
on	doc_919500587380_item	2940608	et	4	main
teist	doc_919500587380_item	2940609	et	4	main
on	doc_919500587380_item	2940612	et	4	main
lõigu	doc_919500587380_item	2940613	et	4	main
esimene	doc_919500587380_item	2940614	et	3	main
täht	doc_919500587380_item	2940615	et	3	main
mis	doc_919500587380_item	2940616	et	4	main
on	doc_919500587380_item	2940617	et	4	main
laotud	doc_919500587380_item	2940618	et	4	main
suuremas	doc_919500587380_item	2940619	et	4	main
kirjas	doc_919500587380_item	2940620	et	4	main
nii	doc_919500587380_item	2940621	et	3	main
ka	doc_919500587380_item	2940624	et	3	main
ei	doc_919500587380_item	2940626	et	4	main
esimesed	doc_919500587380_item	2940632	et	3	main
on	doc_919500587380_item	2940634	et	4	main
tavalises	doc_919500587380_item	2940635	et	4	main
kirjas	doc_919500587380_item	2940636	et	4	main
halvemaks	doc_919500587380_item	2940641	et	4	main
ega	doc_919500587380_item	2940642	et	3	main
paemaks	doc_919500587380_item	2940643	et	3	main
igas	doc_919500587380_item	2940644	et	3	main
tekstis	doc_919500587380_item	2940645	et	3	main
pika	doc_919500587380_item	2940659	et	4	main
kapslisse	doc_919500587380_item	2940663	et	4	main
loo	doc_919500587380_item	2940665	et	4	main
rõhutamine	doc_919500587380_item	2940669	et	4	main
väljavõtete	doc_919500587380_item	2940670	et	3	main
näha	doc_919500587380_item	2940674	et	3	main
näiteks	doc_919500587380_item	2940679	et	4	main
pealkirjad	doc_919500587380_item	2940682	et	3	main
on	doc_919500587380_item	2940684	et	4	main
ka	doc_919500587380_item	2940692	et	3	main
õhtulehes	doc_919500587380_item	2940695	et	3	main
äripäeva	doc_919500587380_item	2940702	et	4	main
suureks	doc_919500587380_item	2940707	et	4	main
tühja	doc_919500587380_item	2940715	et	4	main
portree	doc_919500587380_item	2940719	et	4	main
tekib	doc_919500587380_item	2940723	et	3	main
liiga	doc_919500587380_item	2940729	et	4	main
tühja	doc_919500587380_item	2940731	et	4	main
ühesõnaga	doc_919500587380_item	2940739	et	3	main
õhtulehes	doc_919500587380_item	2940741	et	3	main
pikad	doc_919500587380_item	2940751	et	4	main
ajalehtedes	doc_919500587380_item	2940761	et	4	main
on	doc_919500587380_item	2940769	et	4	main
äripäevas	doc_919500587380_item	2940578	et	3	main
kirja	doc_919500587380_item	2940580	et	4	main
erinevaid	doc_919500587380_item	2940587	et	4	main
lood	doc_919500587380_item	2940598	et	4	main
kui	doc_919500587380_item	2940623	et	3	main
lõigude	doc_919500587380_item	2940631	et	4	main
tähed	doc_919500587380_item	2940633	et	3	main
muutu	doc_919500587380_item	2940639	et	4	main
ajalehte	doc_919500587380_item	2940640	et	4	main
esimeseks	doc_919500587380_item	2940656	et	3	main
paigutamine	doc_919500587380_item	2940662	et	4	main
sees	doc_919500587380_item	2940666	et	4	main
oleva	doc_919500587380_item	2940667	et	4	main
saab	doc_919500587380_item	2940673	et	3	main
ajalehtedes	doc_919500587380_item	2940676	et	4	main
äripäevas	doc_919500587380_item	2940677	et	3	main
suurem	doc_919500587380_item	2940691	et	4	main
see	doc_919500587380_item	2940697	et	3	main
on	doc_919500587380_item	2940705	et	4	main
liiga	doc_919500587380_item	2940706	et	4	main
alla	doc_919500587380_item	2940713	et	3	main
palju	doc_919500587380_item	2940714	et	4	main
vaatlus	doc_919500587380_item	2940718	et	3	main
mul	doc_919500587380_item	2940722	et	3	main
niisugune	doc_919500587380_item	2940724	et	3	main
sellepärast	doc_919500587380_item	2940733	et	3	main
mõned	doc_919500587380_item	2940734	et	3	main
pealkirjad	doc_919500587380_item	2940735	et	3	main
ma	doc_919500587380_item	2940744	et	3	main
sellist	doc_919500587380_item	2940745	et	4	main
enamus	doc_919500587380_item	2940747	et	4	main
pealkirjsdest	doc_919500587380_item	2940748	et	4	main
väiksemaid	doc_919500587380_item	2940757	et	4	main
pealkirju	doc_919500587380_item	2940758	et	4	main
pealkirjad	doc_919500587380_item	2940759	et	3	main
mõlemates	doc_919500587380_item	2940760	et	3	main
on	doc_919500587380_item	2940762	et	4	main
enamasti	doc_919500587380_item	2940763	et	4	main
äripäevas	doc_919500587380_item	2940766	et	3	main
pelakirjad	doc_919500587380_item	2940768	et	4	main
minu	doc_919500587380_item	2940773	et	3	main
üldse	doc_919500587380_item	2940775	et	3	main
ei	doc_919500587380_item	2940776	et	4	main
jaoks	doc_919500587380_item	2940781	et	4	main
siis	doc_919500587380_item	2940822	et	3	main
veerulaius	doc_919500587380_item	2940833	et	4	main
suurel	doc_919500587380_item	2940834	et	3	main
määral	doc_919500587380_item	2940835	et	3	main
ei	doc_919500587380_item	2940836	et	4	main
sama	doc_919500587380_item	2940844	et	4	main
mi	doc_919500587380_item	2940846	et	4	main
ei	doc_919500587380_item	2940871	et	4	main
halvemaks	doc_919500587380_item	2940874	et	4	main
veerud	doc_919500587380_item	2940881	et	4	main
nõuavad	doc_919500587380_item	2940882	et	4	main
on	doc_919500587380_item	2940897	et	4	main
mille	doc_919500587380_item	2940921	et	3	main
ja	doc_919500587380_item	2940930	et	3	main
lehe	doc_919500587380_item	2940932	et	3	main
esikülje	doc_919500587380_item	2940934	et	3	main
lehte	doc_919500587380_item	2940939	et	4	main
kui	doc_919500587380_item	2940957	et	3	main
äripäevaga	doc_919500587380_item	2940960	et	3	main
ütlen	doc_919500587380_item	2940962	et	3	main
äripäeva	doc_919500587380_item	2940965	et	4	main
on	doc_919500587380_item	2940967	et	4	main
või	doc_919500587380_item	2940970	et	4	main
õhtulehe	doc_919500587380_item	2940975	et	3	main
on	doc_919500587380_item	2940977	et	4	main
aga	doc_919500587380_item	2940978	et	3	main
erinevad	doc_919500587380_item	2940979	et	4	main
on	doc_919500587380_item	2940982	et	4	main
tavaliselt	doc_919500587380_item	2940991	et	4	main
õhtulehe	doc_919500587380_item	2941005	et	3	main
näha	doc_919500587380_item	2941008	et	3	main
sisukorda	doc_919500587380_item	2941009	et	4	main
lühikeste	doc_919500587380_item	2941010	et	4	main
jaoks	doc_919500587380_item	2941020	et	4	main
sellepärast	doc_919500587380_item	2941021	et	3	main
uudistest	doc_919500587380_item	2941030	et	4	main
õhtulehe	doc_919500587380_item	2941039	et	3	main
äripäev	doc_919500587380_item	2940625	et	3	main
tiiteltähte	doc_919500587380_item	2940628	et	4	main
oma	doc_919500587380_item	2940629	et	4	main
lugudes	doc_919500587380_item	2940630	et	3	main
vähemolulisi	doc_919500587380_item	2940649	et	4	main
osi	doc_919500587380_item	2940650	et	4	main
igas	doc_919500587380_item	2940651	et	3	main
ajalehes	doc_919500587380_item	2940652	et	3	main
on	doc_919500587380_item	2940653	et	4	main
on	doc_919500587380_item	2940657	et	4	main
ei	doc_919500587380_item	2940638	et	4	main
ja	doc_919500587380_item	2940648	et	3	main
loo	doc_919500587380_item	2940660	et	4	main
alguse	doc_919500587380_item	2940661	et	3	main
on	doc_919500587380_item	2940690	et	4	main
kiri	doc_919500587380_item	2940694	et	3	main
aga	doc_919500587380_item	2940698	et	3	main
paksem	doc_919500587380_item	2940699	et	4	main
läinud	doc_919500587380_item	2940708	et	4	main
luubi	doc_919500587380_item	2940720	et	3	main
äripäevas	doc_919500587380_item	2940727	et	3	main
on	doc_919500587380_item	2940749	et	4	main
ühesugused	doc_919500587380_item	2940750	et	3	main
kasutavad	doc_919500587380_item	2940753	et	4	main
pelakirju	doc_919500587380_item	2940755	et	4	main
meelest	doc_919500587380_item	2940774	et	4	main
kui	doc_919500587380_item	2940782	et	3	main
rääkida	doc_919500587380_item	2940783	et	3	main
keelekasutusest	doc_919500587380_item	2940784	et	4	main
siis	doc_919500587380_item	2940785	et	3	main
märkasin	doc_919500587380_item	2940786	et	3	main
peamiselt	doc_919500587380_item	2940838	et	4	main
ja	doc_919500587380_item	2940843	et	3	main
ole	doc_919500587380_item	2940851	et	4	main
ning	doc_919500587380_item	2940854	et	3	main
lähe	doc_919500587380_item	2940857	et	4	main
torka	doc_919500587380_item	2940868	et	4	main
muutu	doc_919500587380_item	2940872	et	4	main
ajalehtedes	doc_919500587380_item	2940876	et	4	main
leidub	doc_919500587380_item	2940877	et	3	main
pikemaid	doc_919500587380_item	2940878	et	4	main
veerge	doc_919500587380_item	2940879	et	3	main
liiga	doc_919500587380_item	2940898	et	4	main
pikaveerulised	doc_919500587380_item	2940899	et	4	main
on	doc_919500587380_item	2940923	et	4	main
esikülg	doc_919500587380_item	2940925	et	3	main
esikülg	doc_919500587380_item	2940927	et	3	main
ajalehe	doc_919500587380_item	2940929	et	3	main
ostma	doc_919500587380_item	2940940	et	3	main
ehk	doc_919500587380_item	2940955	et	3	main
võrrelda	doc_919500587380_item	2940958	et	4	main
õhtulehe	doc_919500587380_item	2940959	et	3	main
siis	doc_919500587380_item	2940961	et	3	main
seda	doc_919500587380_item	2940963	et	3	main
esilehtedel	doc_919500587380_item	2940976	et	4	main
või	doc_919500587380_item	2940987	et	4	main
juhtumiga	doc_919500587380_item	2940990	et	3	main
rohkem	doc_919500587380_item	2940994	et	4	main
saab	doc_919500587380_item	2941007	et	3	main
iga	doc_919500587380_item	2941023	et	4	main
saab	doc_919500587380_item	2941025	et	3	main
kiiret	doc_919500587380_item	2941027	et	4	main
ülevaadet	doc_919500587380_item	2941028	et	3	main
ning	doc_919500587380_item	2941031	et	3	main
kas	doc_919500587380_item	2941033	et	3	main
selle	doc_919500587380_item	2941035	et	4	main
numbri	doc_919500587380_item	2941054	et	3	main
reklaam	doc_919500587380_item	2941062	et	3	main
peavad	doc_919500587380_item	2941074	et	4	main
olema	doc_919500587380_item	2941075	et	4	main
on	doc_919500587380_item	2941121	et	4	main
paigutamine	doc_919500587380_item	2941134	et	4	main
kus	doc_919500587380_item	2941150	et	3	main
paigutatud	doc_919500587380_item	2941152	et	4	main
foto	doc_919500587380_item	2941156	et	4	main
ei	doc_919500587380_item	2941157	et	4	main
sellega	doc_919500587380_item	2941162	et	3	main
läbi	doc_919500587380_item	2941176	et	4	main
teistmoodi	doc_919500587380_item	2941182	et	3	main
uudis	doc_919500587380_item	2941184	et	3	main
kaksiklehekülje	doc_919500587380_item	2941221	et	3	main
parempoolse	doc_919500587380_item	2941226	et	3	main
äripäeva	doc_919500587380_item	2941238	et	4	main
on	doc_919500587380_item	2941241	et	4	main
reklaam	doc_919500587380_item	2941252	et	3	main
minu	doc_919500587380_item	2941253	et	3	main
tahab	doc_919500587380_item	2941255	et	3	main
näha	doc_919500587380_item	2941257	et	3	main
või	doc_919500587380_item	2941261	et	4	main
toimubki	doc_919500587380_item	2941276	et	3	main
leht	doc_919500587380_item	2941286	et	3	main
iga	doc_919500587380_item	2940658	et	4	main
info	doc_919500587380_item	2940668	et	4	main
on	doc_919500587380_item	2940678	et	4	main
paksemad	doc_919500587380_item	2940686	et	4	main
seoses	doc_919500587380_item	2940687	et	4	main
sellega	doc_919500587380_item	2940688	et	3	main
äripäevas	doc_919500587380_item	2940689	et	3	main
kapsli	doc_919500587380_item	2940693	et	3	main
on	doc_919500587380_item	2940696	et	4	main
minu	doc_919500587380_item	2940700	et	3	main
lehtedel	doc_919500587380_item	2940704	et	4	main
mis	doc_919500587380_item	2940710	et	4	main
võtavad	doc_919500587380_item	2940711	et	3	main
enda	doc_919500587380_item	2940712	et	4	main
osakonnad	doc_919500587380_item	2940717	et	4	main
tunne	doc_919500587380_item	2940725	et	4	main
ruumi	doc_919500587380_item	2940732	et	4	main
on	doc_919500587380_item	2940736	et	4	main
silmatorkavad	doc_919500587380_item	2940738	et	3	main
gigantsed	doc_919500587380_item	2940740	et	3	main
ei	doc_919500587380_item	2940742	et	4	main
probleemi	doc_919500587380_item	2940746	et	4	main
värvi	doc_919500587380_item	2940765	et	4	main
mõned	doc_919500587380_item	2940767	et	3	main
mis	doc_919500587380_item	2940772	et	4	main
heleroosa	doc_919500587380_item	2940779	et	4	main
paberi	doc_919500587380_item	2940780	et	3	main
ma	doc_919500587380_item	2940787	et	3	main
seda	doc_919500587380_item	2940788	et	3	main
et	doc_919500587380_item	2940789	et	3	main
äripäevas	doc_919500587380_item	2940790	et	3	main
pigem	doc_919500587380_item	2940792	et	3	main
asjalik	doc_919500587380_item	2940793	et	3	main
mitte	doc_919500587380_item	2940794	et	3	main
igapäevane	doc_919500587380_item	2940795	et	4	main
keel	doc_919500587380_item	2940796	et	4	main
õhtulehes	doc_919500587380_item	2940797	et	3	main
on	doc_919500587380_item	2940791	et	4	main
aga	doc_919500587380_item	2940798	et	3	main
vastupidi	doc_919500587380_item	2940799	et	3	main
ajalehtede	doc_919500587380_item	2940800	et	4	main
lugedes	doc_919500587380_item	2940801	et	3	main
ei	doc_919500587380_item	2940802	et	4	main
märganud	doc_919500587380_item	2940803	et	4	main
ma	doc_919500587380_item	2940804	et	3	main
ortograafia	doc_919500587380_item	2940805	et	4	main
vigu	doc_919500587380_item	2940806	et	3	main
ega	doc_919500587380_item	2940807	et	3	main
võõrsõõnu	doc_919500587380_item	2940808	et	3	main
kasutust	doc_919500587380_item	2940809	et	4	main
igas	doc_919500587380_item	2940810	et	3	main
ajalehes	doc_919500587380_item	2940811	et	3	main
on	doc_919500587380_item	2940812	et	4	main
üks	doc_919500587380_item	2940813	et	3	main
põhiline	doc_919500587380_item	2940814	et	3	main
veerulaius	doc_919500587380_item	2940815	et	4	main
kui	doc_919500587380_item	2940816	et	3	main
võrrelda	doc_919500587380_item	2940817	et	4	main
veerulaiust	doc_919500587380_item	2940818	et	4	main
äripäevas	doc_919500587380_item	2940819	et	3	main
ja	doc_919500587380_item	2940820	et	3	main
halli	doc_919500587380_item	2940770	et	4	main
sobi	doc_919500587380_item	2940777	et	4	main
õhtulehes	doc_919500587380_item	2940821	et	3	main
täpselt	doc_919500587380_item	2940824	et	4	main
nii	doc_919500587380_item	2940827	et	3	main
varieeri	doc_919500587380_item	2940837	et	4	main
kasutavad	doc_919500587380_item	2940841	et	4	main
selge	doc_919500587380_item	2940848	et	4	main
lehekülg	doc_919500587380_item	2940855	et	3	main
teisi	doc_919500587380_item	2940863	et	4	main
veerge	doc_919500587380_item	2940864	et	3	main
aga	doc_919500587380_item	2940865	et	3	main
see	doc_919500587380_item	2940866	et	3	main
ei	doc_919500587380_item	2940867	et	4	main
pikad	doc_919500587380_item	2940880	et	4	main
pilti	doc_919500587380_item	2940888	et	4	main
nii	doc_919500587380_item	2940889	et	3	main
see	doc_919500587380_item	2940890	et	3	main
ongi	doc_919500587380_item	2940891	et	4	main
õhtulehes	doc_919500587380_item	2940892	et	3	main
ja	doc_919500587380_item	2940893	et	3	main
äripäevas	doc_919500587380_item	2940894	et	3	main
mõnedel	doc_919500587380_item	2940895	et	3	main
lood	doc_919500587380_item	2940900	et	4	main
ning	doc_919500587380_item	2940901	et	3	main
peaaegu	doc_919500587380_item	2940902	et	3	main
nimeks	doc_919500587380_item	2940922	et	3	main
identifitseerib	doc_919500587380_item	2940928	et	3	main
teatab	doc_919500587380_item	2940931	et	3	main
sisu	doc_919500587380_item	2940933	et	4	main
ülesandeks	doc_919500587380_item	2940935	et	4	main
vaataja	doc_919500587380_item	2940942	et	4	main
tähendab	doc_919500587380_item	2940945	et	3	main
esiküljel	doc_919500587380_item	2940947	et	3	main
uudis	doc_919500587380_item	2940954	et	3	main
foto	doc_919500587380_item	2940956	et	4	main
enamasti	doc_919500587380_item	2940968	et	4	main
uudised	doc_919500587380_item	2940972	et	3	main
pildid	doc_919500587380_item	2940974	et	3	main
televisiooniga	doc_919500587380_item	2940986	et	4	main
tähtsama	doc_919500587380_item	2940989	et	4	main
äripäeva	doc_919500587380_item	2941001	et	4	main
esilehel	doc_919500587380_item	2941002	et	3	main
kui	doc_919500587380_item	2941003	et	3	main
ka	doc_919500587380_item	2941004	et	3	main
esilehel	doc_919500587380_item	2941006	et	3	main
arvates	doc_919500587380_item	2941013	et	4	main
on	doc_919500587380_item	2941014	et	4	main
lahutamatu	doc_919500587380_item	2941016	et	4	main
lugeja	doc_919500587380_item	2941024	et	4	main
teha	doc_919500587380_item	2941026	et	3	main
esileheküljel	doc_919500587380_item	2941040	et	3	main
rohkem	doc_919500587380_item	2941042	et	4	main
erinevaid	doc_919500587380_item	2941043	et	4	main
fotosid	doc_919500587380_item	2941044	et	3	main
reklaami	doc_919500587380_item	2941071	et	4	main
tähtsamad	doc_919500587380_item	2941076	et	4	main
huvitavamad	doc_919500587380_item	2941078	et	4	main
on	doc_919500587380_item	2941086	et	4	main
suures	doc_919500587380_item	2941088	et	3	main
tähtsaim	doc_919500587380_item	2941122	et	4	main
teises	doc_919500587380_item	2941126	et	4	main
10	doc_919500587380_item	2941129	et	2	main
ole	doc_919500587380_item	2941136	et	4	main
veel	doc_919500587380_item	2941144	et	4	main
mainida	doc_919500587380_item	2941145	et	3	main
ka	doc_919500587380_item	2941146	et	3	main
esilehel	doc_919500587380_item	2941149	et	3	main
ole	doc_919500587380_item	2941158	et	4	main
mingit	doc_919500587380_item	2941159	et	3	main
numeratsiooni	doc_919500587380_item	2941160	et	4	main
tähtsim	doc_919500587380_item	2941169	et	4	main
uudis	doc_919500587380_item	2941170	et	3	main
ja	doc_919500587380_item	2941171	et	3	main
langeb	doc_919500587380_item	2941223	et	3	main
esmalt	doc_919500587380_item	2941225	et	3	main
ja	doc_919500587380_item	2941229	et	3	main
sealt	doc_919500587380_item	2941231	et	4	main
keskele	doc_919500587380_item	2941234	et	3	main
kui	doc_919500587380_item	2941236	et	3	main
formaadis	doc_919500587380_item	2941249	et	3	main
öelda	doc_919500587380_item	2940825	et	4	main
ühes	doc_919500587380_item	2940828	et	4	main
kui	doc_919500587380_item	2940829	et	3	main
ka	doc_919500587380_item	2940830	et	3	main
teises	doc_919500587380_item	2940831	et	4	main
ajalehes	doc_919500587380_item	2940832	et	3	main
mõlemad	doc_919500587380_item	2940839	et	3	main
ajalehed	doc_919500587380_item	2940840	et	3	main
üht	doc_919500587380_item	2940842	et	3	main
veeerulaiust	doc_919500587380_item	2940845	et	4	main
äratuntav	doc_919500587380_item	2940849	et	4	main
kasutavad	doc_919500587380_item	2940862	et	4	main
ajalehe	doc_919500587380_item	2940873	et	3	main
mõlemates	doc_919500587380_item	2940875	et	3	main
omakorda	doc_919500587380_item	2940883	et	3	main
suurt	doc_919500587380_item	2940884	et	3	main
pealkirja	doc_919500587380_item	2940885	et	4	main
ja	doc_919500587380_item	2940886	et	3	main
suurt	doc_919500587380_item	2940887	et	3	main
ole	doc_919500587380_item	2940904	et	4	main
pilte	doc_919500587380_item	2940905	et	3	main
sellised	doc_919500587380_item	2940906	et	4	main
leheküljed	doc_919500587380_item	2940907	et	3	main
on	doc_919500587380_item	2940908	et	4	main
liiga	doc_919500587380_item	2940909	et	4	main
pikad	doc_919500587380_item	2940910	et	4	main
hallid	doc_919500587380_item	2940911	et	4	main
ning	doc_919500587380_item	2940912	et	3	main
rasked	doc_919500587380_item	2940913	et	3	main
lugeda	doc_919500587380_item	2940914	et	3	main
näidisena	doc_919500587380_item	2940915	et	3	main
võiks	doc_919500587380_item	2940916	et	4	main
tuua	doc_919500587380_item	2940917	et	3	main
õhtulehes	doc_919500587380_item	2940918	et	3	main
olevat	doc_919500587380_item	2940919	et	4	main
osakonda	doc_919500587380_item	2940920	et	4	main
on	doc_919500587380_item	2940936	et	4	main
meelitada	doc_919500587380_item	2940937	et	3	main
lugeja	doc_919500587380_item	2940938	et	4	main
lugejaks	doc_919500587380_item	2940943	et	4	main
mingi	doc_919500587380_item	2940950	et	4	main
olema	doc_919500587380_item	2940949	et	4	main
erakordne	doc_919500587380_item	2940951	et	3	main
ning	doc_919500587380_item	2940952	et	3	main
päevakajaline	doc_919500587380_item	2940953	et	4	main
esilehekülgedel	doc_919500587380_item	2940966	et	4	main
uudised	doc_919500587380_item	2940980	et	3	main
seotud	doc_919500587380_item	2940983	et	4	main
kasvõi	doc_919500587380_item	2940984	et	3	main
kultuuriga	doc_919500587380_item	2940985	et	4	main
on	doc_919500587380_item	2940992	et	4	main
pealkirjad	doc_919500587380_item	2940997	et	3	main
kui	doc_919500587380_item	2940998	et	3	main
sisekülgedel	doc_919500587380_item	2940999	et	4	main
nii	doc_919500587380_item	2941000	et	3	main
minu	doc_919500587380_item	2941012	et	3	main
et	doc_919500587380_item	2941022	et	3	main
poliitilised	doc_919500587380_item	2940969	et	3	main
majanduslikud	doc_919500587380_item	2940971	et	3	main
ja	doc_919500587380_item	2940973	et	3	main
mis	doc_919500587380_item	2940981	et	4	main
isegi	doc_919500587380_item	2940988	et	4	main
esilehel	doc_919500587380_item	2940993	et	3	main
fotosid	doc_919500587380_item	2940995	et	3	main
suuremad	doc_919500587380_item	2940996	et	4	main
resümeedega	doc_919500587380_item	2941011	et	3	main
see	doc_919500587380_item	2941015	et	3	main
osa	doc_919500587380_item	2941017	et	4	main
iga	doc_919500587380_item	2941018	et	4	main
ajalehe	doc_919500587380_item	2941019	et	3	main
tähtsamatest	doc_919500587380_item	2941029	et	4	main
või	doc_919500587380_item	2941037	et	4	main
mitte	doc_919500587380_item	2941038	et	3	main
on	doc_919500587380_item	2941041	et	4	main
mis	doc_919500587380_item	2941045	et	4	main
minu	doc_919500587380_item	2941046	et	3	main
ühe	doc_919500587380_item	2941052	et	4	main
esilehel	doc_919500587380_item	2941060	et	3	main
arvan	doc_919500587380_item	2941064	et	3	main
esilehel	doc_919500587380_item	2941073	et	3	main
ja	doc_919500587380_item	2941077	et	3	main
muudised	doc_919500587380_item	2941079	et	4	main
mida	doc_919500587380_item	2941080	et	4	main
sisaldab	doc_919500587380_item	2941081	et	3	main
ajaleht	doc_919500587380_item	2941082	et	3	main
mõlemate	doc_919500587380_item	2941083	et	3	main
ajalehtede	doc_919500587380_item	2941084	et	4	main
esilehel	doc_919500587380_item	2941085	et	3	main
kirjas	doc_919500587380_item	2941089	et	4	main
pealkiri	doc_919500587380_item	2941090	et	3	main
leheküljel	doc_919500587380_item	2941125	et	3	main
ei	doc_919500587380_item	2941135	et	4	main
lisaks	doc_919500587380_item	2941141	et	4	main
sellele	doc_919500587380_item	2941142	et	4	main
tahaks	doc_919500587380_item	2941143	et	3	main
on	doc_919500587380_item	2941151	et	4	main
tähtsaim	doc_919500587380_item	2941153	et	4	main
uudis	doc_919500587380_item	2941154	et	3	main
peab	doc_919500587380_item	2941172	et	4	main
sirvima	doc_919500587380_item	2941173	et	3	main
äripäevas	doc_919500587380_item	2941180	et	3	main
leheküljel	doc_919500587380_item	2941188	et	3	main
siis	doc_919500587380_item	2941239	et	3	main
reklaam	doc_919500587380_item	2941250	et	3	main
pilti	doc_919500587380_item	2941262	et	4	main
kohast	doc_919500587380_item	2941269	et	4	main
lugu	doc_919500587380_item	2941275	et	4	main
ühes	doc_919500587380_item	2941278	et	4	main
õhtulehe	doc_919500587380_item	2941279	et	3	main
numbris	doc_919500587380_item	2941280	et	3	main
kus	doc_919500587380_item	2941281	et	3	main
parempolne	doc_919500587380_item	2941282	et	4	main
leht	doc_919500587380_item	2941283	et	3	main
on	doc_919500587380_item	2941284	et	4	main
õhtulehe	doc_919500587380_item	2941288	et	3	main
on	doc_919500587380_item	2941290	et	4	main
mõnuainet	doc_919500587380_item	2941322	et	3	main
selle	doc_919500587380_item	2941324	et	4	main
uudisele	doc_919500587380_item	2941325	et	3	main
on	doc_919500587380_item	2941326	et	4	main
pildil	doc_919500587380_item	2941327	et	3	main
olnud	doc_919500587380_item	2941333	et	4	main
nende	doc_919500587380_item	2941334	et	4	main
seitsme	doc_919500587380_item	2941335	et	3	main
noormehe	doc_919500587380_item	2941336	et	3	main
murdejoon	doc_919500587380_item	2941362	et	3	main
fotol	doc_919500587380_item	2941365	et	3	main
on	doc_919500587380_item	2941367	et	4	main
et	doc_919500587380_item	2941370	et	3	main
on	doc_919500587380_item	2941373	et	4	main
pealkiri	doc_919500587380_item	2941377	et	3	main
mis	doc_919500587380_item	2941378	et	4	main
ei	doc_919500587380_item	2941379	et	4	main
ole	doc_919500587380_item	2941380	et	4	main
teine	doc_919500587380_item	2941389	et	3	main
mite	doc_919500587380_item	2941393	et	4	main
lihtsalt	doc_919500587380_item	2941394	et	4	main
dekoratsioon	doc_919500587380_item	2941395	et	3	main
äratavad	doc_919500587380_item	2941402	et	4	main
otsustada	doc_919500587380_item	2941032	et	3	main
osta	doc_919500587380_item	2941034	et	4	main
ajalehe	doc_919500587380_item	2941036	et	3	main
meelest	doc_919500587380_item	2941047	et	4	main
teeb	doc_919500587380_item	2941048	et	3	main
selle	doc_919500587380_item	2941049	et	4	main
ajalehe	doc_919500587380_item	2941050	et	3	main
huvitavamaks	doc_919500587380_item	2941051	et	4	main
23marts	doc_919500587380_item	2941055	et	4	main
on	doc_919500587380_item	2941057	et	4	main
see	doc_919500587380_item	2941058	et	3	main
ei	doc_919500587380_item	2941067	et	4	main
jaoks	doc_919500587380_item	2941072	et	4	main
väga	doc_919500587380_item	2941087	et	3	main
põhitekst	doc_919500587380_item	2941091	et	3	main
aga	doc_919500587380_item	2941092	et	3	main
puudub	doc_919500587380_item	2941093	et	3	main
tähtsaim	doc_919500587380_item	2941094	et	4	main
lugu	doc_919500587380_item	2941095	et	4	main
asub	doc_919500587380_item	2941096	et	3	main
tavaliselt	doc_919500587380_item	2941097	et	4	main
kolmandal	doc_919500587380_item	2941098	et	3	main
leheküljel	doc_919500587380_item	2941099	et	3	main
tavaliselt	doc_919500587380_item	2941100	et	4	main
on	doc_919500587380_item	2941101	et	4	main
ka	doc_919500587380_item	2941102	et	3	main
seal	doc_919500587380_item	2941103	et	4	main
teised	doc_919500587380_item	2941104	et	4	main
lood	doc_919500587380_item	2941105	et	4	main
mille	doc_919500587380_item	2941106	et	3	main
pealkirjad	doc_919500587380_item	2941107	et	3	main
on	doc_919500587380_item	2941108	et	4	main
esilehel	doc_919500587380_item	2941109	et	3	main
välja	doc_919500587380_item	2941110	et	4	main
toodud	doc_919500587380_item	2941111	et	4	main
õhtulehes	doc_919500587380_item	2941112	et	3	main
on	doc_919500587380_item	2941113	et	4	main
aga	doc_919500587380_item	2941114	et	3	main
see	doc_919500587380_item	2941115	et	3	main
asi	doc_919500587380_item	2941116	et	4	main
vastupidi	doc_919500587380_item	2941117	et	3	main
ühes	doc_919500587380_item	2941118	et	4	main
õhtulehe	doc_919500587380_item	2941119	et	3	main
numbris	doc_919500587380_item	2941120	et	3	main
4	doc_919500587380_item	2941124	et	2	main
isegi	doc_919500587380_item	2941128	et	4	main
lehel	doc_919500587380_item	2941130	et	3	main
minu	doc_919500587380_item	2941131	et	3	main
meelest	doc_919500587380_item	2941132	et	4	main
selline	doc_919500587380_item	2941133	et	4	main
seda	doc_919500587380_item	2941147	et	3	main
seoses	doc_919500587380_item	2941161	et	4	main
õhtulehe	doc_919500587380_item	2941053	et	3	main
puuduseks	doc_919500587380_item	2941056	et	4	main
et	doc_919500587380_item	2941059	et	3	main
on	doc_919500587380_item	2941061	et	4	main
ma	doc_919500587380_item	2941063	et	3	main
et	doc_919500587380_item	2941065	et	3	main
esileht	doc_919500587380_item	2941066	et	3	main
ole	doc_919500587380_item	2941068	et	4	main
õige	doc_919500587380_item	2941069	et	4	main
koht	doc_919500587380_item	2941070	et	3	main
uudis	doc_919500587380_item	2941123	et	3	main
aga	doc_919500587380_item	2941127	et	3	main
eriti	doc_919500587380_item	2941137	et	3	main
korrektne	doc_919500587380_item	2941138	et	3	main
lugejte	doc_919500587380_item	2941139	et	4	main
jaoks	doc_919500587380_item	2941140	et	4	main
et	doc_919500587380_item	2941148	et	3	main
ja	doc_919500587380_item	2941155	et	3	main
tea	doc_919500587380_item	2941164	et	4	main
lugeja	doc_919500587380_item	2941165	et	4	main
mis	doc_919500587380_item	2941166	et	4	main
leheküljel	doc_919500587380_item	2941167	et	3	main
asub	doc_919500587380_item	2941168	et	3	main
uudise	doc_919500587380_item	2941178	et	3	main
neljandal	doc_919500587380_item	2941187	et	3	main
ning	doc_919500587380_item	2941189	et	3	main
on	doc_919500587380_item	2941191	et	4	main
näha	doc_919500587380_item	2941193	et	3	main
esilehel	doc_919500587380_item	2941194	et	3	main
on	doc_919500587380_item	2941195	et	4	main
numerastioon	doc_919500587380_item	2941196	et	4	main
mille	doc_919500587380_item	2941197	et	3	main
järgi	doc_919500587380_item	2941198	et	4	main
saab	doc_919500587380_item	2941199	et	3	main
vaadata	doc_919500587380_item	2941200	et	4	main
mis	doc_919500587380_item	2941201	et	4	main
lehel	doc_919500587380_item	2941202	et	3	main
asub	doc_919500587380_item	2941203	et	3	main
üks	doc_919500587380_item	2941204	et	3	main
või	doc_919500587380_item	2941205	et	4	main
teine	doc_919500587380_item	2941206	et	3	main
uudis	doc_919500587380_item	2941207	et	3	main
kaksikleheküljed	doc_919500587380_item	2941208	et	3	main
avatud	doc_919500587380_item	2941209	et	4	main
ajalehes	doc_919500587380_item	2941210	et	3	main
kõrvuti	doc_919500587380_item	2941211	et	3	main
asuvad	doc_919500587380_item	2941212	et	4	main
leheküljed	doc_919500587380_item	2941213	et	3	main
on	doc_919500587380_item	2941214	et	4	main
nimetatud	doc_919500587380_item	2941215	et	4	main
kaksikleheküljeks	doc_919500587380_item	2941216	et	3	main
ma	doc_919500587380_item	2941217	et	3	main
tean	doc_919500587380_item	2941218	et	3	main
et	doc_919500587380_item	2941219	et	3	main
tavaliselt	doc_919500587380_item	2941220	et	4	main
keskle	doc_919500587380_item	2941227	et	4	main
elemendile	doc_919500587380_item	2941228	et	3	main
on	doc_919500587380_item	2941247	et	4	main
suures	doc_919500587380_item	2941248	et	3	main
reklaami	doc_919500587380_item	2941264	et	4	main
mida	doc_919500587380_item	2941265	et	4	main
saab	doc_919500587380_item	2941266	et	3	main
igast	doc_919500587380_item	2941268	et	3	main
raadio	doc_919500587380_item	2941271	et	4	main
ei	doc_919500587380_item	2941163	et	4	main
kogu	doc_919500587380_item	2941174	et	4	main
ajelehe	doc_919500587380_item	2941175	et	4	main
selle	doc_919500587380_item	2941177	et	4	main
ostmiseks	doc_919500587380_item	2941179	et	4	main
on	doc_919500587380_item	2941181	et	4	main
tähtsaim	doc_919500587380_item	2941183	et	4	main
on	doc_919500587380_item	2941185	et	4	main
tavaliselt	doc_919500587380_item	2941186	et	4	main
esilehel	doc_919500587380_item	2941190	et	3	main
seda	doc_919500587380_item	2941192	et	3	main
vaadates	doc_919500587380_item	2941222	et	3	main
pilk	doc_919500587380_item	2941224	et	3	main
liigub	doc_919500587380_item	2941230	et	3	main
vasskpoolse	doc_919500587380_item	2941232	et	4	main
lehekülje	doc_919500587380_item	2941233	et	3	main
elemendile	doc_919500587380_item	2941235	et	3	main
vaadata	doc_919500587380_item	2941237	et	4	main
siin	doc_919500587380_item	2941240	et	4	main
selline	doc_919500587380_item	2941242	et	4	main
asi	doc_919500587380_item	2941243	et	4	main
et	doc_919500587380_item	2941244	et	3	main
parempoolsel	doc_919500587380_item	2941245	et	3	main
lehel	doc_919500587380_item	2941246	et	3	main
auto	doc_919500587380_item	2941251	et	4	main
meelest	doc_919500587380_item	2941254	et	4	main
lugeja	doc_919500587380_item	2941256	et	4	main
mingit	doc_919500587380_item	2941258	et	3	main
mitte	doc_919500587380_item	2941263	et	3	main
sama	doc_919500587380_item	2941274	et	4	main
reklaami	doc_919500587380_item	2941285	et	4	main
teises	doc_919500587380_item	2941287	et	4	main
numbris	doc_919500587380_item	2941289	et	3	main
kujutatud	doc_919500587380_item	2941292	et	4	main
suures	doc_919500587380_item	2941293	et	3	main
formaadis	doc_919500587380_item	2941294	et	3	main
foto	doc_919500587380_item	2941295	et	4	main
mis	doc_919500587380_item	2941296	et	4	main
kuulub	doc_919500587380_item	2941297	et	3	main
parempoolsel	doc_919500587380_item	2941298	et	3	main
lehel	doc_919500587380_item	2941299	et	3	main
kirjutatud	doc_919500587380_item	2941300	et	4	main
uudisele	doc_919500587380_item	2941301	et	3	main
puuduseks	doc_919500587380_item	2941302	et	4	main
on	doc_919500587380_item	2941303	et	4	main
see	doc_919500587380_item	2941304	et	3	main
et	doc_919500587380_item	2941305	et	3	main
uudis	doc_919500587380_item	2941306	et	3	main
on	doc_919500587380_item	2941307	et	4	main
politseireidist	doc_919500587380_item	2941308	et	3	main
mis	doc_919500587380_item	2941309	et	4	main
toimus	doc_919500587380_item	2941310	et	3	main
luua	doc_919500587380_item	2941311	et	4	main
metsakoolis	doc_919500587380_item	2941312	et	4	main
reidi	doc_919500587380_item	2941313	et	4	main
tuvastas	doc_919500587380_item	2941315	et	3	main
politsei	doc_919500587380_item	2941316	et	4	main
et	doc_919500587380_item	2941317	et	3	main
seitse	doc_919500587380_item	2941318	et	3	main
tulemusena	doc_919500587380_item	2941314	et	3	main
õpolast	doc_919500587380_item	2941319	et	4	main
olid	doc_919500587380_item	2941320	et	4	main
huvitavat	doc_919500587380_item	2941259	et	4	main
uudist	doc_919500587380_item	2941260	et	3	main
leida	doc_919500587380_item	2941267	et	3	main
televisioon	doc_919500587380_item	2941270	et	4	main
jne	doc_919500587380_item	2941273	et	4	main
aga	doc_919500587380_item	2941291	et	3	main
kujutatud	doc_919500587380_item	2941328	et	4	main
kes	doc_919500587380_item	2941331	et	4	main
milleks	doc_919500587380_item	2941341	et	4	main
on	doc_919500587380_item	2941342	et	4	main
siis	doc_919500587380_item	2941343	et	3	main
see	doc_919500587380_item	2941344	et	3	main
polt	doc_919500587380_item	2941345	et	3	main
ei	doc_919500587380_item	2941360	et	4	main
see	doc_919500587380_item	2941369	et	3	main
õhtulehes	doc_919500587380_item	2941372	et	3	main
kasutusel	doc_919500587380_item	2941374	et	4	main
keskelt	doc_919500587380_item	2941375	et	3	main
katkev	doc_919500587380_item	2941376	et	4	main
ajal	doc_919500587380_item	2941383	et	4	main
kõrval	doc_919500587380_item	2941388	et	4	main
informatsiooni	doc_919500587380_item	2941391	et	4	main
mõlemates	doc_919500587380_item	2941396	et	3	main
ajalehtedes	doc_919500587380_item	2941397	et	4	main
huvi	doc_919500587380_item	2941403	et	4	main
suur	doc_919500587380_item	2941422	et	3	main
või	doc_919500587380_item	2941428	et	4	main
isegi	doc_919500587380_item	2941429	et	4	main
lugu	doc_919500587380_item	2941435	et	4	main
peaaegu	doc_919500587380_item	2941436	et	3	main
igal	doc_919500587380_item	2941437	et	3	main
suuremat	doc_919500587380_item	2941441	et	4	main
dokumentaalfotod	doc_919500587380_item	2941450	et	3	main
4	doc_919500587380_item	2941460	et	2	main
rohkem	doc_919500587380_item	2941469	et	4	main
paljudel	doc_919500587380_item	2941471	et	3	main
kellest	doc_919500587380_item	2941478	et	4	main
kirjutatud	doc_919500587380_item	2941480	et	4	main
uudis	doc_919500587380_item	2941481	et	3	main
reportaaz	doc_919500587380_item	2941482	et	4	main
märkasin	doc_919500587380_item	2941487	et	3	main
tuua	doc_919500587380_item	2941492	et	3	main
olevat	doc_919500587380_item	2941495	et	4	main
kus	doc_919500587380_item	2941497	et	3	main
järgmise	doc_919500587380_item	2941502	et	3	main
võiks	doc_919500587380_item	2941504	et	4	main
tuua	doc_919500587380_item	2941505	et	3	main
ka	doc_919500587380_item	2941506	et	3	main
selles	doc_919500587380_item	2941507	et	4	main
välismaa	doc_919500587380_item	2941509	et	4	main
asuvat	doc_919500587380_item	2941511	et	4	main
ohvriterohke	doc_919500587380_item	2941519	et	4	main
on	doc_919500587380_item	2941532	et	4	main
narva	doc_919500587380_item	2941534	et	4	main
tavaliselt	doc_919500587380_item	2941537	et	4	main
dünaamilisteks	doc_919500587380_item	2941540	et	3	main
emotsionaalseteks	doc_919500587380_item	2941543	et	3	main
spordi	doc_919500587380_item	2941547	et	4	main
tehtud	doc_919500587380_item	2941551	et	4	main
spontaansed	doc_919500587380_item	2941557	et	3	main
tähelepanu	doc_919500587380_item	2941566	et	4	main
mingi	doc_919500587380_item	2941567	et	4	main
lõbusa	doc_919500587380_item	2941568	et	3	main
või	doc_919500587380_item	2941569	et	4	main
saada	doc_919500587380_item	2941577	et	4	main
9	doc_919500587380_item	2941586	et	2	main
tänav	doc_919500587380_item	2941272	et	4	main
ka	doc_919500587380_item	2941277	et	3	main
kasutanud	doc_919500587380_item	2941321	et	4	main
vastavalt	doc_919500587380_item	2941323	et	4	main
noormeest	doc_919500587380_item	2941330	et	4	main
sellise	doc_919500587380_item	2941339	et	4	main
kui	doc_919500587380_item	2941347	et	3	main
lõhu	doc_919500587380_item	2941361	et	4	main
mugav	doc_919500587380_item	2941381	et	3	main
lugemise	doc_919500587380_item	2941382	et	4	main
foto	doc_919500587380_item	2941385	et	4	main
viis	doc_919500587380_item	2941390	et	4	main
on	doc_919500587380_item	2941398	et	4	main
kasutusel	doc_919500587380_item	2941399	et	4	main
fotod	doc_919500587380_item	2941400	et	3	main
näha	doc_919500587380_item	2941440	et	3	main
nii	doc_919500587380_item	2941443	et	3	main
leida	doc_919500587380_item	2941449	et	3	main
3	doc_919500587380_item	2941458	et	2	main
võrrelda	doc_919500587380_item	2941463	et	4	main
leheküljedel	doc_919500587380_item	2941472	et	4	main
on	doc_919500587380_item	2941473	et	4	main
jne	doc_919500587380_item	2941484	et	4	main
õhtulehe	doc_919500587380_item	2941485	et	3	main
sirvides	doc_919500587380_item	2941486	et	3	main
on	doc_919500587380_item	2941498	et	4	main
kijutatud	doc_919500587380_item	2941499	et	4	main
autoavarii	doc_919500587380_item	2941501	et	4	main
numbris	doc_919500587380_item	2941508	et	3	main
new	doc_919500587380_item	2941521	et	4	main
üks	doc_919500587380_item	2941523	et	3	main
suur	doc_919500587380_item	2941525	et	3	main
osakonnas	doc_919500587380_item	2941530	et	4	main
spordifotod	doc_919500587380_item	2941539	et	3	main
pildid	doc_919500587380_item	2941553	et	3	main
aru	doc_919500587380_item	2941576	et	4	main
või	doc_919500587380_item	2941582	et	4	main
mitte	doc_919500587380_item	2941583	et	3	main
nagu	doc_919500587380_item	2941584	et	3	main
õhtulehes	doc_919500587380_item	2941585	et	3	main
huvitavaid	doc_919500587380_item	2941626	et	4	main
on	doc_919500587380_item	2941641	et	4	main
ka	doc_919500587380_item	2941645	et	3	main
vertikaalsed	doc_919500587380_item	2941646	et	3	main
olemas	doc_919500587380_item	2941648	et	4	main
olevad	doc_919500587380_item	2941654	et	4	main
fotod	doc_919500587380_item	2941656	et	3	main
tavaliselt	doc_919500587380_item	2941658	et	4	main
vertikaalses	doc_919500587380_item	2941659	et	3	main
formaadis	doc_919500587380_item	2941660	et	3	main
mitte	doc_919500587380_item	2941662	et	3	main
6	doc_919500587380_item	2941697	et	2	main
olev	doc_919500587380_item	2941708	et	4	main
pilt	doc_919500587380_item	2941709	et	3	main
visuaalselt	doc_919500587380_item	2941716	et	4	main
lõigatud	doc_919500587380_item	2941722	et	4	main
ma	doc_919500587380_item	2941726	et	3	main
märkasin	doc_919500587380_item	2941727	et	3	main
ainult	doc_919500587380_item	2941728	et	4	main
õhtulehe	doc_919500587380_item	2941733	et	3	main
12-13	doc_919500587380_item	2941736	et	2	main
asuvad	doc_919500587380_item	2941738	et	4	main
tavaliselt	doc_919500587380_item	2941742	et	4	main
olema	doc_919500587380_item	2941754	et	4	main
olema	doc_919500587380_item	2941760	et	4	main
märkasin	doc_919500587380_item	2941766	et	3	main
mis	doc_919500587380_item	2941770	et	4	main
ilma	doc_919500587380_item	2941772	et	4	main
allkirjata	doc_919500587380_item	2941773	et	3	main
näidisena	doc_919500587380_item	2941774	et	3	main
võin	doc_919500587380_item	2941775	et	3	main
allkirjata	doc_919500587380_item	2941794	et	3	main
kohe	doc_919500587380_item	2941798	et	4	main
sellest	doc_919500587380_item	2941799	et	4	main
uudisele	doc_919500587380_item	2941804	et	3	main
kuulub	doc_919500587380_item	2941805	et	3	main
see	doc_919500587380_item	2941806	et	3	main
kas	doc_919500587380_item	2941809	et	3	main
veel	doc_919500587380_item	2941819	et	4	main
pöördama	doc_919500587380_item	2941828	et	4	main
pilt	doc_919500587380_item	2941833	et	3	main
7	doc_919500587380_item	2941329	et	2	main
ei	doc_919500587380_item	2941332	et	4	main
seast	doc_919500587380_item	2941337	et	4	main
just	doc_919500587380_item	2941338	et	3	main
trükkitud	doc_919500587380_item	2941346	et	4	main
ei	doc_919500587380_item	2941350	et	4	main
sisule	doc_919500587380_item	2941353	et	3	main
üldiselt	doc_919500587380_item	2941354	et	4	main
nii	doc_919500587380_item	2941355	et	3	main
äripäevas	doc_919500587380_item	2941356	et	3	main
kui	doc_919500587380_item	2941357	et	3	main
ka	doc_919500587380_item	2941358	et	3	main
õhtulehes	doc_919500587380_item	2941359	et	3	main
olulist	doc_919500587380_item	2941363	et	4	main
puuduseks	doc_919500587380_item	2941366	et	4	main
ka	doc_919500587380_item	2941368	et	3	main
on	doc_919500587380_item	2941386	et	4	main
sunnivad	doc_919500587380_item	2941404	et	3	main
lugejad	doc_919500587380_item	2941405	et	4	main
peatuma	doc_919500587380_item	2941406	et	4	main
täiendavad	doc_919500587380_item	2941407	et	4	main
teksti	doc_919500587380_item	2941408	et	4	main
äripäeva	doc_919500587380_item	2941409	et	4	main
vaadates	doc_919500587380_item	2941410	et	3	main
märkasin	doc_919500587380_item	2941411	et	3	main
ma	doc_919500587380_item	2941412	et	3	main
seda	doc_919500587380_item	2941413	et	3	main
et	doc_919500587380_item	2941414	et	3	main
selles	doc_919500587380_item	2941415	et	4	main
ajalehes	doc_919500587380_item	2941416	et	3	main
on	doc_919500587380_item	2941417	et	4	main
piisavalt	doc_919500587380_item	2941418	et	4	main
palju	doc_919500587380_item	2941419	et	4	main
suuri	doc_919500587380_item	2941420	et	3	main
fotoallkirjaga	doc_919500587380_item	2941340	et	3	main
see	doc_919500587380_item	2941348	et	3	main
isegi	doc_919500587380_item	2941349	et	4	main
vasta	doc_919500587380_item	2941351	et	4	main
uudise	doc_919500587380_item	2941352	et	3	main
detaili	doc_919500587380_item	2941364	et	4	main
ühes	doc_919500587380_item	2941371	et	4	main
foto	doc_919500587380_item	2941384	et	4	main
teksti	doc_919500587380_item	2941387	et	4	main
vahendada	doc_919500587380_item	2941392	et	3	main
mis	doc_919500587380_item	2941401	et	4	main
fotosid	doc_919500587380_item	2941421	et	3	main
on	doc_919500587380_item	2941424	et	4	main
kolme	doc_919500587380_item	2941430	et	4	main
leheküljel	doc_919500587380_item	2941438	et	3	main
saab	doc_919500587380_item	2941448	et	3	main
ajalehte	doc_919500587380_item	2941465	et	4	main
on	doc_919500587380_item	2941468	et	4	main
mingi	doc_919500587380_item	2941475	et	4	main
kindel	doc_919500587380_item	2941476	et	3	main
isik	doc_919500587380_item	2941477	et	3	main
sündmusfotod	doc_919500587380_item	2941489	et	3	main
sokeeriv	doc_919500587380_item	2941500	et	4	main
näidisena	doc_919500587380_item	2941503	et	3	main
pildistatud	doc_919500587380_item	2941533	et	4	main
trans	doc_919500587380_item	2941535	et	4	main
jalgpallimeeskond	doc_919500587380_item	2941536	et	3	main
peetakse	doc_919500587380_item	2941538	et	3	main
ning	doc_919500587380_item	2941542	et	3	main
mõlemates	doc_919500587380_item	2941545	et	3	main
osakonnas	doc_919500587380_item	2941548	et	4	main
on	doc_919500587380_item	2941549	et	4	main
kenasti	doc_919500587380_item	2941550	et	3	main
ei	doc_919500587380_item	2941555	et	4	main
sportlaste	doc_919500587380_item	2941558	et	4	main
on	doc_919500587380_item	2941560	et	4	main
ei	doc_919500587380_item	2941563	et	4	main
pööra	doc_919500587380_item	2941564	et	4	main
eriti	doc_919500587380_item	2941565	et	3	main
ebatavalise	doc_919500587380_item	2941570	et	4	main
lavastatud	doc_919500587380_item	2941581	et	4	main
on	doc_919500587380_item	2941618	et	4	main
äripäevas	doc_919500587380_item	2941619	et	3	main
fotod	doc_919500587380_item	2941623	et	3	main
nii	doc_919500587380_item	2941642	et	3	main
fotod	doc_919500587380_item	2941647	et	3	main
suured	doc_919500587380_item	2941655	et	3	main
kõik	doc_919500587380_item	2941663	et	4	main
peetakse	doc_919500587380_item	2941667	et	3	main
ajalehtedes	doc_919500587380_item	2941673	et	4	main
on	doc_919500587380_item	2941674	et	4	main
rohkesti	doc_919500587380_item	2941675	et	3	main
nii	doc_919500587380_item	2941676	et	3	main
vertikaalseid	doc_919500587380_item	2941677	et	3	main
kui	doc_919500587380_item	2941678	et	3	main
ka	doc_919500587380_item	2941679	et	3	main
on	doc_919500587380_item	2941683	et	4	main
nelinurksed	doc_919500587380_item	2941685	et	3	main
pilte	doc_919500587380_item	2941693	et	3	main
numbris	doc_919500587380_item	2941696	et	3	main
asuv	doc_919500587380_item	2941701	et	4	main
32	doc_919500587380_item	2941703	et	2	main
leheküljel	doc_919500587380_item	2941704	et	3	main
spordi	doc_919500587380_item	2941705	et	4	main
kahte	doc_919500587380_item	2941427	et	4	main
on	doc_919500587380_item	2941433	et	4	main
sama	doc_919500587380_item	2941434	et	4	main
fotosid	doc_919500587380_item	2941442	et	3	main
äripäevas	doc_919500587380_item	2941444	et	3	main
ka	doc_919500587380_item	2941446	et	3	main
jaotada	doc_919500587380_item	2941453	et	3	main
1	doc_919500587380_item	2941454	et	2	main
sündmusfotodeks	doc_919500587380_item	2941455	et	3	main
saab	doc_919500587380_item	2941452	et	3	main
2	doc_919500587380_item	2941456	et	2	main
objektfotodeks	doc_919500587380_item	2941457	et	4	main
foto	doc_919500587380_item	2941423	et	4	main
tavaliselt	doc_919500587380_item	2941425	et	4	main
väärt	doc_919500587380_item	2941426	et	4	main
väiksemat	doc_919500587380_item	2941431	et	4	main
õhtulehes	doc_919500587380_item	2941432	et	3	main
saab	doc_919500587380_item	2941439	et	3	main
kui	doc_919500587380_item	2941445	et	3	main
õhtulehes	doc_919500587380_item	2941447	et	3	main
mida	doc_919500587380_item	2941451	et	4	main
portreefotosid	doc_919500587380_item	2941470	et	3	main
intervjuu	doc_919500587380_item	2941483	et	4	main
näidisena	doc_919500587380_item	2941490	et	3	main
võin	doc_919500587380_item	2941491	et	3	main
leheküljel	doc_919500587380_item	2941494	et	3	main
foto	doc_919500587380_item	2941496	et	4	main
toimunud	doc_919500587380_item	2941518	et	4	main
portreefotodeks	doc_919500587380_item	2941459	et	3	main
grupifotodeks	doc_919500587380_item	2941461	et	3	main
kui	doc_919500587380_item	2941462	et	3	main
neid	doc_919500587380_item	2941464	et	4	main
siis	doc_919500587380_item	2941466	et	3	main
äripäevas	doc_919500587380_item	2941467	et	3	main
kujutatud	doc_919500587380_item	2941474	et	4	main
on	doc_919500587380_item	2941479	et	4	main
ma	doc_919500587380_item	2941488	et	3	main
4	doc_919500587380_item	2941493	et	2	main
osakonnas	doc_919500587380_item	2941510	et	4	main
pilti	doc_919500587380_item	2941512	et	4	main
mis	doc_919500587380_item	2941513	et	4	main
kirjeldab	doc_919500587380_item	2941514	et	3	main
11	doc_919500587380_item	2941515	et	2	main
septembril	doc_919500587380_item	2941516	et	3	main
2001	doc_919500587380_item	2941517	et	2	main
terrorirünnaku	doc_919500587380_item	2941520	et	3	main
spordi	doc_919500587380_item	2941529	et	4	main
õhtulehe	doc_919500587380_item	2941544	et	3	main
tavalised	doc_919500587380_item	2941552	et	4	main
fotod	doc_919500587380_item	2941554	et	3	main
ning	doc_919500587380_item	2941562	et	3	main
näoilmele	doc_919500587380_item	2941571	et	4	main
on	doc_919500587380_item	2941573	et	4	main
kas	doc_919500587380_item	2941578	et	3	main
need	doc_919500587380_item	2941622	et	3	main
kohti	doc_919500587380_item	2941629	et	4	main
on	doc_919500587380_item	2941631	et	4	main
ma	doc_919500587380_item	2941649	et	3	main
et	doc_919500587380_item	2941652	et	3	main
vertikaalsed	doc_919500587380_item	2941665	et	3	main
dramaatilisemaks	doc_919500587380_item	2941668	et	4	main
ümmarguseks	doc_919500587380_item	2941691	et	3	main
õhtulehe	doc_919500587380_item	2941695	et	3	main
peaaegu	doc_919500587380_item	2941710	et	3	main
enamasti	doc_919500587380_item	2941724	et	4	main
must-	doc_919500587380_item	2941730	et	4	main
valget	doc_919500587380_item	2941731	et	3	main
ja	doc_919500587380_item	2941735	et	3	main
lehekülgedel	doc_919500587380_item	2941737	et	4	main
fotod	doc_919500587380_item	2941739	et	3	main
fotost	doc_919500587380_item	2941740	et	3	main
võib	doc_919500587380_item	2941741	et	3	main
saada	doc_919500587380_item	2941744	et	4	main
info	doc_919500587380_item	2941750	et	4	main
pildil	doc_919500587380_item	2941758	et	3	main
portreefotol	doc_919500587380_item	2941763	et	3	main
ma	doc_919500587380_item	2941767	et	3	main
3	doc_919500587380_item	2941778	et	2	main
asuva	doc_919500587380_item	2941781	et	4	main
artikli	doc_919500587380_item	2941788	et	3	main
vahel	doc_919500587380_item	2941789	et	4	main
ning	doc_919500587380_item	2941790	et	3	main
lugeja	doc_919500587380_item	2941795	et	4	main
sa	doc_919500587380_item	2941797	et	3	main
ja	doc_919500587380_item	2941808	et	3	main
seda	doc_919500587380_item	2941814	et	3	main
saab	doc_919500587380_item	2941817	et	3	main
yorgis	doc_919500587380_item	2941522	et	4	main
hästi	doc_919500587380_item	2941524	et	3	main
grupifoto	doc_919500587380_item	2941526	et	4	main
on	doc_919500587380_item	2941527	et	4	main
õhtulehe	doc_919500587380_item	2941528	et	3	main
kus	doc_919500587380_item	2941531	et	3	main
dramaatilisteks	doc_919500587380_item	2941541	et	3	main
numbrites	doc_919500587380_item	2941546	et	3	main
ole	doc_919500587380_item	2941556	et	4	main
näod	doc_919500587380_item	2941559	et	3	main
ilusad	doc_919500587380_item	2941561	et	3	main
mõnikord	doc_919500587380_item	2941572	et	3	main
küllaltki	doc_919500587380_item	2941574	et	4	main
raske	doc_919500587380_item	2941575	et	4	main
foto	doc_919500587380_item	2941579	et	4	main
on	doc_919500587380_item	2941580	et	4	main
leheküljel	doc_919500587380_item	2941587	et	3	main
välismaa	doc_919500587380_item	2941588	et	4	main
osakonnas	doc_919500587380_item	2941589	et	4	main
igas	doc_919500587380_item	2941590	et	3	main
ajalehes	doc_919500587380_item	2941591	et	3	main
saab	doc_919500587380_item	2941592	et	3	main
leida	doc_919500587380_item	2941593	et	3	main
lavastatud	doc_919500587380_item	2941594	et	4	main
ehk	doc_919500587380_item	2941595	et	3	main
poseeritud	doc_919500587380_item	2941596	et	4	main
fotod	doc_919500587380_item	2941597	et	3	main
minu	doc_919500587380_item	2941598	et	3	main
meelest	doc_919500587380_item	2941599	et	4	main
need	doc_919500587380_item	2941600	et	3	main
on	doc_919500587380_item	2941601	et	4	main
kõige	doc_919500587380_item	2941602	et	4	main
standaartsed	doc_919500587380_item	2941603	et	4	main
fotod	doc_919500587380_item	2941604	et	3	main
ning	doc_919500587380_item	2941605	et	3	main
kui	doc_919500587380_item	2941606	et	3	main
neid	doc_919500587380_item	2941607	et	4	main
on	doc_919500587380_item	2941608	et	4	main
liiga	doc_919500587380_item	2941609	et	4	main
palju	doc_919500587380_item	2941610	et	4	main
muutub	doc_919500587380_item	2941611	et	3	main
ajaleht	doc_919500587380_item	2941612	et	3	main
tüütavaks	doc_919500587380_item	2941613	et	4	main
halliks	doc_919500587380_item	2941614	et	4	main
eriti	doc_919500587380_item	2941615	et	3	main
ilusad	doc_919500587380_item	2941616	et	3	main
fotod	doc_919500587380_item	2941617	et	3	main
turismi	doc_919500587380_item	2941620	et	4	main
osakonnas	doc_919500587380_item	2941621	et	4	main
iseloomustavad	doc_919500587380_item	2941624	et	4	main
ilusaid	doc_919500587380_item	2941628	et	3	main
ajalehtedes	doc_919500587380_item	2941640	et	4	main
kui	doc_919500587380_item	2941644	et	3	main
märkasin	doc_919500587380_item	2941650	et	3	main
seda	doc_919500587380_item	2941651	et	3	main
äripäevas	doc_919500587380_item	2941653	et	3	main
on	doc_919500587380_item	2941657	et	4	main
fotod	doc_919500587380_item	2941664	et	3	main
ja	doc_919500587380_item	2941669	et	3	main
fotosid	doc_919500587380_item	2941681	et	3	main
aga	doc_919500587380_item	2941686	et	3	main
lõigatud	doc_919500587380_item	2941692	et	4	main
näiteks	doc_919500587380_item	2941694	et	4	main
uudiste	doc_919500587380_item	2941699	et	3	main
pilt	doc_919500587380_item	2941702	et	3	main
kõik	doc_919500587380_item	2941711	et	4	main
ajalehtedes	doc_919500587380_item	2941712	et	4	main
olevad	doc_919500587380_item	2941713	et	4	main
pildid	doc_919500587380_item	2941714	et	3	main
korralikult	doc_919500587380_item	2941721	et	4	main
värvilised	doc_919500587380_item	2941725	et	4	main
fotod	doc_919500587380_item	2941732	et	3	main
aru	doc_919500587380_item	2941743	et	4	main
viisil	doc_919500587380_item	2941746	et	4	main
ajalehes	doc_919500587380_item	2941747	et	3	main
foto	doc_919500587380_item	2941749	et	4	main
mõistetav	doc_919500587380_item	2941756	et	4	main
isegi	doc_919500587380_item	2941762	et	4	main
vaadates	doc_919500587380_item	2941765	et	3	main
mõned	doc_919500587380_item	2941768	et	3	main
õhtulehes	doc_919500587380_item	2941777	et	3	main
on	doc_919500587380_item	2941792	et	4	main
ilma	doc_919500587380_item	2941793	et	4	main
ei	doc_919500587380_item	2941796	et	4	main
mis	doc_919500587380_item	2941803	et	4	main
foto	doc_919500587380_item	2941807	et	4	main
on	doc_919500587380_item	2941810	et	4	main
üldse	doc_919500587380_item	2941811	et	3	main
siin	doc_919500587380_item	2941812	et	4	main
pilti	doc_919500587380_item	2941815	et	4	main
leida	doc_919500587380_item	2941818	et	3	main
ilma	doc_919500587380_item	2941821	et	4	main
pilte	doc_919500587380_item	2941823	et	3	main
tähelepanu	doc_919500587380_item	2941829	et	4	main
sellele	doc_919500587380_item	2941830	et	4	main
et	doc_919500587380_item	2941831	et	3	main
annaks	doc_919500587380_item	2941837	et	4	main
informatsiooni	doc_919500587380_item	2941840	et	4	main
äripäev	doc_919500587380_item	2941841	et	3	main
on	doc_919500587380_item	2941842	et	4	main
on	doc_919500587380_item	2941848	et	4	main
allkirjaga	doc_919500587380_item	2941849	et	3	main
sõltumata	doc_919500587380_item	2941850	et	4	main
kas	doc_919500587380_item	2941852	et	3	main
portreefoto	doc_919500587380_item	2941863	et	4	main
fotoallkiri	doc_919500587380_item	2941867	et	3	main
ajalehe	doc_919500587380_item	2941869	et	3	main
on	doc_919500587380_item	2941872	et	4	main
poolpaksus	doc_919500587380_item	2941875	et	4	main
kirjas	doc_919500587380_item	2941876	et	4	main
et	doc_919500587380_item	2941881	et	3	main
õhtuleht	doc_919500587380_item	2941885	et	3	main
omamoodi	doc_919500587380_item	2941890	et	3	main
huvitavad	doc_919500587380_item	2941892	et	4	main
igal	doc_919500587380_item	2941893	et	3	main
üht	doc_919500587380_item	2941900	et	3	main
ajalehes	doc_919500587380_item	2941916	et	3	main
mis	doc_919500587380_item	2941919	et	4	main
muudaksin	doc_919500587380_item	2941925	et	3	main
puuduvad	doc_919500587380_item	2941942	et	4	main
kohtades	doc_919500587380_item	2941945	et	3	main
ja	doc_919500587380_item	2941960	et	3	main
peavad	doc_919500587380_item	2941987	et	4	main
täiustama	doc_919500587380_item	2941988	et	3	main
oma	doc_919500587380_item	2941989	et	4	main
õhtuleht	doc_919500587380_item	2941998	et	3	main
täiusliku	doc_919500587380_item	2942000	et	3	main
ajalehtede	doc_919500587380_item	2942003	et	4	main
maailma	doc_919500587380_item	2941625	et	4	main
ja	doc_919500587380_item	2941627	et	3	main
ning	doc_919500587380_item	2941630	et	3	main
tegelikult	doc_919500587380_item	2941632	et	4	main
vapustavad	doc_919500587380_item	2941633	et	4	main
tahaks	doc_919500587380_item	2941634	et	3	main
mainida	doc_919500587380_item	2941635	et	3	main
ka	doc_919500587380_item	2941636	et	3	main
seda	doc_919500587380_item	2941637	et	3	main
et	doc_919500587380_item	2941638	et	3	main
mõlemates	doc_919500587380_item	2941639	et	3	main
horisontaalsed	doc_919500587380_item	2941643	et	3	main
vaid	doc_919500587380_item	2941661	et	3	main
fotod	doc_919500587380_item	2941666	et	3	main
dünaamilisemaks	doc_919500587380_item	2941670	et	4	main
üldjuhul	doc_919500587380_item	2941671	et	3	main
mõlemates	doc_919500587380_item	2941672	et	3	main
horisontaalseid	doc_919500587380_item	2941680	et	3	main
tavaliselt	doc_919500587380_item	2941682	et	4	main
fotod	doc_919500587380_item	2941684	et	3	main
sellistes	doc_919500587380_item	2941687	et	4	main
ajalehtedes	doc_919500587380_item	2941688	et	4	main
leidub	doc_919500587380_item	2941689	et	3	main
ka	doc_919500587380_item	2941690	et	3	main
leheküljel	doc_919500587380_item	2941698	et	3	main
osakonnas	doc_919500587380_item	2941700	et	4	main
osakonnas	doc_919500587380_item	2941706	et	4	main
all	doc_919500587380_item	2941707	et	3	main
on	doc_919500587380_item	2941715	et	4	main
seotavad	doc_919500587380_item	2941717	et	4	main
kõik	doc_919500587380_item	2941718	et	4	main
fotod	doc_919500587380_item	2941719	et	3	main
on	doc_919500587380_item	2941720	et	4	main
kaks	doc_919500587380_item	2941729	et	3	main
36	doc_919500587380_item	2941734	et	2	main
on	doc_919500587380_item	2941748	et	4	main
üheselt	doc_919500587380_item	2941755	et	4	main
peab	doc_919500587380_item	2941759	et	4	main
lehel	doc_919500587380_item	2941779	et	3	main
on	doc_919500587380_item	2941785	et	4	main
paigutatud	doc_919500587380_item	2941786	et	4	main
kahe	doc_919500587380_item	2941787	et	3	main
asjast	doc_919500587380_item	2941800	et	4	main
vaja	doc_919500587380_item	2941813	et	4	main
õhtulehes	doc_919500587380_item	2941816	et	3	main
allkirjata	doc_919500587380_item	2941822	et	3	main
meelest	doc_919500587380_item	2941825	et	4	main
toimetajad	doc_919500587380_item	2941826	et	4	main
peavad	doc_919500587380_item	2941827	et	4	main
väike	doc_919500587380_item	2941857	et	4	main
või	doc_919500587380_item	2941862	et	4	main
eristub	doc_919500587380_item	2941866	et	3	main
selgelt	doc_919500587380_item	2941868	et	4	main
põhitekstist	doc_919500587380_item	2941870	et	3	main
see	doc_919500587380_item	2941873	et	3	main
öelda	doc_919500587380_item	2941880	et	4	main
ka	doc_919500587380_item	2941887	et	3	main
lugejaskond	doc_919500587380_item	2941897	et	3	main
ei	doc_919500587380_item	2941906	et	4	main
pööra	doc_919500587380_item	2941907	et	4	main
eriti	doc_919500587380_item	2941908	et	3	main
tähelepanu	doc_919500587380_item	2941909	et	4	main
mõnedele	doc_919500587380_item	2941910	et	3	main
minusse	doc_919500587380_item	2941921	et	3	main
ma	doc_919500587380_item	2941923	et	3	main
paberi	doc_919500587380_item	2941926	et	3	main
isegi	doc_919500587380_item	2941961	et	4	main
veel	doc_919500587380_item	2941982	et	4	main
ideaalne	doc_919500587380_item	2941983	et	3	main
ajaleht	doc_919500587380_item	2941984	et	3	main
ning	doc_919500587380_item	2941985	et	3	main
võib-	doc_919500587380_item	2941993	et	3	main
olla	doc_919500587380_item	2941994	et	3	main
just	doc_919500587380_item	2941995	et	3	main
äripäev	doc_919500587380_item	2941996	et	3	main
eesti	doc_919500587381_item	2942006	et	4	main
ja	doc_919500587381_item	2942007	et	3	main
ning	doc_919500587380_item	2941723	et	3	main
mitmel	doc_919500587380_item	2941745	et	4	main
vahendaja	doc_919500587380_item	2941751	et	4	main
ja	doc_919500587380_item	2941752	et	3	main
peab	doc_919500587380_item	2941753	et	4	main
igal	doc_919500587380_item	2941757	et	3	main
fotoallkiri	doc_919500587380_item	2941761	et	3	main
õhtulehe	doc_919500587380_item	2941764	et	3	main
pildid	doc_919500587380_item	2941769	et	3	main
on	doc_919500587380_item	2941771	et	4	main
tuua	doc_919500587380_item	2941776	et	3	main
üleval	doc_919500587380_item	2941780	et	4	main
pildi	doc_919500587380_item	2941782	et	4	main
see	doc_919500587380_item	2941783	et	3	main
portreefoto	doc_919500587380_item	2941784	et	4	main
see	doc_919500587380_item	2941791	et	3	main
aru	doc_919500587380_item	2941801	et	4	main
et	doc_919500587380_item	2941802	et	3	main
selliseid	doc_919500587380_item	2941820	et	4	main
minu	doc_919500587380_item	2941824	et	3	main
iga	doc_919500587380_item	2941832	et	4	main
allkirjaga	doc_919500587380_item	2941835	et	3	main
mingit	doc_919500587380_item	2941839	et	3	main
on	doc_919500587380_item	2941854	et	4	main
suur	doc_919500587380_item	2941855	et	3	main
või	doc_919500587380_item	2941856	et	4	main
sündmusfoto	doc_919500587380_item	2941861	et	4	main
ajalehtedes	doc_919500587380_item	2941865	et	4	main
kirjutatud	doc_919500587380_item	2941874	et	4	main
ajalehed	doc_919500587380_item	2941883	et	3	main
oma	doc_919500587380_item	2941896	et	4	main
eelistab	doc_919500587380_item	2941899	et	3	main
teist	doc_919500587380_item	2941902	et	4	main
ajalehte	doc_919500587380_item	2941903	et	4	main
paljud	doc_919500587380_item	2941904	et	3	main
lugejad	doc_919500587380_item	2941905	et	4	main
palju	doc_919500587380_item	2941918	et	4	main
oleks	doc_919500587380_item	2941834	et	3	main
ning	doc_919500587380_item	2941836	et	3	main
lugejale	doc_919500587380_item	2941838	et	4	main
selle	doc_919500587380_item	2941843	et	4	main
vastand	doc_919500587380_item	2941844	et	4	main
äripäevas	doc_919500587380_item	2941845	et	3	main
sellest	doc_919500587380_item	2941851	et	4	main
tähtis	doc_919500587380_item	2941858	et	4	main
või	doc_919500587380_item	2941859	et	4	main
kõrvaline	doc_919500587380_item	2941860	et	4	main
järelduseks	doc_919500587380_item	2941877	et	4	main
tahaks	doc_919500587380_item	2941878	et	3	main
ma	doc_919500587380_item	2941879	et	3	main
mõlemad	doc_919500587380_item	2941882	et	3	main
kui	doc_919500587380_item	2941886	et	3	main
on	doc_919500587380_item	2941889	et	4	main
headning	doc_919500587380_item	2941891	et	4	main
ajalehel	doc_919500587380_item	2941894	et	3	main
on	doc_919500587380_item	2941895	et	4	main
kes	doc_919500587380_item	2941898	et	4	main
üsna	doc_919500587380_item	2941917	et	3	main
puutub	doc_919500587380_item	2941920	et	3	main
kindlasti	doc_919500587380_item	2941924	et	3	main
mis	doc_919500587380_item	2941941	et	4	main
midagi	doc_919500587380_item	2941948	et	4	main
ette	doc_919500587380_item	2941949	et	4	main
võtma	doc_919500587380_item	2941950	et	3	main
et	doc_919500587380_item	2941951	et	3	main
vältida	doc_919500587380_item	2941952	et	3	main
üleliigset	doc_919500587380_item	2941953	et	3	main
reklaami	doc_919500587380_item	2941954	et	4	main
esileheküljel	doc_919500587380_item	2941962	et	3	main
toimetajad	doc_919500587380_item	2941986	et	4	main
või	doc_919500587380_item	2941997	et	4	main
teiste	doc_919500587380_item	2942002	et	4	main
mõlemad	doc_919500587381_item	2942013	et	3	main
vanimatest	doc_919500587381_item	2942021	et	3	main
kuulsaimatest	doc_919500587381_item	2942023	et	4	main
ida-euroopas	doc_919500587381_item	2942025	et	3	main
1579	doc_919500587381_item	2942030	et	2	main
aastal	doc_919500587381_item	2942031	et	3	main
palju	doc_919500587381_item	2942041	et	4	main
tõusnud	doc_919500587381_item	2942046	et	4	main
eelmisel	doc_919500587381_item	2942058	et	3	main
semestril	doc_919500587381_item	2942059	et	3	main
oli	doc_919500587381_item	2942061	et	3	main
üheks	doc_919500587381_item	2942067	et	3	main
saanneid	doc_919500587381_item	2942070	et	4	main
ülikoolid	doc_919500587381_item	2942073	et	3	main
on	doc_919500587381_item	2942079	et	4	main
vana	doc_919500587381_item	2942085	et	4	main
süsteemi	doc_919500587381_item	2942086	et	4	main
aastat	doc_919500587381_item	2942091	et	3	main
ülikoolis	doc_919500587381_item	2942121	et	4	main
kauem	doc_919500587381_item	2942124	et	4	main
kauem	doc_919500587381_item	2942132	et	4	main
siis	doc_919500587381_item	2942133	et	3	main
üliõpilased	doc_919500587381_item	2942134	et	3	main
on	doc_919500587381_item	2942150	et	4	main
mitte	doc_919500587381_item	2942154	et	3	main
ammendavad	doc_919500587381_item	2942156	et	4	main
vilniuse	doc_919500587381_item	2942158	et	4	main
hoonetes	doc_919500587381_item	2942166	et	4	main
peahoone	doc_919500587381_item	2942169	et	4	main
hele	doc_919500587381_item	2942172	et	3	main
ja	doc_919500587381_item	2942173	et	3	main
ilus	doc_919500587381_item	2942174	et	4	main
võrreldes	doc_919500587381_item	2942175	et	3	main
osakonna	doc_919500587381_item	2942180	et	4	main
auditooriumid	doc_919500587381_item	2942181	et	3	main
tööd	doc_919500587381_item	2942193	et	4	main
tegema	doc_919500587381_item	2942194	et	3	main
tartu	doc_919500587381_item	2942200	et	4	main
harjutusi	doc_919500587381_item	2942209	et	4	main
küsimus	doc_919500587381_item	2942222	et	4	main
võib	doc_919500587381_item	2942224	et	3	main
vastata	doc_919500587381_item	2942225	et	4	main
üsna	doc_919500587381_item	2942231	et	3	main
tegin	doc_919500587381_item	2942233	et	3	main
teravmeelitsesid	doc_919500587381_item	2942256	et	4	main
ajal	doc_919500587381_item	2942259	et	4	main
väga	doc_919500587381_item	2942262	et	3	main
väga	doc_919500587381_item	2942264	et	3	main
sest	doc_919500587381_item	2942297	et	4	main
kui	doc_919500587381_item	2942298	et	3	main
olevad	doc_919500587380_item	2941846	et	4	main
fotod	doc_919500587380_item	2941847	et	3	main
foto	doc_919500587380_item	2941853	et	4	main
mõlemates	doc_919500587380_item	2941864	et	3	main
st	doc_919500587380_item	2941871	et	3	main
nii	doc_919500587380_item	2941884	et	3	main
äripäevaleht	doc_919500587380_item	2941888	et	3	main
või	doc_919500587380_item	2941901	et	4	main
puudustele	doc_919500587380_item	2941911	et	4	main
aga	doc_919500587380_item	2941912	et	3	main
neid	doc_919500587380_item	2941913	et	4	main
leidub	doc_919500587380_item	2941914	et	3	main
igas	doc_919500587380_item	2941915	et	3	main
millel	doc_919500587380_item	2941928	et	3	main
trükkitud	doc_919500587380_item	2941930	et	4	main
äripäev	doc_919500587380_item	2941931	et	3	main
pööraksin	doc_919500587380_item	2941932	et	3	main
tähelepanu	doc_919500587380_item	2941933	et	4	main
fotodele	doc_919500587380_item	2941934	et	3	main
teeksin	doc_919500587380_item	2941935	et	3	main
rohkem	doc_919500587380_item	2941936	et	4	main
spontaanseid	doc_919500587380_item	2941937	et	3	main
fotosid	doc_919500587380_item	2941938	et	3	main
ning	doc_919500587380_item	2941939	et	3	main
fotoallkirjadele	doc_919500587380_item	2941940	et	3	main
mõnedes	doc_919500587380_item	2941944	et	3	main
peab	doc_919500587380_item	2941947	et	4	main
leidub	doc_919500587380_item	2941956	et	3	main
peaaegu	doc_919500587380_item	2941957	et	3	main
ajalehes	doc_919500587380_item	2941959	et	3	main
ei	doc_919500587380_item	2941963	et	4	main
essee	doc_919500587381_item	2942005	et	4	main
ja	doc_919500587381_item	2942011	et	3	main
nii	doc_919500587381_item	2942015	et	3	main
asutatud	doc_919500587381_item	2942029	et	4	main
tartu	doc_919500587381_item	2942033	et	4	main
mõlemal	doc_919500587381_item	2942036	et	3	main
kordi	doc_919500587381_item	2942042	et	4	main
nad	doc_919500587381_item	2942043	et	3	main
olnud	doc_919500587381_item	2942045	et	4	main
elustunud	doc_919500587381_item	2942049	et	4	main
vilniuse	doc_919500587381_item	2942056	et	4	main
ülikoolis	doc_919500587381_item	2942057	et	4	main
õppima	doc_919500587381_item	2942065	et	3	main
vilniuse	doc_919500587381_item	2942082	et	4	main
ülikool	doc_919500587381_item	2942083	et	4	main
töötab	doc_919500587381_item	2942084	et	3	main
on	doc_919500587381_item	2942089	et	4	main
neli	doc_919500587381_item	2942090	et	3	main
õpivad	doc_919500587381_item	2942123	et	3	main
rohkem	doc_919500587381_item	2942126	et	4	main
süvitsi	doc_919500587381_item	2942127	et	4	main
kuna	doc_919500587381_item	2942128	et	3	main
lühemalt	doc_919500587381_item	2942147	et	4	main
ja	doc_919500587381_item	2942152	et	3	main
remonditud	doc_919500587381_item	2942183	et	4	main
õppevahenditega	doc_919500587381_item	2942187	et	3	main
praktiliseid	doc_919500587381_item	2942208	et	4	main
mingi	doc_919500587381_item	2942221	et	4	main
sellele	doc_919500587381_item	2942223	et	4	main
töö	doc_919500587381_item	2942229	et	4	main
oli	doc_919500587381_item	2942230	et	3	main
mis	doc_919500587381_item	2942236	et	4	main
raskemad	doc_919500587381_item	2942242	et	4	main
mõned	doc_919500587381_item	2942243	et	3	main
kergemad	doc_919500587381_item	2942244	et	4	main
sageli	doc_919500587381_item	2942265	et	3	main
siis	doc_919500587381_item	2942304	et	3	main
kui	doc_919500587381_item	2942317	et	3	main
ülikoolis	doc_919500587381_item	2942321	et	4	main
osakonnas	doc_919500587381_item	2942323	et	4	main
süsteem	doc_919500587381_item	2942324	et	3	main
me	doc_919500587381_item	2942329	et	4	main
auditooriumides	doc_919500587381_item	2942332	et	3	main
mõned	doc_919500587381_item	2942342	et	3	main
isegi	doc_919500587381_item	2942343	et	4	main
on	doc_919500587381_item	2942350	et	4	main
on	doc_919500587381_item	2942360	et	4	main
ka	doc_919500587381_item	2942370	et	3	main
rohkem	doc_919500587381_item	2942373	et	4	main
võid	doc_919500587381_item	2942382	et	4	main
siis	doc_919500587380_item	2941922	et	3	main
värvi	doc_919500587380_item	2941927	et	4	main
on	doc_919500587380_item	2941929	et	4	main
õhtulehe	doc_919500587380_item	2941943	et	3	main
kindlasti	doc_919500587380_item	2941946	et	3	main
mis	doc_919500587380_item	2941955	et	4	main
igas	doc_919500587380_item	2941958	et	3	main
saa	doc_919500587380_item	2941964	et	4	main
märkamata	doc_919500587380_item	2941965	et	4	main
jätta	doc_919500587380_item	2941966	et	3	main
ka	doc_919500587380_item	2941967	et	3	main
seda	doc_919500587380_item	2941968	et	3	main
et	doc_919500587380_item	2941969	et	3	main
mõned	doc_919500587380_item	2941970	et	3	main
osakonnad	doc_919500587380_item	2941971	et	4	main
lähevad	doc_919500587380_item	2941972	et	3	main
liiga	doc_919500587380_item	2941973	et	4	main
pikemaks	doc_919500587380_item	2941974	et	4	main
aga	doc_919500587380_item	2941975	et	3	main
mõned	doc_919500587380_item	2941976	et	3	main
üldse	doc_919500587380_item	2941977	et	3	main
puuduvad	doc_919500587380_item	2941978	et	4	main
ühesõnaga	doc_919500587380_item	2941979	et	3	main
ei	doc_919500587380_item	2941980	et	4	main
eksisteeri	doc_919500587380_item	2941981	et	4	main
teadmisi	doc_919500587380_item	2941990	et	4	main
ning	doc_919500587380_item	2941991	et	3	main
oskusi	doc_919500587380_item	2941992	et	3	main
muutuvad	doc_919500587380_item	2941999	et	4	main
näidiseks	doc_919500587380_item	2942001	et	3	main
leedu	doc_919500587381_item	2942008	et	4	main
sarnasused	doc_919500587381_item	2942010	et	4	main
ülikoolid	doc_919500587381_item	2942014	et	3	main
vilniuse	doc_919500587381_item	2942016	et	4	main
tartu	doc_919500587381_item	2942018	et	4	main
jaoks	doc_919500587380_item	2942004	et	4	main
üliõpilased	doc_919500587381_item	2942009	et	3	main
erinevused	doc_919500587381_item	2942012	et	4	main
ja	doc_919500587381_item	2942022	et	3	main
vilniuse	doc_919500587381_item	2942026	et	4	main
ja	doc_919500587381_item	2942032	et	3	main
1632	doc_919500587381_item	2942034	et	2	main
aastal	doc_919500587381_item	2942035	et	3	main
on	doc_919500587381_item	2942037	et	4	main
väga	doc_919500587381_item	2942038	et	3	main
suletud	doc_919500587381_item	2942051	et	4	main
õpin	doc_919500587381_item	2942053	et	3	main
keelt	doc_919500587381_item	2942055	et	4	main
minna	doc_919500587381_item	2942066	et	3	main
aga	doc_919500587381_item	2942077	et	3	main
täiesti	doc_919500587381_item	2942080	et	3	main
bakalaureusõpe	doc_919500587381_item	2942088	et	4	main
tööd	doc_919500587381_item	2942138	et	4	main
kestavad	doc_919500587381_item	2942146	et	4	main
asuvad	doc_919500587381_item	2942162	et	4	main
vanades	doc_919500587381_item	2942163	et	3	main
ja	doc_919500587381_item	2942164	et	3	main
ilusates	doc_919500587381_item	2942165	et	3	main
tartu	doc_919500587381_item	2942168	et	4	main
on	doc_919500587381_item	2942170	et	4	main
väga	doc_919500587381_item	2942171	et	3	main
peahoonega	doc_919500587381_item	2942178	et	4	main
filoloogia	doc_919500587381_item	2942179	et	4	main
ja	doc_919500587381_item	2942184	et	3	main
üliõpilased	doc_919500587381_item	2942189	et	3	main
peavad	doc_919500587381_item	2942190	et	4	main
morfoloogiat	doc_919500587381_item	2942199	et	3	main
kodus	doc_919500587381_item	2942202	et	4	main
loengutel	doc_919500587381_item	2942207	et	4	main
kui	doc_919500587381_item	2942017	et	3	main
on	doc_919500587381_item	2942019	et	4	main
kaks	doc_919500587381_item	2942020	et	3	main
ülikoolidest	doc_919500587381_item	2942024	et	3	main
ülikool	doc_919500587381_item	2942027	et	4	main
on	doc_919500587381_item	2942028	et	4	main
vastuoluline	doc_919500587381_item	2942039	et	4	main
ajalugu	doc_919500587381_item	2942040	et	4	main
alla	doc_919500587381_item	2942047	et	3	main
ma	doc_919500587381_item	2942052	et	3	main
eesti	doc_919500587381_item	2942054	et	4	main
võimalus	doc_919500587381_item	2942062	et	3	main
sellepärast	doc_919500587381_item	2942069	et	3	main
olema	doc_919500587381_item	2942075	et	4	main
üliõpilased	doc_919500587381_item	2942122	et	3	main
nende	doc_919500587381_item	2942129	et	4	main
õpingud	doc_919500587381_item	2942130	et	3	main
kestavad	doc_919500587381_item	2942131	et	4	main
teha	doc_919500587381_item	2942139	et	3	main
ja	doc_919500587381_item	2942140	et	3	main
raha	doc_919500587381_item	2942141	et	4	main
teenida	doc_919500587381_item	2942142	et	3	main
tartu	doc_919500587381_item	2942143	et	4	main
ülikoolis	doc_919500587381_item	2942144	et	4	main
õpingud	doc_919500587381_item	2942145	et	3	main
intensiivsemad	doc_919500587381_item	2942151	et	4	main
aga	doc_919500587381_item	2942167	et	3	main
ülikooli	doc_919500587381_item	2942177	et	4	main
näiteks	doc_919500587381_item	2942195	et	4	main
kui	doc_919500587381_item	2942196	et	3	main
ma	doc_919500587381_item	2942197	et	3	main
õpisin	doc_919500587381_item	2942198	et	4	main
ülikoolis	doc_919500587381_item	2942201	et	4	main
tegema	doc_919500587381_item	2942210	et	3	main
õppejõud	doc_919500587381_item	2942226	et	4	main
olid	doc_919500587381_item	2942237	et	4	main
väga	doc_919500587381_item	2942238	et	3	main
õppejõud	doc_919500587381_item	2942245	et	4	main
abivalmid	doc_919500587381_item	2942247	et	4	main
nad	doc_919500587381_item	2942250	et	3	main
palju	doc_919500587381_item	2942255	et	4	main
aga	doc_919500587381_item	2942257	et	3	main
samal	doc_919500587381_item	2942258	et	3	main
pidime	doc_919500587381_item	2942260	et	3	main
intensiivselt	doc_919500587381_item	2942263	et	4	main
ma	doc_919500587381_item	2942299	et	3	main
kogu	doc_919500587381_item	2942302	et	4	main
juba	doc_919500587381_item	2942306	et	3	main
oskan	doc_919500587381_item	2942308	et	3	main
mida	doc_919500587381_item	2942309	et	4	main
vilniuse	doc_919500587381_item	2942320	et	4	main
erinev	doc_919500587381_item	2942327	et	4	main
istuma	doc_919500587381_item	2942331	et	3	main
remonditud	doc_919500587381_item	2942341	et	4	main
ainult	doc_919500587381_item	2942347	et	4	main
mõned	doc_919500587381_item	2942348	et	3	main
remonditud	doc_919500587381_item	2942351	et	4	main
sobivad	doc_919500587381_item	2942353	et	4	main
kuid	doc_919500587381_item	2942355	et	4	main
tingimused	doc_919500587381_item	2942356	et	3	main
on	doc_919500587381_item	2942357	et	4	main
kehvad	doc_919500587381_item	2942358	et	3	main
ala	doc_919500587381_item	2942363	et	4	main
spetsialistid	doc_919500587381_item	2942364	et	3	main
paljud	doc_919500587381_item	2942365	et	3	main
loengud	doc_919500587381_item	2942366	et	3	main
olla	doc_919500587381_item	2942372	et	3	main
iseseisvat	doc_919500587381_item	2942374	et	3	main
kodus	doc_919500587381_item	2942383	et	4	main
materjali	doc_919500587381_item	2942384	et	4	main
juba	doc_919500587381_item	2942389	et	3	main
harjutusi	doc_919500587381_item	2942391	et	4	main
ülikoolides	doc_919500587381_item	2942421	et	3	main
saa	doc_919500587381_item	2942436	et	4	main
ka	doc_919500587381_item	2942437	et	3	main
ülikoolis	doc_919500587381_item	2942445	et	4	main
aga	doc_919500587381_item	2942450	et	3	main
ülikoolis	doc_919500587381_item	2942458	et	4	main
ma	doc_919500587381_item	2942459	et	3	main
õppisin	doc_919500587381_item	2942460	et	3	main
koos	doc_919500587381_item	2942461	et	4	main
olid	doc_919500587381_item	2942044	et	4	main
käinud	doc_919500587381_item	2942048	et	4	main
ja	doc_919500587381_item	2942050	et	3	main
mul	doc_919500587381_item	2942060	et	3	main
tartu	doc_919500587381_item	2942063	et	4	main
ülikooli	doc_919500587381_item	2942064	et	4	main
semestriks	doc_919500587381_item	2942068	et	3	main
võrrelda	doc_919500587381_item	2942071	et	4	main
mõlemad	doc_919500587381_item	2942072	et	3	main
peaksid	doc_919500587381_item	2942074	et	4	main
sarnased	doc_919500587381_item	2942076	et	4	main
nad	doc_919500587381_item	2942078	et	3	main
erinevad	doc_919500587381_item	2942081	et	4	main
järgi	doc_919500587381_item	2942087	et	4	main
ja	doc_919500587381_item	2942092	et	3	main
magistriõpe	doc_919500587381_item	2942093	et	3	main
on	doc_919500587381_item	2942094	et	4	main
kolm	doc_919500587381_item	2942095	et	3	main
aastat	doc_919500587381_item	2942096	et	3	main
aga	doc_919500587381_item	2942097	et	3	main
tartu	doc_919500587381_item	2942098	et	4	main
ülikoolis	doc_919500587381_item	2942099	et	4	main
on	doc_919500587381_item	2942100	et	4	main
tehtud	doc_919500587381_item	2942101	et	4	main
reform	doc_919500587381_item	2942102	et	3	main
ja	doc_919500587381_item	2942103	et	3	main
bakalaureusõpe	doc_919500587381_item	2942104	et	4	main
kestab	doc_919500587381_item	2942105	et	4	main
kolm	doc_919500587381_item	2942106	et	3	main
aastat	doc_919500587381_item	2942107	et	3	main
ja	doc_919500587381_item	2942108	et	3	main
magistriõppes	doc_919500587381_item	2942109	et	3	main
üliõpilased	doc_919500587381_item	2942110	et	3	main
õpivad	doc_919500587381_item	2942111	et	3	main
kaks	doc_919500587381_item	2942112	et	3	main
aastat	doc_919500587381_item	2942113	et	3	main
mis	doc_919500587381_item	2942114	et	4	main
süsteem	doc_919500587381_item	2942115	et	3	main
on	doc_919500587381_item	2942116	et	4	main
parem	doc_919500587381_item	2942117	et	4	main
raske	doc_919500587381_item	2942118	et	4	main
öelda	doc_919500587381_item	2942119	et	4	main
vilniuse	doc_919500587381_item	2942120	et	4	main
aga	doc_919500587381_item	2942125	et	3	main
ei	doc_919500587381_item	2942135	et	4	main
saa	doc_919500587381_item	2942136	et	4	main
täisajaga	doc_919500587381_item	2942137	et	3	main
aga	doc_919500587381_item	2942148	et	3	main
nad	doc_919500587381_item	2942149	et	3	main
kuid	doc_919500587381_item	2942153	et	4	main
nii	doc_919500587381_item	2942155	et	3	main
kui	doc_919500587381_item	2942157	et	3	main
ülikoolis	doc_919500587381_item	2942159	et	4	main
mõlemad	doc_919500587381_item	2942160	et	3	main
ülikoolid	doc_919500587381_item	2942161	et	3	main
vilniuse	doc_919500587381_item	2942176	et	4	main
on	doc_919500587381_item	2942182	et	4	main
varustatud	doc_919500587381_item	2942185	et	4	main
uutega	doc_919500587381_item	2942186	et	3	main
seal	doc_919500587381_item	2942188	et	4	main
rohkem	doc_919500587381_item	2942191	et	4	main
iseseisvat	doc_919500587381_item	2942192	et	3	main
pidin	doc_919500587381_item	2942203	et	3	main
teooriat	doc_919500587381_item	2942204	et	3	main
lugema	doc_919500587381_item	2942205	et	4	main
ja	doc_919500587381_item	2942206	et	3	main
mu	doc_919500587381_item	2942211	et	3	main
arvates	doc_919500587381_item	2942212	et	4	main
see	doc_919500587381_item	2942213	et	3	main
on	doc_919500587381_item	2942214	et	4	main
väga	doc_919500587381_item	2942215	et	3	main
hea	doc_919500587381_item	2942216	et	4	main
süsteem	doc_919500587381_item	2942217	et	3	main
sest	doc_919500587381_item	2942218	et	4	main
kui	doc_919500587381_item	2942219	et	3	main
tekib	doc_919500587381_item	2942220	et	3	main
auditoorne	doc_919500587381_item	2942228	et	4	main
huvitav	doc_919500587381_item	2942232	et	4	main
palju	doc_919500587381_item	2942234	et	4	main
harjutusi	doc_919500587381_item	2942235	et	4	main
olid	doc_919500587381_item	2942246	et	4	main
ja	doc_919500587381_item	2942248	et	3	main
suhtlesid	doc_919500587381_item	2942251	et	4	main
üliõpilastega	doc_919500587381_item	2942252	et	4	main
väga	doc_919500587381_item	2942253	et	3	main
soojalt	doc_919500587381_item	2942254	et	4	main
õppima	doc_919500587381_item	2942261	et	3	main
kirjutasime	doc_919500587381_item	2942266	et	3	main
ja	doc_919500587381_item	2942294	et	3	main
kogu	doc_919500587381_item	2942295	et	4	main
õpingutesse	doc_919500587381_item	2942296	et	3	main
pean	doc_919500587381_item	2942310	et	4	main
oskama	doc_919500587381_item	2942311	et	3	main
eriti	doc_919500587381_item	2942312	et	3	main
see	doc_919500587381_item	2942313	et	3	main
kehtib	doc_919500587381_item	2942314	et	3	main
keelt	doc_919500587381_item	2942319	et	4	main
esiteks	doc_919500587381_item	2942328	et	3	main
on	doc_919500587381_item	2942334	et	4	main
halvas	doc_919500587381_item	2942336	et	4	main
korras	doc_919500587381_item	2942337	et	4	main
paljud	doc_919500587381_item	2942338	et	3	main
haisevad	doc_919500587381_item	2942344	et	4	main
ja	doc_919500587381_item	2942352	et	3	main
ole	doc_919500587381_item	2942377	et	4	main
mõtet	doc_919500587381_item	2942378	et	3	main
läbi	doc_919500587381_item	2942385	et	4	main
ülikoolis	doc_919500587381_item	2942227	et	4	main
erinavad	doc_919500587381_item	2942239	et	4	main
mõned	doc_919500587381_item	2942240	et	3	main
olid	doc_919500587381_item	2942241	et	4	main
sõbralikud	doc_919500587381_item	2942249	et	3	main
kontrolltöid	doc_919500587381_item	2942267	et	3	main
kaks	doc_919500587381_item	2942268	et	3	main
korda	doc_919500587381_item	2942269	et	4	main
semestris	doc_919500587381_item	2942270	et	3	main
kollokviumit	doc_919500587381_item	2942271	et	3	main
aga	doc_919500587381_item	2942272	et	3	main
kui	doc_919500587381_item	2942273	et	3	main
kõvasti	doc_919500587381_item	2942274	et	3	main
õpid	doc_919500587381_item	2942275	et	4	main
sessioonit	doc_919500587381_item	2942276	et	4	main
sul	doc_919500587381_item	2942277	et	3	main
ei	doc_919500587381_item	2942278	et	4	main
ole	doc_919500587381_item	2942279	et	4	main
õppejõud	doc_919500587381_item	2942280	et	4	main
arvestavad	doc_919500587381_item	2942281	et	4	main
sinu	doc_919500587381_item	2942282	et	3	main
tööd	doc_919500587381_item	2942283	et	4	main
semestri	doc_919500587381_item	2942284	et	3	main
ajal	doc_919500587381_item	2942285	et	4	main
ma	doc_919500587381_item	2942286	et	3	main
arvan	doc_919500587381_item	2942287	et	3	main
et	doc_919500587381_item	2942288	et	3	main
see	doc_919500587381_item	2942289	et	3	main
on	doc_919500587381_item	2942290	et	4	main
õige	doc_919500587381_item	2942291	et	4	main
seisukoht	doc_919500587381_item	2942292	et	3	main
eksamitesse	doc_919500587381_item	2942293	et	3	main
õppinud	doc_919500587381_item	2942301	et	4	main
ajal	doc_919500587381_item	2942303	et	4	main
ma	doc_919500587381_item	2942305	et	3	main
kõik	doc_919500587381_item	2942307	et	4	main
õpitakse	doc_919500587381_item	2942318	et	4	main
filoloogia	doc_919500587381_item	2942322	et	4	main
on	doc_919500587381_item	2942325	et	4	main
täiesti	doc_919500587381_item	2942326	et	3	main
ei	doc_919500587381_item	2942339	et	4	main
hallituse	doc_919500587381_item	2942345	et	4	main
õppejõud	doc_919500587381_item	2942359	et	4	main
on	doc_919500587381_item	2942367	et	4	main
kasulikud	doc_919500587381_item	2942368	et	3	main
aga	doc_919500587381_item	2942369	et	3	main
loengutele	doc_919500587381_item	2942379	et	4	main
minna	doc_919500587381_item	2942380	et	3	main
kui	doc_919500587381_item	2942381	et	3	main
siis	doc_919500587381_item	2942388	et	3	main
loengutel	doc_919500587381_item	2942390	et	4	main
teha	doc_919500587381_item	2942392	et	3	main
õppejõud	doc_919500587381_item	2942393	et	4	main
kõrvaleriala	doc_919500587381_item	2942426	et	4	main
võtta	doc_919500587381_item	2942427	et	3	main
kõik	doc_919500587381_item	2942428	et	4	main
loengud	doc_919500587381_item	2942429	et	3	main
soovitavaid	doc_919500587381_item	2942438	et	4	main
aineid	doc_919500587381_item	2942439	et	3	main
valida	doc_919500587381_item	2942440	et	3	main
et	doc_919500587381_item	2942442	et	3	main
nii	doc_919500587381_item	2942448	et	3	main
on	doc_919500587381_item	2942453	et	4	main
vahetusüliõpilastega	doc_919500587381_item	2942468	et	4	main
peaaegu	doc_919500587381_item	2942469	et	3	main
kõik	doc_919500587381_item	2942470	et	4	main
mu	doc_919500587381_item	2942471	et	3	main
kaasüliõpilased	doc_919500587381_item	2942472	et	3	main
olid	doc_919500587381_item	2942473	et	4	main
nendega	doc_919500587381_item	2942479	et	4	main
suhelda	doc_919500587381_item	2942480	et	4	main
sest	doc_919500587381_item	2942481	et	4	main
nad	doc_919500587381_item	2942482	et	3	main
hakkasin	doc_919500587381_item	2942493	et	3	main
keeles	doc_919500587381_item	2942495	et	4	main
vahel	doc_919500587381_item	2942508	et	4	main
mingit	doc_919500587381_item	2942509	et	3	main
pinget	doc_919500587381_item	2942510	et	3	main
mitte	doc_919500587381_item	2942511	et	3	main
mulle	doc_919500587381_item	2942524	et	4	main
eestlaste	doc_919500587381_item	2942534	et	4	main
ja	doc_919500587381_item	2942535	et	3	main
erinevat	doc_919500587381_item	2942545	et	4	main
kõik	doc_919500587381_item	2942553	et	4	main
omavahel	doc_919500587381_item	2942555	et	3	main
kes	doc_919500587381_item	2942561	et	4	main
venelane	doc_919500587381_item	2942565	et	3	main
mõtlema	doc_919500587381_item	2942572	et	3	main
oled	doc_919500587381_item	2942574	et	3	main
sest	doc_919500587381_item	2942577	et	4	main
ole	doc_919500587381_item	2942580	et	4	main
on	doc_919500587381_item	2942588	et	4	main
sõbrad	doc_919500587381_item	2942593	et	3	main
ma	doc_919500587381_item	2942596	et	3	main
mulje	doc_919500587381_item	2942633	et	4	main
nagu	doc_919500587381_item	2942634	et	3	main
juba	doc_919500587381_item	2942635	et	3	main
alguses	doc_919500587381_item	2942636	et	4	main
olin	doc_919500587381_item	2942637	et	3	main
vilniuse	doc_919500587381_item	2942641	et	4	main
on	doc_919500587381_item	2942643	et	4	main
väga	doc_919500587381_item	2942644	et	3	main
erinevad	doc_919500587381_item	2942645	et	4	main
mõlemal	doc_919500587381_item	2942646	et	3	main
kui	doc_919500587381_item	2942654	et	3	main
tartu	doc_919500587381_item	2942655	et	4	main
mõnus	doc_919500587381_item	2942658	et	4	main
õppida	doc_919500587381_item	2942659	et	3	main
on	doc_919500587381_item	2942671	et	4	main
ülikoolis	doc_919500587381_item	2942678	et	4	main
olen	doc_919500587381_item	2942300	et	3	main
sellel	doc_919500587381_item	2942315	et	4	main
juhul	doc_919500587381_item	2942316	et	3	main
peame	doc_919500587381_item	2942330	et	4	main
mis	doc_919500587381_item	2942333	et	4	main
väga	doc_919500587381_item	2942335	et	3	main
ole	doc_919500587381_item	2942340	et	4	main
järele	doc_919500587381_item	2942346	et	4	main
auditooriumid	doc_919500587381_item	2942349	et	3	main
õppimiseks	doc_919500587381_item	2942354	et	4	main
head	doc_919500587381_item	2942361	et	4	main
oma	doc_919500587381_item	2942362	et	4	main
võiks	doc_919500587381_item	2942371	et	4	main
tööd	doc_919500587381_item	2942375	et	4	main
ei	doc_919500587381_item	2942376	et	4	main
lugeda	doc_919500587381_item	2942386	et	3	main
küsivad	doc_919500587381_item	2942399	et	4	main
midagi	doc_919500587381_item	2942400	et	4	main
nende	doc_919500587381_item	2942401	et	4	main
käest	doc_919500587381_item	2942402	et	4	main
see	doc_919500587381_item	2942403	et	3	main
on	doc_919500587381_item	2942404	et	4	main
pisut	doc_919500587381_item	2942405	et	3	main
naljakas	doc_919500587381_item	2942406	et	4	main
sest	doc_919500587381_item	2942407	et	4	main
sagedamini	doc_919500587381_item	2942408	et	4	main
mitte	doc_919500587381_item	2942409	et	3	main
keegi	doc_919500587381_item	2942410	et	4	main
mitte	doc_919500587381_item	2942411	et	3	main
midagi	doc_919500587381_item	2942412	et	4	main
ei	doc_919500587381_item	2942413	et	4	main
küsi	doc_919500587381_item	2942414	et	4	main
ma	doc_919500587381_item	2942415	et	3	main
arvan	doc_919500587381_item	2942416	et	3	main
et	doc_919500587381_item	2942417	et	3	main
niimoodi	doc_919500587381_item	2942418	et	3	main
on	doc_919500587381_item	2942419	et	4	main
paljudes	doc_919500587381_item	2942420	et	3	main
vilniuse	doc_919500587381_item	2942422	et	4	main
ei	doc_919500587381_item	2942424	et	4	main
saa	doc_919500587381_item	2942425	et	4	main
tundub	doc_919500587381_item	2942441	et	3	main
tartu	doc_919500587381_item	2942444	et	4	main
mulje	doc_919500587381_item	2942456	et	4	main
tartu	doc_919500587381_item	2942457	et	4	main
venelased	doc_919500587381_item	2942474	et	3	main
raske	doc_919500587381_item	2942478	et	4	main
ja	doc_919500587381_item	2942497	et	3	main
suhtlema	doc_919500587381_item	2942499	et	3	main
tudengid	doc_919500587381_item	2942500	et	3	main
olid	doc_919500587381_item	2942501	et	4	main
väga	doc_919500587381_item	2942502	et	3	main
ainult	doc_919500587381_item	2942531	et	4	main
ülikoolis	doc_919500587381_item	2942532	et	4	main
suhted	doc_919500587381_item	2942533	et	3	main
vahel	doc_919500587381_item	2942538	et	4	main
kogukonda	doc_919500587381_item	2942546	et	4	main
sa	doc_919500587381_item	2942578	et	3	main
on	doc_919500587381_item	2942583	et	4	main
hulgast	doc_919500587381_item	2942592	et	4	main
üles	doc_919500587381_item	2942594	et	3	main
proovisin	doc_919500587381_item	2942597	et	3	main
ja	doc_919500587381_item	2942387	et	3	main
on	doc_919500587381_item	2942394	et	4	main
väga	doc_919500587381_item	2942395	et	3	main
õnnelikud	doc_919500587381_item	2942396	et	3	main
kui	doc_919500587381_item	2942397	et	3	main
üliõpilased	doc_919500587381_item	2942398	et	3	main
ülikoolis	doc_919500587381_item	2942423	et	4	main
esimesest	doc_919500587381_item	2942431	et	3	main
nädalast	doc_919500587381_item	2942432	et	4	main
ei	doc_919500587381_item	2942446	et	4	main
range	doc_919500587381_item	2942449	et	4	main
üliõpilastega	doc_919500587381_item	2942463	et	4	main
ainult	doc_919500587381_item	2942464	et	4	main
paar	doc_919500587381_item	2942465	et	3	main
loengut	doc_919500587381_item	2942466	et	3	main
toimus	doc_919500587381_item	2942467	et	3	main
rääkisid	doc_919500587381_item	2942483	et	4	main
omavahel	doc_919500587381_item	2942484	et	3	main
ainult	doc_919500587381_item	2942485	et	4	main
vene	doc_919500587381_item	2942486	et	4	main
keeles	doc_919500587381_item	2942487	et	4	main
aga	doc_919500587381_item	2942488	et	3	main
päris	doc_919500587381_item	2942489	et	4	main
ma	doc_919500587381_item	2942492	et	3	main
rääkima	doc_919500587381_item	2942496	et	3	main
rohkem	doc_919500587381_item	2942498	et	4	main
sõbralikud	doc_919500587381_item	2942503	et	3	main
ei	doc_919500587381_item	2942505	et	4	main
olnud	doc_919500587381_item	2942506	et	4	main
ülikoolis	doc_919500587381_item	2942548	et	4	main
sellest	doc_919500587381_item	2942560	et	4	main
ei	doc_919500587381_item	2942570	et	4	main
hakka	doc_919500587381_item	2942571	et	4	main
halvem	doc_919500587381_item	2942575	et	4	main
inimene	doc_919500587381_item	2942576	et	3	main
väga	doc_919500587381_item	2942584	et	3	main
ja	doc_919500587381_item	2942586	et	3	main
raske	doc_919500587381_item	2942590	et	4	main
nende	doc_919500587381_item	2942591	et	4	main
inimesed	doc_919500587381_item	2942621	et	3	main
usun	doc_919500587381_item	2942624	et	3	main
ei	doc_919500587381_item	2942627	et	4	main
see	doc_919500587381_item	2942630	et	3	main
vale	doc_919500587381_item	2942632	et	4	main
oma	doc_919500587381_item	2942648	et	4	main
oma	doc_919500587381_item	2942662	et	4	main
vaim	doc_919500587381_item	2942663	et	3	main
ja	doc_919500587381_item	2942664	et	3	main
mõlemas	doc_919500587381_item	2942665	et	3	main
olnud	doc_919500587381_item	2942672	et	4	main
selline	doc_919500587381_item	2942673	et	4	main
meeldiv	doc_919500587381_item	2942674	et	4	main
kogemus	doc_919500587381_item	2942675	et	3	main
tartu	doc_919500587381_item	2942677	et	4	main
ja	doc_919500587382_item	2942685	et	3	main
olen	doc_919500587382_item	2942688	et	3	main
väga	doc_919500587382_item	2942689	et	3	main
õnnelik	doc_919500587382_item	2942690	et	3	main
uhke	doc_919500587382_item	2942699	et	4	main
üle	doc_919500587382_item	2942701	et	3	main
preestrid	doc_919500587382_item	2942723	et	4	main
õppida	doc_919500587382_item	2942729	et	3	main
mis	doc_919500587382_item	2942735	et	4	main
vaimuga	doc_919500587382_item	2942740	et	3	main
et	doc_919500587382_item	2942743	et	3	main
et	doc_919500587382_item	2942749	et	3	main
on	doc_919500587382_item	2942751	et	4	main
alati	doc_919500587382_item	2942752	et	4	main
et	doc_919500587382_item	2942784	et	3	main
on	doc_919500587382_item	2942794	et	4	main
toimuvad	doc_919500587381_item	2942430	et	4	main
kuni	doc_919500587381_item	2942433	et	3	main
viimaseni	doc_919500587381_item	2942434	et	3	main
ei	doc_919500587381_item	2942435	et	4	main
kord	doc_919500587381_item	2942443	et	4	main
ole	doc_919500587381_item	2942447	et	4	main
vist	doc_919500587381_item	2942451	et	4	main
see	doc_919500587381_item	2942452	et	3	main
lihtsalt	doc_919500587381_item	2942454	et	4	main
niisugune	doc_919500587381_item	2942455	et	3	main
kohalikute	doc_919500587381_item	2942462	et	4	main
oli	doc_919500587381_item	2942476	et	3	main
aega	doc_919500587381_item	2942491	et	4	main
ja	doc_919500587381_item	2942504	et	3	main
keegi	doc_919500587381_item	2942512	et	4	main
ei	doc_919500587381_item	2942513	et	4	main
kadestanud	doc_919500587381_item	2942514	et	4	main
üksteist	doc_919500587381_item	2942515	et	4	main
heade	doc_919500587381_item	2942516	et	3	main
hindade	doc_919500587381_item	2942517	et	3	main
pärast	doc_919500587381_item	2942518	et	4	main
õhkkond	doc_919500587381_item	2942519	et	3	main
oli	doc_919500587381_item	2942520	et	3	main
tõesti	doc_919500587381_item	2942521	et	3	main
mõnus	doc_919500587381_item	2942523	et	4	main
tundus	doc_919500587381_item	2942525	et	3	main
et	doc_919500587381_item	2942526	et	3	main
venelaste	doc_919500587381_item	2942536	et	4	main
on	doc_919500587381_item	2942539	et	4	main
keerulised	doc_919500587381_item	2942541	et	4	main
nad	doc_919500587381_item	2942542	et	3	main
koostavad	doc_919500587381_item	2942543	et	4	main
kaks	doc_919500587381_item	2942544	et	3	main
on	doc_919500587381_item	2942549	et	4	main
üks	doc_919500587381_item	2942550	et	3	main
sõbralik	doc_919500587381_item	2942551	et	3	main
suhtlevad	doc_919500587381_item	2942554	et	4	main
see	doc_919500587381_item	2942557	et	3	main
sa	doc_919500587381_item	2942562	et	3	main
poolakas	doc_919500587381_item	2942564	et	4	main
keegi	doc_919500587381_item	2942569	et	4	main
ei	doc_919500587381_item	2942579	et	4	main
leedukas	doc_919500587381_item	2942581	et	4	main
tagasihoidlikud	doc_919500587381_item	2942585	et	3	main
aga	doc_919500587381_item	2942622	et	3	main
ma	doc_919500587381_item	2942623	et	3	main
niimoodi	doc_919500587381_item	2942626	et	3	main
ja	doc_919500587381_item	2942629	et	3	main
ja	doc_919500587381_item	2942640	et	3	main
ülikoolid	doc_919500587381_item	2942642	et	3	main
midagi	doc_919500587381_item	2942666	et	4	main
võlub	doc_919500587381_item	2942667	et	3	main
õppida	doc_919500587381_item	2942676	et	3	main
erinevused	doc_919500587382_item	2942686	et	4	main
ma	doc_919500587382_item	2942687	et	3	main
ja	doc_919500587382_item	2942691	et	3	main
et	doc_919500587382_item	2942693	et	3	main
õppida	doc_919500587382_item	2942695	et	3	main
viniuse	doc_919500587382_item	2942696	et	4	main
ülikool	doc_919500587382_item	2942704	et	4	main
jne	doc_919500587382_item	2942724	et	4	main
mulle	doc_919500587382_item	2942725	et	4	main
ka	doc_919500587382_item	2942727	et	3	main
seal	doc_919500587382_item	2942731	et	4	main
ülikooli	doc_919500587382_item	2942733	et	4	main
on	doc_919500587382_item	2942745	et	4	main
hoone	doc_919500587382_item	2942748	et	4	main
seal	doc_919500587382_item	2942750	et	4	main
mulle	doc_919500587382_item	2942757	et	4	main
meeldib	doc_919500587382_item	2942758	et	3	main
ette	doc_919500587382_item	2942759	et	4	main
kujutada	doc_919500587382_item	2942760	et	3	main
kuidas	doc_919500587382_item	2942761	et	3	main
kõigepealt	doc_919500587381_item	2942475	et	3	main
väga	doc_919500587381_item	2942477	et	3	main
mõnda	doc_919500587381_item	2942490	et	4	main
vene	doc_919500587381_item	2942494	et	4	main
nende	doc_919500587381_item	2942507	et	4	main
väga	doc_919500587381_item	2942522	et	3	main
tartu	doc_919500587381_item	2942527	et	4	main
ülikoolis	doc_919500587381_item	2942528	et	4	main
ja	doc_919500587381_item	2942529	et	3	main
mitte	doc_919500587381_item	2942530	et	3	main
tudengite	doc_919500587381_item	2942537	et	3	main
päris	doc_919500587381_item	2942540	et	4	main
vilniuse	doc_919500587381_item	2942547	et	4	main
kogukond	doc_919500587381_item	2942552	et	3	main
ja	doc_919500587381_item	2942556	et	3	main
ei	doc_919500587381_item	2942558	et	4	main
sõltu	doc_919500587381_item	2942559	et	4	main
oled	doc_919500587381_item	2942563	et	3	main
või	doc_919500587381_item	2942566	et	4	main
leedukas	doc_919500587381_item	2942567	et	4	main
mitte	doc_919500587381_item	2942568	et	3	main
et	doc_919500587381_item	2942573	et	3	main
eestlased	doc_919500587381_item	2942582	et	3	main
ujed	doc_919500587381_item	2942587	et	4	main
väga	doc_919500587381_item	2942589	et	3	main
leida	doc_919500587381_item	2942595	et	3	main
kuidagi	doc_919500587381_item	2942598	et	3	main
eestlastega	doc_919500587381_item	2942599	et	4	main
suhelda	doc_919500587381_item	2942600	et	4	main
aga	doc_919500587381_item	2942601	et	3	main
mõnikord	doc_919500587381_item	2942602	et	3	main
see	doc_919500587381_item	2942603	et	3	main
oli	doc_919500587381_item	2942604	et	3	main
lihtsalt	doc_919500587381_item	2942605	et	4	main
võimatu	doc_919500587381_item	2942606	et	4	main
nad	doc_919500587381_item	2942607	et	3	main
on	doc_919500587381_item	2942608	et	4	main
nii	doc_919500587381_item	2942609	et	3	main
ettevaatlikud	doc_919500587381_item	2942610	et	3	main
et	doc_919500587381_item	2942611	et	3	main
mõnikord	doc_919500587381_item	2942612	et	3	main
tundub	doc_919500587381_item	2942613	et	3	main
et	doc_919500587381_item	2942614	et	3	main
eestlased	doc_919500587381_item	2942615	et	3	main
tõesti	doc_919500587381_item	2942616	et	3	main
väga	doc_919500587381_item	2942617	et	3	main
külmad	doc_919500587381_item	2942618	et	4	main
ja	doc_919500587381_item	2942619	et	3	main
ebasõbralikud	doc_919500587381_item	2942620	et	3	main
ole	doc_919500587381_item	2942628	et	4	main
on	doc_919500587381_item	2942631	et	4	main
öelnud	doc_919500587381_item	2942638	et	4	main
eelised	doc_919500587381_item	2942649	et	4	main
ja	doc_919500587381_item	2942650	et	3	main
puudused	doc_919500587381_item	2942651	et	3	main
nii	doc_919500587381_item	2942652	et	3	main
vilniuse	doc_919500587381_item	2942653	et	4	main
on	doc_919500587381_item	2942657	et	4	main
olen	doc_919500587381_item	2942668	et	3	main
õnnelik	doc_919500587381_item	2942669	et	3	main
et	doc_919500587381_item	2942670	et	3	main
essee	doc_919500587382_item	2942679	et	4	main
eesti	doc_919500587382_item	2942680	et	4	main
ja	doc_919500587382_item	2942681	et	3	main
et	doc_919500587381_item	2942625	et	3	main
tartu	doc_919500587381_item	2942639	et	4	main
on	doc_919500587381_item	2942647	et	4	main
ülikoolis	doc_919500587381_item	2942656	et	4	main
nendel	doc_919500587381_item	2942660	et	4	main
on	doc_919500587381_item	2942661	et	4	main
leedu	doc_919500587382_item	2942682	et	4	main
et	doc_919500587382_item	2942702	et	3	main
on	doc_919500587382_item	2942705	et	4	main
üks	doc_919500587382_item	2942706	et	3	main
kõige	doc_919500587382_item	2942707	et	4	main
vanematest	doc_919500587382_item	2942708	et	4	main
ülikoolidest	doc_919500587382_item	2942709	et	3	main
ida	doc_919500587382_item	2942710	et	4	main
euroopas	doc_919500587382_item	2942711	et	3	main
et	doc_919500587382_item	2942712	et	3	main
siin	doc_919500587382_item	2942713	et	4	main
on	doc_919500587382_item	2942714	et	4	main
õppinud	doc_919500587382_item	2942715	et	4	main
palju	doc_919500587382_item	2942716	et	4	main
kuulsaid	doc_919500587382_item	2942717	et	3	main
leedu	doc_919500587382_item	2942718	et	4	main
inimesi	doc_919500587382_item	2942719	et	4	main
kirjanukud	doc_919500587382_item	2942720	et	3	main
muusikud	doc_919500587382_item	2942722	et	4	main
meeldib	doc_919500587382_item	2942726	et	3	main
vanalinnas	doc_919500587382_item	2942728	et	4	main
oma	doc_919500587382_item	2942738	et	4	main
arhitektuuri	doc_919500587382_item	2942739	et	4	main
sellega	doc_919500587382_item	2942742	et	3	main
vana	doc_919500587382_item	2942747	et	4	main
turiste	doc_919500587382_item	2942756	et	3	main
sada	doc_919500587382_item	2942779	et	4	main
aastat	doc_919500587382_item	2942780	et	3	main
tagasi	doc_919500587382_item	2942781	et	3	main
arvan	doc_919500587382_item	2942783	et	3	main
on	doc_919500587382_item	2942787	et	4	main
ka	doc_919500587382_item	2942788	et	3	main
oma	doc_919500587382_item	2942789	et	4	main
vaim	doc_919500587382_item	2942790	et	3	main
nagu	doc_919500587382_item	2942791	et	3	main
oma	doc_919500587382_item	2942795	et	4	main
vaim	doc_919500587382_item	2942796	et	3	main
on	doc_919500587382_item	2942798	et	4	main
tõesti	doc_919500587382_item	2942799	et	3	main
heade	doc_919500587382_item	2942800	et	3	main
mõtete	doc_919500587382_item	2942801	et	3	main
on	doc_919500587382_item	2942828	et	4	main
nagu	doc_919500587382_item	2942829	et	3	main
suur	doc_919500587382_item	2942830	et	3	main
tudengite	doc_919500587382_item	2942831	et	3	main
sipelgapesa	doc_919500587382_item	2942832	et	4	main
palju	doc_919500587382_item	2942836	et	4	main
elu	doc_919500587382_item	2942839	et	4	main
liikumist	doc_919500587382_item	2942840	et	4	main
mulle	doc_919500587382_item	2942847	et	4	main
ülikoolis	doc_919500587382_item	2942867	et	4	main
öelda	doc_919500587382_item	2942881	et	4	main
et	doc_919500587382_item	2942882	et	3	main
minu	doc_919500587382_item	2942883	et	3	main
suhted	doc_919500587382_item	2942884	et	3	main
ülikool	doc_919500587382_item	2942897	et	4	main
erineb	doc_919500587382_item	2942898	et	3	main
ainult	doc_919500587382_item	2942910	et	4	main
ametlikud	doc_919500587382_item	2942911	et	3	main
on	doc_919500587382_item	2942924	et	4	main
üliõpolased	doc_919500587382_item	2942683	et	4	main
sarnasused	doc_919500587382_item	2942684	et	4	main
uhke	doc_919500587382_item	2942692	et	4	main
saan	doc_919500587382_item	2942694	et	4	main
ülikoolis	doc_919500587382_item	2942697	et	4	main
olen	doc_919500587382_item	2942698	et	3	main
selle	doc_919500587382_item	2942700	et	4	main
minu	doc_919500587382_item	2942703	et	3	main
on	doc_919500587382_item	2942732	et	4	main
ja	doc_919500587382_item	2942741	et	3	main
tõesti	doc_919500587382_item	2942746	et	3	main
kuulus	doc_919500587382_item	2942766	et	4	main
inimene	doc_919500587382_item	2942767	et	3	main
et	doc_919500587382_item	2942768	et	3	main
ta	doc_919500587382_item	2942769	et	4	main
jalutas	doc_919500587382_item	2942770	et	3	main
seal	doc_919500587382_item	2942771	et	4	main
kus	doc_919500587382_item	2942772	et	3	main
tartu	doc_919500587382_item	2942792	et	4	main
linnal	doc_919500587382_item	2942793	et	3	main
tartu	doc_919500587382_item	2942797	et	4	main
mõlemad	doc_919500587382_item	2942842	et	3	main
on	doc_919500587382_item	2942853	et	4	main
erinevusi	doc_919500587382_item	2942857	et	4	main
et	doc_919500587382_item	2942859	et	3	main
kaasüliõpilastega	doc_919500587382_item	2942886	et	4	main
olid	doc_919500587382_item	2942890	et	4	main
sõbralikud	doc_919500587382_item	2942893	et	3	main
poolest	doc_919500587382_item	2942895	et	4	main
tartu	doc_919500587382_item	2942896	et	4	main
saa	doc_919500587382_item	2942903	et	4	main
siin	doc_919500587382_item	2942906	et	4	main
palju	doc_919500587382_item	2942931	et	4	main
arvamus	doc_919500587382_item	2942936	et	3	main
ja	doc_919500587382_item	2942940	et	3	main
ja	doc_919500587382_item	2942945	et	3	main
inimesed	doc_919500587382_item	2942947	et	3	main
ei	doc_919500587382_item	2942970	et	4	main
mulle	doc_919500587382_item	2942975	et	4	main
auditoorne	doc_919500587382_item	2942977	et	4	main
huvitavam	doc_919500587382_item	2942982	et	4	main
põhjus	doc_919500587382_item	2942989	et	4	main
väga	doc_919500587382_item	2942995	et	3	main
tudengite	doc_919500587382_item	2943005	et	3	main
erinevaid	doc_919500587382_item	2943026	et	4	main
arvutit	doc_919500587382_item	2943031	et	3	main
töö	doc_919500587382_item	2943037	et	4	main
oli	doc_919500587382_item	2943038	et	3	main
aga	doc_919500587382_item	2943041	et	3	main
oli	doc_919500587382_item	2943043	et	3	main
võib-olla	doc_919500587382_item	2943050	et	3	main
see	doc_919500587382_item	2943054	et	3	main
üldse	doc_919500587382_item	2943069	et	3	main
teha	doc_919500587382_item	2943112	et	3	main
võimatu	doc_919500587382_item	2943115	et	4	main
ei	doc_919500587382_item	2943118	et	4	main
õppejõud	doc_919500587382_item	2943123	et	4	main
taha	doc_919500587382_item	2943127	et	4	main
rohkem	doc_919500587382_item	2943128	et	4	main
puhata	doc_919500587382_item	2943129	et	4	main
kas	doc_919500587382_item	2943130	et	3	main
aru	doc_919500587382_item	2943145	et	4	main
mulle	doc_919500587382_item	2943146	et	4	main
meeldisid	doc_919500587382_item	2943147	et	4	main
eksamid	doc_919500587382_item	2943148	et	3	main
et	doc_919500587382_item	2943153	et	3	main
mida	doc_919500587382_item	2943171	et	4	main
sõltub	doc_919500587382_item	2943181	et	3	main
ka	doc_919500587382_item	2943182	et	3	main
peaaegu	doc_919500587382_item	2943192	et	3	main
olin	doc_919500587382_item	2943197	et	3	main
natuke	doc_919500587382_item	2943199	et	4	main
aga	doc_919500587382_item	2943200	et	3	main
arvan	doc_919500587382_item	2943201	et	3	main
et	doc_919500587382_item	2943202	et	3	main
see	doc_919500587382_item	2943203	et	3	main
on	doc_919500587382_item	2943204	et	4	main
normaalne	doc_919500587382_item	2943205	et	3	main
siiski	doc_919500587382_item	2943209	et	4	main
mulle	doc_919500587382_item	2943212	et	4	main
meeldis	doc_919500587382_item	2943213	et	3	main
ja	doc_919500587382_item	2943214	et	3	main
mitte	doc_919500587382_item	2943236	et	3	main
poliitikud	doc_919500587382_item	2942721	et	3	main
sest	doc_919500587382_item	2942730	et	4	main
põhihoone	doc_919500587382_item	2942734	et	4	main
võlub	doc_919500587382_item	2942736	et	3	main
mind	doc_919500587382_item	2942737	et	4	main
see	doc_919500587382_item	2942744	et	3	main
palju	doc_919500587382_item	2942753	et	4	main
üliõpilasi	doc_919500587382_item	2942754	et	3	main
ja	doc_919500587382_item	2942755	et	3	main
mingi	doc_919500587382_item	2942765	et	4	main
ma	doc_919500587382_item	2942782	et	3	main
linn	doc_919500587382_item	2942802	et	3	main
sest	doc_919500587382_item	2942803	et	4	main
seal	doc_919500587382_item	2942804	et	4	main
tunned	doc_919500587382_item	2942805	et	3	main
ennast	doc_919500587382_item	2942806	et	4	main
nagu	doc_919500587382_item	2942807	et	3	main
kodus	doc_919500587382_item	2942808	et	4	main
linn	doc_919500587382_item	2942809	et	3	main
on	doc_919500587382_item	2942810	et	4	main
nii	doc_919500587382_item	2942811	et	3	main
hubane	doc_919500587382_item	2942812	et	3	main
armas	doc_919500587382_item	2942813	et	3	main
tartu	doc_919500587382_item	2942814	et	4	main
ülikool	doc_919500587382_item	2942815	et	4	main
on	doc_919500587382_item	2942816	et	4	main
ka	doc_919500587382_item	2942817	et	3	main
väga	doc_919500587382_item	2942818	et	3	main
hubane	doc_919500587382_item	2942819	et	3	main
tartu	doc_919500587382_item	2942820	et	4	main
nagu	doc_919500587382_item	2942823	et	3	main
ja	doc_919500587382_item	2942825	et	3	main
tartu	doc_919500587382_item	2942826	et	4	main
linn	doc_919500587382_item	2942827	et	3	main
alati	doc_919500587382_item	2942835	et	4	main
palju	doc_919500587382_item	2942838	et	4	main
ülikoolid	doc_919500587382_item	2942843	et	3	main
linnad	doc_919500587382_item	2942845	et	3	main
nendel	doc_919500587382_item	2942852	et	4	main
ja	doc_919500587382_item	2942856	et	3	main
tudengid	doc_919500587382_item	2942860	et	3	main
tartu	doc_919500587382_item	2942862	et	4	main
kui	doc_919500587382_item	2942887	et	3	main
tõesti	doc_919500587382_item	2942891	et	3	main
väga	doc_919500587382_item	2942892	et	3	main
vilniuse	doc_919500587382_item	2942899	et	4	main
öelda	doc_919500587382_item	2942904	et	4	main
samas	doc_919500587382_item	2942762	et	4	main
auditooriumis	doc_919500587382_item	2942763	et	3	main
õpis	doc_919500587382_item	2942764	et	3	main
ma	doc_919500587382_item	2942773	et	3	main
jalutan	doc_919500587382_item	2942774	et	3	main
praegu	doc_919500587382_item	2942775	et	3	main
aga	doc_919500587382_item	2942776	et	3	main
ainult	doc_919500587382_item	2942777	et	4	main
mõni	doc_919500587382_item	2942778	et	3	main
vilniuse	doc_919500587382_item	2942785	et	4	main
ülikoolil	doc_919500587382_item	2942786	et	4	main
ülikool	doc_919500587382_item	2942821	et	4	main
on	doc_919500587382_item	2942834	et	4	main
inimesi	doc_919500587382_item	2942837	et	4	main
ja	doc_919500587382_item	2942844	et	3	main
oma	doc_919500587382_item	2942854	et	4	main
nii	doc_919500587382_item	2942861	et	3	main
ülikoolis	doc_919500587382_item	2942863	et	4	main
kui	doc_919500587382_item	2942864	et	3	main
ka	doc_919500587382_item	2942865	et	3	main
vilniuse	doc_919500587382_item	2942866	et	4	main
päris	doc_919500587382_item	2942869	et	4	main
sõbralikud	doc_919500587382_item	2942871	et	3	main
mõned	doc_919500587382_item	2942872	et	3	main
nii	doc_919500587382_item	2942885	et	3	main
õppejõududega	doc_919500587382_item	2942889	et	3	main
ülikoolist	doc_919500587382_item	2942900	et	4	main
ma	doc_919500587382_item	2942901	et	3	main
ei	doc_919500587382_item	2942902	et	4	main
ja	doc_919500587382_item	2942912	et	3	main
ja	doc_919500587382_item	2942914	et	3	main
soojad	doc_919500587382_item	2942921	et	3	main
päris	doc_919500587382_item	2942925	et	4	main
sõltub	doc_919500587382_item	2942934	et	3	main
saan	doc_919500587382_item	2942959	et	4	main
head	doc_919500587382_item	2942967	et	4	main
muljet	doc_919500587382_item	2942968	et	3	main
see	doc_919500587382_item	2942969	et	3	main
mis	doc_919500587382_item	2942974	et	4	main
töö	doc_919500587382_item	2942978	et	4	main
õppejõud	doc_919500587382_item	2942993	et	4	main
olid	doc_919500587382_item	2942994	et	4	main
ju	doc_919500587382_item	2943007	et	3	main
sõltub	doc_919500587382_item	2943010	et	3	main
oli	doc_919500587382_item	2943017	et	3	main
sellepärast	doc_919500587382_item	2943021	et	3	main
aga	doc_919500587382_item	2943028	et	3	main
videot	doc_919500587382_item	2943030	et	3	main
ka	doc_919500587382_item	2943034	et	3	main
asi	doc_919500587382_item	2943055	et	4	main
see	doc_919500587382_item	2943058	et	3	main
ka	doc_919500587382_item	2943060	et	3	main
süsteem	doc_919500587382_item	2943067	et	3	main
ülikoolis	doc_919500587382_item	2943110	et	4	main
niimoodi	doc_919500587382_item	2943111	et	3	main
peaaegu	doc_919500587382_item	2943114	et	3	main
ja	doc_919500587382_item	2943116	et	3	main
mina	doc_919500587382_item	2943117	et	4	main
miks	doc_919500587382_item	2943121	et	4	main
tulla	doc_919500587382_item	2943133	et	3	main
sessi	doc_919500587382_item	2943136	et	4	main
ajal	doc_919500587382_item	2943137	et	4	main
ja	doc_919500587382_item	2943138	et	3	main
ka	doc_919500587382_item	2943151	et	3	main
olnud	doc_919500587382_item	2943155	et	4	main
kirjutad	doc_919500587382_item	2943173	et	3	main
võib-olla	doc_919500587382_item	2943179	et	3	main
kõige	doc_919500587382_item	2943184	et	4	main
oli	doc_919500587382_item	2943187	et	3	main
et	doc_919500587382_item	2943189	et	3	main
pinget	doc_919500587382_item	2943195	et	3	main
asi	doc_919500587382_item	2943211	et	4	main
on	doc_919500587382_item	2943230	et	4	main
suur	doc_919500587382_item	2943231	et	3	main
modernsust	doc_919500587382_item	2943239	et	4	main
usun	doc_919500587382_item	2943242	et	3	main
raamatukogu	doc_919500587382_item	2943249	et	4	main
õnnelik	doc_919500587382_item	2943253	et	3	main
võimalus	doc_919500587382_item	2943257	et	3	main
ülikoolis	doc_919500587382_item	2943259	et	4	main
süsteemi	doc_919500587382_item	2943262	et	4	main
näha	doc_919500587382_item	2943263	et	3	main
on	doc_919500587382_item	2942822	et	4	main
sipelgapesa	doc_919500587382_item	2942824	et	4	main
seal	doc_919500587382_item	2942833	et	4	main
kuigi	doc_919500587382_item	2942841	et	3	main
on	doc_919500587382_item	2942846	et	4	main
armsad	doc_919500587382_item	2942848	et	3	main
pean	doc_919500587382_item	2942849	et	4	main
ütlema	doc_919500587382_item	2942850	et	3	main
et	doc_919500587382_item	2942851	et	3	main
sarnasusi	doc_919500587382_item	2942855	et	4	main
arvan	doc_919500587382_item	2942858	et	3	main
on	doc_919500587382_item	2942868	et	4	main
sarnased	doc_919500587382_item	2942870	et	4	main
on	doc_919500587382_item	2942873	et	4	main
natuke	doc_919500587382_item	2942874	et	4	main
arad	doc_919500587382_item	2942875	et	3	main
aga	doc_919500587382_item	2942876	et	3	main
väga	doc_919500587382_item	2942877	et	3	main
rõõmsameelsed	doc_919500587382_item	2942878	et	3	main
ma	doc_919500587382_item	2942879	et	3	main
saan	doc_919500587382_item	2942880	et	4	main
ka	doc_919500587382_item	2942888	et	3	main
selle	doc_919500587382_item	2942894	et	4	main
et	doc_919500587382_item	2942905	et	3	main
suhted	doc_919500587382_item	2942907	et	3	main
õppejoududega	doc_919500587382_item	2942908	et	4	main
on	doc_919500587382_item	2942909	et	4	main
külmad	doc_919500587382_item	2942913	et	4	main
et	doc_919500587382_item	2942915	et	3	main
tartu	doc_919500587382_item	2942916	et	4	main
ülikoolis	doc_919500587382_item	2942917	et	4	main
nad	doc_919500587382_item	2942918	et	3	main
on	doc_919500587382_item	2942919	et	4	main
ainult	doc_919500587382_item	2942920	et	4	main
sõbralikud	doc_919500587382_item	2942923	et	3	main
asju	doc_919500587382_item	2942932	et	3	main
õnnestus	doc_919500587382_item	2942939	et	4	main
õnnestus	doc_919500587382_item	2942950	et	4	main
ma	doc_919500587382_item	2942953	et	3	main
olin	doc_919500587382_item	2942954	et	3	main
välismaalane	doc_919500587382_item	2942955	et	3	main
kes	doc_919500587382_item	2942956	et	4	main
teab	doc_919500587382_item	2942957	et	3	main
ma	doc_919500587382_item	2942958	et	3	main
avaldasid	doc_919500587382_item	2942966	et	4	main
asi	doc_919500587382_item	2942973	et	4	main
oli	doc_919500587382_item	2942980	et	3	main
sõbralikud	doc_919500587382_item	2942997	et	3	main
väga	doc_919500587382_item	2943008	et	3	main
sellest	doc_919500587382_item	2943011	et	4	main
missugune	doc_919500587382_item	2943012	et	3	main
inimene	doc_919500587382_item	2943013	et	3	main
sind	doc_919500587382_item	2943014	et	4	main
et	doc_919500587382_item	2943022	et	3	main
ainult	doc_919500587382_item	2943025	et	4	main
raamatuid	doc_919500587382_item	2943027	et	3	main
ka	doc_919500587382_item	2943029	et	3	main
töö	doc_919500587382_item	2943036	et	4	main
intensiivne	doc_919500587382_item	2943039	et	3	main
kõik	doc_919500587382_item	2943042	et	4	main
mõistuse	doc_919500587382_item	2943044	et	3	main
piiridel	doc_919500587382_item	2943045	et	3	main
kõige	doc_919500587382_item	2943046	et	4	main
oli	doc_919500587382_item	2943049	et	3	main
süsteem	doc_919500587382_item	2943052	et	3	main
võib-olla	doc_919500587382_item	2943053	et	3	main
üllatas	doc_919500587382_item	2943059	et	3	main
natuke	doc_919500587382_item	2943062	et	4	main
ka	doc_919500587382_item	2943065	et	3	main
teistsugune	doc_919500587382_item	2943070	et	3	main
saa	doc_919500587382_item	2943119	et	4	main
administratsioon	doc_919500587382_item	2943125	et	3	main
meeldib	doc_919500587382_item	2943132	et	3	main
igal	doc_919500587382_item	2943134	et	3	main
päeval	doc_919500587382_item	2943135	et	3	main
siis	doc_919500587382_item	2943139	et	3	main
ja	doc_919500587382_item	2942922	et	3	main
raske	doc_919500587382_item	2942926	et	4	main
sest	doc_919500587382_item	2942928	et	4	main
on	doc_919500587382_item	2942930	et	4	main
minu	doc_919500587382_item	2942935	et	3	main
mul	doc_919500587382_item	2942938	et	3	main
õpetasid	doc_919500587382_item	2942942	et	4	main
tõesti	doc_919500587382_item	2942943	et	3	main
võib-olla	doc_919500587382_item	2942948	et	3	main
ainult	doc_919500587382_item	2942960	et	4	main
öelda	doc_919500587382_item	2942961	et	4	main
ole	doc_919500587382_item	2942971	et	4	main
meeldis	doc_919500587382_item	2942976	et	3	main
on	doc_919500587382_item	2942990	et	4	main
see	doc_919500587382_item	2942991	et	3	main
et	doc_919500587382_item	2942992	et	3	main
et	doc_919500587382_item	2942998	et	3	main
olnud	doc_919500587382_item	2943000	et	4	main
vahel	doc_919500587382_item	2943006	et	4	main
palju	doc_919500587382_item	2943009	et	4	main
töö	doc_919500587382_item	2943016	et	4	main
huvitavam	doc_919500587382_item	2943018	et	4	main
ka	doc_919500587382_item	2943019	et	3	main
võib-olla	doc_919500587382_item	2943020	et	3	main
kasutati	doc_919500587382_item	2943023	et	4	main
mitte	doc_919500587382_item	2943024	et	3	main
oli	doc_919500587382_item	2943033	et	3	main
iseseisva	doc_919500587382_item	2943035	et	3	main
mõnikord	doc_919500587382_item	2943040	et	3	main
asi	doc_919500587382_item	2943048	et	4	main
eksamite-arvestuste	doc_919500587382_item	2943051	et	4	main
imestab	doc_919500587382_item	2943056	et	3	main
mind	doc_919500587382_item	2943061	et	4	main
ja	doc_919500587382_item	2943063	et	3	main
rõõmustas	doc_919500587382_item	2943064	et	3	main
väga	doc_919500587382_item	2943066	et	3	main
ja	doc_919500587382_item	2943071	et	3	main
see	doc_919500587382_item	2943072	et	3	main
see	doc_919500587382_item	2943104	et	3	main
on	doc_919500587382_item	2943105	et	4	main
nagu	doc_919500587382_item	2943106	et	3	main
paradiis	doc_919500587382_item	2943107	et	3	main
maal	doc_919500587382_item	2943108	et	4	main
on	doc_919500587382_item	2943113	et	4	main
aru	doc_919500587382_item	2943120	et	4	main
otsustada	doc_919500587382_item	2942927	et	3	main
et	doc_919500587382_item	2942929	et	3	main
millest	doc_919500587382_item	2942933	et	3	main
võib-olla	doc_919500587382_item	2942937	et	3	main
mind	doc_919500587382_item	2942941	et	4	main
soojad	doc_919500587382_item	2942944	et	3	main
sõbralikud	doc_919500587382_item	2942946	et	3	main
mul	doc_919500587382_item	2942949	et	3	main
sest	doc_919500587382_item	2942951	et	4	main
et	doc_919500587382_item	2942952	et	3	main
et	doc_919500587382_item	2942962	et	3	main
õppejõud	doc_919500587382_item	2942963	et	4	main
ja	doc_919500587382_item	2942964	et	3	main
kaasüliõpilased	doc_919500587382_item	2942965	et	3	main
ainuke	doc_919500587382_item	2942972	et	4	main
mõnikord	doc_919500587382_item	2942979	et	3	main
isegi	doc_919500587382_item	2942981	et	4	main
kui	doc_919500587382_item	2942983	et	3	main
leedus	doc_919500587382_item	2942984	et	4	main
ma	doc_919500587382_item	2942985	et	3	main
arvan	doc_919500587382_item	2942986	et	3	main
et	doc_919500587382_item	2942987	et	3	main
põhiline	doc_919500587382_item	2942988	et	3	main
rõõmsameelsed	doc_919500587382_item	2942996	et	3	main
ei	doc_919500587382_item	2942999	et	4	main
mingit	doc_919500587382_item	2943001	et	3	main
pinget	doc_919500587382_item	2943002	et	3	main
nende	doc_919500587382_item	2943003	et	4	main
ja	doc_919500587382_item	2943004	et	3	main
õpetab	doc_919500587382_item	2943015	et	3	main
jne	doc_919500587382_item	2943032	et	4	main
parem	doc_919500587382_item	2943047	et	4	main
aga	doc_919500587382_item	2943057	et	3	main
on	doc_919500587382_item	2943068	et	4	main
meeldis	doc_919500587382_item	2943073	et	3	main
mulle	doc_919500587382_item	2943074	et	4	main
tartus	doc_919500587382_item	2943075	et	3	main
kui	doc_919500587382_item	2943076	et	3	main
sa	doc_919500587382_item	2943077	et	3	main
tahad	doc_919500587382_item	2943078	et	3	main
ja	doc_919500587382_item	2943079	et	3	main
õppejõu	doc_919500587382_item	2943080	et	3	main
on	doc_919500587382_item	2943081	et	4	main
nõus	doc_919500587382_item	2943082	et	4	main
saad	doc_919500587382_item	2943083	et	4	main
eksamit	doc_919500587382_item	2943084	et	3	main
teha	doc_919500587382_item	2943085	et	3	main
enne	doc_919500587382_item	2943086	et	4	main
sessi	doc_919500587382_item	2943087	et	4	main
nt	doc_919500587382_item	2943088	et	4	main
viimasel	doc_919500587382_item	2943089	et	3	main
loengul	doc_919500587382_item	2943090	et	3	main
siis	doc_919500587382_item	2943091	et	3	main
sessi	doc_919500587382_item	2943092	et	4	main
ajal	doc_919500587382_item	2943093	et	4	main
sul	doc_919500587382_item	2943094	et	3	main
on	doc_919500587382_item	2943095	et	4	main
ainult	doc_919500587382_item	2943096	et	4	main
kaks	doc_919500587382_item	2943097	et	3	main
kolm	doc_919500587382_item	2943098	et	3	main
või	doc_919500587382_item	2943099	et	4	main
isegi	doc_919500587382_item	2943100	et	4	main
mitte	doc_919500587382_item	2943101	et	3	main
ühtegi	doc_919500587382_item	2943102	et	4	main
eksamit	doc_919500587382_item	2943103	et	3	main
vilniuse	doc_919500587382_item	2943109	et	4	main
ja	doc_919500587382_item	2943124	et	3	main
ei	doc_919500587382_item	2943126	et	4	main
ei	doc_919500587382_item	2943143	et	4	main
saa	doc_919500587382_item	2943144	et	4	main
ülikoolis	doc_919500587382_item	2943150	et	4	main
mitte	doc_919500587382_item	2943174	et	3	main
tundnud	doc_919500587382_item	2943194	et	4	main
erutatud	doc_919500587382_item	2943198	et	4	main
on	doc_919500587382_item	2943208	et	4	main
mind	doc_919500587382_item	2943215	et	4	main
isegi	doc_919500587382_item	2943216	et	4	main
üllatas	doc_919500587382_item	2943217	et	3	main
ka	doc_919500587382_item	2943218	et	3	main
see	doc_919500587382_item	2943221	et	3	main
suur	doc_919500587382_item	2943224	et	3	main
modernne	doc_919500587382_item	2943226	et	3	main
ülikooli	doc_919500587382_item	2943228	et	4	main
aga	doc_919500587382_item	2943235	et	3	main
modernne	doc_919500587382_item	2943238	et	3	main
et	doc_919500587382_item	2943243	et	3	main
modernne	doc_919500587382_item	2943248	et	3	main
olen	doc_919500587382_item	2943251	et	3	main
arvan	doc_919500587382_item	2943277	et	3	main
ilusat	doc_919500587382_item	2943281	et	3	main
ja	doc_919500587382_item	2943283	et	3	main
saab	doc_919500587382_item	2943322	et	3	main
vanast	doc_919500587382_item	2943334	et	3	main
vilniuse	doc_919500587382_item	2943335	et	4	main
tähendab	doc_919500587382_item	2943342	et	3	main
on	doc_919500587382_item	2943345	et	4	main
suur	doc_919500587382_item	2943346	et	3	main
ei	doc_919500587382_item	2943356	et	4	main
sellepärast	doc_919500587382_item	2943359	et	3	main
ta	doc_919500587382_item	2943360	et	4	main
ülikoolil	doc_919500587382_item	2943366	et	4	main
tartu	doc_919500587382_item	2943380	et	4	main
isegi	doc_919500587382_item	2943386	et	4	main
kas	doc_919500587382_item	2943122	et	3	main
neile	doc_919500587382_item	2943131	et	4	main
tartu	doc_919500587382_item	2943149	et	4	main
ei	doc_919500587382_item	2943154	et	4	main
vaja	doc_919500587382_item	2943156	et	4	main
kirjutada	doc_919500587382_item	2943157	et	3	main
traktaate	doc_919500587382_item	2943158	et	3	main
kirjutad	doc_919500587382_item	2943159	et	3	main
põhilisi	doc_919500587382_item	2943160	et	3	main
asju	doc_919500587382_item	2943161	et	3	main
viis	doc_919500587382_item	2943162	et	4	main
seitse	doc_919500587382_item	2943163	et	3	main
kümme	doc_919500587382_item	2943164	et	3	main
lauset	doc_919500587382_item	2943165	et	3	main
ja	doc_919500587382_item	2943166	et	3	main
kõik	doc_919500587382_item	2943167	et	4	main
tähtis	doc_919500587382_item	2943168	et	4	main
lugeda	doc_919500587382_item	2943140	et	3	main
sada	doc_919500587382_item	2943141	et	4	main
tööd	doc_919500587382_item	2943142	et	4	main
sellepärast	doc_919500587382_item	2943152	et	3	main
on	doc_919500587382_item	2943169	et	4	main
see	doc_919500587382_item	2943170	et	3	main
see	doc_919500587382_item	2943175	et	3	main
kui	doc_919500587382_item	2943176	et	3	main
aga	doc_919500587382_item	2943178	et	3	main
see	doc_919500587382_item	2943180	et	3	main
lektorist	doc_919500587382_item	2943183	et	3	main
parem	doc_919500587382_item	2943185	et	4	main
asi	doc_919500587382_item	2943186	et	4	main
ei	doc_919500587382_item	2943193	et	4	main
ainult	doc_919500587382_item	2943196	et	4	main
tartu	doc_919500587382_item	2943219	et	4	main
on	doc_919500587382_item	2943222	et	4	main
nii	doc_919500587382_item	2943223	et	3	main
ja	doc_919500587382_item	2943225	et	3	main
vilniuse	doc_919500587382_item	2943227	et	4	main
raamatukogu	doc_919500587382_item	2943229	et	4	main
puudub	doc_919500587382_item	2943240	et	3	main
sama	doc_919500587382_item	2943247	et	4	main
tartu	doc_919500587382_item	2943258	et	4	main
õppida	doc_919500587382_item	2943260	et	3	main
ei	doc_919500587382_item	2943270	et	4	main
aga	doc_919500587382_item	2943278	et	3	main
nägin	doc_919500587382_item	2943280	et	3	main
saan	doc_919500587382_item	2943284	et	4	main
öelda	doc_919500587382_item	2943285	et	4	main
et	doc_919500587382_item	2943286	et	3	main
olen	doc_919500587382_item	2943287	et	3	main
sellega	doc_919500587382_item	2943288	et	3	main
ülikool	doc_919500587382_item	2943331	et	4	main
saab	doc_919500587382_item	2943332	et	3	main
eeskuju	doc_919500587382_item	2943338	et	4	main
vana	doc_919500587382_item	2943341	et	4	main
et	doc_919500587382_item	2943343	et	3	main
ainult	doc_919500587382_item	2943351	et	4	main
vilniuse	doc_919500587382_item	2943365	et	4	main
lihtsalt	doc_919500587382_item	2943370	et	4	main
suurem	doc_919500587382_item	2943371	et	4	main
niisiis	doc_919500587382_item	2943373	et	3	main
mulje	doc_919500587382_item	2943377	et	4	main
suurepärane	doc_919500587382_item	2943387	et	4	main
ja	doc_919500587382_item	2943388	et	3	main
seal	doc_919500587382_item	2943424	et	4	main
õhkkond	doc_919500587382_item	2943428	et	3	main
mõnus	doc_919500587382_item	2943437	et	4	main
sa	doc_919500587382_item	2943172	et	3	main
palju	doc_919500587382_item	2943177	et	4	main
see	doc_919500587382_item	2943188	et	3	main
nt	doc_919500587382_item	2943190	et	4	main
mina	doc_919500587382_item	2943191	et	4	main
sest	doc_919500587382_item	2943206	et	4	main
eksam	doc_919500587382_item	2943207	et	3	main
ametlik	doc_919500587382_item	2943210	et	3	main
raamatukogu	doc_919500587382_item	2943220	et	4	main
ja	doc_919500587382_item	2943232	et	3	main
vana	doc_919500587382_item	2943233	et	4	main
ka	doc_919500587382_item	2943234	et	3	main
nii	doc_919500587382_item	2943237	et	3	main
aga	doc_919500587382_item	2943241	et	3	main
meil	doc_919500587382_item	2943245	et	4	main
tõesti	doc_919500587382_item	2943252	et	3	main
et	doc_919500587382_item	2943254	et	3	main
oli	doc_919500587382_item	2943256	et	3	main
teistsugust	doc_919500587382_item	2943261	et	3	main
seal	doc_919500587382_item	2943269	et	4	main
ma	doc_919500587382_item	2943276	et	3	main
head	doc_919500587382_item	2943295	et	4	main
vilniuse	doc_919500587382_item	2943296	et	4	main
ülikooli	doc_919500587382_item	2943297	et	4	main
poolt	doc_919500587382_item	2943298	et	4	main
ka	doc_919500587382_item	2943299	et	3	main
miinused	doc_919500587382_item	2943300	et	3	main
ei	doc_919500587382_item	2943301	et	4	main
ole	doc_919500587382_item	2943302	et	4	main
halb	doc_919500587382_item	2943303	et	3	main
asi	doc_919500587382_item	2943304	et	4	main
need	doc_919500587382_item	2943305	et	3	main
on	doc_919500587382_item	2943306	et	4	main
see	doc_919500587382_item	2943307	et	3	main
mis	doc_919500587382_item	2943308	et	4	main
ergutab	doc_919500587382_item	2943309	et	3	main
muutusi	doc_919500587382_item	2943310	et	4	main
teha	doc_919500587382_item	2943311	et	3	main
ma	doc_919500587382_item	2943312	et	3	main
arvan	doc_919500587382_item	2943313	et	3	main
et	doc_919500587382_item	2943314	et	3	main
on	doc_919500587382_item	2943315	et	4	main
päris	doc_919500587382_item	2943316	et	4	main
asju	doc_919500587382_item	2943318	et	3	main
palju	doc_919500587382_item	2943317	et	4	main
mida	doc_919500587382_item	2943319	et	4	main
vilniuse	doc_919500587382_item	2943320	et	4	main
omandada	doc_919500587382_item	2943325	et	3	main
tartu	doc_919500587382_item	2943330	et	4	main
mingit	doc_919500587382_item	2943337	et	3	main
võtma	doc_919500587382_item	2943339	et	3	main
on	doc_919500587382_item	2943350	et	4	main
parem	doc_919500587382_item	2943362	et	4	main
aga	doc_919500587382_item	2943363	et	3	main
võib-olla	doc_919500587382_item	2943364	et	3	main
alal	doc_919500587382_item	2943369	et	4	main
saan	doc_919500587382_item	2943374	et	4	main
ülikoolis	doc_919500587382_item	2943381	et	4	main
on	doc_919500587382_item	2943382	et	4	main
tõesti	doc_919500587382_item	2943383	et	3	main
elada	doc_919500587382_item	2943422	et	3	main
lihtsalt	doc_919500587382_item	2943436	et	4	main
varsti	doc_919500587382_item	2943244	et	3	main
on	doc_919500587382_item	2943246	et	4	main
niisiis	doc_919500587382_item	2943250	et	3	main
mul	doc_919500587382_item	2943255	et	3	main
ole	doc_919500587382_item	2943271	et	4	main
kõik	doc_919500587382_item	2943272	et	4	main
nii	doc_919500587382_item	2943273	et	3	main
ma	doc_919500587382_item	2943279	et	3	main
rahul	doc_919500587382_item	2943289	et	4	main
ma	doc_919500587382_item	2943290	et	3	main
loodan	doc_919500587382_item	2943291	et	3	main
et	doc_919500587382_item	2943292	et	3	main
välismaalased	doc_919500587382_item	2943293	et	3	main
näevad	doc_919500587382_item	2943294	et	3	main
uute	doc_919500587382_item	2943264	et	3	main
inimestega	doc_919500587382_item	2943265	et	3	main
tutvuda	doc_919500587382_item	2943266	et	3	main
tean	doc_919500587382_item	2943267	et	3	main
et	doc_919500587382_item	2943268	et	3	main
ilus	doc_919500587382_item	2943274	et	4	main
nagu	doc_919500587382_item	2943275	et	3	main
poolt	doc_919500587382_item	2943282	et	4	main
ülikool	doc_919500587382_item	2943321	et	4	main
tartu	doc_919500587382_item	2943323	et	4	main
ülikoolist	doc_919500587382_item	2943324	et	4	main
aga	doc_919500587382_item	2943326	et	3	main
usun	doc_919500587382_item	2943327	et	3	main
ka	doc_919500587382_item	2943328	et	3	main
et	doc_919500587382_item	2943329	et	3	main
ülikoolist	doc_919500587382_item	2943336	et	4	main
ju	doc_919500587382_item	2943340	et	3	main
tal	doc_919500587382_item	2943344	et	3	main
vilniuse	doc_919500587382_item	2943348	et	4	main
ülikool	doc_919500587382_item	2943349	et	4	main
see	doc_919500587382_item	2943355	et	3	main
et	doc_919500587382_item	2943358	et	3	main
on	doc_919500587382_item	2943367	et	4	main
kogemus	doc_919500587382_item	2943372	et	3	main
sest	doc_919500587382_item	2943423	et	4	main
natuke	doc_919500587382_item	2943426	et	4	main
teine	doc_919500587382_item	2943429	et	3	main
elada	doc_919500587382_item	2943438	et	3	main
ma	doc_919500587384_item	2943685	et	3	main
ma	doc_919500587384_item	2943692	et	3	main
okupatsioonist	doc_919500587384_item	2943695	et	3	main
see	doc_919500587384_item	2943701	et	3	main
nii	doc_919500587384_item	2943721	et	3	main
põhimõtteliselt	doc_919500587384_item	2943725	et	4	main
ma	doc_919500587384_item	2943726	et	3	main
olin	doc_919500587384_item	2943727	et	3	main
väga	doc_919500587384_item	2943728	et	3	main
rõõm	doc_919500587384_item	2943729	et	3	main
et	doc_919500587384_item	2943730	et	3	main
ma	doc_919500587384_item	2943731	et	3	main
käisin	doc_919500587384_item	2943732	et	3	main
kui	doc_919500587384_item	2943735	et	3	main
olin	doc_919500587384_item	2943737	et	3	main
sõitan	doc_919500587384_item	2943745	et	4	main
tahtsin	doc_919500587384_item	2943749	et	3	main
elada	doc_919500587384_item	2943750	et	3	main
selle	doc_919500587384_item	2943751	et	4	main
ka	doc_919500587382_item	2943333	et	3	main
kogemus	doc_919500587382_item	2943347	et	3	main
natuke	doc_919500587382_item	2943352	et	4	main
vanem	doc_919500587382_item	2943353	et	4	main
ja	doc_919500587382_item	2943354	et	3	main
tähenda	doc_919500587382_item	2943357	et	4	main
on	doc_919500587382_item	2943361	et	4	main
mingil	doc_919500587382_item	2943368	et	4	main
öelda	doc_919500587382_item	2943375	et	4	main
et	doc_919500587382_item	2943376	et	3	main
pärast	doc_919500587382_item	2943378	et	4	main
õppimist	doc_919500587382_item	2943379	et	4	main
hea	doc_919500587382_item	2943384	et	4	main
või	doc_919500587382_item	2943385	et	4	main
mina	doc_919500587382_item	2943389	et	4	main
tõesti	doc_919500587382_item	2943390	et	3	main
tahaks	doc_919500587382_item	2943391	et	3	main
veel	doc_919500587382_item	2943392	et	4	main
kord	doc_919500587382_item	2943393	et	4	main
seal	doc_919500587382_item	2943394	et	4	main
õppima	doc_919500587382_item	2943395	et	3	main
minema	doc_919500587382_item	2943396	et	3	main
minu	doc_919500587382_item	2943397	et	3	main
meelest	doc_919500587382_item	2943398	et	4	main
see	doc_919500587382_item	2943399	et	3	main
oli	doc_919500587382_item	2943400	et	3	main
tõesti	doc_919500587382_item	2943401	et	3	main
hea	doc_919500587382_item	2943402	et	4	main
ja	doc_919500587382_item	2943403	et	3	main
meeldiv	doc_919500587382_item	2943404	et	4	main
kogemus	doc_919500587382_item	2943405	et	3	main
see	doc_919500587382_item	2943406	et	3	main
pool	doc_919500587382_item	2943407	et	4	main
aastat	doc_919500587382_item	2943408	et	3	main
jääb	doc_919500587382_item	2943409	et	3	main
meelde	doc_919500587382_item	2943410	et	3	main
loodan	doc_919500587382_item	2943411	et	3	main
et	doc_919500587382_item	2943412	et	3	main
kunagi	doc_919500587382_item	2943413	et	3	main
veel	doc_919500587382_item	2943414	et	4	main
saan	doc_919500587382_item	2943415	et	4	main
võimalust	doc_919500587382_item	2943416	et	3	main
seal	doc_919500587382_item	2943417	et	4	main
õppida	doc_919500587382_item	2943418	et	3	main
või	doc_919500587382_item	2943419	et	4	main
lihtsalt	doc_919500587382_item	2943420	et	4	main
natuke	doc_919500587382_item	2943421	et	4	main
on	doc_919500587382_item	2943425	et	4	main
teistsugune	doc_919500587382_item	2943427	et	3	main
võõras	doc_919500587382_item	2943430	et	4	main
keel	doc_919500587382_item	2943431	et	4	main
on	doc_919500587382_item	2943435	et	4	main
teistsugused	doc_919500587382_item	2943432	et	3	main
inimesed	doc_919500587382_item	2943433	et	3	main
tartus	doc_919500587382_item	2943434	et	3	main
mina	doc_919500587384_item	2943678	et	4	main
eestist	doc_919500587384_item	2943691	et	3	main
kus	doc_919500587384_item	2943697	et	3	main
oli	doc_919500587384_item	2943702	et	3	main
ei	doc_919500587384_item	2943706	et	4	main
eesti	doc_919500587384_item	2943708	et	4	main
lahti	doc_919500587384_item	2943723	et	4	main
on	doc_919500587384_item	2943724	et	4	main
eelmisel	doc_919500587384_item	2943739	et	3	main
ma	doc_919500587384_item	2943741	et	3	main
miks	doc_919500587384_item	2943743	et	4	main
eestimaale	doc_919500587384_item	2943746	et	4	main
ma	doc_919500587384_item	2943748	et	3	main
ma	doc_919500587384_item	2943753	et	3	main
jõudsin	doc_919500587384_item	2943754	et	3	main
kahekümnendal	doc_919500587384_item	2943755	et	4	main
juulil	doc_919500587384_item	2943756	et	3	main
ma	doc_919500587384_item	2943757	et	3	main
olin	doc_919500587384_item	2943758	et	3	main
oma	doc_919500587384_item	2943759	et	4	main
isaga	doc_919500587384_item	2943760	et	3	main
viis	doc_919500587384_item	2943766	et	4	main
päeva	doc_919500587384_item	2943767	et	4	main
see	doc_919500587384_item	2943768	et	3	main
aeg	doc_919500587384_item	2943769	et	3	main
oli	doc_919500587384_item	2943770	et	3	main
tore	doc_919500587384_item	2943771	et	3	main
üliõpilaste	doc_919500587384_item	2943782	et	4	main
suvel	doc_919500587384_item	2943788	et	3	main
tallinnas	doc_919500587384_item	2943793	et	4	main
ma	doc_919500587384_item	2943794	et	3	main
jään	doc_919500587384_item	2943795	et	3	main
rahule	doc_919500587384_item	2943796	et	4	main
saaremaal	doc_919500587384_item	2943800	et	4	main
narvas	doc_919500587384_item	2943802	et	4	main
ei	doc_919500587384_item	2943804	et	4	main
tegin	doc_919500587384_item	2943823	et	3	main
visakad	doc_919500587384_item	2943829	et	4	main
tähandab	doc_919500587384_item	2943831	et	4	main
et	doc_919500587384_item	2943832	et	3	main
essee	doc_919500587384_item	2943677	et	4	main
eesti	doc_919500587384_item	2943680	et	4	main
hispaanias	doc_919500587384_item	2943684	et	4	main
midagi	doc_919500587384_item	2943690	et	4	main
eesti	doc_919500587384_item	2943698	et	4	main
asub	doc_919500587384_item	2943699	et	3	main
aga	doc_919500587384_item	2943700	et	3	main
kõik	doc_919500587384_item	2943703	et	4	main
osknud	doc_919500587384_item	2943707	et	4	main
siis	doc_919500587384_item	2943733	et	3	main
randas	doc_919500587384_item	2943738	et	4	main
päeval	doc_919500587384_item	2943740	et	3	main
arvasin	doc_919500587384_item	2943742	et	3	main
ma	doc_919500587384_item	2943744	et	3	main
ja	doc_919500587384_item	2943761	et	3	main
olime	doc_919500587384_item	2943763	et	3	main
siin	doc_919500587384_item	2943764	et	4	main
kohtusin	doc_919500587384_item	2943775	et	4	main
eesnimi	doc_919500587384_item	2943776	et	3	main
eesnimi	doc_919500587384_item	2943778	et	3	main
koos	doc_919500587384_item	2943781	et	4	main
ühiselamus	doc_919500587384_item	2943783	et	4	main
karu	doc_919500587384_item	2943784	et	4	main
eesti	doc_919500587384_item	2943791	et	4	main
mitu	doc_919500587384_item	2943825	et	4	main
mulle	doc_919500587384_item	2943838	et	4	main
ja	doc_919500587384_item	2943841	et	3	main
ma	doc_919500587384_item	2943842	et	3	main
aega	doc_919500587384_item	2943845	et	4	main
mitu	doc_919500587384_item	2943850	et	4	main
on	doc_919500587384_item	2943853	et	4	main
minu	doc_919500587384_item	2943859	et	3	main
eestis	doc_919500587384_item	2943861	et	3	main
ma	doc_919500587384_item	2943862	et	3	main
me	doc_919500587384_item	2943888	et	4	main
tantsisime	doc_919500587384_item	2943890	et	3	main
me	doc_919500587384_item	2943900	et	4	main
käisime	doc_919500587384_item	2943901	et	3	main
restoranis	doc_919500587384_item	2943902	et	3	main
sõbrad	doc_919500587384_item	2943906	et	3	main
erilist	doc_919500587384_item	2943910	et	4	main
kell	doc_919500587384_item	2943912	et	3	main
mitte	doc_919500587384_item	2943689	et	3	main
ma	doc_919500587384_item	2943705	et	3	main
ja	doc_919500587384_item	2943679	et	3	main
kui	doc_919500587384_item	2943681	et	3	main
ma	doc_919500587384_item	2943682	et	3	main
olin	doc_919500587384_item	2943683	et	3	main
ei	doc_919500587384_item	2943686	et	4	main
teadnud	doc_919500587384_item	2943687	et	4	main
peaaegu	doc_919500587384_item	2943688	et	3	main
tundis	doc_919500587384_item	2943693	et	3	main
muidugi	doc_919500587384_item	2943694	et	4	main
ja	doc_919500587384_item	2943696	et	3	main
muidugi	doc_919500587384_item	2943704	et	4	main
keelt	doc_919500587384_item	2943709	et	4	main
ja	doc_919500587384_item	2943710	et	3	main
ma	doc_919500587384_item	2943711	et	3	main
sain	doc_919500587384_item	2943713	et	3	main
aru	doc_919500587384_item	2943714	et	4	main
ei	doc_919500587384_item	2943712	et	4	main
kui	doc_919500587384_item	2943715	et	3	main
eestlased	doc_919500587384_item	2943716	et	3	main
räägisid	doc_919500587384_item	2943717	et	4	main
ma	doc_919500587384_item	2943718	et	3	main
olin	doc_919500587384_item	2943719	et	3	main
alati	doc_919500587384_item	2943720	et	4	main
mis	doc_919500587384_item	2943722	et	4	main
loomulikult	doc_919500587384_item	2943747	et	4	main
järgemisel	doc_919500587384_item	2943772	et	4	main
päeval	doc_919500587384_item	2943773	et	3	main
ma	doc_919500587384_item	2943774	et	3	main
elasime	doc_919500587384_item	2943780	et	3	main
vedas	doc_919500587384_item	2943787	et	4	main
me	doc_919500587384_item	2943789	et	4	main
õpisime	doc_919500587384_item	2943790	et	4	main
sellega	doc_919500587384_item	2943797	et	3	main
ma	doc_919500587384_item	2943822	et	3	main
avastust	doc_919500587384_item	2943824	et	4	main
ei	doc_919500587384_item	2943826	et	4	main
ole	doc_919500587384_item	2943827	et	4	main
nii	doc_919500587384_item	2943828	et	3	main
reisidele	doc_919500587384_item	2943847	et	3	main
samuti	doc_919500587384_item	2943854	et	3	main
kaunis	doc_919500587384_item	2943855	et	4	main
natukene	doc_919500587384_item	2943864	et	4	main
käisid	doc_919500587384_item	2943884	et	4	main
külas	doc_919500587384_item	2943885	et	3	main
sõime	doc_919500587384_item	2943889	et	4	main
õhtul	doc_919500587384_item	2943891	et	3	main
me	doc_919500587384_item	2943892	et	4	main
ostsime	doc_919500587384_item	2943893	et	3	main
alkoholi	doc_919500587384_item	2943894	et	4	main
ja	doc_919500587384_item	2943895	et	3	main
jõime	doc_919500587384_item	2943896	et	3	main
koha	doc_919500587384_item	2943916	et	4	main
ja	doc_919500587384_item	2943917	et	3	main
kilpkoonasuppi	doc_919500587384_item	2943922	et	4	main
ometi	doc_919500587384_item	2943734	et	3	main
ma	doc_919500587384_item	2943736	et	3	main
hotellis	doc_919500587384_item	2943765	et	3	main
ja	doc_919500587384_item	2943777	et	3	main
tänaval	doc_919500587384_item	2943785	et	4	main
mul	doc_919500587384_item	2943786	et	3	main
keelt	doc_919500587384_item	2943792	et	4	main
me	doc_919500587384_item	2943798	et	4	main
mis	doc_919500587384_item	2943806	et	4	main
ma	doc_919500587384_item	2943807	et	3	main
pean	doc_919500587384_item	2943808	et	4	main
rääkida	doc_919500587384_item	2943809	et	3	main
rahvast	doc_919500587384_item	2943810	et	4	main
põhimõtteliselt	doc_919500587384_item	2943811	et	4	main
ma	doc_919500587384_item	2943812	et	3	main
mõtlesin	doc_919500587384_item	2943813	et	3	main
et	doc_919500587384_item	2943814	et	3	main
nad	doc_919500587384_item	2943815	et	3	main
oli	doc_919500587384_item	2943816	et	3	main
lahkesed	doc_919500587384_item	2943817	et	4	main
lõbused	doc_919500587384_item	2943818	et	3	main
ja	doc_919500587384_item	2943819	et	3	main
jutukad	doc_919500587384_item	2943820	et	3	main
inimestega	doc_919500587384_item	2943752	et	3	main
me	doc_919500587384_item	2943762	et	4	main
me	doc_919500587384_item	2943779	et	4	main
olime	doc_919500587384_item	2943799	et	3	main
tartus	doc_919500587384_item	2943801	et	3	main
ma	doc_919500587384_item	2943803	et	3	main
tea	doc_919500587384_item	2943805	et	4	main
hiljem	doc_919500587384_item	2943821	et	3	main
see	doc_919500587384_item	2943830	et	3	main
mul	doc_919500587384_item	2943833	et	3	main
olid	doc_919500587384_item	2943834	et	4	main
probleemid	doc_919500587384_item	2943835	et	3	main
siin	doc_919500587384_item	2943836	et	4	main
armastan	doc_919500587384_item	2943843	et	3	main
siin	doc_919500587384_item	2943846	et	4	main
mina	doc_919500587384_item	2943857	et	4	main
sünnipäeva	doc_919500587384_item	2943860	et	4	main
olin	doc_919500587384_item	2943863	et	3	main
me	doc_919500587384_item	2943886	et	4	main
jõime	doc_919500587384_item	2943887	et	3	main
minu	doc_919500587384_item	2943903	et	3	main
sugulased	doc_919500587384_item	2943904	et	3	main
ja	doc_919500587384_item	2943905	et	3	main
ettekandja	doc_919500587384_item	2943914	et	4	main
tuli	doc_919500587384_item	2943915	et	4	main
tellisin	doc_919500587384_item	2943921	et	3	main
ja	doc_919500587384_item	2943923	et	3	main
ei	doc_919500587384_item	2943931	et	4	main
seda	doc_919500587384_item	2943934	et	3	main
läksime	doc_919500587384_item	2943936	et	3	main
sünnipäeval	doc_919500587384_item	2943939	et	3	main
räägisid	doc_919500587384_item	2943943	et	4	main
palju	doc_919500587384_item	2943944	et	4	main
rõõm	doc_919500587384_item	2943949	et	3	main
olla	doc_919500587384_item	2943951	et	3	main
üsna	doc_919500587384_item	2943956	et	3	main
olen	doc_919500587384_item	2943959	et	3	main
oleks	doc_919500587384_item	2943962	et	3	main
minu	doc_919500587384_item	2943965	et	3	main
seiklus	doc_919500587384_item	2943966	et	3	main
lõpetaks	doc_919500587384_item	2943967	et	4	main
meeldib	doc_919500587384_item	2943839	et	3	main
tallinn	doc_919500587384_item	2943840	et	4	main
ma	doc_919500587384_item	2943848	et	3	main
tuttvusin	doc_919500587384_item	2943849	et	4	main
inimest	doc_919500587384_item	2943851	et	3	main
see	doc_919500587384_item	2943852	et	3	main
korraldasin	doc_919500587384_item	2943858	et	3	main
kurb	doc_919500587384_item	2943865	et	3	main
sest	doc_919500587384_item	2943866	et	4	main
ma	doc_919500587384_item	2943867	et	3	main
ei	doc_919500587384_item	2943868	et	4	main
olnud	doc_919500587384_item	2943869	et	4	main
kodulinnas	doc_919500587384_item	2943870	et	4	main
terve	doc_919500587384_item	2943871	et	4	main
perega	doc_919500587384_item	2943872	et	3	main
ma	doc_919500587384_item	2943873	et	3	main
ei	doc_919500587384_item	2943874	et	4	main
soovinud	doc_919500587384_item	2943875	et	4	main
mitte	doc_919500587384_item	2943876	et	3	main
pidu	doc_919500587384_item	2943877	et	4	main
vaid	doc_919500587384_item	2943878	et	3	main
kingitust	doc_919500587384_item	2943879	et	4	main
aga	doc_919500587384_item	2943880	et	3	main
hiljem	doc_919500587384_item	2943881	et	3	main
mu	doc_919500587384_item	2943882	et	3	main
sõbrad	doc_919500587384_item	2943883	et	3	main
siiski	doc_919500587384_item	2943837	et	4	main
seda	doc_919500587384_item	2943844	et	3	main
küll	doc_919500587384_item	2943856	et	4	main
väljas	doc_919500587384_item	2943897	et	4	main
mulle	doc_919500587384_item	2943908	et	4	main
üheksa	doc_919500587384_item	2943913	et	4	main
tellisime	doc_919500587384_item	2943919	et	4	main
ma	doc_919500587384_item	2943920	et	3	main
sest	doc_919500587384_item	2943929	et	4	main
pärast	doc_919500587384_item	2943933	et	4	main
kinno	doc_919500587384_item	2943937	et	3	main
eesnimi	doc_919500587384_item	2943940	et	3	main
eesnimi	doc_919500587384_item	2943942	et	3	main
väike	doc_919500587384_item	2943948	et	4	main
päevas	doc_919500587384_item	2943953	et	3	main
mina	doc_919500587386_item	2944214	et	4	main
ja	doc_919500587386_item	2944215	et	3	main
tulin	doc_919500587386_item	2944222	et	3	main
ülikoolis	doc_919500587386_item	2944225	et	4	main
ma	doc_919500587386_item	2944226	et	3	main
pärast	doc_919500587386_item	2944235	et	4	main
aega	doc_919500587386_item	2944240	et	4	main
ka	doc_919500587386_item	2944255	et	3	main
teda	doc_919500587386_item	2944262	et	4	main
linnu	doc_919500587386_item	2944286	et	4	main
tahan	doc_919500587386_item	2944290	et	3	main
kohtata	doc_919500587386_item	2944314	et	4	main
neljakümnendal	doc_919500587384_item	2943898	et	4	main
veebruaril	doc_919500587384_item	2943899	et	3	main
andsid	doc_919500587384_item	2943907	et	4	main
üht	doc_919500587384_item	2943909	et	3	main
kingitust	doc_919500587384_item	2943911	et	4	main
me	doc_919500587384_item	2943918	et	4	main
meeldi	doc_919500587384_item	2943932	et	4	main
me	doc_919500587384_item	2943935	et	4	main
minu	doc_919500587384_item	2943938	et	3	main
ja	doc_919500587384_item	2943941	et	3	main
mulle	doc_919500587384_item	2943954	et	4	main
rõõmus	doc_919500587384_item	2943960	et	4	main
kurb	doc_919500587384_item	2943963	et	3	main
ei	doc_919500587384_item	2943926	et	4	main
sünnipäevaks	doc_919500587384_item	2943946	et	3	main
las	doc_919500587384_item	2943950	et	4	main
siiani	doc_919500587384_item	2943957	et	4	main
ma	doc_919500587384_item	2943958	et	3	main
ma	doc_919500587384_item	2943961	et	3	main
kui	doc_919500587384_item	2943964	et	3	main
eestis	doc_919500587386_item	2944219	et	3	main
tallinna	doc_919500587386_item	2944224	et	4	main
hakkasin	doc_919500587386_item	2944227	et	3	main
eesti	doc_919500587386_item	2944229	et	4	main
keelt	doc_919500587386_item	2944230	et	4	main
oli	doc_919500587386_item	2944231	et	3	main
väga	doc_919500587386_item	2944232	et	3	main
olnud	doc_919500587386_item	2944237	et	4	main
mõnikord	doc_919500587386_item	2944242	et	3	main
sõbraga	doc_919500587386_item	2944246	et	3	main
vanalinnas	doc_919500587386_item	2944248	et	4	main
aga	doc_919500587386_item	2944249	et	3	main
mulle	doc_919500587386_item	2944250	et	4	main
meeldib	doc_919500587386_item	2944251	et	3	main
meeldib	doc_919500587386_item	2944257	et	3	main
aga	doc_919500587386_item	2944259	et	3	main
ma	doc_919500587386_item	2944289	et	3	main
külastada	doc_919500587386_item	2944291	et	3	main
kui	doc_919500587386_item	2944293	et	3	main
ilm	doc_919500587386_item	2944294	et	3	main
on	doc_919500587386_item	2944295	et	4	main
hea	doc_919500587386_item	2944296	et	4	main
me	doc_919500587386_item	2944297	et	4	main
võtame	doc_919500587386_item	2944298	et	3	main
seljakotid	doc_919500587386_item	2944299	et	3	main
ja	doc_919500587386_item	2944300	et	3	main
sõidame	doc_919500587386_item	2944301	et	3	main
õunamahla	doc_919500587384_item	2943924	et	4	main
ma	doc_919500587384_item	2943925	et	3	main
tellnud	doc_919500587384_item	2943927	et	4	main
magustoidu	doc_919500587384_item	2943928	et	3	main
mulle	doc_919500587384_item	2943930	et	4	main
õnne	doc_919500587384_item	2943945	et	4	main
üks	doc_919500587384_item	2943947	et	3	main
igas	doc_919500587384_item	2943952	et	3	main
meeldis	doc_919500587384_item	2943955	et	3	main
eesti	doc_919500587386_item	2944216	et	4	main
ma	doc_919500587386_item	2944217	et	3	main
käin	doc_919500587386_item	2944218	et	3	main
raskelt	doc_919500587386_item	2944233	et	4	main
selle	doc_919500587386_item	2944234	et	4	main
vaba	doc_919500587386_item	2944239	et	4	main
me	doc_919500587386_item	2944243	et	4	main
mulle	doc_919500587386_item	2944256	et	4	main
ei	doc_919500587386_item	2944260	et	4	main
olnud	doc_919500587386_item	2944261	et	4	main
vaatanud	doc_919500587386_item	2944284	et	4	main
aga	doc_919500587386_item	2944288	et	3	main
palju	doc_919500587386_item	2944319	et	4	main
mina	doc_919500587387_item	2944325	et	4	main
eestil	doc_919500587387_item	2944330	et	3	main
hea	doc_919500587387_item	2944332	et	4	main
õpetaja	doc_919500587387_item	2944353	et	4	main
ma	doc_919500587387_item	2944354	et	3	main
õpetasin	doc_919500587387_item	2944355	et	3	main
keelt	doc_919500587387_item	2944359	et	4	main
ei	doc_919500587387_item	2944371	et	4	main
iial	doc_919500587387_item	2944372	et	3	main
see	doc_919500587387_item	2944373	et	3	main
on	doc_919500587387_item	2944374	et	4	main
eesti	doc_919500587387_item	2944377	et	4	main
vähem	doc_919500587387_item	2944381	et	4	main
head	doc_919500587387_item	2944392	et	4	main
mõned	doc_919500587387_item	2944404	et	3	main
essee	doc_919500587386_item	2944213	et	4	main
sügisel	doc_919500587386_item	2944220	et	3	main
ma	doc_919500587386_item	2944221	et	3	main
õppima	doc_919500587386_item	2944223	et	3	main
õppima	doc_919500587386_item	2944228	et	3	main
ei	doc_919500587386_item	2944236	et	4	main
aga	doc_919500587386_item	2944241	et	3	main
oma	doc_919500587386_item	2944245	et	4	main
jaalutasime	doc_919500587386_item	2944247	et	4	main
ääres	doc_919500587386_item	2944254	et	4	main
merd	doc_919500587386_item	2944258	et	3	main
eestis	doc_919500587386_item	2944287	et	3	main
pärnusse	doc_919500587386_item	2944304	et	4	main
tallinna	doc_919500587386_item	2944322	et	4	main
essee	doc_919500587387_item	2944324	et	4	main
on	doc_919500587387_item	2944341	et	4	main
head	doc_919500587387_item	2944343	et	4	main
kogemusi	doc_919500587387_item	2944344	et	3	main
siin	doc_919500587387_item	2944345	et	4	main
minu	doc_919500587387_item	2944346	et	3	main
esimesel	doc_919500587387_item	2944347	et	3	main
enne	doc_919500587387_item	2944363	et	4	main
kui	doc_919500587387_item	2944364	et	3	main
ma	doc_919500587387_item	2944365	et	3	main
eestis	doc_919500587387_item	2944366	et	3	main
õpetasin	doc_919500587387_item	2944367	et	3	main
ma	doc_919500587387_item	2944368	et	3	main
ei	doc_919500587387_item	2944369	et	4	main
töö	doc_919500587387_item	2944376	et	4	main
on	doc_919500587387_item	2944379	et	4	main
õpilased	doc_919500587387_item	2944384	et	3	main
õpetajad	doc_919500587387_item	2944393	et	4	main
et	doc_919500587387_item	2944407	et	3	main
lasnamäe	doc_919500587387_item	2944408	et	3	main
inetu	doc_919500587387_item	2944412	et	4	main
aga	doc_919500587387_item	2944413	et	3	main
see	doc_919500587387_item	2944414	et	3	main
on	doc_919500587387_item	2944415	et	4	main
väga	doc_919500587387_item	2944416	et	3	main
tüüpiline	doc_919500587387_item	2944417	et	3	main
huvitav	doc_919500587387_item	2944429	et	4	main
see	doc_919500587387_item	2944430	et	3	main
on	doc_919500587387_item	2944432	et	4	main
olukord	doc_919500587387_item	2944433	et	3	main
erinev	doc_919500587387_item	2944434	et	4	main
huvitav	doc_919500587387_item	2944439	et	4	main
aga	doc_919500587387_item	2944440	et	3	main
ma	doc_919500587387_item	2944441	et	3	main
töötan	doc_919500587387_item	2944442	et	3	main
ja	doc_919500587387_item	2944443	et	3	main
õpin	doc_919500587387_item	2944444	et	3	main
järgmine	doc_919500587387_item	2944455	et	3	main
ma	doc_919500587387_item	2944460	et	3	main
liiga	doc_919500587387_item	2944482	et	4	main
tüdrukult	doc_919500587387_item	2944497	et	3	main
palju	doc_919500587386_item	2944238	et	4	main
ma	doc_919500587386_item	2944244	et	3	main
jaalutada	doc_919500587386_item	2944252	et	4	main
mere	doc_919500587386_item	2944253	et	3	main
minu	doc_919500587386_item	2944263	et	3	main
kodulinnas	doc_919500587386_item	2944264	et	4	main
siis	doc_919500587386_item	2944265	et	3	main
ma	doc_919500587386_item	2944266	et	3	main
uude	doc_919500587386_item	2944267	et	3	main
korterisse	doc_919500587386_item	2944268	et	3	main
kolisin	doc_919500587386_item	2944269	et	3	main
sain	doc_919500587386_item	2944270	et	3	main
tööd	doc_919500587386_item	2944271	et	4	main
mul	doc_919500587386_item	2944273	et	3	main
ja	doc_919500587386_item	2944272	et	3	main
ei	doc_919500587386_item	2944274	et	4	main
olnud	doc_919500587386_item	2944275	et	4	main
vaba	doc_919500587386_item	2944276	et	4	main
aega	doc_919500587386_item	2944277	et	4	main
uuesti	doc_919500587386_item	2944278	et	3	main
ma	doc_919500587386_item	2944279	et	3	main
elan	doc_919500587386_item	2944280	et	3	main
tallinnas	doc_919500587386_item	2944281	et	4	main
ja	doc_919500587386_item	2944282	et	3	main
ei	doc_919500587386_item	2944283	et	4	main
teisi	doc_919500587386_item	2944285	et	4	main
neid	doc_919500587386_item	2944292	et	4	main
siis	doc_919500587386_item	2944305	et	3	main
järvele	doc_919500587386_item	2944307	et	4	main
saaremaale	doc_919500587386_item	2944308	et	4	main
ma	doc_919500587386_item	2944309	et	3	main
tahaks	doc_919500587386_item	2944310	et	3	main
teada	doc_919500587386_item	2944311	et	3	main
rohkem	doc_919500587386_item	2944312	et	4	main
eestist	doc_919500587386_item	2944313	et	3	main
palju	doc_919500587386_item	2944320	et	4	main
ja	doc_919500587387_item	2944326	et	3	main
minul	doc_919500587387_item	2944328	et	3	main
aastal	doc_919500587387_item	2944348	et	3	main
eestis	doc_919500587387_item	2944349	et	3	main
olin	doc_919500587387_item	2944350	et	3	main
ma	doc_919500587387_item	2944351	et	3	main
ainult	doc_919500587387_item	2944352	et	4	main
inglise	doc_919500587387_item	2944358	et	4	main
koolis	doc_919500587387_item	2944361	et	4	main
õpilased	doc_919500587387_item	2944378	et	3	main
õpilased	doc_919500587387_item	2944386	et	3	main
äärmiselt	doc_919500587387_item	2944388	et	4	main
vajavad	doc_919500587387_item	2944391	et	4	main
õppi	doc_919500587387_item	2944398	et	4	main
esimesel	doc_919500587387_item	2944399	et	3	main
aastal	doc_919500587387_item	2944400	et	3	main
ma	doc_919500587387_item	2944401	et	3	main
elasin	doc_919500587387_item	2944402	et	3	main
lasnamäel	doc_919500587387_item	2944403	et	3	main
ida	doc_919500587387_item	2944418	et	4	main
eesti	doc_919500587387_item	2944421	et	4	main
seepärast	doc_919500587387_item	2944428	et	3	main
arvan	doc_919500587387_item	2944453	et	3	main
on	doc_919500587387_item	2944474	et	4	main
kena	doc_919500587387_item	2944476	et	4	main
minule	doc_919500587387_item	2944477	et	3	main
mu	doc_919500587387_item	2944479	et	3	main
töö	doc_919500587387_item	2944480	et	4	main
saab	doc_919500587387_item	2944481	et	3	main
tüdruk	doc_919500587387_item	2944485	et	3	main
ja	doc_919500587387_item	2944486	et	3	main
lõõgatame	doc_919500587387_item	2944492	et	4	main
seal	doc_919500587387_item	2944493	et	4	main
ma	doc_919500587387_item	2944494	et	3	main
kingitused	doc_919500587387_item	2944496	et	4	main
emalt	doc_919500587387_item	2944498	et	3	main
tähtis	doc_919500587387_item	2944522	et	4	main
kui	doc_919500587387_item	2944523	et	3	main
eestis	doc_919500587387_item	2944525	et	3	main
või	doc_919500587387_item	2944526	et	4	main
et	doc_919500587387_item	2944531	et	3	main
normaalselt	doc_919500587387_item	2944534	et	4	main
keelt	doc_919500587387_item	2944536	et	4	main
me	doc_919500587387_item	2944537	et	4	main
proovime	doc_919500587387_item	2944538	et	3	main
räägite	doc_919500587387_item	2944539	et	3	main
väga	doc_919500587387_item	2944553	et	3	main
raske	doc_919500587387_item	2944554	et	4	main
ja	doc_919500587387_item	2944555	et	3	main
võtab	doc_919500587387_item	2944556	et	3	main
aega	doc_919500587387_item	2944557	et	4	main
õppida	doc_919500587387_item	2944558	et	3	main
loodetavasti	doc_919500587387_item	2944559	et	3	main
ma	doc_919500587387_item	2944560	et	3	main
tartusse	doc_919500587386_item	2944302	et	3	main
siis	doc_919500587386_item	2944303	et	3	main
kohtla	doc_919500587386_item	2944306	et	4	main
rohkem	doc_919500587386_item	2944315	et	4	main
eestlasi	doc_919500587386_item	2944316	et	3	main
ja	doc_919500587386_item	2944317	et	3	main
vaadata	doc_919500587386_item	2944318	et	4	main
kohtu	doc_919500587386_item	2944321	et	4	main
lisaks	doc_919500587386_item	2944323	et	4	main
eesti	doc_919500587387_item	2944327	et	4	main
ja	doc_919500587387_item	2944329	et	3	main
on	doc_919500587387_item	2944331	et	4	main
seos	doc_919500587387_item	2944333	et	3	main
ma	doc_919500587387_item	2944334	et	3	main
elasin	doc_919500587387_item	2944335	et	3	main
eestis	doc_919500587387_item	2944336	et	3	main
üks	doc_919500587387_item	2944337	et	3	main
aasta	doc_919500587387_item	2944338	et	4	main
ja	doc_919500587387_item	2944339	et	3	main
palju	doc_919500587387_item	2944342	et	4	main
heas	doc_919500587387_item	2944360	et	3	main
vanalinnas	doc_919500587387_item	2944362	et	4	main
suurepärane	doc_919500587387_item	2944375	et	4	main
enam	doc_919500587387_item	2944380	et	4	main
nagu	doc_919500587387_item	2944382	et	3	main
ameerika	doc_919500587387_item	2944383	et	3	main
muidu	doc_919500587387_item	2944395	et	3	main
nad	doc_919500587387_item	2944396	et	3	main
ei	doc_919500587387_item	2944397	et	4	main
ja	doc_919500587387_item	2944411	et	3	main
eelimine	doc_919500587387_item	2944423	et	4	main
uus	doc_919500587387_item	2944426	et	3	main
on	doc_919500587387_item	2944436	et	4	main
ikka	doc_919500587387_item	2944437	et	4	main
on	doc_919500587387_item	2944447	et	4	main
väga	doc_919500587387_item	2944448	et	3	main
ja	doc_919500587387_item	2944451	et	3	main
vähem	doc_919500587387_item	2944459	et	4	main
et	doc_919500587387_item	2944463	et	3	main
on	doc_919500587387_item	2944465	et	4	main
fantastiline	doc_919500587387_item	2944467	et	4	main
päris	doc_919500587387_item	2944475	et	4	main
kui	doc_919500587387_item	2944478	et	3	main
me	doc_919500587387_item	2944491	et	4	main
see	doc_919500587387_item	2944499	et	3	main
ei	doc_919500587387_item	2944521	et	4	main
me	doc_919500587387_item	2944524	et	4	main
tähtis	doc_919500587387_item	2944529	et	4	main
oskan	doc_919500587387_item	2944533	et	3	main
eesti	doc_919500587387_item	2944535	et	4	main
eesti	doc_919500587387_item	2944550	et	4	main
saan	doc_919500587387_item	2944561	et	4	main
seda	doc_919500587387_item	2944562	et	3	main
kelt	doc_919500587387_item	2944563	et	3	main
sellel	doc_919500587387_item	2944564	et	4	main
mul	doc_919500587387_item	2944340	et	3	main
saksa	doc_919500587387_item	2944356	et	4	main
ja	doc_919500587387_item	2944357	et	3	main
õpetanud	doc_919500587387_item	2944370	et	4	main
enamik	doc_919500587387_item	2944385	et	3	main
on	doc_919500587387_item	2944387	et	4	main
tarkad	doc_919500587387_item	2944389	et	4	main
aga	doc_919500587387_item	2944390	et	3	main
või	doc_919500587387_item	2944394	et	4	main
on	doc_919500587387_item	2944409	et	4	main
ohtlik	doc_919500587387_item	2944410	et	3	main
euroopa	doc_919500587387_item	2944419	et	4	main
linnapiirkond	doc_919500587387_item	2944420	et	3	main
aasta	doc_919500587387_item	2944424	et	4	main
ka	doc_919500587387_item	2944425	et	3	main
ja	doc_919500587387_item	2944427	et	3	main
eesti	doc_919500587387_item	2944435	et	4	main
täiskohaga	doc_919500587387_item	2944445	et	4	main
see	doc_919500587387_item	2944446	et	3	main
ma	doc_919500587387_item	2944452	et	3	main
ma	doc_919500587387_item	2944457	et	3	main
olen	doc_919500587387_item	2944461	et	3	main
õnnelik	doc_919500587387_item	2944462	et	3	main
mul	doc_919500587387_item	2944464	et	3	main
nii	doc_919500587387_item	2944466	et	3	main
eesti	doc_919500587387_item	2944468	et	4	main
perekond	doc_919500587387_item	2944469	et	3	main
siin	doc_919500587387_item	2944470	et	4	main
mu	doc_919500587387_item	2944471	et	3	main
tüdruku	doc_919500587387_item	2944472	et	3	main
perekond	doc_919500587387_item	2944473	et	3	main
paljuks	doc_919500587387_item	2944483	et	4	main
mu	doc_919500587387_item	2944484	et	3	main
mina	doc_919500587387_item	2944487	et	4	main
ameerikas	doc_919500587387_item	2944527	et	4	main
keeles	doc_919500587387_item	2944541	et	4	main
kodus	doc_919500587387_item	2944542	et	4	main
on	doc_919500587387_item	2944552	et	4	main
eestlased	doc_919500587387_item	2944405	et	3	main
arvavad	doc_919500587387_item	2944406	et	4	main
oli	doc_919500587387_item	2944422	et	3	main
aasta	doc_919500587387_item	2944431	et	4	main
veel	doc_919500587387_item	2944438	et	4	main
raske	doc_919500587387_item	2944449	et	4	main
olukord	doc_919500587387_item	2944450	et	3	main
et	doc_919500587387_item	2944454	et	3	main
aastal	doc_919500587387_item	2944456	et	3	main
õpetan	doc_919500587387_item	2944458	et	3	main
sõdame	doc_919500587387_item	2944488	et	4	main
tamsalusse	doc_919500587387_item	2944489	et	4	main
ja	doc_919500587387_item	2944490	et	3	main
saan	doc_919500587387_item	2944495	et	4	main
sõnaraamat	doc_919500587387_item	2944500	et	3	main
mis	doc_919500587387_item	2944501	et	4	main
ma	doc_919500587387_item	2944502	et	3	main
nüüd	doc_919500587387_item	2944503	et	4	main
kasutan	doc_919500587387_item	2944504	et	3	main
oli	doc_919500587387_item	2944505	et	3	main
kingitus	doc_919500587387_item	2944506	et	4	main
temalt	doc_919500587387_item	2944507	et	3	main
ma	doc_919500587387_item	2944508	et	3	main
ei	doc_919500587387_item	2944509	et	4	main
tea	doc_919500587387_item	2944510	et	4	main
kui	doc_919500587387_item	2944511	et	3	main
ma	doc_919500587387_item	2944512	et	3	main
jään	doc_919500587387_item	2944513	et	3	main
eestimaale	doc_919500587387_item	2944514	et	4	main
pärast	doc_919500587387_item	2944515	et	4	main
oma	doc_919500587387_item	2944516	et	4	main
magister	doc_919500587387_item	2944517	et	3	main
see	doc_919500587387_item	2944518	et	3	main
mul	doc_919500587387_item	2944519	et	3	main
tüdrukul	doc_919500587387_item	2944520	et	3	main
on	doc_919500587387_item	2944530	et	4	main
ma	doc_919500587387_item	2944532	et	3	main
läheb	doc_919500587387_item	2944545	et	3	main
paremaks	doc_919500587387_item	2944546	et	4	main
probleem	doc_919500587387_item	2944547	et	3	main
on	doc_919500587387_item	2944548	et	4	main
et	doc_919500587387_item	2944549	et	3	main
õppida	doc_919500587387_item	2944566	et	3	main
elame	doc_919500587387_item	2944528	et	3	main
eesti	doc_919500587387_item	2944540	et	4	main
ja	doc_919500587387_item	2944543	et	3	main
see	doc_919500587387_item	2944544	et	3	main
keel	doc_919500587387_item	2944551	et	4	main
aastal	doc_919500587387_item	2944565	et	3	main
essee	doc_929981265996_item	2944757	et	4	main
19	doc_929981265996_item	2944759	et	2	main
kogunes	doc_929981265996_item	2944762	et	3	main
mõtlema	doc_929981265996_item	2944769	et	3	main
võimu	doc_929981265996_item	2944779	et	4	main
alt	doc_929981265996_item	2944780	et	4	main
rahval	doc_929981265996_item	2944788	et	3	main
majandusmasinate	doc_929981265996_item	2944822	et	3	main
tootmine	doc_929981265996_item	2944823	et	4	main
tagasid	doc_929981265996_item	2944833	et	4	main
eestimaa	doc_929981265996_item	2944840	et	4	main
narvast	doc_929981265996_item	2944844	et	4	main
arenes	doc_929981265996_item	2944846	et	3	main
8	doc_929981265996_item	2944850	et	2	main
lennulit	doc_929981265996_item	2944851	et	4	main
liin	doc_929981265996_item	2944852	et	3	main
eriti	doc_929981265996_item	2944863	et	3	main
oli	doc_929981265996_item	2944867	et	3	main
tööd	doc_929981265996_item	2944873	et	4	main
arvamise	doc_929981265996_item	2944904	et	4	main
otsingud	doc_929981265996_item	2944908	et	3	main
rahvuskultuurist	doc_929981265996_item	2944909	et	3	main
rahvuskultuur	doc_929981265996_item	2944912	et	3	main
huvitusid	doc_929981265996_item	2944914	et	4	main
nn	doc_929981265996_item	2944917	et	4	main
masarahva	doc_929981265996_item	2944918	et	4	main
kultuurist	doc_929981265996_item	2944919	et	3	main
tekkis	doc_929981265996_item	2944920	et	3	main
hakkasid	doc_929981265996_item	2944768	et	4	main
tuleb	doc_929981265996_item	2944771	et	3	main
vabadust	doc_929981265996_item	2944773	et	4	main
kõne	doc_929981265996_item	2944785	et	4	main
et	doc_929981265996_item	2944786	et	3	main
oli	doc_929981265996_item	2944826	et	3	main
tekkisid	doc_929981265996_item	2944829	et	4	main
ettevõtted	doc_929981265996_item	2944831	et	3	main
mis	doc_929981265996_item	2944832	et	4	main
riiasse	doc_929981265996_item	2944853	et	4	main
majanduslikud	doc_929981265996_item	2944854	et	3	main
suhted	doc_929981265996_item	2944855	et	3	main
tööjõupuudus	doc_929981265996_item	2944876	et	3	main
teke	doc_929981265996_item	2944905	et	3	main
tasahilju	doc_929981265996_item	2944911	et	3	main
haritlaste	doc_929981265996_item	2944923	et	3	main
kes	doc_929981265996_item	2944925	et	4	main
tegutsesid	doc_929981265996_item	2944926	et	4	main
rahva	doc_929981265996_item	2944927	et	3	main
õpetatud	doc_929981265996_item	2944944	et	4	main
levisid	doc_929981265996_item	2944953	et	4	main
tugev	doc_929981265996_item	2944957	et	4	main
initsiatiivgrupp	doc_929981265996_item	2944958	et	3	main
ja	doc_929981265996_item	2944959	et	3	main
nende	doc_929981265996_item	2944960	et	4	main
inimeste	doc_929981265996_item	2944961	et	3	main
juust	doc_929981265996_item	2944976	et	4	main
andnud	doc_929981265996_item	2944988	et	4	main
kalandusega	doc_929981265996_item	2944989	et	3	main
ekspordiks	doc_929981265996_item	2944992	et	4	main
ajal	doc_929981265996_item	2944995	et	4	main
liiga	doc_929981265996_item	2944996	et	4	main
tugev	doc_929981265996_item	2945004	et	4	main
lisaks	doc_929981265996_item	2945005	et	4	main
metallitööstus	doc_929981265996_item	2945006	et	3	main
tsemendivabrikud	doc_929981265996_item	2945007	et	3	main
sajandi	doc_929981265996_item	2944760	et	3	main
et	doc_929981265996_item	2944770	et	3	main
rohkem	doc_929981265996_item	2944772	et	4	main
saada	doc_929981265996_item	2944774	et	4	main
eesti	doc_929981265996_item	2944775	et	4	main
inimesed	doc_929981265996_item	2944776	et	3	main
vabaneda	doc_929981265996_item	2944781	et	3	main
sellele	doc_929981265996_item	2944782	et	4	main
soodustas	doc_929981265996_item	2944783	et	3	main
eestis	doc_929981265996_item	2944758	et	3	main
lõpul	doc_929981265996_item	2944761	et	3	main
palju	doc_929981265996_item	2944763	et	4	main
haritud	doc_929981265996_item	2944764	et	4	main
mehi	doc_929981265996_item	2944765	et	3	main
ja	doc_929981265996_item	2944766	et	3	main
nad	doc_929981265996_item	2944767	et	3	main
tahtsid	doc_929981265996_item	2944777	et	4	main
baltisakslaste	doc_929981265996_item	2944778	et	4	main
igal	doc_929981265996_item	2944787	et	3	main
on	doc_929981265996_item	2944789	et	4	main
õigus	doc_929981265996_item	2944790	et	4	main
esivanemate	doc_929981265996_item	2944792	et	4	main
oma	doc_929981265996_item	2944791	et	4	main
maa	doc_929981265996_item	2944793	et	4	main
peale	doc_929981265996_item	2944794	et	4	main
tuli	doc_929981265996_item	2944795	et	4	main
juba	doc_929981265996_item	2944796	et	3	main
aeg	doc_929981265996_item	2944797	et	3	main
nagu	doc_929981265996_item	2944798	et	3	main
euroopas	doc_929981265996_item	2944799	et	3	main
oma	doc_929981265996_item	2944800	et	4	main
rahvusriigi	doc_929981265996_item	2944801	et	3	main
ehitada	doc_929981265996_item	2944802	et	3	main
et	doc_929981265996_item	2944803	et	3	main
tagada	doc_929981265996_item	2944804	et	3	main
eestimaa	doc_929981265996_item	2944805	et	4	main
elankutele	doc_929981265996_item	2944806	et	4	main
vaba	doc_929981265996_item	2944807	et	4	main
tuleviku	doc_929981265996_item	2944808	et	4	main
alguses	doc_929981265996_item	2944809	et	4	main
1	doc_929981265996_item	2944810	et	2	main
eesti	doc_929981265996_item	2944811	et	4	main
vabariik	doc_929981265996_item	2944812	et	3	main
sõltus	doc_929981265996_item	2944813	et	4	main
euroopa	doc_929981265996_item	2944814	et	4	main
turult	doc_929981265996_item	2944815	et	3	main
oluline	doc_929981265996_item	2944816	et	4	main
tööstuses	doc_929981265996_item	2944817	et	3	main
oli	doc_929981265996_item	2944818	et	3	main
põlevkivi	doc_929981265996_item	2944819	et	4	main
toodang	doc_929981265996_item	2944820	et	3	main
tähtsal	doc_929981265996_item	2944827	et	3	main
vajadust	doc_929981265996_item	2944836	et	4	main
vajadust	doc_929981265996_item	2944837	et	4	main
rahuldamine	doc_929981265996_item	2944838	et	4	main
jakobsoni	doc_929981265996_item	2944784	et	4	main
piimatööstus	doc_929981265996_item	2944825	et	3	main
kohal	doc_929981265996_item	2944828	et	4	main
väikesed	doc_929981265996_item	2944830	et	4	main
ka	doc_929981265996_item	2944841	et	3	main
energiat	doc_929981265996_item	2944843	et	3	main
eesti	doc_929981265996_item	2944847	et	4	main
laevandus	doc_929981265996_item	2944848	et	3	main
lennundus	doc_929981265996_item	2944849	et	3	main
kriis	doc_929981265996_item	2944862	et	3	main
jätkunud	doc_929981265996_item	2944872	et	4	main
pärast	doc_929981265996_item	2944875	et	4	main
avaliku	doc_929981265996_item	2944903	et	3	main
arendamise	doc_929981265996_item	2944929	et	4	main
roll	doc_929981265996_item	2944932	et	3	main
seltsil	doc_929981265996_item	2944946	et	3	main
õpetajate	doc_929981265996_item	2944948	et	4	main
seminaridel	doc_929981265996_item	2944950	et	3	main
nende	doc_929981265996_item	2944951	et	4	main
kaudu	doc_929981265996_item	2944952	et	3	main
talupoegade	doc_929981265996_item	2944955	et	3	main
olid	doc_929981265996_item	2944963	et	4	main
minu	doc_929981265996_item	2944964	et	3	main
arvates	doc_929981265996_item	2944965	et	4	main
rahvusliku	doc_929981265996_item	2944966	et	3	main
ärkamise	doc_929981265996_item	2944967	et	4	main
tugipunktideks	doc_929981265996_item	2944968	et	3	main
otsiti	doc_929981265996_item	2944969	et	3	main
turgu	doc_929981265996_item	2944970	et	4	main
sealiha	doc_929981265996_item	2944977	et	4	main
peekon	doc_929981265996_item	2944978	et	3	main
areng	doc_929981265996_item	2944979	et	3	main
tegeleti	doc_929981265996_item	2944990	et	3	main
metsaraiele	doc_929981265996_item	2944993	et	3	main
tehtud	doc_929981265996_item	2944997	et	4	main
see	doc_929981265996_item	2944998	et	3	main
aparaadivabrikud	doc_929981265996_item	2945008	et	3	main
a	doc_929981265996_item	2945013	et	4	main
gustav	doc_929981265996_item	2945015	et	4	main
suitsu	doc_929981265996_item	2945016	et	4	main
loosung	doc_929981265996_item	2945017	et	3	main
saagem	doc_929981265996_item	2945018	et	3	main
proffessionaalsele	doc_929981265996_item	2945037	et	4	main
tema	doc_929981265996_item	2945041	et	4	main
mõjudele	doc_929981265996_item	2945047	et	3	main
palju	doc_929981265996_item	2945048	et	4	main
sonetid	doc_929981265996_item	2945054	et	3	main
pos	doc_929981265996_item	2945067	et	4	main
mõju	doc_929981265996_item	2945068	et	4	main
kultuurielule	doc_929981265996_item	2945069	et	3	main
saagem	doc_929981265996_item	2945078	et	3	main
mitte	doc_929981265996_item	2945081	et	3	main
hurt	doc_929981265996_item	2945084	et	3	main
üldlaulupeol	doc_929981265996_item	2945095	et	4	main
hiljem	doc_929981265996_item	2945096	et	3	main
kaastöö	doc_929981265996_item	2945097	et	4	main
kooliharidust	doc_929981265996_item	2945103	et	4	main
tee	doc_929981265996_item	2945110	et	4	main
olema	doc_929981265996_item	2945114	et	4	main
vahepealset	doc_929981265996_item	2945118	et	3	main
lausa	doc_929981265996_item	2945133	et	4	main
ndate	doc_929981265996_item	2945141	et	4	main
algusel	doc_929981265996_item	2945156	et	4	main
sest	doc_929981265996_item	2945157	et	4	main
eestlased	doc_929981265996_item	2945158	et	3	main
ei	doc_929981265996_item	2945165	et	4	main
pärast	doc_929981265996_item	2945168	et	4	main
eestlaseks	doc_929981265996_item	2945179	et	3	main
a	doc_929981265996_item	2945210	et	4	main
pärisor	doc_929981265996_item	2945212	et	4	main
kaotamist	doc_929981265996_item	2945213	et	4	main
vabalt	doc_929981265996_item	2945217	et	4	main
lauldi	doc_929981265996_item	2945221	et	3	main
mängis	doc_929981265996_item	2945223	et	3	main
mu	doc_929981265996_item	2945226	et	3	main
ja	doc_929981265996_item	2945230	et	3	main
metallitööstus	doc_929981265996_item	2944821	et	3	main
ja	doc_929981265996_item	2944824	et	3	main
riigi	doc_929981265996_item	2944834	et	3	main
sisemist	doc_929981265996_item	2944835	et	4	main
andis	doc_929981265996_item	2944842	et	3	main
venemaale	doc_929981265996_item	2944845	et	4	main
majanduslik	doc_929981265996_item	2944861	et	3	main
puudutanud	doc_929981265996_item	2944865	et	4	main
aeg	doc_929981265996_item	2944869	et	3	main
kui	doc_929981265996_item	2944870	et	3	main
ei	doc_929981265996_item	2944871	et	4	main
aga	doc_929981265996_item	2944874	et	3	main
see	doc_929981265996_item	2944877	et	3	main
rühmitus	doc_929981265996_item	2944878	et	4	main
oli	doc_929981265996_item	2944879	et	3	main
selleks	doc_929981265996_item	2944880	et	4	main
et	doc_929981265996_item	2944881	et	3	main
kasvatada	doc_929981265996_item	2944882	et	3	main
ja	doc_929981265996_item	2944883	et	3	main
arendada	doc_929981265996_item	2944884	et	3	main
rahvusliku	doc_929981265996_item	2944885	et	3	main
teadvuse	doc_929981265996_item	2944886	et	4	main
eesti	doc_929981265996_item	2944887	et	4	main
rahval	doc_929981265996_item	2944888	et	3	main
juhiks	doc_929981265996_item	2944889	et	4	main
oli	doc_929981265996_item	2944890	et	3	main
g	doc_929981265996_item	2944891	et	4	main
suits	doc_929981265996_item	2944892	et	3	main
18	doc_929981265996_item	2944893	et	2	main
saj	doc_929981265996_item	2944894	et	4	main
euroopas	doc_929981265996_item	2944895	et	3	main
levima	doc_929981265996_item	2944896	et	3	main
hakanud	doc_929981265996_item	2944897	et	4	main
valgustusesaj	doc_929981265996_item	2944898	et	4	main
järgsed	doc_929981265996_item	2944899	et	3	main
ideed	doc_929981265996_item	2944900	et	4	main
rahvuse	doc_929981265996_item	2944901	et	3	main
pinnal	doc_929981265996_item	2944902	et	3	main
aga	doc_929981265996_item	2944839	et	3	main
olid	doc_929981265996_item	2944856	et	4	main
venemaaga	doc_929981265996_item	2944857	et	3	main
inglismaaga	doc_929981265996_item	2944858	et	3	main
1930-te	doc_929981265996_item	2944859	et	3	main
a-te	doc_929981265996_item	2944860	et	3	main
ei	doc_929981265996_item	2944864	et	4	main
eestit	doc_929981265996_item	2944866	et	3	main
alguses	doc_929981265996_item	2944868	et	4	main
sai	doc_929981265996_item	2944910	et	4	main
eestimaal	doc_929981265996_item	2944913	et	4	main
kohalikud	doc_929981265996_item	2944915	et	3	main
eestlastest	doc_929981265996_item	2944922	et	4	main
nimel	doc_929981265996_item	2944930	et	3	main
suur	doc_929981265996_item	2944931	et	3	main
koostamisel	doc_929981265996_item	2944941	et	4	main
samuti	doc_929981265996_item	2944942	et	3	main
1838	doc_929981265996_item	2944943	et	2	main
meelekindlus	doc_929981265996_item	2944962	et	4	main
välismaal	doc_929981265996_item	2944971	et	4	main
peamised	doc_929981265996_item	2944972	et	3	main
ekspordiartiklid	doc_929981265996_item	2944973	et	3	main
suht	doc_929981265996_item	2944980	et	4	main
positiivne	doc_929981265996_item	2944981	et	3	main
võrreldes	doc_929981265996_item	2944982	et	3	main
venemaaga	doc_929981265996_item	2944983	et	3	main
euroopaga	doc_929981265996_item	2944984	et	3	main
samuti	doc_929981265996_item	2944991	et	3	main
profiili	doc_929981265996_item	2945002	et	4	main
tekstiilitööstus	doc_929981265996_item	2945003	et	3	main
tegutses	doc_929981265996_item	2945010	et	3	main
1925	doc_929981265996_item	2945014	et	2	main
rohkem	doc_929981265996_item	2945023	et	4	main
albumid	doc_929981265996_item	2945028	et	3	main
pani	doc_929981265996_item	2945034	et	4	main
aluse	doc_929981265996_item	2945035	et	4	main
ja	doc_929981265996_item	2945039	et	3	main
kunstikriitikale	doc_929981265996_item	2945040	et	3	main
novellikogud	doc_929981265996_item	2945042	et	3	main
ekspermenteeritud	doc_929981265996_item	2945049	et	4	main
oma	doc_929981265996_item	2945071	et	4	main
suureks	doc_929981265996_item	2945079	et	4	main
jakob	doc_929981265996_item	2945083	et	4	main
noore	doc_929981265996_item	2945086	et	3	main
sekkus	doc_929981265996_item	2945088	et	3	main
eesti	doc_929981265996_item	2945089	et	4	main
eestikeelsetmeelset	doc_929981265996_item	2945102	et	4	main
vene	doc_929981265996_item	2945109	et	4	main
kahe	doc_929981265996_item	2945117	et	3	main
teda	doc_929981265996_item	2945127	et	4	main
liigses	doc_929981265996_item	2945128	et	3	main
saksameelsuses	doc_929981265996_item	2945129	et	4	main
orjameelsus	doc_929981265996_item	2945134	et	4	main
hurdale	doc_929981265996_item	2945135	et	3	main
vastumeelt	doc_929981265996_item	2945136	et	3	main
jakobsoni	doc_929981265996_item	2945137	et	4	main
kogukonna	doc_929981265996_item	2945148	et	4	main
ärkamise	doc_929981265996_item	2945151	et	4	main
19	doc_929981265996_item	2945154	et	2	main
saj	doc_929981265996_item	2945155	et	4	main
õigust	doc_929981265996_item	2945167	et	4	main
pärisorjuse	doc_929981265996_item	2945169	et	3	main
18161819	doc_929981265996_item	2945171	et	2	main
üldlaulupidu	doc_929981265996_item	2945208	et	4	main
50	doc_929981265996_item	2945209	et	2	main
rahvas	doc_929981265996_item	2945214	et	4	main
pacius	doc_929981265996_item	2945234	et	4	main
hümn	doc_929981265996_item	2945235	et	3	main
seltsid	doc_929981265996_item	2945243	et	4	main
ühingud	doc_929981265996_item	2945244	et	3	main
võitlus	doc_929981265996_item	2945245	et	3	main
eesti	doc_929981265996_item	2945251	et	4	main
1919	doc_929981265996_item	2945273	et	2	main
ei	doc_929981265996_item	2945281	et	4	main
majandusselts	doc_929981265996_item	2945299	et	3	main
linda	doc_929981265996_item	2945300	et	4	main
leiutati	doc_929981265996_item	2945305	et	4	main
uusi	doc_929981265996_item	2945306	et	3	main
rukkusorti	doc_929981265996_item	2945307	et	4	main
põllumajandus	doc_929981265996_item	2945308	et	3	main
rahvusliku	doc_929981265996_item	2944906	et	3	main
identiteedi	doc_929981265996_item	2944907	et	4	main
baltisakslased	doc_929981265996_item	2944916	et	3	main
ka	doc_929981265996_item	2944921	et	3	main
faehlmanni	doc_929981265996_item	2944933	et	4	main
ja	doc_929981265996_item	2944934	et	3	main
kreutzwaldil	doc_929981265996_item	2944935	et	4	main
kalevipoja	doc_929981265996_item	2944936	et	4	main
kui	doc_929981265996_item	2944937	et	3	main
ja	doc_929981265996_item	2944947	et	3	main
koolituse	doc_929981265996_item	2944949	et	4	main
eesti	doc_929981265996_item	2944974	et	4	main
palgad	doc_929981265996_item	2944985	et	3	main
võrrelda	doc_929981265996_item	2944986	et	4	main
haru	doc_929981265996_item	2944999	et	4	main
pidas	doc_929981265996_item	2945000	et	3	main
madalat	doc_929981265996_item	2945001	et	3	main
1905-15	doc_929981265996_item	2945009	et	2	main
peale	doc_929981265996_item	2945012	et	4	main
eestlasteks	doc_929981265996_item	2945022	et	4	main
luulekogud	doc_929981265996_item	2945029	et	3	main
luulel	doc_929981265996_item	2945031	et	4	main
kirjandus-	doc_929981265996_item	2945038	et	3	main
euroopa	doc_929981265996_item	2945046	et	4	main
underi	doc_929981265996_item	2945053	et	4	main
kohe	doc_929981265996_item	2945056	et	4	main
noor-eesti	doc_929981265996_item	2945062	et	4	main
avardas	doc_929981265996_item	2945063	et	3	main
eestlase	doc_929981265996_item	2945064	et	3	main
maailmapilti	doc_929981265996_item	2945065	et	4	main
omas	doc_929981265996_item	2945066	et	4	main
rahvarvult	doc_929981265996_item	2945082	et	4	main
juba	doc_929981265996_item	2945085	et	3	main
mehena	doc_929981265996_item	2945087	et	3	main
kultuuriellu	doc_929981265996_item	2945090	et	3	main
postimehele	doc_929981265996_item	2945098	et	4	main
tema	doc_929981265996_item	2945104	et	4	main
eesti	doc_929981265996_item	2945111	et	4	main
nende	doc_929981265996_item	2945116	et	4	main
mis	doc_929981265996_item	2945130	et	4	main
alguses	doc_929981265996_item	2945142	et	4	main
lahkus	doc_929981265996_item	2945143	et	4	main
pastorina	doc_929981265996_item	2945149	et	3	main
algas	doc_929981265996_item	2945153	et	3	main
hakkasid	doc_929981265996_item	2945180	et	4	main
endale	doc_929981265996_item	2945182	et	4	main
tudis	doc_929981265996_item	2945215	et	4	main
seal	doc_929981265996_item	2945220	et	4	main
pol	doc_929981265996_item	2944939	et	4	main
seltskond	doc_929981265996_item	2944924	et	3	main
eneseteadvuse	doc_929981265996_item	2944928	et	4	main
kult	doc_929981265996_item	2944938	et	3	main
teose	doc_929981265996_item	2944940	et	3	main
eesti	doc_929981265996_item	2944945	et	4	main
ideed	doc_929981265996_item	2944954	et	4	main
seas	doc_929981265996_item	2944956	et	4	main
või	doc_929981265996_item	2944975	et	4	main
ei	doc_929981265996_item	2944987	et	4	main
sõja	doc_929981265996_item	2944994	et	3	main
ka	doc_929981265996_item	2945011	et	3	main
eurooplasteks	doc_929981265996_item	2945019	et	3	main
kuid	doc_929981265996_item	2945020	et	4	main
jäägem	doc_929981265996_item	2945021	et	3	main
euroopalist	doc_929981265996_item	2945024	et	3	main
kultuuri	doc_929981265996_item	2945025	et	4	main
ilmusid	doc_929981265996_item	2945026	et	4	main
friedeberg	doc_929981265996_item	2945032	et	4	main
tuglas	doc_929981265996_item	2945033	et	4	main
eesti	doc_929981265996_item	2945036	et	4	main
rääkisid	doc_929981265996_item	2945043	et	4	main
tugevast	doc_929981265996_item	2945044	et	4	main
suurepärane	doc_929981265996_item	2945050	et	4	main
stiilitunnetus	doc_929981265996_item	2945051	et	3	main
müüdi	doc_929981265996_item	2945055	et	4	main
läbi	doc_929981265996_item	2945057	et	4	main
julge	doc_929981265996_item	2945058	et	4	main
armastusest	doc_929981265996_item	2945061	et	4	main
koondas	doc_929981265996_item	2945070	et	3	main
aja	doc_929981265996_item	2945072	et	4	main
tipud	doc_929981265996_item	2945073	et	3	main
vahendas	doc_929981265996_item	2945074	et	3	main
maailmamtippude	doc_929981265996_item	2945075	et	4	main
kirjandust	doc_929981265996_item	2945076	et	3	main
i	doc_929981265996_item	2945094	et	4	main
katkes	doc_929981265996_item	2945100	et	4	main
pooldas	doc_929981265996_item	2945101	et	3	main
välja	doc_929981265996_item	2945107	et	4	main
taoline	doc_929981265996_item	2945108	et	3	main
pidi	doc_929981265996_item	2945113	et	4	main
kahjuks	doc_929981265996_item	2945121	et	4	main
jakobsoniga	doc_929981265996_item	2945124	et	4	main
jakobsoni	doc_929981265996_item	2945131	et	4	main
venemaale	doc_929981265996_item	2945138	et	4	main
peterburi	doc_929981265996_item	2945144	et	4	main
tegutses	doc_929981265996_item	2945145	et	3	main
sealse	doc_929981265996_item	2945146	et	3	main
rahvuslik	doc_929981265996_item	2945150	et	3	main
aeg	doc_929981265996_item	2945152	et	3	main
olid	doc_929981265996_item	2945160	et	4	main
pärisorjad	doc_929981265996_item	2945161	et	3	main
vaesed	doc_929981265996_item	2945162	et	4	main
ja	doc_929981265996_item	2945163	et	3	main
neil	doc_929981265996_item	2945164	et	4	main
maarahvaks	doc_929981265996_item	2945177	et	3	main
pärast	doc_929981265996_item	2945211	et	4	main
iseseisvalt	doc_929981265996_item	2945218	et	4	main
sest	doc_929981265996_item	2945219	et	4	main
rahvalaule	doc_929981265996_item	2945222	et	4	main
ilmus	doc_929981265996_item	2945236	et	4	main
1878	doc_929981265996_item	2945237	et	2	main
õiguste	doc_929981265996_item	2945246	et	4	main
vabariik	doc_929981265996_item	2945252	et	3	main
on	doc_929981265996_item	2945253	et	4	main
pank	doc_929981265996_item	2945272	et	3	main
loodi	doc_929981265996_item	2945275	et	4	main
välised	doc_929981265996_item	2945291	et	4	main
kaudu	doc_929981265996_item	2945295	et	3	main
süsteemi	doc_929981265996_item	2945309	et	4	main
l-e	doc_929981265996_item	2945314	et	3	main
sealiha	doc_929981265996_item	2945320	et	4	main
rühmituse	doc_929981265996_item	2945027	et	4	main
põhirõhk	doc_929981265996_item	2945030	et	3	main
avatusest	doc_929981265996_item	2945045	et	4	main
marie	doc_929981265996_item	2945052	et	4	main
armuluule	doc_929981265996_item	2945059	et	4	main
rõõm	doc_929981265996_item	2945060	et	3	main
eestlasele	doc_929981265996_item	2945077	et	3	main
vaimult	doc_929981265996_item	2945080	et	4	main
esinemine	doc_929981265996_item	2945091	et	4	main
1869	doc_929981265996_item	2945092	et	2	main
a	doc_929981265996_item	2945093	et	4	main
kahjuks	doc_929981265996_item	2945099	et	4	main
konseptisoon	doc_929981265996_item	2945105	et	4	main
nägi	doc_929981265996_item	2945106	et	3	main
tee	doc_929981265996_item	2945112	et	4	main
midagi	doc_929981265996_item	2945115	et	4	main
saksa	doc_929981265996_item	2945119	et	4	main
tee	doc_929981265996_item	2945120	et	4	main
tugevad	doc_929981265996_item	2945122	et	4	main
vastuolud	doc_929981265996_item	2945123	et	3	main
kes	doc_929981265996_item	2945125	et	4	main
süüdistas	doc_929981265996_item	2945126	et	3	main
meelest	doc_929981265996_item	2945132	et	4	main
orienteeritus	doc_929981265996_item	2945139	et	4	main
80	doc_929981265996_item	2945140	et	2	main
eesti	doc_929981265996_item	2945147	et	4	main
varem	doc_929981265996_item	2945159	et	4	main
olnud	doc_929981265996_item	2945166	et	4	main
kaotamist	doc_929981265996_item	2945170	et	4	main
nad	doc_929981265996_item	2945172	et	3	main
hakkasid	doc_929981265996_item	2945173	et	4	main
end	doc_929981265996_item	2945174	et	4	main
kutsuma	doc_929981265996_item	2945175	et	3	main
mitte	doc_929981265996_item	2945176	et	3	main
vaid	doc_929981265996_item	2945178	et	3	main
nõudma	doc_929981265996_item	2945181	et	3	main
hariduse	doc_929981265996_item	2945183	et	3	main
võimalust	doc_929981265996_item	2945184	et	3	main
vabadust	doc_929981265996_item	2945185	et	4	main
tähtsamad	doc_929981265996_item	2945186	et	4	main
liidrid	doc_929981265996_item	2945187	et	3	main
jhurt	doc_929981265996_item	2945188	et	4	main
jakobson	doc_929981265996_item	2945189	et	4	main
jv	doc_929981265996_item	2945190	et	4	main
jannsenn	doc_929981265996_item	2945191	et	4	main
faehlmann	doc_929981265996_item	2945192	et	4	main
kreutzwald	doc_929981265996_item	2945193	et	4	main
1857	doc_929981265996_item	2945194	et	2	main
a	doc_929981265996_item	2945195	et	4	main
jannseni	doc_929981265996_item	2945196	et	4	main
ajaleht	doc_929981265996_item	2945197	et	3	main
perno	doc_929981265996_item	2945198	et	4	main
postimees	doc_929981265996_item	2945199	et	4	main
esimene	doc_929981265996_item	2945200	et	3	main
eestikeelne	doc_929981265996_item	2945201	et	3	main
ajaleht	doc_929981265996_item	2945202	et	3	main
kultuurileevendamine	doc_929981265996_item	2945203	et	3	main
1869a	doc_929981265996_item	2945204	et	4	main
tartus	doc_929981265996_item	2945205	et	3	main
toimus	doc_929981265996_item	2945206	et	3	main
esimene	doc_929981265996_item	2945207	et	3	main
end	doc_929981265996_item	2945216	et	4	main
5	doc_929981265996_item	2945224	et	2	main
isamaa	doc_929981265996_item	2945227	et	4	main
l	doc_929981265996_item	2945232	et	4	main
koidula	doc_929981265996_item	2945233	et	4	main
ajaleht	doc_929981265996_item	2945240	et	3	main
eest	doc_929981265996_item	2945247	et	4	main
eesti	doc_929981265996_item	2945271	et	4	main
eesti	doc_929981265996_item	2945276	et	4	main
olnud	doc_929981265996_item	2945282	et	4	main
viljakas	doc_929981265996_item	2945283	et	4	main
ja	doc_929981265996_item	2945284	et	3	main
hästi	doc_929981265996_item	2945285	et	3	main
arenenud	doc_929981265996_item	2945286	et	4	main
aga	doc_929981265996_item	2945287	et	3	main
euroopaga	doc_929981265996_item	2945293	et	3	main
venemaa	doc_929981265996_item	2945294	et	4	main
asutati	doc_929981265996_item	2945298	et	4	main
kasvatati	doc_929981265996_item	2945311	et	3	main
kartulit	doc_929981265996_item	2945313	et	3	main
tulu	doc_929981265996_item	2945325	et	4	main
ja	doc_929981265996_item	2945326	et	3	main
metallitööstus	doc_929981265996_item	2945334	et	3	main
masinaehitusvarikud	doc_929981265996_item	2945335	et	3	main
vagunivabrik	doc_929981265996_item	2945336	et	3	main
dvigatel	doc_929981265996_item	2945337	et	4	main
masinatehas	doc_929981265996_item	2945338	et	3	main
volta	doc_929981265996_item	2945339	et	4	main
ekstensiivne	doc_929981265996_item	2945340	et	3	main
paberi	doc_929981265996_item	2945341	et	3	main
puuvalmistamine	doc_929981265996_item	2945342	et	3	main
trikotaaž	doc_929981265996_item	2945348	et	2	main
inglismaaga	doc_929981265996_item	2945361	et	3	main
fosforiidi	doc_929981265996_item	2945371	et	4	main
dolomiidi	doc_929981265996_item	2945372	et	3	main
telliskivitööstus	doc_929981265996_item	2945373	et	3	main
tort	doc_929981265996_item	2945376	et	3	main
kultuuriloos	doc_929981265996_item	2945378	et	4	main
noor-eesti	doc_929981265996_item	2945379	et	4	main
arenemist	doc_929981265996_item	2945389	et	4	main
parenemist	doc_929981265996_item	2945390	et	4	main
eestis	doc_929981265996_item	2945392	et	3	main
ja	doc_929981265996_item	2945401	et	3	main
eesti	doc_940752626606_item	2945433	et	4	main
sõda	doc_940752626606_item	2945445	et	4	main
1	doc_940752626606_item	2945446	et	2	main
keskaegne	doc_940752626606_item	2945447	et	3	main
linnakultuur	doc_940752626606_item	2945448	et	3	main
keskaega	doc_940752626606_item	2945464	et	4	main
ja	doc_940752626606_item	2945465	et	3	main
saatus	doc_940752626606_item	2945466	et	3	main
ja	doc_940752626606_item	2945495	et	3	main
samuti	doc_940752626606_item	2945497	et	3	main
viljandi	doc_940752626606_item	2945499	et	4	main
uus-pärnu	doc_940752626606_item	2945500	et	4	main
ehitusmaterjaliks	doc_940752626606_item	2945501	et	3	main
oli	doc_940752626606_item	2945502	et	3	main
dolomiit	doc_940752626606_item	2945503	et	3	main
telliskivi	doc_940752626606_item	2945504	et	4	main
raekoda	doc_940752626606_item	2945509	et	4	main
olid	doc_940752626606_item	2945537	et	4	main
kitsad	doc_940752626606_item	2945538	et	3	main
linna	doc_940752626606_item	2945554	et	4	main
ja	doc_940752626606_item	2945581	et	3	main
valitsuseks	doc_940752626606_item	2945584	et	4	main
12	doc_940752626606_item	2945593	et	2	main
bürgermeistrid	doc_940752626606_item	2945596	et	3	main
seaduste	doc_940752626606_item	2945600	et	4	main
ja	doc_940752626606_item	2945610	et	3	main
gildid	doc_940752626606_item	2945613	et	3	main
siin	doc_940752626606_item	2945619	et	4	main
mis	doc_940752626606_item	2945622	et	4	main
kaupmehed	doc_940752626606_item	2945634	et	3	main
1	doc_940752626606_item	2945637	et	2	main
aasta	doc_940752626606_item	2945638	et	4	main
ja	doc_940752626606_item	2945639	et	3	main
1	doc_940752626606_item	2945640	et	2	main
jooksul	doc_940752626606_item	2945647	et	4	main
siin	doc_940752626606_item	2945670	et	4	main
olid	doc_940752626606_item	2945671	et	4	main
kirikud	doc_940752626606_item	2945672	et	3	main
puhkpilliorkestrit	doc_929981265996_item	2945225	et	3	main
mu	doc_929981265996_item	2945228	et	3	main
õnn	doc_929981265996_item	2945229	et	3	main
rõõm	doc_929981265996_item	2945231	et	3	main
eestlaste	doc_929981265996_item	2945249	et	4	main
eneseteadvus	doc_929981265996_item	2945250	et	4	main
agraarmaa	doc_929981265996_item	2945254	et	4	main
1870	doc_929981265996_item	2945255	et	2	main
a-	doc_929981265996_item	2945256	et	4	main
ilmus	doc_929981265996_item	2945257	et	4	main
esim	doc_929981265996_item	2945259	et	4	main
tartus	doc_929981265996_item	2945258	et	3	main
põllumajanduse	doc_929981265996_item	2945260	et	3	main
selts	doc_929981265996_item	2945261	et	3	main
jakobsoni	doc_929981265996_item	2945238	et	4	main
poliitiline	doc_929981265996_item	2945239	et	3	main
sakala	doc_929981265996_item	2945241	et	4	main
moodustasid	doc_929981265996_item	2945242	et	4	main
kalevipoeg	doc_929981265996_item	2945248	et	3	main
a	doc_929981265996_item	2945263	et	4	main
aastaks	doc_929981265996_item	2945266	et	4	main
millal	doc_929981265996_item	2945267	et	3	main
oli	doc_929981265996_item	2945268	et	3	main
moodustatud	doc_929981265996_item	2945269	et	4	main
esimene	doc_929981265996_item	2945270	et	3	main
a	doc_929981265996_item	2945274	et	4	main
pank	doc_929981265996_item	2945277	et	3	main
alguses	doc_929981265996_item	2945278	et	4	main
eesti	doc_929981265996_item	2945279	et	4	main
suhted	doc_929981265996_item	2945292	et	3	main
1879	doc_929981265996_item	2945296	et	2	main
tallinnas	doc_929981265996_item	2945297	et	4	main
narvas	doc_929981265996_item	2945302	et	4	main
piimatööstus	doc_929981265996_item	2945303	et	3	main
karjakasvatus	doc_929981265996_item	2945304	et	4	main
põhja-eestis	doc_929981265996_item	2945310	et	3	main
ohtralt	doc_929981265996_item	2945312	et	4	main
lina	doc_929981265996_item	2945315	et	4	main
eesti	doc_929981265996_item	2945316	et	4	main
peekon	doc_929981265996_item	2945321	et	3	main
läksid	doc_929981265996_item	2945323	et	4	main
militaalvajadused	doc_929981265996_item	2945331	et	4	main
eestis	doc_929981265996_item	2945332	et	3	main
ehitati	doc_929981265996_item	2945333	et	3	main
kaevandus	doc_929981265996_item	2945349	et	4	main
kalandus	doc_929981265996_item	2945352	et	3	main
karjandus	doc_929981265996_item	2945354	et	3	main
arenes	doc_929981265996_item	2945357	et	3	main
ostsid	doc_929981265996_item	2945364	et	4	main
eestist	doc_929981265996_item	2945366	et	3	main
tähtsat	doc_929981265996_item	2945381	et	3	main
see	doc_929981265996_item	2945384	et	3	main
soodustas	doc_929981265996_item	2945386	et	3	main
kodutütrerd	doc_929981265996_item	2945400	et	4	main
kirjutasid	doc_929981265996_item	2945422	et	4	main
siuru	doc_929981265996_item	2945429	et	4	main
ühing	doc_929981265996_item	2945430	et	3	main
missugune	doc_940752626606_item	2945436	et	3	main
oli	doc_940752626606_item	2945437	et	3	main
keskaegne	doc_940752626606_item	2945438	et	3	main
linnakultuur	doc_940752626606_item	2945439	et	3	main
koos	doc_940752626606_item	2945449	et	4	main
ja	doc_940752626606_item	2945452	et	3	main
euroopa	doc_940752626606_item	2945467	et	4	main
majad	doc_940752626606_item	2945513	et	3	main
ehitis	doc_940752626606_item	2945523	et	3	main
kõrgem	doc_940752626606_item	2945527	et	4	main
kui	doc_940752626606_item	2945528	et	3	main
tänavad	doc_940752626606_item	2945536	et	4	main
kivist	doc_940752626606_item	2945542	et	4	main
rakveres	doc_940752626606_item	2945558	et	4	main
ja	doc_940752626606_item	2945559	et	3	main
narvas	doc_940752626606_item	2945560	et	4	main
mille	doc_940752626606_item	2945578	et	3	main
pärnu	doc_940752626606_item	2945582	et	4	main
rae	doc_940752626606_item	2945587	et	3	main
koosseisus	doc_940752626606_item	2945588	et	4	main
hiljem	doc_940752626606_item	2945592	et	3	main
maahärrad	doc_940752626606_item	2945595	et	3	main
e	doc_940752626606_item	2945597	et	4	main
esindus	doc_940752626606_item	2945604	et	4	main
ühendused	doc_940752626606_item	2945617	et	4	main
suurgild	doc_940752626606_item	2945621	et	3	main
rikkastest	doc_940752626606_item	2945624	et	4	main
vallalised	doc_940752626606_item	2945633	et	4	main
linnas	doc_940752626606_item	2945635	et	4	main
kehtis	doc_940752626606_item	2945636	et	3	main
selle	doc_940752626606_item	2945645	et	4	main
välja	doc_940752626606_item	2945650	et	4	main
temast	doc_940752626606_item	2945652	et	3	main
linnakodanik	doc_940752626606_item	2945654	et	3	main
vaimuelu	doc_940752626606_item	2945666	et	4	main
koole	doc_940752626606_item	2945677	et	4	main
õpetati	doc_940752626606_item	2945678	et	3	main
eluviisi	doc_940752626606_item	2945692	et	4	main
1902	doc_929981265996_item	2945262	et	2	main
võib	doc_929981265996_item	2945264	et	3	main
nimetada	doc_929981265996_item	2945265	et	3	main
majandus	doc_929981265996_item	2945280	et	4	main
pärast	doc_929981265996_item	2945288	et	4	main
laienes	doc_929981265996_item	2945289	et	3	main
siseturg	doc_929981265996_item	2945290	et	3	main
ilmarine	doc_929981265996_item	2945301	et	4	main
tooded	doc_929981265996_item	2945317	et	4	main
nagu	doc_929981265996_item	2945318	et	3	main
venemaal	doc_929981265996_item	2945328	et	4	main
toimus	doc_929981265996_item	2945329	et	3	main
tekstiiltööstus	doc_929981265996_item	2945343	et	4	main
oli	doc_929981265996_item	2945344	et	3	main
põlismurre	doc_929981265996_item	2945350	et	4	main
metsandus	doc_929981265996_item	2945353	et	3	main
majandus	doc_929981265996_item	2945355	et	4	main
parenesid	doc_929981265996_item	2945358	et	4	main
nad	doc_929981265996_item	2945363	et	3	main
eesti	doc_929981265996_item	2945367	et	4	main
sai	doc_929981265996_item	2945368	et	4	main
toormaterjale	doc_929981265996_item	2945369	et	3	main
venemaalt	doc_929981265996_item	2945370	et	3	main
mängis	doc_929981265996_item	2945380	et	3	main
eesti	doc_929981265996_item	2945387	et	4	main
noored	doc_929981265996_item	2945402	et	3	main
uurisid	doc_929981265996_item	2945405	et	4	main
kodumaa	doc_929981265996_item	2945407	et	4	main
traditsioone	doc_929981265996_item	2945408	et	3	main
kes	doc_929981265996_item	2945421	et	4	main
juust	doc_929981265996_item	2945319	et	4	main
või	doc_929981265996_item	2945322	et	4	main
ekspordile	doc_929981265996_item	2945324	et	3	main
kasu	doc_929981265996_item	2945327	et	4	main
kunstside	doc_929981265996_item	2945347	et	4	main
ehitus	doc_929981265996_item	2945351	et	4	main
kiiresti	doc_929981265996_item	2945356	et	3	main
suhted	doc_929981265996_item	2945360	et	3	main
liiv	doc_929981265996_item	2945375	et	3	main
eesti	doc_929981265996_item	2945377	et	4	main
sest	doc_929981265996_item	2945383	et	4	main
rühmitus	doc_929981265996_item	2945385	et	4	main
suundumused	doc_929981265996_item	2945396	et	4	main
gaidid	doc_929981265996_item	2945397	et	3	main
ja	doc_929981265996_item	2945398	et	3	main
skaudid	doc_929981265996_item	2945399	et	3	main
noormehed	doc_929981265996_item	2945404	et	3	main
oma	doc_929981265996_item	2945406	et	4	main
sai	doc_929981265996_item	2945427	et	4	main
pärast	doc_929981265996_item	2945428	et	4	main
kultuuriloost	doc_940752626606_item	2945434	et	4	main
1	doc_940752626606_item	2945435	et	2	main
2	doc_940752626606_item	2945440	et	2	main
miks	doc_940752626606_item	2945441	et	4	main
ristisõdade	doc_940752626606_item	2945450	et	3	main
algusega	doc_940752626606_item	2945451	et	3	main
eesti	doc_940752626606_item	2945455	et	4	main
aladele	doc_940752626606_item	2945456	et	3	main
palju	doc_940752626606_item	2945458	et	4	main
muistne	doc_940752626606_item	2945460	et	3	main
tulnud	doc_940752626606_item	2945470	et	4	main
tallinn	doc_940752626606_item	2945494	et	4	main
tartu	doc_940752626606_item	2945496	et	4	main
ka	doc_940752626606_item	2945498	et	3	main
olid	doc_940752626606_item	2945507	et	4	main
kirikud	doc_940752626606_item	2945508	et	3	main
tööliste	doc_940752626606_item	2945512	et	4	main
määrasid	doc_940752626606_item	2945517	et	4	main
kõrguse	doc_940752626606_item	2945520	et	4	main
relvastamine	doc_929981265996_item	2945330	et	4	main
kõrgemal	doc_929981265996_item	2945345	et	4	main
astmel	doc_929981265996_item	2945346	et	3	main
partneri	doc_929981265996_item	2945359	et	3	main
saksamaaga	doc_929981265996_item	2945362	et	3	main
palju	doc_929981265996_item	2945365	et	4	main
kruus	doc_929981265996_item	2945374	et	3	main
rolli	doc_929981265996_item	2945382	et	4	main
vabriigi	doc_929981265996_item	2945388	et	4	main
uuendamist	doc_929981265996_item	2945391	et	4	main
ilmusid	doc_929981265996_item	2945393	et	4	main
ka	doc_929981265996_item	2945394	et	3	main
uued	doc_929981265996_item	2945395	et	3	main
kotkad	doc_929981265996_item	2945403	et	3	main
kombeid	doc_929981265996_item	2945409	et	4	main
kuidas	doc_929981265996_item	2945410	et	3	main
säilitada	doc_929981265996_item	2945411	et	3	main
eesti	doc_929981265996_item	2945412	et	4	main
kultuuris	doc_929981265996_item	2945413	et	3	main
individuaalsust	doc_929981265996_item	2945414	et	4	main
iseseisvust	doc_929981265996_item	2945415	et	4	main
noor-eesti	doc_929981265996_item	2945416	et	4	main
rühmitusse	doc_929981265996_item	2945417	et	4	main
kuulusid	doc_929981265996_item	2945418	et	4	main
noored	doc_929981265996_item	2945419	et	3	main
kirjanikud	doc_929981265996_item	2945420	et	3	main
uuest	doc_929981265996_item	2945423	et	3	main
vabariigist	doc_929981265996_item	2945425	et	3	main
kontrolltöö	doc_940752626606_item	2945431	et	4	main
sai	doc_940752626606_item	2945442	et	4	main
eestlaste	doc_940752626606_item	2945453	et	4	main
välismaalasi	doc_940752626606_item	2945459	et	3	main
mõju	doc_940752626606_item	2945468	et	4	main
alla	doc_940752626606_item	2945469	et	3	main
kaupmehed	doc_940752626606_item	2945471	et	3	main
linnas	doc_940752626606_item	2945506	et	4	main
kaupmeeste	doc_940752626606_item	2945510	et	4	main
ja	doc_940752626606_item	2945511	et	3	main
raekoda	doc_940752626606_item	2945516	et	4	main
teiste	doc_940752626606_item	2945518	et	4	main
ehitiste	doc_940752626606_item	2945519	et	3	main
ja	doc_940752626606_item	2945539	et	3	main
näide	doc_940752626606_item	2945544	et	3	main
on	doc_940752626606_item	2945547	et	4	main
oli	doc_940752626606_item	2945561	et	3	main
lüübeki	doc_940752626606_item	2945562	et	4	main
haapsalu	doc_940752626606_item	2945580	et	4	main
linna	doc_940752626606_item	2945583	et	4	main
oli	doc_940752626606_item	2945585	et	3	main
alguses	doc_940752626606_item	2945589	et	4	main
oli	doc_940752626606_item	2945590	et	3	main
käsitöö	doc_940752626606_item	2945611	et	4	main
olid	doc_940752626606_item	2945620	et	4	main
eesti	doc_929981265996_item	2945424	et	4	main
nendest	doc_929981265996_item	2945426	et	4	main
kontrolltöö	doc_940752626606_item	2945432	et	4	main
võimalikuks	doc_940752626606_item	2945443	et	3	main
vene-liivi	doc_940752626606_item	2945444	et	4	main
ristiusustamisega	doc_940752626606_item	2945454	et	3	main
jõudis	doc_940752626606_item	2945457	et	3	main
eesti	doc_940752626606_item	2945461	et	4	main
saatus	doc_940752626606_item	2945462	et	3	main
vikingiajast	doc_940752626606_item	2945463	et	4	main
käsitöölised	doc_940752626606_item	2945472	et	3	main
ja	doc_940752626606_item	2945473	et	3	main
misjonärid	doc_940752626606_item	2945474	et	3	main
tõid	doc_940752626606_item	2945475	et	4	main
endaga	doc_940752626606_item	2945476	et	4	main
kaasa	doc_940752626606_item	2945477	et	4	main
oma	doc_940752626606_item	2945478	et	4	main
kombed	doc_940752626606_item	2945479	et	3	main
kultuuri	doc_940752626606_item	2945480	et	4	main
hakkasid	doc_940752626606_item	2945481	et	4	main
tekkima	doc_940752626606_item	2945482	et	3	main
1201	doc_940752626606_item	2945484	et	2	main
linnad	doc_940752626606_item	2945483	et	3	main
rajatakse	doc_940752626606_item	2945485	et	4	main
riia	doc_940752626606_item	2945486	et	4	main
linna	doc_940752626606_item	2945487	et	4	main
muistse	doc_940752626606_item	2945488	et	3	main
eesti	doc_940752626606_item	2945489	et	4	main
alal	doc_940752626606_item	2945490	et	4	main
tähtsamad	doc_940752626606_item	2945491	et	4	main
linnad	doc_940752626606_item	2945492	et	3	main
olid	doc_940752626606_item	2945493	et	4	main
paekivi	doc_940752626606_item	2945505	et	4	main
kirik	doc_940752626606_item	2945514	et	3	main
ja	doc_940752626606_item	2945515	et	3	main
mitte	doc_940752626606_item	2945521	et	3	main
raekoda	doc_940752626606_item	2945529	et	4	main
või	doc_940752626606_item	2945530	et	4	main
toomkirik	doc_940752626606_item	2945531	et	3	main
peakirik	doc_940752626606_item	2945532	et	3	main
olid	doc_940752626606_item	2945533	et	4	main
kaitsetonid	doc_940752626606_item	2945534	et	4	main
linnamüürid	doc_940752626606_item	2945535	et	3	main
teed	doc_940752626606_item	2945540	et	4	main
hea	doc_940752626606_item	2945543	et	4	main
linnast	doc_940752626606_item	2945546	et	4	main
meie	doc_940752626606_item	2945548	et	4	main
vana	doc_940752626606_item	2945549	et	4	main
linn	doc_940752626606_item	2945550	et	3	main
linna	doc_940752626606_item	2945551	et	4	main
õigus	doc_940752626606_item	2945555	et	4	main
näiteks	doc_940752626606_item	2945556	et	4	main
24	doc_940752626606_item	2945591	et	2	main
raejuhatus	doc_940752626606_item	2945598	et	4	main
sundik	doc_940752626606_item	2945599	et	4	main
tähtis	doc_940752626606_item	2945606	et	4	main
tegevusala	doc_940752626606_item	2945607	et	4	main
oli	doc_940752626606_item	2945608	et	3	main
kaubandus	doc_940752626606_item	2945609	et	3	main
olid	doc_940752626606_item	2945612	et	4	main
kaupmeeste	doc_940752626606_item	2945614	et	4	main
ühendused	doc_940752626606_item	2945615	et	4	main
tsunftide	doc_940752626606_item	2945616	et	3	main
koosnes	doc_940752626606_item	2945623	et	3	main
kaupmeestest	doc_940752626606_item	2945625	et	4	main
peamiselt	doc_940752626606_item	2945626	et	4	main
sakslastest	doc_940752626606_item	2945627	et	3	main
ja	doc_940752626606_item	2945628	et	3	main
mustpeade	doc_940752626606_item	2945629	et	3	main
gild	doc_940752626606_item	2945630	et	3	main
kuhu	doc_940752626606_item	2945631	et	3	main
päeva	doc_940752626606_item	2945641	et	4	main
elada	doc_940752626606_item	2945651	et	3	main
kehtis	doc_940752626606_item	2945656	et	3	main
kohta	doc_940752626606_item	2945659	et	4	main
siit	doc_940752626606_item	2945660	et	3	main
ka	doc_940752626606_item	2945661	et	3	main
väljend	doc_940752626606_item	2945662	et	3	main
vaba	doc_940752626606_item	2945663	et	4	main
juures	doc_940752626606_item	2945675	et	4	main
rajati	doc_940752626606_item	2945676	et	3	main
jumalasõna	doc_940752626606_item	2945680	et	4	main
tänu	doc_940752626606_item	2945681	et	4	main
õpetatud	doc_940752626606_item	2945682	et	4	main
inimestele	doc_940752626606_item	2945683	et	3	main
on	doc_940752626606_item	2945696	et	4	main
ladinakeelne	doc_940752626606_item	2945702	et	3	main
kuid	doc_940752626606_item	2945703	et	4	main
väljendeid	doc_940752626606_item	2945710	et	3	main
mingi	doc_940752626606_item	2945522	et	4	main
ei	doc_940752626606_item	2945524	et	4	main
tohtinud	doc_940752626606_item	2945525	et	4	main
olla	doc_940752626606_item	2945526	et	3	main
olid	doc_940752626606_item	2945541	et	4	main
keskaegsest	doc_940752626606_item	2945545	et	3	main
korra	doc_940752626606_item	2945552	et	4	main
määras	doc_940752626606_item	2945553	et	4	main
tallinnas	doc_940752626606_item	2945557	et	4	main
linnaõigus	doc_940752626606_item	2945563	et	4	main
riia	doc_940752626606_item	2945564	et	4	main
oli	doc_940752626606_item	2945566	et	3	main
tartus	doc_940752626606_item	2945567	et	3	main
viljandis	doc_940752626606_item	2945568	et	4	main
linnaõigus	doc_940752626606_item	2945565	et	4	main
paides	doc_940752626606_item	2945569	et	4	main
pärnus	doc_940752626606_item	2945570	et	3	main
ja	doc_940752626606_item	2945571	et	3	main
veel	doc_940752626606_item	2945572	et	4	main
siinsel	doc_940752626606_item	2945573	et	3	main
aladel	doc_940752626606_item	2945574	et	3	main
oli	doc_940752626606_item	2945575	et	3	main
piiskopi	doc_940752626606_item	2945576	et	4	main
linnaõigus	doc_940752626606_item	2945577	et	4	main
said	doc_940752626606_item	2945579	et	4	main
raad	doc_940752626606_item	2945586	et	4	main
liiget	doc_940752626606_item	2945594	et	3	main
tundja	doc_940752626606_item	2945601	et	4	main
ja	doc_940752626606_item	2945602	et	3	main
maahärrade	doc_940752626606_item	2945603	et	3	main
linnafoogt	doc_940752626606_item	2945605	et	3	main
näiteks	doc_940752626606_item	2945618	et	4	main
kuulusid	doc_940752626606_item	2945632	et	4	main
seadus	doc_940752626606_item	2945642	et	4	main
kui	doc_940752626606_item	2945643	et	3	main
inimene	doc_940752626606_item	2945644	et	3	main
võis	doc_940752626606_item	2945648	et	4	main
linna	doc_940752626606_item	2945664	et	4	main
õhk	doc_940752626606_item	2945665	et	3	main
linnas	doc_940752626606_item	2945669	et	4	main
lugemist	doc_940752626606_item	2945679	et	4	main
mitu	doc_940752626606_item	2945686	et	4	main
keskaegse	doc_940752626606_item	2945689	et	3	main
ja	doc_940752626606_item	2945691	et	3	main
head	doc_940752626606_item	2945694	et	4	main
näided	doc_940752626606_item	2945695	et	4	main
mis	doc_940752626606_item	2945700	et	4	main
oli	doc_940752626606_item	2945701	et	3	main
ja	doc_940752626606_item	2945709	et	3	main
ajal	doc_940752626606_item	2945724	et	4	main
võib	doc_940752626606_item	2945725	et	3	main
öelda	doc_940752626606_item	2945726	et	4	main
et	doc_940752626606_item	2945727	et	3	main
ka	doc_940752626606_item	2945728	et	3	main
majanduse	doc_940752626606_item	2945729	et	4	main
said	doc_940752626606_item	2945742	et	4	main
ja	doc_940752626606_item	2945750	et	3	main
keskaegne	doc_940752626606_item	2945755	et	3	main
kiiresti	doc_940752626606_item	2945758	et	3	main
euroopa	doc_940752626606_item	2945760	et	4	main
stiilis	doc_940752626606_item	2945768	et	4	main
ikaldused	doc_940752626606_item	2945771	et	4	main
sai	doc_940752626606_item	2945782	et	4	main
sajandil	doc_940752626606_item	2945786	et	3	main
territooriumi	doc_940752626606_item	2945792	et	4	main
juurde	doc_940752626606_item	2945807	et	4	main
endale	doc_940752626606_item	2945808	et	4	main
teha	doc_940752626606_item	2945809	et	3	main
tegelikult	doc_940752626606_item	2945810	et	4	main
alguses	doc_940752626606_item	2945813	et	4	main
mingit	doc_940752626606_item	2945817	et	3	main
edu	doc_940752626606_item	2945818	et	4	main
ja	doc_940752626606_item	2945821	et	3	main
tartu	doc_940752626606_item	2945827	et	4	main
võimude	doc_940752626606_item	2945833	et	3	main
ja	doc_940752626606_item	2945836	et	3	main
sõda	doc_940752626606_item	2945842	et	4	main
venemaa	doc_940752626606_item	2945846	et	4	main
kehtestas	doc_940752626606_item	2945861	et	3	main
tulemusena	doc_940752626606_item	2945865	et	3	main
7-aastane	doc_940752626606_item	2945870	et	4	main
taaniga	doc_940752626606_item	2945872	et	4	main
poolaga	doc_940752626606_item	2945875	et	3	main
oma	doc_940752626606_item	2945878	et	4	main
arheoloogiline	doc_947478791302_item	2945919	et	4	main
kultuur	doc_947478791302_item	2945920	et	3	main
perioodi	doc_940752626606_item	2945646	et	4	main
linnas	doc_940752626606_item	2945649	et	4	main
sai	doc_940752626606_item	2945653	et	4	main
see	doc_940752626606_item	2945655	et	3	main
näiteks	doc_940752626606_item	2945657	et	4	main
talupoegade	doc_940752626606_item	2945658	et	3	main
keskendus	doc_940752626606_item	2945667	et	4	main
ka	doc_940752626606_item	2945668	et	3	main
meil	doc_940752626606_item	2945684	et	4	main
allikat	doc_940752626606_item	2945688	et	3	main
liivimaa	doc_940752626606_item	2945697	et	4	main
kohtus	doc_940752626606_item	2945704	et	4	main
ka	doc_940752626606_item	2945705	et	3	main
eestikeelseid	doc_940752626606_item	2945706	et	3	main
lauseid	doc_940752626606_item	2945708	et	3	main
b	doc_940752626606_item	2945712	et	4	main
siinsel	doc_940752626606_item	2945718	et	3	main
aladel	doc_940752626606_item	2945719	et	3	main
levis	doc_940752626606_item	2945720	et	4	main
eriti	doc_940752626606_item	2945722	et	3	main
mille	doc_940752626606_item	2945744	et	3	main
üldiselt	doc_940752626606_item	2945749	et	4	main
romaani	doc_940752626606_item	2945765	et	4	main
ja	doc_940752626606_item	2945766	et	3	main
hilisgooti	doc_940752626606_item	2945767	et	4	main
ja	doc_940752626606_item	2945774	et	3	main
võimalikuks	doc_940752626606_item	2945783	et	3	main
16	doc_940752626606_item	2945785	et	2	main
liivimaa	doc_940752626606_item	2945794	et	4	main
ei	doc_940752626606_item	2945819	et	4	main
välja	doc_940752626606_item	2945825	et	4	main
siinsete	doc_940752626606_item	2945832	et	4	main
1558	doc_940752626606_item	2945838	et	2	main
kuigi	doc_940752626606_item	2945843	et	3	main
ainult	doc_940752626606_item	2945845	et	4	main
eesti	doc_940752626606_item	2945848	et	4	main
taani	doc_940752626606_item	2945852	et	4	main
rjetzpospolita	doc_940752626606_item	2945855	et	4	main
tugevnev	doc_940752626606_item	2945857	et	4	main
siin	doc_940752626606_item	2945862	et	4	main
ka	doc_940752626606_item	2945869	et	3	main
lõuna-eesti	doc_940752626606_item	2945876	et	4	main
ülemvõimu	doc_940752626606_item	2945879	et	4	main
eesti	doc_947478791302_item	2945915	et	4	main
mõiste	doc_947478791302_item	2945918	et	4	main
periodiseerida	doc_947478791302_item	2945925	et	3	main
ekr	doc_947478791302_item	2945939	et	4	main
ehk	doc_947478791302_item	2945940	et	3	main
mesoliitikumi	doc_947478791302_item	2945958	et	4	main
asjad	doc_947478791302_item	2945974	et	3	main
paleoliitikumi	doc_947478791302_item	2945975	et	4	main
kuigi	doc_947478791302_item	2945980	et	3	main
kultuurikihti	doc_947478791302_item	2945989	et	4	main
eestis	doc_947478791302_item	2945991	et	3	main
võib	doc_947478791302_item	2945992	et	3	main
iseloomustada	doc_947478791302_item	2945993	et	4	main
tegeldi	doc_947478791302_item	2945994	et	3	main
korjati	doc_947478791302_item	2946000	et	3	main
luust	doc_947478791302_item	2946011	et	4	main
ning	doc_947478791302_item	2946012	et	3	main
ning	doc_947478791302_item	2946016	et	3	main
põtru	doc_947478791302_item	2946019	et	3	main
kloostrid	doc_940752626606_item	2945673	et	3	main
mille	doc_940752626606_item	2945674	et	3	main
säilis	doc_940752626606_item	2945685	et	4	main
ajaloolist	doc_940752626606_item	2945687	et	4	main
linnaelu	doc_940752626606_item	2945690	et	4	main
kohta	doc_940752626606_item	2945693	et	4	main
sõnu	doc_940752626606_item	2945707	et	4	main
holnrike	doc_940752626606_item	2945711	et	4	main
russovi	doc_940752626606_item	2945713	et	4	main
kroonika	doc_940752626606_item	2945714	et	4	main
keskaeg	doc_940752626606_item	2945731	et	3	main
oli	doc_940752626606_item	2945732	et	3	main
päris	doc_940752626606_item	2945733	et	4	main
soode	doc_940752626606_item	2945734	et	3	main
periood	doc_940752626606_item	2945735	et	3	main
elanikute	doc_940752626606_item	2945737	et	4	main
jaoks	doc_940752626606_item	2945738	et	4	main
arenes	doc_940752626606_item	2945739	et	3	main
kaubandus	doc_940752626606_item	2945740	et	3	main
tulusid	doc_940752626606_item	2945743	et	4	main
arenes	doc_940752626606_item	2945757	et	3	main
ja	doc_940752626606_item	2945759	et	3	main
mõju	doc_940752626606_item	2945761	et	4	main
all	doc_940752626606_item	2945762	et	3	main
ehitised	doc_940752626606_item	2945763	et	3	main
gooti	doc_940752626606_item	2945764	et	4	main
kuigi	doc_940752626606_item	2945769	et	3	main
ja	doc_940752626606_item	2945772	et	3	main
linnaelu	doc_940752626606_item	2945777	et	4	main
sest	doc_940752626606_item	2945784	et	4	main
tugenenud	doc_940752626606_item	2945787	et	4	main
vene	doc_940752626606_item	2945788	et	4	main
riik	doc_940752626606_item	2945789	et	3	main
tahtis	doc_940752626606_item	2945790	et	3	main
oli	doc_940752626606_item	2945795	et	3	main
saj	doc_940752626606_item	2945812	et	4	main
venemaa	doc_940752626606_item	2945814	et	4	main
sõjakäigud	doc_940752626606_item	2945815	et	3	main
venemaale	doc_940752626606_item	2945816	et	4	main
mõtlesid	doc_940752626606_item	2945824	et	4	main
maksu	doc_940752626606_item	2945828	et	4	main
põhjendamatu	doc_940752626606_item	2945835	et	4	main
aastal	doc_940752626606_item	2945839	et	3	main
mitte	doc_940752626606_item	2945844	et	3	main
unistas	doc_940752626606_item	2945847	et	3	main
ka	doc_940752626606_item	2945851	et	3	main
leedu	doc_940752626606_item	2945854	et	4	main
ning	doc_940752626606_item	2945856	et	3	main
kes	doc_940752626606_item	2945859	et	4	main
mille	doc_940752626606_item	2945866	et	3	main
sõna	doc_940752626606_item	2945871	et	4	main
ja	doc_940752626606_item	2945873	et	3	main
1661a	doc_940752626606_item	2945881	et	4	main
kiviaeg	doc_947478791302_item	2945914	et	3	main
territooriumil	doc_947478791302_item	2945916	et	3	main
2	doc_947478791302_item	2945917	et	2	main
1	doc_947478791302_item	2945922	et	2	main
kiviaeg	doc_947478791302_item	2945929	et	3	main
at	doc_947478791302_item	2945931	et	4	main
ekr	doc_947478791302_item	2945932	et	4	main
mesoliitikum	doc_947478791302_item	2945933	et	3	main
at	doc_947478791302_item	2945938	et	4	main
neoliitikum	doc_947478791302_item	2945943	et	3	main
aastatuhat	doc_947478791302_item	2945945	et	4	main
kiviaeg	doc_947478791302_item	2945951	et	3	main
eesti	doc_947478791302_item	2945964	et	4	main
luust	doc_947478791302_item	2945971	et	4	main
ja	doc_947478791302_item	2945972	et	3	main
baltimaades	doc_947478791302_item	2945981	et	4	main
leedus	doc_947478791302_item	2945983	et	4	main
inimestel	doc_947478791302_item	2945986	et	3	main
marju	doc_947478791302_item	2946002	et	3	main
seeni	doc_947478791302_item	2946005	et	3	main
praktiliselt	doc_947478791302_item	2946007	et	4	main
ei	doc_947478791302_item	2946008	et	4	main
valmistatud	doc_947478791302_item	2946014	et	4	main
vibudega	doc_947478791302_item	2946018	et	3	main
asula	doc_947478791302_item	2946031	et	4	main
selle	doc_947478791302_item	2946037	et	4	main
on	doc_947478791302_item	2946045	et	4	main
10	doc_947478791302_item	2946046	et	2	main
henriku	doc_940752626606_item	2945698	et	4	main
kroonika	doc_940752626606_item	2945699	et	4	main
tänu	doc_940752626606_item	2945715	et	4	main
kristlikule	doc_940752626606_item	2945716	et	3	main
usule	doc_940752626606_item	2945717	et	3	main
lugemisoskus	doc_940752626606_item	2945721	et	3	main
rootsi	doc_940752626606_item	2945723	et	4	main
linna	doc_940752626606_item	2945736	et	4	main
võib	doc_940752626606_item	2945752	et	3	main
et	doc_940752626606_item	2945754	et	3	main
linnakultuur	doc_940752626606_item	2945756	et	3	main
katkud	doc_940752626606_item	2945773	et	4	main
haigused	doc_940752626606_item	2945776	et	4	main
õitses	doc_940752626606_item	2945778	et	4	main
2	doc_940752626606_item	2945779	et	2	main
vene-liivi	doc_940752626606_item	2945780	et	4	main
oma	doc_940752626606_item	2945791	et	4	main
killustatud	doc_940752626606_item	2945797	et	4	main
16	doc_940752626606_item	2945811	et	2	main
toonud	doc_940752626606_item	2945820	et	4	main
suhtes	doc_940752626606_item	2945730	et	4	main
kaupmehed	doc_940752626606_item	2945741	et	3	main
arvel	doc_940752626606_item	2945745	et	4	main
arenes	doc_940752626606_item	2945746	et	3	main
ka	doc_940752626606_item	2945747	et	3	main
linn	doc_940752626606_item	2945748	et	3	main
kokkuvõttes	doc_940752626606_item	2945751	et	3	main
öelda	doc_940752626606_item	2945753	et	4	main
olid	doc_940752626606_item	2945770	et	4	main
teised	doc_940752626606_item	2945775	et	4	main
sõda	doc_940752626606_item	2945781	et	4	main
laiendada	doc_940752626606_item	2945793	et	3	main
feodaalselt	doc_940752626606_item	2945796	et	4	main
ja	doc_940752626606_item	2945798	et	3	main
omavahelistes	doc_940752626606_item	2945799	et	4	main
suhetes	doc_940752626606_item	2945800	et	3	main
nõrk	doc_940752626606_item	2945801	et	3	main
aga	doc_940752626606_item	2945802	et	3	main
idanaaber	doc_940752626606_item	2945803	et	3	main
tahtis	doc_940752626606_item	2945804	et	3	main
läbikäiku	doc_940752626606_item	2945805	et	4	main
läänemere	doc_940752626606_item	2945806	et	3	main
venelased	doc_940752626606_item	2945823	et	3	main
maksmist	doc_940752626606_item	2945829	et	4	main
see	doc_940752626606_item	2945830	et	3	main
nii	doc_940752626606_item	2945837	et	3	main
alustasid	doc_940752626606_item	2945841	et	4	main
aladelt	doc_940752626606_item	2945849	et	3	main
poola-	doc_940752626606_item	2945853	et	4	main
rootsi	doc_940752626606_item	2945858	et	4	main
liivi	doc_940752626606_item	2945863	et	4	main
sees	doc_940752626606_item	2945867	et	4	main
ja	doc_940752626606_item	2945880	et	3	main
tähendus	doc_947478791302_item	2945921	et	4	main
paleoliitikum	doc_947478791302_item	2945926	et	3	main
vanem	doc_947478791302_item	2945928	et	4	main
ix	doc_947478791302_item	2945934	et	4	main
kiviaeg	doc_947478791302_item	2945942	et	3	main
ekr	doc_947478791302_item	2945946	et	4	main
ii	doc_947478791302_item	2945947	et	4	main
praeguse	doc_947478791302_item	2945952	et	3	main
alal	doc_947478791302_item	2945954	et	4	main
tekkis	doc_947478791302_item	2945955	et	3	main
elu	doc_947478791302_item	2945956	et	4	main
ajal	doc_947478791302_item	2945959	et	4	main
kultuuri	doc_947478791302_item	2945961	et	4	main
kuulus	doc_947478791302_item	2945963	et	4	main
tunnuseks	doc_947478791302_item	2945969	et	3	main
on	doc_947478791302_item	2945970	et	4	main
inimasustus	doc_947478791302_item	2945978	et	3	main
õhukesi	doc_947478791302_item	2945988	et	4	main
mesoliitikumit	doc_947478791302_item	2945990	et	4	main
praktiliselt	doc_947478791302_item	2945995	et	4	main
kalanduse	doc_947478791302_item	2945996	et	3	main
ja	doc_947478791302_item	2946003	et	3	main
tarvitatud	doc_947478791302_item	2946009	et	4	main
kütiti	doc_947478791302_item	2946010	et	3	main
nooleotsiga	doc_947478791302_item	2946015	et	4	main
puust	doc_947478791302_item	2946017	et	4	main
ning	doc_947478791302_item	2946020	et	3	main
harpuunidega	doc_947478791302_item	2946021	et	3	main
ning	doc_947478791302_item	2946024	et	3	main
hülgeid	doc_947478791302_item	2946025	et	3	main
leidude	doc_947478791302_item	2946038	et	4	main
põhjal	doc_947478791302_item	2946039	et	4	main
võib	doc_947478791302_item	2946040	et	3	main
ajajärgul	doc_947478791302_item	2946055	et	3	main
palju	doc_947478791302_item	2946058	et	4	main
keraamika	doc_947478791302_item	2946076	et	4	main
kasutuselevõtt	doc_947478791302_item	2946077	et	3	main
iii	doc_947478791302_item	2946087	et	4	main
koonusekujulised	doc_947478791302_item	2946093	et	4	main
savinõud	doc_947478791302_item	2946094	et	3	main
muistsed	doc_947478791302_item	2946095	et	3	main
eestlased	doc_947478791302_item	2946096	et	3	main
venekirve	doc_947478791302_item	2946112	et	3	main
kujuliste	doc_947478791302_item	2946115	et	4	main
ajal	doc_947478791302_item	2946139	et	4	main
tulekivist	doc_947478791302_item	2946142	et	4	main
hüljeste	doc_947478791302_item	2946159	et	3	main
kasutati	doc_947478791302_item	2946161	et	4	main
olid	doc_947478791302_item	2946187	et	4	main
kultuuri	doc_947478791302_item	2946201	et	4	main
tööriistu	doc_947478791302_item	2946215	et	3	main
animeeritud	doc_947478791302_item	2946219	et	4	main
kujusid	doc_947478791302_item	2946220	et	3	main
sellepärast	doc_940752626606_item	2945822	et	3	main
nn	doc_940752626606_item	2945826	et	4	main
oli	doc_940752626606_item	2945831	et	3	main
jaoks	doc_940752626606_item	2945834	et	4	main
venelased	doc_940752626606_item	2945840	et	3	main
vaid	doc_940752626606_item	2945850	et	3	main
hiljem	doc_940752626606_item	2945860	et	3	main
sõja	doc_940752626606_item	2945864	et	3	main
oli	doc_940752626606_item	2945868	et	3	main
kokkupõrked	doc_940752626606_item	2945874	et	3	main
pärast	doc_940752626606_item	2945877	et	4	main
oliwa	doc_940752626606_item	2945882	et	4	main
rahuga	doc_940752626606_item	2945883	et	3	main
kui	doc_940752626606_item	2945884	et	3	main
ruhnu	doc_940752626606_item	2945885	et	4	main
sai	doc_940752626606_item	2945886	et	4	main
ka	doc_940752626606_item	2945887	et	3	main
rootsi	doc_940752626606_item	2945888	et	4	main
impeeriumi	doc_940752626606_item	2945889	et	4	main
koosseisu	doc_940752626606_item	2945890	et	4	main
tegi	doc_940752626606_item	2945891	et	4	main
läänemere	doc_940752626606_item	2945892	et	3	main
oma	doc_940752626606_item	2945893	et	4	main
sisemereks	doc_940752626606_item	2945894	et	3	main
venelased	doc_940752626606_item	2945895	et	3	main
jäid	doc_940752626606_item	2945896	et	4	main
kaotajateks	doc_940752626606_item	2945897	et	4	main
kuigi	doc_940752626606_item	2945898	et	3	main
pärast	doc_940752626606_item	2945899	et	4	main
17	doc_940752626606_item	2945900	et	2	main
saj	doc_940752626606_item	2945901	et	4	main
proovisid	doc_940752626606_item	2945902	et	4	main
vallutada	doc_940752626606_item	2945903	et	3	main
eesti	doc_940752626606_item	2945904	et	4	main
eduta	doc_940752626606_item	2945905	et	4	main
mis	doc_940752626606_item	2945906	et	4	main
õnnestus	doc_940752626606_item	2945907	et	4	main
ainult	doc_940752626606_item	2945908	et	4	main
pärast	doc_940752626606_item	2945909	et	4	main
põhjasõda	doc_940752626606_item	2945910	et	4	main
vastus	doc_947478791302_item	2945911	et	3	main
küsimusele	doc_947478791302_item	2945912	et	4	main
1	doc_947478791302_item	2945913	et	2	main
võib	doc_947478791302_item	2945924	et	3	main
viii	doc_947478791302_item	2945930	et	4	main
keskmine	doc_947478791302_item	2945941	et	3	main
noorem	doc_947478791302_item	2945950	et	4	main
eesti	doc_947478791302_item	2945953	et	4	main
arheoloogilise	doc_947478791302_item	2945960	et	4	main
mesoliitikumi	doc_947478791302_item	2945965	et	4	main
savist	doc_947478791302_item	2945973	et	4	main
puudus	doc_947478791302_item	2945979	et	4	main
eriti	doc_947478791302_item	2945982	et	3	main
muistsetelt	doc_947478791302_item	2945985	et	3	main
jäänud	doc_947478791302_item	2945987	et	4	main
küttimisega	doc_947478791302_item	2945999	et	4	main
juurikaid	doc_947478791302_item	2946004	et	4	main
kalu	doc_947478791302_item	2946023	et	4	main
mesoliitikumist	doc_947478791302_item	2946026	et	4	main
pärit	doc_947478791302_item	2946028	et	3	main
pärnu	doc_947478791302_item	2946034	et	4	main
jõe	doc_947478791302_item	2946035	et	3	main
väita	doc_947478791302_item	2946041	et	4	main
et	doc_947478791302_item	2946042	et	3	main
noorem	doc_947478791302_item	2946052	et	4	main
kiviaeg	doc_947478791302_item	2946053	et	3	main
sest	doc_947478791302_item	2946064	et	4	main
sel	doc_947478791302_item	2946065	et	3	main
ajal	doc_947478791302_item	2946066	et	4	main
neoliitikumi	doc_947478791302_item	2946072	et	4	main
tähtsamaks	doc_947478791302_item	2946073	et	4	main
tunnuseks	doc_947478791302_item	2946074	et	3	main
oli	doc_947478791302_item	2946075	et	3	main
tunnuseks	doc_947478791302_item	2946103	et	3	main
oli	doc_947478791302_item	2946104	et	3	main
jämedast	doc_947478791302_item	2946105	et	3	main
savist	doc_947478791302_item	2946106	et	4	main
ja	doc_947478791302_item	2946107	et	3	main
teokarpidest	doc_947478791302_item	2946108	et	3	main
kirvedega	doc_947478791302_item	2946116	et	4	main
on	doc_947478791302_item	2946117	et	4	main
kiviaega	doc_947478791302_item	2945923	et	4	main
ehk	doc_947478791302_item	2945927	et	3	main
at	doc_947478791302_item	2945935	et	4	main
ekr	doc_947478791302_item	2945936	et	4	main
iv	doc_947478791302_item	2945937	et	4	main
iii	doc_947478791302_item	2945944	et	4	main
atek	doc_947478791302_item	2945948	et	4	main
ehk	doc_947478791302_item	2945949	et	3	main
alles	doc_947478791302_item	2945957	et	3	main
poolest	doc_947478791302_item	2945962	et	4	main
ajal	doc_947478791302_item	2945966	et	4	main
kunda	doc_947478791302_item	2945967	et	4	main
kultuurisse	doc_947478791302_item	2945968	et	3	main
ajal	doc_947478791302_item	2945976	et	4	main
eestis	doc_947478791302_item	2945977	et	3	main
leiti	doc_947478791302_item	2945984	et	3	main
koriluse	doc_947478791302_item	2945997	et	4	main
ning	doc_947478791302_item	2945998	et	3	main
valdavalt	doc_947478791302_item	2946001	et	4	main
soogiks	doc_947478791302_item	2946006	et	4	main
kivist	doc_947478791302_item	2946013	et	4	main
püüti	doc_947478791302_item	2946022	et	3	main
pulli	doc_947478791302_item	2946032	et	4	main
asula	doc_947478791302_item	2946033	et	4	main
000	doc_947478791302_item	2946047	et	2	main
aastat	doc_947478791302_item	2946048	et	3	main
vana	doc_947478791302_item	2946049	et	4	main
neoliitikum	doc_947478791302_item	2946050	et	3	main
e	doc_947478791302_item	2946051	et	4	main
võib	doc_947478791302_item	2946056	et	3	main
eestit	doc_947478791302_item	2946057	et	3	main
paremini	doc_947478791302_item	2946059	et	4	main
kui	doc_947478791302_item	2946061	et	3	main
kultuurikiht	doc_947478791302_item	2946068	et	3	main
levis	doc_947478791302_item	2946080	et	4	main
kammivajutistega	doc_947478791302_item	2946082	et	4	main
koonuselise	doc_947478791302_item	2946083	et	4	main
alusega	doc_947478791302_item	2946084	et	4	main
nõud	doc_947478791302_item	2946085	et	3	main
ning	doc_947478791302_item	2946086	et	3	main
nöörkeraamika	doc_947478791302_item	2946091	et	4	main
nöörivajutistega	doc_947478791302_item	2946092	et	3	main
ajajärgul	doc_947478791302_item	2946099	et	3	main
kultuuri	doc_947478791302_item	2946101	et	4	main
ka	doc_947478791302_item	2946111	et	3	main
pooside	doc_947478791302_item	2946114	et	3	main
neoliitikumis	doc_947478791302_item	2946122	et	3	main
veel	doc_947478791302_item	2946124	et	4	main
valdavalt	doc_947478791302_item	2946140	et	4	main
kuid	doc_947478791302_item	2946149	et	4	main
ei	doc_947478791302_item	2946151	et	4	main
karusid	doc_947478791302_item	2946158	et	3	main
eesti	doc_947478791302_item	2946185	et	4	main
alal	doc_947478791302_item	2946186	et	4	main
veel	doc_947478791302_item	2946196	et	4	main
külast	doc_947478791302_item	2946205	et	4	main
väljaspool	doc_947478791302_item	2946206	et	3	main
matmisel	doc_947478791302_item	2946207	et	4	main
püüti	doc_947478791302_item	2946208	et	3	main
matkida	doc_947478791302_item	2946209	et	3	main
inimeste	doc_947478791302_item	2946210	et	3	main
magamisasendit	doc_947478791302_item	2946211	et	3	main
surnutele	doc_947478791302_item	2946212	et	4	main
ehteid	doc_947478791302_item	2946216	et	3	main
kujukesi	doc_947478791302_item	2946217	et	4	main
surma	doc_947478791302_item	2946224	et	4	main
kiviaega	doc_947478791302_item	2946225	et	4	main
eestis	doc_947478791302_item	2946226	et	3	main
eesti	doc_947478791302_item	2946236	et	4	main
nappus	doc_947478791302_item	2946244	et	4	main
puudus	doc_947478791302_item	2946250	et	4	main
otsene	doc_947478791302_item	2946251	et	3	main
motiiv	doc_947478791302_item	2946252	et	3	main
sõjaks	doc_947478791302_item	2946253	et	3	main
ka	doc_947478791302_item	2946254	et	3	main
inimeste	doc_947478791302_item	2946255	et	3	main
mida	doc_947478791302_item	2946259	et	4	main
ja	doc_947478791302_item	2946261	et	3	main
ta	doc_947478791302_item	2946267	et	4	main
ajaloole	doc_947478791302_item	2946286	et	4	main
näided	doc_947478791302_item	2946290	et	4	main
kultuur	doc_947478791302_item	2946294	et	3	main
on	doc_947478791302_item	2946027	et	4	main
eesti	doc_947478791302_item	2946029	et	4	main
esimene	doc_947478791302_item	2946030	et	3	main
lähedal	doc_947478791302_item	2946036	et	4	main
eesti	doc_947478791302_item	2946043	et	4	main
kultuur	doc_947478791302_item	2946044	et	3	main
iseloomusta	doc_947478791302_item	2946060	et	4	main
näiteks	doc_947478791302_item	2946062	et	4	main
mesoliitikul	doc_947478791302_item	2946063	et	4	main
atekr	doc_947478791302_item	2946079	et	4	main
at	doc_947478791302_item	2946088	et	4	main
ekr	doc_947478791302_item	2946089	et	4	main
levis	doc_947478791302_item	2946090	et	4	main
tol	doc_947478791302_item	2946098	et	3	main
narva	doc_947478791302_item	2946100	et	4	main
selle	doc_947478791302_item	2946102	et	4	main
eestile	doc_947478791302_item	2946118	et	3	main
sel	doc_947478791302_item	2946119	et	3	main
ajal	doc_947478791302_item	2946120	et	4	main
omane	doc_947478791302_item	2946121	et	3	main
valdavalt	doc_947478791302_item	2946125	et	4	main
algelist	doc_947478791302_item	2946134	et	4	main
kõplapõllundust	doc_947478791302_item	2946135	et	4	main
tööriistad	doc_947478791302_item	2946136	et	3	main
tehti	doc_947478791302_item	2946137	et	3	main
sel	doc_947478791302_item	2946138	et	3	main
lelistellkividest	doc_947478791302_item	2946143	et	4	main
kasvatati	doc_947478791302_item	2946145	et	3	main
hirssi	doc_947478791302_item	2946147	et	4	main
metstarvast	doc_947478791302_item	2946157	et	4	main
noorkeraamika	doc_947478791302_item	2946177	et	4	main
neoliitikumi	doc_947478791302_item	2946181	et	4	main
üheks	doc_947478791302_item	2946182	et	3	main
ka	doc_947478791302_item	2946184	et	3	main
aasta	doc_947478791302_item	2946191	et	4	main
tuhandel	doc_947478791302_item	2946192	et	3	main
ekr	doc_947478791302_item	2946193	et	4	main
maeti	doc_947478791302_item	2946194	et	3	main
usuti	doc_947478791302_item	2946221	et	3	main
ei	doc_947478791302_item	2946246	et	4	main
asustus	doc_947478791302_item	2946256	et	4	main
sõjakamaks	doc_947478791302_item	2946266	et	4	main
muutus	doc_947478791302_item	2946268	et	4	main
kultuuridest	doc_947478791302_item	2946292	et	3	main
tähendus	doc_947478791303_item	2946311	et	4	main
leia	doc_947478791303_item	2946319	et	4	main
sellel	doc_947478791302_item	2946054	et	4	main
leitud	doc_947478791302_item	2946067	et	4	main
on	doc_947478791302_item	2946069	et	4	main
märksa	doc_947478791302_item	2946070	et	3	main
paksem	doc_947478791302_item	2946071	et	4	main
vi	doc_947478791302_item	2946078	et	4	main
kammkeraamika	doc_947478791302_item	2946081	et	4	main
kuulusid	doc_947478791302_item	2946097	et	4	main
valmistatud	doc_947478791302_item	2946109	et	4	main
nõud	doc_947478791302_item	2946110	et	3	main
kultuur	doc_947478791302_item	2946113	et	3	main
kalastamine	doc_947478791302_item	2946129	et	4	main
korilus	doc_947478791302_item	2946130	et	4	main
kuid	doc_947478791302_item	2946131	et	4	main
hakati	doc_947478791302_item	2946132	et	3	main
kasutama	doc_947478791302_item	2946133	et	3	main
kivist	doc_947478791302_item	2946141	et	4	main
nisu	doc_947478791302_item	2946146	et	4	main
otri	doc_947478791302_item	2946148	et	3	main
see	doc_947478791302_item	2946150	et	3	main
põtru	doc_947478791302_item	2946156	et	3	main
rasva	doc_947478791302_item	2946160	et	4	main
valgusallikana	doc_947478791302_item	2946162	et	4	main
segainimestega	doc_947478791302_item	2946176	et	3	main
sarnanesid	doc_947478791302_item	2946179	et	4	main
omapärased	doc_947478791302_item	2946188	et	4	main
inimesi	doc_947478791302_item	2946195	et	4	main
isegi	doc_947478791302_item	2946197	et	4	main
püstkodade	doc_947478791302_item	2946198	et	3	main
alla	doc_947478791302_item	2946199	et	3	main
nöörkeraamika	doc_947478791302_item	2946200	et	4	main
kaasa	doc_947478791302_item	2946214	et	4	main
ning	doc_947478791302_item	2946218	et	3	main
domineeris	doc_947478791302_item	2946123	et	3	main
amestav	doc_947478791302_item	2946126	et	4	main
eluviis	doc_947478791302_item	2946127	et	3	main
küttimine	doc_947478791302_item	2946128	et	4	main
põldude	doc_947478791302_item	2946144	et	4	main
olnud	doc_947478791302_item	2946152	et	4	main
peamine	doc_947478791302_item	2946153	et	3	main
toiduallikas	doc_947478791302_item	2946154	et	4	main
kütiti	doc_947478791302_item	2946155	et	3	main
elati	doc_947478791302_item	2946163	et	3	main
püstkodades	doc_947478791302_item	2946164	et	3	main
kogukonnas	doc_947478791302_item	2946165	et	4	main
oli	doc_947478791302_item	2946166	et	3	main
umbes	doc_947478791302_item	2946167	et	4	main
100	doc_947478791302_item	2946168	et	2	main
inimest	doc_947478791302_item	2946169	et	3	main
kammkeraamika	doc_947478791302_item	2946170	et	4	main
inimesed	doc_947478791302_item	2946171	et	3	main
sarnanesid	doc_947478791302_item	2946172	et	4	main
mongoliidide	doc_947478791302_item	2946173	et	3	main
europiidide	doc_947478791302_item	2946175	et	3	main
ja	doc_947478791302_item	2946174	et	3	main
inimesed	doc_947478791302_item	2946178	et	3	main
indoeurooplastega	doc_947478791302_item	2946180	et	3	main
tunnuseks	doc_947478791302_item	2946183	et	3	main
matmiskombed	doc_947478791302_item	2946189	et	3	main
iv	doc_947478791302_item	2946190	et	4	main
levimisel	doc_947478791302_item	2946202	et	4	main
maeti	doc_947478791302_item	2946203	et	3	main
surnuid	doc_947478791302_item	2946204	et	4	main
pandi	doc_947478791302_item	2946213	et	4	main
elusse	doc_947478791302_item	2946222	et	3	main
võib	doc_947478791302_item	2946227	et	3	main
iseloomustada	doc_947478791302_item	2946228	et	4	main
kui	doc_947478791302_item	2946229	et	3	main
ajaloos	doc_947478791302_item	2946237	et	4	main
söögiülejääke	doc_947478791302_item	2946245	et	4	main
inimene	doc_947478791302_item	2946264	et	3	main
seda	doc_947478791302_item	2946265	et	3	main
kasutuselevõttu	doc_947478791302_item	2946289	et	4	main
narva	doc_947478791302_item	2946293	et	4	main
nöörkeraamika	doc_947478791302_item	2946297	et	4	main
kunda	doc_947478791302_item	2946299	et	4	main
vastus	doc_947478791303_item	2946301	et	3	main
1	doc_947478791303_item	2946303	et	2	main
varane	doc_947478791303_item	2946304	et	4	main
metalliaeg	doc_947478791303_item	2946305	et	3	main
metall	doc_947478791303_item	2946314	et	3	main
ei	doc_947478791303_item	2946318	et	4	main
kulda	doc_947478791303_item	2946320	et	4	main
seda	doc_947478791303_item	2946322	et	3	main
mandrilt	doc_947478791303_item	2946325	et	4	main
kasutati	doc_947478791303_item	2946339	et	4	main
leitud	doc_947478791303_item	2946345	et	4	main
saaremaalt	doc_947478791303_item	2946346	et	4	main
kuna	doc_947478791303_item	2946347	et	3	main
sõideti	doc_947478791303_item	2946348	et	3	main
väga	doc_947478791303_item	2946349	et	3	main
varane	doc_947478791303_item	2946367	et	4	main
aastatuh	doc_947478791303_item	2946371	et	4	main
rauaajal	doc_947478791303_item	2946382	et	3	main
koduloomade	doc_947478791303_item	2946388	et	4	main
on	doc_947478791303_item	2946391	et	4	main
ikka	doc_947478791303_item	2946392	et	4	main
lisaks	doc_947478791303_item	2946413	et	4	main
kasutati	doc_947478791303_item	2946421	et	4	main
kõblas	doc_947478791303_item	2946426	et	3	main
oli	doc_947478791303_item	2946428	et	3	main
kivist	doc_947478791303_item	2946429	et	4	main
sirp	doc_947478791303_item	2946430	et	3	main
oli	doc_947478791303_item	2946431	et	3	main
kasutati	doc_947478791303_item	2946439	et	4	main
rituaalides	doc_947478791303_item	2946440	et	3	main
tal	doc_947478791303_item	2946441	et	3	main
oli	doc_947478791303_item	2946442	et	3	main
et	doc_947478791303_item	2946450	et	3	main
sirpi	doc_947478791303_item	2946453	et	4	main
et	doc_947478791303_item	2946455	et	3	main
hea	doc_947478791303_item	2946458	et	4	main
käsikivi	doc_947478791303_item	2946461	et	4	main
kultuurtaimed	doc_947478791303_item	2946463	et	3	main
lina	doc_947478791303_item	2946464	et	4	main
kasvatus	doc_947478791303_item	2946465	et	4	main
sellega	doc_947478791303_item	2946472	et	3	main
savi	doc_947478791303_item	2946508	et	4	main
sõnnik	doc_947478791303_item	2946509	et	3	main
pärib	doc_947478791303_item	2946520	et	3	main
pae	doc_947478791303_item	2946524	et	3	main
eriti	doc_947478791303_item	2946528	et	3	main
kontakteerisid	doc_947478791303_item	2946544	et	4	main
loodusel	doc_947478791303_item	2946557	et	4	main
nt	doc_947478791303_item	2946561	et	4	main
on	doc_947478791303_item	2946563	et	4	main
vask	doc_947478791304_item	2946588	et	3	main
on	doc_947478791304_item	2946592	et	4	main
arvatud	doc_947478791304_item	2946593	et	4	main
et	doc_947478791304_item	2946594	et	3	main
esimesed	doc_947478791304_item	2946604	et	3	main
on	doc_947478791304_item	2946606	et	4	main
õpiti	doc_947478791304_item	2946610	et	3	main
pronksi	doc_947478791304_item	2946612	et	4	main
kivist	doc_947478791304_item	2946620	et	4	main
suhteliselt	doc_947478791302_item	2946230	et	4	main
rahulikku	doc_947478791302_item	2946231	et	4	main
perioodi	doc_947478791302_item	2946232	et	4	main
sõdu	doc_947478791302_item	2946233	et	3	main
oli	doc_947478791302_item	2946234	et	3	main
vähe	doc_947478791302_item	2946235	et	3	main
suhteline	doc_947478791302_item	2946243	et	4	main
ja	doc_947478791302_item	2946248	et	3	main
seega	doc_947478791302_item	2946249	et	4	main
hõre	doc_947478791302_item	2946258	et	3	main
osavamaks	doc_947478791302_item	2946262	et	4	main
sai	doc_947478791302_item	2946263	et	4	main
2	doc_947478791302_item	2946269	et	2	main
arheoloogiline	doc_947478791302_item	2946270	et	4	main
kultuur	doc_947478791302_item	2946271	et	3	main
arheoloogilistel	doc_947478791302_item	2946272	et	4	main
leidudel	doc_947478791302_item	2946273	et	3	main
muististel	doc_947478791302_item	2946274	et	3	main
põhinev	doc_947478791302_item	2946275	et	4	main
eri	doc_947478791302_item	2946276	et	4	main
rahvaste	doc_947478791302_item	2946277	et	4	main
kultuuriline	doc_947478791302_item	2946278	et	4	main
ning	doc_947478791302_item	2946279	et	3	main
materiaalne	doc_947478791302_item	2946280	et	3	main
kultuur	doc_947478791302_item	2946281	et	3	main
arheoloogiline	doc_947478791302_item	2946282	et	4	main
kultuur	doc_947478791302_item	2946283	et	3	main
on	doc_947478791302_item	2946284	et	4	main
omane	doc_947478791302_item	2946285	et	3	main
pärast	doc_947478791302_item	2946223	et	4	main
selle	doc_947478791302_item	2946238	et	4	main
põhjuseks	doc_947478791302_item	2946239	et	3	main
oli	doc_947478791302_item	2946240	et	3	main
osaliselt	doc_947478791302_item	2946241	et	4	main
varanduse	doc_947478791302_item	2946242	et	3	main
tekkinud	doc_947478791302_item	2946247	et	4	main
oli	doc_947478791302_item	2946257	et	3	main
rikkamaks	doc_947478791302_item	2946260	et	4	main
enne	doc_947478791302_item	2946287	et	4	main
arheoloogilistest	doc_947478791302_item	2946291	et	4	main
kultuur	doc_947478791302_item	2946296	et	3	main
kultuur	doc_947478791302_item	2946298	et	3	main
kultuur	doc_947478791302_item	2946300	et	3	main
küsimusele	doc_947478791303_item	2946302	et	4	main
animism	doc_947478791303_item	2946310	et	3	main
eestis	doc_947478791303_item	2946317	et	3	main
palju	doc_947478791303_item	2946350	et	4	main
üle	doc_947478791303_item	2946351	et	3	main
mere	doc_947478791303_item	2946352	et	3	main
sõja	doc_947478791303_item	2946365	et	3	main
jooksul	doc_947478791303_item	2946366	et	4	main
metalliaeg	doc_947478791303_item	2946368	et	3	main
tehti	doc_947478791303_item	2946378	et	3	main
ja	doc_947478791303_item	2946380	et	3	main
veel	doc_947478791303_item	2946393	et	4	main
veekogude	doc_947478791303_item	2946394	et	3	main
ääres	doc_947478791303_item	2946395	et	4	main
nagu	doc_947478791303_item	2946396	et	3	main
oligi	doc_947478791303_item	2946397	et	3	main
kiviajal	doc_947478791303_item	2946398	et	3	main
pärast	doc_947478791303_item	2946400	et	4	main
neid	doc_947478791303_item	2946401	et	4	main
elab	doc_947478791303_item	2946402	et	3	main
neid	doc_947478791303_item	2946409	et	4	main
vähe	doc_947478791303_item	2946410	et	3	main
inimesed	doc_947478791303_item	2946411	et	3	main
ja	doc_947478791303_item	2946418	et	3	main
hobuseid	doc_947478791303_item	2946419	et	4	main
maakogestamis	doc_947478791303_item	2946424	et	4	main
vilju	doc_947478791303_item	2946436	et	4	main
ja	doc_947478791303_item	2946437	et	3	main
seda	doc_947478791303_item	2946438	et	3	main
sest	doc_947478791303_item	2946449	et	4	main
vette	doc_947478791303_item	2946454	et	3	main
ilm	doc_947478791303_item	2946456	et	3	main
rõivast	doc_947478791303_item	2946467	et	4	main
viljandimaamehed	doc_947478791303_item	2946468	et	3	main
mulk	doc_947478791303_item	2946469	et	3	main
ja	doc_947478791303_item	2946504	et	3	main
uus	doc_947478791303_item	2946518	et	3	main
skandinaaviast	doc_947478791303_item	2946521	et	3	main
see	doc_947478791303_item	2946526	et	3	main
eestis	doc_947478791303_item	2946533	et	3	main
jõuavad	doc_947478791303_item	2946534	et	4	main
skandinaaviaga	doc_947478791303_item	2946549	et	4	main
hing	doc_947478791303_item	2946560	et	3	main
vastus	doc_947478791304_item	2946565	et	3	main
saj	doc_947478791304_item	2946585	et	4	main
on	doc_947478791304_item	2946596	et	4	main
kr	doc_947478791304_item	2946618	et	4	main
ja	doc_947478791304_item	2946621	et	3	main
hakkavad	doc_947478791304_item	2946623	et	4	main
tegelema	doc_947478791304_item	2946624	et	3	main
põllumajandusega	doc_947478791304_item	2946625	et	3	main
seal	doc_947478791304_item	2946626	et	4	main
hulgas	doc_947478791304_item	2946627	et	4	main
ka	doc_947478791304_item	2946628	et	3	main
leitud	doc_947478791304_item	2946633	et	4	main
hobuseid	doc_947478791304_item	2946643	et	4	main
hobuseliha	doc_947478791304_item	2946644	et	4	main
on	doc_947478791304_item	2946650	et	4	main
tehtud	doc_947478791304_item	2946651	et	4	main
sirp	doc_947478791304_item	2946656	et	3	main
maagiline	doc_947478791304_item	2946662	et	4	main
leiti	doc_947478791304_item	2946664	et	3	main
et	doc_947478791304_item	2946666	et	3	main
kasutusel	doc_947478791304_item	2946677	et	4	main
20	doc_947478791304_item	2946680	et	2	main
lina	doc_947478791304_item	2946686	et	4	main
sünvoolne	doc_947478791304_item	2946692	et	4	main
väga	doc_947478791304_item	2946693	et	3	main
kirja	doc_947478791302_item	2946288	et	4	main
kammkeraamika	doc_947478791302_item	2946295	et	4	main
eesti	doc_947478791303_item	2946306	et	4	main
territooriumil	doc_947478791303_item	2946307	et	3	main
2	doc_947478791303_item	2946308	et	2	main
esimene	doc_947478791303_item	2946313	et	3	main
oli	doc_947478791303_item	2946315	et	3	main
ka	doc_947478791303_item	2946327	et	3	main
metall	doc_947478791303_item	2946333	et	3	main
oli	doc_947478791303_item	2946334	et	3	main
tina	doc_947478791303_item	2946337	et	4	main
seda	doc_947478791303_item	2946338	et	3	main
pronksi	doc_947478791303_item	2946342	et	4	main
on	doc_947478791303_item	2946344	et	4	main
ii	doc_947478791303_item	2946370	et	4	main
keskel	doc_947478791303_item	2946372	et	3	main
1	doc_947478791303_item	2946374	et	2	main
saj	doc_947478791303_item	2946375	et	4	main
kivist	doc_947478791303_item	2946379	et	4	main
luust	doc_947478791303_item	2946381	et	4	main
hakkatakse	doc_947478791303_item	2946383	et	4	main
intensiivselt	doc_947478791303_item	2946384	et	4	main
tegelema	doc_947478791303_item	2946385	et	3	main
rohkem	doc_947478791303_item	2946403	et	4	main
kasvatasid	doc_947478791303_item	2946412	et	4	main
hobuseid	doc_947478791303_item	2946420	et	4	main
mis	doc_947478791303_item	2946427	et	4	main
mõiste	doc_947478791303_item	2946309	et	4	main
1	doc_947478791303_item	2946312	et	2	main
kuld	doc_947478791303_item	2946316	et	3	main
aga	doc_947478791303_item	2946321	et	3	main
ameerika	doc_947478791303_item	2946324	et	3	main
ja	doc_947478791303_item	2946326	et	3	main
väga	doc_947478791303_item	2946328	et	3	main
leiti	doc_947478791303_item	2946330	et	3	main
egiptuses	doc_947478791303_item	2946331	et	4	main
teine	doc_947478791303_item	2946332	et	3	main
pronks	doc_947478791303_item	2946335	et	3	main
vask	doc_947478791303_item	2946336	et	3	main
esimesed	doc_947478791303_item	2946341	et	3	main
esemeid	doc_947478791303_item	2946343	et	3	main
ekr-	doc_947478791303_item	2946373	et	4	main
ja	doc_947478791303_item	2946387	et	3	main
kasvatamisega	doc_947478791303_item	2946389	et	4	main
selle	doc_947478791303_item	2946399	et	4	main
peipsi	doc_947478791303_item	2946404	et	4	main
lamastele	doc_947478791303_item	2946414	et	4	main
pronksist	doc_947478791303_item	2946432	et	4	main
sellega	doc_947478791303_item	2946433	et	3	main
maagiline	doc_947478791303_item	2946443	et	4	main
inimesed	doc_947478791303_item	2946451	et	3	main
oleks	doc_947478791303_item	2946457	et	3	main
teravilja	doc_947478791303_item	2946459	et	4	main
abil	doc_947478791303_item	2946462	et	4	main
hakkaid	doc_947478791303_item	2946470	et	4	main
esimesena	doc_947478791303_item	2946471	et	3	main
lydia	doc_947478791303_item	2946474	et	4	main
peale	doc_947478791303_item	2946505	et	4	main
siis	doc_947478791303_item	2946506	et	3	main
pandi	doc_947478791303_item	2946507	et	4	main
muinas	doc_947478791303_item	2946514	et	4	main
linnuseid	doc_947478791303_item	2946515	et	3	main
müüritega	doc_947478791303_item	2946516	et	4	main
leiab	doc_947478791303_item	2946323	et	3	main
palju	doc_947478791303_item	2946329	et	4	main
lähis-idas	doc_947478791303_item	2946340	et	3	main
kaubeldi	doc_947478791303_item	2946353	et	3	main
ka	doc_947478791303_item	2946354	et	3	main
sealsete	doc_947478791303_item	2946355	et	4	main
asuniketega	doc_947478791303_item	2946356	et	4	main
nii	doc_947478791303_item	2946357	et	3	main
et	doc_947478791303_item	2946358	et	3	main
pronksist	doc_947478791303_item	2946359	et	4	main
asju	doc_947478791303_item	2946360	et	3	main
kauba	doc_947478791303_item	2946362	et	3	main
said	doc_947478791303_item	2946361	et	4	main
vahetuses	doc_947478791303_item	2946363	et	4	main
ja	doc_947478791303_item	2946364	et	3	main
eestis	doc_947478791303_item	2946369	et	3	main
pkr	doc_947478791303_item	2946376	et	4	main
ehteid	doc_947478791303_item	2946377	et	3	main
põllumajandusega	doc_947478791303_item	2946386	et	3	main
asulad	doc_947478791303_item	2946390	et	3	main
äres	doc_947478791303_item	2946405	et	4	main
ja	doc_947478791303_item	2946406	et	3	main
lõunas	doc_947478791303_item	2946407	et	3	main
on	doc_947478791303_item	2946408	et	4	main
ja	doc_947478791303_item	2946415	et	3	main
kitsetele	doc_947478791303_item	2946416	et	4	main
sigu	doc_947478791303_item	2946417	et	3	main
põlluriistad	doc_947478791303_item	2946423	et	3	main
vahend	doc_947478791303_item	2946425	et	3	main
lõigata	doc_947478791303_item	2946435	et	4	main
leiti	doc_947478791303_item	2946447	et	3	main
vees	doc_947478791303_item	2946448	et	3	main
jahutati	doc_947478791303_item	2946460	et	4	main
tegelema	doc_947478791303_item	2946473	et	3	main
tol	doc_947478791303_item	2946510	et	3	main
ajal	doc_947478791303_item	2946511	et	4	main
hakkati	doc_947478791303_item	2946512	et	3	main
taratega	doc_947478791303_item	2946517	et	4	main
kaaned	doc_947478791303_item	2946523	et	3	main
saartel	doc_947478791303_item	2946530	et	3	main
põhja	doc_947478791303_item	2946532	et	4	main
sõnad	doc_947478791303_item	2946535	et	4	main
germaani	doc_947478791303_item	2946536	et	3	main
pärit	doc_947478791303_item	2946537	et	3	main
mõõk	doc_947478791303_item	2946538	et	3	main
põld	doc_947478791303_item	2946539	et	3	main
lae	doc_947478791303_item	2946540	et	4	main
volga	doc_947478791303_item	2946545	et	4	main
hõimudega	doc_947478791303_item	2946546	et	3	main
p-e	doc_947478791303_item	2946547	et	3	main
on	doc_947478791303_item	2946558	et	4	main
küsimusele	doc_947478791304_item	2946566	et	4	main
ekr	doc_947478791304_item	2946586	et	4	main
pronks	doc_947478791304_item	2946587	et	3	main
kasutati	doc_947478791304_item	2946590	et	4	main
1	doc_947478791304_item	2946599	et	2	main
valgast	doc_947478791304_item	2946600	et	3	main
ja	doc_947478791304_item	2946601	et	3	main
pronksesemed	doc_947478791304_item	2946605	et	3	main
töötlema	doc_947478791304_item	2946613	et	3	main
pronksiaeg	doc_947478791304_item	2946615	et	3	main
luust	doc_947478791304_item	2946622	et	4	main
on	doc_947478791304_item	2946632	et	4	main
sigu	doc_947478791304_item	2946641	et	3	main
ja	doc_947478791304_item	2946642	et	3	main
ära	doc_947478791304_item	2946647	et	4	main
maaharimisvahend	doc_947478791304_item	2946648	et	3	main
koristati	doc_947478791304_item	2946658	et	3	main
tähendus	doc_947478791304_item	2946663	et	4	main
saada	doc_947478791304_item	2946667	et	4	main
paremat	doc_947478791304_item	2946668	et	4	main
19	doc_947478791304_item	2946678	et	2	main
ja	doc_947478791304_item	2946679	et	3	main
jaoks	doc_947478791304_item	2946688	et	4	main
on	doc_947478791304_item	2946689	et	4	main
see	doc_947478791304_item	2946690	et	3	main
väga	doc_947478791304_item	2946691	et	3	main
skandinaaviast	doc_947478791304_item	2946721	et	3	main
pronksigi	doc_947478791304_item	2946725	et	4	main
rauaaeg	doc_947478791304_item	2946727	et	3	main
põhjal	doc_947478791304_item	2946731	et	4	main
põhja-eesti	doc_947478791304_item	2946738	et	4	main
keskmine	doc_947478791304_item	2946751	et	3	main
pkr	doc_947478791304_item	2946755	et	4	main
suureks	doc_947478791304_item	2946757	et	4	main
rahvaste	doc_947478791304_item	2946758	et	4	main
inimeste	doc_947478791304_item	2946769	et	3	main
konflikt	doc_947478791304_item	2946771	et	3	main
skandinaaviaga	doc_947478791304_item	2946773	et	4	main
saaks	doc_947478791304_item	2946808	et	3	main
kätte	doc_947478791304_item	2946810	et	4	main
rootslased	doc_947478791304_item	2946811	et	3	main
igas	doc_947478791304_item	2946824	et	3	main
oli	doc_947478791304_item	2946826	et	3	main
hakkasid	doc_947478791304_item	2946844	et	4	main
veeloomadena	doc_947478791303_item	2946422	et	3	main
sai	doc_947478791303_item	2946434	et	4	main
tähendus	doc_947478791303_item	2946444	et	4	main
ja	doc_947478791303_item	2946445	et	3	main
seda	doc_947478791303_item	2946446	et	3	main
viskasid	doc_947478791303_item	2946452	et	4	main
kooti	doc_947478791303_item	2946466	et	4	main
koidula	doc_947478791303_item	2946475	et	4	main
kirjutas	doc_947478791303_item	2946476	et	3	main
mulgist	doc_947478791303_item	2946477	et	3	main
tol	doc_947478791303_item	2946478	et	3	main
ajal	doc_947478791303_item	2946479	et	4	main
tegeleti	doc_947478791303_item	2946480	et	3	main
kalapüügiga	doc_947478791303_item	2946481	et	3	main
ja	doc_947478791303_item	2946482	et	3	main
hülgepüügiga	doc_947478791303_item	2946483	et	3	main
kasutati	doc_947478791303_item	2946485	et	4	main
rasva	doc_947478791303_item	2946484	et	4	main
küünlate	doc_947478791303_item	2946486	et	4	main
valmistamiseks	doc_947478791303_item	2946487	et	4	main
ühed	doc_947478791303_item	2946488	et	3	main
hõimud	doc_947478791303_item	2946489	et	4	main
hakkasid	doc_947478791303_item	2946490	et	4	main
teisi	doc_947478791303_item	2946491	et	4	main
röövima	doc_947478791303_item	2946492	et	4	main
selleks	doc_947478791303_item	2946493	et	4	main
et	doc_947478791303_item	2946494	et	3	main
oma	doc_947478791303_item	2946495	et	4	main
vara	doc_947478791303_item	2946496	et	4	main
kaitsta	doc_947478791303_item	2946497	et	4	main
hakkati	doc_947478791303_item	2946498	et	3	main
maase	doc_947478791303_item	2946499	et	4	main
kaivama	doc_947478791303_item	2946500	et	4	main
see	doc_947478791303_item	2946501	et	3	main
oli	doc_947478791303_item	2946502	et	3	main
puu	doc_947478791303_item	2946503	et	4	main
ehitama	doc_947478791303_item	2946513	et	4	main
matusetraditsioon	doc_947478791303_item	2946519	et	3	main
kivi	doc_947478791303_item	2946525	et	4	main
levinud	doc_947478791303_item	2946529	et	4	main
ja	doc_947478791303_item	2946531	et	3	main
haud	doc_947478791303_item	2946541	et	4	main
enam	doc_947478791303_item	2946548	et	4	main
ka	doc_947478791303_item	2946559	et	3	main
hing	doc_947478791303_item	2946564	et	3	main
eestisse	doc_947478791304_item	2946595	et	4	main
leitud	doc_947478791304_item	2946607	et	4	main
siis	doc_947478791304_item	2946609	et	3	main
valmistati	doc_947478791304_item	2946619	et	4	main
loomade	doc_947478791304_item	2946629	et	4	main
lääne	doc_947478791304_item	2946634	et	4	main
söömine	doc_947478791304_item	2946645	et	4	main
kivist	doc_947478791304_item	2946652	et	4	main
on	doc_947478791304_item	2946661	et	4	main
veekogudes	doc_947478791304_item	2946665	et	3	main
olid	doc_947478791304_item	2946676	et	4	main
eestlaste	doc_947478791304_item	2946687	et	4	main
leitud	doc_947478791304_item	2946697	et	4	main
ja	doc_947478791304_item	2946698	et	3	main
viitavad	doc_947478791304_item	2946701	et	4	main
1-5	doc_947478791304_item	2946728	et	2	main
piirkonnad	doc_947478791304_item	2946746	et	4	main
ajaks	doc_947478791304_item	2946760	et	4	main
see	doc_947478791304_item	2946761	et	3	main
oli	doc_947478791304_item	2946762	et	3	main
ka	doc_947478791304_item	2946777	et	3	main
eestist	doc_947478791304_item	2946778	et	3	main
neid	doc_947478791304_item	2946809	et	4	main
pidasid	doc_947478791304_item	2946812	et	4	main
liivakääpadesse	doc_947478791304_item	2946819	et	4	main
tekkima	doc_947478791304_item	2946821	et	3	main
kõige	doc_947478791304_item	2946831	et	4	main
saj	doc_947478791304_item	2946840	et	4	main
rohkem	doc_947478791304_item	2946845	et	4	main
tegelema	doc_947478791304_item	2946846	et	3	main
majanduslik	doc_947478791304_item	2946857	et	3	main
inimestel	doc_947478791304_item	2946859	et	3	main
meisterdamine	doc_947478791304_item	2946871	et	4	main
kaubandus	doc_947478791304_item	2946872	et	3	main
sugulastele	doc_947478791304_item	2946877	et	4	main
hakkavad	doc_947478791304_item	2946880	et	4	main
ja	doc_947478791304_item	2946883	et	3	main
riiki	doc_947478791304_item	2946890	et	4	main
kõikidel	doc_947478791304_item	2946921	et	4	main
ensv	doc_961923037877_item	2946932	et	4	main
ühiskonnakorralduses	doc_961923037877_item	2946933	et	3	main
ja	doc_961923037877_item	2946934	et	3	main
lõppes	doc_961923037877_item	2946949	et	4	main
rahu	doc_961923037877_item	2946957	et	4	main
endast	doc_961923037877_item	2946978	et	4	main
ühiskonnakorraldus	doc_961923037877_item	2946979	et	3	main
alustan	doc_961923037877_item	2946980	et	3	main
kultuurist	doc_961923037877_item	2946981	et	3	main
toetust	doc_961923037877_item	2947026	et	4	main
ajakirjandus	doc_961923037877_item	2947040	et	3	main
sai	doc_961923037877_item	2947053	et	4	main
selle	doc_961923037877_item	2947054	et	4	main
premeerima	doc_961923037877_item	2947070	et	4	main
sai	doc_961923037877_item	2947073	et	4	main
talu	doc_961923037877_item	2947075	et	4	main
kõik	doc_961923037877_item	2947080	et	4	main
pisirahvad	doc_961923037877_item	2947081	et	3	main
praktiliselt	doc_961923037877_item	2947089	et	4	main
emakeelset	doc_961923037877_item	2947098	et	3	main
tegutsesid	doc_961923037877_item	2947100	et	4	main
igasugused	doc_961923037877_item	2947101	et	3	main
seltsid	doc_961923037877_item	2947102	et	4	main
ning	doc_961923037877_item	2947103	et	3	main
jt	doc_961923037877_item	2947121	et	4	main
ja	doc_961923037877_item	2947124	et	3	main
haridus	doc_961923037877_item	2947125	et	3	main
arenes	doc_961923037877_item	2947140	et	3	main
veskile	doc_961923037877_item	2947152	et	3	main
oli	doc_961923037877_item	2947155	et	3	main
parem	doc_961923037877_item	2947174	et	4	main
võrdlen	doc_961923037877_item	2947175	et	3	main
ev	doc_961923037877_item	2947176	et	4	main
kivikirst	doc_947478791303_item	2946522	et	3	main
oli	doc_947478791303_item	2946527	et	3	main
lõuna-eesti	doc_947478791303_item	2946542	et	4	main
hõimud	doc_947478791303_item	2946543	et	4	main
2	doc_947478791303_item	2946550	et	2	main
animism	doc_947478791303_item	2946551	et	3	main
see	doc_947478791303_item	2946552	et	3	main
on	doc_947478791303_item	2946553	et	4	main
uskumus	doc_947478791303_item	2946554	et	3	main
et	doc_947478791303_item	2946555	et	3	main
eluta	doc_947478791303_item	2946556	et	3	main
puudel	doc_947478791303_item	2946562	et	4	main
1	doc_947478791304_item	2946567	et	2	main
varane	doc_947478791304_item	2946568	et	4	main
metalliaeg	doc_947478791304_item	2946569	et	3	main
eesti	doc_947478791304_item	2946570	et	4	main
territooriumil	doc_947478791304_item	2946571	et	3	main
2	doc_947478791304_item	2946572	et	2	main
mõiste	doc_947478791304_item	2946573	et	4	main
animism	doc_947478791304_item	2946574	et	3	main
1	doc_947478791304_item	2946576	et	2	main
1	doc_947478791304_item	2946577	et	2	main
pronksiaeg	doc_947478791304_item	2946578	et	3	main
tähendus	doc_947478791304_item	2946575	et	4	main
ii	doc_947478791304_item	2946579	et	4	main
aasttuh	doc_947478791304_item	2946580	et	4	main
keskel	doc_947478791304_item	2946581	et	3	main
e	doc_947478791304_item	2946582	et	4	main
kr	doc_947478791304_item	2946583	et	4	main
5	doc_947478791304_item	2946584	et	2	main
tina	doc_947478791304_item	2946589	et	4	main
lähis-idas	doc_947478791304_item	2946591	et	3	main
jõudnud	doc_947478791304_item	2946597	et	4	main
pronks	doc_947478791304_item	2946598	et	3	main
2	doc_947478791304_item	2946602	et	2	main
skandinaaviast	doc_947478791304_item	2946603	et	3	main
saaremaalt	doc_947478791304_item	2946608	et	4	main
kohapeal	doc_947478791304_item	2946611	et	3	main
vanim	doc_947478791304_item	2946614	et	3	main
iia	doc_947478791304_item	2946616	et	4	main
e	doc_947478791304_item	2946617	et	4	main
asulaid	doc_947478791304_item	2946631	et	4	main
keelati	doc_947478791304_item	2946646	et	4	main
levinud	doc_947478791304_item	2946653	et	4	main
tööriistad	doc_947478791304_item	2946654	et	3	main
saaki	doc_947478791304_item	2946669	et	4	main
osati	doc_947478791304_item	2946670	et	3	main
ka	doc_947478791304_item	2946671	et	3	main
alguses	doc_947478791304_item	2946682	et	4	main
hakati	doc_947478791304_item	2946684	et	3	main
kasvatama	doc_947478791304_item	2946685	et	4	main
kasvatus	doc_947478791304_item	2946630	et	4	main
ja	doc_947478791304_item	2946635	et	3	main
lõuna	doc_947478791304_item	2946636	et	4	main
eestis	doc_947478791304_item	2946637	et	3	main
hakati	doc_947478791304_item	2946638	et	3	main
kasvatama	doc_947478791304_item	2946639	et	4	main
veiseid	doc_947478791304_item	2946640	et	3	main
kõblas	doc_947478791304_item	2946649	et	3	main
on	doc_947478791304_item	2946655	et	4	main
sellega	doc_947478791304_item	2946657	et	3	main
vilja	doc_947478791304_item	2946659	et	4	main
sellel	doc_947478791304_item	2946660	et	4	main
teravilja	doc_947478791304_item	2946672	et	4	main
jahuks	doc_947478791304_item	2946673	et	3	main
jahvatada	doc_947478791304_item	2946674	et	3	main
nad	doc_947478791304_item	2946675	et	3	main
saj	doc_947478791304_item	2946681	et	4	main
kultuuriainetest	doc_947478791304_item	2946683	et	4	main
tööriistu	doc_947478791304_item	2946699	et	3	main
et	doc_947478791304_item	2946703	et	3	main
sellele	doc_947478791304_item	2946702	et	4	main
linu	doc_947478791304_item	2946704	et	4	main
on	doc_947478791304_item	2946705	et	4	main
tehtud	doc_947478791304_item	2946706	et	4	main
2	doc_947478791304_item	2946707	et	2	main
raud	doc_947478791304_item	2946708	et	3	main
on	doc_947478791304_item	2946709	et	4	main
leitud	doc_947478791304_item	2946710	et	4	main
egiptlaste	doc_947478791304_item	2946711	et	3	main
haualt	doc_947478791304_item	2946712	et	3	main
1300a	doc_947478791304_item	2946713	et	4	main
ekr	doc_947478791304_item	2946714	et	4	main
hakati	doc_947478791304_item	2946715	et	3	main
looduslikult	doc_947478791304_item	2946716	et	4	main
rauda	doc_947478791304_item	2946717	et	4	main
sulatama	doc_947478791304_item	2946718	et	4	main
esialgu	doc_947478791304_item	2946719	et	3	main
toodi	doc_947478791304_item	2946720	et	4	main
nii	doc_947478791304_item	2946723	et	3	main
saj	doc_947478791304_item	2946729	et	4	main
eristuvad	doc_947478791304_item	2946732	et	4	main
rooma	doc_947478791304_item	2946733	et	4	main
rauaajal	doc_947478791304_item	2946734	et	3	main
selgesti	doc_947478791304_item	2946735	et	3	main
kesk-	doc_947478791304_item	2946736	et	3	main
ja	doc_947478791304_item	2946737	et	3	main
suured	doc_947478791304_item	2946745	et	3	main
jaanitule	doc_947478791304_item	2946749	et	4	main
tegemiskombed	doc_947478791304_item	2946750	et	3	main
saj	doc_947478791304_item	2946754	et	4	main
rahutu	doc_947478791304_item	2946763	et	4	main
aeg	doc_947478791304_item	2946764	et	3	main
oli	doc_947478791304_item	2946765	et	3	main
rohkem	doc_947478791304_item	2946766	et	4	main
sõdu	doc_947478791304_item	2946767	et	3	main
rikkamaid	doc_947478791304_item	2946814	et	4	main
asulad	doc_947478791304_item	2946823	et	3	main
pealik	doc_947478791304_item	2946828	et	4	main
kasutama	doc_947478791304_item	2946834	et	3	main
sõna	doc_947478791304_item	2946835	et	4	main
kuningas	doc_947478791304_item	2946836	et	4	main
noorem	doc_947478791304_item	2946837	et	4	main
rauaaeg	doc_947478791304_item	2946838	et	3	main
9-13	doc_947478791304_item	2946839	et	2	main
vanad	doc_947478791304_item	2946694	et	3	main
tekstiilileiud	doc_947478791304_item	2946695	et	3	main
on	doc_947478791304_item	2946696	et	4	main
mis	doc_947478791304_item	2946700	et	4	main
vanem	doc_947478791304_item	2946726	et	4	main
lõuna-	doc_947478791304_item	2946739	et	4	main
ja	doc_947478791304_item	2946740	et	3	main
oli	doc_947478791304_item	2946747	et	3	main
ka	doc_947478791304_item	2946748	et	3	main
5-8	doc_947478791304_item	2946753	et	2	main
peetakse	doc_947478791304_item	2946756	et	3	main
rändamise	doc_947478791304_item	2946759	et	4	main
konflikte	doc_947478791304_item	2946768	et	3	main
on	doc_947478791304_item	2946775	et	4	main
leitud	doc_947478791304_item	2946776	et	4	main
matusi	doc_947478791304_item	2946815	et	4	main
lõuna-eestis	doc_947478791304_item	2946816	et	3	main
maeti	doc_947478791304_item	2946817	et	3	main
inimesi	doc_947478791304_item	2946818	et	4	main
suured	doc_947478791304_item	2946822	et	3	main
oma	doc_947478791304_item	2946827	et	4	main
pealikuks	doc_947478791304_item	2946829	et	4	main
sai	doc_947478791304_item	2946830	et	4	main
kr	doc_947478791304_item	2946842	et	4	main
maaharimisega	doc_947478791304_item	2946847	et	3	main
koonduvad	doc_947478791304_item	2946849	et	4	main
äärde	doc_947478791304_item	2946851	et	4	main
olukord	doc_947478791304_item	2946858	et	3	main
tõuseb	doc_947478791304_item	2946860	et	3	main
oma	doc_947478791304_item	2946866	et	4	main
pärandati	doc_947478791304_item	2946874	et	4	main
oma	doc_947478791304_item	2946875	et	4	main
pojale	doc_947478791304_item	2946879	et	4	main
ei	doc_947478791304_item	2946891	et	4	main
teki	doc_947478791304_item	2946892	et	4	main
kontrolltöö	doc_961923037877_item	2946924	et	4	main
1	doc_961923037877_item	2946925	et	2	main
tooge	doc_961923037877_item	2946926	et	3	main
välja	doc_961923037877_item	2946927	et	4	main
peamised	doc_961923037877_item	2946928	et	3	main
mida	doc_961923037877_item	2946937	et	4	main
kultuuriajaloos	doc_961923037877_item	2946941	et	4	main
vabadussõda	doc_961923037877_item	2946950	et	4	main
ja	doc_961923037877_item	2946951	et	3	main
1920	doc_961923037877_item	2946953	et	2	main
sõlmitud	doc_961923037877_item	2946955	et	4	main
ajast	doc_961923037877_item	2946959	et	4	main
saame	doc_961923037877_item	2946961	et	4	main
rääkida	doc_961923037877_item	2946962	et	3	main
eestist	doc_961923037877_item	2946963	et	3	main
noore	doc_961923037877_item	2946972	et	3	main
oli	doc_961923037877_item	2946983	et	3	main
väga	doc_961923037877_item	2946984	et	3	main
intensiivne	doc_961923037877_item	2946985	et	3	main
üldkultuuriliseks	doc_961923037877_item	2946986	et	4	main
kreedoks	doc_961923037877_item	2946987	et	3	main
kujutas	doc_961923037877_item	2947022	et	3	main
riiklikku	doc_961923037877_item	2947024	et	4	main
rahalist	doc_961923037877_item	2947025	et	4	main
hariduselu	doc_961923037877_item	2947029	et	4	main
eriala-	doc_961923037877_item	2947032	et	4	main
kujutav-	doc_961923037877_item	2947033	et	4	main
välja	doc_961923037877_item	2947048	et	4	main
andma	doc_961923037877_item	2947049	et	3	main
ning	doc_961923037877_item	2947065	et	3	main
1937a	doc_961923037877_item	2947066	et	4	main
alates	doc_961923037877_item	2947067	et	3	main
kirjanikke	doc_961923037877_item	2947068	et	3	main
hakkati	doc_961923037877_item	2947069	et	3	main
b	doc_961923037877_item	2947077	et	4	main
maksimaalselt	doc_961923037877_item	2947083	et	4	main
tähendas	doc_961923037877_item	2947090	et	3	main
et	doc_961923037877_item	2947093	et	3	main
anda	doc_961923037877_item	2947097	et	3	main
ilmus	doc_961923037877_item	2947104	et	4	main
kultuurile	doc_961923037877_item	2947108	et	3	main
arenesid	doc_961923037877_item	2947130	et	4	main
välismaa	doc_961923037877_item	2947138	et	4	main
eesti	doc_961923037877_item	2947142	et	4	main
oli	doc_961923037877_item	2947145	et	3	main
uute	doc_961923037877_item	2947148	et	3	main
rauda	doc_947478791304_item	2946722	et	4	main
nagu	doc_947478791304_item	2946724	et	3	main
kalmete	doc_947478791304_item	2946730	et	3	main
lääne	doc_947478791304_item	2946741	et	4	main
eesti	doc_947478791304_item	2946742	et	4	main
ja	doc_947478791304_item	2946743	et	3	main
saarte	doc_947478791304_item	2946744	et	3	main
rauaaeg	doc_947478791304_item	2946752	et	3	main
vahel	doc_947478791304_item	2946770	et	4	main
tekib	doc_947478791304_item	2946772	et	3	main
kivikalmed	doc_947478791304_item	2946774	et	3	main
inimesi	doc_947478791304_item	2946779	et	4	main
ei	doc_947478791304_item	2946780	et	4	main
maetud	doc_947478791304_item	2946781	et	4	main
maa	doc_947478791304_item	2946782	et	4	main
sisse	doc_947478791304_item	2946783	et	4	main
vaid	doc_947478791304_item	2946784	et	3	main
pandi	doc_947478791304_item	2946785	et	4	main
kividega	doc_947478791304_item	2946786	et	3	main
ümber	doc_947478791304_item	2946787	et	3	main
inimesed	doc_947478791304_item	2946788	et	3	main
hoolitsesid	doc_947478791304_item	2946789	et	4	main
surnute	doc_947478791304_item	2946790	et	4	main
eest	doc_947478791304_item	2946791	et	4	main
surnutele	doc_947478791304_item	2946792	et	4	main
pandi	doc_947478791304_item	2946793	et	4	main
ka	doc_947478791304_item	2946794	et	3	main
asju	doc_947478791304_item	2946795	et	3	main
kaasa	doc_947478791304_item	2946796	et	4	main
tööriistu	doc_947478791304_item	2946797	et	3	main
ehteid	doc_947478791304_item	2946798	et	3	main
inimesed	doc_947478791304_item	2946799	et	3	main
peitsid	doc_947478791304_item	2946800	et	4	main
oma	doc_947478791304_item	2946801	et	4	main
varanduse	doc_947478791304_item	2946802	et	3	main
maa	doc_947478791304_item	2946803	et	4	main
alla	doc_947478791304_item	2946804	et	3	main
et	doc_947478791304_item	2946805	et	3	main
vargad	doc_947478791304_item	2946806	et	3	main
ei	doc_947478791304_item	2946807	et	4	main
kõige	doc_947478791304_item	2946813	et	4	main
hakkavad	doc_947478791304_item	2946820	et	4	main
külas	doc_947478791304_item	2946825	et	3	main
rikkam	doc_947478791304_item	2946832	et	4	main
hakkati	doc_947478791304_item	2946833	et	3	main
p	doc_947478791304_item	2946841	et	4	main
asulad	doc_947478791304_item	2946848	et	3	main
kirves	doc_947478791304_item	2946856	et	4	main
toitu	doc_947478791304_item	2946861	et	4	main
maad	doc_947478791304_item	2946873	et	4	main
isa	doc_947478791304_item	2946878	et	4	main
hakkavad	doc_947478791304_item	2946885	et	4	main
võõrast	doc_947478791304_item	2946887	et	4	main
jõudu	doc_947478791304_item	2946888	et	4	main
aga	doc_947478791304_item	2946889	et	3	main
ei	doc_947478791304_item	2946900	et	4	main
tekkinud	doc_947478791304_item	2946901	et	4	main
2	doc_947478791304_item	2946902	et	2	main
mõiste	doc_947478791304_item	2946903	et	4	main
animism	doc_947478791304_item	2946904	et	3	main
tähendus	doc_947478791304_item	2946905	et	4	main
tol	doc_947478791304_item	2946906	et	3	main
ajal	doc_947478791304_item	2946907	et	4	main
inimesed	doc_947478791304_item	2946908	et	3	main
arvasid	doc_947478791304_item	2946909	et	4	main
et	doc_947478791304_item	2946910	et	3	main
kõikidel	doc_947478791304_item	2946911	et	4	main
asjadel	doc_947478791304_item	2946912	et	3	main
on	doc_947478791304_item	2946913	et	4	main
hing	doc_947478791304_item	2946914	et	3	main
näiteks	doc_947478791304_item	2946915	et	4	main
puudel	doc_947478791304_item	2946916	et	4	main
majadel	doc_947478791304_item	2946918	et	3	main
rohul	doc_947478791304_item	2946917	et	4	main
lilledel	doc_947478791304_item	2946919	et	4	main
neil	doc_947478791304_item	2946920	et	4	main
erinevused	doc_961923037877_item	2946929	et	4	main
ev	doc_961923037877_item	2946930	et	4	main
ja	doc_961923037877_item	2946931	et	3	main
kui	doc_961923037877_item	2946939	et	3	main
nn	doc_961923037877_item	2946943	et	4	main
oli	doc_961923037877_item	2946954	et	3	main
vabariigist	doc_961923037877_item	2946965	et	3	main
kuidas	doc_961923037877_item	2946969	et	3	main
arenes	doc_961923037877_item	2946971	et	3	main
rigi	doc_961923037877_item	2946973	et	4	main
ja	doc_961923037877_item	2946975	et	3	main
mis	doc_961923037877_item	2946976	et	4	main
kujutas	doc_961923037877_item	2946977	et	3	main
endast	doc_961923037877_item	2947023	et	4	main
ja	doc_961923037877_item	2947028	et	3	main
kuue	doc_961923037877_item	2947031	et	4	main
näite-	doc_961923037877_item	2947034	et	4	main
ja	doc_961923037877_item	2947035	et	3	main
helikunst	doc_961923037877_item	2947036	et	3	main
kirjandus	doc_961923037877_item	2947037	et	3	main
jaoks	doc_961923037877_item	2947041	et	4	main
sihtkapitalide	doc_961923037877_item	2947043	et	4	main
valitsused	doc_961923037877_item	2947044	et	4	main
esimesena	doc_961923037877_item	2947052	et	3	main
tammsaare	doc_961923037877_item	2947057	et	3	main
ja	doc_961923037877_item	2947059	et	3	main
omanikuks	doc_961923037877_item	2947076	et	4	main
inimesed	doc_947478791304_item	2946843	et	3	main
veekogude	doc_947478791304_item	2946850	et	3	main
kasutusele	doc_947478791304_item	2946852	et	4	main
tulevad	doc_947478791304_item	2946853	et	4	main
sirp	doc_947478791304_item	2946854	et	3	main
vikat	doc_947478791304_item	2946855	et	3	main
jääb	doc_947478791304_item	2946862	et	3	main
inimesed	doc_947478791304_item	2946864	et	3	main
tuleb	doc_947478791304_item	2946868	et	3	main
tekkima	doc_947478791304_item	2946881	et	3	main
mõisad	doc_947478791304_item	2946882	et	3	main
inimesed	doc_947478791304_item	2946884	et	3	main
on	doc_947478791304_item	2946922	et	4	main
hing	doc_947478791304_item	2946923	et	3	main
majanduses	doc_961923037877_item	2946935	et	4	main
2	doc_961923037877_item	2946936	et	2	main
ensv	doc_961923037877_item	2946940	et	4	main
kõneldakse	doc_961923037877_item	2946942	et	3	main
hrustshovi	doc_961923037877_item	2946944	et	4	main
sulast	doc_961923037877_item	2946945	et	4	main
19	doc_961923037877_item	2946946	et	2	main
0301	doc_961923037877_item	2946947	et	2	main
1920	doc_961923037877_item	2946948	et	2	main
tartu	doc_961923037877_item	2946956	et	4	main
kui	doc_961923037877_item	2946964	et	3	main
sõnadega	doc_961923037877_item	2946967	et	3	main
majandus	doc_961923037877_item	2946974	et	4	main
kultuurautonoomia	doc_961923037877_item	2947021	et	4	main
kultuur-	doc_961923037877_item	2947027	et	3	main
kehakultuur	doc_961923037877_item	2947038	et	3	main
riigivanema	doc_961923037877_item	2947050	et	4	main
auhind	doc_961923037877_item	2947051	et	3	main
h	doc_961923037877_item	2947056	et	4	main
tõde	doc_961923037877_item	2947058	et	4	main
taludega	doc_961923037877_item	2947071	et	3	main
kultuurautonoomia	doc_961923037877_item	2947078	et	4	main
kasutasid	doc_961923037877_item	2947084	et	4	main
seda	doc_961923037877_item	2947085	et	3	main
sakslased	doc_961923037877_item	2947086	et	3	main
ja	doc_961923037877_item	2947087	et	3	main
juudid	doc_961923037877_item	2947088	et	3	main
oli	doc_961923037877_item	2947095	et	3	main
võimalik	doc_961923037877_item	2947096	et	3	main
algharidust	doc_961923037877_item	2947099	et	4	main
ajakirjandus	doc_961923037877_item	2947106	et	3	main
üle	doc_947478791304_item	2946863	et	3	main
kauplevad	doc_947478791304_item	2946865	et	4	main
viljaga	doc_947478791304_item	2946867	et	3	main
kasutusele	doc_947478791304_item	2946869	et	4	main
käsitöö	doc_947478791304_item	2946870	et	4	main
lähimatele	doc_947478791304_item	2946876	et	4	main
kasutama	doc_947478791304_item	2946886	et	3	main
teistes	doc_947478791304_item	2946893	et	4	main
linnades	doc_947478791304_item	2946894	et	3	main
hakkas	doc_947478791304_item	2946895	et	3	main
tekkima	doc_947478791304_item	2946896	et	3	main
linnakultuur	doc_947478791304_item	2946897	et	3	main
aga	doc_947478791304_item	2946898	et	3	main
eestis	doc_947478791304_item	2946899	et	3	main
mõeldakse	doc_961923037877_item	2946938	et	3	main
0202	doc_961923037877_item	2946952	et	2	main
sellest	doc_961923037877_item	2946958	et	4	main
me	doc_961923037877_item	2946960	et	4	main
teiste	doc_961923037877_item	2946966	et	4	main
ev-st	doc_961923037877_item	2946968	et	3	main
siis	doc_961923037877_item	2946970	et	3	main
mis	doc_961923037877_item	2946982	et	4	main
sai	doc_961923037877_item	2946988	et	4	main
j	doc_961923037877_item	2946989	et	4	main
hurda	doc_961923037877_item	2946990	et	3	main
sõnad	doc_961923037877_item	2946991	et	4	main
kuna	doc_961923037877_item	2946992	et	3	main
me	doc_961923037877_item	2946993	et	4	main
ei	doc_961923037877_item	2946994	et	4	main
saa	doc_961923037877_item	2946995	et	4	main
kunagi	doc_961923037877_item	2946996	et	3	main
suureks	doc_961923037877_item	2946997	et	4	main
arvult	doc_961923037877_item	2946998	et	3	main
ega	doc_961923037877_item	2946999	et	3	main
jõult	doc_961923037877_item	2947000	et	3	main
peame	doc_961923037877_item	2947001	et	4	main
saama	doc_961923037877_item	2947002	et	4	main
suureks	doc_961923037877_item	2947003	et	4	main
vaimult	doc_961923037877_item	2947004	et	4	main
suurema	doc_961923037877_item	2947005	et	4	main
saavutuseks	doc_961923037877_item	2947006	et	4	main
ev	doc_961923037877_item	2947007	et	4	main
kultuuriloos	doc_961923037877_item	2947008	et	4	main
said	doc_961923037877_item	2947009	et	4	main
kultuurkapitaali	doc_961923037877_item	2947010	et	4	main
sisseseadmine	doc_961923037877_item	2947011	et	3	main
ja	doc_961923037877_item	2947012	et	3	main
kultuurautonoomia	doc_961923037877_item	2947013	et	4	main
seaduse	doc_961923037877_item	2947014	et	3	main
vastuvõtmine	doc_961923037877_item	2947015	et	3	main
1925	doc_961923037877_item	2947016	et	2	main
aastal	doc_961923037877_item	2947017	et	3	main
lühidalt	doc_961923037877_item	2947018	et	4	main
mõlematest	doc_961923037877_item	2947019	et	4	main
a	doc_961923037877_item	2947020	et	4	main
edendamiseks	doc_961923037877_item	2947030	et	4	main
ja	doc_961923037877_item	2947039	et	3	main
moodustati	doc_961923037877_item	2947042	et	3	main
1934	doc_961923037877_item	2947045	et	2	main
a	doc_961923037877_item	2947046	et	4	main
hakkati	doc_961923037877_item	2947047	et	3	main
a	doc_961923037877_item	2947055	et	4	main
õiguse	doc_961923037877_item	2947060	et	4	main
kahe	doc_961923037877_item	2947061	et	3	main
viimaste	doc_961923037877_item	2947062	et	3	main
köidete	doc_961923037877_item	2947063	et	3	main
eest	doc_961923037877_item	2947064	et	4	main
amälk	doc_961923037877_item	2947072	et	4	main
lagle	doc_961923037877_item	2947074	et	4	main
said	doc_961923037877_item	2947079	et	4	main
seda	doc_961923037877_item	2947092	et	3	main
lastele	doc_961923037877_item	2947094	et	4	main
omakeelne	doc_961923037877_item	2947105	et	3	main
ev	doc_961923037877_item	2947107	et	4	main
oli	doc_961923037877_item	2947109	et	3	main
iseloomulik	doc_961923037877_item	2947110	et	3	main
erinevate	doc_961923037877_item	2947111	et	4	main
seltside	doc_961923037877_item	2947112	et	3	main
aktiivsus	doc_961923037877_item	2947113	et	4	main
õpetajate	doc_961923037877_item	2947114	et	4	main
liit	doc_961923037877_item	2947115	et	3	main
eesti	doc_961923037877_item	2947116	et	4	main
kirjameeste	doc_961923037877_item	2947117	et	4	main
selts	doc_961923037877_item	2947118	et	3	main
kunstiühing	doc_961923037877_item	2947119	et	3	main
pallas	doc_961923037877_item	2947120	et	4	main
euroopa	doc_961923037877_item	2947131	et	4	main
tasemele	doc_961923037877_item	2947132	et	3	main
õppejõud	doc_961923037877_item	2947139	et	4	main
rikas	doc_961923037877_item	2947147	et	4	main
sõnadega	doc_961923037877_item	2947149	et	3	main
tänu	doc_961923037877_item	2947153	et	4	main
milles	doc_961923037877_item	2947154	et	3	main
kuid	doc_961923037877_item	2947169	et	4	main
see	doc_961923037877_item	2947170	et	3	main
poleks	doc_961923037877_item	2947171	et	3	main
vastus	doc_961923037877_item	2947172	et	3	main
küsimusele	doc_961923037877_item	2947173	et	4	main
seltside	doc_961923037877_item	2947185	et	3	main
said	doc_961923037877_item	2947202	et	4	main
kannatada	doc_961923037877_item	2947203	et	3	main
alver	doc_961923037877_item	2947205	et	4	main
lauter	doc_961923037877_item	2947206	et	3	main
starkopf	doc_961923037877_item	2947207	et	4	main
muutused	doc_961923037877_item	2947227	et	4	main
kui	doc_961923037877_item	2947228	et	3	main
ev	doc_961923037877_item	2947229	et	4	main
vaba	doc_961923037877_item	2947240	et	4	main
elektritootmine	doc_961923037877_item	2947263	et	3	main
kindlate	doc_961923037877_item	2947274	et	3	main
rääkides	doc_961923037877_item	2947326	et	4	main
nii	doc_961923037877_item	2947343	et	3	main
repressioonid	doc_961923037877_item	2947346	et	3	main
oli	doc_961923037877_item	2947348	et	3	main
hakkas	doc_961923037877_item	2947357	et	3	main
arenema	doc_961923037877_item	2947358	et	3	main
tõlgekirjandus	doc_961923037877_item	2947359	et	4	main
hakkati	doc_961923037877_item	2947364	et	3	main
samas	doc_961923037877_item	2947389	et	4	main
elu	doc_961923037877_item	2947395	et	4	main
kontrolltöö	doc_961923037878_item	2947407	et	4	main
1	doc_961923037878_item	2947408	et	2	main
tooge	doc_961923037878_item	2947409	et	3	main
ja	doc_961923037878_item	2947414	et	3	main
kuid	doc_961923037877_item	2947082	et	4	main
see	doc_961923037877_item	2947091	et	3	main
teadus	doc_961923037877_item	2947123	et	4	main
eesti	doc_961923037877_item	2947133	et	4	main
kõrgkoolide	doc_961923037877_item	2947134	et	3	main
peamiselt	doc_961923037877_item	2947135	et	4	main
ka	doc_961923037877_item	2947141	et	3	main
millest	doc_961923037877_item	2947144	et	3	main
saanud	doc_961923037877_item	2947146	et	4	main
keel	doc_961923037877_item	2947150	et	4	main
j	doc_961923037877_item	2947151	et	4	main
võimalik	doc_961923037877_item	2947156	et	3	main
rohkemgi	doc_961923037877_item	2947167	et	4	main
jäid	doc_961923037877_item	2947193	et	4	main
olid	doc_961923037877_item	2947199	et	4	main
korraldus	doc_961923037877_item	2947219	et	4	main
ensv-s	doc_961923037877_item	2947220	et	3	main
ka	doc_961923037877_item	2947122	et	3	main
olid	doc_961923037877_item	2947126	et	4	main
kõrgel	doc_961923037877_item	2947127	et	4	main
tasemel	doc_961923037877_item	2947128	et	3	main
ja	doc_961923037877_item	2947129	et	3	main
tü	doc_961923037877_item	2947136	et	4	main
töötas	doc_961923037877_item	2947137	et	3	main
keel	doc_961923037877_item	2947143	et	4	main
kirjutada	doc_961923037877_item	2947157	et	3	main
teadustöid	doc_961923037877_item	2947158	et	3	main
ilukirjandust	doc_961923037877_item	2947160	et	3	main
ja	doc_961923037877_item	2947159	et	3	main
kultuurist	doc_961923037877_item	2947161	et	3	main
ja	doc_961923037877_item	2947162	et	3	main
teadusest	doc_961923037877_item	2947163	et	4	main
oleksin	doc_961923037877_item	2947164	et	3	main
võinud	doc_961923037877_item	2947165	et	4	main
veel	doc_961923037877_item	2947166	et	4	main
ja	doc_961923037877_item	2947178	et	3	main
ühiskondlik	doc_961923037877_item	2947179	et	3	main
elu	doc_961923037877_item	2947180	et	4	main
need	doc_961923037877_item	2947187	et	3	main
varem	doc_961923037877_item	2947189	et	4	main
ilma	doc_961923037877_item	2947195	et	4	main
sest	doc_961923037877_item	2947196	et	4	main
kehtestati	doc_961923037877_item	2947209	et	3	main
tsensuur	doc_961923037877_item	2947210	et	3	main
hävitati	doc_961923037877_item	2947211	et	3	main
oli	doc_961923037877_item	2947221	et	3	main
ev	doc_961923037877_item	2947237	et	4	main
talupoeg	doc_961923037877_item	2947238	et	3	main
oli	doc_961923037877_item	2947239	et	3	main
sest	doc_961923037877_item	2947249	et	4	main
ensv-s	doc_961923037877_item	2947260	et	3	main
olid	doc_961923037877_item	2947266	et	4	main
majandus	doc_961923037877_item	2947269	et	4	main
oli	doc_961923037877_item	2947270	et	3	main
olnud	doc_961923037877_item	2947279	et	4	main
näiteks	doc_961923037877_item	2947285	et	4	main
mida	doc_961923037877_item	2947321	et	4	main
tegema	doc_961923037877_item	2947324	et	3	main
mõeldakse	doc_961923037877_item	2947329	et	3	main
1968	doc_961923037877_item	2947332	et	2	main
aastani	doc_961923037877_item	2947333	et	3	main
nikita	doc_961923037877_item	2947334	et	4	main
hruštšovi	doc_961923037877_item	2947335	et	2	main
olnud	doc_961923037877_item	2947341	et	4	main
karm	doc_961923037877_item	2947344	et	4	main
hruštšovi	doc_961923037877_item	2947347	et	2	main
muutused	doc_961923037877_item	2947356	et	4	main
dissidente	doc_961923037877_item	2947363	et	3	main
küüditamist	doc_961923037877_item	2947381	et	4	main
sula	doc_961923037877_item	2947385	et	4	main
stalinistliku	doc_961923037877_item	2947386	et	4	main
režiimist	doc_961923037877_item	2947387	et	2	main
ei	doc_961923037877_item	2947391	et	4	main
saa	doc_961923037877_item	2947392	et	4	main
tegutsesid	doc_961923037877_item	2947399	et	4	main
ja	doc_961923037877_item	2947401	et	3	main
ja	doc_961923037877_item	2947403	et	3	main
määras	doc_961923037877_item	2947405	et	4	main
ensv	doc_961923037878_item	2947415	et	4	main
ühiskonnakorralduses	doc_961923037878_item	2947416	et	3	main
mida	doc_961923037878_item	2947420	et	4	main
pöörduvad	doc_961923037878_item	2947433	et	4	main
eestlased	doc_961923037878_item	2947434	et	3	main
venemaa	doc_961923037878_item	2947435	et	4	main
ei	doc_961923037878_item	2947457	et	4	main
haaramine	doc_961923037878_item	2947469	et	4	main
elu	doc_961923037878_item	2947474	et	4	main
oli	doc_961923037878_item	2947479	et	3	main
tööstust	doc_961923037878_item	2947489	et	4	main
ja	doc_961923037878_item	2947490	et	3	main
elektritootmist	doc_961923037878_item	2947491	et	3	main
arendati	doc_961923037878_item	2947492	et	3	main
eriti	doc_961923037878_item	2947493	et	3	main
usinalt	doc_961923037878_item	2947494	et	4	main
oblastit	doc_961923037878_item	2947498	et	3	main
öelda	doc_961923037877_item	2947168	et	4	main
ensv	doc_961923037877_item	2947181	et	4	main
omadega	doc_961923037877_item	2947182	et	3	main
kõigepealt	doc_961923037877_item	2947183	et	3	main
kirjutan	doc_961923037877_item	2947184	et	3	main
moodustasid	doc_961923037877_item	2947190	et	4	main
erinevaid	doc_961923037877_item	2947191	et	4	main
seltse	doc_961923037877_item	2947192	et	3	main
seltsid	doc_961923037877_item	2947197	et	4	main
ensv-s	doc_961923037877_item	2947198	et	3	main
betty	doc_961923037877_item	2947204	et	4	main
ka	doc_961923037877_item	2947223	et	3	main
majandus	doc_961923037877_item	2947230	et	4	main
oli	doc_961923037877_item	2947231	et	3	main
kapitalistlik	doc_961923037877_item	2947232	et	3	main
siis	doc_961923037877_item	2947233	et	3	main
ensv	doc_961923037877_item	2947234	et	4	main
majandus	doc_961923037877_item	2947235	et	4	main
sotsialistlik	doc_961923037877_item	2947236	et	3	main
ensv-st	doc_961923037877_item	2947242	et	3	main
saa	doc_961923037877_item	2947245	et	4	main
üldse	doc_961923037877_item	2947246	et	3	main
mainida	doc_961923037877_item	2947247	et	3	main
talupoegi	doc_961923037877_item	2947248	et	4	main
arenes	doc_961923037877_item	2947261	et	3	main
planeeritud	doc_961923037877_item	2947271	et	4	main
arenes	doc_961923037877_item	2947273	et	3	main
ka	doc_961923037877_item	2947282	et	3	main
inimeste	doc_961923037877_item	2947283	et	3	main
2	doc_961923037877_item	2947325	et	2	main
1956-	doc_961923037877_item	2947331	et	4	main
ei	doc_961923037877_item	2947340	et	4	main
toimusid	doc_961923037877_item	2947355	et	4	main
ja	doc_961923037877_item	2947362	et	3	main
välja	doc_961923037877_item	2947365	et	4	main
tõepoolest	doc_961923037877_item	2947384	et	3	main
muutus	doc_961923037877_item	2947396	et	4	main
välja	doc_961923037878_item	2947410	et	4	main
2	doc_961923037878_item	2947419	et	2	main
mõeldakse	doc_961923037878_item	2947421	et	3	main
ensv	doc_961923037878_item	2947423	et	4	main
hrustshovi	doc_961923037878_item	2947427	et	4	main
eestisse	doc_961923037878_item	2947432	et	4	main
oma	doc_961923037878_item	2947439	et	4	main
nii	doc_961923037878_item	2947445	et	3	main
hästi	doc_961923037878_item	2947446	et	3	main
eesti	doc_961923037878_item	2947447	et	4	main
kuid	doc_961923037878_item	2947456	et	4	main
elust	doc_961923037878_item	2947460	et	3	main
liidus	doc_961923037878_item	2947464	et	4	main
muutmine	doc_961923037878_item	2947471	et	4	main
kontrolli	doc_961923037878_item	2947480	et	4	main
all	doc_961923037878_item	2947481	et	3	main
poliitika	doc_961923037878_item	2947482	et	4	main
kultuur	doc_961923037878_item	2947483	et	3	main
ja	doc_961923037878_item	2947484	et	3	main
leningraadi	doc_961923037878_item	2947497	et	4	main
isikuvabadust	doc_961923037878_item	2947500	et	4	main
toetas	doc_961923037878_item	2947532	et	3	main
alustati	doc_961923037878_item	2947534	et	4	main
eestis	doc_961923037878_item	2947535	et	3	main
esimesi	doc_961923037878_item	2947536	et	4	main
ettevõtmisi	doc_961923037878_item	2947537	et	3	main
kolhooside	doc_961923037878_item	2947538	et	3	main
asutamiseks	doc_961923037878_item	2947539	et	4	main
ühismajanditesse	doc_961923037878_item	2947540	et	3	main
astusid	doc_961923037878_item	2947546	et	4	main
suhteliselt	doc_961923037878_item	2947556	et	4	main
moskva	doc_961923037878_item	2947558	et	4	main
hakkas	doc_961923037878_item	2947559	et	3	main
nõudma	doc_961923037878_item	2947560	et	3	main
selle	doc_961923037878_item	2947572	et	4	main
mida	doc_961923037878_item	2947573	et	4	main
ebalojaalsuga20700	doc_961923037878_item	2947582	et	4	main
küüditati	doc_961923037878_item	2947583	et	3	main
oodatud	doc_961923037878_item	2947588	et	4	main
ei	doc_961923037878_item	2947590	et	4	main
tulnud	doc_961923037878_item	2947591	et	4	main
tagant	doc_961923037878_item	2947603	et	3	main
nälgisid	doc_961923037878_item	2947609	et	4	main
asjaajamiskeeleks	doc_961923037878_item	2947618	et	4	main
kultuur	doc_961923037877_item	2947177	et	3	main
tegevusest	doc_961923037877_item	2947186	et	4	main
kas	doc_961923037877_item	2947188	et	3	main
sellest	doc_961923037877_item	2947194	et	4	main
keelatud	doc_961923037877_item	2947200	et	4	main
nii	doc_961923037877_item	2947201	et	3	main
jt	doc_961923037877_item	2947208	et	4	main
25	doc_961923037877_item	2947212	et	2	main
kirjandust	doc_961923037877_item	2947213	et	3	main
samuti	doc_961923037877_item	2947214	et	3	main
vabadussõja	doc_961923037877_item	2947215	et	3	main
kajastuvaid	doc_961923037877_item	2947216	et	4	main
monumente	doc_961923037877_item	2947217	et	3	main
ühiskondlik	doc_961923037877_item	2947218	et	3	main
politiseeritud	doc_961923037877_item	2947222	et	4	main
majanduses	doc_961923037877_item	2947224	et	4	main
toimusid	doc_961923037877_item	2947225	et	4	main
me	doc_961923037877_item	2947243	et	4	main
maa	doc_961923037877_item	2947250	et	4	main
oli	doc_961923037877_item	2947251	et	3	main
riigistatud	doc_961923037877_item	2947252	et	4	main
seal	doc_961923037877_item	2947254	et	4	main
oli	doc_961923037877_item	2947255	et	3	main
moodustatud	doc_961923037877_item	2947256	et	4	main
kolhoosid	doc_961923037877_item	2947257	et	3	main
ja	doc_961923037877_item	2947258	et	3	main
sovhoosid	doc_961923037877_item	2947259	et	3	main
ja	doc_961923037877_item	2947264	et	3	main
põlevkivi	doc_961923037877_item	2947265	et	4	main
tähtsamad	doc_961923037877_item	2947267	et	4	main
majandusharud	doc_961923037877_item	2947268	et	3	main
plaanide	doc_961923037877_item	2947275	et	3	main
mida	doc_961923037877_item	2947277	et	4	main
ei	doc_961923037877_item	2947278	et	4	main
muutusid	doc_961923037877_item	2947281	et	4	main
olulised	doc_961923037877_item	2947226	et	4	main
rääkides	doc_961923037877_item	2947241	et	4	main
ei	doc_961923037877_item	2947244	et	4	main
ja	doc_961923037877_item	2947253	et	3	main
rasketööstus	doc_961923037877_item	2947262	et	3	main
ning	doc_961923037877_item	2947272	et	3	main
järgi	doc_961923037877_item	2947276	et	4	main
ev-s	doc_961923037877_item	2947280	et	3	main
tavad	doc_961923037877_item	2947284	et	3	main
varem	doc_961923037877_item	2947286	et	4	main
ei	doc_961923037877_item	2947287	et	4	main
käidua	doc_961923037877_item	2947288	et	4	main
kalmistusel	doc_961923037877_item	2947289	et	4	main
ilmusid	doc_961923037877_item	2947290	et	4	main
uued	doc_961923037877_item	2947291	et	3	main
poed	doc_961923037877_item	2947292	et	4	main
nagu	doc_961923037877_item	2947293	et	3	main
näiteks	doc_961923037877_item	2947294	et	4	main
1	doc_961923037877_item	2947295	et	2	main
mai	doc_961923037877_item	2947296	et	4	main
7	doc_961923037877_item	2947297	et	2	main
8	doc_961923037877_item	2947299	et	2	main
november	doc_961923037877_item	2947298	et	3	main
märts	doc_961923037877_item	2947300	et	3	main
jne	doc_961923037877_item	2947301	et	4	main
ev	doc_961923037877_item	2947302	et	4	main
inimeste	doc_961923037877_item	2947303	et	3	main
elatustase	doc_961923037877_item	2947304	et	3	main
oli	doc_961923037877_item	2947305	et	3	main
suhteliselt	doc_961923037877_item	2947306	et	4	main
kõrge	doc_961923037877_item	2947307	et	4	main
mida	doc_961923037877_item	2947308	et	4	main
me	doc_961923037877_item	2947309	et	4	main
ei	doc_961923037877_item	2947310	et	4	main
saa	doc_961923037877_item	2947311	et	4	main
öelda	doc_961923037877_item	2947312	et	4	main
ensvst	doc_961923037877_item	2947313	et	4	main
ensv-s	doc_961923037877_item	2947314	et	3	main
partei	doc_961923037877_item	2947315	et	4	main
dikteeris	doc_961923037877_item	2947316	et	3	main
kuidas	doc_961923037877_item	2947317	et	3	main
inimesed	doc_961923037877_item	2947318	et	3	main
peavad	doc_961923037877_item	2947319	et	4	main
elama	doc_961923037877_item	2947320	et	3	main
ja	doc_961923037877_item	2947322	et	3	main
kuidas	doc_961923037877_item	2947323	et	3	main
valitsemisaega	doc_961923037877_item	2947336	et	4	main
hruštšovi	doc_961923037877_item	2947327	et	2	main
sulast	doc_961923037877_item	2947328	et	4	main
ajaperioodi	doc_961923037877_item	2947330	et	4	main
eesti	doc_961923037877_item	2947337	et	4	main
inimeste	doc_961923037877_item	2947338	et	3	main
elu	doc_961923037877_item	2947339	et	4	main
enam	doc_961923037877_item	2947342	et	4	main
lõpetati	doc_961923037877_item	2947345	et	3	main
suunatud	doc_961923037877_item	2947349	et	4	main
inimeste	doc_961923037877_item	2947350	et	3	main
elu	doc_961923037877_item	2947351	et	4	main
reabiliteeriti	doc_961923037877_item	2947360	et	4	main
eestikeelsed	doc_961923037877_item	2947367	et	3	main
raamatud	doc_961923037877_item	2947368	et	4	main
lubati	doc_961923037877_item	2947369	et	3	main
kasutama	doc_961923037877_item	2947370	et	3	main
eesti	doc_961923037877_item	2947371	et	4	main
keelt	doc_961923037877_item	2947372	et	4	main
toimusid	doc_961923037877_item	2947373	et	4	main
igasugused	doc_961923037877_item	2947374	et	3	main
festivalid	doc_961923037877_item	2947375	et	3	main
jazz-muusika	doc_961923037877_item	2947376	et	4	main
inimesed	doc_961923037877_item	2947377	et	3	main
ei	doc_961923037877_item	2947378	et	4	main
kartnud	doc_961923037877_item	2947379	et	4	main
enam	doc_961923037877_item	2947380	et	4	main
see	doc_961923037877_item	2947382	et	3	main
kergendamiseks	doc_961923037877_item	2947352	et	4	main
ka	doc_961923037877_item	2947353	et	3	main
kultuuris	doc_961923037877_item	2947354	et	3	main
kultuurtegelasi	doc_961923037877_item	2947361	et	3	main
andma	doc_961923037877_item	2947366	et	3	main
oli	doc_961923037877_item	2947383	et	3	main
me	doc_961923037877_item	2947390	et	4	main
demokraatlikuks	doc_961923037877_item	2947397	et	3	main
peamised	doc_961923037878_item	2947411	et	3	main
erinevused	doc_961923037878_item	2947412	et	4	main
kultuuriajaloos	doc_961923037878_item	2947424	et	4	main
sisuline	doc_961923037878_item	2947430	et	4	main
tagasi	doc_961923037878_item	2947436	et	3	main
toovad	doc_961923037878_item	2947437	et	4	main
oska	doc_961923037878_item	2947443	et	4	main
suurt	doc_961923037878_item	2947461	et	3	main
majanduse	doc_961923037878_item	2947470	et	4	main
valdkonnad	doc_961923037878_item	2947475	et	4	main
politiseeritud	doc_961923037878_item	2947477	et	4	main
kõik	doc_961923037878_item	2947478	et	4	main
põlvkivi	doc_961923037878_item	2947488	et	4	main
ise	doc_961923037878_item	2947521	et	4	main
vaesemad	doc_961923037878_item	2947542	et	4	main
visalt	doc_961923037878_item	2947549	et	4	main
läheb	doc_961923037878_item	2947555	et	3	main
visalt	doc_961923037878_item	2947557	et	4	main
et	doc_961923037878_item	2947561	et	3	main
ette	doc_961923037878_item	2947565	et	4	main
võtaks	doc_961923037878_item	2947566	et	3	main
midagi	doc_961923037878_item	2947567	et	4	main
radikaalset	doc_961923037878_item	2947568	et	3	main
see	doc_961923037878_item	2947569	et	3	main
tõi	doc_961923037878_item	2947570	et	3	main
talupojad	doc_961923037878_item	2947575	et	4	main
rohkem	doc_961923037878_item	2947584	et	4	main
sest	doc_961923037878_item	2947592	et	4	main
ei	doc_961923037878_item	2947595	et	4	main
pandi	doc_961923037878_item	2947605	et	4	main
loomad	doc_961923037878_item	2947608	et	3	main
võimule	doc_961923037878_item	2947612	et	3	main
kohalik	doc_961923037878_item	2947619	et	3	main
kuid	doc_961923037877_item	2947388	et	4	main
öelda	doc_961923037877_item	2947393	et	4	main
et	doc_961923037877_item	2947394	et	3	main
endiselt	doc_961923037877_item	2947398	et	4	main
sovhoosid	doc_961923037877_item	2947400	et	3	main
kolhoosid	doc_961923037877_item	2947402	et	3	main
eluviisi	doc_961923037877_item	2947404	et	4	main
partei	doc_961923037877_item	2947406	et	4	main
ev	doc_961923037878_item	2947413	et	4	main
ja	doc_961923037878_item	2947417	et	3	main
kui	doc_961923037878_item	2947422	et	3	main
sulast	doc_961923037878_item	2947428	et	4	main
1947a	doc_961923037878_item	2947429	et	4	main
kultuuri	doc_961923037878_item	2947440	et	4	main
nad	doc_961923037878_item	2947441	et	3	main
ei	doc_961923037878_item	2947442	et	4	main
keelt	doc_961923037878_item	2947448	et	4	main
nad	doc_961923037878_item	2947449	et	3	main
on	doc_961923037878_item	2947450	et	4	main
nõukogude-meelsed	doc_961923037878_item	2947451	et	3	main
nad	doc_961923037878_item	2947452	et	3	main
saavad	doc_961923037878_item	2947453	et	4	main
ametnike	doc_961923037878_item	2947454	et	3	main
tea	doc_961923037878_item	2947458	et	4	main
nõukogude	doc_961923037878_item	2947463	et	3	main
oli	doc_961923037878_item	2947465	et	3	main
ainuparteilisus	doc_961923037878_item	2947472	et	4	main
on	doc_961923037878_item	2947476	et	4	main
poliitika	doc_961923037878_item	2947487	et	4	main
varustas	doc_961923037878_item	2947496	et	3	main
elektriga	doc_961923037878_item	2947499	et	3	main
loodi	doc_961923037878_item	2947528	et	4	main
sovhoose	doc_961923037878_item	2947529	et	3	main
need	doc_961923037878_item	2947530	et	3	main
riik	doc_961923037878_item	2947531	et	3	main
1947	doc_961923037878_item	2947533	et	2	main
inimesed	doc_961923037878_item	2947543	et	3	main
vaesemad	doc_961923037878_item	2947544	et	4	main
kartsid	doc_961923037878_item	2947550	et	4	main
uut	doc_961923037878_item	2947551	et	3	main
eestis	doc_961923037878_item	2947562	et	3	main
küüditamine	doc_961923037878_item	2947579	et	4	main
viidi	doc_961923037878_item	2947586	et	4	main
kohalike	doc_961923037878_item	2947593	et	4	main
varas	doc_961923037878_item	2947606	et	4	main
tuli	doc_961923037878_item	2947613	et	4	main
sõda	doc_961923037878_item	2947622	et	4	main
ev	doc_961923037878_item	2947630	et	4	main
eesmärk	doc_961923037878_item	2947631	et	3	main
rahva	doc_961923037878_item	2947633	et	3	main
2	doc_961923037878_item	2947635	et	2	main
hruštsov	doc_961923037878_item	2947645	et	2	main
mõtleb	doc_961923037878_item	2947646	et	3	main
võib	doc_961923037878_item	2947656	et	3	main
said	doc_961923037878_item	2947683	et	4	main
pea	doc_961923037878_item	2947691	et	4	main
sel	doc_961923037878_item	2947692	et	3	main
perioodil	doc_961923037878_item	2947693	et	3	main
hakatakse	doc_961923037878_item	2947694	et	3	main
üha	doc_961923037878_item	2947695	et	3	main
vaid	doc_961923037878_item	2947703	et	3	main
see	doc_961923037878_item	2947707	et	3	main
direktorid	doc_961923037878_item	2947711	et	3	main
kes	doc_961923037878_item	2947713	et	4	main
tihti	doc_961923037878_item	2947719	et	3	main
soovitati	doc_961923037878_item	2947727	et	4	main
tegi	doc_961923037878_item	2947735	et	4	main
vastus	doc_961938048511_item	2947736	et	3	main
käitumine	doc_961938048511_item	2947747	et	4	main
on	doc_961938048511_item	2947748	et	4	main
kujutan	doc_961938048511_item	2947754	et	3	main
kreekat	doc_961938048511_item	2947756	et	4	main
kurb	doc_961938048511_item	2947757	et	3	main
hakkab	doc_961938048511_item	2947758	et	3	main
kui	doc_961938048511_item	2947759	et	3	main
mõtlen	doc_961938048511_item	2947760	et	3	main
inimestest	doc_961938048511_item	2947761	et	3	main
oma	doc_961938048511_item	2947765	et	4	main
kultuur	doc_961938048511_item	2947770	et	3	main
meie	doc_961938048511_item	2947772	et	4	main
maa	doc_961938048511_item	2947773	et	4	main
iseloomujoon	doc_961938048511_item	2947774	et	3	main
majanduses	doc_961923037878_item	2947418	et	4	main
kõneldakse	doc_961923037878_item	2947425	et	3	main
nn	doc_961923037878_item	2947426	et	4	main
ensv	doc_961923037878_item	2947431	et	4	main
kaasa	doc_961923037878_item	2947438	et	4	main
enam	doc_961923037878_item	2947444	et	4	main
kohad	doc_961923037878_item	2947455	et	4	main
siinsest	doc_961923037878_item	2947459	et	3	main
midagi	doc_961923037878_item	2947462	et	4	main
sotsiolism	doc_961923037878_item	2947466	et	4	main
poliitilise	doc_961923037878_item	2947467	et	3	main
võimu	doc_961923037878_item	2947468	et	4	main
kõik	doc_961923037878_item	2947473	et	4	main
majandus	doc_961923037878_item	2947485	et	4	main
mõjutab	doc_961923037878_item	2947486	et	3	main
eesti	doc_961923037878_item	2947495	et	4	main
hakati	doc_961923037878_item	2947501	et	3	main
piirama	doc_961923037878_item	2947502	et	3	main
hakkab	doc_961923037878_item	2947504	et	3	main
tegevust	doc_961923037878_item	2947505	et	4	main
1946a	doc_961923037878_item	2947503	et	4	main
kgb	doc_961923037878_item	2947506	et	4	main
julgeolekomitee	doc_961923037878_item	2947507	et	4	main
kontrolliti	doc_961923037878_item	2947508	et	3	main
inimeste	doc_961923037878_item	2947509	et	3	main
taustu	doc_961923037878_item	2947510	et	3	main
tegevus	doc_961923037878_item	2947511	et	4	main
jms	doc_961923037878_item	2947512	et	4	main
ev	doc_961923037878_item	2947513	et	4	main
majandus	doc_961923037878_item	2947514	et	4	main
loodi	doc_961923037878_item	2947515	et	4	main
kolhoose	doc_961923037878_item	2947516	et	3	main
olid	doc_961923037878_item	2947517	et	4	main
majandid	doc_961923037878_item	2947518	et	3	main
mis	doc_961923037878_item	2947519	et	4	main
pidid	doc_961923037878_item	2947520	et	4	main
end	doc_961923037878_item	2947522	et	4	main
majandama	doc_961923037878_item	2947523	et	3	main
toetus	doc_961923037878_item	2947525	et	4	main
talupojad	doc_961923037878_item	2947545	et	4	main
küüditamist	doc_961923037878_item	2947552	et	4	main
kolhooside	doc_961923037878_item	2947553	et	3	main
partei	doc_961923037878_item	2947563	et	4	main
midagi	doc_961923037878_item	2947564	et	4	main
jõukamad	doc_961923037878_item	2947574	et	4	main
mida	doc_961923037878_item	2947580	et	4	main
põhjendati	doc_961923037878_item	2947581	et	3	main
siberi	doc_961923037878_item	2947587	et	4	main
arvestatud	doc_961923037878_item	2947596	et	4	main
vaesemad	doc_961923037878_item	2947597	et	4	main
kolhoosid	doc_961923037878_item	2947598	et	3	main
hakkasid	doc_961923037878_item	2947599	et	4	main
ühinema	doc_961923037878_item	2947600	et	3	main
kui	doc_961923037878_item	2947601	et	3	main
kolhoos	doc_961923037878_item	2947602	et	3	main
stalin	doc_961923037878_item	2947610	et	4	main
beria	doc_961923037878_item	2947614	et	4	main
ta	doc_961923037878_item	2947615	et	4	main
sarnaselt	doc_961923037878_item	2947649	et	4	main
rääkid	doc_961923037878_item	2947657	et	4	main
süsteemiga	doc_961923037878_item	2947660	et	3	main
keda	doc_961923037878_item	2947679	et	4	main
riigi	doc_961923037878_item	2947524	et	3	main
puudus	doc_961923037878_item	2947526	et	4	main
hiljem	doc_961923037878_item	2947527	et	3	main
astuvad	doc_961923037878_item	2947541	et	4	main
kolhoosi	doc_961923037878_item	2947547	et	4	main
väga	doc_961923037878_item	2947548	et	3	main
loomine	doc_961923037878_item	2947554	et	4	main
kaasa	doc_961923037878_item	2947571	et	4	main
kartsid	doc_961923037878_item	2947576	et	4	main
1949	doc_961923037878_item	2947577	et	2	main
suur	doc_961923037878_item	2947578	et	3	main
inimesi	doc_961923037878_item	2947585	et	4	main
majanduskasvu	doc_961923037878_item	2947589	et	4	main
oludega	doc_961923037878_item	2947594	et	3	main
näpati	doc_961923037878_item	2947604	et	3	main
vangi	doc_961923037878_item	2947607	et	4	main
suri	doc_961923037878_item	2947611	et	3	main
edutas	doc_961923037878_item	2947616	et	3	main
kohalikke	doc_961923037878_item	2947617	et	4	main
pärast	doc_961923037878_item	2947621	et	4	main
prestiizne	doc_961923037878_item	2947625	et	4	main
rajati	doc_961923037878_item	2947626	et	3	main
internaate	doc_961923037878_item	2947627	et	4	main
kultuurimälu	doc_961923037878_item	2947634	et	4	main
1957-1968	doc_961923037878_item	2947636	et	2	main
n	doc_961923037878_item	2947637	et	4	main
hruštsovi	doc_961923037878_item	2947638	et	2	main
palju	doc_961923037878_item	2947647	et	4	main
beriaga	doc_961923037878_item	2947648	et	4	main
eestlaste	doc_961923037878_item	2947658	et	4	main
kohanemisest	doc_961923037878_item	2947659	et	4	main
tankid	doc_961923037878_item	2947676	et	3	main
vajalikuks	doc_961923037878_item	2947680	et	3	main
peeti	doc_961923037878_item	2947681	et	4	main
eestased	doc_961923037878_item	2947682	et	4	main
parteisse	doc_961923037878_item	2947699	et	3	main
lojaalsusest	doc_961923037878_item	2947702	et	4	main
tihti	doc_961923037878_item	2947705	et	3	main
isegi	doc_961923037878_item	2947708	et	4	main
sinna	doc_961923037878_item	2947718	et	3	main
ei	doc_961923037878_item	2947720	et	4	main
saanud	doc_961923037878_item	2947721	et	4	main
kes	doc_961923037878_item	2947731	et	4	main
sõna	doc_961938048511_item	2947740	et	4	main
kultuur	doc_961938048511_item	2947741	et	3	main
ette	doc_961938048511_item	2947755	et	4	main
kultuuri	doc_961938048511_item	2947767	et	4	main
mitmest	doc_961938048511_item	2947776	et	4	main
kultuurist	doc_961938048511_item	2947777	et	3	main
kalevipoeg	doc_961938048511_item	2947778	et	3	main
ei	doc_968228746309_item	2947784	et	4	main
ainuke	doc_968228746309_item	2947832	et	4	main
ja	doc_968228746309_item	2947844	et	3	main
olen	doc_968228746309_item	2947848	et	3	main
nimeks	doc_968228746309_item	2947853	et	3	main
elust	doc_968228746309_item	2947858	et	3	main
paljud	doc_968228746309_item	2947865	et	3	main
noored	doc_968228746309_item	2947867	et	3	main
riskantse	doc_968228746309_item	2947870	et	3	main
veoga	doc_968228746309_item	2947872	et	3	main
hästi	doc_968228746309_item	2947878	et	3	main
kord	doc_968228746309_item	2947882	et	4	main
filmi	doc_968228746309_item	2947885	et	4	main
peategelased	doc_968228746309_item	2947886	et	3	main
on	doc_968228746309_item	2947887	et	4	main
naine	doc_968228746309_item	2947888	et	3	main
keel	doc_961923037878_item	2947620	et	4	main
maalaste	doc_961923037878_item	2947628	et	4	main
jaoks	doc_961923037878_item	2947629	et	4	main
sula	doc_961923037878_item	2947639	et	4	main
propageeris	doc_961923037878_item	2947640	et	3	main
maisi	doc_961923037878_item	2947641	et	4	main
ning	doc_961923037878_item	2947650	et	3	main
hakkab	doc_961923037878_item	2947651	et	3	main
ideed	doc_961923037878_item	2947652	et	4	main
teostama	doc_961923037878_item	2947653	et	3	main
alatest	doc_961923037878_item	2947654	et	3	main
tapeti	doc_961923037878_item	2947677	et	3	main
aru	doc_961923037878_item	2947684	et	4	main
et	doc_961923037878_item	2947685	et	3	main
enam	doc_961923037878_item	2947696	et	4	main
astuma	doc_961923037878_item	2947697	et	3	main
kohustuslik	doc_961923037878_item	2947709	et	3	main
need	doc_961923037878_item	2947712	et	3	main
mitte	doc_961923037878_item	2947728	et	3	main
nende	doc_961923037878_item	2947729	et	4	main
küsimusele	doc_961938048511_item	2947737	et	4	main
ei	doc_961938048511_item	2947763	et	4	main
2	doc_961938048511_item	2947768	et	2	main
eesti	doc_961938048511_item	2947769	et	4	main
on	doc_961938048511_item	2947771	et	4	main
kristjan	doc_961938048511_item	2947779	et	4	main
raua	doc_961938048511_item	2947780	et	3	main
joonistused	doc_961938048511_item	2947781	et	4	main
aga	doc_968228746309_item	2947823	et	3	main
parem	doc_968228746309_item	2947833	et	4	main
kõik	doc_968228746309_item	2947839	et	4	main
loogiline	doc_968228746309_item	2947845	et	4	main
ühest	doc_968228746309_item	2947850	et	4	main
1920	doc_968228746309_item	2947861	et	2	main
tegelesid	doc_968228746309_item	2947869	et	4	main
ülemerenaabrik	doc_968228746309_item	2947873	et	4	main
juurde	doc_968228746309_item	2947874	et	4	main
soome	doc_968228746309_item	2947875	et	3	main
näha	doc_968228746309_item	2947879	et	3	main
tema	doc_968228746309_item	2947891	et	4	main
tegeles	doc_968228746309_item	2947895	et	3	main
kõigilee	doc_968228746309_item	2947921	et	4	main
igal	doc_968228746309_item	2947923	et	3	main
juhul	doc_968228746309_item	2947924	et	3	main
ausus	doc_968228746309_item	2947925	et	4	main
hakkas	doc_968228746309_item	2947931	et	3	main
see	doc_968228746309_item	2947932	et	3	main
kokku	doc_968228746309_item	2947936	et	3	main
hiljem	doc_968228746309_item	2947938	et	3	main
et	doc_968228746309_item	2947941	et	3	main
ma	doc_968228746309_item	2947948	et	3	main
võib-olla	doc_968228746309_item	2947951	et	3	main
filmiosas	doc_968228746309_item	2947953	et	3	main
kui	doc_968228746309_item	2947957	et	3	main
kõige	doc_968228746309_item	2947964	et	4	main
nendest	doc_968228746309_item	2947969	et	4	main
ta	doc_968228746309_item	2947971	et	4	main
nad	doc_968228746309_item	2947974	et	3	main
hulgas	doc_968228746309_item	2947978	et	4	main
julius	doc_968228746309_item	2947981	et	4	main
mõtlemist	doc_968228746309_item	2947999	et	4	main
ja	doc_968228746309_item	2948002	et	3	main
kaotuseks	doc_968228746309_item	2948014	et	4	main
koordis	doc_968228746310_item	2948017	et	4	main
haridus	doc_961923037878_item	2947623	et	3	main
oli	doc_961923037878_item	2947624	et	3	main
hävitada	doc_961923037878_item	2947632	et	3	main
kasvatamist	doc_961923037878_item	2947642	et	4	main
võimule	doc_961923037878_item	2947643	et	3	main
saab	doc_961923037878_item	2947644	et	3	main
sulast	doc_961923037878_item	2947655	et	4	main
üheks	doc_961923037878_item	2947661	et	3	main
põhjuseks	doc_961923037878_item	2947662	et	3	main
on	doc_961923037878_item	2947663	et	4	main
1956a	doc_961923037878_item	2947664	et	4	main
sündmused	doc_961923037878_item	2947665	et	3	main
ungaris	doc_961923037878_item	2947666	et	4	main
ungari	doc_961923037878_item	2947667	et	4	main
püüab	doc_961923037878_item	2947668	et	3	main
saada	doc_961923037878_item	2947669	et	4	main
nõukogude	doc_961923037878_item	2947670	et	3	main
liidust	doc_961923037878_item	2947671	et	4	main
vabaks	doc_961923037878_item	2947672	et	3	main
nsvl	doc_961923037878_item	2947673	et	4	main
saatis	doc_961923037878_item	2947674	et	3	main
kohale	doc_961923037878_item	2947675	et	4	main
need	doc_961923037878_item	2947678	et	3	main
taastada	doc_961923037878_item	2947687	et	3	main
ei	doc_961923037878_item	2947688	et	4	main
õnnestu	doc_961923037878_item	2947689	et	4	main
nii	doc_961923037878_item	2947690	et	3	main
seda	doc_961923037878_item	2947700	et	3	main
ise	doc_961923037878_item	2947714	et	4	main
tahtsid	doc_961923037878_item	2947715	et	4	main
parteisse	doc_961923037878_item	2947716	et	3	main
minna	doc_961923037878_item	2947717	et	3	main
ev	doc_961923037878_item	2947686	et	4	main
kommunistlikusse	doc_961923037878_item	2947698	et	4	main
mitte	doc_961923037878_item	2947701	et	3	main
tahtest	doc_961923037878_item	2947704	et	4	main
oli	doc_961923037878_item	2947706	et	3	main
nt	doc_961923037878_item	2947710	et	4	main
hästi	doc_961923037878_item	2947722	et	3	main
vaadati	doc_961923037878_item	2947723	et	3	main
nende	doc_961923037878_item	2947724	et	4	main
peale	doc_961923037878_item	2947725	et	4	main
keda	doc_961923037878_item	2947726	et	4	main
ise	doc_961923037878_item	2947732	et	4	main
seda	doc_961923037878_item	2947733	et	3	main
ettepaneku	doc_961923037878_item	2947734	et	3	main
kohe	doc_961938048511_item	2947742	et	4	main
tuleb	doc_961938048511_item	2947743	et	3	main
meelde	doc_961938048511_item	2947744	et	3	main
teater	doc_961938048511_item	2947745	et	3	main
ka	doc_961938048511_item	2947746	et	3	main
kes	doc_961938048511_item	2947762	et	4	main
rahva	doc_961938048511_item	2947766	et	3	main
laulupeod	doc_961938048511_item	2947782	et	4	main
ole	doc_968228746309_item	2947785	et	4	main
niimoodi	doc_968228746309_item	2947821	et	3	main
kõik	doc_968228746309_item	2947825	et	4	main
niisugused	doc_968228746309_item	2947827	et	3	main
viis	doc_968228746309_item	2947834	et	4	main
minu	doc_968228746309_item	2947835	et	3	main
meie	doc_968228746309_item	2947840	et	4	main
seda	doc_968228746309_item	2947846	et	3	main
filmist	doc_968228746309_item	2947851	et	4	main
mille	doc_968228746309_item	2947852	et	3	main
tulivesi	doc_968228746309_item	2947855	et	4	main
see	doc_968228746309_item	2947856	et	3	main
film	doc_968228746309_item	2947857	et	3	main
aastate	doc_968228746309_item	2947862	et	3	main
kus	doc_968228746309_item	2947864	et	3	main
hulljulged	doc_968228746309_item	2947866	et	3	main
mehed	doc_968228746309_item	2947868	et	3	main
on	doc_968228746309_item	2947877	et	4	main
saab	doc_968228746309_item	2947883	et	3	main
ühed	doc_968228746309_item	2947884	et	3	main
julius	doc_968228746309_item	2947893	et	4	main
naise	doc_968228746309_item	2947934	et	3	main
sai	doc_968228746309_item	2947939	et	4	main
hilda	doc_968228746309_item	2947942	et	4	main
onu	doc_968228746309_item	2947943	et	4	main
räägib	doc_968228746309_item	2947967	et	3	main
ministrile	doc_968228746309_item	2947968	et	3	main
oli	doc_968228746309_item	2947979	et	3	main
võib	doc_968228746309_item	2947982	et	3	main
ta	doc_968228746309_item	2947989	et	4	main
valvurit	doc_968228746309_item	2947990	et	3	main
andeks	doc_968228746309_item	2947991	et	3	main
anda	doc_968228746309_item	2947992	et	3	main
aga	doc_968228746309_item	2947993	et	3	main
tihti	doc_968228746309_item	2947994	et	3	main
inimene	doc_968228746309_item	2947995	et	3	main
teeb	doc_968228746309_item	2947996	et	3	main
asju	doc_968228746309_item	2947997	et	3	main
nende	doc_968228746309_item	2948000	et	4	main
essee	doc_968228746310_item	2948015	et	4	main
film	doc_968228746310_item	2948018	et	3	main
rajati	doc_968228746310_item	2948027	et	3	main
runge	doc_968228746310_item	2948037	et	3	main
nõukogude	doc_968228746310_item	2948039	et	3	main
ta	doc_968228746310_item	2948041	et	4	main
rõõmus	doc_968228746310_item	2948049	et	4	main
päriselt	doc_968228746310_item	2948071	et	3	main
ja	doc_968228746310_item	2948082	et	3	main
unustab	doc_968228746310_item	2948083	et	3	main
ära	doc_968228746310_item	2948084	et	4	main
et	doc_968228746310_item	2948085	et	3	main
nõukogude	doc_968228746310_item	2948086	et	3	main
võimu	doc_968228746310_item	2948087	et	4	main
eesti	doc_968228746310_item	2948092	et	4	main
oli	doc_968228746310_item	2948097	et	3	main
valu	doc_968228746310_item	2948101	et	4	main
ostsid	doc_968228746310_item	2948103	et	4	main
neid	doc_968228746310_item	2948106	et	4	main
sunniti	doc_968228746310_item	2948107	et	3	main
selleks	doc_968228746310_item	2948108	et	4	main
peale	doc_961923037878_item	2947730	et	4	main
1	doc_961938048511_item	2947738	et	2	main
kuuldes	doc_961938048511_item	2947739	et	4	main
kultuur	doc_961938048511_item	2947749	et	3	main
iidsete	doc_961938048511_item	2947750	et	3	main
aegade	doc_961938048511_item	2947751	et	3	main
kultuurist	doc_961938048511_item	2947752	et	3	main
mõeldes	doc_961938048511_item	2947753	et	3	main
väärtusta	doc_961938048511_item	2947764	et	4	main
essee	doc_968228746309_item	2947783	et	4	main
midagi	doc_968228746309_item	2947786	et	4	main
hirmsamat	doc_968228746309_item	2947787	et	4	main
kui	doc_968228746309_item	2947788	et	3	main
üks	doc_968228746309_item	2947789	et	3	main
elus	doc_968228746309_item	2947793	et	4	main
ausus	doc_968228746309_item	2947794	et	4	main
tajutakse	doc_968228746309_item	2947795	et	4	main
nagu	doc_968228746309_item	2947796	et	3	main
üheks	doc_968228746309_item	2947797	et	3	main
suuremaks	doc_968228746309_item	2947798	et	4	main
vooruseks	doc_968228746309_item	2947799	et	4	main
paljud	doc_968228746309_item	2947800	et	3	main
arvavad	doc_968228746309_item	2947801	et	4	main
et	doc_968228746309_item	2947802	et	3	main
kui	doc_968228746309_item	2947803	et	3	main
nad	doc_968228746309_item	2947804	et	3	main
alati	doc_968228746309_item	2947805	et	4	main
ausalt	doc_968228746309_item	2947806	et	4	main
toimivad	doc_968228746309_item	2947807	et	4	main
siis	doc_968228746309_item	2947808	et	3	main
nendega	doc_968228746309_item	2947809	et	4	main
on	doc_968228746309_item	2947810	et	4	main
kõik	doc_968228746309_item	2947811	et	4	main
korras	doc_968228746309_item	2947812	et	4	main
nad	doc_968228746309_item	2947814	et	3	main
ja	doc_968228746309_item	2947813	et	3	main
jätavad	doc_968228746309_item	2947815	et	3	main
hea	doc_968228746309_item	2947816	et	4	main
mulje	doc_968228746309_item	2947817	et	4	main
endast	doc_968228746309_item	2947818	et	4	main
võib	doc_968228746309_item	2947819	et	3	main
ka	doc_968228746309_item	2947820	et	3	main
öelda	doc_968228746309_item	2947822	et	4	main
mitte	doc_968228746309_item	2947824	et	3	main
olukorrad	doc_968228746309_item	2947826	et	3	main
ausus	doc_968228746309_item	2947829	et	4	main
on	doc_968228746309_item	2947830	et	4	main
üks	doc_968228746309_item	2947831	et	3	main
ei	doc_968228746309_item	2947837	et	4	main
ole	doc_968228746309_item	2947838	et	4	main
näinud	doc_968228746309_item	2947849	et	4	main
rahvakülas	doc_968228746309_item	2947860	et	3	main
lõpus	doc_968228746309_item	2947863	et	4	main
salapiirituse	doc_968228746309_item	2947871	et	4	main
kogudus	doc_961938048511_item	2947775	et	3	main
aus	doc_968228746309_item	2947790	et	4	main
inimene	doc_968228746309_item	2947791	et	3	main
meie	doc_968228746309_item	2947792	et	4	main
et	doc_968228746309_item	2947828	et	3	main
arvates	doc_968228746309_item	2947836	et	4	main
elus	doc_968228746309_item	2947841	et	4	main
nii	doc_968228746309_item	2947842	et	3	main
lihtne	doc_968228746309_item	2947843	et	3	main
ma	doc_968228746309_item	2947847	et	3	main
on	doc_968228746309_item	2947854	et	4	main
eestimaa	doc_968228746309_item	2947859	et	4	main
filmist	doc_968228746309_item	2947876	et	4	main
kuidas	doc_968228746309_item	2947880	et	3	main
ausus	doc_968228746309_item	2947881	et	4	main
onu	doc_968228746309_item	2947892	et	4	main
riskantse	doc_968228746309_item	2947896	et	3	main
salapiirituse	doc_968228746309_item	2947897	et	4	main
kuigi	doc_968228746309_item	2947899	et	3	main
eestis	doc_968228746309_item	2947900	et	3	main
tol	doc_968228746309_item	2947901	et	3	main
ajal	doc_968228746309_item	2947902	et	4	main
eitohtinud	doc_968228746309_item	2947903	et	3	main
viinajuua	doc_968228746309_item	2947904	et	4	main
siis	doc_968228746309_item	2947905	et	3	main
muidugi	doc_968228746309_item	2947906	et	4	main
neid	doc_968228746309_item	2947907	et	4	main
salakaubavedajaid	doc_968228746309_item	2947908	et	3	main
püüti	doc_968228746309_item	2947909	et	3	main
üks	doc_968228746309_item	2947910	et	3	main
noormees	doc_968228746309_item	2947911	et	4	main
valvur	doc_968228746309_item	2947912	et	3	main
kellele	doc_968228746309_item	2947913	et	4	main
anti	doc_968228746309_item	2947914	et	3	main
käsu	doc_968228746309_item	2947915	et	3	main
salakaubavedajaid	doc_968228746309_item	2947916	et	3	main
püüda	doc_968228746309_item	2947917	et	3	main
sai	doc_968228746309_item	2947918	et	4	main
seesamaks	doc_968228746309_item	2947919	et	3	main
näiteks	doc_968228746309_item	2947920	et	4	main
kohal	doc_968228746309_item	2947928	et	4	main
filmi	doc_968228746309_item	2947929	et	4	main
julius	doc_968228746309_item	2947944	et	4	main
tegeleb	doc_968228746309_item	2947945	et	3	main
keelatud	doc_968228746309_item	2947946	et	4	main
asjaga	doc_968228746309_item	2947947	et	3	main
et	doc_968228746309_item	2947950	et	3	main
on	doc_968228746309_item	2947954	et	4	main
jaoks	doc_968228746309_item	2947961	et	4	main
tõde	doc_968228746309_item	2947962	et	4	main
asi	doc_968228746309_item	2947966	et	4	main
tegelesid	doc_968228746309_item	2947975	et	4	main
küll	doc_968228746309_item	2947980	et	4	main
hildast	doc_968228746309_item	2947983	et	4	main
aru	doc_968228746309_item	2947984	et	4	main
saa	doc_968228746309_item	2947988	et	4	main
ei	doc_968228746309_item	2948004	et	4	main
seda	doc_968228746309_item	2948006	et	3	main
aus	doc_968228746309_item	2948008	et	4	main
saab	doc_968228746309_item	2948009	et	3	main
mitte	doc_968228746309_item	2948010	et	3	main
tema	doc_968228746309_item	2948011	et	4	main
saavutuseks	doc_968228746309_item	2948012	et	4	main
vaid	doc_968228746309_item	2948013	et	3	main
hilda	doc_968228746309_item	2947889	et	4	main
ja	doc_968228746309_item	2947890	et	3	main
kes	doc_968228746309_item	2947894	et	4	main
veoga	doc_968228746309_item	2947898	et	3	main
alguses	doc_968228746309_item	2947930	et	4	main
hildaga	doc_968228746309_item	2947935	et	4	main
saama	doc_968228746309_item	2947937	et	4	main
valvur	doc_968228746309_item	2947956	et	3	main
aus	doc_968228746309_item	2947958	et	4	main
inimene	doc_968228746309_item	2947959	et	3	main
kelle	doc_968228746309_item	2947960	et	4	main
kallim	doc_968228746309_item	2947965	et	4	main
salakaubandusega	doc_968228746309_item	2947976	et	3	main
nende	doc_968228746309_item	2947977	et	4	main
saada	doc_968228746309_item	2947985	et	4	main
enne	doc_968228746309_item	2947998	et	4	main
kohta	doc_968228746309_item	2948001	et	4	main
märga	doc_968228746309_item	2948005	et	4	main
et	doc_968228746309_item	2948007	et	3	main
valgus	doc_968228746310_item	2948016	et	4	main
sõja	doc_968228746310_item	2948021	et	3	main
kuidas	doc_968228746310_item	2948026	et	3	main
elust	doc_968228746310_item	2948032	et	3	main
väest	doc_968228746310_item	2948040	et	3	main
andis	doc_968228746310_item	2948046	et	3	main
sünnimaale	doc_968228746310_item	2948059	et	4	main
on	doc_968228746310_item	2948061	et	4	main
õnnelikud	doc_968228746310_item	2948064	et	3	main
ei	doc_968228746310_item	2948080	et	4	main
tegemist	doc_968228746310_item	2948090	et	4	main
seotud	doc_968228746310_item	2948100	et	4	main
inimesed	doc_968228746310_item	2948102	et	3	main
kokkuostu	doc_968228746310_item	2948112	et	4	main
hinnad	doc_968228746310_item	2948113	et	3	main
põllumajandusmaksed	doc_968228746310_item	2948114	et	3	main
ja	doc_968228746310_item	2948115	et	3	main
saadeti	doc_968228746310_item	2948120	et	3	main
oli	doc_968228746310_item	2948127	et	3	main
tegelikult	doc_968228746310_item	2948144	et	4	main
oli	doc_968228746310_item	2948153	et	3	main
aga	doc_968228746310_item	2948161	et	3	main
koordis	doc_96992327343_item	2948180	et	4	main
ühelt	doc_96992327343_item	2948181	et	3	main
kellel	doc_968228746309_item	2947922	et	4	main
on	doc_968228746309_item	2947926	et	4	main
esimesel	doc_968228746309_item	2947927	et	3	main
noormees	doc_968228746309_item	2947933	et	4	main
selgeks	doc_968228746309_item	2947940	et	3	main
arvan	doc_968228746309_item	2947949	et	3	main
selles	doc_968228746309_item	2947952	et	4	main
pöörepunkt	doc_968228746309_item	2947955	et	4	main
on	doc_968228746309_item	2947963	et	4	main
kellest	doc_968228746309_item	2947970	et	4	main
teab	doc_968228746309_item	2947972	et	3	main
et	doc_968228746309_item	2947973	et	3	main
kui	doc_968228746309_item	2947986	et	3	main
ei	doc_968228746309_item	2947987	et	4	main
ta	doc_968228746309_item	2948003	et	4	main
jutustab	doc_968228746310_item	2948019	et	3	main
meile	doc_968228746310_item	2948020	et	4	main
sellest	doc_968228746310_item	2948025	et	4	main
paul	doc_968228746310_item	2948036	et	4	main
tuli	doc_968228746310_item	2948038	et	4	main
oma	doc_968228746310_item	2948058	et	4	main
valgus	doc_968228746310_item	2948072	et	4	main
elu	doc_968228746310_item	2948075	et	4	main
tegelikult	doc_968228746310_item	2948079	et	4	main
näol	doc_968228746310_item	2948088	et	4	main
oli	doc_968228746310_item	2948089	et	3	main
rahva	doc_968228746310_item	2948093	et	3	main
olid	doc_968228746310_item	2948110	et	4	main
teised	doc_968228746310_item	2948116	et	4	main
vastased	doc_968228746310_item	2948119	et	3	main
asumisele	doc_968228746310_item	2948122	et	4	main
kõik	doc_968228746310_item	2948128	et	4	main
vara	doc_968228746310_item	2948131	et	4	main
jaoks	doc_968228746310_item	2948133	et	4	main
midagi	doc_968228746310_item	2948142	et	4	main
olid	doc_968228746310_item	2948160	et	4	main
vastupidised	doc_968228746310_item	2948163	et	3	main
sellest	doc_968228746310_item	2948171	et	4	main
perioodist	doc_968228746310_item	2948172	et	3	main
essee	doc_96992327343_item	2948173	et	4	main
telerist	doc_96992327343_item	2948177	et	4	main
filmi	doc_96992327343_item	2948178	et	4	main
valgus	doc_96992327343_item	2948179	et	4	main
mulle	doc_96992327343_item	2948221	et	4	main
meeldivad	doc_96992327343_item	2948223	et	4	main
näitlejad	doc_96992327343_item	2948225	et	4	main
film	doc_96992327343_item	2948235	et	3	main
me	doc_96992327343_item	2948247	et	4	main
poolt	doc_96992327343_item	2948255	et	4	main
patriotismi	doc_96992327343_item	2948260	et	4	main
kunagi	doc_96992327343_item	2948283	et	3	main
valgus	doc_96992327343_item	2948295	et	4	main
on	doc_96992327344_item	2948310	et	4	main
järgmine	doc_96992327344_item	2948311	et	3	main
taluperre	doc_96992327344_item	2948312	et	3	main
satub	doc_96992327344_item	2948313	et	3	main
tudruk	doc_96992327344_item	2948314	et	4	main
järgsetest	doc_968228746310_item	2948022	et	3	main
eestis	doc_968228746310_item	2948024	et	3	main
kolhoose	doc_968228746310_item	2948029	et	3	main
ja	doc_968228746310_item	2948030	et	3	main
sellel	doc_968228746310_item	2948033	et	4	main
ajal	doc_968228746310_item	2948034	et	4	main
noormees	doc_968228746310_item	2948035	et	4	main
alustas	doc_968228746310_item	2948042	et	3	main
elu	doc_968228746310_item	2948044	et	4	main
talle	doc_968228746310_item	2948047	et	4	main
maatüki	doc_968228746310_item	2948048	et	3	main
tuli	doc_968228746310_item	2948051	et	4	main
tagasi	doc_968228746310_item	2948052	et	3	main
kuna	doc_968228746310_item	2948053	et	3	main
kangelane	doc_968228746310_item	2948054	et	3	main
tuli	doc_968228746310_item	2948055	et	4	main
tagasi	doc_968228746310_item	2948056	et	3	main
koju	doc_968228746310_item	2948057	et	3	main
kõik	doc_968228746310_item	2948062	et	4	main
kas	doc_968228746310_item	2948066	et	3	main
nad	doc_968228746310_item	2948067	et	3	main
koordis	doc_968228746310_item	2948073	et	4	main
näitab	doc_968228746310_item	2948074	et	3	main
sellisena	doc_968228746310_item	2948076	et	4	main
nagu	doc_968228746310_item	2948077	et	3	main
see	doc_968228746310_item	2948078	et	3	main
vaadates	doc_968228746310_item	2948095	et	3	main
kolhooside	doc_968228746310_item	2948098	et	3	main
kolhoose	doc_968228746310_item	2948104	et	3	main
kuna	doc_968228746310_item	2948105	et	3	main
kohustused	doc_968228746310_item	2948117	et	4	main
siberisse	doc_968228746310_item	2948121	et	4	main
rikkad	doc_968228746310_item	2948123	et	4	main
inimesed	doc_968228746310_item	2948124	et	3	main
kellel	doc_968228746310_item	2948125	et	4	main
oma	doc_968228746310_item	2948130	et	4	main
oli	doc_968228746310_item	2948134	et	3	main
see	doc_968228746310_item	2948135	et	3	main
väga	doc_968228746310_item	2948136	et	3	main
raske	doc_968228746310_item	2948137	et	4	main
aeg	doc_968228746310_item	2948138	et	3	main
kardeti	doc_968228746310_item	2948139	et	3	main
et	doc_968228746310_item	2948140	et	3	main
tuleb	doc_968228746310_item	2948141	et	3	main
ei	doc_968228746310_item	2948145	et	4	main
toonud	doc_968228746310_item	2948146	et	4	main
kolhooside	doc_968228746310_item	2948147	et	3	main
inimeste	doc_968228746310_item	2948154	et	3	main
raske	doc_968228746310_item	2948156	et	4	main
see	doc_968228746310_item	2948164	et	3	main
film	doc_968228746310_item	2948165	et	3	main
et	doc_968228746310_item	2948167	et	3	main
vaatasin	doc_96992327343_item	2948176	et	3	main
mulle	doc_96992327343_item	2948184	et	4	main
ühelt	doc_96992327343_item	2948233	et	3	main
näitab	doc_96992327343_item	2948238	et	3	main
meile	doc_96992327343_item	2948239	et	4	main
hea	doc_96992327343_item	2948241	et	4	main
elu	doc_96992327343_item	2948242	et	4	main
seletab	doc_96992327343_item	2948243	et	3	main
kuidas	doc_96992327343_item	2948244	et	3	main
elada	doc_96992327343_item	2948245	et	3	main
õigesti	doc_96992327343_item	2948246	et	3	main
teiselt	doc_96992327343_item	2948254	et	4	main
kasvatab	doc_96992327343_item	2948258	et	3	main
film	doc_96992327343_item	2948286	et	3	main
propaganda	doc_96992327343_item	2948290	et	4	main
süzhee	doc_96992327343_item	2948292	et	4	main
on	doc_96992327343_item	2948293	et	4	main
naiivne	doc_96992327343_item	2948294	et	3	main
filmi	doc_96992327344_item	2948304	et	4	main
orjaaegsest	doc_96992327344_item	2948305	et	3	main
süzhee	doc_96992327344_item	2948309	et	4	main
libahundina	doc_96992327344_item	2948318	et	3	main
orjarahva	doc_96992327344_item	2948322	et	3	main
neist	doc_96992327344_item	2948326	et	4	main
laimu	doc_96992327344_item	2948337	et	4	main
armastusest	doc_96992327344_item	2948345	et	4	main
filmi	doc_96992327344_item	2948352	et	4	main
ainult	doc_96992327344_item	2948361	et	4	main
mulle	doc_96992327344_item	2948368	et	4	main
väga	doc_96992327344_item	2948369	et	3	main
ma	doc_96992327344_item	2948370	et	3	main
aastatest	doc_968228746310_item	2948023	et	4	main
esimesi	doc_968228746310_item	2948028	et	4	main
inimeste	doc_968228746310_item	2948031	et	3	main
uut	doc_968228746310_item	2948043	et	3	main
riik	doc_968228746310_item	2948045	et	3	main
tunne	doc_968228746310_item	2948050	et	4	main
filmis	doc_968228746310_item	2948060	et	4	main
kangelased	doc_968228746310_item	2948063	et	3	main
kuid	doc_968228746310_item	2948065	et	4	main
on	doc_968228746310_item	2948068	et	4	main
seda	doc_968228746310_item	2948069	et	3	main
ka	doc_968228746310_item	2948070	et	3	main
olnud	doc_968228746310_item	2948081	et	4	main
katastroofiga	doc_968228746310_item	2948091	et	4	main
seisukohalt	doc_968228746310_item	2948094	et	4	main
tegelikkuses	doc_968228746310_item	2948096	et	4	main
rajamisega	doc_968228746310_item	2948099	et	4	main
kehtestatud	doc_968228746310_item	2948111	et	4	main
seetõttu	doc_968228746310_item	2948109	et	3	main
kolhoosi	doc_968228746310_item	2948118	et	4	main
kaotasid	doc_968228746310_item	2948129	et	4	main
inimeste	doc_968228746310_item	2948132	et	3	main
head	doc_968228746310_item	2948150	et	4	main
see	doc_968228746310_item	2948151	et	3	main
periood	doc_968228746310_item	2948152	et	3	main
sellele	doc_968228746310_item	2948162	et	4	main
loodi	doc_968228746310_item	2948166	et	4	main
muuta	doc_968228746310_item	2948168	et	4	main
inimeste	doc_968228746310_item	2948169	et	3	main
arvamusi	doc_968228746310_item	2948170	et	3	main
poolt	doc_96992327343_item	2948182	et	4	main
film	doc_96992327343_item	2948183	et	3	main
üldse	doc_96992327343_item	2948222	et	3	main
vanaaja	doc_96992327343_item	2948224	et	3	main
minu	doc_96992327343_item	2948226	et	3	main
arust	doc_96992327343_item	2948227	et	4	main
nad	doc_96992327343_item	2948228	et	3	main
poolt	doc_96992327343_item	2948234	et	4	main
valgus	doc_96992327343_item	2948236	et	4	main
õnnelikuid	doc_96992327343_item	2948249	et	4	main
inimesi	doc_96992327343_item	2948250	et	4	main
film	doc_96992327343_item	2948257	et	3	main
sündmusi	doc_96992327343_item	2948280	et	3	main
pole	doc_96992327343_item	2948282	et	3	main
juhtunud	doc_96992327343_item	2948284	et	4	main
on	doc_96992327343_item	2948287	et	4	main
koordis	doc_96992327343_item	2948296	et	4	main
tuletas	doc_96992327343_item	2948297	et	3	main
kelle	doc_96992327344_item	2948315	et	4	main
hukatud	doc_96992327344_item	2948319	et	4	main
erinevaks	doc_96992327344_item	2948327	et	4	main
tekib	doc_96992327344_item	2948328	et	3	main
kahtlus	doc_96992327344_item	2948329	et	4	main
pageb	doc_96992327344_item	2948336	et	3	main
tähtsam	doc_96992327344_item	2948351	et	4	main
idee	doc_96992327344_item	2948353	et	4	main
filmi	doc_96992327344_item	2948354	et	4	main
põhi	doc_96992327344_item	2948355	et	3	main
mõte	doc_96992327344_item	2948356	et	3	main
orjusest	doc_96992327344_item	2948362	et	4	main
aga	doc_96992327344_item	2948363	et	3	main
ka	doc_96992327344_item	2948364	et	3	main
vaba	doc_96992327344_item	2948376	et	4	main
on	doc_96992327344_item	2948378	et	4	main
libahunt	doc_96992327344_item	2948381	et	3	main
võib	doc_96992327344_item	2948392	et	3	main
hullumeelsust	doc_96992327344_item	2948401	et	4	main
ja	doc_96992327344_item	2948402	et	3	main
näitab	doc_96992327344_item	2948404	et	3	main
teine	doc_96992327344_item	2948407	et	3	main
vastus	doc_973441205323_item	2948415	et	3	main
küsimusele	doc_973441205323_item	2948416	et	4	main
miks	doc_973441205323_item	2948417	et	4	main
ma	doc_973441205323_item	2948418	et	3	main
õpin	doc_973441205323_item	2948419	et	3	main
ma	doc_973441205323_item	2948420	et	3	main
enne	doc_968228746310_item	2948126	et	4	main
hullemat	doc_968228746310_item	2948143	et	4	main
rajamine	doc_968228746310_item	2948148	et	4	main
midagi	doc_968228746310_item	2948149	et	4	main
jaoks	doc_968228746310_item	2948155	et	4	main
filmis	doc_968228746310_item	2948157	et	4	main
näidatud	doc_968228746310_item	2948158	et	4	main
emotsioonid	doc_968228746310_item	2948159	et	3	main
valgus	doc_96992327343_item	2948174	et	4	main
koordis	doc_96992327343_item	2948175	et	4	main
meeldis	doc_96992327343_item	2948185	et	3	main
teiselt	doc_96992327343_item	2948186	et	4	main
aga	doc_96992327343_item	2948187	et	3	main
mitte	doc_96992327343_item	2948188	et	3	main
tahaksin	doc_96992327343_item	2948189	et	3	main
paar	doc_96992327343_item	2948190	et	3	main
sõna	doc_96992327343_item	2948191	et	4	main
öelda	doc_96992327343_item	2948192	et	4	main
näitlejate	doc_96992327343_item	2948193	et	4	main
kohta	doc_96992327343_item	2948194	et	4	main
minu	doc_96992327343_item	2948195	et	3	main
meelest	doc_96992327343_item	2948196	et	4	main
kõik	doc_96992327343_item	2948197	et	4	main
osad	doc_96992327343_item	2948198	et	3	main
isegi	doc_96992327343_item	2948199	et	4	main
võltsid	doc_96992327343_item	2948200	et	4	main
ja	doc_96992327343_item	2948201	et	3	main
valelikud	doc_96992327343_item	2948202	et	3	main
on	doc_96992327343_item	2948203	et	4	main
usutavad	doc_96992327343_item	2948204	et	4	main
inimesed	doc_96992327343_item	2948205	et	3	main
on	doc_96992327343_item	2948206	et	4	main
huvitavad	doc_96992327343_item	2948207	et	4	main
ja	doc_96992327343_item	2948208	et	3	main
ma	doc_96992327343_item	2948209	et	3	main
usun	doc_96992327343_item	2948210	et	3	main
neid	doc_96992327343_item	2948211	et	4	main
ei	doc_96992327343_item	2948212	et	4	main
tea	doc_96992327343_item	2948213	et	4	main
miks	doc_96992327343_item	2948214	et	4	main
aga	doc_96992327343_item	2948215	et	3	main
usun	doc_96992327343_item	2948216	et	3	main
näitlejad	doc_96992327343_item	2948217	et	4	main
on	doc_96992327343_item	2948218	et	4	main
vapustavalt	doc_96992327343_item	2948219	et	4	main
huvitavad	doc_96992327343_item	2948220	et	4	main
on	doc_96992327343_item	2948229	et	4	main
andekad	doc_96992327343_item	2948230	et	3	main
ja	doc_96992327343_item	2948231	et	3	main
targad	doc_96992327343_item	2948232	et	3	main
koordis	doc_96992327343_item	2948237	et	4	main
kes	doc_96992327343_item	2948251	et	4	main
elab	doc_96992327343_item	2948252	et	3	main
kolhoosis	doc_96992327343_item	2948253	et	3	main
inimest	doc_96992327343_item	2948259	et	3	main
minu	doc_96992327343_item	2948262	et	3	main
meelest	doc_96992327343_item	2948263	et	4	main
vaimus	doc_96992327343_item	2948261	et	4	main
kõik	doc_96992327343_item	2948264	et	4	main
mis	doc_96992327343_item	2948265	et	4	main
selles	doc_96992327343_item	2948266	et	4	main
filmis	doc_96992327343_item	2948267	et	4	main
jutustatakse	doc_96992327343_item	2948268	et	3	main
on	doc_96992327343_item	2948269	et	4	main
võlts	doc_96992327343_item	2948270	et	3	main
valgus	doc_96992327343_item	2948271	et	4	main
koordis	doc_96992327343_item	2948272	et	4	main
näitab	doc_96992327343_item	2948273	et	3	main
elu	doc_96992327343_item	2948274	et	4	main
sellisena	doc_96992327343_item	2948275	et	4	main
nagu	doc_96992327343_item	2948276	et	3	main
see	doc_96992327343_item	2948277	et	3	main
poolnud	doc_96992327343_item	2948278	et	4	main
kirjeldatakse	doc_96992327343_item	2948279	et	3	main
nn	doc_96992327343_item	2948240	et	4	main
näeme	doc_96992327343_item	2948248	et	3	main
aga	doc_96992327343_item	2948256	et	3	main
mis	doc_96992327343_item	2948281	et	4	main
see	doc_96992327343_item	2948285	et	3	main
nagu	doc_96992327343_item	2948288	et	3	main
filmi	doc_96992327343_item	2948291	et	4	main
eesti	doc_96992327344_item	2948306	et	4	main
libahunt	doc_96992327344_item	2948308	et	3	main
on	doc_96992327344_item	2948317	et	4	main
kasvab	doc_96992327344_item	2948321	et	3	main
keskel	doc_96992327344_item	2948323	et	3	main
ta	doc_96992327344_item	2948335	et	4	main
ja	doc_96992327344_item	2948338	et	3	main
vabadus	doc_96992327344_item	2948359	et	4	main
mitte	doc_96992327344_item	2948360	et	3	main
et	doc_96992327344_item	2948372	et	3	main
ta	doc_96992327344_item	2948373	et	4	main
ta	doc_96992327344_item	2948377	et	4	main
looduslaps	doc_96992327344_item	2948379	et	4	main
minu	doc_96992327344_item	2948382	et	3	main
meile	doc_96992327344_item	2948399	et	4	main
kuidas	doc_96992327344_item	2948411	et	3	main
veel	doc_973441205323_item	2948427	et	4	main
õpin	doc_973441205323_item	2948429	et	3	main
on	doc_973441205323_item	2948437	et	4	main
õppetöös	doc_973441205323_item	2948438	et	3	main
kõige	doc_973441205323_item	2948439	et	4	main
on	doc_973441205323_item	2948443	et	4	main
kus	doc_973441205323_item	2948446	et	3	main
kõik	doc_973441205323_item	2948461	et	4	main
sinu	doc_973441205323_item	2948465	et	3	main
edasi	doc_973441205323_item	2948471	et	3	main
tahan	doc_973441205323_item	2948474	et	3	main
soovid	doc_973441205323_item	2948481	et	4	main
kas	doc_973441205323_item	2948497	et	3	main
et	doc_973441205323_item	2948504	et	3	main
tänapäeva	doc_973441205323_item	2948505	et	4	main
noored	doc_973441205323_item	2948506	et	3	main
väärustavad	doc_973441205323_item	2948507	et	3	main
on	doc_973441205323_item	2948512	et	4	main
ja	doc_973441205323_item	2948521	et	3	main
kõrg	doc_973441205323_item	2948523	et	4	main
haridust	doc_973441205323_item	2948524	et	4	main
küsimusele	doc_973441205324_item	2948526	et	4	main
terve	doc_973441205324_item	2948543	et	4	main
vaja	doc_973441205324_item	2948547	et	4	main
tulevikus	doc_973441205324_item	2948549	et	4	main
ja	doc_973441205324_item	2948550	et	3	main
ma	doc_973441205324_item	2948551	et	3	main
võin	doc_973441205324_item	2948552	et	3	main
kus	doc_973441205324_item	2948557	et	3	main
vajalikku	doc_973441205324_item	2948560	et	4	main
2kuidas	doc_973441205324_item	2948562	et	3	main
sa	doc_973441205324_item	2948563	et	3	main
praegu	doc_973441205324_item	2948565	et	3	main
ma	doc_973441205324_item	2948566	et	3	main
arvan	doc_973441205324_item	2948567	et	3	main
et	doc_973441205324_item	2948568	et	3	main
praegu	doc_973441205324_item	2948569	et	3	main
ma	doc_973441205324_item	2948570	et	3	main
ei	doc_973441205324_item	2948571	et	4	main
visakaltma	doc_973441205324_item	2948606	et	4	main
on	doc_973441205324_item	2948611	et	4	main
et	doc_973441205324_item	2948617	et	3	main
tegelen	doc_973441205324_item	2948621	et	3	main
oppetöös	doc_973441205324_item	2948629	et	4	main
tuntub	doc_973441205324_item	2948631	et	4	main
jaoks	doc_973441205324_item	2948635	et	4	main
õppe	doc_973441205324_item	2948645	et	4	main
veel	doc_973441205324_item	2948648	et	4	main
õppe	doc_973441205324_item	2948659	et	4	main
eesmärk	doc_973441205324_item	2948660	et	3	main
alguses	doc_973441205324_item	2948670	et	4	main
ma	doc_973441205324_item	2948671	et	3	main
püstitasin	doc_973441205324_item	2948672	et	3	main
siin	doc_973441205324_item	2948681	et	4	main
ma	doc_973441205324_item	2948682	et	3	main
näen	doc_973441205324_item	2948683	et	3	main
poliitiline	doc_96992327343_item	2948289	et	3	main
mulle	doc_96992327343_item	2948298	et	4	main
muinasjutu	doc_96992327343_item	2948299	et	3	main
meelde	doc_96992327343_item	2948300	et	3	main
essee	doc_96992327344_item	2948301	et	4	main
libahunt	doc_96992327344_item	2948302	et	3	main
vaatasin	doc_96992327344_item	2948303	et	3	main
ühiskonnast	doc_96992327344_item	2948307	et	4	main
ema	doc_96992327344_item	2948316	et	4	main
tüdruk	doc_96992327344_item	2948320	et	3	main
vabaks	doc_96992327344_item	2948324	et	3	main
on	doc_96992327344_item	2948333	et	4	main
libahunt	doc_96992327344_item	2948334	et	3	main
eest	doc_96992327344_item	2948340	et	4	main
metsa	doc_96992327344_item	2948341	et	4	main
libahunt	doc_96992327344_item	2948342	et	3	main
on	doc_96992327344_item	2948343	et	4	main
film	doc_96992327344_item	2948344	et	3	main
on	doc_96992327344_item	2948357	et	4	main
vabadus	doc_96992327344_item	2948358	et	4	main
neiu-tiina	doc_96992327344_item	2948366	et	4	main
meeldis	doc_96992327344_item	2948367	et	3	main
on	doc_96992327344_item	2948374	et	4	main
näpuga	doc_96992327344_item	2948393	et	3	main
teise	doc_96992327344_item	2948395	et	4	main
kuidas	doc_96992327344_item	2948405	et	3	main
sõltuvad	doc_96992327344_item	2948409	et	4	main
õpin	doc_973441205323_item	2948421	et	3	main
kõrgharidust	doc_973441205323_item	2948434	et	4	main
missusused	doc_973441205323_item	2948435	et	4	main
raskus	doc_973441205323_item	2948441	et	4	main
et	doc_973441205323_item	2948452	et	3	main
õppida	doc_973441205323_item	2948454	et	3	main
sest	doc_973441205323_item	2948458	et	4	main
eestis	doc_973441205323_item	2948459	et	3	main
on	doc_973441205323_item	2948460	et	4	main
õppida	doc_973441205323_item	2948475	et	3	main
tallinna	doc_973441205323_item	2948477	et	4	main
tehnika	doc_973441205323_item	2948478	et	4	main
hea	doc_973441205323_item	2948491	et	4	main
suurt	doc_973441205323_item	2948495	et	3	main
rohkem	doc_973441205323_item	2948514	et	4	main
astuvad	doc_973441205323_item	2948518	et	4	main
kõrghariduse	doc_973441205323_item	2948519	et	3	main
asutuse	doc_973441205323_item	2948520	et	4	main
ma	doc_973441205324_item	2948528	et	3	main
tahan	doc_973441205324_item	2948529	et	3	main
tahan	doc_973441205324_item	2948532	et	3	main
laheb	doc_973441205324_item	2948546	et	4	main
mulle	doc_973441205324_item	2948548	et	4	main
läbi	doc_973441205324_item	2948553	et	4	main
viia	doc_973441205324_item	2948554	et	3	main
ma	doc_973441205324_item	2948558	et	3	main
ametit	doc_973441205324_item	2948561	et	3	main
keskeltmõnetes	doc_973441205324_item	2948575	et	4	main
õppeainetes	doc_973441205324_item	2948576	et	3	main
aru	doc_973441205324_item	2948608	et	4	main
et	doc_973441205324_item	2948609	et	3	main
õppida	doc_973441205324_item	2948610	et	3	main
klassis	doc_973441205324_item	2948619	et	3	main
vastutuslikult	doc_973441205324_item	2948623	et	4	main
4mis	doc_973441205324_item	2948624	et	4	main
peamine	doc_973441205324_item	2948626	et	3	main
jaoks	doc_973441205324_item	2948628	et	4	main
peaimine	doc_973441205324_item	2948633	et	4	main
hool	doc_973441205324_item	2948638	et	4	main
5missugused	doc_973441205324_item	2948641	et	3	main
mina	doc_973441205324_item	2948647	et	4	main
minu	doc_973441205324_item	2948657	et	3	main
on	doc_973441205324_item	2948661	et	4	main
eksamite	doc_973441205324_item	2948662	et	3	main
sooritamine	doc_973441205324_item	2948663	et	4	main
6missugused	doc_973441205324_item	2948664	et	3	main
ülesanded	doc_973441205324_item	2948665	et	3	main
sa	doc_973441205324_item	2948666	et	3	main
enda	doc_973441205324_item	2948667	et	4	main
jaoks	doc_973441205324_item	2948674	et	4	main
et	doc_973441205324_item	2948684	et	3	main
ei	doc_973441205324_item	2948685	et	4	main
ei	doc_973441205325_item	2948734	et	4	main
oskagi	doc_973441205325_item	2948735	et	4	main
elada	doc_973441205325_item	2948736	et	3	main
nii	doc_973441205325_item	2948737	et	3	main
ja	doc_96992327344_item	2948325	et	3	main
et	doc_96992327344_item	2948330	et	3	main
ka	doc_96992327344_item	2948331	et	3	main
tema	doc_96992327344_item	2948332	et	4	main
kahtluse	doc_96992327344_item	2948339	et	4	main
ühiskonnast	doc_96992327344_item	2948346	et	4	main
suhetest	doc_96992327344_item	2948347	et	3	main
minu	doc_96992327344_item	2948348	et	3	main
arust	doc_96992327344_item	2948349	et	4	main
kõige	doc_96992327344_item	2948350	et	4	main
eelarvamustest	doc_96992327344_item	2948365	et	4	main
film	doc_96992327344_item	2948380	et	3	main
arvates	doc_96992327344_item	2948383	et	4	main
räägib	doc_96992327344_item	2948384	et	3	main
väga	doc_96992327344_item	2948385	et	3	main
hästi	doc_96992327344_item	2948386	et	3	main
ka	doc_96992327344_item	2948387	et	3	main
inimene	doc_96992327344_item	2948391	et	3	main
näidates	doc_96992327344_item	2948394	et	3	main
hävitada	doc_96992327344_item	2948396	et	3	main
näitab	doc_96992327344_item	2948398	et	3	main
rahvahulga	doc_96992327344_item	2948400	et	3	main
julmust	doc_96992327344_item	2948403	et	4	main
inimesed	doc_96992327344_item	2948406	et	3	main
teisest	doc_96992327344_item	2948408	et	4	main
ja	doc_96992327344_item	2948410	et	3	main
nad	doc_96992327344_item	2948412	et	3	main
et	doc_973441205323_item	2948422	et	3	main
olla	doc_973441205323_item	2948423	et	3	main
haritud	doc_973441205323_item	2948426	et	4	main
ma	doc_973441205323_item	2948428	et	3	main
sest	doc_973441205323_item	2948430	et	4	main
ma	doc_973441205323_item	2948431	et	3	main
tahan	doc_973441205323_item	2948432	et	3	main
saada	doc_973441205323_item	2948433	et	4	main
sest	doc_973441205323_item	2948442	et	4	main
arvan	doc_973441205323_item	2948451	et	3	main
parem	doc_973441205323_item	2948453	et	4	main
eestis	doc_973441205323_item	2948455	et	3	main
kui	doc_973441205323_item	2948456	et	3	main
välismaal	doc_973441205323_item	2948457	et	4	main
tuttav	doc_973441205323_item	2948462	et	3	main
sõbrad	doc_973441205323_item	2948466	et	3	main
kus	doc_973441205323_item	2948469	et	3	main
sooviksid	doc_973441205323_item	2948470	et	4	main
ma	doc_973441205323_item	2948473	et	3	main
kõrg	doc_973441205323_item	2948482	et	4	main
haridust	doc_973441205323_item	2948483	et	4	main
omandada	doc_973441205323_item	2948484	et	3	main
sest	doc_973441205323_item	2948485	et	4	main
kõrg	doc_973441205323_item	2948486	et	4	main
haridus	doc_973441205323_item	2948487	et	3	main
annab	doc_973441205323_item	2948488	et	3	main
võimalus	doc_973441205323_item	2948489	et	3	main
astuda	doc_973441205323_item	2948490	et	3	main
ja	doc_973441205323_item	2948493	et	3	main
haridust	doc_973441205323_item	2948508	et	4	main
sest	doc_973441205323_item	2948509	et	4	main
igal	doc_973441205323_item	2948510	et	3	main
noored	doc_973441205323_item	2948517	et	3	main
saavad	doc_973441205323_item	2948522	et	4	main
vastus	doc_973441205324_item	2948525	et	3	main
sestet	doc_973441205324_item	2948534	et	4	main
teadmised	doc_973441205324_item	2948536	et	4	main
saaks	doc_973441205324_item	2948559	et	3	main
õpid	doc_973441205324_item	2948564	et	4	main
õppi	doc_973441205324_item	2948572	et	4	main
on	doc_973441205324_item	2948578	et	4	main
siis	doc_973441205324_item	2948614	et	3	main
märkasin	doc_973441205324_item	2948616	et	3	main
viimases	doc_973441205324_item	2948618	et	3	main
mulle	doc_973441205324_item	2948630	et	4	main
õppetöös	doc_973441205324_item	2948636	et	3	main
vastutus	doc_973441205324_item	2948640	et	4	main
taha	doc_973441205324_item	2948653	et	4	main
edasi	doc_973441205324_item	2948654	et	3	main
õppida	doc_973441205324_item	2948655	et	3	main
jaoks	doc_973441205324_item	2948668	et	4	main
püstitasid	doc_973441205324_item	2948669	et	4	main
ülesande	doc_973441205324_item	2948675	et	4	main
kooli	doc_973441205324_item	2948677	et	4	main
ilma	doc_973441205324_item	2948678	et	4	main
tulevikus	doc_973441205324_item	2948721	et	4	main
1	doc_973441205325_item	2948724	et	2	main
arvan	doc_973441205325_item	2948748	et	3	main
halvasti	doc_973441205325_item	2948750	et	3	main
valdkondadele	doc_973441205325_item	2948766	et	3	main
õppisid	doc_973441205325_item	2948778	et	4	main
3	doc_973441205325_item	2948779	et	2	main
aga	doc_973441205325_item	2948790	et	3	main
jaoks	doc_973441205325_item	2948799	et	4	main
õppetöös	doc_973441205325_item	2948800	et	3	main
arvan	doc_96992327344_item	2948371	et	3	main
täiesti	doc_96992327344_item	2948375	et	3	main
sellest	doc_96992327344_item	2948388	et	4	main
kuidas	doc_96992327344_item	2948389	et	3	main
üks	doc_96992327344_item	2948390	et	3	main
film	doc_96992327344_item	2948397	et	3	main
kardavad	doc_96992327344_item	2948413	et	4	main
uuendusi	doc_96992327344_item	2948414	et	4	main
tark	doc_973441205323_item	2948424	et	3	main
puudub	doc_973441205323_item	2948444	et	3	main
eestis	doc_973441205323_item	2948463	et	3	main
on	doc_973441205323_item	2948464	et	4	main
ja	doc_973441205323_item	2948467	et	3	main
sugulased	doc_973441205323_item	2948468	et	3	main
ülikoolis	doc_973441205323_item	2948479	et	4	main
tööle	doc_973441205323_item	2948492	et	3	main
saada	doc_973441205323_item	2948494	et	4	main
tänapäeva	doc_973441205323_item	2948498	et	4	main
väärtustavad	doc_973441205323_item	2948500	et	4	main
haridust	doc_973441205323_item	2948501	et	4	main
ma	doc_973441205323_item	2948502	et	3	main
arvan	doc_973441205323_item	2948503	et	3	main
ikka	doc_973441205323_item	2948513	et	4	main
rohkem	doc_973441205323_item	2948516	et	4	main
ja	doc_973441205323_item	2948425	et	3	main
raskused	doc_973441205323_item	2948436	et	4	main
tähtsam	doc_973441205323_item	2948440	et	4	main
vabaaeg	doc_973441205323_item	2948445	et	3	main
on	doc_973441205323_item	2948447	et	4	main
parem	doc_973441205323_item	2948448	et	4	main
õppida	doc_973441205323_item	2948449	et	3	main
ma	doc_973441205323_item	2948450	et	3	main
õppida	doc_973441205323_item	2948472	et	3	main
eestis	doc_973441205323_item	2948476	et	3	main
miks	doc_973441205323_item	2948480	et	4	main
palka	doc_973441205323_item	2948496	et	4	main
noored	doc_973441205323_item	2948499	et	3	main
aastal	doc_973441205323_item	2948511	et	3	main
ja	doc_973441205323_item	2948515	et	3	main
ma	doc_973441205324_item	2948531	et	3	main
elukidlasti	doc_973441205324_item	2948544	et	4	main
ulikoolisse	doc_973441205324_item	2948556	et	4	main
õpin	doc_973441205324_item	2948574	et	3	main
mul	doc_973441205324_item	2948577	et	3	main
vaja	doc_973441205324_item	2948612	et	4	main
1miks	doc_973441205324_item	2948527	et	4	main
õppida	doc_973441205324_item	2948530	et	3	main
õppida	doc_973441205324_item	2948533	et	3	main
need	doc_973441205324_item	2948535	et	3	main
mis	doc_973441205324_item	2948537	et	4	main
ma	doc_973441205324_item	2948538	et	3	main
sain	doc_973441205324_item	2948539	et	3	main
koolis	doc_973441205324_item	2948540	et	4	main
tuleb	doc_973441205324_item	2948541	et	3	main
kasutada	doc_973441205324_item	2948542	et	3	main
keskharidus	doc_973441205324_item	2948545	et	3	main
hea	doc_973441205324_item	2948555	et	4	main
hästiaga	doc_973441205324_item	2948573	et	4	main
head	doc_973441205324_item	2948579	et	4	main
hinnedaga	doc_973441205324_item	2948580	et	4	main
teistes	doc_973441205324_item	2948581	et	4	main
õppeainetes	doc_973441205324_item	2948582	et	3	main
situatsioon	doc_973441205324_item	2948583	et	3	main
ei	doc_973441205324_item	2948584	et	4	main
oli	doc_973441205324_item	2948585	et	3	main
nii	doc_973441205324_item	2948586	et	3	main
paha	doc_973441205324_item	2948587	et	4	main
3kuidas	doc_973441205324_item	2948588	et	3	main
sa	doc_973441205324_item	2948589	et	3	main
varem	doc_973441205324_item	2948590	et	4	main
näiteksalg	doc_973441205324_item	2948592	et	3	main
koolis	doc_973441205324_item	2948593	et	4	main
õppisid	doc_973441205324_item	2948591	et	4	main
ma	doc_973441205324_item	2948594	et	3	main
õppisin	doc_973441205324_item	2948595	et	3	main
hästiaga	doc_973441205324_item	2948596	et	4	main
sel	doc_973441205324_item	2948597	et	3	main
ajal	doc_973441205324_item	2948598	et	4	main
ma	doc_973441205324_item	2948599	et	3	main
tunnen	doc_973441205324_item	2948600	et	3	main
et	doc_973441205324_item	2948601	et	3	main
ma	doc_973441205324_item	2948602	et	3	main
ei	doc_973441205324_item	2948603	et	4	main
õpi	doc_973441205324_item	2948604	et	4	main
nii	doc_973441205324_item	2948605	et	3	main
saan	doc_973441205324_item	2948607	et	4	main
ja	doc_973441205324_item	2948613	et	3	main
ma	doc_973441205324_item	2948615	et	3	main
ma	doc_973441205324_item	2948620	et	3	main
õppetööga	doc_973441205324_item	2948622	et	3	main
on	doc_973441205324_item	2948625	et	4	main
sinu	doc_973441205324_item	2948627	et	3	main
et	doc_973441205324_item	2948632	et	3	main
minu	doc_973441205324_item	2948634	et	3	main
on	doc_973441205324_item	2948637	et	4	main
eesmärgid	doc_973441205324_item	2948646	et	3	main
ei	doc_973441205324_item	2948649	et	4	main
otsustanud	doc_973441205324_item	2948650	et	4	main
kus	doc_973441205324_item	2948651	et	3	main
ma	doc_973441205324_item	2948652	et	3	main
pea	doc_973441205324_item	2948658	et	4	main
kolme	doc_973441205324_item	2948679	et	4	main
aga	doc_973441205324_item	2948680	et	3	main
täita	doc_973441205324_item	2948689	et	4	main
2	doc_973441205325_item	2948747	et	2	main
hulk	doc_973441205325_item	2948754	et	3	main
märksalt	doc_973441205325_item	2948755	et	4	main
asjadele	doc_973441205325_item	2948764	et	3	main
minu	doc_973441205325_item	2948768	et	3	main
protsess	doc_973441205325_item	2948770	et	3	main
olid	doc_973441205325_item	2948791	et	4	main
lausa	doc_973441205325_item	2948792	et	4	main
ja	doc_973441205324_item	2948639	et	3	main
on	doc_973441205324_item	2948642	et	4	main
sinu	doc_973441205324_item	2948643	et	3	main
peamised	doc_973441205324_item	2948644	et	3	main
sest	doc_973441205324_item	2948656	et	4	main
enda	doc_973441205324_item	2948673	et	4	main
lõpetama	doc_973441205324_item	2948676	et	4	main
saa	doc_973441205324_item	2948686	et	4	main
seda	doc_973441205324_item	2948687	et	3	main
ülesannet	doc_973441205324_item	2948688	et	4	main
7mis	doc_973441205324_item	2948690	et	4	main
mõjutab	doc_973441205324_item	2948691	et	3	main
sinu	doc_973441205324_item	2948692	et	3	main
õppetööd	doc_973441205324_item	2948693	et	4	main
minu	doc_973441205324_item	2948694	et	3	main
öppetööd	doc_973441205324_item	2948695	et	4	main
mõjutab	doc_973441205324_item	2948696	et	3	main
minu	doc_973441205324_item	2948697	et	3	main
arvates	doc_973441205324_item	2948698	et	4	main
suhted	doc_973441205324_item	2948699	et	3	main
teisega	doc_973441205324_item	2948700	et	4	main
inimestega	doc_973441205324_item	2948701	et	3	main
ja	doc_973441205324_item	2948702	et	3	main
ka	doc_973441205324_item	2948703	et	3	main
suhe	doc_973441205324_item	2948704	et	3	main
oppeainetele	doc_973441205324_item	2948705	et	4	main
8kuidas	doc_973441205324_item	2948706	et	3	main
sa	doc_973441205324_item	2948707	et	3	main
näed	doc_973441205324_item	2948708	et	3	main
oma	doc_973441205324_item	2948709	et	4	main
õpinguid	doc_973441205324_item	2948710	et	3	main
tulevikus	doc_973441205324_item	2948711	et	4	main
mul	doc_973441205324_item	2948712	et	3	main
ainult	doc_973441205324_item	2948713	et	4	main
pole	doc_973441205324_item	2948714	et	3	main
ideet	doc_973441205324_item	2948715	et	4	main
kuidas	doc_973441205324_item	2948716	et	3	main
ma	doc_973441205324_item	2948717	et	3	main
näen	doc_973441205324_item	2948718	et	3	main
oma	doc_973441205324_item	2948719	et	4	main
õpinguid	doc_973441205324_item	2948720	et	3	main
küsimusele	doc_973441205325_item	2948723	et	4	main
miks	doc_973441205325_item	2948725	et	4	main
ma	doc_973441205325_item	2948726	et	3	main
tahan	doc_973441205325_item	2948727	et	3	main
õppida	doc_973441205325_item	2948728	et	3	main
tean	doc_973441205325_item	2948730	et	3	main
et	doc_973441205325_item	2948731	et	3	main
ilma	doc_973441205325_item	2948732	et	4	main
hariduseta	doc_973441205325_item	2948733	et	3	main
praegu	doc_973441205325_item	2948746	et	3	main
vastus	doc_973441205325_item	2948722	et	3	main
1	doc_973441205325_item	2948729	et	2	main
õpid	doc_973441205325_item	2948745	et	4	main
minu	doc_973441205325_item	2948752	et	3	main
vähenenult	doc_973441205325_item	2948756	et	4	main
ja	doc_973441205325_item	2948757	et	3	main
hakkasin	doc_973441205325_item	2948758	et	3	main
mina	doc_973441205325_item	2948759	et	4	main
pöörama	doc_973441205325_item	2948760	et	3	main
ja	doc_973441205325_item	2948765	et	3	main
pärssis	doc_973441205325_item	2948771	et	3	main
noormatselt	doc_973441205325_item	2948780	et	4	main
aga	doc_973441205325_item	2948781	et	3	main
silmaring	doc_973441205325_item	2948782	et	3	main
olnud	doc_973441205325_item	2948784	et	4	main
nii	doc_973441205325_item	2948785	et	3	main
lai	doc_973441205325_item	2948786	et	3	main
nagu	doc_973441205325_item	2948787	et	3	main
täna	doc_973441205325_item	2948788	et	4	main
hinded	doc_973441205325_item	2948789	et	3	main
on	doc_973441205325_item	2948796	et	4	main
peamine	doc_973441205325_item	2948797	et	3	main
sinu	doc_973441205325_item	2948798	et	3	main
4	doc_973441205325_item	2948801	et	2	main
eruditsiooni	doc_973441205325_item	2948805	et	4	main
laiendamine	doc_973441205325_item	2948806	et	4	main
tulemused	doc_973441205325_item	2948807	et	3	main
aga	doc_973441205325_item	2948808	et	3	main
ei	doc_973441205325_item	2948809	et	4	main
ole	doc_973441205325_item	2948810	et	4	main
nii	doc_973441205325_item	2948811	et	3	main
vajalikud	doc_973441205325_item	2948812	et	3	main
peamine	doc_973441205325_item	2948813	et	3	main
asi	doc_973441205325_item	2948814	et	4	main
on	doc_973441205325_item	2948815	et	4	main
teadmised	doc_973441205325_item	2948816	et	4	main
ja	doc_973441205325_item	2948817	et	3	main
oskus	doc_973441205325_item	2948818	et	3	main
õppida	doc_973441205325_item	2948819	et	3	main
ja	doc_973441205325_item	2948820	et	3	main
omistada	doc_973441205325_item	2948821	et	3	main
missugused	doc_973441205325_item	2948826	et	3	main
sinu	doc_973441205325_item	2948828	et	3	main
peamised	doc_973441205325_item	2948829	et	3	main
jaoks	doc_973441205325_item	2948849	et	4	main
mitte	doc_973441205325_item	2948850	et	3	main
heade	doc_973441205325_item	2948851	et	3	main
hinnete	doc_973441205325_item	2948852	et	3	main
esiteks	doc_973441205325_item	2948861	et	3	main
tahe	doc_973441205325_item	2948864	et	4	main
kindlasti	doc_973441205325_item	2948868	et	3	main
mina	doc_973441205326_item	2948910	et	4	main
infoabimees	doc_973441205326_item	2948913	et	4	main
mis	doc_973441205326_item	2948914	et	4	main
nagu	doc_973441205325_item	2948738	et	3	main
tahan	doc_973441205325_item	2948739	et	3	main
ja	doc_973441205325_item	2948740	et	3	main
pean	doc_973441205325_item	2948741	et	4	main
2	doc_973441205325_item	2948742	et	2	main
kuidas	doc_973441205325_item	2948743	et	3	main
sa	doc_973441205325_item	2948744	et	3	main
et	doc_973441205325_item	2948749	et	3	main
kuna	doc_973441205325_item	2948751	et	3	main
eesmäkite	doc_973441205325_item	2948753	et	4	main
rohkem	doc_973441205325_item	2948761	et	4	main
tähelepanu	doc_973441205325_item	2948762	et	4	main
konkreetstele	doc_973441205325_item	2948763	et	4	main
seepaärast	doc_973441205325_item	2948767	et	4	main
õpiimine	doc_973441205325_item	2948769	et	4	main
või	doc_973441205325_item	2948772	et	4	main
soiskus	doc_973441205325_item	2948773	et	4	main
3	doc_973441205325_item	2948774	et	2	main
kuidas	doc_973441205325_item	2948775	et	3	main
sa	doc_973441205325_item	2948776	et	3	main
ei	doc_973441205325_item	2948783	et	4	main
mis	doc_973441205325_item	2948795	et	4	main
vestlemine	doc_973441205325_item	2948802	et	4	main
ja	doc_973441205325_item	2948804	et	3	main
uut	doc_973441205325_item	2948823	et	3	main
kohendada	doc_973441205325_item	2948824	et	3	main
õppe-eesmärgid	doc_973441205325_item	2948830	et	3	main
5	doc_973441205325_item	2948831	et	2	main
olla	doc_973441205325_item	2948832	et	3	main
erudeeritud	doc_973441205325_item	2948833	et	3	main
ja	doc_973441205325_item	2948834	et	3	main
palju	doc_973441205325_item	2948835	et	4	main
jaoks	doc_973441205325_item	2948843	et	4	main
suhtumine	doc_973441205325_item	2948862	et	4	main
kolmandaks	doc_973441205325_item	2948867	et	4	main
nende	doc_973441205325_item	2948876	et	4	main
telefonivestlus	doc_973441205326_item	2948903	et	3	main
probleemidest	doc_973441205326_item	2948920	et	3	main
mul	doc_973441205326_item	2948935	et	3	main
ja	doc_973441205326_item	2948940	et	3	main
tean	doc_973441205326_item	2948942	et	3	main
kinkida	doc_973441205326_item	2948952	et	3	main
sony	doc_973441205326_item	2948954	et	4	main
mina	doc_973441205326_item	2948957	et	4	main
menüü	doc_973441205326_item	2948966	et	4	main
ja	doc_973441205326_item	2948967	et	3	main
kuidas	doc_973441205326_item	2948968	et	3	main
leida	doc_973441205326_item	2948969	et	3	main
sõnumit	doc_973441205326_item	2948970	et	3	main
kirjutamine	doc_973441205326_item	2948971	et	4	main
jah	doc_973441205326_item	2948972	et	3	main
ma	doc_973441205326_item	2948973	et	3	main
aitan	doc_973441205326_item	2948974	et	3	main
kirjutada	doc_973441205326_item	2948979	et	3	main
noh	doc_973441205326_item	2948980	et	3	main
pildides	doc_973441205326_item	2948989	et	3	main
on	doc_973441205326_item	2948992	et	4	main
helinad	doc_973441205326_item	2949001	et	3	main
vali	doc_973441205326_item	2949005	et	4	main
tekstisõnum	doc_973441205326_item	2949014	et	3	main
ui	doc_973441205326_item	2949037	et	4	main
ok	doc_973441205326_item	2949041	et	4	main
suur	doc_973441205326_item	2949051	et	3	main
teile	doc_973441205326_item	2949053	et	4	main
aitame	doc_973441205326_item	2949061	et	3	main
628	doc_973441205327_item	2949068	et	2	main
ei	doc_973441205327_item	2949071	et	4	main
suur	doc_973441205327_item	2949073	et	3	main
aasta	doc_973441205327_item	2949112	et	4	main
näitlesime	doc_973441205327_item	2949114	et	3	main
muinasjuttu	doc_973441205327_item	2949116	et	4	main
meeldisid	doc_973441205327_item	2949133	et	4	main
me	doc_973441205327_item	2949138	et	4	main
riietusime	doc_973441205327_item	2949139	et	4	main
palju	doc_973441205327_item	2949140	et	4	main
erinevatesse	doc_973441205327_item	2949141	et	4	main
kostüümidesse	doc_973441205327_item	2949142	et	3	main
päevarongi	doc_973441205327_item	2949144	et	4	main
kogunesime	doc_973441205327_item	2949153	et	3	main
jutustasime	doc_973441205327_item	2949156	et	3	main
essee	doc_973441205328_item	2949194	et	4	main
varem	doc_973441205325_item	2948777	et	4	main
rahuldavad	doc_973441205325_item	2948793	et	4	main
4	doc_973441205325_item	2948794	et	2	main
midagi	doc_973441205325_item	2948822	et	4	main
on	doc_973441205325_item	2948827	et	4	main
lugetud	doc_973441205325_item	2948836	et	4	main
poisina	doc_973441205325_item	2948837	et	3	main
6	doc_973441205325_item	2948838	et	2	main
missugused	doc_973441205325_item	2948839	et	3	main
ülesanded	doc_973441205325_item	2948840	et	3	main
sa	doc_973441205325_item	2948841	et	3	main
püstitasid	doc_973441205325_item	2948844	et	4	main
lihtsalt	doc_973441205325_item	2948846	et	4	main
õppida	doc_973441205325_item	2948847	et	3	main
enda	doc_973441205325_item	2948848	et	4	main
õppetööd	doc_973441205325_item	2948859	et	4	main
7	doc_973441205325_item	2948860	et	2	main
teiseks	doc_973441205325_item	2948863	et	4	main
huvitatus	doc_973441205325_item	2948870	et	4	main
kuidas	doc_973441205326_item	2948904	et	3	main
aidata	doc_973441205326_item	2948905	et	4	main
sms-sõnumeid	doc_973441205326_item	2948907	et	3	main
tere	doc_973441205326_item	2948909	et	3	main
olen	doc_973441205326_item	2948911	et	3	main
sinu	doc_973441205326_item	2948923	et	3	main
teada	doc_973441205326_item	2948927	et	3	main
sony	doc_973441205326_item	2948932	et	4	main
ericssoni	doc_973441205326_item	2948933	et	4	main
on	doc_973441205326_item	2948936	et	4	main
nokia	doc_973441205326_item	2948938	et	4	main
ma	doc_973441205326_item	2948941	et	3	main
siin	doc_973441205326_item	2948944	et	4	main
vanemad	doc_973441205326_item	2948949	et	4	main
tahavad	doc_973441205326_item	2948950	et	3	main
aga	doc_973441205326_item	2948958	et	3	main
selles	doc_973441205326_item	2948964	et	4	main
telefonis	doc_973441205326_item	2948965	et	3	main
võid	doc_973441205326_item	2948978	et	4	main
vali	doc_973441205326_item	2948982	et	4	main
oma	doc_973441205326_item	2948983	et	4	main
telefonis	doc_973441205326_item	2948984	et	3	main
menüü	doc_973441205326_item	2948985	et	4	main
üleval	doc_973441205326_item	2948991	et	4	main
kirjutatud	doc_973441205326_item	2948993	et	4	main
mis	doc_973441205326_item	2948994	et	4	main
pilt	doc_973441205326_item	2948995	et	3	main
see	doc_973441205326_item	2948996	et	3	main
või	doc_973441205326_item	2949002	et	4	main
ümbriku	doc_973441205326_item	2949006	et	4	main
pilt	doc_973441205326_item	2949007	et	3	main
ja	doc_973441205326_item	2949008	et	3	main
ilmuvad	doc_973441205326_item	2949009	et	4	main
erinevad	doc_973441205326_item	2949010	et	4	main
sõnumite	doc_973441205326_item	2949011	et	3	main
tüübid	doc_973441205326_item	2949012	et	3	main
mms-sõnum	doc_973441205326_item	2949015	et	3	main
mis	doc_973441205326_item	2949021	et	4	main
on	doc_973441205326_item	2949023	et	4	main
leidmine	doc_973441205326_item	2949034	et	4	main
oma	doc_973441205326_item	2949035	et	4	main
sms	doc_973441205326_item	2949045	et	4	main
on	doc_973441205326_item	2949046	et	4	main
saadetud	doc_973441205326_item	2949047	et	4	main
sellega	doc_973441205326_item	2949048	et	3	main
on	doc_973441205326_item	2949049	et	4	main
lõpp	doc_973441205326_item	2949050	et	3	main
aitäh	doc_973441205326_item	2949052	et	3	main
kohe	doc_973441205326_item	2949062	et	4	main
essee	doc_973441205327_item	2949063	et	4	main
see	doc_973441205327_item	2949069	et	3	main
asus	doc_973441205327_item	2949075	et	4	main
kodu	doc_973441205327_item	2949077	et	4	main
me	doc_973441205327_item	2949113	et	4	main
jõulu	doc_973441205327_item	2949115	et	4	main
metsloomad	doc_973441205327_item	2949123	et	3	main
päkapikud	doc_973441205327_item	2949131	et	4	main
me	doc_973441205327_item	2949152	et	4	main
mis	doc_973441205327_item	2949160	et	4	main
selles	doc_973441205327_item	2949162	et	4	main
kõik	doc_973441205327_item	2949181	et	4	main
rõõmsalt	doc_973441205327_item	2949186	et	4	main
ja	doc_973441205327_item	2949192	et	3	main
silmaringi	doc_973441205325_item	2948803	et	4	main
saamise	doc_973441205325_item	2948853	et	4	main
ja	doc_973441205325_item	2948865	et	3	main
nähes	doc_973441205325_item	2948875	et	4	main
paksust	doc_973441205325_item	2948902	et	4	main
et	doc_973441205326_item	2948906	et	3	main
kirjutada	doc_973441205326_item	2948908	et	3	main
sinu	doc_973441205326_item	2948912	et	3	main
kõikidest	doc_973441205326_item	2948919	et	4	main
mudelis	doc_973441205326_item	2948934	et	3	main
vaja	doc_973441205326_item	2948946	et	4	main
uue	doc_973441205326_item	2948953	et	3	main
ericsson	doc_973441205326_item	2948955	et	4	main
ei	doc_973441205326_item	2948960	et	4	main
meelsasti	doc_973441205326_item	2948976	et	3	main
sina	doc_973441205326_item	2948977	et	4	main
alustame	doc_973441205326_item	2948981	et	3	main
ja	doc_973441205326_item	2948990	et	3	main
siis	doc_973441205326_item	2949004	et	3	main
või	doc_973441205326_item	2949016	et	4	main
sulle	doc_973441205326_item	2949022	et	3	main
etap	doc_973441205326_item	2949028	et	4	main
selle	doc_973441205326_item	2949033	et	4	main
kontaktidest	doc_973441205326_item	2949036	et	3	main
numbri	doc_973441205326_item	2949039	et	3	main
kui	doc_973441205326_item	2949058	et	3	main
ei	doc_973441205326_item	2949059	et	4	main
õppisin	doc_973441205327_item	2949065	et	3	main
põhikoolis	doc_973441205327_item	2949066	et	4	main
kool	doc_973441205327_item	2949070	et	4	main
uus	doc_973441205327_item	2949111	et	3	main
selles	doc_973441205327_item	2949117	et	4	main
jõuluvana	doc_973441205327_item	2949120	et	4	main
lumehelbed	doc_973441205327_item	2949121	et	4	main
koos	doc_973441205327_item	2949126	et	4	main
õega	doc_973441205327_item	2949127	et	3	main
tantsivad	doc_973441205327_item	2949129	et	4	main
päkapikke	doc_973441205327_item	2949130	et	4	main
vedasime	doc_973441205327_item	2949143	et	3	main
ning	doc_973441205327_item	2949145	et	3	main
laulsime	doc_973441205327_item	2949146	et	3	main
laule	doc_973441205327_item	2949149	et	4	main
1	doc_973441205327_item	2949150	et	2	main
aprillil	doc_973441205327_item	2949151	et	3	main
ja	doc_973441205327_item	2949155	et	3	main
üksteistele	doc_973441205327_item	2949157	et	4	main
naljakaid	doc_973441205327_item	2949158	et	4	main
lugusid	doc_973441205327_item	2949159	et	3	main
meiega	doc_973441205327_item	2949161	et	4	main
möödusid	doc_973441205327_item	2949183	et	4	main
meeldiva	doc_973441205327_item	2949190	et	4	main
määlestused	doc_973441205327_item	2949193	et	4	main
tegeleb	doc_973441205328_item	2949210	et	3	main
valmistuvad	doc_973441205328_item	2949217	et	4	main
5	doc_973441205325_item	2948825	et	2	main
enda	doc_973441205325_item	2948842	et	4	main
6	doc_973441205325_item	2948845	et	2	main
puhul	doc_973441205325_item	2948854	et	4	main
7	doc_973441205325_item	2948855	et	2	main
mis	doc_973441205325_item	2948856	et	4	main
mõjutab	doc_973441205325_item	2948857	et	3	main
sinu	doc_973441205325_item	2948858	et	3	main
soov	doc_973441205325_item	2948866	et	3	main
õpetajate	doc_973441205325_item	2948869	et	4	main
oma	doc_973441205325_item	2948871	et	4	main
valdkonnas	doc_973441205325_item	2948872	et	4	main
kuna	doc_973441205325_item	2948873	et	3	main
tahan	doc_973441205325_item	2948874	et	3	main
raevust	doc_973441205325_item	2948877	et	4	main
ja	doc_973441205325_item	2948878	et	3	main
oma	doc_973441205325_item	2948879	et	4	main
tunnist	doc_973441205325_item	2948880	et	4	main
lihtsalt	doc_973441205325_item	2948881	et	4	main
meeletust	doc_973441205325_item	2948882	et	4	main
tahan	doc_973441205325_item	2948883	et	3	main
ka	doc_973441205325_item	2948884	et	3	main
õppida	doc_973441205325_item	2948885	et	3	main
seda	doc_973441205325_item	2948886	et	3	main
8	doc_973441205325_item	2948887	et	2	main
kuidas	doc_973441205325_item	2948888	et	3	main
sa	doc_973441205325_item	2948889	et	3	main
näed	doc_973441205325_item	2948890	et	3	main
oma	doc_973441205325_item	2948891	et	4	main
õpinguid	doc_973441205325_item	2948892	et	3	main
tulevikus	doc_973441205325_item	2948893	et	4	main
8	doc_973441205325_item	2948894	et	2	main
kõik	doc_973441205325_item	2948895	et	4	main
sõltub	doc_973441205325_item	2948896	et	3	main
minu	doc_973441205325_item	2948897	et	3	main
lõppeksamite	doc_973441205325_item	2948898	et	3	main
sootitamisest	doc_973441205325_item	2948899	et	4	main
ja	doc_973441205325_item	2948900	et	3	main
kukru	doc_973441205325_item	2948901	et	3	main
sind	doc_973441205326_item	2948915	et	4	main
huvitab	doc_973441205326_item	2948916	et	3	main
võid	doc_973441205326_item	2948917	et	4	main
küsida	doc_973441205326_item	2948918	et	3	main
mis	doc_973441205326_item	2948921	et	4	main
telefonis	doc_973441205326_item	2948924	et	3	main
tahan	doc_973441205326_item	2948926	et	3	main
kirjutada	doc_973441205326_item	2948929	et	3	main
uues	doc_973441205326_item	2948931	et	3	main
mobiiltelefon	doc_973441205326_item	2948939	et	3	main
kirjutada	doc_973441205326_item	2948947	et	3	main
mobiiltelefoni	doc_973441205326_item	2948956	et	4	main
üldse	doc_973441205326_item	2948959	et	3	main
tea	doc_973441205326_item	2948961	et	4	main
sind	doc_973441205326_item	2948975	et	4	main
on	doc_973441205326_item	2948997	et	4	main
kas	doc_973441205326_item	2948998	et	3	main
sõnumid	doc_973441205326_item	2948999	et	3	main
näiteks	doc_973441205326_item	2949013	et	4	main
vaja	doc_973441205326_item	2949024	et	4	main
kirjutad	doc_973441205326_item	2949025	et	3	main
sõnumitekst	doc_973441205326_item	2949026	et	3	main
järgmine	doc_973441205326_item	2949027	et	3	main
leiad	doc_973441205326_item	2949038	et	3	main
head	doc_973441205326_item	2949054	et	4	main
aega	doc_973441205326_item	2949055	et	4	main
palun	doc_973441205326_item	2949056	et	3	main
küsige	doc_973441205326_item	2949057	et	3	main
mina	doc_973441205327_item	2949064	et	4	main
olenud	doc_973441205327_item	2949072	et	4	main
ja	doc_973441205327_item	2949074	et	3	main
minu	doc_973441205327_item	2949076	et	3	main
jäi	doc_973441205327_item	2949108	et	3	main
mulle	doc_973441205327_item	2949109	et	4	main
meelde	doc_973441205327_item	2949110	et	3	main
muinasjutus	doc_973441205327_item	2949118	et	3	main
oli	doc_973441205327_item	2949119	et	3	main
tekkisid	doc_973441205326_item	2948922	et	4	main
ma	doc_973441205326_item	2948925	et	3	main
kuidas	doc_973441205326_item	2948928	et	3	main
sms-sõnumi	doc_973441205326_item	2948930	et	3	main
praegu	doc_973441205326_item	2948937	et	3	main
kuidas	doc_973441205326_item	2948943	et	3	main
on	doc_973441205326_item	2948945	et	4	main
aga	doc_973441205326_item	2948948	et	3	main
mulle	doc_973441205326_item	2948951	et	4	main
milline	doc_973441205326_item	2948962	et	3	main
on	doc_973441205326_item	2948963	et	4	main
ekraanil	doc_973441205326_item	2948986	et	3	main
ilmuvad	doc_973441205326_item	2948987	et	4	main
funktsioonid	doc_973441205326_item	2948988	et	3	main
abimees	doc_973441205326_item	2949000	et	4	main
kontaktid	doc_973441205326_item	2949003	et	3	main
kõneteade	doc_973441205326_item	2949017	et	4	main
sa	doc_973441205326_item	2949018	et	3	main
valid	doc_973441205326_item	2949019	et	3	main
sõnum	doc_973441205326_item	2949020	et	3	main
on	doc_973441205326_item	2949029	et	4	main
telefoninumbri	doc_973441205326_item	2949030	et	3	main
sisestamine	doc_973441205326_item	2949031	et	4	main
või	doc_973441205326_item	2949032	et	4	main
vajuta	doc_973441205326_item	2949040	et	4	main
ja	doc_973441205326_item	2949042	et	3	main
kõik	doc_973441205326_item	2949043	et	4	main
sinu	doc_973441205326_item	2949044	et	3	main
tea	doc_973441205326_item	2949060	et	4	main
nr	doc_973441205327_item	2949067	et	4	main
kõrval	doc_973441205327_item	2949078	et	4	main
meil	doc_973441205327_item	2949079	et	4	main
oli	doc_973441205327_item	2949080	et	3	main
sõbralik	doc_973441205327_item	2949081	et	3	main
klass	doc_973441205327_item	2949082	et	3	main
ja	doc_973441205327_item	2949083	et	3	main
ning	doc_973441205327_item	2949085	et	3	main
hea	doc_973441205327_item	2949084	et	4	main
lõbus	doc_973441205327_item	2949086	et	4	main
klassijuhataja	doc_973441205327_item	2949087	et	4	main
sellepärast	doc_973441205327_item	2949088	et	3	main
üritused	doc_973441205327_item	2949090	et	4	main
kõik	doc_973441205327_item	2949089	et	4	main
olid	doc_973441205327_item	2949091	et	4	main
koolis	doc_973441205327_item	2949092	et	4	main
me	doc_973441205327_item	2949093	et	4	main
tähistasime	doc_973441205327_item	2949094	et	3	main
koos	doc_973441205327_item	2949095	et	4	main
iga	doc_973441205327_item	2949096	et	4	main
üritus	doc_973441205327_item	2949097	et	4	main
ei	doc_973441205327_item	2949098	et	4	main
olnud	doc_973441205327_item	2949099	et	4	main
kunagi	doc_973441205327_item	2949100	et	3	main
üksluine	doc_973441205327_item	2949101	et	4	main
me	doc_973441205327_item	2949102	et	4	main
mõtlisime	doc_973441205327_item	2949103	et	4	main
alati	doc_973441205327_item	2949104	et	4	main
midagi	doc_973441205327_item	2949105	et	4	main
uut	doc_973441205327_item	2949106	et	3	main
eriti	doc_973441205327_item	2949107	et	3	main
mina	doc_973441205327_item	2949125	et	4	main
näitlesime	doc_973441205327_item	2949128	et	3	main
kõigile	doc_973441205327_item	2949134	et	4	main
ja	doc_973441205327_item	2949136	et	3	main
aulasse	doc_973441205327_item	2949154	et	4	main
päevas	doc_973441205327_item	2949163	et	3	main
toimusid	doc_973441205327_item	2949164	et	4	main
pärast	doc_973441205327_item	2949165	et	4	main
olid	doc_973441205327_item	2949166	et	4	main
näljanumbrid	doc_973441205327_item	2949167	et	3	main
ning	doc_973441205327_item	2949168	et	3	main
loosimised	doc_973441205327_item	2949169	et	4	main
aga	doc_973441205327_item	2949170	et	3	main
iga	doc_973441205327_item	2949171	et	4	main
lõpus	doc_973441205327_item	2949173	et	4	main
ürituse	doc_973441205327_item	2949172	et	4	main
olid	doc_973441205327_item	2949174	et	4	main
disko	doc_973441205327_item	2949175	et	4	main
õhtud	doc_973441205327_item	2949176	et	3	main
mis	doc_973441205327_item	2949177	et	4	main
eriti	doc_973441205327_item	2949178	et	3	main
meeldisid	doc_973441205327_item	2949179	et	4	main
õpilastele	doc_973441205327_item	2949180	et	4	main
kooliõhtud	doc_973441205327_item	2949182	et	3	main
ja	doc_973441205327_item	2949122	et	3	main
aga	doc_973441205327_item	2949124	et	3	main
eriti	doc_973441205327_item	2949132	et	3	main
kadri-	doc_973441205327_item	2949135	et	4	main
mardipäeval	doc_973441205327_item	2949137	et	3	main
eesti	doc_973441205327_item	2949147	et	4	main
rahvas	doc_973441205327_item	2949148	et	4	main
ennast	doc_973441205327_item	2949189	et	4	main
vahetund	doc_973441205328_item	2949195	et	4	main
et	doc_973441205328_item	2949198	et	3	main
igas	doc_973441205328_item	2949199	et	3	main
õpetajaid	doc_973441205328_item	2949214	et	4	main
vahetunni	doc_973441205328_item	2949215	et	3	main
kestel	doc_973441205328_item	2949216	et	4	main
vahetunnil	doc_973441205328_item	2949221	et	4	main
ei	doc_973441205328_item	2949223	et	4	main
lähen	doc_973441205328_item	2949230	et	3	main
ajal	doc_973441205328_item	2949235	et	4	main
käin	doc_973441205328_item	2949237	et	3	main
mõnikord	doc_973441205328_item	2949241	et	3	main
vahetunnis	doc_973441205328_item	2949267	et	4	main
vajalik	doc_973441205328_item	2949275	et	3	main
õue	doc_973441205328_item	2949286	et	4	main
jalutama	doc_973441205328_item	2949287	et	3	main
vastus	doc_973441205329_item	2949291	et	3	main
kõige	doc_973441205329_item	2949293	et	4	main
paremaks	doc_973441205329_item	2949294	et	4	main
huvitav	doc_973441205329_item	2949301	et	4	main
tasutav	doc_973441205329_item	2949304	et	4	main
kuid	doc_973441205329_item	2949305	et	4	main
minu	doc_973441205329_item	2949306	et	3	main
huvitav	doc_973441205329_item	2949312	et	4	main
see	doc_973441205329_item	2949314	et	3	main
järel	doc_973441205329_item	2949315	et	4	main
töö	doc_973441205329_item	2949321	et	4	main
meeldi	doc_973441205329_item	2949323	et	4	main
ka	doc_973441205329_item	2949325	et	3	main
töö	doc_973441205329_item	2949326	et	4	main
sobib	doc_973441205331_item	2949429	et	3	main
on	doc_973441205331_item	2949431	et	4	main
inimesi	doc_973441205331_item	2949432	et	4	main
juhtideks	doc_973441205331_item	2949436	et	3	main
ajal	doc_973441205331_item	2949439	et	4	main
saa	doc_973441205331_item	2949460	et	4	main
juhtideks	doc_973441205331_item	2949461	et	3	main
sest	doc_973441205331_item	2949462	et	4	main
hea	doc_973441205331_item	2949474	et	4	main
olema	doc_973441205331_item	2949478	et	4	main
ja	doc_973441205331_item	2949480	et	3	main
ning	doc_973441205331_item	2949482	et	3	main
tegudeks	doc_973441205331_item	2949487	et	3	main
suuremeelne	doc_973441205331_item	2949492	et	3	main
lahke	doc_973441205331_item	2949494	et	4	main
enese	doc_973441205331_item	2949525	et	4	main
üle	doc_973441205331_item	2949526	et	3	main
jääb	doc_973441205331_item	2949529	et	3	main
surmani	doc_973441205331_item	2949531	et	3	main
loete	doc_973441205332_item	2949538	et	4	main
oma	doc_973441205332_item	2949549	et	4	main
vabal	doc_973441205332_item	2949550	et	3	main
loen	doc_973441205332_item	2949558	et	3	main
oma	doc_973441205332_item	2949570	et	4	main
rohkem	doc_973441205332_item	2949577	et	4	main
välja	doc_973441205332_item	2949584	et	4	main
meie	doc_973441205332_item	2949585	et	4	main
gazeta	doc_973441205332_item	2949596	et	4	main
mulle	doc_973441205332_item	2949600	et	4	main
cool	doc_973441205332_item	2949604	et	4	main
ja	doc_973441205332_item	2949605	et	3	main
neis	doc_973441205332_item	2949613	et	4	main
nii	doc_973441205332_item	2949621	et	3	main
olen	doc_973441205332_item	2949623	et	3	main
meie	doc_973441205332_item	2949628	et	4	main
linnas	doc_973441205332_item	2949629	et	4	main
ning	doc_973441205332_item	2949630	et	3	main
huvitavalt	doc_973441205327_item	2949184	et	4	main
ja	doc_973441205327_item	2949185	et	3	main
jäätsid	doc_973441205327_item	2949187	et	4	main
peale	doc_973441205327_item	2949188	et	4	main
meeleolud	doc_973441205327_item	2949191	et	3	main
lemmiktund	doc_973441205328_item	2949201	et	3	main
vahetund	doc_973441205328_item	2949203	et	4	main
ajal	doc_973441205328_item	2949205	et	4	main
õpilane	doc_973441205328_item	2949207	et	3	main
järgmiseks	doc_973441205328_item	2949219	et	3	main
vahetunni	doc_973441205328_item	2949234	et	3	main
koolisööklas	doc_973441205328_item	2949238	et	3	main
kes	doc_973441205328_item	2949247	et	4	main
ka	doc_973441205328_item	2949262	et	3	main
mitu	doc_973441205328_item	2949263	et	4	main
käivad	doc_973441205328_item	2949270	et	4	main
kui	doc_973441205328_item	2949273	et	3	main
kui	doc_973441205328_item	2949276	et	3	main
ja	doc_973441205328_item	2949288	et	3	main
see	doc_973441205329_item	2949297	et	3	main
töö	doc_973441205329_item	2949309	et	4	main
kui	doc_973441205329_item	2949320	et	3	main
pole	doc_973441205329_item	2949328	et	3	main
vastus	doc_973441205331_item	2949425	et	3	main
kes	doc_973441205331_item	2949433	et	4	main
samal	doc_973441205331_item	2949438	et	3	main
on	doc_973441205331_item	2949440	et	4	main
on	doc_973441205331_item	2949444	et	4	main
õppinud	doc_973441205331_item	2949445	et	4	main
visa	doc_973441205331_item	2949447	et	4	main
ja	doc_973441205331_item	2949448	et	3	main
järjekindla	doc_973441205331_item	2949449	et	3	main
ja	doc_973441205331_item	2949451	et	3	main
koolituse	doc_973441205331_item	2949452	et	4	main
neil	doc_973441205331_item	2949463	et	4	main
antud	doc_973441205331_item	2949468	et	4	main
et	doc_973441205331_item	2949472	et	3	main
olla	doc_973441205331_item	2949473	et	3	main
veenda	doc_973441205331_item	2949486	et	4	main
ma	doc_973441205328_item	2949196	et	3	main
arvan	doc_973441205328_item	2949197	et	3	main
koolis	doc_973441205328_item	2949200	et	4	main
on	doc_973441205328_item	2949202	et	4	main
vahetunni	doc_973441205328_item	2949204	et	3	main
iga	doc_973441205328_item	2949206	et	4	main
õpetaja	doc_973441205328_item	2949209	et	4	main
oma	doc_973441205328_item	2949211	et	4	main
asjaga	doc_973441205328_item	2949212	et	3	main
enamus	doc_973441205328_item	2949213	et	4	main
ette	doc_973441205328_item	2949218	et	4	main
selle	doc_973441205328_item	2949228	et	4	main
pärast	doc_973441205328_item	2949229	et	4	main
jälutama	doc_973441205328_item	2949232	et	4	main
ma	doc_973441205328_item	2949236	et	3	main
söömas	doc_973441205328_item	2949240	et	4	main
kestel	doc_973441205328_item	2949243	et	4	main
vastu	doc_973441205328_item	2949261	et	3	main
lapsed	doc_973441205328_item	2949269	et	3	main
samuti	doc_973441205328_item	2949271	et	3	main
on	doc_973441205328_item	2949274	et	4	main
õues	doc_973441205328_item	2949277	et	4	main
on	doc_973441205328_item	2949278	et	4	main
ilus	doc_973441205328_item	2949279	et	4	main
ilm	doc_973441205328_item	2949280	et	3	main
siis	doc_973441205328_item	2949281	et	3	main
paljud	doc_973441205328_item	2949282	et	3	main
õpilased	doc_973441205328_item	2949283	et	3	main
lähevad	doc_973441205328_item	2949284	et	3	main
vareandiks	doc_973441205329_item	2949295	et	4	main
oleks	doc_973441205329_item	2949296	et	3	main
töö	doc_973441205329_item	2949299	et	4	main
hästi	doc_973441205329_item	2949303	et	3	main
peaks	doc_973441205329_item	2949310	et	4	main
tasutav	doc_973441205329_item	2949316	et	4	main
ma	doc_973441205329_item	2949317	et	3	main
mõtlen	doc_973441205329_item	2949318	et	3	main
et	doc_973441205329_item	2949319	et	3	main
ja	doc_973441205328_item	2949208	et	3	main
õppetunniks	doc_973441205328_item	2949220	et	3	main
mulle	doc_973441205328_item	2949222	et	4	main
meeldi	doc_973441205328_item	2949224	et	4	main
klassis	doc_973441205328_item	2949225	et	3	main
niisama	doc_973441205328_item	2949226	et	3	main
istuda	doc_973441205328_item	2949227	et	3	main
koridori	doc_973441205328_item	2949231	et	4	main
suure	doc_973441205328_item	2949233	et	3	main
lõunat	doc_973441205328_item	2949239	et	3	main
vahetunni	doc_973441205328_item	2949242	et	3	main
kohata	doc_973441205328_item	2949245	et	4	main
inimesi	doc_973441205328_item	2949246	et	4	main
lähevad	doc_973441205328_item	2949256	et	3	main
ja	doc_973441205328_item	2949257	et	3	main
tulevad	doc_973441205328_item	2949258	et	4	main
sulle	doc_973441205328_item	2949259	et	3	main
ajal	doc_973441205328_item	2949268	et	4	main
jutta	doc_973441205328_item	2949289	et	4	main
jaoks	doc_973441205329_item	2949307	et	4	main
eelkõige	doc_973441205329_item	2949308	et	3	main
olema	doc_973441205329_item	2949311	et	4	main
kuid	doc_973441205329_item	2949313	et	4	main
resultadid	doc_973441205329_item	2949327	et	4	main
sündinud	doc_973441205331_item	2949435	et	4	main
ka	doc_973441205331_item	2949441	et	3	main
teel	doc_973441205331_item	2949453	et	4	main
on	doc_973441205331_item	2949454	et	4	main
ka	doc_973441205331_item	2949455	et	3	main
inimesi	doc_973441205331_item	2949456	et	4	main
juhiks	doc_973441205331_item	2949465	et	4	main
omadusi	doc_973441205331_item	2949467	et	4	main
looduse	doc_973441205331_item	2949469	et	4	main
poolt	doc_973441205331_item	2949470	et	4	main
inimene	doc_973441205331_item	2949476	et	3	main
tasakalukas	doc_973441205331_item	2949481	et	4	main
teisi	doc_973441205331_item	2949484	et	4	main
inimesi	doc_973441205331_item	2949485	et	4	main
ta	doc_973441205331_item	2949488	et	4	main
olema	doc_973441205331_item	2949490	et	4	main
see	doc_973441205331_item	2949528	et	3	main
kõige	doc_973441205332_item	2949539	et	4	main
teid	doc_973441205332_item	2949543	et	4	main
neid	doc_973441205332_item	2949559	et	4	main
kuid	doc_973441205332_item	2949562	et	4	main
vana	doc_973441205332_item	2949571	et	4	main
vanemate	doc_973441205332_item	2949572	et	4	main
narva	doc_973441205332_item	2949586	et	4	main
cosmopolitan	doc_973441205332_item	2949606	et	4	main
meeldivad	doc_973441205332_item	2949608	et	4	main
kirjutatakse	doc_973441205332_item	2949614	et	3	main
välismaal	doc_973441205332_item	2949635	et	4	main
parendamisel	doc_973441205332_item	2949648	et	4	main
valimiseelsed	doc_973441205332_item	2949651	et	3	main
kus	doc_973441205332_item	2949662	et	3	main
sportlaste	doc_973441205332_item	2949665	et	4	main
elu	doc_973441205332_item	2949667	et	4	main
ja	doc_973441205332_item	2949668	et	3	main
tegemisi	doc_973441205332_item	2949671	et	4	main
armastan	doc_973441205332_item	2949674	et	3	main
on	doc_973441205332_item	2949677	et	4	main
ja	doc_973441205332_item	2949709	et	3	main
väga	doc_973441205332_item	2949720	et	3	main
võib	doc_973441205328_item	2949244	et	3	main
käivad	doc_973441205328_item	2949248	et	4	main
sööklas	doc_973441205328_item	2949249	et	3	main
mitu	doc_973441205328_item	2949250	et	4	main
see	doc_973441205328_item	2949252	et	3	main
korda	doc_973441205328_item	2949251	et	4	main
on	doc_973441205328_item	2949253	et	4	main
et	doc_973441205328_item	2949254	et	3	main
nad	doc_973441205328_item	2949255	et	3	main
koridoris	doc_973441205328_item	2949260	et	3	main
korda	doc_973441205328_item	2949264	et	4	main
peale	doc_973441205328_item	2949265	et	4	main
selle	doc_973441205328_item	2949266	et	4	main
tualetis	doc_973441205328_item	2949272	et	3	main
vahetunnil	doc_973441205328_item	2949285	et	4	main
ajama	doc_973441205328_item	2949290	et	4	main
küsimusele	doc_973441205329_item	2949292	et	4	main
kui	doc_973441205329_item	2949298	et	3	main
on	doc_973441205329_item	2949300	et	4	main
ja	doc_973441205329_item	2949302	et	3	main
küsimusele	doc_973441205331_item	2949426	et	4	main
milline	doc_973441205331_item	2949427	et	3	main
inimene	doc_973441205331_item	2949428	et	3	main
on	doc_973441205331_item	2949434	et	4	main
kuid	doc_973441205331_item	2949437	et	4	main
inimesi	doc_973441205331_item	2949442	et	4	main
vajalikke	doc_973441205331_item	2949466	et	3	main
selleks	doc_973441205331_item	2949471	et	4	main
peab	doc_973441205331_item	2949477	et	4	main
sihikindel	doc_973441205331_item	2949479	et	3	main
oskama	doc_973441205331_item	2949483	et	3	main
peab	doc_973441205331_item	2949489	et	4	main
sest	doc_973441205331_item	2949521	et	4	main
ei	doc_973441205331_item	2949523	et	4	main
jõua	doc_973441205331_item	2949524	et	4	main
sulaseks	doc_973441205331_item	2949530	et	4	main
küsimusele	doc_973441205332_item	2949533	et	4	main
milliseid	doc_973441205332_item	2949534	et	3	main
ajalehti	doc_973441205332_item	2949535	et	4	main
ja	doc_973441205332_item	2949536	et	3	main
ajakirju	doc_973441205332_item	2949537	et	4	main
teemad	doc_973441205332_item	2949542	et	3	main
miks	doc_973441205332_item	2949546	et	4	main
mulle	doc_973441205332_item	2949547	et	4	main
meeldib	doc_973441205332_item	2949548	et	3	main
tavaliselt	doc_973441205332_item	2949556	et	4	main
ma	doc_973441205332_item	2949557	et	3	main
kompuutri	doc_973441205332_item	2949560	et	4	main
vahel	doc_973441205332_item	2949564	et	4	main
trükitud	doc_973441205332_item	2949565	et	4	main
pool	doc_973441205332_item	2949573	et	4	main
külas	doc_973441205332_item	2949574	et	3	main
käin	doc_973441205332_item	2949575	et	3	main
mulle	doc_973441205332_item	2949579	et	4	main
kohalikud	doc_973441205332_item	2949580	et	3	main
mida	doc_973441205332_item	2949582	et	4	main
gorod	doc_973441205332_item	2949592	et	4	main
kreenholmi	doc_973441205332_item	2949593	et	4	main
prospekt	doc_973441205332_item	2949594	et	3	main
meeldivad	doc_973441205332_item	2949601	et	4	main
rohkem	doc_973441205332_item	2949603	et	4	main
sellepärast	doc_973441205332_item	2949611	et	3	main
kohalike	doc_973441205332_item	2949616	et	4	main
kursis	doc_973441205332_item	2949624	et	3	main
mis	doc_973441205332_item	2949626	et	4	main
kohalike	doc_973441205332_item	2949636	et	4	main
on	doc_973441205332_item	2949644	et	4	main
elu	doc_973441205332_item	2949647	et	4	main
millised	doc_973441205332_item	2949650	et	3	main
on	doc_973441205332_item	2949656	et	4	main
täitmisel	doc_973441205332_item	2949657	et	4	main
kirjeldatakse	doc_973441205332_item	2949663	et	3	main
sest	doc_973441205332_item	2949722	et	4	main
nad	doc_973441205332_item	2949723	et	3	main
tutvustavad	doc_973441205332_item	2949724	et	4	main
minule	doc_973441205332_item	2949725	et	3	main
ümbritsevad	doc_973441205332_item	2949726	et	4	main
e	doc_973441205329_item	2949322	et	4	main
siis	doc_973441205329_item	2949324	et	3	main
parimad	doc_973441205329_item	2949329	et	4	main
juhiks	doc_973441205331_item	2949430	et	4	main
kes	doc_973441205331_item	2949443	et	4	main
juhtideks	doc_973441205331_item	2949446	et	3	main
enesekasvatuse	doc_973441205331_item	2949450	et	3	main
kes	doc_973441205331_item	2949457	et	4	main
kunagi	doc_973441205331_item	2949458	et	3	main
ei	doc_973441205331_item	2949459	et	4	main
pole	doc_973441205331_item	2949464	et	3	main
juht	doc_973441205331_item	2949475	et	3	main
õiglane	doc_973441205331_item	2949491	et	3	main
ja	doc_973441205331_item	2949493	et	3	main
samal	doc_973441205331_item	2949495	et	3	main
ajal	doc_973441205331_item	2949496	et	4	main
peenetundeline	doc_973441205331_item	2949497	et	4	main
ning	doc_973441205331_item	2949498	et	3	main
kaaslasimõistev	doc_973441205331_item	2949499	et	4	main
hea	doc_973441205331_item	2949500	et	4	main
juht	doc_973441205331_item	2949501	et	3	main
on	doc_973441205331_item	2949502	et	4	main
otsekohene	doc_973441205331_item	2949503	et	3	main
ja	doc_973441205331_item	2949504	et	3	main
avameelne	doc_973441205331_item	2949505	et	3	main
seltsiv	doc_973441205331_item	2949506	et	4	main
ja	doc_973441205331_item	2949507	et	3	main
töökas	doc_973441205331_item	2949508	et	4	main
ning	doc_973441205331_item	2949509	et	3	main
korralik	doc_973441205331_item	2949510	et	3	main
et	doc_973441205331_item	2949511	et	3	main
olla	doc_973441205331_item	2949512	et	3	main
eeskujuks	doc_973441205331_item	2949513	et	3	main
oma	doc_973441205331_item	2949514	et	4	main
juht	doc_973441205331_item	2949516	et	3	main
peab	doc_973441205331_item	2949517	et	4	main
alluvatele	doc_973441205331_item	2949515	et	4	main
oskama	doc_973441205331_item	2949518	et	3	main
ennast	doc_973441205331_item	2949519	et	4	main
valitseda	doc_973441205331_item	2949520	et	3	main
kes	doc_973441205331_item	2949522	et	4	main
valitseda	doc_973441205331_item	2949527	et	3	main
vastus	doc_973441205332_item	2949532	et	3	main
meelsamini	doc_973441205332_item	2949540	et	3	main
ajal	doc_973441205332_item	2949551	et	4	main
lugeda	doc_973441205332_item	2949552	et	3	main
ajalehti	doc_973441205332_item	2949553	et	4	main
ja	doc_973441205332_item	2949554	et	3	main
ajakirju	doc_973441205332_item	2949555	et	4	main
vahendusel	doc_973441205332_item	2949561	et	4	main
ka	doc_973441205332_item	2949563	et	3	main
meeldivad	doc_973441205332_item	2949578	et	4	main
linnas	doc_973441205332_item	2949587	et	4	main
nimetaksin	doc_973441205332_item	2949588	et	3	main
mõned	doc_973441205332_item	2949589	et	3	main
neist	doc_973441205332_item	2949590	et	4	main
nagu	doc_973441205332_item	2949591	et	3	main
välismaa	doc_973441205332_item	2949598	et	4	main
kohalikud	doc_973441205332_item	2949609	et	3	main
millised	doc_973441205332_item	2949541	et	3	main
huvitavad	doc_973441205332_item	2949544	et	4	main
ja	doc_973441205332_item	2949545	et	3	main
ajalehti	doc_973441205332_item	2949566	et	4	main
siis	doc_973441205332_item	2949567	et	3	main
kui	doc_973441205332_item	2949568	et	3	main
ma	doc_973441205332_item	2949569	et	3	main
kõige	doc_973441205332_item	2949576	et	4	main
ajalehed	doc_973441205332_item	2949581	et	3	main
antakse	doc_973441205332_item	2949583	et	3	main
narvskaja	doc_973441205332_item	2949595	et	4	main
narva	doc_973441205332_item	2949597	et	4	main
ajakirjadest	doc_973441205332_item	2949599	et	3	main
kõige	doc_973441205332_item	2949602	et	4	main
mulle	doc_973441205332_item	2949607	et	4	main
et	doc_973441205332_item	2949612	et	3	main
peale	doc_973441205332_item	2949615	et	4	main
uudiste	doc_973441205332_item	2949617	et	3	main
ka	doc_973441205332_item	2949618	et	3	main
palju	doc_973441205332_item	2949619	et	4	main
välissündmustest	doc_973441205332_item	2949620	et	4	main
ajalehed	doc_973441205332_item	2949610	et	3	main
ma	doc_973441205332_item	2949622	et	3	main
sellega	doc_973441205332_item	2949625	et	3	main
on	doc_973441205332_item	2949633	et	4	main
aktuaalne	doc_973441205332_item	2949634	et	3	main
plaanid	doc_973441205332_item	2949643	et	4	main
meie	doc_973441205332_item	2949646	et	4	main
on	doc_973441205332_item	2949653	et	4	main
huvitavad	doc_973441205332_item	2949659	et	4	main
nende	doc_973441205332_item	2949669	et	4	main
ma	doc_973441205332_item	2949673	et	3	main
kus	doc_973441205332_item	2949676	et	3	main
rõivastuses	doc_973441205332_item	2949708	et	4	main
eelpoolnimetatud	doc_973441205332_item	2949714	et	3	main
on	doc_973441205332_item	2949718	et	4	main
minule	doc_973441205332_item	2949719	et	3	main
olu	doc_973441205332_item	2949728	et	4	main
mis	doc_973441205334_item	2949927	et	4	main
on	doc_973441205334_item	2949928	et	4	main
siis	doc_973441205334_item	2949935	et	3	main
aru	doc_973441205334_item	2949956	et	4	main
ta	doc_973441205334_item	2949967	et	4	main
arvuti	doc_973441205334_item	2949988	et	4	main
kuid	doc_973441205334_item	2949990	et	4	main
toimub	doc_973441205332_item	2949627	et	3	main
ajalehtede	doc_973441205332_item	2949637	et	4	main
kaudu	doc_973441205332_item	2949638	et	3	main
ma	doc_973441205332_item	2949639	et	3	main
ning	doc_973441205332_item	2949649	et	3	main
täidetud	doc_973441205332_item	2949654	et	4	main
sellised	doc_973441205332_item	2949660	et	4	main
teemad	doc_973441205332_item	2949661	et	3	main
isiklikku	doc_973441205332_item	2949666	et	4	main
juttu	doc_973441205332_item	2949678	et	4	main
jalgpallist	doc_973441205332_item	2949679	et	4	main
võrkpallist	doc_973441205332_item	2949680	et	4	main
ning	doc_973441205332_item	2949681	et	3	main
ujumisest	doc_973441205332_item	2949682	et	4	main
kui	doc_973441205332_item	2949683	et	3	main
tehes	doc_973441205332_item	2949684	et	3	main
või	doc_973441205332_item	2949686	et	4	main
lugedes	doc_973441205332_item	2949687	et	3	main
sporti	doc_973441205332_item	2949685	et	4	main
midagi	doc_973441205332_item	2949688	et	4	main
spordist	doc_973441205332_item	2949689	et	3	main
ma	doc_973441205332_item	2949690	et	3	main
saan	doc_973441205332_item	2949691	et	4	main
alati	doc_973441205332_item	2949692	et	4	main
positiivse	doc_973441205332_item	2949693	et	3	main
emotsiooni	doc_973441205332_item	2949694	et	4	main
ja	doc_973441205332_item	2949695	et	3	main
hea	doc_973441205332_item	2949696	et	4	main
tuju	doc_973441205332_item	2949697	et	4	main
nimetatud	doc_973441205332_item	2949698	et	4	main
ajakirjadest	doc_973441205332_item	2949699	et	3	main
ma	doc_973441205332_item	2949700	et	3	main
loen	doc_973441205332_item	2949701	et	3	main
teemasid	doc_973441205332_item	2949702	et	3	main
kus	doc_973441205332_item	2949703	et	3	main
on	doc_973441205332_item	2949704	et	4	main
seotud	doc_973441205332_item	2949705	et	4	main
uute	doc_973441205332_item	2949706	et	3	main
moetrendidega	doc_973441205332_item	2949707	et	4	main
sellega	doc_973441205332_item	2949631	et	3	main
mis	doc_973441205332_item	2949632	et	4	main
saan	doc_973441205332_item	2949640	et	4	main
teada	doc_973441205332_item	2949641	et	3	main
millised	doc_973441205332_item	2949642	et	3	main
linnavalitsusel	doc_973441205332_item	2949645	et	4	main
lubadused	doc_973441205332_item	2949652	et	3	main
või	doc_973441205332_item	2949655	et	4	main
mind	doc_973441205332_item	2949658	et	4	main
spordisündmusi	doc_973441205332_item	2949664	et	3	main
muid	doc_973441205332_item	2949670	et	4	main
eriti	doc_973441205332_item	2949672	et	3	main
teemasid	doc_973441205332_item	2949675	et	3	main
elu	doc_973441205332_item	2949710	et	4	main
igatahes	doc_973441205332_item	2949712	et	3	main
ja	doc_973441205332_item	2949716	et	3	main
ajakirjad	doc_973441205332_item	2949717	et	3	main
stiilis	doc_973441205332_item	2949711	et	4	main
kõike	doc_973441205332_item	2949713	et	4	main
ajalehed	doc_973441205332_item	2949715	et	3	main
elu	doc_973441205332_item	2949727	et	4	main
huvitavad	doc_973441205332_item	2949721	et	4	main
inimene	doc_973441205334_item	2949937	et	3	main
vaba	doc_973441205334_item	2949940	et	4	main
ajaga	doc_973441205334_item	2949941	et	3	main
pühendab	doc_973441205334_item	2949942	et	3	main
teinekord	doc_973441205334_item	2949944	et	3	main
ta	doc_973441205334_item	2949958	et	4	main
inimene	doc_973441205334_item	2949961	et	3	main
perekonna	doc_973441205334_item	2949964	et	4	main
taga	doc_973441205334_item	2949989	et	4	main
mina	doc_973441205334_item	2949991	et	4	main
väidan	doc_973441205336_item	2950115	et	3	main
on	doc_973441205336_item	2950118	et	4	main
liiga	doc_973441205336_item	2950119	et	4	main
ja	doc_973441205336_item	2950122	et	3	main
televaatajat	doc_973441205336_item	2950132	et	3	main
segeva	doc_973441205336_item	2950140	et	4	main
teguri	doc_973441205336_item	2950141	et	3	main
negatiivsed	doc_973441205336_item	2950147	et	3	main
palju	doc_973441205336_item	2950155	et	4	main
oma	doc_973441205336_item	2950164	et	4	main
järjekindluse	doc_973441205336_item	2950166	et	4	main
ja	doc_973441205336_item	2950167	et	3	main
banaalsusega	doc_973441205336_item	2950168	et	4	main
ja	doc_973441205336_item	2950171	et	3	main
näiteks	doc_973441205336_item	2950178	et	4	main
intiimtarbeesemeid	doc_973441205336_item	2950179	et	3	main
iga	doc_973441205336_item	2950183	et	4	main
prahti	doc_973441205336_item	2950185	et	4	main
essee	doc_973441205334_item	2949908	et	4	main
arvutisõltuvus	doc_973441205334_item	2949909	et	4	main
kaasajal	doc_973441205334_item	2949910	et	4	main
kõik	doc_973441205334_item	2949911	et	4	main
teavad	doc_973441205334_item	2949912	et	3	main
mis	doc_973441205334_item	2949913	et	4	main
on	doc_973441205334_item	2949914	et	4	main
arvuti	doc_973441205334_item	2949915	et	4	main
ja	doc_973441205334_item	2949916	et	3	main
enamus	doc_973441205334_item	2949917	et	4	main
kasutab	doc_973441205334_item	2949919	et	3	main
arvutit	doc_973441205334_item	2949920	et	3	main
inimesi	doc_973441205334_item	2949918	et	4	main
iga	doc_973441205334_item	2949921	et	4	main
kuid	doc_973441205334_item	2949923	et	4	main
ei	doc_973441205334_item	2949925	et	4	main
tea	doc_973441205334_item	2949926	et	4	main
et	doc_973441205334_item	2949932	et	3	main
arvutisõltuvus	doc_973441205334_item	2949933	et	4	main
tekib	doc_973441205334_item	2949934	et	3	main
päev	doc_973441205334_item	2949922	et	3	main
igaüks	doc_973441205334_item	2949924	et	3	main
arvutisõltuvus	doc_973441205334_item	2949929	et	4	main
mina	doc_973441205334_item	2949930	et	4	main
arvan	doc_973441205334_item	2949931	et	3	main
kõik	doc_973441205334_item	2949938	et	4	main
et	doc_973441205334_item	2949957	et	3	main
unustab	doc_973441205334_item	2949962	et	3	main
tuttavad	doc_973441205334_item	2949966	et	4	main
ei	doc_973441205334_item	2949992	et	4	main
ole	doc_973441205334_item	2949993	et	4	main
essee	doc_973441205336_item	2950113	et	4	main
televisioonis	doc_973441205336_item	2950117	et	4	main
palju	doc_973441205336_item	2950120	et	4	main
kui	doc_973441205334_item	2949936	et	3	main
oma	doc_973441205334_item	2949939	et	4	main
arvutile	doc_973441205334_item	2949943	et	4	main
isegi	doc_973441205334_item	2949945	et	4	main
jätab	doc_973441205334_item	2949946	et	3	main
lohakile	doc_973441205334_item	2949950	et	3	main
inimine	doc_973441205334_item	2949952	et	4	main
ei	doc_973441205334_item	2949954	et	4	main
saa	doc_973441205334_item	2949955	et	4	main
oma	doc_973441205334_item	2949963	et	4	main
sõbrad	doc_973441205334_item	2949965	et	3	main
pidevalt	doc_973441205334_item	2949969	et	4	main
elektrooniliselt	doc_973441205334_item	2949970	et	4	main
uudiseid	doc_973441205334_item	2949971	et	3	main
reklaami	doc_973441205334_item	2949972	et	4	main
tegeleb	doc_973441205334_item	2949973	et	3	main
arvutimängudega	doc_973441205334_item	2949974	et	3	main
suhtleb	doc_973441205334_item	2949975	et	3	main
teiste	doc_973441205334_item	2949976	et	4	main
inimestega	doc_973441205334_item	2949977	et	3	main
ja	doc_973441205334_item	2949978	et	3	main
unustab	doc_973441205334_item	2949979	et	3	main
soogi	doc_973441205334_item	2949980	et	4	main
ja	doc_973441205334_item	2949981	et	3	main
isegi	doc_973441205334_item	2949982	et	4	main
une	doc_973441205334_item	2949983	et	3	main
mulle	doc_973441205334_item	2949984	et	4	main
ka	doc_973441205334_item	2949985	et	3	main
meeldib	doc_973441205334_item	2949986	et	3	main
istuda	doc_973441205334_item	2949987	et	3	main
oma	doc_973441205334_item	2949947	et	4	main
pakilised	doc_973441205334_item	2949948	et	4	main
tööasjad	doc_973441205334_item	2949949	et	3	main
mõnikord	doc_973441205334_item	2949951	et	3	main
ise	doc_973441205334_item	2949953	et	4	main
on	doc_973441205334_item	2949959	et	4	main
arvutisõltlane	doc_973441205334_item	2949960	et	3	main
loeb	doc_973441205334_item	2949968	et	3	main
et	doc_973441205336_item	2950116	et	3	main
segab	doc_973441205336_item	2950131	et	3	main
telesaatesse	doc_973441205336_item	2950134	et	4	main
ning	doc_973441205336_item	2950143	et	3	main
tulevad	doc_973441205336_item	2950145	et	4	main
mis	doc_973441205336_item	2950161	et	4	main
tüütava	doc_973441205336_item	2950165	et	4	main
mida	doc_973441205336_item	2950173	et	4	main
poleks	doc_973441205336_item	2950175	et	3	main
reklaamida	doc_973441205336_item	2950177	et	4	main
teisest	doc_973441205336_item	2950196	et	4	main
on	doc_973441205336_item	2950200	et	4	main
omal	doc_973441205336_item	2950201	et	3	main
on	doc_973441205336_item	2950204	et	4	main
informeerib	doc_973441205336_item	2950208	et	3	main
ja	doc_973441205336_item	2950209	et	3	main
või	doc_973441205336_item	2950212	et	4	main
asjadest	doc_973441205336_item	2950231	et	3	main
see	doc_973441205336_item	2950235	et	3	main
teenuste	doc_973441205336_item	2950241	et	3	main
reklaamile	doc_973441205336_item	2950265	et	3	main
muid	doc_973441205336_item	2950272	et	4	main
peale	doc_973441205336_item	2950274	et	4	main
telekanalites	doc_973441205336_item	2950281	et	3	main
reklaam	doc_973441205336_item	2950283	et	3	main
doteerib	doc_973441205336_item	2950293	et	4	main
rahaliselt	doc_973441205336_item	2950294	et	4	main
et	doc_973441205336_item	2950298	et	3	main
televisioonile	doc_973441205336_item	2950313	et	4	main
tellijale	doc_973441205336_item	2950316	et	4	main
kõige	doc_973441205337_item	2950331	et	4	main
rohkem	doc_973441205337_item	2950332	et	4	main
mulle	doc_973441205337_item	2950333	et	4	main
meeldib	doc_973441205337_item	2950334	et	3	main
samuti	doc_973441205337_item	2950343	et	3	main
trumm	doc_973441205337_item	2950346	et	3	main
minu	doc_973441205337_item	2950349	et	3	main
muusikariistaks	doc_973441205337_item	2950351	et	4	main
eriti	doc_973441205337_item	2950357	et	3	main
meeldib	doc_973441205337_item	2950359	et	3	main
kontrabassi	doc_973441205337_item	2950361	et	4	main
džassis	doc_973441205337_item	2950362	et	2	main
kõige	doc_973441205337_item	2950369	et	4	main
kontakti	doc_973441205337_item	2950379	et	4	main
veel	doc_973441205334_item	2949994	et	4	main
arvutisõltlane	doc_973441205334_item	2949995	et	3	main
reklaam	doc_973441205336_item	2950130	et	3	main
suhtes	doc_973441205336_item	2950142	et	4	main
emotsioonid	doc_973441205336_item	2950148	et	3	main
selle	doc_973441205336_item	2950149	et	4	main
suhtes	doc_973441205336_item	2950151	et	4	main
kus	doc_973441205336_item	2950152	et	3	main
on	doc_973441205336_item	2950153	et	4	main
segavad	doc_973441205336_item	2950158	et	4	main
need	doc_973441205336_item	2950159	et	3	main
reklaamiklipid	doc_973441205336_item	2950160	et	3	main
peale	doc_973441205336_item	2950163	et	4	main
ja	doc_973441205336_item	2950180	et	3	main
sellist	doc_973441205336_item	2950182	et	4	main
päevast	doc_973441205336_item	2950184	et	4	main
iga	doc_973441205336_item	2950187	et	4	main
inimene	doc_973441205336_item	2950188	et	3	main
teab	doc_973441205336_item	2950189	et	3	main
niisama	doc_973441205336_item	2950192	et	3	main
see	doc_973441205336_item	2950203	et	3	main
selline	doc_973441205336_item	2950205	et	4	main
mis	doc_973441205336_item	2950207	et	4	main
hea	doc_973441205336_item	2950218	et	4	main
reklaam	doc_973441205336_item	2950219	et	3	main
teavitab	doc_973441205336_item	2950220	et	4	main
väide	doc_973441205336_item	2950114	et	4	main
reklaami	doc_973441205336_item	2950121	et	4	main
see	doc_973441205336_item	2950123	et	3	main
saadete	doc_973441205336_item	2950125	et	3	main
filmide	doc_973441205336_item	2950127	et	3	main
vaatamist	doc_973441205336_item	2950128	et	4	main
üleliigne	doc_973441205336_item	2950129	et	3	main
vaatajal	doc_973441205336_item	2950144	et	4	main
liiga	doc_973441205336_item	2950154	et	4	main
sunnivad	doc_973441205336_item	2950162	et	3	main
nagu	doc_973441205336_item	2950174	et	3	main
vajagi	doc_973441205336_item	2950176	et	4	main
muud	doc_973441205336_item	2950181	et	4	main
ostab	doc_973441205336_item	2950191	et	3	main
küljest	doc_973441205336_item	2950197	et	4	main
teinekord	doc_973441205336_item	2950198	et	3	main
reklaam	doc_973441205336_item	2950206	et	3	main
huvitavalt	doc_973441205336_item	2950214	et	4	main
ja	doc_973441205336_item	2950225	et	3	main
reklaami	doc_973441205336_item	2950232	et	4	main
tellib	doc_973441205336_item	2950234	et	3	main
kellel	doc_973441205336_item	2950236	et	4	main
on	doc_973441205336_item	2950237	et	4	main
kaupade	doc_973441205336_item	2950240	et	3	main
käivet	doc_973441205336_item	2950246	et	3	main
eksisteerivad	doc_973441205336_item	2950266	et	4	main
nende	doc_973441205336_item	2950275	et	4	main
mis	doc_973441205336_item	2950276	et	4	main
saadakse	doc_973441205336_item	2950277	et	3	main
kas	doc_973441205336_item	2950282	et	3	main
on	doc_973441205336_item	2950287	et	4	main
see	doc_973441205336_item	2950288	et	3	main
piiratud	doc_973441205336_item	2950289	et	4	main
mahus	doc_973441205336_item	2950290	et	3	main
sest	doc_973441205336_item	2950291	et	4	main
ma	doc_973441205336_item	2950296	et	3	main
arvan	doc_973441205336_item	2950297	et	3	main
kuid	doc_973441205336_item	2950304	et	4	main
mõistlikul	doc_973441205336_item	2950305	et	3	main
ja	doc_973441205336_item	2950314	et	3	main
muusikat	doc_973441205337_item	2950320	et	3	main
oma	doc_973441205337_item	2950323	et	4	main
lemmik	doc_973441205337_item	2950338	et	3	main
manson	doc_973441205337_item	2950342	et	4	main
ja	doc_973441205337_item	2950347	et	3	main
lemmik	doc_973441205337_item	2950350	et	3	main
bass	doc_973441205337_item	2950353	et	3	main
kitarre	doc_973441205337_item	2950354	et	3	main
kontrabass	doc_973441205337_item	2950356	et	3	main
ise	doc_973441205337_item	2950363	et	4	main
mina	doc_973441205337_item	2950364	et	4	main
ka	doc_973441205337_item	2950365	et	3	main
loota	doc_973441205339_item	2950533	et	4	main
minule	doc_973441205339_item	2950534	et	3	main
ja	doc_973441205339_item	2950535	et	3	main
minu	doc_973441205339_item	2950536	et	3	main
eakaaslastele	doc_973441205339_item	2950537	et	4	main
niisugune	doc_973441205339_item	2950541	et	3	main
segab	doc_973441205336_item	2950124	et	3	main
või	doc_973441205336_item	2950126	et	4	main
süvenemaks	doc_973441205336_item	2950133	et	3	main
vaatajal	doc_973441205336_item	2950135	et	4	main
tekib	doc_973441205336_item	2950136	et	3	main
teatud	doc_973441205336_item	2950137	et	4	main
ärritus	doc_973441205336_item	2950138	et	4	main
selle	doc_973441205336_item	2950139	et	4	main
esile	doc_973441205336_item	2950146	et	3	main
telekanali	doc_973441205336_item	2950150	et	4	main
ärireklaami	doc_973441205336_item	2950156	et	4	main
eriti	doc_973441205336_item	2950157	et	3	main
teatud	doc_973441205336_item	2950169	et	4	main
kaupu	doc_973441205336_item	2950170	et	3	main
tarbeesemeid	doc_973441205336_item	2950172	et	3	main
mida	doc_973441205336_item	2950186	et	4	main
ja	doc_973441205336_item	2950190	et	3	main
ilma	doc_973441205336_item	2950193	et	4	main
reklaamita	doc_973441205336_item	2950194	et	4	main
kuid	doc_973441205336_item	2950195	et	4	main
vaatajat	doc_973441205336_item	2950211	et	4	main
on	doc_973441205336_item	2950213	et	4	main
ja	doc_973441205336_item	2950215	et	3	main
andekalt	doc_973441205336_item	2950216	et	4	main
tehtud	doc_973441205336_item	2950217	et	4	main
vaatajat	doc_973441205336_item	2950221	et	4	main
eelolevatest	doc_973441205336_item	2950223	et	3	main
spordi-	doc_973441205336_item	2950224	et	4	main
kunstisündmustest	doc_973441205336_item	2950226	et	4	main
inimestele	doc_973441205336_item	2950229	et	3	main
vaja	doc_973441205336_item	2950238	et	4	main
müügi	doc_973441205336_item	2950244	et	4	main
sest	doc_973441205336_item	2950247	et	4	main
loodud	doc_973441205336_item	2950249	et	4	main
neil	doc_973441205336_item	2950270	et	4	main
pole	doc_973441205336_item	2950271	et	3	main
tellijatelt	doc_973441205336_item	2950279	et	4	main
üldse	doc_973441205336_item	2950285	et	3	main
riik	doc_973441205336_item	2950295	et	3	main
reklaam	doc_973441205336_item	2950299	et	3	main
olla	doc_973441205336_item	2950302	et	3	main
kuulate	doc_973441205337_item	2950321	et	3	main
rock-muusikat	doc_973441205337_item	2950336	et	3	main
laulja	doc_973441205337_item	2950339	et	4	main
marilyn	doc_973441205337_item	2950341	et	4	main
mulle	doc_973441205337_item	2950344	et	4	main
kuulata	doc_973441205337_item	2950360	et	4	main
improviserivad	doc_973441205337_item	2950375	et	4	main
ja	doc_973441205337_item	2950376	et	3	main
leiavad	doc_973441205337_item	2950377	et	3	main
muusikalise	doc_973441205337_item	2950378	et	4	main
kuulajaskonnaga	doc_973441205337_item	2950380	et	4	main
reklaam	doc_973441205336_item	2950199	et	3	main
kohal	doc_973441205336_item	2950202	et	4	main
harib	doc_973441205336_item	2950210	et	3	main
näiteks	doc_973441205336_item	2950222	et	4	main
ning	doc_973441205336_item	2950227	et	3	main
ja	doc_973441205336_item	2950242	et	3	main
artiklite	doc_973441205336_item	2950245	et	3	main
oskuslikult	doc_973441205336_item	2950248	et	4	main
reklaam	doc_973441205336_item	2950250	et	3	main
suurendab	doc_973441205336_item	2950251	et	3	main
läbimüüki	doc_973441205336_item	2950252	et	4	main
ja	doc_973441205336_item	2950253	et	3	main
toob	doc_973441205336_item	2950254	et	3	main
sest	doc_973441205336_item	2950269	et	4	main
sissetulekuid	doc_973441205336_item	2950273	et	4	main
riiklikes	doc_973441205336_item	2950280	et	3	main
või	doc_973441205336_item	2950286	et	4	main
võiks	doc_973441205336_item	2950300	et	4	main
hulgal	doc_973441205336_item	2950306	et	3	main
et	doc_973441205336_item	2950307	et	3	main
oleks	doc_973441205336_item	2950309	et	3	main
kasulik	doc_973441205336_item	2950310	et	3	main
televaatajal	doc_973441205336_item	2950311	et	3	main
minu	doc_973441205337_item	2950337	et	3	main
meeldib	doc_973441205337_item	2950345	et	3	main
bass	doc_973441205337_item	2950348	et	3	main
on	doc_973441205337_item	2950352	et	4	main
ja	doc_973441205337_item	2950355	et	3	main
laulan	doc_973441205337_item	2950366	et	3	main
žanris	doc_973441205337_item	2950368	et	2	main
on	doc_973441205337_item	2950371	et	4	main
esitajad	doc_973441205337_item	2950374	et	4	main
teistest	doc_973441205336_item	2950228	et	4	main
hädavajalikest	doc_973441205336_item	2950230	et	3	main
tavaliselt	doc_973441205336_item	2950233	et	4	main
suurendada	doc_973441205336_item	2950239	et	3	main
teiste	doc_973441205336_item	2950243	et	4	main
reklammi	doc_973441205336_item	2950255	et	4	main
tellijale	doc_973441205336_item	2950256	et	4	main
sisse	doc_973441205336_item	2950257	et	4	main
suurt	doc_973441205336_item	2950258	et	3	main
tulu	doc_973441205336_item	2950259	et	4	main
kolmandaks	doc_973441205336_item	2950260	et	4	main
võib	doc_973441205336_item	2950261	et	3	main
öelda	doc_973441205336_item	2950262	et	4	main
et	doc_973441205336_item	2950263	et	3	main
tänu	doc_973441205336_item	2950264	et	4	main
kõik	doc_973441205336_item	2950267	et	4	main
eratelekanalid	doc_973441205336_item	2950268	et	3	main
reklaami	doc_973441205336_item	2950278	et	4	main
puudub	doc_973441205336_item	2950284	et	3	main
neid	doc_973441205336_item	2950292	et	4	main
siiski	doc_973441205336_item	2950301	et	4	main
teleprogrammides	doc_973441205336_item	2950303	et	3	main
see	doc_973441205336_item	2950308	et	3	main
ka	doc_973441205336_item	2950312	et	3	main
telereklaami	doc_973441205336_item	2950315	et	4	main
vastus	doc_973441205337_item	2950317	et	3	main
küsimusele	doc_973441205337_item	2950318	et	4	main
millist	doc_973441205337_item	2950319	et	3	main
tavaliselt	doc_973441205337_item	2950322	et	4	main
vabal	doc_973441205337_item	2950324	et	3	main
ajal	doc_973441205337_item	2950325	et	4	main
ma	doc_973441205337_item	2950326	et	3	main
kuulan	doc_973441205337_item	2950327	et	3	main
pidevalt	doc_973441205337_item	2950328	et	4	main
mingit	doc_973441205337_item	2950329	et	3	main
muusikat	doc_973441205337_item	2950330	et	3	main
kuulata	doc_973441205337_item	2950335	et	4	main
on	doc_973441205337_item	2950340	et	4	main
mulle	doc_973441205337_item	2950358	et	4	main
selles	doc_973441205337_item	2950367	et	4	main
huvitavam	doc_973441205337_item	2950370	et	4	main
siis	doc_973441205337_item	2950372	et	3	main
kui	doc_973441205337_item	2950373	et	3	main
auditooriumiga	doc_973441205337_item	2950381	et	3	main
elu	doc_973441205339_item	2950539	et	4	main
on	doc_973441205339_item	2950545	et	4	main
mu	doc_973441205339_item	2950550	et	3	main
noored	doc_973441205339_item	2950555	et	3	main
et	doc_973441205339_item	2950556	et	3	main
tänapäevasest	doc_973441205339_item	2950595	et	4	main
mina	doc_973441205339_item	2950598	et	4	main
häletada	doc_973441205339_item	2950602	et	4	main
veel	doc_973441205339_item	2950606	et	4	main
täisealine	doc_973441205339_item	2950607	et	4	main
aga	doc_973441205339_item	2950608	et	3	main
juba	doc_973441205339_item	2950609	et	3	main
arvamus	doc_973441205339_item	2950614	et	3	main
ma	doc_973441205339_item	2950616	et	3	main
essee	doc_973441205339_item	2950529	et	4	main
eestimaa	doc_973441205339_item	2950531	et	4	main
on	doc_973441205339_item	2950540	et	4	main
kõik	doc_973441205339_item	2950543	et	4	main
aga	doc_973441205339_item	2950562	et	3	main
muidugi	doc_973441205339_item	2950563	et	4	main
seda	doc_973441205339_item	2950564	et	3	main
on	doc_973441205339_item	2950580	et	4	main
küsimus	doc_973441205339_item	2950583	et	4	main
loota	doc_973441205339_item	2950586	et	4	main
meiele	doc_973441205339_item	2950587	et	4	main
see	doc_973441205339_item	2950590	et	3	main
veel	doc_973441205339_item	2950599	et	4	main
ei	doc_973441205339_item	2950604	et	4	main
oma	doc_973441205339_item	2950613	et	4	main
moodustaksid	doc_973441205339_item	2950633	et	4	main
oma	doc_973441205339_item	2950634	et	4	main
arvamust	doc_973441205339_item	2950635	et	3	main
aga	doc_973441205339_item	2950636	et	3	main
kahjuks	doc_973441205339_item	2950637	et	4	main
kellele	doc_973441205339_item	2950643	et	4	main
võib	doc_973441205339_item	2950644	et	3	main
et	doc_973441205339_item	2950657	et	3	main
edukad	doc_973441205339_item	2950659	et	3	main
noorud	doc_973441205339_item	2950662	et	4	main
meie	doc_973441205339_item	2950673	et	4	main
ei	doc_973441205339_item	2950706	et	4	main
ole	doc_973441205339_item	2950707	et	4	main
neid	doc_973441205339_item	2950738	et	4	main
kellele	doc_973441205339_item	2950742	et	4	main
eestimaa	doc_973441205339_item	2950745	et	4	main
majanduse	doc_973441205339_item	2950750	et	4	main
olukord	doc_973441205339_item	2950751	et	3	main
põlvkond	doc_973441205339_item	2950761	et	3	main
tähendab	doc_973441205339_item	2950764	et	3	main
kahjuks	doc_973441205339_item	2950766	et	4	main
ei	doc_973441205339_item	2950768	et	4	main
kas	doc_973441205339_item	2950530	et	3	main
võib	doc_973441205339_item	2950532	et	3	main
inimestele	doc_973441205339_item	2950547	et	3	main
eakaaslased	doc_973441205339_item	2950551	et	3	main
on	doc_973441205339_item	2950552	et	4	main
liiga	doc_973441205339_item	2950554	et	4	main
eestimaa	doc_973441205339_item	2950559	et	4	main
päev	doc_973441205339_item	2950566	et	3	main
tore	doc_973441205339_item	2950569	et	3	main
võib	doc_973441205339_item	2950573	et	3	main
õigustama	doc_973441205339_item	2950575	et	3	main
aga	doc_973441205339_item	2950576	et	3	main
kui	doc_973441205339_item	2950577	et	3	main
mitte	doc_973441205339_item	2950578	et	3	main
fülosoofiline	doc_973441205339_item	2950582	et	4	main
kas	doc_973441205339_item	2950584	et	3	main
sõltub	doc_973441205339_item	2950591	et	3	main
saa	doc_973441205339_item	2950601	et	4	main
mul	doc_973441205339_item	2950611	et	3	main
ja	doc_973441205339_item	2950615	et	3	main
meie	doc_973441205339_item	2950622	et	4	main
mõjuda	doc_973441205339_item	2950645	et	3	main
hea	doc_973441205339_item	2950650	et	4	main
lõpetamist	doc_973441205339_item	2950668	et	4	main
see	doc_973441205339_item	2950669	et	3	main
on	doc_973441205339_item	2950670	et	4	main
nii	doc_973441205339_item	2950671	et	3	main
vähemad	doc_973441205339_item	2950677	et	4	main
ja	doc_973441205339_item	2950678	et	3	main
veel	doc_973441205339_item	2950708	et	4	main
kraadi	doc_973441205339_item	2950712	et	4	main
jäävad	doc_973441205339_item	2950716	et	4	main
sinna	doc_973441205339_item	2950717	et	3	main
ole	doc_973441205339_item	2950722	et	4	main
nii	doc_973441205339_item	2950723	et	3	main
ja	doc_973441205339_item	2950725	et	3	main
olla	doc_973441205339_item	2950727	et	3	main
need	doc_973441205339_item	2950728	et	3	main
ja	doc_973441205339_item	2950741	et	3	main
võib	doc_973441205339_item	2950744	et	3	main
on	doc_973441205339_item	2950752	et	4	main
ole	doc_973441205339_item	2950756	et	4	main
stabiilne	doc_973441205339_item	2950757	et	3	main
ja	doc_973441205339_item	2950758	et	3	main
meie	doc_973441205339_item	2950759	et	4	main
et	doc_973441205339_item	2950765	et	3	main
tänapäevane	doc_973441205339_item	2950538	et	4	main
et	doc_973441205339_item	2950542	et	3	main
noortele	doc_973441205339_item	2950546	et	3	main
ja	doc_973441205339_item	2950549	et	3	main
tänapäeva	doc_973441205339_item	2950560	et	4	main
elust	doc_973441205339_item	2950561	et	3	main
sõltub	doc_973441205339_item	2950567	et	3	main
põlvkond	doc_973441205339_item	2950572	et	3	main
väga	doc_973441205339_item	2950581	et	3	main
võib	doc_973441205339_item	2950585	et	3	main
või	doc_973441205339_item	2950588	et	4	main
paljudest	doc_973441205339_item	2950592	et	3	main
näiteks	doc_973441205339_item	2950594	et	4	main
poliitikast	doc_973441205339_item	2950596	et	4	main
kuigi	doc_973441205339_item	2950597	et	3	main
praegu	doc_973441205339_item	2950610	et	3	main
on	doc_973441205339_item	2950612	et	4	main
võin	doc_973441205339_item	2950617	et	3	main
korralikult	doc_973441205339_item	2950618	et	4	main
aru	doc_973441205339_item	2950619	et	4	main
saada	doc_973441205339_item	2950620	et	4	main
ainult	doc_973441205339_item	2950641	et	4	main
need	doc_973441205339_item	2950642	et	3	main
ei	doc_973441205339_item	2950647	et	4	main
see	doc_973441205339_item	2950656	et	3	main
paljud	doc_973441205339_item	2950658	et	3	main
sest	doc_973441205339_item	2950672	et	4	main
meie	doc_973441205339_item	2950704	et	4	main
riigis	doc_973441205339_item	2950705	et	3	main
võimalusi	doc_973441205339_item	2950709	et	3	main
teaduslikut	doc_973441205339_item	2950711	et	4	main
teenida	doc_973441205339_item	2950713	et	3	main
aga	doc_973441205339_item	2950714	et	3	main
siis	doc_973441205339_item	2950715	et	3	main
need	doc_973441205339_item	2950719	et	3	main
saa	doc_973441205339_item	2950731	et	4	main
või	doc_973441205339_item	2950732	et	4	main
on	doc_973441205339_item	2950739	et	4	main
loota	doc_973441205339_item	2950746	et	4	main
eesti	doc_973441205339_item	2950747	et	4	main
poliitiline	doc_973441205339_item	2950748	et	3	main
ja	doc_973441205339_item	2950749	et	3	main
sellepärast	doc_973441205339_item	2950754	et	3	main
ja	doc_973441205339_item	2950762	et	3	main
lootused	doc_973441205339_item	2950544	et	4	main
mina	doc_973441205339_item	2950548	et	4	main
veel	doc_973441205339_item	2950553	et	4	main
osa	doc_973441205339_item	2950557	et	4	main
võtta	doc_973441205339_item	2950558	et	3	main
homne	doc_973441205339_item	2950565	et	3	main
meiest	doc_973441205339_item	2950568	et	4	main
kui	doc_973441205339_item	2950570	et	3	main
meie	doc_973441205339_item	2950571	et	4	main
lootusi	doc_973441205339_item	2950574	et	4	main
see	doc_973441205339_item	2950579	et	3	main
mitte	doc_973441205339_item	2950589	et	3	main
teguritest	doc_973441205339_item	2950593	et	3	main
ei	doc_973441205339_item	2950600	et	4	main
sest	doc_973441205339_item	2950603	et	4	main
ole	doc_973441205339_item	2950605	et	4	main
mis	doc_973441205339_item	2950621	et	4	main
tore	doc_973441205339_item	2950628	et	3	main
kui	doc_973441205339_item	2950629	et	3	main
kõik	doc_973441205339_item	2950630	et	4	main
mu	doc_973441205339_item	2950631	et	3	main
eakaaslased	doc_973441205339_item	2950632	et	3	main
on	doc_973441205339_item	2950640	et	4	main
ole	doc_973441205339_item	2950648	et	4	main
muidugi	doc_973441205339_item	2950649	et	4	main
eestimaa	doc_973441205339_item	2950651	et	4	main
jaoks	doc_973441205339_item	2950652	et	4	main
eelistavad	doc_973441205339_item	2950663	et	4	main
välismaal	doc_973441205339_item	2950665	et	4	main
ülikooli	doc_973441205339_item	2950667	et	4	main
riigis	doc_973441205339_item	2950674	et	3	main
palgad	doc_973441205339_item	2950675	et	3	main
on	doc_973441205339_item	2950676	et	4	main
head	doc_973441205339_item	2950710	et	4	main
ainult	doc_973441205339_item	2950718	et	4	main
riigis	doc_973441205339_item	2950623	et	3	main
poliitikas	doc_973441205339_item	2950624	et	3	main
ja	doc_973441205339_item	2950625	et	3	main
majanduses	doc_973441205339_item	2950626	et	4	main
toimub	doc_973441205339_item	2950627	et	3	main
täna	doc_973441205339_item	2950638	et	4	main
nad	doc_973441205339_item	2950639	et	3	main
see	doc_973441205339_item	2950646	et	3	main
teiseks	doc_973441205339_item	2950653	et	4	main
mõtteks	doc_973441205339_item	2950654	et	3	main
on	doc_973441205339_item	2950655	et	4	main
ja	doc_973441205339_item	2950660	et	3	main
andekad	doc_973441205339_item	2950661	et	3	main
töötada	doc_973441205339_item	2950664	et	3	main
pärast	doc_973441205339_item	2950666	et	4	main
elutase	doc_973441205339_item	2950679	et	3	main
on	doc_973441205339_item	2950680	et	4	main
madalam	doc_973441205339_item	2950681	et	4	main
kui	doc_973441205339_item	2950682	et	3	main
lääne	doc_973441205339_item	2950683	et	4	main
europa	doc_973441205339_item	2950684	et	4	main
riikides	doc_973441205339_item	2950685	et	3	main
ja	doc_973441205339_item	2950686	et	3	main
kuidas	doc_973441205339_item	2950687	et	3	main
eestimaa	doc_973441205339_item	2950688	et	4	main
võib	doc_973441205339_item	2950689	et	3	main
loota	doc_973441205339_item	2950690	et	4	main
nendele	doc_973441205339_item	2950691	et	4	main
kes	doc_973441205339_item	2950692	et	4	main
pärast	doc_973441205339_item	2950693	et	4	main
sõitab	doc_973441205339_item	2950694	et	4	main
ära	doc_973441205339_item	2950695	et	4	main
minu	doc_973441205339_item	2950696	et	3	main
arvates	doc_973441205339_item	2950697	et	4	main
on	doc_973441205339_item	2950698	et	4	main
ka	doc_973441205339_item	2950699	et	3	main
parem	doc_973441205339_item	2950700	et	4	main
ära	doc_973441205339_item	2950701	et	4	main
sõita	doc_973441205339_item	2950702	et	3	main
sest	doc_973441205339_item	2950703	et	4	main
kes	doc_973441205339_item	2950720	et	4	main
ei	doc_973441205339_item	2950721	et	4	main
võib	doc_973441205339_item	2950726	et	3	main
kes	doc_973441205339_item	2950729	et	4	main
ei	doc_973441205339_item	2950730	et	4	main
ära	doc_973441205339_item	2950735	et	4	main
sõita	doc_973441205339_item	2950736	et	3	main
aga	doc_973441205339_item	2950737	et	3	main
siis	doc_973441205339_item	2950743	et	3	main
ebastabiilne	doc_973441205339_item	2950753	et	3	main
ei	doc_973441205339_item	2950755	et	4	main
see	doc_973441205339_item	2950763	et	3	main
andekad	doc_973441205339_item	2950724	et	3	main
ei	doc_973441205339_item	2950733	et	4	main
taha	doc_973441205339_item	2950734	et	4	main
vähe	doc_973441205339_item	2950740	et	3	main
moodustav	doc_973441205339_item	2950760	et	4	main
meile	doc_973441205339_item	2950767	et	4	main
saa	doc_973441205339_item	2950769	et	4	main
loota	doc_973441205339_item	2950770	et	4	main
essee	doc_973441205352_item	2952558	et	4	main
käivad	doc_973441205352_item	2952560	et	4	main
väga	doc_973441205352_item	2952579	et	3	main
tegevus	doc_973441205352_item	2952583	et	4	main
erinevaid	doc_973441205352_item	2952594	et	4	main
et	doc_973441205352_item	2952562	et	3	main
et	doc_973441205352_item	2952573	et	3	main
unustada	doc_973441205352_item	2952575	et	3	main
see	doc_973441205352_item	2952577	et	3	main
ja	doc_973441205352_item	2952581	et	3	main
kasulik	doc_973441205352_item	2952582	et	3	main
filmid	doc_973441205352_item	2952595	et	4	main
ja	doc_973441205352_item	2952623	et	3	main
palju	doc_973441205352_item	2952628	et	4	main
cola	doc_973441205352_item	2952653	et	4	main
film	doc_973441205352_item	2952662	et	3	main
ole	doc_973441205352_item	2952696	et	4	main
teha	doc_973441205352_item	2952707	et	3	main
kinno	doc_973441205352_item	2952720	et	3	main
nõus	doc_973441205353_item	2952732	et	4	main
sellega	doc_973441205353_item	2952733	et	3	main
et	doc_973441205353_item	2952734	et	3	main
positiivne	doc_973441205353_item	2952735	et	3	main
ellusuhtumine	doc_973441205353_item	2952736	et	3	main
edukuse	doc_973441205353_item	2952739	et	4	main
et	doc_973441205353_item	2952743	et	3	main
me	doc_973441205353_item	2952766	et	4	main
peame	doc_973441205353_item	2952767	et	4	main
hästi	doc_973441205353_item	2952768	et	3	main
et	doc_973441205353_item	2952770	et	3	main
kool	doc_973441205353_item	2952771	et	4	main
arvan	doc_973441205353_item	2952776	et	3	main
usu	doc_973441205353_item	2952781	et	4	main
inimesed	doc_973441205352_item	2952559	et	3	main
kinos	doc_973441205352_item	2952561	et	3	main
ma	doc_973441205352_item	2952565	et	3	main
väitega	doc_973441205352_item	2952568	et	3	main
käivad	doc_973441205352_item	2952571	et	4	main
kinos	doc_973441205352_item	2952572	et	3	main
igapäevamured	doc_973441205352_item	2952574	et	3	main
kino	doc_973441205352_item	2952576	et	4	main
on	doc_973441205352_item	2952578	et	4	main
see	doc_973441205352_item	2952584	et	3	main
on	doc_973441205352_item	2952585	et	4	main
mind	doc_973441205352_item	2952586	et	4	main
areneb	doc_973441205352_item	2952587	et	3	main
näiteks	doc_973441205352_item	2952596	et	4	main
puhata	doc_973441205352_item	2952622	et	4	main
lõõgastuda	doc_973441205352_item	2952624	et	3	main
vaba	doc_973441205352_item	2952634	et	4	main
aega	doc_973441205352_item	2952635	et	4	main
kuidas	doc_973441205352_item	2952636	et	3	main
ma	doc_973441205352_item	2952637	et	3	main
plazas	doc_973441205352_item	2952654	et	4	main
see	doc_973441205352_item	2952655	et	3	main
oli	doc_973441205352_item	2952656	et	3	main
väga	doc_973441205352_item	2952657	et	3	main
vaatasin	doc_973441205352_item	2952660	et	3	main
tõuseb	doc_973441205352_item	2952688	et	3	main
mul	doc_973441205352_item	2952694	et	3	main
ei	doc_973441205352_item	2952695	et	4	main
et	doc_973441205352_item	2952715	et	3	main
et	doc_973441205352_item	2952719	et	3	main
minna	doc_973441205352_item	2952721	et	3	main
inimeste	doc_973441205353_item	2952726	et	3	main
ma	doc_973441205353_item	2952729	et	3	main
olen	doc_973441205353_item	2952730	et	3	main
täielikult	doc_973441205353_item	2952731	et	4	main
ma	doc_973441205353_item	2952741	et	3	main
temal	doc_973441205353_item	2952748	et	3	main
kõik	doc_973441205353_item	2952750	et	4	main
siis	doc_973441205353_item	2952752	et	3	main
on	doc_973441205353_item	2952754	et	4	main
näiteks	doc_973441205353_item	2952765	et	4	main
lõpetada	doc_973441205353_item	2952773	et	3	main
ei	doc_973441205353_item	2952780	et	4	main
et	doc_973441205353_item	2952782	et	3	main
ellusuhtumine	doc_973441205353_item	2952792	et	3	main
et	doc_973441205353_item	2952796	et	3	main
igapäevamured	doc_973441205352_item	2952563	et	3	main
unustada	doc_973441205352_item	2952564	et	3	main
olen	doc_973441205352_item	2952566	et	3	main
tihti	doc_973441205352_item	2952588	et	3	main
ma	doc_973441205352_item	2952589	et	3	main
käin	doc_973441205352_item	2952590	et	3	main
kinos	doc_973441205352_item	2952591	et	3	main
mulle	doc_973441205352_item	2952592	et	4	main
nõus	doc_973441205352_item	2952567	et	4	main
et	doc_973441205352_item	2952569	et	3	main
inimesed	doc_973441205352_item	2952570	et	3	main
huvitav	doc_973441205352_item	2952580	et	4	main
meeldib	doc_973441205352_item	2952593	et	3	main
romaantiline	doc_973441205352_item	2952597	et	4	main
komöödia	doc_973441205352_item	2952599	et	4	main
ulmefilme	doc_973441205352_item	2952601	et	3	main
samuti	doc_973441205352_item	2952602	et	3	main
mulle	doc_973441205352_item	2952603	et	4	main
meeldib	doc_973441205352_item	2952604	et	3	main
tõsielufilme	doc_973441205352_item	2952605	et	3	main
kahjuks	doc_973441205352_item	2952606	et	4	main
neid	doc_973441205352_item	2952607	et	4	main
on	doc_973441205352_item	2952608	et	4	main
vähe	doc_973441205352_item	2952609	et	3	main
mulle	doc_973441205352_item	2952610	et	4	main
meeldib	doc_973441205352_item	2952611	et	3	main
keerulistest	doc_973441205352_item	2952612	et	4	main
probleemidest	doc_973441205352_item	2952613	et	3	main
iga	doc_973441205352_item	2952614	et	4	main
päev	doc_973441205352_item	2952615	et	3	main
ma	doc_973441205352_item	2952616	et	3	main
tulen	doc_973441205352_item	2952617	et	3	main
koolist	doc_973441205352_item	2952618	et	4	main
ja	doc_973441205352_item	2952619	et	3	main
ma	doc_973441205352_item	2952620	et	3	main
annavad	doc_973441205352_item	2952626	et	3	main
mulle	doc_973441205352_item	2952627	et	4	main
tööd	doc_973441205352_item	2952629	et	4	main
ja	doc_973441205352_item	2952630	et	3	main
mul	doc_973441205352_item	2952631	et	3	main
ei	doc_973441205352_item	2952632	et	4	main
saan	doc_973441205352_item	2952638	et	4	main
puhkama	doc_973441205352_item	2952639	et	3	main
ma	doc_973441205352_item	2952640	et	3	main
tean	doc_973441205352_item	2952641	et	3	main
et	doc_973441205352_item	2952642	et	3	main
mulle	doc_973441205352_item	2952643	et	4	main
aitab	doc_973441205352_item	2952644	et	3	main
kinno	doc_973441205352_item	2952645	et	3	main
kaks	doc_973441205352_item	2952646	et	3	main
nädalat	doc_973441205352_item	2952647	et	3	main
tagasi	doc_973441205352_item	2952648	et	3	main
ma	doc_973441205352_item	2952649	et	3	main
huvitav	doc_973441205352_item	2952658	et	4	main
ma	doc_973441205352_item	2952659	et	3	main
teisel	doc_973441205352_item	2952691	et	4	main
õpetajad	doc_973441205352_item	2952699	et	4	main
annavad	doc_973441205352_item	2952700	et	3	main
raske	doc_973441205352_item	2952701	et	4	main
ei	doc_973441205352_item	2952705	et	4	main
teda	doc_973441205352_item	2952708	et	4	main
et	doc_973441205352_item	2952709	et	3	main
ma	doc_973441205352_item	2952710	et	3	main
saan	doc_973441205352_item	2952711	et	4	main
kinno	doc_973441205352_item	2952712	et	3	main
filme	doc_973441205352_item	2952598	et	3	main
ja	doc_973441205352_item	2952600	et	3	main
õpetajad	doc_973441205352_item	2952625	et	4	main
ole	doc_973441205352_item	2952633	et	4	main
sõidasin	doc_973441205352_item	2952650	et	4	main
tallinnasse	doc_973441205352_item	2952651	et	3	main
roomaantiline	doc_973441205352_item	2952661	et	4	main
mul	doc_973441205352_item	2952687	et	3	main
meel	doc_973441205352_item	2952690	et	4	main
poolt	doc_973441205352_item	2952692	et	4	main
mõnikord	doc_973441205352_item	2952693	et	3	main
vabaa	doc_973441205352_item	2952697	et	4	main
kodutööd	doc_973441205352_item	2952702	et	4	main
ja	doc_973441205352_item	2952703	et	3	main
mul	doc_973441205352_item	2952716	et	3	main
on	doc_973441205353_item	2952725	et	4	main
inimene	doc_973441205353_item	2952745	et	3	main
tähtis	doc_973441205353_item	2952761	et	4	main
meie	doc_973441205353_item	2952763	et	4	main
elus	doc_973441205353_item	2952764	et	4	main
õppida	doc_973441205353_item	2952769	et	3	main
ma	doc_973441205353_item	2952775	et	3	main
kui	doc_973441205353_item	2952778	et	3	main
edukalt	doc_973441205353_item	2952786	et	4	main
lõpetada	doc_973441205353_item	2952787	et	3	main
siis	doc_973441205353_item	2952788	et	3	main
tal	doc_973441205353_item	2952789	et	3	main
on	doc_973441205353_item	2952790	et	4	main
inimene	doc_973441205353_item	2952798	et	3	main
optimist	doc_973441205353_item	2952827	et	3	main
optimistil	doc_973441205353_item	2952828	et	3	main
on	doc_973441205353_item	2952829	et	4	main
ta	doc_973441205353_item	2952833	et	4	main
meeldib	doc_973441205353_item	2952838	et	3	main
niisuguste	doc_973441205353_item	2952840	et	3	main
et	doc_973441205353_item	2952844	et	3	main
meie	doc_973441205353_item	2952845	et	4	main
alati	doc_973441205353_item	2952858	et	4	main
vaja	doc_973441205353_item	2952866	et	4	main
kõigepealt	doc_973441205353_item	2952867	et	3	main
inimesel	doc_973441205353_item	2952875	et	3	main
ellusuhtumine	doc_973441205353_item	2952878	et	3	main
niisugune	doc_973441205353_item	2952880	et	3	main
usuge	doc_973441205353_item	2952917	et	4	main
ja	doc_973441205353_item	2952918	et	3	main
on	doc_973441205354_item	2952933	et	4	main
mitmekesine	doc_973441205354_item	2952934	et	4	main
igal	doc_973441205354_item	2952935	et	3	main
inimestel	doc_973441205354_item	2952936	et	3	main
komöödia	doc_973441205354_item	2952943	et	4	main
muidugi	doc_973441205354_item	2952948	et	4	main
teie	doc_973441205354_item	2952949	et	4	main
lemmik	doc_973441205354_item	2952950	et	3	main
kino	doc_973441205354_item	2952951	et	4	main
aitab	doc_973441205354_item	2952952	et	3	main
igapäevamured	doc_973441205354_item	2952953	et	3	main
iga	doc_973441205354_item	2952963	et	4	main
oma	doc_973441205354_item	2952967	et	4	main
hea	doc_973441205354_item	2952970	et	4	main
kino	doc_973441205354_item	2952971	et	4	main
aitab	doc_973441205354_item	2952977	et	3	main
inimestele	doc_973441205354_item	2952978	et	3	main
mõtelda	doc_973441205354_item	2952979	et	4	main
ma	doc_973441205354_item	2952980	et	3	main
mõtlen	doc_973441205354_item	2952981	et	3	main
et	doc_973441205354_item	2952982	et	3	main
huvitav	doc_973441205354_item	2952983	et	4	main
kino	doc_973441205354_item	2952986	et	4	main
tahan	doc_973441205352_item	2952621	et	3	main
coca	doc_973441205352_item	2952652	et	4	main
ma	doc_973441205352_item	2952663	et	3	main
tean	doc_973441205352_item	2952664	et	3	main
et	doc_973441205352_item	2952665	et	3	main
ma	doc_973441205352_item	2952666	et	3	main
saan	doc_973441205352_item	2952667	et	4	main
igapäevamured	doc_973441205352_item	2952668	et	3	main
unustama	doc_973441205352_item	2952669	et	3	main
see	doc_973441205352_item	2952670	et	3	main
aitab	doc_973441205352_item	2952672	et	3	main
ühelt	doc_973441205352_item	2952673	et	3	main
on	doc_973441205352_item	2952671	et	4	main
poolt	doc_973441205352_item	2952674	et	4	main
kinno	doc_973441205352_item	2952675	et	3	main
on	doc_973441205352_item	2952676	et	4	main
mind	doc_973441205352_item	2952677	et	4	main
lõõgastuda	doc_973441205352_item	2952678	et	3	main
kui	doc_973441205352_item	2952679	et	3	main
ma	doc_973441205352_item	2952680	et	3	main
käin	doc_973441205352_item	2952681	et	3	main
kinos	doc_973441205352_item	2952682	et	3	main
mul	doc_973441205352_item	2952683	et	3	main
väheneb	doc_973441205352_item	2952684	et	3	main
väsimus	doc_973441205352_item	2952685	et	4	main
ja	doc_973441205352_item	2952686	et	3	main
romaantiline	doc_973441205352_item	2952689	et	4	main
aja	doc_973441205352_item	2952698	et	4	main
ma	doc_973441205352_item	2952704	et	3	main
saa	doc_973441205352_item	2952706	et	4	main
hakkab	doc_973441205352_item	2952717	et	3	main
essee	doc_973441205353_item	2952722	et	4	main
inimestele	doc_973441205353_item	2952738	et	3	main
põhjuseks	doc_973441205353_item	2952740	et	3	main
kui	doc_973441205353_item	2952744	et	3	main
et	doc_973441205353_item	2952747	et	3	main
kõik	doc_973441205353_item	2952755	et	4	main
korras	doc_973441205353_item	2952756	et	4	main
mõte	doc_973441205353_item	2952757	et	3	main
see	doc_973441205353_item	2952758	et	3	main
on	doc_973441205353_item	2952759	et	4	main
asi	doc_973441205353_item	2952762	et	4	main
edukalt	doc_973441205353_item	2952772	et	4	main
inimene	doc_973441205353_item	2952779	et	3	main
ta	doc_973441205353_item	2952783	et	4	main
kool	doc_973441205353_item	2952785	et	4	main
ma	doc_973441205353_item	2952794	et	3	main
minna	doc_973441205352_item	2952713	et	3	main
loodan	doc_973441205352_item	2952714	et	3	main
vabaaega	doc_973441205352_item	2952718	et	4	main
positiivne	doc_973441205353_item	2952723	et	3	main
ellusuhtumine	doc_973441205353_item	2952724	et	3	main
edukuse	doc_973441205353_item	2952727	et	4	main
põhjuseks	doc_973441205353_item	2952728	et	3	main
on	doc_973441205353_item	2952737	et	4	main
arvan	doc_973441205353_item	2952742	et	3	main
usub	doc_973441205353_item	2952746	et	3	main
on	doc_973441205353_item	2952749	et	4	main
korras	doc_973441205353_item	2952751	et	4	main
temal	doc_973441205353_item	2952753	et	3	main
väga	doc_973441205353_item	2952760	et	3	main
aga	doc_973441205353_item	2952774	et	3	main
et	doc_973441205353_item	2952777	et	3	main
saab	doc_973441205353_item	2952784	et	3	main
ja	doc_973441205353_item	2952793	et	3	main
arvan	doc_973441205353_item	2952795	et	3	main
niisugune	doc_973441205353_item	2952797	et	3	main
ei	doc_973441205353_item	2952799	et	4	main
ole	doc_973441205353_item	2952800	et	4	main
ma	doc_973441205353_item	2952802	et	3	main
edukas	doc_973441205353_item	2952801	et	4	main
arvan	doc_973441205353_item	2952803	et	3	main
et	doc_973441205353_item	2952804	et	3	main
kui	doc_973441205353_item	2952805	et	3	main
inimesel	doc_973441205353_item	2952806	et	3	main
on	doc_973441205353_item	2952807	et	4	main
positiivne	doc_973441205353_item	2952808	et	3	main
ellusuhtumine	doc_973441205353_item	2952809	et	3	main
siis	doc_973441205353_item	2952810	et	3	main
ta	doc_973441205353_item	2952811	et	4	main
elu	doc_973441205353_item	2952812	et	4	main
on	doc_973441205353_item	2952813	et	4	main
väga	doc_973441205353_item	2952814	et	3	main
hea	doc_973441205353_item	2952815	et	4	main
sest	doc_973441205353_item	2952816	et	4	main
ta	doc_973441205353_item	2952817	et	4	main
usub	doc_973441205353_item	2952818	et	3	main
kui	doc_973441205353_item	2952819	et	3	main
inimesel	doc_973441205353_item	2952820	et	3	main
on	doc_973441205353_item	2952821	et	4	main
ellusuhtumine	doc_973441205353_item	2952823	et	3	main
kõik	doc_973441205353_item	2952831	et	4	main
ja	doc_973441205353_item	2952835	et	3	main
väga	doc_973441205353_item	2952837	et	3	main
inimestega	doc_973441205353_item	2952841	et	3	main
arvan	doc_973441205353_item	2952843	et	3	main
elu	doc_973441205353_item	2952846	et	4	main
me	doc_973441205353_item	2952850	et	4	main
on	doc_973441205353_item	2952865	et	4	main
usuma	doc_973441205353_item	2952872	et	4	main
aga	doc_973441205353_item	2952873	et	3	main
kui	doc_973441205353_item	2952874	et	3	main
korras	doc_973441205353_item	2952921	et	4	main
ma	doc_973441205354_item	2952923	et	3	main
väidan	doc_973441205354_item	2952924	et	3	main
et	doc_973441205354_item	2952925	et	3	main
kinos	doc_973441205354_item	2952928	et	3	main
igapäevamured	doc_973441205354_item	2952930	et	3	main
oma	doc_973441205354_item	2952938	et	4	main
tragöödia	doc_973441205354_item	2952947	et	4	main
stressi	doc_973441205354_item	2952961	et	4	main
negatiivne	doc_973441205353_item	2952791	et	3	main
siis	doc_973441205353_item	2952824	et	3	main
korras	doc_973441205353_item	2952832	et	4	main
mulle	doc_973441205353_item	2952836	et	4	main
niisugune	doc_973441205353_item	2952848	et	3	main
arvame	doc_973441205353_item	2952851	et	3	main
kellel	doc_973441205353_item	2952853	et	4	main
edu	doc_973441205353_item	2952859	et	4	main
ma	doc_973441205353_item	2952860	et	3	main
arvan	doc_973441205353_item	2952861	et	3	main
meie	doc_973441205353_item	2952863	et	4	main
elus	doc_973441205353_item	2952864	et	4	main
peavad	doc_973441205353_item	2952871	et	4	main
on	doc_973441205353_item	2952876	et	4	main
essee	doc_973441205354_item	2952922	et	4	main
inimesed	doc_973441205354_item	2952926	et	3	main
käivad	doc_973441205354_item	2952927	et	4	main
et	doc_973441205354_item	2952929	et	3	main
unustada	doc_973441205354_item	2952931	et	3	main
kino	doc_973441205354_item	2952932	et	4	main
lemmikino	doc_973441205354_item	2952939	et	4	main
see	doc_973441205354_item	2952940	et	3	main
võib	doc_973441205354_item	2952941	et	3	main
draama	doc_973441205354_item	2952945	et	4	main
või	doc_973441205354_item	2952955	et	4	main
rasket	doc_973441205354_item	2952958	et	3	main
inimene	doc_973441205354_item	2952965	et	3	main
kino	doc_973441205354_item	2952976	et	4	main
hea	doc_973441205354_item	2952985	et	4	main
täiendab	doc_973441205354_item	2952987	et	3	main
inimese	doc_973441205354_item	2952988	et	4	main
iseloomu	doc_973441205354_item	2952989	et	4	main
käivad	doc_973441205354_item	2953037	et	4	main
unustada	doc_973441205354_item	2953041	et	3	main
maailma	doc_973441205355_item	2953046	et	4	main
kuhu	doc_973441205355_item	2953047	et	3	main
inimene	doc_973441205355_item	2953048	et	3	main
saab	doc_973441205355_item	2953049	et	3	main
hea	doc_973441205355_item	2953050	et	4	main
tõielukult	doc_973441205355_item	2953056	et	4	main
maailma	doc_973441205355_item	2953062	et	4	main
hea	doc_973441205355_item	2953066	et	4	main
sisse	doc_973441205355_item	2953068	et	4	main
astuda	doc_973441205355_item	2953069	et	3	main
teatrimaailm	doc_973441205355_item	2953070	et	3	main
maailmast	doc_973441205355_item	2953073	et	4	main
selle	doc_973441205355_item	2953074	et	4	main
anna	doc_973441205355_item	2953081	et	4	main
ja	doc_973441205355_item	2953107	et	3	main
aitab	doc_973441205355_item	2953134	et	3	main
meeldib	doc_973441205355_item	2953141	et	3	main
ballett	doc_973441205355_item	2953152	et	3	main
sest	doc_973441205355_item	2953155	et	4	main
seal	doc_973441205355_item	2953156	et	4	main
aitab	doc_973441205355_item	2953178	et	3	main
tuju	doc_973441205355_item	2953183	et	4	main
meie	doc_973441205357_item	2953347	et	4	main
elada	doc_973441205357_item	2953350	et	3	main
e	doc_973441205357_item	2953361	et	4	main
see	doc_973441205357_item	2953362	et	3	main
inimesed	doc_973441205357_item	2953372	et	3	main
nad	doc_973441205357_item	2953376	et	3	main
lõhet	doc_973441205357_item	2953378	et	3	main
positiivne	doc_973441205353_item	2952822	et	3	main
ta	doc_973441205353_item	2952825	et	4	main
on	doc_973441205353_item	2952826	et	4	main
on	doc_973441205353_item	2952847	et	4	main
on	doc_973441205353_item	2952857	et	4	main
et	doc_973441205353_item	2952862	et	3	main
negatiivne	doc_973441205353_item	2952877	et	3	main
siis	doc_973441205353_item	2952879	et	3	main
inimene	doc_973441205353_item	2952881	et	3	main
ei	doc_973441205353_item	2952882	et	4	main
ole	doc_973441205353_item	2952883	et	4	main
edukas	doc_973441205353_item	2952884	et	4	main
sest	doc_973441205353_item	2952885	et	4	main
ta	doc_973441205353_item	2952886	et	4	main
ei	doc_973441205353_item	2952887	et	4	main
usu	doc_973441205353_item	2952888	et	4	main
ta	doc_973441205353_item	2952889	et	4	main
asjad	doc_973441205353_item	2952890	et	3	main
ei	doc_973441205353_item	2952891	et	4	main
ole	doc_973441205353_item	2952892	et	4	main
korras	doc_973441205353_item	2952893	et	4	main
ma	doc_973441205353_item	2952894	et	3	main
arvan	doc_973441205353_item	2952895	et	3	main
et	doc_973441205353_item	2952896	et	3	main
kui	doc_973441205353_item	2952897	et	3	main
inimesel	doc_973441205353_item	2952898	et	3	main
on	doc_973441205353_item	2952899	et	4	main
negatiivne	doc_973441205353_item	2952900	et	3	main
ellusuhtumine	doc_973441205353_item	2952901	et	3	main
siis	doc_973441205353_item	2952902	et	3	main
ta	doc_973441205353_item	2952903	et	4	main
ei	doc_973441205353_item	2952904	et	4	main
ole	doc_973441205353_item	2952905	et	4	main
terve	doc_973441205353_item	2952906	et	4	main
ma	doc_973441205353_item	2952907	et	3	main
arvan	doc_973441205353_item	2952908	et	3	main
et	doc_973441205353_item	2952909	et	3	main
niisugune	doc_973441205353_item	2952910	et	3	main
inimene	doc_973441205353_item	2952911	et	3	main
peab	doc_973441205353_item	2952912	et	4	main
minema	doc_973441205353_item	2952913	et	3	main
arsti	doc_973441205353_item	2952914	et	4	main
juurde	doc_973441205353_item	2952915	et	4	main
inimesed	doc_973441205353_item	2952916	et	3	main
alati	doc_973441205353_item	2952830	et	4	main
naerab	doc_973441205353_item	2952834	et	3	main
suhelda	doc_973441205353_item	2952839	et	4	main
ma	doc_973441205353_item	2952842	et	3	main
kuidas	doc_973441205353_item	2952849	et	3	main
inimesel	doc_973441205353_item	2952852	et	3	main
on	doc_973441205353_item	2952854	et	4	main
positiivne	doc_973441205353_item	2952855	et	3	main
ellusuhtumine	doc_973441205353_item	2952856	et	3	main
usuda	doc_973441205353_item	2952868	et	4	main
kõik	doc_973441205353_item	2952869	et	4	main
inimesed	doc_973441205353_item	2952870	et	3	main
kõik	doc_973441205353_item	2952919	et	4	main
on	doc_973441205353_item	2952920	et	4	main
ola	doc_973441205354_item	2952942	et	4	main
ja	doc_973441205354_item	2952946	et	3	main
unustada	doc_973441205354_item	2952954	et	3	main
päeva	doc_973441205354_item	2952959	et	4	main
või	doc_973441205354_item	2952960	et	4	main
vaatab	doc_973441205354_item	2952966	et	3	main
elus	doc_973441205354_item	2952974	et	4	main
ja	doc_973441205354_item	2953022	et	3	main
kino	doc_973441205354_item	2953027	et	4	main
loob	doc_973441205354_item	2953028	et	3	main
maailm	doc_973441205354_item	2953029	et	3	main
paneb	doc_973441205354_item	2953030	et	3	main
mõtlema	doc_973441205354_item	2953031	et	3	main
ja	doc_973441205354_item	2953032	et	3	main
annab	doc_973441205354_item	2953033	et	3	main
elamusi	doc_973441205354_item	2953034	et	3	main
sellepärast	doc_973441205354_item	2953035	et	3	main
inimesed	doc_973441205354_item	2953036	et	3	main
kinos	doc_973441205354_item	2953038	et	3	main
et	doc_973441205354_item	2953039	et	3	main
nõus	doc_973441205355_item	2953057	et	4	main
et	doc_973441205355_item	2953058	et	3	main
kuhu	doc_973441205355_item	2953063	et	3	main
inimene	doc_973441205355_item	2953064	et	3	main
meelega	doc_973441205355_item	2953067	et	4	main
erineb	doc_973441205355_item	2953071	et	3	main
vaid	doc_973441205355_item	2953083	et	3	main
mõtlema	doc_973441205355_item	2953086	et	3	main
laiendab	doc_973441205355_item	2953088	et	3	main
elava	doc_973441205355_item	2953095	et	4	main
inimesega	doc_973441205355_item	2953096	et	3	main
mulle	doc_973441205355_item	2953097	et	4	main
ma	doc_973441205355_item	2953104	et	3	main
moskvas	doc_973441205355_item	2953106	et	4	main
kaisin	doc_973441205355_item	2953111	et	4	main
minu	doc_973441205355_item	2953113	et	3	main
oli	doc_973441205355_item	2953115	et	3	main
peaosa	doc_973441205355_item	2953117	et	4	main
oli	doc_973441205355_item	2953122	et	3	main
mulle	doc_973441205355_item	2953126	et	4	main
meeldis	doc_973441205355_item	2953127	et	3	main
unustada	doc_973441205355_item	2953136	et	3	main
mulle	doc_973441205355_item	2953140	et	4	main
on	doc_973441205355_item	2953151	et	4	main
ooper	doc_973441205355_item	2953154	et	3	main
hea	doc_973441205355_item	2953158	et	4	main
ja	doc_973441205355_item	2953160	et	3	main
tuju	doc_973441205355_item	2953166	et	4	main
teatris	doc_973441205355_item	2953169	et	3	main
huvitav	doc_973441205355_item	2953172	et	4	main
ma	doc_973441205355_item	2953174	et	3	main
on	doc_973441205354_item	2952937	et	4	main
märulifilmid	doc_973441205354_item	2952944	et	4	main
lõõgastuda	doc_973441205354_item	2952956	et	3	main
pärast	doc_973441205354_item	2952957	et	4	main
teine	doc_973441205354_item	2952964	et	3	main
kinot	doc_973441205354_item	2952969	et	4	main
aitab	doc_973441205354_item	2952972	et	3	main
meie	doc_973441205354_item	2952973	et	4	main
kino	doc_973441205354_item	2952990	et	4	main
võib	doc_973441205354_item	2952991	et	3	main
ola	doc_973441205354_item	2952992	et	4	main
lõbus	doc_973441205354_item	2952993	et	4	main
või	doc_973441205354_item	2952994	et	4	main
kurb	doc_973441205354_item	2952995	et	3	main
kino	doc_973441205354_item	2952996	et	4	main
aitab	doc_973441205354_item	2952997	et	3	main
meile	doc_973441205354_item	2952998	et	4	main
mõtelda	doc_973441205354_item	2952999	et	4	main
hangida	doc_973441205354_item	2953000	et	4	main
huvatav	doc_973441205354_item	2953001	et	4	main
infot	doc_973441205354_item	2953002	et	3	main
lõõgastuda	doc_973441205354_item	2953003	et	3	main
naeratada	doc_973441205354_item	2953004	et	3	main
ja	doc_973441205354_item	2953005	et	3	main
igapäevamured	doc_973441205354_item	2953006	et	3	main
unustada	doc_973441205354_item	2953007	et	3	main
kinos	doc_973441205354_item	2953009	et	3	main
on	doc_973441205354_item	2953010	et	4	main
palju	doc_973441205354_item	2953011	et	4	main
muidugi	doc_973441205354_item	2953008	et	4	main
huvitavaid	doc_973441205354_item	2953012	et	4	main
infot	doc_973441205354_item	2953013	et	3	main
mugavaid	doc_973441205354_item	2953014	et	3	main
saalid	doc_973441205354_item	2953015	et	4	main
suur	doc_973441205354_item	2953016	et	3	main
ekran	doc_973441205354_item	2953017	et	4	main
kvalitseetne	doc_973441205354_item	2953018	et	4	main
pilt	doc_973441205354_item	2953019	et	3	main
ja	doc_973441205354_item	2953020	et	3	main
palju	doc_973441205354_item	2953023	et	4	main
uusi	doc_973441205354_item	2953024	et	3	main
filme	doc_973441205354_item	2953025	et	3	main
igapäevamured	doc_973441205354_item	2953040	et	3	main
essee	doc_973441205355_item	2953042	et	4	main
teater	doc_973441205355_item	2953043	et	3	main
loob	doc_973441205355_item	2953044	et	3	main
olen	doc_973441205355_item	2953055	et	3	main
ta	doc_973441205355_item	2953077	et	4	main
mitte	doc_973441205355_item	2953078	et	3	main
ainult	doc_973441205355_item	2953079	et	4	main
ka	doc_973441205355_item	2953085	et	3	main
maailmas	doc_973441205354_item	2952962	et	3	main
lemmik	doc_973441205354_item	2952968	et	3	main
klassikaline	doc_973441205354_item	2952975	et	4	main
ja	doc_973441205354_item	2952984	et	3	main
heli	doc_973441205354_item	2953021	et	4	main
kõigipealt	doc_973441205354_item	2953026	et	4	main
uue	doc_973441205355_item	2953045	et	3	main
teater	doc_973441205355_item	2953059	et	3	main
uue	doc_973441205355_item	2953061	et	3	main
saab	doc_973441205355_item	2953065	et	3	main
poolest	doc_973441205355_item	2953075	et	4	main
et	doc_973441205355_item	2953076	et	3	main
elamusi	doc_973441205355_item	2953082	et	3	main
see	doc_973441205355_item	2953092	et	3	main
väga	doc_973441205355_item	2953098	et	3	main
meeldib	doc_973441205355_item	2953099	et	3	main
kaia	doc_973441205355_item	2953101	et	4	main
külastasin	doc_973441205355_item	2953108	et	3	main
kaasaegne	doc_973441205355_item	2953123	et	3	main
ja	doc_973441205355_item	2953138	et	3	main
muusikaline	doc_973441205355_item	2953143	et	4	main
ja	doc_973441205355_item	2953153	et	3	main
muusikalavastus	doc_973441205355_item	2953159	et	3	main
tantsulavastus	doc_973441205355_item	2953161	et	3	main
mul	doc_973441205355_item	2953163	et	3	main
vaatan	doc_973441205355_item	2953171	et	3	main
teatrietendus	doc_973441205355_item	2953173	et	3	main
et	doc_973441205355_item	2953176	et	3	main
meil	doc_973441205355_item	2953179	et	4	main
ja	doc_973441205355_item	2953181	et	3	main
tõstab	doc_973441205355_item	2953182	et	3	main
miks	doc_973441205357_item	2953337	et	4	main
on	doc_973441205357_item	2953338	et	4	main
vaja	doc_973441205357_item	2953339	et	4	main
ei	doc_973441205357_item	2953348	et	4	main
saaks	doc_973441205357_item	2953349	et	3	main
n	doc_973441205357_item	2953360	et	4	main
kõik	doc_973441205357_item	2953364	et	4	main
teevad	doc_973441205357_item	2953373	et	3	main
liike	doc_973441205357_item	2953386	et	4	main
looduses	doc_973441205357_item	2953387	et	4	main
olema	doc_973441205357_item	2953390	et	4	main
teise	doc_973441205357_item	2953395	et	4	main
inimeste	doc_973441205357_item	2953396	et	3	main
meelega	doc_973441205355_item	2953051	et	4	main
sisse	doc_973441205355_item	2953052	et	4	main
astuda	doc_973441205355_item	2953053	et	3	main
ma	doc_973441205355_item	2953054	et	3	main
loob	doc_973441205355_item	2953060	et	3	main
tavalisest	doc_973441205355_item	2953072	et	4	main
ei	doc_973441205355_item	2953080	et	4	main
paneb	doc_973441205355_item	2953084	et	3	main
silmaringi	doc_973441205355_item	2953089	et	4	main
teater	doc_973441205355_item	2953091	et	3	main
teatris	doc_973441205355_item	2953100	et	3	main
möödunud	doc_973441205355_item	2953102	et	4	main
kaisin	doc_973441205355_item	2953105	et	4	main
teatrietendus	doc_973441205355_item	2953109	et	3	main
koht	doc_973441205355_item	2953114	et	3	main
rõdul	doc_973441205355_item	2953116	et	3	main
mängis	doc_973441205355_item	2953118	et	3	main
nina	doc_973441205355_item	2953119	et	4	main
titova	doc_973441205355_item	2953120	et	4	main
etendus	doc_973441205355_item	2953121	et	4	main
neil	doc_973441205355_item	2953135	et	4	main
probleemid	doc_973441205355_item	2953139	et	3	main
teatris	doc_973441205355_item	2953142	et	3	main
kujundus	doc_973441205355_item	2953144	et	4	main
näitlejate	doc_973441205355_item	2953145	et	4	main
mäng	doc_973441205355_item	2953146	et	3	main
meenutab	doc_973441205355_item	2953147	et	3	main
on	doc_973441205355_item	2953164	et	4	main
kain	doc_973441205355_item	2953168	et	3	main
teater	doc_973441205355_item	2953177	et	3	main
eluda	doc_973441205355_item	2953180	et	4	main
teater	doc_973441205355_item	2953087	et	3	main
sest	doc_973441205355_item	2953090	et	4	main
on	doc_973441205355_item	2953093	et	4	main
suhtlemine	doc_973441205355_item	2953094	et	4	main
suvel	doc_973441205355_item	2953103	et	3	main
ma	doc_973441205355_item	2953110	et	3	main
esietendusel	doc_973441205355_item	2953112	et	3	main
ja	doc_973441205355_item	2953124	et	3	main
kaasakiskuv	doc_973441205355_item	2953125	et	4	main
lavastus	doc_973441205355_item	2953128	et	4	main
inimest	doc_973441205355_item	2953129	et	3	main
teeb	doc_973441205355_item	2953130	et	3	main
teater	doc_973441205355_item	2953131	et	3	main
reipaks	doc_973441205355_item	2953132	et	3	main
teater	doc_973441205355_item	2953133	et	3	main
muured	doc_973441205355_item	2953137	et	4	main
elu	doc_973441205355_item	2953148	et	4	main
minu	doc_973441205355_item	2953149	et	3	main
lemmikžanrid	doc_973441205355_item	2953150	et	2	main
on	doc_973441205355_item	2953157	et	4	main
kui	doc_973441205355_item	2953162	et	3	main
halb	doc_973441205355_item	2953165	et	3	main
ma	doc_973441205355_item	2953167	et	3	main
ja	doc_973441205355_item	2953170	et	3	main
arvan	doc_973441205355_item	2953175	et	3	main
kaitsta	doc_973441205357_item	2953340	et	4	main
pea	doc_973441205357_item	2953345	et	4	main
sõber	doc_973441205357_item	2953346	et	3	main
j	doc_973441205357_item	2953359	et	4	main
loodus	doc_973441205357_item	2953365	et	4	main
need	doc_973441205357_item	2953366	et	3	main
meie	doc_973441205357_item	2953368	et	4	main
elu	doc_973441205357_item	2953369	et	4	main
vundamentis	doc_973441205357_item	2953370	et	3	main
mõnikord	doc_973441205357_item	2953371	et	3	main
teevad	doc_973441205357_item	2953377	et	3	main
tähelepanelikuks	doc_973441205357_item	2953391	et	4	main
peaks	doc_973441205357_item	2953393	et	4	main
prograami	doc_973441205357_item	2953401	et	4	main
aitab	doc_973441205357_item	2953403	et	3	main
meid	doc_973441205357_item	2953404	et	4	main
armastada	doc_973441205357_item	2953405	et	3	main
loodust	doc_973441205357_item	2953406	et	4	main
ja	doc_973441205357_item	2953407	et	3	main
hoolitseda	doc_973441205357_item	2953408	et	3	main
ümberjutustus	doc_973441205358_item	2953411	et	3	main
vanaema	doc_973441205358_item	2953426	et	4	main
veel	doc_973441205358_item	2953427	et	4	main
oma	doc_973441205358_item	2953437	et	4	main
teda	doc_973441205358_item	2953445	et	4	main
vaata	doc_973441205358_item	2953456	et	4	main
kuidas	doc_973441205358_item	2953457	et	3	main
et	doc_973441205358_item	2953462	et	3	main
teises	doc_973441205358_item	2953475	et	4	main
külas	doc_973441205358_item	2953476	et	3	main
on	doc_973441205358_item	2953509	et	4	main
küsis	doc_973441205358_item	2953514	et	3	main
punamütsike	doc_973441205358_item	2953526	et	4	main
hunt	doc_973441205358_item	2953527	et	3	main
on	doc_973441205358_item	2953528	et	4	main
kõht	doc_973441205358_item	2953529	et	3	main
väga	doc_973441205358_item	2953530	et	3	main
täis	doc_973441205358_item	2953531	et	4	main
ära	doc_973441205358_item	2953534	et	4	main
et	doc_973441205358_item	2953552	et	3	main
punamütsike	doc_973441205358_item	2953562	et	4	main
hakkas	doc_973441205358_item	2953563	et	3	main
korjatama	doc_973441205358_item	2953564	et	3	main
liiled	doc_973441205358_item	2953565	et	4	main
natukese	doc_973441205358_item	2953566	et	4	main
vanaema	doc_973441205358_item	2953569	et	4	main
kes	doc_973441205358_item	2953575	et	4	main
ja	doc_973441205358_item	2953607	et	3	main
punamütsike	doc_973441205358_item	2953610	et	4	main
majas	doc_973441205358_item	2953615	et	3	main
hunt	doc_973441205358_item	2953624	et	3	main
sind	doc_973441205358_item	2953635	et	4	main
ust	doc_973441205358_item	2953636	et	4	main
ütles	doc_973441205358_item	2953641	et	3	main
väike	doc_973441205359_item	2953651	et	4	main
ema	doc_973441205359_item	2953657	et	4	main
väikese	doc_973441205359_item	2953672	et	4	main
kõik	doc_973441205359_item	2953686	et	4	main
küpsetas	doc_973441205359_item	2953692	et	3	main
kooki	doc_973441205359_item	2953693	et	4	main
ja	doc_973441205359_item	2953694	et	3	main
juurde	doc_973441205359_item	2953699	et	4	main
haige	doc_973441205359_item	2953703	et	4	main
ta	doc_973441205359_item	2953704	et	4	main
elas	doc_973441205359_item	2953705	et	3	main
majas	doc_973441205359_item	2953711	et	3	main
küsimusele	doc_973441205357_item	2953336	et	4	main
loodust	doc_973441205357_item	2953341	et	4	main
maastikud	doc_973441205357_item	2953358	et	4	main
on	doc_973441205357_item	2953363	et	4	main
sisaldavad	doc_973441205357_item	2953367	et	4	main
asju	doc_973441205357_item	2953375	et	3	main
reostavad	doc_973441205357_item	2953380	et	4	main
vett	doc_973441205357_item	2953381	et	3	main
tapavad	doc_973441205357_item	2953384	et	3	main
me	doc_973441205357_item	2953388	et	4	main
peaks	doc_973441205357_item	2953389	et	4	main
ja	doc_973441205357_item	2953392	et	3	main
vaatama	doc_973441205357_item	2953394	et	3	main
eest	doc_973441205357_item	2953397	et	4	main
tuleb	doc_973441205357_item	2953398	et	3	main
teha	doc_973441205357_item	2953399	et	3	main
spetsialse	doc_973441205357_item	2953400	et	4	main
mis	doc_973441205357_item	2953402	et	4	main
eest	doc_973441205357_item	2953410	et	4	main
teda	doc_973441205358_item	2953423	et	4	main
väga	doc_973441205358_item	2953424	et	3	main
armstas	doc_973441205358_item	2953425	et	4	main
tegi	doc_973441205358_item	2953430	et	4	main
ema	doc_973441205358_item	2953449	et	4	main
küpsetas	doc_973441205358_item	2953450	et	3	main
kooki	doc_973441205358_item	2953451	et	4	main
ta	doc_973441205358_item	2953463	et	4	main
haige	doc_973441205358_item	2953465	et	4	main
talle	doc_973441205358_item	2953467	et	4	main
pudel	doc_973441205358_item	2953470	et	3	main
punamütsikese	doc_973441205358_item	2953472	et	4	main
vanaema	doc_973441205358_item	2953473	et	4	main
elas	doc_973441205358_item	2953474	et	3	main
punamütsike	doc_973441205358_item	2953481	et	4	main
võtab	doc_973441205358_item	2953482	et	3	main
korv	doc_973441205358_item	2953483	et	3	main
ja	doc_973441205358_item	2953484	et	3	main
läks	doc_973441205358_item	2953485	et	3	main
vanaemale	doc_973441205358_item	2953486	et	3	main
juurde	doc_973441205358_item	2953487	et	4	main
metsas	doc_973441205358_item	2953488	et	3	main
sa	doc_973441205358_item	2953501	et	3	main
lahed	doc_973441205358_item	2953502	et	3	main
ma	doc_973441205358_item	2953503	et	3	main
lähen	doc_973441205358_item	2953504	et	3	main
vaatama	doc_973441205358_item	2953505	et	3	main
oma	doc_973441205358_item	2953506	et	4	main
kus	doc_973441205358_item	2953511	et	3	main
elab	doc_973441205358_item	2953512	et	3	main
väikeses	doc_973441205358_item	2953522	et	4	main
süüa	doc_973441205358_item	2953535	et	3	main
punamütsike	doc_973441205358_item	2953537	et	4	main
arvan	doc_973441205358_item	2953551	et	3	main
seal	doc_973441205358_item	2953576	et	4	main
ootama	doc_973441205358_item	2953609	et	3	main
juures	doc_973441205358_item	2953616	et	4	main
punamütsike	doc_973441205358_item	2953617	et	4	main
koputas	doc_973441205358_item	2953618	et	3	main
uksele	doc_973441205358_item	2953619	et	3	main
kes	doc_973441205358_item	2953620	et	4	main
vastus	doc_973441205357_item	2953335	et	3	main
loodus	doc_973441205357_item	2953342	et	4	main
on	doc_973441205357_item	2953343	et	4	main
meie	doc_973441205357_item	2953344	et	4	main
loodust	doc_973441205357_item	2953351	et	4	main
loomad	doc_973441205357_item	2953352	et	3	main
taimed	doc_973441205357_item	2953353	et	3	main
veed	doc_973441205357_item	2953354	et	3	main
maad	doc_973441205357_item	2953355	et	4	main
õhk	doc_973441205357_item	2953356	et	3	main
linnud	doc_973441205357_item	2953357	et	3	main
rumalaid	doc_973441205357_item	2953374	et	3	main
metsas	doc_973441205357_item	2953379	et	3	main
saastavad	doc_973441205357_item	2953382	et	4	main
õhku	doc_973441205357_item	2953383	et	4	main
haruldavaid	doc_973441205357_item	2953385	et	4	main
tema	doc_973441205357_item	2953409	et	4	main
ümberjutustus	doc_973441205358_item	2953412	et	3	main
elas	doc_973441205358_item	2953414	et	3	main
kord	doc_973441205358_item	2953415	et	4	main
väike	doc_973441205358_item	2953416	et	4	main
tüdruk	doc_973441205358_item	2953417	et	3	main
ta	doc_973441205358_item	2953418	et	4	main
on	doc_973441205358_item	2953419	et	4	main
vaga	doc_973441205358_item	2953420	et	4	main
ema	doc_973441205358_item	2953422	et	4	main
vanaema	doc_973441205358_item	2953429	et	4	main
punamütsike	doc_973441205358_item	2953435	et	4	main
pani	doc_973441205358_item	2953436	et	4	main
ma	doc_973441205358_item	2953460	et	3	main
vii	doc_973441205358_item	2953466	et	4	main
mahla	doc_973441205358_item	2953471	et	4	main
tee	doc_973441205358_item	2953477	et	4	main
läks	doc_973441205358_item	2953478	et	3	main
kohtus	doc_973441205358_item	2953490	et	4	main
hunt	doc_973441205358_item	2953491	et	3	main
hunt	doc_973441205358_item	2953492	et	3	main
oli	doc_973441205358_item	2953493	et	3	main
suur	doc_973441205358_item	2953494	et	3	main
ja	doc_973441205358_item	2953495	et	3	main
hall	doc_973441205358_item	2953496	et	4	main
hunt	doc_973441205358_item	2953497	et	3	main
küsis	doc_973441205358_item	2953498	et	3	main
punamütsikesest	doc_973441205358_item	2953499	et	4	main
kuhu	doc_973441205358_item	2953500	et	3	main
haige	doc_973441205358_item	2953510	et	4	main
ta	doc_973441205358_item	2953516	et	4	main
ääres	doc_973441205358_item	2953521	et	4	main
rohelises	doc_973441205358_item	2953523	et	4	main
liiled	doc_973441205358_item	2953546	et	4	main
tegi	doc_973441205358_item	2953547	et	4	main
etepanikud	doc_973441205358_item	2953548	et	4	main
hunt	doc_973441205358_item	2953549	et	3	main
ma	doc_973441205358_item	2953550	et	3	main
vanaemad	doc_973441205358_item	2953554	et	3	main
hunt	doc_973441205358_item	2953558	et	3	main
jooksis	doc_973441205358_item	2953560	et	4	main
metsa	doc_973441205358_item	2953561	et	4	main
aja	doc_973441205358_item	2953567	et	4	main
majas	doc_973441205358_item	2953570	et	3	main
juures	doc_973441205358_item	2953571	et	4	main
hunt	doc_973441205358_item	2953572	et	3	main
koputas	doc_973441205358_item	2953573	et	3	main
uksele	doc_973441205358_item	2953574	et	3	main
hakkas	doc_973441205358_item	2953608	et	3	main
vanaema	doc_973441205358_item	2953614	et	4	main
seal	doc_973441205358_item	2953621	et	4	main
häälga	doc_973441205358_item	2953626	et	4	main
mina	doc_973441205358_item	2953629	et	4	main
ava	doc_973441205358_item	2953637	et	4	main
hunt	doc_973441205358_item	2953642	et	3	main
punamütsike	doc_973441205358_item	2953643	et	4	main
punamütsike	doc_973441205358_item	2953413	et	4	main
ilus	doc_973441205358_item	2953421	et	4	main
rohkem	doc_973441205358_item	2953428	et	4	main
mütsikese	doc_973441205358_item	2953433	et	4	main
ja	doc_973441205358_item	2953434	et	3	main
iga	doc_973441205358_item	2953439	et	4	main
päev	doc_973441205358_item	2953440	et	3	main
nii	doc_973441205358_item	2953441	et	3	main
hakkas	doc_973441205358_item	2953442	et	3	main
kõik	doc_973441205358_item	2953443	et	4	main
kutsusid	doc_973441205358_item	2953444	et	4	main
ja	doc_973441205358_item	2953452	et	3	main
ütles	doc_973441205358_item	2953453	et	3	main
punamütsikesele	doc_973441205358_item	2953454	et	4	main
mine	doc_973441205358_item	2953455	et	3	main
kuulsin	doc_973441205358_item	2953461	et	3	main
on	doc_973441205358_item	2953464	et	4	main
ja	doc_973441205358_item	2953469	et	3	main
läbi	doc_973441205358_item	2953479	et	4	main
metsa	doc_973441205358_item	2953480	et	4	main
ta	doc_973441205358_item	2953508	et	4	main
hunt	doc_973441205358_item	2953515	et	3	main
teises	doc_973441205358_item	2953518	et	4	main
talle	doc_973441205358_item	2953431	et	4	main
punase	doc_973441205358_item	2953432	et	4	main
pe	doc_973441205358_item	2953438	et	4	main
punamütsikeseks	doc_973441205358_item	2953446	et	4	main
ühel	doc_973441205358_item	2953447	et	3	main
päeval	doc_973441205358_item	2953448	et	3	main
vanaema	doc_973441205358_item	2953458	et	4	main
elab	doc_973441205358_item	2953459	et	3	main
kooki	doc_973441205358_item	2953468	et	4	main
punamütsike	doc_973441205358_item	2953489	et	4	main
vanaema	doc_973441205358_item	2953507	et	4	main
vanaema	doc_973441205358_item	2953513	et	4	main
elab	doc_973441205358_item	2953517	et	3	main
külas	doc_973441205358_item	2953519	et	3	main
metsa	doc_973441205358_item	2953520	et	4	main
tahtis	doc_973441205358_item	2953533	et	3	main
kõik	doc_973441205358_item	2953553	et	4	main
liiled	doc_973441205358_item	2953556	et	4	main
ja	doc_973441205358_item	2953559	et	3	main
pärast	doc_973441205358_item	2953568	et	4	main
on	doc_973441205358_item	2953577	et	4	main
küsis	doc_973441205358_item	2953578	et	3	main
vanaema	doc_973441205358_item	2953579	et	4	main
natukese	doc_973441205358_item	2953611	et	4	main
aja	doc_973441205358_item	2953612	et	4	main
on	doc_973441205358_item	2953622	et	4	main
küsis	doc_973441205358_item	2953623	et	3	main
see	doc_973441205358_item	2953627	et	3	main
mina	doc_973441205358_item	2953633	et	4	main
vaatama	doc_973441205358_item	2953634	et	3	main
mine	doc_973441205358_item	2953639	et	3	main
typpa	doc_973441205358_item	2953645	et	4	main
ümberjutustus	doc_973441205359_item	2953646	et	3	main
ümberjutustus	doc_973441205359_item	2953647	et	3	main
punamütsike	doc_973441205359_item	2953648	et	4	main
elas	doc_973441205359_item	2953649	et	3	main
kord	doc_973441205359_item	2953650	et	4	main
ta	doc_973441205359_item	2953653	et	4	main
ilus	doc_973441205359_item	2953656	et	4	main
teda	doc_973441205359_item	2953659	et	4	main
väga	doc_973441205359_item	2953660	et	3	main
ja	doc_973441205359_item	2953661	et	3	main
vanaema	doc_973441205359_item	2953662	et	4	main
armastas	doc_973441205359_item	2953663	et	3	main
mütsi	doc_973441205359_item	2953673	et	4	main
temale	doc_973441205359_item	2953674	et	3	main
kutsus	doc_973441205359_item	2953687	et	4	main
palus	doc_973441205359_item	2953695	et	4	main
viima	doc_973441205359_item	2953696	et	3	main
teises	doc_973441205359_item	2953706	et	4	main
külas	doc_973441205359_item	2953707	et	3	main
kutsus	doc_973441205359_item	2953713	et	4	main
ta	doc_973441205359_item	2953730	et	4	main
akki	doc_973441205359_item	2953748	et	4	main
mahla	doc_973441205359_item	2953775	et	4	main
kaugel	doc_973441205359_item	2953783	et	4	main
metsa	doc_973441205359_item	2953789	et	4	main
oli	doc_973441205359_item	2953822	et	3	main
ta	doc_973441205359_item	2953825	et	4	main
tuppas	doc_973441205359_item	2953827	et	4	main
ta	doc_973441205359_item	2953828	et	4	main
teda	doc_973441205359_item	2953832	et	4	main
seda	doc_973441205359_item	2953836	et	3	main
hunt	doc_973441205359_item	2953837	et	3	main
hettis	doc_973441205359_item	2953839	et	4	main
ning	doc_973441205359_item	2953840	et	3	main
hakkas	doc_973441205359_item	2953841	et	3	main
ootama	doc_973441205359_item	2953842	et	3	main
punamütsikest	doc_973441205359_item	2953843	et	4	main
see	doc_973441205359_item	2953851	et	3	main
punamütsike	doc_973441205359_item	2953854	et	4	main
palus	doc_973441205359_item	2953865	et	4	main
temale	doc_973441205359_item	2953868	et	3	main
küll	doc_973441205359_item	2953870	et	4	main
ümberjutustus	doc_973441205360_item	2953901	et	3	main
oli	doc_973441205360_item	2953921	et	3	main
vanaema	doc_973441205360_item	2953923	et	4	main
ema	doc_973441205360_item	2953924	et	4	main
ja	doc_973441205360_item	2953925	et	3	main
vanaema	doc_973441205360_item	2953926	et	4	main
majas	doc_973441205358_item	2953524	et	3	main
vaastas	doc_973441205358_item	2953525	et	4	main
ta	doc_973441205358_item	2953532	et	4	main
kohe	doc_973441205358_item	2953536	et	4	main
aga	doc_973441205358_item	2953538	et	3	main
ta	doc_973441205358_item	2953539	et	4	main
mõtles	doc_973441205358_item	2953540	et	3	main
ümber	doc_973441205358_item	2953541	et	3	main
korja	doc_973441205358_item	2953542	et	4	main
vanaemale	doc_973441205358_item	2953543	et	3	main
suur	doc_973441205358_item	2953544	et	3	main
kimp	doc_973441205358_item	2953545	et	3	main
armastavad	doc_973441205358_item	2953555	et	4	main
ütles	doc_973441205358_item	2953557	et	3	main
see	doc_973441205358_item	2953580	et	3	main
olen	doc_973441205358_item	2953581	et	3	main
mina	doc_973441205358_item	2953582	et	4	main
punamütsike	doc_973441205358_item	2953583	et	4	main
vastas	doc_973441205358_item	2953584	et	4	main
hunt	doc_973441205358_item	2953585	et	3	main
peenikese	doc_973441205358_item	2953586	et	4	main
hääl	doc_973441205358_item	2953587	et	3	main
ust	doc_973441205358_item	2953588	et	4	main
ava	doc_973441205358_item	2953589	et	4	main
ja	doc_973441205358_item	2953590	et	3	main
mine	doc_973441205358_item	2953591	et	3	main
tuppa	doc_973441205358_item	2953592	et	3	main
ütles	doc_973441205358_item	2953593	et	3	main
vanaema	doc_973441205358_item	2953594	et	4	main
hunt	doc_973441205358_item	2953595	et	3	main
astus	doc_973441205358_item	2953596	et	3	main
tuppa	doc_973441205358_item	2953597	et	3	main
ja	doc_973441205358_item	2953598	et	3	main
vanaema	doc_973441205358_item	2953600	et	4	main
sõi	doc_973441205358_item	2953599	et	3	main
kohe	doc_973441205358_item	2953601	et	4	main
pärast	doc_973441205358_item	2953602	et	4	main
ta	doc_973441205358_item	2953603	et	4	main
heitis	doc_973441205358_item	2953604	et	3	main
vanaema	doc_973441205358_item	2953605	et	4	main
voodis	doc_973441205358_item	2953606	et	3	main
pärast	doc_973441205358_item	2953613	et	4	main
vanaema	doc_973441205358_item	2953625	et	4	main
olen	doc_973441205358_item	2953628	et	3	main
ja	doc_973441205358_item	2953638	et	3	main
rohkem	doc_973441205359_item	2953665	et	4	main
meeldid	doc_973441205359_item	2953675	et	3	main
see	doc_973441205359_item	2953676	et	3	main
ning	doc_973441205359_item	2953678	et	3	main
pärast	doc_973441205359_item	2953684	et	4	main
punamütsikest	doc_973441205359_item	2953700	et	4	main
oli	doc_973441205359_item	2953702	et	3	main
rohelises	doc_973441205359_item	2953710	et	4	main
võtma	doc_973441205359_item	2953718	et	3	main
punamütsike	doc_973441205358_item	2953630	et	4	main
vastas	doc_973441205358_item	2953631	et	4	main
tüdruk	doc_973441205358_item	2953632	et	3	main
tuppa	doc_973441205358_item	2953640	et	3	main
astus	doc_973441205358_item	2953644	et	3	main
tüdruk	doc_973441205359_item	2953652	et	3	main
väga	doc_973441205359_item	2953664	et	3	main
kord	doc_973441205359_item	2953667	et	4	main
ta	doc_973441205359_item	2953679	et	4	main
kannas	doc_973441205359_item	2953680	et	4	main
tihti	doc_973441205359_item	2953681	et	3	main
selle	doc_973441205359_item	2953683	et	4	main
tema	doc_973441205359_item	2953685	et	4	main
ema	doc_973441205359_item	2953691	et	4	main
metsa	doc_973441205359_item	2953708	et	4	main
ääres	doc_973441205359_item	2953709	et	4	main
koogiga	doc_973441205359_item	2953722	et	3	main
mütsi	doc_973441205359_item	2953734	et	4	main
läks	doc_973441205359_item	2953737	et	3	main
ta	doc_973441205359_item	2953744	et	4	main
hakkas	doc_973441205359_item	2953745	et	3	main
korjama	doc_973441205359_item	2953746	et	3	main
lilled	doc_973441205359_item	2953747	et	3	main
tema	doc_973441205359_item	2953749	et	4	main
juurde	doc_973441205359_item	2953750	et	4	main
vanaema	doc_973441205359_item	2953764	et	4	main
juurde	doc_973441205359_item	2953765	et	4	main
ta	doc_973441205359_item	2953766	et	4	main
vastas	doc_973441205359_item	2953776	et	4	main
punamütsike	doc_973441205359_item	2953777	et	4	main
külas	doc_973441205359_item	2953788	et	3	main
oli	doc_973441205359_item	2953654	et	3	main
väga	doc_973441205359_item	2953655	et	3	main
armastas	doc_973441205359_item	2953658	et	3	main
üks	doc_973441205359_item	2953666	et	3	main
ema	doc_973441205359_item	2953668	et	4	main
õmbles	doc_973441205359_item	2953669	et	3	main
tüdrukule	doc_973441205359_item	2953670	et	3	main
punase	doc_973441205359_item	2953671	et	4	main
mütsi	doc_973441205359_item	2953677	et	4	main
tema	doc_973441205359_item	2953682	et	4	main
punamütsike	doc_973441205359_item	2953688	et	4	main
üks	doc_973441205359_item	2953689	et	3	main
kord	doc_973441205359_item	2953690	et	4	main
nende	doc_973441205359_item	2953697	et	4	main
vanaema	doc_973441205359_item	2953698	et	4	main
vanaema	doc_973441205359_item	2953701	et	4	main
punamütsikest	doc_973441205359_item	2953714	et	4	main
ja	doc_973441205359_item	2953715	et	3	main
ütles	doc_973441205359_item	2953716	et	3	main
kallis	doc_973441205359_item	2953717	et	4	main
ja	doc_973441205359_item	2953719	et	3	main
ja	doc_973441205359_item	2953723	et	3	main
vanaemale	doc_973441205359_item	2953725	et	3	main
pani	doc_973441205359_item	2953731	et	4	main
oma	doc_973441205359_item	2953732	et	4	main
läbi	doc_973441205359_item	2953743	et	4	main
metsast	doc_973441205359_item	2953751	et	4	main
haige	doc_973441205359_item	2953768	et	4	main
tema	doc_973441205359_item	2953784	et	4	main
teises	doc_973441205359_item	2953787	et	4	main
ja	doc_973441205359_item	2953806	et	3	main
ukse	doc_973441205359_item	2953821	et	3	main
lahti	doc_973441205359_item	2953823	et	4	main
pärast	doc_973441205359_item	2953835	et	4	main
olen	doc_973441205359_item	2953852	et	3	main
küpsetas	doc_973441205359_item	2953862	et	3	main
neid	doc_973441205359_item	2953867	et	4	main
hea	doc_973441205359_item	2953869	et	4	main
tule	doc_973441205359_item	2953871	et	4	main
tuppa	doc_973441205359_item	2953872	et	3	main
suured	doc_973441205359_item	2953899	et	3	main
väga	doc_973441205360_item	2953904	et	3	main
väike	doc_973441205360_item	2953908	et	4	main
elasi	doc_973441205360_item	2953911	et	4	main
puumajas	doc_973441205360_item	2953915	et	3	main
ilus	doc_973441205360_item	2953919	et	4	main
armastad	doc_973441205360_item	2953928	et	3	main
õmbles	doc_973441205360_item	2953931	et	3	main
teda	doc_973441205360_item	2953942	et	4	main
väga	doc_973441205360_item	2953943	et	3	main
kord	doc_973441205360_item	2953946	et	4	main
söömine	doc_973441205360_item	2953957	et	4	main
vanaema	doc_973441205360_item	2953969	et	4	main
maal	doc_973441205360_item	2953972	et	4	main
ta	doc_973441205360_item	2953983	et	4	main
suur	doc_973441205360_item	2953985	et	3	main
lilled	doc_973441205360_item	2954022	et	3	main
hea	doc_973441205360_item	2954025	et	4	main
tean	doc_973441205360_item	2954032	et	3	main
nägemiseni	doc_973441205360_item	2954038	et	4	main
ütles	doc_973441205360_item	2954039	et	3	main
hunt	doc_973441205360_item	2954040	et	3	main
ja	doc_973441205360_item	2954041	et	3	main
aja	doc_973441205360_item	2954045	et	4	main
parast	doc_973441205360_item	2954046	et	3	main
hunt	doc_973441205360_item	2954047	et	3	main
juba	doc_973441205360_item	2954048	et	3	main
vanaema	doc_973441205360_item	2954049	et	4	main
juures	doc_973441205360_item	2954050	et	4	main
koputas	doc_973441205360_item	2954052	et	3	main
punamüstike	doc_973441205360_item	2954063	et	4	main
peenikese	doc_973441205360_item	2954066	et	4	main
häälega	doc_973441205360_item	2954067	et	3	main
ema	doc_973441205360_item	2954068	et	4	main
saatis	doc_973441205360_item	2954069	et	3	main
sulle	doc_973441205360_item	2954070	et	3	main
kooki	doc_973441205360_item	2954071	et	4	main
ja	doc_973441205360_item	2954072	et	3	main
tuleb	doc_973441205360_item	2954079	et	3	main
nägi	doc_973441205360_item	2954081	et	3	main
vanaema	doc_973441205360_item	2954120	et	4	main
et	doc_973441205360_item	2954125	et	3	main
ema	doc_973441205359_item	2953712	et	4	main
viima	doc_973441205359_item	2953720	et	3	main
hea	doc_973441205359_item	2953726	et	4	main
vastas	doc_973441205359_item	2953728	et	4	main
punamütsike	doc_973441205359_item	2953729	et	4	main
puna	doc_973441205359_item	2953733	et	4	main
ja	doc_973441205359_item	2953736	et	3	main
vanaema	doc_973441205359_item	2953738	et	4	main
juurde	doc_973441205359_item	2953739	et	4	main
tee	doc_973441205359_item	2953740	et	4	main
läks	doc_973441205359_item	2953741	et	3	main
metsas	doc_973441205359_item	2953742	et	3	main
oled	doc_973441205359_item	2953767	et	3	main
talle	doc_973441205359_item	2953771	et	4	main
kookid	doc_973441205359_item	2953772	et	4	main
ja	doc_973441205359_item	2953773	et	3	main
pudel	doc_973441205359_item	2953774	et	3	main
ta	doc_973441205359_item	2953780	et	4	main
elab	doc_973441205359_item	2953781	et	3	main
väga	doc_973441205359_item	2953782	et	3	main
asub	doc_973441205359_item	2953786	et	3	main
ja	doc_973441205359_item	2953831	et	3	main
ta	doc_973441205359_item	2953844	et	4	main
tuli	doc_973441205359_item	2953845	et	4	main
ja	doc_973441205359_item	2953846	et	3	main
koputas	doc_973441205359_item	2953847	et	3	main
koogid	doc_973441205359_item	2953863	et	4	main
ja	doc_973441205359_item	2953864	et	3	main
silmad	doc_973441205359_item	2953896	et	4	main
ja	doc_973441205359_item	2953897	et	3	main
kõrvad	doc_973441205359_item	2953898	et	3	main
punamütsike	doc_973441205360_item	2953903	et	4	main
elas	doc_973441205360_item	2953907	et	3	main
ta	doc_973441205360_item	2953910	et	4	main
koos	doc_973441205360_item	2953912	et	4	main
tal	doc_973441205360_item	2953920	et	3	main
teda	doc_973441205360_item	2953929	et	4	main
hakkad	doc_973441205360_item	2953937	et	3	main
kutsuma	doc_973441205360_item	2953938	et	3	main
punamütsike	doc_973441205360_item	2953939	et	4	main
see	doc_973441205360_item	2953940	et	3	main
mutsi	doc_973441205360_item	2953941	et	4	main
soovima	doc_973441205360_item	2953954	et	4	main
viima	doc_973441205360_item	2953955	et	3	main
temale	doc_973441205360_item	2953956	et	3	main
pirukad	doc_973441205360_item	2953962	et	3	main
korvisse	doc_973441205360_item	2953965	et	3	main
punamütsike	doc_973441205360_item	2953966	et	4	main
läks	doc_973441205360_item	2953967	et	3	main
vanaemale	doc_973441205360_item	2953968	et	3	main
teise	doc_973441205360_item	2953971	et	4	main
korvi	doc_973441205360_item	2953978	et	4	main
ja	doc_973441205360_item	2953979	et	3	main
meetsas	doc_973441205360_item	2953981	et	4	main
näljane	doc_973441205360_item	2953990	et	4	main
ja	doc_973441205360_item	2953991	et	3	main
korjama	doc_973441205360_item	2954021	et	3	main
lilli	doc_973441205360_item	2954030	et	4	main
vanaemad	doc_973441205360_item	2954035	et	3	main
tääl	doc_973441205360_item	2954056	et	4	main
vanaema	doc_973441205360_item	2954059	et	4	main
on	doc_973441205360_item	2954061	et	4	main
tuppa	doc_973441205360_item	2954075	et	3	main
juurde	doc_973441205360_item	2954121	et	4	main
sul	doc_973441205360_item	2954133	et	3	main
nii	doc_973441205360_item	2954134	et	3	main
on	doc_973441205360_item	2954137	et	4	main
on	doc_973441205360_item	2954139	et	4	main
utles	doc_973441205360_item	2954145	et	4	main
hunt	doc_973441205360_item	2954146	et	3	main
vanaema	doc_973441205360_item	2954147	et	4	main
selleks	doc_973441205360_item	2954156	et	4	main
selleks	doc_973441205360_item	2954184	et	4	main
et	doc_973441205360_item	2954185	et	3	main
suured	doc_973441205360_item	2954193	et	3	main
see	doc_973441205360_item	2954196	et	3	main
punamütsike	doc_973441205361_item	2954199	et	4	main
ükskord	doc_973441205361_item	2954200	et	3	main
korv	doc_973441205359_item	2953721	et	3	main
mahlaga	doc_973441205359_item	2953724	et	3	main
küll	doc_973441205359_item	2953727	et	4	main
pähe	doc_973441205359_item	2953735	et	4	main
välja	doc_973441205359_item	2953752	et	4	main
jooksma	doc_973441205359_item	2953753	et	3	main
hunt	doc_973441205359_item	2953754	et	3	main
tere	doc_973441205359_item	2953755	et	3	main
punamütsike	doc_973441205359_item	2953756	et	4	main
kuhu	doc_973441205359_item	2953757	et	3	main
sa	doc_973441205359_item	2953758	et	3	main
lähed	doc_973441205359_item	2953759	et	3	main
küsis	doc_973441205359_item	2953760	et	3	main
hunt	doc_973441205359_item	2953761	et	3	main
ma	doc_973441205359_item	2953762	et	3	main
lähen	doc_973441205359_item	2953763	et	3	main
ma	doc_973441205359_item	2953769	et	3	main
viin	doc_973441205359_item	2953770	et	4	main
kui	doc_973441205359_item	2953778	et	3	main
kaugel	doc_973441205359_item	2953779	et	4	main
maja	doc_973441205359_item	2953785	et	4	main
taga	doc_973441205359_item	2953790	et	4	main
hästi	doc_973441205359_item	2953791	et	3	main
ütles	doc_973441205359_item	2953792	et	3	main
hunt	doc_973441205359_item	2953793	et	3	main
ja	doc_973441205359_item	2953794	et	3	main
jooksib	doc_973441205359_item	2953795	et	4	main
metsas	doc_973441205359_item	2953796	et	3	main
hunt	doc_973441205359_item	2953797	et	3	main
koht	doc_973441205359_item	2953798	et	3	main
oli	doc_973441205359_item	2953799	et	3	main
väga	doc_973441205359_item	2953800	et	3	main
tuhi	doc_973441205359_item	2953801	et	4	main
ta	doc_973441205359_item	2953802	et	4	main
tahtis	doc_973441205359_item	2953803	et	3	main
süüa	doc_973441205359_item	2953804	et	3	main
punamütsikese	doc_973441205359_item	2953805	et	4	main
vanaema	doc_973441205359_item	2953807	et	4	main
hunt	doc_973441205359_item	2953808	et	3	main
kiiresti	doc_973441205359_item	2953810	et	3	main
jooksib	doc_973441205359_item	2953809	et	4	main
metsas	doc_973441205359_item	2953811	et	3	main
läbi	doc_973441205359_item	2953812	et	4	main
külasse	doc_973441205359_item	2953813	et	3	main
ta	doc_973441205359_item	2953814	et	4	main
oli	doc_973441205359_item	2953815	et	3	main
vanaema	doc_973441205359_item	2953816	et	4	main
maja	doc_973441205359_item	2953817	et	4	main
juures	doc_973441205359_item	2953818	et	4	main
ning	doc_973441205359_item	2953819	et	3	main
koputas	doc_973441205359_item	2953820	et	3	main
ja	doc_973441205359_item	2953824	et	3	main
läks	doc_973441205359_item	2953826	et	3	main
nägi	doc_973441205359_item	2953829	et	3	main
süüa	doc_973441205359_item	2953834	et	3	main
voodisse	doc_973441205359_item	2953838	et	3	main
uksele	doc_973441205359_item	2953848	et	3	main
mina	doc_973441205359_item	2953853	et	4	main
vastas	doc_973441205359_item	2953855	et	4	main
tüdruk	doc_973441205359_item	2953856	et	3	main
ma	doc_973441205359_item	2953857	et	3	main
tulen	doc_973441205359_item	2953858	et	3	main
sind	doc_973441205359_item	2953859	et	4	main
vaatama	doc_973441205359_item	2953860	et	3	main
tuua	doc_973441205359_item	2953866	et	3	main
ütles	doc_973441205359_item	2953873	et	3	main
hunt	doc_973441205359_item	2953874	et	3	main
peenikese	doc_973441205359_item	2953875	et	4	main
häälega	doc_973441205359_item	2953876	et	3	main
punamütsike	doc_973441205359_item	2953877	et	4	main
astus	doc_973441205359_item	2953878	et	3	main
tuppa	doc_973441205359_item	2953879	et	3	main
ning	doc_973441205359_item	2953880	et	3	main
nagis	doc_973441205359_item	2953881	et	3	main
vanaema	doc_973441205359_item	2953882	et	4	main
voodis	doc_973441205359_item	2953883	et	3	main
ta	doc_973441205359_item	2953884	et	4	main
tuli	doc_973441205359_item	2953885	et	4	main
voodisse	doc_973441205359_item	2953886	et	3	main
ja	doc_973441205359_item	2953887	et	3	main
istus	doc_973441205359_item	2953888	et	4	main
voodille	doc_973441205359_item	2953889	et	4	main
ta	doc_973441205359_item	2953890	et	4	main
imestas	doc_973441205359_item	2953891	et	3	main
miks	doc_973441205359_item	2953892	et	4	main
vanaemal	doc_973441205359_item	2953893	et	3	main
niisugunesed	doc_973441205359_item	2953894	et	4	main
vanaema	doc_973441205359_item	2953830	et	4	main
ära	doc_973441205359_item	2953833	et	4	main
kopp	doc_973441205359_item	2953849	et	3	main
kopp	doc_973441205359_item	2953850	et	3	main
ema	doc_973441205359_item	2953861	et	4	main
ümberjutustus	doc_973441205360_item	2953902	et	3	main
ammu	doc_973441205360_item	2953906	et	4	main
maal	doc_973441205360_item	2953914	et	4	main
tudruk	doc_973441205360_item	2953916	et	4	main
väga	doc_973441205360_item	2953918	et	3	main
suured	doc_973441205359_item	2953895	et	3	main
hambad	doc_973441205359_item	2953900	et	3	main
väga	doc_973441205360_item	2953905	et	3	main
tudruku	doc_973441205360_item	2953909	et	4	main
emaga	doc_973441205360_item	2953913	et	3	main
olin	doc_973441205360_item	2953917	et	3	main
veel	doc_973441205360_item	2953922	et	4	main
ema	doc_973441205360_item	2953947	et	4	main
punamütsikele	doc_973441205360_item	2953949	et	4	main
vanaema	doc_973441205360_item	2953951	et	4	main
haige	doc_973441205360_item	2953952	et	4	main
ja	doc_973441205360_item	2953953	et	3	main
ja	doc_973441205360_item	2953961	et	3	main
näha	doc_973441205360_item	2953984	et	3	main
vaatas	doc_973441205360_item	2953992	et	3	main
on	doc_973441205360_item	2954024	et	4	main
et	doc_973441205360_item	2954026	et	3	main
korjad	doc_973441205360_item	2954028	et	3	main
vanaemale	doc_973441205360_item	2954029	et	3	main
jooksis	doc_973441205360_item	2954042	et	4	main
metsa	doc_973441205360_item	2954043	et	4	main
natukene	doc_973441205360_item	2954044	et	4	main
mina	doc_973441205360_item	2954062	et	4	main
hunt	doc_973441205360_item	2954078	et	3	main
tuppa	doc_973441205360_item	2954080	et	3	main
nägi	doc_973441205360_item	2954124	et	3	main
käed	doc_973441205360_item	2954128	et	3	main
kusis	doc_973441205360_item	2954130	et	4	main
kaed	doc_973441205360_item	2954136	et	4	main
et	doc_973441205360_item	2954157	et	3	main
paremini	doc_973441205360_item	2954159	et	4	main
see	doc_973441205360_item	2954168	et	3	main
sind	doc_973441205360_item	2954172	et	4	main
kuulda	doc_973441205360_item	2954174	et	4	main
vanaema	doc_973441205360_item	2954175	et	4	main
on	doc_973441205360_item	2954181	et	4	main
see	doc_973441205360_item	2954182	et	3	main
on	doc_973441205360_item	2954183	et	4	main
miks	doc_973441205360_item	2954190	et	4	main
sul	doc_973441205360_item	2954191	et	3	main
nii	doc_973441205360_item	2954192	et	3	main
on	doc_973441205360_item	2954195	et	4	main
ümberjutustus	doc_973441205361_item	2954197	et	3	main
ta	doc_973441205361_item	2954222	et	4	main
metsas	doc_973441205361_item	2954242	et	3	main
läks	doc_973441205361_item	2954245	et	3	main
mõtles	doc_973441205361_item	2954258	et	3	main
vanaema	doc_973441205361_item	2954262	et	4	main
ma	doc_973441205361_item	2954286	et	3	main
on	doc_973441205361_item	2954292	et	4	main
aga	doc_973441205361_item	2954322	et	3	main
ta	doc_973441205361_item	2954337	et	4	main
vanaema	doc_973441205361_item	2954339	et	4	main
jures	doc_973441205361_item	2954341	et	4	main
ja	doc_973441205361_item	2954342	et	3	main
ta	doc_973441205361_item	2954350	et	4	main
olen	doc_973441205361_item	2954358	et	3	main
vastas	doc_973441205361_item	2954361	et	4	main
hunt	doc_973441205361_item	2954362	et	3	main
peenikese	doc_973441205361_item	2954363	et	4	main
häälega	doc_973441205361_item	2954364	et	3	main
läheb	doc_973441205361_item	2954375	et	3	main
ütles	doc_973441205361_item	2954377	et	3	main
vanaema	doc_973441205361_item	2954378	et	4	main
ja	doc_973441205361_item	2954382	et	3	main
sõi	doc_973441205361_item	2954383	et	3	main
ära	doc_973441205361_item	2954385	et	4	main
pärast	doc_973441205361_item	2954386	et	4	main
varsti	doc_973441205361_item	2954394	et	3	main
tüdruk	doc_973441205361_item	2954395	et	3	main
vanaema	doc_973441205361_item	2954402	et	4	main
see	doc_973441205361_item	2954404	et	3	main
vastas	doc_973441205361_item	2954408	et	4	main
tüdruk	doc_973441205361_item	2954409	et	3	main
oli	doc_973441205361_item	2954422	et	3	main
voodis	doc_973441205361_item	2954426	et	3	main
tüdrukut	doc_973441205361_item	2954429	et	3	main
lauale	doc_973441205361_item	2954433	et	4	main
ja	doc_973441205361_item	2954434	et	3	main
istus	doc_973441205361_item	2954443	et	4	main
voodile	doc_973441205361_item	2954444	et	3	main
hundi	doc_973441205361_item	2954445	et	3	main
punase	doc_973441205360_item	2953933	et	4	main
ja	doc_973441205360_item	2953935	et	3	main
kõik	doc_973441205360_item	2953936	et	4	main
üks	doc_973441205360_item	2953945	et	3	main
ütles	doc_973441205360_item	2953948	et	3	main
ema	doc_973441205360_item	2953958	et	4	main
küpsetas	doc_973441205360_item	2953959	et	3	main
kooki	doc_973441205360_item	2953960	et	4	main
punamütsike	doc_973441205360_item	2953976	et	4	main
võttis	doc_973441205360_item	2953977	et	3	main
näljaste	doc_973441205360_item	2953993	et	4	main
silmadega	doc_973441205360_item	2953994	et	3	main
punamutsikest	doc_973441205360_item	2953995	et	4	main
tere	doc_973441205360_item	2953996	et	3	main
punamustike	doc_973441205360_item	2953997	et	4	main
tere	doc_973441205360_item	2953998	et	3	main
hunt	doc_973441205360_item	2953999	et	3	main
kuhu	doc_973441205360_item	2954000	et	3	main
sa	doc_973441205360_item	2954001	et	3	main
lähed	doc_973441205360_item	2954002	et	3	main
ma	doc_973441205360_item	2954003	et	3	main
lähen	doc_973441205360_item	2954004	et	3	main
vanaemale	doc_973441205360_item	2954005	et	3	main
mis	doc_973441205360_item	2954006	et	4	main
temaga	doc_973441205360_item	2954007	et	3	main
ta	doc_973441205360_item	2954009	et	4	main
juhtuma	doc_973441205360_item	2954008	et	4	main
on	doc_973441205360_item	2954010	et	4	main
haige	doc_973441205360_item	2954011	et	4	main
sa	doc_973441205360_item	2954012	et	3	main
hea	doc_973441205360_item	2954013	et	4	main
tudruk	doc_973441205360_item	2954014	et	4	main
oled	doc_973441205360_item	2954015	et	3	main
ma	doc_973441205360_item	2954016	et	3	main
mõlten	doc_973441205360_item	2954017	et	4	main
et	doc_973441205360_item	2954018	et	3	main
ma	doc_973441205360_item	2954019	et	3	main
pean	doc_973441205360_item	2954020	et	4	main
see	doc_973441205360_item	2954023	et	3	main
ma	doc_973441205360_item	2954031	et	3	main
et	doc_973441205360_item	2954033	et	3	main
hunt	doc_973441205360_item	2954051	et	3	main
kopp-kopp	doc_973441205360_item	2954054	et	3	main
kes	doc_973441205360_item	2954055	et	4	main
ütles	doc_973441205360_item	2954064	et	3	main
hunt	doc_973441205360_item	2954065	et	3	main
tulen	doc_973441205360_item	2954074	et	3	main
vanaema	doc_973441205360_item	2954077	et	4	main
vanaema	doc_973441205360_item	2954082	et	4	main
ära	doc_973441205360_item	2954084	et	4	main
ja	doc_973441205360_item	2954123	et	3	main
vanaemale	doc_973441205360_item	2954126	et	3	main
miks	doc_973441205360_item	2954132	et	4	main
on	doc_973441205360_item	2954153	et	4	main
väga	doc_973441205360_item	2953927	et	3	main
ema	doc_973441205360_item	2953930	et	4	main
tudruk	doc_973441205360_item	2953932	et	4	main
mutsi	doc_973441205360_item	2953934	et	4	main
meeldis	doc_973441205360_item	2953944	et	3	main
et	doc_973441205360_item	2953950	et	3	main
pani	doc_973441205360_item	2953963	et	4	main
kõik	doc_973441205360_item	2953964	et	4	main
elas	doc_973441205360_item	2953970	et	3	main
väike	doc_973441205360_item	2953973	et	4	main
roohelises	doc_973441205360_item	2953974	et	4	main
majas	doc_973441205360_item	2953975	et	3	main
laks	doc_973441205360_item	2953980	et	4	main
äkki	doc_973441205360_item	2953982	et	3	main
halli	doc_973441205360_item	2953986	et	4	main
hunti	doc_973441205360_item	2953987	et	4	main
hunt	doc_973441205360_item	2953988	et	3	main
oli	doc_973441205360_item	2953989	et	3	main
sa	doc_973441205360_item	2954027	et	3	main
kõik	doc_973441205360_item	2954034	et	4	main
armastavad	doc_973441205360_item	2954036	et	4	main
lilli	doc_973441205360_item	2954037	et	4	main
uksele	doc_973441205360_item	2954053	et	3	main
on	doc_973441205360_item	2954057	et	4	main
kusis	doc_973441205360_item	2954058	et	4	main
see	doc_973441205360_item	2954060	et	3	main
pirukad	doc_973441205360_item	2954073	et	3	main
ütles	doc_973441205360_item	2954076	et	3	main
ja	doc_973441205360_item	2954083	et	3	main
sõi	doc_973441205360_item	2954085	et	3	main
vanaema	doc_973441205360_item	2954086	et	4	main
hunt	doc_973441205360_item	2954087	et	3	main
voodisse	doc_973441205360_item	2954088	et	3	main
heitis	doc_973441205360_item	2954089	et	3	main
ja	doc_973441205360_item	2954090	et	3	main
magusasti	doc_973441205360_item	2954091	et	4	main
magama	doc_973441205360_item	2954092	et	3	main
jääma	doc_973441205360_item	2954093	et	4	main
lähemal	doc_973441205360_item	2954094	et	4	main
ajal	doc_973441205360_item	2954095	et	4	main
tuleb	doc_973441205360_item	2954096	et	3	main
punamüstike	doc_973441205360_item	2954097	et	4	main
ja	doc_973441205360_item	2954098	et	3	main
koputas	doc_973441205360_item	2954099	et	3	main
uksele	doc_973441205360_item	2954100	et	3	main
kopp-kopp	doc_973441205360_item	2954101	et	3	main
kes	doc_973441205360_item	2954102	et	4	main
tääl	doc_973441205360_item	2954103	et	4	main
on	doc_973441205360_item	2954104	et	4	main
küsib	doc_973441205360_item	2954105	et	3	main
hunt	doc_973441205360_item	2954106	et	3	main
see	doc_973441205360_item	2954107	et	3	main
olen	doc_973441205360_item	2954108	et	3	main
mina	doc_973441205360_item	2954109	et	4	main
punamütsike	doc_973441205360_item	2954110	et	4	main
vastas	doc_973441205360_item	2954111	et	4	main
tudruku	doc_973441205360_item	2954112	et	4	main
tulen	doc_973441205360_item	2954113	et	3	main
minule	doc_973441205360_item	2954114	et	3	main
rääkis	doc_973441205360_item	2954115	et	3	main
hunt	doc_973441205360_item	2954116	et	3	main
vanaema	doc_973441205360_item	2954117	et	4	main
häälega	doc_973441205360_item	2954118	et	3	main
punamüstike	doc_973441205360_item	2954119	et	4	main
astuma	doc_973441205360_item	2954122	et	3	main
ta	doc_973441205360_item	2954129	et	4	main
sind	doc_973441205360_item	2954142	et	4	main
paremini	doc_973441205360_item	2954143	et	4	main
kallistama	doc_973441205360_item	2954144	et	3	main
see	doc_973441205360_item	2954154	et	3	main
sind	doc_973441205360_item	2954158	et	4	main
joosta	doc_973441205360_item	2954160	et	4	main
vanaema	doc_973441205360_item	2954161	et	4	main
et	doc_973441205360_item	2954171	et	3	main
sul	doc_973441205360_item	2954177	et	3	main
sind	doc_973441205360_item	2954186	et	4	main
väike	doc_973441205361_item	2954204	et	4	main
tüdruk	doc_973441205361_item	2954205	et	3	main
ta	doc_973441205361_item	2954206	et	4	main
nimi	doc_973441205361_item	2954207	et	3	main
oli	doc_973441205361_item	2954208	et	3	main
punamütsike	doc_973441205361_item	2954209	et	4	main
ta	doc_973441205361_item	2954210	et	4	main
elas	doc_973441205361_item	2954211	et	3	main
koos	doc_973441205361_item	2954212	et	4	main
emaga	doc_973441205361_item	2954213	et	3	main
ükskord	doc_973441205361_item	2954214	et	3	main
ema	doc_973441205361_item	2954215	et	4	main
küpsetas	doc_973441205361_item	2954216	et	3	main
kooki	doc_973441205361_item	2954217	et	4	main
ja	doc_973441205361_item	2954218	et	3	main
rääkis	doc_973441205361_item	2954219	et	3	main
punamütsikele	doc_973441205361_item	2954220	et	4	main
puteli	doc_973441205361_item	2954229	et	4	main
mahla	doc_973441205361_item	2954230	et	4	main
vii	doc_973441205361_item	2954231	et	4	main
kätte	doc_973441205361_item	2954235	et	4	main
vanaema	doc_973441205361_item	2954238	et	4	main
elas	doc_973441205361_item	2954239	et	3	main
teises	doc_973441205361_item	2954240	et	4	main
külas	doc_973441205361_item	2954241	et	3	main
läbi	doc_973441205361_item	2954247	et	4	main
ilm	doc_973441205361_item	2954248	et	3	main
oli	doc_973441205361_item	2954249	et	3	main
väga	doc_973441205361_item	2954250	et	3	main
ilus	doc_973441205361_item	2954251	et	4	main
päike	doc_973441205361_item	2954252	et	3	main
paistis	doc_973441205361_item	2954253	et	3	main
tüdruk	doc_973441205361_item	2954257	et	3	main
hea	doc_973441205361_item	2954261	et	4	main
jaoks	doc_973441205361_item	2954263	et	4	main
lilled	doc_973441205361_item	2954264	et	3	main
korjama	doc_973441205361_item	2954265	et	3	main
ta	doc_973441205361_item	2954266	et	4	main
hall	doc_973441205361_item	2954279	et	4	main
sa	doc_973441205361_item	2954284	et	3	main
vanaema	doc_973441205361_item	2954289	et	4	main
haige	doc_973441205361_item	2954293	et	4	main
rääkis	doc_973441205361_item	2954294	et	3	main
kus	doc_973441205361_item	2954296	et	3	main
vanaema	doc_973441205361_item	2954299	et	4	main
suur	doc_973441205360_item	2954127	et	3	main
vanaema	doc_973441205360_item	2954131	et	4	main
suured	doc_973441205360_item	2954135	et	3	main
see	doc_973441205360_item	2954138	et	3	main
selleks	doc_973441205360_item	2954140	et	4	main
et	doc_973441205360_item	2954141	et	3	main
miks	doc_973441205360_item	2954148	et	4	main
sul	doc_973441205360_item	2954149	et	3	main
nii	doc_973441205360_item	2954150	et	3	main
suured	doc_973441205360_item	2954151	et	3	main
jalad	doc_973441205360_item	2954152	et	3	main
on	doc_973441205360_item	2954155	et	4	main
miks	doc_973441205360_item	2954162	et	4	main
sul	doc_973441205360_item	2954163	et	3	main
nii	doc_973441205360_item	2954164	et	3	main
kõrvad	doc_973441205360_item	2954166	et	3	main
on	doc_973441205360_item	2954169	et	4	main
selleks	doc_973441205360_item	2954170	et	4	main
paremini	doc_973441205360_item	2954173	et	4	main
nii	doc_973441205360_item	2954178	et	3	main
siilmad	doc_973441205360_item	2954180	et	4	main
suu	doc_973441205360_item	2954194	et	4	main
ümberjutustus	doc_973441205361_item	2954198	et	3	main
väikes	doc_973441205361_item	2954201	et	4	main
külas	doc_973441205361_item	2954202	et	3	main
elas	doc_973441205361_item	2954203	et	3	main
et	doc_973441205361_item	2954221	et	3	main
vanaema	doc_973441205361_item	2954224	et	4	main
juurde	doc_973441205361_item	2954225	et	4	main
punamütsike	doc_973441205361_item	2954232	et	4	main
võttis	doc_973441205361_item	2954233	et	3	main
ja	doc_973441205361_item	2954236	et	3	main
läks	doc_973441205361_item	2954237	et	3	main
punamütsike	doc_973441205361_item	2954244	et	4	main
linnud	doc_973441205361_item	2954255	et	3	main
oliks	doc_973441205361_item	2954260	et	4	main
juurde	doc_973441205361_item	2954277	et	4	main
suur	doc_973441205361_item	2954278	et	3	main
ütles	doc_973441205361_item	2954282	et	3	main
oma	doc_973441205361_item	2954288	et	4	main
sinu	doc_973441205361_item	2954298	et	3	main
hunt	doc_973441205361_item	2954301	et	3	main
elab	doc_973441205361_item	2954303	et	3	main
ääres	doc_973441205361_item	2954306	et	4	main
kus	doc_973441205361_item	2954334	et	3	main
maja	doc_973441205361_item	2954340	et	4	main
lamas	doc_973441205361_item	2954355	et	3	main
punamütsike	doc_973441205361_item	2954360	et	4	main
sulle	doc_973441205361_item	2954367	et	3	main
ja	doc_973441205361_item	2954369	et	3	main
uks	doc_973441205361_item	2954374	et	3	main
tuli	doc_973441205361_item	2954380	et	4	main
ootama	doc_973441205361_item	2954392	et	3	main
tuli	doc_973441205361_item	2954396	et	4	main
kes	doc_973441205361_item	2954397	et	4	main
seal	doc_973441205361_item	2954398	et	4	main
linki	doc_973441205361_item	2954411	et	4	main
suured	doc_973441205360_item	2954165	et	3	main
on	doc_973441205360_item	2954167	et	4	main
miks	doc_973441205360_item	2954176	et	4	main
suured	doc_973441205360_item	2954179	et	3	main
paremini	doc_973441205360_item	2954187	et	4	main
näha	doc_973441205360_item	2954188	et	3	main
vanaema	doc_973441205360_item	2954189	et	4	main
läheks	doc_973441205361_item	2954223	et	3	main
ning	doc_973441205361_item	2954226	et	3	main
kooki	doc_973441205361_item	2954227	et	4	main
ja	doc_973441205361_item	2954228	et	3	main
ja	doc_973441205361_item	2954254	et	3	main
pani	doc_973441205361_item	2954267	et	4	main
tema	doc_973441205361_item	2954276	et	4	main
ja	doc_973441205361_item	2954281	et	3	main
punamütsike	doc_973441205361_item	2954295	et	4	main
külas	doc_973441205361_item	2954304	et	3	main
metsa	doc_973441205361_item	2954321	et	4	main
tuli	doc_973441205361_item	2954332	et	4	main
külale	doc_973441205361_item	2954333	et	3	main
elas	doc_973441205361_item	2954335	et	3	main
on	doc_973441205361_item	2954347	et	4	main
küsis	doc_973441205361_item	2954348	et	3	main
vanaema	doc_973441205361_item	2954349	et	4	main
voodis	doc_973441205361_item	2954356	et	3	main
mahla	doc_973441205361_item	2954370	et	4	main
vajuta	doc_973441205361_item	2954371	et	4	main
majja	doc_973441205361_item	2954381	et	3	main
punamütsikest	doc_973441205361_item	2954393	et	4	main
häälega	doc_973441205361_item	2954403	et	3	main
ta	doc_973441205361_item	2954424	et	4	main
ja	doc_973441205361_item	2954427	et	3	main
oma	doc_973441205361_item	2954431	et	4	main
korvi	doc_973441205361_item	2954432	et	4	main
ümberjutustus	doc_973441205362_item	2954452	et	3	main
väike	doc_973441205362_item	2954458	et	4	main
punamütsike	doc_973441205362_item	2954463	et	4	main
sest	doc_973441205362_item	2954468	et	4	main
temale	doc_973441205362_item	2954479	et	3	main
tüdrukule	doc_973441205362_item	2954481	et	3	main
meldis	doc_973441205362_item	2954483	et	3	main
kokki	doc_973441205362_item	2954496	et	4	main
elab	doc_973441205362_item	2954508	et	3	main
oma	doc_973441205362_item	2954511	et	4	main
korvi	doc_973441205362_item	2954516	et	4	main
ja	doc_973441205362_item	2954520	et	3	main
teises	doc_973441205362_item	2954524	et	4	main
metsa	doc_973441205362_item	2954532	et	4	main
ilus	doc_973441205362_item	2954536	et	4	main
tee	doc_973441205362_item	2954542	et	4	main
kasvasid	doc_973441205362_item	2954544	et	4	main
ilus	doc_973441205362_item	2954545	et	4	main
lilled	doc_973441205362_item	2954546	et	3	main
lilli	doc_973441205362_item	2954556	et	4	main
korjama	doc_973441205362_item	2954559	et	3	main
akki	doc_973441205362_item	2954561	et	4	main
tema	doc_973441205362_item	2954562	et	4	main
kuhu	doc_973441205362_item	2954576	et	3	main
ta	doc_973441205362_item	2954577	et	4	main
vanaema	doc_973441205362_item	2954632	et	4	main
voodis	doc_973441205362_item	2954634	et	3	main
oli	doc_973441205362_item	2954636	et	3	main
haige	doc_973441205362_item	2954637	et	4	main
hunt	doc_973441205362_item	2954638	et	3	main
alla	doc_973441205362_item	2954640	et	3	main
vanaema	doc_973441205362_item	2954641	et	4	main
ta	doc_973441205362_item	2954646	et	4	main
ta	doc_973441205362_item	2954651	et	4	main
kõrval	doc_973441205362_item	2954654	et	4	main
koputas	doc_973441205362_item	2954656	et	3	main
ja	doc_973441205362_item	2954657	et	3	main
tuppa	doc_973441205362_item	2954658	et	3	main
mahla	doc_973441205362_item	2954672	et	4	main
ja	doc_973441205362_item	2954673	et	3	main
ütles	doc_973441205362_item	2954680	et	3	main
lauale	doc_973441205362_item	2954683	et	4	main
tule	doc_973441205362_item	2954685	et	4	main
minu	doc_973441205362_item	2954686	et	3	main
juurde	doc_973441205362_item	2954687	et	4	main
hunt	doc_973441205362_item	2954688	et	3	main
ka	doc_973441205362_item	2954689	et	3	main
neelas	doc_973441205362_item	2954690	et	3	main
korvi	doc_973441205361_item	2954234	et	4	main
ääres	doc_973441205361_item	2954243	et	4	main
metsast	doc_973441205361_item	2954246	et	4	main
laulsid	doc_973441205361_item	2954256	et	4	main
et	doc_973441205361_item	2954259	et	3	main
korvi	doc_973441205361_item	2954268	et	4	main
maale	doc_973441205361_item	2954269	et	4	main
ja	doc_973441205361_item	2954270	et	3	main
hakkas	doc_973441205361_item	2954271	et	3	main
buketti	doc_973441205361_item	2954272	et	4	main
korjama	doc_973441205361_item	2954273	et	3	main
äkki	doc_973441205361_item	2954274	et	3	main
tuli	doc_973441205361_item	2954275	et	4	main
hunt	doc_973441205361_item	2954280	et	3	main
kuhu	doc_973441205361_item	2954283	et	3	main
lähed	doc_973441205361_item	2954285	et	3	main
lähen	doc_973441205361_item	2954287	et	3	main
juurde	doc_973441205361_item	2954290	et	4	main
ta	doc_973441205361_item	2954291	et	4	main
elab	doc_973441205361_item	2954297	et	3	main
küsis	doc_973441205361_item	2954300	et	3	main
ta	doc_973441205361_item	2954302	et	4	main
metsas	doc_973441205361_item	2954305	et	3	main
rohelises	doc_973441205361_item	2954307	et	4	main
majas	doc_973441205361_item	2954308	et	3	main
ütles	doc_973441205361_item	2954309	et	3	main
tüdruk	doc_973441205361_item	2954310	et	3	main
sa	doc_973441205361_item	2954311	et	3	main
oled	doc_973441205361_item	2954312	et	3	main
väga	doc_973441205361_item	2954313	et	3	main
hea	doc_973441205361_item	2954314	et	4	main
tüdruk	doc_973441205361_item	2954315	et	3	main
nägemiseni	doc_973441205361_item	2954316	et	4	main
ütles	doc_973441205361_item	2954317	et	3	main
hunt	doc_973441205361_item	2954318	et	3	main
ning	doc_973441205361_item	2954319	et	3	main
jooksis	doc_973441205361_item	2954320	et	4	main
punamütsike	doc_973441205361_item	2954323	et	4	main
korjas	doc_973441205361_item	2954324	et	3	main
edasi	doc_973441205361_item	2954328	et	3	main
sel	doc_973441205361_item	2954329	et	3	main
vanaema	doc_973441205361_item	2954336	et	4	main
oli	doc_973441205361_item	2954338	et	3	main
seal	doc_973441205361_item	2954346	et	4	main
ja	doc_973441205361_item	2954354	et	3	main
see	doc_973441205361_item	2954357	et	3	main
linki	doc_973441205361_item	2954372	et	4	main
vanaema	doc_973441205361_item	2954384	et	4	main
on	doc_973441205361_item	2954399	et	4	main
küsis	doc_973441205361_item	2954400	et	3	main
hunt	doc_973441205361_item	2954401	et	3	main
mina	doc_973441205361_item	2954406	et	4	main
hunt	doc_973441205361_item	2954421	et	3	main
vaatas	doc_973441205361_item	2954428	et	3	main
tule	doc_973441205361_item	2954435	et	4	main
mine	doc_973441205361_item	2954436	et	3	main
juurde	doc_973441205361_item	2954437	et	4	main
ütles	doc_973441205361_item	2954438	et	3	main
hunt	doc_973441205361_item	2954439	et	3	main
punamütsike	doc_973441205361_item	2954440	et	4	main
tuli	doc_973441205361_item	2954441	et	4	main
ja	doc_973441205361_item	2954442	et	3	main
kõik	doc_973441205362_item	2954464	et	4	main
temal	doc_973441205362_item	2954470	et	3	main
väga	doc_973441205362_item	2954472	et	3	main
õmbles	doc_973441205362_item	2954478	et	3	main
väga	doc_973441205362_item	2954482	et	3	main
see	doc_973441205362_item	2954484	et	3	main
kimbu	doc_973441205361_item	2954325	et	3	main
ja	doc_973441205361_item	2954326	et	3	main
läks	doc_973441205361_item	2954327	et	3	main
ajal	doc_973441205361_item	2954330	et	4	main
hunt	doc_973441205361_item	2954331	et	3	main
koputas	doc_973441205361_item	2954343	et	3	main
uksele	doc_973441205361_item	2954344	et	3	main
kes	doc_973441205361_item	2954345	et	4	main
tundis	doc_973441205361_item	2954351	et	3	main
end	doc_973441205361_item	2954352	et	4	main
halvasti	doc_973441205361_item	2954353	et	3	main
mina	doc_973441205361_item	2954359	et	4	main
ema	doc_973441205361_item	2954365	et	4	main
saatis	doc_973441205361_item	2954366	et	3	main
kooki	doc_973441205361_item	2954368	et	4	main
ja	doc_973441205361_item	2954373	et	3	main
lahti	doc_973441205361_item	2954376	et	4	main
hund	doc_973441205361_item	2954379	et	4	main
ta	doc_973441205361_item	2954387	et	4	main
heitis	doc_973441205361_item	2954388	et	3	main
voodisse	doc_973441205361_item	2954389	et	3	main
ning	doc_973441205361_item	2954390	et	3	main
hakkas	doc_973441205361_item	2954391	et	3	main
olen	doc_973441205361_item	2954405	et	3	main
punamütsike	doc_973441205361_item	2954407	et	4	main
vajuta	doc_973441205361_item	2954410	et	4	main
ja	doc_973441205361_item	2954412	et	3	main
uks	doc_973441205361_item	2954413	et	3	main
läheb	doc_973441205361_item	2954414	et	3	main
lahti	doc_973441205361_item	2954415	et	4	main
ütles	doc_973441205361_item	2954416	et	3	main
hunt	doc_973441205361_item	2954417	et	3	main
punamütsike	doc_973441205361_item	2954418	et	4	main
tuli	doc_973441205361_item	2954419	et	4	main
majja	doc_973441205361_item	2954420	et	3	main
toas	doc_973441205361_item	2954423	et	3	main
elas	doc_973441205362_item	2954455	et	3	main
küllas	doc_973441205362_item	2954457	et	3	main
tüdruk	doc_973441205362_item	2954459	et	3	main
teda	doc_973441205362_item	2954466	et	4	main
nii	doc_973441205362_item	2954467	et	3	main
punase	doc_973441205362_item	2954474	et	4	main
mütsike	doc_973441205362_item	2954475	et	4	main
kokkid	doc_973441205362_item	2954489	et	4	main
punamütsikest	doc_973441205362_item	2954492	et	4	main
vaata	doc_973441205362_item	2954505	et	4	main
kuidas	doc_973441205362_item	2954506	et	3	main
pähe	doc_973441205362_item	2954514	et	4	main
võttis	doc_973441205362_item	2954515	et	3	main
mahlaga	doc_973441205362_item	2954519	et	3	main
küllas	doc_973441205362_item	2954525	et	3	main
rohelises	doc_973441205362_item	2954527	et	4	main
tee	doc_973441205362_item	2954529	et	4	main
oli	doc_973441205362_item	2954534	et	3	main
laulsid	doc_973441205362_item	2954540	et	4	main
ja	doc_973441205362_item	2954541	et	3	main
oliks	doc_973441205362_item	2954550	et	4	main
väga	doc_973441205362_item	2954551	et	3	main
hakkas	doc_973441205362_item	2954558	et	3	main
metsast	doc_973441205362_item	2954564	et	4	main
ta	doc_973441205362_item	2954567	et	4	main
oli	doc_973441205362_item	2954568	et	3	main
suur	doc_973441205362_item	2954569	et	3	main
ja	doc_973441205362_item	2954570	et	3	main
hall	doc_973441205362_item	2954571	et	4	main
punamütsikest	doc_973441205362_item	2954575	et	4	main
ta	doc_973441205362_item	2954579	et	4	main
vastas	doc_973441205362_item	2954580	et	4	main
et	doc_973441205362_item	2954581	et	3	main
läheb	doc_973441205362_item	2954582	et	3	main
vanaemale	doc_973441205362_item	2954583	et	3	main
edasi	doc_973441205362_item	2954622	et	3	main
vanaema	doc_973441205362_item	2954625	et	4	main
lamas	doc_973441205361_item	2954425	et	3	main
pane	doc_973441205361_item	2954430	et	4	main
kõrvale	doc_973441205361_item	2954446	et	4	main
tüdruk	doc_973441205361_item	2954447	et	3	main
oli	doc_973441205361_item	2954448	et	3	main
imestanud	doc_973441205361_item	2954449	et	4	main
miks	doc_973441205361_item	2954450	et	4	main
vanaemale	doc_973441205361_item	2954451	et	3	main
ümberjutustus	doc_973441205362_item	2954453	et	3	main
nimetasid	doc_973441205362_item	2954465	et	4	main
et	doc_973441205362_item	2954469	et	3	main
oli	doc_973441205362_item	2954471	et	3	main
ilus	doc_973441205362_item	2954473	et	4	main
seda	doc_973441205362_item	2954476	et	3	main
ema	doc_973441205362_item	2954480	et	4	main
mütsike	doc_973441205362_item	2954485	et	4	main
kupsis	doc_973441205362_item	2954487	et	4	main
ema	doc_973441205362_item	2954488	et	4	main
ütles	doc_973441205362_item	2954494	et	3	main
viia	doc_973441205362_item	2954495	et	3	main
kuulsin	doc_973441205362_item	2954499	et	3	main
mütsikese	doc_973441205362_item	2954513	et	4	main
kokkiga	doc_973441205362_item	2954517	et	4	main
ja	doc_973441205362_item	2954518	et	3	main
punamütsike	doc_973441205362_item	2954454	et	4	main
ühes	doc_973441205362_item	2954456	et	4	main
tema	doc_973441205362_item	2954460	et	4	main
nimi	doc_973441205362_item	2954461	et	3	main
oli	doc_973441205362_item	2954462	et	3	main
mütsi	doc_973441205362_item	2954477	et	4	main
ta	doc_973441205362_item	2954490	et	4	main
ja	doc_973441205362_item	2954493	et	3	main
ma	doc_973441205362_item	2954498	et	3	main
ta	doc_973441205362_item	2954501	et	4	main
on	doc_973441205362_item	2954502	et	4	main
haige	doc_973441205362_item	2954503	et	4	main
mine	doc_973441205362_item	2954504	et	3	main
tüdruk	doc_973441205362_item	2954509	et	3	main
pani	doc_973441205362_item	2954510	et	4	main
puna	doc_973441205362_item	2954512	et	4	main
vanaema	doc_973441205362_item	2954522	et	4	main
laks	doc_973441205362_item	2954530	et	4	main
labi	doc_973441205362_item	2954531	et	4	main
paisis	doc_973441205362_item	2954538	et	3	main
et	doc_973441205362_item	2954549	et	3	main
hea	doc_973441205362_item	2954552	et	4	main
vanaemale	doc_973441205362_item	2954553	et	3	main
kinkida	doc_973441205362_item	2954554	et	3	main
kimbu	doc_973441205362_item	2954555	et	3	main
ilmus	doc_973441205362_item	2954565	et	4	main
hunt	doc_973441205362_item	2954566	et	3	main
et	doc_973441205362_item	2954584	et	3	main
kandib	doc_973441205362_item	2954585	et	3	main
hunt	doc_973441205362_item	2954623	et	3	main
juurde	doc_973441205362_item	2954627	et	4	main
koputas	doc_973441205362_item	2954628	et	3	main
pani	doc_973441205362_item	2954643	et	4	main
värsti	doc_973441205362_item	2954650	et	4	main
sind	doc_973441205362_item	2954666	et	4	main
vaatama	doc_973441205362_item	2954667	et	3	main
ja	doc_973441205362_item	2954668	et	3	main
tõin	doc_973441205362_item	2954669	et	3	main
sinule	doc_973441205362_item	2954670	et	3	main
kokki	doc_973441205362_item	2954671	et	4	main
lamas	doc_973441205362_item	2954677	et	3	main
heidis	doc_973441205362_item	2954694	et	4	main
puuraiujad	doc_973441205362_item	2954702	et	3	main
kuulsid	doc_973441205362_item	2954704	et	4	main
ükskord	doc_973441205362_item	2954486	et	3	main
kutsus	doc_973441205362_item	2954491	et	4	main
vanaemale	doc_973441205362_item	2954497	et	3	main
et	doc_973441205362_item	2954500	et	3	main
vanaema	doc_973441205362_item	2954507	et	4	main
laks	doc_973441205362_item	2954521	et	4	main
majas	doc_973441205362_item	2954528	et	3	main
ilm	doc_973441205362_item	2954533	et	3	main
väga	doc_973441205362_item	2954535	et	3	main
paike	doc_973441205362_item	2954537	et	4	main
ääres	doc_973441205362_item	2954543	et	4	main
ta	doc_973441205362_item	2954557	et	4	main
lilli	doc_973441205362_item	2954560	et	4	main
küsima	doc_973441205362_item	2954574	et	3	main
läheb	doc_973441205362_item	2954578	et	3	main
läks	doc_973441205362_item	2954621	et	3	main
neelas	doc_973441205362_item	2954639	et	3	main
ootama	doc_973441205362_item	2954648	et	3	main
uks	doc_973441205362_item	2954653	et	3	main
vanaema	doc_973441205362_item	2954676	et	4	main
voodis	doc_973441205362_item	2954678	et	3	main
kõik	doc_973441205362_item	2954682	et	4	main
ja	doc_973441205362_item	2954684	et	3	main
koht	doc_973441205362_item	2954697	et	3	main
majas	doc_973441205362_item	2954706	et	3	main
palju	doc_973441205363_item	2954722	et	4	main
tegi	doc_973441205363_item	2954727	et	4	main
talle	doc_973441205363_item	2954728	et	4	main
väike	doc_973441205363_item	2954729	et	4	main
pea	doc_973441205363_item	2954734	et	4	main
kõik	doc_973441205363_item	2954739	et	4	main
vaata	doc_973441205363_item	2954752	et	4	main
ma	doc_973441205363_item	2954756	et	3	main
et	doc_973441205363_item	2954758	et	3	main
ta	doc_973441205363_item	2954773	et	4	main
oma	doc_973441205363_item	2954775	et	4	main
must	doc_973441205363_item	2954777	et	4	main
vanaema	doc_973441205363_item	2954785	et	4	main
elas	doc_973441205363_item	2954786	et	3	main
ilm	doc_973441205363_item	2954793	et	3	main
tee	doc_973441205363_item	2954802	et	4	main
pani	doc_973441205363_item	2954807	et	4	main
lilled	doc_973441205363_item	2954812	et	3	main
ma	doc_973441205363_item	2954831	et	3	main
kas	doc_973441205363_item	2954844	et	3	main
ela	doc_973441205363_item	2954851	et	4	main
kaugel	doc_973441205363_item	2954853	et	4	main
ta	doc_973441205363_item	2954854	et	4	main
elab	doc_973441205363_item	2954855	et	3	main
rohelises	doc_973441205363_item	2954861	et	4	main
majas	doc_973441205363_item	2954862	et	3	main
tuhi	doc_973441205363_item	2954869	et	4	main
punamütsikese	doc_973441205363_item	2954872	et	4	main
ära	doc_973441205363_item	2954873	et	4	main
hästi	doc_973441205363_item	2954885	et	3	main
vanaemale	doc_973441205363_item	2954889	et	3	main
armastasid	doc_973441205363_item	2954896	et	4	main
aeg	doc_973441205363_item	2954906	et	3	main
oli	doc_973441205363_item	2954907	et	3	main
ta	doc_973441205363_item	2954908	et	4	main
juba	doc_973441205363_item	2954909	et	3	main
ta	doc_973441205363_item	2954912	et	4	main
koputas	doc_973441205363_item	2954913	et	3	main
punamütsike	doc_973441205363_item	2954921	et	4	main
vatama	doc_973441205363_item	2954928	et	4	main
kööki	doc_973441205363_item	2954932	et	4	main
vanaema	doc_973441205363_item	2954951	et	4	main
ukse	doc_973441205363_item	2954955	et	3	main
voodisse	doc_973441205363_item	2954957	et	3	main
ja	doc_973441205363_item	2954959	et	3	main
jai	doc_973441205363_item	2954960	et	4	main
punamütsikest	doc_973441205363_item	2954961	et	4	main
ootama	doc_973441205363_item	2954962	et	3	main
punamütsike	doc_973441205363_item	2954987	et	4	main
juurde	doc_973441205363_item	2955000	et	4	main
ta	doc_973441205363_item	2955001	et	4	main
oli	doc_973441205363_item	2955002	et	3	main
väga	doc_973441205363_item	2955003	et	3	main
imestas	doc_973441205363_item	2955004	et	3	main
on	doc_973441205363_item	2955014	et	4	main
sured	doc_973441205363_item	2955015	et	3	main
käid	doc_973441205363_item	2955016	et	3	main
elas	doc_973441205362_item	2954523	et	3	main
vaikes	doc_973441205362_item	2954526	et	4	main
linnud	doc_973441205362_item	2954539	et	3	main
punamütsike	doc_973441205362_item	2954547	et	4	main
mõtles	doc_973441205362_item	2954548	et	3	main
juurde	doc_973441205362_item	2954563	et	4	main
ta	doc_973441205362_item	2954572	et	4	main
hakkas	doc_973441205362_item	2954573	et	3	main
temale	doc_973441205362_item	2954586	et	3	main
kokki	doc_973441205362_item	2954587	et	4	main
natuke	doc_973441205362_item	2954588	et	4	main
mahla	doc_973441205362_item	2954589	et	4	main
ja	doc_973441205362_item	2954590	et	3	main
ilus	doc_973441205362_item	2954591	et	4	main
kimb	doc_973441205362_item	2954592	et	4	main
hunt	doc_973441205362_item	2954593	et	3	main
ütles	doc_973441205362_item	2954594	et	3	main
aga	doc_973441205362_item	2954595	et	3	main
kus	doc_973441205362_item	2954596	et	3	main
elab	doc_973441205362_item	2954597	et	3	main
vanaema	doc_973441205362_item	2954598	et	4	main
kaugel	doc_973441205362_item	2954599	et	4	main
punamütsike	doc_973441205362_item	2954600	et	4	main
vastas	doc_973441205362_item	2954601	et	4	main
et	doc_973441205362_item	2954602	et	3	main
vanaema	doc_973441205362_item	2954603	et	4	main
elab	doc_973441205362_item	2954604	et	3	main
ei	doc_973441205362_item	2954605	et	4	main
kaugel	doc_973441205362_item	2954607	et	4	main
et	doc_973441205362_item	2954608	et	3	main
väga	doc_973441205362_item	2954606	et	3	main
ta	doc_973441205362_item	2954609	et	4	main
elab	doc_973441205362_item	2954610	et	3	main
teises	doc_973441205362_item	2954611	et	4	main
külas	doc_973441205362_item	2954612	et	3	main
metsa	doc_973441205362_item	2954613	et	4	main
kõrval	doc_973441205362_item	2954614	et	4	main
ja	doc_973441205362_item	2954615	et	3	main
hunt	doc_973441205362_item	2954616	et	3	main
ära	doc_973441205362_item	2954617	et	4	main
jooksis	doc_973441205362_item	2954618	et	4	main
metsasse	doc_973441205362_item	2954619	et	4	main
punamütsike	doc_973441205362_item	2954620	et	4	main
maja	doc_973441205362_item	2954626	et	4	main
läheb	doc_973441205362_item	2954624	et	3	main
ja	doc_973441205362_item	2954629	et	3	main
tuppa	doc_973441205362_item	2954630	et	3	main
sisenes	doc_973441205362_item	2954631	et	3	main
ta	doc_973441205362_item	2954635	et	4	main
uks	doc_973441205362_item	2954644	et	3	main
hakkas	doc_973441205362_item	2954647	et	3	main
oli	doc_973441205362_item	2954652	et	3	main
sisenes	doc_973441205362_item	2954659	et	3	main
tere	doc_973441205362_item	2954660	et	3	main
vanaema	doc_973441205362_item	2954661	et	4	main
kuidas	doc_973441205362_item	2954662	et	3	main
kimb	doc_973441205362_item	2954674	et	4	main
ja	doc_973441205362_item	2954679	et	3	main
oli	doc_973441205362_item	2954698	et	3	main
majast	doc_973441205362_item	2954700	et	4	main
möödusid	doc_973441205362_item	2954701	et	4	main
kõvasti	doc_973441205362_item	2954708	et	3	main
keegi	doc_973441205362_item	2954709	et	4	main
norskab	doc_973441205362_item	2954710	et	3	main
ümberjutustus	doc_973441205363_item	2954711	et	3	main
ümberjutustus	doc_973441205363_item	2954712	et	3	main
elas	doc_973441205363_item	2954714	et	3	main
kord	doc_973441205363_item	2954715	et	4	main
punamütsike	doc_973441205363_item	2954713	et	4	main
väike	doc_973441205363_item	2954716	et	4	main
tüdruk	doc_973441205363_item	2954717	et	3	main
ema	doc_973441205363_item	2954718	et	4	main
armastas	doc_973441205363_item	2954719	et	3	main
teda	doc_973441205363_item	2954720	et	4	main
vanaema	doc_973441205363_item	2954723	et	4	main
veel	doc_973441205363_item	2954724	et	4	main
rohkem	doc_973441205363_item	2954725	et	4	main
pani	doc_973441205363_item	2954732	et	4	main
oma	doc_973441205363_item	2954733	et	4	main
ta	doc_973441205363_item	2954748	et	4	main
mine	doc_973441205363_item	2954751	et	3	main
vanaema	doc_973441205363_item	2954754	et	4	main
ja	doc_973441205363_item	2954782	et	3	main
metsa	doc_973441205363_item	2954792	et	4	main
päike	doc_973441205363_item	2954797	et	3	main
linnud	doc_973441205363_item	2954799	et	3	main
hall	doc_973441205363_item	2954819	et	4	main
hünt	doc_973441205363_item	2954820	et	4	main
oli	doc_973441205362_item	2954633	et	3	main
ja	doc_973441205362_item	2954642	et	3	main
kinni	doc_973441205362_item	2954645	et	3	main
punamütsikest	doc_973441205362_item	2954649	et	4	main
ta	doc_973441205362_item	2954655	et	4	main
laheb	doc_973441205362_item	2954663	et	4	main
ma	doc_973441205362_item	2954664	et	3	main
tulen	doc_973441205362_item	2954665	et	3	main
lilli	doc_973441205362_item	2954675	et	4	main
pani	doc_973441205362_item	2954681	et	4	main
magama	doc_973441205362_item	2954695	et	3	main
tema	doc_973441205362_item	2954696	et	4	main
raske	doc_973441205362_item	2954699	et	4	main
väga	doc_973441205363_item	2954721	et	3	main
punamutsikas	doc_973441205363_item	2954730	et	4	main
iga	doc_973441205363_item	2954735	et	4	main
päev	doc_973441205363_item	2954736	et	3	main
üks	doc_973441205363_item	2954743	et	3	main
punamüstikesele	doc_973441205363_item	2954750	et	4	main
kui	doc_973441205363_item	2954753	et	3	main
punast	doc_973441205363_item	2954776	et	4	main
pahe	doc_973441205363_item	2954778	et	4	main
läbi	doc_973441205363_item	2954791	et	4	main
väga	doc_973441205363_item	2954795	et	3	main
lausid	doc_973441205363_item	2954800	et	4	main
tuled	doc_973441205363_item	2954815	et	4	main
ütles	doc_973441205363_item	2954822	et	3	main
lähed	doc_973441205363_item	2954830	et	3	main
vanaema	doc_973441205363_item	2954841	et	4	main
on	doc_973441205363_item	2954842	et	4	main
vaga	doc_973441205363_item	2954852	et	4	main
huntil	doc_973441205363_item	2954865	et	4	main
suua	doc_973441205363_item	2954874	et	4	main
aga	doc_973441205363_item	2954875	et	3	main
sa	doc_973441205363_item	2954887	et	3	main
lilled	doc_973441205363_item	2954890	et	3	main
pärast	doc_973441205363_item	2954904	et	4	main
juures	doc_973441205363_item	2954911	et	4	main
peenikese	doc_973441205363_item	2954924	et	4	main
ja	doc_973441205363_item	2954944	et	3	main
läks	doc_973441205363_item	2954946	et	3	main
natukene	doc_973441205363_item	2954963	et	4	main
aeg	doc_973441205363_item	2954964	et	3	main
lähti	doc_973441205363_item	2954986	et	4	main
ja	doc_973441205363_item	2954990	et	3	main
uks	doc_973441205363_item	2954991	et	3	main
lähti	doc_973441205363_item	2954993	et	4	main
punamütsike	doc_973441205363_item	2954997	et	4	main
kui	doc_973441205363_item	2955005	et	3	main
alla	doc_973441205362_item	2954691	et	3	main
tüdrukut	doc_973441205362_item	2954692	et	3	main
ja	doc_973441205362_item	2954693	et	3	main
nad	doc_973441205362_item	2954703	et	3	main
et	doc_973441205362_item	2954705	et	3	main
väga	doc_973441205362_item	2954707	et	3	main
punamutsike	doc_973441205363_item	2954731	et	4	main
nii	doc_973441205363_item	2954737	et	3	main
hakaski	doc_973441205363_item	2954738	et	4	main
teda	doc_973441205363_item	2954740	et	4	main
kutsusid	doc_973441205363_item	2954742	et	4	main
küpsutas	doc_973441205363_item	2954745	et	4	main
kööki	doc_973441205363_item	2954747	et	4	main
kuulsin	doc_973441205363_item	2954757	et	3	main
pani	doc_973441205363_item	2954774	et	4	main
läks	doc_973441205363_item	2954783	et	3	main
punamütsikele	doc_973441205363_item	2954784	et	4	main
teises	doc_973441205363_item	2954787	et	4	main
külas	doc_973441205363_item	2954788	et	3	main
tee	doc_973441205363_item	2954789	et	4	main
ilusad	doc_973441205363_item	2954796	et	3	main
mahe	doc_973441205363_item	2954809	et	3	main
ja	doc_973441205363_item	2954810	et	3	main
korjama	doc_973441205363_item	2954813	et	3	main
jurde	doc_973441205363_item	2954817	et	4	main
natuke	doc_973441205363_item	2954826	et	4	main
lähen	doc_973441205363_item	2954832	et	3	main
vatama	doc_973441205363_item	2954834	et	4	main
viia	doc_973441205363_item	2954836	et	3	main
vanaema	doc_973441205363_item	2954845	et	4	main
metsa	doc_973441205363_item	2954858	et	4	main
punamütsike	doc_973441205363_item	2954864	et	4	main
tahtis	doc_973441205363_item	2954871	et	3	main
tean	doc_973441205363_item	2954892	et	3	main
natukene	doc_973441205363_item	2954905	et	4	main
mina	doc_973441205363_item	2954920	et	4	main
vanaema	doc_973441205363_item	2954726	et	4	main
punamustikeseks	doc_973441205363_item	2954741	et	4	main
päev	doc_973441205363_item	2954744	et	3	main
ema	doc_973441205363_item	2954746	et	4	main
ütles	doc_973441205363_item	2954749	et	3	main
elab	doc_973441205363_item	2954755	et	3	main
on	doc_973441205363_item	2954760	et	4	main
haige	doc_973441205363_item	2954761	et	4	main
ta	doc_973441205363_item	2954759	et	4	main
vii	doc_973441205363_item	2954762	et	4	main
talle	doc_973441205363_item	2954763	et	4	main
kööki	doc_973441205363_item	2954764	et	4	main
ja	doc_973441205363_item	2954765	et	3	main
pudel	doc_973441205363_item	2954766	et	3	main
mahla	doc_973441205363_item	2954767	et	4	main
hea	doc_973441205363_item	2954768	et	4	main
küll	doc_973441205363_item	2954769	et	4	main
ema	doc_973441205363_item	2954770	et	4	main
ütles	doc_973441205363_item	2954771	et	3	main
punamustike	doc_973441205363_item	2954772	et	4	main
juurde	doc_973441205363_item	2954779	et	4	main
kinni	doc_973441205363_item	2954780	et	3	main
võtma	doc_973441205363_item	2954781	et	3	main
läks	doc_973441205363_item	2954790	et	3	main
oli	doc_973441205363_item	2954794	et	3	main
päistas	doc_973441205363_item	2954798	et	4	main
ja	doc_973441205363_item	2954801	et	3	main
ääres	doc_973441205363_item	2954803	et	4	main
õitsesid	doc_973441205363_item	2954804	et	4	main
lilled	doc_973441205363_item	2954805	et	3	main
punamustikene	doc_973441205363_item	2954806	et	4	main
korvi	doc_973441205363_item	2954808	et	4	main
hakkas	doc_973441205363_item	2954811	et	3	main
äkki	doc_973441205363_item	2954814	et	3	main
talle	doc_973441205363_item	2954816	et	4	main
suur	doc_973441205363_item	2954818	et	3	main
ja	doc_973441205363_item	2954821	et	3	main
tere	doc_973441205363_item	2954823	et	3	main
ajame	doc_973441205363_item	2954825	et	3	main
juttu	doc_973441205363_item	2954827	et	4	main
kuhu	doc_973441205363_item	2954828	et	3	main
sa	doc_973441205363_item	2954829	et	3	main
kööki	doc_973441205363_item	2954838	et	4	main
ja	doc_973441205363_item	2954839	et	3	main
mahla	doc_973441205363_item	2954840	et	4	main
teises	doc_973441205363_item	2954856	et	4	main
külas	doc_973441205363_item	2954857	et	3	main
vastas	doc_973441205363_item	2954863	et	4	main
pärast	doc_973441205363_item	2954876	et	4	main
mõtles	doc_973441205363_item	2954877	et	3	main
umber	doc_973441205363_item	2954878	et	3	main
sa	doc_973441205363_item	2954879	et	3	main
olen	doc_973441205363_item	2954880	et	3	main
ma	doc_973441205363_item	2954891	et	3	main
vanaemad	doc_973441205363_item	2954895	et	3	main
nägemiseni	doc_973441205363_item	2954898	et	4	main
ütles	doc_973441205363_item	2954899	et	3	main
hunt	doc_973441205363_item	2954900	et	3	main
vanaema	doc_973441205363_item	2954910	et	4	main
kopp-kopp	doc_973441205363_item	2954914	et	3	main
kes	doc_973441205363_item	2954915	et	4	main
seal	doc_973441205363_item	2954916	et	4	main
on	doc_973441205363_item	2954917	et	4	main
see	doc_973441205363_item	2954918	et	3	main
olen	doc_973441205363_item	2954919	et	3	main
ütles	doc_973441205363_item	2954922	et	3	main
sulle	doc_973441205363_item	2954927	et	3	main
linki	doc_973441205363_item	2954937	et	4	main
sis	doc_973441205363_item	2954938	et	3	main
uks	doc_973441205363_item	2954939	et	3	main
lähti	doc_973441205363_item	2954940	et	4	main
hunt	doc_973441205363_item	2954941	et	3	main
vajutas	doc_973441205363_item	2954942	et	3	main
uks	doc_973441205363_item	2954945	et	3	main
ta	doc_973441205363_item	2954948	et	4	main
pani	doc_973441205363_item	2954953	et	4	main
ta	doc_973441205363_item	2954956	et	4	main
tuli	doc_973441205363_item	2954966	et	4	main
tuppa	doc_973441205363_item	2954996	et	3	main
lähen	doc_973441205363_item	2954998	et	3	main
vanaema	doc_973441205363_item	2954999	et	4	main
vatama	doc_973441205363_item	2955008	et	4	main
ta	doc_973441205363_item	2955009	et	4	main
on	doc_973441205363_item	2955018	et	4	main
sellepärast	doc_973441205363_item	2955019	et	3	main
et	doc_973441205363_item	2955020	et	3	main
sind	doc_973441205363_item	2955021	et	4	main
miks	doc_973441205363_item	2955025	et	4	main
on	doc_973441205363_item	2955027	et	4	main
see	doc_973441205363_item	2955030	et	3	main
et	doc_973441205363_item	2955033	et	3	main
miks	doc_973441205363_item	2955038	et	4	main
on	doc_973441205363_item	2955040	et	4	main
on	doc_973441205363_item	2955044	et	4	main
sellepärast	doc_973441205363_item	2955045	et	3	main
et	doc_973441205363_item	2955046	et	3	main
sul	doc_973441205363_item	2955052	et	3	main
jaotis	doc_973441205363_item	2955069	et	4	main
magama	doc_973441205363_item	2955070	et	3	main
ja	doc_973441205363_item	2955071	et	3	main
hakkas	doc_973441205363_item	2955072	et	3	main
norskema	doc_973441205363_item	2955073	et	4	main
punamütsike	doc_973441205363_item	2954824	et	4	main
vanaema	doc_973441205363_item	2954833	et	4	main
ema	doc_973441205363_item	2954835	et	4	main
talle	doc_973441205363_item	2954837	et	4	main
häige	doc_973441205363_item	2954843	et	4	main
elas	doc_973441205363_item	2954846	et	3	main
kaugel	doc_973441205363_item	2954847	et	4	main
kusis	doc_973441205363_item	2954848	et	4	main
hunt	doc_973441205363_item	2954849	et	3	main
ei	doc_973441205363_item	2954850	et	4	main
ääres	doc_973441205363_item	2954859	et	4	main
väikeses	doc_973441205363_item	2954860	et	4	main
kõht	doc_973441205363_item	2954866	et	3	main
oli	doc_973441205363_item	2954867	et	3	main
väga	doc_973441205363_item	2954868	et	3	main
ta	doc_973441205363_item	2954870	et	4	main
tupli	doc_973441205363_item	2954881	et	4	main
tüdruk	doc_973441205363_item	2954882	et	3	main
see	doc_973441205363_item	2954883	et	3	main
on	doc_973441205363_item	2954884	et	4	main
et	doc_973441205363_item	2954886	et	3	main
korjasid	doc_973441205363_item	2954888	et	4	main
et	doc_973441205363_item	2954893	et	3	main
kõik	doc_973441205363_item	2954894	et	4	main
lilled	doc_973441205363_item	2954897	et	3	main
ja	doc_973441205363_item	2954901	et	3	main
jooksis	doc_973441205363_item	2954902	et	4	main
metsas	doc_973441205363_item	2954903	et	3	main
hunt	doc_973441205363_item	2954923	et	3	main
mahla	doc_973441205363_item	2954935	et	4	main
vajutama	doc_973441205363_item	2954936	et	4	main
linki	doc_973441205363_item	2954943	et	4	main
hunt	doc_973441205363_item	2954952	et	3	main
kinni	doc_973441205363_item	2954954	et	3	main
heitis	doc_973441205363_item	2954958	et	3	main
uks	doc_973441205363_item	2954984	et	3	main
laheb	doc_973441205363_item	2954985	et	4	main
linki	doc_973441205363_item	2954989	et	4	main
vanaema	doc_973441205363_item	2955007	et	4	main
miks	doc_973441205363_item	2955012	et	4	main
sul	doc_973441205363_item	2955013	et	3	main
vanaema	doc_973441205363_item	2955024	et	4	main
sind	doc_973441205363_item	2955034	et	4	main
vanaema	doc_973441205363_item	2955037	et	4	main
sul	doc_973441205363_item	2955039	et	3	main
sured	doc_973441205363_item	2955041	et	3	main
kõrvad	doc_973441205363_item	2955042	et	3	main
see	doc_973441205363_item	2955043	et	3	main
miks	doc_973441205363_item	2955051	et	4	main
punamütsikese	doc_973441205363_item	2955066	et	4	main
alla	doc_973441205363_item	2955067	et	3	main
hunt	doc_973441205363_item	2955068	et	3	main
tudrük	doc_973441205364_item	2955080	et	4	main
palus	doc_973441205364_item	2955090	et	4	main
haige	doc_973441205364_item	2955098	et	4	main
ma	doc_973441205364_item	2955099	et	3	main
ta	doc_973441205364_item	2955106	et	4	main
rõõmus	doc_973441205364_item	2955108	et	4	main
juurde	doc_973441205364_item	2955118	et	4	main
laulu	doc_973441205364_item	2955122	et	4	main
ääres	doc_973441205364_item	2955124	et	4	main
ta	doc_973441205364_item	2955136	et	4	main
tudrük	doc_973441205364_item	2955144	et	4	main
juttu	doc_973441205364_item	2955146	et	4	main
mahla	doc_973441205364_item	2955160	et	4	main
kimlu	doc_973441205364_item	2955163	et	4	main
armastavad	doc_973441205364_item	2955172	et	4	main
jooksis	doc_973441205364_item	2955184	et	4	main
ja	doc_973441205364_item	2955222	et	3	main
teda	doc_973441205364_item	2955224	et	4	main
jäi	doc_973441205364_item	2955229	et	3	main
oodata	doc_973441205364_item	2955230	et	4	main
mina	doc_973441205364_item	2955248	et	4	main
üks	doc_973441205364_item	2955254	et	3	main
lahti	doc_973441205364_item	2955256	et	4	main
ütles	doc_973441205364_item	2955257	et	3	main
hunt	doc_973441205364_item	2955258	et	3	main
punamütsike	doc_973441205364_item	2955259	et	4	main
vajutas	doc_973441205364_item	2955260	et	3	main
lingile	doc_973441205364_item	2955261	et	3	main
uks	doc_973441205364_item	2955262	et	3	main
läks	doc_973441205364_item	2955263	et	3	main
lahti	doc_973441205364_item	2955264	et	4	main
mahla	doc_973441205364_item	2955269	et	4	main
on	doc_973441205364_item	2955283	et	4	main
nii	doc_973441205364_item	2955284	et	3	main
suured	doc_973441205364_item	2955285	et	3	main
käed	doc_973441205364_item	2955286	et	3	main
küsis	doc_973441205364_item	2955287	et	3	main
hall	doc_973441205363_item	2954925	et	4	main
tulen	doc_973441205363_item	2954926	et	3	main
ema	doc_973441205363_item	2954929	et	4	main
viia	doc_973441205363_item	2954930	et	3	main
sulle	doc_973441205363_item	2954931	et	3	main
ja	doc_973441205363_item	2954933	et	3	main
natuke	doc_973441205363_item	2954934	et	4	main
lähti	doc_973441205363_item	2954947	et	4	main
ära	doc_973441205363_item	2954949	et	4	main
sõi	doc_973441205363_item	2954950	et	3	main
pärast	doc_973441205363_item	2954965	et	4	main
punamütsike	doc_973441205363_item	2954967	et	4	main
ja	doc_973441205363_item	2954968	et	3	main
koputas	doc_973441205363_item	2954969	et	3	main
kopp-kopp	doc_973441205363_item	2954970	et	3	main
kes	doc_973441205363_item	2954971	et	4	main
seal	doc_973441205363_item	2954972	et	4	main
on	doc_973441205363_item	2954973	et	4	main
see	doc_973441205363_item	2954974	et	3	main
olen	doc_973441205363_item	2954975	et	3	main
minna	doc_973441205363_item	2954976	et	3	main
punamütsike	doc_973441205363_item	2954977	et	4	main
tulen	doc_973441205363_item	2954978	et	3	main
sulle	doc_973441205363_item	2954979	et	3	main
vaatama	doc_973441205363_item	2954980	et	3	main
vajutama	doc_973441205363_item	2954981	et	4	main
linki	doc_973441205363_item	2954982	et	4	main
sis	doc_973441205363_item	2954983	et	3	main
vajutas	doc_973441205363_item	2954988	et	3	main
läks	doc_973441205363_item	2954992	et	3	main
punamütsike	doc_973441205363_item	2954994	et	4	main
astus	doc_973441205363_item	2954995	et	3	main
ta	doc_973441205363_item	2955006	et	4	main
küsis	doc_973441205363_item	2955010	et	3	main
vanaema	doc_973441205363_item	2955011	et	4	main
kallistada	doc_973441205363_item	2955023	et	3	main
sul	doc_973441205363_item	2955026	et	3	main
sured	doc_973441205363_item	2955028	et	3	main
joosta	doc_973441205363_item	2955036	et	4	main
parem	doc_973441205363_item	2955048	et	4	main
neelas	doc_973441205363_item	2955065	et	3	main
kord	doc_973441205364_item	2955078	et	4	main
elas	doc_973441205364_item	2955079	et	3	main
vii	doc_973441205364_item	2955103	et	4	main
vanaemale	doc_973441205364_item	2955105	et	3	main
vanaema	doc_973441205364_item	2955117	et	4	main
laulsid	doc_973441205364_item	2955121	et	4	main
tee	doc_973441205364_item	2955123	et	4	main
lillid	doc_973441205364_item	2955126	et	3	main
oli	doc_973441205364_item	2955128	et	3	main
ta	doc_973441205364_item	2955130	et	4	main
kohtus	doc_973441205364_item	2955137	et	4	main
hunti	doc_973441205364_item	2955138	et	4	main
hunt	doc_973441205364_item	2955139	et	3	main
küsis	doc_973441205364_item	2955140	et	3	main
kuhu	doc_973441205364_item	2955141	et	3	main
sa	doc_973441205364_item	2955142	et	3	main
on	doc_973441205364_item	2955152	et	4	main
ma	doc_973441205364_item	2955154	et	3	main
viin	doc_973441205364_item	2955155	et	4	main
lilled	doc_973441205364_item	2955173	et	3	main
vanaema	doc_973441205364_item	2955185	et	4	main
maja	doc_973441205364_item	2955186	et	4	main
kop-kop	doc_973441205364_item	2955238	et	4	main
seal	doc_973441205364_item	2955243	et	4	main
punamütsike	doc_973441205364_item	2955251	et	4	main
vanaema	doc_973441205364_item	2955280	et	4	main
sul	doc_973441205364_item	2955297	et	3	main
suured	doc_973441205364_item	2955300	et	3	main
tudrük	doc_973441205364_item	2955303	et	4	main
vanaema	doc_973441205364_item	2955322	et	4	main
sul	doc_973441205364_item	2955324	et	3	main
on	doc_973441205364_item	2955325	et	4	main
suured	doc_973441205364_item	2955327	et	3	main
paremini	doc_973441205364_item	2955332	et	4	main
miks	doc_973441205364_item	2955338	et	4	main
on	doc_973441205364_item	2955340	et	4	main
suured	doc_973441205364_item	2955341	et	3	main
et	doc_973441205364_item	2955344	et	3	main
paremini	doc_973441205364_item	2955345	et	4	main
puurajujad	doc_973441205364_item	2955354	et	4	main
et	doc_973441205364_item	2955356	et	3	main
mis	doc_973441205364_item	2955372	et	4	main
läksid	doc_973441205364_item	2955379	et	4	main
terved	doc_973441205364_item	2955386	et	4	main
ja	doc_973441205364_item	2955387	et	3	main
panisid	doc_973441205364_item	2955390	et	4	main
hunti	doc_973441205364_item	2955393	et	4	main
on	doc_973441205364_item	2955396	et	4	main
jüüa	doc_973441205364_item	2955404	et	4	main
vette	doc_973441205364_item	2955407	et	3	main
mahlat	doc_973441205364_item	2955417	et	4	main
ta	doc_973441205365_item	2955430	et	4	main
elas	doc_973441205365_item	2955431	et	3	main
koos	doc_973441205365_item	2955432	et	4	main
aga	doc_973441205365_item	2955439	et	3	main
mütsi	doc_973441205365_item	2955459	et	4	main
ütles	doc_973441205365_item	2955461	et	3	main
punamütsikele	doc_973441205365_item	2955462	et	4	main
ma	doc_973441205365_item	2955463	et	3	main
vaatas	doc_973441205365_item	2955464	et	3	main
et	doc_973441205365_item	2955465	et	3	main
meie	doc_973441205365_item	2955466	et	4	main
punamütsike	doc_973441205365_item	2955477	et	4	main
võttis	doc_973441205365_item	2955479	et	3	main
ja	doc_973441205365_item	2955481	et	3	main
vanaema	doc_973441205365_item	2955483	et	4	main
ilus	doc_973441205365_item	2955487	et	4	main
päike	doc_973441205365_item	2955489	et	3	main
lillid	doc_973441205365_item	2955493	et	3	main
see	doc_973441205363_item	2955017	et	3	main
parem	doc_973441205363_item	2955022	et	4	main
jalad	doc_973441205363_item	2955029	et	3	main
on	doc_973441205363_item	2955031	et	4	main
sellepärast	doc_973441205363_item	2955032	et	3	main
sind	doc_973441205363_item	2955047	et	4	main
umberjutustus	doc_973441205364_item	2955075	et	4	main
tema	doc_973441205364_item	2955081	et	4	main
nimi	doc_973441205364_item	2955082	et	3	main
ta	doc_973441205364_item	2955085	et	4	main
elas	doc_973441205364_item	2955086	et	3	main
kuulasin	doc_973441205364_item	2955094	et	3	main
küpsetasin	doc_973441205364_item	2955100	et	3	main
on	doc_973441205364_item	2955107	et	4	main
tudrük	doc_973441205364_item	2955109	et	4	main
metsa	doc_973441205364_item	2955115	et	4	main
parem	doc_973441205363_item	2955035	et	4	main
kuulma	doc_973441205363_item	2955049	et	3	main
vanaema	doc_973441205363_item	2955050	et	4	main
on	doc_973441205363_item	2955053	et	4	main
sured	doc_973441205363_item	2955054	et	3	main
suu	doc_973441205363_item	2955055	et	4	main
see	doc_973441205363_item	2955056	et	3	main
on	doc_973441205363_item	2955057	et	4	main
sellepärast	doc_973441205363_item	2955058	et	3	main
et	doc_973441205363_item	2955059	et	3	main
sind	doc_973441205363_item	2955060	et	4	main
ära	doc_973441205363_item	2955061	et	4	main
suua	doc_973441205363_item	2955062	et	4	main
ning	doc_973441205363_item	2955063	et	3	main
hunt	doc_973441205363_item	2955064	et	3	main
ümberjutustus	doc_973441205364_item	2955074	et	3	main
punamütsike	doc_973441205364_item	2955084	et	4	main
punamütsikesele	doc_973441205364_item	2955091	et	4	main
punamütsike	doc_973441205364_item	2955092	et	4	main
ma	doc_973441205364_item	2955093	et	3	main
vanaema	doc_973441205364_item	2955096	et	4	main
on	doc_973441205364_item	2955097	et	4	main
ja	doc_973441205364_item	2955102	et	3	main
valja	doc_973441205364_item	2955104	et	3	main
läbi	doc_973441205364_item	2955116	et	4	main
õitsesid	doc_973441205364_item	2955125	et	4	main
tore	doc_973441205364_item	2955129	et	3	main
korjab	doc_973441205364_item	2955131	et	3	main
lilli	doc_973441205364_item	2955132	et	4	main
vanaema	doc_973441205364_item	2955133	et	4	main
lähed	doc_973441205364_item	2955143	et	3	main
lähen	doc_973441205364_item	2955148	et	3	main
haige	doc_973441205364_item	2955153	et	4	main
ma	doc_973441205364_item	2955161	et	3	main
vanaemad	doc_973441205364_item	2955171	et	3	main
tudrük	doc_973441205364_item	2955175	et	4	main
hunt	doc_973441205364_item	2955177	et	3	main
jooksis	doc_973441205364_item	2955180	et	4	main
ta	doc_973441205364_item	2955183	et	4	main
neelas	doc_973441205364_item	2955223	et	3	main
ta	doc_973441205364_item	2955225	et	4	main
heitis	doc_973441205364_item	2955226	et	3	main
voodisse	doc_973441205364_item	2955227	et	3	main
ja	doc_973441205364_item	2955228	et	3	main
tuleb	doc_973441205364_item	2955233	et	3	main
punamütsike	doc_973441205364_item	2955234	et	4	main
kusis	doc_973441205364_item	2955244	et	4	main
olen	doc_973441205364_item	2955247	et	3	main
on	doc_973441205364_item	2955255	et	4	main
ja	doc_973441205364_item	2955268	et	3	main
laua	doc_973441205364_item	2955270	et	3	main
ja	doc_973441205364_item	2955272	et	3	main
küsis	doc_973441205364_item	2955273	et	3	main
vanaemale	doc_973441205364_item	2955274	et	3	main
vanaema	doc_973441205364_item	2955295	et	4	main
nii	doc_973441205364_item	2955299	et	3	main
jalad	doc_973441205364_item	2955301	et	3	main
nii	doc_973441205364_item	2955326	et	3	main
näha	doc_973441205364_item	2955333	et	3	main
vastas	doc_973441205364_item	2955335	et	4	main
vastas	doc_973441205364_item	2955348	et	4	main
hunt	doc_973441205364_item	2955349	et	3	main
ta	doc_973441205364_item	2955350	et	4	main
neelas	doc_973441205364_item	2955351	et	3	main
alla	doc_973441205364_item	2955352	et	3	main
teda	doc_973441205364_item	2955353	et	4	main
oli	doc_973441205364_item	2955358	et	3	main
kõht	doc_973441205364_item	2955377	et	3	main
jõe	doc_973441205364_item	2955400	et	3	main
ja	doc_973441205364_item	2955402	et	3	main
ta	doc_973441205364_item	2955405	et	4	main
puurajujad	doc_973441205364_item	2955408	et	4	main
ja	doc_973441205364_item	2955409	et	3	main
vanaema	doc_973441205364_item	2955410	et	4	main
ümberjutustus	doc_973441205365_item	2955418	et	3	main
ümberjutustus	doc_973441205365_item	2955419	et	3	main
punamütsike	doc_973441205365_item	2955420	et	4	main
punamütsike	doc_973441205364_item	2955076	et	4	main
üks	doc_973441205364_item	2955077	et	3	main
on	doc_973441205364_item	2955083	et	4	main
koos	doc_973441205364_item	2955087	et	4	main
emaga	doc_973441205364_item	2955088	et	3	main
ema	doc_973441205364_item	2955089	et	4	main
et	doc_973441205364_item	2955095	et	3	main
pirukaid	doc_973441205364_item	2955101	et	3	main
pani	doc_973441205364_item	2955110	et	4	main
mütsi	doc_973441205364_item	2955111	et	4	main
pahe	doc_973441205364_item	2955112	et	4	main
ja	doc_973441205364_item	2955113	et	3	main
laks	doc_973441205364_item	2955114	et	4	main
metsas	doc_973441205364_item	2955119	et	3	main
lindud	doc_973441205364_item	2955120	et	4	main
jaoks	doc_973441205364_item	2955134	et	4	main
äkki	doc_973441205364_item	2955135	et	3	main
juurde	doc_973441205364_item	2955150	et	4	main
ta	doc_973441205364_item	2955151	et	4	main
korjasin	doc_973441205364_item	2955162	et	3	main
lilli	doc_973441205364_item	2955164	et	4	main
on	doc_973441205364_item	2955166	et	4	main
et	doc_973441205364_item	2955169	et	3	main
tubli	doc_973441205364_item	2955174	et	4	main
ütles	doc_973441205364_item	2955176	et	3	main
ja	doc_973441205364_item	2955178	et	3	main
kiiresti	doc_973441205364_item	2955179	et	3	main
vanaema	doc_973441205364_item	2955181	et	4	main
juurde	doc_973441205364_item	2955221	et	4	main
varsti	doc_973441205364_item	2955232	et	3	main
kopustas	doc_973441205364_item	2955239	et	4	main
tüdrük	doc_973441205364_item	2955240	et	4	main
kes	doc_973441205364_item	2955241	et	4	main
hunt	doc_973441205364_item	2955245	et	3	main
see	doc_973441205364_item	2955246	et	3	main
vajuta	doc_973441205364_item	2955252	et	4	main
lingile	doc_973441205364_item	2955253	et	3	main
punamütsike	doc_973441205364_item	2955265	et	4	main
jäi	doc_973441205364_item	2955266	et	3	main
tema	doc_973441205364_item	2955276	et	4	main
välimus	doc_973441205364_item	2955277	et	3	main
oli	doc_973441205364_item	2955278	et	3	main
imeliku	doc_973441205364_item	2955279	et	3	main
miks	doc_973441205364_item	2955281	et	4	main
sul	doc_973441205364_item	2955282	et	3	main
vastas	doc_973441205364_item	2955293	et	4	main
hunt	doc_973441205364_item	2955294	et	3	main
on	doc_973441205364_item	2955298	et	4	main
küsis	doc_973441205364_item	2955302	et	3	main
tudrük	doc_973441205364_item	2955330	et	4	main
sind	doc_973441205364_item	2955334	et	4	main
vanaema	doc_973441205364_item	2955337	et	4	main
juhtub	doc_973441205364_item	2955373	et	3	main
nad	doc_973441205364_item	2955374	et	3	main
lõigasid	doc_973441205364_item	2955375	et	4	main
kõhust	doc_973441205364_item	2955378	et	3	main
valja	doc_973441205364_item	2955380	et	3	main
ja	doc_973441205364_item	2955382	et	3	main
nad	doc_973441205364_item	2955384	et	3	main
lapselaps	doc_973441205364_item	2955411	et	4	main
elas	doc_973441205365_item	2955423	et	3	main
tüdruk	doc_973441205365_item	2955425	et	3	main
ta	doc_973441205365_item	2955426	et	4	main
väga	doc_973441205365_item	2955428	et	3	main
ema	doc_973441205365_item	2955435	et	4	main
armastas	doc_973441205365_item	2955436	et	3	main
rohkem	doc_973441205365_item	2955442	et	4	main
tegi	doc_973441205365_item	2955444	et	4	main
punase	doc_973441205365_item	2955447	et	4	main
kandis	doc_973441205365_item	2955454	et	4	main
vanaema	doc_973441205365_item	2955467	et	4	main
küpsetasid	doc_973441205365_item	2955471	et	4	main
hea	doc_973441205365_item	2955474	et	4	main
ütles	doc_973441205365_item	2955476	et	3	main
oli	doc_973441205365_item	2955485	et	3	main
paistab	doc_973441205365_item	2955490	et	3	main
koristas	doc_973441205365_item	2955492	et	3	main
äkki	doc_973441205365_item	2955494	et	3	main
lähed	doc_973441205365_item	2955506	et	3	main
juurde	doc_973441205365_item	2955510	et	4	main
ta	doc_973441205365_item	2955511	et	4	main
on	doc_973441205365_item	2955512	et	4	main
väga	doc_973441205364_item	2955127	et	3	main
ajame	doc_973441205364_item	2955145	et	3	main
ma	doc_973441205364_item	2955147	et	3	main
vanaema	doc_973441205364_item	2955149	et	4	main
talle	doc_973441205364_item	2955156	et	4	main
pirukaid	doc_973441205364_item	2955157	et	3	main
ja	doc_973441205364_item	2955158	et	3	main
natukene	doc_973441205364_item	2955159	et	4	main
vanaemale	doc_973441205364_item	2955165	et	3	main
väga	doc_973441205364_item	2955167	et	3	main
meeldib	doc_973441205364_item	2955168	et	3	main
kõigid	doc_973441205364_item	2955170	et	3	main
juurde	doc_973441205364_item	2955182	et	4	main
ja	doc_973441205364_item	2955188	et	3	main
kopustas	doc_973441205364_item	2955189	et	4	main
ukses	doc_973441205364_item	2955190	et	3	main
juurde	doc_973441205364_item	2955187	et	4	main
kop-kop-kop	doc_973441205364_item	2955191	et	4	main
koputas	doc_973441205364_item	2955192	et	3	main
hunt	doc_973441205364_item	2955193	et	3	main
kes	doc_973441205364_item	2955194	et	4	main
läheb	doc_973441205364_item	2955195	et	3	main
küsis	doc_973441205364_item	2955196	et	3	main
vanaema	doc_973441205364_item	2955197	et	4	main
see	doc_973441205364_item	2955198	et	3	main
olen	doc_973441205364_item	2955199	et	3	main
punamütsike	doc_973441205364_item	2955201	et	4	main
vastas	doc_973441205364_item	2955202	et	4	main
hunt	doc_973441205364_item	2955203	et	3	main
mina	doc_973441205364_item	2955200	et	4	main
peenikese	doc_973441205364_item	2955204	et	4	main
hääliga	doc_973441205364_item	2955205	et	4	main
vajuta	doc_973441205364_item	2955206	et	4	main
lingile	doc_973441205364_item	2955207	et	3	main
ja	doc_973441205364_item	2955208	et	3	main
uks	doc_973441205364_item	2955209	et	3	main
läks	doc_973441205364_item	2955210	et	3	main
lahtu	doc_973441205364_item	2955211	et	4	main
hunt	doc_973441205364_item	2955212	et	3	main
vajutas	doc_973441205364_item	2955213	et	3	main
lingile	doc_973441205364_item	2955214	et	3	main
uks	doc_973441205364_item	2955215	et	3	main
läks	doc_973441205364_item	2955216	et	3	main
hunt	doc_973441205364_item	2955218	et	3	main
jookseb	doc_973441205364_item	2955219	et	3	main
lahti	doc_973441205364_item	2955217	et	4	main
vanaema	doc_973441205364_item	2955220	et	4	main
punamütsikese	doc_973441205364_item	2955231	et	4	main
ta	doc_973441205364_item	2955235	et	4	main
kopustas	doc_973441205364_item	2955236	et	4	main
ukses	doc_973441205364_item	2955237	et	3	main
on	doc_973441205364_item	2955242	et	4	main
punamütsike	doc_973441205364_item	2955249	et	4	main
vastas	doc_973441205364_item	2955250	et	4	main
pirukaid	doc_973441205364_item	2955267	et	3	main
peale	doc_973441205364_item	2955271	et	4	main
et	doc_973441205364_item	2955275	et	3	main
miks	doc_973441205364_item	2955296	et	4	main
et	doc_973441205364_item	2955304	et	3	main
joosta	doc_973441205364_item	2955306	et	4	main
paremini	doc_973441205364_item	2955305	et	4	main
vastas	doc_973441205364_item	2955307	et	4	main
hunt	doc_973441205364_item	2955308	et	3	main
vanaema	doc_973441205364_item	2955309	et	4	main
miks	doc_973441205364_item	2955310	et	4	main
sul	doc_973441205364_item	2955311	et	3	main
on	doc_973441205364_item	2955312	et	4	main
suured	doc_973441205364_item	2955313	et	3	main
kõrvad	doc_973441205364_item	2955314	et	3	main
küsis	doc_973441205364_item	2955315	et	3	main
tudrük	doc_973441205364_item	2955316	et	4	main
et	doc_973441205364_item	2955317	et	3	main
paremini	doc_973441205364_item	2955318	et	4	main
kuulata	doc_973441205364_item	2955319	et	4	main
vastas	doc_973441205364_item	2955320	et	4	main
tudrük	doc_973441205364_item	2955288	et	4	main
et	doc_973441205364_item	2955289	et	3	main
paremini	doc_973441205364_item	2955290	et	4	main
kallistada	doc_973441205364_item	2955291	et	3	main
sind	doc_973441205364_item	2955292	et	4	main
küsis	doc_973441205364_item	2955329	et	3	main
et	doc_973441205364_item	2955331	et	3	main
valged	doc_973441205364_item	2955342	et	3	main
süüa	doc_973441205364_item	2955346	et	3	main
ära	doc_973441205364_item	2955347	et	4	main
et	doc_973441205364_item	2955371	et	3	main
nad	doc_973441205364_item	2955389	et	3	main
rasked	doc_973441205364_item	2955391	et	3	main
janu	doc_973441205364_item	2955397	et	4	main
jookseb	doc_973441205364_item	2955399	et	3	main
ääres	doc_973441205364_item	2955401	et	4	main
sai	doc_973441205364_item	2955412	et	4	main
süüa	doc_973441205364_item	2955413	et	3	main
pirukaid	doc_973441205364_item	2955414	et	3	main
ja	doc_973441205364_item	2955415	et	3	main
elas	doc_973441205365_item	2955421	et	3	main
väike	doc_973441205365_item	2955424	et	4	main
oma	doc_973441205365_item	2955433	et	4	main
emaga	doc_973441205365_item	2955434	et	3	main
vanaema	doc_973441205365_item	2955440	et	4	main
sobib	doc_973441205365_item	2955450	et	3	main
on	doc_973441205365_item	2955468	et	4	main
pirukaid	doc_973441205365_item	2955472	et	3	main
küll	doc_973441205365_item	2955475	et	4	main
ja	doc_973441205365_item	2955478	et	3	main
väga	doc_973441205365_item	2955486	et	3	main
ja	doc_973441205365_item	2955497	et	3	main
hund	doc_973441205365_item	2955499	et	4	main
ta	doc_973441205365_item	2955500	et	4	main
ütles	doc_973441205365_item	2955501	et	3	main
vanaema	doc_973441205365_item	2955509	et	4	main
sinu	doc_973441205365_item	2955519	et	3	main
vanaema	doc_973441205365_item	2955520	et	4	main
kas	doc_973441205365_item	2955521	et	3	main
ei	doc_973441205365_item	2955526	et	4	main
kaugel	doc_973441205365_item	2955528	et	4	main
rohelises	doc_973441205365_item	2955534	et	4	main
majas	doc_973441205365_item	2955535	et	3	main
tüdruk	doc_973441205365_item	2955542	et	3	main
ta	doc_973441205365_item	2955546	et	4	main
vanaema	doc_973441205365_item	2955548	et	4	main
maja	doc_973441205365_item	2955549	et	4	main
vanaema	doc_973441205365_item	2955554	et	4	main
on	doc_973441205365_item	2955558	et	4	main
see	doc_973441205365_item	2955559	et	3	main
peenikese	doc_973441205365_item	2955565	et	4	main
häälega	doc_973441205365_item	2955566	et	3	main
hund	doc_973441205365_item	2955577	et	4	main
ja	doc_973441205365_item	2955580	et	3	main
uks	doc_973441205365_item	2955581	et	3	main
läks	doc_973441205365_item	2955582	et	3	main
lahti	doc_973441205365_item	2955583	et	4	main
vanaema	doc_973441205365_item	2955587	et	4	main
sind	doc_973441205365_item	2955622	et	4	main
punamütsike	doc_973441205365_item	2955637	et	4	main
astus	doc_973441205365_item	2955638	et	3	main
vanaema	doc_973441205365_item	2955646	et	4	main
on	doc_973441205365_item	2955658	et	4	main
paremini	doc_973441205365_item	2955662	et	4	main
et	doc_973441205365_item	2955720	et	3	main
ja	doc_973441205365_item	2955724	et	3	main
punamütsike	doc_973441205365_item	2955727	et	4	main
magama	doc_973441205365_item	2955731	et	3	main
ajal	doc_973441205365_item	2955736	et	4	main
läksid	doc_973441205365_item	2955737	et	4	main
nad	doc_973441205365_item	2955741	et	3	main
et	doc_973441205365_item	2955743	et	3	main
astusid	doc_973441205365_item	2955747	et	4	main
majas	doc_973441205365_item	2955748	et	3	main
ja	doc_973441205365_item	2955749	et	3	main
nagid	doc_973441205365_item	2955750	et	3	main
nad	doc_973441205365_item	2955755	et	3	main
hundi	doc_973441205365_item	2955757	et	3	main
lõhki	doc_973441205365_item	2955759	et	4	main
kõhust	doc_973441205365_item	2955760	et	3	main
nad	doc_973441205365_item	2955765	et	3	main
väike	doc_973441205366_item	2955778	et	4	main
hunt	doc_973441205364_item	2955321	et	3	main
miks	doc_973441205364_item	2955323	et	4	main
silmad	doc_973441205364_item	2955328	et	4	main
hunt	doc_973441205364_item	2955336	et	3	main
sul	doc_973441205364_item	2955339	et	3	main
hambad	doc_973441205364_item	2955343	et	3	main
nagid	doc_973441205364_item	2955355	et	3	main
uks	doc_973441205364_item	2955357	et	3	main
lahti	doc_973441205364_item	2955359	et	4	main
nad	doc_973441205364_item	2955360	et	3	main
astusid	doc_973441205364_item	2955361	et	4	main
majja	doc_973441205364_item	2955362	et	3	main
ja	doc_973441205364_item	2955363	et	3	main
nägid	doc_973441205364_item	2955364	et	4	main
et	doc_973441205364_item	2955365	et	3	main
hunt	doc_973441205364_item	2955366	et	3	main
kõvasti	doc_973441205364_item	2955367	et	3	main
norskab	doc_973441205364_item	2955368	et	3	main
nad	doc_973441205364_item	2955369	et	3	main
mõtlesid	doc_973441205364_item	2955370	et	4	main
hunti	doc_973441205364_item	2955376	et	4	main
vanaema	doc_973441205364_item	2955381	et	4	main
lapselaps	doc_973441205364_item	2955383	et	4	main
oli	doc_973441205364_item	2955385	et	3	main
ilusad	doc_973441205364_item	2955388	et	3	main
kivid	doc_973441205364_item	2955392	et	3	main
kõhus	doc_973441205364_item	2955394	et	3	main
hunt	doc_973441205364_item	2955395	et	3	main
ta	doc_973441205364_item	2955398	et	4	main
sai	doc_973441205364_item	2955403	et	4	main
uppus	doc_973441205364_item	2955406	et	3	main
jüüa	doc_973441205364_item	2955416	et	4	main
kord	doc_973441205365_item	2955422	et	4	main
veel	doc_973441205365_item	2955441	et	4	main
ema	doc_973441205365_item	2955443	et	4	main
talle	doc_973441205365_item	2955445	et	4	main
väikese	doc_973441205365_item	2955446	et	4	main
iga	doc_973441205365_item	2955455	et	4	main
paev	doc_973441205365_item	2955456	et	4	main
seda	doc_973441205365_item	2955457	et	3	main
ema	doc_973441205365_item	2955460	et	4	main
me	doc_973441205365_item	2955470	et	4	main
läks	doc_973441205365_item	2955482	et	3	main
juures	doc_973441205365_item	2955484	et	4	main
ilm	doc_973441205365_item	2955488	et	3	main
suur	doc_973441205365_item	2955496	et	3	main
hall	doc_973441205365_item	2955498	et	4	main
ma	doc_973441205365_item	2955507	et	3	main
haige	doc_973441205365_item	2955513	et	4	main
hund	doc_973441205365_item	2955514	et	4	main
kaugel	doc_973441205365_item	2955523	et	4	main
ole	doc_973441205365_item	2955527	et	4	main
väikeses	doc_973441205365_item	2955533	et	4	main
hea	doc_973441205365_item	2955541	et	4	main
kes	doc_973441205365_item	2955556	et	4	main
hund	doc_973441205365_item	2955564	et	4	main
tulin	doc_973441205365_item	2955567	et	3	main
sind	doc_973441205365_item	2955568	et	4	main
vaatama	doc_973441205365_item	2955569	et	3	main
vajutas	doc_973441205365_item	2955578	et	3	main
lingil	doc_973441205365_item	2955579	et	3	main
ja	doc_973441205365_item	2955589	et	3	main
alla	doc_973441205365_item	2955592	et	3	main
pani	doc_973441205365_item	2955594	et	4	main
ta	doc_973441205365_item	2955595	et	4	main
ukse	doc_973441205365_item	2955596	et	3	main
kinni	doc_973441205365_item	2955597	et	3	main
heitis	doc_973441205365_item	2955598	et	3	main
vaatama	doc_973441205365_item	2955623	et	3	main
püüdis	doc_973441205365_item	2955625	et	3	main
vajuta	doc_973441205365_item	2955632	et	4	main
uks	doc_973441205365_item	2955635	et	3	main
ta	doc_973441205365_item	2955640	et	4	main
oli	doc_973441205365_item	2955641	et	3	main
väga	doc_973441205365_item	2955642	et	3	main
imestunud	doc_973441205365_item	2955643	et	4	main
kui	doc_973441205365_item	2955644	et	3	main
vanaema	doc_973441205365_item	2955650	et	4	main
kallistada	doc_973441205365_item	2955663	et	3	main
tütreke	doc_973441205365_item	2955664	et	4	main
hunt	doc_973441205365_item	2955666	et	3	main
vanaema	doc_973441205365_item	2955667	et	4	main
süüa	doc_973441205365_item	2955723	et	3	main
majast	doc_973441205365_item	2955738	et	4	main
nagid	doc_973441205365_item	2955742	et	3	main
üks	doc_973441205365_item	2955745	et	3	main
magas	doc_973441205365_item	2955753	et	4	main
lõikusid	doc_973441205365_item	2955756	et	4	main
kõhu	doc_973441205365_item	2955758	et	3	main
läksid	doc_973441205365_item	2955761	et	4	main
ema	doc_973441205366_item	2955780	et	4	main
punase	doc_973441205366_item	2955791	et	4	main
mütsi	doc_973441205366_item	2955800	et	4	main
jurde	doc_973441205366_item	2955821	et	4	main
võid	doc_973441205366_item	2955828	et	4	main
et	doc_973441205366_item	2955831	et	3	main
tüdruk	doc_973441205366_item	2955838	et	3	main
ta	doc_973441205366_item	2955839	et	4	main
purdi	doc_973441205366_item	2955843	et	4	main
teises	doc_973441205366_item	2955855	et	4	main
külas	doc_973441205366_item	2955856	et	3	main
punamutsikesel	doc_973441205366_item	2955871	et	4	main
oli	doc_973441205365_item	2955427	et	3	main
ilus	doc_973441205365_item	2955429	et	4	main
teda	doc_973441205365_item	2955437	et	4	main
väga	doc_973441205365_item	2955438	et	3	main
mütsi	doc_973441205365_item	2955448	et	4	main
mis	doc_973441205365_item	2955449	et	4	main
talle	doc_973441205365_item	2955451	et	4	main
hästi	doc_973441205365_item	2955452	et	3	main
punamütsike	doc_973441205365_item	2955453	et	4	main
punast	doc_973441205365_item	2955458	et	4	main
haige	doc_973441205365_item	2955469	et	4	main
mine	doc_973441205365_item	2955473	et	3	main
korv	doc_973441205365_item	2955480	et	3	main
punamütsike	doc_973441205365_item	2955491	et	4	main
pünamütsikele	doc_973441205365_item	2955502	et	4	main
tere	doc_973441205365_item	2955503	et	3	main
kuidas	doc_973441205365_item	2955504	et	3	main
sa	doc_973441205365_item	2955505	et	3	main
küla	doc_973441205365_item	2955532	et	4	main
vaga	doc_973441205365_item	2955540	et	4	main
jookseb	doc_973441205365_item	2955544	et	3	main
tuli	doc_973441205365_item	2955547	et	4	main
juurde	doc_973441205365_item	2955550	et	4	main
kop-kop-kop	doc_973441205365_item	2955553	et	4	main
ütles	doc_973441205365_item	2955555	et	3	main
see	doc_973441205365_item	2955557	et	3	main
olen	doc_973441205365_item	2955560	et	3	main
ütles	doc_973441205365_item	2955563	et	3	main
vajuta	doc_973441205365_item	2955570	et	4	main
lingile	doc_973441205365_item	2955571	et	3	main
uks	doc_973441205365_item	2955572	et	3	main
läks	doc_973441205365_item	2955573	et	3	main
ta	doc_973441205365_item	2955584	et	4	main
neelas	doc_973441205365_item	2955590	et	3	main
ta	doc_973441205365_item	2955591	et	4	main
siis	doc_973441205365_item	2955593	et	3	main
peenemaks	doc_973441205365_item	2955628	et	4	main
lingile	doc_973441205365_item	2955633	et	3	main
lahti	doc_973441205365_item	2955636	et	4	main
tuppa	doc_973441205365_item	2955639	et	3	main
sind	doc_973441205365_item	2955661	et	4	main
vastas	doc_973441205365_item	2955665	et	4	main
on	doc_973441205365_item	2955675	et	4	main
selleks	doc_973441205365_item	2955676	et	4	main
et	doc_973441205365_item	2955677	et	3	main
paremini	doc_973441205365_item	2955678	et	4	main
vanaema	doc_973441205365_item	2955681	et	4	main
miks	doc_973441205365_item	2955682	et	4	main
sul	doc_973441205365_item	2955683	et	3	main
selleks	doc_973441205365_item	2955719	et	4	main
ära	doc_973441205365_item	2955722	et	4	main
alla	doc_973441205365_item	2955728	et	3	main
jäi	doc_973441205365_item	2955730	et	3	main
ja	doc_973441205365_item	2955732	et	3	main
norskama	doc_973441205365_item	2955734	et	3	main
vanaema	doc_973441205365_item	2955762	et	4	main
ja	doc_973441205365_item	2955763	et	3	main
terved	doc_973441205365_item	2955767	et	4	main
ilus	doc_973441205365_item	2955769	et	4	main
ümberjutustus	doc_973441205366_item	2955771	et	3	main
elas	doc_973441205366_item	2955773	et	3	main
armastas	doc_973441205366_item	2955781	et	3	main
vanaema	doc_973441205366_item	2955785	et	4	main
vanaema	doc_973441205366_item	2955788	et	4	main
õmbles	doc_973441205366_item	2955789	et	3	main
tüdrukule	doc_973441205366_item	2955790	et	3	main
mis	doc_973441205366_item	2955793	et	4	main
sobis	doc_973441205366_item	2955794	et	4	main
talle	doc_973441205366_item	2955795	et	4	main
kogu	doc_973441205366_item	2955801	et	4	main
aeg	doc_973441205366_item	2955802	et	3	main
vii	doc_973441205366_item	2955823	et	4	main
vanaema	doc_973441205366_item	2955832	et	4	main
on	doc_973441205366_item	2955833	et	4	main
haige	doc_973441205366_item	2955834	et	4	main
hea	doc_973441205366_item	2955835	et	4	main
korvis	doc_973441205366_item	2955847	et	3	main
ja	doc_973441205366_item	2955848	et	3	main
läks	doc_973441205366_item	2955849	et	3	main
vanaema	doc_973441205366_item	2955850	et	4	main
lilli	doc_973441205366_item	2955879	et	4	main
tale	doc_973441205366_item	2955888	et	4	main
kimbu	doc_973441205366_item	2955889	et	3	main
ta	doc_973441205366_item	2955891	et	4	main
tuli	doc_973441205365_item	2955495	et	4	main
lähen	doc_973441205365_item	2955508	et	3	main
ütles	doc_973441205365_item	2955515	et	3	main
aga	doc_973441205365_item	2955516	et	3	main
kus	doc_973441205365_item	2955517	et	3	main
elasid	doc_973441205365_item	2955518	et	4	main
on	doc_973441205365_item	2955522	et	4	main
punamütsike	doc_973441205365_item	2955524	et	4	main
vastas	doc_973441205365_item	2955525	et	4	main
teise	doc_973441205365_item	2955531	et	4	main
punamütsikele	doc_973441205365_item	2955538	et	4	main
sa	doc_973441205365_item	2955539	et	3	main
ta	doc_973441205365_item	2955543	et	4	main
kopsutas	doc_973441205365_item	2955552	et	3	main
punamütsike	doc_973441205365_item	2955562	et	4	main
ütles	doc_973441205365_item	2955575	et	3	main
vanaema	doc_973441205365_item	2955576	et	4	main
kohe	doc_973441205365_item	2955586	et	4	main
ta	doc_973441205365_item	2955529	et	4	main
elab	doc_973441205365_item	2955530	et	3	main
hund	doc_973441205365_item	2955536	et	4	main
ütles	doc_973441205365_item	2955537	et	3	main
metsas	doc_973441205365_item	2955545	et	3	main
ja	doc_973441205365_item	2955551	et	3	main
ma	doc_973441205365_item	2955561	et	3	main
lahti	doc_973441205365_item	2955574	et	4	main
jooksis	doc_973441205365_item	2955585	et	4	main
juurde	doc_973441205365_item	2955588	et	4	main
vanaema	doc_973441205365_item	2955599	et	4	main
voodisse	doc_973441205365_item	2955600	et	3	main
ja	doc_973441205365_item	2955601	et	3	main
jäi	doc_973441205365_item	2955602	et	3	main
punamütsike	doc_973441205365_item	2955603	et	4	main
ootama	doc_973441205365_item	2955604	et	3	main
natukese	doc_973441205365_item	2955605	et	4	main
aja	doc_973441205365_item	2955606	et	4	main
pärast	doc_973441205365_item	2955607	et	4	main
tuli	doc_973441205365_item	2955608	et	4	main
punamütsike	doc_973441205365_item	2955609	et	4	main
ja	doc_973441205365_item	2955610	et	3	main
koputas	doc_973441205365_item	2955611	et	3	main
uksele	doc_973441205365_item	2955612	et	3	main
kopp-kopp	doc_973441205365_item	2955613	et	3	main
kes	doc_973441205365_item	2955614	et	4	main
seal	doc_973441205365_item	2955615	et	4	main
on	doc_973441205365_item	2955616	et	4	main
see	doc_973441205365_item	2955617	et	3	main
olen	doc_973441205365_item	2955618	et	3	main
mina	doc_973441205365_item	2955619	et	4	main
punamütsike	doc_973441205365_item	2955620	et	4	main
tulin	doc_973441205365_item	2955621	et	3	main
teha	doc_973441205365_item	2955629	et	3	main
ja	doc_973441205365_item	2955630	et	3	main
hüüdis	doc_973441205365_item	2955631	et	3	main
läheb	doc_973441205365_item	2955634	et	3	main
miks	doc_973441205365_item	2955651	et	4	main
sul	doc_973441205365_item	2955652	et	3	main
nii	doc_973441205365_item	2955653	et	3	main
suured	doc_973441205365_item	2955654	et	3	main
käed	doc_973441205365_item	2955655	et	3	main
on	doc_973441205365_item	2955656	et	4	main
see	doc_973441205365_item	2955657	et	3	main
miks	doc_973441205365_item	2955668	et	4	main
sul	doc_973441205365_item	2955669	et	3	main
nii	doc_973441205365_item	2955670	et	3	main
suured	doc_973441205365_item	2955671	et	3	main
jalad	doc_973441205365_item	2955672	et	3	main
joosta	doc_973441205365_item	2955679	et	4	main
hunt	doc_973441205365_item	2955725	et	3	main
hund	doc_973441205365_item	2955729	et	4	main
hakkas	doc_973441205365_item	2955733	et	3	main
samal	doc_973441205365_item	2955735	et	3	main
puurajaujad	doc_973441205365_item	2955740	et	4	main
nad	doc_973441205365_item	2955746	et	3	main
voodis	doc_973441205365_item	2955754	et	3	main
oli	doc_973441205365_item	2955766	et	3	main
ja	doc_973441205365_item	2955768	et	3	main
ümberjutustus	doc_973441205366_item	2955770	et	3	main
punamütsike	doc_973441205366_item	2955772	et	4	main
kord	doc_973441205366_item	2955775	et	4	main
ema	doc_973441205366_item	2955776	et	4	main
ja	doc_973441205366_item	2955777	et	3	main
teda	doc_973441205366_item	2955782	et	4	main
hund	doc_973441205365_item	2955624	et	4	main
oma	doc_973441205365_item	2955626	et	4	main
halt	doc_973441205365_item	2955627	et	4	main
ta	doc_973441205365_item	2955645	et	4	main
nägi	doc_973441205365_item	2955647	et	3	main
ta	doc_973441205365_item	2955648	et	4	main
küsis	doc_973441205365_item	2955649	et	3	main
selleks	doc_973441205365_item	2955659	et	4	main
et	doc_973441205365_item	2955660	et	3	main
on	doc_973441205365_item	2955673	et	4	main
see	doc_973441205365_item	2955674	et	3	main
tütreke	doc_973441205365_item	2955680	et	4	main
nii	doc_973441205365_item	2955684	et	3	main
suured	doc_973441205365_item	2955685	et	3	main
silmad	doc_973441205365_item	2955686	et	4	main
on	doc_973441205365_item	2955687	et	4	main
see	doc_973441205365_item	2955688	et	3	main
on	doc_973441205365_item	2955689	et	4	main
selleks	doc_973441205365_item	2955690	et	4	main
et	doc_973441205365_item	2955691	et	3	main
paremini	doc_973441205365_item	2955692	et	4	main
näha	doc_973441205365_item	2955693	et	3	main
tütreke	doc_973441205365_item	2955694	et	4	main
vanaema	doc_973441205365_item	2955695	et	4	main
miks	doc_973441205365_item	2955696	et	4	main
sul	doc_973441205365_item	2955697	et	3	main
nii	doc_973441205365_item	2955698	et	3	main
suured	doc_973441205365_item	2955699	et	3	main
käed	doc_973441205365_item	2955700	et	3	main
on	doc_973441205365_item	2955701	et	4	main
see	doc_973441205365_item	2955702	et	3	main
on	doc_973441205365_item	2955703	et	4	main
selleks	doc_973441205365_item	2955704	et	4	main
et	doc_973441205365_item	2955705	et	3	main
paremini	doc_973441205365_item	2955706	et	4	main
kalistada	doc_973441205365_item	2955707	et	4	main
sind	doc_973441205365_item	2955708	et	4	main
tütreke	doc_973441205365_item	2955709	et	4	main
vanaema	doc_973441205365_item	2955710	et	4	main
miks	doc_973441205365_item	2955711	et	4	main
sul	doc_973441205365_item	2955712	et	3	main
nii	doc_973441205365_item	2955713	et	3	main
suur	doc_973441205365_item	2955714	et	3	main
suu	doc_973441205365_item	2955715	et	4	main
on	doc_973441205365_item	2955716	et	4	main
see	doc_973441205365_item	2955717	et	3	main
on	doc_973441205365_item	2955718	et	4	main
sind	doc_973441205365_item	2955721	et	4	main
neelas	doc_973441205365_item	2955726	et	3	main
mööda	doc_973441205365_item	2955739	et	4	main
lahti	doc_973441205365_item	2955744	et	4	main
hunti	doc_973441205365_item	2955751	et	4	main
ta	doc_973441205365_item	2955752	et	4	main
punamütsike	doc_973441205365_item	2955764	et	4	main
üks	doc_973441205366_item	2955774	et	3	main
aga	doc_973441205366_item	2955784	et	3	main
punast	doc_973441205366_item	2955799	et	4	main
ja	doc_973441205366_item	2955803	et	3	main
nüüd	doc_973441205366_item	2955804	et	4	main
inimesed	doc_973441205366_item	2955805	et	3	main
hakkasid	doc_973441205366_item	2955806	et	4	main
teda	doc_973441205366_item	2955807	et	4	main
kutsuma	doc_973441205366_item	2955808	et	3	main
punamütsikeseks	doc_973441205366_item	2955809	et	4	main
üks	doc_973441205366_item	2955810	et	3	main
kord	doc_973441205366_item	2955811	et	4	main
küpsetas	doc_973441205366_item	2955812	et	3	main
ema	doc_973441205366_item	2955813	et	4	main
pirukaid	doc_973441205366_item	2955814	et	3	main
ja	doc_973441205366_item	2955815	et	3	main
ütles	doc_973441205366_item	2955816	et	3	main
tütrele	doc_973441205366_item	2955817	et	3	main
tule	doc_973441205366_item	2955818	et	4	main
punamütsike	doc_973441205366_item	2955819	et	4	main
vanaema	doc_973441205366_item	2955820	et	4	main
tüdruk	doc_973441205366_item	2955779	et	3	main
väga	doc_973441205366_item	2955783	et	3	main
väga	doc_973441205366_item	2955796	et	3	main
tüdruk	doc_973441205366_item	2955797	et	3	main
kandis	doc_973441205366_item	2955798	et	4	main
talle	doc_973441205366_item	2955824	et	4	main
purgi	doc_973441205366_item	2955827	et	4	main
kulsin	doc_973441205366_item	2955830	et	4	main
küll	doc_973441205366_item	2955836	et	4	main
vastas	doc_973441205366_item	2955837	et	4	main
vanaema	doc_973441205366_item	2955853	et	4	main
elas	doc_973441205366_item	2955854	et	3	main
tuju	doc_973441205366_item	2955875	et	4	main
ääres	doc_973441205366_item	2955877	et	4	main
väga	doc_973441205366_item	2955884	et	3	main
armastab	doc_973441205366_item	2955885	et	3	main
lilli	doc_973441205366_item	2955886	et	4	main
korjan	doc_973441205366_item	2955887	et	3	main
rahul	doc_973441205366_item	2955894	et	4	main
ta	doc_973441205366_item	2955895	et	4	main
akki	doc_973441205366_item	2955903	et	4	main
veel	doc_973441205366_item	2955786	et	4	main
rohkem	doc_973441205366_item	2955787	et	4	main
mütsi	doc_973441205366_item	2955792	et	4	main
pirukaid	doc_973441205366_item	2955825	et	3	main
ja	doc_973441205366_item	2955826	et	3	main
ma	doc_973441205366_item	2955829	et	3	main
võttis	doc_973441205366_item	2955840	et	3	main
pirukaid	doc_973441205366_item	2955841	et	3	main
ja	doc_973441205366_item	2955842	et	3	main
pani	doc_973441205366_item	2955845	et	4	main
kõik	doc_973441205366_item	2955846	et	4	main
punamütsike	doc_973441205366_item	2955880	et	4	main
mõtles	doc_973441205366_item	2955881	et	3	main
lilli	doc_973441205366_item	2955890	et	4	main
korvi	doc_973441205366_item	2955897	et	4	main
vanaema	doc_973441205366_item	2955918	et	4	main
tüdruk	doc_973441205366_item	2955921	et	3	main
mitte	doc_973441205366_item	2955928	et	3	main
taga	doc_973441205366_item	2955931	et	4	main
oli	doc_973441205366_item	2955934	et	3	main
ma	doc_973441205366_item	2955950	et	3	main
jurde	doc_973441205366_item	2955961	et	4	main
teega	doc_973441205366_item	2955968	et	3	main
aja	doc_973441205366_item	2955970	et	4	main
oli	doc_973441205366_item	2955972	et	3	main
hunt	doc_973441205366_item	2955973	et	3	main
vanaema	doc_973441205366_item	2955974	et	4	main
koputas	doc_973441205366_item	2955978	et	3	main
jurde	doc_973441205366_item	2956025	et	4	main
ja	doc_973441205366_item	2956026	et	3	main
neelas	doc_973441205366_item	2956027	et	3	main
alla	doc_973441205366_item	2956028	et	3	main
siis	doc_973441205366_item	2956029	et	3	main
ja	doc_973441205366_item	2956036	et	3	main
punanamütsikesest	doc_973441205366_item	2956038	et	4	main
natukese	doc_973441205366_item	2956040	et	4	main
aja	doc_973441205366_item	2956041	et	4	main
punamütsike	doc_973441205366_item	2956044	et	4	main
kopp-kopp	doc_973441205366_item	2956048	et	3	main
seal	doc_973441205366_item	2956050	et	4	main
punamütsike	doc_973441205366_item	2956056	et	4	main
vastas	doc_973441205366_item	2956067	et	4	main
olen	doc_973441205366_item	2956069	et	3	main
ja	doc_973441205366_item	2956075	et	3	main
võid	doc_973441205366_item	2956077	et	4	main
punamütsike	doc_973441205366_item	2956086	et	4	main
lingile	doc_973441205366_item	2956088	et	3	main
lauale	doc_973441205366_item	2956098	et	4	main
ja	doc_973441205366_item	2956099	et	3	main
tule	doc_973441205366_item	2956100	et	4	main
vanaema	doc_973441205366_item	2956121	et	4	main
on	doc_973441205366_item	2956132	et	4	main
paremini	doc_973441205366_item	2956136	et	4	main
vastas	doc_973441205366_item	2956139	et	4	main
vanaema	doc_973441205366_item	2956141	et	4	main
suured	doc_973441205366_item	2956146	et	3	main
läksid	doc_973441205366_item	2956181	et	4	main
ja	doc_973441205366_item	2956194	et	3	main
sellest	doc_973441205366_item	2956195	et	4	main
välja	doc_973441205366_item	2956197	et	4	main
olid	doc_973441205366_item	2956205	et	4	main
nad	doc_973441205366_item	2956210	et	3	main
puuraiujate	doc_973441205366_item	2956212	et	3	main
neid	doc_973441205366_item	2956215	et	4	main
ilus	doc_973441205367_item	2956229	et	4	main
ja	doc_973441205367_item	2956230	et	3	main
sõbralik	doc_973441205367_item	2956231	et	3	main
ema	doc_973441205367_item	2956232	et	4	main
väga	doc_973441205367_item	2956233	et	3	main
armastas	doc_973441205367_item	2956234	et	3	main
tüdruku	doc_973441205367_item	2956235	et	3	main
aga	doc_973441205367_item	2956236	et	3	main
mütsi	doc_973441205367_item	2956246	et	4	main
ja	doc_973441205367_item	2956247	et	3	main
tüdruk	doc_973441205367_item	2956248	et	3	main
kandis	doc_973441205367_item	2956249	et	4	main
punamütsike	doc_973441205367_item	2956256	et	4	main
ema	doc_973441205367_item	2956259	et	4	main
ja	doc_973441205367_item	2956262	et	3	main
ma	doc_973441205367_item	2956268	et	3	main
kuulasin	doc_973441205367_item	2956269	et	3	main
et	doc_973441205367_item	2956270	et	3	main
ja	doc_973441205366_item	2955822	et	3	main
võid	doc_973441205366_item	2955844	et	4	main
jurde	doc_973441205366_item	2955851	et	4	main
aga	doc_973441205366_item	2955852	et	3	main
metsa	doc_973441205366_item	2955857	et	4	main
taga	doc_973441205366_item	2955858	et	4	main
väikeses	doc_973441205366_item	2955859	et	4	main
rohelises	doc_973441205366_item	2955860	et	4	main
majas	doc_973441205366_item	2955861	et	3	main
tee	doc_973441205366_item	2955862	et	4	main
läks	doc_973441205366_item	2955863	et	3	main
metsa	doc_973441205366_item	2955864	et	4	main
läbi	doc_973441205366_item	2955865	et	4	main
päike	doc_973441205366_item	2955866	et	3	main
päistis	doc_973441205366_item	2955867	et	4	main
lunnud	doc_973441205366_item	2955868	et	4	main
laulsid	doc_973441205366_item	2955869	et	4	main
ja	doc_973441205366_item	2955870	et	3	main
oli	doc_973441205366_item	2955872	et	3	main
hea	doc_973441205366_item	2955874	et	4	main
tee	doc_973441205366_item	2955876	et	4	main
kasvasid	doc_973441205366_item	2955878	et	4	main
jurde	doc_973441205366_item	2955906	et	4	main
vastas	doc_973441205366_item	2955920	et	4	main
kus	doc_973441205366_item	2955923	et	3	main
hunt	doc_973441205366_item	2955927	et	3	main
kaua	doc_973441205366_item	2955929	et	3	main
hunti	doc_973441205366_item	2955932	et	4	main
tühi	doc_973441205366_item	2955936	et	3	main
tähtis	doc_973441205366_item	2955938	et	4	main
punamütsikesest	doc_973441205366_item	2955941	et	4	main
aga	doc_973441205366_item	2955942	et	3	main
mõtles	doc_973441205366_item	2955943	et	3	main
ümber	doc_973441205366_item	2955944	et	3	main
sa	doc_973441205366_item	2955945	et	3	main
oled	doc_973441205366_item	2955946	et	3	main
sest	doc_973441205366_item	2955949	et	4	main
lühikese	doc_973441205366_item	2955962	et	4	main
teega	doc_973441205366_item	2955963	et	3	main
aga	doc_973441205366_item	2955964	et	3	main
pikkuse	doc_973441205366_item	2955967	et	4	main
pärast	doc_973441205366_item	2955971	et	4	main
maja	doc_973441205366_item	2955975	et	4	main
hunt	doc_973441205366_item	2956022	et	3	main
joksis	doc_973441205366_item	2956023	et	4	main
kinni	doc_973441205366_item	2956033	et	3	main
vodisse	doc_973441205366_item	2956035	et	4	main
kes	doc_973441205366_item	2956049	et	4	main
on	doc_973441205366_item	2956051	et	4	main
küsis	doc_973441205366_item	2956052	et	3	main
hunt	doc_973441205366_item	2956053	et	3	main
mõtles	doc_973441205366_item	2956061	et	3	main
ja	doc_973441205366_item	2956066	et	3	main
punamütsike	doc_973441205366_item	2956071	et	4	main
purgi	doc_973441205366_item	2956076	et	4	main
tuppa	doc_973441205366_item	2956095	et	3	main
pane	doc_973441205366_item	2956096	et	4	main
vanaema	doc_973441205366_item	2956122	et	4	main
on	doc_973441205366_item	2956125	et	4	main
nii	doc_973441205366_item	2956126	et	3	main
suured	doc_973441205366_item	2956127	et	3	main
jaoks	doc_973441205366_item	2956134	et	4	main
nii	doc_973441205366_item	2956145	et	3	main
on	doc_973441205366_item	2956149	et	4	main
jaoks	doc_973441205366_item	2956151	et	4	main
et	doc_973441205366_item	2956152	et	3	main
jaoks	doc_973441205366_item	2956166	et	4	main
neelas	doc_973441205366_item	2956176	et	3	main
nad	doc_973441205366_item	2956185	et	3	main
ja	doc_973441205366_item	2956208	et	3	main
pirukatega	doc_973441205366_item	2956218	et	3	main
ümberjutustus	doc_973441205367_item	2956220	et	3	main
elas	doc_973441205367_item	2956222	et	3	main
kord	doc_973441205367_item	2956223	et	4	main
tüdruk	doc_973441205367_item	2956225	et	3	main
ta	doc_973441205367_item	2956226	et	4	main
talle	doc_973441205367_item	2956239	et	4	main
ema	doc_973441205367_item	2956242	et	4	main
aega	doc_973441205367_item	2956251	et	4	main
nii	doc_973441205367_item	2956252	et	3	main
vanaema	doc_973441205367_item	2956266	et	4	main
vii	doc_973441205367_item	2956274	et	4	main
ma	doc_973441205367_item	2956322	et	3	main
ema	doc_973441205367_item	2956326	et	4	main
mahla	doc_973441205367_item	2956331	et	4	main
vanaema	doc_973441205367_item	2956333	et	4	main
küsis	doc_973441205367_item	2956340	et	3	main
ela	doc_973441205367_item	2956343	et	4	main
väikeses	doc_973441205367_item	2956352	et	4	main
majas	doc_973441205367_item	2956354	et	3	main
vastas	doc_973441205367_item	2956355	et	4	main
metsa	doc_973441205367_item	2956359	et	4	main
natukese	doc_973441205367_item	2956360	et	4	main
aja	doc_973441205367_item	2956361	et	4	main
kopp-kopp	doc_973441205367_item	2956370	et	3	main
kes	doc_973441205367_item	2956371	et	4	main
punamütsike	doc_973441205367_item	2956377	et	4	main
ütles	doc_973441205367_item	2956378	et	3	main
vajuta	doc_973441205367_item	2956390	et	4	main
astub	doc_973441205367_item	2956397	et	3	main
väga	doc_973441205366_item	2955873	et	3	main
minu	doc_973441205366_item	2955882	et	3	main
vanaema	doc_973441205366_item	2955883	et	4	main
pani	doc_973441205366_item	2955896	et	4	main
tuli	doc_973441205366_item	2955904	et	4	main
tema	doc_973441205366_item	2955905	et	4	main
jurde	doc_973441205366_item	2955919	et	4	main
aga	doc_973441205366_item	2955922	et	3	main
metsa	doc_973441205366_item	2955930	et	4	main
tüdruk	doc_973441205366_item	2955948	et	3	main
lilli	doc_973441205366_item	2955955	et	4	main
hunt	doc_973441205366_item	2955957	et	3	main
joksis	doc_973441205366_item	2955959	et	4	main
punamütsike	doc_973441205366_item	2955965	et	4	main
jures	doc_973441205366_item	2955976	et	4	main
ja	doc_973441205366_item	2955977	et	3	main
kopp-kopp	doc_973441205366_item	2955980	et	3	main
pani	doc_973441205366_item	2956030	et	4	main
jäi	doc_973441205366_item	2956037	et	3	main
ootama	doc_973441205366_item	2956039	et	3	main
ta	doc_973441205366_item	2956045	et	4	main
uksele	doc_973441205366_item	2956047	et	3	main
häälega	doc_973441205366_item	2956055	et	3	main
imestas	doc_973441205366_item	2956057	et	3	main
siis	doc_973441205366_item	2956059	et	3	main
et	doc_973441205366_item	2956062	et	3	main
külmetatud	doc_973441205366_item	2956065	et	4	main
see	doc_973441205366_item	2956068	et	3	main
pirukaid	doc_973441205366_item	2956074	et	3	main
vajuta	doc_973441205366_item	2956078	et	4	main
lingile	doc_973441205366_item	2956079	et	3	main
siis	doc_973441205366_item	2956080	et	3	main
ukse	doc_973441205366_item	2956081	et	3	main
läheb	doc_973441205366_item	2956082	et	3	main
lahti	doc_973441205366_item	2956083	et	4	main
läks	doc_973441205366_item	2956090	et	3	main
ja	doc_973441205366_item	2956092	et	3	main
korvi	doc_973441205366_item	2956097	et	4	main
küsis	doc_973441205366_item	2956129	et	3	main
punamütsike	doc_973441205366_item	2956130	et	4	main
see	doc_973441205366_item	2956131	et	3	main
miks	doc_973441205366_item	2956142	et	4	main
sul	doc_973441205366_item	2956143	et	3	main
kõrvad	doc_973441205366_item	2956147	et	3	main
selle	doc_973441205366_item	2956150	et	4	main
paremini	doc_973441205366_item	2956153	et	4	main
et	doc_973441205366_item	2956167	et	3	main
sind	doc_973441205366_item	2956170	et	4	main
siis	doc_973441205366_item	2956172	et	3	main
hunt	doc_973441205366_item	2956173	et	3	main
tema	doc_973441205366_item	2956177	et	4	main
alla	doc_973441205366_item	2956178	et	3	main
samal	doc_973441205366_item	2956179	et	3	main
ajal	doc_973441205366_item	2956180	et	4	main
kulsid	doc_973441205366_item	2956186	et	4	main
astusid	doc_973441205366_item	2956188	et	4	main
hunti	doc_973441205366_item	2956192	et	4	main
kõht	doc_973441205366_item	2956193	et	3	main
punamütsike	doc_973441205366_item	2956200	et	4	main
ilusad	doc_973441205366_item	2956201	et	3	main
ja	doc_973441205366_item	2956202	et	3	main
nad	doc_973441205366_item	2956204	et	3	main
väga	doc_973441205366_item	2956206	et	3	main
kutsusid	doc_973441205366_item	2956214	et	4	main
ümberjutustus	doc_973441205367_item	2956219	et	3	main
punamütsike	doc_973441205367_item	2956221	et	4	main
üks	doc_973441205367_item	2956224	et	3	main
vanaema	doc_973441205367_item	2956237	et	4	main
armastas	doc_973441205367_item	2956238	et	3	main
roohkem	doc_973441205367_item	2956241	et	4	main
õmblus	doc_973441205367_item	2956243	et	3	main
kõige	doc_973441205367_item	2956250	et	4	main
kord	doc_973441205367_item	2956258	et	4	main
punamütsikesele	doc_973441205367_item	2956264	et	4	main
tuli	doc_973441205367_item	2956265	et	4	main
ta	doc_973441205367_item	2956271	et	4	main
on	doc_973441205367_item	2956272	et	4	main
ja	doc_973441205367_item	2956277	et	3	main
punamütsike	doc_973441205367_item	2956280	et	4	main
võttis	doc_973441205367_item	2956281	et	3	main
palus	doc_973441205367_item	2956327	et	4	main
ja	doc_973441205367_item	2956330	et	3	main
on	doc_973441205366_item	2955892	et	4	main
väga	doc_973441205366_item	2955893	et	3	main
maha	doc_973441205366_item	2955898	et	4	main
ja	doc_973441205366_item	2955899	et	3	main
hakkas	doc_973441205366_item	2955900	et	3	main
korjama	doc_973441205366_item	2955901	et	3	main
lilli	doc_973441205366_item	2955902	et	4	main
suur	doc_973441205366_item	2955907	et	3	main
hall	doc_973441205366_item	2955908	et	4	main
hunt	doc_973441205366_item	2955909	et	3	main
tere	doc_973441205366_item	2955910	et	3	main
punamütsike	doc_973441205366_item	2955911	et	4	main
kuhu	doc_973441205366_item	2955912	et	3	main
sa	doc_973441205366_item	2955913	et	3	main
lähed	doc_973441205366_item	2955914	et	3	main
tere	doc_973441205366_item	2955915	et	3	main
ma	doc_973441205366_item	2955916	et	3	main
lähen	doc_973441205366_item	2955917	et	3	main
vanaema	doc_973441205366_item	2955925	et	4	main
küsis	doc_973441205366_item	2955926	et	3	main
kõht	doc_973441205366_item	2955933	et	3	main
tupli	doc_973441205366_item	2955947	et	4	main
tean	doc_973441205366_item	2955951	et	3	main
vanaemad	doc_973441205366_item	2955953	et	3	main
natukese	doc_973441205366_item	2955969	et	4	main
uksele	doc_973441205366_item	2955979	et	3	main
kes	doc_973441205366_item	2955981	et	4	main
ütles	doc_973441205366_item	2956014	et	3	main
vanaema	doc_973441205366_item	2956015	et	4	main
hunt	doc_973441205366_item	2956016	et	3	main
vajutas	doc_973441205366_item	2956017	et	3	main
lingile	doc_973441205366_item	2956018	et	3	main
uks	doc_973441205366_item	2956019	et	3	main
läks	doc_973441205366_item	2956020	et	3	main
ukse	doc_973441205366_item	2956032	et	3	main
pärast	doc_973441205366_item	2956042	et	4	main
jämeda	doc_973441205366_item	2956054	et	3	main
aga	doc_973441205366_item	2956058	et	3	main
ta	doc_973441205366_item	2956060	et	4	main
vanaema	doc_973441205366_item	2956063	et	4	main
ma	doc_973441205366_item	2956072	et	3	main
ütles	doc_973441205366_item	2956084	et	3	main
ta	doc_973441205366_item	2956093	et	4	main
astus	doc_973441205366_item	2956094	et	3	main
siia	doc_973441205366_item	2956101	et	4	main
minu	doc_973441205366_item	2956102	et	3	main
silmad	doc_973441205366_item	2956128	et	4	main
et	doc_973441205366_item	2956135	et	3	main
see	doc_973441205366_item	2956148	et	3	main
kulda	doc_973441205366_item	2956154	et	4	main
ära	doc_973441205366_item	2956168	et	4	main
hüppis	doc_973441205366_item	2956174	et	4	main
ja	doc_973441205366_item	2956175	et	3	main
maja	doc_973441205366_item	2956183	et	4	main
puuraiujad	doc_973441205366_item	2956184	et	3	main
tuppa	doc_973441205366_item	2956189	et	3	main
lõikasid	doc_973441205366_item	2956191	et	4	main
terved	doc_973441205366_item	2956203	et	4	main
rõmsad	doc_973441205366_item	2956207	et	4	main
tänasid	doc_973441205366_item	2956211	et	4	main
juua	doc_973441205366_item	2956217	et	3	main
veel	doc_973441205367_item	2956240	et	4	main
talle	doc_973441205367_item	2956244	et	4	main
punase	doc_973441205367_item	2956245	et	4	main
hakkasid	doc_973441205367_item	2956253	et	4	main
üks	doc_973441205367_item	2956257	et	3	main
küpsetas	doc_973441205367_item	2956260	et	3	main
pirukad	doc_973441205367_item	2956261	et	3	main
ütles	doc_973441205367_item	2956263	et	3	main
haige	doc_973441205367_item	2956273	et	4	main
mahla	doc_973441205367_item	2956279	et	4	main
läks	doc_973441205367_item	2956284	et	3	main
elab	doc_973441205366_item	2955924	et	3	main
väga	doc_973441205366_item	2955935	et	3	main
ta	doc_973441205366_item	2955937	et	4	main
süüa	doc_973441205366_item	2955939	et	3	main
ära	doc_973441205366_item	2955940	et	4	main
kõiged	doc_973441205366_item	2955952	et	4	main
armastavad	doc_973441205366_item	2955954	et	4	main
ütles	doc_973441205366_item	2955956	et	3	main
ja	doc_973441205366_item	2955958	et	3	main
vanaema	doc_973441205366_item	2955960	et	4	main
läks	doc_973441205366_item	2955966	et	3	main
seal	doc_973441205366_item	2955982	et	4	main
on	doc_973441205366_item	2955983	et	4	main
küsis	doc_973441205366_item	2955984	et	3	main
vanaema	doc_973441205366_item	2955985	et	4	main
ta	doc_973441205366_item	2955986	et	4	main
oli	doc_973441205366_item	2955987	et	3	main
tõesti	doc_973441205366_item	2955988	et	3	main
haige	doc_973441205366_item	2955989	et	4	main
ja	doc_973441205366_item	2955990	et	3	main
lamas	doc_973441205366_item	2955991	et	3	main
voodi	doc_973441205366_item	2955992	et	4	main
see	doc_973441205366_item	2955993	et	3	main
olen	doc_973441205366_item	2955994	et	3	main
mina	doc_973441205366_item	2955995	et	4	main
punamütsike	doc_973441205366_item	2955996	et	4	main
ma	doc_973441205366_item	2955997	et	3	main
tõin	doc_973441205366_item	2955998	et	3	main
sulle	doc_973441205366_item	2955999	et	3	main
pirukaid	doc_973441205366_item	2956000	et	3	main
ja	doc_973441205366_item	2956001	et	3	main
purgi	doc_973441205366_item	2956002	et	4	main
võid	doc_973441205366_item	2956003	et	4	main
vastas	doc_973441205366_item	2956004	et	4	main
hunt	doc_973441205366_item	2956005	et	3	main
penikese	doc_973441205366_item	2956006	et	4	main
vajuta	doc_973441205366_item	2956008	et	4	main
lingile	doc_973441205366_item	2956009	et	3	main
siis	doc_973441205366_item	2956010	et	3	main
ukse	doc_973441205366_item	2956011	et	3	main
läheb	doc_973441205366_item	2956012	et	3	main
häälega	doc_973441205366_item	2956007	et	3	main
lahti	doc_973441205366_item	2956013	et	4	main
lahti	doc_973441205366_item	2956021	et	4	main
vanaema	doc_973441205366_item	2956024	et	4	main
ta	doc_973441205366_item	2956031	et	4	main
heitis	doc_973441205366_item	2956034	et	3	main
tuli	doc_973441205366_item	2956043	et	4	main
koputas	doc_973441205366_item	2956046	et	3	main
on	doc_973441205366_item	2956064	et	4	main
mina	doc_973441205366_item	2956070	et	4	main
tõi	doc_973441205366_item	2956073	et	3	main
hunt	doc_973441205366_item	2956085	et	3	main
vajutas	doc_973441205366_item	2956087	et	3	main
uks	doc_973441205366_item	2956089	et	3	main
lahti	doc_973441205366_item	2956091	et	4	main
jurde	doc_973441205366_item	2956103	et	4	main
ütles	doc_973441205366_item	2956104	et	3	main
hunt	doc_973441205366_item	2956105	et	3	main
punamütsike	doc_973441205366_item	2956106	et	4	main
pani	doc_973441205366_item	2956107	et	4	main
korvi	doc_973441205366_item	2956108	et	4	main
lauale	doc_973441205366_item	2956109	et	4	main
ja	doc_973441205366_item	2956110	et	3	main
tuli	doc_973441205366_item	2956111	et	4	main
vanaema	doc_973441205366_item	2956112	et	4	main
jurde	doc_973441205366_item	2956113	et	4	main
ta	doc_973441205366_item	2956114	et	4	main
oli	doc_973441205366_item	2956115	et	3	main
väga	doc_973441205366_item	2956116	et	3	main
imestas	doc_973441205366_item	2956117	et	3	main
kui	doc_973441205366_item	2956118	et	3	main
ta	doc_973441205366_item	2956119	et	4	main
nägi	doc_973441205366_item	2956120	et	3	main
miks	doc_973441205366_item	2956123	et	4	main
sul	doc_973441205366_item	2956124	et	3	main
selle	doc_973441205366_item	2956133	et	4	main
näha	doc_973441205366_item	2956137	et	3	main
sind	doc_973441205366_item	2956138	et	4	main
hunt	doc_973441205366_item	2956140	et	3	main
on	doc_973441205366_item	2956144	et	4	main
sind	doc_973441205366_item	2956155	et	4	main
vanaema	doc_973441205366_item	2956156	et	4	main
miks	doc_973441205366_item	2956157	et	4	main
sul	doc_973441205366_item	2956158	et	3	main
on	doc_973441205366_item	2956159	et	4	main
nii	doc_973441205366_item	2956160	et	3	main
suured	doc_973441205366_item	2956161	et	3	main
hambad	doc_973441205366_item	2956162	et	3	main
see	doc_973441205366_item	2956163	et	3	main
on	doc_973441205366_item	2956164	et	4	main
selle	doc_973441205366_item	2956165	et	4	main
süüa	doc_973441205366_item	2956169	et	3	main
ja	doc_973441205366_item	2956171	et	3	main
mööda	doc_973441205366_item	2956182	et	4	main
noisi	doc_973441205366_item	2956187	et	4	main
nad	doc_973441205366_item	2956190	et	3	main
tulid	doc_973441205366_item	2956196	et	4	main
vanaema	doc_973441205366_item	2956198	et	4	main
ja	doc_973441205366_item	2956199	et	3	main
õnelik	doc_973441205366_item	2956209	et	4	main
ja	doc_973441205366_item	2956213	et	3	main
tee	doc_973441205366_item	2956216	et	4	main
oli	doc_973441205367_item	2956227	et	3	main
väike	doc_973441205367_item	2956228	et	4	main
talle	doc_973441205367_item	2956254	et	4	main
kutsuma	doc_973441205367_item	2956255	et	3	main
jurde	doc_973441205367_item	2956267	et	4	main
vanaemale	doc_973441205367_item	2956275	et	3	main
pudel	doc_973441205367_item	2956278	et	3	main
korv	doc_973441205367_item	2956282	et	3	main
juurde	doc_973441205367_item	2956286	et	4	main
tee	doc_973441205367_item	2956291	et	4	main
läks	doc_973441205367_item	2956292	et	3	main
läbi	doc_973441205367_item	2956293	et	4	main
metsa	doc_973441205367_item	2956294	et	4	main
ilm	doc_973441205367_item	2956295	et	3	main
oli	doc_973441205367_item	2956296	et	3	main
ilus	doc_973441205367_item	2956297	et	4	main
päike	doc_973441205367_item	2956298	et	3	main
paistas	doc_973441205367_item	2956299	et	4	main
linnud	doc_973441205367_item	2956300	et	3	main
laulu	doc_973441205367_item	2956301	et	4	main
laulsid	doc_973441205367_item	2956302	et	4	main
õitsevad	doc_973441205367_item	2956303	et	4	main
lilled	doc_973441205367_item	2956304	et	3	main
äkki	doc_973441205367_item	2956305	et	3	main
tuli	doc_973441205367_item	2956306	et	4	main
tema	doc_973441205367_item	2956307	et	4	main
juurde	doc_973441205367_item	2956308	et	4	main
suur	doc_973441205367_item	2956309	et	3	main
hall	doc_973441205367_item	2956310	et	4	main
hunt	doc_973441205367_item	2956311	et	3	main
ja	doc_973441205367_item	2956312	et	3	main
ütles	doc_973441205367_item	2956313	et	3	main
tere	doc_973441205367_item	2956314	et	3	main
punamütsike	doc_973441205367_item	2956315	et	4	main
ajame	doc_973441205367_item	2956316	et	3	main
natuke	doc_973441205367_item	2956317	et	4	main
juttu	doc_973441205367_item	2956318	et	4	main
kuhu	doc_973441205367_item	2956319	et	3	main
sa	doc_973441205367_item	2956320	et	3	main
lähed	doc_973441205367_item	2956321	et	3	main
talle	doc_973441205367_item	2956328	et	4	main
kooki	doc_973441205367_item	2956329	et	4	main
on	doc_973441205367_item	2956334	et	4	main
hunt	doc_973441205367_item	2956341	et	3	main
väga	doc_973441205367_item	2956344	et	3	main
metsa	doc_973441205367_item	2956350	et	4	main
punamütsike	doc_973441205367_item	2956356	et	4	main
hunt	doc_973441205367_item	2956357	et	3	main
tulin	doc_973441205367_item	2956382	et	3	main
läks	doc_973441205367_item	2956394	et	3	main
pärast	doc_973441205367_item	2956409	et	4	main
pirukad	doc_973441205367_item	2956276	et	3	main
ja	doc_973441205367_item	2956283	et	3	main
vanaema	doc_973441205367_item	2956285	et	4	main
vanaema	doc_973441205367_item	2956287	et	4	main
elas	doc_973441205367_item	2956288	et	3	main
teises	doc_973441205367_item	2956289	et	4	main
külas	doc_973441205367_item	2956290	et	3	main
vaatama	doc_973441205367_item	2956325	et	3	main
ääres	doc_973441205367_item	2956351	et	4	main
rohelises	doc_973441205367_item	2956353	et	4	main
maja	doc_973441205367_item	2956365	et	4	main
on	doc_973441205367_item	2956373	et	4	main
see	doc_973441205367_item	2956374	et	3	main
olen	doc_973441205367_item	2956375	et	3	main
peenikese	doc_973441205367_item	2956380	et	4	main
häälega	doc_973441205367_item	2956381	et	3	main
liingile	doc_973441205367_item	2956391	et	4	main
ja	doc_973441205367_item	2956392	et	3	main
üks	doc_973441205367_item	2956393	et	3	main
neelab	doc_973441205367_item	2956400	et	3	main
heittis	doc_973441205367_item	2956404	et	4	main
magama	doc_973441205367_item	2956405	et	3	main
voodisse	doc_973441205367_item	2956406	et	3	main
natukese	doc_973441205367_item	2956407	et	4	main
aja	doc_973441205367_item	2956408	et	4	main
punamütsike	doc_973441205367_item	2956411	et	4	main
punamütsike	doc_973441205367_item	2956422	et	4	main
tüdruk	doc_973441205367_item	2956424	et	3	main
vajuta	doc_973441205367_item	2956425	et	4	main
liingile	doc_973441205367_item	2956426	et	4	main
lahti	doc_973441205367_item	2956430	et	4	main
vanaema	doc_973441205367_item	2956447	et	4	main
selle	doc_973441205367_item	2956456	et	4	main
hunt	doc_973441205367_item	2956463	et	3	main
nii	doc_973441205367_item	2956468	et	3	main
on	doc_973441205367_item	2956482	et	4	main
hambad	doc_973441205367_item	2956485	et	3	main
jai	doc_973441205367_item	2956500	et	4	main
vanaema	doc_973441205367_item	2956522	et	4	main
oli	doc_973441205367_item	2956528	et	3	main
elus	doc_973441205367_item	2956529	et	4	main
ja	doc_973441205367_item	2956530	et	3	main
talle	doc_973441205368_item	2956541	et	4	main
tegi	doc_973441205368_item	2956548	et	4	main
mütsi	doc_973441205368_item	2956554	et	4	main
kutsuma	doc_973441205368_item	2956565	et	3	main
kooki	doc_973441205368_item	2956575	et	4	main
on	doc_973441205368_item	2956583	et	4	main
mütsi	doc_973441205368_item	2956590	et	4	main
ja	doc_973441205368_item	2956594	et	3	main
ütles	doc_973441205368_item	2956612	et	3	main
kuhu	doc_973441205368_item	2956615	et	3	main
ta	doc_973441205368_item	2956622	et	4	main
haige	doc_973441205368_item	2956624	et	4	main
vastas	doc_973441205368_item	2956641	et	4	main
väga	doc_973441205368_item	2956645	et	3	main
tüdruk	doc_973441205368_item	2956647	et	3	main
jooksis	doc_973441205368_item	2956662	et	4	main
juurde	doc_973441205368_item	2956671	et	4	main
küsis	doc_973441205368_item	2956678	et	3	main
jooksis	doc_973441205368_item	2956713	et	4	main
vanaema	doc_973441205368_item	2956714	et	4	main
ta	doc_973441205368_item	2956718	et	4	main
pärast	doc_973441205368_item	2956720	et	4	main
natukese	doc_973441205368_item	2956724	et	4	main
hiljem	doc_973441205368_item	2956726	et	3	main
vanaema	doc_973441205368_item	2956729	et	4	main
maja	doc_973441205368_item	2956730	et	4	main
see	doc_973441205368_item	2956740	et	3	main
ja	doc_973441205368_item	2956750	et	3	main
lahti	doc_973441205368_item	2956752	et	4	main
hunt	doc_973441205368_item	2956754	et	3	main
vajutas	doc_973441205368_item	2956756	et	3	main
ja	doc_973441205368_item	2956758	et	3	main
korvi	doc_973441205368_item	2956762	et	4	main
laua	doc_973441205368_item	2956763	et	3	main
peale	doc_973441205368_item	2956764	et	4	main
panis	doc_973441205368_item	2956768	et	4	main
hundile	doc_973441205368_item	2956780	et	3	main
sul	doc_973441205368_item	2956782	et	3	main
miks	doc_973441205368_item	2956793	et	4	main
punamütsike	doc_973441205368_item	2956821	et	4	main
lähen	doc_973441205367_item	2956323	et	3	main
vanaema	doc_973441205367_item	2956324	et	4	main
haige	doc_973441205367_item	2956335	et	4	main
kas	doc_973441205367_item	2956336	et	3	main
vanaema	doc_973441205367_item	2956337	et	4	main
elab	doc_973441205367_item	2956338	et	3	main
kaugel	doc_973441205367_item	2956339	et	4	main
pärast	doc_973441205367_item	2956362	et	4	main
oli	doc_973441205367_item	2956363	et	3	main
juba	doc_973441205367_item	2956364	et	3	main
seal	doc_973441205367_item	2956372	et	4	main
hunt	doc_973441205367_item	2956396	et	3	main
tuppa	doc_973441205367_item	2956398	et	3	main
tuli	doc_973441205367_item	2956410	et	4	main
koputas	doc_973441205367_item	2956413	et	3	main
üksele	doc_973441205367_item	2956414	et	3	main
kopp-kopp	doc_973441205367_item	2956415	et	3	main
seal	doc_973441205367_item	2956417	et	4	main
on	doc_973441205367_item	2956418	et	4	main
kes	doc_973441205367_item	2956416	et	4	main
see	doc_973441205367_item	2956419	et	3	main
olen	doc_973441205367_item	2956420	et	3	main
mina	doc_973441205367_item	2956421	et	4	main
ütles	doc_973441205367_item	2956423	et	3	main
vajutab	doc_973441205367_item	2956432	et	3	main
astub	doc_973441205367_item	2956435	et	3	main
vanaema	doc_973441205367_item	2956444	et	4	main
ta	doc_973441205367_item	2956445	et	4	main
küsis	doc_973441205367_item	2956446	et	3	main
vanaema	doc_973441205367_item	2956464	et	4	main
on	doc_973441205367_item	2956467	et	4	main
suured	doc_973441205367_item	2956469	et	3	main
see	doc_973441205367_item	2956471	et	3	main
selle	doc_973441205367_item	2956473	et	4	main
jaoks	doc_973441205367_item	2956474	et	4	main
et	doc_973441205367_item	2956475	et	3	main
miks	doc_973441205367_item	2956480	et	4	main
sul	doc_973441205367_item	2956481	et	3	main
on	doc_973441205367_item	2956487	et	4	main
ära	doc_973441205367_item	2956491	et	4	main
süüa	doc_973441205367_item	2956492	et	3	main
sind	doc_973441205367_item	2956493	et	4	main
ja	doc_973441205367_item	2956494	et	3	main
hunt	doc_973441205367_item	2956495	et	3	main
neelas	doc_973441205367_item	2956496	et	3	main
alla	doc_973441205367_item	2956497	et	3	main
hundi	doc_973441205367_item	2956524	et	3	main
punamütsike	doc_973441205368_item	2956534	et	4	main
elas	doc_973441205368_item	2956535	et	3	main
kord	doc_973441205368_item	2956536	et	4	main
punamütsikesele	doc_973441205368_item	2956549	et	4	main
punase	doc_973441205368_item	2956550	et	4	main
iga	doc_973441205368_item	2956555	et	4	main
mine	doc_973441205368_item	2956570	et	3	main
vii	doc_973441205368_item	2956573	et	4	main
talle	doc_973441205368_item	2956574	et	4	main
mahla	doc_973441205368_item	2956578	et	4	main
punamütsike	doc_973441205368_item	2956587	et	4	main
vanaemale	doc_973441205368_item	2956596	et	3	main
läbi	doc_973441205368_item	2956604	et	4	main
äkki	doc_973441205368_item	2956605	et	3	main
tuli	doc_973441205368_item	2956606	et	4	main
tema	doc_973441205368_item	2956607	et	4	main
ja	doc_973441205368_item	2956611	et	3	main
lähen	doc_973441205368_item	2956619	et	3	main
vastas	doc_973441205368_item	2956625	et	4	main
tüdruk	doc_973441205368_item	2956626	et	3	main
aga	doc_973441205368_item	2956627	et	3	main
sinu	doc_973441205368_item	2956628	et	3	main
vanaema	doc_973441205368_item	2956629	et	4	main
elab	doc_973441205368_item	2956630	et	3	main
kaugel	doc_973441205368_item	2956631	et	4	main
küsis	doc_973441205368_item	2956632	et	3	main
hunt	doc_973441205368_item	2956633	et	3	main
oled	doc_973441205368_item	2956644	et	3	main
viia	doc_973441205367_item	2956332	et	3	main
ei	doc_973441205367_item	2956342	et	4	main
kaugel	doc_973441205367_item	2956345	et	4	main
ta	doc_973441205367_item	2956346	et	4	main
elab	doc_973441205367_item	2956347	et	3	main
teises	doc_973441205367_item	2956348	et	4	main
külas	doc_973441205367_item	2956349	et	3	main
jooksis	doc_973441205367_item	2956358	et	4	main
juures	doc_973441205367_item	2956366	et	4	main
ta	doc_973441205367_item	2956367	et	4	main
koputas	doc_973441205367_item	2956368	et	3	main
üksele	doc_973441205367_item	2956369	et	3	main
mina	doc_973441205367_item	2956376	et	4	main
hunt	doc_973441205367_item	2956379	et	3	main
sind	doc_973441205367_item	2956383	et	4	main
vaatama	doc_973441205367_item	2956384	et	3	main
ema	doc_973441205367_item	2956385	et	4	main
saatis	doc_973441205367_item	2956386	et	3	main
pirukad	doc_973441205367_item	2956387	et	3	main
ja	doc_973441205367_item	2956388	et	3	main
mahla	doc_973441205367_item	2956389	et	4	main
lahti	doc_973441205367_item	2956395	et	4	main
ja	doc_973441205367_item	2956399	et	3	main
alla	doc_973441205367_item	2956401	et	3	main
ja	doc_973441205367_item	2956403	et	3	main
ta	doc_973441205367_item	2956412	et	4	main
ja	doc_973441205367_item	2956427	et	3	main
liingile	doc_973441205367_item	2956433	et	4	main
ja	doc_973441205367_item	2956434	et	3	main
tuppa	doc_973441205367_item	2956436	et	3	main
oli	doc_973441205367_item	2956438	et	3	main
imestas	doc_973441205367_item	2956440	et	3	main
ta	doc_973441205367_item	2956442	et	4	main
nägi	doc_973441205367_item	2956443	et	3	main
jaoks	doc_973441205367_item	2956457	et	4	main
et	doc_973441205367_item	2956458	et	3	main
näha	doc_973441205367_item	2956459	et	3	main
miks	doc_973441205367_item	2956465	et	4	main
kõrvad	doc_973441205367_item	2956470	et	3	main
on	doc_973441205367_item	2956472	et	4	main
vanaema	doc_973441205367_item	2956479	et	4	main
see	doc_973441205367_item	2956486	et	3	main
jaoks	doc_973441205367_item	2956489	et	4	main
magama	doc_973441205367_item	2956501	et	3	main
samal	doc_973441205367_item	2956502	et	3	main
ajal	doc_973441205367_item	2956503	et	4	main
ja	doc_973441205367_item	2956521	et	3	main
tulid	doc_973441205367_item	2956523	et	4	main
kõhust	doc_973441205367_item	2956525	et	3	main
välja	doc_973441205367_item	2956526	et	4	main
mõlemad	doc_973441205367_item	2956527	et	3	main
väike	doc_973441205368_item	2956537	et	4	main
tüdruk	doc_973441205368_item	2956538	et	3	main
vanaema	doc_973441205368_item	2956544	et	4	main
rohkem	doc_973441205368_item	2956546	et	4	main
vanaema	doc_973441205368_item	2956547	et	4	main
ja	doc_973441205368_item	2956576	et	3	main
kuulsin	doc_973441205368_item	2956580	et	3	main
vanaema	doc_973441205368_item	2956582	et	4	main
haige	doc_973441205368_item	2956584	et	4	main
hästi	doc_973441205368_item	2956585	et	3	main
vastas	doc_973441205368_item	2956586	et	4	main
võttis	doc_973441205368_item	2956592	et	3	main
elas	doc_973441205368_item	2956598	et	3	main
metsas	doc_973441205368_item	2956600	et	3	main
tee	doc_973441205368_item	2956601	et	4	main
läks	doc_973441205368_item	2956602	et	3	main
metsa	doc_973441205368_item	2956603	et	4	main
hall	doc_973441205368_item	2956609	et	4	main
hunt	doc_973441205368_item	2956610	et	3	main
lähed	doc_973441205368_item	2956617	et	3	main
vanaema	doc_973441205368_item	2956620	et	4	main
väikeses	doc_973441205368_item	2956638	et	4	main
tüdruk	doc_973441205368_item	2956642	et	3	main
vanaemale	doc_973441205368_item	2956651	et	3	main
ma	doc_973441205368_item	2956652	et	3	main
tean	doc_973441205368_item	2956653	et	3	main
et	doc_973441205368_item	2956654	et	3	main
kõik	doc_973441205368_item	2956655	et	4	main
vanaemad	doc_973441205368_item	2956656	et	3	main
ja	doc_973441205368_item	2956661	et	3	main
natukese	doc_973441205368_item	2956664	et	4	main
vanaema	doc_973441205367_item	2956402	et	4	main
uks	doc_973441205367_item	2956428	et	3	main
ta	doc_973441205367_item	2956437	et	4	main
väga	doc_973441205367_item	2956439	et	3	main
kui	doc_973441205367_item	2956441	et	3	main
paremini	doc_973441205367_item	2956460	et	4	main
sind	doc_973441205367_item	2956461	et	4	main
vastas	doc_973441205367_item	2956462	et	4	main
paremini	doc_973441205367_item	2956476	et	4	main
nii	doc_973441205367_item	2956483	et	3	main
suured	doc_973441205367_item	2956484	et	3	main
selle	doc_973441205367_item	2956488	et	4	main
et	doc_973441205367_item	2956490	et	3	main
läks	doc_973441205367_item	2956504	et	3	main
terved	doc_973441205367_item	2956531	et	4	main
ema	doc_973441205368_item	2956539	et	4	main
väga	doc_973441205368_item	2956542	et	3	main
tüdrukule	doc_973441205368_item	2956569	et	3	main
pudel	doc_973441205368_item	2956577	et	3	main
pani	doc_973441205368_item	2956589	et	4	main
läks	doc_973441205368_item	2956595	et	3	main
teises	doc_973441205368_item	2956599	et	4	main
punamütsike	doc_973441205368_item	2956614	et	4	main
ma	doc_973441205368_item	2956618	et	3	main
läks	doc_973441205367_item	2956429	et	3	main
punamütsike	doc_973441205367_item	2956431	et	4	main
miks	doc_973441205367_item	2956448	et	4	main
sul	doc_973441205367_item	2956449	et	3	main
on	doc_973441205367_item	2956450	et	4	main
nii	doc_973441205367_item	2956451	et	3	main
suured	doc_973441205367_item	2956452	et	3	main
silmad	doc_973441205367_item	2956453	et	4	main
see	doc_973441205367_item	2956454	et	3	main
on	doc_973441205367_item	2956455	et	4	main
sul	doc_973441205367_item	2956466	et	3	main
kuuldi	doc_973441205367_item	2956477	et	4	main
sind	doc_973441205367_item	2956478	et	4	main
punamütsike	doc_973441205367_item	2956498	et	4	main
hunt	doc_973441205367_item	2956499	et	3	main
majast	doc_973441205367_item	2956505	et	4	main
mööda	doc_973441205367_item	2956506	et	4	main
puuraiujad	doc_973441205367_item	2956507	et	3	main
nad	doc_973441205367_item	2956508	et	3	main
astusid	doc_973441205367_item	2956509	et	4	main
tuppa	doc_973441205367_item	2956510	et	3	main
ja	doc_973441205367_item	2956511	et	3	main
said	doc_973441205367_item	2956512	et	4	main
äru	doc_973441205367_item	2956513	et	4	main
mis	doc_973441205367_item	2956514	et	4	main
juhtus	doc_973441205367_item	2956515	et	3	main
nad	doc_973441205367_item	2956516	et	3	main
lõikasid	doc_973441205367_item	2956517	et	4	main
kõht	doc_973441205367_item	2956518	et	3	main
hundi	doc_973441205367_item	2956519	et	3	main
punamütsike	doc_973441205367_item	2956520	et	4	main
ümberjutustus	doc_973441205368_item	2956532	et	3	main
ümberjutustus	doc_973441205368_item	2956533	et	3	main
armastas	doc_973441205368_item	2956540	et	3	main
ja	doc_973441205368_item	2956543	et	3	main
veel	doc_973441205368_item	2956545	et	4	main
mütsi	doc_973441205368_item	2956551	et	4	main
tüdruk	doc_973441205368_item	2956552	et	3	main
kandis	doc_973441205368_item	2956553	et	4	main
päev	doc_973441205368_item	2956556	et	3	main
talle	doc_973441205368_item	2956557	et	4	main
meeldiv	doc_973441205368_item	2956558	et	4	main
mütsi	doc_973441205368_item	2956559	et	4	main
nii	doc_973441205368_item	2956560	et	3	main
hakkasid	doc_973441205368_item	2956561	et	4	main
kõik	doc_973441205368_item	2956562	et	4	main
teda	doc_973441205368_item	2956563	et	4	main
punamütsikeseks	doc_973441205368_item	2956564	et	4	main
ükskord	doc_973441205368_item	2956566	et	3	main
ütles	doc_973441205368_item	2956567	et	3	main
ema	doc_973441205368_item	2956568	et	4	main
vanaema	doc_973441205368_item	2956571	et	4	main
vaatama	doc_973441205368_item	2956572	et	3	main
ma	doc_973441205368_item	2956579	et	3	main
et	doc_973441205368_item	2956581	et	3	main
ta	doc_973441205368_item	2956588	et	4	main
päha	doc_973441205368_item	2956591	et	4	main
korvi	doc_973441205368_item	2956593	et	4	main
vanaema	doc_973441205368_item	2956597	et	4	main
juurde	doc_973441205368_item	2956608	et	4	main
tere	doc_973441205368_item	2956613	et	3	main
sa	doc_973441205368_item	2956616	et	3	main
juurde	doc_973441205368_item	2956621	et	4	main
on	doc_973441205368_item	2956623	et	4	main
ta	doc_973441205368_item	2956634	et	4	main
elab	doc_973441205368_item	2956635	et	3	main
teises	doc_973441205368_item	2956636	et	4	main
metsas	doc_973441205368_item	2956637	et	3	main
sa	doc_973441205368_item	2956643	et	3	main
hea	doc_973441205368_item	2956646	et	4	main
lilli	doc_973441205368_item	2956658	et	4	main
ütles	doc_973441205368_item	2956659	et	3	main
metsa	doc_973441205368_item	2956663	et	4	main
aja	doc_973441205368_item	2956665	et	4	main
vanaema	doc_973441205368_item	2956669	et	4	main
maja	doc_973441205368_item	2956670	et	4	main
on	doc_973441205368_item	2956677	et	4	main
jooksis	doc_973441205368_item	2956710	et	4	main
tuppa	doc_973441205368_item	2956711	et	3	main
ja	doc_973441205368_item	2956716	et	3	main
alla	doc_973441205368_item	2956719	et	3	main
heitis	doc_973441205368_item	2956722	et	3	main
koputas	doc_973441205368_item	2956733	et	3	main
punamütsike	doc_973441205368_item	2956743	et	4	main
vajuta	doc_973441205368_item	2956748	et	4	main
uks	doc_973441205368_item	2956751	et	3	main
ütles	doc_973441205368_item	2956753	et	3	main
hunt	doc_973441205368_item	2956766	et	3	main
miks	doc_973441205368_item	2956781	et	4	main
silmad	doc_973441205368_item	2956785	et	4	main
sul	doc_973441205368_item	2956794	et	3	main
nii	doc_973441205368_item	2956795	et	3	main
kõrvad	doc_973441205368_item	2956797	et	3	main
magama	doc_973441205368_item	2956825	et	3	main
samal	doc_973441205368_item	2956826	et	3	main
läksid	doc_973441205368_item	2956828	et	4	main
hunti	doc_973441205368_item	2956834	et	4	main
tulid	doc_973441205368_item	2956844	et	4	main
kõhust	doc_973441205368_item	2956845	et	3	main
olid	doc_973441205368_item	2956847	et	4	main
terved	doc_973441205368_item	2956848	et	4	main
nad	doc_973441205368_item	2956849	et	3	main
ema	doc_973441205369_item	2956927	et	4	main
küpsetas	doc_973441205369_item	2956928	et	3	main
kooki	doc_973441205369_item	2956929	et	4	main
et	doc_973441205369_item	2956935	et	3	main
pudel	doc_973441205369_item	2956943	et	3	main
ütles	doc_973441205369_item	2956947	et	3	main
ta	doc_973441205369_item	2956949	et	4	main
pani	doc_973441205369_item	2956950	et	4	main
mütsi	doc_973441205369_item	2956951	et	4	main
vanaema	doc_973441205369_item	2956958	et	4	main
elas	doc_973441205369_item	2956959	et	3	main
teises	doc_973441205369_item	2956960	et	4	main
külas	doc_973441205369_item	2956961	et	3	main
ilus	doc_973441205369_item	2956968	et	4	main
punamütsike	doc_973441205369_item	2956975	et	4	main
mõtles	doc_973441205369_item	2956976	et	3	main
ta	doc_973441205369_item	2956986	et	4	main
pani	doc_973441205369_item	2956987	et	4	main
teises	doc_973441205369_item	2957032	et	4	main
külas	doc_973441205369_item	2957033	et	3	main
vastas	doc_973441205369_item	2957039	et	4	main
oled	doc_973441205369_item	2957058	et	3	main
korja	doc_973441205369_item	2957062	et	4	main
vanaemale	doc_973441205369_item	2957065	et	3	main
ja	doc_973441205369_item	2957066	et	3	main
tean	doc_973441205369_item	2957067	et	3	main
ära	doc_973441205369_item	2957076	et	4	main
natukese	doc_973441205369_item	2957077	et	4	main
maja	doc_973441205369_item	2957084	et	4	main
rohelises	doc_973441205368_item	2956639	et	4	main
majas	doc_973441205368_item	2956640	et	3	main
korja	doc_973441205368_item	2956648	et	4	main
kimp	doc_973441205368_item	2956649	et	3	main
lilli	doc_973441205368_item	2956650	et	4	main
hund	doc_973441205368_item	2956660	et	4	main
ta	doc_973441205368_item	2956672	et	4	main
koputas	doc_973441205368_item	2956673	et	3	main
uksele	doc_973441205368_item	2956674	et	3	main
vanaema	doc_973441205368_item	2956679	et	4	main
see	doc_973441205368_item	2956680	et	3	main
olen	doc_973441205368_item	2956681	et	3	main
mina	doc_973441205368_item	2956682	et	4	main
punamütsike	doc_973441205368_item	2956683	et	4	main
vastas	doc_973441205368_item	2956684	et	4	main
hunt	doc_973441205368_item	2956685	et	3	main
peenikese	doc_973441205368_item	2956686	et	4	main
hääljaga	doc_973441205368_item	2956687	et	4	main
ma	doc_973441205368_item	2956688	et	3	main
tulin	doc_973441205368_item	2956689	et	3	main
sind	doc_973441205368_item	2956690	et	4	main
vaatama	doc_973441205368_item	2956691	et	3	main
ema	doc_973441205368_item	2956692	et	4	main
palus	doc_973441205368_item	2956693	et	4	main
sulle	doc_973441205368_item	2956694	et	3	main
kooki	doc_973441205368_item	2956695	et	4	main
ja	doc_973441205368_item	2956696	et	3	main
mahla	doc_973441205368_item	2956697	et	4	main
viia	doc_973441205368_item	2956698	et	3	main
vajuta	doc_973441205368_item	2956699	et	4	main
lingile	doc_973441205368_item	2956700	et	3	main
ja	doc_973441205368_item	2956701	et	3	main
uks	doc_973441205368_item	2956702	et	3	main
lahti	doc_973441205368_item	2956703	et	4	main
ütles	doc_973441205368_item	2956704	et	3	main
vanaema	doc_973441205368_item	2956705	et	4	main
hund	doc_973441205368_item	2956706	et	4	main
vajutas	doc_973441205368_item	2956707	et	3	main
lingile	doc_973441205368_item	2956708	et	3	main
ja	doc_973441205368_item	2956709	et	3	main
armastavad	doc_973441205368_item	2956657	et	4	main
hunt	doc_973441205368_item	2956668	et	3	main
ta	doc_973441205368_item	2956712	et	4	main
neelas	doc_973441205368_item	2956717	et	3	main
ta	doc_973441205368_item	2956721	et	4	main
punamütsike	doc_973441205368_item	2956728	et	4	main
mina	doc_973441205368_item	2956742	et	4	main
tulin	doc_973441205368_item	2956745	et	3	main
vaatama	doc_973441205368_item	2956747	et	3	main
tüdruk	doc_973441205368_item	2956755	et	3	main
lingile	doc_973441205368_item	2956757	et	3	main
astus	doc_973441205368_item	2956759	et	3	main
pani	doc_973441205368_item	2956761	et	4	main
ta	doc_973441205368_item	2956774	et	4	main
oli	doc_973441205368_item	2956775	et	3	main
väga	doc_973441205368_item	2956776	et	3	main
imestanud	doc_973441205368_item	2956777	et	4	main
tüdruk	doc_973441205368_item	2956778	et	3	main
küsis	doc_973441205368_item	2956779	et	3	main
see	doc_973441205368_item	2956786	et	3	main
on	doc_973441205368_item	2956787	et	4	main
et	doc_973441205368_item	2956789	et	3	main
parenimi	doc_973441205368_item	2956790	et	4	main
näha	doc_973441205368_item	2956791	et	3	main
ja	doc_973441205368_item	2956823	et	3	main
nägid	doc_973441205368_item	2956833	et	4	main
vanaema	doc_973441205368_item	2956841	et	4	main
õmblesid	doc_973441205368_item	2956850	et	4	main
hundi	doc_973441205368_item	2956851	et	3	main
kõhu	doc_973441205368_item	2956852	et	3	main
enne	doc_973441205368_item	2956853	et	4	main
tal	doc_973441205368_item	2956859	et	3	main
janu	doc_973441205368_item	2956861	et	4	main
jooksis	doc_973441205368_item	2956863	et	4	main
jõe	doc_973441205368_item	2956864	et	3	main
äärde	doc_973441205368_item	2956865	et	4	main
olid	doc_973441205368_item	2956883	et	4	main
rõõmsaid	doc_973441205368_item	2956884	et	3	main
ümberjutustus	doc_973441205369_item	2956885	et	3	main
ümberjutustus	doc_973441205369_item	2956886	et	3	main
kõik	doc_973441205369_item	2956921	et	4	main
teda	doc_973441205369_item	2956923	et	4	main
ja	doc_973441205369_item	2956930	et	3	main
ütles	doc_973441205369_item	2956931	et	3	main
talle	doc_973441205369_item	2956940	et	4	main
hea	doc_973441205369_item	2956945	et	4	main
läbi	doc_973441205369_item	2956965	et	4	main
ilm	doc_973441205369_item	2956966	et	3	main
oli	doc_973441205369_item	2956967	et	3	main
laulsid	doc_973441205369_item	2956972	et	4	main
hea	doc_973441205369_item	2956984	et	4	main
meel	doc_973441205369_item	2956985	et	4	main
korvi	doc_973441205369_item	2956988	et	4	main
viia	doc_973441205369_item	2957024	et	3	main
kus	doc_973441205369_item	2957026	et	3	main
vanaema	doc_973441205369_item	2957028	et	4	main
elab	doc_973441205369_item	2957029	et	3	main
ääres	doc_973441205369_item	2957035	et	4	main
ühes	doc_973441205369_item	2957036	et	4	main
hunt	doc_973441205369_item	2957041	et	3	main
tema	doc_973441205369_item	2957048	et	4	main
kõht	doc_973441205369_item	2957049	et	3	main
oli	doc_973441205369_item	2957050	et	3	main
mõtles	doc_973441205369_item	2957053	et	3	main
ja	doc_973441205369_item	2957055	et	3	main
väga	doc_973441205369_item	2957059	et	3	main
kimp	doc_973441205369_item	2957063	et	3	main
lilli	doc_973441205369_item	2957072	et	4	main
nägemiseni	doc_973441205369_item	2957073	et	4	main
hunt	doc_973441205369_item	2957074	et	3	main
jooksis	doc_973441205369_item	2957075	et	4	main
see	doc_973441205369_item	2957095	et	3	main
ma	doc_973441205369_item	2957103	et	3	main
vaatama	doc_973441205369_item	2957106	et	3	main
kokki	doc_973441205369_item	2957110	et	4	main
hiljem	doc_973441205368_item	2956666	et	3	main
oli	doc_973441205368_item	2956667	et	3	main
kes	doc_973441205368_item	2956675	et	4	main
seal	doc_973441205368_item	2956676	et	4	main
juurde	doc_973441205368_item	2956715	et	4	main
aja	doc_973441205368_item	2956725	et	4	main
juurde	doc_973441205368_item	2956731	et	4	main
ja	doc_973441205368_item	2956732	et	3	main
uksele	doc_973441205368_item	2956734	et	3	main
seal	doc_973441205368_item	2956736	et	4	main
on	doc_973441205368_item	2956737	et	4	main
küsis	doc_973441205368_item	2956738	et	3	main
hunt	doc_973441205368_item	2956739	et	3	main
olen	doc_973441205368_item	2956741	et	3	main
lingile	doc_973441205368_item	2956749	et	3	main
ütles	doc_973441205368_item	2956765	et	3	main
suured	doc_973441205368_item	2956784	et	3	main
sind	doc_973441205368_item	2956792	et	4	main
selleks	doc_973441205368_item	2956800	et	4	main
on	doc_973441205368_item	2956799	et	4	main
et	doc_973441205368_item	2956801	et	3	main
parenimi	doc_973441205368_item	2956802	et	4	main
kuulma	doc_973441205368_item	2956803	et	3	main
sind	doc_973441205368_item	2956804	et	4	main
miks	doc_973441205368_item	2956805	et	4	main
sul	doc_973441205368_item	2956806	et	3	main
nii	doc_973441205368_item	2956807	et	3	main
suured	doc_973441205368_item	2956808	et	3	main
hambad	doc_973441205368_item	2956809	et	3	main
see	doc_973441205368_item	2956810	et	3	main
on	doc_973441205368_item	2956811	et	4	main
selleks	doc_973441205368_item	2956812	et	4	main
et	doc_973441205368_item	2956813	et	3	main
sind	doc_973441205368_item	2956814	et	4	main
süüa	doc_973441205368_item	2956815	et	3	main
ära	doc_973441205368_item	2956816	et	4	main
vastas	doc_973441205368_item	2956817	et	4	main
hunt	doc_973441205368_item	2956818	et	3	main
ja	doc_973441205368_item	2956819	et	3	main
neelas	doc_973441205368_item	2956820	et	3	main
jäi	doc_973441205368_item	2956824	et	3	main
ajal	doc_973441205368_item	2956827	et	4	main
vanaema	doc_973441205368_item	2956835	et	4	main
voodis	doc_973441205368_item	2956836	et	3	main
nad	doc_973441205368_item	2956837	et	3	main
lõikasid	doc_973441205368_item	2956838	et	4	main
nad	doc_973441205368_item	2956846	et	3	main
hunt	doc_973441205368_item	2956857	et	3	main
punamütsike	doc_973441205368_item	2956879	et	4	main
palusid	doc_973441205368_item	2956880	et	4	main
puuraiujaid	doc_973441205368_item	2956881	et	3	main
päev	doc_973441205369_item	2956919	et	3	main
ja	doc_973441205369_item	2956920	et	3	main
kord	doc_973441205369_item	2956926	et	4	main
ma	doc_973441205369_item	2956933	et	3	main
vanaema	doc_973441205369_item	2956936	et	4	main
haige	doc_973441205369_item	2956938	et	4	main
mahla	doc_973441205369_item	2956944	et	4	main
küll	doc_973441205369_item	2956946	et	4	main
tüdruk	doc_973441205369_item	2956948	et	3	main
tee	doc_973441205369_item	2956962	et	4	main
läks	doc_973441205369_item	2956963	et	3	main
metsa	doc_973441205369_item	2956964	et	4	main
linnud	doc_973441205369_item	2956971	et	3	main
sinu	doc_973441205369_item	2957027	et	3	main
ta	doc_973441205369_item	2957030	et	4	main
voodisse	doc_973441205368_item	2956723	et	3	main
tuli	doc_973441205368_item	2956727	et	4	main
kes	doc_973441205368_item	2956735	et	4	main
ma	doc_973441205368_item	2956744	et	3	main
sind	doc_973441205368_item	2956746	et	4	main
tuppa	doc_973441205368_item	2956760	et	3	main
tüdruk	doc_973441205368_item	2956767	et	3	main
korvi	doc_973441205368_item	2956769	et	4	main
ja	doc_973441205368_item	2956770	et	3	main
läks	doc_973441205368_item	2956771	et	3	main
voodi	doc_973441205368_item	2956772	et	4	main
juurde	doc_973441205368_item	2956773	et	4	main
nii	doc_973441205368_item	2956783	et	3	main
selleks	doc_973441205368_item	2956788	et	4	main
suured	doc_973441205368_item	2956796	et	3	main
see	doc_973441205368_item	2956798	et	3	main
alla	doc_973441205368_item	2956822	et	3	main
ja	doc_973441205368_item	2956842	et	3	main
punamütsike	doc_973441205368_item	2956843	et	4	main
ärkas	doc_973441205368_item	2956858	et	3	main
sest	doc_973441205368_item	2956866	et	4	main
ta	doc_973441205368_item	2956867	et	4	main
tahtis	doc_973441205368_item	2956868	et	3	main
juua	doc_973441205368_item	2956869	et	3	main
kivid	doc_973441205368_item	2956870	et	3	main
olid	doc_973441205368_item	2956871	et	4	main
rasked	doc_973441205368_item	2956872	et	3	main
ja	doc_973441205368_item	2956873	et	3	main
hunt	doc_973441205368_item	2956874	et	3	main
ära	doc_973441205368_item	2956875	et	4	main
uppus	doc_973441205368_item	2956876	et	3	main
vanaema	doc_973441205368_item	2956877	et	4	main
ja	doc_973441205368_item	2956878	et	3	main
punamütsike	doc_973441205369_item	2956887	et	4	main
elas	doc_973441205369_item	2956888	et	3	main
kord	doc_973441205369_item	2956889	et	4	main
väike	doc_973441205369_item	2956890	et	4	main
tüdruk	doc_973441205369_item	2956891	et	3	main
ta	doc_973441205369_item	2956892	et	4	main
oli	doc_973441205369_item	2956893	et	3	main
väga	doc_973441205369_item	2956894	et	3	main
ilus	doc_973441205369_item	2956895	et	4	main
ema	doc_973441205369_item	2956896	et	4	main
armastas	doc_973441205369_item	2956897	et	3	main
teda	doc_973441205369_item	2956898	et	4	main
väga	doc_973441205369_item	2956899	et	3	main
ja	doc_973441205369_item	2956900	et	3	main
vanaema	doc_973441205369_item	2956901	et	4	main
veel	doc_973441205369_item	2956902	et	4	main
rohkem	doc_973441205369_item	2956903	et	4	main
üks	doc_973441205369_item	2956904	et	3	main
kord	doc_973441205369_item	2956905	et	4	main
vanaema	doc_973441205369_item	2956906	et	4	main
tüdrukule	doc_973441205369_item	2956908	et	3	main
tegi	doc_973441205369_item	2956907	et	4	main
punase	doc_973441205369_item	2956909	et	4	main
mütsi	doc_973441205369_item	2956910	et	4	main
ta	doc_973441205369_item	2956911	et	4	main
sobis	doc_973441205369_item	2956912	et	4	main
talle	doc_973441205369_item	2956913	et	4	main
hästi	doc_973441205369_item	2956914	et	3	main
tüdruk	doc_973441205369_item	2956915	et	3	main
kandis	doc_973441205369_item	2956916	et	4	main
mütsi	doc_973441205369_item	2956917	et	4	main
iga	doc_973441205369_item	2956918	et	4	main
majast	doc_973441205368_item	2956829	et	4	main
mööda	doc_973441205368_item	2956830	et	4	main
puuraiujad	doc_973441205368_item	2956831	et	3	main
nad	doc_973441205368_item	2956832	et	3	main
hunti	doc_973441205368_item	2956839	et	4	main
kõhu	doc_973441205368_item	2956840	et	3	main
panid	doc_973441205368_item	2956854	et	4	main
sinna	doc_973441205368_item	2956855	et	3	main
kivid	doc_973441205368_item	2956856	et	3	main
oli	doc_973441205368_item	2956860	et	3	main
ta	doc_973441205368_item	2956862	et	4	main
kõik	doc_973441205368_item	2956882	et	4	main
hakkasid	doc_973441205369_item	2956922	et	4	main
punamütsikeseks	doc_973441205369_item	2956924	et	4	main
kutsuma	doc_973441205369_item	2956925	et	3	main
punamütsikesele	doc_973441205369_item	2956932	et	4	main
on	doc_973441205369_item	2956937	et	4	main
vii	doc_973441205369_item	2956939	et	4	main
ja	doc_973441205369_item	2956942	et	3	main
pähe	doc_973441205369_item	2956952	et	4	main
võttis	doc_973441205369_item	2956953	et	3	main
paistis	doc_973441205369_item	2956970	et	3	main
lilled	doc_973441205369_item	2956973	et	3	main
kimbu	doc_973441205369_item	2956979	et	3	main
tal	doc_973441205369_item	2956981	et	3	main
maha	doc_973441205369_item	2956989	et	4	main
ja	doc_973441205369_item	2956990	et	3	main
algas	doc_973441205369_item	2956991	et	3	main
korjama	doc_973441205369_item	2956992	et	3	main
äkki	doc_973441205369_item	2956993	et	3	main
tuli	doc_973441205369_item	2956994	et	4	main
tema	doc_973441205369_item	2956995	et	4	main
juurde	doc_973441205369_item	2956996	et	4	main
suur	doc_973441205369_item	2956997	et	3	main
hall	doc_973441205369_item	2956998	et	4	main
hunt	doc_973441205369_item	2956999	et	3	main
ja	doc_973441205369_item	2957000	et	3	main
ütles	doc_973441205369_item	2957001	et	3	main
tere	doc_973441205369_item	2957002	et	3	main
mida	doc_973441205369_item	2957004	et	4	main
sa	doc_973441205369_item	2957005	et	3	main
teed	doc_973441205369_item	2957006	et	4	main
punamütsike	doc_973441205369_item	2957003	et	4	main
ja	doc_973441205369_item	2957007	et	3	main
kuhu	doc_973441205369_item	2957008	et	3	main
sa	doc_973441205369_item	2957009	et	3	main
lähed	doc_973441205369_item	2957010	et	3	main
ma	doc_973441205369_item	2957011	et	3	main
lähen	doc_973441205369_item	2957012	et	3	main
vanaema	doc_973441205369_item	2957013	et	4	main
vaatama	doc_973441205369_item	2957014	et	3	main
ta	doc_973441205369_item	2957015	et	4	main
on	doc_973441205369_item	2957016	et	4	main
haige	doc_973441205369_item	2957017	et	4	main
ema	doc_973441205369_item	2957018	et	4	main
palus	doc_973441205369_item	2957019	et	4	main
mind	doc_973441205369_item	2957020	et	4	main
kuulsin	doc_973441205369_item	2956934	et	3	main
kooki	doc_973441205369_item	2956941	et	4	main
korvi	doc_973441205369_item	2956954	et	4	main
kätte	doc_973441205369_item	2956955	et	4	main
ja	doc_973441205369_item	2956956	et	3	main
läks	doc_973441205369_item	2956957	et	3	main
päike	doc_973441205369_item	2956969	et	3	main
õitsesid	doc_973441205369_item	2956974	et	4	main
korjan	doc_973441205369_item	2956977	et	3	main
vanaemale	doc_973441205369_item	2956978	et	3	main
lilli	doc_973441205369_item	2956980	et	4	main
on	doc_973441205369_item	2956982	et	4	main
kindlasti	doc_973441205369_item	2956983	et	3	main
kooki	doc_973441205369_item	2957021	et	4	main
metsa	doc_973441205369_item	2957034	et	4	main
punamütsike	doc_973441205369_item	2957040	et	4	main
punamütsikese	doc_973441205369_item	2957043	et	4	main
sa	doc_973441205369_item	2957057	et	3	main
aja	doc_973441205369_item	2957078	et	4	main
pärast	doc_973441205369_item	2957079	et	4	main
ta	doc_973441205369_item	2957080	et	4	main
juba	doc_973441205369_item	2957081	et	3	main
oli	doc_973441205369_item	2957082	et	3	main
kes	doc_973441205369_item	2957090	et	4	main
see	doc_973441205369_item	2957091	et	3	main
on	doc_973441205369_item	2957092	et	4	main
küsis	doc_973441205369_item	2957093	et	3	main
häälega	doc_973441205369_item	2957102	et	3	main
vanaema	doc_973441205369_item	2957121	et	4	main
ja	doc_973441205369_item	2957125	et	3	main
ja	doc_973441205369_item	2957133	et	3	main
neelas	doc_973441205369_item	2957134	et	3	main
uksele	doc_973441205369_item	2957152	et	3	main
see	doc_973441205369_item	2957155	et	3	main
küsis	doc_973441205369_item	2957157	et	3	main
on	doc_973441205369_item	2957160	et	4	main
mina	doc_973441205369_item	2957161	et	4	main
punamütsike	doc_973441205369_item	2957182	et	4	main
vajutas	doc_973441205369_item	2957183	et	3	main
lingile	doc_973441205369_item	2957184	et	3	main
ja	doc_973441205369_item	2957185	et	3	main
pani	doc_973441205369_item	2957200	et	4	main
ja	doc_973441205369_item	2957022	et	3	main
mahla	doc_973441205369_item	2957023	et	4	main
aga	doc_973441205369_item	2957025	et	3	main
süüa	doc_973441205369_item	2957046	et	3	main
sest	doc_973441205369_item	2957047	et	4	main
aga	doc_973441205369_item	2957052	et	3	main
ütles	doc_973441205369_item	2957056	et	3	main
hea	doc_973441205369_item	2957060	et	4	main
täpselt	doc_973441205369_item	2957068	et	4	main
et	doc_973441205369_item	2957069	et	3	main
vanaemad	doc_973441205369_item	2957070	et	3	main
armastavad	doc_973441205369_item	2957071	et	4	main
vanaema	doc_973441205369_item	2957083	et	4	main
on	doc_973441205369_item	2957096	et	4	main
punamütsike	doc_973441205369_item	2957098	et	4	main
ütles	doc_973441205369_item	2957099	et	3	main
hunt	doc_973441205369_item	2957100	et	3	main
sind	doc_973441205369_item	2957105	et	4	main
palus	doc_973441205369_item	2957108	et	4	main
ja	doc_973441205369_item	2957111	et	3	main
mahla	doc_973441205369_item	2957112	et	4	main
viia	doc_973441205369_item	2957113	et	3	main
vajuta	doc_973441205369_item	2957114	et	4	main
lingile	doc_973441205369_item	2957115	et	3	main
ja	doc_973441205369_item	2957116	et	3	main
uks	doc_973441205369_item	2957117	et	3	main
läheb	doc_973441205369_item	2957118	et	3	main
lahti	doc_973441205369_item	2957119	et	4	main
ütles	doc_973441205369_item	2957120	et	3	main
läks	doc_973441205369_item	2957127	et	3	main
jooksis	doc_973441205369_item	2957130	et	4	main
vanaema	doc_973441205369_item	2957131	et	4	main
natukese	doc_973441205369_item	2957145	et	4	main
koputas	doc_973441205369_item	2957151	et	3	main
sind	doc_973441205369_item	2957165	et	4	main
vaatama	doc_973441205369_item	2957166	et	3	main
kooki	doc_973441205369_item	2957170	et	4	main
üks	doc_973441205369_item	2957186	et	3	main
läks	doc_973441205369_item	2957187	et	3	main
lauale	doc_973441205369_item	2957193	et	4	main
tule	doc_973441205369_item	2957195	et	4	main
ja	doc_973441205369_item	2957202	et	3	main
suured	doc_973441205369_item	2957223	et	3	main
vastas	doc_973441205369_item	2957233	et	4	main
tüdruk	doc_973441205369_item	2957234	et	3	main
vanaema	doc_973441205369_item	2957235	et	4	main
miks	doc_973441205369_item	2957236	et	4	main
et	doc_973441205369_item	2957258	et	3	main
paremini	doc_973441205369_item	2957260	et	4	main
miks	doc_973441205369_item	2957277	et	4	main
ära	doc_973441205369_item	2957288	et	4	main
magama	doc_973441205369_item	2957297	et	3	main
sel	doc_973441205369_item	2957301	et	3	main
majast	doc_973441205369_item	2957304	et	4	main
astusid	doc_973441205369_item	2957314	et	4	main
aru	doc_973441205369_item	2957323	et	4	main
lõikasid	doc_973441205369_item	2957327	et	4	main
tulid	doc_973441205369_item	2957334	et	4	main
hundi	doc_973441205369_item	2957335	et	3	main
kõhust	doc_973441205369_item	2957336	et	3	main
nad	doc_973441205369_item	2957337	et	3	main
olid	doc_973441205369_item	2957338	et	4	main
lahti	doc_973441205369_item	2957346	et	4	main
äärde	doc_973441205369_item	2957363	et	4	main
juua	doc_973441205369_item	2957366	et	3	main
punamütsike	doc_973441205369_item	2957376	et	4	main
ja	doc_973441205369_item	2957384	et	3	main
kooki	doc_973441205369_item	2957386	et	4	main
ümberjutustus	doc_973441205370_item	2957390	et	3	main
punamütsike	doc_973441205370_item	2957391	et	4	main
elas	doc_973441205370_item	2957392	et	3	main
väike	doc_973441205370_item	2957395	et	4	main
elab	doc_973441205369_item	2957031	et	3	main
rohelises	doc_973441205369_item	2957037	et	4	main
majas	doc_973441205369_item	2957038	et	3	main
tahtis	doc_973441205369_item	2957042	et	3	main
kohe	doc_973441205369_item	2957044	et	4	main
ära	doc_973441205369_item	2957045	et	4	main
tühi	doc_973441205369_item	2957051	et	3	main
ümber	doc_973441205369_item	2957054	et	3	main
tüdruk	doc_973441205369_item	2957061	et	3	main
lilli	doc_973441205369_item	2957064	et	4	main
juures	doc_973441205369_item	2957085	et	4	main
ta	doc_973441205369_item	2957086	et	4	main
koputas	doc_973441205369_item	2957087	et	3	main
uksele	doc_973441205369_item	2957088	et	3	main
kopp-kopp	doc_973441205369_item	2957089	et	3	main
peenikese	doc_973441205369_item	2957101	et	4	main
lingile	doc_973441205369_item	2957124	et	3	main
hunt	doc_973441205369_item	2957129	et	3	main
voodisse	doc_973441205369_item	2957140	et	3	main
ja	doc_973441205369_item	2957141	et	3	main
tuli	doc_973441205369_item	2957148	et	4	main
punamütsike	doc_973441205369_item	2957162	et	4	main
ma	doc_973441205369_item	2957163	et	3	main
tulin	doc_973441205369_item	2957164	et	3	main
lingile	doc_973441205369_item	2957175	et	3	main
lahti	doc_973441205369_item	2957179	et	4	main
lahti	doc_973441205369_item	2957188	et	4	main
mahla	doc_973441205369_item	2957203	et	4	main
lauale	doc_973441205369_item	2957204	et	4	main
ja	doc_973441205369_item	2957205	et	3	main
juurde	doc_973441205369_item	2957208	et	4	main
oli	doc_973441205369_item	2957210	et	3	main
sul	doc_973441205369_item	2957221	et	3	main
selleks	doc_973441205369_item	2957228	et	4	main
on	doc_973441205369_item	2957243	et	4	main
miks	doc_973441205369_item	2957249	et	4	main
sul	doc_973441205369_item	2957250	et	3	main
nii	doc_973441205369_item	2957251	et	3	main
suured	doc_973441205369_item	2957252	et	3	main
kõrvad	doc_973441205369_item	2957253	et	3	main
selleks	doc_973441205369_item	2957257	et	4	main
suur	doc_973441205369_item	2957280	et	3	main
suu	doc_973441205369_item	2957281	et	4	main
on	doc_973441205369_item	2957284	et	4	main
ta	doc_973441205369_item	2957291	et	4	main
neelas	doc_973441205369_item	2957292	et	3	main
punamütsikest	doc_973441205369_item	2957293	et	4	main
ja	doc_973441205369_item	2957298	et	3	main
nägid	doc_973441205369_item	2957308	et	4	main
et	doc_973441205369_item	2957309	et	3	main
uks	doc_973441205369_item	2957310	et	3	main
lahti	doc_973441205369_item	2957312	et	4	main
vanaema	doc_973441205369_item	2957094	et	4	main
mina	doc_973441205369_item	2957097	et	4	main
tulin	doc_973441205369_item	2957104	et	3	main
ema	doc_973441205369_item	2957107	et	4	main
sulle	doc_973441205369_item	2957109	et	3	main
vajutas	doc_973441205369_item	2957123	et	3	main
juurde	doc_973441205369_item	2957132	et	4	main
teda	doc_973441205369_item	2957135	et	4	main
alla	doc_973441205369_item	2957136	et	3	main
ta	doc_973441205369_item	2957137	et	4	main
heitis	doc_973441205369_item	2957138	et	3	main
vanaema	doc_973441205369_item	2957139	et	4	main
jäi	doc_973441205369_item	2957142	et	3	main
punamütsikest	doc_973441205369_item	2957143	et	4	main
ootama	doc_973441205369_item	2957144	et	3	main
punamütsike	doc_973441205369_item	2957149	et	4	main
ja	doc_973441205369_item	2957150	et	3	main
kes	doc_973441205369_item	2957154	et	4	main
hunt	doc_973441205369_item	2957158	et	3	main
ema	doc_973441205369_item	2957167	et	4	main
ja	doc_973441205369_item	2957171	et	3	main
tuua	doc_973441205369_item	2957173	et	3	main
ja	doc_973441205369_item	2957176	et	3	main
koogid	doc_973441205369_item	2957190	et	4	main
ja	doc_973441205369_item	2957191	et	3	main
koogi	doc_973441205369_item	2957201	et	4	main
vanaema	doc_973441205369_item	2957207	et	4	main
punamütsike	doc_973441205369_item	2957209	et	4	main
on	doc_973441205369_item	2957225	et	4	main
selleks	doc_973441205369_item	2957244	et	4	main
et	doc_973441205369_item	2957245	et	3	main
paremini	doc_973441205369_item	2957246	et	4	main
joosta	doc_973441205369_item	2957247	et	4	main
see	doc_973441205369_item	2957255	et	3	main
nii	doc_973441205369_item	2957279	et	3	main
see	doc_973441205369_item	2957283	et	3	main
süüa	doc_973441205369_item	2957289	et	3	main
ja	doc_973441205369_item	2957290	et	3	main
jäi	doc_973441205369_item	2957296	et	3	main
hakkas	doc_973441205369_item	2957299	et	3	main
ajal	doc_973441205369_item	2957302	et	4	main
oli	doc_973441205369_item	2957311	et	3	main
nad	doc_973441205369_item	2957313	et	3	main
nägid	doc_973441205369_item	2957317	et	4	main
voodis	doc_973441205369_item	2957320	et	3	main
ja	doc_973441205369_item	2957340	et	3	main
sest	doc_973441205369_item	2957364	et	4	main
kivid	doc_973441205369_item	2957367	et	3	main
rasked	doc_973441205369_item	2957369	et	3	main
kukkus	doc_973441205369_item	2957372	et	3	main
vette	doc_973441205369_item	2957373	et	3	main
ja	doc_973441205369_item	2957375	et	3	main
tänasid	doc_973441205369_item	2957377	et	4	main
istusid	doc_973441205369_item	2957380	et	4	main
talle	doc_973441205370_item	2957407	et	4	main
sinu	doc_973441205370_item	2957413	et	3	main
on	doc_973441205370_item	2957415	et	4	main
ja	doc_973441205370_item	2957421	et	3	main
ema	doc_973441205370_item	2957431	et	4	main
nii	doc_973441205370_item	2957432	et	3	main
ütles	doc_973441205370_item	2957433	et	3	main
ta	doc_973441205370_item	2957436	et	4	main
väike	doc_973441205370_item	2957441	et	4	main
elas	doc_973441205370_item	2957452	et	3	main
metsa	doc_973441205370_item	2957458	et	4	main
tüdruk	doc_973441205370_item	2957462	et	3	main
läks	doc_973441205370_item	2957467	et	3	main
kohtus	doc_973441205370_item	2957479	et	4	main
punamütsike	doc_973441205370_item	2957480	et	4	main
sa	doc_973441205370_item	2957484	et	3	main
halb	doc_973441205370_item	2957495	et	3	main
hunt	doc_973441205369_item	2957122	et	3	main
uks	doc_973441205369_item	2957126	et	3	main
lahti	doc_973441205369_item	2957128	et	4	main
aja	doc_973441205369_item	2957146	et	4	main
pärast	doc_973441205369_item	2957147	et	4	main
kopp-kopp	doc_973441205369_item	2957153	et	3	main
on	doc_973441205369_item	2957156	et	4	main
see	doc_973441205369_item	2957159	et	3	main
palus	doc_973441205369_item	2957168	et	4	main
mind	doc_973441205369_item	2957169	et	4	main
mahla	doc_973441205369_item	2957172	et	4	main
vajuta	doc_973441205369_item	2957174	et	4	main
uks	doc_973441205369_item	2957177	et	3	main
läheb	doc_973441205369_item	2957178	et	3	main
vastas	doc_973441205369_item	2957180	et	4	main
hunt	doc_973441205369_item	2957181	et	3	main
pane	doc_973441205369_item	2957189	et	4	main
mahl	doc_973441205369_item	2957192	et	3	main
ja	doc_973441205369_item	2957194	et	3	main
siia	doc_973441205369_item	2957196	et	4	main
ütles	doc_973441205369_item	2957197	et	3	main
hunt	doc_973441205369_item	2957198	et	3	main
tüdruk	doc_973441205369_item	2957199	et	3	main
tuli	doc_973441205369_item	2957206	et	4	main
väga	doc_973441205369_item	2957211	et	3	main
imestunud	doc_973441205369_item	2957212	et	4	main
kui	doc_973441205369_item	2957213	et	3	main
ta	doc_973441205369_item	2957214	et	4	main
vanaema	doc_973441205369_item	2957215	et	4	main
nägi	doc_973441205369_item	2957216	et	3	main
ta	doc_973441205369_item	2957217	et	4	main
küsis	doc_973441205369_item	2957218	et	3	main
vanaema	doc_973441205369_item	2957219	et	4	main
miks	doc_973441205369_item	2957220	et	4	main
nii	doc_973441205369_item	2957222	et	3	main
see	doc_973441205369_item	2957226	et	3	main
paremini	doc_973441205369_item	2957231	et	4	main
kallistada	doc_973441205369_item	2957232	et	3	main
jallad	doc_973441205369_item	2957240	et	4	main
on	doc_973441205369_item	2957241	et	4	main
see	doc_973441205369_item	2957242	et	3	main
vanaema	doc_973441205369_item	2957248	et	4	main
on	doc_973441205369_item	2957256	et	4	main
sind	doc_973441205369_item	2957259	et	4	main
vanaema	doc_973441205369_item	2957276	et	4	main
sind	doc_973441205369_item	2957287	et	4	main
hunt	doc_973441205369_item	2957295	et	3	main
läksid	doc_973441205369_item	2957303	et	4	main
mööda	doc_973441205369_item	2957305	et	4	main
puuraiujad	doc_973441205369_item	2957306	et	3	main
nad	doc_973441205369_item	2957307	et	3	main
tuppa	doc_973441205369_item	2957315	et	3	main
hunti	doc_973441205369_item	2957318	et	4	main
vanaema	doc_973441205369_item	2957319	et	4	main
mis	doc_973441205369_item	2957324	et	4	main
nad	doc_973441205369_item	2957326	et	3	main
aga	doc_973441205369_item	2957347	et	3	main
enne	doc_973441205369_item	2957348	et	4	main
panid	doc_973441205369_item	2957349	et	4	main
sinna	doc_973441205369_item	2957350	et	3	main
hakkasid	doc_973441205369_item	2957385	et	4	main
üks	doc_973441205370_item	2957393	et	3	main
tüdruk	doc_973441205370_item	2957396	et	3	main
ja	doc_973441205370_item	2957397	et	3	main
väga	doc_973441205370_item	2957400	et	3	main
nimi	doc_973441205370_item	2957402	et	3	main
mulle	doc_973441205370_item	2957410	et	4	main
et	doc_973441205370_item	2957412	et	3	main
juurde	doc_973441205370_item	2957424	et	4	main
tea	doc_973441205370_item	2957428	et	4	main
mille	doc_973441205370_item	2957429	et	3	main
oli	doc_973441205370_item	2957437	et	3	main
vanaema	doc_973441205370_item	2957451	et	4	main
käed	doc_973441205369_item	2957224	et	3	main
on	doc_973441205369_item	2957227	et	4	main
et	doc_973441205369_item	2957229	et	3	main
sind	doc_973441205369_item	2957230	et	4	main
sul	doc_973441205369_item	2957237	et	3	main
nii	doc_973441205369_item	2957238	et	3	main
suured	doc_973441205369_item	2957239	et	3	main
on	doc_973441205369_item	2957254	et	4	main
kuulda	doc_973441205369_item	2957261	et	4	main
vanaema	doc_973441205369_item	2957262	et	4	main
miks	doc_973441205369_item	2957263	et	4	main
sul	doc_973441205369_item	2957264	et	3	main
nii	doc_973441205369_item	2957265	et	3	main
suured	doc_973441205369_item	2957266	et	3	main
silmad	doc_973441205369_item	2957267	et	4	main
on	doc_973441205369_item	2957268	et	4	main
see	doc_973441205369_item	2957269	et	3	main
on	doc_973441205369_item	2957270	et	4	main
selleks	doc_973441205369_item	2957271	et	4	main
et	doc_973441205369_item	2957272	et	3	main
sind	doc_973441205369_item	2957273	et	4	main
paremini	doc_973441205369_item	2957274	et	4	main
näha	doc_973441205369_item	2957275	et	3	main
sul	doc_973441205369_item	2957278	et	3	main
on	doc_973441205369_item	2957282	et	4	main
selleks	doc_973441205369_item	2957285	et	4	main
et	doc_973441205369_item	2957286	et	3	main
alla	doc_973441205369_item	2957294	et	3	main
norskama	doc_973441205369_item	2957300	et	3	main
ja	doc_973441205369_item	2957316	et	3	main
nad	doc_973441205369_item	2957321	et	3	main
juhtus	doc_973441205369_item	2957325	et	3	main
hundi	doc_973441205369_item	2957328	et	3	main
kõhu	doc_973441205369_item	2957329	et	3	main
lõhki	doc_973441205369_item	2957330	et	4	main
elu	doc_973441205369_item	2957339	et	4	main
terved	doc_973441205369_item	2957341	et	4	main
nad	doc_973441205369_item	2957342	et	3	main
õmblesid	doc_973441205369_item	2957343	et	4	main
hundi	doc_973441205369_item	2957344	et	3	main
kõhu	doc_973441205369_item	2957345	et	3	main
ta	doc_973441205369_item	2957360	et	4	main
jooksis	doc_973441205369_item	2957361	et	4	main
tahtis	doc_973441205369_item	2957365	et	3	main
ja	doc_973441205369_item	2957370	et	3	main
lauda	doc_973441205369_item	2957383	et	4	main
kord	doc_973441205370_item	2957394	et	4	main
tal	doc_973441205370_item	2957398	et	3	main
imelik	doc_973441205370_item	2957401	et	3	main
ema	doc_973441205370_item	2957409	et	4	main
vanaema	doc_973441205370_item	2957414	et	4	main
haige	doc_973441205370_item	2957416	et	4	main
võta	doc_973441205370_item	2957417	et	4	main
vanaema	doc_973441205370_item	2957423	et	4	main
noh	doc_973441205370_item	2957425	et	3	main
võib	doc_973441205370_item	2957434	et	3	main
vanaema	doc_973441205370_item	2957446	et	4	main
juurde	doc_973441205370_item	2957447	et	4	main
tasub	doc_973441205370_item	2957448	et	3	main
märkida	doc_973441205370_item	2957449	et	4	main
kaugel	doc_973441205370_item	2957453	et	4	main
on	doc_973441205370_item	2957455	et	4	main
vajalik	doc_973441205370_item	2957456	et	3	main
minna	doc_973441205370_item	2957457	et	3	main
vaene	doc_973441205370_item	2957461	et	4	main
ja	doc_973441205370_item	2957466	et	3	main
loomilikult	doc_973441205370_item	2957472	et	4	main
kui	doc_973441205370_item	2957473	et	3	main
alati	doc_973441205370_item	2957474	et	4	main
metsas	doc_973441205370_item	2957475	et	3	main
oli	doc_973441205370_item	2957476	et	3	main
hunt	doc_973441205370_item	2957477	et	3	main
hunt	doc_973441205370_item	2957478	et	3	main
küsis	doc_973441205370_item	2957482	et	3	main
sa	doc_973441205370_item	2957492	et	3	main
väga	doc_973441205370_item	2957494	et	3	main
tüdruk	doc_973441205370_item	2957496	et	3	main
juurde	doc_973441205370_item	2957529	et	4	main
vanaema	doc_973441205370_item	2957538	et	4	main
tõttu	doc_973441205370_item	2957547	et	4	main
vanaema	doc_973441205370_item	2957557	et	4	main
ja	doc_973441205370_item	2957558	et	3	main
ütles	doc_973441205370_item	2957559	et	3	main
noh	doc_973441205370_item	2957560	et	3	main
juba	doc_973441205370_item	2957567	et	3	main
lisas	doc_973441205370_item	2957574	et	4	main
не	doc_973441205370_item	2957576	et	2	main
sul	doc_973441205370_item	2957583	et	3	main
kõrval	doc_973441205370_item	2957608	et	4	main
hunti	doc_973441205370_item	2957624	et	4	main
hunti	doc_973441205370_item	2957639	et	4	main
punamütsike	doc_973441205371_item	2957651	et	4	main
lõbus	doc_973441205371_item	2957660	et	4	main
ja	doc_973441205371_item	2957661	et	3	main
väga	doc_973441205371_item	2957662	et	3	main
ilus	doc_973441205371_item	2957663	et	4	main
tüdruk	doc_973441205371_item	2957664	et	3	main
metsa	doc_973441205371_item	2957669	et	4	main
on	doc_973441205371_item	2957716	et	4	main
kallis	doc_973441205371_item	2957719	et	4	main
said	doc_973441205369_item	2957322	et	4	main
vanaema	doc_973441205369_item	2957331	et	4	main
ja	doc_973441205369_item	2957332	et	3	main
punamütsike	doc_973441205369_item	2957333	et	4	main
kivid	doc_973441205369_item	2957351	et	3	main
natukese	doc_973441205369_item	2957352	et	4	main
aja	doc_973441205369_item	2957353	et	4	main
pärast	doc_973441205369_item	2957354	et	4	main
hunt	doc_973441205369_item	2957355	et	3	main
ärkas	doc_973441205369_item	2957356	et	3	main
tal	doc_973441205369_item	2957357	et	3	main
oli	doc_973441205369_item	2957358	et	3	main
janu	doc_973441205369_item	2957359	et	4	main
jõe	doc_973441205369_item	2957362	et	3	main
olid	doc_973441205369_item	2957368	et	4	main
hunt	doc_973441205369_item	2957371	et	3	main
vanaema	doc_973441205369_item	2957374	et	4	main
puuraiujaid	doc_973441205369_item	2957378	et	3	main
nad	doc_973441205369_item	2957379	et	3	main
kõik	doc_973441205369_item	2957381	et	4	main
koos	doc_973441205369_item	2957382	et	4	main
sööma	doc_973441205369_item	2957387	et	4	main
lõpp	doc_973441205369_item	2957388	et	3	main
ümberjutustus	doc_973441205370_item	2957389	et	3	main
tema	doc_973441205370_item	2957408	et	4	main
mahla	doc_973441205370_item	2957418	et	4	main
ja	doc_973441205370_item	2957419	et	3	main
mine	doc_973441205370_item	2957422	et	3	main
ma	doc_973441205370_item	2957426	et	3	main
ei	doc_973441205370_item	2957427	et	4	main
olla	doc_973441205370_item	2957435	et	3	main
või	doc_973441205370_item	2957439	et	4	main
oma	doc_973441205370_item	2957445	et	4	main
oma	doc_973441205370_item	2957468	et	4	main
juurde	doc_973441205370_item	2957470	et	4	main
lähed	doc_973441205370_item	2957485	et	3	main
lollike	doc_973441205370_item	2957487	et	4	main
tubli	doc_973441205370_item	2957521	et	4	main
kiitas	doc_973441205370_item	2957523	et	4	main
hunt	doc_973441205370_item	2957524	et	3	main
ja	doc_973441205370_item	2957525	et	3	main
jooksis	doc_973441205370_item	2957526	et	4	main
ja	doc_973441205370_item	2957530	et	3	main
sõi	doc_973441205370_item	2957533	et	3	main
ära	doc_973441205370_item	2957534	et	4	main
oli	doc_973441205370_item	2957539	et	3	main
ta	doc_973441205370_item	2957548	et	4	main
hakkas	doc_973441205370_item	2957549	et	3	main
ootama	doc_973441205370_item	2957550	et	3	main
tüdrukut	doc_973441205370_item	2957551	et	3	main
halb	doc_973441205370_item	2957569	et	3	main
ta	doc_973441205370_item	2957579	et	4	main
hakkas	doc_973441205370_item	2957580	et	3	main
on	doc_973441205370_item	2957590	et	4	main
noh	doc_973441205370_item	2957591	et	3	main
lollike	doc_973441205370_item	2957592	et	4	main
ühe	doc_973441205370_item	2957593	et	4	main
sõnaga	doc_973441205370_item	2957594	et	3	main
mida	doc_973441205370_item	2957595	et	4	main
edasi	doc_973441205370_item	2957596	et	3	main
hunt	doc_973441205370_item	2957597	et	3	main
sõi	doc_973441205370_item	2957598	et	3	main
loomilikult	doc_973441205370_item	2957601	et	4	main
huntujahumeest	doc_973441205370_item	2957611	et	4	main
nad	doc_973441205370_item	2957612	et	3	main
vaatasid	doc_973441205370_item	2957613	et	4	main
ja	doc_973441205370_item	2957614	et	3	main
sa	doc_973441205370_item	2957622	et	3	main
nägid	doc_973441205370_item	2957625	et	4	main
hunti	doc_973441205370_item	2957627	et	4	main
jahumeest	doc_973441205370_item	2957630	et	4	main
ümberjutustus	doc_973441205371_item	2957650	et	3	main
ammu	doc_973441205371_item	2957652	et	4	main
vanaema	doc_973441205371_item	2957703	et	4	main
haigus	doc_973441205371_item	2957717	et	4	main
ema	doc_973441205371_item	2957720	et	4	main
olema	doc_973441205371_item	2957737	et	4	main
oli	doc_973441205371_item	2957742	et	3	main
paistis	doc_973441205371_item	2957745	et	3	main
laulasid	doc_973441205371_item	2957747	et	4	main
korjama	doc_973441205371_item	2957755	et	3	main
kimpu	doc_973441205371_item	2957756	et	4	main
ja	doc_973441205371_item	2957757	et	3	main
kallis	doc_973441205371_item	2957763	et	4	main
toon	doc_973441205371_item	2957776	et	4	main
haigus	doc_973441205371_item	2957780	et	4	main
tahaks	doc_973441205371_item	2957788	et	3	main
punamütsike	doc_973441205371_item	2957791	et	4	main
mõtles	doc_973441205371_item	2957793	et	3	main
ümber	doc_973441205371_item	2957795	et	3	main
juurde	doc_973441205371_item	2957800	et	4	main
voodis	doc_973441205371_item	2957806	et	3	main
suured	doc_973441205371_item	2957833	et	3	main
ja	doc_973441205371_item	2957838	et	3	main
oli	doc_973441205370_item	2957399	et	3	main
punamütsike	doc_973441205370_item	2957403	et	4	main
üks	doc_973441205370_item	2957404	et	3	main
kord	doc_973441205370_item	2957405	et	4	main
ütles	doc_973441205370_item	2957406	et	3	main
tundub	doc_973441205370_item	2957411	et	3	main
kooki	doc_973441205370_item	2957420	et	4	main
jaoks	doc_973441205370_item	2957430	et	4	main
purjus	doc_973441205370_item	2957438	et	3	main
ning	doc_973441205370_item	2957440	et	3	main
tüdruk	doc_973441205370_item	2957442	et	3	main
üksinda	doc_973441205370_item	2957443	et	4	main
läks	doc_973441205370_item	2957444	et	3	main
et	doc_973441205370_item	2957450	et	3	main
mõõda	doc_973441205370_item	2957459	et	4	main
ja	doc_973441205370_item	2957464	et	3	main
kuhu	doc_973441205370_item	2957483	et	3	main
väike	doc_973441205370_item	2957486	et	4	main
vanaema	doc_973441205370_item	2957488	et	4	main
juurde	doc_973441205370_item	2957489	et	4	main
märkis	doc_973441205370_item	2957497	et	3	main
hunt	doc_973441205370_item	2957498	et	3	main
sa	doc_973441205370_item	2957499	et	3	main
lähed	doc_973441205370_item	2957500	et	3	main
vanaema	doc_973441205370_item	2957501	et	4	main
juurde	doc_973441205370_item	2957502	et	4	main
aga	doc_973441205370_item	2957503	et	3	main
sul	doc_973441205370_item	2957504	et	3	main
ei	doc_973441205370_item	2957505	et	4	main
kimpu	doc_973441205370_item	2957507	et	4	main
ole	doc_973441205370_item	2957506	et	4	main
tegelikult	doc_973441205370_item	2957508	et	4	main
nii	doc_973441205370_item	2957509	et	3	main
nõustus	doc_973441205370_item	2957510	et	4	main
tüdruk	doc_973441205370_item	2957511	et	3	main
ma	doc_973441205370_item	2957512	et	3	main
korjan	doc_973441205370_item	2957513	et	3	main
ning	doc_973441205370_item	2957514	et	3	main
ainult	doc_973441205370_item	2957515	et	4	main
pärast	doc_973441205370_item	2957516	et	4	main
ma	doc_973441205370_item	2957517	et	3	main
hakkan	doc_973441205370_item	2957518	et	3	main
liikuda	doc_973441205370_item	2957519	et	3	main
edasi	doc_973441205370_item	2957520	et	3	main
hunti	doc_973441205370_item	2957536	et	4	main
midagi	doc_973441205370_item	2957543	et	4	main
nägis	doc_973441205370_item	2957555	et	4	main
ma	doc_973441205370_item	2957562	et	3	main
väga	doc_973441205370_item	2957568	et	3	main
punamütsike	doc_973441205370_item	2957570	et	4	main
mõtles	doc_973441205370_item	2957572	et	3	main
ja	doc_973441205370_item	2957573	et	3	main
старость	doc_973441205370_item	2957575	et	2	main
радость	doc_973441205370_item	2957577	et	2	main
pärast	doc_973441205370_item	2957578	et	4	main
miks	doc_973441205370_item	2957582	et	4	main
miks	doc_973441205370_item	2957585	et	4	main
sul	doc_973441205370_item	2957586	et	3	main
on	doc_973441205370_item	2957587	et	4	main
punamütsike	doc_973441205370_item	2957600	et	4	main
edasi	doc_973441205370_item	2957603	et	3	main
muinasjuttu	doc_973441205370_item	2957604	et	4	main
ja	doc_973441205370_item	2957623	et	3	main
hunti	doc_973441205370_item	2957632	et	4	main
tappid	doc_973441205370_item	2957633	et	4	main
ja	doc_973441205370_item	2957454	et	3	main
võttis	doc_973441205370_item	2957460	et	3	main
mahla	doc_973441205370_item	2957463	et	4	main
kooki	doc_973441205370_item	2957465	et	4	main
vanaema	doc_973441205370_item	2957469	et	4	main
noh	doc_973441205370_item	2957471	et	3	main
ja	doc_973441205370_item	2957481	et	3	main
vastas	doc_973441205370_item	2957490	et	4	main
tüdruk	doc_973441205370_item	2957491	et	3	main
oled	doc_973441205370_item	2957493	et	3	main
ise	doc_973441205370_item	2957527	et	4	main
ta	doc_973441205370_item	2957532	et	4	main
arvates	doc_973441205370_item	2957537	et	4	main
maitsevam	doc_973441205370_item	2957544	et	4	main
ja	doc_973441205370_item	2957545	et	3	main
see	doc_973441205370_item	2957546	et	3	main
oma	doc_973441205370_item	2957556	et	4	main
näen	doc_973441205370_item	2957563	et	3	main
et	doc_973441205370_item	2957564	et	3	main
oled	doc_973441205370_item	2957566	et	3	main
natuke	doc_973441205370_item	2957571	et	4	main
küsima	doc_973441205370_item	2957581	et	3	main
on	doc_973441205370_item	2957584	et	4	main
ära	doc_973441205370_item	2957599	et	4	main
ja	doc_973441205370_item	2957602	et	3	main
järgi	doc_973441205370_item	2957605	et	4	main
hakkas	doc_973441205370_item	2957606	et	3	main
norskama	doc_973441205370_item	2957607	et	3	main
nägid	doc_973441205370_item	2957621	et	4	main
ma	doc_973441205370_item	2957626	et	3	main
tappin	doc_973441205370_item	2957637	et	4	main
ma	doc_973441205370_item	2957638	et	3	main
tappid	doc_973441205370_item	2957640	et	4	main
nii	doc_973441205370_item	2957645	et	3	main
järgi	doc_973441205370_item	2957648	et	4	main
ammu	doc_973441205371_item	2957653	et	4	main
tüdruk	doc_973441205371_item	2957657	et	3	main
ta	doc_973441205371_item	2957658	et	4	main
oli	doc_973441205371_item	2957659	et	3	main
majas	doc_973441205371_item	2957668	et	3	main
ääres	doc_973441205371_item	2957670	et	4	main
aga	doc_973441205371_item	2957673	et	3	main
tema	doc_973441205371_item	2957674	et	4	main
tule	doc_973441205371_item	2957702	et	4	main
puna	doc_973441205371_item	2957726	et	4	main
kätte	doc_973441205371_item	2957729	et	4	main
korvi	doc_973441205371_item	2957730	et	4	main
tulema	doc_973441205371_item	2957740	et	4	main
päike	doc_973441205371_item	2957744	et	3	main
näes	doc_973441205371_item	2957759	et	4	main
tere	doc_973441205371_item	2957761	et	3	main
ja	doc_973441205371_item	2957775	et	3	main
ta	doc_973441205371_item	2957787	et	4	main
ta	doc_973441205371_item	2957794	et	4	main
oli	doc_973441205371_item	2957802	et	3	main
hund	doc_973441205371_item	2957807	et	4	main
ta	doc_973441205371_item	2957821	et	4	main
käed	doc_973441205371_item	2957834	et	3	main
suur	doc_973441205371_item	2957839	et	3	main
ja	doc_973441205371_item	2957847	et	3	main
kohe	doc_973441205371_item	2957848	et	4	main
ümberjutustus	doc_973441205372_item	2957859	et	3	main
punamütsike	doc_973441205372_item	2957861	et	4	main
elas	doc_973441205372_item	2957862	et	3	main
ema	doc_973441205372_item	2957872	et	4	main
väga	doc_973441205372_item	2957873	et	3	main
vanaema	doc_973441205372_item	2957877	et	4	main
veel	doc_973441205372_item	2957879	et	4	main
tegis	doc_973441205372_item	2957905	et	4	main
piirukad	doc_973441205372_item	2957906	et	4	main
ja	doc_973441205372_item	2957907	et	3	main
mahla	doc_973441205372_item	2957913	et	4	main
ja	doc_973441205372_item	2957914	et	3	main
tule	doc_973441205372_item	2957915	et	4	main
müts	doc_973441205372_item	2957937	et	4	main
ja	doc_973441205372_item	2957939	et	3	main
vanaemale	doc_973441205372_item	2957941	et	3	main
vanaema	doc_973441205372_item	2957942	et	4	main
elaks	doc_973441205372_item	2957943	et	3	main
teine	doc_973441205372_item	2957944	et	3	main
maja	doc_973441205372_item	2957945	et	4	main
leidis	doc_973441205372_item	2957954	et	4	main
lillid	doc_973441205372_item	2957955	et	3	main
tubli	doc_973441205370_item	2957522	et	4	main
vanaema	doc_973441205370_item	2957528	et	4	main
seal	doc_973441205370_item	2957531	et	4	main
vanaema	doc_973441205370_item	2957535	et	4	main
vana	doc_973441205370_item	2957540	et	4	main
ta	doc_973441205370_item	2957541	et	4	main
tahtis	doc_973441205370_item	2957542	et	3	main
varsti	doc_973441205370_item	2957552	et	3	main
tuli	doc_973441205370_item	2957553	et	4	main
tüdruk	doc_973441205370_item	2957554	et	3	main
vanaema	doc_973441205370_item	2957561	et	4	main
sa	doc_973441205370_item	2957565	et	3	main
miks	doc_973441205370_item	2957588	et	4	main
sul	doc_973441205370_item	2957589	et	3	main
läksid	doc_973441205370_item	2957609	et	4	main
kaks	doc_973441205370_item	2957610	et	3	main
nägisid	doc_973441205370_item	2957615	et	4	main
hunti	doc_973441205370_item	2957616	et	4	main
ja	doc_973441205370_item	2957617	et	3	main
hakkasid	doc_973441205370_item	2957618	et	4	main
laulma	doc_973441205370_item	2957619	et	3	main
hunti	doc_973441205370_item	2957620	et	4	main
nägid	doc_973441205370_item	2957628	et	4	main
kaks	doc_973441205370_item	2957629	et	3	main
ka	doc_973441205370_item	2957631	et	3	main
kask	doc_973441205370_item	2957641	et	3	main
ka	doc_973441205370_item	2957643	et	3	main
edasi	doc_973441205370_item	2957646	et	3	main
prantsusmaal	doc_973441205371_item	2957654	et	4	main
elas	doc_973441205371_item	2957655	et	3	main
üks	doc_973441205371_item	2957656	et	3	main
vanaema	doc_973441205371_item	2957675	et	4	main
elas	doc_973441205371_item	2957676	et	3	main
metsa	doc_973441205371_item	2957677	et	4	main
taga	doc_973441205371_item	2957678	et	4	main
üks	doc_973441205371_item	2957679	et	3	main
kord	doc_973441205371_item	2957680	et	4	main
vanaema	doc_973441205371_item	2957681	et	4	main
õmbles	doc_973441205371_item	2957682	et	3	main
talle	doc_973441205371_item	2957683	et	4	main
puna	doc_973441205371_item	2957684	et	4	main
mütsi	doc_973441205371_item	2957685	et	4	main
tüdruk	doc_973441205371_item	2957686	et	3	main
kandis	doc_973441205371_item	2957687	et	4	main
selle	doc_973441205371_item	2957688	et	4	main
mütsi	doc_973441205371_item	2957689	et	4	main
pidevalt	doc_973441205371_item	2957690	et	4	main
ja	doc_973441205371_item	2957691	et	3	main
kõik	doc_973441205371_item	2957692	et	4	main
naabrid	doc_973441205371_item	2957693	et	3	main
kutsusid	doc_973441205371_item	2957694	et	4	main
teid	doc_973441205371_item	2957695	et	4	main
punamütsikeks	doc_973441205371_item	2957696	et	4	main
üks	doc_973441205371_item	2957697	et	3	main
kord	doc_973441205371_item	2957698	et	4	main
ema	doc_973441205371_item	2957699	et	4	main
ütles	doc_973441205371_item	2957700	et	3	main
punamütsike	doc_973441205371_item	2957701	et	4	main
sa	doc_973441205370_item	2957634	et	3	main
ja	doc_973441205370_item	2957635	et	3	main
hunti	doc_973441205370_item	2957636	et	4	main
jahumeest	doc_973441205370_item	2957642	et	4	main
ja	doc_973441205370_item	2957644	et	3	main
süžee	doc_973441205370_item	2957647	et	2	main
ümberjutustus	doc_973441205371_item	2957649	et	3	main
ta	doc_973441205371_item	2957665	et	4	main
elas	doc_973441205371_item	2957666	et	3	main
väikses	doc_973441205371_item	2957667	et	4	main
koos	doc_973441205371_item	2957671	et	4	main
emaga	doc_973441205371_item	2957672	et	3	main
juurde	doc_973441205371_item	2957704	et	4	main
ja	doc_973441205371_item	2957705	et	3	main
vanaema	doc_973441205371_item	2957715	et	4	main
vastas	doc_973441205371_item	2957721	et	4	main
mütsi	doc_973441205371_item	2957727	et	4	main
võttis	doc_973441205371_item	2957728	et	3	main
vanaema	doc_973441205371_item	2957733	et	4	main
juurde	doc_973441205371_item	2957734	et	4	main
punamütsike	doc_973441205371_item	2957735	et	4	main
mööda	doc_973441205371_item	2957739	et	4	main
ilus	doc_973441205371_item	2957743	et	4	main
punamütsike	doc_973441205371_item	2957753	et	4	main
otsas	doc_973441205371_item	2957754	et	4	main
päevas	doc_973441205371_item	2957762	et	3	main
tüdruk	doc_973441205371_item	2957764	et	3	main
ütles	doc_973441205371_item	2957765	et	3	main
hund	doc_973441205371_item	2957766	et	4	main
kuhu	doc_973441205371_item	2957767	et	3	main
sa	doc_973441205371_item	2957768	et	3	main
lähed	doc_973441205371_item	2957769	et	3	main
ma	doc_973441205371_item	2957770	et	3	main
lähen	doc_973441205371_item	2957771	et	3	main
oma	doc_973441205371_item	2957772	et	4	main
pirukate	doc_973441205371_item	2957777	et	3	main
ära	doc_973441205371_item	2957790	et	4	main
aga	doc_973441205371_item	2957792	et	3	main
maja	doc_973441205371_item	2957799	et	4	main
lahti	doc_973441205371_item	2957803	et	4	main
lammas	doc_973441205371_item	2957805	et	3	main
miks	doc_973441205371_item	2957830	et	4	main
sul	doc_973441205371_item	2957831	et	3	main
nii	doc_973441205371_item	2957832	et	3	main
silmad	doc_973441205371_item	2957836	et	4	main
küsis	doc_973441205371_item	2957841	et	3	main
armastan	doc_973441205371_item	2957845	et	3	main
hund	doc_973441205371_item	2957852	et	4	main
norskama	doc_973441205371_item	2957858	et	3	main
armastas	doc_973441205372_item	2957874	et	3	main
armastas	doc_973441205372_item	2957878	et	3	main
ütles	doc_973441205372_item	2957908	et	3	main
kuidas	doc_973441205372_item	2957918	et	3	main
ma	doc_973441205372_item	2957922	et	3	main
halb	doc_973441205372_item	2957926	et	3	main
praegu	doc_973441205372_item	2957927	et	3	main
võtab	doc_973441205372_item	2957931	et	3	main
see	doc_973441205372_item	2957932	et	3	main
ja	doc_973441205372_item	2957946	et	3	main
armastab	doc_973441205372_item	2957965	et	3	main
taga	doc_973441205372_item	2957988	et	4	main
läks	doc_973441205372_item	2957989	et	3	main
läheb	doc_973441205372_item	2958002	et	3	main
aga	doc_973441205372_item	2958006	et	3	main
elab	doc_973441205372_item	2958009	et	3	main
aga	doc_973441205372_item	2958014	et	3	main
punamütsike	doc_973441205372_item	2958015	et	4	main
vastas	doc_973441205372_item	2958016	et	4	main
hunt	doc_973441205372_item	2958025	et	3	main
ta	doc_973441205372_item	2958030	et	4	main
väga	doc_973441205372_item	2958031	et	3	main
tahaks	doc_973441205372_item	2958032	et	3	main
süüja	doc_973441205372_item	2958033	et	4	main
praegu	doc_973441205372_item	2958038	et	3	main
süüja	doc_973441205372_item	2958052	et	4	main
juba	doc_973441205372_item	2958055	et	3	main
söön	doc_973441205372_item	2958062	et	3	main
ka	doc_973441205372_item	2958064	et	3	main
punamütsike	doc_973441205372_item	2958067	et	4	main
ma	doc_973441205372_item	2958069	et	3	main
lähen	doc_973441205372_item	2958070	et	3	main
jalutama	doc_973441205372_item	2958071	et	3	main
too	doc_973441205371_item	2957706	et	4	main
talle	doc_973441205371_item	2957707	et	4	main
pirukate	doc_973441205371_item	2957708	et	3	main
ja	doc_973441205371_item	2957709	et	3	main
potti	doc_973441205371_item	2957710	et	4	main
võiga	doc_973441205371_item	2957711	et	3	main
mulle	doc_973441205371_item	2957712	et	4	main
üteldakse	doc_973441205371_item	2957713	et	3	main
et	doc_973441205371_item	2957714	et	3	main
hästi	doc_973441205371_item	2957718	et	3	main
metsa	doc_973441205371_item	2957738	et	4	main
palju	doc_973441205371_item	2957751	et	4	main
lillid	doc_973441205371_item	2957752	et	3	main
vanaema	doc_973441205371_item	2957773	et	4	main
punamütsike	doc_973441205371_item	2957782	et	4	main
hundi	doc_973441205371_item	2957783	et	3	main
kõht	doc_973441205371_item	2957784	et	3	main
oli	doc_973441205371_item	2957785	et	3	main
tühi	doc_973441205371_item	2957786	et	3	main
hund	doc_973441205371_item	2957796	et	4	main
jooksis	doc_973441205371_item	2957797	et	4	main
uks	doc_973441205371_item	2957801	et	3	main
vanaema	doc_973441205371_item	2957804	et	4	main
punamütsike	doc_973441205371_item	2957722	et	4	main
ta	doc_973441205371_item	2957723	et	4	main
panin	doc_973441205371_item	2957724	et	3	main
pähe	doc_973441205371_item	2957725	et	4	main
ja	doc_973441205371_item	2957731	et	3	main
tulis	doc_973441205371_item	2957732	et	4	main
peas	doc_973441205371_item	2957736	et	4	main
ilm	doc_973441205371_item	2957741	et	3	main
linnud	doc_973441205371_item	2957746	et	3	main
tee	doc_973441205371_item	2957748	et	4	main
ääres	doc_973441205371_item	2957749	et	4	main
oli	doc_973441205371_item	2957750	et	3	main
äkki	doc_973441205371_item	2957758	et	3	main
hundi	doc_973441205371_item	2957760	et	3	main
juurde	doc_973441205371_item	2957774	et	4	main
ta	doc_973441205371_item	2957778	et	4	main
on	doc_973441205371_item	2957779	et	4	main
vastas	doc_973441205371_item	2957781	et	4	main
süüa	doc_973441205371_item	2957789	et	3	main
vanaema	doc_973441205371_item	2957798	et	4	main
astus	doc_973441205371_item	2957808	et	3	main
sisse	doc_973441205371_item	2957809	et	4	main
ja	doc_973441205371_item	2957810	et	3	main
sõi	doc_973441205371_item	2957811	et	3	main
ära	doc_973441205371_item	2957812	et	4	main
vanaema	doc_973441205371_item	2957813	et	4	main
ta	doc_973441205371_item	2957814	et	4	main
lammas	doc_973441205371_item	2957815	et	3	main
vanaema	doc_973441205371_item	2957816	et	4	main
voodisse	doc_973441205371_item	2957817	et	3	main
punamütsike	doc_973441205371_item	2957818	et	4	main
jõudis	doc_973441205371_item	2957819	et	3	main
kohale	doc_973441205371_item	2957820	et	4	main
astus	doc_973441205371_item	2957822	et	3	main
nägis	doc_973441205371_item	2957824	et	4	main
jalad	doc_973441205371_item	2957835	et	3	main
suu	doc_973441205371_item	2957840	et	4	main
punamütsike	doc_973441205371_item	2957842	et	4	main
ma	doc_973441205371_item	2957844	et	3	main
ta	doc_973441205371_item	2957853	et	4	main
tegi	doc_973441205371_item	2957854	et	4	main
ja	doc_973441205371_item	2957856	et	3	main
ümberjutustus	doc_973441205372_item	2957860	et	3	main
kord	doc_973441205372_item	2957864	et	4	main
temal	doc_973441205372_item	2957875	et	3	main
vanaemale	doc_973441205372_item	2957916	et	3	main
ta	doc_973441205372_item	2957919	et	4	main
sisse	doc_973441205371_item	2957823	et	4	main
vanaema	doc_973441205371_item	2957825	et	4	main
ja	doc_973441205371_item	2957826	et	3	main
lammas	doc_973441205371_item	2957827	et	3	main
voodisse	doc_973441205371_item	2957828	et	3	main
ka	doc_973441205371_item	2957829	et	3	main
kõrvad	doc_973441205371_item	2957837	et	3	main
sellepärast	doc_973441205371_item	2957843	et	3	main
sind	doc_973441205371_item	2957846	et	4	main
söön	doc_973441205371_item	2957849	et	3	main
ära	doc_973441205371_item	2957850	et	4	main
seda	doc_973441205371_item	2957855	et	3	main
tüdruk	doc_973441205372_item	2957866	et	3	main
oli	doc_973441205372_item	2957868	et	3	main
hea	doc_973441205372_item	2957869	et	4	main
tüdruk	doc_973441205372_item	2957870	et	3	main
ja	doc_973441205372_item	2957871	et	3	main
rohkem	doc_973441205372_item	2957880	et	4	main
kui	doc_973441205372_item	2957881	et	3	main
ema	doc_973441205372_item	2957882	et	4	main
vanaema	doc_973441205372_item	2957883	et	4	main
üks	doc_973441205372_item	2957884	et	3	main
kord	doc_973441205372_item	2957885	et	4	main
ümbles	doc_973441205372_item	2957886	et	4	main
temal	doc_973441205372_item	2957887	et	3	main
punane	doc_973441205372_item	2957888	et	4	main
müts	doc_973441205372_item	2957889	et	4	main
see	doc_973441205372_item	2957890	et	3	main
müts	doc_973441205372_item	2957891	et	4	main
väga	doc_973441205372_item	2957892	et	3	main
meeldis	doc_973441205372_item	2957893	et	3	main
punamütsike	doc_973441205372_item	2957894	et	4	main
ja	doc_973441205372_item	2957895	et	3	main
tal	doc_973441205372_item	2957896	et	3	main
see	doc_973441205372_item	2957897	et	3	main
müts	doc_973441205372_item	2957898	et	4	main
pähe	doc_973441205372_item	2957899	et	4	main
kogu	doc_973441205372_item	2957900	et	4	main
aeg	doc_973441205372_item	2957901	et	3	main
üks	doc_973441205372_item	2957902	et	3	main
kord	doc_973441205372_item	2957903	et	4	main
ema	doc_973441205372_item	2957904	et	4	main
vastas	doc_973441205371_item	2957851	et	4	main
hakkas	doc_973441205371_item	2957857	et	3	main
üks	doc_973441205372_item	2957863	et	3	main
üks	doc_973441205372_item	2957865	et	3	main
ta	doc_973441205372_item	2957867	et	4	main
aga	doc_973441205372_item	2957876	et	3	main
võta	doc_973441205372_item	2957910	et	4	main
ja	doc_973441205372_item	2957912	et	3	main
vaata	doc_973441205372_item	2957917	et	4	main
elab	doc_973441205372_item	2957920	et	3	main
et	doc_973441205372_item	2957924	et	3	main
siis	doc_973441205372_item	2957929	et	3	main
ta	doc_973441205372_item	2957953	et	4	main
ja	doc_973441205372_item	2957981	et	3	main
punamütsike	doc_973441205372_item	2957996	et	4	main
kuidas	doc_973441205372_item	2957997	et	3	main
käsi	doc_973441205372_item	2957998	et	4	main
käib	doc_973441205372_item	2957999	et	3	main
sa	doc_973441205372_item	2958001	et	3	main
kus	doc_973441205372_item	2958007	et	3	main
kohas	doc_973441205372_item	2958008	et	4	main
tahaks	doc_973441205372_item	2958035	et	3	main
süüja	doc_973441205372_item	2958036	et	4	main
hunt	doc_973441205372_item	2958040	et	3	main
loll	doc_973441205372_item	2958044	et	3	main
ja	doc_973441205372_item	2958045	et	3	main
vanaemale	doc_973441205372_item	2958050	et	3	main
aga	doc_973441205372_item	2958054	et	3	main
pärast	doc_973441205372_item	2958056	et	4	main
kui	doc_973441205372_item	2958057	et	3	main
punamütsike	doc_973441205372_item	2958058	et	4	main
ja	doc_973441205372_item	2958077	et	3	main
hunt	doc_973441205372_item	2958080	et	3	main
lamal	doc_973441205372_item	2958122	et	4	main
läks	doc_973441205372_item	2958126	et	3	main
küsis	doc_973441205372_item	2958134	et	3	main
üks	doc_973441205372_item	2958143	et	3	main
lahte	doc_973441205372_item	2958150	et	4	main
jookses	doc_973441205372_item	2958153	et	3	main
peale	doc_973441205372_item	2958160	et	4	main
ja	doc_973441205372_item	2958161	et	3	main
see	doc_973441205372_item	2958170	et	3	main
miks	doc_973441205372_item	2958178	et	4	main
sul	doc_973441205372_item	2958179	et	3	main
on	doc_973441205372_item	2958180	et	4	main
nii	doc_973441205372_item	2958181	et	3	main
suured	doc_973441205372_item	2958182	et	3	main
jalad	doc_973441205372_item	2958183	et	3	main
see	doc_973441205372_item	2958184	et	3	main
on	doc_973441205372_item	2958185	et	4	main
on	doc_973441205372_item	2958194	et	4	main
nii	doc_973441205372_item	2958195	et	3	main
suured	doc_973441205372_item	2958196	et	3	main
punamütsike	doc_973441205372_item	2958223	et	4	main
väga	doc_973441205373_item	2958262	et	3	main
tegi	doc_973441205373_item	2958271	et	4	main
talle	doc_973441205373_item	2958272	et	4	main
soobis	doc_973441205373_item	2958277	et	4	main
teda	doc_973441205373_item	2958290	et	4	main
arvas	doc_973441205373_item	2958322	et	3	main
kimbu	doc_973441205373_item	2958325	et	3	main
sest	doc_973441205373_item	2958327	et	4	main
lilled	doc_973441205373_item	2958330	et	3	main
korvi	doc_973441205373_item	2958333	et	4	main
maha	doc_973441205373_item	2958334	et	4	main
ja	doc_973441205373_item	2958335	et	3	main
hakkas	doc_973441205373_item	2958336	et	3	main
punamütsike	doc_973441205373_item	2958347	et	4	main
vastas	doc_973441205373_item	2958350	et	4	main
ta	doc_973441205373_item	2958362	et	4	main
elab	doc_973441205373_item	2958363	et	3	main
tühi	doc_973441205373_item	2958371	et	3	main
et	doc_973441205373_item	2958374	et	3	main
läks	doc_973441205373_item	2958386	et	3	main
vanaema	doc_973441205373_item	2958393	et	4	main
on	doc_973441205373_item	2958395	et	4	main
mina	doc_973441205373_item	2958396	et	4	main
mahl	doc_973441205373_item	2958402	et	3	main
tuli	doc_973441205373_item	2958411	et	4	main
et	doc_973441205373_item	2958447	et	3	main
sind	doc_973441205373_item	2958449	et	4	main
sii	doc_973441205373_item	2958451	et	4	main
nii	doc_973441205373_item	2958455	et	3	main
punamütsike	doc_973441205372_item	2957909	et	4	main
piirukad	doc_973441205372_item	2957911	et	4	main
seal	doc_973441205372_item	2957921	et	4	main
ta	doc_973441205372_item	2957925	et	4	main
lääks	doc_973441205372_item	2957940	et	4	main
punamütsike	doc_973441205372_item	2957947	et	4	main
käis	doc_973441205372_item	2957948	et	4	main
võtan	doc_973441205372_item	2957959	et	3	main
natukene	doc_973441205372_item	2957960	et	4	main
lilled	doc_973441205372_item	2957961	et	3	main
kaasa	doc_973441205372_item	2957962	et	4	main
ja	doc_973441205372_item	2957970	et	3	main
kinnitan	doc_973441205372_item	2957973	et	3	main
lillid	doc_973441205372_item	2957975	et	3	main
siis	doc_973441205372_item	2957977	et	3	main
oli	doc_973441205372_item	2957979	et	3	main
ta	doc_973441205372_item	2957983	et	4	main
mõtles	doc_973441205372_item	2957984	et	3	main
see	doc_973441205372_item	2957985	et	3	main
tema	doc_973441205372_item	2957986	et	4	main
selja	doc_973441205372_item	2957987	et	3	main
kuhu	doc_973441205372_item	2958000	et	3	main
vanaemale	doc_973441205372_item	2958003	et	3	main
sinu	doc_973441205372_item	2958010	et	3	main
küsiks	doc_973441205372_item	2958012	et	3	main
ta	doc_973441205372_item	2958034	et	4	main
aga	doc_973441205372_item	2958039	et	3	main
oli	doc_973441205372_item	2958041	et	3	main
läheb	doc_973441205372_item	2958059	et	3	main
ütles	doc_973441205372_item	2958066	et	3	main
ok	doc_973441205372_item	2958068	et	4	main
punamütsike	doc_973441205372_item	2958073	et	4	main
läheb	doc_973441205372_item	2958074	et	3	main
ka	doc_973441205372_item	2958075	et	3	main
edasi	doc_973441205372_item	2958076	et	3	main
selele	doc_973441205372_item	2958082	et	4	main
vanaema	doc_973441205372_item	2958119	et	4	main
ja	doc_973441205372_item	2958121	et	3	main
hunt	doc_973441205372_item	2958135	et	3	main
vanaema	doc_973441205372_item	2958137	et	4	main
punamütsike	doc_973441205372_item	2958141	et	4	main
tegis	doc_973441205372_item	2958148	et	4	main
uks	doc_973441205372_item	2958149	et	3	main
rutu	doc_973441205372_item	2958152	et	3	main
tagasi	doc_973441205372_item	2958154	et	3	main
küsiks	doc_973441205372_item	2958162	et	3	main
käed	doc_973441205372_item	2958169	et	3	main
vaja	doc_973441205372_item	2958187	et	4	main
joksuga	doc_973441205372_item	2958190	et	4	main
vanaema	doc_973441205372_item	2958191	et	4	main
aga	doc_973441205372_item	2958224	et	3	main
aru	doc_973441205372_item	2958240	et	4	main
kõht	doc_973441205372_item	2958246	et	3	main
elas	doc_973441205373_item	2958257	et	3	main
ta	doc_973441205373_item	2958260	et	4	main
mis	doc_973441205373_item	2958276	et	4	main
punast	doc_973441205373_item	2958284	et	4	main
ning	doc_973441205373_item	2958286	et	3	main
lilled	doc_973441205373_item	2958337	et	3	main
koristama	doc_973441205373_item	2958338	et	3	main
äkki	doc_973441205373_item	2958339	et	3	main
punamütsike	doc_973441205373_item	2958349	et	4	main
juurde	doc_973441205373_item	2958354	et	4	main
mitte	doc_973441205373_item	2958364	et	3	main
ütles	doc_973441205373_item	2958366	et	3	main
ta	doc_973441205373_item	2958372	et	4	main
punamütsike	doc_973441205373_item	2958375	et	4	main
hea	doc_973441205373_item	2958377	et	4	main
tüdruk	doc_973441205373_item	2958378	et	3	main
ja	doc_973441205373_item	2958379	et	3	main
ta	doc_973441205373_item	2958380	et	4	main
teda	doc_973441205373_item	2958383	et	4	main
ära	doc_973441205373_item	2958384	et	4	main
hunt	doc_973441205373_item	2958385	et	3	main
juurde	doc_973441205373_item	2958388	et	4	main
see	doc_973441205373_item	2958394	et	3	main
ja	doc_973441205373_item	2958401	et	3	main
vajuta	doc_973441205373_item	2958404	et	4	main
lingele	doc_973441205373_item	2958405	et	4	main
vaatas	doc_973441205373_item	2958424	et	3	main
aga	doc_973441205373_item	2958429	et	3	main
miks	doc_973441205373_item	2958440	et	4	main
kuulsin	doc_973441205372_item	2957923	et	3	main
ja	doc_973441205372_item	2957928	et	3	main
punamütsi	doc_973441205372_item	2957930	et	4	main
piirukad	doc_973441205372_item	2957933	et	4	main
ja	doc_973441205372_item	2957934	et	3	main
mahl	doc_973441205372_item	2957935	et	3	main
panes	doc_973441205372_item	2957936	et	3	main
peas	doc_973441205372_item	2957938	et	4	main
metsa	doc_973441205372_item	2957949	et	4	main
keskele	doc_973441205372_item	2957950	et	3	main
seal	doc_973441205372_item	2957951	et	4	main
metsas	doc_973441205372_item	2957952	et	3	main
minu	doc_973441205372_item	2957963	et	3	main
ta	doc_973441205372_item	2957967	et	4	main
kui	doc_973441205372_item	2957971	et	3	main
rõõmus	doc_973441205372_item	2957980	et	4	main
kui	doc_973441205372_item	2957982	et	3	main
tere	doc_973441205372_item	2957995	et	3	main
punamütsike	doc_973441205372_item	2958005	et	4	main
ta	doc_973441205372_item	2958017	et	4	main
elab	doc_973441205372_item	2958018	et	3	main
metsa	doc_973441205372_item	2958019	et	4	main
majas	doc_973441205372_item	2958022	et	3	main
esimeesel	doc_973441205372_item	2958023	et	4	main
korrusel	doc_973441205372_item	2958024	et	3	main
kõht	doc_973441205372_item	2958027	et	3	main
ja	doc_973441205372_item	2958029	et	3	main
punamütsike	doc_973441205372_item	2958037	et	4	main
mõtles	doc_973441205372_item	2958046	et	3	main
ma	doc_973441205372_item	2958048	et	3	main
ja	doc_973441205372_item	2958051	et	3	main
tema	doc_973441205372_item	2958053	et	4	main
ma	doc_973441205372_item	2958061	et	3	main
teda	doc_973441205372_item	2958063	et	4	main
hunt	doc_973441205372_item	2958065	et	3	main
voodi	doc_973441205372_item	2958123	et	4	main
punamütsike	doc_973441205372_item	2958127	et	4	main
ja	doc_973441205372_item	2958128	et	3	main
koputas	doc_973441205372_item	2958129	et	3	main
üksele	doc_973441205372_item	2958130	et	3	main
kes	doc_973441205372_item	2958131	et	4	main
on	doc_973441205372_item	2958139	et	4	main
mina	doc_973441205372_item	2958140	et	4	main
punamütsike	doc_973441205372_item	2958146	et	4	main
hunt	doc_973441205372_item	2958147	et	3	main
peale	doc_973441205372_item	2958156	et	4	main
punamütsike	doc_973441205372_item	2958157	et	4	main
istub	doc_973441205372_item	2958158	et	3	main
on	doc_973441205372_item	2958166	et	4	main
nii	doc_973441205372_item	2958167	et	3	main
on	doc_973441205372_item	2958171	et	4	main
et	doc_973441205372_item	2958174	et	3	main
rohkem	doc_973441205372_item	2958175	et	4	main
kallistama	doc_973441205372_item	2958176	et	3	main
selleks	doc_973441205372_item	2958186	et	4	main
rohkem	doc_973441205372_item	2958189	et	4	main
süüja	doc_973441205372_item	2958222	et	4	main
lamab	doc_973441205372_item	2958226	et	3	main
metsas	doc_973441205372_item	2958230	et	3	main
mis	doc_973441205372_item	2958241	et	4	main
toimus	doc_973441205372_item	2958242	et	3	main
ta	doc_973441205372_item	2958243	et	4	main
teeb	doc_973441205372_item	2958244	et	3	main
ja	doc_973441205372_item	2958248	et	3	main
vanaema	doc_973441205372_item	2958251	et	4	main
punamütsike	doc_973441205372_item	2958253	et	4	main
ümberjutustus	doc_973441205373_item	2958254	et	3	main
ümberjutustus	doc_973441205373_item	2958255	et	3	main
oli	doc_973441205373_item	2958261	et	3	main
ema	doc_973441205373_item	2958264	et	4	main
teda	doc_973441205373_item	2958266	et	4	main
ja	doc_973441205373_item	2958267	et	3	main
vanaema	doc_973441205373_item	2958268	et	4	main
ka	doc_973441205373_item	2958269	et	3	main
punase	doc_973441205373_item	2958274	et	4	main
hästi	doc_973441205373_item	2958279	et	3	main
ta	doc_973441205373_item	2958321	et	4	main
et	doc_973441205373_item	2958323	et	3	main
ta	doc_973441205373_item	2958331	et	4	main
ja	doc_973441205373_item	2958348	et	3	main
vanaema	doc_973441205373_item	2958353	et	4	main
kaugel	doc_973441205373_item	2958365	et	4	main
hunti	doc_973441205373_item	2958368	et	4	main
on	doc_973441205373_item	2958376	et	4	main
ja	doc_973441205373_item	2958391	et	3	main
ütles	doc_973441205373_item	2958392	et	3	main
punamütsike	doc_973441205373_item	2958397	et	4	main
ja	doc_973441205372_item	2957956	et	3	main
mõtleks	doc_973441205372_item	2957957	et	3	main
ma	doc_973441205372_item	2957958	et	3	main
vanaema	doc_973441205372_item	2957964	et	4	main
lillid	doc_973441205372_item	2957966	et	3	main
praegu	doc_973441205372_item	2957968	et	3	main
halb	doc_973441205372_item	2957969	et	3	main
mina	doc_973441205372_item	2957972	et	4	main
see	doc_973441205372_item	2957974	et	3	main
temal	doc_973441205372_item	2957976	et	3	main
ta	doc_973441205372_item	2957978	et	4	main
pahe	doc_973441205372_item	2957990	et	4	main
hunt	doc_973441205372_item	2957991	et	3	main
ja	doc_973441205372_item	2957992	et	3	main
ütles	doc_973441205372_item	2957993	et	3	main
no	doc_973441205372_item	2957994	et	3	main
ütles	doc_973441205372_item	2958004	et	3	main
vanaema	doc_973441205372_item	2958011	et	4	main
hunt	doc_973441205372_item	2958013	et	3	main
taga	doc_973441205372_item	2958020	et	4	main
roheline	doc_973441205372_item	2958021	et	4	main
oli	doc_973441205372_item	2958026	et	3	main
tühi	doc_973441205372_item	2958028	et	3	main
ei	doc_973441205372_item	2958042	et	4	main
ole	doc_973441205372_item	2958043	et	4	main
praegu	doc_973441205372_item	2958047	et	3	main
lähen	doc_973441205372_item	2958049	et	3	main
siis	doc_973441205372_item	2958060	et	3	main
laulab	doc_973441205372_item	2958078	et	3	main
jookseb	doc_973441205372_item	2958081	et	3	main
roheline	doc_973441205372_item	2958083	et	4	main
majani	doc_973441205372_item	2958084	et	3	main
ja	doc_973441205372_item	2958085	et	3	main
koputab	doc_973441205372_item	2958086	et	3	main
üksele	doc_973441205372_item	2958087	et	3	main
kop-kop	doc_973441205372_item	2958088	et	4	main
vanaema	doc_973441205372_item	2958089	et	4	main
küsiks	doc_973441205372_item	2958090	et	3	main
kes	doc_973441205372_item	2958091	et	4	main
seal	doc_973441205372_item	2958092	et	4	main
on	doc_973441205372_item	2958093	et	4	main
hunt	doc_973441205372_item	2958094	et	3	main
vastas	doc_973441205372_item	2958095	et	4	main
see	doc_973441205372_item	2958096	et	3	main
on	doc_973441205372_item	2958097	et	4	main
sinu	doc_973441205372_item	2958099	et	3	main
mina	doc_973441205372_item	2958098	et	4	main
lemmik	doc_973441205372_item	2958100	et	3	main
punamütsike	doc_973441205372_item	2958101	et	4	main
siis	doc_973441205372_item	2958102	et	3	main
vanaema	doc_973441205372_item	2958103	et	4	main
läks	doc_973441205372_item	2958104	et	3	main
üksele	doc_973441205372_item	2958105	et	3	main
ja	doc_973441205372_item	2958106	et	3	main
teeb	doc_973441205372_item	2958107	et	3	main
üks	doc_973441205372_item	2958108	et	3	main
lahti	doc_973441205372_item	2958109	et	4	main
hunt	doc_973441205372_item	2958110	et	3	main
jookses	doc_973441205372_item	2958111	et	3	main
tubase	doc_973441205372_item	2958112	et	4	main
ja	doc_973441205372_item	2958113	et	3	main
süüjas	doc_973441205372_item	2958114	et	4	main
vanaemale	doc_973441205372_item	2958115	et	3	main
aga	doc_973441205372_item	2958116	et	3	main
panas	doc_973441205372_item	2958118	et	4	main
pärast	doc_973441205372_item	2958117	et	4	main
edasi	doc_973441205372_item	2958072	et	3	main
laud	doc_973441205372_item	2958079	et	4	main
riided	doc_973441205372_item	2958120	et	3	main
see	doc_973441205372_item	2958132	et	3	main
tegi	doc_973441205372_item	2958142	et	4	main
voodi	doc_973441205372_item	2958159	et	4	main
suured	doc_973441205372_item	2958168	et	3	main
selleks	doc_973441205372_item	2958172	et	4	main
vaja	doc_973441205372_item	2958173	et	4	main
et	doc_973441205372_item	2958188	et	3	main
silmad	doc_973441205372_item	2958197	et	4	main
see	doc_973441205372_item	2958198	et	3	main
on	doc_973441205372_item	2958199	et	4	main
selleks	doc_973441205372_item	2958200	et	4	main
peale	doc_973441205372_item	2958124	et	4	main
kohe	doc_973441205372_item	2958125	et	4	main
on	doc_973441205372_item	2958133	et	4	main
oo	doc_973441205372_item	2958136	et	3	main
see	doc_973441205372_item	2958138	et	3	main
lahti	doc_973441205372_item	2958144	et	4	main
vastas	doc_973441205372_item	2958145	et	4	main
ja	doc_973441205372_item	2958151	et	3	main
voodi	doc_973441205372_item	2958155	et	4	main
vanaema	doc_973441205372_item	2958163	et	4	main
miks	doc_973441205372_item	2958164	et	4	main
sul	doc_973441205372_item	2958165	et	3	main
vanaema	doc_973441205372_item	2958177	et	4	main
miks	doc_973441205372_item	2958192	et	4	main
sul	doc_973441205372_item	2958193	et	3	main
vaja	doc_973441205372_item	2958201	et	4	main
et	doc_973441205372_item	2958202	et	3	main
rohkem	doc_973441205372_item	2958203	et	4	main
näema	doc_973441205372_item	2958204	et	4	main
vanaema	doc_973441205372_item	2958205	et	4	main
miks	doc_973441205372_item	2958206	et	4	main
sul	doc_973441205372_item	2958207	et	3	main
on	doc_973441205372_item	2958208	et	4	main
nii	doc_973441205372_item	2958209	et	3	main
suur	doc_973441205372_item	2958210	et	3	main
suu	doc_973441205372_item	2958211	et	4	main
see	doc_973441205372_item	2958212	et	3	main
on	doc_973441205372_item	2958213	et	4	main
selleks	doc_973441205372_item	2958214	et	4	main
vaja	doc_973441205372_item	2958215	et	4	main
et	doc_973441205372_item	2958216	et	3	main
kiiresti	doc_973441205372_item	2958217	et	3	main
sööma	doc_973441205372_item	2958218	et	4	main
sule	doc_973441205372_item	2958219	et	4	main
ja	doc_973441205372_item	2958220	et	3	main
hunt	doc_973441205372_item	2958221	et	3	main
peale	doc_973441205372_item	2958228	et	4	main
käib	doc_973441205372_item	2958231	et	3	main
ja	doc_973441205372_item	2958233	et	3	main
huti	doc_973441205372_item	2958247	et	4	main
võtab	doc_973441205372_item	2958249	et	3	main
ja	doc_973441205372_item	2958252	et	3	main
punamütsike	doc_973441205373_item	2958256	et	4	main
tüdruk	doc_973441205373_item	2958259	et	3	main
ilus	doc_973441205373_item	2958263	et	4	main
armastas	doc_973441205373_item	2958265	et	3	main
väikese	doc_973441205373_item	2958273	et	4	main
talle	doc_973441205373_item	2958278	et	4	main
kandis	doc_973441205373_item	2958281	et	4	main
päev	doc_973441205373_item	2958283	et	3	main
kõik	doc_973441205373_item	2958287	et	4	main
hakkasid	doc_973441205373_item	2958288	et	4	main
kutsuda	doc_973441205373_item	2958289	et	3	main
pärast	doc_973441205372_item	2958225	et	4	main
vodi	doc_973441205372_item	2958227	et	4	main
magama	doc_973441205372_item	2958229	et	3	main
mees	doc_973441205372_item	2958232	et	4	main
kuulas	doc_973441205372_item	2958234	et	3	main
kuidas	doc_973441205372_item	2958235	et	3	main
hunt	doc_973441205372_item	2958236	et	3	main
norstas	doc_973441205372_item	2958237	et	4	main
ja	doc_973441205372_item	2958238	et	3	main
saab	doc_973441205372_item	2958239	et	3	main
katke	doc_973441205372_item	2958245	et	4	main
välja	doc_973441205372_item	2958250	et	4	main
ammu	doc_973441205373_item	2958258	et	4	main
vanaema	doc_973441205373_item	2958270	et	4	main
mütsi	doc_973441205373_item	2958275	et	4	main
tüdruk	doc_973441205373_item	2958280	et	3	main
iga	doc_973441205373_item	2958282	et	4	main
mütsist	doc_973441205373_item	2958285	et	3	main
punamütsikeks	doc_973441205373_item	2958291	et	4	main
tegi	doc_973441205373_item	2958292	et	4	main
ema	doc_973441205373_item	2958293	et	4	main
kooki	doc_973441205373_item	2958294	et	4	main
ja	doc_973441205373_item	2958295	et	3	main
ütles	doc_973441205373_item	2958296	et	3	main
punamütsikele	doc_973441205373_item	2958297	et	4	main
et	doc_973441205373_item	2958298	et	3	main
ta	doc_973441205373_item	2958299	et	4	main
viis	doc_973441205373_item	2958300	et	4	main
kooki	doc_973441205373_item	2958301	et	4	main
ja	doc_973441205373_item	2958302	et	3	main
mahla	doc_973441205373_item	2958303	et	4	main
vanaemale	doc_973441205373_item	2958304	et	3	main
sest	doc_973441205373_item	2958305	et	4	main
vanaema	doc_973441205373_item	2958306	et	4	main
oli	doc_973441205373_item	2958307	et	3	main
haige	doc_973441205373_item	2958308	et	4	main
punamütsike	doc_973441205373_item	2958309	et	4	main
läks	doc_973441205373_item	2958310	et	3	main
vanaema	doc_973441205373_item	2958311	et	4	main
juurde	doc_973441205373_item	2958312	et	4	main
kui	doc_973441205373_item	2958313	et	3	main
ta	doc_973441205373_item	2958314	et	4	main
läks	doc_973441205373_item	2958315	et	3	main
metsas	doc_973441205373_item	2958316	et	3	main
ta	doc_973441205373_item	2958317	et	4	main
nägi	doc_973441205373_item	2958318	et	3	main
lilled	doc_973441205373_item	2958319	et	3	main
ja	doc_973441205373_item	2958320	et	3	main
teeb	doc_973441205373_item	2958324	et	3	main
vanaemale	doc_973441205373_item	2958328	et	3	main
meeldivad	doc_973441205373_item	2958329	et	4	main
pani	doc_973441205373_item	2958332	et	4	main
vanaemale	doc_973441205373_item	2958326	et	3	main
tuli	doc_973441205373_item	2958340	et	4	main
hunt	doc_973441205373_item	2958341	et	3	main
ja	doc_973441205373_item	2958342	et	3	main
küsis	doc_973441205373_item	2958343	et	3	main
kuhu	doc_973441205373_item	2958344	et	3	main
sa	doc_973441205373_item	2958345	et	3	main
lähed	doc_973441205373_item	2958346	et	3	main
lähen	doc_973441205373_item	2958352	et	3	main
toon	doc_973441205373_item	2958355	et	4	main
kooki	doc_973441205373_item	2958357	et	4	main
ja	doc_973441205373_item	2958358	et	3	main
tüdruk	doc_973441205373_item	2958367	et	3	main
kõht	doc_973441205373_item	2958369	et	3	main
ei	doc_973441205373_item	2958381	et	4	main
sõinud	doc_973441205373_item	2958382	et	4	main
vanaema	doc_973441205373_item	2958387	et	4	main
kopputas	doc_973441205373_item	2958389	et	4	main
on	doc_973441205373_item	2958399	et	4	main
koogid	doc_973441205373_item	2958400	et	4	main
sinule	doc_973441205373_item	2958403	et	3	main
vanaema	doc_973441205373_item	2958412	et	4	main
juurda	doc_973441205373_item	2958413	et	4	main
ja	doc_973441205373_item	2958414	et	3	main
neelas	doc_973441205373_item	2958415	et	3	main
teda	doc_973441205373_item	2958416	et	4	main
siis	doc_973441205373_item	2958417	et	3	main
ta	doc_973441205373_item	2958418	et	4	main
ootas	doc_973441205373_item	2958419	et	3	main
punamütsikest	doc_973441205373_item	2958420	et	4	main
ma	doc_973441205373_item	2958351	et	3	main
talle	doc_973441205373_item	2958356	et	4	main
mahla	doc_973441205373_item	2958359	et	4	main
aga	doc_973441205373_item	2958360	et	3	main
kus	doc_973441205373_item	2958361	et	3	main
oli	doc_973441205373_item	2958370	et	3	main
mõtles	doc_973441205373_item	2958373	et	3	main
uksele	doc_973441205373_item	2958390	et	3	main
lahti	doc_973441205373_item	2958409	et	4	main
hunt	doc_973441205373_item	2958410	et	3	main
tüdruk	doc_973441205373_item	2958422	et	3	main
ja	doc_973441205373_item	2958426	et	3	main
vanaema	doc_973441205373_item	2958428	et	4	main
paremini	doc_973441205373_item	2958439	et	4	main
silmad	doc_973441205373_item	2958445	et	4	main
selleks	doc_973441205373_item	2958458	et	4	main
hunt	doc_973441205373_item	2958487	et	3	main
vanaemat	doc_973441205373_item	2958489	et	4	main
lõikisid	doc_973441205373_item	2958493	et	3	main
ja	doc_973441205373_item	2958495	et	3	main
tulid	doc_973441205373_item	2958498	et	4	main
kõhust	doc_973441205373_item	2958500	et	3	main
õmblesid	doc_973441205373_item	2958501	et	4	main
hunti	doc_973441205373_item	2958502	et	4	main
kinni	doc_973441205373_item	2958503	et	3	main
kui	doc_973441205373_item	2958504	et	3	main
hunt	doc_973441205373_item	2958505	et	3	main
ärkas	doc_973441205373_item	2958506	et	3	main
tal	doc_973441205373_item	2958507	et	3	main
oli	doc_973441205373_item	2958508	et	3	main
ebameldivad	doc_973441205374_item	2958524	et	3	main
kauges	doc_973441205374_item	2958532	et	3	main
ka	doc_973441205374_item	2958544	et	3	main
head	doc_973441205374_item	2958548	et	4	main
tahaks	doc_973441205374_item	2958550	et	3	main
keerulisel	doc_973441205374_item	2958555	et	4	main
siis	doc_973441205374_item	2958557	et	3	main
sotssüsteem	doc_973441205374_item	2958560	et	3	main
algas	doc_973441205374_item	2958562	et	3	main
keegi	doc_973441205374_item	2958565	et	4	main
ei	doc_973441205374_item	2958566	et	4	main
õppimises	doc_973441205374_item	2958585	et	4	main
ega	doc_973441205374_item	2958586	et	3	main
keskstatistiline	doc_973441205374_item	2958588	et	4	main
õpilane	doc_973441205374_item	2958589	et	3	main
kuid	doc_973441205374_item	2958590	et	4	main
suhtumine	doc_973441205374_item	2958632	et	4	main
ka	doc_973441205374_item	2958635	et	3	main
õppetulemuste	doc_973441205374_item	2958642	et	4	main
kõige	doc_973441205374_item	2958655	et	4	main
arutada	doc_973441205374_item	2958670	et	3	main
kahjuks	doc_973441205374_item	2958671	et	4	main
ise	doc_973441205374_item	2958733	et	4	main
arva	doc_973441205374_item	2958737	et	4	main
pole	doc_973441205374_item	2958741	et	3	main
pojale	doc_973441205374_item	2958745	et	4	main
vaja	doc_973441205374_item	2958793	et	4	main
on	doc_973441205374_item	2958803	et	4	main
hädavajalik	doc_973441205374_item	2958804	et	3	main
peole	doc_973441205374_item	2958805	et	4	main
selle	doc_973441205374_item	2958806	et	4	main
miks	doc_973441205374_item	2958810	et	4	main
mõtte	doc_973441205374_item	2958821	et	3	main
pole	doc_973441205374_item	2958824	et	3	main
peab	doc_973441205374_item	2958827	et	4	main
armastama	doc_973441205374_item	2958828	et	3	main
seda	doc_973441205374_item	2958829	et	3	main
arukas	doc_973441205374_item	2958853	et	4	main
ja	doc_973441205374_item	2958854	et	3	main
olukorda	doc_973441205374_item	2958865	et	4	main
muidugi	doc_973441205374_item	2958868	et	4	main
see	doc_973441205374_item	2958870	et	3	main
õpetamisele	doc_973441205374_item	2958872	et	4	main
puutub	doc_973441205374_item	2958874	et	3	main
ja	doc_973441205374_item	2958887	et	3	main
olema	doc_973441205374_item	2958893	et	4	main
ole	doc_973441205375_item	2958935	et	4	main
oma	doc_973441205375_item	2958952	et	4	main
suurepärane	doc_973441205375_item	2958966	et	4	main
on	doc_973441205375_item	2958974	et	4	main
jäänud	doc_973441205375_item	2958975	et	4	main
meeldivaid	doc_973441205375_item	2958979	et	4	main
mul	doc_973441205373_item	2958398	et	3	main
ja	doc_973441205373_item	2958406	et	3	main
uks	doc_973441205373_item	2958407	et	3	main
on	doc_973441205373_item	2958408	et	4	main
kui	doc_973441205373_item	2958421	et	3	main
tuli	doc_973441205373_item	2958423	et	4	main
vanaemale	doc_973441205373_item	2958425	et	3	main
küsis	doc_973441205373_item	2958427	et	3	main
miks	doc_973441205373_item	2958430	et	4	main
sul	doc_973441205373_item	2958431	et	3	main
on	doc_973441205373_item	2958432	et	4	main
suured	doc_973441205373_item	2958433	et	3	main
kõrvad	doc_973441205373_item	2958434	et	3	main
on	doc_973441205373_item	2958441	et	4	main
sul	doc_973441205373_item	2958442	et	3	main
nii	doc_973441205373_item	2958443	et	3	main
suured	doc_973441205373_item	2958444	et	3	main
paremini	doc_973441205373_item	2958450	et	4	main
miks	doc_973441205373_item	2958452	et	4	main
sul	doc_973441205373_item	2958453	et	3	main
et	doc_973441205373_item	2958459	et	3	main
hunt	doc_973441205373_item	2958462	et	3	main
puuraiuad	doc_973441205373_item	2958492	et	4	main
minevikus	doc_973441205374_item	2958533	et	3	main
kooli	doc_973441205374_item	2958536	et	4	main
on	doc_973441205374_item	2958541	et	4	main
unustatud	doc_973441205374_item	2958542	et	4	main
me	doc_973441205374_item	2958552	et	4	main
täpselt	doc_973441205374_item	2958568	et	4	main
tüdruk	doc_973441205374_item	2958578	et	3	main
polnud	doc_973441205374_item	2958580	et	3	main
erilisi	doc_973441205374_item	2958581	et	4	main
koolis	doc_973441205374_item	2958583	et	4	main
käitumises	doc_973441205374_item	2958587	et	4	main
aasta	doc_973441205374_item	2958621	et	4	main
õppimisprotsessi	doc_973441205374_item	2958627	et	4	main
miinustega	doc_973441205374_item	2958628	et	3	main
võiks	doc_973441205374_item	2958629	et	4	main
nimetada	doc_973441205374_item	2958630	et	3	main
õpilastese	doc_973441205374_item	2958633	et	4	main
vastu	doc_973441205374_item	2958643	et	3	main
asja	doc_973441205374_item	2958644	et	4	main
on	doc_973441205374_item	2958645	et	4	main
ja	doc_973441205374_item	2958654	et	3	main
tema	doc_973441205374_item	2958658	et	4	main
on	doc_973441205374_item	2958660	et	4	main
see	doc_973441205374_item	2958661	et	3	main
et	doc_973441205374_item	2958662	et	3	main
see	doc_973441205374_item	2958672	et	3	main
õpetajad	doc_973441205374_item	2958675	et	4	main
läheb	doc_973441205374_item	2958682	et	3	main
väga	doc_973441205374_item	2958727	et	3	main
kuigi	doc_973441205374_item	2958732	et	3	main
ei	doc_973441205374_item	2958736	et	4	main
kahju	doc_973441205374_item	2958739	et	4	main
erakooli	doc_973441205374_item	2958746	et	4	main
peab	doc_973441205374_item	2958760	et	4	main
laps	doc_973441205374_item	2958768	et	4	main
pangalaenu	doc_973441205374_item	2958794	et	4	main
või	doc_973441205374_item	2958797	et	4	main
lihtsalt	doc_973441205374_item	2958798	et	4	main
nagu	doc_973441205374_item	2958799	et	3	main
igale	doc_973441205374_item	2958800	et	3	main
inimesele	doc_973441205374_item	2958801	et	3	main
on	doc_973441205374_item	2958807	et	4	main
mitte	doc_973441205374_item	2958811	et	3	main
õpetajana	doc_973441205374_item	2958814	et	4	main
minu	doc_973441205374_item	2958816	et	3	main
sest	doc_973441205374_item	2958822	et	4	main
õpetajategevus	doc_973441205374_item	2958823	et	4	main
millega	doc_973441205374_item	2958830	et	3	main
tegeleb	doc_973441205374_item	2958832	et	3	main
kutsumist	doc_973441205374_item	2958834	et	4	main
et	doc_973441205374_item	2958838	et	3	main
seltskonnas	doc_973441205374_item	2958840	et	3	main
kaua	doc_973441205374_item	2958847	et	3	main
sirguv	doc_973441205374_item	2958848	et	4	main
hindeline	doc_973441205374_item	2958855	et	4	main
terased	doc_973441205374_item	2958859	et	4	main
vaatlejad	doc_973441205374_item	2958860	et	4	main
ja	doc_973441205374_item	2958861	et	3	main
peened	doc_973441205374_item	2958862	et	3	main
selleks	doc_973441205373_item	2958435	et	4	main
et	doc_973441205373_item	2958436	et	3	main
kuulama	doc_973441205373_item	2958437	et	3	main
sind	doc_973441205373_item	2958438	et	4	main
näha	doc_973441205373_item	2958448	et	3	main
suur	doc_973441205373_item	2958456	et	3	main
süüa	doc_973441205373_item	2958460	et	3	main
punamütsiket	doc_973441205373_item	2958464	et	4	main
ja	doc_973441205373_item	2958466	et	3	main
jäi	doc_973441205373_item	2958467	et	3	main
magama	doc_973441205373_item	2958468	et	3	main
sellel	doc_973441205373_item	2958469	et	4	main
ajal	doc_973441205373_item	2958470	et	4	main
puuraiuad	doc_973441205373_item	2958471	et	4	main
oli	doc_973441205373_item	2958472	et	3	main
maja	doc_973441205373_item	2958473	et	4	main
juures	doc_973441205373_item	2958474	et	4	main
ja	doc_973441205373_item	2958475	et	3	main
kuulsid	doc_973441205373_item	2958476	et	4	main
et	doc_973441205373_item	2958477	et	3	main
keegi	doc_973441205373_item	2958478	et	4	main
norskab	doc_973441205373_item	2958479	et	3	main
seal	doc_973441205373_item	2958480	et	4	main
nad	doc_973441205373_item	2958481	et	3	main
tulid	doc_973441205373_item	2958482	et	4	main
vanaema	doc_973441205373_item	2958483	et	4	main
juurde	doc_973441205373_item	2958484	et	4	main
nägisid	doc_973441205373_item	2958485	et	4	main
et	doc_973441205373_item	2958486	et	3	main
selleks	doc_973441205373_item	2958446	et	4	main
on	doc_973441205373_item	2958454	et	4	main
suu	doc_973441205373_item	2958457	et	4	main
sind	doc_973441205373_item	2958461	et	4	main
neelas	doc_973441205373_item	2958463	et	3	main
ära	doc_973441205373_item	2958465	et	4	main
sõi	doc_973441205373_item	2958488	et	3	main
ja	doc_973441205373_item	2958490	et	3	main
hunti	doc_973441205373_item	2958494	et	4	main
janu	doc_973441205373_item	2958509	et	4	main
ta	doc_973441205373_item	2958511	et	4	main
juua	doc_973441205373_item	2958513	et	3	main
jõesse	doc_973441205373_item	2958522	et	3	main
lõpetasin	doc_973441205374_item	2958535	et	3	main
aastal	doc_973441205374_item	2958538	et	3	main
halb	doc_973441205374_item	2958540	et	3	main
õppisime	doc_973441205374_item	2958553	et	3	main
võinud	doc_973441205374_item	2958567	et	4	main
tasakaalukas	doc_973441205374_item	2958577	et	4	main
probleeme	doc_973441205374_item	2958582	et	3	main
tüdrukut	doc_973441205373_item	2958491	et	3	main
punamütsikega	doc_973441205373_item	2958497	et	4	main
välja	doc_973441205373_item	2958499	et	4	main
ning	doc_973441205373_item	2958510	et	3	main
läks	doc_973441205373_item	2958512	et	3	main
teda	doc_973441205373_item	2958515	et	4	main
kõhus	doc_973441205373_item	2958516	et	3	main
oli	doc_973441205373_item	2958517	et	3	main
kivid	doc_973441205373_item	2958518	et	3	main
siis	doc_973441205373_item	2958519	et	3	main
ta	doc_973441205373_item	2958520	et	4	main
vanaema	doc_973441205373_item	2958496	et	4	main
aga	doc_973441205373_item	2958514	et	3	main
kukkus	doc_973441205373_item	2958521	et	3	main
essee	doc_973441205374_item	2958523	et	4	main
mälestused	doc_973441205374_item	2958525	et	4	main
koolipõlvest	doc_973441205374_item	2958526	et	4	main
minu	doc_973441205374_item	2958527	et	3	main
jaoks	doc_973441205374_item	2958528	et	4	main
mina	doc_973441205374_item	2958534	et	4	main
kõik	doc_973441205374_item	2958539	et	4	main
polnud	doc_973441205374_item	2958545	et	3	main
meenutada	doc_973441205374_item	2958551	et	3	main
väga	doc_973441205374_item	2958554	et	3	main
ajal	doc_973441205374_item	2958556	et	4	main
lagunes	doc_973441205374_item	2958559	et	3	main
ning	doc_973441205374_item	2958561	et	3	main
öelda	doc_973441205374_item	2958569	et	4	main
rahulik	doc_973441205374_item	2958576	et	3	main
kellel	doc_973441205374_item	2958579	et	4	main
autoritaarne	doc_973441205374_item	2958631	et	4	main
ja	doc_973441205374_item	2958634	et	3	main
lõbus	doc_973441205374_item	2958653	et	4	main
ta	doc_973441205374_item	2958663	et	4	main
armastab	doc_973441205374_item	2958664	et	3	main
rääkida	doc_973441205374_item	2958666	et	3	main
ja	doc_973441205374_item	2958667	et	3	main
elu	doc_973441205374_item	2958668	et	4	main
üle	doc_973441205374_item	2958669	et	3	main
häirib	doc_973441205374_item	2958674	et	3	main
kuid	doc_973441205374_item	2958676	et	4	main
oskus	doc_973441205374_item	2958679	et	3	main
väljendada	doc_973441205374_item	2958681	et	3	main
õnnestus	doc_973441205374_item	2958716	et	4	main
oma	doc_973441205374_item	2958719	et	4	main
koolipõlve	doc_973441205374_item	2958529	et	4	main
aastat	doc_973441205374_item	2958530	et	3	main
jäid	doc_973441205374_item	2958531	et	4	main
1991	doc_973441205374_item	2958537	et	2	main
kuid	doc_973441205374_item	2958543	et	4	main
eriti	doc_973441205374_item	2958546	et	3	main
midagi	doc_973441205374_item	2958547	et	4	main
mis	doc_973441205374_item	2958549	et	4	main
kui	doc_973441205374_item	2958558	et	3	main
ümberkorraldus	doc_973441205374_item	2958563	et	3	main
ja	doc_973441205374_item	2958564	et	3	main
millega	doc_973441205374_item	2958570	et	3	main
see	doc_973441205374_item	2958571	et	3	main
lõppeb	doc_973441205374_item	2958572	et	3	main
kooliajal	doc_973441205374_item	2958573	et	3	main
ma	doc_973441205374_item	2958574	et	3	main
olen	doc_973441205374_item	2958575	et	3	main
ei	doc_973441205374_item	2958584	et	4	main
toll	doc_973441205374_item	2958591	et	3	main
ajal	doc_973441205374_item	2958592	et	4	main
õpilase	doc_973441205374_item	2958593	et	3	main
ja	doc_973441205374_item	2958594	et	3	main
õpetaja	doc_973441205374_item	2958595	et	4	main
vahelises	doc_973441205374_item	2958596	et	4	main
suhted	doc_973441205374_item	2958597	et	3	main
olid	doc_973441205374_item	2958598	et	4	main
lihtsamad	doc_973441205374_item	2958599	et	4	main
selles	doc_973441205374_item	2958600	et	4	main
mõttes	doc_973441205374_item	2958601	et	3	main
et	doc_973441205374_item	2958602	et	3	main
konflikte	doc_973441205374_item	2958603	et	3	main
tekis	doc_973441205374_item	2958604	et	3	main
vähem	doc_973441205374_item	2958605	et	4	main
ja	doc_973441205374_item	2958606	et	3	main
neid	doc_973441205374_item	2958607	et	4	main
püüti	doc_973441205374_item	2958608	et	3	main
kohe	doc_973441205374_item	2958609	et	4	main
lahendada	doc_973441205374_item	2958610	et	3	main
aga	doc_973441205374_item	2958611	et	3	main
kui	doc_973441205374_item	2958612	et	3	main
minu	doc_973441205374_item	2958613	et	3	main
poeg	doc_973441205374_item	2958614	et	3	main
läks	doc_973441205374_item	2958615	et	3	main
kooli	doc_973441205374_item	2958616	et	4	main
siis	doc_973441205374_item	2958617	et	3	main
minumeelest	doc_973441205374_item	2958618	et	4	main
esimest	doc_973441205374_item	2958619	et	4	main
viie	doc_973441205374_item	2958620	et	3	main
puutusin	doc_973441205374_item	2958624	et	3	main
kokku	doc_973441205374_item	2958625	et	3	main
paljude	doc_973441205374_item	2958626	et	3	main
kui	doc_973441205374_item	2958637	et	3	main
jooksul	doc_973441205374_item	2958622	et	4	main
ma	doc_973441205374_item	2958623	et	3	main
vastupidine	doc_973441205374_item	2958636	et	3	main
õpetajana	doc_973441205374_item	2958638	et	4	main
tunne	doc_973441205374_item	2958640	et	4	main
selles	doc_973441205374_item	2958646	et	4	main
et	doc_973441205374_item	2958647	et	3	main
minu	doc_973441205374_item	2958648	et	3	main
poeg	doc_973441205374_item	2958649	et	3	main
on	doc_973441205374_item	2958650	et	4	main
väga	doc_973441205374_item	2958651	et	3	main
energiline	doc_973441205374_item	2958652	et	3	main
minu	doc_973441205374_item	2958677	et	3	main
tal	doc_973441205374_item	2958683	et	3	main
elus	doc_973441205374_item	2958684	et	4	main
tarvis	doc_973441205374_item	2958685	et	3	main
esimesest	doc_973441205374_item	2958686	et	3	main
klaasist	doc_973441205374_item	2958687	et	4	main
peale	doc_973441205374_item	2958688	et	4	main
minu	doc_973441205374_item	2958689	et	3	main
poja	doc_973441205374_item	2958690	et	4	main
päevik	doc_973441205374_item	2958691	et	3	main
oli	doc_973441205374_item	2958692	et	3	main
punane	doc_973441205374_item	2958693	et	4	main
märkustest	doc_973441205374_item	2958694	et	4	main
paha	doc_973441205374_item	2958695	et	4	main
käitumise	doc_973441205374_item	2958696	et	4	main
pärast	doc_973441205374_item	2958697	et	4	main
see	doc_973441205374_item	2958698	et	3	main
võttis	doc_973441205374_item	2958699	et	3	main
pojalt	doc_973441205374_item	2958700	et	4	main
õppimise	doc_973441205374_item	2958701	et	4	main
isu	doc_973441205374_item	2958702	et	4	main
ära	doc_973441205374_item	2958703	et	4	main
kuid	doc_973441205374_item	2958704	et	4	main
õnneks	doc_973441205374_item	2958705	et	4	main
autoritaarne	doc_973441205374_item	2958706	et	4	main
esimese	doc_973441205374_item	2958707	et	3	main
klaasi	doc_973441205374_item	2958708	et	4	main
õpetaja	doc_973441205374_item	2958709	et	4	main
läks	doc_973441205374_item	2958710	et	3	main
pensionile	doc_973441205374_item	2958711	et	3	main
ja	doc_973441205374_item	2958712	et	3	main
alles	doc_973441205374_item	2958713	et	3	main
ei	doc_973441205374_item	2958639	et	4	main
huvi	doc_973441205374_item	2958641	et	4	main
suurem	doc_973441205374_item	2958656	et	4	main
õnnestus	doc_973441205374_item	2958657	et	4	main
jaoks	doc_973441205374_item	2958659	et	4	main
palju	doc_973441205374_item	2958665	et	4	main
omadus	doc_973441205374_item	2958673	et	4	main
arvates	doc_973441205374_item	2958678	et	4	main
end	doc_973441205374_item	2958680	et	4	main
pojaga	doc_973441205374_item	2958717	et	4	main
ma	doc_973441205374_item	2958721	et	3	main
püüdis	doc_973441205374_item	2958723	et	3	main
selgitada	doc_973441205374_item	2958724	et	3	main
temaga	doc_973441205374_item	2958726	et	3	main
raske	doc_973441205374_item	2958728	et	4	main
käitumise	doc_973441205374_item	2958730	et	4	main
ma	doc_973441205374_item	2958734	et	3	main
materiaalset	doc_973441205374_item	2958742	et	3	main
anda	doc_973441205374_item	2958744	et	3	main
haridust	doc_973441205374_item	2958747	et	4	main
tuleb	doc_973441205374_item	2958748	et	3	main
leppida	doc_973441205374_item	2958749	et	3	main
riigi	doc_973441205374_item	2958750	et	3	main
õppesüsteemiga	doc_973441205374_item	2958751	et	3	main
õpetaja	doc_973441205374_item	2958752	et	4	main
olema	doc_973441205374_item	2958761	et	4	main
ka	doc_973441205374_item	2958762	et	3	main
huvitavam	doc_973441205374_item	2958786	et	4	main
prestiižsem	doc_973441205374_item	2958788	et	2	main
tööd	doc_973441205374_item	2958789	et	4	main
leidma	doc_973441205374_item	2958790	et	3	main
aga	doc_973441205374_item	2958791	et	3	main
on	doc_973441205374_item	2958792	et	4	main
maksta	doc_973441205374_item	2958796	et	4	main
ei	doc_973441205374_item	2958812	et	4	main
proovi	doc_973441205374_item	2958813	et	4	main
veel	doc_973441205374_item	2958846	et	4	main
on	doc_973441205374_item	2958850	et	4	main
väga	doc_973441205374_item	2958851	et	3	main
psühholoogial	doc_973441205374_item	2958863	et	3	main
suhet	doc_973441205374_item	2958867	et	3	main
kõik	doc_973441205374_item	2958869	et	4	main
eksisteerivad	doc_973441205374_item	2958880	et	4	main
kasvatusprobleemid	doc_973441205374_item	2958881	et	3	main
alati	doc_973441205374_item	2958882	et	4	main
võtma	doc_973441205374_item	2958886	et	3	main
õpilasel	doc_973441205374_item	2958891	et	3	main
kooliaeg	doc_973441205375_item	2958921	et	3	main
on	doc_973441205375_item	2958923	et	4	main
parim	doc_973441205375_item	2958925	et	4	main
ei	doc_973441205375_item	2958934	et	4	main
sellest	doc_973441205375_item	2958938	et	4	main
kuidas	doc_973441205375_item	2958939	et	3	main
kõike	doc_973441205375_item	2958940	et	4	main
õigel	doc_973441205375_item	2958941	et	3	main
ajal	doc_973441205375_item	2958942	et	4	main
jõudma	doc_973441205375_item	2958943	et	3	main
jätkavad	doc_973441205375_item	2958951	et	4	main
õpemist	doc_973441205375_item	2958953	et	4	main
ma	doc_973441205375_item	2958954	et	3	main
lõpetasin	doc_973441205375_item	2958955	et	3	main
kooli	doc_973441205375_item	2958956	et	4	main
kordada	doc_973441205375_item	2958969	et	4	main
puutub	doc_973441205375_item	2958971	et	3	main
minusse	doc_973441205375_item	2958972	et	3	main
erenevaid	doc_973441205375_item	2958976	et	4	main
kapital	doc_973441205375_item	2958991	et	3	main
siis	doc_973441205374_item	2958714	et	3	main
meil	doc_973441205374_item	2958715	et	4	main
ümberveenata	doc_973441205374_item	2958718	et	3	main
pojale	doc_973441205374_item	2958720	et	4	main
tema	doc_973441205374_item	2958729	et	4	main
nii	doc_973441205374_item	2958735	et	3	main
võimalust	doc_973441205374_item	2958743	et	3	main
jaoks	doc_973441205374_item	2958753	et	4	main
vähe	doc_973441205374_item	2958754	et	3	main
teada	doc_973441205374_item	2958755	et	3	main
hästi	doc_973441205374_item	2958756	et	3	main
hea	doc_973441205374_item	2958763	et	4	main
välja	doc_973441205374_item	2958795	et	4	main
pedagoogiharidus	doc_973441205374_item	2958809	et	3	main
lihtne	doc_973441205374_item	2958825	et	3	main
inimene	doc_973441205374_item	2958826	et	3	main
ta	doc_973441205374_item	2958831	et	4	main
ma	doc_973441205374_item	2958836	et	3	main
teravad	doc_973441205374_item	2958841	et	3	main
on	doc_973441205374_item	2958857	et	4	main
probleemidesse	doc_973441205374_item	2958875	et	3	main
õpetajate	doc_973441205374_item	2958876	et	4	main
ja	doc_973441205374_item	2958877	et	3	main
õpilaste	doc_973441205374_item	2958878	et	4	main
tasemel	doc_973441205374_item	2958888	et	3	main
peab	doc_973441205374_item	2958892	et	4	main
mõtelda	doc_973441205375_item	2958937	et	4	main
töötavad	doc_973441205375_item	2958947	et	4	main
ja	doc_973441205375_item	2958948	et	3	main
ajal	doc_973441205375_item	2958950	et	4	main
kord	doc_973441205375_item	2958964	et	4	main
seda	doc_973441205375_item	2958965	et	3	main
aega	doc_973441205375_item	2958968	et	4	main
mis	doc_973441205375_item	2958970	et	4	main
mul	doc_973441205375_item	2958973	et	3	main
nii	doc_973441205375_item	2958978	et	3	main
kui	doc_973441205375_item	2958980	et	3	main
nõus	doc_973441205375_item	2958985	et	4	main
õpimine	doc_973441205375_item	2958988	et	4	main
see	doc_973441205375_item	2958989	et	3	main
on	doc_973441205375_item	2958990	et	4	main
eluks	doc_973441205375_item	2958993	et	3	main
alati	doc_973441205375_item	2958995	et	4	main
hea	doc_973441205375_item	2959030	et	4	main
meldinud	doc_973441205375_item	2959036	et	4	main
uut	doc_973441205375_item	2959041	et	3	main
et	doc_973441205375_item	2959056	et	3	main
inimene	doc_973441205375_item	2959058	et	3	main
või	doc_973441205375_item	2959079	et	4	main
nägin	doc_973441205375_item	2959086	et	3	main
head	doc_973441205375_item	2959094	et	4	main
professionalid	doc_973441205375_item	2959101	et	4	main
tegelesid	doc_973441205375_item	2959103	et	4	main
nende	doc_973441205375_item	2959104	et	4	main
alati	doc_973441205375_item	2959110	et	4	main
abistasid	doc_973441205375_item	2959111	et	4	main
sõbrad	doc_973441205375_item	2959115	et	3	main
huvitav	doc_973441205375_item	2959117	et	4	main
alati	doc_973441205374_item	2958722	et	4	main
et	doc_973441205374_item	2958725	et	3	main
pärast	doc_973441205374_item	2958731	et	4	main
vaga	doc_973441205374_item	2958738	et	4	main
mul	doc_973441205374_item	2958740	et	3	main
oma	doc_973441205374_item	2958757	et	4	main
ainet	doc_973441205374_item	2958758	et	3	main
ta	doc_973441205374_item	2958759	et	4	main
psühholoog	doc_973441205374_item	2958764	et	4	main
mõistma	doc_973441205374_item	2958765	et	3	main
lapsed	doc_973441205374_item	2958766	et	3	main
iga	doc_973441205374_item	2958767	et	4	main
tunneb	doc_973441205374_item	2958769	et	3	main
vajadust	doc_973441205374_item	2958770	et	4	main
individuaalses	doc_973441205374_item	2958771	et	3	main
lähenemises	doc_973441205374_item	2958772	et	4	main
enamikul	doc_973441205374_item	2958773	et	3	main
juhtudel	doc_973441205374_item	2958774	et	3	main
noored	doc_973441205374_item	2958775	et	3	main
õpetajad	doc_973441205374_item	2958776	et	4	main
koolis	doc_973441205374_item	2958778	et	4	main
sel	doc_973441205374_item	2958779	et	3	main
lihtsal	doc_973441205374_item	2958780	et	3	main
põhjusel	doc_973441205374_item	2958781	et	3	main
et	doc_973441205374_item	2958782	et	3	main
töötavad	doc_973441205374_item	2958777	et	4	main
nad	doc_973441205374_item	2958783	et	3	main
ei	doc_973441205374_item	2958784	et	4	main
suuda	doc_973441205374_item	2958785	et	4	main
ja	doc_973441205374_item	2958787	et	3	main
raha	doc_973441205374_item	2958802	et	4	main
olemas	doc_973441205374_item	2958808	et	4	main
töötada	doc_973441205374_item	2958815	et	3	main
arvates	doc_973441205374_item	2958817	et	4	main
see	doc_973441205374_item	2958818	et	3	main
on	doc_973441205374_item	2958819	et	4	main
halb	doc_973441205374_item	2958820	et	3	main
ja	doc_973441205374_item	2958833	et	3	main
tunda	doc_973441205374_item	2958835	et	3	main
arvan	doc_973441205374_item	2958837	et	3	main
meie	doc_973441205374_item	2958839	et	4	main
on	doc_973441205374_item	2958842	et	4	main
ja	doc_973441205374_item	2958843	et	3	main
jääb	doc_973441205374_item	2958844	et	3	main
haridusprobleemid	doc_973441205374_item	2958845	et	3	main
põlvkond	doc_973441205374_item	2958849	et	3	main
arenenud	doc_973441205374_item	2958852	et	4	main
õpelesed	doc_973441205374_item	2958856	et	4	main
nagu	doc_973441205374_item	2958858	et	3	main
ja	doc_973441205374_item	2958866	et	3	main
mõjub	doc_973441205374_item	2958871	et	3	main
vahel	doc_973441205374_item	2958879	et	4	main
autoriteetsust	doc_973441205374_item	2958885	et	4	main
olema	doc_973441205374_item	2958889	et	4	main
õpetaja	doc_973441205374_item	2958895	et	4	main
ning	doc_973441205374_item	2958896	et	3	main
polt	doc_973441205374_item	2958898	et	3	main
oskust	doc_973441205374_item	2958899	et	3	main
lugupidamist	doc_973441205374_item	2958900	et	3	main
õpetaja	doc_973441205374_item	2958897	et	4	main
võita	doc_973441205374_item	2958901	et	4	main
ja	doc_973441205374_item	2958902	et	3	main
pärast	doc_973441205374_item	2958903	et	4	main
seda	doc_973441205374_item	2958904	et	3	main
on	doc_973441205374_item	2958905	et	4	main
võimalik	doc_973441205374_item	2958906	et	3	main
rääkida	doc_973441205374_item	2958907	et	3	main
teadmisest	doc_973441205374_item	2958908	et	4	main
essee	doc_973441205375_item	2958909	et	4	main
ebameeldivad	doc_973441205375_item	2958910	et	3	main
ja	doc_973441205375_item	2958911	et	3	main
meeldivad	doc_973441205375_item	2958912	et	4	main
mälestused	doc_973441205375_item	2958913	et	4	main
koolipõlvest	doc_973441205375_item	2958914	et	4	main
tahan	doc_973441205375_item	2958915	et	3	main
alustada	doc_973441205375_item	2958916	et	3	main
sellest	doc_973441205375_item	2958917	et	4	main
et	doc_973441205375_item	2958918	et	3	main
millelegi	doc_973441205375_item	2958919	et	4	main
vaatamata	doc_973441205375_item	2958920	et	4	main
see	doc_973441205375_item	2958922	et	3	main
eelkõige	doc_973441205375_item	2958924	et	3	main
aeg	doc_973441205375_item	2958926	et	3	main
elus	doc_973441205375_item	2958927	et	4	main
miks	doc_973441205375_item	2958928	et	4	main
ma	doc_973441205375_item	2958929	et	3	main
arvan	doc_973441205375_item	2958930	et	3	main
nii	doc_973441205375_item	2958931	et	3	main
vaja	doc_973441205375_item	2958936	et	4	main
sest	doc_973441205375_item	2958944	et	4	main
tihti	doc_973441205375_item	2958945	et	3	main
tudengid	doc_973441205375_item	2958946	et	3	main
tunnevad	doc_973441205374_item	2958864	et	3	main
mis	doc_973441205374_item	2958873	et	4	main
õpetajad	doc_973441205374_item	2958883	et	4	main
peavad	doc_973441205374_item	2958884	et	4	main
alguses	doc_973441205374_item	2958890	et	4	main
austus	doc_973441205374_item	2958894	et	4	main
sest	doc_973441205375_item	2958932	et	4	main
teile	doc_973441205375_item	2958933	et	4	main
saamal	doc_973441205375_item	2958949	et	3	main
selles	doc_973441205375_item	2958957	et	4	main
aastal	doc_973441205375_item	2958958	et	3	main
ja	doc_973441205375_item	2958959	et	3	main
juba	doc_973441205375_item	2958960	et	3	main
praegu	doc_973441205375_item	2958961	et	3	main
tahan	doc_973441205375_item	2958962	et	3	main
muretut	doc_973441205375_item	2958967	et	4	main
ebameeldivaid	doc_973441205375_item	2958982	et	3	main
täiesti	doc_973441205375_item	2958984	et	3	main
väitega	doc_973441205375_item	2958986	et	3	main
kogu	doc_973441205375_item	2958992	et	4	main
ma	doc_973441205375_item	2958994	et	3	main
armastasin	doc_973441205375_item	2958996	et	3	main
õppida	doc_973441205375_item	2958997	et	3	main
mulle	doc_973441205375_item	2958998	et	4	main
meeldis	doc_973441205375_item	2958999	et	3	main
ja	doc_973441205375_item	2959000	et	3	main
praegu	doc_973441205375_item	2959001	et	3	main
ka	doc_973441205375_item	2959002	et	3	main
saab	doc_973441205375_item	2959003	et	3	main
teada	doc_973441205375_item	2959004	et	3	main
uut	doc_973441205375_item	2959006	et	3	main
midagi	doc_973441205375_item	2959005	et	4	main
millal	doc_973441205375_item	2959007	et	3	main
ma	doc_973441205375_item	2959008	et	3	main
õpisin	doc_973441205375_item	2959009	et	4	main
ma	doc_973441205375_item	2959011	et	3	main
koolis	doc_973441205375_item	2959010	et	4	main
sain	doc_973441205375_item	2959012	et	3	main
aru	doc_973441205375_item	2959013	et	4	main
et	doc_973441205375_item	2959014	et	3	main
seda	doc_973441205375_item	2959015	et	3	main
eelkõige	doc_973441205375_item	2959016	et	3	main
on	doc_973441205375_item	2959017	et	4	main
vaja	doc_973441205375_item	2959018	et	4	main
mulle	doc_973441205375_item	2959019	et	4	main
selleks	doc_973441205375_item	2959020	et	4	main
et	doc_973441205375_item	2959021	et	3	main
kooli	doc_973441205375_item	2959023	et	4	main
ja	doc_973441205375_item	2959033	et	3	main
mulle	doc_973441205375_item	2959034	et	4	main
andnud	doc_973441205375_item	2959040	et	4	main
olen	doc_973441205375_item	2959054	et	3	main
kindel	doc_973441205375_item	2959055	et	3	main
iseseisvalt	doc_973441205375_item	2959059	et	4	main
ta	doc_973441205375_item	2959073	et	4	main
juba	doc_973441205375_item	2959075	et	3	main
teistega	doc_973441205375_item	2959090	et	4	main
olid	doc_973441205375_item	2959097	et	4	main
ja	doc_973441205375_item	2959098	et	3	main
praegu	doc_973441205375_item	2959099	et	3	main
tahatsid	doc_973441205375_item	2959107	et	4	main
õppida	doc_973441205375_item	2959108	et	3	main
lõpetasid	doc_973441205375_item	2959129	et	4	main
kooli	doc_973441205375_item	2959131	et	4	main
veel	doc_973441205375_item	2958963	et	4	main
mälestusi	doc_973441205375_item	2958977	et	4	main
pärast	doc_973441205375_item	2959022	et	4	main
astuda	doc_973441205375_item	2959024	et	3	main
ja	doc_973441205375_item	2959026	et	3	main
tulevikus	doc_973441205375_item	2959027	et	4	main
mul	doc_973441205375_item	2959028	et	3	main
oleks	doc_973441205375_item	2959029	et	3	main
ei	doc_973441205375_item	2959035	et	4	main
teadmisi	doc_973441205375_item	2959044	et	4	main
räägis	doc_973441205375_item	2959046	et	3	main
et	doc_973441205375_item	2959048	et	3	main
et	doc_973441205375_item	2959072	et	3	main
oma	doc_973441205375_item	2959076	et	4	main
valiku	doc_973441205375_item	2959077	et	3	main
ei	doc_973441205375_item	2959078	et	4	main
aga	doc_973441205375_item	2959084	et	3	main
kes	doc_973441205375_item	2959096	et	4	main
kes	doc_973441205375_item	2959102	et	4	main
kes	doc_973441205375_item	2959109	et	4	main
olid	doc_973441205375_item	2959113	et	4	main
oma	doc_973441205375_item	2959122	et	4	main
kes	doc_973441205375_item	2959124	et	4	main
varem	doc_973441205375_item	2959125	et	4	main
aga	doc_973441205375_item	2959128	et	3	main
eesti	doc_973441205375_item	2959130	et	4	main
räägivad	doc_973441205375_item	2959132	et	3	main
et	doc_973441205375_item	2959133	et	3	main
eesti	doc_973441205375_item	2959134	et	4	main
koolis	doc_973441205375_item	2959135	et	4	main
seda	doc_973441205375_item	2959143	et	3	main
asemel	doc_973441205375_item	2959144	et	4	main
lõpetasin	doc_973441205376_item	2959161	et	3	main
n	doc_973441205376_item	2959163	et	4	main
isegi	doc_973441205376_item	2959179	et	4	main
lemmikained	doc_973441205376_item	2959180	et	3	main
muuresid	doc_973441205376_item	2959184	et	3	main
tundeid	doc_973441205376_item	2959187	et	3	main
aineteks	doc_973441205376_item	2959192	et	3	main
koolis	doc_973441205376_item	2959193	et	4	main
matemaatike	doc_973441205376_item	2959195	et	4	main
bioloogia	doc_973441205376_item	2959196	et	4	main
ema	doc_973441205376_item	2959203	et	4	main
töötab	doc_973441205376_item	2959204	et	3	main
õpetajana	doc_973441205376_item	2959206	et	4	main
sest	doc_973441205376_item	2959210	et	4	main
mind	doc_973441205376_item	2959211	et	4	main
huvitavaid	doc_973441205376_item	2959228	et	4	main
egiptuse	doc_973441205376_item	2959244	et	4	main
isegi	doc_973441205376_item	2959251	et	4	main
lemmik	doc_973441205376_item	2959252	et	3	main
ained	doc_973441205376_item	2959253	et	3	main
olukordi	doc_973441205376_item	2959256	et	4	main
matemaatikas	doc_973441205376_item	2959258	et	3	main
mind	doc_973441205376_item	2959259	et	4	main
ärritas	doc_973441205376_item	2959260	et	3	main
mind	doc_973441205376_item	2959269	et	4	main
tahvli	doc_973441205376_item	2959280	et	3	main
juurde	doc_973441205376_item	2959281	et	4	main
ka	doc_973441205376_item	2959319	et	3	main
lemmik	doc_973441205376_item	2959320	et	3	main
ka	doc_973441205375_item	2958981	et	3	main
ma	doc_973441205375_item	2958983	et	3	main
et	doc_973441205375_item	2958987	et	3	main
ülikooli	doc_973441205375_item	2959025	et	4	main
töö	doc_973441205375_item	2959032	et	4	main
ei	doc_973441205375_item	2959039	et	4	main
uut	doc_973441205375_item	2959043	et	3	main
õpilastele	doc_973441205375_item	2959047	et	4	main
peavad	doc_973441205375_item	2959050	et	4	main
õppima	doc_973441205375_item	2959051	et	3	main
parem	doc_973441205375_item	2959052	et	4	main
ma	doc_973441205375_item	2959053	et	3	main
iga	doc_973441205375_item	2959057	et	4	main
otsustab	doc_973441205375_item	2959060	et	3	main
mida	doc_973441205375_item	2959061	et	4	main
ta	doc_973441205375_item	2959062	et	4	main
tahab	doc_973441205375_item	2959063	et	3	main
ja	doc_973441205375_item	2959064	et	3	main
kui	doc_973441205375_item	2959065	et	3	main
õpilane	doc_973441205375_item	2959066	et	3	main
õpib	doc_973441205375_item	2959067	et	3	main
gümnaasiumis	doc_973441205375_item	2959068	et	3	main
siis	doc_973441205375_item	2959069	et	3	main
ma	doc_973441205375_item	2959070	et	3	main
ööelda	doc_973441205375_item	2959080	et	4	main
kuidas	doc_973441205375_item	2959087	et	3	main
tegis	doc_973441205375_item	2959089	et	4	main
muidugi	doc_973441205375_item	2959091	et	4	main
ka	doc_973441205375_item	2959092	et	3	main
olid	doc_973441205375_item	2959093	et	4	main
on	doc_973441205375_item	2959100	et	4	main
õpelastega	doc_973441205375_item	2959105	et	4	main
kes	doc_973441205375_item	2959106	et	4	main
kes	doc_973441205375_item	2959112	et	4	main
õpisid	doc_973441205375_item	2959126	et	4	main
kõik	doc_973441205375_item	2959136	et	4	main
teadmisi	doc_973441205375_item	2959141	et	4	main
meeldivad	doc_973441205376_item	2959151	et	4	main
kooli	doc_973441205376_item	2959162	et	4	main
6	doc_973441205376_item	2959164	et	2	main
käigus	doc_973441205376_item	2959166	et	4	main
negatiivsed	doc_973441205376_item	2959172	et	3	main
ning	doc_973441205376_item	2959185	et	3	main
minu	doc_973441205376_item	2959190	et	3	main
olid	doc_973441205376_item	2959194	et	4	main
matemaatika	doc_973441205376_item	2959207	et	4	main
bioloogia	doc_973441205376_item	2959220	et	4	main
huvitas	doc_973441205376_item	2959221	et	3	main
kõigepealt	doc_973441205376_item	2959223	et	3	main
teadmisi	doc_973441205376_item	2959229	et	4	main
elusolenditest	doc_973441205376_item	2959230	et	3	main
ajalooõpetaja	doc_973441205376_item	2959231	et	4	main
oskas	doc_973441205376_item	2959232	et	3	main
sündmustest	doc_973441205376_item	2959238	et	4	main
vastu	doc_973441205376_item	2959246	et	3	main
ja	doc_973441205376_item	2959247	et	3	main
lood	doc_973441205376_item	2959248	et	4	main
juurde	doc_973441205376_item	2959271	et	4	main
lõppude	doc_973441205376_item	2959273	et	4	main
ise	doc_973441205376_item	2959278	et	4	main
kutsus	doc_973441205376_item	2959285	et	4	main
kooli	doc_973441205376_item	2959326	et	4	main
essee	doc_973441205377_item	2959328	et	4	main
minu	doc_973441205377_item	2959329	et	3	main
keskkoolis	doc_973441205377_item	2959335	et	4	main
number	doc_973441205377_item	2959336	et	3	main
4	doc_973441205377_item	2959337	et	2	main
neli	doc_973441205377_item	2959338	et	3	main
esimesest	doc_973441205377_item	2959339	et	3	main
klassist	doc_973441205377_item	2959340	et	3	main
ja	doc_973441205377_item	2959341	et	3	main
lõpuni	doc_973441205377_item	2959342	et	3	main
ainult	doc_973441205377_item	2959346	et	4	main
väga	doc_973441205377_item	2959348	et	3	main
koolipäev	doc_973441205377_item	2959353	et	3	main
eelmisel	doc_973441205377_item	2959356	et	3	main
väga	doc_973441205377_item	2959359	et	3	main
ilus	doc_973441205377_item	2959368	et	4	main
kott	doc_973441205377_item	2959369	et	3	main
ja	doc_973441205377_item	2959371	et	3	main
emaga	doc_973441205377_item	2959380	et	3	main
olin	doc_973441205377_item	2959398	et	3	main
armastav	doc_973441205375_item	2959031	et	4	main
kui	doc_973441205375_item	2959037	et	3	main
õpetaja	doc_973441205375_item	2959038	et	4	main
infot	doc_973441205375_item	2959042	et	3	main
aga	doc_973441205375_item	2959045	et	3	main
nad	doc_973441205375_item	2959049	et	3	main
arvan	doc_973441205375_item	2959071	et	3	main
tegis	doc_973441205375_item	2959074	et	4	main
et	doc_973441205375_item	2959081	et	3	main
mind	doc_973441205375_item	2959082	et	4	main
alandas	doc_973441205375_item	2959083	et	3	main
ma	doc_973441205375_item	2959085	et	3	main
see	doc_973441205375_item	2959088	et	3	main
õpetajad	doc_973441205375_item	2959095	et	4	main
nagu	doc_973441205375_item	2959114	et	3	main
väga	doc_973441205375_item	2959116	et	3	main
see	doc_973441205375_item	2959118	et	3	main
fakt	doc_973441205375_item	2959119	et	3	main
et	doc_973441205375_item	2959120	et	3	main
vesteldes	doc_973441205375_item	2959121	et	3	main
sõbradega	doc_973441205375_item	2959123	et	4	main
venekoolis	doc_973441205375_item	2959127	et	4	main
annavad	doc_973441205375_item	2959139	et	3	main
nõusse	doc_973441205375_item	2959148	et	4	main
õppida	doc_973441205375_item	2959149	et	3	main
õppimise	doc_973441205376_item	2959165	et	4	main
mõnikord	doc_973441205376_item	2959181	et	3	main
tõid	doc_973441205376_item	2959182	et	4	main
lemmik	doc_973441205376_item	2959191	et	3	main
ajalugu	doc_973441205376_item	2959197	et	4	main
ja	doc_973441205376_item	2959198	et	3	main
et	doc_973441205376_item	2959201	et	3	main
füüsika	doc_973441205376_item	2959205	et	4	main
mulle	doc_973441205376_item	2959208	et	4	main
lahendamine	doc_973441205376_item	2959216	et	4	main
ja	doc_973441205376_item	2959217	et	3	main
graafikute	doc_973441205376_item	2959218	et	3	main
joonistamine	doc_973441205376_item	2959219	et	4	main
tõttu	doc_973441205376_item	2959225	et	4	main
et	doc_973441205376_item	2959226	et	3	main
sain	doc_973441205376_item	2959227	et	3	main
huvitavalt	doc_973441205376_item	2959234	et	4	main
rääkida	doc_973441205376_item	2959235	et	3	main
möödunud	doc_973441205376_item	2959236	et	4	main
kõige	doc_973441205376_item	2959239	et	4	main
kleopatrast	doc_973441205376_item	2959249	et	4	main
tekitasid	doc_973441205376_item	2959254	et	4	main
näiteks	doc_973441205376_item	2959257	et	4	main
kutsus	doc_973441205376_item	2959268	et	4	main
ning	doc_973441205376_item	2959272	et	3	main
hakkasin	doc_973441205376_item	2959275	et	3	main
kõige	doc_973441205376_item	2959282	et	4	main
mälestused	doc_973441205377_item	2959330	et	4	main
mina	doc_973441205377_item	2959343	et	4	main
mäletan	doc_973441205377_item	2959344	et	3	main
head	doc_973441205377_item	2959347	et	4	main
ema	doc_973441205377_item	2959364	et	4	main
kassidega	doc_973441205377_item	2959370	et	4	main
hommikul	doc_973441205377_item	2959379	et	3	main
kooli	doc_973441205377_item	2959382	et	4	main
kardsin	doc_973441205377_item	2959384	et	4	main
siiski	doc_973441205377_item	2959392	et	4	main
kõige	doc_973441205377_item	2959399	et	4	main
klassis	doc_973441205377_item	2959401	et	3	main
üldse	doc_973441205377_item	2959407	et	3	main
muutus	doc_973441205377_item	2959414	et	4	main
paremaks	doc_973441205377_item	2959415	et	4	main
kohtumine	doc_973441205377_item	2959426	et	4	main
oma	doc_973441205377_item	2959427	et	4	main
esimese	doc_973441205377_item	2959428	et	3	main
ta	doc_973441205377_item	2959435	et	4	main
oli	doc_973441205377_item	2959436	et	3	main
ka	doc_973441205377_item	2959437	et	3	main
väga	doc_973441205377_item	2959438	et	3	main
tark	doc_973441205377_item	2959439	et	3	main
ja	doc_973441205377_item	2959440	et	3	main
õpetaja	doc_973441205377_item	2959450	et	4	main
koolis	doc_973441205377_item	2959457	et	4	main
alati	doc_973441205377_item	2959469	et	4	main
teisiti	doc_973441205375_item	2959137	et	3	main
seal	doc_973441205375_item	2959138	et	4	main
aga	doc_973441205375_item	2959142	et	3	main
meelitata	doc_973441205375_item	2959146	et	4	main
ei	doc_973441205375_item	2959145	et	4	main
tugevaid	doc_973441205375_item	2959140	et	4	main
essee	doc_973441205376_item	2959150	et	4	main
ja	doc_973441205376_item	2959152	et	3	main
mälestused	doc_973441205376_item	2959154	et	4	main
positiivsed	doc_973441205376_item	2959169	et	3	main
ka	doc_973441205376_item	2959171	et	3	main
kus	doc_973441205376_item	2959174	et	3	main
panin	doc_973441205376_item	2959176	et	3	main
kaasa	doc_973441205376_item	2959183	et	4	main
ja	doc_973441205376_item	2959188	et	3	main
sest	doc_973441205376_item	2959200	et	4	main
huvitas	doc_973441205376_item	2959212	et	3	main
arvutamine	doc_973441205376_item	2959213	et	4	main
logiliste	doc_973441205376_item	2959214	et	4	main
ülesannete	doc_973441205376_item	2959215	et	3	main
oma	doc_973441205375_item	2959147	et	4	main
ebameeldivad	doc_973441205376_item	2959153	et	3	main
koolipõlvest	doc_973441205376_item	2959155	et	4	main
ma	doc_973441205376_item	2959156	et	3	main
õppisin	doc_973441205376_item	2959157	et	3	main
erinevates	doc_973441205376_item	2959158	et	4	main
koolides	doc_973441205376_item	2959159	et	3	main
aga	doc_973441205376_item	2959160	et	3	main
esinesid	doc_973441205376_item	2959167	et	4	main
nii	doc_973441205376_item	2959168	et	3	main
kui	doc_973441205376_item	2959170	et	3	main
emotsioonid	doc_973441205376_item	2959173	et	3	main
juures	doc_973441205376_item	2959175	et	4	main
tähelepanu	doc_973441205376_item	2959177	et	4	main
et	doc_973441205376_item	2959178	et	3	main
ebameeldivaid	doc_973441205376_item	2959186	et	3	main
vastupidi	doc_973441205376_item	2959189	et	3	main
füüsika	doc_973441205376_item	2959199	et	4	main
minu	doc_973441205376_item	2959202	et	3	main
meeldis	doc_973441205376_item	2959209	et	3	main
sajandite	doc_973441205376_item	2959237	et	3	main
rohkem	doc_973441205376_item	2959240	et	4	main
ma	doc_973441205376_item	2959241	et	3	main
tundsin	doc_973441205376_item	2959242	et	3	main
huvi	doc_973441205376_item	2959243	et	4	main
samas	doc_973441205376_item	2959250	et	4	main
et	doc_973441205376_item	2959261	et	3	main
õpetaja	doc_973441205376_item	2959262	et	4	main
terve	doc_973441205376_item	2959263	et	4	main
aasta	doc_973441205376_item	2959264	et	4	main
tulema	doc_973441205376_item	2959279	et	4	main
ette	doc_973441205376_item	2959286	et	4	main
samas	doc_973441205376_item	2959322	et	4	main
rõõmuga	doc_973441205376_item	2959324	et	3	main
koolist	doc_973441205377_item	2959345	et	4	main
hästi	doc_973441205377_item	2959349	et	3	main
oma	doc_973441205377_item	2959351	et	4	main
mäletan	doc_973441205377_item	2959354	et	3	main
päeval	doc_973441205377_item	2959357	et	3	main
energiat	doc_973441205377_item	2959360	et	3	main
täis	doc_973441205377_item	2959361	et	4	main
ja	doc_973441205377_item	2959362	et	3	main
elevil	doc_973441205377_item	2959363	et	4	main
ostis	doc_973441205377_item	2959365	et	4	main
mulle	doc_973441205377_item	2959366	et	4	main
uus	doc_973441205377_item	2959367	et	3	main
mina	doc_973441205377_item	2959372	et	4	main
panen	doc_973441205377_item	2959373	et	3	main
kotti	doc_973441205377_item	2959374	et	4	main
uued	doc_973441205377_item	2959375	et	3	main
kooliasjad	doc_973441205377_item	2959376	et	3	main
jõudsime	doc_973441205377_item	2959381	et	3	main
ma	doc_973441205377_item	2959383	et	3	main
ja	doc_973441205377_item	2959385	et	3	main
tahtnud	doc_973441205377_item	2959387	et	4	main
kooli	doc_973441205377_item	2959388	et	4	main
tulla	doc_973441205377_item	2959389	et	3	main
kuid	doc_973441205377_item	2959390	et	4	main
läksin	doc_973441205377_item	2959395	et	3	main
koolimajja	doc_973441205377_item	2959396	et	3	main
ma	doc_973441205377_item	2959397	et	3	main
inimesed	doc_973441205377_item	2959405	et	3	main
oli	doc_973441205377_item	2959408	et	3	main
ilusamaks	doc_973441205377_item	2959424	et	4	main
oli	doc_973441205377_item	2959431	et	3	main
ja	doc_973441205377_item	2959433	et	3	main
ilus	doc_973441205377_item	2959434	et	4	main
kui	doc_973441205377_item	2959444	et	3	main
vaja	doc_973441205377_item	2959445	et	4	main
tihti	doc_973441205377_item	2959446	et	3	main
olin	doc_973441205377_item	2959447	et	3	main
ma	doc_973441205377_item	2959448	et	3	main
kodus	doc_973441205377_item	2959449	et	4	main
nii	doc_973441205377_item	2959459	et	3	main
kui	doc_973441205377_item	2959463	et	3	main
on	doc_973441205377_item	2959466	et	4	main
saab	doc_973441205377_item	2959467	et	3	main
nendega	doc_973441205377_item	2959468	et	4	main
olid	doc_973441205377_item	2959474	et	4	main
ja	doc_973441205377_item	2959476	et	3	main
meie	doc_973441205377_item	2959478	et	4	main
ka	doc_973441205377_item	2959481	et	3	main
mind	doc_973441205376_item	2959222	et	4	main
selle	doc_973441205376_item	2959224	et	4	main
väga	doc_973441205376_item	2959233	et	3	main
ajaloo	doc_973441205376_item	2959245	et	4	main
ebameeldivad	doc_973441205376_item	2959255	et	3	main
jooksul	doc_973441205376_item	2959265	et	4	main
igal	doc_973441205376_item	2959266	et	3	main
õppetunnil	doc_973441205376_item	2959267	et	3	main
tahvli	doc_973441205376_item	2959270	et	3	main
lõpuks	doc_973441205376_item	2959274	et	4	main
õppetunni	doc_973441205376_item	2959276	et	3	main
alguses	doc_973441205376_item	2959277	et	4	main
negatiivsemaia	doc_973441205376_item	2959283	et	4	main
emotsioone	doc_973441205376_item	2959284	et	3	main
bioloogia	doc_973441205376_item	2959287	et	4	main
õpetaja	doc_973441205376_item	2959288	et	4	main
kes	doc_973441205376_item	2959289	et	4	main
tihti	doc_973441205376_item	2959290	et	3	main
rääkis	doc_973441205376_item	2959291	et	3	main
kõrgendatud	doc_973441205376_item	2959292	et	4	main
toonidel	doc_973441205376_item	2959293	et	3	main
alandas	doc_973441205376_item	2959294	et	3	main
andis	doc_973441205376_item	2959296	et	3	main
õppilasi	doc_973441205376_item	2959295	et	4	main
liiga	doc_973441205376_item	2959297	et	4	main
keerukaid	doc_973441205376_item	2959298	et	3	main
ülesandeid	doc_973441205376_item	2959300	et	3	main
mis	doc_973441205376_item	2959301	et	4	main
kontrolltöö	doc_973441205376_item	2959299	et	4	main
sisaldasid	doc_973441205376_item	2959302	et	4	main
õppematerjaali	doc_973441205376_item	2959303	et	4	main
millest	doc_973441205376_item	2959304	et	3	main
polnud	doc_973441205376_item	2959305	et	3	main
õppetundidel	doc_973441205376_item	2959306	et	3	main
räägitud	doc_973441205376_item	2959307	et	4	main
seega	doc_973441205376_item	2959308	et	4	main
ebameeldivad	doc_973441205376_item	2959309	et	3	main
mälestusi	doc_973441205376_item	2959310	et	4	main
koolipõlvest	doc_973441205376_item	2959311	et	4	main
tekitasid	doc_973441205376_item	2959312	et	4	main
mulle	doc_973441205376_item	2959313	et	4	main
mitte	doc_973441205376_item	2959314	et	3	main
ainult	doc_973441205376_item	2959315	et	4	main
ebameeldivad	doc_973441205376_item	2959316	et	3	main
kooliained	doc_973441205376_item	2959317	et	3	main
kuid	doc_973441205376_item	2959318	et	4	main
meenutan	doc_973441205376_item	2959325	et	3	main
koolilapsepõlvest	doc_973441205377_item	2959331	et	4	main
ma	doc_973441205377_item	2959332	et	3	main
ained	doc_973441205376_item	2959321	et	3	main
tihti	doc_973441205376_item	2959323	et	3	main
aastaid	doc_973441205376_item	2959327	et	4	main
mäletan	doc_973441205377_item	2959350	et	3	main
esimene	doc_973441205377_item	2959352	et	3	main
et	doc_973441205377_item	2959355	et	3	main
olin	doc_973441205377_item	2959358	et	3	main
lõpuks	doc_973441205377_item	2959391	et	4	main
ümberringi	doc_973441205377_item	2959402	et	3	main
võõrad	doc_973441205377_item	2959404	et	3	main
sest	doc_973441205377_item	2959416	et	4	main
põnevaid	doc_973441205377_item	2959421	et	3	main
ta	doc_973441205377_item	2959430	et	4	main
alati	doc_973441205377_item	2959443	et	4	main
peamiselt	doc_973441205377_item	2959453	et	4	main
olid	doc_973441205377_item	2959458	et	4	main
ajalugu	doc_973441205377_item	2959477	et	4	main
klass	doc_973441205377_item	2959479	et	3	main
ekskursioon	doc_973441205377_item	2959522	et	3	main
koolilapsepõlvest	doc_973441205377_item	2959529	et	4	main
südamesse	doc_973441205377_item	2959533	et	4	main
praegu	doc_973441205377_item	2959534	et	3	main
mõnikord	doc_973441205377_item	2959535	et	3	main
tuleb	doc_973441205377_item	2959536	et	3	main
essee	doc_973441205378_item	2959543	et	4	main
ja	doc_973441205378_item	2959545	et	3	main
narva	doc_973441205378_item	2959556	et	4	main
gümnaasiumis	doc_973441205378_item	2959558	et	3	main
peterburis	doc_973441205378_item	2959563	et	4	main
midagi	doc_973441205378_item	2959572	et	4	main
eriti	doc_973441205378_item	2959573	et	3	main
kuid	doc_973441205378_item	2959576	et	4	main
õpilasi	doc_973441205378_item	2959592	et	3	main
ja	doc_973441205378_item	2959629	et	3	main
humanitaarained	doc_973441205378_item	2959630	et	3	main
mis	doc_973441205378_item	2959631	et	4	main
väga	doc_973441205378_item	2959632	et	3	main
aitas	doc_973441205378_item	2959633	et	3	main
mind	doc_973441205378_item	2959634	et	4	main
järgmises	doc_973441205378_item	2959635	et	3	main
mäletan	doc_973441205378_item	2959639	et	3	main
alati	doc_973441205378_item	2959642	et	4	main
läbi	doc_973441205378_item	2959644	et	4	main
huvitavaid	doc_973441205378_item	2959645	et	4	main
ettevõtlusi	doc_973441205378_item	2959646	et	3	main
nad	doc_973441205378_item	2959647	et	3	main
oli	doc_973441205378_item	2959648	et	3	main
neid	doc_973441205378_item	2959654	et	4	main
õpisin	doc_973441205378_item	2959660	et	4	main
meeldinud	doc_973441205378_item	2959667	et	4	main
senikaua	doc_973441205378_item	2959676	et	3	main
hakkanud	doc_973441205378_item	2959680	et	4	main
õpima	doc_973441205378_item	2959681	et	4	main
kollidžis	doc_973441205378_item	2959682	et	2	main
esimesel	doc_973441205378_item	2959683	et	3	main
kursusel	doc_973441205378_item	2959684	et	3	main
kõik	doc_973441205378_item	2959691	et	4	main
sööklas	doc_973441205378_item	2959721	et	3	main
kollidžihoone	doc_973441205378_item	2959726	et	2	main
väga	doc_973441205378_item	2959729	et	3	main
nõrk	doc_973441205378_item	2959730	et	3	main
inglise	doc_973441205378_item	2959731	et	4	main
õppimine	doc_973441205378_item	2959736	et	4	main
meeldis	doc_973441205378_item	2959737	et	3	main
ma	doc_973441205378_item	2959738	et	3	main
isegi	doc_973441205378_item	2959739	et	4	main
sain	doc_973441205378_item	2959740	et	3	main
õpetajad	doc_973441205378_item	2959756	et	4	main
mulje	doc_973441205378_item	2959766	et	4	main
et	doc_973441205378_item	2959767	et	3	main
õpetajatest	doc_973441205378_item	2959768	et	4	main
lihtsalt	doc_973441205378_item	2959771	et	4	main
vihkab	doc_973441205378_item	2959772	et	3	main
lapsi	doc_973441205378_item	2959773	et	4	main
kõikedele	doc_973441205378_item	2959774	et	3	main
meile	doc_973441205378_item	2959775	et	4	main
meelepahadele	doc_973441205378_item	2959778	et	3	main
nad	doc_973441205378_item	2959779	et	3	main
oli	doc_973441205378_item	2959786	et	3	main
lihtsalt	doc_973441205378_item	2959791	et	4	main
meie	doc_973441205378_item	2959793	et	4	main
õpisin	doc_973441205377_item	2959333	et	4	main
narva	doc_973441205377_item	2959334	et	4	main
kuid	doc_973441205377_item	2959377	et	4	main
kui	doc_973441205377_item	2959378	et	3	main
ei	doc_973441205377_item	2959386	et	4	main
tulin	doc_973441205377_item	2959393	et	3	main
ja	doc_973441205377_item	2959394	et	3	main
ja	doc_973441205377_item	2959406	et	3	main
kõik	doc_973441205377_item	2959409	et	4	main
tuju	doc_973441205377_item	2959413	et	4	main
seal	doc_973441205377_item	2959417	et	4	main
oli	doc_973441205377_item	2959418	et	3	main
palju	doc_973441205377_item	2959419	et	4	main
igasuguseid	doc_973441205377_item	2959420	et	3	main
väiksem	doc_973441205377_item	2959400	et	4	main
olid	doc_973441205377_item	2959403	et	4	main
harjumatu	doc_973441205377_item	2959410	et	4	main
siiski	doc_973441205377_item	2959411	et	4	main
hiljem	doc_973441205377_item	2959412	et	3	main
asju	doc_973441205377_item	2959422	et	3	main
õpetajaga	doc_973441205377_item	2959429	et	4	main
hea	doc_973441205377_item	2959441	et	4	main
aitas	doc_973441205377_item	2959442	et	3	main
juures	doc_973441205377_item	2959451	et	4	main
üldse	doc_973441205377_item	2959452	et	3	main
ja	doc_973441205377_item	2959461	et	3	main
hoolivad	doc_973441205377_item	2959462	et	4	main
mingi	doc_973441205377_item	2959464	et	4	main
lemmik	doc_973441205377_item	2959472	et	3	main
loodusõpetus	doc_973441205377_item	2959475	et	3	main
oli	doc_973441205377_item	2959480	et	3	main
tore	doc_973441205377_item	2959482	et	3	main
väga	doc_973441205377_item	2959485	et	3	main
jääb	doc_973441205377_item	2959521	et	3	main
moskvasse	doc_973441205377_item	2959523	et	4	main
klassis	doc_973441205377_item	2959527	et	3	main
kooli	doc_973441205377_item	2959541	et	4	main
ebameeldivad	doc_973441205378_item	2959544	et	3	main
seda	doc_973441205378_item	2959560	et	3	main
ei	doc_973441205378_item	2959570	et	4	main
või	doc_973441205378_item	2959571	et	4	main
üttelda	doc_973441205378_item	2959575	et	4	main
midagi	doc_973441205378_item	2959578	et	4	main
head	doc_973441205378_item	2959579	et	4	main
haavasid	doc_973441205378_item	2959591	et	4	main
tahtnud	doc_973441205378_item	2959594	et	4	main
õpilaste	doc_973441205378_item	2959596	et	4	main
seisukohti	doc_973441205378_item	2959597	et	4	main
ja	doc_973441205378_item	2959598	et	3	main
hea	doc_973441205378_item	2959627	et	4	main
koolis	doc_973441205378_item	2959641	et	4	main
kannatamatusega	doc_973441205378_item	2959656	et	4	main
muidugi	doc_973441205378_item	2959657	et	4	main
kui	doc_973441205378_item	2959658	et	3	main
ma	doc_973441205378_item	2959659	et	3	main
mina	doc_973441205378_item	2959672	et	4	main
allahindasin	doc_973441205378_item	2959673	et	4	main
aga	doc_973441205378_item	2959674	et	3	main
ainult	doc_973441205378_item	2959675	et	4	main
kui	doc_973441205378_item	2959677	et	3	main
ei	doc_973441205378_item	2959679	et	4	main
õpetamine	doc_973441205378_item	2959733	et	4	main
eeskujuliks	doc_973441205378_item	2959741	et	4	main
õpilaseks	doc_973441205378_item	2959742	et	3	main
viidi	doc_973441205378_item	2959749	et	4	main
kursusele	doc_973441205378_item	2959752	et	3	main
tundus	doc_973441205378_item	2959761	et	3	main
palvetele	doc_973441205378_item	2959776	et	3	main
ja	doc_973441205378_item	2959777	et	3	main
teie	doc_973441205378_item	2959783	et	4	main
küsimuseid	doc_973441205378_item	2959802	et	4	main
administratsiooni	doc_973441205378_item	2959805	et	4	main
tegevused	doc_973441205378_item	2959806	et	4	main
viidsid	doc_973441205378_item	2959808	et	4	main
üheks	doc_973441205377_item	2959423	et	3	main
mälestuseks	doc_973441205377_item	2959425	et	4	main
pikk	doc_973441205377_item	2959432	et	4	main
kõik	doc_973441205377_item	2959454	et	4	main
õpetajad	doc_973441205377_item	2959455	et	4	main
minu	doc_973441205377_item	2959456	et	3	main
armsad	doc_973441205377_item	2959460	et	3	main
probleem	doc_973441205377_item	2959465	et	3	main
minu	doc_973441205377_item	2959471	et	3	main
tunnid	doc_973441205377_item	2959473	et	3	main
ja	doc_973441205377_item	2959484	et	3	main
keegi	doc_973441205377_item	2959487	et	4	main
ei	doc_973441205377_item	2959488	et	4	main
tülitse	doc_973441205377_item	2959489	et	4	main
koolikaaslaste	doc_973441205377_item	2959490	et	4	main
hulgast	doc_973441205377_item	2959491	et	4	main
on	doc_973441205377_item	2959492	et	4	main
mul	doc_973441205377_item	2959493	et	3	main
praegu	doc_973441205377_item	2959494	et	3	main
palju	doc_973441205377_item	2959495	et	4	main
sõpru	doc_973441205377_item	2959496	et	3	main
koolilapsepõlves	doc_973441205377_item	2959497	et	4	main
ma	doc_973441205377_item	2959498	et	3	main
tihti	doc_973441205377_item	2959499	et	3	main
osalesin	doc_973441205377_item	2959500	et	3	main
põnevades	doc_973441205377_item	2959502	et	4	main
igasugustes	doc_973441205377_item	2959501	et	3	main
kooliüritustes	doc_973441205377_item	2959503	et	3	main
mis	doc_973441205377_item	2959504	et	4	main
olid	doc_973441205377_item	2959505	et	4	main
peale	doc_973441205377_item	2959506	et	4	main
õppimise	doc_973441205377_item	2959507	et	4	main
kuid	doc_973441205377_item	2959508	et	4	main
rohkem	doc_973441205377_item	2959510	et	4	main
meeldis	doc_973441205377_item	2959511	et	3	main
kõige	doc_973441205377_item	2959509	et	4	main
mulle	doc_973441205377_item	2959512	et	4	main
käia	doc_973441205377_item	2959513	et	4	main
matkal	doc_973441205377_item	2959514	et	3	main
või	doc_973441205377_item	2959515	et	4	main
pikkadel	doc_973441205377_item	2959516	et	4	main
ekskursioonidel	doc_973441205377_item	2959517	et	3	main
eriliselt	doc_973441205377_item	2959518	et	4	main
on	doc_973441205377_item	2959519	et	4	main
meelde	doc_973441205377_item	2959520	et	3	main
mis	doc_973441205377_item	2959524	et	4	main
mälestused	doc_973441205377_item	2959528	et	4	main
jäävad	doc_973441205377_item	2959530	et	4	main
kauaks	doc_973441205377_item	2959531	et	3	main
rääkida	doc_973441205377_item	2959470	et	3	main
naljakas	doc_973441205377_item	2959483	et	4	main
sõbralik	doc_973441205377_item	2959486	et	3	main
viiendal	doc_973441205377_item	2959526	et	3	main
klassi	doc_973441205377_item	2959539	et	4	main
ja	doc_973441205377_item	2959540	et	3	main
10	doc_973441205378_item	2959554	et	2	main
pärast	doc_973441205378_item	2959559	et	4	main
ei	doc_973441205378_item	2959580	et	4	main
õpetajad	doc_973441205378_item	2959589	et	4	main
ei	doc_973441205378_item	2959593	et	4	main
oma	doc_973441205378_item	2959600	et	4	main
käiseme	doc_973441205377_item	2959525	et	4	main
igatsus	doc_973441205377_item	2959537	et	4	main
oma	doc_973441205377_item	2959538	et	4	main
koolipõlvest	doc_973441205378_item	2959548	et	4	main
3	doc_973441205378_item	2959549	et	2	main
aastat	doc_973441205378_item	2959550	et	3	main
tagasi	doc_973441205378_item	2959551	et	3	main
ma	doc_973441205378_item	2959552	et	3	main
lõpetasin	doc_973441205378_item	2959553	et	3	main
hummanitaar	doc_973441205378_item	2959557	et	4	main
ma	doc_973441205378_item	2959561	et	3	main
koolist	doc_973441205378_item	2959568	et	4	main
ma	doc_973441205378_item	2959569	et	3	main
halba	doc_973441205378_item	2959574	et	4	main
ka	doc_973441205378_item	2959577	et	3	main
koolis	doc_973441205378_item	2959584	et	4	main
meil	doc_973441205378_item	2959585	et	4	main
ka	doc_973441205378_item	2959586	et	3	main
olid	doc_973441205378_item	2959587	et	4	main
niisugused	doc_973441205378_item	2959588	et	3	main
kasutasid	doc_973441205378_item	2959599	et	4	main
võimu	doc_973441205378_item	2959601	et	4	main
aga	doc_973441205378_item	2959602	et	3	main
oli	doc_973441205378_item	2959603	et	3	main
ka	doc_973441205378_item	2959604	et	3	main
palju	doc_973441205378_item	2959605	et	4	main
häid	doc_973441205378_item	2959606	et	3	main
õpetajad	doc_973441205378_item	2959607	et	4	main
kes	doc_973441205378_item	2959608	et	4	main
armastasid	doc_973441205378_item	2959609	et	4	main
lapsi	doc_973441205378_item	2959610	et	4	main
oma	doc_973441205378_item	2959611	et	4	main
tööd	doc_973441205378_item	2959612	et	4	main
ja	doc_973441205378_item	2959613	et	3	main
põnevalt	doc_973441205378_item	2959614	et	4	main
jutustasid	doc_973441205378_item	2959615	et	4	main
oma	doc_973441205378_item	2959616	et	4	main
õppeainet	doc_973441205378_item	2959617	et	3	main
just	doc_973441205378_item	2959618	et	3	main
need	doc_973441205378_item	2959619	et	3	main
õpetajad	doc_973441205378_item	2959620	et	4	main
määllu	doc_973441205378_item	2959622	et	4	main
ma	doc_973441205378_item	2959638	et	3	main
hingestatult	doc_973441205378_item	2959650	et	4	main
me	doc_973441205378_item	2959652	et	4	main
ootsime	doc_973441205378_item	2959653	et	4	main
koolis	doc_973441205378_item	2959661	et	4	main
ma	doc_973441205378_item	2959678	et	3	main
mulle	doc_973441205378_item	2959685	et	4	main
väga	doc_973441205378_item	2959686	et	3	main
toitlus	doc_973441205378_item	2959723	et	4	main
ja	doc_973441205378_item	2959728	et	3	main
keele	doc_973441205378_item	2959732	et	4	main
uued	doc_973441205378_item	2959755	et	3	main
ja	doc_973441205378_item	2959757	et	3	main
uus	doc_973441205378_item	2959758	et	3	main
administratsioon	doc_973441205378_item	2959759	et	3	main
otsekohe	doc_973441205378_item	2959760	et	3	main
selline	doc_973441205378_item	2959765	et	4	main
need	doc_973441205378_item	2959781	et	3	main
mõnikord	doc_973441205378_item	2959785	et	3	main
tunne	doc_973441205378_item	2959788	et	4	main
minu	doc_973441205377_item	2959532	et	3	main
jarele	doc_973441205377_item	2959542	et	4	main
meeldivad	doc_973441205378_item	2959546	et	4	main
mäletused	doc_973441205378_item	2959547	et	4	main
klassi	doc_973441205378_item	2959555	et	4	main
koolisin	doc_973441205378_item	2959562	et	4	main
kus	doc_973441205378_item	2959564	et	3	main
ma	doc_973441205378_item	2959565	et	3	main
õpisin	doc_973441205378_item	2959566	et	4	main
kolidžis	doc_973441205378_item	2959567	et	2	main
olnud	doc_973441205378_item	2959581	et	4	main
nagu	doc_973441205378_item	2959582	et	3	main
igas	doc_973441205378_item	2959583	et	3	main
kes	doc_973441205378_item	2959590	et	4	main
kuulata	doc_973441205378_item	2959595	et	4	main
jäävad	doc_973441205378_item	2959621	et	4	main
pärast	doc_973441205378_item	2959623	et	4	main
kooli	doc_973441205378_item	2959624	et	4	main
ma	doc_973441205378_item	2959625	et	3	main
sain	doc_973441205378_item	2959626	et	3	main
koolituses	doc_973441205378_item	2959636	et	4	main
et	doc_973441205378_item	2959640	et	3	main
tehtud	doc_973441205378_item	2959649	et	4	main
alati	doc_973441205378_item	2959655	et	4	main
mulle	doc_973441205378_item	2959664	et	4	main
ei	doc_973441205378_item	2959666	et	4	main
ja	doc_973441205378_item	2959668	et	3	main
kõik	doc_973441205378_item	2959669	et	4	main
need	doc_973441205378_item	2959670	et	3	main
meeldisid	doc_973441205378_item	2959687	et	4	main
õpetajate	doc_973441205378_item	2959688	et	4	main
suhtumine	doc_973441205378_item	2959689	et	4	main
nad	doc_973441205378_item	2959690	et	3	main
kohustuslik	doc_973441205378_item	2959725	et	3	main
kuid	doc_973441205378_item	2959734	et	4	main
siiski	doc_973441205378_item	2959743	et	4	main
üle	doc_973441205378_item	2959750	et	3	main
seal	doc_973441205378_item	2959753	et	4	main
olid	doc_973441205378_item	2959754	et	4	main
õhkkond	doc_973441205378_item	2959763	et	3	main
suurem	doc_973441205378_item	2959769	et	4	main
on	doc_973441205378_item	2959782	et	4	main
niisugune	doc_973441205378_item	2959787	et	3	main
et	doc_973441205378_item	2959789	et	3	main
ja	doc_973441205378_item	2959803	et	3	main
alatiseks	doc_973441205378_item	2959810	et	4	main
kollidžihoones	doc_973441205378_item	2959821	et	2	main
me	doc_973441205378_item	2959824	et	4	main
et	doc_973441205378_item	2959826	et	3	main
kõik	doc_973441205378_item	2959836	et	4	main
loogika	doc_973441205378_item	2959847	et	4	main
sain	doc_973441205378_item	2959854	et	3	main
hariduse	doc_973441205378_item	2959856	et	3	main
tean	doc_973441205378_item	2959859	et	3	main
tee	doc_973441205378_item	2959867	et	4	main
selle	doc_973441205378_item	2959873	et	4	main
selgeks	doc_973441205378_item	2959875	et	3	main
kollidžis	doc_973441205378_item	2959878	et	2	main
aasta	doc_973441205378_item	2959882	et	4	main
pärast	doc_973441205378_item	2959883	et	4	main
jäävad	doc_973441205378_item	2959894	et	4	main
referaat	doc_973441205379_item	2959903	et	3	main
praegu	doc_973441205379_item	2959907	et	3	main
nii	doc_973441205379_item	2959918	et	3	main
kelleoskuse	doc_973441205378_item	2959628	et	4	main
veel	doc_973441205378_item	2959637	et	4	main
viidi	doc_973441205378_item	2959643	et	4	main
ja	doc_973441205378_item	2959651	et	3	main
siis	doc_973441205378_item	2959662	et	3	main
see	doc_973441205378_item	2959663	et	3	main
eriti	doc_973441205378_item	2959665	et	3	main
eelisid	doc_973441205378_item	2959671	et	4	main
olid	doc_973441205378_item	2959692	et	4	main
väga	doc_973441205378_item	2959693	et	3	main
head	doc_973441205378_item	2959694	et	4	main
inimesed	doc_973441205378_item	2959695	et	3	main
ja	doc_973441205378_item	2959696	et	3	main
nad	doc_973441205378_item	2959698	et	3	main
panid	doc_973441205378_item	2959699	et	4	main
õpetajad	doc_973441205378_item	2959697	et	4	main
meid	doc_973441205378_item	2959700	et	4	main
uskuma	doc_973441205378_item	2959701	et	3	main
et	doc_973441205378_item	2959702	et	3	main
me	doc_973441205378_item	2959703	et	4	main
oleme	doc_973441205378_item	2959704	et	3	main
tarkad	doc_973441205378_item	2959705	et	4	main
ainult	doc_973441205378_item	2959706	et	4	main
et	doc_973441205378_item	2959707	et	3	main
me	doc_973441205378_item	2959708	et	4	main
ei	doc_973441205378_item	2959709	et	4	main
teadnud	doc_973441205378_item	2959710	et	4	main
sellest	doc_973441205378_item	2959711	et	4	main
muidugi	doc_973441205378_item	2959712	et	4	main
on	doc_973441205378_item	2959713	et	4	main
olnud	doc_973441205378_item	2959714	et	4	main
ka	doc_973441205378_item	2959715	et	3	main
puuduseid	doc_973441205378_item	2959716	et	3	main
niisugused	doc_973441205378_item	2959717	et	3	main
nagu	doc_973441205378_item	2959718	et	3	main
vastik	doc_973441205378_item	2959719	et	3	main
söök	doc_973441205378_item	2959720	et	3	main
aga	doc_973441205378_item	2959722	et	3	main
oli	doc_973441205378_item	2959724	et	3	main
hädaseisus	doc_973441205378_item	2959727	et	4	main
mulle	doc_973441205378_item	2959735	et	4	main
tõeline	doc_973441205378_item	2959744	et	4	main
hirm	doc_973441205378_item	2959745	et	3	main
algas	doc_973441205378_item	2959746	et	3	main
kui	doc_973441205378_item	2959747	et	3	main
meid	doc_973441205378_item	2959748	et	4	main
teisele	doc_973441205378_item	2959751	et	4	main
teissugune	doc_973441205378_item	2959762	et	3	main
jäi	doc_973441205378_item	2959764	et	3	main
osa	doc_973441205378_item	2959770	et	4	main
vastasid	doc_973441205378_item	2959780	et	4	main
väljakutsed	doc_973441205378_item	2959784	et	3	main
organisatsiooniliseid	doc_973441205378_item	2959801	et	4	main
on	doc_973441205378_item	2959811	et	4	main
meelde	doc_973441205378_item	2959813	et	3	main
jäänud	doc_973441205378_item	2959814	et	4	main
kuidas	doc_973441205378_item	2959815	et	3	main
me	doc_973441205378_item	2959816	et	4	main
32	doc_973441205378_item	2959818	et	2	main
külmas	doc_973441205378_item	2959819	et	4	main
aga	doc_973441205378_item	2959820	et	3	main
lori	doc_973441205378_item	2959837	et	4	main
ilma	doc_973441205378_item	2959851	et	4	main
väga	doc_973441205378_item	2959860	et	3	main
uut	doc_973441205378_item	2959862	et	3	main
mulle	doc_973441205378_item	2959865	et	4	main
ma	doc_973441205378_item	2959871	et	3	main
ununevad	doc_973441205378_item	2959884	et	4	main
koolist	doc_973441205378_item	2959892	et	4	main
positiivsed	doc_973441205378_item	2959896	et	3	main
muljed	doc_973441205378_item	2959897	et	3	main
ja	doc_973441205378_item	2959898	et	3	main
tänulikus	doc_973441205378_item	2959899	et	4	main
tõsine	doc_973441205379_item	2959913	et	4	main
probleem	doc_973441205379_item	2959914	et	3	main
rikkades	doc_973441205379_item	2959919	et	4	main
ta	doc_973441205379_item	2959924	et	4	main
elab	doc_973441205379_item	2959925	et	3	main
ka	doc_973441205379_item	2959926	et	3	main
eestis	doc_973441205379_item	2959927	et	3	main
ehkki	doc_973441205379_item	2959928	et	3	main
tööpuuduse	doc_973441205379_item	2959931	et	3	main
62	doc_973441205379_item	2959952	et	2	main
on	doc_973441205379_item	2959969	et	4	main
teisede	doc_973441205379_item	2959974	et	4	main
mina	doc_973441205379_item	2959976	et	4	main
arvan	doc_973441205379_item	2959977	et	3	main
ei	doc_973441205379_item	2959991	et	4	main
keskmise	doc_973441205379_item	2959994	et	3	main
eidata	doc_973441205379_item	2960002	et	4	main
et	doc_973441205379_item	2960003	et	3	main
olukord	doc_973441205379_item	2960004	et	3	main
ida	doc_973441205379_item	2960005	et	4	main
79	doc_973441205379_item	2960016	et	2	main
ni	doc_973441205379_item	2960017	et	4	main
alates	doc_973441205379_item	2960022	et	3	main
positiivsed	doc_973441205379_item	2960025	et	3	main
muutused	doc_973441205379_item	2960026	et	4	main
iseloomustasid	doc_973441205379_item	2960027	et	3	main
töötus	doc_973441205379_item	2960033	et	4	main
aastal	doc_973441205379_item	2960038	et	3	main
aastatel	doc_973441205379_item	2960041	et	4	main
vähenenud	doc_973441205379_item	2960043	et	4	main
viimaste	doc_973441205379_item	2960044	et	3	main
aastate	doc_973441205379_item	2960045	et	3	main
suurima	doc_973441205379_item	2960046	et	4	main
tööpuudusega	doc_973441205379_item	2960047	et	3	main
162	doc_973441205379_item	2960055	et	2	main
ni	doc_973441205379_item	2960056	et	4	main
samas	doc_973441205379_item	2960066	et	4	main
inimeste	doc_973441205379_item	2960097	et	3	main
inimesed	doc_973441205379_item	2960118	et	3	main
nad	doc_973441205378_item	2959790	et	3	main
irvitasid	doc_973441205378_item	2959792	et	4	main
mõned	doc_973441205378_item	2959804	et	3	main
lihtsalt	doc_973441205378_item	2959807	et	4	main
meeleheitele	doc_973441205378_item	2959809	et	3	main
õppesime	doc_973441205378_item	2959817	et	4	main
meile	doc_973441205378_item	2959827	et	4	main
aga	doc_973441205378_item	2959830	et	3	main
selle	doc_973441205378_item	2959838	et	4	main
pärast	doc_973441205378_item	2959839	et	4	main
et	doc_973441205378_item	2959840	et	3	main
temal	doc_973441205378_item	2959841	et	3	main
halvata	doc_973441205378_item	2959852	et	4	main
ma	doc_973441205378_item	2959853	et	3	main
ei	doc_973441205378_item	2959866	et	4	main
olla	doc_973441205378_item	2959880	et	3	main
mõne	doc_973441205378_item	2959881	et	3	main
tööpuudus	doc_973441205379_item	2959908	et	3	main
probleem	doc_973441205379_item	2959916	et	3	main
kui	doc_973441205379_item	2959920	et	3	main
eestis	doc_973441205379_item	2959933	et	3	main
mitu	doc_973441205379_item	2959934	et	4	main
tööpuuduse	doc_973441205379_item	2959939	et	3	main
rohkem	doc_973441205379_item	2959960	et	4	main
või	doc_973441205379_item	2959973	et	4	main
faktoridega	doc_973441205379_item	2959975	et	4	main
et	doc_973441205379_item	2959978	et	3	main
tohi	doc_973441205379_item	2959980	et	4	main
astumise	doc_973441205379_item	2959984	et	4	main
head	doc_973441205379_item	2959985	et	4	main
palgaga	doc_973441205379_item	2959995	et	3	main
eestis	doc_973441205379_item	2959996	et	3	main
tohi	doc_973441205379_item	2960001	et	4	main
on	doc_973441205379_item	2960019	et	4	main
1995	doc_973441205379_item	2960020	et	2	main
üle	doc_973441205378_item	2959794	et	3	main
sööklas	doc_973441205378_item	2959795	et	3	main
söödeti	doc_973441205378_item	2959796	et	3	main
nii	doc_973441205378_item	2959797	et	3	main
samuti	doc_973441205378_item	2959798	et	3	main
halvasti	doc_973441205378_item	2959799	et	3	main
aga	doc_973441205378_item	2959800	et	3	main
mulle	doc_973441205378_item	2959812	et	4	main
oli	doc_973441205378_item	2959822	et	3	main
palusime	doc_973441205378_item	2959825	et	3	main
õppetöö	doc_973441205378_item	2959829	et	4	main
õppealajuhataja	doc_973441205378_item	2959831	et	4	main
vastasid	doc_973441205378_item	2959832	et	4	main
et	doc_973441205378_item	2959833	et	3	main
see	doc_973441205378_item	2959834	et	3	main
on	doc_973441205378_item	2959835	et	4	main
temperatuur	doc_973441205378_item	2959843	et	3	main
8	doc_973441205378_item	2959845	et	2	main
palju	doc_973441205378_item	2959861	et	4	main
mainori	doc_973441205378_item	2959863	et	4	main
kõrgkoolis	doc_973441205378_item	2959864	et	4	main
raskusi	doc_973441205378_item	2959869	et	4	main
kuna	doc_973441205378_item	2959870	et	3	main
olen	doc_973441205378_item	2959872	et	3	main
mul	doc_973441205378_item	2959885	et	3	main
kõik	doc_973441205378_item	2959886	et	4	main
ja	doc_973441205378_item	2959893	et	3	main
ainult	doc_973441205378_item	2959895	et	4	main
saadud	doc_973441205378_item	2959900	et	4	main
eest	doc_973441205378_item	2959902	et	4	main
ühiskonnas	doc_973441205379_item	2959915	et	4	main
elab	doc_973441205379_item	2959917	et	3	main
ka	doc_973441205379_item	2959921	et	3	main
protsenti	doc_973441205379_item	2959932	et	4	main
tagasi	doc_973441205379_item	2959936	et	3	main
praegu	doc_973441205379_item	2959938	et	3	main
protsent	doc_973441205379_item	2959940	et	3	main
esimeks	doc_973441205379_item	2959944	et	4	main
kvartalis	doc_973441205379_item	2959945	et	3	main
64	doc_973441205379_item	2959949	et	2	main
inimesi	doc_973441205379_item	2959961	et	4	main
kui	doc_973441205379_item	2959962	et	3	main
aasta	doc_973441205379_item	2959963	et	4	main
tagasi	doc_973441205379_item	2959964	et	3	main
epl	doc_973441205379_item	2959965	et	4	main
24082006	doc_973441205379_item	2959966	et	2	main
kas	doc_973441205379_item	2959967	et	3	main
eidata	doc_973441205379_item	2959981	et	4	main
euroopa	doc_973441205379_item	2959982	et	4	main
liigisse	doc_973441205379_item	2959983	et	3	main
varem	doc_973441205379_item	2959990	et	4	main
muutunud	doc_973441205379_item	2960009	et	4	main
virumaa	doc_973441205379_item	2960029	et	4	main
tööturgu	doc_973441205379_item	2960030	et	4	main
ida	doc_973441205379_item	2960049	et	4	main
virumaal	doc_973441205379_item	2960050	et	4	main
vähenes	doc_973441205379_item	2960051	et	3	main
töötuse	doc_973441205379_item	2960052	et	4	main
määr	doc_973441205379_item	2960053	et	3	main
mullu	doc_973441205379_item	2960054	et	3	main
on	doc_973441205379_item	2960058	et	4	main
madalaim	doc_973441205379_item	2960064	et	4	main
näitaja	doc_973441205379_item	2960065	et	4	main
töötavad	doc_973441205379_item	2960102	et	4	main
teadmised	doc_973441205379_item	2960110	et	4	main
töötada	doc_973441205379_item	2960114	et	3	main
teises	doc_973441205379_item	2960115	et	4	main
2	doc_973441205379_item	2960117	et	2	main
tööd	doc_973441205379_item	2960127	et	4	main
kirjutamine	doc_973441205379_item	2960135	et	4	main
artiklite	doc_973441205379_item	2960136	et	3	main
inimesed	doc_973441205379_item	2960138	et	3	main
kes	doc_973441205379_item	2960139	et	4	main
käel	doc_973441205379_item	2960143	et	3	main
ole	doc_973441205379_item	2960149	et	4	main
abi	doc_973441205379_item	2960155	et	4	main
tööhõivetalituste	doc_973441205379_item	2960156	et	4	main
kaudu	doc_973441205379_item	2960160	et	3	main
kes	doc_973441205379_item	2960162	et	4	main
saavad	doc_973441205379_item	2960163	et	4	main
töötu	doc_973441205379_item	2960164	et	4	main
13	doc_973441205378_item	2959823	et	2	main
tühistatakse	doc_973441205378_item	2959828	et	3	main
kodus	doc_973441205378_item	2959842	et	4	main
on	doc_973441205378_item	2959844	et	4	main
imelik	doc_973441205378_item	2959846	et	3	main
kuid	doc_973441205378_item	2959848	et	4	main
pole	doc_973441205378_item	2959849	et	3	main
head	doc_973441205378_item	2959850	et	4	main
suurepärase	doc_973441205378_item	2959855	et	4	main
nüüd	doc_973441205378_item	2959857	et	4	main
ma	doc_973441205378_item	2959858	et	3	main
õppimine	doc_973441205378_item	2959868	et	4	main
juba	doc_973441205378_item	2959874	et	3	main
saanud	doc_973441205378_item	2959876	et	4	main
peterburi	doc_973441205378_item	2959877	et	4	main
võib	doc_973441205378_item	2959879	et	3	main
halvad	doc_973441205378_item	2959887	et	4	main
määlestused	doc_973441205378_item	2959888	et	4	main
kollidžist	doc_973441205378_item	2959889	et	2	main
nagu	doc_973441205378_item	2959890	et	3	main
ka	doc_973441205378_item	2959891	et	3	main
teadmiste	doc_973441205378_item	2959901	et	4	main
tänapäevane	doc_973441205379_item	2959904	et	4	main
tööpuudus	doc_973441205379_item	2959905	et	3	main
eestis	doc_973441205379_item	2959906	et	3	main
on	doc_973441205379_item	2959909	et	4	main
väga	doc_973441205379_item	2959910	et	3	main
oluline	doc_973441205379_item	2959911	et	4	main
ja	doc_973441205379_item	2959912	et	3	main
riigides	doc_973441205379_item	2959923	et	4	main
väheneb	doc_973441205379_item	2959942	et	3	main
tsitaat	doc_973441205379_item	2959943	et	3	main
oli	doc_973441205379_item	2959946	et	3	main
eestis	doc_973441205379_item	2959947	et	3	main
tööpuudus	doc_973441205379_item	2959948	et	3	main
teiseks	doc_973441205379_item	2959951	et	4	main
protsenti	doc_973441205379_item	2959953	et	4	main
ehituses	doc_973441205379_item	2959955	et	4	main
protsenti	doc_973441205379_item	2959959	et	4	main
see	doc_973441205379_item	2959968	et	3	main
majandusliku	doc_973441205379_item	2959971	et	3	main
tõusega	doc_973441205379_item	2959972	et	4	main
mõjustust	doc_973441205379_item	2959986	et	4	main
ära	doc_973441205379_item	2959998	et	4	main
euroopasse	doc_973441205379_item	2959999	et	3	main
ei	doc_973441205379_item	2960000	et	4	main
virumaal	doc_973441205379_item	2960006	et	4	main
on	doc_973441205379_item	2960007	et	4	main
ka	doc_973441205379_item	2960008	et	3	main
tsitaat	doc_973441205379_item	2960010	et	3	main
tööpuuduse	doc_973441205379_item	2960011	et	3	main
määr	doc_973441205379_item	2960012	et	3	main
langes	doc_973441205379_item	2960013	et	4	main
eelmisel	doc_973441205379_item	2960014	et	3	main
aastal	doc_973441205379_item	2960015	et	3	main
ida	doc_973441205379_item	2960028	et	4	main
mis	doc_973441205379_item	2960034	et	4	main
oli	doc_973441205379_item	2960035	et	3	main
on	doc_973441205379_item	2960039	et	4	main
maakonnas	doc_973441205379_item	2960048	et	4	main
see	doc_973441205379_item	2960057	et	3	main
tõttu	doc_973441205379_item	2960099	et	4	main
näiteks	doc_973441205379_item	2960100	et	4	main
inimesed	doc_973441205379_item	2960101	et	3	main
anna	doc_973441205379_item	2960112	et	4	main
elukutses	doc_973441205379_item	2960116	et	4	main
kes	doc_973441205379_item	2960119	et	4	main
tahavad	doc_973441205379_item	2960120	et	3	main
töötada	doc_973441205379_item	2960122	et	3	main
saa	doc_973441205379_item	2960124	et	4	main
leia	doc_973441205379_item	2960125	et	4	main
portreede	doc_973441205379_item	2960131	et	4	main
tulemus	doc_973441205379_item	2960137	et	3	main
omal	doc_973441205379_item	2960142	et	3	main
ei	doc_973441205379_item	2960148	et	4	main
alalist	doc_973441205379_item	2960150	et	4	main
4	doc_973441205379_item	2960152	et	2	main
teised	doc_973441205379_item	2960153	et	4	main
kaudu	doc_973441205379_item	2960157	et	3	main
tööturameti	doc_973441205379_item	2960159	et	4	main
inimesed	doc_973441205379_item	2960161	et	3	main
5	doc_973441205379_item	2960166	et	2	main
teenindus	doc_973441205379_item	2960174	et	4	main
nii	doc_973441205379_item	2960177	et	3	main
vaesedes	doc_973441205379_item	2959922	et	3	main
kui	doc_973441205379_item	2959929	et	3	main
võrdlema	doc_973441205379_item	2959930	et	3	main
aastat	doc_973441205379_item	2959935	et	3	main
siis	doc_973441205379_item	2959937	et	3	main
tugevasti	doc_973441205379_item	2959941	et	3	main
protsenti	doc_973441205379_item	2959950	et	4	main
näiteks	doc_973441205379_item	2959954	et	4	main
töötab	doc_973441205379_item	2959956	et	3	main
praegu	doc_973441205379_item	2959957	et	3	main
36	doc_973441205379_item	2959958	et	2	main
seotud	doc_973441205379_item	2959970	et	4	main
ei	doc_973441205379_item	2959979	et	4	main
paljud	doc_973441205379_item	2959987	et	3	main
inimesed	doc_973441205379_item	2959988	et	3	main
kes	doc_973441205379_item	2959989	et	4	main
olnud	doc_973441205379_item	2959992	et	4	main
rahuldanud	doc_973441205379_item	2959993	et	4	main
sõitsid	doc_973441205379_item	2959997	et	4	main
mis	doc_973441205379_item	2960018	et	4	main
aastast	doc_973441205379_item	2960021	et	4	main
madalaim	doc_973441205379_item	2960023	et	4	main
eriti	doc_973441205379_item	2960024	et	3	main
teates	doc_973441205379_item	2960031	et	3	main
statistikaamet	doc_973441205379_item	2960032	et	4	main
2000	doc_973441205379_item	2960037	et	2	main
pidevalt	doc_973441205379_item	2960042	et	4	main
virumaa	doc_973441205379_item	2960060	et	4	main
seitsme	doc_973441205379_item	2960062	et	3	main
on	doc_973441205379_item	2960067	et	4	main
koondamise	doc_973441205379_item	2960098	et	4	main
ühes	doc_973441205379_item	2960105	et	4	main
erialas	doc_973441205379_item	2960106	et	3	main
nende	doc_973441205379_item	2960107	et	4	main
kogemus	doc_973441205379_item	2960108	et	3	main
ja	doc_973441205379_item	2960109	et	3	main
võimalust	doc_973441205379_item	2960113	et	3	main
sobivat	doc_973441205379_item	2960126	et	4	main
maalimine	doc_973441205379_item	2960132	et	4	main
otsivad	doc_973441205379_item	2960140	et	4	main
või	doc_973441205379_item	2960144	et	4	main
kaudu	doc_973441205379_item	2960146	et	3	main
palka	doc_973441205379_item	2960151	et	4	main
tõsine	doc_973441205379_item	2960189	et	4	main
et	doc_973441205379_item	2960192	et	3	main
majanduslikust	doc_973441205379_item	2960198	et	4	main
kõrgeim	doc_973441205379_item	2960036	et	4	main
järgnevatel	doc_973441205379_item	2960040	et	4	main
ida	doc_973441205379_item	2960059	et	4	main
viimase	doc_973441205379_item	2960061	et	3	main
aasta	doc_973441205379_item	2960063	et	4	main
ida	doc_973441205379_item	2960068	et	4	main
virumaa	doc_973441205379_item	2960069	et	4	main
endiselt	doc_973441205379_item	2960070	et	4	main
üks	doc_973441205379_item	2960071	et	3	main
suurima	doc_973441205379_item	2960072	et	4	main
tööpuudusega	doc_973441205379_item	2960073	et	3	main
maakondi	doc_973441205379_item	2960074	et	4	main
epl	doc_973441205379_item	2960075	et	4	main
20032006	doc_973441205379_item	2960076	et	2	main
aga	doc_973441205379_item	2960077	et	3	main
siiski	doc_973441205379_item	2960079	et	4	main
elab	doc_973441205379_item	2960080	et	3	main
nii	doc_973441205379_item	2960081	et	3	main
tööpuudus	doc_973441205379_item	2960078	et	3	main
maailmas	doc_973441205379_item	2960082	et	3	main
kui	doc_973441205379_item	2960083	et	3	main
ka	doc_973441205379_item	2960084	et	3	main
eestis	doc_973441205379_item	2960085	et	3	main
mis	doc_973441205379_item	2960086	et	4	main
mõjutab	doc_973441205379_item	2960087	et	3	main
sellele	doc_973441205379_item	2960088	et	4	main
mulle	doc_973441205379_item	2960089	et	4	main
tundub	doc_973441205379_item	2960090	et	3	main
et	doc_973441205379_item	2960091	et	3	main
on	doc_973441205379_item	2960092	et	4	main
põhjused	doc_973441205379_item	2960093	et	3	main
ja	doc_973441205379_item	2960094	et	3	main
kriteeriumid	doc_973441205379_item	2960095	et	3	main
1	doc_973441205379_item	2960096	et	2	main
palju	doc_973441205379_item	2960103	et	4	main
aastaid	doc_973441205379_item	2960104	et	4	main
ei	doc_973441205379_item	2960111	et	4	main
tegelikult	doc_973441205379_item	2960121	et	4	main
ei	doc_973441205379_item	2960123	et	4	main
3	doc_973441205379_item	2960128	et	2	main
ajutine	doc_973441205379_item	2960129	et	4	main
töö	doc_973441205379_item	2960130	et	4	main
ladumine	doc_973441205379_item	2960134	et	4	main
tööd	doc_973441205379_item	2960141	et	4	main
neil	doc_973441205379_item	2960147	et	4	main
ootavad	doc_973441205379_item	2960154	et	4	main
või	doc_973441205379_item	2960158	et	4	main
abiraha	doc_973441205379_item	2960165	et	4	main
ehitus	doc_973441205379_item	2960168	et	4	main
suvel	doc_973441205379_item	2960169	et	3	main
rohkem	doc_973441205379_item	2960170	et	4	main
kui	doc_973441205379_item	2960171	et	3	main
talvel	doc_973441205379_item	2960172	et	4	main
kaubandus	doc_973441205379_item	2960173	et	3	main
kokkuvõte	doc_973441205379_item	2960179	et	3	main
sotsiaalne	doc_973441205379_item	2960182	et	3	main
on	doc_973441205379_item	2960187	et	4	main
eesti	doc_973441205379_item	2960197	et	4	main
essee	doc_974724932290_item	2960200	et	4	main
eestlaste	doc_974724932290_item	2960202	et	4	main
kohapärimus	doc_974724932290_item	2960203	et	3	main
tänapäeval	doc_974724932290_item	2960204	et	3	main
alles	doc_974724932290_item	2960221	et	3	main
kolmkümmend	doc_974724932290_item	2960223	et	4	main
aastal	doc_974724932290_item	2960225	et	3	main
siberis	doc_974724932290_item	2960226	et	4	main
elanud	doc_974724932290_item	2960227	et	4	main
poole	doc_974724932290_item	2960235	et	4	main
võrra	doc_974724932290_item	2960236	et	3	main
kuidas	doc_974724932290_item	2960242	et	3	main
muutub	doc_974724932290_item	2960243	et	3	main
inimeste	doc_974724932290_item	2960244	et	3	main
rände	doc_974724932290_item	2960245	et	4	main
mis	doc_974724932290_item	2960250	et	4	main
algse	doc_974724932290_item	2960271	et	3	main
kohapärimuse	doc_974724932290_item	2960273	et	3	main
seostuv	doc_974724932290_item	2960276	et	4	main
pärimuse	doc_974724932290_item	2960293	et	4	main
muu	doc_974724932290_item	2960312	et	4	main
seesugune	doc_974724932290_item	2960313	et	3	main
talletatud	doc_974724932290_item	2960314	et	4	main
1	doc_974724932290_item	2960321	et	2	main
pärimus	doc_974724932290_item	2960329	et	4	main
2	doc_974724932290_item	2960330	et	2	main
väljarändamist	doc_974724932290_item	2960346	et	3	main
paari	doc_974724932290_item	2960360	et	4	main
eesti	doc_974724932290_item	2960363	et	4	main
eesti	doc_974724932290_item	2960368	et	4	main
oludest	doc_974724932290_item	2960369	et	3	main
käinudki	doc_974724932290_item	2960386	et	4	main
pole	doc_974724932290_item	2960387	et	3	main
räägivad	doc_974724932290_item	2960395	et	3	main
laenatud	doc_974724932290_item	2960398	et	4	main
tekstid	doc_974724932290_item	2960406	et	3	main
mitte	doc_974724932290_item	2960410	et	3	main
eestlaste	doc_974724932290_item	2960420	et	4	main
müüri	doc_973441205379_item	2960133	et	4	main
tuttavate	doc_973441205379_item	2960145	et	3	main
hoojatöö	doc_973441205379_item	2960167	et	4	main
on	doc_973441205379_item	2960181	et	4	main
see	doc_973441205379_item	2960185	et	3	main
väga	doc_973441205379_item	2960188	et	3	main
tööpuuduse	doc_973441205379_item	2960193	et	3	main
siberi	doc_974724932290_item	2960201	et	4	main
19	doc_974724932290_item	2960205	et	2	main
sajandi	doc_974724932290_item	2960206	et	3	main
teisel	doc_974724932290_item	2960207	et	4	main
poolel	doc_974724932290_item	2960208	et	4	main
ja	doc_974724932290_item	2960209	et	3	main
20	doc_974724932290_item	2960210	et	2	main
alguses	doc_974724932290_item	2960211	et	4	main
tekkisid	doc_974724932290_item	2960212	et	4	main
venemaale	doc_974724932290_item	2960213	et	4	main
siberisse	doc_974724932290_item	2960215	et	4	main
sh	doc_974724932290_item	2960214	et	4	main
eesti	doc_974724932290_item	2960216	et	4	main
asundused	doc_974724932290_item	2960217	et	4	main
neist	doc_974724932290_item	2960218	et	4	main
on	doc_974724932290_item	2960219	et	4	main
tänapäevani	doc_974724932290_item	2960220	et	3	main
600	doc_974724932290_item	2960231	et	2	main
on	doc_974724932290_item	2960232	et	4	main
jaoks	doc_974724932290_item	2960238	et	4	main
on	doc_974724932290_item	2960239	et	4	main
huvipakkuv	doc_974724932290_item	2960240	et	3	main
küsimus	doc_974724932290_item	2960241	et	4	main
nad	doc_974724932290_item	2960268	et	3	main
jutuga	doc_974724932290_item	2960275	et	3	main
selle	doc_974724932290_item	2960283	et	4	main
tõttu	doc_974724932290_item	2960284	et	4	main
elupaika	doc_974724932290_item	2960290	et	4	main
looduslike	doc_974724932290_item	2960303	et	3	main
paikadega	doc_974724932290_item	2960304	et	3	main
kohalikelt	doc_974724932290_item	2960309	et	3	main
eestlaste	doc_974724932290_item	2960316	et	4	main
kohapärimuse	doc_974724932290_item	2960317	et	3	main
saab	doc_974724932290_item	2960318	et	3	main
jagada	doc_974724932290_item	2960319	et	3	main
kolmeks	doc_974724932290_item	2960320	et	4	main
põllumajandus	doc_973441205379_item	2960175	et	3	main
ja	doc_973441205379_item	2960176	et	3	main
edasi	doc_973441205379_item	2960178	et	3	main
ja	doc_973441205379_item	2960184	et	3	main
probleem	doc_973441205379_item	2960186	et	3	main
ma	doc_973441205379_item	2960190	et	3	main
arvan	doc_973441205379_item	2960191	et	3	main
vähenemine	doc_973441205379_item	2960194	et	4	main
tulevikus	doc_973441205379_item	2960195	et	4	main
sõltub	doc_973441205379_item	2960196	et	3	main
tõusest	doc_973441205379_item	2960199	et	3	main
1939	doc_974724932290_item	2960224	et	2	main
tänaseks	doc_974724932290_item	2960233	et	4	main
kahanenud	doc_974724932290_item	2960234	et	4	main
zhanrites	doc_974724932290_item	2960249	et	4	main
eeldavad	doc_974724932290_item	2960251	et	4	main
ning	doc_974724932290_item	2960253	et	3	main
keskkond	doc_974724932290_item	2960277	et	3	main
konkreetsed	doc_974724932290_item	2960278	et	3	main
looduslikud	doc_974724932290_item	2960279	et	3	main
paigad	doc_974724932290_item	2960280	et	3	main
sündmused	doc_974724932290_item	2960281	et	3	main
isikud	doc_974724932290_item	2960282	et	3	main
omanäoline	doc_974724932290_item	2960289	et	4	main
vahetanutel	doc_974724932290_item	2960291	et	4	main
loomiseks	doc_974724932290_item	2960294	et	4	main
võimalust	doc_974724932290_item	2960296	et	3	main
laenata	doc_974724932290_item	2960308	et	4	main
kohapärimus	doc_974724932290_item	2960310	et	3	main
jutud	doc_974724932290_item	2960322	et	3	main
ehk	doc_974724932290_item	2960325	et	3	main
loodud	doc_974724932290_item	2960338	et	4	main
kohtadest	doc_974724932290_item	2960343	et	3	main
pärast	doc_974724932290_item	2960345	et	4	main
aktuaalsuse	doc_974724932290_item	2960347	et	4	main
jutustavad	doc_974724932290_item	2960358	et	4	main
veel	doc_974724932290_item	2960359	et	4	main
üigem	doc_974724932290_item	2960378	et	4	main
inimesed	doc_974724932290_item	2960382	et	3	main
ja	doc_974724932290_item	2960391	et	3	main
olnud	doc_974724932290_item	2960392	et	4	main
2	doc_974724932290_item	2960396	et	2	main
hulka	doc_974724932290_item	2960403	et	4	main
olen	doc_974724932290_item	2960404	et	3	main
paigutanud	doc_974724932290_item	2960405	et	4	main
ei	doc_974724932290_item	2960408	et	4	main
teiste	doc_974724932290_item	2960413	et	4	main
päritolust	doc_974724932290_item	2960416	et	3	main
asutusest	doc_974724932290_item	2960418	et	4	main
kohandusid	doc_974724932290_item	2960424	et	4	main
muistendid	doc_974724932290_item	2960426	et	3	main
kurgaanidest	doc_974724932290_item	2960427	et	3	main
pärimusest	doc_974724932290_item	2960440	et	4	main
ning	doc_974724932290_item	2960441	et	3	main
teisele	doc_974724932290_item	2960447	et	4	main
sellega	doc_974724932290_item	2960456	et	3	main
seotud	doc_974724932290_item	2960457	et	4	main
laenanud	doc_974724932290_item	2960461	et	4	main
jäid	doc_974724932290_item	2960463	et	4	main
rahvad	doc_974724932290_item	2960467	et	3	main
ei	doc_974724932290_item	2960469	et	4	main
pärimuse	doc_974724932290_item	2960485	et	4	main
moodustab	doc_974724932290_item	2960493	et	3	main
kohanimede	doc_974724932290_item	2960495	et	3	main
teatud	doc_974724932290_item	2960512	et	4	main
selle	doc_974724932290_item	2960521	et	4	main
tööpuudus	doc_973441205379_item	2960180	et	3	main
probleem	doc_973441205379_item	2960183	et	3	main
eestlaste	doc_974724932290_item	2960228	et	4	main
arv	doc_974724932290_item	2960229	et	3	main
33	doc_974724932290_item	2960230	et	2	main
folkloristika	doc_974724932290_item	2960237	et	4	main
korral	doc_974724932290_item	2960246	et	4	main
mida	doc_974724932290_item	2960254	et	4	main
ei	doc_974724932290_item	2960255	et	4	main
oma	doc_974724932290_item	2960270	et	4	main
on	doc_974724932290_item	2960285	et	4	main
kohapärimus	doc_974724932290_item	2960286	et	3	main
igal	doc_974724932290_item	2960287	et	3	main
rahval	doc_974724932290_item	2960288	et	3	main
on	doc_974724932290_item	2960292	et	4	main
kohaldada	doc_974724932290_item	2960297	et	3	main
vana	doc_974724932290_item	2960298	et	4	main
või	doc_974724932290_item	2960311	et	4	main
eestimaal	doc_974724932290_item	2960324	et	4	main
nn	doc_974724932290_item	2960326	et	4	main
kaasa	doc_974724932290_item	2960327	et	4	main
võetud	doc_974724932290_item	2960328	et	4	main
siberi	doc_974724932290_item	2960335	et	4	main
lugu	doc_974724932290_item	2960362	et	4	main
kuid	doc_974724932290_item	2960365	et	4	main
nende	doc_974724932290_item	2960366	et	4	main
ei	doc_974724932290_item	2960373	et	4	main
veel	doc_974724932290_item	2960388	et	4	main
aegladest	doc_974724932290_item	2960393	et	3	main
eestlaste	doc_974724932290_item	2960411	et	4	main
põlisrahvaste	doc_974724932290_item	2960415	et	4	main
ja	doc_974724932290_item	2960417	et	3	main
rahvaluulesse	doc_974724932290_item	2960423	et	4	main
edukamalt	doc_974724932290_item	2960425	et	4	main
kultuurilisest	doc_974724932290_item	2960437	et	4	main
keskkonnast	doc_974724932290_item	2960438	et	4	main
senisest	doc_974724932290_item	2960439	et	3	main
eestlased	doc_974724932290_item	2960444	et	3	main
ole	doc_974724932290_item	2960446	et	4	main
poolt	doc_974724932290_item	2960449	et	4	main
märgistatud	doc_974724932290_item	2960450	et	4	main
pärimust	doc_974724932290_item	2960458	et	4	main
ka	doc_974724932290_item	2960462	et	3	main
üksteisest	doc_974724932290_item	2960473	et	4	main
eristada	doc_974724932290_item	2960474	et	3	main
3	doc_974724932290_item	2960475	et	2	main
oleksid	doc_974724932290_item	2960482	et	4	main
siberieestlaste	doc_974724932290_item	2960491	et	4	main
nimi	doc_974724932290_item	2960498	et	3	main
võib	doc_974724932290_item	2960499	et	3	main
saadud	doc_974724932290_item	2960501	et	4	main
mõne	doc_974724932290_item	2960502	et	3	main
iseloomuliku	doc_974724932290_item	2960504	et	3	main
3	doc_974724932290_item	2960515	et	2	main
säilinud	doc_974724932290_item	2960530	et	4	main
nad	doc_974724932290_item	2960533	et	3	main
jutuvormi	doc_974724932290_item	2960535	et	4	main
kultuuriloost	doc_975151536916_item	2960539	et	4	main
missugune	doc_975151536916_item	2960541	et	3	main
miks	doc_975151536916_item	2960546	et	4	main
1248	doc_975151536916_item	2960553	et	2	main
linnakultuur	doc_975151536916_item	2960568	et	3	main
alla	doc_975151536916_item	2960573	et	3	main
paigutada	doc_975151536916_item	2960575	et	3	main
maamatsideks	doc_975151536916_item	2960595	et	4	main
sakste	doc_975151536916_item	2960596	et	3	main
saksasoost	doc_975151536916_item	2960604	et	4	main
umbes	doc_974724932290_item	2960222	et	4	main
rahvaluule	doc_974724932290_item	2960247	et	4	main
seda	doc_974724932290_item	2960248	et	3	main
konkreetsust	doc_974724932290_item	2960252	et	4	main
ole	doc_974724932290_item	2960256	et	4	main
võimalik	doc_974724932290_item	2960257	et	3	main
ühest	doc_974724932290_item	2960258	et	4	main
paigast	doc_974724932290_item	2960259	et	4	main
teise	doc_974724932290_item	2960260	et	4	main
rännates	doc_974724932290_item	2960261	et	3	main
lihtsalt	doc_974724932290_item	2960262	et	4	main
kaasa	doc_974724932290_item	2960263	et	4	main
võtta	doc_974724932290_item	2960264	et	3	main
kuna	doc_974724932290_item	2960265	et	3	main
sellisel	doc_974724932290_item	2960266	et	4	main
ülekandmisel	doc_974724932290_item	2960267	et	3	main
kaotasid	doc_974724932290_item	2960269	et	4	main
tähenduse	doc_974724932290_item	2960272	et	4	main
kujundab	doc_974724932290_item	2960274	et	3	main
mitu	doc_974724932290_item	2960295	et	4	main
tradistioon	doc_974724932290_item	2960299	et	4	main
uute	doc_974724932290_item	2960300	et	3	main
tingimustega	doc_974724932290_item	2960301	et	3	main
ja	doc_974724932290_item	2960302	et	3	main
luua	doc_974724932290_item	2960305	et	4	main
uus	doc_974724932290_item	2960306	et	3	main
traditsioon	doc_974724932290_item	2960307	et	3	main
siberi	doc_974724932290_item	2960315	et	4	main
naaberrahvastelt	doc_974724932290_item	2960331	et	4	main
laenatud	doc_974724932290_item	2960332	et	4	main
eestlaste	doc_974724932290_item	2960336	et	4	main
kohapärimus	doc_974724932290_item	2960339	et	3	main
jutud	doc_974724932290_item	2960341	et	3	main
kaotasid	doc_974724932290_item	2960344	et	4	main
paraku	doc_974724932290_item	2960348	et	3	main
väljarändajaid	doc_974724932290_item	2960350	et	3	main
teadmised	doc_974724932290_item	2960367	et	4	main
võiks	doc_974724932290_item	2960377	et	4	main
pidada	doc_974724932290_item	2960379	et	4	main
seda	doc_974724932290_item	2960380	et	3	main
kes	doc_974724932290_item	2960383	et	4	main
ise	doc_974724932290_item	2960384	et	4	main
eestis	doc_974724932290_item	2960385	et	3	main
pärimuse	doc_974724932290_item	2960402	et	4	main
kõnelda	doc_974724932290_item	2960409	et	4	main
enamasti	doc_974724932290_item	2960414	et	4	main
enne	doc_974724932290_item	2960419	et	4	main
eestlaste	doc_974724932290_item	2960422	et	4	main
ja	doc_974724932290_item	2960428	et	3	main
uue	doc_974724932290_item	2960430	et	3	main
kohanemise	doc_974724932290_item	2960432	et	4	main
ei	doc_974724932290_item	2960445	et	4	main
maastikku	doc_974724932290_item	2960451	et	4	main
oma	doc_974724932290_item	2960459	et	4	main
kohalikud	doc_974724932290_item	2960466	et	3	main
külainimesed	doc_974724932290_item	2960468	et	3	main
oska	doc_974724932290_item	2960470	et	4	main
neid	doc_974724932290_item	2960471	et	4	main
sageli	doc_974724932290_item	2960472	et	3	main
mõeldav	doc_974724932290_item	2960479	et	4	main
et	doc_974724932290_item	2960480	et	3	main
eestlased	doc_974724932290_item	2960481	et	3	main
ning	doc_974724932290_item	2960486	et	3	main
oma	doc_974724932290_item	2960489	et	4	main
loomata	doc_974724932290_item	2960490	et	4	main
tunnuse	doc_974724932290_item	2960505	et	3	main
2	doc_974724932290_item	2960507	et	2	main
võib	doc_974724932290_item	2960509	et	3	main
olla	doc_974724932290_item	2960510	et	3	main
pandud	doc_974724932290_item	2960511	et	4	main
kohaga	doc_974724932290_item	2960522	et	4	main
tekkelood	doc_974724932290_item	2960527	et	4	main
on	doc_974724932290_item	2960528	et	4	main
omandasid	doc_974724932290_item	2960534	et	4	main
sa	doc_975151536916_item	2960547	et	3	main
sõda	doc_975151536916_item	2960550	et	4	main
tallinn	doc_975151536916_item	2960555	et	4	main
oli	doc_975151536916_item	2960569	et	3	main
liivimaal	doc_975151536916_item	2960570	et	4	main
linnakultuur	doc_975151536916_item	2960572	et	3	main
võib	doc_975151536916_item	2960574	et	3	main
kaubandust	doc_975151536916_item	2960576	et	3	main
1227-1343	doc_975151536916_item	2960580	et	2	main
hulka	doc_975151536916_item	2960597	et	4	main
kaupmehed	doc_975151536916_item	2960605	et	3	main
rahasepad	doc_975151536916_item	2960608	et	3	main
töölised	doc_975151536916_item	2960611	et	3	main
tegelesid	doc_975151536916_item	2960613	et	4	main
valitses	doc_975151536916_item	2960628	et	3	main
selgelt	doc_975151536916_item	2960629	et	4	main
tsunftide	doc_975151536916_item	2960631	et	3	main
hierarhia	doc_975151536916_item	2960634	et	4	main
ühte	doc_975151536916_item	2960635	et	4	main
ametid	doc_975151536916_item	2960636	et	3	main
nende	doc_975151536916_item	2960648	et	4	main
oskusi	doc_975151536916_item	2960649	et	3	main
neid	doc_975151536916_item	2960655	et	4	main
kohtadest	doc_974724932290_item	2960323	et	3	main
pärimus	doc_974724932290_item	2960333	et	4	main
3	doc_974724932290_item	2960334	et	2	main
endi	doc_974724932290_item	2960337	et	4	main
1	doc_974724932290_item	2960340	et	2	main
eestimaa	doc_974724932290_item	2960342	et	4	main
pole	doc_974724932290_item	2960349	et	3	main
enam	doc_974724932290_item	2960351	et	4	main
elavate	doc_974724932290_item	2960352	et	4	main
hulgas	doc_974724932290_item	2960353	et	4	main
nende	doc_974724932290_item	2960354	et	4	main
lapsed	doc_974724932290_item	2960355	et	3	main
ja	doc_974724932290_item	2960356	et	3	main
lapselapsed	doc_974724932290_item	2960357	et	3	main
kuuldud	doc_974724932290_item	2960361	et	4	main
elust	doc_974724932290_item	2960364	et	3	main
on	doc_974724932290_item	2960370	et	4	main
kasinad	doc_974724932290_item	2960371	et	3	main
sageli	doc_974724932290_item	2960372	et	3	main
tunta	doc_974724932290_item	2960374	et	3	main
eesti	doc_974724932290_item	2960375	et	4	main
geograafiat	doc_974724932290_item	2960376	et	3	main
kui	doc_974724932290_item	2960381	et	3	main
eestimaa	doc_974724932290_item	2960389	et	4	main
paikadest	doc_974724932290_item	2960390	et	3	main
jutte	doc_974724932290_item	2960394	et	3	main
naaberrahvastelt	doc_974724932290_item	2960397	et	4	main
sh	doc_974724932290_item	2960399	et	4	main
laiema	doc_974724932290_item	2960400	et	4	main
levikuga	doc_974724932290_item	2960401	et	3	main
kus	doc_974724932290_item	2960407	et	3	main
vaid	doc_974724932290_item	2960412	et	3	main
tulekut	doc_974724932290_item	2960421	et	3	main
kääbastest	doc_974724932290_item	2960429	et	3	main
kasutajate	doc_974724932290_item	2960442	et	4	main
maailmavaatest	doc_974724932290_item	2960443	et	4	main
detailselt	doc_974724932290_item	2960452	et	4	main
käibesse	doc_974724932290_item	2960460	et	3	main
võõraks	doc_974724932290_item	2960465	et	3	main
loomulikult	doc_974724932290_item	2960476	et	4	main
laenanud	doc_974724932290_item	2960483	et	4	main
kohaliku	doc_974724932290_item	2960484	et	3	main
jätnud	doc_974724932290_item	2960487	et	4	main
kohapärimusest	doc_974724932290_item	2960492	et	4	main
1	doc_974724932290_item	2960497	et	2	main
olla	doc_974724932290_item	2960500	et	3	main
paigale	doc_974724932290_item	2960503	et	4	main
järgi	doc_974724932290_item	2960506	et	4	main
nimi	doc_974724932290_item	2960508	et	3	main
kontrolltöö	doc_975151536916_item	2960536	et	4	main
kontrolltöö	doc_975151536916_item	2960537	et	4	main
1	doc_975151536916_item	2960540	et	2	main
oli	doc_975151536916_item	2960542	et	3	main
linnakultuur	doc_975151536916_item	2960544	et	3	main
võimalikuks	doc_975151536916_item	2960548	et	3	main
aastal	doc_975151536916_item	2960552	et	3	main
linnaõiguse	doc_975151536916_item	2960558	et	4	main
keskaegne	doc_975151536916_item	2960567	et	3	main
õiguse	doc_975151536916_item	2960585	et	4	main
linna	doc_975151536916_item	2960589	et	4	main
eeskätt	doc_975151536916_item	2960599	et	3	main
saksa	doc_975151536916_item	2960600	et	4	main
päritoluga	doc_975151536916_item	2960601	et	3	main
vaimulikud	doc_975151536916_item	2960602	et	3	main
vasesepad	doc_975151536916_item	2960607	et	3	main
need	doc_975151536916_item	2960610	et	3	main
kes	doc_975151536916_item	2960612	et	4	main
parema	doc_975151536916_item	2960614	et	4	main
ja	doc_975151536916_item	2960615	et	3	main
puhtama	doc_975151536916_item	2960616	et	4	main
tegelesid	doc_975151536916_item	2960622	et	4	main
alamtööga	doc_975151536916_item	2960624	et	3	main
pidavad	doc_975151536916_item	2960637	et	4	main
ametimehed	doc_975151536916_item	2960638	et	3	main
kontrollis	doc_975151536916_item	2960647	et	4	main
väike	doc_975151536916_item	2960653	et	4	main
kaupmehed	doc_975151536916_item	2960654	et	3	main
karusnahka	doc_975151536916_item	2960668	et	4	main
kaupmeeste	doc_975151536916_item	2960675	et	4	main
eeskätt	doc_975151536916_item	2960680	et	3	main
lisaks	doc_975151536916_item	2960685	et	4	main
jutlustuse	doc_975151536916_item	2960699	et	4	main
mulda	doc_975151536916_item	2960710	et	4	main
olid	doc_975151536916_item	2960734	et	4	main
linnarahvale	doc_975151536916_item	2960735	et	3	main
traditsiooni	doc_974724932290_item	2960431	et	4	main
edukus	doc_974724932290_item	2960433	et	4	main
sõltub	doc_974724932290_item	2960434	et	3	main
looduslikust	doc_974724932290_item	2960435	et	4	main
ja	doc_974724932290_item	2960436	et	3	main
rahvaste	doc_974724932290_item	2960448	et	4	main
tundma	doc_974724932290_item	2960453	et	3	main
õppinud	doc_974724932290_item	2960454	et	4	main
ning	doc_974724932290_item	2960455	et	3	main
eestlastele	doc_974724932290_item	2960464	et	4	main
ei	doc_974724932290_item	2960477	et	4	main
ole	doc_974724932290_item	2960478	et	4	main
enda	doc_974724932290_item	2960488	et	4	main
enamuse	doc_974724932290_item	2960494	et	4	main
rahvaetümoloogia	doc_974724932290_item	2960496	et	4	main
sündmuse	doc_974724932290_item	2960513	et	3	main
järgi	doc_974724932290_item	2960514	et	4	main
kõige	doc_974724932290_item	2960516	et	4	main
sagedamini	doc_974724932290_item	2960517	et	4	main
on	doc_974724932290_item	2960518	et	4	main
nimi	doc_974724932290_item	2960519	et	3	main
pandud	doc_974724932290_item	2960520	et	4	main
järgi	doc_974724932290_item	2960525	et	4	main
külanime	doc_974724932290_item	2960526	et	4	main
eesti	doc_975151536916_item	2960538	et	4	main
2	doc_975151536916_item	2960545	et	2	main
vene-liivi	doc_975151536916_item	2960549	et	4	main
sai	doc_975151536916_item	2960554	et	4	main
endale	doc_975151536916_item	2960556	et	4	main
lübecki	doc_975151536916_item	2960557	et	4	main
eestis	doc_975151536916_item	2960566	et	3	main
mitmepalgeline	doc_975151536916_item	2960571	et	4	main
kooliharidust	doc_975151536916_item	2960578	et	4	main
aastatel	doc_975151536916_item	2960579	et	4	main
sai	doc_975151536916_item	2960581	et	4	main
kaubanduse	doc_975151536916_item	2960582	et	3	main
ja	doc_975151536916_item	2960583	et	3	main
meresõitude	doc_975151536916_item	2960584	et	3	main
lõplikult	doc_975151536916_item	2960587	et	4	main
kuulusid	doc_975151536916_item	2960598	et	4	main
kullassepad	doc_975151536916_item	2960606	et	3	main
st	doc_975151536916_item	2960609	et	3	main
peamiselt	doc_975151536916_item	2960623	et	4	main
kingsepad	doc_975151536916_item	2960626	et	3	main
väljakujunenud	doc_975151536916_item	2960630	et	4	main
ja	doc_975151536916_item	2960632	et	3	main
kaitses	doc_975151536916_item	2960643	et	4	main
meeste	doc_975151536916_item	2960645	et	4	main
õigusi	doc_975151536916_item	2960646	et	4	main
käsitöga	doc_975151536916_item	2960651	et	4	main
tegelesid	doc_975151536916_item	2960652	et	4	main
välismaale	doc_975151536916_item	2960665	et	4	main
eeskätt	doc_975151536916_item	2960666	et	3	main
edendajad	doc_975151536916_item	2960678	et	4	main
seega	doc_975151536916_item	2960682	et	4	main
kultuurikeskusteks	doc_975151536916_item	2960683	et	4	main
ka	doc_975151536916_item	2960688	et	3	main
kirik	doc_975151536916_item	2960689	et	3	main
16	doc_975151536916_item	2960691	et	2	main
pandi	doc_975151536916_item	2960702	et	4	main
kirikuisa	doc_975151536916_item	2960707	et	4	main
pühitses	doc_975151536916_item	2960708	et	3	main
surnute	doc_975151536916_item	2960709	et	4	main
muutus	doc_975151536916_item	2960715	et	4	main
kirik	doc_975151536916_item	2960716	et	3	main
lihtrahvale	doc_975151536916_item	2960721	et	3	main
enda	doc_975151536916_item	2960723	et	4	main
palveid	doc_975151536916_item	2960725	et	3	main
ilmub	doc_975151536916_item	2960727	et	3	main
esimene	doc_975151536916_item	2960728	et	3	main
wandradt-koelli	doc_975151536916_item	2960730	et	4	main
katekismus	doc_975151536916_item	2960731	et	3	main
rootsi	doc_975151536916_item	2960738	et	4	main
kirikuõpetajatel	doc_975151536916_item	2960743	et	3	main
rootsiajal	doc_975151536916_item	2960748	et	3	main
seotud	doc_974724932290_item	2960523	et	4	main
inimese	doc_974724932290_item	2960524	et	4	main
paremini	doc_974724932290_item	2960529	et	4	main
asundustes	doc_974724932290_item	2960531	et	4	main
kus	doc_974724932290_item	2960532	et	3	main
keskaegne	doc_975151536916_item	2960543	et	3	main
1	doc_975151536916_item	2960551	et	2	main
sellest	doc_975151536916_item	2960559	et	4	main
ajast	doc_975151536916_item	2960560	et	4	main
saab	doc_975151536916_item	2960561	et	3	main
ametlikult	doc_975151536916_item	2960562	et	4	main
rääkida	doc_975151536916_item	2960563	et	3	main
linnakultuurist	doc_975151536916_item	2960564	et	3	main
keskaegses	doc_975151536916_item	2960565	et	3	main
vaimuelu	doc_975151536916_item	2960577	et	4	main
endale	doc_975151536916_item	2960586	et	4	main
linn	doc_975151536916_item	2960588	et	3	main
elanikkond	doc_975151536916_item	2960590	et	3	main
jagunes	doc_975151536916_item	2960591	et	3	main
rangelt	doc_975151536916_item	2960592	et	4	main
saksteks	doc_975151536916_item	2960593	et	3	main
ja	doc_975151536916_item	2960594	et	3	main
aadlis	doc_975151536916_item	2960603	et	3	main
tööga	doc_975151536916_item	2960617	et	3	main
lihtrahva	doc_975151536916_item	2960618	et	3	main
eestlased	doc_975151536916_item	2960619	et	3	main
ladgolid	doc_975151536916_item	2960620	et	4	main
liivlased	doc_975151536916_item	2960621	et	3	main
puusepad	doc_975151536916_item	2960625	et	3	main
gildide	doc_975151536916_item	2960633	et	3	main
kuulusid	doc_975151536916_item	2960639	et	4	main
ühte	doc_975151536916_item	2960640	et	4	main
tsunfti	doc_975151536916_item	2960641	et	4	main
nende	doc_975151536916_item	2960644	et	4	main
eestlaste	doc_975151536916_item	2960658	et	4	main
ja	doc_975151536916_item	2960659	et	3	main
liivlaste	doc_975151536916_item	2960660	et	4	main
soost	doc_975151536916_item	2960661	et	4	main
transiitkaubandus	doc_975151536916_item	2960662	et	3	main
kus	doc_975151536916_item	2960663	et	3	main
müüdi	doc_975151536916_item	2960664	et	4	main
vaha	doc_975151536916_item	2960670	et	4	main
rukist	doc_975151536916_item	2960671	et	3	main
oli	doc_975151536916_item	2960672	et	3	main
saksa	doc_975151536916_item	2960673	et	4	main
soost	doc_975151536916_item	2960674	et	4	main
olid	doc_975151536916_item	2960679	et	4	main
kuulamine	doc_975151536916_item	2960700	et	4	main
kirikus	doc_975151536916_item	2960701	et	3	main
toomkirikute	doc_975151536916_item	2960732	et	4	main
juures	doc_975151536916_item	2960733	et	4	main
avati	doc_975151536916_item	2960740	et	3	main
ning	doc_975151536916_item	2960745	et	3	main
oli	doc_975151536916_item	2960749	et	3	main
vaimuelu	doc_975151536916_item	2960751	et	4	main
kandsid	doc_975151536916_item	2960762	et	4	main
linna	doc_975151536916_item	2960765	et	4	main
üheks	doc_975151536916_item	2960767	et	3	main
osaks	doc_975151536916_item	2960769	et	3	main
ka	doc_975151536916_item	2960771	et	3	main
keelt	doc_975151536916_item	2960819	et	4	main
toonasesse	doc_975151536916_item	2960820	et	3	main
nn	doc_975151536916_item	2960831	et	4	main
abi	doc_975151536916_item	2960837	et	4	main
mis	doc_975151536916_item	2960846	et	4	main
kivist	doc_975151536916_item	2960849	et	4	main
tuleohtu	doc_975151536916_item	2960852	et	4	main
sai	doc_975151536916_item	2960856	et	4	main
senise	doc_975151536916_item	2960866	et	3	main
tipus	doc_975151536916_item	2960868	et	3	main
ja	doc_975151536916_item	2960873	et	3	main
peapiiskopi	doc_975151536916_item	2960875	et	4	main
vahel	doc_975151536916_item	2960876	et	4	main
riigis	doc_975151536916_item	2960877	et	3	main
ivan	doc_975151536916_item	2960887	et	4	main
territoorium	doc_975151536916_item	2960922	et	3	main
jätmine	doc_975151536916_item	2960931	et	4	main
linnas	doc_975151536916_item	2960627	et	4	main
mis	doc_975151536916_item	2960642	et	4	main
kohapealese	doc_975151536916_item	2960650	et	4	main
leidus	doc_975151536916_item	2960656	et	4	main
ka	doc_975151536916_item	2960657	et	3	main
venemaale	doc_975151536916_item	2960667	et	4	main
linnakultuuri	doc_975151536916_item	2960677	et	4	main
turuplatsile	doc_975151536916_item	2960686	et	4	main
veel	doc_975151536916_item	2960687	et	4	main
ametlikult	doc_975151536916_item	2960704	et	4	main
paari	doc_975151536916_item	2960705	et	4	main
reformatsiooni	doc_975151536916_item	2960711	et	4	main
ajal	doc_975151536916_item	2960712	et	4	main
tähtsaks	doc_975151536916_item	2960717	et	4	main
hariduspunktiks	doc_975151536916_item	2960718	et	4	main
hakati	doc_975151536916_item	2960719	et	3	main
õpetama	doc_975151536916_item	2960720	et	3	main
mett	doc_975151536916_item	2960669	et	4	main
töö	doc_975151536916_item	2960676	et	4	main
vaimulikud	doc_975151536916_item	2960681	et	3	main
oli	doc_975151536916_item	2960684	et	3	main
enne	doc_975151536916_item	2960690	et	4	main
saj	doc_975151536916_item	2960692	et	4	main
oli	doc_975151536916_item	2960693	et	3	main
populaarne	doc_975151536916_item	2960694	et	3	main
altarite	doc_975151536916_item	2960695	et	3	main
kummardamine	doc_975151536916_item	2960696	et	4	main
kirikus	doc_975151536916_item	2960697	et	3	main
ladinakeelse	doc_975151536916_item	2960698	et	3	main
abieluinimesed	doc_975151536916_item	2960703	et	3	main
ning	doc_975151536916_item	2960706	et	3	main
1521	doc_975151536916_item	2960713	et	2	main
liivimaal	doc_975151536916_item	2960714	et	4	main
tema	doc_975151536916_item	2960722	et	4	main
emakeeles	doc_975151536916_item	2960724	et	4	main
1535	doc_975151536916_item	2960726	et	2	main
eestikeelne	doc_975151536916_item	2960729	et	3	main
mõeldud	doc_975151536916_item	2960736	et	4	main
koolid	doc_975151536916_item	2960737	et	3	main
seminarid	doc_975151536916_item	2960742	et	3	main
koolitamiseks	doc_975151536916_item	2960747	et	4	main
eestisoost	doc_975151536916_item	2960757	et	4	main
raad	doc_975151536916_item	2960777	et	4	main
need	doc_975151536916_item	2960779	et	3	main
ehitised	doc_975151536916_item	2960780	et	3	main
kuulda	doc_975151536916_item	2960816	et	4	main
ka	doc_975151536916_item	2960817	et	3	main
linna	doc_975151536916_item	2960821	et	4	main
ka	doc_975151536916_item	2960824	et	3	main
vaimulike	doc_975151536916_item	2960825	et	3	main
poolt	doc_975151536916_item	2960826	et	4	main
puhujad	doc_975151536916_item	2960833	et	4	main
linna	doc_975151536916_item	2960839	et	4	main
et	doc_975151536916_item	2960850	et	3	main
vene-liivi	doc_975151536916_item	2960854	et	4	main
eeskätt	doc_975151536916_item	2960858	et	3	main
poolest	doc_975151536916_item	2960860	et	4	main
võimsuse	doc_975151536916_item	2960867	et	4	main
ordumeistri	doc_975151536916_item	2960872	et	3	main
puudus	doc_975151536916_item	2960878	et	4	main
palju	doc_975151536916_item	2960889	et	4	main
ajal	doc_975151536916_item	2960739	et	4	main
tõlkide	doc_975151536916_item	2960746	et	3	main
vilja	doc_975151536916_item	2960764	et	4	main
kultuuri	doc_975151536916_item	2960766	et	4	main
oli	doc_975151536916_item	2960770	et	3	main
skulptuur	doc_975151536916_item	2960773	et	3	main
sündsuse	doc_975151536916_item	2960781	et	4	main
piirid	doc_975151536916_item	2960782	et	3	main
mis	doc_975151536916_item	2960783	et	4	main
määrasid	doc_975151536916_item	2960784	et	4	main
lihtsate	doc_975151536916_item	2960785	et	3	main
inimeste	doc_975151536916_item	2960786	et	3	main
majade	doc_975151536916_item	2960787	et	3	main
kõrgust	doc_975151536916_item	2960788	et	4	main
gootistiilis	doc_975151536916_item	2960789	et	4	main
maalikultuur	doc_975151536916_item	2960790	et	3	main
on	doc_975151536916_item	2960791	et	4	main
säilinud	doc_975151536916_item	2960792	et	4	main
eelkõige	doc_975151536916_item	2960793	et	3	main
niguliste	doc_975151536916_item	2960794	et	4	main
kirikus	doc_975151536916_item	2960795	et	3	main
ja	doc_975151536916_item	2960796	et	3	main
oleviste	doc_975151536916_item	2960797	et	4	main
kirikus	doc_975151536916_item	2960798	et	3	main
notke	doc_975151536916_item	2960799	et	4	main
surmatants	doc_975151536916_item	2960800	et	3	main
liivimaa	doc_975151536916_item	2960801	et	4	main
linnakultuuri	doc_975151536916_item	2960802	et	4	main
määr	doc_975151536916_item	2960803	et	3	main
eeskätt	doc_975151536916_item	2960804	et	3	main
saksamaa	doc_975151536916_item	2960805	et	4	main
stiil	doc_975151536916_item	2960806	et	3	main
ametlikuks	doc_975151536916_item	2960807	et	3	main
luuleks	doc_975151536916_item	2960808	et	4	main
oli	doc_975151536916_item	2960809	et	3	main
saksa	doc_975151536916_item	2960810	et	4	main
keel	doc_975151536916_item	2960811	et	4	main
linna	doc_975151536916_item	2960812	et	4	main
rahvamurrust	doc_975151536916_item	2960813	et	3	main
võis	doc_975151536916_item	2960814	et	4	main
sageli	doc_975151536916_item	2960815	et	3	main
ka	doc_975151536916_item	2960741	et	3	main
väljaõppeks	doc_975151536916_item	2960744	et	3	main
tuntud	doc_975151536916_item	2960750	et	4	main
edendaja	doc_975151536916_item	2960752	et	4	main
forselius	doc_975151536916_item	2960753	et	4	main
kes	doc_975151536916_item	2960754	et	4	main
püüdis	doc_975151536916_item	2960755	et	3	main
ka	doc_975151536916_item	2960756	et	3	main
ka	doc_975151536916_item	2960763	et	3	main
arkitektuur	doc_975151536916_item	2960772	et	4	main
ning	doc_975151536916_item	2960775	et	3	main
poisse	doc_975151536916_item	2960758	et	4	main
koolitada	doc_975151536916_item	2960759	et	3	main
tema	doc_975151536916_item	2960760	et	4	main
püüdlused	doc_975151536916_item	2960761	et	3	main
tähtsamaks	doc_975151536916_item	2960768	et	4	main
kirikukooned	doc_975151536916_item	2960774	et	4	main
linna	doc_975151536916_item	2960776	et	4	main
olid	doc_975151536916_item	2960778	et	4	main
taani	doc_975151536916_item	2960818	et	4	main
avatud	doc_975151536916_item	2960827	et	4	main
laatsaretis	doc_975151536916_item	2960828	et	3	main
kus	doc_975151536916_item	2960829	et	3	main
meditsiinilist	doc_975151536916_item	2960836	et	4	main
paidutus	doc_975151536916_item	2960845	et	4	main
valtida	doc_975151536916_item	2960851	et	4	main
2	doc_975151536916_item	2960853	et	2	main
oma	doc_975151536916_item	2960865	et	4	main
siseriiklikud	doc_975151536916_item	2960870	et	3	main
riia	doc_975151536916_item	2960874	et	4	main
peal	doc_975151536916_item	2960886	et	4	main
suurem	doc_975151536916_item	2960890	et	4	main
iidsetest	doc_975151536916_item	2960924	et	3	main
kuulunud	doc_975151536916_item	2960926	et	4	main
tastu	doc_975151536916_item	2960928	et	4	main
kontrolltöö	doc_975151536917_item	2960932	et	4	main
1	doc_975151536917_item	2960936	et	2	main
liit	doc_975151536917_item	2960947	et	3	main
oli	doc_975151536917_item	2960950	et	3	main
usu	doc_975151536917_item	2960971	et	4	main
kloostrid	doc_975151536917_item	2960979	et	3	main
ka	doc_975151536917_item	2960983	et	3	main
koolide	doc_975151536917_item	2960984	et	3	main
17-18	doc_975151536917_item	2960998	et	2	main
samas	doc_975151536917_item	2961014	et	4	main
ristiusu	doc_975151536917_item	2961015	et	3	main
miks	doc_975151536917_item	2961024	et	4	main
säilis	doc_975151536917_item	2961026	et	4	main
veenvaks	doc_975151536917_item	2961031	et	4	main
põhjuseks	doc_975151536917_item	2961032	et	3	main
rahvakeeles	doc_975151536917_item	2961042	et	4	main
vaid	doc_975151536917_item	2961043	et	3	main
ladinakeeles	doc_975151536917_item	2961044	et	4	main
eestlased	doc_975151536917_item	2961058	et	3	main
paljud	doc_975151536917_item	2961066	et	3	main
esiteks	doc_975151536917_item	2961068	et	3	main
oli	doc_975151536917_item	2961069	et	3	main
väga	doc_975151536917_item	2961070	et	3	main
populaarne	doc_975151536917_item	2961071	et	3	main
õnnistamine	doc_975151536917_item	2961072	et	4	main
üks	doc_975151536917_item	2961076	et	3	main
veel	doc_975151536917_item	2961079	et	4	main
miks	doc_975151536917_item	2961090	et	4	main
ja	doc_975151536917_item	2961122	et	3	main
lübeck	doc_975151536917_item	2961128	et	4	main
hansaliit	doc_975151536917_item	2961136	et	3	main
kaupmeeste	doc_975151536917_item	2961137	et	4	main
liivimaa	doc_975151536917_item	2961145	et	4	main
venemaa	doc_975151536917_item	2961146	et	4	main
olid	doc_975151536917_item	2961152	et	4	main
novgorad	doc_975151536917_item	2961164	et	4	main
hansaliit	doc_975151536917_item	2961165	et	3	main
oli	doc_975151536917_item	2961166	et	3	main
eestlaste	doc_975151536917_item	2961167	et	4	main
toodi	doc_975151536917_item	2961171	et	4	main
oli	doc_975151536918_item	2961196	et	3	main
saj	doc_975151536918_item	2961210	et	4	main
maal	doc_975151536918_item	2961218	et	4	main
linnas	doc_975151536918_item	2961221	et	4	main
suuremad	doc_975151536918_item	2961223	et	4	main
olid	doc_975151536918_item	2961225	et	4	main
rasva	doc_975151536918_item	2961259	et	4	main
maahärrad	doc_975151536918_item	2961282	et	3	main
tsunftid	doc_975151536918_item	2961285	et	3	main
teine	doc_975151536918_item	2961286	et	3	main
kindlasti	doc_975151536918_item	2961289	et	3	main
oli	doc_975151536918_item	2961292	et	3	main
osatähtsus	doc_975151536918_item	2961294	et	4	main
linna	doc_975151536918_item	2961309	et	4	main
võitlema	doc_975151536918_item	2961314	et	3	main
misjonäridest	doc_975151536916_item	2960830	et	3	main
soola	doc_975151536916_item	2960832	et	4	main
keskaegesse	doc_975151536916_item	2960838	et	4	main
olid	doc_975151536916_item	2960847	et	4	main
sõda	doc_975151536916_item	2960855	et	4	main
võimalikuks	doc_975151536916_item	2960857	et	3	main
selle	doc_975151536916_item	2960859	et	4	main
et	doc_975151536916_item	2960861	et	3	main
liiviordu	doc_975151536916_item	2960862	et	4	main
polnud	doc_975151536916_item	2960863	et	3	main
lahkhelid	doc_975151536916_item	2960871	et	3	main
ka	doc_975151536916_item	2960880	et	3	main
iv	doc_975151536916_item	2960888	et	4	main
pealegi	doc_975151536916_item	2960891	et	4	main
puudus	doc_975151536916_item	2960892	et	4	main
ka	doc_975151536916_item	2960893	et	3	main
lihtrahval	doc_975151536916_item	2960894	et	3	main
tarvilik	doc_975151536916_item	2960895	et	3	main
varustus	doc_975151536916_item	2960896	et	4	main
ja	doc_975151536916_item	2960897	et	3	main
sõjaline	doc_975151536916_item	2960898	et	4	main
väljaõppe	doc_975151536916_item	2960899	et	4	main
pikaajalisteks	doc_975151536916_item	2960900	et	4	main
sõjakäikudeks	doc_975151536916_item	2960901	et	3	main
ivan	doc_975151536916_item	2960902	et	4	main
iv	doc_975151536916_item	2960903	et	4	main
sai	doc_975151536916_item	2960904	et	4	main
innustust	doc_975151536916_item	2960905	et	4	main
ka	doc_975151536916_item	2960906	et	3	main
võitudest	doc_975151536916_item	2960907	et	3	main
fatasi-mongoli	doc_975151536916_item	2960908	et	3	main
lehooniga	doc_975151536916_item	2960909	et	4	main
ning	doc_975151536916_item	2960910	et	3	main
oli	doc_975151536916_item	2960911	et	3	main
oma	doc_975151536916_item	2960912	et	4	main
võidus	doc_975151536916_item	2960913	et	4	main
kindel	doc_975151536916_item	2960914	et	3	main
ajendiks	doc_975151536916_item	2960915	et	3	main
sai	doc_975151536916_item	2960916	et	4	main
siin	doc_975151536916_item	2960917	et	4	main
maal	doc_975151536916_item	2960918	et	4	main
vanausuliste	doc_975151536916_item	2960919	et	4	main
tagakiusamine	doc_975151536916_item	2960920	et	3	main
siinne	doc_975151536916_item	2960921	et	3	main
tasumata	doc_975151536916_item	2960930	et	4	main
kontrolltöö	doc_975151536917_item	2960933	et	4	main
mis	doc_975151536917_item	2960937	et	4	main
soodustas	doc_975151536917_item	2960938	et	3	main
muinasusundi	doc_975151536917_item	2960939	et	3	main
ristisõda	doc_975151536917_item	2960949	et	4	main
uue	doc_975151536917_item	2960953	et	3	main
kultuuri	doc_975151536916_item	2960822	et	4	main
kuuluvad	doc_975151536916_item	2960823	et	4	main
osutasid	doc_975151536916_item	2960834	et	4	main
rahvale	doc_975151536916_item	2960835	et	3	main
kultuuri	doc_975151536916_item	2960840	et	4	main
kuulub	doc_975151536916_item	2960841	et	3	main
ka	doc_975151536916_item	2960842	et	3	main
tihe	doc_975151536916_item	2960843	et	3	main
majade	doc_975151536916_item	2960844	et	3	main
enamasti	doc_975151536916_item	2960848	et	4	main
enam	doc_975151536916_item	2960864	et	4	main
esinesid	doc_975151536916_item	2960869	et	4	main
ühtsus	doc_975151536916_item	2960879	et	4	main
kahurilika	doc_975151536916_item	2960881	et	4	main
onekool	doc_975151536916_item	2960882	et	4	main
oli	doc_975151536916_item	2960883	et	3	main
vene	doc_975151536916_item	2960884	et	4	main
vürstiriigi	doc_975151536916_item	2960885	et	3	main
on	doc_975151536916_item	2960923	et	4	main
aegadest	doc_975151536916_item	2960925	et	3	main
venemaale	doc_975151536916_item	2960927	et	4	main
juures	doc_975151536917_item	2960942	et	4	main
2	doc_975151536917_item	2960943	et	2	main
enne	doc_975151536917_item	2960957	et	4	main
tekkimist	doc_975151536917_item	2960972	et	4	main
sellega	doc_975151536917_item	2960980	et	3	main
kaasa	doc_975151536917_item	2960982	et	4	main
rajamine	doc_975151536917_item	2960985	et	4	main
ja	doc_975151536917_item	2960986	et	3	main
kirjaoskuse	doc_975151536917_item	2960987	et	3	main
levitamine	doc_975151536917_item	2960988	et	4	main
sajandini	doc_975151536917_item	2960999	et	3	main
olid	doc_975151536917_item	2961002	et	4	main
ja	doc_975151536917_item	2961004	et	3	main
paljud	doc_975151536917_item	2961008	et	3	main
kultused	doc_975151536917_item	2961009	et	3	main
rituaale	doc_975151536917_item	2961017	et	3	main
teiseks	doc_975151536917_item	2961030	et	4	main
läbiviidud	doc_975151536917_item	2961041	et	4	main
eestlastel	doc_975151536917_item	2961050	et	4	main
võimalus	doc_975151536917_item	2961051	et	3	main
pihtida	doc_975151536917_item	2961052	et	3	main
et	doc_975151536917_item	2961057	et	3	main
oma	doc_975151536917_item	2961061	et	4	main
olid	doc_975151536917_item	2961063	et	4	main
võetud	doc_975151536917_item	2961064	et	4	main
ka	doc_975151536917_item	2961065	et	3	main
kombed	doc_975151536917_item	2961067	et	3	main
veel	doc_975151536917_item	2961075	et	4	main
see	doc_975151536917_item	2961080	et	3	main
ja	doc_975151536917_item	2961085	et	3	main
ei	doc_975151536917_item	2961087	et	4	main
olnud	doc_975151536917_item	2961088	et	4	main
tundmatu	doc_975151536917_item	2961123	et	4	main
aastal	doc_975151536917_item	2961126	et	3	main
hansaliidu	doc_975151536917_item	2961134	et	3	main
liit	doc_975151536917_item	2961138	et	3	main
madalmaad	doc_975151536917_item	2961144	et	4	main
mis	doc_975151536917_item	2961149	et	4	main
astusid	doc_975151536917_item	2961150	et	4	main
kuna	doc_975151536917_item	2961169	et	3	main
eestis	doc_975151536918_item	2961211	et	3	main
oli	doc_975151536918_item	2961214	et	3	main
ka	doc_975151536918_item	2961220	et	3	main
tartu	doc_975151536918_item	2961226	et	4	main
ja	doc_975151536918_item	2961227	et	3	main
elas	doc_975151536918_item	2961230	et	3	main
000	doc_975151536918_item	2961232	et	2	main
inimest	doc_975151536918_item	2961233	et	3	main
kuulusid	doc_975151536918_item	2961244	et	4	main
kaup	doc_975151536918_item	2961253	et	3	main
viidi	doc_975151536918_item	2961255	et	4	main
välja	doc_975151536918_item	2961256	et	4	main
soola	doc_975151536918_item	2961262	et	4	main
viina	doc_975151536918_item	2961263	et	4	main
piiskop	doc_975151536918_item	2961296	et	3	main
ka	doc_975151536918_item	2961315	et	3	main
eest	doc_975151536918_item	2961317	et	4	main
arstiabi	doc_975151536918_item	2961331	et	4	main
oleviste	doc_975151536918_item	2961335	et	4	main
toomkirik	doc_975151536918_item	2961339	et	3	main
pidid	doc_975151536918_item	2961345	et	4	main
maksu	doc_975151536916_item	2960929	et	4	main
eesti	doc_975151536917_item	2960934	et	4	main
mis	doc_975151536917_item	2960944	et	4	main
oli	doc_975151536917_item	2960945	et	3	main
hansa	doc_975151536917_item	2960946	et	4	main
sõda	doc_975151536917_item	2960952	et	4	main
ja	doc_975151536917_item	2960954	et	3	main
12	doc_975151536917_item	2960958	et	2	main
saj	doc_975151536917_item	2960959	et	4	main
eesti	doc_975151536917_item	2960960	et	4	main
territooriumil	doc_975151536917_item	2960961	et	3	main
elas	doc_975151536917_item	2960962	et	3	main
paganlik	doc_975151536917_item	2960963	et	3	main
rahvas	doc_975151536917_item	2960964	et	4	main
ja	doc_975151536917_item	2960965	et	3	main
ristisõda	doc_975151536917_item	2960966	et	4	main
tõi	doc_975151536917_item	2960967	et	3	main
endaga	doc_975151536917_item	2960968	et	4	main
kultuuriloost	doc_975151536917_item	2960935	et	4	main
säilimist	doc_975151536917_item	2960940	et	4	main
eestlaste	doc_975151536917_item	2960941	et	4	main
1	doc_975151536917_item	2960948	et	2	main
ka	doc_975151536917_item	2960951	et	3	main
vana	doc_975151536917_item	2960955	et	4	main
vahel	doc_975151536917_item	2960956	et	4	main
käis	doc_975151536917_item	2960981	et	4	main
paljud	doc_975151536917_item	2961000	et	3	main
samastatud	doc_975151536917_item	2961003	et	4	main
maagiaga	doc_975151536917_item	2961019	et	3	main
kaasa	doc_975151536917_item	2960969	et	4	main
uue	doc_975151536917_item	2960970	et	3	main
hakkasid	doc_975151536917_item	2960975	et	4	main
tekkima	doc_975151536917_item	2960976	et	3	main
kirikud	doc_975151536917_item	2960977	et	3	main
ja	doc_975151536917_item	2960978	et	3	main
kombeid	doc_975151536917_item	2960994	et	4	main
jäi	doc_975151536917_item	2960995	et	3	main
püsima	doc_975151536917_item	2960996	et	3	main
kuni	doc_975151536917_item	2960997	et	3	main
tehtud	doc_975151536917_item	2961011	et	4	main
kiriku	doc_975151536917_item	2961012	et	3	main
kalmistutel	doc_975151536917_item	2961013	et	3	main
kiriklike	doc_975151536917_item	2961016	et	3	main
oligi	doc_975151536917_item	2961021	et	3	main
põhjustest	doc_975151536917_item	2961023	et	3	main
muinasusud	doc_975151536917_item	2961025	et	3	main
kaua	doc_975151536917_item	2961027	et	3	main
oli	doc_975151536917_item	2961033	et	3	main
emakeeles	doc_975151536917_item	2961053	et	4	main
kuid	doc_975151536917_item	2961054	et	4	main
ristiusku	doc_975151536917_item	2961060	et	4	main
õnnistati	doc_975151536917_item	2961073	et	4	main
kähku	doc_975151536917_item	2961084	et	3	main
uus	doc_975151536917_item	2961121	et	3	main
2	doc_975151536917_item	2961124	et	2	main
pärast	doc_975151536917_item	2961133	et	4	main
olid	doc_975151536917_item	2961141	et	4	main
saksamaa	doc_975151536917_item	2961143	et	4	main
maad	doc_975151536917_item	2961148	et	4	main
riia	doc_975151536917_item	2961153	et	4	main
tartu	doc_975151536917_item	2961155	et	4	main
pärnu	doc_975151536917_item	2961157	et	4	main
eestisse	doc_975151536917_item	2961172	et	4	main
2	doc_975151536918_item	2961199	et	2	main
võimalikuks	doc_975151536918_item	2961202	et	3	main
elanike	doc_975151536918_item	2961212	et	3	main
arv	doc_975151536918_item	2961213	et	3	main
000	doc_975151536918_item	2961216	et	2	main
ristimisega	doc_975151536917_item	2960973	et	4	main
koos	doc_975151536917_item	2960974	et	4	main
kuid	doc_975151536917_item	2960989	et	4	main
enamik	doc_975151536917_item	2960990	et	3	main
tavasid	doc_975151536917_item	2960991	et	3	main
ja	doc_975151536917_item	2960992	et	3	main
paganlike	doc_975151536917_item	2960993	et	3	main
pühakultused	doc_975151536917_item	2961001	et	3	main
sobitatud	doc_975151536917_item	2961005	et	4	main
paganate	doc_975151536917_item	2961006	et	3	main
traditsioonidega	doc_975151536917_item	2961007	et	3	main
olid	doc_975151536917_item	2961010	et	4	main
samastati	doc_975151536917_item	2961018	et	3	main
see	doc_975151536917_item	2961020	et	3	main
üks	doc_975151536917_item	2961022	et	3	main
eestlaste	doc_975151536917_item	2961028	et	4	main
juures	doc_975151536917_item	2961029	et	4	main
see	doc_975151536917_item	2961035	et	3	main
kirikuteenistus	doc_975151536917_item	2961037	et	3	main
ei	doc_975151536917_item	2961039	et	4	main
olnud	doc_975151536917_item	2961040	et	4	main
16	doc_975151536917_item	2961047	et	2	main
sajandist	doc_975151536917_item	2961048	et	3	main
on	doc_975151536917_item	2961049	et	4	main
vaatamata	doc_975151536917_item	2961055	et	4	main
samastasid	doc_975151536917_item	2961059	et	4	main
tavapäradega	doc_975151536917_item	2961062	et	3	main
põhjustest	doc_975151536917_item	2961077	et	3	main
selge	doc_975151536917_item	2961089	et	4	main
ka	doc_975151536917_item	2961034	et	3	main
et	doc_975151536917_item	2961036	et	3	main
algusest	doc_975151536917_item	2961038	et	4	main
ainult	doc_975151536917_item	2961045	et	4	main
alates	doc_975151536917_item	2961046	et	3	main
sellele	doc_975151536917_item	2961056	et	4	main
kõike	doc_975151536917_item	2961074	et	4	main
on	doc_975151536917_item	2961078	et	4	main
et	doc_975151536917_item	2961081	et	3	main
ristiusustamine	doc_975151536917_item	2961082	et	3	main
käis	doc_975151536917_item	2961083	et	4	main
paganatele	doc_975151536917_item	2961086	et	3	main
paljud	doc_975151536917_item	2961091	et	3	main
tavad	doc_975151536917_item	2961092	et	3	main
mis	doc_975151536917_item	2961093	et	4	main
olid	doc_975151536917_item	2961094	et	4	main
neile	doc_975151536917_item	2961095	et	4	main
omased	doc_975151536917_item	2961096	et	3	main
nüüd	doc_975151536917_item	2961097	et	4	main
keelati	doc_975151536917_item	2961098	et	4	main
ära	doc_975151536917_item	2961099	et	4	main
näiteks	doc_975151536917_item	2961100	et	4	main
oli	doc_975151536917_item	2961101	et	3	main
keelatud	doc_975151536917_item	2961102	et	4	main
mitme	doc_975151536917_item	2961103	et	4	main
naise	doc_975151536917_item	2961104	et	3	main
pidamine	doc_975151536917_item	2961105	et	4	main
surnute	doc_975151536917_item	2961106	et	4	main
matmine	doc_975151536917_item	2961107	et	4	main
toimus	doc_975151536917_item	2961108	et	3	main
kirikukalmistutel	doc_975151536917_item	2961109	et	3	main
see	doc_975151536917_item	2961110	et	3	main
ei	doc_975151536917_item	2961111	et	4	main
olnud	doc_975151536917_item	2961112	et	4	main
meeltmööda	doc_975151536917_item	2961113	et	3	main
ka	doc_975151536917_item	2961114	et	3	main
see	doc_975151536917_item	2961115	et	3	main
et	doc_975151536917_item	2961116	et	3	main
veretasu	doc_975151536917_item	2961118	et	4	main
oli	doc_975151536917_item	2961119	et	3	main
keelati	doc_975151536917_item	2961117	et	4	main
eestlastele	doc_975151536917_item	2961120	et	4	main
1143	doc_975151536917_item	2961125	et	2	main
rajati	doc_975151536917_item	2961127	et	3	main
mis	doc_975151536917_item	2961129	et	4	main
sa	doc_975151536917_item	2961130	et	3	main
mõne	doc_975151536917_item	2961131	et	3	main
aasta	doc_975151536917_item	2961132	et	4	main
tallinn	doc_975151536917_item	2961154	et	4	main
viljandi	doc_975151536917_item	2961159	et	4	main
venemaa	doc_975151536917_item	2961160	et	4	main
hansaliidu	doc_975151536917_item	2961161	et	3	main
keskpunktiks	doc_975151536917_item	2961135	et	4	main
hansaliidu	doc_975151536917_item	2961139	et	3	main
liikmed	doc_975151536917_item	2961140	et	3	main
põhja	doc_975151536917_item	2961142	et	4	main
liivimaal	doc_975151536917_item	2961147	et	4	main
hansaliitu	doc_975151536917_item	2961151	et	4	main
uus	doc_975151536917_item	2961156	et	3	main
ja	doc_975151536917_item	2961158	et	3	main
kasulik	doc_975151536917_item	2961168	et	3	main
siis	doc_975151536917_item	2961170	et	3	main
soola	doc_975151536917_item	2961173	et	4	main
kallist	doc_975151536917_item	2961174	et	4	main
riiet	doc_975151536917_item	2961175	et	3	main
heeringat	doc_975151536917_item	2961176	et	3	main
vürtse	doc_975151536917_item	2961177	et	3	main
humalat	doc_975151536917_item	2961178	et	3	main
ja	doc_975151536917_item	2961179	et	3	main
veine	doc_975151536917_item	2961180	et	3	main
eestlased	doc_975151536917_item	2961181	et	3	main
aga	doc_975151536917_item	2961182	et	3	main
viisid	doc_975151536917_item	2961183	et	4	main
välja	doc_975151536917_item	2961184	et	4	main
vaha	doc_975151536917_item	2961185	et	4	main
karusnahka	doc_975151536917_item	2961186	et	4	main
ja	doc_975151536917_item	2961188	et	3	main
kanepit	doc_975151536917_item	2961189	et	3	main
lina	doc_975151536917_item	2961187	et	4	main
kontrolltöö	doc_975151536918_item	2961190	et	4	main
kontrolltöö	doc_975151536918_item	2961191	et	4	main
eesti	doc_975151536918_item	2961192	et	4	main
kultuuriloost	doc_975151536918_item	2961193	et	4	main
1	doc_975151536918_item	2961194	et	2	main
missugune	doc_975151536918_item	2961195	et	3	main
keskpunkt	doc_975151536917_item	2961162	et	3	main
oli	doc_975151536917_item	2961163	et	3	main
keskaegne	doc_975151536918_item	2961197	et	3	main
miks	doc_975151536918_item	2961200	et	4	main
sõda	doc_975151536918_item	2961204	et	4	main
keskaeg	doc_975151536918_item	2961207	et	3	main
13-16	doc_975151536918_item	2961209	et	2	main
200	doc_975151536918_item	2961215	et	2	main
nii	doc_975151536918_item	2961217	et	3	main
tallinn	doc_975151536918_item	2961228	et	4	main
kus	doc_975151536918_item	2961229	et	3	main
6-8	doc_975151536918_item	2961231	et	2	main
igas	doc_975151536918_item	2961234	et	3	main
linnadeks	doc_975151536918_item	2961237	et	3	main
viljandi	doc_975151536918_item	2961241	et	4	main
kõik	doc_975151536918_item	2961242	et	4	main
need	doc_975151536918_item	2961243	et	3	main
transiitlinn	doc_975151536918_item	2961252	et	3	main
teravili	doc_975151536918_item	2961257	et	3	main
kala	doc_975151536918_item	2961258	et	4	main
aastaks	doc_975151536918_item	2961281	et	4	main
linnaosakonnad	doc_975151536918_item	2961283	et	4	main
võim	doc_975151536918_item	2961287	et	3	main
kirik	doc_975151536918_item	2961290	et	3	main
suur	doc_975151536918_item	2961293	et	3	main
kirik	doc_975151536918_item	2961295	et	3	main
kohtn	doc_975151536918_item	2961300	et	4	main
piiskopi	doc_975151536918_item	2961303	et	4	main
korraldusel	doc_975151536918_item	2961304	et	4	main
visitatsioonid	doc_975151536918_item	2961305	et	3	main
haridus	doc_975151536918_item	2961306	et	3	main
toomkoolid	doc_975151536918_item	2961307	et	3	main
ja	doc_975151536918_item	2961308	et	3	main
tallinnas	doc_975151536918_item	2961332	et	4	main
pühavaimu	doc_975151536918_item	2961337	et	4	main
kirik	doc_975151536918_item	2961338	et	3	main
elasid	doc_975151536918_item	2961341	et	4	main
suhteliselt	doc_975151536918_item	2961342	et	4	main
hästi	doc_975151536918_item	2961343	et	3	main
peenemate	doc_975151536918_item	2961356	et	4	main
tööga	doc_975151536918_item	2961357	et	3	main
tegelesid	doc_975151536918_item	2961358	et	4	main
meistrid	doc_975151536918_item	2961362	et	3	main
eesti	doc_975151536918_item	2961369	et	4	main
väga	doc_975151536918_item	2961371	et	3	main
maa	doc_975151536918_item	2961373	et	4	main
sest	doc_975151536918_item	2961374	et	4	main
see	doc_975151536918_item	2961375	et	3	main
oli	doc_975151536918_item	2961376	et	3	main
väljapääs	doc_975151536918_item	2961377	et	3	main
toimus	doc_975151536918_item	2961385	et	3	main
iv	doc_975151536918_item	2961394	et	4	main
1573	doc_975151536918_item	2961395	et	2	main
venemaale	doc_975151536918_item	2961401	et	4	main
oli	doc_975151536918_item	2961402	et	3	main
mitmed	doc_975151536918_item	2961426	et	4	main
venemaa	doc_975151536918_item	2961428	et	4	main
rootsi	doc_975151536918_item	2961430	et	4	main
venemaa	doc_975151536918_item	2961431	et	4	main
ja	doc_975151536918_item	2961437	et	3	main
talle	doc_975151536918_item	2961438	et	4	main
keskpaik	doc_975151536918_item	2961449	et	3	main
tartu	doc_975151536918_item	2961452	et	4	main
ja	doc_975151536918_item	2961453	et	3	main
jäi	doc_975151536918_item	2961461	et	3	main
rootsi	doc_975151536918_item	2961462	et	4	main
linnakultuur	doc_975151536918_item	2961198	et	3	main
sa	doc_975151536918_item	2961201	et	3	main
vene-liivi	doc_975151536918_item	2961203	et	4	main
keskaegne	doc_975151536918_item	2961205	et	3	main
linnakultuur	doc_975151536918_item	2961206	et	3	main
oli	doc_975151536918_item	2961208	et	3	main
kui	doc_975151536918_item	2961219	et	3	main
suuruseks	doc_975151536918_item	2961236	et	4	main
hansaliitu	doc_975151536918_item	2961245	et	4	main
kaubanduslik	doc_975151536918_item	2961246	et	3	main
liit	doc_975151536918_item	2961247	et	3	main
tallinn	doc_975151536918_item	2961248	et	4	main
oli	doc_975151536918_item	2961249	et	3	main
väga	doc_975151536918_item	2961250	et	3	main
tähtis	doc_975151536918_item	2961251	et	4	main
valiti	doc_975151536918_item	2961279	et	3	main
vaimulikud	doc_975151536918_item	2961297	et	3	main
teostas	doc_975151536918_item	2961302	et	3	main
14	doc_975151536918_item	2961311	et	2	main
saj	doc_975151536918_item	2961312	et	4	main
hakatakse	doc_975151536918_item	2961313	et	3	main
nad	doc_975151536918_item	2961344	et	3	main
käsitööliste	doc_975151536918_item	2961349	et	4	main
eestlased	doc_975151536918_item	2961351	et	3	main
tegelesid	doc_975151536918_item	2961352	et	4	main
teisest	doc_975151536918_item	2961359	et	4	main
2	doc_975151536918_item	2961363	et	2	main
sai	doc_975151536918_item	2961365	et	4	main
võimalikuks	doc_975151536918_item	2961366	et	3	main
vene-liivi	doc_975151536918_item	2961367	et	4	main
e	doc_975151536918_item	2961379	et	4	main
euroopaga	doc_975151536918_item	2961382	et	3	main
saj	doc_975151536918_item	2961389	et	4	main
keskpaik	doc_975151536918_item	2961390	et	3	main
troonike	doc_975151536918_item	2961391	et	4	main
pääseb	doc_975151536918_item	2961392	et	3	main
ivo	doc_975151536918_item	2961397	et	4	main
pirita	doc_975151536918_item	2961421	et	4	main
eesti	doc_975151536918_item	2961423	et	4	main
jäigi	doc_975151536918_item	2961439	et	4	main
alguses	doc_975151536918_item	2961440	et	4	main
rootsi	doc_975151536918_item	2961450	et	4	main
aja	doc_975151536918_item	2961455	et	4	main
kätte	doc_975151536918_item	2961463	et	4	main
kontrolltöö	doc_975151536920_item	2961628	et	4	main
1	doc_975151536920_item	2961629	et	2	main
viikingiaeg	doc_975151536920_item	2961630	et	3	main
algas	doc_975151536920_item	2961641	et	3	main
aastal	doc_975151536920_item	2961643	et	3	main
kõige	doc_975151536918_item	2961222	et	4	main
linnad	doc_975151536918_item	2961224	et	3	main
keskmise	doc_975151536918_item	2961235	et	3	main
olid	doc_975151536918_item	2961238	et	4	main
pärnu	doc_975151536918_item	2961239	et	4	main
ja	doc_975151536918_item	2961240	et	3	main
mis	doc_975151536918_item	2961254	et	4	main
lina	doc_975151536918_item	2961260	et	4	main
sisse	doc_975151536918_item	2961261	et	4	main
kangad	doc_975151536918_item	2961264	et	3	main
raud	doc_975151536918_item	2961265	et	3	main
heringas	doc_975151536918_item	2961266	et	4	main
võimu	doc_975151536918_item	2961267	et	4	main
korraldus	doc_975151536918_item	2961268	et	4	main
linnas	doc_975151536918_item	2961269	et	4	main
raat	doc_975151536918_item	2961270	et	3	main
e	doc_975151536918_item	2961271	et	4	main
magitraat	doc_975151536918_item	2961272	et	4	main
kõrgeim	doc_975151536918_item	2961273	et	4	main
valituseüksus	doc_975151536918_item	2961274	et	4	main
24	doc_975151536918_item	2961275	et	2	main
inimest	doc_975151536918_item	2961276	et	3	main
ja	doc_975151536918_item	2961277	et	3	main
neid	doc_975151536918_item	2961278	et	4	main
oli	doc_975151536918_item	2961288	et	3	main
üheks	doc_975151536918_item	2961280	et	3	main
gildid	doc_975151536918_item	2961284	et	3	main
millel	doc_975151536918_item	2961291	et	3	main
kes	doc_975151536918_item	2961298	et	4	main
pidasid	doc_975151536918_item	2961299	et	4	main
kirik	doc_975151536918_item	2961301	et	3	main
koolid	doc_975151536918_item	2961310	et	3	main
selle	doc_975151536918_item	2961316	et	4	main
et	doc_975151536918_item	2961318	et	3	main
haridust	doc_975151536918_item	2961319	et	4	main
tuleb	doc_975151536918_item	2961320	et	3	main
saama	doc_975151536918_item	2961321	et	4	main
esimesed	doc_975151536918_item	2961323	et	3	main
rändmungad	doc_975151536918_item	2961324	et	3	main
eks	doc_975151536918_item	2961325	et	3	main
olid	doc_975151536918_item	2961326	et	4	main
ka	doc_975151536918_item	2961327	et	3	main
maaelanikele	doc_975151536918_item	2961328	et	3	main
arstina	doc_975151536918_item	2961329	et	3	main
rajati	doc_975151536918_item	2961333	et	3	main
kirik	doc_975151536918_item	2961336	et	3	main
linnaelanikud	doc_975151536918_item	2961340	et	3	main
kuuluma	doc_975151536918_item	2961346	et	3	main
gildisse	doc_975151536918_item	2961348	et	3	main
kuid	doc_975151536918_item	2961355	et	4	main
euroopa	doc_975151536918_item	2961360	et	4	main
hea	doc_975151536918_item	2961372	et	4	main
hea	doc_975151536918_item	2961380	et	4	main
transiitmaa	doc_975151536918_item	2961381	et	4	main
1558	doc_975151536918_item	2961383	et	2	main
a	doc_975151536918_item	2961384	et	4	main
liivi	doc_975151536918_item	2961386	et	4	main
sõda	doc_975151536918_item	2961387	et	4	main
16	doc_975151536918_item	2961388	et	2	main
vajalik	doc_975151536918_item	2961403	et	3	main
klooster	doc_975151536918_item	2961422	et	3	main
poola	doc_975151536918_item	2961429	et	4	main
eestimaa	doc_975151536918_item	2961435	et	4	main
vallutamiseks	doc_975151536918_item	2961436	et	4	main
saj	doc_975151536918_item	2961448	et	4	main
vallutas	doc_975151536918_item	2961451	et	3	main
mõne	doc_975151536918_item	2961454	et	3	main
pärast	doc_975151536918_item	2961456	et	4	main
lepinguga	doc_975151536918_item	2961457	et	3	main
kõik	doc_975151536918_item	2961458	et	4	main
algas	doc_975151536918_item	2961464	et	3	main
kõigile	doc_975151536918_item	2961322	et	4	main
andsid	doc_975151536918_item	2961330	et	4	main
kirikud	doc_975151536918_item	2961334	et	3	main
peamiselt	doc_975151536918_item	2961353	et	4	main
käsitööga	doc_975151536918_item	2961354	et	3	main
sõda	doc_975151536918_item	2961368	et	4	main
läänemerele	doc_975151536918_item	2961378	et	3	main
a	doc_975151536918_item	2961396	et	4	main
schenkenberg	doc_975151536918_item	2961398	et	4	main
oli	doc_975151536918_item	2961399	et	3	main
eestimaal	doc_975151536918_item	2961400	et	4	main
eesti	doc_975151536918_item	2961404	et	4	main
selleks	doc_975151536918_item	2961405	et	4	main
et	doc_975151536918_item	2961406	et	3	main
saada	doc_975151536918_item	2961407	et	4	main
väljapääsu	doc_975151536918_item	2961408	et	4	main
balti	doc_975151536918_item	2961409	et	3	main
riigile	doc_975151536918_item	2961410	et	3	main
ja	doc_975151536918_item	2961411	et	3	main
euroopasse	doc_975151536918_item	2961412	et	3	main
eesti	doc_975151536918_item	2961413	et	4	main
oli	doc_975151536918_item	2961414	et	3	main
heaks	doc_975151536918_item	2961415	et	4	main
transiidimaaks	doc_975151536918_item	2961416	et	3	main
kauplemise	doc_975151536918_item	2961417	et	4	main
jaoks	doc_975151536918_item	2961418	et	4	main
1578a	doc_975151536918_item	2961419	et	4	main
pommitati	doc_975151536918_item	2961420	et	4	main
pärast	doc_975151536918_item	2961424	et	4	main
riigid	doc_975151536918_item	2961427	et	3	main
esimesed	doc_975151536918_item	2961433	et	3	main
17	doc_975151536918_item	2961447	et	2	main
eesti	doc_975151536918_item	2961459	et	4	main
rootsi	doc_975151536918_item	2961465	et	4	main
mingi	doc_975151536918_item	2961347	et	4	main
liit	doc_975151536918_item	2961350	et	3	main
riikidest	doc_975151536918_item	2961361	et	3	main
miks	doc_975151536918_item	2961364	et	4	main
oli	doc_975151536918_item	2961370	et	3	main
ivan	doc_975151536918_item	2961393	et	4	main
võitlesid	doc_975151536918_item	2961425	et	4	main
tegi	doc_975151536918_item	2961432	et	4	main
sammud	doc_975151536918_item	2961434	et	4	main
peamine	doc_975151536918_item	2961441	et	3	main
eestimaa	doc_975151536918_item	2961442	et	4	main
territoorium	doc_975151536918_item	2961443	et	3	main
lõuna-eesti	doc_975151536918_item	2961444	et	4	main
jäi	doc_975151536918_item	2961445	et	3	main
poolale	doc_975151536918_item	2961446	et	4	main
ala	doc_975151536918_item	2961460	et	4	main
aeg	doc_975151536918_item	2961466	et	3	main
eesti	doc_975151536920_item	2961639	et	4	main
territooriumil	doc_975151536920_item	2961640	et	3	main
800	doc_975151536920_item	2961642	et	2	main
leidnus	doc_975151536920_item	2961662	et	4	main
selle	doc_975151536920_item	2961664	et	4	main
viikingutele	doc_975151536920_item	2961667	et	4	main
600	doc_975151536920_item	2961675	et	2	main
eestis	doc_975151536920_item	2961680	et	3	main
leidus	doc_975151536920_item	2961681	et	4	main
ka	doc_975151536920_item	2961682	et	3	main
sellest	doc_975151536920_item	2961686	et	4	main
ingvar	doc_975151536920_item	2961689	et	4	main
ja	doc_975151536920_item	2961692	et	3	main
maetud	doc_975151536920_item	2961694	et	4	main
kuskil	doc_975151536920_item	2961695	et	3	main
nüüdses	doc_975151536920_item	2961696	et	3	main
plaatkivist	doc_975151536920_item	2961722	et	4	main
olid	doc_975151536920_item	2961734	et	4	main
ja	doc_975151536920_item	2961741	et	3	main
olid	doc_975151536920_item	2961751	et	4	main
peidetud	doc_975151536920_item	2961752	et	4	main
vaenlaste	doc_975151536920_item	2961753	et	3	main
eest	doc_975151536920_item	2961754	et	4	main
aaretes	doc_975151536920_item	2961755	et	3	main
oma	doc_975151536920_item	2961769	et	4	main
sellest	doc_975151536920_item	2961779	et	4	main
märke	doc_975151536920_item	2961818	et	4	main
tähestikus	doc_975151536920_item	2961820	et	3	main
nurgalised	doc_975151536920_item	2961826	et	4	main
kergem	doc_975151536920_item	2961831	et	4	main
lüüa	doc_975151536920_item	2961832	et	3	main
ladusid	doc_975151536920_item	2961840	et	4	main
kividest	doc_975151536920_item	2961841	et	3	main
tuhka	doc_975151536920_item	2961849	et	4	main
kivide	doc_975151536920_item	2961850	et	3	main
enne	doc_975151536920_item	2961853	et	4	main
kolm	doc_975151536920_item	2961856	et	3	main
ajal	doc_975151536920_item	2961863	et	4	main
rajas	doc_975151536920_item	2961874	et	4	main
uue	doc_975151536920_item	2961875	et	3	main
jurjev	doc_975151536920_item	2961877	et	4	main
olid	doc_975151536920_item	2961879	et	4	main
paadi	doc_975151536920_item	2961888	et	3	main
tuule	doc_975151536920_item	2961895	et	3	main
rõivad	doc_975151536920_item	2961900	et	3	main
nad	doc_975151536920_item	2961921	et	3	main
hävitasid	doc_975151536920_item	2961927	et	4	main
koos	doc_975151536920_item	2961929	et	4	main
2	doc_975151536920_item	2961931	et	2	main
7500	doc_975151536920_item	2961933	et	2	main
ajalugu	doc_975151536920_item	2961939	et	4	main
mis	doc_975151536920_item	2961940	et	4	main
arheoloogiliste	doc_975151536920_item	2961944	et	4	main
leiutiste	doc_975151536920_item	2961945	et	3	main
muinasaeg	doc_975151536920_item	2961947	et	3	main
lõppeb	doc_975151536920_item	2961948	et	3	main
vaadeldab	doc_975151536920_item	2961958	et	4	main
matmiskombed	doc_975151536920_item	2961963	et	3	main
mina	doc_980560860245_item	2961970	et	4	main
kittarist	doc_980560860245_item	2961984	et	4	main
ma	doc_980560860245_item	2961985	et	3	main
keith	doc_980560860245_item	2961995	et	4	main
ma	doc_980560860245_item	2961997	et	3	main
1943	doc_980560860245_item	2962003	et	2	main
ma	doc_980560860245_item	2962005	et	3	main
ronnie	doc_980560860245_item	2962017	et	4	main
ronnie	doc_980560860245_item	2962018	et	4	main
mõiste	doc_975151536920_item	2961634	et	4	main
muinasaeg	doc_975151536920_item	2961635	et	3	main
lõpes	doc_975151536920_item	2961645	et	3	main
vastanud	doc_975151536920_item	2961656	et	4	main
tõele	doc_975151536920_item	2961657	et	4	main
teadlased	doc_975151536920_item	2961658	et	3	main
ja	doc_975151536920_item	2961659	et	3	main
asitõendeid	doc_975151536920_item	2961663	et	3	main
viikingute	doc_975151536920_item	2961671	et	4	main
dateeritud	doc_975151536920_item	2961674	et	4	main
retk	doc_975151536920_item	2961678	et	3	main
eestisse	doc_975151536920_item	2961679	et	4	main
räägib	doc_975151536920_item	2961685	et	3	main
sel	doc_975151536920_item	2961699	et	3	main
linnuseid	doc_975151536920_item	2961707	et	3	main
linnus	doc_975151536920_item	2961723	et	4	main
voorete	doc_975151536920_item	2961726	et	4	main
pool	doc_975151536920_item	2961732	et	4	main
vallid	doc_975151536920_item	2961733	et	3	main
oma	doc_975151536920_item	2961739	et	4	main
karju	doc_975151536920_item	2961740	et	4	main
metallesmeid	doc_975151536920_item	2961742	et	4	main
mis	doc_975151536920_item	2961750	et	4	main
relvi	doc_975151536920_item	2961770	et	4	main
aaretes	doc_975151536920_item	2961771	et	3	main
viikingute	doc_975151536920_item	2961775	et	4	main
pärit	doc_975151536920_item	2961776	et	3	main
see	doc_975151536920_item	2961777	et	3	main
räägib	doc_975151536920_item	2961778	et	3	main
eestlastel	doc_975151536920_item	2961781	et	4	main
alusel	doc_975151536920_item	2961813	et	4	main
kõik	doc_975151536920_item	2961814	et	4	main
piltkivid	doc_975151536920_item	2961815	et	3	main
olid	doc_975151536920_item	2961816	et	4	main
märke	doc_975151536920_item	2961823	et	4	main
selliseid	doc_975151536920_item	2961828	et	4	main
märke	doc_975151536920_item	2961829	et	4	main
mattuse	doc_975151536920_item	2961835	et	4	main
põletati	doc_975151536920_item	2961854	et	3	main
eksisteerivaid	doc_975151536920_item	2961864	et	4	main
riirikovitš	doc_975151536920_item	2961867	et	2	main
vallandaslinnuse	doc_975151536920_item	2961872	et	4	main
linna	doc_975151536920_item	2961876	et	4	main
viikingutel	doc_975151536920_item	2961878	et	4	main
purjedega	doc_975151536920_item	2961887	et	3	main
laev	doc_975151536920_item	2961893	et	3	main
sõudmise	doc_975151536920_item	2961897	et	4	main
eesti	doc_975151536920_item	2961631	et	4	main
territooriumil	doc_975151536920_item	2961632	et	3	main
2	doc_975151536920_item	2961633	et	2	main
ja	doc_975151536920_item	2961644	et	3	main
retkedest	doc_975151536920_item	2961648	et	3	main
arheoloogid	doc_975151536920_item	2961660	et	3	main
esimene	doc_975151536920_item	2961670	et	3	main
oli	doc_975151536920_item	2961673	et	3	main
mis	doc_975151536920_item	2961684	et	4	main
kunigas	doc_975151536920_item	2961688	et	4	main
hukkus	doc_975151536920_item	2961690	et	3	main
on	doc_975151536920_item	2961693	et	4	main
tähendus	doc_975151536920_item	2961636	et	4	main
1	doc_975151536920_item	2961637	et	2	main
viikingiaeg	doc_975151536920_item	2961638	et	3	main
1050	doc_975151536920_item	2961646	et	2	main
viingute	doc_975151536920_item	2961647	et	4	main
eesti	doc_975151536920_item	2961649	et	4	main
territooriumile	doc_975151536920_item	2961650	et	3	main
räägivad	doc_975151536920_item	2961651	et	3	main
saagad	doc_975151536920_item	2961652	et	3	main
mis	doc_975151536920_item	2961653	et	4	main
mõnikord	doc_975151536920_item	2961654	et	3	main
ei	doc_975151536920_item	2961655	et	4	main
kohta	doc_975151536920_item	2961665	et	4	main
hukkunutele	doc_975151536920_item	2961666	et	4	main
püstitati	doc_975151536920_item	2961668	et	4	main
retk	doc_975151536920_item	2961672	et	3	main
a	doc_975151536920_item	2961676	et	4	main
ingvari	doc_975151536920_item	2961677	et	4	main
et	doc_975151536920_item	2961687	et	3	main
lahingus	doc_975151536920_item	2961691	et	3	main
territooriumil	doc_975151536920_item	2961698	et	3	main
tüüpi	doc_975151536920_item	2961706	et	4	main
tavaliselt	doc_975151536920_item	2961708	et	4	main
nad	doc_975151536920_item	2961709	et	3	main
olid	doc_975151536920_item	2961710	et	4	main
ehitatud	doc_975151536920_item	2961711	et	4	main
looduslikult	doc_975151536920_item	2961712	et	4	main
kaitstud	doc_975151536920_item	2961713	et	4	main
alades	doc_975151536920_item	2961714	et	3	main
künkade	doc_975151536920_item	2961715	et	4	main
peal	doc_975151536920_item	2961716	et	4	main
linnus	doc_975151536920_item	2961717	et	4	main
otepää	doc_975151536920_item	2961718	et	4	main
kunstiliselt	doc_975151536920_item	2961719	et	4	main
ehitatud	doc_975151536920_item	2961720	et	4	main
kuivkünkad	doc_975151536920_item	2961721	et	3	main
saaremaal	doc_975151536920_item	2961725	et	4	main
peal	doc_975151536920_item	2961727	et	4	main
ehitatud	doc_975151536920_item	2961728	et	4	main
linnused	doc_975151536920_item	2961729	et	3	main
kus	doc_975151536920_item	2961730	et	3	main
ajast	doc_975151536920_item	2961745	et	4	main
relvi	doc_975151536920_item	2961759	et	4	main
tavaks	doc_975151536920_item	2961765	et	3	main
oli	doc_975151536920_item	2961766	et	3	main
et	doc_975151536920_item	2961780	et	3	main
tekkisid	doc_975151536920_item	2961782	et	4	main
26	doc_975151536920_item	2961822	et	2	main
nad	doc_975151536920_item	2961824	et	3	main
viikingute	doc_975151536920_item	2961834	et	4	main
haudu	doc_975151536920_item	2961844	et	4	main
ja	doc_975151536920_item	2961845	et	3	main
purskati	doc_975151536920_item	2961846	et	3	main
oma	doc_975151536920_item	2961847	et	4	main
surnuid	doc_975151536920_item	2961852	et	4	main
jaroslav	doc_975151536920_item	2961870	et	4	main
sõiduvahendid	doc_975151536920_item	2961881	et	3	main
viikingulaevad	doc_975151536920_item	2961882	et	4	main
nad	doc_975151536920_item	2961883	et	3	main
oid	doc_975151536920_item	2961884	et	3	main
varustatud	doc_975151536920_item	2961885	et	4	main
esimestega	doc_975151536920_item	2961886	et	3	main
külge	doc_975151536920_item	2961889	et	4	main
olid	doc_975151536920_item	2961890	et	4	main
liikus	doc_975151536920_item	2961894	et	3	main
ja	doc_975151536920_item	2961896	et	3	main
nendega	doc_975151536920_item	2961923	et	4	main
a	doc_975151536920_item	2961925	et	4	main
ei	doc_975151536920_item	2961661	et	4	main
piltkive	doc_975151536920_item	2961669	et	3	main
kivipilt	doc_975151536920_item	2961683	et	3	main
harjumaakonna	doc_975151536920_item	2961697	et	4	main
ajal	doc_975151536920_item	2961700	et	4	main
eesti	doc_975151536920_item	2961701	et	4	main
territooriumil	doc_975151536920_item	2961702	et	3	main
ilmuvad	doc_975151536920_item	2961703	et	4	main
linnused	doc_975151536920_item	2961704	et	3	main
4	doc_975151536920_item	2961705	et	2	main
kahel	doc_975151536920_item	2961731	et	4	main
kunstlikult	doc_975151536920_item	2961736	et	4	main
eestlased	doc_975151536920_item	2961737	et	3	main
sellest	doc_975151536920_item	2961744	et	4	main
alustasid	doc_975151536920_item	2961746	et	4	main
elu	doc_975151536920_item	2961748	et	4	main
jane	doc_975151536920_item	2961760	et	4	main
leiduvad	doc_975151536920_item	2961772	et	4	main
ka	doc_975151536920_item	2961773	et	3	main
ladina	doc_975151536920_item	2961810	et	4	main
keele	doc_975151536920_item	2961811	et	4	main
tähestiku	doc_975151536920_item	2961812	et	3	main
täis	doc_975151536920_item	2961817	et	4	main
oli	doc_975151536920_item	2961821	et	3	main
olid	doc_975151536920_item	2961825	et	4	main
sest	doc_975151536920_item	2961827	et	4	main
sisse	doc_975151536920_item	2961833	et	4	main
ristliku	doc_975151536920_item	2961842	et	4	main
vormidega	doc_975151536920_item	2961843	et	3	main
vahele	doc_975151536920_item	2961851	et	4	main
olid	doc_975151536920_item	2961858	et	4	main
kutsutud	doc_975151536920_item	2961859	et	4	main
territoriaalseid	doc_975151536920_item	2961865	et	3	main
üksusi	doc_975151536920_item	2961866	et	3	main
1030	doc_975151536920_item	2961868	et	2	main
a	doc_975151536920_item	2961869	et	4	main
ja	doc_975151536920_item	2961873	et	3	main
omapärased	doc_975151536920_item	2961880	et	4	main
riputatud	doc_975151536920_item	2961891	et	4	main
abil	doc_975151536920_item	2961898	et	4	main
viikingute	doc_975151536920_item	2961899	et	4	main
kauplesid	doc_975151536920_item	2961922	et	4	main
1187	doc_975151536920_item	2961924	et	2	main
vaadeldab	doc_975151536920_item	2961937	et	4	main
teostatut	doc_975151536920_item	2961942	et	4	main
muinasaeg	doc_975151536920_item	2961957	et	3	main
arengut	doc_975151536920_item	2961960	et	3	main
elamud	doc_975151536920_item	2961961	et	3	main
ronnie	doc_980560860245_item	2961965	et	4	main
ronnie	doc_980560860245_item	2961972	et	4	main
olen	doc_980560860245_item	2961974	et	3	main
olen	doc_980560860245_item	2961978	et	3	main
olen	doc_980560860245_item	2961982	et	3	main
tegen	doc_980560860245_item	2961986	et	4	main
minu	doc_980560860245_item	2961992	et	3	main
olen	doc_980560860245_item	2962006	et	3	main
oled	doc_980560860245_item	2962016	et	3	main
kui	doc_980560860245_item	2962022	et	3	main
nägemist	doc_980560860245_item	2962034	et	4	main
asva	doc_975151536920_item	2961724	et	4	main
vajatud	doc_975151536920_item	2961735	et	4	main
kaitsesid	doc_975151536920_item	2961738	et	4	main
just	doc_975151536920_item	2961743	et	3	main
oma	doc_975151536920_item	2961747	et	4	main
aared	doc_975151536920_item	2961749	et	4	main
leiuti	doc_975151536920_item	2961756	et	4	main
münte	doc_975151536920_item	2961757	et	3	main
ehteid	doc_975151536920_item	2961758	et	3	main
pärast	doc_975151536920_item	2961761	et	4	main
edukat	doc_975151536920_item	2961762	et	3	main
lahingud	doc_975151536920_item	2961763	et	3	main
eestlastel	doc_975151536920_item	2961764	et	4	main
kaevata	doc_975151536920_item	2961767	et	4	main
siise	doc_975151536920_item	2961768	et	4	main
ehted	doc_975151536920_item	2961774	et	3	main
kaubandussuhted	doc_975151536920_item	2961783	et	3	main
skandinaaviaga	doc_975151536920_item	2961784	et	4	main
juba	doc_975151536920_item	2961785	et	3	main
rooma	doc_975151536920_item	2961786	et	4	main
rauaajal	doc_975151536920_item	2961787	et	3	main
vahetati	doc_975151536920_item	2961788	et	4	main
karusnahke	doc_975151536920_item	2961789	et	3	main
mõned	doc_975151536920_item	2961790	et	3	main
teadlased	doc_975151536920_item	2961791	et	3	main
arvavad	doc_975151536920_item	2961792	et	4	main
et	doc_975151536920_item	2961793	et	3	main
eestlaste	doc_975151536920_item	2961794	et	4	main
jumal	doc_975151536920_item	2961795	et	3	main
tarapita	doc_975151536920_item	2961796	et	4	main
tara	doc_975151536920_item	2961797	et	4	main
on	doc_975151536920_item	2961798	et	4	main
pärit	doc_975151536920_item	2961799	et	3	main
viikingutelt	doc_975151536920_item	2961800	et	4	main
kelle	doc_975151536920_item	2961801	et	4	main
jumal	doc_975151536920_item	2961802	et	3	main
oli	doc_975151536920_item	2961803	et	3	main
thor	doc_975151536920_item	2961804	et	4	main
viikingutel	doc_975151536920_item	2961805	et	4	main
oli	doc_975151536920_item	2961806	et	3	main
oma	doc_975151536920_item	2961807	et	4	main
tähestik	doc_975151536920_item	2961808	et	3	main
loodud	doc_975151536920_item	2961809	et	4	main
ruunid	doc_975151536920_item	2961819	et	3	main
on	doc_975151536920_item	2961830	et	4	main
rituaal	doc_975151536920_item	2961836	et	3	main
oli	doc_975151536920_item	2961837	et	3	main
omapärane	doc_975151536920_item	2961838	et	4	main
nad	doc_975151536920_item	2961839	et	3	main
surnute	doc_975151536920_item	2961848	et	4	main
882	doc_975151536920_item	2961855	et	2	main
viikinug	doc_975151536920_item	2961857	et	4	main
venemaale	doc_975151536920_item	2961860	et	4	main
ühendada	doc_975151536920_item	2961861	et	3	main
tol	doc_975151536920_item	2961862	et	3	main
tark	doc_975151536920_item	2961871	et	3	main
kilbid	doc_975151536920_item	2961892	et	3	main
olid	doc_975151536920_item	2961901	et	4	main
nahast	doc_975151536920_item	2961902	et	4	main
tehtut	doc_975151536920_item	2961903	et	4	main
kiivrid	doc_975151536920_item	2961904	et	3	main
teravad	doc_975151536920_item	2961905	et	3	main
rauast	doc_975151536920_item	2961906	et	4	main
tehtud	doc_975151536920_item	2961907	et	4	main
mõõgad	doc_975151536920_item	2961908	et	3	main
sõjaretki	doc_975151536920_item	2961909	et	4	main
tegid	doc_975151536920_item	2961910	et	4	main
ainult	doc_975151536920_item	2961911	et	4	main
suvel	doc_975151536920_item	2961912	et	3	main
eestlased	doc_975151536920_item	2961913	et	3	main
olid	doc_975151536920_item	2961914	et	4	main
võimelised	doc_975151536920_item	2961915	et	4	main
vastu	doc_975151536920_item	2961916	et	3	main
seista	doc_975151536920_item	2961917	et	4	main
viikingutele	doc_975151536920_item	2961918	et	4	main
aga	doc_975151536920_item	2961919	et	3	main
siiski	doc_975151536920_item	2961920	et	4	main
eestimaa	doc_975151536920_item	2961938	et	4	main
ainult	doc_975151536920_item	2961943	et	4	main
tööriistad	doc_975151536920_item	2961962	et	3	main
dialoog	doc_980560860245_item	2961964	et	3	main
rolling	doc_980560860245_item	2961987	et	4	main
stones	doc_980560860245_item	2961988	et	4	main
tere	doc_980560860245_item	2961990	et	3	main
nimi	doc_980560860245_item	2961993	et	3	main
olen	doc_980560860245_item	2962001	et	3	main
dartfarlis	doc_980560860245_item	2962004	et	4	main
kuulus	doc_980560860245_item	2962008	et	4	main
kittarist	doc_980560860245_item	2962009	et	4	main
teges	doc_980560860245_item	2962011	et	4	main
hästi	doc_980560860245_item	2962020	et	3	main
vana	doc_980560860245_item	2962023	et	4	main
mina	doc_980560860245_item	2962027	et	4	main
kuuskümmend	doc_980560860245_item	2962029	et	4	main
neli	doc_980560860245_item	2962030	et	3	main
aastat	doc_980560860245_item	2962031	et	3	main
vana	doc_980560860245_item	2962032	et	4	main
aega	doc_980560860245_item	2962037	et	4	main
eestlased	doc_975151536920_item	2961928	et	3	main
liivlastega	doc_975151536920_item	2961930	et	4	main
esimese	doc_975151536920_item	2961949	et	3	main
muinasajavõitlusega	doc_975151536920_item	2961950	et	3	main
muinasajaseset	doc_975151536920_item	2961951	et	4	main
religioonist	doc_975151536920_item	2961952	et	3	main
on	doc_975151536920_item	2961953	et	4	main
teada	doc_975151536920_item	2961954	et	3	main
väga	doc_975151536920_item	2961955	et	3	main
tere	doc_980560860245_item	2961966	et	3	main
siguldat	doc_975151536920_item	2961926	et	4	main
muinasaeg	doc_975151536920_item	2961932	et	3	main
ekr-1227	doc_975151536920_item	2961934	et	4	main
see	doc_975151536920_item	2961935	et	3	main
period	doc_975151536920_item	2961936	et	4	main
on	doc_975151536920_item	2961941	et	4	main
järgi	doc_975151536920_item	2961946	et	4	main
vähe	doc_975151536920_item	2961956	et	3	main
inimeste	doc_975151536920_item	2961959	et	3	main
keef	doc_980560860245_item	2961967	et	4	main
tere	doc_980560860245_item	2961968	et	3	main
ronnie	doc_980560860245_item	2961969	et	4	main
olen	doc_980560860245_item	2961971	et	3	main
wood	doc_980560860245_item	2961973	et	4	main
mina	doc_980560860245_item	2961977	et	4	main
aastat	doc_980560860245_item	2961980	et	3	main
olen	doc_980560860245_item	2961998	et	3	main
mina	doc_980560860245_item	2962000	et	4	main
kes	doc_980560860245_item	2962010	et	4	main
rolling	doc_980560860245_item	2962012	et	4	main
tänan	doc_980560860245_item	2962019	et	3	main
keef	doc_980560860245_item	2962021	et	4	main
ronnie	doc_980560860245_item	2962026	et	4	main
keef	doc_980560860245_item	2962035	et	4	main
sündinud	doc_980560860245_item	2961975	et	4	main
londonis	doc_980560860245_item	2961976	et	4	main
kuuskümmend	doc_980560860245_item	2961979	et	4	main
vana	doc_980560860245_item	2961981	et	4	main
kuulus	doc_980560860245_item	2961983	et	4	main
keef	doc_980560860245_item	2961989	et	4	main
ronnie	doc_980560860245_item	2961991	et	4	main
on	doc_980560860245_item	2961994	et	4	main
richards	doc_980560860245_item	2961996	et	4	main
inglane	doc_980560860245_item	2961999	et	3	main
sündinud	doc_980560860245_item	2962002	et	4	main
ka	doc_980560860245_item	2962007	et	3	main
stones	doc_980560860245_item	2962013	et	4	main
kuidas	doc_980560860245_item	2962014	et	3	main
sa	doc_980560860245_item	2962015	et	3	main
sa	doc_980560860245_item	2962024	et	3	main
ronnie	doc_980560860245_item	2962033	et	4	main
jooksi	doc_980560860248_item	2962256	et	4	main
ja	doc_980560860248_item	2962259	et	3	main
tavaliselt	doc_980560860248_item	2962273	et	4	main
kell	doc_980560860248_item	2962277	et	3	main
kell	doc_980560860248_item	2962282	et	3	main
kas	doc_980560860248_item	2962284	et	3	main
õhtusöögiks	doc_980560860248_item	2962322	et	3	main
kartuleid	doc_980560860248_item	2962323	et	3	main
ja	doc_980560860248_item	2962324	et	3	main
kell	doc_980560860248_item	2962336	et	3	main
loengud	doc_980560860248_item	2962340	et	3	main
ameerikast	doc_980560860248_item	2962348	et	4	main
teie	doc_980560860248_item	2962350	et	4	main
buss	doc_980560860248_item	2962355	et	3	main
väljub	doc_980560860248_item	2962357	et	3	main
12	doc_980560860248_item	2962360	et	2	main
kuhu	doc_980560860248_item	2962361	et	3	main
väljub	doc_980560860248_item	2962362	et	3	main
buss	doc_980560860248_item	2962363	et	3	main
bussijaamast	doc_980560860248_item	2962364	et	4	main
kell	doc_980560860248_item	2962365	et	3	main
12	doc_980560860248_item	2962366	et	2	main
pillel	doc_980560860248_item	2962367	et	3	main
kuhugi	doc_980560860248_item	2962408	et	4	main
perekond	doc_980560860248_item	2962416	et	3	main
soomest	doc_980560860248_item	2962419	et	3	main
oled	doc_980560860245_item	2962025	et	3	main
olen	doc_980560860245_item	2962028	et	3	main
head	doc_980560860245_item	2962036	et	4	main
harjutus	doc_980560860248_item	2962250	et	4	main
verbid	doc_980560860248_item	2962254	et	3	main
ostma	doc_980560860248_item	2962260	et	3	main
leiba	doc_980560860248_item	2962262	et	4	main
10	doc_980560860248_item	2962264	et	2	main
muna	doc_980560860248_item	2962265	et	4	main
ma	doc_980560860248_item	2962266	et	3	main
käin	doc_980560860248_item	2962267	et	3	main
sa	doc_980560860248_item	2962285	et	3	main
algavad	doc_980560860248_item	2962334	et	4	main
meie	doc_980560860248_item	2962343	et	4	main
sõbrad	doc_980560860248_item	2962344	et	3	main
eelmisel	doc_980560860248_item	2962346	et	3	main
kust	doc_980560860248_item	2962349	et	4	main
sõbrad	doc_980560860248_item	2962351	et	3	main
eelmisel	doc_980560860248_item	2962353	et	3	main
käisid	doc_980560860248_item	2962396	et	4	main
reisimas	doc_980560860248_item	2962397	et	3	main
etc	doc_980560860248_item	2962398	et	4	main
peale	doc_980560860248_item	2962409	et	4	main
lapsed	doc_980560860248_item	2962418	et	3	main
ülikoolis	doc_980560860248_item	2962268	et	4	main
ja	doc_980560860248_item	2962269	et	3	main
töötan	doc_980560860248_item	2962270	et	3	main
õhtuti	doc_980560860248_item	2962271	et	3	main
poes	doc_980560860248_item	2962272	et	3	main
äratan	doc_980560860248_item	2962276	et	3	main
ja	doc_980560860248_item	2962279	et	3	main
hommikust	doc_980560860248_item	2962281	et	4	main
tund	doc_980560860248_item	2962286	et	3	main
poissi	doc_980560860248_item	2962288	et	4	main
1	doc_980560860248_item	2962251	et	2	main
mati	doc_980560860248_item	2962255	et	4	main
poodi	doc_980560860248_item	2962258	et	4	main
ma	doc_980560860248_item	2962274	et	3	main
söön	doc_980560860248_item	2962280	et	3	main
9	doc_980560860248_item	2962283	et	2	main
ülikoolis	doc_980560860248_item	2962335	et	4	main
10	doc_980560860248_item	2962337	et	2	main
millal	doc_980560860248_item	2962338	et	3	main
sinu	doc_980560860248_item	2962339	et	3	main
bussijaamast	doc_980560860248_item	2962358	et	4	main
kell	doc_980560860248_item	2962359	et	3	main
ma	doc_980560860248_item	2962399	et	3	main
viibisin	doc_980560860248_item	2962400	et	3	main
kogu	doc_980560860248_item	2962401	et	4	main
suve	doc_980560860248_item	2962402	et	4	main
töös	doc_980560860248_item	2962403	et	3	main
ma	doc_980560860248_item	2962404	et	3	main
edinburgi	doc_980560860248_item	2962410	et	4	main
aga	doc_980560860248_item	2962411	et	3	main
abikaasa	doc_980560860248_item	2962417	et	4	main
janne	doc_980560860248_item	2962422	et	4	main
poegid	doc_980560860248_item	2962425	et	3	main
ma	doc_980560860249_item	2962445	et	3	main
kassi	doc_980560860249_item	2962480	et	4	main
tartus	doc_980560860249_item	2962490	et	3	main
elavad	doc_980560860249_item	2962493	et	4	main
me	doc_980560860249_item	2962494	et	4	main
sõime	doc_980560860249_item	2962495	et	4	main
õhtusöögiks	doc_980560860249_item	2962496	et	3	main
kartuleid	doc_980560860249_item	2962497	et	3	main
mida	doc_980560860249_item	2962500	et	4	main
sa	doc_980560860249_item	2962522	et	3	main
edinburghi	doc_980560860249_item	2962526	et	4	main
mis	doc_980560860249_item	2962531	et	4	main
28-aastaseks	doc_980560860249_item	2962550	et	4	main
sinu	doc_980560860249_item	2962553	et	3	main
sunnipaev	doc_980560860249_item	2962554	et	4	main
tegid	doc_980560860249_item	2962562	et	4	main
kas	doc_980560860249_item	2962563	et	3	main
sa	doc_980560860249_item	2962564	et	3	main
käisid	doc_980560860249_item	2962565	et	4	main
reisimas	doc_980560860249_item	2962566	et	3	main
etc	doc_980560860249_item	2962567	et	4	main
leia	doc_980560860250_item	2962570	et	4	main
mis	doc_980560860250_item	2962633	et	4	main
kartuleid	doc_980560860250_item	2962641	et	3	main
parem	doc_980560860250_item	2962648	et	4	main
kala	doc_980560860250_item	2962650	et	4	main
minu	doc_980560860250_item	2962651	et	3	main
loengud	doc_980560860250_item	2962652	et	3	main
elanud	doc_980560860250_item	2962671	et	4	main
jänest	doc_980560860250_item	2962691	et	3	main
pill	doc_980560860250_item	2962693	et	3	main
hiljuti	doc_980560860250_item	2962705	et	4	main
aastane	doc_980560860250_item	2962709	et	4	main
leia	doc_980560860248_item	2962252	et	4	main
õiged	doc_980560860248_item	2962253	et	3	main
hommikul	doc_980560860248_item	2962257	et	3	main
piima	doc_980560860248_item	2962261	et	4	main
ja	doc_980560860248_item	2962263	et	3	main
üles	doc_980560860248_item	2962275	et	3	main
8	doc_980560860248_item	2962278	et	2	main
seda	doc_980560860248_item	2962287	et	3	main
mida	doc_980560860248_item	2962289	et	4	main
sa	doc_980560860248_item	2962290	et	3	main
tegid	doc_980560860248_item	2962291	et	4	main
eile	doc_980560860248_item	2962292	et	3	main
õhtul	doc_980560860248_item	2962293	et	3	main
kas	doc_980560860248_item	2962294	et	3	main
sulle	doc_980560860248_item	2962295	et	3	main
meeldib	doc_980560860248_item	2962296	et	3	main
šokolaad	doc_980560860248_item	2962297	et	2	main
mul	doc_980560860248_item	2962298	et	3	main
on	doc_980560860248_item	2962299	et	4	main
üks	doc_980560860248_item	2962300	et	3	main
koer	doc_980560860248_item	2962301	et	3	main
ja	doc_980560860248_item	2962302	et	3	main
kaks	doc_980560860248_item	2962303	et	3	main
kassi	doc_980560860248_item	2962304	et	4	main
2	doc_980560860248_item	2962305	et	2	main
tee	doc_980560860248_item	2962306	et	4	main
lause	doc_980560860248_item	2962307	et	4	main
kohta	doc_980560860248_item	2962308	et	4	main
küsimus	doc_980560860248_item	2962309	et	4	main
tiit	doc_980560860248_item	2962310	et	4	main
ja	doc_980560860248_item	2962311	et	3	main
mart	doc_980560860248_item	2962312	et	3	main
elavad	doc_980560860248_item	2962313	et	4	main
tartus	doc_980560860248_item	2962314	et	3	main
kus	doc_980560860248_item	2962315	et	3	main
elavad	doc_980560860248_item	2962316	et	4	main
tiit	doc_980560860248_item	2962317	et	4	main
ja	doc_980560860248_item	2962318	et	3	main
mart	doc_980560860248_item	2962319	et	3	main
me	doc_980560860248_item	2962320	et	4	main
sõime	doc_980560860248_item	2962321	et	4	main
kanaliha	doc_980560860248_item	2962325	et	4	main
kartuleid	doc_980560860248_item	2962329	et	3	main
ja	doc_980560860248_item	2962330	et	3	main
kanaliha	doc_980560860248_item	2962331	et	4	main
minu	doc_980560860248_item	2962332	et	3	main
kes	doc_980560860248_item	2962326	et	4	main
sõi	doc_980560860248_item	2962327	et	3	main
õhtusöögiks	doc_980560860248_item	2962328	et	3	main
ülikoolis	doc_980560860248_item	2962342	et	4	main
tulid	doc_980560860248_item	2962345	et	4	main
nädalal	doc_980560860248_item	2962347	et	3	main
on	doc_980560860248_item	2962368	et	4	main
kolm	doc_980560860248_item	2962369	et	3	main
koera	doc_980560860248_item	2962370	et	4	main
ja	doc_980560860248_item	2962371	et	3	main
neli	doc_980560860248_item	2962372	et	3	main
jänest	doc_980560860248_item	2962373	et	3	main
mitu	doc_980560860248_item	2962374	et	4	main
lemmikloomi	doc_980560860248_item	2962375	et	4	main
pillel	doc_980560860248_item	2962376	et	3	main
on	doc_980560860248_item	2962377	et	4	main
ta	doc_980560860248_item	2962378	et	4	main
saab	doc_980560860248_item	2962379	et	3	main
homme	doc_980560860248_item	2962380	et	3	main
28-aastaseks	doc_980560860248_item	2962381	et	4	main
millal	doc_980560860248_item	2962382	et	3	main
ta	doc_980560860248_item	2962383	et	4	main
saab	doc_980560860248_item	2962384	et	3	main
28-aastaseks	doc_980560860248_item	2962385	et	4	main
3	doc_980560860248_item	2962386	et	2	main
jutusta	doc_980560860248_item	2962387	et	4	main
oma	doc_980560860248_item	2962388	et	4	main
suvest	doc_980560860248_item	2962389	et	3	main
mida	doc_980560860248_item	2962390	et	4	main
sa	doc_980560860248_item	2962391	et	3	main
suvel	doc_980560860248_item	2962392	et	3	main
tegid	doc_980560860248_item	2962393	et	4	main
kas	doc_980560860248_item	2962394	et	3	main
sa	doc_980560860248_item	2962395	et	3	main
loengud	doc_980560860248_item	2962333	et	3	main
algavad	doc_980560860248_item	2962341	et	4	main
tulid	doc_980560860248_item	2962352	et	4	main
nädalad	doc_980560860248_item	2962354	et	3	main
edinburghi	doc_980560860248_item	2962356	et	4	main
reisinud	doc_980560860248_item	2962406	et	4	main
mitte	doc_980560860248_item	2962407	et	3	main
tema	doc_980560860248_item	2962415	et	4	main
visiteerid	doc_980560860248_item	2962420	et	3	main
on	doc_980560860248_item	2962426	et	4	main
armased	doc_980560860248_item	2962428	et	4	main
1	doc_980560860249_item	2962430	et	2	main
leia	doc_980560860249_item	2962431	et	4	main
õiged	doc_980560860249_item	2962432	et	3	main
verbid	doc_980560860249_item	2962433	et	3	main
piima	doc_980560860249_item	2962440	et	4	main
leiba	doc_980560860249_item	2962441	et	4	main
ja	doc_980560860249_item	2962442	et	3	main
seda	doc_980560860249_item	2962463	et	3	main
mida	doc_980560860249_item	2962465	et	4	main
kas	doc_980560860249_item	2962470	et	3	main
šokolaad	doc_980560860249_item	2962473	et	2	main
tiit	doc_980560860249_item	2962486	et	4	main
ja	doc_980560860249_item	2962487	et	3	main
mart	doc_980560860249_item	2962488	et	3	main
kus	doc_980560860249_item	2962491	et	3	main
kanaliha	doc_980560860249_item	2962499	et	4	main
sa	doc_980560860249_item	2962501	et	3	main
sõid	doc_980560860249_item	2962502	et	4	main
minu	doc_980560860249_item	2962503	et	3	main
loengud	doc_980560860249_item	2962504	et	3	main
algavad	doc_980560860249_item	2962505	et	4	main
sõber	doc_980560860249_item	2962523	et	3	main
bussijaamast	doc_980560860249_item	2962528	et	4	main
kell	doc_980560860249_item	2962529	et	3	main
buss	doc_980560860249_item	2962533	et	3	main
väljub	doc_980560860249_item	2962535	et	3	main
on	doc_980560860249_item	2962537	et	4	main
koera	doc_980560860249_item	2962539	et	4	main
jänest	doc_980560860249_item	2962542	et	3	main
on	doc_980560860249_item	2962545	et	4	main
lemmikloom	doc_980560860249_item	2962546	et	3	main
oma	doc_980560860249_item	2962557	et	4	main
suvest	doc_980560860249_item	2962558	et	3	main
mida	doc_980560860249_item	2962559	et	4	main
sa	doc_980560860249_item	2962560	et	3	main
harjutus	doc_980560860250_item	2962568	et	4	main
mati	doc_980560860250_item	2962573	et	4	main
2	doc_980560860250_item	2962623	et	2	main
lause	doc_980560860250_item	2962625	et	4	main
nende	doc_980560860250_item	2962635	et	4	main
aadress	doc_980560860250_item	2962636	et	3	main
tartus	doc_980560860250_item	2962637	et	3	main
armastate	doc_980560860250_item	2962646	et	3	main
kanaliha	doc_980560860250_item	2962647	et	4	main
ameerikas	doc_980560860250_item	2962669	et	4	main
edinburghi	doc_980560860250_item	2962675	et	4	main
kell	doc_980560860250_item	2962678	et	3	main
aga	doc_980560860250_item	2962680	et	3	main
bussireis	doc_980560860250_item	2962684	et	4	main
loomaarsti	doc_980560860250_item	2962695	et	4	main
21	doc_980560860250_item	2962708	et	2	main
jutusta	doc_980560860250_item	2962711	et	4	main
oma	doc_980560860250_item	2962712	et	4	main
suvest	doc_980560860250_item	2962713	et	3	main
olin	doc_980560860250_item	2962726	et	3	main
ma	doc_980560860250_item	2962734	et	3	main
sest	doc_980560860250_item	2962737	et	4	main
ülikool	doc_980560860250_item	2962740	et	4	main
olnud	doc_980560860250_item	2962752	et	4	main
aastast	doc_980560860251_item	2962757	et	4	main
1995	doc_980560860251_item	2962758	et	2	main
keramiikaklubis	doc_980560860251_item	2962764	et	4	main
käsiga	doc_980560860251_item	2962772	et	4	main
elektrilise	doc_980560860251_item	2962774	et	4	main
kujundakse	doc_980560860251_item	2962782	et	4	main
järel	doc_980560860251_item	2962783	et	4	main
järel	doc_980560860251_item	2962792	et	4	main
need	doc_980560860251_item	2962794	et	3	main
prosessi	doc_980560860251_item	2962803	et	4	main
nime	doc_980560860251_item	2962804	et	4	main
ei	doc_980560860248_item	2962405	et	4	main
minu	doc_980560860248_item	2962412	et	3	main
vend	doc_980560860248_item	2962413	et	3	main
ja	doc_980560860248_item	2962414	et	3	main
vend	doc_980560860248_item	2962424	et	3	main
mati	doc_980560860249_item	2962434	et	4	main
läheb	doc_980560860249_item	2962435	et	3	main
hommikul	doc_980560860249_item	2962436	et	3	main
poodi	doc_980560860249_item	2962437	et	4	main
ja	doc_980560860249_item	2962438	et	3	main
muna	doc_980560860249_item	2962444	et	4	main
ja	doc_980560860249_item	2962448	et	3	main
ma	doc_980560860249_item	2962453	et	3	main
tõusen	doc_980560860249_item	2962454	et	3	main
8	doc_980560860249_item	2962456	et	2	main
kell	doc_980560860249_item	2962459	et	3	main
kas	doc_980560860249_item	2962461	et	3	main
eile	doc_980560860249_item	2962468	et	3	main
sulle	doc_980560860249_item	2962471	et	3	main
on	doc_980560860249_item	2962475	et	4	main
üks	doc_980560860249_item	2962476	et	3	main
koer	doc_980560860249_item	2962477	et	3	main
ja	doc_980560860249_item	2962478	et	3	main
kaks	doc_980560860249_item	2962479	et	3	main
tee	doc_980560860249_item	2962482	et	4	main
ja	doc_980560860249_item	2962498	et	3	main
minu	doc_980560860248_item	2962423	et	3	main
eriti	doc_980560860248_item	2962427	et	3	main
harjutus	doc_980560860249_item	2962429	et	4	main
10	doc_980560860249_item	2962443	et	2	main
ülikoolis	doc_980560860249_item	2962447	et	4	main
õhtuti	doc_980560860249_item	2962450	et	3	main
pesin	doc_980560860249_item	2962458	et	3	main
9	doc_980560860249_item	2962460	et	2	main
poissi	doc_980560860249_item	2962464	et	4	main
sa	doc_980560860249_item	2962466	et	3	main
räägib	doc_980560860249_item	2962467	et	3	main
õhtul	doc_980560860249_item	2962469	et	3	main
meeldib	doc_980560860249_item	2962472	et	3	main
mul	doc_980560860249_item	2962474	et	3	main
küsimus	doc_980560860249_item	2962485	et	4	main
mis	doc_980560860249_item	2962509	et	4	main
kell	doc_980560860249_item	2962510	et	3	main
algab	doc_980560860249_item	2962511	et	3	main
loengud	doc_980560860249_item	2962512	et	3	main
meie	doc_980560860249_item	2962513	et	4	main
sõbrad	doc_980560860249_item	2962514	et	3	main
tulid	doc_980560860249_item	2962515	et	4	main
eelmisel	doc_980560860249_item	2962516	et	3	main
nädalal	doc_980560860249_item	2962517	et	3	main
ameerikast	doc_980560860249_item	2962518	et	4	main
millalt	doc_980560860249_item	2962519	et	4	main
ja	doc_980560860249_item	2962520	et	3	main
buss	doc_980560860249_item	2962525	et	3	main
kell	doc_980560860249_item	2962532	et	3	main
pillel	doc_980560860249_item	2962536	et	3	main
kolm	doc_980560860249_item	2962538	et	3	main
ja	doc_980560860249_item	2962540	et	3	main
kas	doc_980560860249_item	2962543	et	3	main
millal	doc_980560860249_item	2962551	et	3	main
3	doc_980560860249_item	2962555	et	2	main
jutusta	doc_980560860249_item	2962556	et	4	main
mul	doc_980560860250_item	2962616	et	3	main
koer	doc_980560860250_item	2962619	et	3	main
mind	doc_980560860248_item	2962421	et	4	main
osta	doc_980560860249_item	2962439	et	4	main
lähen	doc_980560860249_item	2962446	et	3	main
ostan	doc_980560860249_item	2962449	et	3	main
poes	doc_980560860249_item	2962451	et	3	main
tavaliselt	doc_980560860249_item	2962452	et	4	main
kell	doc_980560860249_item	2962455	et	3	main
ja	doc_980560860249_item	2962457	et	3	main
sa	doc_980560860249_item	2962462	et	3	main
2	doc_980560860249_item	2962481	et	2	main
lause	doc_980560860249_item	2962483	et	4	main
kohta	doc_980560860249_item	2962484	et	4	main
elavad	doc_980560860249_item	2962489	et	4	main
nad	doc_980560860249_item	2962492	et	3	main
ülikoolis	doc_980560860249_item	2962506	et	4	main
kell	doc_980560860249_item	2962507	et	3	main
10	doc_980560860249_item	2962508	et	2	main
tulema	doc_980560860249_item	2962524	et	4	main
väljub	doc_980560860249_item	2962527	et	3	main
12	doc_980560860249_item	2962530	et	2	main
neli	doc_980560860249_item	2962541	et	3	main
sul	doc_980560860249_item	2962544	et	3	main
ta	doc_980560860249_item	2962547	et	4	main
saab	doc_980560860249_item	2962548	et	3	main
homme	doc_980560860249_item	2962549	et	3	main
on	doc_980560860249_item	2962552	et	4	main
suvel	doc_980560860249_item	2962561	et	3	main
1	doc_980560860250_item	2962569	et	2	main
õiged	doc_980560860250_item	2962571	et	3	main
verbid	doc_980560860250_item	2962572	et	3	main
läks	doc_980560860250_item	2962574	et	3	main
hommikul	doc_980560860250_item	2962575	et	3	main
poodi	doc_980560860250_item	2962576	et	4	main
ja	doc_980560860250_item	2962577	et	3	main
on	doc_980560860250_item	2962617	et	4	main
üks	doc_980560860250_item	2962618	et	3	main
ja	doc_980560860250_item	2962620	et	3	main
kohta	doc_980560860250_item	2962626	et	4	main
tiit	doc_980560860250_item	2962628	et	4	main
elavad	doc_980560860250_item	2962631	et	4	main
tartus	doc_980560860250_item	2962632	et	3	main
sõime	doc_980560860250_item	2962639	et	4	main
õhtusöögiks	doc_980560860250_item	2962640	et	3	main
meie	doc_980560860250_item	2962662	et	4	main
tulid	doc_980560860250_item	2962664	et	4	main
teie	doc_980560860250_item	2962672	et	4	main
sõbrad	doc_980560860250_item	2962673	et	3	main
bussijaamast	doc_980560860250_item	2962677	et	4	main
12	doc_980560860250_item	2962679	et	2	main
kui	doc_980560860250_item	2962681	et	3	main
tahaks	doc_980560860250_item	2962694	et	3	main
ta	doc_980560860250_item	2962697	et	4	main
saab	doc_980560860250_item	2962698	et	3	main
homme	doc_980560860250_item	2962699	et	3	main
28-aastaseks	doc_980560860250_item	2962700	et	4	main
kas	doc_980560860250_item	2962701	et	3	main
tõesti	doc_980560860250_item	2962702	et	3	main
tere	doc_980560860250_item	2962703	et	3	main
sünnipäevaks	doc_980560860250_item	2962704	et	3	main
tegid	doc_980560860250_item	2962717	et	4	main
kas	doc_980560860250_item	2962718	et	3	main
sa	doc_980560860250_item	2962719	et	3	main
suvel	doc_980560860250_item	2962724	et	3	main
eestimaal	doc_980560860250_item	2962727	et	4	main
kaks	doc_980560860250_item	2962729	et	3	main
õppimiseks	doc_980560860250_item	2962731	et	4	main
eesti	doc_980560860250_item	2962732	et	4	main
eesti	doc_980560860250_item	2962739	et	4	main
külastasin	doc_980560860250_item	2962745	et	3	main
sest	doc_980560860250_item	2962748	et	4	main
ole	doc_980560860250_item	2962751	et	4	main
keraamikaklubi	doc_980560860251_item	2962756	et	4	main
kujundasin	doc_980560860251_item	2962770	et	3	main
oma	doc_980560860251_item	2962771	et	4	main
konega	doc_980560860251_item	2962775	et	3	main
mõned	doc_980560860251_item	2962776	et	3	main
erivärviga	doc_980560860251_item	2962796	et	4	main
ahisse	doc_980560860251_item	2962799	et	4	main
kust	doc_980560860249_item	2962521	et	4	main
edinburghi	doc_980560860249_item	2962534	et	4	main
osta	doc_980560860250_item	2962578	et	4	main
piima	doc_980560860250_item	2962579	et	4	main
leiba	doc_980560860250_item	2962580	et	4	main
ja	doc_980560860250_item	2962581	et	3	main
10	doc_980560860250_item	2962582	et	2	main
muna	doc_980560860250_item	2962583	et	4	main
ma	doc_980560860250_item	2962584	et	3	main
õpin	doc_980560860250_item	2962585	et	3	main
ülikoolis	doc_980560860250_item	2962586	et	4	main
ja	doc_980560860250_item	2962587	et	3	main
käin	doc_980560860250_item	2962588	et	3	main
õhtuti	doc_980560860250_item	2962589	et	3	main
poes	doc_980560860250_item	2962590	et	3	main
tavaliselt	doc_980560860250_item	2962591	et	4	main
ma	doc_980560860250_item	2962592	et	3	main
arkan	doc_980560860250_item	2962593	et	4	main
kell	doc_980560860250_item	2962594	et	3	main
8	doc_980560860250_item	2962595	et	2	main
ja	doc_980560860250_item	2962596	et	3	main
käin	doc_980560860250_item	2962597	et	3	main
dušši	doc_980560860250_item	2962598	et	2	main
all	doc_980560860250_item	2962599	et	3	main
kell	doc_980560860250_item	2962600	et	3	main
9	doc_980560860250_item	2962601	et	2	main
kas	doc_980560860250_item	2962602	et	3	main
sa	doc_980560860250_item	2962603	et	3	main
armastad	doc_980560860250_item	2962604	et	3	main
seda	doc_980560860250_item	2962605	et	3	main
poissi	doc_980560860250_item	2962606	et	4	main
mida	doc_980560860250_item	2962607	et	4	main
sa	doc_980560860250_item	2962608	et	3	main
tegid	doc_980560860250_item	2962609	et	4	main
eile	doc_980560860250_item	2962610	et	3	main
õhtul	doc_980560860250_item	2962611	et	3	main
kas	doc_980560860250_item	2962612	et	3	main
sulle	doc_980560860250_item	2962613	et	3	main
meeldib	doc_980560860250_item	2962614	et	3	main
šokolaad	doc_980560860250_item	2962615	et	2	main
kassi	doc_980560860250_item	2962622	et	4	main
on	doc_980560860250_item	2962634	et	4	main
ja	doc_980560860250_item	2962642	et	3	main
kas	doc_980560860250_item	2962644	et	3	main
kui	doc_980560860250_item	2962649	et	3	main
algavad	doc_980560860250_item	2962653	et	4	main
ülikoolis	doc_980560860250_item	2962654	et	4	main
kell	doc_980560860250_item	2962655	et	3	main
10	doc_980560860250_item	2962656	et	2	main
aga	doc_980560860250_item	2962657	et	3	main
millal	doc_980560860250_item	2962658	et	3	main
lõppevad	doc_980560860250_item	2962659	et	4	main
sinu	doc_980560860250_item	2962660	et	3	main
loengud	doc_980560860250_item	2962661	et	3	main
kaks	doc_980560860250_item	2962621	et	3	main
tee	doc_980560860250_item	2962624	et	4	main
küsimus	doc_980560860250_item	2962627	et	4	main
ja	doc_980560860250_item	2962629	et	3	main
mart	doc_980560860250_item	2962630	et	3	main
me	doc_980560860250_item	2962638	et	4	main
kanaliha	doc_980560860250_item	2962643	et	4	main
te	doc_980560860250_item	2962645	et	4	main
on	doc_980560860250_item	2962670	et	4	main
väljub	doc_980560860250_item	2962676	et	3	main
on	doc_980560860250_item	2962683	et	4	main
pillel	doc_980560860250_item	2962685	et	3	main
kas	doc_980560860250_item	2962692	et	3	main
saada	doc_980560860250_item	2962696	et	4	main
ma	doc_980560860250_item	2962706	et	3	main
3	doc_980560860250_item	2962710	et	2	main
mida	doc_980560860250_item	2962714	et	4	main
sa	doc_980560860250_item	2962715	et	3	main
suvel	doc_980560860250_item	2962716	et	3	main
reisimas	doc_980560860250_item	2962721	et	3	main
sel	doc_980560860250_item	2962723	et	3	main
umbes	doc_980560860250_item	2962728	et	4	main
ka	doc_980560860250_item	2962746	et	3	main
ükskord	doc_980560860251_item	2962762	et	3	main
kujundamas	doc_980560860251_item	2962765	et	3	main
või	doc_980560860251_item	2962773	et	4	main
tassid	doc_980560860251_item	2962777	et	4	main
savitõed	doc_980560860251_item	2962786	et	4	main
põletamise	doc_980560860251_item	2962791	et	4	main
värvisin	doc_980560860251_item	2962793	et	3	main
tema	doc_980560860251_item	2962802	et	4	main
sõbrad	doc_980560860250_item	2962663	et	3	main
eelmisel	doc_980560860250_item	2962665	et	3	main
nädalal	doc_980560860250_item	2962666	et	3	main
ameerikast	doc_980560860250_item	2962667	et	4	main
kus	doc_980560860250_item	2962668	et	3	main
buss	doc_980560860250_item	2962674	et	3	main
kaua	doc_980560860250_item	2962682	et	3	main
on	doc_980560860250_item	2962686	et	4	main
kolm	doc_980560860250_item	2962687	et	3	main
koera	doc_980560860250_item	2962688	et	4	main
ja	doc_980560860250_item	2962689	et	3	main
neli	doc_980560860250_item	2962690	et	3	main
sain	doc_980560860250_item	2962707	et	3	main
käisid	doc_980560860250_item	2962720	et	4	main
ma	doc_980560860250_item	2962725	et	3	main
nädalat	doc_980560860250_item	2962730	et	3	main
elasin	doc_980560860250_item	2962735	et	3	main
asub	doc_980560860250_item	2962741	et	3	main
tartus	doc_980560860250_item	2962742	et	3	main
ma	doc_980560860250_item	2962744	et	3	main
eestimaal	doc_980560860250_item	2962753	et	4	main
enne	doc_980560860250_item	2962754	et	4	main
essee	doc_980560860251_item	2962755	et	4	main
nädalas	doc_980560860251_item	2962763	et	3	main
puna-	doc_980560860251_item	2962766	et	4	main
ning	doc_980560860251_item	2962767	et	3	main
savi	doc_980560860251_item	2962769	et	4	main
kuivat	doc_980560860251_item	2962785	et	4	main
tulikuumasse	doc_980560860251_item	2962787	et	4	main
ahisse	doc_980560860251_item	2962788	et	4	main
900	doc_980560860251_item	2962789	et	2	main
uuesti	doc_980560860251_item	2962798	et	3	main
1000	doc_980560860251_item	2962800	et	2	main
kraadid	doc_980560860251_item	2962801	et	4	main
etc	doc_980560860250_item	2962722	et	4	main
keelt	doc_980560860250_item	2962733	et	4	main
tartus	doc_980560860250_item	2962736	et	3	main
parim	doc_980560860250_item	2962738	et	4	main
siiski	doc_980560860250_item	2962743	et	4	main
tallinna	doc_980560860250_item	2962747	et	4	main
ma	doc_980560860250_item	2962749	et	3	main
ei	doc_980560860250_item	2962750	et	4	main
aastasse	doc_980560860251_item	2962759	et	4	main
1998	doc_980560860251_item	2962760	et	2	main
käin	doc_980560860251_item	2962761	et	3	main
valge	doc_980560860251_item	2962768	et	4	main
lillepotid	doc_980560860251_item	2962778	et	4	main
ning	doc_980560860251_item	2962779	et	3	main
kausid	doc_980560860251_item	2962780	et	3	main
prosess	doc_980560860251_item	2962781	et	4	main
panin	doc_980560860251_item	2962784	et	3	main
kraadid	doc_980560860251_item	2962790	et	4	main
tõed	doc_980560860251_item	2962795	et	4	main
siis	doc_980560860251_item	2962797	et	3	main
on	doc_980560860251_item	2962805	et	4	main
klaasiminen	doc_980560860251_item	2962806	et	4	main
siis	doc_980560860251_item	2962807	et	3	main
on	doc_980560860251_item	2962808	et	4	main
disain	doc_980560860251_item	2962809	et	3	main
valmis	doc_980560860251_item	2962810	et	4	main
ja	doc_980560860251_item	2962811	et	3	main
eriti	doc_980560860251_item	2962812	et	3	main
kestava	doc_980560860251_item	2962813	et	4	main
ja	doc_980560860251_item	2962814	et	3	main
ka	doc_980560860251_item	2962815	et	3	main
ilus	doc_980560860251_item	2962816	et	4	main
supermarketis	doc_980560860260_item	2964119	et	4	main
kerge	doc_980560860260_item	2964123	et	4	main
lihtsalt	doc_980560860260_item	2964125	et	4	main
oma	doc_980560860260_item	2964130	et	4	main
on	doc_980560860260_item	2964136	et	4	main
ostma	doc_980560860260_item	2964138	et	3	main
lähedal	doc_980560860260_item	2964154	et	4	main
mina	doc_980560860261_item	2964168	et	4	main
ja	doc_980560860261_item	2964169	et	3	main
minu	doc_980560860261_item	2964170	et	3	main
sõbrad	doc_980560860261_item	2964171	et	3	main
pärast	doc_980560860261_item	2964177	et	4	main
meie	doc_980560860261_item	2964178	et	4	main
õpisime	doc_980560860261_item	2964179	et	4	main
traditsioonilises	doc_980560860261_item	2964187	et	4	main
udmurtis	doc_980560860261_item	2964188	et	4	main
sarnaneme	doc_980560860261_item	2964222	et	3	main
laua	doc_980560860263_item	2964401	et	3	main
sees	doc_980560860263_item	2964431	et	4	main
ma	doc_980560860263_item	2964432	et	3	main
magan	doc_980560860263_item	2964433	et	3	main
asi	doc_980560860263_item	2964440	et	4	main
sees	doc_980560860263_item	2964443	et	4	main
seest	doc_980560860263_item	2964449	et	3	main
kõrval	doc_980560860263_item	2964451	et	4	main
on	doc_980560860263_item	2964454	et	4	main
minu	doc_980560860263_item	2964455	et	3	main
raamatud	doc_980560860263_item	2964456	et	4	main
mul	doc_980560860263_item	2964457	et	3	main
saia	doc_980560860260_item	2964118	et	4	main
sisseoste	doc_980560860260_item	2964120	et	3	main
tegema	doc_980560860260_item	2964121	et	3	main
tarvis	doc_980560860260_item	2964124	et	3	main
pildi	doc_980560860261_item	2964155	et	4	main
kirjeldus	doc_980560860261_item	2964156	et	4	main
väga	doc_980560860261_item	2964161	et	3	main
tore	doc_980560860261_item	2964164	et	3	main
selles	doc_980560860261_item	2964165	et	4	main
on	doc_980560860261_item	2964167	et	4	main
koos	doc_980560860261_item	2964180	et	4	main
makaroni	doc_980560860260_item	2964116	et	4	main
kaardi	doc_980560860260_item	2964131	et	4	main
ja	doc_980560860260_item	2964132	et	3	main
minna	doc_980560860260_item	2964133	et	3	main
kõige	doc_980560860260_item	2964139	et	4	main
poes	doc_980560860260_item	2964141	et	3	main
väikeses	doc_980560860260_item	2964150	et	4	main
poes	doc_980560860260_item	2964151	et	3	main
minu	doc_980560860260_item	2964152	et	3	main
foto	doc_980560860261_item	2964157	et	4	main
see	doc_980560860261_item	2964158	et	3	main
on	doc_980560860261_item	2964160	et	4	main
soomest	doc_980560860261_item	2964172	et	3	main
hollandist	doc_980560860261_item	2964173	et	4	main
türgist	doc_980560860261_item	2964174	et	4	main
udmurtimaal	doc_980560860261_item	2964181	et	4	main
viimases	doc_980560860261_item	2964182	et	3	main
suves	doc_980560860261_item	2964183	et	3	main
fotos	doc_980560860261_item	2964184	et	3	main
turul	doc_980560860260_item	2964087	et	3	main
ja	doc_980560860260_item	2964088	et	3	main
essee	doc_980560860260_item	2964086	et	4	main
poes	doc_980560860260_item	2964089	et	3	main
ma	doc_980560860260_item	2964090	et	3	main
käiksin	doc_980560860260_item	2964091	et	3	main
turul	doc_980560860260_item	2964092	et	3	main
et	doc_980560860260_item	2964093	et	3	main
sisseoste	doc_980560860260_item	2964094	et	3	main
tegema	doc_980560860260_item	2964095	et	3	main
aga	doc_980560860260_item	2964096	et	3	main
glasgows	doc_980560860260_item	2964097	et	4	main
ei	doc_980560860260_item	2964098	et	4	main
ole	doc_980560860260_item	2964099	et	4	main
turu	doc_980560860260_item	2964100	et	3	main
sellepärast	doc_980560860260_item	2964101	et	3	main
ma	doc_980560860260_item	2964102	et	3	main
käiksin	doc_980560860260_item	2964103	et	3	main
poodi	doc_980560860260_item	2964104	et	4	main
või	doc_980560860260_item	2964105	et	4	main
supermarketis	doc_980560860260_item	2964106	et	4	main
ma	doc_980560860260_item	2964108	et	3	main
ostan	doc_980560860260_item	2964109	et	3	main
enimesid	doc_980560860260_item	2964110	et	4	main
ase	doc_980560860260_item	2964111	et	3	main
supermarketis	doc_980560860260_item	2964107	et	4	main
misuguseid	doc_980560860260_item	2964112	et	4	main
nagu	doc_980560860260_item	2964113	et	3	main
liha	doc_980560860260_item	2964114	et	4	main
piima	doc_980560860260_item	2964115	et	4	main
juustu	doc_980560860260_item	2964117	et	4	main
paneda	doc_980560860260_item	2964126	et	4	main
asjade	doc_980560860260_item	2964127	et	3	main
korvis	doc_980560860260_item	2964128	et	3	main
välgatada	doc_980560860260_item	2964129	et	3	main
see	doc_980560860260_item	2964135	et	3	main
köögiviljaid	doc_980560860260_item	2964146	et	4	main
ja	doc_980560860260_item	2964147	et	3	main
puuviljaid	doc_980560860260_item	2964148	et	4	main
ühes	doc_980560860260_item	2964149	et	4	main
foto	doc_980560860261_item	2964159	et	4	main
naljakas	doc_980560860261_item	2964162	et	4	main
fotos	doc_980560860261_item	2964166	et	3	main
ja	doc_980560860261_item	2964175	et	3	main
iraanist	doc_980560860261_item	2964176	et	4	main
meie	doc_980560860261_item	2964185	et	4	main
istume	doc_980560860261_item	2964186	et	3	main
kodus	doc_980560860261_item	2964189	et	4	main
see	doc_980560860261_item	2964190	et	3	main
on	doc_980560860261_item	2964191	et	4	main
nähtav	doc_980560860261_item	2964192	et	4	main
nii	doc_980560860261_item	2964193	et	3	main
mu	doc_980560860261_item	2964194	et	3	main
türgi	doc_980560860261_item	2964195	et	4	main
sõber	doc_980560860261_item	2964196	et	3	main
xxx	doc_980560860261_item	2964197	et	4	main
mulle	doc_980560860261_item	2964198	et	4	main
meeldis	doc_980560860261_item	2964199	et	3	main
mina	doc_980560860261_item	2964200	et	4	main
püüdlen	doc_980560860261_item	2964201	et	3	main
olla	doc_980560860261_item	2964202	et	3	main
tore	doc_980560860261_item	2964203	et	3	main
ja	doc_980560860261_item	2964204	et	3	main
türgi	doc_980560860261_item	2964205	et	4	main
nagu	doc_980560860261_item	2964206	et	3	main
tema	doc_980560860261_item	2964207	et	4	main
minu	doc_980560860261_item	2964208	et	3	main
tüdruksõbral	doc_980560860261_item	2964209	et	3	main
meeldis	doc_980560860261_item	2964210	et	3	main
see	doc_980560860261_item	2964211	et	3	main
foto	doc_980560860261_item	2964212	et	4	main
et	doc_980560860261_item	2964213	et	3	main
ta	doc_980560860261_item	2964214	et	4	main
otsustas	doc_980560860261_item	2964215	et	3	main
teha	doc_980560860261_item	2964216	et	3	main
t-särgi	doc_980560860261_item	2964217	et	4	main
ta	doc_980560860261_item	2964218	et	4	main
mõtlen	doc_980560860261_item	2964219	et	3	main
et	doc_980560860261_item	2964220	et	3	main
meie	doc_980560860261_item	2964221	et	4	main
rokk-gruppegagi	doc_980560860261_item	2964223	et	4	main
väga	doc_980560860260_item	2964122	et	3	main
koju	doc_980560860260_item	2964134	et	3	main
võimalik	doc_980560860260_item	2964137	et	3	main
ühes	doc_980560860260_item	2964140	et	4	main
siiski	doc_980560860260_item	2964142	et	4	main
mulle	doc_980560860260_item	2964143	et	4	main
meeldis	doc_980560860260_item	2964144	et	3	main
ostma	doc_980560860260_item	2964145	et	3	main
kodu	doc_980560860260_item	2964153	et	4	main
ja	doc_980560860261_item	2964163	et	3	main
laud	doc_980560860263_item	2964400	et	4	main
peale	doc_980560860263_item	2964412	et	4	main
ma	doc_980560860263_item	2964413	et	3	main
laud	doc_980560860263_item	2964422	et	4	main
kõrval	doc_980560860263_item	2964427	et	4	main
voodi	doc_980560860263_item	2964429	et	4	main
on	doc_980560860263_item	2964436	et	4	main
voodi	doc_980560860263_item	2964437	et	4	main
ma	doc_980560860263_item	2964445	et	3	main
kapi	doc_980560860263_item	2964450	et	4	main
põranda	doc_980560860263_item	2964452	et	3	main
raamaturiiulit	doc_980560860263_item	2964460	et	3	main
või	doc_980560860265_item	2964691	et	4	main
veel	doc_980560860265_item	2964697	et	4	main
sööma	doc_980560860265_item	2964700	et	4	main
minu	doc_980560860263_item	2964404	et	3	main
õhtul	doc_980560860263_item	2964406	et	3	main
laua	doc_980560860263_item	2964411	et	3	main
töötan	doc_980560860263_item	2964414	et	3	main
laua	doc_980560860263_item	2964416	et	3	main
ääres	doc_980560860263_item	2964417	et	4	main
akna	doc_980560860263_item	2964426	et	3	main
on	doc_980560860263_item	2964441	et	4	main
võtan	doc_980560860263_item	2964446	et	3	main
ei	doc_980560860263_item	2964458	et	4	main
minu	doc_980560860263_item	2964395	et	3	main
tuba	doc_980560860263_item	2964396	et	4	main
minu	doc_980560860263_item	2964397	et	3	main
toas	doc_980560860263_item	2964398	et	3	main
on	doc_980560860263_item	2964403	et	4	main
arvuti	doc_980560860263_item	2964405	et	4	main
ma	doc_980560860263_item	2964407	et	3	main
panen	doc_980560860263_item	2964408	et	3	main
lampi	doc_980560860263_item	2964410	et	4	main
tavaliselt	doc_980560860263_item	2964415	et	4	main
tool	doc_980560860263_item	2964418	et	3	main
on	doc_980560860263_item	2964419	et	4	main
laua	doc_980560860263_item	2964420	et	3	main
essee	doc_980560860263_item	2964394	et	4	main
on	doc_980560860263_item	2964399	et	4	main
peal	doc_980560860263_item	2964402	et	4	main
ka	doc_980560860263_item	2964409	et	3	main
ees	doc_980560860263_item	2964421	et	4	main
asub	doc_980560860263_item	2964423	et	3	main
all	doc_980560860263_item	2964425	et	3	main
j	doc_980560860263_item	2964434	et	4	main
kapp	doc_980560860263_item	2964435	et	3	main
kapi	doc_980560860263_item	2964442	et	4	main
kapi	doc_980560860263_item	2964448	et	4	main
ole	doc_980560860263_item	2964459	et	4	main
õppima	doc_980560860265_item	2964698	et	3	main
õhtust	doc_980560860265_item	2964701	et	4	main
jalutada	doc_980560860265_item	2964712	et	3	main
puhata	doc_980560860265_item	2964714	et	4	main
ilus	doc_980560860265_item	2964716	et	4	main
ilm	doc_980560860265_item	2964717	et	3	main
on	doc_980560860265_item	2964718	et	4	main
lähen	doc_980560860265_item	2964719	et	3	main
raekoja	doc_980560860265_item	2964720	et	3	main
sööma	doc_980560860265_item	2964722	et	4	main
kas	doc_980560860265_item	2964735	et	3	main
ja	doc_980560860265_item	2964742	et	3	main
on	doc_980560860265_item	2964751	et	4	main
oli	doc_980560860265_item	2964752	et	3	main
kaua	doc_980560860265_item	2964764	et	3	main
ärkab	doc_980560860265_item	2964767	et	3	main
võileiba	doc_980560860265_item	2964778	et	4	main
natuke	doc_980560860265_item	2964786	et	4	main
läbi	doc_980560860265_item	2964822	et	4	main
trolliga	doc_980560860265_item	2964836	et	4	main
talle	doc_980560860265_item	2964845	et	4	main
üks	doc_980560860265_item	2964846	et	3	main
akna	doc_980560860263_item	2964424	et	3	main
on	doc_980560860263_item	2964428	et	4	main
voodi	doc_980560860263_item	2964430	et	4	main
juures	doc_980560860263_item	2964438	et	4	main
minu	doc_980560860263_item	2964439	et	3	main
hommikul	doc_980560860263_item	2964444	et	3	main
asi	doc_980560860263_item	2964447	et	4	main
peal	doc_980560860263_item	2964453	et	4	main
kontrolltöö	doc_980560860265_item	2964686	et	4	main
1	doc_980560860265_item	2964687	et	2	main
täna	doc_980560860265_item	2964696	et	4	main
ja	doc_980560860265_item	2964707	et	3	main
pesuma	doc_980560860265_item	2964709	et	4	main
mulle	doc_980560860265_item	2964710	et	4	main
meeldib	doc_980560860265_item	2964711	et	3	main
kui	doc_980560860265_item	2964715	et	3	main
keele	doc_980560860265_item	2964726	et	4	main
tohi	doc_980560860265_item	2964729	et	4	main
naeratada	doc_980560860265_item	2964730	et	3	main
keelt	doc_980560860265_item	2964734	et	4	main
tuled	doc_980560860265_item	2964737	et	4	main
kadrioru	doc_980560860265_item	2964739	et	3	main
jalutama	doc_980560860265_item	2964741	et	3	main
marju	doc_980560860265_item	2964748	et	3	main
marjul	doc_980560860265_item	2964750	et	3	main
vaba	doc_980560860265_item	2964754	et	4	main
päev	doc_980560860265_item	2964755	et	3	main
lõpuks	doc_980560860265_item	2964756	et	4	main
saab	doc_980560860265_item	2964757	et	3	main
1030	doc_980560860265_item	2964766	et	2	main
siis	doc_980560860265_item	2964771	et	3	main
ta	doc_980560860265_item	2964774	et	4	main
kohvi	doc_980560860265_item	2964775	et	4	main
sööb	doc_980560860265_item	2964776	et	3	main
sõi	doc_980560860265_item	2964777	et	3	main
ta	doc_980560860265_item	2964821	et	4	main
eesti	doc_980560860265_item	2964823	et	4	main
instituudist	doc_980560860265_item	2964824	et	3	main
ning	doc_980560860265_item	2964825	et	3	main
toob	doc_980560860265_item	2964826	et	3	main
tõi	doc_980560860265_item	2964827	et	3	main
sealt	doc_980560860265_item	2964828	et	4	main
kodus	doc_980560860265_item	2964837	et	4	main
teeb	doc_980560860265_item	2964838	et	3	main
nad	doc_980560860265_item	2964849	et	3	main
jooksma	doc_980560860265_item	2964853	et	3	main
jooksevad	doc_980560860265_item	2964855	et	4	main
tund	doc_980560860265_item	2964859	et	3	main
kodus	doc_980560860265_item	2964862	et	4	main
ära	doc_980560860265_item	2964870	et	4	main
pärnography	doc_980560860265_item	2964872	et	4	main
rääkis	doc_980560860265_item	2964875	et	3	main
kuulasis	doc_980560860265_item	2964885	et	4	main
ta	doc_980560860265_item	2964886	et	4	main
uudiseid	doc_980560860265_item	2964887	et	3	main
töötab	doc_980560860265_item	2964888	et	3	main
töötasis	doc_980560860265_item	2964889	et	4	main
veel	doc_980560860265_item	2964890	et	4	main
tegi	doc_980560860265_item	2964901	et	4	main
testi	doc_980560860265_item	2964905	et	4	main
sõitasin	doc_980560860265_item	2964925	et	4	main
bussiga	doc_980560860265_item	2964926	et	3	main
hommikul	doc_980560860265_item	2964927	et	3	main
ja	doc_980560860265_item	2964928	et	3	main
õhtul	doc_980560860265_item	2964929	et	3	main
nägin	doc_980560860265_item	2964930	et	3	main
hea	doc_980560860265_item	2964939	et	4	main
mu	doc_980560860265_item	2964943	et	3	main
da	doc_980560860265_item	2964692	et	4	main
infinitiiviga	doc_980560860265_item	2964693	et	3	main
ma	doc_980560860265_item	2964694	et	3	main
pean	doc_980560860265_item	2964695	et	4	main
ja	doc_980560860265_item	2964699	et	3	main
korristama	doc_980560860265_item	2964706	et	4	main
lõpeta	doc_980560860265_item	2964688	et	4	main
laused	doc_980560860265_item	2964689	et	3	main
ma	doc_980560860265_item	2964690	et	3	main
eesti	doc_980560860265_item	2964725	et	4	main
inglise	doc_980560860265_item	2964733	et	4	main
puhkama	doc_980560860265_item	2964743	et	3	main
tekst	doc_980560860265_item	2964746	et	3	main
päev	doc_980560860265_item	2964749	et	3	main
ta	doc_980560860265_item	2964759	et	4	main
magada	doc_980560860265_item	2964760	et	3	main
ta	doc_980560860265_item	2964761	et	4	main
lugesis	doc_980560860265_item	2964781	et	4	main
ta	doc_980560860265_item	2964783	et	4	main
peab	doc_980560860265_item	2964784	et	4	main
arvuti	doc_980560860265_item	2964787	et	4	main
ära	doc_980560860265_item	2964829	et	4	main
mõned	doc_980560860265_item	2964830	et	3	main
raamatud	doc_980560860265_item	2964831	et	4	main
koju	doc_980560860265_item	2964832	et	3	main
sõidab	doc_980560860265_item	2964833	et	3	main
sõitis	doc_980560860265_item	2964834	et	3	main
ta	doc_980560860265_item	2964835	et	4	main
jooksid	doc_980560860265_item	2964856	et	4	main
räägib	doc_980560860265_item	2964874	et	3	main
eesti	doc_980560860265_item	2964876	et	4	main
priit	doc_980560860265_item	2964881	et	3	main
pärnast	doc_980560860265_item	2964882	et	4	main
ning	doc_980560860265_item	2964894	et	3	main
valmis	doc_980560860265_item	2964902	et	4	main
väljas	doc_980560860265_item	2964923	et	4	main
ma	doc_980560860265_item	2964941	et	3	main
helistasin	doc_980560860265_item	2964942	et	3	main
õde	doc_980560860265_item	2964944	et	4	main
arvutis	doc_980560860265_item	2964946	et	4	main
1	doc_980560860266_item	2964948	et	2	main
pean	doc_980560860266_item	2964956	et	4	main
täna	doc_980560860266_item	2964957	et	4	main
jooma	doc_980560860266_item	2964983	et	4	main
rääkima	doc_980560860266_item	2964985	et	3	main
eesti	doc_980560860266_item	2964986	et	4	main
kas	doc_980560860266_item	2964995	et	3	main
sa	doc_980560860266_item	2964996	et	3	main
tuled	doc_980560860266_item	2964997	et	4	main
magada	doc_980560860266_item	2965021	et	3	main
magab	doc_980560860266_item	2965023	et	3	main
joob	doc_980560860266_item	2965033	et	3	main
arvuti	doc_980560860266_item	2965048	et	4	main
ta	doc_980560860266_item	2965052	et	4	main
avab	doc_980560860266_item	2965053	et	3	main
avas	doc_980560860266_item	2965054	et	4	main
failid	doc_980560860266_item	2965055	et	3	main
ja	doc_980560860266_item	2965056	et	3	main
kirjutab	doc_980560860266_item	2965057	et	3	main
kirjutas	doc_980560860266_item	2965058	et	3	main
tööle	doc_980560860266_item	2965066	et	3	main
paaris	doc_980560860266_item	2965075	et	4	main
poes	doc_980560860266_item	2965076	et	3	main
eesti	doc_980560860266_item	2965084	et	4	main
istus	doc_980560860266_item	2965125	et	4	main
vaatab	doc_980560860266_item	2965129	et	3	main
filmi	doc_980560860266_item	2965132	et	4	main
priit	doc_980560860266_item	2965142	et	3	main
kuulas	doc_980560860266_item	2965146	et	3	main
magama	doc_980560860266_item	2965170	et	3	main
3	doc_980560860266_item	2965176	et	2	main
mida	doc_980560860266_item	2965178	et	4	main
sina	doc_980560860266_item	2965179	et	4	main
eile	doc_980560860266_item	2965180	et	3	main
kell	doc_980560860266_item	2965186	et	3	main
hiljam	doc_980560860266_item	2965202	et	4	main
läksin	doc_980560860266_item	2965204	et	3	main
kella	doc_980560860266_item	2965206	et	4	main
kümneni	doc_980560860266_item	2965208	et	4	main
siis	doc_980560860266_item	2965210	et	3	main
vett	doc_980560860266_item	2965221	et	3	main
ma	doc_980560860266_item	2965229	et	3	main
kontrolltöö	doc_980560860267_item	2965232	et	4	main
lõpeta	doc_980560860267_item	2965234	et	4	main
laused	doc_980560860267_item	2965235	et	3	main
ma	doc_980560860267_item	2965236	et	3	main
või	doc_980560860267_item	2965237	et	4	main
aga	doc_980560860265_item	2964702	et	3	main
ma	doc_980560860265_item	2964703	et	3	main
tahan	doc_980560860265_item	2964704	et	3	main
täna	doc_980560860265_item	2964705	et	4	main
pesu	doc_980560860265_item	2964708	et	4	main
ja	doc_980560860265_item	2964713	et	3	main
platsile	doc_980560860265_item	2964721	et	4	main
ja	doc_980560860265_item	2964723	et	3	main
jooma	doc_980560860265_item	2964724	et	4	main
tunnis	doc_980560860265_item	2964727	et	3	main
ei	doc_980560860265_item	2964728	et	4	main
rääkida	doc_980560860265_item	2964732	et	3	main
sa	doc_980560860265_item	2964736	et	3	main
parki	doc_980560860265_item	2964740	et	4	main
pane	doc_980560860265_item	2964745	et	4	main
minevikku	doc_980560860265_item	2964747	et	4	main
teisipäev	doc_980560860265_item	2964753	et	3	main
magab	doc_980560860265_item	2964762	et	3	main
ta	doc_980560860265_item	2964769	et	4	main
joob	doc_980560860265_item	2964772	et	3	main
ja	doc_980560860265_item	2964779	et	3	main
e-kirju	doc_980560860265_item	2964782	et	4	main
pidi	doc_980560860265_item	2964785	et	4	main
tegi	doc_980560860265_item	2964839	et	4	main
marju	doc_980560860265_item	2964840	et	3	main
otsustad	doc_980560860265_item	2964851	et	3	main
nad	doc_980560860265_item	2964854	et	3	main
umbes	doc_980560860265_item	2964858	et	4	main
aega	doc_980560860265_item	2964860	et	4	main
õhtul	doc_980560860265_item	2964861	et	3	main
istub	doc_980560860265_item	2964863	et	3	main
istus	doc_980560860265_item	2964864	et	4	main
vaatasis	doc_980560860265_item	2964869	et	4	main
man	doc_980560860265_item	2964880	et	3	main
kuulab	doc_980560860265_item	2964884	et	3	main
arvuti	doc_980560860265_item	2964892	et	4	main
taga	doc_980560860265_item	2964893	et	4	main
ning	doc_980560860265_item	2964906	et	3	main
läheb	doc_980560860265_item	2964907	et	3	main
ega	doc_980560860265_item	2964731	et	3	main
ka	doc_980560860265_item	2964738	et	3	main
2	doc_980560860265_item	2964744	et	2	main
sai	doc_980560860265_item	2964758	et	4	main
magasis	doc_980560860265_item	2964763	et	3	main
kell	doc_980560860265_item	2964765	et	3	main
ärkasis	doc_980560860265_item	2964768	et	4	main
üles	doc_980560860265_item	2964770	et	3	main
jõi	doc_980560860265_item	2964773	et	3	main
loeb	doc_980560860265_item	2964780	et	3	main
taga	doc_980560860265_item	2964788	et	4	main
tööd	doc_980560860265_item	2964789	et	4	main
tegema	doc_980560860265_item	2964790	et	3	main
ta	doc_980560860265_item	2964791	et	4	main
avab	doc_980560860265_item	2964792	et	3	main
avasis	doc_980560860265_item	2964793	et	4	main
failid	doc_980560860265_item	2964794	et	3	main
ja	doc_980560860265_item	2964795	et	3	main
kirjutab	doc_980560860265_item	2964796	et	3	main
kirjutasis	doc_980560860265_item	2964797	et	4	main
ta	doc_980560860265_item	2964798	et	4	main
paneb	doc_980560860265_item	2964799	et	3	main
pani	doc_980560860265_item	2964800	et	4	main
pesu	doc_980560860265_item	2964801	et	4	main
masinasse	doc_980560860265_item	2964802	et	4	main
ja	doc_980560860265_item	2964803	et	3	main
masina	doc_980560860265_item	2964804	et	3	main
tööle	doc_980560860265_item	2964805	et	3	main
pärastlõunal	doc_980560860265_item	2964806	et	3	main
läheb	doc_980560860265_item	2964807	et	3	main
läks	doc_980560860265_item	2964808	et	3	main
ta	doc_980560860265_item	2964809	et	4	main
linna	doc_980560860265_item	2964810	et	4	main
ta	doc_980560860265_item	2964811	et	4	main
käib	doc_980560860265_item	2964812	et	3	main
käis	doc_980560860265_item	2964813	et	4	main
paaris	doc_980560860265_item	2964814	et	4	main
poes	doc_980560860265_item	2964815	et	3	main
ja	doc_980560860265_item	2964816	et	3	main
pangas	doc_980560860265_item	2964817	et	4	main
vanalinnas	doc_980560860265_item	2964818	et	4	main
astub	doc_980560860265_item	2964819	et	3	main
astusis	doc_980560860265_item	2964820	et	4	main
spagette	doc_980560860265_item	2964841	et	4	main
õhtul	doc_980560860265_item	2964842	et	3	main
helistab	doc_980560860265_item	2964843	et	3	main
helistasis	doc_980560860265_item	2964844	et	4	main
metsas	doc_980560860265_item	2964857	et	3	main
vaatab	doc_980560860265_item	2964868	et	3	main
film	doc_980560860265_item	2964873	et	3	main
siis	doc_980560860265_item	2964883	et	3	main
natuke	doc_980560860265_item	2964891	et	4	main
jutustasis	doc_980560860265_item	2964896	et	4	main
ühe	doc_980560860265_item	2964897	et	4	main
tartu	doc_980560860265_item	2964898	et	4	main
sõbraga	doc_980560860265_item	2964899	et	3	main
teeb	doc_980560860265_item	2964900	et	3	main
keele	doc_980560860265_item	2964904	et	4	main
läks	doc_980560860265_item	2964908	et	3	main
magama	doc_980560860265_item	2964909	et	3	main
kell	doc_980560860265_item	2964910	et	3	main
on	doc_980560860265_item	2964911	et	4	main
oli	doc_980560860265_item	2964912	et	3	main
üle	doc_980560860265_item	2964913	et	3	main
südaöö	doc_980560860265_item	2964914	et	4	main
3	doc_980560860265_item	2964915	et	2	main
kirjuta	doc_980560860265_item	2964916	et	4	main
mida	doc_980560860265_item	2964917	et	4	main
sina	doc_980560860265_item	2964918	et	4	main
eile	doc_980560860265_item	2964919	et	3	main
tegid	doc_980560860265_item	2964920	et	4	main
on	doc_980560860265_item	2964934	et	4	main
tored	doc_980560860265_item	2964935	et	4	main
mul	doc_980560860265_item	2964936	et	3	main
olin	doc_980560860265_item	2964937	et	3	main
väga	doc_980560860265_item	2964938	et	3	main
kohvi	doc_980560860266_item	2964982	et	4	main
tohi	doc_980560860266_item	2964990	et	4	main
magada	doc_980560860266_item	2964991	et	3	main
ega	doc_980560860266_item	2964992	et	3	main
sõbraga	doc_980560860266_item	2964993	et	3	main
rääkida	doc_980560860266_item	2964994	et	3	main
ja	doc_980560860266_item	2965002	et	3	main
oli	doc_980560860266_item	2965013	et	3	main
vaba	doc_980560860266_item	2965015	et	4	main
päev	doc_980560860266_item	2965016	et	3	main
lõpuks	doc_980560860266_item	2965017	et	4	main
saab	doc_980560860266_item	2965018	et	3	main
kell	doc_980560860266_item	2965026	et	3	main
ärkas	doc_980560860266_item	2965029	et	3	main
siis	doc_980560860266_item	2965032	et	3	main
jõi	doc_980560860266_item	2965034	et	3	main
kohvi	doc_980560860266_item	2965036	et	4	main
sööb	doc_980560860266_item	2965037	et	3	main
ta	doc_980560860266_item	2965044	et	4	main
natuke	doc_980560860266_item	2965047	et	4	main
tööd	doc_980560860266_item	2965050	et	4	main
pesu	doc_980560860266_item	2965062	et	4	main
läks	doc_980560860266_item	2965069	et	3	main
linna	doc_980560860266_item	2965071	et	4	main
ta	doc_980560860266_item	2965072	et	4	main
käib	doc_980560860266_item	2965073	et	3	main
vanalinnas	doc_980560860266_item	2965079	et	4	main
astub	doc_980560860266_item	2965080	et	3	main
astus	doc_980560860266_item	2965081	et	3	main
ta	doc_980560860266_item	2965082	et	4	main
toob	doc_980560860266_item	2965087	et	3	main
sealt	doc_980560860266_item	2965089	et	4	main
mõned	doc_980560860266_item	2965091	et	3	main
ta	doc_980560860266_item	2965126	et	4	main
animafilmi	doc_980560860266_item	2965138	et	4	main
pärnast	doc_980560860266_item	2965143	et	4	main
kuulab	doc_980560860266_item	2965145	et	3	main
ta	doc_980560860266_item	2965147	et	4	main
sõber	doc_980560860265_item	2964847	et	3	main
ning	doc_980560860265_item	2964848	et	3	main
otsustavad	doc_980560860265_item	2964850	et	4	main
minna	doc_980560860265_item	2964852	et	3	main
ta	doc_980560860265_item	2964865	et	4	main
vannis	doc_980560860265_item	2964866	et	3	main
ning	doc_980560860265_item	2964867	et	3	main
filmi	doc_980560860265_item	2964871	et	4	main
animafilmi	doc_980560860265_item	2964877	et	4	main
grand	doc_980560860265_item	2964878	et	3	main
old	doc_980560860265_item	2964879	et	4	main
jutustab	doc_980560860265_item	2964895	et	3	main
eesti	doc_980560860265_item	2964903	et	4	main
eile	doc_980560860265_item	2964921	et	3	main
rääkisime	doc_980560860265_item	2964945	et	3	main
kontrolltöö	doc_980560860266_item	2964947	et	4	main
lõpeta	doc_980560860266_item	2964949	et	4	main
laused	doc_980560860266_item	2964950	et	3	main
ma	doc_980560860266_item	2964951	et	3	main
veel	doc_980560860266_item	2964958	et	4	main
töötama	doc_980560860266_item	2964959	et	3	main
ja	doc_980560860266_item	2964960	et	3	main
õppima	doc_980560860266_item	2964961	et	3	main
aga	doc_980560860266_item	2964962	et	3	main
ma	doc_980560860266_item	2964963	et	3	main
lähen	doc_980560860266_item	2964979	et	3	main
raekoja	doc_980560860266_item	2964980	et	3	main
platsile	doc_980560860266_item	2964981	et	4	main
keele	doc_980560860266_item	2964987	et	4	main
tunnis	doc_980560860266_item	2964988	et	3	main
ei	doc_980560860266_item	2964989	et	4	main
kadrioru	doc_980560860266_item	2964999	et	3	main
parki	doc_980560860266_item	2965000	et	4	main
2	doc_980560860266_item	2965005	et	2	main
sai	doc_980560860266_item	2965019	et	4	main
ta	doc_980560860266_item	2965022	et	4	main
magas	doc_980560860266_item	2965024	et	4	main
üles	doc_980560860266_item	2965031	et	3	main
e-kirju	doc_980560860266_item	2965043	et	4	main
peab	doc_980560860266_item	2965045	et	4	main
pide	doc_980560860266_item	2965046	et	3	main
pärastlõunal	doc_980560860266_item	2965067	et	3	main
ta	doc_980560860266_item	2965070	et	4	main
pangas	doc_980560860266_item	2965078	et	4	main
ning	doc_980560860266_item	2965086	et	3	main
sõin	doc_980560860265_item	2964922	et	3	main
sõbredega	doc_980560860265_item	2964924	et	4	main
mu	doc_980560860265_item	2964931	et	3	main
nabrid	doc_980560860265_item	2964932	et	4	main
need	doc_980560860265_item	2964933	et	3	main
päev	doc_980560860265_item	2964940	et	3	main
või	doc_980560860266_item	2964952	et	4	main
da	doc_980560860266_item	2964953	et	4	main
infinitiiviga	doc_980560860266_item	2964954	et	3	main
ma	doc_980560860266_item	2964955	et	3	main
tahan	doc_980560860266_item	2964964	et	3	main
täna	doc_980560860266_item	2964965	et	4	main
arvutiga	doc_980560860266_item	2964966	et	4	main
mängida	doc_980560860266_item	2964967	et	3	main
ja	doc_980560860266_item	2964968	et	3	main
magada	doc_980560860266_item	2964969	et	3	main
mulle	doc_980560860266_item	2964970	et	4	main
meeldib	doc_980560860266_item	2964971	et	3	main
süüa	doc_980560860266_item	2964972	et	3	main
ja	doc_980560860266_item	2964973	et	3	main
juua	doc_980560860266_item	2964974	et	3	main
kui	doc_980560860266_item	2964975	et	3	main
ilus	doc_980560860266_item	2964976	et	4	main
ilm	doc_980560860266_item	2964977	et	3	main
on	doc_980560860266_item	2964978	et	4	main
ja	doc_980560860266_item	2964984	et	3	main
ka	doc_980560860266_item	2964998	et	3	main
jalutama	doc_980560860266_item	2965001	et	3	main
koera	doc_980560860266_item	2965003	et	4	main
mängima	doc_980560860266_item	2965004	et	3	main
minevikku	doc_980560860266_item	2965008	et	4	main
marju	doc_980560860266_item	2965009	et	3	main
päev	doc_980560860266_item	2965010	et	3	main
marjul	doc_980560860266_item	2965011	et	3	main
teisipäev	doc_980560860266_item	2965014	et	3	main
pane	doc_980560860266_item	2965006	et	4	main
tekst	doc_980560860266_item	2965007	et	3	main
on	doc_980560860266_item	2965012	et	4	main
ta	doc_980560860266_item	2965020	et	4	main
1030	doc_980560860266_item	2965027	et	2	main
ärkab	doc_980560860266_item	2965028	et	3	main
ta	doc_980560860266_item	2965030	et	4	main
ta	doc_980560860266_item	2965035	et	4	main
sõi	doc_980560860266_item	2965038	et	3	main
võileiba	doc_980560860266_item	2965039	et	4	main
ja	doc_980560860266_item	2965040	et	3	main
loeb	doc_980560860266_item	2965041	et	3	main
loes	doc_980560860266_item	2965042	et	3	main
taga	doc_980560860266_item	2965049	et	4	main
tegema	doc_980560860266_item	2965051	et	3	main
masinasse	doc_980560860266_item	2965063	et	4	main
ja	doc_980560860266_item	2965064	et	3	main
masina	doc_980560860266_item	2965065	et	3	main
ja	doc_980560860266_item	2965077	et	3	main
instituudist	doc_980560860266_item	2965085	et	3	main
ära	doc_980560860266_item	2965090	et	4	main
õhtul	doc_980560860266_item	2965122	et	3	main
vannis	doc_980560860266_item	2965127	et	3	main
ning	doc_980560860266_item	2965128	et	3	main
vaatas	doc_980560860266_item	2965130	et	3	main
man	doc_980560860266_item	2965141	et	3	main
taga	doc_980560860266_item	2965154	et	4	main
jutustas	doc_980560860266_item	2965157	et	3	main
kell	doc_980560860266_item	2965171	et	3	main
üle	doc_980560860266_item	2965174	et	3	main
ma	doc_980560860266_item	2965183	et	3	main
üles	doc_980560860266_item	2965185	et	3	main
ma	doc_980560860266_item	2965195	et	3	main
kella	doc_980560860266_item	2965197	et	4	main
kaheksast	doc_980560860266_item	2965207	et	4	main
ja	doc_980560860266_item	2965209	et	3	main
ma	doc_980560860266_item	2965211	et	3	main
koju	doc_980560860266_item	2965213	et	3	main
sõin	doc_980560860266_item	2965215	et	3	main
ja	doc_980560860266_item	2965217	et	3	main
ma	doc_980560860266_item	2965218	et	3	main
vaatasin	doc_980560860266_item	2965225	et	3	main
da	doc_980560860267_item	2965238	et	4	main
infinitiiviga	doc_980560860267_item	2965239	et	3	main
ma	doc_980560860267_item	2965240	et	3	main
veel	doc_980560860267_item	2965243	et	4	main
ja	doc_980560860267_item	2965252	et	3	main
kohvi	doc_980560860267_item	2965268	et	4	main
ja	doc_980560860267_item	2965269	et	3	main
mängima	doc_980560860267_item	2965270	et	3	main
kell	doc_980560860267_item	2965311	et	3	main
üles	doc_980560860267_item	2965316	et	3	main
siis	doc_980560860267_item	2965317	et	3	main
taga	doc_980560860267_item	2965334	et	4	main
tööd	doc_980560860267_item	2965335	et	4	main
panis	doc_980560860267_item	2965346	et	4	main
astub	doc_980560860267_item	2965365	et	3	main
sealt	doc_980560860267_item	2965374	et	4	main
ära	doc_980560860267_item	2965375	et	4	main
mõned	doc_980560860267_item	2965376	et	3	main
raamatud	doc_980560860267_item	2965377	et	4	main
koju	doc_980560860267_item	2965378	et	3	main
sõidab	doc_980560860267_item	2965379	et	3	main
sõi	doc_980560860267_item	2965380	et	3	main
kodus	doc_980560860267_item	2965383	et	4	main
jooksma	doc_980560860267_item	2965399	et	3	main
old	doc_980560860267_item	2965425	et	4	main
kuulas	doc_980560860267_item	2965431	et	3	main
töötas	doc_980560860267_item	2965435	et	3	main
tartu	doc_980560860267_item	2965444	et	4	main
sõbraga	doc_980560860267_item	2965445	et	3	main
teeb	doc_980560860267_item	2965446	et	3	main
testi	doc_980560860267_item	2965451	et	4	main
ning	doc_980560860267_item	2965452	et	3	main
sina	doc_980560860267_item	2965464	et	4	main
jõin	doc_980560860267_item	2965485	et	3	main
kaua	doc_980560860266_item	2965025	et	3	main
ta	doc_980560860266_item	2965059	et	4	main
paneb	doc_980560860266_item	2965060	et	3	main
pani	doc_980560860266_item	2965061	et	4	main
läheb	doc_980560860266_item	2965068	et	3	main
käi	doc_980560860266_item	2965074	et	4	main
läbi	doc_980560860266_item	2965083	et	4	main
tõi	doc_980560860266_item	2965088	et	3	main
raamatud	doc_980560860266_item	2965092	et	4	main
koju	doc_980560860266_item	2965093	et	3	main
sõidab	doc_980560860266_item	2965094	et	3	main
sõidas	doc_980560860266_item	2965095	et	4	main
ta	doc_980560860266_item	2965096	et	4	main
trolliga	doc_980560860266_item	2965097	et	4	main
kodus	doc_980560860266_item	2965098	et	4	main
teeb	doc_980560860266_item	2965099	et	3	main
teges	doc_980560860266_item	2965100	et	4	main
marju	doc_980560860266_item	2965101	et	3	main
spagette	doc_980560860266_item	2965102	et	4	main
õhtul	doc_980560860266_item	2965103	et	3	main
helistab	doc_980560860266_item	2965104	et	3	main
helistas	doc_980560860266_item	2965105	et	3	main
talle	doc_980560860266_item	2965106	et	4	main
üks	doc_980560860266_item	2965107	et	3	main
ning	doc_980560860266_item	2965109	et	3	main
sõber	doc_980560860266_item	2965108	et	3	main
nad	doc_980560860266_item	2965110	et	3	main
otsustavad	doc_980560860266_item	2965111	et	4	main
otsustus	doc_980560860266_item	2965112	et	4	main
minna	doc_980560860266_item	2965113	et	3	main
jooksma	doc_980560860266_item	2965114	et	3	main
nad	doc_980560860266_item	2965115	et	3	main
jooksevad	doc_980560860266_item	2965116	et	4	main
jookses	doc_980560860266_item	2965117	et	3	main
metsas	doc_980560860266_item	2965118	et	3	main
umbes	doc_980560860266_item	2965119	et	4	main
tund	doc_980560860266_item	2965120	et	3	main
kodus	doc_980560860266_item	2965123	et	4	main
grand	doc_980560860266_item	2965139	et	3	main
old	doc_980560860266_item	2965140	et	4	main
uudiseid	doc_980560860266_item	2965148	et	3	main
veel	doc_980560860266_item	2965151	et	4	main
jutustab	doc_980560860266_item	2965156	et	3	main
on	doc_980560860266_item	2965172	et	4	main
oli	doc_980560860266_item	2965173	et	3	main
setse	doc_980560860266_item	2965187	et	4	main
võtsin	doc_980560860266_item	2965189	et	3	main
läksin	doc_980560860266_item	2965193	et	3	main
trenni	doc_980560860266_item	2965205	et	4	main
veini	doc_980560860266_item	2965223	et	4	main
televiisorit	doc_980560860266_item	2965226	et	3	main
voodisse	doc_980560860266_item	2965231	et	3	main
pean	doc_980560860267_item	2965241	et	4	main
magama	doc_980560860267_item	2965244	et	3	main
aega	doc_980560860266_item	2965121	et	4	main
istub	doc_980560860266_item	2965124	et	3	main
ära	doc_980560860266_item	2965131	et	4	main
pärnography	doc_980560860266_item	2965133	et	4	main
film	doc_980560860266_item	2965134	et	3	main
räägib	doc_980560860266_item	2965135	et	3	main
räägis	doc_980560860266_item	2965136	et	3	main
eesti	doc_980560860266_item	2965137	et	4	main
siis	doc_980560860266_item	2965144	et	3	main
ning	doc_980560860266_item	2965155	et	3	main
ühe	doc_980560860266_item	2965158	et	4	main
tartu	doc_980560860266_item	2965159	et	4	main
sõbraga	doc_980560860266_item	2965160	et	3	main
teeb	doc_980560860266_item	2965161	et	3	main
tege	doc_980560860266_item	2965162	et	4	main
valmis	doc_980560860266_item	2965163	et	4	main
eesti	doc_980560860266_item	2965164	et	4	main
keele	doc_980560860266_item	2965165	et	4	main
testi	doc_980560860266_item	2965166	et	4	main
ning	doc_980560860266_item	2965167	et	3	main
töötab	doc_980560860266_item	2965149	et	3	main
töötas	doc_980560860266_item	2965150	et	3	main
natuke	doc_980560860266_item	2965152	et	4	main
arvuti	doc_980560860266_item	2965153	et	4	main
läheb	doc_980560860266_item	2965168	et	3	main
läks	doc_980560860266_item	2965169	et	3	main
südaöö	doc_980560860266_item	2965175	et	4	main
kirjuta	doc_980560860266_item	2965177	et	4	main
tegid	doc_980560860266_item	2965181	et	4	main
ma	doc_980560860266_item	2965192	et	3	main
tööle	doc_980560860266_item	2965194	et	3	main
töötasin	doc_980560860266_item	2965196	et	3	main
kaheksast	doc_980560860266_item	2965198	et	4	main
hommikul	doc_980560860266_item	2965199	et	3	main
seitmeni	doc_980560860266_item	2965200	et	4	main
õhtul	doc_980560860266_item	2965201	et	3	main
läksin	doc_980560860266_item	2965212	et	3	main
ma	doc_980560860266_item	2965214	et	3	main
kana	doc_980560860266_item	2965216	et	4	main
jõin	doc_980560860266_item	2965219	et	3	main
natuke	doc_980560860266_item	2965220	et	4	main
eile	doc_980560860266_item	2965182	et	3	main
tõusin	doc_980560860266_item	2965184	et	3	main
ma	doc_980560860266_item	2965188	et	3	main
kohvi	doc_980560860266_item	2965190	et	4	main
ja	doc_980560860266_item	2965191	et	3	main
ma	doc_980560860266_item	2965203	et	3	main
ma	doc_980560860266_item	2965224	et	3	main
ja	doc_980560860266_item	2965227	et	3	main
läksin	doc_980560860266_item	2965230	et	3	main
korvpalli	doc_980560860267_item	2965257	et	4	main
ja	doc_980560860267_item	2965258	et	3	main
raekoja	doc_980560860267_item	2965265	et	3	main
platsile	doc_980560860267_item	2965266	et	4	main
jooma	doc_980560860267_item	2965267	et	4	main
õpetaga	doc_980560860267_item	2965277	et	4	main
ega	doc_980560860267_item	2965278	et	3	main
1030	doc_980560860267_item	2965312	et	2	main
ta	doc_980560860267_item	2965320	et	4	main
võileiba	doc_980560860267_item	2965324	et	4	main
ja	doc_980560860267_item	2965325	et	3	main
loeb	doc_980560860267_item	2965326	et	3	main
kirjutab	doc_980560860267_item	2965342	et	3	main
kirjutas	doc_980560860267_item	2965343	et	3	main
ta	doc_980560860267_item	2965344	et	4	main
ta	doc_980560860267_item	2965357	et	4	main
käib	doc_980560860267_item	2965358	et	3	main
käi	doc_980560860267_item	2965359	et	4	main
vanalinnas	doc_980560860267_item	2965364	et	4	main
astus	doc_980560860267_item	2965366	et	3	main
läbi	doc_980560860267_item	2965368	et	4	main
eesti	doc_980560860267_item	2965369	et	4	main
instituudist	doc_980560860267_item	2965370	et	3	main
ning	doc_980560860267_item	2965371	et	3	main
toob	doc_980560860267_item	2965372	et	3	main
ning	doc_980560860267_item	2965394	et	3	main
nad	doc_980560860267_item	2965395	et	3	main
otsustavad	doc_980560860267_item	2965396	et	4	main
ja	doc_980560860266_item	2965222	et	3	main
hiljam	doc_980560860266_item	2965228	et	4	main
1	doc_980560860267_item	2965233	et	2	main
õppima	doc_980560860267_item	2965246	et	3	main
tahan	doc_980560860267_item	2965249	et	3	main
oskada	doc_980560860267_item	2965253	et	4	main
mulle	doc_980560860267_item	2965254	et	4	main
meeldib	doc_980560860267_item	2965255	et	3	main
mängida	doc_980560860267_item	2965256	et	3	main
ilus	doc_980560860267_item	2965261	et	4	main
on	doc_980560860267_item	2965263	et	4	main
eesti	doc_980560860267_item	2965272	et	4	main
keele	doc_980560860267_item	2965273	et	4	main
tunnis	doc_980560860267_item	2965274	et	3	main
ei	doc_980560860267_item	2965275	et	4	main
kas	doc_980560860267_item	2965280	et	3	main
tuled	doc_980560860267_item	2965282	et	4	main
ka	doc_980560860267_item	2965283	et	3	main
kadrioru	doc_980560860267_item	2965284	et	3	main
parki	doc_980560860267_item	2965285	et	4	main
mängima	doc_980560860267_item	2965286	et	3	main
ja	doc_980560860267_item	2965287	et	3	main
kohtuma	doc_980560860267_item	2965288	et	3	main
mind	doc_980560860267_item	2965289	et	4	main
2	doc_980560860267_item	2965290	et	2	main
pane	doc_980560860267_item	2965291	et	4	main
tekst	doc_980560860267_item	2965292	et	3	main
minevikku	doc_980560860267_item	2965293	et	4	main
marju	doc_980560860267_item	2965294	et	3	main
päev	doc_980560860267_item	2965295	et	3	main
marjul	doc_980560860267_item	2965296	et	3	main
on	doc_980560860267_item	2965297	et	4	main
oli	doc_980560860267_item	2965298	et	3	main
teisipäev	doc_980560860267_item	2965299	et	3	main
vaba	doc_980560860267_item	2965300	et	4	main
päev	doc_980560860267_item	2965301	et	3	main
lõpuks	doc_980560860267_item	2965302	et	4	main
saab	doc_980560860267_item	2965303	et	3	main
saas	doc_980560860267_item	2965304	et	4	main
ta	doc_980560860267_item	2965305	et	4	main
magada	doc_980560860267_item	2965306	et	3	main
ta	doc_980560860267_item	2965307	et	4	main
magab	doc_980560860267_item	2965308	et	3	main
magas	doc_980560860267_item	2965309	et	4	main
täna	doc_980560860267_item	2965242	et	4	main
ma	doc_980560860267_item	2965248	et	3	main
täna	doc_980560860267_item	2965250	et	4	main
töötada	doc_980560860267_item	2965251	et	3	main
kui	doc_980560860267_item	2965260	et	3	main
tohi	doc_980560860267_item	2965276	et	4	main
sa	doc_980560860267_item	2965281	et	3	main
ta	doc_980560860267_item	2965315	et	4	main
jõi	doc_980560860267_item	2965319	et	3	main
lõe	doc_980560860267_item	2965327	et	4	main
ta	doc_980560860267_item	2965329	et	4	main
paneb	doc_980560860267_item	2965345	et	3	main
pesu	doc_980560860267_item	2965347	et	4	main
paaris	doc_980560860267_item	2965360	et	4	main
poes	doc_980560860267_item	2965361	et	3	main
ja	doc_980560860267_item	2965362	et	3	main
pangas	doc_980560860267_item	2965363	et	4	main
ta	doc_980560860267_item	2965367	et	4	main
trolliga	doc_980560860267_item	2965382	et	4	main
otsustasid	doc_980560860267_item	2965397	et	4	main
minna	doc_980560860267_item	2965398	et	3	main
eesti	doc_980560860267_item	2965422	et	4	main
veel	doc_980560860267_item	2965436	et	4	main
arvuti	doc_980560860267_item	2965438	et	4	main
ning	doc_980560860267_item	2965440	et	3	main
jutustab	doc_980560860267_item	2965441	et	3	main
eesti	doc_980560860267_item	2965449	et	4	main
keele	doc_980560860267_item	2965450	et	4	main
kell	doc_980560860267_item	2965456	et	3	main
üle	doc_980560860267_item	2965459	et	3	main
3	doc_980560860267_item	2965461	et	2	main
eile	doc_980560860267_item	2965465	et	3	main
kohtusin	doc_980560860267_item	2965482	et	4	main
veini	doc_980560860267_item	2965486	et	4	main
või	doc_980560860269_item	2965745	et	4	main
veel	doc_980560860269_item	2965751	et	4	main
ma	doc_980560860269_item	2965756	et	3	main
kino	doc_980560860269_item	2965759	et	4	main
ja	doc_980560860269_item	2965761	et	3	main
mulle	doc_980560860269_item	2965763	et	4	main
keele	doc_980560860269_item	2965783	et	4	main
tunnis	doc_980560860269_item	2965784	et	3	main
ja	doc_980560860267_item	2965245	et	3	main
aga	doc_980560860267_item	2965247	et	3	main
ujuda	doc_980560860267_item	2965259	et	3	main
ilm	doc_980560860267_item	2965262	et	3	main
lähen	doc_980560860267_item	2965264	et	3	main
kaart	doc_980560860267_item	2965271	et	4	main
natuke	doc_980560860267_item	2965279	et	4	main
kaua	doc_980560860267_item	2965310	et	3	main
ärkas	doc_980560860267_item	2965314	et	3	main
kohvi	doc_980560860267_item	2965321	et	4	main
sõis	doc_980560860267_item	2965323	et	4	main
e-kirju	doc_980560860267_item	2965328	et	4	main
peab	doc_980560860267_item	2965330	et	4	main
natuke	doc_980560860267_item	2965332	et	4	main
arvuti	doc_980560860267_item	2965333	et	4	main
ta	doc_980560860267_item	2965337	et	4	main
avab	doc_980560860267_item	2965338	et	3	main
avas	doc_980560860267_item	2965339	et	4	main
failid	doc_980560860267_item	2965340	et	3	main
ja	doc_980560860267_item	2965341	et	3	main
masinasse	doc_980560860267_item	2965348	et	4	main
ja	doc_980560860267_item	2965349	et	3	main
masina	doc_980560860267_item	2965350	et	3	main
tööle	doc_980560860267_item	2965351	et	3	main
pärastlõunal	doc_980560860267_item	2965352	et	3	main
läheb	doc_980560860267_item	2965353	et	3	main
läks	doc_980560860267_item	2965354	et	3	main
ta	doc_980560860267_item	2965355	et	4	main
talle	doc_980560860267_item	2965391	et	4	main
üks	doc_980560860267_item	2965392	et	3	main
sõber	doc_980560860267_item	2965393	et	3	main
grand	doc_980560860267_item	2965424	et	3	main
natuke	doc_980560860267_item	2965437	et	4	main
täis	doc_980560860267_item	2965447	et	4	main
läks	doc_980560860267_item	2965454	et	3	main
natuke	doc_980560860267_item	2965487	et	4	main
ärkab	doc_980560860267_item	2965313	et	3	main
joob	doc_980560860267_item	2965318	et	3	main
sööb	doc_980560860267_item	2965322	et	3	main
panis	doc_980560860267_item	2965331	et	4	main
tegema	doc_980560860267_item	2965336	et	3	main
linna	doc_980560860267_item	2965356	et	4	main
tõis	doc_980560860267_item	2965373	et	4	main
ta	doc_980560860267_item	2965381	et	4	main
teeb	doc_980560860267_item	2965384	et	3	main
täis	doc_980560860267_item	2965385	et	4	main
marju	doc_980560860267_item	2965386	et	3	main
spagette	doc_980560860267_item	2965387	et	4	main
õhtul	doc_980560860267_item	2965388	et	3	main
helistab	doc_980560860267_item	2965389	et	3	main
helistas	doc_980560860267_item	2965390	et	3	main
nad	doc_980560860267_item	2965400	et	3	main
jooksevad	doc_980560860267_item	2965401	et	4	main
jõisid	doc_980560860267_item	2965402	et	4	main
metsas	doc_980560860267_item	2965403	et	3	main
umbes	doc_980560860267_item	2965404	et	4	main
tund	doc_980560860267_item	2965405	et	3	main
aega	doc_980560860267_item	2965406	et	4	main
õhtul	doc_980560860267_item	2965407	et	3	main
kodus	doc_980560860267_item	2965408	et	4	main
istub	doc_980560860267_item	2965409	et	3	main
istus	doc_980560860267_item	2965410	et	4	main
ta	doc_980560860267_item	2965411	et	4	main
vannis	doc_980560860267_item	2965412	et	3	main
ning	doc_980560860267_item	2965413	et	3	main
vaatab	doc_980560860267_item	2965414	et	3	main
vaatas	doc_980560860267_item	2965415	et	3	main
ära	doc_980560860267_item	2965416	et	4	main
pärnography	doc_980560860267_item	2965418	et	4	main
film	doc_980560860267_item	2965419	et	3	main
filmi	doc_980560860267_item	2965417	et	4	main
räägib	doc_980560860267_item	2965420	et	3	main
animafilmi	doc_980560860267_item	2965423	et	4	main
man	doc_980560860267_item	2965426	et	3	main
pärnast	doc_980560860267_item	2965428	et	4	main
kuulab	doc_980560860267_item	2965430	et	3	main
taga	doc_980560860267_item	2965439	et	4	main
jutustas	doc_980560860267_item	2965442	et	3	main
ühe	doc_980560860267_item	2965443	et	4	main
magama	doc_980560860267_item	2965455	et	3	main
on	doc_980560860267_item	2965457	et	4	main
ja	doc_980560860267_item	2965481	et	3	main
sõbra	doc_980560860267_item	2965483	et	3	main
ja	doc_980560860267_item	2965484	et	3	main
räägis	doc_980560860267_item	2965421	et	3	main
priit	doc_980560860267_item	2965427	et	3	main
siis	doc_980560860267_item	2965429	et	3	main
ta	doc_980560860267_item	2965432	et	4	main
uudiseid	doc_980560860267_item	2965433	et	3	main
töötab	doc_980560860267_item	2965434	et	3	main
valmis	doc_980560860267_item	2965448	et	4	main
läheb	doc_980560860267_item	2965453	et	3	main
oli	doc_980560860267_item	2965458	et	3	main
südaöö	doc_980560860267_item	2965460	et	4	main
kirjuta	doc_980560860267_item	2965462	et	4	main
mida	doc_980560860267_item	2965463	et	4	main
tegid	doc_980560860267_item	2965466	et	4	main
ma	doc_980560860267_item	2965467	et	3	main
läksin	doc_980560860267_item	2965468	et	3	main
töö	doc_980560860267_item	2965469	et	4	main
ja	doc_980560860267_item	2965470	et	3	main
olin	doc_980560860267_item	2965471	et	3	main
kodus	doc_980560860267_item	2965472	et	4	main
ja	doc_980560860267_item	2965473	et	3	main
õpisin	doc_980560860267_item	2965474	et	4	main
eesti	doc_980560860267_item	2965475	et	4	main
keelt	doc_980560860267_item	2965476	et	4	main
pärast	doc_980560860267_item	2965477	et	4	main
ma	doc_980560860267_item	2965478	et	3	main
sõin	doc_980560860267_item	2965479	et	3	main
makkaronid	doc_980560860267_item	2965480	et	4	main
da	doc_980560860269_item	2965746	et	4	main
infinitiiviga	doc_980560860269_item	2965747	et	3	main
ja	doc_980560860269_item	2965753	et	3	main
tuled	doc_980560860269_item	2965792	et	4	main
parki	doc_980560860269_item	2965795	et	4	main
ja	doc_980560860269_item	2965797	et	3	main
2	doc_980560860269_item	2965799	et	2	main
päev	doc_980560860269_item	2965810	et	3	main
ta	doc_980560860269_item	2965814	et	4	main
magada	doc_980560860269_item	2965815	et	3	main
ta	doc_980560860269_item	2965816	et	4	main
magab	doc_980560860269_item	2965817	et	3	main
ta	doc_980560860269_item	2965824	et	4	main
joob	doc_980560860269_item	2965827	et	3	main
e-kirju	doc_980560860269_item	2965837	et	4	main
ta	doc_980560860269_item	2965838	et	4	main
taga	doc_980560860269_item	2965843	et	4	main
ta	doc_980560860269_item	2965853	et	4	main
paneb	doc_980560860269_item	2965854	et	3	main
pani	doc_980560860269_item	2965855	et	4	main
tööle	doc_980560860269_item	2965860	et	3	main
ta	doc_980560860269_item	2965864	et	4	main
linna	doc_980560860269_item	2965865	et	4	main
ta	doc_980560860269_item	2965866	et	4	main
käib	doc_980560860269_item	2965867	et	3	main
läbi	doc_980560860269_item	2965877	et	4	main
instituudist	doc_980560860269_item	2965879	et	3	main
ning	doc_980560860269_item	2965880	et	3	main
ta	doc_980560860269_item	2965920	et	4	main
1	doc_980560860269_item	2965741	et	2	main
lõpeta	doc_980560860269_item	2965742	et	4	main
laused	doc_980560860269_item	2965743	et	3	main
ma	doc_980560860269_item	2965744	et	3	main
töötama	doc_980560860269_item	2965754	et	3	main
mineda	doc_980560860269_item	2965760	et	4	main
magada	doc_980560860269_item	2965762	et	3	main
jooma	doc_980560860269_item	2965781	et	4	main
juua	doc_980560860269_item	2965789	et	3	main
kas	doc_980560860269_item	2965790	et	3	main
puhkama	doc_980560860269_item	2965798	et	3	main
pane	doc_980560860269_item	2965800	et	4	main
tekst	doc_980560860269_item	2965801	et	3	main
minevikku	doc_980560860269_item	2965802	et	4	main
marju	doc_980560860269_item	2965803	et	3	main
päev	doc_980560860269_item	2965804	et	3	main
marjul	doc_980560860269_item	2965805	et	3	main
lõpuks	doc_980560860269_item	2965811	et	4	main
siis	doc_980560860269_item	2965826	et	3	main
peab	doc_980560860269_item	2965839	et	4	main
tööd	doc_980560860269_item	2965844	et	4	main
pesu	doc_980560860269_item	2965856	et	4	main
läheb	doc_980560860269_item	2965862	et	3	main
käis	doc_980560860269_item	2965868	et	4	main
vannis	doc_980560860269_item	2965921	et	3	main
vaatas	doc_980560860269_item	2965924	et	3	main
grand	doc_980560860269_item	2965933	et	3	main
priit	doc_980560860269_item	2965936	et	3	main
ta	doc_980560860269_item	2965941	et	4	main
veel	doc_980560860269_item	2965945	et	4	main
ma	doc_980560860269_item	2965976	et	3	main
läisk	doc_980560860269_item	2965981	et	4	main
ma	doc_980560860269_item	2965983	et	3	main
ja	doc_980560860269_item	2965989	et	3	main
ja	doc_980560860269_item	2965991	et	3	main
ülikoolile	doc_980560860269_item	2965998	et	4	main
foto	doc_980560860269_item	2966010	et	4	main
ma	doc_980560860270_item	2966022	et	3	main
da	doc_980560860270_item	2966024	et	4	main
pean	doc_980560860270_item	2966027	et	4	main
täna	doc_980560860270_item	2966028	et	4	main
ja	doc_980560860270_item	2966031	et	3	main
tahan	doc_980560860270_item	2966035	et	3	main
magada	doc_980560860270_item	2966039	et	3	main
vaatada	doc_980560860270_item	2966044	et	4	main
eesti	doc_980560860270_item	2966056	et	4	main
kas	doc_980560860270_item	2966064	et	3	main
kadrioru	doc_980560860270_item	2966068	et	3	main
ja	doc_980560860270_item	2966108	et	3	main
loeb	doc_980560860270_item	2966109	et	3	main
lõi	doc_980560860270_item	2966110	et	4	main
natuke	doc_980560860270_item	2966115	et	4	main
avab	doc_980560860270_item	2966121	et	3	main
paneb	doc_980560860270_item	2966128	et	3	main
masinasse	doc_980560860270_item	2966131	et	4	main
läks	doc_980560860270_item	2966137	et	3	main
paaris	doc_980560860270_item	2966143	et	4	main
pangas	doc_980560860270_item	2966146	et	4	main
toob	doc_980560860270_item	2966155	et	3	main
ta	doc_980560860270_item	2966164	et	4	main
istus	doc_980560860270_item	2966193	et	4	main
eesti	doc_980560860270_item	2966205	et	4	main
natuke	doc_980560860270_item	2966220	et	4	main
taga	doc_980560860270_item	2966222	et	4	main
teeb	doc_980560860270_item	2966229	et	3	main
kontrolltöö	doc_980560860269_item	2965740	et	4	main
pean	doc_980560860269_item	2965749	et	4	main
täna	doc_980560860269_item	2965750	et	4	main
tahan	doc_980560860269_item	2965757	et	3	main
kohvi	doc_980560860269_item	2965780	et	4	main
tohi	doc_980560860269_item	2965786	et	4	main
süüa	doc_980560860269_item	2965787	et	3	main
ega	doc_980560860269_item	2965788	et	3	main
sa	doc_980560860269_item	2965791	et	3	main
kadrioru	doc_980560860269_item	2965794	et	3	main
jooksma	doc_980560860269_item	2965796	et	3	main
magas	doc_980560860269_item	2965818	et	4	main
kaua	doc_980560860269_item	2965819	et	3	main
kell	doc_980560860269_item	2965820	et	3	main
ma	doc_980560860269_item	2965748	et	3	main
õppima	doc_980560860269_item	2965752	et	3	main
aga	doc_980560860269_item	2965755	et	3	main
täna	doc_980560860269_item	2965758	et	4	main
meeldib	doc_980560860269_item	2965764	et	3	main
klaver	doc_980560860269_item	2965765	et	3	main
mängida	doc_980560860269_item	2965766	et	3	main
ja	doc_980560860269_item	2965767	et	3	main
eesti	doc_980560860269_item	2965768	et	4	main
keelt	doc_980560860269_item	2965769	et	4	main
õppida	doc_980560860269_item	2965770	et	3	main
kui	doc_980560860269_item	2965771	et	3	main
ilus	doc_980560860269_item	2965772	et	4	main
ilm	doc_980560860269_item	2965773	et	3	main
on	doc_980560860269_item	2965774	et	4	main
lähen	doc_980560860269_item	2965775	et	3	main
raekoja	doc_980560860269_item	2965776	et	3	main
platsile	doc_980560860269_item	2965777	et	4	main
jaalutama	doc_980560860269_item	2965778	et	4	main
ja	doc_980560860269_item	2965779	et	3	main
eesti	doc_980560860269_item	2965782	et	4	main
on	doc_980560860269_item	2965806	et	4	main
oli	doc_980560860269_item	2965807	et	3	main
teisipäev	doc_980560860269_item	2965808	et	3	main
saab	doc_980560860269_item	2965812	et	3	main
ärkab	doc_980560860269_item	2965822	et	3	main
jõi	doc_980560860269_item	2965828	et	3	main
sööb	doc_980560860269_item	2965831	et	3	main
pidani	doc_980560860269_item	2965840	et	4	main
tegema	doc_980560860269_item	2965845	et	3	main
ta	doc_980560860269_item	2965846	et	4	main
avab	doc_980560860269_item	2965847	et	3	main
avas	doc_980560860269_item	2965848	et	4	main
failid	doc_980560860269_item	2965849	et	3	main
ja	doc_980560860269_item	2965850	et	3	main
kirjutab	doc_980560860269_item	2965851	et	3	main
kirjutas	doc_980560860269_item	2965852	et	3	main
masina	doc_980560860269_item	2965859	et	3	main
läisk	doc_980560860269_item	2965863	et	4	main
paaris	doc_980560860269_item	2965869	et	4	main
ja	doc_980560860269_item	2965871	et	3	main
vanalinnas	doc_980560860269_item	2965873	et	4	main
astub	doc_980560860269_item	2965874	et	3	main
astus	doc_980560860269_item	2965875	et	3	main
eesti	doc_980560860269_item	2965878	et	4	main
ning	doc_980560860269_item	2965922	et	3	main
animafilmi	doc_980560860269_item	2965932	et	4	main
old	doc_980560860269_item	2965934	et	4	main
man	doc_980560860269_item	2965935	et	3	main
uudiseid	doc_980560860269_item	2965942	et	3	main
tõi	doc_980560860269_item	2965944	et	3	main
natuke	doc_980560860269_item	2965946	et	4	main
arvuti	doc_980560860269_item	2965947	et	4	main
valmis	doc_980560860269_item	2965957	et	4	main
eesti	doc_980560860269_item	2965958	et	4	main
oli	doc_980560860269_item	2965967	et	3	main
3	doc_980560860269_item	2965970	et	2	main
eile	doc_980560860269_item	2965974	et	3	main
kell	doc_980560860269_item	2965978	et	3	main
ja	doc_980560860269_item	2965986	et	3	main
läisk	doc_980560860269_item	2965997	et	4	main
lõpeta	doc_980560860270_item	2966020	et	4	main
laused	doc_980560860270_item	2966021	et	3	main
või	doc_980560860270_item	2966023	et	4	main
infinitiiviga	doc_980560860270_item	2966025	et	3	main
jööma	doc_980560860270_item	2966032	et	4	main
ma	doc_980560860270_item	2966034	et	3	main
täna	doc_980560860270_item	2966036	et	4	main
ja	doc_980560860270_item	2966038	et	3	main
ilus	doc_980560860270_item	2966047	et	4	main
lähen	doc_980560860270_item	2966050	et	3	main
minevikku	doc_980560860270_item	2966076	et	4	main
marju	doc_980560860270_item	2966077	et	3	main
võileiba	doc_980560860270_item	2966107	et	4	main
peab	doc_980560860270_item	2966113	et	4	main
tööd	doc_980560860270_item	2966118	et	4	main
avas	doc_980560860270_item	2966122	et	4	main
pani	doc_980560860270_item	2966129	et	4	main
käis	doc_980560860270_item	2966142	et	4	main
eesti	doc_980560860270_item	2966152	et	4	main
instituudist	doc_980560860270_item	2966153	et	3	main
ning	doc_980560860270_item	2966154	et	3	main
tõi	doc_980560860270_item	2966156	et	3	main
ära	doc_980560860270_item	2966158	et	4	main
sõitis	doc_980560860270_item	2966163	et	3	main
kodus	doc_980560860270_item	2966166	et	4	main
tees	doc_980560860270_item	2966168	et	4	main
ta	doc_980560860270_item	2966194	et	4	main
vannis	doc_980560860270_item	2966195	et	3	main
ning	doc_980560860270_item	2966196	et	3	main
animafilmi	doc_980560860270_item	2966206	et	4	main
old	doc_980560860270_item	2966208	et	4	main
pärnast	doc_980560860270_item	2966211	et	4	main
kuulas	doc_980560860270_item	2966214	et	3	main
ta	doc_980560860270_item	2966215	et	4	main
uudiseid	doc_980560860270_item	2966216	et	3	main
töötab	doc_980560860270_item	2966217	et	3	main
töötas	doc_980560860270_item	2966218	et	3	main
jutustas	doc_980560860270_item	2966225	et	3	main
tartu	doc_980560860270_item	2966227	et	4	main
keele	doc_980560860270_item	2966233	et	4	main
testi	doc_980560860270_item	2966234	et	4	main
ei	doc_980560860269_item	2965785	et	4	main
ka	doc_980560860269_item	2965793	et	3	main
vaba	doc_980560860269_item	2965809	et	4	main
sai	doc_980560860269_item	2965813	et	4	main
1030	doc_980560860269_item	2965821	et	2	main
üles	doc_980560860269_item	2965825	et	3	main
kohvi	doc_980560860269_item	2965830	et	4	main
sõi	doc_980560860269_item	2965832	et	3	main
ja	doc_980560860269_item	2965834	et	3	main
loeb	doc_980560860269_item	2965835	et	3	main
natuke	doc_980560860269_item	2965841	et	4	main
masinasse	doc_980560860269_item	2965857	et	4	main
ja	doc_980560860269_item	2965858	et	3	main
poes	doc_980560860269_item	2965870	et	3	main
pangas	doc_980560860269_item	2965872	et	4	main
vaatab	doc_980560860269_item	2965923	et	3	main
filmi	doc_980560860269_item	2965926	et	4	main
film	doc_980560860269_item	2965928	et	3	main
räägis	doc_980560860269_item	2965930	et	3	main
kuulab	doc_980560860269_item	2965939	et	3	main
taga	doc_980560860269_item	2965948	et	4	main
keele	doc_980560860269_item	2965959	et	4	main
testi	doc_980560860269_item	2965960	et	4	main
ning	doc_980560860269_item	2965961	et	3	main
läheb	doc_980560860269_item	2965962	et	3	main
mida	doc_980560860269_item	2965972	et	4	main
tegid	doc_980560860269_item	2965975	et	4	main
pesin	doc_980560860269_item	2965984	et	3	main
sõin	doc_980560860269_item	2965987	et	3	main
teed	doc_980560860269_item	2965995	et	4	main
ja	doc_980560860269_item	2965996	et	3	main
õppisin	doc_980560860269_item	2966011	et	3	main
ja	doc_980560860269_item	2966014	et	3	main
platsile	doc_980560860269_item	2966017	et	4	main
kontrolltöö	doc_980560860270_item	2966018	et	4	main
1	doc_980560860270_item	2966019	et	2	main
veel	doc_980560860270_item	2966029	et	4	main
kui	doc_980560860270_item	2966046	et	3	main
platsile	doc_980560860270_item	2966052	et	4	main
vaatada	doc_980560860270_item	2966053	et	4	main
ja	doc_980560860270_item	2966054	et	3	main
tuleda	doc_980560860270_item	2966055	et	4	main
tohi	doc_980560860270_item	2966060	et	4	main
rääkida	doc_980560860270_item	2966061	et	3	main
ega	doc_980560860270_item	2966062	et	3	main
õpida	doc_980560860270_item	2966063	et	4	main
e-kirju	doc_980560860270_item	2966111	et	4	main
pea	doc_980560860270_item	2966114	et	4	main
kirjutab	doc_980560860270_item	2966125	et	3	main
kirjutas	doc_980560860270_item	2966126	et	3	main
pesu	doc_980560860270_item	2966130	et	4	main
ja	doc_980560860270_item	2966132	et	3	main
masina	doc_980560860270_item	2966133	et	3	main
tööle	doc_980560860270_item	2966134	et	3	main
läheb	doc_980560860270_item	2966136	et	3	main
läbi	doc_980560860270_item	2966151	et	4	main
sõidab	doc_980560860270_item	2966162	et	3	main
trolliga	doc_980560860270_item	2966165	et	4	main
teeb	doc_980560860270_item	2966167	et	3	main
vaatab	doc_980560860270_item	2966197	et	3	main
vaatas	doc_980560860270_item	2966198	et	3	main
veel	doc_980560860270_item	2966219	et	4	main
jutustab	doc_980560860270_item	2966224	et	3	main
eesti	doc_980560860270_item	2966232	et	4	main
üle	doc_980560860270_item	2966242	et	3	main
ostasin	doc_980560860270_item	2966251	et	4	main
piima	doc_980560860270_item	2966253	et	4	main
ja	doc_980560860270_item	2966255	et	3	main
läksin	doc_980560860270_item	2966258	et	3	main
õppisin	doc_980560860270_item	2966261	et	3	main
ma	doc_980560860270_item	2966264	et	3	main
pildid	doc_980560860270_item	2966266	et	3	main
ja	doc_980560860270_item	2966268	et	3	main
vilniuselt	doc_980560860270_item	2966269	et	4	main
sõin	doc_980560860270_item	2966271	et	3	main
pean	doc_980560860271_item	2966288	et	4	main
täna	doc_980560860271_item	2966289	et	4	main
ärkas	doc_980560860269_item	2965823	et	3	main
ta	doc_980560860269_item	2965829	et	4	main
võileiba	doc_980560860269_item	2965833	et	4	main
loes	doc_980560860269_item	2965836	et	3	main
arvuti	doc_980560860269_item	2965842	et	4	main
pärastlõunal	doc_980560860269_item	2965861	et	3	main
ta	doc_980560860269_item	2965876	et	4	main
toob	doc_980560860269_item	2965881	et	3	main
töis	doc_980560860269_item	2965882	et	3	main
sealt	doc_980560860269_item	2965883	et	4	main
ära	doc_980560860269_item	2965884	et	4	main
mõned	doc_980560860269_item	2965885	et	3	main
raamatud	doc_980560860269_item	2965886	et	4	main
koju	doc_980560860269_item	2965887	et	3	main
sõidab	doc_980560860269_item	2965888	et	3	main
sõis	doc_980560860269_item	2965889	et	4	main
ta	doc_980560860269_item	2965890	et	4	main
trolliga	doc_980560860269_item	2965891	et	4	main
kodus	doc_980560860269_item	2965892	et	4	main
teeb	doc_980560860269_item	2965893	et	3	main
tees	doc_980560860269_item	2965894	et	4	main
marju	doc_980560860269_item	2965895	et	3	main
spagette	doc_980560860269_item	2965896	et	4	main
õhtul	doc_980560860269_item	2965897	et	3	main
helistab	doc_980560860269_item	2965898	et	3	main
helistas	doc_980560860269_item	2965899	et	3	main
talle	doc_980560860269_item	2965900	et	4	main
üks	doc_980560860269_item	2965901	et	3	main
sõber	doc_980560860269_item	2965902	et	3	main
ning	doc_980560860269_item	2965903	et	3	main
nad	doc_980560860269_item	2965904	et	3	main
otsustavad	doc_980560860269_item	2965905	et	4	main
otsustasid	doc_980560860269_item	2965906	et	4	main
minna	doc_980560860269_item	2965907	et	3	main
jooksma	doc_980560860269_item	2965908	et	3	main
nad	doc_980560860269_item	2965909	et	3	main
jooksevad	doc_980560860269_item	2965910	et	4	main
jooksesid	doc_980560860269_item	2965911	et	4	main
metsas	doc_980560860269_item	2965912	et	3	main
umbes	doc_980560860269_item	2965913	et	4	main
tund	doc_980560860269_item	2965914	et	3	main
aega	doc_980560860269_item	2965915	et	4	main
õhtul	doc_980560860269_item	2965916	et	3	main
kodus	doc_980560860269_item	2965917	et	4	main
istub	doc_980560860269_item	2965918	et	3	main
istus	doc_980560860269_item	2965919	et	4	main
ära	doc_980560860269_item	2965925	et	4	main
pärnography	doc_980560860269_item	2965927	et	4	main
räägib	doc_980560860269_item	2965929	et	3	main
eesti	doc_980560860269_item	2965931	et	4	main
pärnast	doc_980560860269_item	2965937	et	4	main
läisk	doc_980560860269_item	2965963	et	4	main
magama	doc_980560860269_item	2965964	et	3	main
kell	doc_980560860269_item	2965965	et	3	main
on	doc_980560860269_item	2965966	et	4	main
sina	doc_980560860269_item	2965973	et	4	main
seitse	doc_980560860269_item	2965979	et	3	main
hambaid	doc_980560860269_item	2965985	et	3	main
võileiba	doc_980560860269_item	2965988	et	4	main
raekoja	doc_980560860269_item	2966016	et	3	main
ma	doc_980560860270_item	2966026	et	3	main
sööma	doc_980560860270_item	2966030	et	4	main
öpida	doc_980560860270_item	2966037	et	4	main
mulle	doc_980560860270_item	2966040	et	4	main
meeldib	doc_980560860270_item	2966041	et	3	main
ujuda	doc_980560860270_item	2966042	et	3	main
ja	doc_980560860270_item	2966043	et	3	main
televiisorit	doc_980560860270_item	2966045	et	3	main
on	doc_980560860270_item	2966049	et	4	main
raekoja	doc_980560860270_item	2966051	et	3	main
tuled	doc_980560860270_item	2966066	et	4	main
öpima	doc_980560860270_item	2966070	et	4	main
ja	doc_980560860270_item	2966071	et	3	main
istuma	doc_980560860270_item	2966072	et	3	main
arvuti	doc_980560860270_item	2966116	et	4	main
taga	doc_980560860270_item	2966117	et	4	main
tegema	doc_980560860270_item	2966119	et	3	main
siis	doc_980560860269_item	2965938	et	3	main
kuulas	doc_980560860269_item	2965940	et	3	main
töötab	doc_980560860269_item	2965943	et	3	main
ning	doc_980560860269_item	2965949	et	3	main
jutustab	doc_980560860269_item	2965950	et	3	main
jutustas	doc_980560860269_item	2965951	et	3	main
ühe	doc_980560860269_item	2965952	et	4	main
tartu	doc_980560860269_item	2965953	et	4	main
sõbraga	doc_980560860269_item	2965954	et	3	main
teeb	doc_980560860269_item	2965955	et	3	main
tees	doc_980560860269_item	2965956	et	4	main
üle	doc_980560860269_item	2965968	et	3	main
südaöö	doc_980560860269_item	2965969	et	4	main
kirjuta	doc_980560860269_item	2965971	et	4	main
ärkasin	doc_980560860269_item	2965977	et	3	main
ja	doc_980560860269_item	2965980	et	3	main
vannituba	doc_980560860269_item	2965982	et	4	main
jogurtit	doc_980560860269_item	2965990	et	3	main
banaani	doc_980560860269_item	2965992	et	4	main
ma	doc_980560860269_item	2965993	et	3	main
join	doc_980560860269_item	2965994	et	4	main
ülikoolil	doc_980560860269_item	2965999	et	4	main
ma	doc_980560860269_item	2966000	et	3	main
õppisin	doc_980560860269_item	2966001	et	3	main
õhtul	doc_980560860269_item	2966002	et	3	main
ma	doc_980560860269_item	2966003	et	3	main
sõin	doc_980560860269_item	2966004	et	3	main
brokoli	doc_980560860269_item	2966005	et	4	main
ja	doc_980560860269_item	2966006	et	3	main
kala	doc_980560860269_item	2966007	et	4	main
ma	doc_980560860269_item	2966008	et	3	main
vaatasin	doc_980560860269_item	2966009	et	3	main
inglise	doc_980560860269_item	2966012	et	4	main
keelt	doc_980560860269_item	2966013	et	4	main
läisk	doc_980560860269_item	2966015	et	4	main
aga	doc_980560860270_item	2966033	et	3	main
ilm	doc_980560860270_item	2966048	et	3	main
keele	doc_980560860270_item	2966057	et	4	main
tunnis	doc_980560860270_item	2966058	et	3	main
ei	doc_980560860270_item	2966059	et	4	main
sa	doc_980560860270_item	2966065	et	3	main
ka	doc_980560860270_item	2966067	et	3	main
parki	doc_980560860270_item	2966069	et	4	main
2	doc_980560860270_item	2966073	et	2	main
pane	doc_980560860270_item	2966074	et	4	main
tekst	doc_980560860270_item	2966075	et	3	main
päev	doc_980560860270_item	2966078	et	3	main
marjul	doc_980560860270_item	2966079	et	3	main
on	doc_980560860270_item	2966080	et	4	main
oli	doc_980560860270_item	2966081	et	3	main
teisipäev	doc_980560860270_item	2966082	et	3	main
vaba	doc_980560860270_item	2966083	et	4	main
päev	doc_980560860270_item	2966084	et	3	main
saab	doc_980560860270_item	2966086	et	3	main
lõpuks	doc_980560860270_item	2966085	et	4	main
sai	doc_980560860270_item	2966087	et	4	main
magada	doc_980560860270_item	2966089	et	3	main
ta	doc_980560860270_item	2966088	et	4	main
ta	doc_980560860270_item	2966090	et	4	main
magab	doc_980560860270_item	2966091	et	3	main
magas	doc_980560860270_item	2966092	et	4	main
kaua	doc_980560860270_item	2966093	et	3	main
kell	doc_980560860270_item	2966094	et	3	main
1030	doc_980560860270_item	2966095	et	2	main
ärkab	doc_980560860270_item	2966096	et	3	main
ärkas	doc_980560860270_item	2966097	et	3	main
ta	doc_980560860270_item	2966098	et	4	main
üles	doc_980560860270_item	2966099	et	3	main
siis	doc_980560860270_item	2966100	et	3	main
joob	doc_980560860270_item	2966101	et	3	main
jõi	doc_980560860270_item	2966102	et	3	main
ta	doc_980560860270_item	2966103	et	4	main
sööb	doc_980560860270_item	2966105	et	3	main
sõi	doc_980560860270_item	2966106	et	3	main
kohvi	doc_980560860270_item	2966104	et	4	main
ta	doc_980560860270_item	2966112	et	4	main
ta	doc_980560860270_item	2966120	et	4	main
failid	doc_980560860270_item	2966123	et	3	main
ta	doc_980560860270_item	2966140	et	4	main
käib	doc_980560860270_item	2966141	et	3	main
ja	doc_980560860270_item	2966145	et	3	main
vanalinnas	doc_980560860270_item	2966147	et	4	main
astub	doc_980560860270_item	2966148	et	3	main
astus	doc_980560860270_item	2966149	et	3	main
ta	doc_980560860270_item	2966150	et	4	main
sealt	doc_980560860270_item	2966157	et	4	main
mõned	doc_980560860270_item	2966159	et	3	main
raamatud	doc_980560860270_item	2966160	et	4	main
koju	doc_980560860270_item	2966161	et	3	main
filmi	doc_980560860270_item	2966200	et	4	main
film	doc_980560860270_item	2966202	et	3	main
räägib	doc_980560860270_item	2966203	et	3	main
räägis	doc_980560860270_item	2966204	et	3	main
priit	doc_980560860270_item	2966210	et	3	main
siis	doc_980560860270_item	2966212	et	3	main
kuulab	doc_980560860270_item	2966213	et	3	main
arvuti	doc_980560860270_item	2966221	et	4	main
3	doc_980560860270_item	2966244	et	2	main
eesti	doc_980560860270_item	2966262	et	4	main
rigalt	doc_980560860270_item	2966267	et	4	main
ma	doc_980560860270_item	2966270	et	3	main
makaronid	doc_980560860270_item	2966272	et	3	main
ja	doc_980560860270_item	2966273	et	3	main
tomati	doc_980560860270_item	2966274	et	3	main
sauce	doc_980560860270_item	2966275	et	4	main
soose	doc_980560860270_item	2966276	et	3	main
da	doc_980560860271_item	2966285	et	4	main
ma	doc_980560860271_item	2966287	et	3	main
ujuda	doc_980560860271_item	2966298	et	3	main
tunnis	doc_980560860271_item	2966322	et	3	main
ei	doc_980560860271_item	2966323	et	4	main
tohi	doc_980560860271_item	2966324	et	4	main
rääkida	doc_980560860271_item	2966325	et	3	main
ega	doc_980560860271_item	2966326	et	3	main
kirjutada	doc_980560860271_item	2966327	et	3	main
kas	doc_980560860271_item	2966328	et	3	main
parki	doc_980560860271_item	2966333	et	4	main
ja	doc_980560860271_item	2966335	et	3	main
2	doc_980560860271_item	2966337	et	2	main
oli	doc_980560860271_item	2966345	et	3	main
magada	doc_980560860271_item	2966353	et	3	main
ta	doc_980560860271_item	2966354	et	4	main
magab	doc_980560860271_item	2966355	et	3	main
magasi	doc_980560860271_item	2966356	et	3	main
kaua	doc_980560860271_item	2966357	et	3	main
lugesis	doc_980560860271_item	2966374	et	4	main
natuke	doc_980560860271_item	2966379	et	4	main
failid	doc_980560860271_item	2966387	et	3	main
ja	doc_980560860271_item	2966388	et	3	main
kirjutab	doc_980560860271_item	2966389	et	3	main
läks	doc_980560860271_item	2966401	et	3	main
ära	doc_980560860271_item	2966422	et	4	main
raamatud	doc_980560860271_item	2966424	et	4	main
koju	doc_980560860271_item	2966425	et	3	main
spagette	doc_980560860271_item	2966434	et	4	main
õhtul	doc_980560860271_item	2966435	et	3	main
helistas	doc_980560860271_item	2966437	et	3	main
nad	doc_980560860271_item	2966442	et	3	main
ta	doc_980560860271_item	2966458	et	4	main
vannis	doc_980560860271_item	2966459	et	3	main
ning	doc_980560860271_item	2966460	et	3	main
vaatab	doc_980560860271_item	2966461	et	3	main
vaatas	doc_980560860271_item	2966462	et	3	main
eesti	doc_980560860271_item	2966469	et	4	main
old	doc_980560860271_item	2966472	et	4	main
läheb	doc_980560860271_item	2966500	et	3	main
on	doc_980560860271_item	2966504	et	4	main
oli	doc_980560860271_item	2966505	et	3	main
üle	doc_980560860271_item	2966506	et	3	main
südaöö	doc_980560860271_item	2966507	et	4	main
ja	doc_980560860271_item	2966517	et	3	main
filmi	doc_980560860271_item	2966519	et	4	main
järvi	doc_980560860271_item	2966520	et	4	main
ja	doc_980560860270_item	2966124	et	3	main
ta	doc_980560860270_item	2966127	et	4	main
pärastlõunal	doc_980560860270_item	2966135	et	3	main
ta	doc_980560860270_item	2966138	et	4	main
linna	doc_980560860270_item	2966139	et	4	main
poes	doc_980560860270_item	2966144	et	3	main
marju	doc_980560860270_item	2966169	et	3	main
spagette	doc_980560860270_item	2966170	et	4	main
õhtul	doc_980560860270_item	2966171	et	3	main
helistab	doc_980560860270_item	2966172	et	3	main
helistas	doc_980560860270_item	2966173	et	3	main
talle	doc_980560860270_item	2966174	et	4	main
üks	doc_980560860270_item	2966175	et	3	main
sõber	doc_980560860270_item	2966176	et	3	main
ning	doc_980560860270_item	2966177	et	3	main
nad	doc_980560860270_item	2966178	et	3	main
otsustavad	doc_980560860270_item	2966179	et	4	main
otsustasid	doc_980560860270_item	2966180	et	4	main
minna	doc_980560860270_item	2966181	et	3	main
jooksma	doc_980560860270_item	2966182	et	3	main
nad	doc_980560860270_item	2966183	et	3	main
jooksevad	doc_980560860270_item	2966184	et	4	main
jõid	doc_980560860270_item	2966185	et	4	main
metsas	doc_980560860270_item	2966186	et	3	main
umbes	doc_980560860270_item	2966187	et	4	main
tund	doc_980560860270_item	2966188	et	3	main
aega	doc_980560860270_item	2966189	et	4	main
õhtul	doc_980560860270_item	2966190	et	3	main
kodus	doc_980560860270_item	2966191	et	4	main
istub	doc_980560860270_item	2966192	et	3	main
ära	doc_980560860270_item	2966199	et	4	main
pärnography	doc_980560860270_item	2966201	et	4	main
grand	doc_980560860270_item	2966207	et	3	main
man	doc_980560860270_item	2966209	et	3	main
ning	doc_980560860270_item	2966223	et	3	main
ühe	doc_980560860270_item	2966226	et	4	main
sõbraga	doc_980560860270_item	2966228	et	3	main
tees	doc_980560860270_item	2966230	et	4	main
valmis	doc_980560860270_item	2966231	et	4	main
oli	doc_980560860270_item	2966241	et	3	main
kirjuta	doc_980560860270_item	2966245	et	4	main
sina	doc_980560860270_item	2966247	et	4	main
eile	doc_980560860270_item	2966248	et	3	main
tegid	doc_980560860270_item	2966249	et	4	main
ma	doc_980560860270_item	2966250	et	3	main
ja	doc_980560860270_item	2966277	et	3	main
banan	doc_980560860270_item	2966278	et	4	main
ma	doc_980560860271_item	2966283	et	3	main
ja	doc_980560860271_item	2966299	et	3	main
magada	doc_980560860271_item	2966300	et	3	main
mulle	doc_980560860271_item	2966301	et	4	main
meeldib	doc_980560860271_item	2966302	et	3	main
muusika	doc_980560860271_item	2966303	et	4	main
kuulama	doc_980560860271_item	2966304	et	3	main
ja	doc_980560860271_item	2966305	et	3	main
filmi	doc_980560860271_item	2966306	et	4	main
vaatama	doc_980560860271_item	2966307	et	3	main
kui	doc_980560860271_item	2966308	et	3	main
ilus	doc_980560860271_item	2966309	et	4	main
ilm	doc_980560860271_item	2966310	et	3	main
on	doc_980560860271_item	2966311	et	4	main
lähen	doc_980560860271_item	2966312	et	3	main
raekoja	doc_980560860271_item	2966313	et	3	main
platsile	doc_980560860271_item	2966314	et	4	main
raamatu	doc_980560860271_item	2966315	et	4	main
lugema	doc_980560860271_item	2966316	et	4	main
ja	doc_980560860271_item	2966317	et	3	main
istuma	doc_980560860271_item	2966319	et	3	main
pubis	doc_980560860271_item	2966318	et	4	main
eesti	doc_980560860271_item	2966320	et	4	main
kadrioru	doc_980560860271_item	2966332	et	3	main
jalutama	doc_980560860271_item	2966334	et	3	main
jooksima	doc_980560860271_item	2966336	et	4	main
päev	doc_980560860271_item	2966342	et	3	main
ta	doc_980560860271_item	2966352	et	4	main
ärkas	doc_980560860271_item	2966361	et	3	main
üles	doc_980560860271_item	2966363	et	3	main
joob	doc_980560860271_item	2966365	et	3	main
e-kirju	doc_980560860271_item	2966375	et	4	main
arvuti	doc_980560860271_item	2966380	et	4	main
tööd	doc_980560860271_item	2966382	et	4	main
tegema	doc_980560860271_item	2966383	et	3	main
ta	doc_980560860271_item	2966384	et	4	main
avab	doc_980560860271_item	2966385	et	3	main
paneb	doc_980560860271_item	2966392	et	3	main
paaris	doc_980560860271_item	2966407	et	4	main
poes	doc_980560860271_item	2966408	et	3	main
sealt	doc_980560860271_item	2966421	et	4	main
kodus	doc_980560860271_item	2966430	et	4	main
teeb	doc_980560860271_item	2966431	et	3	main
talle	doc_980560860271_item	2966438	et	4	main
ning	doc_980560860271_item	2966441	et	3	main
otsustavad	doc_980560860271_item	2966443	et	4	main
otsustasid	doc_980560860271_item	2966444	et	4	main
ning	doc_980560860270_item	2966235	et	3	main
läheb	doc_980560860270_item	2966236	et	3	main
läks	doc_980560860270_item	2966237	et	3	main
magama	doc_980560860270_item	2966238	et	3	main
kell	doc_980560860270_item	2966239	et	3	main
on	doc_980560860270_item	2966240	et	4	main
singi	doc_980560860270_item	2966254	et	3	main
ma	doc_980560860270_item	2966257	et	3	main
politseisse	doc_980560860270_item	2966259	et	3	main
keelt	doc_980560860270_item	2966263	et	4	main
vaatasin	doc_980560860270_item	2966265	et	3	main
1	doc_980560860271_item	2966280	et	2	main
lõpeta	doc_980560860271_item	2966281	et	4	main
laused	doc_980560860271_item	2966282	et	3	main
või	doc_980560860271_item	2966284	et	4	main
infinitiiviga	doc_980560860271_item	2966286	et	3	main
täna	doc_980560860271_item	2966297	et	4	main
keele	doc_980560860271_item	2966321	et	4	main
ka	doc_980560860271_item	2966331	et	3	main
pane	doc_980560860271_item	2966338	et	4	main
minevikku	doc_980560860271_item	2966340	et	4	main
vaba	doc_980560860271_item	2966347	et	4	main
kell	doc_980560860271_item	2966358	et	3	main
jõi	doc_980560860271_item	2966366	et	3	main
pidi	doc_980560860271_item	2966378	et	4	main
pani	doc_980560860271_item	2966393	et	4	main
pesu	doc_980560860271_item	2966394	et	4	main
ta	doc_980560860271_item	2966402	et	4	main
ta	doc_980560860271_item	2966404	et	4	main
käib	doc_980560860271_item	2966405	et	3	main
südaöö	doc_980560860270_item	2966243	et	4	main
mida	doc_980560860270_item	2966246	et	4	main
pirnid	doc_980560860270_item	2966252	et	3	main
leiva	doc_980560860270_item	2966256	et	3	main
ma	doc_980560860270_item	2966260	et	3	main
kontrolltöö	doc_980560860271_item	2966279	et	4	main
veel	doc_980560860271_item	2966290	et	4	main
õppima	doc_980560860271_item	2966291	et	3	main
ja	doc_980560860271_item	2966292	et	3	main
jalutama	doc_980560860271_item	2966293	et	3	main
aga	doc_980560860271_item	2966294	et	3	main
ma	doc_980560860271_item	2966295	et	3	main
tahan	doc_980560860271_item	2966296	et	3	main
tekst	doc_980560860271_item	2966339	et	3	main
marju	doc_980560860271_item	2966341	et	3	main
on	doc_980560860271_item	2966344	et	4	main
teisipäev	doc_980560860271_item	2966346	et	3	main
päev	doc_980560860271_item	2966348	et	3	main
saab	doc_980560860271_item	2966350	et	3	main
sai	doc_980560860271_item	2966351	et	4	main
ärkab	doc_980560860271_item	2966360	et	3	main
ta	doc_980560860271_item	2966362	et	4	main
siis	doc_980560860271_item	2966364	et	3	main
ta	doc_980560860271_item	2966367	et	4	main
kohvi	doc_980560860271_item	2966368	et	4	main
sööb	doc_980560860271_item	2966369	et	3	main
sõi	doc_980560860271_item	2966370	et	3	main
peab	doc_980560860271_item	2966377	et	4	main
avasis	doc_980560860271_item	2966386	et	4	main
kirjutas	doc_980560860271_item	2966390	et	3	main
läheb	doc_980560860271_item	2966400	et	3	main
linna	doc_980560860271_item	2966403	et	4	main
käis	doc_980560860271_item	2966406	et	4	main
trolliga	doc_980560860271_item	2966429	et	4	main
jooksevad	doc_980560860271_item	2966448	et	4	main
tund	doc_980560860271_item	2966452	et	3	main
aega	doc_980560860271_item	2966453	et	4	main
eile	doc_980560860271_item	2966512	et	3	main
maja	doc_980560860271_item	2966521	et	4	main
veel	doc_980560860271_item	2966524	et	4	main
eesti	doc_980560860271_item	2966526	et	4	main
keelt	doc_980560860271_item	2966527	et	4	main
eile	doc_980560860271_item	2966528	et	3	main
oli	doc_980560860271_item	2966529	et	3	main
sa	doc_980560860271_item	2966329	et	3	main
tuled	doc_980560860271_item	2966330	et	4	main
marjul	doc_980560860271_item	2966343	et	3	main
lõpuks	doc_980560860271_item	2966349	et	4	main
1030	doc_980560860271_item	2966359	et	2	main
võileiba	doc_980560860271_item	2966371	et	4	main
ja	doc_980560860271_item	2966372	et	3	main
loeb	doc_980560860271_item	2966373	et	3	main
ta	doc_980560860271_item	2966376	et	4	main
taga	doc_980560860271_item	2966381	et	4	main
ta	doc_980560860271_item	2966391	et	4	main
masinasse	doc_980560860271_item	2966395	et	4	main
ja	doc_980560860271_item	2966396	et	3	main
masina	doc_980560860271_item	2966397	et	3	main
tööle	doc_980560860271_item	2966398	et	3	main
pärastlõunal	doc_980560860271_item	2966399	et	3	main
ja	doc_980560860271_item	2966409	et	3	main
pangas	doc_980560860271_item	2966410	et	4	main
vanalinnas	doc_980560860271_item	2966411	et	4	main
astub	doc_980560860271_item	2966412	et	3	main
astus	doc_980560860271_item	2966413	et	3	main
ta	doc_980560860271_item	2966414	et	4	main
läbi	doc_980560860271_item	2966415	et	4	main
eesti	doc_980560860271_item	2966416	et	4	main
instituudist	doc_980560860271_item	2966417	et	3	main
ning	doc_980560860271_item	2966418	et	3	main
toob	doc_980560860271_item	2966419	et	3	main
tõi	doc_980560860271_item	2966420	et	3	main
ta	doc_980560860271_item	2966428	et	4	main
marju	doc_980560860271_item	2966433	et	3	main
üks	doc_980560860271_item	2966439	et	3	main
sõber	doc_980560860271_item	2966440	et	3	main
metsas	doc_980560860271_item	2966450	et	3	main
õhtul	doc_980560860271_item	2966454	et	3	main
pärnography	doc_980560860271_item	2966465	et	4	main
film	doc_980560860271_item	2966466	et	3	main
grand	doc_980560860271_item	2966471	et	3	main
3	doc_980560860271_item	2966508	et	2	main
mida	doc_980560860271_item	2966510	et	4	main
ilus	doc_980560860271_item	2966530	et	4	main
päeva	doc_980560860271_item	2966531	et	4	main
ja	doc_980560860271_item	2966532	et	3	main
mõned	doc_980560860271_item	2966423	et	3	main
sõidab	doc_980560860271_item	2966426	et	3	main
sõidas	doc_980560860271_item	2966427	et	4	main
tegi	doc_980560860271_item	2966432	et	4	main
helistab	doc_980560860271_item	2966436	et	3	main
jooksid	doc_980560860271_item	2966449	et	4	main
ära	doc_980560860271_item	2966463	et	4	main
filmi	doc_980560860271_item	2966464	et	4	main
animafilmi	doc_980560860271_item	2966470	et	4	main
man	doc_980560860271_item	2966473	et	3	main
priit	doc_980560860271_item	2966474	et	3	main
pärnast	doc_980560860271_item	2966475	et	4	main
siis	doc_980560860271_item	2966476	et	3	main
kuulab	doc_980560860271_item	2966477	et	3	main
kuulasit	doc_980560860271_item	2966478	et	4	main
ta	doc_980560860271_item	2966479	et	4	main
uudiseid	doc_980560860271_item	2966480	et	3	main
töötab	doc_980560860271_item	2966481	et	3	main
töötas	doc_980560860271_item	2966482	et	3	main
veel	doc_980560860271_item	2966483	et	4	main
natuke	doc_980560860271_item	2966484	et	4	main
arvuti	doc_980560860271_item	2966485	et	4	main
taga	doc_980560860271_item	2966486	et	4	main
ning	doc_980560860271_item	2966487	et	3	main
jutustab	doc_980560860271_item	2966488	et	3	main
jutustas	doc_980560860271_item	2966489	et	3	main
ühe	doc_980560860271_item	2966490	et	4	main
tartu	doc_980560860271_item	2966491	et	4	main
sõbraga	doc_980560860271_item	2966492	et	3	main
teeb	doc_980560860271_item	2966493	et	3	main
tegi	doc_980560860271_item	2966494	et	4	main
valmis	doc_980560860271_item	2966495	et	4	main
eesti	doc_980560860271_item	2966496	et	4	main
keele	doc_980560860271_item	2966497	et	4	main
minna	doc_980560860271_item	2966445	et	3	main
jooksma	doc_980560860271_item	2966446	et	3	main
nad	doc_980560860271_item	2966447	et	3	main
umbes	doc_980560860271_item	2966451	et	4	main
kodus	doc_980560860271_item	2966455	et	4	main
istub	doc_980560860271_item	2966456	et	3	main
istus	doc_980560860271_item	2966457	et	4	main
räägib	doc_980560860271_item	2966467	et	3	main
räägis	doc_980560860271_item	2966468	et	3	main
ning	doc_980560860271_item	2966499	et	3	main
magama	doc_980560860271_item	2966502	et	3	main
kirjuta	doc_980560860271_item	2966509	et	4	main
vaatasin	doc_980560860271_item	2966518	et	3	main
eile	doc_980560860271_item	2966523	et	3	main
õppisin	doc_980560860271_item	2966525	et	3	main
testi	doc_980560860271_item	2966498	et	4	main
läks	doc_980560860271_item	2966501	et	3	main
kell	doc_980560860271_item	2966503	et	3	main
sina	doc_980560860271_item	2966511	et	4	main
tegid	doc_980560860271_item	2966513	et	4	main
ma	doc_980560860271_item	2966514	et	3	main
olin	doc_980560860271_item	2966515	et	3	main
kodus	doc_980560860271_item	2966516	et	4	main
ma	doc_980560860271_item	2966522	et	3	main
ilus	doc_980560860271_item	2966533	et	4	main
ilm	doc_980560860271_item	2966534	et	3	main
baktereid	doc_980560860276_item	2966912	et	3	main
oletatavasti	doc_980560860276_item	2966923	et	3	main
elavate	doc_980560860276_item	2966924	et	4	main
avastati	doc_980560860276_item	2966929	et	3	main
kolmekilomeetrise	doc_980560860276_item	2966931	et	4	main
teadlaste	doc_980560860276_item	2966942	et	3	main
soojalembeste	doc_980560860276_item	2966945	et	4	main
põhjas	doc_980560860276_item	2966951	et	4	main
leidub	doc_980560860276_item	2966952	et	3	main
saadud	doc_980560860276_item	2966956	et	4	main
annavad	doc_980560860276_item	2966958	et	3	main
teadlastele	doc_980560860276_item	2966959	et	3	main
jää	doc_980560860276_item	2966967	et	4	main
katab	doc_980560860276_item	2966968	et	3	main
tema	doc_980560860276_item	2966976	et	4	main
järve	doc_980560860276_item	2966986	et	4	main
sellised	doc_980560860276_item	2967003	et	4	main
eksisteerivad	doc_980560860276_item	2967006	et	4	main
jõuda	doc_980560860276_item	2967025	et	3	main
puurimine	doc_980560860276_item	2967029	et	4	main
m	doc_980560860276_item	2967032	et	4	main
jääkilbi	doc_980560860276_item	2967034	et	3	main
leiti	doc_980560860276_item	2967045	et	3	main
ilmselt	doc_980560860276_item	2967052	et	4	main
ladestustes	doc_980560860276_item	2967060	et	4	main
geneetilisi	doc_980560860276_item	2967063	et	3	main
jälge	doc_980560860276_item	2967064	et	4	main
tavaliselt	doc_980560860276_item	2967065	et	4	main
bakterid	doc_980560860276_item	2967068	et	3	main
on	doc_980560860276_item	2967097	et	4	main
lükkavad	doc_980560860276_item	2967103	et	4	main
vostoki	doc_980560860276_item	2967108	et	4	main
on	doc_980560860276_item	2967110	et	4	main
seega	doc_980560860276_item	2967113	et	4	main
on	doc_980560860276_item	2967114	et	4	main
arendusplaani	doc_980560860277_item	2967131	et	4	main
loomisest	doc_980560860277_item	2967152	et	4	main
tõlge	doc_980560860276_item	2966908	et	3	main
soojalembeseid	doc_980560860276_item	2966911	et	4	main
teadlastele	doc_980560860276_item	2966915	et	3	main
uue	doc_980560860276_item	2966916	et	3	main
avastuse	doc_980560860276_item	2966917	et	4	main
uurijad	doc_980560860276_item	2966918	et	4	main
leidsid	doc_980560860276_item	2966919	et	4	main
vostoki	doc_980560860276_item	2966920	et	4	main
soojalembeste	doc_980560860276_item	2966925	et	4	main
leid	doc_980560860276_item	2966928	et	4	main
segus	doc_980560860276_item	2966938	et	3	main
ja	doc_980560860276_item	2966940	et	3	main
arvamusel	doc_980560860276_item	2966943	et	3	main
olemasolu	doc_980560860276_item	2966947	et	4	main
et	doc_980560860276_item	2966949	et	3	main
veekogu	doc_980560860276_item	2966950	et	4	main
järves	doc_980560860276_item	2966965	et	4	main
pindala	doc_980560860276_item	2966977	et	4	main
km	doc_980560860276_item	2966981	et	4	main
juba	doc_980560860276_item	2966989	et	3	main
jooksul	doc_980560860276_item	2966993	et	4	main
teadlastele	doc_980560860276_item	2966997	et	3	main
et	doc_980560860276_item	2966999	et	3	main
on	doc_980560860276_item	2967001	et	4	main
säilinud	doc_980560860276_item	2967002	et	4	main
jupiteri	doc_980560860276_item	2967011	et	4	main
jääproovid	doc_980560860276_item	2967014	et	3	main
olid	doc_980560860276_item	2967015	et	4	main
ei	doc_980560860276_item	2967026	et	4	main
kuna	doc_980560860276_item	2967028	et	3	main
enne	doc_980560860276_item	2967033	et	4	main
jäätunud	doc_980560860276_item	2967041	et	4	main
järvevett	doc_980560860276_item	2967042	et	3	main
jääs	doc_980560860276_item	2967046	et	3	main
vahekihte	doc_980560860276_item	2967049	et	3	main
on	doc_980560860276_item	2967051	et	4	main
põhjast	doc_980560860276_item	2967054	et	4	main
temperatuuri	doc_980560860276_item	2967070	et	4	main
et	doc_980560860276_item	2967100	et	3	main
seisukohta	doc_980560860276_item	2967105	et	4	main
sellest	doc_980560860276_item	2967106	et	4	main
kõige	doc_980560860276_item	2967115	et	4	main
stroomi	doc_980560860277_item	2967121	et	4	main
uue	doc_980560860277_item	2967123	et	3	main
pealinna	doc_980560860277_item	2967128	et	4	main
linnavalitsus	doc_980560860277_item	2967129	et	3	main
põhja-tallinna	doc_980560860277_item	2967130	et	4	main
põhja-tallinna	doc_980560860277_item	2967146	et	4	main
linnaosa	doc_980560860277_item	2967147	et	4	main
1993aastal	doc_980560860277_item	2967153	et	3	main
arenes	doc_980560860277_item	2967154	et	3	main
linnaosa	doc_980560860277_item	2967156	et	4	main
aga	doc_980560860277_item	2967158	et	3	main
on	doc_980560860277_item	2967161	et	4	main
seni	doc_980560860277_item	2967162	et	3	main
olnud	doc_980560860277_item	2967163	et	4	main
linnaosa	doc_980560860277_item	2967168	et	4	main
ei	doc_980560860277_item	2967202	et	4	main
juba	doc_980560860277_item	2967204	et	3	main
lammutada	doc_980560860277_item	2967215	et	3	main
amortiseeritud	doc_980560860277_item	2967218	et	4	main
antarktikas	doc_980560860276_item	2966909	et	4	main
antarktika	doc_980560860276_item	2966913	et	4	main
järve	doc_980560860276_item	2966921	et	4	main
bakterite	doc_980560860276_item	2966926	et	3	main
jäljed	doc_980560860276_item	2966927	et	3	main
ja	doc_980560860276_item	2966936	et	3	main
settekivimi	doc_980560860276_item	2966937	et	4	main
prantsuse	doc_980560860276_item	2966941	et	3	main
viidab	doc_980560860276_item	2966944	et	3	main
kuumaveeallikaid	doc_980560860276_item	2966953	et	3	main
sellel	doc_980560860276_item	2966954	et	4	main
teada	doc_980560860276_item	2966961	et	3	main
kas	doc_980560860276_item	2966963	et	3	main
elu	doc_980560860276_item	2966964	et	4	main
neist	doc_980560860276_item	2966973	et	4	main
on	doc_980560860276_item	2966974	et	4	main
vostok	doc_980560860276_item	2966975	et	4	main
000	doc_980560860276_item	2966980	et	2	main
jääkilp	doc_980560860276_item	2966983	et	3	main
aasta	doc_980560860276_item	2966992	et	4	main
asjaolu	doc_980560860276_item	2966995	et	4	main
näiteks	doc_980560860276_item	2967010	et	4	main
europal	doc_980560860276_item	2967013	et	4	main
kuigi	doc_980560860276_item	2967021	et	3	main
peatati	doc_980560860276_item	2967030	et	4	main
lõppu	doc_980560860276_item	2967035	et	4	main
näitas	doc_980560860276_item	2967036	et	3	main
analüüs	doc_980560860276_item	2967037	et	3	main
et	doc_980560860276_item	2967038	et	3	main
jääproovides	doc_980560860276_item	2967039	et	3	main
sisaldub	doc_980560860276_item	2967040	et	3	main
väikese	doc_980560860276_item	2967055	et	4	main
maavärinaga	doc_980560860276_item	2967056	et	3	main
üles	doc_980560860276_item	2967057	et	3	main
leiduski	doc_980560860276_item	2967061	et	4	main
bakterite	doc_980560860276_item	2967062	et	3	main
elavad	doc_980560860276_item	2967066	et	4	main
50-60c	doc_980560860276_item	2967069	et	4	main
juures	doc_980560860276_item	2967071	et	4	main
võimalik	doc_980560860276_item	2967099	et	3	main
tulemused	doc_980560860276_item	2967102	et	3	main
vesi	doc_980560860276_item	2967109	et	4	main
steriilne	doc_980560860276_item	2967111	et	3	main
ja	doc_980560860276_item	2967112	et	3	main
veepark	doc_980560860277_item	2967120	et	3	main
esimesel	doc_980560860277_item	2967125	et	3	main
kinnitas	doc_980560860277_item	2967127	et	3	main
arenduskava	doc_980560860277_item	2967134	et	4	main
võib	doc_980560860277_item	2967136	et	3	main
linnaosa	doc_980560860277_item	2967137	et	4	main
areneda	doc_980560860277_item	2967139	et	3	main
vilja	doc_980560860277_item	2967149	et	4	main
vanem	doc_980560860277_item	2967169	et	4	main
kui	doc_980560860277_item	2967197	et	3	main
2010aastaks	doc_980560860277_item	2967201	et	4	main
nimeta	doc_980560860277_item	2967203	et	4	main
keegi	doc_980560860277_item	2967205	et	4	main
teemandiks	doc_980560860277_item	2967208	et	4	main
siin	doc_980560860277_item	2967209	et	4	main
kas	doc_980560860277_item	2967214	et	3	main
majad	doc_980560860277_item	2967222	et	3	main
on	doc_980560860277_item	2967224	et	4	main
mida	doc_980560860277_item	2967234	et	4	main
leiti	doc_980560860276_item	2966910	et	3	main
kinkis	doc_980560860276_item	2966914	et	3	main
puurimisel	doc_980560860276_item	2966933	et	4	main
jää	doc_980560860276_item	2966935	et	4	main
on	doc_980560860276_item	2966978	et	4	main
14	doc_980560860276_item	2966979	et	2	main
2	doc_980560860276_item	2966982	et	2	main
seda	doc_980560860276_item	2966985	et	3	main
see	doc_980560860276_item	2966994	et	3	main
lubab	doc_980560860276_item	2966996	et	3	main
loota	doc_980560860276_item	2966998	et	4	main
järves	doc_980560860276_item	2967000	et	4	main
mis	doc_980560860276_item	2967005	et	4	main
ka	doc_980560860276_item	2967007	et	3	main
teistel	doc_980560860276_item	2967008	et	4	main
planeetidel	doc_980560860276_item	2967009	et	3	main
kaaslasel	doc_980560860276_item	2967012	et	3	main
esialgselt	doc_980560860276_item	2967016	et	4	main
järveni	doc_980560860276_item	2967023	et	3	main
100	doc_980560860276_item	2967031	et	2	main
selle	doc_980560860276_item	2967044	et	4	main
ka	doc_980560860276_item	2967047	et	3	main
järve	doc_980560860276_item	2967053	et	4	main
nendes	doc_980560860276_item	2967059	et	4	main
uurimisega	doc_980560860276_item	2967096	et	4	main
järv	doc_980560860276_item	2967117	et	3	main
maakeral	doc_980560860276_item	2967118	et	3	main
tõlge	doc_980560860277_item	2967119	et	3	main
põhjas	doc_980560860276_item	2966922	et	4	main
järvepinna	doc_980560860276_item	2966930	et	3	main
jääkatte	doc_980560860276_item	2966932	et	4	main
saadud	doc_980560860276_item	2966934	et	4	main
vene	doc_980560860276_item	2966939	et	4	main
bakterite	doc_980560860276_item	2966946	et	3	main
sellele	doc_980560860276_item	2966948	et	4	main
hooajal	doc_980560860276_item	2966955	et	3	main
jääproovid	doc_980560860276_item	2966957	et	3	main
võimaluse	doc_980560860276_item	2966960	et	3	main
saada	doc_980560860276_item	2966962	et	4	main
eksisteerib	doc_980560860276_item	2966966	et	3	main
tuhandeid	doc_980560860276_item	2966969	et	3	main
järvesid	doc_980560860276_item	2966970	et	3	main
antarktikas	doc_980560860276_item	2966971	et	4	main
suurim	doc_980560860276_item	2966972	et	3	main
on	doc_980560860276_item	2966984	et	4	main
atmosfäärist	doc_980560860276_item	2966987	et	4	main
eraldanud	doc_980560860276_item	2966988	et	4	main
15	doc_980560860276_item	2966990	et	2	main
mln	doc_980560860276_item	2966991	et	4	main
eluvormid	doc_980560860276_item	2967004	et	3	main
mõeldud	doc_980560860276_item	2967017	et	4	main
mineviku	doc_980560860276_item	2967018	et	3	main
kliima	doc_980560860276_item	2967019	et	4	main
uurimiseks	doc_980560860276_item	2967020	et	4	main
otse	doc_980560860276_item	2967022	et	4	main
teadlastel	doc_980560860276_item	2967024	et	3	main
õnnestunud	doc_980560860276_item	2967027	et	4	main
pele	doc_980560860276_item	2967043	et	3	main
settekivimi	doc_980560860276_item	2967048	et	4	main
mis	doc_980560860276_item	2967050	et	4	main
tõstetud	doc_980560860276_item	2967058	et	4	main
need	doc_980560860276_item	2967067	et	3	main
vaid	doc_980560860276_item	2967072	et	3	main
5-6	doc_980560860276_item	2967073	et	2	main
kohas	doc_980560860276_item	2967074	et	4	main
maal	doc_980560860276_item	2967075	et	4	main
antud	doc_980560860276_item	2967076	et	4	main
avastus	doc_980560860276_item	2967077	et	4	main
äärmiselt	doc_980560860276_item	2967078	et	4	main
üllatas	doc_980560860276_item	2967079	et	3	main
teadlasi	doc_980560860276_item	2967080	et	3	main
sest	doc_980560860276_item	2967081	et	4	main
nad	doc_980560860276_item	2967082	et	3	main
ootasid	doc_980560860276_item	2967083	et	4	main
külmaks	doc_980560860276_item	2967084	et	4	main
keskkonnaks	doc_980560860276_item	2967085	et	3	main
kohanenud	doc_980560860276_item	2967086	et	4	main
eluvorme	doc_980560860276_item	2967087	et	3	main
leida	doc_980560860276_item	2967088	et	3	main
praegu	doc_980560860276_item	2967089	et	3	main
tegeleb	doc_980560860276_item	2967090	et	3	main
spetsialistide	doc_980560860276_item	2967091	et	3	main
meeskond	doc_980560860276_item	2967092	et	3	main
saadud	doc_980560860276_item	2967093	et	4	main
näidiste	doc_980560860276_item	2967094	et	3	main
põhjaliku	doc_980560860276_item	2967095	et	3	main
täiesti	doc_980560860276_item	2967098	et	3	main
uuringute	doc_980560860276_item	2967101	et	3	main
ümber	doc_980560860276_item	2967104	et	3	main
et	doc_980560860276_item	2967107	et	3	main
elutum	doc_980560860276_item	2967116	et	4	main
rannas	doc_980560860277_item	2967122	et	3	main
20072010aastaks	doc_980560860277_item	2967132	et	4	main
vastuvõetud	doc_980560860277_item	2967133	et	4	main
vanem	doc_980560860277_item	2967148	et	4	main
alates	doc_980560860277_item	2967151	et	3	main
põhjapoolne	doc_980560860277_item	2967155	et	3	main
kiiresti	doc_980560860277_item	2967157	et	3	main
stiihiliselt	doc_980560860277_item	2967159	et	4	main
põhiteguriteks	doc_980560860277_item	2967160	et	3	main
märkis	doc_980560860277_item	2967167	et	3	main
põhja-tallinna	doc_980560860277_item	2967170	et	4	main
arengu	doc_980560860277_item	2967172	et	3	main
investoritele	doc_980560860277_item	2967196	et	4	main
põhja-tallinna	doc_980560860277_item	2967206	et	4	main
renoveerida	doc_980560860277_item	2967217	et	4	main
keeruline	doc_980560860277_item	2967225	et	4	main
kuna	doc_980560860277_item	2967227	et	3	main
säilitama	doc_980560860277_item	2967236	et	4	main
paneelmajad	doc_980560860277_item	2967243	et	3	main
näruselt	doc_980560860277_item	2967246	et	4	main
kavandatakse	doc_980560860277_item	2967248	et	3	main
jätkata	doc_980560860277_item	2967249	et	4	main
munitsipaalelamute	doc_980560860277_item	2967250	et	3	main
ka	doc_980560860277_item	2967251	et	3	main
sotsiaalmajade	doc_980560860277_item	2967252	et	3	main
ja	doc_980560860277_item	2967253	et	3	main
kuid	doc_980560860277_item	2967256	et	4	main
ehitada	doc_980560860277_item	2967281	et	3	main
ja	doc_980560860277_item	2967287	et	3	main
kultuuriasutuste	doc_980560860277_item	2967322	et	4	main
alustatakse	doc_980560860277_item	2967325	et	3	main
sõle	doc_980560860277_item	2967326	et	3	main
baasil	doc_980560860277_item	2967328	et	3	main
ehitamist	doc_980560860277_item	2967330	et	4	main
ja	doc_980560860277_item	2967331	et	3	main
juba	doc_980560860277_item	2967332	et	3	main
olemasolevate	doc_980560860277_item	2967333	et	3	main
noortekeskuse	doc_980560860277_item	2967340	et	3	main
loomist	doc_980560860277_item	2967341	et	4	main
meelitavad	doc_980560860277_item	2967352	et	4	main
suplusrannad	doc_980560860277_item	2967355	et	4	main
võimalikult	doc_980560860277_item	2967363	et	4	main
ligipääsetavaks	doc_980560860277_item	2967364	et	4	main
kuuluvad	doc_980560860277_item	2967377	et	4	main
kõrvale	doc_980560860277_item	2967384	et	4	main
kerkib	doc_980560860277_item	2967385	et	3	main
lähiajal	doc_980560860277_item	2967386	et	3	main
ka	doc_980560860277_item	2967387	et	3	main
aasta	doc_980560860277_item	2967124	et	4	main
istungil	doc_980560860277_item	2967126	et	3	main
alusel	doc_980560860277_item	2967135	et	4	main
stabiilselt	doc_980560860277_item	2967138	et	4	main
sõltumata	doc_980560860277_item	2967140	et	4	main
sellest	doc_980560860277_item	2967141	et	4	main
kes	doc_980560860277_item	2967142	et	4	main
on	doc_980560860277_item	2967143	et	4	main
võimul	doc_980560860277_item	2967144	et	3	main
räägib	doc_980560860277_item	2967145	et	3	main
savisaar	doc_980560860277_item	2967150	et	3	main
kava	doc_980560860277_item	2967173	et	4	main
väljatöötamist	doc_980560860277_item	2967174	et	3	main
alustati	doc_980560860277_item	2967175	et	4	main
2003aastal	doc_980560860277_item	2967176	et	3	main
linnavalitsus	doc_980560860277_item	2967177	et	3	main
kinnitas	doc_980560860277_item	2967178	et	3	main
selle	doc_980560860277_item	2967179	et	4	main
möödunud	doc_980560860277_item	2967180	et	4	main
neljapäeval	doc_980560860277_item	2967181	et	3	main
peale	doc_980560860277_item	2967182	et	4	main
ülesannete	doc_980560860277_item	2967183	et	3	main
sisaldab	doc_980560860277_item	2967184	et	3	main
dokument	doc_980560860277_item	2967185	et	3	main
konkreetsete	doc_980560860277_item	2967186	et	3	main
projektide	doc_980560860277_item	2967187	et	3	main
loetelu	doc_980560860277_item	2967188	et	4	main
järgmiseks	doc_980560860277_item	2967189	et	3	main
neljaks	doc_980560860277_item	2967190	et	4	main
aastaks	doc_980560860277_item	2967191	et	4	main
viidates	doc_980560860277_item	2967192	et	3	main
tähtaegadele	doc_980560860277_item	2967193	et	3	main
erinevad	doc_980560860277_item	2967164	et	4	main
majanduslikud	doc_980560860277_item	2967165	et	3	main
huvid	doc_980560860277_item	2967166	et	3	main
tasakaalustatud	doc_980560860277_item	2967171	et	4	main
ja	doc_980560860277_item	2967194	et	3	main
teoks	doc_980560860277_item	2967200	et	4	main
kavandatakse	doc_980560860277_item	2967210	et	3	main
või	doc_980560860277_item	2967216	et	4	main
ja	doc_980560860277_item	2967219	et	3	main
võimalikele	doc_980560860277_item	2967195	et	3	main
kavandatud	doc_980560860277_item	2967198	et	4	main
saab	doc_980560860277_item	2967199	et	3	main
lihvimata	doc_980560860277_item	2967207	et	4	main
vanad	doc_980560860277_item	2967211	et	3	main
hooned	doc_980560860277_item	2967212	et	4	main
korrastada	doc_980560860277_item	2967213	et	3	main
mahajäetud	doc_980560860277_item	2967221	et	4	main
see	doc_980560860277_item	2967223	et	3	main
linnaosas	doc_980560860277_item	2967228	et	3	main
palju	doc_980560860277_item	2967230	et	4	main
arhitektuuriliselt	doc_980560860277_item	2967231	et	4	main
väärtuslikke	doc_980560860277_item	2967232	et	3	main
munitsipaalomandis	doc_980560860277_item	2967237	et	3	main
olevad	doc_980560860277_item	2967238	et	4	main
ühiselamud	doc_980560860277_item	2967239	et	3	main
vajavad	doc_980560860277_item	2967240	et	4	main
näevad	doc_980560860277_item	2967244	et	3	main
ehitamist	doc_980560860277_item	2967255	et	4	main
suurima	doc_980560860277_item	2967268	et	4	main
osa	doc_980560860277_item	2967269	et	4	main
vanad	doc_980560860277_item	2967271	et	3	main
asumid	doc_980560860277_item	2967272	et	3	main
esinevad	doc_980560860277_item	2967274	et	4	main
suured	doc_980560860277_item	2967275	et	3	main
kanalisatsiooniprobleemid	doc_980560860277_item	2967276	et	3	main
kavandatakse	doc_980560860277_item	2967278	et	3	main
ümber	doc_980560860277_item	2967280	et	3	main
ja	doc_980560860277_item	2967321	et	3	main
platside	doc_980560860277_item	2967336	et	4	main
kavandatakse	doc_980560860277_item	2967338	et	3	main
ammu	doc_980560860277_item	2967345	et	4	main
kujunenud	doc_980560860277_item	2967346	et	4	main
lemmikpuhkekoht	doc_980560860277_item	2967349	et	3	main
eriti	doc_980560860277_item	2967350	et	3	main
pargid	doc_980560860277_item	2967353	et	4	main
ja	doc_980560860277_item	2967354	et	3	main
kõikidest	doc_980560860277_item	2967357	et	4	main
linnaosadest	doc_980560860277_item	2967358	et	3	main
seetõttu	doc_980560860277_item	2967359	et	3	main
muuta	doc_980560860277_item	2967361	et	4	main
rannaala	doc_980560860277_item	2967362	et	4	main
jaoks	doc_980560860277_item	2967366	et	4	main
kavandatakse	doc_980560860277_item	2967369	et	3	main
suplusranna	doc_980560860277_item	2967376	et	4	main
rannamaja	doc_980560860277_item	2967383	et	4	main
omanike	doc_980560860277_item	2967220	et	3	main
hooneid	doc_980560860277_item	2967233	et	4	main
üsna	doc_980560860277_item	2967245	et	3	main
välja	doc_980560860277_item	2967247	et	4	main
varjupaikade	doc_980560860277_item	2967254	et	4	main
põhilisteks	doc_980560860277_item	2967257	et	3	main
lähiaastail	doc_980560860277_item	2967259	et	4	main
kopli	doc_980560860277_item	2967261	et	3	main
liinide	doc_980560860277_item	2967262	et	3	main
sirbi-vasara	doc_980560860277_item	2967264	et	3	main
renoveerimisprojektid	doc_980560860277_item	2967266	et	3	main
põhja-tallinna	doc_980560860277_item	2967267	et	4	main
sellepärast	doc_980560860277_item	2967277	et	3	main
lähiaastail	doc_980560860277_item	2967279	et	4	main
vee-	doc_980560860277_item	2967282	et	3	main
kalamajas	doc_980560860277_item	2967285	et	3	main
ees	doc_980560860277_item	2967289	et	4	main
materiaal-tehniline	doc_980560860277_item	2967323	et	3	main
baas	doc_980560860277_item	2967324	et	3	main
gümnaasiumi	doc_980560860277_item	2967327	et	4	main
põhja-tallinnast	doc_980560860277_item	2967342	et	3	main
juba	doc_980560860277_item	2967344	et	3	main
tallinlaste	doc_980560860277_item	2967347	et	3	main
üks	doc_980560860277_item	2967348	et	3	main
suveajal	doc_980560860277_item	2967351	et	3	main
samanimelise	doc_980560860277_item	2967375	et	4	main
töö	doc_980560860277_item	2967226	et	4	main
on	doc_980560860277_item	2967229	et	4	main
peab	doc_980560860277_item	2967235	et	4	main
paljud	doc_980560860277_item	2967242	et	3	main
kvartali	doc_980560860277_item	2967265	et	3	main
ja	doc_980560860277_item	2967283	et	3	main
pelgulinnas	doc_980560860277_item	2967288	et	4	main
ootab	doc_980560860277_item	2967290	et	3	main
ka	doc_980560860277_item	2967291	et	3	main
mahukas	doc_980560860277_item	2967292	et	4	main
tee-ehitus	doc_980560860277_item	2967293	et	4	main
prioriteediks	doc_980560860277_item	2967294	et	3	main
on	doc_980560860277_item	2967295	et	4	main
aga	doc_980560860277_item	2967296	et	3	main
ümbersõiduteed	doc_980560860277_item	2967297	et	4	main
kalamaja	doc_980560860277_item	2967298	et	4	main
ja	doc_980560860277_item	2967299	et	3	main
pelgulinna	doc_980560860277_item	2967300	et	4	main
ümber	doc_980560860277_item	2967301	et	3	main
ja	doc_980560860277_item	2967302	et	3	main
liiklussõlm	doc_980560860277_item	2967303	et	3	main
sitsi	doc_980560860277_item	2967304	et	4	main
põhja-tallinna	doc_980560860277_item	2967306	et	4	main
mäel	doc_980560860277_item	2967305	et	3	main
arenduskavas	doc_980560860277_item	2967307	et	3	main
palju	doc_980560860277_item	2967308	et	4	main
tähelepanu	doc_980560860277_item	2967309	et	4	main
pööratakse	doc_980560860277_item	2967310	et	3	main
sotsiaalsetele	doc_980560860277_item	2967311	et	4	main
projektidele	doc_980560860277_item	2967312	et	3	main
munitsipaalkoolid	doc_980560860277_item	2967313	et	3	main
ja	doc_980560860277_item	2967314	et	3	main
lasteaiad	doc_980560860277_item	2967315	et	4	main
on	doc_980560860277_item	2967316	et	4	main
renoveerimist	doc_980560860277_item	2967317	et	4	main
ootamas	doc_980560860277_item	2967318	et	3	main
täieneb	doc_980560860277_item	2967319	et	3	main
õppe-	doc_980560860277_item	2967320	et	4	main
uuendamist	doc_980560860277_item	2967337	et	4	main
tallinlasi	doc_980560860277_item	2967356	et	3	main
inimeste	doc_980560860277_item	2967365	et	3	main
kõike	doc_980560860277_item	2967368	et	4	main
heakorrastada	doc_980560860277_item	2967370	et	3	main
puhkeala	doc_980560860277_item	2967372	et	4	main
millesse	doc_980560860277_item	2967373	et	3	main
rannapark	doc_980560860277_item	2967378	et	3	main
ja	doc_980560860277_item	2967379	et	3	main
merimetsa	doc_980560860277_item	2967380	et	4	main
renoveerimist	doc_980560860277_item	2967241	et	4	main
ülesanneteks	doc_980560860277_item	2967258	et	3	main
jäävad	doc_980560860277_item	2967260	et	4	main
ja	doc_980560860277_item	2967263	et	3	main
moodustavad	doc_980560860277_item	2967270	et	4	main
kus	doc_980560860277_item	2967273	et	3	main
kanalisatsioonivõrgud	doc_980560860277_item	2967284	et	3	main
koplis	doc_980560860277_item	2967286	et	3	main
spordikeskuse	doc_980560860277_item	2967329	et	3	main
spordisaalide	doc_980560860277_item	2967334	et	3	main
ja	doc_980560860277_item	2967335	et	3	main
avatud	doc_980560860277_item	2967339	et	4	main
on	doc_980560860277_item	2967343	et	4	main
otsustati	doc_980560860277_item	2967360	et	3	main
enne	doc_980560860277_item	2967367	et	4	main
stroomi	doc_980560860277_item	2967371	et	4	main
peale	doc_980560860277_item	2967374	et	4	main
parkmets	doc_980560860277_item	2967381	et	3	main
stroomi	doc_980560860277_item	2967382	et	4	main
veepark	doc_980560860277_item	2967388	et	3	main
ning	doc_986203247096_item	2967893	et	3	main
kas	doc_986203247096_item	2967895	et	3	main
2	doc_986203247096_item	2967921	et	2	main
kirjutage	doc_986203247096_item	2967928	et	3	main
nõutav	doc_986203247096_item	2967933	et	4	main
pikkus	doc_986203247096_item	2967934	et	4	main
on	doc_986203247096_item	2967935	et	4	main
tarkus	doc_986203247096_item	2967941	et	4	main
käivad	doc_986203247096_item	2967942	et	4	main
poolt	doc_986203247096_item	2967962	et	4	main
arvan	doc_986203247096_item	2967969	et	3	main
raha	doc_986203247096_item	2967979	et	4	main
rikkad	doc_986203247096_item	2967984	et	4	main
inimesed	doc_986203247096_item	2967985	et	3	main
ilma	doc_986203247096_item	2968001	et	4	main
meie	doc_986203247096_item	2968004	et	4	main
mõtlevad	doc_986203247096_item	2968010	et	4	main
välismaalide	doc_986203247096_item	2968015	et	3	main
inimesed	doc_986203247096_item	2968022	et	3	main
tänu	doc_986203247096_item	2968028	et	4	main
riigid	doc_986203247096_item	2968031	et	3	main
aga	doc_986203247096_item	2968033	et	3	main
uued	doc_986203247096_item	2968039	et	3	main
ei	doc_986203247096_item	2968049	et	4	main
et	doc_986203247096_item	2968055	et	3	main
riigis	doc_986203247096_item	2968057	et	3	main
tarkus	doc_986203247096_item	2968058	et	4	main
rikus	doc_986203247096_item	2968060	et	4	main
ei	doc_986203247096_item	2968061	et	4	main
koos	doc_986203247096_item	2968064	et	4	main
rikkus	doc_986203247096_item	2967922	et	4	main
tarkus	doc_986203247096_item	2967924	et	4	main
kasti	doc_986203247096_item	2967930	et	4	main
sisse	doc_986203247096_item	2967931	et	4	main
teksti	doc_986203247096_item	2967932	et	4	main
alati	doc_986203247096_item	2967943	et	4	main
alati	doc_986203247096_item	2967950	et	4	main
on	doc_986203247096_item	2967966	et	4	main
rikkad	doc_986203247096_item	2967967	et	4	main
ma	doc_986203247096_item	2967968	et	3	main
palju	doc_986203247096_item	2967971	et	4	main
tarkad	doc_986203247096_item	2967972	et	4	main
inimesed	doc_986203247096_item	2967973	et	3	main
oma	doc_986203247096_item	2967976	et	4	main
ei	doc_986203247096_item	2967982	et	4	main
hinnata	doc_986203247096_item	2967983	et	4	main
ei	doc_986203247096_item	2967987	et	4	main
tarkus	doc_986203247096_item	2967995	et	4	main
inimesed	doc_986203247096_item	2968003	et	3	main
rikk	doc_986203247096_item	2968005	et	4	main
juba	doc_986203247096_item	2968012	et	3	main
seal	doc_986203247096_item	2968018	et	4	main
on	doc_986203247096_item	2968019	et	4	main
meie	doc_986203247096_item	2968024	et	4	main
tarkusi	doc_986203247096_item	2968025	et	4	main
neile	doc_986203247096_item	2968029	et	4	main
kõik	doc_986203247096_item	2968038	et	4	main
kui	doc_986203247096_item	2968041	et	3	main
meie	doc_986203247096_item	2968042	et	4	main
inimesed	doc_986203247096_item	2968044	et	3	main
ollnud	doc_986203247096_item	2968045	et	4	main
ma	doc_986203247096_item	2968053	et	3	main
käinud	doc_986203247096_item	2968062	et	4	main
väiteid	doc_986203247096_item	2967889	et	4	main
valige	doc_986203247096_item	2967890	et	3	main
neist	doc_986203247096_item	2967891	et	4	main
üks	doc_986203247096_item	2967892	et	3	main
käivad	doc_986203247096_item	2967925	et	4	main
alati	doc_986203247096_item	2967926	et	4	main
u	doc_986203247096_item	2967936	et	4	main
160	doc_986203247096_item	2967937	et	2	main
sõna	doc_986203247096_item	2967938	et	4	main
koos	doc_986203247096_item	2967944	et	4	main
minu	doc_986203247096_item	2967945	et	3	main
tarkad	doc_986203247096_item	2967959	et	4	main
aga	doc_986203247096_item	2967960	et	3	main
et	doc_986203247096_item	2967970	et	3	main
saanud	doc_986203247096_item	2967975	et	4	main
tarkus	doc_986203247096_item	2967977	et	4	main
palju	doc_986203247096_item	2967978	et	4	main
kui	doc_986203247096_item	2967992	et	3	main
siis	doc_986203247096_item	2967996	et	3	main
tarkad	doc_986203247096_item	2968002	et	4	main
ei	doc_986203247096_item	2968006	et	4	main
saa	doc_986203247096_item	2968007	et	4	main
arenema	doc_986203247096_item	2968008	et	3	main
inimesed	doc_986203247096_item	2968011	et	3	main
ära	doc_986203247096_item	2968014	et	4	main
sellepärast	doc_986203247096_item	2968016	et	3	main
hindavad	doc_986203247096_item	2968020	et	4	main
tarkad	doc_986203247096_item	2968021	et	4	main
palju	doc_986203247096_item	2968023	et	4	main
rikk	doc_986203247096_item	2968035	et	4	main
lasknud	doc_986203247096_item	2968050	et	4	main
seda	doc_986203247096_item	2968051	et	3	main
sellepärast	doc_986203247096_item	2968052	et	3	main
ja	doc_986203247096_item	2968059	et	3	main
alati	doc_986203247096_item	2968063	et	4	main
arvamus	doc_986203247096_item	2967887	et	3	main
lugege	doc_986203247096_item	2967888	et	3	main
kirjutage	doc_986203247096_item	2967894	et	3	main
olete	doc_986203247096_item	2967896	et	3	main
selle	doc_986203247096_item	2967897	et	4	main
väitega	doc_986203247096_item	2967898	et	3	main
nõus	doc_986203247096_item	2967899	et	4	main
või	doc_986203247096_item	2967900	et	4	main
mitte	doc_986203247096_item	2967901	et	3	main
esitage	doc_986203247096_item	2967902	et	3	main
poolt-	doc_986203247096_item	2967903	et	4	main
ja	doc_986203247096_item	2967904	et	3	main
vastuargumente	doc_986203247096_item	2967905	et	3	main
väide	doc_986203247096_item	2967906	et	4	main
1	doc_986203247096_item	2967907	et	2	main
igal	doc_986203247096_item	2967908	et	3	main
koolil	doc_986203247096_item	2967909	et	4	main
peaks	doc_986203247096_item	2967910	et	4	main
olema	doc_986203247096_item	2967911	et	4	main
oma	doc_986203247096_item	2967912	et	4	main
koolivorm	doc_986203247096_item	2967913	et	3	main
sest	doc_986203247096_item	2967914	et	4	main
see	doc_986203247096_item	2967915	et	3	main
aitab	doc_986203247096_item	2967916	et	3	main
kaasa	doc_986203247096_item	2967917	et	4	main
omakoolitunde	doc_986203247096_item	2967918	et	4	main
tekkimisele	doc_986203247096_item	2967919	et	4	main
väide	doc_986203247096_item	2967920	et	4	main
koos	doc_986203247096_item	2967927	et	4	main
arust	doc_986203247096_item	2967946	et	4	main
ei	doc_986203247096_item	2967948	et	4	main
ole	doc_986203247096_item	2967949	et	4	main
teiselt	doc_986203247096_item	2967961	et	4	main
mitte	doc_986203247096_item	2967963	et	3	main
koik	doc_986203247096_item	2967964	et	4	main
tarkad	doc_986203247096_item	2967965	et	4	main
nende	doc_986203247096_item	2967980	et	4	main
kellel	doc_986203247096_item	2967986	et	4	main
ole	doc_986203247096_item	2967988	et	4	main
tarkus	doc_986203247096_item	2967989	et	4	main
sellepärast	doc_986203247096_item	2967990	et	3	main
et	doc_986203247096_item	2967991	et	3	main
nad	doc_986203247096_item	2967997	et	3	main
soovad	doc_986203247096_item	2967998	et	4	main
aru	doc_986203247096_item	2967999	et	4	main
te	doc_986203247096_item	2968000	et	4	main
palju	doc_986203247096_item	2968009	et	4	main
sõidab	doc_986203247096_item	2968013	et	3	main
ja	doc_986203247096_item	2967923	et	3	main
joonitud	doc_986203247096_item	2967929	et	4	main
rikkus	doc_986203247096_item	2967939	et	4	main
ja	doc_986203247096_item	2967940	et	3	main
see	doc_986203247096_item	2967947	et	3	main
õige	doc_986203247096_item	2967951	et	4	main
mitte	doc_986203247096_item	2967952	et	3	main
kõik	doc_986203247096_item	2967953	et	4	main
inimesed	doc_986203247096_item	2967954	et	3	main
kes	doc_986203247096_item	2967955	et	4	main
on	doc_986203247096_item	2967956	et	4	main
rikkad	doc_986203247096_item	2967957	et	4	main
ka	doc_986203247096_item	2967958	et	3	main
ei	doc_986203247096_item	2967974	et	4	main
tarkus	doc_986203247096_item	2967981	et	4	main
nendel	doc_986203247096_item	2967993	et	4	main
on	doc_986203247096_item	2967994	et	4	main
töötavad	doc_986203247096_item	2968026	et	4	main
välismaalidel	doc_986203247096_item	2968027	et	3	main
neid	doc_986203247096_item	2968030	et	4	main
arenevad	doc_986203247096_item	2968032	et	4	main
ainul	doc_986203247096_item	2968036	et	4	main
rikat	doc_986203247096_item	2968043	et	4	main
ka	doc_986203247096_item	2968046	et	3	main
tarkad	doc_986203247096_item	2968047	et	4	main
nad	doc_986203247096_item	2968048	et	3	main
arvan	doc_986203247096_item	2968054	et	3	main
meie	doc_986203247096_item	2968056	et	4	main
neist	doc_986203247098_item	2968214	et	4	main
esitage	doc_986203247098_item	2968225	et	3	main
ā	doc_986203247098_item	2968229	et	2	main
aitab	doc_986203247098_item	2968241	et	3	main
ā	doc_986203247098_item	2968253	et	2	main
joonitud	doc_986203247098_item	2968256	et	4	main
teksti	doc_986203247098_item	2968259	et	4	main
on	doc_986203247098_item	2968262	et	4	main
160	doc_986203247098_item	2968264	et	2	main
ā	doc_986203247098_item	2968266	et	2	main
ā	doc_986203247098_item	2968269	et	2	main
ja	doc_986203247098_item	2968271	et	3	main
tarkus	doc_986203247098_item	2968272	et	4	main
kćivad	doc_986203247098_item	2968273	et	2	main
ma	doc_986203247098_item	2968278	et	3	main
sellepćrast	doc_986203247098_item	2968282	et	2	main
eraldi	doc_986203247098_item	2968296	et	4	main
maailmas	doc_986203247098_item	2968297	et	3	main
ć¼hiskonnas	doc_986203247098_item	2968298	et	2	main
on	doc_986203247098_item	2968299	et	4	main
vćike	doc_986203247098_item	2968322	et	2	main
ole	doc_986203247098_item	2968326	et	4	main
vćµimalusi	doc_986203247098_item	2968327	et	2	main
realiseerida	doc_986203247098_item	2968328	et	3	main
nad	doc_986203247098_item	2968335	et	3	main
nad	doc_986203247098_item	2968339	et	3	main
nad	doc_986203247098_item	2968343	et	3	main
vćµivad	doc_986203247098_item	2968350	et	2	main
eestis	doc_986203247098_item	2968353	et	3	main
siis	doc_986203247098_item	2968388	et	3	main
see	doc_986203247098_item	2968393	et	3	main
ja	doc_986203247098_item	2968399	et	3	main
ā	doc_986203247098_item	2968415	et	2	main
et	doc_986203247096_item	2968017	et	3	main
meie	doc_986203247096_item	2968034	et	4	main
ostab	doc_986203247096_item	2968037	et	3	main
tehnoloogiat	doc_986203247096_item	2968040	et	3	main
ć¼ks	doc_986203247098_item	2968215	et	2	main
ning	doc_986203247098_item	2968216	et	3	main
kirjutage	doc_986203247098_item	2968217	et	3	main
kas	doc_986203247098_item	2968218	et	3	main
olete	doc_986203247098_item	2968219	et	3	main
selle	doc_986203247098_item	2968220	et	4	main
vćµi	doc_986203247098_item	2968223	et	2	main
poolt-	doc_986203247098_item	2968226	et	4	main
vastuargumente	doc_986203247098_item	2968228	et	3	main
vćide	doc_986203247098_item	2968231	et	2	main
igal	doc_986203247098_item	2968233	et	3	main
peaks	doc_986203247098_item	2968235	et	4	main
olema	doc_986203247098_item	2968236	et	4	main
omakoolitunde	doc_986203247098_item	2968243	et	4	main
2	doc_986203247098_item	2968246	et	2	main
ja	doc_986203247098_item	2968248	et	3	main
tarkus	doc_986203247098_item	2968249	et	4	main
kasti	doc_986203247098_item	2968257	et	4	main
u	doc_986203247098_item	2968263	et	4	main
ā	doc_986203247098_item	2968267	et	2	main
kinnitusega	doc_986203247098_item	2968277	et	4	main
ole	doc_986203247098_item	2968280	et	4	main
et	doc_986203247098_item	2968283	et	3	main
rikkus	doc_986203247098_item	2968286	et	4	main
tarkus	doc_986203247098_item	2968294	et	4	main
kćivad	doc_986203247098_item	2968295	et	2	main
kćtte	doc_986203247098_item	2968321	et	2	main
neil	doc_986203247098_item	2968324	et	4	main
ei	doc_986203247098_item	2968325	et	4	main
omavad	doc_986203247098_item	2968332	et	4	main
raha	doc_986203247098_item	2968333	et	4	main
ja	doc_986203247098_item	2968334	et	3	main
saavad	doc_986203247098_item	2968344	et	4	main
eestis	doc_986203247098_item	2968348	et	3	main
siin	doc_986203247098_item	2968352	et	4	main
rikkad	doc_986203247098_item	2968362	et	4	main
olla	doc_986203247098_item	2968365	et	3	main
tavaliselt	doc_986203247098_item	2968397	et	4	main
rikkus	doc_986203247098_item	2968398	et	4	main
eraldi	doc_986203247098_item	2968402	et	4	main
nendest	doc_986203247098_item	2968411	et	4	main
targed	doc_986203247098_item	2968413	et	3	main
vćitega	doc_986203247098_item	2968221	et	2	main
ā	doc_986203247098_item	2968230	et	2	main
sest	doc_986203247098_item	2968239	et	4	main
koos	doc_986203247098_item	2968252	et	4	main
ā	doc_986203247098_item	2968254	et	2	main
pikkus	doc_986203247098_item	2968261	et	4	main
koos	doc_986203247098_item	2968275	et	4	main
sellega	doc_986203247098_item	2968276	et	3	main
nćµus	doc_986203247098_item	2968281	et	2	main
alati	doc_986203247098_item	2968285	et	4	main
tarkus	doc_986203247098_item	2968288	et	4	main
palka	doc_986203247098_item	2968323	et	4	main
vćµimalusi	doc_986203247098_item	2968338	et	2	main
vćlismaal	doc_986203247098_item	2968342	et	2	main
tććtada	doc_986203247098_item	2968347	et	2	main
ćµppida	doc_986203247098_item	2968351	et	2	main
on	doc_986203247098_item	2968355	et	4	main
raha	doc_986203247098_item	2968356	et	4	main
siis	doc_986203247098_item	2968357	et	3	main
on	doc_986203247098_item	2968358	et	4	main
vćµimalus	doc_986203247098_item	2968359	et	2	main
saada	doc_986203247098_item	2968360	et	4	main
kćµrgharidus	doc_986203247098_item	2968361	et	2	main
ma	doc_986203247098_item	2968389	et	3	main
nćµus	doc_986203247098_item	2968391	et	2	main
aga	doc_986203247098_item	2968392	et	3	main
vćga	doc_986203247098_item	2968395	et	2	main
harva	doc_986203247098_item	2968396	et	4	main
tarkus	doc_986203247098_item	2968400	et	4	main
praegu	doc_986203247098_item	2968403	et	3	main
rikkad	doc_986203247098_item	2968405	et	4	main
inimesed	doc_986203247098_item	2968410	et	3	main
on	doc_986203247098_item	2968412	et	4	main
ā	doc_986203247098_item	2968414	et	2	main
uus	doc_986203247098_item	2968209	et	3	main
dokument	doc_986203247098_item	2968210	et	3	main
lugege	doc_986203247098_item	2968211	et	3	main
vćiteid	doc_986203247098_item	2968212	et	2	main
valige	doc_986203247098_item	2968213	et	3	main
nćµus	doc_986203247098_item	2968222	et	2	main
oma	doc_986203247098_item	2968237	et	4	main
koolivorm	doc_986203247098_item	2968238	et	3	main
kaasa	doc_986203247098_item	2968242	et	4	main
tekkimisele	doc_986203247098_item	2968244	et	4	main
rikkus	doc_986203247098_item	2968247	et	4	main
kćivad	doc_986203247098_item	2968250	et	2	main
alati	doc_986203247098_item	2968251	et	4	main
sisse	doc_986203247098_item	2968258	et	4	main
nćµutav	doc_986203247098_item	2968260	et	2	main
alati	doc_986203247098_item	2968274	et	4	main
ei	doc_986203247098_item	2968279	et	4	main
mitte	doc_986203247098_item	2968284	et	3	main
ja	doc_986203247098_item	2968287	et	3	main
kćivad	doc_986203247098_item	2968289	et	2	main
koos	doc_986203247098_item	2968290	et	4	main
harilikult	doc_986203247098_item	2968291	et	4	main
mitte	doc_986203247098_item	2968224	et	3	main
ja	doc_986203247098_item	2968227	et	3	main
1	doc_986203247098_item	2968232	et	2	main
koolil	doc_986203247098_item	2968234	et	4	main
see	doc_986203247098_item	2968240	et	3	main
vćide	doc_986203247098_item	2968245	et	2	main
kirjutage	doc_986203247098_item	2968255	et	3	main
sćµna	doc_986203247098_item	2968265	et	2	main
ā	doc_986203247098_item	2968268	et	2	main
rikkus	doc_986203247098_item	2968270	et	4	main
rikkus	doc_986203247098_item	2968292	et	4	main
ja	doc_986203247098_item	2968293	et	3	main
rikkad	doc_986203247098_item	2968300	et	4	main
inimesed	doc_986203247098_item	2968301	et	3	main
targed	doc_986203247098_item	2968302	et	3	main
inimesed	doc_986203247098_item	2968303	et	3	main
tavaliselt	doc_986203247098_item	2968304	et	4	main
targed	doc_986203247098_item	2968305	et	3	main
inimesed	doc_986203247098_item	2968306	et	3	main
mitte	doc_986203247098_item	2968307	et	3	main
ei	doc_986203247098_item	2968309	et	4	main
alati	doc_986203247098_item	2968308	et	4	main
ole	doc_986203247098_item	2968310	et	4	main
rikkad	doc_986203247098_item	2968311	et	4	main
inimesed	doc_986203247098_item	2968312	et	3	main
tavalised	doc_986203247098_item	2968313	et	4	main
inimesed	doc_986203247098_item	2968314	et	3	main
tććtavad	doc_986203247098_item	2968315	et	2	main
tehases	doc_986203247098_item	2968316	et	3	main
teevad	doc_986203247098_item	2968317	et	3	main
musta	doc_986203247098_item	2968318	et	4	main
tććt	doc_986203247098_item	2968319	et	2	main
saavad	doc_986203247098_item	2968320	et	4	main
ise	doc_986203247098_item	2968329	et	4	main
vćµivad	doc_986203247098_item	2968336	et	2	main
ćµppida	doc_986203247098_item	2968341	et	2	main
igasuguseid	doc_986203247098_item	2968345	et	3	main
kutseid	doc_986203247098_item	2968346	et	3	main
inimesed	doc_986203247098_item	2968363	et	3	main
ka	doc_986203247098_item	2968366	et	3	main
olen	doc_986203247098_item	2968390	et	3	main
on	doc_986203247098_item	2968394	et	4	main
inimesed	doc_986203247098_item	2968406	et	3	main
aga	doc_986203247098_item	2968407	et	3	main
kćµik	doc_986203247098_item	2968409	et	2	main
rikkad	doc_986203247098_item	2968330	et	4	main
inimesed	doc_986203247098_item	2968331	et	3	main
igasuguseid	doc_986203247098_item	2968337	et	3	main
vćµivad	doc_986203247098_item	2968340	et	2	main
nad	doc_986203247098_item	2968349	et	3	main
kui	doc_986203247098_item	2968354	et	3	main
vćµivad	doc_986203247098_item	2968364	et	2	main
sellepćrast	doc_986203247098_item	2968368	et	2	main
targed	doc_986203247098_item	2968367	et	3	main
et	doc_986203247098_item	2968369	et	3	main
inimesed	doc_986203247098_item	2968370	et	3	main
teevad	doc_986203247098_item	2968371	et	3	main
karjććri	doc_986203247098_item	2968372	et	2	main
siis	doc_986203247098_item	2968373	et	3	main
saavad	doc_986203247098_item	2968374	et	4	main
kćµrgetasuline	doc_986203247098_item	2968375	et	2	main
eriala	doc_986203247098_item	2968376	et	4	main
ma	doc_986203247098_item	2968377	et	3	main
olen	doc_986203247098_item	2968378	et	3	main
nćµus	doc_986203247098_item	2968379	et	2	main
sellega	doc_986203247098_item	2968380	et	3	main
kinnitusega	doc_986203247098_item	2968381	et	4	main
kui	doc_986203247098_item	2968382	et	3	main
inimesed	doc_986203247098_item	2968383	et	3	main
saavad	doc_986203247098_item	2968384	et	4	main
rikkaks	doc_986203247098_item	2968385	et	4	main
mćµistust	doc_986203247098_item	2968387	et	2	main
lćbi	doc_986203247098_item	2968386	et	2	main
kćivad	doc_986203247098_item	2968401	et	2	main
palju	doc_986203247098_item	2968404	et	4	main
mitte	doc_986203247098_item	2968408	et	3	main
kas	doc_986203247101_item	2968802	et	3	main
väide	doc_986203247101_item	2968813	et	4	main
igal	doc_986203247101_item	2968815	et	3	main
valige	doc_986203247101_item	2968797	et	3	main
kirjutage	doc_986203247101_item	2968801	et	3	main
oma	doc_986203247101_item	2968819	et	4	main
koolivorm	doc_986203247101_item	2968820	et	3	main
sest	doc_986203247101_item	2968821	et	4	main
kaasa	doc_986203247101_item	2968824	et	4	main
tarkus	doc_986203247101_item	2968831	et	4	main
käivad	doc_986203247101_item	2968832	et	4	main
pikkus	doc_986203247101_item	2968841	et	4	main
siis	doc_986203247101_item	2968850	et	3	main
võin	doc_986203247101_item	2968863	et	3	main
järgi	doc_986203247101_item	2968870	et	4	main
vaid	doc_986203247101_item	2968871	et	3	main
ka	doc_986203247101_item	2968872	et	3	main
inimesed	doc_986203247101_item	2968881	et	3	main
on	doc_986203247101_item	2968882	et	4	main
vaised	doc_986203247101_item	2968886	et	4	main
lahkeit	doc_986203247101_item	2968895	et	3	main
inimesi	doc_986203247101_item	2968899	et	4	main
vastupidi	doc_986203247101_item	2968902	et	3	main
et	doc_986203247101_item	2968904	et	3	main
on	doc_986203247101_item	2968905	et	4	main
hirm	doc_986203247101_item	2968906	et	3	main
visata	doc_986203247101_item	2968911	et	4	main
üks	doc_986203247101_item	2968799	et	3	main
olete	doc_986203247101_item	2968803	et	3	main
väitega	doc_986203247101_item	2968805	et	3	main
mitte	doc_986203247101_item	2968808	et	3	main
esitage	doc_986203247101_item	2968809	et	3	main
poolt-	doc_986203247101_item	2968810	et	4	main
ja	doc_986203247101_item	2968811	et	3	main
vastuargumente	doc_986203247101_item	2968812	et	3	main
1	doc_986203247101_item	2968814	et	2	main
väide	doc_986203247101_item	2968827	et	4	main
2	doc_986203247101_item	2968828	et	2	main
rikkus	doc_986203247101_item	2968829	et	4	main
ja	doc_986203247101_item	2968830	et	3	main
joonitud	doc_986203247101_item	2968836	et	4	main
160	doc_986203247101_item	2968844	et	2	main
kui	doc_986203247101_item	2968846	et	3	main
ümber	doc_986203247101_item	2968848	et	3	main
materjalse	doc_986203247101_item	2968874	et	4	main
seisundi	doc_986203247101_item	2968875	et	3	main
või	doc_986203247101_item	2968885	et	4	main
ja	doc_986203247101_item	2968896	et	3	main
häit	doc_986203247101_item	2968898	et	4	main
ja	doc_986203247101_item	2968900	et	3	main
on	doc_986203247101_item	2968920	et	4	main
kadedad	doc_986203247101_item	2968921	et	3	main
lihtsalt	doc_986203247101_item	2968925	et	4	main
olen	doc_986203247101_item	2968929	et	3	main
seni	doc_986203247101_item	2968932	et	3	main
minu	doc_986203247101_item	2968933	et	3	main
eluteel	doc_986203247101_item	2968934	et	3	main
olen	doc_986203247101_item	2968935	et	3	main
kohtunud	doc_986203247101_item	2968936	et	4	main
häid	doc_986203247101_item	2968939	et	3	main
arvatest	doc_986203247101_item	2968944	et	3	main
on	doc_986203247101_item	2968947	et	4	main
taskus	doc_986203247101_item	2968956	et	3	main
saada	doc_986203247101_item	2968961	et	4	main
palju	doc_986203247101_item	2968964	et	4	main
sa	doc_986203247101_item	2968975	et	3	main
rikkaks	doc_986203247101_item	2968988	et	4	main
kui	doc_986203247101_item	2968990	et	3	main
selle	doc_986203247101_item	2968991	et	4	main
all	doc_986203247101_item	2968992	et	3	main
siis	doc_986203247101_item	2968996	et	3	main
kindlasti	doc_986203247101_item	2968998	et	3	main
temal	doc_986203247101_item	2969009	et	3	main
eesmärg	doc_986203247101_item	2969011	et	3	main
ta	doc_986203247101_item	2969017	et	4	main
investeerib	doc_986203247101_item	2969018	et	3	main
oma	doc_986203247101_item	2969019	et	4	main
eriala	doc_986203247101_item	2969028	et	4	main
minu	doc_986203247101_item	2969054	et	3	main
saabgi	doc_986203247101_item	2969063	et	4	main
on	doc_986203247101_item	2969064	et	4	main
kes	doc_986203247101_item	2969076	et	4	main
tahab	doc_986203247101_item	2969077	et	3	main
väiteid	doc_986203247101_item	2968796	et	4	main
ning	doc_986203247101_item	2968800	et	3	main
koolil	doc_986203247101_item	2968816	et	4	main
peaks	doc_986203247101_item	2968817	et	4	main
aitab	doc_986203247101_item	2968823	et	3	main
omakoolitunde	doc_986203247101_item	2968825	et	4	main
tekkimisele	doc_986203247101_item	2968826	et	4	main
alati	doc_986203247101_item	2968833	et	4	main
teksti	doc_986203247101_item	2968839	et	4	main
on	doc_986203247101_item	2968842	et	4	main
sõna	doc_986203247101_item	2968845	et	4	main
ma	doc_986203247101_item	2968847	et	3	main
vaatan	doc_986203247101_item	2968849	et	3	main
öelda	doc_986203247101_item	2968864	et	4	main
ainult	doc_986203247101_item	2968866	et	4	main
sarnased	doc_986203247101_item	2968883	et	4	main
nende	doc_986203247101_item	2968888	et	4	main
leida	doc_986203247101_item	2968891	et	3	main
nii	doc_986203247101_item	2968892	et	3	main
kui	doc_986203247101_item	2968893	et	3	main
huvitavait	doc_986203247101_item	2968894	et	4	main
lihtsalt	doc_986203247101_item	2968897	et	4	main
täiesti	doc_986203247101_item	2968901	et	3	main
niisuguseit	doc_986203247101_item	2968903	et	4	main
poole	doc_986203247101_item	2968909	et	4	main
sest	doc_986203247101_item	2968912	et	4	main
minu	doc_986203247101_item	2968943	et	3	main
aga	doc_986203247101_item	2968958	et	3	main
erinevait	doc_986203247101_item	2968965	et	4	main
võimalusi	doc_986203247101_item	2968966	et	3	main
võib	doc_986203247101_item	2968967	et	3	main
rikkas	doc_986203247101_item	2968976	et	4	main
ei	doc_986203247101_item	2968978	et	4	main
oska	doc_986203247101_item	2968979	et	4	main
kui	doc_986203247101_item	2968985	et	3	main
materjalset	doc_986203247101_item	2968994	et	4	main
peab	doc_986203247101_item	2968999	et	4	main
vaeva	doc_986203247101_item	2969001	et	4	main
püüab	doc_986203247101_item	2969007	et	3	main
valitut	doc_986203247101_item	2969027	et	4	main
on	doc_986203247101_item	2969029	et	4	main
ja	doc_986203247101_item	2969031	et	3	main
teeb	doc_986203247101_item	2969033	et	3	main
ise	doc_986203247101_item	2969038	et	4	main
raha	doc_986203247101_item	2969046	et	4	main
ja	doc_986203247101_item	2969047	et	3	main
planeerib	doc_986203247101_item	2969048	et	3	main
on	doc_986203247101_item	2969057	et	4	main
rikkaks	doc_986203247101_item	2969059	et	4	main
rikkus	doc_986203247101_item	2969070	et	4	main
alati	doc_986203247101_item	2969074	et	4	main
koos	doc_986203247101_item	2969075	et	4	main
tõesti	doc_986203247101_item	2969081	et	3	main
inimene	doc_986203247101_item	2969082	et	3	main
arvamus	doc_986203247101_item	2968794	et	3	main
lugege	doc_986203247101_item	2968795	et	3	main
neist	doc_986203247101_item	2968798	et	4	main
selle	doc_986203247101_item	2968804	et	4	main
nõus	doc_986203247101_item	2968806	et	4	main
või	doc_986203247101_item	2968807	et	4	main
olema	doc_986203247101_item	2968818	et	4	main
see	doc_986203247101_item	2968822	et	3	main
kasti	doc_986203247101_item	2968837	et	4	main
sisse	doc_986203247101_item	2968838	et	4	main
u	doc_986203247101_item	2968843	et	4	main
näen	doc_986203247101_item	2968851	et	3	main
ma	doc_986203247101_item	2968862	et	3	main
mitte	doc_986203247101_item	2968865	et	3	main
välimuse	doc_986203247101_item	2968867	et	3	main
ja	doc_986203247101_item	2968868	et	3	main
iseloomu	doc_986203247101_item	2968869	et	4	main
järgi	doc_986203247101_item	2968876	et	4	main
ja	doc_986203247101_item	2968877	et	3	main
isegi	doc_986203247101_item	2968878	et	4	main
siis	doc_986203247101_item	2968879	et	3	main
kui	doc_986203247101_item	2968880	et	3	main
rikkad	doc_986203247101_item	2968884	et	4	main
nigunii	doc_986203247101_item	2968887	et	4	main
hulgast	doc_986203247101_item	2968889	et	4	main
võib	doc_986203247101_item	2968890	et	3	main
isegi	doc_986203247101_item	2968907	et	4	main
pilku	doc_986203247101_item	2968910	et	4	main
nende	doc_986203247101_item	2968913	et	4	main
silmadest	doc_986203247101_item	2968914	et	3	main
on	doc_986203247101_item	2968915	et	4	main
kurjad	doc_986203247101_item	2968922	et	4	main
ja	doc_986203247101_item	2968924	et	3	main
ebameeldivad	doc_986203247101_item	2968926	et	3	main
inimesed	doc_986203247101_item	2968927	et	3	main
ma	doc_986203247101_item	2968928	et	3	main
õnnelik	doc_986203247101_item	2968930	et	3	main
et	doc_986203247101_item	2968931	et	3	main
rohkem	doc_986203247101_item	2968938	et	4	main
halbu	doc_986203247101_item	2968942	et	3	main
muidugi	doc_986203247101_item	2968959	et	4	main
mõnda	doc_986203247101_item	2968972	et	4	main
kui	doc_986203247101_item	2968977	et	3	main
midagi	doc_986203247101_item	2968982	et	4	main
ette	doc_986203247101_item	2968983	et	4	main
võtta	doc_986203247101_item	2968984	et	3	main
inimene	doc_986203247101_item	2968986	et	3	main
mõelda	doc_986203247101_item	2968993	et	4	main
saada	doc_986203247101_item	2969012	et	4	main
kindla	doc_986203247101_item	2969014	et	3	main
siis	doc_986203247101_item	2969016	et	3	main
haridusse	doc_986203247101_item	2969020	et	3	main
ja	doc_986203247101_item	2969021	et	3	main
saamisse	doc_986203247101_item	2969024	et	4	main
sest	doc_986203247101_item	2969025	et	4	main
kui	doc_986203247101_item	2969026	et	3	main
ta	doc_986203247101_item	2969032	et	4	main
on	doc_986203247101_item	2969037	et	4	main
valinud	doc_986203247101_item	2969039	et	4	main
ja	doc_986203247101_item	2969040	et	3	main
mida	doc_986203247101_item	2969049	et	4	main
sellega	doc_986203247101_item	2969050	et	3	main
ette	doc_986203247101_item	2969051	et	4	main
võtta	doc_986203247101_item	2969052	et	3	main
arvatest	doc_986203247101_item	2969055	et	3	main
eesmärk	doc_986203247101_item	2969058	et	3	main
saada	doc_986203247101_item	2969060	et	4	main
selleks	doc_986203247101_item	2969061	et	4	main
isegi	doc_986203247101_item	2969065	et	4	main
mäng	doc_986203247101_item	2969066	et	3	main
mis	doc_986203247101_item	2969067	et	4	main
tõestab	doc_986203247101_item	2969068	et	3	main
et	doc_986203247101_item	2969069	et	3	main
tarkus	doc_986203247101_item	2969072	et	4	main
koos	doc_986203247101_item	2968834	et	4	main
kirjutage	doc_986203247101_item	2968835	et	3	main
nõutav	doc_986203247101_item	2968840	et	4	main
et	doc_986203247101_item	2968852	et	3	main
kui	doc_986203247101_item	2968853	et	3	main
palju	doc_986203247101_item	2968854	et	4	main
inimesi	doc_986203247101_item	2968855	et	4	main
ei	doc_986203247101_item	2968856	et	4	main
oleks	doc_986203247101_item	2968857	et	3	main
kõik	doc_986203247101_item	2968858	et	4	main
nad	doc_986203247101_item	2968859	et	3	main
erinevad	doc_986203247101_item	2968860	et	4	main
seda	doc_986203247101_item	2968861	et	3	main
nende	doc_986203247101_item	2968873	et	4	main
nende	doc_986203247101_item	2968908	et	4	main
kohe	doc_986203247101_item	2968916	et	4	main
näha	doc_986203247101_item	2968917	et	3	main
et	doc_986203247101_item	2968918	et	3	main
nad	doc_986203247101_item	2968919	et	3	main
valelikud	doc_986203247101_item	2968923	et	3	main
ainult	doc_986203247101_item	2968937	et	4	main
kui	doc_986203247101_item	2968941	et	3	main
inimene	doc_986203247101_item	2968946	et	3	main
noh	doc_986203247101_item	2968957	et	3	main
et	doc_986203247101_item	2968960	et	3	main
lihtsalt	doc_986203247101_item	2968968	et	4	main
päranduse	doc_986203247101_item	2968969	et	4	main
saada	doc_986203247101_item	2968970	et	4	main
ja	doc_986203247101_item	2968971	et	3	main
ajaks	doc_986203247101_item	2968973	et	4	main
rahaga	doc_986203247101_item	2968981	et	4	main
kui	doc_986203247101_item	2969005	et	3	main
inimesi	doc_986203247101_item	2968940	et	4	main
et	doc_986203247101_item	2968945	et	3	main
või	doc_986203247101_item	2968949	et	4	main
halb	doc_986203247101_item	2968950	et	3	main
hea	doc_986203247101_item	2968948	et	4	main
ei	doc_986203247101_item	2968951	et	4	main
sõltu	doc_986203247101_item	2968952	et	4	main
raha	doc_986203247101_item	2968953	et	4	main
suurusest	doc_986203247101_item	2968954	et	4	main
tema	doc_986203247101_item	2968955	et	4	main
rikkaks	doc_986203247101_item	2968962	et	4	main
on	doc_986203247101_item	2968963	et	4	main
oled	doc_986203247101_item	2968974	et	3	main
selle	doc_986203247101_item	2968980	et	4	main
tahab	doc_986203247101_item	2968987	et	3	main
saada	doc_986203247101_item	2968989	et	4	main
rikkust	doc_986203247101_item	2968995	et	3	main
ta	doc_986203247101_item	2968997	et	4	main
palju	doc_986203247101_item	2969000	et	4	main
näha	doc_986203247101_item	2969002	et	3	main
eriala	doc_986203247101_item	2969003	et	4	main
omandamisega	doc_986203247101_item	2969004	et	4	main
inimene	doc_986203247101_item	2969006	et	3	main
ja	doc_986203247101_item	2969008	et	3	main
on	doc_986203247101_item	2969010	et	4	main
endale	doc_986203247101_item	2969013	et	4	main
tuleviku	doc_986203247101_item	2969015	et	4	main
omandanud	doc_986203247101_item	2969030	et	4	main
tööt	doc_986203247101_item	2969034	et	4	main
talle	doc_986203247101_item	2969041	et	4	main
see	doc_986203247101_item	2969042	et	3	main
meeldib	doc_986203247101_item	2969043	et	3	main
ta	doc_986203247101_item	2969044	et	4	main
teenib	doc_986203247101_item	2969045	et	3	main
ta	doc_986203247101_item	2969062	et	4	main
saada	doc_986203247101_item	2969078	et	4	main
peaks	doc_986203247103_item	2969264	et	4	main
rikkus	doc_986203247103_item	2969276	et	4	main
ja	doc_986203247103_item	2969277	et	3	main
käivad	doc_986203247103_item	2969310	et	4	main
alati	doc_986203247103_item	2969311	et	4	main
koos	doc_986203247103_item	2969312	et	4	main
targed	doc_986203247103_item	2969313	et	3	main
inimesed	doc_986203247103_item	2969314	et	3	main
võivad	doc_986203247103_item	2969320	et	4	main
tarkus	doc_986203247103_item	2969324	et	4	main
alati	doc_986203247103_item	2969326	et	4	main
väärtus	doc_986203247103_item	2969327	et	3	main
inimestes	doc_986203247103_item	2969328	et	3	main
ja	doc_986203247103_item	2969329	et	3	main
tööandja	doc_986203247103_item	2969330	et	4	main
kes	doc_986203247103_item	2969343	et	4	main
ma	doc_986203247103_item	2969351	et	3	main
nende	doc_986203247103_item	2969363	et	4	main
isegi	doc_986203247103_item	2969392	et	4	main
ravida	doc_986203247103_item	2969396	et	3	main
oma	doc_986203247103_item	2969397	et	4	main
patsiendi	doc_986203247103_item	2969398	et	3	main
aga	doc_986203247103_item	2969399	et	3	main
see	doc_986203247103_item	2969400	et	3	main
ma	doc_986203247103_item	2969406	et	3	main
enda	doc_986203247101_item	2969022	et	4	main
targeks	doc_986203247101_item	2969023	et	4	main
mida	doc_986203247101_item	2969035	et	4	main
ta	doc_986203247101_item	2969036	et	4	main
siis	doc_986203247101_item	2969053	et	3	main
kui	doc_986203247101_item	2969056	et	3	main
ja	doc_986203247101_item	2969071	et	3	main
käivad	doc_986203247101_item	2969073	et	4	main
miljonäriks	doc_986203247101_item	2969079	et	4	main
ja	doc_986203247101_item	2969080	et	3	main
peab	doc_986203247101_item	2969083	et	4	main
olema	doc_986203247101_item	2969084	et	4	main
tark	doc_986203247101_item	2969085	et	3	main
et	doc_986203247101_item	2969086	et	3	main
saada	doc_986203247101_item	2969087	et	4	main
rikkaks	doc_986203247101_item	2969088	et	4	main
ja	doc_986203247101_item	2969089	et	3	main
selleks	doc_986203247101_item	2969090	et	4	main
ka	doc_986203247101_item	2969091	et	3	main
mina	doc_986203247101_item	2969093	et	4	main
jääda	doc_986203247101_item	2969092	et	4	main
olen	doc_986203247101_item	2969094	et	3	main
mõistega	doc_986203247101_item	2969095	et	3	main
nõus	doc_986203247101_item	2969096	et	4	main
väitega	doc_986203247103_item	2969252	et	3	main
mitte	doc_986203247103_item	2969255	et	3	main
olema	doc_986203247103_item	2969265	et	4	main
kaasa	doc_986203247103_item	2969271	et	4	main
tekkimisele	doc_986203247103_item	2969273	et	4	main
väide	doc_986203247103_item	2969274	et	4	main
2	doc_986203247103_item	2969275	et	2	main
ja	doc_986203247103_item	2969308	et	3	main
ja	doc_986203247103_item	2969318	et	3	main
töötada	doc_986203247103_item	2969321	et	3	main
austab	doc_986203247103_item	2969332	et	3	main
oma	doc_986203247103_item	2969335	et	4	main
töötajat	doc_986203247103_item	2969336	et	4	main
halvasti	doc_986203247103_item	2969344	et	3	main
õppisid	doc_986203247103_item	2969345	et	4	main
pärast	doc_986203247103_item	2969347	et	4	main
see	doc_986203247103_item	2969354	et	3	main
sellepärast	doc_986203247103_item	2969356	et	3	main
nendel	doc_986203247103_item	2969358	et	4	main
oli	doc_986203247103_item	2969360	et	3	main
raha	doc_986203247103_item	2969361	et	4	main
et	doc_986203247103_item	2969362	et	3	main
olema	doc_986203247105_item	2969611	et	4	main
tekkimisele	doc_986203247105_item	2969619	et	4	main
tarkus	doc_986203247105_item	2969624	et	4	main
joonitud	doc_986203247105_item	2969629	et	4	main
kasti	doc_986203247105_item	2969630	et	4	main
on	doc_986203247105_item	2969635	et	4	main
see	doc_986203247105_item	2969650	et	3	main
tikkimisele	doc_986203247105_item	2969654	et	4	main
kui	doc_986203247105_item	2969656	et	3	main
vanemad	doc_986203247105_item	2969660	et	4	main
koolivorm	doc_986203247105_item	2969663	et	3	main
nagu	doc_986203247105_item	2969668	et	3	main
osta	doc_986203247105_item	2969675	et	4	main
välja	doc_986203247105_item	2969678	et	4	main
ja	doc_986203247105_item	2969681	et	3	main
ma	doc_986203247105_item	2969683	et	3	main
arvamus	doc_986203247103_item	2969241	et	3	main
lugege	doc_986203247103_item	2969242	et	3	main
1	doc_986203247103_item	2969261	et	2	main
igal	doc_986203247103_item	2969262	et	3	main
koolil	doc_986203247103_item	2969263	et	4	main
see	doc_986203247103_item	2969269	et	3	main
omakoolitunde	doc_986203247103_item	2969272	et	4	main
käivad	doc_986203247103_item	2969279	et	4	main
alati	doc_986203247103_item	2969280	et	4	main
koos	doc_986203247103_item	2969281	et	4	main
saavad	doc_986203247103_item	2969315	et	4	main
ona	doc_986203247103_item	2969325	et	4	main
väiteid	doc_986203247103_item	2969243	et	4	main
valige	doc_986203247103_item	2969244	et	3	main
nõus	doc_986203247103_item	2969253	et	4	main
esitage	doc_986203247103_item	2969256	et	3	main
oma	doc_986203247103_item	2969266	et	4	main
koolivorm	doc_986203247103_item	2969267	et	3	main
sest	doc_986203247103_item	2969268	et	4	main
aitab	doc_986203247103_item	2969270	et	3	main
tarkus	doc_986203247103_item	2969309	et	4	main
sellepärast	doc_986203247103_item	2969319	et	3	main
kõrgelttasustaval	doc_986203247103_item	2969322	et	3	main
elus	doc_986203247103_item	2969337	et	4	main
on	doc_986203247103_item	2969338	et	4	main
nii	doc_986203247103_item	2969339	et	3	main
et	doc_986203247103_item	2969340	et	3	main
arvan	doc_986203247103_item	2969352	et	3	main
et	doc_986203247103_item	2969357	et	3	main
tea	doc_986203247103_item	2969394	et	4	main
kuidas	doc_986203247103_item	2969395	et	3	main
nüüd	doc_986203247103_item	2969405	et	4	main
isegi	doc_986203247103_item	2969407	et	4	main
ei	doc_986203247103_item	2969408	et	4	main
tea	doc_986203247103_item	2969409	et	4	main
kas	doc_986203247103_item	2969410	et	3	main
ma	doc_986203247103_item	2969411	et	3	main
olen	doc_986203247103_item	2969412	et	3	main
igal	doc_986203247105_item	2969608	et	3	main
peaks	doc_986203247105_item	2969610	et	4	main
omakoolitunde	doc_986203247105_item	2969618	et	4	main
rikkus	doc_986203247105_item	2969622	et	4	main
kirjutage	doc_986203247105_item	2969628	et	3	main
olen	doc_986203247105_item	2969640	et	3	main
sest	doc_986203247105_item	2969649	et	4	main
panna	doc_986203247105_item	2969672	et	4	main
selga	doc_986203247105_item	2969673	et	4	main
neist	doc_986203247103_item	2969245	et	4	main
üks	doc_986203247103_item	2969246	et	3	main
ning	doc_986203247103_item	2969247	et	3	main
kirjutage	doc_986203247103_item	2969248	et	3	main
kas	doc_986203247103_item	2969249	et	3	main
olete	doc_986203247103_item	2969250	et	3	main
selle	doc_986203247103_item	2969251	et	4	main
või	doc_986203247103_item	2969254	et	4	main
poolt-	doc_986203247103_item	2969257	et	4	main
ja	doc_986203247103_item	2969258	et	3	main
vastuargumente	doc_986203247103_item	2969259	et	3	main
väide	doc_986203247103_item	2969260	et	4	main
tarkus	doc_986203247103_item	2969278	et	4	main
kirjutage	doc_986203247103_item	2969282	et	3	main
joonitud	doc_986203247103_item	2969283	et	4	main
kasti	doc_986203247103_item	2969284	et	4	main
sisse	doc_986203247103_item	2969285	et	4	main
teksti	doc_986203247103_item	2969286	et	4	main
nõutav	doc_986203247103_item	2969287	et	4	main
pikkus	doc_986203247103_item	2969288	et	4	main
on	doc_986203247103_item	2969289	et	4	main
u	doc_986203247103_item	2969290	et	4	main
160	doc_986203247103_item	2969291	et	2	main
sõna	doc_986203247103_item	2969292	et	4	main
vaide	doc_986203247103_item	2969293	et	3	main
2	doc_986203247103_item	2969294	et	2	main
rikkus	doc_986203247103_item	2969295	et	4	main
ja	doc_986203247103_item	2969296	et	3	main
tarkus	doc_986203247103_item	2969297	et	4	main
käivad	doc_986203247103_item	2969298	et	4	main
alati	doc_986203247103_item	2969299	et	4	main
koos	doc_986203247103_item	2969300	et	4	main
mina	doc_986203247103_item	2969301	et	4	main
olen	doc_986203247103_item	2969302	et	3	main
nõus	doc_986203247103_item	2969303	et	4	main
selle	doc_986203247103_item	2969304	et	4	main
väitega	doc_986203247103_item	2969305	et	3	main
et	doc_986203247103_item	2969306	et	3	main
rikkus	doc_986203247103_item	2969307	et	4	main
kõrgema	doc_986203247103_item	2969316	et	4	main
hariduse	doc_986203247103_item	2969317	et	3	main
tööl	doc_986203247103_item	2969323	et	3	main
ja	doc_986203247103_item	2969333	et	3	main
need	doc_986203247103_item	2969341	et	3	main
kohal	doc_986203247103_item	2969350	et	4	main
et	doc_986203247103_item	2969353	et	3	main
vanematel	doc_986203247103_item	2969359	et	4	main
poeg	doc_986203247103_item	2969364	et	3	main
tütar	doc_986203247103_item	2969366	et	3	main
saama	doc_986203247103_item	2969368	et	4	main
nõus	doc_986203247103_item	2969413	et	4	main
olen	doc_986203247103_item	2969422	et	3	main
poolel	doc_986203247103_item	2969424	et	4	main
alati	doc_986203247103_item	2969331	et	4	main
hindab	doc_986203247103_item	2969334	et	3	main
inimesed	doc_986203247103_item	2969342	et	3	main
koolis	doc_986203247103_item	2969346	et	4	main
töötavad	doc_986203247103_item	2969348	et	4	main
kõrgelttasustaval	doc_986203247103_item	2969349	et	3	main
on	doc_986203247103_item	2969355	et	4	main
või	doc_986203247103_item	2969365	et	4	main
läks	doc_986203247103_item	2969367	et	3	main
kõrgema	doc_986203247103_item	2969369	et	4	main
hariduse	doc_986203247103_item	2969370	et	3	main
aga	doc_986203247103_item	2969371	et	3	main
see	doc_986203247103_item	2969372	et	3	main
on	doc_986203247103_item	2969373	et	4	main
probleem	doc_986203247103_item	2969374	et	3	main
kui	doc_986203247103_item	2969375	et	3	main
see	doc_986203247103_item	2969376	et	3	main
poeg	doc_986203247103_item	2969377	et	3	main
või	doc_986203247103_item	2969378	et	4	main
tütar	doc_986203247103_item	2969379	et	3	main
läks	doc_986203247103_item	2969380	et	3	main
näiteks	doc_986203247103_item	2969381	et	4	main
õppima	doc_986203247103_item	2969382	et	3	main
arstiks	doc_986203247103_item	2969383	et	4	main
ja	doc_986203247103_item	2969384	et	3	main
kui	doc_986203247103_item	2969385	et	3	main
ta	doc_986203247103_item	2969386	et	4	main
töötab	doc_986203247103_item	2969387	et	3	main
arstina	doc_986203247103_item	2969388	et	3	main
ja	doc_986203247103_item	2969389	et	3	main
ei	doc_986203247103_item	2969390	et	4	main
saa	doc_986203247103_item	2969391	et	4	main
ei	doc_986203247103_item	2969393	et	4	main
on	doc_986203247103_item	2969401	et	4	main
juba	doc_986203247103_item	2969402	et	3	main
katastroff	doc_986203247103_item	2969403	et	4	main
ja	doc_986203247103_item	2969404	et	3	main
või	doc_986203247103_item	2969414	et	4	main
mitte	doc_986203247103_item	2969415	et	3	main
selle	doc_986203247103_item	2969416	et	4	main
väitega	doc_986203247103_item	2969417	et	3	main
ma	doc_986203247103_item	2969418	et	3	main
arvan	doc_986203247103_item	2969419	et	3	main
et	doc_986203247103_item	2969420	et	3	main
ma	doc_986203247103_item	2969421	et	3	main
neutraalsel	doc_986203247103_item	2969423	et	3	main
koolil	doc_986203247105_item	2969609	et	4	main
käivad	doc_986203247105_item	2969625	et	4	main
koos	doc_986203247105_item	2969627	et	4	main
sisse	doc_986203247105_item	2969631	et	4	main
u	doc_986203247105_item	2969636	et	4	main
160	doc_986203247105_item	2969637	et	2	main
olema	doc_986203247105_item	2969646	et	4	main
omakoolitunde	doc_986203247105_item	2969653	et	4	main
veel	doc_986203247105_item	2969657	et	4	main
õpinud	doc_986203247105_item	2969658	et	4	main
oli	doc_986203247105_item	2969661	et	3	main
ei	doc_986203247105_item	2969665	et	4	main
praegu	doc_986203247105_item	2969669	et	3	main
meil	doc_986203247105_item	2969670	et	4	main
mida	doc_986203247105_item	2969671	et	4	main
et	doc_986203247105_item	2969676	et	3	main
ilusti	doc_986203247105_item	2969680	et	3	main
ei	doc_986203247105_item	2969684	et	4	main
leia	doc_986203247105_item	2969685	et	4	main
kooli	doc_986203247105_item	2969693	et	4	main
küll	doc_986203247105_item	2969696	et	4	main
olnud	doc_986203247105_item	2969698	et	4	main
oma	doc_986203247105_item	2969707	et	4	main
koolivorm	doc_986203247105_item	2969708	et	3	main
venemaal	doc_986203247105_item	2969723	et	4	main
hea	doc_986203247105_item	2969735	et	4	main
või	doc_986203247105_item	2969736	et	4	main
halb	doc_986203247105_item	2969737	et	3	main
kui	doc_986203247105_item	2969738	et	3	main
ilusad	doc_986203247105_item	2969747	et	3	main
ja	doc_986203247105_item	2969751	et	3	main
seelikud	doc_986203247105_item	2969753	et	3	main
kui	doc_986203247105_item	2969755	et	3	main
koolis	doc_986203247105_item	2969769	et	4	main
teinud	doc_986203247105_item	2969776	et	4	main
õpiks	doc_986203247105_item	2969779	et	4	main
nagu	doc_986203247105_item	2969781	et	3	main
ma	doc_986203247105_item	2969786	et	3	main
väide	doc_986203247105_item	2969620	et	4	main
arvamus	doc_986203247105_item	2969587	et	3	main
lugege	doc_986203247105_item	2969588	et	3	main
väiteid	doc_986203247105_item	2969589	et	4	main
valige	doc_986203247105_item	2969590	et	3	main
neist	doc_986203247105_item	2969591	et	4	main
üks	doc_986203247105_item	2969592	et	3	main
ning	doc_986203247105_item	2969593	et	3	main
kirjutage	doc_986203247105_item	2969594	et	3	main
kas	doc_986203247105_item	2969595	et	3	main
olete	doc_986203247105_item	2969596	et	3	main
selle	doc_986203247105_item	2969597	et	4	main
väitega	doc_986203247105_item	2969598	et	3	main
nõus	doc_986203247105_item	2969599	et	4	main
või	doc_986203247105_item	2969600	et	4	main
mitte	doc_986203247105_item	2969601	et	3	main
esitage	doc_986203247105_item	2969602	et	3	main
poolt-	doc_986203247105_item	2969603	et	4	main
ja	doc_986203247105_item	2969604	et	3	main
vastuargumente	doc_986203247105_item	2969605	et	3	main
väide	doc_986203247105_item	2969606	et	4	main
1	doc_986203247105_item	2969607	et	2	main
oma	doc_986203247105_item	2969612	et	4	main
koolivorm	doc_986203247105_item	2969613	et	3	main
sest	doc_986203247105_item	2969614	et	4	main
see	doc_986203247105_item	2969615	et	3	main
aitab	doc_986203247105_item	2969616	et	3	main
kaasa	doc_986203247105_item	2969617	et	4	main
2	doc_986203247105_item	2969621	et	2	main
alati	doc_986203247105_item	2969626	et	4	main
teksti	doc_986203247105_item	2969632	et	4	main
nõutav	doc_986203247105_item	2969633	et	4	main
pikkus	doc_986203247105_item	2969634	et	4	main
oma	doc_986203247105_item	2969647	et	4	main
koolivorm	doc_986203247105_item	2969648	et	3	main
kaasa	doc_986203247105_item	2969652	et	4	main
meie	doc_986203247105_item	2969659	et	4	main
tekkinud	doc_986203247105_item	2969666	et	4	main
probleemid	doc_986203247105_item	2969667	et	3	main
mida	doc_986203247105_item	2969674	et	4	main
seda	doc_986203247105_item	2969695	et	3	main
ei	doc_986203247105_item	2969697	et	4	main
mu	doc_986203247105_item	2969699	et	3	main
ema	doc_986203247105_item	2969700	et	4	main
räägis	doc_986203247105_item	2969701	et	3	main
te	doc_986203247105_item	2969709	et	4	main
võiksite	doc_986203247105_item	2969710	et	3	main
käia	doc_986203247105_item	2969714	et	4	main
siis	doc_986203247105_item	2969724	et	3	main
meil	doc_986203247105_item	2969725	et	4	main
küll	doc_986203247105_item	2969726	et	4	main
oli	doc_986203247105_item	2969727	et	3	main
koolivorm	doc_986203247105_item	2969728	et	3	main
aga	doc_986203247105_item	2969729	et	3	main
vaadata	doc_986203247105_item	2969739	et	4	main
tüdrukutel	doc_986203247105_item	2969745	et	4	main
siis	doc_986203247105_item	2969758	et	3	main
valged	doc_986203247105_item	2969761	et	3	main
rangemad	doc_986203247105_item	2969771	et	4	main
ei	doc_986203247105_item	2969775	et	4	main
vanasti	doc_986203247105_item	2969782	et	3	main
kui	doc_986203247105_item	2969785	et	3	main
sellel	doc_986203247105_item	2969799	et	4	main
ja	doc_986203247105_item	2969623	et	3	main
sõna	doc_986203247105_item	2969638	et	4	main
ma	doc_986203247105_item	2969639	et	3	main
nõus	doc_986203247105_item	2969641	et	4	main
et	doc_986203247105_item	2969642	et	3	main
igal	doc_986203247105_item	2969643	et	3	main
koolil	doc_986203247105_item	2969644	et	4	main
peaks	doc_986203247105_item	2969645	et	4	main
aitab	doc_986203247105_item	2969651	et	3	main
vanasti	doc_986203247105_item	2969655	et	3	main
küll	doc_986203247105_item	2969662	et	4	main
ja	doc_986203247105_item	2969664	et	3	main
midagi	doc_986203247105_item	2969686	et	4	main
siis	doc_986203247105_item	2969687	et	3	main
otsustan	doc_986203247105_item	2969688	et	3	main
et	doc_986203247105_item	2969689	et	3	main
täna	doc_986203247105_item	2969690	et	4	main
vanasti	doc_986203247105_item	2969694	et	3	main
teil	doc_986203247105_item	2969704	et	4	main
õppida	doc_986203247105_item	2969712	et	3	main
igapäev	doc_986203247105_item	2969713	et	3	main
ma	doc_986203247105_item	2969716	et	3	main
mäletan	doc_986203247105_item	2969717	et	3	main
kui	doc_986203247105_item	2969718	et	3	main
ma	doc_986203247105_item	2969719	et	3	main
õpisin	doc_986203247105_item	2969720	et	4	main
klassis	doc_986203247105_item	2969722	et	3	main
ei	doc_986203247105_item	2969730	et	4	main
pilti	doc_986203247105_item	2969740	et	4	main
oli	doc_986203247105_item	2969746	et	3	main
aga	doc_986203247105_item	2969754	et	3	main
oleks	doc_986203247105_item	2969770	et	3	main
keegi	doc_986203247105_item	2969774	et	4	main
praegu	doc_986203247105_item	2969784	et	3	main
on	doc_986203247105_item	2969789	et	4	main
koolis	doc_986203247105_item	2969677	et	4	main
nägema	doc_986203247105_item	2969679	et	3	main
kui	doc_986203247105_item	2969682	et	3	main
ei	doc_986203247105_item	2969691	et	4	main
mulle	doc_986203247105_item	2969702	et	4	main
kui	doc_986203247105_item	2969703	et	3	main
hästi	doc_986203247105_item	2969711	et	3	main
esimesel	doc_986203247105_item	2969721	et	3	main
sii	doc_986203247105_item	2969741	et	4	main
oli	doc_986203247105_item	2969742	et	3	main
väga	doc_986203247105_item	2969743	et	3	main
ilus	doc_986203247105_item	2969744	et	4	main
patsid	doc_986203247105_item	2969748	et	4	main
pluusid	doc_986203247105_item	2969750	et	3	main
panime	doc_986203247105_item	2969760	et	3	main
muidugi	doc_986203247105_item	2969763	et	4	main
koolivorm	doc_986203247105_item	2969764	et	3	main
aitaks	doc_986203247105_item	2969765	et	3	main
käitumisest	doc_986203247105_item	2969766	et	4	main
ja	doc_986203247105_item	2969767	et	3	main
kui	doc_986203247105_item	2969768	et	3	main
siis	doc_986203247105_item	2969773	et	3	main
ja	doc_986203247105_item	2969778	et	3	main
hästi	doc_986203247105_item	2969780	et	3	main
koolindžis	doc_986203247105_item	2969788	et	2	main
ei	doc_986203247105_item	2969792	et	4	main
tea	doc_986203247105_item	2969793	et	4	main
kas	doc_986203247105_item	2969794	et	3	main
see	doc_986203247105_item	2969795	et	3	main
aitab	doc_986203247105_item	2969796	et	3	main
või	doc_986203247105_item	2969797	et	4	main
mitte	doc_986203247105_item	2969798	et	3	main
lähe	doc_986203247105_item	2969692	et	4	main
koolis	doc_986203247105_item	2969705	et	4	main
oleks	doc_986203247105_item	2969706	et	3	main
kooli	doc_986203247105_item	2969715	et	4	main
mäleta	doc_986203247105_item	2969731	et	4	main
kas	doc_986203247105_item	2969732	et	3	main
see	doc_986203247105_item	2969733	et	3	main
oli	doc_986203247105_item	2969734	et	3	main
sinised	doc_986203247105_item	2969749	et	4	main
mustad	doc_986203247105_item	2969752	et	4	main
oli	doc_986203247105_item	2969756	et	3	main
pidu	doc_986203247105_item	2969757	et	4	main
me	doc_986203247105_item	2969759	et	4	main
pluusid	doc_986203247105_item	2969762	et	3	main
suhted	doc_986203247105_item	2969772	et	3	main
poppi	doc_986203247105_item	2969777	et	4	main
aga	doc_986203247105_item	2969783	et	3	main
mäletan	doc_986203247105_item	2969787	et	3	main
koolivorm	doc_986203247105_item	2969790	et	3	main
aga	doc_986203247105_item	2969791	et	3	main
elus	doc_986203247105_item	2969800	et	4	main
sest	doc_986203247105_item	2969801	et	4	main
meil	doc_986203247105_item	2969802	et	4	main
praegu	doc_986203247105_item	2969803	et	3	main
nii	doc_986203247105_item	2969804	et	3	main
hull	doc_986203247105_item	2969805	et	3	main
elu	doc_986203247105_item	2969806	et	4	main
töötajad	doc_986203247112_item	2970713	et	4	main
viis	doc_986203247112_item	2970714	et	4	main
läbi	doc_986203247112_item	2970717	et	4	main
inimeste	doc_986203247112_item	2970723	et	3	main
inimest	doc_986203247112_item	2970728	et	3	main
erinevaid	doc_986203247112_item	2970730	et	4	main
kui	doc_986203247112_item	2970745	et	3	main
õppeaasta	doc_986203247112_item	2970748	et	4	main
igal	doc_986203247112_item	2970787	et	3	main
aastal	doc_986203247112_item	2970788	et	3	main
kuna	doc_986203247112_item	2970789	et	3	main
kasvatatakse	doc_986203247112_item	2970792	et	3	main
esikohal	doc_986203247112_item	2970800	et	4	main
see	doc_986203247112_item	2970810	et	3	main
minu	doc_986203247112_item	2970814	et	3	main
mõned	doc_986203247112_item	2970816	et	3	main
pühitsetakse	doc_986203247112_item	2970822	et	3	main
seda	doc_986203247112_item	2970824	et	3	main
et	doc_986203247112_item	2970837	et	3	main
osalenud	doc_986203247112_item	2970839	et	4	main
suviti	doc_986203247112_item	2970840	et	3	main
puhkavad	doc_986203247112_item	2970841	et	4	main
nad	doc_986203247112_item	2970842	et	3	main
päevitades	doc_986203247112_item	2970846	et	3	main
sügise	doc_986203247112_item	2970849	et	3	main
tuleb	doc_986203247112_item	2970851	et	3	main
töötamise	doc_986203247112_item	2970855	et	4	main
grupi	doc_986203247112_item	2970861	et	3	main
kelle	doc_986203247112_item	2970862	et	4	main
algusega	doc_986203247112_item	2970868	et	3	main
ja	doc_986203247112_item	2970869	et	3	main
teise	doc_986203247112_item	2970870	et	4	main
postimees	doc_986203247112_item	2970712	et	4	main
uuriti	doc_986203247112_item	2970720	et	3	main
uurimuses	doc_986203247112_item	2970725	et	3	main
küsitleti	doc_986203247112_item	2970729	et	3	main
elanike	doc_986203247112_item	2970731	et	3	main
nii	doc_986203247112_item	2970743	et	3	main
kõige	doc_986203247112_item	2970760	et	4	main
skemil	doc_986203247112_item	2970799	et	4	main
väiksem	doc_986203247112_item	2970802	et	4	main
septembrit	doc_986203247112_item	2970807	et	3	main
rahupäevaga	doc_986203247112_item	2970809	et	3	main
tea	doc_986203247112_item	2970819	et	4	main
käigus	doc_986203247112_item	2970719	et	4	main
2584	doc_986203247112_item	2970727	et	2	main
nii	doc_986203247112_item	2970733	et	3	main
vanemaid	doc_986203247112_item	2970737	et	4	main
nii	doc_986203247112_item	2970738	et	3	main
lapsi	doc_986203247112_item	2970739	et	4	main
kui	doc_986203247112_item	2970740	et	3	main
ka	doc_986203247112_item	2970741	et	3	main
täiskasvanuid	doc_986203247112_item	2970742	et	3	main
jõuab	doc_986203247112_item	2970749	et	3	main
teada	doc_986203247112_item	2970753	et	3	main
vastajatest	doc_986203247112_item	2970755	et	4	main
millega	doc_986203247112_item	2970756	et	3	main
vastanute	doc_986203247112_item	2970762	et	4	main
osa	doc_986203247112_item	2970763	et	4	main
tähtis	doc_986203247112_item	2970785	et	4	main
peaaegu	doc_986203247112_item	2970790	et	3	main
õpilased	doc_986203247112_item	2970793	et	3	main
loogiline	doc_986203247112_item	2970795	et	4	main
et	doc_986203247112_item	2970796	et	3	main
see	doc_986203247112_item	2970797	et	3	main
on	doc_986203247112_item	2970798	et	4	main
seostab	doc_986203247112_item	2970805	et	3	main
pole	doc_986203247112_item	2970811	et	3	main
arvates	doc_986203247112_item	2970815	et	4	main
teisel	doc_986203247112_item	2970826	et	4	main
kohal	doc_986203247112_item	2970827	et	4	main
suve	doc_986203247112_item	2970833	et	4	main
pöörduma	doc_986203247112_item	2970853	et	3	main
poole	doc_986203247112_item	2970856	et	4	main
skeemi	doc_986203247112_item	2970874	et	4	main
vastasid	doc_986203247112_item	2970880	et	4	main
töötavad	doc_986203247112_item	2970885	et	4	main
oma	doc_986203247112_item	2970886	et	4	main
suvilades	doc_986203247112_item	2970887	et	3	main
ja	doc_986203247112_item	2970888	et	3	main
kui	doc_986203247112_item	2970892	et	3	main
minu	doc_986203247112_item	2970904	et	3	main
seda	doc_986203247112_item	2970908	et	3	main
kaunistan	doc_986203247112_item	2970912	et	3	main
läbi	doc_986203247112_item	2970917	et	4	main
väga	doc_986203247112_item	2970918	et	3	main
tähtsa	doc_986203247112_item	2970919	et	3	main
postimees	doc_986203247113_item	2970930	et	4	main
küsitletud	doc_986203247113_item	2970944	et	4	main
ajalehe	doc_986203247113_item	2970956	et	3	main
suurem	doc_986203247113_item	2970958	et	4	main
algusega	doc_986203247113_item	2970968	et	3	main
inimesed	doc_986203247113_item	2970971	et	3	main
peamiselt	doc_986203247113_item	2970972	et	4	main
kirjeldus	doc_986203247112_item	2970710	et	4	main
ajalehe	doc_986203247112_item	2970711	et	3	main
küsitluse	doc_986203247112_item	2970716	et	4	main
kirjeldus	doc_986203247112_item	2970708	et	4	main
graafiku	doc_986203247112_item	2970709	et	3	main
hiljuti	doc_986203247112_item	2970715	et	4	main
selle	doc_986203247112_item	2970718	et	4	main
esimesele	doc_986203247112_item	2970721	et	3	main
osales	doc_986203247112_item	2970726	et	3	main
nooremaid	doc_986203247112_item	2970734	et	4	main
ka	doc_986203247112_item	2970736	et	3	main
tööliseid	doc_986203247112_item	2970744	et	3	main
uut	doc_986203247112_item	2970747	et	3	main
ligi	doc_986203247112_item	2970750	et	3	main
sestap	doc_986203247112_item	2970751	et	3	main
sooviti	doc_986203247112_item	2970752	et	3	main
saada	doc_986203247112_item	2970754	et	4	main
seostub	doc_986203247112_item	2970757	et	3	main
neile	doc_986203247112_item	2970758	et	4	main
1september	doc_986203247112_item	2970759	et	3	main
suurem	doc_986203247112_item	2970761	et	4	main
perekonnas	doc_986203247112_item	2970791	et	4	main
on	doc_986203247112_item	2970794	et	4	main
vastanuid	doc_986203247112_item	2970804	et	4	main
ülemaailmse	doc_986203247112_item	2970808	et	3	main
imekspandav	doc_986203247112_item	2970812	et	3	main
et	doc_986203247112_item	2970821	et	3	main
maailmas	doc_986203247112_item	2970823	et	3	main
on	doc_986203247112_item	2970828	et	4	main
1september	doc_986203247112_item	2970831	et	3	main
näitabki	doc_986203247112_item	2970836	et	3	main
puhata	doc_986203247112_item	2970844	et	4	main
aga	doc_986203247112_item	2970848	et	3	main
jälle	doc_986203247112_item	2970852	et	3	main
saagi	doc_986203247112_item	2970890	et	4	main
ma	doc_986203247112_item	2970893	et	3	main
vastaksin	doc_986203247112_item	2970895	et	3	main
küsimusele	doc_986203247112_item	2970896	et	4	main
räägiksin	doc_986203247112_item	2970899	et	3	main
algusest	doc_986203247112_item	2970901	et	4	main
sügis	doc_986203247112_item	2970902	et	3	main
nimetus	doc_986203247112_item	2970922	et	4	main
viis	doc_986203247113_item	2970931	et	4	main
välja	doc_986203247113_item	2970937	et	4	main
millega	doc_986203247113_item	2970938	et	3	main
võib	doc_986203247113_item	2970939	et	3	main
seostuda	doc_986203247113_item	2970940	et	3	main
vastajat	doc_986203247113_item	2970950	et	4	main
kui	doc_986203247113_item	2970953	et	3	main
lugejaid	doc_986203247113_item	2970957	et	4	main
osa	doc_986203247113_item	2970959	et	4	main
ise	doc_986203247113_item	2970974	et	4	main
teisel	doc_986203247113_item	2970980	et	4	main
külmemaks	doc_986203247113_item	2971022	et	4	main
protsent	doc_986203247113_item	2971028	et	3	main
ütles	doc_986203247113_item	2971029	et	3	main
et	doc_986203247113_item	2971030	et	3	main
ülemaailmse	doc_986203247113_item	2971034	et	3	main
ja	doc_986203247113_item	2971036	et	3	main
koolis	doc_986203247113_item	2971057	et	4	main
peavad	doc_986203247113_item	2971062	et	4	main
septembrile	doc_986203247112_item	2970722	et	3	main
suhet	doc_986203247112_item	2970724	et	3	main
gruppe	doc_986203247112_item	2970732	et	3	main
kui	doc_986203247112_item	2970735	et	3	main
üliõpilasi	doc_986203247112_item	2970746	et	3	main
umbes	doc_986203247112_item	2970764	et	4	main
kolm	doc_986203247112_item	2970765	et	3	main
neljandik	doc_986203247112_item	2970766	et	3	main
veerandi	doc_986203247112_item	2970767	et	4	main
seostab	doc_986203247112_item	2970768	et	3	main
septembrit	doc_986203247112_item	2970770	et	3	main
esimest	doc_986203247112_item	2970769	et	4	main
kooliaasta	doc_986203247112_item	2970771	et	4	main
algusega	doc_986203247112_item	2970772	et	3	main
see	doc_986203247112_item	2970773	et	3	main
protsent	doc_986203247112_item	2970774	et	3	main
kujuneb	doc_986203247112_item	2970775	et	3	main
õpilastest	doc_986203247112_item	2970776	et	4	main
vanematest	doc_986203247112_item	2970777	et	4	main
õpetajatest	doc_986203247112_item	2970778	et	4	main
kelle	doc_986203247112_item	2970779	et	4	main
jaoks	doc_986203247112_item	2970780	et	4	main
õppimise	doc_986203247112_item	2970781	et	4	main
algus	doc_986203247112_item	2970782	et	4	main
on	doc_986203247112_item	2970783	et	4	main
väga	doc_986203247112_item	2970784	et	3	main
sündmus	doc_986203247112_item	2970786	et	3	main
kõige	doc_986203247112_item	2970801	et	4	main
protsent	doc_986203247112_item	2970803	et	3	main
1	doc_986203247112_item	2970806	et	2	main
sest	doc_986203247112_item	2970813	et	4	main
inimesed	doc_986203247112_item	2970817	et	3	main
ei	doc_986203247112_item	2970818	et	4	main
üldse	doc_986203247112_item	2970820	et	3	main
vastanud	doc_986203247112_item	2970829	et	4	main
eelistavad	doc_986203247112_item	2970843	et	4	main
mererannas	doc_986203247112_item	2970847	et	3	main
tulekul	doc_986203247112_item	2970850	et	3	main
oma	doc_986203247112_item	2970854	et	4	main
on	doc_986203247112_item	2970857	et	4	main
andmetest	doc_986203247112_item	2970875	et	4	main
niimoodi	doc_986203247112_item	2970879	et	3	main
vanemad	doc_986203247112_item	2970881	et	4	main
inimesed	doc_986203247112_item	2970882	et	3	main
siis	doc_986203247112_item	2970897	et	3	main
sügise	doc_986203247112_item	2970900	et	3	main
lemmik	doc_986203247112_item	2970905	et	3	main
pärast	doc_986203247112_item	2970907	et	4	main
esimeseks	doc_986203247112_item	2970909	et	3	main
ma	doc_986203247112_item	2970911	et	3	main
peo	doc_986203247112_item	2970920	et	4	main
mille	doc_986203247112_item	2970921	et	3	main
on	doc_986203247112_item	2970923	et	4	main
läbi	doc_986203247113_item	2970932	et	4	main
online-küsitluse	doc_986203247113_item	2970933	et	4	main
mille	doc_986203247113_item	2970934	et	3	main
inimestele	doc_986203247113_item	2970941	et	3	main
gruppid	doc_986203247113_item	2970947	et	4	main
2584	doc_986203247113_item	2970949	et	2	main
nii	doc_986203247113_item	2970951	et	3	main
noori	doc_986203247113_item	2970952	et	3	main
vastab	doc_986203247113_item	2970961	et	3	main
seovad	doc_986203247113_item	2970964	et	3	main
loogiliselt	doc_986203247113_item	2970969	et	4	main
omavad	doc_986203247113_item	2970976	et	4	main
lühemaks	doc_986203247113_item	2971024	et	4	main
väiksem	doc_986203247113_item	2971026	et	4	main
vastust	doc_986203247113_item	2971038	et	4	main
5protsenti	doc_986203247113_item	2971042	et	4	main
ise	doc_986203247113_item	2971055	et	4	main
töötan	doc_986203247113_item	2971056	et	3	main
lapsed	doc_986203247113_item	2971060	et	3	main
vastata	doc_986203247113_item	2971071	et	4	main
ja	doc_986203247115_item	2971250	et	3	main
käin	doc_986203247115_item	2971254	et	3	main
on	doc_986203247115_item	2971291	et	4	main
kursustel	doc_986203247115_item	2971296	et	3	main
siin	doc_986203247115_item	2971301	et	4	main
saab	doc_986203247115_item	2971302	et	3	main
tähtpäeva	doc_986203247112_item	2970825	et	4	main
kelleks	doc_986203247112_item	2970830	et	4	main
seostub	doc_986203247112_item	2970832	et	3	main
lõppega	doc_986203247112_item	2970834	et	3	main
see	doc_986203247112_item	2970835	et	3	main
küsitluses	doc_986203247112_item	2970838	et	4	main
reisides	doc_986203247112_item	2970845	et	4	main
samuti	doc_986203247112_item	2970858	et	3	main
vastajate	doc_986203247112_item	2970859	et	4	main
kaks	doc_986203247112_item	2970860	et	3	main
jaoks	doc_986203247112_item	2970863	et	4	main
1september	doc_986203247112_item	2970864	et	3	main
seostub	doc_986203247112_item	2970865	et	3	main
uue	doc_986203247112_item	2970866	et	3	main
hooaja	doc_986203247112_item	2970867	et	3	main
võib	doc_986203247112_item	2970876	et	3	main
et	doc_986203247112_item	2970878	et	3	main
ma	doc_986203247112_item	2970898	et	3	main
aastaaeg	doc_986203247112_item	2970906	et	3	main
tavaliselt	doc_986203247112_item	2970913	et	4	main
muusikasaali	doc_986203247112_item	2970914	et	4	main
ja	doc_986203247112_item	2970915	et	3	main
viib	doc_986203247112_item	2970916	et	3	main
maailmasõja	doc_986203247112_item	2970871	et	3	main
algusega	doc_986203247112_item	2970872	et	3	main
lähtudes	doc_986203247112_item	2970873	et	3	main
oletada	doc_986203247112_item	2970877	et	3	main
peamiseltpensionäärid	doc_986203247112_item	2970883	et	4	main
kes	doc_986203247112_item	2970884	et	4	main
koristavad	doc_986203247112_item	2970889	et	4	main
juhul	doc_986203247112_item	2970891	et	3	main
ise	doc_986203247112_item	2970894	et	4	main
on	doc_986203247112_item	2970903	et	4	main
septembriks	doc_986203247112_item	2970910	et	3	main
teadmiste	doc_986203247112_item	2970924	et	4	main
päev	doc_986203247112_item	2970925	et	3	main
analüüs	doc_986203247113_item	2970926	et	3	main
skeemi	doc_986203247113_item	2970927	et	4	main
analüüs	doc_986203247113_item	2970928	et	3	main
ajaleht	doc_986203247113_item	2970929	et	3	main
käigus	doc_986203247113_item	2970935	et	4	main
selgitas	doc_986203247113_item	2970936	et	3	main
1september	doc_986203247113_item	2970942	et	3	main
olid	doc_986203247113_item	2970943	et	4	main
erinevate	doc_986203247113_item	2970945	et	4	main
elanikute	doc_986203247113_item	2970946	et	4	main
vanasid	doc_986203247113_item	2970955	et	3	main
küsitletuid	doc_986203247113_item	2970960	et	4	main
nad	doc_986203247113_item	2970963	et	3	main
seda	doc_986203247113_item	2970965	et	3	main
kooliaasta	doc_986203247113_item	2970967	et	4	main
sest	doc_986203247113_item	2970970	et	4	main
õppivad	doc_986203247113_item	2970973	et	4	main
lapsi	doc_986203247113_item	2970977	et	4	main
ja	doc_986203247113_item	2970978	et	3	main
lapselapsi	doc_986203247113_item	2970979	et	4	main
lähevad	doc_986203247113_item	2971021	et	3	main
ja	doc_986203247113_item	2971023	et	3	main
kõige	doc_986203247113_item	2971025	et	4	main
seostub	doc_986203247113_item	2971033	et	3	main
võrdselt	doc_986203247113_item	2971041	et	4	main
mina	doc_986203247113_item	2971044	et	4	main
vastaksin	doc_986203247113_item	2971046	et	3	main
nagu	doc_986203247113_item	2971047	et	3	main
enamik	doc_986203247113_item	2971048	et	3	main
1september	doc_986203247113_item	2971049	et	3	main
ja	doc_986203247113_item	2971058	et	3	main
ma	doc_986203247113_item	2971068	et	3	main
veel	doc_986203247113_item	2971069	et	4	main
võin	doc_986203247113_item	2971070	et	3	main
elus	doc_986203247115_item	2971249	et	4	main
ma	doc_986203247115_item	2971253	et	3	main
need	doc_986203247115_item	2971259	et	3	main
mulle	doc_986203247115_item	2971262	et	4	main
väga	doc_986203247115_item	2971263	et	3	main
ja	doc_986203247115_item	2971286	et	3	main
meie	doc_986203247115_item	2971292	et	4	main
suhelda	doc_986203247115_item	2971304	et	4	main
kokku	doc_986203247113_item	2970948	et	3	main
ka	doc_986203247113_item	2970954	et	3	main
et	doc_986203247113_item	2970962	et	3	main
kuupäeva	doc_986203247113_item	2970966	et	4	main
või	doc_986203247113_item	2970975	et	4	main
kohal	doc_986203247113_item	2970981	et	4	main
on	doc_986203247113_item	2970982	et	4	main
niisugune	doc_986203247113_item	2970983	et	3	main
vastus	doc_986203247113_item	2970984	et	3	main
kui	doc_986203247113_item	2970985	et	3	main
suve	doc_986203247113_item	2970986	et	4	main
lõpp	doc_986203247113_item	2970987	et	3	main
see	doc_986203247113_item	2970988	et	3	main
on	doc_986203247113_item	2970989	et	4	main
ka	doc_986203247113_item	2970990	et	3	main
arusaadav	doc_986203247113_item	2970991	et	4	main
sest	doc_986203247113_item	2970992	et	4	main
eestimaal	doc_986203247113_item	2970993	et	4	main
suvi	doc_986203247113_item	2970994	et	3	main
on	doc_986203247113_item	2970995	et	4	main
küllaltki	doc_986203247113_item	2970996	et	4	main
lühike	doc_986203247113_item	2970997	et	4	main
kõik	doc_986203247113_item	2970998	et	4	main
ootavad	doc_986203247113_item	2970999	et	4	main
suvet	doc_986203247113_item	2971000	et	4	main
ja	doc_986203247113_item	2971001	et	3	main
on	doc_986203247113_item	2971002	et	4	main
ikka	doc_986203247113_item	2971003	et	4	main
kahju	doc_986203247113_item	2971004	et	4	main
kui	doc_986203247113_item	2971005	et	3	main
see	doc_986203247113_item	2971006	et	3	main
ära	doc_986203247113_item	2971008	et	4	main
lõpevad	doc_986203247113_item	2971009	et	4	main
puhkused	doc_986203247113_item	2971010	et	3	main
meri	doc_986203247113_item	2971011	et	3	main
ja	doc_986203247113_item	2971012	et	3	main
lõpeb	doc_986203247113_item	2971007	et	4	main
soe	doc_986203247113_item	2971013	et	4	main
päike	doc_986203247113_item	2971014	et	3	main
jäävad	doc_986203247113_item	2971015	et	4	main
ainult	doc_986203247113_item	2971016	et	4	main
meeles	doc_986203247113_item	2971017	et	3	main
muutus	doc_986203247113_item	2971018	et	4	main
loodus	doc_986203247113_item	2971019	et	4	main
päevad	doc_986203247113_item	2971020	et	3	main
vastajate	doc_986203247113_item	2971027	et	4	main
kaudu	doc_986203247113_item	2971043	et	3	main
neile	doc_986203247113_item	2971031	et	4	main
1september	doc_986203247113_item	2971032	et	3	main
rahupäevaga	doc_986203247113_item	2971035	et	3	main
kaks	doc_986203247113_item	2971037	et	3	main
on	doc_986203247113_item	2971039	et	4	main
korjanud	doc_986203247113_item	2971040	et	4	main
algus	doc_986203247113_item	2971053	et	4	main
kuna	doc_986203247113_item	2971054	et	3	main
kõik	doc_986203247113_item	2971059	et	4	main
kuupäeval	doc_986203247113_item	2971064	et	3	main
õppimisele	doc_986203247113_item	2971066	et	4	main
mida	doc_986203247113_item	2971067	et	4	main
ise	doc_986203247113_item	2971045	et	4	main
on	doc_986203247113_item	2971050	et	4	main
kõigepealt	doc_986203247113_item	2971051	et	3	main
kooliaasta	doc_986203247113_item	2971052	et	4	main
ka	doc_986203247113_item	2971061	et	3	main
sellel	doc_986203247113_item	2971063	et	4	main
minna	doc_986203247113_item	2971065	et	3	main
kiri	doc_986203247115_item	2971245	et	3	main
kursustel	doc_986203247115_item	2971255	et	3	main
õpin	doc_986203247115_item	2971257	et	3	main
on	doc_986203247115_item	2971261	et	4	main
vajalikud	doc_986203247115_item	2971264	et	3	main
väga	doc_986203247115_item	2971294	et	3	main
targemaks	doc_986203247115_item	2971309	et	4	main
arvan	doc_986203247115_item	2971311	et	3	main
kaevandakse	doc_986203247115_item	2971328	et	4	main
selest	doc_986203247115_item	2971332	et	4	main
saadetakse	doc_986203247115_item	2971334	et	3	main
tuba	doc_986203247115_item	2971383	et	4	main
tuletõrjetuba	doc_986203247115_item	2971386	et	4	main
ma	doc_988291579395_item	2971421	et	3	main
õpin	doc_988291579395_item	2971425	et	3	main
skandinavistikat	doc_988291579395_item	2971428	et	3	main
ülikoolis	doc_988291579395_item	2971430	et	4	main
tegemine	doc_988291579395_item	2971436	et	4	main
sõitmine	doc_988291579395_item	2971439	et	4	main
kodutelefoninumber	doc_988291579395_item	2971459	et	3	main
kolmkümmend	doc_988291579395_item	2971463	et	4	main
null	doc_988291579395_item	2971465	et	3	main
üheksa	doc_988291579395_item	2971466	et	4	main
mul	doc_988291579395_item	2971467	et	3	main
ta	doc_988291579395_item	2971475	et	4	main
nimi	doc_988291579395_item	2971476	et	3	main
ei	doc_988291579395_item	2971522	et	4	main
nad	doc_988291579395_item	2971528	et	3	main
fabian	doc_988291579395_item	2971547	et	4	main
on	doc_988291579395_item	2971548	et	4	main
kümme	doc_988291579395_item	2971549	et	3	main
aastat	doc_988291579395_item	2971550	et	3	main
ta	doc_988291579395_item	2971552	et	4	main
kasselis	doc_988291579395_item	2971555	et	4	main
ja	doc_988291579395_item	2971556	et	3	main
on	doc_988291579396_item	2971563	et	4	main
õ	doc_988291579396_item	2971593	et	4	main
mis	doc_988291579396_item	2971598	et	4	main
mere	doc_988291579396_item	2971600	et	3	main
vasakul	doc_988291579396_item	2971602	et	4	main
lookleb	doc_988291579396_item	2971603	et	3	main
mere	doc_988291579396_item	2971605	et	3	main
juurde	doc_988291579396_item	2971606	et	4	main
taga	doc_988291579396_item	2971618	et	4	main
laiub	doc_988291579396_item	2971619	et	3	main
suur	doc_988291579396_item	2971620	et	3	main
tere	doc_986203247115_item	2971246	et	3	main
tatjana	doc_986203247115_item	2971247	et	4	main
olen	doc_986203247115_item	2971248	et	3	main
terve	doc_986203247115_item	2971251	et	4	main
praegu	doc_986203247115_item	2971252	et	3	main
juhiabi-asjaajajaks	doc_986203247115_item	2971258	et	4	main
kursused	doc_986203247115_item	2971260	et	3	main
ja	doc_986203247115_item	2971265	et	3	main
kasulikud	doc_986203247115_item	2971266	et	3	main
kursused	doc_986203247115_item	2971267	et	3	main
kestavad	doc_986203247115_item	2971268	et	4	main
veel	doc_986203247115_item	2971269	et	4	main
paar	doc_986203247115_item	2971270	et	3	main
päeva	doc_986203247115_item	2971271	et	4	main
ja	doc_986203247115_item	2971272	et	3	main
ma	doc_986203247115_item	2971273	et	3	main
pean	doc_986203247115_item	2971274	et	4	main
minema	doc_986203247115_item	2971275	et	3	main
praktikale	doc_986203247115_item	2971276	et	3	main
üheks	doc_986203247115_item	2971277	et	3	main
kuuks	doc_986203247115_item	2971278	et	3	main
kursustel	doc_986203247115_item	2971279	et	3	main
ma	doc_986203247115_item	2971280	et	3	main
õpisin	doc_986203247115_item	2971281	et	4	main
ja	doc_986203247115_item	2971256	et	3	main
asjaajamist	doc_986203247115_item	2971285	et	4	main
eesti	doc_986203247115_item	2971288	et	4	main
elus	doc_986203247115_item	2971293	et	4	main
käia	doc_986203247115_item	2971297	et	4	main
mulle	doc_986203247115_item	2971298	et	4	main
meeldib	doc_986203247115_item	2971300	et	3	main
kursustel	doc_986203247115_item	2971313	et	3	main
hästi	doc_986203247115_item	2971316	et	3	main
ma	doc_986203247115_item	2971318	et	3	main
psühholoogiat	doc_986203247115_item	2971282	et	3	main
ettevõtlust	doc_986203247115_item	2971283	et	3	main
arvutit	doc_986203247115_item	2971284	et	3	main
palju	doc_986203247115_item	2971287	et	4	main
keelt	doc_986203247115_item	2971289	et	4	main
mis	doc_986203247115_item	2971290	et	4	main
tähtis	doc_986203247115_item	2971295	et	4	main
väga	doc_986203247115_item	2971299	et	3	main
palju	doc_986203247115_item	2971308	et	4	main
läks	doc_986203247115_item	2971315	et	3	main
praktikale	doc_986203247115_item	2971317	et	3	main
lähen	doc_986203247115_item	2971319	et	3	main
põlevkivisse	doc_986203247115_item	2971322	et	3	main
siin	doc_986203247115_item	2971327	et	4	main
narva	doc_986203247115_item	2971335	et	4	main
mina	doc_986203247115_item	2971337	et	4	main
hakkan	doc_986203247115_item	2971338	et	3	main
tegelema	doc_986203247115_item	2971340	et	3	main
käisime	doc_986203247115_item	2971343	et	3	main
kevanduse	doc_986203247115_item	2971346	et	4	main
iisaku	doc_986203247115_item	2971350	et	4	main
kaevanduse	doc_986203247115_item	2971352	et	4	main
muuseum	doc_986203247115_item	2971353	et	3	main
asub	doc_986203247115_item	2971354	et	3	main
kohtla-nõmmel	doc_986203247115_item	2971355	et	4	main
vanas	doc_986203247115_item	2971356	et	3	main
ise	doc_986203247115_item	2971360	et	4	main
nägime	doc_986203247115_item	2971361	et	3	main
kuidas	doc_986203247115_item	2971362	et	3	main
huvitav	doc_986203247115_item	2971370	et	4	main
välja	doc_986203247115_item	2971375	et	4	main
seitse	doc_986203247115_item	2971377	et	3	main
teemat	doc_986203247115_item	2971378	et	3	main
koolituba	doc_986203247115_item	2971385	et	4	main
ja	doc_988291579395_item	2971424	et	3	main
ja	doc_988291579395_item	2971427	et	3	main
muusikaga	doc_988291579395_item	2971435	et	3	main
minu	doc_988291579395_item	2971446	et	3	main
aadress	doc_988291579395_item	2971447	et	3	main
tänavas	doc_988291579395_item	2971450	et	4	main
kolmkümmend	doc_988291579395_item	2971452	et	4	main
neli	doc_988291579395_item	2971453	et	3	main
üks	doc_988291579395_item	2971454	et	3	main
kolmkümmend	doc_988291579395_item	2971455	et	4	main
neli	doc_988291579395_item	2971456	et	3	main
on	doc_988291579395_item	2971468	et	4	main
viis	doc_988291579395_item	2971469	et	4	main
koduloomad	doc_988291579395_item	2971470	et	3	main
ja	doc_988291579395_item	2971482	et	3	main
kirju	doc_988291579395_item	2971484	et	4	main
enam	doc_988291579395_item	2971524	et	4	main
venaema	doc_988291579395_item	2971525	et	4	main
aga	doc_988291579395_item	2971526	et	3	main
mthias	doc_988291579395_item	2971536	et	4	main
on	doc_988291579395_item	2971537	et	4	main
vana	doc_988291579395_item	2971541	et	4	main
elab	doc_988291579395_item	2971543	et	3	main
töötab	doc_988291579395_item	2971545	et	3	main
kasselis	doc_988291579395_item	2971546	et	4	main
elab	doc_988291579395_item	2971554	et	3	main
ta	doc_988291579395_item	2971557	et	4	main
käib	doc_988291579395_item	2971558	et	3	main
pildi	doc_988291579396_item	2971564	et	4	main
käed	doc_988291579396_item	2971584	et	3	main
lihtsalt	doc_988291579396_item	2971585	et	4	main
pandud	doc_988291579396_item	2971588	et	4	main
lgade	doc_988291579396_item	2971591	et	4	main
k	doc_988291579396_item	2971592	et	4	main
tee	doc_988291579396_item	2971604	et	4	main
j	doc_988291579396_item	2971609	et	4	main
gi	doc_988291579396_item	2971611	et	4	main
mere	doc_988291579396_item	2971614	et	3	main
on	doc_988291579396_item	2971623	et	4	main
mägedega	doc_988291579396_item	2971625	et	3	main
pildi	doc_988291579396_item	2971627	et	4	main
kleid	doc_988291579396_item	2971647	et	4	main
mustad	doc_988291579396_item	2971652	et	4	main
kleit	doc_988291579396_item	2971653	et	3	main
helendab	doc_988291579396_item	2971658	et	3	main
kuldselt	doc_988291579396_item	2971659	et	4	main
ja	doc_988291579396_item	2971661	et	3	main
õ	doc_988291579396_item	2971671	et	4	main
palju	doc_986203247115_item	2971303	et	4	main
ma	doc_986203247115_item	2971310	et	3	main
et	doc_986203247115_item	2971312	et	3	main
vist	doc_986203247115_item	2971320	et	4	main
põlevkivi	doc_986203247115_item	2971329	et	4	main
elektrijaama	doc_986203247115_item	2971336	et	4	main
asjaajamistega	doc_986203247115_item	2971341	et	4	main
ekskursioonil	doc_986203247115_item	2971345	et	3	main
iisaku	doc_986203247115_item	2971348	et	4	main
maa	doc_986203247115_item	2971365	et	4	main
all	doc_986203247115_item	2971366	et	3	main
väga	doc_986203247115_item	2971369	et	3	main
iisaku	doc_986203247115_item	2971371	et	4	main
muuseumis	doc_986203247115_item	2971372	et	3	main
seal	doc_986203247115_item	2971373	et	4	main
pandud	doc_986203247115_item	2971376	et	4	main
looduse	doc_986203247115_item	2971379	et	4	main
tuba	doc_986203247115_item	2971380	et	4	main
ja	doc_986203247115_item	2971305	et	3	main
ma	doc_986203247115_item	2971306	et	3	main
sain	doc_986203247115_item	2971307	et	3	main
mul	doc_986203247115_item	2971314	et	3	main
eesti	doc_986203247115_item	2971321	et	4	main
see	doc_986203247115_item	2971323	et	3	main
on	doc_986203247115_item	2971324	et	4	main
suur	doc_986203247115_item	2971325	et	3	main
ja	doc_986203247115_item	2971330	et	3	main
seal	doc_986203247115_item	2971339	et	4	main
muuseumis	doc_986203247115_item	2971349	et	3	main
kirikus	doc_986203247115_item	2971351	et	3	main
seal	doc_986203247115_item	2971358	et	4	main
ka	doc_986203247115_item	2971367	et	3	main
oli	doc_986203247115_item	2971368	et	3	main
rehielamu	doc_986203247115_item	2971381	et	4	main
meistrite	doc_986203247115_item	2971382	et	3	main
kasselis	doc_988291579395_item	2971423	et	4	main
üldekeeleteadust	doc_988291579395_item	2971426	et	4	main
göttingeni	doc_988291579395_item	2971429	et	4	main
hobid	doc_988291579395_item	2971432	et	3	main
laulamine	doc_988291579395_item	2971437	et	4	main
skateboardi	doc_988291579395_item	2971438	et	4	main
ja	doc_988291579395_item	2971440	et	3	main
joonestamine	doc_988291579395_item	2971441	et	4	main
ma	doc_988291579395_item	2971442	et	3	main
armastan	doc_988291579395_item	2971443	et	3	main
puhata	doc_988291579395_item	2971444	et	4	main
seilenborn	doc_988291579395_item	2971449	et	4	main
kuus	doc_988291579395_item	2971451	et	4	main
on	doc_988291579395_item	2971460	et	4	main
seitse	doc_988291579395_item	2971462	et	3	main
neli	doc_988291579395_item	2971464	et	3	main
üks	doc_988291579395_item	2971471	et	3	main
musta	doc_988291579395_item	2971472	et	4	main
suur	doc_988291579395_item	2971473	et	3	main
dinka	doc_988291579395_item	2971478	et	4	main
musta	doc_988291579395_item	2971481	et	4	main
valge	doc_988291579395_item	2971483	et	4	main
firma	doc_986203247115_item	2971326	et	4	main
80	doc_986203247115_item	2971331	et	2	main
kogust	doc_986203247115_item	2971333	et	4	main
me	doc_986203247115_item	2971342	et	4	main
ka	doc_986203247115_item	2971344	et	3	main
muuseumis	doc_986203247115_item	2971347	et	3	main
kaevanduses	doc_986203247115_item	2971357	et	4	main
me	doc_986203247115_item	2971359	et	4	main
töötavad	doc_986203247115_item	2971363	et	4	main
kaevurid	doc_986203247115_item	2971364	et	3	main
oli	doc_986203247115_item	2971374	et	3	main
vana	doc_986203247115_item	2971384	et	4	main
ja	doc_986203247115_item	2971387	et	3	main
korter	doc_986203247115_item	2971389	et	3	main
essee	doc_988291579395_item	2971390	et	4	main
minu	doc_988291579395_item	2971391	et	3	main
eesnimi	doc_988291579395_item	2971392	et	3	main
õpetaja	doc_986203247115_item	2971388	et	4	main
on	doc_988291579395_item	2971393	et	4	main
eesnimi	doc_988291579395_item	2971394	et	3	main
minu	doc_988291579395_item	2971395	et	3	main
perekonnanimi	doc_988291579395_item	2971396	et	3	main
on	doc_988291579395_item	2971397	et	4	main
perekonnanimi	doc_988291579395_item	2971398	et	3	main
minu	doc_988291579395_item	2971399	et	3	main
juuksed	doc_988291579395_item	2971400	et	3	main
pruunid	doc_988291579395_item	2971402	et	3	main
on	doc_988291579395_item	2971401	et	4	main
ja	doc_988291579395_item	2971403	et	3	main
blondid	doc_988291579395_item	2971404	et	3	main
ja	doc_988291579395_item	2971405	et	3	main
minu	doc_988291579395_item	2971406	et	3	main
silmad	doc_988291579395_item	2971407	et	4	main
on	doc_988291579395_item	2971408	et	4	main
rohelised	doc_988291579395_item	2971409	et	4	main
ma	doc_988291579395_item	2971410	et	3	main
olen	doc_988291579395_item	2971411	et	3	main
kakskümmend	doc_988291579395_item	2971412	et	4	main
üks	doc_988291579395_item	2971413	et	3	main
aastat	doc_988291579395_item	2971414	et	3	main
vana	doc_988291579395_item	2971415	et	4	main
ja	doc_988291579395_item	2971416	et	3	main
olen	doc_988291579395_item	2971417	et	3	main
sündinud	doc_988291579395_item	2971418	et	4	main
saksamaal	doc_988291579395_item	2971419	et	4	main
kasselis	doc_988291579395_item	2971420	et	4	main
minu	doc_988291579395_item	2971431	et	3	main
on	doc_988291579395_item	2971433	et	4	main
taanis	doc_988291579395_item	2971445	et	4	main
elan	doc_988291579395_item	2971422	et	3	main
kudumine	doc_988291579395_item	2971434	et	4	main
on	doc_988291579395_item	2971448	et	4	main
minu	doc_988291579395_item	2971458	et	3	main
on	doc_988291579395_item	2971477	et	4	main
pruuni-	doc_988291579395_item	2971480	et	4	main
merisigasid	doc_988291579395_item	2971485	et	3	main
teie	doc_988291579395_item	2971486	et	4	main
nimed	doc_988291579395_item	2971487	et	3	main
olevad	doc_988291579395_item	2971488	et	4	main
sammy	doc_988291579395_item	2971489	et	4	main
il	doc_988291579395_item	2971490	et	4	main
sole	doc_988291579395_item	2971491	et	3	main
ja	doc_988291579395_item	2971492	et	3	main
farfalla	doc_988291579395_item	2971493	et	4	main
belina	doc_988291579395_item	2971494	et	4	main
kaks	doc_988291579395_item	2971495	et	3	main
küülikuid	doc_988291579395_item	2971496	et	3	main
rubino	doc_988291579395_item	2971497	et	4	main
rosso	doc_988291579395_item	2971498	et	4	main
on	doc_988291579395_item	2971499	et	4	main
valge-	doc_988291579395_item	2971500	et	4	main
triibuline	doc_988291579395_item	2971502	et	4	main
hall	doc_988291579395_item	2971501	et	4	main
ja	doc_988291579395_item	2971503	et	3	main
leonardo	doc_988291579395_item	2971504	et	4	main
vinci	doc_988291579395_item	2971506	et	4	main
da	doc_988291579395_item	2971505	et	4	main
on	doc_988291579395_item	2971507	et	4	main
musta	doc_988291579395_item	2971508	et	4	main
minu	doc_988291579395_item	2971509	et	3	main
ema	doc_988291579395_item	2971510	et	4	main
on	doc_988291579395_item	2971511	et	4	main
erzieherin	doc_988291579395_item	2971512	et	4	main
aga	doc_988291579395_item	2971513	et	3	main
tema	doc_988291579395_item	2971514	et	4	main
ei	doc_988291579395_item	2971515	et	4	main
minu	doc_988291579395_item	2971517	et	3	main
tööta	doc_988291579395_item	2971516	et	4	main
isa	doc_988291579395_item	2971518	et	4	main
on	doc_988291579395_item	2971519	et	4	main
keemik	doc_988291579395_item	2971520	et	3	main
vanaisa	doc_988291579395_item	2971527	et	4	main
venda	doc_988291579395_item	2971535	et	4	main
aastat	doc_988291579395_item	2971540	et	3	main
ta	doc_988291579395_item	2971542	et	4	main
vana	doc_988291579395_item	2971551	et	4	main
kassel	doc_988291579395_item	2971457	et	3	main
nelikümmend	doc_988291579395_item	2971461	et	4	main
koera	doc_988291579395_item	2971474	et	4	main
kaks	doc_988291579395_item	2971479	et	3	main
mul	doc_988291579395_item	2971521	et	3	main
ole	doc_988291579395_item	2971523	et	4	main
sürnud	doc_988291579395_item	2971530	et	4	main
mul	doc_988291579395_item	2971532	et	3	main
kaks	doc_988291579395_item	2971534	et	3	main
koolis	doc_988291579395_item	2971559	et	4	main
õ	doc_988291579396_item	2971590	et	4	main
maastik	doc_988291579396_item	2971597	et	3	main
voolab	doc_988291579396_item	2971608	et	3	main
all	doc_988291579396_item	2971613	et	3	main
merelaht	doc_988291579396_item	2971621	et	3	main
järskkude	doc_988291579396_item	2971624	et	4	main
värved	doc_988291579396_item	2971628	et	4	main
meri	doc_988291579396_item	2971631	et	3	main
mäed	doc_988291579396_item	2971633	et	3	main
tume-pruun	doc_988291579396_item	2971642	et	3	main
ja	doc_988291579396_item	2971645	et	3	main
on	doc_988291579396_item	2971648	et	4	main
väga	doc_988291579396_item	2971649	et	3	main
tume	doc_988291579396_item	2971650	et	3	main
peaaegu	doc_988291579396_item	2971651	et	3	main
ning	doc_988291579396_item	2971657	et	3	main
õ	doc_988291579396_item	2971663	et	4	main
peal	doc_988291579396_item	2971665	et	4	main
kus	doc_988291579396_item	2971666	et	3	main
valgus	doc_988291579396_item	2971667	et	4	main
k	doc_988291579396_item	2971670	et	4	main
pildi	doc_988291579396_item	2971675	et	4	main
keskmes	doc_988291579396_item	2971676	et	3	main
selle	doc_988291579396_item	2971682	et	4	main
nägu	doc_988291579396_item	2971685	et	4	main
selle	doc_988291579396_item	2971687	et	4	main
käed	doc_988291579396_item	2971690	et	3	main
ümbritsetud	doc_988291579396_item	2971700	et	4	main
mis	doc_988291579396_item	2971703	et	4	main
langevad	doc_988291579396_item	2971704	et	4	main
alla	doc_988291579396_item	2971705	et	3	main
õ	doc_988291579396_item	2971710	et	4	main
ning	doc_988291579396_item	2971714	et	3	main
naeratab	doc_988291579396_item	2971715	et	3	main
tagap	doc_988291579396_item	2971724	et	4	main
üle	doc_988291579396_item	2971730	et	3	main
harvasti	doc_988291579396_item	2971745	et	3	main
maali	doc_988291579396_item	2971767	et	4	main
maalis	doc_988291579396_item	2971768	et	4	main
v	doc_988291579397_item	2971772	et	4	main
õ	doc_988291579397_item	2971773	et	4	main
meie	doc_988291579397_item	2971779	et	4	main
on	doc_988291579397_item	2971781	et	4	main
meelest	doc_988291579397_item	2971787	et	4	main
õ	doc_988291579397_item	2971792	et	4	main
istusin	doc_988291579397_item	2971821	et	3	main
siin	doc_988291579397_item	2971826	et	4	main
büroos	doc_988291579397_item	2971830	et	3	main
tunnen	doc_988291579397_item	2971837	et	3	main
õnnetu	doc_988291579397_item	2971840	et	4	main
maa	doc_988291579397_item	2971843	et	4	main
vaba	doc_988291579397_item	2971844	et	4	main
toit	doc_988291579397_item	2971851	et	3	main
köögivili	doc_988291579397_item	2971855	et	3	main
endast	doc_988291579397_item	2971857	et	4	main
aiast	doc_988291579397_item	2971858	et	4	main
ja	doc_988291579397_item	2971859	et	3	main
on	doc_988291579397_item	2971891	et	4	main
otsustanud	doc_988291579397_item	2971900	et	4	main
mul	doc_988291579397_item	2971904	et	3	main
oma	doc_988291579397_item	2971915	et	4	main
on	doc_988291579395_item	2971529	et	4	main
aga	doc_988291579395_item	2971531	et	3	main
on	doc_988291579395_item	2971533	et	4	main
kakskümmend	doc_988291579395_item	2971538	et	4	main
neli	doc_988291579395_item	2971539	et	3	main
ja	doc_988291579395_item	2971544	et	3	main
essee	doc_988291579396_item	2971560	et	4	main
katab	doc_988291579396_item	2971565	et	3	main
peaaegu	doc_988291579396_item	2971566	et	3	main
täielikult	doc_988291579396_item	2971567	et	4	main
ühe	doc_988291579396_item	2971568	et	4	main
naise	doc_988291579396_item	2971569	et	3	main
kuju	doc_988291579396_item	2971570	et	4	main
ilmselt	doc_988291579396_item	2971571	et	4	main
istub	doc_988291579396_item	2971572	et	3	main
ta	doc_988291579396_item	2971573	et	4	main
tugitooli	doc_988291579396_item	2971574	et	4	main
peal	doc_988291579396_item	2971575	et	4	main
mis	doc_988291579396_item	2971576	et	4	main
on	doc_988291579396_item	2971577	et	4	main
kuni	doc_988291579396_item	2971578	et	3	main
käetoeni	doc_988291579396_item	2971579	et	3	main
näha	doc_988291579396_item	2971580	et	3	main
käetoe	doc_988291579396_item	2971581	et	3	main
peal	doc_988291579396_item	2971582	et	4	main
on	doc_988291579396_item	2971583	et	4	main
üle	doc_988291579396_item	2971587	et	3	main
ka	doc_988291579395_item	2971553	et	3	main
kes	doc_988291579396_item	2971561	et	4	main
see	doc_988291579396_item	2971562	et	3	main
naise	doc_988291579396_item	2971589	et	3	main
paremal	doc_988291579396_item	2971607	et	4	main
on	doc_988291579396_item	2971629	et	4	main
õ	doc_988291579396_item	2971635	et	4	main
hjas	doc_988291579396_item	2971636	et	4	main
maastik	doc_988291579396_item	2971640	et	3	main
väärtuslikust	doc_988291579396_item	2971655	et	4	main
langeb	doc_988291579396_item	2971669	et	3	main
heledam	doc_988291579396_item	2971673	et	4	main
pimedusest	doc_988291579396_item	2971677	et	4	main
välja	doc_988291579396_item	2971678	et	4	main
naise	doc_988291579396_item	2971679	et	3	main
all	doc_988291579396_item	2971688	et	3	main
tema	doc_988291579396_item	2971689	et	4	main
ige	doc_988291579396_item	2971693	et	3	main
nägu	doc_988291579396_item	2971699	et	4	main
rahutu	doc_988291579396_item	2971722	et	4	main
kontrasti	doc_988291579396_item	2971728	et	4	main
mille	doc_988291579396_item	2971729	et	3	main
ripub	doc_988291579396_item	2971737	et	3	main
louvres	doc_988291579396_item	2971739	et	4	main
saad	doc_988291579396_item	2971742	et	4	main
katavad	doc_988291579396_item	2971755	et	3	main
on	doc_988291579396_item	2971763	et	4	main
essee	doc_988291579397_item	2971769	et	4	main
i	doc_988291579397_item	2971774	et	4	main
on	doc_988291579397_item	2971785	et	4	main
linnas	doc_988291579397_item	2971790	et	4	main
maal	doc_988291579397_item	2971795	et	4	main
paljute	doc_988291579397_item	2971823	et	4	main
minu	doc_988291579397_item	2971829	et	3	main
teenin	doc_988291579397_item	2971831	et	3	main
maal	doc_988291579397_item	2971835	et	4	main
liha	doc_988291579397_item	2971860	et	4	main
surnud	doc_988291579397_item	2971882	et	4	main
ja	doc_988291579397_item	2971883	et	3	main
kõva	doc_988291579397_item	2971892	et	4	main
ja	doc_988291579397_item	2971893	et	3	main
kurb	doc_988291579397_item	2971894	et	3	main
lünk	doc_988291579397_item	2971895	et	3	main
üks	doc_988291579397_item	2971901	et	3	main
ühe	doc_988291579397_item	2971909	et	4	main
talu	doc_988291579397_item	2971918	et	4	main
oma	doc_988291579397_item	2971921	et	4	main
veel	doc_988291579397_item	2971923	et	4	main
elasid	doc_988291579397_item	2971924	et	4	main
tead	doc_988291579397_item	2971944	et	4	main
kui	doc_988291579397_item	2971945	et	3	main
mina	doc_988291579397_item	2971968	et	4	main
veel	doc_988291579397_item	2971977	et	4	main
inimene	doc_988291579397_item	2971985	et	3	main
mina	doc_988291579397_item	2971989	et	4	main
sündinud	doc_988291579397_item	2971991	et	4	main
noorusaeg	doc_988291579397_item	2971996	et	3	main
veetsin	doc_988291579397_item	2971997	et	3	main
ma	doc_988291579397_item	2972000	et	3	main
maal	doc_988291579397_item	2972014	et	4	main
kinno	doc_988291579397_item	2972025	et	3	main
kõrtse	doc_988291579397_item	2972037	et	3	main
puhkusele	doc_988291579397_item	2972049	et	4	main
sõita	doc_988291579397_item	2972051	et	3	main
juba	doc_988291579397_item	2972055	et	3	main
ütlesid	doc_988291579397_item	2972061	et	4	main
ma	doc_988291579397_item	2972063	et	3	main
toda	doc_988291579397_item	2972065	et	3	main
sinu	doc_988291579397_item	2972067	et	3	main
vanavanematel	doc_988291579397_item	2972068	et	4	main
ettepanek	doc_988291579397_item	2972073	et	3	main
juba	doc_988291579397_item	2972074	et	3	main
sind	doc_988291579397_item	2972078	et	4	main
abielluma	doc_988291579397_item	2972080	et	3	main
ikka	doc_988291579397_item	2972082	et	4	main
mina	doc_988291579397_item	2972120	et	4	main
maal	doc_988291579397_item	2972127	et	4	main
mida	doc_988291579397_item	2972141	et	4	main
ma	doc_988291579397_item	2972142	et	3	main
peangi	doc_988291579397_item	2972148	et	4	main
kiri	doc_988291579398_item	2972150	et	3	main
kirjeldus	doc_988291579398_item	2972156	et	4	main
on	doc_988291579398_item	2972164	et	4	main
risti	doc_988291579396_item	2971586	et	4	main
rval	doc_988291579396_item	2971594	et	4	main
vadatakse	doc_988291579396_item	2971595	et	3	main
romantiline	doc_988291579396_item	2971596	et	3	main
piirneb	doc_988291579396_item	2971599	et	3	main
juurde	doc_988291579396_item	2971601	et	4	main
õ	doc_988291579396_item	2971610	et	4	main
silla	doc_988291579396_item	2971612	et	3	main
sisse	doc_988291579396_item	2971615	et	4	main
naise	doc_988291579396_item	2971616	et	3	main
pea	doc_988291579396_item	2971617	et	4	main
mis	doc_988291579396_item	2971622	et	4	main
tumedad	doc_988291579396_item	2971630	et	3	main
tagap	doc_988291579396_item	2971634	et	4	main
on	doc_988291579396_item	2971637	et	4	main
pigem	doc_988291579396_item	2971638	et	3	main
tumesinised	doc_988291579396_item	2971639	et	4	main
rohkem	doc_988291579396_item	2971641	et	4	main
on	doc_988291579396_item	2971654	et	4	main
varrukate	doc_988291579396_item	2971660	et	3	main
peale	doc_988291579396_item	2971668	et	4	main
dekoltee	doc_988291579396_item	2971680	et	4	main
üle	doc_988291579396_item	2971683	et	3	main
k	doc_988291579396_item	2971691	et	4	main
huvitavam	doc_988291579396_item	2971694	et	4	main
juustega	doc_988291579396_item	2971702	et	3	main
istatusliku	doc_988291579396_item	2971711	et	4	main
otsa	doc_988291579396_item	2971713	et	4	main
kuju	doc_988291579396_item	2971720	et	4	main
hjas	doc_988291579396_item	2971726	et	4	main
teevad	doc_988291579396_item	2971727	et	3	main
maal	doc_988291579396_item	2971736	et	4	main
sest	doc_988291579396_item	2971747	et	4	main
seisavad	doc_988291579396_item	2971749	et	3	main
ja	doc_988291579396_item	2971754	et	3	main
kes	doc_988291579396_item	2971760	et	4	main
ja	doc_988291579396_item	2971764	et	3	main
elu	doc_988291579397_item	2971770	et	4	main
maal	doc_988291579397_item	2971775	et	4	main
linnaelanik	doc_988291579397_item	2971776	et	3	main
meie	doc_988291579397_item	2971786	et	4	main
v	doc_988291579397_item	2971791	et	4	main
mis	doc_988291579397_item	2971796	et	4	main
ma	doc_988291579397_item	2971822	et	3	main
aastate	doc_988291579397_item	2971824	et	3	main
linnas	doc_988291579397_item	2971828	et	4	main
aga	doc_988291579397_item	2971836	et	3	main
taevas	doc_988291579397_item	2971845	et	4	main
loomade	doc_988291579397_item	2971846	et	4	main
näiteks	doc_988291579397_item	2971854	et	4	main
niikaua	doc_988291579397_item	2971864	et	3	main
suur	doc_988291579397_item	2971885	et	3	main
müüdud	doc_988291579397_item	2971888	et	4	main
minu	doc_988291579397_item	2971889	et	3	main
elus	doc_988291579397_item	2971890	et	4	main
päev	doc_988291579397_item	2971902	et	3	main
osta	doc_988291579397_item	2971908	et	4	main
talu	doc_988291579397_item	2971911	et	4	main
saaremaal	doc_988291579397_item	2971912	et	4	main
kus	doc_988291579397_item	2971913	et	3	main
ka	doc_988291579397_item	2971914	et	3	main
kui	doc_988291579397_item	2971920	et	3	main
vanavanemad	doc_988291579397_item	2971922	et	4	main
ise	doc_988291579397_item	2971926	et	4	main
peeter	doc_988291579397_item	2971927	et	3	main
oled	doc_988291579397_item	2971928	et	3	main
ju	doc_988291579397_item	2971929	et	3	main
sinna	doc_988291579397_item	2971934	et	3	main
sõitnud	doc_988291579397_item	2971935	et	4	main
ja	doc_988291579397_item	2971936	et	3	main
me	doc_988291579397_item	2971937	et	4	main
mõlemad	doc_988291579397_item	2971938	et	3	main
olime	doc_988291579397_item	2971939	et	3	main
paljutel	doc_988291579397_item	2971963	et	4	main
puhkusel	doc_988291579397_item	2971966	et	4	main
maaelu	doc_988291579397_item	2971970	et	4	main
tahaks	doc_988291579397_item	2971986	et	3	main
suures	doc_988291579397_item	2971992	et	3	main
või	doc_988291579397_item	2972002	et	4	main
maal	doc_988291579397_item	2972007	et	4	main
elada	doc_988291579397_item	2972008	et	3	main
ma	doc_988291579397_item	2972009	et	3	main
ümbritsetud	doc_988291579396_item	2971626	et	4	main
ja	doc_988291579396_item	2971632	et	3	main
naise	doc_988291579396_item	2971643	et	3	main
juuksed	doc_988291579396_item	2971644	et	3	main
tema	doc_988291579396_item	2971646	et	4	main
riiest	doc_988291579396_item	2971656	et	3	main
parema	doc_988291579396_item	2971662	et	4	main
la	doc_988291579396_item	2971664	et	4	main
ige	doc_988291579396_item	2971672	et	3	main
ja	doc_988291579396_item	2971681	et	3	main
naise	doc_988291579396_item	2971684	et	3	main
on	doc_988291579396_item	2971697	et	4	main
naise	doc_988291579396_item	2971698	et	3	main
ta	doc_988291579396_item	2971706	et	4	main
vaatab	doc_988291579396_item	2971707	et	3	main
vaatajale	doc_988291579396_item	2971708	et	4	main
pilguga	doc_988291579396_item	2971712	et	3	main
salapärase	doc_988291579396_item	2971716	et	4	main
naertusega	doc_988291579396_item	2971717	et	4	main
naise	doc_988291579396_item	2971718	et	3	main
rahulik	doc_988291579396_item	2971719	et	3	main
ja	doc_988291579396_item	2971721	et	3	main
maastik	doc_988291579396_item	2971723	et	3	main
õ	doc_988291579396_item	2971725	et	4	main
elda	doc_988291579396_item	2971733	et	4	main
maksab	doc_988291579396_item	2971734	et	3	main
see	doc_988291579396_item	2971735	et	3	main
ja	doc_988291579396_item	2971740	et	3	main
sa	doc_988291579396_item	2971741	et	3	main
ainult	doc_988291579396_item	2971744	et	4	main
japanlast	doc_988291579396_item	2971753	et	4	main
nende	doc_988291579396_item	2971756	et	4	main
fotoapparatidega	doc_988291579396_item	2971757	et	4	main
see	doc_988291579396_item	2971761	et	3	main
teda	doc_988291579396_item	2971766	et	4	main
peeter	doc_988291579397_item	2971777	et	3	main
ülesanne	doc_988291579397_item	2971780	et	4	main
kirjutada	doc_988291579397_item	2971782	et	3	main
mis	doc_988291579397_item	2971783	et	4	main
parem	doc_988291579397_item	2971788	et	4	main
i	doc_988291579397_item	2971793	et	4	main
elu	doc_988291579397_item	2971794	et	4	main
paistavad	doc_988291579396_item	2971674	et	3	main
ning	doc_988291579396_item	2971686	et	3	main
õ	doc_988291579396_item	2971692	et	4	main
maali	doc_988291579396_item	2971695	et	4	main
osa	doc_988291579396_item	2971696	et	4	main
mustade	doc_988291579396_item	2971701	et	3	main
m	doc_988291579396_item	2971709	et	4	main
m	doc_988291579396_item	2971731	et	4	main
õ	doc_988291579396_item	2971732	et	4	main
parisis	doc_988291579396_item	2971738	et	4	main
seda	doc_988291579396_item	2971743	et	3	main
näha	doc_988291579396_item	2971746	et	3	main
enamasti	doc_988291579396_item	2971748	et	4	main
selle	doc_988291579396_item	2971750	et	4	main
ees	doc_988291579396_item	2971751	et	4	main
sadakond	doc_988291579396_item	2971752	et	3	main
kogu	doc_988291579396_item	2971758	et	4	main
vaadet	doc_988291579396_item	2971759	et	3	main
naine	doc_988291579396_item	2971762	et	3	main
kes	doc_988291579396_item	2971765	et	4	main
linnas	doc_988291579397_item	2971771	et	4	main
liina	doc_988291579397_item	2971778	et	3	main
elu	doc_988291579397_item	2971784	et	4	main
elu	doc_988291579397_item	2971789	et	4	main
sa	doc_988291579397_item	2971797	et	3	main
arvad	doc_988291579397_item	2971798	et	3	main
maaelanik	doc_988291579397_item	2971799	et	3	main
liina	doc_988291579397_item	2971800	et	3	main
minu	doc_988291579397_item	2971801	et	3	main
meelest	doc_988291579397_item	2971802	et	4	main
see	doc_988291579397_item	2971803	et	3	main
s	doc_988291579397_item	2971804	et	4	main
õltub	doc_988291579397_item	2971805	et	4	main
kus	doc_988291579397_item	2971806	et	3	main
sa	doc_988291579397_item	2971807	et	3	main
lapsepõlves	doc_988291579397_item	2971808	et	4	main
elasid	doc_988291579397_item	2971809	et	4	main
mina	doc_988291579397_item	2971810	et	4	main
näiteks	doc_988291579397_item	2971811	et	4	main
elasin	doc_988291579397_item	2971812	et	3	main
terve	doc_988291579397_item	2971813	et	4	main
lapsepõlv	doc_988291579397_item	2971814	et	3	main
minu	doc_988291579397_item	2971815	et	3	main
vanavanemate	doc_988291579397_item	2971816	et	4	main
juures	doc_988291579397_item	2971817	et	4	main
nende	doc_988291579397_item	2971818	et	4	main
talus	doc_988291579397_item	2971819	et	4	main
nüüd	doc_988291579397_item	2971820	et	4	main
saadik	doc_988291579397_item	2971825	et	4	main
suures	doc_988291579397_item	2971827	et	3	main
raha	doc_988291579397_item	2971833	et	4	main
kui	doc_988291579397_item	2971834	et	3	main
puudub	doc_988291579397_item	2971842	et	3	main
lautadest	doc_988291579397_item	2971848	et	3	main
ja	doc_988291579397_item	2971849	et	3	main
laua	doc_988291579397_item	2971852	et	3	main
oma	doc_988291579397_item	2971861	et	4	main
nende	doc_988291579397_item	2971884	et	4	main
on	doc_988291579397_item	2971887	et	4	main
selle	doc_988291579397_item	2971896	et	4	main
pärast	doc_988291579397_item	2971897	et	4	main
kui	doc_988291579397_item	2971903	et	3	main
on	doc_988291579397_item	2971905	et	4	main
raha	doc_988291579397_item	2971907	et	4	main
vanavanemate	doc_988291579397_item	2971916	et	4	main
rohkem	doc_988291579397_item	2971832	et	4	main
end	doc_988291579397_item	2971838	et	4	main
üsna	doc_988291579397_item	2971839	et	3	main
mulle	doc_988291579397_item	2971841	et	4	main
hääled	doc_988291579397_item	2971847	et	3	main
värske	doc_988291579397_item	2971850	et	4	main
peal	doc_988291579397_item	2971853	et	4	main
oma	doc_988291579397_item	2971856	et	4	main
endast	doc_988291579397_item	2971862	et	4	main
laudast	doc_988291579397_item	2971863	et	4	main
kui	doc_988291579397_item	2971865	et	3	main
mu	doc_988291579397_item	2971866	et	3	main
vanavanemad	doc_988291579397_item	2971867	et	4	main
veel	doc_988291579397_item	2971868	et	4	main
elasid	doc_988291579397_item	2971869	et	4	main
sain	doc_988291579397_item	2971870	et	3	main
ma	doc_988291579397_item	2971871	et	3	main
alati	doc_988291579397_item	2971872	et	4	main
vähemalt	doc_988291579397_item	2971873	et	4	main
puhkusel	doc_988291579397_item	2971874	et	4	main
nende	doc_988291579397_item	2971875	et	4	main
talule	doc_988291579397_item	2971876	et	3	main
sõita	doc_988291579397_item	2971877	et	3	main
aga	doc_988291579397_item	2971878	et	3	main
sestsaadik	doc_988291579397_item	2971879	et	3	main
nad	doc_988291579397_item	2971880	et	3	main
on	doc_988291579397_item	2971881	et	4	main
talu	doc_988291579397_item	2971886	et	4	main
ma	doc_988291579397_item	2971898	et	3	main
olen	doc_988291579397_item	2971899	et	3	main
piisav	doc_988291579397_item	2971906	et	4	main
väikese	doc_988291579397_item	2971910	et	4	main
asus	doc_988291579397_item	2971919	et	4	main
ka	doc_988291579397_item	2971931	et	3	main
too	doc_988291579397_item	2971947	et	4	main
linnaelanik	doc_988291579397_item	2971950	et	3	main
sul	doc_988291579397_item	2971952	et	3	main
päevad	doc_988291579397_item	2971956	et	3	main
põhjustel	doc_988291579397_item	2971964	et	3	main
sina	doc_988291579397_item	2971976	et	4	main
otsustavad	doc_988291579397_item	2971982	et	4	main
sellejaoks	doc_988291579397_item	2971983	et	3	main
kus	doc_988291579397_item	2971984	et	3	main
näe	doc_988291579397_item	2971988	et	4	main
terve	doc_988291579397_item	2971995	et	4	main
suurtes	doc_988291579397_item	2971998	et	3	main
elu	doc_988291579397_item	2972013	et	4	main
suur	doc_988291579397_item	2971917	et	3	main
sina	doc_988291579397_item	2971925	et	4	main
vanavanematel	doc_988291579397_item	2971940	et	4	main
külas	doc_988291579397_item	2971941	et	3	main
siis	doc_988291579397_item	2971942	et	3	main
sa	doc_988291579397_item	2971943	et	3	main
maa	doc_988291579397_item	2971948	et	4	main
peeter	doc_988291579397_item	2971951	et	3	main
on	doc_988291579397_item	2971953	et	4	main
need	doc_988291579397_item	2971955	et	3	main
armastan	doc_988291579397_item	2971969	et	3	main
ka	doc_988291579397_item	2971972	et	3	main
ütlesid	doc_988291579397_item	2971978	et	4	main
lapsepõlve	doc_988291579397_item	2971979	et	4	main
muljed	doc_988291579397_item	2971980	et	3	main
on	doc_988291579397_item	2971981	et	4	main
ja	doc_988291579397_item	2971994	et	3	main
linnades	doc_988291579397_item	2971999	et	3	main
ei	doc_988291579397_item	2972001	et	4	main
ette	doc_988291579397_item	2972003	et	4	main
kujutada	doc_988291579397_item	2972004	et	3	main
kaua	doc_988291579397_item	2972005	et	3	main
aeg	doc_988291579397_item	2972006	et	3	main
kiiret	doc_988291579397_item	2972012	et	4	main
teatrisse	doc_988291579397_item	2972023	et	3	main
või	doc_988291579397_item	2972024	et	4	main
minna	doc_988291579397_item	2972026	et	3	main
palju	doc_988291579397_item	2972036	et	4	main
palju	doc_988291579397_item	2972040	et	4	main
muide	doc_988291579397_item	2972042	et	3	main
sinna	doc_988291579397_item	2972050	et	3	main
nagu	doc_988291579397_item	2972054	et	3	main
sa	doc_988291579397_item	2972058	et	3	main
õigesti	doc_988291579397_item	2972060	et	3	main
et	doc_988291579397_item	2972062	et	3	main
hea	doc_988291579397_item	2972072	et	4	main
minuga	doc_988291579397_item	2972079	et	3	main
talu	doc_988291579397_item	2972112	et	4	main
elu	doc_988291579397_item	2972115	et	4	main
õppin	doc_988291579397_item	2972121	et	4	main
pärast	doc_988291579397_item	2972123	et	4	main
varem	doc_988291579397_item	2972124	et	4	main
või	doc_988291579397_item	2972125	et	4	main
hiljem	doc_988291579397_item	2972126	et	3	main
eraldi	doc_988291579397_item	2972147	et	4	main
ametlik	doc_988291579398_item	2972149	et	3	main
ei	doc_988291579398_item	2972158	et	4	main
ametlik	doc_988291579399_item	2972171	et	3	main
kuid	doc_988291579399_item	2972178	et	4	main
aega	doc_988291579399_item	2972193	et	4	main
ilma	doc_995572625433_item	2972199	et	4	main
milleta	doc_995572625433_item	2972200	et	3	main
elada	doc_995572625433_item	2972204	et	3	main
saa	doc_995572625433_item	2972208	et	4	main
ei	doc_995572625433_item	2972218	et	4	main
loomulikult	doc_995572625433_item	2972223	et	4	main
on	doc_995572625433_item	2972225	et	4	main
tervis	doc_995572625433_item	2972226	et	3	main
head	doc_995572625433_item	2972242	et	4	main
ma	doc_995572625433_item	2972250	et	3	main
arvan	doc_995572625433_item	2972251	et	3	main
et	doc_995572625433_item	2972252	et	3	main
kõigepealt	doc_995572625433_item	2972253	et	3	main
ei	doc_995572625433_item	2972256	et	4	main
võimalused	doc_995572625433_item	2972267	et	3	main
inimesel	doc_995572625433_item	2972330	et	3	main
kus	doc_995572625433_item	2972336	et	3	main
armastab	doc_995572625433_item	2972338	et	3	main
kedagi	doc_995572625433_item	2972339	et	4	main
ja	doc_995572625433_item	2972340	et	3	main
muretseb	doc_995572625433_item	2972341	et	3	main
ja	doc_995572625433_item	2972342	et	3	main
hoolitseb	doc_995572625433_item	2972343	et	3	main
temast	doc_995572625433_item	2972344	et	3	main
edasi	doc_995572625433_item	2972345	et	3	main
huvitavat	doc_995572625433_item	2972351	et	4	main
olla	doc_995572625433_item	2972352	et	3	main
jaoks	doc_995572625433_item	2972354	et	4	main
on	doc_995572625433_item	2972365	et	4	main
käesoleval	doc_995572625433_item	2972373	et	3	main
on	doc_995572625433_item	2972375	et	4	main
mitmesuguseid	doc_995572625433_item	2972404	et	3	main
ükskord	doc_988291579397_item	2971930	et	3	main
koos	doc_988291579397_item	2971932	et	4	main
minuga	doc_988291579397_item	2971933	et	3	main
ilus	doc_988291579397_item	2971946	et	4	main
on	doc_988291579397_item	2971949	et	4	main
õigus	doc_988291579397_item	2971954	et	4	main
sinu	doc_988291579397_item	2971957	et	3	main
kodumaal	doc_988291579397_item	2971958	et	4	main
olid	doc_988291579397_item	2971959	et	4	main
väga	doc_988291579397_item	2971960	et	3	main
ilusad	doc_988291579397_item	2971961	et	3	main
ja	doc_988291579397_item	2971962	et	3	main
unustamatud	doc_988291579397_item	2971965	et	4	main
isegi	doc_988291579397_item	2971967	et	4	main
aga	doc_988291579397_item	2971971	et	3	main
ainult	doc_988291579397_item	2971973	et	4	main
puhkusel	doc_988291579397_item	2971974	et	4	main
kui	doc_988291579397_item	2971975	et	3	main
elada	doc_988291579397_item	2971987	et	3	main
olen	doc_988291579397_item	2971990	et	3	main
linnas	doc_988291579397_item	2971993	et	4	main
vajatan	doc_988291579397_item	2972010	et	4	main
linna	doc_988291579397_item	2972011	et	4	main
on	doc_988291579397_item	2972015	et	4	main
jaoks	doc_988291579397_item	2972017	et	4	main
minu	doc_988291579397_item	2972016	et	3	main
liiga	doc_988291579397_item	2972018	et	4	main
vähe	doc_988291579397_item	2972019	et	3	main
vaheldust	doc_988291579397_item	2972020	et	4	main
mul	doc_988291579397_item	2972028	et	3	main
soov	doc_988291579397_item	2972030	et	3	main
mul	doc_988291579397_item	2972031	et	3	main
vaja	doc_988291579397_item	2972033	et	4	main
eriti	doc_988291579397_item	2972039	et	3	main
loomulikult	doc_988291579397_item	2972044	et	4	main
ka	doc_988291579397_item	2972052	et	3	main
meeldib	doc_988291579397_item	2972057	et	3	main
nautisin	doc_988291579397_item	2972064	et	3	main
puhkust	doc_988291579397_item	2972066	et	4	main
on	doc_988291579397_item	2972071	et	4	main
aastaid	doc_988291579397_item	2972075	et	4	main
sinu	doc_988291579397_item	2972114	et	3	main
armastan	doc_988291579397_item	2972022	et	3	main
kui	doc_988291579397_item	2972027	et	3	main
on	doc_988291579397_item	2972029	et	4	main
on	doc_988291579397_item	2972032	et	4	main
ja	doc_988291579397_item	2972038	et	3	main
raamatupoode	doc_988291579397_item	2972041	et	3	main
ma	doc_988291579397_item	2972043	et	3	main
ei	doc_988291579397_item	2972045	et	4	main
vihkan	doc_988291579397_item	2972046	et	3	main
elu	doc_988291579397_item	2972047	et	4	main
öeldud	doc_988291579397_item	2972056	et	4	main
oled	doc_988291579397_item	2972059	et	3	main
kuule	doc_988291579397_item	2972069	et	4	main
ma	doc_988291579397_item	2972076	et	3	main
palun	doc_988291579397_item	2972077	et	3	main
ning	doc_988291579397_item	2972081	et	3	main
veel	doc_988291579397_item	2972083	et	4	main
sa	doc_988291579397_item	2972084	et	3	main
pole	doc_988291579397_item	2972085	et	3	main
kindel	doc_988291579397_item	2972086	et	3	main
kas	doc_988291579397_item	2972087	et	3	main
sa	doc_988291579397_item	2972088	et	3	main
tahad	doc_988291579397_item	2972089	et	3	main
mind	doc_988291579397_item	2972090	et	4	main
või	doc_988291579397_item	2972091	et	4	main
mitte	doc_988291579397_item	2972092	et	3	main
nüüd	doc_988291579397_item	2972093	et	4	main
sul	doc_988291579397_item	2972094	et	3	main
on	doc_988291579397_item	2972095	et	4	main
hea	doc_988291579397_item	2972096	et	4	main
põhjus	doc_988291579397_item	2972097	et	4	main
otsustada	doc_988291579397_item	2972098	et	3	main
kui	doc_988291579397_item	2972099	et	3	main
me	doc_988291579397_item	2972100	et	4	main
abiellume	doc_988291579397_item	2972101	et	3	main
siis	doc_988291579397_item	2972102	et	3	main
me	doc_988291579397_item	2972103	et	4	main
paneme	doc_988291579397_item	2972104	et	3	main
oma	doc_988291579397_item	2972105	et	4	main
raha	doc_988291579397_item	2972106	et	4	main
kokku	doc_988291579397_item	2972107	et	3	main
ja	doc_988291579397_item	2972108	et	3	main
ostame	doc_988291579397_item	2972109	et	3	main
tolle	doc_988291579397_item	2972110	et	4	main
väikese	doc_988291579397_item	2972111	et	4	main
ma	doc_988291579397_item	2972021	et	3	main
palju	doc_988291579397_item	2972034	et	4	main
kauplusi	doc_988291579397_item	2972035	et	3	main
maal	doc_988291579397_item	2972048	et	4	main
mulle	doc_988291579397_item	2972053	et	4	main
mul	doc_988291579397_item	2972070	et	3	main
täidetud	doc_988291579397_item	2972118	et	4	main
ja	doc_988291579397_item	2972119	et	3	main
oled	doc_988291579397_item	2972130	et	3	main
liina	doc_988291579397_item	2972133	et	3	main
ma	doc_988291579397_item	2972134	et	3	main
pigemini	doc_988291579397_item	2972143	et	3	main
sest	doc_988291579398_item	2972157	et	4	main
saanud	doc_988291579398_item	2972159	et	4	main
kirjutamata	doc_988291579399_item	2972181	et	4	main
teil	doc_988291579399_item	2972183	et	4	main
mõnda	doc_988291579399_item	2972186	et	4	main
teemat	doc_988291579399_item	2972187	et	3	main
juhendamisel	doc_988291579399_item	2972189	et	4	main
leiate	doc_988291579399_item	2972192	et	3	main
milleta	doc_995572625433_item	2972206	et	3	main
ilma	doc_995572625433_item	2972216	et	4	main
milleta	doc_995572625433_item	2972217	et	3	main
ajal	doc_995572625433_item	2972221	et	4	main
rahad	doc_995572625433_item	2972231	et	4	main
kui	doc_995572625433_item	2972232	et	3	main
see	doc_995572625433_item	2972233	et	3	main
on	doc_995572625433_item	2972234	et	4	main
riigis	doc_995572625433_item	2972235	et	3	main
siis	doc_995572625433_item	2972236	et	3	main
ennast	doc_995572625433_item	2972249	et	4	main
milleta	doc_995572625433_item	2972254	et	3	main
siis	doc_995572625433_item	2972265	et	3	main
normaalselt	doc_995572625433_item	2972270	et	4	main
ainult	doc_995572625433_item	2972284	et	4	main
püüdma	doc_995572625433_item	2972285	et	3	main
tervislik	doc_995572625433_item	2972286	et	3	main
eluviis	doc_995572625433_item	2972287	et	3	main
kodu	doc_995572625433_item	2972328	et	4	main
igal	doc_995572625433_item	2972329	et	3	main
kodu	doc_995572625433_item	2972335	et	4	main
selle	doc_995572625433_item	2972353	et	4	main
spaneestis	doc_995572625433_item	2972372	et	4	main
tõenäoliselt	doc_995572625433_item	2972412	et	4	main
elada	doc_995572625433_item	2972413	et	3	main
ei	doc_995572625433_item	2972417	et	4	main
minu	doc_995572625433_item	2972420	et	3	main
mind	doc_995572625433_item	2972423	et	4	main
töötada	doc_995572625433_item	2972425	et	3	main
tulu	doc_995572625433_item	2972427	et	4	main
rahata	doc_995572625434_item	2972447	et	4	main
on	doc_995572625434_item	2972452	et	4	main
kui	doc_995572625434_item	2972469	et	3	main
rohkem	doc_995572625434_item	2972470	et	4	main
keelte	doc_995572625434_item	2972471	et	3	main
sa	doc_995572625434_item	2972472	et	3	main
oskad	doc_995572625434_item	2972473	et	3	main
siis	doc_995572625434_item	2972474	et	3	main
omad	doc_995572625434_item	2972478	et	4	main
maja	doc_995572625434_item	2972486	et	4	main
osta	doc_995572625434_item	2972487	et	4	main
kui	doc_995572625434_item	2972490	et	3	main
sa	doc_995572625434_item	2972494	et	3	main
elab	doc_995572625434_item	2972524	et	3	main
hammastele	doc_995572625434_item	2972530	et	3	main
hooldada	doc_995572625434_item	2972540	et	3	main
näha	doc_995572625434_item	2972550	et	3	main
on	doc_995572625434_item	2972553	et	4	main
head	doc_995572625434_item	2972559	et	4	main
kahjuks	doc_995572625434_item	2972565	et	4	main
on	doc_995572625434_item	2972566	et	4	main
selle	doc_995572625434_item	2972569	et	4	main
et	doc_995572625434_item	2972571	et	3	main
saada	doc_995572625434_item	2972596	et	4	main
hiljem	doc_995572625434_item	2972597	et	3	main
head	doc_995572625434_item	2972598	et	4	main
ja	doc_995572625434_item	2972610	et	3	main
vaja	doc_995572625434_item	2972615	et	4	main
suurendada	doc_995572625434_item	2972618	et	3	main
siis	doc_988291579397_item	2972113	et	3	main
lünka	doc_988291579397_item	2972116	et	4	main
on	doc_988291579397_item	2972117	et	4	main
sinu	doc_988291579397_item	2972122	et	3	main
maaelanik	doc_988291579397_item	2972132	et	3	main
eristan	doc_988291579397_item	2972144	et	3	main
tänasesse	doc_988291579398_item	2972160	et	4	main
kiri	doc_988291579399_item	2972172	et	3	main
lõpetama	doc_988291579399_item	2972175	et	4	main
lõputöö	doc_988291579399_item	2972179	et	4	main
jäi	doc_988291579399_item	2972180	et	3	main
teie	doc_988291579399_item	2972188	et	4	main
saa	doc_995572625433_item	2972202	et	4	main
tänapäeval	doc_995572625433_item	2972203	et	3	main
ei	doc_995572625433_item	2972207	et	4	main
tänapäeval	doc_995572625433_item	2972209	et	3	main
elada	doc_995572625433_item	2972210	et	3	main
millised	doc_995572625433_item	2972211	et	3	main
asjad	doc_995572625433_item	2972212	et	3	main
meile	doc_995572625433_item	2972213	et	4	main
saa	doc_995572625433_item	2972219	et	4	main
käesoleval	doc_995572625433_item	2972220	et	3	main
elada	doc_995572625433_item	2972222	et	3	main
need	doc_995572625433_item	2972224	et	3	main
pere	doc_995572625433_item	2972227	et	4	main
need	doc_995572625433_item	2972237	et	3	main
areng	doc_995572625433_item	2972241	et	3	main
teise	doc_995572625433_item	2972244	et	4	main
ma	doc_995572625433_item	2972255	et	3	main
saa	doc_995572625433_item	2972257	et	4	main
kui	doc_995572625433_item	2972262	et	3	main
tervis	doc_995572625433_item	2972264	et	3	main
on	doc_995572625433_item	2972266	et	4	main
ja	doc_995572625433_item	2972268	et	3	main
tervis	doc_995572625433_item	2972278	et	3	main
minu	doc_995572625433_item	2972280	et	3	main
on	doc_995572625433_item	2972282	et	4	main
vaja	doc_995572625433_item	2972283	et	4	main
period	doc_995572625433_item	2972321	et	4	main
kolmandaks	doc_995572625433_item	2972323	et	4	main
ma	doc_995572625433_item	2972324	et	3	main
kodu	doc_995572625433_item	2972333	et	4	main
panneksin	doc_995572625433_item	2972347	et	4	main
tööd	doc_995572625433_item	2972348	et	4	main
peab	doc_995572625433_item	2972350	et	4	main
vaja	doc_995572625433_item	2972366	et	4	main
omadaspan	doc_995572625433_item	2972371	et	4	main
ajal	doc_995572625433_item	2972374	et	4	main
tähtis	doc_995572625433_item	2972376	et	4	main
eesti	doc_995572625433_item	2972377	et	4	main
saata	doc_995572625433_item	2972406	et	3	main
mõelnud	doc_995572625433_item	2972418	et	4	main
nii	doc_995572625433_item	2972424	et	3	main
ei	doc_995572625434_item	2972435	et	4	main
tänapäeval	doc_995572625434_item	2972437	et	3	main
elada	doc_995572625434_item	2972438	et	3	main
saa	doc_995572625434_item	2972449	et	4	main
omada	doc_995572625434_item	2972454	et	3	main
sa	doc_995572625434_item	2972477	et	3	main
head	doc_995572625434_item	2972479	et	4	main
head	doc_995572625434_item	2972488	et	4	main
on	doc_995572625434_item	2972492	et	4	main
näiteks	doc_995572625434_item	2972498	et	4	main
kui	doc_995572625434_item	2972499	et	3	main
inimene	doc_995572625434_item	2972523	et	3	main
vaata	doc_995572625434_item	2972528	et	4	main
neid	doc_995572625434_item	2972541	et	4	main
on	doc_995572625434_item	2972542	et	4	main
ilusalt	doc_995572625434_item	2972551	et	4	main
head	doc_995572625434_item	2972561	et	4	main
hoolduskosmeetikad	doc_995572625434_item	2972562	et	3	main
raha	doc_995572625434_item	2972568	et	4	main
võivad	doc_995572625434_item	2972595	et	4	main
välismaale	doc_995572625434_item	2972603	et	4	main
see	doc_995572625434_item	2972604	et	3	main
tähendab	doc_995572625434_item	2972605	et	3	main
et	doc_995572625434_item	2972606	et	3	main
saanud	doc_995572625434_item	2972637	et	4	main
kui	doc_995572625434_item	2972638	et	3	main
sinu	doc_995572625434_item	2972639	et	3	main
sind	doc_995572625434_item	2972643	et	4	main
edusamm	doc_995572625434_item	2972645	et	3	main
elada	doc_988291579397_item	2972128	et	3	main
kas	doc_988291579397_item	2972129	et	3	main
nõus	doc_988291579397_item	2972131	et	4	main
veel	doc_988291579397_item	2972135	et	4	main
ei	doc_988291579397_item	2972136	et	4	main
tea	doc_988291579397_item	2972137	et	4	main
sa	doc_988291579397_item	2972138	et	3	main
segab	doc_988291579397_item	2972139	et	3	main
asju	doc_988291579397_item	2972140	et	3	main
ja	doc_988291579397_item	2972145	et	3	main
täpselt	doc_988291579397_item	2972146	et	4	main
terepalun	doc_988291579398_item	2972151	et	4	main
saatke	doc_988291579398_item	2972152	et	3	main
mulle	doc_988291579398_item	2972153	et	4	main
uue	doc_988291579398_item	2972154	et	3	main
kodutöö	doc_988291579398_item	2972155	et	4	main
loengusse	doc_988291579398_item	2972161	et	4	main
tulla	doc_988291579398_item	2972162	et	3	main
kui	doc_988291579398_item	2972163	et	3	main
tere	doc_988291579399_item	2972173	et	3	main
pidin	doc_988291579399_item	2972174	et	3	main
kevadsemestril	doc_988291579399_item	2972177	et	3	main
juhendamiseks	doc_988291579399_item	2972195	et	4	main
eesnimi	doc_988291579399_item	2972197	et	3	main
perekonnanimi	doc_988291579399_item	2972198	et	3	main
ei	doc_995572625433_item	2972201	et	4	main
ilma	doc_995572625433_item	2972205	et	4	main
vaja	doc_995572625433_item	2972215	et	4	main
head	doc_995572625433_item	2972228	et	4	main
sissekord	doc_995572625433_item	2972239	et	3	main
riigi	doc_995572625433_item	2972240	et	3	main
tänapäeval	doc_995572625433_item	2972259	et	3	main
on	doc_995572625433_item	2972260	et	4	main
tahtmised	doc_995572625433_item	2972269	et	4	main
elada	doc_995572625433_item	2972271	et	3	main
õppida	doc_995572625433_item	2972272	et	3	main
töötada	doc_995572625433_item	2972273	et	3	main
puhata	doc_995572625433_item	2972274	et	4	main
ja	doc_995572625433_item	2972275	et	3	main
on	doc_995572625433_item	2972279	et	4	main
käes	doc_995572625433_item	2972281	et	4	main
võimalik	doc_988291579398_item	2972165	et	3	main
siis	doc_988291579398_item	2972166	et	3	main
ka	doc_988291579398_item	2972167	et	3	main
tänase	doc_988291579398_item	2972168	et	3	main
loengu	doc_988291579398_item	2972169	et	3	main
materjal	doc_988291579398_item	2972170	et	3	main
eelmisel	doc_988291579399_item	2972176	et	3	main
kas	doc_988291579399_item	2972182	et	3	main
oleks	doc_988291579399_item	2972184	et	3	main
pakkuda	doc_988291579399_item	2972185	et	3	main
kas	doc_988291579399_item	2972190	et	3	main
te	doc_988291579399_item	2972191	et	4	main
minu	doc_988291579399_item	2972194	et	3	main
lugupidamisega	doc_988291579399_item	2972196	et	3	main
on	doc_995572625433_item	2972214	et	4	main
sõbrad	doc_995572625433_item	2972229	et	3	main
töö	doc_995572625433_item	2972230	et	4	main
on	doc_995572625433_item	2972238	et	4	main
suhtumised	doc_995572625433_item	2972243	et	4	main
riikidega	doc_995572625433_item	2972245	et	3	main
ma	doc_995572625433_item	2972246	et	3	main
kirjutan	doc_995572625433_item	2972247	et	3	main
ise	doc_995572625433_item	2972248	et	4	main
elada	doc_995572625433_item	2972258	et	3	main
tervis	doc_995572625433_item	2972261	et	3	main
on	doc_995572625433_item	2972263	et	4	main
ne	doc_995572625433_item	2972276	et	4	main
minu	doc_995572625433_item	2972277	et	3	main
viia	doc_995572625433_item	2972288	et	3	main
õiglasel	doc_995572625433_item	2972289	et	3	main
ajal	doc_995572625433_item	2972290	et	4	main
on	doc_995572625433_item	2972291	et	4	main
vaja	doc_995572625433_item	2972292	et	4	main
oma	doc_995572625433_item	2972293	et	4	main
tervise	doc_995572625433_item	2972294	et	3	main
seisundi	doc_995572625433_item	2972295	et	3	main
kontrollida	doc_995572625433_item	2972296	et	4	main
teiseks	doc_995572625433_item	2972297	et	4	main
milleta	doc_995572625433_item	2972298	et	3	main
ma	doc_995572625433_item	2972299	et	3	main
ei	doc_995572625433_item	2972300	et	4	main
saa	doc_995572625433_item	2972301	et	4	main
elada	doc_995572625433_item	2972302	et	3	main
käesoleval	doc_995572625433_item	2972303	et	3	main
ajal	doc_995572625433_item	2972304	et	4	main
see	doc_995572625433_item	2972305	et	3	main
on	doc_995572625433_item	2972306	et	4	main
pere	doc_995572625433_item	2972307	et	4	main
sõbrad	doc_995572625433_item	2972308	et	3	main
ja	doc_995572625433_item	2972309	et	3	main
nende	doc_995572625433_item	2972310	et	4	main
abi	doc_995572625433_item	2972311	et	4	main
kui	doc_995572625433_item	2972312	et	3	main
sulle	doc_995572625433_item	2972313	et	3	main
on	doc_995572625433_item	2972314	et	4	main
raske	doc_995572625433_item	2972315	et	4	main
need	doc_995572625433_item	2972316	et	3	main
inimesed	doc_995572625433_item	2972317	et	3	main
aitavad	doc_995572625433_item	2972318	et	4	main
sind	doc_995572625433_item	2972319	et	4	main
halva	doc_995572625433_item	2972320	et	4	main
peab	doc_995572625433_item	2972331	et	4	main
oma	doc_995572625433_item	2972332	et	4	main
teda	doc_995572625433_item	2972337	et	4	main
töö	doc_995572625433_item	2972349	et	4	main
üleelada	doc_995572625433_item	2972322	et	4	main
mõtlen	doc_995572625433_item	2972325	et	3	main
see	doc_995572625433_item	2972326	et	3	main
on	doc_995572625433_item	2972327	et	4	main
olema	doc_995572625433_item	2972334	et	4	main
ma	doc_995572625433_item	2972346	et	3	main
erialat	doc_995572625433_item	2972360	et	4	main
et	doc_995572625433_item	2972361	et	3	main
töötada	doc_995572625433_item	2972362	et	3	main
effektiivselt	doc_995572625433_item	2972363	et	4	main
siis	doc_995572625433_item	2972364	et	3	main
huvi	doc_995572625433_item	2972370	et	4	main
keelt	doc_995572625433_item	2972378	et	4	main
ning	doc_995572625433_item	2972379	et	3	main
teisi	doc_995572625433_item	2972380	et	4	main
võõrkeelt	doc_995572625433_item	2972381	et	4	main
valdada	doc_995572625433_item	2972382	et	4	main
oskama	doc_995572625433_item	2972383	et	3	main
arvutiprogramme	doc_995572625433_item	2972384	et	3	main
ma	doc_995572625433_item	2972385	et	3	main
püüan	doc_995572625433_item	2972386	et	3	main
eesti	doc_995572625433_item	2972387	et	4	main
keelt	doc_995572625433_item	2972388	et	4	main
valdada	doc_995572625433_item	2972389	et	4	main
samuti	doc_995572625433_item	2972390	et	3	main
parem	doc_995572625433_item	2972391	et	4	main
arvuti	doc_995572625433_item	2972392	et	4	main
teada	doc_995572625433_item	2972393	et	3	main
ja	doc_995572625433_item	2972394	et	3	main
viimasele	doc_995572625433_item	2972395	et	3	main
kohale	doc_995572625433_item	2972396	et	4	main
ma	doc_995572625433_item	2972397	et	3	main
panneksin	doc_995572625433_item	2972398	et	4	main
raha	doc_995572625433_item	2972399	et	4	main
nad	doc_995572625433_item	2972400	et	3	main
ainult	doc_995572625433_item	2972401	et	4	main
aitavad	doc_995572625433_item	2972402	et	4	main
meid	doc_995572625433_item	2972403	et	4	main
on	doc_995572625433_item	2972355	et	4	main
vaja	doc_995572625433_item	2972356	et	4	main
õppida	doc_995572625433_item	2972357	et	3	main
põlvest	doc_995572625433_item	2972358	et	4	main
lemmikut	doc_995572625433_item	2972359	et	3	main
haridust	doc_995572625433_item	2972367	et	4	main
kogemust	doc_995572625433_item	2972368	et	3	main
ja	doc_995572625433_item	2972369	et	3	main
siiani	doc_995572625433_item	2972414	et	4	main
sellele	doc_995572625433_item	2972415	et	4	main
aitas	doc_995572625433_item	2972422	et	3	main
puhata	doc_995572625433_item	2972432	et	4	main
ilma	doc_995572625434_item	2972433	et	4	main
milleta	doc_995572625434_item	2972434	et	3	main
ei	doc_995572625434_item	2972448	et	4	main
vaja	doc_995572625434_item	2972453	et	4	main
tööt	doc_995572625434_item	2972456	et	4	main
palgaga	doc_995572625434_item	2972458	et	3	main
jaoks	doc_995572625434_item	2972460	et	4	main
omada	doc_995572625434_item	2972463	et	3	main
eriala	doc_995572625434_item	2972464	et	4	main
ja	doc_995572625434_item	2972465	et	3	main
oskata	doc_995572625434_item	2972466	et	4	main
mõningaid	doc_995572625434_item	2972467	et	3	main
keeli	doc_995572625434_item	2972468	et	4	main
sa	doc_995572625434_item	2972481	et	3	main
osta	doc_995572625434_item	2972483	et	4	main
endale	doc_995572625434_item	2972484	et	4	main
korterit	doc_995572625434_item	2972485	et	3	main
sööki	doc_995572625434_item	2972489	et	4	main
saad	doc_995572625434_item	2972495	et	4	main
eesmärke	doc_995572625433_item	2972405	et	4	main
aga	doc_995572625433_item	2972407	et	3	main
küsimusele	doc_995572625433_item	2972416	et	4	main
sest	doc_995572625433_item	2972419	et	4	main
rahata	doc_995572625433_item	2972408	et	4	main
tänapäeval	doc_995572625433_item	2972409	et	3	main
ei	doc_995572625433_item	2972410	et	4	main
saa	doc_995572625433_item	2972411	et	4	main
tervis	doc_995572625433_item	2972421	et	3	main
saata	doc_995572625433_item	2972426	et	3	main
kui	doc_995572625433_item	2972428	et	3	main
õppida	doc_995572625433_item	2972429	et	3	main
arenguseks	doc_995572625433_item	2972430	et	3	main
ja	doc_995572625433_item	2972431	et	3	main
saa	doc_995572625434_item	2972436	et	4	main
kahjuks	doc_995572625434_item	2972439	et	4	main
ma	doc_995572625434_item	2972440	et	3	main
tulin	doc_995572625434_item	2972441	et	3	main
selleks	doc_995572625434_item	2972442	et	4	main
et	doc_995572625434_item	2972443	et	3	main
selle	doc_995572625434_item	2972450	et	4	main
on	doc_995572625434_item	2972461	et	4	main
parem	doc_995572625434_item	2972475	et	4	main
kui	doc_995572625434_item	2972476	et	3	main
sul	doc_995572625434_item	2972491	et	3	main
oma	doc_995572625434_item	2972496	et	4	main
teada	doc_995572625434_item	2972521	et	3	main
omab	doc_995572625434_item	2972526	et	3	main
raha	doc_995572625434_item	2972527	et	4	main
tema	doc_995572625434_item	2972529	et	4	main
raha	doc_995572625434_item	2972546	et	4	main
kui	doc_995572625434_item	2972547	et	3	main
naine	doc_995572625434_item	2972548	et	3	main
tahab	doc_995572625434_item	2972549	et	3	main
osta	doc_995572625434_item	2972558	et	4	main
asjadega	doc_995572625434_item	2972588	et	3	main
kõik	doc_995572625434_item	2972607	et	4	main
seda	doc_995572625434_item	2972608	et	3	main
omada	doc_995572625434_item	2972609	et	3	main
hea	doc_995572625434_item	2972612	et	4	main
elu	doc_995572625434_item	2972630	et	4	main
teele	doc_995572625434_item	2972631	et	3	main
kes	doc_995572625434_item	2972632	et	4	main
ootab	doc_995572625434_item	2972644	et	3	main
p	doc_995572625434_item	2972646	et	4	main
milleta	doc_995572625435_item	2972648	et	3	main
ei	doc_995572625435_item	2972649	et	4	main
saa	doc_995572625435_item	2972650	et	4	main
inimene	doc_995572625435_item	2972651	et	3	main
tänapäeval	doc_995572625435_item	2972652	et	3	main
elada	doc_995572625435_item	2972653	et	3	main
ma	doc_995572625435_item	2972654	et	3	main
arvan	doc_995572625435_item	2972655	et	3	main
et	doc_995572625435_item	2972656	et	3	main
see	doc_995572625435_item	2972657	et	3	main
küsimus	doc_995572625435_item	2972661	et	4	main
raske	doc_995572625435_item	2972664	et	4	main
kõik	doc_995572625435_item	2972666	et	4	main
inimesed	doc_995572625435_item	2972667	et	3	main
on	doc_995572625435_item	2972668	et	4	main
esimesel	doc_995572625435_item	2972676	et	3	main
milleks	doc_995572625435_item	2972688	et	4	main
on	doc_995572625435_item	2972699	et	4	main
perele	doc_995572625435_item	2972700	et	3	main
armastus	doc_995572625435_item	2972701	et	4	main
raha	doc_995572625435_item	2972725	et	4	main
annavad	doc_995572625435_item	2972727	et	3	main
võimalused	doc_995572625435_item	2972729	et	3	main
on	doc_995572625435_item	2972730	et	4	main
käia	doc_995572625435_item	2972733	et	4	main
kinno	doc_995572625435_item	2972734	et	3	main
teatrisse	doc_995572625435_item	2972735	et	3	main
ravida	doc_995572625435_item	2972736	et	3	main
eraklinnikus	doc_995572625435_item	2972737	et	4	main
töö	doc_995572625435_item	2972745	et	4	main
armastab	doc_995572625435_item	2972748	et	3	main
see	doc_995572625435_item	2972750	et	3	main
väga	doc_995572625435_item	2972752	et	3	main
ei	doc_995572625436_item	2972799	et	4	main
saa	doc_995572625436_item	2972800	et	4	main
elada	doc_995572625436_item	2972801	et	3	main
ilma	doc_995572625436_item	2972802	et	4	main
teisele	doc_995572625436_item	2972831	et	4	main
tal	doc_995572625436_item	2972832	et	3	main
on	doc_995572625436_item	2972833	et	4	main
nendel	doc_995572625436_item	2972856	et	4	main
praegu	doc_995572625434_item	2972444	et	3	main
momendil	doc_995572625434_item	2972445	et	3	main
ilma	doc_995572625434_item	2972446	et	4	main
jaoks	doc_995572625434_item	2972451	et	4	main
head	doc_995572625434_item	2972455	et	4	main
suurega	doc_995572625434_item	2972457	et	4	main
selle	doc_995572625434_item	2972459	et	4	main
vaja	doc_995572625434_item	2972462	et	4	main
palga	doc_995572625434_item	2972480	et	3	main
saad	doc_995572625434_item	2972482	et	4	main
raha	doc_995572625434_item	2972493	et	4	main
hooldada	doc_995572625434_item	2972497	et	3	main
naine	doc_995572625434_item	2972501	et	3	main
sina	doc_995572625434_item	2972500	et	4	main
sa	doc_995572625434_item	2972502	et	3	main
saad	doc_995572625434_item	2972503	et	4	main
võtta	doc_995572625434_item	2972504	et	3	main
teenindust	doc_995572625434_item	2972505	et	4	main
kosmeetikasalongist	doc_995572625434_item	2972506	et	3	main
tegeleda	doc_995572625434_item	2972507	et	3	main
erinevatega	doc_995572625434_item	2972508	et	4	main
sportidega	doc_995572625434_item	2972509	et	3	main
käia	doc_995572625434_item	2972510	et	4	main
igadel	doc_995572625434_item	2972511	et	3	main
puhkepäevadel	doc_995572625434_item	2972512	et	3	main
basseini	doc_995572625434_item	2972513	et	4	main
spordisaali	doc_995572625434_item	2972514	et	4	main
spa-protseduuri	doc_995572625434_item	2972515	et	4	main
võtma	doc_995572625434_item	2972516	et	3	main
räägitakse	doc_995572625434_item	2972517	et	3	main
et	doc_995572625434_item	2972518	et	3	main
kui	doc_995572625434_item	2972519	et	3	main
tahad	doc_995572625434_item	2972520	et	3	main
kuidas	doc_995572625434_item	2972522	et	3	main
praegu	doc_995572625434_item	2972531	et	3	main
jaoks	doc_995572625434_item	2972534	et	4	main
hambad	doc_995572625434_item	2972538	et	3	main
kreemid	doc_995572625434_item	2972560	et	3	main
vaja	doc_995572625434_item	2972567	et	4	main
jaoks	doc_995572625434_item	2972570	et	4	main
tööt	doc_995572625434_item	2972599	et	4	main
omada	doc_995572625434_item	2972611	et	3	main
on	doc_995572625434_item	2972614	et	4	main
koguaeg	doc_995572625434_item	2972616	et	3	main
ei	doc_995572625434_item	2972622	et	4	main
otsida	doc_995572625434_item	2972624	et	4	main
midagi	doc_995572625434_item	2972625	et	4	main
uut	doc_995572625434_item	2972626	et	3	main
tööt	doc_995572625434_item	2972627	et	4	main
koguaeg	doc_995572625434_item	2972628	et	3	main
liikuda	doc_995572625434_item	2972629	et	3	main
sest	doc_995572625434_item	2972635	et	4	main
on	doc_995572625434_item	2972641	et	4	main
on	doc_995572625435_item	2972658	et	4	main
see	doc_995572625435_item	2972662	et	3	main
kui	doc_995572625435_item	2972681	et	3	main
vaja	doc_995572625435_item	2972689	et	4	main
vaja	doc_995572625435_item	2972692	et	4	main
panen	doc_995572625435_item	2972724	et	3	main
reisida	doc_995572625435_item	2972732	et	3	main
ja	doc_995572625434_item	2972525	et	3	main
momendil	doc_995572625434_item	2972532	et	3	main
selle	doc_995572625434_item	2972533	et	4	main
et	doc_995572625434_item	2972535	et	3	main
teha	doc_995572625434_item	2972536	et	3	main
ilusad	doc_995572625434_item	2972537	et	3	main
ja	doc_995572625434_item	2972539	et	3	main
vaja	doc_995572625434_item	2972543	et	4	main
väga	doc_995572625434_item	2972544	et	3	main
palju	doc_995572625434_item	2972545	et	4	main
temale	doc_995572625434_item	2972552	et	3	main
vaja	doc_995572625434_item	2972554	et	4	main
süstemaatiliselt	doc_995572625434_item	2972555	et	4	main
hooldada	doc_995572625434_item	2972556	et	3	main
ennast	doc_995572625434_item	2972557	et	4	main
selle	doc_995572625434_item	2972563	et	4	main
jaoks	doc_995572625434_item	2972564	et	4	main
sinu	doc_995572625434_item	2972572	et	3	main
lapsed	doc_995572625434_item	2972573	et	3	main
omavad	doc_995572625434_item	2972574	et	4	main
head	doc_995572625434_item	2972575	et	4	main
eriala	doc_995572625434_item	2972576	et	4	main
on	doc_995572625434_item	2972577	et	4	main
vaja	doc_995572625434_item	2972578	et	4	main
anda	doc_995572625434_item	2972579	et	3	main
palju	doc_995572625434_item	2972580	et	4	main
raha	doc_995572625434_item	2972581	et	4	main
nendele	doc_995572625434_item	2972582	et	4	main
et	doc_995572625434_item	2972583	et	3	main
nad	doc_995572625434_item	2972584	et	3	main
võivad	doc_995572625434_item	2972585	et	4	main
tegeleda	doc_995572625434_item	2972586	et	3	main
erinevatega	doc_995572625434_item	2972587	et	4	main
võivad	doc_995572625434_item	2972589	et	4	main
õppida	doc_995572625434_item	2972590	et	3	main
palju	doc_995572625434_item	2972591	et	4	main
keeli	doc_995572625434_item	2972592	et	4	main
siis	doc_995572625434_item	2972593	et	3	main
nad	doc_995572625434_item	2972594	et	3	main
kuhugi	doc_995572625434_item	2972600	et	4	main
sõita	doc_995572625434_item	2972601	et	3	main
töötama	doc_995572625434_item	2972602	et	3	main
elu	doc_995572625434_item	2972613	et	4	main
areneda	doc_995572625434_item	2972617	et	3	main
oma	doc_995572625434_item	2972619	et	4	main
oskust	doc_995572625434_item	2972620	et	3	main
ja	doc_995572625434_item	2972621	et	3	main
karta	doc_995572625434_item	2972623	et	3	main
ei	doc_995572625434_item	2972633	et	4	main
proovi	doc_995572625434_item	2972634	et	4	main
elus	doc_995572625434_item	2972640	et	4	main
ilma	doc_995572625435_item	2972647	et	4	main
raske	doc_995572625435_item	2972660	et	4	main
probleem	doc_995572625435_item	2972665	et	3	main
on	doc_995572625435_item	2972671	et	4	main
kohal	doc_995572625435_item	2972677	et	4	main
inimesel	doc_995572625435_item	2972682	et	3	main
on	doc_995572625435_item	2972683	et	4	main
pere	doc_995572625435_item	2972684	et	4	main
siis	doc_995572625435_item	2972685	et	3	main
mis	doc_995572625435_item	2972697	et	4	main
tal	doc_995572625435_item	2972698	et	3	main
ei	doc_995572625434_item	2972636	et	4	main
eesmärk	doc_995572625434_item	2972642	et	3	main
väga	doc_995572625435_item	2972659	et	3	main
on	doc_995572625435_item	2972663	et	4	main
ja	doc_995572625435_item	2972674	et	3	main
ta	doc_995572625435_item	2972686	et	4	main
teab	doc_995572625435_item	2972687	et	3	main
mis	doc_995572625435_item	2972691	et	4	main
teha	doc_995572625435_item	2972693	et	3	main
ta	doc_995572625435_item	2972694	et	4	main
annab	doc_995572625435_item	2972695	et	3	main
teated	doc_995572625435_item	2972702	et	3	main
ta	doc_995572625435_item	2972703	et	4	main
perele	doc_995572625435_item	2972707	et	3	main
ja	doc_995572625435_item	2972708	et	3	main
tema	doc_995572625435_item	2972709	et	4	main
pere	doc_995572625435_item	2972710	et	4	main
ka	doc_995572625435_item	2972711	et	3	main
aitab	doc_995572625435_item	2972712	et	3	main
talle	doc_995572625435_item	2972713	et	4	main
praegu	doc_995572625435_item	2972714	et	3	main
meil	doc_995572625435_item	2972715	et	4	main
on	doc_995572625435_item	2972716	et	4	main
väga	doc_995572625435_item	2972717	et	3	main
raske	doc_995572625435_item	2972718	et	4	main
elu	doc_995572625435_item	2972719	et	4	main
ja	doc_995572625435_item	2972720	et	3	main
teisel	doc_995572625435_item	2972721	et	4	main
raha	doc_995572625435_item	2972726	et	4	main
suured	doc_995572625435_item	2972728	et	3	main
kohal	doc_995572625435_item	2972741	et	4	main
ma	doc_995572625435_item	2972742	et	3	main
panen	doc_995572625435_item	2972743	et	3	main
lemmik	doc_995572625435_item	2972744	et	3	main
päeval	doc_995572625435_item	2972755	et	3	main
surepärane	doc_995572625435_item	2972763	et	4	main
see	doc_995572625435_item	2972764	et	3	main
aitab	doc_995572625435_item	2972765	et	3	main
elada	doc_995572625435_item	2972766	et	3	main
kui	doc_995572625435_item	2972767	et	3	main
inimene	doc_995572625435_item	2972768	et	3	main
teab	doc_995572625435_item	2972769	et	3	main
ka	doc_995572625435_item	2972773	et	3	main
tulevikus	doc_995572625436_item	2972798	et	4	main
hariduseta	doc_995572625436_item	2972804	et	3	main
tähtus	doc_995572625436_item	2972812	et	4	main
suurem	doc_995572625436_item	2972814	et	4	main
hea	doc_995572625436_item	2972817	et	4	main
annab	doc_995572625436_item	2972819	et	3	main
karda	doc_995572625436_item	2972848	et	4	main
vahetada	doc_995572625436_item	2972849	et	3	main
uus	doc_995572625436_item	2972854	et	3	main
on	doc_995572625436_item	2972864	et	4	main
ja	doc_995572625436_item	2972867	et	3	main
meie	doc_995572625436_item	2972870	et	4	main
paremaks	doc_995572625436_item	2972872	et	4	main
eest	doc_995572625436_item	2972883	et	4	main
kõik	doc_995572625436_item	2972884	et	4	main
noored	doc_995572625436_item	2972885	et	3	main
sõidavad	doc_995572625436_item	2972922	et	3	main
pärast	doc_995572625436_item	2972925	et	4	main
kaotame	doc_995572625436_item	2972932	et	3	main
noorte	doc_995572625436_item	2972933	et	3	main
inimeste	doc_995572625436_item	2972934	et	3	main
tööjõudu	doc_995572625436_item	2972935	et	4	main
ilma	doc_995572625437_item	2972943	et	4	main
milleta	doc_995572625437_item	2972944	et	3	main
ei	doc_995572625437_item	2972945	et	4	main
keeruline	doc_995572625437_item	2972952	et	4	main
erinevad	doc_995572625435_item	2972669	et	4	main
kõigil	doc_995572625435_item	2972670	et	4	main
oma	doc_995572625435_item	2972672	et	4	main
iseloom	doc_995572625435_item	2972673	et	3	main
eluviis	doc_995572625435_item	2972675	et	3	main
ma	doc_995572625435_item	2972678	et	3	main
panen	doc_995572625435_item	2972679	et	3	main
pere	doc_995572625435_item	2972680	et	4	main
elada	doc_995572625435_item	2972690	et	3	main
kõk	doc_995572625435_item	2972696	et	4	main
holitseb	doc_995572625435_item	2972704	et	4	main
ja	doc_995572625435_item	2972705	et	3	main
aitab	doc_995572625435_item	2972706	et	3	main
kohal	doc_995572625435_item	2972722	et	4	main
käi	doc_995572625435_item	2972738	et	4	main
kursustel	doc_995572625435_item	2972739	et	3	main
ja	doc_995572625435_item	2972746	et	3	main
tore	doc_995572625435_item	2972753	et	3	main
ta	doc_995572625435_item	2972756	et	4	main
see	doc_995572625435_item	2972772	et	3	main
hea	doc_995572625436_item	2972803	et	4	main
suurem	doc_995572625436_item	2972816	et	4	main
haridus	doc_995572625436_item	2972818	et	3	main
muutub	doc_995572625436_item	2972822	et	3	main
julgemaks	doc_995572625436_item	2972824	et	4	main
inimine	doc_995572625436_item	2972825	et	4	main
oskab	doc_995572625436_item	2972826	et	3	main
võtta	doc_995572625436_item	2972827	et	3	main
otsust	doc_995572625436_item	2972828	et	4	main
ja	doc_995572625436_item	2972829	et	3	main
pere	doc_995572625436_item	2972835	et	4	main
ja	doc_995572625436_item	2972836	et	3	main
edukad	doc_995572625436_item	2972837	et	3	main
lapsed	doc_995572625436_item	2972838	et	3	main
ei	doc_995572625436_item	2972847	et	4	main
hakkata	doc_995572625436_item	2972853	et	4	main
suur	doc_995572625436_item	2972858	et	3	main
töö	doc_995572625436_item	2972859	et	4	main
väga	doc_995572625436_item	2972865	et	3	main
peab	doc_995572625436_item	2972878	et	4	main
toetama	doc_995572625436_item	2972879	et	3	main
ma	doc_995572625435_item	2972723	et	3	main
võimalus	doc_995572625435_item	2972731	et	3	main
kolmas	doc_995572625435_item	2972740	et	3	main
ta	doc_995572625435_item	2972747	et	4	main
igal	doc_995572625435_item	2972754	et	3	main
käi	doc_995572625435_item	2972757	et	4	main
tööl	doc_995572625435_item	2972758	et	3	main
kui	doc_995572625435_item	2972759	et	3	main
pidul	doc_995572625435_item	2972760	et	3	main
see	doc_995572625435_item	2972761	et	3	main
on	doc_995572625435_item	2972762	et	4	main
võõrkeele	doc_995572625435_item	2972771	et	4	main
aitab	doc_995572625435_item	2972774	et	3	main
elada	doc_995572625435_item	2972775	et	3	main
elu	doc_995572625435_item	2972776	et	4	main
see	doc_995572625435_item	2972777	et	3	main
on	doc_995572625435_item	2972778	et	4	main
elu	doc_995572625435_item	2972779	et	4	main
ja	doc_995572625435_item	2972780	et	3	main
vaja	doc_995572625435_item	2972781	et	4	main
lihtsalt	doc_995572625435_item	2972782	et	4	main
elada	doc_995572625435_item	2972783	et	3	main
p	doc_995572625435_item	2972784	et	4	main
ilma	doc_995572625436_item	2972785	et	4	main
milleta	doc_995572625436_item	2972786	et	3	main
ei	doc_995572625436_item	2972787	et	4	main
saa	doc_995572625436_item	2972788	et	4	main
inimene	doc_995572625436_item	2972789	et	3	main
tänapäeval	doc_995572625436_item	2972790	et	3	main
elada	doc_995572625436_item	2972791	et	3	main
olen	doc_995572625436_item	2972792	et	3	main
kindel	doc_995572625436_item	2972793	et	3	main
et	doc_995572625436_item	2972794	et	3	main
tänapäeval	doc_995572625436_item	2972795	et	3	main
varem	doc_995572625436_item	2972796	et	4	main
ja	doc_995572625436_item	2972797	et	3	main
teda	doc_995572625435_item	2972749	et	4	main
on	doc_995572625435_item	2972751	et	4	main
palju	doc_995572625435_item	2972770	et	4	main
meie	doc_995572625436_item	2972805	et	4	main
elu	doc_995572625436_item	2972806	et	4	main
on	doc_995572625436_item	2972813	et	4	main
palju	doc_995572625436_item	2972820	et	4	main
võimalusi	doc_995572625436_item	2972821	et	3	main
inimese	doc_995572625436_item	2972823	et	4	main
hea	doc_995572625436_item	2972834	et	4	main
tööd	doc_995572625436_item	2972845	et	4	main
inimesed	doc_995572625436_item	2972846	et	3	main
välismaale	doc_995572625436_item	2972852	et	4	main
on	doc_995572625436_item	2972857	et	4	main
ja	doc_995572625436_item	2972860	et	3	main
sellised	doc_995572625436_item	2972862	et	4	main
võivad	doc_995572625436_item	2972868	et	4	main
kodanikke	doc_995572625436_item	2972881	et	3	main
võimaluse	doc_995572625436_item	2972888	et	3	main
hea	doc_995572625436_item	2972889	et	4	main
tule	doc_995572625436_item	2972929	et	4	main
tagasi	doc_995572625436_item	2972930	et	3	main
saa	doc_995572625437_item	2972946	et	4	main
tänapäeval	doc_995572625437_item	2972947	et	3	main
elada	doc_995572625437_item	2972948	et	3	main
meie	doc_995572625437_item	2972959	et	4	main
ei	doc_995572625437_item	2972986	et	4	main
ainult	doc_995572625437_item	2972993	et	4	main
ennast	doc_995572625437_item	2972994	et	4	main
kuidas	doc_995572625437_item	2972995	et	3	main
inimesel	doc_995572625437_item	2972996	et	3	main
on	doc_995572625437_item	2972997	et	4	main
perekond	doc_995572625437_item	2972998	et	3	main
kuidas	doc_995572625437_item	2972999	et	3	main
ta	doc_995572625437_item	2973000	et	4	main
tunneb	doc_995572625437_item	2973001	et	3	main
perekond	doc_995572625437_item	2973012	et	3	main
muutus	doc_995572625436_item	2972807	et	4	main
viimasel	doc_995572625436_item	2972808	et	3	main
ajal	doc_995572625436_item	2972809	et	4	main
aga	doc_995572625436_item	2972810	et	3	main
hariduse	doc_995572625436_item	2972811	et	3	main
ja	doc_995572625436_item	2972815	et	3	main
aidata	doc_995572625436_item	2972830	et	4	main
hea	doc_995572625436_item	2972839	et	4	main
haridusega	doc_995572625436_item	2972840	et	3	main
alati	doc_995572625436_item	2972841	et	4	main
võib	doc_995572625436_item	2972842	et	3	main
leida	doc_995572625436_item	2972843	et	3	main
hea	doc_995572625436_item	2972844	et	4	main
elu	doc_995572625436_item	2972850	et	4	main
sõida	doc_995572625436_item	2972851	et	4	main
tööd	doc_995572625436_item	2972855	et	4	main
muuta	doc_995572625436_item	2972869	et	4	main
oma	doc_995572625436_item	2972880	et	4	main
hariduse	doc_995572625436_item	2972882	et	3	main
peavad	doc_995572625436_item	2972887	et	4	main
saama	doc_995572625436_item	2972891	et	4	main
minu	doc_995572625436_item	2972892	et	3	main
arvates	doc_995572625436_item	2972893	et	4	main
rootsis	doc_995572625436_item	2972894	et	3	main
on	doc_995572625436_item	2972895	et	4	main
väga	doc_995572625436_item	2972896	et	3	main
eduka	doc_995572625436_item	2972897	et	3	main
kogemus	doc_995572625436_item	2972898	et	3	main
selles	doc_995572625436_item	2972899	et	4	main
vallas	doc_995572625436_item	2972900	et	3	main
ja	doc_995572625436_item	2972901	et	3	main
me	doc_995572625436_item	2972902	et	4	main
peame	doc_995572625436_item	2972903	et	4	main
ka	doc_995572625436_item	2972904	et	3	main
midagi	doc_995572625436_item	2972905	et	4	main
vahetama	doc_995572625436_item	2972906	et	3	main
haridusega	doc_995572625436_item	2972907	et	3	main
tänapäeval	doc_995572625436_item	2972908	et	3	main
on	doc_995572625436_item	2972909	et	4	main
selline	doc_995572625436_item	2972910	et	4	main
asjaolud	doc_995572625436_item	2972911	et	3	main
et	doc_995572625436_item	2972912	et	3	main
mõned	doc_995572625436_item	2972913	et	3	main
noored	doc_995572625436_item	2972914	et	3	main
inimesed	doc_995572625436_item	2972915	et	3	main
ei	doc_995572625436_item	2972916	et	4	main
saa	doc_995572625436_item	2972917	et	4	main
õppida	doc_995572625436_item	2972918	et	3	main
meie	doc_995572625436_item	2972919	et	4	main
riigis	doc_995572625436_item	2972920	et	3	main
nad	doc_995572625436_item	2972921	et	3	main
välismaale	doc_995572625436_item	2972923	et	4	main
me	doc_995572625436_item	2972931	et	4	main
päeva	doc_995572625436_item	2972940	et	4	main
raskem	doc_995572625436_item	2972941	et	4	main
see	doc_995572625437_item	2972949	et	3	main
on	doc_995572625437_item	2972950	et	4	main
täpselt	doc_995572625437_item	2972954	et	4	main
ei	doc_995572625437_item	2972957	et	4	main
oska	doc_995572625437_item	2972958	et	4	main
inimene	doc_995572625437_item	2972978	et	3	main
isamaata	doc_995572625437_item	2972980	et	3	main
nägu	doc_995572625437_item	2972981	et	4	main
tilk	doc_995572625437_item	2972982	et	3	main
elukogemus	doc_995572625436_item	2972861	et	3	main
inimesed	doc_995572625436_item	2972863	et	3	main
initsiatiivsed	doc_995572625436_item	2972866	et	4	main
elu	doc_995572625436_item	2972871	et	4	main
seoses	doc_995572625436_item	2972873	et	4	main
sellega	doc_995572625436_item	2972874	et	3	main
arvan	doc_995572625436_item	2972875	et	3	main
et	doc_995572625436_item	2972876	et	3	main
riik	doc_995572625436_item	2972877	et	3	main
inimesed	doc_995572625436_item	2972886	et	3	main
hariduse	doc_995572625436_item	2972890	et	3	main
p	doc_995572625436_item	2972942	et	4	main
väga	doc_995572625437_item	2972951	et	3	main
ma	doc_995572625437_item	2972955	et	3	main
vastata	doc_995572625437_item	2972956	et	4	main
nii	doc_995572625437_item	2972961	et	3	main
armastuseta	doc_995572625437_item	2972976	et	4	main
tööta	doc_995572625437_item	2972977	et	4	main
ilma	doc_995572625437_item	2972979	et	4	main
tema	doc_995572625437_item	2973004	et	4	main
ta	doc_995572625437_item	2973009	et	4	main
elada	doc_995572625437_item	2973020	et	3	main
vaja	doc_995572625437_item	2973023	et	4	main
armastus	doc_995572625437_item	2973034	et	4	main
väga	doc_995572625437_item	2973036	et	3	main
ma	doc_995572625437_item	2973055	et	3	main
ei	doc_995572625437_item	2973056	et	4	main
lapsepõlvest	doc_995572625437_item	2973060	et	4	main
ehitab	doc_995572625437_item	2973061	et	3	main
oma	doc_995572625437_item	2973062	et	4	main
karjäär	doc_995572625437_item	2973063	et	3	main
näiteks	doc_995572625437_item	2973064	et	4	main
majad	doc_995572625437_item	2973089	et	3	main
on	doc_995572625437_item	2973092	et	4	main
töö	doc_995572625437_item	2973095	et	4	main
kodu	doc_995572625437_item	2973106	et	4	main
aga	doc_995572625437_item	2973107	et	3	main
kodu	doc_995572625437_item	2973115	et	4	main
tugev	doc_995572625437_item	2973119	et	4	main
ja	doc_995572625436_item	2972924	et	3	main
kõrghariduse	doc_995572625436_item	2972926	et	3	main
saamist	doc_995572625436_item	2972927	et	4	main
ei	doc_995572625436_item	2972928	et	4	main
see	doc_995572625436_item	2972936	et	3	main
probleem	doc_995572625436_item	2972937	et	3	main
on	doc_995572625436_item	2972938	et	4	main
iga	doc_995572625436_item	2972939	et	4	main
küsimus	doc_995572625437_item	2972953	et	4	main
palju	doc_995572625437_item	2972962	et	4	main
väärtused	doc_995572625437_item	2972963	et	3	main
ilma	doc_995572625437_item	2972964	et	4	main
milleta	doc_995572625437_item	2972965	et	3	main
ei	doc_995572625437_item	2972966	et	4	main
saa	doc_995572625437_item	2972967	et	4	main
elada	doc_995572625437_item	2972968	et	3	main
ei	doc_995572625437_item	2972969	et	4	main
saa	doc_995572625437_item	2972970	et	4	main
elada	doc_995572625437_item	2972971	et	3	main
ilma	doc_995572625437_item	2972972	et	4	main
isamaata	doc_995572625437_item	2972973	et	3	main
pereta	doc_995572625437_item	2972974	et	3	main
sõpradeta	doc_995572625437_item	2972975	et	3	main
elus	doc_995572625437_item	2972960	et	4	main
ole	doc_995572625437_item	2972987	et	4	main
õigusi	doc_995572625437_item	2972988	et	4	main
ja	doc_995572625437_item	2972989	et	3	main
vanemad	doc_995572625437_item	2973005	et	4	main
oled	doc_995572625437_item	2973010	et	3	main
tähtis	doc_995572625437_item	2973014	et	4	main
nad	doc_995572625437_item	2973024	et	3	main
ja	doc_995572625437_item	2973027	et	3	main
ka	doc_995572625437_item	2973035	et	3	main
armastus	doc_995572625437_item	2973041	et	4	main
linnale	doc_995572625437_item	2973048	et	4	main
lihtsalt	doc_995572625437_item	2973051	et	4	main
ei	doc_995572625437_item	2973052	et	4	main
saa	doc_995572625437_item	2973053	et	4	main
elada	doc_995572625437_item	2973054	et	3	main
see	doc_995572625437_item	2973091	et	3	main
tema	doc_995572625437_item	2973093	et	4	main
õnne	doc_995572625437_item	2973101	et	4	main
selle	doc_995572625437_item	2973102	et	4	main
kodu	doc_995572625437_item	2973108	et	4	main
minu	doc_995572625437_item	2973109	et	3	main
ainult	doc_995572625437_item	2973113	et	4	main
tervised	doc_995572625437_item	2973121	et	3	main
ja	doc_995572625437_item	2973123	et	3	main
kellest	doc_995572625437_item	2973125	et	4	main
peab	doc_995572625437_item	2973127	et	4	main
hooldama	doc_995572625437_item	2973128	et	3	main
olla	doc_995572625437_item	2973130	et	3	main
elanikud	doc_995572625437_item	2973139	et	3	main
riigis	doc_995572625437_item	2973141	et	3	main
me	doc_995572625437_item	2973146	et	4	main
paremaks	doc_995572625437_item	2973150	et	4	main
vabaks	doc_995572625437_item	2973151	et	3	main
ja	doc_995572625437_item	2973152	et	3	main
rikkaks	doc_995572625437_item	2973153	et	4	main
ilma	doc_995572625438_item	2973154	et	4	main
milleta	doc_995572625438_item	2973155	et	3	main
on	doc_995572625438_item	2973183	et	4	main
raha	doc_995572625438_item	2973185	et	4	main
ilma	doc_995572625438_item	2973187	et	4	main
rahata	doc_995572625438_item	2973188	et	4	main
toidu	doc_995572625438_item	2973196	et	3	main
ja	doc_995572625438_item	2973197	et	3	main
palju	doc_995572625438_item	2973198	et	4	main
inimene	doc_995572625438_item	2973201	et	3	main
endale	doc_995572625438_item	2973203	et	4	main
on	doc_995572625438_item	2973210	et	4	main
ja	doc_995572625438_item	2973217	et	3	main
vesi	doc_995572625437_item	2972983	et	4	main
meres	doc_995572625437_item	2972984	et	3	main
tal	doc_995572625437_item	2972985	et	3	main
ta	doc_995572625437_item	2972991	et	4	main
mõtleb	doc_995572625437_item	2972992	et	3	main
kes	doc_995572625437_item	2973002	et	4	main
oli	doc_995572625437_item	2973003	et	3	main
tugevaks	doc_995572625437_item	2973011	et	4	main
on	doc_995572625437_item	2973013	et	4	main
aga	doc_995572625437_item	2973015	et	3	main
ilma	doc_995572625437_item	2973016	et	4	main
sõbradeta	doc_995572625437_item	2973017	et	4	main
kuidas	doc_995572625437_item	2973022	et	3	main
nõukoguga	doc_995572625437_item	2973026	et	3	main
rahaga	doc_995572625437_item	2973028	et	4	main
aitavad	doc_995572625437_item	2973029	et	4	main
elu	doc_995572625437_item	2973032	et	4	main
tähtis	doc_995572625437_item	2973037	et	4	main
oma	doc_995572625437_item	2973039	et	4	main
elus	doc_995572625437_item	2973040	et	4	main
oma	doc_995572625437_item	2973047	et	4	main
räägi	doc_995572625437_item	2973057	et	4	main
ja	doc_995572625437_item	2973090	et	3	main
armastus	doc_995572625437_item	2973094	et	4	main
kogu	doc_995572625437_item	2973096	et	4	main
elule	doc_995572625437_item	2973097	et	3	main
see	doc_995572625437_item	2973098	et	3	main
pärast	doc_995572625437_item	2973103	et	4	main
tal	doc_995572625437_item	2973104	et	3	main
meelne	doc_995572625437_item	2973110	et	3	main
lemmik	doc_995572625437_item	2973117	et	3	main
lapsed	doc_995572625437_item	2973122	et	3	main
ma	doc_995572625437_item	2973134	et	3	main
kindel	doc_995572625437_item	2973136	et	3	main
kõik	doc_995572625437_item	2973138	et	4	main
oma	doc_995572625437_item	2973140	et	4	main
hakkame	doc_995572625437_item	2973147	et	3	main
elama	doc_995572625437_item	2973149	et	3	main
ütleme	doc_995572625438_item	2973160	et	3	main
on	doc_995572625438_item	2973163	et	4	main
saa	doc_995572625438_item	2973190	et	4	main
mis	doc_995572625438_item	2973193	et	4	main
annab	doc_995572625438_item	2973194	et	3	main
meile	doc_995572625438_item	2973195	et	4	main
palju	doc_995572625438_item	2973208	et	4	main
raha	doc_995572625438_item	2973209	et	4	main
ise	doc_995572625438_item	2973216	et	4	main
mis	doc_995572625438_item	2973229	et	4	main
on	doc_995572625438_item	2973230	et	4	main
kasulik	doc_995572625438_item	2973231	et	3	main
selle	doc_995572625438_item	2973232	et	4	main
kui	doc_995572625438_item	2973239	et	3	main
sull	doc_995572625438_item	2973240	et	4	main
ja	doc_995572625438_item	2973243	et	3	main
said	doc_995572625438_item	2973245	et	4	main
palkaga	doc_995572625438_item	2973247	et	4	main
töökoht	doc_995572625438_item	2973248	et	3	main
nii	doc_995572625438_item	2973277	et	3	main
ütleme	doc_995572625438_item	2973282	et	3	main
raha	doc_995572625438_item	2973284	et	4	main
ka	doc_995572625438_item	2973286	et	3	main
meie	doc_995572625438_item	2973292	et	4	main
ei	doc_995572625438_item	2973304	et	4	main
sest	doc_995572625438_item	2973307	et	4	main
on	doc_995572625438_item	2973313	et	4	main
elu	doc_995572625438_item	2973315	et	4	main
aga	doc_995572625438_item	2973316	et	3	main
elu	doc_995572625438_item	2973317	et	4	main
see	doc_995572625438_item	2973318	et	3	main
oma	doc_995572625438_item	2973345	et	4	main
mis	doc_995572625438_item	2973350	et	4	main
on	doc_995572625438_item	2973359	et	4	main
on	doc_995572625438_item	2973368	et	4	main
oma	doc_995572625438_item	2973369	et	4	main
elu	doc_995572625438_item	2973370	et	4	main
oma	doc_995572625438_item	2973371	et	4	main
saab	doc_995572625438_item	2973378	et	3	main
elu	doc_995572625439_item	2973385	et	4	main
kliima	doc_995572625439_item	2973389	et	4	main
tõusis	doc_995572625439_item	2973403	et	4	main
mõne	doc_995572625439_item	2973404	et	3	main
inimese	doc_995572625439_item	2973410	et	4	main
selline	doc_995572625439_item	2973436	et	4	main
kohustusi	doc_995572625437_item	2972990	et	4	main
vanavanemad	doc_995572625437_item	2973006	et	4	main
sugulased	doc_995572625437_item	2973007	et	3	main
sest	doc_995572625437_item	2973008	et	4	main
ei	doc_995572625437_item	2973018	et	4	main
saa	doc_995572625437_item	2973019	et	4	main
ka	doc_995572625437_item	2973021	et	3	main
aitavad	doc_995572625437_item	2973025	et	4	main
keerulisi	doc_995572625437_item	2973031	et	4	main
probleemi	doc_995572625437_item	2973033	et	4	main
osa	doc_995572625437_item	2973038	et	4	main
lastele	doc_995572625437_item	2973045	et	4	main
loodusele	doc_995572625437_item	2973046	et	4	main
töö	doc_995572625437_item	2973050	et	4	main
lapsepõlves	doc_995572625437_item	2973065	et	4	main
uued	doc_995572625437_item	2973086	et	3	main
ja	doc_995572625437_item	2973087	et	3	main
ilusad	doc_995572625437_item	2973088	et	3	main
tema	doc_995572625437_item	2973100	et	4	main
mitte	doc_995572625437_item	2973112	et	3	main
maja	doc_995572625437_item	2973114	et	4	main
olen	doc_995572625437_item	2973135	et	3	main
elada	doc_995572625438_item	2973159	et	3	main
et	doc_995572625438_item	2973161	et	3	main
muidugi	doc_995572625438_item	2973184	et	4	main
sest	doc_995572625438_item	2973186	et	4	main
üldse	doc_995572625438_item	2973192	et	3	main
mis	doc_995572625438_item	2973200	et	4	main
soobib	doc_995572625438_item	2973202	et	4	main
teine	doc_995572625438_item	2973204	et	3	main
vaja	doc_995572625438_item	2973211	et	4	main
inimestele	doc_995572625438_item	2973212	et	3	main
see	doc_995572625438_item	2973213	et	3	main
kasutab	doc_995572625438_item	2973218	et	3	main
oma	doc_995572625438_item	2973219	et	4	main
eriala	doc_995572625438_item	2973221	et	4	main
eneergiat	doc_995572625438_item	2973224	et	4	main
suhtlemisoskust	doc_995572625438_item	2973225	et	3	main
näiteks	doc_995572625438_item	2973237	et	4	main
et	doc_995572625438_item	2973238	et	3	main
veendunud	doc_995572625438_item	2973242	et	4	main
hea	doc_995572625438_item	2973246	et	4	main
siis	doc_995572625438_item	2973249	et	3	main
sull	doc_995572625438_item	2973250	et	4	main
saada	doc_995572625438_item	2973254	et	4	main
rohkem	doc_995572625438_item	2973274	et	4	main
tahad	doc_995572625438_item	2973280	et	3	main
oluline	doc_995572625438_item	2973290	et	4	main
oma	doc_995572625438_item	2973297	et	4	main
armastuseta	doc_995572625438_item	2973302	et	4	main
elada	doc_995572625438_item	2973306	et	3	main
meie	doc_995572625438_item	2973308	et	4	main
oleme	doc_995572625438_item	2973309	et	3	main
kõigipealt	doc_995572625438_item	2973320	et	4	main
otsustada	doc_995572625437_item	2973030	et	3	main
isamaale	doc_995572625437_item	2973042	et	4	main
perele	doc_995572625437_item	2973043	et	3	main
vanurile	doc_995572625437_item	2973044	et	3	main
ilma	doc_995572625437_item	2973049	et	4	main
rahast	doc_995572625437_item	2973058	et	4	main
inimine	doc_995572625437_item	2973059	et	4	main
ta	doc_995572625437_item	2973066	et	4	main
tahab	doc_995572625437_item	2973067	et	3	main
olla	doc_995572625437_item	2973068	et	3	main
arhitektorina	doc_995572625437_item	2973069	et	4	main
siis	doc_995572625437_item	2973070	et	3	main
pärast	doc_995572625437_item	2973071	et	4	main
kooli	doc_995572625437_item	2973072	et	4	main
ta	doc_995572625437_item	2973073	et	4	main
käis	doc_995572625437_item	2973074	et	4	main
ülikooli	doc_995572625437_item	2973075	et	4	main
pärast	doc_995572625437_item	2973076	et	4	main
seda	doc_995572625437_item	2973077	et	3	main
aspirantuuri	doc_995572625437_item	2973078	et	4	main
parast	doc_995572625437_item	2973079	et	3	main
koolitust	doc_995572625437_item	2973080	et	4	main
ta	doc_995572625437_item	2973081	et	4	main
töötab	doc_995572625437_item	2973082	et	3	main
ehituse	doc_995572625437_item	2973083	et	4	main
objektidel	doc_995572625437_item	2973084	et	3	main
proekteerib	doc_995572625437_item	2973085	et	4	main
on	doc_995572625437_item	2973099	et	4	main
on	doc_995572625437_item	2973105	et	4	main
tähendab	doc_995572625437_item	2973111	et	3	main
tähendab	doc_995572625437_item	2973116	et	3	main
töö	doc_995572625437_item	2973118	et	4	main
perekond	doc_995572625437_item	2973120	et	3	main
vanurid	doc_995572625437_item	2973124	et	3	main
ta	doc_995572625437_item	2973126	et	4	main
võib	doc_995572625437_item	2973129	et	3	main
ma	doc_995572625437_item	2973131	et	3	main
eksin	doc_995572625437_item	2973132	et	3	main
olevad	doc_995572625437_item	2973142	et	4	main
mõelda	doc_995572625437_item	2973143	et	4	main
nagu	doc_995572625437_item	2973144	et	3	main
ei	doc_995572625438_item	2973156	et	4	main
võimalused	doc_995572625438_item	2973199	et	3	main
inimene	doc_995572625438_item	2973215	et	3	main
kogemused	doc_995572625438_item	2973220	et	3	main
selllest	doc_995572625438_item	2973236	et	4	main
sina	doc_995572625438_item	2973244	et	4	main
toiduained	doc_995572625438_item	2973272	et	3	main
lihtsalt	doc_995572625438_item	2973273	et	4	main
võimalust	doc_995572625438_item	2973275	et	3	main
sina	doc_995572625438_item	2973279	et	4	main
ei	doc_995572625438_item	2973287	et	4	main
elus	doc_995572625438_item	2973293	et	4	main
oma	doc_995572625438_item	2973299	et	4	main
inimesed	doc_995572625438_item	2973311	et	3	main
oma	doc_995572625438_item	2973314	et	4	main
veel	doc_995572625438_item	2973331	et	4	main
et	doc_995572625438_item	2973332	et	3	main
mitte	doc_995572625438_item	2973333	et	3	main
veel	doc_995572625438_item	2973342	et	4	main
annavad	doc_995572625438_item	2973351	et	3	main
on	doc_995572625438_item	2973355	et	4	main
ikkagi	doc_995572625438_item	2973360	et	4	main
väga	doc_995572625438_item	2973361	et	3	main
raske	doc_995572625438_item	2973362	et	4	main
et	doc_995572625438_item	2973365	et	3	main
ja	doc_995572625438_item	2973376	et	3	main
vastuseid	doc_995572625438_item	2973377	et	3	main
inimese	doc_995572625439_item	2973384	et	4	main
muutub	doc_995572625439_item	2973390	et	3	main
öelda	doc_995572625439_item	2973392	et	4	main
isegi	doc_995572625439_item	2973396	et	4	main
jää	doc_995572625439_item	2973398	et	4	main
sulama	doc_995572625439_item	2973400	et	4	main
ja	doc_995572625439_item	2973401	et	3	main
õhutemperatuur	doc_995572625439_item	2973402	et	3	main
mõjutavad	doc_995572625439_item	2973409	et	4	main
ei	doc_995572625439_item	2973419	et	4	main
ja	doc_995572625439_item	2973421	et	3	main
terve	doc_995572625439_item	2973422	et	4	main
jooksul	doc_995572625439_item	2973424	et	4	main
sajab	doc_995572625439_item	2973425	et	3	main
vihma	doc_995572625439_item	2973426	et	4	main
inimesed	doc_995572625439_item	2973427	et	3	main
mõju	doc_995572625439_item	2973434	et	4	main
ja	doc_995572625439_item	2973435	et	3	main
lume	doc_995572625439_item	2973441	et	3	main
sajab	doc_995572625439_item	2973443	et	3	main
vihma	doc_995572625439_item	2973445	et	4	main
ilm	doc_995572625439_item	2973451	et	3	main
rikkub	doc_995572625439_item	2973452	et	4	main
on	doc_995572625439_item	2973458	et	4	main
olemas	doc_995572625439_item	2973459	et	4	main
südamega	doc_995572625439_item	2973460	et	3	main
hingamisega	doc_995572625439_item	2973461	et	4	main
ja	doc_995572625439_item	2973462	et	3	main
mõjutab	doc_995572625439_item	2973519	et	3	main
sagikust	doc_995572625439_item	2973520	et	4	main
aga	doc_995572625437_item	2973133	et	3	main
et	doc_995572625437_item	2973137	et	3	main
mina	doc_995572625437_item	2973145	et	4	main
kõik	doc_995572625437_item	2973148	et	4	main
saa	doc_995572625438_item	2973157	et	4	main
inimene	doc_995572625438_item	2973158	et	3	main
see	doc_995572625438_item	2973162	et	3	main
väga	doc_995572625438_item	2973164	et	3	main
raske	doc_995572625438_item	2973165	et	4	main
küsimus	doc_995572625438_item	2973166	et	4	main
kõigile	doc_995572625438_item	2973167	et	4	main
saab	doc_995572625438_item	2973168	et	3	main
öelda	doc_995572625438_item	2973169	et	4	main
et	doc_995572625438_item	2973170	et	3	main
igaühelt	doc_995572625438_item	2973171	et	3	main
tänapäeval	doc_995572625438_item	2973172	et	3	main
seisab	doc_995572625438_item	2973173	et	3	main
oma	doc_995572625438_item	2973174	et	4	main
vastus	doc_995572625438_item	2973175	et	3	main
aga	doc_995572625438_item	2973176	et	3	main
ma	doc_995572625438_item	2973177	et	3	main
arvan	doc_995572625438_item	2973178	et	3	main
et	doc_995572625438_item	2973179	et	3	main
kõige	doc_995572625438_item	2973180	et	4	main
olulisem	doc_995572625438_item	2973181	et	4	main
see	doc_995572625438_item	2973182	et	3	main
ei	doc_995572625438_item	2973189	et	4	main
elada	doc_995572625438_item	2973191	et	3	main
küsimus	doc_995572625438_item	2973205	et	4	main
on	doc_995572625438_item	2973206	et	4	main
kui	doc_995572625438_item	2973207	et	3	main
otsustab	doc_995572625438_item	2973214	et	3	main
oskuseid	doc_995572625438_item	2973223	et	3	main
ja	doc_995572625438_item	2973226	et	3	main
teised	doc_995572625438_item	2973227	et	4	main
parameetrid	doc_995572625438_item	2973228	et	4	main
sõltub	doc_995572625438_item	2973234	et	3	main
veel	doc_995572625438_item	2973235	et	4	main
on	doc_995572625438_item	2973251	et	4	main
rohkem	doc_995572625438_item	2973252	et	4	main
võiamlust	doc_995572625438_item	2973253	et	4	main
keelt	doc_995572625438_item	2973269	et	4	main
elada	doc_995572625438_item	2973276	et	3	main
aga	doc_995572625438_item	2973281	et	3	main
küsimus	doc_995572625438_item	2973291	et	4	main
perekondata	doc_995572625438_item	2973298	et	4	main
ilma	doc_995572625438_item	2973301	et	4	main
saa	doc_995572625438_item	2973305	et	4	main
kõik	doc_995572625438_item	2973310	et	4	main
kellel	doc_995572625438_item	2973312	et	4	main
armastus	doc_995572625438_item	2973321	et	4	main
selleta	doc_995572625438_item	2973323	et	3	main
ka	doc_995572625438_item	2973324	et	3	main
ainult	doc_995572625438_item	2973334	et	4	main
tervist	doc_995572625438_item	2973346	et	4	main
inimeste	doc_995572625438_item	2973348	et	3	main
meile	doc_995572625438_item	2973352	et	4	main
elu	doc_995572625438_item	2973354	et	4	main
tähtis	doc_995572625438_item	2973356	et	4	main
hea	doc_995572625438_item	2973372	et	4	main
ja	doc_995572625438_item	2973373	et	3	main
kliima	doc_995572625439_item	2973382	et	4	main
mõjutab	doc_995572625439_item	2973383	et	3	main
igal	doc_995572625439_item	2973386	et	3	main
meie	doc_995572625439_item	2973388	et	4	main
saaks	doc_995572625439_item	2973391	et	3	main
et	doc_995572625439_item	2973393	et	3	main
tervist	doc_995572625439_item	2973411	et	4	main
eestis	doc_995572625439_item	2973415	et	3	main
pasta	doc_995572625439_item	2973420	et	4	main
päeva	doc_995572625439_item	2973423	et	4	main
ongi	doc_995572625439_item	2973432	et	4	main
kliima	doc_995572625439_item	2973433	et	4	main
kui	doc_995572625439_item	2973440	et	3	main
jälle	doc_995572625439_item	2973444	et	3	main
soojeneb	doc_995572625439_item	2973448	et	3	main
selline	doc_995572625439_item	2973450	et	4	main
ka	doc_995572625439_item	2973453	et	3	main
inimese	doc_995572625439_item	2973454	et	4	main
haigusi	doc_995572625439_item	2973501	et	4	main
nagu	doc_995572625439_item	2973503	et	3	main
peame	doc_995572625439_item	2973528	et	4	main
väga	doc_995572625439_item	2973529	et	3	main
saa	doc_995572625440_item	2973535	et	4	main
oluline	doc_995572625440_item	2973550	et	4	main
siis	doc_995572625440_item	2973556	et	3	main
elada	doc_995572625440_item	2973559	et	3	main
päeva	doc_995572625440_item	2973562	et	4	main
vähem	doc_995572625440_item	2973565	et	4	main
soe	doc_995572625440_item	2973591	et	4	main
söök	doc_995572625440_item	2973592	et	3	main
ja	doc_995572625440_item	2973593	et	3	main
inimese	doc_995572625440_item	2973597	et	4	main
on	doc_995572625440_item	2973612	et	4	main
on	doc_995572625440_item	2973621	et	4	main
vaadelda	doc_995572625440_item	2973634	et	4	main
kui	doc_995572625440_item	2973640	et	3	main
palju	doc_995572625440_item	2973654	et	4	main
eest	doc_995572625440_item	2973701	et	4	main
ta	doc_995572625440_item	2973702	et	4	main
tunneb	doc_995572625440_item	2973703	et	3	main
et	doc_995572625440_item	2973708	et	3	main
inimesest	doc_995572625440_item	2973711	et	3	main
tahtejõud	doc_995572625440_item	2973713	et	4	main
ja	doc_995572625440_item	2973715	et	3	main
iseloom	doc_995572625440_item	2973718	et	3	main
juhul	doc_995572625440_item	2973720	et	3	main
keelte	doc_995572625438_item	2973222	et	3	main
küsimustele	doc_995572625438_item	2973233	et	4	main
on	doc_995572625438_item	2973241	et	4	main
elust	doc_995572625438_item	2973255	et	3	main
või	doc_995572625438_item	2973256	et	4	main
oma	doc_995572625438_item	2973257	et	4	main
palgast	doc_995572625438_item	2973258	et	4	main
inimene	doc_995572625438_item	2973259	et	3	main
saab	doc_995572625438_item	2973260	et	3	main
korjata	doc_995572625438_item	2973261	et	4	main
raha	doc_995572625438_item	2973262	et	4	main
ja	doc_995572625438_item	2973263	et	3	main
sõitma	doc_995572625438_item	2973264	et	3	main
puhkusele	doc_995572625438_item	2973265	et	4	main
välismaale	doc_995572625438_item	2973266	et	4	main
saab	doc_995572625438_item	2973267	et	3	main
õpida	doc_995572625438_item	2973268	et	4	main
osta	doc_995572625438_item	2973270	et	4	main
raamatuid	doc_995572625438_item	2973271	et	3	main
kui	doc_995572625438_item	2973278	et	3	main
et	doc_995572625438_item	2973283	et	3	main
on	doc_995572625438_item	2973285	et	4	main
ole	doc_995572625438_item	2973288	et	4	main
nii	doc_995572625438_item	2973289	et	3	main
ütleme	doc_995572625438_item	2973294	et	3	main
et	doc_995572625438_item	2973295	et	3	main
ilma	doc_995572625438_item	2973296	et	4	main
sõbrata	doc_995572625438_item	2973300	et	3	main
ka	doc_995572625438_item	2973303	et	3	main
on	doc_995572625438_item	2973319	et	4	main
raha	doc_995572625438_item	2973335	et	4	main
võimalus	doc_995572625438_item	2973338	et	3	main
see	doc_995572625438_item	2973340	et	3	main
kõike	doc_995572625438_item	2973347	et	4	main
parameetrid	doc_995572625438_item	2973349	et	4	main
normaalne	doc_995572625438_item	2973353	et	3	main
kõigile	doc_995572625438_item	2973364	et	4	main
inimistel	doc_995572625438_item	2973367	et	4	main
oma	doc_995572625438_item	2973374	et	4	main
mõteid	doc_995572625438_item	2973375	et	4	main
saada	doc_995572625438_item	2973379	et	4	main
väga	doc_995572625438_item	2973380	et	3	main
palju	doc_995572625438_item	2973381	et	4	main
aastal	doc_995572625439_item	2973387	et	3	main
soojeneb	doc_995572625439_item	2973395	et	3	main
graadi	doc_995572625439_item	2973405	et	4	main
võrra	doc_995572625439_item	2973406	et	3	main
sellised	doc_995572625439_item	2973407	et	4	main
muutused	doc_995572625439_item	2973408	et	4	main
vaatame	doc_995572625439_item	2973412	et	3	main
toimub	doc_995572625439_item	2973414	et	3	main
suvel	doc_995572625439_item	2973416	et	3	main
päike	doc_995572625439_item	2973418	et	3	main
vastuarusaamine	doc_995572625438_item	2973322	et	4	main
ei	doc_995572625438_item	2973325	et	4	main
saa	doc_995572625438_item	2973326	et	4	main
elada	doc_995572625438_item	2973327	et	3	main
tänapäeval	doc_995572625438_item	2973328	et	3	main
ja	doc_995572625438_item	2973329	et	3	main
ütleme	doc_995572625438_item	2973330	et	3	main
annab	doc_995572625438_item	2973336	et	3	main
meile	doc_995572625438_item	2973337	et	4	main
elada	doc_995572625438_item	2973339	et	3	main
sõltub	doc_995572625438_item	2973341	et	3	main
oma	doc_995572625438_item	2973343	et	4	main
enesetunuseta	doc_995572625438_item	2973344	et	4	main
põhimõtelised	doc_995572625438_item	2973357	et	4	main
see	doc_995572625438_item	2973358	et	3	main
küsimus	doc_995572625438_item	2973363	et	4	main
igal	doc_995572625438_item	2973366	et	3	main
kliima	doc_995572625439_item	2973394	et	4	main
antarktikas	doc_995572625439_item	2973397	et	4	main
hakkas	doc_995572625439_item	2973399	et	3	main
mis	doc_995572625439_item	2973413	et	4	main
kui	doc_995572625439_item	2973417	et	3	main
jaavad	doc_995572625439_item	2973428	et	4	main
haigeks	doc_995572625439_item	2973429	et	4	main
ja	doc_995572625439_item	2973430	et	3	main
see	doc_995572625439_item	2973431	et	3	main
talvel	doc_995572625439_item	2973439	et	4	main
õhutemperatuur	doc_995572625439_item	2973447	et	3	main
5-ni	doc_995572625439_item	2973449	et	3	main
tervist	doc_995572625439_item	2973455	et	4	main
inimesed	doc_995572625439_item	2973456	et	3	main
liikumisega	doc_995572625439_item	2973463	et	4	main
probleeme	doc_995572625439_item	2973464	et	3	main
väga	doc_995572625439_item	2973465	et	3	main
tarbima	doc_995572625439_item	2973492	et	3	main
teadlased	doc_995572625439_item	2973493	et	3	main
oletavad	doc_995572625439_item	2973494	et	4	main
et	doc_995572625439_item	2973495	et	3	main
võiks	doc_995572625439_item	2973498	et	4	main
intsüfoliit	doc_995572625439_item	2973506	et	4	main
aga	doc_995572625439_item	2973516	et	3	main
tulevikus	doc_995572625439_item	2973522	et	4	main
p	doc_995572625439_item	2973532	et	4	main
elu	doc_995572625440_item	2973538	et	4	main
vesi	doc_995572625440_item	2973551	et	4	main
kui	doc_995572625440_item	2973552	et	3	main
võib	doc_995572625440_item	2973558	et	3	main
kuni	doc_995572625440_item	2973560	et	3	main
teiseks	doc_995572625440_item	2973563	et	4	main
inimese	doc_995572625440_item	2973575	et	4	main
on	doc_995572625440_item	2973577	et	4	main
soe	doc_995572625440_item	2973589	et	4	main
söök	doc_995572625440_item	2973590	et	3	main
kestab	doc_995572625440_item	2973596	et	4	main
elu	doc_995572625440_item	2973598	et	4	main
tunduvalt	doc_995572625440_item	2973599	et	4	main
on	doc_995572625440_item	2973605	et	4	main
väga	doc_995572625440_item	2973613	et	3	main
reostaja	doc_995572625440_item	2973625	et	4	main
ettevõtted	doc_995572625440_item	2973626	et	3	main
mida	doc_995572625440_item	2973627	et	4	main
ehitab	doc_995572625440_item	2973628	et	3	main
inimene	doc_995572625440_item	2973629	et	3	main
reostavad	doc_995572625440_item	2973630	et	4	main
keskkonda	doc_995572625440_item	2973631	et	4	main
kuidas	doc_995572625440_item	2973645	et	3	main
elada	doc_995572625440_item	2973647	et	3	main
aga	doc_995572625440_item	2973657	et	3	main
reostajaid	doc_995572625440_item	2973665	et	4	main
peavad	doc_995572625440_item	2973668	et	4	main
looduse	doc_995572625440_item	2973671	et	4	main
hoolitseb	doc_995572625440_item	2973706	et	3	main
ehitab	doc_995572625440_item	2973733	et	3	main
ja	doc_995572625440_item	2973736	et	3	main
vaja	doc_995572625441_item	2973759	et	4	main
inimestele	doc_995572625441_item	2973760	et	3	main
mittu	doc_995572625441_item	2973763	et	4	main
arvan	doc_995572625441_item	2973769	et	3	main
ei	doc_995572625441_item	2973786	et	4	main
armastuseta	doc_995572625441_item	2973793	et	4	main
ja	doc_995572625441_item	2973794	et	3	main
ni	doc_995572625441_item	2973795	et	4	main
edasi	doc_995572625441_item	2973796	et	3	main
see	doc_995572625441_item	2973797	et	3	main
tähtsad	doc_995572625441_item	2973800	et	3	main
inimesi	doc_995572625441_item	2973802	et	4	main
õpivad	doc_995572625441_item	2973809	et	3	main
informatsioone	doc_995572625441_item	2973819	et	3	main
uudiseid	doc_995572625441_item	2973820	et	3	main
jaoks	doc_995572625441_item	2973827	et	4	main
et	doc_995572625441_item	2973834	et	3	main
ka	doc_995572625439_item	2973438	et	3	main
kellel	doc_995572625439_item	2973457	et	4	main
reageerivad	doc_995572625439_item	2973466	et	4	main
kliima	doc_995572625439_item	2973467	et	4	main
muutustele	doc_995572625439_item	2973468	et	4	main
ja	doc_995572625439_item	2973469	et	3	main
sellepärast	doc_995572625439_item	2973470	et	3	main
nad	doc_995572625439_item	2973471	et	3	main
peavad	doc_995572625439_item	2973472	et	4	main
rohkem	doc_995572625439_item	2973473	et	4	main
ravimeid	doc_995572625439_item	2973474	et	3	main
kasutama	doc_995572625439_item	2973475	et	3	main
kliima	doc_995572625439_item	2973476	et	4	main
muutumine	doc_995572625439_item	2973477	et	4	main
mõjutab	doc_995572625439_item	2973478	et	3	main
ka	doc_995572625439_item	2973479	et	3	main
inimese	doc_995572625439_item	2973480	et	4	main
toitumist	doc_995572625439_item	2973481	et	4	main
nende	doc_995572625439_item	2973482	et	4	main
isu	doc_995572625439_item	2973483	et	4	main
halveneb	doc_995572625439_item	2973484	et	3	main
ja	doc_995572625439_item	2973485	et	3	main
nad	doc_995572625439_item	2973486	et	3	main
jälle	doc_995572625439_item	2973487	et	3	main
hakkavad	doc_995572625439_item	2973488	et	4	main
rohkem	doc_995572625439_item	2973489	et	4	main
mao	doc_995572625439_item	2973490	et	4	main
ravimeid	doc_995572625439_item	2973491	et	3	main
toimub	doc_995572625439_item	2973437	et	3	main
asemel	doc_995572625439_item	2973442	et	4	main
ja	doc_995572625439_item	2973446	et	3	main
muutumine	doc_995572625439_item	2973497	et	4	main
infektsiooni	doc_995572625439_item	2973500	et	4	main
arendada	doc_995572625439_item	2973502	et	3	main
muutumine	doc_995572625439_item	2973508	et	4	main
isegi	doc_995572625439_item	2973517	et	4	main
ta	doc_995572625439_item	2973518	et	4	main
mis	doc_995572625439_item	2973521	et	4	main
toob	doc_995572625439_item	2973523	et	3	main
ja	doc_995572625439_item	2973525	et	3	main
me	doc_995572625439_item	2973527	et	4	main
olema	doc_995572625439_item	2973531	et	4	main
ei	doc_995572625440_item	2973534	et	4	main
elada	doc_995572625440_item	2973537	et	3	main
näitab	doc_995572625440_item	2973539	et	3	main
inimene	doc_995572625440_item	2973541	et	3	main
et	doc_995572625440_item	2973547	et	3	main
esiteks	doc_995572625440_item	2973548	et	3	main
ta	doc_995572625440_item	2973557	et	4	main
kolm	doc_995572625440_item	2973561	et	3	main
kuni	doc_995572625440_item	2973573	et	3	main
olnud	doc_995572625440_item	2973581	et	4	main
siis	doc_995572625440_item	2973583	et	3	main
proovinud	doc_995572625440_item	2973588	et	4	main
rohkem	doc_995572625440_item	2973600	et	4	main
kui	doc_995572625440_item	2973601	et	3	main
kliima	doc_995572625439_item	2973496	et	4	main
ka	doc_995572625439_item	2973499	et	3	main
malaaria	doc_995572625439_item	2973504	et	4	main
või	doc_995572625439_item	2973505	et	4	main
kliima	doc_995572625439_item	2973507	et	4	main
võiks	doc_995572625439_item	2973509	et	4	main
ka	doc_995572625439_item	2973510	et	3	main
mitte	doc_995572625439_item	2973511	et	3	main
tervisele	doc_995572625439_item	2973512	et	3	main
halbu	doc_995572625439_item	2973513	et	3	main
asju	doc_995572625439_item	2973514	et	3	main
tuua	doc_995572625439_item	2973515	et	3	main
kõhutühjust	doc_995572625439_item	2973524	et	4	main
sellepärast	doc_995572625439_item	2973526	et	3	main
milleta	doc_995572625440_item	2973533	et	3	main
et	doc_995572625440_item	2973540	et	3	main
veest	doc_995572625440_item	2973543	et	4	main
inimene	doc_995572625440_item	2973553	et	3	main
ei	doc_995572625440_item	2973554	et	4	main
nädala	doc_995572625440_item	2973574	et	3	main
vara	doc_995572625440_item	2973576	et	4	main
tuli	doc_995572625440_item	2973578	et	4	main
kui	doc_995572625440_item	2973579	et	3	main
tuli	doc_995572625440_item	2973582	et	4	main
mitte	doc_995572625440_item	2973585	et	3	main
kunagi	doc_995572625440_item	2973586	et	3	main
ei	doc_995572625440_item	2973587	et	4	main
ju	doc_995572625440_item	2973595	et	3	main
järgmiseks	doc_995572625440_item	2973604	et	3	main
oluline	doc_995572625440_item	2973606	et	4	main
keskkond	doc_995572625440_item	2973607	et	3	main
tahan	doc_995572625440_item	2973608	et	3	main
öelda	doc_995572625440_item	2973609	et	4	main
et	doc_995572625440_item	2973610	et	3	main
loodus	doc_995572625440_item	2973611	et	4	main
selle	doc_995572625440_item	2973635	et	4	main
poolt	doc_995572625440_item	2973638	et	4	main
ole	doc_995572625440_item	2973642	et	4	main
ettevõtteid	doc_995572625440_item	2973644	et	3	main
inimene	doc_995572625440_item	2973648	et	3	main
karistama	doc_995572625440_item	2973664	et	3	main
inimesed	doc_995572625440_item	2973667	et	3	main
näiteks	doc_995572625440_item	2973673	et	4	main
see	doc_995572625440_item	2973696	et	3	main
potilill	doc_995572625440_item	2973699	et	3	main
arvan	doc_995572625440_item	2973707	et	3	main
kannatlik	doc_995572625440_item	2973714	et	3	main
ehitab	doc_995572625440_item	2973717	et	3	main
vastasel	doc_995572625440_item	2973719	et	3	main
inimene	doc_995572625440_item	2973721	et	3	main
ja	doc_995572625440_item	2973725	et	3	main
lõpetuseks	doc_995572625440_item	2973727	et	4	main
otsustab	doc_995572625440_item	2973738	et	3	main
milleta	doc_995572625440_item	2973739	et	3	main
elada	doc_995572625440_item	2973741	et	3	main
ei	doc_995572625441_item	2973746	et	4	main
saa	doc_995572625441_item	2973747	et	4	main
inimene	doc_995572625441_item	2973748	et	3	main
on	doc_995572625441_item	2973757	et	4	main
väga	doc_995572625441_item	2973758	et	3	main
elu	doc_995572625441_item	2973766	et	4	main
sõltub	doc_995572625441_item	2973767	et	3	main
ma	doc_995572625441_item	2973768	et	3	main
toidust	doc_995572625441_item	2973770	et	4	main
tervist	doc_995572625441_item	2973779	et	4	main
inimesi	doc_995572625441_item	2973806	et	4	main
areneda	doc_995572625441_item	2973807	et	3	main
vaja	doc_995572625441_item	2973812	et	4	main
televisiooni	doc_995572625441_item	2973814	et	4	main
kaudu	doc_995572625441_item	2973815	et	3	main
alati	doc_995572625441_item	2973832	et	4	main
teda	doc_995572625441_item	2973835	et	4	main
lähedased	doc_995572625441_item	2973837	et	3	main
loodus	doc_995572625441_item	2973847	et	4	main
annab	doc_995572625441_item	2973848	et	3	main
jõudu	doc_995572625441_item	2973856	et	4	main
ilma	doc_995572625442_item	2973857	et	4	main
milleta	doc_995572625442_item	2973858	et	3	main
filosoofiline	doc_995572625442_item	2973868	et	4	main
kõik	doc_995572625442_item	2973872	et	4	main
inimesed	doc_995572625442_item	2973873	et	3	main
meil	doc_995572625442_item	2973874	et	4	main
ettevaatlikud	doc_995572625439_item	2973530	et	3	main
inimene	doc_995572625440_item	2973536	et	3	main
sisaldab	doc_995572625440_item	2973542	et	3	main
siis	doc_995572625440_item	2973544	et	3	main
võib	doc_995572625440_item	2973545	et	3	main
öelda	doc_995572625440_item	2973546	et	4	main
on	doc_995572625440_item	2973549	et	4	main
joo	doc_995572625440_item	2973555	et	4	main
mitte	doc_995572625440_item	2973564	et	3	main
tähtis	doc_995572625440_item	2973566	et	4	main
söök	doc_995572625440_item	2973567	et	3	main
et	doc_995572625440_item	2973568	et	3	main
söögita	doc_995572625440_item	2973569	et	3	main
inimene	doc_995572625440_item	2973570	et	3	main
võib	doc_995572625440_item	2973571	et	3	main
elada	doc_995572625440_item	2973572	et	3	main
ei	doc_995572625440_item	2973580	et	4	main
inimene	doc_995572625440_item	2973584	et	3	main
joogivesi	doc_995572625440_item	2973594	et	4	main
tavaline	doc_995572625440_item	2973602	et	4	main
söök	doc_995572625440_item	2973603	et	3	main
tähtis	doc_995572625440_item	2973614	et	4	main
inimese	doc_995572625440_item	2973615	et	4	main
jaoks	doc_995572625440_item	2973616	et	4	main
aga	doc_995572625440_item	2973617	et	3	main
meie	doc_995572625440_item	2973618	et	4	main
ajal	doc_995572625440_item	2973619	et	4	main
inimene	doc_995572625440_item	2973620	et	3	main
kõige	doc_995572625440_item	2973622	et	4	main
probleemi	doc_995572625440_item	2973636	et	4	main
siis	doc_995572625440_item	2973639	et	3	main
ei	doc_995572625440_item	2973641	et	4	main
erinevaid	doc_995572625440_item	2973643	et	4	main
võib	doc_995572625440_item	2973646	et	3	main
näiteks	doc_995572625440_item	2973649	et	4	main
kodumasinateta	doc_995572625440_item	2973650	et	3	main
mööblita	doc_995572625440_item	2973651	et	3	main
riieta	doc_995572625440_item	2973652	et	4	main
ja	doc_995572625440_item	2973653	et	3	main
riik	doc_995572625440_item	2973658	et	3	main
kontrollima	doc_995572625440_item	2973660	et	4	main
ja	doc_995572625440_item	2973666	et	3	main
kohta	doc_995572625440_item	2973672	et	4	main
vastutus	doc_995572625440_item	2973704	et	4	main
ja	doc_995572625440_item	2973705	et	3	main
vastutustunne	doc_995572625440_item	2973709	et	3	main
üldse	doc_995572625440_item	2973716	et	3	main
suurem	doc_995572625440_item	2973623	et	4	main
looduse	doc_995572625440_item	2973624	et	4	main
tootmisjäätmetega	doc_995572625440_item	2973632	et	4	main
kui	doc_995572625440_item	2973633	et	3	main
teist	doc_995572625440_item	2973637	et	4	main
teisi	doc_995572625440_item	2973655	et	4	main
asju	doc_995572625440_item	2973656	et	3	main
peab	doc_995572625440_item	2973659	et	4	main
ettevõtete	doc_995572625440_item	2973661	et	3	main
tegevus	doc_995572625440_item	2973662	et	4	main
ja	doc_995572625440_item	2973663	et	3	main
säästlikult	doc_995572625440_item	2973669	et	4	main
suhelda	doc_995572625440_item	2973670	et	4	main
ei	doc_995572625440_item	2973674	et	4	main
tohi	doc_995572625440_item	2973675	et	4	main
metsa	doc_995572625440_item	2973676	et	4	main
mõtlematult	doc_995572625440_item	2973677	et	4	main
raiuda	doc_995572625440_item	2973678	et	3	main
mets	doc_995572625440_item	2973679	et	3	main
on	doc_995572625440_item	2973680	et	4	main
meie	doc_995572625440_item	2973681	et	4	main
roheline	doc_995572625440_item	2973682	et	4	main
kuldbr	doc_995572625440_item	2973683	et	4	main
veel	doc_995572625440_item	2973684	et	4	main
tahan	doc_995572625440_item	2973685	et	3	main
öelda	doc_995572625440_item	2973686	et	4	main
et	doc_995572625440_item	2973687	et	3	main
igal	doc_995572625440_item	2973688	et	3	main
inimesel	doc_995572625440_item	2973689	et	3	main
peab	doc_995572625440_item	2973690	et	4	main
olema	doc_995572625440_item	2973691	et	4	main
oma	doc_995572625440_item	2973692	et	4	main
osake	doc_995572625440_item	2973693	et	4	main
loodusest	doc_995572625440_item	2973694	et	4	main
olgu	doc_995572625440_item	2973695	et	3	main
koer	doc_995572625440_item	2973697	et	3	main
või	doc_995572625440_item	2973698	et	4	main
mille	doc_995572625440_item	2973700	et	3	main
teeb	doc_995572625440_item	2973710	et	3	main
esiteks	doc_995572625440_item	2973712	et	3	main
saada	doc_995572625440_item	2973723	et	4	main
loohakaks	doc_995572625440_item	2973726	et	4	main
tahan	doc_995572625440_item	2973728	et	3	main
öelda	doc_995572625440_item	2973729	et	4	main
et	doc_995572625440_item	2973730	et	3	main
inimene	doc_995572625440_item	2973731	et	3	main
oma	doc_995572625440_item	2973734	et	4	main
milleta	doc_995572625441_item	2973745	et	3	main
ta	doc_995572625441_item	2973756	et	4	main
päev	doc_995572625441_item	2973762	et	3	main
korda	doc_995572625441_item	2973764	et	4	main
peab	doc_995572625441_item	2973772	et	4	main
siis	doc_995572625441_item	2973780	et	3	main
on	doc_995572625441_item	2973781	et	4	main
väga	doc_995572625441_item	2973782	et	3	main
ravineteta	doc_995572625441_item	2973790	et	4	main
raamatud	doc_995572625441_item	2973804	et	4	main
aitavad	doc_995572625441_item	2973805	et	4	main
me	doc_995572625441_item	2973816	et	4	main
saame	doc_995572625441_item	2973817	et	4	main
samuti	doc_995572625441_item	2973822	et	3	main
on	doc_995572625441_item	2973823	et	4	main
teada	doc_995572625441_item	2973833	et	3	main
näiteks	doc_995572625441_item	2973851	et	4	main
tõstab	doc_995572625441_item	2973852	et	3	main
annab	doc_995572625441_item	2973855	et	3	main
arvan	doc_995572625442_item	2973864	et	3	main
see	doc_995572625442_item	2973866	et	3	main
oma	doc_995572625442_item	2973876	et	4	main
arvamused	doc_995572625442_item	2973877	et	3	main
eluväärtused	doc_995572625442_item	2973881	et	3	main
erinevad	doc_995572625442_item	2973886	et	4	main
sarnane	doc_995572625442_item	2973889	et	4	main
teineteisega	doc_995572625442_item	2973890	et	3	main
raske	doc_995572625442_item	2973891	et	4	main
loomulikult	doc_995572625442_item	2973922	et	4	main
kõik	doc_995572625442_item	2973931	et	4	main
vajalike	doc_995572625442_item	2973932	et	3	main
me	doc_995572625442_item	2973945	et	4	main
see	doc_995572625442_item	2973950	et	3	main
selle	doc_995572625442_item	2973959	et	4	main
ta	doc_995572625442_item	2973981	et	4	main
teenib	doc_995572625442_item	2973982	et	3	main
võib	doc_995572625440_item	2973722	et	3	main
ise	doc_995572625440_item	2973732	et	4	main
ise	doc_995572625440_item	2973737	et	4	main
milleta	doc_995572625440_item	2973742	et	3	main
ei	doc_995572625440_item	2973743	et	4	main
saa	doc_995572625440_item	2973744	et	4	main
elada	doc_995572625441_item	2973749	et	3	main
kõigepealt	doc_995572625441_item	2973750	et	3	main
inimene	doc_995572625441_item	2973751	et	3	main
ei	doc_995572625441_item	2973752	et	4	main
ihnuskoiks	doc_995572625440_item	2973724	et	3	main
elu	doc_995572625440_item	2973735	et	4	main
saab	doc_995572625440_item	2973740	et	3	main
ei	doc_995572625441_item	2973777	et	4	main
ole	doc_995572625441_item	2973778	et	4	main
saa	doc_995572625441_item	2973787	et	4	main
elada	doc_995572625441_item	2973788	et	3	main
tuleta	doc_995572625441_item	2973789	et	4	main
nad	doc_995572625441_item	2973808	et	3	main
palju	doc_995572625441_item	2973818	et	4	main
saa	doc_995572625441_item	2973753	et	4	main
elada	doc_995572625441_item	2973754	et	3	main
toituta	doc_995572625441_item	2973755	et	4	main
iga	doc_995572625441_item	2973761	et	4	main
inimese	doc_995572625441_item	2973765	et	4	main
ta	doc_995572625441_item	2973771	et	4	main
olema	doc_995572625441_item	2973773	et	4	main
täisväärtuseid	doc_995572625441_item	2973774	et	3	main
kui	doc_995572625441_item	2973775	et	3	main
inimesel	doc_995572625441_item	2973776	et	3	main
raske	doc_995572625441_item	2973783	et	4	main
elada	doc_995572625441_item	2973784	et	3	main
inimene	doc_995572625441_item	2973785	et	3	main
televisioonita	doc_995572625441_item	2973791	et	4	main
raamatuteta	doc_995572625441_item	2973792	et	3	main
on	doc_995572625441_item	2973798	et	4	main
väga	doc_995572625441_item	2973799	et	3	main
asjad	doc_995572625441_item	2973801	et	3	main
elus	doc_995572625441_item	2973803	et	4	main
kuidas	doc_995572625441_item	2973810	et	3	main
on	doc_995572625441_item	2973811	et	4	main
elada	doc_995572625441_item	2973813	et	3	main
maailmast	doc_995572625441_item	2973821	et	4	main
väga	doc_995572625441_item	2973824	et	3	main
tähtis	doc_995572625441_item	2973825	et	4	main
inimese	doc_995572625441_item	2973826	et	4	main
vaja	doc_995572625441_item	2973831	et	4	main
armastavad	doc_995572625441_item	2973836	et	4	main
sugulased	doc_995572625441_item	2973838	et	3	main
paljut	doc_995572625441_item	2973850	et	3	main
saa	doc_995572625442_item	2973860	et	4	main
inimene	doc_995572625442_item	2973861	et	3	main
elada	doc_995572625442_item	2973862	et	3	main
ma	doc_995572625442_item	2973863	et	3	main
on	doc_995572625442_item	2973867	et	4	main
me	doc_995572625442_item	2973870	et	4	main
ja	doc_995572625442_item	2973878	et	3	main
käitumismudelid	doc_995572625442_item	2973879	et	3	main
hoiakud	doc_995572625442_item	2973882	et	3	main
ning	doc_995572625442_item	2973887	et	3	main
peab	doc_995572625442_item	2973924	et	4	main
mineraale	doc_995572625442_item	2973930	et	3	main
ühe	doc_995572625442_item	2973936	et	4	main
siis	doc_995572625442_item	2973948	et	3	main
selleks	doc_995572625442_item	2973952	et	4	main
raha	doc_995572625442_item	2973955	et	4	main
et	doc_995572625442_item	2973956	et	3	main
midagi	doc_995572625442_item	2973962	et	4	main
küsimus	doc_995572625442_item	2973967	et	4	main
ka	doc_995572625442_item	2973972	et	3	main
aspektidest	doc_995572625442_item	2973974	et	3	main
see	doc_995572625442_item	2973977	et	3	main
raha	doc_995572625442_item	2973983	et	4	main
ajal	doc_995572625442_item	2973985	et	4	main
saab	doc_995572625442_item	2973991	et	3	main
mida	doc_995572625442_item	2973995	et	4	main
kasu	doc_995572625442_item	2973999	et	4	main
kas	doc_995572625442_item	2974001	et	3	main
kui	doc_995572625442_item	2974027	et	3	main
muud	doc_995572625442_item	2974041	et	4	main
asjad	doc_995572625442_item	2974042	et	3	main
nagu	doc_995572625442_item	2974043	et	3	main
ma	doc_995572625442_item	2974044	et	3	main
alustasin	doc_995572625442_item	2974045	et	3	main
see	doc_995572625442_item	2974046	et	3	main
ühte	doc_995572625442_item	2974051	et	4	main
kool	doc_995572625443_item	2974066	et	4	main
arvan	doc_995572625443_item	2974070	et	3	main
kasulikum	doc_995572625443_item	2974072	et	4	main
venelatel	doc_995572625443_item	2974076	et	3	main
õppimiskeel	doc_995572625443_item	2974078	et	4	main
oleks	doc_995572625443_item	2974087	et	3	main
riigikeelt	doc_995572625443_item	2974090	et	4	main
et	doc_995572625443_item	2974093	et	3	main
elad	doc_995572625443_item	2974096	et	3	main
riigi	doc_995572625443_item	2974101	et	3	main
kursusi	doc_995572625443_item	2974109	et	3	main
eesti	doc_995572625443_item	2974114	et	4	main
armastus	doc_995572625441_item	2973828	et	4	main
inimeseta	doc_995572625441_item	2973829	et	3	main
on	doc_995572625441_item	2973830	et	4	main
saa	doc_995572625441_item	2973844	et	4	main
elada	doc_995572625441_item	2973845	et	3	main
looduseta	doc_995572625441_item	2973846	et	4	main
ei	doc_995572625442_item	2973859	et	4	main
on	doc_995572625442_item	2973875	et	4	main
kõik	doc_995572625442_item	2973885	et	4	main
ei	doc_995572625442_item	2973888	et	4	main
praegu	doc_995572625442_item	2973893	et	3	main
milleta	doc_995572625442_item	2973894	et	3	main
me	doc_995572625442_item	2973895	et	4	main
ei	doc_995572625442_item	2973896	et	4	main
saa	doc_995572625442_item	2973897	et	4	main
elada	doc_995572625442_item	2973898	et	3	main
ega	doc_995572625442_item	2973899	et	3	main
eksisteerida	doc_995572625442_item	2973900	et	3	main
juba	doc_995572625442_item	2973901	et	3	main
sellepärast	doc_995572625442_item	2973902	et	3	main
et	doc_995572625442_item	2973903	et	3	main
meie	doc_995572625442_item	2973904	et	4	main
vastus	doc_995572625442_item	2973905	et	3	main
sõltub	doc_995572625442_item	2973906	et	3	main
meie	doc_995572625442_item	2973907	et	4	main
elu	doc_995572625442_item	2973908	et	4	main
vaatlustest	doc_995572625442_item	2973909	et	4	main
tingimustest	doc_995572625442_item	2973910	et	3	main
kohe	doc_995572625442_item	2973911	et	4	main
teen	doc_995572625442_item	2973912	et	3	main
näide	doc_995572625442_item	2973913	et	3	main
et	doc_995572625442_item	2973914	et	3	main
kui	doc_995572625442_item	2973915	et	3	main
inimene	doc_995572625442_item	2973916	et	3	main
tahab	doc_995572625442_item	2973917	et	3	main
olla	doc_995572625442_item	2973918	et	3	main
terve	doc_995572625442_item	2973919	et	4	main
tugev	doc_995572625442_item	2973920	et	4	main
siis	doc_995572625442_item	2973921	et	3	main
ta	doc_995572625442_item	2973923	et	4	main
saada	doc_995572625442_item	2973925	et	4	main
toiduga	doc_995572625442_item	2973926	et	3	main
energiat	doc_995572625442_item	2973927	et	3	main
vitamiine	doc_995572625442_item	2973928	et	3	main
kasulike	doc_995572625442_item	2973934	et	3	main
edasi	doc_995572625442_item	2973947	et	3	main
on	doc_995572625442_item	2973953	et	4	main
vaja	doc_995572625442_item	2973954	et	4	main
raha	doc_995572625442_item	2973960	et	4	main
peale	doc_995572625442_item	2973961	et	4	main
teine	doc_995572625442_item	2973966	et	3	main
elu	doc_995572625442_item	2973970	et	4	main
ja	doc_995572625442_item	2973975	et	3	main
on	doc_995572625442_item	2973978	et	4	main
mulle	doc_995572625441_item	2973839	et	4	main
tundub	doc_995572625441_item	2973840	et	3	main
et	doc_995572625441_item	2973841	et	3	main
inimene	doc_995572625441_item	2973842	et	3	main
ei	doc_995572625441_item	2973843	et	4	main
inimesele	doc_995572625441_item	2973849	et	3	main
tuju	doc_995572625441_item	2973853	et	4	main
ja	doc_995572625441_item	2973854	et	3	main
et	doc_995572625442_item	2973865	et	3	main
küsimus	doc_995572625442_item	2973869	et	4	main
oleme	doc_995572625442_item	2973871	et	3	main
oma	doc_995572625442_item	2973880	et	4	main
me	doc_995572625442_item	2973883	et	4	main
oleme	doc_995572625442_item	2973884	et	3	main
ja	doc_995572625442_item	2973933	et	3	main
aineid	doc_995572625442_item	2973935	et	3	main
ta	doc_995572625442_item	2973938	et	4	main
vaatame	doc_995572625442_item	2973946	et	3	main
tuleb	doc_995572625442_item	2973949	et	3	main
et	doc_995572625442_item	2973951	et	3	main
osta	doc_995572625442_item	2973963	et	4	main
et	doc_995572625442_item	2973968	et	3	main
tööd	doc_995572625442_item	2973989	et	4	main
et	doc_995572625442_item	2973993	et	3	main
ta	doc_995572625442_item	2973996	et	4	main
oleks	doc_995572625442_item	2974021	et	3	main
öelda	doc_995572625442_item	2974032	et	4	main
et	doc_995572625442_item	2974033	et	3	main
filosoofiline	doc_995572625442_item	2974048	et	4	main
küsimus	doc_995572625442_item	2974049	et	4	main
vastust	doc_995572625442_item	2974052	et	4	main
arvamusi	doc_995572625442_item	2974062	et	3	main
eesti	doc_995572625443_item	2974067	et	4	main
eesti	doc_995572625443_item	2974080	et	4	main
sa	doc_995572625443_item	2974095	et	3	main
praegu	doc_995572625443_item	2974103	et	3	main
eesti	doc_995572625443_item	2974107	et	4	main
keelt	doc_995572625443_item	2974115	et	4	main
väga	doc_995572625443_item	2974117	et	3	main
nad	doc_995572625443_item	2974119	et	3	main
eesti	doc_995572625443_item	2974142	et	4	main
keelt	doc_995572625443_item	2974143	et	4	main
siis	doc_995572625443_item	2974144	et	3	main
ei	doc_995572625443_item	2974160	et	4	main
õppida	doc_995572625443_item	2974168	et	3	main
eesti	doc_995572625443_item	2974176	et	4	main
et	doc_995572625443_item	2974186	et	3	main
parem	doc_995572625443_item	2974190	et	4	main
koolis	doc_995572625443_item	2974197	et	4	main
keeles	doc_995572625443_item	2974203	et	4	main
teadmist	doc_995572625443_item	2974225	et	4	main
et	doc_995572625443_item	2974228	et	3	main
koolides	doc_995572625443_item	2974230	et	3	main
rohkem	doc_995572625443_item	2974232	et	4	main
eesti	doc_995572625443_item	2974233	et	4	main
on	doc_995572625443_item	2974242	et	4	main
vajalik	doc_995572625443_item	2974249	et	3	main
oli	doc_995572625443_item	2974252	et	3	main
naised	doc_995572625444_item	2974263	et	3	main
on	doc_995572625444_item	2974264	et	4	main
autojuhid	doc_995572625444_item	2974266	et	3	main
kui	doc_995572625444_item	2974267	et	3	main
on	doc_995572625444_item	2974278	et	4	main
ei	doc_995572625444_item	2974317	et	4	main
öelda	doc_995572625442_item	2973892	et	4	main
ja	doc_995572625442_item	2973929	et	3	main
sõnaga	doc_995572625442_item	2973937	et	3	main
ei	doc_995572625442_item	2973939	et	4	main
suuda	doc_995572625442_item	2973940	et	4	main
elada	doc_995572625442_item	2973941	et	3	main
toiduta	doc_995572625442_item	2973942	et	3	main
aga	doc_995572625442_item	2973943	et	3	main
kui	doc_995572625442_item	2973944	et	3	main
ta	doc_995572625442_item	2973957	et	4	main
saaks	doc_995572625442_item	2973958	et	3	main
nüüd	doc_995572625442_item	2973964	et	4	main
tekkib	doc_995572625442_item	2973965	et	3	main
inimese	doc_995572625442_item	2973969	et	4	main
oleneb	doc_995572625442_item	2973971	et	3	main
materiaalsest	doc_995572625442_item	2973973	et	3	main
muidu	doc_995572625442_item	2973976	et	3	main
samal	doc_995572625442_item	2973984	et	3	main
ta	doc_995572625442_item	2973990	et	4	main
see	doc_995572625442_item	2973994	et	3	main
teistele	doc_995572625442_item	2974000	et	4	main
on	doc_995572625442_item	2974003	et	4	main
arst	doc_995572625442_item	2974004	et	3	main
ja	doc_995572625442_item	2974005	et	3	main
ravib	doc_995572625442_item	2974006	et	3	main
haigeid	doc_995572625442_item	2974007	et	3	main
või	doc_995572625442_item	2974008	et	4	main
ta	doc_995572625442_item	2974009	et	4	main
lihtsalt	doc_995572625442_item	2974010	et	4	main
ehitaja	doc_995572625442_item	2974011	et	4	main
see	doc_995572625442_item	2974012	et	3	main
pole	doc_995572625442_item	2974013	et	3	main
tähtis	doc_995572625442_item	2974014	et	4	main
sest	doc_995572625442_item	2974015	et	4	main
oluline	doc_995572625442_item	2974016	et	4	main
on	doc_995572625442_item	2974017	et	4	main
see	doc_995572625442_item	2974018	et	3	main
et	doc_995572625442_item	2974019	et	3	main
inimene	doc_995572625442_item	2974020	et	3	main
tööga	doc_995572625442_item	2974024	et	3	main
sotsiaalselt	doc_995572625442_item	2974026	et	4	main
materiaalselt	doc_995572625442_item	2974028	et	4	main
samuti	doc_995572625442_item	2974029	et	3	main
me	doc_995572625442_item	2974030	et	4	main
inimese	doc_995572625442_item	2974038	et	4	main
ole	doc_995572625442_item	2974054	et	4	main
selle	doc_995572625442_item	2974063	et	4	main
kohta	doc_995572625442_item	2974064	et	4	main
et	doc_995572625443_item	2974071	et	3	main
oleks	doc_995572625443_item	2974073	et	3	main
kõikjal	doc_995572625443_item	2974075	et	3	main
koolidel	doc_995572625443_item	2974077	et	3	main
oleks	doc_995572625443_item	2974079	et	3	main
kergem	doc_995572625443_item	2974088	et	4	main
kui	doc_995572625443_item	2974094	et	3	main
eestis	doc_995572625443_item	2974097	et	3	main
keele	doc_995572625443_item	2974108	et	4	main
need	doc_995572625443_item	2974111	et	3	main
tahavad	doc_995572625443_item	2974113	et	3	main
hästi	doc_995572625443_item	2974118	et	3	main
külastavad	doc_995572625443_item	2974120	et	4	main
need	doc_995572625443_item	2974121	et	3	main
ennekõike	doc_995572625443_item	2974133	et	3	main
suhtlemine	doc_995572625443_item	2974136	et	4	main
kui	doc_995572625443_item	2974138	et	3	main
töö	doc_995572625442_item	2973979	et	4	main
tööl	doc_995572625442_item	2973980	et	3	main
ta	doc_995572625442_item	2973986	et	4	main
naudib	doc_995572625442_item	2973987	et	3	main
oma	doc_995572625442_item	2973988	et	4	main
rahuldustunde	doc_995572625442_item	2973992	et	4	main
teeb	doc_995572625442_item	2973997	et	3	main
annab	doc_995572625442_item	2973998	et	3	main
ta	doc_995572625442_item	2974002	et	4	main
võime	doc_995572625442_item	2974031	et	4	main
tunnistus	doc_995572625442_item	2974039	et	4	main
ja	doc_995572625442_item	2974040	et	3	main
ja	doc_995572625442_item	2974050	et	3	main
keeles	doc_995572625443_item	2974068	et	4	main
et	doc_995572625443_item	2974074	et	3	main
mulle	doc_995572625443_item	2974083	et	4	main
tundub	doc_995572625443_item	2974084	et	3	main
et	doc_995572625443_item	2974085	et	3	main
nii	doc_995572625443_item	2974086	et	3	main
sa	doc_995572625443_item	2974098	et	3	main
oskama	doc_995572625443_item	2974100	et	3	main
keelt	doc_995572625443_item	2974102	et	4	main
on	doc_995572625443_item	2974104	et	4	main
nii	doc_995572625443_item	2974105	et	3	main
palju	doc_995572625443_item	2974106	et	4	main
ja	doc_995572625443_item	2974110	et	3	main
kes	doc_995572625443_item	2974112	et	4	main
oska	doc_995572625443_item	2974116	et	4	main
ei	doc_995572625443_item	2974125	et	4	main
aita	doc_995572625443_item	2974126	et	4	main
kui	doc_995572625443_item	2974127	et	3	main
sa	doc_995572625443_item	2974128	et	3	main
tahad	doc_995572625443_item	2974129	et	3	main
täiesti	doc_995572625443_item	2974130	et	3	main
vajalik	doc_995572625443_item	2974135	et	3	main
sellepärast	doc_995572625443_item	2974137	et	3	main
tuleb	doc_995572625443_item	2974141	et	3	main
oma	doc_995572625443_item	2974149	et	4	main
muidugi	doc_995572625443_item	2974152	et	4	main
esialgu	doc_995572625443_item	2974153	et	3	main
tuleb	doc_995572625443_item	2974154	et	3	main
raske	doc_995572625443_item	2974156	et	4	main
ja	doc_995572625443_item	2974169	et	3	main
õppimiskeel	doc_995572625443_item	2974174	et	4	main
on	doc_995572625443_item	2974175	et	4	main
on	doc_995572625443_item	2974180	et	4	main
see	doc_995572625443_item	2974187	et	3	main
keelt	doc_995572625443_item	2974193	et	4	main
millal	doc_995572625443_item	2974194	et	3	main
õppisin	doc_995572625443_item	2974196	et	3	main
meil	doc_995572625443_item	2974198	et	4	main
keele	doc_995572625443_item	2974206	et	4	main
saada	doc_995572625443_item	2974221	et	4	main
tean	doc_995572625443_item	2974227	et	3	main
on	doc_995572625443_item	2974231	et	4	main
lastel	doc_995572625443_item	2974237	et	4	main
on	doc_995572625443_item	2974238	et	4	main
eesti	doc_995572625443_item	2974239	et	4	main
kui	doc_995572625443_item	2974244	et	3	main
minu	doc_995572625443_item	2974245	et	3	main
et	doc_995572625443_item	2974247	et	3	main
et	doc_995572625443_item	2974250	et	3	main
seadustega	doc_995572625443_item	2974251	et	3	main
kehtestatud	doc_995572625443_item	2974253	et	4	main
eesti	doc_995572625443_item	2974254	et	4	main
autojuhid	doc_995572625444_item	2974260	et	3	main
pärast	doc_995572625444_item	2974275	et	4	main
et	doc_995572625444_item	2974276	et	3	main
nad	doc_995572625444_item	2974277	et	3	main
palju	doc_995572625444_item	2974280	et	4	main
saa	doc_995572625444_item	2974318	et	4	main
ainult	doc_995572625444_item	2974330	et	4	main
saavad	doc_995572625444_item	2974333	et	4	main
probleemi	doc_995572625444_item	2974335	et	4	main
see	doc_995572625444_item	2974338	et	3	main
ei	doc_995572625444_item	2974339	et	4	main
ole	doc_995572625444_item	2974340	et	4	main
nii	doc_995572625444_item	2974341	et	3	main
autojuhid	doc_995572625444_item	2974346	et	3	main
minu	doc_995572625445_item	2974360	et	3	main
tähtis	doc_995572625445_item	2974365	et	4	main
pärast	doc_995572625445_item	2974377	et	4	main
rahulik	doc_995572625442_item	2974022	et	3	main
oma	doc_995572625442_item	2974023	et	4	main
nii	doc_995572625442_item	2974025	et	3	main
inimesel	doc_995572625442_item	2974034	et	3	main
oleks	doc_995572625442_item	2974035	et	3	main
armastus	doc_995572625442_item	2974036	et	4	main
teise	doc_995572625442_item	2974037	et	4	main
on	doc_995572625442_item	2974047	et	4	main
ei	doc_995572625442_item	2974053	et	4	main
selle	doc_995572625442_item	2974055	et	4	main
küsimuse	doc_995572625442_item	2974056	et	4	main
peale	doc_995572625442_item	2974057	et	4	main
sest	doc_995572625442_item	2974058	et	4	main
on	doc_995572625442_item	2974059	et	4	main
väga	doc_995572625442_item	2974060	et	3	main
palju	doc_995572625442_item	2974061	et	4	main
vene	doc_995572625443_item	2974065	et	4	main
ma	doc_995572625443_item	2974069	et	3	main
keelt	doc_995572625443_item	2974081	et	4	main
sest	doc_995572625443_item	2974082	et	4	main
õppida	doc_995572625443_item	2974089	et	3	main
minu	doc_995572625443_item	2974091	et	3	main
arvamus	doc_995572625443_item	2974092	et	3	main
pead	doc_995572625443_item	2974099	et	4	main
kui	doc_995572625443_item	2974123	et	3	main
on	doc_995572625443_item	2974134	et	4	main
neil	doc_995572625443_item	2974159	et	4	main
tulen	doc_995572625443_item	2974167	et	3	main
rõõmus	doc_995572625443_item	2974171	et	4	main
siin	doc_995572625443_item	2974173	et	4	main
aitab	doc_995572625443_item	2974188	et	3	main
mulle	doc_995572625443_item	2974189	et	4	main
oska	doc_995572625443_item	2974191	et	4	main
eesti	doc_995572625443_item	2974192	et	4	main
kõik	doc_995572625443_item	2974199	et	4	main
tunnid	doc_995572625443_item	2974200	et	3	main
olid	doc_995572625443_item	2974201	et	4	main
eesti	doc_995572625443_item	2974205	et	4	main
kursused	doc_995572625443_item	2974122	et	3	main
see	doc_995572625443_item	2974124	et	3	main
õppida	doc_995572625443_item	2974131	et	3	main
keelt	doc_995572625443_item	2974132	et	4	main
lastele	doc_995572625443_item	2974145	et	4	main
tuleb	doc_995572625443_item	2974146	et	3	main
eesti	doc_995572625443_item	2974150	et	4	main
tule	doc_995572625443_item	2974161	et	4	main
probleemi	doc_995572625443_item	2974162	et	4	main
tööga	doc_995572625443_item	2974163	et	3	main
ja	doc_995572625443_item	2974164	et	3	main
et	doc_995572625443_item	2974172	et	3	main
keelt	doc_995572625443_item	2974177	et	4	main
praegu	doc_995572625443_item	2974178	et	3	main
mul	doc_995572625443_item	2974179	et	3	main
väga	doc_995572625443_item	2974181	et	3	main
arvan	doc_995572625443_item	2974185	et	3	main
ja	doc_995572625443_item	2974204	et	3	main
tund	doc_995572625443_item	2974207	et	3	main
kaks	doc_995572625443_item	2974209	et	3	main
oli	doc_995572625443_item	2974208	et	3	main
korda	doc_995572625443_item	2974210	et	4	main
nädalas	doc_995572625443_item	2974211	et	3	main
ma	doc_995572625443_item	2974212	et	3	main
tean	doc_995572625443_item	2974213	et	3	main
et	doc_995572625443_item	2974214	et	3	main
see	doc_995572625443_item	2974215	et	3	main
on	doc_995572625443_item	2974216	et	4	main
väga	doc_995572625443_item	2974217	et	3	main
vähe	doc_995572625443_item	2974218	et	3	main
ja	doc_995572625443_item	2974219	et	3	main
ebareaalne	doc_995572625443_item	2974220	et	3	main
head	doc_995572625443_item	2974222	et	4	main
ja	doc_995572625443_item	2974236	et	3	main
tase	doc_995572625443_item	2974241	et	3	main
arvamus	doc_995572625443_item	2974246	et	3	main
on	doc_995572625443_item	2974248	et	4	main
keele	doc_995572625443_item	2974255	et	4	main
kui	doc_995572625444_item	2974261	et	3	main
ma	doc_995572625444_item	2974269	et	3	main
olen	doc_995572625444_item	2974270	et	3	main
kiirust	doc_995572625444_item	2974316	et	4	main
ajal	doc_995572625444_item	2974328	et	4	main
sõidusest	doc_995572625444_item	2974331	et	4	main
parkemisega	doc_995572625444_item	2974336	et	3	main
p	doc_995572625444_item	2974355	et	4	main
näen	doc_995572625445_item	2974357	et	3	main
päeva	doc_995572625445_item	2974379	et	4	main
puhkama	doc_995572625445_item	2974380	et	3	main
lähen	doc_995572625445_item	2974381	et	3	main
iga	doc_995572625445_item	2974382	et	4	main
selline	doc_995572625445_item	2974386	et	4	main
ma	doc_995572625445_item	2974395	et	3	main
kõige	doc_995572625445_item	2974398	et	4	main
elu	doc_995572625445_item	2974400	et	4	main
kuhu	doc_995572625445_item	2974411	et	3	main
töölt	doc_995572625445_item	2974412	et	3	main
peakski	doc_995572625445_item	2974415	et	4	main
koolides	doc_995572625443_item	2974139	et	3	main
õppimiskeelt	doc_995572625443_item	2974140	et	4	main
kergem	doc_995572625443_item	2974147	et	4	main
täiendada	doc_995572625443_item	2974148	et	3	main
keeleteadmist	doc_995572625443_item	2974151	et	3	main
väga	doc_995572625443_item	2974155	et	3	main
kuid	doc_995572625443_item	2974157	et	4	main
tulevikus	doc_995572625443_item	2974158	et	4	main
suhtlemisega	doc_995572625443_item	2974165	et	4	main
ma	doc_995572625443_item	2974166	et	3	main
väga	doc_995572625443_item	2974170	et	3	main
raske	doc_995572625443_item	2974182	et	4	main
kui	doc_995572625443_item	2974183	et	3	main
ma	doc_995572625443_item	2974184	et	3	main
ma	doc_995572625443_item	2974195	et	3	main
vene	doc_995572625443_item	2974202	et	4	main
ma	doc_995572625443_item	2974226	et	3	main
praegu	doc_995572625443_item	2974229	et	3	main
tundi	doc_995572625443_item	2974235	et	4	main
kõrgem	doc_995572625443_item	2974243	et	4	main
mehed	doc_995572625444_item	2974262	et	3	main
paremad	doc_995572625444_item	2974265	et	4	main
mehed	doc_995572625444_item	2974268	et	3	main
nõus	doc_995572625444_item	2974271	et	4	main
sellega	doc_995572625444_item	2974272	et	3	main
väitega	doc_995572625444_item	2974273	et	3	main
selle	doc_995572625444_item	2974274	et	4	main
ettevatlikud	doc_995572625444_item	2974279	et	4	main
ületa	doc_995572625444_item	2974315	et	4	main
vigastada	doc_995572625444_item	2974319	et	3	main
raagi	doc_995572625444_item	2974321	et	4	main
ei	doc_995572625444_item	2974323	et	4	main
suitsuta	doc_995572625444_item	2974324	et	4	main
autos	doc_995572625444_item	2974325	et	3	main
ja	doc_995572625444_item	2974326	et	3	main
sõidu	doc_995572625444_item	2974327	et	3	main
on	doc_995572625444_item	2974344	et	4	main
staatistika	doc_995572625444_item	2974348	et	4	main
on	doc_995572625444_item	2974351	et	4	main
vähem	doc_995572625444_item	2974352	et	4	main
kodu	doc_995572625445_item	2974362	et	4	main
üks	doc_995572625445_item	2974363	et	3	main
kuhu	doc_995572625445_item	2974374	et	3	main
ma	doc_995572625445_item	2974375	et	3	main
inimese	doc_995572625445_item	2974383	et	4	main
tulla	doc_995572625445_item	2974394	et	3	main
tulevikukodu	doc_995572625445_item	2974414	et	4	main
selline	doc_995572625445_item	2974416	et	4	main
seal	doc_995572625445_item	2974418	et	4	main
olema	doc_995572625445_item	2974427	et	4	main
naine	doc_995572625445_item	2974428	et	3	main
lapsed	doc_995572625445_item	2974431	et	3	main
ja	doc_995572625445_item	2974437	et	3	main
jaoks	doc_995572625445_item	2974446	et	4	main
on	doc_995572625445_item	2974447	et	4	main
kodutöid	doc_995572625445_item	2974455	et	3	main
peab	doc_995572625445_item	2974458	et	4	main
selline	doc_995572625445_item	2974460	et	4	main
on	doc_995572625445_item	2974463	et	4	main
rõõmu	doc_995572625445_item	2974471	et	4	main
on	doc_995572625445_item	2974476	et	4	main
kõik	doc_995572625446_item	2974483	et	4	main
ma	doc_995572625446_item	2974489	et	3	main
on	doc_995572625446_item	2974493	et	4	main
ajast	doc_995572625446_item	2974500	et	4	main
et	doc_995572625446_item	2974505	et	3	main
eesti	doc_995572625443_item	2974223	et	4	main
keele	doc_995572625443_item	2974224	et	4	main
keele	doc_995572625443_item	2974234	et	4	main
keele	doc_995572625443_item	2974240	et	4	main
õppimiskeelt	doc_995572625443_item	2974256	et	4	main
naised	doc_995572625444_item	2974257	et	3	main
on	doc_995572625444_item	2974258	et	4	main
paremad	doc_995572625444_item	2974259	et	4	main
mehed	doc_995572625444_item	2974281	et	3	main
räägivad	doc_995572625444_item	2974282	et	3	main
telefoniga	doc_995572625444_item	2974283	et	4	main
suitsetavad	doc_995572625444_item	2974284	et	4	main
teevad	doc_995572625444_item	2974285	et	3	main
oma	doc_995572625444_item	2974286	et	4	main
asi	doc_995572625444_item	2974287	et	4	main
sõidu	doc_995572625444_item	2974288	et	3	main
ajal	doc_995572625444_item	2974289	et	4	main
mis	doc_995572625444_item	2974290	et	4	main
võib	doc_995572625444_item	2974291	et	3	main
olla	doc_995572625444_item	2974292	et	3	main
avarii	doc_995572625444_item	2974293	et	4	main
põhjus	doc_995572625444_item	2974294	et	4	main
mehed	doc_995572625444_item	2974295	et	3	main
armastavad	doc_995572625444_item	2974296	et	4	main
suure	doc_995572625444_item	2974297	et	3	main
kiirega	doc_995572625444_item	2974298	et	4	main
sõita	doc_995572625444_item	2974299	et	3	main
mis	doc_995572625444_item	2974300	et	4	main
on	doc_995572625444_item	2974301	et	4	main
väga	doc_995572625444_item	2974302	et	3	main
ohtlik	doc_995572625444_item	2974303	et	3	main
ka	doc_995572625444_item	2974304	et	3	main
naisega	doc_995572625444_item	2974305	et	3	main
on	doc_995572625444_item	2974306	et	4	main
teine	doc_995572625444_item	2974307	et	3	main
lugu	doc_995572625444_item	2974308	et	4	main
naised	doc_995572625444_item	2974309	et	3	main
alati	doc_995572625444_item	2974310	et	4	main
ettevatlikud	doc_995572625444_item	2974311	et	4	main
teel	doc_995572625444_item	2974312	et	4	main
nad	doc_995572625444_item	2974313	et	3	main
ei	doc_995572625444_item	2974314	et	4	main
ei	doc_995572625444_item	2974320	et	4	main
mõtlevad	doc_995572625444_item	2974329	et	4	main
mõnikord	doc_995572625444_item	2974332	et	3	main
head	doc_995572625444_item	2974345	et	4	main
järgi	doc_995572625444_item	2974349	et	4	main
naisel	doc_995572625444_item	2974350	et	3	main
teel	doc_995572625444_item	2974354	et	4	main
millisena	doc_995572625445_item	2974356	et	3	main
väga	doc_995572625445_item	2974364	et	3	main
ma	doc_995572625445_item	2974368	et	3	main
rahus	doc_995572625445_item	2974370	et	4	main
saan	doc_995572625445_item	2974372	et	4	main
ja	doc_995572625445_item	2974373	et	3	main
kodu	doc_995572625445_item	2974384	et	4	main
olema	doc_995572625445_item	2974387	et	4	main
kuhu	doc_995572625445_item	2974388	et	3	main
õhtu	doc_995572625445_item	2974392	et	4	main
töölt	doc_995572625445_item	2974393	et	3	main
peaks	doc_995572625445_item	2974419	et	4	main
mees	doc_995572625445_item	2974429	et	4	main
ja	doc_995572625445_item	2974430	et	3	main
tulles	doc_995572625445_item	2974434	et	4	main
olemema	doc_995572625445_item	2974441	et	4	main
hubane	doc_995572625445_item	2974442	et	3	main
ja	doc_995572625445_item	2974443	et	3	main
mugav	doc_995572625445_item	2974444	et	3	main
selle	doc_995572625445_item	2974445	et	4	main
juba	doc_995572625445_item	2974448	et	3	main
kes	doc_995572625445_item	2974454	et	4	main
asjad	doc_995572625445_item	2974469	et	3	main
mis	doc_995572625445_item	2974470	et	4	main
vaatavad	doc_995572625446_item	2974484	et	4	main
natuke	doc_995572625446_item	2974487	et	4	main
arvan	doc_995572625446_item	2974490	et	3	main
reklaami	doc_995572625446_item	2974499	et	4	main
paljud	doc_995572625446_item	2974522	et	3	main
ükskõik	doc_995572625446_item	2974529	et	3	main
aga	doc_995572625446_item	2974530	et	3	main
ikka	doc_995572625446_item	2974531	et	4	main
kui	doc_995572625446_item	2974532	et	3	main
külmkappi	doc_995572625446_item	2974545	et	4	main
coca-cola	doc_995572625446_item	2974546	et	4	main
õlu	doc_995572625446_item	2974551	et	3	main
lehmaga	doc_995572625446_item	2974553	et	3	main
piim	doc_995572625446_item	2974555	et	3	main
aga	doc_995572625446_item	2974561	et	3	main
on	doc_995572625446_item	2974564	et	4	main
näiteks	doc_995572625446_item	2974568	et	4	main
coca-colat	doc_995572625446_item	2974572	et	4	main
nesteat	doc_995572625446_item	2974574	et	4	main
on	doc_995572625446_item	2974575	et	4	main
ka	doc_995572625446_item	2974578	et	3	main
ma	doc_995572625446_item	2974580	et	3	main
et	doc_995572625446_item	2974583	et	3	main
parem	doc_995572625446_item	2974592	et	4	main
on	doc_995572625446_item	2974601	et	4	main
inimestel	doc_995572625446_item	2974610	et	3	main
on	doc_995572625446_item	2974615	et	4	main
raskem	doc_995572625446_item	2974617	et	4	main
kui	doc_995572625446_item	2974622	et	3	main
viru	doc_995572625446_item	2974628	et	4	main
coolerit	doc_995572625446_item	2974629	et	4	main
söövad	doc_995572625446_item	2974630	et	4	main
on	doc_995572625446_item	2974637	et	4	main
seda	doc_995572625446_item	2974647	et	3	main
stiili	doc_995572625446_item	2974648	et	4	main
meie	doc_995572625446_item	2974649	et	4	main
kultuuriloo	doc_553383122817_item	2974669	et	4	main
mis	doc_553383122817_item	2974681	et	4	main
esimesest	doc_553383122817_item	2974682	et	3	main
erinevad	doc_553383122817_item	2974685	et	4	main
milline	doc_553383122817_item	2974690	et	3	main
on	doc_553383122817_item	2974693	et	4	main
ja	doc_553383122817_item	2974695	et	3	main
kas	doc_553383122817_item	2974696	et	3	main
see	doc_553383122817_item	2974698	et	3	main
vajalik	doc_553383122817_item	2974701	et	3	main
ajal	doc_553383122817_item	2974702	et	4	main
kui	doc_553383122817_item	2974703	et	3	main
inimestel	doc_553383122817_item	2974704	et	3	main
diskoõhtud	doc_553383122817_item	2974709	et	3	main
kui	doc_553383122817_item	2974713	et	3	main
telefoniga	doc_995572625444_item	2974322	et	4	main
olla	doc_995572625444_item	2974334	et	3	main
aga	doc_995572625444_item	2974337	et	3	main
oluline	doc_995572625444_item	2974342	et	4	main
naised	doc_995572625444_item	2974343	et	3	main
ja	doc_995572625444_item	2974347	et	3	main
avarii	doc_995572625444_item	2974353	et	4	main
tuleviku	doc_995572625445_item	2974358	et	4	main
kodu	doc_995572625445_item	2974359	et	4	main
jaoks	doc_995572625445_item	2974361	et	4	main
koht	doc_995572625445_item	2974366	et	3	main
kus	doc_995572625445_item	2974367	et	3	main
alati	doc_995572625445_item	2974369	et	4	main
olla	doc_995572625445_item	2974371	et	3	main
alati	doc_995572625445_item	2974376	et	4	main
peab	doc_995572625445_item	2974385	et	4	main
ta	doc_995572625445_item	2974389	et	4	main
tahaks	doc_995572625445_item	2974390	et	3	main
iga	doc_995572625445_item	2974391	et	4	main
et	doc_995572625445_item	2974397	et	3	main
parem	doc_995572625445_item	2974399	et	4	main
on	doc_995572625445_item	2974401	et	4	main
siis	doc_995572625445_item	2974402	et	3	main
kui	doc_995572625445_item	2974403	et	3	main
olema	doc_995572625445_item	2974417	et	4	main
harmoonia	doc_995572625445_item	2974421	et	4	main
rahu	doc_995572625445_item	2974423	et	4	main
veel	doc_995572625445_item	2974424	et	4	main
peaks	doc_995572625445_item	2974425	et	4	main
kodus	doc_995572625445_item	2974435	et	4	main
lemmikloom	doc_995572625445_item	2974438	et	3	main
peab	doc_995572625445_item	2974440	et	4	main
erinevaid	doc_995572625445_item	2974450	et	4	main
teevad	doc_995572625445_item	2974456	et	3	main
kodu	doc_995572625445_item	2974457	et	4	main
olema	doc_995572625445_item	2974459	et	4	main
on	doc_995572625445_item	2974468	et	4	main
tähtsad	doc_995572625445_item	2974475	et	3	main
inimeste	doc_995572625446_item	2974477	et	3	main
mõjutab	doc_995572625446_item	2974479	et	3	main
et	doc_995572625446_item	2974491	et	3	main
enamuse	doc_995572625446_item	2974498	et	4	main
isegi	doc_995572625446_item	2974506	et	4	main
lapsed	doc_995572625446_item	2974508	et	3	main
et	doc_995572625446_item	2974510	et	3	main
coca-cola	doc_995572625446_item	2974511	et	4	main
rõõm-	doc_995572625446_item	2974521	et	3	main
öelda	doc_995572625446_item	2974524	et	4	main
nendele	doc_995572625446_item	2974526	et	4	main
on	doc_995572625446_item	2974527	et	4	main
vahest	doc_995572625446_item	2974536	et	4	main
ta	doc_995572625446_item	2974537	et	4	main
pudel	doc_995572625446_item	2974552	et	3	main
rolton	doc_995572625446_item	2974558	et	4	main
tähele	doc_995572625446_item	2974565	et	3	main
prismas	doc_995572625446_item	2974569	et	3	main
aurat	doc_995572625446_item	2974571	et	3	main
joogid	doc_995572625446_item	2974577	et	4	main
tundmatu	doc_995572625446_item	2974599	et	4	main
reklaam	doc_995572625446_item	2974600	et	3	main
ühest	doc_995572625446_item	2974607	et	4	main
see	doc_995572625446_item	2974612	et	3	main
meelde	doc_995572625446_item	2974613	et	3	main
et	doc_995572625446_item	2974621	et	3	main
joovad	doc_995572625446_item	2974624	et	4	main
marlborot	doc_995572625446_item	2974634	et	4	main
paljud	doc_995572625446_item	2974645	et	3	main
inimesi	doc_995572625446_item	2974654	et	4	main
sissejuhatus	doc_553383122817_item	2974671	et	4	main
on	doc_553383122817_item	2974675	et	4	main
mis	doc_553383122817_item	2974687	et	4	main
tänapäevaelus	doc_553383122817_item	2974694	et	4	main
nüüdisajal	doc_553383122817_item	2974697	et	3	main
internet	doc_553383122817_item	2974706	et	4	main
ööklubid	doc_553383122817_item	2974711	et	3	main
ajal	doc_553383122817_item	2974712	et	4	main
valla	doc_553383122817_item	2974735	et	4	main
läbi	doc_553383122817_item	2974738	et	4	main
harku	doc_553383122817_item	2974741	et	4	main
oma	doc_553383122817_item	2974746	et	4	main
tänapäeval	doc_553383122817_item	2974769	et	3	main
elukommete	doc_553383122817_item	2974782	et	4	main
on	doc_553383122817_item	2974788	et	4	main
rasket	doc_995572625445_item	2974378	et	3	main
leian	doc_995572625445_item	2974396	et	3	main
on	doc_995572625445_item	2974404	et	4	main
töö	doc_995572625445_item	2974405	et	4	main
kuhu	doc_995572625445_item	2974406	et	3	main
tahad	doc_995572625445_item	2974407	et	3	main
minna	doc_995572625445_item	2974408	et	3	main
ja	doc_995572625445_item	2974409	et	3	main
kodu	doc_995572625445_item	2974410	et	4	main
tulla	doc_995572625445_item	2974413	et	3	main
valitsema	doc_995572625445_item	2974420	et	3	main
ja	doc_995572625445_item	2974422	et	3	main
kes	doc_995572625445_item	2974432	et	4	main
ootaks	doc_995572625445_item	2974436	et	3	main
isegi	doc_995572625445_item	2974449	et	4	main
roboteid	doc_995572625445_item	2974451	et	3	main
mõeldud	doc_995572625445_item	2974453	et	4	main
koht	doc_995572625445_item	2974461	et	3	main
pakuvad	doc_995572625445_item	2974472	et	3	main
ning	doc_995572625445_item	2974473	et	3	main
kõige	doc_995572625446_item	2974480	et	4	main
rohkem	doc_995572625446_item	2974481	et	4	main
reklaam	doc_995572625446_item	2974482	et	3	main
vähemalt	doc_995572625446_item	2974486	et	4	main
ja	doc_995572625446_item	2974488	et	3	main
kõik	doc_995572625446_item	2974492	et	4	main
märkanud	doc_995572625446_item	2974494	et	4	main
et	doc_995572625446_item	2974495	et	3	main
meie	doc_995572625446_item	2974496	et	4	main
võtab	doc_995572625446_item	2974501	et	3	main
toidureklaam	doc_995572625446_item	2974502	et	3	main
ma	doc_995572625446_item	2974503	et	3	main
arvan	doc_995572625446_item	2974504	et	3	main
väiksed	doc_995572625446_item	2974507	et	4	main
teavad	doc_995572625446_item	2974509	et	3	main
on	doc_995572625446_item	2974512	et	4	main
nauding	doc_995572625446_item	2974513	et	3	main
võivad	doc_995572625446_item	2974523	et	4	main
et	doc_995572625446_item	2974525	et	3	main
inimene	doc_995572625446_item	2974533	et	3	main
läheb	doc_995572625446_item	2974534	et	3	main
poodi	doc_995572625446_item	2974535	et	4	main
pea	doc_995572625446_item	2974539	et	4	main
isegi	doc_995572625446_item	2974540	et	4	main
kaubanimesi	doc_995572625446_item	2974541	et	4	main
loema	doc_995572625446_item	2974542	et	4	main
näed	doc_995572625446_item	2974543	et	3	main
sinine	doc_995572625446_item	2974548	et	4	main
saku	doc_995572625446_item	2974550	et	4	main
alma	doc_995572625446_item	2974554	et	4	main
kollased	doc_995572625446_item	2974556	et	4	main
pakkid	doc_995572625446_item	2974557	et	4	main
kas	doc_995572625446_item	2974562	et	3	main
pandud	doc_995572625446_item	2974566	et	4	main
peale	doc_995572625446_item	2974570	et	4	main
et	doc_995572625446_item	2974590	et	3	main
rakvere	doc_995572625446_item	2974594	et	4	main
mingid	doc_995572625446_item	2974597	et	4	main
teised	doc_995572625446_item	2974598	et	4	main
ainult	doc_995572625446_item	2974606	et	4	main
jääb	doc_995572625446_item	2974611	et	3	main
noortel	doc_995572625446_item	2974614	et	3	main
veel	doc_995572625446_item	2974616	et	4	main
13-15aastased	doc_995572625446_item	2974618	et	4	main
nad	doc_995572625446_item	2974623	et	3	main
snikersi	doc_995572625446_item	2974631	et	4	main
ja	doc_995572625446_item	2974632	et	3	main
siis	doc_995572625446_item	2974635	et	3	main
nad	doc_995572625446_item	2974636	et	3	main
jumala	doc_995572625446_item	2974638	et	3	main
kõva	doc_995572625446_item	2974639	et	4	main
ajal	doc_995572625446_item	2974650	et	4	main
on	doc_995572625446_item	2974651	et	4	main
väga	doc_995572625446_item	2974652	et	3	main
vähe	doc_995572625446_item	2974653	et	3	main
mida	doc_995572625446_item	2974660	et	4	main
tema	doc_995572625446_item	2974661	et	4	main
tahab	doc_995572625446_item	2974662	et	3	main
kodus	doc_995572625445_item	2974426	et	4	main
töölt	doc_995572625445_item	2974433	et	3	main
tulevikukodu	doc_995572625445_item	2974439	et	4	main
välja	doc_995572625445_item	2974452	et	4	main
mis	doc_995572625445_item	2974462	et	4	main
ise	doc_995572625445_item	2974464	et	4	main
kujundatud	doc_995572625445_item	2974465	et	4	main
ja	doc_995572625445_item	2974466	et	3	main
kus	doc_995572625445_item	2974467	et	3	main
mis	doc_995572625445_item	2974474	et	4	main
toitumisharjumuis	doc_995572625446_item	2974478	et	3	main
telerit	doc_995572625446_item	2974485	et	3	main
ajal	doc_995572625446_item	2974497	et	4	main
orbiti	doc_995572625446_item	2974514	et	4	main
soovitavad	doc_995572625446_item	2974515	et	4	main
hambaarstid	doc_995572625446_item	2974516	et	3	main
ja	doc_995572625446_item	2974517	et	3	main
jägermeister	doc_995572625446_item	2974518	et	4	main
on	doc_995572625446_item	2974519	et	4	main
jagatud	doc_995572625446_item	2974520	et	4	main
kast	doc_995572625446_item	2974549	et	3	main
jne	doc_995572625446_item	2974560	et	4	main
paljud	doc_995572625446_item	2974563	et	3	main
ja	doc_995572625446_item	2974573	et	3	main
usu	doc_995572625446_item	2974582	et	4	main
inimene	doc_995572625446_item	2974591	et	3	main
ostaks	doc_995572625446_item	2974593	et	3	main
viinerid	doc_995572625446_item	2974595	et	3	main
nagu	doc_995572625446_item	2974602	et	3	main
õppik	doc_995572625446_item	2974603	et	4	main
ta	doc_995572625446_item	2974604	et	4	main
räägib	doc_995572625446_item	2974605	et	3	main
ja	doc_995572625446_item	2974609	et	3	main
reklaamid	doc_995572625446_item	2974528	et	4	main
ei	doc_995572625446_item	2974538	et	4	main
punast	doc_995572625446_item	2974544	et	4	main
tooteid	doc_995572625446_item	2974547	et	4	main
makaroonid	doc_995572625446_item	2974559	et	4	main
et	doc_995572625446_item	2974567	et	3	main
teised	doc_995572625446_item	2974576	et	4	main
olemas	doc_995572625446_item	2974579	et	4	main
ei	doc_995572625446_item	2974581	et	4	main
kõik	doc_995572625446_item	2974584	et	4	main
sellest	doc_995572625446_item	2974585	et	4	main
teavad	doc_995572625446_item	2974586	et	3	main
ja	doc_995572625446_item	2974587	et	3	main
ma	doc_995572625446_item	2974588	et	3	main
arvan	doc_995572625446_item	2974589	et	3	main
kui	doc_995572625446_item	2974596	et	3	main
kaubast	doc_995572625446_item	2974608	et	4	main
poissid	doc_995572625446_item	2974619	et	4	main
arvavad	doc_995572625446_item	2974620	et	4	main
bulli	doc_995572625446_item	2974626	et	4	main
mehed	doc_995572625446_item	2974640	et	3	main
reklaam	doc_995572625446_item	2974641	et	3	main
stiili	doc_995572625446_item	2974643	et	4	main
ja	doc_995572625446_item	2974644	et	3	main
ise	doc_995572625446_item	2974657	et	4	main
valida	doc_995572625446_item	2974658	et	3	main
eesti	doc_553383122817_item	2974668	et	4	main
töö	doc_553383122817_item	2974673	et	4	main
teemaks	doc_553383122817_item	2974674	et	4	main
pilgust	doc_553383122817_item	2974683	et	4	main
nii	doc_553383122817_item	2974684	et	3	main
on	doc_553383122817_item	2974688	et	4	main
tal	doc_553383122817_item	2974692	et	3	main
on	doc_553383122817_item	2974699	et	4	main
üldse	doc_553383122817_item	2974700	et	3	main
igasugused	doc_553383122817_item	2974708	et	3	main
inimesed	doc_553383122817_item	2974714	et	3	main
ühes	doc_553383122817_item	2974721	et	4	main
nende	doc_553383122817_item	2974728	et	4	main
naaber	doc_553383122817_item	2974729	et	3	main
on	doc_553383122817_item	2974730	et	4	main
rikkas	doc_553383122817_item	2974745	et	4	main
nendel	doc_553383122817_item	2974768	et	4	main
oma	doc_553383122817_item	2974776	et	4	main
rahvajuttude	doc_553383122817_item	2974777	et	4	main
mingite	doc_553383122817_item	2974779	et	4	main
minevikul	doc_553383122817_item	2974780	et	3	main
esinenud	doc_553383122817_item	2974781	et	4	main
seal	doc_553383122817_item	2974787	et	4	main
kui	doc_553383122817_item	2974801	et	3	main
kodukohale	doc_553383122817_item	2974815	et	4	main
mida	doc_553383122817_item	2974821	et	4	main
tänapäeval	doc_553383122817_item	2974824	et	3	main
haaras	doc_553383122817_item	2974872	et	4	main
enda	doc_553383122817_item	2974873	et	4	main
tiskre	doc_553383122817_item	2974883	et	4	main
kakumäe	doc_553383122817_item	2974884	et	3	main
õismäe	doc_553383122817_item	2974885	et	3	main
taastati	doc_553383122817_item	2974893	et	4	main
21	doc_553383122817_item	2974894	et	2	main
novembril	doc_553383122817_item	2974895	et	3	main
aastal	doc_553383122817_item	2974897	et	3	main
tabasalu	doc_553383122817_item	2974901	et	4	main
ja	doc_553383122817_item	2974902	et	3	main
harku	doc_553383122817_item	2974903	et	4	main
liikva	doc_553383122817_item	2974911	et	4	main
kütke	doc_553383122817_item	2974917	et	4	main
türisalu	doc_553383122817_item	2974920	et	4	main
vääna-	doc_553383122817_item	2974922	et	4	main
jõesuu	doc_553383122817_item	2974923	et	4	main
ilmandu	doc_553383122817_item	2974928	et	4	main
soositud	doc_553383122817_item	2974936	et	4	main
elu-	doc_553383122817_item	2974937	et	4	main
ja	doc_553383122817_item	2974938	et	3	main
paiknevad	doc_553383122817_item	2974968	et	4	main
kumna	doc_553383122817_item	2974971	et	4	main
vana-	doc_553383122817_item	2974975	et	4	main
vääna	doc_553383122817_item	2974980	et	4	main
vääna	doc_553383122817_item	2974981	et	4	main
nimetada	doc_553383122817_item	2974985	et	3	main
red	doc_995572625446_item	2974625	et	4	main
või	doc_995572625446_item	2974627	et	4	main
suitsetavad	doc_995572625446_item	2974633	et	4	main
näitab	doc_995572625446_item	2974642	et	3	main
jälgivad	doc_995572625446_item	2974646	et	4	main
kes	doc_995572625446_item	2974655	et	4	main
oskab	doc_995572625446_item	2974656	et	3	main
seda	doc_995572625446_item	2974659	et	3	main
mitte	doc_995572625446_item	2974663	et	3	main
seda	doc_995572625446_item	2974664	et	3	main
mida	doc_995572625446_item	2974665	et	4	main
kõik	doc_995572625446_item	2974666	et	4	main
ostavad	doc_995572625446_item	2974667	et	3	main
parunid	doc_553383122817_item	2980762	et	3	main
eestlased	doc_553383122817_item	2980763	et	3	main
ja	doc_553383122817_item	2980764	et	3	main
enamlased	doc_553383122817_item	2980765	et	3	main
tartu	doc_553383122817_item	2980766	et	4	main
124-132	doc_553383122817_item	2980767	et	2	main
referaat	doc_553383122817_item	2974670	et	3	main
sõnu	doc_553383122817_item	2974680	et	4	main
on	doc_553383122817_item	2974686	et	4	main
koht	doc_553383122817_item	2974691	et	3	main
televisioon	doc_553383122817_item	2974707	et	4	main
ei	doc_553383122817_item	2974716	et	4	main
ei	doc_553383122817_item	2974718	et	4	main
käi	doc_553383122817_item	2974719	et	4	main
teatrites	doc_553383122817_item	2974720	et	3	main
kes	doc_553383122817_item	2974727	et	4	main
harku	doc_553383122817_item	2974734	et	4	main
elu	doc_553383122817_item	2974737	et	4	main
aegade	doc_553383122817_item	2974739	et	3	main
kohti	doc_553383122817_item	2974754	et	4	main
ühekaupa	doc_553383122817_item	2974755	et	4	main
ning	doc_553383122817_item	2974756	et	3	main
uurida	doc_553383122817_item	2974757	et	3	main
mille	doc_553383122817_item	2974758	et	3	main
poolest	doc_553383122817_item	2974759	et	4	main
nad	doc_553383122817_item	2974760	et	3	main
olid	doc_553383122817_item	2974761	et	4	main
tuntud	doc_553383122817_item	2974762	et	4	main
minevikus	doc_553383122817_item	2974763	et	3	main
ja	doc_553383122817_item	2974764	et	3	main
missugune	doc_553383122817_item	2974765	et	3	main
kultuuriline	doc_553383122817_item	2974766	et	4	main
väärtus	doc_553383122817_item	2974767	et	3	main
kas	doc_553383122817_item	2974771	et	3	main
huvitavad	doc_553383122817_item	2974774	et	4	main
või	doc_553383122817_item	2974783	et	4	main
elanud	doc_553383122817_item	2974789	et	4	main
on	doc_553383122817_item	2974797	et	4	main
on	doc_553383122817_item	2974804	et	4	main
nad	doc_553383122817_item	2974807	et	3	main
tõid	doc_553383122817_item	2974816	et	4	main
mille	doc_553383122817_item	2974817	et	3	main
poolest	doc_553383122817_item	2974818	et	4	main
kuulsad	doc_553383122817_item	2974820	et	3	main
ülivaade	doc_553383122817_item	2974826	et	3	main
1981	doc_553383122817_item	2974870	et	2	main
alla	doc_553383122817_item	2974874	et	3	main
hiljem	doc_553383122817_item	2974879	et	3	main
õigused	doc_553383122817_item	2974892	et	4	main
alevikud	doc_553383122817_item	2974904	et	4	main
ning	doc_553383122817_item	2974905	et	3	main
sõrve	doc_553383122817_item	2974910	et	4	main
vahi	doc_553383122817_item	2974914	et	4	main
suurupi	doc_553383122817_item	2974925	et	4	main
muraste	doc_553383122817_item	2974926	et	4	main
ja	doc_553383122817_item	2974927	et	3	main
temast	doc_553383122817_item	2974935	et	3	main
kevades	doc_553383122817_item	2974940	et	4	main
peetri	doc_553383122817_item	2974973	et	3	main
kultuurikeskuseks	doc_553383122817_item	2974990	et	4	main
ning	doc_553383122817_item	2974991	et	3	main
tulevikku	doc_553383122817_item	2974992	et	4	main
turismiobjektiks	doc_553383122817_item	2974993	et	3	main
vaid	doc_553383122817_item	2974994	et	3	main
kogu	doc_553383122817_item	2975001	et	4	main
suurem	doc_553383122817_item	2975008	et	4	main
läbi	doc_553383122817_item	2975017	et	4	main
viiakse	doc_553383122817_item	2975018	et	3	main
seal	doc_553383122817_item	2975019	et	4	main
ja	doc_553383122817_item	2975075	et	3	main
kaheks	doc_553383122817_item	2975083	et	4	main
selle	doc_553383122817_item	2975092	et	4	main
barokkansambel	doc_553383122817_item	2975100	et	3	main
von	doc_553383122817_item	2975104	et	4	main
selle	doc_553383122817_item	2974672	et	4	main
traditsioon	doc_553383122817_item	2974676	et	3	main
ja	doc_553383122817_item	2974677	et	3	main
nüüdisaeg	doc_553383122817_item	2974678	et	3	main
kaks	doc_553383122817_item	2974679	et	3	main
traditsioon	doc_553383122817_item	2974689	et	3	main
on	doc_553383122817_item	2974705	et	4	main
ja	doc_553383122817_item	2974710	et	3	main
peaaegu	doc_553383122817_item	2974715	et	3	main
loe	doc_553383122817_item	2974717	et	4	main
majas	doc_553383122817_item	2974722	et	3	main
nad	doc_553383122817_item	2974724	et	3	main
seminaritöö	doc_553383122817_item	2974731	et	4	main
uurimisobjekt	doc_553383122817_item	2974732	et	3	main
on	doc_553383122817_item	2974733	et	4	main
on	doc_553383122817_item	2974743	et	4	main
päris	doc_553383122817_item	2974744	et	4	main
mõisate	doc_553383122817_item	2974747	et	3	main
elades	doc_553383122817_item	2974723	et	4	main
ei	doc_553383122817_item	2974725	et	4	main
tunne	doc_553383122817_item	2974726	et	4	main
kultuuriline	doc_553383122817_item	2974736	et	4	main
kuna	doc_553383122817_item	2974740	et	3	main
vald	doc_553383122817_item	2974742	et	3	main
poolest	doc_553383122817_item	2974748	et	4	main
siis	doc_553383122817_item	2974749	et	3	main
ma	doc_553383122817_item	2974750	et	3	main
otsustasin	doc_553383122817_item	2974751	et	3	main
võtta	doc_553383122817_item	2974752	et	3	main
neid	doc_553383122817_item	2974753	et	4	main
on	doc_553383122817_item	2974770	et	4	main
või	doc_553383122817_item	2974778	et	4	main
inimesi	doc_553383122817_item	2974790	et	4	main
kes	doc_553383122817_item	2974791	et	4	main
kunagi	doc_553383122817_item	2974792	et	3	main
kuulsad	doc_553383122817_item	2974793	et	3	main
olid	doc_553383122817_item	2974794	et	4	main
unustatud	doc_553383122817_item	2974799	et	4	main
selliseid	doc_553383122817_item	2974802	et	4	main
kuidas	doc_553383122817_item	2974806	et	3	main
tegelesid	doc_553383122817_item	2974810	et	4	main
nendest	doc_553383122817_item	2974822	et	4	main
1	doc_553383122817_item	2974825	et	2	main
vald	doc_553383122817_item	2974828	et	3	main
on	doc_553383122817_item	2974829	et	4	main
mereäärne	doc_553383122817_item	2974830	et	3	main
vald	doc_553383122817_item	2974831	et	3	main
maadest	doc_553383122817_item	2974862	et	4	main
kuid	doc_553383122817_item	2974863	et	4	main
vald	doc_553383122817_item	2974868	et	3	main
ala	doc_553383122817_item	2974876	et	4	main
osa	doc_553383122817_item	2974878	et	4	main
tallinnale	doc_553383122817_item	2974880	et	4	main
küla	doc_553383122817_item	2974889	et	4	main
1991	doc_553383122817_item	2974896	et	2	main
praegu	doc_553383122817_item	2974898	et	3	main
kuuluvad	doc_553383122817_item	2974900	et	4	main
rannamõisa	doc_553383122817_item	2974908	et	3	main
humala	doc_553383122817_item	2974918	et	3	main
adra	doc_553383122817_item	2974919	et	3	main
naage	doc_553383122817_item	2974921	et	4	main
harku	doc_553383122817_item	2974930	et	4	main
valla	doc_553383122817_item	2974931	et	4	main
loodus	doc_553383122817_item	2974933	et	4	main
tegi	doc_553383122817_item	2974934	et	4	main
humala	doc_553383122817_item	2974970	et	3	main
mõisa	doc_553383122817_item	2974982	et	3	main
julgesti	doc_553383122817_item	2974984	et	3	main
harku	doc_553383122817_item	2974988	et	4	main
valla	doc_553383122817_item	2974989	et	4	main
laiem	doc_553383122817_item	2974999	et	4	main
kultuurile	doc_553383122817_item	2975003	et	3	main
audentsed	doc_553383122817_item	2975021	et	4	main
pärinevad	doc_553383122817_item	2975024	et	4	main
kloostrimõisast	doc_553383122817_item	2975032	et	4	main
frommholdid	doc_553383122817_item	2975073	et	4	main
maydellid	doc_553383122817_item	2975074	et	4	main
tuntud	doc_553383122817_item	2975090	et	4	main
just	doc_553383122817_item	2975091	et	3	main
vääna	doc_553383122817_item	2975098	et	4	main
ainulaadne	doc_553383122817_item	2975099	et	3	main
otto	doc_553383122817_item	2975103	et	4	main
strackelberg	doc_553383122817_item	2975105	et	4	main
üks	doc_553383122817_item	2975106	et	3	main
kuulasamaid	doc_553383122817_item	2975107	et	4	main
mehi	doc_553383122817_item	2975108	et	3	main
von	doc_553383122817_item	2975115	et	4	main
rahvusvaheliselt	doc_553383122817_item	2975120	et	4	main
ja	doc_553383122817_item	2975124	et	3	main
uurija	doc_553383122817_item	2975126	et	4	main
mitme	doc_553383122817_item	2975127	et	4	main
vastu	doc_553383122817_item	2975139	et	3	main
kunstnik	doc_553383122817_item	2975148	et	3	main
nad	doc_553383122817_item	2974772	et	3	main
on	doc_553383122817_item	2974773	et	4	main
näiteks	doc_553383122817_item	2974775	et	4	main
sündmuste	doc_553383122817_item	2974784	et	3	main
järgi	doc_553383122817_item	2974785	et	4	main
võibolla	doc_553383122817_item	2974786	et	4	main
üldse	doc_553383122817_item	2974798	et	3	main
inimesi	doc_553383122817_item	2974803	et	4	main
siis	doc_553383122817_item	2974805	et	3	main
kultuurilisi	doc_553383122817_item	2974812	et	4	main
väärtusi	doc_553383122817_item	2974813	et	3	main
oma	doc_553383122817_item	2974814	et	4	main
olid	doc_553383122817_item	2974819	et	4	main
teatakse	doc_553383122817_item	2974823	et	3	main
harku	doc_553383122817_item	2974827	et	4	main
lääne-	doc_553383122817_item	2974832	et	4	main
harjumaal	doc_553383122817_item	2974833	et	4	main
tallinna	doc_553383122817_item	2974834	et	4	main
ja	doc_553383122817_item	2974835	et	3	main
keila	doc_553383122817_item	2974836	et	4	main
vahel	doc_553383122817_item	2974837	et	4	main
kuulus	doc_553383122817_item	2974838	et	4	main
keila	doc_553383122817_item	2974839	et	4	main
kihelkonda	doc_553383122817_item	2974840	et	4	main
peale	doc_553383122817_item	2974841	et	4	main
teda	doc_553383122817_item	2974842	et	4	main
keila	doc_553383122817_item	2974843	et	4	main
kihelkonda	doc_553383122817_item	2974844	et	4	main
kuulusid	doc_553383122817_item	2974845	et	4	main
ka	doc_553383122817_item	2974846	et	3	main
saue	doc_553383122817_item	2974847	et	4	main
ning	doc_553383122817_item	2974848	et	3	main
praeguse	doc_553383122817_item	2974849	et	3	main
keila	doc_553383122817_item	2974850	et	4	main
territooriumid	doc_553383122817_item	2974851	et	3	main
harku	doc_553383122817_item	2974852	et	4	main
ja	doc_553383122817_item	2974853	et	3	main
keila	doc_553383122817_item	2974854	et	4	main
vallad	doc_553383122817_item	2974855	et	3	main
hõlmavad	doc_553383122817_item	2974856	et	4	main
mõlemad	doc_553383122817_item	2974857	et	3	main
umbes	doc_553383122817_item	2974858	et	4	main
veerandi	doc_553383122817_item	2974859	et	4	main
endise	doc_553383122817_item	2974860	et	3	main
kihelkonna	doc_553383122817_item	2974861	et	3	main
kuid	doc_553383122817_item	2974795	et	4	main
nüüdisajal	doc_553383122817_item	2974796	et	3	main
ja	doc_553383122817_item	2974800	et	3	main
elasid	doc_553383122817_item	2974808	et	4	main
millega	doc_553383122817_item	2974809	et	3	main
milliseid	doc_553383122817_item	2974811	et	3	main
harku	doc_553383122817_item	2974865	et	4	main
valla	doc_553383122817_item	2974866	et	4	main
tagasi	doc_553383122817_item	2974867	et	3	main
pöördume	doc_553383122817_item	2974864	et	3	main
tekkis	doc_553383122817_item	2974869	et	3	main
praeguse	doc_553383122817_item	2974875	et	3	main
antud	doc_553383122817_item	2974881	et	4	main
territooriumist	doc_553383122817_item	2974882	et	4	main
ja	doc_553383122817_item	2974887	et	3	main
sinna	doc_553383122817_item	2974899	et	3	main
harkujärve	doc_553383122817_item	2974906	et	4	main
tiske	doc_553383122817_item	2974907	et	4	main
laabi	doc_553383122817_item	2974909	et	3	main
vääna	doc_553383122817_item	2974913	et	4	main
tutermaa	doc_553383122817_item	2974915	et	4	main
kumna	doc_553383122817_item	2974916	et	4	main
viti	doc_553383122817_item	2974924	et	4	main
külad1	doc_553383122817_item	2974929	et	2	main
kaunis	doc_553383122817_item	2974932	et	4	main
ning	doc_553383122817_item	2974871	et	3	main
ja	doc_553383122817_item	2974877	et	3	main
pikaliiva	doc_553383122817_item	2974886	et	4	main
kadaka	doc_553383122817_item	2974888	et	3	main
harku	doc_553383122817_item	2974890	et	4	main
valla	doc_553383122817_item	2974891	et	4	main
vaila	doc_553383122817_item	2974912	et	4	main
puhkepaiga	doc_553383122817_item	2974939	et	4	main
sügiseni	doc_553383122817_item	2974941	et	3	main
valla	doc_553383122817_item	2974942	et	4	main
elanike	doc_553383122817_item	2974943	et	3	main
arv	doc_553383122817_item	2974944	et	3	main
tänu	doc_553383122817_item	2974945	et	4	main
suvitajatele	doc_553383122817_item	2974946	et	4	main
pea	doc_553383122817_item	2974947	et	4	main
neljakordne	doc_553383122817_item	2974948	et	3	main
harku	doc_553383122817_item	2974949	et	4	main
vald	doc_553383122817_item	2974950	et	3	main
on	doc_553383122817_item	2974951	et	4	main
rikas	doc_553383122817_item	2974952	et	4	main
mõisate	doc_553383122817_item	2974953	et	3	main
poolest	doc_553383122817_item	2974954	et	4	main
kõige	doc_553383122817_item	2974955	et	4	main
esinduslikumad	doc_553383122817_item	2974956	et	4	main
on	doc_553383122817_item	2974957	et	4	main
harku	doc_553383122817_item	2974958	et	4	main
vääna	doc_553383122817_item	2974959	et	4	main
ning	doc_553383122817_item	2974960	et	3	main
muraste	doc_553383122817_item	2974961	et	4	main
mõisad	doc_553383122817_item	2974962	et	3	main
peale	doc_553383122817_item	2974963	et	4	main
neid	doc_553383122817_item	2974964	et	4	main
praeguse	doc_553383122817_item	2974965	et	3	main
valla	doc_553383122817_item	2974966	et	4	main
territooriumil	doc_553383122817_item	2974967	et	3	main
ka	doc_553383122817_item	2974969	et	3	main
pääla	doc_553383122817_item	2974976	et	4	main
viti	doc_553383122817_item	2974977	et	4	main
mõisad	doc_553383122817_item	2974978	et	3	main
2	doc_553383122817_item	2974979	et	2	main
väänas	doc_553383122817_item	2975005	et	3	main
kultuurilisi	doc_553383122817_item	2975015	et	4	main
sündmusi	doc_553383122817_item	2975016	et	3	main
andmed	doc_553383122817_item	2975022	et	3	main
väänast	doc_553383122817_item	2975023	et	4	main
1306	doc_553383122817_item	2975025	et	2	main
aastast	doc_553383122817_item	2975026	et	4	main
kui	doc_553383122817_item	2975027	et	3	main
teel	doc_553383122817_item	2975066	et	4	main
mõisa	doc_553383122817_item	2975067	et	3	main
lucca	doc_553383122817_item	2974972	et	4	main
rannamõisa	doc_553383122817_item	2974974	et	3	main
võib	doc_553383122817_item	2974983	et	3	main
mitte	doc_553383122817_item	2974986	et	3	main
ainult	doc_553383122817_item	2974987	et	4	main
ka	doc_553383122817_item	2974995	et	3	main
kohaks	doc_553383122817_item	2974996	et	4	main
millel	doc_553383122817_item	2974997	et	3	main
on	doc_553383122817_item	2974998	et	4	main
eesti	doc_553383122817_item	2975002	et	4	main
asub	doc_553383122817_item	2975006	et	3	main
valla	doc_553383122817_item	2975014	et	4	main
asustatud	doc_553383122817_item	2975031	et	4	main
vanimad	doc_553383122817_item	2975033	et	3	main
kirjalikud	doc_553383122817_item	2975034	et	3	main
teated2	doc_553383122817_item	2975035	et	2	main
väänast	doc_553383122817_item	2975036	et	4	main
pärinevad	doc_553383122817_item	2975037	et	4	main
aga	doc_553383122817_item	2975038	et	3	main
1325	doc_553383122817_item	2975039	et	2	main
aastast	doc_553383122817_item	2975040	et	4	main
millal	doc_553383122817_item	2975041	et	3	main
sai	doc_553383122817_item	2975042	et	4	main
hermann	doc_553383122817_item	2975043	et	4	main
bremen	doc_553383122817_item	2975044	et	4	main
koos	doc_553383122817_item	2975045	et	4	main
vendade	doc_553383122817_item	2975046	et	3	main
tile	doc_553383122817_item	2975047	et	4	main
ja	doc_553383122817_item	2975048	et	3	main
rotkeriga	doc_553383122817_item	2975049	et	4	main
taani	doc_553383122817_item	2975050	et	4	main
kuningalt	doc_553383122817_item	2975051	et	4	main
kuus	doc_553383122817_item	2975052	et	4	main
küla	doc_553383122817_item	2975053	et	4	main
1460	doc_553383122817_item	2975054	et	2	main
aastani	doc_553383122817_item	2975055	et	3	main
kuuluski	doc_553383122817_item	2975056	et	4	main
vööne	doc_553383122817_item	2975057	et	4	main
breminite	doc_553383122817_item	2975058	et	4	main
perekonnale	doc_553383122817_item	2975059	et	4	main
hiljem	doc_553383122817_item	2975060	et	3	main
abielumiste	doc_553383122817_item	2975061	et	4	main
ostmiste-	doc_553383122817_item	2975062	et	4	main
müümiste	doc_553383122817_item	2975063	et	4	main
ja	doc_553383122817_item	2975064	et	3	main
pärimiste	doc_553383122817_item	2975065	et	4	main
tähendus	doc_553383122817_item	2975000	et	4	main
praegu	doc_553383122817_item	2975004	et	3	main
kõige	doc_553383122817_item	2975007	et	4	main
kool	doc_553383122817_item	2975009	et	4	main
harku	doc_553383122817_item	2975010	et	4	main
vallas	doc_553383122817_item	2975011	et	3	main
ning	doc_553383122817_item	2975012	et	3	main
enamik	doc_553383122817_item	2975013	et	3	main
esimesed	doc_553383122817_item	2975020	et	3	main
padise	doc_553383122817_item	2975028	et	4	main
kloostri	doc_553383122817_item	2975029	et	3	main
munkade	doc_553383122817_item	2975030	et	3	main
olnud	doc_553383122817_item	2975069	et	4	main
tiesenhausenid	doc_553383122817_item	2975071	et	4	main
taubed	doc_553383122817_item	2975072	et	4	main
sealt	doc_553383122817_item	2975077	et	4	main
aga	doc_553383122817_item	2975078	et	3	main
edasi	doc_553383122817_item	2975079	et	3	main
mõisa	doc_553383122817_item	2975080	et	3	main
perekonna	doc_553383122817_item	2975093	et	4	main
21	doc_553383122817_item	2975101	et	2	main
pikas	doc_553383122817_item	2975110	et	4	main
oli	doc_553383122817_item	2975112	et	3	main
1786-18373	doc_553383122817_item	2975117	et	2	main
kunstnik	doc_553383122817_item	2975122	et	3	main
liige	doc_553383122817_item	2975129	et	4	main
juba	doc_553383122817_item	2975130	et	3	main
ja	doc_553383122817_item	2975137	et	3	main
talle	doc_553383122817_item	2975145	et	4	main
suguvõsa	doc_553383122817_item	2975152	et	4	main
peale	doc_553383122817_item	2975172	et	4	main
töö-	doc_553383122817_item	2975178	et	4	main
kreekas	doc_553383122817_item	2975181	et	4	main
konstantinoopolis	doc_553383122817_item	2975182	et	4	main
oli	doc_553383122817_item	2975192	et	3	main
aja	doc_553383122817_item	2975194	et	4	main
vang	doc_553383122817_item	2975196	et	3	main
illustreeritud	doc_553383122817_item	2975202	et	4	main
teoseid	doc_553383122817_item	2975203	et	3	main
oma	doc_553383122817_item	2975204	et	4	main
huvitava	doc_553383122817_item	2975205	et	4	main
onu	doc_553383122817_item	2975212	et	4	main
joonistuste	doc_553383122817_item	2975222	et	4	main
järgi	doc_553383122817_item	2975223	et	4	main
ehitati	doc_553383122817_item	2975224	et	3	main
keila	doc_553383122817_item	2975225	et	4	main
instutio	doc_553383122817_item	2975246	et	4	main
liige	doc_553383122817_item	2975252	et	4	main
kuningliku	doc_553383122817_item	2975254	et	3	main
apollptempel	doc_553383122817_item	2975268	et	4	main
von	doc_553383122817_item	2975070	et	4	main
dückerid	doc_553383122817_item	2975076	et	4	main
sattus	doc_553383122817_item	2975081	et	3	main
aastasajaks	doc_553383122817_item	2975084	et	3	main
kätte	doc_553383122817_item	2975086	et	4	main
ning	doc_553383122817_item	2975087	et	3	main
tänapäeval	doc_553383122817_item	2975088	et	3	main
on	doc_553383122817_item	2975089	et	4	main
stackenbergide	doc_553383122817_item	2975109	et	4	main
kes	doc_553383122817_item	2975118	et	4	main
arheoloog	doc_553383122817_item	2975123	et	3	main
lapsepõlvest	doc_553383122817_item	2975131	et	4	main
varakult	doc_553383122817_item	2975132	et	4	main
poisil	doc_553383122817_item	2975133	et	3	main
ärkas	doc_553383122817_item	2975134	et	3	main
huvi	doc_553383122817_item	2975135	et	4	main
ema	doc_553383122817_item	2975144	et	4	main
neusi	doc_553383122817_item	2975151	et	4	main
nimekate	doc_553383122817_item	2975153	et	4	main
sõjaväelaste	doc_553383122817_item	2975154	et	4	main
ja	doc_553383122817_item	2975155	et	3	main
diplomaatide	doc_553383122817_item	2975156	et	3	main
eeskujul	doc_553383122817_item	2975157	et	3	main
pidi	doc_553383122817_item	2975158	et	4	main
otto	doc_553383122817_item	2975159	et	4	main
magnusest	doc_553383122817_item	2975160	et	4	main
saama	doc_553383122817_item	2975161	et	4	main
diplomaat	doc_553383122817_item	2975162	et	3	main
õpingud	doc_553383122817_item	2975163	et	3	main
viisid	doc_553383122817_item	2975164	et	4	main
ta	doc_553383122817_item	2975165	et	4	main
halle	doc_553383122817_item	2975166	et	4	main
pedagoogiumi	doc_553383122817_item	2975167	et	4	main
viibis	doc_553383122817_item	2975175	et	3	main
pikkadel	doc_553383122817_item	2975177	et	4	main
ja	doc_553383122817_item	2975179	et	3	main
aasias	doc_553383122817_item	2975185	et	4	main
üks	doc_553383122817_item	2975186	et	3	main
kord	doc_553383122817_item	2975187	et	4	main
sattus	doc_553383122817_item	2975188	et	3	main
piraatide	doc_553383122817_item	2975189	et	3	main
mõne	doc_553383122817_item	2975193	et	3	main
antiikkunsti	doc_553383122817_item	2975197	et	4	main
kohta	doc_553383122817_item	2975198	et	4	main
avaldas	doc_553383122817_item	2975199	et	3	main
ta	doc_553383122817_item	2975208	et	4	main
oluliselt	doc_553383122817_item	2975210	et	4	main
raamatukogu	doc_553383122817_item	2975220	et	4	main
tema	doc_553383122817_item	2975221	et	4	main
kirikuaeda	doc_553383122817_item	2975227	et	4	main
huvitasid	doc_553383122817_item	2975234	et	4	main
antiikkunst	doc_553383122817_item	2975235	et	3	main
ja	doc_553383122817_item	2975236	et	3	main
maastikumaal	doc_553383122817_item	2975237	et	4	main
itaalias	doc_553383122817_item	2975244	et	4	main
1826	doc_553383122817_item	2975271	et	2	main
grece	doc_553383122817_item	2975272	et	4	main
on	doc_553383122817_item	2975288	et	4	main
seotud	doc_553383122817_item	2975289	et	4	main
üks	doc_553383122817_item	2975290	et	3	main
ajal	doc_553383122817_item	2975294	et	4	main
selle	doc_553383122817_item	2975310	et	4	main
looga	doc_553383122817_item	2975311	et	4	main
elavaid	doc_553383122817_item	2975324	et	4	main
von	doc_553383122817_item	2975330	et	4	main
ning	doc_553383122817_item	2975339	et	3	main
omanikeks	doc_553383122817_item	2975068	et	3	main
ligi	doc_553383122817_item	2975082	et	3	main
stackelbergide	doc_553383122817_item	2975085	et	4	main
tänuks	doc_553383122817_item	2975094	et	3	main
strackbergide	doc_553383122817_item	2975095	et	4	main
ajal	doc_553383122817_item	2975096	et	4	main
rajati	doc_553383122817_item	2975097	et	3	main
parun	doc_553383122817_item	2975102	et	3	main
stackenberg	doc_553383122817_item	2975116	et	4	main
tuntud	doc_553383122817_item	2975121	et	4	main
antiikajaloo	doc_553383122817_item	2975125	et	4	main
kunsti	doc_553383122817_item	2975136	et	4	main
poja	doc_553383122817_item	2975140	et	4	main
arendamiseks	doc_553383122817_item	2975142	et	4	main
kutsus	doc_553383122817_item	2975143	et	4	main
saksamaalt	doc_553383122817_item	2975146	et	3	main
parun	doc_553383122817_item	2975174	et	3	main
itaalias	doc_553383122817_item	2975183	et	4	main
väike-	doc_553383122817_item	2975184	et	4	main
ning	doc_553383122817_item	2975191	et	3	main
alu	doc_553383122817_item	2975206	et	4	main
v	doc_553383122817_item	2975214	et	4	main
kirikuaeda	doc_553383122817_item	2975226	et	4	main
magnuse	doc_553383122817_item	2975233	et	4	main
näiteks	doc_553383122817_item	2975243	et	4	main
akadeemia	doc_553383122817_item	2975251	et	4	main
põhjamaade	doc_553383122817_item	2975255	et	3	main
voes	doc_553383122817_item	2975273	et	3	main
1830	doc_553383122817_item	2975277	et	2	main
1837	doc_553383122817_item	2975282	et	2	main
vääna	doc_553383122817_item	2975284	et	4	main
tragöödia	doc_553383122817_item	2975285	et	4	main
vääna	doc_553383122817_item	2975286	et	4	main
mõisaga	doc_553383122817_item	2975287	et	3	main
kaunis	doc_553383122817_item	2975291	et	4	main
isegi	doc_553383122817_item	2975299	et	4	main
seotud	doc_553383122817_item	2975312	et	4	main
käinud	doc_553383122817_item	2975316	et	4	main
mõjutasid	doc_553383122817_item	2975320	et	4	main
tool	doc_553383122817_item	2975321	et	3	main
ajal	doc_553383122817_item	2975322	et	4	main
tema	doc_553383122817_item	2975332	et	4	main
korompa	doc_553383122817_item	2975338	et	4	main
beethoven	doc_553383122817_item	2975345	et	4	main
selle	doc_553383122817_item	2975347	et	4	main
tõestusmaterjal	doc_553383122817_item	2975349	et	3	main
on	doc_553383122817_item	2975350	et	4	main
kirjad	doc_553383122817_item	2975351	et	4	main
beethoven	doc_553383122817_item	2975359	et	4	main
on	doc_553383122817_item	2975362	et	4	main
inglise-	doc_553383122817_item	2975364	et	4	main
ja	doc_553383122817_item	2975365	et	3	main
saksakeeltes	doc_553383122817_item	2975366	et	3	main
ning	doc_553383122817_item	2975367	et	3	main
tõlgitud	doc_553383122817_item	2975373	et	4	main
kust	doc_553383122817_item	2975374	et	4	main
see	doc_553383122817_item	2975375	et	3	main
romaan	doc_553383122817_item	2975376	et	3	main
missugune	doc_553383122817_item	2975381	et	3	main
nende	doc_553383122817_item	2975392	et	4	main
kirjadest	doc_553383122817_item	2975393	et	3	main
sest	doc_553383122817_item	2975394	et	4	main
loomu	doc_553383122817_item	2975405	et	4	main
ja	doc_553383122817_item	2975409	et	3	main
oli	doc_553383122817_item	2975417	et	3	main
henrich	doc_553383122817_item	2975426	et	4	main
aja	doc_553383122817_item	2975442	et	4	main
biograafide	doc_553383122817_item	2975470	et	4	main
ja	doc_553383122817_item	2975477	et	3	main
esitakse	doc_553383122817_item	2975478	et	3	main
algas	doc_553383122817_item	2975486	et	3	main
helilooja	doc_553383122817_item	2975487	et	4	main
tema	doc_553383122817_item	2975494	et	4	main
peale	doc_553383122817_item	2975499	et	4	main
tihti	doc_553383122817_item	2975501	et	3	main
ja	doc_553383122817_item	2975503	et	3	main
beethoven	doc_553383122817_item	2975511	et	4	main
tunnetest	doc_553383122817_item	2975514	et	3	main
armastusega	doc_553383122817_item	2975516	et	4	main
ja	doc_553383122817_item	2975517	et	3	main
traagikaga	doc_553383122817_item	2975518	et	3	main
reas	doc_553383122817_item	2975111	et	3	main
otto	doc_553383122817_item	2975113	et	4	main
magnus	doc_553383122817_item	2975114	et	4	main
oli	doc_553383122817_item	2975119	et	3	main
teadusorganisatsiooni	doc_553383122817_item	2975128	et	4	main
muusika	doc_553383122817_item	2975138	et	4	main
joonistushuvi	doc_553383122817_item	2975141	et	4	main
õpetajaks	doc_553383122817_item	2975147	et	4	main
p	doc_553383122817_item	2975149	et	4	main
j	doc_553383122817_item	2975150	et	4	main
göttingeni	doc_553383122817_item	2975168	et	4	main
moskva	doc_553383122817_item	2975170	et	4	main
neid	doc_553383122817_item	2975173	et	4	main
kätte	doc_553383122817_item	2975190	et	4	main
ta	doc_553383122817_item	2975200	et	4	main
enda	doc_553383122817_item	2975201	et	4	main
jooksul	doc_553383122817_item	2975207	et	4	main
peter	doc_553383122817_item	2975213	et	4	main
dückeri	doc_553383122817_item	2975215	et	4	main
vääna	doc_553383122817_item	2975217	et	4	main
kunstikogusid	doc_553383122817_item	2975218	et	4	main
ja	doc_553383122817_item	2975219	et	3	main
stackelbergide	doc_553383122817_item	2975228	et	4	main
perekonna	doc_553383122817_item	2975229	et	4	main
kabel-mausoleum	doc_553383122817_item	2975230	et	3	main
eriti	doc_553383122817_item	2975231	et	3	main
otto	doc_553383122817_item	2975232	et	4	main
ta	doc_553383122817_item	2975238	et	4	main
esines	doc_553383122817_item	2975239	et	3	main
mitmete	doc_553383122817_item	2975240	et	4	main
kunstiühingute	doc_553383122817_item	2975241	et	3	main
töös	doc_553383122817_item	2975242	et	3	main
archeolgico	doc_553383122817_item	2975247	et	4	main
kaasasutaja	doc_553383122817_item	2975248	et	4	main
kunstide	doc_553383122817_item	2975250	et	3	main
taani	doc_553383122817_item	2975253	et	4	main
pittoresques	doc_553383122817_item	2975274	et	4	main
hellenen	doc_553383122817_item	2975281	et	4	main
samal	doc_553383122817_item	2975293	et	3	main
armastuslugu	doc_553383122817_item	2975296	et	4	main
võib	doc_553383122817_item	2975298	et	3	main
ja	doc_553383122817_item	2975317	et	3	main
kindlasti	doc_553383122817_item	2975319	et	3	main
on	doc_553383122817_item	2975327	et	4	main
christoph	doc_553383122817_item	2975328	et	4	main
naine	doc_553383122817_item	2975333	et	3	main
josephine	doc_553383122817_item	2975334	et	4	main
de	doc_553383122817_item	2975337	et	4	main
helilooja	doc_553383122817_item	2975341	et	4	main
ludwig	doc_553383122817_item	2975343	et	4	main
van	doc_553383122817_item	2975344	et	4	main
kahjuks	doc_553383122817_item	2975360	et	4	main
eesti	doc_553383122817_item	2975368	et	4	main
nad	doc_553383122817_item	2975370	et	3	main
ei	doc_553383122817_item	2975371	et	4	main
ole	doc_553383122817_item	2975372	et	4	main
kuidas	doc_553383122817_item	2975379	et	3	main
lõpp	doc_553383122817_item	2975382	et	3	main
neile	doc_553383122817_item	2975385	et	4	main
püüan	doc_553383122817_item	2975388	et	3	main
lugemata	doc_553383122817_item	2975397	et	4	main
221	doc_553383122817_item	2975411	et	2	main
salalaekas	doc_553383122817_item	2975413	et	3	main
väga	doc_553383122817_item	2975419	et	3	main
vanast	doc_553383122817_item	2975420	et	3	main
oli	doc_553383122817_item	2975435	et	3	main
suareedel	doc_553383122817_item	2975439	et	3	main
ja	doc_553383122817_item	2975468	et	3	main
jaoks	doc_553383122817_item	2975471	et	4	main
surematu	doc_553383122817_item	2975472	et	4	main
saladus	doc_553383122817_item	2975473	et	3	main
uusi	doc_553383122817_item	2975480	et	3	main
armastusest	doc_553383122817_item	2975485	et	4	main
ta	doc_553383122817_item	2975491	et	4	main
ajast	doc_553383122817_item	2975498	et	4	main
on	doc_553383122817_item	2975506	et	4	main
see	doc_553383122817_item	2975507	et	3	main
saladuslik	doc_553383122817_item	2975508	et	3	main
naine	doc_553383122817_item	2975509	et	3	main
oma	doc_553383122817_item	2975513	et	4	main
kuulus	doc_553383122817_item	2975529	et	4	main
ja	doc_553383122817_item	2975169	et	3	main
ülikooli	doc_553383122817_item	2975171	et	4	main
ka	doc_553383122817_item	2975176	et	3	main
teadusreisidel	doc_553383122817_item	2975180	et	3	main
nende	doc_553383122817_item	2975195	et	4	main
täiendas	doc_553383122817_item	2975209	et	3	main
oma	doc_553383122817_item	2975211	et	4	main
asutatud	doc_553383122817_item	2975216	et	4	main
oli	doc_553383122817_item	2975245	et	3	main
berliini	doc_553383122817_item	2975249	et	4	main
muinasteduste	doc_553383122817_item	2975256	et	4	main
liige	doc_553383122817_item	2975257	et	4	main
tähtsamad	doc_553383122817_item	2975258	et	4	main
tööd	doc_553383122817_item	2975259	et	4	main
on	doc_553383122817_item	2975260	et	4	main
trachten	doc_553383122817_item	2975261	et	4	main
und	doc_553383122817_item	2975262	et	4	main
gebräuche	doc_553383122817_item	2975263	et	4	main
der	doc_553383122817_item	2975264	et	4	main
neugriechen	doc_553383122817_item	2975265	et	4	main
1825	doc_553383122817_item	2975266	et	2	main
der	doc_553383122817_item	2975267	et	4	main
zu	doc_553383122817_item	2975269	et	4	main
bassa	doc_553383122817_item	2975270	et	4	main
et	doc_553383122817_item	2975275	et	3	main
topographiques	doc_553383122817_item	2975276	et	4	main
die	doc_553383122817_item	2975278	et	4	main
gräben	doc_553383122817_item	2975279	et	4	main
kurb	doc_553383122817_item	2975295	et	3	main
tunded	doc_553383122817_item	2975313	et	3	main
siit	doc_553383122817_item	2975314	et	3	main
üle	doc_553383122817_item	2975315	et	3	main
mis	doc_553383122817_item	2975318	et	4	main
inimesi	doc_553383122817_item	2975325	et	4	main
peategelasteks	doc_553383122817_item	2975326	et	3	main
stackelberg	doc_553383122817_item	2975331	et	4	main
brunswik	doc_553383122817_item	2975336	et	4	main
peamine	doc_553383122817_item	2975346	et	3	main
loo	doc_553383122817_item	2975348	et	4	main
josephine	doc_553383122817_item	2975357	et	4	main
nad	doc_553383122817_item	2975361	et	3	main
keelesse	doc_553383122817_item	2975369	et	4	main
alguse	doc_553383122817_item	2975377	et	3	main
oli	doc_553383122817_item	2975384	et	3	main
vastata	doc_553383122817_item	2975389	et	4	main
toon	doc_553383122817_item	2975390	et	4	main
väljalõigud	doc_553383122817_item	2975391	et	3	main
ilma	doc_553383122817_item	2975395	et	4	main
raske	doc_553383122817_item	2975399	et	4	main
edasi	doc_553383122817_item	2975400	et	3	main
anda	doc_553383122817_item	2975401	et	3	main
peategelaste	doc_553383122817_item	2975402	et	3	main
tundeid	doc_553383122817_item	2975403	et	3	main
ja	doc_553383122817_item	2975404	et	3	main
sügavust	doc_553383122817_item	2975408	et	4	main
krahvinna	doc_553383122817_item	2975414	et	4	main
de	doc_553383122817_item	2975415	et	4	main
tema	doc_553383122817_item	2975422	et	4	main
löwen	doc_553383122817_item	2975428	et	4	main
1158	doc_553383122817_item	2975431	et	2	main
aastal	doc_553383122817_item	2975432	et	3	main
müncheni	doc_553383122817_item	2975433	et	4	main
hea	doc_553383122817_item	2975436	et	4	main
koos	doc_553383122817_item	2975440	et	4	main
selle	doc_553383122817_item	2975441	et	4	main
bethooveni	doc_553383122817_item	2975469	et	4	main
vaieldakse	doc_553383122817_item	2975476	et	3	main
surematu	doc_553383122817_item	2975484	et	4	main
surma	doc_553383122817_item	2975492	et	4	main
der	doc_553383122817_item	2975280	et	4	main
22	doc_553383122817_item	2975283	et	2	main
ja	doc_553383122817_item	2975292	et	3	main
mida	doc_553383122817_item	2975297	et	4	main
tragöödiaks	doc_553383122817_item	2975300	et	3	main
nimetada	doc_553383122817_item	2975301	et	3	main
see	doc_553383122817_item	2975302	et	3	main
pole	doc_553383122817_item	2975303	et	3	main
toimud	doc_553383122817_item	2975304	et	3	main
küll	doc_553383122817_item	2975305	et	4	main
vääna	doc_553383122817_item	2975306	et	4	main
mõisa	doc_553383122817_item	2975307	et	3	main
sees	doc_553383122817_item	2975308	et	4	main
kuid	doc_553383122817_item	2975309	et	4	main
seal	doc_553383122817_item	2975323	et	4	main
adam	doc_553383122817_item	2975329	et	4	main
von	doc_553383122817_item	2975335	et	4	main
kuulus	doc_553383122817_item	2975340	et	4	main
franz	doc_553383122817_item	2975342	et	4	main
ja	doc_553383122817_item	2975358	et	3	main
arenes	doc_553383122817_item	2975380	et	3	main
küsimustele	doc_553383122817_item	2975386	et	4	main
ma	doc_553383122817_item	2975387	et	3	main
nende	doc_553383122817_item	2975406	et	4	main
korompa4	doc_553383122817_item	2975416	et	2	main
des	doc_553383122817_item	2975427	et	4	main
josephine	doc_553383122817_item	2975434	et	4	main
pianist	doc_553383122817_item	2975437	et	3	main
esines	doc_553383122817_item	2975438	et	3	main
mida	doc_553383122817_item	2975352	et	4	main
kirjutasid	doc_553383122817_item	2975353	et	4	main
kaks	doc_553383122817_item	2975354	et	3	main
armastajad	doc_553383122817_item	2975355	et	4	main
ehk	doc_553383122817_item	2975356	et	3	main
kirjutatud	doc_553383122817_item	2975363	et	4	main
sai	doc_553383122817_item	2975378	et	4	main
tal	doc_553383122817_item	2975383	et	3	main
neid	doc_553383122817_item	2975396	et	4	main
on	doc_553383122817_item	2975398	et	4	main
armastuse	doc_553383122817_item	2975407	et	4	main
kurbust	doc_553383122817_item	2975410	et	4	main
salapärane	doc_553383122817_item	2975412	et	4	main
pärit	doc_553383122817_item	2975418	et	3	main
aadlisoost	doc_553383122817_item	2975421	et	4	main
esivanemaks	doc_553383122817_item	2975423	et	4	main
oli	doc_553383122817_item	2975424	et	3	main
näiteks	doc_553383122817_item	2975425	et	4	main
kes	doc_553383122817_item	2975429	et	4	main
asutas	doc_553383122817_item	2975430	et	3	main
viini	doc_553383122817_item	2975443	et	4	main
tippmuusikutega	doc_553383122817_item	2975444	et	3	main
naine	doc_553383122817_item	2975445	et	3	main
oli	doc_553383122817_item	2975446	et	3	main
franz	doc_553383122817_item	2975447	et	4	main
ludwig	doc_553383122817_item	2975448	et	4	main
van	doc_553383122817_item	2975449	et	4	main
beethoveni	doc_553383122817_item	2975450	et	4	main
õpilane	doc_553383122817_item	2975451	et	3	main
josephine	doc_553383122817_item	2975452	et	4	main
on	doc_553383122817_item	2975453	et	4	main
peetud	doc_553383122817_item	2975454	et	4	main
paljude	doc_553383122817_item	2975455	et	3	main
teiste	doc_553383122817_item	2975456	et	4	main
kandidaatide	doc_553383122817_item	2975457	et	3	main
seas	doc_553383122817_item	2975458	et	4	main
bethooveni	doc_553383122817_item	2975459	et	4	main
surematuks	doc_553383122817_item	2975460	et	4	main
armastuseks	doc_553383122817_item	2975461	et	4	main
unsterbliche	doc_553383122817_item	2975462	et	4	main
geliebte	doc_553383122817_item	2975463	et	4	main
mis	doc_553383122817_item	2975464	et	4	main
omakorda	doc_553383122817_item	2975465	et	3	main
on	doc_553383122817_item	2975466	et	4	main
muusikateadlaste	doc_553383122817_item	2975467	et	3	main
mille	doc_553383122817_item	2975474	et	3	main
järjest	doc_553383122817_item	2975479	et	4	main
versioone	doc_553383122817_item	2975481	et	3	main
beethoveni	doc_553383122817_item	2975483	et	4	main
mida	doc_553383122817_item	2975489	et	4	main
pärast	doc_553383122817_item	2975490	et	4	main
kirjutuslaua	doc_553383122817_item	2975495	et	3	main
muusikateadlased	doc_553383122817_item	2975500	et	3	main
uurisid	doc_553383122817_item	2975502	et	4	main
kellele	doc_553383122817_item	2975510	et	4	main
täpselt	doc_553383122817_item	2975521	et	4	main
öelda	doc_553383122817_item	2975522	et	4	main
kas	doc_553383122817_item	2975523	et	3	main
tõepoolest	doc_553383122817_item	2975524	et	3	main
just	doc_553383122817_item	2975525	et	3	main
oligi	doc_553383122817_item	2975527	et	3	main
ridadega	doc_553383122817_item	2975568	et	3	main
igavesti	doc_553383122817_item	2975573	et	4	main
üle	doc_553383122817_item	2975475	et	3	main
lugu	doc_553383122817_item	2975482	et	4	main
kirjadest	doc_553383122817_item	2975488	et	3	main
leiti	doc_553383122817_item	2975493	et	3	main
salalaekast	doc_553383122817_item	2975496	et	4	main
sellest	doc_553383122817_item	2975497	et	4	main
ei	doc_553383122817_item	2975519	et	4	main
saa	doc_553383122817_item	2975520	et	4	main
josephine	doc_553383122817_item	2975526	et	4	main
lugeda	doc_553383122817_item	2975534	et	3	main
nende	doc_553383122817_item	2975535	et	4	main
kirju	doc_553383122817_item	2975536	et	4	main
siis	doc_553383122817_item	2975537	et	3	main
see	doc_553383122817_item	2975538	et	3	main
näeb	doc_553383122817_item	2975539	et	3	main
väga	doc_553383122817_item	2975540	et	3	main
tõenäolisena	doc_553383122817_item	2975541	et	4	main
muidu	doc_553383122817_item	2975542	et	3	main
on	doc_553383122817_item	2975543	et	4	main
raske	doc_553383122817_item	2975544	et	4	main
seletada	doc_553383122817_item	2975545	et	3	main
nende	doc_553383122817_item	2975546	et	4	main
kirjade	doc_553383122817_item	2975547	et	3	main
olemasolu	doc_553383122817_item	2975548	et	4	main
üks	doc_553383122817_item	2975549	et	3	main
nendest	doc_553383122817_item	2975550	et	4	main
kirjadest	doc_553383122817_item	2975551	et	3	main
algas	doc_553383122817_item	2975552	et	3	main
sõnadega	doc_553383122817_item	2975553	et	3	main
mu	doc_553383122817_item	2975554	et	3	main
ingel	doc_553383122817_item	2975555	et	3	main
mu	doc_553383122817_item	2975556	et	3	main
kõik	doc_553383122817_item	2975557	et	4	main
mu	doc_553383122817_item	2975558	et	3	main
mina	doc_553383122817_item	2975559	et	4	main
mein	doc_553383122817_item	2975560	et	4	main
engel	doc_553383122817_item	2975561	et	4	main
mein	doc_553383122817_item	2975562	et	4	main
alles	doc_553383122817_item	2975563	et	3	main
mein	doc_553383122817_item	2975564	et	4	main
ich	doc_553383122817_item	2975565	et	4	main
ja	doc_553383122817_item	2975566	et	3	main
lõppes	doc_553383122817_item	2975567	et	4	main
armastatu	doc_553383122817_item	2975570	et	4	main
sinu	doc_553383122817_item	2975574	et	3	main
igavesti	doc_553383122817_item	2975581	et	4	main
meie	doc_553383122817_item	2975582	et	4	main
ewing	doc_553383122817_item	2975583	et	4	main
mõtisklesid	doc_553383122817_item	2975504	et	4	main
kes	doc_553383122817_item	2975505	et	4	main
kirjutas	doc_553383122817_item	2975512	et	3	main
sellise	doc_553383122817_item	2975515	et	4	main
helilooja	doc_553383122817_item	2975528	et	4	main
armastus	doc_553383122817_item	2975531	et	4	main
surematu	doc_553383122817_item	2975530	et	4	main
aga	doc_553383122817_item	2975532	et	3	main
deines	doc_553383122817_item	2975571	et	4	main
ewing	doc_553383122817_item	2975575	et	4	main
igavesti	doc_553383122817_item	2975577	et	4	main
minu	doc_553383122817_item	2975578	et	3	main
ewing	doc_553383122817_item	2975579	et	4	main
unss	doc_553383122817_item	2975584	et	4	main
222	doc_553383122817_item	2975585	et	2	main
beethoveni	doc_553383122817_item	2975591	et	4	main
algab	doc_553383122817_item	2975595	et	3	main
von	doc_553383122817_item	2975602	et	4	main
1752-1830	doc_553383122817_item	2975604	et	2	main
et	doc_553383122817_item	2975612	et	3	main
viinis	doc_553383122817_item	2975616	et	3	main
hakkavad	doc_553383122817_item	2975618	et	4	main
toolajal	doc_553383122817_item	2975619	et	4	main
juba	doc_553383122817_item	2975620	et	3	main
beethoveni	doc_553383122817_item	2975625	et	4	main
kiiresti	doc_553383122817_item	2975630	et	3	main
mida	doc_553383122817_item	2975676	et	4	main
võib	doc_553383122817_item	2975677	et	3	main
kanaarilind	doc_553383122817_item	2975689	et	3	main
flööti	doc_553383122817_item	2975691	et	4	main
mitmesugused	doc_553383122817_item	2975711	et	3	main
mozarti	doc_553383122817_item	2975715	et	4	main
joseph	doc_553383122817_item	2975718	et	4	main
deyem	doc_553383122817_item	2975719	et	4	main
oli	doc_553383122817_item	2975720	et	3	main
perekonna	doc_553383122817_item	2975728	et	4	main
hea	doc_553383122817_item	2975733	et	4	main
vaimustatud	doc_553383122817_item	2975738	et	4	main
krahvinna	doc_553383122817_item	2975757	et	4	main
vaimustuses	doc_553383122817_item	2975761	et	4	main
probleemid	doc_553383122817_item	2975767	et	3	main
on	doc_553383122817_item	2975771	et	4	main
brunswikide	doc_553383122817_item	2975779	et	4	main
perekonnalt	doc_553383122817_item	2975780	et	4	main
josephine	doc_553383122817_item	2975788	et	4	main
ennast	doc_553383122817_item	2975793	et	4	main
beethoven	doc_553383122817_item	2975801	et	4	main
joseph	doc_553383122817_item	2975808	et	4	main
üksi	doc_553383122817_item	2975828	et	4	main
masendatud	doc_553383122817_item	2975829	et	4	main
ja	doc_553383122817_item	2975830	et	3	main
läbi	doc_553383122817_item	2975831	et	4	main
beethoven	doc_553383122817_item	2975851	et	4	main
esineb	doc_553383122817_item	2975852	et	3	main
samuti	doc_553383122817_item	2975853	et	3	main
nagu	doc_553383122817_item	2975854	et	3	main
kirjutab	doc_553383122817_item	2975855	et	3	main
von	doc_553383122817_item	2975859	et	4	main
charming	doc_553383122817_item	2975863	et	4	main
josephine	doc_553383122817_item	2975873	et	4	main
always	doc_553383122817_item	2975876	et	4	main
inquires	doc_553383122817_item	2975877	et	4	main
selections	doc_553383122817_item	2975890	et	4	main
võib	doc_553383122817_item	2975895	et	3	main
järeldada	doc_553383122817_item	2975896	et	3	main
et	doc_553383122817_item	2975897	et	3	main
brunswikide	doc_553383122817_item	2975898	et	4	main
aina	doc_553383122817_item	2975903	et	4	main
helilooja	doc_553383122817_item	2975905	et	4	main
pühendab	doc_553383122817_item	2975906	et	3	main
therese	doc_553383122817_item	2975923	et	4	main
umbest	doc_553383122817_item	2975926	et	4	main
algabki	doc_553383122817_item	2975929	et	3	main
loo	doc_553383122817_item	2975931	et	4	main
traagilisus	doc_553383122817_item	2975932	et	4	main
millele	doc_553383122817_item	2975933	et	3	main
tunnid	doc_553383122817_item	2975943	et	3	main
comes	doc_553383122817_item	2975947	et	4	main
it	doc_553383122817_item	2975955	et	4	main
i	doc_553383122817_item	2975960	et	4	main
josephine	doc_553383122817_item	2975965	et	4	main
vastu	doc_553383122817_item	2975966	et	3	main
ei	doc_553383122817_item	2975978	et	4	main
ning	doc_553383122817_item	2975984	et	3	main
tema	doc_553383122817_item	2975987	et	4	main
ehk	doc_553383122817_item	2975988	et	3	main
your	doc_553383122817_item	2975993	et	4	main
kui	doc_553383122817_item	2975533	et	3	main
sinu	doc_553383122817_item	2975569	et	3	main
dein	doc_553383122817_item	2975576	et	4	main
õpilane	doc_553383122817_item	2975592	et	3	main
aasta	doc_553383122817_item	2975598	et	4	main
ema	doc_553383122817_item	2975600	et	4	main
anna	doc_553383122817_item	2975601	et	4	main
ungarist	doc_553383122817_item	2975610	et	4	main
helilooja	doc_553383122817_item	2975622	et	4	main
klaveritunde	doc_553383122817_item	2975627	et	4	main
võtta	doc_553383122817_item	2975628	et	3	main
sobilikku	doc_553383122817_item	2975633	et	4	main
mehe	doc_553383122817_item	2975634	et	3	main
josephine	doc_553383122817_item	2975669	et	4	main
kunstikambrit	doc_553383122817_item	2975675	et	3	main
omaaegseks	doc_553383122817_item	2975679	et	4	main
keskuses	doc_553383122817_item	2975681	et	4	main
on	doc_553383122817_item	2975682	et	4	main
eksootilised	doc_553383122817_item	2975683	et	3	main
ja	doc_553383122817_item	2975684	et	3	main
heroilised	doc_553383122817_item	2975685	et	3	main
vahakujud-	doc_553383122817_item	2975686	et	3	main
mehaaniline	doc_553383122817_item	2975687	et	3	main
negližees	doc_553383122817_item	2975697	et	2	main
isiklikult	doc_553383122817_item	2975721	et	4	main
tuttav	doc_553383122817_item	2975722	et	3	main
abiellumise	doc_553383122817_item	2975723	et	3	main
järel	doc_553383122817_item	2975724	et	4	main
vahel	doc_553383122817_item	2975730	et	4	main
on	doc_553383122817_item	2975735	et	4	main
1800	doc_553383122817_item	2975740	et	2	main
oma	doc_553383122817_item	2975744	et	4	main
theresele	doc_553383122817_item	2975746	et	4	main
kirja	doc_553383122817_item	2975747	et	4	main
kus	doc_553383122817_item	2975748	et	3	main
räägib	doc_553383122817_item	2975749	et	3	main
kuivõrd	doc_553383122817_item	2975756	et	3	main
tema	doc_553383122817_item	2975759	et	4	main
algavad	doc_553383122817_item	2975766	et	4	main
geliebten	doc_553383122817_item	2975572	et	4	main
josephine	doc_553383122817_item	2975587	et	4	main
tutvustus	doc_553383122817_item	2975594	et	4	main
1799	doc_553383122817_item	2975597	et	2	main
viini	doc_553383122817_item	2975611	et	4	main
tuntud	doc_553383122817_item	2975621	et	4	main
josephinale	doc_553383122817_item	2975632	et	4	main
ehk	doc_553383122817_item	2975635	et	3	main
ta	doc_553383122817_item	2975639	et	4	main
nende	doc_553383122817_item	2975644	et	4	main
pulmadeks	doc_553383122817_item	2975645	et	3	main
pühendab	doc_553383122817_item	2975646	et	3	main
beethoven	doc_553383122817_item	2975647	et	4	main
josephine	doc_553383122817_item	2975648	et	4	main
von	doc_553383122817_item	2975649	et	4	main
deymile	doc_553383122817_item	2975650	et	4	main
ja	doc_553383122817_item	2975651	et	3	main
tema	doc_553383122817_item	2975652	et	4	main
õele	doc_553383122817_item	2975653	et	3	main
variationen	doc_553383122817_item	2975654	et	4	main
über	doc_553383122817_item	2975655	et	4	main
ich	doc_553383122817_item	2975656	et	4	main
denke	doc_553383122817_item	2975657	et	4	main
dein	doc_553383122817_item	2975658	et	4	main
muusikapalu	doc_553383122817_item	2975659	et	4	main
ning	doc_553383122817_item	2975660	et	3	main
isegi	doc_553383122817_item	2975661	et	4	main
pärast	doc_553383122817_item	2975662	et	4	main
josephine	doc_553383122817_item	2975663	et	4	main
abiellumist	doc_553383122817_item	2975664	et	3	main
läkitab	doc_553383122817_item	2975665	et	3	main
naisele	doc_553383122817_item	2975666	et	3	main
õrnu	doc_553383122817_item	2975667	et	4	main
mein	doc_553383122817_item	2975580	et	4	main
armastuslugu	doc_553383122817_item	2975586	et	4	main
nende	doc_553383122817_item	2975593	et	4	main
kui	doc_553383122817_item	2975596	et	3	main
mais	doc_553383122817_item	2975599	et	4	main
brunswick	doc_553383122817_item	2975603	et	4	main
tuleb	doc_553383122817_item	2975605	et	3	main
neile	doc_553383122817_item	2975613	et	4	main
peigmehed	doc_553383122817_item	2975614	et	3	main
leida	doc_553383122817_item	2975615	et	3	main
ludwig	doc_553383122817_item	2975623	et	4	main
van	doc_553383122817_item	2975624	et	4	main
ema	doc_553383122817_item	2975629	et	4	main
deymi	doc_553383122817_item	2975637	et	4	main
von	doc_553383122817_item	2975672	et	4	main
multimeediakeskuseks	doc_553383122817_item	2975680	et	4	main
kaks	doc_553383122817_item	2975690	et	3	main
elusuuruses	doc_553383122817_item	2975696	et	4	main
tausta	doc_553383122817_item	2975709	et	4	main
muusikaautomaadid	doc_553383122817_item	2975712	et	4	main
mis	doc_553383122817_item	2975713	et	4	main
mängivad	doc_553383122817_item	2975714	et	4	main
deymi	doc_553383122817_item	2975729	et	4	main
josephine	doc_553383122817_item	2975734	et	4	main
oktoobris	doc_553383122817_item	2975739	et	3	main
ta	doc_553383122817_item	2975743	et	4	main
õele	doc_553383122817_item	2975745	et	3	main
ta	doc_553383122817_item	2975753	et	4	main
on	doc_553383122817_item	2975754	et	4	main
ja	doc_553383122817_item	2975755	et	3	main
elus	doc_553383122817_item	2975765	et	4	main
deymi	doc_553383122817_item	2975769	et	4	main
majanduslikult	doc_553383122817_item	2975770	et	4	main
ta	doc_553383122817_item	2975773	et	4	main
rikas	doc_553383122817_item	2975787	et	4	main
tütar	doc_553383122817_item	2975792	et	3	main
abielust	doc_553383122817_item	2975795	et	3	main
kuid	doc_553383122817_item	2975797	et	4	main
naine	doc_553383122817_item	2975826	et	3	main
on	doc_553383122817_item	2975827	et	4	main
tekivad	doc_553383122817_item	2975832	et	3	main
paraneb	doc_553383122817_item	2975841	et	3	main
brunwick	doc_553383122817_item	2975860	et	4	main
de	doc_553383122817_item	2975588	et	4	main
korompa	doc_553383122817_item	2975589	et	4	main
on	doc_553383122817_item	2975590	et	4	main
koos	doc_553383122817_item	2975606	et	4	main
kahe	doc_553383122817_item	2975607	et	3	main
oma	doc_553383122817_item	2975608	et	4	main
tütardega	doc_553383122817_item	2975609	et	3	main
neiud	doc_553383122817_item	2975617	et	4	main
juures	doc_553383122817_item	2975626	et	4	main
leiab	doc_553383122817_item	2975631	et	3	main
joseph	doc_553383122817_item	2975636	et	4	main
kellega	doc_553383122817_item	2975638	et	3	main
1799	doc_553383122817_item	2975640	et	2	main
aastal	doc_553383122817_item	2975641	et	3	main
tüdruk	doc_553383122817_item	2975642	et	3	main
abiellubki	doc_553383122817_item	2975643	et	3	main
kirju	doc_553383122817_item	2975668	et	4	main
mees	doc_553383122817_item	2975670	et	4	main
joseph	doc_553383122817_item	2975671	et	4	main
peab	doc_553383122817_item	2975674	et	4	main
laulev	doc_553383122817_item	2975688	et	4	main
poissi	doc_553383122817_item	2975695	et	4	main
klaveri	doc_553383122817_item	2975699	et	3	main
istuv	doc_553383122817_item	2975701	et	4	main
naine	doc_553383122817_item	2975702	et	3	main
pakuvad	doc_553383122817_item	2975710	et	3	main
kellega	doc_553383122817_item	2975717	et	3	main
on	doc_553383122817_item	2975725	et	4	main
beethoveni	doc_553383122817_item	2975726	et	4	main
ja	doc_553383122817_item	2975727	et	3	main
on	doc_553383122817_item	2975732	et	4	main
endiselt	doc_553383122817_item	2975737	et	4	main
kirjutab	doc_553383122817_item	2975742	et	3	main
sellest	doc_553383122817_item	2975750	et	4	main
kui	doc_553383122817_item	2975751	et	3	main
charming	doc_553383122817_item	2975752	et	4	main
josephine	doc_553383122817_item	2975764	et	4	main
nimelt	doc_553383122817_item	2975768	et	4	main
mitte	doc_553383122817_item	2975777	et	3	main
saanud	doc_553383122817_item	2975778	et	4	main
välja	doc_553383122817_item	2975783	et	4	main
et	doc_553383122817_item	2975784	et	3	main
ta	doc_553383122817_item	2975785	et	4	main
pole	doc_553383122817_item	2975786	et	3	main
et	doc_553383122817_item	2975791	et	3	main
ei	doc_553383122817_item	2975799	et	4	main
nõustu	doc_553383122817_item	2975800	et	4	main
raskel	doc_553383122817_item	2975804	et	3	main
deyemi	doc_553383122817_item	2975809	et	4	main
probleemid	doc_553383122817_item	2975835	et	3	main
novembriks	doc_553383122817_item	2975837	et	3	main
emotsionaalne	doc_553383122817_item	2975839	et	3	main
ta	doc_553383122817_item	2975843	et	4	main
josephine	doc_553383122817_item	2975856	et	4	main
almost	doc_553383122817_item	2975866	et	4	main
gives	doc_553383122817_item	2975871	et	4	main
pepi	doc_553383122817_item	2975872	et	4	main
after	doc_553383122817_item	2975878	et	4	main
composing	doc_553383122817_item	2975882	et	4	main
and	doc_553383122817_item	2975886	et	3	main
from	doc_553383122817_item	2975891	et	4	main
it	doc_553383122817_item	2975892	et	4	main
ja	doc_553383122817_item	2975900	et	3	main
brunswikile	doc_553383122817_item	2975925	et	4	main
perioodist	doc_553383122817_item	2975928	et	3	main
on	doc_553383122817_item	2975935	et	4	main
nimetab	doc_553383122817_item	2975941	et	3	main
beethoven	doc_553383122817_item	2975946	et	4	main
quite	doc_553383122817_item	2975948	et	4	main
frequently	doc_553383122817_item	2975949	et	4	main
a	doc_553383122817_item	2975957	et	4	main
must	doc_553383122817_item	2975961	et	4	main
confess	doc_553383122817_item	2975962	et	4	main
deymile	doc_553383122817_item	2975673	et	4	main
nimetada	doc_553383122817_item	2975678	et	3	main
mängivat	doc_553383122817_item	2975692	et	4	main
hispaania	doc_553383122817_item	2975693	et	4	main
riietuses	doc_553383122817_item	2975694	et	4	main
isemängiva	doc_553383122817_item	2975698	et	3	main
ees	doc_553383122817_item	2975700	et	4	main
kõrgeltsündinud	doc_553383122817_item	2975703	et	3	main
isikute	doc_553383122817_item	2975704	et	4	main
büstid	doc_553383122817_item	2975705	et	3	main
antiikkujude	doc_553383122817_item	2975706	et	3	main
koopiat	doc_553383122817_item	2975707	et	3	main
muusikalist	doc_553383122817_item	2975708	et	4	main
muusikat	doc_553383122817_item	2975716	et	3	main
läbisaamine	doc_553383122817_item	2975731	et	4	main
beethovenist	doc_553383122817_item	2975736	et	4	main
aastal	doc_553383122817_item	2975741	et	3	main
on	doc_553383122817_item	2975758	et	4	main
loomingust	doc_553383122817_item	2975760	et	3	main
1800	doc_553383122817_item	2975762	et	2	main
aastast	doc_553383122817_item	2975763	et	4	main
põhjas	doc_553383122817_item	2975772	et	4	main
on	doc_553383122817_item	2975774	et	4	main
lootnud	doc_553383122817_item	2975775	et	4	main
kaasvara	doc_553383122817_item	2975781	et	4	main
ema	doc_553383122817_item	2975789	et	4	main
on	doc_553383122817_item	2975802	et	4	main
perioodil	doc_553383122817_item	2975805	et	3	main
rasedana	doc_553383122817_item	2975825	et	3	main
ka	doc_553383122817_item	2975833	et	3	main
kuid	doc_553383122817_item	2975836	et	4	main
krahvina	doc_553383122817_item	2975838	et	3	main
seisund	doc_553383122817_item	2975840	et	3	main
korraldab	doc_553383122817_item	2975844	et	3	main
kodus	doc_553383122817_item	2975846	et	4	main
jälle	doc_553383122817_item	2975847	et	3	main
muusikalisi	doc_553383122817_item	2975848	et	4	main
suareesid	doc_553383122817_item	2975849	et	3	main
kus	doc_553383122817_item	2975850	et	3	main
is	doc_553383122817_item	2975862	et	4	main
he	doc_553383122817_item	2975864	et	4	main
comes	doc_553383122817_item	2975865	et	4	main
you	doc_553383122817_item	2975879	et	4	main
some	doc_553383122817_item	2975889	et	4	main
kust	doc_553383122817_item	2975894	et	4	main
beethoveni	doc_553383122817_item	2975901	et	4	main
side	doc_553383122817_item	2975902	et	4	main
kasvab	doc_553383122817_item	2975904	et	3	main
nr	doc_553383122817_item	2975921	et	4	main
24	doc_553383122817_item	2975922	et	2	main
sellest	doc_553383122817_item	2975927	et	4	main
charlotte	doc_553383122817_item	2975936	et	4	main
beethoveni	doc_553383122817_item	2975942	et	4	main
he	doc_553383122817_item	2975950	et	4	main
is	doc_553383122817_item	2975951	et	4	main
tema	doc_553383122817_item	2975970	et	4	main
kus	doc_553383122817_item	2975972	et	3	main
et	doc_553383122817_item	2975976	et	3	main
ta	doc_553383122817_item	2975977	et	4	main
piisavalt	doc_553383122817_item	2975982	et	4	main
in	doc_553383122817_item	2975991	et	4	main
varsi	doc_553383122817_item	2975995	et	4	main
on	doc_553383122817_item	2976015	et	4	main
seda	doc_553383122817_item	2976016	et	3	main
märganud	doc_553383122817_item	2976017	et	4	main
arvas	doc_553383122817_item	2976022	et	3	main
muusa	doc_553383122817_item	2976034	et	4	main
ta	doc_553383122817_item	2976036	et	4	main
inspireerib	doc_553383122817_item	2976037	et	3	main
teda	doc_553383122817_item	2976038	et	4	main
an	doc_553383122817_item	2976044	et	4	main
die	doc_553383122817_item	2976045	et	4	main
hoffnung	doc_553383122817_item	2976046	et	4	main
op53	doc_553383122817_item	2976055	et	4	main
1805	doc_553383122817_item	2976056	et	2	main
aastal	doc_553383122817_item	2976057	et	3	main
kuid	doc_553383122817_item	2975776	et	4	main
tuleb	doc_553383122817_item	2975782	et	3	main
soovib	doc_553383122817_item	2975790	et	3	main
sellest	doc_553383122817_item	2975794	et	4	main
lahutaks	doc_553383122817_item	2975796	et	3	main
naine	doc_553383122817_item	2975798	et	3	main
sellel	doc_553383122817_item	2975803	et	4	main
josephine	doc_553383122817_item	2975806	et	4	main
ja	doc_553383122817_item	2975807	et	3	main
truu	doc_553383122817_item	2975810	et	4	main
sõber	doc_553383122817_item	2975811	et	3	main
ja	doc_553383122817_item	2975812	et	3	main
lohutaja	doc_553383122817_item	2975813	et	4	main
josephine	doc_553383122817_item	2975814	et	4	main
mees	doc_553383122817_item	2975815	et	4	main
sureb	doc_553383122817_item	2975816	et	3	main
8	doc_553383122817_item	2975817	et	2	main
jaanuaril	doc_553383122817_item	2975818	et	3	main
tiisikusse	doc_553383122817_item	2975819	et	3	main
jättes	doc_553383122817_item	2975820	et	4	main
teda	doc_553383122817_item	2975821	et	4	main
kolme	doc_553383122817_item	2975822	et	4	main
lapse	doc_553383122817_item	2975823	et	4	main
ja	doc_553383122817_item	2975824	et	3	main
rahalised	doc_553383122817_item	2975834	et	4	main
ja	doc_553383122817_item	2975842	et	3	main
oma	doc_553383122817_item	2975845	et	4	main
õde	doc_553383122817_item	2975857	et	4	main
charlotte	doc_553383122817_item	2975858	et	4	main
beethoven	doc_553383122817_item	2975861	et	4	main
every	doc_553383122817_item	2975867	et	4	main
second	doc_553383122817_item	2975868	et	4	main
and	doc_553383122817_item	2975870	et	3	main
lessons	doc_553383122817_item	2975874	et	4	main
he	doc_553383122817_item	2975880	et	4	main
an	doc_553383122817_item	2975883	et	4	main
and	doc_553383122817_item	2975885	et	3	main
perekonna	doc_553383122817_item	2975899	et	4	main
tõestuseks	doc_553383122817_item	2975934	et	4	main
ta	doc_553383122817_item	2975940	et	4	main
ohtlikeks	doc_553383122817_item	2975945	et	3	main
giving	doc_553383122817_item	2975952	et	4	main
pepi	doc_553383122817_item	2975953	et	4	main
lessons	doc_553383122817_item	2975954	et	4	main
on	doc_553383122817_item	2975967	et	4	main
näha	doc_553383122817_item	2975968	et	3	main
pööranud	doc_553383122817_item	2975979	et	4	main
nimetab	doc_553383122817_item	2975985	et	3	main
beethoveniks	doc_553383122817_item	2975990	et	4	main
beethoven	doc_553383122817_item	2975994	et	4	main
tundeid	doc_553383122817_item	2975997	et	3	main
lichnowsky	doc_553383122817_item	2976014	et	4	main
helolooja	doc_553383122817_item	2976028	et	4	main
lootuseks	doc_553383122817_item	2976047	et	4	main
op	doc_553383122817_item	2976048	et	4	main
21	doc_553383122817_item	2976053	et	2	main
ja	doc_553383122817_item	2976070	et	3	main
tähtis	doc_553383122817_item	2976072	et	4	main
on	doc_553383122817_item	2976074	et	4	main
there	doc_553383122817_item	2976078	et	4	main
you	doc_553383122817_item	2976092	et	4	main
all	doc_553383122817_item	2976093	et	3	main
my	doc_553383122817_item	2976094	et	4	main
feeling	doc_553383122817_item	2976102	et	4	main
my	doc_553383122817_item	2976107	et	4	main
no	doc_553383122817_item	2976118	et	3	main
one	doc_553383122817_item	2976119	et	4	main
sorrows	doc_553383122817_item	2976130	et	4	main
and	doc_553383122817_item	2976131	et	3	main
the	doc_553383122817_item	2976132	et	4	main
god	doc_553383122817_item	2976140	et	4	main
things	doc_553383122817_item	2976146	et	4	main
tell	doc_553383122817_item	2976151	et	4	main
feel	doc_553383122817_item	2976161	et	3	main
words	doc_553383122817_item	2976171	et	4	main
josephine	doc_553383122817_item	2976179	et	4	main
vastab	doc_553383122817_item	2976180	et	3	main
temale	doc_553383122817_item	2976181	et	3	main
can	doc_553383122817_item	2976188	et	4	main
felt	doc_553383122817_item	2976197	et	4	main
enthusiasm	doc_553383122817_item	2976198	et	4	main
for	doc_553383122817_item	2976199	et	4	main
personally	doc_553383122817_item	2976204	et	4	main
lies	doc_553383122817_item	2976208	et	4	main
my	doc_553383122817_item	2976211	et	4	main
love	doc_553383122817_item	2976219	et	4	main
süüdistavad	doc_553383122817_item	2976250	et	4	main
kirjas	doc_553383122817_item	2976253	et	4	main
mis	doc_553383122817_item	2976256	et	4	main
kõlab	doc_553383122817_item	2976257	et	3	main
nagu	doc_553383122817_item	2976258	et	3	main
lahkumiskiri	doc_553383122817_item	2976259	et	3	main
not	doc_553383122817_item	2976265	et	4	main
protest	doc_553383122817_item	2976266	et	3	main
day	doc_553383122817_item	2975869	et	4	main
he	doc_553383122817_item	2975875	et	4	main
is	doc_553383122817_item	2975881	et	4	main
opera	doc_553383122817_item	2975884	et	4	main
played	doc_553383122817_item	2975887	et	4	main
us	doc_553383122817_item	2975888	et	4	main
charming	doc_553383122817_item	2975893	et	4	main
1805	doc_553383122817_item	2975907	et	2	main
aastal	doc_553383122817_item	2975908	et	3	main
kirjutatud	doc_553383122817_item	2975909	et	4	main
klaversonaati	doc_553383122817_item	2975910	et	4	main
nr	doc_553383122817_item	2975911	et	4	main
23	doc_553383122817_item	2975912	et	2	main
franz	doc_553383122817_item	2975913	et	4	main
von	doc_553383122817_item	2975914	et	4	main
brunswikile	doc_553383122817_item	2975915	et	4	main
ning	doc_553383122817_item	2975916	et	3	main
1809	doc_553383122817_item	2975917	et	2	main
aastal	doc_553383122817_item	2975918	et	3	main
ilmunud	doc_553383122817_item	2975919	et	4	main
klaversonaati	doc_553383122817_item	2975920	et	4	main
von	doc_553383122817_item	2975924	et	4	main
kogu	doc_553383122817_item	2975930	et	4	main
kiri	doc_553383122817_item	2975937	et	3	main
theresiale	doc_553383122817_item	2975938	et	4	main
et	doc_553383122817_item	2975939	et	3	main
josephinale	doc_553383122817_item	2975944	et	4	main
is	doc_553383122817_item	2975956	et	4	main
bit	doc_553383122817_item	2975958	et	4	main
dangerous	doc_553383122817_item	2975959	et	4	main
beethoveni	doc_553383122817_item	2975963	et	4	main
tunded	doc_553383122817_item	2975964	et	3	main
ka	doc_553383122817_item	2975969	et	3	main
kirjades	doc_553383122817_item	2975971	et	3	main
ta	doc_553383122817_item	2975973	et	4	main
on	doc_553383122817_item	2975974	et	4	main
murelik	doc_553383122817_item	2975975	et	3	main
armastatu	doc_553383122817_item	2975980	et	4	main
ennast	doc_553383122817_item	2975986	et	4	main
haste	doc_553383122817_item	2975992	et	4	main
nende	doc_553383122817_item	2975996	et	4	main
märgavad	doc_553383122817_item	2975998	et	4	main
nende	doc_553383122817_item	2976000	et	4	main
tema	doc_553383122817_item	2976011	et	4	main
patroon	doc_553383122817_item	2976012	et	3	main
kuid	doc_553383122817_item	2976018	et	4	main
kiitis	doc_553383122817_item	2976019	et	3	main
et	doc_553383122817_item	2976023	et	3	main
on	doc_553383122817_item	2976032	et	4	main
helilooja	doc_553383122817_item	2976039	et	4	main
pühendab	doc_553383122817_item	2976040	et	3	main
temale	doc_553383122817_item	2976041	et	3	main
sonaate	doc_553383122817_item	2976042	et	3	main
32	doc_553383122817_item	2976049	et	2	main
which	doc_553383122817_item	2976082	et	4	main
far	doc_553383122817_item	2976087	et	4	main
hapiness	doc_553383122817_item	2976095	et	4	main
some	doc_553383122817_item	2976098	et	4	main
adored	doc_553383122817_item	2976108	et	4	main
j	doc_553383122817_item	2976109	et	4	main
to	doc_553383122817_item	2976120	et	4	main
hear	doc_553383122817_item	2976125	et	4	main
all	doc_553383122817_item	2976126	et	3	main
death	doc_553383122817_item	2976137	et	4	main
and	doc_553383122817_item	2976138	et	3	main
many	doc_553383122817_item	2976144	et	4	main
love	doc_553383122817_item	2976149	et	4	main
what	doc_553383122817_item	2976159	et	4	main
beethoveni	doc_553383122817_item	2976172	et	4	main
ta	doc_553383122817_item	2976182	et	4	main
your	doc_553383122817_item	2976192	et	4	main
which	doc_553383122817_item	2976207	et	4	main
ineffable	doc_553383122817_item	2976216	et	4	main
made	doc_553383122817_item	2976217	et	3	main
ühes	doc_553383122817_item	2976252	et	4	main
josephine	doc_553383122817_item	2976254	et	4	main
your	doc_553383122817_item	2976262	et	4	main
does	doc_553383122817_item	2976264	et	4	main
accuse	doc_553383122817_item	2976269	et	4	main
me	doc_553383122817_item	2976270	et	4	main
do	doc_553383122817_item	2976275	et	4	main
you	doc_553383122817_item	2976283	et	4	main
value	doc_553383122817_item	2976292	et	4	main
have	doc_553383122817_item	2976297	et	4	main
demonstrated	doc_553383122817_item	2976298	et	4	main
me	doc_553383122817_item	2976306	et	4	main
and	doc_553383122817_item	2976307	et	3	main
will	doc_553383122817_item	2976322	et	4	main
always	doc_553383122817_item	2976323	et	4	main
an	doc_553383122817_item	2976325	et	4	main
interest	doc_553383122817_item	2976326	et	4	main
to	doc_553383122817_item	2976332	et	4	main
can	doc_553383122817_item	2976337	et	4	main
take	doc_553383122817_item	2976342	et	4	main
if	doc_553383122817_item	2976345	et	4	main
lastega	doc_553383122817_item	2976353	et	3	main
mõisa	doc_553383122817_item	2976356	et	3	main
ja	doc_553383122817_item	2976358	et	3	main
kokkusaamatus	doc_553383122817_item	2976372	et	4	main
on	doc_553383122817_item	2976378	et	4	main
pärast	doc_553383122817_item	2976386	et	4	main
aasta	doc_553383122817_item	2976394	et	4	main
few	doc_553383122817_item	2976401	et	4	main
sõnadele	doc_553383122817_item	2975981	et	3	main
tähelepanu	doc_553383122817_item	2975983	et	4	main
josephine	doc_553383122817_item	2975989	et	4	main
ka	doc_553383122817_item	2975999	et	3	main
lähedased	doc_553383122817_item	2976001	et	3	main
perekond	doc_553383122817_item	2976002	et	3	main
sõbrad	doc_553383122817_item	2976003	et	3	main
ühest	doc_553383122817_item	2976005	et	4	main
oma	doc_553383122817_item	2976006	et	4	main
kirjadest	doc_553383122817_item	2976007	et	3	main
jutustab	doc_553383122817_item	2976008	et	3	main
beethoven	doc_553383122817_item	2976009	et	4	main
et	doc_553383122817_item	2976010	et	3	main
kuna	doc_553383122817_item	2976021	et	3	main
tunded	doc_553383122817_item	2976025	et	3	main
loomingu	doc_553383122817_item	2976029	et	3	main
tõepoolest	doc_553383122817_item	2976030	et	3	main
josephine	doc_553383122817_item	2976031	et	4	main
beethovenile	doc_553383122817_item	2976035	et	4	main
laulu	doc_553383122817_item	2976050	et	4	main
beethoven	doc_553383122817_item	2976058	et	4	main
unistab	doc_553383122817_item	2976059	et	3	main
nende	doc_553383122817_item	2976060	et	4	main
armastusest	doc_553383122817_item	2976061	et	4	main
kirjutab	doc_553383122817_item	2976062	et	3	main
talle	doc_553383122817_item	2976063	et	4	main
tunnistab	doc_553383122817_item	2976064	et	3	main
kui	doc_553383122817_item	2976065	et	3	main
palju	doc_553383122817_item	2976066	et	4	main
ta	doc_553383122817_item	2976067	et	4	main
mõtleb	doc_553383122817_item	2976068	et	3	main
why	doc_553383122817_item	2976077	et	4	main
is	doc_553383122817_item	2976079	et	4	main
no	doc_553383122817_item	2976080	et	3	main
language	doc_553383122817_item	2976081	et	4	main
what	doc_553383122817_item	2976085	et	4	main
is	doc_553383122817_item	2976086	et	4	main
for	doc_553383122817_item	2976097	et	4	main
time	doc_553383122817_item	2976099	et	4	main
after	doc_553383122817_item	2976100	et	4	main
for	doc_553383122817_item	2976105	et	4	main
as	doc_553383122817_item	2976110	et	4	main
soon	doc_553383122817_item	2976111	et	3	main
disturb	doc_553383122817_item	2976121	et	4	main
about	doc_553383122817_item	2976127	et	4	main
struggle	doc_553383122817_item	2976133	et	4	main
myself	doc_553383122817_item	2976135	et	4	main
between	doc_553383122817_item	2976136	et	4	main
there	doc_553383122817_item	2976141	et	4	main
are	doc_553383122817_item	2976142	et	3	main
so	doc_553383122817_item	2976143	et	4	main
i	doc_553383122817_item	2976147	et	4	main
should	doc_553383122817_item	2976148	et	4	main
much	doc_553383122817_item	2976154	et	4	main
think	doc_553383122817_item	2976156	et	4	main
poor	doc_553383122817_item	2976168	et	3	main
ole	doc_553383122817_item	2976175	et	4	main
ühepoolsed	doc_553383122817_item	2976177	et	3	main
kuna	doc_553383122817_item	2976178	et	3	main
it	doc_553383122817_item	2976184	et	4	main
lessen	doc_553383122817_item	2976189	et	4	main
feelings	doc_553383122817_item	2976193	et	4	main
soul	doc_553383122817_item	2976195	et	4	main
which	doc_553383122817_item	2976196	et	4	main
you	doc_553383122817_item	2976200	et	4	main
before	doc_553383122817_item	2976201	et	4	main
feeling	doc_553383122817_item	2976206	et	4	main
deep	doc_553383122817_item	2976209	et	4	main
soul	doc_553383122817_item	2976212	et	4	main
and	doc_553383122817_item	2976213	et	3	main
which	doc_553383122817_item	2976214	et	4	main
me	doc_553383122817_item	2976218	et	4	main
näiteks	doc_553383122817_item	2976004	et	4	main
prints	doc_553383122817_item	2976013	et	3	main
heaks	doc_553383122817_item	2976020	et	4	main
nende	doc_553383122817_item	2976024	et	4	main
positiivselt	doc_553383122817_item	2976026	et	4	main
mõjutavad	doc_553383122817_item	2976027	et	4	main
nagu	doc_553383122817_item	2976033	et	3	main
laulu	doc_553383122817_item	2976043	et	4	main
klaverisonaadi	doc_553383122817_item	2976051	et	3	main
nr	doc_553383122817_item	2976052	et	4	main
aurora	doc_553383122817_item	2976054	et	4	main
temast	doc_553383122817_item	2976069	et	3	main
kui	doc_553383122817_item	2976071	et	3	main
naine	doc_553383122817_item	2976073	et	3	main
tema	doc_553383122817_item	2976075	et	4	main
jaoks	doc_553383122817_item	2976076	et	4	main
express	doc_553383122817_item	2976084	et	4	main
regard---you	doc_553383122817_item	2976091	et	4	main
and	doc_553383122817_item	2976096	et	3	main
of	doc_553383122817_item	2976103	et	4	main
love	doc_553383122817_item	2976104	et	4	main
together	doc_553383122817_item	2976115	et	4	main
us	doc_553383122817_item	2976122	et	4	main
my	doc_553383122817_item	2976128	et	4	main
real	doc_553383122817_item	2976129	et	3	main
life	doc_553383122817_item	2976139	et	4	main
more	doc_553383122817_item	2976145	et	4	main
to	doc_553383122817_item	2976150	et	4	main
how	doc_553383122817_item	2976153	et	4	main
i	doc_553383122817_item	2976160	et	4	main
for	doc_553383122817_item	2976162	et	4	main
can	doc_553383122817_item	2976083	et	4	main
above	doc_553383122817_item	2976088	et	4	main
all	doc_553383122817_item	2976089	et	3	main
mere	doc_553383122817_item	2976090	et	3	main
the	doc_553383122817_item	2976101	et	4	main
you	doc_553383122817_item	2976106	et	4	main
as	doc_553383122817_item	2976112	et	4	main
we	doc_553383122817_item	2976113	et	4	main
are	doc_553383122817_item	2976114	et	3	main
again	doc_553383122817_item	2976116	et	4	main
with	doc_553383122817_item	2976117	et	4	main
you	doc_553383122817_item	2976123	et	4	main
shall	doc_553383122817_item	2976124	et	4	main
with	doc_553383122817_item	2976134	et	4	main
you	doc_553383122817_item	2976152	et	4	main
i	doc_553383122817_item	2976155	et	4	main
of	doc_553383122817_item	2976157	et	4	main
you	doc_553383122817_item	2976158	et	4	main
you	doc_553383122817_item	2976163	et	4	main
but	doc_553383122817_item	2976164	et	4	main
how	doc_553383122817_item	2976165	et	4	main
weak	doc_553383122817_item	2976166	et	4	main
and	doc_553383122817_item	2976167	et	3	main
those	doc_553383122817_item	2976170	et	4	main
tunned	doc_553383122817_item	2976173	et	3	main
kirjutab	doc_553383122817_item	2976183	et	3	main
is	doc_553383122817_item	2976185	et	4	main
you	doc_553383122817_item	2976186	et	4	main
heighten	doc_553383122817_item	2976191	et	4	main
my	doc_553383122817_item	2976194	et	4	main
a	doc_553383122817_item	2976205	et	4	main
in	doc_553383122817_item	2976210	et	4	main
kirjutab	doc_553383122817_item	2976255	et	3	main
nagu	doc_553383122817_item	2976260	et	3	main
know	doc_553383122817_item	2976277	et	4	main
me	doc_553383122817_item	2976285	et	4	main
i	doc_553383122817_item	2976288	et	4	main
much	doc_553383122817_item	2976299	et	4	main
that	doc_553383122817_item	2976300	et	4	main
long	doc_553383122817_item	2976317	et	4	main
your	doc_553383122817_item	2976328	et	4	main
happiness	doc_553383122817_item	2976334	et	4	main
josephine	doc_553383122817_item	2976351	et	4	main
oma	doc_553383122817_item	2976355	et	4	main
disloyality	doc_553383122817_item	2976369	et	4	main
või	doc_553383122817_item	2976373	et	4	main
josephine	doc_553383122817_item	2976380	et	4	main
viibib	doc_553383122817_item	2976381	et	3	main
oma	doc_553383122817_item	2976382	et	4	main
mõisas	doc_553383122817_item	2976383	et	3	main
2	doc_553383122817_item	2976384	et	2	main
aastat	doc_553383122817_item	2976385	et	3	main
taas	doc_553383122817_item	2976392	et	3	main
1907	doc_553383122817_item	2976393	et	2	main
a	doc_553383122817_item	2976400	et	4	main
a	doc_553383122817_item	2976404	et	4	main
i	doc_553383122817_item	2976419	et	4	main
with	doc_553383122817_item	2976460	et	4	main
just	doc_553383122817_item	2976464	et	3	main
into	doc_553383122817_item	2976466	et	4	main
are	doc_553383122817_item	2976169	et	3	main
ei	doc_553383122817_item	2976174	et	4	main
päris	doc_553383122817_item	2976176	et	4	main
who	doc_553383122817_item	2976187	et	4	main
or	doc_553383122817_item	2976190	et	4	main
iknow	doc_553383122817_item	2976202	et	4	main
you	doc_553383122817_item	2976203	et	4	main
is	doc_553383122817_item	2976215	et	4	main
you	doc_553383122817_item	2976220	et	4	main
selline	doc_553383122817_item	2976221	et	4	main
tundeline	doc_553383122817_item	2976222	et	4	main
kirjavahetus	doc_553383122817_item	2976223	et	4	main
kestab	doc_553383122817_item	2976224	et	4	main
mitu	doc_553383122817_item	2976225	et	4	main
aastaid	doc_553383122817_item	2976226	et	4	main
nad	doc_553383122817_item	2976227	et	3	main
kohtuvad	doc_553383122817_item	2976228	et	4	main
vahetevahel	doc_553383122817_item	2976229	et	3	main
beethoven	doc_553383122817_item	2976230	et	4	main
annab	doc_553383122817_item	2976231	et	3	main
josephinele	doc_553383122817_item	2976232	et	4	main
klaveritunde	doc_553383122817_item	2976233	et	4	main
kuid	doc_553383122817_item	2976234	et	4	main
pole	doc_553383122817_item	2976235	et	3	main
teada	doc_553383122817_item	2976236	et	3	main
miks	doc_553383122817_item	2976237	et	4	main
aga	doc_553383122817_item	2976238	et	3	main
järsult	doc_553383122817_item	2976239	et	4	main
nende	doc_553383122817_item	2976240	et	4	main
vahel	doc_553383122817_item	2976241	et	4	main
ilmub	doc_553383122817_item	2976242	et	3	main
mingi	doc_553383122817_item	2976243	et	4	main
arusaamatus	doc_553383122817_item	2976244	et	4	main
oma	doc_553383122817_item	2976245	et	4	main
viimastes	doc_553383122817_item	2976246	et	3	main
kirjades	doc_553383122817_item	2976247	et	3	main
nad	doc_553383122817_item	2976248	et	3	main
nagu	doc_553383122817_item	2976249	et	3	main
teineteist	doc_553383122817_item	2976251	et	4	main
heart	doc_553383122817_item	2976263	et	4	main
when	doc_553383122817_item	2976267	et	4	main
you	doc_553383122817_item	2976268	et	4	main
heart	doc_553383122817_item	2976282	et	4	main
dear	doc_553383122817_item	2976302	et	4	main
my	doc_553383122817_item	2976308	et	4	main
i	doc_553383122817_item	2976311	et	4	main
never	doc_553383122817_item	2976313	et	4	main
live	doc_553383122817_item	2976320	et	4	main
take	doc_553383122817_item	2976324	et	4	main
contribute	doc_553383122817_item	2976331	et	4	main
i	doc_553383122817_item	2976336	et	4	main
not	doc_553383122817_item	2976341	et	4	main
amiss	doc_553383122817_item	2976344	et	4	main
i	doc_553383122817_item	2976346	et	4	main
pärast	doc_553383122817_item	2976347	et	4	main
1805	doc_553383122817_item	2976348	et	2	main
aastal	doc_553383122817_item	2976349	et	3	main
lahkub	doc_553383122817_item	2976350	et	3	main
hüvastijätt	doc_553383122817_item	2976261	et	3	main
of	doc_553383122817_item	2976271	et	4	main
certain	doc_553383122817_item	2976272	et	4	main
things	doc_553383122817_item	2976273	et	4	main
you	doc_553383122817_item	2976274	et	4	main
how	doc_553383122817_item	2976278	et	4	main
you	doc_553383122817_item	2976279	et	4	main
hurt	doc_553383122817_item	2976280	et	3	main
my	doc_553383122817_item	2976281	et	4	main
treat	doc_553383122817_item	2976284	et	4	main
wrongly	doc_553383122817_item	2976287	et	4	main
love	doc_553383122817_item	2976289	et	4	main
you	doc_553383122817_item	2976290	et	4	main
and	doc_553383122817_item	2976291	et	3	main
you	doc_553383122817_item	2976296	et	4	main
and	doc_553383122817_item	2976303	et	3	main
kind	doc_553383122817_item	2976304	et	4	main
to	doc_553383122817_item	2976305	et	4	main
that	doc_553383122817_item	2976310	et	4	main
as	doc_553383122817_item	2976318	et	4	main
i	doc_553383122817_item	2976319	et	4	main
in	doc_553383122817_item	2976327	et	4	main
your	doc_553383122817_item	2976333	et	4	main
but	doc_553383122817_item	2976338	et	4	main
koos	doc_553383122817_item	2976352	et	4	main
kas	doc_553383122817_item	2976370	et	3	main
pettumus	doc_553383122817_item	2976374	et	4	main
nende	doc_553383122817_item	2976376	et	4	main
vahel	doc_553383122817_item	2976377	et	4	main
sügisel	doc_553383122817_item	2976395	et	3	main
beethoven	doc_553383122817_item	2976396	et	4	main
kirjutab	doc_553383122817_item	2976397	et	3	main
lines	doc_553383122817_item	2976402	et	4	main
few	doc_553383122817_item	2976405	et	4	main
have	doc_553383122817_item	2976409	et	4	main
me	doc_553383122817_item	2976411	et	4	main
pleasure	doc_553383122817_item	2976413	et	4	main
after	doc_553383122817_item	2976418	et	4	main
heaven	doc_553383122817_item	2976424	et	4	main
united	doc_553383122817_item	2976459	et	4	main
am	doc_553383122817_item	2976463	et	4	main
town	doc_553383122817_item	2976467	et	4	main
could	doc_553383122817_item	2976471	et	4	main
if	doc_553383122817_item	2976477	et	4	main
i	doc_553383122817_item	2976483	et	4	main
third	doc_553383122817_item	2976487	et	4	main
ilmselt	doc_553383122817_item	2976502	et	4	main
beethoven	doc_553383122817_item	2976506	et	4	main
josephine	doc_553383122817_item	2976510	et	4	main
millegi	doc_553383122817_item	2976517	et	4	main
i	doc_553383122817_item	2976529	et	4	main
jargmisel	doc_553383122817_item	2976534	et	4	main
päeval	doc_553383122817_item	2976535	et	3	main
suaree	doc_553383122817_item	2976540	et	4	main
jälle	doc_553383122817_item	2976543	et	3	main
mingi	doc_553383122817_item	2976545	et	4	main
i	doc_553383122817_item	2976557	et	4	main
did	doc_553383122817_item	2976558	et	4	main
dear	doc_553383122817_item	2976564	et	4	main
you	doc_553383122817_item	2976568	et	4	main
i	doc_553383122817_item	2976574	et	4	main
of	doc_553383122817_item	2976578	et	4	main
conventional	doc_553383122817_item	2976580	et	4	main
code	doc_553383122817_item	2976581	et	4	main
deem	doc_553383122817_item	2976586	et	4	main
beg	doc_553383122817_item	2976595	et	4	main
well	doc_553383122817_item	2976610	et	4	main
for	doc_553383122817_item	2976616	et	4	main
esteem	doc_553383122817_item	2976621	et	4	main
weaker	doc_553383122817_item	2976632	et	4	main
sorry	doc_553383122817_item	2976638	et	4	main
be	doc_553383122817_item	2976643	et	4	main
you	doc_553383122817_item	2976647	et	4	main
it	doc_553383122817_item	2976649	et	4	main
peace	doc_553383122817_item	2976654	et	4	main
not	doc_553383122817_item	2976659	et	4	main
223	doc_553383122817_item	2976676	et	2	main
nad	doc_553383122817_item	2976679	et	3	main
õpetaja	doc_553383122817_item	2976689	et	4	main
seisis	doc_553383122817_item	2976694	et	4	main
suur	doc_553383122817_item	2976695	et	3	main
müür	doc_553383122817_item	2976696	et	3	main
nimega	doc_553383122817_item	2976697	et	3	main
not	doc_553383122817_item	2976276	et	4	main
quite	doc_553383122817_item	2976286	et	4	main
your	doc_553383122817_item	2976293	et	4	main
moral	doc_553383122817_item	2976294	et	4	main
character	doc_553383122817_item	2976295	et	4	main
is	doc_553383122817_item	2976301	et	4	main
children	doc_553383122817_item	2976309	et	4	main
will	doc_553383122817_item	2976312	et	4	main
forget	doc_553383122817_item	2976314	et	4	main
and	doc_553383122817_item	2976315	et	3	main
as	doc_553383122817_item	2976316	et	4	main
i	doc_553383122817_item	2976321	et	4	main
fate	doc_553383122817_item	2976329	et	4	main
and	doc_553383122817_item	2976330	et	3	main
what	doc_553383122817_item	2976335	et	4	main
you	doc_553383122817_item	2976339	et	4	main
must	doc_553383122817_item	2976340	et	4	main
it	doc_553383122817_item	2976343	et	4	main
viinist	doc_553383122817_item	2976354	et	3	main
ungarisse	doc_553383122817_item	2976357	et	4	main
beethoven	doc_553383122817_item	2976359	et	4	main
kirjutab	doc_553383122817_item	2976360	et	3	main
laulu	doc_553383122817_item	2976361	et	4	main
tunded	doc_553383122817_item	2976362	et	3	main
lydia	doc_553383122817_item	2976363	et	4	main
truudusetuse	doc_553383122817_item	2976364	et	4	main
üle	doc_553383122817_item	2976365	et	3	main
feelings	doc_553383122817_item	2976366	et	4	main
over	doc_553383122817_item	2976367	et	4	main
on	doc_553383122817_item	2976371	et	4	main
mis	doc_553383122817_item	2976375	et	4	main
tuleb	doc_553383122817_item	2976387	et	3	main
tagasi	doc_553383122817_item	2976389	et	3	main
again	doc_553383122817_item	2976398	et	4	main
even	doc_553383122817_item	2976399	et	4	main
from	doc_553383122817_item	2976407	et	4	main
or	doc_553383122817_item	2976415	et	4	main
the	doc_553383122817_item	2976416	et	4	main
shall	doc_553383122817_item	2976420	et	4	main
see	doc_553383122817_item	2976421	et	3	main
you	doc_553383122817_item	2976422	et	4	main
be	doc_553383122817_item	2976458	et	4	main
coming	doc_553383122817_item	2976465	et	4	main
almost	doc_553383122817_item	2976472	et	4	main
letter	doc_553383122817_item	2976475	et	4	main
myself	doc_553383122817_item	2976476	et	4	main
not	doc_553383122817_item	2976480	et	4	main
suspect	doc_553383122817_item	2976481	et	4	main
for	doc_553383122817_item	2976485	et	4	main
the	doc_553383122817_item	2976486	et	4	main
arvatavasti	doc_553383122817_item	2976493	et	3	main
kohtuvad	doc_553383122817_item	2976495	et	4	main
suareel	doc_553383122817_item	2976498	et	3	main
lausa	doc_553383122817_item	2976515	et	4	main
it	doc_553383122817_item	2976520	et	4	main
to	doc_553383122817_item	2976524	et	4	main
your	doc_553383122817_item	2976531	et	4	main
pardon	doc_553383122817_item	2976532	et	4	main
jälle	doc_553383122817_item	2976539	et	3	main
mille	doc_553383122817_item	2976547	et	3	main
on	doc_553383122817_item	2976550	et	4	main
taas	doc_553383122817_item	2976551	et	3	main
solvanud	doc_553383122817_item	2976552	et	4	main
ning	doc_553383122817_item	2976553	et	3	main
ja	doc_553383122817_item	2976554	et	3	main
mean	doc_553383122817_item	2976560	et	4	main
b	doc_553383122817_item	2976565	et	4	main
but	doc_553383122817_item	2976566	et	4	main
since	doc_553383122817_item	2976567	et	4	main
lydias	doc_553383122817_item	2976368	et	4	main
juhtunud	doc_553383122817_item	2976379	et	4	main
viini	doc_553383122817_item	2976388	et	4	main
armastajad	doc_553383122817_item	2976390	et	4	main
kohtuvad	doc_553383122817_item	2976391	et	4	main
only	doc_553383122817_item	2976403	et	4	main
you	doc_553383122817_item	2976408	et	4	main
given	doc_553383122817_item	2976410	et	4	main
tomorrow	doc_553383122817_item	2976414	et	4	main
grant	doc_553383122817_item	2976425	et	4	main
me	doc_553383122817_item	2976426	et	4	main
one	doc_553383122817_item	2976427	et	4	main
undisturbed	doc_553383122817_item	2976428	et	4	main
hour	doc_553383122817_item	2976429	et	4	main
to	doc_553383122817_item	2976430	et	4	main
spend	doc_553383122817_item	2976431	et	4	main
with	doc_553383122817_item	2976432	et	4	main
you	doc_553383122817_item	2976433	et	4	main
so	doc_553383122817_item	2976434	et	4	main
as	doc_553383122817_item	2976435	et	4	main
to	doc_553383122817_item	2976436	et	4	main
have	doc_553383122817_item	2976437	et	4	main
just	doc_553383122817_item	2976438	et	3	main
once	doc_553383122817_item	2976439	et	4	main
that	doc_553383122817_item	2976440	et	4	main
talk	doc_553383122817_item	2976441	et	3	main
we	doc_553383122817_item	2976442	et	4	main
have	doc_553383122817_item	2976443	et	4	main
not	doc_553383122817_item	2976444	et	4	main
had	doc_553383122817_item	2976445	et	4	main
for	doc_553383122817_item	2976446	et	4	main
a	doc_553383122817_item	2976447	et	4	main
long	doc_553383122817_item	2976448	et	4	main
time	doc_553383122817_item	2976449	et	4	main
when	doc_553383122817_item	2976450	et	4	main
my	doc_553383122817_item	2976451	et	4	main
heart	doc_553383122817_item	2976452	et	4	main
and	doc_553383122817_item	2976453	et	3	main
my	doc_553383122817_item	2976454	et	4	main
soul	doc_553383122817_item	2976455	et	4	main
may	doc_553383122817_item	2976456	et	4	main
again	doc_553383122817_item	2976457	et	4	main
lines	doc_553383122817_item	2976406	et	4	main
great	doc_553383122817_item	2976412	et	4	main
day	doc_553383122817_item	2976417	et	4	main
may	doc_553383122817_item	2976423	et	4	main
i	doc_553383122817_item	2976462	et	4	main
today	doc_553383122817_item	2976468	et	4	main
deliver	doc_553383122817_item	2976473	et	4	main
i	doc_553383122817_item	2976478	et	4	main
did	doc_553383122817_item	2976479	et	4	main
might	doc_553383122817_item	2976484	et	4	main
time	doc_553383122817_item	2976488	et	4	main
you	doc_553383122817_item	2976492	et	4	main
nad	doc_553383122817_item	2976494	et	3	main
järgmisel	doc_553383122817_item	2976496	et	3	main
midagi	doc_553383122817_item	2976503	et	4	main
juhtub	doc_553383122817_item	2976504	et	3	main
solvanud	doc_553383122817_item	2976508	et	4	main
talle	doc_553383122817_item	2976512	et	4	main
kirja	doc_553383122817_item	2976513	et	4	main
kus	doc_553383122817_item	2976514	et	3	main
vabandust	doc_553383122817_item	2976519	et	4	main
beg	doc_553383122817_item	2976530	et	4	main
josephine	doc_553383122817_item	2976536	et	4	main
majas	doc_553383122817_item	2976537	et	3	main
on	doc_553383122817_item	2976538	et	4	main
ilmselt	doc_553383122817_item	2976542	et	4	main
pärast	doc_553383122817_item	2976548	et	4	main
you	doc_553383122817_item	2976563	et	4	main
it	doc_553383122817_item	2976570	et	4	main
am	doc_553383122817_item	2976575	et	4	main
transgress	doc_553383122817_item	2976583	et	4	main
of	doc_553383122817_item	2976587	et	4	main
my	doc_553383122817_item	2976592	et	4	main
your	doc_553383122817_item	2976596	et	4	main
yourpardon	doc_553383122817_item	2976601	et	4	main
all	doc_553383122817_item	2976602	et	3	main
the	doc_553383122817_item	2976603	et	4	main
how	doc_553383122817_item	2976611	et	4	main
touchiness	doc_553383122817_item	2976617	et	4	main
exists	doc_553383122817_item	2976622	et	4	main
which	doc_553383122817_item	2976625	et	4	main
suspected	doc_553383122817_item	2976629	et	4	main
am	doc_553383122817_item	2976640	et	4	main
to	doc_553383122817_item	2976645	et	4	main
but	doc_553383122817_item	2976648	et	4	main
is	doc_553383122817_item	2976650	et	4	main
better	doc_553383122817_item	2976651	et	4	main
viimast	doc_553383122817_item	2976670	et	4	main
nimetada	doc_553383122817_item	2976673	et	3	main
lõpp	doc_553383122817_item	2976677	et	3	main
õpilase	doc_553383122817_item	2976687	et	3	main
ühiskond	doc_553383122817_item	2976698	et	3	main
oli	doc_553383122817_item	2976701	et	3	main
aadlivastane	doc_553383122817_item	2976708	et	3	main
oma	doc_553383122817_item	2976732	et	4	main
mõelnud	doc_553383122817_item	2976741	et	4	main
tuli	doc_553383122817_item	2976747	et	4	main
aeg	doc_553383122817_item	2976748	et	3	main
kus	doc_553383122817_item	2976749	et	3	main
nad	doc_553383122817_item	2976750	et	3	main
on	doc_553383122817_item	2976755	et	4	main
josephine	doc_553383122817_item	2976760	et	4	main
viinist	doc_553383122817_item	2976762	et	3	main
yours	doc_553383122817_item	2976461	et	4	main
i	doc_553383122817_item	2976470	et	4	main
that	doc_553383122817_item	2976482	et	4	main
fail	doc_553383122817_item	2976489	et	3	main
see	doc_553383122817_item	2976491	et	3	main
päeval	doc_553383122817_item	2976497	et	3	main
josephine	doc_553383122817_item	2976499	et	4	main
majas	doc_553383122817_item	2976500	et	3	main
kuid	doc_553383122817_item	2976501	et	4	main
ja	doc_553383122817_item	2976505	et	3	main
kirjutab	doc_553383122817_item	2976511	et	3	main
palub	doc_553383122817_item	2976516	et	3	main
is	doc_553383122817_item	2976521	et	4	main
my	doc_553383122817_item	2976522	et	4	main
beg	doc_553383122817_item	2976525	et	4	main
pardon	doc_553383122817_item	2976527	et	4	main
so	doc_553383122817_item	2976528	et	4	main
ja	doc_553383122817_item	2976541	et	3	main
toimub	doc_553383122817_item	2976544	et	3	main
intsident	doc_553383122817_item	2976546	et	3	main
beethoven	doc_553383122817_item	2976549	et	4	main
not	doc_553383122817_item	2976559	et	4	main
to	doc_553383122817_item	2976582	et	4	main
it	doc_553383122817_item	2976590	et	4	main
beg	doc_553383122817_item	2976600	et	4	main
i	doc_553383122817_item	2976606	et	4	main
understand	doc_553383122817_item	2976608	et	4	main
very	doc_553383122817_item	2976609	et	4	main
be	doc_553383122817_item	2976614	et	4	main
room	doc_553383122817_item	2976615	et	3	main
mutual	doc_553383122817_item	2976620	et	4	main
malady	doc_553383122817_item	2976624	et	4	main
could	doc_553383122817_item	2976627	et	4	main
souls	doc_553383122817_item	2976633	et	4	main
i	doc_553383122817_item	2976639	et	4	main
able	doc_553383122817_item	2976644	et	4	main
for	doc_553383122817_item	2976652	et	4	main
and	doc_553383122817_item	2976657	et	3	main
mine	doc_553383122817_item	2976658	et	3	main
and	doc_553383122817_item	2976469	et	3	main
this	doc_553383122817_item	2976474	et	4	main
to	doc_553383122817_item	2976490	et	4	main
on	doc_553383122817_item	2976507	et	4	main
sest	doc_553383122817_item	2976509	et	4	main
eest	doc_553383122817_item	2976518	et	4	main
turn	doc_553383122817_item	2976523	et	4	main
your	doc_553383122817_item	2976526	et	4	main
tõenäoliselt	doc_553383122817_item	2976533	et	4	main
josephine	doc_553383122817_item	2976555	et	4	main
vabandab	doc_553383122817_item	2976556	et	3	main
to	doc_553383122817_item	2976561	et	4	main
insult	doc_553383122817_item	2976562	et	3	main
aware	doc_553383122817_item	2976577	et	4	main
i	doc_553383122817_item	2976585	et	4	main
little	doc_553383122817_item	2976588	et	4	main
pardon	doc_553383122817_item	2976597	et	4	main
so	doc_553383122817_item	2976598	et	4	main
i	doc_553383122817_item	2976599	et	4	main
since	doc_553383122817_item	2976605	et	4	main
there	doc_553383122817_item	2976612	et	4	main
could	doc_553383122817_item	2976613	et	4	main
true	doc_553383122817_item	2976619	et	4	main
only	doc_553383122817_item	2976630	et	4	main
in	doc_553383122817_item	2976631	et	4	main
how	doc_553383122817_item	2976637	et	4	main
to	doc_553383122817_item	2976642	et	4	main
your	doc_553383122817_item	2976653	et	4	main
kaks	doc_553383122817_item	2976668	et	3	main
külmadeks	doc_553383122817_item	2976674	et	3	main
miks	doc_553383122817_item	2976678	et	4	main
lahku	doc_553383122817_item	2976680	et	4	main
läksid	doc_553383122817_item	2976681	et	4	main
mispärast	doc_553383122817_item	2976682	et	3	main
algas	doc_553383122817_item	2976683	et	3	main
vahel	doc_553383122817_item	2976690	et	4	main
nende	doc_553383122817_item	2976699	et	4	main
beethoven	doc_553383122817_item	2976704	et	4	main
liberaal	doc_553383122817_item	2976707	et	3	main
elus-	doc_553383122817_item	2976730	et	4	main
nende	doc_553383122817_item	2976735	et	4	main
kuid	doc_553383122817_item	2976746	et	4	main
et	doc_553383122817_item	2976757	et	3	main
lahkus	doc_553383122817_item	2976761	et	4	main
tegi	doc_553383122817_item	2976763	et	4	main
adam	doc_553383122817_item	2976775	et	4	main
von	doc_553383122817_item	2976776	et	4	main
stackelberg6	doc_553383122817_item	2976777	et	2	main
sündis	doc_553383122817_item	2976778	et	3	main
väänas	doc_553383122817_item	2976779	et	3	main
lõpetas	doc_553383122817_item	2976780	et	3	main
kubermangugümnaasiumi	doc_553383122817_item	2976791	et	4	main
ja	doc_553383122817_item	2976792	et	3	main
komitee	doc_553383122817_item	2976800	et	4	main
jooksul	doc_553383122817_item	2976811	et	4	main
ungaris	doc_553383122817_item	2976821	et	4	main
josephine	doc_553383122817_item	2976823	et	4	main
hernhuutlusega7	doc_553383122817_item	2976837	et	2	main
liikumisega	doc_553383122817_item	2976839	et	4	main
peamine	doc_553383122817_item	2976841	et	3	main
oli	doc_553383122817_item	2976844	et	3	main
nende	doc_553383122817_item	2976859	et	4	main
vennastekogudus	doc_553383122817_item	2976860	et	3	main
soodustas	doc_553383122817_item	2976861	et	3	main
eestlastele	doc_553383122817_item	2976868	et	4	main
eneseväärtustunde	doc_553383122817_item	2976870	et	4	main
ja	doc_553383122817_item	2976878	et	3	main
ühistegevuse	doc_553383122817_item	2976885	et	4	main
koosolekud	doc_553383122817_item	2976904	et	3	main
võrdsete	doc_553383122817_item	2976908	et	4	main
tänu	doc_553383122817_item	2976911	et	4	main
peale	doc_553383122817_item	2976957	et	4	main
sest	doc_553383122817_item	2976958	et	4	main
christoph	doc_553383122817_item	2976962	et	4	main
aga	doc_553383122817_item	2976964	et	3	main
protestant	doc_553383122817_item	2976965	et	3	main
kaks	doc_553383122817_item	2976969	et	3	main
maria	doc_553383122817_item	2976973	et	4	main
kas	doc_553383122817_item	2976975	et	3	main
theresele	doc_553383122817_item	2976987	et	4	main
pilti	doc_553383122817_item	2976991	et	4	main
millel	doc_553383122817_item	2976992	et	3	main
took	doc_553383122817_item	2976569	et	3	main
as	doc_553383122817_item	2976571	et	4	main
such	doc_553383122817_item	2976572	et	4	main
and	doc_553383122817_item	2976573	et	3	main
well	doc_553383122817_item	2976576	et	4	main
the	doc_553383122817_item	2976579	et	4	main
which	doc_553383122817_item	2976584	et	4	main
importance	doc_553383122817_item	2976589	et	4	main
is	doc_553383122817_item	2976591	et	4	main
turn	doc_553383122817_item	2976593	et	4	main
to	doc_553383122817_item	2976594	et	4	main
more	doc_553383122817_item	2976604	et	4	main
cannot	doc_553383122817_item	2976607	et	4	main
where	doc_553383122817_item	2976618	et	4	main
a	doc_553383122817_item	2976623	et	4	main
usually	doc_553383122817_item	2976626	et	4	main
be	doc_553383122817_item	2976628	et	4	main
beethoven	doc_553383122817_item	2976634	et	4	main
vastab	doc_553383122817_item	2976635	et	3	main
kohe	doc_553383122817_item	2976636	et	4	main
not	doc_553383122817_item	2976641	et	4	main
see	doc_553383122817_item	2976646	et	3	main
of	doc_553383122817_item	2976655	et	4	main
mind	doc_553383122817_item	2976656	et	4	main
to	doc_553383122817_item	2976660	et	4	main
see	doc_553383122817_item	2976661	et	3	main
you	doc_553383122817_item	2976662	et	4	main
you	doc_553383122817_item	2976663	et	4	main
have	doc_553383122817_item	2976664	et	4	main
not	doc_553383122817_item	2976665	et	4	main
offended	doc_553383122817_item	2976666	et	4	main
me5	doc_553383122817_item	2976667	et	2	main
kirja	doc_553383122817_item	2976671	et	4	main
võib	doc_553383122817_item	2976672	et	3	main
hüvastijattudeks	doc_553383122817_item	2976675	et	4	main
tüli	doc_553383122817_item	2976686	et	4	main
ja	doc_553383122817_item	2976688	et	3	main
kahjuks	doc_553383122817_item	2976691	et	4	main
nende	doc_553383122817_item	2976692	et	4	main
lihtsalt	doc_553383122817_item	2976702	et	4	main
demokraat	doc_553383122817_item	2976706	et	3	main
lastele	doc_553383122817_item	2976733	et	4	main
kui	doc_553383122817_item	2976734	et	3	main
sellest	doc_553383122817_item	2976742	et	4	main
pidid	doc_553383122817_item	2976751	et	4	main
teada	doc_553383122817_item	2976756	et	3	main
ringreisi	doc_553383122817_item	2976765	et	4	main
kuid	doc_553383122817_item	2976766	et	4	main
saatjaks	doc_553383122817_item	2976768	et	4	main
adam	doc_553383122817_item	2976771	et	4	main
von	doc_553383122817_item	2976772	et	4	main
tallinnas	doc_553383122817_item	2976781	et	4	main
saksamaal	doc_553383122817_item	2976785	et	4	main
ja	doc_553383122817_item	2976787	et	3	main
õigusteadust	doc_553383122817_item	2976788	et	4	main
oli	doc_553383122817_item	2976789	et	3	main
tallinna	doc_553383122817_item	2976790	et	4	main
eestimaa	doc_553383122817_item	2976797	et	4	main
alalise	doc_553383122817_item	2976798	et	4	main
koolikorralduse	doc_553383122817_item	2976799	et	3	main
ja	doc_553383122817_item	2976804	et	3	main
ning	doc_553383122817_item	2976806	et	3	main
rahvakooliõpetajate	doc_553383122817_item	2976807	et	3	main
reisis	doc_553383122817_item	2976812	et	4	main
palju	doc_553383122817_item	2976813	et	4	main
kus	doc_553383122817_item	2976815	et	3	main
1810	doc_553383122817_item	2976818	et	2	main
aastal	doc_553383122817_item	2976819	et	3	main
abielluski	doc_553383122817_item	2976820	et	3	main
on	doc_553383122817_item	2976829	et	4	main
see	doc_553383122817_item	2976830	et	3	main
oli	doc_553383122817_item	2976835	et	3	main
religioosne	doc_553383122817_item	2976842	et	3	main
päeva	doc_553383122817_item	2976845	et	4	main
nende	doc_553383122817_item	2976669	et	4	main
arusaamatus	doc_553383122817_item	2976684	et	4	main
ja	doc_553383122817_item	2976685	et	3	main
vahel	doc_553383122817_item	2976693	et	4	main
abielu	doc_553383122817_item	2976700	et	4	main
võimatu	doc_553383122817_item	2976703	et	4	main
aga	doc_553383122817_item	2976710	et	3	main
pärit	doc_553383122817_item	2976711	et	3	main
väga	doc_553383122817_item	2976712	et	3	main
vana	doc_553383122817_item	2976713	et	4	main
aadli	doc_553383122817_item	2976714	et	3	main
soost	doc_553383122817_item	2976715	et	4	main
abielludes	doc_553383122817_item	2976716	et	3	main
kodanlikuga	doc_553383122817_item	2976717	et	3	main
ta	doc_553383122817_item	2976718	et	4	main
kaotaks	doc_553383122817_item	2976719	et	4	main
ainult	doc_553383122817_item	2976721	et	4	main
mitte	doc_553383122817_item	2976720	et	3	main
oma	doc_553383122817_item	2976722	et	4	main
positsiooni	doc_553383122817_item	2976723	et	4	main
ühiskonnas	doc_553383122817_item	2976724	et	4	main
suurema	doc_553383122817_item	2976726	et	4	main
kingituse	doc_553383122817_item	2976727	et	4	main
vaid	doc_553383122817_item	2976725	et	3	main
iga	doc_553383122817_item	2976728	et	4	main
oli	doc_553383122817_item	2976705	et	3	main
josephine	doc_553383122817_item	2976709	et	4	main
naise	doc_553383122817_item	2976729	et	3	main
õiguse	doc_553383122817_item	2976731	et	4	main
nad	doc_553383122817_item	2976743	et	3	main
lihtsalt	doc_553383122817_item	2976744	et	4	main
reaalsusega	doc_553383122817_item	2976752	et	4	main
puutuda	doc_553383122817_item	2976754	et	3	main
aastal	doc_553383122817_item	2976759	et	3	main
tema	doc_553383122817_item	2976767	et	4	main
strackelberg	doc_553383122817_item	2976773	et	4	main
gümnaasiumi	doc_553383122817_item	2976782	et	4	main
eestimaa	doc_553383122817_item	2976793	et	4	main
liige	doc_553383122817_item	2976801	et	4	main
asutas	doc_553383122817_item	2976802	et	3	main
vaeslastekoole	doc_553383122817_item	2976805	et	4	main
seminari	doc_553383122817_item	2976808	et	4	main
oma	doc_553383122817_item	2976809	et	4	main
tutvuski	doc_553383122817_item	2976816	et	4	main
ja	doc_553383122817_item	2976817	et	3	main
von	doc_553383122817_item	2976824	et	4	main
huvitav	doc_553383122817_item	2976828	et	4	main
fakt	doc_553383122817_item	2976831	et	3	main
et	doc_553383122817_item	2976832	et	3	main
seotud	doc_553383122817_item	2976836	et	4	main
palve	doc_553383122817_item	2976848	et	4	main
kirjakultuuri	doc_553383122817_item	2976862	et	4	main
seas	doc_553383122817_item	2976865	et	4	main
pärisoristele	doc_553383122817_item	2976867	et	4	main
enesearendamisvõimalusi	doc_553383122817_item	2976874	et	4	main
pasunakooride	doc_553383122817_item	2976879	et	3	main
distsiplineeritud	doc_553383122817_item	2976887	et	4	main
luterlikule	doc_553383122817_item	2976895	et	4	main
kirikule	doc_553383122817_item	2976896	et	3	main
henhuutluse	doc_553383122817_item	2976912	et	4	main
vaeslastekoole	doc_553383122817_item	2976920	et	4	main
ning	doc_553383122817_item	2976921	et	3	main
kahe	doc_553383122817_item	2976946	et	3	main
pärast	doc_553383122817_item	2976948	et	4	main
ja	doc_553383122817_item	2976972	et	3	main
mees	doc_553383122817_item	2976984	et	4	main
vaatab	doc_553383122817_item	2976994	et	3	main
miks	doc_553383122817_item	2977001	et	4	main
armastuse	doc_553383122817_item	2977014	et	4	main
sümbol	doc_553383122817_item	2977015	et	3	main
kas	doc_553383122817_item	2977016	et	3	main
tõesti	doc_553383122817_item	2977017	et	3	main
oma	doc_553383122817_item	2977020	et	4	main
õnne	doc_553383122817_item	2977021	et	4	main
eestit	doc_553383122817_item	2977055	et	3	main
perekonna	doc_553383122817_item	2977071	et	4	main
on	doc_553383122817_item	2977080	et	4	main
ning	doc_553383122817_item	2977092	et	3	main
sündis	doc_553383122817_item	2977097	et	3	main
uurijad	doc_553383122817_item	2977104	et	4	main
räägiti	doc_553383122817_item	2977109	et	3	main
kolm	doc_553383122817_item	2977123	et	3	main
pärast	doc_553383122817_item	2977134	et	4	main
tuleb	doc_553383122817_item	2977135	et	3	main
vaid	doc_553383122817_item	2977136	et	3	main
varsti	doc_553383122817_item	2977142	et	3	main
oma	doc_553383122817_item	2977176	et	4	main
elu	doc_553383122817_item	2977177	et	4	main
ta	doc_553383122817_item	2977181	et	4	main
koos	doc_553383122817_item	2977182	et	4	main
oma	doc_553383122817_item	2977183	et	4	main
esimesest	doc_553383122817_item	2977189	et	3	main
kolm	doc_553383122817_item	2977192	et	3	main
eestis	doc_553383122817_item	2977198	et	3	main
sureb	doc_553383122817_item	2977200	et	3	main
widow	doc_553383122817_item	2977243	et	4	main
her	doc_553383122817_item	2977248	et	4	main
husband	doc_553383122817_item	2977249	et	4	main
she	doc_553383122817_item	2977250	et	4	main
happier	doc_553383122817_item	2977255	et	4	main
her	doc_553383122817_item	2977264	et	4	main
her	doc_553383122817_item	2977267	et	4	main
own	doc_553383122817_item	2977268	et	4	main
he	doc_553383122817_item	2977270	et	4	main
who	doc_553383122817_item	2977271	et	4	main
like	doc_553383122817_item	2977275	et	4	main
her	doc_553383122817_item	2977276	et	4	main
armastus	doc_553383122817_item	2976736	et	4	main
tekkis	doc_553383122817_item	2976737	et	3	main
nad	doc_553383122817_item	2976738	et	3	main
arvatavasti	doc_553383122817_item	2976739	et	3	main
ei	doc_553383122817_item	2976740	et	4	main
armastasid	doc_553383122817_item	2976745	et	4	main
kokku	doc_553383122817_item	2976753	et	3	main
1808	doc_553383122817_item	2976758	et	2	main
pikka	doc_553383122817_item	2976764	et	4	main
christoph	doc_553383122817_item	2976770	et	4	main
pärast	doc_553383122817_item	2976783	et	4	main
meditsiini	doc_553383122817_item	2976786	et	4	main
kubermangukooli	doc_553383122817_item	2976794	et	4	main
direktoriks	doc_553383122817_item	2976795	et	3	main
ning	doc_553383122817_item	2976796	et	3	main
pühapäeva-	doc_553383122817_item	2976803	et	4	main
krahvina	doc_553383122817_item	2976822	et	3	main
de	doc_553383122817_item	2976826	et	4	main
christop	doc_553383122817_item	2976833	et	4	main
vennaskoguduse	doc_553383122817_item	2976838	et	3	main
mille	doc_553383122817_item	2976840	et	3	main
loosung	doc_553383122817_item	2976843	et	3	main
1730-ndatel	doc_553383122817_item	2976849	et	4	main
isegi	doc_553383122817_item	2976857	et	4	main
demokraatlik	doc_553383122817_item	2976858	et	3	main
levikut	doc_553383122817_item	2976863	et	3	main
oli	doc_553383122817_item	2976769	et	3	main
christoph	doc_553383122817_item	2976774	et	4	main
õppis	doc_553383122817_item	2976784	et	3	main
elu	doc_553383122817_item	2976810	et	4	main
euroopas	doc_553383122817_item	2976814	et	3	main
brunswick	doc_553383122817_item	2976825	et	4	main
korompaga	doc_553383122817_item	2976827	et	4	main
adam	doc_553383122817_item	2976834	et	4	main
on	doc_553383122817_item	2976855	et	4	main
rahvalik	doc_553383122817_item	2976856	et	3	main
uusi	doc_553383122817_item	2976871	et	3	main
ja	doc_553383122817_item	2976873	et	3	main
eesti	doc_553383122817_item	2976876	et	4	main
traditsiooni	doc_553383122817_item	2976880	et	4	main
õpetasid	doc_553383122817_item	2976886	et	4	main
eluviisi	doc_553383122817_item	2976890	et	4	main
liikumine	doc_553383122817_item	2976891	et	4	main
hingeline	doc_553383122817_item	2976900	et	4	main
ja	doc_553383122817_item	2976901	et	3	main
mäss	doc_553383122817_item	2976903	et	3	main
mõisnike	doc_553383122817_item	2976905	et	3	main
nõudmine	doc_553383122817_item	2976909	et	4	main
just	doc_553383122817_item	2976910	et	3	main
selle	doc_553383122817_item	2976955	et	4	main
oli	doc_553383122817_item	2976960	et	3	main
adam	doc_553383122817_item	2976963	et	4	main
neil	doc_553383122817_item	2976967	et	4	main
last	doc_553383122817_item	2976970	et	4	main
laura	doc_553383122817_item	2976974	et	4	main
tõepoolest	doc_553383122817_item	2976976	et	3	main
päikest	doc_553383122817_item	2976995	et	4	main
miks	doc_553383122817_item	2976996	et	4	main
see	doc_553383122817_item	2976997	et	3	main
nii	doc_553383122817_item	2976998	et	3	main
ei	doc_553383122817_item	2977003	et	4	main
tagasi	doc_553383122817_item	2977007	et	3	main
ohverdas	doc_553383122817_item	2977019	et	3	main
oleks	doc_553383122817_item	2977053	et	3	main
vääna	doc_553383122817_item	2977057	et	4	main
või	doc_553383122817_item	2977059	et	4	main
1812	doc_553383122817_item	2977061	et	2	main
juunis	doc_553383122817_item	2977063	et	3	main
christop	doc_553383122817_item	2977068	et	4	main
ning	doc_553383122817_item	2977073	et	3	main
6	doc_553383122817_item	2977076	et	2	main
et	doc_553383122817_item	2977082	et	3	main
josephine	doc_553383122817_item	2977085	et	4	main
beethoven	doc_553383122817_item	2977087	et	4	main
18	doc_553383122817_item	2977093	et	2	main
aastal	doc_553383122817_item	2977096	et	3	main
josephine	doc_553383122817_item	2977098	et	4	main
laps	doc_553383122817_item	2977100	et	4	main
minona	doc_553383122817_item	2977101	et	4	main
pidanud	doc_553383122817_item	2977106	et	4	main
beethoveni	doc_553383122817_item	2977107	et	4	main
et	doc_553383122817_item	2977110	et	3	main
klaveripedagoog	doc_553383122817_item	2977122	et	3	main
kuud	doc_553383122817_item	2977124	et	4	main
christop	doc_553383122817_item	2977129	et	4	main
adam	doc_553383122817_item	2977130	et	4	main
ja	doc_553383122817_item	2977138	et	3	main
lühikesteks	doc_553383122817_item	2977139	et	4	main
josephine	doc_553383122817_item	2977143	et	4	main
nõus	doc_553383122817_item	2977168	et	4	main
koos	doc_553383122817_item	2977171	et	4	main
õe	doc_553383122817_item	2977184	et	4	main
last	doc_553383122817_item	2977194	et	4	main
aga	doc_553383122817_item	2977196	et	3	main
loo	doc_553383122817_item	2977207	et	4	main
our	doc_553383122817_item	2977230	et	4	main
house	doc_553383122817_item	2977231	et	4	main
accept	doc_553383122817_item	2977245	et	4	main
him	doc_553383122817_item	2977246	et	4	main
would	doc_553383122817_item	2977251	et	4	main
than	doc_553383122817_item	2977256	et	4	main
maternal	doc_553383122817_item	2977261	et	4	main
was	doc_553383122817_item	2977272	et	4	main
so	doc_553383122817_item	2977273	et	4	main
been	doc_553383122817_item	2977293	et	4	main
been	doc_553383122817_item	2977298	et	4	main
happiness	doc_553383122817_item	2977309	et	4	main
küsimustele	doc_553383122817_item	2977320	et	4	main
mõte	doc_553383122817_item	2976846	et	3	main
päeva	doc_553383122817_item	2976847	et	4	main
liikumine	doc_553383122817_item	2976850	et	4	main
hakkab	doc_553383122817_item	2976851	et	3	main
eestis	doc_553383122817_item	2976852	et	3	main
levima	doc_553383122817_item	2976853	et	3	main
henhuutlus	doc_553383122817_item	2976854	et	4	main
talupoegade	doc_553383122817_item	2976864	et	3	main
andis	doc_553383122817_item	2976866	et	3	main
tekitas	doc_553383122817_item	2976875	et	3	main
ja	doc_553383122817_item	2976881	et	3	main
koos	doc_553383122817_item	2976883	et	4	main
kunstialaste	doc_553383122817_item	2976884	et	4	main
ja	doc_553383122817_item	2976888	et	3	main
kokkuhoidliku	doc_553383122817_item	2976889	et	3	main
see	doc_553383122817_item	2976897	et	3	main
oli	doc_553383122817_item	2976898	et	3	main
nagu	doc_553383122817_item	2976899	et	3	main
religioosne	doc_553383122817_item	2976902	et	3	main
ja	doc_553383122817_item	2976906	et	3	main
christop	doc_553383122817_item	2976915	et	4	main
adam	doc_553383122817_item	2976916	et	4	main
asutaski	doc_553383122817_item	2976917	et	3	main
pühapäeva-	doc_553383122817_item	2976918	et	4	main
ja	doc_553383122817_item	2976919	et	3	main
algusest	doc_553383122817_item	2976956	et	4	main
katoliiklane	doc_553383122817_item	2976961	et	3	main
varsti	doc_553383122817_item	2976966	et	3	main
uue	doc_553383122817_item	2976869	et	3	main
tegutsemis-	doc_553383122817_item	2976872	et	4	main
koorilaulu	doc_553383122817_item	2976877	et	4	main
sellega	doc_553383122817_item	2976882	et	3	main
oli	doc_553383122817_item	2976892	et	3	main
teatud	doc_553383122817_item	2976893	et	4	main
vastuseis	doc_553383122817_item	2976894	et	4	main
talupoegade	doc_553383122817_item	2976907	et	3	main
liikumise	doc_553383122817_item	2976913	et	4	main
mõjule	doc_553383122817_item	2976914	et	3	main
rahvakooliõpetajate	doc_553383122817_item	2976922	et	3	main
seminari	doc_553383122817_item	2976923	et	4	main
kus	doc_553383122817_item	2976924	et	3	main
tegutses	doc_553383122817_item	2976925	et	3	main
rahva	doc_553383122817_item	2976926	et	3	main
valgustajana	doc_553383122817_item	2976927	et	4	main
tema	doc_553383122817_item	2976928	et	4	main
sellised	doc_553383122817_item	2976929	et	4	main
demokraatlikud	doc_553383122817_item	2976930	et	3	main
kalduvused	doc_553383122817_item	2976931	et	4	main
võiksid	doc_553383122817_item	2976932	et	4	main
tõenäoliselt	doc_553383122817_item	2976933	et	4	main
samuti	doc_553383122817_item	2976934	et	3	main
olla	doc_553383122817_item	2976935	et	3	main
josephine	doc_553383122817_item	2976936	et	4	main
ja	doc_553383122817_item	2976937	et	3	main
christoph	doc_553383122817_item	2976938	et	4	main
adami	doc_553383122817_item	2976939	et	4	main
vahelise	doc_553383122817_item	2976940	et	4	main
konflikti	doc_553383122817_item	2976941	et	4	main
põhjuseks	doc_553383122817_item	2976942	et	3	main
tulevikus	doc_553383122817_item	2976943	et	4	main
nad	doc_553383122817_item	2976944	et	3	main
abiellusid	doc_553383122817_item	2976945	et	4	main
aasta	doc_553383122817_item	2976947	et	4	main
13	doc_553383122817_item	2976949	et	2	main
veebruaril	doc_553383122817_item	2976950	et	3	main
abielu	doc_553383122817_item	2976951	et	4	main
oli	doc_553383122817_item	2976952	et	3	main
problemaatiline	doc_553383122817_item	2976953	et	3	main
juba	doc_553383122817_item	2976954	et	3	main
josephine	doc_553383122817_item	2976959	et	4	main
sündis	doc_553383122817_item	2976968	et	3	main
saadab	doc_553383122817_item	2976985	et	3	main
kirja	doc_553383122817_item	2976986	et	4	main
tagasi	doc_553383122817_item	2976990	et	3	main
on	doc_553383122817_item	2977000	et	4	main
pilti	doc_553383122817_item	2977005	et	4	main
päikesesse	doc_553383122817_item	2977009	et	4	main
kotkas	doc_553383122817_item	2977011	et	4	main
on	doc_553383122817_item	2977012	et	4	main
ju	doc_553383122817_item	2977013	et	3	main
küsimustele	doc_553383122817_item	2977045	et	4	main
vastus	doc_553383122817_item	2977047	et	3	main
ei	doc_553383122817_item	2977048	et	4	main
ole	doc_553383122817_item	2977049	et	4	main
teada	doc_553383122817_item	2977050	et	3	main
kas	doc_553383122817_item	2977051	et	3	main
ja	doc_553383122817_item	2977056	et	3	main
nende	doc_553383122817_item	2977065	et	4	main
perekonnal	doc_553383122817_item	2977066	et	4	main
abielukriis	doc_553383122817_item	2977067	et	3	main
lahkus	doc_553383122817_item	2977070	et	4	main
tuli	doc_553383122817_item	2977074	et	4	main
kuu	doc_553383122817_item	2977077	et	4	main
pärast	doc_553383122817_item	2977078	et	4	main
tagasi	doc_553383122817_item	2977079	et	3	main
prahas	doc_553383122817_item	2977091	et	4	main
lapseks	doc_553383122817_item	2977108	et	4	main
silmapaistev	doc_553383122817_item	2977119	et	4	main
muusik	doc_553383122817_item	2977120	et	3	main
ja	doc_553383122817_item	2977121	et	3	main
pärast	doc_553383122817_item	2977125	et	4	main
tüdruku	doc_553383122817_item	2977126	et	3	main
harva	doc_553383122817_item	2977137	et	4	main
teophile	doc_553383122817_item	2976971	et	4	main
josephine	doc_553383122817_item	2976977	et	4	main
unustas	doc_553383122817_item	2976978	et	3	main
beethoveni	doc_553383122817_item	2976979	et	4	main
23	doc_553383122817_item	2976980	et	2	main
novembril	doc_553383122817_item	2976981	et	3	main
1810	doc_553383122817_item	2976982	et	2	main
aastal	doc_553383122817_item	2976983	et	3	main
milles	doc_553383122817_item	2976988	et	3	main
palub	doc_553383122817_item	2976989	et	3	main
oluline	doc_553383122817_item	2976999	et	4	main
taha	doc_553383122817_item	2977004	et	4	main
anda	doc_553383122817_item	2977008	et	3	main
naine	doc_553383122817_item	2977018	et	3	main
ja	doc_553383122817_item	2977022	et	3	main
armastuse	doc_553383122817_item	2977023	et	4	main
kuid	doc_553383122817_item	2977024	et	4	main
hinges	doc_553383122817_item	2977025	et	4	main
jäi	doc_553383122817_item	2977026	et	3	main
sellele	doc_553383122817_item	2977027	et	4	main
tundele	doc_553383122817_item	2977028	et	3	main
truu	doc_553383122817_item	2977029	et	4	main
oma	doc_553383122817_item	2977030	et	4	main
elu	doc_553383122817_item	2977031	et	4	main
lõppuni	doc_553383122817_item	2977032	et	3	main
sellel	doc_553383122817_item	2977033	et	4	main
teemal	doc_553383122817_item	2977034	et	3	main
võib	doc_553383122817_item	2977035	et	3	main
palju	doc_553383122817_item	2977036	et	4	main
oletada	doc_553383122817_item	2977037	et	3	main
ja	doc_553383122817_item	2977038	et	3	main
vaielda	doc_553383122817_item	2977039	et	4	main
kuid	doc_553383122817_item	2977040	et	4	main
kahtlen	doc_553383122817_item	2977041	et	3	main
et	doc_553383122817_item	2977042	et	3	main
kunagi	doc_553383122817_item	2977043	et	3	main
kotkas	doc_553383122817_item	2976993	et	4	main
josephine	doc_553383122817_item	2977002	et	4	main
beethovenile	doc_553383122817_item	2977006	et	4	main
vaatav	doc_553383122817_item	2977010	et	4	main
toimus	doc_553383122817_item	2977064	et	3	main
neile	doc_553383122817_item	2977044	et	4	main
leidub	doc_553383122817_item	2977046	et	3	main
josephine	doc_553383122817_item	2977052	et	4	main
külastanud	doc_553383122817_item	2977054	et	4	main
mõisa	doc_553383122817_item	2977058	et	3	main
mitte	doc_553383122817_item	2977060	et	3	main
aasta	doc_553383122817_item	2977062	et	4	main
adam	doc_553383122817_item	2977069	et	4	main
ainult	doc_553383122817_item	2977075	et	4	main
teada	doc_553383122817_item	2977081	et	3	main
aastal	doc_553383122817_item	2977084	et	3	main
ja	doc_553383122817_item	2977086	et	3	main
on	doc_553383122817_item	2977088	et	4	main
samal	doc_553383122817_item	2977089	et	3	main
ajal	doc_553383122817_item	2977090	et	4	main
1813	doc_553383122817_item	2977095	et	2	main
keda	doc_553383122817_item	2977102	et	4	main
mõned	doc_553383122817_item	2977103	et	3	main
on	doc_553383122817_item	2977105	et	4	main
erines	doc_553383122817_item	2977112	et	3	main
väliselt	doc_553383122817_item	2977113	et	4	main
õdedest	doc_553383122817_item	2977115	et	3	main
lahkub	doc_553383122817_item	2977128	et	3	main
taas	doc_553383122817_item	2977131	et	3	main
perioodideks	doc_553383122817_item	2977140	et	3	main
nõuab	doc_553383122817_item	2977144	et	3	main
lapsed	doc_553383122817_item	2977170	et	3	main
mehega	doc_553383122817_item	2977172	et	3	main
on	doc_553383122817_item	2977173	et	4	main
temast	doc_553383122817_item	2977174	et	3	main
eemal	doc_553383122817_item	2977175	et	3	main
aastaid	doc_553383122817_item	2977179	et	4	main
elab	doc_553383122817_item	2977180	et	3	main
nelja	doc_553383122817_item	2977187	et	4	main
lapsega	doc_553383122817_item	2977188	et	3	main
viinis	doc_553383122817_item	2977191	et	3	main
42	doc_553383122817_item	2977201	et	2	main
pärast	doc_553383122817_item	2977203	et	4	main
seda	doc_553383122817_item	2977204	et	3	main
kui	doc_553383122817_item	2977205	et	3	main
kõik	doc_553383122817_item	2977206	et	4	main
intimate	doc_553383122817_item	2977228	et	4	main
a	doc_553383122817_item	2977232	et	4	main
my	doc_553383122817_item	2977238	et	4	main
sister	doc_553383122817_item	2977239	et	4	main
deym	doc_553383122817_item	2977244	et	4	main
been	doc_553383122817_item	2977253	et	4	main
much	doc_553383122817_item	2977254	et	4	main
with	doc_553383122817_item	2977259	et	4	main
stackelberg	doc_553383122817_item	2977260	et	4	main
to	doc_553383122817_item	2977265	et	4	main
juurest	doc_553383122817_item	2977072	et	4	main
1812	doc_553383122817_item	2977083	et	2	main
aprillil	doc_553383122817_item	2977094	et	3	main
seitsmes	doc_553383122817_item	2977099	et	4	main
tüdruk	doc_553383122817_item	2977111	et	3	main
oma	doc_553383122817_item	2977114	et	4	main
tulevikus	doc_553383122817_item	2977116	et	4	main
minonast	doc_553383122817_item	2977117	et	4	main
saab	doc_553383122817_item	2977118	et	3	main
sündi	doc_553383122817_item	2977127	et	4	main
perekonna	doc_553383122817_item	2977132	et	4	main
juurest	doc_553383122817_item	2977133	et	4	main
tagasi	doc_553383122817_item	2977141	et	3	main
mehest	doc_553383122817_item	2977145	et	4	main
eemaldamist	doc_553383122817_item	2977146	et	4	main
voodist	doc_553383122817_item	2977147	et	3	main
ja	doc_553383122817_item	2977148	et	3	main
lauast	doc_553383122817_item	2977149	et	4	main
ehk	doc_553383122817_item	2977150	et	3	main
abielulahutuse	doc_553383122817_item	2977151	et	4	main
1819	doc_553383122817_item	2977152	et	2	main
aastal	doc_553383122817_item	2977153	et	3	main
pöördub	doc_553383122817_item	2977154	et	3	main
christop	doc_553383122817_item	2977155	et	4	main
adam	doc_553383122817_item	2977156	et	4	main
viini	doc_553383122817_item	2977157	et	4	main
tagasi	doc_553383122817_item	2977158	et	3	main
josephine	doc_553383122817_item	2977159	et	4	main
on	doc_553383122817_item	2977160	et	4	main
toole	doc_553383122817_item	2977161	et	3	main
ajaks	doc_553383122817_item	2977162	et	4	main
haige	doc_553383122817_item	2977163	et	4	main
ja	doc_553383122817_item	2977164	et	3	main
kurnatud	doc_553383122817_item	2977165	et	4	main
ja	doc_553383122817_item	2977166	et	3	main
on	doc_553383122817_item	2977167	et	4	main
et	doc_553383122817_item	2977169	et	3	main
viimseid	doc_553383122817_item	2977178	et	3	main
teresia	doc_553383122817_item	2977185	et	4	main
elavad	doc_553383122817_item	2977195	et	4	main
isaga	doc_553383122817_item	2977197	et	3	main
aastasena	doc_553383122817_item	2977202	et	4	main
of	doc_553383122817_item	2977229	et	4	main
did	doc_553383122817_item	2977236	et	4	main
not	doc_553383122817_item	2977237	et	4	main
the	doc_553383122817_item	2977242	et	4	main
as	doc_553383122817_item	2977247	et	4	main
have	doc_553383122817_item	2977252	et	4	main
she	doc_553383122817_item	2977257	et	4	main
love	doc_553383122817_item	2977262	et	4	main
happinessbeethoven	doc_553383122817_item	2977269	et	4	main
born	doc_553383122817_item	2977286	et	4	main
other	doc_553383122817_item	2977289	et	4	main
would	doc_553383122817_item	2977296	et	4	main
ema	doc_553383122817_item	2977310	et	4	main
teda	doc_553383122817_item	2977313	et	4	main
vastuseks	doc_553383122817_item	2977321	et	4	main
paljude	doc_553383122817_item	2977322	et	3	main
romaanide	doc_553383122817_item	2977323	et	3	main
ja	doc_553383122817_item	2977186	et	3	main
abielust	doc_553383122817_item	2977190	et	3	main
viimast	doc_553383122817_item	2977193	et	4	main
josephine	doc_553383122817_item	2977199	et	4	main
peategelased	doc_553383122817_item	2977208	et	3	main
on	doc_553383122817_item	2977209	et	4	main
surnud	doc_553383122817_item	2977210	et	4	main
kirjutab	doc_553383122817_item	2977211	et	3	main
4021846	doc_553383122817_item	2977212	et	2	main
therese	doc_553383122817_item	2977213	et	4	main
oma	doc_553383122817_item	2977214	et	4	main
päevikusse	doc_553383122817_item	2977215	et	4	main
beethoven	doc_553383122817_item	2977216	et	4	main
it	doc_553383122817_item	2977217	et	4	main
seems	doc_553383122817_item	2977218	et	4	main
like	doc_553383122817_item	2977219	et	4	main
a	doc_553383122817_item	2977220	et	4	main
dream	doc_553383122817_item	2977221	et	4	main
that	doc_553383122817_item	2977222	et	4	main
he	doc_553383122817_item	2977223	et	4	main
was	doc_553383122817_item	2977224	et	4	main
the	doc_553383122817_item	2977225	et	4	main
friend	doc_553383122817_item	2977226	et	4	main
the	doc_553383122817_item	2977227	et	4	main
stupendous	doc_553383122817_item	2977233	et	4	main
spirit	doc_553383122817_item	2977234	et	4	main
why	doc_553383122817_item	2977235	et	4	main
j	doc_553383122817_item	2977240	et	4	main
as	doc_553383122817_item	2977241	et	4	main
was	doc_553383122817_item	2977258	et	4	main
caused	doc_553383122817_item	2977263	et	4	main
forgo	doc_553383122817_item	2977266	et	4	main
in	doc_553383122817_item	2977277	et	4	main
heart	doc_553383122817_item	2977283	et	4	main
for	doc_553383122817_item	2977287	et	4	main
and	doc_553383122817_item	2977290	et	3	main
they	doc_553383122817_item	2977295	et	4	main
to	doc_553383122817_item	2977305	et	4	main
armastus	doc_553383122817_item	2977311	et	4	main
pani	doc_553383122817_item	2977312	et	4	main
õnne	doc_553383122817_item	2977314	et	4	main
unustama	doc_553383122817_item	2977315	et	3	main
need	doc_553383122817_item	2977316	et	3	main
sõnad	doc_553383122817_item	2977317	et	4	main
224	doc_553383122817_item	2977325	et	2	main
loo	doc_553383122817_item	2977326	et	4	main
väänas	doc_553383122817_item	2977333	et	3	main
pärildest	doc_553383122817_item	2977343	et	4	main
põhjal	doc_553383122817_item	2977347	et	4	main
ekraanil	doc_553383122817_item	2977358	et	3	main
seonduvaid	doc_553383122817_item	2977362	et	4	main
asju	doc_553383122817_item	2977366	et	3	main
loo	doc_553383122817_item	2977368	et	4	main
monolooge	doc_553383122817_item	2977371	et	4	main
lühikesi	doc_553383122817_item	2977376	et	4	main
stseene	doc_553383122817_item	2977377	et	3	main
praegu	doc_553383122817_item	2977378	et	3	main
juba	doc_553383122817_item	2977379	et	3	main
otsitakse	doc_553383122817_item	2977387	et	3	main
ning	doc_553383122817_item	2977404	et	3	main
tervikuna	doc_553383122817_item	2977412	et	3	main
kes	doc_553383122817_item	2977418	et	4	main
kõik	doc_553383122817_item	2977428	et	4	main
need	doc_553383122817_item	2977429	et	3	main
kirjad	doc_553383122817_item	2977430	et	4	main
very	doc_553383122817_item	2977274	et	4	main
spirit	doc_553383122817_item	2977278	et	4	main
josephines	doc_553383122817_item	2977279	et	4	main
they	doc_553383122817_item	2977284	et	4	main
were	doc_553383122817_item	2977285	et	4	main
each	doc_553383122817_item	2977288	et	4	main
had	doc_553383122817_item	2977291	et	4	main
they	doc_553383122817_item	2977292	et	4	main
have	doc_553383122817_item	2977297	et	4	main
now8	doc_553383122817_item	2977300	et	2	main
maternal	doc_553383122817_item	2977301	et	4	main
love	doc_553383122817_item	2977302	et	4	main
caused	doc_553383122817_item	2977303	et	4	main
her	doc_553383122817_item	2977304	et	4	main
friendin	doc_553383122817_item	2977280	et	4	main
house	doc_553383122817_item	2977281	et	4	main
and	doc_553383122817_item	2977282	et	3	main
united	doc_553383122817_item	2977294	et	4	main
living	doc_553383122817_item	2977299	et	4	main
her	doc_553383122817_item	2977307	et	4	main
ongi	doc_553383122817_item	2977318	et	4	main
tänapäeva	doc_553383122817_item	2977327	et	4	main
loo	doc_553383122817_item	2977337	et	4	main
selle	doc_553383122817_item	2977345	et	4	main
beethoveni	doc_553383122817_item	2977356	et	4	main
muusika	doc_553383122817_item	2977357	et	4	main
kirju	doc_553383122817_item	2977374	et	4	main
selle	doc_553383122817_item	2977383	et	4	main
päevikuid	doc_553383122817_item	2977396	et	4	main
oleks	doc_553383122817_item	2977419	et	3	main
ja	doc_553383122817_item	2977422	et	3	main
jutustaja	doc_553383122817_item	2977424	et	4	main
ning	doc_553383122817_item	2977425	et	3	main
kommenteerija	doc_553383122817_item	2977426	et	4	main
ei	doc_553383122817_item	2977431	et	4	main
ole	doc_553383122817_item	2977432	et	4	main
tunnistajateks	doc_553383122817_item	2977469	et	4	main
stackelbergide	doc_553383122817_item	2977471	et	4	main
oma	doc_553383122817_item	2977484	et	4	main
ajalooga	doc_553383122817_item	2977485	et	4	main
oli	doc_553383122817_item	2977490	et	3	main
puhkemaja	doc_553383122817_item	2977494	et	4	main
instituut	doc_553383122817_item	2977496	et	3	main
tulu	doc_553383122817_item	2977508	et	4	main
nimetus	doc_553383122817_item	2977529	et	4	main
tuleneb	doc_553383122817_item	2977530	et	3	main
soomekeelsest	doc_553383122817_item	2977531	et	3	main
et	doc_553383122817_item	2977539	et	3	main
nimetus	doc_553383122817_item	2977540	et	4	main
pärineb	doc_553383122817_item	2977541	et	3	main
ligikaudu	doc_553383122817_item	2977546	et	3	main
enne	doc_553383122817_item	2977549	et	4	main
oma	doc_553383122817_item	2977556	et	4	main
tähendab	doc_553383122817_item	2977564	et	3	main
forgot	doc_553383122817_item	2977306	et	4	main
own	doc_553383122817_item	2977308	et	4	main
kõikidele	doc_553383122817_item	2977319	et	4	main
tähtsus	doc_553383122817_item	2977328	et	4	main
lavastus	doc_553383122817_item	2977338	et	4	main
oleks	doc_553383122817_item	2977339	et	3	main
üks	doc_553383122817_item	2977340	et	3	main
praegu	doc_553383122817_item	2977344	et	3	main
looga	doc_553383122817_item	2977361	et	4	main
inimesi	doc_553383122817_item	2977365	et	4	main
kohti	doc_553383122817_item	2977367	et	4	main
mängiksid	doc_553383122817_item	2977375	et	4	main
lavastuse	doc_553383122817_item	2977384	et	4	main
läbiviimiseks	doc_553383122817_item	2977385	et	3	main
ning	doc_553383122817_item	2977386	et	3	main
sest	doc_553383122817_item	2977397	et	4	main
tema	doc_553383122817_item	2977398	et	4	main
oli	doc_553383122817_item	2977399	et	3	main
just	doc_553383122817_item	2977405	et	3	main
erapooletu	doc_553383122817_item	2977408	et	4	main
anda	doc_553383122817_item	2977410	et	3	main
muidu	doc_553383122817_item	2977413	et	3	main
temast	doc_553383122817_item	2977415	et	3	main
peategelast	doc_553383122817_item	2977417	et	3	main
pealtnägija	doc_553383122817_item	2977421	et	4	main
loo	doc_553383122817_item	2977423	et	4	main
ajalugu	doc_553383122817_item	2977480	et	4	main
oma	doc_553383122817_item	2977487	et	4	main
mõisnike	doc_553383122817_item	2977493	et	3	main
lõbu	doc_553383122817_item	2977506	et	4	main
harkko	doc_553383122817_item	2977533	et	4	main
kivipank	doc_553383122817_item	2977535	et	3	main
tuleb	doc_553383122817_item	2977537	et	3	main
arvata	doc_553383122817_item	2977538	et	4	main
ajastust	doc_553383122817_item	2977545	et	4	main
meie	doc_553383122817_item	2977550	et	4	main
mathias	doc_553383122817_item	2977552	et	4	main
johann	doc_553383122817_item	2977553	et	4	main
et	doc_553383122817_item	2977562	et	3	main
raamatus	doc_553383122817_item	2977570	et	4	main
või	doc_553383122817_item	2977581	et	4	main
kivikamakat	doc_553383122817_item	2977582	et	3	main
ning	doc_553383122817_item	2977583	et	3	main
ajaloolased	doc_553383122817_item	2977584	et	3	main
eeltoodud	doc_553383122817_item	2977585	et	3	main
eriti	doc_553383122817_item	2977587	et	3	main
harku	doc_553383122817_item	2977594	et	4	main
küla	doc_553383122817_item	2977595	et	4	main
nimetatud	doc_553383122817_item	2977596	et	4	main
ka	doc_553383122817_item	2977597	et	3	main
esmakordselt	doc_553383122817_item	2977603	et	4	main
harkut	doc_553383122817_item	2977605	et	4	main
hindamisraamatus	doc_553383122817_item	2977607	et	4	main
seoses	doc_553383122817_item	2977608	et	4	main
ficke	doc_553383122817_item	2977648	et	4	main
tema	doc_553383122817_item	2977656	et	4	main
nime	doc_553383122817_item	2977669	et	4	main
inimesed	doc_553383122817_item	2977673	et	3	main
fakte	doc_553383122817_item	2977680	et	3	main
ka	doc_553383122817_item	2977689	et	3	main
harke	doc_553383122817_item	2977704	et	3	main
aastast	doc_553383122817_item	2977719	et	4	main
kuni	doc_553383122817_item	2977720	et	3	main
liivi	doc_553383122817_item	2977721	et	4	main
alluv	doc_553383122817_item	2977730	et	4	main
selle	doc_553383122817_item	2977744	et	4	main
johan	doc_553383122817_item	2977747	et	4	main
eest	doc_553383122817_item	2977754	et	4	main
mekesele	doc_553383122817_item	2977757	et	4	main
tänu	doc_553383122817_item	2977758	et	4	main
ja	doc_553383122817_item	2977764	et	3	main
teine	doc_553383122817_item	2977773	et	3	main
kotipere	doc_553383122817_item	2977776	et	4	main
etendab	doc_553383122817_item	2977780	et	3	main
harku	doc_553383122817_item	2977793	et	4	main
külad	doc_553383122817_item	2977794	et	3	main
1617	doc_553383122817_item	2977800	et	2	main
mõisa	doc_553383122817_item	2977806	et	3	main
pole	doc_553383122817_item	2977809	et	3	main
oletada	doc_553383122817_item	2977813	et	3	main
arvatavasti	doc_553383122817_item	2977815	et	3	main
tool	doc_553383122817_item	2977819	et	3	main
traagikaks	doc_553383122817_item	2977324	et	3	main
muuseumi	doc_553383122817_item	2977334	et	4	main
ja	doc_553383122817_item	2977335	et	3	main
selle	doc_553383122817_item	2977336	et	4	main
peamistest	doc_553383122817_item	2977342	et	4	main
loo	doc_553383122817_item	2977346	et	4	main
tahetakse	doc_553383122817_item	2977348	et	4	main
teha	doc_553383122817_item	2977349	et	3	main
lavastuse	doc_553383122817_item	2977350	et	4	main
mille	doc_553383122817_item	2977351	et	3	main
taustaks	doc_553383122817_item	2977352	et	3	main
ja	doc_553383122817_item	2977353	et	3	main
vahepaladeks	doc_553383122817_item	2977354	et	3	main
oleks	doc_553383122817_item	2977355	et	3	main
ehk	doc_553383122817_item	2977364	et	3	main
harku	doc_553383122817_item	2977329	et	4	main
vald	doc_553383122817_item	2977330	et	3	main
planeerib	doc_553383122817_item	2977331	et	3	main
rajada	doc_553383122817_item	2977332	et	3	main
muuseumi	doc_553383122817_item	2977341	et	4	main
võiks	doc_553383122817_item	2977359	et	4	main
näidata	doc_553383122817_item	2977360	et	4	main
pilte	doc_553383122817_item	2977363	et	3	main
tegelased	doc_553383122817_item	2977369	et	3	main
loeksid	doc_553383122817_item	2977370	et	4	main
ja	doc_553383122817_item	2977372	et	3	main
oma	doc_553383122817_item	2977373	et	4	main
eksisteerivad	doc_553383122817_item	2977380	et	4	main
reaalsed	doc_553383122817_item	2977381	et	3	main
plaanid	doc_553383122817_item	2977382	et	4	main
inimesi	doc_553383122817_item	2977388	et	4	main
tööd	doc_553383122817_item	2977391	et	4	main
organiseeriks	doc_553383122817_item	2977392	et	3	main
kavatsetakse	doc_553383122817_item	2977393	et	3	main
uurida	doc_553383122817_item	2977394	et	3	main
theresa	doc_553383122817_item	2977395	et	4	main
suhe	doc_553383122817_item	2977401	et	3	main
pealt	doc_553383122817_item	2977402	et	4	main
nägija	doc_553383122817_item	2977403	et	4	main
nagu	doc_553383122817_item	2977420	et	3	main
von	doc_553383122817_item	2977470	et	4	main
3	doc_553383122817_item	2977476	et	2	main
rikkalik	doc_553383122817_item	2977483	et	3	main
jooksul	doc_553383122817_item	2977489	et	4	main
nii	doc_553383122817_item	2977491	et	3	main
seda	doc_553383122817_item	2977497	et	3	main
teised	doc_553383122817_item	2977507	et	4	main
kandja	doc_553383122817_item	2977527	et	4	main
ehk	doc_553383122817_item	2977534	et	3	main
ühis	doc_553383122817_item	2977543	et	4	main
soome	doc_553383122817_item	2977544	et	3	main
eisen	doc_553383122817_item	2977554	et	4	main
aga	doc_553383122817_item	2977555	et	3	main
teoses	doc_553383122817_item	2977557	et	3	main
daani	doc_553383122817_item	2977558	et	4	main
hindamise	doc_553383122817_item	2977559	et	4	main
raamat	doc_553383122817_item	2977560	et	3	main
ütleb	doc_553383122817_item	2977561	et	3	main
hulk	doc_553383122817_item	2977566	et	3	main
veetammi	doc_553383122817_item	2977568	et	4	main
öeldut	doc_553383122817_item	2977575	et	4	main
ei	doc_553383122817_item	2977588	et	4	main
toeta	doc_553383122817_item	2977589	et	4	main
ordumõisa	doc_553383122817_item	2977601	et	3	main
et	doc_553383122817_item	2977631	et	3	main
1317	doc_553383122817_item	2977639	et	2	main
ning	doc_553383122817_item	2977641	et	3	main
sugukonnamõis	doc_553383122817_item	2977643	et	3	main
kuulus	doc_553383122817_item	2977645	et	4	main
tool	doc_553383122817_item	2977646	et	3	main
ajal	doc_553383122817_item	2977647	et	4	main
harkele	doc_553383122817_item	2977652	et	4	main
ja	doc_553383122817_item	2977653	et	3	main
1349	doc_553383122817_item	2977654	et	2	main
aastal	doc_553383122817_item	2977655	et	3	main
tilo	doc_553383122817_item	2977658	et	4	main
de	doc_553383122817_item	2977661	et	4	main
harkele	doc_553383122817_item	2977662	et	4	main
viimasele	doc_553383122817_item	2977663	et	3	main
järgnes	doc_553383122817_item	2977664	et	3	main
de	doc_553383122817_item	2977667	et	4	main
kes	doc_553383122817_item	2977389	et	4	main
kogu	doc_553383122817_item	2977390	et	4	main
selle	doc_553383122817_item	2977400	et	4	main
tema	doc_553383122817_item	2977406	et	4	main
oskas	doc_553383122817_item	2977407	et	3	main
pilti	doc_553383122817_item	2977409	et	4	main
loole	doc_553383122817_item	2977411	et	4	main
just	doc_553383122817_item	2977414	et	3	main
lavastuse	doc_553383122817_item	2977416	et	4	main
kahjuks	doc_553383122817_item	2977427	et	4	main
eesti	doc_553383122817_item	2977433	et	4	main
keelde	doc_553383122817_item	2977434	et	4	main
tõlgitud	doc_553383122817_item	2977435	et	4	main
ning	doc_553383122817_item	2977436	et	3	main
lugu	doc_553383122817_item	2977437	et	4	main
ise	doc_553383122817_item	2977438	et	4	main
nõuab	doc_553383122817_item	2977439	et	3	main
palju	doc_553383122817_item	2977440	et	4	main
lisauuringuid	doc_553383122817_item	2977441	et	3	main
ja	doc_553383122817_item	2977442	et	3	main
tööd	doc_553383122817_item	2977443	et	4	main
enda	doc_553383122817_item	2977444	et	4	main
kaldal	doc_553383122817_item	2977445	et	3	main
kuid	doc_553383122817_item	2977446	et	4	main
plaanid	doc_553383122817_item	2977447	et	4	main
selle	doc_553383122817_item	2977448	et	4	main
kohta	doc_553383122817_item	2977449	et	4	main
on	doc_553383122817_item	2977450	et	4	main
juba	doc_553383122817_item	2977451	et	3	main
olemas	doc_553383122817_item	2977452	et	4	main
seega	doc_553383122817_item	2977453	et	4	main
jääb	doc_553383122817_item	2977454	et	3	main
loota	doc_553383122817_item	2977455	et	4	main
et	doc_553383122817_item	2977456	et	3	main
üsna	doc_553383122817_item	2977457	et	3	main
varsti	doc_553383122817_item	2977458	et	3	main
see	doc_553383122817_item	2977459	et	3	main
armastuslugu	doc_553383122817_item	2977460	et	4	main
ärkab	doc_553383122817_item	2977461	et	3	main
taas	doc_553383122817_item	2977462	et	3	main
ning	doc_553383122817_item	2977463	et	3	main
vääna	doc_553383122817_item	2977464	et	4	main
mõisa	doc_553383122817_item	2977465	et	3	main
seinad	doc_553383122817_item	2977466	et	3	main
saavad	doc_553383122817_item	2977467	et	4	main
jälle	doc_553383122817_item	2977468	et	3	main
draamale	doc_553383122817_item	2977473	et	3	main
saladustele	doc_553383122817_item	2977475	et	4	main
perekonna	doc_553383122817_item	2977472	et	4	main
ja	doc_553383122817_item	2977474	et	3	main
on	doc_553383122817_item	2977481	et	4	main
väga	doc_553383122817_item	2977482	et	3	main
elu	doc_553383122817_item	2977488	et	4	main
siin	doc_553383122817_item	2977505	et	4	main
harku	doc_553383122817_item	2977509	et	4	main
mõis	doc_553383122817_item	2977510	et	3	main
on	doc_553383122817_item	2977511	et	4	main
vaidlemata	doc_553383122817_item	2977512	et	4	main
harku	doc_553383122817_item	2977513	et	4	main
valla	doc_553383122817_item	2977514	et	4	main
üks	doc_553383122817_item	2977515	et	3	main
kuulsamaid	doc_553383122817_item	2977516	et	4	main
vaatamisväärsusi	doc_553383122817_item	2977517	et	4	main
kas	doc_553383122817_item	2977518	et	3	main
juba	doc_553383122817_item	2977519	et	3	main
sellepoolest	doc_553383122817_item	2977520	et	4	main
et	doc_553383122817_item	2977521	et	3	main
see	doc_553383122817_item	2977522	et	3	main
oli	doc_553383122817_item	2977523	et	3	main
esimene	doc_553383122817_item	2977524	et	3	main
harku	doc_553383122817_item	2977525	et	4	main
harku	doc_553383122817_item	2977477	et	4	main
harku	doc_553383122817_item	2977478	et	4	main
mõisa	doc_553383122817_item	2977479	et	3	main
hoone	doc_553383122817_item	2977486	et	4	main
orduloss	doc_553383122817_item	2977492	et	3	main
vangla	doc_553383122817_item	2977495	et	4	main
tihti	doc_553383122817_item	2977498	et	3	main
müüdi	doc_553383122817_item	2977499	et	4	main
kingiti	doc_553383122817_item	2977500	et	3	main
renditi	doc_553383122817_item	2977501	et	3	main
mõned	doc_553383122817_item	2977502	et	3	main
omanikud	doc_553383122817_item	2977503	et	3	main
otsisid	doc_553383122817_item	2977504	et	4	main
nimetuse	doc_553383122817_item	2977526	et	4	main
harku	doc_553383122817_item	2977528	et	4	main
seega	doc_553383122817_item	2977536	et	4	main
aastat	doc_553383122817_item	2977548	et	3	main
ajaarvamist9	doc_553383122817_item	2977551	et	2	main
hunnik	doc_553383122817_item	2977565	et	3	main
tallinnast	doc_553383122817_item	2977571	et	3	main
on	doc_553383122817_item	2977574	et	4	main
et	doc_553383122817_item	2977576	et	3	main
sõna	doc_553383122817_item	2977578	et	4	main
tähendab	doc_553383122817_item	2977579	et	3	main
metalli-	doc_553383122817_item	2977580	et	4	main
siinset	doc_553383122817_item	2977600	et	3	main
mainitakse	doc_553383122817_item	2977604	et	3	main
taani	doc_553383122817_item	2977606	et	4	main
andmed	doc_553383122817_item	2977633	et	3	main
de	doc_553383122817_item	2977635	et	4	main
harke	doc_553383122817_item	2977636	et	3	main
aastast	doc_553383122817_item	2977640	et	4	main
frederik	doc_553383122817_item	2977650	et	4	main
de	doc_553383122817_item	2977651	et	4	main
või	doc_553383122817_item	2977659	et	4	main
kandjaid	doc_553383122817_item	2977670	et	4	main
ei	doc_553383122817_item	2977676	et	4	main
et	doc_553383122817_item	2977685	et	3	main
mõnel	doc_553383122817_item	2977690	et	3	main
pärineval	doc_553383122817_item	2977692	et	4	main
pärinevad	doc_553383122817_item	2977698	et	4	main
de	doc_553383122817_item	2977703	et	4	main
tallinnas	doc_553383122817_item	2977707	et	4	main
on	doc_553383122817_item	2977727	et	4	main
orduloss11	doc_553383122817_item	2977731	et	2	main
mitte	doc_553383122817_item	2977732	et	3	main
enam	doc_553383122817_item	2977733	et	4	main
eraomandina	doc_553383122817_item	2977736	et	3	main
seda	doc_553383122817_item	2977738	et	3	main
alles	doc_553383122817_item	2977739	et	3	main
koha	doc_553383122817_item	2977745	et	4	main
toddeven	doc_553383122817_item	2977748	et	4	main
harku	doc_553383122817_item	2977750	et	4	main
mõisa	doc_553383122817_item	2977751	et	3	main
300	doc_553383122817_item	2977752	et	2	main
sõnast	doc_553383122817_item	2977532	et	4	main
veel	doc_553383122817_item	2977542	et	4	main
200-100	doc_553383122817_item	2977547	et	2	main
harku	doc_553383122817_item	2977563	et	4	main
agu	doc_553383122817_item	2977567	et	4	main
keila-	doc_553383122817_item	2977572	et	4	main
arvamust	doc_553383122817_item	2977586	et	3	main
sest	doc_553383122817_item	2977590	et	4	main
mõnes	doc_553383122817_item	2977591	et	3	main
ürikus	doc_553383122817_item	2977592	et	3	main
on	doc_553383122817_item	2977593	et	4	main
harkua	doc_553383122817_item	2977598	et	4	main
ja	doc_553383122817_item	2977599	et	3	main
ajaloost10	doc_553383122817_item	2977629	et	2	main
esimesed	doc_553383122817_item	2977632	et	3	main
ilmusid	doc_553383122817_item	2977638	et	4	main
et	doc_553383122817_item	2977642	et	3	main
harku	doc_553383122817_item	2977644	et	4	main
pojale	doc_553383122817_item	2977657	et	4	main
theodoricus	doc_553383122817_item	2977660	et	4	main
rida	doc_553383122817_item	2977666	et	4	main
aga	doc_553383122817_item	2977671	et	3	main
on	doc_553383122817_item	2977683	et	4	main
esines	doc_553383122817_item	2977688	et	3	main
olid	doc_553383122817_item	2977696	et	4	main
harkust	doc_553383122817_item	2977697	et	3	main
1490	doc_553383122817_item	2977705	et	2	main
katku	doc_553383122817_item	2977708	et	4	main
claves	doc_553383122817_item	2977710	et	4	main
harke	doc_553383122817_item	2977711	et	3	main
sõjani	doc_553383122817_item	2977722	et	3	main
xvi	doc_553383122817_item	2977723	et	4	main
sajandil	doc_553383122817_item	2977724	et	3	main
ordulinnusena	doc_553383122817_item	2977734	et	3	main
vaid	doc_553383122817_item	2977735	et	3	main
müüs	doc_553383122817_item	2977749	et	4	main
noore	doc_553383122817_item	2977755	et	3	main
lääne	doc_553383122817_item	2977760	et	4	main
tekkib	doc_553383122817_item	2977769	et	3	main
mõisa	doc_553383122817_item	2977771	et	3	main
mis	doc_553383122817_item	2977778	et	4	main
osa	doc_553383122817_item	2977784	et	4	main
1612	doc_553383122817_item	2977785	et	2	main
aastal	doc_553383122817_item	2977786	et	3	main
kuningas	doc_553383122817_item	2977789	et	4	main
adolf	doc_553383122817_item	2977791	et	4	main
vatsla	doc_553383122817_item	2977792	et	4	main
kroonikates	doc_553383122817_item	2977803	et	4	main
võib	doc_553383122817_item	2977812	et	3	main
ajal	doc_553383122817_item	2977820	et	4	main
aastal	doc_553383122817_item	2977824	et	3	main
gustav	doc_553383122817_item	2977826	et	4	main
adolf	doc_553383122817_item	2977827	et	4	main
kingib	doc_553383122817_item	2977828	et	3	main
ka	doc_553383122817_item	2977833	et	3	main
rudolf	doc_553383122817_item	2977859	et	4	main
vahel	doc_553383122817_item	2977874	et	4	main
vene	doc_553383122817_item	2977884	et	4	main
vägedele	doc_553383122817_item	2977885	et	3	main
millega	doc_553383122817_item	2977886	et	3	main
lõppeb	doc_553383122817_item	2977888	et	3	main
eestimaal	doc_553383122817_item	2977890	et	4	main
harku	doc_553383122817_item	2977896	et	4	main
mõisat	doc_553383122817_item	2977897	et	3	main
peter	doc_553383122817_item	2977899	et	4	main
sternberg12	doc_553383122817_item	2977904	et	2	main
sõjaväele	doc_553383122817_item	2977915	et	3	main
mõisad	doc_553383122817_item	2977926	et	3	main
suurim	doc_553383122817_item	2977938	et	3	main
xix	doc_553383122817_item	2977942	et	4	main
kuulub	doc_553383122817_item	2977944	et	3	main
enam	doc_553383122817_item	2977947	et	4	main
kui	doc_553383122817_item	2977948	et	3	main
kuuekümne	doc_553383122817_item	2977949	et	4	main
selle	doc_553383122817_item	2977954	et	4	main
võetakse	doc_553383122817_item	2977958	et	3	main
sinna	doc_553383122817_item	2977967	et	3	main
reliktjärveke	doc_553383122817_item	2977972	et	4	main
muudetakse	doc_553383122817_item	2977975	et	3	main
majapidamisharuks	doc_553383122817_item	2977978	et	3	main
viimane	doc_553383122817_item	2977987	et	3	main
maalehe	doc_553383122817_item	2977569	et	3	main
joale	doc_553383122817_item	2977573	et	3	main
see	doc_553383122817_item	2977577	et	3	main
harke	doc_553383122817_item	2977602	et	3	main
tallinna	doc_553383122817_item	2977609	et	4	main
ümbruse	doc_553383122817_item	2977610	et	3	main
rahva	doc_553383122817_item	2977611	et	3	main
ristimisega	doc_553383122817_item	2977612	et	4	main
mis	doc_553383122817_item	2977613	et	4	main
oli	doc_553383122817_item	2977614	et	3	main
korraldatud	doc_553383122817_item	2977615	et	4	main
taanlaste	doc_553383122817_item	2977616	et	3	main
poolt	doc_553383122817_item	2977617	et	4	main
1219	doc_553383122817_item	2977618	et	2	main
aasta	doc_553383122817_item	2977619	et	4	main
juuni-	doc_553383122817_item	2977620	et	4	main
ja	doc_553383122817_item	2977621	et	3	main
juulikuus	doc_553383122817_item	2977622	et	3	main
p	doc_553383122817_item	2977623	et	4	main
rahno	doc_553383122817_item	2977624	et	4	main
oma	doc_553383122817_item	2977625	et	4	main
raamatus	doc_553383122817_item	2977626	et	4	main
harku	doc_553383122817_item	2977627	et	4	main
mõisa	doc_553383122817_item	2977628	et	3	main
räägib	doc_553383122817_item	2977630	et	3	main
suguvõsa	doc_553383122817_item	2977634	et	4	main
kohta	doc_553383122817_item	2977637	et	4	main
või	doc_553383122817_item	2977649	et	4	main
terve	doc_553383122817_item	2977665	et	4	main
harke	doc_553383122817_item	2977668	et	3	main
harkus	doc_553383122817_item	2977675	et	3	main
peale	doc_553383122817_item	2977678	et	4	main
rahno	doc_553383122817_item	2977681	et	4	main
raamatus	doc_553383122817_item	2977682	et	4	main
liignimi	doc_553383122817_item	2977686	et	4	main
tallinna	doc_553383122817_item	2977693	et	4	main
käsitöölisel	doc_553383122817_item	2977694	et	3	main
kes	doc_553383122817_item	2977695	et	4	main
1370-1374	doc_553383122817_item	2977700	et	2	main
kiviraidur	doc_553383122817_item	2977701	et	3	main
henne	doc_553383122817_item	2977702	et	4	main
kronoloogia	doc_553383122817_item	2977717	et	4	main
1371	doc_553383122817_item	2977718	et	2	main
mõis	doc_553383122817_item	2977726	et	3	main
1543	doc_553383122817_item	2977740	et	2	main
aastal	doc_553383122817_item	2977741	et	3	main
omanik	doc_553383122817_item	2977746	et	3	main
marga	doc_553383122817_item	2977753	et	3	main
claus	doc_553383122817_item	2977756	et	4	main
piirkonnas	doc_553383122817_item	2977761	et	4	main
toimuvate	doc_553383122817_item	2977762	et	4	main
talude	doc_553383122817_item	2977763	et	3	main
harku	doc_553383122817_item	2977770	et	4	main
mõis	doc_553383122817_item	2977774	et	3	main
edaspidi	doc_553383122817_item	2977779	et	3	main
kingib	doc_553383122817_item	2977788	et	3	main
harku	doc_553383122817_item	2977805	et	4	main
teada	doc_553383122817_item	2977810	et	3	main
et	doc_553383122817_item	2977814	et	3	main
oli	doc_553383122817_item	2977818	et	3	main
1641	doc_553383122817_item	2977823	et	2	main
scheiding	doc_553383122817_item	2977830	et	4	main
tühjalt	doc_553383122817_item	2977834	et	4	main
harku	doc_553383122817_item	2977836	et	4	main
mõisa	doc_553383122817_item	2977837	et	3	main
hiljem	doc_553383122817_item	2977838	et	3	main
sõjakomissari	doc_553383122817_item	2977839	et	4	main
lesk	doc_553383122817_item	2977840	et	3	main
1645	doc_553383122817_item	2977841	et	2	main
aastal	doc_553383122817_item	2977842	et	3	main
nimetab	doc_553383122817_item	2977843	et	3	main
1710	doc_553383122817_item	2977850	et	2	main
vene	doc_553383122817_item	2977855	et	4	main
vägede	doc_553383122817_item	2977856	et	3	main
juhataja	doc_553383122817_item	2977857	et	4	main
kindralleitnant	doc_553383122817_item	2977858	et	3	main
kus	doc_553383122817_item	2977863	et	3	main
septembril	doc_553383122817_item	2977865	et	3	main
need	doc_553383122817_item	2977672	et	3	main
enam	doc_553383122817_item	2977674	et	4	main
elanud	doc_553383122817_item	2977677	et	4	main
neid	doc_553383122817_item	2977679	et	4	main
märgitud	doc_553383122817_item	2977684	et	4	main
harke	doc_553383122817_item	2977687	et	3	main
harkust	doc_553383122817_item	2977691	et	3	main
talupojad	doc_553383122817_item	2977699	et	4	main
a	doc_553383122817_item	2977706	et	4	main
surnud	doc_553383122817_item	2977709	et	4	main
31	doc_553383122817_item	2977712	et	2	main
mõisa	doc_553383122817_item	2977713	et	3	main
huvitav	doc_553383122817_item	2977714	et	4	main
saatus	doc_553383122817_item	2977715	et	3	main
ja	doc_553383122817_item	2977716	et	3	main
harku	doc_553383122817_item	2977725	et	4	main
tallinna	doc_553383122817_item	2977728	et	4	main
komtuurile	doc_553383122817_item	2977729	et	4	main
märgitakse	doc_553383122817_item	2977737	et	4	main
brieflades	doc_553383122817_item	2977742	et	4	main
kui	doc_553383122817_item	2977743	et	3	main
harku	doc_553383122817_item	2977759	et	4	main
külade	doc_553383122817_item	2977765	et	3	main
liitmistele	doc_553383122817_item	2977766	et	4	main
1561	doc_553383122817_item	2977767	et	2	main
aastal	doc_553383122817_item	2977768	et	3	main
lähedal	doc_553383122817_item	2977772	et	4	main
mõis	doc_553383122817_item	2977777	et	3	main
ajaloos	doc_553383122817_item	2977782	et	4	main
aga	doc_553383122817_item	2977787	et	3	main
gustav	doc_553383122817_item	2977790	et	4	main
et	doc_553383122817_item	2977804	et	3	main
aga	doc_553383122817_item	2977811	et	3	main
põhjuseks	doc_553383122817_item	2977817	et	3	main
levinud	doc_553383122817_item	2977821	et	4	main
kuningas	doc_553383122817_item	2977825	et	4	main
pärisomandina	doc_553383122817_item	2977832	et	3	main
kotipere	doc_553383122817_item	2977845	et	4	main
ja	doc_553383122817_item	2977846	et	3	main
harku	doc_553383122817_item	2977847	et	4	main
harku	doc_553383122817_item	2977852	et	4	main
asub	doc_553383122817_item	2977854	et	3	main
baueri	doc_553383122817_item	2977861	et	4	main
peakorter	doc_553383122817_item	2977862	et	3	main
29	doc_553383122817_item	2977864	et	2	main
ehk	doc_553383122817_item	2977875	et	3	main
rootsi	doc_553383122817_item	2977878	et	4	main
ja	doc_553383122817_item	2977880	et	3	main
ungern	doc_553383122817_item	2977903	et	4	main
hiiumaa	doc_553383122817_item	2977906	et	4	main
oma	doc_553383122817_item	2977912	et	4	main
laevaga	doc_553383122817_item	2977913	et	4	main
vilja	doc_553383122817_item	2977916	et	4	main
vedades	doc_553383122817_item	2977919	et	4	main
tool	doc_553383122817_item	2977920	et	3	main
ajal	doc_553383122817_item	2977921	et	4	main
jäid	doc_553383122817_item	2977927	et	4	main
oli	doc_553383122817_item	2977931	et	3	main
kokku	doc_553383122817_item	2977933	et	3	main
nii	doc_553383122817_item	2977935	et	3	main
tast	doc_553383122817_item	2977937	et	3	main
aasta	doc_553383122817_item	2977950	et	4	main
jooksul	doc_553383122817_item	2977951	et	4	main
aja	doc_553383122817_item	2977955	et	4	main
parki	doc_553383122817_item	2977963	et	4	main
looduslik	doc_553383122817_item	2977971	et	3	main
kasvatusega	doc_553383122817_item	2977986	et	4	main
sternberg	doc_553383122817_item	2977995	et	4	main
tema	doc_553383122817_item	2977996	et	4	main
olnud	doc_553383122817_item	2978004	et	4	main
kulla	doc_553383122817_item	2978015	et	4	main
juttu	doc_553383122817_item	2978021	et	4	main
polnud	doc_553383122817_item	2978045	et	3	main
vilhelm	doc_553383122817_item	2978055	et	4	main
rahno	doc_553383122817_item	2978068	et	4	main
mõisas	doc_553383122817_item	2978075	et	3	main
elas	doc_553383122817_item	2978077	et	3	main
keda	doc_553383122817_item	2978079	et	4	main
parun	doc_553383122817_item	2978080	et	3	main
külastas	doc_553383122817_item	2978081	et	3	main
ehk	doc_553383122817_item	2977775	et	3	main
harku	doc_553383122817_item	2977781	et	4	main
teatavat	doc_553383122817_item	2977783	et	4	main
mõisa	doc_553383122817_item	2977796	et	3	main
sõjakomissarile	doc_553383122817_item	2977797	et	3	main
kotipere	doc_553383122817_item	2977795	et	4	main
adam	doc_553383122817_item	2977798	et	4	main
schrapfferile	doc_553383122817_item	2977799	et	4	main
aastal	doc_553383122817_item	2977801	et	3	main
märgitakse	doc_553383122817_item	2977802	et	4	main
tühjaksjäänud	doc_553383122817_item	2977807	et	4	main
põhjus	doc_553383122817_item	2977808	et	4	main
sellele	doc_553383122817_item	2977816	et	4	main
philipp	doc_553383122817_item	2977829	et	4	main
end	doc_553383122817_item	2977844	et	4	main
aastal	doc_553383122817_item	2977851	et	3	main
mõisahoones	doc_553383122817_item	2977853	et	4	main
kirjutakse	doc_553383122817_item	2977866	et	4	main
alla	doc_553383122817_item	2977867	et	3	main
harku	doc_553383122817_item	2977868	et	4	main
tallinna	doc_553383122817_item	2977870	et	4	main
baueri	doc_553383122817_item	2977873	et	4	main
rüütelkond	doc_553383122817_item	2977882	et	4	main
alistusid	doc_553383122817_item	2977883	et	4	main
von	doc_553383122817_item	2977902	et	4	main
vene	doc_553383122817_item	2977914	et	4	main
majanduskriis	doc_553383122817_item	2977924	et	3	main
ning	doc_553383122817_item	2977929	et	3	main
maaomanik	doc_553383122817_item	2977939	et	3	main
laiendatakse	doc_553383122817_item	2977964	et	4	main
palju	doc_553383122817_item	2977968	et	4	main
puuliike	doc_553383122817_item	2977970	et	4	main
tegeletakse	doc_553383122817_item	2977981	et	3	main
pidamisega	doc_553383122817_item	2977983	et	4	main
meriino	doc_553383122817_item	2977984	et	4	main
lammaste	doc_553383122817_item	2977985	et	3	main
ungern	doc_553383122817_item	2977994	et	4	main
välismaale	doc_553383122817_item	2978010	et	4	main
aga	doc_553383122817_item	2978012	et	3	main
kaevanud	doc_553383122817_item	2978013	et	4	main
oma	doc_553383122817_item	2978014	et	4	main
selle	doc_553383122817_item	2978020	et	4	main
kindraliproua	doc_553383122817_item	2978049	et	4	main
1907	doc_553383122817_item	2978051	et	2	main
kuulus	doc_553383122817_item	2978052	et	4	main
mõis	doc_553383122817_item	2978053	et	3	main
ta	doc_553383122817_item	2978059	et	4	main
mõisas	doc_553383122817_item	2978060	et	3	main
pole	doc_553383122817_item	2978061	et	3	main
käinud	doc_553383122817_item	2978064	et	4	main
tema	doc_553383122817_item	2978070	et	4	main
end	doc_553383122817_item	2978086	et	4	main
näiteks	doc_553383122817_item	2978091	et	4	main
kui	doc_553383122817_item	2978098	et	3	main
püstitati	doc_553383122817_item	2978108	et	4	main
on	doc_553383122817_item	2978123	et	4	main
aga	doc_553383122817_item	2978126	et	3	main
kohta	doc_553383122817_item	2978131	et	4	main
siduda	doc_553383122817_item	2978132	et	3	main
tasuja	doc_553383122817_item	2978133	et	4	main
lugudega	doc_553383122817_item	2978134	et	3	main
väites	doc_553383122817_item	2978135	et	4	main
et	doc_553383122817_item	2978136	et	3	main
viibib	doc_553383122817_item	2978168	et	3	main
või	doc_553383122817_item	2978175	et	4	main
peremehed	doc_553383122817_item	2978182	et	3	main
harkust	doc_553383122817_item	2978185	et	3	main
mõisas	doc_553383122817_item	2978192	et	3	main
tegeleti	doc_553383122817_item	2978193	et	3	main
peamiselt	doc_553383122817_item	2978194	et	4	main
karjakasvatamisega	doc_553383122817_item	2978195	et	3	main
ehk	doc_553383122817_item	2978196	et	3	main
nimelt	doc_553383122817_item	2978223	et	4	main
peamiselt	doc_553383122817_item	2978227	et	4	main
kasvatamisega	doc_553383122817_item	2978229	et	4	main
mõned	doc_553383122817_item	2978230	et	3	main
sissetulekuid	doc_553383122817_item	2978231	et	4	main
tallinna	doc_553383122817_item	2978237	et	4	main
turul	doc_553383122817_item	2978238	et	3	main
õiget	doc_553383122817_item	2978239	et	3	main
arvepidamist	doc_553383122817_item	2978240	et	3	main
aga	doc_553383122817_item	2978241	et	3	main
polnud	doc_553383122817_item	2978242	et	3	main
majapidamist	doc_553383122817_item	2978303	et	3	main
need	doc_553383122817_item	2978326	et	3	main
valvas	doc_553383122817_item	2978338	et	4	main
eriti	doc_553383122817_item	2978339	et	3	main
proua	doc_553383122817_item	2978340	et	4	main
õde	doc_553383122817_item	2978341	et	4	main
katk	doc_553383122817_item	2977822	et	3	main
lesele	doc_553383122817_item	2977831	et	3	main
seisva	doc_553383122817_item	2977835	et	4	main
mõisate	doc_553383122817_item	2977848	et	3	main
omanikuks	doc_553383122817_item	2977849	et	4	main
felix	doc_553383122817_item	2977860	et	4	main
kapitulatsioonile	doc_553383122817_item	2977869	et	3	main
rahu	doc_553383122817_item	2977877	et	4	main
põhimõtteliselt	doc_553383122817_item	2977887	et	4	main
põhjasõda	doc_553383122817_item	2977889	et	4	main
311	doc_553383122817_item	2977891	et	2	main
röövelparuni	doc_553383122817_item	2977892	et	4	main
poeg	doc_553383122817_item	2977893	et	3	main
kasumit	doc_553383122817_item	2977911	et	3	main
ja	doc_553383122817_item	2977917	et	3	main
viina	doc_553383122817_item	2977918	et	4	main
paljud	doc_553383122817_item	2977925	et	3	main
sai	doc_553383122817_item	2977936	et	4	main
sajandil	doc_553383122817_item	2977943	et	3	main
harku	doc_553383122817_item	2977945	et	4	main
ungern	doc_553383122817_item	2977952	et	4	main
sternbergidele	doc_553383122817_item	2977953	et	4	main
ette	doc_553383122817_item	2977959	et	4	main
ehitus-	doc_553383122817_item	2977960	et	4	main
ja	doc_553383122817_item	2977961	et	3	main
korrastustöid	doc_553383122817_item	2977962	et	3	main
ja	doc_553383122817_item	2977974	et	3	main
linna	doc_553383122817_item	2977871	et	4	main
ja	doc_553383122817_item	2977872	et	3	main
harku	doc_553383122817_item	2977876	et	4	main
garnison	doc_553383122817_item	2977879	et	3	main
eestimaa	doc_553383122817_item	2977881	et	4	main
1830	doc_553383122817_item	2977894	et	2	main
aastal	doc_553383122817_item	2977895	et	3	main
ostab	doc_553383122817_item	2977898	et	3	main
ludwig	doc_553383122817_item	2977900	et	4	main
constantin	doc_553383122817_item	2977901	et	4	main
kurikuulsa	doc_553383122817_item	2977905	et	3	main
röövelparuni	doc_553383122817_item	2977907	et	4	main
poeg	doc_553383122817_item	2977908	et	3	main
teenis	doc_553383122817_item	2977909	et	3	main
suur	doc_553383122817_item	2977910	et	3	main
baltimaadel	doc_553383122817_item	2977922	et	4	main
valitses	doc_553383122817_item	2977923	et	3	main
pankrotti	doc_553383122817_item	2977928	et	4	main
neid	doc_553383122817_item	2977930	et	4	main
võimalik	doc_553383122817_item	2977932	et	3	main
osta	doc_553383122817_item	2977934	et	4	main
eestimaal	doc_553383122817_item	2977940	et	4	main
niimoodi	doc_553383122817_item	2977941	et	3	main
mõis	doc_553383122817_item	2977946	et	3	main
jooksul	doc_553383122817_item	2977956	et	4	main
seal	doc_553383122817_item	2977957	et	4	main
tunduvalt	doc_553383122817_item	2977965	et	4	main
istutakse	doc_553383122817_item	2977966	et	3	main
haruldasi	doc_553383122817_item	2977969	et	3	main
tiigiks	doc_553383122817_item	2977976	et	3	main
harku	doc_553383122817_item	2977979	et	4	main
selle	doc_553383122817_item	2977988	et	4	main
kohta	doc_553383122817_item	2977997	et	4	main
levis	doc_553383122817_item	2977998	et	4	main
tool	doc_553383122817_item	2977999	et	3	main
ajal	doc_553383122817_item	2978000	et	4	main
rahvajutt	doc_553383122817_item	2978001	et	3	main
et	doc_553383122817_item	2978002	et	3	main
põgenenud	doc_553383122817_item	2978008	et	4	main
enne	doc_553383122817_item	2978011	et	4	main
friederih	doc_553383122817_item	2978054	et	4	main
elanud	doc_553383122817_item	2978062	et	4	main
sõnul	doc_553383122817_item	2978069	et	3	main
puuduvad	doc_553383122817_item	2978074	et	4	main
aga	doc_553383122817_item	2978076	et	3	main
jättis	doc_553383122817_item	2978087	et	3	main
mõisa	doc_553383122817_item	2978104	et	3	main
pargis	doc_553383122817_item	2978105	et	3	main
mägi	doc_553383122817_item	2978112	et	3	main
see	doc_553383122817_item	2978121	et	3	main
tasuja	doc_553383122817_item	2978140	et	4	main
ta	doc_553383122817_item	2978170	et	4	main
selle	doc_553383122817_item	2978180	et	4	main
ta	doc_553383122817_item	2978183	et	4	main
võimalikult	doc_553383122817_item	2978186	et	4	main
rohkem	doc_553383122817_item	2978187	et	4	main
tulu	doc_553383122817_item	2978188	et	4	main
välja	doc_553383122817_item	2978189	et	4	main
pigistada	doc_553383122817_item	2978190	et	3	main
ennem	doc_553383122817_item	2978191	et	4	main
aga	doc_553383122817_item	2978200	et	3	main
uus	doc_553383122817_item	2978201	et	3	main
omanik	doc_553383122817_item	2978202	et	3	main
ehitab	doc_553383122817_item	2978203	et	3	main
sinna	doc_553383122817_item	2978204	et	3	main
piiritusevabriku	doc_553383122817_item	2978205	et	3	main
sellega	doc_553383122817_item	2978220	et	3	main
tegeleti	doc_553383122817_item	2978226	et	3	main
endale	doc_553383122817_item	2978249	et	4	main
piisavalt	doc_553383122817_item	2978255	et	4	main
tulu	doc_553383122817_item	2978256	et	4	main
ning	doc_553383122817_item	2978257	et	3	main
parun	doc_553383122817_item	2978258	et	3	main
põldroos	doc_553383122817_item	2978269	et	4	main
von	doc_553383122817_item	2978281	et	4	main
samuti	doc_553383122817_item	2978284	et	3	main
tema	doc_553383122817_item	2978289	et	4	main
isiklikult	doc_553383122817_item	2978290	et	4	main
tuleb	doc_553383122817_item	2978291	et	3	main
sest	doc_553383122817_item	2978301	et	4	main
ajab	doc_553383122817_item	2978302	et	3	main
ise	doc_553383122817_item	2978304	et	4	main
räägiti	doc_553383122817_item	2978305	et	3	main
et	doc_553383122817_item	2978306	et	3	main
tema	doc_553383122817_item	2978307	et	4	main
rangelt	doc_553383122817_item	2978324	et	4	main
said	doc_553383122817_item	2978331	et	4	main
kohe	doc_553383122817_item	2978332	et	4	main
süvendatakse	doc_553383122817_item	2977973	et	3	main
peamiseks	doc_553383122817_item	2977977	et	3	main
mõisas	doc_553383122817_item	2977980	et	3	main
piimakarja	doc_553383122817_item	2977982	et	4	main
suguvõsast	doc_553383122817_item	2977989	et	4	main
pärit	doc_553383122817_item	2977990	et	3	main
parun	doc_553383122817_item	2977991	et	3	main
oli	doc_553383122817_item	2977992	et	3	main
robert	doc_553383122817_item	2977993	et	4	main
segatud	doc_553383122817_item	2978005	et	4	main
keisritapmise	doc_553383122817_item	2978006	et	3	main
vandenõusse	doc_553383122817_item	2978007	et	3	main
harku	doc_553383122817_item	2978016	et	4	main
kinnitas	doc_553383122817_item	2978022	et	3	main
endine	doc_553383122817_item	2978023	et	3	main
harku	doc_553383122817_item	2978024	et	4	main
mõisa	doc_553383122817_item	2978025	et	3	main
sepp	doc_553383122817_item	2978026	et	3	main
julius	doc_553383122817_item	2978027	et	4	main
põldroos	doc_553383122817_item	2978028	et	4	main
tema	doc_553383122817_item	2978029	et	4	main
sõnul	doc_553383122817_item	2978030	et	3	main
ta	doc_553383122817_item	2978031	et	4	main
ise	doc_553383122817_item	2978032	et	4	main
käinud	doc_553383122817_item	2978033	et	4	main
koos	doc_553383122817_item	2978034	et	4	main
viimase	doc_553383122817_item	2978035	et	3	main
harku	doc_553383122817_item	2978036	et	4	main
mõisnikuga	doc_553383122817_item	2978037	et	3	main
seda	doc_553383122817_item	2978038	et	3	main
varandust	doc_553383122817_item	2978039	et	3	main
otsima	doc_553383122817_item	2978040	et	4	main
aga	doc_553383122817_item	2978041	et	3	main
mõisniku	doc_553383122817_item	2978042	et	3	main
näidatud	doc_553383122817_item	2978043	et	4	main
ta	doc_553383122817_item	2978003	et	4	main
sellepärast	doc_553383122817_item	2978009	et	3	main
metsas	doc_553383122817_item	2978017	et	3	main
maa	doc_553383122817_item	2978018	et	4	main
sisse	doc_553383122817_item	2978019	et	4	main
aga	doc_553383122817_item	2978046	et	3	main
312	doc_553383122817_item	2978048	et	2	main
1895-	doc_553383122817_item	2978050	et	4	main
isiklikult	doc_553383122817_item	2978058	et	4	main
arhiivandmed	doc_553383122817_item	2978072	et	4	main
kindraliproua	doc_553383122817_item	2978078	et	4	main
mälestusi	doc_553383122817_item	2978090	et	4	main
kuulus	doc_553383122817_item	2978093	et	4	main
ratsahobune	doc_553383122817_item	2978095	et	4	main
ja	doc_553383122817_item	2978097	et	3	main
otsa	doc_553383122817_item	2978100	et	4	main
saanud	doc_553383122817_item	2978101	et	4	main
maeti	doc_553383122817_item	2978102	et	3	main
monument	doc_553383122817_item	2978109	et	3	main
kivitükki	doc_553383122817_item	2978119	et	4	main
millel	doc_553383122817_item	2978120	et	3	main
pealkiri	doc_553383122817_item	2978122	et	3	main
hiljem	doc_553383122817_item	2978125	et	3	main
rahvajutud	doc_553383122817_item	2978128	et	3	main
püüavad	doc_553383122817_item	2978129	et	3	main
on	doc_553383122817_item	2978138	et	4	main
peterburis	doc_553383122817_item	2978169	et	4	main
piimakarja	doc_553383122817_item	2978197	et	4	main
aurujahuveski	doc_553383122817_item	2978207	et	4	main
ta	doc_553383122817_item	2978210	et	4	main
mõisas	doc_553383122817_item	2978225	et	3	main
piimakarja	doc_553383122817_item	2978228	et	4	main
tooteid	doc_553383122817_item	2978235	et	4	main
müüdi	doc_553383122817_item	2978236	et	4	main
aednikupoisid	doc_553383122817_item	2978244	et	4	main
jätsid	doc_553383122817_item	2978246	et	4	main
müüs	doc_553383122817_item	2978259	et	4	main
seda	doc_553383122817_item	2978260	et	3	main
julius	doc_553383122817_item	2978268	et	4	main
richard	doc_553383122817_item	2978280	et	4	main
on	doc_553383122817_item	2978283	et	4	main
tulu	doc_553383122817_item	2978286	et	4	main
otsija	doc_553383122817_item	2978287	et	4	main
siia	doc_553383122817_item	2978292	et	4	main
ning	doc_553383122817_item	2978293	et	3	main
hakkab	doc_553383122817_item	2978294	et	3	main
mõisas	doc_553383122817_item	2978295	et	3	main
elama	doc_553383122817_item	2978296	et	3	main
harpe	doc_553383122817_item	2978297	et	4	main
muudab	doc_553383122817_item	2978298	et	3	main
keelatud	doc_553383122817_item	2978325	et	4	main
selle	doc_553383122817_item	2978336	et	4	main
kes	doc_553383122817_item	2978342	et	4	main
oli	doc_553383122817_item	2978343	et	3	main
keda	doc_553383122817_item	2978352	et	4	main
pargis	doc_553383122817_item	2978353	et	3	main
kohanud	doc_553383122817_item	2978354	et	4	main
võimalusi	doc_553383122817_item	2978361	et	3	main
tema	doc_553383122817_item	2978363	et	4	main
oligi	doc_553383122817_item	2978364	et	3	main
see	doc_553383122817_item	2978365	et	3	main
mõisnik	doc_553383122817_item	2978366	et	3	main
kellega	doc_553383122817_item	2978367	et	3	main
ungern	doc_553383122817_item	2978373	et	4	main
juttu	doc_553383122817_item	2978378	et	4	main
kinnitab	doc_553383122817_item	2978379	et	3	main
1938	doc_553383122817_item	2978381	et	2	main
nr9	doc_553383122817_item	2978386	et	4	main
samuti	doc_553383122817_item	2978389	et	3	main
öeldud	doc_553383122817_item	2978390	et	4	main
et	doc_553383122817_item	2978391	et	3	main
viimane	doc_553383122817_item	2978392	et	3	main
harku	doc_553383122817_item	2978393	et	4	main
omanik	doc_553383122817_item	2978394	et	3	main
kaevamise	doc_553383122817_item	2978412	et	4	main
on	doc_553383122817_item	2978421	et	4	main
sõnul	doc_553383122817_item	2978427	et	3	main
harku	doc_553383122817_item	2978428	et	4	main
meister	doc_553383122817_item	2978444	et	3	main
kohtades	doc_553383122817_item	2978044	et	3	main
midagi	doc_553383122817_item	2978047	et	4	main
von	doc_553383122817_item	2978056	et	4	main
weymarnile13	doc_553383122817_item	2978057	et	2	main
kuid	doc_553383122817_item	2978063	et	4	main
seal	doc_553383122817_item	2978065	et	4	main
vahetevahel	doc_553383122817_item	2978066	et	3	main
p	doc_553383122817_item	2978067	et	4	main
kohta	doc_553383122817_item	2978071	et	4	main
peaaegu	doc_553383122817_item	2978073	et	3	main
päris	doc_553383122817_item	2978088	et	4	main
temale	doc_553383122817_item	2978092	et	3	main
üks	doc_553383122817_item	2978094	et	3	main
ataman	doc_553383122817_item	2978096	et	3	main
see	doc_553383122817_item	2978099	et	3	main
hauale	doc_553383122817_item	2978107	et	3	main
püha	doc_553383122817_item	2978111	et	4	main
praegugi	doc_553383122817_item	2978113	et	3	main
veel	doc_553383122817_item	2978115	et	4	main
näha	doc_553383122817_item	2978116	et	3	main
selle	doc_553383122817_item	2978117	et	4	main
monumendi	doc_553383122817_item	2978118	et	3	main
seal	doc_553383122817_item	2978137	et	4	main
hobune	doc_553383122817_item	2978141	et	4	main
või	doc_553383122817_item	2978142	et	4	main
isegi	doc_553383122817_item	2978143	et	4	main
tasuja	doc_553383122817_item	2978144	et	4	main
kuldmõõk	doc_553383122817_item	2978145	et	3	main
313	doc_553383122817_item	2978146	et	2	main
omanik	doc_553383122817_item	2978147	et	3	main
peterburist	doc_553383122817_item	2978148	et	4	main
1907-	doc_553383122817_item	2978149	et	4	main
08	doc_553383122817_item	2978150	et	2	main
aastate	doc_553383122817_item	2978151	et	3	main
paiku	doc_553383122817_item	2978152	et	4	main
müüb	doc_553383122817_item	2978153	et	3	main
friederih	doc_553383122817_item	2978154	et	4	main
vilhelm	doc_553383122817_item	2978155	et	4	main
von	doc_553383122817_item	2978156	et	4	main
weymarn	doc_553383122817_item	2978157	et	4	main
harku	doc_553383122817_item	2978158	et	4	main
parun	doc_553383122817_item	2978159	et	3	main
knorringile14	doc_553383122817_item	2978160	et	2	main
kes	doc_553383122817_item	2978161	et	4	main
samuti	doc_553383122817_item	2978162	et	3	main
isiklikult	doc_553383122817_item	2978163	et	4	main
seal	doc_553383122817_item	2978164	et	4	main
ei	doc_553383122817_item	2978165	et	4	main
ela	doc_553383122817_item	2978166	et	4	main
vaid	doc_553383122817_item	2978167	et	3	main
vahetevahel	doc_553383122817_item	2978082	et	3	main
naine	doc_553383122817_item	2978083	et	3	main
aga	doc_553383122817_item	2978084	et	3	main
pärast	doc_553383122817_item	2978085	et	4	main
huvitavaid	doc_553383122817_item	2978089	et	4	main
looma	doc_553383122817_item	2978103	et	4	main
ning	doc_553383122817_item	2978106	et	3	main
nimega	doc_553383122817_item	2978110	et	3	main
on	doc_553383122817_item	2978114	et	4	main
alles	doc_553383122817_item	2978124	et	3	main
ilmunud	doc_553383122817_item	2978127	et	4	main
sedagi	doc_553383122817_item	2978130	et	3	main
maetud	doc_553383122817_item	2978139	et	4	main
otsi	doc_553383122817_item	2978172	et	4	main
puhkepaika	doc_553383122817_item	2978174	et	4	main
lõbutsemist	doc_553383122817_item	2978176	et	4	main
nagu	doc_553383122817_item	2978177	et	3	main
seda	doc_553383122817_item	2978178	et	3	main
tegid	doc_553383122817_item	2978179	et	4	main
kasvatamisega	doc_553383122817_item	2978198	et	4	main
aga	doc_553383122817_item	2978208	et	3	main
kuna	doc_553383122817_item	2978209	et	3	main
ei	doc_553383122817_item	2978211	et	4	main
elanud	doc_553383122817_item	2978212	et	4	main
kunagi	doc_553383122817_item	2978213	et	3	main
mõisas	doc_553383122817_item	2978214	et	3	main
ning	doc_553383122817_item	2978215	et	3	main
isiklikult	doc_553383122817_item	2978216	et	4	main
majapidamisega	doc_553383122817_item	2978217	et	3	main
pole	doc_553383122817_item	2978218	et	3	main
kuna	doc_553383122817_item	2978224	et	3	main
aiast	doc_553383122817_item	2978234	et	4	main
vanemad	doc_553383122817_item	2978243	et	4	main
seega	doc_553383122817_item	2978250	et	4	main
mõis	doc_553383122817_item	2978251	et	3	main
ei	doc_553383122817_item	2978252	et	4	main
ära	doc_553383122817_item	2978261	et	4	main
ei	doc_553383122817_item	2978171	et	4	main
mõisas	doc_553383122817_item	2978173	et	3	main
endised	doc_553383122817_item	2978181	et	3	main
püüab	doc_553383122817_item	2978184	et	3	main
nüüd	doc_553383122817_item	2978199	et	4	main
ja	doc_553383122817_item	2978206	et	3	main
tegelenud	doc_553383122817_item	2978219	et	4	main
tekkisid	doc_553383122817_item	2978221	et	4	main
raskused	doc_553383122817_item	2978222	et	4	main
saadi	doc_553383122817_item	2978232	et	4	main
ka	doc_553383122817_item	2978233	et	3	main
tihti	doc_553383122817_item	2978245	et	3	main
osa	doc_553383122817_item	2978247	et	4	main
raha	doc_553383122817_item	2978248	et	4	main
andnud	doc_553383122817_item	2978253	et	4	main
omanikule	doc_553383122817_item	2978254	et	3	main
314	doc_553383122817_item	2978262	et	2	main
viimane	doc_553383122817_item	2978263	et	3	main
eraomanik	doc_553383122817_item	2978264	et	3	main
ja	doc_553383122817_item	2978265	et	3	main
jutustaja	doc_553383122817_item	2978266	et	4	main
sepp	doc_553383122817_item	2978267	et	3	main
herman	doc_553383122817_item	2978279	et	4	main
kuid	doc_553383122817_item	2978288	et	4	main
harku	doc_553383122817_item	2978299	et	4	main
ajal	doc_553383122817_item	2978308	et	4	main
kes	doc_553383122817_item	2978327	et	4	main
vahele	doc_553383122817_item	2978329	et	4	main
jäid	doc_553383122817_item	2978330	et	4	main
kätte	doc_553383122817_item	2978335	et	4	main
peksnud	doc_553383122817_item	2978349	et	4	main
sellega	doc_553383122817_item	2978350	et	3	main
inimesi	doc_553383122817_item	2978351	et	4	main
majapidamise	doc_553383122817_item	2978356	et	3	main
põldroos	doc_553383122817_item	2978370	et	4	main
kulla	doc_553383122817_item	2978375	et	4	main
otsimas	doc_553383122817_item	2978376	et	4	main
ilmunud	doc_553383122817_item	2978383	et	4	main
herman	doc_553383122817_item	2978395	et	4	main
richard	doc_553383122817_item	2978396	et	4	main
tambeti	doc_553383122817_item	2978400	et	4	main
talu	doc_553383122817_item	2978401	et	4	main
varemetes	doc_553383122817_item	2978402	et	4	main
jälgi	doc_553383122817_item	2978413	et	4	main
seotud	doc_553383122817_item	2978422	et	4	main
ka	doc_553383122817_item	2978423	et	3	main
teine	doc_553383122817_item	2978424	et	3	main
kohalekutsutud	doc_553383122817_item	2978442	et	4	main
kella	doc_553383122817_item	2978471	et	4	main
pani	doc_553383122817_item	2978479	et	4	main
seisma	doc_553383122817_item	2978482	et	3	main
parimaid	doc_553383122817_item	2978488	et	4	main
meistreid	doc_553383122817_item	2978489	et	3	main
kohale	doc_553383122817_item	2978490	et	4	main
käima	doc_553383122817_item	2978497	et	4	main
kuna	doc_553383122817_item	2978502	et	3	main
ajal	doc_553383122817_item	2978509	et	4	main
võetud	doc_553383122817_item	2978517	et	4	main
kodanluse	doc_553383122817_item	2978518	et	4	main
toodi	doc_553383122817_item	2978530	et	4	main
viidi	doc_553383122817_item	2978537	et	4	main
laitse	doc_553383122817_item	2978540	et	4	main
liivamägedes	doc_553383122817_item	2978568	et	3	main
praegu	doc_553383122817_item	2978571	et	3	main
võimalik	doc_553383122817_item	2978572	et	3	main
40-60	doc_553383122817_item	2978574	et	2	main
kalmu	doc_553383122817_item	2978575	et	4	main
lükati	doc_553383122817_item	2978586	et	4	main
buldooseriga	doc_553383122817_item	2978590	et	3	main
on	doc_553383122817_item	2978603	et	4	main
andmeid	doc_553383122817_item	2978604	et	3	main
eksperimentaalbioloogia	doc_553383122817_item	2978619	et	4	main
instituut	doc_553383122817_item	2978620	et	3	main
mis	doc_553383122817_item	2978621	et	4	main
töötab	doc_553383122817_item	2978622	et	3	main
vilde	doc_553383122817_item	2978633	et	4	main
mõisa	doc_553383122817_item	2978270	et	3	main
ostnud	doc_553383122817_item	2978271	et	4	main
1911	doc_553383122817_item	2978272	et	2	main
aastast	doc_553383122817_item	2978273	et	4	main
uus	doc_553383122817_item	2978274	et	3	main
ja	doc_553383122817_item	2978275	et	3	main
viimane	doc_553383122817_item	2978276	et	3	main
eraomanik	doc_553383122817_item	2978277	et	3	main
ehk	doc_553383122817_item	2978278	et	3	main
harpe15	doc_553383122817_item	2978282	et	2	main
suure	doc_553383122817_item	2978285	et	3	main
tulutoovamaks	doc_553383122817_item	2978300	et	4	main
olnud	doc_553383122817_item	2978309	et	4	main
mõisa	doc_553383122817_item	2978310	et	3	main
park	doc_553383122817_item	2978311	et	3	main
hästi	doc_553383122817_item	2978312	et	3	main
korras	doc_553383122817_item	2978313	et	4	main
pargi	doc_553383122817_item	2978314	et	4	main
teed	doc_553383122817_item	2978315	et	4	main
hoitud	doc_553383122817_item	2978316	et	4	main
alati	doc_553383122817_item	2978317	et	4	main
puhtad	doc_553383122817_item	2978318	et	3	main
lihtrahval	doc_553383122817_item	2978319	et	3	main
kuid	doc_553383122817_item	2978320	et	4	main
sinna	doc_553383122817_item	2978321	et	3	main
minek	doc_553383122817_item	2978322	et	3	main
oli	doc_553383122817_item	2978323	et	3	main
seal	doc_553383122817_item	2978328	et	4	main
järele	doc_553383122817_item	2978337	et	4	main
pargis	doc_553383122817_item	2978345	et	3	main
alati	doc_553383122817_item	2978346	et	4	main
ratsapiitsaga	doc_553383122817_item	2978347	et	3	main
ja	doc_553383122817_item	2978348	et	3	main
otsinud	doc_553383122817_item	2978357	et	4	main
ka	doc_553383122817_item	2978359	et	3	main
julius	doc_553383122817_item	2978369	et	4	main
sternbergi	doc_553383122817_item	2978374	et	4	main
ka	doc_553383122817_item	2978380	et	3	main
aastal	doc_553383122817_item	2978382	et	3	main
kaitse	doc_553383122817_item	2978384	et	4	main
kodu	doc_553383122817_item	2978385	et	4	main
on	doc_553383122817_item	2978388	et	4	main
von	doc_553383122817_item	2978397	et	4	main
peale	doc_553383122817_item	2978407	et	4	main
nendes	doc_553383122817_item	2978414	et	4	main
rahvajutt	doc_553383122817_item	2978425	et	3	main
mõisahoone	doc_553383122817_item	2978429	et	4	main
põhjapoolsel	doc_553383122817_item	2978430	et	3	main
küljel	doc_553383122817_item	2978431	et	3	main
radu	doc_553383122817_item	2978432	et	3	main
kõrval	doc_553383122817_item	2978433	et	4	main
oli	doc_553383122817_item	2978434	et	3	main
mõisnike	doc_553383122817_item	2978435	et	3	main
vaid	doc_553383122817_item	2978468	et	3	main
ta	doc_553383122817_item	2978478	et	4	main
kogu	doc_553383122817_item	2978486	et	4	main
maailmast	doc_553383122817_item	2978487	et	4	main
on	doc_553383122817_item	2978500	et	4	main
kindrali	doc_553383122817_item	2978508	et	3	main
käinud	doc_553383122817_item	2978510	et	4	main
jäi	doc_553383122817_item	2978511	et	3	main
seisma	doc_553383122817_item	2978512	et	3	main
harpe	doc_553383122817_item	2978513	et	4	main
valitsuse	doc_553383122817_item	2978519	et	4	main
alaealiste	doc_553383122817_item	2978531	et	4	main
kurjategijate	doc_553383122817_item	2978532	et	3	main
koloonia	doc_553383122817_item	2978533	et	4	main
koloonia	doc_553383122817_item	2978538	et	4	main
matmispaigas	doc_553383122817_item	2978569	et	4	main
uurimistööid	doc_553383122817_item	2978595	et	4	main
harku	doc_553383122817_item	2978605	et	4	main
vanglas	doc_553383122817_item	2978606	et	3	main
matmispaiga	doc_553383122817_item	2978611	et	4	main
kohta16	doc_553383122817_item	2978612	et	2	main
1957	doc_553383122817_item	2978613	et	2	main
aastal	doc_553383122817_item	2978614	et	3	main
rajati	doc_553383122817_item	2978615	et	3	main
rahvapärimuste	doc_553383122817_item	2978628	et	4	main
ning	doc_553383122817_item	2978644	et	3	main
lugu	doc_553383122817_item	2978645	et	4	main
toetub	doc_553383122817_item	2978647	et	3	main
kuuldud	doc_553383122817_item	2978652	et	4	main
motiividele	doc_553383122817_item	2978653	et	3	main
praegu	doc_553383122817_item	2978654	et	3	main
saksakeelsest	doc_553383122817_item	2978691	et	3	main
lodensee	doc_553383122817_item	2978693	et	4	main
valmis	doc_553383122817_item	2978705	et	4	main
näitama	doc_553383122817_item	2978706	et	3	main
nii	doc_553383122817_item	2978707	et	3	main
lossi	doc_553383122817_item	2978709	et	4	main
varemeid	doc_553383122817_item	2978710	et	4	main
kus	doc_553383122817_item	2978717	et	3	main
peetud	doc_553383122817_item	2978719	et	4	main
ja	doc_553383122817_item	2978720	et	3	main
mille	doc_553383122817_item	2978731	et	3	main
fotoarhiivis	doc_553383122817_item	2978768	et	3	main
harku	doc_553383122817_item	2978784	et	4	main
mõisa	doc_553383122817_item	2978785	et	3	main
pargist	doc_553383122817_item	2978786	et	3	main
otsitakse	doc_553383122817_item	2978787	et	3	main
endiselt	doc_553383122817_item	2978788	et	4	main
väärikate	doc_553383122817_item	2978789	et	3	main
puude	doc_553383122817_item	2978790	et	4	main
trüki	doc_553383122817_item	2978801	et	4	main
ajalooliste	doc_553383122817_item	2978809	et	4	main
ole	doc_553383122817_item	2978823	et	4	main
faktidele	doc_553383122817_item	2978824	et	3	main
tõepoolest	doc_553383122817_item	2978843	et	3	main
oma	doc_553383122817_item	2978333	et	4	main
karistuse	doc_553383122817_item	2978334	et	4	main
käinud	doc_553383122817_item	2978344	et	4	main
harpe	doc_553383122817_item	2978358	et	4	main
sepp	doc_553383122817_item	2978368	et	3	main
käis	doc_553383122817_item	2978371	et	4	main
robert	doc_553383122817_item	2978372	et	4	main
seppa	doc_553383122817_item	2978377	et	4	main
käisarvatava	doc_553383122817_item	2978399	et	4	main
naisega	doc_553383122817_item	2978404	et	3	main
kaevamas	doc_553383122817_item	2978405	et	4	main
ja	doc_553383122817_item	2978406	et	3	main
selle	doc_553383122817_item	2978408	et	4	main
midagi	doc_553383122817_item	2978409	et	4	main
mõisa	doc_553383122817_item	2978410	et	3	main
varemetes	doc_553383122817_item	2978415	et	4	main
tõepoolest	doc_553383122817_item	2978416	et	3	main
nähtub	doc_553383122817_item	2978417	et	3	main
julius	doc_553383122817_item	2978418	et	4	main
põldroose	doc_553383122817_item	2978419	et	3	main
nimega	doc_553383122817_item	2978420	et	3	main
tema	doc_553383122817_item	2978426	et	4	main
saksamaalt	doc_553383122817_item	2978441	et	3	main
pime	doc_553383122817_item	2978443	et	3	main
juures	doc_553383122817_item	2978472	et	4	main
osanud	doc_553383122817_item	2978494	et	4	main
kella	doc_553383122817_item	2978495	et	4	main
vastuolud	doc_553383122817_item	2978501	et	3	main
kell	doc_553383122817_item	2978506	et	3	main
algul	doc_553383122817_item	2978520	et	4	main
harku	doc_553383122817_item	2978523	et	4	main
kodanliku	doc_553383122817_item	2978545	et	3	main
valitsuse	doc_553383122817_item	2978546	et	4	main
ajal	doc_553383122817_item	2978547	et	4	main
asus	doc_553383122817_item	2978548	et	4	main
harkus	doc_553383122817_item	2978549	et	3	main
ka	doc_553383122817_item	2978550	et	3	main
tallinna	doc_553383122817_item	2978551	et	4	main
tunduvalt	doc_553383122817_item	2978581	et	4	main
vähemalt	doc_553383122817_item	2978587	et	4	main
kalmukünkaid	doc_553383122817_item	2978589	et	3	main
sinna	doc_553383122817_item	2978616	et	3	main
teaduste	doc_553383122817_item	2978617	et	3	main
akadeemia	doc_553383122817_item	2978618	et	4	main
tasuja	doc_553383122817_item	2978626	et	4	main
järgi	doc_553383122817_item	2978629	et	4	main
eduard	doc_553383122817_item	2978635	et	4	main
bornhöhe	doc_553383122817_item	2978636	et	4	main
kandis	doc_553383122817_item	2978651	et	4	main
jüriööga	doc_553383122817_item	2978661	et	3	main
tekkinud	doc_553383122817_item	2978667	et	4	main
mõjul	doc_553383122817_item	2978669	et	4	main
lodijärv	doc_553383122817_item	2978673	et	4	main
harku	doc_553383122817_item	2978676	et	4	main
on	doc_553383122817_item	2978686	et	4	main
hoopis	doc_553383122817_item	2978687	et	3	main
nimest	doc_553383122817_item	2978692	et	3	main
aastat	doc_553383122817_item	2978699	et	3	main
lodijärve	doc_553383122817_item	2978708	et	4	main
metsatalu	doc_553383122817_item	2978712	et	4	main
ka	doc_553383122817_item	2978715	et	3	main
tambetit	doc_553383122817_item	2978718	et	4	main
ta	doc_553383122817_item	2978724	et	4	main
olnud	doc_553383122817_item	2978725	et	4	main
needitud	doc_553383122817_item	2978726	et	4	main
näidati	doc_553383122817_item	2978727	et	3	main
ka	doc_553383122817_item	2978728	et	3	main
olid	doc_553383122817_item	2978739	et	4	main
laiematki	doc_553383122817_item	2978740	et	4	main
peale	doc_553383122817_item	2978355	et	4	main
muid	doc_553383122817_item	2978360	et	4	main
rikastumiseks	doc_553383122817_item	2978362	et	4	main
kus	doc_553383122817_item	2978387	et	3	main
harpe	doc_553383122817_item	2978398	et	4	main
koos	doc_553383122817_item	2978403	et	4	main
tassinud	doc_553383122817_item	2978411	et	4	main
ajal	doc_553383122817_item	2978436	et	4	main
suur	doc_553383122817_item	2978437	et	3	main
tunnikell	doc_553383122817_item	2978438	et	3	main
mille	doc_553383122817_item	2978439	et	3	main
ehitas	doc_553383122817_item	2978440	et	3	main
töö	doc_553383122817_item	2978445	et	4	main
valmimisel	doc_553383122817_item	2978446	et	4	main
mõisnik	doc_553383122817_item	2978447	et	3	main
olevat	doc_553383122817_item	2978448	et	4	main
tahtnud	doc_553383122817_item	2978449	et	4	main
meistrit	doc_553383122817_item	2978450	et	3	main
tüssata	doc_553383122817_item	2978451	et	4	main
ja	doc_553383122817_item	2978452	et	3	main
andnud	doc_553383122817_item	2978453	et	4	main
talle	doc_553383122817_item	2978454	et	4	main
õige	doc_553383122817_item	2978455	et	4	main
kuldraha	doc_553383122817_item	2978456	et	4	main
asemel	doc_553383122817_item	2978457	et	4	main
valeraha	doc_553383122817_item	2978458	et	4	main
meister	doc_553383122817_item	2978459	et	3	main
märgas	doc_553383122817_item	2978460	et	3	main
pettust	doc_553383122817_item	2978461	et	3	main
aga	doc_553383122817_item	2978462	et	3	main
pole	doc_553383122817_item	2978463	et	3	main
sellest	doc_553383122817_item	2978464	et	4	main
midagi	doc_553383122817_item	2978465	et	4	main
välja	doc_553383122817_item	2978466	et	4	main
teinud	doc_553383122817_item	2978467	et	4	main
luba	doc_553383122817_item	2978470	et	4	main
veel	doc_553383122817_item	2978473	et	4	main
kohendada	doc_553383122817_item	2978475	et	3	main
seda	doc_553383122817_item	2978480	et	3	main
uuesti	doc_553383122817_item	2978496	et	3	main
teada	doc_553383122817_item	2978504	et	3	main
ning	doc_553383122817_item	2978515	et	3	main
oli	doc_553383122817_item	2978516	et	3	main
315	doc_553383122817_item	2978522	et	2	main
enne	doc_553383122817_item	2978534	et	4	main
1940	doc_553383122817_item	2978535	et	2	main
on	doc_553383122817_item	2978570	et	4	main
määratleda	doc_553383122817_item	2978573	et	3	main
tegelike	doc_553383122817_item	2978576	et	3	main
matmise	doc_553383122817_item	2978577	et	4	main
arv	doc_553383122817_item	2978578	et	3	main
võib	doc_553383122817_item	2978579	et	3	main
olla	doc_553383122817_item	2978580	et	3	main
tasaseks	doc_553383122817_item	2978591	et	4	main
tänapäeval	doc_553383122817_item	2978592	et	3	main
viibinud	doc_553383122817_item	2978607	et	4	main
või	doc_553383122817_item	2978609	et	4	main
harku	doc_553383122817_item	2978610	et	4	main
seal	doc_553383122817_item	2978623	et	4	main
tänapäevani	doc_553383122817_item	2978624	et	3	main
32	doc_553383122817_item	2978625	et	2	main
tasujas	doc_553383122817_item	2978639	et	4	main
sealkandis	doc_553383122817_item	2978660	et	3	main
palus	doc_553383122817_item	2978469	et	4	main
midagi	doc_553383122817_item	2978474	et	4	main
selle	doc_553383122817_item	2978476	et	4	main
asemel	doc_553383122817_item	2978477	et	4	main
hoopis	doc_553383122817_item	2978481	et	3	main
pärast	doc_553383122817_item	2978483	et	4	main
kutsunud	doc_553383122817_item	2978484	et	4	main
mõisnik	doc_553383122817_item	2978485	et	3	main
aga	doc_553383122817_item	2978491	et	3	main
keegi	doc_553383122817_item	2978492	et	4	main
pole	doc_553383122817_item	2978493	et	3	main
panna	doc_553383122817_item	2978498	et	4	main
legendis	doc_553383122817_item	2978499	et	3	main
on	doc_553383122817_item	2978503	et	4	main
et	doc_553383122817_item	2978505	et	3	main
veel	doc_553383122817_item	2978507	et	4	main
ajal	doc_553383122817_item	2978514	et	4	main
maha	doc_553383122817_item	2978521	et	4	main
valu	doc_553383122817_item	2978524	et	4	main
ja	doc_553383122817_item	2978525	et	3	main
tänapäev	doc_553383122817_item	2978526	et	3	main
1919	doc_553383122817_item	2978527	et	2	main
aastal	doc_553383122817_item	2978528	et	3	main
harkusse	doc_553383122817_item	2978529	et	3	main
aastast	doc_553383122817_item	2978536	et	4	main
harkust	doc_553383122817_item	2978539	et	3	main
kuid	doc_553383122817_item	2978541	et	4	main
on	doc_553383122817_item	2978542	et	4	main
teada	doc_553383122817_item	2978543	et	3	main
et	doc_553383122817_item	2978544	et	3	main
keskvangla	doc_553383122817_item	2978552	et	4	main
osakond	doc_553383122817_item	2978553	et	3	main
kuhu	doc_553383122817_item	2978554	et	3	main
vange	doc_553383122817_item	2978555	et	3	main
toodi	doc_553383122817_item	2978556	et	4	main
turbatöödeks	doc_553383122817_item	2978557	et	3	main
lähedalasuvas	doc_553383122817_item	2978558	et	3	main
rabas	doc_553383122817_item	2978559	et	4	main
surnuid	doc_553383122817_item	2978560	et	4	main
vange	doc_553383122817_item	2978561	et	3	main
maeti	doc_553383122817_item	2978562	et	3	main
nõmme	doc_553383122817_item	2978563	et	4	main
poole	doc_553383122817_item	2978564	et	4	main
viiva	doc_553383122817_item	2978565	et	4	main
tee	doc_553383122817_item	2978566	et	4	main
äärde	doc_553383122817_item	2978567	et	4	main
suurem	doc_553383122817_item	2978582	et	4	main
kuna	doc_553383122817_item	2978583	et	3	main
1965	doc_553383122817_item	2978584	et	2	main
aastal	doc_553383122817_item	2978585	et	3	main
osa	doc_553383122817_item	2978588	et	4	main
läbi	doc_553383122817_item	2978593	et	4	main
viiakse	doc_553383122817_item	2978594	et	3	main
keskvangla	doc_553383122817_item	2978596	et	4	main
kohta	doc_553383122817_item	2978597	et	4	main
ning	doc_553383122817_item	2978598	et	3	main
otsitakse	doc_553383122817_item	2978599	et	3	main
abi	doc_553383122817_item	2978600	et	4	main
inimestelt	doc_553383122817_item	2978601	et	3	main
kellel	doc_553383122817_item	2978602	et	4	main
poliitvangide	doc_553383122817_item	2978608	et	4	main
tammed	doc_553383122817_item	2978627	et	3	main
olnud	doc_553383122817_item	2978630	et	4	main
just	doc_553383122817_item	2978631	et	3	main
e	doc_553383122817_item	2978632	et	4	main
kirjeldatud	doc_553383122817_item	2978640	et	4	main
lossi	doc_553383122817_item	2978642	et	4	main
harku	doc_553383122817_item	2978648	et	4	main
ja	doc_553383122817_item	2978649	et	3	main
padise	doc_553383122817_item	2978650	et	4	main
on	doc_553383122817_item	2978655	et	4	main
raske	doc_553383122817_item	2978656	et	4	main
kindlaks	doc_553383122817_item	2978657	et	3	main
teha	doc_553383122817_item	2978658	et	3	main
millised	doc_553383122817_item	2978659	et	3	main
seostavad	doc_553383122817_item	2978662	et	4	main
muistendid	doc_553383122817_item	2978663	et	3	main
on	doc_553383122817_item	2978664	et	4	main
vanad	doc_553383122817_item	2978665	et	3	main
millised	doc_553383122817_item	2978666	et	3	main
nimetus	doc_553383122817_item	2978672	et	4	main
on	doc_553383122817_item	2978674	et	4	main
tulnud	doc_553383122817_item	2978675	et	4	main
omaaegsest	doc_553383122817_item	2978678	et	3	main
ehkki	doc_553383122817_item	2978680	et	3	main
laenatud	doc_553383122817_item	2978688	et	4	main
mõisa	doc_553383122817_item	2978690	et	3	main
teada	doc_553383122817_item	2978695	et	3	main
veel	doc_553383122817_item	2978697	et	4	main
olid	doc_553383122817_item	2978701	et	4	main
asukohta	doc_553383122817_item	2978713	et	4	main
keldrit	doc_553383122817_item	2978716	et	3	main
olevat	doc_553383122817_item	2978734	et	4	main
neid	doc_553383122817_item	2978742	et	4	main
ise	doc_553383122817_item	2978770	et	4	main
endistviisi	doc_553383122817_item	2978792	et	3	main
tekkisid	doc_553383122817_item	2978797	et	4	main
tõsiasjadena	doc_553383122817_item	2978810	et	3	main
mis	doc_553383122817_item	2978811	et	4	main
omakorda	doc_553383122817_item	2978812	et	3	main
samuti	doc_553383122817_item	2978813	et	3	main
aitas	doc_553383122817_item	2978814	et	3	main
legendi	doc_553383122817_item	2978815	et	4	main
levikule	doc_553383122817_item	2978816	et	3	main
ja	doc_553383122817_item	2978817	et	3	main
nagu	doc_553383122817_item	2978819	et	3	main
enamik	doc_553383122817_item	2978820	et	3	main
kirjandusteoseid	doc_553383122817_item	2978821	et	3	main
ei	doc_553383122817_item	2978822	et	4	main
koosneb	doc_553383122817_item	2978828	et	3	main
võib	doc_553383122817_item	2978835	et	3	main
need	doc_553383122817_item	2978838	et	3	main
saatus	doc_553383122817_item	2978848	et	3	main
oli	doc_553383122817_item	2978849	et	3	main
saatusega	doc_553383122817_item	2978851	et	3	main
kirjutas	doc_553383122817_item	2978855	et	3	main
tädipoeg	doc_553383122817_item	2978634	et	3	main
1862-	doc_553383122817_item	2978637	et	4	main
1923	doc_553383122817_item	2978638	et	2	main
lodijarve	doc_553383122817_item	2978641	et	4	main
asupaik17	doc_553383122817_item	2978643	et	2	main
ise	doc_553383122817_item	2978646	et	4	main
kuid	doc_553383122817_item	2978670	et	4	main
isegi	doc_553383122817_item	2978671	et	4	main
kirjandusloolased	doc_553383122817_item	2978681	et	3	main
peavad	doc_553383122817_item	2978682	et	4	main
õigemaks	doc_553383122817_item	2978683	et	4	main
et	doc_553383122817_item	2978684	et	3	main
nimi	doc_553383122817_item	2978685	et	3	main
klooga	doc_553383122817_item	2978689	et	4	main
et	doc_553383122817_item	2978696	et	3	main
tasuja	doc_553383122817_item	2978711	et	4	main
raudrõngastki	doc_553383122817_item	2978721	et	4	main
mille	doc_553383122817_item	2978722	et	3	main
külge	doc_553383122817_item	2978723	et	4	main
kahte	doc_553383122817_item	2978729	et	4	main
alla	doc_553383122817_item	2978732	et	3	main
tuntud	doc_553383122817_item	2978741	et	4	main
käidi	doc_553383122817_item	2978743	et	3	main
vaatamas	doc_553383122817_item	2978744	et	3	main
ja	doc_553383122817_item	2978745	et	3	main
neist	doc_553383122817_item	2978746	et	4	main
tehti	doc_553383122817_item	2978747	et	3	main
pilte	doc_553383122817_item	2978748	et	3	main
mõned	doc_553383122817_item	2978749	et	3	main
lodijärve	doc_553383122817_item	2978750	et	4	main
lossist	doc_553383122817_item	2978751	et	3	main
ja	doc_553383122817_item	2978752	et	3	main
tasuja	doc_553383122817_item	2978753	et	4	main
tammedest	doc_553383122817_item	2978754	et	4	main
fotod	doc_553383122817_item	2978755	et	3	main
ilmusid	doc_553383122817_item	2978756	et	4	main
1910	doc_553383122817_item	2978757	et	2	main
aastal	doc_553383122817_item	2978758	et	3	main
eesti	doc_553383122817_item	2978759	et	4	main
kodus	doc_553383122817_item	2978760	et	4	main
mõned	doc_553383122817_item	2978761	et	3	main
fotod	doc_553383122817_item	2978762	et	3	main
on	doc_553383122817_item	2978763	et	4	main
säilinud	doc_553383122817_item	2978764	et	4	main
ka	doc_553383122817_item	2978765	et	3	main
eesti	doc_553383122817_item	2978766	et	4	main
ajaloomuuseumi	doc_553383122817_item	2978767	et	4	main
juba	doc_553383122817_item	2978772	et	3	main
kõdunenud	doc_553383122817_item	2978777	et	4	main
legend	doc_553383122817_item	2978778	et	3	main
on	doc_553383122817_item	2978779	et	4	main
aga	doc_553383122817_item	2978780	et	3	main
täies	doc_553383122817_item	2978781	et	3	main
elujõus	doc_553383122817_item	2978782	et	3	main
ja	doc_553383122817_item	2978783	et	3	main
seast	doc_553383122817_item	2978791	et	4	main
nimetatud	doc_553383122817_item	2978795	et	4	main
ilmumise	doc_553383122817_item	2978802	et	4	main
tuginev	doc_553383122817_item	2978825	et	4	main
osas	doc_553383122817_item	2978830	et	4	main
kirjaniku	doc_553383122817_item	2978831	et	3	main
kuid	doc_553383122817_item	2978833	et	4	main
et	doc_553383122817_item	2978837	et	3	main
tasuja	doc_553383122817_item	2978668	et	4	main
järve	doc_553383122817_item	2978677	et	4	main
nimest	doc_553383122817_item	2978679	et	3	main
on	doc_553383122817_item	2978694	et	4	main
paarkümmend	doc_553383122817_item	2978698	et	4	main
tagasi	doc_553383122817_item	2978700	et	3	main
harku	doc_553383122817_item	2978702	et	4	main
vanemad	doc_553383122817_item	2978703	et	4	main
elanikud	doc_553383122817_item	2978704	et	3	main
kui	doc_553383122817_item	2978714	et	3	main
tamme	doc_553383122817_item	2978730	et	4	main
tasuja	doc_553383122817_item	2978733	et	4	main
isa	doc_553383122817_item	2978735	et	4	main
matnud	doc_553383122817_item	2978736	et	4	main
need	doc_553383122817_item	2978737	et	3	main
tammed	doc_553383122817_item	2978738	et	3	main
tammed	doc_553383122817_item	2978769	et	3	main
ammu	doc_553383122817_item	2978773	et	4	main
ja	doc_553383122817_item	2978775	et	3	main
tammesid	doc_553383122817_item	2978794	et	3	main
järel	doc_553383122817_item	2978803	et	4	main
tollases	doc_553383122817_item	2978804	et	3	main
ajakirjanduses	doc_553383122817_item	2978805	et	3	main
tasuja	doc_553383122817_item	2978818	et	4	main
suures	doc_553383122817_item	2978829	et	3	main
fantaasiast	doc_553383122817_item	2978832	et	3	main
samuti	doc_553383122817_item	2978834	et	3	main
oletada	doc_553383122817_item	2978836	et	3	main
legendid	doc_553383122817_item	2978839	et	3	main
eksisteerisid	doc_553383122817_item	2978841	et	4	main
elas	doc_553383122817_item	2978844	et	3	main
kirjanik	doc_553383122817_item	2978854	et	3	main
harku	doc_553383122817_item	2978857	et	4	main
polnud	doc_553383122817_item	2978858	et	3	main
bornhöhele	doc_553383122817_item	2978859	et	4	main
tasuja	doc_553383122817_item	2978871	et	4	main
ja	doc_553383122817_item	2978873	et	3	main
lugu	doc_553383122817_item	2978879	et	4	main
riias	doc_553383122817_item	2978889	et	4	main
baltische	doc_553383122817_item	2978893	et	4	main
estland	doc_553383122817_item	2978899	et	4	main
tasuja	doc_553383122817_item	2978902	et	4	main
tammedest	doc_553383122817_item	2978903	et	4	main
kahe	doc_553383122817_item	2978908	et	3	main
enam	doc_553383122817_item	2978909	et	4	main
kui	doc_553383122817_item	2978910	et	3	main
700	doc_553383122817_item	2978911	et	2	main
juhti	doc_553383122817_item	2978921	et	4	main
estenführer18	doc_553383122817_item	2978923	et	2	main
kahjuks	doc_553383122817_item	2978924	et	4	main
sellised	doc_553383122817_item	2978932	et	4	main
ajal	doc_553383122817_item	2978943	et	4	main
nendes	doc_553383122817_item	2978957	et	4	main
kohtades	doc_553383122817_item	2978958	et	3	main
kaevamisi	doc_553383122817_item	2978959	et	4	main
1480	doc_553383122817_item	2978969	et	2	main
asus	doc_553383122817_item	2978972	et	4	main
väike	doc_553383122817_item	2978973	et	4	main
mõisaansambel	doc_553383122817_item	2978974	et	3	main
mis	doc_553383122817_item	2978975	et	4	main
oma	doc_553383122817_item	2978988	et	4	main
aastani	doc_553383122817_item	2978996	et	3	main
mõisa-	doc_553383122817_item	2978998	et	3	main
lõpuni	doc_553383122817_item	2979000	et	3	main
von	doc_553383122817_item	2979003	et	4	main
meyendolffide	doc_553383122817_item	2979004	et	4	main
pansionaat	doc_553383122817_item	2979059	et	3	main
ehitatud	doc_553383122817_item	2979066	et	4	main
villas	doc_553383122817_item	2979068	et	4	main
meyendoffe	doc_553383122817_item	2979072	et	4	main
nagu	doc_553383122817_item	2979074	et	3	main
viimane	doc_553383122817_item	2979095	et	3	main
suguvõsa	doc_553383122817_item	2979096	et	4	main
luterlane	doc_553383122817_item	2979097	et	3	main
meyendoffid	doc_553383122817_item	2979118	et	4	main
olid	doc_553383122817_item	2979125	et	4	main
suguluses	doc_553383122817_item	2979130	et	4	main
dünastiaga	doc_553383122817_item	2979132	et	3	main
kumnasse	doc_553383122817_item	2979142	et	4	main
paremaid	doc_553383122817_item	2979143	et	4	main
oma	doc_553383122817_item	2979148	et	4	main
on	doc_553383122817_item	2978771	et	4	main
murdunud	doc_553383122817_item	2978774	et	4	main
kännudki	doc_553383122817_item	2978776	et	3	main
tasuja	doc_553383122817_item	2978793	et	4	main
rahvapärimused	doc_553383122817_item	2978796	et	3	main
ilmselt	doc_553383122817_item	2978798	et	4	main
tasuja	doc_553383122817_item	2978799	et	4	main
esimese	doc_553383122817_item	2978800	et	3	main
esitati	doc_553383122817_item	2978806	et	4	main
neid	doc_553383122817_item	2978807	et	4	main
lugusid	doc_553383122817_item	2978808	et	3	main
ajalookronoloogia	doc_553383122817_item	2978826	et	4	main
vaid	doc_553383122817_item	2978827	et	3	main
kelle	doc_553383122817_item	2978847	et	4	main
tasuja	doc_553383122817_item	2978850	et	4	main
sarnane	doc_553383122817_item	2978852	et	4	main
ning	doc_553383122817_item	2978853	et	3	main
temast	doc_553383122817_item	2978856	et	3	main
võõras	doc_553383122817_item	2978861	et	4	main
paik	doc_553383122817_item	2978862	et	3	main
seal	doc_553383122817_item	2978863	et	4	main
teda	doc_553383122817_item	2978864	et	4	main
olevat	doc_553383122817_item	2978865	et	4	main
nähtud	doc_553383122817_item	2978866	et	4	main
ringi	doc_553383122817_item	2978867	et	4	main
ta	doc_553383122817_item	2978874	et	4	main
rahvasuust	doc_553383122817_item	2978877	et	3	main
ilmus	doc_553383122817_item	2978890	et	4	main
adolf	doc_553383122817_item	2978891	et	4	main
verkhrs-	doc_553383122817_item	2978894	et	4	main
puude	doc_553383122817_item	2978905	et	4	main
aasta	doc_553383122817_item	2978912	et	4	main
tamme	doc_553383122817_item	2978914	et	4	main
alla	doc_553383122817_item	2978915	et	3	main
rahvajutu	doc_553383122817_item	2978916	et	3	main
järgi	doc_553383122817_item	2978917	et	4	main
ei	doc_553383122817_item	2978925	et	4	main
ilmumist	doc_553383122817_item	2978938	et	4	main
ehk	doc_553383122817_item	2978939	et	3	main
1880	doc_553383122817_item	2978940	et	2	main
asjatundlikul	doc_553383122817_item	2978960	et	3	main
esimene	doc_553383122817_item	2978980	et	3	main
nimetuse	doc_553383122817_item	2978989	et	4	main
1838	doc_553383122817_item	2978992	et	2	main
kuni	doc_553383122817_item	2978994	et	3	main
ehk	doc_553383122817_item	2978997	et	3	main
ajastu	doc_553383122817_item	2978999	et	4	main
mõis	doc_553383122817_item	2979002	et	3	main
baltlastele	doc_553383122817_item	2979008	et	4	main
peahoone	doc_553383122817_item	2979021	et	4	main
on	doc_553383122817_item	2979051	et	4	main
venepärane	doc_553383122817_item	2979058	et	4	main
kumna	doc_553383122817_item	2979060	et	4	main
põlises	doc_553383122817_item	2979061	et	4	main
suures	doc_553383122817_item	2979067	et	3	main
põlvkonda	doc_553383122817_item	2979071	et	4	main
kes	doc_553383122817_item	2979073	et	4	main
parunid	doc_553383122817_item	2979079	et	3	main
eestlased	doc_553383122817_item	2979080	et	3	main
ja	doc_553383122817_item	2979081	et	3	main
inimesed	doc_553383122817_item	2979086	et	3	main
kandis	doc_553383122817_item	2979090	et	4	main
sageli	doc_553383122817_item	2979092	et	3	main
oli	doc_553383122817_item	2979098	et	3	main
georg	doc_553383122817_item	2979100	et	4	main
õigeusku	doc_553383122817_item	2979112	et	4	main
ning	doc_553383122817_item	2979113	et	3	main
tsaari	doc_553383122817_item	2979120	et	4	main
õukonnas	doc_553383122817_item	2979121	et	3	main
abielu	doc_553383122817_item	2979128	et	4	main
romanovite	doc_553383122817_item	2979131	et	4	main
jäid	doc_553383122817_item	2979141	et	4	main
moodustasid	doc_553383122817_item	2979147	et	4	main
lahkelt	doc_553383122817_item	2979154	et	4	main
tõepoolest	doc_553383122817_item	2978840	et	3	main
ja	doc_553383122817_item	2978842	et	3	main
kunagi	doc_553383122817_item	2978845	et	3	main
liikumas	doc_553383122817_item	2978868	et	3	main
kuulda	doc_553383122817_item	2978876	et	4	main
ja	doc_553383122817_item	2978880	et	3	main
richtersi	doc_553383122817_item	2978892	et	4	main
nimetatavate	doc_553383122817_item	2978904	et	4	main
maetud	doc_553383122817_item	2978918	et	4	main
kaks	doc_553383122817_item	2978919	et	3	main
eestlaste	doc_553383122817_item	2978920	et	4	main
praegu	doc_553383122817_item	2978927	et	3	main
võimalik	doc_553383122817_item	2978928	et	3	main
kindlaks	doc_553383122817_item	2978929	et	3	main
enne	doc_553383122817_item	2978936	et	4	main
tasuja	doc_553383122817_item	2978937	et	4	main
on	doc_553383122817_item	2978944	et	4	main
vaid	doc_553383122817_item	2978945	et	3	main
üks	doc_553383122817_item	2978946	et	3	main
võimalus	doc_553383122817_item	2978947	et	3	main
kõigi	doc_553383122817_item	2978948	et	4	main
tõelise	doc_553383122817_item	2978951	et	4	main
esinemiseaja	doc_553383122817_item	2978954	et	4	main
selgitamiseks	doc_553383122817_item	2978955	et	4	main
organiseerida	doc_553383122817_item	2978956	et	3	main
kangelane	doc_553383122817_item	2978846	et	3	main
mingi	doc_553383122817_item	2978860	et	4	main
enne	doc_553383122817_item	2978870	et	4	main
kirjutamist	doc_553383122817_item	2978872	et	4	main
võiks	doc_553383122817_item	2978875	et	4	main
kirjeldada	doc_553383122817_item	2978882	et	3	main
oma	doc_553383122817_item	2978884	et	4	main
teoses	doc_553383122817_item	2978885	et	3	main
näiteks	doc_553383122817_item	2978886	et	4	main
1913	doc_553383122817_item	2978887	et	2	main
aastal	doc_553383122817_item	2978888	et	3	main
adressebücher	doc_553383122817_item	2978896	et	4	main
band	doc_553383122817_item	2978897	et	4	main
praegu	doc_553383122817_item	2978901	et	3	main
ole	doc_553383122817_item	2978926	et	4	main
teha	doc_553383122817_item	2978930	et	3	main
rahvapärimused	doc_553383122817_item	2978933	et	3	main
ka	doc_553383122817_item	2978935	et	3	main
praegusel	doc_553383122817_item	2978942	et	3	main
mälestusmärkide	doc_553383122817_item	2978950	et	3	main
tekkimise	doc_553383122817_item	2978952	et	4	main
ja	doc_553383122817_item	2978953	et	3	main
oli	doc_553383122817_item	2978976	et	3	main
1620tel	doc_553383122817_item	2978978	et	4	main
aastatel	doc_553383122817_item	2978979	et	4	main
johan	doc_553383122817_item	2978983	et	4	main
kelle	doc_553383122817_item	2978985	et	4	main
järgi	doc_553383122817_item	2978986	et	4	main
koht	doc_553383122817_item	2978987	et	3	main
alates	doc_553383122817_item	2978991	et	3	main
aastast	doc_553383122817_item	2978993	et	4	main
1920	doc_553383122817_item	2978995	et	2	main
oli	doc_553383122817_item	2979001	et	3	main
põlistele	doc_553383122817_item	2979007	et	4	main
olid	doc_553383122817_item	2979010	et	4	main
mitu	doc_553383122817_item	2979011	et	4	main
põlve	doc_553383122817_item	2979012	et	4	main
venemaa	doc_553383122817_item	2979013	et	4	main
õukonna-	doc_553383122817_item	2979014	et	3	main
ja	doc_553383122817_item	2979015	et	3	main
riigiteenistuses	doc_553383122817_item	2979016	et	3	main
olles	doc_553383122817_item	2979017	et	3	main
venestunud19	doc_553383122817_item	2979018	et	2	main
mõisa	doc_553383122817_item	2979019	et	3	main
kasutusel	doc_553383122817_item	2979052	et	4	main
korterimajana	doc_553383122817_item	2979053	et	3	main
häärberis	doc_553383122817_item	2979062	et	3	main
ja	doc_553383122817_item	2979063	et	3	main
ka	doc_553383122817_item	2978869	et	3	main
mingi	doc_553383122817_item	2978878	et	4	main
pärast	doc_553383122817_item	2978881	et	4	main
seda	doc_553383122817_item	2978883	et	3	main
und	doc_553383122817_item	2978895	et	4	main
3	doc_553383122817_item	2978898	et	2	main
kus	doc_553383122817_item	2978900	et	3	main
kohta	doc_553383122817_item	2978906	et	4	main
märgitakse	doc_553383122817_item	2978907	et	4	main
vanuse	doc_553383122817_item	2978913	et	4	main
2	doc_553383122817_item	2978922	et	2	main
kas	doc_553383122817_item	2978931	et	3	main
esinesid	doc_553383122817_item	2978934	et	4	main
aastast	doc_553383122817_item	2978941	et	4	main
nende	doc_553383122817_item	2978949	et	4	main
juhendamisel	doc_553383122817_item	2978961	et	4	main
4	doc_553383122817_item	2978962	et	2	main
kumna	doc_553383122817_item	2978963	et	4	main
kumna	doc_553383122817_item	2978964	et	4	main
küla	doc_553383122817_item	2978965	et	4	main
oli	doc_553383122817_item	2978966	et	3	main
esmakordselt	doc_553383122817_item	2978967	et	4	main
mainitud	doc_553383122817_item	2978968	et	4	main
seal	doc_553383122817_item	2978971	et	4	main
oli	doc_553383122817_item	2978982	et	3	main
valduses	doc_553383122817_item	2979006	et	4	main
vana	doc_553383122817_item	2979020	et	4	main
uuem	doc_553383122817_item	2979054	et	4	main
aga	doc_553383122817_item	2979055	et	3	main
41	doc_553383122817_item	2979057	et	2	main
hiljem	doc_553383122817_item	2979065	et	3	main
kolm	doc_553383122817_item	2979070	et	3	main
raamatus	doc_553383122817_item	2979078	et	4	main
enamlased	doc_553383122817_item	2979082	et	3	main
olid	doc_553383122817_item	2979084	et	4	main
ja	doc_553383122817_item	2979087	et	3	main
parun	doc_553383122817_item	2979099	et	3	main
astusid	doc_553383122817_item	2979114	et	4	main
vene	doc_553383122817_item	2979115	et	4	main
teenistusse	doc_553383122817_item	2979116	et	3	main
kõrgetele	doc_553383122817_item	2979122	et	4	main
võimupositsioonidele	doc_553383122817_item	2979123	et	3	main
kaudu	doc_553383122817_item	2979129	et	3	main
pärast	doc_553383122817_item	2979133	et	4	main
suurt	doc_553383122817_item	2979134	et	3	main
revolutsiooni	doc_553383122817_item	2979135	et	4	main
kus	doc_553383122817_item	2979152	et	3	main
ning	doc_553383122817_item	2979160	et	3	main
1919	doc_553383122817_item	2979162	et	2	main
eesti	doc_553383122817_item	2979164	et	4	main
kogu	doc_553383122817_item	2979166	et	4	main
poolt	doc_553383122817_item	2979167	et	4	main
tulemiseks	doc_553383122817_item	2979181	et	4	main
mõisaelanikel	doc_553383122817_item	2979183	et	3	main
taimelavade	doc_553383122817_item	2979197	et	3	main
nüüd	doc_553383122817_item	2979200	et	4	main
hoolt	doc_553383122817_item	2979201	et	4	main
parunessid21	doc_553383122817_item	2979202	et	2	main
neli	doc_553383122817_item	2979209	et	3	main
aga	doc_553383122817_item	2979210	et	3	main
aru	doc_553383122817_item	2979222	et	4	main
andma	doc_553383122817_item	2979223	et	3	main
olid	doc_553383122817_item	2979230	et	4	main
ja	doc_553383122817_item	2979257	et	3	main
muistsest	doc_553383122817_item	2979260	et	3	main
ajast	doc_553383122817_item	2979263	et	4	main
näiteks	doc_553383122817_item	2979264	et	4	main
elu	doc_553383122817_item	2979274	et	4	main
oli	doc_553383122817_item	2979278	et	3	main
tehti	doc_553383122817_item	2979281	et	3	main
seda	doc_553383122817_item	2979283	et	3	main
mida	doc_553383122817_item	2979284	et	4	main
erilisi	doc_553383122817_item	2979293	et	4	main
midagi	doc_553383122817_item	2979301	et	4	main
alati	doc_553383122817_item	2979306	et	4	main
aastal	doc_553383122817_item	2978970	et	3	main
rajatud	doc_553383122817_item	2978977	et	4	main
omanik	doc_553383122817_item	2978981	et	3	main
knopius	doc_553383122817_item	2978984	et	4	main
saigi	doc_553383122817_item	2978990	et	4	main
aadliperekonna	doc_553383122817_item	2979005	et	4	main
kes	doc_553383122817_item	2979009	et	4	main
on	doc_553383122817_item	2979022	et	4	main
puuehitis	doc_553383122817_item	2979023	et	3	main
millele	doc_553383122817_item	2979024	et	3	main
on	doc_553383122817_item	2979025	et	4	main
iseloomulikud	doc_553383122817_item	2979026	et	3	main
arvukad	doc_553383122817_item	2979027	et	3	main
puidust	doc_553383122817_item	2979028	et	3	main
kaunistused	doc_553383122817_item	2979029	et	4	main
1910tel	doc_553383122817_item	2979030	et	4	main
aastatel	doc_553383122817_item	2979031	et	4	main
püstitati	doc_553383122817_item	2979032	et	4	main
vanast	doc_553383122817_item	2979033	et	3	main
peahoonest	doc_553383122817_item	2979034	et	4	main
põhjapoole	doc_553383122817_item	2979035	et	4	main
kahekorruseline	doc_553383122817_item	2979036	et	4	main
neoklassitsistlik	doc_553383122817_item	2979037	et	3	main
uus	doc_553383122817_item	2979038	et	3	main
peahoone	doc_553383122817_item	2979039	et	4	main
pärast	doc_553383122817_item	2979040	et	4	main
von	doc_553383122817_item	2979041	et	4	main
meyendolffide	doc_553383122817_item	2979042	et	4	main
perekonda	doc_553383122817_item	2979043	et	4	main
mõisasse	doc_553383122817_item	2979044	et	3	main
paigutati	doc_553383122817_item	2979045	et	3	main
sovhoosi	doc_553383122817_item	2979046	et	4	main
osakonnakeskuse	doc_553383122817_item	2979047	et	3	main
tänapäeval	doc_553383122817_item	2979048	et	3	main
puust	doc_553383122817_item	2979049	et	4	main
peahoone	doc_553383122817_item	2979050	et	4	main
varemetes20	doc_553383122817_item	2979056	et	2	main
kahes	doc_553383122817_item	2979064	et	4	main
elas	doc_553383122817_item	2979069	et	3	main
carl	doc_553383122817_item	2979075	et	4	main
mothander	doc_553383122817_item	2979076	et	4	main
kirjeldab	doc_553383122817_item	2979083	et	3	main
andekad	doc_553383122817_item	2979085	et	3	main
nende	doc_553383122817_item	2979088	et	4	main
neid	doc_553383122817_item	2979091	et	4	main
vene	doc_553383122817_item	2979111	et	4	main
tõusid	doc_553383122817_item	2979119	et	4	main
mingi	doc_553383122817_item	2979126	et	4	main
suurvürstliku	doc_553383122817_item	2979127	et	3	main
eestisse	doc_553383122817_item	2979138	et	4	main
tagasi	doc_553383122817_item	2979139	et	3	main
ja	doc_553383122817_item	2979140	et	3	main
hõimukolooniat	doc_553383122817_item	2979151	et	3	main
võeti	doc_553383122817_item	2979153	et	3	main
oma	doc_553383122817_item	2979077	et	4	main
talent	doc_553383122817_item	2979089	et	3	main
laia	doc_553383122817_item	2979093	et	4	main
maailma	doc_553383122817_item	2979094	et	4	main
meyendorff	doc_553383122817_item	2979101	et	4	main
tema	doc_553383122817_item	2979102	et	4	main
pojad	doc_553383122817_item	2979103	et	4	main
on	doc_553383122817_item	2979104	et	4	main
aga	doc_553383122817_item	2979105	et	3	main
usust	doc_553383122817_item	2979106	et	3	main
lahti	doc_553383122817_item	2979107	et	4	main
ütlesid	doc_553383122817_item	2979108	et	4	main
ning	doc_553383122817_item	2979109	et	3	main
pöördusid	doc_553383122817_item	2979110	et	4	main
venestunud	doc_553383122817_item	2979117	et	4	main
isegi	doc_553383122817_item	2979124	et	4	main
põgenesid	doc_553383122817_item	2979136	et	4	main
nad	doc_553383122817_item	2979137	et	3	main
aegu	doc_553383122817_item	2979144	et	4	main
ootama	doc_553383122817_item	2979145	et	3	main
nad	doc_553383122817_item	2979146	et	3	main
asutava	doc_553383122817_item	2979165	et	4	main
maareformi	doc_553383122817_item	2979170	et	4	main
toime	doc_553383122817_item	2979180	et	4	main
ja	doc_553383122817_item	2979184	et	3	main
käed	doc_553383122817_item	2979187	et	3	main
hoida	doc_553383122817_item	2979189	et	3	main
kolme	doc_553383122817_item	2979191	et	4	main
eest	doc_553383122817_item	2979198	et	4	main
jooma	doc_553383122817_item	2979215	et	4	main
oma	doc_553383122817_item	2979219	et	4	main
kõik	doc_553383122817_item	2979225	et	4	main
lasid	doc_553383122817_item	2979226	et	4	main
end	doc_553383122817_item	2979227	et	4	main
lõdvaks	doc_553383122817_item	2979228	et	3	main
need	doc_553383122817_item	2979229	et	3	main
luksusest	doc_553383122817_item	2979256	et	4	main
pudipadist	doc_553383122817_item	2979259	et	4	main
praegusest	doc_553383122817_item	2979262	et	3	main
pulktoolidega	doc_553383122817_item	2979270	et	3	main
seal	doc_553383122817_item	2979275	et	4	main
see	doc_553383122817_item	2979277	et	3	main
koht	doc_553383122817_item	2979279	et	3	main
nende	doc_553383122817_item	2979289	et	4	main
varjatud	doc_553383122817_item	2979300	et	4	main
peeti	doc_553383122817_item	2979312	et	4	main
pansionaati	doc_553383122817_item	2979313	et	4	main
maalt	doc_553383122817_item	2979315	et	3	main
pere	doc_553383122817_item	2979333	et	4	main
noort	doc_553383122817_item	2979334	et	3	main
pidi	doc_553383122817_item	2979341	et	4	main
oma	doc_553383122817_item	2979343	et	4	main
mõne	doc_553383122817_item	2979369	et	3	main
tädiga	doc_553383122817_item	2979371	et	3	main
abistamas	doc_553383122817_item	2979373	et	3	main
julgesti	doc_553383122817_item	2979378	et	3	main
ajaloos	doc_553383122817_item	2979385	et	4	main
kindlasti	doc_553383122817_item	2979394	et	3	main
kavalerid	doc_553383122817_item	2979402	et	4	main
siin	doc_553383122817_item	2979411	et	4	main
meeldis	doc_553383122817_item	2979412	et	3	main
imetabane	doc_553383122817_item	2979422	et	4	main
kodu	doc_553383122817_item	2979430	et	4	main
1624	doc_553383122817_item	2979468	et	2	main
mõis	doc_553383122817_item	2979472	et	3	main
linnusele	doc_553383122817_item	2979475	et	4	main
parun	doc_553383122817_item	2979483	et	3	main
perekonna	doc_553383122817_item	2979485	et	4	main
puhkekohana25	doc_553383122817_item	2979487	et	2	main
rannamõisa	doc_553383122817_item	2979489	et	3	main
kui	doc_553383122817_item	2979493	et	3	main
kaupmees	doc_553383122817_item	2979495	et	4	main
a	doc_553383122817_item	2979496	et	4	main
on	doc_553383122817_item	2979515	et	4	main
intensiivne	doc_553383122817_item	2979516	et	3	main
suvilate	doc_553383122817_item	2979517	et	3	main
pärast	doc_553383122817_item	2979529	et	4	main
olnud	doc_553383122817_item	2979532	et	4	main
suurt	doc_553383122817_item	2979540	et	3	main
säilinud	doc_553383122817_item	2979542	et	4	main
tuntud	doc_553383122817_item	2979546	et	4	main
suvilate	doc_553383122817_item	2979548	et	3	main
kuhu	doc_553383122817_item	2979551	et	3	main
sageli	doc_553383122817_item	2979554	et	3	main
17	doc_553383122817_item	2979569	et	2	main
kindralsuperintendent	doc_553383122817_item	2979574	et	3	main
burchard	doc_553383122817_item	2979576	et	4	main
seda	doc_553383122817_item	2979579	et	3	main
kiriku	doc_553383122817_item	2979581	et	3	main
altarimaali	doc_553383122817_item	2979584	et	4	main
taevaminek	doc_553383122817_item	2979585	et	3	main
1937	doc_553383122817_item	2979590	et	2	main
kuus	doc_553383122817_item	2979602	et	4	main
organist	doc_553383122817_item	2979608	et	4	main
selles	doc_553383122817_item	2979618	et	4	main
kodupaigast	doc_553383122817_item	2979149	et	4	main
sellist	doc_553383122817_item	2979150	et	4	main
vastu	doc_553383122817_item	2979155	et	3	main
kaugemaid	doc_553383122817_item	2979156	et	4	main
ja	doc_553383122817_item	2979157	et	3	main
lähemaid	doc_553383122817_item	2979158	et	4	main
sõpru	doc_553383122817_item	2979159	et	3	main
sugulasi	doc_553383122817_item	2979161	et	3	main
vastu	doc_553383122817_item	2979168	et	3	main
tuli	doc_553383122817_item	2979182	et	4	main
külalistel	doc_553383122817_item	2979186	et	4	main
terve	doc_553383122817_item	2979203	et	4	main
teed	doc_553383122817_item	2979214	et	4	main
valdkonna	doc_553383122817_item	2979220	et	4	main
kohta	doc_553383122817_item	2979221	et	4	main
odavast	doc_553383122817_item	2979258	et	4	main
ja	doc_553383122817_item	2979261	et	3	main
carl	doc_553383122817_item	2979271	et	4	main
imeliseks	doc_553383122817_item	2979276	et	4	main
pärast	doc_553383122817_item	2979290	et	4	main
pingutusi	doc_553383122817_item	2979294	et	4	main
olid	doc_553383122817_item	2979304	et	4	main
kumnas	doc_553383122817_item	2979305	et	4	main
mõisas	doc_553383122817_item	2979311	et	3	main
mitmelt	doc_553383122817_item	2979314	et	4	main
päri	doc_553383122817_item	2979316	et	4	main
tosinale	doc_553383122817_item	2979317	et	4	main
pansionaati	doc_553383122817_item	2979335	et	4	main
oli	doc_553383122817_item	2979337	et	3	main
kuid	doc_553383122817_item	2979339	et	4	main
valla	doc_553383122817_item	2979384	et	4	main
praeguse	doc_553383122817_item	2979390	et	3	main
oma	doc_553383122817_item	2979396	et	4	main
kumna	doc_553383122817_item	2979413	et	4	main
kohal	doc_553383122817_item	2979414	et	4	main
kära	doc_553383122817_item	2979417	et	4	main
ja	doc_553383122817_item	2979418	et	3	main
kilkamise	doc_553383122817_item	2979419	et	4	main
pilv	doc_553383122817_item	2979420	et	3	main
ning	doc_553383122817_item	2979421	et	3	main
oli	doc_553383122817_item	2979428	et	3	main
kus	doc_553383122817_item	2979431	et	3	main
aastani	doc_553383122817_item	2979469	et	3	main
aja	doc_553383122817_item	2979477	et	4	main
algusest	doc_553383122817_item	2979478	et	4	main
eraomand	doc_553383122817_item	2979486	et	3	main
sai	doc_553383122817_item	2979488	et	4	main
tallinna	doc_553383122817_item	2979494	et	4	main
tõelise	doc_553383122817_item	2979507	et	4	main
eestimaale	doc_553383122817_item	2979510	et	4	main
hoogustus	doc_553383122817_item	2979519	et	4	main
rohkem	doc_553383122817_item	2979545	et	4	main
ja	doc_553383122817_item	2979549	et	3	main
sõideti	doc_553383122817_item	2979552	et	3	main
pidusid	doc_553383122817_item	2979555	et	4	main
pidama	doc_553383122817_item	2979556	et	4	main
51	doc_553383122817_item	2979557	et	2	main
aastal	doc_553383122817_item	2979163	et	3	main
olukorra	doc_553383122817_item	2979179	et	3	main
töös	doc_553383122817_item	2979188	et	3	main
mõisa	doc_553383122817_item	2979190	et	3	main
suuruse	doc_553383122817_item	2979193	et	4	main
ja	doc_553383122817_item	2979194	et	3	main
viisaja	doc_553383122817_item	2979195	et	4	main
aknaga	doc_553383122817_item	2979196	et	3	main
kandsid	doc_553383122817_item	2979199	et	4	main
kell	doc_553383122817_item	2979208	et	3	main
koguneti	doc_553383122817_item	2979211	et	3	main
siis	doc_553383122817_item	2979216	et	3	main
igaüks	doc_553383122817_item	2979218	et	3	main
segadik	doc_553383122817_item	2979255	et	3	main
kõige	doc_553383122817_item	2979268	et	4	main
mothander	doc_553383122817_item	2979272	et	4	main
kus	doc_553383122817_item	2979280	et	3	main
külalistel	doc_553383122817_item	2979286	et	4	main
oli	doc_553383122817_item	2979287	et	3	main
palju	doc_553383122817_item	2979288	et	4	main
ei	doc_553383122817_item	2979291	et	4	main
nende	doc_553383122817_item	2979296	et	4	main
elu	doc_553383122817_item	2979302	et	4	main
uksed	doc_553383122817_item	2979303	et	3	main
kui	doc_553383122817_item	2979310	et	3	main
kolooniasse	doc_553383122817_item	2979327	et	3	main
hind	doc_553383122817_item	2979336	et	3	main
aednikust	doc_553383122817_item	2979370	et	3	main
kumnat	doc_553383122817_item	2979376	et	4	main
võib	doc_553383122817_item	2979377	et	3	main
selliseks	doc_553383122817_item	2979380	et	4	main
vene	doc_553383122817_item	2979381	et	4	main
tilgaks	doc_553383122817_item	2979382	et	3	main
loomulikult	doc_553383122817_item	2979387	et	4	main
erines	doc_553383122817_item	2979388	et	3	main
kohtadest	doc_553383122817_item	2979392	et	3	main
andis	doc_553383122817_item	2979395	et	3	main
balalaikamäng	doc_553383122817_item	2979403	et	3	main
ja	doc_553383122817_item	2979404	et	3	main
masurka	doc_553383122817_item	2979405	et	4	main
polnud	doc_553383122817_item	2979406	et	3	main
et	doc_553383122817_item	2979408	et	3	main
välismaa	doc_553383122817_item	2979409	et	4	main
noortele	doc_553383122817_item	2979410	et	3	main
otsekui	doc_553383122817_item	2979416	et	3	main
see	doc_553383122817_item	2979427	et	3	main
kõikidest	doc_553383122817_item	2979434	et	4	main
rannamõisa	doc_553383122817_item	2979471	et	3	main
tallinna	doc_553383122817_item	2979474	et	4	main
tsaarivalitsuse	doc_553383122817_item	2979476	et	3	main
vabahärrade	doc_553383122817_item	2979482	et	3	main
budbergide	doc_553383122817_item	2979484	et	4	main
18	doc_553383122817_item	2979491	et	2	main
sajandil	doc_553383122817_item	2979492	et	3	main
mis	doc_553383122817_item	2979505	et	4	main
tõi	doc_553383122817_item	2979506	et	3	main
hoogu	doc_553383122817_item	2979509	et	4	main
1950ndatel	doc_553383122817_item	2979511	et	4	main
aastatel	doc_553383122817_item	2979512	et	4	main
rannamõisa	doc_553383122817_item	2979513	et	3	main
aastakümneid	doc_553383122817_item	2979520	et	4	main
invaliididekodu	doc_553383122817_item	2979524	et	4	main
on	doc_553383122817_item	2979527	et	4	main
seal	doc_553383122817_item	2979528	et	4	main
ümberehitusi	doc_553383122817_item	2979531	et	3	main
suurbritannia	doc_553383122817_item	2979533	et	4	main
suursaadiku	doc_553383122817_item	2979534	et	3	main
residents	doc_553383122817_item	2979535	et	3	main
seega	doc_553383122817_item	2979536	et	4	main
vanast	doc_553383122817_item	2979537	et	3	main
midagi	doc_553383122817_item	2979541	et	4	main
juba	doc_553383122817_item	2979568	et	3	main
1905	doc_553383122817_item	2979571	et	2	main
allus	doc_553383122817_item	2979592	et	3	main
ja	doc_553383122817_item	2979596	et	3	main
jutustaja	doc_553383122817_item	2979610	et	4	main
oli	doc_553383122817_item	2979611	et	3	main
lipsthal	doc_553383122817_item	2979624	et	4	main
t	doc_553383122817_item	2979625	et	4	main
kes	doc_553383122817_item	2979635	et	4	main
aastaid	doc_553383122817_item	2979646	et	4	main
võetud	doc_553383122817_item	2979169	et	4	main
seadusega	doc_553383122817_item	2979171	et	3	main
meyendorfide	doc_553383122817_item	2979172	et	4	main
valdusse	doc_553383122817_item	2979173	et	4	main
jäi	doc_553383122817_item	2979174	et	3	main
vaid	doc_553383122817_item	2979175	et	3	main
mõisasüda	doc_553383122817_item	2979176	et	3	main
uue	doc_553383122817_item	2979177	et	3	main
majandusliku	doc_553383122817_item	2979178	et	3	main
ka	doc_553383122817_item	2979185	et	3	main
hektari	doc_553383122817_item	2979192	et	3	main
päeva	doc_553383122817_item	2979204	et	4	main
perekond	doc_553383122817_item	2979205	et	3	main
nüüd	doc_553383122817_item	2979206	et	4	main
töötas	doc_553383122817_item	2979207	et	3	main
esiema	doc_553383122817_item	2979212	et	4	main
juurde	doc_553383122817_item	2979213	et	4	main
pidi	doc_553383122817_item	2979217	et	4	main
pärast	doc_553383122817_item	2979224	et	4	main
boheemliku	doc_553383122817_item	2979231	et	3	main
hoiakuga	doc_553383122817_item	2979232	et	3	main
individualistid	doc_553383122817_item	2979233	et	3	main
riietusid	doc_553383122817_item	2979234	et	4	main
vabameelselt	doc_553383122817_item	2979235	et	4	main
kogu	doc_553383122817_item	2979236	et	4	main
kumna	doc_553383122817_item	2979237	et	4	main
kohal	doc_553383122817_item	2979238	et	4	main
valitses	doc_553383122817_item	2979239	et	3	main
selline	doc_553383122817_item	2979240	et	4	main
kunstnikulohakus	doc_553383122817_item	2979241	et	4	main
ja	doc_553383122817_item	2979242	et	3	main
venelik	doc_553383122817_item	2979243	et	3	main
tolerants	doc_553383122817_item	2979244	et	3	main
carl	doc_553383122817_item	2979245	et	4	main
mothanderi	doc_553383122817_item	2979246	et	4	main
sõnul	doc_553383122817_item	2979247	et	3	main
vabameelsete	doc_553383122817_item	2979248	et	3	main
ja	doc_553383122817_item	2979249	et	3	main
kunstnikuloomuga	doc_553383122817_item	2979250	et	3	main
meyendoffide	doc_553383122817_item	2979251	et	4	main
hoonete	doc_553383122817_item	2979252	et	4	main
interjöör	doc_553383122817_item	2979253	et	3	main
oli	doc_553383122817_item	2979254	et	3	main
vaimustav	doc_553383122817_item	2979265	et	4	main
rokokoomööbel	doc_553383122817_item	2979266	et	3	main
segiläbi	doc_553383122817_item	2979267	et	3	main
odavamate	doc_553383122817_item	2979269	et	4	main
nimetab	doc_553383122817_item	2979273	et	3	main
täpselt	doc_553383122817_item	2979282	et	4	main
sooviti	doc_553383122817_item	2979285	et	3	main
tehtud	doc_553383122817_item	2979292	et	4	main
aga	doc_553383122817_item	2979295	et	3	main
eest	doc_553383122817_item	2979297	et	4	main
ka	doc_553383122817_item	2979298	et	3	main
ei	doc_553383122817_item	2979299	et	4	main
suviti	doc_553383122817_item	2979309	et	3	main
maalt	doc_553383122817_item	2979319	et	3	main
noorele	doc_553383122817_item	2979321	et	3	main
peale	doc_553383122817_item	2979323	et	4	main
veel	doc_553383122817_item	2979328	et	4	main
parimas	doc_553383122817_item	2979330	et	4	main
flirtimiseas	doc_553383122817_item	2979331	et	3	main
oma	doc_553383122817_item	2979332	et	4	main
soodne	doc_553383122817_item	2979338	et	3	main
külaline	doc_553383122817_item	2979340	et	4	main
abistama	doc_553383122817_item	2979348	et	3	main
ka	doc_553383122817_item	2979349	et	3	main
majapidamises	doc_553383122817_item	2979350	et	3	main
aga	doc_553383122817_item	2979351	et	3	main
mõisas	doc_553383122817_item	2979352	et	3	main
viibis	doc_553383122817_item	2979353	et	3	main
selline	doc_553383122817_item	2979354	et	4	main
atmosfäär	doc_553383122817_item	2979355	et	3	main
et	doc_553383122817_item	2979356	et	3	main
see	doc_553383122817_item	2979357	et	3	main
oli	doc_553383122817_item	2979358	et	3	main
rohkem	doc_553383122817_item	2979359	et	4	main
kui	doc_553383122817_item	2979360	et	3	main
lõbustus	doc_553383122817_item	2979361	et	4	main
ja	doc_553383122817_item	2979362	et	3	main
mitte	doc_553383122817_item	2979363	et	3	main
eriti	doc_553383122817_item	2979365	et	3	main
külalised	doc_553383122817_item	2979366	et	4	main
armastasid	doc_553383122817_item	2979367	et	4	main
töö	doc_553383122817_item	2979364	et	4	main
koos	doc_553383122817_item	2979368	et	4	main
turureisidel	doc_553383122817_item	2979372	et	3	main
käia22	doc_553383122817_item	2979374	et	2	main
nimetada	doc_553383122817_item	2979379	et	3	main
mis	doc_553383122817_item	2979386	et	4	main
valla	doc_553383122817_item	2979391	et	4	main
panuse	doc_553383122817_item	2979397	et	3	main
paiga	doc_553383122817_item	2979399	et	4	main
noored	doc_553383122817_item	2979401	et	3	main
ime	doc_553383122817_item	2979407	et	4	main
õhtuni	doc_553383122817_item	2979415	et	3	main
minnalaskmisemeeleolu	doc_553383122817_item	2979426	et	4	main
vabadus	doc_553383122817_item	2979433	et	4	main
avatud	doc_553383122817_item	2979307	et	4	main
eriti	doc_553383122817_item	2979308	et	3	main
mitmelt	doc_553383122817_item	2979318	et	4	main
pärit	doc_553383122817_item	2979320	et	3	main
inimesele	doc_553383122817_item	2979322	et	3	main
neid	doc_553383122817_item	2979324	et	4	main
külalisi	doc_553383122817_item	2979325	et	4	main
kuulus	doc_553383122817_item	2979326	et	4	main
tosin	doc_553383122817_item	2979329	et	4	main
ise	doc_553383122817_item	2979342	et	4	main
voodi	doc_553383122817_item	2979344	et	4	main
ära	doc_553383122817_item	2979345	et	4	main
tegema	doc_553383122817_item	2979346	et	3	main
ja	doc_553383122817_item	2979347	et	3	main
seega	doc_553383122817_item	2979375	et	4	main
harku	doc_553383122817_item	2979383	et	4	main
teistest	doc_553383122817_item	2979389	et	4	main
aga	doc_553383122817_item	2979393	et	3	main
selle	doc_553383122817_item	2979398	et	4	main
ajaloosse	doc_553383122817_item	2979400	et	4	main
tsivilisatsioonist	doc_553383122817_item	2979423	et	3	main
vabastav	doc_553383122817_item	2979424	et	4	main
armastusväärne	doc_553383122817_item	2979425	et	3	main
vene	doc_553383122817_item	2979429	et	4	main
valitses	doc_553383122817_item	2979432	et	3	main
kunstlikest	doc_553383122817_item	2979435	et	3	main
kütketest23	doc_553383122817_item	2979436	et	2	main
just	doc_553383122817_item	2979437	et	3	main
sellisena	doc_553383122817_item	2979438	et	4	main
oli	doc_553383122817_item	2979439	et	3	main
on	doc_553383122817_item	2979440	et	4	main
ja	doc_553383122817_item	2979441	et	3	main
jääb	doc_553383122817_item	2979442	et	3	main
kumna	doc_553383122817_item	2979443	et	4	main
ajalukku	doc_553383122817_item	2979444	et	4	main
sellise	doc_553383122817_item	2979445	et	4	main
imelise	doc_553383122817_item	2979446	et	4	main
pansionaatena	doc_553383122817_item	2979447	et	4	main
ta	doc_553383122817_item	2979448	et	4	main
oli	doc_553383122817_item	2979449	et	3	main
tuntud	doc_553383122817_item	2979450	et	4	main
oma	doc_553383122817_item	2979451	et	4	main
ajal	doc_553383122817_item	2979452	et	4	main
sellisena	doc_553383122817_item	2979453	et	4	main
mäletatakse	doc_553383122817_item	2979454	et	3	main
seda	doc_553383122817_item	2979455	et	3	main
ka	doc_553383122817_item	2979456	et	3	main
tänapäeval	doc_553383122817_item	2979457	et	3	main
5	doc_553383122817_item	2979458	et	2	main
rannamõisa	doc_553383122817_item	2979459	et	3	main
küla	doc_553383122817_item	2979460	et	4	main
rannamõisat	doc_553383122817_item	2979461	et	3	main
mainitakse	doc_553383122817_item	2979462	et	3	main
esmakordselt	doc_553383122817_item	2979463	et	4	main
1428	doc_553383122817_item	2979464	et	2	main
aastal	doc_553383122817_item	2979465	et	3	main
leppesgute24	doc_553383122817_item	2979466	et	2	main
kuni	doc_553383122817_item	2979467	et	3	main
kuulus	doc_553383122817_item	2979470	et	4	main
peale	doc_553383122817_item	2979479	et	4	main
see	doc_553383122817_item	2979480	et	3	main
oli	doc_553383122817_item	2979481	et	3	main
arvatavasti	doc_553383122817_item	2979473	et	3	main
girard	doc_553383122817_item	2979497	et	4	main
lucca	doc_553383122817_item	2979503	et	4	main
suvitusmõis	doc_553383122817_item	2979504	et	3	main
läheduses	doc_553383122817_item	2979514	et	4	main
lucca	doc_553383122817_item	2979521	et	4	main
mõisas	doc_553383122817_item	2979522	et	3	main
aastad	doc_553383122817_item	2979526	et	3	main
mõisast	doc_553383122817_item	2979538	et	4	main
on	doc_553383122817_item	2979544	et	4	main
kui	doc_553383122817_item	2979547	et	3	main
puhkepaik	doc_553383122817_item	2979550	et	3	main
suviti	doc_553383122817_item	2979553	et	3	main
rannamõisa	doc_553383122817_item	2979558	et	3	main
kirik	doc_553383122817_item	2979559	et	3	main
neogooti	doc_553383122817_item	2979560	et	4	main
stiilis	doc_553383122817_item	2979561	et	4	main
kiriku	doc_553383122817_item	2979562	et	3	main
ehitamist	doc_553383122817_item	2979563	et	4	main
alustati	doc_553383122817_item	2979564	et	4	main
1901	doc_553383122817_item	2979565	et	2	main
aastal	doc_553383122817_item	2979566	et	3	main
ning	doc_553383122817_item	2979567	et	3	main
aastal	doc_553383122817_item	2979572	et	3	main
teadmata	doc_553383122817_item	2979588	et	4	main
kandis	doc_553383122817_item	2979597	et	4	main
kabel	doc_553383122817_item	2979604	et	4	main
esimene	doc_553383122817_item	2979606	et	3	main
pärast	doc_553383122817_item	2979617	et	4	main
r	doc_553383122817_item	2979623	et	4	main
1936	doc_553383122817_item	2979628	et	2	main
lahkus	doc_553383122817_item	2979636	et	4	main
1944	doc_553383122817_item	2979638	et	2	main
aastal	doc_553383122817_item	2979639	et	3	main
kanadasse	doc_553383122817_item	2979640	et	4	main
luterlikku	doc_553383122817_item	2979648	et	4	main
juulil	doc_553383122817_item	2979655	et	3	main
ja	doc_553383122817_item	2979667	et	3	main
raidkivitööd	doc_553383122817_item	2979671	et	4	main
võiks	doc_553383122817_item	2979674	et	4	main
kultuuriloost	doc_553383122817_item	2979690	et	4	main
kuna	doc_553383122817_item	2979691	et	3	main
vabu	doc_553383122817_item	2979692	et	3	main
hauplaste	doc_553383122817_item	2979693	et	4	main
kalmistul	doc_553383122817_item	2979694	et	3	main
hetkel	doc_553383122817_item	2979698	et	4	main
kirikus	doc_553383122817_item	2979720	et	3	main
i	doc_553383122817_item	2979744	et	4	main
von	doc_553383122817_item	2979752	et	4	main
renditi	doc_553383122817_item	2979757	et	3	main
korduvalt	doc_553383122817_item	2979761	et	4	main
aastal	doc_553383122817_item	2979763	et	3	main
krusenstiern	doc_553383122817_item	2979768	et	4	main
pärast	doc_553383122817_item	2979770	et	4	main
ehitas	doc_553383122817_item	2979771	et	3	main
sellest	doc_553383122817_item	2979772	et	4	main
neorenessanss-	doc_553383122817_item	2979779	et	3	main
eestis	doc_553383122817_item	2979782	et	3	main
pärast	doc_553383122817_item	2979791	et	4	main
mõisate	doc_553383122817_item	2979792	et	3	main
võõrandamist	doc_553383122817_item	2979793	et	4	main
muraste	doc_553383122817_item	2979797	et	4	main
jäänud	doc_553383122817_item	2979811	et	4	main
lapsed	doc_553383122817_item	2979812	et	3	main
lastekodu	doc_553383122817_item	2979815	et	4	main
krustenid	doc_553383122817_item	2979857	et	4	main
nad	doc_553383122817_item	2979858	et	3	main
sündisid	doc_553383122817_item	2979859	et	4	main
aedniku	doc_553383122817_item	2979860	et	3	main
jaan	doc_553383122817_item	2979861	et	3	main
tuntuks	doc_553383122817_item	2979490	et	4	main
de	doc_553383122817_item	2979498	et	4	main
srajas	doc_553383122817_item	2979499	et	4	main
tiskresse	doc_553383122817_item	2979500	et	4	main
panga	doc_553383122817_item	2979501	et	3	main
jalamile	doc_553383122817_item	2979502	et	4	main
itaalia	doc_553383122817_item	2979508	et	4	main
ehitamise	doc_553383122817_item	2979518	et	4	main
asus	doc_553383122817_item	2979523	et	4	main
viimased	doc_553383122817_item	2979525	et	3	main
olulisi	doc_553383122817_item	2979530	et	4	main
pole	doc_553383122817_item	2979539	et	3	main
rannamõisa	doc_553383122817_item	2979543	et	3	main
eestimaa	doc_553383122817_item	2979573	et	4	main
daniel	doc_553383122817_item	2979575	et	4	main
lemm	doc_553383122817_item	2979577	et	3	main
rannamõisa	doc_553383122817_item	2979580	et	3	main
ja	doc_553383122817_item	2979583	et	3	main
autor	doc_553383122817_item	2979586	et	3	main
on	doc_553383122817_item	2979587	et	4	main
aastani	doc_553383122817_item	2979591	et	3	main
ranna	doc_553383122817_item	2979598	et	3	main
kabeli	doc_553383122817_item	2979599	et	3	main
nime	doc_553383122817_item	2979600	et	4	main
septembri	doc_553383122817_item	2979601	et	3	main
iseseisvakskoguduseks	doc_553383122817_item	2979605	et	4	main
kiriku	doc_553383122817_item	2979607	et	3	main
ja	doc_553383122817_item	2979609	et	3	main
karl	doc_553383122817_item	2979612	et	4	main
dunkel	doc_553383122817_item	2979613	et	4	main
kuni	doc_553383122817_item	2979614	et	3	main
1930	doc_553383122817_item	2979615	et	2	main
aastani	doc_553383122817_item	2979616	et	3	main
volmer	doc_553383122817_item	2979622	et	4	main
oja	doc_553383122817_item	2979626	et	4	main
ning	doc_553383122817_item	2979627	et	3	main
aasta	doc_553383122817_item	2979629	et	4	main
maikuust	doc_553383122817_item	2979630	et	4	main
eestist	doc_553383122817_item	2979637	et	3	main
kanada	doc_553383122817_item	2979647	et	4	main
21	doc_553383122817_item	2979654	et	2	main
seal	doc_553383122817_item	2979658	et	4	main
juulil	doc_553383122817_item	2979570	et	3	main
pühitses	doc_553383122817_item	2979578	et	3	main
arhitekt	doc_553383122817_item	2979582	et	3	main
kogu	doc_553383122817_item	2979589	et	4	main
kirik	doc_553383122817_item	2979593	et	3	main
keila	doc_553383122817_item	2979594	et	4	main
kogudusele	doc_553383122817_item	2979595	et	3	main
sai	doc_553383122817_item	2979603	et	4	main
ametis	doc_553383122817_item	2979619	et	3	main
töötasid	doc_553383122817_item	2979620	et	4	main
mathias	doc_553383122817_item	2979621	et	4	main
oskar	doc_553383122817_item	2979633	et	4	main
puhm	doc_553383122817_item	2979634	et	3	main
hiljem	doc_553383122817_item	2979643	et	3	main
töötas	doc_553383122817_item	2979644	et	3	main
pikki	doc_553383122817_item	2979645	et	4	main
1902	doc_553383122817_item	2979656	et	2	main
leidub	doc_553383122817_item	2979659	et	3	main
kunsti-	doc_553383122817_item	2979661	et	4	main
sepa-	doc_553383122817_item	2979669	et	3	main
isegi	doc_553383122817_item	2979673	et	4	main
uuesti	doc_553383122817_item	2979675	et	3	main
on	doc_553383122817_item	2979697	et	4	main
probleem	doc_553383122817_item	2979701	et	3	main
ranna	doc_553383122817_item	2979705	et	3	main
ja	doc_553383122817_item	2979718	et	3	main
ka	doc_553383122817_item	2979722	et	3	main
poolel	doc_553383122817_item	2979745	et	4	main
alates	doc_553383122817_item	2979746	et	3	main
1653	doc_553383122817_item	2979747	et	2	main
aastast	doc_553383122817_item	2979748	et	4	main
sajandite	doc_553383122817_item	2979754	et	3	main
ja	doc_553383122817_item	2979758	et	3	main
kirikuõpetajaks	doc_553383122817_item	2979631	et	3	main
sai	doc_553383122817_item	2979632	et	4	main
kus	doc_553383122817_item	2979641	et	3	main
ta	doc_553383122817_item	2979642	et	4	main
ajakirja	doc_553383122817_item	2979649	et	4	main
elu26	doc_553383122817_item	2979650	et	2	main
rannamõisa	doc_553383122817_item	2979651	et	3	main
kalmistu	doc_553383122817_item	2979652	et	4	main
aastal	doc_553383122817_item	2979657	et	3	main
vanu	doc_553383122817_item	2979665	et	4	main
irdriste	doc_553383122817_item	2979666	et	4	main
hauatähiseid	doc_553383122817_item	2979668	et	4	main
sellele	doc_553383122817_item	2979681	et	4	main
piirkonnale	doc_553383122817_item	2979682	et	4	main
väga	doc_553383122817_item	2979683	et	3	main
omased	doc_553383122817_item	2979684	et	3	main
ja	doc_553383122817_item	2979685	et	3	main
iseloomulikud	doc_553383122817_item	2979686	et	3	main
ning	doc_553383122817_item	2979687	et	3	main
räägivad	doc_553383122817_item	2979688	et	3	main
kohalikust	doc_553383122817_item	2979689	et	4	main
kõige	doc_553383122817_item	2979699	et	4	main
peale	doc_553383122817_item	2979724	et	4	main
muraste	doc_553383122817_item	2979736	et	4	main
ja	doc_553383122817_item	2979738	et	3	main
17	doc_553383122817_item	2979742	et	2	main
saj	doc_553383122817_item	2979743	et	4	main
see	doc_553383122817_item	2979750	et	3	main
henning	doc_553383122817_item	2979751	et	4	main
jooksul	doc_553383122817_item	2979755	et	4	main
panditi	doc_553383122817_item	2979759	et	4	main
1848	doc_553383122817_item	2979762	et	2	main
von	doc_553383122817_item	2979767	et	4	main
suurejoonelise	doc_553383122817_item	2979773	et	4	main
härrarahvas	doc_553383122817_item	2979788	et	4	main
1920	doc_553383122817_item	2979795	et	2	main
teist	doc_553383122817_item	2979804	et	4	main
maailmasõda	doc_553383122817_item	2979805	et	4	main
1995	doc_553383122817_item	2979813	et	2	main
1997	doc_553383122817_item	2979818	et	2	main
krusteni	doc_553383122817_item	2979862	et	4	main
otto	doc_553383122817_item	2979866	et	4	main
tuntud	doc_553383122817_item	2979883	et	4	main
kirjanikud	doc_553383122817_item	2979884	et	3	main
krusteni	doc_553383122817_item	2979888	et	4	main
oli	doc_553383122817_item	2979890	et	3	main
elasid	doc_553383122817_item	2979903	et	4	main
päris	doc_553383122817_item	2979904	et	4	main
vaeselt	doc_553383122817_item	2979905	et	4	main
nii	doc_553383122817_item	2979914	et	3	main
erni	doc_553383122817_item	2979915	et	4	main
pedro	doc_553383122817_item	2979922	et	4	main
triloogias	doc_553383122817_item	2979927	et	3	main
selle	doc_553383122817_item	2979929	et	4	main
a	doc_553383122817_item	2979946	et	4	main
õppis	doc_553383122817_item	2979947	et	3	main
ja	doc_553383122817_item	2979971	et	3	main
joonekäsitluse	doc_553383122817_item	2979973	et	3	main
tabavalt	doc_553383122817_item	2979975	et	4	main
iseloomustavaid	doc_553383122817_item	2979976	et	4	main
humoristlikke	doc_553383122817_item	2979977	et	3	main
śarźe	doc_553383122817_item	2979978	et	2	main
ning	doc_553383122817_item	2979983	et	3	main
teda	doc_553383122817_item	2979986	et	4	main
parimaks	doc_553383122817_item	2979988	et	4	main
eestis	doc_553383122817_item	2979989	et	3	main
on	doc_553383122817_item	2979990	et	4	main
23	doc_553383122817_item	2979995	et	2	main
a	doc_553383122817_item	2979998	et	4	main
mis	doc_553383122817_item	2980021	et	4	main
kuulub	doc_553383122817_item	2980022	et	3	main
hulka	doc_553383122817_item	2980027	et	4	main
selle	doc_553383122817_item	2980062	et	4	main
lõpetamist	doc_553383122817_item	2980063	et	4	main
kodusõjas	doc_553383122817_item	2980068	et	3	main
ajakirjanikuna	doc_553383122817_item	2980075	et	3	main
sõna	doc_553383122817_item	2980081	et	4	main
saksamaale	doc_553383122817_item	2980090	et	4	main
ametlikult	doc_553383122817_item	2980097	et	4	main
seal	doc_553383122817_item	2980104	et	4	main
pedro	doc_553383122817_item	2980112	et	4	main
õnnistati	doc_553383122817_item	2979653	et	4	main
selliseid	doc_553383122817_item	2979660	et	4	main
ja	doc_553383122817_item	2979662	et	3	main
kultuurivara	doc_553383122817_item	2979663	et	4	main
nagu	doc_553383122817_item	2979664	et	3	main
ja	doc_553383122817_item	2979670	et	3	main
enam	doc_553383122817_item	2979695	et	4	main
pole	doc_553383122817_item	2979696	et	3	main
laiendamine	doc_553383122817_item	2979703	et	4	main
kogudusse	doc_553383122817_item	2979706	et	3	main
korraldakse	doc_553383122817_item	2979728	et	4	main
kontserte	doc_553383122817_item	2979729	et	3	main
näiteks	doc_553383122817_item	2979730	et	4	main
6	doc_553383122817_item	2979731	et	2	main
muraste	doc_553383122817_item	2979732	et	4	main
muraste	doc_553383122817_item	2979733	et	4	main
kurba	doc_553383122817_item	2979737	et	4	main
grassile	doc_553383122817_item	2979753	et	4	main
mõisa	doc_553383122817_item	2979760	et	3	main
ostis	doc_553383122817_item	2979764	et	4	main
selle	doc_553383122817_item	2979765	et	4	main
mõisahäärberi	doc_553383122817_item	2979774	et	3	main
stiilis	doc_553383122817_item	2979780	et	4	main
mõisahooneks	doc_553383122817_item	2979781	et	4	main
lossiliku	doc_553383122817_item	2979784	et	4	main
ilmega	doc_553383122817_item	2979785	et	3	main
mõisahoonet	doc_553383122817_item	2979786	et	4	main
kasutas	doc_553383122817_item	2979787	et	3	main
sai	doc_553383122817_item	2979794	et	4	main
punaste	doc_553383122817_item	2979799	et	4	main
suurupi	doc_553383122817_item	2979801	et	4	main
siin	doc_553383122817_item	2979807	et	4	main
sõja	doc_553383122817_item	2979808	et	3	main
tõttu	doc_553383122817_item	2979809	et	4	main
orbudeks	doc_553383122817_item	2979810	et	3	main
likvideeriti	doc_553383122817_item	2979816	et	3	main
aastal	doc_553383122817_item	2979819	et	3	main
isikud	doc_553383122817_item	2979853	et	3	main
on	doc_553383122817_item	2979855	et	4	main
1988-1937	doc_553383122817_item	2979868	et	2	main
pedro	doc_553383122817_item	2979877	et	4	main
jaan	doc_553383122817_item	2979887	et	3	main
ülesandeks	doc_553383122817_item	2979889	et	4	main
pargi	doc_553383122817_item	2979892	et	4	main
ja	doc_553383122817_item	2979893	et	3	main
lillepeenarde	doc_553383122817_item	2979894	et	3	main
korrashoidmine	doc_553383122817_item	2979895	et	3	main
ja	doc_553383122817_item	2979896	et	3	main
triiphoone	doc_553383122817_item	2979897	et	4	main
kuus	doc_553383122817_item	2979901	et	4	main
last	doc_553383122817_item	2979902	et	4	main
mõisas	doc_553383122817_item	2979908	et	3	main
piltid	doc_553383122817_item	2979911	et	4	main
ka	doc_553383122817_item	2979917	et	3	main
krusteni	doc_553383122817_item	2979919	et	4	main
teostes	doc_553383122817_item	2979920	et	3	main
näiteks	doc_553383122817_item	2979921	et	4	main
mõisaolustikku	doc_553383122817_item	2979925	et	4	main
61	doc_553383122817_item	2979935	et	2	main
otto	doc_553383122817_item	2979938	et	4	main
krusten	doc_553383122817_item	2979939	et	4	main
ehk	doc_553383122817_item	2979940	et	3	main
raudnõges	doc_553383122817_item	2979941	et	3	main
sündis	doc_553383122817_item	2979942	et	3	main
18	doc_553383122817_item	2979943	et	2	main
juunil	doc_553383122817_item	2979944	et	3	main
1888	doc_553383122817_item	2979945	et	2	main
stiilse	doc_553383122817_item	2979970	et	3	main
lakoonilise	doc_553383122817_item	2979972	et	3	main
tegi	doc_553383122817_item	2979974	et	4	main
ja	doc_553383122817_item	2979981	et	3	main
loonud	doc_553383122817_item	2979991	et	4	main
maale	doc_553383122817_item	2979993	et	4	main
kuulsamaid	doc_553383122817_item	2980008	et	4	main
töö	doc_553383122817_item	2980011	et	4	main
nimega	doc_553383122817_item	2980012	et	3	main
olge	doc_553383122817_item	2980013	et	3	main
rõõmsad	doc_553383122817_item	2980014	et	3	main
minu	doc_553383122817_item	2980015	et	3	main
vaesed	doc_553383122817_item	2980016	et	4	main
seedin	doc_553383122817_item	2980018	et	3	main
mida	doc_553383122817_item	2979672	et	4	main
kasutusele	doc_553383122817_item	2979676	et	4	main
võtta	doc_553383122817_item	2979677	et	3	main
kuna	doc_553383122817_item	2979678	et	3	main
nad	doc_553383122817_item	2979679	et	3	main
on	doc_553383122817_item	2979680	et	4	main
suurem	doc_553383122817_item	2979700	et	4	main
kalmistu	doc_553383122817_item	2979702	et	4	main
praegu	doc_553383122817_item	2979704	et	3	main
kuulub	doc_553383122817_item	2979707	et	3	main
umbes	doc_553383122817_item	2979708	et	4	main
150	doc_553383122817_item	2979709	et	2	main
inimest	doc_553383122817_item	2979710	et	3	main
pühapäeviti	doc_553383122817_item	2979711	et	4	main
toimuvad	doc_553383122817_item	2979712	et	4	main
jumalateenistused	doc_553383122817_item	2979713	et	3	main
komapäeva	doc_553383122817_item	2979714	et	4	main
õhtuti	doc_553383122817_item	2979715	et	3	main
on	doc_553383122817_item	2979716	et	4	main
piibli-	doc_553383122817_item	2979717	et	3	main
palvetunnid	doc_553383122817_item	2979719	et	3	main
tegutseb	doc_553383122817_item	2979721	et	3	main
pühapäevakool	doc_553383122817_item	2979723	et	4	main
neid	doc_553383122817_item	2979725	et	4	main
üüritus	doc_553383122817_item	2979726	et	4	main
kirikus	doc_553383122817_item	2979727	et	3	main
mõis27	doc_553383122817_item	2979734	et	2	main
moodustus	doc_553383122817_item	2979735	et	4	main
merekülast	doc_553383122817_item	2979739	et	4	main
seda	doc_553383122817_item	2979740	et	3	main
rajati	doc_553383122817_item	2979741	et	3	main
kuulus	doc_553383122817_item	2979749	et	4	main
müüdi	doc_553383122817_item	2979756	et	4	main
otto	doc_553383122817_item	2979766	et	4	main
mida	doc_553383122817_item	2979775	et	4	main
peetakse	doc_553383122817_item	2979776	et	3	main
üheks	doc_553383122817_item	2979777	et	3	main
põhiliselt	doc_553383122817_item	2979789	et	4	main
suvel	doc_553383122817_item	2979790	et	3	main
aastal	doc_553383122817_item	2979796	et	3	main
risti	doc_553383122817_item	2979800	et	4	main
lastekodu	doc_553383122817_item	2979802	et	4	main
pärast	doc_553383122817_item	2979803	et	4	main
aastal	doc_553383122817_item	2979814	et	3	main
valdaja	doc_553383122817_item	2979821	et	4	main
kultuurimaailmas	doc_553383122817_item	2979851	et	3	main
perekonnas	doc_553383122817_item	2979863	et	4	main
kõige	doc_553383122817_item	2979864	et	4	main
krusten	doc_553383122817_item	2979867	et	4	main
erni	doc_553383122817_item	2979874	et	4	main
1900-1984	doc_553383122817_item	2979875	et	2	main
ja	doc_553383122817_item	2979876	et	3	main
1897-1987	doc_553383122817_item	2979878	et	2	main
olid	doc_553383122817_item	2979879	et	4	main
nende	doc_553383122817_item	2979885	et	4	main
hooldamine	doc_553383122817_item	2979898	et	4	main
ning	doc_553383122817_item	2979909	et	3	main
peegelduvad	doc_553383122817_item	2979913	et	4	main
krusten	doc_553383122817_item	2979923	et	4	main
metsa	doc_553383122817_item	2979934	et	4	main
kujundas	doc_553383122817_item	2979968	et	3	main
ühiskonnategelastes	doc_553383122817_item	2979982	et	3	main
karikaturis	doc_553383122817_item	2980000	et	4	main
tuntuks	doc_553383122817_item	2980002	et	4	main
karikatuure	doc_553383122817_item	2980009	et	4	main
on	doc_553383122817_item	2980010	et	4	main
võttis	doc_553383122817_item	2980064	et	3	main
punaarmees	doc_553383122817_item	2980065	et	3	main
osa	doc_553383122817_item	2980066	et	4	main
alates	doc_553383122817_item	2980072	et	3	main
tallinnas	doc_553383122817_item	2980074	et	4	main
ajakirjades	doc_553383122817_item	2980076	et	3	main
sündmuste	doc_553383122817_item	2980084	et	3	main
pärast	doc_553383122817_item	2980091	et	4	main
tema	doc_553383122817_item	2980098	et	4	main
põgeniku	doc_553383122817_item	2980099	et	3	main
staatus	doc_553383122817_item	2980100	et	3	main
washington	doc_553383122817_item	2980105	et	4	main
ning	doc_553383122817_item	2980106	et	3	main
tööpaigaks	doc_553383122817_item	2980107	et	3	main
ameerika	doc_553383122817_item	2980108	et	3	main
lühiproosat	doc_553383122817_item	2980120	et	3	main
teostes	doc_553383122817_item	2980130	et	3	main
ja	doc_553383122817_item	2980138	et	3	main
tihe	doc_553383122817_item	2980140	et	3	main
sügavalt	doc_553383122817_item	2980142	et	4	main
krusten	doc_553383122817_item	2980170	et	4	main
kui	doc_553383122817_item	2980175	et	3	main
siis	doc_553383122817_item	2980178	et	3	main
pedro	doc_553383122817_item	2980193	et	4	main
rahvas	doc_553383122817_item	2980203	et	4	main
loolaadi	doc_553383122817_item	2980210	et	4	main
võib	doc_553383122817_item	2980211	et	3	main
niivõrd	doc_553383122817_item	2980218	et	3	main
mis	doc_553383122817_item	2980243	et	4	main
on	doc_553383122817_item	2980249	et	4	main
päris	doc_553383122817_item	2980253	et	4	main
inimese	doc_553383122817_item	2980266	et	4	main
moraalne	doc_553383122817_item	2980267	et	3	main
kes	doc_553383122817_item	2979769	et	4	main
varasemaks	doc_553383122817_item	2979778	et	4	main
aga	doc_553383122817_item	2979783	et	3	main
mõisahoonest	doc_553383122817_item	2979798	et	4	main
elasid	doc_553383122817_item	2979806	et	4	main
ja	doc_553383122817_item	2979817	et	3	main
härrastemaja	doc_553383122817_item	2979820	et	4	main
eesti	doc_553383122817_item	2979822	et	4	main
punane	doc_553383122817_item	2979823	et	4	main
rist	doc_553383122817_item	2979824	et	3	main
müüs	doc_553383122817_item	2979825	et	4	main
hoone	doc_553383122817_item	2979826	et	4	main
paldiski	doc_553383122817_item	2979827	et	4	main
ekslinnapeale	doc_553383122817_item	2979828	et	3	main
jaan	doc_553383122817_item	2979829	et	3	main
mölderile	doc_553383122817_item	2979830	et	3	main
2001	doc_553383122817_item	2979831	et	2	main
aastal	doc_553383122817_item	2979832	et	3	main
veebruaris	doc_553383122817_item	2979833	et	3	main
panid	doc_553383122817_item	2979834	et	4	main
kaks	doc_553383122817_item	2979835	et	3	main
kohalikku	doc_553383122817_item	2979836	et	4	main
13-	doc_553383122817_item	2979837	et	4	main
aastast	doc_553383122817_item	2979838	et	4	main
poissi	doc_553383122817_item	2979839	et	4	main
mõisamaja	doc_553383122817_item	2979840	et	4	main
põlema	doc_553383122817_item	2979841	et	4	main
alles	doc_553383122817_item	2979842	et	3	main
jäi	doc_553383122817_item	2979843	et	3	main
vahelagedeta	doc_553383122817_item	2979844	et	3	main
vare28	doc_553383122817_item	2979845	et	2	main
muraste	doc_553383122817_item	2979846	et	4	main
mõisas	doc_553383122817_item	2979847	et	3	main
üles	doc_553383122817_item	2979848	et	3	main
kasvasid	doc_553383122817_item	2979849	et	4	main
kolm	doc_553383122817_item	2979850	et	3	main
tuntud	doc_553383122817_item	2979852	et	4	main
nad	doc_553383122817_item	2979854	et	3	main
vennad	doc_553383122817_item	2979856	et	3	main
vanem	doc_553383122817_item	2979865	et	4	main
sai	doc_553383122817_item	2979869	et	4	main
ning	doc_553383122817_item	2979872	et	3	main
nooremad	doc_553383122817_item	2979873	et	4	main
päris	doc_553383122817_item	2979882	et	4	main
isa	doc_553383122817_item	2979886	et	4	main
mõisa	doc_553383122817_item	2979891	et	3	main
perekonnas	doc_553383122817_item	2979899	et	4	main
oli	doc_553383122817_item	2979900	et	3	main
elu	doc_553383122817_item	2979906	et	4	main
lapsepõlve	doc_553383122817_item	2979910	et	4	main
tihti	doc_553383122817_item	2979912	et	3	main
autobiograafilises	doc_553383122817_item	2979926	et	4	main
esimeses	doc_553383122817_item	2979930	et	3	main
osas	doc_553383122817_item	2979931	et	4	main
torn	doc_553383122817_item	2979932	et	3	main
üle	doc_553383122817_item	2979933	et	3	main
laikmaa	doc_553383122817_item	2979948	et	4	main
kuulsaks	doc_553383122817_item	2979870	et	4	main
karikaturistiks	doc_553383122817_item	2979871	et	4	main
omal	doc_553383122817_item	2979880	et	3	main
ajal	doc_553383122817_item	2979881	et	4	main
muraste	doc_553383122817_item	2979907	et	4	main
kui	doc_553383122817_item	2979916	et	3	main
pedro	doc_553383122817_item	2979918	et	4	main
kirjeldab	doc_553383122817_item	2979924	et	3	main
peamiselt	doc_553383122817_item	2979928	et	4	main
otto	doc_553383122817_item	2979936	et	4	main
krusten	doc_553383122817_item	2979937	et	4	main
ateljeekoolis	doc_553383122817_item	2979949	et	4	main
ja	doc_553383122817_item	2979950	et	3	main
pärast	doc_553383122817_item	2979951	et	4	main
peterburis	doc_553383122817_item	2979952	et	4	main
kunstide	doc_553383122817_item	2979953	et	3	main
edendamise	doc_553383122817_item	2979954	et	4	main
seltsi	doc_553383122817_item	2979955	et	4	main
kunstikoolis	doc_553383122817_item	2979956	et	4	main
joonistas	doc_553383122817_item	2979957	et	3	main
karikatuure	doc_553383122817_item	2979958	et	4	main
ajalehtedele	doc_553383122817_item	2979959	et	4	main
satiirkirjadele	doc_553383122817_item	2979960	et	4	main
ja	doc_553383122817_item	2979961	et	3	main
albumile	doc_553383122817_item	2979962	et	3	main
ösituled	doc_553383122817_item	2979963	et	4	main
lähtus	doc_553383122817_item	2979964	et	3	main
o	doc_553383122817_item	2979965	et	4	main
gulbranssoni	doc_553383122817_item	2979966	et	4	main
eeskujust	doc_553383122817_item	2979967	et	3	main
eesti	doc_553383122817_item	2979979	et	4	main
sellel	doc_553383122817_item	2979984	et	4	main
alal	doc_553383122817_item	2979985	et	4	main
peetakse	doc_553383122817_item	2979987	et	3	main
veebruaril	doc_553383122817_item	2979996	et	3	main
sai	doc_553383122817_item	2980001	et	4	main
oma	doc_553383122817_item	2980004	et	4	main
ühiskonnakriitilise	doc_553383122817_item	2980005	et	3	main
loominguga	doc_553383122817_item	2980006	et	3	main
üks	doc_553383122817_item	2980007	et	3	main
täna	doc_553383122817_item	2980017	et	4	main
pärast	doc_553383122817_item	2980061	et	4	main
keskpaigast	doc_553383122817_item	2980071	et	4	main
eesti	doc_553383122817_item	2980080	et	4	main
1950a	doc_553383122817_item	2980095	et	4	main
lõppes	doc_553383122817_item	2980096	et	4	main
sai	doc_553383122817_item	2980103	et	4	main
toimetus	doc_553383122817_item	2980111	et	4	main
ajakirjade	doc_553383122817_item	2980121	et	3	main
aga	doc_553383122817_item	2980123	et	3	main
hakkab	doc_553383122817_item	2980131	et	3	main
tugev	doc_553383122817_item	2980133	et	4	main
kirjaniku	doc_553383122817_item	2980139	et	3	main
enesesäilitamine	doc_553383122817_item	2980168	et	3	main
washingtonis	doc_553383122817_item	2980177	et	4	main
teda	doc_553383122817_item	2980186	et	4	main
lugejad	doc_553383122817_item	2980189	et	4	main
teda	doc_553383122817_item	2980190	et	4	main
tähele	doc_553383122817_item	2980191	et	3	main
olnud	doc_553383122817_item	2980197	et	4	main
inimene	doc_553383122817_item	2980198	et	3	main
nähtused	doc_553383122817_item	2980206	et	4	main
isikupärase	doc_553383122817_item	2979969	et	4	main
kultuuri-	doc_553383122817_item	2979980	et	4	main
ka	doc_553383122817_item	2979992	et	3	main
suri	doc_553383122817_item	2979994	et	3	main
1937	doc_553383122817_item	2979997	et	2	main
tallinnas29	doc_553383122817_item	2979999	et	2	main
eeskätt	doc_553383122817_item	2980003	et	3	main
otto	doc_553383122817_item	2980023	et	4	main
krusteni	doc_553383122817_item	2980024	et	4	main
pilti	doc_553383122817_item	2980028	et	4	main
ajendasid	doc_553383122817_item	2980029	et	4	main
looma	doc_553383122817_item	2980030	et	4	main
kahekümnendate	doc_553383122817_item	2980031	et	4	main
aastate	doc_553383122817_item	2980032	et	3	main
algul	doc_553383122817_item	2980033	et	4	main
moodi	doc_553383122817_item	2980034	et	4	main
läinud	doc_553383122817_item	2980035	et	4	main
ballid	doc_553383122817_item	2980036	et	3	main
tuluüritused	doc_553383122817_item	2980037	et	3	main
mida	doc_553383122817_item	2980038	et	4	main
korraldati	doc_553383122817_item	2980039	et	3	main
heaks	doc_553383122817_item	2980041	et	4	main
vaeste	doc_553383122817_item	2980040	et	4	main
62	doc_553383122817_item	2980042	et	2	main
pedro	doc_553383122817_item	2980043	et	4	main
krusten	doc_553383122817_item	2980044	et	4	main
kirjanik	doc_553383122817_item	2980045	et	3	main
pedro	doc_553383122817_item	2980046	et	4	main
krusten	doc_553383122817_item	2980047	et	4	main
sündis	doc_553383122817_item	2980048	et	3	main
ja	doc_553383122817_item	2980049	et	3	main
üles	doc_553383122817_item	2980050	et	3	main
kasvas	doc_553383122817_item	2980051	et	3	main
põhjarannikul	doc_553383122817_item	2980052	et	3	main
murastes	doc_553383122817_item	2980053	et	4	main
mõisa	doc_553383122817_item	2980054	et	3	main
aedniku	doc_553383122817_item	2980055	et	3	main
pojana	doc_553383122817_item	2980056	et	4	main
ta	doc_553383122817_item	2980057	et	4	main
õpis	doc_553383122817_item	2980058	et	3	main
tallinna	doc_553383122817_item	2980059	et	4	main
ma	doc_553383122817_item	2980019	et	3	main
teile	doc_553383122817_item	2980020	et	4	main
sarkastilisemate	doc_553383122817_item	2980025	et	4	main
tööde	doc_553383122817_item	2980026	et	3	main
progümnaasiumis	doc_553383122817_item	2980060	et	4	main
venemaa	doc_553383122817_item	2980067	et	4	main
aastate	doc_553383122817_item	2980070	et	3	main
hääl	doc_553383122817_item	2980109	et	3	main
on	doc_553383122817_item	2980114	et	4	main
kes	doc_553383122817_item	2980117	et	4	main
enamasti	doc_553383122817_item	2980118	et	4	main
kirjutas	doc_553383122817_item	2980119	et	3	main
leidub	doc_553383122817_item	2980124	et	3	main
loomingus	doc_553383122817_item	2980126	et	3	main
kelle	doc_553383122817_item	2980129	et	4	main
salgamata	doc_553383122817_item	2980135	et	4	main
isikupära	doc_553383122817_item	2980136	et	4	main
kirjutaja	doc_553383122817_item	2980143	et	4	main
loomusest	doc_553383122817_item	2980144	et	4	main
lähtuv	doc_553383122817_item	2980145	et	4	main
humanism	doc_553383122817_item	2980146	et	3	main
ja	doc_553383122817_item	2980147	et	3	main
tolerants	doc_553383122817_item	2980148	et	3	main
teda	doc_553383122817_item	2980149	et	4	main
ei	doc_553383122817_item	2980150	et	4	main
huvita	doc_553383122817_item	2980151	et	4	main
eriti	doc_553383122817_item	2980152	et	3	main
ajalugu	doc_553383122817_item	2980153	et	4	main
see	doc_553383122817_item	2980154	et	3	main
on	doc_553383122817_item	2980155	et	4	main
ainult	doc_553383122817_item	2980156	et	4	main
foon	doc_553383122817_item	2980157	et	3	main
esiplaanis	doc_553383122817_item	2980158	et	3	main
aga	doc_553383122817_item	2980159	et	3	main
seisab	doc_553383122817_item	2980160	et	3	main
inimene	doc_553383122817_item	2980161	et	3	main
ning	doc_553383122817_item	2980162	et	3	main
selle	doc_553383122817_item	2980163	et	4	main
isiku	doc_553383122817_item	2980164	et	3	main
moraalne	doc_553383122817_item	2980165	et	3	main
toimetulek	doc_553383122817_item	2980166	et	3	main
ja	doc_553383122817_item	2980167	et	3	main
1920	doc_553383122817_item	2980069	et	2	main
töötas	doc_553383122817_item	2980073	et	3	main
vaba	doc_553383122817_item	2980077	et	4	main
maa	doc_553383122817_item	2980078	et	4	main
päevaleht	doc_553383122817_item	2980079	et	3	main
kuid	doc_553383122817_item	2980082	et	4	main
poliitiliste	doc_553383122817_item	2980083	et	3	main
tõttu	doc_553383122817_item	2980085	et	4	main
lahkus	doc_553383122817_item	2980086	et	4	main
kodumaalt	doc_553383122817_item	2980087	et	3	main
1944	doc_553383122817_item	2980088	et	2	main
aastal	doc_553383122817_item	2980089	et	3	main
asus	doc_553383122817_item	2980092	et	4	main
usa-sse	doc_553383122817_item	2980093	et	3	main
kus	doc_553383122817_item	2980094	et	3	main
püsivaks	doc_553383122817_item	2980101	et	4	main
elukohaks	doc_553383122817_item	2980102	et	4	main
raadiojaama	doc_553383122817_item	2980110	et	4	main
ajakirjanik	doc_553383122817_item	2980116	et	3	main
tema	doc_553383122817_item	2980125	et	4	main
ka	doc_553383122817_item	2980127	et	3	main
inimese	doc_553383122817_item	2980137	et	4	main
seotus	doc_553383122817_item	2980141	et	4	main
kodumaal	doc_553383122817_item	2980172	et	4	main
ajakirjanik	doc_553383122817_item	2980174	et	3	main
tema	doc_553383122817_item	2980179	et	4	main
olid	doc_553383122817_item	2980181	et	4	main
maailmas	doc_553383122817_item	2980182	et	3	main
laiali	doc_553383122817_item	2980183	et	3	main
kriitika	doc_553383122817_item	2980184	et	4	main
oli	doc_553383122817_item	2980185	et	3	main
pannud	doc_553383122817_item	2980192	et	4	main
kui	doc_553383122817_item	2980199	et	3	main
niisugune	doc_553383122817_item	2980200	et	3	main
kodumaa	doc_553383122817_item	2980201	et	4	main
ja	doc_553383122817_item	2980202	et	3	main
meie	doc_553383122817_item	2980207	et	4	main
inimeses	doc_553383122817_item	2980208	et	3	main
varema	doc_553383122817_item	2980209	et	3	main
mille	doc_553383122817_item	2980214	et	3	main
ei	doc_553383122817_item	2980216	et	4	main
kusagile	doc_553383122817_item	2980219	et	3	main
maailma	doc_553383122817_item	2980221	et	4	main
väid	doc_553383122817_item	2980222	et	4	main
sinna	doc_553383122817_item	2980223	et	3	main
kus	doc_553383122817_item	2980224	et	3	main
eriti	doc_553383122817_item	2980225	et	3	main
kerkivad	doc_553383122817_item	2980226	et	4	main
üles	doc_553383122817_item	2980227	et	3	main
ja	doc_553383122817_item	2980235	et	3	main
oma	doc_553383122817_item	2980238	et	4	main
ta	doc_553383122817_item	2980240	et	4	main
püüab	doc_553383122817_item	2980241	et	3	main
vastata	doc_553383122817_item	2980242	et	4	main
ja	doc_553383122817_item	2980247	et	3	main
mis	doc_553383122817_item	2980248	et	4	main
mida	doc_553383122817_item	2980256	et	4	main
nimetada	doc_553383122817_item	2980260	et	3	main
kui	doc_553383122817_item	2980269	et	3	main
sellesse	doc_553383122817_item	2980278	et	4	main
õilis	doc_553383122817_item	2980282	et	3	main
hädaohtlik	doc_553383122817_item	2980298	et	3	main
pedro	doc_553383122817_item	2980302	et	4	main
ei	doc_553383122817_item	2980304	et	4	main
ole	doc_553383122817_item	2980305	et	4	main
nii	doc_553383122817_item	2980306	et	3	main
kuuluvad	doc_553383122817_item	2980321	et	4	main
kaldametsa-	doc_553383122817_item	2980322	et	4	main
aedniku	doc_553383122817_item	2980328	et	3	main
romaanid	doc_553383122817_item	2980330	et	3	main
kordustrükina	doc_553383122817_item	2980332	et	3	main
1990	doc_553383122817_item	2980334	et	2	main
a	doc_553383122817_item	2980335	et	4	main
kes	doc_553383122817_item	2980342	et	4	main
kordustrükkide	doc_553383122817_item	2980346	et	3	main
järelsõnade	doc_553383122817_item	2980347	et	3	main
oma	doc_553383122817_item	2980349	et	4	main
artiklis	doc_553383122817_item	2980350	et	3	main
ta	doc_553383122817_item	2980351	et	4	main
kirjanikud	doc_553383122817_item	2980370	et	3	main
kaldametsa-	doc_553383122817_item	2980371	et	4	main
triloogias	doc_553383122817_item	2980372	et	3	main
krusten	doc_553383122817_item	2980113	et	4	main
eluaegne	doc_553383122817_item	2980115	et	3	main
jaoks	doc_553383122817_item	2980122	et	4	main
romaane	doc_553383122817_item	2980128	et	3	main
silma	doc_553383122817_item	2980132	et	4	main
ja	doc_553383122817_item	2980134	et	3	main
p	doc_553383122817_item	2980169	et	4	main
tuntud	doc_553383122817_item	2980173	et	4	main
lugejad	doc_553383122817_item	2980180	et	4	main
krusteni	doc_553383122817_item	2980194	et	4	main
vaatlusobjektiks	doc_553383122817_item	2980195	et	3	main
on	doc_553383122817_item	2980196	et	4	main
teatava	doc_553383122817_item	2980204	et	4	main
ajastu	doc_553383122817_item	2980205	et	4	main
nimetada	doc_553383122817_item	2980212	et	3	main
huvi	doc_553383122817_item	2980215	et	4	main
suundu	doc_553383122817_item	2980217	et	4	main
alateadvuse	doc_553383122817_item	2980220	et	4	main
tõe	doc_553383122817_item	2980228	et	4	main
ja	doc_553383122817_item	2980229	et	3	main
lunastuse	doc_553383122817_item	2980236	et	4	main
tõeline	doc_553383122817_item	2980245	et	4	main
tõde	doc_553383122817_item	2980246	et	4	main
vale	doc_553383122817_item	2980254	et	4	main
ja	doc_553383122817_item	2980255	et	3	main
õilsaks	doc_553383122817_item	2980258	et	3	main
näeb	doc_553383122817_item	2980261	et	3	main
palju	doc_553383122817_item	2980270	et	4	main
on	doc_553383122817_item	2980272	et	4	main
juhust	doc_553383122817_item	2980275	et	4	main
ja	doc_553383122817_item	2980276	et	3	main
kuuluvad	doc_553383122817_item	2980280	et	4	main
1930	doc_553383122817_item	2980284	et	2	main
voorus	doc_553383122817_item	2980286	et	4	main
jaanuse	doc_553383122817_item	2980289	et	4	main
kättemaks	doc_553383122817_item	2980290	et	4	main
mõlemad	doc_553383122817_item	2980291	et	3	main
1938	doc_553383122817_item	2980292	et	2	main
ning	doc_553383122817_item	2980293	et	3	main
1934	doc_553383122817_item	2980297	et	2	main
oma	doc_553383122817_item	2980309	et	4	main
eriti	doc_553383122817_item	2980312	et	3	main
kordustrükke	doc_553383122817_item	2980315	et	3	main
triloogia	doc_553383122817_item	2980323	et	4	main
laev	doc_553383122817_item	2980324	et	3	main
akna	doc_553383122817_item	2980325	et	3	main
armastus	doc_553383122817_item	2980329	et	4	main
ilmusid	doc_553383122817_item	2980331	et	4	main
ülo	doc_553383122817_item	2980340	et	4	main
tonts	doc_553383122817_item	2980341	et	4	main
olnudki	doc_553383122817_item	2980344	et	4	main
koostajaks	doc_553383122817_item	2980348	et	4	main
lugejad	doc_553383122817_item	2980368	et	4	main
metsa	doc_553383122817_item	2980379	et	4	main
kes	doc_553383122817_item	2980394	et	4	main
külast	doc_553383122817_item	2980398	et	4	main
küla	doc_553383122817_item	2980401	et	4	main
autobiograafilisteks	doc_553383122817_item	2980420	et	4	main
ja	doc_553383122817_item	2980421	et	3	main
peegeldab	doc_553383122817_item	2980456	et	3	main
ja	doc_553383122817_item	2980459	et	3	main
kõik	doc_553383122817_item	2980467	et	4	main
mis	doc_553383122817_item	2980490	et	4	main
oli	doc_553383122817_item	2980491	et	3	main
autoriga	doc_553383122817_item	2980492	et	3	main
kaugelviibija	doc_553383122817_item	2980511	et	4	main
käekõrval	doc_553383122817_item	2980512	et	3	main
ja	doc_553383122817_item	2980521	et	3	main
nagu	doc_553383122817_item	2980527	et	3	main
krusten	doc_553383122817_item	2980544	et	4	main
jälgib	doc_553383122817_item	2980545	et	3	main
eelkõige	doc_553383122817_item	2980546	et	3	main
inimese	doc_553383122817_item	2980549	et	4	main
siseprobleeme	doc_553383122817_item	2980550	et	3	main
inimese	doc_553383122817_item	2980552	et	4	main
ja	doc_553383122817_item	2980554	et	3	main
teise	doc_553383122817_item	2980556	et	4	main
maailmasõja	doc_553383122817_item	2980557	et	3	main
nende	doc_553383122817_item	2980563	et	4	main
inimsõbralikkus	doc_553383122817_item	2980564	et	4	main
peamine	doc_553383122817_item	2980565	et	3	main
oli	doc_553383122817_item	2980171	et	3	main
elas	doc_553383122817_item	2980176	et	3	main
tunnustanud	doc_553383122817_item	2980187	et	4	main
ning	doc_553383122817_item	2980188	et	3	main
probleemid	doc_553383122817_item	2980237	et	3	main
loomingus	doc_553383122817_item	2980239	et	3	main
kujuteldav	doc_553383122817_item	2980250	et	4	main
on	doc_553383122817_item	2980265	et	4	main
selles	doc_553383122817_item	2980271	et	4	main
paradokse	doc_553383122817_item	2980273	et	3	main
kokkusattumusi	doc_553383122817_item	2980274	et	3	main
novellikogud	doc_553383122817_item	2980294	et	3	main
tee	doc_553383122817_item	2980299	et	4	main
krusten	doc_553383122817_item	2980303	et	4	main
nagu	doc_553383122817_item	2980308	et	3	main
temast	doc_553383122817_item	2980311	et	3	main
ei	doc_553383122817_item	2980313	et	4	main
on	doc_553383122817_item	2980316	et	4	main
samuti	doc_553383122817_item	2980317	et	3	main
vähe	doc_553383122817_item	2980318	et	3	main
nende	doc_553383122817_item	2980319	et	4	main
krusteni	doc_553383122817_item	2980336	et	4	main
loominguga	doc_553383122817_item	2980337	et	3	main
tegeleb	doc_553383122817_item	2980338	et	3	main
on	doc_553383122817_item	2980343	et	4	main
1963	doc_553383122817_item	2980374	et	2	main
romaanides	doc_553383122817_item	2980376	et	3	main
üle	doc_553383122817_item	2980378	et	3	main
laul	doc_553383122817_item	2980380	et	4	main
läks	doc_553383122817_item	2980385	et	3	main
autor	doc_553383122817_item	2980387	et	3	main
näitab	doc_553383122817_item	2980388	et	3	main
eesti	doc_553383122817_item	2980389	et	4	main
ja	doc_553383122817_item	2980392	et	3	main
mõisast	doc_553383122817_item	2980396	et	4	main
mõisa	doc_553383122817_item	2980399	et	3	main
mõisast	doc_553383122817_item	2980409	et	4	main
rahva	doc_553383122817_item	2980458	et	3	main
on	doc_553383122817_item	2980468	et	4	main
ei	doc_553383122817_item	2980473	et	4	main
p	doc_553383122817_item	2980476	et	4	main
veel	doc_553383122817_item	2980481	et	4	main
läbinähtud	doc_553383122817_item	2980493	et	4	main
kaaselatud	doc_553383122817_item	2980494	et	3	main
1950	doc_553383122817_item	2980503	et	2	main
akna	doc_553383122817_item	2980507	et	3	main
taga	doc_553383122817_item	2980508	et	4	main
ja	doc_553383122817_item	2980510	et	3	main
1957	doc_553383122817_item	2980513	et	2	main
autor	doc_553383122817_item	2980514	et	3	main
kirjeldab	doc_553383122817_item	2980515	et	3	main
oma	doc_553383122817_item	2980516	et	4	main
usa-sse	doc_553383122817_item	2980522	et	3	main
mõned	doc_553383122817_item	2980524	et	3	main
väidsid	doc_553383122817_item	2980526	et	4	main
pagulaselu	doc_553383122817_item	2980531	et	4	main
kuid	doc_553383122817_item	2980533	et	4	main
ülo	doc_553383122817_item	2980534	et	4	main
vasta	doc_553383122817_item	2980539	et	4	main
tõele	doc_553383122817_item	2980540	et	4	main
ja	doc_553383122817_item	2980541	et	3	main
nende	doc_553383122817_item	2980542	et	4	main
raamatutes	doc_553383122817_item	2980543	et	3	main
järgses	doc_553383122817_item	2980558	et	3	main
huvi	doc_553383122817_item	2980568	et	4	main
mitte	doc_553383122817_item	2980575	et	3	main
ideed	doc_553383122817_item	2980578	et	4	main
mitte	doc_553383122817_item	2980579	et	3	main
maailmavaade	doc_553383122817_item	2980580	et	3	main
vaid	doc_553383122817_item	2980581	et	3	main
ikka	doc_553383122817_item	2980582	et	4	main
inimene	doc_553383122817_item	2980583	et	3	main
kõik	doc_553383122817_item	2980589	et	4	main
raamatud	doc_553383122817_item	2980591	et	4	main
valdamisest	doc_553383122817_item	2980598	et	4	main
tasub	doc_553383122817_item	2980599	et	3	main
mõtelda	doc_553383122817_item	2980600	et	4	main
ka	doc_553383122817_item	2980601	et	3	main
tänasel	doc_553383122817_item	2980602	et	3	main
tähtpäeval	doc_553383122817_item	2980603	et	3	main
63	doc_553383122817_item	2980604	et	2	main
tallinnast	doc_553383122817_item	2980611	et	3	main
2004vääna	doc_553383122817_item	2980615	et	4	main
tulevikuprespektiivid	doc_553383122817_item	2980617	et	4	main
psühholoogiliseks	doc_553383122817_item	2980213	et	4	main
vale	doc_553383122817_item	2980230	et	4	main
süü	doc_553383122817_item	2980231	et	4	main
ja	doc_553383122817_item	2980232	et	3	main
patu	doc_553383122817_item	2980233	et	3	main
puhtuse	doc_553383122817_item	2980234	et	4	main
on	doc_553383122817_item	2980244	et	4	main
mis	doc_553383122817_item	2980251	et	4	main
on	doc_553383122817_item	2980252	et	4	main
võib	doc_553383122817_item	2980257	et	3	main
valeks	doc_553383122817_item	2980259	et	3	main
läbi	doc_553383122817_item	2980262	et	4	main
kui	doc_553383122817_item	2980263	et	3	main
õhuke	doc_553383122817_item	2980264	et	4	main
olemus	doc_553383122817_item	2980268	et	3	main
ekslemist	doc_553383122817_item	2980277	et	4	main
romaanid	doc_553383122817_item	2980281	et	3	main
kalle	doc_553383122817_item	2980288	et	3	main
käega	doc_553383122817_item	2980296	et	3	main
1936	doc_553383122817_item	2980300	et	2	main
eluajal	doc_553383122817_item	2980310	et	3	main
hulka	doc_553383122817_item	2980320	et	4	main
ning	doc_553383122817_item	2980327	et	3	main
pärast	doc_553383122817_item	2980333	et	4	main
ka	doc_553383122817_item	2980345	et	3	main
gruppi	doc_553383122817_item	2980279	et	4	main
vale	doc_553383122817_item	2980283	et	4	main
pime	doc_553383122817_item	2980285	et	3	main
ja	doc_553383122817_item	2980287	et	3	main
varasema	doc_553383122817_item	2980295	et	4	main
tänapäeval	doc_553383122817_item	2980301	et	3	main
tuntud	doc_553383122817_item	2980307	et	4	main
kirjuta	doc_553383122817_item	2980314	et	4	main
taga	doc_553383122817_item	2980326	et	4	main
peamiselt	doc_553383122817_item	2980339	et	4	main
nimetab	doc_553383122817_item	2980352	et	3	main
p	doc_553383122817_item	2980353	et	4	main
krusteni	doc_553383122817_item	2980354	et	4	main
tundmatu	doc_553383122817_item	2980355	et	4	main
eesti	doc_553383122817_item	2980356	et	4	main
kirjanikuks	doc_553383122817_item	2980357	et	3	main
kes	doc_553383122817_item	2980358	et	4	main
on	doc_553383122817_item	2980359	et	4	main
kadunud	doc_553383122817_item	2980360	et	4	main
ja	doc_553383122817_item	2980361	et	3	main
unustatud	doc_553383122817_item	2980362	et	4	main
miks	doc_553383122817_item	2980363	et	4	main
aeg	doc_553383122817_item	2980364	et	3	main
lendab	doc_553383122817_item	2980365	et	3	main
tulevad	doc_553383122817_item	2980366	et	4	main
uued	doc_553383122817_item	2980367	et	3	main
uued	doc_553383122817_item	2980369	et	3	main
1959-	doc_553383122817_item	2980373	et	4	main
neiuke	doc_553383122817_item	2980384	et	4	main
sündi	doc_553383122817_item	2980391	et	4	main
pärines	doc_553383122817_item	2980395	et	3	main
võrsuv	doc_553383122817_item	2980410	et	4	main
sest	doc_553383122817_item	2980423	et	4	main
ise	doc_553383122817_item	2980463	et	4	main
kunagi	doc_553383122817_item	2980464	et	3	main
kommenteeris	doc_553383122817_item	2980465	et	3	main
seda	doc_553383122817_item	2980466	et	3	main
kõrgel	doc_553383122817_item	2980381	et	4	main
kaldal	doc_553383122817_item	2980382	et	3	main
ja	doc_553383122817_item	2980383	et	3	main
kujunemist	doc_553383122817_item	2980393	et	4	main
rõhk	doc_553383122817_item	2980405	et	3	main
mälestuslikeks	doc_553383122817_item	2980422	et	4	main
nende	doc_553383122817_item	2980424	et	4	main
peategelane	doc_553383122817_item	2980425	et	3	main
on	doc_553383122817_item	2980426	et	4	main
mõisaednik	doc_553383122817_item	2980427	et	4	main
ja	doc_553383122817_item	2980428	et	3	main
tema	doc_553383122817_item	2980429	et	4	main
pojad	doc_553383122817_item	2980430	et	4	main
samasused	doc_553383122817_item	2980431	et	3	main
eksisteerivad	doc_553383122817_item	2980432	et	4	main
ka	doc_553383122817_item	2980433	et	3	main
süžee	doc_553383122817_item	2980434	et	2	main
taustas	doc_553383122817_item	2980435	et	3	main
mõisarahva	doc_553383122817_item	2980436	et	3	main
ja	doc_553383122817_item	2980437	et	3	main
külainimeste	doc_553383122817_item	2980438	et	3	main
suhted	doc_553383122817_item	2980439	et	3	main
mõisnike	doc_553383122817_item	2980440	et	3	main
ja	doc_553383122817_item	2980441	et	3	main
mõisarahva	doc_553383122817_item	2980442	et	3	main
vahekord	doc_553383122817_item	2980443	et	3	main
kaldametsa	doc_553383122817_item	2980444	et	4	main
mõisa	doc_553383122817_item	2980445	et	3	main
ei	doc_553383122817_item	2980446	et	4	main
ole	doc_553383122817_item	2980447	et	4	main
midagi	doc_553383122817_item	2980448	et	4	main
muud	doc_553383122817_item	2980449	et	4	main
kui	doc_553383122817_item	2980450	et	3	main
tema	doc_553383122817_item	2980451	et	4	main
lapsepõlvekodu	doc_553383122817_item	2980452	et	4	main
muraste	doc_553383122817_item	2980453	et	4	main
mis	doc_553383122817_item	2980454	et	4	main
nagu	doc_553383122817_item	2980455	et	3	main
kuuluvates	doc_553383122817_item	2980375	et	4	main
torn	doc_553383122817_item	2980377	et	3	main
roosiaeda	doc_553383122817_item	2980386	et	4	main
maaintelligentsi	doc_553383122817_item	2980390	et	4	main
mitte	doc_553383122817_item	2980397	et	3	main
ja	doc_553383122817_item	2980400	et	3	main
vastuolud	doc_553383122817_item	2980402	et	3	main
kuid	doc_553383122817_item	2980403	et	4	main
peamine	doc_553383122817_item	2980404	et	3	main
on	doc_553383122817_item	2980406	et	4	main
sellel	doc_553383122817_item	2980407	et	4	main
kuidas	doc_553383122817_item	2980408	et	3	main
rahvas	doc_553383122817_item	2980411	et	4	main
on	doc_553383122817_item	2980412	et	4	main
külale	doc_553383122817_item	2980413	et	3	main
täienduseks	doc_553383122817_item	2980414	et	4	main
teosed	doc_553383122817_item	2980415	et	3	main
võib	doc_553383122817_item	2980416	et	3	main
julgesti	doc_553383122817_item	2980417	et	3	main
nimetada	doc_553383122817_item	2980418	et	3	main
perekondlikeks	doc_553383122817_item	2980419	et	3	main
ole	doc_553383122817_item	2980474	et	4	main
gruppi	doc_553383122817_item	2980483	et	4	main
pöördelised	doc_553383122817_item	2980487	et	4	main
sündmused	doc_553383122817_item	2980488	et	3	main
kõik	doc_553383122817_item	2980489	et	4	main
üleparda	doc_553383122817_item	2980499	et	4	main
1946	doc_553383122817_item	2980500	et	2	main
põgenemise	doc_553383122817_item	2980517	et	4	main
kodumaalt	doc_553383122817_item	2980518	et	3	main
teod	doc_553383122817_item	2980530	et	4	main
võõrsile	doc_553383122817_item	2980547	et	4	main
eetilise	doc_553383122817_item	2980551	et	3	main
kogemusi	doc_553383122817_item	2980553	et	3	main
inimese	doc_553383122817_item	2980571	et	4	main
ise	doc_553383122817_item	2980584	et	4	main
seega	doc_553383122817_item	2980585	et	4	main
siis	doc_553383122817_item	2980586	et	3	main
1	doc_553383122817_item	2980607	et	2	main
httpwwwharkueeindexphp	doc_553383122817_item	2980608	et	4	main
2	doc_553383122817_item	2980609	et	2	main
3	doc_553383122817_item	2980614	et	2	main
ja	doc_553383122817_item	2980622	et	3	main
sihtasutus	doc_553383122817_item	2980625	et	4	main
eesti	doc_553383122817_item	2980659	et	4	main
regionaalse	doc_553383122817_item	2980660	et	3	main
ja	doc_553383122817_item	2980661	et	3	main
kohaliku	doc_553383122817_item	2980662	et	3	main
arengu	doc_553383122817_item	2980663	et	3	main
sihtasutus	doc_553383122817_item	2980664	et	4	main
55-56	doc_553383122817_item	2980665	et	2	main
7	doc_553383122817_item	2980666	et	2	main
tulevikuprespektiivid	doc_553383122817_item	2980669	et	4	main
ja	doc_553383122817_item	2980674	et	3	main
8	doc_553383122817_item	2980679	et	2	main
mõisa	doc_553383122817_item	2980681	et	3	main
tulevikuprespektiivid	doc_553383122817_item	2980682	et	4	main
polüfunktsionaalse	doc_553383122817_item	2980683	et	4	main
keskusena	doc_553383122817_item	2980684	et	3	main
rahnop1976	doc_553383122817_item	2980694	et	4	main
harku	doc_553383122817_item	2980695	et	4	main
mõisa	doc_553383122817_item	2980701	et	3	main
tallinn	doc_553383122817_item	2980703	et	4	main
rahno	doc_553383122817_item	2980705	et	4	main
p1976	doc_553383122817_item	2980706	et	4	main
ajaloost	doc_553383122817_item	2980713	et	4	main
tallinn	doc_553383122817_item	2980714	et	4	main
13rahnop1965	doc_553383122817_item	2980715	et	2	main
ajaloost	doc_553383122817_item	2980718	et	4	main
14	doc_553383122817_item	2980720	et	2	main
rahnop1965	doc_553383122817_item	2980721	et	4	main
harku	doc_553383122817_item	2980728	et	4	main
mõisa	doc_553383122817_item	2980729	et	3	main
ülevainor2001	doc_553383122817_item	2980736	et	4	main
enamlased	doc_553383122817_item	2980772	et	3	main
24	doc_553383122817_item	2980775	et	2	main
11	doc_553383122817_item	2980782	et	2	main
221105	doc_553383122817_item	2980785	et	2	main
ülevainor2001	doc_553383122817_item	2980787	et	4	main
tallinnast	doc_553383122817_item	2980788	et	3	main
sealelava	doc_553383122817_item	2980457	et	3	main
kultuuri	doc_553383122817_item	2980460	et	4	main
kujunemist	doc_553383122817_item	2980461	et	4	main
kirjanik	doc_553383122817_item	2980462	et	3	main
võetud	doc_553383122817_item	2980470	et	4	main
kuigi	doc_553383122817_item	2980471	et	3	main
niisugust	doc_553383122817_item	2980472	et	3	main
ühe	doc_553383122817_item	2980482	et	4	main
kajastuvad	doc_553383122817_item	2980485	et	4	main
tõlgendatud	doc_553383122817_item	2980495	et	4	main
need	doc_553383122817_item	2980496	et	3	main
silmapilk	doc_553383122817_item	2980502	et	3	main
1952	doc_553383122817_item	2980505	et	2	main
1955	doc_553383122817_item	2980509	et	2	main
laagrite	doc_553383122817_item	2980520	et	3	main
tontsu	doc_553383122817_item	2980535	et	4	main
sõnadel	doc_553383122817_item	2980536	et	3	main
see	doc_553383122817_item	2980537	et	3	main
katsumusi	doc_553383122817_item	2980555	et	3	main
pohmelsuses	doc_553383122817_item	2980559	et	4	main
krusteni	doc_553383122817_item	2980560	et	4	main
teoseid	doc_553383122817_item	2980561	et	3	main
elust	doc_553383122817_item	2980469	et	3	main
juhtunud	doc_553383122817_item	2980475	et	4	main
krusteni	doc_553383122817_item	2980477	et	4	main
teostest	doc_553383122817_item	2980478	et	3	main
võib	doc_553383122817_item	2980479	et	3	main
eristada	doc_553383122817_item	2980480	et	3	main
kus	doc_553383122817_item	2980484	et	3	main
ajastu	doc_553383122817_item	2980486	et	4	main
on	doc_553383122817_item	2980497	et	4	main
romaanid	doc_553383122817_item	2980498	et	3	main
ihaldatud	doc_553383122817_item	2980501	et	4	main
inimesehoidja	doc_553383122817_item	2980504	et	4	main
laev	doc_553383122817_item	2980506	et	3	main
diipii-	doc_553383122817_item	2980519	et	4	main
ümberasumisest	doc_553383122817_item	2980523	et	4	main
kriitikut	doc_553383122817_item	2980525	et	3	main
oleksid	doc_553383122817_item	2980528	et	4	main
need	doc_553383122817_item	2980529	et	3	main
kroonika	doc_553383122817_item	2980532	et	4	main
ei	doc_553383122817_item	2980538	et	4	main
paisatud	doc_553383122817_item	2980548	et	4	main
iseloomustab	doc_553383122817_item	2980562	et	4	main
vaatlemine	doc_553383122817_item	2980572	et	4	main
avastamine	doc_553383122817_item	2980574	et	4	main
olustik	doc_553383122817_item	2980576	et	3	main
tema	doc_553383122817_item	2980590	et	4	main
kuuluvad	doc_553383122817_item	2980592	et	4	main
rahvusliku	doc_553383122817_item	2980593	et	3	main
varanduse	doc_553383122817_item	2980594	et	3	main
hulka	doc_553383122817_item	2980595	et	4	main
mille	doc_553383122817_item	2980596	et	3	main
ülevainor2001	doc_553383122817_item	2980610	et	4	main
polüfunktsionaalse	doc_553383122817_item	2980670	et	4	main
arengu	doc_553383122817_item	2980676	et	3	main
2004vääna	doc_553383122817_item	2980680	et	4	main
57-	doc_553383122817_item	2980691	et	4	main
9	doc_553383122817_item	2980693	et	2	main
rahnop1965	doc_553383122817_item	2980699	et	4	main
tallinn	doc_553383122817_item	2980708	et	4	main
12rahnop1965	doc_553383122817_item	2980710	et	2	main
mõisa	doc_553383122817_item	2980712	et	3	main
ajaloost	doc_553383122817_item	2980724	et	4	main
tallinn	doc_553383122817_item	2980731	et	4	main
16	doc_553383122817_item	2980732	et	2	main
keila-joale	doc_553383122817_item	2980738	et	3	main
35	doc_553383122817_item	2980740	et	2	main
parunid	doc_553383122817_item	2980769	et	3	main
httpwwweestigiideecatid89itemid325	doc_553383122817_item	2980776	et	4	main
keila-joale	doc_553383122817_item	2980780	et	3	main
ja	doc_553383122817_item	2980566	et	3	main
muutumatu	doc_553383122817_item	2980567	et	4	main
inimene	doc_553383122817_item	2980570	et	3	main
ja	doc_553383122817_item	2980573	et	3	main
mitte	doc_553383122817_item	2980577	et	3	main
psühholoogiline	doc_553383122817_item	2980587	et	4	main
erni	doc_553383122817_item	2980605	et	4	main
keila-joale	doc_553383122817_item	2980612	et	3	main
kohaliku	doc_553383122817_item	2980623	et	3	main
regionaalse	doc_553383122817_item	2980673	et	3	main
kohaliku	doc_553383122817_item	2980675	et	3	main
77-80	doc_553383122817_item	2980678	et	2	main
arengu	doc_553383122817_item	2980689	et	3	main
3	doc_553383122817_item	2980697	et	2	main
harku	doc_553383122817_item	2980707	et	4	main
harku	doc_553383122817_item	2980722	et	4	main
mõisa	doc_553383122817_item	2980723	et	3	main
ajaloost	doc_553383122817_item	2980730	et	4	main
tallinnast	doc_553383122817_item	2980737	et	3	main
ja	doc_553383122817_item	2980771	et	3	main
tartu	doc_553383122817_item	2980773	et	4	main
221105	doc_553383122817_item	2980777	et	2	main
tallinnast	doc_553383122817_item	2980779	et	3	main
26	doc_553383122817_item	2980783	et	2	main
27	doc_553383122817_item	2980786	et	2	main
olnud	doc_553383122817_item	2980569	et	4	main
proosa	doc_553383122817_item	2980588	et	4	main
paremast	doc_553383122817_item	2980597	et	4	main
krusten	doc_553383122817_item	2980606	et	4	main
38	doc_553383122817_item	2980613	et	2	main
mõisa	doc_553383122817_item	2980616	et	3	main
2004vääna	doc_553383122817_item	2980627	et	4	main
mõisa	doc_553383122817_item	2980628	et	3	main
tulevikuprespektiivid	doc_553383122817_item	2980629	et	4	main
polüfunktsionaalse	doc_553383122817_item	2980630	et	4	main
keskusena	doc_553383122817_item	2980631	et	3	main
eesti	doc_553383122817_item	2980632	et	4	main
regionaalse	doc_553383122817_item	2980633	et	3	main
ja	doc_553383122817_item	2980634	et	3	main
kohaliku	doc_553383122817_item	2980635	et	3	main
arengu	doc_553383122817_item	2980636	et	3	main
sihtasutus	doc_553383122817_item	2980637	et	4	main
55-57	doc_553383122817_item	2980638	et	2	main
5	doc_553383122817_item	2980639	et	2	main
2004vääna	doc_553383122817_item	2980640	et	4	main
mõisa	doc_553383122817_item	2980641	et	3	main
tulevikuprespektiivid	doc_553383122817_item	2980642	et	4	main
polüfunktsionaalse	doc_553383122817_item	2980643	et	4	main
keskusena	doc_553383122817_item	2980644	et	3	main
eesti	doc_553383122817_item	2980645	et	4	main
regionaalse	doc_553383122817_item	2980646	et	3	main
ja	doc_553383122817_item	2980647	et	3	main
kohaliku	doc_553383122817_item	2980648	et	3	main
arengu	doc_553383122817_item	2980649	et	3	main
sihtasutus	doc_553383122817_item	2980650	et	4	main
57-	doc_553383122817_item	2980651	et	4	main
73	doc_553383122817_item	2980652	et	2	main
6	doc_553383122817_item	2980653	et	2	main
2004vääna	doc_553383122817_item	2980654	et	4	main
mõisa	doc_553383122817_item	2980655	et	3	main
tulevikuprespektiivid	doc_553383122817_item	2980656	et	4	main
polüfunktsionaalse	doc_553383122817_item	2980657	et	4	main
keskusena	doc_553383122817_item	2980658	et	3	main
polüfunktsionaalse	doc_553383122817_item	2980618	et	4	main
keskusena	doc_553383122817_item	2980619	et	3	main
eesti	doc_553383122817_item	2980620	et	4	main
regionaalse	doc_553383122817_item	2980621	et	3	main
arengu	doc_553383122817_item	2980624	et	3	main
4	doc_553383122817_item	2980626	et	2	main
2004vääna	doc_553383122817_item	2980667	et	4	main
eesti	doc_553383122817_item	2980672	et	4	main
eesti	doc_553383122817_item	2980685	et	4	main
regionaalse	doc_553383122817_item	2980686	et	3	main
kohaliku	doc_553383122817_item	2980688	et	3	main
tallinn	doc_553383122817_item	2980696	et	4	main
10	doc_553383122817_item	2980698	et	2	main
11	doc_553383122817_item	2980704	et	2	main
5-8	doc_553383122817_item	2980709	et	2	main
harku	doc_553383122817_item	2980711	et	4	main
mõisa	doc_553383122817_item	2980717	et	3	main
tallinn	doc_553383122817_item	2980719	et	4	main
httpwwwharkueefiles103pdf	doc_553383122817_item	2980733	et	4	main
221105	doc_553383122817_item	2980734	et	2	main
18	doc_553383122817_item	2980741	et	2	main
rahnop1965	doc_553383122817_item	2980742	et	4	main
harku	doc_553383122817_item	2980743	et	4	main
mõisa	doc_553383122817_item	2980744	et	3	main
ajaloost	doc_553383122817_item	2980745	et	4	main
tallinn	doc_553383122817_item	2980746	et	4	main
19	doc_553383122817_item	2980747	et	2	main
httpwwweestigiideescat15catid0itemid130	doc_553383122817_item	2980748	et	4	main
221105	doc_553383122817_item	2980749	et	2	main
20	doc_553383122817_item	2980750	et	2	main
sakki2002	doc_553383122817_item	2980751	et	4	main
eesti	doc_553383122817_item	2980752	et	4	main
mõisad	doc_553383122817_item	2980753	et	3	main
reisijuht	doc_553383122817_item	2980754	et	3	main
tallinn	doc_553383122817_item	2980755	et	4	main
32-33	doc_553383122817_item	2980756	et	2	main
21	doc_553383122817_item	2980757	et	2	main
httpwwwharkueefiles84pdf	doc_553383122817_item	2980758	et	4	main
221105	doc_553383122817_item	2980759	et	2	main
22	doc_553383122817_item	2980760	et	2	main
monthanderc1997	doc_553383122817_item	2980761	et	4	main
23monthanderc1997	doc_553383122817_item	2980768	et	2	main
25ülevainor2001	doc_553383122817_item	2980778	et	2	main
sakki2002	doc_553383122817_item	2980793	et	4	main
mõisa	doc_553383122817_item	2980668	et	3	main
keskusena	doc_553383122817_item	2980671	et	3	main
sihtasutus	doc_553383122817_item	2980677	et	4	main
ja	doc_553383122817_item	2980687	et	3	main
sihtasutus	doc_553383122817_item	2980690	et	4	main
73	doc_553383122817_item	2980692	et	2	main
harku	doc_553383122817_item	2980700	et	4	main
ajaloost	doc_553383122817_item	2980702	et	4	main
harku	doc_553383122817_item	2980716	et	4	main
tallinn	doc_553383122817_item	2980725	et	4	main
15	doc_553383122817_item	2980726	et	2	main
rahnop1965	doc_553383122817_item	2980727	et	4	main
17	doc_553383122817_item	2980735	et	2	main
tallinn	doc_553383122817_item	2980739	et	4	main
eestlased	doc_553383122817_item	2980770	et	3	main
129	doc_553383122817_item	2980774	et	2	main
tallinn	doc_553383122817_item	2980781	et	4	main
httpwwweestigiideescat10catid1itemid7890	doc_553383122817_item	2980784	et	4	main
eesti	doc_553383122817_item	2980794	et	4	main
mõisad	doc_553383122817_item	2980795	et	3	main
reisijuht	doc_553383122817_item	2980796	et	3	main
tallinn	doc_553383122817_item	2980797	et	4	main
22-40	doc_553383122817_item	2980798	et	2	main
29	doc_553383122817_item	2980799	et	2	main
httpwwweestigiideepersonnimipyearaastaitemid214	doc_553383122817_item	2980800	et	4	main
221105	doc_553383122817_item	2980801	et	2	main
keila-joale	doc_553383122817_item	2980789	et	3	main
tallinn	doc_553383122817_item	2980790	et	4	main
20-21	doc_553383122817_item	2980791	et	2	main
28	doc_553383122817_item	2980792	et	2	main
referaat	doc_101672866015_item	3136799	et	3	main
teemaks	doc_101672866015_item	3136803	et	4	main
esimesest	doc_101672866015_item	3136811	et	3	main
tänapäevaelus	doc_101672866015_item	3136823	et	4	main
ja	doc_101672866015_item	3136824	et	3	main
see	doc_101672866015_item	3136827	et	3	main
kui	doc_101672866015_item	3136832	et	3	main
on	doc_101672866015_item	3136834	et	4	main
harku	doc_101672866015_item	3136863	et	4	main
elu	doc_101672866015_item	3136866	et	4	main
aegade	doc_101672866015_item	3136868	et	3	main
kohti	doc_101672866015_item	3136883	et	4	main
olid	doc_101672866015_item	3136890	et	4	main
minevikus	doc_101672866015_item	3136892	et	3	main
nad	doc_101672866015_item	3136901	et	3	main
või	doc_101672866015_item	3136912	et	4	main
sündmuste	doc_101672866015_item	3136913	et	3	main
elanud	doc_101672866015_item	3136918	et	4	main
on	doc_101672866015_item	3136933	et	4	main
siis	doc_101672866015_item	3136934	et	3	main
kuidas	doc_101672866015_item	3136935	et	3	main
nad	doc_101672866015_item	3136936	et	3	main
teda	doc_101672866015_item	3136971	et	4	main
praeguse	doc_101672866015_item	3136978	et	3	main
keila	doc_101672866015_item	3136979	et	4	main
harku	doc_101672866015_item	3136994	et	4	main
vald	doc_101672866015_item	3136997	et	3	main
antud	doc_101672866015_item	3137010	et	4	main
pikaliiva	doc_101672866015_item	3137015	et	4	main
harku	doc_101672866015_item	3137019	et	4	main
sinna	doc_101672866015_item	3137028	et	3	main
ja	doc_101672866015_item	3137031	et	3	main
harkujärve	doc_101672866015_item	3137035	et	4	main
kumna	doc_101672866015_item	3137045	et	4	main
türisalu	doc_101672866015_item	3137049	et	4	main
selle	doc_101672866015_item	3136801	et	4	main
sõnu	doc_101672866015_item	3136809	et	4	main
nii	doc_101672866015_item	3136813	et	3	main
kas	doc_101672866015_item	3136825	et	3	main
vajalik	doc_101672866015_item	3136830	et	3	main
ajal	doc_101672866015_item	3136831	et	4	main
inimestel	doc_101672866015_item	3136833	et	3	main
valla	doc_101672866015_item	3136864	et	4	main
harku	doc_101672866015_item	3136870	et	4	main
neid	doc_101672866015_item	3136882	et	4	main
nad	doc_101672866015_item	3136889	et	3	main
tuntud	doc_101672866015_item	3136891	et	4	main
tänapäeval	doc_101672866015_item	3136898	et	3	main
on	doc_101672866015_item	3136902	et	4	main
huvitavad	doc_101672866015_item	3136903	et	4	main
või	doc_101672866015_item	3136907	et	4	main
mingite	doc_101672866015_item	3136908	et	4	main
minevikul	doc_101672866015_item	3136909	et	3	main
võibolla	doc_101672866015_item	3136915	et	4	main
kes	doc_101672866015_item	3136920	et	4	main
kunagi	doc_101672866015_item	3136921	et	3	main
kuulsad	doc_101672866015_item	3136922	et	3	main
üldse	doc_101672866015_item	3136927	et	3	main
unustatud	doc_101672866015_item	3136928	et	4	main
ja	doc_101672866015_item	3136929	et	3	main
kui	doc_101672866015_item	3136930	et	3	main
tegelesid	doc_101672866015_item	3136939	et	4	main
kultuurilisi	doc_101672866015_item	3136941	et	4	main
väärtusi	doc_101672866015_item	3136942	et	3	main
keila	doc_101672866015_item	3136972	et	4	main
territooriumid	doc_101672866015_item	3136980	et	3	main
harku	doc_101672866015_item	3136981	et	4	main
ja	doc_101672866015_item	3136982	et	3	main
keila	doc_101672866015_item	3136983	et	4	main
eesti	doc_101672866015_item	3136797	et	4	main
pilgust	doc_101672866015_item	3136812	et	4	main
on	doc_101672866015_item	3136822	et	4	main
üldse	doc_101672866015_item	3136829	et	3	main
kui	doc_101672866015_item	3136842	et	3	main
inimesed	doc_101672866015_item	3136843	et	3	main
kuna	doc_101672866015_item	3136869	et	3	main
ühekaupa	doc_101672866015_item	3136884	et	4	main
ning	doc_101672866015_item	3136885	et	3	main
uurida	doc_101672866015_item	3136886	et	3	main
mille	doc_101672866015_item	3136887	et	3	main
nendel	doc_101672866015_item	3136897	et	4	main
on	doc_101672866015_item	3136899	et	4	main
kas	doc_101672866015_item	3136900	et	3	main
rahvajuttude	doc_101672866015_item	3136906	et	4	main
järgi	doc_101672866015_item	3136914	et	4	main
inimesi	doc_101672866015_item	3136919	et	4	main
on	doc_101672866015_item	3136926	et	4	main
selliseid	doc_101672866015_item	3136931	et	4	main
inimesi	doc_101672866015_item	3136932	et	4	main
kihelkonda	doc_101672866015_item	3136973	et	4	main
umbes	doc_101672866015_item	3136987	et	4	main
maadest	doc_101672866015_item	3136991	et	4	main
kuid	doc_101672866015_item	3136992	et	4	main
pöördume	doc_101672866015_item	3136993	et	3	main
ning	doc_101672866015_item	3137000	et	3	main
enda	doc_101672866015_item	3137002	et	4	main
praeguse	doc_101672866015_item	3137004	et	3	main
osa	doc_101672866015_item	3137007	et	4	main
hiljem	doc_101672866015_item	3137008	et	3	main
tallinnale	doc_101672866015_item	3137009	et	4	main
kakumäe	doc_101672866015_item	3137013	et	3	main
ja	doc_101672866015_item	3137016	et	3	main
21	doc_101672866015_item	3137023	et	2	main
novembril	doc_101672866015_item	3137024	et	3	main
aastal	doc_101672866015_item	3137026	et	3	main
alevikud	doc_101672866015_item	3137033	et	4	main
adra	doc_101672866015_item	3137048	et	3	main
naage	doc_101672866015_item	3137050	et	4	main
mõisad	doc_101672866015_item	3137091	et	3	main
paiknevad	doc_101672866015_item	3137097	et	4	main
vana-	doc_101672866015_item	3137104	et	4	main
viti	doc_101672866015_item	3137106	et	4	main
mõisad	doc_101672866015_item	3137107	et	3	main
julgesti	doc_101672866015_item	3137113	et	3	main
mitte	doc_101672866015_item	3137115	et	3	main
turismiobjektiks	doc_101672866015_item	3137122	et	3	main
ka	doc_101672866015_item	3137124	et	3	main
millel	doc_101672866015_item	3137126	et	3	main
eesti	doc_101672866015_item	3137131	et	4	main
väänas	doc_101672866015_item	3137134	et	3	main
läbi	doc_101672866015_item	3137146	et	4	main
viiakse	doc_101672866015_item	3137147	et	3	main
seal	doc_101672866015_item	3137148	et	4	main
esimesed	doc_101672866015_item	3137149	et	3	main
1306	doc_101672866015_item	3137154	et	2	main
abielumiste	doc_101672866015_item	3137190	et	4	main
sissejuhatus	doc_101672866015_item	3136800	et	4	main
töö	doc_101672866015_item	3136802	et	4	main
on	doc_101672866015_item	3136804	et	4	main
traditsioon	doc_101672866015_item	3136805	et	3	main
ja	doc_101672866015_item	3136806	et	3	main
nüüdisaeg	doc_101672866015_item	3136807	et	3	main
kaks	doc_101672866015_item	3136808	et	3	main
on	doc_101672866015_item	3136815	et	4	main
nüüdisajal	doc_101672866015_item	3136826	et	3	main
ajal	doc_101672866015_item	3136841	et	4	main
nende	doc_101672866015_item	3136857	et	4	main
naaber	doc_101672866015_item	3136858	et	3	main
on	doc_101672866015_item	3136859	et	4	main
kultuuriline	doc_101672866015_item	3136865	et	4	main
läbi	doc_101672866015_item	3136867	et	4	main
on	doc_101672866015_item	3136872	et	4	main
päris	doc_101672866015_item	3136873	et	4	main
oma	doc_101672866015_item	3136875	et	4	main
mõisate	doc_101672866015_item	3136876	et	3	main
poolest	doc_101672866015_item	3136877	et	4	main
siis	doc_101672866015_item	3136878	et	3	main
ma	doc_101672866015_item	3136879	et	3	main
otsustasin	doc_101672866015_item	3136880	et	3	main
võtta	doc_101672866015_item	3136881	et	3	main
poolest	doc_101672866015_item	3136888	et	4	main
ja	doc_101672866015_item	3136893	et	3	main
missugune	doc_101672866015_item	3136894	et	3	main
kultuuriline	doc_101672866015_item	3136895	et	4	main
väärtus	doc_101672866015_item	3136896	et	3	main
tallinnast	doc_101672866015_item	3142906	et	3	main
keila-joale	doc_101672866015_item	3142907	et	3	main
tallinn	doc_101672866015_item	3142908	et	4	main
11	doc_101672866015_item	3142909	et	2	main
26	doc_101672866015_item	3142910	et	2	main
httpwwweestigiideescat10catid1itemid7890	doc_101672866015_item	3142911	et	4	main
221105	doc_101672866015_item	3142912	et	2	main
27	doc_101672866015_item	3142913	et	2	main
ülevainor2001	doc_101672866015_item	3142914	et	4	main
tallinnast	doc_101672866015_item	3142915	et	3	main
keila-joale	doc_101672866015_item	3142916	et	3	main
tallinn	doc_101672866015_item	3142917	et	4	main
20-21	doc_101672866015_item	3142918	et	2	main
28	doc_101672866015_item	3142919	et	2	main
sakki2002	doc_101672866015_item	3142920	et	4	main
eesti	doc_101672866015_item	3142921	et	4	main
mõisad	doc_101672866015_item	3142922	et	3	main
reisijuht	doc_101672866015_item	3142923	et	3	main
tallinn	doc_101672866015_item	3142924	et	4	main
22-40	doc_101672866015_item	3142925	et	2	main
29	doc_101672866015_item	3142926	et	2	main
httpwwweestigiideepersonnimipyearaastaitemid214	doc_101672866015_item	3142927	et	4	main
221105	doc_101672866015_item	3142928	et	2	main
kultuuriloo	doc_101672866015_item	3136798	et	4	main
mis	doc_101672866015_item	3136810	et	4	main
erinevad	doc_101672866015_item	3136814	et	4	main
mis	doc_101672866015_item	3136816	et	4	main
on	doc_101672866015_item	3136817	et	4	main
traditsioon	doc_101672866015_item	3136818	et	3	main
milline	doc_101672866015_item	3136819	et	3	main
koht	doc_101672866015_item	3136820	et	3	main
tal	doc_101672866015_item	3136821	et	3	main
on	doc_101672866015_item	3136828	et	4	main
internet	doc_101672866015_item	3136835	et	4	main
televisioon	doc_101672866015_item	3136836	et	4	main
igasugused	doc_101672866015_item	3136837	et	3	main
diskoõhtud	doc_101672866015_item	3136838	et	3	main
ja	doc_101672866015_item	3136839	et	3	main
ööklubid	doc_101672866015_item	3136840	et	3	main
peaaegu	doc_101672866015_item	3136844	et	3	main
ei	doc_101672866015_item	3136845	et	4	main
loe	doc_101672866015_item	3136846	et	4	main
ei	doc_101672866015_item	3136847	et	4	main
käi	doc_101672866015_item	3136848	et	4	main
teatrites	doc_101672866015_item	3136849	et	3	main
ühes	doc_101672866015_item	3136850	et	4	main
majas	doc_101672866015_item	3136851	et	3	main
elades	doc_101672866015_item	3136852	et	4	main
nad	doc_101672866015_item	3136853	et	3	main
ei	doc_101672866015_item	3136854	et	4	main
tunne	doc_101672866015_item	3136855	et	4	main
kes	doc_101672866015_item	3136856	et	4	main
seminaritöö	doc_101672866015_item	3136860	et	4	main
uurimisobjekt	doc_101672866015_item	3136861	et	3	main
on	doc_101672866015_item	3136862	et	4	main
vald	doc_101672866015_item	3136871	et	3	main
rikkas	doc_101672866015_item	3136874	et	4	main
näiteks	doc_101672866015_item	3136904	et	4	main
oma	doc_101672866015_item	3136905	et	4	main
esinenud	doc_101672866015_item	3136910	et	4	main
elukommete	doc_101672866015_item	3136911	et	4	main
seal	doc_101672866015_item	3136916	et	4	main
on	doc_101672866015_item	3136917	et	4	main
olid	doc_101672866015_item	3136923	et	4	main
kuid	doc_101672866015_item	3136924	et	4	main
nüüdisajal	doc_101672866015_item	3136925	et	3	main
elasid	doc_101672866015_item	3136937	et	4	main
millega	doc_101672866015_item	3136938	et	3	main
kuulusid	doc_101672866015_item	3136974	et	4	main
ka	doc_101672866015_item	3136975	et	3	main
valla	doc_101672866015_item	3136995	et	4	main
tagasi	doc_101672866015_item	3136996	et	3	main
milliseid	doc_101672866015_item	3136940	et	3	main
oma	doc_101672866015_item	3136943	et	4	main
kodukohale	doc_101672866015_item	3136944	et	4	main
tõid	doc_101672866015_item	3136945	et	4	main
mille	doc_101672866015_item	3136946	et	3	main
poolest	doc_101672866015_item	3136947	et	4	main
olid	doc_101672866015_item	3136948	et	4	main
kuulsad	doc_101672866015_item	3136949	et	3	main
mida	doc_101672866015_item	3136950	et	4	main
nendest	doc_101672866015_item	3136951	et	4	main
teatakse	doc_101672866015_item	3136952	et	3	main
tänapäeval	doc_101672866015_item	3136953	et	3	main
1	doc_101672866015_item	3136954	et	2	main
ülivaade	doc_101672866015_item	3136955	et	3	main
harku	doc_101672866015_item	3136956	et	4	main
vald	doc_101672866015_item	3136957	et	3	main
on	doc_101672866015_item	3136958	et	4	main
mereäärne	doc_101672866015_item	3136959	et	3	main
vald	doc_101672866015_item	3136960	et	3	main
lääne-	doc_101672866015_item	3136961	et	4	main
harjumaal	doc_101672866015_item	3136962	et	4	main
tallinna	doc_101672866015_item	3136963	et	4	main
ja	doc_101672866015_item	3136964	et	3	main
keila	doc_101672866015_item	3136965	et	4	main
vahel	doc_101672866015_item	3136966	et	4	main
kuulus	doc_101672866015_item	3136967	et	4	main
keila	doc_101672866015_item	3136968	et	4	main
kihelkonda	doc_101672866015_item	3136969	et	4	main
peale	doc_101672866015_item	3136970	et	4	main
saue	doc_101672866015_item	3136976	et	4	main
ning	doc_101672866015_item	3136977	et	3	main
mõlemad	doc_101672866015_item	3136986	et	3	main
endise	doc_101672866015_item	3136989	et	3	main
kihelkonna	doc_101672866015_item	3136990	et	3	main
tekkis	doc_101672866015_item	3136998	et	3	main
ja	doc_101672866015_item	3137006	et	3	main
tiskre	doc_101672866015_item	3137012	et	4	main
kadaka	doc_101672866015_item	3137017	et	3	main
kuuluvad	doc_101672866015_item	3137029	et	4	main
tabasalu	doc_101672866015_item	3137030	et	4	main
vahi	doc_101672866015_item	3137043	et	4	main
humala	doc_101672866015_item	3137047	et	3	main
viti	doc_101672866015_item	3137053	et	4	main
valla	doc_101672866015_item	3137095	et	4	main
territooriumil	doc_101672866015_item	3137096	et	3	main
kumna	doc_101672866015_item	3137100	et	4	main
ainult	doc_101672866015_item	3137116	et	4	main
ning	doc_101672866015_item	3137120	et	3	main
kohaks	doc_101672866015_item	3137125	et	4	main
kultuurilisi	doc_101672866015_item	3137144	et	4	main
sündmusi	doc_101672866015_item	3137145	et	3	main
aastast	doc_101672866015_item	3137155	et	4	main
aastani	doc_101672866015_item	3137184	et	3	main
vööne	doc_101672866015_item	3137186	et	4	main
breminite	doc_101672866015_item	3137187	et	4	main
omanikeks	doc_101672866015_item	3137197	et	3	main
von	doc_101672866015_item	3137199	et	4	main
aga	doc_101672866015_item	3137207	et	3	main
sattus	doc_101672866015_item	3137210	et	3	main
kaheks	doc_101672866015_item	3137212	et	4	main
stackelbergide	doc_101672866015_item	3137214	et	4	main
strackbergide	doc_101672866015_item	3137224	et	4	main
von	doc_101672866015_item	3137233	et	4	main
stackenbergide	doc_101672866015_item	3137238	et	4	main
otto	doc_101672866015_item	3137242	et	4	main
teadusorganisatsiooni	doc_101672866015_item	3137257	et	4	main
ärkas	doc_101672866015_item	3137263	et	3	main
poja	doc_101672866015_item	3137269	et	4	main
göttingeni	doc_101672866015_item	3137297	et	4	main
ülikooli	doc_101672866015_item	3137300	et	4	main
peale	doc_101672866015_item	3137301	et	4	main
ja	doc_101672866015_item	3137308	et	3	main
itaalias	doc_101672866015_item	3137312	et	4	main
aasias	doc_101672866015_item	3137314	et	4	main
üks	doc_101672866015_item	3137315	et	3	main
kord	doc_101672866015_item	3137316	et	4	main
sattus	doc_101672866015_item	3137317	et	3	main
piraatide	doc_101672866015_item	3137318	et	3	main
kohta	doc_101672866015_item	3137327	et	4	main
avaldas	doc_101672866015_item	3137328	et	3	main
jooksul	doc_101672866015_item	3137336	et	4	main
peter	doc_101672866015_item	3137342	et	4	main
kunstikogusid	doc_101672866015_item	3137347	et	4	main
taani	doc_101672866015_item	3137382	et	4	main
põhjamaade	doc_101672866015_item	3137384	et	3	main
on	doc_101672866015_item	3137389	et	4	main
1825	doc_101672866015_item	3137395	et	2	main
der	doc_101672866015_item	3137396	et	4	main
apollptempel	doc_101672866015_item	3137397	et	4	main
bassa	doc_101672866015_item	3137399	et	4	main
1826	doc_101672866015_item	3137400	et	2	main
topographiques	doc_101672866015_item	3137405	et	4	main
1830	doc_101672866015_item	3137406	et	2	main
22	doc_101672866015_item	3137412	et	2	main
mõisaga	doc_101672866015_item	3137416	et	3	main
seotud	doc_101672866015_item	3137418	et	4	main
üks	doc_101672866015_item	3137419	et	3	main
vääna	doc_101672866015_item	3137435	et	4	main
mõisa	doc_101672866015_item	3137436	et	3	main
sees	doc_101672866015_item	3137437	et	4	main
tunded	doc_101672866015_item	3137442	et	3	main
siit	doc_101672866015_item	3137443	et	3	main
üle	doc_101672866015_item	3137444	et	3	main
käinud	doc_101672866015_item	3137445	et	4	main
ja	doc_101672866015_item	3137446	et	3	main
seal	doc_101672866015_item	3137452	et	4	main
inimesi	doc_101672866015_item	3137454	et	4	main
on	doc_101672866015_item	3137456	et	4	main
vallad	doc_101672866015_item	3136984	et	3	main
hõlmavad	doc_101672866015_item	3136985	et	4	main
veerandi	doc_101672866015_item	3136988	et	4	main
haaras	doc_101672866015_item	3137001	et	4	main
alla	doc_101672866015_item	3137003	et	3	main
ala	doc_101672866015_item	3137005	et	4	main
õismäe	doc_101672866015_item	3137014	et	3	main
taastati	doc_101672866015_item	3137022	et	4	main
1991	doc_101672866015_item	3137025	et	2	main
harku	doc_101672866015_item	3137032	et	4	main
ning	doc_101672866015_item	3137034	et	3	main
sõrve	doc_101672866015_item	3137039	et	4	main
vaila	doc_101672866015_item	3137041	et	4	main
vääna	doc_101672866015_item	3137042	et	4	main
tutermaa	doc_101672866015_item	3137044	et	4	main
kütke	doc_101672866015_item	3137046	et	4	main
suurupi	doc_101672866015_item	3137054	et	4	main
muraste	doc_101672866015_item	3137055	et	4	main
ja	doc_101672866015_item	3137056	et	3	main
ilmandu	doc_101672866015_item	3137057	et	4	main
külad1	doc_101672866015_item	3137058	et	2	main
praeguse	doc_101672866015_item	3137094	et	3	main
1981	doc_101672866015_item	3136999	et	2	main
territooriumist	doc_101672866015_item	3137011	et	4	main
küla	doc_101672866015_item	3137018	et	4	main
valla	doc_101672866015_item	3137020	et	4	main
õigused	doc_101672866015_item	3137021	et	4	main
praegu	doc_101672866015_item	3137027	et	3	main
tiske	doc_101672866015_item	3137036	et	4	main
rannamõisa	doc_101672866015_item	3137037	et	3	main
laabi	doc_101672866015_item	3137038	et	3	main
liikva	doc_101672866015_item	3137040	et	4	main
jõesuu	doc_101672866015_item	3137052	et	4	main
harku	doc_101672866015_item	3137059	et	4	main
valla	doc_101672866015_item	3137060	et	4	main
kaunis	doc_101672866015_item	3137061	et	4	main
loodus	doc_101672866015_item	3137062	et	4	main
tegi	doc_101672866015_item	3137063	et	4	main
temast	doc_101672866015_item	3137064	et	3	main
soositud	doc_101672866015_item	3137065	et	4	main
elu-	doc_101672866015_item	3137066	et	4	main
ja	doc_101672866015_item	3137067	et	3	main
puhkepaiga	doc_101672866015_item	3137068	et	4	main
kevades	doc_101672866015_item	3137069	et	4	main
sügiseni	doc_101672866015_item	3137070	et	3	main
valla	doc_101672866015_item	3137071	et	4	main
elanike	doc_101672866015_item	3137072	et	3	main
arv	doc_101672866015_item	3137073	et	3	main
tänu	doc_101672866015_item	3137074	et	4	main
suvitajatele	doc_101672866015_item	3137075	et	4	main
pea	doc_101672866015_item	3137076	et	4	main
neljakordne	doc_101672866015_item	3137077	et	3	main
harku	doc_101672866015_item	3137078	et	4	main
vald	doc_101672866015_item	3137079	et	3	main
on	doc_101672866015_item	3137080	et	4	main
rikas	doc_101672866015_item	3137081	et	4	main
mõisate	doc_101672866015_item	3137082	et	3	main
poolest	doc_101672866015_item	3137083	et	4	main
kõige	doc_101672866015_item	3137084	et	4	main
esinduslikumad	doc_101672866015_item	3137085	et	4	main
on	doc_101672866015_item	3137086	et	4	main
harku	doc_101672866015_item	3137087	et	4	main
vääna	doc_101672866015_item	3137088	et	4	main
ning	doc_101672866015_item	3137089	et	3	main
muraste	doc_101672866015_item	3137090	et	4	main
vääna-	doc_101672866015_item	3137051	et	4	main
neid	doc_101672866015_item	3137093	et	4	main
ka	doc_101672866015_item	3137098	et	3	main
rannamõisa	doc_101672866015_item	3137103	et	3	main
võib	doc_101672866015_item	3137112	et	3	main
nimetada	doc_101672866015_item	3137114	et	3	main
harku	doc_101672866015_item	3137117	et	4	main
tähendus	doc_101672866015_item	3137129	et	4	main
kõige	doc_101672866015_item	3137136	et	4	main
kool	doc_101672866015_item	3137138	et	4	main
andmed	doc_101672866015_item	3137151	et	3	main
väänast	doc_101672866015_item	3137152	et	4	main
perekonnale	doc_101672866015_item	3137188	et	4	main
hiljem	doc_101672866015_item	3137189	et	3	main
mõisa	doc_101672866015_item	3137196	et	3	main
tiesenhausenid	doc_101672866015_item	3137200	et	4	main
taubed	doc_101672866015_item	3137201	et	4	main
edasi	doc_101672866015_item	3137208	et	3	main
mõisa	doc_101672866015_item	3137209	et	3	main
kätte	doc_101672866015_item	3137215	et	4	main
tuntud	doc_101672866015_item	3137219	et	4	main
kuulasamaid	doc_101672866015_item	3137236	et	4	main
oli	doc_101672866015_item	3137241	et	3	main
magnus	doc_101672866015_item	3137243	et	4	main
von	doc_101672866015_item	3137244	et	4	main
muusika	doc_101672866015_item	3137267	et	4	main
peale	doc_101672866015_item	3137092	et	4	main
lucca	doc_101672866015_item	3137101	et	4	main
peetri	doc_101672866015_item	3137102	et	3	main
pääla	doc_101672866015_item	3137105	et	4	main
2	doc_101672866015_item	3137108	et	2	main
vääna	doc_101672866015_item	3137109	et	4	main
kultuurikeskuseks	doc_101672866015_item	3137119	et	4	main
tulevikku	doc_101672866015_item	3137121	et	4	main
on	doc_101672866015_item	3137127	et	4	main
laiem	doc_101672866015_item	3137128	et	4	main
praegu	doc_101672866015_item	3137133	et	3	main
suurem	doc_101672866015_item	3137137	et	4	main
pärinevad	doc_101672866015_item	3137153	et	4	main
1460	doc_101672866015_item	3137183	et	2	main
kuuluski	doc_101672866015_item	3137185	et	4	main
ostmiste-	doc_101672866015_item	3137191	et	4	main
olnud	doc_101672866015_item	3137198	et	4	main
ja	doc_101672866015_item	3137204	et	3	main
tänapäeval	doc_101672866015_item	3137217	et	3	main
tänuks	doc_101672866015_item	3137223	et	3	main
ajal	doc_101672866015_item	3137225	et	4	main
rajati	doc_101672866015_item	3137226	et	3	main
vääna	doc_101672866015_item	3137227	et	4	main
ainulaadne	doc_101672866015_item	3137228	et	3	main
barokkansambel	doc_101672866015_item	3137229	et	3	main
mehi	doc_101672866015_item	3137237	et	3	main
reas	doc_101672866015_item	3137240	et	3	main
varakult	doc_101672866015_item	3137261	et	4	main
poisil	doc_101672866015_item	3137262	et	3	main
joonistushuvi	doc_101672866015_item	3137270	et	4	main
moskva	doc_101672866015_item	3137299	et	4	main
ka	doc_101672866015_item	3137305	et	3	main
töö-	doc_101672866015_item	3137307	et	4	main
kreekas	doc_101672866015_item	3137310	et	4	main
väike-	doc_101672866015_item	3137313	et	4	main
huvitava	doc_101672866015_item	3137334	et	4	main
alu	doc_101672866015_item	3137335	et	4	main
onu	doc_101672866015_item	3137341	et	4	main
vääna	doc_101672866015_item	3137346	et	4	main
kuningliku	doc_101672866015_item	3137383	et	3	main
muinasteduste	doc_101672866015_item	3137385	et	4	main
liige	doc_101672866015_item	3137386	et	4	main
und	doc_101672866015_item	3137391	et	4	main
der	doc_101672866015_item	3137393	et	4	main
zu	doc_101672866015_item	3137398	et	4	main
grece	doc_101672866015_item	3137401	et	4	main
voes	doc_101672866015_item	3137402	et	3	main
gräben	doc_101672866015_item	3137408	et	4	main
vääna	doc_101672866015_item	3137413	et	4	main
vääna	doc_101672866015_item	3137415	et	4	main
samal	doc_101672866015_item	3137422	et	3	main
ajal	doc_101672866015_item	3137423	et	4	main
kurb	doc_101672866015_item	3137424	et	3	main
armastuslugu	doc_101672866015_item	3137425	et	4	main
mida	doc_101672866015_item	3137426	et	4	main
võib	doc_101672866015_item	3137427	et	3	main
seotud	doc_101672866015_item	3137441	et	4	main
tool	doc_101672866015_item	3137450	et	3	main
von	doc_101672866015_item	3137459	et	4	main
stackelberg	doc_101672866015_item	3137460	et	4	main
brunswik	doc_101672866015_item	3137465	et	4	main
de	doc_101672866015_item	3137466	et	4	main
helilooja	doc_101672866015_item	3137470	et	4	main
ludwig	doc_101672866015_item	3137472	et	4	main
van	doc_101672866015_item	3137473	et	4	main
loo	doc_101672866015_item	3137477	et	4	main
nad	doc_101672866015_item	3137499	et	3	main
tõlgitud	doc_101672866015_item	3137502	et	4	main
see	doc_101672866015_item	3137504	et	3	main
romaan	doc_101672866015_item	3137505	et	3	main
alguse	doc_101672866015_item	3137506	et	3	main
sai	doc_101672866015_item	3137507	et	4	main
kuidas	doc_101672866015_item	3137508	et	3	main
arenes	doc_101672866015_item	3137509	et	3	main
missugune	doc_101672866015_item	3137510	et	3	main
lõpp	doc_101672866015_item	3137511	et	3	main
tal	doc_101672866015_item	3137512	et	3	main
nende	doc_101672866015_item	3137521	et	4	main
neid	doc_101672866015_item	3137525	et	4	main
edasi	doc_101672866015_item	3137529	et	3	main
tundeid	doc_101672866015_item	3137532	et	3	main
nende	doc_101672866015_item	3137535	et	4	main
humala	doc_101672866015_item	3137099	et	3	main
vääna	doc_101672866015_item	3137110	et	4	main
mõisa	doc_101672866015_item	3137111	et	3	main
valla	doc_101672866015_item	3137118	et	4	main
vaid	doc_101672866015_item	3137123	et	3	main
kogu	doc_101672866015_item	3137130	et	4	main
kultuurile	doc_101672866015_item	3137132	et	3	main
asub	doc_101672866015_item	3137135	et	3	main
harku	doc_101672866015_item	3137139	et	4	main
vallas	doc_101672866015_item	3137140	et	3	main
ning	doc_101672866015_item	3137141	et	3	main
enamik	doc_101672866015_item	3137142	et	3	main
valla	doc_101672866015_item	3137143	et	4	main
audentsed	doc_101672866015_item	3137150	et	4	main
kui	doc_101672866015_item	3137156	et	3	main
padise	doc_101672866015_item	3137157	et	4	main
kloostri	doc_101672866015_item	3137158	et	3	main
munkade	doc_101672866015_item	3137159	et	3	main
asustatud	doc_101672866015_item	3137160	et	4	main
kloostrimõisast	doc_101672866015_item	3137161	et	4	main
vanimad	doc_101672866015_item	3137162	et	3	main
kirjalikud	doc_101672866015_item	3137163	et	3	main
teated2	doc_101672866015_item	3137164	et	2	main
väänast	doc_101672866015_item	3137165	et	4	main
pärinevad	doc_101672866015_item	3137166	et	4	main
aga	doc_101672866015_item	3137167	et	3	main
1325	doc_101672866015_item	3137168	et	2	main
aastast	doc_101672866015_item	3137169	et	4	main
millal	doc_101672866015_item	3137170	et	3	main
sai	doc_101672866015_item	3137171	et	4	main
hermann	doc_101672866015_item	3137172	et	4	main
bremen	doc_101672866015_item	3137173	et	4	main
koos	doc_101672866015_item	3137174	et	4	main
vendade	doc_101672866015_item	3137175	et	3	main
tile	doc_101672866015_item	3137176	et	4	main
ja	doc_101672866015_item	3137177	et	3	main
rotkeriga	doc_101672866015_item	3137178	et	4	main
taani	doc_101672866015_item	3137179	et	4	main
kuningalt	doc_101672866015_item	3137180	et	4	main
kuus	doc_101672866015_item	3137181	et	4	main
küla	doc_101672866015_item	3137182	et	4	main
frommholdid	doc_101672866015_item	3137202	et	4	main
sealt	doc_101672866015_item	3137206	et	4	main
ligi	doc_101672866015_item	3137211	et	3	main
aastasajaks	doc_101672866015_item	3137213	et	3	main
perekonna	doc_101672866015_item	3137222	et	4	main
otto	doc_101672866015_item	3137232	et	4	main
üks	doc_101672866015_item	3137235	et	3	main
pikas	doc_101672866015_item	3137239	et	4	main
kes	doc_101672866015_item	3137247	et	4	main
oli	doc_101672866015_item	3137248	et	3	main
rahvusvaheliselt	doc_101672866015_item	3137249	et	4	main
tuntud	doc_101672866015_item	3137250	et	4	main
kunstnik	doc_101672866015_item	3137251	et	3	main
arheoloog	doc_101672866015_item	3137252	et	3	main
ja	doc_101672866015_item	3137253	et	3	main
antiikajaloo	doc_101672866015_item	3137254	et	4	main
liige	doc_101672866015_item	3137258	et	4	main
juba	doc_101672866015_item	3137259	et	3	main
lapsepõlvest	doc_101672866015_item	3137260	et	4	main
vastu	doc_101672866015_item	3137268	et	3	main
kutsus	doc_101672866015_item	3137272	et	4	main
neid	doc_101672866015_item	3137302	et	4	main
parun	doc_101672866015_item	3137303	et	3	main
viibis	doc_101672866015_item	3137304	et	3	main
konstantinoopolis	doc_101672866015_item	3137311	et	4	main
oluliselt	doc_101672866015_item	3137339	et	4	main
oma	doc_101672866015_item	3137340	et	4	main
dückeri	doc_101672866015_item	3137344	et	4	main
asutatud	doc_101672866015_item	3137345	et	4	main
raamatukogu	doc_101672866015_item	3137349	et	4	main
tähtsamad	doc_101672866015_item	3137387	et	4	main
trachten	doc_101672866015_item	3137390	et	4	main
neugriechen	doc_101672866015_item	3137394	et	4	main
der	doc_101672866015_item	3137409	et	4	main
on	doc_101672866015_item	3137417	et	4	main
kaunis	doc_101672866015_item	3137420	et	4	main
kuid	doc_101672866015_item	3137438	et	4	main
selle	doc_101672866015_item	3137439	et	4	main
kindlasti	doc_101672866015_item	3137448	et	3	main
adam	doc_101672866015_item	3137458	et	4	main
von	doc_101672866015_item	3137464	et	4	main
kuulus	doc_101672866015_item	3137469	et	4	main
oli	doc_101672866015_item	3137513	et	3	main
neile	doc_101672866015_item	3137514	et	4	main
kirjadest	doc_101672866015_item	3137522	et	3	main
sest	doc_101672866015_item	3137523	et	4	main
kurbust	doc_101672866015_item	3137539	et	4	main
221	doc_101672866015_item	3137540	et	2	main
korompa4	doc_101672866015_item	3137545	et	2	main
väga	doc_101672866015_item	3137548	et	3	main
aja	doc_101672866015_item	3137571	et	4	main
müümiste	doc_101672866015_item	3137192	et	4	main
ja	doc_101672866015_item	3137193	et	3	main
pärimiste	doc_101672866015_item	3137194	et	4	main
teel	doc_101672866015_item	3137195	et	4	main
maydellid	doc_101672866015_item	3137203	et	4	main
dückerid	doc_101672866015_item	3137205	et	4	main
ning	doc_101672866015_item	3137216	et	3	main
on	doc_101672866015_item	3137218	et	4	main
just	doc_101672866015_item	3137220	et	3	main
selle	doc_101672866015_item	3137221	et	4	main
21	doc_101672866015_item	3137230	et	2	main
parun	doc_101672866015_item	3137231	et	3	main
strackelberg	doc_101672866015_item	3137234	et	4	main
stackenberg	doc_101672866015_item	3137245	et	4	main
1786-18373	doc_101672866015_item	3137246	et	2	main
uurija	doc_101672866015_item	3137255	et	4	main
mitme	doc_101672866015_item	3137256	et	4	main
huvi	doc_101672866015_item	3137264	et	4	main
kunsti	doc_101672866015_item	3137265	et	4	main
ja	doc_101672866015_item	3137266	et	3	main
arendamiseks	doc_101672866015_item	3137271	et	4	main
ema	doc_101672866015_item	3137273	et	4	main
talle	doc_101672866015_item	3137274	et	4	main
saksamaalt	doc_101672866015_item	3137275	et	3	main
õpetajaks	doc_101672866015_item	3137276	et	4	main
kunstnik	doc_101672866015_item	3137277	et	3	main
p	doc_101672866015_item	3137278	et	4	main
j	doc_101672866015_item	3137279	et	4	main
neusi	doc_101672866015_item	3137280	et	4	main
suguvõsa	doc_101672866015_item	3137281	et	4	main
nimekate	doc_101672866015_item	3137282	et	4	main
sõjaväelaste	doc_101672866015_item	3137283	et	4	main
ja	doc_101672866015_item	3137284	et	3	main
diplomaatide	doc_101672866015_item	3137285	et	3	main
eeskujul	doc_101672866015_item	3137286	et	3	main
pidi	doc_101672866015_item	3137287	et	4	main
otto	doc_101672866015_item	3137288	et	4	main
magnusest	doc_101672866015_item	3137289	et	4	main
saama	doc_101672866015_item	3137290	et	4	main
diplomaat	doc_101672866015_item	3137291	et	3	main
õpingud	doc_101672866015_item	3137292	et	3	main
viisid	doc_101672866015_item	3137293	et	4	main
ta	doc_101672866015_item	3137294	et	4	main
halle	doc_101672866015_item	3137295	et	4	main
pedagoogiumi	doc_101672866015_item	3137296	et	4	main
pikkadel	doc_101672866015_item	3137306	et	4	main
teadusreisidel	doc_101672866015_item	3137309	et	3	main
kätte	doc_101672866015_item	3137319	et	4	main
ning	doc_101672866015_item	3137320	et	3	main
oli	doc_101672866015_item	3137321	et	3	main
mõne	doc_101672866015_item	3137322	et	3	main
aja	doc_101672866015_item	3137323	et	4	main
nende	doc_101672866015_item	3137324	et	4	main
vang	doc_101672866015_item	3137325	et	3	main
antiikkunsti	doc_101672866015_item	3137326	et	4	main
enda	doc_101672866015_item	3137330	et	4	main
illustreeritud	doc_101672866015_item	3137331	et	4	main
ta	doc_101672866015_item	3137337	et	4	main
täiendas	doc_101672866015_item	3137338	et	3	main
v	doc_101672866015_item	3137343	et	4	main
tema	doc_101672866015_item	3137350	et	4	main
gebräuche	doc_101672866015_item	3137392	et	4	main
ja	doc_101672866015_item	3137298	et	3	main
ta	doc_101672866015_item	3137329	et	4	main
teoseid	doc_101672866015_item	3137332	et	3	main
oma	doc_101672866015_item	3137333	et	4	main
ja	doc_101672866015_item	3137348	et	3	main
joonistuste	doc_101672866015_item	3137351	et	4	main
järgi	doc_101672866015_item	3137352	et	4	main
ehitati	doc_101672866015_item	3137353	et	3	main
keila	doc_101672866015_item	3137354	et	4	main
kirikuaeda	doc_101672866015_item	3137355	et	4	main
kirikuaeda	doc_101672866015_item	3137356	et	4	main
stackelbergide	doc_101672866015_item	3137357	et	4	main
perekonna	doc_101672866015_item	3137358	et	4	main
kabel-mausoleum	doc_101672866015_item	3137359	et	3	main
eriti	doc_101672866015_item	3137360	et	3	main
otto	doc_101672866015_item	3137361	et	4	main
magnuse	doc_101672866015_item	3137362	et	4	main
huvitasid	doc_101672866015_item	3137363	et	4	main
antiikkunst	doc_101672866015_item	3137364	et	3	main
ja	doc_101672866015_item	3137365	et	3	main
maastikumaal	doc_101672866015_item	3137366	et	4	main
ta	doc_101672866015_item	3137367	et	4	main
esines	doc_101672866015_item	3137368	et	3	main
mitmete	doc_101672866015_item	3137369	et	4	main
kunstiühingute	doc_101672866015_item	3137370	et	3	main
töös	doc_101672866015_item	3137371	et	3	main
näiteks	doc_101672866015_item	3137372	et	4	main
itaalias	doc_101672866015_item	3137373	et	4	main
oli	doc_101672866015_item	3137374	et	3	main
instutio	doc_101672866015_item	3137375	et	4	main
archeolgico	doc_101672866015_item	3137376	et	4	main
kaasasutaja	doc_101672866015_item	3137377	et	4	main
berliini	doc_101672866015_item	3137378	et	4	main
kunstide	doc_101672866015_item	3137379	et	3	main
akadeemia	doc_101672866015_item	3137380	et	4	main
liige	doc_101672866015_item	3137381	et	4	main
tööd	doc_101672866015_item	3137388	et	4	main
pittoresques	doc_101672866015_item	3137403	et	4	main
et	doc_101672866015_item	3137404	et	3	main
hellenen	doc_101672866015_item	3137410	et	4	main
1837	doc_101672866015_item	3137411	et	2	main
ja	doc_101672866015_item	3137421	et	3	main
küll	doc_101672866015_item	3137434	et	4	main
looga	doc_101672866015_item	3137440	et	4	main
mõjutasid	doc_101672866015_item	3137449	et	4	main
elavaid	doc_101672866015_item	3137453	et	4	main
peategelasteks	doc_101672866015_item	3137455	et	3	main
naine	doc_101672866015_item	3137462	et	3	main
josephine	doc_101672866015_item	3137463	et	4	main
eesti	doc_101672866015_item	3137497	et	4	main
ole	doc_101672866015_item	3137501	et	4	main
kust	doc_101672866015_item	3137503	et	4	main
toon	doc_101672866015_item	3137519	et	4	main
väljalõigud	doc_101672866015_item	3137520	et	3	main
lugemata	doc_101672866015_item	3137526	et	4	main
ja	doc_101672866015_item	3137533	et	3	main
kes	doc_101672866015_item	3137558	et	4	main
1158	doc_101672866015_item	3137560	et	2	main
aastal	doc_101672866015_item	3137561	et	3	main
müncheni	doc_101672866015_item	3137562	et	4	main
surematu	doc_101672866015_item	3137601	et	4	main
saladus	doc_101672866015_item	3137602	et	3	main
üle	doc_101672866015_item	3137604	et	3	main
esitakse	doc_101672866015_item	3137607	et	3	main
lugu	doc_101672866015_item	3137611	et	4	main
algas	doc_101672866015_item	3137615	et	3	main
kes	doc_101672866015_item	3137634	et	4	main
on	doc_101672866015_item	3137635	et	4	main
see	doc_101672866015_item	3137636	et	3	main
saladuslik	doc_101672866015_item	3137637	et	3	main
naine	doc_101672866015_item	3137638	et	3	main
sellise	doc_101672866015_item	3137644	et	4	main
tõepoolest	doc_101672866015_item	3137653	et	3	main
just	doc_101672866015_item	3137654	et	3	main
josephine	doc_101672866015_item	3137655	et	4	main
oligi	doc_101672866015_item	3137656	et	3	main
aga	doc_101672866015_item	3137661	et	3	main
kui	doc_101672866015_item	3137662	et	3	main
lugeda	doc_101672866015_item	3137663	et	3	main
see	doc_101672866015_item	3137667	et	3	main
üks	doc_101672866015_item	3137678	et	3	main
kirjadest	doc_101672866015_item	3137680	et	3	main
mu	doc_101672866015_item	3137685	et	3	main
mu	doc_101672866015_item	3137687	et	3	main
alles	doc_101672866015_item	3137692	et	3	main
ridadega	doc_101672866015_item	3137697	et	3	main
geliebten	doc_101672866015_item	3137701	et	4	main
igavesti	doc_101672866015_item	3137702	et	4	main
sinu	doc_101672866015_item	3137703	et	3	main
igavesti	doc_101672866015_item	3137706	et	4	main
mein	doc_101672866015_item	3137709	et	4	main
igavesti	doc_101672866015_item	3137710	et	4	main
josephine	doc_101672866015_item	3137716	et	4	main
kui	doc_101672866015_item	3137725	et	3	main
von	doc_101672866015_item	3137731	et	4	main
koos	doc_101672866015_item	3137735	et	4	main
neile	doc_101672866015_item	3137742	et	4	main
neiud	doc_101672866015_item	3137746	et	4	main
toolajal	doc_101672866015_item	3137748	et	4	main
juba	doc_101672866015_item	3137749	et	3	main
tuntud	doc_101672866015_item	3137750	et	4	main
juures	doc_101672866015_item	3137755	et	4	main
kiiresti	doc_101672866015_item	3137759	et	3	main
joseph	doc_101672866015_item	3137765	et	4	main
von	doc_101672866015_item	3137778	et	4	main
kirju	doc_101672866015_item	3137797	et	4	main
mees	doc_101672866015_item	3137799	et	4	main
joseph	doc_101672866015_item	3137800	et	4	main
võib	doc_101672866015_item	3137806	et	3	main
multimeediakeskuseks	doc_101672866015_item	3137809	et	4	main
mängivat	doc_101672866015_item	3137821	et	4	main
hispaania	doc_101672866015_item	3137822	et	4	main
elusuuruses	doc_101672866015_item	3137825	et	4	main
isemängiva	doc_101672866015_item	3137827	et	3	main
mängivad	doc_101672866015_item	3137843	et	4	main
muusikat	doc_101672866015_item	3137845	et	3	main
järel	doc_101672866015_item	3137853	et	4	main
die	doc_101672866015_item	3137407	et	4	main
tragöödia	doc_101672866015_item	3137414	et	4	main
isegi	doc_101672866015_item	3137428	et	4	main
tragöödiaks	doc_101672866015_item	3137429	et	3	main
nimetada	doc_101672866015_item	3137430	et	3	main
see	doc_101672866015_item	3137431	et	3	main
pole	doc_101672866015_item	3137432	et	3	main
toimud	doc_101672866015_item	3137433	et	3	main
mis	doc_101672866015_item	3137447	et	4	main
ajal	doc_101672866015_item	3137451	et	4	main
beethoven	doc_101672866015_item	3137474	et	4	main
peamine	doc_101672866015_item	3137475	et	3	main
on	doc_101672866015_item	3137479	et	4	main
kirjad	doc_101672866015_item	3137480	et	4	main
mida	doc_101672866015_item	3137481	et	4	main
kirjutasid	doc_101672866015_item	3137482	et	4	main
kaks	doc_101672866015_item	3137483	et	3	main
armastajad	doc_101672866015_item	3137484	et	4	main
ehk	doc_101672866015_item	3137485	et	3	main
josephine	doc_101672866015_item	3137486	et	4	main
ja	doc_101672866015_item	3137487	et	3	main
beethoven	doc_101672866015_item	3137488	et	4	main
kahjuks	doc_101672866015_item	3137489	et	4	main
nad	doc_101672866015_item	3137490	et	3	main
on	doc_101672866015_item	3137491	et	4	main
kirjutatud	doc_101672866015_item	3137492	et	4	main
inglise-	doc_101672866015_item	3137493	et	4	main
ja	doc_101672866015_item	3137494	et	3	main
ning	doc_101672866015_item	3137496	et	3	main
saksakeeltes	doc_101672866015_item	3137495	et	3	main
keelesse	doc_101672866015_item	3137498	et	4	main
on	doc_101672866015_item	3137527	et	4	main
raske	doc_101672866015_item	3137528	et	4	main
anda	doc_101672866015_item	3137530	et	3	main
loomu	doc_101672866015_item	3137534	et	4	main
armastuse	doc_101672866015_item	3137536	et	4	main
sügavust	doc_101672866015_item	3137537	et	4	main
ja	doc_101672866015_item	3137538	et	3	main
de	doc_101672866015_item	3137544	et	4	main
oli	doc_101672866015_item	3137546	et	3	main
vanast	doc_101672866015_item	3137549	et	3	main
henrich	doc_101672866015_item	3137555	et	4	main
des	doc_101672866015_item	3137556	et	4	main
löwen	doc_101672866015_item	3137557	et	4	main
oli	doc_101672866015_item	3137564	et	3	main
pianist	doc_101672866015_item	3137566	et	3	main
koos	doc_101672866015_item	3137569	et	4	main
selle	doc_101672866015_item	3137570	et	4	main
biograafide	doc_101672866015_item	3137599	et	4	main
jaoks	doc_101672866015_item	3137600	et	4	main
järjest	doc_101672866015_item	3137608	et	4	main
armastusest	doc_101672866015_item	3137614	et	4	main
helilooja	doc_101672866015_item	3137616	et	4	main
ja	doc_101672866015_item	3137632	et	3	main
oma	doc_101672866015_item	3137642	et	4	main
tunnetest	doc_101672866015_item	3137643	et	3	main
ei	doc_101672866015_item	3137648	et	4	main
helilooja	doc_101672866015_item	3137657	et	4	main
nende	doc_101672866015_item	3137664	et	4	main
näeb	doc_101672866015_item	3137668	et	3	main
on	doc_101672866015_item	3137672	et	4	main
nendest	doc_101672866015_item	3137679	et	4	main
algas	doc_101672866015_item	3137681	et	3	main
mu	doc_101672866015_item	3137683	et	3	main
christoph	doc_101672866015_item	3137457	et	4	main
tema	doc_101672866015_item	3137461	et	4	main
korompa	doc_101672866015_item	3137467	et	4	main
ning	doc_101672866015_item	3137468	et	3	main
franz	doc_101672866015_item	3137471	et	4	main
selle	doc_101672866015_item	3137476	et	4	main
tõestusmaterjal	doc_101672866015_item	3137478	et	3	main
ei	doc_101672866015_item	3137500	et	4	main
küsimustele	doc_101672866015_item	3137515	et	4	main
ma	doc_101672866015_item	3137516	et	3	main
püüan	doc_101672866015_item	3137517	et	3	main
vastata	doc_101672866015_item	3137518	et	4	main
ilma	doc_101672866015_item	3137524	et	4	main
peategelaste	doc_101672866015_item	3137531	et	3	main
salapärane	doc_101672866015_item	3137541	et	4	main
salalaekas	doc_101672866015_item	3137542	et	3	main
josephine	doc_101672866015_item	3137563	et	4	main
hea	doc_101672866015_item	3137565	et	4	main
suareedel	doc_101672866015_item	3137568	et	3	main
viini	doc_101672866015_item	3137572	et	4	main
tippmuusikutega	doc_101672866015_item	3137573	et	3	main
naine	doc_101672866015_item	3137574	et	3	main
oli	doc_101672866015_item	3137575	et	3	main
franz	doc_101672866015_item	3137576	et	4	main
ludwig	doc_101672866015_item	3137577	et	4	main
van	doc_101672866015_item	3137578	et	4	main
beethoveni	doc_101672866015_item	3137579	et	4	main
õpilane	doc_101672866015_item	3137580	et	3	main
josephine	doc_101672866015_item	3137581	et	4	main
on	doc_101672866015_item	3137582	et	4	main
peetud	doc_101672866015_item	3137583	et	4	main
paljude	doc_101672866015_item	3137584	et	3	main
teiste	doc_101672866015_item	3137585	et	4	main
kandidaatide	doc_101672866015_item	3137586	et	3	main
seas	doc_101672866015_item	3137587	et	4	main
bethooveni	doc_101672866015_item	3137588	et	4	main
surematuks	doc_101672866015_item	3137589	et	4	main
armastuseks	doc_101672866015_item	3137590	et	4	main
geliebte	doc_101672866015_item	3137592	et	4	main
mis	doc_101672866015_item	3137593	et	4	main
omakorda	doc_101672866015_item	3137594	et	3	main
unsterbliche	doc_101672866015_item	3137591	et	4	main
on	doc_101672866015_item	3137595	et	4	main
muusikateadlaste	doc_101672866015_item	3137596	et	3	main
uusi	doc_101672866015_item	3137609	et	3	main
beethoveni	doc_101672866015_item	3137612	et	4	main
mida	doc_101672866015_item	3137618	et	4	main
leiti	doc_101672866015_item	3137622	et	3	main
salalaekast	doc_101672866015_item	3137625	et	4	main
tihti	doc_101672866015_item	3137630	et	3	main
armastusega	doc_101672866015_item	3137645	et	4	main
saa	doc_101672866015_item	3137649	et	4	main
täpselt	doc_101672866015_item	3137650	et	4	main
öelda	doc_101672866015_item	3137651	et	4	main
kas	doc_101672866015_item	3137652	et	3	main
siis	doc_101672866015_item	3137666	et	3	main
tõenäolisena	doc_101672866015_item	3137670	et	4	main
sõnadega	doc_101672866015_item	3137682	et	3	main
mina	doc_101672866015_item	3137688	et	4	main
mein	doc_101672866015_item	3137689	et	4	main
ich	doc_101672866015_item	3137694	et	4	main
ja	doc_101672866015_item	3137695	et	3	main
lõppes	doc_101672866015_item	3137696	et	4	main
krahvinna	doc_101672866015_item	3137543	et	4	main
pärit	doc_101672866015_item	3137547	et	3	main
aadlisoost	doc_101672866015_item	3137550	et	4	main
tema	doc_101672866015_item	3137551	et	4	main
esivanemaks	doc_101672866015_item	3137552	et	4	main
oli	doc_101672866015_item	3137553	et	3	main
näiteks	doc_101672866015_item	3137554	et	4	main
asutas	doc_101672866015_item	3137559	et	3	main
esines	doc_101672866015_item	3137567	et	3	main
ja	doc_101672866015_item	3137597	et	3	main
vaieldakse	doc_101672866015_item	3137605	et	3	main
versioone	doc_101672866015_item	3137610	et	3	main
kirjadest	doc_101672866015_item	3137617	et	3	main
pärast	doc_101672866015_item	3137619	et	4	main
ta	doc_101672866015_item	3137620	et	4	main
uurisid	doc_101672866015_item	3137631	et	4	main
mõtisklesid	doc_101672866015_item	3137633	et	4	main
kellele	doc_101672866015_item	3137639	et	4	main
beethoven	doc_101672866015_item	3137640	et	4	main
traagikaga	doc_101672866015_item	3137647	et	3	main
kuulus	doc_101672866015_item	3137658	et	4	main
kirju	doc_101672866015_item	3137665	et	4	main
muidu	doc_101672866015_item	3137671	et	3	main
raske	doc_101672866015_item	3137673	et	4	main
seletada	doc_101672866015_item	3137674	et	3	main
nende	doc_101672866015_item	3137675	et	4	main
kirjade	doc_101672866015_item	3137676	et	3	main
ingel	doc_101672866015_item	3137684	et	3	main
kõik	doc_101672866015_item	3137686	et	4	main
deines	doc_101672866015_item	3137700	et	4	main
dein	doc_101672866015_item	3137705	et	4	main
ewing	doc_101672866015_item	3137708	et	4	main
unss	doc_101672866015_item	3137713	et	4	main
tutvustus	doc_101672866015_item	3137723	et	4	main
aasta	doc_101672866015_item	3137727	et	4	main
brunswick	doc_101672866015_item	3137732	et	4	main
tuleb	doc_101672866015_item	3137734	et	3	main
kahe	doc_101672866015_item	3137736	et	3	main
oma	doc_101672866015_item	3137737	et	4	main
tütardega	doc_101672866015_item	3137738	et	3	main
ungarist	doc_101672866015_item	3137739	et	4	main
peigmehed	doc_101672866015_item	3137743	et	3	main
helilooja	doc_101672866015_item	3137751	et	4	main
ludwig	doc_101672866015_item	3137752	et	4	main
võtta	doc_101672866015_item	3137757	et	3	main
nende	doc_101672866015_item	3137773	et	4	main
pühendab	doc_101672866015_item	3137775	et	3	main
beethoven	doc_101672866015_item	3137776	et	4	main
josephine	doc_101672866015_item	3137777	et	4	main
laulev	doc_101672866015_item	3137817	et	4	main
kanaarilind	doc_101672866015_item	3137818	et	3	main
kaks	doc_101672866015_item	3137819	et	3	main
isikute	doc_101672866015_item	3137833	et	4	main
büstid	doc_101672866015_item	3137834	et	3	main
antiikkujude	doc_101672866015_item	3137835	et	3	main
koopiat	doc_101672866015_item	3137836	et	3	main
mis	doc_101672866015_item	3137842	et	4	main
kellega	doc_101672866015_item	3137846	et	3	main
deyem	doc_101672866015_item	3137848	et	4	main
beethoveni	doc_101672866015_item	3137855	et	4	main
ja	doc_101672866015_item	3137856	et	3	main
perekonna	doc_101672866015_item	3137857	et	4	main
põhjas	doc_101672866015_item	3137901	et	4	main
ta	doc_101672866015_item	3137902	et	4	main
on	doc_101672866015_item	3137903	et	4	main
lootnud	doc_101672866015_item	3137904	et	4	main
kaasvara	doc_101672866015_item	3137910	et	4	main
tuleb	doc_101672866015_item	3137911	et	3	main
rikas	doc_101672866015_item	3137916	et	4	main
ennast	doc_101672866015_item	3137922	et	4	main
abielust	doc_101672866015_item	3137924	et	3	main
lahutaks	doc_101672866015_item	3137925	et	3	main
sellel	doc_101672866015_item	3137932	et	4	main
raskel	doc_101672866015_item	3137933	et	3	main
josephine	doc_101672866015_item	3137943	et	4	main
masendatud	doc_101672866015_item	3137958	et	4	main
ja	doc_101672866015_item	3137959	et	3	main
läbi	doc_101672866015_item	3137960	et	4	main
krahvina	doc_101672866015_item	3137967	et	3	main
paraneb	doc_101672866015_item	3137970	et	3	main
oma	doc_101672866015_item	3137974	et	4	main
bethooveni	doc_101672866015_item	3137598	et	4	main
mille	doc_101672866015_item	3137603	et	3	main
ja	doc_101672866015_item	3137606	et	3	main
surematu	doc_101672866015_item	3137613	et	4	main
surma	doc_101672866015_item	3137621	et	4	main
tema	doc_101672866015_item	3137623	et	4	main
kirjutuslaua	doc_101672866015_item	3137624	et	3	main
sellest	doc_101672866015_item	3137626	et	4	main
ajast	doc_101672866015_item	3137627	et	4	main
peale	doc_101672866015_item	3137628	et	4	main
muusikateadlased	doc_101672866015_item	3137629	et	3	main
kirjutas	doc_101672866015_item	3137641	et	3	main
ja	doc_101672866015_item	3137646	et	3	main
surematu	doc_101672866015_item	3137659	et	4	main
armastus	doc_101672866015_item	3137660	et	4	main
väga	doc_101672866015_item	3137669	et	3	main
olemasolu	doc_101672866015_item	3137677	et	4	main
mein	doc_101672866015_item	3137693	et	4	main
meie	doc_101672866015_item	3137711	et	4	main
de	doc_101672866015_item	3137717	et	4	main
1752-1830	doc_101672866015_item	3137733	et	2	main
leida	doc_101672866015_item	3137744	et	3	main
hakkavad	doc_101672866015_item	3137747	et	4	main
leiab	doc_101672866015_item	3137760	et	3	main
sobilikku	doc_101672866015_item	3137762	et	4	main
ehk	doc_101672866015_item	3137764	et	3	main
deymi	doc_101672866015_item	3137766	et	4	main
kellega	doc_101672866015_item	3137767	et	3	main
ta	doc_101672866015_item	3137768	et	4	main
1799	doc_101672866015_item	3137769	et	2	main
aastal	doc_101672866015_item	3137770	et	3	main
tüdruk	doc_101672866015_item	3137771	et	3	main
abiellubki	doc_101672866015_item	3137772	et	3	main
deymile	doc_101672866015_item	3137802	et	4	main
peab	doc_101672866015_item	3137803	et	4	main
omaaegseks	doc_101672866015_item	3137808	et	4	main
keskuses	doc_101672866015_item	3137810	et	4	main
on	doc_101672866015_item	3137811	et	4	main
eksootilised	doc_101672866015_item	3137812	et	3	main
ja	doc_101672866015_item	3137813	et	3	main
heroilised	doc_101672866015_item	3137814	et	3	main
vahakujud-	doc_101672866015_item	3137815	et	3	main
mehaaniline	doc_101672866015_item	3137816	et	3	main
riietuses	doc_101672866015_item	3137823	et	4	main
negližees	doc_101672866015_item	3137826	et	2	main
ees	doc_101672866015_item	3137829	et	4	main
istuv	doc_101672866015_item	3137830	et	4	main
naine	doc_101672866015_item	3137831	et	3	main
kõrgeltsündinud	doc_101672866015_item	3137832	et	3	main
joseph	doc_101672866015_item	3137847	et	4	main
oli	doc_101672866015_item	3137849	et	3	main
isiklikult	doc_101672866015_item	3137850	et	4	main
tuttav	doc_101672866015_item	3137851	et	3	main
abiellumise	doc_101672866015_item	3137852	et	3	main
deymi	doc_101672866015_item	3137858	et	4	main
saanud	doc_101672866015_item	3137907	et	4	main
josephine	doc_101672866015_item	3137917	et	4	main
on	doc_101672866015_item	3137931	et	4	main
josephine	doc_101672866015_item	3137935	et	4	main
mees	doc_101672866015_item	3137944	et	4	main
sureb	doc_101672866015_item	3137945	et	3	main
lapse	doc_101672866015_item	3137952	et	4	main
naine	doc_101672866015_item	3137955	et	3	main
üksi	doc_101672866015_item	3137957	et	4	main
rahalised	doc_101672866015_item	3137963	et	4	main
probleemid	doc_101672866015_item	3137964	et	3	main
novembriks	doc_101672866015_item	3137966	et	3	main
seisund	doc_101672866015_item	3137969	et	3	main
ta	doc_101672866015_item	3137972	et	4	main
kodus	doc_101672866015_item	3137975	et	4	main
almost	doc_101672866015_item	3137995	et	4	main
gives	doc_101672866015_item	3138000	et	4	main
composing	doc_101672866015_item	3138011	et	4	main
an	doc_101672866015_item	3138012	et	4	main
selections	doc_101672866015_item	3138019	et	4	main
aina	doc_101672866015_item	3138032	et	4	main
aastal	doc_101672866015_item	3138037	et	3	main
klaversonaati	doc_101672866015_item	3138039	et	4	main
23	doc_101672866015_item	3138041	et	2	main
franz	doc_101672866015_item	3138042	et	4	main
therese	doc_101672866015_item	3138052	et	4	main
brunswikile	doc_101672866015_item	3138054	et	4	main
umbest	doc_101672866015_item	3138055	et	4	main
traagilisus	doc_101672866015_item	3138061	et	4	main
tema	doc_101672866015_item	3138099	et	4	main
kus	doc_101672866015_item	3138101	et	3	main
on	doc_101672866015_item	3138103	et	4	main
sõnadele	doc_101672866015_item	3138110	et	3	main
your	doc_101672866015_item	3138122	et	4	main
nende	doc_101672866015_item	3138129	et	4	main
beethoven	doc_101672866015_item	3138138	et	4	main
patroon	doc_101672866015_item	3138141	et	3	main
engel	doc_101672866015_item	3137690	et	4	main
mein	doc_101672866015_item	3137691	et	4	main
armastatu	doc_101672866015_item	3137699	et	4	main
minu	doc_101672866015_item	3137707	et	3	main
ewing	doc_101672866015_item	3137712	et	4	main
222	doc_101672866015_item	3137714	et	2	main
armastuslugu	doc_101672866015_item	3137715	et	4	main
beethoveni	doc_101672866015_item	3137720	et	4	main
õpilane	doc_101672866015_item	3137721	et	3	main
nende	doc_101672866015_item	3137722	et	4	main
1799	doc_101672866015_item	3137726	et	2	main
mais	doc_101672866015_item	3137728	et	4	main
ema	doc_101672866015_item	3137729	et	4	main
anna	doc_101672866015_item	3137730	et	4	main
et	doc_101672866015_item	3137741	et	3	main
klaveritunde	doc_101672866015_item	3137756	et	4	main
josephinale	doc_101672866015_item	3137761	et	4	main
mehe	doc_101672866015_item	3137763	et	3	main
sinu	doc_101672866015_item	3137698	et	3	main
ewing	doc_101672866015_item	3137704	et	4	main
korompa	doc_101672866015_item	3137718	et	4	main
on	doc_101672866015_item	3137719	et	4	main
algab	doc_101672866015_item	3137724	et	3	main
viini	doc_101672866015_item	3137740	et	4	main
viinis	doc_101672866015_item	3137745	et	3	main
van	doc_101672866015_item	3137753	et	4	main
beethoveni	doc_101672866015_item	3137754	et	4	main
ema	doc_101672866015_item	3137758	et	4	main
pulmadeks	doc_101672866015_item	3137774	et	3	main
deymile	doc_101672866015_item	3137779	et	4	main
ja	doc_101672866015_item	3137780	et	3	main
tema	doc_101672866015_item	3137781	et	4	main
õele	doc_101672866015_item	3137782	et	3	main
variationen	doc_101672866015_item	3137783	et	4	main
über	doc_101672866015_item	3137784	et	4	main
ich	doc_101672866015_item	3137785	et	4	main
denke	doc_101672866015_item	3137786	et	4	main
dein	doc_101672866015_item	3137787	et	4	main
muusikapalu	doc_101672866015_item	3137788	et	4	main
ning	doc_101672866015_item	3137789	et	3	main
isegi	doc_101672866015_item	3137790	et	4	main
pärast	doc_101672866015_item	3137791	et	4	main
josephine	doc_101672866015_item	3137792	et	4	main
abiellumist	doc_101672866015_item	3137793	et	3	main
läkitab	doc_101672866015_item	3137794	et	3	main
naisele	doc_101672866015_item	3137795	et	3	main
õrnu	doc_101672866015_item	3137796	et	4	main
von	doc_101672866015_item	3137801	et	4	main
nimetada	doc_101672866015_item	3137807	et	3	main
flööti	doc_101672866015_item	3137820	et	4	main
poissi	doc_101672866015_item	3137824	et	4	main
klaveri	doc_101672866015_item	3137828	et	3	main
tausta	doc_101672866015_item	3137838	et	4	main
pakuvad	doc_101672866015_item	3137839	et	3	main
mitmesugused	doc_101672866015_item	3137840	et	3	main
muusikaautomaadid	doc_101672866015_item	3137841	et	4	main
mozarti	doc_101672866015_item	3137844	et	4	main
josephine	doc_101672866015_item	3137798	et	4	main
kunstikambrit	doc_101672866015_item	3137804	et	3	main
mida	doc_101672866015_item	3137805	et	4	main
muusikalist	doc_101672866015_item	3137837	et	4	main
läbisaamine	doc_101672866015_item	3137860	et	4	main
on	doc_101672866015_item	3137861	et	4	main
hea	doc_101672866015_item	3137862	et	4	main
josephine	doc_101672866015_item	3137863	et	4	main
on	doc_101672866015_item	3137864	et	4	main
beethovenist	doc_101672866015_item	3137865	et	4	main
endiselt	doc_101672866015_item	3137866	et	4	main
vaimustatud	doc_101672866015_item	3137867	et	4	main
oktoobris	doc_101672866015_item	3137868	et	3	main
1800	doc_101672866015_item	3137869	et	2	main
aastal	doc_101672866015_item	3137870	et	3	main
kirjutab	doc_101672866015_item	3137871	et	3	main
ta	doc_101672866015_item	3137872	et	4	main
oma	doc_101672866015_item	3137873	et	4	main
õele	doc_101672866015_item	3137874	et	3	main
theresele	doc_101672866015_item	3137875	et	4	main
kirja	doc_101672866015_item	3137876	et	4	main
kus	doc_101672866015_item	3137877	et	3	main
räägib	doc_101672866015_item	3137878	et	3	main
sellest	doc_101672866015_item	3137879	et	4	main
kui	doc_101672866015_item	3137880	et	3	main
charming	doc_101672866015_item	3137881	et	4	main
ta	doc_101672866015_item	3137882	et	4	main
on	doc_101672866015_item	3137883	et	4	main
ja	doc_101672866015_item	3137884	et	3	main
kuivõrd	doc_101672866015_item	3137885	et	3	main
krahvinna	doc_101672866015_item	3137886	et	4	main
on	doc_101672866015_item	3137887	et	4	main
tema	doc_101672866015_item	3137888	et	4	main
loomingust	doc_101672866015_item	3137889	et	3	main
vaimustuses	doc_101672866015_item	3137890	et	4	main
1800	doc_101672866015_item	3137891	et	2	main
aastast	doc_101672866015_item	3137892	et	4	main
josephine	doc_101672866015_item	3137893	et	4	main
elus	doc_101672866015_item	3137894	et	4	main
algavad	doc_101672866015_item	3137895	et	4	main
probleemid	doc_101672866015_item	3137896	et	3	main
ta	doc_101672866015_item	3137914	et	4	main
tütar	doc_101672866015_item	3137921	et	3	main
sellest	doc_101672866015_item	3137923	et	4	main
kuid	doc_101672866015_item	3137926	et	4	main
on	doc_101672866015_item	3137854	et	4	main
vahel	doc_101672866015_item	3137859	et	4	main
nimelt	doc_101672866015_item	3137897	et	4	main
majanduslikult	doc_101672866015_item	3137899	et	4	main
on	doc_101672866015_item	3137900	et	4	main
kuid	doc_101672866015_item	3137905	et	4	main
mitte	doc_101672866015_item	3137906	et	3	main
välja	doc_101672866015_item	3137912	et	4	main
et	doc_101672866015_item	3137913	et	3	main
ema	doc_101672866015_item	3137918	et	4	main
et	doc_101672866015_item	3137920	et	3	main
beethoven	doc_101672866015_item	3137930	et	4	main
ja	doc_101672866015_item	3137936	et	3	main
joseph	doc_101672866015_item	3137937	et	4	main
8	doc_101672866015_item	3137946	et	2	main
jaanuaril	doc_101672866015_item	3137947	et	3	main
tiisikusse	doc_101672866015_item	3137948	et	3	main
jättes	doc_101672866015_item	3137949	et	4	main
ja	doc_101672866015_item	3137953	et	3	main
korraldab	doc_101672866015_item	3137973	et	3	main
muusikalisi	doc_101672866015_item	3137977	et	4	main
suareesid	doc_101672866015_item	3137978	et	3	main
kus	doc_101672866015_item	3137979	et	3	main
beethoven	doc_101672866015_item	3137980	et	4	main
esineb	doc_101672866015_item	3137981	et	3	main
samuti	doc_101672866015_item	3137982	et	3	main
nagu	doc_101672866015_item	3137983	et	3	main
kirjutab	doc_101672866015_item	3137984	et	3	main
brunwick	doc_101672866015_item	3137989	et	4	main
charming	doc_101672866015_item	3137992	et	4	main
second	doc_101672866015_item	3137997	et	4	main
lessons	doc_101672866015_item	3138003	et	4	main
he	doc_101672866015_item	3138009	et	4	main
is	doc_101672866015_item	3138010	et	4	main
played	doc_101672866015_item	3138016	et	4	main
us	doc_101672866015_item	3138017	et	4	main
charming	doc_101672866015_item	3138022	et	4	main
side	doc_101672866015_item	3138031	et	4	main
1805	doc_101672866015_item	3138036	et	2	main
kirjutatud	doc_101672866015_item	3138038	et	4	main
nr	doc_101672866015_item	3138040	et	4	main
klaversonaati	doc_101672866015_item	3138049	et	4	main
nr	doc_101672866015_item	3138050	et	4	main
24	doc_101672866015_item	3138051	et	2	main
theresiale	doc_101672866015_item	3138067	et	4	main
et	doc_101672866015_item	3138068	et	3	main
ta	doc_101672866015_item	3138069	et	4	main
josephinale	doc_101672866015_item	3138073	et	4	main
beethoven	doc_101672866015_item	3138075	et	4	main
näha	doc_101672866015_item	3138097	et	3	main
ta	doc_101672866015_item	3138102	et	4	main
murelik	doc_101672866015_item	3138104	et	3	main
et	doc_101672866015_item	3138105	et	3	main
ta	doc_101672866015_item	3138106	et	4	main
tähelepanu	doc_101672866015_item	3138112	et	4	main
tema	doc_101672866015_item	3138116	et	4	main
märgavad	doc_101672866015_item	3138127	et	4	main
perekond	doc_101672866015_item	3138131	et	3	main
näiteks	doc_101672866015_item	3138133	et	4	main
oma	doc_101672866015_item	3138135	et	4	main
kirjadest	doc_101672866015_item	3138136	et	3	main
op	doc_101672866015_item	3138177	et	4	main
klaverisonaadi	doc_101672866015_item	3138180	et	3	main
ta	doc_101672866015_item	3138196	et	4	main
mõtleb	doc_101672866015_item	3138197	et	3	main
is	doc_101672866015_item	3138208	et	4	main
no	doc_101672866015_item	3138209	et	3	main
what	doc_101672866015_item	3138214	et	4	main
some	doc_101672866015_item	3138227	et	4	main
of	doc_101672866015_item	3138232	et	4	main
adored	doc_101672866015_item	3138237	et	4	main
together	doc_101672866015_item	3138244	et	4	main
one	doc_101672866015_item	3138248	et	4	main
death	doc_101672866015_item	3138266	et	4	main
and	doc_101672866015_item	3138267	et	3	main
life	doc_101672866015_item	3138268	et	4	main
many	doc_101672866015_item	3138273	et	4	main
ühepoolsed	doc_101672866015_item	3138306	et	3	main
who	doc_101672866015_item	3138316	et	4	main
before	doc_101672866015_item	3138330	et	4	main
which	doc_101672866015_item	3138336	et	4	main
me	doc_101672866015_item	3138347	et	4	main
deymi	doc_101672866015_item	3137898	et	4	main
brunswikide	doc_101672866015_item	3137908	et	4	main
perekonnalt	doc_101672866015_item	3137909	et	4	main
pole	doc_101672866015_item	3137915	et	3	main
soovib	doc_101672866015_item	3137919	et	3	main
naine	doc_101672866015_item	3137927	et	3	main
ei	doc_101672866015_item	3137928	et	4	main
perioodil	doc_101672866015_item	3137934	et	3	main
deyemi	doc_101672866015_item	3137938	et	4	main
truu	doc_101672866015_item	3137939	et	4	main
sõber	doc_101672866015_item	3137940	et	3	main
ja	doc_101672866015_item	3137941	et	3	main
teda	doc_101672866015_item	3137950	et	4	main
rasedana	doc_101672866015_item	3137954	et	3	main
on	doc_101672866015_item	3137956	et	4	main
ka	doc_101672866015_item	3137962	et	3	main
kuid	doc_101672866015_item	3137965	et	4	main
emotsionaalne	doc_101672866015_item	3137968	et	3	main
ja	doc_101672866015_item	3137971	et	3	main
õde	doc_101672866015_item	3137986	et	4	main
charlotte	doc_101672866015_item	3137987	et	4	main
is	doc_101672866015_item	3137991	et	4	main
he	doc_101672866015_item	3137993	et	4	main
comes	doc_101672866015_item	3137994	et	4	main
day	doc_101672866015_item	3137998	et	4	main
josephine	doc_101672866015_item	3138002	et	4	main
he	doc_101672866015_item	3138004	et	4	main
always	doc_101672866015_item	3138005	et	4	main
and	doc_101672866015_item	3138014	et	3	main
and	doc_101672866015_item	3138015	et	3	main
it	doc_101672866015_item	3138021	et	4	main
beethoveni	doc_101672866015_item	3138030	et	4	main
pühendab	doc_101672866015_item	3138035	et	3	main
1809	doc_101672866015_item	3138046	et	2	main
aastal	doc_101672866015_item	3138047	et	3	main
kogu	doc_101672866015_item	3138059	et	4	main
charlotte	doc_101672866015_item	3138065	et	4	main
kiri	doc_101672866015_item	3138066	et	3	main
tunnid	doc_101672866015_item	3138072	et	3	main
nõustu	doc_101672866015_item	3137929	et	4	main
lohutaja	doc_101672866015_item	3137942	et	4	main
kolme	doc_101672866015_item	3137951	et	4	main
tekivad	doc_101672866015_item	3137961	et	3	main
josephine	doc_101672866015_item	3137985	et	4	main
beethoven	doc_101672866015_item	3137990	et	4	main
pepi	doc_101672866015_item	3138001	et	4	main
after	doc_101672866015_item	3138007	et	4	main
you	doc_101672866015_item	3138008	et	4	main
opera	doc_101672866015_item	3138013	et	4	main
from	doc_101672866015_item	3138020	et	4	main
kasvab	doc_101672866015_item	3138033	et	3	main
von	doc_101672866015_item	3138043	et	4	main
brunswikile	doc_101672866015_item	3138044	et	4	main
ning	doc_101672866015_item	3138045	et	3	main
ilmunud	doc_101672866015_item	3138048	et	4	main
von	doc_101672866015_item	3138053	et	4	main
loo	doc_101672866015_item	3138060	et	4	main
millele	doc_101672866015_item	3138062	et	3	main
tõestuseks	doc_101672866015_item	3138063	et	4	main
nimetab	doc_101672866015_item	3138070	et	3	main
ning	doc_101672866015_item	3138113	et	3	main
nimetab	doc_101672866015_item	3138114	et	3	main
josephine	doc_101672866015_item	3138118	et	4	main
in	doc_101672866015_item	3138120	et	4	main
haste	doc_101672866015_item	3138121	et	4	main
tundeid	doc_101672866015_item	3138126	et	3	main
lähedased	doc_101672866015_item	3138130	et	3	main
inspireerib	doc_101672866015_item	3138166	et	3	main
teda	doc_101672866015_item	3138167	et	4	main
helilooja	doc_101672866015_item	3138168	et	4	main
pühendab	doc_101672866015_item	3138169	et	3	main
temale	doc_101672866015_item	3138170	et	3	main
sonaate	doc_101672866015_item	3138171	et	3	main
die	doc_101672866015_item	3138174	et	4	main
hoffnung	doc_101672866015_item	3138175	et	4	main
lootuseks	doc_101672866015_item	3138176	et	4	main
21	doc_101672866015_item	3138182	et	2	main
armastusest	doc_101672866015_item	3138190	et	4	main
kirjutab	doc_101672866015_item	3138191	et	3	main
talle	doc_101672866015_item	3138192	et	4	main
tunnistab	doc_101672866015_item	3138193	et	3	main
kui	doc_101672866015_item	3138194	et	3	main
ja	doc_101672866015_item	3138199	et	3	main
naine	doc_101672866015_item	3138202	et	3	main
language	doc_101672866015_item	3138210	et	4	main
far	doc_101672866015_item	3138216	et	4	main
all	doc_101672866015_item	3138222	et	3	main
my	doc_101672866015_item	3138223	et	4	main
for	doc_101672866015_item	3138226	et	4	main
feeling	doc_101672866015_item	3138231	et	4	main
my	doc_101672866015_item	3138236	et	4	main
soon	doc_101672866015_item	3138240	et	3	main
no	doc_101672866015_item	3138247	et	3	main
you	doc_101672866015_item	3138252	et	4	main
hear	doc_101672866015_item	3138254	et	4	main
all	doc_101672866015_item	3138255	et	3	main
about	doc_101672866015_item	3138256	et	4	main
struggle	doc_101672866015_item	3138262	et	4	main
with	doc_101672866015_item	3138263	et	4	main
god	doc_101672866015_item	3138269	et	4	main
jälle	doc_101672866015_item	3137976	et	3	main
von	doc_101672866015_item	3137988	et	4	main
every	doc_101672866015_item	3137996	et	4	main
and	doc_101672866015_item	3137999	et	3	main
inquires	doc_101672866015_item	3138006	et	4	main
some	doc_101672866015_item	3138018	et	4	main
kust	doc_101672866015_item	3138023	et	4	main
võib	doc_101672866015_item	3138024	et	3	main
järeldada	doc_101672866015_item	3138025	et	3	main
et	doc_101672866015_item	3138026	et	3	main
brunswikide	doc_101672866015_item	3138027	et	4	main
perekonna	doc_101672866015_item	3138028	et	4	main
ja	doc_101672866015_item	3138029	et	3	main
helilooja	doc_101672866015_item	3138034	et	4	main
sellest	doc_101672866015_item	3138056	et	4	main
perioodist	doc_101672866015_item	3138057	et	3	main
algabki	doc_101672866015_item	3138058	et	3	main
on	doc_101672866015_item	3138064	et	4	main
beethoveni	doc_101672866015_item	3138071	et	4	main
ohtlikeks	doc_101672866015_item	3138074	et	3	main
comes	doc_101672866015_item	3138076	et	4	main
quite	doc_101672866015_item	3138077	et	4	main
frequently	doc_101672866015_item	3138078	et	4	main
he	doc_101672866015_item	3138079	et	4	main
is	doc_101672866015_item	3138080	et	4	main
giving	doc_101672866015_item	3138081	et	4	main
pepi	doc_101672866015_item	3138082	et	4	main
lessons	doc_101672866015_item	3138083	et	4	main
it	doc_101672866015_item	3138084	et	4	main
is	doc_101672866015_item	3138085	et	4	main
a	doc_101672866015_item	3138086	et	4	main
bit	doc_101672866015_item	3138087	et	4	main
dangerous	doc_101672866015_item	3138088	et	4	main
i	doc_101672866015_item	3138089	et	4	main
must	doc_101672866015_item	3138090	et	4	main
confess	doc_101672866015_item	3138091	et	4	main
beethoveni	doc_101672866015_item	3138092	et	4	main
tunded	doc_101672866015_item	3138093	et	3	main
josephine	doc_101672866015_item	3138094	et	4	main
vastu	doc_101672866015_item	3138095	et	3	main
on	doc_101672866015_item	3138096	et	4	main
ka	doc_101672866015_item	3138098	et	3	main
kirjades	doc_101672866015_item	3138100	et	3	main
pööranud	doc_101672866015_item	3138108	et	4	main
armastatu	doc_101672866015_item	3138109	et	4	main
ehk	doc_101672866015_item	3138117	et	3	main
beethoven	doc_101672866015_item	3138123	et	4	main
varsi	doc_101672866015_item	3138124	et	4	main
ka	doc_101672866015_item	3138128	et	3	main
ühest	doc_101672866015_item	3138134	et	4	main
jutustab	doc_101672866015_item	3138137	et	3	main
lichnowsky	doc_101672866015_item	3138143	et	4	main
on	doc_101672866015_item	3138144	et	4	main
an	doc_101672866015_item	3138173	et	4	main
beethoven	doc_101672866015_item	3138187	et	4	main
unistab	doc_101672866015_item	3138188	et	3	main
palju	doc_101672866015_item	3138195	et	4	main
on	doc_101672866015_item	3138203	et	4	main
jaoks	doc_101672866015_item	3138205	et	4	main
which	doc_101672866015_item	3138211	et	4	main
above	doc_101672866015_item	3138217	et	4	main
all	doc_101672866015_item	3138218	et	3	main
mere	doc_101672866015_item	3138219	et	3	main
regard---you	doc_101672866015_item	3138220	et	4	main
ei	doc_101672866015_item	3138107	et	4	main
piisavalt	doc_101672866015_item	3138111	et	4	main
ennast	doc_101672866015_item	3138115	et	4	main
beethoveniks	doc_101672866015_item	3138119	et	4	main
nende	doc_101672866015_item	3138125	et	4	main
sõbrad	doc_101672866015_item	3138132	et	3	main
et	doc_101672866015_item	3138139	et	3	main
tema	doc_101672866015_item	3138140	et	4	main
seda	doc_101672866015_item	3138145	et	3	main
märganud	doc_101672866015_item	3138146	et	4	main
kuid	doc_101672866015_item	3138147	et	4	main
kiitis	doc_101672866015_item	3138148	et	3	main
heaks	doc_101672866015_item	3138149	et	4	main
kuna	doc_101672866015_item	3138150	et	3	main
arvas	doc_101672866015_item	3138151	et	3	main
et	doc_101672866015_item	3138152	et	3	main
nende	doc_101672866015_item	3138153	et	4	main
tunded	doc_101672866015_item	3138154	et	3	main
positiivselt	doc_101672866015_item	3138155	et	4	main
mõjutavad	doc_101672866015_item	3138156	et	4	main
helolooja	doc_101672866015_item	3138157	et	4	main
loomingu	doc_101672866015_item	3138158	et	3	main
tõepoolest	doc_101672866015_item	3138159	et	3	main
josephine	doc_101672866015_item	3138160	et	4	main
on	doc_101672866015_item	3138161	et	4	main
nagu	doc_101672866015_item	3138162	et	3	main
muusa	doc_101672866015_item	3138163	et	4	main
beethovenile	doc_101672866015_item	3138164	et	4	main
ta	doc_101672866015_item	3138165	et	4	main
prints	doc_101672866015_item	3138142	et	3	main
laulu	doc_101672866015_item	3138172	et	4	main
32	doc_101672866015_item	3138178	et	2	main
nende	doc_101672866015_item	3138189	et	4	main
temast	doc_101672866015_item	3138198	et	3	main
tähtis	doc_101672866015_item	3138201	et	4	main
is	doc_101672866015_item	3138215	et	4	main
you	doc_101672866015_item	3138221	et	4	main
hapiness	doc_101672866015_item	3138224	et	4	main
and	doc_101672866015_item	3138225	et	3	main
the	doc_101672866015_item	3138230	et	4	main
you	doc_101672866015_item	3138235	et	4	main
as	doc_101672866015_item	3138239	et	4	main
as	doc_101672866015_item	3138241	et	4	main
we	doc_101672866015_item	3138242	et	4	main
are	doc_101672866015_item	3138243	et	3	main
to	doc_101672866015_item	3138249	et	4	main
my	doc_101672866015_item	3138257	et	4	main
real	doc_101672866015_item	3138258	et	3	main
sorrows	doc_101672866015_item	3138259	et	4	main
and	doc_101672866015_item	3138260	et	3	main
between	doc_101672866015_item	3138265	et	4	main
there	doc_101672866015_item	3138270	et	4	main
you	doc_101672866015_item	3138315	et	4	main
heighten	doc_101672866015_item	3138320	et	4	main
soul	doc_101672866015_item	3138324	et	4	main
iknow	doc_101672866015_item	3138331	et	4	main
you	doc_101672866015_item	3138332	et	4	main
personally	doc_101672866015_item	3138333	et	4	main
soul	doc_101672866015_item	3138341	et	4	main
is	doc_101672866015_item	3138344	et	4	main
nad	doc_101672866015_item	3138356	et	3	main
kohtuvad	doc_101672866015_item	3138357	et	4	main
beethoven	doc_101672866015_item	3138359	et	4	main
aga	doc_101672866015_item	3138367	et	3	main
vahel	doc_101672866015_item	3138370	et	4	main
josephine	doc_101672866015_item	3138383	et	4	main
kirjutab	doc_101672866015_item	3138384	et	3	main
laulu	doc_101672866015_item	3138179	et	4	main
nr	doc_101672866015_item	3138181	et	4	main
aurora	doc_101672866015_item	3138183	et	4	main
op53	doc_101672866015_item	3138184	et	4	main
1805	doc_101672866015_item	3138185	et	2	main
aastal	doc_101672866015_item	3138186	et	3	main
kui	doc_101672866015_item	3138200	et	3	main
tema	doc_101672866015_item	3138204	et	4	main
why	doc_101672866015_item	3138206	et	4	main
there	doc_101672866015_item	3138207	et	4	main
can	doc_101672866015_item	3138212	et	4	main
express	doc_101672866015_item	3138213	et	4	main
time	doc_101672866015_item	3138228	et	4	main
after	doc_101672866015_item	3138229	et	4	main
j	doc_101672866015_item	3138238	et	4	main
with	doc_101672866015_item	3138246	et	4	main
disturb	doc_101672866015_item	3138250	et	4	main
shall	doc_101672866015_item	3138253	et	4	main
the	doc_101672866015_item	3138261	et	4	main
are	doc_101672866015_item	3138271	et	3	main
more	doc_101672866015_item	3138274	et	4	main
things	doc_101672866015_item	3138275	et	4	main
i	doc_101672866015_item	3138276	et	4	main
should	doc_101672866015_item	3138277	et	4	main
love	doc_101672866015_item	3138278	et	4	main
to	doc_101672866015_item	3138279	et	4	main
tell	doc_101672866015_item	3138280	et	4	main
you	doc_101672866015_item	3138281	et	4	main
how	doc_101672866015_item	3138282	et	4	main
much	doc_101672866015_item	3138283	et	4	main
i	doc_101672866015_item	3138284	et	4	main
think	doc_101672866015_item	3138285	et	4	main
of	doc_101672866015_item	3138286	et	4	main
you	doc_101672866015_item	3138287	et	4	main
what	doc_101672866015_item	3138288	et	4	main
i	doc_101672866015_item	3138289	et	4	main
feel	doc_101672866015_item	3138290	et	3	main
for	doc_101672866015_item	3138291	et	4	main
you	doc_101672866015_item	3138292	et	4	main
but	doc_101672866015_item	3138293	et	4	main
how	doc_101672866015_item	3138294	et	4	main
weak	doc_101672866015_item	3138295	et	4	main
and	doc_101672866015_item	3138296	et	3	main
poor	doc_101672866015_item	3138297	et	3	main
those	doc_101672866015_item	3138299	et	4	main
beethoveni	doc_101672866015_item	3138301	et	4	main
tunned	doc_101672866015_item	3138302	et	3	main
ei	doc_101672866015_item	3138303	et	4	main
kuna	doc_101672866015_item	3138307	et	3	main
vastab	doc_101672866015_item	3138309	et	3	main
ta	doc_101672866015_item	3138311	et	4	main
it	doc_101672866015_item	3138313	et	4	main
is	doc_101672866015_item	3138314	et	4	main
feelings	doc_101672866015_item	3138322	et	4	main
which	doc_101672866015_item	3138325	et	4	main
enthusiasm	doc_101672866015_item	3138327	et	4	main
for	doc_101672866015_item	3138328	et	4	main
my	doc_101672866015_item	3138340	et	4	main
love	doc_101672866015_item	3138348	et	4	main
kestab	doc_101672866015_item	3138353	et	4	main
kuid	doc_101672866015_item	3138363	et	4	main
pole	doc_101672866015_item	3138364	et	3	main
teada	doc_101672866015_item	3138365	et	3	main
järsult	doc_101672866015_item	3138368	et	4	main
mingi	doc_101672866015_item	3138372	et	4	main
arusaamatus	doc_101672866015_item	3138373	et	4	main
ühes	doc_101672866015_item	3138381	et	4	main
love	doc_101672866015_item	3138233	et	4	main
for	doc_101672866015_item	3138234	et	4	main
again	doc_101672866015_item	3138245	et	4	main
us	doc_101672866015_item	3138251	et	4	main
myself	doc_101672866015_item	3138264	et	4	main
so	doc_101672866015_item	3138272	et	4	main
ole	doc_101672866015_item	3138304	et	4	main
josephine	doc_101672866015_item	3138308	et	4	main
temale	doc_101672866015_item	3138310	et	3	main
kirjutab	doc_101672866015_item	3138312	et	3	main
can	doc_101672866015_item	3138317	et	4	main
lessen	doc_101672866015_item	3138318	et	4	main
or	doc_101672866015_item	3138319	et	4	main
my	doc_101672866015_item	3138323	et	4	main
felt	doc_101672866015_item	3138326	et	4	main
feeling	doc_101672866015_item	3138335	et	4	main
lies	doc_101672866015_item	3138337	et	4	main
deep	doc_101672866015_item	3138338	et	4	main
and	doc_101672866015_item	3138342	et	3	main
ineffable	doc_101672866015_item	3138345	et	4	main
aastaid	doc_101672866015_item	3138355	et	4	main
josephinele	doc_101672866015_item	3138361	et	4	main
klaveritunde	doc_101672866015_item	3138362	et	4	main
nende	doc_101672866015_item	3138369	et	4	main
ilmub	doc_101672866015_item	3138371	et	3	main
not	doc_101672866015_item	3138394	et	4	main
protest	doc_101672866015_item	3138395	et	3	main
certain	doc_101672866015_item	3138401	et	4	main
how	doc_101672866015_item	3138407	et	4	main
quite	doc_101672866015_item	3138415	et	4	main
value	doc_101672866015_item	3138421	et	4	main
have	doc_101672866015_item	3138426	et	4	main
that	doc_101672866015_item	3138429	et	4	main
will	doc_101672866015_item	3138441	et	4	main
what	doc_101672866015_item	3138464	et	4	main
must	doc_101672866015_item	3138469	et	4	main
aastal	doc_101672866015_item	3138478	et	3	main
viinist	doc_101672866015_item	3138483	et	3	main
kirjutab	doc_101672866015_item	3138489	et	3	main
truudusetuse	doc_101672866015_item	3138492	et	4	main
üle	doc_101672866015_item	3138493	et	3	main
feelings	doc_101672866015_item	3138494	et	4	main
või	doc_101672866015_item	3138502	et	4	main
pettumus	doc_101672866015_item	3138503	et	4	main
mis	doc_101672866015_item	3138504	et	4	main
nende	doc_101672866015_item	3138505	et	4	main
juhtunud	doc_101672866015_item	3138508	et	4	main
viibib	doc_101672866015_item	3138510	et	3	main
2	doc_101672866015_item	3138513	et	2	main
pärast	doc_101672866015_item	3138515	et	4	main
aasta	doc_101672866015_item	3138523	et	4	main
beethoven	doc_101672866015_item	3138525	et	4	main
few	doc_101672866015_item	3138534	et	4	main
given	doc_101672866015_item	3138539	et	4	main
or	doc_101672866015_item	3138544	et	4	main
grant	doc_101672866015_item	3138554	et	4	main
me	doc_101672866015_item	3138555	et	4	main
one	doc_101672866015_item	3138556	et	4	main
with	doc_101672866015_item	3138561	et	4	main
have	doc_101672866015_item	3138566	et	4	main
just	doc_101672866015_item	3138567	et	3	main
once	doc_101672866015_item	3138568	et	4	main
have	doc_101672866015_item	3138572	et	4	main
today	doc_101672866015_item	3138597	et	4	main
this	doc_101672866015_item	3138603	et	4	main
letter	doc_101672866015_item	3138604	et	4	main
did	doc_101672866015_item	3138608	et	4	main
third	doc_101672866015_item	3138616	et	4	main
fail	doc_101672866015_item	3138618	et	3	main
see	doc_101672866015_item	3138620	et	3	main
nad	doc_101672866015_item	3138623	et	3	main
ja	doc_101672866015_item	3138634	et	3	main
solvanud	doc_101672866015_item	3138637	et	4	main
i	doc_101672866015_item	3138658	et	4	main
jargmisel	doc_101672866015_item	3138663	et	4	main
päeval	doc_101672866015_item	3138664	et	3	main
jälle	doc_101672866015_item	3138672	et	3	main
to	doc_101672866015_item	3138690	et	4	main
b	doc_101672866015_item	3138694	et	4	main
and	doc_101672866015_item	3138702	et	3	main
code	doc_101672866015_item	3138710	et	4	main
deem	doc_101672866015_item	3138715	et	4	main
is	doc_101672866015_item	3138720	et	4	main
are	doc_101672866015_item	3138298	et	3	main
words	doc_101672866015_item	3138300	et	4	main
päris	doc_101672866015_item	3138305	et	4	main
your	doc_101672866015_item	3138321	et	4	main
you	doc_101672866015_item	3138329	et	4	main
a	doc_101672866015_item	3138334	et	4	main
in	doc_101672866015_item	3138339	et	4	main
which	doc_101672866015_item	3138343	et	4	main
made	doc_101672866015_item	3138346	et	3	main
selline	doc_101672866015_item	3138350	et	4	main
mitu	doc_101672866015_item	3138354	et	4	main
vahetevahel	doc_101672866015_item	3138358	et	3	main
annab	doc_101672866015_item	3138360	et	3	main
miks	doc_101672866015_item	3138366	et	4	main
teineteist	doc_101672866015_item	3138380	et	4	main
nagu	doc_101672866015_item	3138387	et	3	main
lahkumiskiri	doc_101672866015_item	3138388	et	3	main
when	doc_101672866015_item	3138396	et	4	main
accuse	doc_101672866015_item	3138398	et	4	main
know	doc_101672866015_item	3138406	et	4	main
my	doc_101672866015_item	3138410	et	4	main
wrongly	doc_101672866015_item	3138416	et	4	main
demonstrated	doc_101672866015_item	3138427	et	4	main
is	doc_101672866015_item	3138430	et	4	main
that	doc_101672866015_item	3138439	et	4	main
i	doc_101672866015_item	3138440	et	4	main
your	doc_101672866015_item	3138462	et	4	main
amiss	doc_101672866015_item	3138473	et	4	main
1805	doc_101672866015_item	3138477	et	2	main
over	doc_101672866015_item	3138495	et	4	main
disloyality	doc_101672866015_item	3138498	et	4	main
kas	doc_101672866015_item	3138499	et	3	main
kohtuvad	doc_101672866015_item	3138520	et	4	main
taas	doc_101672866015_item	3138521	et	3	main
1907	doc_101672866015_item	3138522	et	2	main
a	doc_101672866015_item	3138533	et	4	main
have	doc_101672866015_item	3138538	et	4	main
tomorrow	doc_101672866015_item	3138543	et	4	main
after	doc_101672866015_item	3138547	et	4	main
undisturbed	doc_101672866015_item	3138557	et	4	main
hour	doc_101672866015_item	3138558	et	4	main
you	doc_101672866015_item	3138349	et	4	main
tundeline	doc_101672866015_item	3138351	et	4	main
kirjavahetus	doc_101672866015_item	3138352	et	4	main
oma	doc_101672866015_item	3138374	et	4	main
viimastes	doc_101672866015_item	3138375	et	3	main
kirjades	doc_101672866015_item	3138376	et	3	main
nad	doc_101672866015_item	3138377	et	3	main
nagu	doc_101672866015_item	3138378	et	3	main
süüdistavad	doc_101672866015_item	3138379	et	4	main
mis	doc_101672866015_item	3138385	et	4	main
nagu	doc_101672866015_item	3138389	et	3	main
your	doc_101672866015_item	3138391	et	4	main
you	doc_101672866015_item	3138397	et	4	main
me	doc_101672866015_item	3138399	et	4	main
of	doc_101672866015_item	3138400	et	4	main
things	doc_101672866015_item	3138402	et	4	main
you	doc_101672866015_item	3138403	et	4	main
you	doc_101672866015_item	3138408	et	4	main
heart	doc_101672866015_item	3138411	et	4	main
i	doc_101672866015_item	3138417	et	4	main
love	doc_101672866015_item	3138418	et	4	main
character	doc_101672866015_item	3138424	et	4	main
much	doc_101672866015_item	3138428	et	4	main
dear	doc_101672866015_item	3138431	et	4	main
and	doc_101672866015_item	3138432	et	3	main
kind	doc_101672866015_item	3138433	et	4	main
to	doc_101672866015_item	3138434	et	4	main
happiness	doc_101672866015_item	3138463	et	4	main
but	doc_101672866015_item	3138467	et	4	main
not	doc_101672866015_item	3138470	et	4	main
pärast	doc_101672866015_item	3138476	et	4	main
koos	doc_101672866015_item	3138481	et	4	main
oma	doc_101672866015_item	3138484	et	4	main
mõisa	doc_101672866015_item	3138485	et	3	main
ungarisse	doc_101672866015_item	3138486	et	4	main
s	doc_101672866015_item	3138497	et	4	main
on	doc_101672866015_item	3138507	et	4	main
josephine	doc_101672866015_item	3138509	et	4	main
sügisel	doc_101672866015_item	3138524	et	3	main
again	doc_101672866015_item	3138527	et	4	main
even	doc_101672866015_item	3138528	et	4	main
from	doc_101672866015_item	3138536	et	4	main
you	doc_101672866015_item	3138537	et	4	main
pleasure	doc_101672866015_item	3138542	et	4	main
you	doc_101672866015_item	3138551	et	4	main
you	doc_101672866015_item	3138562	et	4	main
so	doc_101672866015_item	3138563	et	4	main
that	doc_101672866015_item	3138569	et	4	main
talk	doc_101672866015_item	3138570	et	3	main
myself	doc_101672866015_item	3138605	et	4	main
suspect	doc_101672866015_item	3138610	et	4	main
might	doc_101672866015_item	3138613	et	4	main
time	doc_101672866015_item	3138617	et	4	main
kuid	doc_101672866015_item	3138630	et	4	main
on	doc_101672866015_item	3138636	et	4	main
your	doc_101672866015_item	3138660	et	4	main
mille	doc_101672866015_item	3138676	et	3	main
vabandab	doc_101672866015_item	3138685	et	3	main
insult	doc_101672866015_item	3138691	et	3	main
it	doc_101672866015_item	3138699	et	4	main
which	doc_101672866015_item	3138713	et	4	main
i	doc_101672866015_item	3138714	et	4	main
it	doc_101672866015_item	3138719	et	4	main
to	doc_101672866015_item	3138723	et	4	main
yourpardon	doc_101672866015_item	3138730	et	4	main
esteem	doc_101672866015_item	3138750	et	4	main
usually	doc_101672866015_item	3138755	et	4	main
in	doc_101672866015_item	3138760	et	4	main
beethoven	doc_101672866015_item	3138763	et	4	main
but	doc_101672866015_item	3138777	et	4	main
it	doc_101672866015_item	3138778	et	4	main
is	doc_101672866015_item	3138779	et	4	main
your	doc_101672866015_item	3138782	et	4	main
viimast	doc_101672866015_item	3138799	et	4	main
lõpp	doc_101672866015_item	3138806	et	3	main
nad	doc_101672866015_item	3138808	et	3	main
arusaamatus	doc_101672866015_item	3138813	et	4	main
õpetaja	doc_101672866015_item	3138818	et	4	main
nende	doc_101672866015_item	3138821	et	4	main
müür	doc_101672866015_item	3138825	et	3	main
võimatu	doc_101672866015_item	3138832	et	4	main
aadlivastane	doc_101672866015_item	3138837	et	3	main
vana	doc_101672866015_item	3138842	et	4	main
kirjas	doc_101672866015_item	3138382	et	4	main
kõlab	doc_101672866015_item	3138386	et	3	main
hüvastijätt	doc_101672866015_item	3138390	et	3	main
heart	doc_101672866015_item	3138392	et	4	main
does	doc_101672866015_item	3138393	et	4	main
not	doc_101672866015_item	3138405	et	4	main
me	doc_101672866015_item	3138414	et	4	main
you	doc_101672866015_item	3138419	et	4	main
and	doc_101672866015_item	3138420	et	3	main
you	doc_101672866015_item	3138425	et	4	main
children	doc_101672866015_item	3138438	et	4	main
i	doc_101672866015_item	3138465	et	4	main
you	doc_101672866015_item	3138468	et	4	main
take	doc_101672866015_item	3138471	et	4	main
it	doc_101672866015_item	3138472	et	4	main
lahkub	doc_101672866015_item	3138479	et	3	main
josephine	doc_101672866015_item	3138480	et	4	main
lastega	doc_101672866015_item	3138482	et	3	main
beethoven	doc_101672866015_item	3138488	et	4	main
tunded	doc_101672866015_item	3138491	et	3	main
vahel	doc_101672866015_item	3138506	et	4	main
a	doc_101672866015_item	3138529	et	4	main
lines	doc_101672866015_item	3138535	et	4	main
the	doc_101672866015_item	3138545	et	4	main
i	doc_101672866015_item	3138548	et	4	main
shall	doc_101672866015_item	3138549	et	4	main
see	doc_101672866015_item	3138550	et	3	main
may	doc_101672866015_item	3138552	et	4	main
to	doc_101672866015_item	3138559	et	4	main
spend	doc_101672866015_item	3138560	et	4	main
to	doc_101672866015_item	3138565	et	4	main
we	doc_101672866015_item	3138571	et	4	main
deliver	doc_101672866015_item	3138602	et	4	main
i	doc_101672866015_item	3138607	et	4	main
you	doc_101672866015_item	3138621	et	4	main
midagi	doc_101672866015_item	3138632	et	4	main
juhtub	doc_101672866015_item	3138633	et	3	main
so	doc_101672866015_item	3138657	et	4	main
pardon	doc_101672866015_item	3138661	et	4	main
tõenäoliselt	doc_101672866015_item	3138662	et	4	main
suaree	doc_101672866015_item	3138669	et	4	main
ja	doc_101672866015_item	3138670	et	3	main
ilmselt	doc_101672866015_item	3138671	et	4	main
intsident	doc_101672866015_item	3138675	et	3	main
josephine	doc_101672866015_item	3138684	et	4	main
i	doc_101672866015_item	3138686	et	4	main
did	doc_101672866015_item	3138687	et	4	main
you	doc_101672866015_item	3138692	et	4	main
but	doc_101672866015_item	3138695	et	4	main
do	doc_101672866015_item	3138404	et	4	main
hurt	doc_101672866015_item	3138409	et	3	main
you	doc_101672866015_item	3138412	et	4	main
treat	doc_101672866015_item	3138413	et	4	main
your	doc_101672866015_item	3138422	et	4	main
moral	doc_101672866015_item	3138423	et	4	main
me	doc_101672866015_item	3138435	et	4	main
and	doc_101672866015_item	3138436	et	3	main
my	doc_101672866015_item	3138437	et	4	main
never	doc_101672866015_item	3138442	et	4	main
forget	doc_101672866015_item	3138443	et	4	main
and	doc_101672866015_item	3138444	et	3	main
as	doc_101672866015_item	3138445	et	4	main
long	doc_101672866015_item	3138446	et	4	main
as	doc_101672866015_item	3138447	et	4	main
i	doc_101672866015_item	3138448	et	4	main
live	doc_101672866015_item	3138449	et	4	main
i	doc_101672866015_item	3138450	et	4	main
will	doc_101672866015_item	3138451	et	4	main
always	doc_101672866015_item	3138452	et	4	main
take	doc_101672866015_item	3138453	et	4	main
an	doc_101672866015_item	3138454	et	4	main
interest	doc_101672866015_item	3138455	et	4	main
in	doc_101672866015_item	3138456	et	4	main
your	doc_101672866015_item	3138457	et	4	main
fate	doc_101672866015_item	3138458	et	4	main
and	doc_101672866015_item	3138459	et	3	main
contribute	doc_101672866015_item	3138460	et	4	main
to	doc_101672866015_item	3138461	et	4	main
can	doc_101672866015_item	3138466	et	4	main
if	doc_101672866015_item	3138474	et	4	main
i	doc_101672866015_item	3138475	et	4	main
ja	doc_101672866015_item	3138487	et	3	main
laulu	doc_101672866015_item	3138490	et	4	main
lydia	doc_101672866015_item	3138496	et	4	main
on	doc_101672866015_item	3138500	et	4	main
kokkusaamatus	doc_101672866015_item	3138501	et	4	main
oma	doc_101672866015_item	3138511	et	4	main
mõisas	doc_101672866015_item	3138512	et	3	main
aastat	doc_101672866015_item	3138514	et	3	main
tuleb	doc_101672866015_item	3138516	et	3	main
viini	doc_101672866015_item	3138517	et	4	main
tagasi	doc_101672866015_item	3138518	et	3	main
armastajad	doc_101672866015_item	3138519	et	4	main
kirjutab	doc_101672866015_item	3138526	et	3	main
few	doc_101672866015_item	3138530	et	4	main
lines	doc_101672866015_item	3138531	et	4	main
only	doc_101672866015_item	3138532	et	4	main
me	doc_101672866015_item	3138540	et	4	main
great	doc_101672866015_item	3138541	et	4	main
day	doc_101672866015_item	3138546	et	4	main
heaven	doc_101672866015_item	3138553	et	4	main
as	doc_101672866015_item	3138564	et	4	main
not	doc_101672866015_item	3138573	et	4	main
had	doc_101672866015_item	3138574	et	4	main
for	doc_101672866015_item	3138575	et	4	main
a	doc_101672866015_item	3138576	et	4	main
long	doc_101672866015_item	3138577	et	4	main
time	doc_101672866015_item	3138578	et	4	main
when	doc_101672866015_item	3138579	et	4	main
my	doc_101672866015_item	3138580	et	4	main
heart	doc_101672866015_item	3138581	et	4	main
and	doc_101672866015_item	3138582	et	3	main
my	doc_101672866015_item	3138583	et	4	main
soul	doc_101672866015_item	3138584	et	4	main
may	doc_101672866015_item	3138585	et	4	main
again	doc_101672866015_item	3138586	et	4	main
be	doc_101672866015_item	3138587	et	4	main
united	doc_101672866015_item	3138588	et	4	main
with	doc_101672866015_item	3138589	et	4	main
yours	doc_101672866015_item	3138590	et	4	main
i	doc_101672866015_item	3138591	et	4	main
am	doc_101672866015_item	3138592	et	4	main
just	doc_101672866015_item	3138593	et	3	main
coming	doc_101672866015_item	3138594	et	4	main
into	doc_101672866015_item	3138595	et	4	main
town	doc_101672866015_item	3138596	et	4	main
and	doc_101672866015_item	3138598	et	3	main
i	doc_101672866015_item	3138599	et	4	main
could	doc_101672866015_item	3138600	et	4	main
almost	doc_101672866015_item	3138601	et	4	main
if	doc_101672866015_item	3138606	et	4	main
not	doc_101672866015_item	3138609	et	4	main
i	doc_101672866015_item	3138612	et	4	main
for	doc_101672866015_item	3138614	et	4	main
the	doc_101672866015_item	3138615	et	4	main
to	doc_101672866015_item	3138619	et	4	main
ilmselt	doc_101672866015_item	3138631	et	4	main
talle	doc_101672866015_item	3138641	et	4	main
josephine	doc_101672866015_item	3138665	et	4	main
majas	doc_101672866015_item	3138666	et	3	main
on	doc_101672866015_item	3138667	et	4	main
jälle	doc_101672866015_item	3138668	et	3	main
mingi	doc_101672866015_item	3138674	et	4	main
that	doc_101672866015_item	3138611	et	4	main
arvatavasti	doc_101672866015_item	3138622	et	3	main
kohtuvad	doc_101672866015_item	3138624	et	4	main
järgmisel	doc_101672866015_item	3138625	et	3	main
päeval	doc_101672866015_item	3138626	et	3	main
suareel	doc_101672866015_item	3138627	et	3	main
josephine	doc_101672866015_item	3138628	et	4	main
majas	doc_101672866015_item	3138629	et	3	main
beethoven	doc_101672866015_item	3138635	et	4	main
sest	doc_101672866015_item	3138638	et	4	main
josephine	doc_101672866015_item	3138639	et	4	main
kirjutab	doc_101672866015_item	3138640	et	3	main
kirja	doc_101672866015_item	3138642	et	4	main
kus	doc_101672866015_item	3138643	et	3	main
lausa	doc_101672866015_item	3138644	et	4	main
palub	doc_101672866015_item	3138645	et	3	main
millegi	doc_101672866015_item	3138646	et	4	main
eest	doc_101672866015_item	3138647	et	4	main
vabandust	doc_101672866015_item	3138648	et	4	main
it	doc_101672866015_item	3138649	et	4	main
is	doc_101672866015_item	3138650	et	4	main
my	doc_101672866015_item	3138651	et	4	main
turn	doc_101672866015_item	3138652	et	4	main
to	doc_101672866015_item	3138653	et	4	main
beg	doc_101672866015_item	3138654	et	4	main
your	doc_101672866015_item	3138655	et	4	main
pardon	doc_101672866015_item	3138656	et	4	main
beg	doc_101672866015_item	3138659	et	4	main
toimub	doc_101672866015_item	3138673	et	3	main
pärast	doc_101672866015_item	3138677	et	4	main
on	doc_101672866015_item	3138679	et	4	main
taas	doc_101672866015_item	3138680	et	3	main
not	doc_101672866015_item	3138688	et	4	main
dear	doc_101672866015_item	3138693	et	4	main
since	doc_101672866015_item	3138696	et	4	main
i	doc_101672866015_item	3138703	et	4	main
am	doc_101672866015_item	3138704	et	4	main
aware	doc_101672866015_item	3138706	et	4	main
of	doc_101672866015_item	3138707	et	4	main
transgress	doc_101672866015_item	3138712	et	4	main
my	doc_101672866015_item	3138721	et	4	main
turn	doc_101672866015_item	3138722	et	4	main
beg	doc_101672866015_item	3138724	et	4	main
your	doc_101672866015_item	3138725	et	4	main
beg	doc_101672866015_item	3138729	et	4	main
be	doc_101672866015_item	3138743	et	4	main
exists	doc_101672866015_item	3138751	et	4	main
a	doc_101672866015_item	3138752	et	4	main
be	doc_101672866015_item	3138757	et	4	main
vastab	doc_101672866015_item	3138764	et	3	main
how	doc_101672866015_item	3138766	et	4	main
mind	doc_101672866015_item	3138785	et	4	main
and	doc_101672866015_item	3138786	et	3	main
have	doc_101672866015_item	3138793	et	4	main
kaks	doc_101672866015_item	3138797	et	3	main
külmadeks	doc_101672866015_item	3138803	et	3	main
algas	doc_101672866015_item	3138812	et	3	main
tüli	doc_101672866015_item	3138815	et	4	main
vahel	doc_101672866015_item	3138819	et	4	main
ühiskond	doc_101672866015_item	3138827	et	3	main
lihtsalt	doc_101672866015_item	3138831	et	4	main
oli	doc_101672866015_item	3138834	et	3	main
liberaal	doc_101672866015_item	3138836	et	3	main
pärit	doc_101672866015_item	3138840	et	3	main
abielludes	doc_101672866015_item	3138845	et	3	main
mitte	doc_101672866015_item	3138849	et	3	main
aeg	doc_101672866015_item	3138877	et	3	main
puutuda	doc_101672866015_item	3138883	et	3	main
lahkus	doc_101672866015_item	3138890	et	4	main
kuid	doc_101672866015_item	3138895	et	4	main
strackelberg	doc_101672866015_item	3138902	et	4	main
tallinnas	doc_101672866015_item	3138910	et	4	main
kubermangugümnaasiumi	doc_101672866015_item	3138920	et	4	main
ja	doc_101672866015_item	3138921	et	3	main
eestimaa	doc_101672866015_item	3138922	et	4	main
kubermangukooli	doc_101672866015_item	3138923	et	4	main
kus	doc_101672866015_item	3138944	et	3	main
ungaris	doc_101672866015_item	3138950	et	4	main
josephine	doc_101672866015_item	3138952	et	4	main
hakkab	doc_101672866015_item	3138980	et	3	main
eestis	doc_101672866015_item	3138981	et	3	main
pärisoristele	doc_101672866015_item	3138996	et	4	main
beethoven	doc_101672866015_item	3138678	et	4	main
solvanud	doc_101672866015_item	3138681	et	4	main
ning	doc_101672866015_item	3138682	et	3	main
ja	doc_101672866015_item	3138683	et	3	main
mean	doc_101672866015_item	3138689	et	4	main
you	doc_101672866015_item	3138697	et	4	main
such	doc_101672866015_item	3138701	et	4	main
the	doc_101672866015_item	3138708	et	4	main
conventional	doc_101672866015_item	3138709	et	4	main
importance	doc_101672866015_item	3138718	et	4	main
pardon	doc_101672866015_item	3138726	et	4	main
so	doc_101672866015_item	3138727	et	4	main
room	doc_101672866015_item	3138744	et	3	main
touchiness	doc_101672866015_item	3138746	et	4	main
true	doc_101672866015_item	3138748	et	4	main
mutual	doc_101672866015_item	3138749	et	4	main
malady	doc_101672866015_item	3138753	et	4	main
which	doc_101672866015_item	3138754	et	4	main
only	doc_101672866015_item	3138759	et	4	main
am	doc_101672866015_item	3138769	et	4	main
to	doc_101672866015_item	3138774	et	4	main
see	doc_101672866015_item	3138775	et	3	main
you	doc_101672866015_item	3138776	et	4	main
better	doc_101672866015_item	3138780	et	4	main
to	doc_101672866015_item	3138789	et	4	main
see	doc_101672866015_item	3138790	et	3	main
you	doc_101672866015_item	3138791	et	4	main
you	doc_101672866015_item	3138792	et	4	main
took	doc_101672866015_item	3138698	et	3	main
as	doc_101672866015_item	3138700	et	4	main
well	doc_101672866015_item	3138705	et	4	main
to	doc_101672866015_item	3138711	et	4	main
of	doc_101672866015_item	3138716	et	4	main
little	doc_101672866015_item	3138717	et	4	main
all	doc_101672866015_item	3138731	et	3	main
the	doc_101672866015_item	3138732	et	4	main
more	doc_101672866015_item	3138733	et	4	main
since	doc_101672866015_item	3138734	et	4	main
i	doc_101672866015_item	3138735	et	4	main
cannot	doc_101672866015_item	3138736	et	4	main
understand	doc_101672866015_item	3138737	et	4	main
very	doc_101672866015_item	3138738	et	4	main
well	doc_101672866015_item	3138739	et	4	main
how	doc_101672866015_item	3138740	et	4	main
there	doc_101672866015_item	3138741	et	4	main
i	doc_101672866015_item	3138728	et	4	main
for	doc_101672866015_item	3138745	et	4	main
could	doc_101672866015_item	3138756	et	4	main
weaker	doc_101672866015_item	3138761	et	4	main
kohe	doc_101672866015_item	3138765	et	4	main
sorry	doc_101672866015_item	3138767	et	4	main
i	doc_101672866015_item	3138768	et	4	main
be	doc_101672866015_item	3138772	et	4	main
able	doc_101672866015_item	3138773	et	4	main
for	doc_101672866015_item	3138781	et	4	main
peace	doc_101672866015_item	3138783	et	4	main
of	doc_101672866015_item	3138784	et	4	main
offended	doc_101672866015_item	3138795	et	4	main
me5	doc_101672866015_item	3138796	et	2	main
kirja	doc_101672866015_item	3138800	et	4	main
223	doc_101672866015_item	3138805	et	2	main
mispärast	doc_101672866015_item	3138811	et	3	main
ja	doc_101672866015_item	3138817	et	3	main
suur	doc_101672866015_item	3138824	et	3	main
abielu	doc_101672866015_item	3138829	et	4	main
josephine	doc_101672866015_item	3138838	et	4	main
väga	doc_101672866015_item	3138841	et	3	main
ta	doc_101672866015_item	3138847	et	4	main
nad	doc_101672866015_item	3138879	et	3	main
reaalsusega	doc_101672866015_item	3138881	et	4	main
teada	doc_101672866015_item	3138885	et	3	main
josephine	doc_101672866015_item	3138889	et	4	main
pikka	doc_101672866015_item	3138893	et	4	main
tema	doc_101672866015_item	3138896	et	4	main
saatjaks	doc_101672866015_item	3138897	et	4	main
adam	doc_101672866015_item	3138900	et	4	main
von	doc_101672866015_item	3138901	et	4	main
sündis	doc_101672866015_item	3138907	et	3	main
tallinna	doc_101672866015_item	3138919	et	4	main
alalise	doc_101672866015_item	3138927	et	4	main
koolikorralduse	doc_101672866015_item	3138928	et	3	main
reisis	doc_101672866015_item	3138941	et	4	main
1810	doc_101672866015_item	3138947	et	2	main
levima	doc_101672866015_item	3138982	et	3	main
henhuutlus	doc_101672866015_item	3138983	et	4	main
isegi	doc_101672866015_item	3138986	et	4	main
nende	doc_101672866015_item	3138988	et	4	main
kirjakultuuri	doc_101672866015_item	3138991	et	4	main
levikut	doc_101672866015_item	3138992	et	3	main
talupoegade	doc_101672866015_item	3138993	et	3	main
seas	doc_101672866015_item	3138994	et	4	main
andis	doc_101672866015_item	3138995	et	3	main
eesti	doc_101672866015_item	3139005	et	4	main
koorilaulu	doc_101672866015_item	3139006	et	4	main
ja	doc_101672866015_item	3139007	et	3	main
pasunakooride	doc_101672866015_item	3139008	et	3	main
kunstialaste	doc_101672866015_item	3139013	et	4	main
luterlikule	doc_101672866015_item	3139024	et	4	main
kirikule	doc_101672866015_item	3139025	et	3	main
see	doc_101672866015_item	3139026	et	3	main
koosolekud	doc_101672866015_item	3139033	et	3	main
mõisnike	doc_101672866015_item	3139034	et	3	main
võrdsete	doc_101672866015_item	3139037	et	4	main
just	doc_101672866015_item	3139039	et	3	main
ja	doc_101672866015_item	3139048	et	3	main
sellised	doc_101672866015_item	3139058	et	4	main
demokraatlikud	doc_101672866015_item	3139059	et	3	main
josephine	doc_101672866015_item	3139065	et	4	main
kahe	doc_101672866015_item	3139075	et	3	main
selle	doc_101672866015_item	3139084	et	4	main
josephine	doc_101672866015_item	3139088	et	4	main
could	doc_101672866015_item	3138742	et	4	main
where	doc_101672866015_item	3138747	et	4	main
suspected	doc_101672866015_item	3138758	et	4	main
souls	doc_101672866015_item	3138762	et	4	main
not	doc_101672866015_item	3138770	et	4	main
to	doc_101672866015_item	3138771	et	4	main
mine	doc_101672866015_item	3138787	et	3	main
not	doc_101672866015_item	3138788	et	4	main
not	doc_101672866015_item	3138794	et	4	main
nende	doc_101672866015_item	3138798	et	4	main
nimetada	doc_101672866015_item	3138802	et	3	main
miks	doc_101672866015_item	3138807	et	4	main
läksid	doc_101672866015_item	3138810	et	4	main
õpilase	doc_101672866015_item	3138816	et	3	main
kahjuks	doc_101672866015_item	3138820	et	4	main
nimega	doc_101672866015_item	3138826	et	3	main
oli	doc_101672866015_item	3138830	et	3	main
demokraat	doc_101672866015_item	3138835	et	3	main
soost	doc_101672866015_item	3138844	et	4	main
ainult	doc_101672866015_item	3138850	et	4	main
pidid	doc_101672866015_item	3138880	et	4	main
kokku	doc_101672866015_item	3138882	et	3	main
aastal	doc_101672866015_item	3138888	et	3	main
tegi	doc_101672866015_item	3138892	et	4	main
ringreisi	doc_101672866015_item	3138894	et	4	main
võib	doc_101672866015_item	3138801	et	3	main
hüvastijattudeks	doc_101672866015_item	3138804	et	4	main
lahku	doc_101672866015_item	3138809	et	4	main
ja	doc_101672866015_item	3138814	et	3	main
vahel	doc_101672866015_item	3138822	et	4	main
seisis	doc_101672866015_item	3138823	et	4	main
nende	doc_101672866015_item	3138828	et	4	main
beethoven	doc_101672866015_item	3138833	et	4	main
aga	doc_101672866015_item	3138839	et	3	main
aadli	doc_101672866015_item	3138843	et	3	main
kaotaks	doc_101672866015_item	3138848	et	4	main
oma	doc_101672866015_item	3138851	et	4	main
positsiooni	doc_101672866015_item	3138852	et	4	main
ühiskonnas	doc_101672866015_item	3138853	et	4	main
vaid	doc_101672866015_item	3138854	et	3	main
suurema	doc_101672866015_item	3138855	et	4	main
kingituse	doc_101672866015_item	3138856	et	4	main
iga	doc_101672866015_item	3138857	et	4	main
naise	doc_101672866015_item	3138858	et	3	main
elus-	doc_101672866015_item	3138859	et	4	main
õiguse	doc_101672866015_item	3138860	et	4	main
oma	doc_101672866015_item	3138861	et	4	main
lastele	doc_101672866015_item	3138862	et	4	main
kui	doc_101672866015_item	3138863	et	3	main
nende	doc_101672866015_item	3138864	et	4	main
armastus	doc_101672866015_item	3138865	et	4	main
tekkis	doc_101672866015_item	3138866	et	3	main
nad	doc_101672866015_item	3138867	et	3	main
arvatavasti	doc_101672866015_item	3138868	et	3	main
ei	doc_101672866015_item	3138869	et	4	main
mõelnud	doc_101672866015_item	3138870	et	4	main
sellest	doc_101672866015_item	3138871	et	4	main
nad	doc_101672866015_item	3138872	et	3	main
lihtsalt	doc_101672866015_item	3138873	et	4	main
armastasid	doc_101672866015_item	3138874	et	4	main
kuid	doc_101672866015_item	3138875	et	4	main
kodanlikuga	doc_101672866015_item	3138846	et	3	main
kus	doc_101672866015_item	3138878	et	3	main
on	doc_101672866015_item	3138884	et	4	main
1808	doc_101672866015_item	3138887	et	2	main
viinist	doc_101672866015_item	3138891	et	3	main
christoph	doc_101672866015_item	3138903	et	4	main
gümnaasiumi	doc_101672866015_item	3138911	et	4	main
oma	doc_101672866015_item	3138938	et	4	main
elu	doc_101672866015_item	3138939	et	4	main
tutvuski	doc_101672866015_item	3138945	et	4	main
aastal	doc_101672866015_item	3138948	et	3	main
krahvina	doc_101672866015_item	3138951	et	3	main
von	doc_101672866015_item	3138953	et	4	main
on	doc_101672866015_item	3138984	et	4	main
uue	doc_101672866015_item	3138998	et	3	main
eneseväärtustunde	doc_101672866015_item	3138999	et	4	main
uusi	doc_101672866015_item	3139000	et	3	main
ühistegevuse	doc_101672866015_item	3139014	et	4	main
õpetasid	doc_101672866015_item	3139015	et	4	main
oli	doc_101672866015_item	3139021	et	3	main
ja	doc_101672866015_item	3139030	et	3	main
vaeslastekoole	doc_101672866015_item	3139049	et	4	main
seminari	doc_101672866015_item	3139052	et	4	main
tegutses	doc_101672866015_item	3139054	et	3	main
võiksid	doc_101672866015_item	3139061	et	4	main
tõenäoliselt	doc_101672866015_item	3139062	et	4	main
samuti	doc_101672866015_item	3139063	et	3	main
olla	doc_101672866015_item	3139064	et	3	main
abiellusid	doc_101672866015_item	3139074	et	4	main
peale	doc_101672866015_item	3139086	et	4	main
christoph	doc_101672866015_item	3139091	et	4	main
kaks	doc_101672866015_item	3139098	et	3	main
ja	doc_101672866015_item	3139101	et	3	main
maria	doc_101672866015_item	3139102	et	4	main
saadab	doc_101672866015_item	3139114	et	3	main
päikest	doc_101672866015_item	3139124	et	4	main
miks	doc_101672866015_item	3139130	et	4	main
josephine	doc_101672866015_item	3139131	et	4	main
ei	doc_101672866015_item	3139132	et	4	main
sümbol	doc_101672866015_item	3139144	et	3	main
tõesti	doc_101672866015_item	3139146	et	3	main
ja	doc_101672866015_item	3139151	et	3	main
kuid	doc_101672866015_item	3139153	et	4	main
hinges	doc_101672866015_item	3139154	et	4	main
jäi	doc_101672866015_item	3139155	et	3	main
oma	doc_101672866015_item	3139159	et	4	main
elu	doc_101672866015_item	3139160	et	4	main
lõppuni	doc_101672866015_item	3139161	et	3	main
sellel	doc_101672866015_item	3139162	et	4	main
teemal	doc_101672866015_item	3139163	et	3	main
palju	doc_101672866015_item	3139165	et	4	main
oletada	doc_101672866015_item	3139166	et	3	main
ja	doc_101672866015_item	3139167	et	3	main
vaielda	doc_101672866015_item	3139168	et	4	main
külastanud	doc_101672866015_item	3139183	et	4	main
eestit	doc_101672866015_item	3139184	et	3	main
ja	doc_101672866015_item	3139185	et	3	main
vääna	doc_101672866015_item	3139186	et	4	main
mõisa	doc_101672866015_item	3139187	et	3	main
christop	doc_101672866015_item	3139197	et	4	main
lahkus	doc_101672866015_item	3139199	et	4	main
perekonna	doc_101672866015_item	3139200	et	4	main
pärast	doc_101672866015_item	3139207	et	4	main
tagasi	doc_101672866015_item	3139208	et	3	main
ajal	doc_101672866015_item	3139219	et	4	main
aastal	doc_101672866015_item	3139225	et	3	main
josephine	doc_101672866015_item	3139227	et	4	main
laps	doc_101672866015_item	3139229	et	4	main
minona	doc_101672866015_item	3139230	et	4	main
tüdruk	doc_101672866015_item	3139240	et	3	main
on	doc_101672866015_item	3139296	et	4	main
tuli	doc_101672866015_item	3138876	et	4	main
et	doc_101672866015_item	3138886	et	3	main
christoph	doc_101672866015_item	3138899	et	4	main
adam	doc_101672866015_item	3138904	et	4	main
von	doc_101672866015_item	3138905	et	4	main
stackelberg6	doc_101672866015_item	3138906	et	2	main
väänas	doc_101672866015_item	3138908	et	3	main
õppis	doc_101672866015_item	3138913	et	3	main
meditsiini	doc_101672866015_item	3138915	et	4	main
ja	doc_101672866015_item	3138916	et	3	main
õigusteadust	doc_101672866015_item	3138917	et	4	main
oli	doc_101672866015_item	3138918	et	3	main
direktoriks	doc_101672866015_item	3138924	et	3	main
ning	doc_101672866015_item	3138925	et	3	main
eestimaa	doc_101672866015_item	3138926	et	4	main
vaeslastekoole	doc_101672866015_item	3138934	et	4	main
ning	doc_101672866015_item	3138935	et	3	main
rahvakooliõpetajate	doc_101672866015_item	3138936	et	3	main
seminari	doc_101672866015_item	3138937	et	4	main
palju	doc_101672866015_item	3138942	et	4	main
euroopas	doc_101672866015_item	3138943	et	3	main
soodustas	doc_101672866015_item	3138990	et	3	main
liikumine	doc_101672866015_item	3139020	et	4	main
oli	doc_101672866015_item	3139027	et	3	main
nagu	doc_101672866015_item	3139028	et	3	main
hingeline	doc_101672866015_item	3139029	et	4	main
talupoegade	doc_101672866015_item	3139036	et	3	main
nõudmine	doc_101672866015_item	3139038	et	4	main
tänu	doc_101672866015_item	3139040	et	4	main
adam	doc_101672866015_item	3139045	et	4	main
ja	doc_101672866015_item	3139066	et	3	main
adami	doc_101672866015_item	3139068	et	4	main
nad	doc_101672866015_item	3139073	et	3	main
aasta	doc_101672866015_item	3139076	et	4	main
pärast	doc_101672866015_item	3139077	et	4	main
13	doc_101672866015_item	3139078	et	2	main
veebruaril	doc_101672866015_item	3139079	et	3	main
algusest	doc_101672866015_item	3139085	et	4	main
oli	doc_101672866015_item	3139089	et	3	main
last	doc_101672866015_item	3139099	et	4	main
unustas	doc_101672866015_item	3139107	et	3	main
23	doc_101672866015_item	3139109	et	2	main
novembril	doc_101672866015_item	3139110	et	3	main
kotkas	doc_101672866015_item	3139122	et	4	main
vaatab	doc_101672866015_item	3139123	et	3	main
päikesesse	doc_101672866015_item	3139138	et	4	main
oma	doc_101672866015_item	3139149	et	4	main
õnne	doc_101672866015_item	3139150	et	4	main
või	doc_101672866015_item	3139188	et	4	main
mitte	doc_101672866015_item	3139189	et	3	main
1812	doc_101672866015_item	3139190	et	2	main
on	doc_101672866015_item	3139209	et	4	main
teada	doc_101672866015_item	3139210	et	3	main
1812	doc_101672866015_item	3139212	et	2	main
josephine	doc_101672866015_item	3139214	et	4	main
aprillil	doc_101672866015_item	3139223	et	3	main
sündis	doc_101672866015_item	3139226	et	3	main
on	doc_101672866015_item	3139234	et	4	main
pidanud	doc_101672866015_item	3139235	et	4	main
beethoveni	doc_101672866015_item	3139236	et	4	main
väliselt	doc_101672866015_item	3139242	et	4	main
minonast	doc_101672866015_item	3139246	et	4	main
christop	doc_101672866015_item	3139284	et	4	main
adam	doc_101672866015_item	3139285	et	4	main
josephine	doc_101672866015_item	3139288	et	4	main
ajaks	doc_101672866015_item	3139291	et	4	main
haige	doc_101672866015_item	3139292	et	4	main
ja	doc_101672866015_item	3139293	et	3	main
lapsed	doc_101672866015_item	3139299	et	3	main
temast	doc_101672866015_item	3139303	et	3	main
oma	doc_101672866015_item	3139305	et	4	main
viimseid	doc_101672866015_item	3139307	et	3	main
viinis	doc_101672866015_item	3139320	et	3	main
eestis	doc_101672866015_item	3139327	et	3	main
aastasena	doc_101672866015_item	3139331	et	4	main
4021846	doc_101672866015_item	3139341	et	2	main
päevikusse	doc_101672866015_item	3139344	et	4	main
a	doc_101672866015_item	3139361	et	4	main
her	doc_101672866015_item	3139377	et	4	main
would	doc_101672866015_item	3139380	et	4	main
been	doc_101672866015_item	3139382	et	4	main
oli	doc_101672866015_item	3138898	et	3	main
lõpetas	doc_101672866015_item	3138909	et	3	main
pärast	doc_101672866015_item	3138912	et	4	main
saksamaal	doc_101672866015_item	3138914	et	4	main
komitee	doc_101672866015_item	3138929	et	4	main
liige	doc_101672866015_item	3138930	et	4	main
asutas	doc_101672866015_item	3138931	et	3	main
pühapäeva-	doc_101672866015_item	3138932	et	4	main
ja	doc_101672866015_item	3138933	et	3	main
jooksul	doc_101672866015_item	3138940	et	4	main
ja	doc_101672866015_item	3138946	et	3	main
abielluski	doc_101672866015_item	3138949	et	3	main
brunswick	doc_101672866015_item	3138954	et	4	main
de	doc_101672866015_item	3138955	et	4	main
korompaga	doc_101672866015_item	3138956	et	4	main
huvitav	doc_101672866015_item	3138957	et	4	main
on	doc_101672866015_item	3138958	et	4	main
see	doc_101672866015_item	3138959	et	3	main
fakt	doc_101672866015_item	3138960	et	3	main
et	doc_101672866015_item	3138961	et	3	main
christop	doc_101672866015_item	3138962	et	4	main
adam	doc_101672866015_item	3138963	et	4	main
oli	doc_101672866015_item	3138964	et	3	main
seotud	doc_101672866015_item	3138965	et	4	main
hernhuutlusega7	doc_101672866015_item	3138966	et	2	main
vennaskoguduse	doc_101672866015_item	3138967	et	3	main
liikumisega	doc_101672866015_item	3138968	et	4	main
mille	doc_101672866015_item	3138969	et	3	main
peamine	doc_101672866015_item	3138970	et	3	main
religioosne	doc_101672866015_item	3138971	et	3	main
loosung	doc_101672866015_item	3138972	et	3	main
oli	doc_101672866015_item	3138973	et	3	main
päeva	doc_101672866015_item	3138974	et	4	main
mõte	doc_101672866015_item	3138975	et	3	main
päeva	doc_101672866015_item	3138976	et	4	main
palve	doc_101672866015_item	3138977	et	4	main
1730-ndatel	doc_101672866015_item	3138978	et	4	main
liikumine	doc_101672866015_item	3138979	et	4	main
rahvalik	doc_101672866015_item	3138985	et	3	main
demokraatlik	doc_101672866015_item	3138987	et	3	main
vennastekogudus	doc_101672866015_item	3138989	et	3	main
enesearendamisvõimalusi	doc_101672866015_item	3139003	et	4	main
tekitas	doc_101672866015_item	3139004	et	3	main
koos	doc_101672866015_item	3139012	et	4	main
eluviisi	doc_101672866015_item	3139019	et	4	main
vastuseis	doc_101672866015_item	3139023	et	4	main
mäss	doc_101672866015_item	3139032	et	3	main
pühapäeva-	doc_101672866015_item	3139047	et	4	main
rahvakooliõpetajate	doc_101672866015_item	3139051	et	3	main
kus	doc_101672866015_item	3139053	et	3	main
rahva	doc_101672866015_item	3139055	et	3	main
kalduvused	doc_101672866015_item	3139060	et	4	main
konflikti	doc_101672866015_item	3139070	et	4	main
põhjuseks	doc_101672866015_item	3139071	et	3	main
tulevikus	doc_101672866015_item	3139072	et	4	main
oli	doc_101672866015_item	3139081	et	3	main
problemaatiline	doc_101672866015_item	3139082	et	3	main
sest	doc_101672866015_item	3139087	et	4	main
katoliiklane	doc_101672866015_item	3139090	et	3	main
adam	doc_101672866015_item	3139092	et	4	main
aga	doc_101672866015_item	3139093	et	3	main
protestant	doc_101672866015_item	3139094	et	3	main
varsti	doc_101672866015_item	3139095	et	3	main
sündis	doc_101672866015_item	3139097	et	3	main
teophile	doc_101672866015_item	3139100	et	4	main
tõepoolest	doc_101672866015_item	3139105	et	3	main
mees	doc_101672866015_item	3139113	et	4	main
theresele	doc_101672866015_item	3139116	et	4	main
miks	doc_101672866015_item	3139125	et	4	main
see	doc_101672866015_item	3139126	et	3	main
taha	doc_101672866015_item	3139133	et	4	main
pilti	doc_101672866015_item	3139134	et	4	main
beethovenile	doc_101672866015_item	3139135	et	4	main
tagasi	doc_101672866015_item	3139136	et	3	main
anda	doc_101672866015_item	3139137	et	3	main
ju	doc_101672866015_item	3139142	et	3	main
kas	doc_101672866015_item	3139145	et	3	main
sellele	doc_101672866015_item	3139156	et	4	main
tundele	doc_101672866015_item	3139157	et	3	main
kuid	doc_101672866015_item	3139169	et	4	main
kahtlen	doc_101672866015_item	3139170	et	3	main
et	doc_101672866015_item	3139171	et	3	main
kunagi	doc_101672866015_item	3139172	et	3	main
neile	doc_101672866015_item	3139173	et	4	main
küsimustele	doc_101672866015_item	3139174	et	4	main
leidub	doc_101672866015_item	3139175	et	3	main
ole	doc_101672866015_item	3139178	et	4	main
josephine	doc_101672866015_item	3139181	et	4	main
aasta	doc_101672866015_item	3139191	et	4	main
adam	doc_101672866015_item	3139198	et	4	main
ning	doc_101672866015_item	3139202	et	3	main
ainult	doc_101672866015_item	3139204	et	4	main
aastal	doc_101672866015_item	3139213	et	3	main
beethoven	doc_101672866015_item	3139216	et	4	main
on	doc_101672866015_item	3139217	et	4	main
samal	doc_101672866015_item	3139218	et	3	main
1813	doc_101672866015_item	3139224	et	2	main
keda	doc_101672866015_item	3139231	et	4	main
lapseks	doc_101672866015_item	3139237	et	4	main
räägiti	doc_101672866015_item	3139238	et	3	main
tulevikus	doc_101672866015_item	3139245	et	4	main
abielulahutuse	doc_101672866015_item	3139280	et	4	main
1819	doc_101672866015_item	3139281	et	2	main
aastal	doc_101672866015_item	3139282	et	3	main
pöördub	doc_101672866015_item	3139283	et	3	main
kurnatud	doc_101672866015_item	3139294	et	4	main
ja	doc_101672866015_item	3139295	et	3	main
nõus	doc_101672866015_item	3139297	et	4	main
aastaid	doc_101672866015_item	3139308	et	4	main
elab	doc_101672866015_item	3139309	et	3	main
ta	doc_101672866015_item	3139310	et	4	main
elavad	doc_101672866015_item	3139324	et	4	main
loo	doc_101672866015_item	3139336	et	4	main
oma	doc_101672866015_item	3139343	et	4	main
like	doc_101672866015_item	3139348	et	4	main
a	doc_101672866015_item	3139349	et	4	main
was	doc_101672866015_item	3139353	et	4	main
the	doc_101672866015_item	3139354	et	4	main
friend	doc_101672866015_item	3139355	et	4	main
eestlastele	doc_101672866015_item	3138997	et	4	main
tegutsemis-	doc_101672866015_item	3139001	et	4	main
ja	doc_101672866015_item	3139002	et	3	main
traditsiooni	doc_101672866015_item	3139009	et	4	main
ja	doc_101672866015_item	3139010	et	3	main
sellega	doc_101672866015_item	3139011	et	3	main
distsiplineeritud	doc_101672866015_item	3139016	et	4	main
ja	doc_101672866015_item	3139017	et	3	main
kokkuhoidliku	doc_101672866015_item	3139018	et	3	main
teatud	doc_101672866015_item	3139022	et	4	main
religioosne	doc_101672866015_item	3139031	et	3	main
ja	doc_101672866015_item	3139035	et	3	main
henhuutluse	doc_101672866015_item	3139041	et	4	main
liikumise	doc_101672866015_item	3139042	et	4	main
mõjule	doc_101672866015_item	3139043	et	3	main
christop	doc_101672866015_item	3139044	et	4	main
asutaski	doc_101672866015_item	3139046	et	3	main
ning	doc_101672866015_item	3139050	et	3	main
valgustajana	doc_101672866015_item	3139056	et	4	main
tema	doc_101672866015_item	3139057	et	4	main
christoph	doc_101672866015_item	3139067	et	4	main
vahelise	doc_101672866015_item	3139069	et	4	main
abielu	doc_101672866015_item	3139080	et	4	main
juba	doc_101672866015_item	3139083	et	3	main
neil	doc_101672866015_item	3139096	et	4	main
kas	doc_101672866015_item	3139104	et	3	main
josephine	doc_101672866015_item	3139106	et	4	main
oluline	doc_101672866015_item	3139128	et	4	main
on	doc_101672866015_item	3139129	et	4	main
vaatav	doc_101672866015_item	3139139	et	4	main
kotkas	doc_101672866015_item	3139140	et	4	main
on	doc_101672866015_item	3139141	et	4	main
ohverdas	doc_101672866015_item	3139148	et	3	main
võib	doc_101672866015_item	3139164	et	3	main
vastus	doc_101672866015_item	3139176	et	3	main
teada	doc_101672866015_item	3139179	et	3	main
juunis	doc_101672866015_item	3139192	et	3	main
toimus	doc_101672866015_item	3139193	et	3	main
laura	doc_101672866015_item	3139103	et	4	main
beethoveni	doc_101672866015_item	3139108	et	4	main
1810	doc_101672866015_item	3139111	et	2	main
aastal	doc_101672866015_item	3139112	et	3	main
kirja	doc_101672866015_item	3139115	et	4	main
milles	doc_101672866015_item	3139117	et	3	main
palub	doc_101672866015_item	3139118	et	3	main
tagasi	doc_101672866015_item	3139119	et	3	main
pilti	doc_101672866015_item	3139120	et	4	main
millel	doc_101672866015_item	3139121	et	3	main
nii	doc_101672866015_item	3139127	et	3	main
armastuse	doc_101672866015_item	3139143	et	4	main
naine	doc_101672866015_item	3139147	et	3	main
armastuse	doc_101672866015_item	3139152	et	4	main
truu	doc_101672866015_item	3139158	et	4	main
ei	doc_101672866015_item	3139177	et	4	main
kas	doc_101672866015_item	3139180	et	3	main
oleks	doc_101672866015_item	3139182	et	3	main
nende	doc_101672866015_item	3139194	et	4	main
perekonnal	doc_101672866015_item	3139195	et	4	main
abielukriis	doc_101672866015_item	3139196	et	3	main
juurest	doc_101672866015_item	3139201	et	4	main
tuli	doc_101672866015_item	3139203	et	4	main
6	doc_101672866015_item	3139205	et	2	main
kuu	doc_101672866015_item	3139206	et	4	main
ja	doc_101672866015_item	3139215	et	3	main
ning	doc_101672866015_item	3139221	et	3	main
seitsmes	doc_101672866015_item	3139228	et	4	main
mõned	doc_101672866015_item	3139232	et	3	main
uurijad	doc_101672866015_item	3139233	et	4	main
et	doc_101672866015_item	3139239	et	3	main
oma	doc_101672866015_item	3139243	et	4	main
mehest	doc_101672866015_item	3139274	et	4	main
tagasi	doc_101672866015_item	3139287	et	3	main
toole	doc_101672866015_item	3139290	et	3	main
koos	doc_101672866015_item	3139300	et	4	main
koos	doc_101672866015_item	3139311	et	4	main
abielust	doc_101672866015_item	3139319	et	3	main
sureb	doc_101672866015_item	3139329	et	3	main
pärast	doc_101672866015_item	3139332	et	4	main
seda	doc_101672866015_item	3139333	et	3	main
kui	doc_101672866015_item	3139334	et	3	main
kõik	doc_101672866015_item	3139335	et	4	main
therese	doc_101672866015_item	3139342	et	4	main
beethoven	doc_101672866015_item	3139345	et	4	main
it	doc_101672866015_item	3139346	et	4	main
dream	doc_101672866015_item	3139350	et	4	main
that	doc_101672866015_item	3139351	et	4	main
our	doc_101672866015_item	3139359	et	4	main
stupendous	doc_101672866015_item	3139362	et	4	main
my	doc_101672866015_item	3139367	et	4	main
widow	doc_101672866015_item	3139372	et	4	main
deym	doc_101672866015_item	3139373	et	4	main
accept	doc_101672866015_item	3139374	et	4	main
than	doc_101672866015_item	3139385	et	4	main
maternal	doc_101672866015_item	3139390	et	4	main
was	doc_101672866015_item	3139401	et	4	main
friendin	doc_101672866015_item	3139409	et	4	main
born	doc_101672866015_item	3139415	et	4	main
they	doc_101672866015_item	3139421	et	4	main
maternal	doc_101672866015_item	3139430	et	4	main
love	doc_101672866015_item	3139431	et	4	main
armastus	doc_101672866015_item	3139440	et	4	main
ongi	doc_101672866015_item	3139447	et	4	main
224	doc_101672866015_item	3139454	et	2	main
tänapäeva	doc_101672866015_item	3139456	et	4	main
planeerib	doc_101672866015_item	3139460	et	3	main
peamistest	doc_101672866015_item	3139471	et	4	main
praegu	doc_101672866015_item	3139473	et	3	main
selle	doc_101672866015_item	3139474	et	4	main
et	doc_101672866015_item	3139211	et	3	main
prahas	doc_101672866015_item	3139220	et	4	main
18	doc_101672866015_item	3139222	et	2	main
erines	doc_101672866015_item	3139241	et	3	main
õdedest	doc_101672866015_item	3139244	et	3	main
saab	doc_101672866015_item	3139247	et	3	main
silmapaistev	doc_101672866015_item	3139248	et	4	main
muusik	doc_101672866015_item	3139249	et	3	main
ja	doc_101672866015_item	3139250	et	3	main
klaveripedagoog	doc_101672866015_item	3139251	et	3	main
kolm	doc_101672866015_item	3139252	et	3	main
kuud	doc_101672866015_item	3139253	et	4	main
pärast	doc_101672866015_item	3139254	et	4	main
tüdruku	doc_101672866015_item	3139255	et	3	main
sündi	doc_101672866015_item	3139256	et	4	main
lahkub	doc_101672866015_item	3139257	et	3	main
christop	doc_101672866015_item	3139258	et	4	main
adam	doc_101672866015_item	3139259	et	4	main
taas	doc_101672866015_item	3139260	et	3	main
perekonna	doc_101672866015_item	3139261	et	4	main
juurest	doc_101672866015_item	3139262	et	4	main
pärast	doc_101672866015_item	3139263	et	4	main
tuleb	doc_101672866015_item	3139264	et	3	main
vaid	doc_101672866015_item	3139265	et	3	main
harva	doc_101672866015_item	3139266	et	4	main
ja	doc_101672866015_item	3139267	et	3	main
lühikesteks	doc_101672866015_item	3139268	et	4	main
perioodideks	doc_101672866015_item	3139269	et	3	main
tagasi	doc_101672866015_item	3139270	et	3	main
varsti	doc_101672866015_item	3139271	et	3	main
josephine	doc_101672866015_item	3139272	et	4	main
nõuab	doc_101672866015_item	3139273	et	3	main
ja	doc_101672866015_item	3139277	et	3	main
eemaldamist	doc_101672866015_item	3139275	et	4	main
voodist	doc_101672866015_item	3139276	et	3	main
lauast	doc_101672866015_item	3139278	et	4	main
ehk	doc_101672866015_item	3139279	et	3	main
viini	doc_101672866015_item	3139286	et	4	main
on	doc_101672866015_item	3139289	et	4	main
et	doc_101672866015_item	3139298	et	3	main
on	doc_101672866015_item	3139302	et	4	main
eemal	doc_101672866015_item	3139304	et	3	main
elu	doc_101672866015_item	3139306	et	4	main
kolm	doc_101672866015_item	3139321	et	3	main
last	doc_101672866015_item	3139323	et	4	main
aga	doc_101672866015_item	3139325	et	3	main
josephine	doc_101672866015_item	3139328	et	4	main
peategelased	doc_101672866015_item	3139337	et	3	main
on	doc_101672866015_item	3139338	et	4	main
seems	doc_101672866015_item	3139347	et	4	main
he	doc_101672866015_item	3139352	et	4	main
intimate	doc_101672866015_item	3139357	et	4	main
did	doc_101672866015_item	3139365	et	4	main
as	doc_101672866015_item	3139370	et	4	main
him	doc_101672866015_item	3139375	et	4	main
she	doc_101672866015_item	3139379	et	4	main
she	doc_101672866015_item	3139386	et	4	main
own	doc_101672866015_item	3139397	et	4	main
he	doc_101672866015_item	3139399	et	4	main
who	doc_101672866015_item	3139400	et	4	main
like	doc_101672866015_item	3139404	et	4	main
heart	doc_101672866015_item	3139412	et	4	main
each	doc_101672866015_item	3139417	et	4	main
living	doc_101672866015_item	3139428	et	4	main
now8	doc_101672866015_item	3139429	et	2	main
to	doc_101672866015_item	3139434	et	4	main
ema	doc_101672866015_item	3139439	et	4	main
teda	doc_101672866015_item	3139442	et	4	main
romaanide	doc_101672866015_item	3139452	et	3	main
väänas	doc_101672866015_item	3139462	et	3	main
muuseumi	doc_101672866015_item	3139463	et	4	main
selle	doc_101672866015_item	3139465	et	4	main
pärildest	doc_101672866015_item	3139472	et	4	main
tahetakse	doc_101672866015_item	3139477	et	4	main
kirju	doc_101672866015_item	3139503	et	4	main
selle	doc_101672866015_item	3139512	et	4	main
kes	doc_101672866015_item	3139518	et	4	main
kavatsetakse	doc_101672866015_item	3139522	et	3	main
selle	doc_101672866015_item	3139529	et	4	main
suhe	doc_101672866015_item	3139530	et	3	main
pealt	doc_101672866015_item	3139531	et	4	main
anda	doc_101672866015_item	3139539	et	3	main
loole	doc_101672866015_item	3139540	et	4	main
tervikuna	doc_101672866015_item	3139541	et	3	main
muidu	doc_101672866015_item	3139542	et	3	main
just	doc_101672866015_item	3139543	et	3	main
temast	doc_101672866015_item	3139544	et	3	main
lavastuse	doc_101672866015_item	3139545	et	4	main
peategelast	doc_101672866015_item	3139546	et	3	main
kes	doc_101672866015_item	3139547	et	4	main
oleks	doc_101672866015_item	3139548	et	3	main
nagu	doc_101672866015_item	3139549	et	3	main
kahjuks	doc_101672866015_item	3139556	et	4	main
kirjad	doc_101672866015_item	3139559	et	4	main
eesti	doc_101672866015_item	3139562	et	4	main
palju	doc_101672866015_item	3139569	et	4	main
lisauuringuid	doc_101672866015_item	3139570	et	3	main
ja	doc_101672866015_item	3139571	et	3	main
kuid	doc_101672866015_item	3139575	et	4	main
on	doc_101672866015_item	3139579	et	4	main
üsna	doc_101672866015_item	3139586	et	3	main
saladustele	doc_101672866015_item	3139604	et	4	main
mõisa	doc_101672866015_item	3139608	et	3	main
oma	doc_101672866015_item	3139616	et	4	main
instituut	doc_101672866015_item	3139625	et	3	main
kingiti	doc_101672866015_item	3139629	et	3	main
mõned	doc_101672866015_item	3139631	et	3	main
nimetus	doc_101672866015_item	3139658	et	4	main
tuleneb	doc_101672866015_item	3139659	et	3	main
harkko	doc_101672866015_item	3139662	et	4	main
seega	doc_101672866015_item	3139665	et	4	main
tuleb	doc_101672866015_item	3139666	et	3	main
arvata	doc_101672866015_item	3139667	et	4	main
et	doc_101672866015_item	3139668	et	3	main
soome	doc_101672866015_item	3139673	et	3	main
mehega	doc_101672866015_item	3139301	et	3	main
oma	doc_101672866015_item	3139312	et	4	main
õe	doc_101672866015_item	3139313	et	4	main
teresia	doc_101672866015_item	3139314	et	4	main
ja	doc_101672866015_item	3139315	et	3	main
nelja	doc_101672866015_item	3139316	et	4	main
lapsega	doc_101672866015_item	3139317	et	3	main
esimesest	doc_101672866015_item	3139318	et	3	main
viimast	doc_101672866015_item	3139322	et	4	main
isaga	doc_101672866015_item	3139326	et	3	main
42	doc_101672866015_item	3139330	et	2	main
surnud	doc_101672866015_item	3139339	et	4	main
kirjutab	doc_101672866015_item	3139340	et	3	main
of	doc_101672866015_item	3139358	et	4	main
not	doc_101672866015_item	3139366	et	4	main
the	doc_101672866015_item	3139371	et	4	main
as	doc_101672866015_item	3139376	et	4	main
happier	doc_101672866015_item	3139384	et	4	main
stackelberg	doc_101672866015_item	3139389	et	4	main
love	doc_101672866015_item	3139391	et	4	main
caused	doc_101672866015_item	3139392	et	4	main
her	doc_101672866015_item	3139393	et	4	main
to	doc_101672866015_item	3139394	et	4	main
forgo	doc_101672866015_item	3139395	et	4	main
her	doc_101672866015_item	3139396	et	4	main
house	doc_101672866015_item	3139410	et	4	main
and	doc_101672866015_item	3139411	et	3	main
for	doc_101672866015_item	3139416	et	4	main
been	doc_101672866015_item	3139422	et	4	main
would	doc_101672866015_item	3139425	et	4	main
her	doc_101672866015_item	3139433	et	4	main
happiness	doc_101672866015_item	3139438	et	4	main
õnne	doc_101672866015_item	3139443	et	4	main
loo	doc_101672866015_item	3139455	et	4	main
tähtsus	doc_101672866015_item	3139457	et	4	main
harku	doc_101672866015_item	3139458	et	4	main
tegelased	doc_101672866015_item	3139498	et	3	main
lühikesi	doc_101672866015_item	3139505	et	4	main
stseene	doc_101672866015_item	3139506	et	3	main
eksisteerivad	doc_101672866015_item	3139509	et	4	main
reaalsed	doc_101672866015_item	3139510	et	3	main
plaanid	doc_101672866015_item	3139511	et	4	main
kogu	doc_101672866015_item	3139519	et	4	main
organiseeriks	doc_101672866015_item	3139521	et	3	main
theresa	doc_101672866015_item	3139524	et	4	main
päevikuid	doc_101672866015_item	3139525	et	4	main
nägija	doc_101672866015_item	3139532	et	4	main
ning	doc_101672866015_item	3139533	et	3	main
just	doc_101672866015_item	3139534	et	3	main
jutustaja	doc_101672866015_item	3139553	et	4	main
ole	doc_101672866015_item	3139561	et	4	main
ise	doc_101672866015_item	3139567	et	4	main
nõuab	doc_101672866015_item	3139568	et	3	main
plaanid	doc_101672866015_item	3139576	et	4	main
varsti	doc_101672866015_item	3139587	et	3	main
jälle	doc_101672866015_item	3139597	et	3	main
hoone	doc_101672866015_item	3139615	et	4	main
vangla	doc_101672866015_item	3139624	et	4	main
siin	doc_101672866015_item	3139634	et	4	main
harku	doc_101672866015_item	3139654	et	4	main
sõnast	doc_101672866015_item	3139661	et	4	main
kivipank	doc_101672866015_item	3139664	et	3	main
ühis	doc_101672866015_item	3139672	et	4	main
200-100	doc_101672866015_item	3139676	et	2	main
aastat	doc_101672866015_item	3139677	et	3	main
enne	doc_101672866015_item	3139678	et	4	main
et	doc_101672866015_item	3139691	et	3	main
maalehe	doc_101672866015_item	3139698	et	3	main
tallinnast	doc_101672866015_item	3139700	et	3	main
tähendab	doc_101672866015_item	3139708	et	3	main
ning	doc_101672866015_item	3139712	et	3	main
eriti	doc_101672866015_item	3139716	et	3	main
küla	doc_101672866015_item	3139724	et	4	main
harke	doc_101672866015_item	3139731	et	3	main
aasta	doc_101672866015_item	3139748	et	4	main
ajaloost10	doc_101672866015_item	3139758	et	2	main
the	doc_101672866015_item	3139356	et	4	main
house	doc_101672866015_item	3139360	et	4	main
spirit	doc_101672866015_item	3139363	et	4	main
why	doc_101672866015_item	3139364	et	4	main
sister	doc_101672866015_item	3139368	et	4	main
j	doc_101672866015_item	3139369	et	4	main
husband	doc_101672866015_item	3139378	et	4	main
have	doc_101672866015_item	3139381	et	4	main
was	doc_101672866015_item	3139387	et	4	main
with	doc_101672866015_item	3139388	et	4	main
happinessbeethoven	doc_101672866015_item	3139398	et	4	main
her	doc_101672866015_item	3139405	et	4	main
spirit	doc_101672866015_item	3139407	et	4	main
josephines	doc_101672866015_item	3139408	et	4	main
other	doc_101672866015_item	3139418	et	4	main
they	doc_101672866015_item	3139424	et	4	main
have	doc_101672866015_item	3139426	et	4	main
been	doc_101672866015_item	3139427	et	4	main
caused	doc_101672866015_item	3139432	et	4	main
own	doc_101672866015_item	3139437	et	4	main
pani	doc_101672866015_item	3139441	et	4	main
sõnad	doc_101672866015_item	3139446	et	4	main
kõikidele	doc_101672866015_item	3139448	et	4	main
küsimustele	doc_101672866015_item	3139449	et	4	main
vald	doc_101672866015_item	3139459	et	3	main
muuseumi	doc_101672866015_item	3139470	et	4	main
põhjal	doc_101672866015_item	3139476	et	4	main
loo	doc_101672866015_item	3139497	et	4	main
loeksid	doc_101672866015_item	3139499	et	4	main
oma	doc_101672866015_item	3139502	et	4	main
juba	doc_101672866015_item	3139508	et	3	main
inimesi	doc_101672866015_item	3139517	et	4	main
tööd	doc_101672866015_item	3139520	et	4	main
uurida	doc_101672866015_item	3139523	et	3	main
pilti	doc_101672866015_item	3139538	et	4	main
loo	doc_101672866015_item	3139552	et	4	main
kõik	doc_101672866015_item	3139557	et	4	main
tõlgitud	doc_101672866015_item	3139564	et	4	main
enda	doc_101672866015_item	3139573	et	4	main
loota	doc_101672866015_item	3139584	et	4	main
et	doc_101672866015_item	3139585	et	3	main
much	doc_101672866015_item	3139383	et	4	main
so	doc_101672866015_item	3139402	et	4	main
very	doc_101672866015_item	3139403	et	4	main
in	doc_101672866015_item	3139406	et	4	main
they	doc_101672866015_item	3139413	et	4	main
were	doc_101672866015_item	3139414	et	4	main
and	doc_101672866015_item	3139419	et	3	main
had	doc_101672866015_item	3139420	et	4	main
united	doc_101672866015_item	3139423	et	4	main
forgot	doc_101672866015_item	3139435	et	4	main
her	doc_101672866015_item	3139436	et	4	main
unustama	doc_101672866015_item	3139444	et	3	main
need	doc_101672866015_item	3139445	et	3	main
vastuseks	doc_101672866015_item	3139450	et	4	main
paljude	doc_101672866015_item	3139451	et	3	main
traagikaks	doc_101672866015_item	3139453	et	3	main
rajada	doc_101672866015_item	3139461	et	3	main
ja	doc_101672866015_item	3139464	et	3	main
loo	doc_101672866015_item	3139466	et	4	main
lavastus	doc_101672866015_item	3139467	et	4	main
oleks	doc_101672866015_item	3139468	et	3	main
üks	doc_101672866015_item	3139469	et	3	main
loo	doc_101672866015_item	3139475	et	4	main
teha	doc_101672866015_item	3139478	et	3	main
lavastuse	doc_101672866015_item	3139479	et	4	main
mille	doc_101672866015_item	3139480	et	3	main
taustaks	doc_101672866015_item	3139481	et	3	main
ja	doc_101672866015_item	3139482	et	3	main
vahepaladeks	doc_101672866015_item	3139483	et	3	main
oleks	doc_101672866015_item	3139484	et	3	main
beethoveni	doc_101672866015_item	3139485	et	4	main
muusika	doc_101672866015_item	3139486	et	4	main
ekraanil	doc_101672866015_item	3139487	et	3	main
võiks	doc_101672866015_item	3139488	et	4	main
näidata	doc_101672866015_item	3139489	et	4	main
looga	doc_101672866015_item	3139490	et	4	main
seonduvaid	doc_101672866015_item	3139491	et	4	main
pilte	doc_101672866015_item	3139492	et	3	main
ehk	doc_101672866015_item	3139493	et	3	main
inimesi	doc_101672866015_item	3139494	et	4	main
asju	doc_101672866015_item	3139495	et	3	main
kohti	doc_101672866015_item	3139496	et	4	main
monolooge	doc_101672866015_item	3139500	et	4	main
ja	doc_101672866015_item	3139501	et	3	main
praegu	doc_101672866015_item	3139507	et	3	main
sest	doc_101672866015_item	3139526	et	4	main
tema	doc_101672866015_item	3139535	et	4	main
oskas	doc_101672866015_item	3139536	et	3	main
ning	doc_101672866015_item	3139554	et	3	main
keelde	doc_101672866015_item	3139563	et	4	main
tööd	doc_101672866015_item	3139572	et	4	main
selle	doc_101672866015_item	3139577	et	4	main
olemas	doc_101672866015_item	3139581	et	4	main
seega	doc_101672866015_item	3139582	et	4	main
jääb	doc_101672866015_item	3139583	et	3	main
von	doc_101672866015_item	3139599	et	4	main
harku	doc_101672866015_item	3139606	et	4	main
on	doc_101672866015_item	3139610	et	4	main
oma	doc_101672866015_item	3139613	et	4	main
ajalooga	doc_101672866015_item	3139614	et	4	main
tihti	doc_101672866015_item	3139627	et	3	main
renditi	doc_101672866015_item	3139630	et	3	main
tulu	doc_101672866015_item	3139637	et	4	main
soomekeelsest	doc_101672866015_item	3139660	et	3	main
mängiksid	doc_101672866015_item	3139504	et	4	main
lavastuse	doc_101672866015_item	3139513	et	4	main
läbiviimiseks	doc_101672866015_item	3139514	et	3	main
ning	doc_101672866015_item	3139515	et	3	main
otsitakse	doc_101672866015_item	3139516	et	3	main
tema	doc_101672866015_item	3139527	et	4	main
oli	doc_101672866015_item	3139528	et	3	main
erapooletu	doc_101672866015_item	3139537	et	4	main
pealtnägija	doc_101672866015_item	3139550	et	4	main
ja	doc_101672866015_item	3139551	et	3	main
kommenteerija	doc_101672866015_item	3139555	et	4	main
need	doc_101672866015_item	3139558	et	3	main
ei	doc_101672866015_item	3139560	et	4	main
ning	doc_101672866015_item	3139565	et	3	main
lugu	doc_101672866015_item	3139566	et	4	main
kaldal	doc_101672866015_item	3139574	et	3	main
kohta	doc_101672866015_item	3139578	et	4	main
juba	doc_101672866015_item	3139580	et	3	main
see	doc_101672866015_item	3139588	et	3	main
armastuslugu	doc_101672866015_item	3139589	et	4	main
ärkab	doc_101672866015_item	3139590	et	3	main
taas	doc_101672866015_item	3139591	et	3	main
ning	doc_101672866015_item	3139592	et	3	main
vääna	doc_101672866015_item	3139593	et	4	main
mõisa	doc_101672866015_item	3139594	et	3	main
seinad	doc_101672866015_item	3139595	et	3	main
saavad	doc_101672866015_item	3139596	et	4	main
tunnistajateks	doc_101672866015_item	3139598	et	4	main
stackelbergide	doc_101672866015_item	3139600	et	4	main
perekonna	doc_101672866015_item	3139601	et	4	main
draamale	doc_101672866015_item	3139602	et	3	main
ja	doc_101672866015_item	3139603	et	3	main
harku	doc_101672866015_item	3139607	et	4	main
rikkalik	doc_101672866015_item	3139612	et	3	main
elu	doc_101672866015_item	3139617	et	4	main
jooksul	doc_101672866015_item	3139618	et	4	main
oli	doc_101672866015_item	3139619	et	3	main
nii	doc_101672866015_item	3139620	et	3	main
orduloss	doc_101672866015_item	3139621	et	3	main
mõisnike	doc_101672866015_item	3139622	et	3	main
puhkemaja	doc_101672866015_item	3139623	et	4	main
müüdi	doc_101672866015_item	3139628	et	4	main
omanikud	doc_101672866015_item	3139632	et	3	main
nimetus	doc_101672866015_item	3139669	et	4	main
pärineb	doc_101672866015_item	3139670	et	3	main
veel	doc_101672866015_item	3139671	et	4	main
johann	doc_101672866015_item	3139682	et	4	main
ütleb	doc_101672866015_item	3139690	et	3	main
hunnik	doc_101672866015_item	3139694	et	3	main
agu	doc_101672866015_item	3139696	et	4	main
veetammi	doc_101672866015_item	3139697	et	4	main
raamatus	doc_101672866015_item	3139699	et	4	main
metalli-	doc_101672866015_item	3139709	et	4	main
arvamust	doc_101672866015_item	3139715	et	3	main
harkua	doc_101672866015_item	3139727	et	4	main
siinset	doc_101672866015_item	3139729	et	3	main
tallinna	doc_101672866015_item	3139738	et	4	main
ümbruse	doc_101672866015_item	3139739	et	3	main
rahva	doc_101672866015_item	3139740	et	3	main
raamatus	doc_101672866015_item	3139755	et	4	main
esimesed	doc_101672866015_item	3139761	et	3	main
suguvõsa	doc_101672866015_item	3139763	et	4	main
harke	doc_101672866015_item	3139765	et	3	main
harke	doc_101672866015_item	3139797	et	3	main
aga	doc_101672866015_item	3139800	et	3	main
peale	doc_101672866015_item	3139807	et	4	main
märgitud	doc_101672866015_item	3139813	et	4	main
et	doc_101672866015_item	3139814	et	3	main
mõnel	doc_101672866015_item	3139819	et	3	main
harkust	doc_101672866015_item	3139826	et	3	main
pärinevad	doc_101672866015_item	3139827	et	4	main
talupojad	doc_101672866015_item	3139828	et	4	main
3	doc_101672866015_item	3139605	et	2	main
ajalugu	doc_101672866015_item	3139609	et	4	main
väga	doc_101672866015_item	3139611	et	3	main
seda	doc_101672866015_item	3139626	et	3	main
otsisid	doc_101672866015_item	3139633	et	4	main
lõbu	doc_101672866015_item	3139635	et	4	main
teised	doc_101672866015_item	3139636	et	4	main
harku	doc_101672866015_item	3139638	et	4	main
mõis	doc_101672866015_item	3139639	et	3	main
on	doc_101672866015_item	3139640	et	4	main
vaidlemata	doc_101672866015_item	3139641	et	4	main
harku	doc_101672866015_item	3139642	et	4	main
valla	doc_101672866015_item	3139643	et	4	main
üks	doc_101672866015_item	3139644	et	3	main
kuulsamaid	doc_101672866015_item	3139645	et	4	main
vaatamisväärsusi	doc_101672866015_item	3139646	et	4	main
kas	doc_101672866015_item	3139647	et	3	main
juba	doc_101672866015_item	3139648	et	3	main
sellepoolest	doc_101672866015_item	3139649	et	4	main
et	doc_101672866015_item	3139650	et	3	main
see	doc_101672866015_item	3139651	et	3	main
oli	doc_101672866015_item	3139652	et	3	main
esimene	doc_101672866015_item	3139653	et	3	main
nimetuse	doc_101672866015_item	3139655	et	4	main
kandja	doc_101672866015_item	3139656	et	4	main
harku	doc_101672866015_item	3139657	et	4	main
meie	doc_101672866015_item	3139679	et	4	main
ajaarvamist9	doc_101672866015_item	3139680	et	2	main
öeldut	doc_101672866015_item	3139704	et	4	main
sõna	doc_101672866015_item	3139707	et	4	main
kivikamakat	doc_101672866015_item	3139711	et	3	main
ei	doc_101672866015_item	3139717	et	4	main
sest	doc_101672866015_item	3139719	et	4	main
mõnes	doc_101672866015_item	3139720	et	3	main
ürikus	doc_101672866015_item	3139721	et	3	main
on	doc_101672866015_item	3139722	et	4	main
ka	doc_101672866015_item	3139726	et	3	main
ja	doc_101672866015_item	3139728	et	3	main
ristimisega	doc_101672866015_item	3139741	et	4	main
mis	doc_101672866015_item	3139742	et	4	main
oli	doc_101672866015_item	3139743	et	3	main
juuni-	doc_101672866015_item	3139749	et	4	main
ja	doc_101672866015_item	3139750	et	3	main
juulikuus	doc_101672866015_item	3139751	et	3	main
p	doc_101672866015_item	3139752	et	4	main
harku	doc_101672866015_item	3139756	et	4	main
mõisa	doc_101672866015_item	3139757	et	3	main
de	doc_101672866015_item	3139764	et	4	main
et	doc_101672866015_item	3139771	et	3	main
kandjaid	doc_101672866015_item	3139799	et	4	main
enam	doc_101672866015_item	3139803	et	4	main
harkus	doc_101672866015_item	3139804	et	3	main
ei	doc_101672866015_item	3139805	et	4	main
liignimi	doc_101672866015_item	3139815	et	4	main
käsitöölisel	doc_101672866015_item	3139823	et	3	main
de	doc_101672866015_item	3139832	et	4	main
harke	doc_101672866015_item	3139833	et	3	main
1490	doc_101672866015_item	3139834	et	2	main
claves	doc_101672866015_item	3139839	et	4	main
mõisa	doc_101672866015_item	3139842	et	3	main
1371	doc_101672866015_item	3139847	et	2	main
alluv	doc_101672866015_item	3139859	et	4	main
ordulinnusena	doc_101672866015_item	3139863	et	3	main
aastal	doc_101672866015_item	3139870	et	3	main
kui	doc_101672866015_item	3139872	et	3	main
harku	doc_101672866015_item	3139899	et	4	main
lähedal	doc_101672866015_item	3139901	et	4	main
ehk	doc_101672866015_item	3139904	et	3	main
osa	doc_101672866015_item	3139913	et	4	main
1612	doc_101672866015_item	3139914	et	2	main
aastal	doc_101672866015_item	3139915	et	3	main
aga	doc_101672866015_item	3139916	et	3	main
kingib	doc_101672866015_item	3139917	et	3	main
harku	doc_101672866015_item	3139922	et	4	main
külad	doc_101672866015_item	3139923	et	3	main
kroonikates	doc_101672866015_item	3139932	et	4	main
tühjaksjäänud	doc_101672866015_item	3139936	et	4	main
pole	doc_101672866015_item	3139938	et	3	main
ajal	doc_101672866015_item	3139949	et	4	main
1641	doc_101672866015_item	3139952	et	2	main
aastal	doc_101672866015_item	3139953	et	3	main
kuningas	doc_101672866015_item	3139954	et	4	main
vahel	doc_101672866015_item	3140003	et	4	main
harku	doc_101672866015_item	3140005	et	4	main
alistusid	doc_101672866015_item	3140012	et	4	main
vene	doc_101672866015_item	3140013	et	4	main
vägedele	doc_101672866015_item	3140014	et	3	main
311	doc_101672866015_item	3140020	et	2	main
harku	doc_101672866015_item	3140025	et	4	main
peter	doc_101672866015_item	3140028	et	4	main
ludwig	doc_101672866015_item	3140029	et	4	main
constantin	doc_101672866015_item	3140030	et	4	main
röövelparuni	doc_101672866015_item	3140036	et	4	main
poeg	doc_101672866015_item	3140037	et	3	main
teenis	doc_101672866015_item	3140038	et	3	main
oma	doc_101672866015_item	3140041	et	4	main
vene	doc_101672866015_item	3140043	et	4	main
sõjaväele	doc_101672866015_item	3140044	et	3	main
vilja	doc_101672866015_item	3140045	et	4	main
ja	doc_101672866015_item	3140046	et	3	main
kokku	doc_101672866015_item	3140062	et	3	main
osta	doc_101672866015_item	3140063	et	4	main
nii	doc_101672866015_item	3140064	et	3	main
tast	doc_101672866015_item	3140066	et	3	main
suurim	doc_101672866015_item	3140067	et	3	main
ehk	doc_101672866015_item	3139663	et	3	main
mathias	doc_101672866015_item	3139681	et	4	main
hindamise	doc_101672866015_item	3139688	et	4	main
raamat	doc_101672866015_item	3139689	et	3	main
ajastust	doc_101672866015_item	3139674	et	4	main
ligikaudu	doc_101672866015_item	3139675	et	3	main
eisen	doc_101672866015_item	3139683	et	4	main
aga	doc_101672866015_item	3139684	et	3	main
oma	doc_101672866015_item	3139685	et	4	main
teoses	doc_101672866015_item	3139686	et	3	main
daani	doc_101672866015_item	3139687	et	4	main
harku	doc_101672866015_item	3139692	et	4	main
tähendab	doc_101672866015_item	3139693	et	3	main
hulk	doc_101672866015_item	3139695	et	3	main
keila-	doc_101672866015_item	3139701	et	4	main
joale	doc_101672866015_item	3139702	et	3	main
on	doc_101672866015_item	3139703	et	4	main
või	doc_101672866015_item	3139710	et	4	main
ajaloolased	doc_101672866015_item	3139713	et	3	main
toeta	doc_101672866015_item	3139718	et	4	main
nimetatud	doc_101672866015_item	3139725	et	4	main
ordumõisa	doc_101672866015_item	3139730	et	3	main
harkut	doc_101672866015_item	3139734	et	4	main
hindamisraamatus	doc_101672866015_item	3139736	et	4	main
seoses	doc_101672866015_item	3139737	et	4	main
rahno	doc_101672866015_item	3139753	et	4	main
räägib	doc_101672866015_item	3139759	et	3	main
nime	doc_101672866015_item	3139798	et	4	main
need	doc_101672866015_item	3139801	et	3	main
inimesed	doc_101672866015_item	3139802	et	3	main
harke	doc_101672866015_item	3139816	et	3	main
a	doc_101672866015_item	3139835	et	4	main
31	doc_101672866015_item	3139841	et	2	main
xvi	doc_101672866015_item	3139852	et	4	main
sajandil	doc_101672866015_item	3139853	et	3	main
enam	doc_101672866015_item	3139862	et	4	main
vaid	doc_101672866015_item	3139864	et	3	main
märgitakse	doc_101672866015_item	3139866	et	4	main
ajaloos	doc_101672866015_item	3139911	et	4	main
adolf	doc_101672866015_item	3139920	et	4	main
schrapfferile	doc_101672866015_item	3139928	et	4	main
1617	doc_101672866015_item	3139929	et	2	main
aastal	doc_101672866015_item	3139930	et	3	main
märgitakse	doc_101672866015_item	3139931	et	4	main
mõisa	doc_101672866015_item	3139935	et	3	main
oletada	doc_101672866015_item	3139942	et	3	main
tool	doc_101672866015_item	3139948	et	3	main
levinud	doc_101672866015_item	3139950	et	4	main
katk	doc_101672866015_item	3139951	et	3	main
kingib	doc_101672866015_item	3139957	et	3	main
ja	doc_101672866015_item	3140001	et	3	main
eestimaal	doc_101672866015_item	3140019	et	4	main
1830	doc_101672866015_item	3140023	et	2	main
mõisat	doc_101672866015_item	3140026	et	3	main
suur	doc_101672866015_item	3140039	et	3	main
ajal	doc_101672866015_item	3140050	et	4	main
baltimaadel	doc_101672866015_item	3140051	et	4	main
valitses	doc_101672866015_item	3140052	et	3	main
majanduskriis	doc_101672866015_item	3140053	et	3	main
paljud	doc_101672866015_item	3140054	et	3	main
mõisad	doc_101672866015_item	3140055	et	3	main
jäid	doc_101672866015_item	3140056	et	4	main
puuliike	doc_101672866015_item	3140099	et	4	main
reliktjärveke	doc_101672866015_item	3140101	et	4	main
süvendatakse	doc_101672866015_item	3140102	et	3	main
ja	doc_101672866015_item	3140103	et	3	main
muudetakse	doc_101672866015_item	3140104	et	3	main
tiigiks	doc_101672866015_item	3140105	et	3	main
peamiseks	doc_101672866015_item	3140106	et	3	main
kasvatusega	doc_101672866015_item	3140115	et	4	main
viimane	doc_101672866015_item	3140116	et	3	main
sternberg	doc_101672866015_item	3140124	et	4	main
tool	doc_101672866015_item	3140128	et	3	main
et	doc_101672866015_item	3140131	et	3	main
olnud	doc_101672866015_item	3140133	et	4	main
vandenõusse	doc_101672866015_item	3140136	et	3	main
põgenenud	doc_101672866015_item	3140137	et	4	main
sellepärast	doc_101672866015_item	3140138	et	3	main
kulla	doc_101672866015_item	3140144	et	4	main
maa	doc_101672866015_item	3140147	et	4	main
sepp	doc_101672866015_item	3140155	et	3	main
põldroos	doc_101672866015_item	3140157	et	4	main
viimase	doc_101672866015_item	3140164	et	3	main
sõnul	doc_101672866015_item	3140198	et	3	main
naine	doc_101672866015_item	3140212	et	3	main
et	doc_101672866015_item	3139705	et	3	main
see	doc_101672866015_item	3139706	et	3	main
eeltoodud	doc_101672866015_item	3139714	et	3	main
harku	doc_101672866015_item	3139723	et	4	main
esmakordselt	doc_101672866015_item	3139732	et	4	main
mainitakse	doc_101672866015_item	3139733	et	3	main
taani	doc_101672866015_item	3139735	et	4	main
korraldatud	doc_101672866015_item	3139744	et	4	main
taanlaste	doc_101672866015_item	3139745	et	3	main
poolt	doc_101672866015_item	3139746	et	4	main
1219	doc_101672866015_item	3139747	et	2	main
oma	doc_101672866015_item	3139754	et	4	main
et	doc_101672866015_item	3139760	et	3	main
aastast	doc_101672866015_item	3139769	et	4	main
ning	doc_101672866015_item	3139770	et	3	main
harku	doc_101672866015_item	3139773	et	4	main
kuulus	doc_101672866015_item	3139774	et	4	main
tool	doc_101672866015_item	3139775	et	3	main
ajal	doc_101672866015_item	3139776	et	4	main
ficke	doc_101672866015_item	3139777	et	4	main
või	doc_101672866015_item	3139778	et	4	main
frederik	doc_101672866015_item	3139779	et	4	main
de	doc_101672866015_item	3139780	et	4	main
harkele	doc_101672866015_item	3139781	et	4	main
ja	doc_101672866015_item	3139782	et	3	main
1349	doc_101672866015_item	3139783	et	2	main
aastal	doc_101672866015_item	3139784	et	3	main
tema	doc_101672866015_item	3139785	et	4	main
pojale	doc_101672866015_item	3139786	et	4	main
tilo	doc_101672866015_item	3139787	et	4	main
või	doc_101672866015_item	3139788	et	4	main
theodoricus	doc_101672866015_item	3139789	et	4	main
de	doc_101672866015_item	3139790	et	4	main
harkele	doc_101672866015_item	3139791	et	4	main
viimasele	doc_101672866015_item	3139792	et	3	main
järgnes	doc_101672866015_item	3139793	et	3	main
terve	doc_101672866015_item	3139794	et	4	main
rida	doc_101672866015_item	3139795	et	4	main
de	doc_101672866015_item	3139796	et	4	main
elanud	doc_101672866015_item	3139806	et	4	main
on	doc_101672866015_item	3139812	et	4	main
ka	doc_101672866015_item	3139818	et	3	main
pärineval	doc_101672866015_item	3139821	et	4	main
henne	doc_101672866015_item	3139831	et	4	main
katku	doc_101672866015_item	3139837	et	4	main
saatus	doc_101672866015_item	3139844	et	3	main
kronoloogia	doc_101672866015_item	3139846	et	4	main
aastast	doc_101672866015_item	3139848	et	4	main
kuni	doc_101672866015_item	3139849	et	3	main
liivi	doc_101672866015_item	3139850	et	4	main
sõjani	doc_101672866015_item	3139851	et	3	main
komtuurile	doc_101672866015_item	3139858	et	4	main
eraomandina	doc_101672866015_item	3139865	et	3	main
seda	doc_101672866015_item	3139867	et	3	main
aastal	doc_101672866015_item	3139897	et	3	main
teine	doc_101672866015_item	3139902	et	3	main
mõis	doc_101672866015_item	3139903	et	3	main
teatavat	doc_101672866015_item	3139912	et	4	main
vatsla	doc_101672866015_item	3139921	et	4	main
andmed	doc_101672866015_item	3139762	et	3	main
kohta	doc_101672866015_item	3139766	et	4	main
ilmusid	doc_101672866015_item	3139767	et	4	main
1317	doc_101672866015_item	3139768	et	2	main
sugukonnamõis	doc_101672866015_item	3139772	et	3	main
neid	doc_101672866015_item	3139808	et	4	main
fakte	doc_101672866015_item	3139809	et	3	main
rahno	doc_101672866015_item	3139810	et	4	main
raamatus	doc_101672866015_item	3139811	et	4	main
esines	doc_101672866015_item	3139817	et	3	main
harkust	doc_101672866015_item	3139820	et	3	main
tallinna	doc_101672866015_item	3139822	et	4	main
kes	doc_101672866015_item	3139824	et	4	main
olid	doc_101672866015_item	3139825	et	4	main
surnud	doc_101672866015_item	3139838	et	4	main
harku	doc_101672866015_item	3139854	et	4	main
mõis	doc_101672866015_item	3139855	et	3	main
orduloss11	doc_101672866015_item	3139860	et	2	main
1543	doc_101672866015_item	3139869	et	2	main
koha	doc_101672866015_item	3139874	et	4	main
omanik	doc_101672866015_item	3139875	et	3	main
johan	doc_101672866015_item	3139876	et	4	main
toddeven	doc_101672866015_item	3139877	et	4	main
müüs	doc_101672866015_item	3139878	et	4	main
harku	doc_101672866015_item	3139879	et	4	main
300	doc_101672866015_item	3139881	et	2	main
mõisa	doc_101672866015_item	3139880	et	3	main
marga	doc_101672866015_item	3139882	et	3	main
eest	doc_101672866015_item	3139883	et	4	main
noore	doc_101672866015_item	3139884	et	3	main
claus	doc_101672866015_item	3139885	et	4	main
mekesele	doc_101672866015_item	3139886	et	4	main
tänu	doc_101672866015_item	3139887	et	4	main
harku	doc_101672866015_item	3139888	et	4	main
lääne	doc_101672866015_item	3139889	et	4	main
piirkonnas	doc_101672866015_item	3139890	et	4	main
toimuvate	doc_101672866015_item	3139891	et	4	main
talude	doc_101672866015_item	3139892	et	3	main
ja	doc_101672866015_item	3139893	et	3	main
külade	doc_101672866015_item	3139894	et	3	main
liitmistele	doc_101672866015_item	3139895	et	4	main
1561	doc_101672866015_item	3139896	et	2	main
tekkib	doc_101672866015_item	3139898	et	3	main
mõisa	doc_101672866015_item	3139900	et	3	main
kotipere	doc_101672866015_item	3139905	et	4	main
mõis	doc_101672866015_item	3139906	et	3	main
mis	doc_101672866015_item	3139907	et	4	main
edaspidi	doc_101672866015_item	3139908	et	3	main
etendab	doc_101672866015_item	3139909	et	3	main
kuningas	doc_101672866015_item	3139918	et	4	main
kotipere	doc_101672866015_item	3139924	et	4	main
mõisa	doc_101672866015_item	3139925	et	3	main
sõjakomissarile	doc_101672866015_item	3139926	et	3	main
et	doc_101672866015_item	3139933	et	3	main
teada	doc_101672866015_item	3139939	et	3	main
gustav	doc_101672866015_item	3139955	et	4	main
scheiding	doc_101672866015_item	3139959	et	4	main
pärisomandina	doc_101672866015_item	3139961	et	3	main
seisva	doc_101672866015_item	3139964	et	4	main
harku	doc_101672866015_item	3139965	et	4	main
mõisa	doc_101672866015_item	3139966	et	3	main
tallinna	doc_101672866015_item	3139999	et	4	main
linna	doc_101672866015_item	3140000	et	4	main
1370-1374	doc_101672866015_item	3139829	et	2	main
kiviraidur	doc_101672866015_item	3139830	et	3	main
tallinnas	doc_101672866015_item	3139836	et	4	main
harke	doc_101672866015_item	3139840	et	3	main
huvitav	doc_101672866015_item	3139843	et	4	main
ja	doc_101672866015_item	3139845	et	3	main
on	doc_101672866015_item	3139856	et	4	main
tallinna	doc_101672866015_item	3139857	et	4	main
mitte	doc_101672866015_item	3139861	et	3	main
alles	doc_101672866015_item	3139868	et	3	main
brieflades	doc_101672866015_item	3139871	et	4	main
selle	doc_101672866015_item	3139873	et	4	main
harku	doc_101672866015_item	3139910	et	4	main
gustav	doc_101672866015_item	3139919	et	4	main
adam	doc_101672866015_item	3139927	et	4	main
võib	doc_101672866015_item	3139941	et	3	main
et	doc_101672866015_item	3139943	et	3	main
sellele	doc_101672866015_item	3139945	et	4	main
oli	doc_101672866015_item	3139947	et	3	main
adolf	doc_101672866015_item	3139956	et	4	main
tühjalt	doc_101672866015_item	3139963	et	4	main
hiljem	doc_101672866015_item	3139967	et	3	main
sõjakomissari	doc_101672866015_item	3139968	et	4	main
lesk	doc_101672866015_item	3139969	et	3	main
1645	doc_101672866015_item	3139970	et	2	main
aastal	doc_101672866015_item	3139971	et	3	main
nimetab	doc_101672866015_item	3139972	et	3	main
end	doc_101672866015_item	3139973	et	4	main
kotipere	doc_101672866015_item	3139974	et	4	main
ja	doc_101672866015_item	3139975	et	3	main
harku	doc_101672866015_item	3139976	et	4	main
mõisate	doc_101672866015_item	3139977	et	3	main
omanikuks	doc_101672866015_item	3139978	et	4	main
1710	doc_101672866015_item	3139979	et	2	main
aastal	doc_101672866015_item	3139980	et	3	main
harku	doc_101672866015_item	3139981	et	4	main
mõisahoones	doc_101672866015_item	3139982	et	4	main
asub	doc_101672866015_item	3139983	et	3	main
vene	doc_101672866015_item	3139984	et	4	main
vägede	doc_101672866015_item	3139985	et	3	main
juhataja	doc_101672866015_item	3139986	et	4	main
kindralleitnant	doc_101672866015_item	3139987	et	3	main
rudolf	doc_101672866015_item	3139988	et	4	main
felix	doc_101672866015_item	3139989	et	4	main
baueri	doc_101672866015_item	3139990	et	4	main
peakorter	doc_101672866015_item	3139991	et	3	main
kus	doc_101672866015_item	3139992	et	3	main
29	doc_101672866015_item	3139993	et	2	main
septembril	doc_101672866015_item	3139994	et	3	main
kirjutakse	doc_101672866015_item	3139995	et	4	main
alla	doc_101672866015_item	3139996	et	3	main
kapitulatsioonile	doc_101672866015_item	3139998	et	3	main
baueri	doc_101672866015_item	3140002	et	4	main
eestimaa	doc_101672866015_item	3140010	et	4	main
põhjasõda	doc_101672866015_item	3140018	et	4	main
poeg	doc_101672866015_item	3140022	et	3	main
aastal	doc_101672866015_item	3140024	et	3	main
ostab	doc_101672866015_item	3140027	et	3	main
ungern	doc_101672866015_item	3140032	et	4	main
kurikuulsa	doc_101672866015_item	3140034	et	3	main
hiiumaa	doc_101672866015_item	3140035	et	4	main
kasumit	doc_101672866015_item	3140040	et	3	main
laevaga	doc_101672866015_item	3140042	et	4	main
harku	doc_101672866015_item	3139934	et	4	main
põhjus	doc_101672866015_item	3139937	et	4	main
aga	doc_101672866015_item	3139940	et	3	main
arvatavasti	doc_101672866015_item	3139944	et	3	main
põhjuseks	doc_101672866015_item	3139946	et	3	main
philipp	doc_101672866015_item	3139958	et	4	main
lesele	doc_101672866015_item	3139960	et	3	main
ka	doc_101672866015_item	3139962	et	3	main
harku	doc_101672866015_item	3139997	et	4	main
ehk	doc_101672866015_item	3140004	et	3	main
rüütelkond	doc_101672866015_item	3140011	et	4	main
röövelparuni	doc_101672866015_item	3140021	et	4	main
von	doc_101672866015_item	3140031	et	4	main
sternberg12	doc_101672866015_item	3140033	et	2	main
vedades	doc_101672866015_item	3140048	et	4	main
sai	doc_101672866015_item	3140065	et	4	main
niimoodi	doc_101672866015_item	3140070	et	3	main
xix	doc_101672866015_item	3140071	et	4	main
sajandil	doc_101672866015_item	3140072	et	3	main
kuulub	doc_101672866015_item	3140073	et	3	main
mõis	doc_101672866015_item	3140075	et	3	main
enam	doc_101672866015_item	3140076	et	4	main
kui	doc_101672866015_item	3140077	et	3	main
kuuekümne	doc_101672866015_item	3140078	et	4	main
harku	doc_101672866015_item	3140074	et	4	main
aasta	doc_101672866015_item	3140079	et	4	main
jooksul	doc_101672866015_item	3140080	et	4	main
ungern	doc_101672866015_item	3140081	et	4	main
sternbergidele	doc_101672866015_item	3140082	et	4	main
selle	doc_101672866015_item	3140083	et	4	main
aja	doc_101672866015_item	3140084	et	4	main
jooksul	doc_101672866015_item	3140085	et	4	main
seal	doc_101672866015_item	3140086	et	4	main
võetakse	doc_101672866015_item	3140087	et	3	main
ette	doc_101672866015_item	3140088	et	4	main
ehitus-	doc_101672866015_item	3140089	et	4	main
ja	doc_101672866015_item	3140090	et	3	main
korrastustöid	doc_101672866015_item	3140091	et	3	main
parki	doc_101672866015_item	3140092	et	4	main
laiendatakse	doc_101672866015_item	3140093	et	4	main
tunduvalt	doc_101672866015_item	3140094	et	4	main
istutakse	doc_101672866015_item	3140095	et	3	main
sinna	doc_101672866015_item	3140096	et	3	main
piimakarja	doc_101672866015_item	3140111	et	4	main
suguvõsast	doc_101672866015_item	3140118	et	4	main
pärit	doc_101672866015_item	3140119	et	3	main
parun	doc_101672866015_item	3140120	et	3	main
kohta	doc_101672866015_item	3140126	et	4	main
enne	doc_101672866015_item	3140140	et	4	main
aga	doc_101672866015_item	3140141	et	3	main
kaevanud	doc_101672866015_item	3140142	et	4	main
oma	doc_101672866015_item	3140143	et	4	main
julius	doc_101672866015_item	3140156	et	4	main
käinud	doc_101672866015_item	3140162	et	4	main
näidatud	doc_101672866015_item	3140172	et	4	main
rahno	doc_101672866015_item	3140197	et	4	main
tema	doc_101672866015_item	3140199	et	4	main
kohta	doc_101672866015_item	3140200	et	4	main
arhiivandmed	doc_101672866015_item	3140201	et	4	main
peaaegu	doc_101672866015_item	3140202	et	3	main
vahetevahel	doc_101672866015_item	3140211	et	3	main
mälestusi	doc_101672866015_item	3140219	et	4	main
rahu	doc_101672866015_item	3140006	et	4	main
rootsi	doc_101672866015_item	3140007	et	4	main
garnison	doc_101672866015_item	3140008	et	3	main
ja	doc_101672866015_item	3140009	et	3	main
millega	doc_101672866015_item	3140015	et	3	main
põhimõtteliselt	doc_101672866015_item	3140016	et	4	main
lõppeb	doc_101672866015_item	3140017	et	3	main
viina	doc_101672866015_item	3140047	et	4	main
pankrotti	doc_101672866015_item	3140057	et	4	main
eestimaal	doc_101672866015_item	3140069	et	4	main
pidamisega	doc_101672866015_item	3140112	et	4	main
oli	doc_101672866015_item	3140121	et	3	main
robert	doc_101672866015_item	3140122	et	4	main
ungern	doc_101672866015_item	3140123	et	4	main
levis	doc_101672866015_item	3140127	et	4	main
harku	doc_101672866015_item	3140145	et	4	main
sisse	doc_101672866015_item	3140148	et	4	main
selle	doc_101672866015_item	3140149	et	4	main
ise	doc_101672866015_item	3140161	et	4	main
aga	doc_101672866015_item	3140170	et	3	main
mõisas	doc_101672866015_item	3140204	et	3	main
kindraliproua	doc_101672866015_item	3140207	et	4	main
keda	doc_101672866015_item	3140208	et	4	main
parun	doc_101672866015_item	3140209	et	3	main
külastas	doc_101672866015_item	3140210	et	3	main
aga	doc_101672866015_item	3140213	et	3	main
näiteks	doc_101672866015_item	3140220	et	4	main
temale	doc_101672866015_item	3140221	et	3	main
saanud	doc_101672866015_item	3140230	et	4	main
mõisa	doc_101672866015_item	3140233	et	3	main
nimega	doc_101672866015_item	3140239	et	3	main
mägi	doc_101672866015_item	3140241	et	3	main
näha	doc_101672866015_item	3140245	et	3	main
weymarn	doc_101672866015_item	3140286	et	4	main
harku	doc_101672866015_item	3140287	et	4	main
parun	doc_101672866015_item	3140288	et	3	main
knorringile14	doc_101672866015_item	3140289	et	2	main
ei	doc_101672866015_item	3140294	et	4	main
viibib	doc_101672866015_item	3140297	et	3	main
välja	doc_101672866015_item	3140318	et	4	main
pigistada	doc_101672866015_item	3140319	et	3	main
ennem	doc_101672866015_item	3140320	et	4	main
tegeleti	doc_101672866015_item	3140322	et	3	main
karjakasvatamisega	doc_101672866015_item	3140324	et	3	main
nüüd	doc_101672866015_item	3140328	et	4	main
uus	doc_101672866015_item	3140330	et	3	main
ehitab	doc_101672866015_item	3140332	et	3	main
piiritusevabriku	doc_101672866015_item	3140334	et	3	main
kuna	doc_101672866015_item	3140338	et	3	main
ei	doc_101672866015_item	3140340	et	4	main
elanud	doc_101672866015_item	3140341	et	4	main
kunagi	doc_101672866015_item	3140342	et	3	main
mõisas	doc_101672866015_item	3140343	et	3	main
ning	doc_101672866015_item	3140344	et	3	main
tegelenud	doc_101672866015_item	3140348	et	4	main
kasvatamisega	doc_101672866015_item	3140358	et	4	main
müüdi	doc_101672866015_item	3140365	et	4	main
õiget	doc_101672866015_item	3140368	et	3	main
aga	doc_101672866015_item	3140370	et	3	main
raha	doc_101672866015_item	3140377	et	4	main
seega	doc_101672866015_item	3140379	et	4	main
müüs	doc_101672866015_item	3140388	et	4	main
ära	doc_101672866015_item	3140390	et	4	main
otsija	doc_101672866015_item	3140416	et	4	main
siia	doc_101672866015_item	3140421	et	4	main
elama	doc_101672866015_item	3140425	et	3	main
hästi	doc_101672866015_item	3140441	et	3	main
oli	doc_101672866015_item	3140452	et	3	main
keelatud	doc_101672866015_item	3140454	et	4	main
need	doc_101672866015_item	3140455	et	3	main
kes	doc_101672866015_item	3140456	et	4	main
tema	doc_101672866015_item	3140492	et	4	main
oligi	doc_101672866015_item	3140493	et	3	main
see	doc_101672866015_item	3140494	et	3	main
mõisnik	doc_101672866015_item	3140495	et	3	main
otsimas	doc_101672866015_item	3140505	et	4	main
1938	doc_101672866015_item	3140510	et	2	main
ilmunud	doc_101672866015_item	3140512	et	4	main
kodu	doc_101672866015_item	3140514	et	4	main
nr9	doc_101672866015_item	3140515	et	4	main
kus	doc_101672866015_item	3140516	et	3	main
tool	doc_101672866015_item	3140049	et	3	main
ning	doc_101672866015_item	3140058	et	3	main
neid	doc_101672866015_item	3140059	et	4	main
oli	doc_101672866015_item	3140060	et	3	main
võimalik	doc_101672866015_item	3140061	et	3	main
maaomanik	doc_101672866015_item	3140068	et	3	main
palju	doc_101672866015_item	3140097	et	4	main
majapidamisharuks	doc_101672866015_item	3140107	et	3	main
harku	doc_101672866015_item	3140108	et	4	main
mõisas	doc_101672866015_item	3140109	et	3	main
tegeletakse	doc_101672866015_item	3140110	et	3	main
selle	doc_101672866015_item	3140117	et	4	main
tema	doc_101672866015_item	3140125	et	4	main
rahvajutt	doc_101672866015_item	3140130	et	3	main
ta	doc_101672866015_item	3140132	et	4	main
segatud	doc_101672866015_item	3140134	et	4	main
keisritapmise	doc_101672866015_item	3140135	et	3	main
metsas	doc_101672866015_item	3140146	et	3	main
mõisa	doc_101672866015_item	3140154	et	3	main
tema	doc_101672866015_item	3140158	et	4	main
sõnul	doc_101672866015_item	3140159	et	3	main
ta	doc_101672866015_item	3140160	et	4	main
harku	doc_101672866015_item	3140165	et	4	main
mõisnikuga	doc_101672866015_item	3140166	et	3	main
seda	doc_101672866015_item	3140167	et	3	main
varandust	doc_101672866015_item	3140168	et	3	main
otsima	doc_101672866015_item	3140169	et	4	main
mõisniku	doc_101672866015_item	3140171	et	3	main
haruldasi	doc_101672866015_item	3140098	et	3	main
looduslik	doc_101672866015_item	3140100	et	3	main
meriino	doc_101672866015_item	3140113	et	4	main
lammaste	doc_101672866015_item	3140114	et	3	main
ajal	doc_101672866015_item	3140129	et	4	main
välismaale	doc_101672866015_item	3140139	et	4	main
juttu	doc_101672866015_item	3140150	et	4	main
kinnitas	doc_101672866015_item	3140151	et	3	main
endine	doc_101672866015_item	3140152	et	3	main
harku	doc_101672866015_item	3140153	et	4	main
koos	doc_101672866015_item	3140163	et	4	main
kohtades	doc_101672866015_item	3140173	et	3	main
polnud	doc_101672866015_item	3140174	et	3	main
aga	doc_101672866015_item	3140175	et	3	main
midagi	doc_101672866015_item	3140176	et	4	main
312	doc_101672866015_item	3140177	et	2	main
kindraliproua	doc_101672866015_item	3140178	et	4	main
1895-	doc_101672866015_item	3140179	et	4	main
1907	doc_101672866015_item	3140180	et	2	main
kuulus	doc_101672866015_item	3140181	et	4	main
mõis	doc_101672866015_item	3140182	et	3	main
friederih	doc_101672866015_item	3140183	et	4	main
vilhelm	doc_101672866015_item	3140184	et	4	main
von	doc_101672866015_item	3140185	et	4	main
weymarnile13	doc_101672866015_item	3140186	et	2	main
isiklikult	doc_101672866015_item	3140187	et	4	main
ta	doc_101672866015_item	3140188	et	4	main
mõisas	doc_101672866015_item	3140189	et	3	main
pole	doc_101672866015_item	3140190	et	3	main
elanud	doc_101672866015_item	3140191	et	4	main
kuid	doc_101672866015_item	3140192	et	4	main
käinud	doc_101672866015_item	3140193	et	4	main
seal	doc_101672866015_item	3140194	et	4	main
vahetevahel	doc_101672866015_item	3140195	et	3	main
p	doc_101672866015_item	3140196	et	4	main
aga	doc_101672866015_item	3140205	et	3	main
päris	doc_101672866015_item	3140217	et	4	main
huvitavaid	doc_101672866015_item	3140218	et	4	main
pargis	doc_101672866015_item	3140234	et	3	main
püha	doc_101672866015_item	3140240	et	4	main
veel	doc_101672866015_item	3140244	et	4	main
isiklikult	doc_101672866015_item	3140292	et	4	main
puuduvad	doc_101672866015_item	3140203	et	4	main
elas	doc_101672866015_item	3140206	et	3	main
ratsahobune	doc_101672866015_item	3140224	et	4	main
ataman	doc_101672866015_item	3140225	et	3	main
ja	doc_101672866015_item	3140226	et	3	main
kui	doc_101672866015_item	3140227	et	3	main
see	doc_101672866015_item	3140228	et	3	main
otsa	doc_101672866015_item	3140229	et	4	main
ning	doc_101672866015_item	3140235	et	3	main
monument	doc_101672866015_item	3140238	et	3	main
aga	doc_101672866015_item	3140255	et	3	main
ilmunud	doc_101672866015_item	3140256	et	4	main
rahvajutud	doc_101672866015_item	3140257	et	3	main
püüavad	doc_101672866015_item	3140258	et	3	main
sedagi	doc_101672866015_item	3140259	et	3	main
kohta	doc_101672866015_item	3140260	et	4	main
siduda	doc_101672866015_item	3140261	et	3	main
tasuja	doc_101672866015_item	3140262	et	4	main
lugudega	doc_101672866015_item	3140263	et	3	main
väites	doc_101672866015_item	3140264	et	4	main
et	doc_101672866015_item	3140265	et	3	main
seal	doc_101672866015_item	3140266	et	4	main
on	doc_101672866015_item	3140267	et	4	main
maetud	doc_101672866015_item	3140268	et	4	main
tasuja	doc_101672866015_item	3140269	et	4	main
hobune	doc_101672866015_item	3140270	et	4	main
isegi	doc_101672866015_item	3140272	et	4	main
tasuja	doc_101672866015_item	3140273	et	4	main
kuldmõõk	doc_101672866015_item	3140274	et	3	main
313	doc_101672866015_item	3140275	et	2	main
või	doc_101672866015_item	3140271	et	4	main
omanik	doc_101672866015_item	3140276	et	3	main
peterburist	doc_101672866015_item	3140277	et	4	main
1907-	doc_101672866015_item	3140278	et	4	main
08	doc_101672866015_item	3140279	et	2	main
aastate	doc_101672866015_item	3140280	et	3	main
paiku	doc_101672866015_item	3140281	et	4	main
müüb	doc_101672866015_item	3140282	et	3	main
friederih	doc_101672866015_item	3140283	et	4	main
vilhelm	doc_101672866015_item	3140284	et	4	main
pärast	doc_101672866015_item	3140214	et	4	main
end	doc_101672866015_item	3140215	et	4	main
jättis	doc_101672866015_item	3140216	et	3	main
kuulus	doc_101672866015_item	3140222	et	4	main
üks	doc_101672866015_item	3140223	et	3	main
maeti	doc_101672866015_item	3140231	et	3	main
püstitati	doc_101672866015_item	3140237	et	4	main
praegugi	doc_101672866015_item	3140242	et	3	main
on	doc_101672866015_item	3140252	et	4	main
alles	doc_101672866015_item	3140253	et	3	main
hiljem	doc_101672866015_item	3140254	et	3	main
samuti	doc_101672866015_item	3140291	et	3	main
vaid	doc_101672866015_item	3140296	et	3	main
puhkepaika	doc_101672866015_item	3140303	et	4	main
selle	doc_101672866015_item	3140309	et	4	main
endised	doc_101672866015_item	3140310	et	3	main
ta	doc_101672866015_item	3140312	et	4	main
püüab	doc_101672866015_item	3140313	et	3	main
harkust	doc_101672866015_item	3140314	et	3	main
ehk	doc_101672866015_item	3140325	et	3	main
aga	doc_101672866015_item	3140329	et	3	main
isiklikult	doc_101672866015_item	3140345	et	4	main
piimakarja	doc_101672866015_item	3140357	et	4	main
saadi	doc_101672866015_item	3140361	et	4	main
osa	doc_101672866015_item	3140376	et	4	main
endale	doc_101672866015_item	3140378	et	4	main
mõis	doc_101672866015_item	3140380	et	3	main
herman	doc_101672866015_item	3140408	et	4	main
richard	doc_101672866015_item	3140409	et	4	main
ning	doc_101672866015_item	3140422	et	3	main
muudab	doc_101672866015_item	3140427	et	3	main
tulutoovamaks	doc_101672866015_item	3140429	et	4	main
sest	doc_101672866015_item	3140430	et	4	main
ajab	doc_101672866015_item	3140431	et	3	main
majapidamist	doc_101672866015_item	3140432	et	3	main
mõisa	doc_101672866015_item	3140439	et	3	main
seal	doc_101672866015_item	3140457	et	4	main
ka	doc_101672866015_item	3140488	et	3	main
looma	doc_101672866015_item	3140232	et	4	main
hauale	doc_101672866015_item	3140236	et	3	main
on	doc_101672866015_item	3140243	et	4	main
selle	doc_101672866015_item	3140246	et	4	main
monumendi	doc_101672866015_item	3140247	et	3	main
kivitükki	doc_101672866015_item	3140248	et	4	main
millel	doc_101672866015_item	3140249	et	3	main
see	doc_101672866015_item	3140250	et	3	main
pealkiri	doc_101672866015_item	3140251	et	3	main
von	doc_101672866015_item	3140285	et	4	main
seal	doc_101672866015_item	3140293	et	4	main
ela	doc_101672866015_item	3140295	et	4	main
ta	doc_101672866015_item	3140299	et	4	main
ei	doc_101672866015_item	3140300	et	4	main
otsi	doc_101672866015_item	3140301	et	4	main
mõisas	doc_101672866015_item	3140302	et	3	main
seda	doc_101672866015_item	3140307	et	3	main
tegid	doc_101672866015_item	3140308	et	4	main
rohkem	doc_101672866015_item	3140316	et	4	main
tulu	doc_101672866015_item	3140317	et	4	main
majapidamisega	doc_101672866015_item	3140346	et	3	main
tekkisid	doc_101672866015_item	3140350	et	4	main
nimelt	doc_101672866015_item	3140352	et	4	main
kuna	doc_101672866015_item	3140353	et	3	main
mõisas	doc_101672866015_item	3140354	et	3	main
tegeleti	doc_101672866015_item	3140355	et	3	main
peamiselt	doc_101672866015_item	3140356	et	4	main
mõned	doc_101672866015_item	3140359	et	3	main
aiast	doc_101672866015_item	3140363	et	4	main
turul	doc_101672866015_item	3140367	et	3	main
arvepidamist	doc_101672866015_item	3140369	et	3	main
polnud	doc_101672866015_item	3140371	et	3	main
aednikupoisid	doc_101672866015_item	3140373	et	4	main
piisavalt	doc_101672866015_item	3140384	et	4	main
põldroos	doc_101672866015_item	3140398	et	4	main
von	doc_101672866015_item	3140410	et	4	main
harpe15	doc_101672866015_item	3140411	et	2	main
on	doc_101672866015_item	3140412	et	4	main
samuti	doc_101672866015_item	3140413	et	3	main
suure	doc_101672866015_item	3140414	et	3	main
isiklikult	doc_101672866015_item	3140419	et	4	main
tuleb	doc_101672866015_item	3140420	et	3	main
harku	doc_101672866015_item	3140428	et	4	main
park	doc_101672866015_item	3140440	et	3	main
pargi	doc_101672866015_item	3140443	et	4	main
vahele	doc_101672866015_item	3140458	et	4	main
võimalusi	doc_101672866015_item	3140490	et	3	main
rikastumiseks	doc_101672866015_item	3140491	et	4	main
julius	doc_101672866015_item	3140498	et	4	main
käis	doc_101672866015_item	3140500	et	4	main
robert	doc_101672866015_item	3140501	et	4	main
kinnitab	doc_101672866015_item	3140508	et	3	main
on	doc_101672866015_item	3140517	et	4	main
samuti	doc_101672866015_item	3140518	et	3	main
viimane	doc_101672866015_item	3140521	et	3	main
omanik	doc_101672866015_item	3140523	et	3	main
von	doc_101672866015_item	3140526	et	4	main
varemetes	doc_101672866015_item	3140531	et	4	main
selle	doc_101672866015_item	3140537	et	4	main
tassinud	doc_101672866015_item	3140540	et	4	main
mõisahoone	doc_101672866015_item	3140558	et	4	main
põhjapoolsel	doc_101672866015_item	3140559	et	3	main
küljel	doc_101672866015_item	3140560	et	3	main
radu	doc_101672866015_item	3140561	et	3	main
kõrval	doc_101672866015_item	3140562	et	4	main
oli	doc_101672866015_item	3140563	et	3	main
mõisnike	doc_101672866015_item	3140564	et	3	main
ajal	doc_101672866015_item	3140565	et	4	main
suur	doc_101672866015_item	3140566	et	3	main
tunnikell	doc_101672866015_item	3140567	et	3	main
mille	doc_101672866015_item	3140568	et	3	main
ehitas	doc_101672866015_item	3140569	et	3	main
saksamaalt	doc_101672866015_item	3140570	et	3	main
õige	doc_101672866015_item	3140584	et	4	main
aga	doc_101672866015_item	3140591	et	3	main
teinud	doc_101672866015_item	3140596	et	4	main
midagi	doc_101672866015_item	3140603	et	4	main
parimaid	doc_101672866015_item	3140617	et	4	main
maha	doc_101672866015_item	3140650	et	4	main
315	doc_101672866015_item	3140651	et	2	main
1919	doc_101672866015_item	3140656	et	2	main
kes	doc_101672866015_item	3140290	et	4	main
peterburis	doc_101672866015_item	3140298	et	4	main
lõbutsemist	doc_101672866015_item	3140305	et	4	main
nagu	doc_101672866015_item	3140306	et	3	main
kasvatamisega	doc_101672866015_item	3140327	et	4	main
omanik	doc_101672866015_item	3140331	et	3	main
aurujahuveski	doc_101672866015_item	3140336	et	4	main
sellega	doc_101672866015_item	3140349	et	3	main
raskused	doc_101672866015_item	3140351	et	4	main
ka	doc_101672866015_item	3140362	et	3	main
tallinna	doc_101672866015_item	3140366	et	4	main
vanemad	doc_101672866015_item	3140372	et	4	main
tihti	doc_101672866015_item	3140374	et	3	main
ei	doc_101672866015_item	3140381	et	4	main
andnud	doc_101672866015_item	3140382	et	4	main
omanikule	doc_101672866015_item	3140383	et	3	main
seda	doc_101672866015_item	3140389	et	3	main
314	doc_101672866015_item	3140391	et	2	main
viimane	doc_101672866015_item	3140392	et	3	main
eraomanik	doc_101672866015_item	3140393	et	3	main
või	doc_101672866015_item	3140304	et	4	main
peremehed	doc_101672866015_item	3140311	et	3	main
võimalikult	doc_101672866015_item	3140315	et	4	main
mõisas	doc_101672866015_item	3140321	et	3	main
peamiselt	doc_101672866015_item	3140323	et	4	main
piimakarja	doc_101672866015_item	3140326	et	4	main
sinna	doc_101672866015_item	3140333	et	3	main
ja	doc_101672866015_item	3140335	et	3	main
aga	doc_101672866015_item	3140337	et	3	main
ta	doc_101672866015_item	3140339	et	4	main
pole	doc_101672866015_item	3140347	et	3	main
sissetulekuid	doc_101672866015_item	3140360	et	4	main
tooteid	doc_101672866015_item	3140364	et	4	main
jätsid	doc_101672866015_item	3140375	et	4	main
tulu	doc_101672866015_item	3140385	et	4	main
ning	doc_101672866015_item	3140386	et	3	main
parun	doc_101672866015_item	3140387	et	3	main
ja	doc_101672866015_item	3140394	et	3	main
jutustaja	doc_101672866015_item	3140395	et	4	main
sepp	doc_101672866015_item	3140396	et	3	main
julius	doc_101672866015_item	3140397	et	4	main
mõisa	doc_101672866015_item	3140399	et	3	main
ostnud	doc_101672866015_item	3140400	et	4	main
kuid	doc_101672866015_item	3140417	et	4	main
tema	doc_101672866015_item	3140418	et	4	main
hakkab	doc_101672866015_item	3140423	et	3	main
mõisas	doc_101672866015_item	3140424	et	3	main
ise	doc_101672866015_item	3140433	et	4	main
räägiti	doc_101672866015_item	3140434	et	3	main
et	doc_101672866015_item	3140435	et	3	main
ajal	doc_101672866015_item	3140437	et	4	main
olnud	doc_101672866015_item	3140438	et	4	main
korras	doc_101672866015_item	3140442	et	4	main
teed	doc_101672866015_item	3140444	et	4	main
hoitud	doc_101672866015_item	3140445	et	4	main
minek	doc_101672866015_item	3140451	et	3	main
rangelt	doc_101672866015_item	3140453	et	4	main
muid	doc_101672866015_item	3140489	et	4	main
põldroos	doc_101672866015_item	3140499	et	4	main
ka	doc_101672866015_item	3140509	et	3	main
et	doc_101672866015_item	3140520	et	3	main
tambeti	doc_101672866015_item	3140529	et	4	main
kohalekutsutud	doc_101672866015_item	3140571	et	4	main
meister	doc_101672866015_item	3140573	et	3	main
olevat	doc_101672866015_item	3140577	et	4	main
meistrit	doc_101672866015_item	3140579	et	3	main
tüssata	doc_101672866015_item	3140580	et	4	main
ja	doc_101672866015_item	3140581	et	3	main
asemel	doc_101672866015_item	3140586	et	4	main
valeraha	doc_101672866015_item	3140587	et	4	main
meister	doc_101672866015_item	3140588	et	3	main
märgas	doc_101672866015_item	3140589	et	3	main
pettust	doc_101672866015_item	3140590	et	3	main
sellest	doc_101672866015_item	3140593	et	4	main
midagi	doc_101672866015_item	3140594	et	4	main
välja	doc_101672866015_item	3140595	et	4	main
1911	doc_101672866015_item	3140401	et	2	main
aastast	doc_101672866015_item	3140402	et	4	main
uus	doc_101672866015_item	3140403	et	3	main
ja	doc_101672866015_item	3140404	et	3	main
viimane	doc_101672866015_item	3140405	et	3	main
eraomanik	doc_101672866015_item	3140406	et	3	main
ehk	doc_101672866015_item	3140407	et	3	main
tulu	doc_101672866015_item	3140415	et	4	main
harpe	doc_101672866015_item	3140426	et	4	main
tema	doc_101672866015_item	3140436	et	4	main
alati	doc_101672866015_item	3140446	et	4	main
puhtad	doc_101672866015_item	3140447	et	3	main
lihtrahval	doc_101672866015_item	3140448	et	3	main
kuid	doc_101672866015_item	3140449	et	4	main
sinna	doc_101672866015_item	3140450	et	3	main
jäid	doc_101672866015_item	3140459	et	4	main
said	doc_101672866015_item	3140460	et	4	main
kohe	doc_101672866015_item	3140461	et	4	main
oma	doc_101672866015_item	3140462	et	4	main
karistuse	doc_101672866015_item	3140463	et	4	main
kätte	doc_101672866015_item	3140464	et	4	main
selle	doc_101672866015_item	3140465	et	4	main
järele	doc_101672866015_item	3140466	et	4	main
valvas	doc_101672866015_item	3140467	et	4	main
eriti	doc_101672866015_item	3140468	et	3	main
proua	doc_101672866015_item	3140469	et	4	main
õde	doc_101672866015_item	3140470	et	4	main
kes	doc_101672866015_item	3140471	et	4	main
oli	doc_101672866015_item	3140472	et	3	main
käinud	doc_101672866015_item	3140473	et	4	main
pargis	doc_101672866015_item	3140474	et	3	main
alati	doc_101672866015_item	3140475	et	4	main
ratsapiitsaga	doc_101672866015_item	3140476	et	3	main
ja	doc_101672866015_item	3140477	et	3	main
peksnud	doc_101672866015_item	3140478	et	4	main
sellega	doc_101672866015_item	3140479	et	3	main
inimesi	doc_101672866015_item	3140480	et	4	main
keda	doc_101672866015_item	3140481	et	4	main
pargis	doc_101672866015_item	3140482	et	3	main
kohanud	doc_101672866015_item	3140483	et	4	main
peale	doc_101672866015_item	3140484	et	4	main
majapidamise	doc_101672866015_item	3140485	et	3	main
otsinud	doc_101672866015_item	3140486	et	4	main
harpe	doc_101672866015_item	3140487	et	4	main
kellega	doc_101672866015_item	3140496	et	3	main
sepp	doc_101672866015_item	3140497	et	3	main
ungern	doc_101672866015_item	3140502	et	4	main
sternbergi	doc_101672866015_item	3140503	et	4	main
kulla	doc_101672866015_item	3140504	et	4	main
juttu	doc_101672866015_item	3140507	et	4	main
kaitse	doc_101672866015_item	3140513	et	4	main
öeldud	doc_101672866015_item	3140519	et	4	main
harku	doc_101672866015_item	3140522	et	4	main
talu	doc_101672866015_item	3140530	et	4	main
peale	doc_101672866015_item	3140536	et	4	main
mõisa	doc_101672866015_item	3140539	et	3	main
sõnul	doc_101672866015_item	3140556	et	3	main
harku	doc_101672866015_item	3140557	et	4	main
valmimisel	doc_101672866015_item	3140575	et	4	main
mõisnik	doc_101672866015_item	3140576	et	3	main
tahtnud	doc_101672866015_item	3140578	et	4	main
vaid	doc_101672866015_item	3140597	et	3	main
kella	doc_101672866015_item	3140600	et	4	main
juures	doc_101672866015_item	3140601	et	4	main
pärast	doc_101672866015_item	3140612	et	4	main
kohale	doc_101672866015_item	3140619	et	4	main
panna	doc_101672866015_item	3140627	et	4	main
legendis	doc_101672866015_item	3140628	et	3	main
käinud	doc_101672866015_item	3140639	et	4	main
jäi	doc_101672866015_item	3140640	et	3	main
ajal	doc_101672866015_item	3140643	et	4	main
võetud	doc_101672866015_item	3140646	et	4	main
aastal	doc_101672866015_item	3140657	et	3	main
toodi	doc_101672866015_item	3140659	et	4	main
kurjategijate	doc_101672866015_item	3140661	et	3	main
viidi	doc_101672866015_item	3140666	et	4	main
valitsuse	doc_101672866015_item	3140675	et	4	main
ajal	doc_101672866015_item	3140676	et	4	main
keskvangla	doc_101672866015_item	3140681	et	4	main
lähedalasuvas	doc_101672866015_item	3140687	et	3	main
matmispaigas	doc_101672866015_item	3140698	et	4	main
praegu	doc_101672866015_item	3140700	et	3	main
võimalik	doc_101672866015_item	3140701	et	3	main
võib	doc_101672866015_item	3140708	et	3	main
tunduvalt	doc_101672866015_item	3140710	et	4	main
kuna	doc_101672866015_item	3140712	et	3	main
1965	doc_101672866015_item	3140713	et	2	main
aastal	doc_101672866015_item	3140714	et	3	main
buldooseriga	doc_101672866015_item	3140719	et	3	main
tänapäeval	doc_101672866015_item	3140721	et	3	main
viiakse	doc_101672866015_item	3140723	et	3	main
poliitvangide	doc_101672866015_item	3140737	et	4	main
aastal	doc_101672866015_item	3140743	et	3	main
lossi	doc_101672866015_item	3140771	et	4	main
ise	doc_101672866015_item	3140775	et	4	main
motiividele	doc_101672866015_item	3140782	et	3	main
praegu	doc_101672866015_item	3140783	et	3	main
tasuja	doc_101672866015_item	3140797	et	4	main
harku	doc_101672866015_item	3140805	et	4	main
järve	doc_101672866015_item	3140806	et	4	main
omaaegsest	doc_101672866015_item	3140807	et	3	main
nimest	doc_101672866015_item	3140808	et	3	main
laenatud	doc_101672866015_item	3140817	et	4	main
nimest	doc_101672866015_item	3140821	et	3	main
on	doc_101672866015_item	3140823	et	4	main
teada	doc_101672866015_item	3140824	et	3	main
et	doc_101672866015_item	3140825	et	3	main
veel	doc_101672866015_item	3140826	et	4	main
elanikud	doc_101672866015_item	3140833	et	3	main
valmis	doc_101672866015_item	3140834	et	4	main
asukohta	doc_101672866015_item	3140842	et	4	main
kui	doc_101672866015_item	3140843	et	3	main
ka	doc_101672866015_item	3140844	et	3	main
kus	doc_101672866015_item	3140846	et	3	main
peetud	doc_101672866015_item	3140848	et	4	main
ja	doc_101672866015_item	3140849	et	3	main
raudrõngastki	doc_101672866015_item	3140850	et	4	main
mille	doc_101672866015_item	3140851	et	3	main
olevat	doc_101672866015_item	3140863	et	4	main
seppa	doc_101672866015_item	3140506	et	4	main
aastal	doc_101672866015_item	3140511	et	3	main
herman	doc_101672866015_item	3140524	et	4	main
harpe	doc_101672866015_item	3140527	et	4	main
käisarvatava	doc_101672866015_item	3140528	et	4	main
koos	doc_101672866015_item	3140532	et	4	main
naisega	doc_101672866015_item	3140533	et	3	main
kaevamas	doc_101672866015_item	3140534	et	4	main
ja	doc_101672866015_item	3140535	et	3	main
midagi	doc_101672866015_item	3140538	et	4	main
kaevamise	doc_101672866015_item	3140541	et	4	main
jälgi	doc_101672866015_item	3140542	et	4	main
nendes	doc_101672866015_item	3140543	et	4	main
varemetes	doc_101672866015_item	3140544	et	4	main
tõepoolest	doc_101672866015_item	3140545	et	3	main
nähtub	doc_101672866015_item	3140546	et	3	main
julius	doc_101672866015_item	3140547	et	4	main
põldroose	doc_101672866015_item	3140548	et	3	main
nimega	doc_101672866015_item	3140549	et	3	main
on	doc_101672866015_item	3140550	et	4	main
seotud	doc_101672866015_item	3140551	et	4	main
ka	doc_101672866015_item	3140552	et	3	main
teine	doc_101672866015_item	3140553	et	3	main
rahvajutt	doc_101672866015_item	3140554	et	3	main
tema	doc_101672866015_item	3140555	et	4	main
richard	doc_101672866015_item	3140525	et	4	main
pime	doc_101672866015_item	3140572	et	3	main
kuldraha	doc_101672866015_item	3140585	et	4	main
luba	doc_101672866015_item	3140599	et	4	main
kohendada	doc_101672866015_item	3140604	et	3	main
maailmast	doc_101672866015_item	3140616	et	4	main
meistreid	doc_101672866015_item	3140618	et	3	main
osanud	doc_101672866015_item	3140623	et	4	main
kella	doc_101672866015_item	3140624	et	4	main
uuesti	doc_101672866015_item	3140625	et	3	main
käima	doc_101672866015_item	3140626	et	4	main
veel	doc_101672866015_item	3140636	et	4	main
kindrali	doc_101672866015_item	3140637	et	3	main
ajal	doc_101672866015_item	3140638	et	4	main
kodanluse	doc_101672866015_item	3140647	et	4	main
valitsuse	doc_101672866015_item	3140648	et	4	main
valu	doc_101672866015_item	3140653	et	4	main
alaealiste	doc_101672866015_item	3140660	et	4	main
koloonia	doc_101672866015_item	3140667	et	4	main
harkust	doc_101672866015_item	3140668	et	3	main
laitse	doc_101672866015_item	3140669	et	4	main
asus	doc_101672866015_item	3140677	et	4	main
harkus	doc_101672866015_item	3140678	et	3	main
ka	doc_101672866015_item	3140679	et	3	main
tallinna	doc_101672866015_item	3140680	et	4	main
kuhu	doc_101672866015_item	3140683	et	3	main
toodi	doc_101672866015_item	3140685	et	4	main
rabas	doc_101672866015_item	3140688	et	4	main
surnuid	doc_101672866015_item	3140689	et	4	main
vange	doc_101672866015_item	3140690	et	3	main
maeti	doc_101672866015_item	3140691	et	3	main
äärde	doc_101672866015_item	3140696	et	4	main
töö	doc_101672866015_item	3140574	et	4	main
andnud	doc_101672866015_item	3140582	et	4	main
talle	doc_101672866015_item	3140583	et	4	main
pole	doc_101672866015_item	3140592	et	3	main
palus	doc_101672866015_item	3140598	et	4	main
veel	doc_101672866015_item	3140602	et	4	main
asemel	doc_101672866015_item	3140606	et	4	main
pani	doc_101672866015_item	3140608	et	4	main
seda	doc_101672866015_item	3140609	et	3	main
hoopis	doc_101672866015_item	3140610	et	3	main
seisma	doc_101672866015_item	3140611	et	3	main
kutsunud	doc_101672866015_item	3140613	et	4	main
mõisnik	doc_101672866015_item	3140614	et	3	main
kogu	doc_101672866015_item	3140615	et	4	main
seisma	doc_101672866015_item	3140641	et	3	main
ning	doc_101672866015_item	3140644	et	3	main
algul	doc_101672866015_item	3140649	et	4	main
tänapäev	doc_101672866015_item	3140655	et	3	main
et	doc_101672866015_item	3140673	et	3	main
kodanliku	doc_101672866015_item	3140674	et	3	main
osakond	doc_101672866015_item	3140682	et	3	main
vange	doc_101672866015_item	3140684	et	3	main
turbatöödeks	doc_101672866015_item	3140686	et	3	main
viiva	doc_101672866015_item	3140694	et	4	main
tee	doc_101672866015_item	3140695	et	4	main
40-60	doc_101672866015_item	3140703	et	2	main
lükati	doc_101672866015_item	3140715	et	4	main
keskvangla	doc_101672866015_item	3140725	et	4	main
kellel	doc_101672866015_item	3140731	et	4	main
harku	doc_101672866015_item	3140734	et	4	main
sinna	doc_101672866015_item	3140745	et	3	main
1923	doc_101672866015_item	3140767	et	2	main
kirjeldatud	doc_101672866015_item	3140769	et	4	main
kandis	doc_101672866015_item	3140780	et	4	main
on	doc_101672866015_item	3140793	et	4	main
vanad	doc_101672866015_item	3140794	et	3	main
millised	doc_101672866015_item	3140795	et	3	main
mõjul	doc_101672866015_item	3140798	et	4	main
nimetus	doc_101672866015_item	3140801	et	4	main
ehkki	doc_101672866015_item	3140809	et	3	main
kirjandusloolased	doc_101672866015_item	3140810	et	3	main
paarkümmend	doc_101672866015_item	3140827	et	4	main
aastat	doc_101672866015_item	3140828	et	3	main
tagasi	doc_101672866015_item	3140829	et	3	main
näitama	doc_101672866015_item	3140835	et	3	main
ta	doc_101672866015_item	3140853	et	4	main
needitud	doc_101672866015_item	3140855	et	4	main
näidati	doc_101672866015_item	3140856	et	3	main
ka	doc_101672866015_item	3140857	et	3	main
kahte	doc_101672866015_item	3140858	et	4	main
on	doc_101672866015_item	3140900	et	4	main
juba	doc_101672866015_item	3140901	et	3	main
murdunud	doc_101672866015_item	3140903	et	4	main
ja	doc_101672866015_item	3140904	et	3	main
kännudki	doc_101672866015_item	3140905	et	3	main
esimese	doc_101672866015_item	3140929	et	3	main
et	doc_101672866015_item	3140966	et	3	main
tõepoolest	doc_101672866015_item	3140969	et	3	main
oli	doc_101672866015_item	3140978	et	3	main
liikumas	doc_101672866015_item	3140997	et	3	main
rahvasuust	doc_101672866015_item	3141006	et	3	main
mingi	doc_101672866015_item	3141007	et	4	main
1913	doc_101672866015_item	3141016	et	2	main
baltische	doc_101672866015_item	3141022	et	4	main
estland	doc_101672866015_item	3141028	et	4	main
kus	doc_101672866015_item	3141029	et	3	main
ei	doc_101672866015_item	3141055	et	4	main
rahvapärimused	doc_101672866015_item	3141063	et	3	main
1480	doc_101672866015_item	3141099	et	2	main
rajatud	doc_101672866015_item	3141107	et	4	main
aastatel	doc_101672866015_item	3141109	et	4	main
oli	doc_101672866015_item	3141112	et	3	main
ehk	doc_101672866015_item	3141127	et	3	main
von	doc_101672866015_item	3141133	et	4	main
olid	doc_101672866015_item	3141140	et	4	main
mitu	doc_101672866015_item	3141141	et	4	main
olles	doc_101672866015_item	3141147	et	3	main
peahoone	doc_101672866015_item	3141151	et	4	main
puuehitis	doc_101672866015_item	3141153	et	3	main
pansionaat	doc_101672866015_item	3141189	et	3	main
elas	doc_101672866015_item	3141199	et	3	main
põlvkonda	doc_101672866015_item	3141201	et	4	main
selle	doc_101672866015_item	3140605	et	4	main
ta	doc_101672866015_item	3140607	et	4	main
aga	doc_101672866015_item	3140620	et	3	main
keegi	doc_101672866015_item	3140621	et	4	main
pole	doc_101672866015_item	3140622	et	3	main
on	doc_101672866015_item	3140629	et	4	main
vastuolud	doc_101672866015_item	3140630	et	3	main
kuna	doc_101672866015_item	3140631	et	3	main
on	doc_101672866015_item	3140632	et	4	main
teada	doc_101672866015_item	3140633	et	3	main
et	doc_101672866015_item	3140634	et	3	main
kell	doc_101672866015_item	3140635	et	3	main
harpe	doc_101672866015_item	3140642	et	4	main
oli	doc_101672866015_item	3140645	et	3	main
harku	doc_101672866015_item	3140652	et	4	main
ja	doc_101672866015_item	3140654	et	3	main
harkusse	doc_101672866015_item	3140658	et	3	main
koloonia	doc_101672866015_item	3140662	et	4	main
enne	doc_101672866015_item	3140663	et	4	main
1940	doc_101672866015_item	3140664	et	2	main
kuid	doc_101672866015_item	3140670	et	4	main
poole	doc_101672866015_item	3140693	et	4	main
liivamägedes	doc_101672866015_item	3140697	et	3	main
on	doc_101672866015_item	3140699	et	4	main
määratleda	doc_101672866015_item	3140702	et	3	main
tegelike	doc_101672866015_item	3140705	et	3	main
arv	doc_101672866015_item	3140707	et	3	main
olla	doc_101672866015_item	3140709	et	3	main
osa	doc_101672866015_item	3140717	et	4	main
inimestelt	doc_101672866015_item	3140730	et	3	main
viibinud	doc_101672866015_item	3140736	et	4	main
harku	doc_101672866015_item	3140739	et	4	main
kohta16	doc_101672866015_item	3140741	et	2	main
1862-	doc_101672866015_item	3140766	et	4	main
tasujas	doc_101672866015_item	3140768	et	4	main
lodijarve	doc_101672866015_item	3140770	et	4	main
lugu	doc_101672866015_item	3140774	et	4	main
toetub	doc_101672866015_item	3140776	et	3	main
on	doc_101672866015_item	3140784	et	4	main
raske	doc_101672866015_item	3140785	et	4	main
kindlaks	doc_101672866015_item	3140786	et	3	main
kuid	doc_101672866015_item	3140799	et	4	main
lodensee	doc_101672866015_item	3140822	et	4	main
vanemad	doc_101672866015_item	3140832	et	4	main
lodijärve	doc_101672866015_item	3140837	et	4	main
varemeid	doc_101672866015_item	3140839	et	4	main
tasuja	doc_101672866015_item	3140840	et	4	main
tammed	doc_101672866015_item	3140898	et	3	main
ammu	doc_101672866015_item	3140902	et	4	main
elujõus	doc_101672866015_item	3140911	et	3	main
tasuja	doc_101672866015_item	3140922	et	4	main
ilmselt	doc_101672866015_item	3140927	et	4	main
ilmumise	doc_101672866015_item	3140931	et	4	main
ja	doc_101672866015_item	3140946	et	3	main
enamik	doc_101672866015_item	3140949	et	3	main
vaid	doc_101672866015_item	3140956	et	3	main
suures	doc_101672866015_item	3140958	et	3	main
kirjaniku	doc_101672866015_item	3140960	et	3	main
oma	doc_101672866015_item	3141013	et	4	main
teoses	doc_101672866015_item	3141014	et	3	main
näiteks	doc_101672866015_item	3141015	et	4	main
adolf	doc_101672866015_item	3141020	et	4	main
nimetatavate	doc_101672866015_item	3141033	et	4	main
kaks	doc_101672866015_item	3141048	et	3	main
2	doc_101672866015_item	3141051	et	2	main
18	doc_101672866015_item	3141053	et	2	main
kahjuks	doc_101672866015_item	3141054	et	4	main
aastast	doc_101672866015_item	3141071	et	4	main
praegusel	doc_101672866015_item	3141072	et	3	main
võimalus	doc_101672866015_item	3141077	et	3	main
kumna	doc_101672866015_item	3141093	et	4	main
väike	doc_101672866015_item	3141103	et	4	main
kelle	doc_101672866015_item	3141115	et	4	main
aastast	doc_101672866015_item	3141123	et	4	main
kuni	doc_101672866015_item	3141124	et	3	main
1920	doc_101672866015_item	3141125	et	2	main
aastani	doc_101672866015_item	3141126	et	3	main
mõis	doc_101672866015_item	3141132	et	3	main
meyendolffide	doc_101672866015_item	3141134	et	4	main
valduses	doc_101672866015_item	3141136	et	4	main
põlistele	doc_101672866015_item	3141137	et	4	main
ja	doc_101672866015_item	3141145	et	3	main
põlises	doc_101672866015_item	3141191	et	4	main
häärberis	doc_101672866015_item	3141192	et	3	main
ja	doc_101672866015_item	3141193	et	3	main
kahes	doc_101672866015_item	3141194	et	4	main
hiljem	doc_101672866015_item	3141195	et	3	main
aastast	doc_101672866015_item	3140665	et	4	main
on	doc_101672866015_item	3140671	et	4	main
teada	doc_101672866015_item	3140672	et	3	main
nõmme	doc_101672866015_item	3140692	et	4	main
tasaseks	doc_101672866015_item	3140720	et	4	main
kohta	doc_101672866015_item	3140726	et	4	main
ning	doc_101672866015_item	3140727	et	3	main
otsitakse	doc_101672866015_item	3140728	et	3	main
on	doc_101672866015_item	3140732	et	4	main
või	doc_101672866015_item	3140738	et	4	main
rajati	doc_101672866015_item	3140744	et	3	main
bornhöhe	doc_101672866015_item	3140765	et	4	main
ning	doc_101672866015_item	3140773	et	3	main
kuuldud	doc_101672866015_item	3140781	et	4	main
tekkinud	doc_101672866015_item	3140796	et	4	main
kalmu	doc_101672866015_item	3140704	et	4	main
matmise	doc_101672866015_item	3140706	et	4	main
suurem	doc_101672866015_item	3140711	et	4	main
vähemalt	doc_101672866015_item	3140716	et	4	main
kalmukünkaid	doc_101672866015_item	3140718	et	3	main
läbi	doc_101672866015_item	3140722	et	4	main
uurimistööid	doc_101672866015_item	3140724	et	4	main
abi	doc_101672866015_item	3140729	et	4	main
andmeid	doc_101672866015_item	3140733	et	3	main
vanglas	doc_101672866015_item	3140735	et	3	main
matmispaiga	doc_101672866015_item	3140740	et	4	main
1957	doc_101672866015_item	3140742	et	2	main
teaduste	doc_101672866015_item	3140746	et	3	main
akadeemia	doc_101672866015_item	3140747	et	4	main
eksperimentaalbioloogia	doc_101672866015_item	3140748	et	4	main
instituut	doc_101672866015_item	3140749	et	3	main
mis	doc_101672866015_item	3140750	et	4	main
töötab	doc_101672866015_item	3140751	et	3	main
seal	doc_101672866015_item	3140752	et	4	main
tänapäevani	doc_101672866015_item	3140753	et	3	main
32	doc_101672866015_item	3140754	et	2	main
tasuja	doc_101672866015_item	3140755	et	4	main
tammed	doc_101672866015_item	3140756	et	3	main
rahvapärimuste	doc_101672866015_item	3140757	et	4	main
järgi	doc_101672866015_item	3140758	et	4	main
olnud	doc_101672866015_item	3140759	et	4	main
just	doc_101672866015_item	3140760	et	3	main
e	doc_101672866015_item	3140761	et	4	main
vilde	doc_101672866015_item	3140762	et	4	main
tädipoeg	doc_101672866015_item	3140763	et	3	main
eduard	doc_101672866015_item	3140764	et	4	main
asupaik17	doc_101672866015_item	3140772	et	2	main
harku	doc_101672866015_item	3140777	et	4	main
ja	doc_101672866015_item	3140778	et	3	main
padise	doc_101672866015_item	3140779	et	4	main
teha	doc_101672866015_item	3140787	et	3	main
millised	doc_101672866015_item	3140788	et	3	main
sealkandis	doc_101672866015_item	3140789	et	3	main
jüriööga	doc_101672866015_item	3140790	et	3	main
seostavad	doc_101672866015_item	3140791	et	4	main
muistendid	doc_101672866015_item	3140792	et	3	main
isegi	doc_101672866015_item	3140800	et	4	main
lodijärv	doc_101672866015_item	3140802	et	4	main
on	doc_101672866015_item	3140803	et	4	main
peavad	doc_101672866015_item	3140811	et	4	main
õigemaks	doc_101672866015_item	3140812	et	4	main
et	doc_101672866015_item	3140813	et	3	main
nimi	doc_101672866015_item	3140814	et	3	main
klooga	doc_101672866015_item	3140818	et	4	main
mõisa	doc_101672866015_item	3140819	et	3	main
harku	doc_101672866015_item	3140831	et	4	main
metsatalu	doc_101672866015_item	3140841	et	4	main
külge	doc_101672866015_item	3140852	et	4	main
tamme	doc_101672866015_item	3140859	et	4	main
mille	doc_101672866015_item	3140860	et	3	main
alla	doc_101672866015_item	3140861	et	3	main
tasuja	doc_101672866015_item	3140862	et	4	main
fotoarhiivis	doc_101672866015_item	3140897	et	3	main
ise	doc_101672866015_item	3140899	et	4	main
aga	doc_101672866015_item	3140909	et	3	main
täies	doc_101672866015_item	3140910	et	3	main
harku	doc_101672866015_item	3140913	et	4	main
mõisa	doc_101672866015_item	3140914	et	3	main
pargist	doc_101672866015_item	3140915	et	3	main
otsitakse	doc_101672866015_item	3140916	et	3	main
endiselt	doc_101672866015_item	3140917	et	4	main
väärikate	doc_101672866015_item	3140918	et	3	main
puude	doc_101672866015_item	3140919	et	4	main
tekkisid	doc_101672866015_item	3140926	et	4	main
mis	doc_101672866015_item	3140940	et	4	main
omakorda	doc_101672866015_item	3140941	et	3	main
samuti	doc_101672866015_item	3140942	et	3	main
tasuja	doc_101672866015_item	3140947	et	4	main
ei	doc_101672866015_item	3140951	et	4	main
koosneb	doc_101672866015_item	3140957	et	3	main
osas	doc_101672866015_item	3140959	et	4	main
kuid	doc_101672866015_item	3140962	et	4	main
samuti	doc_101672866015_item	3140963	et	3	main
võib	doc_101672866015_item	3140964	et	3	main
legendid	doc_101672866015_item	3140968	et	3	main
kirjanik	doc_101672866015_item	3140983	et	3	main
enne	doc_101672866015_item	3140999	et	4	main
kirjutamist	doc_101672866015_item	3141001	et	4	main
ja	doc_101672866015_item	3141002	et	3	main
lugu	doc_101672866015_item	3141008	et	4	main
ja	doc_101672866015_item	3141009	et	3	main
pärast	doc_101672866015_item	3141010	et	4	main
kirjeldada	doc_101672866015_item	3141011	et	3	main
seda	doc_101672866015_item	3141012	et	3	main
ilmus	doc_101672866015_item	3141019	et	4	main
3	doc_101672866015_item	3141027	et	2	main
tasuja	doc_101672866015_item	3141031	et	4	main
tammedest	doc_101672866015_item	3141032	et	4	main
maetud	doc_101672866015_item	3141047	et	4	main
juhti	doc_101672866015_item	3141050	et	4	main
estenführer	doc_101672866015_item	3141052	et	4	main
teha	doc_101672866015_item	3141060	et	3	main
esinesid	doc_101672866015_item	3141064	et	4	main
enne	doc_101672866015_item	3141066	et	4	main
vaid	doc_101672866015_item	3141075	et	3	main
kõigi	doc_101672866015_item	3141078	et	4	main
kumna	doc_101672866015_item	3141094	et	4	main
oli	doc_101672866015_item	3141096	et	3	main
esmakordselt	doc_101672866015_item	3141097	et	4	main
seal	doc_101672866015_item	3141101	et	4	main
asus	doc_101672866015_item	3141102	et	4	main
oli	doc_101672866015_item	3141106	et	3	main
järgi	doc_101672866015_item	3141116	et	4	main
mõisa-	doc_101672866015_item	3141128	et	3	main
lõpuni	doc_101672866015_item	3141130	et	3	main
vana	doc_101672866015_item	3141150	et	4	main
on	doc_101672866015_item	3141152	et	4	main
tulnud	doc_101672866015_item	3140804	et	4	main
on	doc_101672866015_item	3140815	et	4	main
hoopis	doc_101672866015_item	3140816	et	3	main
saksakeelsest	doc_101672866015_item	3140820	et	3	main
olid	doc_101672866015_item	3140830	et	4	main
nii	doc_101672866015_item	3140836	et	3	main
lossi	doc_101672866015_item	3140838	et	4	main
keldrit	doc_101672866015_item	3140845	et	3	main
tambetit	doc_101672866015_item	3140847	et	4	main
olnud	doc_101672866015_item	3140854	et	4	main
isa	doc_101672866015_item	3140864	et	4	main
matnud	doc_101672866015_item	3140865	et	4	main
need	doc_101672866015_item	3140866	et	3	main
tammed	doc_101672866015_item	3140867	et	3	main
olid	doc_101672866015_item	3140868	et	4	main
laiematki	doc_101672866015_item	3140869	et	4	main
tuntud	doc_101672866015_item	3140870	et	4	main
neid	doc_101672866015_item	3140871	et	4	main
käidi	doc_101672866015_item	3140872	et	3	main
vaatamas	doc_101672866015_item	3140873	et	3	main
ja	doc_101672866015_item	3140874	et	3	main
neist	doc_101672866015_item	3140875	et	4	main
tehti	doc_101672866015_item	3140876	et	3	main
pilte	doc_101672866015_item	3140877	et	3	main
mõned	doc_101672866015_item	3140878	et	3	main
lodijärve	doc_101672866015_item	3140879	et	4	main
lossist	doc_101672866015_item	3140880	et	3	main
ja	doc_101672866015_item	3140881	et	3	main
tasuja	doc_101672866015_item	3140882	et	4	main
tammedest	doc_101672866015_item	3140883	et	4	main
fotod	doc_101672866015_item	3140884	et	3	main
ilmusid	doc_101672866015_item	3140885	et	4	main
1910	doc_101672866015_item	3140886	et	2	main
aastal	doc_101672866015_item	3140887	et	3	main
eesti	doc_101672866015_item	3140888	et	4	main
kodus	doc_101672866015_item	3140889	et	4	main
mõned	doc_101672866015_item	3140890	et	3	main
fotod	doc_101672866015_item	3140891	et	3	main
on	doc_101672866015_item	3140892	et	4	main
säilinud	doc_101672866015_item	3140893	et	4	main
ka	doc_101672866015_item	3140894	et	3	main
eesti	doc_101672866015_item	3140895	et	4	main
ajaloomuuseumi	doc_101672866015_item	3140896	et	4	main
seast	doc_101672866015_item	3140920	et	4	main
endistviisi	doc_101672866015_item	3140921	et	3	main
tasuja	doc_101672866015_item	3140928	et	4	main
trüki	doc_101672866015_item	3140930	et	4	main
järel	doc_101672866015_item	3140932	et	4	main
kõdunenud	doc_101672866015_item	3140906	et	4	main
legend	doc_101672866015_item	3140907	et	3	main
on	doc_101672866015_item	3140908	et	4	main
ja	doc_101672866015_item	3140912	et	3	main
tammesid	doc_101672866015_item	3140923	et	3	main
nimetatud	doc_101672866015_item	3140924	et	4	main
rahvapärimused	doc_101672866015_item	3140925	et	3	main
neid	doc_101672866015_item	3140936	et	4	main
lugusid	doc_101672866015_item	3140937	et	3	main
ajalooliste	doc_101672866015_item	3140938	et	4	main
tõsiasjadena	doc_101672866015_item	3140939	et	3	main
legendi	doc_101672866015_item	3140944	et	4	main
ajalookronoloogia	doc_101672866015_item	3140955	et	4	main
ja	doc_101672866015_item	3140971	et	3	main
elas	doc_101672866015_item	3140973	et	3	main
kangelane	doc_101672866015_item	3140975	et	3	main
saatus	doc_101672866015_item	3140977	et	3	main
kirjutas	doc_101672866015_item	3140984	et	3	main
temast	doc_101672866015_item	3140985	et	3	main
harku	doc_101672866015_item	3140986	et	4	main
polnud	doc_101672866015_item	3140987	et	3	main
bornhöhele	doc_101672866015_item	3140988	et	4	main
mingi	doc_101672866015_item	3140989	et	4	main
võõras	doc_101672866015_item	3140990	et	4	main
paik	doc_101672866015_item	3140991	et	3	main
seal	doc_101672866015_item	3140992	et	4	main
teda	doc_101672866015_item	3140993	et	4	main
olevat	doc_101672866015_item	3140994	et	4	main
nähtud	doc_101672866015_item	3140995	et	4	main
ringi	doc_101672866015_item	3140996	et	4	main
tollases	doc_101672866015_item	3140933	et	3	main
ajakirjanduses	doc_101672866015_item	3140934	et	3	main
esitati	doc_101672866015_item	3140935	et	4	main
aitas	doc_101672866015_item	3140943	et	3	main
levikule	doc_101672866015_item	3140945	et	3	main
nagu	doc_101672866015_item	3140948	et	3	main
kirjandusteoseid	doc_101672866015_item	3140950	et	3	main
ole	doc_101672866015_item	3140952	et	4	main
faktidele	doc_101672866015_item	3140953	et	3	main
tuginev	doc_101672866015_item	3140954	et	4	main
fantaasiast	doc_101672866015_item	3140961	et	3	main
oletada	doc_101672866015_item	3140965	et	3	main
need	doc_101672866015_item	3140967	et	3	main
eksisteerisid	doc_101672866015_item	3140970	et	4	main
tõepoolest	doc_101672866015_item	3140972	et	3	main
kunagi	doc_101672866015_item	3140974	et	3	main
kelle	doc_101672866015_item	3140976	et	4	main
tasuja	doc_101672866015_item	3140979	et	4	main
saatusega	doc_101672866015_item	3140980	et	3	main
sarnane	doc_101672866015_item	3140981	et	4	main
ning	doc_101672866015_item	3140982	et	3	main
ka	doc_101672866015_item	3140998	et	3	main
tasuja	doc_101672866015_item	3141000	et	4	main
ta	doc_101672866015_item	3141003	et	4	main
aastal	doc_101672866015_item	3141017	et	3	main
adressebücher	doc_101672866015_item	3141025	et	4	main
band	doc_101672866015_item	3141026	et	4	main
puude	doc_101672866015_item	3141034	et	4	main
eestlaste	doc_101672866015_item	3141049	et	4	main
kas	doc_101672866015_item	3141061	et	3	main
ka	doc_101672866015_item	3141065	et	3	main
tasuja	doc_101672866015_item	3141067	et	4	main
ilmumist	doc_101672866015_item	3141068	et	4	main
ehk	doc_101672866015_item	3141069	et	3	main
1880	doc_101672866015_item	3141070	et	2	main
üks	doc_101672866015_item	3141076	et	3	main
nende	doc_101672866015_item	3141079	et	4	main
mälestusmärkide	doc_101672866015_item	3141080	et	3	main
tõelise	doc_101672866015_item	3141081	et	4	main
tekkimise	doc_101672866015_item	3141082	et	4	main
ja	doc_101672866015_item	3141083	et	3	main
mõisaansambel	doc_101672866015_item	3141104	et	3	main
1620tel	doc_101672866015_item	3141108	et	4	main
esimene	doc_101672866015_item	3141110	et	3	main
koht	doc_101672866015_item	3141117	et	3	main
oma	doc_101672866015_item	3141118	et	4	main
ajastu	doc_101672866015_item	3141129	et	4	main
baltlastele	doc_101672866015_item	3141138	et	4	main
kes	doc_101672866015_item	3141139	et	4	main
venemaa	doc_101672866015_item	3141143	et	4	main
riigiteenistuses	doc_101672866015_item	3141146	et	3	main
venestunud19	doc_101672866015_item	3141148	et	2	main
1910tel	doc_101672866015_item	3141160	et	4	main
suures	doc_101672866015_item	3141197	et	3	main
mothander	doc_101672866015_item	3141206	et	4	main
parunid	doc_101672866015_item	3141209	et	3	main
andekad	doc_101672866015_item	3141215	et	3	main
neid	doc_101672866015_item	3141221	et	4	main
laia	doc_101672866015_item	3141223	et	4	main
õigeusku	doc_101672866015_item	3141242	et	4	main
astusid	doc_101672866015_item	3141244	et	4	main
teenistusse	doc_101672866015_item	3141246	et	3	main
õukonnas	doc_101672866015_item	3141251	et	3	main
kõrgetele	doc_101672866015_item	3141252	et	4	main
suguluses	doc_101672866015_item	3141260	et	4	main
romanovite	doc_101672866015_item	3141261	et	4	main
dünastiaga	doc_101672866015_item	3141262	et	3	main
pärast	doc_101672866015_item	3141263	et	4	main
suurt	doc_101672866015_item	3141264	et	3	main
jäid	doc_101672866015_item	3141271	et	4	main
vastu	doc_101672866015_item	3141298	et	3	main
maareformi	doc_101672866015_item	3141300	et	4	main
jäi	doc_101672866015_item	3141304	et	3	main
vaid	doc_101672866015_item	3141305	et	3	main
mõisasüda	doc_101672866015_item	3141306	et	3	main
olukorra	doc_101672866015_item	3141309	et	3	main
käed	doc_101672866015_item	3141317	et	3	main
kolme	doc_101672866015_item	3141321	et	4	main
suuruse	doc_101672866015_item	3141323	et	4	main
perekond	doc_101672866015_item	3141335	et	3	main
kell	doc_101672866015_item	3141338	et	3	main
võiks	doc_101672866015_item	3141004	et	4	main
kuulda	doc_101672866015_item	3141005	et	4	main
riias	doc_101672866015_item	3141018	et	4	main
richtersi	doc_101672866015_item	3141021	et	4	main
verkhrs-	doc_101672866015_item	3141023	et	4	main
und	doc_101672866015_item	3141024	et	4	main
praegu	doc_101672866015_item	3141030	et	3	main
kohta	doc_101672866015_item	3141035	et	4	main
märgitakse	doc_101672866015_item	3141036	et	4	main
kahe	doc_101672866015_item	3141037	et	3	main
enam	doc_101672866015_item	3141038	et	4	main
kui	doc_101672866015_item	3141039	et	3	main
700	doc_101672866015_item	3141040	et	2	main
aasta	doc_101672866015_item	3141041	et	4	main
vanuse	doc_101672866015_item	3141042	et	4	main
tamme	doc_101672866015_item	3141043	et	4	main
alla	doc_101672866015_item	3141044	et	3	main
rahvajutu	doc_101672866015_item	3141045	et	3	main
järgi	doc_101672866015_item	3141046	et	4	main
ole	doc_101672866015_item	3141056	et	4	main
praegu	doc_101672866015_item	3141057	et	3	main
võimalik	doc_101672866015_item	3141058	et	3	main
kindlaks	doc_101672866015_item	3141059	et	3	main
sellised	doc_101672866015_item	3141062	et	4	main
ajal	doc_101672866015_item	3141073	et	4	main
on	doc_101672866015_item	3141074	et	4	main
esinemiseaja	doc_101672866015_item	3141084	et	4	main
selgitamiseks	doc_101672866015_item	3141085	et	4	main
organiseerida	doc_101672866015_item	3141086	et	3	main
nendes	doc_101672866015_item	3141087	et	4	main
kohtades	doc_101672866015_item	3141088	et	3	main
kaevamisi	doc_101672866015_item	3141089	et	4	main
asjatundlikul	doc_101672866015_item	3141090	et	3	main
juhendamisel	doc_101672866015_item	3141091	et	4	main
4	doc_101672866015_item	3141092	et	2	main
küla	doc_101672866015_item	3141095	et	4	main
mainitud	doc_101672866015_item	3141098	et	4	main
aastal	doc_101672866015_item	3141100	et	3	main
mis	doc_101672866015_item	3141105	et	4	main
omanik	doc_101672866015_item	3141111	et	3	main
johan	doc_101672866015_item	3141113	et	4	main
knopius	doc_101672866015_item	3141114	et	4	main
nimetuse	doc_101672866015_item	3141119	et	4	main
saigi	doc_101672866015_item	3141120	et	4	main
alates	doc_101672866015_item	3141121	et	3	main
1838	doc_101672866015_item	3141122	et	2	main
oli	doc_101672866015_item	3141131	et	3	main
aadliperekonna	doc_101672866015_item	3141135	et	4	main
põlve	doc_101672866015_item	3141142	et	4	main
õukonna-	doc_101672866015_item	3141144	et	3	main
mõisa	doc_101672866015_item	3141149	et	3	main
millele	doc_101672866015_item	3141154	et	3	main
aastatel	doc_101672866015_item	3141161	et	4	main
püstitati	doc_101672866015_item	3141162	et	4	main
vanast	doc_101672866015_item	3141163	et	3	main
peahoonest	doc_101672866015_item	3141164	et	4	main
põhjapoole	doc_101672866015_item	3141165	et	4	main
kahekorruseline	doc_101672866015_item	3141166	et	4	main
neoklassitsistlik	doc_101672866015_item	3141167	et	3	main
uus	doc_101672866015_item	3141168	et	3	main
peahoone	doc_101672866015_item	3141169	et	4	main
pärast	doc_101672866015_item	3141170	et	4	main
von	doc_101672866015_item	3141171	et	4	main
meyendolffide	doc_101672866015_item	3141172	et	4	main
perekonda	doc_101672866015_item	3141173	et	4	main
mõisasse	doc_101672866015_item	3141174	et	3	main
paigutati	doc_101672866015_item	3141175	et	3	main
sovhoosi	doc_101672866015_item	3141176	et	4	main
osakonnakeskuse	doc_101672866015_item	3141177	et	3	main
tänapäeval	doc_101672866015_item	3141178	et	3	main
puust	doc_101672866015_item	3141179	et	4	main
peahoone	doc_101672866015_item	3141180	et	4	main
on	doc_101672866015_item	3141181	et	4	main
kasutusel	doc_101672866015_item	3141182	et	4	main
korterimajana	doc_101672866015_item	3141183	et	3	main
uuem	doc_101672866015_item	3141184	et	4	main
aga	doc_101672866015_item	3141185	et	3	main
varemetes20	doc_101672866015_item	3141186	et	2	main
41	doc_101672866015_item	3141187	et	2	main
venepärane	doc_101672866015_item	3141188	et	4	main
on	doc_101672866015_item	3141155	et	4	main
iseloomulikud	doc_101672866015_item	3141156	et	3	main
arvukad	doc_101672866015_item	3141157	et	3	main
puidust	doc_101672866015_item	3141158	et	3	main
kaunistused	doc_101672866015_item	3141159	et	4	main
ehitatud	doc_101672866015_item	3141196	et	4	main
kumna	doc_101672866015_item	3141190	et	4	main
kes	doc_101672866015_item	3141203	et	4	main
nagu	doc_101672866015_item	3141204	et	3	main
raamatus	doc_101672866015_item	3141208	et	4	main
eestlased	doc_101672866015_item	3141210	et	3	main
ja	doc_101672866015_item	3141211	et	3	main
kirjeldab	doc_101672866015_item	3141213	et	3	main
maailma	doc_101672866015_item	3141224	et	4	main
georg	doc_101672866015_item	3141230	et	4	main
meyendorff	doc_101672866015_item	3141231	et	4	main
ning	doc_101672866015_item	3141239	et	3	main
venestunud	doc_101672866015_item	3141247	et	4	main
meyendoffid	doc_101672866015_item	3141248	et	4	main
isegi	doc_101672866015_item	3141254	et	4	main
olid	doc_101672866015_item	3141255	et	4	main
põgenesid	doc_101672866015_item	3141266	et	4	main
ja	doc_101672866015_item	3141270	et	3	main
uue	doc_101672866015_item	3141307	et	3	main
toime	doc_101672866015_item	3141310	et	4	main
tulemiseks	doc_101672866015_item	3141311	et	4	main
töös	doc_101672866015_item	3141318	et	3	main
nüüd	doc_101672866015_item	3141330	et	4	main
hoolt	doc_101672866015_item	3141331	et	4	main
parunessid21	doc_101672866015_item	3141332	et	2	main
nüüd	doc_101672866015_item	3141336	et	4	main
neli	doc_101672866015_item	3141339	et	3	main
koguneti	doc_101672866015_item	3141341	et	3	main
teed	doc_101672866015_item	3141344	et	4	main
jooma	doc_101672866015_item	3141345	et	4	main
siis	doc_101672866015_item	3141346	et	3	main
aru	doc_101672866015_item	3141352	et	4	main
andma	doc_101672866015_item	3141353	et	3	main
olid	doc_101672866015_item	3141360	et	4	main
boheemliku	doc_101672866015_item	3141361	et	3	main
villas	doc_101672866015_item	3141198	et	4	main
kolm	doc_101672866015_item	3141200	et	3	main
meyendoffe	doc_101672866015_item	3141202	et	4	main
ja	doc_101672866015_item	3141217	et	3	main
viimane	doc_101672866015_item	3141225	et	3	main
suguvõsa	doc_101672866015_item	3141226	et	4	main
luterlane	doc_101672866015_item	3141227	et	3	main
ütlesid	doc_101672866015_item	3141238	et	4	main
tsaari	doc_101672866015_item	3141250	et	4	main
eestisse	doc_101672866015_item	3141268	et	4	main
tagasi	doc_101672866015_item	3141269	et	3	main
kumnasse	doc_101672866015_item	3141272	et	4	main
paremaid	doc_101672866015_item	3141273	et	4	main
aegu	doc_101672866015_item	3141274	et	4	main
ootama	doc_101672866015_item	3141275	et	3	main
nad	doc_101672866015_item	3141276	et	3	main
moodustasid	doc_101672866015_item	3141277	et	4	main
oma	doc_101672866015_item	3141278	et	4	main
kodupaigast	doc_101672866015_item	3141279	et	4	main
sellist	doc_101672866015_item	3141280	et	4	main
hõimukolooniat	doc_101672866015_item	3141281	et	3	main
kus	doc_101672866015_item	3141282	et	3	main
võeti	doc_101672866015_item	3141283	et	3	main
lahkelt	doc_101672866015_item	3141284	et	4	main
vastu	doc_101672866015_item	3141285	et	3	main
kaugemaid	doc_101672866015_item	3141286	et	4	main
ja	doc_101672866015_item	3141287	et	3	main
lähemaid	doc_101672866015_item	3141288	et	4	main
sõpru	doc_101672866015_item	3141289	et	3	main
ning	doc_101672866015_item	3141290	et	3	main
sugulasi	doc_101672866015_item	3141291	et	3	main
1919	doc_101672866015_item	3141292	et	2	main
aastal	doc_101672866015_item	3141293	et	3	main
eesti	doc_101672866015_item	3141294	et	4	main
asutava	doc_101672866015_item	3141295	et	4	main
kogu	doc_101672866015_item	3141296	et	4	main
poolt	doc_101672866015_item	3141297	et	4	main
võetud	doc_101672866015_item	3141299	et	4	main
mõisa	doc_101672866015_item	3141320	et	3	main
viisaja	doc_101672866015_item	3141325	et	4	main
aknaga	doc_101672866015_item	3141326	et	3	main
terve	doc_101672866015_item	3141333	et	4	main
päeva	doc_101672866015_item	3141334	et	4	main
pidi	doc_101672866015_item	3141347	et	4	main
igaüks	doc_101672866015_item	3141348	et	3	main
pärast	doc_101672866015_item	3141354	et	4	main
odavamate	doc_101672866015_item	3141399	et	4	main
carl	doc_101672866015_item	3141401	et	4	main
mothander	doc_101672866015_item	3141402	et	4	main
nimetab	doc_101672866015_item	3141403	et	3	main
pingutusi	doc_101672866015_item	3141424	et	4	main
elu	doc_101672866015_item	3141432	et	4	main
kumnas	doc_101672866015_item	3141435	et	4	main
mitmelt	doc_101672866015_item	3141444	et	4	main
pere	doc_101672866015_item	3141463	et	4	main
ära	doc_101672866015_item	3141475	et	4	main
carl	doc_101672866015_item	3141205	et	4	main
enamlased	doc_101672866015_item	3141212	et	3	main
inimesed	doc_101672866015_item	3141216	et	3	main
talent	doc_101672866015_item	3141219	et	3	main
parun	doc_101672866015_item	3141229	et	3	main
lahti	doc_101672866015_item	3141237	et	4	main
pöördusid	doc_101672866015_item	3141240	et	4	main
ning	doc_101672866015_item	3141243	et	3	main
vene	doc_101672866015_item	3141245	et	4	main
võimupositsioonidele	doc_101672866015_item	3141253	et	3	main
kaudu	doc_101672866015_item	3141259	et	3	main
revolutsiooni	doc_101672866015_item	3141265	et	4	main
seadusega	doc_101672866015_item	3141301	et	3	main
majandusliku	doc_101672866015_item	3141308	et	3	main
hoida	doc_101672866015_item	3141319	et	3	main
hektari	doc_101672866015_item	3141322	et	3	main
ja	doc_101672866015_item	3141324	et	3	main
taimelavade	doc_101672866015_item	3141327	et	3	main
eest	doc_101672866015_item	3141328	et	4	main
töötas	doc_101672866015_item	3141337	et	3	main
esiema	doc_101672866015_item	3141342	et	4	main
valdkonna	doc_101672866015_item	3141350	et	4	main
kohta	doc_101672866015_item	3141351	et	4	main
segiläbi	doc_101672866015_item	3141397	et	3	main
imeliseks	doc_101672866015_item	3141406	et	4	main
koht	doc_101672866015_item	3141409	et	3	main
tehti	doc_101672866015_item	3141411	et	3	main
seda	doc_101672866015_item	3141413	et	3	main
sooviti	doc_101672866015_item	3141415	et	3	main
ei	doc_101672866015_item	3141421	et	4	main
varjatud	doc_101672866015_item	3141430	et	4	main
olid	doc_101672866015_item	3141434	et	4	main
oli	doc_101672866015_item	3141467	et	3	main
külaline	doc_101672866015_item	3141470	et	4	main
voodi	doc_101672866015_item	3141474	et	4	main
majapidamises	doc_101672866015_item	3141480	et	3	main
töö	doc_101672866015_item	3141494	et	4	main
oma	doc_101672866015_item	3141207	et	4	main
olid	doc_101672866015_item	3141214	et	4	main
nende	doc_101672866015_item	3141218	et	4	main
kandis	doc_101672866015_item	3141220	et	4	main
sageli	doc_101672866015_item	3141222	et	3	main
oli	doc_101672866015_item	3141228	et	3	main
tema	doc_101672866015_item	3141232	et	4	main
pojad	doc_101672866015_item	3141233	et	4	main
on	doc_101672866015_item	3141234	et	4	main
aga	doc_101672866015_item	3141235	et	3	main
usust	doc_101672866015_item	3141236	et	3	main
vene	doc_101672866015_item	3141241	et	4	main
tõusid	doc_101672866015_item	3141249	et	4	main
mingi	doc_101672866015_item	3141256	et	4	main
suurvürstliku	doc_101672866015_item	3141257	et	3	main
abielu	doc_101672866015_item	3141258	et	4	main
nad	doc_101672866015_item	3141267	et	3	main
meyendorfide	doc_101672866015_item	3141302	et	4	main
valdusse	doc_101672866015_item	3141303	et	4	main
tuli	doc_101672866015_item	3141312	et	4	main
mõisaelanikel	doc_101672866015_item	3141313	et	3	main
ja	doc_101672866015_item	3141314	et	3	main
ka	doc_101672866015_item	3141315	et	3	main
külalistel	doc_101672866015_item	3141316	et	4	main
kandsid	doc_101672866015_item	3141329	et	4	main
oma	doc_101672866015_item	3141349	et	4	main
kõik	doc_101672866015_item	3141355	et	4	main
hoiakuga	doc_101672866015_item	3141362	et	3	main
individualistid	doc_101672866015_item	3141363	et	3	main
riietusid	doc_101672866015_item	3141364	et	4	main
vabameelselt	doc_101672866015_item	3141365	et	4	main
kogu	doc_101672866015_item	3141366	et	4	main
kumna	doc_101672866015_item	3141367	et	4	main
kohal	doc_101672866015_item	3141368	et	4	main
valitses	doc_101672866015_item	3141369	et	3	main
selline	doc_101672866015_item	3141370	et	4	main
kunstnikulohakus	doc_101672866015_item	3141371	et	4	main
ja	doc_101672866015_item	3141372	et	3	main
venelik	doc_101672866015_item	3141373	et	3	main
tolerants	doc_101672866015_item	3141374	et	3	main
carl	doc_101672866015_item	3141375	et	4	main
mothanderi	doc_101672866015_item	3141376	et	4	main
sõnul	doc_101672866015_item	3141377	et	3	main
vabameelsete	doc_101672866015_item	3141378	et	3	main
ja	doc_101672866015_item	3141379	et	3	main
kunstnikuloomuga	doc_101672866015_item	3141380	et	3	main
meyendoffide	doc_101672866015_item	3141381	et	4	main
hoonete	doc_101672866015_item	3141382	et	4	main
interjöör	doc_101672866015_item	3141383	et	3	main
oli	doc_101672866015_item	3141384	et	3	main
segadik	doc_101672866015_item	3141385	et	3	main
luksusest	doc_101672866015_item	3141386	et	4	main
ja	doc_101672866015_item	3141387	et	3	main
odavast	doc_101672866015_item	3141388	et	4	main
pudipadist	doc_101672866015_item	3141389	et	4	main
muistsest	doc_101672866015_item	3141390	et	3	main
ja	doc_101672866015_item	3141391	et	3	main
praegusest	doc_101672866015_item	3141392	et	3	main
ajast	doc_101672866015_item	3141393	et	4	main
näiteks	doc_101672866015_item	3141394	et	4	main
vaimustav	doc_101672866015_item	3141395	et	4	main
rokokoomööbel	doc_101672866015_item	3141396	et	3	main
aga	doc_101672866015_item	3141340	et	3	main
juurde	doc_101672866015_item	3141343	et	4	main
lasid	doc_101672866015_item	3141356	et	4	main
end	doc_101672866015_item	3141357	et	4	main
lõdvaks	doc_101672866015_item	3141358	et	3	main
need	doc_101672866015_item	3141359	et	3	main
see	doc_101672866015_item	3141407	et	3	main
nende	doc_101672866015_item	3141419	et	4	main
ei	doc_101672866015_item	3141429	et	4	main
peeti	doc_101672866015_item	3141442	et	4	main
oma	doc_101672866015_item	3141473	et	4	main
tegema	doc_101672866015_item	3141476	et	3	main
aga	doc_101672866015_item	3141481	et	3	main
viibis	doc_101672866015_item	3141483	et	3	main
koos	doc_101672866015_item	3141498	et	4	main
tädiga	doc_101672866015_item	3141501	et	3	main
käia22	doc_101672866015_item	3141504	et	2	main
ajaloos	doc_101672866015_item	3141515	et	4	main
mis	doc_101672866015_item	3141516	et	4	main
aga	doc_101672866015_item	3141523	et	3	main
panuse	doc_101672866015_item	3141527	et	3	main
paiga	doc_101672866015_item	3141529	et	4	main
et	doc_101672866015_item	3141538	et	3	main
ning	doc_101672866015_item	3141551	et	3	main
tsivilisatsioonist	doc_101672866015_item	3141553	et	3	main
armastusväärne	doc_101672866015_item	3141555	et	3	main
kunstlikest	doc_101672866015_item	3141565	et	3	main
sellisena	doc_101672866015_item	3141568	et	4	main
jääb	doc_101672866015_item	3141572	et	3	main
ajalukku	doc_101672866015_item	3141574	et	4	main
sellise	doc_101672866015_item	3141575	et	4	main
oli	doc_101672866015_item	3141579	et	3	main
seda	doc_101672866015_item	3141585	et	3	main
arvatavasti	doc_101672866015_item	3141603	et	3	main
tallinna	doc_101672866015_item	3141604	et	4	main
tsaarivalitsuse	doc_101672866015_item	3141606	et	3	main
perekonna	doc_101672866015_item	3141615	et	4	main
puhkekohana25	doc_101672866015_item	3141617	et	2	main
18	doc_101672866015_item	3141621	et	2	main
lucca	doc_101672866015_item	3141633	et	4	main
suvitusmõis	doc_101672866015_item	3141634	et	3	main
mis	doc_101672866015_item	3141635	et	4	main
tõi	doc_101672866015_item	3141636	et	3	main
eestimaale	doc_101672866015_item	3141640	et	4	main
intensiivne	doc_101672866015_item	3141646	et	3	main
hoogustus	doc_101672866015_item	3141649	et	4	main
51	doc_101672866015_item	3141687	et	2	main
neogooti	doc_101672866015_item	3141690	et	4	main
on	doc_101672866015_item	3141717	et	4	main
keila	doc_101672866015_item	3141724	et	4	main
septembri	doc_101672866015_item	3141731	et	3	main
sai	doc_101672866015_item	3141733	et	4	main
kabel	doc_101672866015_item	3141734	et	4	main
oli	doc_101672866015_item	3141741	et	3	main
1930	doc_101672866015_item	3141745	et	2	main
pärast	doc_101672866015_item	3141747	et	4	main
maikuust	doc_101672866015_item	3141760	et	4	main
võiks	doc_101672866015_item	3141804	et	4	main
on	doc_101672866015_item	3141810	et	4	main
piirkonnale	doc_101672866015_item	3141812	et	4	main
väga	doc_101672866015_item	3141813	et	3	main
omased	doc_101672866015_item	3141814	et	3	main
ja	doc_101672866015_item	3141815	et	3	main
iseloomulikud	doc_101672866015_item	3141816	et	3	main
ning	doc_101672866015_item	3141817	et	3	main
räägivad	doc_101672866015_item	3141818	et	3	main
kohalikust	doc_101672866015_item	3141819	et	4	main
hetkel	doc_101672866015_item	3141828	et	4	main
ranna	doc_101672866015_item	3141835	et	3	main
kuulub	doc_101672866015_item	3141837	et	3	main
õhtuti	doc_101672866015_item	3141845	et	3	main
piibli-	doc_101672866015_item	3141847	et	3	main
kirikus	doc_101672866015_item	3141850	et	3	main
ja	doc_101672866015_item	3141868	et	3	main
poolel	doc_101672866015_item	3141875	et	4	main
alates	doc_101672866015_item	3141876	et	3	main
1653	doc_101672866015_item	3141877	et	2	main
henning	doc_101672866015_item	3141881	et	4	main
müüdi	doc_101672866015_item	3141886	et	4	main
mõisahooneks	doc_101672866015_item	3141911	et	4	main
härrarahvas	doc_101672866015_item	3141918	et	4	main
kõige	doc_101672866015_item	3141398	et	4	main
pulktoolidega	doc_101672866015_item	3141400	et	3	main
seal	doc_101672866015_item	3141405	et	4	main
oli	doc_101672866015_item	3141408	et	3	main
kus	doc_101672866015_item	3141410	et	3	main
külalistel	doc_101672866015_item	3141416	et	4	main
oli	doc_101672866015_item	3141417	et	3	main
palju	doc_101672866015_item	3141418	et	4	main
tehtud	doc_101672866015_item	3141422	et	4	main
midagi	doc_101672866015_item	3141431	et	4	main
pansionaati	doc_101672866015_item	3141443	et	4	main
maalt	doc_101672866015_item	3141445	et	3	main
päri	doc_101672866015_item	3141446	et	4	main
tosinale	doc_101672866015_item	3141447	et	4	main
mitmelt	doc_101672866015_item	3141448	et	4	main
maalt	doc_101672866015_item	3141449	et	3	main
pärit	doc_101672866015_item	3141450	et	3	main
noorele	doc_101672866015_item	3141451	et	3	main
inimesele	doc_101672866015_item	3141452	et	3	main
peale	doc_101672866015_item	3141453	et	4	main
neid	doc_101672866015_item	3141454	et	4	main
külalisi	doc_101672866015_item	3141455	et	4	main
kuulus	doc_101672866015_item	3141456	et	4	main
kolooniasse	doc_101672866015_item	3141457	et	3	main
veel	doc_101672866015_item	3141458	et	4	main
tosin	doc_101672866015_item	3141459	et	4	main
parimas	doc_101672866015_item	3141460	et	4	main
flirtimiseas	doc_101672866015_item	3141461	et	3	main
oma	doc_101672866015_item	3141462	et	4	main
noort	doc_101672866015_item	3141464	et	3	main
elu	doc_101672866015_item	3141404	et	4	main
täpselt	doc_101672866015_item	3141412	et	4	main
mida	doc_101672866015_item	3141414	et	4	main
pärast	doc_101672866015_item	3141420	et	4	main
erilisi	doc_101672866015_item	3141423	et	4	main
aga	doc_101672866015_item	3141425	et	3	main
nende	doc_101672866015_item	3141426	et	4	main
eest	doc_101672866015_item	3141427	et	4	main
ka	doc_101672866015_item	3141428	et	3	main
uksed	doc_101672866015_item	3141433	et	3	main
alati	doc_101672866015_item	3141436	et	4	main
avatud	doc_101672866015_item	3141437	et	4	main
eriti	doc_101672866015_item	3141438	et	3	main
suviti	doc_101672866015_item	3141439	et	3	main
kui	doc_101672866015_item	3141440	et	3	main
mõisas	doc_101672866015_item	3141441	et	3	main
pansionaati	doc_101672866015_item	3141465	et	4	main
kuid	doc_101672866015_item	3141469	et	4	main
pidi	doc_101672866015_item	3141471	et	4	main
ise	doc_101672866015_item	3141472	et	4	main
abistama	doc_101672866015_item	3141478	et	3	main
selline	doc_101672866015_item	3141484	et	4	main
oli	doc_101672866015_item	3141488	et	3	main
eriti	doc_101672866015_item	3141495	et	3	main
valla	doc_101672866015_item	3141514	et	4	main
valla	doc_101672866015_item	3141521	et	4	main
kohtadest	doc_101672866015_item	3141522	et	3	main
oma	doc_101672866015_item	3141526	et	4	main
selle	doc_101672866015_item	3141528	et	4	main
minnalaskmisemeeleolu	doc_101672866015_item	3141556	et	4	main
see	doc_101672866015_item	3141557	et	3	main
oli	doc_101672866015_item	3141558	et	3	main
vene	doc_101672866015_item	3141559	et	4	main
just	doc_101672866015_item	3141567	et	3	main
pansionaatena	doc_101672866015_item	3141577	et	4	main
sellisena	doc_101672866015_item	3141583	et	4	main
ka	doc_101672866015_item	3141586	et	3	main
rannamõisat	doc_101672866015_item	3141591	et	3	main
1428	doc_101672866015_item	3141594	et	2	main
leppesgute24	doc_101672866015_item	3141596	et	2	main
kuni	doc_101672866015_item	3141597	et	3	main
kuulus	doc_101672866015_item	3141600	et	4	main
linnusele	doc_101672866015_item	3141605	et	4	main
aja	doc_101672866015_item	3141607	et	4	main
algusest	doc_101672866015_item	3141608	et	4	main
rannamõisa	doc_101672866015_item	3141619	et	3	main
kui	doc_101672866015_item	3141623	et	3	main
kaupmees	doc_101672866015_item	3141625	et	4	main
a	doc_101672866015_item	3141626	et	4	main
girard	doc_101672866015_item	3141627	et	4	main
tõelise	doc_101672866015_item	3141637	et	4	main
itaalia	doc_101672866015_item	3141638	et	4	main
hoogu	doc_101672866015_item	3141639	et	4	main
ehitamise	doc_101672866015_item	3141648	et	4	main
aastad	doc_101672866015_item	3141656	et	3	main
pidama	doc_101672866015_item	3141686	et	4	main
rannamõisa	doc_101672866015_item	3141688	et	3	main
ning	doc_101672866015_item	3141697	et	3	main
juulil	doc_101672866015_item	3141700	et	3	main
aastal	doc_101672866015_item	3141702	et	3	main
teadmata	doc_101672866015_item	3141718	et	4	main
kogudusele	doc_101672866015_item	3141725	et	3	main
ranna	doc_101672866015_item	3141728	et	3	main
organist	doc_101672866015_item	3141738	et	4	main
dunkel	doc_101672866015_item	3141743	et	4	main
aastani	doc_101672866015_item	3141746	et	3	main
volmer	doc_101672866015_item	3141752	et	4	main
r	doc_101672866015_item	3141753	et	4	main
lipsthal	doc_101672866015_item	3141754	et	4	main
kirikuõpetajaks	doc_101672866015_item	3141761	et	3	main
ja	doc_101672866015_item	3141797	et	3	main
ja	doc_101672866015_item	3141800	et	3	main
uuesti	doc_101672866015_item	3141805	et	3	main
võtta	doc_101672866015_item	3141807	et	3	main
on	doc_101672866015_item	3141827	et	4	main
praegu	doc_101672866015_item	3141834	et	3	main
150	doc_101672866015_item	3141839	et	2	main
komapäeva	doc_101672866015_item	3141844	et	4	main
tegutseb	doc_101672866015_item	3141851	et	3	main
korraldakse	doc_101672866015_item	3141858	et	4	main
kontserte	doc_101672866015_item	3141859	et	3	main
hind	doc_101672866015_item	3141466	et	3	main
soodne	doc_101672866015_item	3141468	et	3	main
ja	doc_101672866015_item	3141477	et	3	main
see	doc_101672866015_item	3141487	et	3	main
armastasid	doc_101672866015_item	3141497	et	4	main
mõne	doc_101672866015_item	3141499	et	3	main
turureisidel	doc_101672866015_item	3141502	et	3	main
vene	doc_101672866015_item	3141511	et	4	main
tilgaks	doc_101672866015_item	3141512	et	3	main
loomulikult	doc_101672866015_item	3141517	et	4	main
erines	doc_101672866015_item	3141518	et	3	main
andis	doc_101672866015_item	3141525	et	3	main
masurka	doc_101672866015_item	3141535	et	4	main
polnud	doc_101672866015_item	3141536	et	3	main
välismaa	doc_101672866015_item	3141539	et	4	main
noortele	doc_101672866015_item	3141540	et	3	main
kodu	doc_101672866015_item	3141560	et	4	main
kus	doc_101672866015_item	3141561	et	3	main
valitses	doc_101672866015_item	3141562	et	3	main
oli	doc_101672866015_item	3141569	et	3	main
ja	doc_101672866015_item	3141571	et	3	main
kumna	doc_101672866015_item	3141573	et	4	main
ta	doc_101672866015_item	3141578	et	4	main
mäletatakse	doc_101672866015_item	3141584	et	3	main
tänapäeval	doc_101672866015_item	3141587	et	3	main
küla	doc_101672866015_item	3141590	et	4	main
mõis	doc_101672866015_item	3141602	et	3	main
peale	doc_101672866015_item	3141609	et	4	main
oli	doc_101672866015_item	3141611	et	3	main
parun	doc_101672866015_item	3141613	et	3	main
tuntuks	doc_101672866015_item	3141620	et	4	main
sajandil	doc_101672866015_item	3141622	et	3	main
de	doc_101672866015_item	3141628	et	4	main
aastatel	doc_101672866015_item	3141642	et	4	main
rannamõisa	doc_101672866015_item	3141643	et	3	main
läheduses	doc_101672866015_item	3141644	et	4	main
on	doc_101672866015_item	3141645	et	4	main
invaliididekodu	doc_101672866015_item	3141654	et	4	main
viimased	doc_101672866015_item	3141655	et	3	main
stiilis	doc_101672866015_item	3141691	et	4	main
alustati	doc_101672866015_item	3141694	et	4	main
aastal	doc_101672866015_item	3141696	et	3	main
1905	doc_101672866015_item	3141701	et	2	main
daniel	doc_101672866015_item	3141705	et	4	main
burchard	doc_101672866015_item	3141706	et	4	main
lemm	doc_101672866015_item	3141707	et	3	main
pühitses	doc_101672866015_item	3141708	et	3	main
seda	doc_101672866015_item	3141709	et	3	main
rannamõisa	doc_101672866015_item	3141710	et	3	main
arhitekt	doc_101672866015_item	3141712	et	3	main
ja	doc_101672866015_item	3141713	et	3	main
kandis	doc_101672866015_item	3141727	et	4	main
iseseisvakskoguduseks	doc_101672866015_item	3141735	et	4	main
esimene	doc_101672866015_item	3141736	et	3	main
mathias	doc_101672866015_item	3141751	et	4	main
ka	doc_101672866015_item	3141479	et	3	main
mõisas	doc_101672866015_item	3141482	et	3	main
atmosfäär	doc_101672866015_item	3141485	et	3	main
et	doc_101672866015_item	3141486	et	3	main
rohkem	doc_101672866015_item	3141489	et	4	main
kui	doc_101672866015_item	3141490	et	3	main
lõbustus	doc_101672866015_item	3141491	et	4	main
ja	doc_101672866015_item	3141492	et	3	main
mitte	doc_101672866015_item	3141493	et	3	main
külalised	doc_101672866015_item	3141496	et	4	main
selliseks	doc_101672866015_item	3141510	et	4	main
kindlasti	doc_101672866015_item	3141524	et	3	main
ime	doc_101672866015_item	3141537	et	4	main
vabastav	doc_101672866015_item	3141554	et	4	main
kõikidest	doc_101672866015_item	3141564	et	4	main
kütketest23	doc_101672866015_item	3141566	et	2	main
on	doc_101672866015_item	3141570	et	4	main
tuntud	doc_101672866015_item	3141580	et	4	main
oma	doc_101672866015_item	3141581	et	4	main
5	doc_101672866015_item	3141588	et	2	main
mainitakse	doc_101672866015_item	3141592	et	3	main
aednikust	doc_101672866015_item	3141500	et	3	main
abistamas	doc_101672866015_item	3141503	et	3	main
seega	doc_101672866015_item	3141505	et	4	main
kumnat	doc_101672866015_item	3141506	et	4	main
võib	doc_101672866015_item	3141507	et	3	main
julgesti	doc_101672866015_item	3141508	et	3	main
nimetada	doc_101672866015_item	3141509	et	3	main
harku	doc_101672866015_item	3141513	et	4	main
teistest	doc_101672866015_item	3141519	et	4	main
praeguse	doc_101672866015_item	3141520	et	3	main
ajaloosse	doc_101672866015_item	3141530	et	4	main
noored	doc_101672866015_item	3141531	et	3	main
kavalerid	doc_101672866015_item	3141532	et	4	main
balalaikamäng	doc_101672866015_item	3141533	et	3	main
ja	doc_101672866015_item	3141534	et	3	main
siin	doc_101672866015_item	3141541	et	4	main
meeldis	doc_101672866015_item	3141542	et	3	main
kumna	doc_101672866015_item	3141543	et	4	main
kohal	doc_101672866015_item	3141544	et	4	main
õhtuni	doc_101672866015_item	3141545	et	3	main
otsekui	doc_101672866015_item	3141546	et	3	main
kära	doc_101672866015_item	3141547	et	4	main
ja	doc_101672866015_item	3141548	et	3	main
kilkamise	doc_101672866015_item	3141549	et	4	main
pilv	doc_101672866015_item	3141550	et	3	main
imetabane	doc_101672866015_item	3141552	et	4	main
vabadus	doc_101672866015_item	3141563	et	4	main
imelise	doc_101672866015_item	3141576	et	4	main
ajal	doc_101672866015_item	3141582	et	4	main
rannamõisa	doc_101672866015_item	3141589	et	3	main
esmakordselt	doc_101672866015_item	3141593	et	4	main
aastal	doc_101672866015_item	3141595	et	3	main
1624	doc_101672866015_item	3141598	et	2	main
rannamõisa	doc_101672866015_item	3141601	et	3	main
srajas	doc_101672866015_item	3141629	et	4	main
tiskresse	doc_101672866015_item	3141630	et	4	main
panga	doc_101672866015_item	3141631	et	3	main
jalamile	doc_101672866015_item	3141632	et	4	main
asus	doc_101672866015_item	3141653	et	4	main
kiriku	doc_101672866015_item	3141692	et	3	main
aastani	doc_101672866015_item	3141599	et	3	main
see	doc_101672866015_item	3141610	et	3	main
vabahärrade	doc_101672866015_item	3141612	et	3	main
budbergide	doc_101672866015_item	3141614	et	4	main
eraomand	doc_101672866015_item	3141616	et	3	main
sai	doc_101672866015_item	3141618	et	4	main
tallinna	doc_101672866015_item	3141624	et	4	main
1950ndatel	doc_101672866015_item	3141641	et	4	main
suvilate	doc_101672866015_item	3141647	et	3	main
aastakümneid	doc_101672866015_item	3141650	et	4	main
lucca	doc_101672866015_item	3141651	et	4	main
mõisas	doc_101672866015_item	3141652	et	3	main
on	doc_101672866015_item	3141657	et	4	main
seal	doc_101672866015_item	3141658	et	4	main
pärast	doc_101672866015_item	3141659	et	4	main
olulisi	doc_101672866015_item	3141660	et	4	main
ümberehitusi	doc_101672866015_item	3141661	et	3	main
olnud	doc_101672866015_item	3141662	et	4	main
suurbritannia	doc_101672866015_item	3141663	et	4	main
suursaadiku	doc_101672866015_item	3141664	et	3	main
residents	doc_101672866015_item	3141665	et	3	main
seega	doc_101672866015_item	3141666	et	4	main
vanast	doc_101672866015_item	3141667	et	3	main
mõisast	doc_101672866015_item	3141668	et	4	main
pole	doc_101672866015_item	3141669	et	3	main
suurt	doc_101672866015_item	3141670	et	3	main
midagi	doc_101672866015_item	3141671	et	4	main
säilinud	doc_101672866015_item	3141672	et	4	main
rannamõisa	doc_101672866015_item	3141673	et	3	main
on	doc_101672866015_item	3141674	et	4	main
rohkem	doc_101672866015_item	3141675	et	4	main
tuntud	doc_101672866015_item	3141676	et	4	main
kui	doc_101672866015_item	3141677	et	3	main
suvilate	doc_101672866015_item	3141678	et	3	main
ja	doc_101672866015_item	3141679	et	3	main
puhkepaik	doc_101672866015_item	3141680	et	3	main
kuhu	doc_101672866015_item	3141681	et	3	main
sõideti	doc_101672866015_item	3141682	et	3	main
suviti	doc_101672866015_item	3141683	et	3	main
sageli	doc_101672866015_item	3141684	et	3	main
pidusid	doc_101672866015_item	3141685	et	4	main
kirik	doc_101672866015_item	3141689	et	3	main
ehitamist	doc_101672866015_item	3141693	et	4	main
1901	doc_101672866015_item	3141695	et	2	main
17	doc_101672866015_item	3141699	et	2	main
eestimaa	doc_101672866015_item	3141703	et	4	main
kiriku	doc_101672866015_item	3141711	et	3	main
altarimaali	doc_101672866015_item	3141714	et	4	main
taevaminek	doc_101672866015_item	3141715	et	3	main
autor	doc_101672866015_item	3141716	et	3	main
ja	doc_101672866015_item	3141726	et	3	main
kabeli	doc_101672866015_item	3141729	et	3	main
kiriku	doc_101672866015_item	3141737	et	3	main
ja	doc_101672866015_item	3141739	et	3	main
karl	doc_101672866015_item	3141742	et	4	main
selles	doc_101672866015_item	3141748	et	4	main
ametis	doc_101672866015_item	3141749	et	3	main
töötasid	doc_101672866015_item	3141750	et	4	main
t	doc_101672866015_item	3141755	et	4	main
oja	doc_101672866015_item	3141756	et	4	main
ning	doc_101672866015_item	3141757	et	3	main
1936	doc_101672866015_item	3141758	et	2	main
sai	doc_101672866015_item	3141762	et	4	main
isegi	doc_101672866015_item	3141803	et	4	main
nad	doc_101672866015_item	3141809	et	3	main
sellele	doc_101672866015_item	3141811	et	4	main
kõige	doc_101672866015_item	3141829	et	4	main
suurem	doc_101672866015_item	3141830	et	4	main
probleem	doc_101672866015_item	3141831	et	3	main
kogudusse	doc_101672866015_item	3141836	et	3	main
jumalateenistused	doc_101672866015_item	3141843	et	3	main
neid	doc_101672866015_item	3141855	et	4	main
üüritus	doc_101672866015_item	3141856	et	4	main
kirikus	doc_101672866015_item	3141857	et	3	main
muraste	doc_101672866015_item	3141862	et	4	main
moodustus	doc_101672866015_item	3141865	et	4	main
kuulus	doc_101672866015_item	3141879	et	4	main
see	doc_101672866015_item	3141880	et	3	main
grassile	doc_101672866015_item	3141883	et	4	main
ostis	doc_101672866015_item	3141894	et	4	main
selle	doc_101672866015_item	3141895	et	4	main
eestis	doc_101672866015_item	3141912	et	3	main
aga	doc_101672866015_item	3141913	et	3	main
lossiliku	doc_101672866015_item	3141914	et	4	main
ilmega	doc_101672866015_item	3141915	et	3	main
mõisahoonet	doc_101672866015_item	3141916	et	4	main
kasutas	doc_101672866015_item	3141917	et	3	main
sai	doc_101672866015_item	3141924	et	4	main
aastal	doc_101672866015_item	3141926	et	3	main
muraste	doc_101672866015_item	3141927	et	4	main
lastekodu	doc_101672866015_item	3141932	et	4	main
elasid	doc_101672866015_item	3141936	et	4	main
tõttu	doc_101672866015_item	3141939	et	4	main
paldiski	doc_101672866015_item	3141957	et	4	main
ekslinnapeale	doc_101672866015_item	3141958	et	3	main
veebruaris	doc_101672866015_item	3141963	et	3	main
panid	doc_101672866015_item	3141964	et	4	main
kohalikku	doc_101672866015_item	3141966	et	4	main
krusten	doc_101672866015_item	3141997	et	4	main
1897-1987	doc_101672866015_item	3142008	et	2	main
olid	doc_101672866015_item	3142009	et	4	main
isa	doc_101672866015_item	3142016	et	4	main
ja	doc_101672866015_item	3142023	et	3	main
korrashoidmine	doc_101672866015_item	3142025	et	3	main
triiphoone	doc_101672866015_item	3142027	et	4	main
päris	doc_101672866015_item	3142034	et	4	main
lapsepõlve	doc_101672866015_item	3142040	et	4	main
ka	doc_101672866015_item	3142047	et	3	main
peterburis	doc_101672866015_item	3142082	et	4	main
gulbranssoni	doc_101672866015_item	3142096	et	4	main
isikupärase	doc_101672866015_item	3142099	et	4	main
sellel	doc_101672866015_item	3142114	et	4	main
alal	doc_101672866015_item	3142115	et	4	main
veebruaril	doc_101672866015_item	3142126	et	3	main
oma	doc_101672866015_item	3142134	et	4	main
rõõmsad	doc_101672866015_item	3142144	et	3	main
minu	doc_101672866015_item	3142145	et	3	main
vaesed	doc_101672866015_item	3142146	et	4	main
tööde	doc_101672866015_item	3142156	et	3	main
kodusõjas	doc_101672866015_item	3142198	et	3	main
töötas	doc_101672866015_item	3142203	et	3	main
ajakirjanikuna	doc_101672866015_item	3142205	et	3	main
juba	doc_101672866015_item	3141698	et	3	main
kindralsuperintendent	doc_101672866015_item	3141704	et	3	main
kogu	doc_101672866015_item	3141719	et	4	main
1937	doc_101672866015_item	3141720	et	2	main
aastani	doc_101672866015_item	3141721	et	3	main
allus	doc_101672866015_item	3141722	et	3	main
kirik	doc_101672866015_item	3141723	et	3	main
nime	doc_101672866015_item	3141730	et	4	main
kuus	doc_101672866015_item	3141732	et	4	main
jutustaja	doc_101672866015_item	3141740	et	4	main
kuni	doc_101672866015_item	3141744	et	3	main
aasta	doc_101672866015_item	3141759	et	4	main
oskar	doc_101672866015_item	3141763	et	4	main
puhm	doc_101672866015_item	3141764	et	3	main
kes	doc_101672866015_item	3141765	et	4	main
lahkus	doc_101672866015_item	3141766	et	4	main
eestist	doc_101672866015_item	3141767	et	3	main
1944	doc_101672866015_item	3141768	et	2	main
aastal	doc_101672866015_item	3141769	et	3	main
kanadasse	doc_101672866015_item	3141770	et	4	main
kus	doc_101672866015_item	3141771	et	3	main
ta	doc_101672866015_item	3141772	et	4	main
hiljem	doc_101672866015_item	3141773	et	3	main
töötas	doc_101672866015_item	3141774	et	3	main
pikki	doc_101672866015_item	3141775	et	4	main
aastaid	doc_101672866015_item	3141776	et	4	main
kanada	doc_101672866015_item	3141777	et	4	main
luterlikku	doc_101672866015_item	3141778	et	4	main
elu26	doc_101672866015_item	3141780	et	2	main
ajakirja	doc_101672866015_item	3141779	et	4	main
rannamõisa	doc_101672866015_item	3141781	et	3	main
kalmistu	doc_101672866015_item	3141782	et	4	main
õnnistati	doc_101672866015_item	3141783	et	4	main
21	doc_101672866015_item	3141784	et	2	main
juulil	doc_101672866015_item	3141785	et	3	main
1902	doc_101672866015_item	3141786	et	2	main
aastal	doc_101672866015_item	3141787	et	3	main
seal	doc_101672866015_item	3141788	et	4	main
leidub	doc_101672866015_item	3141789	et	3	main
selliseid	doc_101672866015_item	3141790	et	4	main
kunsti-	doc_101672866015_item	3141791	et	4	main
ja	doc_101672866015_item	3141792	et	3	main
kultuurivara	doc_101672866015_item	3141793	et	4	main
nagu	doc_101672866015_item	3141794	et	3	main
vanu	doc_101672866015_item	3141795	et	4	main
irdriste	doc_101672866015_item	3141796	et	4	main
sepa-	doc_101672866015_item	3141799	et	3	main
raidkivitööd	doc_101672866015_item	3141801	et	4	main
hauatähiseid	doc_101672866015_item	3141798	et	4	main
kuna	doc_101672866015_item	3141808	et	3	main
kuna	doc_101672866015_item	3141821	et	3	main
vabu	doc_101672866015_item	3141822	et	3	main
hauplaste	doc_101672866015_item	3141823	et	4	main
kalmistul	doc_101672866015_item	3141824	et	3	main
enam	doc_101672866015_item	3141825	et	4	main
mida	doc_101672866015_item	3141802	et	4	main
kasutusele	doc_101672866015_item	3141806	et	4	main
kultuuriloost	doc_101672866015_item	3141820	et	4	main
pole	doc_101672866015_item	3141826	et	3	main
kalmistu	doc_101672866015_item	3141832	et	4	main
laiendamine	doc_101672866015_item	3141833	et	4	main
umbes	doc_101672866015_item	3141838	et	4	main
pühapäeviti	doc_101672866015_item	3141841	et	4	main
toimuvad	doc_101672866015_item	3141842	et	4	main
on	doc_101672866015_item	3141846	et	4	main
ja	doc_101672866015_item	3141848	et	3	main
palvetunnid	doc_101672866015_item	3141849	et	3	main
ka	doc_101672866015_item	3141852	et	3	main
pühapäevakool	doc_101672866015_item	3141853	et	4	main
peale	doc_101672866015_item	3141854	et	4	main
6	doc_101672866015_item	3141861	et	2	main
rajati	doc_101672866015_item	3141871	et	3	main
saj	doc_101672866015_item	3141873	et	4	main
i	doc_101672866015_item	3141874	et	4	main
panditi	doc_101672866015_item	3141889	et	4	main
mõisa	doc_101672866015_item	3141890	et	3	main
sellest	doc_101672866015_item	3141902	et	4	main
stiilis	doc_101672866015_item	3141910	et	4	main
suvel	doc_101672866015_item	3141920	et	3	main
punaste	doc_101672866015_item	3141929	et	4	main
härrastemaja	doc_101672866015_item	3141950	et	4	main
mölderile	doc_101672866015_item	3141960	et	3	main
inimest	doc_101672866015_item	3141840	et	3	main
muraste	doc_101672866015_item	3141863	et	4	main
seda	doc_101672866015_item	3141870	et	3	main
17	doc_101672866015_item	3141872	et	2	main
aastast	doc_101672866015_item	3141878	et	4	main
von	doc_101672866015_item	3141882	et	4	main
sajandite	doc_101672866015_item	3141884	et	3	main
jooksul	doc_101672866015_item	3141885	et	4	main
korduvalt	doc_101672866015_item	3141891	et	4	main
1848	doc_101672866015_item	3141892	et	2	main
aastal	doc_101672866015_item	3141893	et	3	main
von	doc_101672866015_item	3141897	et	4	main
kes	doc_101672866015_item	3141899	et	4	main
suurejoonelise	doc_101672866015_item	3141903	et	4	main
mõisahäärberi	doc_101672866015_item	3141904	et	3	main
mida	doc_101672866015_item	3141905	et	4	main
peetakse	doc_101672866015_item	3141906	et	3	main
üheks	doc_101672866015_item	3141907	et	3	main
varasemaks	doc_101672866015_item	3141908	et	4	main
neorenessanss-	doc_101672866015_item	3141909	et	3	main
põhiliselt	doc_101672866015_item	3141919	et	4	main
pärast	doc_101672866015_item	3141933	et	4	main
teist	doc_101672866015_item	3141934	et	4	main
siin	doc_101672866015_item	3141937	et	4	main
jäänud	doc_101672866015_item	3141941	et	4	main
lapsed	doc_101672866015_item	3141942	et	3	main
valdaja	doc_101672866015_item	3141951	et	4	main
punane	doc_101672866015_item	3141953	et	4	main
jaan	doc_101672866015_item	3141959	et	3	main
päris	doc_101672866015_item	3142012	et	4	main
kirjanikud	doc_101672866015_item	3142014	et	3	main
krusteni	doc_101672866015_item	3142018	et	4	main
ülesandeks	doc_101672866015_item	3142019	et	4	main
oli	doc_101672866015_item	3142020	et	3	main
mõisa	doc_101672866015_item	3142021	et	3	main
last	doc_101672866015_item	3142032	et	4	main
muraste	doc_101672866015_item	3142037	et	4	main
mõisas	doc_101672866015_item	3142038	et	3	main
ning	doc_101672866015_item	3142039	et	3	main
peegelduvad	doc_101672866015_item	3142043	et	4	main
erni	doc_101672866015_item	3142045	et	4	main
pedro	doc_101672866015_item	3142048	et	4	main
krusteni	doc_101672866015_item	3142049	et	4	main
pärast	doc_101672866015_item	3142081	et	4	main
ösituled	doc_101672866015_item	3142093	et	4	main
lähtus	doc_101672866015_item	3142094	et	3	main
kujundas	doc_101672866015_item	3142098	et	3	main
stiilse	doc_101672866015_item	3142100	et	3	main
lakoonilise	doc_101672866015_item	3142102	et	3	main
tabavalt	doc_101672866015_item	3142105	et	4	main
iseloomustavaid	doc_101672866015_item	3142106	et	4	main
humoristlikke	doc_101672866015_item	3142107	et	3	main
śarźe	doc_101672866015_item	3142108	et	2	main
teda	doc_101672866015_item	3142116	et	4	main
peetakse	doc_101672866015_item	3142117	et	3	main
maale	doc_101672866015_item	3142123	et	4	main
tallinnas29	doc_101672866015_item	3142129	et	2	main
sai	doc_101672866015_item	3142131	et	4	main
tuntuks	doc_101672866015_item	3142132	et	4	main
eeskätt	doc_101672866015_item	3142133	et	3	main
loominguga	doc_101672866015_item	3142136	et	3	main
täna	doc_101672866015_item	3142147	et	4	main
seedin	doc_101672866015_item	3142148	et	3	main
krusteni	doc_101672866015_item	3142154	et	4	main
maa	doc_101672866015_item	3142208	et	4	main
päevaleht	doc_101672866015_item	3142209	et	3	main
lahkus	doc_101672866015_item	3142216	et	4	main
saksamaale	doc_101672866015_item	3142220	et	4	main
asus	doc_101672866015_item	3142222	et	4	main
usa-sse	doc_101672866015_item	3142223	et	3	main
kus	doc_101672866015_item	3142224	et	3	main
1950a	doc_101672866015_item	3142225	et	4	main
staatus	doc_101672866015_item	3142230	et	3	main
ning	doc_101672866015_item	3142236	et	3	main
ameerika	doc_101672866015_item	3142238	et	3	main
pedro	doc_101672866015_item	3142242	et	4	main
kes	doc_101672866015_item	3142247	et	4	main
tugev	doc_101672866015_item	3142263	et	4	main
ja	doc_101672866015_item	3142264	et	3	main
inimese	doc_101672866015_item	3142267	et	4	main
loomusest	doc_101672866015_item	3142274	et	4	main
näiteks	doc_101672866015_item	3141860	et	4	main
mõis27	doc_101672866015_item	3141864	et	2	main
muraste	doc_101672866015_item	3141866	et	4	main
kurba	doc_101672866015_item	3141867	et	4	main
merekülast	doc_101672866015_item	3141869	et	4	main
renditi	doc_101672866015_item	3141887	et	3	main
ja	doc_101672866015_item	3141888	et	3	main
otto	doc_101672866015_item	3141896	et	4	main
krusenstiern	doc_101672866015_item	3141898	et	4	main
pärast	doc_101672866015_item	3141900	et	4	main
ehitas	doc_101672866015_item	3141901	et	3	main
pärast	doc_101672866015_item	3141921	et	4	main
mõisate	doc_101672866015_item	3141922	et	3	main
1920	doc_101672866015_item	3141925	et	2	main
risti	doc_101672866015_item	3141930	et	4	main
suurupi	doc_101672866015_item	3141931	et	4	main
sõja	doc_101672866015_item	3141938	et	3	main
orbudeks	doc_101672866015_item	3141940	et	3	main
1995	doc_101672866015_item	3141943	et	2	main
aastal	doc_101672866015_item	3141944	et	3	main
lastekodu	doc_101672866015_item	3141945	et	4	main
likvideeriti	doc_101672866015_item	3141946	et	3	main
ja	doc_101672866015_item	3141947	et	3	main
1997	doc_101672866015_item	3141948	et	2	main
aastal	doc_101672866015_item	3141949	et	3	main
eesti	doc_101672866015_item	3141952	et	4	main
rist	doc_101672866015_item	3141954	et	3	main
müüs	doc_101672866015_item	3141955	et	4	main
2001	doc_101672866015_item	3141961	et	2	main
poissi	doc_101672866015_item	3141969	et	4	main
mõisamaja	doc_101672866015_item	3141970	et	4	main
põlema	doc_101672866015_item	3141971	et	4	main
alles	doc_101672866015_item	3141972	et	3	main
jäi	doc_101672866015_item	3141973	et	3	main
vahelagedeta	doc_101672866015_item	3141974	et	3	main
vare28	doc_101672866015_item	3141975	et	2	main
muraste	doc_101672866015_item	3141976	et	4	main
mõisas	doc_101672866015_item	3141977	et	3	main
üles	doc_101672866015_item	3141978	et	3	main
kasvasid	doc_101672866015_item	3141979	et	4	main
kolm	doc_101672866015_item	3141980	et	3	main
kultuurimaailmas	doc_101672866015_item	3141981	et	3	main
tuntud	doc_101672866015_item	3141982	et	4	main
isikud	doc_101672866015_item	3141983	et	3	main
nad	doc_101672866015_item	3141984	et	3	main
on	doc_101672866015_item	3141985	et	4	main
vennad	doc_101672866015_item	3141986	et	3	main
krustenid	doc_101672866015_item	3141987	et	4	main
nad	doc_101672866015_item	3141988	et	3	main
sündisid	doc_101672866015_item	3141989	et	4	main
aedniku	doc_101672866015_item	3141990	et	3	main
jaan	doc_101672866015_item	3141991	et	3	main
krusteni	doc_101672866015_item	3141992	et	4	main
perekonnas	doc_101672866015_item	3141993	et	4	main
kõige	doc_101672866015_item	3141994	et	4	main
vanem	doc_101672866015_item	3141995	et	4	main
otto	doc_101672866015_item	3141996	et	4	main
nooremad	doc_101672866015_item	3142003	et	4	main
erni	doc_101672866015_item	3142004	et	4	main
1900-1984	doc_101672866015_item	3142005	et	2	main
ja	doc_101672866015_item	3142006	et	3	main
ajal	doc_101672866015_item	3142011	et	4	main
võõrandamist	doc_101672866015_item	3141923	et	4	main
mõisahoonest	doc_101672866015_item	3141928	et	4	main
maailmasõda	doc_101672866015_item	3141935	et	4	main
hoone	doc_101672866015_item	3141956	et	4	main
aastal	doc_101672866015_item	3141962	et	3	main
kaks	doc_101672866015_item	3141965	et	3	main
13-	doc_101672866015_item	3141967	et	4	main
aastast	doc_101672866015_item	3141968	et	4	main
1988-1937	doc_101672866015_item	3141998	et	2	main
pedro	doc_101672866015_item	3142007	et	4	main
tuntud	doc_101672866015_item	3142013	et	4	main
pargi	doc_101672866015_item	3142022	et	4	main
elasid	doc_101672866015_item	3142033	et	4	main
tihti	doc_101672866015_item	3142042	et	3	main
ateljeekoolis	doc_101672866015_item	3142079	et	4	main
ja	doc_101672866015_item	3142080	et	3	main
seltsi	doc_101672866015_item	3142085	et	4	main
o	doc_101672866015_item	3142095	et	4	main
eesti	doc_101672866015_item	3142109	et	4	main
parimaks	doc_101672866015_item	3142118	et	4	main
eestis	doc_101672866015_item	3142119	et	3	main
suri	doc_101672866015_item	3142124	et	3	main
ma	doc_101672866015_item	3142149	et	3	main
hulka	doc_101672866015_item	3142157	et	4	main
venemaa	doc_101672866015_item	3142197	et	4	main
aastate	doc_101672866015_item	3142200	et	3	main
alates	doc_101672866015_item	3142202	et	3	main
tallinnas	doc_101672866015_item	3142204	et	4	main
kuid	doc_101672866015_item	3142212	et	4	main
poliitiliste	doc_101672866015_item	3142213	et	3	main
sündmuste	doc_101672866015_item	3142214	et	3	main
tõttu	doc_101672866015_item	3142215	et	4	main
lõppes	doc_101672866015_item	3142226	et	4	main
washington	doc_101672866015_item	3142235	et	4	main
hääl	doc_101672866015_item	3142239	et	3	main
salgamata	doc_101672866015_item	3142265	et	4	main
krusten	doc_101672866015_item	3142300	et	4	main
tema	doc_101672866015_item	3142309	et	4	main
tunnustanud	doc_101672866015_item	3142317	et	4	main
ning	doc_101672866015_item	3142318	et	3	main
lugejad	doc_101672866015_item	3142319	et	4	main
vaatlusobjektiks	doc_101672866015_item	3142325	et	3	main
on	doc_101672866015_item	3142326	et	4	main
olnud	doc_101672866015_item	3142327	et	4	main
kui	doc_101672866015_item	3142329	et	3	main
nähtused	doc_101672866015_item	3142336	et	4	main
ei	doc_101672866015_item	3142346	et	4	main
alateadvuse	doc_101672866015_item	3142350	et	4	main
eriti	doc_101672866015_item	3142355	et	3	main
sai	doc_101672866015_item	3141999	et	4	main
kuulsaks	doc_101672866015_item	3142000	et	4	main
karikaturistiks	doc_101672866015_item	3142001	et	4	main
ning	doc_101672866015_item	3142002	et	3	main
omal	doc_101672866015_item	3142010	et	3	main
kuus	doc_101672866015_item	3142031	et	4	main
elu	doc_101672866015_item	3142036	et	4	main
piltid	doc_101672866015_item	3142041	et	4	main
nii	doc_101672866015_item	3142044	et	3	main
kui	doc_101672866015_item	3142046	et	3	main
näiteks	doc_101672866015_item	3142051	et	4	main
pedro	doc_101672866015_item	3142052	et	4	main
krusten	doc_101672866015_item	3142053	et	4	main
kirjeldab	doc_101672866015_item	3142054	et	3	main
mõisaolustikku	doc_101672866015_item	3142055	et	4	main
autobiograafilises	doc_101672866015_item	3142056	et	4	main
triloogias	doc_101672866015_item	3142057	et	3	main
peamiselt	doc_101672866015_item	3142058	et	4	main
selle	doc_101672866015_item	3142059	et	4	main
esimeses	doc_101672866015_item	3142060	et	3	main
osas	doc_101672866015_item	3142061	et	4	main
torn	doc_101672866015_item	3142062	et	3	main
üle	doc_101672866015_item	3142063	et	3	main
metsa	doc_101672866015_item	3142064	et	4	main
61	doc_101672866015_item	3142065	et	2	main
otto	doc_101672866015_item	3142066	et	4	main
krusten	doc_101672866015_item	3142067	et	4	main
otto	doc_101672866015_item	3142068	et	4	main
krusten	doc_101672866015_item	3142069	et	4	main
ehk	doc_101672866015_item	3142070	et	3	main
raudnõges	doc_101672866015_item	3142071	et	3	main
sündis	doc_101672866015_item	3142072	et	3	main
18	doc_101672866015_item	3142073	et	2	main
juunil	doc_101672866015_item	3142074	et	3	main
1888	doc_101672866015_item	3142075	et	2	main
nende	doc_101672866015_item	3142015	et	4	main
jaan	doc_101672866015_item	3142017	et	3	main
lillepeenarde	doc_101672866015_item	3142024	et	3	main
ja	doc_101672866015_item	3142026	et	3	main
hooldamine	doc_101672866015_item	3142028	et	4	main
perekonnas	doc_101672866015_item	3142029	et	4	main
oli	doc_101672866015_item	3142030	et	3	main
vaeselt	doc_101672866015_item	3142035	et	4	main
teostes	doc_101672866015_item	3142050	et	3	main
a	doc_101672866015_item	3142076	et	4	main
õppis	doc_101672866015_item	3142077	et	3	main
laikmaa	doc_101672866015_item	3142078	et	4	main
kunstikoolis	doc_101672866015_item	3142086	et	4	main
karikatuure	doc_101672866015_item	3142088	et	4	main
kunstide	doc_101672866015_item	3142083	et	3	main
edendamise	doc_101672866015_item	3142084	et	4	main
joonistas	doc_101672866015_item	3142087	et	3	main
ajalehtedele	doc_101672866015_item	3142089	et	4	main
satiirkirjadele	doc_101672866015_item	3142090	et	4	main
ja	doc_101672866015_item	3142091	et	3	main
albumile	doc_101672866015_item	3142092	et	3	main
eeskujust	doc_101672866015_item	3142097	et	3	main
ja	doc_101672866015_item	3142101	et	3	main
joonekäsitluse	doc_101672866015_item	3142103	et	3	main
tegi	doc_101672866015_item	3142104	et	4	main
kultuuri-	doc_101672866015_item	3142110	et	4	main
ja	doc_101672866015_item	3142111	et	3	main
ühiskonnategelastes	doc_101672866015_item	3142112	et	3	main
on	doc_101672866015_item	3142120	et	4	main
loonud	doc_101672866015_item	3142121	et	4	main
ka	doc_101672866015_item	3142122	et	3	main
1937	doc_101672866015_item	3142127	et	2	main
karikaturis	doc_101672866015_item	3142130	et	4	main
üks	doc_101672866015_item	3142137	et	3	main
karikatuure	doc_101672866015_item	3142139	et	4	main
on	doc_101672866015_item	3142140	et	4	main
töö	doc_101672866015_item	3142141	et	4	main
nimega	doc_101672866015_item	3142142	et	3	main
olge	doc_101672866015_item	3142143	et	3	main
otto	doc_101672866015_item	3142153	et	4	main
pilti	doc_101672866015_item	3142158	et	4	main
ajendasid	doc_101672866015_item	3142159	et	4	main
kahekümnendate	doc_101672866015_item	3142161	et	4	main
aastate	doc_101672866015_item	3142162	et	3	main
algul	doc_101672866015_item	3142163	et	4	main
keskpaigast	doc_101672866015_item	3142201	et	4	main
kodumaalt	doc_101672866015_item	3142217	et	3	main
pärast	doc_101672866015_item	3142221	et	4	main
enamasti	doc_101672866015_item	3142248	et	4	main
kirjutas	doc_101672866015_item	3142249	et	3	main
lühiproosat	doc_101672866015_item	3142250	et	3	main
kelle	doc_101672866015_item	3142259	et	4	main
sügavalt	doc_101672866015_item	3142272	et	4	main
tolerants	doc_101672866015_item	3142278	et	3	main
eriti	doc_101672866015_item	3142282	et	3	main
p	doc_101672866015_item	3142299	et	4	main
kodumaal	doc_101672866015_item	3142302	et	4	main
tuntud	doc_101672866015_item	3142303	et	4	main
ajakirjanik	doc_101672866015_item	3142304	et	3	main
kui	doc_101672866015_item	3142305	et	3	main
elas	doc_101672866015_item	3142306	et	3	main
kriitika	doc_101672866015_item	3142314	et	4	main
oli	doc_101672866015_item	3142315	et	3	main
pannud	doc_101672866015_item	3142322	et	4	main
inimene	doc_101672866015_item	3142328	et	3	main
niisugune	doc_101672866015_item	3142330	et	3	main
meie	doc_101672866015_item	3142337	et	4	main
varema	doc_101672866015_item	3142339	et	3	main
võib	doc_101672866015_item	3142341	et	3	main
psühholoogiliseks	doc_101672866015_item	3142343	et	4	main
mille	doc_101672866015_item	3142344	et	3	main
huvi	doc_101672866015_item	3142345	et	4	main
kusagile	doc_101672866015_item	3142349	et	3	main
väid	doc_101672866015_item	3142352	et	4	main
kus	doc_101672866015_item	3142354	et	3	main
ekslemist	doc_101672866015_item	3142407	et	4	main
sellesse	doc_101672866015_item	3142408	et	4	main
gruppi	doc_101672866015_item	3142409	et	4	main
ning	doc_101672866015_item	3142423	et	3	main
käega	doc_101672866015_item	3142426	et	3	main
hädaohtlik	doc_101672866015_item	3142428	et	3	main
eriti	doc_101672866015_item	3142442	et	3	main
on	doc_101672866015_item	3142446	et	4	main
samuti	doc_101672866015_item	3142447	et	3	main
vähe	doc_101672866015_item	3142448	et	3	main
nende	doc_101672866015_item	3142449	et	4	main
laev	doc_101672866015_item	3142454	et	3	main
akna	doc_101672866015_item	3142455	et	3	main
taga	doc_101672866015_item	3142456	et	4	main
ning	doc_101672866015_item	3142457	et	3	main
a	doc_101672866015_item	3142465	et	4	main
on	doc_101672866015_item	3142473	et	4	main
ta	doc_101672866015_item	3142481	et	4	main
krusteni	doc_101672866015_item	3142484	et	4	main
kadunud	doc_101672866015_item	3142490	et	4	main
ning	doc_101672866015_item	3142113	et	3	main
23	doc_101672866015_item	3142125	et	2	main
a	doc_101672866015_item	3142128	et	4	main
ühiskonnakriitilise	doc_101672866015_item	3142135	et	3	main
kuulsamaid	doc_101672866015_item	3142138	et	4	main
teile	doc_101672866015_item	3142150	et	4	main
mis	doc_101672866015_item	3142151	et	4	main
kuulub	doc_101672866015_item	3142152	et	3	main
sarkastilisemate	doc_101672866015_item	3142155	et	4	main
looma	doc_101672866015_item	3142160	et	4	main
moodi	doc_101672866015_item	3142164	et	4	main
läinud	doc_101672866015_item	3142165	et	4	main
ballid	doc_101672866015_item	3142166	et	3	main
tuluüritused	doc_101672866015_item	3142167	et	3	main
mida	doc_101672866015_item	3142168	et	4	main
korraldati	doc_101672866015_item	3142169	et	3	main
vaeste	doc_101672866015_item	3142170	et	4	main
heaks	doc_101672866015_item	3142171	et	4	main
62	doc_101672866015_item	3142172	et	2	main
pedro	doc_101672866015_item	3142173	et	4	main
krusten	doc_101672866015_item	3142174	et	4	main
kirjanik	doc_101672866015_item	3142175	et	3	main
pedro	doc_101672866015_item	3142176	et	4	main
krusten	doc_101672866015_item	3142177	et	4	main
sündis	doc_101672866015_item	3142178	et	3	main
ja	doc_101672866015_item	3142179	et	3	main
üles	doc_101672866015_item	3142180	et	3	main
kasvas	doc_101672866015_item	3142181	et	3	main
põhjarannikul	doc_101672866015_item	3142182	et	3	main
murastes	doc_101672866015_item	3142183	et	4	main
mõisa	doc_101672866015_item	3142184	et	3	main
aedniku	doc_101672866015_item	3142185	et	3	main
pojana	doc_101672866015_item	3142186	et	4	main
ta	doc_101672866015_item	3142187	et	4	main
õpis	doc_101672866015_item	3142188	et	3	main
tallinna	doc_101672866015_item	3142189	et	4	main
progümnaasiumis	doc_101672866015_item	3142190	et	4	main
pärast	doc_101672866015_item	3142191	et	4	main
selle	doc_101672866015_item	3142192	et	4	main
lõpetamist	doc_101672866015_item	3142193	et	4	main
võttis	doc_101672866015_item	3142194	et	3	main
punaarmees	doc_101672866015_item	3142195	et	3	main
osa	doc_101672866015_item	3142196	et	4	main
1920	doc_101672866015_item	3142199	et	2	main
eesti	doc_101672866015_item	3142210	et	4	main
sõna	doc_101672866015_item	3142211	et	4	main
1944	doc_101672866015_item	3142218	et	2	main
ametlikult	doc_101672866015_item	3142227	et	4	main
seal	doc_101672866015_item	3142234	et	4	main
toimetus	doc_101672866015_item	3142241	et	4	main
ajakirjade	doc_101672866015_item	3142251	et	3	main
jaoks	doc_101672866015_item	3142252	et	4	main
aga	doc_101672866015_item	3142253	et	3	main
leidub	doc_101672866015_item	3142254	et	3	main
loomingus	doc_101672866015_item	3142256	et	3	main
romaane	doc_101672866015_item	3142258	et	3	main
teostes	doc_101672866015_item	3142260	et	3	main
hakkab	doc_101672866015_item	3142261	et	3	main
silma	doc_101672866015_item	3142262	et	4	main
isikupära	doc_101672866015_item	3142266	et	4	main
ja	doc_101672866015_item	3142268	et	3	main
kirjaniku	doc_101672866015_item	3142269	et	3	main
tihe	doc_101672866015_item	3142270	et	3	main
seotus	doc_101672866015_item	3142271	et	4	main
lähtuv	doc_101672866015_item	3142275	et	4	main
humanism	doc_101672866015_item	3142276	et	3	main
teda	doc_101672866015_item	3142279	et	4	main
ajalugu	doc_101672866015_item	3142283	et	4	main
see	doc_101672866015_item	3142284	et	3	main
on	doc_101672866015_item	3142285	et	4	main
ainult	doc_101672866015_item	3142286	et	4	main
foon	doc_101672866015_item	3142287	et	3	main
esiplaanis	doc_101672866015_item	3142288	et	3	main
aga	doc_101672866015_item	3142289	et	3	main
seisab	doc_101672866015_item	3142290	et	3	main
inimene	doc_101672866015_item	3142291	et	3	main
ning	doc_101672866015_item	3142292	et	3	main
selle	doc_101672866015_item	3142293	et	4	main
isiku	doc_101672866015_item	3142294	et	3	main
moraalne	doc_101672866015_item	3142295	et	3	main
toimetulek	doc_101672866015_item	3142296	et	3	main
ja	doc_101672866015_item	3142297	et	3	main
pedro	doc_101672866015_item	3142323	et	4	main
kodumaa	doc_101672866015_item	3142331	et	4	main
ja	doc_101672866015_item	3142332	et	3	main
rahvas	doc_101672866015_item	3142333	et	4	main
teatava	doc_101672866015_item	3142334	et	4	main
ajastu	doc_101672866015_item	3142335	et	4	main
selles	doc_101672866015_item	3142401	et	4	main
kokkusattumusi	doc_101672866015_item	3142404	et	3	main
juhust	doc_101672866015_item	3142405	et	4	main
ja	doc_101672866015_item	3142406	et	3	main
vale	doc_101672866015_item	3142413	et	4	main
1930	doc_101672866015_item	3142414	et	2	main
pime	doc_101672866015_item	3142415	et	3	main
1938	doc_101672866015_item	3142422	et	2	main
ole	doc_101672866015_item	3142435	et	4	main
nii	doc_101672866015_item	3142436	et	3	main
tuntud	doc_101672866015_item	3142437	et	4	main
hulka	doc_101672866015_item	3142450	et	4	main
aedniku	doc_101672866015_item	3142458	et	3	main
pärast	doc_101672866015_item	3142463	et	4	main
krusteni	doc_101672866015_item	3142466	et	4	main
loominguga	doc_101672866015_item	3142467	et	3	main
tegeleb	doc_101672866015_item	3142468	et	3	main
peamiselt	doc_101672866015_item	3142469	et	4	main
olnudki	doc_101672866015_item	3142474	et	4	main
ka	doc_101672866015_item	3142475	et	3	main
kordustrükkide	doc_101672866015_item	3142476	et	3	main
järelsõnade	doc_101672866015_item	3142477	et	3	main
kirjanikuks	doc_101672866015_item	3142487	et	3	main
ajakirjades	doc_101672866015_item	3142206	et	3	main
vaba	doc_101672866015_item	3142207	et	4	main
aastal	doc_101672866015_item	3142219	et	3	main
tema	doc_101672866015_item	3142228	et	4	main
põgeniku	doc_101672866015_item	3142229	et	3	main
püsivaks	doc_101672866015_item	3142231	et	4	main
elukohaks	doc_101672866015_item	3142232	et	4	main
sai	doc_101672866015_item	3142233	et	4	main
tööpaigaks	doc_101672866015_item	3142237	et	3	main
raadiojaama	doc_101672866015_item	3142240	et	4	main
krusten	doc_101672866015_item	3142243	et	4	main
on	doc_101672866015_item	3142244	et	4	main
eluaegne	doc_101672866015_item	3142245	et	3	main
ajakirjanik	doc_101672866015_item	3142246	et	3	main
tema	doc_101672866015_item	3142255	et	4	main
ka	doc_101672866015_item	3142257	et	3	main
kirjutaja	doc_101672866015_item	3142273	et	4	main
huvita	doc_101672866015_item	3142281	et	4	main
ja	doc_101672866015_item	3142277	et	3	main
ei	doc_101672866015_item	3142280	et	4	main
enesesäilitamine	doc_101672866015_item	3142298	et	3	main
oli	doc_101672866015_item	3142301	et	3	main
lugejad	doc_101672866015_item	3142310	et	4	main
olid	doc_101672866015_item	3142311	et	4	main
maailmas	doc_101672866015_item	3142312	et	3	main
laiali	doc_101672866015_item	3142313	et	3	main
teda	doc_101672866015_item	3142320	et	4	main
tähele	doc_101672866015_item	3142321	et	3	main
inimeses	doc_101672866015_item	3142338	et	3	main
loolaadi	doc_101672866015_item	3142340	et	4	main
suundu	doc_101672866015_item	3142347	et	4	main
maailma	doc_101672866015_item	3142351	et	4	main
sinna	doc_101672866015_item	3142353	et	3	main
kerkivad	doc_101672866015_item	3142356	et	4	main
üles	doc_101672866015_item	3142357	et	3	main
tõe	doc_101672866015_item	3142358	et	4	main
ja	doc_101672866015_item	3142359	et	3	main
moraalne	doc_101672866015_item	3142397	et	3	main
voorus	doc_101672866015_item	3142416	et	4	main
ja	doc_101672866015_item	3142417	et	3	main
kalle	doc_101672866015_item	3142418	et	3	main
jaanuse	doc_101672866015_item	3142419	et	4	main
kättemaks	doc_101672866015_item	3142420	et	4	main
ei	doc_101672866015_item	3142434	et	4	main
temast	doc_101672866015_item	3142441	et	3	main
kuuluvad	doc_101672866015_item	3142451	et	4	main
ilmusid	doc_101672866015_item	3142461	et	4	main
kordustrükina	doc_101672866015_item	3142462	et	3	main
tonts	doc_101672866015_item	3142471	et	4	main
p	doc_101672866015_item	3142483	et	4	main
lendab	doc_101672866015_item	3142495	et	3	main
uued	doc_101672866015_item	3142497	et	3	main
washingtonis	doc_101672866015_item	3142307	et	4	main
siis	doc_101672866015_item	3142308	et	3	main
teda	doc_101672866015_item	3142316	et	4	main
krusteni	doc_101672866015_item	3142324	et	4	main
nimetada	doc_101672866015_item	3142342	et	3	main
niivõrd	doc_101672866015_item	3142348	et	3	main
vale	doc_101672866015_item	3142360	et	4	main
süü	doc_101672866015_item	3142361	et	4	main
ja	doc_101672866015_item	3142362	et	3	main
patu	doc_101672866015_item	3142363	et	3	main
puhtuse	doc_101672866015_item	3142364	et	4	main
ja	doc_101672866015_item	3142365	et	3	main
lunastuse	doc_101672866015_item	3142366	et	4	main
probleemid	doc_101672866015_item	3142367	et	3	main
oma	doc_101672866015_item	3142368	et	4	main
loomingus	doc_101672866015_item	3142369	et	3	main
ta	doc_101672866015_item	3142370	et	4	main
püüab	doc_101672866015_item	3142371	et	3	main
vastata	doc_101672866015_item	3142372	et	4	main
mis	doc_101672866015_item	3142373	et	4	main
on	doc_101672866015_item	3142374	et	4	main
tõeline	doc_101672866015_item	3142375	et	4	main
tõde	doc_101672866015_item	3142376	et	4	main
ja	doc_101672866015_item	3142377	et	3	main
mis	doc_101672866015_item	3142378	et	4	main
on	doc_101672866015_item	3142379	et	4	main
kujuteldav	doc_101672866015_item	3142380	et	4	main
mis	doc_101672866015_item	3142381	et	4	main
on	doc_101672866015_item	3142382	et	4	main
päris	doc_101672866015_item	3142383	et	4	main
vale	doc_101672866015_item	3142384	et	4	main
ja	doc_101672866015_item	3142385	et	3	main
mida	doc_101672866015_item	3142386	et	4	main
võib	doc_101672866015_item	3142387	et	3	main
õilsaks	doc_101672866015_item	3142388	et	3	main
valeks	doc_101672866015_item	3142389	et	3	main
nimetada	doc_101672866015_item	3142390	et	3	main
näeb	doc_101672866015_item	3142391	et	3	main
läbi	doc_101672866015_item	3142392	et	4	main
kui	doc_101672866015_item	3142393	et	3	main
õhuke	doc_101672866015_item	3142394	et	4	main
on	doc_101672866015_item	3142395	et	4	main
inimese	doc_101672866015_item	3142396	et	4	main
kui	doc_101672866015_item	3142399	et	3	main
novellikogud	doc_101672866015_item	3142424	et	3	main
olemus	doc_101672866015_item	3142398	et	3	main
palju	doc_101672866015_item	3142400	et	4	main
on	doc_101672866015_item	3142402	et	4	main
paradokse	doc_101672866015_item	3142403	et	3	main
kuuluvad	doc_101672866015_item	3142410	et	4	main
romaanid	doc_101672866015_item	3142411	et	3	main
õilis	doc_101672866015_item	3142412	et	3	main
mõlemad	doc_101672866015_item	3142421	et	3	main
varasema	doc_101672866015_item	3142425	et	4	main
tee	doc_101672866015_item	3142429	et	4	main
1936	doc_101672866015_item	3142430	et	2	main
tänapäeval	doc_101672866015_item	3142431	et	3	main
pedro	doc_101672866015_item	3142432	et	4	main
krusten	doc_101672866015_item	3142433	et	4	main
1934	doc_101672866015_item	3142427	et	2	main
nagu	doc_101672866015_item	3142438	et	3	main
eluajal	doc_101672866015_item	3142440	et	3	main
kirjuta	doc_101672866015_item	3142444	et	4	main
kaldametsa-	doc_101672866015_item	3142452	et	4	main
armastus	doc_101672866015_item	3142459	et	4	main
1990	doc_101672866015_item	3142464	et	2	main
kes	doc_101672866015_item	3142472	et	4	main
nimetab	doc_101672866015_item	3142482	et	3	main
tundmatu	doc_101672866015_item	3142485	et	4	main
eesti	doc_101672866015_item	3142486	et	4	main
uued	doc_101672866015_item	3142499	et	3	main
üle	doc_101672866015_item	3142508	et	3	main
kes	doc_101672866015_item	3142524	et	4	main
pärines	doc_101672866015_item	3142525	et	3	main
mõisast	doc_101672866015_item	3142526	et	4	main
mitte	doc_101672866015_item	3142527	et	3	main
peamine	doc_101672866015_item	3142534	et	3	main
sellel	doc_101672866015_item	3142537	et	4	main
mõisast	doc_101672866015_item	3142539	et	4	main
suhted	doc_101672866015_item	3142569	et	3	main
ja	doc_101672866015_item	3142571	et	3	main
midagi	doc_101672866015_item	3142578	et	4	main
tema	doc_101672866015_item	3142581	et	4	main
muraste	doc_101672866015_item	3142583	et	4	main
mis	doc_101672866015_item	3142584	et	4	main
nagu	doc_101672866015_item	3142585	et	3	main
peegeldab	doc_101672866015_item	3142586	et	3	main
sealelava	doc_101672866015_item	3142587	et	3	main
rahva	doc_101672866015_item	3142588	et	3	main
ja	doc_101672866015_item	3142589	et	3	main
oma	doc_101672866015_item	3142439	et	4	main
ei	doc_101672866015_item	3142443	et	4	main
kordustrükke	doc_101672866015_item	3142445	et	3	main
triloogia	doc_101672866015_item	3142453	et	4	main
romaanid	doc_101672866015_item	3142460	et	3	main
ülo	doc_101672866015_item	3142470	et	4	main
koostajaks	doc_101672866015_item	3142478	et	4	main
oma	doc_101672866015_item	3142479	et	4	main
artiklis	doc_101672866015_item	3142480	et	3	main
on	doc_101672866015_item	3142489	et	4	main
unustatud	doc_101672866015_item	3142492	et	4	main
aeg	doc_101672866015_item	3142494	et	3	main
tulevad	doc_101672866015_item	3142496	et	4	main
lugejad	doc_101672866015_item	3142498	et	4	main
kirjanikud	doc_101672866015_item	3142500	et	3	main
metsa	doc_101672866015_item	3142509	et	4	main
roosiaeda	doc_101672866015_item	3142516	et	4	main
autor	doc_101672866015_item	3142517	et	3	main
näitab	doc_101672866015_item	3142518	et	3	main
eesti	doc_101672866015_item	3142519	et	4	main
on	doc_101672866015_item	3142536	et	4	main
täienduseks	doc_101672866015_item	3142544	et	4	main
mõisarahva	doc_101672866015_item	3142566	et	3	main
kaldametsa	doc_101672866015_item	3142574	et	4	main
kultuuri	doc_101672866015_item	3142590	et	4	main
ole	doc_101672866015_item	3142604	et	4	main
krusteni	doc_101672866015_item	3142607	et	4	main
veel	doc_101672866015_item	3142611	et	4	main
mis	doc_101672866015_item	3142620	et	4	main
autoriga	doc_101672866015_item	3142622	et	3	main
kaaselatud	doc_101672866015_item	3142624	et	3	main
need	doc_101672866015_item	3142626	et	3	main
on	doc_101672866015_item	3142627	et	4	main
romaanid	doc_101672866015_item	3142628	et	3	main
üleparda	doc_101672866015_item	3142629	et	4	main
1946	doc_101672866015_item	3142630	et	2	main
laev	doc_101672866015_item	3142636	et	3	main
autor	doc_101672866015_item	3142644	et	3	main
oma	doc_101672866015_item	3142646	et	4	main
ja	doc_101672866015_item	3142671	et	3	main
krusten	doc_101672866015_item	3142674	et	4	main
võõrsile	doc_101672866015_item	3142677	et	4	main
paisatud	doc_101672866015_item	3142678	et	4	main
iseloomustab	doc_101672866015_item	3142692	et	4	main
ja	doc_101672866015_item	3142696	et	3	main
psühholoogiline	doc_101672866015_item	3142717	et	4	main
kõik	doc_101672866015_item	3142719	et	4	main
raamatud	doc_101672866015_item	3142721	et	4	main
kuuluvad	doc_101672866015_item	3142722	et	4	main
rahvusliku	doc_101672866015_item	3142723	et	3	main
varanduse	doc_101672866015_item	3142724	et	3	main
tähtpäeval	doc_101672866015_item	3142733	et	3	main
2	doc_101672866015_item	3142739	et	2	main
tallinnast	doc_101672866015_item	3142741	et	3	main
kohaliku	doc_101672866015_item	3142765	et	3	main
mõisa	doc_101672866015_item	3142771	et	3	main
polüfunktsionaalse	doc_101672866015_item	3142773	et	4	main
73	doc_101672866015_item	3142782	et	2	main
kohaliku	doc_101672866015_item	3142792	et	3	main
55-56	doc_101672866015_item	3142795	et	2	main
polüfunktsionaalse	doc_101672866015_item	3142812	et	4	main
keskusena	doc_101672866015_item	3142813	et	3	main
eesti	doc_101672866015_item	3142814	et	4	main
regionaalse	doc_101672866015_item	3142815	et	3	main
ja	doc_101672866015_item	3142816	et	3	main
kohaliku	doc_101672866015_item	3142817	et	3	main
arengu	doc_101672866015_item	3142818	et	3	main
9	doc_101672866015_item	3142822	et	2	main
tallinn	doc_101672866015_item	3142825	et	4	main
rahnop1965	doc_101672866015_item	3142828	et	4	main
harku	doc_101672866015_item	3142836	et	4	main
tallinn	doc_101672866015_item	3142837	et	4	main
5-8	doc_101672866015_item	3142838	et	2	main
12rahnop1965	doc_101672866015_item	3142839	et	2	main
tallinn	doc_101672866015_item	3142843	et	4	main
ajaloost	doc_101672866015_item	3142853	et	4	main
tallinn	doc_101672866015_item	3142854	et	4	main
kes	doc_101672866015_item	3142488	et	4	main
ja	doc_101672866015_item	3142491	et	3	main
miks	doc_101672866015_item	3142493	et	4	main
kuuluvates	doc_101672866015_item	3142505	et	4	main
laul	doc_101672866015_item	3142510	et	4	main
kõrgel	doc_101672866015_item	3142511	et	4	main
kaldal	doc_101672866015_item	3142512	et	3	main
ja	doc_101672866015_item	3142513	et	3	main
neiuke	doc_101672866015_item	3142514	et	4	main
läks	doc_101672866015_item	3142515	et	3	main
külast	doc_101672866015_item	3142528	et	4	main
mõisa	doc_101672866015_item	3142529	et	3	main
ja	doc_101672866015_item	3142530	et	3	main
küla	doc_101672866015_item	3142531	et	4	main
vastuolud	doc_101672866015_item	3142532	et	3	main
süžee	doc_101672866015_item	3142564	et	2	main
külainimeste	doc_101672866015_item	3142568	et	3	main
vahekord	doc_101672866015_item	3142573	et	3	main
muud	doc_101672866015_item	3142579	et	4	main
seda	doc_101672866015_item	3142596	et	3	main
on	doc_101672866015_item	3142598	et	4	main
teostest	doc_101672866015_item	3142608	et	3	main
kus	doc_101672866015_item	3142614	et	3	main
tõlgendatud	doc_101672866015_item	3142625	et	4	main
inimesehoidja	doc_101672866015_item	3142634	et	4	main
1955	doc_101672866015_item	3142639	et	2	main
käekõrval	doc_101672866015_item	3142642	et	3	main
kirjeldab	doc_101672866015_item	3142645	et	3	main
põgenemise	doc_101672866015_item	3142647	et	4	main
inimese	doc_101672866015_item	3142679	et	4	main
siseprobleeme	doc_101672866015_item	3142680	et	3	main
eetilise	doc_101672866015_item	3142681	et	3	main
inimese	doc_101672866015_item	3142682	et	4	main
katsumusi	doc_101672866015_item	3142685	et	3	main
maailmasõja	doc_101672866015_item	3142687	et	3	main
kaldametsa-	doc_101672866015_item	3142501	et	4	main
triloogias	doc_101672866015_item	3142502	et	3	main
romaanides	doc_101672866015_item	3142506	et	3	main
torn	doc_101672866015_item	3142507	et	3	main
sündi	doc_101672866015_item	3142521	et	4	main
ja	doc_101672866015_item	3142522	et	3	main
kujunemist	doc_101672866015_item	3142523	et	4	main
rõhk	doc_101672866015_item	3142535	et	3	main
kuidas	doc_101672866015_item	3142538	et	3	main
võrsuv	doc_101672866015_item	3142540	et	4	main
teosed	doc_101672866015_item	3142545	et	3	main
võib	doc_101672866015_item	3142546	et	3	main
julgesti	doc_101672866015_item	3142547	et	3	main
nimetada	doc_101672866015_item	3142548	et	3	main
perekondlikeks	doc_101672866015_item	3142549	et	3	main
autobiograafilisteks	doc_101672866015_item	3142550	et	4	main
ja	doc_101672866015_item	3142551	et	3	main
külale	doc_101672866015_item	3142543	et	3	main
mälestuslikeks	doc_101672866015_item	3142552	et	4	main
sest	doc_101672866015_item	3142553	et	4	main
nende	doc_101672866015_item	3142554	et	4	main
peategelane	doc_101672866015_item	3142555	et	3	main
on	doc_101672866015_item	3142556	et	4	main
mõisaednik	doc_101672866015_item	3142557	et	4	main
ja	doc_101672866015_item	3142558	et	3	main
tema	doc_101672866015_item	3142559	et	4	main
pojad	doc_101672866015_item	3142560	et	4	main
samasused	doc_101672866015_item	3142561	et	3	main
eksisteerivad	doc_101672866015_item	3142562	et	4	main
1959-	doc_101672866015_item	3142503	et	4	main
1963	doc_101672866015_item	3142504	et	2	main
maaintelligentsi	doc_101672866015_item	3142520	et	4	main
kuid	doc_101672866015_item	3142533	et	4	main
rahvas	doc_101672866015_item	3142541	et	4	main
on	doc_101672866015_item	3142542	et	4	main
ja	doc_101672866015_item	3142567	et	3	main
mõisnike	doc_101672866015_item	3142570	et	3	main
ei	doc_101672866015_item	3142576	et	4	main
kui	doc_101672866015_item	3142580	et	3	main
lapsepõlvekodu	doc_101672866015_item	3142582	et	4	main
kirjanik	doc_101672866015_item	3142592	et	3	main
ise	doc_101672866015_item	3142593	et	4	main
kunagi	doc_101672866015_item	3142594	et	3	main
kommenteeris	doc_101672866015_item	3142595	et	3	main
kõik	doc_101672866015_item	3142597	et	4	main
elust	doc_101672866015_item	3142599	et	3	main
võetud	doc_101672866015_item	3142600	et	4	main
niisugust	doc_101672866015_item	3142602	et	3	main
ei	doc_101672866015_item	3142603	et	4	main
võib	doc_101672866015_item	3142609	et	3	main
ühe	doc_101672866015_item	3142612	et	4	main
ajastu	doc_101672866015_item	3142616	et	4	main
ihaldatud	doc_101672866015_item	3142631	et	4	main
silmapilk	doc_101672866015_item	3142632	et	3	main
1950	doc_101672866015_item	3142633	et	2	main
1957	doc_101672866015_item	3142643	et	2	main
järgses	doc_101672866015_item	3142688	et	3	main
inimsõbralikkus	doc_101672866015_item	3142694	et	4	main
muutumatu	doc_101672866015_item	3142697	et	4	main
mitte	doc_101672866015_item	3142709	et	3	main
maailmavaade	doc_101672866015_item	3142710	et	3	main
vaid	doc_101672866015_item	3142711	et	3	main
ikka	doc_101672866015_item	3142712	et	4	main
inimene	doc_101672866015_item	3142713	et	3	main
ise	doc_101672866015_item	3142714	et	4	main
hulka	doc_101672866015_item	3142725	et	4	main
63	doc_101672866015_item	3142734	et	2	main
keskusena	doc_101672866015_item	3142761	et	3	main
2004vääna	doc_101672866015_item	3142770	et	4	main
6	doc_101672866015_item	3142783	et	2	main
tulevikuprespektiivid	doc_101672866015_item	3142786	et	4	main
polüfunktsionaalse	doc_101672866015_item	3142787	et	4	main
keskusena	doc_101672866015_item	3142788	et	3	main
tulevikuprespektiivid	doc_101672866015_item	3142798	et	4	main
keskusena	doc_101672866015_item	3142800	et	3	main
eesti	doc_101672866015_item	3142801	et	4	main
regionaalse	doc_101672866015_item	3142802	et	3	main
arengu	doc_101672866015_item	3142805	et	3	main
sihtasutus	doc_101672866015_item	3142819	et	4	main
harku	doc_101672866015_item	3142824	et	4	main
tallinn	doc_101672866015_item	3142832	et	4	main
rahno	doc_101672866015_item	3142834	et	4	main
p1976	doc_101672866015_item	3142835	et	4	main
ajaloost	doc_101672866015_item	3142842	et	4	main
22	doc_101672866015_item	3142888	et	2	main
parunid	doc_101672866015_item	3142890	et	3	main
eestlased	doc_101672866015_item	3142891	et	3	main
ja	doc_101672866015_item	3142892	et	3	main
124-132	doc_101672866015_item	3142894	et	2	main
parunid	doc_101672866015_item	3142896	et	3	main
ka	doc_101672866015_item	3142563	et	3	main
taustas	doc_101672866015_item	3142565	et	3	main
mõisarahva	doc_101672866015_item	3142572	et	3	main
mõisa	doc_101672866015_item	3142575	et	3	main
ole	doc_101672866015_item	3142577	et	4	main
kujunemist	doc_101672866015_item	3142591	et	4	main
juhtunud	doc_101672866015_item	3142605	et	4	main
eristada	doc_101672866015_item	3142610	et	3	main
oli	doc_101672866015_item	3142621	et	3	main
läbinähtud	doc_101672866015_item	3142623	et	4	main
akna	doc_101672866015_item	3142637	et	3	main
ja	doc_101672866015_item	3142640	et	3	main
kaugelviibija	doc_101672866015_item	3142641	et	4	main
nende	doc_101672866015_item	3142672	et	4	main
eelkõige	doc_101672866015_item	3142676	et	3	main
kogemusi	doc_101672866015_item	3142683	et	3	main
teise	doc_101672866015_item	3142686	et	4	main
pohmelsuses	doc_101672866015_item	3142689	et	4	main
krusteni	doc_101672866015_item	3142690	et	4	main
teoseid	doc_101672866015_item	3142691	et	3	main
peamine	doc_101672866015_item	3142695	et	3	main
vaatlemine	doc_101672866015_item	3142702	et	4	main
ja	doc_101672866015_item	3142703	et	3	main
seega	doc_101672866015_item	3142715	et	4	main
mille	doc_101672866015_item	3142726	et	3	main
paremast	doc_101672866015_item	3142727	et	4	main
valdamisest	doc_101672866015_item	3142728	et	4	main
erni	doc_101672866015_item	3142735	et	4	main
httpwwwharkueeindexphp	doc_101672866015_item	3142738	et	4	main
keila-joale	doc_101672866015_item	3142742	et	3	main
ja	doc_101672866015_item	3142764	et	3	main
sihtasutus	doc_101672866015_item	3142767	et	4	main
57-	doc_101672866015_item	3142781	et	4	main
eesti	doc_101672866015_item	3142789	et	4	main
regionaalse	doc_101672866015_item	3142790	et	3	main
sihtasutus	doc_101672866015_item	3142794	et	4	main
mõisa	doc_101672866015_item	3142797	et	3	main
ja	doc_101672866015_item	3142803	et	3	main
kohaliku	doc_101672866015_item	3142804	et	3	main
8	doc_101672866015_item	3142808	et	2	main
mõisa	doc_101672866015_item	3142810	et	3	main
tulevikuprespektiivid	doc_101672866015_item	3142811	et	4	main
57-	doc_101672866015_item	3142820	et	4	main
3	doc_101672866015_item	3142826	et	2	main
harku	doc_101672866015_item	3142840	et	4	main
13rahnop1965	doc_101672866015_item	3142844	et	2	main
ajaloost	doc_101672866015_item	3142847	et	4	main
15	doc_101672866015_item	3142855	et	2	main
monthanderc1997	doc_101672866015_item	3142889	et	4	main
enamlased	doc_101672866015_item	3142893	et	3	main
kuigi	doc_101672866015_item	3142601	et	3	main
p	doc_101672866015_item	3142606	et	4	main
gruppi	doc_101672866015_item	3142613	et	4	main
kajastuvad	doc_101672866015_item	3142615	et	4	main
pöördelised	doc_101672866015_item	3142617	et	4	main
sündmused	doc_101672866015_item	3142618	et	3	main
kõik	doc_101672866015_item	3142619	et	4	main
1952	doc_101672866015_item	3142635	et	2	main
taga	doc_101672866015_item	3142638	et	4	main
kodumaalt	doc_101672866015_item	3142648	et	3	main
diipii-	doc_101672866015_item	3142649	et	4	main
laagrite	doc_101672866015_item	3142650	et	3	main
ja	doc_101672866015_item	3142651	et	3	main
usa-sse	doc_101672866015_item	3142652	et	3	main
ümberasumisest	doc_101672866015_item	3142653	et	4	main
mõned	doc_101672866015_item	3142654	et	3	main
kriitikut	doc_101672866015_item	3142655	et	3	main
väidsid	doc_101672866015_item	3142656	et	4	main
nagu	doc_101672866015_item	3142657	et	3	main
oleksid	doc_101672866015_item	3142658	et	4	main
need	doc_101672866015_item	3142659	et	3	main
teod	doc_101672866015_item	3142660	et	4	main
pagulaselu	doc_101672866015_item	3142661	et	4	main
kroonika	doc_101672866015_item	3142662	et	4	main
kuid	doc_101672866015_item	3142663	et	4	main
ülo	doc_101672866015_item	3142664	et	4	main
tontsu	doc_101672866015_item	3142665	et	4	main
sõnadel	doc_101672866015_item	3142666	et	3	main
see	doc_101672866015_item	3142667	et	3	main
ei	doc_101672866015_item	3142668	et	4	main
vasta	doc_101672866015_item	3142669	et	4	main
tõele	doc_101672866015_item	3142670	et	4	main
raamatutes	doc_101672866015_item	3142673	et	3	main
jälgib	doc_101672866015_item	3142675	et	3	main
ja	doc_101672866015_item	3142684	et	3	main
nende	doc_101672866015_item	3142693	et	4	main
avastamine	doc_101672866015_item	3142704	et	4	main
mitte	doc_101672866015_item	3142705	et	3	main
olustik	doc_101672866015_item	3142706	et	3	main
mitte	doc_101672866015_item	3142707	et	3	main
ideed	doc_101672866015_item	3142708	et	4	main
proosa	doc_101672866015_item	3142718	et	4	main
tasub	doc_101672866015_item	3142729	et	3	main
mõtelda	doc_101672866015_item	3142730	et	4	main
ka	doc_101672866015_item	3142731	et	3	main
tänasel	doc_101672866015_item	3142732	et	3	main
1	doc_101672866015_item	3142737	et	2	main
ülevainor2001	doc_101672866015_item	3142740	et	4	main
55-57	doc_101672866015_item	3142768	et	2	main
tulevikuprespektiivid	doc_101672866015_item	3142772	et	4	main
keskusena	doc_101672866015_item	3142774	et	3	main
ja	doc_101672866015_item	3142791	et	3	main
huvi	doc_101672866015_item	3142698	et	4	main
olnud	doc_101672866015_item	3142699	et	4	main
inimene	doc_101672866015_item	3142700	et	3	main
inimese	doc_101672866015_item	3142701	et	4	main
siis	doc_101672866015_item	3142716	et	3	main
tema	doc_101672866015_item	3142720	et	4	main
krusten	doc_101672866015_item	3142736	et	4	main
38	doc_101672866015_item	3142743	et	2	main
3	doc_101672866015_item	3142744	et	2	main
2004vääna	doc_101672866015_item	3142745	et	4	main
mõisa	doc_101672866015_item	3142746	et	3	main
tulevikuprespektiivid	doc_101672866015_item	3142747	et	4	main
polüfunktsionaalse	doc_101672866015_item	3142748	et	4	main
keskusena	doc_101672866015_item	3142749	et	3	main
eesti	doc_101672866015_item	3142750	et	4	main
regionaalse	doc_101672866015_item	3142751	et	3	main
ja	doc_101672866015_item	3142752	et	3	main
kohaliku	doc_101672866015_item	3142753	et	3	main
arengu	doc_101672866015_item	3142754	et	3	main
sihtasutus	doc_101672866015_item	3142755	et	4	main
4	doc_101672866015_item	3142756	et	2	main
2004vääna	doc_101672866015_item	3142757	et	4	main
mõisa	doc_101672866015_item	3142758	et	3	main
tulevikuprespektiivid	doc_101672866015_item	3142759	et	4	main
polüfunktsionaalse	doc_101672866015_item	3142760	et	4	main
eesti	doc_101672866015_item	3142762	et	4	main
regionaalse	doc_101672866015_item	3142763	et	3	main
arengu	doc_101672866015_item	3142766	et	3	main
5	doc_101672866015_item	3142769	et	2	main
eesti	doc_101672866015_item	3142775	et	4	main
regionaalse	doc_101672866015_item	3142776	et	3	main
ja	doc_101672866015_item	3142777	et	3	main
kohaliku	doc_101672866015_item	3142778	et	3	main
arengu	doc_101672866015_item	3142779	et	3	main
sihtasutus	doc_101672866015_item	3142780	et	4	main
2004vääna	doc_101672866015_item	3142784	et	4	main
mõisa	doc_101672866015_item	3142785	et	3	main
arengu	doc_101672866015_item	3142793	et	3	main
72004vääna	doc_101672866015_item	3142796	et	2	main
polüfunktsionaalse	doc_101672866015_item	3142799	et	4	main
sihtasutus	doc_101672866015_item	3142806	et	4	main
rahnop1976	doc_101672866015_item	3142823	et	4	main
10	doc_101672866015_item	3142827	et	2	main
harku	doc_101672866015_item	3142829	et	4	main
mõisa	doc_101672866015_item	3142830	et	3	main
ajaloost	doc_101672866015_item	3142831	et	4	main
harku	doc_101672866015_item	3142845	et	4	main
mõisa	doc_101672866015_item	3142846	et	3	main
14	doc_101672866015_item	3142849	et	2	main
rahnop1965	doc_101672866015_item	3142856	et	4	main
77-80	doc_101672866015_item	3142807	et	2	main
2004vääna	doc_101672866015_item	3142809	et	4	main
73	doc_101672866015_item	3142821	et	2	main
11	doc_101672866015_item	3142833	et	2	main
mõisa	doc_101672866015_item	3142841	et	3	main
tallinn	doc_101672866015_item	3142848	et	4	main
rahnop1965	doc_101672866015_item	3142850	et	4	main
harku	doc_101672866015_item	3142851	et	4	main
mõisa	doc_101672866015_item	3142852	et	3	main
harku	doc_101672866015_item	3142857	et	4	main
mõisa	doc_101672866015_item	3142858	et	3	main
ajaloost	doc_101672866015_item	3142859	et	4	main
tallinn	doc_101672866015_item	3142860	et	4	main
16	doc_101672866015_item	3142861	et	2	main
httpwwwharkueefiles103pdf	doc_101672866015_item	3142862	et	4	main
17	doc_101672866015_item	3142864	et	2	main
221105	doc_101672866015_item	3142863	et	2	main
ülevainor2001	doc_101672866015_item	3142865	et	4	main
tallinnast	doc_101672866015_item	3142866	et	3	main
keila-joale	doc_101672866015_item	3142867	et	3	main
tallinn	doc_101672866015_item	3142868	et	4	main
35	doc_101672866015_item	3142869	et	2	main
18	doc_101672866015_item	3142870	et	2	main
rahnop1965	doc_101672866015_item	3142871	et	4	main
harku	doc_101672866015_item	3142872	et	4	main
mõisa	doc_101672866015_item	3142873	et	3	main
ajaloost	doc_101672866015_item	3142874	et	4	main
tallinn	doc_101672866015_item	3142875	et	4	main
19	doc_101672866015_item	3142876	et	2	main
httpwwweestigiideescat15catid0itemid130	doc_101672866015_item	3142877	et	4	main
221105	doc_101672866015_item	3142878	et	2	main
20	doc_101672866015_item	3142879	et	2	main
sakki2002	doc_101672866015_item	3142880	et	4	main
eesti	doc_101672866015_item	3142881	et	4	main
mõisad	doc_101672866015_item	3142882	et	3	main
reisijuht	doc_101672866015_item	3142883	et	3	main
32-33	doc_101672866015_item	3142884	et	2	main
21	doc_101672866015_item	3142885	et	2	main
httpwwwharkueefiles84pdf	doc_101672866015_item	3142886	et	4	main
221105	doc_101672866015_item	3142887	et	2	main
23monthanderc1997	doc_101672866015_item	3142895	et	2	main
eestlased	doc_101672866015_item	3142897	et	3	main
ja	doc_101672866015_item	3142898	et	3	main
enamlased	doc_101672866015_item	3142899	et	3	main
tartu	doc_101672866015_item	3142900	et	4	main
129	doc_101672866015_item	3142901	et	2	main
24	doc_101672866015_item	3142902	et	2	main
httpwwweestigiideecatid89itemid325	doc_101672866015_item	3142903	et	4	main
221105	doc_101672866015_item	3142904	et	2	main
25ülevainor2001	doc_101672866015_item	3142905	et	2	main
ajalehe	doc_491521501775_item	3155161	et	3	main
uurida	doc_491521501775_item	3155166	et	3	main
virumaa	doc_491521501775_item	3155168	et	4	main
teataja	doc_491521501775_item	3155169	et	4	main
igast	doc_491521501775_item	3155170	et	3	main
on	doc_491521501775_item	3155176	et	4	main
kui	doc_491521501775_item	3155179	et	3	main
minu	doc_491521501775_item	3155182	et	3	main
esiteks	doc_491521501775_item	3155189	et	3	main
toimetuse	doc_491521501775_item	3155190	et	4	main
mis	doc_491521501775_item	3155201	et	4	main
on	doc_491521501775_item	3155209	et	4	main
väga	doc_491521501775_item	3155216	et	3	main
analüüs	doc_491521501775_item	3155160	et	3	main
üldkujundus	doc_491521501775_item	3155173	et	3	main
kujunduses	doc_491521501775_item	3155175	et	4	main
plusse	doc_491521501775_item	3155178	et	3	main
miinuseid	doc_491521501775_item	3155181	et	3	main
valesti	doc_491521501775_item	3155187	et	3	main
asub	doc_491521501775_item	3155192	et	3	main
pehme	doc_491521501775_item	3155203	et	4	main
lugu	doc_491521501775_item	3155204	et	4	main
läheb	doc_491521501775_item	3155205	et	3	main
poliitikaosakond	doc_491521501775_item	3155206	et	3	main
kolmandaks	doc_491521501775_item	3155207	et	4	main
spordiosakond	doc_491521501775_item	3155208	et	3	main
teisel	doc_491521501775_item	3155211	et	4	main
lõppleheküljel	doc_491521501775_item	3155215	et	3	main
meeldis	doc_491521501775_item	3155217	et	3	main
kujundust	doc_491521501775_item	3155219	et	4	main
tähtsad	doc_491521501775_item	3155221	et	3	main
on	doc_491521501775_item	3155223	et	4	main
oma	doc_491521501775_item	3155163	et	4	main
ajalehe	doc_491521501775_item	3155174	et	3	main
nii	doc_491521501775_item	3155177	et	3	main
ka	doc_491521501775_item	3155180	et	3	main
arvates	doc_491521501775_item	3155183	et	4	main
ajalehe	doc_491521501775_item	3155184	et	3	main
osakonnad	doc_491521501775_item	3155185	et	4	main
teise	doc_491521501775_item	3155193	et	4	main
hoopis	doc_491521501775_item	3155196	et	3	main
teiseks	doc_491521501775_item	3155198	et	4	main
leheküljel	doc_491521501775_item	3155212	et	3	main
esilehe	doc_491521501775_item	3155218	et	3	main
korduse	doc_491521501775_item	3155229	et	3	main
teiseks	doc_491521501775_item	3155231	et	4	main
on	doc_491521501775_item	3155234	et	4	main
paigutatud	doc_491521501775_item	3155235	et	4	main
analüüs	doc_491521501775_item	3155162	et	3	main
küljest	doc_491521501775_item	3155171	et	4	main
ajalehe	doc_491521501775_item	3155172	et	3	main
on	doc_491521501775_item	3155186	et	4	main
lehekülg	doc_491521501775_item	3155191	et	3	main
asemel	doc_491521501775_item	3155195	et	4	main
viimasel	doc_491521501775_item	3155197	et	3	main
pärast	doc_491521501775_item	3155199	et	4	main
naistelehte	doc_491521501775_item	3155200	et	4	main
aga	doc_491521501775_item	3155213	et	3	main
mitte	doc_491521501775_item	3155214	et	3	main
esiteks	doc_491521501775_item	3155220	et	3	main
on	doc_491521501775_item	3155227	et	4	main
need	doc_491521501775_item	3155264	et	3	main
asuvad	doc_491521501775_item	3155271	et	4	main
välisservadel	doc_491521501775_item	3155272	et	3	main
näha	doc_491521501775_item	3155292	et	3	main
ilmateadet	doc_491521501775_item	3155293	et	4	main
hakka	doc_491521501775_item	3155315	et	4	main
sees	doc_491521501775_item	3155319	et	4	main
informatsiooni	doc_491521501775_item	3155327	et	4	main
mõistlik	doc_491521501775_item	3155331	et	3	main
lehel	doc_491521501775_item	3155338	et	3	main
sest	doc_491521501775_item	3155339	et	4	main
ajalehe	doc_491521501775_item	3155340	et	3	main
kujundamise	doc_491521501775_item	3155341	et	4	main
info	doc_491521501775_item	3155346	et	4	main
ajalehe	doc_491521501775_item	3155353	et	3	main
spordiosakond	doc_491521501775_item	3155360	et	3	main
on	doc_491521501775_item	3155368	et	4	main
koos	doc_491521501775_item	3155370	et	4	main
kultuurosakonda	doc_491521501775_item	3155380	et	4	main
aga	doc_491521501775_item	3155381	et	3	main
nagu	doc_491521501775_item	3155406	et	3	main
mõttetu	doc_491521501775_item	3155409	et	4	main
ja	doc_491521501775_item	3155410	et	3	main
halvasti	doc_491521501775_item	3155411	et	3	main
leheküljel	doc_491521501775_item	3155413	et	3	main
on	doc_491521501775_item	3155452	et	4	main
vales	doc_491521501775_item	3155453	et	3	main
mitte	doc_491521501775_item	3155462	et	3	main
enamus	doc_491521501775_item	3155466	et	4	main
on	doc_491521501775_item	3155476	et	4	main
ka	doc_491521501775_item	3155477	et	3	main
mõned	doc_491521501775_item	3155478	et	3	main
isegi	doc_491521501775_item	3155481	et	4	main
kuueveerulises	doc_491521501775_item	3155482	et	4	main
naisteleht	doc_491521501775_item	3155487	et	3	main
lugemist	doc_491521501775_item	3155501	et	4	main
päismik	doc_491521501775_item	3155510	et	4	main
artiklite	doc_491521501775_item	3155511	et	3	main
pealkirjad	doc_491521501775_item	3155512	et	3	main
pisiinfo	doc_491521501775_item	3155515	et	4	main
kirjas	doc_491521501775_item	3155518	et	4	main
tekstides	doc_491521501775_item	3155519	et	3	main
on	doc_491521501775_item	3155520	et	4	main
kursiivkirjas	doc_491521501775_item	3155531	et	4	main
stiiliga	doc_491521501775_item	3155537	et	3	main
loetav	doc_491521501775_item	3155540	et	4	main
et	doc_491521501775_item	3155543	et	3	main
paksus	doc_491521501775_item	3155562	et	4	main
kuigi	doc_491521501775_item	3155568	et	3	main
on	doc_491521501775_item	3155571	et	4	main
pealkiri	doc_491521501775_item	3155572	et	3	main
jäädud	doc_491521501775_item	3155573	et	4	main
murdejoonele	doc_491521501775_item	3155574	et	3	main
pealkirjade	doc_491521501775_item	3155579	et	3	main
pikkus	doc_491521501775_item	3155580	et	4	main
vahelpealkirjad	doc_491521501775_item	3155629	et	4	main
kõrvalekaldumistega	doc_491521501775_item	3155639	et	3	main
viis	doc_491521501775_item	3155651	et	4	main
analüüsis	doc_491521501775_item	3155164	et	4	main
tahan	doc_491521501775_item	3155165	et	3	main
ajalehte	doc_491521501775_item	3155167	et	4	main
järjestatud	doc_491521501775_item	3155188	et	4	main
lehekülje	doc_491521501775_item	3155194	et	3	main
on	doc_491521501775_item	3155202	et	4	main
paigutatud	doc_491521501775_item	3155210	et	4	main
uudised	doc_491521501775_item	3155222	et	3	main
esitatud	doc_491521501775_item	3155224	et	4	main
tervikuna	doc_491521501775_item	3155225	et	3	main
hea	doc_491521501775_item	3155228	et	4	main
esilehel	doc_491521501775_item	3155233	et	3	main
kõik	doc_491521501775_item	3155236	et	4	main
tähtsad	doc_491521501775_item	3155237	et	3	main
sündmused	doc_491521501775_item	3155238	et	3	main
mis	doc_491521501775_item	3155239	et	4	main
toimusid	doc_491521501775_item	3155240	et	4	main
nii	doc_491521501775_item	3155241	et	3	main
lääne-virumaal	doc_491521501775_item	3155242	et	4	main
kui	doc_491521501775_item	3155243	et	3	main
ka	doc_491521501775_item	3155244	et	3	main
kogu	doc_491521501775_item	3155245	et	4	main
eestis	doc_491521501775_item	3155246	et	3	main
kolmandaks	doc_491521501775_item	3155247	et	4	main
kui	doc_491521501775_item	3155248	et	3	main
arvestada	doc_491521501775_item	3155249	et	3	main
et	doc_491521501775_item	3155250	et	3	main
ajaleht	doc_491521501775_item	3155251	et	3	main
on	doc_491521501775_item	3155252	et	4	main
kohalik	doc_491521501775_item	3155253	et	3	main
siis	doc_491521501775_item	3155254	et	3	main
just	doc_491521501775_item	3155255	et	3	main
kohalikud	doc_491521501775_item	3155256	et	3	main
sündmused	doc_491521501775_item	3155257	et	3	main
hakkavad	doc_491521501775_item	3155258	et	4	main
tõmbama	doc_491521501775_item	3155259	et	3	main
samuti	doc_491521501775_item	3155291	et	3	main
ei	doc_491521501775_item	3155314	et	4	main
järgi	doc_491521501775_item	3155343	et	4	main
kolmandal	doc_491521501775_item	3155349	et	3	main
mis	doc_491521501775_item	3155364	et	4	main
paigutatud	doc_491521501775_item	3155369	et	4	main
minu	doc_491521501775_item	3155371	et	3	main
artikkel	doc_491521501775_item	3155383	et	3	main
rakvere	doc_491521501775_item	3155384	et	4	main
vajab	doc_491521501775_item	3155385	et	3	main
nimesid	doc_491521501775_item	3155386	et	3	main
mis	doc_491521501775_item	3155404	et	4	main
mulle	doc_491521501775_item	3155407	et	4	main
reklaami	doc_491521501775_item	3155416	et	4	main
kui	doc_491521501775_item	3155417	et	3	main
arust	doc_491521501775_item	3155451	et	4	main
mis	doc_491521501775_item	3155226	et	4	main
vältimiseks	doc_491521501775_item	3155230	et	4	main
ajalehe	doc_491521501775_item	3155232	et	3	main
kohalike	doc_491521501775_item	3155260	et	4	main
tähelepanu	doc_491521501775_item	3155262	et	4	main
asuvadki	doc_491521501775_item	3155265	et	4	main
esilehe	doc_491521501775_item	3155266	et	3	main
esiplaanil	doc_491521501775_item	3155267	et	4	main
aga	doc_491521501775_item	3155268	et	3	main
lühiuudiste	doc_491521501775_item	3155269	et	3	main
neljandaks	doc_491521501775_item	3155273	et	4	main
kuumade	doc_491521501775_item	3155274	et	4	main
uudiste	doc_491521501775_item	3155275	et	3	main
pealkirjad	doc_491521501775_item	3155276	et	3	main
asuvad	doc_491521501775_item	3155277	et	4	main
ajalehe	doc_491521501775_item	3155278	et	3	main
päismiku	doc_491521501775_item	3155279	et	3	main
kohal	doc_491521501775_item	3155280	et	4	main
et	doc_491521501775_item	3155281	et	3	main
võib	doc_491521501775_item	3155290	et	3	main
minu	doc_491521501775_item	3155294	et	3	main
väga	doc_491521501775_item	3155298	et	3	main
esilehele	doc_491521501775_item	3155323	et	4	main
ning	doc_491521501775_item	3155324	et	3	main
paigutatud	doc_491521501775_item	3155336	et	4	main
kolmandal	doc_491521501775_item	3155337	et	3	main
paigutama	doc_491521501775_item	3155347	et	3	main
arust	doc_491521501775_item	3155352	et	4	main
teine	doc_491521501775_item	3155354	et	3	main
on	doc_491521501775_item	3155356	et	4	main
muud	doc_491521501775_item	3155362	et	4	main
arvates	doc_491521501775_item	3155372	et	4	main
näiteks	doc_491521501775_item	3155382	et	4	main
lk	doc_491521501775_item	3155388	et	4	main
kuulub	doc_491521501775_item	3155391	et	3	main
hulka	doc_491521501775_item	3155394	et	4	main
paigutada	doc_491521501775_item	3155395	et	3	main
teisele	doc_491521501775_item	3155396	et	4	main
lehele	doc_491521501775_item	3155397	et	3	main
ajalehe	doc_491521501775_item	3155398	et	3	main
neljandal	doc_491521501775_item	3155399	et	3	main
leheküljel	doc_491521501775_item	3155400	et	3	main
võib	doc_491521501775_item	3155401	et	3	main
leida	doc_491521501775_item	3155402	et	3	main
naistelehte	doc_491521501775_item	3155403	et	4	main
kohas	doc_491521501775_item	3155454	et	4	main
asuda	doc_491521501775_item	3155457	et	3	main
näiteks	doc_491521501775_item	3155458	et	4	main
ka	doc_491521501775_item	3155459	et	3	main
koos	doc_491521501775_item	3155463	et	4	main
veerud	doc_491521501775_item	3155465	et	4	main
artikleid	doc_491521501775_item	3155467	et	3	main
aga	doc_491521501775_item	3155475	et	3	main
viie-	doc_491521501775_item	3155479	et	3	main
mis	doc_491521501775_item	3155488	et	4	main
eriti	doc_491521501775_item	3155491	et	3	main
hea	doc_491521501775_item	3155493	et	4	main
on	doc_491521501775_item	3155496	et	4	main
vahelpealkirjad	doc_491521501775_item	3155513	et	4	main
nt	doc_491521501775_item	3155524	et	4	main
trükitud	doc_491521501775_item	3155530	et	4	main
arvates	doc_491521501775_item	3155533	et	4	main
sobib	doc_491521501775_item	3155535	et	3	main
ja	doc_491521501775_item	3155538	et	3	main
arvan	doc_491521501775_item	3155542	et	3	main
juhtlõigud	doc_491521501775_item	3155545	et	3	main
on	doc_491521501775_item	3155560	et	4	main
mis	doc_491521501775_item	3155575	et	4	main
on	doc_491521501775_item	3155576	et	4	main
ei	doc_491521501775_item	3155581	et	4	main
sisaldavad	doc_491521501775_item	3155586	et	4	main
verbi	doc_491521501775_item	3155588	et	4	main
ja	doc_491521501775_item	3155589	et	3	main
on	doc_491521501775_item	3155590	et	4	main
arusaadavad	doc_491521501775_item	3155591	et	3	main
ja	doc_491521501775_item	3155592	et	3	main
erinevad	doc_491521501775_item	3155621	et	4	main
kui	doc_491521501775_item	3155622	et	3	main
pealkirjad	doc_491521501775_item	3155624	et	3	main
sihilist	doc_491521501775_item	3155626	et	4	main
verbi	doc_491521501775_item	3155627	et	4	main
veerud	doc_491521501775_item	3155270	et	4	main
lugeja	doc_491521501775_item	3155282	et	4	main
saaks	doc_491521501775_item	3155283	et	3	main
kiiresti	doc_491521501775_item	3155284	et	3	main
teda	doc_491521501775_item	3155285	et	4	main
huvitavat	doc_491521501775_item	3155286	et	4	main
uudist	doc_491521501775_item	3155287	et	3	main
leida	doc_491521501775_item	3155288	et	3	main
arust	doc_491521501775_item	3155295	et	4	main
see	doc_491521501775_item	3155297	et	3	main
kui	doc_491521501775_item	3155301	et	3	main
näiteks	doc_491521501775_item	3155302	et	4	main
inimestel	doc_491521501775_item	3155303	et	3	main
on	doc_491521501775_item	3155304	et	4	main
kiire	doc_491521501775_item	3155305	et	4	main
aga	doc_491521501775_item	3155306	et	3	main
nad	doc_491521501775_item	3155307	et	3	main
tahavad	doc_491521501775_item	3155308	et	3	main
ilmateadet	doc_491521501775_item	3155309	et	4	main
kiiresti	doc_491521501775_item	3155310	et	3	main
teada	doc_491521501775_item	3155311	et	3	main
siis	doc_491521501775_item	3155312	et	3	main
nad	doc_491521501775_item	3155313	et	3	main
elanike	doc_491521501775_item	3155261	et	3	main
ning	doc_491521501775_item	3155263	et	3	main
esilehel	doc_491521501775_item	3155289	et	3	main
on	doc_491521501775_item	3155296	et	4	main
õige	doc_491521501775_item	3155299	et	4	main
sest	doc_491521501775_item	3155300	et	4	main
seda	doc_491521501775_item	3155316	et	3	main
ajalehe	doc_491521501775_item	3155318	et	3	main
otsima	doc_491521501775_item	3155320	et	4	main
vaid	doc_491521501775_item	3155321	et	3	main
vaatavad	doc_491521501775_item	3155322	et	4	main
vajalikku	doc_491521501775_item	3155326	et	4	main
samuti	doc_491521501775_item	3155329	et	3	main
et	doc_491521501775_item	3155332	et	3	main
reegli	doc_491521501775_item	3155342	et	3	main
olulisem	doc_491521501775_item	3155345	et	4	main
minu	doc_491521501775_item	3155351	et	3	main
kujundatud	doc_491521501775_item	3155358	et	4	main
sest	doc_491521501775_item	3155359	et	4	main
kuskil	doc_491521501775_item	3155317	et	3	main
saavad	doc_491521501775_item	3155325	et	4	main
on	doc_491521501775_item	3155328	et	4	main
väga	doc_491521501775_item	3155330	et	3	main
olulised	doc_491521501775_item	3155333	et	4	main
linnauudised	doc_491521501775_item	3155334	et	3	main
on	doc_491521501775_item	3155335	et	4	main
peab	doc_491521501775_item	3155344	et	4	main
just	doc_491521501775_item	3155348	et	3	main
lehel	doc_491521501775_item	3155350	et	3	main
lehekülg	doc_491521501775_item	3155355	et	3	main
halvasti	doc_491521501775_item	3155357	et	3	main
ja	doc_491521501775_item	3155361	et	3	main
artiklid	doc_491521501775_item	3155363	et	3	main
ei	doc_491521501775_item	3155365	et	4	main
kuulu	doc_491521501775_item	3155366	et	4	main
spordisse	doc_491521501775_item	3155367	et	3	main
panna	doc_491521501775_item	3155378	et	4	main
ajalehe	doc_491521501775_item	3155379	et	3	main
vt	doc_491521501775_item	3155387	et	4	main
ka	doc_491521501775_item	3155392	et	3	main
kujundatud	doc_491521501775_item	3155412	et	4	main
on	doc_491521501775_item	3155414	et	4	main
rohkem	doc_491521501775_item	3155415	et	4	main
kuulutustega	doc_491521501775_item	3155464	et	4	main
kuueveerulises	doc_491521501775_item	3155483	et	4	main
ei	doc_491521501775_item	3155489	et	4	main
ole	doc_491521501775_item	3155490	et	4	main
lugemiseks	doc_491521501775_item	3155492	et	4	main
veerud	doc_491521501775_item	3155495	et	4	main
lühikised	doc_491521501775_item	3155497	et	4	main
mis	doc_491521501775_item	3155498	et	4	main
teeb	doc_491521501775_item	3155499	et	3	main
ka	doc_491521501775_item	3155500	et	3	main
antiikvakirjas	doc_491521501775_item	3155508	et	4	main
aga	doc_491521501775_item	3155509	et	3	main
olemas	doc_491521501775_item	3155521	et	4	main
mõned	doc_491521501775_item	3155522	et	3	main
võõrsõnad	doc_491521501775_item	3155523	et	3	main
on	doc_491521501775_item	3155529	et	4	main
on	doc_491521501775_item	3155373	et	4	main
mõistlikum	doc_491521501775_item	3155374	et	4	main
kultuursündmused	doc_491521501775_item	3155375	et	3	main
sealhulgas	doc_491521501775_item	3155376	et	3	main
spordisündmused	doc_491521501775_item	3155377	et	3	main
8	doc_491521501775_item	3155389	et	2	main
mis	doc_491521501775_item	3155390	et	4	main
linnasündmuste	doc_491521501775_item	3155393	et	3	main
on	doc_491521501775_item	3155405	et	4	main
tundus	doc_491521501775_item	3155408	et	3	main
teksti	doc_491521501775_item	3155418	et	4	main
kui	doc_491521501775_item	3155419	et	3	main
arvestada	doc_491521501775_item	3155420	et	3	main
reegel	doc_491521501775_item	3155421	et	3	main
et	doc_491521501775_item	3155422	et	3	main
reklaami	doc_491521501775_item	3155423	et	4	main
ja	doc_491521501775_item	3155424	et	3	main
artikleid	doc_491521501775_item	3155425	et	3	main
ei	doc_491521501775_item	3155426	et	4	main
koondata	doc_491521501775_item	3155427	et	3	main
ühte	doc_491521501775_item	3155428	et	4	main
kohta	doc_491521501775_item	3155429	et	4	main
kokku	doc_491521501775_item	3155430	et	3	main
siis	doc_491521501775_item	3155431	et	3	main
on	doc_491521501775_item	3155432	et	4	main
mõistlikum	doc_491521501775_item	3155433	et	4	main
seda	doc_491521501775_item	3155434	et	3	main
lehte	doc_491521501775_item	3155435	et	4	main
panna	doc_491521501775_item	3155436	et	4	main
ajalehe	doc_491521501775_item	3155437	et	3	main
lõppu	doc_491521501775_item	3155438	et	4	main
ajalehe	doc_491521501775_item	3155439	et	3	main
viimasel	doc_491521501775_item	3155440	et	3	main
lehel	doc_491521501775_item	3155441	et	3	main
asuvad	doc_491521501775_item	3155442	et	4	main
mõned	doc_491521501775_item	3155443	et	3	main
väikesed	doc_491521501775_item	3155444	et	4	main
ajalooartiklid	doc_491521501775_item	3155445	et	3	main
ja	doc_491521501775_item	3155446	et	3	main
statistika	doc_491521501775_item	3155447	et	4	main
tabel	doc_491521501775_item	3155448	et	3	main
mis	doc_491521501775_item	3155449	et	4	main
minu	doc_491521501775_item	3155450	et	3	main
need	doc_491521501775_item	3155455	et	3	main
võiksid	doc_491521501775_item	3155456	et	4	main
kultuurosakonnas	doc_491521501775_item	3155460	et	4	main
on	doc_491521501775_item	3155468	et	4	main
esitatud	doc_491521501775_item	3155469	et	4	main
ajalehes	doc_491521501775_item	3155470	et	3	main
ja	doc_491521501775_item	3155480	et	3	main
kujundatud	doc_491521501775_item	3155486	et	4	main
keerukamaks	doc_491521501775_item	3155502	et	4	main
trükikiri	doc_491521501775_item	3155503	et	3	main
põhitekstid	doc_491521501775_item	3155504	et	3	main
plokk	doc_491521501775_item	3155517	et	3	main
play-off	doc_491521501775_item	3155527	et	4	main
mis	doc_491521501775_item	3155528	et	4	main
minu	doc_491521501775_item	3155532	et	3	main
kiri	doc_491521501775_item	3155534	et	3	main
ajalehe	doc_491521501775_item	3155536	et	3	main
kirjas	doc_491521501775_item	3155563	et	4	main
vormistatud	doc_491521501775_item	3155566	et	4	main
ajalehe	doc_491521501775_item	3155569	et	3	main
põhimõtteliselt	doc_491521501775_item	3155577	et	4	main
sõna	doc_491521501775_item	3155584	et	4	main
intrigeerivad	doc_491521501775_item	3155594	et	4	main
pealkirjade	doc_491521501775_item	3155595	et	3	main
loo	doc_491521501775_item	3155599	et	4	main
pealkirjadest	doc_491521501775_item	3155619	et	3	main
peamised	doc_491521501775_item	3155623	et	3	main
sisaldavad	doc_491521501775_item	3155625	et	4	main
mõnede	doc_491521501775_item	3155637	et	3	main
leheküljel	doc_491521501775_item	3155643	et	3	main
veeru	doc_491521501775_item	3155645	et	4	main
on	doc_491521501775_item	3155657	et	4	main
et	doc_491521501775_item	3155659	et	3	main
vahelpealkirja	doc_491521501775_item	3155660	et	4	main
kuuendal	doc_491521501775_item	3155671	et	3	main
ainult	doc_491521501775_item	3155684	et	4	main
neli	doc_491521501775_item	3155685	et	3	main
natuke	doc_491521501775_item	3155695	et	4	main
häirib	doc_491521501775_item	3155696	et	3	main
näiteks	doc_491521501775_item	3155709	et	4	main
politseikroonika	doc_491521501775_item	3155710	et	4	main
on	doc_491521501775_item	3155711	et	4	main
pöördkirjas	doc_491521501775_item	3155712	et	3	main
minu	doc_491521501775_item	3155713	et	3	main
hea	doc_491521501775_item	3155717	et	4	main
politseikroonika	doc_491521501775_item	3155719	et	4	main
on	doc_491521501775_item	3155720	et	4	main
esitatud	doc_491521501775_item	3155764	et	4	main
palju	doc_491521501775_item	3155773	et	4	main
fotosid	doc_491521501775_item	3155774	et	3	main
olemas	doc_491521501775_item	3155782	et	4	main
üks	doc_491521501775_item	3155783	et	3	main
suur	doc_491521501775_item	3155784	et	3	main
mis	doc_491521501775_item	3155798	et	4	main
aga	doc_491521501775_item	3155802	et	3	main
poolt	doc_491521501775_item	3155804	et	4	main
foto	doc_491521501775_item	3155805	et	4	main
keelatud	doc_491521501775_item	3155818	et	4	main
teha	doc_491521501775_item	3155819	et	3	main
ruumi	doc_491521501775_item	3155860	et	4	main
fotot	doc_491521501775_item	3155863	et	3	main
natuke	doc_491521501775_item	3155865	et	4	main
väiksemaks	doc_491521501775_item	3155866	et	4	main
teha	doc_491521501775_item	3155867	et	3	main
kolmandal	doc_491521501775_item	3155879	et	3	main
väga	doc_491521501775_item	3155886	et	3	main
arusaadavad	doc_491521501775_item	3155896	et	3	main
pandud	doc_491521501775_item	3155905	et	4	main
ja	doc_491521501775_item	3155937	et	3	main
kasutatud	doc_491521501775_item	3155943	et	4	main
silmad	doc_491521501775_item	3155952	et	4	main
kui	doc_491521501775_item	3155955	et	3	main
artikkel	doc_491521501775_item	3155961	et	3	main
meelelahutuseks	doc_491521501775_item	3155964	et	4	main
artiklis	doc_491521501775_item	3155971	et	3	main
kirjatatud	doc_491521501775_item	3155981	et	4	main
juba	doc_491521501775_item	3155982	et	3	main
stiilis	doc_491521501775_item	3155984	et	4	main
päismik	doc_491521501775_item	3155987	et	4	main
näib	doc_491521501775_item	3155988	et	3	main
sõna	doc_491521501775_item	3155991	et	4	main
aga	doc_491521501775_item	3155461	et	3	main
kolme-	doc_491521501775_item	3155471	et	4	main
ja	doc_491521501775_item	3155472	et	3	main
neljaveerulises	doc_491521501775_item	3155473	et	4	main
formaadis	doc_491521501775_item	3155474	et	3	main
formaadis	doc_491521501775_item	3155484	et	3	main
on	doc_491521501775_item	3155485	et	4	main
lisaks	doc_491521501775_item	3155494	et	4	main
on	doc_491521501775_item	3155505	et	4	main
trükitud	doc_491521501775_item	3155506	et	4	main
ajalehes	doc_491521501775_item	3155507	et	3	main
ja	doc_491521501775_item	3155514	et	3	main
on	doc_491521501775_item	3155516	et	4	main
black	doc_491521501775_item	3155525	et	4	main
boxid	doc_491521501775_item	3155526	et	2	main
hästi	doc_491521501775_item	3155539	et	3	main
kuigi	doc_491521501775_item	3155541	et	3	main
artiklite	doc_491521501775_item	3155544	et	3	main
võiksid	doc_491521501775_item	3155546	et	4	main
ka	doc_491521501775_item	3155547	et	3	main
paksus	doc_491521501775_item	3155548	et	4	main
kirjas	doc_491521501775_item	3155549	et	4	main
olla	doc_491521501775_item	3155550	et	3	main
sest	doc_491521501775_item	3155551	et	4	main
neid	doc_491521501775_item	3155552	et	4	main
on	doc_491521501775_item	3155553	et	4	main
raske	doc_491521501775_item	3155554	et	4	main
põhitekstist	doc_491521501775_item	3155555	et	3	main
eristada	doc_491521501775_item	3155556	et	3	main
pealkirjad	doc_491521501775_item	3155557	et	3	main
ajalehe	doc_491521501775_item	3155558	et	3	main
pealkirjad	doc_491521501775_item	3155559	et	3	main
esitatud	doc_491521501775_item	3155561	et	4	main
üldiselt	doc_491521501775_item	3155565	et	4	main
õigesti	doc_491521501775_item	3155567	et	3	main
kaksiklehel	doc_491521501775_item	3155570	et	3	main
keelatud	doc_491521501775_item	3155578	et	4	main
ületa	doc_491521501775_item	3155582	et	4	main
need	doc_491521501775_item	3155585	et	3	main
sihilist	doc_491521501775_item	3155587	et	4	main
suurus	doc_491521501775_item	3155596	et	4	main
on	doc_491521501775_item	3155597	et	4	main
pikkusega	doc_491521501775_item	3155600	et	4	main
väga	doc_491521501775_item	3155620	et	3	main
koosnevad	doc_491521501775_item	3155630	et	4	main
vastupidi	doc_491521501775_item	3155631	et	3	main
ainult	doc_491521501775_item	3155632	et	4	main
nimisõnadest	doc_491521501775_item	3155633	et	3	main
ajalehes	doc_491521501775_item	3155634	et	3	main
võib	doc_491521501775_item	3155635	et	3	main
kohtuda	doc_491521501775_item	3155636	et	3	main
näiteks	doc_491521501775_item	3155640	et	4	main
ajalehe	doc_491521501775_item	3155641	et	3	main
esimese	doc_491521501775_item	3155644	et	3	main
peaks	doc_491521501775_item	3155664	et	4	main
teksti	doc_491521501775_item	3155669	et	4	main
viga	doc_491521501775_item	3155677	et	4	main
aga	doc_491521501775_item	3155678	et	3	main
nüüd	doc_491521501775_item	3155679	et	4	main
vahelpealkirja	doc_491521501775_item	3155681	et	4	main
pisiinfo	doc_491521501775_item	3155697	et	4	main
pisiinfot	doc_491521501775_item	3155702	et	3	main
neist	doc_491521501775_item	3155704	et	4	main
arust	doc_491521501775_item	3155714	et	4	main
lühike	doc_491521501775_item	3155760	et	4	main
on	doc_491521501775_item	3155763	et	4	main
paksus	doc_491521501775_item	3155767	et	4	main
ja	doc_491521501775_item	3155564	et	3	main
seitse	doc_491521501775_item	3155583	et	3	main
piisavalt	doc_491521501775_item	3155593	et	4	main
vastavuses	doc_491521501775_item	3155598	et	4	main
mida	doc_491521501775_item	3155601	et	4	main
tõsisem	doc_491521501775_item	3155602	et	4	main
ja	doc_491521501775_item	3155603	et	3	main
tähtsam	doc_491521501775_item	3155604	et	4	main
tekst	doc_491521501775_item	3155605	et	3	main
seda	doc_491521501775_item	3155606	et	3	main
suurem	doc_491521501775_item	3155607	et	4	main
pealkirja	doc_491521501775_item	3155608	et	4	main
suurus	doc_491521501775_item	3155609	et	4	main
vahelpealkirjad	doc_491521501775_item	3155610	et	4	main
vahelpealkirjad	doc_491521501775_item	3155611	et	4	main
asuvad	doc_491521501775_item	3155612	et	4	main
ajalehes	doc_491521501775_item	3155613	et	3	main
veeru	doc_491521501775_item	3155614	et	4	main
vasakul	doc_491521501775_item	3155615	et	4	main
pool	doc_491521501775_item	3155616	et	4	main
ning	doc_491521501775_item	3155617	et	3	main
peamistest	doc_491521501775_item	3155618	et	4	main
siis	doc_491521501775_item	3155628	et	3	main
reeglist	doc_491521501775_item	3155638	et	4	main
kaheksandal	doc_491521501775_item	3155642	et	3	main
allpool	doc_491521501775_item	3155646	et	3	main
on	doc_491521501775_item	3155647	et	4	main
vahelpealkirja	doc_491521501775_item	3155648	et	4	main
alla	doc_491521501775_item	3155649	et	3	main
teksti	doc_491521501775_item	3155653	et	4	main
kui	doc_491521501775_item	3155654	et	3	main
aga	doc_491521501775_item	3155655	et	3	main
öeldud	doc_491521501775_item	3155658	et	4	main
jäädud	doc_491521501775_item	3155650	et	4	main
reeglis	doc_491521501775_item	3155656	et	3	main
alla	doc_491521501775_item	3155663	et	3	main
jääma	doc_491521501775_item	3155665	et	4	main
kuus	doc_491521501775_item	3155667	et	4	main
rida	doc_491521501775_item	3155668	et	4	main
veerus	doc_491521501775_item	3155674	et	4	main
on	doc_491521501775_item	3155680	et	4	main
teksti	doc_491521501775_item	3155687	et	4	main
on	doc_491521501775_item	3155688	et	4	main
mis	doc_491521501775_item	3155693	et	4	main
ajalehes	doc_491521501775_item	3155698	et	3	main
kuid	doc_491521501775_item	3155708	et	4	main
trükitud	doc_491521501775_item	3155721	et	4	main
just	doc_491521501775_item	3155722	et	3	main
pöördkirjas	doc_491521501775_item	3155723	et	3	main
esiteks	doc_491521501775_item	3155724	et	3	main
pöördkiri	doc_491521501775_item	3155725	et	3	main
tõmbab	doc_491521501775_item	3155726	et	3	main
rida	doc_491521501775_item	3155652	et	4	main
ja	doc_491521501775_item	3155662	et	3	main
vähemalt	doc_491521501775_item	3155666	et	4	main
ajalehe	doc_491521501775_item	3155670	et	3	main
leheküljel	doc_491521501775_item	3155672	et	3	main
jäädud	doc_491521501775_item	3155683	et	4	main
rida	doc_491521501775_item	3155686	et	4	main
palju	doc_491521501775_item	3155690	et	4	main
ajalehes	doc_491521501775_item	3155691	et	3	main
võib	doc_491521501775_item	3155699	et	3	main
mitu	doc_491521501775_item	3155701	et	4	main
paljud	doc_491521501775_item	3155703	et	3	main
on	doc_491521501775_item	3155705	et	4	main
esitatud	doc_491521501775_item	3155706	et	4	main
rasteris	doc_491521501775_item	3155707	et	3	main
väga	doc_491521501775_item	3155716	et	3	main
et	doc_491521501775_item	3155718	et	3	main
rasteris	doc_491521501775_item	3155765	et	3	main
näiteks	doc_491521501775_item	3155779	et	4	main
esileheküljel	doc_491521501775_item	3155780	et	3	main
on	doc_491521501775_item	3155781	et	4	main
foto	doc_491521501775_item	3155788	et	4	main
on	doc_491521501775_item	3155789	et	4	main
olukorras	doc_491521501775_item	3155797	et	3	main
huvitavamaks	doc_491521501775_item	3155801	et	4	main
teiselt	doc_491521501775_item	3155803	et	4	main
ära	doc_491521501775_item	3155808	et	4	main
lõigatud	doc_491521501775_item	3155815	et	4	main
mis	doc_491521501775_item	3155816	et	4	main
tundub	doc_491521501775_item	3155822	et	3	main
kohale	doc_491521501775_item	3155661	et	4	main
teises	doc_491521501775_item	3155673	et	4	main
on	doc_491521501775_item	3155675	et	4	main
sama	doc_491521501775_item	3155676	et	4	main
kohale	doc_491521501775_item	3155682	et	4	main
samuti	doc_491521501775_item	3155689	et	3	main
leskridu	doc_491521501775_item	3155692	et	3	main
ka	doc_491521501775_item	3155694	et	3	main
leida	doc_491521501775_item	3155700	et	3	main
on	doc_491521501775_item	3155715	et	4	main
kohe	doc_491521501775_item	3155727	et	4	main
lugeja	doc_491521501775_item	3155728	et	4	main
tähelepanu	doc_491521501775_item	3155729	et	4	main
aga	doc_491521501775_item	3155730	et	3	main
teiseks	doc_491521501775_item	3155731	et	4	main
annab	doc_491521501775_item	3155732	et	3	main
teada	doc_491521501775_item	3155733	et	3	main
et	doc_491521501775_item	3155734	et	3	main
tegemist	doc_491521501775_item	3155735	et	4	main
on	doc_491521501775_item	3155736	et	4	main
tõsise	doc_491521501775_item	3155737	et	4	main
infoga	doc_491521501775_item	3155738	et	3	main
ajalehes	doc_491521501775_item	3155739	et	3	main
on	doc_491521501775_item	3155740	et	4	main
olemas	doc_491521501775_item	3155741	et	4	main
kaksikleht	doc_491521501775_item	3155742	et	3	main
millel	doc_491521501775_item	3155743	et	3	main
on	doc_491521501775_item	3155744	et	4	main
paigutatud	doc_491521501775_item	3155745	et	4	main
reportaaž	doc_491521501775_item	3155746	et	2	main
reportaaž	doc_491521501775_item	3155747	et	2	main
sisaldab	doc_491521501775_item	3155748	et	3	main
ka	doc_491521501775_item	3155749	et	3	main
pisiinfot	doc_491521501775_item	3155750	et	3	main
üks	doc_491521501775_item	3155751	et	3	main
on	doc_491521501775_item	3155752	et	4	main
euroopa	doc_491521501775_item	3155753	et	4	main
parlamendi	doc_491521501775_item	3155754	et	3	main
statistika	doc_491521501775_item	3155755	et	4	main
ning	doc_491521501775_item	3155756	et	3	main
teine	doc_491521501775_item	3155757	et	3	main
on	doc_491521501775_item	3155758	et	4	main
lihtsalt	doc_491521501775_item	3155759	et	4	main
need	doc_491521501775_item	3155762	et	3	main
ja	doc_491521501775_item	3155766	et	3	main
kirjas	doc_491521501775_item	3155768	et	4	main
fotod	doc_491521501775_item	3155769	et	3	main
ajalehes	doc_491521501775_item	3155770	et	3	main
on	doc_491521501775_item	3155771	et	4	main
tehtud	doc_491521501775_item	3155790	et	4	main
esileht	doc_491521501775_item	3155800	et	3	main
ära	doc_491521501775_item	3155814	et	4	main
liiga	doc_491521501775_item	3155820	et	4	main
ülevaade	doc_491521501775_item	3155761	et	3	main
päris	doc_491521501775_item	3155772	et	4	main
draamatilises	doc_491521501775_item	3155796	et	4	main
on	doc_491521501775_item	3155806	et	4	main
mulle	doc_491521501775_item	3155823	et	4	main
spordifoto	doc_491521501775_item	3155824	et	4	main
sest	doc_491521501775_item	3155825	et	4	main
see	doc_491521501775_item	3155826	et	3	main
on	doc_491521501775_item	3155827	et	4	main
rohkem	doc_491521501775_item	3155828	et	4	main
stampfoto	doc_491521501775_item	3155829	et	4	main
staatiline	doc_491521501775_item	3155830	et	3	main
ja	doc_491521501775_item	3155831	et	3	main
elutu	doc_491521501775_item	3155832	et	4	main
mis	doc_491521501775_item	3155833	et	4	main
ei	doc_491521501775_item	3155834	et	4	main
ole	doc_491521501775_item	3155835	et	4	main
spordiosakonnale	doc_491521501775_item	3155836	et	4	main
omane	doc_491521501775_item	3155837	et	3	main
kolmandal	doc_491521501775_item	3155838	et	3	main
leheküljel	doc_491521501775_item	3155839	et	3	main
vasakul	doc_491521501775_item	3155840	et	4	main
serval	doc_491521501775_item	3155841	et	3	main
on	doc_491521501775_item	3155842	et	4	main
olemas	doc_491521501775_item	3155843	et	4	main
väike	doc_491521501775_item	3155844	et	4	main
ajakirjaniku	doc_491521501775_item	3155845	et	3	main
foto	doc_491521501775_item	3155846	et	4	main
mis	doc_491521501775_item	3155847	et	4	main
on	doc_491521501775_item	3155848	et	4	main
nagu	doc_491521501775_item	3155849	et	3	main
mulle	doc_491521501775_item	3155850	et	4	main
tundus	doc_491521501775_item	3155851	et	3	main
ka	doc_491521501775_item	3155852	et	3	main
valesti	doc_491521501775_item	3155853	et	3	main
kujundatud	doc_491521501775_item	3155854	et	4	main
fotol	doc_491521501775_item	3155855	et	3	main
on	doc_491521501775_item	3155856	et	4	main
liiga	doc_491521501775_item	3155857	et	4	main
palju	doc_491521501775_item	3155858	et	4	main
tühja	doc_491521501775_item	3155859	et	4	main
seda	doc_491521501775_item	3155862	et	3	main
võiks	doc_491521501775_item	3155864	et	4	main
ajalehes	doc_491521501775_item	3155871	et	3	main
asjakohased	doc_491521501775_item	3155872	et	4	main
enamus	doc_491521501775_item	3155775	et	4	main
nendest	doc_491521501775_item	3155776	et	4	main
on	doc_491521501775_item	3155777	et	4	main
portreefotod	doc_491521501775_item	3155778	et	3	main
portreefoto	doc_491521501775_item	3155785	et	4	main
ühelt	doc_491521501775_item	3155786	et	3	main
poolt	doc_491521501775_item	3155787	et	4	main
spontaanselt	doc_491521501775_item	3155791	et	4	main
ning	doc_491521501775_item	3155792	et	3	main
isik	doc_491521501775_item	3155793	et	3	main
on	doc_491521501775_item	3155794	et	4	main
fotol	doc_491521501775_item	3155795	et	3	main
teeb	doc_491521501775_item	3155799	et	3	main
valesti	doc_491521501775_item	3155807	et	3	main
lõigatud	doc_491521501775_item	3155809	et	4	main
sest	doc_491521501775_item	3155810	et	4	main
isiku	doc_491521501775_item	3155811	et	3	main
juuksed	doc_491521501775_item	3155812	et	3	main
on	doc_491521501775_item	3155813	et	4	main
on	doc_491521501775_item	3155817	et	4	main
ning	doc_491521501775_item	3155861	et	3	main
visuaalselt	doc_491521501775_item	3155875	et	4	main
foto	doc_491521501775_item	3155884	et	4	main
on	doc_491521501775_item	3155893	et	4	main
ka	doc_491521501775_item	3155894	et	3	main
allkirja	doc_491521501775_item	3155907	et	4	main
artiklis	doc_491521501775_item	3155941	et	3	main
on	doc_491521501775_item	3155942	et	4	main
libedal	doc_491521501775_item	3155950	et	3	main
arvates	doc_491521501775_item	3155959	et	4	main
esitatud	doc_491521501775_item	3155972	et	4	main
sest	doc_491521501775_item	3155990	et	4	main
reportaaž	doc_491521501775_item	3155992	et	2	main
artiklid	doc_491521501775_item	3156008	et	3	main
kirjutatud	doc_491521501775_item	3156010	et	4	main
informatiivne	doc_491521501775_item	3156023	et	3	main
kuigi	doc_491521501775_item	3156035	et	3	main
igavana	doc_491521501775_item	3155821	et	4	main
üldiselt	doc_491521501775_item	3155868	et	4	main
fotod	doc_491521501775_item	3155869	et	3	main
seotud	doc_491521501775_item	3155876	et	4	main
mis	doc_491521501775_item	3155885	et	4	main
hästi	doc_491521501775_item	3155887	et	3	main
teksti	doc_491521501775_item	3155889	et	4	main
ning	doc_491521501775_item	3155897	et	3	main
all	doc_491521501775_item	3155908	et	3	main
pool	doc_491521501775_item	3155910	et	4	main
selles	doc_491521501775_item	3155940	et	4	main
jääl	doc_491521501775_item	3155951	et	3	main
suured	doc_491521501775_item	3155954	et	3	main
tõllarattad	doc_491521501775_item	3155956	et	3	main
minu	doc_491521501775_item	3155958	et	3	main
on	doc_491521501775_item	3155870	et	4	main
näiteks	doc_491521501775_item	3155877	et	4	main
on	doc_491521501775_item	3155881	et	4	main
piisavalt	doc_491521501775_item	3155895	et	4	main
põhjendavad	doc_491521501775_item	3155898	et	4	main
foto	doc_491521501775_item	3155906	et	4	main
paremal	doc_491521501775_item	3155909	et	4	main
ning	doc_491521501775_item	3155911	et	3	main
need	doc_491521501775_item	3155912	et	3	main
ei	doc_491521501775_item	3155913	et	4	main
lähe	doc_491521501775_item	3155914	et	4	main
segi	doc_491521501775_item	3155915	et	3	main
keelekasutus	doc_491521501775_item	3155916	et	4	main
artiklid	doc_491521501775_item	3155917	et	3	main
on	doc_491521501775_item	3155918	et	4	main
kirjatatud	doc_491521501775_item	3155919	et	4	main
piisavalt	doc_491521501775_item	3155920	et	4	main
arusaadavas	doc_491521501775_item	3155921	et	3	main
ja	doc_491521501775_item	3155922	et	3	main
jõukohases	doc_491521501775_item	3155923	et	4	main
keeles	doc_491521501775_item	3155924	et	4	main
kuigi	doc_491521501775_item	3155925	et	3	main
artikkel	doc_491521501775_item	3155926	et	3	main
miks	doc_491521501775_item	3155927	et	4	main
reporter	doc_491521501775_item	3155928	et	3	main
brüsselis	doc_491521501775_item	3155929	et	4	main
sugu	doc_491521501775_item	3155930	et	4	main
muutis	doc_491521501775_item	3155931	et	3	main
on	doc_491521501775_item	3155932	et	4	main
kirjutatud	doc_491521501775_item	3155933	et	4	main
rohkem	doc_491521501775_item	3155934	et	4	main
informaalses	doc_491521501775_item	3155935	et	4	main
stiilis	doc_491521501775_item	3155936	et	4	main
ning	doc_491521501775_item	3155873	et	3	main
tekstiga	doc_491521501775_item	3155874	et	3	main
ajalehe	doc_491521501775_item	3155878	et	3	main
leheküljel	doc_491521501775_item	3155880	et	3	main
päris	doc_491521501775_item	3155882	et	4	main
hea	doc_491521501775_item	3155883	et	4	main
illustreerib	doc_491521501775_item	3155888	et	3	main
sisu	doc_491521501775_item	3155890	et	4	main
foto	doc_491521501775_item	3155891	et	4	main
allkirjad	doc_491521501775_item	3155892	et	3	main
mis	doc_491521501775_item	3155899	et	4	main
toimub	doc_491521501775_item	3155900	et	3	main
fotol	doc_491521501775_item	3155901	et	3	main
fotograafi	doc_491521501775_item	3155902	et	4	main
nimi	doc_491521501775_item	3155903	et	3	main
on	doc_491521501775_item	3155904	et	4	main
isegi	doc_491521501775_item	3155938	et	4	main
palju	doc_491521501775_item	3155944	et	4	main
kõnekeelseid	doc_491521501775_item	3155945	et	3	main
väljendeid	doc_491521501775_item	3155946	et	3	main
näiteks	doc_491521501775_item	3155947	et	4	main
nagu	doc_491521501775_item	3155948	et	3	main
lehm	doc_491521501775_item	3155949	et	3	main
on	doc_491521501775_item	3155953	et	4	main
jpt	doc_491521501775_item	3155957	et	4	main
see	doc_491521501775_item	3155960	et	3	main
on	doc_491521501775_item	3155962	et	4	main
lugu	doc_491521501775_item	3155969	et	4	main
on	doc_491521501775_item	3155980	et	4	main
lõpus	doc_491521501775_item	3155996	et	4	main
ülejäänud	doc_491521501775_item	3156006	et	4	main
teataja	doc_491521501775_item	3156020	et	4	main
informatsiooni	doc_491521501775_item	3156027	et	4	main
naljakalt	doc_491521501775_item	3155939	et	4	main
rohkem	doc_491521501775_item	3155963	et	4	main
kui	doc_491521501775_item	3155965	et	3	main
mingi	doc_491521501775_item	3155966	et	4	main
pisiinfo	doc_491521501775_item	3155973	et	4	main
tõsiseid	doc_491521501775_item	3155975	et	4	main
formaalses	doc_491521501775_item	3155983	et	3	main
kaksiklehekülje	doc_491521501775_item	3155986	et	3	main
kummalisena	doc_491521501775_item	3155989	et	3	main
et	doc_491521501775_item	3155999	et	3	main
ajalehe	doc_491521501775_item	3156000	et	3	main
ajalehe	doc_491521501775_item	3156007	et	3	main
formaalses	doc_491521501775_item	3156011	et	3	main
on	doc_491521501775_item	3156021	et	4	main
piisavalt	doc_491521501775_item	3156026	et	4	main
nii	doc_491521501775_item	3156028	et	3	main
ka	doc_491521501775_item	3156032	et	3	main
eestist	doc_491521501775_item	3156034	et	3	main
tõsine	doc_491521501775_item	3155967	et	4	main
poliitiline	doc_491521501775_item	3155968	et	3	main
kuigi	doc_491521501775_item	3155970	et	3	main
sisaldab	doc_491521501775_item	3155974	et	3	main
ja	doc_491521501775_item	3155976	et	3	main
huvitavaid	doc_491521501775_item	3155977	et	4	main
andmeid	doc_491521501775_item	3155978	et	3	main
mis	doc_491521501775_item	3155979	et	4	main
samuti	doc_491521501775_item	3155985	et	3	main
reportaazh	doc_491521501775_item	3155997	et	4	main
arvan	doc_491521501775_item	3155998	et	3	main
küljendaja	doc_491521501775_item	3156001	et	4	main
võis	doc_491521501775_item	3156002	et	4	main
leida	doc_491521501775_item	3156003	et	3	main
ž	doc_491521501775_item	3156004	et	2	main
tähte	doc_491521501775_item	3156005	et	4	main
on	doc_491521501775_item	3156009	et	4	main
kirjakeeles	doc_491521501775_item	3156012	et	4	main
kokkuvõte	doc_491521501775_item	3156013	et	3	main
kokkuvõttes	doc_491521501775_item	3156014	et	3	main
tahaksin	doc_491521501775_item	3156015	et	3	main
öelda	doc_491521501775_item	3156016	et	4	main
et	doc_491521501775_item	3156017	et	3	main
ajaleht	doc_491521501775_item	3156018	et	3	main
ajaleht	doc_491521501775_item	3156024	et	3	main
kogu	doc_491521501775_item	3156033	et	4	main
arvan	doc_491521501775_item	3156036	et	3	main
et	doc_491521501775_item	3156037	et	3	main
ajalehe	doc_491521501775_item	3156038	et	3	main
küljendajad	doc_491521501775_item	3156039	et	4	main
võiksid	doc_491521501775_item	3156040	et	4	main
mõndasid	doc_491521501775_item	3156041	et	4	main
muudatusi	doc_491521501775_item	3156042	et	3	main
ajalehe	doc_491521501775_item	3156043	et	3	main
kujunduses	doc_491521501775_item	3156044	et	4	main
teha	doc_491521501775_item	3156045	et	3	main
on	doc_491521501775_item	3155993	et	4	main
trükitud	doc_491521501775_item	3155994	et	4	main
h-ga	doc_491521501775_item	3155995	et	3	main
virumaa	doc_491521501775_item	3156019	et	4	main
piisavalt	doc_491521501775_item	3156022	et	4	main
sisaldab	doc_491521501775_item	3156025	et	3	main
oma	doc_491521501775_item	3156029	et	4	main
maast	doc_491521501775_item	3156030	et	3	main
kui	doc_491521501775_item	3156031	et	3	main
veaanalüüs	doc_491521501781_item	3221493	et	4	main
sõnajärjed	doc_491521501781_item	3221495	et	3	main
sündmused	doc_491521501781_item	3221498	et	3	main
ajal	doc_491521501781_item	3221503	et	4	main
tekkisid	doc_491521501781_item	3221516	et	4	main
reformatsiooni	doc_491521501781_item	3221517	et	4	main
tagajärjena	doc_491521501781_item	3221518	et	3	main
hakkasid	doc_491521501781_item	3221519	et	4	main
domineerima	doc_491521501781_item	3221520	et	3	main
vale	doc_491521501781_item	3221534	et	4	main
käändevalik	doc_491521501781_item	3221535	et	4	main
reformatsiooni	doc_491521501781_item	3221539	et	4	main
lause	doc_491521501781_item	3221541	et	4	main
keegi	doc_491521501781_item	3221549	et	4	main
osa	doc_491521501781_item	3221596	et	4	main
kahe	doc_491521501781_item	3221601	et	3	main
on	doc_491521501781_item	3221603	et	4	main
1568	doc_491521501781_item	3221606	et	2	main
ilmus	doc_491521501781_item	3221610	et	4	main
ilmus	doc_491521501781_item	3221617	et	4	main
aasta	doc_491521501781_item	3221619	et	4	main
jooksul	doc_491521501781_item	3221620	et	4	main
18	doc_491521501781_item	3221621	et	2	main
õige	doc_491521501781_item	3221630	et	4	main
tagasi	doc_491521501781_item	3221636	et	3	main
jaoks	doc_491521501781_item	3221646	et	4	main
on	doc_491521501781_item	3221647	et	4	main
kasutama	doc_491521501781_item	3221654	et	3	main
ja	doc_491521501781_item	3221657	et	3	main
samal	doc_491521501781_item	3221502	et	3	main
rasked	doc_491521501781_item	3221506	et	3	main
toimusid	doc_491521501781_item	3221508	et	4	main
ajal	doc_491521501781_item	3221510	et	4	main
levikuga	doc_491521501781_item	3221512	et	3	main
need	doc_491521501781_item	3221513	et	3	main
kirikud	doc_491521501781_item	3221514	et	3	main
õige	doc_491521501781_item	3221521	et	4	main
reformatsiooni	doc_491521501781_item	3221529	et	4	main
suured	doc_491521501781_item	3221536	et	3	main
ei	doc_491521501781_item	3221550	et	4	main
õige	doc_491521501781_item	3221554	et	4	main
protestantide	doc_491521501781_item	3221556	et	3	main
keegi	doc_491521501781_item	3221559	et	4	main
ei	doc_491521501781_item	3221560	et	4	main
katoliiklased	doc_491521501781_item	3221593	et	3	main
enam	doc_491521501781_item	3221595	et	4	main
võtta	doc_491521501781_item	3221597	et	3	main
transsilvaania	doc_491521501781_item	3221600	et	4	main
ss-ga	doc_491521501781_item	3221602	et	3	main
õigekirjaviga	doc_491521501781_item	3221604	et	4	main
aastal	doc_491521501781_item	3221605	et	3	main
õige	doc_491521501781_item	3221613	et	4	main
lause	doc_491521501781_item	3221614	et	4	main
aastal	doc_491521501781_item	3221615	et	3	main
1568	doc_491521501781_item	3221616	et	2	main
oma	doc_491521501781_item	3221628	et	4	main
said	doc_491521501781_item	3221635	et	4	main
religioonivabadust	doc_491521501781_item	3221639	et	4	main
vale	doc_491521501781_item	3221642	et	4	main
raske	doc_491521501781_item	3221648	et	4	main
on	doc_491521501781_item	3221661	et	4	main
saksa	doc_491521501781_item	3221666	et	4	main
lausesõnajärjest	doc_491521501781_item	3221667	et	4	main
morfoloogilised	doc_491521501781_item	3221668	et	4	main
põhjuseks	doc_491521501781_item	3221677	et	3	main
võib	doc_491521501781_item	3221678	et	3	main
olla	doc_491521501781_item	3221679	et	3	main
põhjus	doc_491521501781_item	3221699	et	4	main
langeb	doc_491521501781_item	3221700	et	3	main
levikuga	doc_491521501781_item	3221501	et	3	main
sündmused	doc_491521501781_item	3221507	et	3	main
samal	doc_491521501781_item	3221509	et	3	main
reformatsioni	doc_491521501781_item	3221511	et	4	main
mis	doc_491521501781_item	3221515	et	4	main
lause	doc_491521501781_item	3221522	et	4	main
tagajärjel	doc_491521501781_item	3221530	et	3	main
tagajärjena	doc_491521501781_item	3221531	et	3	main
on	doc_491521501781_item	3221532	et	4	main
isiksused	doc_491521501781_item	3221537	et	3	main
seast	doc_491521501781_item	3221547	et	4	main
mitte	doc_491521501781_item	3221548	et	3	main
hulga	doc_491521501781_item	3221553	et	4	main
seast	doc_491521501781_item	3221557	et	4	main
mitte	doc_491521501781_item	3221558	et	3	main
ühe	doc_491521501781_item	3221607	et	4	main
aasta	doc_491521501781_item	3221608	et	4	main
1581	doc_491521501781_item	3221625	et	2	main
said	doc_491521501781_item	3221626	et	4	main
tagasi	doc_491521501781_item	3221627	et	3	main
1581	doc_491521501781_item	3221634	et	2	main
käändevalik	doc_491521501781_item	3221643	et	4	main
põhjus	doc_491521501781_item	3221644	et	4	main
kindlaks	doc_491521501781_item	3221650	et	3	main
teha	doc_491521501781_item	3221651	et	3	main
omastavat	doc_491521501781_item	3221655	et	4	main
käänet	doc_491521501781_item	3221656	et	3	main
millal	doc_491521501781_item	3221658	et	3	main
enamasti	doc_491521501781_item	3221662	et	4	main
põhjustatud	doc_491521501781_item	3221663	et	4	main
talupoegadele	doc_491521501781_item	3221672	et	3	main
astmevahelduslik	doc_491521501781_item	3221675	et	4	main
et	doc_491521501781_item	3221681	et	3	main
tähtsus	doc_491521501781_item	3221694	et	4	main
eelnevaga	doc_491521501781_item	3221702	et	4	main
teadmisi	doc_491521501781_item	3221703	et	4	main
vormist	doc_491521501781_item	3221711	et	4	main
omastavast	doc_491521501781_item	3221719	et	4	main
m-i	doc_491521501781_item	3221726	et	4	main
sõna	doc_491521501781_item	3221729	et	4	main
ära	doc_491521501781_item	3221732	et	4	main
õpitud	doc_491521501781_item	3221733	et	4	main
väitnud	doc_491521501781_item	3221738	et	4	main
reformatoorite	doc_491521501781_item	3221745	et	4	main
või	doc_491521501781_item	3221756	et	4	main
kasutatud	doc_491521501781_item	3221757	et	4	main
õige	doc_491521501781_item	3221761	et	4	main
mõnevõrra	doc_491521501781_item	3221767	et	3	main
religioosne	doc_491521501781_item	3221770	et	3	main
vahetada	doc_491521501781_item	3221793	et	3	main
vahendada	doc_491521501781_item	3221796	et	3	main
käänes	doc_491521501781_item	3221810	et	3	main
rumeenialased	doc_491521501781_item	3221813	et	4	main
laule	doc_491521501781_item	3221825	et	4	main
mitmuse	doc_491521501781_item	3221826	et	3	main
välja	doc_491521501781_item	3221838	et	4	main
õigust	doc_491521501781_item	3221839	et	4	main
vabadust	doc_491521501781_item	3221852	et	4	main
sätestati	doc_491521501781_item	3221854	et	3	main
nad	doc_491521501781_item	3221894	et	3	main
kuidas	doc_491521501781_item	3221899	et	3	main
katoliiklased	doc_491521501781_item	3221900	et	3	main
õige	doc_491521501781_item	3221906	et	4	main
kuidas	doc_491521501781_item	3221907	et	3	main
katoliiklased	doc_491521501781_item	3221908	et	3	main
osastav	doc_491521501781_item	3221922	et	4	main
kääne	doc_491521501781_item	3221923	et	3	main
ungarisse	doc_491521501781_item	3221927	et	4	main
piiblid	doc_491521501781_item	3221928	et	3	main
õpikud	doc_491521501781_item	3221929	et	3	main
mõnda	doc_491521501781_item	3221930	et	4	main
reformatsiooni	doc_491521501781_item	3221500	et	4	main
lause	doc_491521501781_item	3221505	et	4	main
hakkasid	doc_491521501781_item	3221523	et	4	main
domineerima	doc_491521501781_item	3221524	et	3	main
objektiviga	doc_491521501781_item	3221533	et	4	main
reformatsiooni	doc_491521501781_item	3221542	et	4	main
toetasid	doc_491521501781_item	3221543	et	4	main
suured	doc_491521501781_item	3221544	et	3	main
isiksused	doc_491521501781_item	3221545	et	3	main
protestantide	doc_491521501781_item	3221546	et	3	main
valitsejate	doc_491521501781_item	3221552	et	4	main
lause	doc_491521501781_item	3221555	et	4	main
valitsejate	doc_491521501781_item	3221562	et	4	main
aga	doc_491521501781_item	3221594	et	3	main
riigi	doc_491521501781_item	3221598	et	3	main
vaidluslehte	doc_491521501781_item	3221622	et	4	main
katoliiklased	doc_491521501781_item	3221623	et	3	main
aastal	doc_491521501781_item	3221624	et	3	main
lause	doc_491521501781_item	3221631	et	4	main
parandusi	doc_491521501781_item	3222301	et	4	main
lausepõhistruktuurivead	doc_491521501781_item	3221494	et	3	main
lauses	doc_491521501781_item	3221496	et	3	main
rasked	doc_491521501781_item	3221497	et	3	main
toimusid	doc_491521501781_item	3221499	et	4	main
õige	doc_491521501781_item	3221504	et	4	main
need	doc_491521501781_item	3221525	et	3	main
kirikud	doc_491521501781_item	3221526	et	3	main
mis	doc_491521501781_item	3221527	et	4	main
tekkisid	doc_491521501781_item	3221528	et	4	main
toetasid	doc_491521501781_item	3221538	et	4	main
õige	doc_491521501781_item	3221540	et	4	main
sattunud	doc_491521501781_item	3221551	et	4	main
sattunud	doc_491521501781_item	3221561	et	4	main
hulka	doc_491521501781_item	3221563	et	4	main
hulga	doc_491521501781_item	3221564	et	4	main
on	doc_491521501781_item	3221565	et	4	main
astmevahelduslik	doc_491521501781_item	3221566	et	4	main
viga	doc_491521501781_item	3221567	et	4	main
põhjuseks	doc_491521501781_item	3221568	et	3	main
saaks	doc_491521501781_item	3221569	et	3	main
olla	doc_491521501781_item	3221570	et	3	main
et	doc_491521501781_item	3221571	et	3	main
mitteeeslaste	doc_491521501781_item	3221572	et	4	main
jaoks	doc_491521501781_item	3221573	et	4	main
on	doc_491521501781_item	3221574	et	4	main
astmevaheldus	doc_491521501781_item	3221575	et	4	main
raske	doc_491521501781_item	3221577	et	4	main
väga	doc_491521501781_item	3221576	et	3	main
transsilvaanias	doc_491521501781_item	3221578	et	2	main
katoliiklased	doc_491521501781_item	3221579	et	3	main
aga	doc_491521501781_item	3221580	et	3	main
enam	doc_491521501781_item	3221581	et	4	main
ei	doc_491521501781_item	3221582	et	4	main
saanud	doc_491521501781_item	3221583	et	4	main
osa	doc_491521501781_item	3221584	et	4	main
võtta	doc_491521501781_item	3221585	et	3	main
riigi	doc_491521501781_item	3221586	et	3	main
valitsemisest	doc_491521501781_item	3221587	et	4	main
õige	doc_491521501781_item	3221588	et	4	main
lause	doc_491521501781_item	3221589	et	4	main
transilvaanias	doc_491521501781_item	3221590	et	4	main
ei	doc_491521501781_item	3221591	et	4	main
saanud	doc_491521501781_item	3221592	et	4	main
valitsemisest	doc_491521501781_item	3221599	et	4	main
jooksul	doc_491521501781_item	3221609	et	4	main
18	doc_491521501781_item	3221611	et	2	main
vaidluslehte	doc_491521501781_item	3221612	et	4	main
ühe	doc_491521501781_item	3221618	et	4	main
religioonivabadust	doc_491521501781_item	3221629	et	4	main
religioonivabaduse	doc_491521501781_item	3221638	et	4	main
alati	doc_491521501781_item	3221649	et	4	main
millal	doc_491521501781_item	3221652	et	3	main
lausesõnajärjevead	doc_491521501781_item	3221660	et	3	main
see	doc_491521501781_item	3221673	et	3	main
viga	doc_491521501781_item	3221676	et	4	main
mitmuse	doc_491521501781_item	3221682	et	3	main
omastava	doc_491521501781_item	3221683	et	4	main
käände	doc_491521501781_item	3221684	et	4	main
määramiseks	doc_491521501781_item	3221685	et	4	main
lähtuti	doc_491521501781_item	3221686	et	3	main
ainsuse	doc_491521501781_item	3221687	et	4	main
omastavast	doc_491521501781_item	3221688	et	4	main
käändest	doc_491521501781_item	3221689	et	4	main
teode	doc_491521501781_item	3221690	et	4	main
tähtsuse	doc_491521501781_item	3221691	et	4	main
asemel	doc_491521501781_item	3221692	et	4	main
on	doc_491521501781_item	3221695	et	4	main
ka	doc_491521501781_item	3221696	et	3	main
hankiti	doc_491521501781_item	3221704	et	4	main
infinitiivi	doc_491521501781_item	3221710	et	4	main
õige	doc_491521501781_item	3221713	et	4	main
sõdadega	doc_491521501781_item	3221714	et	3	main
mitmuse	doc_491521501781_item	3221715	et	3	main
omastav	doc_491521501781_item	3221716	et	4	main
moodustati	doc_491521501781_item	3221717	et	3	main
vaja	doc_491521501781_item	3221728	et	4	main
õige	doc_491521501781_item	3221736	et	4	main
despooti	doc_491521501781_item	3221742	et	4	main
reformaatorite	doc_491521501781_item	3221747	et	3	main
mitmuse	doc_491521501781_item	3221749	et	3	main
sõna	doc_491521501781_item	3221751	et	4	main
ära	doc_491521501781_item	3221754	et	4	main
mõndavõrra	doc_491521501781_item	3221765	et	4	main
kuningas	doc_491521501781_item	3221801	et	4	main
raske	doc_491521501781_item	3221804	et	4	main
sõnade	doc_491521501781_item	3221806	et	3	main
rumeenlased	doc_491521501781_item	3221815	et	3	main
tekkinud	doc_491521501781_item	3221821	et	4	main
palju	doc_491521501781_item	3221822	et	4	main
laulusid	doc_491521501781_item	3221823	et	3	main
raske	doc_491521501781_item	3221829	et	4	main
reeglipärane	doc_491521501781_item	3221836	et	4	main
õige	doc_491521501781_item	3221840	et	4	main
kuulutati	doc_491521501781_item	3221841	et	4	main
õige	doc_491521501781_item	3221853	et	4	main
usukuulutamise	doc_491521501781_item	3221856	et	3	main
need	doc_491521501781_item	3221886	et	3	main
avalikuks	doc_491521501781_item	3221887	et	3	main
nad	doc_491521501781_item	3221888	et	3	main
ideesid	doc_491521501781_item	3221892	et	3	main
õige	doc_491521501781_item	3221893	et	4	main
uust	doc_491521501781_item	3221902	et	4	main
ungari	doc_491521501781_item	3221915	et	4	main
suuruses	doc_491521501781_item	3221933	et	4	main
piible	doc_491521501781_item	3221943	et	4	main
tõlkis	doc_491521501781_item	3221955	et	3	main
keelde	doc_491521501781_item	3221960	et	4	main
õige	doc_491521501781_item	3221961	et	4	main
keelest	doc_491521501781_item	3221966	et	4	main
ungari	doc_491521501781_item	3221967	et	4	main
juhul	doc_491521501781_item	3221973	et	3	main
arvatavasti	doc_491521501781_item	3221976	et	3	main
katoliiklased	doc_491521501781_item	3221632	et	3	main
aastal	doc_491521501781_item	3221633	et	3	main
oma	doc_491521501781_item	3221637	et	4	main
on	doc_491521501781_item	3221640	et	4	main
objektiviga	doc_491521501781_item	3221641	et	4	main
ungarlaste	doc_491521501781_item	3221645	et	3	main
peab	doc_491521501781_item	3221653	et	4	main
osastavat	doc_491521501781_item	3221659	et	4	main
vead	doc_491521501781_item	3221669	et	4	main
talupojadele	doc_491521501781_item	3221670	et	3	main
asemel	doc_491521501781_item	3221671	et	4	main
see	doc_491521501781_item	3221680	et	3	main
tegude	doc_491521501781_item	3221693	et	3	main
astmevahelduslik	doc_491521501781_item	3221697	et	4	main
viga	doc_491521501781_item	3221698	et	4	main
õige	doc_491521501781_item	3221705	et	4	main
vorm	doc_491521501781_item	3221706	et	3	main
ainsuse	doc_491521501781_item	3221718	et	4	main
ei	doc_491521501781_item	3221734	et	4	main
võidis	doc_491521501781_item	3221739	et	4	main
oli	doc_491521501781_item	3221752	et	3	main
valesti	doc_491521501781_item	3221753	et	3	main
järgis	doc_491521501781_item	3221758	et	4	main
suur	doc_491521501781_item	3221759	et	3	main
religiooslik	doc_491521501781_item	3221768	et	4	main
õige	doc_491521501781_item	3221769	et	4	main
tollel	doc_491521501781_item	3221771	et	4	main
õige	doc_491521501781_item	3221795	et	4	main
istvan	doc_491521501781_item	3221802	et	4	main
nende	doc_491521501781_item	3221805	et	4	main
käänamine	doc_491521501781_item	3221807	et	4	main
mis	doc_491521501781_item	3221808	et	4	main
õige	doc_491521501781_item	3221824	et	4	main
eesti	doc_491521501781_item	3221830	et	4	main
kuulutati	doc_491521501781_item	3221837	et	4	main
välja	doc_491521501781_item	3221842	et	4	main
tõid	doc_491521501781_item	3221889	et	4	main
usupuhastuse	doc_491521501781_item	3221891	et	3	main
usupuhastuse	doc_491521501781_item	3221897	et	3	main
uue	doc_491521501781_item	3221909	et	3	main
ka	doc_491521501781_item	3221924	et	3	main
välismaalt	doc_491521501781_item	3221925	et	3	main
saadeti	doc_491521501781_item	3221926	et	3	main
õige	doc_491521501781_item	3221938	et	4	main
ka	doc_491521501781_item	3221939	et	3	main
välismaalt	doc_491521501781_item	3221940	et	3	main
ulatuses	doc_491521501781_item	3221948	et	4	main
elektrat	doc_491521501781_item	3221956	et	4	main
keelest	doc_491521501781_item	3221958	et	4	main
tõlkis	doc_491521501781_item	3221963	et	3	main
keelde	doc_491521501781_item	3221968	et	4	main
ungari	doc_491521501781_item	3221969	et	4	main
kääne	doc_491521501781_item	3221975	et	3	main
katoliku	doc_491521501781_item	3221993	et	3	main
jättis	doc_491521501781_item	3221996	et	3	main
see	doc_491521501781_item	3221998	et	3	main
sama	doc_491521501781_item	3221999	et	4	main
selles	doc_491521501781_item	3222008	et	4	main
trükiti	doc_491521501781_item	3222010	et	3	main
õige	doc_491521501781_item	3222013	et	4	main
selles	doc_491521501781_item	3222014	et	4	main
trükikojas	doc_491521501781_item	3222015	et	3	main
trükiti	doc_491521501781_item	3222016	et	3	main
põhjus	doc_491521501781_item	3222019	et	4	main
langenud	doc_491521501781_item	3222026	et	4	main
õige	doc_491521501781_item	3222027	et	4	main
on	doc_491521501781_item	3222031	et	4	main
tõlkelaen	doc_491521501781_item	3222032	et	3	main
keelest	doc_491521501781_item	3222034	et	4	main
nad	doc_491521501781_item	3222035	et	3	main
rõhutasid	doc_491521501781_item	3222036	et	4	main
võimude	doc_491521501781_item	3222037	et	3	main
kiiresti	doc_491521501781_item	3222058	et	3	main
sattuda	doc_491521501781_item	3222060	et	3	main
asjaolu	doc_491521501781_item	3222062	et	4	main
uued	doc_491521501781_item	3222064	et	3	main
trükkimise	doc_491521501781_item	3222077	et	4	main
ungaris	doc_491521501781_item	3222090	et	4	main
luuletuse	doc_491521501781_item	3222100	et	4	main
oleks	doc_491521501781_item	3222104	et	3	main
vead	doc_491521501781_item	3222112	et	4	main
ungari	doc_491521501781_item	3221664	et	4	main
või	doc_491521501781_item	3221665	et	4	main
on	doc_491521501781_item	3221674	et	4	main
teadmisi	doc_491521501781_item	3221707	et	4	main
lähtuti	doc_491521501781_item	3221709	et	3	main
sõjadega	doc_491521501781_item	3221712	et	4	main
pole	doc_491521501781_item	3221727	et	3	main
oli	doc_491521501781_item	3221730	et	3	main
valesti	doc_491521501781_item	3221731	et	3	main
ei	doc_491521501781_item	3221737	et	4	main
õige	doc_491521501781_item	3221743	et	4	main
despoodi	doc_491521501781_item	3221744	et	3	main
lähtuti	doc_491521501781_item	3221748	et	3	main
õpitud	doc_491521501781_item	3221755	et	4	main
õige	doc_491521501781_item	3221766	et	4	main
õige	doc_491521501781_item	3221772	et	4	main
tollal	doc_491521501781_item	3221773	et	3	main
pretsedendita	doc_491521501781_item	3221774	et	3	main
õige	doc_491521501781_item	3221775	et	4	main
pretsedenditu	doc_491521501781_item	3221776	et	4	main
tagakiusatamine	doc_491521501781_item	3221777	et	4	main
õige	doc_491521501781_item	3221778	et	4	main
tagakiusamine	doc_491521501781_item	3221779	et	3	main
täitsa	doc_491521501781_item	3221780	et	3	main
õige	doc_491521501781_item	3221781	et	4	main
täie	doc_491521501781_item	3221782	et	3	main
reformatoorne	doc_491521501781_item	3221783	et	4	main
õige	doc_491521501781_item	3221784	et	4	main
reformaatorlik	doc_491521501781_item	3221785	et	4	main
tema	doc_491521501781_item	3221786	et	4	main
teenuseks	doc_491521501781_item	3221787	et	3	main
oli	doc_491521501781_item	3221788	et	3	main
õige	doc_491521501781_item	3221789	et	4	main
tema	doc_491521501781_item	3221790	et	4	main
teeneks	doc_491521501781_item	3221791	et	4	main
oli	doc_491521501781_item	3221792	et	3	main
õige	doc_491521501781_item	3221800	et	4	main
nimetavas	doc_491521501781_item	3221809	et	4	main
sga	doc_491521501781_item	3221812	et	4	main
õige	doc_491521501781_item	3221814	et	4	main
objektivead	doc_491521501781_item	3221816	et	4	main
vorm	doc_491521501781_item	3221817	et	3	main
ja	doc_491521501781_item	3221818	et	3	main
oli	doc_491521501781_item	3221820	et	3	main
keeles	doc_491521501781_item	3221831	et	4	main
see	doc_491521501781_item	3221832	et	3	main
ei	doc_491521501781_item	3221833	et	4	main
õigus	doc_491521501781_item	3221843	et	4	main
see	doc_491521501781_item	3221844	et	3	main
viga	doc_491521501781_item	3221845	et	4	main
tuleb	doc_491521501781_item	3221846	et	3	main
ungarisse	doc_491521501781_item	3221890	et	4	main
kokku	doc_491521501781_item	3221701	et	3	main
hangiti	doc_491521501781_item	3221708	et	3	main
laulmikudes	doc_491521501781_item	3221720	et	4	main
õige	doc_491521501781_item	3221721	et	4	main
laulikutes	doc_491521501781_item	3221722	et	3	main
see	doc_491521501781_item	3221723	et	3	main
sama	doc_491521501781_item	3221724	et	4	main
viga	doc_491521501781_item	3221725	et	4	main
väidenud	doc_491521501781_item	3221735	et	4	main
õige	doc_491521501781_item	3221740	et	4	main
võitis	doc_491521501781_item	3221741	et	3	main
õige	doc_491521501781_item	3221746	et	4	main
nimetavast	doc_491521501781_item	3221750	et	4	main
tähelepanu	doc_491521501781_item	3221760	et	4	main
jälgis	doc_491521501781_item	3221762	et	4	main
suur	doc_491521501781_item	3221763	et	3	main
tähelepanu	doc_491521501781_item	3221764	et	4	main
kultuuri	doc_491521501781_item	3221794	et	4	main
kultuuri	doc_491521501781_item	3221797	et	4	main
kuninga	doc_491521501781_item	3221798	et	3	main
istvan	doc_491521501781_item	3221799	et	4	main
on	doc_491521501781_item	3221803	et	4	main
lõpevad	doc_491521501781_item	3221811	et	4	main
käändevalik	doc_491521501781_item	3221819	et	4	main
osastav	doc_491521501781_item	3221827	et	4	main
on	doc_491521501781_item	3221828	et	4	main
ole	doc_491521501781_item	3221834	et	4	main
nii	doc_491521501781_item	3221835	et	3	main
ungari	doc_491521501781_item	3221847	et	4	main
keelest	doc_491521501781_item	3221848	et	4	main
sätestati	doc_491521501781_item	3221849	et	3	main
seaduses	doc_491521501781_item	3221850	et	3	main
usukuulutamise	doc_491521501781_item	3221851	et	3	main
seaduses	doc_491521501781_item	3221855	et	3	main
vabadus	doc_491521501781_item	3221857	et	4	main
see	doc_491521501781_item	3221858	et	3	main
sama	doc_491521501781_item	3221859	et	4	main
põhjus	doc_491521501781_item	3221860	et	4	main
ta	doc_491521501781_item	3221861	et	4	main
kasvatas	doc_491521501781_item	3221862	et	3	main
vaimulikuid	doc_491521501781_item	3221863	et	4	main
õige	doc_491521501781_item	3221864	et	4	main
ta	doc_491521501781_item	3221865	et	4	main
kasvatas	doc_491521501781_item	3221866	et	3	main
vaimulike	doc_491521501781_item	3221867	et	3	main
ta	doc_491521501781_item	3221868	et	4	main
tõlkis	doc_491521501781_item	3221869	et	3	main
ungari	doc_491521501781_item	3221870	et	4	main
keelde	doc_491521501781_item	3221871	et	4	main
raamatu	doc_491521501781_item	3221872	et	4	main
õige	doc_491521501781_item	3221873	et	4	main
ta	doc_491521501781_item	3221874	et	4	main
tõlkis	doc_491521501781_item	3221875	et	3	main
ungari	doc_491521501781_item	3221876	et	4	main
keelde	doc_491521501781_item	3221877	et	4	main
raamatut	doc_491521501781_item	3221878	et	3	main
nad	doc_491521501781_item	3221879	et	3	main
tegid	doc_491521501781_item	3221880	et	4	main
neid	doc_491521501781_item	3221881	et	4	main
avalikuks	doc_491521501781_item	3221882	et	3	main
õige	doc_491521501781_item	3221883	et	4	main
nad	doc_491521501781_item	3221884	et	3	main
tegid	doc_491521501781_item	3221885	et	4	main
ideid	doc_491521501781_item	3221898	et	3	main
vasti	doc_491521501781_item	3221904	et	4	main
võtsid	doc_491521501781_item	3221905	et	4	main
tuleb	doc_491521501781_item	3221914	et	3	main
ungari	doc_491521501781_item	3221917	et	4	main
keeles	doc_491521501781_item	3221918	et	4	main
oleks	doc_491521501781_item	3221919	et	3	main
sel	doc_491521501781_item	3221920	et	3	main
juhal	doc_491521501781_item	3221921	et	3	main
saadeti	doc_491521501781_item	3221941	et	3	main
ungarisse	doc_491521501781_item	3221942	et	4	main
jälle	doc_491521501781_item	3221949	et	3	main
olid	doc_491521501781_item	3221950	et	4	main
osastavaga	doc_491521501781_item	3221953	et	4	main
kreeka	doc_491521501781_item	3221957	et	4	main
ungari	doc_491521501781_item	3221959	et	4	main
osastav	doc_491521501781_item	3221974	et	4	main
esimene	doc_491521501781_item	3221979	et	3	main
õige	doc_491521501781_item	3221986	et	4	main
arvatavasti	doc_491521501781_item	3221987	et	3	main
oli	doc_491521501781_item	3221988	et	3	main
jättis	doc_491521501781_item	3221985	et	3	main
ta	doc_491521501781_item	3221989	et	4	main
esimene	doc_491521501781_item	3221990	et	3	main
kes	doc_491521501781_item	3221991	et	4	main
transilvaanias	doc_491521501781_item	3221992	et	4	main
tõid	doc_491521501781_item	3221895	et	4	main
ungarisse	doc_491521501781_item	3221896	et	4	main
seda	doc_491521501781_item	3221901	et	3	main
usku	doc_491521501781_item	3221903	et	4	main
usu	doc_491521501781_item	3221910	et	4	main
vastu	doc_491521501781_item	3221911	et	3	main
võtsid	doc_491521501781_item	3221912	et	4	main
viga	doc_491521501781_item	3221913	et	4	main
keelest	doc_491521501781_item	3221916	et	4	main
tuhande	doc_491521501781_item	3221931	et	3	main
eksemplari	doc_491521501781_item	3221932	et	4	main
on	doc_491521501781_item	3221935	et	4	main
õpikuid	doc_491521501781_item	3221944	et	4	main
mitmuse	doc_491521501781_item	3221952	et	3	main
ta	doc_491521501781_item	3221954	et	4	main
ta	doc_491521501781_item	3221978	et	4	main
transilvaanias	doc_491521501781_item	3221981	et	4	main
usu	doc_491521501781_item	3221994	et	4	main
jälle	doc_491521501781_item	3221997	et	3	main
siin	doc_491521501781_item	3222005	et	4	main
grammatikat	doc_491521501781_item	3222012	et	3	main
on	doc_491521501781_item	3222025	et	4	main
see	doc_491521501781_item	3222030	et	3	main
ungari	doc_491521501781_item	3222033	et	4	main
õige	doc_491521501781_item	3222085	et	4	main
trükkimise	doc_491521501781_item	3222087	et	4	main
alguses	doc_491521501781_item	3222088	et	4	main
oli	doc_491521501781_item	3222089	et	3	main
vead	doc_491521501781_item	3222096	et	4	main
ungari	doc_491521501781_item	3222102	et	4	main
sel	doc_491521501781_item	3222105	et	3	main
lõpul	doc_491521501781_item	3222107	et	3	main
õige	doc_491521501781_item	3222109	et	4	main
õigekirja	doc_491521501781_item	3222111	et	4	main
olnud	doc_491521501781_item	3222123	et	4	main
religiosse	doc_491521501781_item	3222125	et	4	main
religioosse	doc_491521501781_item	3222127	et	3	main
siiamaani	doc_491521501781_item	3222133	et	3	main
trükkitud	doc_491521501781_item	3222134	et	4	main
õige	doc_491521501781_item	3222135	et	4	main
valikuid	doc_491521501781_item	3222165	et	4	main
teha	doc_491521501781_item	3222166	et	3	main
mõned	doc_491521501781_item	3222179	et	3	main
reformatsiooni	doc_491521501781_item	3222180	et	4	main
õige	doc_491521501781_item	3222187	et	4	main
ka	doc_491521501781_item	3222188	et	3	main
välismaalt	doc_491521501781_item	3222189	et	3	main
saadeti	doc_491521501781_item	3222190	et	3	main
suuruses	doc_491521501781_item	3221934	et	4	main
stiili	doc_491521501781_item	3221936	et	4	main
viga	doc_491521501781_item	3221937	et	4	main
mõne	doc_491521501781_item	3221945	et	3	main
tuhande	doc_491521501781_item	3221946	et	3	main
eksemplari	doc_491521501781_item	3221947	et	4	main
raskusi	doc_491521501781_item	3221951	et	4	main
ta	doc_491521501781_item	3221962	et	4	main
elektra	doc_491521501781_item	3221964	et	4	main
kreeka	doc_491521501781_item	3221965	et	4	main
keeles	doc_491521501781_item	3221970	et	4	main
oleks	doc_491521501781_item	3221971	et	3	main
sel	doc_491521501781_item	3221972	et	3	main
oli	doc_491521501781_item	3221977	et	3	main
usku	doc_491521501781_item	3221983	et	4	main
maha	doc_491521501781_item	3221984	et	4	main
kääne	doc_491521501781_item	3222007	et	3	main
sylvesteri	doc_491521501781_item	3222011	et	4	main
grammatika	doc_491521501781_item	3222018	et	4	main
vajalikkust	doc_491521501781_item	3222038	et	4	main
said	doc_491521501781_item	3222059	et	4	main
ungarisse	doc_491521501781_item	3222069	et	4	main
viga	doc_491521501781_item	3222071	et	4	main
tuleb	doc_491521501781_item	3222072	et	3	main
vist	doc_491521501781_item	3222073	et	4	main
vene	doc_491521501781_item	3222074	et	4	main
keelest	doc_491521501781_item	3222075	et	4	main
juba	doc_491521501781_item	3222076	et	3	main
ungaris	doc_491521501781_item	3222080	et	4	main
raamatute	doc_491521501781_item	3222082	et	3	main
kes	doc_491521501781_item	3221980	et	4	main
katoliku	doc_491521501781_item	3221982	et	3	main
maha	doc_491521501781_item	3221995	et	4	main
põhjus	doc_491521501781_item	3222000	et	4	main
et	doc_491521501781_item	3222001	et	3	main
osastav	doc_491521501781_item	3222006	et	4	main
vabadussõda	doc_491521501781_item	3222024	et	4	main
kaotati	doc_491521501781_item	3222029	et	3	main
õige	doc_491521501781_item	3222039	et	4	main
ungarisse	doc_491521501781_item	3222061	et	4	main
ideed	doc_491521501781_item	3222065	et	4	main
jõudsid	doc_491521501781_item	3222066	et	4	main
nii	doc_491521501781_item	3222067	et	3	main
kiirsti	doc_491521501781_item	3222068	et	4	main
oli	doc_491521501781_item	3222079	et	3	main
suur	doc_491521501781_item	3222084	et	3	main
juba	doc_491521501781_item	3222086	et	3	main
suur	doc_491521501781_item	3222094	et	3	main
luuletuse	doc_491521501781_item	3222097	et	4	main
lõpul	doc_491521501781_item	3222098	et	3	main
õige	doc_491521501781_item	3222099	et	4	main
juhul	doc_491521501781_item	3222106	et	3	main
ei	doc_491521501781_item	3222122	et	4	main
transilvaania	doc_491521501781_item	3222130	et	4	main
trükitud	doc_491521501781_item	3222136	et	4	main
rietusid	doc_491521501781_item	3222140	et	4	main
tegema	doc_491521501781_item	3222169	et	3	main
levitajatest	doc_491521501781_item	3222175	et	4	main
said	doc_491521501781_item	3222176	et	4	main
viga	doc_491521501781_item	3222191	et	4	main
tuleb	doc_491521501781_item	3222192	et	3	main
kirikuorganisatsiooniga	doc_491521501781_item	3222213	et	3	main
õige	doc_491521501781_item	3222220	et	4	main
usupuhastus	doc_491521501781_item	3222221	et	3	main
rektsiooni	doc_491521501781_item	3222235	et	4	main
kuulusid	doc_491521501781_item	3222243	et	4	main
tähtsam	doc_491521501781_item	3222250	et	4	main
viga	doc_491521501781_item	3222257	et	4	main
õppima	doc_491521501781_item	3222264	et	3	main
maadesse	doc_491521501781_item	3222273	et	4	main
muud	doc_491521501781_item	3222279	et	4	main
mängis	doc_491521501781_item	3222288	et	3	main
osa	doc_491521501781_item	3222290	et	4	main
veaanalüüsi	doc_491521501891_item	3222302	et	4	main
kirjakeelest	doc_491521501891_item	3222307	et	4	main
näited	doc_491521501891_item	3222310	et	3	main
kus	doc_491521501891_item	3222320	et	3	main
5	doc_491521501891_item	3222326	et	2	main
täiskasvanutele	doc_491521501891_item	3222330	et	3	main
pärit	doc_491521501891_item	3222338	et	3	main
valesti	doc_491521501891_item	3222355	et	3	main
hääldus	doc_491521501891_item	3222370	et	4	main
õigekiri	doc_491521501891_item	3222371	et	3	main
tjudruk	doc_491521501891_item	3222372	et	4	main
tjäna	doc_491521501891_item	3222380	et	4	main
taivas	doc_491521501891_item	3222386	et	4	main
viis	doc_491521501891_item	3222391	et	4	main
kus	doc_491521501891_item	3222392	et	3	main
insenär	doc_491521501891_item	3222395	et	4	main
astmevaheldusvead	doc_491521501891_item	3222397	et	4	main
tüüpiline	doc_491521501891_item	3222398	et	3	main
eesti	doc_491521501891_item	3222402	et	4	main
eile	doc_491521501891_item	3222405	et	3	main
hüpan	doc_491521501891_item	3222410	et	4	main
kui	doc_491521501891_item	3222411	et	3	main
te	doc_491521501891_item	3222412	et	4	main
ma	doc_491521501891_item	3222422	et	3	main
olen	doc_491521501891_item	3222423	et	3	main
tubas	doc_491521501891_item	3222424	et	4	main
muutu	doc_491521501891_item	3222430	et	4	main
nad	doc_491521501891_item	3222435	et	3	main
seda	doc_491521501891_item	3222436	et	3	main
ka	doc_491521501891_item	3222438	et	3	main
лудче	doc_491521501891_item	3222483	et	2	main
külm	doc_491521501891_item	3222490	et	3	main
maitsavam	doc_491521501891_item	3222493	et	4	main
järgnevad	doc_491521501891_item	3222495	et	4	main
vead	doc_491521501891_item	3222496	et	4	main
ta	doc_491521501891_item	3222504	et	4	main
vanemuise	doc_491521501891_item	3222506	et	4	main
on	doc_491521501891_item	3222509	et	4	main
ungari	doc_491521501781_item	3222002	et	4	main
keeles	doc_491521501781_item	3222003	et	4	main
oleks	doc_491521501781_item	3222004	et	3	main
trükikojas	doc_491521501781_item	3222009	et	3	main
sylvesteri	doc_491521501781_item	3222017	et	4	main
on	doc_491521501781_item	3222020	et	4	main
see	doc_491521501781_item	3222021	et	3	main
sama	doc_491521501781_item	3222022	et	4	main
stiilivead	doc_491521501781_item	3222023	et	3	main
vabadussõda	doc_491521501781_item	3222028	et	4	main
nad	doc_491521501781_item	3222040	et	3	main
rõhutasid	doc_491521501781_item	3222041	et	4	main
võimude	doc_491521501781_item	3222042	et	3	main
tähtsust	doc_491521501781_item	3222043	et	4	main
protestandid	doc_491521501781_item	3222044	et	3	main
omistasid	doc_491521501781_item	3222045	et	4	main
suurt	doc_491521501781_item	3222046	et	3	main
tähendust	doc_491521501781_item	3222047	et	4	main
õige	doc_491521501781_item	3222048	et	4	main
protestandid	doc_491521501781_item	3222049	et	3	main
omistasid	doc_491521501781_item	3222050	et	4	main
suurt	doc_491521501781_item	3222051	et	3	main
tähtsust	doc_491521501781_item	3222052	et	4	main
asjaolu	doc_491521501781_item	3222053	et	4	main
et	doc_491521501781_item	3222054	et	3	main
uued	doc_491521501781_item	3222055	et	3	main
ideed	doc_491521501781_item	3222056	et	4	main
nii	doc_491521501781_item	3222057	et	3	main
et	doc_491521501781_item	3222063	et	3	main
see	doc_491521501781_item	3222070	et	3	main
alguses	doc_491521501781_item	3222078	et	4	main
trükitud	doc_491521501781_item	3222081	et	4	main
arv	doc_491521501781_item	3222083	et	3	main
trükitud	doc_491521501781_item	3222091	et	4	main
raamatute	doc_491521501781_item	3222092	et	3	main
tiraaž	doc_491521501781_item	3222093	et	2	main
lõpus	doc_491521501781_item	3222101	et	4	main
effektiivne	doc_491521501781_item	3222113	et	4	main
õige	doc_491521501781_item	3222120	et	4	main
õige	doc_491521501781_item	3222126	et	4	main
transsilvaania	doc_491521501781_item	3222128	et	4	main
õige	doc_491521501781_item	3222129	et	4	main
järgi	doc_491521501781_item	3222139	et	4	main
riietusid	doc_491521501781_item	3222142	et	4	main
periodi	doc_491521501781_item	3222143	et	4	main
õige	doc_491521501781_item	3222167	et	4	main
valikud	doc_491521501781_item	3222168	et	3	main
vead	doc_491521501781_item	3222172	et	4	main
mõned	doc_491521501781_item	3222173	et	3	main
olid	doc_491521501781_item	3222185	et	4	main
ja	doc_491521501781_item	3222198	et	3	main
usupuhastus	doc_491521501781_item	3222209	et	3	main
käändevalik	doc_491521501781_item	3222218	et	4	main
religiooniga	doc_491521501781_item	3222219	et	3	main
mis	doc_491521501781_item	3222237	et	4	main
transilvaania	doc_491521501781_item	3222239	et	4	main
õige	doc_491521501781_item	3222241	et	4	main
mis	doc_491521501781_item	3222242	et	4	main
mis	doc_491521501781_item	3222246	et	4	main
olid	doc_491521501781_item	3222247	et	4	main
ühiskondliku	doc_491521501781_item	3222248	et	3	main
positsioonidest	doc_491521501781_item	3222249	et	3	main
tähtsam	doc_491521501781_item	3222256	et	4	main
ta	doc_491521501781_item	3222263	et	4	main
õige	doc_491521501781_item	3222267	et	4	main
läks	doc_491521501781_item	3222269	et	3	main
vist	doc_491521501781_item	3222276	et	4	main
suurt	doc_491521501781_item	3222283	et	3	main
osa	doc_491521501781_item	3222284	et	4	main
ballassi	doc_491521501781_item	3222285	et	4	main
kohakäände	doc_491521501781_item	3222095	et	4	main
keeles	doc_491521501781_item	3222103	et	4	main
belgiumi	doc_491521501781_item	3222108	et	4	main
belgiasse	doc_491521501781_item	3222110	et	4	main
õige	doc_491521501781_item	3222114	et	4	main
efektiivne	doc_491521501781_item	3222115	et	3	main
kirjutati	doc_491521501781_item	3222116	et	3	main
häälduse	doc_491521501781_item	3222117	et	4	main
järgi	doc_491521501781_item	3222118	et	4	main
reformatsioon	doc_491521501781_item	3222121	et	3	main
kirjutati	doc_491521501781_item	3222137	et	3	main
häälduse	doc_491521501781_item	3222138	et	4	main
õige	doc_491521501781_item	3222141	et	4	main
õige	doc_491521501781_item	3222144	et	4	main
perioodi	doc_491521501781_item	3222145	et	4	main
mistitsism	doc_491521501781_item	3222146	et	4	main
õige	doc_491521501781_item	3222147	et	4	main
müstitsism	doc_491521501781_item	3222148	et	3	main
trükkikoda	doc_491521501781_item	3222149	et	4	main
õige	doc_491521501781_item	3222150	et	4	main
trükikoda	doc_491521501781_item	3222151	et	4	main
krakkovis	doc_491521501781_item	3222152	et	4	main
õige	doc_491521501781_item	3222153	et	4	main
krackovis	doc_491521501781_item	3222154	et	4	main
õppikud	doc_491521501781_item	3222155	et	4	main
õige	doc_491521501781_item	3222156	et	4	main
õpikud	doc_491521501781_item	3222157	et	3	main
trükimise	doc_491521501781_item	3222158	et	4	main
õige	doc_491521501781_item	3222159	et	4	main
trükkimise	doc_491521501781_item	3222160	et	4	main
da-	doc_491521501781_item	3222161	et	4	main
reformatsion	doc_491521501781_item	3222119	et	4	main
tähelepanelik	doc_491521501781_item	3222124	et	4	main
siamaani	doc_491521501781_item	3222131	et	4	main
õige	doc_491521501781_item	3222132	et	4	main
ja	doc_491521501781_item	3222162	et	3	main
ma-	doc_491521501781_item	3222163	et	3	main
verbivormide	doc_491521501781_item	3222170	et	4	main
reformatsiooni	doc_491521501781_item	3222174	et	4	main
õige	doc_491521501781_item	3222178	et	4	main
levitajatest	doc_491521501781_item	3222181	et	4	main
vangistati	doc_491521501781_item	3222182	et	4	main
ka	doc_491521501781_item	3222183	et	3	main
välismaalt	doc_491521501781_item	3222184	et	3	main
käänamine	doc_491521501781_item	3222197	et	4	main
kasutamine	doc_491521501781_item	3222199	et	4	main
kolm	doc_491521501781_item	3222201	et	3	main
tegurid	doc_491521501781_item	3222202	et	3	main
õige	doc_491521501781_item	3222203	et	4	main
need	doc_491521501781_item	3222204	et	3	main
kolm	doc_491521501781_item	3222205	et	3	main
tegurit	doc_491521501781_item	3222206	et	3	main
rektsiooni	doc_491521501781_item	3222207	et	4	main
ungaris	doc_491521501781_item	3222210	et	4	main
kahte	doc_491521501781_item	3222212	et	4	main
mõnda	doc_491521501781_item	3222215	et	4	main
väiksema	doc_491521501781_item	3222216	et	4	main
kohtas	doc_491521501781_item	3222223	et	3	main
kahte	doc_491521501781_item	3222224	et	4	main
viga	doc_491521501781_item	3222236	et	4	main
juurde	doc_491521501781_item	3222240	et	4	main
ühildumisvead	doc_491521501781_item	3222245	et	4	main
mis	doc_491521501781_item	3222252	et	4	main
keelest	doc_491521501781_item	3222260	et	4	main
hiljem	doc_491521501781_item	3222261	et	3	main
läks	doc_491521501781_item	3222262	et	3	main
viga	doc_491521501781_item	3222274	et	4	main
käändevead	doc_491521501781_item	3222280	et	4	main
sellest	doc_491521501781_item	3222281	et	4	main
mängis	doc_491521501781_item	3222282	et	3	main
eesti	doc_491521501891_item	3222306	et	4	main
keelekasutuse	doc_491521501891_item	3222309	et	4	main
nii	doc_491521501891_item	3222313	et	3	main
kõne-	doc_491521501891_item	3222314	et	4	main
õpetan	doc_491521501891_item	3222321	et	3	main
klass	doc_491521501891_item	3222327	et	3	main
algtasemel	doc_491521501891_item	3222331	et	3	main
keelt	doc_491521501891_item	3222333	et	4	main
mõningates	doc_491521501891_item	3222339	et	3	main
ühe	doc_491521501891_item	3222353	et	4	main
sellepärast	doc_491521501891_item	3222361	et	3	main
olen	doc_491521501891_item	3222362	et	3	main
tapselt	doc_491521501891_item	3222375	et	4	main
täna	doc_491521501891_item	3222381	et	4	main
töötan	doc_491521501891_item	3222383	et	3	main
vis	doc_491521501891_item	3222389	et	4	main
kuus	doc_491521501891_item	3222394	et	4	main
inseneer	doc_491521501891_item	3222396	et	4	main
ma	doc_491521501891_item	3222406	et	3	main
lugeksite	doc_491521501891_item	3222416	et	4	main
sõna	doc_491521501891_item	3222427	et	4	main
tüvi	doc_491521501891_item	3222428	et	3	main
taba	doc_491521501891_item	3222434	et	4	main
eesti	doc_491521501891_item	3222439	et	4	main
keeles	doc_491521501891_item	3222440	et	4	main
klassis	doc_491521501891_item	3222445	et	3	main
omadusõna	doc_491521501891_item	3222447	et	4	main
võrdlusastmed	doc_491521501891_item	3222448	et	3	main
kordava	doc_491521501891_item	3222449	et	4	main
osana	doc_491521501891_item	3222450	et	3	main
palju	doc_491521501891_item	3222455	et	4	main
tark	doc_491521501891_item	3222486	et	3	main
tarkem	doc_491521501891_item	3222487	et	4	main
halb	doc_491521501891_item	3222488	et	3	main
on	doc_491521501891_item	3222497	et	4	main
täiskasvanute	doc_491521501891_item	3222498	et	3	main
keelekasutusest	doc_491521501891_item	3222499	et	4	main
ma	doc_491521501891_item	3222501	et	3	main
olen	doc_491521501891_item	3222502	et	3	main
on	doc_491521501891_item	3222513	et	4	main
pastapliiats	doc_491521501891_item	3222519	et	4	main
kasutamise	doc_491521501891_item	3222524	et	4	main
infinitiivivead	doc_491521501781_item	3222164	et	4	main
valiku	doc_491521501781_item	3222171	et	3	main
vangistatud	doc_491521501781_item	3222177	et	4	main
saadetud	doc_491521501781_item	3222186	et	4	main
arvatavasti	doc_491521501781_item	3222193	et	3	main
keelest	doc_491521501781_item	3222195	et	4	main
arvsõna	doc_491521501781_item	3222196	et	4	main
need	doc_491521501781_item	3222200	et	3	main
vale	doc_491521501781_item	3222217	et	4	main
kirikuorganisatsiooni	doc_491521501781_item	3222225	et	4	main
transilvaaniasse	doc_491521501781_item	3222244	et	4	main
õige	doc_491521501781_item	3222251	et	4	main
tuleb	doc_491521501781_item	3222258	et	3	main
ungari	doc_491521501781_item	3222259	et	4	main
maadesse	doc_491521501781_item	3222266	et	4	main
tuleb	doc_491521501781_item	3222275	et	3	main
õige	doc_491521501781_item	3222286	et	4	main
suurt	doc_491521501781_item	3222289	et	3	main
ballassi	doc_491521501781_item	3222291	et	4	main
veaanalüüsi	doc_491521501781_item	3222292	et	4	main
kirjutamisel	doc_491521501781_item	3222293	et	4	main
oma	doc_491521501781_item	3222295	et	4	main
bakalaurustöös	doc_491521501781_item	3222296	et	4	main
kasutasin	doc_491521501781_item	3222294	et	3	main
tehtud	doc_491521501781_item	3222297	et	4	main
vigasid	doc_491521501781_item	3222298	et	3	main
ja	doc_491521501781_item	3222299	et	3	main
nende	doc_491521501781_item	3222300	et	4	main
toodud	doc_491521501891_item	3222305	et	4	main
kirjakeelest	doc_491521501891_item	3222316	et	4	main
tähelepanekud	doc_491521501891_item	3222317	et	3	main
keelt	doc_491521501891_item	3222324	et	4	main
õpetan	doc_491521501891_item	3222329	et	3	main
sealt	doc_491521501891_item	3222337	et	4	main
sõnades	doc_491521501891_item	3222340	et	4	main
selliseid	doc_491521501891_item	3222352	et	4	main
kirjutamise	doc_491521501891_item	3222356	et	4	main
mitmel	doc_491521501891_item	3222359	et	4	main
ka	doc_491521501891_item	3222363	et	3	main
need	doc_491521501891_item	3222364	et	3	main
tudruk	doc_491521501891_item	3222373	et	4	main
siia	doc_491521501891_item	3222376	et	4	main
sija	doc_491521501891_item	3222377	et	4	main
aias	doc_491521501891_item	3222378	et	4	main
taivas	doc_491521501891_item	3222387	et	4	main
kus	doc_491521501891_item	3222393	et	3	main
keelt	doc_491521501891_item	3222403	et	4	main
keeles	doc_491521501891_item	3222426	et	4	main
sellepärast	doc_491521501891_item	3222432	et	3	main
muutust	doc_491521501891_item	3222437	et	4	main
on	doc_491521501891_item	3222446	et	4	main
väga	doc_491521501891_item	3222454	et	3	main
vigu	doc_491521501891_item	3222456	et	3	main
maitsev	doc_491521501891_item	3222492	et	4	main
elab	doc_491521501891_item	3222505	et	3	main
tänavas	doc_491521501891_item	3222507	et	4	main
seinas	doc_491521501891_item	3222508	et	3	main
tudengite	doc_491521501891_item	3222520	et	3	main
keele	doc_491521501891_item	3222523	et	4	main
jaoks	doc_491521501891_item	3222525	et	4	main
oleme	doc_491521501891_item	3222526	et	3	main
jõudnud	doc_491521501891_item	3222527	et	4	main
kokkuleppeni	doc_491521501891_item	3222528	et	3	main
vaja	doc_491521501891_item	3222538	et	4	main
läheb	doc_491521501891_item	3222542	et	3	main
ja	doc_491521501891_item	3222549	et	3	main
see	doc_491521501891_item	3222551	et	3	main
et	doc_491521501891_item	3222554	et	3	main
miks	doc_491521501891_item	3222564	et	4	main
tingitud	doc_491521501891_item	3222571	et	4	main
ainult	doc_491521501891_item	3222577	et	4	main
sall	doc_491521501891_item	3222603	et	3	main
on	doc_491521501891_item	3222607	et	4	main
saksa	doc_491521501781_item	3222194	et	4	main
vead	doc_491521501781_item	3222208	et	4	main
kohtas	doc_491521501781_item	3222211	et	3	main
ja	doc_491521501781_item	3222214	et	3	main
ungaris	doc_491521501781_item	3222222	et	4	main
ja	doc_491521501781_item	3222226	et	3	main
mõnda	doc_491521501781_item	3222227	et	4	main
väiksemat	doc_491521501781_item	3222228	et	4	main
religiooni	doc_491521501781_item	3222229	et	4	main
kirikuorganisatsiooni	doc_491521501781_item	3222230	et	4	main
ja	doc_491521501781_item	3222231	et	3	main
religiooni	doc_491521501781_item	3222232	et	4	main
puhul	doc_491521501781_item	3222233	et	4	main
on	doc_491521501781_item	3222234	et	4	main
kuulusid	doc_491521501781_item	3222238	et	4	main
olid	doc_491521501781_item	3222253	et	4	main
ühiskondlikest	doc_491521501781_item	3222254	et	3	main
positsioonidest	doc_491521501781_item	3222255	et	3	main
teiste	doc_491521501781_item	3222265	et	4	main
hiljem	doc_491521501781_item	3222268	et	3	main
ta	doc_491521501781_item	3222270	et	4	main
õppima	doc_491521501781_item	3222271	et	3	main
teistesse	doc_491521501781_item	3222272	et	4	main
ungari	doc_491521501781_item	3222277	et	4	main
keelest	doc_491521501781_item	3222278	et	4	main
selles	doc_491521501781_item	3222287	et	4	main
kodutöö	doc_491521501891_item	3222303	et	4	main
on	doc_491521501891_item	3222311	et	4	main
kogutud	doc_491521501891_item	3222312	et	4	main
kui	doc_491521501891_item	3222315	et	3	main
pärinevad	doc_491521501891_item	3222318	et	4	main
l	doc_491521501891_item	3222325	et	4	main
esines	doc_491521501891_item	3222358	et	3	main
õpilasel	doc_491521501891_item	3222360	et	3	main
välja	doc_491521501891_item	3222365	et	4	main
tjäpselt	doc_491521501891_item	3222374	et	4	main
tjöötan	doc_491521501891_item	3222382	et	4	main
kantrolltöö	doc_491521501891_item	3222384	et	4	main
kontroltöö	doc_491521501891_item	3222385	et	4	main
vis	doc_491521501891_item	3222390	et	4	main
õppin	doc_491521501891_item	3222401	et	4	main
sina	doc_491521501891_item	3222872	et	4	main
loed	doc_491521501891_item	3222873	et	4	main
jne	doc_491521501891_item	3222874	et	4	main
aga	doc_491521501891_item	3222875	et	3	main
kõnes	doc_491521501891_item	3222876	et	3	main
kasutab	doc_491521501891_item	3222877	et	3	main
ta	doc_491521501891_item	3222878	et	4	main
ikkagi	doc_491521501891_item	3222879	et	4	main
valesti	doc_491521501891_item	3222880	et	3	main
tema	doc_491521501891_item	3222881	et	4	main
loed	doc_491521501891_item	3222882	et	4	main
keelepraktikat	doc_491521501891_item	3222883	et	3	main
on	doc_491521501891_item	3222884	et	4	main
rohkem	doc_491521501891_item	3222885	et	4	main
vaja	doc_491521501891_item	3222886	et	4	main
töös	doc_491521501891_item	3222304	et	3	main
hälbiva	doc_491521501891_item	3222308	et	4	main
koolist	doc_491521501891_item	3222319	et	4	main
ise	doc_491521501891_item	3222322	et	4	main
eesti	doc_491521501891_item	3222323	et	4	main
kuna	doc_491521501891_item	3222328	et	3	main
eesti	doc_491521501891_item	3222332	et	4	main
on	doc_491521501891_item	3222334	et	4	main
osa	doc_491521501891_item	3222335	et	4	main
näiteid	doc_491521501891_item	3222336	et	3	main
on	doc_491521501891_item	3222341	et	4	main
viga	doc_491521501891_item	3222342	et	4	main
vaid	doc_491521501891_item	3222343	et	3	main
ühes	doc_491521501891_item	3222344	et	4	main
tähes	doc_491521501891_item	3222345	et	3	main
ja	doc_491521501891_item	3222346	et	3	main
kohati	doc_491521501891_item	3222347	et	4	main
tundub	doc_491521501891_item	3222348	et	3	main
see	doc_491521501891_item	3222349	et	3	main
lohakusena	doc_491521501891_item	3222350	et	4	main
aga	doc_491521501891_item	3222351	et	3	main
tähe	doc_491521501891_item	3222354	et	3	main
vigu	doc_491521501891_item	3222357	et	3	main
toonud	doc_491521501891_item	3222366	et	4	main
hääldus	doc_491521501891_item	3222367	et	4	main
ja	doc_491521501891_item	3222368	et	3	main
õigekiri	doc_491521501891_item	3222369	et	3	main
ajas	doc_491521501891_item	3222379	et	4	main
taevas	doc_491521501891_item	3222388	et	4	main
viga	doc_491521501891_item	3222399	et	4	main
ma	doc_491521501891_item	3222400	et	3	main
ei	doc_491521501891_item	3222407	et	4	main
ma	doc_491521501891_item	3222409	et	3	main
v	doc_491521501891_item	3222417	et	4	main
kursuse	doc_491521501891_item	3222418	et	3	main
tudeng	doc_491521501891_item	3222419	et	3	main
lähme	doc_491521501891_item	3222420	et	3	main
tubasse	doc_491521501891_item	3222421	et	4	main
ei	doc_491521501891_item	3222429	et	4	main
ei	doc_491521501891_item	3222433	et	4	main
omadussõna	doc_491521501891_item	3222442	et	4	main
võrdlusastmed	doc_491521501891_item	3222443	et	3	main
5	doc_491521501891_item	3222444	et	2	main
tehakse	doc_491521501891_item	3222453	et	3	main
hea	doc_491521501891_item	3222484	et	4	main
halbem	doc_491521501891_item	3222489	et	4	main
tubas	doc_491521501891_item	3222512	et	4	main
iseloomulik	doc_491521501891_item	3222522	et	3	main
võib	doc_491521501891_item	3222531	et	3	main
kohakäänete	doc_491521501891_item	3222539	et	3	main
hiiumaas	doc_491521501891_item	3222548	et	3	main
jääb	doc_491521501891_item	3222552	et	3	main
on	doc_491521501891_item	3222557	et	4	main
sellest	doc_491521501891_item	3222572	et	4	main
et	doc_491521501891_item	3222573	et	3	main
eessõna	doc_491521501891_item	3222578	et	4	main
головä	doc_491521501891_item	3222602	et	2	main
kaes	doc_491521501891_item	3222611	et	4	main
ja	doc_491521501891_item	3222617	et	3	main
mitmes	doc_491521501891_item	3222636	et	4	main
mitmendaks	doc_491521501891_item	3222637	et	3	main
tekstis	doc_491521501891_item	3222645	et	3	main
25	doc_491521501891_item	3222649	et	2	main
korraga	doc_491521501891_item	3222659	et	4	main
kakskümnendal	doc_491521501891_item	3222670	et	4	main
kahekümne	doc_491521501891_item	3222707	et	4	main
viiendal	doc_491521501891_item	3222708	et	3	main
пятого	doc_491521501891_item	3222710	et	2	main
sama	doc_491521501891_item	3222712	et	4	main
on	doc_491521501891_item	3222714	et	4	main
oma	doc_491521501891_item	3222715	et	4	main
on	doc_491521501891_item	3222720	et	4	main
olen	doc_491521501891_item	3222732	et	3	main
vana	doc_491521501891_item	3222735	et	4	main
sest	doc_491521501891_item	3222748	et	4	main
raskusi	doc_491521501891_item	3222763	et	4	main
novemberil	doc_491521501891_item	3222767	et	3	main
täna	doc_491521501891_item	3222768	et	4	main
juhul	doc_491521501891_item	3222781	et	3	main
ühildumisvead	doc_491521501891_item	3222803	et	4	main
vigu	doc_491521501891_item	3222805	et	3	main
olulised	doc_491521501891_item	3222812	et	4	main
järgnevad	doc_491521501891_item	3222824	et	4	main
töödest	doc_491521501891_item	3222828	et	3	main
suurt	doc_491521501891_item	3222832	et	3	main
ta	doc_491521501891_item	3222868	et	4	main
pöörata	doc_491521501891_item	3222869	et	4	main
aga	doc_491521501891_item	3222404	et	3	main
õpinud	doc_491521501891_item	3222408	et	4	main
ise	doc_491521501891_item	3222413	et	4	main
seda	doc_491521501891_item	3222414	et	3	main
artiklit	doc_491521501891_item	3222415	et	3	main
vene	doc_491521501891_item	3222425	et	4	main
ja	doc_491521501891_item	3222431	et	3	main
ära	doc_491521501891_item	3222441	et	4	main
ja	doc_491521501891_item	3222451	et	3	main
ikkagi	doc_491521501891_item	3222452	et	4	main
eriti	doc_491521501891_item	3222457	et	3	main
algvõrdest	doc_491521501891_item	3222458	et	4	main
keskvõrde	doc_491521501891_item	3222459	et	3	main
moodustamisel	doc_491521501891_item	3222460	et	4	main
vahel	doc_491521501891_item	3222461	et	4	main
on	doc_491521501891_item	3222462	et	4	main
see	doc_491521501891_item	3222463	et	3	main
loomulik	doc_491521501891_item	3222464	et	3	main
sest	doc_491521501891_item	3222465	et	4	main
eesti	doc_491521501891_item	3222466	et	4	main
keeles	doc_491521501891_item	3222467	et	4	main
on	doc_491521501891_item	3222468	et	4	main
ebareeglipäraseid	doc_491521501891_item	3222469	et	4	main
võrdlusastmeid	doc_491521501891_item	3222470	et	3	main
n	doc_491521501891_item	3222471	et	4	main
hea	doc_491521501891_item	3222472	et	4	main
parem	doc_491521501891_item	3222473	et	4	main
kuigi	doc_491521501891_item	3222474	et	3	main
ka	doc_491521501891_item	3222475	et	3	main
vene	doc_491521501891_item	3222476	et	4	main
keeles	doc_491521501891_item	3222477	et	4	main
on	doc_491521501891_item	3222478	et	4	main
vastavad	doc_491521501891_item	3222479	et	4	main
vormid	doc_491521501891_item	3222480	et	4	main
olemas	doc_491521501891_item	3222481	et	4	main
хорошо	doc_491521501891_item	3222482	et	2	main
heam	doc_491521501891_item	3222485	et	4	main
külmim	doc_491521501891_item	3222491	et	3	main
käändevead	doc_491521501891_item	3222494	et	4	main
pärit	doc_491521501891_item	3222500	et	3	main
rõdus	doc_491521501891_item	3222503	et	3	main
kaks	doc_491521501891_item	3222514	et	3	main
laud	doc_491521501891_item	3222515	et	4	main
mul	doc_491521501891_item	3222516	et	3	main
on	doc_491521501891_item	3222517	et	4	main
töödest	doc_491521501891_item	3222521	et	3	main
le	doc_491521501891_item	3222529	et	4	main
jääda	doc_491521501891_item	3222532	et	4	main
ks	doc_491521501891_item	3222534	et	4	main
pidevalt	doc_491521501891_item	3222541	et	4	main
puhul	doc_491521501891_item	3222556	et	4	main
on	doc_491521501891_item	3222570	et	4	main
on	doc_491521501891_item	3222576	et	4	main
ja	doc_491521501891_item	3222580	et	3	main
käändelõpp	doc_491521501891_item	3222581	et	4	main
seda	doc_491521501891_item	3222582	et	3	main
kas	doc_491521501891_item	3222583	et	3	main
on	doc_491521501891_item	3222584	et	4	main
saaremaal	doc_491521501891_item	3222585	et	4	main
voi	doc_491521501891_item	3222586	et	4	main
saaremaas	doc_491521501891_item	3222587	et	3	main
ütleb	doc_491521501891_item	3222588	et	3	main
eestlasele	doc_491521501891_item	3222589	et	3	main
keelevaist	doc_491521501891_item	3222590	et	3	main
kohtla-järves	doc_491521501891_item	3222591	et	4	main
saaremaas	doc_491521501891_item	3222592	et	3	main
nõmmes	doc_491521501891_item	3222593	et	4	main
piritas	doc_491521501891_item	3222594	et	4	main
müts	doc_491521501891_item	3222595	et	4	main
on	doc_491521501891_item	3222596	et	4	main
peas	doc_491521501891_item	3222597	et	4	main
aga	doc_491521501891_item	3222598	et	3	main
vene	doc_491521501891_item	3222599	et	4	main
keeles	doc_491521501891_item	3222600	et	4	main
на	doc_491521501891_item	3222601	et	2	main
saabas	doc_491521501891_item	3222606	et	3	main
jalas	doc_491521501891_item	3222608	et	4	main
kinnas	doc_491521501891_item	3222609	et	3	main
otsest	doc_491521501891_item	3222614	et	4	main
vastet	doc_491521501891_item	3222615	et	3	main
pole	doc_491521501891_item	3222616	et	3	main
eesti	doc_491521501891_item	3222620	et	4	main
käänamine	doc_491521501891_item	3222627	et	4	main
ja	doc_491521501891_item	3222628	et	3	main
kasutamine	doc_491521501891_item	3222629	et	4	main
kui	doc_491521501891_item	3222630	et	3	main
ette	doc_491521501891_item	3222633	et	4	main
lihsam	doc_491521501891_item	3222640	et	4	main
arvsõna	doc_491521501891_item	3222643	et	4	main
ei	doc_491521501891_item	3222702	et	4	main
keeles	doc_491521501891_item	3222719	et	4	main
лет	doc_491521501891_item	3222747	et	2	main
on	doc_491521501891_item	3222750	et	4	main
üks	doc_491521501891_item	3222752	et	3	main
мне	doc_491521501891_item	3222756	et	2	main
ka	doc_491521501891_item	3222757	et	3	main
kuupäeva	doc_491521501891_item	3222758	et	4	main
on	doc_491521501891_item	3222765	et	4	main
on	doc_491521501891_item	3222769	et	4	main
kolmkümmenes	doc_491521501891_item	3222770	et	4	main
kaks	doc_491521501891_item	3222510	et	3	main
seinalambid	doc_491521501891_item	3222511	et	3	main
vaja	doc_491521501891_item	3222518	et	4	main
vead	doc_491521501891_item	3222540	et	4	main
segamini	doc_491521501891_item	3222543	et	4	main
on	doc_491521501891_item	3222545	et	4	main
kui	doc_491521501891_item	3222550	et	3	main
meelde	doc_491521501891_item	3222553	et	3	main
saarte	doc_491521501891_item	3222555	et	3	main
1	doc_491521501891_item	3222558	et	2	main
lõpus	doc_491521501891_item	3222559	et	4	main
ja	doc_491521501891_item	3222560	et	3	main
mitte	doc_491521501891_item	3222561	et	3	main
s	doc_491521501891_item	3222562	et	4	main
vead	doc_491521501891_item	3222569	et	4	main
vene	doc_491521501891_item	3222574	et	4	main
keeles	doc_491521501891_item	3222575	et	4	main
b	doc_491521501891_item	3222579	et	4	main
on	doc_491521501891_item	3222610	et	4	main
kasutamine	doc_491521501891_item	3222624	et	4	main
küsimus	doc_491521501891_item	3222631	et	4	main
natuke	doc_491521501891_item	3222639	et	4	main
esineb	doc_491521501891_item	3222644	et	3	main
kadripäev	doc_491521501891_item	3222647	et	3	main
on	doc_491521501891_item	3222652	et	4	main
juhus	doc_491521501891_item	3222655	et	4	main
kui	doc_491521501891_item	3222656	et	3	main
see	doc_491521501891_item	3222657	et	3	main
esimese	doc_491521501891_item	3222658	et	3	main
ikka	doc_491521501891_item	3222662	et	4	main
öeldakse	doc_491521501891_item	3222663	et	3	main
kahekümmend	doc_491521501891_item	3222664	et	4	main
viis	doc_491521501891_item	3222665	et	4	main
novembril	doc_491521501891_item	3222666	et	3	main
muutu	doc_491521501891_item	3222703	et	4	main
nagu	doc_491521501891_item	3222704	et	3	main
eesti	doc_491521501891_item	3222705	et	4	main
keeles	doc_491521501891_item	3222706	et	4	main
vanust	doc_491521501891_item	3222725	et	4	main
öeldakse	doc_491521501891_item	3222726	et	3	main
ma	doc_491521501891_item	3222727	et	3	main
olen	doc_491521501891_item	3222728	et	3	main
aga	doc_491521501891_item	3222736	et	3	main
keeles	doc_491521501891_item	3222738	et	4	main
vaid	doc_491521501891_item	3222740	et	3	main
üks	doc_491521501891_item	3222741	et	3	main
ja	doc_491521501891_item	3222742	et	3	main
kirjutamine	doc_491521501891_item	3222761	et	4	main
valmistab	doc_491521501891_item	3222762	et	3	main
kolmkümmend	doc_491521501891_item	3222766	et	4	main
kolmekümnes	doc_491521501891_item	3222780	et	4	main
on	doc_491521501891_item	3222783	et	4	main
need	doc_491521501891_item	3222811	et	3	main
tähendus	doc_491521501891_item	3222818	et	4	main
arusaamatuks	doc_491521501891_item	3222819	et	4	main
just	doc_491521501891_item	3222820	et	3	main
ilusalt	doc_491521501891_item	3222829	et	4	main
põhjus	doc_491521501891_item	3222530	et	4	main
ebaselgena	doc_491521501891_item	3222533	et	3	main
peaaegu	doc_491521501891_item	3222535	et	3	main
igaühe	doc_491521501891_item	3222536	et	4	main
oli	doc_491521501891_item	3222537	et	3	main
kas	doc_491521501891_item	3222544	et	3	main
hiiumaal	doc_491521501891_item	3222546	et	4	main
või	doc_491521501891_item	3222547	et	4	main
siis	doc_491521501891_item	3222563	et	3	main
kohtla-järvel	doc_491521501891_item	3222565	et	4	main
põltsamaal	doc_491521501891_item	3222566	et	4	main
tapal	doc_491521501891_item	3222567	et	3	main
jne	doc_491521501891_item	3222568	et	4	main
on	doc_491521501891_item	3222604	et	4	main
kaelas	doc_491521501891_item	3222605	et	4	main
vene	doc_491521501891_item	3222612	et	4	main
seega	doc_491521501891_item	3222618	et	4	main
raskusi	doc_491521501891_item	3222625	et	4	main
arvsõna	doc_491521501891_item	3222626	et	4	main
on	doc_491521501891_item	3222632	et	4	main
antud	doc_491521501891_item	3222634	et	4	main
mitu	doc_491521501891_item	3222635	et	4	main
aga	doc_491521501891_item	3222641	et	3	main
n	doc_491521501891_item	3222646	et	4	main
on	doc_491521501891_item	3222648	et	4	main
novembril	doc_491521501891_item	3222650	et	3	main
siis	doc_491521501891_item	3222651	et	3	main
üsna	doc_491521501891_item	3222653	et	3	main
harv	doc_491521501891_item	3222654	et	3	main
õigesti	doc_491521501891_item	3222660	et	3	main
öeldakse	doc_491521501891_item	3222661	et	3	main
viiel	doc_491521501891_item	3222671	et	3	main
novemril	doc_491521501891_item	3222672	et	4	main
jne	doc_491521501891_item	3222673	et	4	main
kohati	doc_491521501891_item	3222674	et	4	main
tundub	doc_491521501891_item	3222675	et	3	main
nagu	doc_491521501891_item	3222676	et	3	main
põhjuseks	doc_491521501891_item	3222677	et	3	main
oleks	doc_491521501891_item	3222678	et	3	main
see	doc_491521501891_item	3222679	et	3	main
et	doc_491521501891_item	3222680	et	3	main
teatakse	doc_491521501891_item	3222681	et	3	main
arvsõna	doc_491521501891_item	3222682	et	4	main
käändub	doc_491521501891_item	3222683	et	3	main
kuidagi	doc_491521501891_item	3222684	et	3	main
ja	doc_491521501891_item	3222686	et	3	main
siis	doc_491521501891_item	3222687	et	3	main
keeruliselt	doc_491521501891_item	3222685	et	4	main
tulebki	doc_491521501891_item	3222688	et	3	main
vastuseks	doc_491521501891_item	3222689	et	4	main
kõikvõimalikke	doc_491521501891_item	3222690	et	3	main
variante	doc_491521501891_item	3222691	et	3	main
nad	doc_491521501891_item	3222692	et	3	main
ei	doc_491521501891_item	3222693	et	4	main
saa	doc_491521501891_item	3222694	et	4	main
süsteemist	doc_491521501891_item	3222695	et	4	main
aru	doc_491521501891_item	3222696	et	4	main
pealegi	doc_491521501891_item	3222697	et	4	main
arvsõna	doc_491521501891_item	3222698	et	4	main
ise	doc_491521501891_item	3222699	et	4	main
vene	doc_491521501891_item	3222700	et	4	main
keeles	doc_491521501891_item	3222701	et	4	main
keeles	doc_491521501891_item	3222613	et	4	main
tekitab	doc_491521501891_item	3222619	et	3	main
keeles	doc_491521501891_item	3222621	et	4	main
nendes	doc_491521501891_item	3222622	et	4	main
sõnade	doc_491521501891_item	3222623	et	3	main
on	doc_491521501891_item	3222638	et	4	main
kui	doc_491521501891_item	3222642	et	3	main
kakskümmend	doc_491521501891_item	3222667	et	4	main
viiendal	doc_491521501891_item	3222668	et	3	main
november	doc_491521501891_item	3222669	et	3	main
двадцать	doc_491521501891_item	3222709	et	2	main
ноября	doc_491521501891_item	3222711	et	2	main
lugu	doc_491521501891_item	3222713	et	4	main
eesti	doc_491521501891_item	3222718	et	4	main
mitu	doc_491521501891_item	3222721	et	4	main
varianti	doc_491521501891_item	3222722	et	4	main
kuidas	doc_491521501891_item	3222723	et	3	main
oma	doc_491521501891_item	3222724	et	4	main
ma	doc_491521501891_item	3222731	et	3	main
aastat	doc_491521501891_item	3222734	et	3	main
ütlemine	doc_491521501891_item	3222759	et	4	main
ja	doc_491521501891_item	3222760	et	3	main
tegemist	doc_491521501891_item	3222784	et	4	main
первый	doc_491521501891_item	3222802	et	2	main
kõige	doc_491521501891_item	3222807	et	4	main
sagedamini	doc_491521501891_item	3222808	et	4	main
vead	doc_491521501891_item	3222825	et	4	main
korteris	doc_491521501891_item	3222830	et	3	main
oskab	doc_491521501891_item	3222867	et	3	main
vanuse	doc_491521501891_item	3222716	et	4	main
ütlemisega	doc_491521501891_item	3222717	et	2	main
kümne	doc_491521501891_item	3222729	et	4	main
aastane	doc_491521501891_item	3222730	et	4	main
kümme	doc_491521501891_item	3222733	et	3	main
vene	doc_491521501891_item	3222737	et	4	main
on	doc_491521501891_item	3222739	et	4	main
õige	doc_491521501891_item	3222743	et	4	main
variant	doc_491521501891_item	3222744	et	3	main
мне	doc_491521501891_item	3222745	et	2	main
десят	doc_491521501891_item	3222746	et	2	main
neil	doc_491521501891_item	3222749	et	4	main
vaid	doc_491521501891_item	3222751	et	3	main
võimalik	doc_491521501891_item	3222753	et	3	main
variant	doc_491521501891_item	3222754	et	3	main
mul	doc_491521501891_item	3222755	et	3	main
täna	doc_491521501891_item	3222764	et	4	main
kui	doc_491521501891_item	3222782	et	3	main
voi	doc_491521501891_item	3222786	et	4	main
teise	doc_491521501891_item	3222787	et	4	main
kuupäevaga	doc_491521501891_item	3222788	et	3	main
ei	doc_491521501891_item	3222789	et	4	main
aita	doc_491521501891_item	3222790	et	4	main
ka	doc_491521501891_item	3222791	et	3	main
see	doc_491521501891_item	3222792	et	3	main
küsimus	doc_491521501891_item	3222793	et	4	main
kuigi	doc_491521501891_item	3222794	et	3	main
vene	doc_491521501891_item	3222795	et	4	main
keeles	doc_491521501891_item	3222796	et	4	main
on	doc_491521501891_item	3222797	et	4	main
vaste	doc_491521501891_item	3222798	et	4	main
olemas	doc_491521501891_item	3222799	et	4	main
один	doc_491521501891_item	3222800	et	2	main
и	doc_491521501891_item	3222801	et	2	main
november	doc_491521501891_item	3222771	et	3	main
kui	doc_491521501891_item	3222772	et	3	main
küsida	doc_491521501891_item	3222773	et	3	main
et	doc_491521501891_item	3222774	et	3	main
mitmes	doc_491521501891_item	3222775	et	4	main
siis	doc_491521501891_item	3222776	et	3	main
tuleb	doc_491521501891_item	3222777	et	3	main
meelde	doc_491521501891_item	3222778	et	3	main
et	doc_491521501891_item	3222779	et	3	main
esimese	doc_491521501891_item	3222785	et	3	main
ühtlasi	doc_491521501891_item	3222809	et	4	main
vead	doc_491521501891_item	3222813	et	4	main
selliste	doc_491521501891_item	3222821	et	4	main
vigade	doc_491521501891_item	3222822	et	3	main
pärast	doc_491521501891_item	3222823	et	4	main
neid	doc_491521501891_item	3222804	et	4	main
esineb	doc_491521501891_item	3222806	et	3	main
on	doc_491521501891_item	3222810	et	4	main
sest	doc_491521501891_item	3222814	et	4	main
vahel	doc_491521501891_item	3222815	et	4	main
võib	doc_491521501891_item	3222816	et	3	main
jääda	doc_491521501891_item	3222817	et	4	main
pärinevad	doc_491521501891_item	3222826	et	4	main
tudengite	doc_491521501891_item	3222827	et	3	main
kus	doc_491521501891_item	3222831	et	3	main
kortereid	doc_491521501891_item	3222833	et	3	main
mida	doc_491521501891_item	3222834	et	4	main
palju	doc_491521501891_item	3222835	et	4	main
ilus	doc_491521501891_item	3222836	et	4	main
kasse	doc_491521501891_item	3222837	et	3	main
kokkuvõtteks	doc_491521501891_item	3222838	et	3	main
võib	doc_491521501891_item	3222839	et	3	main
öelda	doc_491521501891_item	3222840	et	4	main
et	doc_491521501891_item	3222841	et	3	main
paljud	doc_491521501891_item	3222842	et	3	main
vead	doc_491521501891_item	3222843	et	4	main
on	doc_491521501891_item	3222844	et	4	main
tingitud	doc_491521501891_item	3222845	et	4	main
mõjust	doc_491521501891_item	3222847	et	3	main
ja	doc_491521501891_item	3222849	et	3	main
käänded	doc_491521501891_item	3222850	et	3	main
emakeele	doc_491521501891_item	3222846	et	4	main
on	doc_491521501891_item	3222851	et	4	main
ju	doc_491521501891_item	3222852	et	3	main
lauseehitus	doc_491521501891_item	3222848	et	4	main
erinevad	doc_491521501891_item	3222853	et	4	main
põhiliseks	doc_491521501891_item	3222854	et	3	main
põhjuseks	doc_491521501891_item	3222855	et	3	main
ongi	doc_491521501891_item	3222856	et	4	main
see	doc_491521501891_item	3222857	et	3	main
et	doc_491521501891_item	3222858	et	3	main
venelane	doc_491521501891_item	3222859	et	3	main
kasutab	doc_491521501891_item	3222860	et	3	main
eesti	doc_491521501891_item	3222861	et	4	main
keelt	doc_491521501891_item	3222862	et	4	main
väljapool	doc_491521501891_item	3222863	et	4	main
tundi	doc_491521501891_item	3222864	et	4	main
harva	doc_491521501891_item	3222865	et	4	main
näiteks	doc_491521501891_item	3222866	et	4	main
mina	doc_491521501891_item	3222870	et	4	main
loen	doc_491521501891_item	3222871	et	3	main
tallinna	doc_491521501867_item	3233605	et	4	main
juhendaja	doc_491521501867_item	3233618	et	4	main
kasutatud	doc_491521501867_item	3233633	et	4	main
valdkonnas	doc_491521501867_item	3233642	et	4	main
eksitus	doc_491521501867_item	3233663	et	4	main
loog	doc_491521501867_item	3233670	et	3	main
ja	doc_491521501867_item	3233671	et	3	main
mis	doc_491521501867_item	3233681	et	4	main
viitab	doc_491521501867_item	3233682	et	3	main
kindla	doc_491521501867_item	3233683	et	3	main
oskuse	doc_491521501867_item	3233684	et	3	main
puudumisele	doc_491521501867_item	3233685	et	4	main
reegleid	doc_491521501867_item	3233691	et	3	main
või	doc_491521501867_item	3233695	et	4	main
hoopis	doc_491521501867_item	3233698	et	3	main
viga	doc_491521501867_item	3233700	et	4	main
kerge	doc_491521501867_item	3233703	et	4	main
pedagoogikaülikool	doc_491521501867_item	3233606	et	4	main
keele	doc_491521501867_item	3233611	et	4	main
analüüs	doc_491521501867_item	3233616	et	3	main
sissejuhatus	doc_491521501867_item	3233624	et	4	main
vigade	doc_491521501867_item	3233627	et	3	main
sissejuhatus	doc_491521501867_item	3233635	et	4	main
võimeline	doc_491521501867_item	3233645	et	4	main
mis	doc_491521501867_item	3233664	et	4	main
põhjustab	doc_491521501867_item	3233665	et	3	main
1999	doc_491521501867_item	3233674	et	2	main
viga	doc_491521501867_item	3233677	et	4	main
kui	doc_491521501867_item	3233678	et	3	main
siastemaatilist	doc_491521501867_item	3233679	et	4	main
vigu	doc_491521501867_item	3233686	et	3	main
tehakse	doc_491521501867_item	3233687	et	3	main
ei	doc_491521501867_item	3233689	et	4	main
toimida	doc_491521501867_item	3233693	et	3	main
juhtida	doc_491521501867_item	3233711	et	4	main
õpilasele	doc_491521501867_item	3233712	et	3	main
hinnet	doc_491521501867_item	3233713	et	3	main
tehtud	doc_491521501867_item	3233718	et	4	main
hulka	doc_491521501867_item	3233720	et	4	main
raskusastet	doc_491521501867_item	3233725	et	4	main
õigekirjavead	doc_491521501867_item	3233736	et	3	main
vormimoodustusvead	doc_491521501867_item	3233740	et	4	main
hindamisel	doc_491521501867_item	3233742	et	4	main
arvestada	doc_491521501867_item	3233745	et	3	main
emakeeles	doc_491521501867_item	3233753	et	4	main
esinevad	doc_491521501867_item	3233754	et	4	main
kõnelemisel	doc_491521501867_item	3233762	et	4	main
käesolev	doc_491521501867_item	3233763	et	3	main
uurimistöö	doc_491521501867_item	3233764	et	4	main
vigade	doc_491521501867_item	3233768	et	3	main
õpilaste	doc_491521501867_item	3233775	et	4	main
kodutööde	doc_491521501867_item	3233777	et	3	main
alusel	doc_491521501867_item	3233780	et	4	main
arvates	doc_491521501867_item	3233785	et	4	main
tegemist	doc_491521501867_item	3233786	et	4	main
isegi	doc_491521501867_item	3233792	et	4	main
alusel	doc_491521501867_item	3233796	et	4	main
analüüsida	doc_491521501867_item	3233798	et	3	main
oma	doc_491521501867_item	3233805	et	4	main
kes	doc_491521501867_item	3233808	et	4	main
aitas	doc_491521501867_item	3233809	et	3	main
on	doc_491521501867_item	3233824	et	4	main
ta	doc_491521501867_item	3233834	et	4	main
märkab	doc_491521501867_item	3233835	et	3	main
juhtub	doc_491521501867_item	3233842	et	3	main
mida	doc_491521501867_item	3233846	et	4	main
hullemaks	doc_491521501867_item	3233850	et	4	main
läheb	doc_491521501867_item	3233851	et	3	main
saab	doc_491521501867_item	3233891	et	3	main
samas	doc_491521501867_item	3233904	et	4	main
tööd	doc_491521501867_item	3233907	et	4	main
rohkem	doc_491521501867_item	3233910	et	4	main
või	doc_491521501867_item	3233918	et	4	main
sellest	doc_491521501867_item	3233923	et	4	main
ei	doc_491521501867_item	3233926	et	4	main
analüüs	doc_491521501867_item	3233604	et	3	main
teaduskond	doc_491521501867_item	3233609	et	3	main
e	doc_491521501867_item	3233620	et	4	main
perekonnanimi	doc_491521501867_item	3233621	et	3	main
2001	doc_491521501867_item	3233622	et	2	main
rühmitamine	doc_491521501867_item	3233628	et	4	main
ja	doc_491521501867_item	3233629	et	3	main
põhjuste	doc_491521501867_item	3233630	et	3	main
seletamine	doc_491521501867_item	3233631	et	4	main
kokkuvõte	doc_491521501867_item	3233632	et	3	main
keeleoskust	doc_491521501867_item	3233636	et	3	main
vastavalt	doc_491521501867_item	3233638	et	4	main
sellele	doc_491521501867_item	3233639	et	4	main
kui	doc_491521501867_item	3233640	et	3	main
kaasa	doc_491521501867_item	3233646	et	4	main
krista	doc_491521501867_item	3233672	et	4	main
kerge	doc_491521501867_item	3233673	et	4	main
defineerinud	doc_491521501867_item	3233676	et	4	main
kui	doc_491521501867_item	3233688	et	3	main
kui	doc_491521501867_item	3233696	et	3	main
sellised	doc_491521501867_item	3233697	et	4	main
hõlpsasti	doc_491521501867_item	3233706	et	3	main
kõrvaldatav	doc_491521501867_item	3233707	et	4	main
pannes	doc_491521501867_item	3233714	et	4	main
vigade	doc_491521501867_item	3233719	et	3	main
on	doc_491521501867_item	3233737	et	4	main
seda	doc_491521501867_item	3233744	et	3	main
pidama	doc_491521501867_item	3233751	et	4	main
ole	doc_491521501867_item	3233757	et	4	main
keele	doc_491521501867_item	3233760	et	4	main
analüüsimisele	doc_491521501867_item	3233769	et	4	main
uurimus	doc_491521501867_item	3233770	et	3	main
on	doc_491521501867_item	3233771	et	4	main
kirjandite	doc_491521501867_item	3233776	et	3	main
kontrolltööde	doc_491521501867_item	3233779	et	3	main
mind	doc_491521501867_item	3233810	et	4	main
uurimismaterjali	doc_491521501867_item	3233811	et	4	main
ei	doc_491521501867_item	3233817	et	4	main
märka	doc_491521501867_item	3233818	et	4	main
arusaamatutel	doc_491521501867_item	3233830	et	4	main
põhjustel	doc_491521501867_item	3233831	et	3	main
ta	doc_491521501867_item	3233839	et	4	main
et	doc_491521501867_item	3233845	et	3	main
seda	doc_491521501867_item	3233849	et	3	main
kirjalik	doc_491521501867_item	3233852	et	3	main
tekst	doc_491521501867_item	3233853	et	3	main
muutub	doc_491521501867_item	3233854	et	3	main
arusaamatuks	doc_491521501867_item	3233855	et	4	main
sama	doc_491521501867_item	3233896	et	4	main
kirjalikul	doc_491521501867_item	3233898	et	3	main
kujul	doc_491521501867_item	3233899	et	4	main
teenida	doc_491521501867_item	3233903	et	3	main
õpetajal	doc_491521501867_item	3233909	et	4	main
aega	doc_491521501867_item	3233911	et	4	main
mõelda	doc_491521501867_item	3233912	et	4	main
kas	doc_491521501867_item	3233913	et	3	main
tõsine	doc_491521501867_item	3233919	et	4	main
et	doc_491521501867_item	3233924	et	3	main
reegel	doc_491521501867_item	3233925	et	3	main
seletamine	doc_491521501867_item	3233934	et	4	main
nii	doc_491521501867_item	3233935	et	3	main
õpetajad	doc_491521501867_item	3233936	et	4	main
kui	doc_491521501867_item	3233937	et	3	main
õpilased	doc_491521501867_item	3233938	et	3	main
kasutab	doc_491521501867_item	3233959	et	3	main
vale	doc_491521501867_item	3233960	et	4	main
ei	doc_491521501867_item	3233964	et	4	main
on	doc_491521501867_item	3233973	et	4	main
juba	doc_491521501867_item	3233974	et	3	main
seetõttu	doc_491521501867_item	3233986	et	3	main
ei	doc_491521501867_item	3233987	et	4	main
nt	doc_491521501867_item	3233993	et	4	main
eesti	doc_491521501867_item	3233607	et	4	main
õppetool	doc_491521501867_item	3233612	et	3	main
eesnimi	doc_491521501867_item	3233613	et	3	main
perekonnanimi	doc_491521501867_item	3233614	et	3	main
vigade	doc_491521501867_item	3233615	et	3	main
sisukord	doc_491521501867_item	3233623	et	3	main
registreerimine	doc_491521501867_item	3233626	et	4	main
mitmes	doc_491521501867_item	3233641	et	4	main
mai	doc_491521501867_item	3233669	et	4	main
on	doc_491521501867_item	3233675	et	4	main
tea	doc_491521501867_item	3233690	et	4	main
õigesti	doc_491521501867_item	3233694	et	3	main
eksimus	doc_491521501867_item	3233704	et	4	main
arvesse	doc_491521501867_item	3233717	et	4	main
ning	doc_491521501867_item	3233721	et	3	main
arvata	doc_491521501867_item	3233727	et	4	main
et	doc_491521501867_item	3233735	et	3	main
kui	doc_491521501867_item	3233739	et	3	main
ning	doc_491521501867_item	3233741	et	3	main
tuleb	doc_491521501867_item	3233743	et	3	main
eesti	doc_491521501867_item	3233746	et	4	main
keele	doc_491521501867_item	3233747	et	4	main
et	doc_491521501867_item	3233752	et	3	main
on	doc_491521501867_item	3233765	et	4	main
tehtud	doc_491521501867_item	3233772	et	4	main
10	doc_491521501867_item	3233773	et	2	main
klassi	doc_491521501867_item	3233774	et	4	main
ja	doc_491521501867_item	3233778	et	3	main
õpetaja	doc_491521501867_item	3233784	et	4	main
on	doc_491521501867_item	3233791	et	4	main
tööde	doc_491521501867_item	3233795	et	3	main
koolipoolset	doc_491521501867_item	3233806	et	3	main
registreerimine	doc_491521501867_item	3233814	et	4	main
kõiki	doc_491521501867_item	3233819	et	4	main
vigu	doc_491521501867_item	3233820	et	3	main
sest	doc_491521501867_item	3233821	et	4	main
paljud	doc_491521501867_item	3233822	et	3	main
ootamatud	doc_491521501867_item	3233825	et	4	main
ja	doc_491521501867_item	3233827	et	3	main
neid	doc_491521501867_item	3233828	et	4	main
tehakse	doc_491521501867_item	3233829	et	3	main
oska	doc_491521501867_item	3233838	et	4	main
nii	doc_491521501867_item	3233844	et	3	main
rohkem	doc_491521501867_item	3233847	et	4	main
parandada	doc_491521501867_item	3233848	et	3	main
kui	doc_491521501867_item	3233889	et	3	main
suulise	doc_491521501867_item	3233892	et	4	main
vastuse	doc_491521501867_item	3233893	et	3	main
viie	doc_491521501867_item	3233894	et	3	main
võib	doc_491521501867_item	3233895	et	3	main
tekst	doc_491521501867_item	3233897	et	3	main
välja	doc_491521501867_item	3233902	et	4	main
viga	doc_491521501867_item	3233914	et	4	main
viga	doc_491521501867_item	3233920	et	4	main
ole	doc_491521501867_item	3233927	et	4	main
selgeks	doc_491521501867_item	3233928	et	3	main
oskavad	doc_491521501867_item	3233939	et	4	main
õppija	doc_491521501867_item	3233958	et	4	main
saada	doc_491521501867_item	3233969	et	4	main
tehtud	doc_491521501867_item	3233976	et	4	main
kindlasti	doc_491521501867_item	3233977	et	3	main
ole	doc_491521501867_item	3233988	et	4	main
võimalik	doc_491521501867_item	3233989	et	3	main
mulle	doc_491521501867_item	3233994	et	4	main
üldse	doc_491521501867_item	3233995	et	3	main
põllumajandussaated	doc_491521501867_item	3234001	et	3	main
filoloogia	doc_491521501867_item	3233608	et	4	main
eesti	doc_491521501867_item	3233610	et	4	main
uurimistöö	doc_491521501867_item	3233617	et	4	main
dots	doc_491521501867_item	3233619	et	4	main
vigade	doc_491521501867_item	3233625	et	3	main
kirjandus	doc_491521501867_item	3233634	et	3	main
hinnatakse	doc_491521501867_item	3233637	et	4	main
inimene	doc_491521501867_item	3233643	et	3	main
on	doc_491521501867_item	3233644	et	4	main
rääkima	doc_491521501867_item	3233647	et	3	main
kui	doc_491521501867_item	3233648	et	3	main
õigesti	doc_491521501867_item	3233649	et	3	main
ta	doc_491521501867_item	3233650	et	4	main
seda	doc_491521501867_item	3233651	et	3	main
teeb	doc_491521501867_item	3233652	et	3	main
viga	doc_491521501867_item	3233653	et	4	main
on	doc_491521501867_item	3233654	et	4	main
kõrvalekalle	doc_491521501867_item	3233655	et	3	main
kehtivast	doc_491521501867_item	3233656	et	4	main
normist	doc_491521501867_item	3233657	et	4	main
keeleviga	doc_491521501867_item	3233658	et	4	main
võib	doc_491521501867_item	3233659	et	3	main
olla	doc_491521501867_item	3233660	et	3	main
vääratus	doc_491521501867_item	3233661	et	4	main
või	doc_491521501867_item	3233662	et	4	main
arusaamatuse	doc_491521501867_item	3233666	et	4	main
ja	doc_491521501867_item	3233667	et	3	main
valestimõistmist	doc_491521501867_item	3233668	et	3	main
eksimist	doc_491521501867_item	3233680	et	4	main
kuidas	doc_491521501867_item	3233692	et	3	main
puuduvad	doc_491521501867_item	3233699	et	4	main
võib	doc_491521501867_item	3233701	et	3	main
olla	doc_491521501867_item	3233702	et	3	main
ja	doc_491521501867_item	3233705	et	3	main
kui	doc_491521501867_item	3233708	et	3	main
sellele	doc_491521501867_item	3233709	et	4	main
tähelepanu	doc_491521501867_item	3233710	et	4	main
võtab	doc_491521501867_item	3233715	et	3	main
võiks	doc_491521501867_item	3233726	et	4	main
või	doc_491521501867_item	3233734	et	4	main
peab	doc_491521501867_item	3233749	et	4	main
meeles	doc_491521501867_item	3233750	et	3	main
ei	doc_491521501867_item	3233756	et	4	main
sama	doc_491521501867_item	3233759	et	4	main
võõrkeelena	doc_491521501867_item	3233761	et	3	main
õpilaste	doc_491521501867_item	3233767	et	4	main
keele	doc_491521501867_item	3233783	et	4	main
peamiselt	doc_491521501867_item	3233788	et	4	main
kesktasemega	doc_491521501867_item	3233789	et	3	main
mõnedel	doc_491521501867_item	3233790	et	3	main
nende	doc_491521501867_item	3233794	et	4	main
püüdsingi	doc_491521501867_item	3233797	et	3	main
õpetaja	doc_491521501867_item	3233716	et	4	main
enamasti	doc_491521501867_item	3233722	et	4	main
ka	doc_491521501867_item	3233723	et	3	main
nende	doc_491521501867_item	3233724	et	4	main
et	doc_491521501867_item	3233728	et	3	main
kuulata	doc_491521501867_item	3233729	et	4	main
on	doc_491521501867_item	3233730	et	4	main
kergem	doc_491521501867_item	3233731	et	4	main
kui	doc_491521501867_item	3233732	et	3	main
rääkida	doc_491521501867_item	3233733	et	3	main
lihtsamad	doc_491521501867_item	3233738	et	4	main
õpetaja	doc_491521501867_item	3233748	et	4	main
vead	doc_491521501867_item	3233755	et	4	main
olulised	doc_491521501867_item	3233758	et	4	main
pühendatud	doc_491521501867_item	3233766	et	4	main
nende	doc_491521501867_item	3233781	et	4	main
eesti	doc_491521501867_item	3233782	et	4	main
on	doc_491521501867_item	3233787	et	4	main
algtase	doc_491521501867_item	3233793	et	3	main
vigu	doc_491521501867_item	3233799	et	3	main
ja	doc_491521501867_item	3233800	et	3	main
põhjusi	doc_491521501867_item	3233802	et	3	main
tahaksin	doc_491521501867_item	3233803	et	3	main
nende	doc_491521501867_item	3233801	et	4	main
tänada	doc_491521501867_item	3233804	et	3	main
juhendajat	doc_491521501867_item	3233807	et	4	main
algaja	doc_491521501867_item	3233815	et	4	main
õpetaja	doc_491521501867_item	3233816	et	4	main
isegi	doc_491521501867_item	3233832	et	4	main
kui	doc_491521501867_item	3233833	et	3	main
neid	doc_491521501867_item	3233840	et	4	main
käsitleda	doc_491521501867_item	3233841	et	3	main
kõnelev	doc_491521501867_item	3233856	et	4	main
õppija	doc_491521501867_item	3233857	et	4	main
silmatorkavaks	doc_491521501867_item	3233887	et	3	main
teha	doc_491521501867_item	3233888	et	3	main
õppija	doc_491521501867_item	3233890	et	4	main
nelja-kolme	doc_491521501867_item	3233901	et	4	main
otsida	doc_491521501867_item	3233812	et	4	main
vigade	doc_491521501867_item	3233813	et	3	main
neist	doc_491521501867_item	3233823	et	4	main
ebaloogilised	doc_491521501867_item	3233826	et	4	main
vigu	doc_491521501867_item	3233836	et	3	main
ei	doc_491521501867_item	3233837	et	4	main
ju	doc_491521501867_item	3233843	et	3	main
kaotab	doc_491521501867_item	3233858	et	3	main
järje	doc_491521501867_item	3233859	et	3	main
ja	doc_491521501867_item	3233860	et	3	main
jääb	doc_491521501867_item	3233861	et	3	main
sõnatuks	doc_491521501867_item	3233862	et	4	main
vigu	doc_491521501867_item	3233863	et	3	main
on	doc_491521501867_item	3233864	et	4	main
kerge	doc_491521501867_item	3233865	et	4	main
leida	doc_491521501867_item	3233866	et	3	main
kirjakeelest	doc_491521501867_item	3233867	et	4	main
mis	doc_491521501867_item	3233868	et	4	main
on	doc_491521501867_item	3233869	et	4	main
õpetajale	doc_491521501867_item	3233870	et	4	main
nähtav	doc_491521501867_item	3233871	et	4	main
või	doc_491521501867_item	3233872	et	4	main
kuuldav	doc_491521501867_item	3233873	et	4	main
arvan	doc_491521501867_item	3233874	et	3	main
et	doc_491521501867_item	3233875	et	3	main
kirjavigu	doc_491521501867_item	3233876	et	3	main
on	doc_491521501867_item	3233877	et	4	main
suhteliselt	doc_491521501867_item	3233878	et	4	main
mugav	doc_491521501867_item	3233879	et	3	main
parandada	doc_491521501867_item	3233880	et	3	main
sest	doc_491521501867_item	3233881	et	4	main
kirjalikul	doc_491521501867_item	3233882	et	3	main
tekstil	doc_491521501867_item	3233883	et	3	main
on	doc_491521501867_item	3233884	et	4	main
omadus	doc_491521501867_item	3233885	et	4	main
vead	doc_491521501867_item	3233886	et	4	main
ainult	doc_491521501867_item	3233900	et	4	main
parandades	doc_491521501867_item	3233908	et	3	main
eksitus	doc_491521501867_item	3233917	et	4	main
põhjustatud	doc_491521501867_item	3233922	et	4	main
rühmitamine	doc_491521501867_item	3233931	et	4	main
ja	doc_491521501867_item	3233932	et	3	main
põhjuste	doc_491521501867_item	3233933	et	3	main
mis	doc_491521501867_item	3233941	et	4	main
sõnavara	doc_491521501867_item	3233957	et	4	main
tõttu	doc_491521501867_item	3233963	et	4	main
ole	doc_491521501867_item	3233965	et	4	main
võimalik	doc_491521501867_item	3233966	et	3	main
lausest	doc_491521501867_item	3233967	et	4	main
kõik	doc_491521501867_item	3233972	et	4	main
puhkan	doc_491521501867_item	3233980	et	3	main
kõigidest	doc_491521501867_item	3233981	et	4	main
lausest	doc_491521501867_item	3233990	et	4	main
ei	doc_491521501867_item	3233996	et	4	main
kasutatud	doc_491521501867_item	3234005	et	4	main
oleks	doc_491521501867_item	3234007	et	3	main
ei	doc_491521501867_item	3234010	et	4	main
ansamblid	doc_491521501867_item	3234012	et	3	main
põhjus	doc_491521501867_item	3234026	et	4	main
ole	doc_491521501867_item	3234037	et	4	main
liittegusõnad	doc_491521501867_item	3234054	et	3	main
erinevast	doc_491521501867_item	3234057	et	4	main
tüvest	doc_491521501867_item	3234058	et	3	main
mis	doc_491521501867_item	3234059	et	4	main
tegelikult	doc_491521501867_item	3234065	et	4	main
tähendust	doc_491521501867_item	3234071	et	4	main
nt	doc_491521501867_item	3234074	et	4	main
ala	doc_491521501867_item	3234077	et	4	main
koormama	doc_491521501867_item	3234078	et	3	main
siirdistutama	doc_491521501867_item	3234079	et	4	main
mitte	doc_491521501867_item	3234080	et	3	main
teha	doc_491521501867_item	3234104	et	3	main
või	doc_491521501867_item	3234121	et	4	main
toimub	doc_491521501867_item	3234122	et	3	main
kutsumist	doc_491521501867_item	3234133	et	4	main
ma	doc_491521501867_item	3234142	et	3	main
ennast	doc_491521501867_item	3234146	et	4	main
mitte	doc_491521501867_item	3234150	et	3	main
nimisõnu	doc_491521501867_item	3234175	et	3	main
mitte	doc_491521501867_item	3234198	et	3	main
sel	doc_491521501867_item	3234201	et	3	main
täpne	doc_491521501867_item	3234205	et	3	main
kaal	doc_491521501867_item	3234206	et	3	main
kell	doc_491521501867_item	3234208	et	3	main
pärlid	doc_491521501867_item	3234210	et	3	main
kapsas	doc_491521501867_item	3234211	et	4	main
maasikas	doc_491521501867_item	3234213	et	4	main
maasikad	doc_491521501867_item	3234214	et	3	main
aetakse	doc_491521501867_item	3234215	et	3	main
segi	doc_491521501867_item	3234216	et	3	main
eesti	doc_491521501867_item	3234221	et	4	main
kui	doc_491521501867_item	3234224	et	3	main
on	doc_491521501867_item	3234226	et	4	main
ma	doc_491521501867_item	3234234	et	3	main
hästi	doc_491521501867_item	3234236	et	3	main
halvemini	doc_491521501867_item	3234250	et	4	main
ohtlikult	doc_491521501867_item	3234260	et	4	main
õpilased	doc_491521501867_item	3234267	et	3	main
meeles	doc_491521501867_item	3234269	et	3	main
on	doc_491521501867_item	3233905	et	4	main
kirjalikku	doc_491521501867_item	3233906	et	4	main
on	doc_491521501867_item	3233915	et	4	main
juhuslik	doc_491521501867_item	3233916	et	3	main
mis	doc_491521501867_item	3233921	et	4	main
õpitud	doc_491521501867_item	3233929	et	4	main
vigade	doc_491521501867_item	3233930	et	3	main
öelda	doc_491521501867_item	3233940	et	4	main
eesti	doc_491521501867_item	3233943	et	4	main
keeles	doc_491521501867_item	3233944	et	4	main
kõige	doc_491521501867_item	3233945	et	4	main
raskem	doc_491521501867_item	3233946	et	4	main
siin	doc_491521501867_item	3233947	et	4	main
on	doc_491521501867_item	3233948	et	4	main
toodud	doc_491521501867_item	3233949	et	4	main
keeletasandid	doc_491521501867_item	3233950	et	3	main
kus	doc_491521501867_item	3233951	et	3	main
10	doc_491521501867_item	3233952	et	2	main
klassi	doc_491521501867_item	3233953	et	4	main
õpilased	doc_491521501867_item	3233954	et	3	main
teevad	doc_491521501867_item	3233955	et	3	main
on	doc_491521501867_item	3233942	et	4	main
vigu	doc_491521501867_item	3233956	et	3	main
aru	doc_491521501867_item	3233968	et	4	main
ära	doc_491521501867_item	3233975	et	4	main
lause	doc_491521501867_item	3233982	et	4	main
on	doc_491521501867_item	3233984	et	4	main
ebaselge	doc_491521501867_item	3233985	et	4	main
meeldi	doc_491521501867_item	3233997	et	4	main
vanamuusika	doc_491521501867_item	3234002	et	4	main
on	doc_491521501867_item	3234004	et	4	main
parem-mulle	doc_491521501867_item	3234008	et	4	main
mis	doc_491521501867_item	3234013	et	4	main
muusikatja	doc_491521501867_item	3234016	et	4	main
põllumajandussaated	doc_491521501867_item	3234017	et	3	main
sagedasem	doc_491521501867_item	3234025	et	4	main
emakeele	doc_491521501867_item	3234028	et	4	main
keeles	doc_491521501867_item	3234053	et	4	main
kahest	doc_491521501867_item	3234056	et	4	main
kahest	doc_491521501867_item	3234066	et	4	main
abimäärsõnast	doc_491521501867_item	3234073	et	4	main
alakoormama	doc_491521501867_item	3234075	et	3	main
mitte	doc_491521501867_item	3234076	et	3	main
alla	doc_491521501867_item	3234088	et	3	main
mitte	doc_491521501867_item	3234090	et	3	main
enesekohaste	doc_491521501867_item	3234105	et	4	main
tegevus	doc_491521501867_item	3234116	et	4	main
on	doc_491521501867_item	3234117	et	4	main
suunatud	doc_491521501867_item	3234118	et	4	main
tegija	doc_491521501867_item	3234123	et	4	main
või	doc_491521501867_item	3234131	et	4	main
esile	doc_491521501867_item	3234132	et	3	main
tegemata	doc_491521501867_item	3234141	et	4	main
ei	doc_491521501867_item	3234154	et	4	main
vormis	doc_491521501867_item	3234179	et	4	main
ainsuses	doc_491521501867_item	3234184	et	4	main
jõulud-	doc_491521501867_item	3234185	et	3	main
рождество	doc_491521501867_item	3234186	et	2	main
tangud-крупа	doc_491521501867_item	3234187	et	2	main
пасха	doc_491521501867_item	3234189	et	2	main
jt	doc_491521501867_item	3234190	et	4	main
lumeta	doc_491521501867_item	3234204	et	4	main
määrsõna	doc_491521501867_item	3234219	et	4	main
keeles	doc_491521501867_item	3234222	et	4	main
sõnaliigil	doc_491521501867_item	3234225	et	3	main
arvsõnade	doc_491521501867_item	3234230	et	3	main
on	doc_491521501867_item	3234242	et	4	main
mitte	doc_491521501867_item	3234245	et	3	main
omadussõnade	doc_491521501867_item	3234261	et	3	main
raske	doc_491521501867_item	3234266	et	4	main
peavad	doc_491521501867_item	3234268	et	4	main
mille	doc_491521501867_item	3234304	et	3	main
pikam	doc_491521501867_item	3234325	et	4	main
paks	doc_491521501867_item	3234326	et	3	main
kurja	doc_491521501867_item	3234332	et	4	main
ebaselge	doc_491521501867_item	3234338	et	4	main
kui	doc_491521501867_item	3234339	et	3	main
tüvi	doc_491521501867_item	3234340	et	3	main
i	doc_491521501867_item	3234348	et	4	main
muutub	doc_491521501867_item	3234349	et	3	main
kallis	doc_491521501867_item	3234352	et	4	main
truuim	doc_491521501867_item	3234358	et	4	main
truim	doc_491521501867_item	3234359	et	4	main
mitte	doc_491521501867_item	3234360	et	3	main
truuim	doc_491521501867_item	3234361	et	4	main
näiteks	doc_491521501867_item	3234369	et	4	main
ja	doc_491521501867_item	3234371	et	3	main
ei	doc_491521501867_item	3234379	et	4	main
pähe	doc_491521501867_item	3234381	et	4	main
öelda	doc_491521501867_item	3234389	et	4	main
kaheksa	doc_491521501867_item	3234396	et	4	main
arvsõnad	doc_491521501867_item	3234398	et	3	main
olen	doc_491521501867_item	3234401	et	3	main
sündinud	doc_491521501867_item	3234402	et	4	main
tuhande	doc_491521501867_item	3234403	et	3	main
sõna	doc_491521501867_item	3233961	et	4	main
mille	doc_491521501867_item	3233962	et	3	main
nt	doc_491521501867_item	3233970	et	4	main
kui	doc_491521501867_item	3233971	et	3	main
ja	doc_491521501867_item	3233978	et	3	main
mina	doc_491521501867_item	3233979	et	4	main
sõnastus	doc_491521501867_item	3233983	et	4	main
aru	doc_491521501867_item	3233991	et	4	main
saada	doc_491521501867_item	3233992	et	4	main
vanamuusika	doc_491521501867_item	3233998	et	4	main
ansamblid	doc_491521501867_item	3233999	et	3	main
meeldi	doc_491521501867_item	3234011	et	4	main
morfoloogia	doc_491521501867_item	3234018	et	4	main
õppija	doc_491521501867_item	3234019	et	4	main
moodustab	doc_491521501867_item	3234020	et	3	main
vigaseid	doc_491521501867_item	3234021	et	4	main
grammatilisi	doc_491521501867_item	3234022	et	3	main
üks	doc_491521501867_item	3234024	et	3	main
ei	doc_491521501867_item	3234036	et	4	main
arusaadav	doc_491521501867_item	3234038	et	4	main
on	doc_491521501867_item	3234045	et	4	main
lauses	doc_491521501867_item	3234047	et	3	main
liit-	doc_491521501867_item	3234049	et	3	main
koosnevad	doc_491521501867_item	3234055	et	4	main
koosnevad	doc_491521501867_item	3234064	et	4	main
ja	doc_491521501867_item	3234069	et	3	main
selle	doc_491521501867_item	3234070	et	4	main
siird	doc_491521501867_item	3234081	et	4	main
allaandma	doc_491521501867_item	3234091	et	4	main
magama	doc_491521501867_item	3234093	et	3	main
ja	doc_491521501867_item	3234000	et	3	main
ansamblid	doc_491521501867_item	3234003	et	3	main
üldse	doc_491521501867_item	3234009	et	3	main
õpilased	doc_491521501867_item	3234039	et	3	main
tea	doc_491521501867_item	3234041	et	4	main
tegemist	doc_491521501867_item	3234046	et	4	main
või	doc_491521501867_item	3234050	et	4	main
ühendverbiga	doc_491521501867_item	3234051	et	3	main
eesti	doc_491521501867_item	3234052	et	4	main
liitsõna	doc_491521501867_item	3234061	et	4	main
ja	doc_491521501867_item	3234062	et	3	main
ühendtegusõnad	doc_491521501867_item	3234063	et	3	main
tegusõnast	doc_491521501867_item	3234068	et	4	main
istutama	doc_491521501867_item	3234082	et	4	main
ristküsitlema	doc_491521501867_item	3234083	et	3	main
mitte	doc_491521501867_item	3234084	et	3	main
rist	doc_491521501867_item	3234085	et	3	main
küsitlema	doc_491521501867_item	3234086	et	3	main
nt	doc_491521501867_item	3234087	et	4	main
andma	doc_491521501867_item	3234089	et	3	main
maha	doc_491521501867_item	3234092	et	4	main
mitte	doc_491521501867_item	3234094	et	3	main
sihiliste	doc_491521501867_item	3234107	et	4	main
sest	doc_491521501867_item	3234110	et	4	main
enesekohased	doc_491521501867_item	3234111	et	4	main
tegusõnad	doc_491521501867_item	3234112	et	3	main
tegijale	doc_491521501867_item	3234119	et	4	main
põhjustamist	doc_491521501867_item	3234130	et	4	main
liigun	doc_491521501867_item	3234145	et	3	main
ma	doc_491521501867_item	3234147	et	3	main
söötma	doc_491521501867_item	3234149	et	3	main
mis	doc_491521501867_item	3234176	et	4	main
esinevad	doc_491521501867_item	3234177	et	4	main
mitmuse	doc_491521501867_item	3234178	et	3	main
on	doc_491521501867_item	3234183	et	4	main
kapsad	doc_491521501867_item	3234212	et	4	main
sest	doc_491521501867_item	3234220	et	4	main
tegusõnade	doc_491521501867_item	3234229	et	3	main
ja	doc_491521501867_item	3234231	et	3	main
väga	doc_491521501867_item	3234235	et	3	main
hea	doc_491521501867_item	3234238	et	4	main
alati	doc_491521501867_item	3234243	et	4	main
võrdlusastmete	doc_491521501867_item	3234262	et	3	main
eriti	doc_491521501867_item	3234265	et	3	main
u	doc_491521501867_item	3234317	et	4	main
toimub	doc_491521501867_item	3234343	et	3	main
nt	doc_491521501867_item	3234351	et	4	main
kalliim	doc_491521501867_item	3234353	et	4	main
kalleim	doc_491521501867_item	3234354	et	4	main
mitte	doc_491521501867_item	3234355	et	3	main
kalliim	doc_491521501867_item	3234356	et	4	main
arvsõnad	doc_491521501867_item	3234362	et	3	main
käivad	doc_491521501867_item	3234363	et	4	main
väga	doc_491521501867_item	3234364	et	3	main
paljudele	doc_491521501867_item	3234365	et	3	main
õpilastele	doc_491521501867_item	3234366	et	4	main
üle	doc_491521501867_item	3234367	et	3	main
kuupäevi	doc_491521501867_item	3234370	et	4	main
neid	doc_491521501867_item	3234385	et	4	main
nii	doc_491521501867_item	3234386	et	3	main
võõrkeeles	doc_491521501867_item	3234390	et	4	main
ja	doc_491521501867_item	3234395	et	3	main
nt	doc_491521501867_item	3234399	et	4	main
ma	doc_491521501867_item	3234400	et	3	main
tuhande	doc_491521501867_item	3234421	et	3	main
mitte	doc_491521501867_item	3234426	et	3	main
aastal	doc_491521501867_item	3234435	et	3	main
tüve	doc_491521501867_item	3234466	et	4	main
nt	doc_491521501867_item	3234470	et	4	main
poisil	doc_491521501867_item	3234471	et	3	main
olid	doc_491521501867_item	3234472	et	4	main
kõrvad	doc_491521501867_item	3234473	et	3	main
midagi	doc_491521501867_item	3234485	et	4	main
asesõnade	doc_491521501867_item	3234487	et	3	main
kasutamisel	doc_491521501867_item	3234488	et	4	main
pronoomeni	doc_491521501867_item	3234504	et	3	main
enda	doc_491521501867_item	3234506	et	4	main
peamiselt	doc_491521501867_item	3234512	et	4	main
enesekohase	doc_491521501867_item	3234518	et	4	main
lisandub	doc_491521501867_item	3234520	et	3	main
omamistähendus	doc_491521501867_item	3234521	et	3	main
valesti	doc_491521501867_item	3234006	et	3	main
mängivad	doc_491521501867_item	3234014	et	4	main
vana	doc_491521501867_item	3234015	et	4	main
vorme	doc_491521501867_item	3234023	et	3	main
on	doc_491521501867_item	3234027	et	4	main
mõju	doc_491521501867_item	3234029	et	4	main
liit-	doc_491521501867_item	3234030	et	3	main
ja	doc_491521501867_item	3234031	et	3	main
ühendtegusõnade	doc_491521501867_item	3234032	et	3	main
moodustusvead	doc_491521501867_item	3234033	et	4	main
kui	doc_491521501867_item	3234034	et	3	main
kontekst	doc_491521501867_item	3234035	et	3	main
ei	doc_491521501867_item	3234040	et	4	main
mis	doc_491521501867_item	3234042	et	4	main
laadi	doc_491521501867_item	3234043	et	4	main
tegusõnaga	doc_491521501867_item	3234044	et	3	main
kas	doc_491521501867_item	3234048	et	3	main
moodustavad	doc_491521501867_item	3234060	et	4	main
sõnast	doc_491521501867_item	3234067	et	4	main
muutvast	doc_491521501867_item	3234072	et	4	main
mahamagama	doc_491521501867_item	3234095	et	4	main
ale	doc_491521501867_item	3234096	et	4	main
elama	doc_491521501867_item	3234097	et	3	main
mitte	doc_491521501867_item	3234098	et	3	main
üleelama	doc_491521501867_item	3234099	et	4	main
õpilastel	doc_491521501867_item	3234100	et	4	main
on	doc_491521501867_item	3234101	et	4	main
raske	doc_491521501867_item	3234102	et	4	main
vahet	doc_491521501867_item	3234103	et	3	main
ja	doc_491521501867_item	3234106	et	3	main
vahel	doc_491521501867_item	3234109	et	4	main
väljendavad	doc_491521501867_item	3234113	et	4	main
seda	doc_491521501867_item	3234114	et	3	main
et	doc_491521501867_item	3234115	et	3	main
endale	doc_491521501867_item	3234120	et	4	main
endaga	doc_491521501867_item	3234124	et	4	main
aga	doc_491521501867_item	3234125	et	3	main
sihilised	doc_491521501867_item	3234126	et	4	main
verbid	doc_491521501867_item	3234127	et	3	main
väljendavad	doc_491521501867_item	3234128	et	4	main
nt	doc_491521501867_item	3234134	et	4	main
liigutan	doc_491521501867_item	3234143	et	3	main
mis	doc_491521501867_item	3234180	et	4	main
lihavõtted	doc_491521501867_item	3234188	et	3	main
lumeta	doc_491521501867_item	3234197	et	4	main
oli	doc_491521501867_item	3234200	et	3	main
ilma	doc_491521501867_item	3234203	et	4	main
omadussõna	doc_491521501867_item	3234217	et	4	main
ja	doc_491521501867_item	3234218	et	3	main
määrsõnade	doc_491521501867_item	3234228	et	4	main
nt	doc_491521501867_item	3234233	et	4	main
jooksen	doc_491521501867_item	3234239	et	3	main
tundides	doc_491521501867_item	3234241	et	3	main
mitte	doc_491521501867_item	3234251	et	3	main
halvem	doc_491521501867_item	3234252	et	4	main
kord	doc_491521501867_item	3234253	et	4	main
paremini	doc_491521501867_item	3234254	et	4	main
on	doc_491521501867_item	3234264	et	4	main
omastav	doc_491521501867_item	3234306	et	4	main
lõpeb	doc_491521501867_item	3234308	et	4	main
a-ga	doc_491521501867_item	3234309	et	3	main
või	doc_491521501867_item	3234310	et	4	main
u-ga	doc_491521501867_item	3234311	et	2	main
muutub	doc_491521501867_item	3234318	et	3	main
pikk	doc_491521501867_item	3234321	et	4	main
kurjem	doc_491521501867_item	3234333	et	4	main
mitte	doc_491521501867_item	3234334	et	3	main
kurjam	doc_491521501867_item	3234335	et	4	main
i-ülivorre	doc_491521501867_item	3234336	et	4	main
i-ga	doc_491521501867_item	3234342	et	3	main
e-ks	doc_491521501867_item	3234350	et	3	main
jõu	doc_491521501867_item	3234368	et	3	main
aastaarve	doc_491521501867_item	3234372	et	4	main
verbide	doc_491521501867_item	3234108	et	3	main
tegevuse	doc_491521501867_item	3234129	et	4	main
täna	doc_491521501867_item	3234135	et	4	main
jätan	doc_491521501867_item	3234136	et	3	main
mitte	doc_491521501867_item	3234137	et	3	main
jään	doc_491521501867_item	3234138	et	3	main
ma	doc_491521501867_item	3234139	et	3	main
töö	doc_491521501867_item	3234140	et	4	main
mitte	doc_491521501867_item	3234144	et	3	main
pean	doc_491521501867_item	3234148	et	4	main
sööma	doc_491521501867_item	3234151	et	4	main
loomi	doc_491521501867_item	3234152	et	4	main
õpilased	doc_491521501867_item	3234153	et	3	main
tee	doc_491521501867_item	3234155	et	4	main
vahet	doc_491521501867_item	3234156	et	3	main
ainsus-	doc_491521501867_item	3234157	et	4	main
ja	doc_491521501867_item	3234158	et	3	main
mitmussõnade	doc_491521501867_item	3234159	et	4	main
vahel	doc_491521501867_item	3234160	et	4	main
sest	doc_491521501867_item	3234161	et	4	main
eesti	doc_491521501867_item	3234162	et	4	main
keeles	doc_491521501867_item	3234163	et	4	main
on	doc_491521501867_item	3234164	et	4	main
nimisõnu	doc_491521501867_item	3234165	et	3	main
mis	doc_491521501867_item	3234166	et	4	main
esinevad	doc_491521501867_item	3234167	et	4	main
tavaliselt	doc_491521501867_item	3234168	et	4	main
ainsuse	doc_491521501867_item	3234169	et	4	main
vormis	doc_491521501867_item	3234170	et	4	main
kurjus	doc_491521501867_item	3234171	et	4	main
headus	doc_491521501867_item	3234172	et	4	main
nohu	doc_491521501867_item	3234173	et	4	main
ja	doc_491521501867_item	3234174	et	3	main
vene	doc_491521501867_item	3234181	et	4	main
keeles	doc_491521501867_item	3234182	et	4	main
nt	doc_491521501867_item	3234191	et	4	main
jõulud	doc_491521501867_item	3234192	et	3	main
olid	doc_491521501867_item	3234193	et	4	main
sel	doc_491521501867_item	3234194	et	3	main
aastal	doc_491521501867_item	3234195	et	3	main
ilma	doc_491521501867_item	3234196	et	4	main
jõulu	doc_491521501867_item	3234199	et	4	main
aastal	doc_491521501867_item	3234202	et	3	main
vanaaegne	doc_491521501867_item	3234207	et	3	main
kallid	doc_491521501867_item	3234209	et	3	main
omadussõnadel	doc_491521501867_item	3234223	et	3	main
ühisosad	doc_491521501867_item	3234227	et	3	main
nimisõnadega	doc_491521501867_item	3234232	et	3	main
mitte	doc_491521501867_item	3234237	et	3	main
meie	doc_491521501867_item	3234240	et	4	main
huvitav	doc_491521501867_item	3234244	et	4	main
huvitavalt	doc_491521501867_item	3234246	et	4	main
mul	doc_491521501867_item	3234247	et	3	main
läheb	doc_491521501867_item	3234248	et	3	main
kord	doc_491521501867_item	3234249	et	4	main
mitte	doc_491521501867_item	3234255	et	3	main
parem	doc_491521501867_item	3234256	et	4	main
arge	doc_491521501867_item	3234257	et	3	main
sisenege-ohtlik	doc_491521501867_item	3234258	et	3	main
mitte	doc_491521501867_item	3234259	et	3	main
moodustamine	doc_491521501867_item	3234263	et	4	main
pidama	doc_491521501867_item	3234270	et	4	main
et	doc_491521501867_item	3234271	et	3	main
keskvõrde	doc_491521501867_item	3234272	et	3	main
tunnuseks	doc_491521501867_item	3234273	et	3	main
on	doc_491521501867_item	3234274	et	4	main
alati	doc_491521501867_item	3234275	et	4	main
m	doc_491521501867_item	3234276	et	4	main
mis	doc_491521501867_item	3234277	et	4	main
liitub	doc_491521501867_item	3234278	et	3	main
tavaliselt	doc_491521501867_item	3234279	et	4	main
algvorde	doc_491521501867_item	3234280	et	4	main
omastava	doc_491521501867_item	3234281	et	4	main
käände	doc_491521501867_item	3234282	et	4	main
tüvele	doc_491521501867_item	3234283	et	3	main
nt	doc_491521501867_item	3234284	et	4	main
suur	doc_491521501867_item	3234285	et	3	main
suure	doc_491521501867_item	3234286	et	3	main
suurem	doc_491521501867_item	3234287	et	4	main
mitte	doc_491521501867_item	3234288	et	3	main
suurtem	doc_491521501867_item	3234289	et	4	main
kaunis	doc_491521501867_item	3234290	et	4	main
kauni	doc_491521501867_item	3234291	et	4	main
mitte	doc_491521501867_item	3234293	et	3	main
kaunim	doc_491521501867_item	3234292	et	4	main
kaunisam	doc_491521501867_item	3234294	et	4	main
korralik	doc_491521501867_item	3234295	et	3	main
korraliku	doc_491521501867_item	3234296	et	3	main
korralikum	doc_491521501867_item	3234297	et	4	main
mitte	doc_491521501867_item	3234298	et	3	main
korralikem	doc_491521501867_item	3234299	et	4	main
ligi	doc_491521501867_item	3234300	et	3	main
70	doc_491521501867_item	3234301	et	2	main
omadussõna	doc_491521501867_item	3234302	et	4	main
korral	doc_491521501867_item	3234303	et	4	main
algvõrde	doc_491521501867_item	3234305	et	3	main
kääne	doc_491521501867_item	3234307	et	3	main
toimub	doc_491521501867_item	3234312	et	3	main
tunnuse	doc_491521501867_item	3234313	et	3	main
ees	doc_491521501867_item	3234314	et	4	main
e-ks	doc_491521501867_item	3234319	et	3	main
paksu	doc_491521501867_item	3234327	et	4	main
paksem	doc_491521501867_item	3234328	et	4	main
mitte	doc_491521501867_item	3234329	et	3	main
paksum	doc_491521501867_item	3234330	et	4	main
lõpeb	doc_491521501867_item	3234341	et	4	main
ülivorde	doc_491521501867_item	3234344	et	4	main
tunnuse	doc_491521501867_item	3234345	et	3	main
kirjutamisel	doc_491521501867_item	3234375	et	4	main
väidetakse	doc_491521501867_item	3234376	et	3	main
et	doc_491521501867_item	3234377	et	3	main
emakeeleski	doc_491521501867_item	3234382	et	4	main
sellepärast	doc_491521501867_item	3234383	et	3	main
on	doc_491521501867_item	3234384	et	4	main
segi	doc_491521501867_item	3234393	et	3	main
kaks	doc_491521501867_item	3234394	et	3	main
kahekümne	doc_491521501867_item	3234414	et	4	main
kahendal	doc_491521501867_item	3234415	et	4	main
aastal	doc_491521501867_item	3234416	et	3	main
minu	doc_491521501867_item	3234417	et	3	main
kahekümne	doc_491521501867_item	3234423	et	4	main
aastal	doc_491521501867_item	3234425	et	3	main
minu	doc_491521501867_item	3234427	et	3	main
on	doc_491521501867_item	3234429	et	4	main
sündinud	doc_491521501867_item	3234430	et	4	main
tuhande	doc_491521501867_item	3234431	et	3	main
üksikjuhtudel	doc_491521501867_item	3234436	et	3	main
tekkivad	doc_491521501867_item	3234437	et	4	main
on	doc_491521501867_item	3234441	et	4	main
määrsõnaga	doc_491521501867_item	3234445	et	4	main
ei	doc_491521501867_item	3234447	et	4	main
nimisõna	doc_491521501867_item	3234450	et	4	main
käändevormi	doc_491521501867_item	3234451	et	4	main
ja	doc_491521501867_item	3234452	et	3	main
käändega	doc_491521501867_item	3234458	et	3	main
ka	doc_491521501867_item	3234465	et	3	main
tugeva	doc_491521501867_item	3234467	et	4	main
lukus	doc_491521501867_item	3234476	et	3	main
selles	doc_491521501867_item	3234477	et	4	main
tohutus	doc_491521501867_item	3234478	et	4	main
omastavas	doc_491521501867_item	3234513	et	4	main
väliskohakäänetes	doc_491521501867_item	3234516	et	3	main
tähendusele	doc_491521501867_item	3234519	et	4	main
nt	doc_491521501867_item	3234522	et	4	main
vanemad	doc_491521501867_item	3234523	et	4	main
laskis	doc_491521501867_item	3234531	et	4	main
omal	doc_491521501867_item	3234532	et	3	main
pea	doc_491521501867_item	3234535	et	4	main
ajada	doc_491521501867_item	3234537	et	3	main
ei	doc_491521501867_item	3234542	et	4	main
tuttav	doc_491521501867_item	3234544	et	3	main
too	doc_491521501867_item	3234552	et	4	main
ruumis	doc_491521501867_item	3234556	et	4	main
kaugemal	doc_491521501867_item	3234559	et	4	main
paiknevale	doc_491521501867_item	3234560	et	4	main
noored	doc_491521501867_item	3234606	et	3	main
toasse	doc_491521501867_item	3234620	et	3	main
mitte	doc_491521501867_item	3234649	et	3	main
mitte	doc_491521501867_item	3234656	et	3	main
on	doc_491521501867_item	3234661	et	4	main
õpetaja	doc_491521501867_item	3234663	et	4	main
mitte	doc_491521501867_item	3234678	et	3	main
osastava	doc_491521501867_item	3234685	et	4	main
moodustamine	doc_491521501867_item	3234686	et	4	main
on	doc_491521501867_item	3234687	et	4	main
tunnused	doc_491521501867_item	3234692	et	3	main
on	doc_491521501867_item	3234693	et	4	main
neli	doc_491521501867_item	3234694	et	3	main
kusjuures	doc_491521501867_item	3234700	et	3	main
valik	doc_491521501867_item	3234701	et	3	main
sõltub	doc_491521501867_item	3234702	et	3	main
sõnatüübist	doc_491521501867_item	3234703	et	3	main
küünla	doc_491521501867_item	3234716	et	3	main
kahet	doc_491521501867_item	3234729	et	4	main
kus	doc_491521501867_item	3234736	et	3	main
palju	doc_491521501867_item	3234739	et	4	main
vokaaliteisendus	doc_491521501867_item	3234315	et	4	main
a	doc_491521501867_item	3234316	et	4	main
nt	doc_491521501867_item	3234320	et	4	main
pika	doc_491521501867_item	3234322	et	4	main
pikem	doc_491521501867_item	3234323	et	4	main
mitte	doc_491521501867_item	3234324	et	3	main
kuri	doc_491521501867_item	3234331	et	4	main
on	doc_491521501867_item	3234337	et	4	main
ees	doc_491521501867_item	3234346	et	4	main
vokaaliteisendus	doc_491521501867_item	3234347	et	4	main
truu	doc_491521501867_item	3234357	et	4	main
arvud	doc_491521501867_item	3234378	et	3	main
raske	doc_491521501867_item	3234387	et	4	main
sagedasti	doc_491521501867_item	3234391	et	3	main
üheksasada	doc_491521501867_item	3234404	et	4	main
kaheksandal	doc_491521501867_item	3234406	et	3	main
üheksasada	doc_491521501867_item	3234413	et	4	main
on	doc_491521501867_item	3234419	et	4	main
sündinud	doc_491521501867_item	3234420	et	4	main
tegemist	doc_491521501867_item	3234440	et	4	main
nimisõna	doc_491521501867_item	3234442	et	4	main
õpilased	doc_491521501867_item	3234446	et	3	main
vahet	doc_491521501867_item	3234449	et	3	main
sest	doc_491521501867_item	3234455	et	4	main
nimisõna	doc_491521501867_item	3234456	et	4	main
seesütleva	doc_491521501867_item	3234457	et	3	main
määrsõnavormid	doc_491521501867_item	3234460	et	4	main
ja	doc_491521501867_item	3234479	et	3	main
keerulises	doc_491521501867_item	3234480	et	4	main
lukus	doc_491521501867_item	3234481	et	3	main
mitte	doc_491521501867_item	3234482	et	3	main
enese	doc_491521501867_item	3234505	et	4	main
asendamine	doc_491521501867_item	3234507	et	4	main
pronoomeniga	doc_491521501867_item	3234508	et	3	main
oma	doc_491521501867_item	3234509	et	4	main
käändes	doc_491521501867_item	3234514	et	3	main
kui	doc_491521501867_item	3234517	et	3	main
mitte	doc_491521501867_item	3234533	et	3	main
paljaks	doc_491521501867_item	3234536	et	3	main
päritolu	doc_491521501867_item	3234539	et	4	main
asesõna	doc_491521501867_item	3234540	et	4	main
ole	doc_491521501867_item	3234543	et	4	main
ei	doc_491521501867_item	3234546	et	4	main
oska	doc_491521501867_item	3234547	et	4	main
seda	doc_491521501867_item	3234548	et	3	main
viitamaks	doc_491521501867_item	3234554	et	3	main
too	doc_491521501867_item	3234562	et	4	main
vastamisel	doc_491521501867_item	3234373	et	4	main
ja	doc_491521501867_item	3234374	et	3	main
jää	doc_491521501867_item	3234380	et	4	main
välja	doc_491521501867_item	3234388	et	4	main
aetakse	doc_491521501867_item	3234392	et	3	main
sisaldavad	doc_491521501867_item	3234397	et	4	main
kaheksakümne	doc_491521501867_item	3234405	et	4	main
mitte	doc_491521501867_item	3234408	et	3	main
ma	doc_491521501867_item	3234409	et	3	main
sündinud	doc_491521501867_item	3234411	et	4	main
tuhande	doc_491521501867_item	3234412	et	3	main
teisel	doc_491521501867_item	3234424	et	4	main
vanemad	doc_491521501867_item	3234428	et	4	main
üheksasada	doc_491521501867_item	3234432	et	4	main
kahtlused	doc_491521501867_item	3234438	et	4	main
kas	doc_491521501867_item	3234439	et	3	main
tee	doc_491521501867_item	3234448	et	4	main
sarnanevad	doc_491521501867_item	3234459	et	4	main
erinevad	doc_491521501867_item	3234461	et	4	main
astme	doc_491521501867_item	3234468	et	3	main
poolest	doc_491521501867_item	3234469	et	4	main
oli	doc_491521501867_item	3234484	et	3	main
aastal	doc_491521501867_item	3234407	et	3	main
olen	doc_491521501867_item	3234410	et	3	main
vanemad	doc_491521501867_item	3234418	et	4	main
üheksasada	doc_491521501867_item	3234422	et	4	main
kahekümne	doc_491521501867_item	3234433	et	4	main
kahendal	doc_491521501867_item	3234434	et	4	main
käändevormiga	doc_491521501867_item	3234443	et	4	main
või	doc_491521501867_item	3234444	et	4	main
määrsõna	doc_491521501867_item	3234453	et	4	main
vahel	doc_491521501867_item	3234454	et	4	main
paradigmaatiliselt	doc_491521501867_item	3234462	et	4	main
käändevormist	doc_491521501867_item	3234463	et	4	main
sageli	doc_491521501867_item	3234464	et	3	main
lukkus	doc_491521501867_item	3234474	et	4	main
mitte	doc_491521501867_item	3234475	et	3	main
lukkus	doc_491521501867_item	3234483	et	4	main
pahaendelist	doc_491521501867_item	3234486	et	4	main
tekkivad	doc_491521501867_item	3234489	et	4	main
ka	doc_491521501867_item	3234490	et	3	main
mõned	doc_491521501867_item	3234491	et	3	main
vead	doc_491521501867_item	3234492	et	4	main
pronoomeni	doc_491521501867_item	3234493	et	3	main
oma	doc_491521501867_item	3234494	et	4	main
põhifunktsioon	doc_491521501867_item	3234495	et	3	main
on	doc_491521501867_item	3234496	et	4	main
omastav	doc_491521501867_item	3234497	et	4	main
ja	doc_491521501867_item	3234498	et	3	main
enesekohases	doc_491521501867_item	3234499	et	4	main
tähenduses	doc_491521501867_item	3234500	et	4	main
esineb	doc_491521501867_item	3234501	et	3	main
ta	doc_491521501867_item	3234502	et	4	main
harva	doc_491521501867_item	3234503	et	4	main
on	doc_491521501867_item	3234510	et	4	main
või	doc_491521501867_item	3234515	et	4	main
said	doc_491521501867_item	3234524	et	4	main
omale	doc_491521501867_item	3234525	et	3	main
mitte	doc_491521501867_item	3234526	et	3	main
endale	doc_491521501867_item	3234527	et	4	main
hea	doc_491521501867_item	3234528	et	4	main
sõbra	doc_491521501867_item	3234529	et	3	main
artur	doc_491521501867_item	3234530	et	4	main
enesel	doc_491521501867_item	3234534	et	4	main
lõunaeestilist	doc_491521501867_item	3234538	et	3	main
sest	doc_491521501867_item	3234550	et	4	main
asesõna	doc_491521501867_item	3234551	et	4	main
nt	doc_491521501867_item	3234561	et	4	main
kui	doc_491521501867_item	3234603	et	3	main
mitte	doc_491521501867_item	3234604	et	3	main
kergem	doc_491521501867_item	3234617	et	4	main
õige	doc_491521501867_item	3234624	et	4	main
õige	doc_491521501867_item	3234627	et	4	main
omastav	doc_491521501867_item	3234637	et	4	main
raamatut	doc_491521501867_item	3234655	et	3	main
kui	doc_491521501867_item	3234660	et	3	main
osasihitis	doc_491521501867_item	3234662	et	3	main
luges	doc_491521501867_item	3234664	et	3	main
kuulata	doc_491521501867_item	3234675	et	4	main
head	doc_491521501867_item	3234676	et	4	main
t	doc_491521501867_item	3234696	et	4	main
kollaset	doc_491521501867_item	3234709	et	4	main
suur	doc_491521501867_item	3234710	et	3	main
suure	doc_491521501867_item	3234711	et	3	main
suurt	doc_491521501867_item	3234712	et	3	main
küünlat	doc_491521501867_item	3234719	et	4	main
mitmuse	doc_491521501867_item	3234730	et	3	main
osastava	doc_491521501867_item	3234731	et	4	main
moodustamine	doc_491521501867_item	3234732	et	4	main
on	doc_491521501867_item	3234742	et	4	main
sid	doc_491521501867_item	3234748	et	4	main
võimalik	doc_491521501867_item	3234511	et	3	main
too	doc_491521501867_item	3234541	et	4	main
õpilased	doc_491521501867_item	3234545	et	3	main
kasutatakse	doc_491521501867_item	3234553	et	3	main
ajas	doc_491521501867_item	3234558	et	4	main
seal	doc_491521501867_item	3234563	et	4	main
on	doc_491521501867_item	3234564	et	4	main
minu	doc_491521501867_item	3234565	et	3	main
auto	doc_491521501867_item	3234566	et	4	main
mitte	doc_491521501867_item	3234567	et	3	main
too	doc_491521501867_item	3234568	et	4	main
siin	doc_491521501867_item	3234569	et	4	main
on	doc_491521501867_item	3234570	et	4	main
minu	doc_491521501867_item	3234571	et	3	main
auto	doc_491521501867_item	3234572	et	4	main
tol	doc_491521501867_item	3234573	et	3	main
aastal	doc_491521501867_item	3234574	et	3	main
oli	doc_491521501867_item	3234575	et	3	main
maria	doc_491521501867_item	3234576	et	4	main
väga	doc_491521501867_item	3234577	et	3	main
paks	doc_491521501867_item	3234578	et	3	main
mitte	doc_491521501867_item	3234579	et	3	main
tol	doc_491521501867_item	3234580	et	3	main
aastal	doc_491521501867_item	3234581	et	3	main
on	doc_491521501867_item	3234582	et	4	main
maria	doc_491521501867_item	3234583	et	4	main
väga	doc_491521501867_item	3234584	et	3	main
paks	doc_491521501867_item	3234585	et	3	main
sidesõna	doc_491521501867_item	3234586	et	4	main
vahetatakse	doc_491521501867_item	3234587	et	3	main
ära	doc_491521501867_item	3234588	et	4	main
küsisõnaga	doc_491521501867_item	3234589	et	3	main
nt	doc_491521501867_item	3234590	et	4	main
jõudsin	doc_491521501867_item	3234591	et	3	main
koju	doc_491521501867_item	3234592	et	3	main
kui	doc_491521501867_item	3234593	et	3	main
mitte	doc_491521501867_item	3234594	et	3	main
millal	doc_491521501867_item	3234595	et	3	main
vanemad	doc_491521501867_item	3234596	et	4	main
olid	doc_491521501867_item	3234597	et	4	main
kodus	doc_491521501867_item	3234598	et	4	main
huvitavaid	doc_491521501867_item	3234601	et	4	main
kirjutada	doc_491521501867_item	3234549	et	3	main
kõnelejast	doc_491521501867_item	3234555	et	4	main
ja	doc_491521501867_item	3234557	et	3	main
asju	doc_491521501867_item	3234602	et	3	main
räägivad	doc_491521501867_item	3234607	et	3	main
oma	doc_491521501867_item	3234608	et	4	main
lühike	doc_491521501867_item	3234610	et	4	main
jääb	doc_491521501867_item	3234612	et	3	main
öelda	doc_491521501867_item	3234618	et	4	main
tuppa	doc_491521501867_item	3234622	et	3	main
õige	doc_491521501867_item	3234630	et	4	main
õige	doc_491521501867_item	3234633	et	4	main
pessa	doc_491521501867_item	3234634	et	3	main
aetakse	doc_491521501867_item	3234635	et	3	main
segi	doc_491521501867_item	3234636	et	3	main
mart	doc_491521501867_item	3234657	et	3	main
raamatu	doc_491521501867_item	3234659	et	4	main
tegevus	doc_491521501867_item	3234672	et	4	main
mulle	doc_491521501867_item	3234673	et	4	main
meeldib	doc_491521501867_item	3234674	et	3	main
ainsuse	doc_491521501867_item	3234684	et	4	main
sest	doc_491521501867_item	3234689	et	4	main
osastava	doc_491521501867_item	3234690	et	4	main
käände	doc_491521501867_item	3234691	et	4	main
mitte	doc_491521501867_item	3234713	et	3	main
suuret	doc_491521501867_item	3234714	et	4	main
küünalt	doc_491521501867_item	3234717	et	3	main
ema	doc_491521501867_item	3234720	et	4	main
ema	doc_491521501867_item	3234721	et	4	main
teevad	doc_491521501867_item	3234738	et	3	main
nt	doc_491521501867_item	3234751	et	4	main
mõttesid	doc_491521501867_item	3234754	et	4	main
oli	doc_491521501867_item	3234807	et	3	main
aega	doc_491521501867_item	3234809	et	4	main
on	doc_491521501867_item	3234812	et	4	main
õpilastele	doc_491521501867_item	3234813	et	4	main
tingiva	doc_491521501867_item	3234821	et	4	main
tegiksime	doc_491521501867_item	3234842	et	4	main
peseksin	doc_491521501867_item	3234843	et	3	main
mitte	doc_491521501867_item	3234844	et	3	main
pestaksin	doc_491521501867_item	3234845	et	4	main
puhkaksime	doc_491521501867_item	3234846	et	3	main
mitte	doc_491521501867_item	3234847	et	3	main
puhaksime	doc_491521501867_item	3234848	et	4	main
töö	doc_491521501867_item	3234870	et	4	main
mitte	doc_491521501867_item	3234873	et	3	main
segadust	doc_491521501867_item	3234885	et	4	main
mitte	doc_491521501867_item	3234890	et	3	main
mitte	doc_491521501867_item	3234893	et	3	main
noortesaadetes	doc_491521501867_item	3234599	et	3	main
on	doc_491521501867_item	3234600	et	4	main
millal	doc_491521501867_item	3234605	et	3	main
probleemidest	doc_491521501867_item	3234609	et	3	main
sisseütlev	doc_491521501867_item	3234611	et	4	main
halvasti	doc_491521501867_item	3234613	et	3	main
meelde	doc_491521501867_item	3234614	et	3	main
õpilastele	doc_491521501867_item	3234615	et	4	main
õige	doc_491521501867_item	3234621	et	4	main
metsasse	doc_491521501867_item	3234623	et	4	main
metsa	doc_491521501867_item	3234625	et	4	main
koogisse	doc_491521501867_item	3234626	et	3	main
pesasse	doc_491521501867_item	3234632	et	3	main
kõik	doc_491521501867_item	3234650	et	4	main
kuulsid	doc_491521501867_item	3234651	et	4	main
luges	doc_491521501867_item	3234658	et	3	main
õpetaja	doc_491521501867_item	3234667	et	4	main
luges	doc_491521501867_item	3234668	et	3	main
raamatut	doc_491521501867_item	3234669	et	3	main
kui	doc_491521501867_item	3234670	et	3	main
lõpetatud	doc_491521501867_item	3234671	et	4	main
muusikat	doc_491521501867_item	3234677	et	3	main
kuulata	doc_491521501867_item	3234681	et	4	main
muusika	doc_491521501867_item	3234683	et	4	main
raske	doc_491521501867_item	3234688	et	4	main
morfeemvarianti	doc_491521501867_item	3234695	et	4	main
nt	doc_491521501867_item	3234704	et	4	main
kollase	doc_491521501867_item	3234706	et	4	main
küünal	doc_491521501867_item	3234715	et	3	main
mitte	doc_491521501867_item	3234718	et	3	main
õpilased	doc_491521501867_item	3234737	et	3	main
vigu	doc_491521501867_item	3234740	et	3	main
vahel	doc_491521501867_item	3234750	et	4	main
sõpraid	doc_491521501867_item	3234760	et	4	main
koerasid	doc_491521501867_item	3234761	et	3	main
mitte	doc_491521501867_item	3234762	et	3	main
on	doc_491521501867_item	3234616	et	4	main
nt	doc_491521501867_item	3234619	et	4	main
kooki	doc_491521501867_item	3234628	et	4	main
suusse	doc_491521501867_item	3234629	et	3	main
suhu	doc_491521501867_item	3234631	et	3	main
ja	doc_491521501867_item	3234638	et	3	main
osastav	doc_491521501867_item	3234639	et	4	main
kääne	doc_491521501867_item	3234640	et	3	main
lõpetatud	doc_491521501867_item	3234641	et	4	main
ja	doc_491521501867_item	3234642	et	3	main
lõpetamata	doc_491521501867_item	3234643	et	4	main
tegevus	doc_491521501867_item	3234644	et	4	main
nt	doc_491521501867_item	3234645	et	4	main
kõik	doc_491521501867_item	3234646	et	4	main
kuulsid	doc_491521501867_item	3234647	et	4	main
raadiot	doc_491521501867_item	3234648	et	3	main
raadio	doc_491521501867_item	3234652	et	4	main
mart	doc_491521501867_item	3234653	et	3	main
luges	doc_491521501867_item	3234654	et	3	main
raamatu	doc_491521501867_item	3234665	et	4	main
mitte	doc_491521501867_item	3234666	et	3	main
mulle	doc_491521501867_item	3234679	et	4	main
meeldib	doc_491521501867_item	3234680	et	3	main
hea	doc_491521501867_item	3234682	et	4	main
d	doc_491521501867_item	3234697	et	4	main
ja	doc_491521501867_item	3234698	et	3	main
da	doc_491521501867_item	3234699	et	4	main
kollane	doc_491521501867_item	3234705	et	4	main
kollast	doc_491521501867_item	3234707	et	4	main
mitte	doc_491521501867_item	3234708	et	3	main
ema	doc_491521501867_item	3234722	et	4	main
mitte	doc_491521501867_item	3234723	et	3	main
emat	doc_491521501867_item	3234724	et	4	main
kaks	doc_491521501867_item	3234725	et	3	main
kahe	doc_491521501867_item	3234726	et	3	main
kaht	doc_491521501867_item	3234727	et	3	main
mitte	doc_491521501867_item	3234728	et	3	main
on	doc_491521501867_item	3234733	et	4	main
eriti	doc_491521501867_item	3234734	et	3	main
raske	doc_491521501867_item	3234735	et	4	main
teha	doc_491521501867_item	3234745	et	3	main
ja	doc_491521501867_item	3234747	et	3	main
mõtteid	doc_491521501867_item	3234752	et	3	main
koeraid	doc_491521501867_item	3234763	et	4	main
täisminevikku	doc_491521501867_item	3234769	et	4	main
nt	doc_491521501867_item	3234770	et	4	main
loodan	doc_491521501867_item	3234771	et	3	main
oled	doc_491521501867_item	3234775	et	3	main
sa	doc_491521501867_item	3234776	et	3	main
selle	doc_491521501867_item	3234777	et	4	main
töö	doc_491521501867_item	3234778	et	4	main
lõpetanud	doc_491521501867_item	3234779	et	4	main
mitte	doc_491521501867_item	3234780	et	3	main
loodan	doc_491521501867_item	3234781	et	3	main
et	doc_491521501867_item	3234782	et	3	main
pühapäeva	doc_491521501867_item	3234783	et	4	main
õhtuks	doc_491521501867_item	3234784	et	3	main
sa	doc_491521501867_item	3234785	et	3	main
selle	doc_491521501867_item	3234786	et	4	main
töö	doc_491521501867_item	3234787	et	4	main
lõpetanud	doc_491521501867_item	3234788	et	4	main
mari	doc_491521501867_item	3234789	et	4	main
oli	doc_491521501867_item	3234790	et	3	main
kõvasti	doc_491521501867_item	3234791	et	3	main
tööd	doc_491521501867_item	3234792	et	4	main
teinud	doc_491521501867_item	3234793	et	4	main
mitte	doc_491521501867_item	3234794	et	3	main
mari	doc_491521501867_item	3234795	et	4	main
kõvasti	doc_491521501867_item	3234796	et	3	main
tööd	doc_491521501867_item	3234797	et	4	main
teinud	doc_491521501867_item	3234798	et	4	main
mul	doc_491521501867_item	3234799	et	3	main
ei	doc_491521501867_item	3234800	et	4	main
olnud	doc_491521501867_item	3234801	et	4	main
vaba	doc_491521501867_item	3234802	et	4	main
aega	doc_491521501867_item	3234803	et	4	main
tingiv	doc_491521501867_item	3234810	et	4	main
on	doc_491521501867_item	3234824	et	4	main
kaks	doc_491521501867_item	3234825	et	3	main
ja	doc_491521501867_item	3234833	et	3	main
nendel	doc_491521501867_item	3234741	et	4	main
raske	doc_491521501867_item	3234743	et	4	main
vahet	doc_491521501867_item	3234744	et	3	main
i	doc_491521501867_item	3234746	et	4	main
mitte	doc_491521501867_item	3234753	et	3	main
siileid	doc_491521501867_item	3234757	et	4	main
sõprusid	doc_491521501867_item	3234758	et	4	main
mitte	doc_491521501867_item	3234759	et	3	main
raskem	doc_491521501867_item	3234766	et	4	main
moodustada	doc_491521501867_item	3234767	et	3	main
kui	doc_491521501867_item	3234768	et	3	main
pühapäeva	doc_491521501867_item	3234773	et	4	main
mitte	doc_491521501867_item	3234804	et	3	main
vaba	doc_491521501867_item	3234808	et	4	main
kõneviisi	doc_491521501867_item	3234822	et	4	main
tunnusel	doc_491521501867_item	3234823	et	3	main
ksi	doc_491521501867_item	3234827	et	4	main
kui	doc_491521501867_item	3234828	et	3	main
pöördetunnus	doc_491521501867_item	3234830	et	3	main
tahaksin	doc_491521501867_item	3234832	et	3	main
lõpus	doc_491521501867_item	3234836	et	4	main
nt	doc_491521501867_item	3234837	et	4	main
elaks	doc_491521501867_item	3234838	et	3	main
nt	doc_491521501867_item	3234839	et	4	main
teeksime	doc_491521501867_item	3234840	et	3	main
mitte	doc_491521501867_item	3234841	et	3	main
on	doc_491521501867_item	3234871	et	4	main
tehtud	doc_491521501867_item	3234872	et	4	main
kui	doc_491521501867_item	3234874	et	3	main
on	doc_491521501867_item	3234876	et	4	main
tehnud	doc_491521501867_item	3234877	et	4	main
võib	doc_491521501867_item	3234878	et	3	main
minna	doc_491521501867_item	3234879	et	3	main
koju	doc_491521501867_item	3234880	et	3	main
nt	doc_491521501867_item	3234888	et	4	main
vedakse	doc_491521501867_item	3234891	et	4	main
ostakse	doc_491521501867_item	3234894	et	4	main
tahetakse	doc_491521501867_item	3234895	et	4	main
mitte	doc_491521501867_item	3234896	et	3	main
jooma-tüübis	doc_491521501867_item	3234906	et	3	main
ees	doc_491521501867_item	3234910	et	4	main
jooma	doc_491521501867_item	3234916	et	4	main
loodakse	doc_491521501867_item	3234928	et	4	main
mitte	doc_491521501867_item	3234931	et	3	main
raskematest	doc_491521501867_item	3234940	et	4	main
ülesannetest	doc_491521501867_item	3234941	et	3	main
infinitiivi	doc_491521501867_item	3234944	et	4	main
tegusõna	doc_491521501867_item	3234945	et	4	main
lõpus	doc_491521501867_item	3234946	et	4	main
ma	doc_491521501867_item	3234947	et	3	main
kasutame	doc_491521501867_item	3234948	et	3	main
da	doc_491521501867_item	3234952	et	4	main
infinitiivi	doc_491521501867_item	3234953	et	4	main
a	doc_491521501867_item	3234958	et	4	main
kasutame	doc_491521501867_item	3234959	et	3	main
kuulama	doc_491521501867_item	3234970	et	3	main
vaja	doc_491521501867_item	3234972	et	4	main
teha	doc_491521501867_item	3234973	et	3	main
tarvitseda	doc_491521501867_item	3234977	et	3	main
olen	doc_491521501867_item	3234980	et	3	main
kirjutada	doc_491521501867_item	3234990	et	3	main
mitte	doc_491521501867_item	3234995	et	3	main
lõpude	doc_491521501867_item	3234749	et	4	main
siile	doc_491521501867_item	3234755	et	3	main
mitte	doc_491521501867_item	3234756	et	3	main
lihtminevikku	doc_491521501867_item	3234764	et	4	main
on	doc_491521501867_item	3234765	et	4	main
et	doc_491521501867_item	3234772	et	3	main
õhtuks	doc_491521501867_item	3234774	et	3	main
ei	doc_491521501867_item	3234806	et	4	main
tavaliselt	doc_491521501867_item	3234814	et	4	main
selge	doc_491521501867_item	3234815	et	4	main
kui	doc_491521501867_item	3234816	et	3	main
moodustamise	doc_491521501867_item	3234817	et	4	main
nt	doc_491521501867_item	3234831	et	4	main
sõna	doc_491521501867_item	3234835	et	4	main
ja	doc_491521501867_item	3234867	et	3	main
töö	doc_491521501867_item	3234875	et	4	main
tekitab	doc_491521501867_item	3234884	et	3	main
silpide	doc_491521501867_item	3234886	et	3	main
veetakse	doc_491521501867_item	3234889	et	4	main
ostetakse	doc_491521501867_item	3234892	et	3	main
pöördkonna	doc_491521501867_item	3234905	et	4	main
joodakse	doc_491521501867_item	3234920	et	4	main
tuuakse	doc_491521501867_item	3234930	et	3	main
ma-	doc_491521501867_item	3234933	et	3	main
da	doc_491521501867_item	3234956	et	4	main
mitte	doc_491521501867_item	3234974	et	3	main
tuleb	doc_491521501867_item	3234976	et	3	main
tarvitsema	doc_491521501867_item	3234979	et	3	main
võib	doc_491521501867_item	3234989	et	3	main
kirjutama	doc_491521501867_item	3234992	et	3	main
puhkama	doc_491521501867_item	3234994	et	3	main
puhata	doc_491521501867_item	3234996	et	4	main
meid	doc_491521501867_item	3234998	et	4	main
kirja	doc_491521501867_item	3234999	et	4	main
kirjutama	doc_491521501867_item	3235000	et	3	main
mitte	doc_491521501867_item	3235001	et	3	main
kirjutada	doc_491521501867_item	3235002	et	3	main
mitte	doc_491521501867_item	3235006	et	3	main
armastan	doc_491521501867_item	3235012	et	3	main
eksitakse	doc_491521501867_item	3235019	et	4	main
keele	doc_491521501867_item	3235024	et	4	main
reeglitele	doc_491521501867_item	3235025	et	3	main
nt	doc_491521501867_item	3235026	et	4	main
kaasnema	doc_491521501867_item	3235034	et	3	main
mitte	doc_491521501867_item	3235036	et	3	main
mida	doc_491521501867_item	3235051	et	4	main
mitte	doc_491521501867_item	3235054	et	3	main
mida	doc_491521501867_item	3235058	et	4	main
keda	doc_491521501867_item	3235063	et	4	main
mida	doc_491521501867_item	3235064	et	4	main
mitte	doc_491521501867_item	3235065	et	3	main
milles	doc_491521501867_item	3235073	et	3	main
millele	doc_491521501867_item	3235081	et	3	main
mitte	doc_491521501867_item	3235088	et	3	main
harjuma	doc_491521501867_item	3235090	et	3	main
baseeruma	doc_491521501867_item	3235094	et	3	main
ja	doc_491521501867_item	3235105	et	3	main
on	doc_491521501867_item	3235111	et	4	main
on	doc_491521501867_item	3235117	et	4	main
siis	doc_491521501867_item	3235125	et	3	main
kingsepatöökoda	doc_491521501867_item	3235128	et	4	main
mitte	doc_491521501867_item	3235129	et	3	main
kingsepa	doc_491521501867_item	3235130	et	3	main
põrandavarvimine	doc_491521501867_item	3235136	et	4	main
üheksa	doc_491521501867_item	3235155	et	4	main
nelikümmend	doc_491521501867_item	3235161	et	4	main
kolm	doc_491521501867_item	3235162	et	3	main
mitte	doc_491521501867_item	3235163	et	3	main
neli	doc_491521501867_item	3235164	et	3	main
kahetuhandes	doc_491521501867_item	3235167	et	4	main
kahe	doc_491521501867_item	3235169	et	3	main
koolimajast	doc_491521501867_item	3235215	et	4	main
olevaks	doc_491521501867_item	3235219	et	4	main
loetud	doc_491521501867_item	3235229	et	4	main
mitte	doc_491521501867_item	3235230	et	3	main
raamat	doc_491521501867_item	3235231	et	3	main
on	doc_491521501867_item	3235232	et	4	main
laiendeil	doc_491521501867_item	3235236	et	4	main
asukoht	doc_491521501867_item	3235238	et	3	main
tema	doc_491521501867_item	3235240	et	4	main
ees	doc_491521501867_item	3235241	et	4	main
mul	doc_491521501867_item	3234805	et	3	main
kõneviis	doc_491521501867_item	3234811	et	3	main
teeb	doc_491521501867_item	3234818	et	3	main
raskeks	doc_491521501867_item	3234819	et	3	main
laadivaheldus	doc_491521501867_item	3234820	et	4	main
kuju	doc_491521501867_item	3234826	et	4	main
järgneb	doc_491521501867_item	3234829	et	3	main
ks	doc_491521501867_item	3234834	et	4	main
õmbleksin	doc_491521501867_item	3234849	et	3	main
mitte	doc_491521501867_item	3234850	et	3	main
õmmeldaksin	doc_491521501867_item	3234851	et	4	main
umbisikuline	doc_491521501867_item	3234852	et	4	main
tegumood	doc_491521501867_item	3234853	et	3	main
on	doc_491521501867_item	3234854	et	4	main
raske	doc_491521501867_item	3234855	et	4	main
eriti	doc_491521501867_item	3234856	et	3	main
täisminevikus	doc_491521501867_item	3234857	et	3	main
nt	doc_491521501867_item	3234858	et	4	main
pildil	doc_491521501867_item	3234859	et	3	main
on	doc_491521501867_item	3234860	et	4	main
kujutatud	doc_491521501867_item	3234861	et	4	main
mitte	doc_491521501867_item	3234862	et	3	main
pildil	doc_491521501867_item	3234863	et	3	main
on	doc_491521501867_item	3234864	et	4	main
kujutanud	doc_491521501867_item	3234865	et	4	main
õunad	doc_491521501867_item	3234866	et	3	main
pirnid	doc_491521501867_item	3234868	et	3	main
olevikus	doc_491521501867_item	3234883	et	3	main
tahakse	doc_491521501867_item	3234897	et	4	main
murtakse	doc_491521501867_item	3234898	et	3	main
mitte	doc_491521501867_item	3234899	et	3	main
toimuv	doc_491521501867_item	3234907	et	4	main
uuakse	doc_491521501867_item	3234918	et	4	main
mitte	doc_491521501867_item	3234919	et	3	main
looma	doc_491521501867_item	3234925	et	4	main
luuakse	doc_491521501867_item	3234926	et	3	main
ja	doc_491521501867_item	3234934	et	3	main
koos	doc_491521501867_item	3234949	et	4	main
ta	doc_491521501867_item	3234957	et	4	main
koos	doc_491521501867_item	3234960	et	4	main
sõnadega	doc_491521501867_item	3234961	et	3	main
mitte	doc_491521501867_item	3234987	et	3	main
mitte	doc_491521501867_item	3234991	et	3	main
alustan	doc_491521501867_item	3234993	et	3	main
pani	doc_491521501867_item	3234997	et	4	main
ta	doc_491521501867_item	3235003	et	4	main
laulma	doc_491521501867_item	3235005	et	3	main
laulda	doc_491521501867_item	3235007	et	4	main
rektsioone	doc_491521501867_item	3235016	et	3	main
sageli	doc_491521501867_item	3235018	et	3	main
ühildumine	doc_491521501867_item	3235020	et	4	main
ei	doc_491521501867_item	3235021	et	4	main
vasta	doc_491521501867_item	3235022	et	4	main
huvi	doc_491521501867_item	3235027	et	4	main
tundma	doc_491521501867_item	3235028	et	3	main
mille	doc_491521501867_item	3235029	et	3	main
vastu	doc_491521501867_item	3235030	et	3	main
mitte	doc_491521501867_item	3235031	et	3	main
kust	doc_491521501867_item	3235043	et	4	main
jätma	doc_491521501867_item	3235052	et	3	main
kus	doc_491521501867_item	3235055	et	3	main
millele	doc_491521501867_item	3235067	et	3	main
kahetsema	doc_491521501867_item	3235068	et	3	main
keda	doc_491521501867_item	3235069	et	4	main
põhinema	doc_491521501867_item	3235074	et	3	main
millele	doc_491521501867_item	3235077	et	3	main
millele	doc_491521501867_item	3235085	et	3	main
millega	doc_491521501867_item	3235087	et	3	main
millel	doc_491521501867_item	3235095	et	3	main
ortograafia	doc_491521501867_item	3235102	et	4	main
nimisõnade	doc_491521501867_item	3235107	et	3	main
lahkukirjutamine	doc_491521501867_item	3235110	et	3	main
ei	doc_491521501867_item	3235114	et	4	main
erista	doc_491521501867_item	3235115	et	4	main
kas	doc_491521501867_item	3235116	et	3	main
tegevusalaga	doc_491521501867_item	3235124	et	3	main
lahkukirjutamine	doc_491521501867_item	3235148	et	3	main
sada	doc_491521501867_item	3235156	et	4	main
kui	doc_491521501867_item	3235216	et	3	main
lause	doc_491521501867_item	3235217	et	4	main
on	doc_491521501867_item	3235227	et	4	main
läbi	doc_491521501867_item	3235228	et	4	main
infiniitverbi	doc_491521501867_item	3235235	et	4	main
ühildumise	doc_491521501867_item	3235251	et	4	main
vead	doc_491521501867_item	3235252	et	4	main
alusega	doc_491521501867_item	3235255	et	4	main
õpilased	doc_491521501867_item	3235256	et	3	main
öeldistaide	doc_491521501867_item	3235265	et	4	main
tangid	doc_491521501867_item	3235275	et	4	main
tööriist	doc_491521501867_item	3235277	et	3	main
tööriistad	doc_491521501867_item	3235279	et	3	main
elina	doc_491521501867_item	3235287	et	4	main
on	doc_491521501867_item	3235290	et	4	main
üliõpilased	doc_491521501867_item	3235291	et	3	main
õpilaste	doc_491521501867_item	3235302	et	4	main
parandada	doc_491521501867_item	3235304	et	3	main
võimalik	doc_491521501867_item	3235308	et	3	main
õpetada	doc_491521501867_item	3235313	et	3	main
õpetaja	doc_491521501867_item	3235317	et	4	main
tahab	doc_491521501867_item	3235318	et	3	main
tema	doc_491521501867_item	3235320	et	4	main
õppijad	doc_491521501867_item	3235321	et	4	main
õpetamine	doc_491521501867_item	3235329	et	4	main
õppijatele	doc_491521501867_item	3235337	et	4	main
neile	doc_491521501867_item	3235344	et	4	main
teda	doc_491521501867_item	3235364	et	4	main
praktikas	doc_491521501867_item	3235366	et	3	main
kui	doc_491521501867_item	3234869	et	3	main
umbisikulise	doc_491521501867_item	3234881	et	4	main
tegumoe	doc_491521501867_item	3234882	et	3	main
kordus	doc_491521501867_item	3234887	et	4	main
murdatakse	doc_491521501867_item	3234900	et	4	main
eriti	doc_491521501867_item	3234901	et	3	main
ebaselge	doc_491521501867_item	3234902	et	4	main
on	doc_491521501867_item	3234903	et	4	main
1	doc_491521501867_item	3234904	et	2	main
öö-üü	doc_491521501867_item	3234914	et	4	main
nt	doc_491521501867_item	3234915	et	4	main
sööma	doc_491521501867_item	3234921	et	4	main
süüakse	doc_491521501867_item	3234922	et	3	main
mitte	doc_491521501867_item	3234923	et	3	main
söödakse	doc_491521501867_item	3234924	et	4	main
tooma	doc_491521501867_item	3234929	et	3	main
sest	doc_491521501867_item	3234942	et	4	main
ma	doc_491521501867_item	3234943	et	3	main
sõnadega	doc_491521501867_item	3234950	et	3	main
mitte	doc_491521501867_item	3234969	et	3	main
minna	doc_491521501867_item	3234988	et	3	main
mitte	doc_491521501867_item	3235010	et	3	main
töötada	doc_491521501867_item	3235013	et	3	main
eesti	doc_491521501867_item	3235023	et	4	main
käima	doc_491521501867_item	3235038	et	4	main
mitte	doc_491521501867_item	3235040	et	3	main
ostma	doc_491521501867_item	3235042	et	3	main
kus	doc_491521501867_item	3235045	et	3	main
kellele	doc_491521501867_item	3235047	et	4	main
millele	doc_491521501867_item	3235048	et	3	main
aitama	doc_491521501867_item	3235056	et	3	main
mitte	doc_491521501867_item	3235059	et	3	main
häirima	doc_491521501867_item	3235062	et	3	main
mida	doc_491521501867_item	3235070	et	4	main
mitte	doc_491521501867_item	3235076	et	3	main
sarnanema	doc_491521501867_item	3235078	et	3	main
mitte	doc_491521501867_item	3235080	et	3	main
muganema	doc_491521501867_item	3235082	et	3	main
kohanema	doc_491521501867_item	3235086	et	3	main
millega	doc_491521501867_item	3235091	et	3	main
millele	doc_491521501867_item	3235093	et	3	main
tuginema	doc_491521501867_item	3235098	et	3	main
mitte	doc_491521501867_item	3235100	et	3	main
interpunktsioonis	doc_491521501867_item	3235106	et	4	main
segane	doc_491521501867_item	3235112	et	3	main
õpilased	doc_491521501867_item	3235113	et	3	main
üksikjuhtumiga	doc_491521501867_item	3235120	et	3	main
kokku	doc_491521501867_item	3235126	et	3	main
purjespordikeskus	doc_491521501867_item	3235135	et	3	main
tegevusala	doc_491521501867_item	3235138	et	4	main
kui	doc_491521501867_item	3235140	et	3	main
kingaparandus	doc_491521501867_item	3235142	et	3	main
tegevusala	doc_491521501867_item	3235144	et	4	main
arvsõnade	doc_491521501867_item	3235145	et	3	main
kokku-	doc_491521501867_item	3235146	et	3	main
raske	doc_491521501867_item	3235151	et	4	main
nt	doc_491521501867_item	3235152	et	4	main
viis	doc_491521501867_item	3235157	et	4	main
tuhat	doc_491521501867_item	3235158	et	4	main
mitte	doc_491521501867_item	3235159	et	3	main
kolm	doc_491521501867_item	3235166	et	3	main
mitte	doc_491521501867_item	3235168	et	3	main
formatiivi	doc_491521501867_item	3234908	et	4	main
akse	doc_491521501867_item	3234909	et	4	main
vokaaliteisendus	doc_491521501867_item	3234911	et	4	main
oo-uu	doc_491521501867_item	3234912	et	3	main
voi	doc_491521501867_item	3234913	et	4	main
j	doc_491521501867_item	3234917	et	4	main
mitte	doc_491521501867_item	3234927	et	3	main
toodakse	doc_491521501867_item	3234932	et	4	main
da-	doc_491521501867_item	3234935	et	4	main
tegevusnime	doc_491521501867_item	3234936	et	4	main
kasutamine	doc_491521501867_item	3234937	et	4	main
on	doc_491521501867_item	3234938	et	4	main
üks	doc_491521501867_item	3234939	et	3	main
aga	doc_491521501867_item	3234951	et	3	main
tegusõna	doc_491521501867_item	3234954	et	4	main
lõpus	doc_491521501867_item	3234955	et	4	main
nt	doc_491521501867_item	3234962	et	4	main
oskab	doc_491521501867_item	3234963	et	3	main
arvestada	doc_491521501867_item	3234964	et	3	main
mitte	doc_491521501867_item	3234965	et	3	main
arvestama	doc_491521501867_item	3234966	et	3	main
meeldib	doc_491521501867_item	3234967	et	3	main
kuulata	doc_491521501867_item	3234968	et	4	main
on	doc_491521501867_item	3234971	et	4	main
tegema	doc_491521501867_item	3234975	et	3	main
mitte	doc_491521501867_item	3234978	et	3	main
nõus	doc_491521501867_item	3234981	et	4	main
tantsima	doc_491521501867_item	3234982	et	3	main
mitte	doc_491521501867_item	3234983	et	3	main
tantsida	doc_491521501867_item	3234984	et	3	main
valmis	doc_491521501867_item	3234985	et	4	main
minema	doc_491521501867_item	3234986	et	3	main
hakkas	doc_491521501867_item	3235004	et	3	main
töötama	doc_491521501867_item	3235015	et	3	main
pärast	doc_491521501867_item	3235033	et	4	main
millega	doc_491521501867_item	3235035	et	3	main
mitte	doc_491521501867_item	3235044	et	3	main
kuulatama	doc_491521501867_item	3235046	et	4	main
mitte	doc_491521501867_item	3235049	et	3	main
keda	doc_491521501867_item	3235050	et	4	main
keda	doc_491521501867_item	3235057	et	4	main
kellele	doc_491521501867_item	3235060	et	4	main
millele	doc_491521501867_item	3235061	et	3	main
mitte	doc_491521501867_item	3235071	et	3	main
kelles	doc_491521501867_item	3235072	et	4	main
millega	doc_491521501867_item	3235079	et	3	main
mitte	doc_491521501867_item	3235084	et	3	main
millele	doc_491521501867_item	3235089	et	3	main
mitte	doc_491521501867_item	3235096	et	3	main
millele	doc_491521501867_item	3235099	et	3	main
vead	doc_491521501867_item	3235103	et	4	main
õigekirjas	doc_491521501867_item	3235104	et	3	main
ja	doc_491521501867_item	3235109	et	3	main
siis	doc_491521501867_item	3235121	et	3	main
või	doc_491521501867_item	3235123	et	4	main
nt	doc_491521501867_item	3235127	et	4	main
töökoda	doc_491521501867_item	3235131	et	4	main
olümpiapurjespordikeskus	doc_491521501867_item	3235132	et	3	main
mitte	doc_491521501867_item	3235133	et	3	main
kui	doc_491521501867_item	3235137	et	3	main
vaibapuhastus	doc_491521501867_item	3235139	et	3	main
tegevusala	doc_491521501867_item	3235141	et	4	main
on	doc_491521501867_item	3235149	et	4	main
kümmend	doc_491521501867_item	3235165	et	4	main
põhjustada	doc_491521501867_item	3235204	et	3	main
nt	doc_491521501867_item	3235206	et	4	main
lahkusid	doc_491521501867_item	3235208	et	4	main
koolimajast	doc_491521501867_item	3235210	et	4	main
mitte	doc_491521501867_item	3235211	et	3	main
õpilased	doc_491521501867_item	3235212	et	3	main
kiiresti	doc_491521501867_item	3235213	et	3	main
lahkusid	doc_491521501867_item	3235214	et	4	main
verbilaiendiks	doc_491521501867_item	3235220	et	4	main
tihedalt	doc_491521501867_item	3235223	et	4	main
seotud	doc_491521501867_item	3235224	et	4	main
raamat	doc_491521501867_item	3235226	et	3	main
alus	doc_491521501867_item	3235261	et	4	main
tähistab	doc_491521501867_item	3235262	et	3	main
alus	doc_491521501867_item	3235268	et	4	main
tähistab	doc_491521501867_item	3235269	et	3	main
nt	doc_491521501867_item	3235274	et	4	main
on	doc_491521501867_item	3235276	et	4	main
pulmad	doc_491521501867_item	3235280	et	3	main
on	doc_491521501867_item	3235281	et	4	main
meeldejääv	doc_491521501867_item	3235282	et	4	main
sündmus	doc_491521501867_item	3235283	et	3	main
mitte	doc_491521501867_item	3235284	et	3	main
meeldejäävad	doc_491521501867_item	3235285	et	3	main
ühtki	doc_491521501867_item	3235298	et	4	main
üldkehtivat	doc_491521501867_item	3235299	et	3	main
reeglit	doc_491521501867_item	3235300	et	3	main
kuidas	doc_491521501867_item	3235301	et	3	main
ei	doc_491521501867_item	3235306	et	4	main
reegleid	doc_491521501867_item	3235311	et	3	main
laksime	doc_491521501867_item	3235008	et	3	main
sööma	doc_491521501867_item	3235009	et	4	main
süüa	doc_491521501867_item	3235011	et	3	main
mitte	doc_491521501867_item	3235014	et	3	main
milles	doc_491521501867_item	3235017	et	3	main
mille	doc_491521501867_item	3235032	et	3	main
millele	doc_491521501867_item	3235037	et	3	main
kus	doc_491521501867_item	3235039	et	3	main
kuhu	doc_491521501867_item	3235041	et	3	main
kuhu	doc_491521501867_item	3235053	et	3	main
kellele	doc_491521501867_item	3235066	et	4	main
millel	doc_491521501867_item	3235075	et	3	main
millega	doc_491521501867_item	3235083	et	3	main
mitte	doc_491521501867_item	3235092	et	3	main
millele	doc_491521501867_item	3235097	et	3	main
millel	doc_491521501867_item	3235101	et	3	main
kokku-	doc_491521501867_item	3235108	et	3	main
tegemist	doc_491521501867_item	3235118	et	4	main
konkreetse	doc_491521501867_item	3235119	et	3	main
lahku	doc_491521501867_item	3235122	et	4	main
olümpia	doc_491521501867_item	3235134	et	4	main
kui	doc_491521501867_item	3235143	et	3	main
ja	doc_491521501867_item	3235147	et	3	main
samuti	doc_491521501867_item	3235150	et	3	main
üheksasada	doc_491521501867_item	3235153	et	4	main
mitte	doc_491521501867_item	3235154	et	3	main
viistuhat	doc_491521501867_item	3235160	et	4	main
tuhandes	doc_491521501867_item	3235170	et	4	main
kolm	doc_491521501867_item	3235171	et	3	main
miljonit	doc_491521501867_item	3235172	et	3	main
mitte	doc_491521501867_item	3235173	et	3	main
kolmmiljonit	doc_491521501867_item	3235174	et	4	main
kolmemiljoniline	doc_491521501867_item	3235175	et	3	main
mitte	doc_491521501867_item	3235176	et	3	main
kolme	doc_491521501867_item	3235177	et	4	main
miljoniline	doc_491521501867_item	3235178	et	3	main
pool	doc_491521501867_item	3235179	et	4	main
mitte	doc_491521501867_item	3235181	et	3	main
miljardit	doc_491521501867_item	3235180	et	3	main
poolmiljardit	doc_491521501867_item	3235182	et	4	main
poolemiljardik	doc_491521501867_item	3235183	et	4	main
mitte	doc_491521501867_item	3235184	et	3	main
poole	doc_491521501867_item	3235185	et	4	main
miljardik	doc_491521501867_item	3235186	et	3	main
süntaks	doc_491521501867_item	3235187	et	3	main
sõnajärg	doc_491521501867_item	3235188	et	3	main
ja	doc_491521501867_item	3235189	et	3	main
lauseehitus	doc_491521501867_item	3235190	et	4	main
on	doc_491521501867_item	3235191	et	4	main
vale	doc_491521501867_item	3235192	et	4	main
lauseehitus	doc_491521501867_item	3235193	et	4	main
on	doc_491521501867_item	3235194	et	4	main
eesti	doc_491521501867_item	3235195	et	4	main
keeles	doc_491521501867_item	3235196	et	4	main
suhteliselt	doc_491521501867_item	3235197	et	4	main
vaba	doc_491521501867_item	3235198	et	4	main
kuid	doc_491521501867_item	3235199	et	4	main
vale	doc_491521501867_item	3235200	et	4	main
sõnajärg	doc_491521501867_item	3235201	et	3	main
võib	doc_491521501867_item	3235202	et	3	main
omakorda	doc_491521501867_item	3235203	et	3	main
õpilased	doc_491521501867_item	3235209	et	3	main
algul	doc_491521501867_item	3235218	et	4	main
vigu	doc_491521501867_item	3235205	et	3	main
kiiresti	doc_491521501867_item	3235207	et	3	main
on	doc_491521501867_item	3235221	et	4	main
kaasa	doc_491521501867_item	3235244	et	4	main
võtta	doc_491521501867_item	3235245	et	3	main
mitte	doc_491521501867_item	3235246	et	3	main
raadiot	doc_491521501867_item	3235247	et	3	main
kaasa	doc_491521501867_item	3235248	et	4	main
võib	doc_491521501867_item	3235249	et	3	main
võtta	doc_491521501867_item	3235250	et	3	main
ühildumine	doc_491521501867_item	3235254	et	4	main
öeldistäide	doc_491521501867_item	3235272	et	4	main
üliõpilane	doc_491521501867_item	3235293	et	3	main
ei	doc_491521501867_item	3235295	et	4	main
saa	doc_491521501867_item	3235296	et	4	main
anda	doc_491521501867_item	3235297	et	3	main
verbiga	doc_491521501867_item	3235222	et	3	main
viisimäärus	doc_491521501867_item	3235225	et	3	main
lugenud	doc_491521501867_item	3235233	et	4	main
läbi	doc_491521501867_item	3235234	et	4	main
on	doc_491521501867_item	3235237	et	4	main
paikneda	doc_491521501867_item	3235239	et	3	main
ühte	doc_491521501867_item	3235263	et	4	main
siis	doc_491521501867_item	3235264	et	3	main
mitut	doc_491521501867_item	3235270	et	4	main
siis	doc_491521501867_item	3235271	et	3	main
sündmused	doc_491521501867_item	3235286	et	3	main
karina	doc_491521501867_item	3235289	et	3	main
mitte	doc_491521501867_item	3235292	et	3	main
kokkuvõte	doc_491521501867_item	3235294	et	3	main
keelevigu	doc_491521501867_item	3235303	et	3	main
ole	doc_491521501867_item	3235307	et	4	main
kuidas	doc_491521501867_item	3235312	et	3	main
iga	doc_491521501867_item	3235316	et	4	main
et	doc_491521501867_item	3235319	et	3	main
vestlejatena	doc_491521501867_item	3235328	et	4	main
sellest	doc_491521501867_item	3235334	et	4	main
oleks	doc_491521501867_item	3235335	et	3	main
abi	doc_491521501867_item	3235336	et	4	main
ihkavad	doc_491521501867_item	3235339	et	4	main
vabalt	doc_491521501867_item	3235340	et	4	main
eksperimenteerida	doc_491521501867_item	3235341	et	3	main
kuid	doc_491521501867_item	3235342	et	4	main
ka	doc_491521501867_item	3235343	et	3	main
teadmist	doc_491521501867_item	3235348	et	4	main
mis	doc_491521501867_item	3235349	et	4	main
loodan	doc_491521501867_item	3235355	et	3	main
et	doc_491521501867_item	3235356	et	3	main
käesolev	doc_491521501867_item	3235357	et	3	main
vigade	doc_491521501867_item	3235358	et	3	main
analüüs	doc_491521501867_item	3235359	et	3	main
raadiot	doc_491521501867_item	3235242	et	3	main
võib	doc_491521501867_item	3235243	et	3	main
öeldistaite	doc_491521501867_item	3235253	et	4	main
ei	doc_491521501867_item	3235257	et	4	main
tee	doc_491521501867_item	3235258	et	4	main
vahet	doc_491521501867_item	3235259	et	3	main
kas	doc_491521501867_item	3235260	et	3	main
ainsuses	doc_491521501867_item	3235266	et	4	main
või	doc_491521501867_item	3235267	et	4	main
mitmuses	doc_491521501867_item	3235273	et	3	main
mitte	doc_491521501867_item	3235278	et	3	main
ja	doc_491521501867_item	3235288	et	3	main
nagu	doc_491521501867_item	3235305	et	3	main
selgeid	doc_491521501867_item	3235310	et	3	main
õppida	doc_491521501867_item	3235315	et	3	main
end	doc_491521501867_item	3235326	et	4	main
vilunud	doc_491521501867_item	3235327	et	4	main
kes	doc_491521501867_item	3235345	et	4	main
on	doc_491521501867_item	3235350	et	4	main
huvi	doc_491521501867_item	3235362	et	4	main
ja	doc_491521501867_item	3235363	et	3	main
anda	doc_491521501867_item	3235309	et	3	main
ja	doc_491521501867_item	3235314	et	3	main
õpiksid	doc_491521501867_item	3235322	et	4	main
suhtlema	doc_491521501867_item	3235323	et	3	main
ja	doc_491521501867_item	3235324	et	3	main
peaks	doc_491521501867_item	3235330	et	4	main
kes	doc_491521501867_item	3235338	et	4	main
soovivad	doc_491521501867_item	3235346	et	4	main
õige	doc_491521501867_item	3235351	et	4	main
ja	doc_491521501867_item	3235352	et	3	main
mis	doc_491521501867_item	3235353	et	4	main
vale	doc_491521501867_item	3235354	et	4	main
pakub	doc_491521501867_item	3235360	et	3	main
õpetajatele	doc_491521501867_item	3235361	et	4	main
kerge	doc_491521501867_item	3235371	et	4	main
krista	doc_491521501867_item	3235372	et	4	main
1996funktsionaalse	doc_491521501867_item	3235373	et	3	main
keeleoskuse	doc_491521501867_item	3235374	et	3	main
taseme	doc_491521501867_item	3235375	et	3	main
maaratlemine	doc_491521501867_item	3235376	et	4	main
2	doc_491521501867_item	3235377	et	2	main
krista	doc_491521501867_item	3235379	et	4	main
kerge	doc_491521501867_item	3235378	et	4	main
loog	doc_491521501867_item	3235380	et	3	main
mai	doc_491521501867_item	3235381	et	4	main
1999	doc_491521501867_item	3235382	et	2	main
tuul	doc_491521501867_item	3235383	et	3	main
tiibades	doc_491521501867_item	3235384	et	3	main
tallinn	doc_491521501867_item	3235385	et	4	main
riiklik	doc_491521501867_item	3235386	et	3	main
eksami-	doc_491521501867_item	3235387	et	3	main
ja	doc_491521501867_item	3235388	et	3	main
kvalifikatsioonikeskus	doc_491521501867_item	3235389	et	3	main
tundma	doc_491521501867_item	3235325	et	3	main
olema	doc_491521501867_item	3235331	et	4	main
paindlik	doc_491521501867_item	3235332	et	3	main
et	doc_491521501867_item	3235333	et	3	main
turvalist	doc_491521501867_item	3235347	et	4	main
saab	doc_491521501867_item	3235365	et	3	main
kasutada	doc_491521501867_item	3235367	et	3	main
kasutatud	doc_491521501867_item	3235368	et	4	main
kirjandus	doc_491521501867_item	3235369	et	3	main
1	doc_491521501867_item	3235370	et	2	main
teade	doc_491521501757_item	3261068	et	4	main
seetõttu	doc_491521501757_item	3261077	et	3	main
majandusest	doc_491521501757_item	3261081	et	4	main
lugejatele	doc_491521501757_item	3261083	et	4	main
kuid	doc_491521501757_item	3261084	et	4	main
sisult	doc_491521501757_item	3261085	et	3	main
meenutab	doc_491521501757_item	3261086	et	3	main
hoopis	doc_491521501757_item	3261087	et	3	main
peaks	doc_491521501757_item	3261093	et	4	main
huvi	doc_491521501757_item	3261100	et	4	main
küsimus	doc_491521501757_item	3261125	et	4	main
võiks	doc_491521501757_item	3261127	et	4	main
tähendada	doc_491521501757_item	3261128	et	3	main
hispaania	doc_491521501757_item	3261129	et	4	main
peaministri	doc_491521501757_item	3261130	et	3	main
kas	doc_491521501757_item	3261061	et	3	main
olemuselt	doc_491521501757_item	3261067	et	3	main
majandusajakirjast	doc_491521501757_item	3261072	et	2	main
the	doc_491521501757_item	3261073	et	4	main
оlеmа	doc_491521501757_item	3261078	et	2	main
mõnda	doc_491521501757_item	3261088	et	4	main
seltskonnaajakirjas	doc_491521501757_item	3261089	et	2	main
ilmunud	doc_491521501757_item	3261090	et	4	main
artiklit	doc_491521501757_item	3261091	et	3	main
seega	doc_491521501757_item	3261092	et	4	main
tekitab	doc_491521501757_item	3261099	et	3	main
kuigi	doc_491521501757_item	3261101	et	3	main
hispaania	doc_491521501757_item	3261103	et	4	main
mida	doc_491521501757_item	3261126	et	4	main
tutvustatakse	doc_491521501757_item	3261137	et	3	main
veelkord	doc_491521501757_item	3261147	et	3	main
kuivõrd	doc_491521501757_item	3261148	et	3	main
ärritav	doc_491521501757_item	3261149	et	4	main
on	doc_491521501757_item	3261150	et	4	main
lugeja	doc_491521501757_item	3261155	et	4	main
ajastu	doc_491521501757_item	3261063	et	4	main
see	doc_491521501757_item	3261069	et	3	main
on	doc_491521501757_item	3261070	et	4	main
ning	doc_491521501757_item	3261075	et	3	main
lugejaskond	doc_491521501757_item	3261094	et	3	main
pealkiri	doc_491521501757_item	3261098	et	3	main
mul	doc_491521501757_item	3261105	et	3	main
seejärellugejale	doc_491521501757_item	3261132	et	2	main
räägitakse	doc_491521501757_item	3261133	et	3	main
sündmusest	doc_491521501757_item	3261134	et	4	main
vaid	doc_491521501757_item	3261144	et	3	main
arvates	doc_491521501757_item	3261152	et	4	main
peaministri	doc_491521501757_item	3261153	et	3	main
selle	doc_491521501757_item	3261157	et	4	main
palju	doc_491521501757_item	3261163	et	4	main
ja	doc_491521501757_item	3261165	et	3	main
neid	doc_491521501757_item	3261167	et	4	main
viimaseid	doc_491521501757_item	3261168	et	3	main
liiga	doc_491521501757_item	3261172	et	4	main
lühikesed	doc_491521501757_item	3261184	et	4	main
palju	doc_491521501757_item	3261209	et	4	main
kirjavigu	doc_491521501757_item	3261210	et	3	main
komavead	doc_491521501757_item	3261211	et	2	main
vahetanud	doc_491521501757_item	3261217	et	4	main
soovi	doc_491521501757_item	3261229	et	4	main
analüüs	doc_491521501757_item	3261059	et	3	main
ühe	doc_491521501757_item	3261062	et	4	main
lõрр	doc_491521501757_item	3261064	et	2	main
on	doc_491521501757_item	3261065	et	4	main
peaks	doc_491521501757_item	3261076	et	4	main
mõеldud	doc_491521501757_item	3261079	et	2	main
üsna	doc_491521501757_item	3261096	et	3	main
lai	doc_491521501757_item	3261097	et	3	main
selle	doc_491521501757_item	3261138	et	4	main
vastust	doc_491521501757_item	3261140	et	4	main
küsimusele	doc_491521501757_item	3261141	et	4	main
kõigi	doc_491521501757_item	3261151	et	4	main
juhitakse	doc_491521501757_item	3261156	et	2	main
vahest	doc_491521501757_item	3261170	et	4	main
palju	doc_491521501757_item	3261173	et	4	main
laused	doc_491521501757_item	3261181	et	3	main
tähed	doc_491521501757_item	3261212	et	3	main
on	doc_491521501757_item	3261213	et	4	main
kirjavahemärke	doc_491521501757_item	3261218	et	4	main
igaüks	doc_491521501757_item	3261232	et	3	main
artikli	doc_491521501757_item	3261237	et	3	main
peaministri	doc_491521501757_item	3261240	et	3	main
selle	doc_491521501757_item	3261244	et	4	main
ei	doc_491521501757_item	3261254	et	4	main
artikel	doc_491521501757_item	3261060	et	4	main
oma	doc_491521501757_item	3261066	et	4	main
tõlgitud	doc_491521501757_item	3261071	et	4	main
economist	doc_491521501757_item	3261074	et	2	main
just	doc_491521501757_item	3261080	et	3	main
huvitatud	doc_491521501757_item	3261082	et	4	main
оlеmа	doc_491521501757_item	3261095	et	2	main
märkest	doc_491521501757_item	3261102	et	2	main
jäi	doc_491521501757_item	3261104	et	3	main
muljе	doc_491521501757_item	3261106	et	2	main
et	doc_491521501757_item	3261107	et	3	main
tekstis	doc_491521501757_item	3261108	et	3	main
on	doc_491521501757_item	3261109	et	4	main
juttu	doc_491521501757_item	3261110	et	4	main
mõnest	doc_491521501757_item	3261111	et	3	main
hispaania	doc_491521501757_item	3261112	et	4	main
rahvakombest	doc_491521501757_item	3261113	et	2	main
artikkel	doc_491521501757_item	3261114	et	3	main
on	doc_491521501757_item	3261115	et	4	main
üsna	doc_491521501757_item	3261116	et	3	main
lühike	doc_491521501757_item	3261117	et	4	main
see	doc_491521501757_item	3261118	et	3	main
koosneb	doc_491521501757_item	3261119	et	3	main
viiest	doc_491521501757_item	3261120	et	4	main
lõigust	doc_491521501757_item	3261121	et	2	main
esimeses	doc_491521501757_item	3261122	et	3	main
sissejuhatuses	doc_491521501757_item	3261123	et	4	main
esitatakse	doc_491521501757_item	3261124	et	3	main
tegu	doc_491521501757_item	3261131	et	4	main
ei	doc_491521501757_item	3261142	et	4	main
antagi	doc_491521501757_item	3261143	et	2	main
rõhutatakse	doc_491521501757_item	3261145	et	3	main
lõpetuseks	doc_491521501757_item	3261146	et	4	main
teguviis	doc_491521501757_item	3261154	et	2	main
järelduseni	doc_491521501757_item	3261158	et	4	main
seejuures	doc_491521501757_item	3261162	et	3	main
näiteid	doc_491521501757_item	3261164	et	3	main
fakte	doc_491521501757_item	3261166	et	3	main
on	doc_491521501757_item	3261169	et	4	main
nii	doc_491521501757_item	3261175	et	3	main
ja	doc_491521501757_item	3261185	et	3	main
on	doc_491521501757_item	3261219	et	4	main
millegipärast	doc_491521501757_item	3261220	et	3	main
eelnevatest	doc_491521501757_item	3261222	et	2	main
sõnadest	doc_491521501757_item	3261223	et	3	main
nihutatud	doc_491521501757_item	3261225	et	2	main
tekstil	doc_491521501757_item	3261226	et	3	main
puudub	doc_491521501757_item	3261227	et	3	main
isikupära	doc_491521501757_item	3261228	et	4	main
võiks	doc_491521501757_item	3261231	et	4	main
ja	doc_491521501757_item	3261242	et	3	main
rõhutada	doc_491521501757_item	3261243	et	3	main
mina	doc_491521501757_item	3261257	et	4	main
pole	doc_491521501757_item	3261258	et	3	main
aga	doc_491521501757_item	3261259	et	3	main
nende	doc_491521501757_item	3261260	et	4	main
hulgas	doc_491521501757_item	3261261	et	4	main
mind	doc_491521501757_item	3261262	et	4	main
ei	doc_491521501757_item	3261263	et	4	main
huvita	doc_491521501757_item	3261264	et	4	main
eestigi	doc_491521501757_item	3261265	et	2	main
poliitikute	doc_491521501757_item	3261266	et	3	main
isiklik	doc_491521501757_item	3261267	et	3	main
elu	doc_491521501757_item	3261268	et	4	main
rääkimata	doc_491521501757_item	3261269	et	4	main
juba	doc_491521501757_item	3261270	et	3	main
teiste	doc_491521501757_item	3261271	et	4	main
riikide	doc_491521501757_item	3261272	et	3	main
omast	doc_491521501757_item	3261273	et	4	main
pealegi	doc_491521501757_item	3261274	et	4	main
ei	doc_491521501757_item	3261275	et	4	main
lое	doc_491521501757_item	3261276	et	2	main
mа	doc_491521501757_item	3261277	et	2	main
seltskonnaajakirjandust	doc_491521501757_item	3261278	et	2	main
endast	doc_491521501757_item	3261135	et	4	main
ja	doc_491521501757_item	3261136	et	3	main
tausta	doc_491521501757_item	3261139	et	4	main
otseselt	doc_491521501757_item	3261160	et	4	main
tuua	doc_491521501757_item	3261174	et	3	main
palju	doc_491521501757_item	3261176	et	4	main
eriti	doc_491521501757_item	3261179	et	3	main
kohta	doc_491521501757_item	3261216	et	4	main
neile	doc_491521501757_item	3261221	et	4	main
ееmаlе	doc_491521501757_item	3261224	et	2	main
sellise	doc_491521501757_item	3261233	et	4	main
saada	doc_491521501757_item	3261236	et	4	main
teost	doc_491521501757_item	3261241	et	4	main
lugejaid	doc_491521501757_item	3261250	et	4	main
keda	doc_491521501757_item	3261251	et	4	main
see	doc_491521501757_item	3261252	et	3	main
üsna	doc_491521501757_item	3261159	et	3	main
kasutades	doc_491521501757_item	3261161	et	3	main
isegi	doc_491521501757_item	3261171	et	4	main
numbreid	doc_491521501757_item	3261177	et	3	main
pole	doc_491521501757_item	3261178	et	3	main
mõtekas	doc_491521501757_item	3261180	et	4	main
on	doc_491521501757_item	3261182	et	4	main
piisavalt	doc_491521501757_item	3261183	et	4	main
lihtsad	doc_491521501757_item	3261186	et	3	main
seetõttu	doc_491521501757_item	3261187	et	3	main
ka	doc_491521501757_item	3261188	et	3	main
kergeltltjälgitavad	doc_491521501757_item	3261189	et	2	main
теkst	doc_491521501757_item	3261190	et	2	main
oil	doc_491521501757_item	3261191	et	4	main
kirjutatud	doc_491521501757_item	3261192	et	4	main
argikeeles	doc_491521501757_item	3261193	et	2	main
nii	doc_491521501757_item	3261194	et	3	main
et	doc_491521501757_item	3261195	et	3	main
see	doc_491521501757_item	3261196	et	3	main
oleks	doc_491521501757_item	3261197	et	3	main
võimalikult	doc_491521501757_item	3261198	et	4	main
paljudele	doc_491521501757_item	3261199	et	3	main
arusaadav	doc_491521501757_item	3261200	et	4	main
arvestades	doc_491521501757_item	3261201	et	3	main
sisu	doc_491521501757_item	3261202	et	4	main
on	doc_491521501757_item	3261203	et	4	main
sõnavalik	doc_491521501757_item	3261204	et	3	main
õnnestunud	doc_491521501757_item	3261205	et	4	main
samas	doc_491521501757_item	3261206	et	4	main
on	doc_491521501757_item	3261207	et	4	main
tekstis	doc_491521501757_item	3261208	et	3	main
paaris	doc_491521501757_item	3261214	et	4	main
sõnas	doc_491521501757_item	3261215	et	4	main
korral	doc_491521501757_item	3261230	et	4	main
hakkama	doc_491521501757_item	3261235	et	3	main
on	doc_491521501757_item	3261246	et	4	main
tekst	doc_491521501757_item	3261253	et	3	main
jäta	doc_491521501757_item	3261255	et	4	main
külmaks	doc_491521501757_item	3261256	et	4	main
kirjutisega	doc_491521501757_item	3261234	et	2	main
eesmärk	doc_491521501757_item	3261238	et	3	main
jutustada	doc_491521501757_item	3261239	et	3	main
kohatust	doc_491521501757_item	3261245	et	2	main
täidetud	doc_491521501757_item	3261247	et	4	main
kindlasti	doc_491521501757_item	3261248	et	3	main
on	doc_491521501757_item	3261249	et	4	main
analüüs	doc_491521501783_item	3265725	et	3	main
ning	doc_491521501783_item	3265734	et	3	main
allikatest	doc_491521501783_item	3265742	et	4	main
esiteks	doc_491521501783_item	3265743	et	3	main
need	doc_491521501783_item	3265744	et	3	main
kus	doc_491521501783_item	3265753	et	3	main
11	doc_491521501783_item	3265760	et	2	main
on	doc_491521501783_item	3265765	et	4	main
õpetajad	doc_491521501783_item	3265767	et	4	main
ning	doc_491521501783_item	3265768	et	3	main
on	doc_491521501783_item	3265773	et	4	main
kõrgel	doc_491521501783_item	3265774	et	4	main
veaanalüüs	doc_491521501783_item	3265728	et	4	main
veaanalüüsis	doc_491521501783_item	3265730	et	4	main
mõnikord	doc_491521501783_item	3265735	et	3	main
mis	doc_491521501783_item	3265738	et	4	main
on	doc_491521501783_item	3265739	et	4	main
ma	doc_491521501783_item	3265754	et	3	main
10	doc_491521501783_item	3265758	et	2	main
kesklinnagümnaasiumis	doc_491521501783_item	3265763	et	3	main
õpilaste	doc_491521501783_item	3265769	et	4	main
eesti	doc_491521501783_item	3265770	et	4	main
keele	doc_491521501783_item	3265771	et	4	main
oskus	doc_491521501783_item	3265772	et	3	main
on	doc_491521501783_item	3265784	et	4	main
vastustest	doc_491521501783_item	3265791	et	4	main
esitatud	doc_491521501783_item	3265799	et	4	main
mina	doc_491521501783_item	3265802	et	4	main
lingvistika	doc_491521501783_item	3265727	et	4	main
leida	doc_491521501783_item	3265732	et	3	main
naljakaid	doc_491521501783_item	3265736	et	4	main
on	doc_491521501783_item	3265745	et	4	main
minu	doc_491521501783_item	3265746	et	3	main
poolt	doc_491521501783_item	3265747	et	4	main
kontrolltööd	doc_491521501783_item	3265751	et	4	main
eelmisel	doc_491521501783_item	3265755	et	3	main
klassides	doc_491521501783_item	3265761	et	3	main
mina	doc_491521501783_item	3265777	et	4	main
annan	doc_491521501783_item	3265778	et	3	main
mõned	doc_491521501783_item	3265781	et	3	main
õpilaste	doc_491521501783_item	3265786	et	4	main
kui	doc_491521501783_item	3265805	et	3	main
alustasin	doc_491521501783_item	3265806	et	3	main
eesti	doc_491521501783_item	3265807	et	4	main
naerma	doc_491521501783_item	3265827	et	3	main
ja	doc_491521501783_item	3265829	et	3	main
ole	doc_491521501783_item	3265835	et	4	main
nt	doc_491521501783_item	3265839	et	4	main
da	doc_491521501783_item	3265854	et	4	main
õpilased	doc_491521501783_item	3265858	et	3	main
ta	doc_491521501783_item	3265866	et	4	main
oli	doc_491521501783_item	3265867	et	3	main
on	doc_491521501783_item	3265872	et	4	main
ei	doc_491521501783_item	3265878	et	4	main
teevad	doc_491521501783_item	3265887	et	3	main
loomulikult	doc_491521501783_item	3265894	et	4	main
rõhku	doc_491521501783_item	3265898	et	4	main
eksisteerivad	doc_491521501783_item	3265911	et	4	main
kirjutamisel	doc_491521501783_item	3265926	et	4	main
ei	doc_491521501783_item	3265927	et	4	main
alkohooli	doc_491521501783_item	3265929	et	3	main
tarvitada	doc_491521501783_item	3265930	et	3	main
alkohol	doc_491521501783_item	3265931	et	3	main
kuna	doc_491521501783_item	3265932	et	3	main
pannakse	doc_491521501783_item	3265934	et	3	main
valesti	doc_491521501783_item	3265935	et	3	main
siis	doc_491521501783_item	3265936	et	3	main
ma	doc_491521501783_item	3265940	et	3	main
sinu	doc_491521501783_item	3265943	et	3	main
tüüpi	doc_491521501783_item	3265948	et	4	main
vigu	doc_491521501783_item	3265949	et	3	main
see	doc_491521501783_item	3265951	et	3	main
seda	doc_491521501783_item	3265959	et	3	main
elan	doc_491521501783_item	3265968	et	3	main
keele	doc_491521501783_item	3266021	et	4	main
kasutamisel	doc_491521501783_item	3266022	et	4	main
põhiline	doc_491521501783_item	3266023	et	3	main
esineb	doc_491521501783_item	3266025	et	3	main
keeles	doc_491521501783_item	3266030	et	4	main
see	doc_491521501783_item	3266031	et	3	main
vastab	doc_491521501783_item	3266032	et	3	main
käib	doc_491521501783_item	3266040	et	3	main
käisid	doc_491521501783_item	3266045	et	4	main
aeg	doc_491521501783_item	3266047	et	3	main
teised	doc_491521501783_item	3266050	et	4	main
vead	doc_491521501783_item	3266051	et	4	main
seepärast	doc_491521501783_item	3266055	et	3	main
et	doc_491521501783_item	3266056	et	3	main
käände	doc_491521501783_item	3266060	et	4	main
lühivorm	doc_491521501783_item	3266061	et	3	main
mitte	doc_491521501783_item	3266063	et	3	main
muud	doc_491521501783_item	3266077	et	4	main
nagu	doc_491521501783_item	3266079	et	3	main
probleemid	doc_491521501783_item	3266082	et	3	main
ma	doc_491521501783_item	3266087	et	3	main
käesolevas	doc_491521501783_item	3265729	et	3	main
huvitavaid	doc_491521501783_item	3265733	et	4	main
vigu	doc_491521501783_item	3265737	et	3	main
kogutud	doc_491521501783_item	3265740	et	4	main
säilinud	doc_491521501783_item	3265748	et	4	main
alles	doc_491521501783_item	3265749	et	3	main
koolipraktikast	doc_491521501783_item	3265752	et	4	main
aastal	doc_491521501783_item	3265756	et	3	main
ja	doc_491521501783_item	3265759	et	3	main
tasemel	doc_491521501783_item	3265775	et	3	main
töös	doc_491521501783_item	3265797	et	3	main
keele	doc_491521501783_item	3265808	et	4	main
hääldus	doc_491521501783_item	3265828	et	4	main
eesti	doc_491521501783_item	3265831	et	4	main
keeruline	doc_491521501783_item	3265837	et	4	main
vene	doc_491521501783_item	3265840	et	4	main
ortograafia	doc_491521501783_item	3265842	et	4	main
käia	doc_491521501783_item	3265852	et	4	main
ma	doc_491521501783_item	3265860	et	3	main
ise	doc_491521501783_item	3265868	et	4	main
selles	doc_491521501783_item	3265869	et	4	main
vaja	doc_491521501783_item	3265873	et	4	main
jalksi	doc_491521501783_item	3265880	et	4	main
minna	doc_491521501783_item	3265881	et	3	main
teiseks	doc_491521501783_item	3265883	et	4	main
miks	doc_491521501783_item	3265885	et	4	main
õpilased	doc_491521501783_item	3265886	et	3	main
mõju	doc_491521501783_item	3265892	et	4	main
nt	doc_491521501783_item	3265893	et	4	main
2	doc_491521501783_item	3265897	et	2	main
mis	doc_491521501783_item	3265900	et	4	main
põhjustabki	doc_491521501783_item	3265901	et	3	main
vigade	doc_491521501783_item	3265902	et	3	main
tegemist	doc_491521501783_item	3265903	et	4	main
sarnased	doc_491521501783_item	3265912	et	4	main
tohi	doc_491521501783_item	3265928	et	4	main
rõhk	doc_491521501783_item	3265933	et	3	main
kirjutatakse	doc_491521501783_item	3265937	et	3	main
ka	doc_491521501783_item	3265938	et	3	main
valesti	doc_491521501783_item	3265939	et	3	main
tea	doc_491521501783_item	3265942	et	4	main
aadresi	doc_491521501783_item	3265944	et	4	main
astmevaheldus	doc_491521501783_item	3265946	et	4	main
sellist	doc_491521501783_item	3265947	et	4	main
neile	doc_491521501783_item	3265958	et	4	main
üldse	doc_491521501783_item	3265960	et	3	main
kauplus	doc_491521501783_item	3265971	et	3	main
keskturgu	doc_491521501783_item	3265973	et	4	main
kasutamine	doc_491521501783_item	3265981	et	4	main
küsimusele	doc_491521501783_item	3266033	et	4	main
kuhu	doc_491521501783_item	3266034	et	3	main
arvuti	doc_491521501783_item	3266041	et	4	main
tekkivad	doc_491521501783_item	3266052	et	4	main
eesti	doc_491521501783_item	3266053	et	4	main
sisseütleva	doc_491521501783_item	3266059	et	3	main
peatus	doc_491521501783_item	3266069	et	4	main
asub	doc_491521501783_item	3266070	et	3	main
kinno	doc_491521501783_item	3266071	et	3	main
ees	doc_491521501783_item	3266072	et	4	main
kino	doc_491521501783_item	3266073	et	4	main
me	doc_491521501783_item	3266074	et	4	main
läheme	doc_491521501783_item	3266075	et	3	main
teatri	doc_491521501783_item	3266076	et	3	main
näitab	doc_491521501783_item	3266080	et	3	main
tekkivad	doc_491521501783_item	3266083	et	4	main
osastava	doc_491521501783_item	3266084	et	4	main
5	doc_491521501783_item	3266089	et	2	main
peatust	doc_491521501783_item	3266091	et	4	main
esita	doc_491521501783_item	3266125	et	4	main
ma	doc_491521501783_item	3266134	et	3	main
raamatu	doc_491521501783_item	3266136	et	4	main
ei	doc_491521501783_item	3266151	et	4	main
praktiseerida	doc_491521501783_item	3266161	et	3	main
ja	doc_491521501783_item	3266162	et	3	main
harjutada	doc_491521501783_item	3266163	et	3	main
korrusel	doc_491521501783_item	3266167	et	3	main
kontrastiiv	doc_491521501783_item	3265726	et	4	main
võib	doc_491521501783_item	3265731	et	3	main
erinevatest	doc_491521501783_item	3265741	et	4	main
jäänud	doc_491521501783_item	3265750	et	4	main
õpetasin	doc_491521501783_item	3265757	et	3	main
tallinna	doc_491521501783_item	3265762	et	4	main
koolis	doc_491521501783_item	3265764	et	4	main
tugevad	doc_491521501783_item	3265766	et	4	main
kuna	doc_491521501783_item	3265776	et	3	main
eratunde	doc_491521501783_item	3265779	et	4	main
siis	doc_491521501783_item	3265780	et	3	main
võetud	doc_491521501783_item	3265785	et	4	main
huvitav	doc_491521501783_item	3265792	et	4	main
on	doc_491521501783_item	3265793	et	4	main
see	doc_491521501783_item	3265794	et	3	main
et	doc_491521501783_item	3265795	et	3	main
minu	doc_491521501783_item	3265796	et	3	main
vead	doc_491521501783_item	3265800	et	4	main
õppimist	doc_491521501783_item	3265809	et	4	main
käies	doc_491521501783_item	3265810	et	3	main
eratundides	doc_491521501783_item	3265811	et	3	main
tihti	doc_491521501783_item	3265812	et	3	main
kirjutasin	doc_491521501783_item	3265813	et	3	main
igasuguseid	doc_491521501783_item	3265814	et	3	main
kirjalikke	doc_491521501783_item	3265815	et	3	main
töid	doc_491521501783_item	3265816	et	3	main
mida	doc_491521501783_item	3265817	et	4	main
praegu	doc_491521501783_item	3265818	et	3	main
on	doc_491521501783_item	3265819	et	4	main
väga	doc_491521501783_item	3265820	et	3	main
huvitav	doc_491521501783_item	3265821	et	4	main
lugeda	doc_491521501783_item	3265822	et	3	main
ja	doc_491521501783_item	3265823	et	3	main
mis	doc_491521501783_item	3265824	et	4	main
tihtipeale	doc_491521501783_item	3265825	et	3	main
ei	doc_491521501783_item	3265834	et	4	main
tavaliselt	doc_491521501783_item	3265843	et	4	main
kirjutame	doc_491521501783_item	3265844	et	3	main
nii	doc_491521501783_item	3265845	et	3	main
nagu	doc_491521501783_item	3265846	et	3	main
hääldame	doc_491521501783_item	3265847	et	3	main
kuid	doc_491521501783_item	3265848	et	4	main
mitte	doc_491521501783_item	3265849	et	3	main
alati	doc_491521501783_item	3265850	et	4	main
nt	doc_491521501783_item	3265851	et	4	main
tihtipeale	doc_491521501783_item	3265856	et	3	main
kirjutama	doc_491521501783_item	3265859	et	3	main
koolis	doc_491521501783_item	3265863	et	4	main
käja	doc_491521501783_item	3265864	et	4	main
süüti	doc_491521501783_item	3265870	et	4	main
ma	doc_491521501783_item	3265877	et	3	main
kõnekeele	doc_491521501783_item	3265891	et	4	main
pannakse	doc_491521501783_item	3265896	et	3	main
loomuliikult	doc_491521501783_item	3265899	et	4	main
keeles	doc_491521501783_item	3265910	et	4	main
sõnade	doc_491521501783_item	3265925	et	3	main
et	doc_491521501783_item	3265952	et	3	main
ei	doc_491521501783_item	3265954	et	4	main
õpetata	doc_491521501783_item	3265962	et	3	main
korrusel	doc_491521501783_item	3265970	et	3	main
asub	doc_491521501783_item	3265972	et	3	main
objektivead	doc_491521501783_item	3265975	et	4	main
mis	doc_491521501783_item	3265976	et	4	main
tähendab	doc_491521501783_item	3265977	et	3	main
sihitiste	doc_491521501783_item	3265978	et	3	main
esitatud	doc_491521501783_item	3265782	et	4	main
vead	doc_491521501783_item	3265783	et	4	main
kirjalikkest	doc_491521501783_item	3265787	et	4	main
töödest	doc_491521501783_item	3265788	et	3	main
ja	doc_491521501783_item	3265789	et	3	main
suulistest	doc_491521501783_item	3265790	et	4	main
on	doc_491521501783_item	3265798	et	4	main
mida	doc_491521501783_item	3265801	et	4	main
veel	doc_491521501783_item	3265803	et	4	main
tegin	doc_491521501783_item	3265804	et	3	main
paneb	doc_491521501783_item	3265826	et	3	main
nii	doc_491521501783_item	3265836	et	3	main
käima	doc_491521501783_item	3265853	et	4	main
kippuvad	doc_491521501783_item	3265857	et	4	main
taha	doc_491521501783_item	3265862	et	4	main
hästi	doc_491521501783_item	3265874	et	3	main
süja	doc_491521501783_item	3265875	et	4	main
süüa	doc_491521501783_item	3265876	et	3	main
põhjuseks	doc_491521501783_item	3265884	et	3	main
selliseid	doc_491521501783_item	3265888	et	4	main
vigu	doc_491521501783_item	3265889	et	3	main
on	doc_491521501783_item	3265890	et	4	main
siia	doc_491521501783_item	3265895	et	4	main
eesti	doc_491521501783_item	3265909	et	4	main
õigekiri	doc_491521501783_item	3265830	et	3	main
keele	doc_491521501783_item	3265832	et	4	main
ortograafia	doc_491521501783_item	3265833	et	4	main
kui	doc_491521501783_item	3265838	et	3	main
keele	doc_491521501783_item	3265841	et	4	main
infinitiivis	doc_491521501783_item	3265855	et	3	main
ei	doc_491521501783_item	3265861	et	4	main
käia	doc_491521501783_item	3265865	et	4	main
süüdi	doc_491521501783_item	3265871	et	4	main
taha	doc_491521501783_item	3265879	et	4	main
jalgsi	doc_491521501783_item	3265882	et	3	main
loomuliikult	doc_491521501783_item	3265904	et	4	main
ma	doc_491521501783_item	3265905	et	3	main
tahan	doc_491521501783_item	3265906	et	3	main
süüa	doc_491521501783_item	3265907	et	3	main
kui	doc_491521501783_item	3265908	et	3	main
sõnad	doc_491521501783_item	3265913	et	4	main
kui	doc_491521501783_item	3265914	et	3	main
vene	doc_491521501783_item	3265915	et	4	main
keeles	doc_491521501783_item	3265916	et	4	main
nt	doc_491521501783_item	3265917	et	4	main
алкоголь	doc_491521501783_item	3265918	et	2	main
адрес	doc_491521501783_item	3265919	et	2	main
siis	doc_491521501783_item	3265920	et	3	main
võivad	doc_491521501783_item	3265921	et	4	main
kerkida	doc_491521501783_item	3265922	et	3	main
mõned	doc_491521501783_item	3265923	et	3	main
probleemid	doc_491521501783_item	3265924	et	3	main
ei	doc_491521501783_item	3265941	et	4	main
põhjustab	doc_491521501783_item	3265950	et	3	main
õpilased	doc_491521501783_item	3265953	et	3	main
tea	doc_491521501783_item	3265955	et	4	main
tüüpsõnu	doc_491521501783_item	3265956	et	3	main
või	doc_491521501783_item	3265957	et	4	main
ei	doc_491521501783_item	3265961	et	4	main
ei	doc_491521501783_item	3265964	et	4	main
vedanud	doc_491521501783_item	3265965	et	4	main
treppikodaga	doc_491521501783_item	3265966	et	4	main
ma	doc_491521501783_item	3265967	et	3	main
lähedal	doc_491521501783_item	3265974	et	4	main
tavaliselt	doc_491521501783_item	3265982	et	4	main
viga	doc_491521501783_item	3266024	et	4	main
käima-verbi	doc_491521501783_item	3266026	et	4	main
kuna	doc_491521501783_item	3266028	et	3	main
kus	doc_491521501783_item	3266038	et	3	main
ta	doc_491521501783_item	3266039	et	4	main
kogu	doc_491521501783_item	3266046	et	4	main
ekskursioonidele	doc_491521501783_item	3266048	et	3	main
on	doc_491521501783_item	3266057	et	4	main
käändevead	doc_491521501783_item	3266078	et	4	main
kogemus	doc_491521501783_item	3266081	et	3	main
sõidan	doc_491521501783_item	3266088	et	3	main
saada	doc_491521501783_item	3266101	et	4	main
vastused	doc_491521501783_item	3266103	et	3	main
vastuseid	doc_491521501783_item	3266106	et	3	main
kaasas	doc_491521501783_item	3266133	et	4	main
õpilased	doc_491521501783_item	3266150	et	3	main
oska	doc_491521501783_item	3266152	et	4	main
kakskümmendaastane	doc_491521501783_item	3266170	et	4	main
sai	doc_491521501783_item	3266196	et	4	main
ma	doc_491521501783_item	3266200	et	3	main
samas	doc_491521501783_item	3266202	et	4	main
kohal	doc_491521501783_item	3266203	et	4	main
meid	doc_491521501783_item	3266204	et	4	main
ümbritseb	doc_491521501783_item	3266205	et	3	main
kus	doc_491521501783_item	3266229	et	3	main
kesk-	doc_491521501783_item	3266232	et	3	main
ülivõrret	doc_491521501783_item	3266234	et	3	main
ilmnevad	doc_491521501783_item	3266242	et	4	main
aadressi	doc_491521501783_item	3265945	et	4	main
mul	doc_491521501783_item	3265963	et	3	main
üheksandal	doc_491521501783_item	3265969	et	3	main
vale	doc_491521501783_item	3265980	et	4	main
see	doc_491521501783_item	3265983	et	3	main
on	doc_491521501783_item	3265984	et	4	main
seotud	doc_491521501783_item	3265985	et	4	main
emakeele	doc_491521501783_item	3265986	et	4	main
mõjuga	doc_491521501783_item	3265987	et	3	main
ma	doc_491521501783_item	3265988	et	3	main
valisin	doc_491521501783_item	3265989	et	3	main
seda	doc_491521501783_item	3265990	et	3	main
teemat	doc_491521501783_item	3265991	et	3	main
sest	doc_491521501783_item	3265992	et	4	main
selle	doc_491521501783_item	3265993	et	4	main
teema	doc_491521501783_item	3265994	et	4	main
ta	doc_491521501783_item	3265995	et	4	main
võttis	doc_491521501783_item	3265996	et	3	main
kaasa	doc_491521501783_item	3265997	et	4	main
oma	doc_491521501783_item	3265998	et	4	main
noort	doc_491521501783_item	3265999	et	3	main
naist	doc_491521501783_item	3266000	et	3	main
noore	doc_491521501783_item	3266001	et	3	main
naise	doc_491521501783_item	3266002	et	3	main
pane	doc_491521501783_item	3266003	et	4	main
aknat	doc_491521501783_item	3266004	et	4	main
kinni	doc_491521501783_item	3266005	et	3	main
aken	doc_491521501783_item	3266006	et	3	main
kohakäänete	doc_491521501783_item	3266007	et	3	main
vead	doc_491521501783_item	3266008	et	4	main
selliste	doc_491521501783_item	3266009	et	4	main
vigade	doc_491521501783_item	3266010	et	3	main
puhul	doc_491521501783_item	3266011	et	4	main
võib	doc_491521501783_item	3266012	et	3	main
väita	doc_491521501783_item	3266013	et	4	main
et	doc_491521501783_item	3266014	et	3	main
need	doc_491521501783_item	3266015	et	3	main
on	doc_491521501783_item	3266016	et	4	main
seotud	doc_491521501783_item	3266017	et	4	main
emakeele	doc_491521501783_item	3266018	et	4	main
vormide	doc_491521501783_item	3265979	et	3	main
mõjuga	doc_491521501783_item	3266019	et	3	main
eesti	doc_491521501783_item	3266020	et	4	main
kasutamisel	doc_491521501783_item	3266027	et	4	main
eesti	doc_491521501783_item	3266035	et	4	main
keeles	doc_491521501783_item	3266036	et	4	main
aga	doc_491521501783_item	3266037	et	3	main
kursustele	doc_491521501783_item	3266042	et	3	main
olemas	doc_491521501783_item	3266058	et	4	main
kuid	doc_491521501783_item	3266062	et	4	main
kõikides	doc_491521501783_item	3266064	et	4	main
sõnades	doc_491521501783_item	3266065	et	4	main
kasutamisel	doc_491521501783_item	3266086	et	4	main
peatusi	doc_491521501783_item	3266090	et	4	main
peres	doc_491521501783_item	3266092	et	3	main
on	doc_491521501783_item	3266093	et	4	main
neli	doc_491521501783_item	3266094	et	3	main
perekonnaliikmeid	doc_491521501783_item	3266095	et	3	main
ta	doc_491521501783_item	3266096	et	4	main
tahab	doc_491521501783_item	3266097	et	3	main
küsida	doc_491521501783_item	3266098	et	3	main
arvamust	doc_491521501783_item	3266099	et	3	main
head	doc_491521501783_item	3266102	et	4	main
häid	doc_491521501783_item	3266105	et	3	main
kaasa	doc_491521501783_item	3266131	et	4	main
käänamine	doc_491521501783_item	3266142	et	4	main
ja	doc_491521501783_item	3266143	et	3	main
kasutamine	doc_491521501783_item	3266144	et	4	main
siin	doc_491521501783_item	3266145	et	4	main
esineb	doc_491521501783_item	3266146	et	3	main
kuna	doc_491521501783_item	3266149	et	3	main
käänata	doc_491521501783_item	3266153	et	4	main
õigesti	doc_491521501783_item	3266154	et	3	main
arvsõnu	doc_491521501783_item	3266155	et	3	main
seepärast	doc_491521501783_item	3266156	et	3	main
seda	doc_491521501783_item	3266157	et	3	main
tuleb	doc_491521501783_item	3266158	et	3	main
võimalikult	doc_491521501783_item	3266159	et	4	main
olen	doc_491521501783_item	3266169	et	3	main
on	doc_491521501783_item	3266172	et	4	main
viisteiskümnes	doc_491521501783_item	3266173	et	4	main
jaanuar	doc_491521501783_item	3266174	et	3	main
põõrama	doc_491521501783_item	3266180	et	4	main
üks	doc_491521501783_item	3266184	et	3	main
käändes	doc_491521501783_item	3266188	et	3	main
osastavas	doc_491521501783_item	3266191	et	4	main
käändes	doc_491521501783_item	3266192	et	3	main
ja	doc_491521501783_item	3266198	et	3	main
olen	doc_491521501783_item	3266201	et	3	main
mõnikord	doc_491521501783_item	3266225	et	3	main
sellised	doc_491521501783_item	3266227	et	4	main
on	doc_491521501783_item	3266237	et	4	main
ilusaim	doc_491521501783_item	3266239	et	4	main
ilusam	doc_491521501783_item	3266240	et	4	main
nt	doc_491521501783_item	3266247	et	4	main
on	doc_491521501783_item	3266254	et	4	main
nt	doc_491521501783_item	3266265	et	4	main
hapnim	doc_491521501783_item	3266266	et	4	main
see	doc_491521501783_item	3266267	et	3	main
verbivormide	doc_491521501783_item	3266273	et	4	main
astmevahelduseta	doc_491521501783_item	3266278	et	4	main
verbi	doc_491521501783_item	3266287	et	4	main
koolis	doc_491521501783_item	3266300	et	4	main
õpib	doc_491521501783_item	3266301	et	3	main
vene	doc_491521501783_item	3266304	et	4	main
da	doc_491521501783_item	3266321	et	4	main
endale	doc_491521501783_item	3266344	et	4	main
säilinud	doc_491521501783_item	3266353	et	4	main
sel	doc_491521501783_item	3266357	et	3	main
sõna	doc_491521501783_item	3266360	et	4	main
olla	doc_491521501783_item	3266366	et	3	main
või	doc_491521501783_item	3266369	et	4	main
aga	doc_491521501783_item	3266371	et	3	main
mitte	doc_491521501783_item	3266372	et	3	main
töötada	doc_491521501783_item	3266387	et	3	main
infinitiivi	doc_491521501783_item	3266392	et	4	main
vene	doc_491521501783_item	3266029	et	4	main
kursustel	doc_491521501783_item	3266043	et	3	main
nad	doc_491521501783_item	3266044	et	3	main
ekskursioonidel	doc_491521501783_item	3266049	et	3	main
keeles	doc_491521501783_item	3266054	et	4	main
mis	doc_491521501783_item	3266066	et	4	main
tekitabki	doc_491521501783_item	3266067	et	3	main
probleeme	doc_491521501783_item	3266068	et	3	main
käände	doc_491521501783_item	3266085	et	4	main
ja	doc_491521501783_item	3266100	et	3	main
arvamusi	doc_491521501783_item	3266104	et	3	main
tihti	doc_491521501783_item	3266107	et	3	main
unustatakse	doc_491521501783_item	3266108	et	3	main
ära	doc_491521501783_item	3266109	et	4	main
ni-na-ta-ga	doc_491521501783_item	3266110	et	3	main
reegel	doc_491521501783_item	3266111	et	3	main
ma	doc_491521501783_item	3266112	et	3	main
sõidan	doc_491521501783_item	3266113	et	3	main
kooli	doc_491521501783_item	3266114	et	4	main
trammiga	doc_491521501783_item	3266115	et	3	main
ja	doc_491521501783_item	3266116	et	3	main
bussiga	doc_491521501783_item	3266117	et	3	main
vead	doc_491521501783_item	3266118	et	4	main
tekkivad	doc_491521501783_item	3266119	et	4	main
ka	doc_491521501783_item	3266120	et	3	main
siis	doc_491521501783_item	3266121	et	3	main
kui	doc_491521501783_item	3266122	et	3	main
õpilased	doc_491521501783_item	3266123	et	3	main
ei	doc_491521501783_item	3266124	et	4	main
sõnadele	doc_491521501783_item	3266126	et	3	main
küsimusi	doc_491521501783_item	3266127	et	4	main
nt	doc_491521501783_item	3266128	et	4	main
võttis	doc_491521501783_item	3266129	et	3	main
kuhu	doc_491521501783_item	3266130	et	3	main
kuhu	doc_491521501783_item	3266138	et	3	main
ülesse	doc_491521501783_item	3266140	et	4	main
arvsõna	doc_491521501783_item	3266141	et	4	main
rohkem	doc_491521501783_item	3266160	et	4	main
elan	doc_491521501783_item	3266165	et	3	main
üheksasal	doc_491521501783_item	3266166	et	3	main
õpetaja	doc_491521501783_item	3266176	et	4	main
on	doc_491521501783_item	3266186	et	4	main
teine	doc_491521501783_item	3266190	et	3	main
ka	doc_491521501783_item	3266193	et	3	main
palju	doc_491521501783_item	3266206	et	4	main
õppur	doc_491521501783_item	3266230	et	3	main
ja	doc_491521501783_item	3266236	et	3	main
kõige	doc_491521501783_item	3266238	et	4	main
kus	doc_491521501783_item	3266244	et	3	main
tüvi	doc_491521501783_item	3266246	et	3	main
soe	doc_491521501783_item	3266248	et	4	main
seal	doc_491521501783_item	3266253	et	4	main
soojam	doc_491521501783_item	3266255	et	4	main
teha	doc_491521501783_item	3266264	et	3	main
on	doc_491521501783_item	3266277	et	4	main
teki	doc_491521501783_item	3266282	et	4	main
on	doc_491521501783_item	3266285	et	4	main
pöörata	doc_491521501783_item	3266288	et	4	main
puhul	doc_491521501783_item	3266290	et	4	main
õppib	doc_491521501783_item	3266299	et	4	main
tõlkin	doc_491521501783_item	3266303	et	4	main
minen	doc_491521501783_item	3266312	et	4	main
keeles	doc_491521501783_item	3266338	et	4	main
on	doc_491521501783_item	3266339	et	4	main
da	doc_491521501783_item	3266345	et	4	main
mitte	doc_491521501783_item	3266132	et	3	main
panin	doc_491521501783_item	3266135	et	3	main
üleval	doc_491521501783_item	3266137	et	4	main
ülevale	doc_491521501783_item	3266139	et	3	main
palju	doc_491521501783_item	3266147	et	4	main
vigu	doc_491521501783_item	3266148	et	3	main
ma	doc_491521501783_item	3266164	et	3	main
ma	doc_491521501783_item	3266168	et	3	main
täna	doc_491521501783_item	3266171	et	4	main
ühildumisvead	doc_491521501783_item	3266175	et	4	main
tähelepanu	doc_491521501783_item	3266179	et	4	main
et	doc_491521501783_item	3266182	et	3	main
sõna	doc_491521501783_item	3266185	et	4	main
vabaduse	doc_491521501783_item	3266197	et	4	main
tige	doc_491521501783_item	3266207	et	3	main
inimesi	doc_491521501783_item	3266208	et	4	main
tal	doc_491521501783_item	3266209	et	3	main
segab	doc_491521501783_item	3266210	et	3	main
materiaalne	doc_491521501783_item	3266211	et	3	main
võimaluse	doc_491521501783_item	3266212	et	3	main
puudus	doc_491521501783_item	3266213	et	4	main
nad	doc_491521501783_item	3266214	et	3	main
küsivad	doc_491521501783_item	3266215	et	4	main
palju	doc_491521501783_item	3266216	et	4	main
küsimusi	doc_491521501783_item	3266217	et	4	main
tihti	doc_491521501783_item	3266218	et	3	main
isegi	doc_491521501783_item	3266219	et	4	main
meie	doc_491521501783_item	3266220	et	4	main
jaoks	doc_491521501783_item	3266221	et	4	main
rumalad	doc_491521501783_item	3266222	et	3	main
omadussõna	doc_491521501783_item	3266223	et	4	main
võrdlusastmed	doc_491521501783_item	3266224	et	3	main
peaks	doc_491521501783_item	3266177	et	4	main
õpilaste	doc_491521501783_item	3266178	et	4	main
sellele	doc_491521501783_item	3266181	et	4	main
kui	doc_491521501783_item	3266183	et	3	main
osastavas	doc_491521501783_item	3266187	et	4	main
siis	doc_491521501783_item	3266189	et	3	main
jms	doc_491521501783_item	3266194	et	4	main
eesti	doc_491521501783_item	3266195	et	4	main
iseseisvust	doc_491521501783_item	3266199	et	4	main
tulevad	doc_491521501783_item	3266226	et	4	main
vead	doc_491521501783_item	3266228	et	4	main
raskused	doc_491521501783_item	3266241	et	4	main
lähme	doc_491521501783_item	3266251	et	3	main
koju	doc_491521501783_item	3266252	et	3	main
on	doc_491521501783_item	3266268	et	4	main
moodustusvead	doc_491521501783_item	3266274	et	4	main
kui	doc_491521501783_item	3266275	et	3	main
verb	doc_491521501783_item	3266276	et	3	main
vaja	doc_491521501783_item	3266286	et	4	main
ta	doc_491521501783_item	3266298	et	4	main
muutuda	doc_491521501783_item	3266310	et	3	main
koju	doc_491521501783_item	3266313	et	3	main
verbivormide	doc_491521501783_item	3266315	et	4	main
puhul	doc_491521501783_item	3266323	et	4	main
ilmnenud	doc_491521501783_item	3266324	et	4	main
vead	doc_491521501783_item	3266325	et	4	main
on	doc_491521501783_item	3266327	et	4	main
nad	doc_491521501783_item	3266326	et	3	main
harjunud	doc_491521501783_item	3266328	et	4	main
töötama	doc_491521501783_item	3266329	et	3	main
töötada	doc_491521501783_item	3266330	et	3	main
lugemise	doc_491521501783_item	3266331	et	4	main
ajal	doc_491521501783_item	3266332	et	4	main
pidin	doc_491521501783_item	3266333	et	3	main
lugema	doc_491521501783_item	3266334	et	4	main
ja	doc_491521501783_item	3266335	et	3	main
teatud	doc_491521501783_item	3266340	et	4	main
verbid	doc_491521501783_item	3266341	et	3	main
infinitiivi	doc_491521501783_item	3266346	et	4	main
paneb	doc_491521501783_item	3266231	et	3	main
ja	doc_491521501783_item	3266233	et	3	main
kokku	doc_491521501783_item	3266235	et	3	main
muutub	doc_491521501783_item	3266245	et	3	main
sooja	doc_491521501783_item	3266249	et	4	main
samuti	doc_491521501783_item	3266256	et	3	main
moodustatakse	doc_491521501783_item	3266257	et	3	main
i-ülivõr	doc_491521501783_item	3266258	et	4	main
seal	doc_491521501783_item	3266259	et	4	main
kus	doc_491521501783_item	3266260	et	3	main
seda	doc_491521501783_item	3266261	et	3	main
ei	doc_491521501783_item	3266262	et	4	main
tohi	doc_491521501783_item	3266263	et	4	main
sõnadega	doc_491521501783_item	3266243	et	3	main
soojem	doc_491521501783_item	3266250	et	3	main
kõige	doc_491521501783_item	3266271	et	4	main
hapum	doc_491521501783_item	3266272	et	4	main
tavaliselt	doc_491521501783_item	3266280	et	4	main
ei	doc_491521501783_item	3266281	et	4	main
kahtlusi	doc_491521501783_item	3266283	et	4	main
kuidas	doc_491521501783_item	3266284	et	3	main
astmevahelduse	doc_491521501783_item	3266289	et	4	main
tekkivad	doc_491521501783_item	3266291	et	4	main
juba	doc_491521501783_item	3266292	et	3	main
probleemid	doc_491521501783_item	3266293	et	3	main
ma	doc_491521501783_item	3266294	et	3	main
tahan	doc_491521501783_item	3266295	et	3	main
õmbleda	doc_491521501783_item	3266296	et	4	main
ma	doc_491521501783_item	3266311	et	3	main
lähen	doc_491521501783_item	3266314	et	3	main
valikuvead	doc_491521501783_item	3266316	et	3	main
tavaliselt	doc_491521501783_item	3266317	et	4	main
need	doc_491521501783_item	3266318	et	3	main
on	doc_491521501783_item	3266319	et	4	main
ma	doc_491521501783_item	3266320	et	3	main
proovida	doc_491521501783_item	3266336	et	3	main
eesti	doc_491521501783_item	3266337	et	4	main
nt	doc_491521501783_item	3266347	et	4	main
vaja	doc_491521501783_item	3266350	et	4	main
alles	doc_491521501783_item	3266355	et	3	main
võib	doc_491521501783_item	3266365	et	3	main
kooli	doc_491521501783_item	3266378	et	4	main
harjunud	doc_491521501783_item	3266386	et	4	main
hapnim	doc_491521501783_item	3266269	et	4	main
õun	doc_491521501783_item	3266270	et	3	main
siis	doc_491521501783_item	3266279	et	3	main
õmmelda	doc_491521501783_item	3266297	et	4	main
mina	doc_491521501783_item	3266302	et	4	main
keelde	doc_491521501783_item	3266305	et	4	main
tõlgin	doc_491521501783_item	3266306	et	3	main
sõna	doc_491521501783_item	3266307	et	4	main
võib	doc_491521501783_item	3266308	et	3	main
üldse	doc_491521501783_item	3266309	et	3	main
infinitiivi	doc_491521501783_item	3266322	et	4	main
mis	doc_491521501783_item	3266342	et	4	main
nõuavad	doc_491521501783_item	3266343	et	4	main
tahan	doc_491521501783_item	3266348	et	3	main
jne	doc_491521501783_item	3266351	et	4	main
veaanalüüs	doc_491521501783_item	3266352	et	4	main
jäänud	doc_491521501783_item	3266356	et	4	main
sellist	doc_491521501783_item	3266359	et	4	main
kas	doc_491521501783_item	3266367	et	3	main
sai	doc_491521501783_item	3266370	et	4	main
nimetus	doc_491521501783_item	3266379	et	4	main
seepärast	doc_491521501783_item	3266380	et	3	main
kirjutatakse	doc_491521501783_item	3266381	et	3	main
lahku	doc_491521501783_item	3266382	et	4	main
1	doc_491521501783_item	3266388	et	2	main
da	doc_491521501783_item	3266391	et	4	main
on	doc_491521501783_item	3266349	et	4	main
juhul	doc_491521501783_item	3266358	et	3	main
ei	doc_491521501783_item	3266361	et	4	main
tohi	doc_491521501783_item	3266362	et	4	main
kasutada	doc_491521501783_item	3266363	et	3	main
piim	doc_491521501783_item	3266368	et	3	main
kesklinna	doc_491521501783_item	3266374	et	4	main
gümnaasium	doc_491521501783_item	3266375	et	3	main
see	doc_491521501783_item	3266376	et	3	main
on	doc_491521501783_item	3266377	et	4	main
av	doc_491521501783_item	3266384	et	4	main
sõna	doc_491521501783_item	3266385	et	4	main
verb	doc_491521501783_item	3266389	et	3	main
kontrolltööd	doc_491521501783_item	3266354	et	4	main
säilinud	doc_491521501783_item	3266364	et	4	main
kontrolltööd	doc_491521501783_item	3266373	et	4	main
kipuvad	doc_491521501783_item	3266383	et	3	main
nõuab	doc_491521501783_item	3266390	et	3	main
lugege	doc_491521501675_item	3315030	et	3	main
teksti	doc_491521501675_item	3315032	et	4	main
vastus	doc_491521501675_item	3315035	et	3	main
head	doc_491521501675_item	3315039	et	4	main
puhkust	doc_491521501675_item	3315040	et	4	main
head	doc_491521501675_item	3315066	et	4	main
oma	doc_491521501675_item	3315072	et	4	main
suur	doc_491521501675_item	3315075	et	3	main
aed	doc_491521501675_item	3315076	et	3	main
minu	doc_491521501675_item	3315077	et	3	main
lapsed	doc_491521501675_item	3315078	et	3	main
elavad	doc_491521501675_item	3315079	et	4	main
ka	doc_491521501675_item	3315080	et	3	main
hästi	doc_491521501675_item	3315081	et	3	main
tulen	doc_491521501675_item	3315093	et	3	main
kõik	doc_491521501675_item	3315098	et	4	main
kõige	doc_491521501675_item	3315065	et	4	main
poisid	doc_491521501675_item	3315082	et	4	main
kodus	doc_491521501675_item	3315086	et	4	main
tal	doc_491521501675_item	3315087	et	3	main
on	doc_491521501675_item	3315088	et	4	main
väike	doc_491521501675_item	3315089	et	4	main
ma	doc_491521501675_item	3315092	et	3	main
ja	doc_491521501675_item	3315096	et	3	main
kiri	doc_285078626585_item	3315258	et	3	main
inimeste	doc_285078626585_item	3315271	et	3	main
on	doc_285078626585_item	3315274	et	4	main
isiklik	doc_285078626585_item	3315275	et	3	main
kuikeegi	doc_285078626585_item	3315280	et	2	main
vaatan	doc_285078626585_item	3315295	et	3	main
mängis	doc_285078626585_item	3315298	et	3	main
seeinimene	doc_285078626585_item	3315302	et	2	main
üldse	doc_285078626585_item	3315304	et	3	main
olin	doc_285078626585_item	3315336	et	3	main
kõik	doc_285078626585_item	3315339	et	4	main
järgmist	doc_491521501675_item	3315031	et	3	main
20-25	doc_491521501675_item	3315057	et	2	main
minu	doc_491521501675_item	3315060	et	3	main
mina	doc_491521501675_item	3315067	et	4	main
hästi	doc_491521501675_item	3315069	et	3	main
sulle	doc_491521501675_item	3315094	et	3	main
kiri	doc_491521501675_item	3315029	et	3	main
tere	doc_491521501675_item	3315036	et	3	main
sõnaga	doc_491521501675_item	3315058	et	3	main
armas	doc_491521501675_item	3315061	et	3	main
sulle	doc_491521501675_item	3315064	et	3	main
elan	doc_491521501675_item	3315068	et	3	main
on	doc_491521501675_item	3315071	et	4	main
maja	doc_491521501675_item	3315073	et	4	main
ja	doc_491521501675_item	3315074	et	3	main
töötavad	doc_491521501675_item	3315083	et	4	main
tütar	doc_491521501675_item	3315084	et	3	main
istub	doc_491521501675_item	3315085	et	3	main
ja	doc_491521501675_item	3315033	et	3	main
kirjutage	doc_491521501675_item	3315034	et	3	main
soovin	doc_491521501675_item	3315037	et	3	main
sulle	doc_491521501675_item	3315038	et	3	main
ootan	doc_491521501675_item	3315041	et	3	main
sind	doc_491521501675_item	3315042	et	4	main
endale	doc_491521501675_item	3315043	et	4	main
külla	doc_491521501675_item	3315044	et	4	main
kirjuta	doc_491521501675_item	3315045	et	4	main
mida	doc_491521501675_item	3315046	et	4	main
teed	doc_491521501675_item	3315047	et	4	main
kuidas	doc_491521501675_item	3315048	et	3	main
lapsed	doc_491521501675_item	3315049	et	3	main
elavad	doc_491521501675_item	3315050	et	4	main
ja	doc_491521501675_item	3315051	et	3	main
millal	doc_491521501675_item	3315052	et	3	main
sõidad	doc_491521501675_item	3315053	et	3	main
venemaale	doc_491521501675_item	3315054	et	4	main
kirjutage	doc_491521501675_item	3315055	et	3	main
vastus	doc_491521501675_item	3315056	et	3	main
tere	doc_491521501675_item	3315059	et	3	main
sõbranna	doc_491521501675_item	3315062	et	4	main
soovin	doc_491521501675_item	3315063	et	3	main
mul	doc_491521501675_item	3315070	et	3	main
poeg	doc_491521501675_item	3315090	et	3	main
septembris	doc_491521501675_item	3315091	et	3	main
külla	doc_491521501675_item	3315095	et	4	main
rägin	doc_491521501675_item	3315097	et	3	main
on	doc_285078626585_item	3315260	et	4	main
sellest	doc_285078626585_item	3315266	et	4	main
mul	doc_285078626585_item	3315273	et	3	main
kontrabass	doc_285078626585_item	3315276	et	3	main
tahab	doc_285078626585_item	3315281	et	3	main
käest	doc_285078626585_item	3315286	et	4	main
jalle	doc_285078626585_item	3315294	et	4	main
ja	doc_285078626585_item	3315300	et	3	main
koolis	doc_285078626585_item	3315335	et	4	main
aru	doc_285078626585_item	3315348	et	4	main
kui	doc_285078626585_item	3315356	et	3	main
omaasjad	doc_285078626585_item	3315358	et	2	main
ei	doc_285078626585_item	3315362	et	4	main
võtta	doc_285078626585_item	3315363	et	3	main
minu	doc_285078626585_item	3315380	et	3	main
201	doc_285078626585_item	3315384	et	2	main
palun	doc_285078626585_item	3315390	et	3	main
normalsed	doc_285078626585_item	3315392	et	4	main
mõtlema	doc_285078626585_item	3315395	et	3	main
mitte	doc_285078626585_item	3315396	et	3	main
saadav	doc_285078626585_item	3315407	et	4	main
kõigele	doc_285078626585_item	3315408	et	4	main
et	doc_285078626585_item	3315267	et	3	main
ära	doc_285078626585_item	3315269	et	4	main
see	doc_285078626585_item	3315278	et	3	main
küsib	doc_285078626585_item	3315284	et	3	main
või	doc_285078626585_item	3315287	et	4	main
paremkui	doc_285078626585_item	3315290	et	2	main
üldse	doc_285078626585_item	3315291	et	3	main
ei	doc_285078626585_item	3315292	et	4	main
võtta	doc_285078626585_item	3315293	et	3	main
kegi	doc_285078626585_item	3315297	et	4	main
poognega	doc_285078626585_item	3315299	et	4	main
kes	doc_285078626585_item	3315303	et	4	main
kolmpäeva	doc_285078626585_item	3315332	et	2	main
haige	doc_285078626585_item	3315337	et	4	main
asjad	doc_285078626585_item	3315340	et	3	main
on	doc_285078626585_item	3315341	et	4	main
laiali	doc_285078626585_item	3315342	et	3	main
ja	doc_285078626585_item	3315343	et	3	main
olidkasutusel	doc_285078626585_item	3315344	et	2	main
ma	doc_285078626585_item	3315345	et	3	main
aru	doc_285078626585_item	3315353	et	4	main
saata	doc_285078626585_item	3315354	et	3	main
mul	doc_285078626585_item	3315259	et	3	main
väga	doc_285078626585_item	3315261	et	3	main
kurb	doc_285078626585_item	3315262	et	3	main
mitmes	doc_285078626585_item	3315264	et	4	main
kord	doc_285078626585_item	3315265	et	4	main
ja	doc_285078626585_item	3315277	et	3	main
seda	doc_285078626585_item	3315282	et	3	main
et	doc_285078626585_item	3315296	et	3	main
ei	doc_285078626585_item	3315305	et	4	main
tea	doc_285078626585_item	3315306	et	4	main
kuidas	doc_285078626585_item	3315307	et	3	main
see	doc_285078626585_item	3315308	et	3	main
tehakse	doc_285078626585_item	3315309	et	3	main
ma	doc_285078626585_item	3315310	et	3	main
pean	doc_285078626585_item	3315311	et	4	main
peale	doc_285078626585_item	3315312	et	4	main
teie	doc_285078626585_item	3315313	et	4	main
mängupool	doc_285078626585_item	3315314	et	2	main
päeva	doc_285078626585_item	3315315	et	4	main
puhastama	doc_285078626585_item	3315316	et	3	main
pilli	doc_285078626585_item	3315317	et	4	main
suur	doc_285078626585_item	3315318	et	3	main
palve	doc_285078626585_item	3315319	et	4	main
kegi	doc_285078626585_item	3315320	et	4	main
võtta	doc_285078626585_item	3315322	et	3	main
ei	doc_285078626585_item	3315321	et	4	main
minukontrabassi	doc_285078626585_item	3315323	et	2	main
ei	doc_285078626585_item	3315324	et	4	main
mängi	doc_285078626585_item	3315325	et	4	main
ei	doc_285078626585_item	3315326	et	4	main
proovi	doc_285078626585_item	3315327	et	4	main
ja	doc_285078626585_item	3315328	et	3	main
saama	doc_285078626585_item	3315329	et	4	main
lugu	doc_285078626585_item	3315330	et	4	main
bassivõimuga	doc_285078626585_item	3315331	et	3	main
räkkida	doc_285078626585_item	3315263	et	4	main
palun	doc_285078626585_item	3315268	et	3	main
võtketeiste	doc_285078626585_item	3315270	et	2	main
pillid	doc_285078626585_item	3315272	et	4	main
tähendab	doc_285078626585_item	3315279	et	3	main
mängida	doc_285078626585_item	3315283	et	3	main
minu	doc_285078626585_item	3315285	et	3	main
helistab	doc_285078626585_item	3315288	et	3	main
aga	doc_285078626585_item	3315289	et	3	main
just	doc_285078626585_item	3315301	et	3	main
ei	doc_285078626585_item	3315333	et	4	main
ei	doc_285078626585_item	3315346	et	4	main
raske	doc_285078626585_item	3315352	et	4	main
on	doc_285078626585_item	3315357	et	4	main
siis	doc_285078626585_item	3315359	et	3	main
olemas	doc_285078626585_item	3315375	et	4	main
kaks	doc_285078626585_item	3315376	et	3	main
asjad	doc_285078626585_item	3315381	et	3	main
et	doc_285078626585_item	3315399	et	3	main
filoloogia	doc_285078626585_item	3315402	et	4	main
kirjas	doc_285078626585_item	3315404	et	4	main
on	doc_285078626585_item	3315405	et	4	main
olnud	doc_285078626585_item	3315334	et	4	main
ja	doc_285078626585_item	3315338	et	3	main
saa	doc_285078626585_item	3315347	et	4	main
et	doc_285078626585_item	3315355	et	3	main
seda	doc_285078626585_item	3315361	et	3	main
kui	doc_285078626585_item	3315365	et	3	main
küsime	doc_285078626585_item	3315366	et	3	main
aga	doc_285078626585_item	3315367	et	3	main
kasutame	doc_285078626585_item	3315368	et	3	main
kontrabassi	doc_285078626585_item	3315377	et	4	main
seisavad	doc_285078626585_item	3315382	et	3	main
minu	doc_285078626585_item	3315400	et	3	main
aru	doc_285078626585_item	3315406	et	4	main
kas	doc_285078626585_item	3315349	et	3	main
on	doc_285078626585_item	3315350	et	4	main
nii	doc_285078626585_item	3315351	et	3	main
on	doc_285078626585_item	3315373	et	4	main
praegu	doc_285078626585_item	3315374	et	3	main
kaksbassivõimu	doc_285078626585_item	3315379	et	2	main
klassis	doc_285078626585_item	3315385	et	3	main
nad	doc_285078626585_item	3315387	et	3	main
üldse	doc_285078626585_item	3315389	et	3	main
oleme	doc_285078626585_item	3315391	et	3	main
hakkame	doc_285078626585_item	3315394	et	3	main
loodan	doc_285078626585_item	3315398	et	3	main
isiklik	doc_285078626585_item	3315401	et	3	main
siin	doc_285078626585_item	3315403	et	4	main
me	doc_285078626585_item	3315360	et	4	main
ennem	doc_285078626585_item	3315364	et	4	main
koolipillid	doc_285078626585_item	3315369	et	2	main
ja	doc_285078626585_item	3315370	et	3	main
võimud	doc_285078626585_item	3315371	et	3	main
koolis	doc_285078626585_item	3315372	et	4	main
ja	doc_285078626585_item	3315378	et	3	main
korralikult	doc_285078626585_item	3315383	et	4	main
nurgas	doc_285078626585_item	3315386	et	3	main
eiseega	doc_285078626585_item	3315388	et	2	main
ja	doc_285078626585_item	3315393	et	3	main
ainultennast	doc_285078626585_item	3315397	et	2	main
küsimused	doc_285078626585_item	3315409	et	4	main
on	doc_285078626585_item	3315410	et	4	main
tere	doc_285078626585_item	3315411	et	3	main
tulnud	doc_285078626585_item	3315412	et	4	main
kõike	doc_285078626585_item	3315413	et	4	main
head	doc_285078626585_item	3315414	et	4	main
eesnimi	doc_285078626585_item	3315415	et	3	main
perekonnanimi	doc_285078626585_item	3315416	et	3	main
et	doc_491521501702_item	3321733	et	3	main
saa	doc_491521501702_item	3321734	et	4	main
praktikale	doc_491521501702_item	3321740	et	3	main
kirjuta	doc_491521501702_item	3321741	et	4	main
kuidas	doc_491521501702_item	3321742	et	3	main
sul	doc_491521501702_item	3321743	et	3	main
kursustel	doc_491521501702_item	3321744	et	3	main
läks	doc_491521501702_item	3321745	et	3	main
tegeleb	doc_491521501702_item	3321757	et	3	main
seal	doc_491521501702_item	3321761	et	4	main
tegema	doc_491521501702_item	3321762	et	3	main
hakkad	doc_491521501702_item	3321763	et	3	main
tere	doc_491521501702_item	3321764	et	3	main
anne	doc_491521501702_item	3321765	et	4	main
ma	doc_491521501702_item	3321766	et	3	main
sain	doc_491521501702_item	3321767	et	3	main
sinu	doc_491521501702_item	3321768	et	3	main
sulle	doc_491521501702_item	3321772	et	3	main
mulle	doc_491521501702_item	3321775	et	4	main
kuidas	doc_491521501702_item	3321784	et	3	main
huvitav	doc_491521501702_item	3321792	et	4	main
uudis	doc_491521501702_item	3321793	et	3	main
keel	doc_491521501702_item	3321812	et	4	main
ettevõtluse	doc_491521501702_item	3321813	et	3	main
alused	doc_491521501702_item	3321814	et	4	main
huvitav	doc_491521501702_item	3321822	et	4	main
kõige	doc_491521501702_item	3321823	et	4	main
oma	doc_491521501702_item	3321730	et	4	main
sõbrale	doc_491521501702_item	3321732	et	3	main
mida	doc_491521501702_item	3321759	et	4	main
kätte	doc_491521501702_item	3321770	et	4	main
eest	doc_491521501702_item	3321774	et	4	main
oli	doc_491521501702_item	3321776	et	3	main
väga	doc_491521501702_item	3321777	et	3	main
huvitav	doc_491521501702_item	3321778	et	4	main
mul	doc_491521501702_item	3321779	et	3	main
tahan	doc_491521501702_item	3321789	et	3	main
käisin	doc_491521501702_item	3321795	et	3	main
asjaajamine	doc_491521501702_item	3321803	et	4	main
arvutiõpetus	doc_491521501702_item	3321804	et	3	main
alused	doc_491521501702_item	3321809	et	4	main
eesti	doc_491521501702_item	3321811	et	4	main
on	doc_491521501702_item	3321831	et	4	main
minu	doc_491521501702_item	3321832	et	3	main
meid	doc_491521501702_item	3321837	et	4	main
video	doc_491521501702_item	3321840	et	4	main
loodusest	doc_491521501702_item	3321842	et	4	main
rääkis	doc_491521501702_item	3321843	et	3	main
mida	doc_491521501702_item	3321746	et	4	main
sa	doc_491521501702_item	3321747	et	3	main
see	doc_491521501702_item	3321755	et	3	main
sa	doc_491521501702_item	3321760	et	3	main
äitah	doc_491521501702_item	3321771	et	4	main
kõik	doc_491521501702_item	3321781	et	4	main
hästi	doc_491521501702_item	3321782	et	3	main
sinul	doc_491521501702_item	3321785	et	3	main
teatada	doc_491521501702_item	3321790	et	3	main
kursusel	doc_491521501702_item	3321796	et	3	main
mulle	doc_491521501702_item	3321798	et	4	main
turunduse	doc_491521501702_item	3321806	et	3	main
alused	doc_491521501702_item	3321807	et	4	main
esmaabi	doc_491521501702_item	3321810	et	4	main
äri-plaan	doc_491521501702_item	3321817	et	3	main
rohkem	doc_491521501702_item	3321824	et	4	main
mulle	doc_491521501702_item	3321825	et	4	main
meeldis	doc_491521501702_item	3321826	et	3	main
keel	doc_491521501702_item	3321834	et	4	main
kirjanikust	doc_491521501702_item	3321847	et	3	main
praktika	doc_491521501702_item	3321850	et	4	main
lähen	doc_491521501702_item	3321852	et	3	main
mööblisalongis	doc_491521501702_item	3321854	et	3	main
järgmist	doc_491521501680_item	3322072	et	3	main
ja	doc_491521501680_item	3322074	et	3	main
kirjutage	doc_491521501680_item	3322075	et	3	main
kuidas	doc_491521501680_item	3322089	et	3	main
elavad	doc_491521501680_item	3322091	et	4	main
tere	doc_491521501680_item	3322100	et	3	main
mulle	doc_491521501680_item	3322106	et	4	main
kõik	doc_491521501680_item	3322109	et	4	main
hästi	doc_491521501680_item	3322110	et	3	main
lapsed	doc_491521501680_item	3322111	et	3	main
on	doc_491521501680_item	3322112	et	4	main
mul	doc_491521501680_item	3322117	et	3	main
puhkusele	doc_491521501680_item	3322125	et	4	main
sõidame	doc_491521501680_item	3322128	et	3	main
venemaale	doc_491521501680_item	3322129	et	4	main
kaheks	doc_491521501680_item	3322130	et	4	main
nädalaks	doc_491521501680_item	3322131	et	3	main
saa	doc_491521501680_item	3322139	et	4	main
kiri	doc_491521501702_item	3321728	et	3	main
firma	doc_491521501702_item	3321756	et	4	main
kirja	doc_491521501702_item	3321773	et	4	main
aga	doc_491521501702_item	3321783	et	3	main
käsi	doc_491521501702_item	3321786	et	4	main
käib	doc_491521501702_item	3321787	et	3	main
ma	doc_491521501702_item	3321788	et	3	main
sulle	doc_491521501702_item	3321791	et	3	main
psühholoogia	doc_491521501702_item	3321805	et	4	main
kõik	doc_491521501702_item	3321818	et	4	main
tunnid	doc_491521501702_item	3321819	et	3	main
on	doc_491521501702_item	3321820	et	4	main
väga	doc_491521501702_item	3321821	et	3	main
eesti	doc_491521501702_item	3321827	et	4	main
keel	doc_491521501702_item	3321828	et	4	main
õpitaja	doc_491521501702_item	3321835	et	4	main
kirjuta	doc_491521501702_item	3321729	et	4	main
eestlasest	doc_491521501702_item	3321731	et	3	main
käid	doc_491521501702_item	3321735	et	3	main
kursustel	doc_491521501702_item	3321736	et	3	main
ja	doc_491521501702_item	3321737	et	3	main
varsti	doc_491521501702_item	3321738	et	3	main
lähed	doc_491521501702_item	3321739	et	3	main
seal	doc_491521501702_item	3321748	et	4	main
õppisid	doc_491521501702_item	3321749	et	4	main
kuhu	doc_491521501702_item	3321750	et	3	main
sa	doc_491521501702_item	3321751	et	3	main
praktikale	doc_491521501702_item	3321752	et	3	main
lähed	doc_491521501702_item	3321753	et	3	main
millega	doc_491521501702_item	3321754	et	3	main
ja	doc_491521501702_item	3321758	et	3	main
kirja	doc_491521501702_item	3321769	et	4	main
on	doc_491521501702_item	3321780	et	4	main
ma	doc_491521501702_item	3321794	et	3	main
müügisekretar	doc_491521501702_item	3321797	et	4	main
oli	doc_491521501702_item	3321799	et	3	main
meeldiv	doc_491521501702_item	3321800	et	4	main
me	doc_491521501702_item	3321801	et	4	main
õppisime	doc_491521501702_item	3321802	et	3	main
tööseadusandluse	doc_491521501702_item	3321808	et	3	main
me	doc_491521501702_item	3321815	et	4	main
kirjutasime	doc_491521501702_item	3321816	et	3	main
nüüd	doc_491521501702_item	3321829	et	4	main
see	doc_491521501702_item	3321830	et	3	main
meeldiv	doc_491521501702_item	3321833	et	4	main
õppitas	doc_491521501702_item	3321836	et	4	main
näitas	doc_491521501702_item	3321839	et	3	main
eesti	doc_491521501702_item	3321841	et	4	main
hakkab	doc_491521501702_item	3321849	et	3	main
ma	doc_491521501702_item	3321851	et	3	main
tere	doc_491521501680_item	3322077	et	3	main
sulle	doc_491521501680_item	3322079	et	3	main
ootan	doc_491521501680_item	3322082	et	3	main
endale	doc_491521501680_item	3322084	et	4	main
lapsed	doc_491521501680_item	3322090	et	3	main
sõidad	doc_491521501680_item	3322094	et	3	main
kirjutage	doc_491521501680_item	3322096	et	3	main
vastus	doc_491521501680_item	3322097	et	3	main
20-25	doc_491521501680_item	3322098	et	2	main
sõnaga	doc_491521501680_item	3322099	et	3	main
terved	doc_491521501680_item	3322113	et	4	main
jäi	doc_491521501680_item	3322118	et	3	main
üks	doc_491521501680_item	3322120	et	3	main
ja	doc_491521501680_item	3322122	et	3	main
lähen	doc_491521501680_item	3322124	et	3	main
kahekümne	doc_491521501680_item	3322126	et	4	main
ei	doc_491521501680_item	3322138	et	4	main
grammatikale	doc_491521501702_item	3321838	et	3	main
eesti	doc_491521501702_item	3321846	et	4	main
meil	doc_491521501702_item	3321848	et	4	main
praktikale	doc_491521501702_item	3321853	et	3	main
siin	doc_491521501702_item	3321855	et	4	main
müüjakse	doc_491521501702_item	3321856	et	4	main
mööblit	doc_491521501702_item	3321857	et	3	main
ja	doc_491521501702_item	3321858	et	3	main
mööblifurnituur	doc_491521501702_item	3321859	et	3	main
ma	doc_491521501702_item	3321860	et	3	main
hakkan	doc_491521501702_item	3321861	et	3	main
müüma	doc_491521501702_item	3321862	et	3	main
rääkima	doc_491521501702_item	3321863	et	3	main
ostjaga	doc_491521501702_item	3321864	et	4	main
ostminest	doc_491521501702_item	3321865	et	4	main
tulle	doc_491521501702_item	3321866	et	4	main
meil	doc_491521501702_item	3321867	et	4	main
kauplus	doc_491521501702_item	3321868	et	3	main
ja	doc_491521501702_item	3321869	et	3	main
me	doc_491521501702_item	3321870	et	4	main
vallime	doc_491521501702_item	3321871	et	4	main
sulle	doc_491521501702_item	3321872	et	3	main
ilus	doc_491521501702_item	3321873	et	4	main
mööbli	doc_491521501702_item	3321874	et	3	main
head	doc_491521501702_item	3321875	et	4	main
aega	doc_491521501702_item	3321876	et	4	main
sinu	doc_491521501702_item	3321877	et	3	main
sõbranna	doc_491521501702_item	3321878	et	4	main
eesti	doc_491521501702_item	3321844	et	4	main
kultuurist	doc_491521501702_item	3321845	et	3	main
lugege	doc_491521501680_item	3322071	et	3	main
teksti	doc_491521501680_item	3322073	et	4	main
puhkust	doc_491521501680_item	3322081	et	4	main
kirjuta	doc_491521501680_item	3322086	et	4	main
läheb	doc_491521501680_item	3322108	et	3	main
hästi	doc_491521501680_item	3322116	et	3	main
mul	doc_491521501680_item	3322132	et	3	main
on	doc_491521501680_item	3322133	et	4	main
väga	doc_491521501680_item	3322134	et	3	main
kahju	doc_491521501680_item	3322135	et	4	main
et	doc_491521501680_item	3322136	et	3	main
aga	doc_491521501680_item	3322142	et	3	main
ma	doc_491521501680_item	3322143	et	3	main
loodan	doc_491521501680_item	3322144	et	3	main
et	doc_491521501680_item	3322145	et	3	main
kiri	doc_491521501680_item	3322070	et	3	main
soovin	doc_491521501680_item	3322078	et	3	main
külla	doc_491521501680_item	3322085	et	4	main
teed	doc_491521501680_item	3322088	et	4	main
ja	doc_491521501680_item	3322092	et	3	main
venemaale	doc_491521501680_item	3322095	et	4	main
kallis	doc_491521501680_item	3322101	et	4	main
sõbranna	doc_491521501680_item	3322102	et	4	main
aitäh	doc_491521501680_item	3322103	et	3	main
et	doc_491521501680_item	3322104	et	3	main
kooli	doc_491521501680_item	3322114	et	4	main
lõpetasid	doc_491521501680_item	3322115	et	4	main
veel	doc_491521501680_item	3322119	et	4	main
nädal	doc_491521501680_item	3322121	et	3	main
siis	doc_491521501680_item	3322123	et	3	main
varem	doc_491521501680_item	3322140	et	4	main
kohtuda	doc_491521501680_item	3322141	et	3	main
läbi	doc_491521502042_item	3322261	et	4	main
tere	doc_491521502042_item	3322272	et	3	main
sa	doc_491521502042_item	3322277	et	3	main
tahad	doc_491521502042_item	3322291	et	3	main
margus	doc_491521502042_item	3322297	et	3	main
ma	doc_491521502042_item	3322300	et	3	main
aega	doc_491521502042_item	3322305	et	4	main
ma	doc_491521502042_item	3322312	et	3	main
külastasin	doc_491521502042_item	3322313	et	3	main
ma	doc_491521502042_item	3322319	et	3	main
suplesin	doc_491521502042_item	3322321	et	3	main
praegu	doc_491521502042_item	3322322	et	3	main
tulen	doc_491521502042_item	3322334	et	3	main
kolme	doc_491521502042_item	3322337	et	4	main
hakkan	doc_491521501680_item	3322152	et	3	main
lõppetama	doc_491521501680_item	3322153	et	3	main
oma	doc_491521501680_item	3322154	et	4	main
kirja	doc_491521501680_item	3322155	et	4	main
ole	doc_491521501680_item	3322156	et	4	main
terve	doc_491521501680_item	3322157	et	4	main
ja	doc_491521501680_item	3322158	et	3	main
kõike	doc_491521501680_item	3322159	et	4	main
head	doc_491521501680_item	3322160	et	4	main
sulle	doc_491521501680_item	3322161	et	3	main
nägemiseni	doc_491521501680_item	3322162	et	4	main
sinu	doc_491521501680_item	3322163	et	3	main
sõbranna	doc_491521501680_item	3322164	et	4	main
vastus	doc_491521501680_item	3322076	et	3	main
head	doc_491521501680_item	3322080	et	4	main
sind	doc_491521501680_item	3322083	et	4	main
mida	doc_491521501680_item	3322087	et	4	main
millal	doc_491521501680_item	3322093	et	3	main
kirjutasid	doc_491521501680_item	3322105	et	4	main
mel	doc_491521501680_item	3322107	et	4	main
viiendal	doc_491521501680_item	3322127	et	3	main
me	doc_491521501680_item	3322137	et	4	main
peale	doc_491521501680_item	3322146	et	4	main
minu	doc_491521501680_item	3322147	et	3	main
reisimist	doc_491521501680_item	3322148	et	4	main
kohtume	doc_491521501680_item	3322150	et	3	main
ikka	doc_491521501680_item	3322149	et	4	main
nüüd	doc_491521501680_item	3322151	et	4	main
kiri	doc_491521502042_item	3322259	et	3	main
ja	doc_491521502042_item	3322264	et	3	main
mulle	doc_491521502042_item	3322275	et	4	main
päeva	doc_491521502042_item	3322281	et	4	main
sa	doc_491521502042_item	3322282	et	3	main
minu	doc_491521502042_item	3322283	et	3	main
juures	doc_491521502042_item	3322284	et	4	main
oled	doc_491521502042_item	3322285	et	3	main
ja	doc_491521502042_item	3322286	et	3	main
kuhu	doc_491521502042_item	3322287	et	3	main
sa	doc_491521502042_item	3322288	et	3	main
vastust	doc_491521502042_item	3322293	et	4	main
onu	doc_491521502042_item	3322314	et	4	main
elab	doc_491521502042_item	3322316	et	3	main
mere	doc_491521502042_item	3322317	et	3	main
tema	doc_491521502042_item	3322331	et	4	main
kiri	doc_491521502042_item	3322263	et	3	main
20-25	doc_491521502042_item	3322270	et	2	main
sõna	doc_491521502042_item	3322271	et	4	main
tallinnasse	doc_491521502042_item	3322278	et	3	main
mitu	doc_491521502042_item	3322280	et	4	main
jään	doc_491521502042_item	3322292	et	3	main
ootama	doc_491521502042_item	3322294	et	3	main
tere	doc_491521502042_item	3322296	et	3	main
minul	doc_491521502042_item	3322307	et	3	main
saai	doc_491521502042_item	3322329	et	4	main
sõidis	doc_491521502042_item	3322330	et	3	main
juurde	doc_491521502042_item	3322336	et	4	main
nädala	doc_491521502042_item	3322338	et	3	main
viibisin	doc_491521502042_item	3322341	et	3	main
sinu	doc_491521502042_item	3322342	et	3	main
juures	doc_491521502042_item	3322343	et	4	main
umbes	doc_491521502042_item	3322344	et	4	main
kolm	doc_491521502042_item	3322345	et	3	main
päeva	doc_491521502042_item	3322346	et	4	main
oodake	doc_491521502042_item	3322347	et	3	main
kirja	doc_491521502042_item	3322348	et	4	main
sinu	doc_491521502042_item	3322349	et	3	main
sõbranna	doc_491521502042_item	3322350	et	4	main
eesnimi	doc_491521502042_item	3322351	et	3	main
lugege	doc_491521502042_item	3322260	et	3	main
kirjutage	doc_491521502042_item	3322265	et	3	main
talle	doc_491521502042_item	3322266	et	4	main
vastus	doc_491521502042_item	3322267	et	3	main
kus	doc_491521502042_item	3322268	et	3	main
on	doc_491521502042_item	3322269	et	4	main
marguse	doc_491521502042_item	3322262	et	4	main
palun	doc_491521502042_item	3322274	et	3	main
millal	doc_491521502042_item	3322276	et	3	main
tuled	doc_491521502042_item	3322279	et	4	main
minna	doc_491521502042_item	3322290	et	3	main
margus	doc_491521502042_item	3322295	et	3	main
andesta	doc_491521502042_item	3322298	et	4	main
kirjutanud	doc_491521502042_item	3322306	et	4	main
tööli	doc_491521502042_item	3322310	et	4	main
kes	doc_491521502042_item	3322315	et	4	main
töötan	doc_491521502042_item	3322324	et	3	main
juurde	doc_491521502042_item	3322332	et	4	main
ma	doc_491521502042_item	3322340	et	3	main
kirjuta	doc_491521502042_item	3322273	et	4	main
tallinnas	doc_491521502042_item	3322289	et	4	main
et	doc_491521502042_item	3322299	et	3	main
ei	doc_491521502042_item	3322301	et	4	main
ole	doc_491521502042_item	3322302	et	4	main
sinu	doc_491521502042_item	3322303	et	3	main
kaua	doc_491521502042_item	3322304	et	3	main
oli	doc_491521502042_item	3322308	et	3	main
väga	doc_491521502042_item	3322309	et	3	main
augustis	doc_491521502042_item	3322311	et	3	main
ääres	doc_491521502042_item	3322318	et	4	main
päevisin	doc_491521502042_item	3322320	et	4	main
ma	doc_491521502042_item	3322323	et	3	main
ajas	doc_491521502042_item	3322325	et	4	main
sellepärast	doc_491521502042_item	3322326	et	3	main
ma	doc_491521502042_item	3322327	et	3	main
ei	doc_491521502042_item	3322328	et	4	main
ma	doc_491521502042_item	3322333	et	3	main
sinu	doc_491521502042_item	3322335	et	3	main
parast	doc_491521502042_item	3322339	et	3	main
eestlasest	doc_491521501736_item	3324449	et	3	main
teile	doc_491521501736_item	3324457	et	4	main
kas	doc_491521501736_item	3324463	et	3	main
oma	doc_491521501736_item	3324466	et	4	main
teie	doc_491521501736_item	3324480	et	4	main
huvialade	doc_491521501736_item	3324481	et	3	main
vabal	doc_491521501736_item	3324487	et	3	main
sisse	doc_491521501736_item	3324495	et	4	main
u	doc_491521501736_item	3324500	et	4	main
sinu	doc_491521501736_item	3324507	et	3	main
kiri	doc_491521501736_item	3324447	et	3	main
oma	doc_491521501736_item	3324452	et	4	main
kirjas	doc_491521501736_item	3324453	et	4	main
millist	doc_491521501736_item	3324454	et	3	main
muusikat	doc_491521501736_item	3324455	et	3	main
meeldib	doc_491521501736_item	3324456	et	3	main
kirjutage	doc_491521501736_item	3324462	et	3	main
või	doc_491521501736_item	3324468	et	4	main
ja	doc_491521501736_item	3324470	et	3	main
kontserdil	doc_491521501736_item	3324475	et	3	main
kirjutage	doc_491521501736_item	3324484	et	3	main
ajal	doc_491521501736_item	3324488	et	4	main
kirjutage	doc_491521501736_item	3324491	et	3	main
on	doc_491521501736_item	3324499	et	4	main
sain	doc_491521501736_item	3324506	et	3	main
mulle	doc_491521501736_item	3324510	et	4	main
võimleme	doc_491521501736_item	3324549	et	3	main
trennida	doc_491521501736_item	3324575	et	4	main
üks	doc_491521501736_item	3324576	et	3	main
mulle	doc_491521501736_item	3324582	et	4	main
reisida	doc_491521501736_item	3324585	et	3	main
mulle	doc_491521501736_item	3324596	et	4	main
kuulata	doc_491521501736_item	3324458	et	4	main
kirjutage	doc_491521501736_item	3324459	et	3	main
teil	doc_491521501736_item	3324464	et	4	main
lindikogu	doc_491521501736_item	3324469	et	4	main
vahel	doc_491521501736_item	3324473	et	4	main
kui	doc_491521501736_item	3324476	et	3	main
ei	doc_491521501736_item	3324478	et	4	main
mida	doc_491521501736_item	3324485	et	4	main
joonitud	doc_491521501736_item	3324493	et	4	main
kirja	doc_491521501736_item	3324496	et	4	main
sõna	doc_491521501736_item	3324502	et	4	main
hele	doc_491521501736_item	3324505	et	3	main
sõbrannaga	doc_491521501736_item	3324544	et	3	main
aeroobikasse	doc_491521501736_item	3324546	et	4	main
terve	doc_491521501736_item	3324550	et	4	main
tund	doc_491521501736_item	3324551	et	3	main
esmaspäeval	doc_491521501736_item	3324553	et	3	main
ma	doc_491521501736_item	3324556	et	3	main
mu	doc_491521501736_item	3324559	et	3	main
kuus	doc_491521501736_item	3324578	et	4	main
millega	doc_491521501736_item	3324597	et	3	main
huvialasedega	doc_491521501736_item	3324601	et	3	main
ootan	doc_491521501736_item	3324605	et	3	main
küsib	doc_491521501736_item	3324451	et	3	main
vastus	doc_491521501736_item	3324461	et	3	main
on	doc_491521501736_item	3324465	et	4	main
käite	doc_491521501736_item	3324472	et	3	main
hulka	doc_491521501736_item	3324482	et	4	main
siis	doc_491521501736_item	3324483	et	3	main
teha	doc_491521501736_item	3324489	et	3	main
kiri	doc_491521501736_item	3324492	et	3	main
nõutav	doc_491521501736_item	3324497	et	4	main
80	doc_491521501736_item	3324501	et	2	main
kallis	doc_491521501736_item	3324504	et	4	main
kätte	doc_491521501736_item	3324509	et	4	main
oma	doc_491521501736_item	3324543	et	4	main
käin	doc_491521501736_item	3324545	et	3	main
seal	doc_491521501736_item	3324547	et	4	main
kord	doc_491521501736_item	3324577	et	4	main
väga	doc_491521501736_item	3324583	et	3	main
sest	doc_491521501736_item	3324586	et	4	main
seal	doc_491521501736_item	3324587	et	4	main
võib	doc_491521501736_item	3324588	et	3	main
puhata	doc_491521501736_item	3324589	et	4	main
lõbutseda	doc_491521501736_item	3324590	et	3	main
tutvustada	doc_491521501736_item	3324591	et	3	main
aega	doc_491521501736_item	3324609	et	4	main
sinu	doc_491521501736_item	3324610	et	3	main
eesnimi	doc_491521501736_item	3324611	et	3	main
19112002	doc_491521501736_item	3324612	et	2	main
käin	doc_491521501736_item	3324573	et	3	main
temaga	doc_491521501736_item	3324574	et	3	main
teie	doc_491521501736_item	3324448	et	4	main
sõber	doc_491521501736_item	3324450	et	3	main
talle	doc_491521501736_item	3324460	et	4	main
plaadi-	doc_491521501736_item	3324467	et	4	main
kas	doc_491521501736_item	3324471	et	3	main
ka	doc_491521501736_item	3324474	et	3	main
muusika	doc_491521501736_item	3324477	et	4	main
kuulu	doc_491521501736_item	3324479	et	4	main
teile	doc_491521501736_item	3324486	et	4	main
meeldib	doc_491521501736_item	3324490	et	3	main
kasti	doc_491521501736_item	3324494	et	4	main
pikkus	doc_491521501736_item	3324498	et	4	main
tere	doc_491521501736_item	3324503	et	3	main
kirja	doc_491521501736_item	3324508	et	4	main
meeldib	doc_491521501736_item	3324511	et	3	main
kuulata	doc_491521501736_item	3324512	et	4	main
klaasikamuusikat	doc_491521501736_item	3324513	et	4	main
tahan	doc_491521501736_item	3324514	et	3	main
kirjutada	doc_491521501736_item	3324515	et	3	main
sulle	doc_491521501736_item	3324516	et	3	main
kuidas	doc_491521501736_item	3324517	et	3	main
ma	doc_491521501736_item	3324518	et	3	main
veetan	doc_491521501736_item	3324519	et	4	main
oma	doc_491521501736_item	3324520	et	4	main
vaba	doc_491521501736_item	3324521	et	4	main
aega	doc_491521501736_item	3324522	et	4	main
ja	doc_491521501736_item	3324523	et	3	main
mis	doc_491521501736_item	3324524	et	4	main
huvialased	doc_491521501736_item	3324525	et	4	main
meeldivad	doc_491521501736_item	3324526	et	4	main
vaba	doc_491521501736_item	3324527	et	4	main
ael	doc_491521501736_item	3324528	et	4	main
mulle	doc_491521501736_item	3324529	et	4	main
meeldib	doc_491521501736_item	3324530	et	3	main
käija	doc_491521501736_item	3324531	et	4	main
külla	doc_491521501736_item	3324532	et	4	main
suhelda	doc_491521501736_item	3324533	et	4	main
sõbratega	doc_491521501736_item	3324534	et	4	main
samuti	doc_491521501736_item	3324535	et	3	main
iga	doc_491521501736_item	3324536	et	4	main
teisipäeval	doc_491521501736_item	3324537	et	3	main
ja	doc_491521501736_item	3324538	et	3	main
neljapäeval	doc_491521501736_item	3324539	et	3	main
kell	doc_491521501736_item	3324540	et	3	main
viis	doc_491521501736_item	3324541	et	4	main
õhtul	doc_491521501736_item	3324542	et	3	main
me	doc_491521501736_item	3324548	et	4	main
iga	doc_491521501736_item	3324552	et	4	main
ja	doc_491521501736_item	3324554	et	3	main
tegeleb	doc_491521501736_item	3324561	et	3	main
kerge	doc_491521501736_item	3324562	et	4	main
jõustiga	doc_491521501736_item	3324563	et	4	main
ta	doc_491521501736_item	3324564	et	4	main
on	doc_491521501736_item	3324565	et	4	main
treener	doc_491521501736_item	3324566	et	3	main
ja	doc_491521501736_item	3324567	et	3	main
kui	doc_491521501736_item	3324568	et	3	main
on	doc_491521501736_item	3324569	et	4	main
vaba	doc_491521501736_item	3324570	et	4	main
aega	doc_491521501736_item	3324571	et	4	main
ma	doc_491521501736_item	3324572	et	3	main
käin	doc_491521501736_item	3324580	et	3	main
reisile	doc_491521501736_item	3324581	et	3	main
meeldib	doc_491521501736_item	3324584	et	3	main
saa	doc_491521501736_item	3324598	et	4	main
mis	doc_491521501736_item	3324600	et	4	main
tegeled	doc_491521501736_item	3324603	et	3	main
väga	doc_491521501736_item	3324604	et	3	main
kirja	doc_491521501736_item	3324607	et	4	main
head	doc_491521501736_item	3324608	et	4	main
reedel	doc_491521501736_item	3324555	et	3	main
käin	doc_491521501736_item	3324557	et	3	main
ujuma	doc_491521501736_item	3324558	et	3	main
õde	doc_491521501736_item	3324560	et	4	main
ma	doc_491521501736_item	3324579	et	3	main
teistega	doc_491521501736_item	3324592	et	4	main
inimistega	doc_491521501736_item	3324593	et	3	main
hele	doc_491521501736_item	3324594	et	3	main
kirjuta	doc_491521501736_item	3324595	et	4	main
tegeled	doc_491521501736_item	3324599	et	3	main
sa	doc_491521501736_item	3324602	et	3	main
sinu	doc_491521501736_item	3324606	et	3	main
kiri	doc_491521501737_item	3325895	et	3	main
küsib	doc_491521501737_item	3325899	et	3	main
kuulata	doc_491521501737_item	3325906	et	4	main
vastus	doc_491521501737_item	3325909	et	3	main
kontserdil	doc_491521501737_item	3325923	et	3	main
kirja	doc_491521501737_item	3325939	et	4	main
sõna	doc_491521501737_item	3325945	et	4	main
ja	doc_491521501737_item	3325951	et	3	main
vastuse	doc_491521501737_item	3325954	et	3	main
rõõmes	doc_491521501737_item	3325958	et	3	main
asjad	doc_491521501737_item	3325961	et	3	main
olen	doc_491521501737_item	3325977	et	3	main
metsas	doc_491521501737_item	3325988	et	3	main
koos	doc_491521501737_item	3326028	et	4	main
sõbraga	doc_491521501737_item	3326029	et	3	main
väga	doc_491521501737_item	3326039	et	3	main
kõige	doc_491521501737_item	3326050	et	4	main
sõber	doc_491521501737_item	3325898	et	3	main
muusikat	doc_491521501737_item	3325903	et	3	main
plaadi-	doc_491521501737_item	3325915	et	4	main
kui	doc_491521501737_item	3325924	et	3	main
nõutav	doc_491521501737_item	3325940	et	4	main
pikkus	doc_491521501737_item	3325941	et	4	main
tervist	doc_491521501737_item	3325946	et	4	main
marika	doc_491521501737_item	3325947	et	4	main
sain	doc_491521501737_item	3325948	et	3	main
sinult	doc_491521501737_item	3325949	et	3	main
sinu	doc_491521501737_item	3325955	et	3	main
kirjutan	doc_491521501737_item	3325963	et	3	main
et	doc_491521501737_item	3325965	et	3	main
sulle	doc_491521501737_item	3325967	et	3	main
teha	doc_491521501737_item	3325970	et	3	main
perega	doc_491521501737_item	3325979	et	3	main
on	doc_491521501737_item	3325981	et	4	main
mees	doc_491521501737_item	3325982	et	4	main
ja	doc_491521501737_item	3325983	et	3	main
tütar	doc_491521501737_item	3325984	et	3	main
suvel	doc_491521501737_item	3325985	et	3	main
matkavad	doc_491521501737_item	3325989	et	4	main
metsas	doc_491521501737_item	3325990	et	3	main
me	doc_491521501737_item	3325991	et	4	main
korjame	doc_491521501737_item	3325992	et	3	main
marju	doc_491521501737_item	3325993	et	3	main
või	doc_491521501737_item	3325994	et	4	main
meile	doc_491521501737_item	3326009	et	4	main
meeldib	doc_491521501737_item	3326010	et	3	main
lõkke	doc_491521501737_item	3326012	et	3	main
ujuda	doc_491521501737_item	3326016	et	3	main
järves	doc_491521501737_item	3326017	et	4	main
me	doc_491521501737_item	3326030	et	4	main
teeme	doc_491521501737_item	3326031	et	3	main
sind	doc_491521501737_item	3326049	et	4	main
teie	doc_491521501737_item	3325896	et	4	main
kirjas	doc_491521501737_item	3325901	et	4	main
kirjutage	doc_491521501737_item	3325907	et	3	main
teil	doc_491521501737_item	3325912	et	4	main
vahel	doc_491521501737_item	3325921	et	4	main
muusika	doc_491521501737_item	3325925	et	4	main
kuulu	doc_491521501737_item	3325927	et	4	main
meeldib	doc_491521501737_item	3325938	et	3	main
80	doc_491521501737_item	3325944	et	2	main
annan	doc_491521501737_item	3325953	et	3	main
teinnen	doc_491521501737_item	3325957	et	4	main
eedenevad	doc_491521501737_item	3325962	et	4	main
et	doc_491521501737_item	3325968	et	3	main
vabal	doc_491521501737_item	3325971	et	3	main
me	doc_491521501737_item	3325986	et	4	main
šašlõkke	doc_491521501737_item	3326014	et	2	main
meeldib	doc_491521501737_item	3326021	et	3	main
suusatada	doc_491521501737_item	3326023	et	3	main
mängida	doc_491521501737_item	3326025	et	3	main
õues	doc_491521501737_item	3326027	et	4	main
ja	doc_491521501737_item	3326038	et	3	main
joonistasin	doc_491521501737_item	3326041	et	3	main
käib	doc_491521501737_item	3326044	et	3	main
külla	doc_491521501737_item	3326046	et	4	main
me	doc_491521501737_item	3326047	et	4	main
ootame	doc_491521501737_item	3326048	et	3	main
sõbranna	doc_491521501737_item	3326054	et	4	main
eesnimi	doc_491521501737_item	3326055	et	3	main
eestlasest	doc_491521501737_item	3325897	et	3	main
teile	doc_491521501737_item	3325905	et	4	main
talle	doc_491521501737_item	3325908	et	4	main
kirjutage	doc_491521501737_item	3325910	et	3	main
on	doc_491521501737_item	3325913	et	4	main
oma	doc_491521501737_item	3325914	et	4	main
käite	doc_491521501737_item	3325920	et	3	main
ka	doc_491521501737_item	3325922	et	3	main
ei	doc_491521501737_item	3325926	et	4	main
u	doc_491521501737_item	3325943	et	4	main
kirjadest	doc_491521501737_item	3325956	et	3	main
sinu	doc_491521501737_item	3325960	et	3	main
sulle	doc_491521501737_item	3325964	et	3	main
räägida	doc_491521501737_item	3325966	et	4	main
ma	doc_491521501737_item	3325969	et	3	main
ajal	doc_491521501737_item	3325972	et	4	main
meeldib	doc_491521501737_item	3325973	et	3	main
vabal	doc_491521501737_item	3325974	et	3	main
ajal	doc_491521501737_item	3325975	et	4	main
käime	doc_491521501737_item	3325987	et	4	main
talvel	doc_491521501737_item	3326020	et	4	main
lumesõda	doc_491521501737_item	3326026	et	4	main
ilus	doc_491521501737_item	3326040	et	4	main
hakkan	doc_491521501737_item	3326042	et	3	main
head	doc_491521501737_item	3326051	et	4	main
kottasemine	doc_491521501737_item	3326052	et	4	main
sinu	doc_491521501737_item	3326053	et	3	main
oma	doc_491521501737_item	3325900	et	4	main
millist	doc_491521501737_item	3325902	et	3	main
meeldib	doc_491521501737_item	3325904	et	3	main
kas	doc_491521501737_item	3325911	et	3	main
või	doc_491521501737_item	3325916	et	4	main
lindikogu	doc_491521501737_item	3325917	et	4	main
ja	doc_491521501737_item	3325918	et	3	main
kas	doc_491521501737_item	3325919	et	3	main
teie	doc_491521501737_item	3325928	et	4	main
huvialade	doc_491521501737_item	3325929	et	3	main
hulka	doc_491521501737_item	3325930	et	4	main
siis	doc_491521501737_item	3325931	et	3	main
kirjutage	doc_491521501737_item	3325932	et	3	main
mida	doc_491521501737_item	3325933	et	4	main
teile	doc_491521501737_item	3325934	et	4	main
vabal	doc_491521501737_item	3325935	et	3	main
ajal	doc_491521501737_item	3325936	et	4	main
teha	doc_491521501737_item	3325937	et	3	main
on	doc_491521501737_item	3325942	et	4	main
kirja	doc_491521501737_item	3325950	et	4	main
kohe	doc_491521501737_item	3325952	et	4	main
kuidas	doc_491521501737_item	3325959	et	3	main
ma	doc_491521501737_item	3325976	et	3	main
oma	doc_491521501737_item	3325978	et	4	main
ned	doc_491521501737_item	3325980	et	4	main
seeni	doc_491521501737_item	3325995	et	3	main
me	doc_491521501737_item	3325996	et	4	main
võime	doc_491521501737_item	3325997	et	4	main
terve	doc_491521501737_item	3325998	et	4	main
päev	doc_491521501737_item	3325999	et	3	main
olla	doc_491521501737_item	3326000	et	3	main
metsas	doc_491521501737_item	3326001	et	3	main
nautida	doc_491521501737_item	3326002	et	3	main
metsa	doc_491521501737_item	3326003	et	4	main
ilu	doc_491521501737_item	3326004	et	4	main
ja	doc_491521501737_item	3326005	et	3	main
lindude	doc_491521501737_item	3326006	et	4	main
laulmist	doc_491521501737_item	3326007	et	4	main
matkal	doc_491521501737_item	3326008	et	3	main
istuda	doc_491521501737_item	3326011	et	3	main
juures	doc_491521501737_item	3326013	et	4	main
süüa	doc_491521501737_item	3326015	et	3	main
koos	doc_491521501737_item	3326018	et	4	main
sõbraga	doc_491521501737_item	3326019	et	3	main
meile	doc_491521501737_item	3326022	et	4	main
ja	doc_491521501737_item	3326024	et	3	main
lumememme	doc_491521501737_item	3326032	et	4	main
aga	doc_491521501737_item	3326033	et	3	main
enne	doc_491521501737_item	3326034	et	4	main
ma	doc_491521501737_item	3326035	et	3	main
kogusin	doc_491521501737_item	3326036	et	3	main
postmarke	doc_491521501737_item	3326037	et	3	main
lõpetan	doc_491521501737_item	3326043	et	3	main
meile	doc_491521501737_item	3326045	et	4	main
teie	doc_491521501738_item	3327163	et	4	main
sõber	doc_491521501738_item	3327165	et	3	main
kuulata	doc_491521501738_item	3327173	et	4	main
kirjutage	doc_491521501738_item	3327174	et	3	main
vastus	doc_491521501738_item	3327176	et	3	main
kas	doc_491521501738_item	3327178	et	3	main
või	doc_491521501738_item	3327183	et	4	main
lindikogu	doc_491521501738_item	3327184	et	4	main
vahel	doc_491521501738_item	3327188	et	4	main
kirja	doc_491521501738_item	3327206	et	4	main
kiri	doc_491521501738_item	3327162	et	3	main
oma	doc_491521501738_item	3327167	et	4	main
on	doc_491521501738_item	3327180	et	4	main
oma	doc_491521501738_item	3327181	et	4	main
kas	doc_491521501738_item	3327186	et	3	main
kontserdil	doc_491521501738_item	3327190	et	3	main
teie	doc_491521501738_item	3327195	et	4	main
tere	doc_491521501738_item	3327213	et	3	main
ajal	doc_491521501738_item	3327219	et	4	main
lugeme	doc_491521501738_item	3327222	et	4	main
raamat	doc_491521501738_item	3327223	et	3	main
tütriga	doc_491521501738_item	3327224	et	4	main
mängime	doc_491521501738_item	3327225	et	3	main
malet	doc_491521501738_item	3327226	et	3	main
vaba	doc_491521501738_item	3327252	et	4	main
meil	doc_491521501738_item	3327255	et	4	main
on	doc_491521501738_item	3327256	et	4	main
väga	doc_491521501738_item	3327257	et	3	main
ma	doc_491521501738_item	3327276	et	3	main
me	doc_491521501738_item	3327282	et	4	main
meeldib	doc_491521501738_item	3327286	et	3	main
kõike	doc_491521501738_item	3327288	et	4	main
palju	doc_491521501738_item	3327289	et	4	main
video	doc_491521501738_item	3327297	et	4	main
kompjutriga	doc_491521501738_item	3327300	et	4	main
ometi	doc_491521501977_item	3327306	et	3	main
tead	doc_491521501977_item	3327317	et	4	main
suures	doc_491521501977_item	3327343	et	3	main
see	doc_491521501977_item	3327345	et	3	main
ehituse	doc_491521501977_item	3327347	et	4	main
abc	doc_491521501977_item	3327348	et	4	main
minu	doc_491521501977_item	3327349	et	3	main
kohustused	doc_491521501977_item	3327350	et	4	main
oli	doc_491521501977_item	3327351	et	3	main
teenindamine	doc_491521501977_item	3327357	et	4	main
oli	doc_491521501977_item	3327358	et	3	main
kõige	doc_491521501977_item	3327361	et	4	main
klientiga	doc_491521501977_item	3327366	et	4	main
kell	doc_491521501977_item	3327369	et	3	main
eestlasest	doc_491521501738_item	3327164	et	3	main
kirjas	doc_491521501738_item	3327168	et	4	main
muusikat	doc_491521501738_item	3327170	et	3	main
teile	doc_491521501738_item	3327172	et	4	main
ja	doc_491521501738_item	3327185	et	3	main
kui	doc_491521501738_item	3327191	et	3	main
ajal	doc_491521501738_item	3327203	et	4	main
teha	doc_491521501738_item	3327204	et	3	main
meeldib	doc_491521501738_item	3327205	et	3	main
u	doc_491521501738_item	3327210	et	4	main
80	doc_491521501738_item	3327211	et	2	main
ja	doc_491521501738_item	3327251	et	3	main
kaisime	doc_491521501738_item	3327262	et	4	main
kohvikus	doc_491521501738_item	3327263	et	3	main
leo	doc_491521501738_item	3327264	et	4	main
kohvik	doc_491521501738_item	3327265	et	3	main
leo	doc_491521501738_item	3327266	et	4	main
asub	doc_491521501738_item	3327267	et	3	main
meie	doc_491521501738_item	3327268	et	4	main
majas	doc_491521501738_item	3327269	et	3	main
minu	doc_491521501738_item	3327270	et	3	main
tütar	doc_491521501738_item	3327271	et	3	main
armastab	doc_491521501738_item	3327272	et	3	main
jook	doc_491521501738_item	3327273	et	3	main
millist	doc_491521501738_item	3327169	et	3	main
meeldib	doc_491521501738_item	3327171	et	3	main
talle	doc_491521501738_item	3327175	et	4	main
kirjutage	doc_491521501738_item	3327177	et	3	main
teil	doc_491521501738_item	3327179	et	4	main
kuulu	doc_491521501738_item	3327194	et	4	main
siis	doc_491521501738_item	3327198	et	3	main
kirjutage	doc_491521501738_item	3327199	et	3	main
mida	doc_491521501738_item	3327200	et	4	main
teile	doc_491521501738_item	3327201	et	4	main
vabal	doc_491521501738_item	3327202	et	3	main
on	doc_491521501738_item	3327209	et	4	main
sõber	doc_491521501738_item	3327214	et	3	main
meie	doc_491521501738_item	3327216	et	4	main
ajal	doc_491521501738_item	3327253	et	4	main
jäätis	doc_491521501738_item	3327275	et	3	main
ja	doc_491521501738_item	3327277	et	3	main
ka	doc_491521501738_item	3327283	et	3	main
me	doc_491521501738_item	3327290	et	4	main
armastame	doc_491521501738_item	3327291	et	3	main
istume	doc_491521501738_item	3327292	et	3	main
koju	doc_491521501738_item	3327293	et	3	main
tütar	doc_491521501738_item	3327298	et	3	main
mängib	doc_491521501738_item	3327299	et	3	main
tere	doc_491521501977_item	3327303	et	3	main
leidsin	doc_491521501977_item	3327308	et	3	main
aega	doc_491521501977_item	3327310	et	4	main
kirjutata	doc_491521501977_item	3327312	et	3	main
väiksed	doc_491521501977_item	3327320	et	4	main
lapsed	doc_491521501977_item	3327321	et	3	main
siis	doc_491521501977_item	3327322	et	3	main
on	doc_491521501977_item	3327323	et	4	main
vähem	doc_491521501977_item	3327326	et	4	main
teatada	doc_491521501977_item	3327329	et	3	main
ühe	doc_491521501977_item	3327331	et	4	main
hea	doc_491521501977_item	3327332	et	4	main
uudist	doc_491521501977_item	3327333	et	3	main
ma	doc_491521501977_item	3327334	et	3	main
käisin	doc_491521501977_item	3327335	et	3	main
juuli	doc_491521501977_item	3327336	et	4	main
ühes	doc_491521501977_item	3327342	et	4	main
kaupa	doc_491521501977_item	3327352	et	4	main
vastuvõtmine	doc_491521501977_item	3327353	et	3	main
suhtelda	doc_491521501977_item	3327365	et	4	main
tööpäev	doc_491521501977_item	3327367	et	3	main
suvel	doc_491521501738_item	3327244	et	3	main
metsa	doc_491521501738_item	3327245	et	4	main
koristame	doc_491521501738_item	3327246	et	3	main
marjad	doc_491521501738_item	3327247	et	3	main
ja	doc_491521501738_item	3327248	et	3	main
seenid	doc_491521501738_item	3327249	et	4	main
puhkul	doc_491521501738_item	3327250	et	4	main
küsib	doc_491521501738_item	3327166	et	3	main
plaadi-	doc_491521501738_item	3327182	et	4	main
käite	doc_491521501738_item	3327187	et	3	main
ka	doc_491521501738_item	3327189	et	3	main
muusika	doc_491521501738_item	3327192	et	4	main
ei	doc_491521501738_item	3327193	et	4	main
huvialade	doc_491521501738_item	3327196	et	3	main
hulka	doc_491521501738_item	3327197	et	4	main
anja	doc_491521501738_item	3327215	et	4	main
vabal	doc_491521501738_item	3327218	et	3	main
vaatame	doc_491521501738_item	3327220	et	3	main
telerit	doc_491521501738_item	3327221	et	3	main
mehega	doc_491521501738_item	3327227	et	3	main
õhtul	doc_491521501738_item	3327228	et	3	main
pärast	doc_491521501738_item	3327229	et	4	main
töö	doc_491521501738_item	3327230	et	4	main
me	doc_491521501738_item	3327231	et	4	main
teha	doc_491521501738_item	3327232	et	3	main
sööma	doc_491521501738_item	3327233	et	4	main
ja	doc_491521501738_item	3327234	et	3	main
vatame	doc_491521501738_item	3327235	et	4	main
video	doc_491521501738_item	3327236	et	4	main
muultik	doc_491521501738_item	3327237	et	4	main
me	doc_491521501738_item	3327238	et	4	main
väga	doc_491521501738_item	3327239	et	3	main
armastan	doc_491521501738_item	3327240	et	3	main
suvel	doc_491521501738_item	3327241	et	3	main
me	doc_491521501738_item	3327242	et	4	main
käisime	doc_491521501738_item	3327243	et	3	main
mees	doc_491521501738_item	3327279	et	4	main
kõikile	doc_491521501738_item	3327294	et	4	main
ja	doc_491521501738_item	3327295	et	3	main
lõpuks	doc_491521501977_item	3327305	et	4	main
kui	doc_491521501977_item	3327318	et	3	main
on	doc_491521501977_item	3327319	et	4	main
aega	doc_491521501977_item	3327325	et	4	main
ma	doc_491521501977_item	3327327	et	3	main
tahan	doc_491521501977_item	3327328	et	3	main
sulle	doc_491521501977_item	3327330	et	3	main
praktilase	doc_491521501977_item	3327338	et	4	main
minu	doc_491521501977_item	3327339	et	3	main
ehitusekaupluses	doc_491521501977_item	3327344	et	4	main
nõutav	doc_491521501738_item	3327207	et	4	main
pikkus	doc_491521501738_item	3327208	et	4	main
sõna	doc_491521501738_item	3327212	et	4	main
peres	doc_491521501738_item	3327217	et	3	main
on	doc_491521501738_item	3327254	et	4	main
meeldime	doc_491521501738_item	3327258	et	3	main
meie	doc_491521501738_item	3327259	et	4	main
huvialad	doc_491521501738_item	3327260	et	3	main
on	doc_491521501738_item	3327261	et	4	main
ja	doc_491521501738_item	3327274	et	3	main
armastame	doc_491521501738_item	3327280	et	3	main
koju	doc_491521501738_item	3327284	et	3	main
minu	doc_491521501738_item	3327278	et	3	main
kokteilid	doc_491521501738_item	3327281	et	3	main
tehe	doc_491521501738_item	3327285	et	3	main
kokteilid	doc_491521501738_item	3327287	et	3	main
vaatame	doc_491521501738_item	3327296	et	3	main
kiri	doc_491521501977_item	3327302	et	3	main
maret	doc_491521501977_item	3327304	et	4	main
alati	doc_491521501977_item	3327324	et	4	main
praktika	doc_491521501977_item	3327340	et	4	main
oli	doc_491521501977_item	3327341	et	3	main
on	doc_491521501977_item	3327346	et	4	main
markeerimine	doc_491521501977_item	3327354	et	4	main
ja	doc_491521501977_item	3327355	et	3	main
klienti	doc_491521501977_item	3327356	et	4	main
huvitav	doc_491521501977_item	3327360	et	4	main
juba	doc_491521501977_item	3327381	et	3	main
kutsuvad	doc_491521501977_item	3327382	et	4	main
tööle	doc_491521501977_item	3327384	et	3	main
minna	doc_491521501977_item	3327385	et	3	main
mis	doc_491521501977_item	3327386	et	4	main
väga	doc_491521501977_item	3327387	et	3	main
mind	doc_491521501977_item	3327383	et	4	main
rõõmustab	doc_491521501977_item	3327388	et	3	main
mind	doc_491521501977_item	3327389	et	4	main
ma	doc_491521501977_item	3327390	et	3	main
hakkan	doc_491521501977_item	3327391	et	3	main
lõpetama	doc_491521501977_item	3327392	et	4	main
enda	doc_491521501977_item	3327393	et	4	main
kirja	doc_491521501977_item	3327394	et	4	main
nägemiseni	doc_491521501977_item	3327395	et	4	main
eesnimi	doc_491521501977_item	3327396	et	3	main
ma	doc_491521501977_item	3327307	et	3	main
natukene	doc_491521501977_item	3327309	et	4	main
et	doc_491521501977_item	3327311	et	3	main
sind	doc_491521501977_item	3327313	et	4	main
sa	doc_491521501977_item	3327314	et	3	main
ju	doc_491521501977_item	3327315	et	3	main
ise	doc_491521501977_item	3327316	et	4	main
kuus	doc_491521501977_item	3327337	et	4	main
väga	doc_491521501977_item	3327359	et	3	main
rohkem	doc_491521501977_item	3327362	et	4	main
mulle	doc_491521501977_item	3327363	et	4	main
meeldib	doc_491521501977_item	3327364	et	3	main
pool	doc_491521501977_item	3327370	et	4	main
üheksa	doc_491521501977_item	3327371	et	4	main
ja	doc_491521501977_item	3327372	et	3	main
lõppeb	doc_491521501977_item	3327373	et	3	main
pool	doc_491521501977_item	3327374	et	4	main
viis	doc_491521501977_item	3327375	et	4	main
õhtul	doc_491521501977_item	3327376	et	3	main
kauplus	doc_491521501977_item	3327377	et	3	main
asub	doc_491521501977_item	3327378	et	3	main
jõhvis	doc_491521501977_item	3327379	et	3	main
nad	doc_491521501977_item	3327380	et	3	main
algab	doc_491521501977_item	3327368	et	3	main
pole	doc_491521501798_item	3328368	et	3	main
kooli	doc_491521501798_item	3328373	et	4	main
suur	doc_491521501798_item	3328385	et	3	main
eiffeli	doc_491521501798_item	3328401	et	4	main
pariisis	doc_491521501798_item	3328405	et	4	main
päeava	doc_491521501798_item	3328407	et	4	main
on	doc_491521501798_item	3328425	et	4	main
eiffeli	doc_491521501798_item	3328426	et	4	main
torn	doc_491521501798_item	3328427	et	3	main
kui	doc_491521501798_item	3328428	et	3	main
teie	doc_491521501798_item	3328436	et	4	main
pariisis	doc_491521501798_item	3328438	et	4	main
on	doc_491521501798_item	3328448	et	4	main
kolivahe	doc_491521501798_item	3328449	et	4	main
aeg	doc_491521501798_item	3328450	et	3	main
ootan	doc_491521501798_item	3328371	et	3	main
sind	doc_491521501798_item	3328372	et	4	main
vahendusel	doc_491521501798_item	3328374	et	4	main
elimesel	doc_491521501798_item	3328375	et	4	main
nädalal	doc_491521501798_item	3328376	et	3	main
ma	doc_491521501798_item	3328377	et	3	main
käisin	doc_491521501798_item	3328378	et	3	main
ja	doc_491521501798_item	3328384	et	3	main
sümbolid	doc_491521501798_item	3328387	et	3	main
mina	doc_491521501798_item	3328395	et	4	main
kõige	doc_491521501798_item	3328398	et	4	main
elan	doc_491521501798_item	3328404	et	3	main
oli	doc_491521501798_item	3328409	et	3	main
veel	doc_491521501798_item	3328420	et	4	main
kõige	doc_491521501798_item	3328421	et	4	main
tahan	doc_491521501798_item	3328434	et	3	main
sõidan	doc_491521501798_item	3328437	et	3	main
ka	doc_491521501798_item	3328439	et	3	main
ma	doc_491521501798_item	3328451	et	3	main
ootan	doc_491521501798_item	3328452	et	3	main
sind	doc_491521501798_item	3328453	et	4	main
kalliss	doc_491521501798_item	3328361	et	4	main
käsi	doc_491521501798_item	3328364	et	4	main
ma	doc_491521501798_item	3328370	et	3	main
on	doc_491521501798_item	3328381	et	4	main
väga	doc_491521501798_item	3328382	et	3	main
on	doc_491521501798_item	3328389	et	4	main
kirikut	doc_491521501798_item	3328391	et	3	main
triumfikaar	doc_491521501798_item	3328392	et	3	main
eiffeli	doc_491521501798_item	3328393	et	4	main
et	doc_491521501798_item	3328397	et	3	main
ma	doc_491521501798_item	3328403	et	3	main
kolm	doc_491521501798_item	3328406	et	3	main
mul	doc_491521501798_item	3328408	et	3	main
kiri	doc_491521501798_item	3328359	et	3	main
andress	doc_491521501798_item	3328362	et	4	main
viiga	doc_491521501798_item	3328369	et	4	main
ilus	doc_491521501798_item	3328383	et	4	main
jumalaema	doc_491521501798_item	3328390	et	4	main
mõtlen	doc_491521501798_item	3328396	et	3	main
ilusam	doc_491521501798_item	3328399	et	4	main
on	doc_491521501798_item	3328400	et	4	main
linnas	doc_491521501798_item	3328415	et	4	main
käisin	doc_491521501798_item	3328416	et	3	main
rohkem	doc_491521501798_item	3328422	et	4	main
turiste	doc_491521501798_item	3328423	et	3	main
viibis	doc_491521501798_item	3328424	et	3	main
et	doc_491521501798_item	3328435	et	3	main
pärast	doc_491521501798_item	3328446	et	4	main
tere	doc_491521501798_item	3328360	et	3	main
kuidas	doc_491521501798_item	3328363	et	3	main
käib	doc_491521501798_item	3328365	et	3	main
mul	doc_491521501798_item	3328366	et	3	main
on	doc_491521501798_item	3328367	et	4	main
pariisis	doc_491521501798_item	3328379	et	4	main
see	doc_491521501798_item	3328380	et	3	main
linn	doc_491521501798_item	3328386	et	3	main
see	doc_491521501798_item	3328388	et	3	main
torni	doc_491521501798_item	3328394	et	4	main
torn	doc_491521501798_item	3328402	et	3	main
kauplusedes	doc_491521501798_item	3328417	et	4	main
ja	doc_491521501798_item	3328418	et	3	main
palju	doc_491521501798_item	3328419	et	4	main
õppin	doc_491521501798_item	3328443	et	4	main
aga	doc_491521501798_item	3328444	et	3	main
nädala	doc_491521501798_item	3328445	et	3	main
mul	doc_491521501798_item	3328447	et	3	main
sa	doc_491521501798_item	3328455	et	3	main
ei	doc_491521501798_item	3328456	et	4	main
kirjuta	doc_491521501798_item	3328457	et	4	main
mulle	doc_491521501798_item	3328458	et	4	main
ma	doc_491521501798_item	3328459	et	3	main
itatsen	doc_491521501798_item	3328460	et	4	main
ja	doc_491521501798_item	3328461	et	3	main
minu	doc_491521501798_item	3328462	et	3	main
õde	doc_491521501798_item	3328463	et	4	main
tahad	doc_491521501798_item	3328465	et	3	main
et	doc_491521501798_item	3328466	et	3	main
ka	doc_491521501798_item	3328464	et	3	main
te	doc_491521501798_item	3328467	et	4	main
kirjuta	doc_491521501798_item	3328468	et	4	main
mulle	doc_491521501798_item	3328469	et	4	main
ma	doc_491521501798_item	3328470	et	3	main
ootan	doc_491521501798_item	3328471	et	3	main
sinu	doc_491521501798_item	3328472	et	3	main
kirju	doc_491521501798_item	3328473	et	4	main
ja	doc_491521501798_item	3328474	et	3	main
ma	doc_491521501798_item	3328475	et	3	main
armastan	doc_491521501798_item	3328476	et	3	main
sind	doc_491521501798_item	3328477	et	4	main
sinu	doc_491521501798_item	3328478	et	3	main
eesnimi	doc_491521501798_item	3328479	et	3	main
palju	doc_491521501798_item	3328410	et	4	main
vaba	doc_491521501798_item	3328411	et	4	main
aeg	doc_491521501798_item	3328412	et	3	main
ma	doc_491521501798_item	3328413	et	3	main
jalutasin	doc_491521501798_item	3328414	et	3	main
te	doc_491521501798_item	3328429	et	4	main
teaksite	doc_491521501798_item	3328430	et	3	main
vaid	doc_491521501798_item	3328431	et	3	main
kui	doc_491521501798_item	3328432	et	3	main
ma	doc_491521501798_item	3328433	et	3	main
sellel	doc_491521501798_item	3328440	et	4	main
nädalal	doc_491521501798_item	3328441	et	3	main
ma	doc_491521501798_item	3328442	et	3	main
miks	doc_491521501798_item	3328454	et	4	main
pill	doc_285078626586_item	3329167	et	3	main
siiski	doc_285078626586_item	3329168	et	4	main
on	doc_285078626586_item	3329169	et	4	main
kui	doc_285078626586_item	3329183	et	3	main
kui	doc_285078626586_item	3329192	et	3	main
selle	doc_285078626586_item	3329193	et	4	main
pillidele	doc_285078626586_item	3329194	et	3	main
ettenähtud	doc_285078626586_item	3329195	et	4	main
panen	doc_285078626586_item	3329205	et	3	main
kegi	doc_285078626586_item	3329209	et	4	main
teeb	doc_285078626586_item	3329210	et	3	main
akna	doc_285078626586_item	3329211	et	3	main
lahti	doc_285078626586_item	3329212	et	4	main
ja	doc_285078626586_item	3329213	et	3	main
nagu	doc_285078626586_item	3329214	et	3	main
nii	doc_285078626586_item	3329215	et	3	main
võiks	doc_285078626586_item	3329219	et	4	main
jutub	doc_285078626586_item	3329226	et	4	main
ees	doc_285078626586_item	3329172	et	4	main
parem	doc_285078626586_item	3329181	et	4	main
oleks	doc_285078626586_item	3329182	et	3	main
kontrabassi	doc_285078626586_item	3329184	et	4	main
sealt	doc_285078626586_item	3329185	et	4	main
eemale	doc_285078626586_item	3329186	et	3	main
üldse	doc_285078626586_item	3329198	et	3	main
eesnimi	doc_285078626586_item	3329202	et	3	main
ma	doc_285078626586_item	3329204	et	3	main
akna	doc_285078626586_item	3329206	et	3	main
siis	doc_285078626586_item	3329208	et	3	main
panna	doc_285078626586_item	3329223	et	4	main
ja	doc_285078626586_item	3329224	et	3	main
siis	doc_285078626586_item	3329225	et	3	main
pilli	doc_285078626586_item	3329266	et	4	main
ei	doc_285078626586_item	3329269	et	4	main
saa	doc_285078626586_item	3329270	et	4	main
kirjavahetus	doc_285078626586_item	3329164	et	4	main
parem	doc_285078626586_item	3329191	et	4	main
paned	doc_285078626586_item	3329197	et	3	main
ei	doc_285078626586_item	3329216	et	4	main
panna	doc_285078626586_item	3329271	et	4	main
liga	doc_285078626586_item	3329274	et	4	main
kuiv	doc_285078626586_item	3329275	et	3	main
pill	doc_285078626586_item	3329276	et	3	main
läheb	doc_285078626586_item	3329277	et	3	main
sinu	doc_285078626586_item	3329166	et	3	main
tegelikult	doc_285078626586_item	3329170	et	4	main
pisut	doc_285078626586_item	3329171	et	3	main
pääse	doc_285078626586_item	3329177	et	4	main
tahvlile	doc_285078626586_item	3329178	et	3	main
üldse	doc_285078626586_item	3329179	et	3	main
ligi	doc_285078626586_item	3329180	et	3	main
veel	doc_285078626586_item	3329190	et	4	main
kohta	doc_285078626586_item	3329196	et	4	main
head	doc_285078626586_item	3329200	et	4	main
juurde	doc_285078626586_item	3329207	et	4	main
et	doc_285078626586_item	3329218	et	3	main
pilli	doc_285078626586_item	3329220	et	4	main
teise	doc_285078626586_item	3329221	et	4	main
kohta	doc_285078626586_item	3329222	et	4	main
segab	doc_285078626586_item	3329265	et	3	main
vähemalt	doc_285078626586_item	3329281	et	4	main
üks	doc_285078626586_item	3329282	et	3	main
te	doc_842434202405_item	3329289	et	4	main
kolinud	doc_842434202405_item	3329291	et	4	main
oma	doc_842434202405_item	3329298	et	4	main
eestlasest	doc_842434202405_item	3329299	et	3	main
sõbrale	doc_842434202405_item	3329300	et	3	main
kirjutage	doc_842434202405_item	3329301	et	3	main
teile	doc_842434202405_item	3329307	et	4	main
kas	doc_842434202405_item	3329311	et	3	main
kauge	doc_842434202405_item	3329313	et	4	main
tööl	doc_842434202405_item	3329314	et	3	main
maria	doc_842434202405_item	3329328	et	4	main
kahetoaline	doc_842434202405_item	3329379	et	4	main
korter	doc_842434202405_item	3329380	et	3	main
üheksakorruselises	doc_842434202405_item	3329383	et	4	main
kirjas	doc_285078626586_item	3329246	et	4	main
et	doc_285078626586_item	3329247	et	3	main
ära	doc_285078626586_item	3329248	et	4	main
võtke	doc_285078626586_item	3329249	et	3	main
minu	doc_285078626586_item	3329250	et	3	main
võimu	doc_285078626586_item	3329251	et	4	main
ja	doc_285078626586_item	3329252	et	3	main
pilli	doc_285078626586_item	3329253	et	4	main
palun	doc_285078626586_item	3329254	et	3	main
aga	doc_285078626586_item	3329255	et	3	main
õppejõud	doc_285078626586_item	3329256	et	4	main
veel	doc_285078626586_item	3329257	et	4	main
ühtegi	doc_285078626586_item	3329258	et	4	main
korda	doc_285078626586_item	3329259	et	4	main
mulle	doc_285078626586_item	3329260	et	4	main
ei	doc_285078626586_item	3329261	et	4	main
öeldnud	doc_285078626586_item	3329262	et	4	main
et	doc_285078626586_item	3329263	et	3	main
eesnimi	doc_285078626586_item	3329165	et	3	main
klass	doc_285078626586_item	3329173	et	3	main
201s	doc_285078626586_item	3329174	et	4	main
nimelt	doc_285078626586_item	3329175	et	4	main
ei	doc_285078626586_item	3329176	et	4	main
akna	doc_285078626586_item	3329187	et	3	main
juurde	doc_285078626586_item	3329188	et	4	main
paned	doc_285078626586_item	3329189	et	3	main
ikka	doc_285078626586_item	3329199	et	4	main
soovides	doc_285078626586_item	3329201	et	4	main
kui	doc_285078626586_item	3329203	et	3	main
mõtle	doc_285078626586_item	3329217	et	4	main
see	doc_285078626586_item	3329227	et	3	main
mis	doc_285078626586_item	3329228	et	4	main
juhtus	doc_285078626586_item	3329229	et	3	main
eesnimi	doc_285078626586_item	3329230	et	3	main
pilliga	doc_285078626586_item	3329231	et	3	main
tal	doc_285078626586_item	3329232	et	3	main
oli	doc_285078626586_item	3329233	et	3	main
teine	doc_285078626586_item	3329234	et	3	main
probleem	doc_285078626586_item	3329235	et	3	main
muidu	doc_285078626586_item	3329236	et	3	main
aga	doc_285078626586_item	3329237	et	3	main
lõpp	doc_285078626586_item	3329238	et	3	main
resultaat	doc_285078626586_item	3329239	et	3	main
on	doc_285078626586_item	3329240	et	4	main
saama	doc_285078626586_item	3329241	et	4	main
ma	doc_285078626586_item	3329242	et	3	main
rääkisin	doc_285078626586_item	3329243	et	3	main
sellest	doc_285078626586_item	3329244	et	4	main
elmises	doc_285078626586_item	3329245	et	4	main
pill	doc_285078626586_item	3329264	et	3	main
ruumi	doc_285078626586_item	3329267	et	4	main
ma	doc_285078626586_item	3329268	et	3	main
seal	doc_285078626586_item	3329272	et	4	main
on	doc_285078626586_item	3329273	et	4	main
kiri	doc_842434202405_item	3329288	et	3	main
uude	doc_842434202405_item	3329292	et	3	main
korterisse	doc_842434202405_item	3329293	et	3	main
ja	doc_842434202405_item	3329294	et	3	main
tahate	doc_842434202405_item	3329295	et	3	main
kuidas	doc_842434202405_item	3329306	et	3	main
kutsuge	doc_842434202405_item	3329317	et	3	main
kuidas	doc_842434202405_item	3329329	et	3	main
käsi	doc_842434202405_item	3329330	et	4	main
käib	doc_842434202405_item	3329331	et	3	main
kuidas	doc_842434202405_item	3329332	et	3	main
on	doc_842434202405_item	3329333	et	4	main
sinu	doc_842434202405_item	3329334	et	3	main
on	doc_842434202405_item	3329352	et	4	main
uus	doc_842434202405_item	3329353	et	3	main
korter	doc_842434202405_item	3329354	et	3	main
meil	doc_842434202405_item	3329358	et	4	main
mahtuvad	doc_842434202405_item	3329369	et	4	main
auto	doc_842434202405_item	3329375	et	4	main
praegu	doc_842434202405_item	3329376	et	3	main
mul	doc_842434202405_item	3329377	et	3	main
on	doc_842434202405_item	3329378	et	4	main
korteris	doc_842434202405_item	3329388	et	3	main
tehtud	doc_842434202405_item	3329393	et	4	main
meeldis	doc_842434202405_item	3329399	et	3	main
väga	doc_842434202405_item	3329402	et	3	main
elukohas	doc_842434202405_item	3329405	et	4	main
vaikne	doc_842434202405_item	3329409	et	3	main
lähedal	doc_842434202405_item	3329410	et	4	main
asub	doc_842434202405_item	3329411	et	3	main
katki	doc_285078626586_item	3329278	et	4	main
aitäh	doc_285078626586_item	3329279	et	3	main
et	doc_285078626586_item	3329280	et	3	main
inimnene	doc_285078626586_item	3329283	et	4	main
luges	doc_285078626586_item	3329284	et	3	main
kirja	doc_285078626586_item	3329285	et	4	main
eesnimi	doc_285078626586_item	3329286	et	3	main
olete	doc_842434202405_item	3329290	et	3	main
teatada	doc_842434202405_item	3329296	et	3	main
sellest	doc_842434202405_item	3329297	et	4	main
uues	doc_842434202405_item	3329309	et	3	main
elukohas	doc_842434202405_item	3329310	et	4	main
on	doc_842434202405_item	3329312	et	4	main
käia	doc_842434202405_item	3329315	et	4	main
ja	doc_842434202405_item	3329316	et	3	main
mul	doc_842434202405_item	3329336	et	3	main
on	doc_842434202405_item	3329337	et	4	main
kõik	doc_842434202405_item	3329338	et	4	main
hästi	doc_842434202405_item	3329339	et	3	main
mul	doc_842434202405_item	3329340	et	3	main
läks	doc_842434202405_item	3329356	et	3	main
oli	doc_842434202405_item	3329359	et	3	main
auto	doc_842434202405_item	3329361	et	4	main
autos	doc_842434202405_item	3329370	et	3	main
minu	doc_842434202405_item	3329373	et	3	main
majas	doc_842434202405_item	3329384	et	3	main
korrusel	doc_842434202405_item	3329386	et	3	main
ma	doc_842434202405_item	3329390	et	3	main
oli	doc_842434202405_item	3329392	et	3	main
väga	doc_842434202405_item	3329394	et	3	main
hea	doc_842434202405_item	3329395	et	4	main
remont	doc_842434202405_item	3329400	et	3	main
on	doc_842434202405_item	3329407	et	4	main
väga	doc_842434202405_item	3329408	et	3	main
ja	doc_842434202405_item	3329417	et	3	main
veel	doc_842434202405_item	3329418	et	4	main
mulle	doc_842434202405_item	3329420	et	4	main
väga	doc_842434202405_item	3329421	et	3	main
praegu	doc_842434202405_item	3329449	et	3	main
on	doc_842434202405_item	3329450	et	4	main
sinu	doc_842434202405_item	3329451	et	3	main
kord	doc_842434202405_item	3329452	et	4	main
ja	doc_842434202405_item	3329453	et	3	main
seda	doc_842434202405_item	3329454	et	3	main
enam	doc_842434202405_item	3329455	et	4	main
mul	doc_842434202405_item	3329456	et	3	main
on	doc_842434202405_item	3329457	et	4	main
uus	doc_842434202405_item	3329458	et	3	main
korter	doc_842434202405_item	3329459	et	3	main
ma	doc_842434202405_item	3329460	et	3	main
ootan	doc_842434202405_item	3329461	et	3	main
sind	doc_842434202405_item	3329462	et	4	main
me	doc_842434202405_item	3329463	et	4	main
veedame	doc_842434202405_item	3329464	et	3	main
sinu	doc_842434202405_item	3329465	et	3	main
puhkus	doc_842434202405_item	3329466	et	3	main
väga	doc_842434202405_item	3329467	et	3	main
hea	doc_842434202405_item	3329468	et	4	main
sinu	doc_842434202405_item	3329469	et	3	main
sõbranna	doc_842434202405_item	3329470	et	4	main
talle	doc_842434202405_item	3329302	et	4	main
kuidas	doc_842434202405_item	3329303	et	3	main
meeldib	doc_842434202405_item	3329308	et	3	main
ta	doc_842434202405_item	3329318	et	4	main
külla	doc_842434202405_item	3329319	et	4	main
kirja	doc_842434202405_item	3329320	et	4	main
nõutav	doc_842434202405_item	3329321	et	4	main
pikkus	doc_842434202405_item	3329322	et	4	main
on	doc_842434202405_item	3329323	et	4	main
umbes	doc_842434202405_item	3329324	et	4	main
80	doc_842434202405_item	3329325	et	2	main
sõna	doc_842434202405_item	3329326	et	4	main
kallid	doc_842434202405_item	3329327	et	3	main
läks	doc_842434202405_item	3329304	et	3	main
kolimine	doc_842434202405_item	3329305	et	4	main
tervis	doc_842434202405_item	3329335	et	3	main
kolimine	doc_842434202405_item	3329355	et	4	main
suur	doc_842434202405_item	3329360	et	3	main
see	doc_842434202405_item	3329362	et	3	main
see	doc_842434202405_item	3329371	et	3	main
oli	doc_842434202405_item	3329372	et	3	main
onu	doc_842434202405_item	3329374	et	4	main
mis	doc_842434202405_item	3329381	et	4	main
kuhu	doc_842434202405_item	3329389	et	3	main
mulle	doc_842434202405_item	3329398	et	4	main
mulle	doc_842434202405_item	3329401	et	4	main
meeldib	doc_842434202405_item	3329403	et	3	main
talle	doc_491521501940_item	3329870	et	4	main
20-25	doc_491521501940_item	3329874	et	2	main
sõna	doc_491521501940_item	3329875	et	4	main
millal	doc_491521501940_item	3329880	et	3	main
tallinnasse	doc_491521501940_item	3329882	et	3	main
päeva	doc_491521501940_item	3329885	et	4	main
juures	doc_491521501940_item	3329888	et	4	main
oled	doc_491521501940_item	3329889	et	3	main
ja	doc_491521501940_item	3329890	et	3	main
kuhu	doc_491521501940_item	3329891	et	3	main
sa	doc_491521501940_item	3329892	et	3	main
ootama	doc_491521501940_item	3329898	et	3	main
tere	doc_491521501940_item	3329900	et	3	main
on	doc_842434202405_item	3329341	et	4	main
suur	doc_842434202405_item	3329342	et	3	main
uudis	doc_842434202405_item	3329343	et	3	main
ja	doc_842434202405_item	3329344	et	3	main
ma	doc_842434202405_item	3329345	et	3	main
tahan	doc_842434202405_item	3329346	et	3	main
sulle	doc_842434202405_item	3329347	et	3	main
sellest	doc_842434202405_item	3329348	et	4	main
kirjutada	doc_842434202405_item	3329349	et	3	main
praegu	doc_842434202405_item	3329350	et	3	main
mul	doc_842434202405_item	3329351	et	3	main
hästi	doc_842434202405_item	3329357	et	3	main
on	doc_842434202405_item	3329363	et	4	main
mugav	doc_842434202405_item	3329364	et	3	main
sellepärast	doc_842434202405_item	3329365	et	3	main
et	doc_842434202405_item	3329366	et	3	main
kõik	doc_842434202405_item	3329367	et	4	main
asjad	doc_842434202405_item	3329368	et	3	main
asub	doc_842434202405_item	3329382	et	3	main
teisel	doc_842434202405_item	3329385	et	4	main
selles	doc_842434202405_item	3329387	et	4	main
ja	doc_842434202405_item	3329397	et	3	main
uues	doc_842434202405_item	3329404	et	3	main
rajoon	doc_842434202405_item	3329406	et	3	main
pankaautomaat	doc_842434202405_item	3329416	et	4	main
kolisin	doc_842434202405_item	3329391	et	3	main
remont	doc_842434202405_item	3329396	et	3	main
ja	doc_842434202405_item	3329415	et	3	main
mida	doc_842434202405_item	3329419	et	4	main
meeldib	doc_842434202405_item	3329422	et	3	main
et	doc_842434202405_item	3329423	et	3	main
üle	doc_842434202405_item	3329424	et	3	main
tee	doc_842434202405_item	3329425	et	4	main
asub	doc_842434202405_item	3329426	et	3	main
firma	doc_842434202405_item	3329427	et	4	main
kus	doc_842434202405_item	3329428	et	3	main
ma	doc_842434202405_item	3329429	et	3	main
töötan	doc_842434202405_item	3329430	et	3	main
maria	doc_842434202405_item	3329431	et	4	main
ma	doc_842434202405_item	3329432	et	3	main
tean	doc_842434202405_item	3329433	et	3	main
et	doc_842434202405_item	3329434	et	3	main
varsti	doc_842434202405_item	3329435	et	3	main
sul	doc_842434202405_item	3329436	et	3	main
on	doc_842434202405_item	3329437	et	4	main
puhkus	doc_842434202405_item	3329438	et	3	main
ja	doc_842434202405_item	3329439	et	3	main
ma	doc_842434202405_item	3329440	et	3	main
kutsun	doc_842434202405_item	3329441	et	3	main
sind	doc_842434202405_item	3329442	et	4	main
külla	doc_842434202405_item	3329443	et	4	main
ma	doc_842434202405_item	3329444	et	3	main
olin	doc_842434202405_item	3329445	et	3	main
sul	doc_842434202405_item	3329446	et	3	main
küllas	doc_842434202405_item	3329447	et	3	main
ja	doc_842434202405_item	3329448	et	3	main
toidupood	doc_842434202405_item	3329412	et	3	main
apteek	doc_842434202405_item	3329413	et	3	main
postkontor	doc_842434202405_item	3329414	et	3	main
vastus	doc_491521501940_item	3329871	et	3	main
on	doc_491521501940_item	3329873	et	4	main
palun	doc_491521501940_item	3329878	et	3	main
minna	doc_491521501940_item	3329894	et	3	main
tahad	doc_491521501940_item	3329895	et	3	main
mulle	doc_491521501940_item	3329879	et	4	main
mitu	doc_491521501940_item	3329884	et	4	main
sa	doc_491521501940_item	3329886	et	3	main
minu	doc_491521501940_item	3329887	et	3	main
vastust	doc_491521501940_item	3329897	et	4	main
kiri	doc_491521501940_item	3329863	et	3	main
lugege	doc_491521501940_item	3329864	et	3	main
läbi	doc_491521501940_item	3329865	et	4	main
marguse	doc_491521501940_item	3329866	et	4	main
kiri	doc_491521501940_item	3329867	et	3	main
ja	doc_491521501940_item	3329868	et	3	main
kirjutage	doc_491521501940_item	3329869	et	3	main
kus	doc_491521501940_item	3329872	et	3	main
tere	doc_491521501940_item	3329876	et	3	main
sa	doc_491521501940_item	3329881	et	3	main
tuled	doc_491521501940_item	3329883	et	4	main
margus	doc_491521501940_item	3329899	et	3	main
margus	doc_491521501940_item	3329901	et	3	main
ma	doc_491521501940_item	3329902	et	3	main
tulen	doc_491521501940_item	3329903	et	3	main
tallinnasse	doc_491521501940_item	3329904	et	3	main
reede	doc_491521501940_item	3329905	et	4	main
õhtul	doc_491521501940_item	3329906	et	3	main
bussiga	doc_491521501940_item	3329907	et	3	main
ja	doc_491521501940_item	3329908	et	3	main
mõtlen	doc_491521501940_item	3329909	et	3	main
et	doc_491521501940_item	3329910	et	3	main
olen	doc_491521501940_item	3329911	et	3	main
tallinnas	doc_491521501940_item	3329912	et	4	main
kaks	doc_491521501940_item	3329913	et	3	main
päeva	doc_491521501940_item	3329914	et	4	main
pärast	doc_491521501940_item	3329915	et	4	main
seda	doc_491521501940_item	3329916	et	3	main
ma	doc_491521501940_item	3329917	et	3	main
tahan	doc_491521501940_item	3329918	et	3	main
minna	doc_491521501940_item	3329919	et	3	main
tartusse	doc_491521501940_item	3329920	et	3	main
kirjuta	doc_491521501940_item	3329877	et	4	main
tallinnas	doc_491521501940_item	3329893	et	4	main
jään	doc_491521501940_item	3329896	et	3	main
11	doc_441430986979_item	3337286	et	2	main
ümber	doc_441430986979_item	3337289	et	3	main
risk	doc_441430986979_item	3337310	et	3	main
tervist	doc_441430986979_item	3337315	et	4	main
kui	doc_441430986979_item	3337316	et	3	main
te	doc_441430986979_item	3337317	et	4	main
tegelete	doc_441430986979_item	3337318	et	3	main
aja	doc_441430986979_item	3337328	et	4	main
pikenenud	doc_441430986979_item	3337331	et	4	main
areng	doc_441430986979_item	3337333	et	3	main
4	doc_441430986979_item	3337341	et	2	main
inimesed	doc_441430986979_item	3337342	et	3	main
muudavad	doc_441430986979_item	3337343	et	4	main
ja	doc_441430986979_item	3337283	et	3	main
kirjutage	doc_441430986979_item	3337287	et	3	main
laused	doc_441430986979_item	3337288	et	3	main
2	doc_441430986979_item	3337311	et	2	main
eluiga	doc_441430986979_item	3337326	et	4	main
pidevalt	doc_441430986979_item	3337330	et	4	main
jooksul	doc_441430986979_item	3337339	et	4	main
pikendab	doc_441430986979_item	3337340	et	3	main
harjutus	doc_441430986979_item	3337281	et	4	main
tegusõnad	doc_441430986979_item	3337285	et	3	main
sihitu	doc_441430986979_item	3337291	et	4	main
asemel	doc_441430986979_item	3337293	et	4	main
sihilist	doc_441430986979_item	3337294	et	4	main
ja	doc_441430986979_item	3337295	et	3	main
1	doc_441430986979_item	3337297	et	2	main
pidev	doc_441430986979_item	3337298	et	3	main
stress	doc_441430986979_item	3337299	et	3	main
suurendab	doc_441430986979_item	3337300	et	3	main
haigestumise	doc_441430986979_item	3337309	et	4	main
tegelemine	doc_441430986979_item	3337313	et	4	main
spordiga	doc_441430986979_item	3337319	et	3	main
te	doc_441430986979_item	3337320	et	4	main
paranete	doc_441430986979_item	3337321	et	3	main
aja	doc_441430986979_item	3337338	et	4	main
sihitud	doc_441430986979_item	3337282	et	4	main
vastupidi	doc_441430986979_item	3337296	et	3	main
haigestumise	doc_441430986979_item	3337301	et	4	main
riski	doc_441430986979_item	3337302	et	4	main
inimestel	doc_441430986979_item	3337303	et	3	main
kes	doc_441430986979_item	3337304	et	4	main
spordiga	doc_441430986979_item	3337312	et	3	main
parandab	doc_441430986979_item	3337314	et	3	main
on	doc_441430986979_item	3337327	et	4	main
eluiga	doc_441430986979_item	3337337	et	4	main
ja	doc_441430986979_item	3337345	et	3	main
tekitavad	doc_441430986979_item	3337346	et	4	main
sellega	doc_441430986979_item	3337347	et	3	main
uusi	doc_441430986979_item	3337348	et	3	main
probleeme	doc_441430986979_item	3337349	et	3	main
kui	doc_441430986979_item	3337350	et	3	main
looduskeskkond	doc_441430986979_item	3337351	et	3	main
muutab	doc_441430986979_item	3337352	et	4	main
inimesel	doc_441430986979_item	3337353	et	3	main
tekkib	doc_441430986979_item	3337354	et	3	main
sellega	doc_441430986979_item	3337355	et	3	main
uued	doc_441430986979_item	3337356	et	3	main
5	doc_441430986979_item	3337358	et	2	main
probleemid	doc_441430986979_item	3337357	et	3	main
tekivad	doc_441430986979_item	3337360	et	3	main
haigused	doc_441430986979_item	3337359	et	4	main
paljude	doc_441430986979_item	3337361	et	3	main
tegurite	doc_441430986979_item	3337362	et	3	main
koosmõjul	doc_441430986979_item	3337363	et	3	main
paljude	doc_441430986979_item	3337364	et	3	main
tegurite	doc_441430986979_item	3337365	et	3	main
koosmõju	doc_441430986979_item	3337366	et	4	main
tekitab	doc_441430986979_item	3337367	et	3	main
haigused	doc_441430986979_item	3337368	et	4	main
sihilised	doc_441430986979_item	3337284	et	4	main
kasutades	doc_441430986979_item	3337290	et	3	main
tegusõna	doc_441430986979_item	3337292	et	4	main
on	doc_441430986979_item	3337305	et	4	main
pidevas	doc_441430986979_item	3337306	et	3	main
stressis	doc_441430986979_item	3337307	et	3	main
suureneb	doc_441430986979_item	3337308	et	3	main
tervist	doc_441430986979_item	3337322	et	4	main
3	doc_441430986979_item	3337323	et	2	main
inimeste	doc_441430986979_item	3337324	et	3	main
keskmine	doc_441430986979_item	3337325	et	3	main
jooksul	doc_441430986979_item	3337329	et	4	main
tsivilisatsiooni	doc_441430986979_item	3337332	et	4	main
on	doc_441430986979_item	3337334	et	4	main
inimeste	doc_441430986979_item	3337335	et	3	main
keskmist	doc_441430986979_item	3337336	et	3	main
looduskeskkonda	doc_441430986979_item	3337344	et	4	main
kontrolltöö	doc_491521501652_item	3343159	et	4	main
tuvastama	doc_491521501652_item	3343164	et	3	main
taipama	doc_491521501652_item	3343165	et	3	main
välja	doc_491521501652_item	3343172	et	4	main
плесневеть	doc_491521501652_item	3343177	et	2	main
sundima	doc_491521501652_item	3343180	et	4	main
ii	doc_491521501652_item	3343182	et	4	main
tähelepanelik	doc_491521501652_item	3343190	et	4	main
vaatama	doc_491521501652_item	3343200	et	3	main
võtke	doc_491521501652_item	3343201	et	3	main
aktiivne	doc_491521501652_item	3343236	et	3	main
remonti	doc_491521501652_item	3343241	et	4	main
saate	doc_491521501652_item	3343248	et	4	main
parima	doc_491521501652_item	3343249	et	4	main
tulemuse	doc_491521501652_item	3343250	et	3	main
kuus	doc_491521501652_item	3343257	et	4	main
sajaviiekroonine	doc_491521501652_item	3343266	et	4	main
kakskümmend	doc_491521501652_item	3343267	et	4	main
ruutmeetrit	doc_491521501652_item	3343268	et	3	main
kahekümneruutmeetrine	doc_491521501652_item	3343269	et	4	main
liisama	doc_491521501652_item	3343279	et	4	main
ära	doc_491521501652_item	3343284	et	4	main
mida	doc_491521501652_item	3343288	et	4	main
saatma	doc_491521501652_item	3343290	et	3	main
oleti	doc_491521501652_item	3343303	et	4	main
имеют	doc_491521501652_item	3343308	et	2	main
вас	doc_491521501652_item	3343323	et	2	main
возможность	doc_491521501652_item	3343325	et	2	main
teil	doc_491521501652_item	3343330	et	4	main
препятствовать	doc_491521501652_item	3343163	et	2	main
убивать	doc_491521501652_item	3343166	et	2	main
недоверчивый	doc_491521501652_item	3343170	et	2	main
hallitama	doc_491521501652_item	3343176	et	3	main
olge	doc_491521501652_item	3343189	et	3	main
lepingut	doc_491521501652_item	3343191	et	3	main
sõlmides	doc_491521501652_item	3343192	et	4	main
olge	doc_491521501652_item	3343193	et	3	main
üle	doc_491521501652_item	3343199	et	3	main
ka	doc_491521501652_item	3343234	et	3	main
tulemuse	doc_491521501652_item	3343244	et	3	main
remonti	doc_491521501652_item	3343245	et	4	main
ise	doc_491521501652_item	3343246	et	4	main
tehes	doc_491521501652_item	3343247	et	3	main
tundi	doc_491521501652_item	3343258	et	4	main
viieliikmeline	doc_491521501652_item	3343262	et	4	main
sada	doc_491521501652_item	3343263	et	4	main
panema	doc_491521501652_item	3343278	et	3	main
aru	doc_491521501652_item	3343282	et	4	main
некоторые	doc_491521501652_item	3343306	et	2	main
качество	doc_491521501652_item	3343310	et	2	main
tooded	doc_491521501652_item	3343315	et	4	main
kiiresti	doc_491521501652_item	3343320	et	3	main
у	doc_491521501652_item	3343322	et	2	main
есть	doc_491521501652_item	3343324	et	2	main
изучить	doc_491521501652_item	3343328	et	2	main
korteriühisyu	doc_491521501652_item	3343360	et	4	main
läbiajas	doc_491521501652_item	3343363	et	3	main
hakkas	doc_491521501652_item	3343371	et	3	main
väljakutsuvalt	doc_491521501652_item	3343402	et	4	main
sõnad	doc_491521501652_item	3343411	et	4	main
pealetükkivalt	doc_491521501652_item	3343415	et	4	main
pange	doc_491521501652_item	3343418	et	4	main
välja	doc_491521501652_item	3343428	et	4	main
ootamatu	doc_491521501652_item	3343431	et	4	main
ringi	doc_491521501652_item	3343437	et	4	main
kui	doc_491521501652_item	3343447	et	3	main
takistama	doc_491521501651_item	3343456	et	3	main
устанавливать	doc_491521501651_item	3343459	et	2	main
понимать	doc_491521501651_item	3343462	et	2	main
umbusklik	doc_491521501651_item	3343465	et	3	main
ii	doc_491521501651_item	3343478	et	4	main
olge	doc_491521501651_item	3343485	et	3	main
kui	doc_491521501651_item	3343492	et	3	main
kaasa	doc_491521501651_item	3343498	et	4	main
lähedes	doc_491521501651_item	3343500	et	4	main
korterit	doc_491521501651_item	3343501	et	3	main
üle	doc_491521501651_item	3343502	et	3	main
maaklerist	doc_491521501651_item	3343513	et	3	main
kuuetundi	doc_491521501651_item	3343554	et	4	main
sajaviiekrooni	doc_491521501651_item	3343561	et	4	main
paranema	doc_491521501651_item	3343571	et	3	main
mida	doc_491521501651_item	3343586	et	4	main
laskma	doc_491521501651_item	3343596	et	3	main
olema	doc_491521501651_item	3343600	et	4	main
oldi	doc_491521501651_item	3343601	et	3	main
tõlkige	doc_491521501651_item	3343603	et	3	main
некоторые	doc_491521501651_item	3343604	et	2	main
товары	doc_491521501651_item	3343605	et	2	main
takistama	doc_491521501652_item	3343162	et	3	main
сомневаться	doc_491521501652_item	3343168	et	2	main
peibutama	doc_491521501652_item	3343171	et	3	main
küünistama	doc_491521501652_item	3343178	et	3	main
tähelepanelik	doc_491521501652_item	3343194	et	4	main
asjatundja	doc_491521501652_item	3343203	et	4	main
minnes	doc_491521501652_item	3343207	et	3	main
pooleteisemeetrine	doc_491521501652_item	3343256	et	4	main
kuuetunnine	doc_491521501652_item	3343259	et	4	main
liiget	doc_491521501652_item	3343261	et	3	main
iv	doc_491521501652_item	3343270	et	4	main
juurde	doc_491521501652_item	3343277	et	4	main
minema	doc_491521501652_item	3343285	et	3	main
saadeti	doc_491521501652_item	3343291	et	3	main
pakkuma	doc_491521501652_item	3343294	et	3	main
pakuti	doc_491521501652_item	3343295	et	3	main
nõudma	doc_491521501652_item	3343296	et	3	main
nõuti	doc_491521501652_item	3343297	et	3	main
laskma	doc_491521501652_item	3343298	et	3	main
lasti	doc_491521501652_item	3343299	et	4	main
ostma	doc_491521501652_item	3343300	et	3	main
osteti	doc_491521501652_item	3343301	et	3	main
olema	doc_491521501652_item	3343302	et	4	main
tõlkige	doc_491521501652_item	3343305	et	3	main
плохое	doc_491521501652_item	3343309	et	2	main
ломаются	doc_491521501652_item	3343313	et	2	main
katki	doc_491521501652_item	3343321	et	4	main
каталог	doc_491521501652_item	3343329	et	2	main
on	doc_491521501652_item	3343331	et	4	main
võimalus	doc_491521501652_item	3343332	et	3	main
lasi	doc_491521501652_item	3343362	et	4	main
kordanägi	doc_491521501652_item	3343364	et	2	main
vaeva	doc_491521501652_item	3343365	et	4	main
et	doc_491521501652_item	3343366	et	3	main
korterit	doc_491521501652_item	3343367	et	3	main
saagile	doc_491521501652_item	3343372	et	3	main
maitsetult	doc_491521501652_item	3343399	et	4	main
müüja	doc_491521501652_item	3343403	et	4	main
pealetükkivalt	doc_491521501652_item	3343407	et	4	main
lõhnas	doc_491521501652_item	3343409	et	4	main
isuäratavalt	doc_491521501652_item	3343410	et	4	main
sulgudes	doc_491521501652_item	3343419	et	4	main
olevad	doc_491521501652_item	3343420	et	4	main
sõnad	doc_491521501652_item	3343421	et	4	main
jubedalt	doc_491521501652_item	3343427	et	4	main
tuli	doc_491521501652_item	3343430	et	4	main
lahtiselt	doc_491521501652_item	3343436	et	4	main
see	doc_491521501652_item	3343438	et	3	main
juhtum	doc_491521501652_item	3343439	et	3	main
oli	doc_491521501652_item	3343440	et	3	main
lihtsalt	doc_491521501652_item	3343441	et	4	main
piinlik	doc_491521501652_item	3343446	et	3	main
ei	doc_491521501652_item	3343449	et	4	main
препятствовать	doc_491521501651_item	3343457	et	2	main
обращаться	doc_491521501651_item	3343464	et	2	main
растягивать	doc_491521501651_item	3343471	et	2	main
плесневеть	doc_491521501651_item	3343473	et	2	main
kasutage	doc_491521501651_item	3343479	et	3	main
1	doc_491521501651_item	3343481	et	2	main
sõlmite	doc_491521501651_item	3343483	et	3	main
2	doc_491521501651_item	3343491	et	2	main
i	doc_491521501652_item	3343160	et	4	main
kohtlema	doc_491521501652_item	3343167	et	3	main
venima	doc_491521501652_item	3343173	et	3	main
растягиваться	doc_491521501652_item	3343175	et	2	main
царапать	doc_491521501652_item	3343179	et	2	main
kasutage	doc_491521501652_item	3343183	et	3	main
des-vormi	doc_491521501652_item	3343184	et	4	main
1	doc_491521501652_item	3343185	et	2	main
kui	doc_491521501652_item	3343186	et	3	main
sõlmite	doc_491521501652_item	3343187	et	3	main
lepingut	doc_491521501652_item	3343188	et	3	main
korterit	doc_491521501652_item	3343198	et	3	main
kaasa	doc_491521501652_item	3343202	et	4	main
korterit	doc_491521501652_item	3343204	et	3	main
üle	doc_491521501652_item	3343205	et	3	main
võtke	doc_491521501652_item	3343208	et	3	main
5	doc_491521501652_item	3343237	et	2	main
kui	doc_491521501652_item	3343238	et	3	main
ise	doc_491521501652_item	3343240	et	4	main
saate	doc_491521501652_item	3343242	et	4	main
parima	doc_491521501652_item	3343243	et	4	main
iii	doc_491521501652_item	3343251	et	4	main
viis	doc_491521501652_item	3343260	et	4	main
viis	doc_491521501652_item	3343264	et	4	main
krooni	doc_491521501652_item	3343265	et	4	main
moodustage	doc_491521501652_item	3343271	et	3	main
ühesõnalised	doc_491521501652_item	3343272	et	4	main
sünonüümid	doc_491521501652_item	3343273	et	3	main
terveks	doc_491521501652_item	3343274	et	4	main
saama	doc_491521501652_item	3343275	et	4	main
tervenema	doc_491521501652_item	3343276	et	3	main
lahkuma	doc_491521501652_item	3343286	et	3	main
товары	doc_491521501652_item	3343307	et	2	main
и	doc_491521501652_item	3343311	et	2	main
дома	doc_491521501652_item	3343326	et	2	main
maha	doc_491521501652_item	3343368	et	4	main
müüa	doc_491521501652_item	3343369	et	3	main
käitus	doc_491521501652_item	3343401	et	4	main
toit	doc_491521501652_item	3343408	et	3	main
tüdinult	doc_491521501652_item	3343413	et	4	main
maitsetult	doc_491521501652_item	3343416	et	4	main
jube	doc_491521501652_item	3343426	et	4	main
ootamatult	doc_491521501652_item	3343432	et	4	main
jookseb	doc_491521501652_item	3343434	et	3	main
hirmus	doc_491521501652_item	3343443	et	4	main
asju	doc_491521501652_item	3343451	et	3	main
i	doc_491521501651_item	3343454	et	4	main
tuvastama	doc_491521501651_item	3343458	et	3	main
догадываться	doc_491521501651_item	3343461	et	2	main
peibutama	doc_491521501651_item	3343467	et	3	main
välja	doc_491521501651_item	3343469	et	4	main
sundima	doc_491521501651_item	3343476	et	4	main
kui	doc_491521501651_item	3343482	et	3	main
tähelepanelik	doc_491521501651_item	3343486	et	4	main
lepingut	doc_491521501651_item	3343488	et	3	main
lähete	doc_491521501651_item	3343493	et	4	main
üle	doc_491521501651_item	3343495	et	3	main
abi	doc_491521501651_item	3343512	et	4	main
on	doc_491521501651_item	3343516	et	4	main
maaklerist	doc_491521501651_item	3343518	et	3	main
kui	doc_491521501651_item	3343520	et	3	main
krooni	doc_491521501651_item	3343560	et	4	main
saama	doc_491521501651_item	3343570	et	4	main
гоняться	doc_491521501651_item	3343577	et	2	main
jälitama	doc_491521501651_item	3343578	et	3	main
lahkuma	doc_491521501651_item	3343584	et	3	main
pakkuti	doc_491521501651_item	3343593	et	4	main
lasti	doc_491521501651_item	3343597	et	4	main
osteti	doc_491521501651_item	3343599	et	3	main
teil	doc_491521501651_item	3343633	et	4	main
постоянные	doc_491521501651_item	3343640	et	2	main
lõvi	doc_491521501651_item	3343672	et	4	main
tõlkige	doc_491521501652_item	3343161	et	3	main
umbusklik	doc_491521501652_item	3343169	et	3	main
вытягиваться	doc_491521501652_item	3343174	et	2	main
принуждать	doc_491521501652_item	3343181	et	2	main
2	doc_491521501652_item	3343195	et	2	main
kui	doc_491521501652_item	3343196	et	3	main
lähete	doc_491521501652_item	3343197	et	4	main
vaatama	doc_491521501652_item	3343206	et	3	main
kaasa	doc_491521501652_item	3343209	et	4	main
asjatundja	doc_491521501652_item	3343210	et	4	main
3	doc_491521501652_item	3343211	et	2	main
kui	doc_491521501652_item	3343212	et	3	main
suhtlete	doc_491521501652_item	3343213	et	3	main
ametnikega	doc_491521501652_item	3343214	et	3	main
on	doc_491521501652_item	3343215	et	4	main
abi	doc_491521501652_item	3343216	et	4	main
maaklerist	doc_491521501652_item	3343217	et	3	main
ametnikega	doc_491521501652_item	3343218	et	3	main
suheldes	doc_491521501652_item	3343219	et	3	main
on	doc_491521501652_item	3343220	et	4	main
abi	doc_491521501652_item	3343221	et	4	main
4	doc_491521501652_item	3343223	et	2	main
maaklerist	doc_491521501652_item	3343222	et	3	main
kui	doc_491521501652_item	3343224	et	3	main
ootate	doc_491521501652_item	3343225	et	3	main
pakkumisi	doc_491521501652_item	3343226	et	4	main
olge	doc_491521501652_item	3343227	et	3	main
ka	doc_491521501652_item	3343228	et	3	main
ise	doc_491521501652_item	3343229	et	4	main
aktiivne	doc_491521501652_item	3343230	et	3	main
pakkumisi	doc_491521501652_item	3343231	et	4	main
oodates	doc_491521501652_item	3343232	et	3	main
olge	doc_491521501652_item	3343233	et	3	main
ise	doc_491521501652_item	3343235	et	4	main
teete	doc_491521501652_item	3343239	et	3	main
moodustage	doc_491521501652_item	3343252	et	3	main
liitsõnad	doc_491521501652_item	3343253	et	3	main
poolteist	doc_491521501652_item	3343254	et	4	main
meetrit	doc_491521501652_item	3343255	et	3	main
taga	doc_491521501652_item	3343280	et	4	main
ajama	doc_491521501652_item	3343281	et	4	main
saama	doc_491521501652_item	3343283	et	4	main
v	doc_491521501652_item	3343287	et	4	main
tehti	doc_491521501652_item	3343289	et	3	main
lugema	doc_491521501652_item	3343292	et	4	main
loeti	doc_491521501652_item	3343293	et	3	main
vi	doc_491521501652_item	3343304	et	4	main
быстро	doc_491521501652_item	3343312	et	2	main
mõned	doc_491521501652_item	3343314	et	3	main
on	doc_491521501652_item	3343316	et	4	main
ebakvaliteetsed	doc_491521501652_item	3343317	et	3	main
ning	doc_491521501652_item	3343318	et	3	main
lähevad	doc_491521501652_item	3343319	et	3	main
спокойно	doc_491521501652_item	3343327	et	2	main
kodus	doc_491521501652_item	3343333	et	4	main
rahulikult	doc_491521501652_item	3343334	et	4	main
kataloogi	doc_491521501652_item	3343335	et	4	main
uurida	doc_491521501652_item	3343336	et	3	main
постоянные	doc_491521501652_item	3343337	et	2	main
клиенты	doc_491521501652_item	3343338	et	2	main
имеют	doc_491521501652_item	3343339	et	2	main
право	doc_491521501652_item	3343340	et	2	main
покупать	doc_491521501652_item	3343341	et	2	main
товар	doc_491521501652_item	3343342	et	2	main
в	doc_491521501652_item	3343343	et	2	main
рассрочку	doc_491521501652_item	3343344	et	2	main
püsiklientidel	doc_491521501652_item	3343345	et	3	main
on	doc_491521501652_item	3343346	et	4	main
võimalus	doc_491521501652_item	3343347	et	3	main
osta	doc_491521501652_item	3343348	et	4	main
kaupu	doc_491521501652_item	3343349	et	3	main
järelmaksuga	doc_491521501652_item	3343350	et	3	main
vii	doc_491521501652_item	3343351	et	4	main
tõmmake	doc_491521501652_item	3343352	et	3	main
maha	doc_491521501652_item	3343353	et	4	main
alla	doc_491521501652_item	3343354	et	3	main
valed	doc_491521501652_item	3343355	et	3	main
sõnad	doc_491521501652_item	3343356	et	4	main
seda	doc_491521501652_item	3343357	et	3	main
maja	doc_491521501652_item	3343358	et	4	main
kerkibkaasnebhaldab	doc_491521501652_item	3343359	et	4	main
maakler	doc_491521501652_item	3343361	et	3	main
lõvi	doc_491521501652_item	3343370	et	4	main
neiu	doc_491521501652_item	3343400	et	4	main
kaupa	doc_491521501652_item	3343406	et	4	main
isuäratavalt	doc_491521501652_item	3343412	et	4	main
õigesse	doc_491521501652_item	3343422	et	3	main
vormi	doc_491521501652_item	3343423	et	4	main
see	doc_491521501652_item	3343424	et	3	main
näeb	doc_491521501652_item	3343425	et	3	main
koer	doc_491521501652_item	3343433	et	3	main
on	doc_491521501652_item	3343444	et	4	main
piinlik	doc_491521501652_item	3343445	et	3	main
peale	doc_491521501652_item	3343373	et	4	main
tulemaligi	doc_491521501652_item	3343375	et	4	main
hiilima	doc_491521501652_item	3343376	et	3	main
käimatoime	doc_491521501652_item	3343374	et	4	main
toote	doc_491521501652_item	3343377	et	4	main
kasutusjuhendis	doc_491521501652_item	3343378	et	3	main
on	doc_491521501652_item	3343379	et	4	main
mõned	doc_491521501652_item	3343380	et	3	main
üleolevadeksitavadkehtivad	doc_491521501652_item	3343381	et	2	main
kohad	doc_491521501652_item	3343382	et	4	main
artiklid	doc_491521501652_item	3343383	et	3	main
kahjustasid	doc_491521501652_item	3343384	et	4	main
firma	doc_491521501652_item	3343385	et	4	main
olemustmainetpuänti	doc_491521501652_item	3343386	et	2	main
viii	doc_491521501652_item	3343387	et	4	main
kirjutage	doc_491521501652_item	3343388	et	3	main
lünka	doc_491521501652_item	3343389	et	4	main
sobiv	doc_491521501652_item	3343390	et	4	main
määrsõna	doc_491521501652_item	3343391	et	4	main
inimesed	doc_491521501652_item	3343392	et	3	main
seisid	doc_491521501652_item	3343393	et	4	main
tüdinult	doc_491521501652_item	3343394	et	4	main
järjekorras	doc_491521501652_item	3343395	et	3	main
ta	doc_491521501652_item	3343396	et	4	main
riietub	doc_491521501652_item	3343397	et	3	main
üsna	doc_491521501652_item	3343398	et	3	main
pakkus	doc_491521501652_item	3343404	et	3	main
oma	doc_491521501652_item	3343405	et	4	main
väljakutsuvalt	doc_491521501652_item	3343414	et	4	main
ix	doc_491521501652_item	3343417	et	4	main
külm	doc_491521501652_item	3343429	et	3	main
lahtine	doc_491521501652_item	3343435	et	3	main
hirmus	doc_491521501652_item	3343442	et	4	main
hoia	doc_491521501652_item	3343450	et	4	main
inimesed	doc_491521501652_item	3343448	et	3	main
korras	doc_491521501652_item	3343452	et	4	main
kontrolltöö	doc_491521501651_item	3343453	et	4	main
kohtlema	doc_491521501651_item	3343463	et	3	main
неверующий	doc_491521501651_item	3343466	et	2	main
venima	doc_491521501651_item	3343470	et	3	main
царапать	doc_491521501651_item	3343475	et	2	main
des-vormi	doc_491521501651_item	3343480	et	4	main
lepingut	doc_491521501651_item	3343484	et	3	main
solmites	doc_491521501651_item	3343487	et	4	main
olge	doc_491521501651_item	3343489	et	3	main
vaatama	doc_491521501651_item	3343496	et	3	main
kaasa	doc_491521501651_item	3343505	et	4	main
ametnikega	doc_491521501651_item	3343515	et	3	main
abi	doc_491521501651_item	3343517	et	4	main
4	doc_491521501651_item	3343519	et	2	main
ootate	doc_491521501651_item	3343521	et	3	main
tundi	doc_491521501651_item	3343553	et	4	main
kahekümnendaruutmetri	doc_491521501651_item	3343564	et	4	main
iv	doc_491521501651_item	3343565	et	4	main
moodustage	doc_491521501651_item	3343566	et	3	main
ühesõnalised	doc_491521501651_item	3343567	et	4	main
sünonüümid	doc_491521501651_item	3343568	et	3	main
panema	doc_491521501651_item	3343573	et	3	main
lisama	doc_491521501651_item	3343574	et	3	main
aru	doc_491521501651_item	3343579	et	4	main
saama	doc_491521501651_item	3343580	et	4	main
taipama	doc_491521501651_item	3343581	et	3	main
nõudma	doc_491521501651_item	3343594	et	3	main
tootedetel	doc_491521501651_item	3343613	et	4	main
каталог	doc_491521501651_item	3343632	et	2	main
on	doc_491521501651_item	3343634	et	4	main
rahulikult	doc_491521501651_item	3343636	et	4	main
katalogi	doc_491521501651_item	3343637	et	4	main
kodus	doc_491521501651_item	3343638	et	4	main
üritada	doc_491521501651_item	3343639	et	3	main
vii	doc_491521501651_item	3343653	et	4	main
alla	doc_491521501651_item	3343656	et	3	main
korteriühisyu	doc_491521501651_item	3343662	et	4	main
maakler	doc_491521501651_item	3343663	et	3	main
lasi	doc_491521501651_item	3343664	et	4	main
kordanägi	doc_491521501651_item	3343666	et	2	main
vaeva	doc_491521501651_item	3343667	et	4	main
et	doc_491521501651_item	3343668	et	3	main
korterit	doc_491521501651_item	3343669	et	3	main
toote	doc_491521501651_item	3343679	et	4	main
üleolevadeksitavadkehtivad	doc_491521501651_item	3343683	et	2	main
artiklid	doc_491521501651_item	3343685	et	3	main
kahjustasid	doc_491521501651_item	3343686	et	4	main
firma	doc_491521501651_item	3343687	et	4	main
olemustmainetpuänti	doc_491521501651_item	3343688	et	2	main
sobiv	doc_491521501651_item	3343692	et	4	main
neiu	doc_491521501651_item	3343702	et	4	main
käitus	doc_491521501651_item	3343703	et	4	main
oma	doc_491521501651_item	3343707	et	4	main
pealetükkivalt	doc_491521501651_item	3343709	et	4	main
toit	doc_491521501651_item	3343710	et	3	main
hirm	doc_491521501651_item	3343745	et	3	main
on	doc_491521501651_item	3343746	et	4	main
piinlik	doc_491521501651_item	3343747	et	3	main
inimesed	doc_491521501651_item	3343750	et	3	main
ei	doc_491521501651_item	3343751	et	4	main
hoia	doc_491521501651_item	3343752	et	4	main
asju	doc_491521501651_item	3343753	et	3	main
korras	doc_491521501651_item	3343754	et	4	main
tõlkige	doc_491521501651_item	3343455	et	3	main
taipama	doc_491521501651_item	3343460	et	3	main
привлекать	doc_491521501651_item	3343468	et	2	main
hallitama	doc_491521501651_item	3343472	et	3	main
küünistama	doc_491521501651_item	3343474	et	3	main
принуждать	doc_491521501651_item	3343477	et	2	main
tähelepanelik	doc_491521501651_item	3343490	et	4	main
asjatundja	doc_491521501651_item	3343499	et	4	main
vaatama	doc_491521501651_item	3343503	et	3	main
asjatundja	doc_491521501651_item	3343506	et	4	main
kui	doc_491521501651_item	3343508	et	3	main
suhtlete	doc_491521501651_item	3343509	et	3	main
suheldes	doc_491521501651_item	3343514	et	3	main
pakkumisi	doc_491521501651_item	3343522	et	4	main
olge	doc_491521501651_item	3343523	et	3	main
ka	doc_491521501651_item	3343524	et	3	main
ise	doc_491521501651_item	3343525	et	4	main
aktiivne	doc_491521501651_item	3343526	et	3	main
oodates	doc_491521501651_item	3343527	et	3	main
pakkumisi	doc_491521501651_item	3343528	et	4	main
olge	doc_491521501651_item	3343529	et	3	main
ka	doc_491521501651_item	3343530	et	3	main
ise	doc_491521501651_item	3343531	et	4	main
aktiivne	doc_491521501651_item	3343532	et	3	main
5	doc_491521501651_item	3343533	et	2	main
kui	doc_491521501651_item	3343534	et	3	main
teete	doc_491521501651_item	3343535	et	3	main
ise	doc_491521501651_item	3343536	et	4	main
remonti	doc_491521501651_item	3343537	et	4	main
saate	doc_491521501651_item	3343538	et	4	main
parima	doc_491521501651_item	3343539	et	4	main
tulemuse	doc_491521501651_item	3343540	et	3	main
tehtes	doc_491521501651_item	3343541	et	3	main
ise	doc_491521501651_item	3343542	et	4	main
remonti	doc_491521501651_item	3343543	et	4	main
saate	doc_491521501651_item	3343544	et	4	main
parima	doc_491521501651_item	3343545	et	4	main
tulemuse	doc_491521501651_item	3343546	et	3	main
iii	doc_491521501651_item	3343547	et	4	main
moodustage	doc_491521501651_item	3343548	et	3	main
liitsõnad	doc_491521501651_item	3343549	et	3	main
poolteist	doc_491521501651_item	3343550	et	4	main
meetrit	doc_491521501651_item	3343551	et	3	main
kuus	doc_491521501651_item	3343552	et	4	main
korterit	doc_491521501651_item	3343494	et	3	main
võtke	doc_491521501651_item	3343497	et	3	main
võtke	doc_491521501651_item	3343504	et	3	main
3	doc_491521501651_item	3343507	et	2	main
ametnikega	doc_491521501651_item	3343510	et	3	main
on	doc_491521501651_item	3343511	et	4	main
sada	doc_491521501651_item	3343558	et	4	main
viis	doc_491521501651_item	3343559	et	4	main
juurde	doc_491521501651_item	3343572	et	4	main
taga	doc_491521501651_item	3343575	et	4	main
ajama	doc_491521501651_item	3343576	et	4	main
minema	doc_491521501651_item	3343583	et	3	main
tehti	doc_491521501651_item	3343587	et	3	main
saatma	doc_491521501651_item	3343588	et	3	main
saadeti	doc_491521501651_item	3343589	et	3	main
lugema	doc_491521501651_item	3343590	et	4	main
loeti	doc_491521501651_item	3343591	et	3	main
pakkuma	doc_491521501651_item	3343592	et	3	main
качество	doc_491521501651_item	3343608	et	2	main
быстро	doc_491521501651_item	3343610	et	2	main
on	doc_491521501651_item	3343614	et	4	main
väga	doc_491521501651_item	3343615	et	3	main
väga	doc_491521501651_item	3343620	et	3	main
kiiresti	doc_491521501651_item	3343621	et	3	main
maha	doc_491521501651_item	3343655	et	4	main
valed	doc_491521501651_item	3343657	et	3	main
seda	doc_491521501651_item	3343659	et	3	main
maha	doc_491521501651_item	3343670	et	4	main
müüa	doc_491521501651_item	3343671	et	3	main
tulemaligi	doc_491521501651_item	3343677	et	4	main
on	doc_491521501651_item	3343681	et	4	main
pakkus	doc_491521501651_item	3343706	et	3	main
viis	doc_491521501651_item	3343555	et	4	main
liiget	doc_491521501651_item	3343556	et	3	main
viieliige	doc_491521501651_item	3343557	et	4	main
kakskümmend	doc_491521501651_item	3343562	et	4	main
ruutmeetrit	doc_491521501651_item	3343563	et	3	main
terveks	doc_491521501651_item	3343569	et	4	main
ära	doc_491521501651_item	3343582	et	4	main
v	doc_491521501651_item	3343585	et	4	main
nõuti	doc_491521501651_item	3343595	et	3	main
ostma	doc_491521501651_item	3343598	et	3	main
vi	doc_491521501651_item	3343602	et	4	main
halva	doc_491521501651_item	3343616	et	4	main
kvaliteet	doc_491521501651_item	3343617	et	3	main
ja	doc_491521501651_item	3343618	et	3	main
lähevad	doc_491521501651_item	3343622	et	3	main
purunevad	doc_491521501651_item	3343624	et	4	main
вас	doc_491521501651_item	3343626	et	2	main
возможность	doc_491521501651_item	3343628	et	2	main
спокойно	doc_491521501651_item	3343630	et	2	main
клиенты	doc_491521501651_item	3343641	et	2	main
право	doc_491521501651_item	3343643	et	2	main
покупать	doc_491521501651_item	3343644	et	2	main
в	doc_491521501651_item	3343646	et	2	main
товар	doc_491521501651_item	3343645	et	2	main
рассрочку	doc_491521501651_item	3343647	et	2	main
püsikliendid	doc_491521501651_item	3343648	et	3	main
võivad	doc_491521501651_item	3343649	et	4	main
osta	doc_491521501651_item	3343650	et	4	main
kaupa	doc_491521501651_item	3343651	et	4	main
järelmaksuga	doc_491521501651_item	3343652	et	3	main
имеют	doc_491521501651_item	3343606	et	2	main
плохое	doc_491521501651_item	3343607	et	2	main
и	doc_491521501651_item	3343609	et	2	main
ломаются	doc_491521501651_item	3343611	et	2	main
mõnedel	doc_491521501651_item	3343612	et	3	main
nad	doc_491521501651_item	3343619	et	3	main
katki	doc_491521501651_item	3343623	et	4	main
у	doc_491521501651_item	3343625	et	2	main
есть	doc_491521501651_item	3343627	et	2	main
дома	doc_491521501651_item	3343629	et	2	main
изучить	doc_491521501651_item	3343631	et	2	main
võimalus	doc_491521501651_item	3343635	et	3	main
имеют	doc_491521501651_item	3343642	et	2	main
tõmmake	doc_491521501651_item	3343654	et	3	main
sõnad	doc_491521501651_item	3343658	et	4	main
maja	doc_491521501651_item	3343660	et	4	main
läbiajas	doc_491521501651_item	3343665	et	3	main
käimatoime	doc_491521501651_item	3343676	et	4	main
kasutusjuhendis	doc_491521501651_item	3343680	et	3	main
kohad	doc_491521501651_item	3343684	et	4	main
ta	doc_491521501651_item	3343698	et	4	main
riietub	doc_491521501651_item	3343699	et	3	main
üsna	doc_491521501651_item	3343700	et	3	main
müüja	doc_491521501651_item	3343705	et	4	main
kaupa	doc_491521501651_item	3343708	et	4	main
lõhnas	doc_491521501651_item	3343711	et	4	main
kui	doc_491521501651_item	3343749	et	3	main
kerkibkaasnebhaldab	doc_491521501651_item	3343661	et	4	main
hiilima	doc_491521501651_item	3343678	et	3	main
mõned	doc_491521501651_item	3343682	et	3	main
lünka	doc_491521501651_item	3343691	et	4	main
määrsõna	doc_491521501651_item	3343693	et	4	main
inimesed	doc_491521501651_item	3343694	et	3	main
seisid	doc_491521501651_item	3343695	et	4	main
tüdinult	doc_491521501651_item	3343696	et	4	main
järjekorras	doc_491521501651_item	3343697	et	3	main
väljakutsuvalt	doc_491521501651_item	3343704	et	4	main
sõnad	doc_491521501651_item	3343713	et	4	main
isuäratavalt	doc_491521501651_item	3343714	et	4	main
tüdinult	doc_491521501651_item	3343715	et	4	main
väljakutsuvalt	doc_491521501651_item	3343716	et	4	main
pealetükkivalt	doc_491521501651_item	3343717	et	4	main
maitsetult	doc_491521501651_item	3343718	et	4	main
ix	doc_491521501651_item	3343719	et	4	main
pange	doc_491521501651_item	3343720	et	4	main
sulgudes	doc_491521501651_item	3343721	et	4	main
olevad	doc_491521501651_item	3343722	et	4	main
sõnad	doc_491521501651_item	3343723	et	4	main
õigesse	doc_491521501651_item	3343724	et	3	main
vormi	doc_491521501651_item	3343725	et	4	main
see	doc_491521501651_item	3343726	et	3	main
näeb	doc_491521501651_item	3343727	et	3	main
jube	doc_491521501651_item	3343728	et	4	main
jubedamaks	doc_491521501651_item	3343729	et	4	main
välja	doc_491521501651_item	3343730	et	4	main
külm	doc_491521501651_item	3343731	et	3	main
tuli	doc_491521501651_item	3343732	et	4	main
ootamatu	doc_491521501651_item	3343733	et	4	main
ootamatult	doc_491521501651_item	3343734	et	4	main
koer	doc_491521501651_item	3343735	et	3	main
jookseb	doc_491521501651_item	3343736	et	3	main
lahtine	doc_491521501651_item	3343737	et	3	main
lahtise	doc_491521501651_item	3343738	et	3	main
ringi	doc_491521501651_item	3343739	et	4	main
see	doc_491521501651_item	3343740	et	3	main
juhtum	doc_491521501651_item	3343741	et	3	main
oli	doc_491521501651_item	3343742	et	3	main
lihtsalt	doc_491521501651_item	3343743	et	4	main
hakkas	doc_491521501651_item	3343673	et	3	main
saagile	doc_491521501651_item	3343674	et	3	main
peale	doc_491521501651_item	3343675	et	4	main
viii	doc_491521501651_item	3343689	et	4	main
kirjutage	doc_491521501651_item	3343690	et	3	main
maitsetult	doc_491521501651_item	3343701	et	4	main
isuäratavalt	doc_491521501651_item	3343712	et	4	main
piinlik	doc_491521501651_item	3343748	et	3	main
hirmus	doc_491521501651_item	3343744	et	4	main
kontrolltöö	doc_491521501657_item	3350024	et	4	main
tõlkige	doc_491521501657_item	3350026	et	3	main
takistama	doc_491521501657_item	3350027	et	3	main
tuvastama	doc_491521501657_item	3350029	et	3	main
догадываться	doc_491521501657_item	3350031	et	2	main
kohtlema	doc_491521501657_item	3350033	et	3	main
приманивать	doc_491521501657_item	3350038	et	2	main
välja	doc_491521501657_item	3350039	et	4	main
venima	doc_491521501657_item	3350040	et	3	main
царапать	doc_491521501657_item	3350045	et	2	main
заставлять	doc_491521501657_item	3350047	et	2	main
kasutage	doc_491521501657_item	3350049	et	3	main
1	doc_491521501657_item	3350051	et	2	main
kui	doc_491521501657_item	3350052	et	3	main
sõlmite	doc_491521501657_item	3350053	et	3	main
lepingut	doc_491521501657_item	3350054	et	3	main
olge	doc_491521501657_item	3350055	et	3	main
tähelepanelik	doc_491521501657_item	3350056	et	4	main
lepingut	doc_491521501657_item	3350057	et	3	main
2	doc_491521501657_item	3350061	et	2	main
on	doc_491521501657_item	3350081	et	4	main
on	doc_491521501657_item	3350086	et	4	main
abi	doc_491521501657_item	3350087	et	4	main
maaklerist	doc_491521501657_item	3350088	et	3	main
kui	doc_491521501657_item	3350090	et	3	main
ootate	doc_491521501657_item	3350091	et	3	main
pakkumisi	doc_491521501657_item	3350092	et	4	main
olge	doc_491521501657_item	3350093	et	3	main
ka	doc_491521501657_item	3350094	et	3	main
remonti	doc_491521501657_item	3350111	et	4	main
saate	doc_491521501657_item	3350114	et	4	main
parima	doc_491521501657_item	3350115	et	4	main
tulemuse	doc_491521501657_item	3350116	et	3	main
poolteist	doc_491521501657_item	3350120	et	4	main
плесневеть	doc_491521501657_item	3350043	et	2	main
ii	doc_491521501657_item	3350048	et	4	main
asjatundja	doc_491521501657_item	3350076	et	4	main
suhtlete	doc_491521501657_item	3350079	et	3	main
maaklerist	doc_491521501657_item	3350083	et	3	main
olge	doc_491521501657_item	3350099	et	3	main
5	doc_491521501657_item	3350103	et	2	main
remonti	doc_491521501657_item	3350107	et	4	main
parima	doc_491521501657_item	3350109	et	4	main
tulemuse	doc_491521501657_item	3350110	et	3	main
iii	doc_491521501657_item	3350117	et	4	main
sada	doc_491521501657_item	3350129	et	4	main
krooni	doc_491521501657_item	3350131	et	4	main
ühesõnalised	doc_491521501657_item	3350138	et	4	main
juurde	doc_491521501657_item	3350143	et	4	main
lisama	doc_491521501657_item	3350145	et	3	main
ajama	doc_491521501657_item	3350147	et	4	main
saama	doc_491521501657_item	3350150	et	4	main
saadeti	doc_491521501657_item	3350159	et	3	main
loeti	doc_491521501657_item	3350161	et	3	main
pakuti	doc_491521501657_item	3350163	et	3	main
nõuti	doc_491521501657_item	3350165	et	3	main
изучить	doc_491521501657_item	3350198	et	2	main
on	doc_491521501657_item	3350201	et	4	main
valed	doc_491521501657_item	3350224	et	3	main
i	doc_491521501657_item	3350025	et	4	main
taipama	doc_491521501657_item	3350030	et	3	main
umbusklik	doc_491521501657_item	3350035	et	3	main
küünistama	doc_491521501657_item	3350044	et	3	main
olge	doc_491521501657_item	3350059	et	3	main
kui	doc_491521501657_item	3350062	et	3	main
ise	doc_491521501657_item	3350095	et	4	main
aktiivne	doc_491521501657_item	3350096	et	3	main
pakkumisi	doc_491521501657_item	3350097	et	4	main
oodates	doc_491521501657_item	3350098	et	3	main
kui	doc_491521501657_item	3350104	et	3	main
iv	doc_491521501657_item	3350136	et	4	main
terveks	doc_491521501657_item	3350140	et	4	main
v	doc_491521501657_item	3350155	et	4	main
mida	doc_491521501657_item	3350156	et	4	main
tehti	doc_491521501657_item	3350157	et	3	main
nõudma	doc_491521501657_item	3350164	et	3	main
lasti	doc_491521501657_item	3350167	et	4	main
дома	doc_491521501657_item	3350196	et	2	main
seda	doc_491521501657_item	3350226	et	3	main
kerkibkaasnebhaldab	doc_491521501657_item	3350228	et	4	main
korteriühisyu	doc_491521501657_item	3350229	et	4	main
maakler	doc_491521501657_item	3350230	et	3	main
peale	doc_491521501657_item	3350242	et	4	main
kasutusjuhendis	doc_491521501657_item	3350247	et	3	main
üleolevadeksitavadkehtivad	doc_491521501657_item	3350250	et	2	main
artiklid	doc_491521501657_item	3350252	et	3	main
kahjustasid	doc_491521501657_item	3350253	et	4	main
määrsõna	doc_491521501657_item	3350260	et	4	main
inimesed	doc_491521501657_item	3350261	et	3	main
pakkus	doc_491521501657_item	3350273	et	3	main
sõnad	doc_491521501657_item	3350280	et	4	main
isuäratavalt	doc_491521501657_item	3350281	et	4	main
tüdinult	doc_491521501657_item	3350282	et	4	main
hallitama	doc_491521501657_item	3350042	et	3	main
sõlmides	doc_491521501657_item	3350058	et	4	main
kaasa	doc_491521501657_item	3350075	et	4	main
kui	doc_491521501657_item	3350078	et	3	main
4	doc_491521501657_item	3350089	et	2	main
ka	doc_491521501657_item	3350100	et	3	main
aktiivne	doc_491521501657_item	3350102	et	3	main
teete	doc_491521501657_item	3350105	et	3	main
ise	doc_491521501657_item	3350112	et	4	main
tehes	doc_491521501657_item	3350113	et	3	main
liitsõnad	doc_491521501657_item	3350119	et	3	main
viis	doc_491521501657_item	3350130	et	4	main
kahekümnemeetriline	doc_491521501657_item	3350135	et	4	main
saama	doc_491521501657_item	3350141	et	4	main
tervenema	doc_491521501657_item	3350142	et	3	main
panema	doc_491521501657_item	3350144	et	3	main
taga	doc_491521501657_item	3350146	et	4	main
aru	doc_491521501657_item	3350149	et	4	main
taipama	doc_491521501657_item	3350151	et	3	main
ära	doc_491521501657_item	3350152	et	4	main
minema	doc_491521501657_item	3350153	et	3	main
lahkuma	doc_491521501657_item	3350154	et	3	main
tõlkige	doc_491521501657_item	3350173	et	3	main
товары	doc_491521501657_item	3350175	et	2	main
плохое	doc_491521501657_item	3350177	et	2	main
и	doc_491521501657_item	3350179	et	2	main
препятствовать	doc_491521501657_item	3350028	et	2	main
соображать	doc_491521501657_item	3350032	et	2	main
обращаться	doc_491521501657_item	3350034	et	2	main
недоверчивый	doc_491521501657_item	3350036	et	2	main
peibutama	doc_491521501657_item	3350037	et	3	main
растягиваться	doc_491521501657_item	3350041	et	2	main
sundima	doc_491521501657_item	3350046	et	4	main
des-vormi	doc_491521501657_item	3350050	et	4	main
tähelepanelik	doc_491521501657_item	3350060	et	4	main
lähete	doc_491521501657_item	3350063	et	4	main
korterit	doc_491521501657_item	3350064	et	3	main
üle	doc_491521501657_item	3350065	et	3	main
vaatama	doc_491521501657_item	3350066	et	3	main
võtke	doc_491521501657_item	3350067	et	3	main
kaasa	doc_491521501657_item	3350068	et	4	main
asjatundja	doc_491521501657_item	3350069	et	4	main
korterit	doc_491521501657_item	3350070	et	3	main
üle	doc_491521501657_item	3350071	et	3	main
vaatama	doc_491521501657_item	3350072	et	3	main
minnes	doc_491521501657_item	3350073	et	3	main
võtke	doc_491521501657_item	3350074	et	3	main
3	doc_491521501657_item	3350077	et	2	main
ametnikega	doc_491521501657_item	3350080	et	3	main
abi	doc_491521501657_item	3350082	et	4	main
ametnikega	doc_491521501657_item	3350084	et	3	main
suheldes	doc_491521501657_item	3350085	et	3	main
ise	doc_491521501657_item	3350101	et	4	main
ise	doc_491521501657_item	3350106	et	4	main
saate	doc_491521501657_item	3350108	et	4	main
moodustage	doc_491521501657_item	3350118	et	3	main
meetrit	doc_491521501657_item	3350121	et	3	main
kuus	doc_491521501657_item	3350123	et	4	main
tundi	doc_491521501657_item	3350124	et	4	main
viis	doc_491521501657_item	3350126	et	4	main
liiget	doc_491521501657_item	3350127	et	3	main
sajaviiekroonine	doc_491521501657_item	3350132	et	4	main
moodustage	doc_491521501657_item	3350137	et	3	main
lugema	doc_491521501657_item	3350160	et	4	main
laskma	doc_491521501657_item	3350166	et	3	main
ostma	doc_491521501657_item	3350168	et	3	main
есть	doc_491521501657_item	3350194	et	2	main
каталог	doc_491521501657_item	3350199	et	2	main
pooleteistmeetriline	doc_491521501657_item	3350122	et	4	main
kuuetunnine	doc_491521501657_item	3350125	et	4	main
viieliikmeline	doc_491521501657_item	3350128	et	4	main
kakskümmend	doc_491521501657_item	3350133	et	4	main
ruutmeetrit	doc_491521501657_item	3350134	et	3	main
sünonüümid	doc_491521501657_item	3350139	et	3	main
jälgima	doc_491521501657_item	3350148	et	4	main
saatma	doc_491521501657_item	3350158	et	3	main
pakkuma	doc_491521501657_item	3350162	et	3	main
osteti	doc_491521501657_item	3350169	et	3	main
olema	doc_491521501657_item	3350170	et	4	main
oldi	doc_491521501657_item	3350171	et	3	main
vi	doc_491521501657_item	3350172	et	4	main
некоторые	doc_491521501657_item	3350174	et	2	main
имеют	doc_491521501657_item	3350176	et	2	main
качество	doc_491521501657_item	3350178	et	2	main
быстро	doc_491521501657_item	3350180	et	2	main
mõnedel	doc_491521501657_item	3350182	et	3	main
kaupadel	doc_491521501657_item	3350183	et	3	main
on	doc_491521501657_item	3350184	et	4	main
halb	doc_491521501657_item	3350185	et	3	main
kvaliteet	doc_491521501657_item	3350186	et	3	main
ja	doc_491521501657_item	3350187	et	3	main
nad	doc_491521501657_item	3350188	et	3	main
lähevad	doc_491521501657_item	3350189	et	3	main
kiiresti	doc_491521501657_item	3350190	et	3	main
katki	doc_491521501657_item	3350191	et	4	main
у	doc_491521501657_item	3350192	et	2	main
вас	doc_491521501657_item	3350193	et	2	main
возможность	doc_491521501657_item	3350195	et	2	main
teil	doc_491521501657_item	3350200	et	4	main
võimalus	doc_491521501657_item	3350202	et	3	main
uurida	doc_491521501657_item	3350204	et	3	main
kataloogi	doc_491521501657_item	3350203	et	4	main
rahulikult	doc_491521501657_item	3350205	et	4	main
kodus	doc_491521501657_item	3350206	et	4	main
постоянные	doc_491521501657_item	3350207	et	2	main
клиенты	doc_491521501657_item	3350208	et	2	main
имеют	doc_491521501657_item	3350209	et	2	main
право	doc_491521501657_item	3350210	et	2	main
покупать	doc_491521501657_item	3350211	et	2	main
товар	doc_491521501657_item	3350212	et	2	main
в	doc_491521501657_item	3350213	et	2	main
рассрочку	doc_491521501657_item	3350214	et	2	main
püsiklientidel	doc_491521501657_item	3350215	et	3	main
on	doc_491521501657_item	3350216	et	4	main
õigus	doc_491521501657_item	3350217	et	4	main
osta	doc_491521501657_item	3350219	et	4	main
järelmaksuga	doc_491521501657_item	3350220	et	3	main
kaupa	doc_491521501657_item	3350218	et	4	main
vii	doc_491521501657_item	3350221	et	4	main
tõmmake	doc_491521501657_item	3350222	et	3	main
maha	doc_491521501657_item	3350223	et	4	main
vaeva	doc_491521501657_item	3350234	et	4	main
lünka	doc_491521501657_item	3350258	et	4	main
sobiv	doc_491521501657_item	3350259	et	4	main
ta	doc_491521501657_item	3350265	et	4	main
riietub	doc_491521501657_item	3350266	et	3	main
üsna	doc_491521501657_item	3350267	et	3	main
neiu	doc_491521501657_item	3350269	et	4	main
ломаются	doc_491521501657_item	3350181	et	2	main
спокойно	doc_491521501657_item	3350197	et	2	main
sõnad	doc_491521501657_item	3350225	et	4	main
maja	doc_491521501657_item	3350227	et	4	main
läbiajas	doc_491521501657_item	3350232	et	3	main
korterit	doc_491521501657_item	3350236	et	3	main
müüa	doc_491521501657_item	3350238	et	3	main
hakkas	doc_491521501657_item	3350240	et	3	main
toote	doc_491521501657_item	3350246	et	4	main
mõned	doc_491521501657_item	3350249	et	3	main
kohad	doc_491521501657_item	3350251	et	4	main
firma	doc_491521501657_item	3350254	et	4	main
olemustmainetpuänti	doc_491521501657_item	3350255	et	2	main
seisid	doc_491521501657_item	3350262	et	4	main
müüja	doc_491521501657_item	3350272	et	4	main
oma	doc_491521501657_item	3350274	et	4	main
väljakutsuvalt	doc_491521501657_item	3350283	et	4	main
maitsetult	doc_491521501657_item	3350285	et	4	main
ix	doc_491521501657_item	3350286	et	4	main
kordanägi	doc_491521501657_item	3350233	et	2	main
et	doc_491521501657_item	3350235	et	3	main
maha	doc_491521501657_item	3350237	et	4	main
lõvi	doc_491521501657_item	3350239	et	4	main
saagile	doc_491521501657_item	3350241	et	3	main
käimatoime	doc_491521501657_item	3350243	et	4	main
viii	doc_491521501657_item	3350256	et	4	main
kirjutage	doc_491521501657_item	3350257	et	3	main
tüdinult	doc_491521501657_item	3350263	et	4	main
järjekorras	doc_491521501657_item	3350264	et	3	main
maitsetult	doc_491521501657_item	3350268	et	4	main
isuäratavalt	doc_491521501657_item	3350279	et	4	main
sulgudes	doc_491521501657_item	3350288	et	4	main
sõnad	doc_491521501657_item	3350290	et	4	main
õigesse	doc_491521501657_item	3350291	et	3	main
vormi	doc_491521501657_item	3350292	et	4	main
see	doc_491521501657_item	3350293	et	3	main
näeb	doc_491521501657_item	3350294	et	3	main
jube	doc_491521501657_item	3350295	et	4	main
jube	doc_491521501657_item	3350296	et	4	main
välja	doc_491521501657_item	3350297	et	4	main
külm	doc_491521501657_item	3350298	et	3	main
tuli	doc_491521501657_item	3350299	et	4	main
ootamatu	doc_491521501657_item	3350300	et	4	main
ootamatult	doc_491521501657_item	3350301	et	4	main
koer	doc_491521501657_item	3350302	et	3	main
jookseb	doc_491521501657_item	3350303	et	3	main
lahtine	doc_491521501657_item	3350304	et	3	main
lahtiselt	doc_491521501657_item	3350305	et	4	main
ringi	doc_491521501657_item	3350306	et	4	main
see	doc_491521501657_item	3350307	et	3	main
juhtum	doc_491521501657_item	3350308	et	3	main
oli	doc_491521501657_item	3350309	et	3	main
lihtsalt	doc_491521501657_item	3350310	et	4	main
hirmus	doc_491521501657_item	3350311	et	4	main
hirmus	doc_491521501657_item	3350312	et	4	main
on	doc_491521501657_item	3350313	et	4	main
piinlik	doc_491521501657_item	3350314	et	3	main
piinlik	doc_491521501657_item	3350315	et	3	main
kui	doc_491521501657_item	3350316	et	3	main
inimesed	doc_491521501657_item	3350317	et	3	main
ei	doc_491521501657_item	3350318	et	4	main
hoia	doc_491521501657_item	3350319	et	4	main
asju	doc_491521501657_item	3350320	et	3	main
korras	doc_491521501657_item	3350321	et	4	main
lasi	doc_491521501657_item	3350231	et	4	main
tulemaligi	doc_491521501657_item	3350244	et	4	main
hiilima	doc_491521501657_item	3350245	et	3	main
on	doc_491521501657_item	3350248	et	4	main
väljakutsuvalt	doc_491521501657_item	3350271	et	4	main
lõhnas	doc_491521501657_item	3350278	et	4	main
pange	doc_491521501657_item	3350287	et	4	main
käitus	doc_491521501657_item	3350270	et	4	main
kaupa	doc_491521501657_item	3350275	et	4	main
pealetükkivalt	doc_491521501657_item	3350276	et	4	main
toit	doc_491521501657_item	3350277	et	3	main
pealetükkivalt	doc_491521501657_item	3350284	et	4	main
olevad	doc_491521501657_item	3350289	et	4	main
eksamitöö	doc_491521501911_item	3362282	et	4	main
laused	doc_491521501911_item	3362284	et	3	main
sõnad	doc_491521501911_item	3362285	et	4	main
on	doc_491521501911_item	3362286	et	4	main
järjekorras	doc_491521501911_item	3362288	et	3	main
homme	doc_491521501911_item	3362298	et	3	main
raekoja	doc_491521501911_item	3362301	et	3	main
vastuvõtt	doc_491521501911_item	3362303	et	3	main
sportlastele	doc_491521501911_item	3362305	et	4	main
te	doc_491521501911_item	3362308	et	4	main
võima	doc_491521501911_item	3362309	et	3	main
3	doc_491521501911_item	3362321	et	2	main
meie	doc_491521501911_item	3362338	et	4	main
sõitis	doc_491521501911_item	3362341	et	3	main
5	doc_491521501911_item	3362346	et	2	main
suur	doc_491521501911_item	3362354	et	3	main
vihmavari	doc_491521501911_item	3362355	et	4	main
6	doc_491521501911_item	3362367	et	2	main
vanasti	doc_491521501911_item	3362368	et	3	main
ja	doc_491521501911_item	3362372	et	3	main
ka	doc_491521501911_item	3362374	et	3	main
vanasti	doc_491521501911_item	3362376	et	3	main
kui	doc_491521501911_item	3362394	et	3	main
kodu	doc_491521501911_item	3362396	et	4	main
oli	doc_491521501911_item	3362398	et	3	main
trepikoja	doc_491521501911_item	3362400	et	3	main
ukse	doc_491521501911_item	3362401	et	3	main
kiri	doc_491521501911_item	3362408	et	3	main
näita	doc_491521501911_item	3362410	et	4	main
seda	doc_491521501911_item	3362412	et	3	main
9	doc_491521501911_item	3362414	et	2	main
juuli	doc_491521501911_item	3362415	et	4	main
õiges	doc_491521501911_item	3362287	et	3	main
homme	doc_491521501911_item	3362290	et	3	main
toimuma	doc_491521501911_item	3362292	et	3	main
pidulik	doc_491521501911_item	3362294	et	3	main
õhtul	doc_491521501911_item	3362299	et	3	main
pidulikul	doc_491521501911_item	3362302	et	3	main
parimatele	doc_491521501911_item	3362304	et	4	main
viima	doc_491521501911_item	3362310	et	3	main
need	doc_491521501911_item	3362311	et	3	main
palju	doc_491521501911_item	3362327	et	4	main
meie	doc_491521501911_item	3362330	et	4	main
osakond	doc_491521501911_item	3362331	et	3	main
šveits	doc_491521501911_item	3362336	et	2	main
komandeering	doc_491521501911_item	3362337	et	3	main
juhataja	doc_491521501911_item	3362340	et	4	main
nädalal	doc_491521501911_item	3362343	et	3	main
vihm	doc_491521501911_item	3362348	et	3	main
hakkama	doc_491521501911_item	3362350	et	3	main
kõik	doc_491521501911_item	3362362	et	4	main
lapsi	doc_491521501911_item	3362363	et	4	main
suuri	doc_491521501911_item	3362364	et	3	main
kodu	doc_491521501911_item	3362370	et	4	main
võid	doc_491521501911_item	3362383	et	4	main
kui	doc_491521501911_item	3362385	et	3	main
trepikoda	doc_491521501911_item	3362391	et	4	main
see	doc_491521501911_item	3362407	et	3	main
mulle	doc_491521501911_item	3362411	et	4	main
kirja	doc_491521501911_item	3362413	et	4	main
koos	doc_491521501911_item	3362419	et	4	main
sõbrad	doc_491521501911_item	3362420	et	3	main
jalgrattamatk	doc_491521501911_item	3362422	et	3	main
lõppus	doc_491521501911_item	3362424	et	4	main
lähen	doc_491521501911_item	3362425	et	3	main
ma	doc_491521501911_item	3362426	et	3	main
koos	doc_491521501911_item	3362427	et	4	main
sõpradega	doc_491521501911_item	3362428	et	3	main
huvitav	doc_491521501911_item	3362437	et	4	main
huvitavaid	doc_491521501911_item	3362446	et	4	main
festival	doc_491521501911_item	3362449	et	3	main
olin	doc_491521501911_item	3362496	et	3	main
kollased	doc_491521501911_item	3362508	et	4	main
punased	doc_491521501911_item	3362510	et	4	main
seal	doc_491521501911_item	3362512	et	4	main
tahan	doc_491521501911_item	3362522	et	3	main
sõida	doc_491521501911_item	3362523	et	4	main
1	doc_491521501911_item	3362289	et	2	main
vastuvõtt	doc_491521501911_item	3362295	et	3	main
sportlased	doc_491521501911_item	3362297	et	3	main
öö	doc_491521501911_item	3362323	et	4	main
naabrid	doc_491521501911_item	3362325	et	3	main
juures	doc_491521501911_item	3362326	et	4	main
šveitsi	doc_491521501911_item	3362344	et	2	main
kui	doc_491521501911_item	3362347	et	3	main
vihma	doc_491521501911_item	3362358	et	4	main
sadama	doc_491521501911_item	3362359	et	4	main
hakkab	doc_491521501911_item	3362360	et	3	main
jooksma	doc_491521501911_item	3362361	et	3	main
küpsetama	doc_491521501911_item	3362369	et	4	main
leib	doc_491521501911_item	3362371	et	3	main
tegema	doc_491521501911_item	3362373	et	3	main
või	doc_491521501911_item	3362375	et	4	main
küpsetama	doc_491521501911_item	3362377	et	4	main
ka	doc_491521501911_item	3362382	et	3	main
ma	doc_491521501911_item	3362386	et	3	main
jõudma	doc_491521501911_item	3362388	et	3	main
olema	doc_491521501911_item	3362389	et	4	main
lukk	doc_491521501911_item	3362393	et	3	main
ma	doc_491521501911_item	3362395	et	3	main
mina	doc_491521501911_item	3362406	et	4	main
lõpp	doc_491521501911_item	3362416	et	3	main
see	doc_491521501911_item	3362432	et	3	main
palju	doc_491521501911_item	3362444	et	4	main
igasuguseid	doc_491521501911_item	3362445	et	3	main
ja	doc_491521501911_item	3362448	et	3	main
ma	doc_491521501911_item	3362495	et	3	main
meie	doc_491521501911_item	3362497	et	4	main
on	doc_491521501911_item	3362507	et	4	main
lehed	doc_491521501911_item	3362511	et	3	main
on	doc_491521501911_item	3362513	et	4	main
palju	doc_491521501911_item	3362514	et	4	main
ole	doc_491521501911_item	3362519	et	4	main
kirjuta	doc_491521501911_item	3362283	et	4	main
toimub	doc_491521501911_item	3362300	et	3	main
2	doc_491521501911_item	3362306	et	2	main
kas	doc_491521501911_item	3362307	et	3	main
arve	doc_491521501911_item	3362312	et	4	main
pearaamatupidaja	doc_491521501911_item	3362313	et	4	main
kas	doc_491521501911_item	3362314	et	3	main
te	doc_491521501911_item	3362315	et	4	main
või	doc_491521501911_item	3362316	et	4	main
viia	doc_491521501911_item	3362317	et	3	main
need	doc_491521501911_item	3362318	et	3	main
arved	doc_491521501911_item	3362319	et	3	main
õhtu	doc_491521501911_item	3362291	et	4	main
raekoda	doc_491521501911_item	3362293	et	4	main
parimad	doc_491521501911_item	3362296	et	4	main
raamatupidajale	doc_491521501911_item	3362320	et	3	main
eile	doc_491521501911_item	3362322	et	3	main
käima	doc_491521501911_item	3362324	et	4	main
külalised	doc_491521501911_item	3362328	et	4	main
osakonna	doc_491521501911_item	3362339	et	4	main
eelmisel	doc_491521501911_item	3362342	et	3	main
sadama	doc_491521501911_item	3362349	et	4	main
jooksma	doc_491521501911_item	3362351	et	3	main
laps	doc_491521501911_item	3362353	et	4	main
kodu	doc_491521501911_item	3362378	et	4	main
leib	doc_491521501911_item	3362379	et	3	main
tegema	doc_491521501911_item	3362381	et	3	main
kodu	doc_491521501911_item	3362387	et	4	main
uks	doc_491521501911_item	3362392	et	3	main
meie	doc_491521501911_item	3362399	et	4	main
lukkus	doc_491521501911_item	3362402	et	4	main
8	doc_491521501911_item	3362403	et	2	main
palun	doc_491521501911_item	3362404	et	3	main
näitama	doc_491521501911_item	3362405	et	3	main
minema	doc_491521501911_item	3362417	et	3	main
jalgrattamatkale	doc_491521501911_item	3362430	et	3	main
suvi	doc_491521501911_item	3362433	et	3	main
üritus	doc_491521501911_item	3362438	et	4	main
festival	doc_491521501911_item	3362440	et	3	main
suvel	doc_491521501911_item	3362442	et	3	main
15-18	doc_491521501911_item	3362451	et	2	main
seal	doc_491521501911_item	3362483	et	4	main
restoraani	doc_491521501911_item	3362482	et	4	main
on	doc_491521501911_item	3362484	et	4	main
väga	doc_491521501911_item	3362485	et	3	main
erinevad	doc_491521501911_item	3362486	et	4	main
inimesed	doc_491521501911_item	3362487	et	3	main
viimasel	doc_491521501911_item	3362488	et	3	main
korral	doc_491521501911_item	3362489	et	4	main
ma	doc_491521501911_item	3362490	et	3	main
olin	doc_491521501911_item	3362491	et	3	main
4	doc_491521501911_item	3362329	et	2	main
juhataja	doc_491521501911_item	3362332	et	4	main
sõitma	doc_491521501911_item	3362333	et	3	main
eelmine	doc_491521501911_item	3362334	et	3	main
nädal	doc_491521501911_item	3362335	et	3	main
komandeeringusse	doc_491521501911_item	3362345	et	3	main
kõik	doc_491521501911_item	3362352	et	4	main
all	doc_491521501911_item	3362356	et	3	main
kui	doc_491521501911_item	3362357	et	3	main
vihmavarju	doc_491521501911_item	3362365	et	4	main
alla	doc_491521501911_item	3362366	et	3	main
ja	doc_491521501911_item	3362380	et	3	main
7	doc_491521501911_item	3362384	et	2	main
meie	doc_491521501911_item	3362390	et	4	main
jõudsin	doc_491521501911_item	3362397	et	3	main
palun	doc_491521501911_item	3362409	et	3	main
ma	doc_491521501911_item	3362418	et	3	main
norra	doc_491521501911_item	3362429	et	4	main
10	doc_491521501911_item	3362431	et	2	main
olema	doc_491521501911_item	3362434	et	4	main
palju	doc_491521501911_item	3362435	et	4	main
ja	doc_491521501911_item	3362439	et	3	main
sellel	doc_491521501911_item	3362441	et	4	main
üüritusi	doc_491521501911_item	3362447	et	4	main
kirjuta	doc_491521501911_item	3362450	et	4	main
lauset	doc_491521501911_item	3362452	et	3	main
minu	doc_491521501911_item	3362453	et	3	main
kõige	doc_491521501911_item	3362454	et	4	main
huvitavam	doc_491521501911_item	3362455	et	4	main
reis	doc_491521501911_item	3362456	et	4	main
mulle	doc_491521501911_item	3362457	et	4	main
meeldib	doc_491521501911_item	3362458	et	3	main
reisida	doc_491521501911_item	3362459	et	3	main
see	doc_491521501911_item	3362460	et	3	main
on	doc_491521501911_item	3362461	et	4	main
väga	doc_491521501911_item	3362462	et	3	main
huvitav	doc_491521501911_item	3362463	et	4	main
kui	doc_491521501911_item	3362464	et	3	main
mul	doc_491521501911_item	3362465	et	3	main
on	doc_491521501911_item	3362466	et	4	main
võimalus	doc_491521501911_item	3362467	et	3	main
siis	doc_491521501911_item	3362468	et	3	main
ma	doc_491521501911_item	3362469	et	3	main
sõidan	doc_491521501911_item	3362470	et	3	main
kuhugi	doc_491521501911_item	3362471	et	4	main
mulle	doc_491521501911_item	3362472	et	4	main
väga	doc_491521501911_item	3362473	et	3	main
meeldib	doc_491521501911_item	3362474	et	3	main
jalutada	doc_491521501911_item	3362475	et	3	main
vana	doc_491521501911_item	3362476	et	4	main
tallinnas	doc_491521501911_item	3362477	et	4	main
seal	doc_491521501911_item	3362478	et	4	main
on	doc_491521501911_item	3362479	et	4	main
palju	doc_491521501911_item	3362480	et	4	main
kauplusi	doc_491521501911_item	3362481	et	3	main
tallinnas	doc_491521501911_item	3362492	et	4	main
toilas	doc_491521501911_item	3362503	et	4	main
eriti	doc_491521501911_item	3362504	et	3	main
kaunis	doc_491521501911_item	3362505	et	4	main
pargis	doc_491521501911_item	3362506	et	3	main
rajaid	doc_491521501911_item	3362516	et	4	main
mina	doc_491521501911_item	3362517	et	4	main
sinna	doc_491521501911_item	3362524	et	3	main
norra	doc_491521501911_item	3362421	et	4	main
juuli	doc_491521501911_item	3362423	et	4	main
igasugune	doc_491521501911_item	3362436	et	3	main
oli	doc_491521501911_item	3362443	et	3	main
ükskord	doc_491521501911_item	3362494	et	3	main
ja	doc_491521501911_item	3362509	et	3	main
ei	doc_491521501911_item	3362518	et	4	main
esmaspäeval	doc_491521501911_item	3362493	et	3	main
gruppiga	doc_491521501911_item	3362498	et	4	main
ekskursioonis	doc_491521501911_item	3362499	et	3	main
toilas	doc_491521501911_item	3362500	et	4	main
sügisel	doc_491521501911_item	3362501	et	3	main
on	doc_491521501911_item	3362502	et	4	main
erinevaid	doc_491521501911_item	3362515	et	4	main
saaremaal	doc_491521501911_item	3362520	et	4	main
ma	doc_491521501911_item	3362521	et	3	main
i	doc_491521502069_item	3363002	et	4	main
umbusklik	doc_491521502069_item	3363008	et	3	main
lakkama	doc_491521502069_item	3363017	et	3	main
terveks	doc_491521502069_item	3363042	et	4	main
tervenema	doc_491521502069_item	3363044	et	3	main
jätma	doc_491521502069_item	3363046	et	3	main
hülgama	doc_491521502069_item	3363047	et	3	main
kinni	doc_491521502069_item	3363048	et	3	main
püüdma	doc_491521502069_item	3363049	et	3	main
haarama	doc_491521502069_item	3363050	et	3	main
iii	doc_491521502069_item	3363051	et	4	main
pakuti	doc_491521502069_item	3363061	et	3	main
v	doc_491521502069_item	3363110	et	4	main
kasutage	doc_491521502069_item	3363111	et	3	main
tav-kesksõna	doc_491521502069_item	3363112	et	4	main
kreemidele	doc_491521502069_item	3363113	et	3	main
toodetavad	doc_491521502069_item	3363118	et	4	main
kreemid	doc_491521502069_item	3363119	et	3	main
mida	doc_491521502069_item	3363121	et	4	main
pestakse	doc_491521502069_item	3363122	et	3	main
käsitsi	doc_491521502069_item	3363123	et	3	main
käsitsi	doc_491521502069_item	3363124	et	3	main
pestav	doc_491521502069_item	3363125	et	4	main
toit	doc_491521502069_item	3363131	et	3	main
kaupu	doc_491521502069_item	3363132	et	3	main
mida	doc_491521502069_item	3363133	et	4	main
ostetakse	doc_491521502069_item	3363134	et	3	main
avavad	doc_491521502069_item	3363145	et	4	main
peab	doc_491521502069_item	3363155	et	4	main
liigitada	doc_491521502069_item	3363176	et	3	main
järeldusi	doc_491521502069_item	3363186	et	4	main
prügi	doc_491521502069_item	3363196	et	4	main
veel	doc_491521502069_item	3363200	et	4	main
taipama	doc_491521502069_item	3363004	et	3	main
hallitama	doc_491521502069_item	3363006	et	3	main
мнительный	doc_491521502069_item	3363009	et	2	main
отходы	doc_491521502069_item	3363012	et	2	main
пассильный	doc_491521502069_item	3363016	et	2	main
эффективный	doc_491521502069_item	3363021	et	2	main
kuluma	doc_491521502069_item	3363023	et	3	main
затаскаться	doc_491521502069_item	3363024	et	2	main
долго	doc_491521502069_item	3363027	et	2	main
toime	doc_491521502069_item	3363029	et	4	main
tulema	doc_491521502069_item	3363030	et	4	main
справляться	doc_491521502069_item	3363031	et	2	main
ühesõnalised	doc_491521502069_item	3363034	et	4	main
jääma	doc_491521502069_item	3363040	et	4	main
saama	doc_491521502069_item	3363043	et	4	main
pakkuma	doc_491521502069_item	3363060	et	3	main
laskma	doc_491521502069_item	3363066	et	3	main
rääkima	doc_491521502069_item	3363070	et	3	main
teatama	doc_491521502069_item	3363072	et	4	main
niisutav	doc_491521502069_item	3363101	et	4	main
välismaal	doc_491521502069_item	3363117	et	4	main
saab	doc_491521502069_item	3363141	et	3	main
kergesti	doc_491521502069_item	3363144	et	3	main
kontrolltöö	doc_491521502069_item	3363001	et	4	main
подозрительный	doc_491521502069_item	3363010	et	2	main
pihustama	doc_491521502069_item	3363013	et	3	main
jõukohane	doc_491521502069_item	3363015	et	4	main
tõhus	doc_491521502069_item	3363020	et	4	main
что	doc_491521502069_item	3363026	et	2	main
служило	doc_491521502069_item	3363028	et	2	main
kirjutage	doc_491521502069_item	3363033	et	3	main
mida	doc_491521502069_item	3363052	et	4	main
tehti	doc_491521502069_item	3363053	et	3	main
nõudma	doc_491521502069_item	3363054	et	3	main
anti	doc_491521502069_item	3363059	et	3	main
lubati	doc_491521502069_item	3363063	et	3	main
tehti	doc_491521502069_item	3363065	et	3	main
räägiti	doc_491521502069_item	3363071	et	3	main
догадываться	doc_491521502069_item	3363005	et	2	main
плесневеть	doc_491521502069_item	3363007	et	2	main
распылять	doc_491521502069_item	3363014	et	2	main
зализывать	doc_491521502069_item	3363019	et	2	main
ära	doc_491521502069_item	3363022	et	4	main
то	doc_491521502069_item	3363025	et	2	main
haigestuma	doc_491521502069_item	3363041	et	3	main
maha	doc_491521502069_item	3363045	et	4	main
lubama	doc_491521502069_item	3363062	et	3	main
tegema	doc_491521502069_item	3363064	et	3	main
lasti	doc_491521502069_item	3363067	et	4	main
saati	doc_491521502069_item	3363069	et	3	main
šampoone	doc_491521502069_item	3363103	et	2	main
pesu	doc_491521502069_item	3363126	et	4	main
harva	doc_491521502069_item	3363135	et	4	main
endale	doc_491521502069_item	3363181	et	4	main
reostamise	doc_491521502069_item	3363185	et	4	main
мусора	doc_491521502069_item	3363193	et	2	main
разработана	doc_491521502069_item	3363195	et	2	main
возможность	doc_491521502069_item	3363234	et	2	main
tõlkige	doc_491521502069_item	3363003	et	3	main
jäätmed	doc_491521502069_item	3363011	et	3	main
лакать	doc_491521502069_item	3363018	et	2	main
ii	doc_491521502069_item	3363032	et	4	main
sünonüümid	doc_491521502069_item	3363035	et	3	main
ära	doc_491521502069_item	3363036	et	4	main
minema	doc_491521502069_item	3363037	et	3	main
lahkuma	doc_491521502069_item	3363038	et	3	main
haigeks	doc_491521502069_item	3363039	et	4	main
nõuti	doc_491521502069_item	3363055	et	3	main
ütlema	doc_491521502069_item	3363056	et	3	main
öeldi	doc_491521502069_item	3363057	et	3	main
andma	doc_491521502069_item	3363058	et	3	main
saatma	doc_491521502069_item	3363068	et	3	main
teatati	doc_491521502069_item	3363073	et	3	main
kasutage	doc_491521502069_item	3363075	et	3	main
iv	doc_491521502069_item	3363074	et	4	main
v-kesksõna	doc_491521502069_item	3363076	et	4	main
prügi	doc_491521502069_item	3363077	et	4	main
mis	doc_491521502069_item	3363078	et	4	main
tekib	doc_491521502069_item	3363079	et	3	main
kodus	doc_491521502069_item	3363080	et	4	main
kodus	doc_491521502069_item	3363081	et	4	main
tekkiv	doc_491521502069_item	3363082	et	4	main
prügi	doc_491521502069_item	3363083	et	4	main
vahenditeta	doc_491521502069_item	3363084	et	3	main
mis	doc_491521502069_item	3363085	et	4	main
värskendavad	doc_491521502069_item	3363086	et	4	main
õhku	doc_491521502069_item	3363087	et	4	main
õhku	doc_491521502069_item	3363088	et	4	main
värskendavate	doc_491521502069_item	3363089	et	4	main
vahenditega	doc_491521502069_item	3363090	et	3	main
inimest	doc_491521502069_item	3363091	et	3	main
kes	doc_491521502069_item	3363092	et	4	main
müüb	doc_491521502069_item	3363093	et	3	main
kosmeetikavahendeid	doc_491521502069_item	3363094	et	3	main
kosmeetikavahendeid	doc_491521502069_item	3363095	et	3	main
müüv	doc_491521502069_item	3363096	et	4	main
inimene	doc_491521502069_item	3363097	et	3	main
kreemiga	doc_491521502069_item	3363098	et	4	main
mis	doc_491521502069_item	3363099	et	4	main
niisutab	doc_491521502069_item	3363100	et	3	main
mis	doc_491521502069_item	3363104	et	4	main
mis	doc_491521502069_item	3363114	et	4	main
toodetakse	doc_491521502069_item	3363115	et	3	main
välismaal	doc_491521502069_item	3363116	et	4	main
pesu	doc_491521502069_item	3363120	et	4	main
kergesti	doc_491521502069_item	3363142	et	3	main
avada	doc_491521502069_item	3363143	et	3	main
maha	doc_491521502069_item	3363149	et	4	main
alla	doc_491521502069_item	3363150	et	3	main
inimesed	doc_491521502069_item	3363179	et	3	main
peaksid	doc_491521502069_item	3363180	et	4	main
kreem	doc_491521502069_item	3363102	et	3	main
ravivad	doc_491521502069_item	3363105	et	4	main
juukseid	doc_491521502069_item	3363106	et	3	main
juukseid	doc_491521502069_item	3363107	et	3	main
raviv	doc_491521502069_item	3363108	et	4	main
šampoon	doc_491521502069_item	3363109	et	2	main
toidust	doc_491521502069_item	3363127	et	4	main
mida	doc_491521502069_item	3363128	et	4	main
süüakse	doc_491521502069_item	3363129	et	3	main
söödav	doc_491521502069_item	3363130	et	4	main
harva	doc_491521502069_item	3363136	et	4	main
ostetav	doc_491521502069_item	3363137	et	4	main
kaup	doc_491521502069_item	3363138	et	3	main
kaanega	doc_491521502069_item	3363139	et	3	main
mida	doc_491521502069_item	3363140	et	4	main
koera	doc_491521502069_item	3363154	et	4	main
kordamööda	doc_491521502069_item	3363156	et	3	main
ilmtingimata	doc_491521502069_item	3363157	et	3	main
omapead	doc_491521502069_item	3363158	et	3	main
õpetama	doc_491521502069_item	3363159	et	3	main
selle	doc_491521502069_item	3363160	et	4	main
pintsaku	doc_491521502069_item	3363161	et	3	main
õmblused	doc_491521502069_item	3363162	et	3	main
käsitsevad	doc_491521502069_item	3363163	et	4	main
kisuvad	doc_491521502069_item	3363164	et	3	main
luituvad	doc_491521502069_item	3363165	et	4	main
artiklid	doc_491521502069_item	3363166	et	3	main
kahjustasid	doc_491521502069_item	3363167	et	4	main
firma	doc_491521502069_item	3363168	et	4	main
olemust	doc_491521502069_item	3363169	et	3	main
mainet	doc_491521502069_item	3363170	et	4	main
puänti	doc_491521502069_item	3363171	et	4	main
seda	doc_491521502069_item	3363172	et	3	main
plaani	doc_491521502069_item	3363173	et	4	main
on	doc_491521502069_item	3363174	et	4	main
raske	doc_491521502069_item	3363175	et	4	main
kaaned	doc_491521502069_item	3363146	et	3	main
vi	doc_491521502069_item	3363147	et	4	main
tõmmake	doc_491521502069_item	3363148	et	3	main
valed	doc_491521502069_item	3363151	et	3	main
sõnad	doc_491521502069_item	3363152	et	4	main
suurt	doc_491521502069_item	3363153	et	3	main
sisaldada	doc_491521502069_item	3363177	et	3	main
tagajärgi	doc_491521502069_item	3363187	et	4	main
tulemusi	doc_491521502069_item	3363188	et	4	main
süsteem	doc_491521502069_item	3363198	et	3	main
on	doc_491521502069_item	3363199	et	4	main
есть	doc_491521502069_item	3363233	et	2	main
каталог	doc_491521502069_item	3363238	et	2	main
teostada	doc_491521502069_item	3363178	et	3	main
ümbertöötamise	doc_491521502069_item	3363197	et	3	main
дома	doc_491521502069_item	3363235	et	2	main
rohkem	doc_491521502069_item	3363182	et	4	main
teadvustama	doc_491521502069_item	3363183	et	3	main
keskkonna	doc_491521502069_item	3363184	et	3	main
vii	doc_491521502069_item	3363189	et	4	main
tõlkige	doc_491521502069_item	3363190	et	3	main
система	doc_491521502069_item	3363191	et	2	main
переработки	doc_491521502069_item	3363192	et	2	main
не	doc_491521502069_item	3363194	et	2	main
töötamata	doc_491521502069_item	3363201	et	4	main
по	doc_491521502069_item	3363203	et	2	main
каталогу	doc_491521502069_item	3363204	et	2	main
заказывая	doc_491521502069_item	3363202	et	2	main
вы	doc_491521502069_item	3363205	et	2	main
экономите	doc_491521502069_item	3363206	et	2	main
время	doc_491521502069_item	3363207	et	2	main
kataloogi	doc_491521502069_item	3363208	et	4	main
tellides	doc_491521502069_item	3363209	et	3	main
te	doc_491521502069_item	3363210	et	4	main
säästate	doc_491521502069_item	3363211	et	3	main
aega	doc_491521502069_item	3363212	et	4	main
фирма	doc_491521502069_item	3363213	et	2	main
привлекает	doc_491521502069_item	3363214	et	2	main
firma	doc_491521502069_item	3363217	et	4	main
подарками	doc_491521502069_item	3363216	et	2	main
клиентов	doc_491521502069_item	3363215	et	2	main
meelitab	doc_491521502069_item	3363218	et	3	main
kliente	doc_491521502069_item	3363219	et	3	main
kingitustega	doc_491521502069_item	3363220	et	4	main
это	doc_491521502069_item	3363221	et	2	main
нарушает	doc_491521502069_item	3363222	et	2	main
принципы	doc_491521502069_item	3363223	et	2	main
торговли	doc_491521502069_item	3363224	et	2	main
свободного	doc_491521502069_item	3363225	et	2	main
рынка	doc_491521502069_item	3363226	et	2	main
see	doc_491521502069_item	3363227	et	3	main
sekkub	doc_491521502069_item	3363228	et	3	main
vabakaubanduse	doc_491521502069_item	3363229	et	3	main
põhimõtetesse	doc_491521502069_item	3363230	et	3	main
у	doc_491521502069_item	3363231	et	2	main
вас	doc_491521502069_item	3363232	et	2	main
спокойно	doc_491521502069_item	3363236	et	2	main
изучить	doc_491521502069_item	3363237	et	2	main
tõlkige	doc_491521502070_item	3363797	et	3	main
отходы	doc_491521502070_item	3363805	et	2	main
lakkama	doc_491521502070_item	3363809	et	3	main
ära	doc_491521502070_item	3363812	et	4	main
toime	doc_491521502070_item	3363815	et	4	main
sünonüümid	doc_491521502070_item	3363824	et	3	main
lahkuma	doc_491521502070_item	3363827	et	3	main
jääma	doc_491521502070_item	3363829	et	4	main
põdema	doc_491521502070_item	3363830	et	3	main
terveks	doc_491521502070_item	3363831	et	4	main
püüdma	doc_491521502070_item	3363837	et	3	main
nõuti	doc_491521502070_item	3363842	et	3	main
tehti	doc_491521502070_item	3363852	et	3	main
pesu	doc_491521502070_item	3363907	et	4	main
mida	doc_491521502070_item	3363915	et	4	main
vi	doc_491521502070_item	3363934	et	4	main
valed	doc_491521502070_item	3363938	et	3	main
suurt	doc_491521502070_item	3363940	et	3	main
on	doc_491521502070_item	3363986	et	4	main
каталогу	doc_491521502070_item	3363991	et	2	main
kontrolltöö	doc_491521502070_item	3363795	et	4	main
hallitama	doc_491521502070_item	3363800	et	3	main
неверующий	doc_491521502070_item	3363803	et	2	main
разбрызгивать	doc_491521502070_item	3363807	et	2	main
tulema	doc_491521502070_item	3363816	et	4	main
помощь	doc_491521502070_item	3363819	et	2	main
ii	doc_491521502070_item	3363821	et	4	main
ära	doc_491521502070_item	3363825	et	4	main
haigeks	doc_491521502070_item	3363828	et	4	main
kinni	doc_491521502070_item	3363836	et	3	main
nõudma	doc_491521502070_item	3363841	et	3	main
andi	doc_491521502070_item	3363846	et	4	main
pakuti	doc_491521502070_item	3363848	et	3	main
laskma	doc_491521502070_item	3363853	et	3	main
mis	doc_491521502070_item	3363891	et	4	main
šampoonid	doc_491521502070_item	3363896	et	2	main
tav-kesksõna	doc_491521502070_item	3363899	et	4	main
toodetakse	doc_491521502070_item	3363902	et	3	main
välismaal	doc_491521502070_item	3363904	et	4	main
toodetavad	doc_491521502070_item	3363905	et	4	main
kreemid	doc_491521502070_item	3363906	et	3	main
toidust	doc_491521502070_item	3363914	et	4	main
toit	doc_491521502070_item	3363918	et	3	main
mida	doc_491521502070_item	3363920	et	4	main
harva	doc_491521502070_item	3363922	et	4	main
kergesti	doc_491521502070_item	3363929	et	3	main
kergesti	doc_491521502070_item	3363931	et	3	main
maha	doc_491521502070_item	3363936	et	4	main
sõnad	doc_491521502070_item	3363939	et	4	main
koera	doc_491521502070_item	3363941	et	4	main
peab	doc_491521502070_item	3363942	et	4	main
kordamööda	doc_491521502070_item	3363943	et	3	main
ilmtingimata	doc_491521502070_item	3363944	et	3	main
omapead	doc_491521502070_item	3363945	et	3	main
õpetama	doc_491521502070_item	3363946	et	3	main
selle	doc_491521502070_item	3363947	et	4	main
pintsaku	doc_491521502070_item	3363948	et	3	main
õmblused	doc_491521502070_item	3363949	et	3	main
система	doc_491521502070_item	3363978	et	2	main
мусора	doc_491521502070_item	3363980	et	2	main
разработана	doc_491521502070_item	3363982	et	2	main
prügi	doc_491521502070_item	3363983	et	4	main
ümbertootmise	doc_491521502070_item	3363984	et	3	main
süsteem	doc_491521502070_item	3363985	et	3	main
по	doc_491521502070_item	3363990	et	2	main
время	doc_491521502070_item	3363994	et	2	main
tellides	doc_491521502070_item	3363996	et	3	main
säästate	doc_491521502070_item	3363998	et	3	main
vormi	doc_491521502070_item	3364042	et	4	main
see	doc_491521502070_item	3364043	et	3	main
näeb	doc_491521502070_item	3364044	et	3	main
on	doc_491521502070_item	3364048	et	4	main
vihma	doc_491521502070_item	3364058	et	4	main
hirmust	doc_491521502070_item	3364065	et	4	main
karva	doc_491521502070_item	3364066	et	4	main
vaadata	doc_491521502070_item	3364072	et	4	main
taipama	doc_491521502070_item	3363798	et	3	main
плесневеть	doc_491521502070_item	3363801	et	2	main
jäätmed	doc_491521502070_item	3363804	et	3	main
придти	doc_491521502070_item	3363817	et	2	main
пригодиться	doc_491521502070_item	3363820	et	2	main
saama	doc_491521502070_item	3363832	et	4	main
mida	doc_491521502070_item	3363839	et	4	main
andma	doc_491521502070_item	3363845	et	3	main
lubati	doc_491521502070_item	3363850	et	3	main
rääkima	doc_491521502070_item	3363857	et	3	main
kreem	doc_491521502070_item	3363889	et	3	main
šampoone	doc_491521502070_item	3363890	et	2	main
ravivad	doc_491521502070_item	3363895	et	4	main
kasutage	doc_491521502070_item	3363898	et	3	main
käsitsi	doc_491521502070_item	3363911	et	3	main
kaupu	doc_491521502070_item	3363919	et	3	main
saab	doc_491521502070_item	3363928	et	3	main
avada	doc_491521502070_item	3363930	et	3	main
переработки	doc_491521502070_item	3363979	et	2	main
не	doc_491521502070_item	3363981	et	2	main
заказывая	doc_491521502070_item	3363989	et	2	main
kataloogi	doc_491521502070_item	3363995	et	4	main
oma	doc_491521502070_item	3363999	et	4	main
jubeks	doc_491521502070_item	3364046	et	4	main
piinlik	doc_491521502070_item	3364050	et	3	main
korista	doc_491521502070_item	3364055	et	4	main
enda	doc_491521502070_item	3364056	et	4	main
järelt	doc_491521502070_item	3364057	et	4	main
mul	doc_491521502070_item	3364067	et	3	main
on	doc_491521502070_item	3364068	et	4	main
ebameeldiv	doc_491521502070_item	3364069	et	3	main
убивать	doc_491521502070_item	3363799	et	2	main
pihustama	doc_491521502070_item	3363806	et	3	main
сдавать	doc_491521502070_item	3363810	et	2	main
tõhus	doc_491521502070_item	3363811	et	4	main
kuluma	doc_491521502070_item	3363813	et	3	main
отслужить	doc_491521502070_item	3363814	et	2	main
kirjutage	doc_491521502070_item	3363822	et	3	main
minema	doc_491521502070_item	3363826	et	3	main
maha	doc_491521502070_item	3363833	et	4	main
tehti	doc_491521502070_item	3363840	et	3	main
ütlema	doc_491521502070_item	3363843	et	3	main
lasti	doc_491521502070_item	3363854	et	4	main
saatma	doc_491521502070_item	3363855	et	3	main
ravivad	doc_491521502070_item	3363892	et	4	main
juukseid	doc_491521502070_item	3363893	et	3	main
juukseid	doc_491521502070_item	3363894	et	3	main
õppida	doc_491521502070_item	3364035	et	3	main
viii	doc_491521502070_item	3364036	et	4	main
pange	doc_491521502070_item	3364037	et	4	main
sulgudes	doc_491521502070_item	3364038	et	4	main
olevad	doc_491521502070_item	3364039	et	4	main
sõnad	doc_491521502070_item	3364040	et	4	main
i	doc_491521502070_item	3363796	et	4	main
umbusklik	doc_491521502070_item	3363802	et	3	main
jõukohane	doc_491521502070_item	3363808	et	4	main
на	doc_491521502070_item	3363818	et	2	main
ühesõnalised	doc_491521502070_item	3363823	et	4	main
jätma	doc_491521502070_item	3363834	et	3	main
visata	doc_491521502070_item	3363835	et	4	main
iii	doc_491521502070_item	3363838	et	4	main
öeldi	doc_491521502070_item	3363844	et	3	main
pakkuma	doc_491521502070_item	3363847	et	3	main
lubama	doc_491521502070_item	3363849	et	3	main
tegema	doc_491521502070_item	3363851	et	3	main
saati	doc_491521502070_item	3363856	et	3	main
räägiti	doc_491521502070_item	3363858	et	3	main
teatama	doc_491521502070_item	3363859	et	4	main
teatati	doc_491521502070_item	3363860	et	3	main
iv	doc_491521502070_item	3363861	et	4	main
kasutage	doc_491521502070_item	3363862	et	3	main
v-kesksõna	doc_491521502070_item	3363863	et	4	main
prügi	doc_491521502070_item	3363864	et	4	main
mis	doc_491521502070_item	3363865	et	4	main
tekib	doc_491521502070_item	3363866	et	3	main
kodus	doc_491521502070_item	3363867	et	4	main
kodus	doc_491521502070_item	3363868	et	4	main
tekkiv	doc_491521502070_item	3363869	et	4	main
prügi	doc_491521502070_item	3363870	et	4	main
mis	doc_491521502070_item	3363872	et	4	main
vahenditeta	doc_491521502070_item	3363871	et	3	main
värskendavad	doc_491521502070_item	3363873	et	4	main
õhku	doc_491521502070_item	3363874	et	4	main
õhku	doc_491521502070_item	3363875	et	4	main
värskendav	doc_491521502070_item	3363876	et	4	main
vahend	doc_491521502070_item	3363877	et	3	main
inimest	doc_491521502070_item	3363878	et	3	main
kes	doc_491521502070_item	3363879	et	4	main
müüb	doc_491521502070_item	3363880	et	3	main
kosmeetikavahendeid	doc_491521502070_item	3363881	et	3	main
kosmeetikavahendeid	doc_491521502070_item	3363882	et	3	main
müüv	doc_491521502070_item	3363883	et	4	main
inimene	doc_491521502070_item	3363884	et	3	main
kreemiga	doc_491521502070_item	3363885	et	4	main
mis	doc_491521502070_item	3363886	et	4	main
niisutab	doc_491521502070_item	3363887	et	3	main
niisutav	doc_491521502070_item	3363888	et	4	main
v	doc_491521502070_item	3363897	et	4	main
mis	doc_491521502070_item	3363901	et	4	main
välismaal	doc_491521502070_item	3363903	et	4	main
süüakse	doc_491521502070_item	3363916	et	3	main
ostetakse	doc_491521502070_item	3363921	et	3	main
harva	doc_491521502070_item	3363923	et	4	main
ostetav	doc_491521502070_item	3363924	et	4	main
kaup	doc_491521502070_item	3363925	et	3	main
kaanega	doc_491521502070_item	3363926	et	3	main
tõmmake	doc_491521502070_item	3363935	et	3	main
alla	doc_491521502070_item	3363937	et	3	main
luituvad	doc_491521502070_item	3363952	et	4	main
artiklid	doc_491521502070_item	3363953	et	3	main
kahjustasid	doc_491521502070_item	3363954	et	4	main
firma	doc_491521502070_item	3363955	et	4	main
olemust	doc_491521502070_item	3363956	et	3	main
mainet	doc_491521502070_item	3363957	et	4	main
puänti	doc_491521502070_item	3363958	et	4	main
seda	doc_491521502070_item	3363959	et	3	main
plaani	doc_491521502070_item	3363960	et	4	main
on	doc_491521502070_item	3363961	et	4	main
raske	doc_491521502070_item	3363962	et	4	main
liigitada	doc_491521502070_item	3363963	et	3	main
sisaldada	doc_491521502070_item	3363964	et	3	main
teostada	doc_491521502070_item	3363965	et	3	main
inimesed	doc_491521502070_item	3363966	et	3	main
peaksid	doc_491521502070_item	3363967	et	4	main
endale	doc_491521502070_item	3363968	et	4	main
rohkem	doc_491521502070_item	3363969	et	4	main
teadvustama	doc_491521502070_item	3363970	et	3	main
keskkonna	doc_491521502070_item	3363971	et	3	main
reostamise	doc_491521502070_item	3363972	et	4	main
järeldusi	doc_491521502070_item	3363973	et	4	main
tagajärgi	doc_491521502070_item	3363974	et	4	main
tulemusi	doc_491521502070_item	3363975	et	4	main
vii	doc_491521502070_item	3363976	et	4	main
tõlkige	doc_491521502070_item	3363977	et	3	main
kreemidele	doc_491521502070_item	3363900	et	3	main
mida	doc_491521502070_item	3363908	et	4	main
pestakse	doc_491521502070_item	3363909	et	3	main
käsitsi	doc_491521502070_item	3363910	et	3	main
pestav	doc_491521502070_item	3363912	et	4	main
pesu	doc_491521502070_item	3363913	et	4	main
söödav	doc_491521502070_item	3363917	et	4	main
mida	doc_491521502070_item	3363927	et	4	main
avatavad	doc_491521502070_item	3363932	et	4	main
kaaned	doc_491521502070_item	3363933	et	3	main
käsitsevad	doc_491521502070_item	3363950	et	4	main
kisuvad	doc_491521502070_item	3363951	et	3	main
töötamata	doc_491521502070_item	3363988	et	4	main
экономите	doc_491521502070_item	3363993	et	2	main
te	doc_491521502070_item	3363997	et	4	main
aega	doc_491521502070_item	3364000	et	4	main
фирма	doc_491521502070_item	3364001	et	2	main
õigesse	doc_491521502070_item	3364041	et	3	main
piinlik	doc_491521502070_item	3364051	et	3	main
lakkamatu	doc_491521502070_item	3364060	et	4	main
lakkamatult	doc_491521502070_item	3364061	et	4	main
kassis	doc_491521502070_item	3364062	et	3	main
ajavad	doc_491521502070_item	3364063	et	4	main
seda	doc_491521502070_item	3364071	et	3	main
veel	doc_491521502070_item	3363987	et	4	main
вы	doc_491521502070_item	3363992	et	2	main
jube	doc_491521502070_item	3364045	et	4	main
väga	doc_491521502070_item	3364049	et	3	main
inimesed	doc_491521502070_item	3364053	et	3	main
sajab	doc_491521502070_item	3364059	et	3	main
привлекает	doc_491521502070_item	3364002	et	2	main
клиентов	doc_491521502070_item	3364003	et	2	main
подарками	doc_491521502070_item	3364004	et	2	main
firma	doc_491521502070_item	3364005	et	4	main
peidub	doc_491521502070_item	3364006	et	4	main
kliente	doc_491521502070_item	3364007	et	3	main
kingitustega	doc_491521502070_item	3364008	et	4	main
это	doc_491521502070_item	3364009	et	2	main
нарушает	doc_491521502070_item	3364010	et	2	main
принципы	doc_491521502070_item	3364011	et	2	main
торговли	doc_491521502070_item	3364012	et	2	main
свободного	doc_491521502070_item	3364013	et	2	main
рынка	doc_491521502070_item	3364014	et	2	main
see	doc_491521502070_item	3364015	et	3	main
sekkub	doc_491521502070_item	3364016	et	3	main
vabaturu	doc_491521502070_item	3364017	et	3	main
töötamise	doc_491521502070_item	3364018	et	4	main
prinsiipe	doc_491521502070_item	3364019	et	4	main
вас	doc_491521502070_item	3364021	et	2	main
есть	doc_491521502070_item	3364022	et	2	main
возможность	doc_491521502070_item	3364023	et	2	main
дома	doc_491521502070_item	3364024	et	2	main
спокойно	doc_491521502070_item	3364025	et	2	main
изучить	doc_491521502070_item	3364026	et	2	main
каталог	doc_491521502070_item	3364027	et	2	main
у	doc_491521502070_item	3364020	et	2	main
teil	doc_491521502070_item	3364028	et	4	main
on	doc_491521502070_item	3364029	et	4	main
võimalus	doc_491521502070_item	3364030	et	3	main
rahulikult	doc_491521502070_item	3364031	et	4	main
kodus	doc_491521502070_item	3364032	et	4	main
kataloogi	doc_491521502070_item	3364033	et	4	main
ära	doc_491521502070_item	3364034	et	4	main
välja	doc_491521502070_item	3364047	et	4	main
kui	doc_491521502070_item	3364052	et	3	main
ei	doc_491521502070_item	3364054	et	4	main
hirmus	doc_491521502070_item	3364064	et	4	main
ebameeldiv	doc_491521502070_item	3364070	et	3	main
jõukohane	doc_491521502074_item	3365803	et	4	main
по	doc_491521502074_item	3365804	et	2	main
lakkama	doc_491521502074_item	3365808	et	3	main
tulema	doc_491521502074_item	3365818	et	4	main
terveks	doc_491521502074_item	3365830	et	4	main
tabama	doc_491521502074_item	3365838	et	3	main
mida	doc_491521502074_item	3365840	et	4	main
nõudma	doc_491521502074_item	3365842	et	3	main
nõuti	doc_491521502074_item	3365843	et	3	main
anti	doc_491521502074_item	3365847	et	3	main
lubati	doc_491521502074_item	3365851	et	3	main
tegema	doc_491521502074_item	3365852	et	3	main
mis	doc_491521502074_item	3365866	et	4	main
mis	doc_491521502074_item	3365873	et	4	main
värskendavad	doc_491521502074_item	3365874	et	4	main
õhku	doc_491521502074_item	3365875	et	4	main
vahenditeta	doc_491521502074_item	3365878	et	3	main
kes	doc_491521502074_item	3365880	et	4	main
kosmeetikavahendeid	doc_491521502074_item	3365883	et	3	main
ravivaid	doc_491521502074_item	3365896	et	4	main
šampoone	doc_491521502074_item	3365897	et	2	main
välismaal	doc_491521502074_item	3365905	et	4	main
pesu	doc_491521502074_item	3365908	et	4	main
käsitsi	doc_491521502074_item	3365912	et	3	main
süüakse	doc_491521502074_item	3365917	et	3	main
kaupu	doc_491521502074_item	3365920	et	3	main
i	doc_491521502074_item	3365790	et	4	main
понимать	doc_491521502074_item	3365793	et	2	main
плесневеть	doc_491521502074_item	3365796	et	2	main
недоверчивый	doc_491521502074_item	3365798	et	2	main
jäätmed	doc_491521502074_item	3365799	et	3	main
дело	doc_491521502074_item	3365807	et	2	main
непрекращаться	doc_491521502074_item	3365810	et	2	main
справляться	doc_491521502074_item	3365819	et	2	main
kirjutage	doc_491521502074_item	3365821	et	3	main
saama	doc_491521502074_item	3365831	et	4	main
paranema	doc_491521502074_item	3365832	et	3	main
saatma	doc_491521502074_item	3365856	et	3	main
teatati	doc_491521502074_item	3365861	et	3	main
kasutage	doc_491521502074_item	3365863	et	3	main
v-kesksõna	doc_491521502074_item	3365864	et	4	main
prügi	doc_491521502074_item	3365865	et	4	main
õhku	doc_491521502074_item	3365876	et	4	main
pestavat	doc_491521502074_item	3365913	et	4	main
toidust	doc_491521502074_item	3365919	et	4	main
saab	doc_491521502074_item	3365929	et	3	main
kergesti	doc_491521502074_item	3365930	et	3	main
raske	doc_491521502074_item	3365963	et	4	main
liigitada	doc_491521502074_item	3365964	et	3	main
sisaldada	doc_491521502074_item	3365965	et	3	main
teostada	doc_491521502074_item	3365966	et	3	main
inimesed	doc_491521502074_item	3365967	et	3	main
peaksid	doc_491521502074_item	3365968	et	4	main
prügi	doc_491521502074_item	3365984	et	4	main
väljatoodeldud	doc_491521502074_item	3365990	et	4	main
по	doc_491521502074_item	3365992	et	2	main
экономите	doc_491521502074_item	3365995	et	2	main
время	doc_491521502074_item	3365996	et	2	main
изучить	doc_491521502074_item	3366029	et	2	main
sõnad	doc_491521502074_item	3366042	et	4	main
õigesse	doc_491521502074_item	3366043	et	3	main
see	doc_491521502074_item	3366045	et	3	main
näeb	doc_491521502074_item	3366046	et	3	main
jube	doc_491521502074_item	3366047	et	4	main
on	doc_491521502074_item	3366050	et	4	main
kui	doc_491521502074_item	3366054	et	3	main
korista	doc_491521502074_item	3366057	et	4	main
järelt	doc_491521502074_item	3366059	et	4	main
vihma	doc_491521502074_item	3366060	et	4	main
sajab	doc_491521502074_item	3366061	et	3	main
распылять	doc_491521502074_item	3365802	et	2	main
tõhus	doc_491521502074_item	3365811	et	4	main
изнашиваться	doc_491521502074_item	3365815	et	2	main
toime	doc_491521502074_item	3365817	et	4	main
ii	doc_491521502074_item	3365820	et	4	main
ühesõnalised	doc_491521502074_item	3365822	et	4	main
ära	doc_491521502074_item	3365824	et	4	main
maha	doc_491521502074_item	3365833	et	4	main
jätma	doc_491521502074_item	3365834	et	3	main
hülgama	doc_491521502074_item	3365835	et	3	main
iii	doc_491521502074_item	3365839	et	4	main
tehti	doc_491521502074_item	3365841	et	3	main
öeldi	doc_491521502074_item	3365845	et	3	main
pakkuma	doc_491521502074_item	3365848	et	3	main
lubama	doc_491521502074_item	3365850	et	3	main
tehti	doc_491521502074_item	3365853	et	3	main
lasti	doc_491521502074_item	3365855	et	4	main
räägiti	doc_491521502074_item	3365859	et	3	main
tekiv	doc_491521502074_item	3365870	et	4	main
prügi	doc_491521502074_item	3365871	et	4	main
vahenditeta	doc_491521502074_item	3365872	et	3	main
mis	doc_491521502074_item	3365887	et	4	main
kontrolltöö	doc_491521502074_item	3365789	et	4	main
tõlkige	doc_491521502074_item	3365791	et	3	main
соображать	doc_491521502074_item	3365794	et	2	main
pihustama	doc_491521502074_item	3365801	et	3	main
силам	doc_491521502074_item	3365805	et	2	main
неостанавливаться	doc_491521502074_item	3365809	et	2	main
ära	doc_491521502074_item	3365813	et	4	main
одежда	doc_491521502074_item	3365816	et	2	main
sünonüümid	doc_491521502074_item	3365823	et	3	main
minema	doc_491521502074_item	3365825	et	3	main
lahkuma	doc_491521502074_item	3365826	et	3	main
haigeks	doc_491521502074_item	3365827	et	4	main
püüdma	doc_491521502074_item	3365837	et	3	main
saadeti	doc_491521502074_item	3365857	et	3	main
rääkima	doc_491521502074_item	3365858	et	3	main
teatama	doc_491521502074_item	3365860	et	4	main
tekib	doc_491521502074_item	3365867	et	3	main
kodus	doc_491521502074_item	3365868	et	4	main
kodus	doc_491521502074_item	3365869	et	4	main
inimest	doc_491521502074_item	3365879	et	3	main
müüb	doc_491521502074_item	3365881	et	3	main
müüvat	doc_491521502074_item	3365884	et	4	main
inimest	doc_491521502074_item	3365885	et	3	main
kreemiga	doc_491521502074_item	3365886	et	4	main
kreemiga	doc_491521502074_item	3365890	et	4	main
tav-kesksõna	doc_491521502074_item	3365900	et	4	main
kreemidele	doc_491521502074_item	3365901	et	3	main
mis	doc_491521502074_item	3365902	et	4	main
toodetakse	doc_491521502074_item	3365903	et	3	main
kreemidele	doc_491521502074_item	3365907	et	3	main
mida	doc_491521502074_item	3365909	et	4	main
pestakse	doc_491521502074_item	3365910	et	3	main
käsitsi	doc_491521502074_item	3365911	et	3	main
toidust	doc_491521502074_item	3365915	et	4	main
ostetakse	doc_491521502074_item	3365922	et	3	main
harva	doc_491521502074_item	3365923	et	4	main
avada	doc_491521502074_item	3365931	et	3	main
avatava	doc_491521502074_item	3365933	et	4	main
seda	doc_491521502074_item	3365960	et	3	main
on	doc_491521502074_item	3365962	et	4	main
järeldusi	doc_491521502074_item	3365974	et	4	main
süsteem	doc_491521502074_item	3365986	et	3	main
taipama	doc_491521502074_item	3365792	et	3	main
hallitama	doc_491521502074_item	3365795	et	3	main
umbusklik	doc_491521502074_item	3365797	et	3	main
остатки	doc_491521502074_item	3365800	et	2	main
какое-то	doc_491521502074_item	3365806	et	2	main
эфективный	doc_491521502074_item	3365812	et	2	main
kuluma	doc_491521502074_item	3365814	et	3	main
jääma	doc_491521502074_item	3365828	et	4	main
haigestuma	doc_491521502074_item	3365829	et	3	main
kinni	doc_491521502074_item	3365836	et	3	main
ütlema	doc_491521502074_item	3365844	et	3	main
andma	doc_491521502074_item	3365846	et	3	main
pakuti	doc_491521502074_item	3365849	et	3	main
laskma	doc_491521502074_item	3365854	et	3	main
iv	doc_491521502074_item	3365862	et	4	main
värskendavate	doc_491521502074_item	3365877	et	4	main
kosmeetikavahendeid	doc_491521502074_item	3365882	et	3	main
niisutab	doc_491521502074_item	3365888	et	3	main
niisutava	doc_491521502074_item	3365889	et	4	main
v	doc_491521502074_item	3365898	et	4	main
kasutage	doc_491521502074_item	3365899	et	3	main
toodetavatele	doc_491521502074_item	3365906	et	4	main
mida	doc_491521502074_item	3365916	et	4	main
söödavast	doc_491521502074_item	3365918	et	4	main
mida	doc_491521502074_item	3365921	et	4	main
harva	doc_491521502074_item	3365924	et	4	main
ostetavaid	doc_491521502074_item	3365925	et	4	main
kaupu	doc_491521502074_item	3365926	et	3	main
kaanega	doc_491521502074_item	3365927	et	3	main
maha	doc_491521502074_item	3365937	et	4	main
teadvustama	doc_491521502074_item	3365971	et	3	main
keskkonna	doc_491521502074_item	3365972	et	3	main
tagajärgi	doc_491521502074_item	3365975	et	4	main
vii	doc_491521502074_item	3365977	et	4	main
tõlkige	doc_491521502074_item	3365978	et	3	main
система	doc_491521502074_item	3365979	et	2	main
переработки	doc_491521502074_item	3365980	et	2	main
мусора	doc_491521502074_item	3365981	et	2	main
не	doc_491521502074_item	3365982	et	2	main
разработана	doc_491521502074_item	3365983	et	2	main
ei	doc_491521502074_item	3365987	et	4	main
veel	doc_491521502074_item	3365989	et	4	main
каталогу	doc_491521502074_item	3365993	et	2	main
вы	doc_491521502074_item	3365994	et	2	main
tellides	doc_491521502074_item	3365998	et	3	main
oma	doc_491521502074_item	3366001	et	4	main
фирма	doc_491521502074_item	3366003	et	2	main
клиентов	doc_491521502074_item	3366005	et	2	main
каталог	doc_491521502074_item	3366030	et	2	main
kataloogi	doc_491521502074_item	3366036	et	4	main
uurida	doc_491521502074_item	3366037	et	3	main
viii	doc_491521502074_item	3366038	et	4	main
vormi	doc_491521502074_item	3366044	et	4	main
ei	doc_491521502074_item	3366056	et	4	main
i	doc_491521502075_item	3366486	et	4	main
jäätmed	doc_491521502075_item	3366492	et	3	main
jõukohane	doc_491521502075_item	3366495	et	4	main
tõhus	doc_491521502075_item	3366497	et	4	main
ühesõnalised	doc_491521502075_item	3366504	et	4	main
lahkuma	doc_491521502075_item	3366508	et	3	main
jääma	doc_491521502075_item	3366510	et	4	main
saama	doc_491521502075_item	3366512	et	4	main
pakkuti	doc_491521502075_item	3366527	et	4	main
lubama	doc_491521502075_item	3366528	et	3	main
tehti	doc_491521502075_item	3366531	et	3	main
saati	doc_491521502075_item	3366535	et	3	main
teati	doc_491521502075_item	3366539	et	3	main
v-kesksõna	doc_491521502075_item	3366542	et	4	main
värskendavad	doc_491521502075_item	3366549	et	4	main
kreemiga	doc_491521502075_item	3366555	et	4	main
mis	doc_491521502075_item	3366556	et	4	main
niisutab	doc_491521502075_item	3366557	et	3	main
šampoone	doc_491521502075_item	3366558	et	2	main
süüakse	doc_491521502075_item	3366575	et	3	main
kaupu	doc_491521502075_item	3366576	et	3	main
mida	doc_491521502075_item	3366577	et	4	main
ostetakse	doc_491521502075_item	3366578	et	3	main
maha	doc_491521502075_item	3366587	et	4	main
plaani	doc_491521502075_item	3366611	et	4	main
šampoone	doc_491521502074_item	3365891	et	2	main
mis	doc_491521502074_item	3365892	et	4	main
ravivad	doc_491521502074_item	3365893	et	4	main
juukseid	doc_491521502074_item	3365894	et	3	main
juukseid	doc_491521502074_item	3365895	et	3	main
välismaal	doc_491521502074_item	3365904	et	4	main
pesu	doc_491521502074_item	3365914	et	4	main
mida	doc_491521502074_item	3365928	et	4	main
valed	doc_491521502074_item	3365939	et	3	main
sõnad	doc_491521502074_item	3365940	et	4	main
suurt	doc_491521502074_item	3365941	et	3	main
koera	doc_491521502074_item	3365942	et	4	main
peab	doc_491521502074_item	3365943	et	4	main
kordamööda	doc_491521502074_item	3365944	et	3	main
ilmtingimata	doc_491521502074_item	3365945	et	3	main
omapead	doc_491521502074_item	3365946	et	3	main
õpetama	doc_491521502074_item	3365947	et	3	main
selle	doc_491521502074_item	3365948	et	4	main
pintsaku	doc_491521502074_item	3365949	et	3	main
õmblused	doc_491521502074_item	3365950	et	3	main
käsitsevad	doc_491521502074_item	3365951	et	4	main
kisuvad	doc_491521502074_item	3365952	et	3	main
luituvad	doc_491521502074_item	3365953	et	4	main
artiklid	doc_491521502074_item	3365954	et	3	main
kahjustasid	doc_491521502074_item	3365955	et	4	main
firma	doc_491521502074_item	3365956	et	4	main
olemust	doc_491521502074_item	3365957	et	3	main
mainet	doc_491521502074_item	3365958	et	4	main
puänti	doc_491521502074_item	3365959	et	4	main
plaani	doc_491521502074_item	3365961	et	4	main
kergesti	doc_491521502074_item	3365932	et	3	main
kaanega	doc_491521502074_item	3365934	et	3	main
vi	doc_491521502074_item	3365935	et	4	main
tõmmake	doc_491521502074_item	3365936	et	3	main
alla	doc_491521502074_item	3365938	et	3	main
reostamise	doc_491521502074_item	3365973	et	4	main
tulemusi	doc_491521502074_item	3365976	et	4	main
привлекает	doc_491521502074_item	3366004	et	2	main
подарками	doc_491521502074_item	3366006	et	2	main
peibutab	doc_491521502074_item	3366008	et	3	main
kingitustega	doc_491521502074_item	3366010	et	4	main
нарушает	doc_491521502074_item	3366012	et	2	main
торговли	doc_491521502074_item	3366014	et	2	main
спокойно	doc_491521502074_item	3366028	et	2	main
teil	doc_491521502074_item	3366031	et	4	main
on	doc_491521502074_item	3366032	et	4	main
võimalus	doc_491521502074_item	3366033	et	3	main
pange	doc_491521502074_item	3366039	et	4	main
välja	doc_491521502074_item	3366049	et	4	main
piinlik	doc_491521502074_item	3366053	et	3	main
kontrolltöö	doc_491521502075_item	3366485	et	4	main
taipama	doc_491521502075_item	3366488	et	3	main
ii	doc_491521502075_item	3366502	et	4	main
kirjutage	doc_491521502075_item	3366503	et	3	main
minema	doc_491521502075_item	3366507	et	3	main
haigeks	doc_491521502075_item	3366509	et	4	main
iii	doc_491521502075_item	3366517	et	4	main
tegema	doc_491521502075_item	3366530	et	3	main
lasti	doc_491521502075_item	3366533	et	4	main
räägiti	doc_491521502075_item	3366537	et	3	main
prügi	doc_491521502075_item	3366543	et	4	main
mis	doc_491521502075_item	3366544	et	4	main
tekib	doc_491521502075_item	3366545	et	3	main
ravivad	doc_491521502075_item	3366560	et	4	main
juukseid	doc_491521502075_item	3366561	et	3	main
pesu	doc_491521502075_item	3366569	et	4	main
pestakse	doc_491521502075_item	3366571	et	3	main
käsitsi	doc_491521502075_item	3366572	et	3	main
toidust	doc_491521502075_item	3366573	et	4	main
mida	doc_491521502075_item	3366581	et	4	main
endale	doc_491521502074_item	3365969	et	4	main
rohkem	doc_491521502074_item	3365970	et	4	main
ümbertöötlemise	doc_491521502074_item	3365985	et	3	main
ole	doc_491521502074_item	3365988	et	4	main
teie	doc_491521502074_item	3365999	et	4	main
säästate	doc_491521502074_item	3366000	et	3	main
kliente	doc_491521502074_item	3366009	et	3	main
это	doc_491521502074_item	3366011	et	2	main
принципы	doc_491521502074_item	3366013	et	2	main
свободного	doc_491521502074_item	3366015	et	2	main
rahulikult	doc_491521502074_item	3366035	et	4	main
jubedalt	doc_491521502074_item	3366048	et	4	main
piinlik	doc_491521502074_item	3366052	et	3	main
umbusklik	doc_491521502075_item	3366490	et	3	main
ära	doc_491521502075_item	3366498	et	4	main
maha	doc_491521502075_item	3366513	et	4	main
jätma	doc_491521502075_item	3366514	et	3	main
kinni	doc_491521502075_item	3366515	et	3	main
püüdma	doc_491521502075_item	3366516	et	3	main
pakkuma	doc_491521502075_item	3366526	et	3	main
teatama	doc_491521502075_item	3366538	et	4	main
õhku	doc_491521502075_item	3366550	et	4	main
müüb	doc_491521502075_item	3366553	et	3	main
välismaal	doc_491521502075_item	3366568	et	4	main
saab	doc_491521502075_item	3366582	et	3	main
kergesti	doc_491521502075_item	3366583	et	3	main
avada	doc_491521502075_item	3366584	et	3	main
tõmmake	doc_491521502075_item	3366586	et	3	main
õpetama	doc_491521502075_item	3366597	et	3	main
selle	doc_491521502075_item	3366598	et	4	main
pintsaku	doc_491521502075_item	3366599	et	3	main
olemust	doc_491521502075_item	3366607	et	3	main
mainet	doc_491521502075_item	3366608	et	4	main
raske	doc_491521502075_item	3366613	et	4	main
liigitada	doc_491521502075_item	3366614	et	3	main
sisaldada	doc_491521502075_item	3366615	et	3	main
teostada	doc_491521502075_item	3366616	et	3	main
järeldusi	doc_491521502075_item	3366624	et	4	main
нарушает	doc_491521502075_item	3366645	et	2	main
у	doc_491521502075_item	3366650	et	2	main
изучить	doc_491521502075_item	3366656	et	2	main
sulgudes	doc_491521502075_item	3366660	et	4	main
õigesse	doc_491521502075_item	3366663	et	3	main
vormi	doc_491521502075_item	3366664	et	4	main
заказывая	doc_491521502074_item	3365991	et	2	main
kataloogist	doc_491521502074_item	3365997	et	3	main
aega	doc_491521502074_item	3366002	et	4	main
firma	doc_491521502074_item	3366007	et	4	main
рынка	doc_491521502074_item	3366016	et	2	main
see	doc_491521502074_item	3366017	et	3	main
häirib	doc_491521502074_item	3366018	et	3	main
vaba	doc_491521502074_item	3366019	et	4	main
turu	doc_491521502074_item	3366020	et	3	main
kaubanduse	doc_491521502074_item	3366021	et	3	main
printsiibe	doc_491521502074_item	3366022	et	4	main
у	doc_491521502074_item	3366023	et	2	main
вас	doc_491521502074_item	3366024	et	2	main
есть	doc_491521502074_item	3366025	et	2	main
возможность	doc_491521502074_item	3366026	et	2	main
дома	doc_491521502074_item	3366027	et	2	main
kodus	doc_491521502074_item	3366034	et	4	main
sulgudes	doc_491521502074_item	3366040	et	4	main
olevad	doc_491521502074_item	3366041	et	4	main
väga	doc_491521502074_item	3366051	et	3	main
inimesed	doc_491521502074_item	3366055	et	3	main
enda	doc_491521502074_item	3366058	et	4	main
lakkamatu	doc_491521502074_item	3366062	et	4	main
lakkamatult	doc_491521502074_item	3366063	et	4	main
kassis	doc_491521502074_item	3366064	et	3	main
ajavad	doc_491521502074_item	3366065	et	4	main
hirmus	doc_491521502074_item	3366066	et	4	main
hirmsalt	doc_491521502074_item	3366067	et	4	main
karva	doc_491521502074_item	3366068	et	4	main
mul	doc_491521502074_item	3366069	et	3	main
on	doc_491521502074_item	3366070	et	4	main
ebameeldiv	doc_491521502074_item	3366071	et	3	main
ebameeldiv	doc_491521502074_item	3366072	et	3	main
seda	doc_491521502074_item	3366073	et	3	main
vaadata	doc_491521502074_item	3366074	et	4	main
hallitama	doc_491521502075_item	3366489	et	3	main
остатки	doc_491521502075_item	3366493	et	2	main
tulema	doc_491521502075_item	3366501	et	4	main
ära	doc_491521502075_item	3366506	et	4	main
rääkima	doc_491521502075_item	3366536	et	3	main
iv	doc_491521502075_item	3366540	et	4	main
kodus	doc_491521502075_item	3366546	et	4	main
vahenditeta	doc_491521502075_item	3366547	et	3	main
mis	doc_491521502075_item	3366548	et	4	main
kes	doc_491521502075_item	3366552	et	4	main
v	doc_491521502075_item	3366562	et	4	main
kasutage	doc_491521502075_item	3366563	et	3	main
tav-kesksõna	doc_491521502075_item	3366564	et	4	main
kreemidele	doc_491521502075_item	3366565	et	3	main
mis	doc_491521502075_item	3366566	et	4	main
harva	doc_491521502075_item	3366579	et	4	main
kaanega	doc_491521502075_item	3366580	et	3	main
vi	doc_491521502075_item	3366585	et	4	main
alla	doc_491521502075_item	3366588	et	3	main
luituvad	doc_491521502075_item	3366603	et	4	main
artiklid	doc_491521502075_item	3366604	et	3	main
tõlkige	doc_491521502075_item	3366487	et	3	main
безличн	doc_491521502075_item	3366491	et	2	main
pihustama	doc_491521502075_item	3366494	et	3	main
lakkama	doc_491521502075_item	3366496	et	3	main
kuluma	doc_491521502075_item	3366499	et	3	main
toime	doc_491521502075_item	3366500	et	4	main
sünonüümid	doc_491521502075_item	3366505	et	3	main
terveks	doc_491521502075_item	3366511	et	4	main
mida	doc_491521502075_item	3366518	et	4	main
tehti	doc_491521502075_item	3366519	et	3	main
nõudma	doc_491521502075_item	3366520	et	3	main
nõuti	doc_491521502075_item	3366521	et	3	main
ütlema	doc_491521502075_item	3366522	et	3	main
üelti	doc_491521502075_item	3366523	et	4	main
andma	doc_491521502075_item	3366524	et	3	main
anti	doc_491521502075_item	3366525	et	3	main
lubati	doc_491521502075_item	3366529	et	3	main
laskma	doc_491521502075_item	3366532	et	3	main
saatma	doc_491521502075_item	3366534	et	3	main
kasutage	doc_491521502075_item	3366541	et	3	main
inimest	doc_491521502075_item	3366551	et	3	main
kosmeetikavahendeid	doc_491521502075_item	3366554	et	3	main
mis	doc_491521502075_item	3366559	et	4	main
toodetakse	doc_491521502075_item	3366567	et	3	main
mida	doc_491521502075_item	3366570	et	4	main
mida	doc_491521502075_item	3366574	et	4	main
sõnad	doc_491521502075_item	3366590	et	4	main
suurt	doc_491521502075_item	3366591	et	3	main
õmblused	doc_491521502075_item	3366600	et	3	main
käsitsevad	doc_491521502075_item	3366601	et	4	main
kisuvad	doc_491521502075_item	3366602	et	3	main
puänti	doc_491521502075_item	3366609	et	4	main
seda	doc_491521502075_item	3366610	et	3	main
endale	doc_491521502075_item	3366619	et	4	main
время	doc_491521502075_item	3366639	et	2	main
клиентов	doc_491521502075_item	3366642	et	2	main
рынка	doc_491521502075_item	3366649	et	2	main
спокойно	doc_491521502075_item	3366655	et	2	main
valed	doc_491521502075_item	3366589	et	3	main
koera	doc_491521502075_item	3366592	et	4	main
peab	doc_491521502075_item	3366593	et	4	main
kordamööda	doc_491521502075_item	3366594	et	3	main
ilmtingimata	doc_491521502075_item	3366595	et	3	main
omapead	doc_491521502075_item	3366596	et	3	main
firma	doc_491521502075_item	3366606	et	4	main
inimesed	doc_491521502075_item	3366617	et	3	main
peaksid	doc_491521502075_item	3366618	et	4	main
tulemusi	doc_491521502075_item	3366626	et	4	main
vii	doc_491521502075_item	3366627	et	4	main
tõlkige	doc_491521502075_item	3366628	et	3	main
система	doc_491521502075_item	3366629	et	2	main
переработки	doc_491521502075_item	3366630	et	2	main
мусора	doc_491521502075_item	3366631	et	2	main
не	doc_491521502075_item	3366632	et	2	main
разработана	doc_491521502075_item	3366633	et	2	main
заказывая	doc_491521502075_item	3366634	et	2	main
по	doc_491521502075_item	3366635	et	2	main
каталогу	doc_491521502075_item	3366636	et	2	main
вы	doc_491521502075_item	3366637	et	2	main
это	doc_491521502075_item	3366644	et	2	main
торговли	doc_491521502075_item	3366647	et	2	main
есть	doc_491521502075_item	3366652	et	2	main
see	doc_491521502075_item	3366665	et	3	main
näeb	doc_491521502075_item	3366666	et	3	main
jube	doc_491521502075_item	3366667	et	4	main
välja	doc_491521502075_item	3366668	et	4	main
on	doc_491521502075_item	3366669	et	4	main
väga	doc_491521502075_item	3366670	et	3	main
piinlik	doc_491521502075_item	3366671	et	3	main
kui	doc_491521502075_item	3366672	et	3	main
inimesed	doc_491521502075_item	3366673	et	3	main
ei	doc_491521502075_item	3366674	et	4	main
korista	doc_491521502075_item	3366675	et	4	main
enda	doc_491521502075_item	3366676	et	4	main
järelt	doc_491521502075_item	3366677	et	4	main
vihma	doc_491521502075_item	3366678	et	4	main
sajab	doc_491521502075_item	3366679	et	3	main
kassis	doc_491521502075_item	3366681	et	3	main
lakkamatu	doc_491521502075_item	3366680	et	4	main
ajavad	doc_491521502075_item	3366682	et	4	main
hirmus	doc_491521502075_item	3366683	et	4	main
karva	doc_491521502075_item	3366684	et	4	main
kahjustasid	doc_491521502075_item	3366605	et	4	main
on	doc_491521502075_item	3366612	et	4	main
tagajärgi	doc_491521502075_item	3366625	et	4	main
фирма	doc_491521502075_item	3366640	et	2	main
подарками	doc_491521502075_item	3366643	et	2	main
свободного	doc_491521502075_item	3366648	et	2	main
возможность	doc_491521502075_item	3366653	et	2	main
каталог	doc_491521502075_item	3366657	et	2	main
pange	doc_491521502075_item	3366659	et	4	main
sõnad	doc_491521502075_item	3366662	et	4	main
rohkem	doc_491521502075_item	3366620	et	4	main
teadvustama	doc_491521502075_item	3366621	et	3	main
keskkonna	doc_491521502075_item	3366622	et	3	main
reostamise	doc_491521502075_item	3366623	et	4	main
экономите	doc_491521502075_item	3366638	et	2	main
привлекает	doc_491521502075_item	3366641	et	2	main
принципы	doc_491521502075_item	3366646	et	2	main
вас	doc_491521502075_item	3366651	et	2	main
дома	doc_491521502075_item	3366654	et	2	main
viii	doc_491521502075_item	3366658	et	4	main
olevad	doc_491521502075_item	3366661	et	4	main
mul	doc_491521502075_item	3366685	et	3	main
on	doc_491521502075_item	3366686	et	4	main
ebameeldiv	doc_491521502075_item	3366687	et	3	main
seda	doc_491521502075_item	3366688	et	3	main
vaadata	doc_491521502075_item	3366689	et	4	main
ära	doc_491521502076_item	3367524	et	4	main
kuluma	doc_491521502076_item	3367525	et	3	main
изнашиваться	doc_491521502076_item	3367526	et	2	main
lahkuma	doc_491521502076_item	3367536	et	3	main
tervenema	doc_491521502076_item	3367542	et	3	main
iii	doc_491521502076_item	3367551	et	4	main
kes	doc_491521502076_item	3367592	et	4	main
kosmeetikavahendeid	doc_491521502076_item	3367594	et	3	main
inimene	doc_491521502076_item	3367597	et	3	main
mis	doc_491521502076_item	3367604	et	4	main
ravivad	doc_491521502076_item	3367605	et	4	main
i	doc_491521502076_item	3367507	et	4	main
umbusklik	doc_491521502076_item	3367514	et	3	main
jäätmed	doc_491521502076_item	3367516	et	3	main
tulema	doc_491521502076_item	3367528	et	4	main
содержать	doc_491521502076_item	3367529	et	2	main
ii	doc_491521502076_item	3367530	et	4	main
kirjutage	doc_491521502076_item	3367531	et	3	main
minema	doc_491521502076_item	3367535	et	3	main
haigeks	doc_491521502076_item	3367537	et	4	main
põdenema	doc_491521502076_item	3367539	et	4	main
saada	doc_491521502076_item	3367549	et	4	main
kätte	doc_491521502076_item	3367550	et	4	main
anti	doc_491521502076_item	3367559	et	3	main
kreemiga	doc_491521502076_item	3367602	et	4	main
šampoone	doc_491521502076_item	3367603	et	2	main
välismalt	doc_491521502076_item	3367617	et	4	main
pesu	doc_491521502076_item	3367626	et	4	main
süüakse	doc_491521502076_item	3367629	et	3	main
toidust	doc_491521502076_item	3367631	et	4	main
mida	doc_491521502076_item	3367633	et	4	main
ostetakse	doc_491521502076_item	3367634	et	3	main
ostetav	doc_491521502076_item	3367637	et	4	main
kaup	doc_491521502076_item	3367638	et	3	main
kaanega	doc_491521502076_item	3367639	et	3	main
valed	doc_491521502076_item	3367651	et	3	main
koera	doc_491521502076_item	3367654	et	4	main
peab	doc_491521502076_item	3367655	et	4	main
õpetama	doc_491521502076_item	3367659	et	3	main
selle	doc_491521502076_item	3367660	et	4	main
pintsaku	doc_491521502076_item	3367661	et	3	main
õmblused	doc_491521502076_item	3367662	et	3	main
käsitsevad	doc_491521502076_item	3367663	et	4	main
puänti	doc_491521502076_item	3367671	et	4	main
seda	doc_491521502076_item	3367672	et	3	main
inimesed	doc_491521502076_item	3367679	et	3	main
tulemusi	doc_491521502076_item	3367688	et	4	main
kontrolltöö	doc_491521502076_item	3367506	et	4	main
tõlkige	doc_491521502076_item	3367508	et	3	main
taipama	doc_491521502076_item	3367509	et	3	main
догадываться	doc_491521502076_item	3367510	et	2	main
плеснеть	doc_491521502076_item	3367512	et	2	main
заплеснеть	doc_491521502076_item	3367513	et	2	main
недоверчивый	doc_491521502076_item	3367515	et	2	main
остатки	doc_491521502076_item	3367517	et	2	main
распылять	doc_491521502076_item	3367519	et	2	main
посильный	doc_491521502076_item	3367521	et	2	main
lakkama	doc_491521502076_item	3367522	et	3	main
tõhus	doc_491521502076_item	3367523	et	4	main
ühesõnalised	doc_491521502076_item	3367532	et	4	main
andma	doc_491521502076_item	3367558	et	3	main
pakkuti	doc_491521502076_item	3367561	et	4	main
niisutava	doc_491521502076_item	3367601	et	4	main
juukseid	doc_491521502076_item	3367607	et	3	main
toodetavatele	doc_491521502076_item	3367618	et	4	main
kreemidele	doc_491521502076_item	3367619	et	3	main
pestav	doc_491521502076_item	3367625	et	4	main
mida	doc_491521502076_item	3367628	et	4	main
söödavast	doc_491521502076_item	3367630	et	4	main
kaupu	doc_491521502076_item	3367632	et	3	main
maha	doc_491521502076_item	3367649	et	4	main
alla	doc_491521502076_item	3367650	et	3	main
kahjustasid	doc_491521502076_item	3367667	et	4	main
on	doc_491521502076_item	3367674	et	4	main
peaksid	doc_491521502076_item	3367680	et	4	main
rohkem	doc_491521502076_item	3367682	et	4	main
vii	doc_491521502076_item	3367689	et	4	main
система	doc_491521502076_item	3367691	et	2	main
переработки	doc_491521502076_item	3367692	et	2	main
разработана	doc_491521502076_item	3367695	et	2	main
kataloogist	doc_491521502076_item	3367707	et	3	main
aega	doc_491521502076_item	3367710	et	4	main
фирма	doc_491521502076_item	3367712	et	2	main
привлекает	doc_491521502076_item	3367713	et	2	main
подарками	doc_491521502076_item	3367715	et	2	main
kodus	doc_491521502076_item	3367738	et	4	main
kassis	doc_491521502076_item	3367767	et	3	main
hallitama	doc_491521502076_item	3367511	et	3	main
pihustama	doc_491521502076_item	3367518	et	3	main
jõukohane	doc_491521502076_item	3367520	et	4	main
ära	doc_491521502076_item	3367534	et	4	main
jääma	doc_491521502076_item	3367538	et	4	main
krappama	doc_491521502076_item	3367548	et	4	main
öeldi	doc_491521502076_item	3367557	et	3	main
pakkuma	doc_491521502076_item	3367560	et	3	main
lubama	doc_491521502076_item	3367562	et	3	main
tegema	doc_491521502076_item	3367564	et	3	main
vahenditeta	doc_491521502076_item	3367590	et	3	main
inimest	doc_491521502076_item	3367591	et	3	main
müüb	doc_491521502076_item	3367593	et	3	main
müuv	doc_491521502076_item	3367596	et	4	main
raviv	doc_491521502076_item	3367608	et	4	main
välismaal	doc_491521502076_item	3367616	et	4	main
käsitsi	doc_491521502076_item	3367624	et	3	main
harva	doc_491521502076_item	3367636	et	4	main
mida	doc_491521502076_item	3367640	et	4	main
saab	doc_491521502076_item	3367641	et	3	main
kergesti	doc_491521502076_item	3367642	et	3	main
avada	doc_491521502076_item	3367643	et	3	main
kergest	doc_491521502076_item	3367644	et	3	main
avatav	doc_491521502076_item	3367645	et	4	main
kaanega	doc_491521502076_item	3367646	et	3	main
suurt	doc_491521502076_item	3367653	et	3	main
ilmtingimata	doc_491521502076_item	3367657	et	3	main
kisuvad	doc_491521502076_item	3367664	et	3	main
luituvad	doc_491521502076_item	3367665	et	4	main
artiklid	doc_491521502076_item	3367666	et	3	main
plaani	doc_491521502076_item	3367673	et	4	main
järeldusi	doc_491521502076_item	3367686	et	4	main
не	doc_491521502076_item	3367694	et	2	main
on	doc_491521502076_item	3367698	et	4	main
по	doc_491521502076_item	3367701	et	2	main
экономите	doc_491521502076_item	3367704	et	2	main
õigesse	doc_491521502076_item	3367746	et	3	main
vormi	doc_491521502076_item	3367747	et	4	main
see	doc_491521502076_item	3367748	et	3	main
näeb	doc_491521502076_item	3367749	et	3	main
jube	doc_491521502076_item	3367750	et	4	main
välja	doc_491521502076_item	3367752	et	4	main
jube	doc_491521502076_item	3367751	et	4	main
on	doc_491521502076_item	3367753	et	4	main
väga	doc_491521502076_item	3367754	et	3	main
piinlik	doc_491521502076_item	3367755	et	3	main
piinlik	doc_491521502076_item	3367756	et	3	main
kui	doc_491521502076_item	3367757	et	3	main
inimesed	doc_491521502076_item	3367758	et	3	main
ei	doc_491521502076_item	3367759	et	4	main
enda	doc_491521502076_item	3367761	et	4	main
korista	doc_491521502076_item	3367760	et	4	main
järelt	doc_491521502076_item	3367762	et	4	main
vihma	doc_491521502076_item	3367763	et	4	main
toime	doc_491521502076_item	3367527	et	4	main
sünonüümid	doc_491521502076_item	3367533	et	3	main
terveks	doc_491521502076_item	3367540	et	4	main
saama	doc_491521502076_item	3367541	et	4	main
maha	doc_491521502076_item	3367543	et	4	main
jätma	doc_491521502076_item	3367544	et	3	main
paidama	doc_491521502076_item	3367545	et	4	main
kinni	doc_491521502076_item	3367546	et	3	main
püüdma	doc_491521502076_item	3367547	et	3	main
mida	doc_491521502076_item	3367552	et	4	main
tehti	doc_491521502076_item	3367553	et	3	main
nõudma	doc_491521502076_item	3367554	et	3	main
nõuti	doc_491521502076_item	3367555	et	3	main
ütlema	doc_491521502076_item	3367556	et	3	main
lubati	doc_491521502076_item	3367563	et	3	main
tehti	doc_491521502076_item	3367565	et	3	main
laskma	doc_491521502076_item	3367566	et	3	main
lasti	doc_491521502076_item	3367567	et	4	main
saatma	doc_491521502076_item	3367568	et	3	main
saadeti	doc_491521502076_item	3367569	et	3	main
rääkima	doc_491521502076_item	3367570	et	3	main
räägiti	doc_491521502076_item	3367571	et	3	main
teatama	doc_491521502076_item	3367572	et	4	main
teatati	doc_491521502076_item	3367573	et	3	main
iv	doc_491521502076_item	3367574	et	4	main
kasutage	doc_491521502076_item	3367575	et	3	main
v-kesksõna	doc_491521502076_item	3367576	et	4	main
prügi	doc_491521502076_item	3367577	et	4	main
mis	doc_491521502076_item	3367578	et	4	main
tekib	doc_491521502076_item	3367579	et	3	main
kodus	doc_491521502076_item	3367580	et	4	main
kodus	doc_491521502076_item	3367581	et	4	main
tekkiv	doc_491521502076_item	3367582	et	4	main
prügi	doc_491521502076_item	3367583	et	4	main
vahenditeta	doc_491521502076_item	3367584	et	3	main
mis	doc_491521502076_item	3367585	et	4	main
värskendavad	doc_491521502076_item	3367586	et	4	main
õhku	doc_491521502076_item	3367587	et	4	main
õhku	doc_491521502076_item	3367588	et	4	main
värskendava	doc_491521502076_item	3367589	et	4	main
kosmeetikavendeid	doc_491521502076_item	3367595	et	4	main
kreemiga	doc_491521502076_item	3367598	et	4	main
mis	doc_491521502076_item	3367599	et	4	main
niisutab	doc_491521502076_item	3367600	et	3	main
šampoon	doc_491521502076_item	3367609	et	2	main
v	doc_491521502076_item	3367610	et	4	main
kreemidele	doc_491521502076_item	3367613	et	3	main
mis	doc_491521502076_item	3367614	et	4	main
toodetakse	doc_491521502076_item	3367615	et	3	main
mida	doc_491521502076_item	3367621	et	4	main
pestakse	doc_491521502076_item	3367622	et	3	main
käsitsi	doc_491521502076_item	3367623	et	3	main
harva	doc_491521502076_item	3367635	et	4	main
sõnad	doc_491521502076_item	3367652	et	4	main
kordamööda	doc_491521502076_item	3367656	et	3	main
omapead	doc_491521502076_item	3367658	et	3	main
firma	doc_491521502076_item	3367668	et	4	main
olemust	doc_491521502076_item	3367669	et	3	main
raske	doc_491521502076_item	3367675	et	4	main
liigitada	doc_491521502076_item	3367676	et	3	main
sisaldada	doc_491521502076_item	3367677	et	3	main
tagajärgi	doc_491521502076_item	3367687	et	4	main
prügi	doc_491521502076_item	3367696	et	4	main
заказывая	doc_491521502076_item	3367700	et	2	main
вы	doc_491521502076_item	3367703	et	2	main
tellides	doc_491521502076_item	3367706	et	3	main
teie	doc_491521502076_item	3367708	et	4	main
свободного	doc_491521502076_item	3367724	et	2	main
у	doc_491521502076_item	3367726	et	2	main
есть	doc_491521502076_item	3367728	et	2	main
спокойно	doc_491521502076_item	3367731	et	2	main
kataloogi	doc_491521502076_item	3367739	et	4	main
karva	doc_491521502076_item	3367771	et	4	main
mul	doc_491521502076_item	3367772	et	3	main
juukseid	doc_491521502076_item	3367606	et	3	main
kasutage	doc_491521502076_item	3367611	et	3	main
tav-kesksõna	doc_491521502076_item	3367612	et	4	main
pesu	doc_491521502076_item	3367620	et	4	main
toidust	doc_491521502076_item	3367627	et	4	main
vi	doc_491521502076_item	3367647	et	4	main
tõmmake	doc_491521502076_item	3367648	et	3	main
mainet	doc_491521502076_item	3367670	et	4	main
teostada	doc_491521502076_item	3367678	et	3	main
endale	doc_491521502076_item	3367681	et	4	main
teadvustama	doc_491521502076_item	3367683	et	3	main
keskkonna	doc_491521502076_item	3367684	et	3	main
reostamise	doc_491521502076_item	3367685	et	4	main
tõlkige	doc_491521502076_item	3367690	et	3	main
мусора	doc_491521502076_item	3367693	et	2	main
время	doc_491521502076_item	3367705	et	2	main
kingitustega	doc_491521502076_item	3367719	et	4	main
нарушает	doc_491521502076_item	3367721	et	2	main
рынка	doc_491521502076_item	3367725	et	2	main
вас	doc_491521502076_item	3367727	et	2	main
дома	doc_491521502076_item	3367730	et	2	main
каталог	doc_491521502076_item	3367733	et	2	main
uurida	doc_491521502076_item	3367740	et	3	main
viii	doc_491521502076_item	3367741	et	4	main
sajab	doc_491521502076_item	3367764	et	3	main
hirmsalt	doc_491521502076_item	3367770	et	4	main
süsteem	doc_491521502076_item	3367697	et	3	main
töötamata	doc_491521502076_item	3367699	et	4	main
каталогу	doc_491521502076_item	3367702	et	2	main
hoijate	doc_491521502076_item	3367709	et	4	main
kokku	doc_491521502076_item	3367711	et	3	main
клиентов	doc_491521502076_item	3367714	et	2	main
firma	doc_491521502076_item	3367716	et	4	main
meelitab	doc_491521502076_item	3367717	et	3	main
kliente	doc_491521502076_item	3367718	et	3	main
rahulikult	doc_491521502076_item	3367737	et	4	main
lakkamatu	doc_491521502076_item	3367765	et	4	main
lakkamatult	doc_491521502076_item	3367766	et	4	main
on	doc_491521502076_item	3367773	et	4	main
ebameeldiv	doc_491521502076_item	3367774	et	3	main
ebameeldiv	doc_491521502076_item	3367775	et	3	main
seda	doc_491521502076_item	3367776	et	3	main
это	doc_491521502076_item	3367720	et	2	main
принципы	doc_491521502076_item	3367722	et	2	main
торговли	doc_491521502076_item	3367723	et	2	main
возможность	doc_491521502076_item	3367729	et	2	main
изучить	doc_491521502076_item	3367732	et	2	main
teil	doc_491521502076_item	3367734	et	4	main
on	doc_491521502076_item	3367735	et	4	main
võimalus	doc_491521502076_item	3367736	et	3	main
pange	doc_491521502076_item	3367742	et	4	main
sulgudes	doc_491521502076_item	3367743	et	4	main
olevad	doc_491521502076_item	3367744	et	4	main
sõnad	doc_491521502076_item	3367745	et	4	main
ajavad	doc_491521502076_item	3367768	et	4	main
hirmus	doc_491521502076_item	3367769	et	4	main
vaadata	doc_491521502076_item	3367777	et	4	main
отходы	doc_491521502077_item	3368577	et	2	main
посильный	doc_491521502077_item	3368581	et	2	main
tõhus	doc_491521502077_item	3368584	et	4	main
ära	doc_491521502077_item	3368586	et	4	main
haigestuma	doc_491521502077_item	3368601	et	3	main
nõuti	doc_491521502077_item	3368612	et	3	main
ütlema	doc_491521502077_item	3368613	et	3	main
õeldi	doc_491521502077_item	3368614	et	4	main
tehti	doc_491521502077_item	3368622	et	3	main
prügi	doc_491521502077_item	3368634	et	4	main
mis	doc_491521502077_item	3368635	et	4	main
vahenditeta	doc_491521502077_item	3368641	et	3	main
kes	doc_491521502077_item	3368649	et	4	main
müüb	doc_491521502077_item	3368650	et	3	main
kontrolltöö	doc_491521502077_item	3368567	et	4	main
плесневеть	doc_491521502077_item	3368573	et	2	main
umbusklik	doc_491521502077_item	3368574	et	3	main
распылять	doc_491521502077_item	3368579	et	2	main
лизать	doc_491521502077_item	3368583	et	2	main
эффективный	doc_491521502077_item	3368585	et	2	main
изнашиваться	doc_491521502077_item	3368588	et	2	main
minema	doc_491521502077_item	3368597	et	3	main
terveks	doc_491521502077_item	3368602	et	4	main
maha	doc_491521502077_item	3368604	et	4	main
jätma	doc_491521502077_item	3368605	et	3	main
kinni	doc_491521502077_item	3368606	et	3	main
püüdma	doc_491521502077_item	3368607	et	3	main
iii	doc_491521502077_item	3368608	et	4	main
pakuti	doc_491521502077_item	3368618	et	3	main
tekkiv	doc_491521502077_item	3368638	et	4	main
mis	doc_491521502077_item	3368642	et	4	main
õhku	doc_491521502077_item	3368644	et	4	main
kosmeetikavahendeid	doc_491521502077_item	3368651	et	3	main
niisutava	doc_491521502077_item	3368658	et	4	main
kasutage	doc_491521502077_item	3368668	et	3	main
toodetavatele	doc_491521502077_item	3368674	et	4	main
pesu	doc_491521502077_item	3368677	et	4	main
pestav	doc_491521502077_item	3368681	et	4	main
pesu	doc_491521502077_item	3368683	et	4	main
harva	doc_491521502077_item	3368694	et	4	main
raske	doc_491521502077_item	3368732	et	4	main
inimesed	doc_491521502077_item	3368736	et	3	main
tagajärgi	doc_491521502077_item	3368744	et	4	main
tulemusi	doc_491521502077_item	3368745	et	4	main
заказывая	doc_491521502077_item	3368753	et	2	main
время	doc_491521502077_item	3368758	et	2	main
tellides	doc_491521502077_item	3368760	et	3	main
see	doc_491521502077_item	3368800	et	3	main
pihustama	doc_491521502077_item	3368578	et	3	main
jõukohane	doc_491521502077_item	3368580	et	4	main
lakkama	doc_491521502077_item	3368582	et	3	main
ühesõnalised	doc_491521502077_item	3368594	et	4	main
sünonüümid	doc_491521502077_item	3368595	et	3	main
ära	doc_491521502077_item	3368596	et	4	main
lahkuma	doc_491521502077_item	3368598	et	3	main
haigeks	doc_491521502077_item	3368599	et	4	main
lubama	doc_491521502077_item	3368619	et	3	main
tegema	doc_491521502077_item	3368621	et	3	main
lasti	doc_491521502077_item	3368624	et	4	main
teatama	doc_491521502077_item	3368629	et	4	main
teatati	doc_491521502077_item	3368630	et	3	main
iv	doc_491521502077_item	3368631	et	4	main
kasutage	doc_491521502077_item	3368632	et	3	main
kodus	doc_491521502077_item	3368637	et	4	main
müüvat	doc_491521502077_item	3368652	et	4	main
kosmeetikavahendeid	doc_491521502077_item	3368653	et	3	main
inimest	doc_491521502077_item	3368654	et	3	main
kreemiga	doc_491521502077_item	3368655	et	4	main
v	doc_491521502077_item	3368667	et	4	main
pestakse	doc_491521502077_item	3368679	et	3	main
käsitsi	doc_491521502077_item	3368682	et	3	main
kaupu	doc_491521502077_item	3368689	et	3	main
harva	doc_491521502077_item	3368692	et	4	main
kaupu	doc_491521502077_item	3368695	et	3	main
kergesti	doc_491521502077_item	3368699	et	3	main
avatava	doc_491521502077_item	3368701	et	4	main
vi	doc_491521502077_item	3368704	et	4	main
tõmmake	doc_491521502077_item	3368705	et	3	main
maha	doc_491521502077_item	3368706	et	4	main
alla	doc_491521502077_item	3368707	et	3	main
valed	doc_491521502077_item	3368708	et	3	main
endale	doc_491521502077_item	3368738	et	4	main
keskkonna	doc_491521502077_item	3368741	et	3	main
reostamise	doc_491521502077_item	3368742	et	4	main
система	doc_491521502077_item	3368748	et	2	main
мусора	doc_491521502077_item	3368750	et	2	main
каталогу	doc_491521502077_item	3368755	et	2	main
jubedalt	doc_491521502077_item	3368803	et	4	main
piinlik	doc_491521502077_item	3368807	et	3	main
piinlik	doc_491521502077_item	3368808	et	3	main
kui	doc_491521502077_item	3368809	et	3	main
inimesed	doc_491521502077_item	3368810	et	3	main
ei	doc_491521502077_item	3368811	et	4	main
korista	doc_491521502077_item	3368812	et	4	main
enda	doc_491521502077_item	3368813	et	4	main
järelt	doc_491521502077_item	3368814	et	4	main
vihma	doc_491521502077_item	3368815	et	4	main
sajab	doc_491521502077_item	3368816	et	3	main
lakkamatu	doc_491521502077_item	3368817	et	4	main
lakkamatult	doc_491521502077_item	3368818	et	4	main
kassis	doc_491521502077_item	3368819	et	3	main
ajavad	doc_491521502077_item	3368820	et	4	main
hirmus	doc_491521502077_item	3368821	et	4	main
hirmsasti	doc_491521502077_item	3368822	et	3	main
karva	doc_491521502077_item	3368823	et	4	main
mul	doc_491521502077_item	3368824	et	3	main
on	doc_491521502077_item	3368825	et	4	main
ebameeldiv	doc_491521502077_item	3368826	et	3	main
ebameeldiv	doc_491521502077_item	3368827	et	3	main
seda	doc_491521502077_item	3368828	et	3	main
vaadata	doc_491521502077_item	3368829	et	4	main
i	doc_491521502077_item	3368568	et	4	main
tõlkige	doc_491521502077_item	3368569	et	3	main
догадываться	doc_491521502077_item	3368571	et	2	main
jäätmed	doc_491521502077_item	3368576	et	3	main
kuluma	doc_491521502077_item	3368587	et	3	main
toime	doc_491521502077_item	3368589	et	4	main
tulema	doc_491521502077_item	3368590	et	4	main
справляться	doc_491521502077_item	3368591	et	2	main
ii	doc_491521502077_item	3368592	et	4	main
kirjutage	doc_491521502077_item	3368593	et	3	main
jääma	doc_491521502077_item	3368600	et	4	main
saama	doc_491521502077_item	3368603	et	4	main
andma	doc_491521502077_item	3368615	et	3	main
anti	doc_491521502077_item	3368616	et	3	main
pakkuma	doc_491521502077_item	3368617	et	3	main
lubati	doc_491521502077_item	3368620	et	3	main
laskma	doc_491521502077_item	3368623	et	3	main
saatma	doc_491521502077_item	3368625	et	3	main
saadeti	doc_491521502077_item	3368626	et	3	main
rääkima	doc_491521502077_item	3368627	et	3	main
räägiti	doc_491521502077_item	3368628	et	3	main
tekib	doc_491521502077_item	3368636	et	3	main
kodus	doc_491521502077_item	3368639	et	4	main
värskendavate	doc_491521502077_item	3368645	et	4	main
õhku	doc_491521502077_item	3368646	et	4	main
vahenditeta	doc_491521502077_item	3368647	et	3	main
inimest	doc_491521502077_item	3368648	et	3	main
niisutab	doc_491521502077_item	3368657	et	3	main
šampoone	doc_491521502077_item	3368660	et	2	main
ravivad	doc_491521502077_item	3368662	et	4	main
juukseid	doc_491521502077_item	3368663	et	3	main
värvivaid	doc_491521502077_item	3368664	et	4	main
juukseid	doc_491521502077_item	3368665	et	3	main
šampoone	doc_491521502077_item	3368666	et	2	main
kreemidele	doc_491521502077_item	3368670	et	3	main
välismaal	doc_491521502077_item	3368673	et	4	main
välismaal	doc_491521502077_item	3368675	et	4	main
kreemidele	doc_491521502077_item	3368676	et	3	main
käsitsi	doc_491521502077_item	3368680	et	3	main
toidust	doc_491521502077_item	3368688	et	4	main
sõnad	doc_491521502077_item	3368709	et	4	main
suurt	doc_491521502077_item	3368710	et	3	main
liigitada	doc_491521502077_item	3368733	et	3	main
järeldusi	doc_491521502077_item	3368743	et	4	main
не	doc_491521502077_item	3368751	et	2	main
экономите	doc_491521502077_item	3368757	et	2	main
aega	doc_491521502077_item	3368763	et	4	main
клиентов	doc_491521502077_item	3368766	et	2	main
näeb	doc_491521502077_item	3368801	et	3	main
väga	doc_491521502077_item	3368806	et	3	main
taipama	doc_491521502077_item	3368570	et	3	main
hallitama	doc_491521502077_item	3368572	et	3	main
недоверчивый	doc_491521502077_item	3368575	et	2	main
mida	doc_491521502077_item	3368609	et	4	main
tehti	doc_491521502077_item	3368610	et	3	main
nõudma	doc_491521502077_item	3368611	et	3	main
v-kesksõna	doc_491521502077_item	3368633	et	4	main
prügi	doc_491521502077_item	3368640	et	4	main
värskendavad	doc_491521502077_item	3368643	et	4	main
mis	doc_491521502077_item	3368656	et	4	main
kreemiga	doc_491521502077_item	3368659	et	4	main
mis	doc_491521502077_item	3368661	et	4	main
tav-kesksõna	doc_491521502077_item	3368669	et	4	main
toodetakse	doc_491521502077_item	3368672	et	3	main
söödavast	doc_491521502077_item	3368687	et	4	main
ostetakse	doc_491521502077_item	3368691	et	3	main
ostetavaid	doc_491521502077_item	3368693	et	4	main
mida	doc_491521502077_item	3368697	et	4	main
saab	doc_491521502077_item	3368698	et	3	main
avada	doc_491521502077_item	3368700	et	3	main
kiiresti	doc_491521502077_item	3368702	et	3	main
kaanega	doc_491521502077_item	3368703	et	3	main
kordamööda	doc_491521502077_item	3368713	et	3	main
sisaldada	doc_491521502077_item	3368734	et	3	main
peaksid	doc_491521502077_item	3368737	et	4	main
rohkem	doc_491521502077_item	3368739	et	4	main
teadvustama	doc_491521502077_item	3368740	et	3	main
vii	doc_491521502077_item	3368746	et	4	main
tõlkige	doc_491521502077_item	3368747	et	3	main
переработки	doc_491521502077_item	3368749	et	2	main
по	doc_491521502077_item	3368754	et	2	main
säästate	doc_491521502077_item	3368762	et	3	main
привлекает	doc_491521502077_item	3368765	et	2	main
jube	doc_491521502077_item	3368802	et	4	main
välja	doc_491521502077_item	3368804	et	4	main
mis	doc_491521502077_item	3368671	et	4	main
mida	doc_491521502077_item	3368678	et	4	main
toidust	doc_491521502077_item	3368684	et	4	main
mida	doc_491521502077_item	3368685	et	4	main
süüakse	doc_491521502077_item	3368686	et	3	main
mida	doc_491521502077_item	3368690	et	4	main
kaanega	doc_491521502077_item	3368696	et	3	main
koera	doc_491521502077_item	3368711	et	4	main
peab	doc_491521502077_item	3368712	et	4	main
ilmtingimata	doc_491521502077_item	3368714	et	3	main
omapead	doc_491521502077_item	3368715	et	3	main
õpetama	doc_491521502077_item	3368716	et	3	main
selle	doc_491521502077_item	3368717	et	4	main
pintsaku	doc_491521502077_item	3368718	et	3	main
õmblused	doc_491521502077_item	3368719	et	3	main
käsitsevad	doc_491521502077_item	3368720	et	4	main
kisuvad	doc_491521502077_item	3368721	et	3	main
luituvad	doc_491521502077_item	3368722	et	4	main
artiklid	doc_491521502077_item	3368723	et	3	main
kahjustasid	doc_491521502077_item	3368724	et	4	main
firma	doc_491521502077_item	3368725	et	4	main
olemust	doc_491521502077_item	3368726	et	3	main
mainet	doc_491521502077_item	3368727	et	4	main
puänti	doc_491521502077_item	3368728	et	4	main
seda	doc_491521502077_item	3368729	et	3	main
plaani	doc_491521502077_item	3368730	et	4	main
on	doc_491521502077_item	3368731	et	4	main
teostada	doc_491521502077_item	3368735	et	3	main
разработана	doc_491521502077_item	3368752	et	2	main
вы	doc_491521502077_item	3368756	et	2	main
kataloogist	doc_491521502077_item	3368759	et	3	main
te	doc_491521502077_item	3368761	et	4	main
фирма	doc_491521502077_item	3368764	et	2	main
подарками	doc_491521502077_item	3368767	et	2	main
firma	doc_491521502077_item	3368768	et	4	main
meelitab	doc_491521502077_item	3368769	et	3	main
kliente	doc_491521502077_item	3368770	et	3	main
kingitustega	doc_491521502077_item	3368771	et	4	main
это	doc_491521502077_item	3368772	et	2	main
нарушает	doc_491521502077_item	3368773	et	2	main
принципы	doc_491521502077_item	3368774	et	2	main
торговли	doc_491521502077_item	3368775	et	2	main
свободного	doc_491521502077_item	3368776	et	2	main
рынка	doc_491521502077_item	3368777	et	2	main
у	doc_491521502077_item	3368778	et	2	main
вас	doc_491521502077_item	3368779	et	2	main
есть	doc_491521502077_item	3368780	et	2	main
дома	doc_491521502077_item	3368782	et	2	main
возможность	doc_491521502077_item	3368781	et	2	main
спокойно	doc_491521502077_item	3368783	et	2	main
изучить	doc_491521502077_item	3368784	et	2	main
каталог	doc_491521502077_item	3368785	et	2	main
teil	doc_491521502077_item	3368786	et	4	main
on	doc_491521502077_item	3368787	et	4	main
võimalus	doc_491521502077_item	3368788	et	3	main
kodus	doc_491521502077_item	3368789	et	4	main
kataloogi	doc_491521502077_item	3368790	et	4	main
rahulikult	doc_491521502077_item	3368791	et	4	main
uurida	doc_491521502077_item	3368792	et	3	main
viii	doc_491521502077_item	3368793	et	4	main
pange	doc_491521502077_item	3368794	et	4	main
sulgudes	doc_491521502077_item	3368795	et	4	main
olevad	doc_491521502077_item	3368796	et	4	main
sõnad	doc_491521502077_item	3368797	et	4	main
õigesse	doc_491521502077_item	3368798	et	3	main
vormi	doc_491521502077_item	3368799	et	4	main
on	doc_491521502077_item	3368805	et	4	main
juhend	doc_542009824806_item	3369146	et	3	main
tohi	doc_542009824806_item	3369151	et	4	main
peale	doc_542009824806_item	3369153	et	4	main
tohi	doc_542009824806_item	3369158	et	4	main
mobiiltelefoni	doc_542009824806_item	3369181	et	4	main
tohib	doc_542009824806_item	3369202	et	3	main
otsas	doc_542009824806_item	3369206	et	4	main
5	doc_542009824806_item	3369207	et	2	main
mobiiltelefonilt	doc_542009824806_item	3369208	et	3	main
tohib	doc_542009824806_item	3369209	et	3	main
pildistama	doc_542009824806_item	3369210	et	3	main
mobiiltelefon	doc_542009824806_item	3369147	et	3	main
ei	doc_542009824806_item	3369150	et	4	main
külmkappi	doc_542009824806_item	3369152	et	4	main
ei	doc_542009824806_item	3369157	et	4	main
tohib	doc_542009824806_item	3369183	et	3	main
mtelefon	doc_542009824806_item	3369186	et	4	main
kaasa	doc_542009824806_item	3369190	et	4	main
3	doc_542009824806_item	3369192	et	2	main
kinnitama	doc_542009824806_item	3369195	et	3	main
ja	doc_542009824806_item	3369197	et	3	main
väikesed	doc_542009824806_item	3369198	et	4	main
mänguasjad	doc_542009824806_item	3369199	et	3	main
4	doc_542009824806_item	3369200	et	2	main
mobiiltelefon	doc_542009824806_item	3369201	et	3	main
1	doc_542009824806_item	3369148	et	2	main
lastele	doc_542009824806_item	3369159	et	4	main
mobiiltelefon	doc_542009824806_item	3369162	et	3	main
tohi	doc_542009824806_item	3369164	et	4	main
viskama	doc_542009824806_item	3369165	et	3	main
4	doc_542009824806_item	3369166	et	2	main
mobiiltelefon	doc_542009824806_item	3369167	et	3	main
ei	doc_542009824806_item	3369168	et	4	main
ei	doc_542009824806_item	3369163	et	4	main
tohi	doc_542009824806_item	3369169	et	4	main
kasutada	doc_542009824806_item	3369170	et	3	main
tihti	doc_542009824806_item	3369171	et	3	main
kui	doc_542009824806_item	3369172	et	3	main
oled	doc_542009824806_item	3369173	et	3	main
rase	doc_542009824806_item	3369174	et	3	main
5	doc_542009824806_item	3369175	et	2	main
mobiiltelefoniga	doc_542009824806_item	3369176	et	4	main
ei	doc_542009824806_item	3369177	et	4	main
tohi	doc_542009824806_item	3369178	et	4	main
ujuma	doc_542009824806_item	3369179	et	3	main
1	doc_542009824806_item	3369180	et	2	main
2	doc_542009824806_item	3369155	et	2	main
mobiiltelefon	doc_542009824806_item	3369156	et	3	main
3	doc_542009824806_item	3369161	et	2	main
teel	doc_542009824806_item	3369182	et	4	main
võtma	doc_542009824806_item	3369191	et	3	main
mobiiltelefonile	doc_542009824806_item	3369193	et	3	main
kleebi	doc_542009824806_item	3369196	et	4	main
kaela	doc_542009824806_item	3369204	et	4	main
paela	doc_542009824806_item	3369205	et	4	main
mobiiltelefon	doc_542009824806_item	3369149	et	3	main
panna	doc_542009824806_item	3369154	et	4	main
andma	doc_542009824806_item	3369160	et	3	main
2	doc_542009824806_item	3369185	et	2	main
tohib	doc_542009824806_item	3369187	et	3	main
poole	doc_542009824806_item	3369189	et	4	main
tohib	doc_542009824806_item	3369194	et	3	main
räägima	doc_542009824806_item	3369184	et	4	main
igale	doc_542009824806_item	3369188	et	3	main
riputada	doc_542009824806_item	3369203	et	3	main
сильный	doc_491521502071_item	3370076	et	2	main
ii	doc_491521502071_item	3370088	et	4	main
lahkuma	doc_491521502071_item	3370094	et	3	main
jääma	doc_491521502071_item	3370096	et	4	main
jätma	doc_491521502071_item	3370102	et	3	main
õhku	doc_491521502071_item	3370144	et	4	main
kes	doc_491521502071_item	3370148	et	4	main
kosmeetikavahendeid	doc_491521502071_item	3370150	et	3	main
müüvat	doc_491521502071_item	3370152	et	4	main
mis	doc_491521502071_item	3370160	et	4	main
juukseid	doc_491521502071_item	3370162	et	3	main
toodetakse	doc_491521502071_item	3370171	et	3	main
välismaal	doc_491521502071_item	3370172	et	4	main
pesu	doc_491521502071_item	3370176	et	4	main
pestakse	doc_491521502071_item	3370178	et	3	main
pestava	doc_491521502071_item	3370181	et	3	main
ostetava	doc_491521502071_item	3370193	et	4	main
kergesti	doc_491521502071_item	3370198	et	3	main
avatava	doc_491521502071_item	3370201	et	4	main
kordamööda	doc_491521502071_item	3370212	et	3	main
õpetama	doc_491521502071_item	3370215	et	3	main
pintsaku	doc_491521502071_item	3370217	et	3	main
käsitsevad	doc_491521502071_item	3370219	et	4	main
leiutud	doc_491521502071_item	3370256	et	4	main
i	doc_491521502071_item	3370061	et	4	main
taipama	doc_491521502071_item	3370063	et	3	main
определенный	doc_491521502071_item	3370069	et	2	main
jäätmed	doc_491521502071_item	3370070	et	3	main
pihustama	doc_491521502071_item	3370072	et	3	main
усердный	doc_491521502071_item	3370077	et	2	main
эффективный	doc_491521502071_item	3370081	et	2	main
kuluma	doc_491521502071_item	3370083	et	3	main
toime	doc_491521502071_item	3370085	et	4	main
tulema	doc_491521502071_item	3370086	et	4	main
справляться	doc_491521502071_item	3370087	et	2	main
ära	doc_491521502071_item	3370092	et	4	main
haigeks	doc_491521502071_item	3370095	et	4	main
haigestuma	doc_491521502071_item	3370097	et	3	main
iii	doc_491521502071_item	3370107	et	4	main
tehti	doc_491521502071_item	3370109	et	3	main
nõudma	doc_491521502071_item	3370110	et	3	main
nõuti	doc_491521502071_item	3370111	et	3	main
ütlema	doc_491521502071_item	3370112	et	3	main
andma	doc_491521502071_item	3370114	et	3	main
pakuti	doc_491521502071_item	3370117	et	3	main
värskendava	doc_491521502071_item	3370145	et	4	main
kreemiga	doc_491521502071_item	3370154	et	4	main
mis	doc_491521502071_item	3370155	et	4	main
niisutab	doc_491521502071_item	3370156	et	3	main
ravivad	doc_491521502071_item	3370161	et	4	main
juukseid	doc_491521502071_item	3370163	et	3	main
šampoone	doc_491521502071_item	3370165	et	2	main
välismaal	doc_491521502071_item	3370173	et	4	main
söödavast	doc_491521502071_item	3370186	et	4	main
mida	doc_491521502071_item	3370196	et	4	main
vi	doc_491521502071_item	3370203	et	4	main
peab	doc_491521502071_item	3370211	et	4	main
selle	doc_491521502071_item	3370216	et	4	main
экономите	doc_491521502071_item	3370261	et	2	main
kataloogi	doc_491521502071_item	3370264	et	4	main
подарками	doc_491521502071_item	3370272	et	2	main
peibutab	doc_491521502071_item	3370274	et	3	main
jõukohane	doc_491521502071_item	3370075	et	4	main
лизать	doc_491521502071_item	3370079	et	2	main
ära	doc_491521502071_item	3370082	et	4	main
изнашиваться	doc_491521502071_item	3370084	et	2	main
ühesõnalised	doc_491521502071_item	3370090	et	4	main
maha	doc_491521502071_item	3370101	et	4	main
hülgama	doc_491521502071_item	3370103	et	3	main
püüdma	doc_491521502071_item	3370105	et	3	main
vahenditeta	doc_491521502071_item	3370146	et	3	main
müüb	doc_491521502071_item	3370149	et	3	main
kreemiga	doc_491521502071_item	3370158	et	4	main
šampoone	doc_491521502071_item	3370159	et	2	main
kontrolltöö	doc_491521502071_item	3370060	et	4	main
tõlkige	doc_491521502071_item	3370062	et	3	main
понимать	doc_491521502071_item	3370065	et	2	main
плесневеть	doc_491521502071_item	3370067	et	2	main
umbusklik	doc_491521502071_item	3370068	et	3	main
разбрызгивать	doc_491521502071_item	3370074	et	2	main
tõhus	doc_491521502071_item	3370080	et	4	main
minema	doc_491521502071_item	3370093	et	3	main
terveks	doc_491521502071_item	3370098	et	4	main
saama	doc_491521502071_item	3370099	et	4	main
paranema	doc_491521502071_item	3370100	et	3	main
anti	doc_491521502071_item	3370115	et	3	main
inimest	doc_491521502071_item	3370147	et	3	main
kosmeetikavahendid	doc_491521502071_item	3370151	et	3	main
inimest	doc_491521502071_item	3370153	et	3	main
tav-kesksõna	doc_491521502071_item	3370168	et	4	main
kreemidele	doc_491521502071_item	3370169	et	3	main
mis	doc_491521502071_item	3370170	et	4	main
kreemidele	doc_491521502071_item	3370175	et	3	main
käsitsi	doc_491521502071_item	3370179	et	3	main
toidust	doc_491521502071_item	3370187	et	4	main
kaupu	doc_491521502071_item	3370188	et	3	main
kaanega	doc_491521502071_item	3370195	et	3	main
kergesti	doc_491521502071_item	3370200	et	3	main
kaanega	doc_491521502071_item	3370202	et	3	main
tõmmake	doc_491521502071_item	3370204	et	3	main
maha	doc_491521502071_item	3370205	et	4	main
alla	doc_491521502071_item	3370206	et	3	main
valed	doc_491521502071_item	3370207	et	3	main
sõnad	doc_491521502071_item	3370208	et	4	main
suurt	doc_491521502071_item	3370209	et	3	main
ilmtingimata	doc_491521502071_item	3370213	et	3	main
artiklid	doc_491521502071_item	3370222	et	3	main
kahjustasid	doc_491521502071_item	3370223	et	4	main
firma	doc_491521502071_item	3370224	et	4	main
olemust	doc_491521502071_item	3370225	et	3	main
заказывая	doc_491521502071_item	3370257	et	2	main
каталогу	doc_491521502071_item	3370259	et	2	main
время	doc_491521502071_item	3370262	et	2	main
клиентов	doc_491521502071_item	3370271	et	2	main
kliente	doc_491521502071_item	3370275	et	3	main
нарушает	doc_491521502071_item	3370278	et	2	main
торговли	doc_491521502071_item	3370280	et	2	main
у	doc_491521502071_item	3370289	et	2	main
возможность	doc_491521502071_item	3370292	et	2	main
каталог	doc_491521502071_item	3370296	et	2	main
on	doc_491521502071_item	3370298	et	4	main
võimalus	doc_491521502071_item	3370299	et	3	main
kodus	doc_491521502071_item	3370300	et	4	main
jube	doc_491521502071_item	3370315	et	4	main
väga	doc_491521502071_item	3370319	et	3	main
inimesed	doc_491521502071_item	3370323	et	3	main
korista	doc_491521502071_item	3370325	et	4	main
enda	doc_491521502071_item	3370326	et	4	main
sajab	doc_491521502071_item	3370329	et	3	main
lakkamatult	doc_491521502071_item	3370331	et	4	main
kassis	doc_491521502071_item	3370332	et	3	main
ajavad	doc_491521502071_item	3370333	et	4	main
соображать	doc_491521502071_item	3370064	et	2	main
hallitama	doc_491521502071_item	3370066	et	3	main
остатки	doc_491521502071_item	3370071	et	2	main
распылять	doc_491521502071_item	3370073	et	2	main
lakkama	doc_491521502071_item	3370078	et	3	main
kirjutage	doc_491521502071_item	3370089	et	3	main
sünonüümid	doc_491521502071_item	3370091	et	3	main
kinni	doc_491521502071_item	3370104	et	3	main
kinnitama	doc_491521502071_item	3370106	et	3	main
mida	doc_491521502071_item	3370108	et	4	main
öeldi	doc_491521502071_item	3370113	et	3	main
pakkuma	doc_491521502071_item	3370116	et	3	main
lubama	doc_491521502071_item	3370118	et	3	main
lubati	doc_491521502071_item	3370119	et	3	main
tegema	doc_491521502071_item	3370120	et	3	main
tehti	doc_491521502071_item	3370121	et	3	main
laskma	doc_491521502071_item	3370122	et	3	main
lasti	doc_491521502071_item	3370123	et	4	main
saatma	doc_491521502071_item	3370124	et	3	main
saadeti	doc_491521502071_item	3370125	et	3	main
rääkima	doc_491521502071_item	3370126	et	3	main
räägiti	doc_491521502071_item	3370127	et	3	main
teatama	doc_491521502071_item	3370128	et	4	main
teati	doc_491521502071_item	3370129	et	3	main
iv	doc_491521502071_item	3370130	et	4	main
kasutage	doc_491521502071_item	3370131	et	3	main
v-kesksõna	doc_491521502071_item	3370132	et	4	main
prügi	doc_491521502071_item	3370133	et	4	main
mis	doc_491521502071_item	3370134	et	4	main
tekib	doc_491521502071_item	3370135	et	3	main
kodus	doc_491521502071_item	3370136	et	4	main
tekkiv	doc_491521502071_item	3370137	et	4	main
kodus	doc_491521502071_item	3370138	et	4	main
prügi	doc_491521502071_item	3370139	et	4	main
vahenditeta	doc_491521502071_item	3370140	et	3	main
mis	doc_491521502071_item	3370141	et	4	main
värskendavad	doc_491521502071_item	3370142	et	4	main
õhku	doc_491521502071_item	3370143	et	4	main
niisutava	doc_491521502071_item	3370157	et	4	main
mida	doc_491521502071_item	3370184	et	4	main
süüakse	doc_491521502071_item	3370185	et	3	main
harva	doc_491521502071_item	3370192	et	4	main
koera	doc_491521502071_item	3370210	et	4	main
kisuvad	doc_491521502071_item	3370220	et	3	main
tellides	doc_491521502071_item	3370263	et	3	main
teel	doc_491521502071_item	3370265	et	4	main
vabalt	doc_491521502071_item	3370301	et	4	main
viii	doc_491521502071_item	3370306	et	4	main
sulgudes	doc_491521502071_item	3370308	et	4	main
välja	doc_491521502071_item	3370317	et	4	main
piinlikult	doc_491521502071_item	3370321	et	4	main
vihma	doc_491521502071_item	3370328	et	4	main
ravivaid	doc_491521502071_item	3370164	et	4	main
v	doc_491521502071_item	3370166	et	4	main
kasutage	doc_491521502071_item	3370167	et	3	main
toodetavale	doc_491521502071_item	3370174	et	4	main
mida	doc_491521502071_item	3370177	et	4	main
käsitsi	doc_491521502071_item	3370180	et	3	main
pesu	doc_491521502071_item	3370182	et	4	main
toidust	doc_491521502071_item	3370183	et	4	main
mida	doc_491521502071_item	3370189	et	4	main
ostetakse	doc_491521502071_item	3370190	et	3	main
harva	doc_491521502071_item	3370191	et	4	main
kaupu	doc_491521502071_item	3370194	et	3	main
saab	doc_491521502071_item	3370197	et	3	main
avada	doc_491521502071_item	3370199	et	3	main
omapead	doc_491521502071_item	3370214	et	3	main
õmblused	doc_491521502071_item	3370218	et	3	main
luituvad	doc_491521502071_item	3370221	et	4	main
mainet	doc_491521502071_item	3370226	et	4	main
puänti	doc_491521502071_item	3370227	et	4	main
seda	doc_491521502071_item	3370228	et	3	main
plaani	doc_491521502071_item	3370229	et	4	main
on	doc_491521502071_item	3370230	et	4	main
raske	doc_491521502071_item	3370231	et	4	main
liigitada	doc_491521502071_item	3370232	et	3	main
sisaldada	doc_491521502071_item	3370233	et	3	main
teostada	doc_491521502071_item	3370234	et	3	main
inimesed	doc_491521502071_item	3370235	et	3	main
peaksid	doc_491521502071_item	3370236	et	4	main
endale	doc_491521502071_item	3370237	et	4	main
rohkem	doc_491521502071_item	3370238	et	4	main
teadvustama	doc_491521502071_item	3370239	et	3	main
keskkonna	doc_491521502071_item	3370240	et	3	main
reostamise	doc_491521502071_item	3370241	et	4	main
järeldusi	doc_491521502071_item	3370242	et	4	main
tagajärgi	doc_491521502071_item	3370243	et	4	main
tulemusi	doc_491521502071_item	3370244	et	4	main
vii	doc_491521502071_item	3370245	et	4	main
tõlkige	doc_491521502071_item	3370246	et	3	main
система	doc_491521502071_item	3370247	et	2	main
переработки	doc_491521502071_item	3370248	et	2	main
мусора	doc_491521502071_item	3370249	et	2	main
не	doc_491521502071_item	3370250	et	2	main
разработана	doc_491521502071_item	3370251	et	2	main
prügisüsteemi	doc_491521502071_item	3370252	et	2	main
ümbertegemine	doc_491521502071_item	3370253	et	3	main
pole	doc_491521502071_item	3370254	et	3	main
veel	doc_491521502071_item	3370255	et	4	main
по	doc_491521502071_item	3370258	et	2	main
вы	doc_491521502071_item	3370260	et	2	main
привлекает	doc_491521502071_item	3370270	et	2	main
kingitustega	doc_491521502071_item	3370276	et	4	main
принципы	doc_491521502071_item	3370279	et	2	main
рынка	doc_491521502071_item	3370282	et	2	main
see	doc_491521502071_item	3370283	et	3	main
вас	doc_491521502071_item	3370290	et	2	main
спокойно	doc_491521502071_item	3370294	et	2	main
teil	doc_491521502071_item	3370297	et	4	main
pange	doc_491521502071_item	3370307	et	4	main
olevad	doc_491521502071_item	3370309	et	4	main
sõnad	doc_491521502071_item	3370310	et	4	main
õigesse	doc_491521502071_item	3370311	et	3	main
järelt	doc_491521502071_item	3370327	et	4	main
lakkamatu	doc_491521502071_item	3370330	et	4	main
te	doc_491521502071_item	3370266	et	4	main
säästate	doc_491521502071_item	3370267	et	3	main
aega	doc_491521502071_item	3370268	et	4	main
фирма	doc_491521502071_item	3370269	et	2	main
firma	doc_491521502071_item	3370273	et	4	main
turunduseprintsiipe	doc_491521502071_item	3370288	et	4	main
дома	doc_491521502071_item	3370293	et	2	main
kataloogi	doc_491521502071_item	3370302	et	4	main
uurida	doc_491521502071_item	3370303	et	3	main
läbi	doc_491521502071_item	3370304	et	4	main
vaadata	doc_491521502071_item	3370305	et	4	main
jubedalt	doc_491521502071_item	3370316	et	4	main
piinlik	doc_491521502071_item	3370320	et	3	main
karva	doc_491521502071_item	3370336	et	4	main
mul	doc_491521502071_item	3370337	et	3	main
on	doc_491521502071_item	3370338	et	4	main
ebameeldiv	doc_491521502071_item	3370339	et	3	main
ebameeldivalt	doc_491521502071_item	3370340	et	4	main
seda	doc_491521502071_item	3370341	et	3	main
vaadata	doc_491521502071_item	3370342	et	4	main
это	doc_491521502071_item	3370277	et	2	main
свободного	doc_491521502071_item	3370281	et	2	main
ei	doc_491521502071_item	3370284	et	4	main
vastu	doc_491521502071_item	3370285	et	3	main
vaba	doc_491521502071_item	3370286	et	4	main
turu	doc_491521502071_item	3370287	et	3	main
есть	doc_491521502071_item	3370291	et	2	main
изучить	doc_491521502071_item	3370295	et	2	main
vormi	doc_491521502071_item	3370312	et	4	main
see	doc_491521502071_item	3370313	et	3	main
näeb	doc_491521502071_item	3370314	et	3	main
on	doc_491521502071_item	3370318	et	4	main
kui	doc_491521502071_item	3370322	et	3	main
ei	doc_491521502071_item	3370324	et	4	main
hirmus	doc_491521502071_item	3370334	et	4	main
hirmsasti	doc_491521502071_item	3370335	et	3	main
taipama	doc_491521502072_item	3371216	et	3	main
jõukohane	doc_491521502072_item	3371226	et	4	main
что-то	doc_491521502072_item	3371230	et	2	main
мощный	doc_491521502072_item	3371235	et	2	main
ära	doc_491521502072_item	3371237	et	4	main
kuluma	doc_491521502072_item	3371238	et	3	main
изнашиваться	doc_491521502072_item	3371240	et	2	main
toime	doc_491521502072_item	3371241	et	4	main
tulema	doc_491521502072_item	3371242	et	4	main
приводить	doc_491521502072_item	3371243	et	2	main
в	doc_491521502072_item	3371244	et	2	main
действие	doc_491521502072_item	3371245	et	2	main
terveks	doc_491521502072_item	3371256	et	4	main
saama	doc_491521502072_item	3371257	et	4	main
paranema	doc_491521502072_item	3371258	et	3	main
nõudma	doc_491521502072_item	3371269	et	3	main
teatama	doc_491521502072_item	3371287	et	4	main
kodus	doc_491521502072_item	3371295	et	4	main
tekkiv	doc_491521502072_item	3371297	et	4	main
hallitama	doc_491521502072_item	3371217	et	3	main
недоверчивый	doc_491521502072_item	3371220	et	2	main
pihustama	doc_491521502072_item	3371223	et	3	main
останавливаться	doc_491521502072_item	3371232	et	2	main
крепкий	doc_491521502072_item	3371236	et	2	main
снашиваться	doc_491521502072_item	3371239	et	2	main
ühesõnalised	doc_491521502072_item	3371248	et	4	main
maha	doc_491521502072_item	3371259	et	4	main
jätma	doc_491521502072_item	3371260	et	3	main
jätma	doc_491521502072_item	3371261	et	3	main
kinni	doc_491521502072_item	3371262	et	3	main
püüdma	doc_491521502072_item	3371263	et	3	main
arestima	doc_491521502072_item	3371265	et	3	main
mida	doc_491521502072_item	3371267	et	4	main
ütlema	doc_491521502072_item	3371271	et	3	main
andi	doc_491521502072_item	3371274	et	4	main
pakkuti	doc_491521502072_item	3371276	et	4	main
lubama	doc_491521502072_item	3371277	et	3	main
lubati	doc_491521502072_item	3371278	et	3	main
tegema	doc_491521502072_item	3371279	et	3	main
õhku	doc_491521502072_item	3371303	et	4	main
müuv	doc_491521502072_item	3371311	et	4	main
inimest	doc_491521502072_item	3371312	et	3	main
niisutava	doc_491521502072_item	3371316	et	4	main
mis	doc_491521502072_item	3371319	et	4	main
v	doc_491521502072_item	3371325	et	4	main
kasutage	doc_491521502072_item	3371326	et	3	main
toodetavale	doc_491521502072_item	3371333	et	4	main
kreemidele	doc_491521502072_item	3371334	et	3	main
süüakse	doc_491521502072_item	3371344	et	3	main
toidust	doc_491521502072_item	3371346	et	4	main
mida	doc_491521502072_item	3371348	et	4	main
ostetakse	doc_491521502072_item	3371349	et	3	main
harva	doc_491521502072_item	3371350	et	4	main
avada	doc_491521502072_item	3371358	et	3	main
kaanega	doc_491521502072_item	3371361	et	3	main
valed	doc_491521502072_item	3371366	et	3	main
suurt	doc_491521502072_item	3371368	et	3	main
tellides	doc_491521502072_item	3371422	et	3	main
aega	doc_491521502072_item	3371426	et	4	main
hoiate	doc_491521502072_item	3371427	et	3	main
привлекает	doc_491521502072_item	3371431	et	2	main
sekkub	doc_491521502072_item	3371446	et	3	main
у	doc_491521502072_item	3371450	et	2	main
дома	doc_491521502072_item	3371454	et	2	main
kataloogi	doc_491521502072_item	3371463	et	4	main
uurida	doc_491521502072_item	3371464	et	3	main
vaadata	doc_491521502072_item	3371465	et	4	main
sõnad	doc_491521502072_item	3371470	et	4	main
näeb	doc_491521502072_item	3371474	et	3	main
ei	doc_491521502072_item	3371484	et	4	main
i	doc_491521502072_item	3371214	et	4	main
распылять	doc_491521502072_item	3371225	et	2	main
lakkama	doc_491521502072_item	3371228	et	3	main
ii	doc_491521502072_item	3371246	et	4	main
kirjutage	doc_491521502072_item	3371247	et	3	main
lahkuma	doc_491521502072_item	3371252	et	3	main
nõuti	doc_491521502072_item	3371270	et	3	main
mis	doc_491521502072_item	3371293	et	4	main
tekib	doc_491521502072_item	3371294	et	3	main
õhku	doc_491521502072_item	3371302	et	4	main
kontrolltöö	doc_491521502072_item	3371213	et	4	main
плесневеть	doc_491521502072_item	3371218	et	2	main
jäätmed	doc_491521502072_item	3371221	et	3	main
делать	doc_491521502072_item	3371231	et	2	main
tõhus	doc_491521502072_item	3371234	et	4	main
sünonüümid	doc_491521502072_item	3371249	et	3	main
haigeks	doc_491521502072_item	3371253	et	4	main
andma	doc_491521502072_item	3371273	et	3	main
pakkuma	doc_491521502072_item	3371275	et	3	main
tehti	doc_491521502072_item	3371280	et	3	main
laskma	doc_491521502072_item	3371281	et	3	main
laskti	doc_491521502072_item	3371282	et	4	main
saatma	doc_491521502072_item	3371283	et	3	main
saati	doc_491521502072_item	3371284	et	3	main
rääkima	doc_491521502072_item	3371285	et	3	main
räägiti	doc_491521502072_item	3371286	et	3	main
iv	doc_491521502072_item	3371289	et	4	main
prügi	doc_491521502072_item	3371292	et	4	main
kodus	doc_491521502072_item	3371296	et	4	main
prügi	doc_491521502072_item	3371298	et	4	main
vahenditeta	doc_491521502072_item	3371299	et	3	main
mis	doc_491521502072_item	3371300	et	4	main
müüb	doc_491521502072_item	3371308	et	3	main
kreemiga	doc_491521502072_item	3371313	et	4	main
tav-kesksõna	doc_491521502072_item	3371327	et	4	main
kreemidele	doc_491521502072_item	3371328	et	3	main
mis	doc_491521502072_item	3371329	et	4	main
toodetakse	doc_491521502072_item	3371330	et	3	main
välismaal	doc_491521502072_item	3371331	et	4	main
pestav	doc_491521502072_item	3371340	et	4	main
pesu	doc_491521502072_item	3371341	et	4	main
ostetava	doc_491521502072_item	3371352	et	4	main
kaupu	doc_491521502072_item	3371353	et	3	main
vi	doc_491521502072_item	3371362	et	4	main
koera	doc_491521502072_item	3371369	et	4	main
peab	doc_491521502072_item	3371370	et	4	main
kordamööda	doc_491521502072_item	3371371	et	3	main
ilmtingimata	doc_491521502072_item	3371372	et	3	main
omapead	doc_491521502072_item	3371373	et	3	main
õpetama	doc_491521502072_item	3371374	et	3	main
kataloogist	doc_491521502072_item	3371423	et	3	main
kokku	doc_491521502072_item	3371429	et	3	main
see	doc_491521502072_item	3371445	et	3	main
rikkub	doc_491521502072_item	3371447	et	4	main
põhimõtted	doc_491521502072_item	3371449	et	3	main
возможность	doc_491521502072_item	3371453	et	2	main
изучить	doc_491521502072_item	3371456	et	2	main
kodus	doc_491521502072_item	3371461	et	4	main
rahulikult	doc_491521502072_item	3371462	et	4	main
vormi	doc_491521502072_item	3371472	et	4	main
korista	doc_491521502072_item	3371485	et	4	main
tõlkige	doc_491521502072_item	3371215	et	3	main
umbusklik	doc_491521502072_item	3371219	et	3	main
остатки	doc_491521502072_item	3371222	et	2	main
брызгать	doc_491521502072_item	3371224	et	2	main
подходящий	doc_491521502072_item	3371227	et	2	main
прекращать	doc_491521502072_item	3371229	et	2	main
перестать	doc_491521502072_item	3371233	et	2	main
ära	doc_491521502072_item	3371250	et	4	main
minema	doc_491521502072_item	3371251	et	3	main
jääma	doc_491521502072_item	3371254	et	4	main
haigestuma	doc_491521502072_item	3371255	et	3	main
поймать	doc_491521502072_item	3371264	et	2	main
iii	doc_491521502072_item	3371266	et	4	main
tehti	doc_491521502072_item	3371268	et	3	main
õeldi	doc_491521502072_item	3371272	et	4	main
teatati	doc_491521502072_item	3371288	et	3	main
kasutage	doc_491521502072_item	3371290	et	3	main
v-kesksõna	doc_491521502072_item	3371291	et	4	main
värskendavad	doc_491521502072_item	3371301	et	4	main
vahenditeta	doc_491521502072_item	3371305	et	3	main
inimest	doc_491521502072_item	3371306	et	3	main
kes	doc_491521502072_item	3371307	et	4	main
kosmeetikavahendeid	doc_491521502072_item	3371309	et	3	main
kosmetikavahendeid	doc_491521502072_item	3371310	et	4	main
mis	doc_491521502072_item	3371314	et	4	main
pesu	doc_491521502072_item	3371335	et	4	main
toidust	doc_491521502072_item	3371342	et	4	main
kaanega	doc_491521502072_item	3371354	et	3	main
saab	doc_491521502072_item	3371356	et	3	main
kergesti	doc_491521502072_item	3371357	et	3	main
avatava	doc_491521502072_item	3371360	et	4	main
maha	doc_491521502072_item	3371364	et	4	main
värsendava	doc_491521502072_item	3371304	et	4	main
kreemiga	doc_491521502072_item	3371317	et	4	main
ravivad	doc_491521502072_item	3371320	et	4	main
juukseid	doc_491521502072_item	3371321	et	3	main
juukse	doc_491521502072_item	3371322	et	3	main
raviva	doc_491521502072_item	3371323	et	4	main
šampoone	doc_491521502072_item	3371324	et	2	main
välismaal	doc_491521502072_item	3371332	et	4	main
käsitsi	doc_491521502072_item	3371338	et	3	main
söödavast	doc_491521502072_item	3371345	et	4	main
mida	doc_491521502072_item	3371355	et	4	main
kergesti	doc_491521502072_item	3371359	et	3	main
selle	doc_491521502072_item	3371375	et	4	main
pintsaku	doc_491521502072_item	3371376	et	3	main
õmblused	doc_491521502072_item	3371377	et	3	main
kisuvad	doc_491521502072_item	3371379	et	3	main
seda	doc_491521502072_item	3371387	et	3	main
sisteem	doc_491521502072_item	3371413	et	4	main
arenenud	doc_491521502072_item	3371415	et	4	main
заказывая	doc_491521502072_item	3371416	et	2	main
каталогу	doc_491521502072_item	3371418	et	2	main
экономите	doc_491521502072_item	3371420	et	2	main
te	doc_491521502072_item	3371424	et	4	main
фирма	doc_491521502072_item	3371430	et	2	main
клиентов	doc_491521502072_item	3371432	et	2	main
peibutab	doc_491521502072_item	3371435	et	3	main
meelitab	doc_491521502072_item	3371436	et	3	main
kingitusega	doc_491521502072_item	3371438	et	4	main
принципы	doc_491521502072_item	3371441	et	2	main
свободного	doc_491521502072_item	3371443	et	2	main
vabaturu	doc_491521502072_item	3371448	et	3	main
вас	doc_491521502072_item	3371451	et	2	main
спокойно	doc_491521502072_item	3371455	et	2	main
pange	doc_491521502072_item	3371467	et	4	main
sulgudes	doc_491521502072_item	3371468	et	4	main
on	doc_491521502072_item	3371478	et	4	main
väga	doc_491521502072_item	3371479	et	3	main
piinlik	doc_491521502072_item	3371480	et	3	main
piinlik	doc_491521502072_item	3371481	et	3	main
kui	doc_491521502072_item	3371482	et	3	main
inimesed	doc_491521502072_item	3371483	et	3	main
vihma	doc_491521502072_item	3371488	et	4	main
sajab	doc_491521502072_item	3371489	et	3	main
niisutab	doc_491521502072_item	3371315	et	3	main
šampoone	doc_491521502072_item	3371318	et	2	main
mida	doc_491521502072_item	3371336	et	4	main
pestakse	doc_491521502072_item	3371337	et	3	main
käsitsi	doc_491521502072_item	3371339	et	3	main
mida	doc_491521502072_item	3371343	et	4	main
kaupu	doc_491521502072_item	3371347	et	3	main
harva	doc_491521502072_item	3371351	et	4	main
tõmmake	doc_491521502072_item	3371363	et	3	main
alla	doc_491521502072_item	3371365	et	3	main
sõnad	doc_491521502072_item	3371367	et	4	main
käsitsevad	doc_491521502072_item	3371378	et	4	main
luituvad	doc_491521502072_item	3371380	et	4	main
artiklid	doc_491521502072_item	3371381	et	3	main
kahjustasid	doc_491521502072_item	3371382	et	4	main
olemust	doc_491521502072_item	3371384	et	3	main
mainet	doc_491521502072_item	3371385	et	4	main
firma	doc_491521502072_item	3371383	et	4	main
puänti	doc_491521502072_item	3371386	et	4	main
plaani	doc_491521502072_item	3371388	et	4	main
on	doc_491521502072_item	3371389	et	4	main
raske	doc_491521502072_item	3371390	et	4	main
liigitada	doc_491521502072_item	3371391	et	3	main
sisaldada	doc_491521502072_item	3371392	et	3	main
teostada	doc_491521502072_item	3371393	et	3	main
inimesed	doc_491521502072_item	3371394	et	3	main
peaksid	doc_491521502072_item	3371395	et	4	main
endale	doc_491521502072_item	3371396	et	4	main
rohkem	doc_491521502072_item	3371397	et	4	main
teadvustama	doc_491521502072_item	3371398	et	3	main
keskkonna	doc_491521502072_item	3371399	et	3	main
reostamise	doc_491521502072_item	3371400	et	4	main
järeldusi	doc_491521502072_item	3371401	et	4	main
tagajärgi	doc_491521502072_item	3371402	et	4	main
tulemusi	doc_491521502072_item	3371403	et	4	main
vii	doc_491521502072_item	3371404	et	4	main
tõlkige	doc_491521502072_item	3371405	et	3	main
система	doc_491521502072_item	3371406	et	2	main
переработки	doc_491521502072_item	3371407	et	2	main
мусора	doc_491521502072_item	3371408	et	2	main
не	doc_491521502072_item	3371409	et	2	main
разработана	doc_491521502072_item	3371410	et	2	main
prügi	doc_491521502072_item	3371411	et	4	main
ümbertöötamise	doc_491521502072_item	3371412	et	3	main
время	doc_491521502072_item	3371421	et	2	main
säästate	doc_491521502072_item	3371425	et	3	main
firma	doc_491521502072_item	3371434	et	4	main
kliente	doc_491521502072_item	3371437	et	3	main
ei	doc_491521502072_item	3371414	et	4	main
по	doc_491521502072_item	3371417	et	2	main
вы	doc_491521502072_item	3371419	et	2	main
aega	doc_491521502072_item	3371428	et	4	main
подарками	doc_491521502072_item	3371433	et	2	main
это	doc_491521502072_item	3371439	et	2	main
каталог	doc_491521502072_item	3371457	et	2	main
on	doc_491521502072_item	3371459	et	4	main
viii	doc_491521502072_item	3371466	et	4	main
õigesse	doc_491521502072_item	3371471	et	3	main
see	doc_491521502072_item	3371473	et	3	main
jube	doc_491521502072_item	3371475	et	4	main
jubedalt	doc_491521502072_item	3371476	et	4	main
välja	doc_491521502072_item	3371477	et	4	main
järelt	doc_491521502072_item	3371487	et	4	main
lakkamatult	doc_491521502072_item	3371491	et	4	main
hirmsalt	doc_491521502072_item	3371495	et	4	main
karva	doc_491521502072_item	3371496	et	4	main
mul	doc_491521502072_item	3371497	et	3	main
on	doc_491521502072_item	3371498	et	4	main
ebameeldiv	doc_491521502072_item	3371499	et	3	main
ebameeldiv	doc_491521502072_item	3371500	et	3	main
seda	doc_491521502072_item	3371501	et	3	main
vaadata	doc_491521502072_item	3371502	et	4	main
нарушает	doc_491521502072_item	3371440	et	2	main
торговли	doc_491521502072_item	3371442	et	2	main
рынка	doc_491521502072_item	3371444	et	2	main
есть	doc_491521502072_item	3371452	et	2	main
teil	doc_491521502072_item	3371458	et	4	main
võimalus	doc_491521502072_item	3371460	et	3	main
olevad	doc_491521502072_item	3371469	et	4	main
enda	doc_491521502072_item	3371486	et	4	main
lakkamatu	doc_491521502072_item	3371490	et	4	main
kassis	doc_491521502072_item	3371492	et	3	main
ajavad	doc_491521502072_item	3371493	et	4	main
hirmus	doc_491521502072_item	3371494	et	4	main
kontrolltöö	doc_491521502073_item	3372346	et	4	main
taipama	doc_491521502073_item	3372349	et	3	main
hallitama	doc_491521502073_item	3372351	et	3	main
umbusklik	doc_491521502073_item	3372353	et	3	main
сомнительный	doc_491521502073_item	3372355	et	2	main
jäätmed	doc_491521502073_item	3372356	et	3	main
распылять	doc_491521502073_item	3372359	et	2	main
сделать	doc_491521502073_item	3372364	et	2	main
tõhus	doc_491521502073_item	3372367	et	4	main
kirjutage	doc_491521502073_item	3372376	et	3	main
sünonüümid	doc_491521502073_item	3372378	et	3	main
haigeks	doc_491521502073_item	3372382	et	4	main
saama	doc_491521502073_item	3372386	et	4	main
ütlema	doc_491521502073_item	3372398	et	3	main
pakkuma	doc_491521502073_item	3372402	et	3	main
laskma	doc_491521502073_item	3372408	et	3	main
mis	doc_491521502073_item	3372420	et	4	main
tekib	doc_491521502073_item	3372421	et	3	main
vahenditeta	doc_491521502073_item	3372426	et	3	main
välismaal	doc_491521502073_item	3372458	et	4	main
kreemidele	doc_491521502073_item	3372461	et	3	main
i	doc_491521502073_item	3372347	et	4	main
tõlkige	doc_491521502073_item	3372348	et	3	main
догадываться	doc_491521502073_item	3372350	et	2	main
плеснеть	doc_491521502073_item	3372352	et	2	main
неверующий	doc_491521502073_item	3372354	et	2	main
что-то	doc_491521502073_item	3372363	et	2	main
прекращать	doc_491521502073_item	3372366	et	2	main
ära	doc_491521502073_item	3372369	et	4	main
kuluma	doc_491521502073_item	3372370	et	3	main
tulema	doc_491521502073_item	3372373	et	4	main
справляться	doc_491521502073_item	3372374	et	2	main
ära	doc_491521502073_item	3372379	et	4	main
andma	doc_491521502073_item	3372400	et	3	main
lubati	doc_491521502073_item	3372405	et	3	main
saatma	doc_491521502073_item	3372410	et	3	main
teatama	doc_491521502073_item	3372414	et	4	main
mis	doc_491521502073_item	3372427	et	4	main
värskendavate	doc_491521502073_item	3372431	et	4	main
v	doc_491521502073_item	3372452	et	4	main
kasutage	doc_491521502073_item	3372453	et	3	main
tav-kesksõna	doc_491521502073_item	3372454	et	4	main
kreemidele	doc_491521502073_item	3372455	et	3	main
toodetakse	doc_491521502073_item	3372457	et	3	main
pesu	doc_491521502073_item	3372468	et	4	main
mida	doc_491521502073_item	3372475	et	4	main
силу	doc_491521502073_item	3372362	et	2	main
lakkama	doc_491521502073_item	3372365	et	3	main
ii	doc_491521502073_item	3372375	et	4	main
minema	doc_491521502073_item	3372380	et	3	main
jääma	doc_491521502073_item	3372383	et	4	main
põdema	doc_491521502073_item	3372384	et	3	main
terveks	doc_491521502073_item	3372385	et	4	main
püüdma	doc_491521502073_item	3372391	et	3	main
öeldi	doc_491521502073_item	3372399	et	3	main
rääkima	doc_491521502073_item	3372412	et	3	main
kodus	doc_491521502073_item	3372422	et	4	main
kodus	doc_491521502073_item	3372423	et	4	main
tekkiv	doc_491521502073_item	3372424	et	4	main
õhku	doc_491521502073_item	3372429	et	4	main
õhku	doc_491521502073_item	3372430	et	4	main
vahenditeta	doc_491521502073_item	3372432	et	3	main
inimest	doc_491521502073_item	3372433	et	3	main
kes	doc_491521502073_item	3372434	et	4	main
mis	doc_491521502073_item	3372446	et	4	main
juukseid	doc_491521502073_item	3372449	et	3	main
под	doc_491521502073_item	3372361	et	2	main
эффективный	doc_491521502073_item	3372368	et	2	main
расходоваться	doc_491521502073_item	3372371	et	2	main
toime	doc_491521502073_item	3372372	et	4	main
lahkuma	doc_491521502073_item	3372381	et	3	main
maha	doc_491521502073_item	3372387	et	4	main
kinni	doc_491521502073_item	3372390	et	3	main
mida	doc_491521502073_item	3372394	et	4	main
tehti	doc_491521502073_item	3372395	et	3	main
nõudma	doc_491521502073_item	3372396	et	3	main
pakuti	doc_491521502073_item	3372403	et	3	main
tegema	doc_491521502073_item	3372406	et	3	main
räägiti	doc_491521502073_item	3372413	et	3	main
teatati	doc_491521502073_item	3372415	et	3	main
värskendavad	doc_491521502073_item	3372428	et	4	main
ravivaid	doc_491521502073_item	3372450	et	4	main
välismaal	doc_491521502073_item	3372459	et	4	main
toidust	doc_491521502073_item	3372469	et	4	main
ostetakse	doc_491521502073_item	3372476	et	3	main
ostetavat	doc_491521502073_item	3372479	et	4	main
mida	doc_491521502073_item	3372482	et	4	main
saab	doc_491521502073_item	3372483	et	3	main
kergesti	doc_491521502073_item	3372484	et	3	main
kordamööda	doc_491521502073_item	3372498	et	3	main
plaani	doc_491521502073_item	3372515	et	4	main
on	doc_491521502073_item	3372516	et	4	main
endale	doc_491521502073_item	3372523	et	4	main
reostamise	doc_491521502073_item	3372527	et	4	main
tagajärgi	doc_491521502073_item	3372529	et	4	main
tulemusi	doc_491521502073_item	3372530	et	4	main
ei	doc_491521502073_item	3372541	et	4	main
возможность	doc_491521502073_item	3372578	et	2	main
teil	doc_491521502073_item	3372583	et	4	main
olevad	doc_491521502073_item	3372593	et	4	main
enda	doc_491521502073_item	3372610	et	4	main
sajab	doc_491521502073_item	3372613	et	3	main
lakkamatu	doc_491521502073_item	3372614	et	4	main
остатки	doc_491521502073_item	3372357	et	2	main
pihustama	doc_491521502073_item	3372358	et	3	main
jõukohane	doc_491521502073_item	3372360	et	4	main
ühesõnalised	doc_491521502073_item	3372377	et	4	main
jätma	doc_491521502073_item	3372388	et	3	main
hülgama	doc_491521502073_item	3372389	et	3	main
hoidma	doc_491521502073_item	3372392	et	3	main
iii	doc_491521502073_item	3372393	et	4	main
nõuti	doc_491521502073_item	3372397	et	3	main
anti	doc_491521502073_item	3372401	et	3	main
lubama	doc_491521502073_item	3372404	et	3	main
tehti	doc_491521502073_item	3372407	et	3	main
lasti	doc_491521502073_item	3372409	et	4	main
saadi	doc_491521502073_item	3372411	et	4	main
iv	doc_491521502073_item	3372416	et	4	main
kasutage	doc_491521502073_item	3372417	et	3	main
v-kesksõna	doc_491521502073_item	3372418	et	4	main
prügi	doc_491521502073_item	3372419	et	4	main
prügi	doc_491521502073_item	3372425	et	4	main
müüb	doc_491521502073_item	3372435	et	3	main
kosmeetikavahendeid	doc_491521502073_item	3372436	et	3	main
kosmeetikavahendeid	doc_491521502073_item	3372437	et	3	main
müüvat	doc_491521502073_item	3372438	et	4	main
inimest	doc_491521502073_item	3372439	et	3	main
kreemiga	doc_491521502073_item	3372440	et	4	main
mis	doc_491521502073_item	3372441	et	4	main
niisutab	doc_491521502073_item	3372442	et	3	main
niisutava	doc_491521502073_item	3372443	et	4	main
kreemiga	doc_491521502073_item	3372444	et	4	main
šampoone	doc_491521502073_item	3372445	et	2	main
ravivad	doc_491521502073_item	3372447	et	4	main
juukseid	doc_491521502073_item	3372448	et	3	main
mis	doc_491521502073_item	3372456	et	4	main
toodetavatele	doc_491521502073_item	3372460	et	4	main
pesu	doc_491521502073_item	3372462	et	4	main
mida	doc_491521502073_item	3372470	et	4	main
süüakse	doc_491521502073_item	3372471	et	3	main
söödavast	doc_491521502073_item	3372472	et	4	main
harva	doc_491521502073_item	3372477	et	4	main
avada	doc_491521502073_item	3372485	et	3	main
kergesti	doc_491521502073_item	3372486	et	3	main
avatava	doc_491521502073_item	3372487	et	4	main
kaanega	doc_491521502073_item	3372488	et	3	main
vi	doc_491521502073_item	3372489	et	4	main
tõmmake	doc_491521502073_item	3372490	et	3	main
maha	doc_491521502073_item	3372491	et	4	main
alla	doc_491521502073_item	3372492	et	3	main
valed	doc_491521502073_item	3372493	et	3	main
sõnad	doc_491521502073_item	3372494	et	4	main
suurt	doc_491521502073_item	3372495	et	3	main
šampoone	doc_491521502073_item	3372451	et	2	main
pestav	doc_491521502073_item	3372467	et	4	main
toidust	doc_491521502073_item	3372473	et	4	main
kaupu	doc_491521502073_item	3372474	et	3	main
selle	doc_491521502073_item	3372502	et	4	main
pintsaku	doc_491521502073_item	3372503	et	3	main
õmblused	doc_491521502073_item	3372504	et	3	main
käsitsevad	doc_491521502073_item	3372505	et	4	main
kisuvad	doc_491521502073_item	3372506	et	3	main
kahjustasid	doc_491521502073_item	3372509	et	4	main
mainet	doc_491521502073_item	3372512	et	4	main
seda	doc_491521502073_item	3372514	et	3	main
inimesed	doc_491521502073_item	3372521	et	3	main
keskkonna	doc_491521502073_item	3372526	et	3	main
система	doc_491521502073_item	3372533	et	2	main
мусора	doc_491521502073_item	3372535	et	2	main
есть	doc_491521502073_item	3372577	et	2	main
изучить	doc_491521502073_item	3372581	et	2	main
on	doc_491521502073_item	3372584	et	4	main
rahulikult	doc_491521502073_item	3372587	et	4	main
välja	doc_491521502073_item	3372601	et	4	main
korista	doc_491521502073_item	3372609	et	4	main
hirmus	doc_491521502073_item	3372618	et	4	main
mida	doc_491521502073_item	3372463	et	4	main
pestakse	doc_491521502073_item	3372464	et	3	main
käsitsi	doc_491521502073_item	3372465	et	3	main
kästsi	doc_491521502073_item	3372466	et	4	main
kaanega	doc_491521502073_item	3372481	et	3	main
omapead	doc_491521502073_item	3372500	et	3	main
firma	doc_491521502073_item	3372510	et	4	main
raske	doc_491521502073_item	3372517	et	4	main
liigitada	doc_491521502073_item	3372518	et	3	main
sisaldada	doc_491521502073_item	3372519	et	3	main
peaksid	doc_491521502073_item	3372522	et	4	main
vii	doc_491521502073_item	3372531	et	4	main
tõlkige	doc_491521502073_item	3372532	et	3	main
переработки	doc_491521502073_item	3372534	et	2	main
не	doc_491521502073_item	3372536	et	2	main
prügi	doc_491521502073_item	3372538	et	4	main
вас	doc_491521502073_item	3372576	et	2	main
каталог	doc_491521502073_item	3372582	et	2	main
kodus	doc_491521502073_item	3372586	et	4	main
kataloogi	doc_491521502073_item	3372588	et	4	main
uurida	doc_491521502073_item	3372589	et	3	main
viii	doc_491521502073_item	3372590	et	4	main
sõnad	doc_491521502073_item	3372594	et	4	main
õigesse	doc_491521502073_item	3372595	et	3	main
see	doc_491521502073_item	3372597	et	3	main
on	doc_491521502073_item	3372602	et	4	main
piinlik	doc_491521502073_item	3372605	et	3	main
inimesed	doc_491521502073_item	3372607	et	3	main
ajavad	doc_491521502073_item	3372617	et	4	main
vaadata	doc_491521502073_item	3372626	et	4	main
harva	doc_491521502073_item	3372478	et	4	main
kaupu	doc_491521502073_item	3372480	et	3	main
luituvad	doc_491521502073_item	3372507	et	4	main
rohkem	doc_491521502073_item	3372524	et	4	main
разработана	doc_491521502073_item	3372537	et	2	main
süsteem	doc_491521502073_item	3372540	et	3	main
ole	doc_491521502073_item	3372542	et	4	main
veel	doc_491521502073_item	3372543	et	4	main
kavas	doc_491521502073_item	3372544	et	3	main
заказывая	doc_491521502073_item	3372545	et	2	main
по	doc_491521502073_item	3372546	et	2	main
каталогу	doc_491521502073_item	3372547	et	2	main
вы	doc_491521502073_item	3372548	et	2	main
экономите	doc_491521502073_item	3372549	et	2	main
время	doc_491521502073_item	3372550	et	2	main
tellides	doc_491521502073_item	3372551	et	3	main
kataloogist	doc_491521502073_item	3372552	et	3	main
te	doc_491521502073_item	3372553	et	4	main
säästate	doc_491521502073_item	3372554	et	3	main
aega	doc_491521502073_item	3372555	et	4	main
фирма	doc_491521502073_item	3372556	et	2	main
привлекает	doc_491521502073_item	3372557	et	2	main
клиентов	doc_491521502073_item	3372558	et	2	main
подарками	doc_491521502073_item	3372559	et	2	main
firma	doc_491521502073_item	3372560	et	4	main
peibutab	doc_491521502073_item	3372561	et	3	main
kliente	doc_491521502073_item	3372562	et	3	main
kingitustega	doc_491521502073_item	3372563	et	4	main
это	doc_491521502073_item	3372564	et	2	main
нарушает	doc_491521502073_item	3372565	et	2	main
торговли	doc_491521502073_item	3372567	et	2	main
принципы	doc_491521502073_item	3372566	et	2	main
свободного	doc_491521502073_item	3372568	et	2	main
рынка	doc_491521502073_item	3372569	et	2	main
see	doc_491521502073_item	3372570	et	3	main
sekkub	doc_491521502073_item	3372571	et	3	main
vabakaubanduse	doc_491521502073_item	3372572	et	3	main
turu	doc_491521502073_item	3372573	et	3	main
põhimõtteid	doc_491521502073_item	3372574	et	3	main
koera	doc_491521502073_item	3372496	et	4	main
peab	doc_491521502073_item	3372497	et	4	main
ilmtingimata	doc_491521502073_item	3372499	et	3	main
õpetama	doc_491521502073_item	3372501	et	3	main
artiklid	doc_491521502073_item	3372508	et	3	main
olemust	doc_491521502073_item	3372511	et	3	main
puänti	doc_491521502073_item	3372513	et	4	main
teostada	doc_491521502073_item	3372520	et	3	main
teadvustama	doc_491521502073_item	3372525	et	3	main
järeldusi	doc_491521502073_item	3372528	et	4	main
ümbertöötlemise	doc_491521502073_item	3372539	et	3	main
дома	doc_491521502073_item	3372579	et	2	main
võimalus	doc_491521502073_item	3372585	et	3	main
sulgudes	doc_491521502073_item	3372592	et	4	main
vormi	doc_491521502073_item	3372596	et	4	main
näeb	doc_491521502073_item	3372598	et	3	main
väga	doc_491521502073_item	3372603	et	3	main
järelt	doc_491521502073_item	3372611	et	4	main
vihma	doc_491521502073_item	3372612	et	4	main
hirmsalt	doc_491521502073_item	3372619	et	4	main
karva	doc_491521502073_item	3372620	et	4	main
mul	doc_491521502073_item	3372621	et	3	main
у	doc_491521502073_item	3372575	et	2	main
спокойно	doc_491521502073_item	3372580	et	2	main
pange	doc_491521502073_item	3372591	et	4	main
jube	doc_491521502073_item	3372599	et	4	main
jubedalt	doc_491521502073_item	3372600	et	4	main
piinlik	doc_491521502073_item	3372604	et	3	main
kui	doc_491521502073_item	3372606	et	3	main
ei	doc_491521502073_item	3372608	et	4	main
lakkamatult	doc_491521502073_item	3372615	et	4	main
kassis	doc_491521502073_item	3372616	et	3	main
on	doc_491521502073_item	3372622	et	4	main
ebameeldiv	doc_491521502073_item	3372623	et	3	main
ebameeldiv	doc_491521502073_item	3372624	et	3	main
seda	doc_491521502073_item	3372625	et	3	main
kontrolltöö	doc_491521502079_item	3375308	et	4	main
umbusklik	doc_491521502079_item	3375314	et	3	main
jõukohane	doc_491521502079_item	3375319	et	4	main
tõhus	doc_491521502079_item	3375322	et	4	main
kuluma	doc_491521502079_item	3375324	et	3	main
высушивать	doc_491521502079_item	3375325	et	2	main
toime	doc_491521502079_item	3375326	et	4	main
ära	doc_491521502079_item	3375332	et	4	main
minema	doc_491521502079_item	3375333	et	3	main
lahkuma	doc_491521502079_item	3375334	et	3	main
haigeks	doc_491521502079_item	3375335	et	4	main
maha	doc_491521502079_item	3375341	et	4	main
nõuti	doc_491521502079_item	3375351	et	3	main
pakkuti	doc_491521502079_item	3375357	et	4	main
lubati	doc_491521502079_item	3375359	et	3	main
iv	doc_491521502079_item	3375370	et	4	main
mis	doc_491521502079_item	3375384	et	4	main
i	doc_491521502079_item	3375309	et	4	main
загрезить	doc_491521502079_item	3375313	et	2	main
ära	doc_491521502079_item	3375323	et	4	main
jätma	doc_491521502079_item	3375342	et	3	main
tabama	doc_491521502079_item	3375346	et	3	main
mida	doc_491521502079_item	3375348	et	4	main
tegema	doc_491521502079_item	3375360	et	3	main
kasutage	doc_491521502079_item	3375371	et	3	main
prügi	doc_491521502079_item	3375373	et	4	main
mis	doc_491521502079_item	3375374	et	4	main
tekib	doc_491521502079_item	3375375	et	3	main
prügi	doc_491521502079_item	3375379	et	4	main
kodu	doc_491521502079_item	3375380	et	4	main
raviv	doc_491521502079_item	3375425	et	4	main
šampoon	doc_491521502079_item	3375426	et	2	main
on	doc_491521502079_item	3375434	et	4	main
mida	doc_491521502079_item	3375444	et	4	main
pestakse	doc_491521502079_item	3375445	et	3	main
käsitsi	doc_491521502079_item	3375446	et	3	main
pesu	doc_491521502079_item	3375451	et	4	main
suur	doc_491521502079_item	3375456	et	3	main
seda	doc_491521502079_item	3375509	et	3	main
rohkem	doc_491521502079_item	3375519	et	4	main
keskkonna	doc_491521502079_item	3375521	et	3	main
reostamise	doc_491521502079_item	3375522	et	4	main
tulemusi	doc_491521502079_item	3375525	et	4	main
мусора	doc_491521502079_item	3375530	et	2	main
prügi	doc_491521502079_item	3375533	et	4	main
ei	doc_491521502079_item	3375536	et	4	main
ole	doc_491521502079_item	3375537	et	4	main
вы	doc_491521502079_item	3375543	et	2	main
oma	doc_491521502079_item	3375548	et	4	main
raha	doc_491521502079_item	3375549	et	4	main
tellite	doc_491521502079_item	3375551	et	3	main
kliendid	doc_491521502079_item	3375561	et	3	main
это	doc_491521502079_item	3375564	et	2	main
рынка	doc_491521502079_item	3375569	et	2	main
rikkub	doc_491521502079_item	3375571	et	4	main
kaubanduse	doc_491521502079_item	3375573	et	3	main
taipama	doc_491521502079_item	3375311	et	3	main
jäätmed	doc_491521502079_item	3375316	et	3	main
pihustama	doc_491521502079_item	3375318	et	3	main
lakkama	doc_491521502079_item	3375321	et	3	main
terveks	doc_491521502079_item	3375338	et	4	main
hülgima	doc_491521502079_item	3375343	et	4	main
püüdma	doc_491521502079_item	3375345	et	3	main
iii	doc_491521502079_item	3375347	et	4	main
nõudma	doc_491521502079_item	3375350	et	3	main
andma	doc_491521502079_item	3375354	et	3	main
pakkuma	doc_491521502079_item	3375356	et	3	main
laskma	doc_491521502079_item	3375362	et	3	main
saati	doc_491521502079_item	3375365	et	3	main
räägiti	doc_491521502079_item	3375367	et	3	main
v-kesksõna	doc_491521502079_item	3375372	et	4	main
kodus	doc_491521502079_item	3375376	et	4	main
tekkitav	doc_491521502079_item	3375381	et	4	main
kreemiga	doc_491521502079_item	3375408	et	4	main
niisutab	doc_491521502079_item	3375410	et	3	main
komponentid	doc_491521502079_item	3375415	et	4	main
niisutav	doc_491521502079_item	3375416	et	4	main
kreem	doc_491521502079_item	3375417	et	3	main
ravivad	doc_491521502079_item	3375420	et	4	main
v	doc_491521502079_item	3375427	et	4	main
tehtud	doc_491521502079_item	3375435	et	4	main
loetavat	doc_491521502079_item	3375438	et	4	main
toodetav	doc_491521502079_item	3375441	et	4	main
pesu	doc_491521502079_item	3375443	et	4	main
kasipestav	doc_491521502079_item	3375450	et	4	main
kaupu	doc_491521502079_item	3375462	et	3	main
mida	doc_491521502079_item	3375463	et	4	main
ostetakse	doc_491521502079_item	3375464	et	3	main
käsitsevad	doc_491521502079_item	3375500	et	4	main
luituvad	doc_491521502079_item	3375502	et	4	main
artiklid	doc_491521502079_item	3375503	et	3	main
kahjustasid	doc_491521502079_item	3375504	et	4	main
puänti	doc_491521502079_item	3375508	et	4	main
plaani	doc_491521502079_item	3375510	et	4	main
teadvustama	doc_491521502079_item	3375520	et	3	main
vii	doc_491521502079_item	3375526	et	4	main
разработана	doc_491521502079_item	3375532	et	2	main
toodetud	doc_491521502079_item	3375539	et	4	main
заказывая	doc_491521502079_item	3375540	et	2	main
каталогу	doc_491521502079_item	3375542	et	2	main
te	doc_491521502079_item	3375546	et	4	main
firma	doc_491521502079_item	3375558	et	4	main
kingituse	doc_491521502079_item	3375562	et	4	main
свободного	doc_491521502079_item	3375568	et	2	main
vaba	doc_491521502079_item	3375572	et	4	main
hallitama	doc_491521502079_item	3375312	et	3	main
недоверчивый	doc_491521502079_item	3375315	et	2	main
доступный	doc_491521502079_item	3375320	et	2	main
ii	doc_491521502079_item	3375328	et	4	main
kirjutage	doc_491521502079_item	3375329	et	3	main
ühesõnalised	doc_491521502079_item	3375330	et	4	main
sünonüümid	doc_491521502079_item	3375331	et	3	main
saama	doc_491521502079_item	3375339	et	4	main
paranema	doc_491521502079_item	3375340	et	3	main
kinni	doc_491521502079_item	3375344	et	3	main
ütlema	doc_491521502079_item	3375352	et	3	main
öeldi	doc_491521502079_item	3375353	et	3	main
anti	doc_491521502079_item	3375355	et	3	main
lasti	doc_491521502079_item	3375363	et	4	main
on	doc_491521502079_item	3375377	et	4	main
prügi	doc_491521502079_item	3375382	et	4	main
vahenditeta	doc_491521502079_item	3375383	et	3	main
ajavad	doc_491521502079_item	3375621	et	4	main
hirmus	doc_491521502079_item	3375622	et	4	main
hirmselt	doc_491521502079_item	3375623	et	4	main
karva	doc_491521502079_item	3375624	et	4	main
mul	doc_491521502079_item	3375625	et	3	main
on	doc_491521502079_item	3375626	et	4	main
ebameeldiv	doc_491521502079_item	3375627	et	3	main
ebameeldiv	doc_491521502079_item	3375628	et	3	main
seda	doc_491521502079_item	3375629	et	3	main
vaadata	doc_491521502079_item	3375630	et	4	main
tõlkige	doc_491521502079_item	3375310	et	3	main
остатки	doc_491521502079_item	3375317	et	2	main
tulema	doc_491521502079_item	3375327	et	4	main
jääma	doc_491521502079_item	3375336	et	4	main
haigestuma	doc_491521502079_item	3375337	et	3	main
tehti	doc_491521502079_item	3375349	et	3	main
lubama	doc_491521502079_item	3375358	et	3	main
tehti	doc_491521502079_item	3375361	et	3	main
saatma	doc_491521502079_item	3375364	et	3	main
rääkima	doc_491521502079_item	3375366	et	3	main
teatama	doc_491521502079_item	3375368	et	4	main
teati	doc_491521502079_item	3375369	et	3	main
sorteeriv	doc_491521502079_item	3375378	et	4	main
õhku	doc_491521502079_item	3375386	et	4	main
võib	doc_491521502079_item	3375387	et	3	main
iga	doc_491521502079_item	3375388	et	4	main
hästi	doc_491521502079_item	3375389	et	3	main
opetav	doc_491521502079_item	3375390	et	4	main
inimene	doc_491521502079_item	3375391	et	3	main
kasutada	doc_491521502079_item	3375392	et	3	main
värskendavat	doc_491521502079_item	3375394	et	4	main
õhku	doc_491521502079_item	3375393	et	4	main
vahendit	doc_491521502079_item	3375395	et	3	main
inimest	doc_491521502079_item	3375396	et	3	main
kes	doc_491521502079_item	3375397	et	4	main
müüb	doc_491521502079_item	3375398	et	3	main
kosmeetikavahendeid	doc_491521502079_item	3375399	et	3	main
on	doc_491521502079_item	3375400	et	4	main
väga	doc_491521502079_item	3375401	et	3	main
ammu	doc_491521502079_item	3375402	et	4	main
tekkiv	doc_491521502079_item	3375403	et	4	main
reputatsioon	doc_491521502079_item	3375404	et	3	main
kosmeetikavahendeid	doc_491521502079_item	3375405	et	3	main
müüav	doc_491521502079_item	3375406	et	4	main
inimene	doc_491521502079_item	3375407	et	3	main
nahku	doc_491521502079_item	3375411	et	4	main
šampoone	doc_491521502079_item	3375418	et	2	main
on	doc_491521502079_item	3375422	et	4	main
ravitav	doc_491521502079_item	3375423	et	4	main
mis	doc_491521502079_item	3375431	et	4	main
toodetakse	doc_491521502079_item	3375432	et	3	main
juhendit	doc_491521502079_item	3375439	et	3	main
välismaal	doc_491521502079_item	3375440	et	4	main
kreem	doc_491521502079_item	3375442	et	3	main
mida	doc_491521502079_item	3375453	et	4	main
süüakse	doc_491521502079_item	3375454	et	3	main
harva	doc_491521502079_item	3375465	et	4	main
on	doc_491521502079_item	3375466	et	4	main
õmblused	doc_491521502079_item	3375499	et	3	main
peaksid	doc_491521502079_item	3375517	et	4	main
tõlkige	doc_491521502079_item	3375527	et	3	main
переработки	doc_491521502079_item	3375529	et	2	main
veel	doc_491521502079_item	3375538	et	4	main
kui	doc_491521502079_item	3375550	et	3	main
asjad	doc_491521502079_item	3375552	et	3	main
katalogist	doc_491521502079_item	3375553	et	4	main
фирма	doc_491521502079_item	3375554	et	2	main
привлекает	doc_491521502079_item	3375555	et	2	main
värskendavad	doc_491521502079_item	3375385	et	4	main
toodev	doc_491521502079_item	3375414	et	4	main
mis	doc_491521502079_item	3375419	et	4	main
juukseid	doc_491521502079_item	3375421	et	3	main
kasutage	doc_491521502079_item	3375428	et	3	main
tav-kesksõna	doc_491521502079_item	3375429	et	4	main
kreemidele	doc_491521502079_item	3375430	et	3	main
palju	doc_491521502079_item	3375436	et	4	main
on	doc_491521502079_item	3375447	et	4	main
toidust	doc_491521502079_item	3375452	et	4	main
kasvatav	doc_491521502079_item	3375458	et	4	main
protsent	doc_491521502079_item	3375459	et	3	main
halvasti	doc_491521502079_item	3375467	et	3	main
mainet	doc_491521502079_item	3375507	et	4	main
mis	doc_491521502079_item	3375409	et	4	main
on	doc_491521502079_item	3375412	et	4	main
valis	doc_491521502079_item	3375413	et	3	main
effekt	doc_491521502079_item	3375424	et	4	main
välismaal	doc_491521502079_item	3375433	et	4	main
raske	doc_491521502079_item	3375437	et	4	main
käsipestav	doc_491521502079_item	3375448	et	4	main
pesu	doc_491521502079_item	3375449	et	4	main
on	doc_491521502079_item	3375455	et	4	main
valismaale	doc_491521502079_item	3375457	et	4	main
söötav	doc_491521502079_item	3375460	et	4	main
toit	doc_491521502079_item	3375461	et	3	main
tekitav	doc_491521502079_item	3375468	et	4	main
reklaam	doc_491521502079_item	3375469	et	3	main
ostetav	doc_491521502079_item	3375470	et	4	main
kaup	doc_491521502079_item	3375471	et	3	main
kaanega	doc_491521502079_item	3375472	et	3	main
mida	doc_491521502079_item	3375473	et	4	main
saab	doc_491521502079_item	3375474	et	3	main
kergesti	doc_491521502079_item	3375475	et	3	main
avada	doc_491521502079_item	3375476	et	3	main
on	doc_491521502079_item	3375477	et	4	main
hasti	doc_491521502079_item	3375478	et	4	main
mõetav	doc_491521502079_item	3375479	et	4	main
süsteem	doc_491521502079_item	3375480	et	3	main
kergesti	doc_491521502079_item	3375481	et	3	main
avatav	doc_491521502079_item	3375482	et	4	main
kaan	doc_491521502079_item	3375483	et	3	main
vi	doc_491521502079_item	3375484	et	4	main
tõmmake	doc_491521502079_item	3375485	et	3	main
maha	doc_491521502079_item	3375486	et	4	main
alla	doc_491521502079_item	3375487	et	3	main
valed	doc_491521502079_item	3375488	et	3	main
sõnad	doc_491521502079_item	3375489	et	4	main
suurt	doc_491521502079_item	3375490	et	3	main
koera	doc_491521502079_item	3375491	et	4	main
peab	doc_491521502079_item	3375492	et	4	main
kordamööda	doc_491521502079_item	3375493	et	3	main
ilmtingimata	doc_491521502079_item	3375494	et	3	main
omapead	doc_491521502079_item	3375495	et	3	main
õpetama	doc_491521502079_item	3375496	et	3	main
selle	doc_491521502079_item	3375497	et	4	main
pintsaku	doc_491521502079_item	3375498	et	3	main
kisuvad	doc_491521502079_item	3375501	et	3	main
firma	doc_491521502079_item	3375505	et	4	main
olemust	doc_491521502079_item	3375506	et	3	main
endale	doc_491521502079_item	3375518	et	4	main
tagajärgi	doc_491521502079_item	3375524	et	4	main
не	doc_491521502079_item	3375531	et	2	main
sorteerimine	doc_491521502079_item	3375534	et	4	main
süsteem	doc_491521502079_item	3375535	et	3	main
экономите	doc_491521502079_item	3375544	et	2	main
uued	doc_491521502079_item	3375560	et	3	main
принципы	doc_491521502079_item	3375566	et	2	main
on	doc_491521502079_item	3375511	et	4	main
raske	doc_491521502079_item	3375512	et	4	main
liigitada	doc_491521502079_item	3375513	et	3	main
sisaldada	doc_491521502079_item	3375514	et	3	main
teostada	doc_491521502079_item	3375515	et	3	main
inimesed	doc_491521502079_item	3375516	et	3	main
järeldusi	doc_491521502079_item	3375523	et	4	main
система	doc_491521502079_item	3375528	et	2	main
по	doc_491521502079_item	3375541	et	2	main
время	doc_491521502079_item	3375545	et	2	main
säästate	doc_491521502079_item	3375547	et	3	main
toob	doc_491521502079_item	3375559	et	3	main
торговли	doc_491521502079_item	3375567	et	2	main
printsipid	doc_491521502079_item	3375574	et	4	main
у	doc_491521502079_item	3375575	et	2	main
вас	doc_491521502079_item	3375576	et	2	main
есть	doc_491521502079_item	3375577	et	2	main
возможность	doc_491521502079_item	3375578	et	2	main
дома	doc_491521502079_item	3375579	et	2	main
спокойно	doc_491521502079_item	3375580	et	2	main
изучить	doc_491521502079_item	3375581	et	2	main
каталог	doc_491521502079_item	3375582	et	2	main
teil	doc_491521502079_item	3375583	et	4	main
on	doc_491521502079_item	3375584	et	4	main
võimalus	doc_491521502079_item	3375585	et	3	main
koju	doc_491521502079_item	3375586	et	3	main
kataloog	doc_491521502079_item	3375587	et	3	main
rahulikult	doc_491521502079_item	3375588	et	4	main
läba	doc_491521502079_item	3375589	et	4	main
vaadata	doc_491521502079_item	3375590	et	4	main
ära	doc_491521502079_item	3375591	et	4	main
õppida	doc_491521502079_item	3375592	et	3	main
выучить	doc_491521502079_item	3375593	et	2	main
viii	doc_491521502079_item	3375594	et	4	main
pange	doc_491521502079_item	3375595	et	4	main
sulgudes	doc_491521502079_item	3375596	et	4	main
olevad	doc_491521502079_item	3375597	et	4	main
sõnad	doc_491521502079_item	3375598	et	4	main
õigesse	doc_491521502079_item	3375599	et	3	main
vormi	doc_491521502079_item	3375600	et	4	main
see	doc_491521502079_item	3375601	et	3	main
näeb	doc_491521502079_item	3375602	et	3	main
jube	doc_491521502079_item	3375603	et	4	main
jubedat	doc_491521502079_item	3375604	et	3	main
välja	doc_491521502079_item	3375605	et	4	main
on	doc_491521502079_item	3375606	et	4	main
väga	doc_491521502079_item	3375607	et	3	main
клиентов	doc_491521502079_item	3375556	et	2	main
подарками	doc_491521502079_item	3375557	et	2	main
abil	doc_491521502079_item	3375563	et	4	main
нарушает	doc_491521502079_item	3375565	et	2	main
see	doc_491521502079_item	3375570	et	3	main
piinlik	doc_491521502079_item	3375608	et	3	main
piinlik	doc_491521502079_item	3375609	et	3	main
kui	doc_491521502079_item	3375610	et	3	main
inimesed	doc_491521502079_item	3375611	et	3	main
ei	doc_491521502079_item	3375612	et	4	main
korista	doc_491521502079_item	3375613	et	4	main
enda	doc_491521502079_item	3375614	et	4	main
järelt	doc_491521502079_item	3375615	et	4	main
vihma	doc_491521502079_item	3375616	et	4	main
sajab	doc_491521502079_item	3375617	et	3	main
lakkamatu	doc_491521502079_item	3375618	et	4	main
lakkamatult	doc_491521502079_item	3375619	et	4	main
kassis	doc_491521502079_item	3375620	et	3	main
jõukohane	doc_491521502080_item	3376485	et	4	main
ära	doc_491521502080_item	3376503	et	4	main
parenema	doc_491521502080_item	3376511	et	3	main
tekkiv	doc_491521502080_item	3376550	et	4	main
värskendava	doc_491521502080_item	3376557	et	4	main
vahenditega	doc_491521502080_item	3376558	et	3	main
inimest	doc_491521502080_item	3376559	et	3	main
müüdav	doc_491521502080_item	3376563	et	4	main
v	doc_491521502080_item	3376577	et	4	main
kreemile	doc_491521502080_item	3376586	et	3	main
söödetav	doc_491521502080_item	3376597	et	4	main
toit	doc_491521502080_item	3376598	et	3	main
kaupu	doc_491521502080_item	3376599	et	3	main
saab	doc_491521502080_item	3376608	et	3	main
järeldusi	doc_491521502080_item	3376653	et	4	main
prügi	doc_491521502080_item	3376663	et	4	main
töötamata	doc_491521502080_item	3376668	et	4	main
подходящий	doc_491521502080_item	3376486	et	2	main
разлагаться	doc_491521502080_item	3376488	et	2	main
ära	doc_491521502080_item	3376491	et	4	main
отслужить	doc_491521502080_item	3376493	et	2	main
toime	doc_491521502080_item	3376495	et	4	main
tulema	doc_491521502080_item	3376496	et	4	main
оказывать	doc_491521502080_item	3376497	et	2	main
действие	doc_491521502080_item	3376498	et	2	main
minema	doc_491521502080_item	3376504	et	3	main
saama	doc_491521502080_item	3376510	et	4	main
v-kesksõna	doc_491521502080_item	3376544	et	4	main
mis	doc_491521502080_item	3376546	et	4	main
tekib	doc_491521502080_item	3376547	et	3	main
kodus	doc_491521502080_item	3376548	et	4	main
värskendavad	doc_491521502080_item	3376554	et	4	main
müüb	doc_491521502080_item	3376561	et	3	main
inimene	doc_491521502080_item	3376564	et	3	main
tav-kesksõna	doc_491521502080_item	3376579	et	4	main
kreemidele	doc_491521502080_item	3376580	et	3	main
pesu	doc_491521502080_item	3376587	et	4	main
mida	doc_491521502080_item	3376588	et	4	main
pestakse	doc_491521502080_item	3376589	et	3	main
mida	doc_491521502080_item	3376600	et	4	main
harva	doc_491521502080_item	3376602	et	4	main
harvasti	doc_491521502080_item	3376603	et	3	main
ostetav	doc_491521502080_item	3376604	et	4	main
kergesti	doc_491521502080_item	3376611	et	3	main
avadav	doc_491521502080_item	3376612	et	4	main
vi	doc_491521502080_item	3376614	et	4	main
tõmmake	doc_491521502080_item	3376615	et	3	main
maha	doc_491521502080_item	3376616	et	4	main
kahjustasid	doc_491521502080_item	3376634	et	4	main
firma	doc_491521502080_item	3376635	et	4	main
olemust	doc_491521502080_item	3376636	et	3	main
raske	doc_491521502080_item	3376642	et	4	main
liigitada	doc_491521502080_item	3376643	et	3	main
sisaldada	doc_491521502080_item	3376644	et	3	main
tagajärgi	doc_491521502080_item	3376654	et	4	main
ümbertöötamise	doc_491521502080_item	3376664	et	3	main
välja	doc_491521502080_item	3376667	et	4	main
по	doc_491521502080_item	3376670	et	2	main
вы	doc_491521502080_item	3376672	et	2	main
vaadata	doc_491521502080_item	3376713	et	4	main
sulgudes	doc_491521502080_item	3376716	et	4	main
välja	doc_491521502080_item	3376725	et	4	main
lakkamatult	doc_491521502080_item	3376739	et	4	main
kassis	doc_491521502080_item	3376740	et	3	main
kontrolltöö	doc_491521502080_item	3376471	et	4	main
сереть	doc_491521502080_item	3376477	et	2	main
остатки	doc_491521502080_item	3376482	et	2	main
мусор	doc_491521502080_item	3376490	et	2	main
kuluma	doc_491521502080_item	3376492	et	3	main
ühesõnalised	doc_491521502080_item	3376501	et	4	main
lahkuma	doc_491521502080_item	3376505	et	3	main
terveks	doc_491521502080_item	3376509	et	4	main
maha	doc_491521502080_item	3376512	et	4	main
jätma	doc_491521502080_item	3376513	et	3	main
lahku	doc_491521502080_item	3376514	et	4	main
minema	doc_491521502080_item	3376515	et	3	main
kinni	doc_491521502080_item	3376516	et	3	main
püüdma	doc_491521502080_item	3376517	et	3	main
suletama	doc_491521502080_item	3376518	et	3	main
prügi	doc_491521502080_item	3376545	et	4	main
kes	doc_491521502080_item	3376560	et	4	main
mis	doc_491521502080_item	3376566	et	4	main
kreem	doc_491521502080_item	3376569	et	3	main
i	doc_491521502080_item	3376472	et	4	main
tõlkige	doc_491521502080_item	3376473	et	3	main
taipama	doc_491521502080_item	3376474	et	3	main
hallitama	doc_491521502080_item	3376476	et	3	main
umbusklik	doc_491521502080_item	3376478	et	3	main
неверящий	doc_491521502080_item	3376480	et	2	main
jäätmed	doc_491521502080_item	3376481	et	3	main
pihustama	doc_491521502080_item	3376484	et	3	main
tõhus	doc_491521502080_item	3376489	et	4	main
износиться	doc_491521502080_item	3376494	et	2	main
sünonüümid	doc_491521502080_item	3376502	et	3	main
haigeks	doc_491521502080_item	3376506	et	4	main
haigestama	doc_491521502080_item	3376508	et	3	main
iii	doc_491521502080_item	3376519	et	4	main
kodus	doc_491521502080_item	3376549	et	4	main
õhku	doc_491521502080_item	3376555	et	4	main
õhu	doc_491521502080_item	3376556	et	3	main
niisutav	doc_491521502080_item	3376568	et	4	main
šampoone	doc_491521502080_item	3376570	et	2	main
mis	doc_491521502080_item	3376571	et	4	main
toodetavale	doc_491521502080_item	3376585	et	4	main
käsiti	doc_491521502080_item	3376591	et	4	main
pesu	doc_491521502080_item	3376593	et	4	main
kergesti	doc_491521502080_item	3376609	et	3	main
kaan	doc_491521502080_item	3376613	et	3	main
mainet	doc_491521502080_item	3376637	et	4	main
teostada	doc_491521502080_item	3376645	et	3	main
endale	doc_491521502080_item	3376648	et	4	main
vii	doc_491521502080_item	3376656	et	4	main
система	doc_491521502080_item	3376658	et	2	main
мусора	doc_491521502080_item	3376660	et	2	main
разработана	doc_491521502080_item	3376662	et	2	main
каталогу	doc_491521502080_item	3376671	et	2	main
pange	doc_491521502080_item	3376715	et	4	main
sõnad	doc_491521502080_item	3376718	et	4	main
õigesse	doc_491521502080_item	3376719	et	3	main
vormi	doc_491521502080_item	3376720	et	4	main
see	doc_491521502080_item	3376721	et	3	main
näeb	doc_491521502080_item	3376722	et	3	main
kui	doc_491521502080_item	3376730	et	3	main
inimesed	doc_491521502080_item	3376731	et	3	main
enda	doc_491521502080_item	3376734	et	4	main
hirmus	doc_491521502080_item	3376742	et	4	main
hirmuseid	doc_491521502080_item	3376743	et	3	main
karva	doc_491521502080_item	3376744	et	4	main
mul	doc_491521502080_item	3376745	et	3	main
on	doc_491521502080_item	3376746	et	4	main
ebameeldiv	doc_491521502080_item	3376747	et	3	main
ebameeldiv	doc_491521502080_item	3376748	et	3	main
seda	doc_491521502080_item	3376749	et	3	main
rahulikult	doc_491521502080_item	3376711	et	4	main
ümber	doc_491521502080_item	3376712	et	3	main
понимать	doc_491521502080_item	3376475	et	2	main
атеист	doc_491521502080_item	3376479	et	2	main
отходы	doc_491521502080_item	3376483	et	2	main
lakkama	doc_491521502080_item	3376487	et	3	main
ii	doc_491521502080_item	3376499	et	4	main
kirjutage	doc_491521502080_item	3376500	et	3	main
jääma	doc_491521502080_item	3376507	et	4	main
mida	doc_491521502080_item	3376520	et	4	main
tehti	doc_491521502080_item	3376521	et	3	main
nõudma	doc_491521502080_item	3376522	et	3	main
nõuti	doc_491521502080_item	3376523	et	3	main
ütlema	doc_491521502080_item	3376524	et	3	main
öeldi	doc_491521502080_item	3376525	et	3	main
andma	doc_491521502080_item	3376526	et	3	main
pakkuma	doc_491521502080_item	3376528	et	3	main
anti	doc_491521502080_item	3376527	et	3	main
pakuti	doc_491521502080_item	3376529	et	3	main
lubama	doc_491521502080_item	3376530	et	3	main
lubati	doc_491521502080_item	3376531	et	3	main
tegema	doc_491521502080_item	3376532	et	3	main
tehti	doc_491521502080_item	3376533	et	3	main
laskma	doc_491521502080_item	3376534	et	3	main
laseti	doc_491521502080_item	3376535	et	4	main
saatma	doc_491521502080_item	3376536	et	3	main
saati	doc_491521502080_item	3376537	et	3	main
rääkima	doc_491521502080_item	3376538	et	3	main
räägiti	doc_491521502080_item	3376539	et	3	main
teatama	doc_491521502080_item	3376540	et	4	main
teadeti	doc_491521502080_item	3376541	et	4	main
iv	doc_491521502080_item	3376542	et	4	main
kasutage	doc_491521502080_item	3376543	et	3	main
prügi	doc_491521502080_item	3376551	et	4	main
vahenditeta	doc_491521502080_item	3376552	et	3	main
mis	doc_491521502080_item	3376553	et	4	main
kosmeetikavahendeid	doc_491521502080_item	3376562	et	3	main
kreemiga	doc_491521502080_item	3376565	et	4	main
niisutab	doc_491521502080_item	3376567	et	3	main
kasutage	doc_491521502080_item	3376578	et	3	main
mis	doc_491521502080_item	3376581	et	4	main
toodetakse	doc_491521502080_item	3376582	et	3	main
välismaal	doc_491521502080_item	3376583	et	4	main
käsitsi	doc_491521502080_item	3376590	et	3	main
toidust	doc_491521502080_item	3376594	et	4	main
mida	doc_491521502080_item	3376595	et	4	main
süüakse	doc_491521502080_item	3376596	et	3	main
kaup	doc_491521502080_item	3376605	et	3	main
kaanega	doc_491521502080_item	3376606	et	3	main
mida	doc_491521502080_item	3376607	et	4	main
puänti	doc_491521502080_item	3376638	et	4	main
seda	doc_491521502080_item	3376639	et	3	main
peaksid	doc_491521502080_item	3376647	et	4	main
tulemusi	doc_491521502080_item	3376655	et	4	main
süsteem	doc_491521502080_item	3376665	et	3	main
время	doc_491521502080_item	3376674	et	2	main
tellimisel	doc_491521502080_item	3376676	et	4	main
jube	doc_491521502080_item	3376723	et	4	main
lakkamatu	doc_491521502080_item	3376738	et	4	main
ravivad	doc_491521502080_item	3376572	et	4	main
juukseid	doc_491521502080_item	3376573	et	3	main
juuste	doc_491521502080_item	3376574	et	4	main
raviv	doc_491521502080_item	3376575	et	4	main
šampoon	doc_491521502080_item	3376576	et	2	main
välismaal	doc_491521502080_item	3376584	et	4	main
pesetav	doc_491521502080_item	3376592	et	4	main
ostetakse	doc_491521502080_item	3376601	et	3	main
avada	doc_491521502080_item	3376610	et	3	main
alla	doc_491521502080_item	3376617	et	3	main
valed	doc_491521502080_item	3376618	et	3	main
sõnad	doc_491521502080_item	3376619	et	4	main
suurt	doc_491521502080_item	3376620	et	3	main
koera	doc_491521502080_item	3376621	et	4	main
peab	doc_491521502080_item	3376622	et	4	main
kordamööda	doc_491521502080_item	3376623	et	3	main
ilmtingimata	doc_491521502080_item	3376624	et	3	main
omapead	doc_491521502080_item	3376625	et	3	main
õpetama	doc_491521502080_item	3376626	et	3	main
selle	doc_491521502080_item	3376627	et	4	main
pintsaku	doc_491521502080_item	3376628	et	3	main
õmblused	doc_491521502080_item	3376629	et	3	main
käsitsevad	doc_491521502080_item	3376630	et	4	main
kisuvad	doc_491521502080_item	3376631	et	3	main
artiklid	doc_491521502080_item	3376633	et	3	main
luituvad	doc_491521502080_item	3376632	et	4	main
plaani	doc_491521502080_item	3376640	et	4	main
on	doc_491521502080_item	3376641	et	4	main
inimesed	doc_491521502080_item	3376646	et	3	main
rohkem	doc_491521502080_item	3376649	et	4	main
teadvustama	doc_491521502080_item	3376650	et	3	main
keskkonna	doc_491521502080_item	3376651	et	3	main
reostamise	doc_491521502080_item	3376652	et	4	main
tõlkige	doc_491521502080_item	3376657	et	3	main
переработки	doc_491521502080_item	3376659	et	2	main
не	doc_491521502080_item	3376661	et	2	main
on	doc_491521502080_item	3376666	et	4	main
заказывая	doc_491521502080_item	3376669	et	2	main
экономите	doc_491521502080_item	3376673	et	2	main
katalogist	doc_491521502080_item	3376675	et	4	main
te	doc_491521502080_item	3376677	et	4	main
viii	doc_491521502080_item	3376714	et	4	main
olevad	doc_491521502080_item	3376717	et	4	main
on	doc_491521502080_item	3376726	et	4	main
väga	doc_491521502080_item	3376727	et	3	main
piinlik	doc_491521502080_item	3376728	et	3	main
piinlik	doc_491521502080_item	3376729	et	3	main
ei	doc_491521502080_item	3376732	et	4	main
ajavad	doc_491521502080_item	3376741	et	4	main
säästate	doc_491521502080_item	3376678	et	3	main
aega	doc_491521502080_item	3376679	et	4	main
фирма	doc_491521502080_item	3376680	et	2	main
привлекает	doc_491521502080_item	3376681	et	2	main
клиентов	doc_491521502080_item	3376682	et	2	main
подарками	doc_491521502080_item	3376683	et	2	main
firma	doc_491521502080_item	3376684	et	4	main
peibutab	doc_491521502080_item	3376685	et	3	main
klienti	doc_491521502080_item	3376686	et	4	main
kingitustega	doc_491521502080_item	3376687	et	4	main
это	doc_491521502080_item	3376688	et	2	main
нарушает	doc_491521502080_item	3376689	et	2	main
принципы	doc_491521502080_item	3376690	et	2	main
торговли	doc_491521502080_item	3376691	et	2	main
свободного	doc_491521502080_item	3376692	et	2	main
рынка	doc_491521502080_item	3376693	et	2	main
see	doc_491521502080_item	3376694	et	3	main
sekkub	doc_491521502080_item	3376695	et	3	main
vabakaubanduse	doc_491521502080_item	3376696	et	3	main
põhimõtetesse	doc_491521502080_item	3376697	et	3	main
у	doc_491521502080_item	3376698	et	2	main
вас	doc_491521502080_item	3376699	et	2	main
есть	doc_491521502080_item	3376700	et	2	main
возможность	doc_491521502080_item	3376701	et	2	main
спокойно	doc_491521502080_item	3376703	et	2	main
дома	doc_491521502080_item	3376702	et	2	main
изучить	doc_491521502080_item	3376704	et	2	main
каталог	doc_491521502080_item	3376705	et	2	main
teil	doc_491521502080_item	3376706	et	4	main
võimalus	doc_491521502080_item	3376708	et	3	main
on	doc_491521502080_item	3376707	et	4	main
kataloogi	doc_491521502080_item	3376709	et	4	main
kodus	doc_491521502080_item	3376710	et	4	main
jubedalt	doc_491521502080_item	3376724	et	4	main
korista	doc_491521502080_item	3376733	et	4	main
järelt	doc_491521502080_item	3376735	et	4	main
vihma	doc_491521502080_item	3376736	et	4	main
sajab	doc_491521502080_item	3376737	et	3	main
vaadata	doc_491521502080_item	3376750	et	4	main
kontrolltöö	doc_491521502081_item	3377036	et	4	main
соображать	doc_491521502081_item	3377042	et	2	main
umbusklik	doc_491521502081_item	3377045	et	3	main
pihustama	doc_491521502081_item	3377050	et	3	main
силу	doc_491521502081_item	3377054	et	2	main
действенный	doc_491521502081_item	3377057	et	2	main
изнашиваться	doc_491521502081_item	3377061	et	2	main
toime	doc_491521502081_item	3377062	et	4	main
kirjutage	doc_491521502081_item	3377066	et	3	main
sünonüümid	doc_491521502081_item	3377068	et	3	main
jätma	doc_491521502081_item	3377078	et	3	main
püüdma	doc_491521502081_item	3377081	et	3	main
tehti	doc_491521502081_item	3377085	et	3	main
lubama	doc_491521502081_item	3377094	et	3	main
tehti	doc_491521502081_item	3377097	et	3	main
saatma	doc_491521502081_item	3377100	et	3	main
raagiti	doc_491521502081_item	3377103	et	4	main
teatama	doc_491521502081_item	3377104	et	4	main
teatati	doc_491521502081_item	3377105	et	3	main
v-kesksõna	doc_491521502081_item	3377108	et	4	main
õhku	doc_491521502081_item	3377120	et	4	main
v	doc_491521502081_item	3377142	et	4	main
tav-kesksõna	doc_491521502081_item	3377144	et	4	main
mis	doc_491521502081_item	3377146	et	4	main
käsitsi	doc_491521502081_item	3377156	et	3	main
süüakse	doc_491521502081_item	3377161	et	3	main
toidust	doc_491521502081_item	3377163	et	4	main
vi	doc_491521502081_item	3377179	et	4	main
õmblused	doc_491521502081_item	3377194	et	3	main
kisuvad	doc_491521502081_item	3377196	et	3	main
on	doc_491521502081_item	3377206	et	4	main
kataloogi	doc_491521502081_item	3377243	et	4	main
säästate	doc_491521502081_item	3377246	et	3	main
oma	doc_491521502081_item	3377247	et	4	main
takistab	doc_491521502081_item	3377261	et	3	main
ellu	doc_491521502081_item	3377264	et	4	main
вас	doc_491521502081_item	3377267	et	2	main
возможность	doc_491521502081_item	3377269	et	2	main
каталог	doc_491521502081_item	3377273	et	2	main
on	doc_491521502081_item	3377275	et	4	main
kodus	doc_491521502081_item	3377277	et	4	main
rahulikult	doc_491521502081_item	3377278	et	4	main
sulgudes	doc_491521502081_item	3377283	et	4	main
see	doc_491521502081_item	3377288	et	3	main
ei	doc_491521502081_item	3377299	et	4	main
korista	doc_491521502081_item	3377300	et	4	main
enda	doc_491521502081_item	3377301	et	4	main
on	doc_491521502081_item	3377313	et	4	main
ebameeldiv	doc_491521502081_item	3377314	et	3	main
ebameeldivalt	doc_491521502081_item	3377315	et	4	main
tõlkige	doc_491521502081_item	3377039	et	3	main
недоверчивый	doc_491521502081_item	3377046	et	2	main
отходы	doc_491521502081_item	3377049	et	2	main
jõukohane	doc_491521502081_item	3377052	et	4	main
lakkama	doc_491521502081_item	3377055	et	3	main
интенсивный	doc_491521502081_item	3377058	et	2	main
ära	doc_491521502081_item	3377059	et	4	main
kuluma	doc_491521502081_item	3377060	et	3	main
ii	doc_491521502081_item	3377065	et	4	main
lahkuma	doc_491521502081_item	3377071	et	3	main
jääma	doc_491521502081_item	3377073	et	4	main
haigestama	doc_491521502081_item	3377074	et	3	main
terveks	doc_491521502081_item	3377075	et	4	main
kinni	doc_491521502081_item	3377080	et	3	main
nõudi	doc_491521502081_item	3377087	et	4	main
öeldi	doc_491521502081_item	3377089	et	3	main
pakuti	doc_491521502081_item	3377093	et	3	main
laskma	doc_491521502081_item	3377098	et	3	main
iv	doc_491521502081_item	3377106	et	4	main
prügi	doc_491521502081_item	3377109	et	4	main
mis	doc_491521502081_item	3377110	et	4	main
tekib	doc_491521502081_item	3377111	et	3	main
õhku	doc_491521502081_item	3377119	et	4	main
šampoone	doc_491521502081_item	3377135	et	2	main
ravivaid	doc_491521502081_item	3377140	et	4	main
pesu	doc_491521502081_item	3377152	et	4	main
kaupu	doc_491521502081_item	3377164	et	3	main
ostetakse	doc_491521502081_item	3377166	et	3	main
kaanega	doc_491521502081_item	3377178	et	3	main
õpetama	doc_491521502081_item	3377191	et	3	main
sisaldada	doc_491521502081_item	3377209	et	3	main
tagajärgi	doc_491521502081_item	3377219	et	4	main
tulemusi	doc_491521502081_item	3377220	et	4	main
prügi	doc_491521502081_item	3377228	et	4	main
süsteem	doc_491521502081_item	3377230	et	3	main
ei	doc_491521502081_item	3377231	et	4	main
ole	doc_491521502081_item	3377232	et	4	main
время	doc_491521502081_item	3377239	et	2	main
te	doc_491521502081_item	3377245	et	4	main
принципы	doc_491521502081_item	3377256	et	2	main
рынка	doc_491521502081_item	3377259	et	2	main
спокойно	doc_491521502081_item	3377271	et	2	main
sõnad	doc_491521502081_item	3377285	et	4	main
õigesse	doc_491521502081_item	3377286	et	3	main
jube	doc_491521502081_item	3377290	et	4	main
jubedalt	doc_491521502081_item	3377291	et	4	main
vihma	doc_491521502081_item	3377303	et	4	main
sajab	doc_491521502081_item	3377304	et	3	main
ajavad	doc_491521502081_item	3377308	et	4	main
hirmsalt	doc_491521502081_item	3377310	et	4	main
seda	doc_491521502081_item	3377316	et	3	main
am-12	doc_491521502081_item	3377037	et	4	main
taipama	doc_491521502081_item	3377040	et	3	main
плесневеть	doc_491521502081_item	3377044	et	2	main
jäätmed	doc_491521502081_item	3377047	et	3	main
распылять	doc_491521502081_item	3377051	et	2	main
tõhus	doc_491521502081_item	3377056	et	4	main
ühesõnalised	doc_491521502081_item	3377067	et	4	main
ära	doc_491521502081_item	3377069	et	4	main
maha	doc_491521502081_item	3377077	et	4	main
hügistama	doc_491521502081_item	3377079	et	4	main
tabama	doc_491521502081_item	3377082	et	3	main
nõudma	doc_491521502081_item	3377086	et	3	main
anti	doc_491521502081_item	3377091	et	3	main
lubati	doc_491521502081_item	3377095	et	3	main
rääkima	doc_491521502081_item	3377102	et	3	main
kasutage	doc_491521502081_item	3377107	et	3	main
tekkiv	doc_491521502081_item	3377114	et	4	main
mis	doc_491521502081_item	3377117	et	4	main
värskendavad	doc_491521502081_item	3377118	et	4	main
kontrolltöö	doc_491521502081_item	3377035	et	4	main
hallitama	doc_491521502081_item	3377043	et	3	main
под	doc_491521502081_item	3377053	et	2	main
действовать	doc_491521502081_item	3377064	et	2	main
saama	doc_491521502081_item	3377076	et	4	main
mida	doc_491521502081_item	3377084	et	4	main
ütlema	doc_491521502081_item	3377088	et	3	main
andma	doc_491521502081_item	3377090	et	3	main
pakkuma	doc_491521502081_item	3377092	et	3	main
lasti	doc_491521502081_item	3377099	et	4	main
saadi	doc_491521502081_item	3377101	et	4	main
kodus	doc_491521502081_item	3377113	et	4	main
vahenditeta	doc_491521502081_item	3377116	et	3	main
inimest	doc_491521502081_item	3377123	et	3	main
juukseid	doc_491521502081_item	3377139	et	3	main
šampoone	doc_491521502081_item	3377141	et	2	main
toodetavatele	doc_491521502081_item	3377150	et	4	main
kreemidele	doc_491521502081_item	3377151	et	3	main
toidust	doc_491521502081_item	3377159	et	4	main
söödavast	doc_491521502081_item	3377162	et	4	main
mida	doc_491521502081_item	3377165	et	4	main
peab	doc_491521502081_item	3377187	et	4	main
kordamööda	doc_491521502081_item	3377188	et	3	main
ilmtingimata	doc_491521502081_item	3377189	et	3	main
omapead	doc_491521502081_item	3377190	et	3	main
mainet	doc_491521502081_item	3377202	et	4	main
puänti	doc_491521502081_item	3377203	et	4	main
seda	doc_491521502081_item	3377204	et	3	main
teostada	doc_491521502081_item	3377210	et	3	main
järeldusi	doc_491521502081_item	3377218	et	4	main
veel	doc_491521502081_item	3377233	et	4	main
заказывая	doc_491521502081_item	3377234	et	2	main
по	doc_491521502081_item	3377235	et	2	main
каталогу	doc_491521502081_item	3377236	et	2	main
вы	doc_491521502081_item	3377237	et	2	main
i	doc_491521502081_item	3377038	et	4	main
понимать	doc_491521502081_item	3377041	et	2	main
остатки	doc_491521502081_item	3377048	et	2	main
tulema	doc_491521502081_item	3377063	et	4	main
minema	doc_491521502081_item	3377070	et	3	main
haigeks	doc_491521502081_item	3377072	et	4	main
iii	doc_491521502081_item	3377083	et	4	main
tegema	doc_491521502081_item	3377096	et	3	main
kodus	doc_491521502081_item	3377112	et	4	main
prügi	doc_491521502081_item	3377115	et	4	main
värskendavateta	doc_491521502081_item	3377121	et	4	main
vahenditeta	doc_491521502081_item	3377122	et	3	main
kes	doc_491521502081_item	3377124	et	4	main
müüb	doc_491521502081_item	3377125	et	3	main
kosmeetikavahendeid	doc_491521502081_item	3377126	et	3	main
kosmeetikavahendeid	doc_491521502081_item	3377127	et	3	main
müüv	doc_491521502081_item	3377128	et	4	main
inimene	doc_491521502081_item	3377129	et	3	main
kreemiga	doc_491521502081_item	3377130	et	4	main
mis	doc_491521502081_item	3377131	et	4	main
niisutab	doc_491521502081_item	3377132	et	3	main
niisutava	doc_491521502081_item	3377133	et	4	main
kreemiga	doc_491521502081_item	3377134	et	4	main
mis	doc_491521502081_item	3377136	et	4	main
ravivad	doc_491521502081_item	3377137	et	4	main
juukseid	doc_491521502081_item	3377138	et	3	main
kasutage	doc_491521502081_item	3377143	et	3	main
kreemidele	doc_491521502081_item	3377145	et	3	main
toodetakse	doc_491521502081_item	3377147	et	3	main
välismaal	doc_491521502081_item	3377148	et	4	main
mida	doc_491521502081_item	3377153	et	4	main
pestakse	doc_491521502081_item	3377154	et	3	main
käsitsi	doc_491521502081_item	3377155	et	3	main
mida	doc_491521502081_item	3377160	et	4	main
avatava	doc_491521502081_item	3377177	et	4	main
maha	doc_491521502081_item	3377181	et	4	main
suurt	doc_491521502081_item	3377185	et	3	main
koera	doc_491521502081_item	3377186	et	4	main
pintsaku	doc_491521502081_item	3377193	et	3	main
luituvad	doc_491521502081_item	3377197	et	4	main
artiklid	doc_491521502081_item	3377198	et	3	main
kahjustasid	doc_491521502081_item	3377199	et	4	main
plaani	doc_491521502081_item	3377205	et	4	main
inimesed	doc_491521502081_item	3377211	et	3	main
endale	doc_491521502081_item	3377213	et	4	main
rohkem	doc_491521502081_item	3377214	et	4	main
teadvustama	doc_491521502081_item	3377215	et	3	main
keskkonna	doc_491521502081_item	3377216	et	3	main
reostamise	doc_491521502081_item	3377217	et	4	main
система	doc_491521502081_item	3377223	et	2	main
мусора	doc_491521502081_item	3377225	et	2	main
разработана	doc_491521502081_item	3377227	et	2	main
tellite	doc_491521502081_item	3377242	et	3	main
нарушает	doc_491521502081_item	3377255	et	2	main
свободного	doc_491521502081_item	3377258	et	2	main
see	doc_491521502081_item	3377260	et	3	main
у	doc_491521502081_item	3377266	et	2	main
teil	doc_491521502081_item	3377274	et	4	main
võimalus	doc_491521502081_item	3377276	et	3	main
viii	doc_491521502081_item	3377281	et	4	main
pange	doc_491521502081_item	3377282	et	4	main
vormi	doc_491521502081_item	3377287	et	4	main
näeb	doc_491521502081_item	3377289	et	3	main
piinlikult	doc_491521502081_item	3377296	et	4	main
kui	doc_491521502081_item	3377297	et	3	main
inimesed	doc_491521502081_item	3377298	et	3	main
lakkamatu	doc_491521502081_item	3377305	et	4	main
vaadata	doc_491521502081_item	3377317	et	4	main
välismaal	doc_491521502081_item	3377149	et	4	main
pestav	doc_491521502081_item	3377157	et	4	main
pesu	doc_491521502081_item	3377158	et	4	main
harva	doc_491521502081_item	3377167	et	4	main
harva	doc_491521502081_item	3377168	et	4	main
ostetava	doc_491521502081_item	3377169	et	4	main
kaupu	doc_491521502081_item	3377170	et	3	main
kaanega	doc_491521502081_item	3377171	et	3	main
mida	doc_491521502081_item	3377172	et	4	main
saab	doc_491521502081_item	3377173	et	3	main
kergesti	doc_491521502081_item	3377174	et	3	main
avada	doc_491521502081_item	3377175	et	3	main
kergesti	doc_491521502081_item	3377176	et	3	main
tõmmake	doc_491521502081_item	3377180	et	3	main
alla	doc_491521502081_item	3377182	et	3	main
valed	doc_491521502081_item	3377183	et	3	main
sõnad	doc_491521502081_item	3377184	et	4	main
selle	doc_491521502081_item	3377192	et	4	main
käsitsevad	doc_491521502081_item	3377195	et	4	main
firma	doc_491521502081_item	3377200	et	4	main
olemust	doc_491521502081_item	3377201	et	3	main
raske	doc_491521502081_item	3377207	et	4	main
liigitada	doc_491521502081_item	3377208	et	3	main
peaksid	doc_491521502081_item	3377212	et	4	main
vii	doc_491521502081_item	3377221	et	4	main
tõlkige	doc_491521502081_item	3377222	et	3	main
переработки	doc_491521502081_item	3377224	et	2	main
не	doc_491521502081_item	3377226	et	2	main
ületoodamise	doc_491521502081_item	3377229	et	4	main
kui	doc_491521502081_item	3377240	et	3	main
firma	doc_491521502081_item	3377253	et	4	main
это	doc_491521502081_item	3377254	et	2	main
торговли	doc_491521502081_item	3377257	et	2	main
vabaturu	doc_491521502081_item	3377262	et	3	main
изучить	doc_491521502081_item	3377272	et	2	main
vaadata	doc_491521502081_item	3377279	et	4	main
olevad	doc_491521502081_item	3377284	et	4	main
välja	doc_491521502081_item	3377292	et	4	main
kassis	doc_491521502081_item	3377307	et	3	main
экономите	doc_491521502081_item	3377238	et	2	main
te	doc_491521502081_item	3377241	et	4	main
järgi	doc_491521502081_item	3377244	et	4	main
aega	doc_491521502081_item	3377248	et	4	main
фирма	doc_491521502081_item	3377249	et	2	main
привлекает	doc_491521502081_item	3377250	et	2	main
клиентов	doc_491521502081_item	3377251	et	2	main
подарками	doc_491521502081_item	3377252	et	2	main
printsiipide	doc_491521502081_item	3377263	et	3	main
viimist	doc_491521502081_item	3377265	et	4	main
есть	doc_491521502081_item	3377268	et	2	main
дома	doc_491521502081_item	3377270	et	2	main
kataloogi	doc_491521502081_item	3377280	et	4	main
on	doc_491521502081_item	3377293	et	4	main
väga	doc_491521502081_item	3377294	et	3	main
piinlik	doc_491521502081_item	3377295	et	3	main
järelt	doc_491521502081_item	3377302	et	4	main
lakkamatult	doc_491521502081_item	3377306	et	4	main
hirmus	doc_491521502081_item	3377309	et	4	main
karva	doc_491521502081_item	3377311	et	4	main
mul	doc_491521502081_item	3377312	et	3	main
kontrastiivlingvistika	doc_491521501855_item	3398015	et	4	main
vead	doc_491521501855_item	3398019	et	4	main
kogutud	doc_491521501855_item	3398021	et	4	main
eesti	doc_491521501855_item	3398022	et	4	main
merekooli	doc_491521501855_item	3398025	et	4	main
16-	doc_491521501855_item	3398026	et	4	main
18-aastaste	doc_491521501855_item	3398028	et	2	main
venekeelse	doc_491521501855_item	3398029	et	3	main
põhikooli	doc_491521501855_item	3398030	et	4	main
multilingua	doc_491521501855_item	3398037	et	4	main
detsember	doc_491521501855_item	3398046	et	3	main
ema	doc_491521501855_item	3398048	et	4	main
õpilased	doc_491521501855_item	3398050	et	3	main
põhikooli	doc_491521501855_item	3398055	et	4	main
tase	doc_491521501855_item	3398059	et	3	main
erinevatest	doc_491521501855_item	3398067	et	4	main
parema	doc_491521501855_item	3398069	et	4	main
õpilastel	doc_491521501855_item	3398071	et	4	main
välismaiste	doc_491521501855_item	3398077	et	4	main
nimede	doc_491521501855_item	3398078	et	3	main
kirjutamisel	doc_491521501855_item	3398079	et	4	main
bruss	doc_491521501855_item	3398085	et	4	main
lee	doc_491521501855_item	3398088	et	4	main
keidz	doc_491521501855_item	3398090	et	4	main
viga	doc_491521501855_item	3398095	et	4	main
keeles	doc_491521501855_item	3398102	et	4	main
kirjutatakse	doc_491521501855_item	3398103	et	3	main
on	doc_491521501855_item	3398115	et	4	main
selles	doc_491521501855_item	3398016	et	4	main
kuni	doc_491521501855_item	3398027	et	3	main
ning	doc_491521501855_item	3398035	et	3	main
erakooli	doc_491521501855_item	3398036	et	4	main
grupi	doc_491521501855_item	3398041	et	3	main
2001	doc_491521501855_item	3398047	et	2	main
merekooli	doc_491521501855_item	3398049	et	4	main
on	doc_491521501855_item	3398065	et	4	main
koolidest	doc_491521501855_item	3398068	et	3	main
mickey	doc_491521501855_item	3398083	et	4	main
nicolas	doc_491521501855_item	3398091	et	4	main
on	doc_491521501855_item	3398096	et	4	main
keelest	doc_491521501855_item	3398119	et	4	main
vead	doc_491521501855_item	3398128	et	4	main
hästi	doc_491521501855_item	3398129	et	3	main
eesti	doc_491521501855_item	3398130	et	4	main
seas	doc_491521501855_item	3398134	et	4	main
on	doc_491521501855_item	3398135	et	4	main
ma	doc_491521501855_item	3398147	et	3	main
tõenäoliselt	doc_491521501855_item	3398154	et	4	main
eestlastega	doc_491521501855_item	3398156	et	4	main
kõike	doc_491521501855_item	3398162	et	4	main
mida	doc_491521501855_item	3398163	et	4	main
räägitakse	doc_491521501855_item	3398164	et	3	main
ka	doc_491521501855_item	3398166	et	3	main
kirja	doc_491521501855_item	3398167	et	4	main
mitmuse	doc_491521501855_item	3398174	et	3	main
jooksul	doc_491521501855_item	3398191	et	4	main
küll	doc_491521501855_item	3398197	et	4	main
teab	doc_491521501855_item	3398198	et	3	main
kus	doc_491521501855_item	3398199	et	3	main
on	doc_491521501855_item	3398200	et	4	main
analüüsitud	doc_491521501855_item	3398018	et	4	main
on	doc_491521501855_item	3398020	et	4	main
lõpetanud	doc_491521501855_item	3398031	et	4	main
eesti	doc_491521501855_item	3398038	et	4	main
ajavahemikul	doc_491521501855_item	3398044	et	4	main
on	doc_491521501855_item	3398051	et	4	main
eesti	doc_491521501855_item	3398052	et	4	main
grupi	doc_491521501855_item	3398058	et	3	main
väga	doc_491521501855_item	3398061	et	3	main
kuna	doc_491521501855_item	3398063	et	3	main
ortograafiavead	doc_491521501855_item	3398075	et	4	main
eriti	doc_491521501855_item	3398076	et	3	main
rourke	doc_491521501855_item	3398084	et	4	main
bruce	doc_491521501855_item	3398087	et	4	main
nicolaz	doc_491521501855_item	3398089	et	4	main
hollywood	doc_491521501855_item	3398094	et	4	main
keeles	doc_491521501855_item	3398114	et	4	main
otse	doc_491521501855_item	3398117	et	4	main
vene	doc_491521501855_item	3398118	et	4	main
muskitirs	doc_491521501855_item	3398124	et	4	main
kolm	doc_491521501855_item	3398125	et	3	main
musketäri	doc_491521501855_item	3398126	et	4	main
paljud	doc_491521501855_item	3398127	et	3	main
kõnekeele	doc_491521501855_item	3398137	et	4	main
ka	doc_491521501855_item	3398144	et	3	main
siukest	doc_491521501855_item	3398145	et	4	main
sobib	doc_491521501855_item	3398165	et	3	main
esineb	doc_491521501855_item	3398170	et	3	main
ka	doc_491521501855_item	3398171	et	3	main
ja	doc_491521501855_item	3398173	et	3	main
on	doc_491521501855_item	3398179	et	4	main
lemmiknäitlejaid	doc_491521501855_item	3398181	et	3	main
oma	doc_491521501855_item	3398189	et	4	main
palju	doc_491521501855_item	3398194	et	4	main
osastavat	doc_491521501855_item	3398203	et	4	main
päris	doc_491521501855_item	3398208	et	4	main
selgeks	doc_491521501855_item	3398209	et	3	main
ja	doc_491521501855_item	3398214	et	3	main
esineb	doc_491521501855_item	3398219	et	3	main
mitmuse	doc_491521501855_item	3398221	et	3	main
on	doc_491521501855_item	3398227	et	4	main
ka	doc_491521501855_item	3398228	et	3	main
alati	doc_491521501855_item	3398233	et	4	main
ainsuse	doc_491521501855_item	3398257	et	4	main
eksimuste	doc_491521501855_item	3398261	et	4	main
koht	doc_491521501855_item	3398262	et	3	main
merekooli	doc_491521501855_item	3398264	et	4	main
raske	doc_491521501855_item	3398275	et	4	main
ei	doc_491521501855_item	3398279	et	4	main
või	doc_491521501855_item	3398293	et	4	main
vale	doc_491521501855_item	3398305	et	4	main
nt	doc_491521501855_item	3398307	et	4	main
jooksid	doc_491521501855_item	3398312	et	4	main
veaanalüüs	doc_491521501855_item	3398014	et	4	main
õpilaste	doc_491521501855_item	3398032	et	4	main
sõnastusõpetuse	doc_491521501855_item	3398033	et	4	main
töödest	doc_491521501855_item	3398034	et	3	main
algajate	doc_491521501855_item	3398040	et	4	main
õpilaste	doc_491521501855_item	3398042	et	4	main
töödest	doc_491521501855_item	3398043	et	3	main
õppinud	doc_491521501855_item	3398054	et	4	main
9	doc_491521501855_item	3398056	et	2	main
klassini	doc_491521501855_item	3398057	et	3	main
tulnud	doc_491521501855_item	3398066	et	4	main
keeletasemega	doc_491521501855_item	3398070	et	3	main
esinevad	doc_491521501855_item	3398072	et	4	main
ainult	doc_491521501855_item	3398073	et	4	main
nt	doc_491521501855_item	3398080	et	4	main
miki	doc_491521501855_item	3398081	et	3	main
cage	doc_491521501855_item	3398092	et	4	main
tingitud	doc_491521501855_item	3398097	et	4	main
tõlgitud	doc_491521501855_item	3398120	et	4	main
nimesid	doc_491521501855_item	3398121	et	3	main
nt	doc_491521501855_item	3398122	et	4	main
kolm	doc_491521501855_item	3398123	et	3	main
oskavate	doc_491521501855_item	3398132	et	4	main
mõjul	doc_491521501855_item	3398138	et	4	main
trennis	doc_491521501855_item	3398146	et	3	main
tingitud	doc_491521501855_item	3398155	et	4	main
suhtlemisel	doc_491521501855_item	3398157	et	4	main
tekkinud	doc_491521501855_item	3398158	et	4	main
ekslikust	doc_491521501855_item	3398159	et	4	main
nt	doc_491521501855_item	3398177	et	4	main
mul	doc_491521501855_item	3398178	et	3	main
nad	doc_491521501855_item	3398182	et	3	main
karjääri	doc_491521501855_item	3398190	et	4	main
filmi	doc_491521501855_item	3398195	et	4	main
õpilane	doc_491521501855_item	3398196	et	3	main
kuid	doc_491521501855_item	3398204	et	4	main
saanud	doc_491521501855_item	3398210	et	4	main
millal	doc_491521501855_item	3398211	et	3	main
kasutada	doc_491521501855_item	3398212	et	3	main
sagedamini	doc_491521501855_item	3398218	et	4	main
vormi	doc_491521501855_item	3398222	et	4	main
asendamist	doc_491521501855_item	3398223	et	4	main
ainsuse	doc_491521501855_item	3398224	et	4	main
sest	doc_491521501855_item	3398230	et	4	main
kasutada	doc_491521501855_item	3398248	et	3	main
tüüpiline	doc_491521501855_item	3398260	et	3	main
tugevamate	doc_491521501855_item	3398263	et	4	main
seas	doc_491521501855_item	3398266	et	4	main
õigekiri	doc_491521501855_item	3398269	et	3	main
nt	doc_491521501855_item	3398270	et	4	main
igaühele	doc_491521501855_item	3398271	et	3	main
on	doc_491521501855_item	3398272	et	4	main
kas	doc_491521501855_item	3398277	et	3	main
nimetava	doc_491521501855_item	3398287	et	4	main
eeskujul	doc_491521501855_item	3398289	et	3	main
ortograafia	doc_491521501855_item	3398306	et	4	main
mootorataga	doc_491521501855_item	3398308	et	4	main
mittu	doc_491521501855_item	3398309	et	4	main
põhjuseks	doc_491521501855_item	3398315	et	3	main
eesti	doc_491521501855_item	3398318	et	4	main
keele	doc_491521501855_item	3398319	et	4	main
silme	doc_491521501855_item	3398326	et	4	main
on	doc_491521501855_item	3398328	et	4	main
sõna	doc_491521501855_item	3398337	et	4	main
teine	doc_491521501855_item	3398338	et	3	main
on	doc_491521501855_item	3398347	et	4	main
d	doc_491521501855_item	3398355	et	4	main
muusikad	doc_491521501855_item	3398361	et	3	main
õpilase	doc_491521501855_item	3398367	et	3	main
kõrv	doc_491521501855_item	3398368	et	3	main
kuna	doc_491521501855_item	3398377	et	3	main
eesti	doc_491521501855_item	3398382	et	4	main
oma	doc_491521501855_item	3398389	et	4	main
olemasolu	doc_491521501855_item	3398403	et	4	main
see	doc_491521501855_item	3398414	et	3	main
konksukesi	doc_491521501855_item	3399403	et	4	main
kui	doc_491521501855_item	3399404	et	3	main
ka	doc_491521501855_item	3399405	et	3	main
ilma	doc_491521501855_item	3399406	et	4	main
nendeta	doc_491521501855_item	3399407	et	4	main
on	doc_491521501855_item	3399408	et	4	main
kõik	doc_491521501855_item	3399409	et	4	main
arusaadav	doc_491521501855_item	3399410	et	4	main
sellest	doc_491521501855_item	3399411	et	4	main
vaikesest	doc_491521501855_item	3399412	et	4	main
analüüsist	doc_491521501855_item	3399413	et	3	main
töös	doc_491521501855_item	3398017	et	3	main
mereakadeemia	doc_491521501855_item	3398023	et	4	main
ema	doc_491521501855_item	3398024	et	4	main
keele	doc_491521501855_item	3398039	et	4	main
november	doc_491521501855_item	3398045	et	3	main
keelt	doc_491521501855_item	3398053	et	4	main
on	doc_491521501855_item	3398060	et	4	main
erinev	doc_491521501855_item	3398062	et	4	main
õpilased	doc_491521501855_item	3398064	et	3	main
väikesed	doc_491521501855_item	3398074	et	4	main
rurk	doc_491521501855_item	3398082	et	4	main
lii	doc_491521501855_item	3398086	et	4	main
holliwuud	doc_491521501855_item	3398093	et	4	main
emakeele	doc_491521501855_item	3398098	et	4	main
mõjust	doc_491521501855_item	3398099	et	3	main
kuna	doc_491521501855_item	3398100	et	3	main
vene	doc_491521501855_item	3398101	et	4	main
võõrnimesid	doc_491521501855_item	3398104	et	3	main
häälduse	doc_491521501855_item	3398105	et	4	main
järgi	doc_491521501855_item	3398106	et	4	main
siis	doc_491521501855_item	3398107	et	3	main
automaatselt	doc_491521501855_item	3398108	et	4	main
on	doc_491521501855_item	3398109	et	4	main
sama	doc_491521501855_item	3398110	et	4	main
tehtud	doc_491521501855_item	3398111	et	4	main
ka	doc_491521501855_item	3398112	et	3	main
eesti	doc_491521501855_item	3398113	et	4	main
ka	doc_491521501855_item	3398116	et	3	main
keelt	doc_491521501855_item	3398131	et	4	main
eesti	doc_491521501855_item	3398136	et	4	main
tahan	doc_491521501855_item	3398142	et	3	main
endale	doc_491521501855_item	3398143	et	4	main
käind	doc_491521501855_item	3398149	et	4	main
aastat	doc_491521501855_item	3398151	et	3	main
on	doc_491521501855_item	3398153	et	4	main
arvamusest	doc_491521501855_item	3398160	et	4	main
panna	doc_491521501855_item	3398168	et	4	main
iga	doc_491521501855_item	3398184	et	4	main
paremat	doc_491521501855_item	3398187	et	4	main
autot	doc_491521501855_item	3398188	et	3	main
ta	doc_491521501855_item	3398193	et	4	main
vaja	doc_491521501855_item	3398201	et	4	main
kasutada	doc_491521501855_item	3398202	et	3	main
veel	doc_491521501855_item	3398207	et	4	main
mitmuse	doc_491521501855_item	3398216	et	3	main
vormiga	doc_491521501855_item	3398225	et	4	main
mis	doc_491521501855_item	3398226	et	4	main
ainsus	doc_491521501855_item	3398231	et	4	main
näites	doc_491521501855_item	3398236	et	3	main
on	doc_491521501855_item	3398238	et	4	main
mõelda	doc_491521501855_item	3398244	et	4	main
ühtviisi	doc_491521501855_item	3398246	et	3	main
osastavat	doc_491521501855_item	3398258	et	4	main
vaja	doc_491521501855_item	3398273	et	4	main
sõbra	doc_491521501855_item	3398274	et	3	main
õpilane	doc_491521501855_item	3398278	et	3	main
b	doc_491521501855_item	3398292	et	4	main
käände	doc_491521501855_item	3398300	et	4	main
üsna	doc_491521501855_item	3398301	et	3	main
sagedane	doc_491521501855_item	3398302	et	3	main
on	doc_491521501855_item	3398303	et	4	main
käte	doc_491521501855_item	3398311	et	3	main
olla	doc_491521501855_item	3398317	et	3	main
ka	doc_491521501855_item	3398322	et	3	main
või	doc_491521501855_item	3398335	et	4	main
nt	doc_491521501855_item	3398340	et	4	main
sagedane	doc_491521501855_item	3398343	et	3	main
osastava	doc_491521501855_item	3398348	et	4	main
sõnalõpulist	doc_491521501855_item	3398372	et	4	main
ilusad	doc_491521501855_item	3398379	et	3	main
muusikad	doc_491521501855_item	3398381	et	3	main
keeles	doc_491521501855_item	3398383	et	4	main
õpilaste	doc_491521501855_item	3398133	et	4	main
tekkinud	doc_491521501855_item	3398139	et	4	main
nt	doc_491521501855_item	3398140	et	4	main
ma	doc_491521501855_item	3398141	et	3	main
olen	doc_491521501855_item	3398148	et	3	main
kolm	doc_491521501855_item	3398150	et	3	main
viga	doc_491521501855_item	3398152	et	4	main
et	doc_491521501855_item	3398161	et	3	main
tihti	doc_491521501855_item	3398169	et	3	main
ainsuse	doc_491521501855_item	3398172	et	4	main
osastava	doc_491521501855_item	3398175	et	4	main
segiajamist	doc_491521501855_item	3398176	et	4	main
mitu	doc_491521501855_item	3398180	et	4	main
toodavad	doc_491521501855_item	3398183	et	4	main
aastaga	doc_491521501855_item	3398185	et	3	main
aina	doc_491521501855_item	3398186	et	4	main
tegi	doc_491521501855_item	3398192	et	4	main
ei	doc_491521501855_item	3398205	et	4	main
ole	doc_491521501855_item	3398206	et	4	main
ainsuse	doc_491521501855_item	3398213	et	4	main
millal	doc_491521501855_item	3398215	et	3	main
siiski	doc_491521501855_item	3398220	et	4	main
loogiline	doc_491521501855_item	3398229	et	4	main
õpitakse	doc_491521501855_item	3398232	et	4	main
ära	doc_491521501855_item	3398235	et	4	main
nii	doc_491521501855_item	3398249	et	3	main
kui	doc_491521501855_item	3398251	et	3	main
palju	doc_491521501855_item	3398252	et	4	main
unustades	doc_491521501855_item	3398253	et	3	main
et	doc_491521501855_item	3398254	et	3	main
mitu	doc_491521501855_item	3398255	et	4	main
nõuab	doc_491521501855_item	3398256	et	3	main
konsonantide	doc_491521501855_item	3398268	et	3	main
öelda	doc_491521501855_item	3398276	et	4	main
teadnud	doc_491521501855_item	3398280	et	4	main
siin	doc_491521501855_item	3398281	et	4	main
õiget	doc_491521501855_item	3398282	et	3	main
väldet	doc_491521501855_item	3398283	et	3	main
ja	doc_491521501855_item	3398284	et	3	main
kirjutas	doc_491521501855_item	3398285	et	3	main
käände	doc_491521501855_item	3398288	et	4	main
p	doc_491521501855_item	3398290	et	4	main
asemel	doc_491521501855_item	3398291	et	4	main
segi	doc_491521501855_item	3398296	et	3	main
omastava	doc_491521501855_item	3398297	et	4	main
ja	doc_491521501855_item	3398298	et	3	main
osastava	doc_491521501855_item	3398299	et	4	main
konsonantühendite	doc_491521501855_item	3398304	et	4	main
vea	doc_491521501855_item	3398314	et	4	main
võivad	doc_491521501855_item	3398316	et	4	main
või	doc_491521501855_item	3398321	et	4	main
ees	doc_491521501855_item	3398327	et	4	main
sarnase	doc_491521501855_item	3398330	et	4	main
peal	doc_491521501855_item	3398342	et	4	main
käände	doc_491521501855_item	3398349	et	4	main
t	doc_491521501855_item	3398350	et	4	main
lõpu	doc_491521501855_item	3398351	et	3	main
asemel	doc_491521501855_item	3398352	et	4	main
mitmuse	doc_491521501855_item	3398353	et	3	main
lõpu	doc_491521501855_item	3398354	et	3	main
ilusad	doc_491521501855_item	3398360	et	3	main
d-d	doc_491521501855_item	3398373	et	4	main
ja	doc_491521501855_item	3398374	et	3	main
t-d	doc_491521501855_item	3398375	et	4	main
ning	doc_491521501855_item	3398376	et	3	main
ei	doc_491521501855_item	3398386	et	4	main
d	doc_491521501855_item	3398397	et	4	main
sõna	doc_491521501855_item	3398399	et	4	main
esineb	doc_491521501855_item	3398418	et	3	main
nt	doc_491521501855_item	3398430	et	4	main
tal	doc_491521501855_item	3398431	et	3	main
käes	doc_491521501855_item	3398432	et	4	main
on	doc_491521501855_item	3398433	et	4	main
sõrmus	doc_491521501855_item	3398434	et	3	main
kell	doc_491521501855_item	3398436	et	3	main
ta	doc_491521501855_item	3398447	et	4	main
mängib	doc_491521501855_item	3398449	et	3	main
on	doc_491521501855_item	3398451	et	4	main
otseselt	doc_491521501855_item	3398452	et	4	main
vene	doc_491521501855_item	3398457	et	4	main
tasemega	doc_491521501855_item	3398478	et	3	main
aru	doc_491521501855_item	3398485	et	4	main
ei	doc_491521501855_item	3398500	et	4	main
võib	doc_491521501855_item	3398501	et	3	main
vormi	doc_491521501855_item	3398217	et	4	main
varem	doc_491521501855_item	3398234	et	4	main
mul	doc_491521501855_item	3398237	et	3	main
mitu	doc_491521501855_item	3398239	et	4	main
lemmiknäitlejaid	doc_491521501855_item	3398240	et	3	main
võis	doc_491521501855_item	3398241	et	4	main
õpilane	doc_491521501855_item	3398242	et	3	main
ka	doc_491521501855_item	3398243	et	3	main
et	doc_491521501855_item	3398245	et	3	main
saab	doc_491521501855_item	3398247	et	3	main
mitu	doc_491521501855_item	3398250	et	4	main
järgmine	doc_491521501855_item	3398259	et	3	main
õpilaste	doc_491521501855_item	3398265	et	4	main
on	doc_491521501855_item	3398267	et	4	main
lihtsalt	doc_491521501855_item	3398286	et	4	main
ajas	doc_491521501855_item	3398294	et	4	main
hoopis	doc_491521501855_item	3398295	et	3	main
saab	doc_491521501855_item	3398310	et	3	main
tekkile	doc_491521501855_item	3398313	et	4	main
välted	doc_491521501855_item	3398320	et	3	main
et	doc_491521501855_item	3398325	et	3	main
sama	doc_491521501855_item	3398336	et	4	main
käte	doc_491521501855_item	3398341	et	3	main
viga	doc_491521501855_item	3398344	et	4	main
kirjutamine	doc_491521501855_item	3398356	et	4	main
nt	doc_491521501855_item	3398357	et	4	main
teevad	doc_491521501855_item	3398359	et	3	main
võib	doc_491521501855_item	3398363	et	3	main
selles	doc_491521501855_item	3398365	et	4	main
ja	doc_491521501855_item	3398380	et	3	main
riiva	doc_491521501855_item	3398387	et	4	main
silma	doc_491521501855_item	3398388	et	4	main
just	doc_491521501855_item	3398396	et	3	main
on	doc_491521501855_item	3398404	et	4	main
võimalik	doc_491521501855_item	3398415	et	3	main
merekooli	doc_491521501855_item	3398419	et	4	main
seas	doc_491521501855_item	3398421	et	4	main
sellist	doc_491521501855_item	3398422	et	4	main
seljas	doc_491521501855_item	3398438	et	4	main
pintsak	doc_491521501855_item	3398441	et	3	main
tal	doc_491521501855_item	3398443	et	3	main
ja	doc_491521501855_item	3398446	et	3	main
emakeele	doc_491521501855_item	3398454	et	4	main
keeles	doc_491521501855_item	3398458	et	4	main
kehvema	doc_491521501855_item	3398477	et	4	main
töödest	doc_491521501855_item	3398480	et	3	main
saada	doc_491521501855_item	3398486	et	4	main
tahtnud	doc_491521501855_item	3398491	et	4	main
tahavad	doc_491521501855_item	3398495	et	3	main
aga	doc_491521501855_item	3398497	et	3	main
ei	doc_491521501855_item	3398498	et	4	main
midagi	doc_491521501855_item	3398499	et	4	main
oletada	doc_491521501855_item	3398505	et	3	main
tahtsid	doc_491521501855_item	3398510	et	4	main
tappa	doc_491521501855_item	3398512	et	4	main
kuid	doc_491521501855_item	3398513	et	4	main
lihtsalt	doc_491521501855_item	3398323	et	4	main
see	doc_491521501855_item	3398324	et	3	main
olnud	doc_491521501855_item	3398329	et	4	main
sõna	doc_491521501855_item	3398331	et	4	main
kirjapilt	doc_491521501855_item	3398332	et	3	main
nt	doc_491521501855_item	3398333	et	4	main
mitte	doc_491521501855_item	3398334	et	3	main
käändevorm	doc_491521501855_item	3398339	et	4	main
merekooli	doc_491521501855_item	3398345	et	4	main
õpilastel	doc_491521501855_item	3398346	et	4	main
nad	doc_491521501855_item	3398358	et	3	main
viga	doc_491521501855_item	3398362	et	4	main
seisneda	doc_491521501855_item	3398364	et	3	main
et	doc_491521501855_item	3398366	et	3	main
ei	doc_491521501855_item	3398369	et	4	main
erista	doc_491521501855_item	3398370	et	4	main
hästi	doc_491521501855_item	3398371	et	3	main
sõnavormid	doc_491521501855_item	3398378	et	3	main
valinud	doc_491521501855_item	3398395	et	4	main
muidugi	doc_491521501855_item	3398405	et	4	main
vaieldav	doc_491521501855_item	3398406	et	4	main
kuid	doc_491521501855_item	3398407	et	4	main
julgen	doc_491521501855_item	3398408	et	3	main
arvata	doc_491521501855_item	3398409	et	4	main
et	doc_491521501855_item	3398410	et	3	main
teatud	doc_491521501855_item	3398411	et	4	main
kontekstis	doc_491521501855_item	3398412	et	3	main
on	doc_491521501855_item	3398413	et	4	main
eksisteerivad	doc_491521501855_item	3398384	et	4	main
ja	doc_491521501855_item	3398385	et	3	main
vale	doc_491521501855_item	3398390	et	4	main
kirjapildiga	doc_491521501855_item	3398391	et	3	main
siis	doc_491521501855_item	3398392	et	3	main
ongi	doc_491521501855_item	3398393	et	4	main
õpilane	doc_491521501855_item	3398394	et	3	main
lõpud	doc_491521501855_item	3398398	et	3	main
muusika	doc_491521501855_item	3398400	et	4	main
mitmuse	doc_491521501855_item	3398401	et	3	main
vormi	doc_491521501855_item	3398402	et	4	main
tihti	doc_491521501855_item	3398417	et	3	main
vale	doc_491521501855_item	3398427	et	4	main
sõnajärje	doc_491521501855_item	3398428	et	3	main
kasutus	doc_491521501855_item	3398429	et	4	main
on	doc_491521501855_item	3398439	et	4	main
peened	doc_491521501855_item	3398442	et	3	main
tingitud	doc_491521501855_item	3398453	et	4	main
vahel	doc_491521501855_item	3398482	et	4	main
lausa	doc_491521501855_item	3398483	et	4	main
mida	doc_491521501855_item	3398487	et	4	main
selle	doc_491521501855_item	3398488	et	4	main
ära	doc_491521501855_item	3398502	et	4	main
sellise	doc_491521501855_item	3398518	et	4	main
õpilaste	doc_491521501855_item	3398530	et	4	main
tundmine	doc_491521501855_item	3398537	et	4	main
ning	doc_491521501855_item	3398538	et	3	main
asendatakse	doc_491521501855_item	3398545	et	3	main
sa	doc_491521501855_item	3398565	et	3	main
t	doc_491521501855_item	3398577	et	4	main
on	doc_491521501855_item	3398591	et	4	main
osastava	doc_491521501855_item	3398597	et	4	main
on	doc_491521501855_item	3398602	et	4	main
väga	doc_491521501855_item	3398416	et	3	main
õpilaste	doc_491521501855_item	3398420	et	4	main
põhistruktuuri	doc_491521501855_item	3398424	et	4	main
viga	doc_491521501855_item	3398425	et	4	main
nagu	doc_491521501855_item	3398426	et	3	main
ja	doc_491521501855_item	3398435	et	3	main
tal	doc_491521501855_item	3398437	et	3	main
on	doc_491521501855_item	3398444	et	4	main
mõjust	doc_491521501855_item	3398455	et	3	main
sest	doc_491521501855_item	3398456	et	4	main
on	doc_491521501855_item	3398459	et	4	main
sõnajarg	doc_491521501855_item	3398460	et	2	main
erinev	doc_491521501855_item	3398461	et	4	main
eesti	doc_491521501855_item	3398462	et	4	main
keele	doc_491521501855_item	3398463	et	4	main
omast	doc_491521501855_item	3398464	et	4	main
nagu	doc_491521501855_item	3398465	et	3	main
eespool	doc_491521501855_item	3398466	et	3	main
mainitud	doc_491521501855_item	3398467	et	4	main
on	doc_491521501855_item	3398468	et	4	main
selles	doc_491521501855_item	3398469	et	4	main
merekooli	doc_491521501855_item	3398470	et	4	main
grupis	doc_491521501855_item	3398471	et	3	main
väga	doc_491521501855_item	3398472	et	3	main
erinev	doc_491521501855_item	3398473	et	4	main
eesti	doc_491521501855_item	3398474	et	4	main
keele	doc_491521501855_item	3398475	et	4	main
lause	doc_491521501855_item	3398423	et	4	main
must	doc_491521501855_item	3398440	et	4	main
huuled	doc_491521501855_item	3398445	et	3	main
hasti	doc_491521501855_item	3398448	et	4	main
viga	doc_491521501855_item	3398450	et	4	main
tase	doc_491521501855_item	3398476	et	3	main
õpilaste	doc_491521501855_item	3398479	et	4	main
on	doc_491521501855_item	3398481	et	4	main
öelda	doc_491521501855_item	3398492	et	4	main
nt	doc_491521501855_item	3398493	et	4	main
teda	doc_491521501855_item	3398496	et	4	main
vaid	doc_491521501855_item	3398504	et	3	main
vmt	doc_491521501855_item	3398517	et	4	main
halb	doc_491521501855_item	3398524	et	3	main
tase	doc_491521501855_item	3398526	et	3	main
kõige	doc_491521501855_item	3398543	et	4	main
juba	doc_491521501855_item	3398566	et	3	main
töötad	doc_491521501855_item	3398568	et	3	main
näites	doc_491521501855_item	3398570	et	3	main
samas	doc_491521501855_item	3398579	et	4	main
lauses	doc_491521501855_item	3398580	et	3	main
paljud	doc_491521501855_item	3398587	et	3	main
mul	doc_491521501855_item	3398601	et	3	main
lemmikud	doc_491521501855_item	3398604	et	3	main
auto	doc_491521501855_item	3398616	et	4	main
lasevad	doc_491521501855_item	3398620	et	3	main
et	doc_491521501855_item	3398622	et	3	main
olla	doc_491521501855_item	3398625	et	3	main
tea	doc_491521501855_item	3398634	et	4	main
lihtsalt	doc_491521501855_item	3398643	et	4	main
on	doc_491521501855_item	3398654	et	4	main
kas	doc_491521501855_item	3398689	et	3	main
üsna	doc_491521501855_item	3398694	et	3	main
ka	doc_491521501855_item	3398696	et	3	main
ja	doc_491521501855_item	3398698	et	3	main
emakeele	doc_491521501855_item	3398716	et	4	main
on	doc_491521501855_item	3398726	et	4	main
ühed	doc_491521501855_item	3398727	et	3	main
ja	doc_491521501855_item	3398728	et	3	main
ka	doc_491521501855_item	3398736	et	3	main
nt	doc_491521501855_item	3398739	et	4	main
kui	doc_491521501855_item	3398740	et	3	main
tormi	doc_491521501855_item	3398750	et	4	main
sellist	doc_491521501855_item	3398753	et	4	main
viga	doc_491521501855_item	3398755	et	4	main
esineb	doc_491521501855_item	3398756	et	3	main
isegi	doc_491521501855_item	3398757	et	4	main
vormiliselt	doc_491521501855_item	3398769	et	4	main
raske	doc_491521501855_item	3398484	et	4	main
kirjutaja	doc_491521501855_item	3398489	et	4	main
on	doc_491521501855_item	3398490	et	4	main
bantided	doc_491521501855_item	3398494	et	4	main
võib	doc_491521501855_item	3398503	et	3	main
tähendab	doc_491521501855_item	3398508	et	3	main
see	doc_491521501855_item	3398514	et	3	main
seas	doc_491521501855_item	3398531	et	4	main
torkab	doc_491521501855_item	3398532	et	3	main
oskamatus	doc_491521501855_item	3398539	et	4	main
seda	doc_491521501855_item	3398540	et	3	main
vajadusel	doc_491521501855_item	3398541	et	3	main
kasutada	doc_491521501855_item	3398542	et	3	main
kaks	doc_491521501855_item	3398555	et	3	main
konserdile	doc_491521501855_item	3398559	et	4	main
tuleb	doc_491521501855_item	3398560	et	3	main
palju	doc_491521501855_item	3398561	et	4	main
inimesed	doc_491521501855_item	3398562	et	3	main
mitu	doc_491521501855_item	3398563	et	4	main
siin	doc_491521501855_item	3398567	et	4	main
eelviimases	doc_491521501855_item	3398569	et	3	main
ortografiaviga	doc_491521501855_item	3398573	et	4	main
näol	doc_491521501855_item	3398578	et	4	main
tahetud	doc_491521501855_item	3398584	et	4	main
mitmuse	doc_491521501855_item	3398593	et	3	main
nimetava	doc_491521501855_item	3398594	et	4	main
asemel	doc_491521501855_item	3398599	et	4	main
näited	doc_491521501855_item	3398600	et	3	main
filmid	doc_491521501855_item	3398605	et	4	main
mulle	doc_491521501855_item	3398606	et	4	main
meeldib	doc_491521501855_item	3398607	et	3	main
lugeda	doc_491521501855_item	3398608	et	3	main
raamatud	doc_491521501855_item	3398609	et	4	main
kolm	doc_491521501855_item	3398618	et	3	main
keele	doc_491521501855_item	3398630	et	4	main
õpetusest	doc_491521501855_item	3398631	et	4	main
õpilane	doc_491521501855_item	3398632	et	3	main
ei	doc_491521501855_item	3398633	et	4	main
väljendada	doc_491521501855_item	3398647	et	3	main
esimene	doc_491521501855_item	3398648	et	3	main
vorm	doc_491521501855_item	3398649	et	3	main
mis	doc_491521501855_item	3398650	et	4	main
käändes	doc_491521501855_item	3398656	et	3	main
vaevuta	doc_491521501855_item	3398659	et	3	main
kas	doc_491521501855_item	3398661	et	3	main
et	doc_491521501855_item	3398688	et	3	main
meres	doc_491521501855_item	3398692	et	3	main
sisse-	doc_491521501855_item	3398697	et	4	main
kui	doc_491521501855_item	3398709	et	3	main
viga	doc_491521501855_item	3398713	et	4	main
tingitud	doc_491521501855_item	3398715	et	4	main
keeles	doc_491521501855_item	3398725	et	4	main
ja	doc_491521501855_item	3398733	et	3	main
verbivalikul	doc_491521501855_item	3398738	et	4	main
me	doc_491521501855_item	3398741	et	4	main
lahkume	doc_491521501855_item	3398742	et	3	main
merele	doc_491521501855_item	3398743	et	3	main
homme	doc_491521501855_item	3398744	et	3	main
ma	doc_491521501855_item	3398745	et	3	main
käin	doc_491521501855_item	3398746	et	3	main
hea	doc_491521501855_item	3398758	et	4	main
keeleoskusega	doc_491521501855_item	3398759	et	3	main
inimeste	doc_491521501855_item	3398760	et	3	main
tegemist	doc_491521501855_item	3398763	et	4	main
sõnadega	doc_491521501855_item	3398765	et	3	main
mis	doc_491521501855_item	3398766	et	4	main
merele	doc_491521501855_item	3398773	et	3	main
olla	doc_491521501855_item	3398775	et	3	main
eesti	doc_491521501855_item	3398779	et	4	main
keele	doc_491521501855_item	3398780	et	4	main
fraasist	doc_491521501855_item	3398781	et	3	main
läheme	doc_491521501855_item	3398782	et	3	main
minnakse	doc_491521501855_item	3398816	et	3	main
kõlaline	doc_491521501855_item	3398834	et	4	main
on	doc_491521501855_item	3398836	et	4	main
väga	doc_491521501855_item	3398837	et	3	main
erakooli	doc_491521501855_item	3398847	et	4	main
kõnest	doc_491521501855_item	3398857	et	4	main
enam-vähem	doc_491521501855_item	3398858	et	3	main
saa	doc_491521501855_item	3398863	et	4	main
venekeelsete	doc_491521501855_item	3398865	et	4	main
et	doc_491521501855_item	3398506	et	3	main
see	doc_491521501855_item	3398507	et	3	main
bandiidid	doc_491521501855_item	3398509	et	3	main
teda	doc_491521501855_item	3398511	et	4	main
õnnestunud	doc_491521501855_item	3398516	et	4	main
peamiseks	doc_491521501855_item	3398520	et	3	main
on	doc_491521501855_item	3398522	et	4	main
kindlasti	doc_491521501855_item	3398523	et	3	main
põhikoolis	doc_491521501855_item	3398527	et	4	main
kehvema	doc_491521501855_item	3398528	et	4	main
tasemega	doc_491521501855_item	3398529	et	3	main
käände	doc_491521501855_item	3398535	et	4	main
halb	doc_491521501855_item	3398536	et	3	main
sagedamini	doc_491521501855_item	3398544	et	4	main
meremehed	doc_491521501855_item	3398556	et	3	main
tema	doc_491521501855_item	3398558	et	4	main
ärajäänud	doc_491521501855_item	3398576	et	4	main
ka	doc_491521501855_item	3398583	et	3	main
öelda	doc_491521501855_item	3398585	et	4	main
tulevad	doc_491521501855_item	3398586	et	4	main
inimesed	doc_491521501855_item	3398588	et	3	main
ja	doc_491521501855_item	3398589	et	3	main
sellest	doc_491521501855_item	3398590	et	4	main
kasutamine	doc_491521501855_item	3398595	et	4	main
ainsuse	doc_491521501855_item	3398596	et	4	main
palju	doc_491521501855_item	3398603	et	4	main
hea	doc_491521501855_item	3398615	et	4	main
viga	doc_491521501855_item	3398623	et	4	main
tingitud	doc_491521501855_item	3398626	et	4	main
nii	doc_491521501855_item	3398627	et	3	main
halvast	doc_491521501855_item	3398628	et	3	main
eesti	doc_491521501855_item	3398629	et	4	main
mis	doc_491521501855_item	3398635	et	4	main
nõuab	doc_491521501855_item	3398636	et	3	main
soovist	doc_491521501855_item	3398644	et	4	main
ning	doc_491521501855_item	3398657	et	3	main
sellel	doc_491521501855_item	3398685	et	4	main
filmil	doc_491521501855_item	3398686	et	3	main
teisel	doc_491521501855_item	3398710	et	4	main
võib	doc_491521501855_item	3398712	et	3	main
sest	doc_491521501855_item	3398718	et	4	main
sise-	doc_491521501855_item	3398720	et	4	main
nt	doc_491521501855_item	3398731	et	4	main
esineb	doc_491521501855_item	3398735	et	3	main
aafrikas	doc_491521501855_item	3398747	et	4	main
käes	doc_491521501855_item	3398751	et	4	main
seas	doc_491521501855_item	3398761	et	4	main
on	doc_491521501855_item	3398764	et	4	main
fraas	doc_491521501855_item	3398771	et	3	main
ära	doc_491521501855_item	3398783	et	4	main
korduvalt	doc_491521501855_item	3398815	et	4	main
javõi	doc_491521501855_item	3398820	et	4	main
kaudne	doc_491521501855_item	3398827	et	3	main
sarnasus	doc_491521501855_item	3398829	et	4	main
hukkuma	doc_491521501855_item	3398831	et	3	main
kuna	doc_491521501855_item	3398833	et	3	main
multilingua	doc_491521501855_item	3398846	et	4	main
selgitusteta	doc_491521501855_item	3398866	et	4	main
sarnaseid	doc_491521501855_item	3398873	et	4	main
minema	doc_491521501855_item	3398886	et	3	main
multilingua	doc_491521501855_item	3398890	et	4	main
õpilastel	doc_491521501855_item	3398891	et	4	main
esines	doc_491521501855_item	3398892	et	3	main
järgmisi	doc_491521501855_item	3398893	et	3	main
mulle	doc_491521501855_item	3398900	et	4	main
meeldib	doc_491521501855_item	3398901	et	3	main
telerit	doc_491521501855_item	3398902	et	3	main
vaatama	doc_491521501855_item	3398903	et	3	main
erineva	doc_491521501855_item	3398914	et	4	main
üks	doc_491521501855_item	3398926	et	3	main
asjaolu	doc_491521501855_item	3398936	et	4	main
arusaamist	doc_491521501855_item	3398943	et	4	main
kõnes	doc_491521501855_item	3398945	et	3	main
kuna	doc_491521501855_item	3398947	et	3	main
inimesed	doc_491521501855_item	3398950	et	3	main
jääda	doc_491521501855_item	3398962	et	4	main
mulje	doc_491521501855_item	3398963	et	4	main
tüüpilisem	doc_491521501855_item	3398977	et	4	main
viga	doc_491521501855_item	3398980	et	4	main
kohas	doc_491521501855_item	3399019	et	4	main
midagi	doc_491521501855_item	3399022	et	4	main
ei	doc_491521501855_item	3398515	et	4	main
vea	doc_491521501855_item	3398519	et	4	main
põhjuseks	doc_491521501855_item	3398521	et	3	main
keeleõpetuse	doc_491521501855_item	3398525	et	3	main
silma	doc_491521501855_item	3398533	et	4	main
osastava	doc_491521501855_item	3398534	et	4	main
osastav	doc_491521501855_item	3398546	et	4	main
lihtsalt	doc_491521501855_item	3398547	et	4	main
mitmuse	doc_491521501855_item	3398548	et	3	main
nimetavaga	doc_491521501855_item	3398549	et	4	main
nt	doc_491521501855_item	3398550	et	4	main
see	doc_491521501855_item	3398551	et	3	main
lugu	doc_491521501855_item	3398552	et	4	main
räägib	doc_491521501855_item	3398553	et	3	main
kuidas	doc_491521501855_item	3398554	et	3	main
lähevad	doc_491521501855_item	3398557	et	3	main
aastad	doc_491521501855_item	3398564	et	3	main
on	doc_491521501855_item	3398571	et	4	main
ka	doc_491521501855_item	3398572	et	3	main
sõnast	doc_491521501855_item	3398574	et	4	main
kontsert	doc_491521501855_item	3398575	et	3	main
on	doc_491521501855_item	3398581	et	4	main
võib-olla	doc_491521501855_item	3398582	et	3	main
tulnud	doc_491521501855_item	3398592	et	4	main
inimesi	doc_491521501855_item	3398598	et	4	main
tulevikus	doc_491521501855_item	3398610	et	4	main
ma	doc_491521501855_item	3398611	et	3	main
ostan	doc_491521501855_item	3398612	et	3	main
see	doc_491521501855_item	3398613	et	3	main
väga	doc_491521501855_item	3398614	et	3	main
võib	doc_491521501855_item	3398624	et	3	main
keeles	doc_491521501855_item	3398638	et	4	main
osastavat	doc_491521501855_item	3398639	et	4	main
käänet	doc_491521501855_item	3398640	et	3	main
kui	doc_491521501855_item	3398641	et	3	main
ka	doc_491521501855_item	3398642	et	3	main
tavaliselt	doc_491521501855_item	3398651	et	4	main
meelde	doc_491521501855_item	3398652	et	3	main
tuleb	doc_491521501855_item	3398653	et	3	main
ei	doc_491521501855_item	3398658	et	4	main
mõtlema	doc_491521501855_item	3398660	et	3	main
sa	doc_491521501855_item	3398690	et	3	main
olid	doc_491521501855_item	3398691	et	4	main
tihti	doc_491521501855_item	3398695	et	3	main
juhul	doc_491521501855_item	3398711	et	3	main
mõjust	doc_491521501855_item	3398717	et	3	main
nii	doc_491521501855_item	3398719	et	3	main
kui	doc_491521501855_item	3398721	et	3	main
väliskohakäänete	doc_491521501855_item	3398722	et	3	main
vasteteks	doc_491521501855_item	3398723	et	4	main
vene	doc_491521501855_item	3398724	et	4	main
eessõnad	doc_491521501855_item	3398730	et	3	main
a	doc_491521501855_item	3398732	et	4	main
laev	doc_491521501855_item	3398749	et	3	main
tähenduselt	doc_491521501855_item	3398767	et	4	main
ja	doc_491521501855_item	3398768	et	3	main
võib	doc_491521501855_item	3398774	et	3	main
ka	doc_491521501855_item	3398776	et	3	main
tingitud	doc_491521501855_item	3398777	et	4	main
ja	doc_491521501855_item	3398814	et	3	main
väike	doc_491521501855_item	3398826	et	4	main
kuid	doc_491521501855_item	3398832	et	4	main
sarnasus	doc_491521501855_item	3398835	et	4	main
on	doc_491521501855_item	3398839	et	4	main
õpilane	doc_491521501855_item	3398840	et	3	main
pidanud	doc_491521501855_item	3398841	et	4	main
seda	doc_491521501855_item	3398842	et	3	main
siinkohal	doc_491521501855_item	3398843	et	3	main
aru	doc_491521501855_item	3398859	et	4	main
ilma	doc_491521501855_item	3398864	et	4	main
hakkama	doc_491521501855_item	3398868	et	3	main
siiski	doc_491521501855_item	3398872	et	4	main
vigu	doc_491521501855_item	3398874	et	3	main
tulema	doc_491521501855_item	3398885	et	4	main
nt	doc_491521501855_item	3398899	et	4	main
peame	doc_491521501855_item	3398905	et	4	main
infinitiivivormi	doc_491521501855_item	3398915	et	4	main
on	doc_491521501855_item	3398924	et	4	main
olla	doc_491521501855_item	3398934	et	3	main
kahe	doc_491521501855_item	3398938	et	3	main
segiajamine	doc_491521501855_item	3398940	et	4	main
takista	doc_491521501855_item	3398942	et	4	main
õppijal	doc_491521501855_item	3398961	et	4	main
ta	doc_491521501855_item	3398965	et	4	main
õiget	doc_491521501855_item	3398967	et	3	main
vormi	doc_491521501855_item	3398968	et	4	main
ning	doc_491521501855_item	3398969	et	3	main
hoopis	doc_491521501855_item	3398970	et	3	main
vale	doc_491521501855_item	3398971	et	4	main
vorm	doc_491521501855_item	3398972	et	3	main
võib	doc_491521501855_item	3398973	et	3	main
kinnistuda	doc_491521501855_item	3398974	et	3	main
üks	doc_491521501855_item	3398975	et	3	main
levinum	doc_491521501855_item	3398979	et	4	main
parasiitsõna	doc_491521501855_item	3399015	et	4	main
on	doc_491521501855_item	3399026	et	4	main
seletada	doc_491521501855_item	3399027	et	3	main
ainult	doc_491521501855_item	3398617	et	4	main
nimi	doc_491521501855_item	3398619	et	3	main
arvata	doc_491521501855_item	3398621	et	4	main
eesti	doc_491521501855_item	3398637	et	4	main
ennast	doc_491521501855_item	3398645	et	4	main
kiiresti	doc_491521501855_item	3398646	et	3	main
nimetavas	doc_491521501855_item	3398655	et	4	main
see	doc_491521501855_item	3398662	et	3	main
on	doc_491521501855_item	3398663	et	4	main
õige	doc_491521501855_item	3398664	et	4	main
või	doc_491521501855_item	3398665	et	4	main
mitte	doc_491521501855_item	3398666	et	3	main
väga	doc_491521501855_item	3398667	et	3	main
sagedasti	doc_491521501855_item	3398668	et	3	main
esineb	doc_491521501855_item	3398669	et	3	main
õpilaste	doc_491521501855_item	3398670	et	4	main
töödes	doc_491521501855_item	3398671	et	3	main
kohakäänete	doc_491521501855_item	3398672	et	3	main
segiajamisi	doc_491521501855_item	3398673	et	4	main
nende	doc_491521501855_item	3398674	et	4	main
hulgas	doc_491521501855_item	3398675	et	4	main
sise-	doc_491521501855_item	3398676	et	4	main
ja	doc_491521501855_item	3398677	et	3	main
väliskohakäänete	doc_491521501855_item	3398678	et	3	main
äravahetamist	doc_491521501855_item	3398679	et	3	main
nt	doc_491521501855_item	3398680	et	4	main
selles	doc_491521501855_item	3398681	et	4	main
pildis	doc_491521501855_item	3398682	et	3	main
on	doc_491521501855_item	3398683	et	4	main
kujutatud	doc_491521501855_item	3398684	et	4	main
räägitakse	doc_491521501855_item	3398687	et	3	main
ja	doc_491521501855_item	3398693	et	3	main
seesütleva	doc_491521501855_item	3398699	et	3	main
segiajamist	doc_491521501855_item	3398700	et	4	main
nt	doc_491521501855_item	3398701	et	4	main
lähme	doc_491521501855_item	3398702	et	3	main
minu	doc_491521501855_item	3398703	et	3	main
isa	doc_491521501855_item	3398704	et	4	main
juures	doc_491521501855_item	3398705	et	4	main
laevas	doc_491521501855_item	3398706	et	3	main
nii	doc_491521501855_item	3398707	et	3	main
esimesel	doc_491521501855_item	3398708	et	3	main
olla	doc_491521501855_item	3398714	et	3	main
samad	doc_491521501855_item	3398729	et	3	main
ha	doc_491521501855_item	3398734	et	4	main
vääratusi	doc_491521501855_item	3398737	et	4	main
meie	doc_491521501855_item	3398748	et	4	main
kukkus	doc_491521501855_item	3398752	et	3	main
sõnatasandi	doc_491521501855_item	3398754	et	3	main
kuna	doc_491521501855_item	3398762	et	3	main
sarnanevad	doc_491521501855_item	3398770	et	4	main
lahkume	doc_491521501855_item	3398772	et	3	main
teisest	doc_491521501855_item	3398778	et	4	main
merele	doc_491521501855_item	3398784	et	3	main
sest	doc_491521501855_item	3398785	et	4	main
õpilane	doc_491521501855_item	3398786	et	3	main
on	doc_491521501855_item	3398787	et	4	main
järeldanud	doc_491521501855_item	3398788	et	4	main
et	doc_491521501855_item	3398789	et	3	main
ära	doc_491521501855_item	3398790	et	4	main
minema	doc_491521501855_item	3398791	et	3	main
tähendab	doc_491521501855_item	3398792	et	3	main
ju	doc_491521501855_item	3398793	et	3	main
ka	doc_491521501855_item	3398794	et	3	main
lahkuma	doc_491521501855_item	3398795	et	3	main
teine	doc_491521501855_item	3398796	et	3	main
näide	doc_491521501855_item	3398797	et	3	main
tavaline	doc_491521501855_item	3398799	et	4	main
illustreerimaks	doc_491521501855_item	3398800	et	3	main
eksimisi	doc_491521501855_item	3398801	et	4	main
verbidega	doc_491521501855_item	3398802	et	3	main
on	doc_491521501855_item	3398798	et	4	main
minema	doc_491521501855_item	3398803	et	3	main
ja	doc_491521501855_item	3398804	et	3	main
käima	doc_491521501855_item	3398805	et	4	main
õpilane	doc_491521501855_item	3398806	et	3	main
ei	doc_491521501855_item	3398807	et	4	main
ole	doc_491521501855_item	3398808	et	4	main
ära	doc_491521501855_item	3398809	et	4	main
õppinud	doc_491521501855_item	3398810	et	4	main
et	doc_491521501855_item	3398811	et	3	main
käiakse	doc_491521501855_item	3398812	et	3	main
edasi-tagasi	doc_491521501855_item	3398813	et	3	main
ühe	doc_491521501855_item	3398818	et	4	main
tähenduslik	doc_491521501855_item	3398828	et	3	main
verbiga	doc_491521501855_item	3398830	et	3	main
sobivaks	doc_491521501855_item	3398844	et	4	main
tegusõnaks	doc_491521501855_item	3398845	et	3	main
saab	doc_491521501855_item	3398855	et	3	main
eestikeelsest	doc_491521501855_item	3398856	et	3	main
mõni	doc_491521501855_item	3398861	et	3	main
ei	doc_491521501855_item	3398862	et	4	main
üldse	doc_491521501855_item	3398867	et	3	main
nad	doc_491521501855_item	3398871	et	3	main
aga	doc_491521501855_item	3398817	et	3	main
korra	doc_491521501855_item	3398819	et	4	main
tulevikus	doc_491521501855_item	3398821	et	4	main
verbil	doc_491521501855_item	3398822	et	3	main
kukkuma	doc_491521501855_item	3398823	et	3	main
on	doc_491521501855_item	3398824	et	4	main
võib-olla	doc_491521501855_item	3398825	et	3	main
suur	doc_491521501855_item	3398838	et	3	main
õpilastel	doc_491521501855_item	3398848	et	4	main
on	doc_491521501855_item	3398849	et	4	main
algajate	doc_491521501855_item	3398850	et	4	main
tase	doc_491521501855_item	3398851	et	3	main
suurem	doc_491521501855_item	3398852	et	4	main
osa	doc_491521501855_item	3398853	et	4	main
neist	doc_491521501855_item	3398854	et	4	main
kuid	doc_491521501855_item	3398860	et	4	main
kirjatöödes	doc_491521501855_item	3398869	et	3	main
on	doc_491521501855_item	3398878	et	4	main
omased	doc_491521501855_item	3398879	et	3	main
kõigile	doc_491521501855_item	3398880	et	4	main
algtaseme	doc_491521501855_item	3398881	et	3	main
õpilastele	doc_491521501855_item	3398882	et	4	main
käima	doc_491521501855_item	3398887	et	4	main
segiajamine	doc_491521501855_item	3398898	et	4	main
sellest	doc_491521501855_item	3398911	et	4	main
et	doc_491521501855_item	3398912	et	3	main
kahe	doc_491521501855_item	3398913	et	3	main
teevad	doc_491521501855_item	3398870	et	3	main
vead	doc_491521501855_item	3398877	et	4	main
verbivalikuvead	doc_491521501855_item	3398884	et	4	main
infinitiivivigu	doc_491521501855_item	3398894	et	4	main
ma-	doc_491521501855_item	3398895	et	3	main
ja	doc_491521501855_item	3398896	et	3	main
koju	doc_491521501855_item	3398906	et	3	main
minna	doc_491521501855_item	3398907	et	3	main
on	doc_491521501855_item	3398909	et	4	main
tingitud	doc_491521501855_item	3398910	et	4	main
ei	doc_491521501855_item	3398917	et	4	main
kinnistunud	doc_491521501855_item	3398920	et	4	main
vaid	doc_491521501855_item	3398925	et	3	main
on	doc_491521501855_item	3398928	et	4	main
ka	doc_491521501855_item	3398935	et	3	main
et	doc_491521501855_item	3398937	et	3	main
infinitiivi	doc_491521501855_item	3398939	et	4	main
ei	doc_491521501855_item	3398941	et	4	main
nt	doc_491521501855_item	3398944	et	4	main
seetõttu	doc_491521501855_item	3398948	et	3	main
ei	doc_491521501855_item	3398951	et	4	main
igapäevases	doc_491521501855_item	3398957	et	4	main
suhtluses	doc_491521501855_item	3398958	et	3	main
siis	doc_491521501855_item	3398959	et	3	main
kõige	doc_491521501855_item	3398976	et	4	main
kus	doc_491521501855_item	3399020	et	3	main
eesti	doc_491521501855_item	3399035	et	4	main
keelt	doc_491521501855_item	3399036	et	4	main
minu	doc_491521501855_item	3399042	et	3	main
arvates	doc_491521501855_item	3399043	et	4	main
seotud	doc_491521501855_item	3399049	et	4	main
mõjuga	doc_491521501855_item	3399051	et	3	main
verbi	doc_491521501855_item	3399055	et	4	main
see	doc_491521501855_item	3399063	et	3	main
võib-olla	doc_491521501855_item	3399064	et	3	main
õppinud	doc_491521501855_item	3399078	et	4	main
sagedamini	doc_491521501855_item	3399092	et	4	main
on	doc_491521501855_item	3399101	et	4	main
multilingua	doc_491521501855_item	3399116	et	4	main
sageli	doc_491521501855_item	3399119	et	3	main
venemaal	doc_491521501855_item	3399140	et	4	main
mõjust	doc_491521501855_item	3399141	et	3	main
õpilasel	doc_491521501855_item	3399142	et	3	main
on	doc_491521501855_item	3399143	et	4	main
meeles	doc_491521501855_item	3399144	et	3	main
et	doc_491521501855_item	3399145	et	3	main
ära	doc_491521501855_item	3399152	et	4	main
sellist	doc_491521501855_item	3399182	et	4	main
keelelist	doc_491521501855_item	3399183	et	4	main
tunnetus	doc_491521501855_item	3399196	et	4	main
piisav	doc_491521501855_item	3399203	et	4	main
kuulmis-	doc_491521501855_item	3399205	et	3	main
sagedane	doc_491521501855_item	3399208	et	3	main
on	doc_491521501855_item	3399210	et	4	main
ka	doc_491521501855_item	3399211	et	3	main
2	doc_491521501855_item	3399212	et	2	main
ja	doc_491521501855_item	3399213	et	3	main
isiku	doc_491521501855_item	3399215	et	3	main
sa	doc_491521501855_item	3399219	et	3	main
ta	doc_491521501855_item	3399224	et	4	main
põhjuseks	doc_491521501855_item	3399227	et	3	main
d	doc_491521501855_item	3399230	et	4	main
ja	doc_491521501855_item	3399231	et	3	main
b	doc_491521501855_item	3399232	et	4	main
eriti	doc_491521501855_item	3399237	et	3	main
kiire	doc_491521501855_item	3399238	et	4	main
tavaliselt	doc_491521501855_item	3399241	et	4	main
õiget	doc_491521501855_item	3399247	et	3	main
kuid	doc_491521501855_item	3399249	et	4	main
ja	doc_491521501855_item	3399251	et	3	main
sellist	doc_491521501855_item	3399263	et	4	main
multilingua	doc_491521501855_item	3399273	et	4	main
sööma	doc_491521501855_item	3399279	et	4	main
ma	doc_491521501855_item	3399280	et	3	main
söön	doc_491521501855_item	3399281	et	3	main
keeles	doc_491521501855_item	3399293	et	4	main
tahetakse	doc_491521501855_item	3399297	et	4	main
seda	doc_491521501855_item	3399298	et	3	main
hääldada	doc_491521501855_item	3399299	et	3	main
ä-d	doc_491521501855_item	3399319	et	2	main
tahetakse	doc_491521501855_item	3399320	et	4	main
vene	doc_491521501855_item	3399321	et	4	main
kõige	doc_491521501855_item	3398875	et	4	main
levinumad	doc_491521501855_item	3398876	et	4	main
infinitiivivead	doc_491521501855_item	3398883	et	4	main
kohakäänetevead	doc_491521501855_item	3398888	et	4	main
jm	doc_491521501855_item	3398889	et	4	main
da-tegevusnime	doc_491521501855_item	3398897	et	4	main
me	doc_491521501855_item	3398904	et	4	main
viga	doc_491521501855_item	3398908	et	4	main
ole	doc_491521501855_item	3398918	et	4	main
veel	doc_491521501855_item	3398919	et	4	main
kuna	doc_491521501855_item	3398921	et	3	main
õpilaste	doc_491521501855_item	3398922	et	4	main
infinitiiv	doc_491521501855_item	3398927	et	3	main
sellised	doc_491521501855_item	3398929	et	4	main
eksimised	doc_491521501855_item	3398930	et	4	main
sagedased	doc_491521501855_item	3398931	et	3	main
põhjuseks	doc_491521501855_item	3398932	et	3	main
pööra	doc_491521501855_item	3398952	et	4	main
selle	doc_491521501855_item	3398953	et	4	main
võib	doc_491521501855_item	3398960	et	3	main
et	doc_491521501855_item	3398964	et	3	main
kasutab	doc_491521501855_item	3398966	et	3	main
ja	doc_491521501855_item	3398978	et	3	main
multilingua	doc_491521501855_item	3398981	et	4	main
või	doc_491521501855_item	3399014	et	4	main
mida	doc_491521501855_item	3399016	et	4	main
kasutatakse	doc_491521501855_item	3399017	et	3	main
alati	doc_491521501855_item	3399018	et	4	main
raske	doc_491521501855_item	3399025	et	4	main
taolist	doc_491521501855_item	3399032	et	3	main
tendentsi	doc_491521501855_item	3399033	et	4	main
ei	doc_491521501855_item	3399044	et	4	main
saa	doc_491521501855_item	3399045	et	4	main
see	doc_491521501855_item	3399046	et	3	main
vene	doc_491521501855_item	3399053	et	4	main
keeles	doc_491521501855_item	3399054	et	4	main
ei	doc_491521501855_item	3399058	et	4	main
kasutata	doc_491521501855_item	3399059	et	3	main
käesoleval	doc_491521501855_item	3399060	et	3	main
juhul	doc_491521501855_item	3399061	et	3	main
on	doc_491521501855_item	3399062	et	4	main
ma	doc_491521501855_item	3399080	et	3	main
olen	doc_491521501855_item	3399081	et	3	main
sündinud	doc_491521501855_item	3399082	et	4	main
sa	doc_491521501855_item	3399083	et	3	main
oled	doc_491521501855_item	3399084	et	3	main
sündinud	doc_491521501855_item	3399085	et	4	main
on	doc_491521501855_item	3399093	et	4	main
õppetundides	doc_491521501855_item	3399094	et	3	main
jäänud	doc_491521501855_item	3399102	et	4	main
kohakäänetega	doc_491521501855_item	3399114	et	3	main
ma	doc_491521501855_item	3399121	et	3	main
pärit	doc_491521501855_item	3399123	et	3	main
viga	doc_491521501855_item	3399126	et	4	main
võib	doc_491521501855_item	3399127	et	3	main
olla	doc_491521501855_item	3399128	et	3	main
tingitud	doc_491521501855_item	3399129	et	4	main
nii	doc_491521501855_item	3399130	et	3	main
sündinud	doc_491521501855_item	3399139	et	4	main
kattuvad	doc_491521501855_item	3399147	et	4	main
veel	doc_491521501855_item	3399151	et	4	main
õppinud	doc_491521501855_item	3399153	et	4	main
et	doc_491521501855_item	3399154	et	3	main
olema	doc_491521501855_item	3399155	et	4	main
pärit	doc_491521501855_item	3399156	et	3	main
vastab	doc_491521501855_item	3399157	et	3	main
tekkinud	doc_491521501855_item	3399181	et	4	main
kas	doc_491521501855_item	3399188	et	3	main
voi	doc_491521501855_item	3399193	et	4	main
1	doc_491521501855_item	3399194	et	2	main
tavaliselt	doc_491521501855_item	3399198	et	4	main
siis	doc_491521501855_item	3399199	et	3	main
kui	doc_491521501855_item	3399200	et	3	main
õpilasel	doc_491521501855_item	3399201	et	3	main
on	doc_491521501855_item	3399202	et	4	main
viga	doc_491521501855_item	3399209	et	4	main
kasutamisväljad	doc_491521501855_item	3398916	et	3	main
emakeeles	doc_491521501855_item	3398923	et	4	main
võib	doc_491521501855_item	3398933	et	3	main
ning	doc_491521501855_item	3398946	et	3	main
eestikeelsed	doc_491521501855_item	3398949	et	3	main
parandamisele	doc_491521501855_item	3398954	et	4	main
tähelepanu	doc_491521501855_item	3398955	et	4	main
nt	doc_491521501855_item	3398956	et	4	main
õpilastel	doc_491521501855_item	3398982	et	4	main
on	doc_491521501855_item	3398983	et	4	main
verbi	doc_491521501855_item	3398984	et	4	main
3	doc_491521501855_item	3398986	et	2	main
olema	doc_491521501855_item	3398985	et	4	main
isiku	doc_491521501855_item	3398987	et	3	main
pöördevormi	doc_491521501855_item	3398988	et	4	main
vajaduseta	doc_491521501855_item	3398989	et	3	main
kasutamine	doc_491521501855_item	3398990	et	4	main
nt	doc_491521501855_item	3398991	et	4	main
ma	doc_491521501855_item	3398992	et	3	main
on	doc_491521501855_item	3398993	et	4	main
töötan	doc_491521501855_item	3398994	et	3	main
insenerina	doc_491521501855_item	3398995	et	3	main
talle	doc_491521501855_item	3398996	et	4	main
on	doc_491521501855_item	3398997	et	4	main
meeldib	doc_491521501855_item	3398998	et	3	main
nagu	doc_491521501855_item	3398999	et	3	main
öeldud	doc_491521501855_item	3399000	et	4	main
on	doc_491521501855_item	3399001	et	4	main
viga	doc_491521501855_item	3399002	et	4	main
väga	doc_491521501855_item	3399003	et	3	main
levinud	doc_491521501855_item	3399004	et	4	main
sõna	doc_491521501855_item	3399005	et	4	main
on	doc_491521501855_item	3399006	et	4	main
nende	doc_491521501855_item	3399007	et	4	main
õpilaste	doc_491521501855_item	3399008	et	4	main
jaoks	doc_491521501855_item	3399009	et	4	main
on	doc_491521501855_item	3399010	et	4	main
kui	doc_491521501855_item	3399011	et	3	main
omalaadne	doc_491521501855_item	3399012	et	3	main
side-	doc_491521501855_item	3399013	et	4	main
tundub	doc_491521501855_item	3399021	et	3	main
puudu	doc_491521501855_item	3399023	et	4	main
olevat	doc_491521501855_item	3399024	et	4	main
varem	doc_491521501855_item	3399041	et	4	main
olla	doc_491521501855_item	3399048	et	3	main
sest	doc_491521501855_item	3399052	et	4	main
ühest	doc_491521501855_item	3399066	et	4	main
siiani	doc_491521501855_item	3399068	et	4	main
täismineviku	doc_491521501855_item	3399070	et	3	main
vormist	doc_491521501855_item	3399071	et	4	main
mida	doc_491521501855_item	3399072	et	4	main
multilingua	doc_491521501855_item	3399073	et	4	main
selle	doc_491521501855_item	3399074	et	4	main
grupi	doc_491521501855_item	3399075	et	3	main
õpilased	doc_491521501855_item	3399076	et	3	main
sündinud	doc_491521501855_item	3399088	et	4	main
tema-pööre	doc_491521501855_item	3399097	et	4	main
siis	doc_491521501855_item	3399098	et	3	main
võib-olla	doc_491521501855_item	3399099	et	3	main
siit	doc_491521501855_item	3399100	et	3	main
salapärane	doc_491521501855_item	3399106	et	4	main
on	doc_491521501855_item	3399107	et	4	main
mis	doc_491521501855_item	3399108	et	4	main
nagu	doc_491521501855_item	3399109	et	3	main
igale	doc_491521501855_item	3399110	et	3	main
poole	doc_491521501855_item	3399111	et	4	main
peaks	doc_491521501855_item	3399112	et	4	main
sobima	doc_491521501855_item	3399113	et	3	main
sellise	doc_491521501855_item	3399028	et	4	main
vea	doc_491521501855_item	3399029	et	4	main
tekkepõhjust	doc_491521501855_item	3399030	et	4	main
olen	doc_491521501855_item	3399031	et	3	main
kõnelevate	doc_491521501855_item	3399037	et	4	main
venelaste	doc_491521501855_item	3399038	et	4	main
emakeele	doc_491521501855_item	3399050	et	4	main
selliselt	doc_491521501855_item	3399057	et	4	main
on	doc_491521501855_item	3399077	et	4	main
ta	doc_491521501855_item	3399086	et	4	main
olnud	doc_491521501855_item	3399095	et	4	main
õpilastele	doc_491521501855_item	3399103	et	4	main
õpilased	doc_491521501855_item	3399117	et	3	main
nt	doc_491521501855_item	3399120	et	4	main
olen	doc_491521501855_item	3399122	et	3	main
venemaal	doc_491521501855_item	3399124	et	4	main
kuid	doc_491521501855_item	3399149	et	4	main
kust	doc_491521501855_item	3399159	et	4	main
keele	doc_491521501855_item	3399204	et	4	main
ja	doc_491521501855_item	3399206	et	3	main
nt	doc_491521501855_item	3399218	et	4	main
joob	doc_491521501855_item	3399222	et	3	main
kõlaline	doc_491521501855_item	3399234	et	4	main
korral	doc_491521501855_item	3399240	et	4	main
ja	doc_491521501855_item	3399244	et	3	main
pöördelõppu	doc_491521501855_item	3399248	et	4	main
harjutustes	doc_491521501855_item	3399250	et	4	main
kasutab	doc_491521501855_item	3399258	et	3	main
valesti	doc_491521501855_item	3399259	et	3	main
harvemini	doc_491521501855_item	3399260	et	4	main
viga	doc_491521501855_item	3399264	et	4	main
hääldusviga	doc_491521501855_item	3399272	et	4	main
sõnades	doc_491521501855_item	3399278	et	4	main
alati	doc_491521501855_item	3399288	et	4	main
i-ga	doc_491521501855_item	3399289	et	3	main
sjöma	doc_491521501855_item	3399290	et	4	main
kuna	doc_491521501855_item	3399291	et	3	main
märganud	doc_491521501855_item	3399034	et	4	main
juures	doc_491521501855_item	3399039	et	4	main
ka	doc_491521501855_item	3399040	et	3	main
kuidagi	doc_491521501855_item	3399047	et	3	main
olema	doc_491521501855_item	3399056	et	4	main
tingitud	doc_491521501855_item	3399065	et	4	main
ja	doc_491521501855_item	3399067	et	3	main
ainukesest	doc_491521501855_item	3399069	et	4	main
so	doc_491521501855_item	3399079	et	4	main
on	doc_491521501855_item	3399087	et	4	main
jne	doc_491521501855_item	3399089	et	4	main
kuna	doc_491521501855_item	3399090	et	3	main
kõige	doc_491521501855_item	3399091	et	4	main
kasutusel	doc_491521501855_item	3399096	et	4	main
kõrva	doc_491521501855_item	3399104	et	4	main
see	doc_491521501855_item	3399105	et	3	main
samuti	doc_491521501855_item	3399118	et	3	main
see	doc_491521501855_item	3399125	et	3	main
fraasi	doc_491521501855_item	3399136	et	4	main
ma	doc_491521501855_item	3399137	et	3	main
olen	doc_491521501855_item	3399138	et	3	main
tähenduselt	doc_491521501855_item	3399148	et	4	main
pole	doc_491521501855_item	3399150	et	3	main
küsimusele	doc_491521501855_item	3399158	et	4	main
intuitiivselt	doc_491521501855_item	3399186	et	4	main
ütleks	doc_491521501855_item	3399187	et	3	main
sõna	doc_491521501855_item	3399189	et	4	main
lõppu	doc_491521501855_item	3399190	et	4	main
tuleb	doc_491521501855_item	3399191	et	3	main
3	doc_491521501855_item	3399214	et	2	main
ja	doc_491521501855_item	3399221	et	3	main
vähene	doc_491521501855_item	3399233	et	4	main
õpilane	doc_491521501855_item	3399242	et	3	main
kõnekasutuses	doc_491521501855_item	3399252	et	4	main
ajab	doc_491521501855_item	3399253	et	3	main
lõpud	doc_491521501855_item	3399254	et	3	main
omavahel	doc_491521501855_item	3399255	et	3	main
segi	doc_491521501855_item	3399256	et	3	main
ning	doc_491521501855_item	3399257	et	3	main
kõige	doc_491521501855_item	3399270	et	4	main
sagedasem	doc_491521501855_item	3399271	et	4	main
s-i	doc_491521501855_item	3399284	et	4	main
vene	doc_491521501855_item	3399292	et	4	main
nagu	doc_491521501855_item	3399301	et	3	main
keele	doc_491521501855_item	3399322	et	4	main
raskusi	doc_491521501855_item	3399330	et	4	main
tekitab	doc_491521501855_item	3399331	et	3	main
sõpra	doc_491521501855_item	3399339	et	4	main
seas	doc_491521501855_item	3399346	et	4	main
täppide	doc_491521501855_item	3399351	et	3	main
milleks	doc_491521501855_item	3399394	et	4	main
erinevaid	doc_491521501855_item	3399400	et	4	main
selgus	doc_491521501855_item	3399414	et	4	main
nende	doc_491521501855_item	3399423	et	4	main
kuid	doc_491521501855_item	3399427	et	4	main
vigasid	doc_491521501855_item	3399428	et	3	main
põhjustavad	doc_491521501855_item	3399429	et	4	main
ka	doc_491521501855_item	3399430	et	3	main
eksitavad	doc_491521501855_item	3399115	et	4	main
emakeelest	doc_491521501855_item	3399131	et	4	main
kui	doc_491521501855_item	3399132	et	3	main
ka	doc_491521501855_item	3399133	et	3	main
teise	doc_491521501855_item	3399134	et	4	main
sarnase	doc_491521501855_item	3399135	et	4	main
need	doc_491521501855_item	3399146	et	3	main
ja	doc_491521501855_item	3399160	et	3	main
olema	doc_491521501855_item	3399161	et	4	main
sündinud	doc_491521501855_item	3399162	et	4	main
küsimusele	doc_491521501855_item	3399163	et	4	main
kus	doc_491521501855_item	3399164	et	3	main
samuti	doc_491521501855_item	3399165	et	3	main
ma	doc_491521501855_item	3399166	et	3	main
töötan	doc_491521501855_item	3399167	et	3	main
näitab	doc_491521501855_item	3399169	et	3	main
firmal	doc_491521501855_item	3399168	et	3	main
nii	doc_491521501855_item	3399170	et	3	main
emakeele	doc_491521501855_item	3399171	et	4	main
mõju	doc_491521501855_item	3399172	et	4	main
kui	doc_491521501855_item	3399173	et	3	main
ka	doc_491521501855_item	3399174	et	3	main
seda	doc_491521501855_item	3399175	et	3	main
et	doc_491521501855_item	3399176	et	3	main
õpilasel	doc_491521501855_item	3399177	et	3	main
ei	doc_491521501855_item	3399178	et	4	main
ole	doc_491521501855_item	3399179	et	4	main
veel	doc_491521501855_item	3399180	et	4	main
tunnetust	doc_491521501855_item	3399184	et	4	main
mis	doc_491521501855_item	3399185	et	4	main
s	doc_491521501855_item	3399192	et	4	main
selline	doc_491521501855_item	3399195	et	4	main
tuleb	doc_491521501855_item	3399197	et	3	main
kuulamiskogemus	doc_491521501855_item	3399207	et	3	main
äravahetamine	doc_491521501855_item	3399217	et	3	main
sööb	doc_491521501855_item	3399220	et	3	main
kui	doc_491521501855_item	3399223	et	3	main
vea	doc_491521501855_item	3399226	et	4	main
olla	doc_491521501855_item	3399229	et	3	main
kõne	doc_491521501855_item	3399239	et	4	main
hästi	doc_491521501855_item	3399246	et	3	main
esinenud	doc_491521501855_item	3399262	et	4	main
mina-pöördega	doc_491521501855_item	3399266	et	2	main
nt	doc_491521501855_item	3399267	et	4	main
õpilastel	doc_491521501855_item	3399274	et	4	main
ö	doc_491521501855_item	3399276	et	4	main
hääldamisel	doc_491521501855_item	3399277	et	4	main
hääldub	doc_491521501855_item	3399283	et	3	main
o	doc_491521501855_item	3399286	et	4	main
ä-d	doc_491521501855_item	3399315	et	2	main
hjäl	doc_491521501855_item	3399318	et	4	main
e-sarnasena	doc_491521501855_item	3399326	et	4	main
nt	doc_491521501855_item	3399327	et	4	main
hästi	doc_491521501855_item	3399328	et	3	main
hesti	doc_491521501855_item	3399329	et	4	main
kätte	doc_491521501855_item	3399337	et	4	main
kinno	doc_491521501855_item	3399338	et	3	main
õpilaste	doc_491521501855_item	3399345	et	4	main
täpitähtede	doc_491521501855_item	3399350	et	4	main
endile	doc_491521501855_item	3399383	et	4	main
võib-olla	doc_491521501855_item	3399384	et	3	main
sarnast	doc_491521501855_item	3399388	et	4	main
on	doc_491521501855_item	3399395	et	4	main
neil	doc_491521501855_item	3399396	et	4	main
paljud	doc_491521501855_item	3399417	et	3	main
emakeele	doc_491521501855_item	3399424	et	4	main
tingitud	doc_491521501855_item	3399426	et	4	main
javõi	doc_491521501855_item	3399437	et	4	main
õpe	doc_491521501855_item	3399438	et	3	main
pöördelõpu	doc_491521501855_item	3399216	et	3	main
ärkad	doc_491521501855_item	3399225	et	3	main
võib	doc_491521501855_item	3399228	et	3	main
erinevus	doc_491521501855_item	3399235	et	4	main
sõnalõpul	doc_491521501855_item	3399236	et	3	main
teab	doc_491521501855_item	3399243	et	3	main
mäletab	doc_491521501855_item	3399245	et	3	main
on	doc_491521501855_item	3399261	et	4	main
ka	doc_491521501855_item	3399265	et	3	main
ma	doc_491521501855_item	3399268	et	3	main
töötad	doc_491521501855_item	3399269	et	3	main
tekib	doc_491521501855_item	3399275	et	3	main
jt	doc_491521501855_item	3399282	et	4	main
ja	doc_491521501855_item	3399285	et	3	main
vahel	doc_491521501855_item	3399287	et	4	main
vastav	doc_491521501855_item	3399294	et	4	main
häälik	doc_491521501855_item	3399295	et	3	main
puudub	doc_491521501855_item	3399296	et	3	main
j-ühendina	doc_491521501855_item	3399300	et	3	main
vene	doc_491521501855_item	3399302	et	4	main
keele	doc_491521501855_item	3399303	et	4	main
я	doc_491521501855_item	3399305	et	2	main
e	doc_491521501855_item	3399306	et	4	main
ю	doc_491521501855_item	3399304	et	2	main
mis	doc_491521501855_item	3399307	et	4	main
aga	doc_491521501855_item	3399308	et	3	main
pole	doc_491521501855_item	3399309	et	3	main
õige	doc_491521501855_item	3399310	et	4	main
samuti	doc_491521501855_item	3399311	et	3	main
kiputakse	doc_491521501855_item	3399312	et	3	main
j-ühendina	doc_491521501855_item	3399313	et	3	main
hääldama	doc_491521501855_item	3399314	et	3	main
hääl	doc_491521501855_item	3399317	et	3	main
ka	doc_491521501855_item	3399332	et	3	main
jt	doc_491521501855_item	3399340	et	4	main
on	doc_491521501855_item	3399347	et	4	main
ärajätmine	doc_491521501855_item	3399352	et	3	main
aitah	doc_491521501855_item	3399355	et	4	main
kui	doc_491521501855_item	3399381	et	3	main
eestlastele	doc_491521501855_item	3399382	et	4	main
midagi	doc_491521501855_item	3399387	et	4	main
kui	doc_491521501855_item	3399389	et	3	main
kriipsukesi	doc_491521501855_item	3399401	et	4	main
ja	doc_491521501855_item	3399402	et	3	main
üsna	doc_491521501855_item	3399416	et	3	main
keele	doc_491521501855_item	3399419	et	4	main
vead	doc_491521501855_item	3399421	et	4	main
on	doc_491521501855_item	3399422	et	4	main
mõjust	doc_491521501855_item	3399425	et	3	main
nt	doc_491521501855_item	3399316	et	4	main
mõjul	doc_491521501855_item	3399323	et	4	main
hääldada	doc_491521501855_item	3399324	et	3	main
ka	doc_491521501855_item	3399325	et	3	main
kolmandavälteliste	doc_491521501855_item	3399333	et	4	main
sõnade	doc_491521501855_item	3399334	et	3	main
nii	doc_491521501855_item	3399341	et	3	main
merekooli	doc_491521501855_item	3399342	et	4	main
kui	doc_491521501855_item	3399343	et	3	main
multilingua	doc_491521501855_item	3399344	et	4	main
nt	doc_491521501855_item	3399353	et	4	main
janes	doc_491521501855_item	3399354	et	4	main
kaisin	doc_491521501855_item	3399356	et	4	main
merel	doc_491521501855_item	3399357	et	3	main
nad	doc_491521501855_item	3399358	et	3	main
lahevad	doc_491521501855_item	3399359	et	4	main
jt	doc_491521501855_item	3399360	et	4	main
öelda	doc_491521501855_item	3399362	et	4	main
kas	doc_491521501855_item	3399363	et	3	main
tegu	doc_491521501855_item	3399364	et	4	main
raske	doc_491521501855_item	3399361	et	4	main
on	doc_491521501855_item	3399365	et	4	main
ainult	doc_491521501855_item	3399366	et	4	main
hooletusvigadega	doc_491521501855_item	3399367	et	4	main
pigem	doc_491521501855_item	3399368	et	3	main
tundub	doc_491521501855_item	3399369	et	3	main
et	doc_491521501855_item	3399370	et	3	main
eesti	doc_491521501855_item	3399371	et	4	main
keelt	doc_491521501855_item	3399372	et	4	main
inimesele	doc_491521501855_item	3399374	et	3	main
õppivale	doc_491521501855_item	3399373	et	4	main
ei	doc_491521501855_item	3399375	et	4	main
ole	doc_491521501855_item	3399376	et	4	main
need	doc_491521501855_item	3399377	et	3	main
täpid	doc_491521501855_item	3399378	et	4	main
nii	doc_491521501855_item	3399379	et	3	main
olulised	doc_491521501855_item	3399380	et	4	main
hääldamine	doc_491521501855_item	3399335	et	4	main
nt	doc_491521501855_item	3399336	et	4	main
sagedaseks	doc_491521501855_item	3399348	et	3	main
ortograafiaveaks	doc_491521501855_item	3399349	et	4	main
mõtlevad	doc_491521501855_item	3399385	et	4	main
nad	doc_491521501855_item	3399386	et	3	main
meie	doc_491521501855_item	3399390	et	4	main
prantsuse	doc_491521501855_item	3399391	et	3	main
keelt	doc_491521501855_item	3399392	et	4	main
eesti	doc_491521501855_item	3399418	et	4	main
õppijate	doc_491521501855_item	3399420	et	4	main
kõnekeel	doc_491521501855_item	3399432	et	4	main
ning	doc_491521501855_item	3399433	et	3	main
loomulikult	doc_491521501855_item	3399434	et	4	main
halb	doc_491521501855_item	3399435	et	3	main
keeleõpetus	doc_491521501855_item	3399436	et	3	main
õppides	doc_491521501855_item	3399393	et	4	main
vaja	doc_491521501855_item	3399397	et	4	main
nii	doc_491521501855_item	3399398	et	3	main
palju	doc_491521501855_item	3399399	et	4	main
et	doc_491521501855_item	3399415	et	3	main
eestlaste	doc_491521501855_item	3399431	et	4	main
eestlasest	doc_491521501729_item	3408656	et	3	main
oma	doc_491521501729_item	3408659	et	4	main
hulka	doc_491521501729_item	3408689	et	4	main
siis	doc_491521501729_item	3408690	et	3	main
teile	doc_491521501729_item	3408693	et	4	main
meeldib	doc_491521501729_item	3408697	et	3	main
nõutav	doc_491521501729_item	3408704	et	4	main
sõna	doc_491521501729_item	3408709	et	4	main
vaba	doc_491521501729_item	3408724	et	4	main
suvel	doc_491521501729_item	3408729	et	3	main
kõik	doc_491521501729_item	3408731	et	4	main
oma	doc_491521501729_item	3408737	et	4	main
tütrega	doc_491521501729_item	3408738	et	3	main
armastan	doc_491521501729_item	3408741	et	3	main
sega	doc_491521501729_item	3408747	et	4	main
jalgrataga	doc_491521501729_item	3408748	et	4	main
sõita	doc_491521501729_item	3408749	et	3	main
aga	doc_491521501729_item	3408750	et	3	main
kiri	doc_491521501729_item	3408654	et	3	main
küsib	doc_491521501729_item	3408658	et	3	main
kirjas	doc_491521501729_item	3408660	et	4	main
millist	doc_491521501729_item	3408661	et	3	main
muusikat	doc_491521501729_item	3408662	et	3	main
meeldib	doc_491521501729_item	3408663	et	3	main
teile	doc_491521501729_item	3408664	et	4	main
on	doc_491521501729_item	3408672	et	4	main
või	doc_491521501729_item	3408675	et	4	main
lindikogu	doc_491521501729_item	3408676	et	4	main
ja	doc_491521501729_item	3408677	et	3	main
kas	doc_491521501729_item	3408678	et	3	main
käite	doc_491521501729_item	3408679	et	3	main
teie	doc_491521501729_item	3408687	et	4	main
huvialade	doc_491521501729_item	3408688	et	3	main
sisse	doc_491521501729_item	3408702	et	4	main
u	doc_491521501729_item	3408707	et	4	main
80	doc_491521501729_item	3408708	et	2	main
kallis	doc_491521501729_item	3408711	et	4	main
aega	doc_491521501729_item	3408725	et	4	main
nagu	doc_491521501729_item	3408730	et	3	main
inimesed	doc_491521501729_item	3408732	et	3	main
telerit	doc_491521501729_item	3408734	et	3	main
metsas	doc_491521501729_item	3408763	et	3	main
käin	doc_491521501729_item	3408772	et	3	main
tihti	doc_491521501729_item	3408773	et	3	main
ja	doc_491521501729_item	3408776	et	3	main
ei	doc_491521501729_item	3408786	et	4	main
kuulata	doc_491521501729_item	3408665	et	4	main
kirjutage	doc_491521501729_item	3408666	et	3	main
vahel	doc_491521501729_item	3408680	et	4	main
ka	doc_491521501729_item	3408681	et	3	main
kontserdil	doc_491521501729_item	3408682	et	3	main
kui	doc_491521501729_item	3408683	et	3	main
muusika	doc_491521501729_item	3408684	et	4	main
kirjutage	doc_491521501729_item	3408691	et	3	main
kirja	doc_491521501729_item	3408703	et	4	main
muidugi	doc_491521501729_item	3408726	et	4	main
pühkepäevati	doc_491521501729_item	3408727	et	4	main
marju	doc_491521501729_item	3408744	et	3	main
seal	doc_491521501729_item	3408768	et	4	main
marjad	doc_491521501729_item	3408769	et	3	main
mina	doc_491521501729_item	3408784	et	4	main
praegu	doc_491521501729_item	3408785	et	3	main
ma	doc_491521501729_item	3408791	et	3	main
tervitades	doc_491521501729_item	3408799	et	3	main
sinu	doc_491521501729_item	3408800	et	3	main
oma	doc_491521501729_item	3408673	et	4	main
ei	doc_491521501729_item	3408685	et	4	main
kirjutage	doc_491521501729_item	3408698	et	3	main
teie	doc_491521501729_item	3408655	et	4	main
sõber	doc_491521501729_item	3408657	et	3	main
talle	doc_491521501729_item	3408667	et	4	main
vastus	doc_491521501729_item	3408668	et	3	main
kirjutage	doc_491521501729_item	3408669	et	3	main
kas	doc_491521501729_item	3408670	et	3	main
teil	doc_491521501729_item	3408671	et	4	main
plaadi-	doc_491521501729_item	3408674	et	4	main
kuulu	doc_491521501729_item	3408686	et	4	main
mida	doc_491521501729_item	3408692	et	4	main
vabal	doc_491521501729_item	3408694	et	3	main
ajal	doc_491521501729_item	3408695	et	4	main
teha	doc_491521501729_item	3408696	et	3	main
kiri	doc_491521501729_item	3408699	et	3	main
pikkus	doc_491521501729_item	3408705	et	4	main
on	doc_491521501729_item	3408706	et	4	main
rohkem	doc_491521501729_item	3408723	et	4	main
ja	doc_491521501729_item	3408728	et	3	main
armastan	doc_491521501729_item	3408733	et	3	main
ja	doc_491521501729_item	3408736	et	3	main
mängima	doc_491521501729_item	3408739	et	3	main
suvel	doc_491521501729_item	3408740	et	3	main
koos	doc_491521501729_item	3408751	et	4	main
mulle	doc_491521501729_item	3408761	et	4	main
puhata	doc_491521501729_item	3408764	et	4	main
värske	doc_491521501729_item	3408765	et	4	main
õhk	doc_491521501729_item	3408766	et	3	main
kirikus	doc_491521501729_item	3408774	et	3	main
minu	doc_491521501729_item	3408777	et	3	main
vaba	doc_491521501729_item	3408780	et	4	main
ajal	doc_491521501729_item	3408781	et	4	main
meeldib	doc_491521501729_item	3408782	et	3	main
reisida	doc_491521501729_item	3408783	et	3	main
muidugi	doc_491521501729_item	3408790	et	4	main
raha	doc_491521501729_item	3408795	et	4	main
joonitud	doc_491521501729_item	3408700	et	4	main
kasti	doc_491521501729_item	3408701	et	4	main
tere	doc_491521501729_item	3408710	et	3	main
sõbranna	doc_491521501729_item	3408712	et	4	main
ma	doc_491521501729_item	3408713	et	3	main
väga	doc_491521501729_item	3408714	et	3	main
igatsen	doc_491521501729_item	3408715	et	3	main
sinu	doc_491521501729_item	3408716	et	3	main
järele	doc_491521501729_item	3408717	et	4	main
tahan	doc_491521501729_item	3408718	et	3	main
rääkida	doc_491521501729_item	3408719	et	3	main
sinuga	doc_491521501729_item	3408720	et	3	main
millal	doc_491521501729_item	3408721	et	3	main
on	doc_491521501729_item	3408722	et	4	main
vaatama	doc_491521501729_item	3408735	et	3	main
seeni	doc_491521501729_item	3408742	et	3	main
ja	doc_491521501729_item	3408743	et	3	main
korjata	doc_491521501729_item	3408745	et	4	main
koos	doc_491521501729_item	3408746	et	4	main
oma	doc_491521501729_item	3408752	et	4	main
vanematega	doc_491521501729_item	3408753	et	4	main
sõidame	doc_491521501729_item	3408754	et	3	main
peipsi	doc_491521501729_item	3408755	et	4	main
järve	doc_491521501729_item	3408756	et	4	main
äärde	doc_491521501729_item	3408757	et	4	main
suplema	doc_491521501729_item	3408758	et	3	main
ja	doc_491521501729_item	3408759	et	3	main
päevitama	doc_491521501729_item	3408760	et	3	main
meeldib	doc_491521501729_item	3408762	et	3	main
seened	doc_491521501729_item	3408770	et	3	main
pühapäeviti	doc_491521501729_item	3408771	et	4	main
armastab	doc_491521501729_item	3408775	et	3	main
tütar	doc_491521501729_item	3408779	et	3	main
ei	doc_491521501729_item	3408793	et	4	main
sõbranna	doc_491521501729_item	3408801	et	4	main
eesnimi	doc_491521501729_item	3408802	et	3	main
on	doc_491521501729_item	3408767	et	4	main
väike	doc_491521501729_item	3408778	et	4	main
mul	doc_491521501729_item	3408792	et	3	main
ole	doc_491521501729_item	3408794	et	4	main
et	doc_491521501729_item	3408796	et	3	main
kaugel	doc_491521501729_item	3408797	et	4	main
reisida	doc_491521501729_item	3408798	et	3	main
tööta	doc_491521501729_item	3408787	et	4	main
aga	doc_491521501729_item	3408788	et	3	main
õpin	doc_491521501729_item	3408789	et	3	main
20	doc_193540241569_item	3487045	et	2	main
lüürikale	doc_193540241569_item	3487047	et	3	main
erinevate	doc_193540241569_item	3487054	et	4	main
rahvuskirjanduste	doc_193540241569_item	3487055	et	3	main
autoritest	doc_193540241569_item	3487056	et	4	main
iseloomustage	doc_193540241569_item	3487060	et	4	main
loetud	doc_193540241569_item	3487061	et	4	main
tekstile	doc_193540241569_item	3487062	et	3	main
1	doc_193540241569_item	3487043	et	2	main
teemakomplekse	doc_193540241569_item	3487049	et	3	main
näiteid	doc_193540241569_item	3487053	et	3	main
ja	doc_193540241569_item	3487057	et	3	main
2	doc_193540241569_item	3487059	et	2	main
godotd	doc_193540241569_item	3487080	et	4	main
ja	doc_193540241569_item	3487085	et	3	main
tunnuseid	doc_193540241569_item	3487100	et	3	main
stiil	doc_193540241569_item	3487104	et	3	main
loogilised	doc_193540241569_item	3487111	et	4	main
peitnud	doc_193540241569_item	3487127	et	4	main
ei	doc_193540241569_item	3487187	et	4	main
saa	doc_193540241569_item	3487188	et	4	main
aeg	doc_193540241569_item	3487197	et	3	main
läheb	doc_193540241569_item	3487198	et	3	main
eksam	doc_193540241569_item	3487042	et	3	main
omaseid	doc_193540241569_item	3487048	et	3	main
tooge	doc_193540241569_item	3487052	et	3	main
tekstidest	doc_193540241569_item	3487058	et	3	main
kalduvat	doc_193540241569_item	3487067	et	4	main
kirjandust	doc_193540241569_item	3487068	et	3	main
a	doc_193540241569_item	3487069	et	4	main
kafka	doc_193540241569_item	3487073	et	4	main
protsess	doc_193540241569_item	3487074	et	3	main
h	doc_193540241569_item	3487075	et	4	main
välja	doc_193540241569_item	3487083	et	4	main
eksistentsialistlikule	doc_193540241569_item	3487084	et	4	main
absurdikirjandusele	doc_193540241569_item	3487086	et	3	main
vormilised	doc_193540241569_item	3487088	et	4	main
ja	doc_193540241569_item	3487089	et	3	main
sisulised	doc_193540241569_item	3487090	et	4	main
tunnused	doc_193540241569_item	3487091	et	3	main
kasutage	doc_193540241569_item	3487092	et	3	main
tekstinäiteid	doc_193540241569_item	3487093	et	3	main
2	doc_193540241569_item	3487094	et	2	main
igas	doc_193540241569_item	3487095	et	3	main
tekstis	doc_193540241569_item	3487096	et	3	main
mis	doc_193540241569_item	3487101	et	4	main
näitavad	doc_193540241569_item	3487102	et	4	main
kus	doc_193540241569_item	3487109	et	3	main
kõik	doc_193540241569_item	3487110	et	4	main
mitte	doc_193540241569_item	3487115	et	3	main
midagi	doc_193540241569_item	3487116	et	4	main
reeglid	doc_193540241569_item	3487120	et	3	main
on	doc_193540241569_item	3487122	et	4	main
on	doc_193540241569_item	3487130	et	4	main
suur	doc_193540241569_item	3487131	et	3	main
arusaamatus	doc_193540241569_item	3487132	et	4	main
tekstis	doc_193540241569_item	3487133	et	3	main
sajandi	doc_193540241569_item	3487046	et	3	main
vormivõtteid	doc_193540241569_item	3487051	et	3	main
ja	doc_193540241569_item	3487065	et	3	main
absurdifilosoofiasse	doc_193540241569_item	3487066	et	4	main
tooge	doc_193540241569_item	3487082	et	3	main
on	doc_193540241569_item	3487097	et	4	main
võimalik	doc_193540241569_item	3487098	et	3	main
olukorda	doc_193540241569_item	3487108	et	4	main
tähenda	doc_193540241569_item	3487114	et	4	main
protsessis	doc_193540241569_item	3487118	et	4	main
millega	doc_193540241569_item	3487121	et	3	main
inimesed	doc_193540241569_item	3487123	et	3	main
asemel	doc_193540241569_item	3487129	et	4	main
toimub	doc_193540241569_item	3487144	et	3	main
reaalne	doc_193540241569_item	3487146	et	3	main
või	doc_193540241569_item	3487147	et	4	main
mitte	doc_193540241569_item	3487148	et	3	main
tundub	doc_193540241569_item	3487149	et	3	main
kui	doc_193540241569_item	3487183	et	3	main
tegijad	doc_193540241569_item	3487186	et	4	main
ja	doc_193540241569_item	3487193	et	3	main
on	doc_193540241569_item	3487195	et	4	main
liiga	doc_193540241569_item	3487200	et	4	main
kiiresti	doc_193540241569_item	3487201	et	3	main
või	doc_193540241569_item	3487202	et	4	main
või	doc_193540241569_item	3487205	et	4	main
vastupidi	doc_193540241569_item	3487206	et	3	main
toimuvad	doc_193540241569_item	3487207	et	4	main
loogikale	doc_193540241569_item	3487208	et	3	main
vastased	doc_193540241569_item	3487209	et	3	main
sündmused	doc_193540241569_item	3487210	et	3	main
tundub	doc_193540241569_item	3487211	et	3	main
et	doc_193540241569_item	3487212	et	3	main
on	doc_193540241569_item	3487213	et	4	main
mingi	doc_193540241569_item	3487215	et	4	main
süsteem	doc_193540241569_item	3487216	et	3	main
mille	doc_193540241569_item	3487217	et	3	main
loogika	doc_193540241569_item	3487218	et	4	main
olemas	doc_193540241569_item	3487214	et	4	main
järgi	doc_193540241569_item	3487219	et	4	main
tegevus	doc_193540241569_item	3487220	et	4	main
läheb	doc_193540241569_item	3487221	et	3	main
kuid	doc_193540241569_item	3487222	et	4	main
see	doc_193540241569_item	3487223	et	3	main
on	doc_193540241569_item	3487224	et	4	main
arusaamatu	doc_193540241569_item	3487225	et	4	main
iseloomustage	doc_193540241569_item	3487044	et	4	main
ja	doc_193540241569_item	3487050	et	3	main
eksistentsialistlikku	doc_193540241569_item	3487064	et	4	main
võõras	doc_193540241569_item	3487071	et	4	main
f	doc_193540241569_item	3487072	et	4	main
s	doc_193540241569_item	3487078	et	4	main
beckett	doc_193540241569_item	3487079	et	4	main
leida	doc_193540241569_item	3487099	et	3	main
et	doc_193540241569_item	3487103	et	3	main
või	doc_193540241569_item	3487105	et	4	main
mõted	doc_193540241569_item	3487112	et	4	main
ei	doc_193540241569_item	3487113	et	4	main
kõik	doc_193540241569_item	3487119	et	4	main
harjunud	doc_193540241569_item	3487124	et	4	main
on	doc_193540241569_item	3487125	et	4	main
kuskil	doc_193540241569_item	3487126	et	3	main
godotd	doc_193540241569_item	3487134	et	4	main
oodates	doc_193540241569_item	3487135	et	3	main
inimesed	doc_193540241569_item	3487136	et	3	main
ei	doc_193540241569_item	3487137	et	4	main
saa	doc_193540241569_item	3487138	et	4	main
isegi	doc_193540241569_item	3487139	et	4	main
aru	doc_193540241569_item	3487140	et	4	main
kas	doc_193540241569_item	3487141	et	3	main
ka	doc_193540241569_item	3487184	et	3	main
mis	doc_193540241569_item	3487190	et	4	main
toimub	doc_193540241569_item	3487191	et	3	main
liiga	doc_193540241569_item	3487203	et	4	main
aeglaselt	doc_193540241569_item	3487204	et	4	main
toetudes	doc_193540241569_item	3487063	et	3	main
camus	doc_193540241569_item	3487070	et	4	main
hesse	doc_193540241569_item	3487076	et	4	main
stepihunt	doc_193540241569_item	3487077	et	3	main
oodates	doc_193540241569_item	3487081	et	3	main
omased	doc_193540241569_item	3487087	et	3	main
idee	doc_193540241569_item	3487106	et	4	main
iseloomustavad	doc_193540241569_item	3487107	et	4	main
näiteks	doc_193540241569_item	3487117	et	4	main
nende	doc_193540241569_item	3487128	et	4	main
see	doc_193540241569_item	3487142	et	3	main
lugeja	doc_193540241569_item	3487182	et	4	main
mõnikord	doc_193540241569_item	3487185	et	3	main
reaalset	doc_193540241569_item	3487192	et	3	main
fantaasia	doc_193540241569_item	3487196	et	4	main
kas	doc_193540241569_item	3487199	et	3	main
mis	doc_193540241569_item	3487143	et	4	main
on	doc_193540241569_item	3487145	et	4	main
et	doc_193540241569_item	3487150	et	3	main
eile	doc_193540241569_item	3487151	et	3	main
olid	doc_193540241569_item	3487152	et	4	main
samad	doc_193540241569_item	3487153	et	3	main
sündmused	doc_193540241569_item	3487154	et	3	main
või	doc_193540241569_item	3487155	et	4	main
täna	doc_193540241569_item	3487156	et	4	main
ongi	doc_193540241569_item	3487157	et	4	main
eile	doc_193540241569_item	3487158	et	3	main
veel	doc_193540241569_item	3487159	et	4	main
stepihundis	doc_193540241569_item	3487160	et	3	main
räägitakse	doc_193540241569_item	3487161	et	3	main
mehest	doc_193540241569_item	3487162	et	4	main
kelle	doc_193540241569_item	3487163	et	4	main
meeles	doc_193540241569_item	3487164	et	3	main
ta	doc_193540241569_item	3487165	et	4	main
on	doc_193540241569_item	3487166	et	4	main
samal	doc_193540241569_item	3487167	et	3	main
ajal	doc_193540241569_item	3487168	et	4	main
mees	doc_193540241569_item	3487169	et	4	main
ja	doc_193540241569_item	3487170	et	3	main
hunt	doc_193540241569_item	3487171	et	3	main
ja	doc_193540241569_item	3487172	et	3	main
lõpus	doc_193540241569_item	3487173	et	4	main
ta	doc_193540241569_item	3487174	et	4	main
ei	doc_193540241569_item	3487175	et	4	main
saa	doc_193540241569_item	3487176	et	4	main
aru	doc_193540241569_item	3487177	et	4	main
kumb	doc_193540241569_item	3487178	et	3	main
neist	doc_193540241569_item	3487179	et	4	main
võidab	doc_193540241569_item	3487180	et	3	main
nii	doc_193540241569_item	3487181	et	3	main
aru	doc_193540241569_item	3487189	et	4	main
mis	doc_193540241569_item	3487194	et	4	main
aasta	doc_617668397745_item	3487552	et	4	main
keel	doc_617668397745_item	3487563	et	4	main
mõjutas	doc_617668397745_item	3487571	et	3	main
pärsiorjusest	doc_617668397745_item	3487573	et	4	main
linnastumist	doc_617668397745_item	3487575	et	4	main
ja	doc_617668397745_item	3487576	et	3	main
1	doc_617668397745_item	3487579	et	2	main
sajandil	doc_617668397745_item	3487581	et	3	main
hakkasid	doc_617668397745_item	3487596	et	4	main
ilmuda	doc_617668397745_item	3487597	et	3	main
nõudma	doc_617668397745_item	3487625	et	3	main
iseteadvust	doc_617668397745_item	3487636	et	4	main
eestlased	doc_617668397745_item	3487637	et	3	main
hakkasid	doc_617668397745_item	3487638	et	4	main
ajas	doc_617668397745_item	3487644	et	4	main
kontrolltöö	doc_617668397745_item	3487546	et	4	main
eesti	doc_617668397745_item	3487548	et	4	main
revolutsioon	doc_617668397745_item	3487553	et	3	main
ja	doc_617668397745_item	3487555	et	3	main
19	doc_617668397745_item	3487558	et	2	main
ii	doc_617668397745_item	3487560	et	4	main
poole	doc_617668397745_item	3487561	et	4	main
jne	doc_617668397745_item	3487567	et	4	main
kuidas	doc_617668397745_item	3487570	et	3	main
talupoegade	doc_617668397745_item	3487572	et	3	main
ja	doc_617668397745_item	3487585	et	3	main
linnadele	doc_617668397745_item	3487590	et	3	main
arendasid	doc_617668397745_item	3487630	et	4	main
ka	doc_617668397745_item	3487631	et	3	main
demokraatlikud	doc_617668397745_item	3487632	et	3	main
nad	doc_617668397745_item	3487646	et	3	main
revolutsioon	doc_617668397745_item	3487651	et	3	main
venemaal	doc_617668397745_item	3487653	et	4	main
pärast	doc_617668397745_item	3487665	et	4	main
saadetud	doc_617668397745_item	3487674	et	4	main
venestamine	doc_617668397745_item	3487680	et	4	main
rootsi	doc_617668397745_item	3487682	et	4	main
ajal	doc_617668397745_item	3487683	et	4	main
virgiliusega	doc_617668397745_item	3487691	et	4	main
aastal	doc_617668397745_item	3487698	et	3	main
piibel	doc_617668397745_item	3487701	et	4	main
tõlkis	doc_617668397745_item	3487706	et	3	main
1632	doc_617668397745_item	3487710	et	2	main
oli	doc_617668397745_item	3487712	et	3	main
saj	doc_617668397745_item	3487722	et	4	main
perno	doc_617668397745_item	3487729	et	4	main
tõstis	doc_617668397745_item	3487765	et	4	main
eesti	doc_617668397745_item	3487766	et	4	main
kirjanduseselts	doc_617668397745_item	3487773	et	3	main
aastal	doc_617668397745_item	3487775	et	3	main
kirjanikud	doc_617668397745_item	3487782	et	3	main
nagu	doc_617668397745_item	3487783	et	3	main
eepost	doc_617668397745_item	3487788	et	3	main
patriootiliseid	doc_617668397745_item	3487796	et	4	main
oli	doc_617668397745_item	3487807	et	3	main
3	doc_617668397745_item	3487810	et	2	main
pärisorjuse	doc_617668397745_item	3487811	et	3	main
vabastamine	doc_617668397745_item	3487812	et	4	main
andis	doc_617668397745_item	3487813	et	3	main
arenema	doc_617668397745_item	3487847	et	3	main
ja	doc_617668397745_item	3487849	et	3	main
metalltehased	doc_617668397745_item	3487850	et	3	main
aurumasiin	doc_617668397745_item	3487859	et	4	main
muutused	doc_617668397746_item	3487872	et	4	main
materiaalses	doc_617668397746_item	3487873	et	3	main
kiviajast	doc_617668397746_item	3487879	et	4	main
kirjelda	doc_617668397746_item	3487882	et	4	main
tagajärjed	doc_617668397745_item	3487556	et	3	main
muusika	doc_617668397745_item	3487565	et	4	main
lühiülevaade	doc_617668397745_item	3487568	et	3	main
areneda	doc_617668397745_item	3487583	et	3	main
sotsiaal	doc_617668397745_item	3487598	et	4	main
ideed	doc_617668397745_item	3487619	et	4	main
nii	doc_617668397745_item	3487620	et	3	main
nimetakse	doc_617668397745_item	3487621	et	3	main
ärkamisaeg	doc_617668397745_item	3487622	et	3	main
eestlased	doc_617668397745_item	3487623	et	3	main
hakkasid	doc_617668397745_item	3487624	et	4	main
rohkem	doc_617668397745_item	3487627	et	4	main
sotsiaal	doc_617668397745_item	3487656	et	4	main
demokraadid	doc_617668397745_item	3487657	et	3	main
õiguse	doc_617668397745_item	3487659	et	4	main
ja	doc_617668397745_item	3487660	et	3	main
eest	doc_617668397745_item	3487664	et	4	main
asumisele	doc_617668397745_item	3487673	et	4	main
põhjus	doc_617668397745_item	3487554	et	4	main
2	doc_617668397745_item	3487557	et	2	main
sajandi	doc_617668397745_item	3487559	et	3	main
kirjandus	doc_617668397745_item	3487564	et	3	main
3	doc_617668397745_item	3487569	et	2	main
linnad	doc_617668397745_item	3487584	et	3	main
rohkem	doc_617668397745_item	3487588	et	4	main
kuid	doc_617668397745_item	3487591	et	4	main
töötlejate	doc_617668397745_item	3487592	et	4	main
olukord	doc_617668397745_item	3487593	et	3	main
oli	doc_617668397745_item	3487594	et	3	main
kurb	doc_617668397745_item	3487595	et	3	main
endale	doc_617668397745_item	3487626	et	4	main
õigust	doc_617668397745_item	3487628	et	4	main
siin	doc_617668397745_item	3487629	et	4	main
end	doc_617668397745_item	3487639	et	4	main
tundma	doc_617668397745_item	3487640	et	3	main
üheks	doc_617668397745_item	3487641	et	3	main
rahvaks	doc_617668397745_item	3487642	et	3	main
juba	doc_617668397745_item	3487647	et	3	main
ametiühingut	doc_617668397745_item	3487649	et	3	main
kus	doc_617668397745_item	3487654	et	3	main
oma	doc_617668397745_item	3487658	et	4	main
imperatori	doc_617668397745_item	3487661	et	4	main
revolutsiooni	doc_617668397745_item	3487666	et	4	main
sibirisse	doc_617668397745_item	3487675	et	4	main
2	doc_617668397745_item	3487681	et	2	main
oli	doc_617668397745_item	3487689	et	3	main
tõlgitud	doc_617668397745_item	3487690	et	4	main
aga	doc_617668397745_item	3487696	et	3	main
keeles	doc_617668397745_item	3487704	et	4	main
mis	doc_617668397745_item	3487705	et	4	main
helle	doc_617668397745_item	3487709	et	3	main
oli	doc_617668397745_item	3487718	et	3	main
ladina	doc_617668397745_item	3487719	et	4	main
poolel	doc_617668397745_item	3487724	et	4	main
oli	doc_617668397745_item	3487725	et	3	main
loodi	doc_617668397745_item	3487726	et	4	main
avaldas	doc_617668397745_item	3487746	et	3	main
eesti	doc_617668397745_item	3487753	et	4	main
ja	doc_617668397745_item	3487755	et	3	main
mis	doc_617668397745_item	3487764	et	4	main
loodi	doc_617668397745_item	3487770	et	4	main
1872	doc_617668397745_item	3487774	et	2	main
tuntud	doc_617668397745_item	3487781	et	4	main
kreutzwald	doc_617668397745_item	3487784	et	4	main
kes	doc_617668397745_item	3487785	et	4	main
esimene	doc_617668397745_item	3487790	et	3	main
lydia	doc_617668397745_item	3487792	et	4	main
kes	doc_617668397745_item	3487794	et	4	main
see	doc_617668397745_item	3487798	et	3	main
ärkamisaeg	doc_617668397745_item	3487800	et	3	main
arenes	doc_617668397745_item	3487802	et	3	main
liikumisvabadust	doc_617668397745_item	3487815	et	4	main
talupoegadele	doc_617668397745_item	3487816	et	3	main
ja	doc_617668397745_item	3487817	et	3	main
nad	doc_617668397745_item	3487818	et	3	main
kontrolltöö	doc_617668397745_item	3487547	et	4	main
kultuuriloost	doc_617668397745_item	3487549	et	4	main
1	doc_617668397745_item	3487550	et	2	main
1905	doc_617668397745_item	3487551	et	2	main
kultuurielu	doc_617668397745_item	3487562	et	4	main
teater	doc_617668397745_item	3487566	et	3	main
vabastamine	doc_617668397745_item	3487574	et	4	main
tööstuse	doc_617668397745_item	3487577	et	3	main
arengut	doc_617668397745_item	3487578	et	3	main
19	doc_617668397745_item	3487580	et	2	main
hakkasid	doc_617668397745_item	3487582	et	4	main
inimesed	doc_617668397745_item	3487586	et	3	main
hakkasid	doc_617668397745_item	3487587	et	4	main
rändama	doc_617668397745_item	3487589	et	3	main
demokraatlikud	doc_617668397745_item	3487599	et	3	main
ideed	doc_617668397745_item	3487600	et	4	main
juhtusid	doc_617668397745_item	3487601	et	4	main
tihti	doc_617668397745_item	3487602	et	3	main
manifestatsioonid	doc_617668397745_item	3487603	et	3	main
ja	doc_617668397745_item	3487604	et	3	main
demonstratsioonid	doc_617668397745_item	3487605	et	3	main
mis	doc_617668397745_item	3487606	et	4	main
olid	doc_617668397745_item	3487607	et	4	main
surunud	doc_617668397745_item	3487608	et	4	main
maha	doc_617668397745_item	3487609	et	4	main
eestis	doc_617668397745_item	3487610	et	3	main
hakkasid	doc_617668397745_item	3487611	et	4	main
revolutsioonini	doc_617668397745_item	3487612	et	3	main
umbes	doc_617668397745_item	3487613	et	4	main
1850	doc_617668397745_item	3487614	et	2	main
tel	doc_617668397745_item	3487615	et	4	main
aastatel	doc_617668397745_item	3487616	et	4	main
ilmuma	doc_617668397745_item	3487617	et	3	main
iseseisvuse	doc_617668397745_item	3487618	et	4	main
ideed	doc_617668397745_item	3487633	et	4	main
ja	doc_617668397745_item	3487634	et	3	main
kasvas	doc_617668397745_item	3487635	et	3	main
revolutsiooni	doc_617668397745_item	3487643	et	4	main
hakkasid	doc_617668397745_item	3487645	et	4	main
rajada	doc_617668397745_item	3487648	et	3	main
see	doc_617668397745_item	3487650	et	3	main
võimu	doc_617668397745_item	3487662	et	4	main
olid	doc_617668397745_item	3487667	et	4	main
repressioonid	doc_617668397745_item	3487668	et	3	main
palju	doc_617668397745_item	3487669	et	4	main
eestlaste	doc_617668397745_item	3487670	et	4	main
kultuuritegelejaid	doc_617668397745_item	3487671	et	3	main
olid	doc_617668397745_item	3487672	et	4	main
eesti	doc_617668397745_item	3487703	et	4	main
tartu	doc_617668397745_item	3487714	et	4	main
kus	doc_617668397745_item	3487716	et	3	main
keeles	doc_617668397745_item	3487720	et	4	main
19	doc_617668397745_item	3487721	et	2	main
eesti	doc_617668397745_item	3487727	et	4	main
ajaleht	doc_617668397745_item	3487728	et	3	main
eestimeelse	doc_617668397745_item	3487747	et	3	main
seisukohti	doc_617668397745_item	3487749	et	4	main
ülelaulupidu	doc_617668397745_item	3487763	et	4	main
tegutsevad	doc_617668397745_item	3487778	et	4	main
eestis	doc_617668397745_item	3487779	et	3	main
loodis	doc_617668397745_item	3487786	et	4	main
loodis	doc_617668397745_item	3487795	et	4	main
oli	doc_617668397745_item	3487799	et	3	main
millal	doc_617668397745_item	3487801	et	3	main
kirjakeel	doc_617668397745_item	3487804	et	4	main
ilmusid	doc_617668397745_item	3487805	et	4	main
piimatööstust	doc_617668397745_item	3487848	et	4	main
ilmusid	doc_617668397745_item	3487851	et	4	main
manufaktuur	doc_617668397745_item	3487853	et	3	main
arenes	doc_617668397745_item	3487854	et	3	main
tekstiilitööstust	doc_617668397745_item	3487855	et	4	main
oli	doc_617668397745_item	3487856	et	3	main
kapitalistlik	doc_617668397745_item	3487863	et	3	main
kontrolltöö	doc_617668397746_item	3487866	et	4	main
eesti	doc_617668397746_item	3487868	et	4	main
toimusid	doc_617668397746_item	3487877	et	4	main
2	doc_617668397746_item	3487881	et	2	main
muistne	doc_617668397746_item	3487888	et	3	main
sest	doc_617668397746_item	3487912	et	4	main
teised	doc_617668397746_item	3487918	et	4	main
mis	doc_617668397746_item	3487920	et	4	main
kergendasid	doc_617668397746_item	3487921	et	4	main
põllundust	doc_617668397746_item	3487922	et	3	main
nad	doc_617668397746_item	3487923	et	3	main
hobuseid	doc_617668397746_item	3487933	et	4	main
inimesed	doc_617668397746_item	3487934	et	3	main
ehteid	doc_617668397746_item	3487938	et	3	main
rauast	doc_617668397746_item	3487939	et	4	main
arenes	doc_617668397746_item	3487940	et	3	main
algasid	doc_617668397746_item	3487974	et	4	main
ehitati	doc_617668397746_item	3487987	et	3	main
peale	doc_617668397746_item	3487991	et	4	main
lugeda	doc_617668397746_item	3488004	et	3	main
renessansi	doc_617668397746_item	3488026	et	3	main
stiilis	doc_617668397746_item	3488027	et	4	main
linn	doc_617668397746_item	3488028	et	3	main
oli	doc_617668397746_item	3488029	et	3	main
mitte	doc_617668397746_item	3488030	et	3	main
oli	doc_617668397746_item	3488034	et	3	main
tallinna	doc_617668397746_item	3488038	et	4	main
kaubanduse	doc_617668397746_item	3488041	et	3	main
seisuslik	doc_617668397746_item	3488049	et	3	main
ülemkiht	doc_617668397746_item	3488052	et	3	main
ja	doc_617668397746_item	3488070	et	3	main
olid	doc_617668397746_item	3488072	et	4	main
raamatuid	doc_617668397746_item	3488076	et	3	main
lõppes	doc_617668397746_item	3488080	et	4	main
kaotusega	doc_617668397746_item	3488082	et	4	main
kõigepealt	doc_617668397746_item	3488083	et	3	main
ei	doc_617668397746_item	3488087	et	4	main
elasid	doc_617668397746_item	3488095	et	4	main
ja	doc_617668397746_item	3488103	et	3	main
nad	doc_617668397746_item	3488108	et	3	main
kaitsesid	doc_617668397746_item	3488118	et	4	main
muinaseestlaste	doc_617668397752_item	3488168	et	4	main
algas	doc_617668397745_item	3487652	et	3	main
võitlesid	doc_617668397745_item	3487655	et	4	main
lühendamise	doc_617668397745_item	3487663	et	4	main
põletatud	doc_617668397745_item	3487678	et	4	main
tugevnes	doc_617668397745_item	3487679	et	3	main
eestimaal	doc_617668397745_item	3487685	et	4	main
talurahvakoolid	doc_617668397745_item	3487686	et	3	main
1686	doc_617668397745_item	3487687	et	2	main
aastal	doc_617668397745_item	3487688	et	3	main
tartu	doc_617668397745_item	3487692	et	4	main
testament	doc_617668397745_item	3487695	et	3	main
1739	doc_617668397745_item	3487697	et	2	main
juba	doc_617668397745_item	3487700	et	3	main
põhja	doc_617668397745_item	3487702	et	4	main
anton	doc_617668397745_item	3487707	et	4	main
loonud	doc_617668397745_item	3487713	et	4	main
õpetamine	doc_617668397745_item	3487717	et	4	main
postimees	doc_617668397745_item	3487730	et	4	main
mille	doc_617668397745_item	3487731	et	3	main
rajaja	doc_617668397745_item	3487732	et	4	main
on	doc_617668397745_item	3487733	et	4	main
j	doc_617668397745_item	3487734	et	4	main
v	doc_617668397745_item	3487735	et	4	main
jannsen	doc_617668397745_item	3487736	et	4	main
pärast	doc_617668397745_item	3487737	et	4	main
seda	doc_617668397745_item	3487738	et	3	main
loodi	doc_617668397745_item	3487739	et	4	main
eesti	doc_617668397745_item	3487740	et	4	main
postimees	doc_617668397745_item	3487741	et	4	main
mis	doc_617668397745_item	3487742	et	4	main
ilmus	doc_617668397745_item	3487743	et	4	main
tartus	doc_617668397745_item	3487744	et	3	main
seda	doc_617668397745_item	3487745	et	3	main
ka	doc_617668397745_item	3487752	et	3	main
mänguselts	doc_617668397745_item	3487756	et	3	main
1869	doc_617668397745_item	3487758	et	2	main
aastal	doc_617668397745_item	3487759	et	3	main
oli	doc_617668397745_item	3487760	et	3	main
ka	doc_617668397745_item	3487771	et	3	main
eesti	doc_617668397745_item	3487772	et	4	main
sellel	doc_617668397745_item	3487776	et	4	main
ajal	doc_617668397745_item	3487777	et	4	main
kalevipoeg	doc_617668397745_item	3487789	et	3	main
ajakirjad	doc_617668397745_item	3487806	et	3	main
hakkas	doc_617668397745_item	3487846	et	3	main
narva	doc_617668397745_item	3487852	et	4	main
eesti	doc_617668397745_item	3487860	et	4	main
algas	doc_617668397745_item	3487861	et	3	main
tööstuse	doc_617668397745_item	3487862	et	3	main
vaimses	doc_617668397746_item	3487875	et	3	main
kiviajast	doc_617668397746_item	3487894	et	4	main
подсечное	doc_617668397746_item	3487910	et	2	main
on	doc_617668397746_item	3487914	et	4	main
kasvasid	doc_617668397746_item	3487928	et	4	main
tegivad	doc_617668397746_item	3487935	et	4	main
mis	doc_617668397746_item	3487943	et	4	main
oli	doc_617668397746_item	3487944	et	3	main
animistlik	doc_617668397746_item	3487945	et	3	main
nad	doc_617668397746_item	3487946	et	3	main
tuntuv	doc_617668397746_item	3487966	et	4	main
jumal	doc_617668397746_item	3487968	et	3	main
linnasüdaks	doc_617668397746_item	3487978	et	4	main
algharidust	doc_617668397746_item	3488000	et	4	main
õpetati	doc_617668397746_item	3488001	et	3	main
lüüa	doc_617668397746_item	3488020	et	3	main
talud	doc_617668397745_item	3487676	et	4	main
olid	doc_617668397745_item	3487677	et	4	main
ilmusid	doc_617668397745_item	3487684	et	4	main
murdel	doc_617668397745_item	3487693	et	4	main
uus	doc_617668397745_item	3487694	et	3	main
ilmus	doc_617668397745_item	3487699	et	4	main
thor	doc_617668397745_item	3487708	et	4	main
aastal	doc_617668397745_item	3487711	et	3	main
ülikool	doc_617668397745_item	3487715	et	4	main
teisel	doc_617668397745_item	3487723	et	4	main
intellegentsi	doc_617668397745_item	3487748	et	4	main
ta	doc_617668397745_item	3487750	et	4	main
loodi	doc_617668397745_item	3487751	et	4	main
laulu	doc_617668397745_item	3487754	et	4	main
vanemuine	doc_617668397745_item	3487757	et	4	main
i	doc_617668397745_item	3487761	et	4	main
eestimaa	doc_617668397745_item	3487762	et	4	main
rahva	doc_617668397745_item	3487767	et	3	main
identiteedi	doc_617668397745_item	3487768	et	4	main
oli	doc_617668397745_item	3487769	et	3	main
sellised	doc_617668397745_item	3487780	et	4	main
eesti	doc_617668397745_item	3487787	et	4	main
naiseluuletaja	doc_617668397745_item	3487791	et	4	main
koidula	doc_617668397745_item	3487793	et	4	main
luuletuse	doc_617668397745_item	3487797	et	4	main
eesti	doc_617668397745_item	3487803	et	4	main
tõstetatud	doc_617668397745_item	3487808	et	4	main
iseteadvust	doc_617668397745_item	3487809	et	4	main
rohkem	doc_617668397745_item	3487814	et	4	main
hakkasid	doc_617668397745_item	3487819	et	4	main
paigustuma	doc_617668397745_item	3487820	et	4	main
linnades	doc_617668397745_item	3487821	et	3	main
kus	doc_617668397745_item	3487822	et	3	main
nad	doc_617668397745_item	3487823	et	3	main
rajasid	doc_617668397745_item	3487824	et	4	main
tsunffeid	doc_617668397745_item	3487825	et	4	main
ja	doc_617668397745_item	3487826	et	3	main
manufaktuurid	doc_617668397745_item	3487827	et	3	main
suurenes	doc_617668397745_item	3487828	et	4	main
linnaelaniku	doc_617668397745_item	3487829	et	3	main
arv	doc_617668397745_item	3487830	et	3	main
ja	doc_617668397745_item	3487831	et	3	main
hakkas	doc_617668397745_item	3487833	et	3	main
arenema	doc_617668397745_item	3487834	et	3	main
tööstus	doc_617668397745_item	3487832	et	3	main
kõik	doc_617668397745_item	3487835	et	4	main
muutus	doc_617668397745_item	3487836	et	4	main
raudtee	doc_617668397745_item	3487837	et	4	main
rajamisega	doc_617668397745_item	3487838	et	4	main
mille	doc_617668397745_item	3487839	et	3	main
pärast	doc_617668397745_item	3487840	et	4	main
tööstuse	doc_617668397745_item	3487841	et	3	main
arengus	doc_617668397745_item	3487842	et	3	main
jõudis	doc_617668397745_item	3487843	et	3	main
oma	doc_617668397745_item	3487844	et	4	main
apogee	doc_617668397745_item	3487845	et	4	main
i	doc_617668397745_item	3487858	et	4	main
ilmunud	doc_617668397745_item	3487857	et	4	main
arenemine	doc_617668397745_item	3487864	et	4	main
kontrolltöö	doc_617668397746_item	3487867	et	4	main
kultuuriloost	doc_617668397746_item	3487869	et	4	main
1	doc_617668397746_item	3487870	et	2	main
millised	doc_617668397746_item	3487871	et	3	main
üleminekul	doc_617668397746_item	3487878	et	3	main
miks	doc_617668397746_item	3487887	et	4	main
lõppes	doc_617668397746_item	3487890	et	4	main
eestlastele	doc_617668397746_item	3487891	et	4	main
kaotusega	doc_617668397746_item	3487892	et	4	main
1	doc_617668397746_item	3487893	et	2	main
hakkasid	doc_617668397746_item	3487924	et	4	main
tegeleme	doc_617668397746_item	3487925	et	3	main
karjakasvatusega	doc_617668397746_item	3487926	et	3	main
nad	doc_617668397746_item	3487927	et	3	main
nende	doc_617668397746_item	3487941	et	4	main
uskusüsteem	doc_617668397746_item	3487942	et	3	main
linnad	doc_617668397746_item	3487976	et	3	main
olid	doc_617668397746_item	3487979	et	4	main
kirikuid	doc_617668397746_item	3487988	et	4	main
õpetati	doc_617668397746_item	3487990	et	3	main
kõike	doc_617668397746_item	3487992	et	4	main
kirjutada	doc_617668397746_item	3487993	et	3	main
algasid	doc_617668397746_item	3487994	et	4	main
ilmuma	doc_617668397746_item	3487995	et	3	main
esimesed	doc_617668397746_item	3487996	et	3	main
koolid	doc_617668397746_item	3487997	et	3	main
kus	doc_617668397746_item	3487998	et	3	main
anti	doc_617668397746_item	3487999	et	3	main
ehitati	doc_617668397746_item	3488022	et	3	main
maja	doc_617668397746_item	3488024	et	4	main
gotika	doc_617668397746_item	3488025	et	4	main
siin	doc_617668397746_item	3488033	et	4	main
hanza	doc_617668397746_item	3488045	et	4	main
kord	doc_617668397746_item	3488050	et	4	main
saaksid	doc_617668397746_item	3488060	et	4	main
kätte	doc_617668397746_item	3488061	et	4	main
saada	doc_617668397746_item	3488062	et	4	main
religioosne	doc_617668397746_item	3488063	et	3	main
ka	doc_617668397746_item	3488066	et	3	main
ümber	doc_617668397746_item	3488068	et	3	main
3	doc_617668397746_item	3488077	et	2	main
nad	doc_617668397746_item	3488086	et	3	main
vabaduse	doc_617668397746_item	3488092	et	4	main
eest	doc_617668397746_item	3488093	et	4	main
nad	doc_617668397746_item	3488094	et	3	main
uskusid	doc_617668397746_item	3488105	et	4	main
ei	doc_617668397746_item	3488109	et	4	main
oska	doc_617668397746_item	3488110	et	4	main
nad	doc_617668397746_item	3488117	et	3	main
asulat	doc_617668397746_item	3488121	et	3	main
ühineda	doc_617668397746_item	3488126	et	3	main
võitlesid	doc_617668397746_item	3488128	et	4	main
ja	doc_617668397746_item	3487874	et	3	main
kultuuris	doc_617668397746_item	3487876	et	3	main
rauaaega	doc_617668397746_item	3487880	et	4	main
linnakultuuri	doc_617668397746_item	3487883	et	4	main
vabadusvõitlus	doc_617668397746_item	3487889	et	3	main
inimesed	doc_617668397746_item	3487895	et	3	main
koriluse	doc_617668397746_item	3487898	et	4	main
земледелие	doc_617668397746_item	3487911	et	2	main
nendel	doc_617668397746_item	3487913	et	4	main
ilmusid	doc_617668397746_item	3487915	et	4	main
rauakirvesid	doc_617668397746_item	3487916	et	4	main
rauatööristad	doc_617668397746_item	3487919	et	4	main
ususid	doc_617668397746_item	3487947	et	4	main
et	doc_617668397746_item	3487948	et	3	main
igal	doc_617668397746_item	3487949	et	3	main
asjadel	doc_617668397746_item	3487950	et	3	main
loomadel	doc_617668397746_item	3487951	et	3	main
kividel	doc_617668397746_item	3487953	et	3	main
on	doc_617668397746_item	3487954	et	4	main
hing	doc_617668397746_item	3487955	et	3	main
nad	doc_617668397746_item	3487956	et	3	main
austasid	doc_617668397746_item	3487957	et	4	main
oma	doc_617668397746_item	3487958	et	4	main
nendel	doc_617668397746_item	3487960	et	4	main
oli	doc_617668397746_item	3487961	et	3	main
eellaseid	doc_617668397746_item	3487959	et	3	main
rauaajas	doc_617668397746_item	3487962	et	3	main
keeruline	doc_617668397746_item	3487963	et	4	main
jumalastruktuur	doc_617668397746_item	3487964	et	3	main
kõige	doc_617668397746_item	3487965	et	4	main
keskaegsel	doc_617668397746_item	3487884	et	3	main
eestimaal	doc_617668397746_item	3487885	et	4	main
3	doc_617668397746_item	3487886	et	2	main
tegelesid	doc_617668397746_item	3487896	et	4	main
küttimise	doc_617668397746_item	3487897	et	4	main
ja	doc_617668397746_item	3487899	et	3	main
kalapüügiga	doc_617668397746_item	3487900	et	3	main
rauaajal	doc_617668397746_item	3487901	et	3	main
nad	doc_617668397746_item	3487902	et	3	main
hakkasid	doc_617668397746_item	3487903	et	4	main
tegelema	doc_617668397746_item	3487904	et	3	main
põllundusega	doc_617668397746_item	3487905	et	3	main
nad	doc_617668397746_item	3487906	et	3	main
võtsid	doc_617668397746_item	3487907	et	4	main
kasutusele	doc_617668397746_item	3487908	et	4	main
allpõllundust	doc_617668397746_item	3487909	et	3	main
ja	doc_617668397746_item	3487917	et	3	main
lammbad	doc_617668397746_item	3487929	et	4	main
kitsaid	doc_617668397746_item	3487930	et	3	main
lehmaid	doc_617668397746_item	3487931	et	4	main
ja	doc_617668397746_item	3487932	et	3	main
endale	doc_617668397746_item	3487936	et	4	main
mitmesuguseid	doc_617668397746_item	3487937	et	3	main
puudel	doc_617668397746_item	3487952	et	4	main
tarapita	doc_617668397746_item	3487969	et	4	main
tara	doc_617668397746_item	3487971	et	4	main
3	doc_617668397746_item	3487972	et	2	main
keskaegsel	doc_617668397746_item	3487973	et	3	main
kuid	doc_617668397746_item	3487977	et	4	main
saakslased	doc_617668397746_item	3487980	et	4	main
mitte	doc_617668397746_item	3487981	et	3	main
siin	doc_617668397746_item	3487986	et	4	main
kirjutada	doc_617668397746_item	3488002	et	3	main
tagasi	doc_617668397746_item	3488019	et	3	main
ainult	doc_617668397746_item	3488031	et	4	main
keskendatud	doc_617668397746_item	3488035	et	4	main
punkt	doc_617668397746_item	3488046	et	4	main
klostrid	doc_617668397746_item	3488057	et	4	main
kus	doc_617668397746_item	3488058	et	3	main
inimesed	doc_617668397746_item	3488059	et	3	main
siin	doc_617668397746_item	3488065	et	4	main
oli	doc_617668397746_item	3487967	et	3	main
või	doc_617668397746_item	3487970	et	4	main
areneda	doc_617668397746_item	3487975	et	3	main
eestlased	doc_617668397746_item	3487982	et	3	main
linnas	doc_617668397746_item	3487983	et	4	main
arenes	doc_617668397746_item	3487984	et	3	main
kultuur	doc_617668397746_item	3487985	et	3	main
kus	doc_617668397746_item	3487989	et	3	main
ja	doc_617668397746_item	3488003	et	3	main
ilmuma	doc_617668397746_item	3488006	et	3	main
hakkasid	doc_617668397746_item	3488005	et	4	main
haritud	doc_617668397746_item	3488007	et	4	main
inimesed	doc_617668397746_item	3488008	et	3	main
kes	doc_617668397746_item	3488009	et	4	main
täiendasid	doc_617668397746_item	3488010	et	4	main
riikliku	doc_617668397746_item	3488011	et	3	main
ametikohti	doc_617668397746_item	3488012	et	4	main
linn	doc_617668397746_item	3488013	et	3	main
oli	doc_617668397746_item	3488014	et	3	main
kaitstud	doc_617668397746_item	3488015	et	4	main
et	doc_617668397746_item	3488017	et	3	main
kindlustusega	doc_617668397746_item	3488016	et	4	main
vaenlasi	doc_617668397746_item	3488018	et	3	main
linnas	doc_617668397746_item	3488021	et	4	main
ka	doc_617668397746_item	3488036	et	3	main
kaubandus	doc_617668397746_item	3488037	et	3	main
läbindas	doc_617668397746_item	3488040	et	3	main
linnas	doc_617668397746_item	3488047	et	4	main
formeerus	doc_617668397746_item	3488048	et	3	main
eraldus	doc_617668397746_item	3488051	et	4	main
linnas	doc_617668397746_item	3488053	et	4	main
olid	doc_617668397746_item	3488054	et	4	main
ehitatud	doc_617668397746_item	3488055	et	4	main
ka	doc_617668397746_item	3488056	et	3	main
haridust	doc_617668397746_item	3488064	et	4	main
kirjutati	doc_617668397746_item	3488067	et	3	main
vabadusvõitlus	doc_617668397746_item	3488079	et	3	main
oma	doc_617668397746_item	3488091	et	4	main
küttides	doc_617668397746_item	3488098	et	4	main
võitelda	doc_617668397746_item	3488111	et	4	main
nad	doc_617668397746_item	3488112	et	3	main
ainult	doc_617668397746_item	3488119	et	4	main
kuid	doc_617668397746_item	3488122	et	4	main
saaksid	doc_617668397746_item	3488134	et	4	main
ühineda	doc_617668397746_item	3488135	et	3	main
kontrolltöö	doc_617668397752_item	3488163	et	4	main
eesti	doc_617668397752_item	3488164	et	4	main
arheoloogilised	doc_617668397752_item	3488180	et	4	main
3	doc_617668397752_item	3488182	et	2	main
teadus	doc_617668397752_item	3488185	et	4	main
räägitakse	doc_617668397752_item	3488192	et	3	main
arheoloogiast	doc_617668397752_item	3488193	et	3	main
siis	doc_617668397752_item	3488194	et	3	main
mis	doc_617668397752_item	3488211	et	4	main
peitleidude	doc_617668397752_item	3488216	et	4	main
nende	doc_617668397752_item	3488228	et	4	main
religioonist	doc_617668397752_item	3488229	et	3	main
sümbolitest	doc_617668397752_item	3488235	et	4	main
püstkoju	doc_617668397752_item	3488244	et	4	main
põranda	doc_617668397752_item	3488245	et	3	main
alla	doc_617668397752_item	3488246	et	3	main
küüni	doc_617668397752_item	3488259	et	4	main
muinaseestlaste	doc_617668397752_item	3488273	et	4	main
korjamine	doc_617668397752_item	3488277	et	4	main
tavaliselt	doc_617668397752_item	3488281	et	4	main
selle	doc_617668397752_item	3488289	et	4	main
pidid	doc_617668397752_item	3488292	et	4	main
liikuma	doc_617668397752_item	3488296	et	3	main
hõimude	doc_617668397752_item	3488297	et	3	main
peatuspaigad	doc_617668397752_item	3488298	et	3	main
olid	doc_617668397752_item	3488299	et	4	main
võimaldab	doc_617668397752_item	3488306	et	3	main
kalapüüdmist	doc_617668397752_item	3488307	et	3	main
ja	doc_617668397752_item	3488308	et	3	main
veelinnujahti	doc_617668397752_item	3488309	et	4	main
muinaseestlased	doc_617668397752_item	3488310	et	3	main
hiljuti	doc_617668397752_item	3488316	et	4	main
kloostrid	doc_617668397752_item	3488335	et	3	main
hariduselu	doc_617668397752_item	3488338	et	4	main
kultuurikeskustena	doc_617668397752_item	3488340	et	4	main
reliigia	doc_617668397752_item	3488341	et	4	main
mängis	doc_617668397752_item	3488342	et	3	main
suurt	doc_617668397752_item	3488343	et	3	main
said	doc_617668397752_item	3488348	et	4	main
haridust	doc_617668397752_item	3488350	et	4	main
26072006	doc_213943984904_item	3488358	et	2	main
seitse	doc_213943984904_item	3488365	et	3	main
ka	doc_213943984904_item	3488371	et	3	main
kuum	doc_213943984904_item	3488379	et	3	main
ja	doc_213943984904_item	3488385	et	3	main
gruppiga	doc_213943984904_item	3488388	et	4	main
me	doc_213943984904_item	3488398	et	4	main
sillamäe	doc_213943984904_item	3488401	et	3	main
narvasse	doc_213943984904_item	3488403	et	4	main
on	doc_213943984904_item	3488405	et	4	main
narvale	doc_213943984904_item	3488412	et	4	main
aga	doc_213943984904_item	3488413	et	3	main
olukorda	doc_792821541745_item	3488460	et	4	main
saaremaal	doc_792821541745_item	3488463	et	4	main
ning	doc_792821541745_item	3488464	et	3	main
millisesse	doc_792821541745_item	3488471	et	4	main
ilusaid	doc_617668397746_item	3488023	et	3	main
kultuurisüda	doc_617668397746_item	3488032	et	3	main
läbi	doc_617668397746_item	3488039	et	4	main
tee	doc_617668397746_item	3488042	et	4	main
tallinn	doc_617668397746_item	3488043	et	4	main
oli	doc_617668397746_item	3488044	et	3	main
raamatuid	doc_617668397746_item	3488069	et	3	main
siin	doc_617668397746_item	3488071	et	4	main
loonud	doc_617668397746_item	3488073	et	4	main
ka	doc_617668397746_item	3488074	et	3	main
uut	doc_617668397746_item	3488075	et	3	main
et	doc_617668397746_item	3488085	et	3	main
olnud	doc_617668397746_item	3488088	et	4	main
valmis	doc_617668397746_item	3488089	et	4	main
võitelda	doc_617668397746_item	3488090	et	4	main
oma	doc_617668397746_item	3488096	et	4	main
maailmas	doc_617668397746_item	3488097	et	3	main
karjakasvatusega	doc_617668397746_item	3488104	et	3	main
mõtle	doc_617668397746_item	3488114	et	4	main
lahingu	doc_617668397746_item	3488115	et	3	main
strateegiast	doc_617668397746_item	3488116	et	3	main
nende	doc_617668397746_item	3488120	et	4	main
nad	doc_617668397746_item	3488123	et	3	main
nad	doc_617668397746_item	3488127	et	3	main
ühekaupa	doc_617668397746_item	3488129	et	4	main
ainult	doc_617668397746_item	3488130	et	4	main
siis	doc_617668397746_item	3488131	et	3	main
kui	doc_617668397746_item	3488132	et	3	main
nad	doc_617668397746_item	3488133	et	3	main
kultuuriloost	doc_617668397752_item	3488165	et	4	main
kloostrid	doc_617668397752_item	3488171	et	3	main
keskaegse	doc_617668397752_item	3488172	et	3	main
arheoloogia	doc_617668397752_item	3488183	et	4	main
otstarbekas	doc_617668397752_item	3488196	et	4	main
meenutada	doc_617668397752_item	3488197	et	3	main
arheoloogilistest	doc_617668397752_item	3488198	et	4	main
kultuuridest	doc_617668397752_item	3488199	et	3	main
tuntud	doc_617668397752_item	3488203	et	4	main
omased	doc_617668397752_item	3488205	et	3	main
käigus	doc_617668397752_item	3488214	et	4	main
matmiskommetest	doc_617668397752_item	3488230	et	4	main
näiteks	doc_617668397752_item	3488236	et	4	main
kiviajas	doc_617668397752_item	3488237	et	3	main
asula	doc_617668397752_item	3488240	et	4	main
loomade	doc_617668397752_item	3488257	et	4	main
kihvu	doc_617668397752_item	3488260	et	3	main
võime	doc_617668397752_item	3488267	et	4	main
jälgida	doc_617668397752_item	3488268	et	3	main
kogu	doc_617668397752_item	3488269	et	4	main
küttisid	doc_617668397752_item	3488282	et	4	main
põhjapõtru	doc_617668397752_item	3488283	et	3	main
tavaliselt	doc_617668397752_item	3488300	et	4	main
jõe	doc_617668397752_item	3488301	et	3	main
kaldal	doc_617668397752_item	3488302	et	3	main
veekogu	doc_617668397752_item	3488303	et	4	main
muidugi	doc_617668397752_item	3488317	et	4	main
täiustati	doc_617668397752_item	3488318	et	3	main
ja	doc_617668397752_item	3488339	et	3	main
inimesed	doc_617668397752_item	3488347	et	3	main
sel	doc_617668397752_item	3488351	et	3	main
päevik	doc_213943984904_item	3488357	et	3	main
juba	doc_213943984904_item	3488362	et	3	main
ei	doc_213943984904_item	3488377	et	4	main
rahvuspargisse	doc_213943984904_item	3488390	et	3	main
siis	doc_213943984904_item	3488397	et	3	main
tudeng	doc_213943984904_item	3488407	et	3	main
ta	doc_213943984904_item	3488410	et	4	main
kartsin	doc_213943984904_item	3488411	et	3	main
ma	doc_213943984904_item	3488414	et	3	main
arvamus	doc_792821541745_item	3488457	et	3	main
võimalus	doc_792821541745_item	3488467	et	3	main
külastada	doc_792821541745_item	3488468	et	3	main
mitmeid	doc_792821541745_item	3488469	et	4	main
esitatud	doc_792821541745_item	3488476	et	4	main
kõigepealt	doc_792821541745_item	3488480	et	3	main
on	doc_792821541745_item	3488493	et	4	main
pakkub	doc_792821541745_item	3488500	et	4	main
lauljate	doc_792821541745_item	3488508	et	4	main
esinemine	doc_792821541745_item	3488509	et	4	main
tantsud	doc_792821541745_item	3488510	et	3	main
arvates	doc_792821541745_item	3488518	et	4	main
muistne	doc_617668397746_item	3488078	et	3	main
eestlastele	doc_617668397746_item	3488081	et	4	main
sellepärast	doc_617668397746_item	3488084	et	3	main
kalapüügimises	doc_617668397746_item	3488099	et	4	main
nad	doc_617668397746_item	3488100	et	3	main
tegelesid	doc_617668397746_item	3488101	et	4	main
põllutööga	doc_617668397746_item	3488102	et	3	main
nende	doc_617668397746_item	3488106	et	4	main
jumalatesse	doc_617668397746_item	3488107	et	3	main
ei	doc_617668397746_item	3488113	et	4	main
ei	doc_617668397746_item	3488124	et	4	main
taha	doc_617668397746_item	3488125	et	4	main
kõige	doc_617668397746_item	3488136	et	4	main
maakondadega	doc_617668397746_item	3488137	et	3	main
nad	doc_617668397746_item	3488138	et	3	main
algasid	doc_617668397746_item	3488139	et	4	main
võitama	doc_617668397746_item	3488140	et	4	main
näiteks	doc_617668397746_item	3488141	et	4	main
saaremaa	doc_617668397746_item	3488142	et	4	main
lahing	doc_617668397746_item	3488143	et	3	main
selle	doc_617668397746_item	3488144	et	4	main
lisaks	doc_617668397746_item	3488145	et	4	main
vaenlasi	doc_617668397746_item	3488146	et	3	main
oli	doc_617668397746_item	3488147	et	3	main
liiga	doc_617668397746_item	3488148	et	4	main
palju	doc_617668397746_item	3488149	et	4	main
ja	doc_617668397746_item	3488150	et	3	main
nad	doc_617668397746_item	3488151	et	3	main
parem	doc_617668397746_item	3488153	et	4	main
olid	doc_617668397746_item	3488152	et	4	main
relvastatud	doc_617668397746_item	3488154	et	4	main
muisted	doc_617668397746_item	3488155	et	4	main
eestlased	doc_617668397746_item	3488156	et	3	main
ei	doc_617668397746_item	3488157	et	4	main
olnud	doc_617668397746_item	3488158	et	4	main
valmis	doc_617668397746_item	3488159	et	4	main
võitluseks	doc_617668397746_item	3488160	et	3	main
kontrolltöö	doc_617668397752_item	3488162	et	4	main
iseloomusta	doc_617668397752_item	3488167	et	4	main
hariduselu	doc_617668397752_item	3488173	et	4	main
kultuurikeskustena	doc_617668397752_item	3488175	et	4	main
on	doc_617668397752_item	3488179	et	4	main
on	doc_617668397752_item	3488184	et	4	main
mis	doc_617668397752_item	3488186	et	4	main
tegeleb	doc_617668397752_item	3488187	et	3	main
arheoloogilised	doc_617668397752_item	3488200	et	4	main
kultuurid	doc_617668397752_item	3488201	et	3	main
kultuurid	doc_617668397752_item	3488210	et	3	main
ilmuvad	doc_617668397752_item	3488212	et	4	main
ja	doc_617668397752_item	3488217	et	3	main
mitmesuguste	doc_617668397752_item	3488218	et	3	main
muististe	doc_617668397752_item	3488219	et	3	main
uskumuskommetest	doc_617668397752_item	3488231	et	4	main
sängitati	doc_617668397752_item	3488238	et	3	main
territooriumi	doc_617668397752_item	3488241	et	4	main
üleminek	doc_617668397752_item	3488321	et	3	main
anastaspõllumajandusest	doc_617668397752_item	3488322	et	4	main
viljeluspõllumajandusele	doc_617668397752_item	3488323	et	3	main
kasutati	doc_617668397752_item	3488324	et	4	main
serpe	doc_617668397752_item	3488325	et	4	main
ja	doc_617668397752_item	3488326	et	3	main
kõblaid	doc_617668397752_item	3488327	et	4	main
põldudel	doc_617668397752_item	3488328	et	3	main
kasvasid	doc_617668397752_item	3488329	et	4	main
oder	doc_617668397752_item	3488330	et	3	main
1	doc_617668397752_item	3488166	et	2	main
argikultuuri	doc_617668397752_item	3488169	et	4	main
kultuurid	doc_617668397752_item	3488181	et	3	main
kaevamiste	doc_617668397752_item	3488188	et	4	main
arheoloogiliste	doc_617668397752_item	3488189	et	4	main
leidudega	doc_617668397752_item	3488190	et	3	main
kui	doc_617668397752_item	3488191	et	3	main
2	doc_617668397752_item	3488170	et	2	main
ja	doc_617668397752_item	3488174	et	3	main
3	doc_617668397752_item	3488176	et	2	main
missugused	doc_617668397752_item	3488177	et	3	main
kultuurid	doc_617668397752_item	3488178	et	3	main
uurimistöö	doc_617668397752_item	3488213	et	4	main
tänu	doc_617668397752_item	3488220	et	4	main
saame	doc_617668397752_item	3488222	et	4	main
teada	doc_617668397752_item	3488223	et	3	main
vanasti	doc_617668397752_item	3488224	et	3	main
elanud	doc_617668397752_item	3488225	et	4	main
inimeste	doc_617668397752_item	3488226	et	3	main
elust	doc_617668397752_item	3488227	et	3	main
surnu	doc_617668397752_item	3488239	et	4	main
hauatagusse	doc_617668397752_item	3488247	et	4	main
elusse	doc_617668397752_item	3488248	et	3	main
võeti	doc_617668397752_item	3488249	et	3	main
kaasa	doc_617668397752_item	3488250	et	4	main
merevaiku	doc_617668397752_item	3488251	et	4	main
veri	doc_617668397752_item	3488252	et	3	main
ja	doc_617668397752_item	3488253	et	3	main
ajajärgi	doc_617668397752_item	3488270	et	4	main
elatusviisid	doc_617668397752_item	3488275	et	3	main
püsivat	doc_617668397752_item	3488284	et	4	main
kasutasid	doc_617668397752_item	3488311	et	4	main
kividest	doc_617668397752_item	3488312	et	3	main
tehtud	doc_617668397752_item	3488313	et	4	main
oli	doc_617668397752_item	3488320	et	3	main
peeti	doc_617668397752_item	3488336	et	4	main
keskaegses	doc_617668397752_item	3488345	et	3	main
elus	doc_617668397752_item	3488346	et	4	main
ärkasin	doc_213943984904_item	3488361	et	3	main
pool	doc_213943984904_item	3488364	et	4	main
sest	doc_213943984904_item	3488366	et	4	main
ma	doc_213943984904_item	3488367	et	3	main
tahtsin	doc_213943984904_item	3488368	et	3	main
võtma	doc_213943984904_item	3488370	et	3	main
olnud	doc_213943984904_item	3488378	et	4	main
soe	doc_213943984904_item	3488381	et	4	main
ma	doc_213943984904_item	3488384	et	3	main
lahemaa	doc_213943984904_item	3488389	et	4	main
sõitsime	doc_213943984904_item	3488392	et	3	main
jalutasime	doc_213943984904_item	3488395	et	3	main
ursula	doc_213943984904_item	3488408	et	4	main
ainult	doc_213943984904_item	3488416	et	4	main
ette	doc_792821541745_item	3488459	et	4	main
et	doc_792821541745_item	3488461	et	3	main
üritusi	doc_792821541745_item	3488470	et	4	main
te	doc_792821541745_item	3488474	et	4	main
1	doc_792821541745_item	3488479	et	2	main
plus	doc_792821541745_item	3488499	et	4	main
ranna	doc_792821541745_item	3488504	et	3	main
ilutulestik	doc_792821541745_item	3488511	et	3	main
öösel	doc_792821541745_item	3488515	et	4	main
minu	doc_792821541745_item	3488517	et	3	main
veeta	doc_792821541745_item	3488526	et	4	main
vaba	doc_792821541745_item	3488528	et	4	main
aega	doc_792821541745_item	3488529	et	4	main
2	doc_792821541745_item	3488535	et	2	main
tahaksin	doc_792821541745_item	3488537	et	3	main
festivali	doc_792821541745_item	3488540	et	4	main
oma	doc_792821541745_item	3488557	et	4	main
osast	doc_792821541745_item	3488562	et	4	main
on	doc_792821541745_item	3488564	et	4	main
on	doc_792821541745_item	3488571	et	4	main
et	doc_792821541745_item	3488584	et	3	main
sa	doc_792821541745_item	3488595	et	3	main
mulle	doc_792821541745_item	3488600	et	4	main
ja	doc_792821541745_item	3488603	et	3	main
käiksin	doc_792821541745_item	3488614	et	3	main
näiteks	doc_792821541745_item	3488621	et	4	main
on	doc_617668397752_item	3488195	et	4	main
on	doc_617668397752_item	3488202	et	4	main
inimgrupile	doc_617668397752_item	3488204	et	3	main
sarnased	doc_617668397752_item	3488206	et	4	main
materiaalsed	doc_617668397752_item	3488207	et	3	main
ja	doc_617668397752_item	3488208	et	3	main
vaimsed	doc_617668397752_item	3488209	et	3	main
leidude	doc_617668397752_item	3488215	et	4	main
me	doc_617668397752_item	3488221	et	4	main
missuguseid	doc_617668397752_item	3488232	et	3	main
tööristu	doc_617668397752_item	3488233	et	4	main
kasutati	doc_617668397752_item	3488234	et	4	main
pärast	doc_617668397752_item	3488243	et	4	main
elu	doc_617668397752_item	3488254	et	4	main
sümbol	doc_617668397752_item	3488255	et	3	main
puuehteid	doc_617668397752_item	3488256	et	3	main
kurjadest	doc_617668397752_item	3488262	et	4	main
olenditest	doc_617668397752_item	3488263	et	3	main
tööristu	doc_617668397752_item	3488264	et	4	main
arheoloogia	doc_617668397752_item	3488265	et	4	main
abil	doc_617668397752_item	3488266	et	4	main
või	doc_617668397752_item	3488242	et	4	main
hambaid	doc_617668397752_item	3488258	et	3	main
kaitsmine	doc_617668397752_item	3488261	et	4	main
üle	doc_617668397752_item	3488271	et	3	main
metsandide	doc_617668397752_item	3488276	et	3	main
kalapüük	doc_617668397752_item	3488278	et	3	main
ja	doc_617668397752_item	3488279	et	3	main
küttimine	doc_617668397752_item	3488280	et	4	main
ei	doc_617668397752_item	3488287	et	4	main
olnudki	doc_617668397752_item	3488288	et	4	main
et	doc_617668397752_item	3488291	et	3	main
lähedal	doc_617668397752_item	3488304	et	4	main
tööristu	doc_617668397752_item	3488314	et	4	main
mesoliitikumis	doc_617668397752_item	3488319	et	3	main
nisu	doc_617668397752_item	3488331	et	4	main
2	doc_617668397752_item	3488333	et	2	main
keskaegsed	doc_617668397752_item	3488334	et	3	main
rooli	doc_617668397752_item	3488344	et	4	main
religioosset	doc_617668397752_item	3488349	et	3	main
ajal	doc_617668397752_item	3488352	et	4	main
palju	doc_617668397752_item	3488354	et	4	main
raamatuid	doc_617668397752_item	3488355	et	3	main
1	doc_617668397752_item	3488272	et	2	main
olulisemad	doc_617668397752_item	3488274	et	4	main
asulat	doc_617668397752_item	3488285	et	3	main
hõimudel	doc_617668397752_item	3488286	et	3	main
pärast	doc_617668397752_item	3488290	et	4	main
nad	doc_617668397752_item	3488293	et	3	main
põtrade	doc_617668397752_item	3488294	et	3	main
järel	doc_617668397752_item	3488295	et	4	main
mis	doc_617668397752_item	3488305	et	4	main
mis	doc_617668397752_item	3488315	et	4	main
hirss	doc_617668397752_item	3488332	et	3	main
keskaegse	doc_617668397752_item	3488337	et	3	main
ümberkirjutati	doc_617668397752_item	3488353	et	4	main
ma	doc_213943984904_item	3488360	et	3	main
dušši	doc_213943984904_item	3488369	et	2	main
tallinnas	doc_213943984904_item	3488372	et	4	main
päike	doc_213943984904_item	3488373	et	3	main
paistsis	doc_213943984904_item	3488374	et	4	main
aga	doc_213943984904_item	3488375	et	3	main
pärast	doc_213943984904_item	3488383	et	4	main
ema	doc_213943984904_item	3488386	et	4	main
me	doc_213943984904_item	3488391	et	4	main
käsmusse	doc_213943984904_item	3488393	et	4	main
ja	doc_213943984904_item	3488394	et	3	main
rannas	doc_213943984904_item	3488396	et	3	main
eesti	doc_213943984904_item	3488406	et	4	main
ja	doc_213943984904_item	3488409	et	3	main
kujutage	doc_792821541745_item	3488458	et	3	main
viibite	doc_792821541745_item	3488462	et	3	main
teil	doc_792821541745_item	3488465	et	4	main
tähtusjärje	doc_792821541745_item	3488472	et	4	main
üritused	doc_792821541745_item	3488477	et	4	main
külastaksite	doc_792821541745_item	3488478	et	3	main
sky	doc_792821541745_item	3488483	et	4	main
suurim	doc_792821541745_item	3488494	et	3	main
nortele	doc_792821541745_item	3488497	et	4	main
erinevaid	doc_792821541745_item	3488501	et	4	main
meelelahutusi	doc_792821541745_item	3488502	et	4	main
üks	doc_792821541745_item	3488514	et	3	main
vahupidu	doc_792821541745_item	3488516	et	4	main
kus	doc_792821541745_item	3488522	et	3	main
puhata	doc_792821541745_item	3488530	et	4	main
samba	doc_792821541745_item	3488539	et	4	main
noortele	doc_792821541745_item	3488551	et	3	main
ja	doc_792821541745_item	3488554	et	3	main
festivalipäev	doc_792821541745_item	3488559	et	3	main
kuressaare	doc_792821541745_item	3488567	et	4	main
teine	doc_792821541745_item	3488569	et	3	main
ma	doc_792821541745_item	3488582	et	3	main
noortele	doc_792821541745_item	3488590	et	3	main
et	doc_792821541745_item	3488606	et	3	main
minu	doc_792821541745_item	3488609	et	3	main
3	doc_792821541745_item	3488612	et	2	main
valifestivalil	doc_792821541745_item	3488615	et	4	main
ajal	doc_792821541745_item	3488617	et	4	main
noorte	doc_792821541745_item	3488622	et	3	main
huvitav	doc_213943984904_item	3488438	et	4	main
siis	doc_213943984904_item	3488439	et	3	main
me	doc_213943984904_item	3488440	et	4	main
sõitsime	doc_213943984904_item	3488441	et	3	main
narva-jõesuusse	doc_213943984904_item	3488442	et	3	main
kus	doc_213943984904_item	3488443	et	3	main
päivitasime	doc_213943984904_item	3488444	et	4	main
rannas	doc_213943984904_item	3488445	et	3	main
õhtul	doc_213943984904_item	3488446	et	3	main
me	doc_213943984904_item	3488447	et	4	main
söime	doc_213943984904_item	3488448	et	4	main
hotellis	doc_213943984904_item	3488449	et	3	main
salatit	doc_213943984904_item	3488450	et	3	main
ja	doc_213943984904_item	3488451	et	3	main
leiba	doc_213943984904_item	3488452	et	4	main
ja	doc_213943984904_item	3488453	et	3	main
jõime	doc_213943984904_item	3488454	et	3	main
õlut	doc_213943984904_item	3488455	et	3	main
täna	doc_213943984904_item	3488359	et	4	main
kell	doc_213943984904_item	3488363	et	3	main
seal	doc_213943984904_item	3488376	et	4	main
ainult	doc_213943984904_item	3488380	et	4	main
hommikusöögi	doc_213943984904_item	3488382	et	3	main
läksime	doc_213943984904_item	3488387	et	3	main
veel	doc_213943984904_item	3488399	et	4	main
sõitsime	doc_213943984904_item	3488400	et	3	main
läbi	doc_213943984904_item	3488402	et	4	main
meiega	doc_213943984904_item	3488404	et	4	main
olin	doc_213943984904_item	3488415	et	3	main
uudishimulik	doc_213943984904_item	3488417	et	3	main
narva	doc_213943984904_item	3488418	et	4	main
on	doc_213943984904_item	3488419	et	4	main
tühi	doc_213943984904_item	3488420	et	3	main
linn	doc_213943984904_item	3488421	et	3	main
mitte	doc_213943984904_item	3488422	et	3	main
kusagil	doc_213943984904_item	3488423	et	3	main
olid	doc_213943984904_item	3488424	et	4	main
inimesed	doc_213943984904_item	3488425	et	3	main
me	doc_213943984904_item	3488426	et	4	main
olime	doc_213943984904_item	3488427	et	3	main
narva	doc_213943984904_item	3488428	et	4	main
kolledžis	doc_213943984904_item	3488429	et	2	main
kus	doc_213943984904_item	3488430	et	3	main
anneli	doc_213943984904_item	3488431	et	4	main
roose	doc_213943984904_item	3488432	et	3	main
ettekannet	doc_213943984904_item	3488433	et	4	main
pidasis	doc_213943984904_item	3488434	et	4	main
see	doc_213943984904_item	3488435	et	3	main
oli	doc_213943984904_item	3488436	et	3	main
väga	doc_213943984904_item	3488437	et	3	main
lõpuks	doc_792821541745_item	3488647	et	4	main
tahaksin	doc_792821541745_item	3488648	et	3	main
käia	doc_792821541745_item	3488649	et	4	main
merepäevadel	doc_792821541745_item	3488650	et	3	main
see	doc_792821541745_item	3488651	et	3	main
pidu	doc_792821541745_item	3488652	et	4	main
on	doc_792821541745_item	3488653	et	4	main
rohkem	doc_792821541745_item	3488654	et	4	main
vanematele	doc_792821541745_item	3488655	et	4	main
inimestele	doc_792821541745_item	3488656	et	3	main
aga	doc_792821541745_item	3488657	et	3	main
tahan	doc_792821541745_item	3488658	et	3	main
käia	doc_792821541745_item	3488659	et	4	main
mere	doc_792821541745_item	3488660	et	3	main
peal	doc_792821541745_item	3488661	et	4	main
aga	doc_792821541745_item	3488662	et	3	main
mõtlen	doc_792821541745_item	3488663	et	3	main
et	doc_792821541745_item	3488664	et	3	main
seal	doc_792821541745_item	3488665	et	4	main
natukene	doc_792821541745_item	3488667	et	4	main
igav	doc_792821541745_item	3488668	et	3	main
on	doc_792821541745_item	3488666	et	4	main
ja	doc_792821541745_item	3488669	et	3	main
lisaks	doc_792821541745_item	3488670	et	4	main
seal	doc_792821541745_item	3488671	et	4	main
kõlab	doc_792821541745_item	3488672	et	3	main
rahvamuusikat	doc_792821541745_item	3488673	et	3	main
on	doc_792821541745_item	3488466	et	4	main
korda	doc_792821541745_item	3488473	et	4	main
ma	doc_792821541745_item	3488481	et	3	main
plussi	doc_792821541745_item	3488484	et	4	main
üritus	doc_792821541745_item	3488486	et	4	main
toimub	doc_792821541745_item	3488487	et	3	main
6	doc_792821541745_item	3488488	et	2	main
augustil	doc_792821541745_item	3488489	et	3	main
mändjala	doc_792821541745_item	3488490	et	3	main
rannas	doc_792821541745_item	3488491	et	3	main
see	doc_792821541745_item	3488492	et	3	main
allpool	doc_792821541745_item	3488475	et	3	main
külastaksin	doc_792821541745_item	3488482	et	3	main
see	doc_792821541745_item	3488485	et	3	main
show	doc_792821541745_item	3488507	et	4	main
kell	doc_792821541745_item	3488513	et	3	main
üritus	doc_792821541745_item	3488521	et	4	main
võib	doc_792821541745_item	3488524	et	3	main
oma	doc_792821541745_item	3488527	et	4	main
ja	doc_792821541745_item	3488531	et	3	main
uusi	doc_792821541745_item	3488533	et	3	main
pärast	doc_792821541745_item	3488536	et	4	main
külastada	doc_792821541745_item	3488538	et	3	main
samba	doc_792821541745_item	3488541	et	4	main
tantsijatele	doc_792821541745_item	3488552	et	4	main
võimalust	doc_792821541745_item	3488555	et	3	main
suvepidu	doc_792821541745_item	3488495	et	4	main
saaremaal	doc_792821541745_item	3488496	et	4	main
sky	doc_792821541745_item	3488498	et	4	main
näiteks	doc_792821541745_item	3488503	et	4	main
mängud	doc_792821541745_item	3488505	et	3	main
karaoke	doc_792821541745_item	3488506	et	4	main
ja	doc_792821541745_item	3488512	et	3	main
igaüks	doc_792821541745_item	3488523	et	3	main
hästi	doc_792821541745_item	3488525	et	3	main
leida	doc_792821541745_item	3488532	et	3	main
sõbru	doc_792821541745_item	3488534	et	4	main
festival	doc_792821541745_item	3488542	et	3	main
on	doc_792821541745_item	3488543	et	4	main
laadina-ameerika	doc_792821541745_item	3488544	et	3	main
tantsude	doc_792821541745_item	3488545	et	3	main
ja	doc_792821541745_item	3488546	et	3	main
rütmide	doc_792821541745_item	3488547	et	3	main
päev	doc_792821541745_item	3488548	et	3	main
mis	doc_792821541745_item	3488549	et	4	main
oskust	doc_792821541745_item	3488558	et	3	main
kahest	doc_792821541745_item	3488561	et	4	main
esimene	doc_792821541745_item	3488563	et	3	main
linna	doc_792821541745_item	3488568	et	4	main
kuressaare	doc_792821541745_item	3488576	et	4	main
lossi	doc_792821541745_item	3488577	et	4	main
hoovis	doc_792821541745_item	3488578	et	4	main
ilutulestik	doc_792821541745_item	3488579	et	3	main
lõpetab	doc_792821541745_item	3488580	et	3	main
see	doc_792821541745_item	3488585	et	3	main
on	doc_792821541745_item	3488586	et	4	main
üritus	doc_792821541745_item	3488588	et	4	main
nii	doc_792821541745_item	3488589	et	3	main
kui	doc_792821541745_item	3488591	et	3	main
täiskasvanutele	doc_792821541745_item	3488593	et	3	main
tantsida	doc_792821541745_item	3488602	et	3	main
mõtlen	doc_792821541745_item	3488605	et	3	main
oleks	doc_792821541745_item	3488608	et	3	main
jaoks	doc_792821541745_item	3488610	et	4	main
festival	doc_792821541745_item	3488616	et	3	main
toimuvad	doc_792821541745_item	3488618	et	4	main
laulufestival	doc_792821541745_item	3488623	et	3	main
iseloomustage	doc_171929905769_item	3488927	et	4	main
2	doc_171929905769_item	3488930	et	2	main
see	doc_792821541745_item	3488519	et	3	main
on	doc_792821541745_item	3488520	et	4	main
pakkub	doc_792821541745_item	3488550	et	4	main
tantsurõõmu	doc_792821541745_item	3488553	et	4	main
näidata	doc_792821541745_item	3488556	et	4	main
rongkäik	doc_792821541745_item	3488565	et	3	main
osa	doc_792821541745_item	3488570	et	4	main
esinejate	doc_792821541745_item	3488572	et	4	main
ühiskontsert	doc_792821541745_item	3488573	et	3	main
mis	doc_792821541745_item	3488574	et	4	main
toimub	doc_792821541745_item	3488575	et	3	main
festivali	doc_792821541745_item	3488581	et	4	main
nautida	doc_792821541745_item	3488597	et	3	main
tantse	doc_792821541745_item	3488599	et	3	main
meeldib	doc_792821541745_item	3488601	et	3	main
ma	doc_792821541745_item	3488604	et	3	main
erinevaid	doc_792821541745_item	3488619	et	4	main
koosneb	doc_792821541745_item	3488560	et	3	main
läbi	doc_792821541745_item	3488566	et	4	main
mõtlen	doc_792821541745_item	3488583	et	3	main
huvitav	doc_792821541745_item	3488587	et	4	main
ka	doc_792821541745_item	3488592	et	3	main
kus	doc_792821541745_item	3488594	et	3	main
võid	doc_792821541745_item	3488596	et	4	main
ameerika	doc_792821541745_item	3488598	et	3	main
see	doc_792821541745_item	3488607	et	3	main
kasulik	doc_792821541745_item	3488611	et	3	main
siis	doc_792821541745_item	3488613	et	3	main
üritusi	doc_792821541745_item	3488620	et	4	main
tuntud	doc_792821541745_item	3488624	et	4	main
lauljate	doc_792821541745_item	3488625	et	4	main
kontsert	doc_792821541745_item	3488626	et	3	main
tänava	doc_792821541745_item	3488627	et	4	main
karneval	doc_792821541745_item	3488628	et	3	main
lossi	doc_792821541745_item	3488629	et	4	main
tänaval	doc_792821541745_item	3488630	et	4	main
ja	doc_792821541745_item	3488631	et	3	main
suur	doc_792821541745_item	3488632	et	3	main
tantsupidu	doc_792821541745_item	3488633	et	4	main
mõtlen	doc_792821541745_item	3488634	et	3	main
et	doc_792821541745_item	3488635	et	3	main
see	doc_792821541745_item	3488636	et	3	main
on	doc_792821541745_item	3488637	et	4	main
päris	doc_792821541745_item	3488638	et	4	main
huvitav	doc_792821541745_item	3488639	et	4	main
tantsida	doc_792821541745_item	3488640	et	3	main
rahvatantse	doc_792821541745_item	3488641	et	3	main
ja	doc_792821541745_item	3488642	et	3	main
võtta	doc_792821541745_item	3488643	et	3	main
osa	doc_792821541745_item	3488644	et	4	main
karnevalist	doc_792821541745_item	3488645	et	4	main
4	doc_792821541745_item	3488646	et	2	main
eesti	doc_171929905769_item	3488924	et	4	main
ew	doc_171929905769_item	3488928	et	4	main
kollektiviseerimine	doc_171929905769_item	3488935	et	4	main
kaasa	doc_171929905769_item	3488936	et	4	main
eestlaste	doc_171929905769_item	3488943	et	4	main
tuglas	doc_171929905769_item	3488964	et	4	main
aavik	doc_171929905769_item	3488966	et	4	main
kui	doc_171929905769_item	3488989	et	3	main
sai	doc_171929905769_item	3488991	et	4	main
hakkas	doc_171929905769_item	3489004	et	3	main
väga	doc_171929905769_item	3489007	et	3	main
nt	doc_171929905769_item	3489022	et	4	main
m	doc_171929905769_item	3489023	et	4	main
looming	doc_171929905769_item	3489025	et	3	main
ka	doc_171929905769_item	3489028	et	3	main
ajaloos	doc_171929905769_item	3489038	et	4	main
eesti	doc_171929905769_item	3489047	et	4	main
enamlastele	doc_171929905769_item	3489052	et	4	main
ja	doc_171929905769_item	3489053	et	3	main
sulgeda	doc_171929905769_item	3489054	et	3	main
ajalehed	doc_171929905769_item	3489055	et	3	main
olid	doc_171929905769_item	3489141	et	4	main
veerandi	doc_171929905769_item	3489145	et	4	main
massiline	doc_171929905769_item	3489149	et	4	main
eesti	doc_171929905769_item	3489151	et	4	main
kultuuriloost	doc_171929905769_item	3488925	et	4	main
kirjanduselu	doc_171929905769_item	3488929	et	4	main
pärastsõjajärgne	doc_171929905769_item	3488934	et	3	main
maailmasõda	doc_171929905769_item	3488942	et	4	main
1905	doc_171929905769_item	3488947	et	2	main
aasta	doc_171929905769_item	3488948	et	4	main
arenema	doc_171929905769_item	3488953	et	3	main
ilmus	doc_171929905769_item	3488954	et	4	main
kirjandusorganisatsioon	doc_171929905769_item	3488955	et	3	main
gustav	doc_171929905769_item	3488961	et	4	main
j	doc_171929905769_item	3488965	et	4	main
jt	doc_171929905769_item	3488967	et	4	main
nad	doc_171929905769_item	3488968	et	3	main
tahtsid	doc_171929905769_item	3488969	et	4	main
tutvustada	doc_171929905769_item	3488970	et	3	main
enne	doc_171929905769_item	3488982	et	4	main
vabariigi	doc_171929905769_item	3488984	et	3	main
eesti	doc_171929905769_item	3488990	et	4	main
iseseisvust	doc_171929905769_item	3488992	et	4	main
paranesid	doc_171929905769_item	3488993	et	4	main
haridustingimused	doc_171929905769_item	3488994	et	3	main
tekis	doc_171929905769_item	3488995	et	3	main
haritlaskond	doc_171929905769_item	3488996	et	3	main
ja	doc_171929905769_item	3488997	et	3	main
eest	doc_171929905769_item	3489002	et	4	main
tõde	doc_171929905769_item	3489014	et	4	main
ja	doc_171929905769_item	3489015	et	3	main
populaarne	doc_171929905769_item	3489018	et	3	main
luule	doc_171929905769_item	3489021	et	4	main
underi	doc_171929905769_item	3489024	et	4	main
hakkas	doc_171929905769_item	3489026	et	3	main
proosa	doc_171929905769_item	3489029	et	4	main
trükiti	doc_171929905769_item	3489030	et	3	main
välja	doc_171929905769_item	3489031	et	4	main
väga	doc_171929905769_item	3489032	et	3	main
millal	doc_171929905769_item	3489039	et	3	main
valitsus	doc_171929905769_item	3489043	et	4	main
ei	doc_171929905769_item	3489050	et	4	main
eesti	doc_171929905769_item	3489065	et	4	main
talupoegadel	doc_171929905769_item	3489066	et	3	main
võeti	doc_171929905769_item	3489067	et	3	main
30	doc_171929905769_item	3489073	et	2	main
hakkas	doc_171929905769_item	3489079	et	3	main
ei	doc_171929905769_item	3489138	et	4	main
kaotas	doc_171929905769_item	3489144	et	3	main
sellest	doc_171929905769_item	3489154	et	4	main
kontrolltöö	doc_171929905769_item	3488923	et	4	main
külaühiskonda	doc_171929905769_item	3488937	et	4	main
pärast	doc_171929905769_item	3488946	et	4	main
suits	doc_171929905769_item	3488962	et	3	main
euroopas	doc_171929905769_item	3488972	et	3	main
seda	doc_171929905769_item	3488988	et	3	main
kirjanduselu	doc_171929905769_item	3489003	et	4	main
sai	doc_171929905769_item	3489009	et	4	main
õigus	doc_171929905769_item	3489016	et	4	main
oli	doc_171929905769_item	3489019	et	3	main
ka	doc_171929905769_item	3489020	et	3	main
palju	doc_171929905769_item	3489033	et	4	main
raamatuid	doc_171929905769_item	3489034	et	3	main
oli	doc_171929905769_item	3489041	et	3	main
mis	doc_171929905769_item	3489049	et	4	main
pärastsõjajärgne	doc_171929905769_item	3489057	et	3	main
tõi	doc_171929905769_item	3489059	et	3	main
palju	doc_171929905769_item	3489061	et	4	main
muudatusi	doc_171929905769_item	3489062	et	3	main
pärast	doc_171929905769_item	3489063	et	4	main
sõja	doc_171929905769_item	3489064	et	3	main
ületasid	doc_171929905769_item	3489072	et	4	main
ülejäänud	doc_171929905769_item	3489075	et	4	main
enamasti	doc_171929905769_item	3489085	et	4	main
lapsed	doc_171929905769_item	3489086	et	3	main
naised	doc_171929905769_item	3489087	et	3	main
majandus	doc_171929905769_item	3489135	et	4	main
ja	doc_171929905769_item	3489136	et	3	main
arenenud	doc_171929905769_item	3489139	et	4	main
laostanud	doc_171929905769_item	3489142	et	4	main
toimus	doc_171929905769_item	3489148	et	3	main
küüditamine	doc_171929905769_item	3489150	et	4	main
oli	doc_171929905769_item	3489152	et	3	main
kes	doc_171929905769_item	3489156	et	4	main
olid	doc_171929905769_item	3489157	et	4	main
raskesti	doc_171929905769_item	3489158	et	3	main
laostanud	doc_171929905769_item	3489159	et	4	main
ii	doc_171929905769_item	3489160	et	4	main
maailmasõjal	doc_171929905769_item	3489161	et	3	main
ja	doc_171929905769_item	3489162	et	3	main
kellel	doc_171929905769_item	3489163	et	4	main
olid	doc_171929905769_item	3489164	et	4	main
suured	doc_171929905769_item	3489165	et	3	main
raskused	doc_171929905769_item	3489166	et	4	main
ja	doc_171929905769_item	3489167	et	3	main
kannatused	doc_171929905769_item	3489168	et	4	main
1	doc_171929905769_item	3488926	et	2	main
3	doc_171929905769_item	3488938	et	2	main
mida	doc_171929905769_item	3488939	et	4	main
tähendas	doc_171929905769_item	3488940	et	3	main
ii	doc_171929905769_item	3488941	et	4	main
1	doc_171929905769_item	3488945	et	2	main
eesti	doc_171929905769_item	3488950	et	4	main
kirjanduselu	doc_171929905769_item	3488951	et	4	main
hakkas	doc_171929905769_item	3488952	et	3	main
noor	doc_171929905769_item	3488956	et	3	main
milliseid	doc_171929905769_item	3488931	et	3	main
muudatusi	doc_171929905769_item	3488932	et	3	main
tõi	doc_171929905769_item	3488933	et	3	main
jaoks	doc_171929905769_item	3488944	et	4	main
revolutsioonist	doc_171929905769_item	3488949	et	3	main
olid	doc_171929905769_item	3488960	et	4	main
rahvast	doc_171929905769_item	3488971	et	4	main
toimuvatega	doc_171929905769_item	3488973	et	4	main
nad	doc_171929905769_item	3488974	et	3	main
andsid	doc_171929905769_item	3488975	et	4	main
välja	doc_171929905769_item	3488976	et	4	main
samanimelist	doc_171929905769_item	3488977	et	4	main
albumit	doc_171929905769_item	3488978	et	3	main
aga	doc_171929905769_item	3488979	et	3	main
see	doc_171929905769_item	3488980	et	3	main
eesti	doc_171929905769_item	3488983	et	4	main
ilmus	doc_171929905769_item	3488998	et	4	main
h	doc_171929905769_item	3489011	et	4	main
tammsaare	doc_171929905769_item	3489012	et	3	main
romaan	doc_171929905769_item	3489013	et	3	main
oli	doc_171929905769_item	3489035	et	3	main
aeg	doc_171929905769_item	3489036	et	3	main
eesti	doc_171929905769_item	3489037	et	4	main
raamatud	doc_171929905769_item	3489048	et	4	main
2	doc_171929905769_item	3489056	et	2	main
kaasa	doc_171929905769_item	3489060	et	4	main
maad	doc_171929905769_item	3489069	et	4	main
kui	doc_171929905769_item	3489070	et	3	main
nad	doc_171929905769_item	3489071	et	3	main
ha	doc_171929905769_item	3489074	et	4	main
maal	doc_171929905769_item	3489076	et	4	main
sovhoose	doc_171929905769_item	3489078	et	3	main
olid	doc_171929905769_item	3489084	et	4	main
olla	doc_171929905769_item	3489120	et	3	main
vabad	doc_171929905769_item	3489121	et	3	main
ja	doc_171929905769_item	3489122	et	3	main
omama	doc_171929905769_item	3489123	et	4	main
oma	doc_171929905769_item	3489124	et	4	main
talud	doc_171929905769_item	3489125	et	4	main
maad	doc_171929905769_item	3489126	et	4	main
seda	doc_171929905769_item	3489127	et	3	main
nendel	doc_171929905769_item	3489128	et	4	main
ei	doc_171929905769_item	3489129	et	4	main
olnud	doc_171929905769_item	3489130	et	4	main
ii	doc_171929905769_item	3489131	et	4	main
maailmasõja	doc_171929905769_item	3489132	et	3	main
pärast	doc_171929905769_item	3489133	et	4	main
eesti	doc_171929905769_item	3489134	et	4	main
eesti	doc_171929905769_item	3488957	et	4	main
selle	doc_171929905769_item	3488958	et	4	main
riikmeteks	doc_171929905769_item	3488959	et	4	main
fr	doc_171929905769_item	3488963	et	4	main
oli	doc_171929905769_item	3488981	et	3	main
iseseisvust	doc_171929905769_item	3488985	et	4	main
aga	doc_171929905769_item	3488986	et	3	main
pärast	doc_171929905769_item	3488987	et	4	main
palju	doc_171929905769_item	3488999	et	4	main
haritud	doc_171929905769_item	3489000	et	4	main
inimesi	doc_171929905769_item	3489001	et	4	main
kiiresti	doc_171929905769_item	3489005	et	3	main
arenema	doc_171929905769_item	3489006	et	3	main
populaarseks	doc_171929905769_item	3489008	et	4	main
a	doc_171929905769_item	3489010	et	4	main
väga	doc_171929905769_item	3489017	et	3	main
arenema	doc_171929905769_item	3489027	et	3	main
siin	doc_171929905769_item	3489040	et	4	main
vene	doc_171929905769_item	3489042	et	4	main
ja	doc_171929905769_item	3489044	et	3	main
hakati	doc_171929905769_item	3489045	et	3	main
hävitama	doc_171929905769_item	3489046	et	4	main
meeldinud	doc_171929905769_item	3489051	et	4	main
kollektiviseerimine	doc_171929905769_item	3489058	et	4	main
ära	doc_171929905769_item	3489068	et	4	main
tehti	doc_171929905769_item	3489077	et	3	main
massiline	doc_171929905769_item	3489080	et	4	main
küüditamine	doc_171929905769_item	3489081	et	4	main
kus	doc_171929905769_item	3489082	et	3	main
küüditatuid	doc_171929905769_item	3489083	et	4	main
ja	doc_171929905769_item	3489088	et	3	main
vanad	doc_171929905769_item	3489089	et	3	main
inimesed	doc_171929905769_item	3489090	et	3	main
niisugusel	doc_171929905769_item	3489091	et	3	main
moel	doc_171929905769_item	3489092	et	4	main
vabastati	doc_171929905769_item	3489093	et	3	main
maad	doc_171929905769_item	3489094	et	4	main
liituma	doc_171929905769_item	3489095	et	4	main
kolhoosi	doc_171929905769_item	3489096	et	4	main
juurde	doc_171929905769_item	3489097	et	4	main
3	doc_171929905769_item	3489098	et	2	main
teine	doc_171929905769_item	3489099	et	3	main
maailmasõda	doc_171929905769_item	3489100	et	4	main
tähendas	doc_171929905769_item	3489101	et	3	main
eestlaste	doc_171929905769_item	3489102	et	4	main
jaoks	doc_171929905769_item	3489103	et	4	main
mitu	doc_171929905769_item	3489104	et	4	main
aastat	doc_171929905769_item	3489105	et	3	main
nõukogude	doc_171929905769_item	3489106	et	3	main
liidu	doc_171929905769_item	3489107	et	3	main
valitsuse	doc_171929905769_item	3489108	et	4	main
all	doc_171929905769_item	3489109	et	3	main
eesti	doc_171929905769_item	3489110	et	4	main
rahvas	doc_171929905769_item	3489111	et	4	main
oli	doc_171929905769_item	3489112	et	3	main
harjunud	doc_171929905769_item	3489113	et	4	main
ise	doc_171929905769_item	3489114	et	4	main
otsustada	doc_171929905769_item	3489115	et	3	main
oma	doc_171929905769_item	3489116	et	4	main
saatuse	doc_171929905769_item	3489117	et	3	main
nad	doc_171929905769_item	3489118	et	3	main
tahtsid	doc_171929905769_item	3489119	et	4	main
kultuur	doc_171929905769_item	3489137	et	3	main
maad	doc_171929905769_item	3489140	et	4	main
elanikust	doc_171929905769_item	3489147	et	3	main
maast	doc_171929905769_item	3489155	et	3	main
eesti	doc_171929905769_item	3489143	et	4	main
oma	doc_171929905769_item	3489146	et	4	main
üks	doc_171929905769_item	3489153	et	3	main
see	doc_901133458156_item	3489667	et	3	main
elu	doc_901133458156_item	3489669	et	4	main
2	doc_901133458156_item	3489671	et	2	main
see	doc_901133458156_item	3489679	et	3	main
liiga	doc_901133458156_item	3489682	et	4	main
selle	doc_901133458156_item	3489684	et	4	main
laualampi	doc_901133458156_item	3489685	et	4	main
5	doc_901133458156_item	3489692	et	2	main
spetsialisti	doc_901133458156_item	3489700	et	4	main
võtke	doc_901133458156_item	3489704	et	3	main
paigutage	doc_901133458156_item	3489709	et	3	main
juhend	doc_901133458159_item	3489898	et	3	main
elektriseadmeid	doc_901133458159_item	3489903	et	3	main
see	doc_901133458159_item	3489904	et	3	main
mis	doc_901133458159_item	3489911	et	4	main
d	doc_901133458159_item	3489923	et	4	main
ärge	doc_901133458159_item	3489924	et	3	main
kasutage	doc_901133458159_item	3489925	et	3	main
elektriarvesti	doc_901133458159_item	3489931	et	4	main
pesu	doc_901133458159_item	3489946	et	4	main
ja	doc_901133458159_item	3489947	et	3	main
luuk	doc_901133458159_item	3489953	et	3	main
avage	doc_901133458159_item	3489971	et	3	main
pistke	doc_901133458159_item	3489974	et	3	main
seina	doc_901133458159_item	3489976	et	4	main
programmi	doc_901133458159_item	3489988	et	4	main
umbes	doc_901133458159_item	3489992	et	4	main
juhend	doc_901133458156_item	3489661	et	3	main
rikkis	doc_901133458156_item	3489665	et	3	main
juhtmes	doc_901133458156_item	3489672	et	3	main
lühis	doc_901133458156_item	3489674	et	4	main
mis	doc_901133458156_item	3489675	et	4	main
põhjustab	doc_901133458156_item	3489676	et	3	main
on	doc_901133458156_item	3489681	et	4	main
jaoks	doc_901133458156_item	3489686	et	4	main
mobiiltelefoni	doc_901133458156_item	3489690	et	4	main
elektrikulu	doc_901133458156_item	3489693	et	4	main
elektriarvesti	doc_901133458156_item	3489695	et	4	main
hooleks	doc_901133458156_item	3489701	et	3	main
puhur	doc_901133458156_item	3489705	et	3	main
välja	doc_901133458156_item	3489707	et	4	main
kerige	doc_901133458156_item	3489712	et	3	main
toitejuhe	doc_901133458156_item	3489713	et	4	main
1	doc_901133458156_item	3489662	et	2	main
kasutage	doc_901133458156_item	3489664	et	3	main
elektrisaadet	doc_901133458156_item	3489666	et	3	main
on	doc_901133458156_item	3489668	et	4	main
ohtlik	doc_901133458156_item	3489670	et	3	main
toimub	doc_901133458156_item	3489673	et	3	main
lamp	doc_901133458156_item	3489680	et	3	main
võimas	doc_901133458156_item	3489683	et	4	main
kasutage	doc_901133458156_item	3489689	et	3	main
möödab	doc_901133458156_item	3489694	et	4	main
6	doc_901133458156_item	3489696	et	2	main
jätke	doc_901133458156_item	3489697	et	4	main
suured	doc_901133458156_item	3489698	et	3	main
puhur	doc_901133458156_item	3489702	et	3	main
pakendist	doc_901133458156_item	3489706	et	3	main
sobivasse	doc_901133458156_item	3489710	et	4	main
kohta	doc_901133458156_item	3489711	et	4	main
a	doc_901133458159_item	3489899	et	4	main
selle	doc_901133458159_item	3489918	et	4	main
tahklas	doc_901133458159_item	3489927	et	4	main
loputusvahedid	doc_901133458159_item	3489948	et	4	main
2	doc_901133458159_item	3489949	et	2	main
3	doc_901133458159_item	3489954	et	2	main
kontrollige	doc_901133458159_item	3489960	et	4	main
täiteventiil	doc_901133458159_item	3489972	et	3	main
ja	doc_901133458159_item	3489973	et	3	main
valitud	doc_901133458159_item	3489987	et	4	main
ärge	doc_901133458156_item	3489663	et	3	main
tulekaju	doc_901133458156_item	3489677	et	4	main
4	doc_901133458156_item	3489687	et	2	main
ärge	doc_901133458156_item	3489688	et	3	main
elektritööd	doc_901133458156_item	3489699	et	4	main
lahti	doc_901133458156_item	3489714	et	4	main
kasutage	doc_901133458159_item	3489901	et	3	main
eluohtlik	doc_901133458159_item	3489906	et	3	main
põhjustas	doc_901133458159_item	3489912	et	3	main
on	doc_901133458159_item	3489917	et	4	main
jaoks	doc_901133458159_item	3489920	et	4	main
liiga	doc_901133458159_item	3489921	et	4	main
võimas	doc_901133458159_item	3489922	et	4	main
pesumasina	doc_901133458159_item	3489939	et	3	main
pange	doc_901133458159_item	3489941	et	4	main
pesumasinasse	doc_901133458159_item	3489942	et	4	main
ja	doc_901133458159_item	3489943	et	3	main
mõõtke	doc_901133458159_item	3489944	et	3	main
hoolikalt	doc_901133458159_item	3489951	et	4	main
programivalija	doc_901133458159_item	3489956	et	4	main
alguskohta	doc_901133458159_item	3489959	et	4	main
5	doc_901133458159_item	3489970	et	2	main
8	doc_901133458159_item	3489991	et	2	main
kahe	doc_901133458159_item	3489993	et	3	main
ja	doc_901133458159_item	3489998	et	3	main
võtke	doc_901133458159_item	3489999	et	3	main
pesumasinast	doc_901133458159_item	3490000	et	4	main
välja	doc_901133458159_item	3490001	et	4	main
9	doc_901133458159_item	3490002	et	2	main
sulgege	doc_901133458159_item	3490003	et	3	main
täiteventiil	doc_901133458159_item	3490004	et	3	main
10	doc_901133458159_item	3490005	et	2	main
tõmmake	doc_901133458159_item	3490006	et	3	main
pistik	doc_901133458159_item	3490007	et	3	main
seinakontaktist	doc_901133458159_item	3490008	et	3	main
välja	doc_901133458159_item	3490009	et	4	main
11	doc_901133458159_item	3490010	et	2	main
kuivatage	doc_901133458159_item	3490011	et	3	main
masin	doc_901133458159_item	3490012	et	3	main
ja	doc_901133458159_item	3490013	et	3	main
jätke	doc_901133458159_item	3490014	et	4	main
luuk	doc_901133458159_item	3490015	et	3	main
paariks	doc_901133458159_item	3490016	et	4	main
tunniks	doc_901133458159_item	3490017	et	3	main
ohutu	doc_901133458156_item	3489742	et	4	main
paigaldamine	doc_901133458156_item	3489743	et	4	main
ärge	doc_901133458156_item	3489744	et	3	main
kasutage	doc_901133458156_item	3489745	et	3	main
puhurit	doc_901133458156_item	3489746	et	3	main
väljas	doc_901133458156_item	3489747	et	4	main
puhur	doc_901133458156_item	3489749	et	3	main
paigaldage	doc_901133458156_item	3489748	et	3	main
nii	doc_901133458156_item	3489750	et	3	main
et	doc_901133458156_item	3489751	et	3	main
õhu	doc_901133458156_item	3489752	et	3	main
sisse-	doc_901133458156_item	3489753	et	4	main
väljavool	doc_901133458156_item	3489755	et	4	main
seadmesse	doc_901133458156_item	3489756	et	4	main
ja	doc_901133458156_item	3489754	et	3	main
ei	doc_901133458156_item	3489757	et	4	main
oleks	doc_901133458156_item	3489758	et	3	main
takistatud	doc_901133458156_item	3489759	et	4	main
puhurit	doc_901133458156_item	3489760	et	3	main
ei	doc_901133458156_item	3489761	et	4	main
tohi	doc_901133458156_item	3489762	et	4	main
kinni	doc_901133458156_item	3489763	et	3	main
katta	doc_901133458156_item	3489764	et	3	main
tulekahju	doc_901133458156_item	3489765	et	4	main
3	doc_901133458156_item	3489678	et	2	main
tanklas	doc_901133458156_item	3489691	et	3	main
kasutamine	doc_901133458156_item	3489703	et	4	main
ning	doc_901133458156_item	3489708	et	3	main
ning	doc_901133458156_item	3489715	et	3	main
pange	doc_901133458156_item	3489716	et	4	main
pistik	doc_901133458156_item	3489717	et	3	main
pistikupessa	doc_901133458156_item	3489718	et	4	main
puhuri	doc_901133458156_item	3489719	et	3	main
sisselülitamiseks	doc_901133458156_item	3489720	et	3	main
keerake	doc_901133458156_item	3489721	et	3	main
lülitit	doc_901133458156_item	3489722	et	3	main
päripäeva	doc_901133458156_item	3489723	et	3	main
tiiviku	doc_901133458156_item	3489724	et	3	main
sümbolile	doc_901133458156_item	3489725	et	3	main
kui	doc_901133458156_item	3489726	et	3	main
soovite	doc_901133458156_item	3489727	et	3	main
jahedat	doc_901133458156_item	3489728	et	3	main
õhuvoolu	doc_901133458156_item	3489729	et	4	main
i	doc_901133458156_item	3489730	et	4	main
märgistusele	doc_901133458156_item	3489731	et	4	main
kui	doc_901133458156_item	3489732	et	3	main
soovite	doc_901133458156_item	3489733	et	3	main
nõrka	doc_901133458156_item	3489734	et	4	main
kuuma	doc_901133458156_item	3489735	et	4	main
õhuvoolu	doc_901133458156_item	3489736	et	4	main
ii	doc_901133458156_item	3489737	et	4	main
märgistusele	doc_901133458156_item	3489738	et	4	main
õhu	doc_901133458156_item	3489739	et	3	main
kuumutamist	doc_901133458156_item	3489740	et	4	main
maksimaalvõimsused	doc_901133458156_item	3489741	et	4	main
rikkis	doc_901133458159_item	3489902	et	3	main
tekkis	doc_901133458159_item	3489909	et	3	main
tulekahju	doc_901133458159_item	3489913	et	4	main
see	doc_901133458159_item	3489915	et	3	main
laualambi	doc_901133458159_item	3489919	et	3	main
e	doc_901133458159_item	3489928	et	4	main
elektrikulu	doc_901133458159_item	3489929	et	4	main
mõõdab	doc_901133458159_item	3489930	et	3	main
suuremad	doc_901133458159_item	3489934	et	4	main
elektritööd	doc_901133458159_item	3489935	et	4	main
asjatundja	doc_901133458159_item	3489936	et	4	main
hooleks	doc_901133458159_item	3489937	et	3	main
kasutusjuhend	doc_901133458159_item	3489938	et	3	main
1	doc_901133458159_item	3489940	et	2	main
sulgege	doc_901133458159_item	3489950	et	3	main
4	doc_901133458159_item	3489965	et	2	main
muud	doc_901133458159_item	3489967	et	4	main
toimingud	doc_901133458159_item	3489969	et	3	main
kontakti	doc_901133458159_item	3489977	et	4	main
lõpuni	doc_901133458159_item	3489990	et	3	main
lahti	doc_901133458159_item	3490018	et	4	main
12	doc_901133458159_item	3490019	et	2	main
ärge	doc_901133458159_item	3490020	et	3	main
kasutage	doc_901133458159_item	3490021	et	3	main
rikkis	doc_901133458159_item	3490022	et	3	main
elektriseadet	doc_901133458159_item	3490023	et	4	main
see	doc_901133458159_item	3490024	et	3	main
on	doc_901133458159_item	3490025	et	4	main
elu	doc_901133458159_item	3490026	et	4	main
ja	doc_901133458159_item	3490027	et	3	main
tuleohtlik	doc_901133458159_item	3490028	et	3	main
ärge	doc_901133458159_item	3489900	et	3	main
on	doc_901133458159_item	3489905	et	4	main
b	doc_901133458159_item	3489907	et	4	main
juhtmes	doc_901133458159_item	3489908	et	3	main
lühis	doc_901133458159_item	3489910	et	4	main
c	doc_901133458159_item	3489914	et	4	main
pirn	doc_901133458159_item	3489916	et	3	main
mobiiltelefoni	doc_901133458159_item	3489926	et	4	main
f	doc_901133458159_item	3489932	et	4	main
jätke	doc_901133458159_item	3489933	et	4	main
valmis	doc_901133458159_item	3489945	et	4	main
pesumasina	doc_901133458159_item	3489952	et	3	main
keerake	doc_901133458159_item	3489955	et	3	main
soovitud	doc_901133458159_item	3489957	et	4	main
programmi	doc_901133458159_item	3489958	et	4	main
et	doc_901133458159_item	3489961	et	3	main
käivitusnupp	doc_901133458159_item	3489962	et	3	main
oleks	doc_901133458159_item	3489963	et	3	main
nullasendis	doc_901133458159_item	3489964	et	3	main
valige	doc_901133458159_item	3489966	et	3	main
võimalikud	doc_901133458159_item	3489968	et	3	main
pistik	doc_901133458159_item	3489975	et	3	main
6	doc_901133458159_item	3489978	et	2	main
valjutage	doc_901133458159_item	3489979	et	4	main
kaivitusnupp	doc_901133458159_item	3489980	et	4	main
alla	doc_901133458159_item	3489981	et	3	main
7	doc_901133458159_item	3489982	et	2	main
oodake	doc_901133458159_item	3489983	et	3	main
kuni	doc_901133458159_item	3489984	et	3	main
masin	doc_901133458159_item	3489985	et	3	main
teeb	doc_901133458159_item	3489986	et	3	main
automaatselt	doc_901133458159_item	3489989	et	4	main
minuti	doc_901133458159_item	3489994	et	3	main
pärast	doc_901133458159_item	3489995	et	4	main
avage	doc_901133458159_item	3489996	et	3	main
luuk	doc_901133458159_item	3489997	et	3	main
ohud	doc_214589672702_item	3490172	et	3	main
ja	doc_214589672702_item	3490173	et	3	main
võlud	doc_214589672702_item	3490174	et	4	main
ümbritseva	doc_214589672702_item	3490177	et	4	main
on	doc_214589672702_item	3490186	et	4	main
võib	doc_214589672702_item	3490194	et	3	main
kahjuks	doc_214589672702_item	3490197	et	4	main
ei	doc_214589672702_item	3490198	et	4	main
iga	doc_214589672702_item	3490206	et	4	main
päev	doc_214589672702_item	3490207	et	3	main
õppima	doc_214589672702_item	3490208	et	3	main
iga	doc_214589672702_item	3490217	et	4	main
päev	doc_214589672702_item	3490218	et	3	main
see	doc_214589672702_item	3490219	et	3	main
aga	doc_214589672702_item	3490220	et	3	main
tähendab	doc_214589672702_item	3490221	et	3	main
perega	doc_214589672702_item	3490224	et	3	main
ei	doc_214589672702_item	3490229	et	4	main
on	doc_214589672702_item	3490234	et	4	main
sest	doc_214589672702_item	3490245	et	4	main
jää	doc_214589672702_item	3490250	et	4	main
sooviks	doc_214589672702_item	3490262	et	4	main
maailma	doc_214589672702_item	3490171	et	4	main
laused	doc_214589672702_item	3490175	et	3	main
meid	doc_214589672702_item	3490176	et	4	main
ohud	doc_214589672702_item	3490179	et	3	main
ja	doc_214589672702_item	3490180	et	3	main
igas	doc_214589672702_item	3490182	et	3	main
asjas	doc_214589672702_item	3490183	et	3	main
siin	doc_214589672702_item	3490184	et	4	main
maailmas	doc_214589672702_item	3490185	et	3	main
oma	doc_214589672702_item	3490187	et	4	main
ohud	doc_214589672702_item	3490188	et	3	main
nende	doc_214589672702_item	3490192	et	4	main
olla	doc_214589672702_item	3490195	et	3	main
vasta	doc_214589672702_item	3490199	et	4	main
see	doc_214589672702_item	3490201	et	3	main
iga	doc_214589672702_item	3490210	et	4	main
päev	doc_214589672702_item	3490211	et	3	main
trennid	doc_214589672702_item	3490214	et	3	main
on	doc_214589672702_item	3490215	et	4	main
pea	doc_214589672702_item	3490216	et	4	main
näiteks	doc_214589672702_item	3490223	et	4	main
saa	doc_214589672702_item	3490230	et	4	main
soov	doc_214589672702_item	3490233	et	3	main
trenni	doc_214589672702_item	3490244	et	4	main
ei	doc_214589672702_item	3490249	et	4	main
ei	doc_214589672702_item	3490253	et	4	main
ole	doc_214589672702_item	3490254	et	4	main
selline	doc_214589672702_item	3490267	et	4	main
siin	doc_214589672702_item	3490274	et	4	main
kogu	doc_214589672702_item	3490290	et	4	main
aeg	doc_214589672702_item	3490291	et	3	main
surfamist	doc_214589672702_item	3490298	et	4	main
kirjeldus	doc_491521501804_item	3490305	et	4	main
homme	doc_491521501804_item	3490306	et	3	main
keegi	doc_491521501804_item	3490311	et	4	main
läheb	doc_491521501804_item	3490312	et	3	main
alati	doc_491521501804_item	3490346	et	4	main
olime	doc_491521501804_item	3490348	et	3	main
kõrval	doc_491521501804_item	3490356	et	4	main
minu	doc_491521501804_item	3490357	et	3	main
vend	doc_491521501804_item	3490358	et	3	main
parteid	doc_491521501804_item	3490365	et	4	main
jälgsid	doc_491521501804_item	3490367	et	4	main
ema	doc_491521501804_item	3490368	et	4	main
ja	doc_491521501804_item	3490369	et	3	main
kui	doc_491521501804_item	3490376	et	3	main
võitlesid	doc_491521501804_item	3490382	et	4	main
nägis	doc_491521501804_item	3490390	et	4	main
ka	doc_491521501804_item	3490391	et	3	main
et	doc_491521501804_item	3490392	et	3	main
väikest	doc_491521501804_item	3490393	et	4	main
pojast	doc_491521501804_item	3490394	et	4	main
nutis	doc_491521501804_item	3490395	et	3	main
ma	doc_491521501804_item	3490396	et	3	main
mäletan	doc_491521501804_item	3490397	et	3	main
ümbritseva	doc_214589672702_item	3490170	et	4	main
maailma	doc_214589672702_item	3490178	et	4	main
võlud	doc_214589672702_item	3490181	et	4	main
ja	doc_214589672702_item	3490189	et	3	main
lõputu	doc_214589672702_item	3490196	et	4	main
ütlus	doc_214589672702_item	3490202	et	3	main
koolis	doc_214589672702_item	3490204	et	4	main
käime	doc_214589672702_item	3490205	et	4	main
ja	doc_214589672702_item	3490212	et	3	main
ka	doc_214589672702_item	3490213	et	3	main
ei	doc_214589672702_item	3490236	et	4	main
paar	doc_214589672702_item	3490240	et	3	main
enam	doc_214589672702_item	3490242	et	4	main
üldse	doc_214589672702_item	3490243	et	3	main
meid	doc_214589672702_item	3490169	et	4	main
võlud	doc_214589672702_item	3490190	et	4	main
ning	doc_214589672702_item	3490191	et	3	main
loetelu	doc_214589672702_item	3490193	et	4	main
alati	doc_214589672702_item	3490200	et	4	main
tõele	doc_214589672702_item	3490203	et	4	main
olla	doc_214589672702_item	3490228	et	3	main
kui	doc_214589672702_item	3490232	et	3	main
samas	doc_214589672702_item	3490235	et	4	main
viimased	doc_214589672702_item	3490239	et	3	main
aega	doc_214589672702_item	3490246	et	4	main
õppimise	doc_214589672702_item	3490247	et	4	main
ning	doc_214589672702_item	3490252	et	3	main
ka	doc_214589672702_item	3490255	et	3	main
kui	doc_214589672702_item	3490259	et	3	main
tahtnud	doc_214589672702_item	3490261	et	4	main
et	doc_214589672702_item	3490263	et	3	main
elu	doc_214589672702_item	3490264	et	4	main
maailmas	doc_214589672702_item	3490275	et	3	main
ei	doc_214589672702_item	3490276	et	4	main
ei	doc_214589672702_item	3490279	et	4	main
peast	doc_214589672702_item	3490281	et	4	main
minema	doc_214589672702_item	3490282	et	3	main
pühitud	doc_214589672702_item	3490283	et	4	main
mälestusi	doc_214589672702_item	3490284	et	4	main
egiptuses	doc_214589672702_item	3490287	et	4	main
hea	doc_214589672702_item	3490292	et	4	main
tuul	doc_214589672702_item	3490293	et	3	main
seetõttu	doc_214589672702_item	3490294	et	3	main
ei	doc_214589672702_item	3490295	et	4	main
surfamisega	doc_214589672702_item	3490301	et	4	main
vaba	doc_491521501804_item	3490308	et	4	main
on	doc_491521501804_item	3490315	et	4	main
päev	doc_491521501804_item	3490317	et	3	main
igal	doc_491521501804_item	3490318	et	3	main
puhkusel	doc_491521501804_item	3490319	et	4	main
minu	doc_491521501804_item	3490320	et	3	main
sugulased	doc_491521501804_item	3490321	et	3	main
ja	doc_491521501804_item	3490322	et	3	main
ja	doc_491521501804_item	3490327	et	3	main
kui	doc_491521501804_item	3490329	et	3	main
ilus	doc_491521501804_item	3490331	et	4	main
ilm	doc_491521501804_item	3490332	et	3	main
ma	doc_491521501804_item	3490333	et	3	main
mäletan	doc_491521501804_item	3490334	et	3	main
kuidas	doc_491521501804_item	3490335	et	3	main
oli	doc_491521501804_item	3490336	et	3	main
eelmisel	doc_491521501804_item	3490337	et	3	main
aastal	doc_491521501804_item	3490338	et	3	main
me	doc_491521501804_item	3490339	et	4	main
läksime	doc_491521501804_item	3490340	et	3	main
pargis	doc_491521501804_item	3490341	et	3	main
ja	doc_491521501804_item	3490342	et	3	main
tegime	doc_491521501804_item	3490343	et	3	main
piknik	doc_491521501804_item	3490344	et	3	main
me	doc_491521501804_item	3490347	et	4	main
puu	doc_491521501804_item	3490350	et	4	main
lähedal	doc_491521501804_item	3490351	et	4	main
ja	doc_491521501804_item	3490352	et	3	main
oli	doc_491521501804_item	3490353	et	3	main
ja	doc_491521501804_item	3490363	et	3	main
ainult	doc_491521501804_item	3490366	et	4	main
nii	doc_491521501804_item	3490372	et	3	main
palju	doc_491521501804_item	3490373	et	4	main
et	doc_491521501804_item	3490402	et	3	main
ja	doc_491521501804_item	3490424	et	3	main
simon	doc_491521501804_item	3490425	et	4	main
et	doc_491521501804_item	3490431	et	3	main
suurest	doc_491521501804_item	3490432	et	4	main
väsinud	doc_491521501804_item	3490440	et	4	main
ja	doc_491521501804_item	3490441	et	3	main
terve	doc_491521501804_item	3490442	et	4	main
päev	doc_491521501804_item	3490443	et	3	main
selles	doc_491521501804_item	3490451	et	4	main
ja	doc_491521501804_item	3490460	et	3	main
ainult	doc_491521501804_item	3490462	et	4	main
peame	doc_214589672702_item	3490209	et	4	main
et	doc_214589672702_item	3490222	et	3	main
või	doc_214589672702_item	3490225	et	4	main
sõpradega	doc_214589672702_item	3490226	et	3	main
koos	doc_214589672702_item	3490227	et	4	main
alati	doc_214589672702_item	3490231	et	4	main
ole	doc_214589672702_item	3490237	et	4	main
jõudnud	doc_214589672702_item	3490238	et	4	main
kuud	doc_214589672702_item	3490241	et	4	main
üle	doc_214589672702_item	3490251	et	3	main
saanud	doc_214589672702_item	3490256	et	4	main
sõpradega	doc_214589672702_item	3490257	et	3	main
kokku	doc_214589672702_item	3490258	et	3	main
oleks	doc_214589672702_item	3490260	et	3	main
ei	doc_214589672702_item	3490265	et	4	main
oleks	doc_214589672702_item	3490266	et	3	main
tormamine	doc_214589672702_item	3490268	et	4	main
aga	doc_214589672702_item	3490269	et	3	main
saa	doc_214589672702_item	3490277	et	4	main
mitte	doc_214589672702_item	3490278	et	3	main
saa	doc_214589672702_item	3490280	et	4	main
surfilaagrist	doc_214589672702_item	3490286	et	3	main
on	doc_214589672702_item	3490288	et	4	main
pea	doc_214589672702_item	3490289	et	4	main
võrrelda	doc_214589672702_item	3490299	et	4	main
eestis	doc_214589672702_item	3490300	et	3	main
pildi	doc_491521501804_item	3490304	et	4	main
mitte	doc_491521501804_item	3490310	et	3	main
tööle	doc_491521501804_item	3490313	et	3	main
nagu	doc_491521501804_item	3490345	et	3	main
suur	doc_491521501804_item	3490349	et	3	main
aga	doc_491521501804_item	3490359	et	3	main
meeldis	doc_491521501804_item	3490360	et	3	main
vette	doc_491521501804_item	3490361	et	3	main
hüpata	doc_491521501804_item	3490362	et	4	main
samal	doc_491521501804_item	3490374	et	3	main
ajal	doc_491521501804_item	3490375	et	4	main
õmblesis	doc_491521501804_item	3490377	et	4	main
ja	doc_491521501804_item	3490378	et	3	main
luges	doc_491521501804_item	3490379	et	3	main
nägis	doc_491521501804_item	3490387	et	4	main
kõige	doc_491521501804_item	3490388	et	4	main
ja	doc_491521501804_item	3490389	et	3	main
toitu	doc_491521501804_item	3490421	et	4	main
teist	doc_491521501804_item	3490427	et	4	main
nad	doc_491521501804_item	3490428	et	3	main
järgnes	doc_491521501804_item	3490434	et	3	main
rahulikult	doc_491521501804_item	3490446	et	4	main
olla	doc_491521501804_item	3490453	et	3	main
mul	doc_491521501804_item	3490457	et	3	main
eksami	doc_491521501804_item	3490459	et	3	main
kirjeldus	doc_491521501805_item	3490494	et	4	main
puhkama	doc_491521501805_item	3490499	et	3	main
kui	doc_491521501805_item	3490501	et	3	main
üks	doc_491521501805_item	3490504	et	3	main
perekond	doc_491521501805_item	3490511	et	3	main
ya	doc_491521501805_item	3490530	et	4	main
minu	doc_491521501805_item	3490531	et	3	main
ya	doc_491521501805_item	3490542	et	4	main
venndad	doc_491521501805_item	3490547	et	4	main
salakuulama	doc_491521501805_item	3490552	et	3	main
vaatavad	doc_491521501805_item	3490556	et	4	main
binokkel	doc_491521501805_item	3490557	et	3	main
joonistavad	doc_491521501805_item	3490558	et	4	main
ja	doc_491521501805_item	3490559	et	3	main
nähtamatu	doc_491521501805_item	3490563	et	4	main
ühe	doc_491521501805_item	3490564	et	4	main
pilt	doc_491521501806_item	3490594	et	3	main
ilus	doc_491521501806_item	3490597	et	4	main
ühe	doc_491521501806_item	3490599	et	4	main
pere	doc_491521501806_item	3490600	et	4	main
koos	doc_491521501806_item	3490601	et	4	main
lastega	doc_491521501806_item	3490603	et	3	main
piknikule	doc_491521501806_item	3490605	et	3	main
ja	doc_491521501806_item	3490608	et	3	main
kaasas	doc_491521501806_item	3490612	et	4	main
päike	doc_491521501806_item	3490615	et	3	main
paistis	doc_491521501806_item	3490616	et	3	main
oli	doc_491521501806_item	3490632	et	3	main
tiigi	doc_491521501806_item	3490642	et	3	main
kõrvalt	doc_214589672702_item	3490248	et	4	main
samas	doc_214589672702_item	3490270	et	4	main
tean	doc_214589672702_item	3490271	et	3	main
et	doc_214589672702_item	3490272	et	3	main
teisiti	doc_214589672702_item	3490273	et	3	main
dahabi	doc_214589672702_item	3490285	et	4	main
saa	doc_214589672702_item	3490296	et	4	main
sealset	doc_214589672702_item	3490297	et	3	main
päev	doc_491521501804_item	3490309	et	3	main
mina	doc_491521501804_item	3490323	et	4	main
teeme	doc_491521501804_item	3490324	et	3	main
pealegi	doc_491521501804_item	3490328	et	4	main
on	doc_491521501804_item	3490330	et	4	main
jogi	doc_491521501804_item	3490355	et	4	main
kaks	doc_491521501804_item	3490364	et	3	main
räägisid	doc_491521501804_item	3490371	et	4	main
poesid	doc_491521501804_item	3490381	et	4	main
päeva	doc_491521501804_item	3490384	et	4	main
ma	doc_491521501804_item	3490403	et	3	main
triin	doc_491521501804_item	3490423	et	4	main
näinud	doc_491521501804_item	3490430	et	4	main
neid	doc_491521501804_item	3490435	et	4	main
isa	doc_491521501804_item	3490437	et	4	main
nii	doc_491521501804_item	3490439	et	3	main
tahaksinud	doc_491521501804_item	3490450	et	4	main
sest	doc_491521501804_item	3490454	et	4	main
päev	doc_491521501804_item	3490456	et	3	main
oli	doc_491521501804_item	3490458	et	3	main
tahaksin	doc_491521501804_item	3490461	et	3	main
meeldi	doc_491521501805_item	3490496	et	4	main
mul	doc_491521501805_item	3490502	et	3	main
väike	doc_491521501805_item	3490505	et	4	main
tudruk	doc_491521501805_item	3490506	et	4	main
läksime	doc_491521501805_item	3490512	et	3	main
kevadel	doc_491521501805_item	3490514	et	4	main
pühapäeval	doc_491521501805_item	3490515	et	3	main
jõgi	doc_491521501805_item	3490516	et	3	main
ääres	doc_491521501805_item	3490517	et	4	main
minu	doc_491521501805_item	3490518	et	3	main
mängima	doc_491521501805_item	3490523	et	3	main
minu	doc_491521501805_item	3490524	et	3	main
isa	doc_491521501805_item	3490525	et	4	main
magasi	doc_491521501805_item	3490526	et	3	main
nende	doc_491521501805_item	3490543	et	4	main
teised	doc_491521501805_item	3490546	et	4	main
puud	doc_491521501805_item	3490555	et	4	main
päeva	doc_491521501805_item	3490562	et	4	main
spioon	doc_491521501805_item	3490565	et	3	main
minu	doc_491521501805_item	3490566	et	3	main
vana	doc_491521501805_item	3490567	et	4	main
õpida	doc_491521501804_item	3490463	et	4	main
aga	doc_491521501804_item	3490464	et	3	main
ma	doc_491521501804_item	3490465	et	3	main
läksin	doc_491521501804_item	3490466	et	3	main
ja	doc_491521501804_item	3490467	et	3	main
mida	doc_491521501804_item	3490468	et	4	main
ma	doc_491521501804_item	3490469	et	3	main
tegin	doc_491521501804_item	3490470	et	3	main
istusin	doc_491521501804_item	3490471	et	3	main
põrandal	doc_491521501804_item	3490472	et	3	main
ja	doc_491521501804_item	3490473	et	3	main
hakasin	doc_491521501804_item	3490474	et	4	main
õpida	doc_491521501804_item	3490475	et	4	main
pärast	doc_491521501804_item	3490476	et	4	main
lõuna	doc_491521501804_item	3490477	et	4	main
ma	doc_491521501804_item	3490478	et	3	main
magasin	doc_491521501804_item	3490479	et	4	main
raamatut	doc_491521501804_item	3490480	et	3	main
näo	doc_491521501804_item	3490481	et	3	main
peale	doc_491521501804_item	3490482	et	4	main
ja	doc_491521501804_item	3490483	et	3	main
ma	doc_491521501804_item	3490484	et	3	main
ei	doc_491521501804_item	3490485	et	4	main
mäleta	doc_491521501804_item	3490486	et	4	main
kuidas	doc_491521501804_item	3490487	et	3	main
oli	doc_491521501804_item	3490488	et	3	main
teine	doc_491521501804_item	3490489	et	3	main
on	doc_491521501804_item	3490307	et	4	main
sest	doc_491521501804_item	3490314	et	4	main
töötaja	doc_491521501804_item	3490316	et	4	main
midagi	doc_491521501804_item	3490325	et	4	main
koos	doc_491521501804_item	3490326	et	4	main
väike	doc_491521501804_item	3490354	et	4	main
tädi	doc_491521501804_item	3490370	et	4	main
tädi	doc_491521501804_item	3490380	et	4	main
terve	doc_491521501804_item	3490383	et	4	main
aga	doc_491521501804_item	3490385	et	3	main
tädi	doc_491521501804_item	3490386	et	4	main
ei	doc_491521501804_item	3490404	et	4	main
leinud	doc_491521501804_item	3490405	et	4	main
kes	doc_491521501804_item	3490406	et	4	main
oli	doc_491521501804_item	3490407	et	3	main
ronis	doc_491521501804_item	3490408	et	4	main
puu	doc_491521501804_item	3490409	et	4	main
peale	doc_491521501804_item	3490410	et	4	main
ja	doc_491521501804_item	3490411	et	3	main
teine	doc_491521501804_item	3490412	et	3	main
oli	doc_491521501804_item	3490413	et	3	main
peitunud	doc_491521501804_item	3490414	et	4	main
puu	doc_491521501804_item	3490415	et	4	main
taga	doc_491521501804_item	3490416	et	4	main
tädid	doc_491521501804_item	3490418	et	3	main
teisid	doc_491521501804_item	3490417	et	4	main
ette	doc_491521501804_item	3490419	et	4	main
valmistasid	doc_491521501804_item	3490420	et	4	main
ka	doc_491521501804_item	3490398	et	3	main
et	doc_491521501804_item	3490399	et	3	main
üks	doc_491521501804_item	3490400	et	3	main
poeg	doc_491521501804_item	3490401	et	3	main
jälgsid	doc_491521501804_item	3490426	et	4	main
hobusest	doc_491521501804_item	3490433	et	4	main
minu	doc_491521501804_item	3490436	et	3	main
oli	doc_491521501804_item	3490438	et	3	main
põrandal	doc_491521501804_item	3490447	et	3	main
ma	doc_491521501804_item	3490448	et	3	main
ei	doc_491521501804_item	3490449	et	4	main
mina	doc_491521501805_item	3490507	et	4	main
ja	doc_491521501805_item	3490508	et	3	main
kõik	doc_491521501805_item	3490509	et	4	main
minu	doc_491521501805_item	3490510	et	3	main
iga	doc_491521501805_item	3490513	et	4	main
last	doc_491521501805_item	3490522	et	4	main
loes	doc_491521501805_item	3490529	et	3	main
vana	doc_491521501805_item	3490537	et	4	main
venndad	doc_491521501805_item	3490538	et	4	main
uskusivad	doc_491521501805_item	3490539	et	4	main
koer	doc_491521501805_item	3490544	et	3	main
naaberi	doc_491521501805_item	3490549	et	3	main
mangisivad	doc_491521501805_item	3490551	et	4	main
ronisivad	doc_491521501805_item	3490554	et	4	main
pildi	doc_491521501806_item	3490590	et	4	main
pildil	doc_491521501806_item	3490595	et	3	main
oli	doc_491521501806_item	3490596	et	3	main
kevad	doc_491521501806_item	3490598	et	3	main
12	doc_491521501806_item	3490609	et	2	main
koera	doc_491521501806_item	3490613	et	4	main
ka	doc_491521501806_item	3490614	et	3	main
ilusasti	doc_491521501806_item	3490617	et	3	main
parti	doc_491521501806_item	3490638	et	4	main
üks	doc_491521501806_item	3490639	et	3	main
ühe	doc_491521501806_item	3490648	et	4	main
vaadata	doc_491521501806_item	3490656	et	4	main
lapsed	doc_491521501806_item	3490661	et	3	main
sama	doc_491521501806_item	3490673	et	4	main
ja	doc_491521501806_item	3490674	et	3	main
vaatas	doc_491521501806_item	3490675	et	3	main
kaks	doc_491521501806_item	3490676	et	3	main
poissi	doc_491521501806_item	3490677	et	4	main
kakles	doc_491521501806_item	3490678	et	3	main
ja	doc_491521501806_item	3490679	et	3	main
ikka	doc_491521501806_item	3490685	et	4	main
kõikele	doc_491521501804_item	3490422	et	4	main
ei	doc_491521501804_item	3490429	et	4	main
oli	doc_491521501804_item	3490444	et	3	main
istunud	doc_491521501804_item	3490445	et	4	main
piknikis	doc_491521501804_item	3490452	et	3	main
teine	doc_491521501804_item	3490455	et	3	main
mulle	doc_491521501805_item	3490495	et	4	main
ääres	doc_491521501805_item	3490498	et	4	main
sallepärast	doc_491521501805_item	3490500	et	4	main
oli	doc_491521501805_item	3490503	et	3	main
näeras	doc_491521501805_item	3490520	et	4	main
kõiki	doc_491521501805_item	3490521	et	4	main
vanaema	doc_491521501805_item	3490528	et	4	main
ema	doc_491521501805_item	3490532	et	4	main
käsi	doc_491521501805_item	3490534	et	4	main
kõik	doc_491521501805_item	3490540	et	4	main
kaukas	doc_491521501805_item	3490545	et	3	main
õesid	doc_491521501805_item	3490568	et	4	main
süüa	doc_491521501805_item	3490569	et	3	main
ja	doc_491521501805_item	3490570	et	3	main
mängivad	doc_491521501805_item	3490571	et	4	main
ilus	doc_491521501806_item	3490593	et	4	main
4	doc_491521501806_item	3490606	et	2	main
last	doc_491521501806_item	3490610	et	4	main
selpäeval	doc_491521501806_item	3490618	et	4	main
nad	doc_491521501806_item	3490619	et	3	main
sõid	doc_491521501806_item	3490620	et	4	main
juures	doc_491521501806_item	3490643	et	4	main
seal	doc_491521501806_item	3490644	et	4	main
oli	doc_491521501806_item	3490645	et	3	main
ta	doc_491521501806_item	3490654	et	4	main
mõned	doc_491521501806_item	3490660	et	3	main
juures	doc_491521501806_item	3490669	et	4	main
seisis	doc_491521501806_item	3490671	et	4	main
nii	doc_491521501806_item	3490672	et	3	main
pereisa	doc_491521501806_item	3490683	et	4	main
luges	doc_491521501806_item	3490687	et	3	main
raamatut	doc_491521501806_item	3490688	et	3	main
tüdrukut	doc_491521501806_item	3490703	et	3	main
hobune	doc_491521501806_item	3490706	et	4	main
kõrval	doc_491521501806_item	3490707	et	4	main
samuti	doc_491521501806_item	3490708	et	3	main
üks	doc_491521501806_item	3490709	et	3	main
poiss	doc_491521501806_item	3490710	et	3	main
lastel	doc_491521501806_item	3490719	et	4	main
oli	doc_491521501806_item	3490720	et	3	main
sest	doc_491521501806_item	3490723	et	4	main
sest	doc_491521501806_item	3490731	et	4	main
nad	doc_491521501806_item	3490732	et	3	main
oli	doc_491521501806_item	3490733	et	3	main
tööga	doc_491521501806_item	3490734	et	3	main
igapäeva	doc_491521501806_item	3490735	et	4	main
eluga	doc_491521501806_item	3490736	et	3	main
ja	doc_491521501806_item	3490737	et	3	main
lastega	doc_491521501806_item	3490738	et	3	main
tüdinenud	doc_491521501806_item	3490739	et	4	main
ilus	doc_491521501807_item	3490780	et	4	main
ja	doc_491521501807_item	3490781	et	3	main
soe	doc_491521501807_item	3490782	et	4	main
ma	doc_491521501807_item	3490783	et	3	main
tahtsin	doc_491521501807_item	3490784	et	3	main
välja	doc_491521501807_item	3490785	et	4	main
sõita	doc_491521501807_item	3490789	et	3	main
nii	doc_491521501807_item	3490804	et	3	main
autosid	doc_491521501807_item	3490806	et	3	main
sama	doc_491521501807_item	3490819	et	4	main
siin	doc_491521501807_item	3490824	et	4	main
ma	doc_491521501807_item	3490829	et	3	main
naudivad	doc_491521501807_item	3490838	et	3	main
ka	doc_491521501807_item	3490839	et	3	main
peale	doc_491521501807_item	3490846	et	4	main
nüüd	doc_491521501807_item	3490848	et	4	main
ma	doc_491521501807_item	3490849	et	3	main
ema	doc_491521501807_item	3490860	et	4	main
beebi	doc_491521501807_item	3490868	et	4	main
päev	doc_491521501804_item	3490490	et	3	main
pildi	doc_491521501805_item	3490493	et	4	main
sööki	doc_491521501805_item	3490573	et	4	main
vahepeal	doc_491521501805_item	3490574	et	3	main
meie	doc_491521501805_item	3490575	et	4	main
naaberi	doc_491521501805_item	3490576	et	3	main
tudrukut	doc_491521501805_item	3490577	et	4	main
näerivad	doc_491521501805_item	3490578	et	4	main
nende	doc_491521501805_item	3490579	et	4	main
ja	doc_491521501805_item	3490580	et	3	main
mina	doc_491521501805_item	3490581	et	4	main
küüasin	doc_491521501805_item	3490582	et	4	main
minu	doc_491521501805_item	3490583	et	3	main
vanaema	doc_491521501805_item	3490584	et	4	main
all	doc_491521501805_item	3490585	et	3	main
tahksin	doc_491521501805_item	3490586	et	4	main
tähelepanu	doc_491521501805_item	3490587	et	4	main
jõgi	doc_491521501805_item	3490497	et	3	main
vanaisa	doc_491521501805_item	3490519	et	4	main
minu	doc_491521501805_item	3490527	et	3	main
teegi	doc_491521501805_item	3490533	et	4	main
töö	doc_491521501805_item	3490535	et	4	main
minu	doc_491521501805_item	3490536	et	3	main
aega	doc_491521501805_item	3490541	et	4	main
koos	doc_491521501805_item	3490548	et	4	main
poisu	doc_491521501805_item	3490550	et	4	main
nende	doc_491521501805_item	3490553	et	4	main
hüppavad	doc_491521501805_item	3490560	et	4	main
kõik	doc_491521501805_item	3490561	et	4	main
teed	doc_491521501805_item	3490572	et	4	main
oh	doc_491521501806_item	3490592	et	3	main
ning	doc_491521501806_item	3490611	et	3	main
väike	doc_491521501806_item	3490633	et	4	main
tiik	doc_491521501806_item	3490634	et	3	main
seal	doc_491521501806_item	3490635	et	4	main
oli	doc_491521501806_item	3490636	et	3	main
2	doc_491521501806_item	3490637	et	2	main
ka	doc_491521501806_item	3490646	et	3	main
ronnida	doc_491521501806_item	3490650	et	4	main
tahtis	doc_491521501806_item	3490655	et	3	main
tahtis	doc_491521501806_item	3490663	et	3	main
midagi	doc_491521501806_item	3490665	et	4	main
süüa	doc_491521501806_item	3490666	et	3	main
söögi	doc_491521501806_item	3490667	et	4	main
haugus	doc_491521501806_item	3490680	et	4	main
koera	doc_491521501806_item	3490681	et	4	main
aga	doc_491521501806_item	3490682	et	3	main
vanaema	doc_491521501806_item	3490686	et	4	main
ema	doc_491521501806_item	3490690	et	4	main
midagi	doc_491521501806_item	3490692	et	4	main
koos	doc_491521501806_item	3490693	et	4	main
linnusid	doc_491521501806_item	3490699	et	4	main
ja	doc_491521501806_item	3490700	et	3	main
meeldis	doc_491521501806_item	3490701	et	3	main
mingi	doc_491521501806_item	3490716	et	4	main
erilist	doc_491521501806_item	3490717	et	4	main
igav	doc_491521501806_item	3490722	et	3	main
ei	doc_491521501806_item	3490725	et	4	main
oskasid	doc_491521501806_item	3490726	et	4	main
on	doc_491521501807_item	3490779	et	4	main
järve	doc_491521501807_item	3490787	et	4	main
tänaval	doc_491521501807_item	3490808	et	4	main
jõudsin	doc_491521501807_item	3490810	et	3	main
äärde	doc_491521501807_item	3490812	et	4	main
palju	doc_491521501807_item	3490816	et	4	main
inimesi	doc_491521501807_item	3490817	et	4	main
mõtlesid	doc_491521501807_item	3490818	et	4	main
ma	doc_491521501807_item	3490822	et	3	main
ole	doc_491521501807_item	3490826	et	4	main
ja	doc_491521501807_item	3490828	et	3	main
on	doc_491521501807_item	3490835	et	4	main
ma	doc_491521501807_item	3490843	et	3	main
mida	doc_491521501807_item	3490856	et	4	main
need	doc_491521501807_item	3490857	et	3	main
lamab	doc_491521501807_item	3490869	et	3	main
peal	doc_491521501807_item	3490871	et	4	main
on	doc_491521501807_item	3490874	et	4	main
peitab	doc_491521501807_item	3490907	et	4	main
teised	doc_491521501807_item	3490917	et	4	main
kõvasti	doc_491521501807_item	3490926	et	3	main
söövad	doc_491521501807_item	3490944	et	4	main
ja	doc_491521501807_item	3490945	et	3	main
joovad	doc_491521501807_item	3490946	et	4	main
väga	doc_491521501807_item	3490947	et	3	main
hobusega	doc_491521501807_item	3490952	et	4	main
ja	doc_491521501807_item	3490953	et	3	main
need	doc_491521501807_item	3490955	et	3	main
seisavad	doc_491521501807_item	3490956	et	3	main
ja	doc_491521501807_item	3490957	et	3	main
vaatavad	doc_491521501807_item	3490958	et	4	main
aga	doc_491521501807_item	3490976	et	3	main
kirjeldus	doc_491521501806_item	3490591	et	4	main
naabri	doc_491521501806_item	3490602	et	3	main
sõitis	doc_491521501806_item	3490604	et	3	main
täiskasvanuid	doc_491521501806_item	3490607	et	3	main
ära	doc_491521501806_item	3490621	et	4	main
mida	doc_491521501806_item	3490622	et	4	main
neil	doc_491521501806_item	3490623	et	4	main
kaasas	doc_491521501806_item	3490624	et	4	main
pikniku	doc_491521501806_item	3490625	et	3	main
koht	doc_491521501806_item	3490626	et	3	main
oli	doc_491521501806_item	3490627	et	3	main
rahulik	doc_491521501806_item	3490628	et	3	main
ja	doc_491521501806_item	3490629	et	3	main
ilus	doc_491521501806_item	3490630	et	4	main
kõrval	doc_491521501806_item	3490631	et	4	main
laps	doc_491521501806_item	3490640	et	4	main
hüppas	doc_491521501806_item	3490641	et	3	main
tammepuu	doc_491521501806_item	3490647	et	4	main
kaugemale	doc_491521501806_item	3490657	et	4	main
korvi	doc_491521501806_item	3490668	et	4	main
vanaisa	doc_491521501806_item	3490670	et	4	main
väike	doc_491521501806_item	3490694	et	4	main
tita	doc_491521501806_item	3490695	et	4	main
valvamisega	doc_491521501806_item	3490696	et	4	main
beebi	doc_491521501806_item	3490697	et	4	main
nägi	doc_491521501806_item	3490698	et	3	main
lihtsalt	doc_491521501806_item	3490704	et	4	main
seisis	doc_491521501806_item	3490705	et	4	main
huvitavat	doc_491521501806_item	3490718	et	4	main
vanemad	doc_491521501806_item	3490729	et	4	main
mis	doc_491521501806_item	3490740	et	4	main
teha	doc_491521501806_item	3490741	et	3	main
lapsed	doc_491521501806_item	3490742	et	3	main
kirjeldus	doc_491521501807_item	3490773	et	4	main
täna	doc_491521501807_item	3490774	et	4	main
on	doc_491521501807_item	3490775	et	4	main
pühapäeval	doc_491521501807_item	3490776	et	3	main
ja	doc_491521501807_item	3490777	et	3	main
ilm	doc_491521501807_item	3490778	et	3	main
loodusse	doc_491521501807_item	3490786	et	4	main
ja	doc_491521501807_item	3490790	et	3	main
parte	doc_491521501807_item	3490795	et	4	main
kui	doc_491521501807_item	3490809	et	3	main
järve	doc_491521501807_item	3490811	et	4	main
nägin	doc_491521501807_item	3490814	et	3	main
et	doc_491521501807_item	3490815	et	3	main
kui	doc_491521501807_item	3490821	et	3	main
ei	doc_491521501807_item	3490825	et	4	main
rahulik	doc_491521501807_item	3490827	et	3	main
ei	doc_491521501807_item	3490830	et	4	main
saa	doc_491521501807_item	3490831	et	4	main
siin	doc_491521501807_item	3490836	et	4	main
ja	doc_491521501807_item	3490837	et	3	main
ilusat	doc_491521501807_item	3490840	et	3	main
nende	doc_491521501807_item	3490845	et	4	main
vaatan	doc_491521501807_item	3490855	et	3	main
teevad	doc_491521501807_item	3490858	et	3	main
isa	doc_491521501807_item	3490862	et	4	main
lamamistoolidel	doc_491521501807_item	3490864	et	3	main
ja	doc_491521501807_item	3490865	et	3	main
loevad	doc_491521501807_item	3490866	et	3	main
teki	doc_491521501807_item	3490870	et	4	main
rohis	doc_491521501807_item	3490872	et	3	main
rahul	doc_491521501807_item	3490876	et	4	main
ta	doc_491521501807_item	3490877	et	4	main
üks	doc_491521501807_item	3490898	et	3	main
hüppab	doc_491521501807_item	3490899	et	3	main
üle	doc_491521501807_item	3490900	et	3	main
jõe	doc_491521501807_item	3490901	et	3	main
üks	doc_491521501807_item	3490902	et	3	main
ronib	doc_491521501807_item	3490903	et	3	main
läbi	doc_491521501807_item	3490915	et	4	main
ja	doc_491521501807_item	3490916	et	3	main
kõrval	doc_491521501807_item	3490923	et	4	main
ja	doc_491521501807_item	3490924	et	3	main
isa	doc_491521501807_item	3490928	et	4	main
on	doc_491521501807_item	3490929	et	4	main
minu	doc_491521501807_item	3490937	et	3	main
taga	doc_491521501807_item	3490938	et	4	main
teeb	doc_491521501807_item	3490939	et	3	main
rikkalikult	doc_491521501807_item	3490948	et	4	main
noor	doc_491521501807_item	3490949	et	3	main
paar	doc_491521501807_item	3490950	et	3	main
nüüd	doc_491521501807_item	3490954	et	4	main
mida	doc_491521501807_item	3490959	et	4	main
oleks	doc_491521501807_item	3490973	et	3	main
väga	doc_491521501807_item	3490974	et	3	main
palju	doc_491521501807_item	3490980	et	4	main
homme	doc_491521501835_item	3490990	et	3	main
vaba	doc_491521501835_item	3490992	et	4	main
keegi	doc_491521501835_item	3490995	et	4	main
midagi	doc_491521501835_item	3491009	et	4	main
koos	doc_491521501835_item	3491010	et	4	main
ja	doc_491521501835_item	3491011	et	3	main
ilus	doc_491521501835_item	3491015	et	4	main
mäletan	doc_491521501835_item	3491018	et	3	main
oli	doc_491521501835_item	3491020	et	3	main
tahtis	doc_491521501806_item	3490649	et	3	main
puu	doc_491521501806_item	3490651	et	4	main
oksale	doc_491521501806_item	3490652	et	3	main
sest	doc_491521501806_item	3490653	et	4	main
ja	doc_491521501806_item	3490658	et	3	main
ümbrusele	doc_491521501806_item	3490659	et	3	main
ikka	doc_491521501806_item	3490662	et	4	main
veel	doc_491521501806_item	3490664	et	4	main
magas	doc_491521501806_item	3490684	et	4	main
ja	doc_491521501806_item	3490689	et	3	main
2	doc_491521501806_item	3490702	et	2	main
natukene	doc_491521501806_item	3490721	et	4	main
nad	doc_491521501806_item	3490724	et	3	main
puhkasid	doc_491521501806_item	3490730	et	4	main
pildi	doc_491521501807_item	3490772	et	4	main
äärde	doc_491521501807_item	3490788	et	4	main
püsiga	doc_491521501807_item	3490794	et	3	main
kõik	doc_491521501807_item	3490796	et	4	main
oli	doc_491521501807_item	3490797	et	3	main
korras	doc_491521501807_item	3490798	et	4	main
aga	doc_491521501807_item	3490799	et	3	main
ma	doc_491521501807_item	3490813	et	3	main
moodis	doc_491521501807_item	3490820	et	4	main
alguses	doc_491521501807_item	3490842	et	4	main
varjus	doc_491521501807_item	3490853	et	4	main
ja	doc_491521501807_item	3490854	et	3	main
vaatab	doc_491521501807_item	3490878	et	3	main
puu	doc_491521501807_item	3490904	et	4	main
puu	doc_491521501807_item	3490909	et	4	main
poisid	doc_491521501807_item	3490918	et	4	main
haukub	doc_491521501807_item	3490925	et	4	main
kuule	doc_491521501807_item	3490935	et	4	main
midagi	doc_491521501807_item	3490936	et	4	main
teised	doc_491521501807_item	3490960	et	4	main
inimesed	doc_491521501807_item	3490961	et	3	main
teevad	doc_491521501807_item	3490962	et	3	main
ma	doc_491521501807_item	3490963	et	3	main
arvan	doc_491521501807_item	3490964	et	3	main
järve	doc_491521501807_item	3490971	et	4	main
kudus	doc_491521501806_item	3490691	et	4	main
ka	doc_491521501806_item	3490711	et	3	main
istus	doc_491521501806_item	3490712	et	4	main
vaatab	doc_491521501806_item	3490713	et	3	main
pildil	doc_491521501806_item	3490714	et	3	main
pole	doc_491521501806_item	3490715	et	3	main
midagi	doc_491521501806_item	3490727	et	4	main
teha	doc_491521501806_item	3490728	et	3	main
nii	doc_491521501806_item	3490743	et	3	main
sama	doc_491521501806_item	3490744	et	4	main
mängis	doc_491521501806_item	3490745	et	3	main
ikka	doc_491521501806_item	3490746	et	4	main
lõbus	doc_491521501806_item	3490747	et	4	main
kodunt	doc_491521501806_item	3490748	et	3	main
välja	doc_491521501806_item	3490749	et	4	main
sõit	doc_491521501806_item	3490750	et	3	main
ja	doc_491521501806_item	3490751	et	3	main
söömisest	doc_491521501806_item	3490752	et	4	main
loodus	doc_491521501806_item	3490753	et	4	main
andis	doc_491521501806_item	3490754	et	3	main
perele	doc_491521501806_item	3490755	et	3	main
vabadust	doc_491521501806_item	3490756	et	4	main
värske	doc_491521501806_item	3490757	et	4	main
õhku	doc_491521501806_item	3490758	et	4	main
jõud	doc_491521501806_item	3490759	et	4	main
jne	doc_491521501806_item	3490760	et	4	main
ma	doc_491521501806_item	3490761	et	3	main
tahan	doc_491521501806_item	3490762	et	3	main
ka	doc_491521501806_item	3490763	et	3	main
sõita	doc_491521501806_item	3490764	et	3	main
koos	doc_491521501806_item	3490765	et	4	main
perega	doc_491521501806_item	3490766	et	3	main
kuhugi	doc_491521501806_item	3490767	et	4	main
ilusale	doc_491521501806_item	3490768	et	4	main
paigale	doc_491521501806_item	3490769	et	4	main
ma	doc_491521501807_item	3490791	et	3	main
tahtsin	doc_491521501807_item	3490792	et	3	main
jahtida	doc_491521501807_item	3490793	et	4	main
natukene	doc_491521501807_item	3490800	et	4	main
imelik	doc_491521501807_item	3490801	et	3	main
oli	doc_491521501807_item	3490802	et	3	main
et	doc_491521501807_item	3490803	et	3	main
palju	doc_491521501807_item	3490805	et	4	main
olid	doc_491521501807_item	3490807	et	4	main
mõtlesin	doc_491521501807_item	3490823	et	3	main
jagida	doc_491521501807_item	3490832	et	4	main
noored	doc_491521501807_item	3490833	et	3	main
perekonnad	doc_491521501807_item	3490834	et	4	main
ilma	doc_491521501807_item	3490841	et	4	main
vihastasin	doc_491521501807_item	3490844	et	3	main
aga	doc_491521501807_item	3490847	et	3	main
seisan	doc_491521501807_item	3490850	et	3	main
puu	doc_491521501807_item	3490851	et	4	main
all	doc_491521501807_item	3490852	et	3	main
siin	doc_491521501807_item	3490859	et	4	main
ja	doc_491521501807_item	3490861	et	3	main
istuvad	doc_491521501807_item	3490863	et	4	main
nende	doc_491521501807_item	3490867	et	4	main
ja	doc_491521501807_item	3490873	et	3	main
nii	doc_491521501807_item	3490875	et	3	main
üks	doc_491521501807_item	3490906	et	3	main
end	doc_491521501807_item	3490908	et	4	main
taga	doc_491521501807_item	3490910	et	4	main
üks	doc_491521501807_item	3490911	et	3	main
paneb	doc_491521501807_item	3490912	et	3	main
tähele	doc_491521501807_item	3490913	et	3	main
pikksilma	doc_491521501807_item	3490914	et	4	main
koer	doc_491521501807_item	3490920	et	3	main
seisab	doc_491521501807_item	3490921	et	3	main
nende	doc_491521501807_item	3490922	et	4	main
ja	doc_491521501807_item	3490933	et	3	main
ei	doc_491521501807_item	3490934	et	4	main
perekond	doc_491521501807_item	3490940	et	3	main
kivi	doc_491521501807_item	3490941	et	4	main
piknikku	doc_491521501807_item	3490942	et	4	main
need	doc_491521501807_item	3490943	et	3	main
tuli	doc_491521501807_item	3490951	et	4	main
et	doc_491521501807_item	3490965	et	3	main
need	doc_491521501807_item	3490966	et	3	main
ka	doc_491521501807_item	3490967	et	3	main
mõtlesid	doc_491521501807_item	3490968	et	4	main
loodus	doc_491521501807_item	3490970	et	4	main
ükskõik	doc_491521501807_item	3490977	et	3	main
eestil	doc_491521501807_item	3490978	et	3	main
läheb	doc_491521501835_item	3490996	et	3	main
on	doc_491521501835_item	3490999	et	4	main
päev	doc_491521501835_item	3491001	et	3	main
igal	doc_491521501835_item	3491002	et	3	main
puhkusel	doc_491521501835_item	3491003	et	4	main
minu	doc_491521501835_item	3491004	et	3	main
sugulased	doc_491521501835_item	3491005	et	3	main
ja	doc_491521501835_item	3491006	et	3	main
ilm	doc_491521501835_item	3491016	et	3	main
me	doc_491521501835_item	3491023	et	4	main
pargis	doc_491521501835_item	3491025	et	3	main
piknik	doc_491521501835_item	3491028	et	3	main
parteid	doc_491521501835_item	3491049	et	4	main
jälgsid	doc_491521501835_item	3491051	et	4	main
tädi	doc_491521501835_item	3491054	et	4	main
luges	doc_491521501835_item	3491063	et	3	main
võitlesid	doc_491521501835_item	3491066	et	4	main
et	doc_491521501835_item	3491083	et	3	main
tipusid	doc_491521501807_item	3490879	et	4	main
rohis	doc_491521501807_item	3490880	et	3	main
väike	doc_491521501807_item	3490881	et	4	main
jänes	doc_491521501807_item	3490882	et	3	main
jookseb	doc_491521501807_item	3490883	et	3	main
lamamistoolide	doc_491521501807_item	3490884	et	3	main
taga	doc_491521501807_item	3490885	et	4	main
selle	doc_491521501807_item	3490886	et	4	main
perekonna	doc_491521501807_item	3490887	et	4	main
kõrval	doc_491521501807_item	3490888	et	4	main
lamab	doc_491521501807_item	3490889	et	3	main
teine	doc_491521501807_item	3490890	et	3	main
isa	doc_491521501807_item	3490891	et	4	main
rohis	doc_491521501807_item	3490892	et	3	main
ta	doc_491521501807_item	3490893	et	4	main
tema	doc_491521501807_item	3490895	et	4	main
pojad	doc_491521501807_item	3490896	et	4	main
magab	doc_491521501807_item	3490894	et	3	main
mängivad	doc_491521501807_item	3490897	et	4	main
otsa	doc_491521501807_item	3490905	et	4	main
võitlevad	doc_491521501807_item	3490919	et	4	main
aga	doc_491521501807_item	3490927	et	3	main
ilmselt	doc_491521501807_item	3490930	et	4	main
väga	doc_491521501807_item	3490931	et	3	main
väsinud	doc_491521501807_item	3490932	et	4	main
et	doc_491521501807_item	3490969	et	3	main
ääres	doc_491521501807_item	3490972	et	4	main
vaikne	doc_491521501807_item	3490975	et	3	main
ümberjutustus	doc_491521501835_item	3490989	et	3	main
päev	doc_491521501835_item	3490993	et	3	main
sest	doc_491521501835_item	3490998	et	4	main
pealegi	doc_491521501835_item	3491012	et	4	main
kui	doc_491521501835_item	3491013	et	3	main
poesid	doc_491521501835_item	3491065	et	4	main
kõige	doc_491521501835_item	3491072	et	4	main
ja	doc_491521501835_item	3491073	et	3	main
poeg	doc_491521501835_item	3491085	et	3	main
peale	doc_491521501835_item	3491094	et	4	main
ja	doc_491521501835_item	3491095	et	3	main
teine	doc_491521501835_item	3491096	et	3	main
oli	doc_491521501835_item	3491097	et	3	main
oli	doc_491521501835_item	3491142	et	3	main
õpida	doc_491521501835_item	3491147	et	4	main
mul	doc_491521501836_item	3491184	et	3	main
oli	doc_491521501836_item	3491185	et	3	main
pühapäeval	doc_491521501836_item	3491197	et	3	main
vanaema	doc_491521501836_item	3491210	et	4	main
loes	doc_491521501836_item	3491211	et	3	main
nende	doc_491521501836_item	3491225	et	4	main
koer	doc_491521501836_item	3491226	et	3	main
kaukas	doc_491521501836_item	3491227	et	3	main
mangisivad	doc_491521501836_item	3491233	et	4	main
salakuulama	doc_491521501836_item	3491234	et	3	main
binokkel	doc_491521501836_item	3491239	et	3	main
oh	doc_491521501837_item	3491274	et	3	main
sõitis	doc_491521501837_item	3491286	et	3	main
last	doc_491521501837_item	3491292	et	4	main
kaasas	doc_491521501837_item	3491294	et	4	main
paistis	doc_491521501837_item	3491298	et	3	main
selpäeval	doc_491521501837_item	3491300	et	4	main
rahulik	doc_491521501837_item	3491310	et	3	main
ikka	doc_491521501837_item	3491344	et	4	main
tahtis	doc_491521501837_item	3491345	et	3	main
vanaema	doc_491521501837_item	3491368	et	4	main
ja	doc_491521501837_item	3491371	et	3	main
valvamisega	doc_491521501837_item	3491378	et	4	main
nad	doc_491521501837_item	3491406	et	3	main
ei	doc_491521501837_item	3491407	et	4	main
tüdinenud	doc_491521501837_item	3491421	et	4	main
lõbus	doc_491521501837_item	3491429	et	4	main
välja	doc_491521501837_item	3491431	et	4	main
on	doc_491521501807_item	3490979	et	4	main
loodust	doc_491521501807_item	3490981	et	4	main
ja	doc_491521501807_item	3490982	et	3	main
igaüks	doc_491521501807_item	3490983	et	3	main
leiab	doc_491521501807_item	3490984	et	3	main
oma	doc_491521501807_item	3490985	et	4	main
rahulikku	doc_491521501807_item	3490986	et	4	main
kohta	doc_491521501807_item	3490987	et	4	main
on	doc_491521501835_item	3490991	et	4	main
mitte	doc_491521501835_item	3490994	et	3	main
kaks	doc_491521501835_item	3491048	et	3	main
ja	doc_491521501835_item	3491062	et	3	main
pojast	doc_491521501835_item	3491078	et	4	main
nutis	doc_491521501835_item	3491079	et	3	main
ma	doc_491521501835_item	3491080	et	3	main
mäletan	doc_491521501835_item	3491081	et	3	main
valmistasid	doc_491521501835_item	3491104	et	4	main
päev	doc_491521501835_item	3491140	et	3	main
eksami	doc_491521501835_item	3491143	et	3	main
ümberjutustus	doc_491521501836_item	3491176	et	3	main
puhkama	doc_491521501836_item	3491181	et	3	main
üks	doc_491521501836_item	3491186	et	3	main
tudruk	doc_491521501836_item	3491188	et	4	main
mina	doc_491521501836_item	3491189	et	4	main
ja	doc_491521501836_item	3491190	et	3	main
kõik	doc_491521501836_item	3491191	et	4	main
minu	doc_491521501836_item	3491192	et	3	main
perekond	doc_491521501836_item	3491193	et	3	main
läksime	doc_491521501836_item	3491194	et	3	main
näeras	doc_491521501836_item	3491202	et	4	main
ya	doc_491521501836_item	3491212	et	4	main
minu	doc_491521501836_item	3491213	et	3	main
teegi	doc_491521501836_item	3491215	et	4	main
käsi	doc_491521501836_item	3491216	et	4	main
töö	doc_491521501836_item	3491217	et	4	main
minu	doc_491521501836_item	3491218	et	3	main
uskusivad	doc_491521501836_item	3491221	et	4	main
ronisivad	doc_491521501836_item	3491236	et	4	main
joonistavad	doc_491521501836_item	3491240	et	4	main
kõik	doc_491521501836_item	3491243	et	4	main
ilus	doc_491521501837_item	3491275	et	4	main
oli	doc_491521501837_item	3491278	et	3	main
ühe	doc_491521501837_item	3491281	et	4	main
pere	doc_491521501837_item	3491282	et	4	main
koos	doc_491521501837_item	3491283	et	4	main
naabri	doc_491521501837_item	3491284	et	3	main
koera	doc_491521501837_item	3491295	et	4	main
ilusasti	doc_491521501837_item	3491299	et	3	main
nad	doc_491521501837_item	3491301	et	3	main
kaasas	doc_491521501837_item	3491306	et	4	main
pikniku	doc_491521501837_item	3491307	et	3	main
oli	doc_491521501837_item	3491309	et	3	main
ja	doc_491521501837_item	3491311	et	3	main
väike	doc_491521501837_item	3491315	et	4	main
veel	doc_491521501837_item	3491346	et	4	main
midagi	doc_491521501837_item	3491347	et	4	main
süüa	doc_491521501837_item	3491348	et	3	main
söögi	doc_491521501837_item	3491349	et	4	main
aga	doc_491521501837_item	3491364	et	3	main
pereisa	doc_491521501837_item	3491365	et	4	main
väike	doc_491521501837_item	3491376	et	4	main
tita	doc_491521501837_item	3491377	et	4	main
oskasid	doc_491521501837_item	3491408	et	4	main
vanemad	doc_491521501837_item	3491411	et	4	main
kodunt	doc_491521501837_item	3491430	et	3	main
on	doc_491521501838_item	3491457	et	4	main
ilus	doc_491521501838_item	3491462	et	4	main
soe	doc_491521501838_item	3491464	et	4	main
ma	doc_491521501838_item	3491465	et	3	main
tahtsin	doc_491521501838_item	3491466	et	3	main
välja	doc_491521501838_item	3491467	et	4	main
sõita	doc_491521501838_item	3491471	et	3	main
jahtida	doc_491521501838_item	3491475	et	4	main
imelik	doc_491521501838_item	3491483	et	3	main
olid	doc_491521501838_item	3491489	et	4	main
ma	doc_491521501835_item	3491153	et	3	main
tegin	doc_491521501835_item	3491154	et	3	main
istusin	doc_491521501835_item	3491155	et	3	main
põrandal	doc_491521501835_item	3491156	et	3	main
ja	doc_491521501835_item	3491157	et	3	main
hakasin	doc_491521501835_item	3491158	et	4	main
õpida	doc_491521501835_item	3491159	et	4	main
pärast	doc_491521501835_item	3491160	et	4	main
lõuna	doc_491521501835_item	3491161	et	4	main
ma	doc_491521501835_item	3491162	et	3	main
magasin	doc_491521501835_item	3491163	et	4	main
raamatut	doc_491521501835_item	3491164	et	3	main
näo	doc_491521501835_item	3491165	et	3	main
peale	doc_491521501835_item	3491166	et	4	main
ja	doc_491521501835_item	3491167	et	3	main
ma	doc_491521501835_item	3491168	et	3	main
ei	doc_491521501835_item	3491169	et	4	main
mäleta	doc_491521501835_item	3491170	et	4	main
kuidas	doc_491521501835_item	3491171	et	3	main
oli	doc_491521501835_item	3491172	et	3	main
teine	doc_491521501835_item	3491173	et	3	main
päev	doc_491521501835_item	3491174	et	3	main
tööle	doc_491521501835_item	3490997	et	3	main
töötaja	doc_491521501835_item	3491000	et	4	main
mina	doc_491521501835_item	3491007	et	4	main
teeme	doc_491521501835_item	3491008	et	3	main
on	doc_491521501835_item	3491014	et	4	main
ma	doc_491521501835_item	3491017	et	3	main
kuidas	doc_491521501835_item	3491019	et	3	main
eelmisel	doc_491521501835_item	3491021	et	3	main
ja	doc_491521501835_item	3491026	et	3	main
nagu	doc_491521501835_item	3491029	et	3	main
olime	doc_491521501835_item	3491032	et	3	main
suur	doc_491521501835_item	3491033	et	3	main
puu	doc_491521501835_item	3491034	et	4	main
lähedal	doc_491521501835_item	3491035	et	4	main
ja	doc_491521501835_item	3491036	et	3	main
oli	doc_491521501835_item	3491037	et	3	main
väike	doc_491521501835_item	3491038	et	4	main
jogi	doc_491521501835_item	3491039	et	4	main
kõrval	doc_491521501835_item	3491040	et	4	main
minu	doc_491521501835_item	3491041	et	3	main
vend	doc_491521501835_item	3491042	et	3	main
aga	doc_491521501835_item	3491043	et	3	main
meeldis	doc_491521501835_item	3491044	et	3	main
vette	doc_491521501835_item	3491045	et	3	main
hüpata	doc_491521501835_item	3491046	et	4	main
ja	doc_491521501835_item	3491047	et	3	main
aastal	doc_491521501835_item	3491022	et	3	main
läksime	doc_491521501835_item	3491024	et	3	main
tegime	doc_491521501835_item	3491027	et	3	main
alati	doc_491521501835_item	3491030	et	4	main
me	doc_491521501835_item	3491031	et	4	main
ema	doc_491521501835_item	3491052	et	4	main
ja	doc_491521501835_item	3491053	et	3	main
räägisid	doc_491521501835_item	3491055	et	4	main
nii	doc_491521501835_item	3491056	et	3	main
palju	doc_491521501835_item	3491057	et	4	main
samal	doc_491521501835_item	3491058	et	3	main
ajal	doc_491521501835_item	3491059	et	4	main
kui	doc_491521501835_item	3491060	et	3	main
tädi	doc_491521501835_item	3491064	et	4	main
terve	doc_491521501835_item	3491067	et	4	main
päeva	doc_491521501835_item	3491068	et	4	main
aga	doc_491521501835_item	3491069	et	3	main
tädi	doc_491521501835_item	3491070	et	4	main
nägis	doc_491521501835_item	3491074	et	4	main
ka	doc_491521501835_item	3491075	et	3	main
et	doc_491521501835_item	3491076	et	3	main
väikest	doc_491521501835_item	3491077	et	4	main
üks	doc_491521501835_item	3491084	et	3	main
et	doc_491521501835_item	3491086	et	3	main
ei	doc_491521501835_item	3491088	et	4	main
kes	doc_491521501835_item	3491090	et	4	main
oli	doc_491521501835_item	3491091	et	3	main
ette	doc_491521501835_item	3491103	et	4	main
kõikele	doc_491521501835_item	3491106	et	4	main
tahaksin	doc_491521501835_item	3491145	et	3	main
ainult	doc_491521501835_item	3491146	et	4	main
mida	doc_491521501835_item	3491152	et	4	main
kui	doc_491521501836_item	3491183	et	3	main
kevadel	doc_491521501836_item	3491196	et	4	main
ääres	doc_491521501836_item	3491199	et	4	main
vana	doc_491521501836_item	3491219	et	4	main
kõik	doc_491521501836_item	3491222	et	4	main
ya	doc_491521501836_item	3491224	et	4	main
poisu	doc_491521501836_item	3491232	et	4	main
vaatavad	doc_491521501836_item	3491238	et	4	main
ainult	doc_491521501835_item	3491050	et	4	main
õmblesis	doc_491521501835_item	3491061	et	4	main
nägis	doc_491521501835_item	3491071	et	4	main
ka	doc_491521501835_item	3491082	et	3	main
ma	doc_491521501835_item	3491087	et	3	main
leinud	doc_491521501835_item	3491089	et	4	main
ronis	doc_491521501835_item	3491092	et	4	main
puu	doc_491521501835_item	3491093	et	4	main
teisid	doc_491521501835_item	3491101	et	4	main
tädid	doc_491521501835_item	3491102	et	3	main
ja	doc_491521501835_item	3491144	et	3	main
aga	doc_491521501835_item	3491148	et	3	main
ma	doc_491521501835_item	3491149	et	3	main
läksin	doc_491521501835_item	3491150	et	3	main
ja	doc_491521501835_item	3491151	et	3	main
peitunud	doc_491521501835_item	3491098	et	4	main
puu	doc_491521501835_item	3491099	et	4	main
taga	doc_491521501835_item	3491100	et	4	main
toitu	doc_491521501835_item	3491105	et	4	main
triin	doc_491521501835_item	3491107	et	4	main
ja	doc_491521501835_item	3491108	et	3	main
simon	doc_491521501835_item	3491109	et	4	main
jälgsid	doc_491521501835_item	3491110	et	4	main
teist	doc_491521501835_item	3491111	et	4	main
nad	doc_491521501835_item	3491112	et	3	main
ei	doc_491521501835_item	3491113	et	4	main
näinud	doc_491521501835_item	3491114	et	4	main
et	doc_491521501835_item	3491115	et	3	main
suurest	doc_491521501835_item	3491116	et	4	main
hobusest	doc_491521501835_item	3491117	et	4	main
järgnes	doc_491521501835_item	3491118	et	3	main
neid	doc_491521501835_item	3491119	et	4	main
minu	doc_491521501835_item	3491120	et	3	main
isa	doc_491521501835_item	3491121	et	4	main
oli	doc_491521501835_item	3491122	et	3	main
nii	doc_491521501835_item	3491123	et	3	main
väsinud	doc_491521501835_item	3491124	et	4	main
ja	doc_491521501835_item	3491125	et	3	main
terve	doc_491521501835_item	3491126	et	4	main
päev	doc_491521501835_item	3491127	et	3	main
oli	doc_491521501835_item	3491128	et	3	main
istunud	doc_491521501835_item	3491129	et	4	main
rahulikult	doc_491521501835_item	3491130	et	4	main
põrandal	doc_491521501835_item	3491131	et	3	main
ma	doc_491521501835_item	3491132	et	3	main
ei	doc_491521501835_item	3491133	et	4	main
tahaksinud	doc_491521501835_item	3491134	et	4	main
selles	doc_491521501835_item	3491135	et	4	main
piknikis	doc_491521501835_item	3491136	et	3	main
olla	doc_491521501835_item	3491137	et	3	main
sest	doc_491521501835_item	3491138	et	4	main
teine	doc_491521501835_item	3491139	et	3	main
mul	doc_491521501835_item	3491141	et	3	main
jõgi	doc_491521501836_item	3491179	et	3	main
ääres	doc_491521501836_item	3491180	et	4	main
väike	doc_491521501836_item	3491187	et	4	main
jõgi	doc_491521501836_item	3491198	et	3	main
minu	doc_491521501836_item	3491200	et	3	main
last	doc_491521501836_item	3491204	et	4	main
minu	doc_491521501836_item	3491206	et	3	main
isa	doc_491521501836_item	3491207	et	4	main
magasi	doc_491521501836_item	3491208	et	3	main
minu	doc_491521501836_item	3491209	et	3	main
teised	doc_491521501836_item	3491228	et	4	main
nende	doc_491521501836_item	3491235	et	4	main
hüppavad	doc_491521501836_item	3491242	et	4	main
päeva	doc_491521501836_item	3491244	et	4	main
nähtamatu	doc_491521501836_item	3491245	et	4	main
pilt	doc_491521501837_item	3491276	et	3	main
pildil	doc_491521501837_item	3491277	et	3	main
kevad	doc_491521501837_item	3491280	et	3	main
piknikule	doc_491521501837_item	3491287	et	3	main
12	doc_491521501837_item	3491291	et	2	main
päike	doc_491521501837_item	3491297	et	3	main
sõid	doc_491521501837_item	3491302	et	4	main
ära	doc_491521501837_item	3491303	et	4	main
koht	doc_491521501837_item	3491308	et	3	main
ilus	doc_491521501837_item	3491312	et	4	main
ta	doc_491521501837_item	3491336	et	4	main
tahtis	doc_491521501837_item	3491337	et	3	main
vaadata	doc_491521501837_item	3491338	et	4	main
kaugemale	doc_491521501837_item	3491339	et	4	main
ja	doc_491521501837_item	3491340	et	3	main
ümbrusele	doc_491521501837_item	3491341	et	3	main
mõned	doc_491521501837_item	3491342	et	3	main
lapsed	doc_491521501837_item	3491343	et	3	main
korvi	doc_491521501837_item	3491350	et	4	main
magas	doc_491521501837_item	3491366	et	4	main
ema	doc_491521501837_item	3491372	et	4	main
midagi	doc_491521501837_item	3491409	et	4	main
puhkasid	doc_491521501837_item	3491412	et	4	main
sama	doc_491521501837_item	3491426	et	4	main
pühapäeval	doc_491521501838_item	3491458	et	3	main
on	doc_491521501838_item	3491461	et	4	main
ja	doc_491521501838_item	3491463	et	3	main
ma	doc_491521501838_item	3491473	et	3	main
parte	doc_491521501838_item	3491477	et	4	main
korras	doc_491521501838_item	3491480	et	4	main
aga	doc_491521501838_item	3491481	et	3	main
ma	doc_491521501838_item	3491504	et	3	main
mõtlesin	doc_491521501838_item	3491505	et	3	main
siin	doc_491521501838_item	3491506	et	4	main
on	doc_491521501838_item	3491517	et	4	main
ilma	doc_491521501838_item	3491523	et	4	main
vihastasin	doc_491521501838_item	3491526	et	3	main
nende	doc_491521501838_item	3491527	et	4	main
vaatan	doc_491521501838_item	3491537	et	3	main
nende	doc_491521501838_item	3491549	et	4	main
rohis	doc_491521501838_item	3491554	et	3	main
jänes	doc_491521501838_item	3491564	et	3	main
puu	doc_491521501838_item	3491591	et	4	main
poisid	doc_491521501838_item	3491600	et	4	main
ilmselt	doc_491521501838_item	3491612	et	4	main
väga	doc_491521501838_item	3491613	et	3	main
taga	doc_491521501838_item	3491620	et	4	main
mulle	doc_491521501836_item	3491177	et	4	main
meeldi	doc_491521501836_item	3491178	et	4	main
sallepärast	doc_491521501836_item	3491182	et	4	main
iga	doc_491521501836_item	3491195	et	4	main
vanaisa	doc_491521501836_item	3491201	et	4	main
kõiki	doc_491521501836_item	3491203	et	4	main
mängima	doc_491521501836_item	3491205	et	3	main
ema	doc_491521501836_item	3491214	et	4	main
venndad	doc_491521501836_item	3491220	et	4	main
aega	doc_491521501836_item	3491223	et	4	main
venndad	doc_491521501836_item	3491229	et	4	main
koos	doc_491521501836_item	3491230	et	4	main
naaberi	doc_491521501836_item	3491231	et	3	main
puud	doc_491521501836_item	3491237	et	4	main
ja	doc_491521501836_item	3491241	et	3	main
ühe	doc_491521501836_item	3491246	et	4	main
spioon	doc_491521501836_item	3491247	et	3	main
minu	doc_491521501836_item	3491248	et	3	main
vana	doc_491521501836_item	3491249	et	4	main
õesid	doc_491521501836_item	3491250	et	4	main
süüa	doc_491521501836_item	3491251	et	3	main
ja	doc_491521501836_item	3491252	et	3	main
mängivad	doc_491521501836_item	3491253	et	4	main
teed	doc_491521501836_item	3491254	et	4	main
sööki	doc_491521501836_item	3491255	et	4	main
vahepeal	doc_491521501836_item	3491256	et	3	main
meie	doc_491521501836_item	3491257	et	4	main
naaberi	doc_491521501836_item	3491258	et	3	main
tudrukut	doc_491521501836_item	3491259	et	4	main
näerivad	doc_491521501836_item	3491260	et	4	main
nende	doc_491521501836_item	3491261	et	4	main
ja	doc_491521501836_item	3491262	et	3	main
mina	doc_491521501836_item	3491263	et	4	main
küüasin	doc_491521501836_item	3491264	et	4	main
minu	doc_491521501836_item	3491265	et	3	main
vanaema	doc_491521501836_item	3491266	et	4	main
all	doc_491521501836_item	3491267	et	3	main
tahksin	doc_491521501836_item	3491268	et	4	main
tähelepanu	doc_491521501836_item	3491269	et	4	main
kirjeldus	doc_491521501837_item	3491273	et	4	main
lastega	doc_491521501837_item	3491285	et	3	main
täiskasvanuid	doc_491521501837_item	3491289	et	3	main
ka	doc_491521501837_item	3491296	et	3	main
neil	doc_491521501837_item	3491305	et	4	main
kõrval	doc_491521501837_item	3491313	et	4	main
juures	doc_491521501837_item	3491351	et	4	main
vanaisa	doc_491521501837_item	3491352	et	4	main
haugus	doc_491521501837_item	3491362	et	4	main
koera	doc_491521501837_item	3491363	et	4	main
luges	doc_491521501837_item	3491369	et	3	main
raamatut	doc_491521501837_item	3491370	et	3	main
söömisest	doc_491521501837_item	3491434	et	4	main
loodus	doc_491521501837_item	3491435	et	4	main
andis	doc_491521501837_item	3491436	et	3	main
perele	doc_491521501837_item	3491437	et	3	main
vabadust	doc_491521501837_item	3491438	et	4	main
värske	doc_491521501837_item	3491439	et	4	main
õhku	doc_491521501837_item	3491440	et	4	main
jne	doc_491521501837_item	3491442	et	4	main
jõud	doc_491521501837_item	3491441	et	4	main
ma	doc_491521501837_item	3491443	et	3	main
tahan	doc_491521501837_item	3491444	et	3	main
ka	doc_491521501837_item	3491445	et	3	main
sõita	doc_491521501837_item	3491446	et	3	main
koos	doc_491521501837_item	3491447	et	4	main
perega	doc_491521501837_item	3491448	et	3	main
kuhugi	doc_491521501837_item	3491449	et	4	main
ilusale	doc_491521501837_item	3491450	et	4	main
paigale	doc_491521501837_item	3491451	et	4	main
pildi	doc_491521501837_item	3491272	et	4	main
ilus	doc_491521501837_item	3491279	et	4	main
4	doc_491521501837_item	3491288	et	2	main
ja	doc_491521501837_item	3491290	et	3	main
ning	doc_491521501837_item	3491293	et	3	main
mida	doc_491521501837_item	3491304	et	4	main
oli	doc_491521501837_item	3491314	et	3	main
tiik	doc_491521501837_item	3491316	et	3	main
seal	doc_491521501837_item	3491317	et	4	main
oli	doc_491521501837_item	3491318	et	3	main
2	doc_491521501837_item	3491319	et	2	main
parti	doc_491521501837_item	3491320	et	4	main
üks	doc_491521501837_item	3491321	et	3	main
laps	doc_491521501837_item	3491322	et	4	main
hüppas	doc_491521501837_item	3491323	et	3	main
tiigi	doc_491521501837_item	3491324	et	3	main
juures	doc_491521501837_item	3491325	et	4	main
seal	doc_491521501837_item	3491326	et	4	main
oli	doc_491521501837_item	3491327	et	3	main
ka	doc_491521501837_item	3491328	et	3	main
ühe	doc_491521501837_item	3491330	et	4	main
tahtis	doc_491521501837_item	3491331	et	3	main
ronnida	doc_491521501837_item	3491332	et	4	main
tammepuu	doc_491521501837_item	3491329	et	4	main
puu	doc_491521501837_item	3491333	et	4	main
oksale	doc_491521501837_item	3491334	et	3	main
sest	doc_491521501837_item	3491335	et	4	main
seisis	doc_491521501837_item	3491353	et	4	main
nii	doc_491521501837_item	3491354	et	3	main
sama	doc_491521501837_item	3491355	et	4	main
ja	doc_491521501837_item	3491356	et	3	main
vaatas	doc_491521501837_item	3491357	et	3	main
kaks	doc_491521501837_item	3491358	et	3	main
poissi	doc_491521501837_item	3491359	et	4	main
kakles	doc_491521501837_item	3491360	et	3	main
ja	doc_491521501837_item	3491361	et	3	main
ikka	doc_491521501837_item	3491367	et	4	main
kudus	doc_491521501837_item	3491373	et	4	main
midagi	doc_491521501837_item	3491374	et	4	main
koos	doc_491521501837_item	3491375	et	4	main
teha	doc_491521501837_item	3491410	et	3	main
mis	doc_491521501837_item	3491422	et	4	main
teha	doc_491521501837_item	3491423	et	3	main
lapsed	doc_491521501837_item	3491424	et	3	main
nii	doc_491521501837_item	3491425	et	3	main
sõit	doc_491521501837_item	3491432	et	3	main
ja	doc_491521501837_item	3491433	et	3	main
ja	doc_491521501838_item	3491459	et	3	main
järve	doc_491521501838_item	3491469	et	4	main
tänaval	doc_491521501838_item	3491490	et	4	main
äärde	doc_491521501838_item	3491494	et	4	main
ma	doc_491521501838_item	3491495	et	3	main
nägin	doc_491521501838_item	3491496	et	3	main
et	doc_491521501838_item	3491497	et	3	main
ei	doc_491521501838_item	3491507	et	4	main
ja	doc_491521501838_item	3491510	et	3	main
siin	doc_491521501838_item	3491518	et	4	main
nüüd	doc_491521501838_item	3491530	et	4	main
ma	doc_491521501838_item	3491531	et	3	main
seisan	doc_491521501838_item	3491532	et	3	main
puu	doc_491521501838_item	3491533	et	4	main
all	doc_491521501838_item	3491534	et	3	main
need	doc_491521501838_item	3491539	et	3	main
siin	doc_491521501838_item	3491541	et	4	main
väike	doc_491521501838_item	3491563	et	4	main
ta	doc_491521501838_item	3491575	et	4	main
magab	doc_491521501838_item	3491576	et	3	main
tema	doc_491521501838_item	3491577	et	4	main
puu	doc_491521501838_item	3491586	et	4	main
üks	doc_491521501838_item	3491588	et	3	main
peitab	doc_491521501838_item	3491589	et	4	main
end	doc_491521501838_item	3491590	et	4	main
teised	doc_491521501838_item	3491599	et	4	main
nende	doc_491521501838_item	3491604	et	4	main
ja	doc_491521501838_item	3491606	et	3	main
kõvasti	doc_491521501838_item	3491608	et	3	main
ja	doc_491521501838_item	3491615	et	3	main
ei	doc_491521501838_item	3491616	et	4	main
kuule	doc_491521501838_item	3491617	et	4	main
perekond	doc_491521501838_item	3491622	et	3	main
beebi	doc_491521501837_item	3491379	et	4	main
nägi	doc_491521501837_item	3491380	et	3	main
linnusid	doc_491521501837_item	3491381	et	4	main
ja	doc_491521501837_item	3491382	et	3	main
meeldis	doc_491521501837_item	3491383	et	3	main
2	doc_491521501837_item	3491384	et	2	main
tüdrukut	doc_491521501837_item	3491385	et	3	main
lihtsalt	doc_491521501837_item	3491386	et	4	main
seisis	doc_491521501837_item	3491387	et	4	main
hobune	doc_491521501837_item	3491388	et	4	main
kõrval	doc_491521501837_item	3491389	et	4	main
samuti	doc_491521501837_item	3491390	et	3	main
üks	doc_491521501837_item	3491391	et	3	main
poiss	doc_491521501837_item	3491392	et	3	main
ka	doc_491521501837_item	3491393	et	3	main
istus	doc_491521501837_item	3491394	et	4	main
vaatab	doc_491521501837_item	3491395	et	3	main
pole	doc_491521501837_item	3491397	et	3	main
pildil	doc_491521501837_item	3491396	et	3	main
mingi	doc_491521501837_item	3491398	et	4	main
huvitavat	doc_491521501837_item	3491400	et	4	main
erilist	doc_491521501837_item	3491399	et	4	main
lastel	doc_491521501837_item	3491401	et	4	main
oli	doc_491521501837_item	3491402	et	3	main
natukene	doc_491521501837_item	3491403	et	4	main
igav	doc_491521501837_item	3491404	et	3	main
sest	doc_491521501837_item	3491405	et	4	main
sest	doc_491521501837_item	3491413	et	4	main
nad	doc_491521501837_item	3491414	et	3	main
oli	doc_491521501837_item	3491415	et	3	main
tööga	doc_491521501837_item	3491416	et	3	main
igapäeva	doc_491521501837_item	3491417	et	4	main
eluga	doc_491521501837_item	3491418	et	3	main
ja	doc_491521501837_item	3491419	et	3	main
lastega	doc_491521501837_item	3491420	et	3	main
mängis	doc_491521501837_item	3491427	et	3	main
ikka	doc_491521501837_item	3491428	et	4	main
kirjeldus	doc_491521501838_item	3491455	et	4	main
ilm	doc_491521501838_item	3491460	et	3	main
ja	doc_491521501838_item	3491472	et	3	main
natukene	doc_491521501838_item	3491482	et	4	main
moodis	doc_491521501838_item	3491502	et	4	main
kui	doc_491521501838_item	3491503	et	3	main
ma	doc_491521501838_item	3491511	et	3	main
peale	doc_491521501838_item	3491528	et	4	main
aga	doc_491521501838_item	3491529	et	3	main
isa	doc_491521501838_item	3491544	et	4	main
istuvad	doc_491521501838_item	3491545	et	4	main
lamamistoolidel	doc_491521501838_item	3491546	et	3	main
ja	doc_491521501838_item	3491547	et	3	main
loevad	doc_491521501838_item	3491548	et	3	main
on	doc_491521501838_item	3491556	et	4	main
lamamistoolide	doc_491521501838_item	3491566	et	3	main
perekonna	doc_491521501838_item	3491569	et	4	main
kõrval	doc_491521501838_item	3491570	et	4	main
lamab	doc_491521501838_item	3491571	et	3	main
teine	doc_491521501838_item	3491572	et	3	main
mängivad	doc_491521501838_item	3491579	et	4	main
üks	doc_491521501838_item	3491580	et	3	main
hüppab	doc_491521501838_item	3491581	et	3	main
üle	doc_491521501838_item	3491582	et	3	main
ronib	doc_491521501838_item	3491585	et	3	main
võitlevad	doc_491521501838_item	3491601	et	4	main
koer	doc_491521501838_item	3491602	et	3	main
aga	doc_491521501838_item	3491609	et	3	main
üldiseloomustus	doc_491521501882_item	3491895	et	4	main
2	doc_491521501882_item	3491896	et	2	main
osa	doc_491521501882_item	3491902	et	4	main
ja	doc_491521501882_item	3491909	et	3	main
venestamispoliitika	doc_491521501882_item	3491912	et	4	main
keeles	doc_491521501882_item	3491920	et	4	main
neid	doc_491521501882_item	3491921	et	4	main
üks	doc_491521501882_item	3491942	et	3	main
ajakiri	doc_491521501882_item	3491944	et	3	main
enam	doc_491521501882_item	3491947	et	4	main
ainult	doc_491521501882_item	3491952	et	4	main
4	doc_491521501882_item	3491953	et	2	main
ma	doc_491521501838_item	3491645	et	3	main
arvan	doc_491521501838_item	3491646	et	3	main
et	doc_491521501838_item	3491647	et	3	main
need	doc_491521501838_item	3491648	et	3	main
ka	doc_491521501838_item	3491649	et	3	main
mõtlesid	doc_491521501838_item	3491650	et	4	main
et	doc_491521501838_item	3491651	et	3	main
loodus	doc_491521501838_item	3491652	et	4	main
järve	doc_491521501838_item	3491653	et	4	main
ääres	doc_491521501838_item	3491654	et	4	main
oleks	doc_491521501838_item	3491655	et	3	main
väga	doc_491521501838_item	3491656	et	3	main
vaikne	doc_491521501838_item	3491657	et	3	main
aga	doc_491521501838_item	3491658	et	3	main
ükskõik	doc_491521501838_item	3491659	et	3	main
eestil	doc_491521501838_item	3491660	et	3	main
on	doc_491521501838_item	3491661	et	4	main
palju	doc_491521501838_item	3491662	et	4	main
loodust	doc_491521501838_item	3491663	et	4	main
ja	doc_491521501838_item	3491664	et	3	main
igaüks	doc_491521501838_item	3491665	et	3	main
leiab	doc_491521501838_item	3491666	et	3	main
oma	doc_491521501838_item	3491667	et	4	main
rahulikku	doc_491521501838_item	3491668	et	4	main
kohta	doc_491521501838_item	3491669	et	4	main
pildi	doc_491521501838_item	3491454	et	4	main
täna	doc_491521501838_item	3491456	et	4	main
loodusse	doc_491521501838_item	3491468	et	4	main
äärde	doc_491521501838_item	3491470	et	4	main
tahtsin	doc_491521501838_item	3491474	et	3	main
püsiga	doc_491521501838_item	3491476	et	3	main
kõik	doc_491521501838_item	3491478	et	4	main
oli	doc_491521501838_item	3491479	et	3	main
oli	doc_491521501838_item	3491484	et	3	main
et	doc_491521501838_item	3491485	et	3	main
nii	doc_491521501838_item	3491486	et	3	main
palju	doc_491521501838_item	3491487	et	4	main
autosid	doc_491521501838_item	3491488	et	3	main
kui	doc_491521501838_item	3491491	et	3	main
jõudsin	doc_491521501838_item	3491492	et	3	main
järve	doc_491521501838_item	3491493	et	4	main
inimesi	doc_491521501838_item	3491499	et	4	main
mõtlesid	doc_491521501838_item	3491500	et	4	main
sama	doc_491521501838_item	3491501	et	4	main
ole	doc_491521501838_item	3491508	et	4	main
rahulik	doc_491521501838_item	3491509	et	3	main
saa	doc_491521501838_item	3491513	et	4	main
noored	doc_491521501838_item	3491515	et	3	main
ja	doc_491521501838_item	3491519	et	3	main
ilusat	doc_491521501838_item	3491522	et	3	main
alguses	doc_491521501838_item	3491524	et	4	main
ma	doc_491521501838_item	3491525	et	3	main
varjus	doc_491521501838_item	3491535	et	4	main
ja	doc_491521501838_item	3491536	et	3	main
beebi	doc_491521501838_item	3491550	et	4	main
lamab	doc_491521501838_item	3491551	et	3	main
nii	doc_491521501838_item	3491557	et	3	main
rahul	doc_491521501838_item	3491558	et	4	main
ta	doc_491521501838_item	3491559	et	4	main
vaatab	doc_491521501838_item	3491560	et	3	main
tipusid	doc_491521501838_item	3491561	et	4	main
rohis	doc_491521501838_item	3491562	et	3	main
taga	doc_491521501838_item	3491567	et	4	main
selle	doc_491521501838_item	3491568	et	4	main
isa	doc_491521501838_item	3491573	et	4	main
rohis	doc_491521501838_item	3491574	et	3	main
jõe	doc_491521501838_item	3491583	et	3	main
üks	doc_491521501838_item	3491584	et	3	main
otsa	doc_491521501838_item	3491587	et	4	main
seisab	doc_491521501838_item	3491603	et	3	main
väsinud	doc_491521501838_item	3491614	et	4	main
teeb	doc_491521501838_item	3491621	et	3	main
palju	doc_491521501838_item	3491498	et	4	main
ei	doc_491521501838_item	3491512	et	4	main
jagida	doc_491521501838_item	3491514	et	4	main
perekonnad	doc_491521501838_item	3491516	et	4	main
naudivad	doc_491521501838_item	3491520	et	3	main
ka	doc_491521501838_item	3491521	et	3	main
mida	doc_491521501838_item	3491538	et	4	main
teevad	doc_491521501838_item	3491540	et	3	main
ema	doc_491521501838_item	3491542	et	4	main
ja	doc_491521501838_item	3491543	et	3	main
teki	doc_491521501838_item	3491552	et	4	main
peal	doc_491521501838_item	3491553	et	4	main
ja	doc_491521501838_item	3491555	et	3	main
jookseb	doc_491521501838_item	3491565	et	3	main
pojad	doc_491521501838_item	3491578	et	4	main
taga	doc_491521501838_item	3491592	et	4	main
üks	doc_491521501838_item	3491593	et	3	main
paneb	doc_491521501838_item	3491594	et	3	main
tähele	doc_491521501838_item	3491595	et	3	main
pikksilma	doc_491521501838_item	3491596	et	4	main
läbi	doc_491521501838_item	3491597	et	4	main
ja	doc_491521501838_item	3491598	et	3	main
kõrval	doc_491521501838_item	3491605	et	4	main
haukub	doc_491521501838_item	3491607	et	4	main
isa	doc_491521501838_item	3491610	et	4	main
on	doc_491521501838_item	3491611	et	4	main
midagi	doc_491521501838_item	3491618	et	4	main
minu	doc_491521501838_item	3491619	et	3	main
kivi	doc_491521501838_item	3491623	et	4	main
piknikku	doc_491521501838_item	3491624	et	4	main
need	doc_491521501838_item	3491625	et	3	main
söövad	doc_491521501838_item	3491626	et	4	main
ja	doc_491521501838_item	3491627	et	3	main
joovad	doc_491521501838_item	3491628	et	4	main
väga	doc_491521501838_item	3491629	et	3	main
rikkalikult	doc_491521501838_item	3491630	et	4	main
noor	doc_491521501838_item	3491631	et	3	main
paar	doc_491521501838_item	3491632	et	3	main
tuli	doc_491521501838_item	3491633	et	4	main
hobusega	doc_491521501838_item	3491634	et	4	main
ja	doc_491521501838_item	3491635	et	3	main
nüüd	doc_491521501838_item	3491636	et	4	main
need	doc_491521501838_item	3491637	et	3	main
seisavad	doc_491521501838_item	3491638	et	3	main
ja	doc_491521501838_item	3491639	et	3	main
vaatavad	doc_491521501838_item	3491640	et	4	main
mida	doc_491521501838_item	3491641	et	4	main
teised	doc_491521501838_item	3491642	et	4	main
inimesed	doc_491521501838_item	3491643	et	3	main
teevad	doc_491521501838_item	3491644	et	3	main
eksamitöö	doc_491521501882_item	3491888	et	4	main
eesti	doc_491521501882_item	3491903	et	4	main
meri	doc_491521501882_item	3491907	et	3	main
1	doc_491521501882_item	3491911	et	2	main
raamatuid	doc_491521501882_item	3491922	et	3	main
põrandaalune	doc_491521501882_item	3491941	et	4	main
isetrükk	doc_491521501882_item	3491943	et	3	main
olid	doc_491521501882_item	3491957	et	4	main
ilmuv	doc_491521501882_item	3491964	et	4	main
ajakiri	doc_491521501882_item	3491965	et	3	main
ain	doc_491521501882_item	3491966	et	3	main
kaalep	doc_491521501882_item	3491967	et	4	main
palju	doc_491521501882_item	3491968	et	4	main
kiigi	doc_491521501882_item	3491979	et	4	main
selle	doc_491521501882_item	3491981	et	4	main
vastu	doc_491521501882_item	3491982	et	3	main
ägedalt	doc_491521501882_item	3491983	et	4	main
protesteeriti	doc_491521501882_item	3491984	et	3	main
uus	doc_491521501882_item	3491986	et	3	main
väliseestlased	doc_491521501882_item	3491988	et	3	main
peamiselt	doc_491521501882_item	3491990	et	4	main
toimunutel	doc_491521501882_item	3492002	et	4	main
sept	doc_491521501882_item	3492007	et	4	main
oma	doc_491521501882_item	3492017	et	4	main
laule	doc_491521501882_item	3492018	et	4	main
neile	doc_491521501882_item	3492023	et	4	main
võidelda	doc_491521501882_item	3492032	et	4	main
sümboolika	doc_491521501882_item	3492048	et	4	main
ja	doc_491521501882_item	3492049	et	3	main
riided	doc_491521501882_item	3492050	et	3	main
protestiks	doc_491521501882_item	3492059	et	4	main
tagastamise	doc_491521501882_item	3492068	et	4	main
eesti	doc_491521501882_item	3492074	et	4	main
esimese	doc_491521501882_item	3492076	et	3	main
pühendatud	doc_491521501882_item	3492082	et	4	main
eesti	doc_491521501882_item	3492084	et	4	main
teistele	doc_491521501882_item	3492088	et	4	main
uurimustele	doc_491521501882_item	3492089	et	3	main
kõige	doc_491521501882_item	3492090	et	4	main
tuntuim	doc_491521501882_item	3492091	et	4	main
hõbevalge	doc_491521501882_item	3492092	et	4	main
film	doc_491521501882_item	3492093	et	3	main
kali	doc_491521501882_item	3492094	et	4	main
meteoriitkraateri	doc_491521501882_item	3492095	et	4	main
tekest	doc_491521501882_item	3492096	et	3	main
ka	doc_491521501882_item	3492097	et	3	main
reisikrjad	doc_491521501882_item	3492098	et	4	main
erinevatest	doc_491521501882_item	3492099	et	4	main
maapaikadest	doc_491521501882_item	3492100	et	3	main
ja	doc_491521501882_item	3492101	et	3	main
soome-ugri	doc_491521501882_item	3492102	et	3	main
1	doc_491521501882_item	3491889	et	2	main
ii	doc_491521501882_item	3491892	et	4	main
kirjanduselu	doc_491521501882_item	3491894	et	4	main
laulva	doc_491521501882_item	3491900	et	4	main
revolutsiooni	doc_491521501882_item	3491901	et	4	main
3	doc_491521501882_item	3491905	et	2	main
läbiviimisega	doc_491521501882_item	3491913	et	3	main
rohkem	doc_491521501882_item	3491917	et	4	main
kirjutama	doc_491521501882_item	3491918	et	3	main
tsenseeriti	doc_491521501882_item	3491923	et	3	main
kui	doc_491521501882_item	3491925	et	3	main
täiesti	doc_491521501882_item	3491940	et	3	main
hees	doc_491521501882_item	3491945	et	4	main
hullem	doc_491521501882_item	3491946	et	4	main
ilmus	doc_491521501882_item	3491951	et	4	main
a	doc_491521501882_item	3491959	et	4	main
pe	doc_491521501882_item	3491974	et	4	main
rummo	doc_491521501882_item	3491975	et	4	main
tuhkatriinu	doc_491521501882_item	3491976	et	4	main
eksiilkirjandus	doc_491521501882_item	3491985	et	3	main
kirjutavad	doc_491521501882_item	3491989	et	4	main
eesti	doc_491521501882_item	3491991	et	4	main
saatusest	doc_491521501882_item	3491992	et	4	main
et	doc_491521501882_item	3491993	et	3	main
1980ndate	doc_491521501882_item	3492000	et	4	main
revolutsioonil	doc_491521501882_item	3492006	et	3	main
väike	doc_491521501882_item	3492029	et	4	main
vabadust	doc_491521501882_item	3492039	et	4	main
mitu	doc_491521501882_item	3492051	et	4	main
vabaduse	doc_491521501882_item	3492067	et	4	main
demonstratsiooniks	doc_491521501882_item	3492072	et	4	main
3	doc_491521501882_item	3492073	et	2	main
ajaloole	doc_491521501882_item	3492085	et	4	main
19701980	doc_491521501882_item	3491890	et	2	main
poole	doc_491521501882_item	3491893	et	4	main
öölaulupidude	doc_491521501882_item	3491898	et	4	main
ja	doc_491521501882_item	3491899	et	3	main
taasiseseisvumisel	doc_491521501882_item	3491904	et	3	main
filmiloojana	doc_491521501882_item	3491910	et	3	main
seoses	doc_491521501882_item	3491914	et	4	main
hakati	doc_491521501882_item	3491915	et	3	main
palju	doc_491521501882_item	3491916	et	4	main
vähem	doc_491521501882_item	3491924	et	4	main
saa	doc_491521501882_item	3491949	et	4	main
sellest	doc_491521501882_item	3491950	et	4	main
udi	doc_491521501882_item	3491958	et	4	main
nähtus	doc_491521501882_item	3491987	et	4	main
lõpus	doc_491521501882_item	3492001	et	4	main
oli	doc_491521501882_item	3492009	et	3	main
laulsid	doc_491521501882_item	3492016	et	4	main
andis	doc_491521501882_item	3492022	et	3	main
oma	doc_491521501882_item	3492025	et	4	main
jõusse	doc_491521501882_item	3492026	et	4	main
et	doc_491521501882_item	3492027	et	3	main
ka	doc_491521501882_item	3492028	et	3	main
selles	doc_491521501882_item	3492041	et	4	main
suurelt	doc_491521501882_item	3492043	et	4	main
tuhat	doc_491521501882_item	3492052	et	4	main
inimest	doc_491521501882_item	3492053	et	3	main
venestamise	doc_491521501882_item	3492060	et	4	main
kuid	doc_491521501882_item	3492062	et	4	main
palju	doc_491521501882_item	3492063	et	4	main
kultuuri	doc_491521501882_item	3492070	et	4	main
pärast	doc_491521501882_item	3492077	et	4	main
19701980	doc_491521501883_item	3492351	et	2	main
ii	doc_491521501883_item	3492353	et	4	main
öölaulupidude	doc_491521501883_item	3492359	et	4	main
laulva	doc_491521501883_item	3492361	et	4	main
osa	doc_491521501883_item	3492363	et	4	main
l	doc_491521501883_item	3492367	et	4	main
kirjaniku	doc_491521501883_item	3492369	et	3	main
me	doc_491521501883_item	3492374	et	4	main
tahavad	doc_491521501883_item	3492385	et	3	main
üsna	doc_491521501883_item	3492410	et	3	main
eestlasteks	doc_491521501883_item	3492413	et	4	main
ajaloo	doc_491521501883_item	3492415	et	4	main
raamat	doc_491521501883_item	3492416	et	3	main
l	doc_491521501883_item	3492417	et	4	main
a-te	doc_491521501882_item	3491891	et	3	main
nn	doc_491521501882_item	3491897	et	4	main
l	doc_491521501882_item	3491906	et	4	main
kirjaniku	doc_491521501882_item	3491908	et	3	main
vene	doc_491521501882_item	3491919	et	4	main
eestikeelseid	doc_491521501882_item	3491926	et	3	main
anti	doc_491521501882_item	3491927	et	3	main
välja	doc_491521501882_item	3491928	et	4	main
hulgaliselt	doc_491521501882_item	3491929	et	4	main
ajakirju	doc_491521501882_item	3491930	et	4	main
ja	doc_491521501882_item	3491931	et	3	main
ajalehti	doc_491521501882_item	3491932	et	4	main
levis	doc_491521501882_item	3491933	et	4	main
niisugune	doc_491521501882_item	3491934	et	3	main
nähtus	doc_491521501882_item	3491935	et	4	main
nagu	doc_491521501882_item	3491936	et	3	main
isetrükk	doc_491521501882_item	3491937	et	3	main
poolpõrandaalune	doc_491521501882_item	3491938	et	4	main
ja	doc_491521501882_item	3491939	et	3	main
ei	doc_491521501882_item	3491948	et	4	main
hulgas	doc_491521501882_item	3491956	et	4	main
marm	doc_491521501882_item	3491962	et	4	main
tartus	doc_491521501882_item	3491963	et	3	main
keelatud	doc_491521501882_item	3491973	et	4	main
ja	doc_491521501882_item	3491978	et	3	main
numbrit	doc_491521501882_item	3491954	et	3	main
autorite	doc_491521501882_item	3491955	et	3	main
reinla	doc_491521501882_item	3491960	et	4	main
ajakiri	doc_491521501882_item	3491961	et	3	main
eesti	doc_491521501882_item	3491969	et	4	main
autorite	doc_491521501882_item	3491970	et	3	main
loomingus	doc_491521501882_item	3491971	et	3	main
oli	doc_491521501882_item	3491972	et	3	main
mäng	doc_491521501882_item	3491977	et	3	main
tondiöömaja	doc_491521501882_item	3491980	et	4	main
pöörata	doc_491521501882_item	3491994	et	4	main
selle	doc_491521501882_item	3491995	et	4	main
probleemile	doc_491521501882_item	3491996	et	3	main
öölaulupidudel	doc_491521501882_item	3492003	et	4	main
ja	doc_491521501882_item	3492004	et	3	main
1988	doc_491521501882_item	3492008	et	2	main
psühholoogiline	doc_491521501882_item	3492011	et	4	main
inimesed	doc_491521501882_item	3492013	et	3	main
kogunesid	doc_491521501882_item	3492014	et	4	main
ja	doc_491521501882_item	3492015	et	3	main
emakeeles	doc_491521501882_item	3492020	et	4	main
see	doc_491521501882_item	3492021	et	3	main
usku	doc_491521501882_item	3492024	et	4	main
saab	doc_491521501882_item	3492031	et	3	main
suure	doc_491521501882_item	3492033	et	3	main
arvult	doc_491521501882_item	3492034	et	3	main
rahvaga	doc_491521501882_item	3492035	et	3	main
ja	doc_491521501882_item	3492036	et	3	main
saada	doc_491521501882_item	3492037	et	4	main
oma	doc_491521501882_item	3492038	et	4	main
osales	doc_491521501882_item	3492042	et	3	main
rahvarinne	doc_491521501882_item	3492044	et	3	main
oli	doc_491521501882_item	3492045	et	3	main
kasutusel	doc_491521501882_item	3492046	et	4	main
kogunesid	doc_491521501882_item	3492054	et	4	main
lauluväljakule	doc_491521501882_item	3492055	et	3	main
see	doc_491521501882_item	3492056	et	3	main
oli	doc_491521501882_item	3492057	et	3	main
ka	doc_491521501882_item	3492058	et	3	main
vastu	doc_491521501882_item	3492061	et	3	main
rohkem	doc_491521501882_item	3492064	et	4	main
see	doc_491521501882_item	3492065	et	3	main
oli	doc_491521501882_item	3492066	et	3	main
elujõukuse	doc_491521501882_item	3492071	et	4	main
taasiseseisvumist	doc_491521501882_item	3492078	et	3	main
looming	doc_491521501882_item	3492080	et	3	main
uurimused	doc_491521501882_item	3492104	et	3	main
ühiskonna	doc_491521501882_item	3491997	et	4	main
tähelepanu	doc_491521501882_item	3491998	et	4	main
2	doc_491521501882_item	3491999	et	2	main
laulva	doc_491521501882_item	3492005	et	4	main
suur	doc_491521501882_item	3492010	et	3	main
tähtsus	doc_491521501882_item	3492012	et	4	main
oma	doc_491521501882_item	3492019	et	4	main
rahvas	doc_491521501882_item	3492030	et	4	main
tagasi	doc_491521501882_item	3492040	et	3	main
eesti	doc_491521501882_item	3492047	et	4	main
nõudmine	doc_491521501882_item	3492069	et	4	main
vabariigi	doc_491521501882_item	3492075	et	3	main
presidendi	doc_491521501882_item	3492079	et	4	main
oli	doc_491521501882_item	3492081	et	3	main
nii	doc_491521501882_item	3492083	et	3	main
kui	doc_491521501882_item	3492086	et	3	main
ka	doc_491521501882_item	3492087	et	3	main
folkloori	doc_491521501882_item	3492103	et	4	main
üldiseloomustus	doc_491521501883_item	3492356	et	4	main
3	doc_491521501883_item	3492366	et	2	main
kes	doc_491521501883_item	3492373	et	4	main
ja	doc_491521501883_item	3492376	et	3	main
oleme	doc_491521501883_item	3492378	et	3	main
rohkem	doc_491521501883_item	3492386	et	4	main
kirjutada	doc_491521501883_item	3492387	et	3	main
oma	doc_491521501883_item	3492388	et	4	main
minevikust	doc_491521501883_item	3492389	et	3	main
kirjutavad	doc_491521501883_item	3492393	et	4	main
naisest	doc_491521501883_item	3492395	et	3	main
suur	doc_491521501883_item	3492411	et	3	main
jaan	doc_491521501883_item	3492421	et	3	main
romaanid	doc_491521501883_item	3492423	et	3	main
eksamitöö	doc_491521501883_item	3492349	et	4	main
2	doc_491521501883_item	3492357	et	2	main
revolutsiooni	doc_491521501883_item	3492362	et	4	main
pea	doc_491521501883_item	3492381	et	4	main
mõned	doc_491521501883_item	3492391	et	3	main
tugevast	doc_491521501883_item	3492394	et	4	main
koit	doc_491521501883_item	3492420	et	3	main
krossi	doc_491521501883_item	3492422	et	4	main
hinnad	doc_491521501883_item	3492424	et	3	main
madalad	doc_491521501883_item	3492426	et	3	main
katku	doc_491521501883_item	3492456	et	4	main
luuletaja	doc_491521501883_item	3492462	et	4	main
seaduslikult	doc_491521501883_item	3492477	et	4	main
eestimaa	doc_491521501883_item	3492514	et	4	main
isamaa	doc_491521501883_item	3492519	et	4	main
kett	doc_491521501883_item	3492522	et	4	main
sest	doc_491521501883_item	3492524	et	4	main
ei	doc_491521501883_item	3492530	et	4	main
n	doc_491521501883_item	3492533	et	4	main
l	doc_491521501883_item	3492534	et	4	main
eitab	doc_491521501883_item	3492535	et	3	main
aug	doc_491521501883_item	3492542	et	4	main
oli	doc_491521501883_item	3492544	et	3	main
ajaloost	doc_491521501883_item	3492586	et	4	main
ja	doc_491521501883_item	3492587	et	3	main
ka	doc_491521501883_item	3492588	et	3	main
some-ugri	doc_491521501883_item	3492589	et	3	main
rahvuse	doc_491521501883_item	3492590	et	3	main
ii	doc_491521501884_item	3492601	et	4	main
1	doc_491521501883_item	3492350	et	2	main
ja	doc_491521501883_item	3492360	et	3	main
eesti	doc_491521501883_item	3492364	et	4	main
ja	doc_491521501883_item	3492370	et	3	main
1	doc_491521501883_item	3492372	et	2	main
küsimus	doc_491521501883_item	3492382	et	4	main
inimestele	doc_491521501883_item	3492383	et	3	main
kirjanikud	doc_491521501883_item	3492384	et	3	main
kirjanikud	doc_491521501883_item	3492392	et	3	main
beekmann	doc_491521501883_item	3492396	et	4	main
traat	doc_491521501883_item	3492397	et	3	main
tool	doc_491521501883_item	3492398	et	3	main
ajal	doc_491521501883_item	3492399	et	4	main
oli	doc_491521501883_item	3492400	et	3	main
suur	doc_491521501883_item	3492401	et	3	main
tsensuur	doc_491521501883_item	3492402	et	3	main
ja	doc_491521501883_item	3492403	et	3	main
all	doc_491521501883_item	3492409	et	3	main
meri	doc_491521501883_item	3492418	et	3	main
oli	doc_491521501883_item	3492451	et	3	main
tugevmini	doc_491521501883_item	3492452	et	4	main
j	doc_491521501883_item	3492453	et	4	main
kross	doc_491521501883_item	3492454	et	3	main
kolme	doc_491521501883_item	3492455	et	4	main
üdi	doc_491521501883_item	3492461	et	4	main
teksti	doc_491521501883_item	3492464	et	4	main
väga	doc_491521501883_item	3492465	et	3	main
viisistati	doc_491521501883_item	3492467	et	3	main
ajakirja	doc_491521501883_item	3492478	et	4	main
ja	doc_491521501883_item	3492479	et	3	main
august	doc_491521501883_item	3492483	et	4	main
laul	doc_491521501883_item	3492515	et	4	main
balti	doc_491521501883_item	3492521	et	3	main
tahtsid	doc_491521501883_item	3492526	et	4	main
teada	doc_491521501883_item	3492527	et	3	main
tõde	doc_491521501883_item	3492528	et	4	main
meeldinud	doc_491521501883_item	3492531	et	4	main
kett	doc_491521501883_item	3492548	et	4	main
eesti	doc_491521501883_item	3492585	et	4	main
1	doc_491521501884_item	3492594	et	2	main
a-te	doc_491521501883_item	3492352	et	3	main
poole	doc_491521501883_item	3492354	et	4	main
kirjanduselu	doc_491521501883_item	3492355	et	4	main
nn	doc_491521501883_item	3492358	et	4	main
taasiseseisvumisel	doc_491521501883_item	3492365	et	3	main
meri	doc_491521501883_item	3492368	et	3	main
filmiloojana	doc_491521501883_item	3492371	et	3	main
oleme	doc_491521501883_item	3492375	et	3	main
kust	doc_491521501883_item	3492377	et	4	main
tulnud	doc_491521501883_item	3492379	et	4	main
on	doc_491521501883_item	3492380	et	4	main
aga	doc_491521501883_item	3492390	et	3	main
eesti	doc_491521501883_item	3492404	et	4	main
väljaanded	doc_491521501883_item	3492405	et	3	main
olid	doc_491521501883_item	3492406	et	4	main
rohkem	doc_491521501883_item	3492407	et	4	main
tsensuuri	doc_491521501883_item	3492408	et	4	main
mõju	doc_491521501883_item	3492412	et	4	main
oli	doc_491521501883_item	3492414	et	3	main
olid	doc_491521501883_item	3492425	et	4	main
ja	doc_491521501883_item	3492427	et	3	main
inimesed	doc_491521501883_item	3492428	et	3	main
said	doc_491521501883_item	3492429	et	4	main
osta	doc_491521501883_item	3492430	et	4	main
endale	doc_491521501883_item	3492431	et	4	main
palju	doc_491521501883_item	3492432	et	4	main
1979	doc_491521501883_item	3492434	et	2	main
raamatuid	doc_491521501883_item	3492433	et	3	main
oli	doc_491521501883_item	3492435	et	3	main
svlane	doc_491521501883_item	3492436	et	4	main
dokument	doc_491521501883_item	3492437	et	3	main
vennestamise	doc_491521501883_item	3492438	et	4	main
kohta	doc_491521501883_item	3492439	et	4	main
ja	doc_491521501883_item	3492440	et	3	main
sallepärast	doc_491521501883_item	3492441	et	4	main
eelduseks	doc_491521501883_item	3492442	et	4	main
oli	doc_491521501883_item	3492443	et	3	main
vene	doc_491521501883_item	3492444	et	4	main
keele	doc_491521501883_item	3492445	et	4	main
valdamine	doc_491521501883_item	3492446	et	4	main
siis	doc_491521501883_item	3492447	et	3	main
tsensuur	doc_491521501883_item	3492448	et	3	main
vahel	doc_491521501883_item	3492457	et	4	main
rakvere	doc_491521501883_item	3492458	et	4	main
romaan	doc_491521501883_item	3492459	et	3	main
tema	doc_491521501883_item	3492463	et	4	main
palju	doc_491521501883_item	3492466	et	4	main
tekkib	doc_491521501883_item	3492468	et	3	main
dissidentide	doc_491521501883_item	3492469	et	3	main
liikumine	doc_491521501883_item	3492470	et	4	main
välja	doc_491521501883_item	3492475	et	4	main
mitte	doc_491521501883_item	3492476	et	3	main
23	doc_491521501883_item	3492482	et	2	main
see	doc_491521501883_item	3492500	et	3	main
oli	doc_491521501883_item	3492501	et	3	main
rahulik	doc_491521501883_item	3492502	et	3	main
iseseisvuspüüde	doc_491521501883_item	3492503	et	4	main
siis	doc_491521501883_item	3492504	et	3	main
pärast	doc_491521501883_item	3492505	et	4	main
seda	doc_491521501883_item	3492506	et	3	main
aga	doc_491521501883_item	3492507	et	3	main
hõbe	doc_491521501883_item	3492419	et	3	main
eesti	doc_491521501883_item	3492449	et	4	main
ja	doc_491521501883_item	3492471	et	3	main
nad	doc_491521501883_item	3492472	et	3	main
ka	doc_491521501883_item	3492473	et	3	main
ajalehti	doc_491521501883_item	3492480	et	4	main
11	doc_491521501883_item	3492508	et	2	main
septembril	doc_491521501883_item	3492509	et	3	main
tallinna	doc_491521501883_item	3492516	et	4	main
lauluväljakul	doc_491521501883_item	3492517	et	3	main
paljudele	doc_491521501883_item	3492529	et	3	main
et	doc_491521501883_item	3492532	et	3	main
nn	doc_491521501883_item	3492538	et	4	main
23	doc_491521501883_item	3492541	et	2	main
sõlminud	doc_491521501883_item	3492545	et	4	main
see	doc_491521501883_item	3492546	et	3	main
ajaloost	doc_491521501883_item	3492591	et	4	main
19701980ndate	doc_491521501884_item	3492600	et	4	main
rahvus	doc_491521501884_item	3492605	et	3	main
eesti	doc_491521501884_item	3492607	et	4	main
keeles	doc_491521501884_item	3492608	et	4	main
teistsugune	doc_491521501884_item	3492609	et	3	main
nation	doc_491521501884_item	3492614	et	4	main
kus	doc_491521501884_item	3492618	et	3	main
viiekroonisel	doc_491521501884_item	3492628	et	4	main
ka	doc_491521501884_item	3492650	et	3	main
ja	doc_491521501884_item	3492652	et	3	main
seega	doc_491521501884_item	3492659	et	4	main
rahvani	doc_491521501884_item	3492660	et	3	main
kogu	doc_491521501884_item	3492661	et	4	main
see	doc_491521501884_item	3492662	et	3	main
vähemkättesaadav	doc_491521501884_item	3492681	et	3	main
kui	doc_491521501884_item	3492682	et	3	main
nendel	doc_491521501884_item	3492685	et	4	main
rahvas	doc_491521501884_item	3492697	et	4	main
televisioon	doc_491521501884_item	3492711	et	4	main
ja	doc_491521501884_item	3492712	et	3	main
edasikandjateks	doc_491521501884_item	3492716	et	3	main
on	doc_491521501884_item	3492741	et	4	main
elu	doc_491521501884_item	3492747	et	4	main
ja	doc_491521501884_item	3492748	et	3	main
kuna	doc_491521501884_item	3492784	et	3	main
on	doc_491521501884_item	3492787	et	4	main
olnud	doc_491521501884_item	3492788	et	4	main
mis	doc_491521501884_item	3492801	et	4	main
paneb	doc_491521501884_item	3492802	et	3	main
eesti	doc_491521501884_item	3492803	et	4	main
nimel	doc_491521501884_item	3492810	et	3	main
paul	doc_491521501884_item	3492812	et	4	main
omal	doc_491521501884_item	3492815	et	3	main
võivad	doc_491521501884_item	3492827	et	4	main
tulla	doc_491521501884_item	3492828	et	3	main
kujutatud	doc_491521501884_item	3492833	et	4	main
kirjanduseks	doc_491521501883_item	3492450	et	3	main
jüri	doc_491521501883_item	3492460	et	4	main
andsid	doc_491521501883_item	3492474	et	4	main
2	doc_491521501883_item	3492481	et	2	main
1989	doc_491521501883_item	3492484	et	2	main
a	doc_491521501883_item	3492485	et	4	main
toimub	doc_491521501883_item	3492486	et	3	main
balti	doc_491521501883_item	3492487	et	3	main
kett	doc_491521501883_item	3492488	et	4	main
osales	doc_491521501883_item	3492489	et	3	main
umbes	doc_491521501883_item	3492490	et	4	main
2	doc_491521501883_item	3492491	et	2	main
milj	doc_491521501883_item	3492492	et	4	main
inimest	doc_491521501883_item	3492493	et	3	main
balti	doc_491521501883_item	3492494	et	3	main
kett	doc_491521501883_item	3492495	et	4	main
äratas	doc_491521501883_item	3492496	et	3	main
tähelepanu	doc_491521501883_item	3492497	et	4	main
kogu	doc_491521501883_item	3492498	et	4	main
maailmas	doc_491521501883_item	3492499	et	3	main
1988	doc_491521501883_item	3492510	et	2	main
a	doc_491521501883_item	3492511	et	4	main
toimub	doc_491521501883_item	3492512	et	3	main
lauldi	doc_491521501883_item	3492518	et	3	main
olemast	doc_491521501883_item	3492536	et	4	main
molotovi-ribentropi	doc_491521501883_item	3492539	et	4	main
pakti	doc_491521501883_item	3492540	et	4	main
1939	doc_491521501883_item	3492543	et	2	main
lennart	doc_491521501883_item	3492582	et	4	main
meri	doc_491521501883_item	3492583	et	3	main
kirjutas	doc_491521501883_item	3492584	et	3	main
rahva	doc_491521501884_item	3492595	et	3	main
üldised	doc_491521501884_item	3492598	et	3	main
sõnal	doc_491521501884_item	3492613	et	3	main
keeltes	doc_491521501884_item	3492617	et	3	main
rahatähel	doc_491521501884_item	3492629	et	3	main
hariduse	doc_491521501884_item	3492653	et	3	main
kontrolli	doc_491521501884_item	3492655	et	4	main
alla	doc_491521501884_item	3492656	et	3	main
teave	doc_491521501884_item	3492663	et	3	main
mida	doc_491521501884_item	3492664	et	4	main
aegadel	doc_491521501884_item	3492686	et	3	main
välisturistide	doc_491521501884_item	3492689	et	3	main
oli	doc_491521501884_item	3492693	et	3	main
tunda	doc_491521501884_item	3492699	et	3	main
kultuuri	doc_491521501884_item	3492715	et	4	main
j	doc_491521501884_item	3492729	et	4	main
kunstnik	doc_491521501884_item	3492734	et	3	main
mõttelaadi	doc_491521501884_item	3492749	et	4	main
on	doc_491521501884_item	3492753	et	4	main
rahvus	doc_491521501884_item	3492755	et	3	main
alad	doc_491521501884_item	3492786	et	3	main
all	doc_491521501884_item	3492792	et	3	main
maletamise	doc_491521501884_item	3492817	et	4	main
ta	doc_491521501884_item	3492819	et	4	main
maailmameistriteks	doc_491521501884_item	3492829	et	3	main
viiekroonisel	doc_491521501884_item	3492830	et	4	main
rahatähel	doc_491521501884_item	3492831	et	3	main
üritus	doc_491521501883_item	3492513	et	4	main
laule	doc_491521501883_item	3492520	et	4	main
toimus	doc_491521501883_item	3492523	et	3	main
inimesed	doc_491521501883_item	3492525	et	3	main
salaprotokolli	doc_491521501883_item	3492537	et	4	main
protokoll	doc_491521501883_item	3492547	et	4	main
umbes	doc_491521501883_item	3492550	et	4	main
oli	doc_491521501883_item	3492549	et	3	main
600	doc_491521501883_item	3492551	et	2	main
km	doc_491521501883_item	3492552	et	4	main
vilnusist	doc_491521501883_item	3492553	et	4	main
tallinnani	doc_491521501883_item	3492554	et	4	main
inimeste	doc_491521501883_item	3492555	et	3	main
loosungites	doc_491521501883_item	3492556	et	3	main
oli	doc_491521501883_item	3492557	et	3	main
vabadus	doc_491521501883_item	3492558	et	4	main
baltimaadele	doc_491521501883_item	3492559	et	4	main
aga	doc_491521501883_item	3492560	et	3	main
24	doc_491521501883_item	3492561	et	2	main
dets	doc_491521501883_item	3492562	et	4	main
1989	doc_491521501883_item	3492563	et	2	main
a	doc_491521501883_item	3492564	et	4	main
nl	doc_491521501883_item	3492565	et	4	main
esimest	doc_491521501883_item	3492566	et	4	main
korda	doc_491521501883_item	3492567	et	4	main
tunnistab	doc_491521501883_item	3492568	et	3	main
et	doc_491521501883_item	3492569	et	3	main
on	doc_491521501883_item	3492570	et	4	main
olemas	doc_491521501883_item	3492571	et	4	main
salaprotokoll	doc_491521501883_item	3492572	et	4	main
ja	doc_491521501883_item	3492573	et	3	main
baltimaadele	doc_491521501883_item	3492574	et	4	main
see	doc_491521501883_item	3492575	et	3	main
tähendab	doc_491521501883_item	3492576	et	3	main
hea	doc_491521501883_item	3492577	et	4	main
suhtumine	doc_491521501883_item	3492578	et	4	main
teistest	doc_491521501883_item	3492579	et	4	main
riikidest	doc_491521501883_item	3492580	et	3	main
3	doc_491521501883_item	3492581	et	2	main
ka	doc_491521501884_item	3492834	et	3	main
tema	doc_491521501884_item	3492835	et	4	main
sünnikoht-linn	doc_491521501884_item	3492836	et	3	main
narva	doc_491521501884_item	3492837	et	4	main
kus	doc_491521501884_item	3492838	et	3	main
on	doc_491521501884_item	3492839	et	4	main
tema	doc_491521501884_item	3492840	et	4	main
nimetatud	doc_491521501884_item	3492842	et	4	main
tänav	doc_491521501884_item	3492843	et	4	main
auks	doc_491521501884_item	3492841	et	3	main
tänapäeval	doc_491521501884_item	3492844	et	3	main
korraldatakse	doc_491521501884_item	3492845	et	3	main
ka	doc_491521501884_item	3492846	et	3	main
paul	doc_491521501884_item	3492847	et	4	main
kerese	doc_491521501884_item	3492848	et	4	main
mälestuseks	doc_491521501884_item	3492849	et	4	main
ka	doc_491521501884_item	3492850	et	3	main
temanimelised	doc_491521501884_item	3492851	et	4	main
maleturniirid	doc_491521501884_item	3492852	et	3	main
tegutseb	doc_491521501884_item	3492853	et	3	main
ka	doc_491521501884_item	3492854	et	3	main
temanimeline	doc_491521501884_item	3492855	et	4	main
maleklubi	doc_491521501884_item	3492856	et	4	main
tunnused	doc_491521501884_item	3492599	et	3	main
2	doc_491521501884_item	3492603	et	2	main
on	doc_491521501884_item	3492606	et	4	main
teistes	doc_491521501884_item	3492615	et	4	main
kerest	doc_491521501884_item	3492633	et	4	main
1916-1975	doc_491521501884_item	3492634	et	2	main
tema	doc_491521501884_item	3492635	et	4	main
roll	doc_491521501884_item	3492636	et	3	main
eesti	doc_491521501884_item	3492637	et	4	main
kultuuriloos	doc_491521501884_item	3492638	et	4	main
1	doc_491521501884_item	3492639	et	2	main
peale	doc_491521501884_item	3492640	et	4	main
hruštšovi	doc_491521501884_item	3492641	et	2	main
sulaperioodi	doc_491521501884_item	3492642	et	4	main
võttis	doc_491521501884_item	3492643	et	3	main
riik	doc_491521501884_item	3492644	et	3	main
jälle	doc_491521501884_item	3492645	et	3	main
käte	doc_491521501884_item	3492646	et	3	main
elu	doc_491521501884_item	3492647	et	4	main
valdkonnad	doc_491521501884_item	3492648	et	4	main
sealhulgas	doc_491521501884_item	3492649	et	3	main
eksamitöö	doc_491521501884_item	3492593	et	4	main
kultuuritarbimist	doc_491521501884_item	3492596	et	3	main
iseloomustavad	doc_491521501884_item	3492597	et	4	main
tähendus	doc_491521501884_item	3492610	et	4	main
kui	doc_491521501884_item	3492611	et	3	main
euroopa	doc_491521501884_item	3492616	et	4	main
on	doc_491521501884_item	3492620	et	4	main
seotud	doc_491521501884_item	3492622	et	4	main
on	doc_491521501884_item	3492630	et	4	main
kujutatud	doc_491521501884_item	3492631	et	4	main
paul	doc_491521501884_item	3492632	et	4	main
soovisid	doc_491521501884_item	3492667	et	4	main
kadusid	doc_491521501884_item	3492677	et	4	main
üliõpilasseltsid	doc_491521501884_item	3492678	et	3	main
oli	doc_491521501884_item	3492680	et	3	main
sagenesid	doc_491521501884_item	3492687	et	4	main
baltimaadesse	doc_491521501884_item	3492691	et	4	main
poolel	doc_491521501884_item	3492602	et	4	main
sõnal	doc_491521501884_item	3492604	et	3	main
sellel	doc_491521501884_item	3492612	et	4	main
see	doc_491521501884_item	3492619	et	3	main
valdavalt	doc_491521501884_item	3492621	et	4	main
riikluse	doc_491521501884_item	3492623	et	4	main
ja	doc_491521501884_item	3492624	et	3	main
kodakondsusega	doc_491521501884_item	3492625	et	3	main
missugune	doc_491521501884_item	3492626	et	3	main
3	doc_491521501884_item	3492627	et	2	main
rahvuskultuur	doc_491521501884_item	3492679	et	3	main
nõukogude	doc_491521501884_item	3492683	et	3	main
kultuur	doc_491521501884_item	3492684	et	3	main
ka	doc_491521501884_item	3492688	et	3	main
üks	doc_491521501884_item	3492694	et	3	main
kust	doc_491521501884_item	3492696	et	4	main
raadio	doc_491521501884_item	3492713	et	4	main
sellel	doc_491521501884_item	3492720	et	4	main
rummo	doc_491521501884_item	3492728	et	4	main
sõna	doc_491521501884_item	3492742	et	4	main
rahvus	doc_491521501884_item	3492743	et	3	main
neis	doc_491521501884_item	3492751	et	4	main
sõna	doc_491521501884_item	3492754	et	4	main
seotud	doc_491521501884_item	3492756	et	4	main
läbi	doc_491521501884_item	3492789	et	4	main
aegade	doc_491521501884_item	3492790	et	3	main
eesti	doc_491521501884_item	3492797	et	4	main
midagi	doc_491521501884_item	3492799	et	4	main
sellist	doc_491521501884_item	3492800	et	4	main
iseseisvuse	doc_491521501884_item	3492807	et	4	main
ja	doc_491521501884_item	3492808	et	3	main
kultuuri	doc_491521501884_item	3492651	et	4	main
rangema	doc_491521501884_item	3492654	et	4	main
suurenes	doc_491521501884_item	3492657	et	4	main
tsensuur	doc_491521501884_item	3492658	et	3	main
kultuuritegelased	doc_491521501884_item	3492665	et	3	main
edastada	doc_491521501884_item	3492666	et	3	main
ei	doc_491521501884_item	3492668	et	4	main
jõudnud	doc_491521501884_item	3492669	et	4	main
kohale	doc_491521501884_item	3492670	et	4	main
koolidest	doc_491521501884_item	3492671	et	3	main
vallandati	doc_491521501884_item	3492672	et	3	main
õpetajaid	doc_491521501884_item	3492673	et	4	main
ülikoolid	doc_491521501884_item	3492674	et	3	main
korraldati	doc_491521501884_item	3492675	et	3	main
ümber	doc_491521501884_item	3492676	et	3	main
reisid	doc_491521501884_item	3492690	et	4	main
see	doc_491521501884_item	3492692	et	3	main
osa	doc_491521501884_item	3492695	et	4	main
lääne	doc_491521501884_item	3492701	et	4	main
kultuuri	doc_491521501884_item	3492703	et	4	main
edasikandjaks	doc_491521501884_item	3492704	et	3	main
kirjanduse	doc_491521501884_item	3492705	et	3	main
ja	doc_491521501884_item	3492706	et	3	main
rahvusliku	doc_491521501884_item	3492714	et	3	main
ka	doc_491521501884_item	3492718	et	3	main
ajal	doc_491521501884_item	3492721	et	4	main
said	doc_491521501884_item	3492722	et	4	main
tunnustuse	doc_491521501884_item	3492723	et	4	main
kaplinski	doc_491521501884_item	3492730	et	4	main
jaan	doc_491521501884_item	3492731	et	3	main
kross	doc_491521501884_item	3492732	et	3	main
j	doc_491521501884_item	3492735	et	4	main
2	doc_491521501884_item	3492737	et	2	main
kujunenud	doc_491521501884_item	3492744	et	4	main
välja	doc_491521501884_item	3492745	et	4	main
järgi	doc_491521501884_item	3492750	et	4	main
võõrvõimu	doc_491521501884_item	3492791	et	4	main
minu	doc_491521501884_item	3492793	et	3	main
arvates	doc_491521501884_item	3492794	et	4	main
tähendab	doc_491521501884_item	3492795	et	3	main
sai	doc_491521501884_item	3492698	et	4	main
ka	doc_491521501884_item	3492700	et	3	main
kultuuri	doc_491521501884_item	3492702	et	4	main
teatri	doc_491521501884_item	3492707	et	3	main
kõrvale	doc_491521501884_item	3492708	et	4	main
kujunes	doc_491521501884_item	3492709	et	3	main
ka	doc_491521501884_item	3492710	et	3	main
olid	doc_491521501884_item	3492717	et	4	main
väliseestlased	doc_491521501884_item	3492719	et	3	main
sellised	doc_491521501884_item	3492724	et	4	main
kirjanikud	doc_491521501884_item	3492725	et	3	main
nagu	doc_491521501884_item	3492726	et	3	main
pe	doc_491521501884_item	3492727	et	4	main
unt	doc_491521501884_item	3492733	et	4	main
arrak	doc_491521501884_item	3492736	et	3	main
teistes	doc_491521501884_item	3492738	et	4	main
euroopa	doc_491521501884_item	3492739	et	4	main
keeltes	doc_491521501884_item	3492740	et	3	main
nende	doc_491521501884_item	3492746	et	4	main
keeltes	doc_491521501884_item	3492752	et	3	main
riikluse	doc_491521501884_item	3492757	et	4	main
ja	doc_491521501884_item	3492758	et	3	main
kodakonsusega	doc_491521501884_item	3492759	et	4	main
seepärast	doc_491521501884_item	3492760	et	3	main
et	doc_491521501884_item	3492761	et	3	main
neil	doc_491521501884_item	3492762	et	4	main
oli	doc_491521501884_item	3492763	et	3	main
oma	doc_491521501884_item	3492764	et	4	main
iseseisev	doc_491521501884_item	3492765	et	3	main
riik	doc_491521501884_item	3492766	et	3	main
juba	doc_491521501884_item	3492767	et	3	main
palju	doc_491521501884_item	3492768	et	4	main
aega	doc_491521501884_item	3492769	et	4	main
tagasi	doc_491521501884_item	3492770	et	3	main
eesti	doc_491521501884_item	3492771	et	4	main
keeles	doc_491521501884_item	3492772	et	4	main
on	doc_491521501884_item	3492773	et	4	main
ajaloo	doc_491521501884_item	3492774	et	4	main
sündmuste	doc_491521501884_item	3492775	et	3	main
tõttu	doc_491521501884_item	3492776	et	4	main
sõna	doc_491521501884_item	3492777	et	4	main
rahvus	doc_491521501884_item	3492778	et	3	main
seotud	doc_491521501884_item	3492779	et	4	main
pigem	doc_491521501884_item	3492780	et	3	main
kultuuri	doc_491521501884_item	3492781	et	4	main
ja	doc_491521501884_item	3492782	et	3	main
keelega	doc_491521501884_item	3492783	et	3	main
eesti	doc_491521501884_item	3492785	et	4	main
eksistensi	doc_491521501884_item	3492809	et	4	main
3	doc_491521501884_item	3492811	et	2	main
keres	doc_491521501884_item	3492813	et	3	main
ajal	doc_491521501884_item	3492816	et	4	main
et	doc_491521501884_item	3492821	et	3	main
mitte	doc_491521501884_item	3492822	et	3	main
ainult	doc_491521501884_item	3492823	et	4	main
on	doc_491521501884_item	3492832	et	4	main
eksamitöö	doc_491521501885_item	3493206	et	4	main
nende	doc_491521501885_item	3493222	et	4	main
3	doc_491521501885_item	3493224	et	2	main
mida	doc_491521501885_item	3493225	et	4	main
1	doc_491521501885_item	3493230	et	2	main
kriis	doc_491521501885_item	3493235	et	3	main
tähelepanu	doc_491521501885_item	3493245	et	4	main
mitmete	doc_491521501885_item	3493250	et	4	main
olema	doc_491521501885_item	3493284	et	4	main
eestis	doc_491521501885_item	3493285	et	3	main
gorbatšovi	doc_491521501885_item	3493289	et	2	main
poliitika	doc_491521501885_item	3493290	et	4	main
aidanud	doc_491521501885_item	3493303	et	4	main
keele	doc_491521501885_item	3493337	et	4	main
eestluse	doc_491521501885_item	3493361	et	4	main
elujõud	doc_491521501885_item	3493362	et	4	main
visnapuu	doc_491521501885_item	3493369	et	4	main
ristikivi	doc_491521501885_item	3493377	et	4	main
rahvus	doc_491521501884_item	3492796	et	3	main
keeles	doc_491521501884_item	3492798	et	4	main
inimesi	doc_491521501884_item	3492804	et	4	main
võitlema	doc_491521501884_item	3492805	et	3	main
oma	doc_491521501884_item	3492806	et	4	main
oli	doc_491521501884_item	3492814	et	3	main
maailmameister	doc_491521501884_item	3492818	et	3	main
tõestas	doc_491521501884_item	3492820	et	3	main
vene	doc_491521501884_item	3492824	et	4	main
rahvusest	doc_491521501884_item	3492825	et	4	main
inimesed	doc_491521501884_item	3492826	et	3	main
kultuurilis-poliitilised	doc_491521501885_item	3493209	et	3	main
võimalikuks	doc_491521501885_item	3493212	et	3	main
kiri	doc_491521501885_item	3493229	et	3	main
lõpul	doc_491521501885_item	3493233	et	3	main
kõikides	doc_491521501885_item	3493237	et	4	main
euroopa	doc_491521501885_item	3493239	et	4	main
riigid	doc_491521501885_item	3493240	et	3	main
ameerika	doc_491521501885_item	3493242	et	3	main
kett	doc_491521501885_item	3493257	et	4	main
rohkem	doc_491521501885_item	3493293	et	4	main
kirjutati	doc_491521501885_item	3493322	et	3	main
40	doc_491521501885_item	3493324	et	2	main
ahistamisele	doc_491521501885_item	3493338	et	4	main
ja	doc_491521501885_item	3493339	et	3	main
rahvussuhete	doc_491521501885_item	3493340	et	3	main
loorits	doc_491521501885_item	3493360	et	4	main
teekond	doc_491521501885_item	3493371	et	3	main
m	doc_491521501885_item	3493372	et	4	main
j	doc_491521501885_item	3493374	et	4	main
smuul	doc_491521501885_item	3493375	et	4	main
tegurid	doc_491521501885_item	3493210	et	3	main
taasiseseisvumise	doc_491521501885_item	3493214	et	3	main
aastatel	doc_491521501885_item	3493216	et	4	main
nimetage	doc_491521501885_item	3493218	et	3	main
väliseesti	doc_491521501885_item	3493219	et	4	main
kirjanikke	doc_491521501885_item	3493220	et	3	main
ja	doc_491521501885_item	3493221	et	3	main
endast	doc_491521501885_item	3493227	et	4	main
nsv-s	doc_491521501885_item	3493231	et	3	main
peaaegu	doc_491521501885_item	3493236	et	3	main
sfäärides	doc_491521501885_item	3493238	et	3	main
ja	doc_491521501885_item	3493241	et	3	main
balti	doc_491521501885_item	3493247	et	3	main
venemaa	doc_491521501885_item	3493258	et	4	main
ohverdas	doc_491521501885_item	3493259	et	3	main
et	doc_491521501885_item	3493260	et	3	main
püüti	doc_491521501885_item	3493286	et	3	main
teha	doc_491521501885_item	3493287	et	3	main
omavalitsust	doc_491521501885_item	3493288	et	3	main
jõukohane	doc_491521501885_item	3493294	et	4	main
baltimaadel	doc_491521501885_item	3493295	et	4	main
prooviti	doc_491521501885_item	3493296	et	3	main
kasutada	doc_491521501885_item	3493297	et	3	main
teised	doc_491521501885_item	3493304	et	4	main
alla	doc_491521501885_item	3493323	et	3	main
tuntud	doc_491521501885_item	3493325	et	4	main
haritlast	doc_491521501885_item	3493326	et	3	main
see	doc_491521501885_item	3493327	et	3	main
kiri	doc_491521501885_item	3493328	et	3	main
levis	doc_491521501885_item	3493329	et	4	main
tuhandeis	doc_491521501885_item	3493330	et	3	main
kirjas	doc_491521501885_item	3493333	et	4	main
tähelepanu	doc_491521501885_item	3493335	et	4	main
eesti	doc_491521501885_item	3493336	et	4	main
et	doc_491521501885_item	3493352	et	3	main
ei	doc_491521501885_item	3493355	et	4	main
tohi	doc_491521501885_item	3493356	et	4	main
toimuda	doc_491521501885_item	3493357	et	3	main
2	doc_491521501885_item	3493358	et	2	main
a	doc_491521501885_item	3493363	et	4	main
mägi	doc_491521501885_item	3493364	et	3	main
tuuline	doc_491521501885_item	3493370	et	3	main
1	doc_491521501885_item	3493207	et	2	main
teoseid	doc_491521501885_item	3493223	et	3	main
40	doc_491521501885_item	3493228	et	2	main
oli	doc_491521501885_item	3493234	et	3	main
hakkasid	doc_491521501885_item	3493243	et	4	main
rohkem	doc_491521501885_item	3493244	et	4	main
riikidele	doc_491521501885_item	3493248	et	3	main
nt	doc_491521501885_item	3493252	et	4	main
ei	doc_491521501885_item	3493291	et	4	main
omoni	doc_491521501885_item	3493298	et	4	main
riigid	doc_491521501885_item	3493305	et	3	main
eksemplaris	doc_491521501885_item	3493331	et	3	main
pingestamisele	doc_491521501885_item	3493341	et	4	main
see	doc_491521501885_item	3493342	et	3	main
kiri	doc_491521501885_item	3493343	et	3	main
venestamise	doc_491521501885_item	3493353	et	4	main
poliitika	doc_491521501885_item	3493354	et	4	main
h	doc_491521501885_item	3493368	et	4	main
under	doc_491521501885_item	3493373	et	4	main
öö	doc_491521501885_item	3493379	et	4	main
eksamitöö	doc_491521501886_item	3493906	et	4	main
tegurid	doc_491521501886_item	3493910	et	3	main
võimalikuks	doc_491521501886_item	3493912	et	3	main
1990	doc_491521501886_item	3493915	et	2	main
probleemiga	doc_491521501886_item	3493940	et	4	main
rühmitused	doc_491521501886_item	3493945	et	4	main
tartu	doc_491521501886_item	3493949	et	4	main
vahtre	doc_491521501886_item	3493954	et	4	main
keel	doc_491521501886_item	3493972	et	4	main
koolidest	doc_491521501886_item	3493973	et	3	main
80	doc_491521501886_item	3493974	et	2	main
heisatakse	doc_491521501886_item	3494014	et	3	main
leedus	doc_491521501886_item	3494020	et	4	main
1989	doc_491521501886_item	3494026	et	2	main
kehtetuks	doc_491521501886_item	3494030	et	3	main
90ndatel	doc_491521501886_item	3494034	et	4	main
valitakse	doc_491521501886_item	3494035	et	3	main
ensv	doc_491521501886_item	3494036	et	4	main
mõjusid	doc_491521501886_item	3494039	et	4	main
millised	doc_491521501885_item	3493208	et	3	main
tegid	doc_491521501885_item	3493211	et	4	main
eesti	doc_491521501885_item	3493213	et	4	main
1990	doc_491521501885_item	3493215	et	2	main
2	doc_491521501885_item	3493217	et	2	main
kujutas	doc_491521501885_item	3493226	et	3	main
1980-te	doc_491521501885_item	3493232	et	3	main
pöörama	doc_491521501885_item	3493246	et	3	main
seoses	doc_491521501885_item	3493249	et	4	main
sündmustega	doc_491521501885_item	3493251	et	3	main
23	doc_491521501885_item	3493253	et	2	main
august	doc_491521501885_item	3493254	et	4	main
1989	doc_491521501885_item	3493255	et	2	main
balti	doc_491521501885_item	3493256	et	3	main
balti	doc_491521501885_item	3493261	et	3	main
riigid	doc_491521501885_item	3493262	et	3	main
mitte	doc_491521501885_item	3493263	et	3	main
kunagi	doc_491521501885_item	3493264	et	3	main
ei	doc_491521501885_item	3493265	et	4	main
saa	doc_491521501885_item	3493266	et	4	main
iseseisvaks	doc_491521501885_item	3493267	et	3	main
aga	doc_491521501885_item	3493268	et	3	main
see	doc_491521501885_item	3493269	et	3	main
andis	doc_491521501885_item	3493271	et	3	main
veelgi	doc_491521501885_item	3493270	et	4	main
jõudu	doc_491521501885_item	3493272	et	4	main
tunti	doc_491521501885_item	3493274	et	3	main
euroopas	doc_491521501885_item	3493273	et	3	main
et	doc_491521501885_item	3493275	et	3	main
nsv	doc_491521501885_item	3493276	et	4	main
poliitika	doc_491521501885_item	3493277	et	4	main
ei	doc_491521501885_item	3493278	et	4	main
ole	doc_491521501885_item	3493279	et	4	main
demokraatlik	doc_491521501885_item	3493280	et	3	main
nagu	doc_491521501885_item	3493281	et	3	main
see	doc_491521501885_item	3493282	et	3	main
pidi	doc_491521501885_item	3493283	et	4	main
olnud	doc_491521501885_item	3493292	et	4	main
võimu	doc_491521501885_item	3493299	et	4	main
aga	doc_491521501885_item	3493300	et	3	main
see	doc_491521501885_item	3493301	et	3	main
ei	doc_491521501885_item	3493302	et	4	main
tunnistati	doc_491521501885_item	3493306	et	4	main
baltiriikide	doc_491521501885_item	3493307	et	3	main
iseseisvumist	doc_491521501885_item	3493308	et	3	main
3	doc_491521501885_item	3493309	et	2	main
1980	doc_491521501885_item	3493310	et	2	main
a	doc_491521501885_item	3493311	et	4	main
kirjutati	doc_491521501885_item	3493312	et	3	main
40	doc_491521501885_item	3493313	et	2	main
kirja	doc_491521501885_item	3493314	et	4	main
mis	doc_491521501885_item	3493315	et	4	main
oli	doc_491521501885_item	3493316	et	3	main
avalik	doc_491521501885_item	3493317	et	3	main
kiri	doc_491521501885_item	3493318	et	3	main
eesti	doc_491521501885_item	3493319	et	4	main
nsv-st	doc_491521501885_item	3493320	et	3	main
mida	doc_491521501885_item	3493321	et	4	main
selles	doc_491521501885_item	3493332	et	4	main
juhiti	doc_491521501885_item	3493334	et	3	main
näitas	doc_491521501885_item	3493344	et	3	main
et	doc_491521501885_item	3493345	et	3	main
vene	doc_491521501885_item	3493346	et	4	main
süsteem	doc_491521501885_item	3493347	et	3	main
pole	doc_491521501885_item	3493348	et	3	main
enam	doc_491521501885_item	3493349	et	4	main
kõikvõimas	doc_491521501885_item	3493350	et	3	main
ja	doc_491521501885_item	3493351	et	3	main
o	doc_491521501885_item	3493359	et	4	main
kuidas	doc_491521501885_item	3493365	et	3	main
valitseti	doc_491521501885_item	3493366	et	3	main
eestis	doc_491521501885_item	3493367	et	3	main
k	doc_491521501885_item	3493376	et	4	main
hingede	doc_491521501885_item	3493378	et	3	main
nimetage	doc_491521501886_item	3493918	et	3	main
väliseesti	doc_491521501886_item	3493919	et	4	main
ja	doc_491521501886_item	3493921	et	3	main
3	doc_491521501886_item	3493924	et	2	main
mida	doc_491521501886_item	3493925	et	4	main
poolel	doc_491521501886_item	3493935	et	4	main
tegemist	doc_491521501886_item	3493937	et	4	main
keelepoliitika	doc_491521501886_item	3493942	et	4	main
tartus	doc_491521501886_item	3493947	et	3	main
l	doc_491521501886_item	3493953	et	4	main
olid	doc_491521501886_item	3493955	et	4	main
avatunud	doc_491521501886_item	3493956	et	4	main
ajalehed	doc_491521501886_item	3493960	et	3	main
1986	doc_491521501886_item	3493962	et	2	main
ajakiri	doc_491521501886_item	3493963	et	3	main
vikerkaar	doc_491521501886_item	3493964	et	3	main
kus	doc_491521501886_item	3493965	et	3	main
kirjutati	doc_491521501886_item	3493966	et	3	main
vabameelseid	doc_491521501886_item	3493967	et	3	main
artikleid	doc_491521501886_item	3493968	et	3	main
70ndatel	doc_491521501886_item	3493969	et	4	main
likvideeriti	doc_491521501886_item	3493970	et	3	main
kultuurilis-poliitilised	doc_491521501886_item	3493909	et	3	main
aastatel	doc_491521501886_item	3493916	et	4	main
kirjanikke	doc_491521501886_item	3493920	et	3	main
nende	doc_491521501886_item	3493922	et	4	main
teoseid	doc_491521501886_item	3493923	et	3	main
lõpus	doc_491521501886_item	3493933	et	4	main
1970-80ndate	doc_491521501886_item	3493941	et	4	main
nt	doc_491521501886_item	3493946	et	4	main
m	doc_491521501886_item	3493951	et	4	main
valgevene	doc_491521501886_item	3493971	et	4	main
üliõpilas	doc_491521501886_item	3493976	et	4	main
eesti	doc_491521501886_item	3494009	et	4	main
lubati	doc_491521501886_item	3494027	et	3	main
ülemnõukogu	doc_491521501886_item	3494037	et	4	main
1	doc_491521501886_item	3493907	et	2	main
eesti	doc_491521501886_item	3493913	et	4	main
taasiseseisvumise	doc_491521501886_item	3493914	et	3	main
saj	doc_491521501886_item	3493932	et	4	main
olid	doc_491521501886_item	3493943	et	4	main
noor	doc_491521501886_item	3493948	et	3	main
laar	doc_491521501886_item	3493952	et	3	main
tegevust	doc_491521501886_item	3493958	et	4	main
uued	doc_491521501886_item	3493959	et	3	main
ersp	doc_491521501886_item	3494008	et	4	main
rahvuslik	doc_491521501886_item	3494010	et	3	main
partei	doc_491521501886_item	3494012	et	4	main
im-õigus	doc_491521501886_item	3494029	et	2	main
molotov-ribbendropi	doc_491521501886_item	3494032	et	4	main
sündmused	doc_491521501886_item	3494041	et	3	main
a	doc_491521501886_item	3494043	et	4	main
alliksaar	doc_491521501886_item	3494067	et	4	main
masing	doc_491521501886_item	3494068	et	4	main
jacobson	doc_491521501886_item	3494069	et	4	main
juhan	doc_491521501886_item	3494070	et	3	main
smuul	doc_491521501886_item	3494071	et	4	main
3	doc_491521501886_item	3494072	et	2	main
haritlased	doc_491521501886_item	3494073	et	3	main
teadlased	doc_491521501886_item	3494074	et	3	main
kirjutasid	doc_491521501886_item	3494075	et	4	main
kirju	doc_491521501886_item	3494076	et	4	main
palvedega	doc_491521501886_item	3494077	et	4	main
lõpetada	doc_491521501886_item	3494078	et	3	main
venestuspoliitikat	doc_491521501886_item	3494079	et	3	main
millised	doc_491521501886_item	3493908	et	3	main
tegid	doc_491521501886_item	3493911	et	4	main
2	doc_491521501886_item	3493917	et	2	main
kujutas	doc_491521501886_item	3493926	et	3	main
endast	doc_491521501886_item	3493927	et	4	main
40	doc_491521501886_item	3493928	et	2	main
kiri	doc_491521501886_item	3493929	et	3	main
1	doc_491521501886_item	3493930	et	2	main
20	doc_491521501886_item	3493931	et	2	main
ii	doc_491521501886_item	3493934	et	4	main
oli	doc_491521501886_item	3493936	et	3	main
eesti	doc_491521501886_item	3493938	et	4	main
keele	doc_491521501886_item	3493939	et	4	main
avatud	doc_491521501886_item	3493944	et	4	main
liidrid	doc_491521501886_item	3493950	et	3	main
oma	doc_491521501886_item	3493957	et	4	main
nt	doc_491521501886_item	3493961	et	4	main
ndad	doc_491521501886_item	3493975	et	4	main
ja	doc_491521501886_item	3493977	et	3	main
õpilasrahutused	doc_491521501886_item	3493978	et	4	main
80	doc_491521501886_item	3493979	et	2	main
ndate	doc_491521501886_item	3493980	et	4	main
lõpp	doc_491521501886_item	3493981	et	3	main
rahvariide	doc_491521501886_item	3493982	et	4	main
loomise	doc_491521501886_item	3493983	et	4	main
idee	doc_491521501886_item	3493984	et	4	main
1985	doc_491521501886_item	3493985	et	2	main
tuli	doc_491521501886_item	3493986	et	4	main
võimule	doc_491521501886_item	3493987	et	3	main
gorbatšov	doc_491521501886_item	3493988	et	2	main
kes	doc_491521501886_item	3493989	et	4	main
soovis	doc_491521501886_item	3493990	et	4	main
nõukogude	doc_491521501886_item	3493991	et	3	main
süsteemi	doc_491521501886_item	3493992	et	4	main
säilitada	doc_491521501886_item	3493993	et	3	main
aga	doc_491521501886_item	3493994	et	3	main
reformida	doc_491521501886_item	3493995	et	4	main
1988	doc_491521501886_item	3493997	et	2	main
öölälupeod	doc_491521501886_item	3493998	et	4	main
perestroika	doc_491521501886_item	3493996	et	4	main
savisaar	doc_491521501886_item	3493999	et	3	main
tegi	doc_491521501886_item	3494000	et	4	main
ettepaneku	doc_491521501886_item	3494001	et	3	main
perestroika	doc_491521501886_item	3494002	et	4	main
toetuseks	doc_491521501886_item	3494003	et	4	main
korraldada	doc_491521501886_item	3494004	et	3	main
rahvarinde	doc_491521501886_item	3494005	et	4	main
paralleelselt	doc_491521501886_item	3494006	et	4	main
pikas	doc_491521501886_item	3494017	et	4	main
hermanis	doc_491521501886_item	3494018	et	4	main
ja	doc_491521501886_item	3494019	et	3	main
eestile	doc_491521501886_item	3494028	et	3	main
tegutses	doc_491521501886_item	3494007	et	3	main
sõltumatuse	doc_491521501886_item	3494011	et	4	main
1989	doc_491521501886_item	3494013	et	2	main
esimest	doc_491521501886_item	3494015	et	4	main
korda	doc_491521501886_item	3494016	et	4	main
gediminase	doc_491521501886_item	3494021	et	4	main
tornis	doc_491521501886_item	3494022	et	3	main
riigilipud	doc_491521501886_item	3494023	et	3	main
tekkis	doc_491521501886_item	3494024	et	3	main
interrinne	doc_491521501886_item	3494025	et	3	main
tunnistati	doc_491521501886_item	3494031	et	4	main
pakt	doc_491521501886_item	3494033	et	3	main
järgmised	doc_491521501886_item	3494040	et	3	main
1968	doc_491521501886_item	3494042	et	2	main
tšehhi	doc_491521501886_item	3494044	et	2	main
sündmused	doc_491521501886_item	3494045	et	3	main
kultuuri	doc_491521501886_item	3494046	et	4	main
piir	doc_491521501886_item	3494048	et	3	main
stagneerimise	doc_491521501886_item	3494047	et	4	main
1980ndate	doc_491521501886_item	3494049	et	4	main
lõpus	doc_491521501886_item	3494050	et	4	main
maaelu	doc_491521501886_item	3494051	et	4	main
kriis	doc_491521501886_item	3494052	et	3	main
hirm	doc_491521501886_item	3494054	et	3	main
2	doc_491521501886_item	3494055	et	2	main
tuumakatastroofi	doc_491521501886_item	3494053	et	4	main
raimond	doc_491521501886_item	3494056	et	4	main
kolk	doc_491521501886_item	3494057	et	3	main
luuletaja	doc_491521501886_item	3494058	et	4	main
ristikivi	doc_491521501886_item	3494059	et	4	main
hingede	doc_491521501886_item	3494060	et	3	main
öö	doc_491521501886_item	3494061	et	4	main
kangro	doc_491521501886_item	3494062	et	4	main
tartu	doc_491521501886_item	3494063	et	4	main
kirjanik	doc_491521501886_item	3494064	et	3	main
maria	doc_491521501886_item	3494065	et	4	main
under	doc_491521501886_item	3494066	et	4	main
veel	doc_491521501886_item	3494038	et	4	main
1	doc_491521501887_item	3494824	et	2	main
tegid	doc_491521501887_item	3494828	et	4	main
kirjanikke	doc_491521501887_item	3494837	et	3	main
a	doc_491521501887_item	3494849	et	4	main
eesti	doc_491521501887_item	3494853	et	4	main
võib	doc_491521501887_item	3494854	et	3	main
üle	doc_491521501887_item	3494855	et	3	main
minna	doc_491521501887_item	3494856	et	3	main
isemajandamise	doc_491521501887_item	3494857	et	3	main
süsteemile	doc_491521501887_item	3494858	et	3	main
1988	doc_491521501887_item	3494859	et	2	main
sini-must-valget	doc_491521501887_item	3494865	et	3	main
kultuurilis-poliitilised	doc_491521501887_item	3494826	et	3	main
võimalikuks	doc_491521501887_item	3494829	et	3	main
ja	doc_491521501887_item	3494838	et	3	main
teoseid	doc_491521501887_item	3494840	et	3	main
tekib	doc_491521501887_item	3494850	et	3	main
idee	doc_491521501887_item	3494851	et	4	main
linnavalitsus	doc_491521501887_item	3494862	et	3	main
oleks	doc_491521501887_item	3494891	et	3	main
1988	doc_491521501887_item	3494897	et	2	main
a	doc_491521501887_item	3494911	et	4	main
võetakse	doc_491521501887_item	3494912	et	3	main
eestis	doc_491521501887_item	3494913	et	3	main
vastu	doc_491521501887_item	3494914	et	3	main
1989	doc_491521501887_item	3494929	et	2	main
ungari	doc_491521501887_item	3494933	et	4	main
riik	doc_491521501887_item	3494934	et	3	main
esimesena	doc_491521501887_item	3494935	et	3	main
saab	doc_491521501887_item	3494936	et	3	main
iseseisvust	doc_491521501887_item	3494937	et	4	main
hakatakse	doc_491521501887_item	3494939	et	3	main
siis	doc_491521501887_item	3494944	et	3	main
kus	doc_491521501887_item	3494949	et	3	main
1990	doc_491521501887_item	3494957	et	2	main
a	doc_491521501887_item	3494958	et	4	main
eesti	doc_491521501887_item	3494962	et	4	main
eesti	doc_491521501887_item	3494964	et	4	main
a	doc_491521501887_item	3494970	et	4	main
välja	doc_491521501887_item	3494973	et	4	main
omandireform	doc_491521501887_item	3495005	et	3	main
võetud	doc_491521501887_item	3495017	et	4	main
1991	doc_491521501887_item	3495018	et	2	main
iseseisvust	doc_491521501887_item	3495024	et	4	main
tunnistab	doc_491521501887_item	3495028	et	3	main
läti	doc_491521501887_item	3495030	et	4	main
leedu	doc_491521501887_item	3495032	et	4	main
riikide	doc_491521501887_item	3495033	et	3	main
iseseisvumist	doc_491521501887_item	3495034	et	3	main
enne	doc_491521501887_item	3495035	et	4	main
seda	doc_491521501887_item	3495036	et	3	main
eestis	doc_491521501887_item	3495047	et	3	main
eesti	doc_491521501887_item	3495049	et	4	main
sept	doc_491521501887_item	3495061	et	4	main
presidendiks	doc_491521501887_item	3495066	et	4	main
ja	doc_491521501887_item	3495070	et	3	main
valitakse	doc_491521501887_item	3495071	et	3	main
1993	doc_491521501887_item	3495074	et	2	main
nõukogu	doc_491521501887_item	3495079	et	4	main
täisliige	doc_491521501887_item	3495080	et	4	main
u	doc_491521501887_item	3495129	et	4	main
masing	doc_491521501887_item	3495130	et	4	main
u	doc_491521501887_item	3495138	et	4	main
pidevaks	doc_491521501887_item	3495144	et	4	main
tegurid	doc_491521501887_item	3494827	et	3	main
taasiseseisvumise	doc_491521501887_item	3494831	et	3	main
1990	doc_491521501887_item	3494832	et	2	main
2	doc_491521501887_item	3494834	et	2	main
a	doc_491521501887_item	3494860	et	4	main
a	doc_491521501887_item	3494868	et	4	main
nõukogude	doc_491521501887_item	3494892	et	3	main
septembris	doc_491521501887_item	3494896	et	3	main
toimub	doc_491521501887_item	3494899	et	3	main
üritus	doc_491521501887_item	3494902	et	4	main
eksamitöö	doc_491521501887_item	3494823	et	4	main
eesti	doc_491521501887_item	3494830	et	4	main
aastatel	doc_491521501887_item	3494833	et	4	main
nimetage	doc_491521501887_item	3494835	et	3	main
3	doc_491521501887_item	3494841	et	2	main
kujutas	doc_491521501887_item	3494843	et	3	main
40	doc_491521501887_item	3494845	et	2	main
kiri	doc_491521501887_item	3494846	et	3	main
1987	doc_491521501887_item	3494848	et	2	main
et	doc_491521501887_item	3494852	et	3	main
tartu	doc_491521501887_item	3494861	et	4	main
kasutada	doc_491521501887_item	3494864	et	3	main
1988	doc_491521501887_item	3494867	et	2	main
baltikumis	doc_491521501887_item	3494890	et	4	main
valitsema	doc_491521501887_item	3494895	et	3	main
a	doc_491521501887_item	3494898	et	4	main
tallinna	doc_491521501887_item	3494900	et	4	main
eestimaa	doc_491521501887_item	3494903	et	4	main
e	doc_491521501887_item	3494917	et	4	main
iseseisvusdeklaratsioon	doc_491521501887_item	3494918	et	3	main
1989	doc_491521501887_item	3494919	et	2	main
a	doc_491521501887_item	3494920	et	4	main
riputatakse	doc_491521501887_item	3494921	et	3	main
tornile	doc_491521501887_item	3494922	et	3	main
pea	doc_491521501887_item	3495174	et	4	main
kirjutama	doc_491521501887_item	3495175	et	3	main
ei	doc_491521501887_item	3495173	et	4	main
ainult	doc_491521501887_item	3495176	et	4	main
e	doc_491521501887_item	3495177	et	4	main
keeles	doc_491521501887_item	3495178	et	4	main
ja	doc_491521501887_item	3495179	et	3	main
rääkima	doc_491521501887_item	3495180	et	3	main
aga	doc_491521501887_item	3495181	et	3	main
on	doc_491521501887_item	3495182	et	4	main
vaja	doc_491521501887_item	3495183	et	4	main
ka	doc_491521501887_item	3495184	et	3	main
eesti	doc_491521501887_item	3495185	et	4	main
keeles	doc_491521501887_item	3495186	et	4	main
et	doc_491521501887_item	3495187	et	3	main
nad	doc_491521501887_item	3495188	et	3	main
saaksid	doc_491521501887_item	3495189	et	4	main
õppida	doc_491521501887_item	3495190	et	3	main
ka	doc_491521501887_item	3495191	et	3	main
eesti	doc_491521501887_item	3495192	et	4	main
keeles	doc_491521501887_item	3495193	et	4	main
millised	doc_491521501887_item	3494825	et	3	main
väliseesti	doc_491521501887_item	3494836	et	4	main
nende	doc_491521501887_item	3494839	et	4	main
mida	doc_491521501887_item	3494842	et	4	main
endast	doc_491521501887_item	3494844	et	4	main
1	doc_491521501887_item	3494847	et	2	main
lubab	doc_491521501887_item	3494863	et	3	main
lippu	doc_491521501887_item	3494866	et	4	main
oli	doc_491521501887_item	3494869	et	3	main
ekp	doc_491521501887_item	3494870	et	4	main
pleenum	doc_491521501887_item	3494871	et	3	main
kus	doc_491521501887_item	3494872	et	3	main
avaldatakse	doc_491521501887_item	3494873	et	3	main
rahva	doc_491521501887_item	3494874	et	3	main
rinnet	doc_491521501887_item	3494875	et	3	main
toetamist	doc_491521501887_item	3494876	et	4	main
partei	doc_491521501887_item	3494877	et	4	main
toetab	doc_491521501887_item	3494878	et	3	main
rahva	doc_491521501887_item	3494879	et	3	main
rinnet	doc_491521501887_item	3494880	et	3	main
ja	doc_491521501887_item	3494881	et	3	main
ei	doc_491521501887_item	3494882	et	4	main
toeta	doc_491521501887_item	3494883	et	4	main
interrinde	doc_491521501887_item	3494884	et	4	main
tegevust	doc_491521501887_item	3494885	et	4	main
eestis	doc_491521501887_item	3494886	et	3	main
interrinne	doc_491521501887_item	3494887	et	3	main
tahtsid	doc_491521501887_item	3494888	et	4	main
et	doc_491521501887_item	3494889	et	3	main
edasi	doc_491521501887_item	3494894	et	3	main
lauluväljaluk	doc_491521501887_item	3494901	et	4	main
laul	doc_491521501887_item	3494904	et	4	main
kus	doc_491521501887_item	3494905	et	3	main
lauldakse	doc_491521501887_item	3494906	et	3	main
isamaalaule	doc_491521501887_item	3494907	et	4	main
16	doc_491521501887_item	3494908	et	2	main
sini-must-valge	doc_491521501887_item	3494927	et	4	main
lipp	doc_491521501887_item	3494928	et	3	main
a	doc_491521501887_item	3494930	et	4	main
astub	doc_491521501887_item	3494931	et	3	main
nl-st	doc_491521501887_item	3494932	et	3	main
vabariigi	doc_491521501887_item	3494942	et	3	main
piiriprobleem	doc_491521501887_item	3494946	et	3	main
vaidlema	doc_491521501887_item	3494948	et	3	main
piir	doc_491521501887_item	3494952	et	3	main
24	doc_491521501887_item	3494959	et	2	main
kongress	doc_491521501887_item	3494963	et	3	main
kodanikud	doc_491521501887_item	3494965	et	3	main
kulud	doc_491521501887_item	3495000	et	4	main
varasid	doc_491521501887_item	3495007	et	3	main
tagastama	doc_491521501887_item	3495008	et	3	main
nendele	doc_491521501887_item	3495009	et	4	main
vara	doc_491521501887_item	3495014	et	4	main
venemaal	doc_491521501887_item	3495037	et	4	main
saab	doc_491521501887_item	3495038	et	3	main
uueks	doc_491521501887_item	3495039	et	3	main
a	doc_491521501887_item	3495044	et	4	main
kasutusele	doc_491521501887_item	3495048	et	4	main
kroon	doc_491521501887_item	3495050	et	3	main
1992	doc_491521501887_item	3495062	et	2	main
esimeseks	doc_491521501887_item	3495065	et	3	main
valitakse	doc_491521501887_item	3495067	et	3	main
mais	doc_491521501887_item	3495073	et	4	main
lahkunud	doc_491521501887_item	3495086	et	4	main
jacobson	doc_491521501887_item	3495131	et	4	main
j	doc_491521501887_item	3495134	et	4	main
smuul	doc_491521501887_item	3495135	et	4	main
vaarandi	doc_491521501887_item	3495136	et	4	main
on	doc_491521501887_item	3495142	et	4	main
1990ndani	doc_491521501887_item	3495146	et	4	main
aastani	doc_491521501887_item	3495147	et	3	main
sahtlikirjandus	doc_491521501887_item	3495148	et	3	main
luuletaja	doc_491521501887_item	3495154	et	4	main
eksamitöö	doc_491521501939_item	3495393	et	4	main
vastake	doc_491521501939_item	3495398	et	3	main
kirjas	doc_491521501939_item	3495400	et	4	main
umbes	doc_491521501939_item	3495403	et	4	main
sõna	doc_491521501939_item	3495405	et	4	main
ennast	doc_491521501939_item	3495407	et	4	main
haridus	doc_491521501939_item	3495409	et	3	main
kuu	doc_491521501939_item	3495430	et	4	main
vajatakse	doc_491521501939_item	3495436	et	4	main
pakkijaid	doc_491521501939_item	3495441	et	4	main
eesti	doc_491521501939_item	3495444	et	4	main
ja	doc_491521501939_item	3495445	et	3	main
süsteem	doc_491521501887_item	3494893	et	3	main
nov	doc_491521501887_item	3494909	et	4	main
1988	doc_491521501887_item	3494910	et	2	main
eesti	doc_491521501887_item	3494941	et	4	main
peab	doc_491521501887_item	3494950	et	4	main
ev	doc_491521501887_item	3494953	et	4	main
ja	doc_491521501887_item	3494954	et	3	main
venemaa	doc_491521501887_item	3494955	et	4	main
dets	doc_491521501887_item	3494960	et	4	main
1990	doc_491521501887_item	3494969	et	2	main
kuulutatakse	doc_491521501887_item	3494972	et	3	main
oma	doc_491521501887_item	3495001	et	4	main
tulud	doc_491521501887_item	3495002	et	3	main
viiakse	doc_491521501887_item	3495003	et	3	main
kellelt	doc_491521501887_item	3495010	et	4	main
nl	doc_491521501887_item	3495011	et	4	main
ebaõiglaselt	doc_491521501887_item	3495015	et	4	main
ära	doc_491521501887_item	3495016	et	4	main
suveräänsuse	doc_491521501887_item	3494915	et	4	main
deklaratsioon	doc_491521501887_item	3494916	et	3	main
hermann	doc_491521501887_item	3494924	et	4	main
räägima	doc_491521501887_item	3494940	et	4	main
tekib	doc_491521501887_item	3494945	et	3	main
hakatakse	doc_491521501887_item	3494947	et	3	main
vahel	doc_491521501887_item	3494956	et	4	main
valitakse	doc_491521501887_item	3494961	et	3	main
kuuluvad	doc_491521501887_item	3494966	et	4	main
siia	doc_491521501887_item	3494967	et	4	main
läbi	doc_491521501887_item	3495004	et	4	main
ajal	doc_491521501887_item	3495012	et	4	main
oli	doc_491521501887_item	3495013	et	3	main
a	doc_491521501887_item	3495019	et	4	main
6	doc_491521501887_item	3495020	et	2	main
ev	doc_491521501887_item	3495023	et	4	main
venemaa	doc_491521501887_item	3495025	et	4	main
b	doc_491521501887_item	3495041	et	4	main
tuleb	doc_491521501887_item	3495046	et	3	main
olid	doc_491521501887_item	3495052	et	4	main
vastu	doc_491521501887_item	3495057	et	3	main
ev	doc_491521501887_item	3495058	et	4	main
põhiseaduse	doc_491521501887_item	3495059	et	3	main
20	doc_491521501887_item	3495060	et	2	main
lennart	doc_491521501887_item	3495068	et	4	main
riigikogu	doc_491521501887_item	3495072	et	4	main
a	doc_491521501887_item	3495075	et	4	main
eesti	doc_491521501887_item	3495076	et	4	main
saab	doc_491521501887_item	3495077	et	3	main
maria	doc_491521501887_item	3495123	et	4	main
under	doc_491521501887_item	3495124	et	4	main
pikk	doc_491521501887_item	3494923	et	4	main
esimest	doc_491521501887_item	3494925	et	4	main
korda	doc_491521501887_item	3494926	et	4	main
kui	doc_491521501887_item	3494938	et	3	main
iseseisvumisest	doc_491521501887_item	3494943	et	3	main
olema	doc_491521501887_item	3494951	et	4	main
märtsis	doc_491521501887_item	3494968	et	3	main
eestis	doc_491521501887_item	3494971	et	3	main
nn	doc_491521501887_item	3494974	et	4	main
ülemineku	doc_491521501887_item	3494975	et	3	main
periood	doc_491521501887_item	3494976	et	3	main
8	doc_491521501887_item	3494977	et	2	main
mail	doc_491521501887_item	3494978	et	4	main
võetakse	doc_491521501887_item	3494979	et	3	main
uuesti	doc_491521501887_item	3494980	et	3	main
kasutusele	doc_491521501887_item	3494981	et	4	main
ev	doc_491521501887_item	3494982	et	4	main
nimetust	doc_491521501887_item	3494983	et	4	main
uut	doc_491521501887_item	3494984	et	3	main
valitsust	doc_491521501887_item	3494985	et	4	main
hakkab	doc_491521501887_item	3494986	et	3	main
juhima	doc_491521501887_item	3494987	et	4	main
edgar	doc_491521501887_item	3494988	et	4	main
savisaar	doc_491521501887_item	3494989	et	3	main
kes	doc_491521501887_item	3494990	et	4	main
viib	doc_491521501887_item	3494991	et	3	main
läbi	doc_491521501887_item	3494992	et	4	main
majandusreforme	doc_491521501887_item	3494993	et	3	main
ev	doc_491521501887_item	3494994	et	4	main
saab	doc_491521501887_item	3494995	et	3	main
oma	doc_491521501887_item	3494996	et	4	main
iseseisva	doc_491521501887_item	3494997	et	3	main
eelarve	doc_491521501887_item	3494998	et	4	main
oma	doc_491521501887_item	3494999	et	4	main
hakasid	doc_491521501887_item	3495006	et	4	main
sept	doc_491521501887_item	3495021	et	4	main
tunnustatakse	doc_491521501887_item	3495022	et	3	main
poolest	doc_491521501887_item	3495026	et	4	main
ka	doc_491521501887_item	3495029	et	3	main
ja	doc_491521501887_item	3495031	et	3	main
jeltsin	doc_491521501887_item	3495042	et	4	main
1992	doc_491521501887_item	3495043	et	2	main
enne	doc_491521501887_item	3495051	et	4	main
rublad	doc_491521501887_item	3495053	et	3	main
28	doc_491521501887_item	3495054	et	2	main
juunil	doc_491521501887_item	3495055	et	3	main
võetakse	doc_491521501887_item	3495056	et	3	main
ev	doc_491521501887_item	3495064	et	4	main
euroopa	doc_491521501887_item	3495078	et	4	main
1994	doc_491521501887_item	3495081	et	2	main
a	doc_491521501887_item	3495082	et	4	main
jt	doc_491521501887_item	3495125	et	4	main
nagu	doc_491521501887_item	3495126	et	3	main
a	doc_491521501887_item	3495127	et	4	main
a	doc_491521501887_item	3495132	et	4	main
masingu	doc_491521501887_item	3495139	et	4	main
teoste	doc_491521501887_item	3495140	et	3	main
avaldamine	doc_491521501887_item	3495141	et	4	main
arbujad	doc_491521501887_item	3495153	et	4	main
intelligentsus	doc_491521501887_item	3495162	et	4	main
teadlased	doc_491521501887_item	3495163	et	3	main
kirjanikud	doc_491521501887_item	3495164	et	3	main
jt	doc_491521501887_item	3495165	et	4	main
tohi	doc_491521501887_item	3495170	et	4	main
kuulutus	doc_491521501939_item	3495396	et	4	main
sellele	doc_491521501939_item	3495399	et	4	main
peab	doc_491521501939_item	3495401	et	4	main
keelteoskus	doc_491521501939_item	3495411	et	3	main
hobid	doc_491521501939_item	3495414	et	3	main
kirjutage	doc_491521501939_item	3495416	et	3	main
avatakse	doc_491521501939_item	3495432	et	4	main
head	doc_491521501939_item	3495449	et	4	main
suhtlemisoskust	doc_491521501939_item	3495450	et	3	main
teile	doc_491521501939_item	3495458	et	4	main
kindlat	doc_491521501939_item	3495461	et	3	main
mnt	doc_491521501939_item	3495467	et	4	main
tuhande	doc_491521501939_item	3495476	et	3	main
koos	doc_491521501939_item	3495483	et	4	main
töötada	doc_491521501939_item	3495508	et	3	main
arvutitehnikad	doc_491521501939_item	3495510	et	3	main
auto	doc_491521501939_item	3495512	et	4	main
rohkem	doc_491521501939_item	3495541	et	4	main
kehalise	doc_491521501939_item	3495566	et	4	main
soobib	doc_491521501939_item	3495577	et	4	main
töögraafik	doc_491521501939_item	3495578	et	3	main
1	doc_491521502058_item	3495593	et	2	main
olema	doc_491521502058_item	3495602	et	4	main
töökogemused	doc_491521502058_item	3495610	et	3	main
kirjutage	doc_491521502058_item	3495616	et	3	main
avatakse	doc_491521502058_item	3495632	et	4	main
uus	doc_491521502058_item	3495633	et	3	main
toidukauplus	doc_491521502058_item	3495634	et	3	main
kauplusse	doc_491521502058_item	3495635	et	3	main
et	doc_491521502058_item	3495680	et	3	main
teie	doc_491521502058_item	3495681	et	4	main
poole	doc_491521502058_item	3495687	et	4	main
ja	doc_491521502058_item	3495729	et	3	main
politseikool	doc_491521502058_item	3495738	et	4	main
venemaa	doc_491521501887_item	3495027	et	4	main
presidendiks	doc_491521501887_item	3495040	et	4	main
juunis	doc_491521501887_item	3495045	et	3	main
a	doc_491521501887_item	3495063	et	4	main
meri	doc_491521501887_item	3495069	et	3	main
olid	doc_491521501887_item	3495083	et	4	main
võõrväed	doc_491521501887_item	3495084	et	3	main
eestist	doc_491521501887_item	3495085	et	3	main
ja	doc_491521501887_item	3495087	et	3	main
sünnib	doc_491521501887_item	3495088	et	3	main
eesti	doc_491521501887_item	3495089	et	4	main
ja	doc_491521501887_item	3495090	et	3	main
teiste	doc_491521501887_item	3495091	et	4	main
riikide	doc_491521501887_item	3495092	et	3	main
vahel	doc_491521501887_item	3495093	et	4	main
kaubandusleping	doc_491521501887_item	3495094	et	3	main
2	doc_491521501887_item	3495095	et	2	main
palju	doc_491521501887_item	3495096	et	4	main
tähtsad	doc_491521501887_item	3495097	et	3	main
teosed	doc_491521501887_item	3495098	et	3	main
olid	doc_491521501887_item	3495099	et	4	main
kirjutatud	doc_491521501887_item	3495100	et	4	main
eesti	doc_491521501887_item	3495101	et	4	main
kirjanukutena	doc_491521501887_item	3495102	et	4	main
kes	doc_491521501887_item	3495103	et	4	main
oli	doc_491521501887_item	3495104	et	3	main
sundinud	doc_491521501887_item	3495105	et	4	main
elada	doc_491521501887_item	3495106	et	3	main
emigratsioonis	doc_491521501887_item	3495107	et	3	main
need	doc_491521501887_item	3495108	et	3	main
olid	doc_491521501887_item	3495109	et	4	main
k	doc_491521501887_item	3495110	et	4	main
ristikivi	doc_491521501887_item	3495111	et	4	main
hingede	doc_491521501887_item	3495112	et	3	main
öö	doc_491521501887_item	3495113	et	4	main
b	doc_491521501887_item	3495114	et	4	main
kangro	doc_491521501887_item	3495115	et	4	main
kes	doc_491521501887_item	3495116	et	4	main
kirjutas	doc_491521501887_item	3495117	et	3	main
tartu	doc_491521501887_item	3495118	et	4	main
elust	doc_491521501887_item	3495119	et	3	main
veel	doc_491521501887_item	3495120	et	4	main
tuntud	doc_491521501887_item	3495121	et	4	main
naiskirjanik	doc_491521501887_item	3495122	et	3	main
alliksaar	doc_491521501887_item	3495128	et	4	main
luuletaja	doc_491521501887_item	3495137	et	4	main
hint	doc_491521501887_item	3495133	et	4	main
probleemiks	doc_491521501887_item	3495145	et	4	main
jätkasid	doc_491521501887_item	3495149	et	4	main
ka	doc_491521501887_item	3495150	et	3	main
raimond	doc_491521501887_item	3495155	et	4	main
kolk	doc_491521501887_item	3495156	et	3	main
3	doc_491521501887_item	3495157	et	2	main
40	doc_491521501887_item	3495158	et	2	main
kiri	doc_491521501887_item	3495159	et	3	main
kirjutasid	doc_491521501887_item	3495160	et	4	main
toimuda	doc_491521501887_item	3495171	et	3	main
olnud	doc_491521501887_item	3495143	et	4	main
kodumaale	doc_491521501887_item	3495151	et	4	main
venemaale	doc_491521501887_item	3495166	et	4	main
et	doc_491521501887_item	3495167	et	3	main
venestuspoliitika	doc_491521501887_item	3495168	et	4	main
ei	doc_491521501887_item	3495169	et	4	main
jäänud	doc_491521501887_item	3495152	et	4	main
eesti	doc_491521501887_item	3495161	et	4	main
eestis	doc_491521501887_item	3495172	et	3	main
läbi	doc_491521501939_item	3495395	et	4	main
arvutioskus	doc_491521501939_item	3495412	et	3	main
ja	doc_491521501939_item	3495415	et	3	main
millist	doc_491521501939_item	3495419	et	3	main
soovite	doc_491521501939_item	3495421	et	3	main
kui	doc_491521501939_item	3495422	et	3	main
suurt	doc_491521501939_item	3495423	et	3	main
töötasu	doc_491521501939_item	3495424	et	4	main
soovite	doc_491521501939_item	3495425	et	3	main
milline	doc_491521501939_item	3495426	et	3	main
töögraafik	doc_491521501939_item	3495427	et	3	main
sobib	doc_491521501939_item	3495428	et	3	main
kahe	doc_491521501939_item	3495429	et	3	main
kauplusse	doc_491521501939_item	3495435	et	3	main
turvamehi	doc_491521501939_item	3495439	et	3	main
kanditaatidelt	doc_491521501939_item	3495442	et	3	main
keele	doc_491521501939_item	3495447	et	4	main
oskust	doc_491521501939_item	3495448	et	3	main
sobivat	doc_491521501939_item	3495459	et	4	main
töögraafikut	doc_491521501939_item	3495460	et	3	main
lisainfo	doc_491521501939_item	3495463	et	4	main
3	doc_491521501939_item	3495468	et	2	main
tallinn	doc_491521501939_item	3495469	et	4	main
ja	doc_491521501939_item	3495485	et	3	main
minu	doc_491521501939_item	3495490	et	3	main
lugege	doc_491521501939_item	3495394	et	3	main
olema	doc_491521501939_item	3495402	et	4	main
60	doc_491521501939_item	3495404	et	2	main
perekonnaseis	doc_491521501939_item	3495408	et	4	main
töökogemused	doc_491521501939_item	3495410	et	3	main
soovidest	doc_491521501939_item	3495418	et	3	main
pärast	doc_491521501939_item	3495431	et	4	main
toidukauplus	doc_491521501939_item	3495434	et	3	main
müüjat	doc_491521501939_item	3495437	et	4	main
kassapidajat	doc_491521501939_item	3495438	et	3	main
soovitav	doc_491521501939_item	3495451	et	4	main
kakuke	doc_491521501939_item	3495465	et	4	main
sündinud	doc_491521501939_item	3495473	et	4	main
üheksandal	doc_491521501939_item	3495474	et	3	main
viiekümne	doc_491521501939_item	3495478	et	4	main
aastal	doc_491521501939_item	3495480	et	3	main
elan	doc_491521501939_item	3495482	et	3	main
isaga	doc_491521501939_item	3495486	et	3	main
on	doc_491521501939_item	3495488	et	4	main
tööstaaz	doc_491521501939_item	3495491	et	4	main
18	doc_491521501939_item	3495493	et	2	main
õpin	doc_491521501939_item	3495496	et	3	main
keelt	doc_491521501939_item	3495498	et	4	main
ammu	doc_491521501939_item	3495500	et	4	main
aga	doc_491521501939_item	3495501	et	3	main
väga	doc_491521501939_item	3495504	et	3	main
ma	doc_491521501939_item	3495516	et	3	main
mängib	doc_491521501939_item	3495536	et	3	main
väike	doc_491521501939_item	3495548	et	4	main
maja	doc_491521501939_item	3495549	et	4	main
ja	doc_491521501939_item	3495550	et	3	main
kaks	doc_491521501939_item	3495551	et	3	main
ei	doc_491521501939_item	3495555	et	4	main
aga	doc_491521501939_item	3495557	et	3	main
töötada	doc_491521501939_item	3495559	et	3	main
ma	doc_491521501939_item	3495561	et	3	main
soovin	doc_491521501939_item	3495570	et	3	main
koolis	doc_491521501939_item	3495579	et	4	main
kirjas	doc_491521502058_item	3495600	et	4	main
ennast	doc_491521502058_item	3495607	et	4	main
autojuhiload	doc_491521502058_item	3495613	et	4	main
ja	doc_491521502058_item	3495615	et	3	main
oma	doc_491521502058_item	3495617	et	4	main
kui	doc_491521502058_item	3495622	et	3	main
suurt	doc_491521502058_item	3495623	et	3	main
milline	doc_491521502058_item	3495626	et	3	main
töögraafik	doc_491521502058_item	3495627	et	3	main
müüjat	doc_491521502058_item	3495637	et	4	main
kauplusesse	doc_491521502058_item	3495682	et	4	main
huvitav	doc_491521502058_item	3495688	et	4	main
keelt	doc_491521502058_item	3495725	et	4	main
on	doc_491521502058_item	3495726	et	4	main
kakskümmend	doc_491521502058_item	3495732	et	4	main
aastat	doc_491521502058_item	3495733	et	3	main
tagasi	doc_491521502058_item	3495734	et	3	main
olen	doc_491521502058_item	3495735	et	3	main
lõpetanud	doc_491521502058_item	3495736	et	4	main
paikuse	doc_491521502058_item	3495737	et	3	main
alal	doc_491521502058_item	3495750	et	4	main
sobib	doc_491521502058_item	3495751	et	3	main
suvaliselt	doc_491521502058_item	3495752	et	4	main
töögraafik	doc_491521502058_item	3495753	et	3	main
krooni	doc_491521502058_item	3495762	et	4	main
lugupidamisega	doc_491521502058_item	3495764	et	3	main
hea	doc_491521502058_item	3495766	et	4	main
sellepärast	doc_491521501939_item	3495580	et	3	main
et	doc_491521501939_item	3495581	et	3	main
väga	doc_491521501939_item	3495582	et	3	main
mugav	doc_491521501939_item	3495583	et	3	main
töötada	doc_491521501939_item	3495584	et	3	main
päeval	doc_491521501939_item	3495585	et	3	main
aga	doc_491521501939_item	3495586	et	3	main
õhtul	doc_491521501939_item	3495587	et	3	main
olla	doc_491521501939_item	3495588	et	3	main
kodus	doc_491521501939_item	3495589	et	4	main
perega	doc_491521501939_item	3495591	et	3	main
koos	doc_491521501939_item	3495590	et	4	main
ja	doc_491521501939_item	3495397	et	3	main
tutvustage	doc_491521501939_item	3495406	et	3	main
autojuhiload	doc_491521501939_item	3495413	et	4	main
oma	doc_491521501939_item	3495417	et	4	main
tööd	doc_491521501939_item	3495420	et	4	main
uus	doc_491521501939_item	3495433	et	3	main
koristajaid	doc_491521501939_item	3495440	et	4	main
ootame	doc_491521501939_item	3495443	et	3	main
on	doc_491521501939_item	3495452	et	4	main
mugavaid	doc_491521501939_item	3495456	et	3	main
tartu	doc_491521501939_item	3495466	et	4	main
septembril	doc_491521501939_item	3495475	et	3	main
ma	doc_491521501939_item	3495481	et	3	main
pojaga	doc_491521501939_item	3495484	et	4	main
kõrgharidus	doc_491521501939_item	3495489	et	3	main
on	doc_491521501939_item	3495492	et	4	main
ma	doc_491521501939_item	3495506	et	3	main
ka	doc_491521501939_item	3495509	et	3	main
oma	doc_491521501939_item	3495511	et	4	main
ei	doc_491521501939_item	3495514	et	4	main
jalgsi	doc_491521501939_item	3495519	et	3	main
veel	doc_491521501939_item	3495534	et	4	main
klaverit	doc_491521501939_item	3495537	et	3	main
mulle	doc_491521501939_item	3495538	et	4	main
meeldib	doc_491521501939_item	3495539	et	3	main
kõige	doc_491521501939_item	3495540	et	4	main
on	doc_491521501939_item	3495545	et	4	main
suur	doc_491521501939_item	3495546	et	3	main
aed	doc_491521501939_item	3495547	et	3	main
praegu	doc_491521501939_item	3495553	et	3	main
kasvatuse	doc_491521501939_item	3495567	et	4	main
teaduskond	doc_491521501939_item	3495568	et	3	main
ma	doc_491521501939_item	3495569	et	3	main
3-5	doc_491521501939_item	3495573	et	2	main
krooni	doc_491521501939_item	3495575	et	4	main
mulle	doc_491521501939_item	3495576	et	4	main
lugege	doc_491521502058_item	3495594	et	3	main
läbi	doc_491521502058_item	3495595	et	4	main
vastake	doc_491521502058_item	3495598	et	3	main
umbes	doc_491521502058_item	3495603	et	4	main
60	doc_491521502058_item	3495604	et	2	main
keelteoskus	doc_491521502058_item	3495611	et	3	main
millist	doc_491521502058_item	3495619	et	3	main
töötasu	doc_491521502058_item	3495624	et	4	main
sobib	doc_491521502058_item	3495628	et	3	main
kahe	doc_491521502058_item	3495629	et	3	main
kuu	doc_491521502058_item	3495630	et	4	main
turvamehi	doc_491521502058_item	3495639	et	3	main
eesti	doc_491521502058_item	3495644	et	4	main
ja	doc_491521502058_item	3495645	et	3	main
austatud	doc_491521502058_item	3495675	et	4	main
direktor	doc_491521502058_item	3495677	et	3	main
töötajaid	doc_491521502058_item	3495684	et	4	main
pöördun	doc_491521502058_item	3495685	et	3	main
teie	doc_491521502058_item	3495686	et	4	main
ja	doc_491521502058_item	3495691	et	3	main
vabalt	doc_491521502058_item	3495720	et	4	main
eesti	doc_491521502058_item	3495721	et	4	main
olemas	doc_491521502058_item	3495727	et	4	main
tunnistuse	doc_491521502058_item	3495747	et	4	main
arvutikasutamise	doc_491521502058_item	3495748	et	3	main
töötasu	doc_491521502058_item	3495759	et	4	main
kuus	doc_491521502058_item	3495763	et	4	main
loodad	doc_491521502058_item	3495765	et	3	main
koostööle	doc_491521502058_item	3495767	et	3	main
selgelt	doc_973441205340_item	3495910	et	4	main
pildistati	doc_973441205340_item	3495922	et	3	main
öelda	doc_973441205340_item	3495927	et	4	main
see	doc_973441205340_item	3495929	et	3	main
on	doc_973441205340_item	3495930	et	4	main
lõuna	doc_973441205340_item	3495947	et	4	main
valgus	doc_973441205340_item	3495954	et	4	main
esiplaanil	doc_973441205340_item	3495958	et	4	main
vene	doc_491521501939_item	3495446	et	4	main
ka	doc_491521501939_item	3495453	et	3	main
arvutikasutusoskus	doc_491521501939_item	3495454	et	3	main
pakume	doc_491521501939_item	3495455	et	3	main
töötingimusi	doc_491521501939_item	3495457	et	3	main
palka	doc_491521501939_item	3495462	et	4	main
as	doc_491521501939_item	3495464	et	4	main
mina	doc_491521501939_item	3495470	et	4	main
eesnimi	doc_491521501939_item	3495471	et	3	main
olen	doc_491521501939_item	3495472	et	3	main
üheksasaja	doc_491521501939_item	3495477	et	4	main
üheksandal	doc_491521501939_item	3495479	et	3	main
mul	doc_491521501939_item	3495487	et	3	main
ma	doc_491521501939_item	3495495	et	3	main
oskan	doc_491521501939_item	3495507	et	3	main
ole	doc_491521501939_item	3495515	et	4	main
eelistan	doc_491521501939_item	3495517	et	3	main
tegelda	doc_491521501939_item	3495542	et	4	main
aias	doc_491521501939_item	3495543	et	4	main
ma	doc_491521501939_item	3495554	et	3	main
tööta	doc_491521501939_item	3495556	et	4	main
erialalt	doc_491521501939_item	3495560	et	3	main
tuula	doc_491521501939_item	3495563	et	4	main
pedagoogiline	doc_491521501939_item	3495564	et	4	main
instituudi	doc_491521501939_item	3495565	et	3	main
töötasu	doc_491521501939_item	3495571	et	4	main
tuhat	doc_491521501939_item	3495574	et	4	main
aastat	doc_491521501939_item	3495494	et	3	main
eesti	doc_491521501939_item	3495497	et	4	main
väga	doc_491521501939_item	3495499	et	3	main
oskan	doc_491521501939_item	3495502	et	3	main
rääkida	doc_491521501939_item	3495503	et	3	main
halvasti	doc_491521501939_item	3495505	et	3	main
mul	doc_491521501939_item	3495513	et	3	main
käia	doc_491521501939_item	3495518	et	4	main
rohkem	doc_491521501939_item	3495520	et	4	main
ma	doc_491521501939_item	3495521	et	3	main
tegelen	doc_491521501939_item	3495522	et	3	main
oma	doc_491521501939_item	3495523	et	4	main
pojaga	doc_491521501939_item	3495524	et	4	main
andrei	doc_491521501939_item	3495525	et	4	main
on	doc_491521501939_item	3495526	et	4	main
üksteist	doc_491521501939_item	3495527	et	4	main
aastat	doc_491521501939_item	3495528	et	3	main
vana	doc_491521501939_item	3495529	et	4	main
ta	doc_491521501939_item	3495530	et	4	main
käib	doc_491521501939_item	3495531	et	3	main
viiendas	doc_491521501939_item	3495532	et	3	main
klassis	doc_491521501939_item	3495533	et	3	main
ta	doc_491521501939_item	3495535	et	4	main
seal	doc_491521501939_item	3495544	et	4	main
kasvahooned	doc_491521501939_item	3495552	et	4	main
tahan	doc_491521501939_item	3495558	et	3	main
lõpetasin	doc_491521501939_item	3495562	et	3	main
ümbes	doc_491521501939_item	3495572	et	4	main
eksamitöö	doc_491521502058_item	3495592	et	4	main
kuulutus	doc_491521502058_item	3495596	et	4	main
ja	doc_491521502058_item	3495597	et	3	main
sellele	doc_491521502058_item	3495599	et	4	main
sõna	doc_491521502058_item	3495605	et	4	main
tutvustage	doc_491521502058_item	3495606	et	3	main
arvutioskus	doc_491521502058_item	3495612	et	3	main
soovidest	doc_491521502058_item	3495618	et	3	main
tööd	doc_491521502058_item	3495620	et	4	main
soovite	doc_491521502058_item	3495625	et	3	main
pärast	doc_491521502058_item	3495631	et	4	main
kassapidajat	doc_491521502058_item	3495638	et	3	main
pakkijaid	doc_491521502058_item	3495641	et	4	main
ootame	doc_491521502058_item	3495643	et	3	main
3	doc_491521502058_item	3495673	et	2	main
tallinn	doc_491521502058_item	3495674	et	4	main
vajatakse	doc_491521502058_item	3495683	et	4	main
informatsiooni	doc_491521502058_item	3495689	et	4	main
suhtlemisoskus	doc_491521502058_item	3495718	et	3	main
oskan	doc_491521502058_item	3495719	et	3	main
auto	doc_491521502058_item	3495731	et	4	main
kätte	doc_491521502058_item	3495746	et	4	main
vallaline	doc_491521502058_item	3495757	et	4	main
tahaksin	doc_491521502058_item	3495758	et	3	main
peab	doc_491521502058_item	3495601	et	4	main
perekonnaseis	doc_491521502058_item	3495608	et	4	main
haridus	doc_491521502058_item	3495609	et	3	main
hobid	doc_491521502058_item	3495614	et	3	main
soovite	doc_491521502058_item	3495621	et	3	main
vajatakse	doc_491521502058_item	3495636	et	4	main
koristajaid	doc_491521502058_item	3495640	et	4	main
kanditaatidelt	doc_491521502058_item	3495642	et	3	main
vene	doc_491521502058_item	3495646	et	4	main
keele	doc_491521502058_item	3495647	et	4	main
oskust	doc_491521502058_item	3495648	et	3	main
head	doc_491521502058_item	3495649	et	4	main
suhtlemisoskust	doc_491521502058_item	3495650	et	3	main
soovitav	doc_491521502058_item	3495651	et	4	main
on	doc_491521502058_item	3495652	et	4	main
ka	doc_491521502058_item	3495653	et	3	main
arvutikasutusoskus	doc_491521502058_item	3495654	et	3	main
pakume	doc_491521502058_item	3495655	et	3	main
mugavaid	doc_491521502058_item	3495656	et	3	main
töötingimus	doc_491521502058_item	3495657	et	2	main
teile	doc_491521502058_item	3495658	et	4	main
sobivat	doc_491521502058_item	3495659	et	4	main
töögraafikut	doc_491521502058_item	3495660	et	3	main
kindlat	doc_491521502058_item	3495661	et	3	main
palka	doc_491521502058_item	3495662	et	4	main
lisainfo	doc_491521502058_item	3495663	et	4	main
as	doc_491521502058_item	3495664	et	4	main
kakuke	doc_491521502058_item	3495665	et	4	main
tartu	doc_491521502058_item	3495666	et	4	main
mnt3	doc_491521502058_item	3495667	et	4	main
tallinn	doc_491521502058_item	3495668	et	4	main
kakuke	doc_491521502058_item	3495669	et	4	main
as	doc_491521502058_item	3495670	et	4	main
tartu	doc_491521502058_item	3495671	et	4	main
mnt	doc_491521502058_item	3495672	et	4	main
toidukaupluse	doc_491521502058_item	3495676	et	3	main
lugesin	doc_491521502058_item	3495678	et	3	main
ajalehest	doc_491521502058_item	3495679	et	4	main
saamiseks	doc_491521502058_item	3495690	et	4	main
ennast	doc_491521502058_item	3495692	et	4	main
tutvustamiseks	doc_491521502058_item	3495693	et	4	main
tahaksin	doc_491521502058_item	3495694	et	3	main
töötada	doc_491521502058_item	3495695	et	3	main
kaupluses	doc_491521502058_item	3495696	et	3	main
turvamehena	doc_491521502058_item	3495697	et	3	main
selle	doc_491521502058_item	3495698	et	4	main
jaoks	doc_491521502058_item	3495699	et	4	main
mul	doc_491521502058_item	3495700	et	3	main
on	doc_491521502058_item	3495701	et	4	main
suur	doc_491521502058_item	3495702	et	3	main
töökogemus	doc_491521502058_item	3495703	et	3	main
15	doc_491521502058_item	3495705	et	2	main
töötasin	doc_491521502058_item	3495704	et	3	main
aasta	doc_491521502058_item	3495706	et	4	main
jooksul	doc_491521502058_item	3495707	et	4	main
politseiprefektuuris	doc_491521502058_item	3495708	et	3	main
konstäblina	doc_491521502058_item	3495709	et	4	main
kohtus	doc_491521502058_item	3495710	et	4	main
ja	doc_491521502058_item	3495711	et	3	main
täitevosakonnas	doc_491521502058_item	3495712	et	4	main
kordnikuna	doc_491521502058_item	3495713	et	3	main
sellega	doc_491521502058_item	3495714	et	3	main
mul	doc_491521502058_item	3495715	et	3	main
on	doc_491521502058_item	3495716	et	4	main
hea	doc_491521502058_item	3495717	et	4	main
vene	doc_491521502058_item	3495722	et	4	main
ja	doc_491521502058_item	3495723	et	3	main
inglise	doc_491521502058_item	3495724	et	4	main
autojuhiload	doc_491521502058_item	3495728	et	4	main
oma	doc_491521502058_item	3495730	et	4	main
oskuse	doc_491521502058_item	3495749	et	3	main
sellel	doc_491521502058_item	3495739	et	4	main
aastal	doc_491521502058_item	3495740	et	3	main
ka	doc_491521502058_item	3495741	et	3	main
arvutikursused	doc_491521502058_item	3495742	et	3	main
kus	doc_491521502058_item	3495743	et	3	main
ma	doc_491521502058_item	3495744	et	3	main
sain	doc_491521502058_item	3495745	et	3	main
sest	doc_491521502058_item	3495754	et	4	main
ma	doc_491521502058_item	3495755	et	3	main
olen	doc_491521502058_item	3495756	et	3	main
tuhat	doc_491521502058_item	3495761	et	4	main
pildi	doc_973441205340_item	3495895	et	4	main
pilt	doc_973441205340_item	3495898	et	3	main
näha	doc_973441205340_item	3495911	et	3	main
iseloomulikku	doc_973441205340_item	3495915	et	4	main
inimesi	doc_973441205340_item	3495917	et	4	main
et	doc_973441205340_item	3495921	et	3	main
tööasutuses	doc_973441205340_item	3495924	et	4	main
ei	doc_973441205340_item	3495925	et	4	main
saa	doc_973441205340_item	3495926	et	4	main
söökla	doc_973441205340_item	3495932	et	4	main
väljas	doc_973441205340_item	3495940	et	4	main
on	doc_973441205340_item	3495959	et	4	main
3	doc_973441205340_item	3495961	et	2	main
üks	doc_973441205340_item	3495964	et	3	main
temagi	doc_973441205340_item	3495980	et	4	main
on	doc_973441205340_item	3495987	et	4	main
hõivatud	doc_973441205340_item	3495988	et	4	main
roa	doc_973441205340_item	3495989	et	4	main
6-7	doc_491521502058_item	3495760	et	2	main
see	doc_973441205340_item	3495899	et	3	main
ning	doc_973441205340_item	3495914	et	3	main
tundub	doc_973441205340_item	3495920	et	3	main
kooli	doc_973441205340_item	3495931	et	4	main
arust	doc_973441205340_item	3495942	et	4	main
pilt	doc_973441205340_item	3495943	et	3	main
tehtud	doc_973441205340_item	3495945	et	4	main
ajal	doc_973441205340_item	3495948	et	4	main
on	doc_973441205340_item	3495955	et	4	main
paneb	doc_973441205340_item	3495981	et	3	main
kaks	doc_973441205340_item	3495984	et	3	main
naist	doc_973441205340_item	3495986	et	3	main
nii	doc_973441205340_item	3495991	et	3	main
ka	doc_973441205340_item	3495992	et	3	main
küsimusele	doc_485437783974_item	3496023	et	4	main
endas	doc_485437783974_item	3496039	et	4	main
kuidas	doc_485437783974_item	3496041	et	3	main
seda	doc_485437783974_item	3496043	et	3	main
teeb	doc_485437783974_item	3496044	et	3	main
kui	doc_485437783974_item	3496056	et	3	main
teadmisis	doc_485437783974_item	3496060	et	4	main
on	doc_485437783974_item	3496062	et	4	main
ka	doc_485437783974_item	3496070	et	3	main
inimene	doc_485437783974_item	3496073	et	3	main
ühestvõi	doc_485437783974_item	3496075	et	4	main
midagi	doc_485437783974_item	3496078	et	4	main
seletada	doc_485437783974_item	3496080	et	3	main
on	doc_485437783974_item	3496085	et	4	main
minu	doc_485437783974_item	3496086	et	3	main
läheb	doc_485437783974_item	3496097	et	3	main
hoida	doc_485437783974_item	3496099	et	3	main
endas	doc_485437783974_item	3496104	et	4	main
ei	doc_485437783974_item	3496115	et	4	main
tavad	doc_485437783974_item	3496127	et	3	main
eesti	doc_485437783974_item	3496153	et	4	main
ja	doc_485437783974_item	3496161	et	3	main
ühine	doc_485437783974_item	3496168	et	4	main
see	doc_485437783974_item	3496172	et	3	main
aitab	doc_485437783974_item	3496174	et	3	main
kirjeldus	doc_973441205340_item	3495896	et	4	main
potte	doc_973441205340_item	3495912	et	3	main
järjekorda	doc_973441205340_item	3495916	et	4	main
rohkem	doc_973441205340_item	3495919	et	4	main
mingi	doc_973441205340_item	3495923	et	4	main
et	doc_973441205340_item	3495928	et	3	main
enamasti	doc_973441205340_item	3495935	et	4	main
naised	doc_973441205340_item	3495936	et	3	main
on	doc_973441205340_item	3495937	et	4	main
juba	doc_973441205340_item	3495938	et	3	main
koolieast	doc_973441205340_item	3495939	et	3	main
sest	doc_973441205340_item	3495949	et	4	main
väljas	doc_973441205340_item	3495950	et	4	main
lülitatud	doc_973441205340_item	3495956	et	4	main
pildi	doc_973441205340_item	3495957	et	4	main
nooremate	doc_485437783974_item	3496028	et	4	main
enesest	doc_485437783974_item	3496047	et	4	main
ja	doc_485437783974_item	3496058	et	3	main
tall	doc_485437783974_item	3496061	et	3	main
sellest	doc_485437783974_item	3496063	et	4	main
maailmast	doc_485437783974_item	3496064	et	4	main
meelest	doc_485437783974_item	3496087	et	4	main
see	doc_485437783974_item	3496088	et	3	main
kuidas	doc_485437783974_item	3496089	et	3	main
sa	doc_485437783974_item	3496090	et	3	main
tarvis	doc_485437783974_item	3496098	et	3	main
eesti	doc_485437783974_item	3496105	et	4	main
kultuur	doc_485437783974_item	3496106	et	3	main
eesti	doc_485437783974_item	3496107	et	4	main
kultuur	doc_485437783974_item	3496108	et	3	main
täpselt	doc_485437783974_item	3496113	et	4	main
võib	doc_485437783974_item	3496118	et	3	main
oma	doc_485437783974_item	3496130	et	4	main
oma	doc_485437783974_item	3496132	et	4	main
kirjandus	doc_485437783974_item	3496133	et	3	main
oma	doc_485437783974_item	3496134	et	4	main
aegadest	doc_485437783974_item	3496144	et	3	main
dikteerib	doc_485437783974_item	3496147	et	3	main
rahvale	doc_485437783974_item	3496149	et	3	main
eestlaste	doc_485437783974_item	3496160	et	4	main
olla	doc_485437783974_item	3496170	et	3	main
on	doc_485437783974_item	3496171	et	4	main
inimestel	doc_485437783974_item	3496175	et	3	main
2	doc_344825459480_item	3496193	et	2	main
kultuur	doc_344825459480_item	3496195	et	3	main
kõige	doc_344825459480_item	3496205	et	4	main
tulevad	doc_344825459480_item	3496207	et	4	main
meelde	doc_344825459480_item	3496208	et	3	main
rohkem	doc_344825459480_item	3496217	et	4	main
aga	doc_344825459480_item	3496218	et	3	main
see	doc_344825459480_item	3496234	et	3	main
toitu	doc_344825459480_item	3496238	et	4	main
peale	doc_344825459480_item	3496240	et	4	main
seda	doc_344825459480_item	3496241	et	3	main
kultuur	doc_344825459480_item	3496242	et	3	main
minu	doc_344825459480_item	3496243	et	3	main
meelest	doc_344825459480_item	3496244	et	4	main
kellelegi	doc_344825459480_item	3496253	et	4	main
kohas	doc_344825459480_item	3496263	et	4	main
ei	doc_344825459480_item	3496266	et	4	main
jääb	doc_344825459480_item	3496273	et	3	main
2	doc_344825459480_item	3496276	et	2	main
ma	doc_344825459480_item	3496278	et	3	main
kuulen	doc_344825459480_item	3496279	et	3	main
teisi	doc_344825459480_item	3496304	et	4	main
kirjanikke	doc_344825459480_item	3496305	et	3	main
nagu	doc_344825459480_item	3496306	et	3	main
tammsaare	doc_344825459480_item	3496307	et	3	main
toit	doc_344825459480_item	3496316	et	3	main
maitsev	doc_344825459480_item	3496321	et	4	main
inimesed	doc_344825459480_item	3496323	et	3	main
selle	doc_344825459480_item	3496331	et	4	main
pärast	doc_344825459480_item	3496332	et	4	main
on	doc_973441205340_item	3495971	et	4	main
söökla	doc_973441205340_item	3495972	et	4	main
töötaja	doc_973441205340_item	3495973	et	4	main
sest	doc_973441205340_item	3495974	et	4	main
tal	doc_973441205340_item	3495975	et	3	main
peas	doc_973441205340_item	3495976	et	4	main
on	doc_973441205340_item	3495977	et	4	main
valge	doc_973441205340_item	3495978	et	4	main
kokkamüts	doc_973441205340_item	3495979	et	4	main
2	doc_973441205340_item	3495897	et	2	main
pilt	doc_973441205340_item	3495900	et	3	main
on	doc_973441205340_item	3495901	et	4	main
tehtud	doc_973441205340_item	3495902	et	4	main
sööklas	doc_973441205340_item	3495903	et	3	main
ma	doc_973441205340_item	3495904	et	3	main
arvan	doc_973441205340_item	3495905	et	3	main
nii	doc_973441205340_item	3495906	et	3	main
sest	doc_973441205340_item	3495907	et	4	main
pildil	doc_973441205340_item	3495908	et	3	main
on	doc_973441205340_item	3495909	et	4	main
toiduga	doc_973441205340_item	3495913	et	3	main
taldrikutega	doc_973441205340_item	3495918	et	3	main
sest	doc_973441205340_item	3495933	et	4	main
inimesed	doc_973441205340_item	3495934	et	3	main
mu	doc_973441205340_item	3495941	et	3	main
on	doc_973441205340_item	3495944	et	4	main
pärast	doc_973441205340_item	3495946	et	4	main
on	doc_973441205340_item	3495951	et	4	main
pime	doc_973441205340_item	3495952	et	3	main
ja	doc_973441205340_item	3495953	et	3	main
väike	doc_973441205340_item	3495965	et	4	main
tüdruk	doc_973441205340_item	3495966	et	3	main
arvan	doc_973441205340_item	3495967	et	3	main
et	doc_973441205340_item	3495968	et	3	main
üks	doc_973441205340_item	3495969	et	3	main
naissoost	doc_973441205340_item	3495970	et	4	main
toitu	doc_973441205340_item	3495983	et	4	main
näitab	doc_973441205340_item	3495995	et	3	main
midagi	doc_973441205340_item	3495996	et	4	main
käega	doc_973441205340_item	3495997	et	3	main
kuna	doc_973441205340_item	3495998	et	3	main
pilt	doc_973441205340_item	3495999	et	3	main
on	doc_973441205340_item	3496000	et	4	main
tehtud	doc_973441205340_item	3496001	et	4	main
ruumis	doc_973441205340_item	3496002	et	4	main
inimesed	doc_973441205340_item	3496003	et	3	main
ei	doc_973441205340_item	3496004	et	4	main
ole	doc_973441205340_item	3496005	et	4	main
sojalt	doc_973441205340_item	3496006	et	3	main
riides	doc_973441205340_item	3496007	et	4	main
inimesed	doc_973441205340_item	3496008	et	3	main
tagaplaanil	doc_973441205340_item	3496009	et	4	main
kannatlikult	doc_973441205340_item	3496010	et	4	main
ootavad	doc_973441205340_item	3496011	et	4	main
oma	doc_973441205340_item	3496012	et	4	main
järjekorda	doc_973441205340_item	3496013	et	4	main
üldiselt	doc_973441205340_item	3496014	et	4	main
õhkkond	doc_973441205340_item	3496015	et	3	main
on	doc_973441205340_item	3496016	et	4	main
rahulik	doc_973441205340_item	3496017	et	3	main
ja	doc_973441205340_item	3496018	et	3	main
sõbralik	doc_973441205340_item	3496019	et	3	main
kujutatud	doc_973441205340_item	3495960	et	4	main
naist	doc_973441205340_item	3495962	et	3	main
ja	doc_973441205340_item	3495963	et	3	main
taldrikule	doc_973441205340_item	3495982	et	3	main
teist	doc_973441205340_item	3495985	et	4	main
valimisega	doc_973441205340_item	3495990	et	4	main
tüdruk	doc_973441205340_item	3495993	et	3	main
kes	doc_973441205340_item	3495994	et	4	main
vastus	doc_485437783974_item	3496022	et	3	main
laste	doc_485437783974_item	3496026	et	4	main
või	doc_485437783974_item	3496027	et	4	main
kultuur	doc_485437783974_item	3496033	et	3	main
on	doc_485437783974_item	3496034	et	4	main
see	doc_485437783974_item	3496035	et	3	main
mida	doc_485437783974_item	3496036	et	4	main
inimene	doc_485437783974_item	3496037	et	3	main
sõltub	doc_485437783974_item	3496045	et	3	main
inimese	doc_485437783974_item	3496046	et	4	main
palju	doc_485437783974_item	3496057	et	4	main
teda	doc_485437783974_item	3496066	et	4	main
ümbritseb	doc_485437783974_item	3496067	et	3	main
kultuur	doc_485437783974_item	3496068	et	3	main
see	doc_485437783974_item	3496071	et	3	main
oskab	doc_485437783974_item	3496074	et	3	main
oskad	doc_485437783974_item	3496091	et	3	main
suhtuda	doc_485437783974_item	3496092	et	3	main
teistesse	doc_485437783974_item	3496093	et	4	main
inimestesse	doc_485437783974_item	3496094	et	3	main
samasuguseid	doc_485437783974_item	3496114	et	3	main
kuid	doc_485437783974_item	3496117	et	4	main
traditsioonid	doc_485437783974_item	3496129	et	3	main
eesti	doc_485437783974_item	3496136	et	4	main
kultuur	doc_485437783974_item	3496137	et	3	main
on	doc_485437783974_item	3496138	et	4	main
ajalooline	doc_485437783974_item	3496139	et	4	main
pärand	doc_485437783974_item	3496140	et	3	main
mis	doc_485437783974_item	3496141	et	4	main
eesti	doc_485437783974_item	3496145	et	4	main
see	doc_485437783974_item	3496156	et	3	main
on	doc_485437783974_item	3496158	et	4	main
kõikide	doc_485437783974_item	3496159	et	4	main
ka	doc_485437783974_item	3496164	et	3	main
rahvuste	doc_485437783974_item	3496166	et	3	main
küsimusele	doc_344825459480_item	3496190	et	4	main
sõna	doc_344825459480_item	3496201	et	4	main
erinevad	doc_344825459480_item	3496209	et	4	main
riigid	doc_344825459480_item	3496210	et	3	main
sest	doc_344825459480_item	3496211	et	4	main
tahaksin	doc_344825459480_item	3496212	et	3	main
rohkem	doc_344825459480_item	3496213	et	4	main
teada	doc_344825459480_item	3496214	et	3	main
nende	doc_344825459480_item	3496215	et	4	main
kultuurist	doc_344825459480_item	3496216	et	3	main
rahva	doc_344825459480_item	3496237	et	3	main
laule	doc_344825459480_item	3496239	et	4	main
see	doc_344825459480_item	3496265	et	3	main
tule	doc_344825459480_item	3496267	et	4	main
kasuks	doc_344825459480_item	3496268	et	4	main
riigile	doc_344825459480_item	3496269	et	3	main
halb	doc_344825459480_item	3496274	et	3	main
sõna	doc_344825459480_item	3496280	et	4	main
meenub	doc_344825459480_item	3496285	et	3	main
koidula	doc_344825459480_item	3496308	et	4	main
ja	doc_344825459480_item	3496309	et	3	main
paljud	doc_344825459480_item	3496310	et	3	main
teised	doc_344825459480_item	3496311	et	4	main
sest	doc_344825459480_item	3496317	et	4	main
väga	doc_344825459480_item	3496320	et	3	main
teagi	doc_344825459480_item	3496325	et	4	main
peaksid	doc_344825459480_item	3496333	et	4	main
teistele	doc_344825459480_item	3496337	et	4	main
ka	doc_485437783974_item	3496184	et	3	main
riigis	doc_485437783974_item	3496185	et	3	main
rahu	doc_485437783974_item	3496186	et	4	main
oma	doc_485437783974_item	3496025	et	4	main
sugulaste	doc_485437783974_item	3496029	et	4	main
arendab	doc_485437783974_item	3496038	et	3	main
ta	doc_485437783974_item	3496042	et	4	main
kultuur	doc_485437783974_item	3496048	et	3	main
on	doc_485437783974_item	3496049	et	4	main
see	doc_485437783974_item	3496050	et	3	main
kuidas	doc_485437783974_item	3496051	et	3	main
inimene	doc_485437783974_item	3496052	et	3	main
oskab	doc_485437783974_item	3496053	et	3	main
käituda	doc_485437783974_item	3496054	et	3	main
ja	doc_485437783974_item	3496055	et	3	main
milliseid	doc_485437783974_item	3496059	et	3	main
on	doc_485437783974_item	3496069	et	4	main
kuidas	doc_485437783974_item	3496072	et	3	main
valdkonnast	doc_485437783974_item	3496077	et	4	main
rääkida	doc_485437783974_item	3496079	et	3	main
ja	doc_485437783974_item	3496095	et	3	main
oma	doc_485437783974_item	3496100	et	4	main
ja	doc_485437783974_item	3496102	et	3	main
on	doc_485437783974_item	3496109	et	4	main
kindlasti	doc_485437783974_item	3496110	et	3	main
ainulaadne	doc_485437783974_item	3496111	et	3	main
teisi	doc_485437783974_item	3496112	et	4	main
olla	doc_485437783974_item	3496119	et	3	main
leidub	doc_485437783974_item	3496120	et	3	main
sarnaseid	doc_485437783974_item	3496121	et	4	main
kombed	doc_485437783974_item	3496128	et	3	main
keel	doc_485437783974_item	3496131	et	4	main
iidsetest	doc_485437783974_item	3496143	et	3	main
eesti	doc_485437783974_item	3496148	et	4	main
kultuur	doc_485437783974_item	3496154	et	3	main
mis	doc_485437783974_item	3496157	et	4	main
olla	doc_485437783974_item	3496163	et	3	main
võib	doc_485437783974_item	3496169	et	3	main
mis	doc_485437783974_item	3496173	et	4	main
olla	doc_485437783974_item	3496176	et	3	main
koos	doc_485437783974_item	3496177	et	4	main
ja	doc_485437783974_item	3496178	et	3	main
hoida	doc_485437783974_item	3496179	et	3	main
nii	doc_485437783974_item	3496180	et	3	main
oma	doc_485437783974_item	3496181	et	4	main
kodudes	doc_485437783974_item	3496182	et	3	main
kui	doc_485437783974_item	3496183	et	3	main
vastus	doc_344825459480_item	3496189	et	3	main
eesti	doc_344825459480_item	3496194	et	4	main
1	doc_344825459480_item	3496197	et	2	main
ma	doc_344825459480_item	3496199	et	3	main
siis	doc_344825459480_item	3496203	et	3	main
kõige	doc_344825459480_item	3496219	et	4	main
on	doc_344825459480_item	3496245	et	4	main
see	doc_344825459480_item	3496246	et	3	main
ei	doc_344825459480_item	3496254	et	4	main
meeldiks	doc_344825459480_item	3496255	et	3	main
muus	doc_344825459480_item	3496262	et	4	main
sest	doc_344825459480_item	3496270	et	4	main
eesti	doc_344825459480_item	3496281	et	4	main
mulle	doc_344825459480_item	3496284	et	4	main
oskar	doc_344825459480_item	3496287	et	4	main
luts	doc_344825459480_item	3496288	et	3	main
on	doc_344825459480_item	3496319	et	4	main
eesti	doc_344825459480_item	3496329	et	4	main
ja	doc_344825459480_item	3496330	et	3	main
eestist	doc_344825459480_item	3496335	et	3	main
kultuur	doc_485437783974_item	3496024	et	3	main
vendade	doc_485437783974_item	3496030	et	3	main
õdede	doc_485437783974_item	3496031	et	3	main
kasvatamine	doc_485437783974_item	3496032	et	4	main
ja	doc_485437783974_item	3496040	et	3	main
mis	doc_485437783974_item	3496065	et	4	main
teisest	doc_485437783974_item	3496076	et	4	main
võib	doc_485437783974_item	3496081	et	3	main
olla	doc_485437783974_item	3496082	et	3	main
õppetada	doc_485437783974_item	3496083	et	4	main
kultuur	doc_485437783974_item	3496084	et	3	main
kui	doc_485437783974_item	3496096	et	3	main
tundeid	doc_485437783974_item	3496101	et	3	main
mõtteid	doc_485437783974_item	3496103	et	3	main
ole	doc_485437783974_item	3496116	et	4	main
kultuure	doc_485437783974_item	3496122	et	3	main
eesti	doc_485437783974_item	3496123	et	4	main
kultuur	doc_485437783974_item	3496124	et	3	main
on	doc_485437783974_item	3496125	et	4	main
omad	doc_485437783974_item	3496126	et	4	main
rahvas	doc_485437783974_item	3496135	et	4	main
tuleb	doc_485437783974_item	3496142	et	3	main
kultuur	doc_485437783974_item	3496146	et	3	main
käitumisviisi	doc_485437783974_item	3496150	et	4	main
toitumistavasid	doc_485437783974_item	3496151	et	3	main
kasvatamisviisi	doc_485437783974_item	3496152	et	4	main
on	doc_485437783974_item	3496155	et	4	main
võib	doc_485437783974_item	3496162	et	3	main
teiste	doc_485437783974_item	3496165	et	4	main
jaoks	doc_485437783974_item	3496167	et	4	main
1	doc_344825459480_item	3496191	et	2	main
kuulen	doc_344825459480_item	3496200	et	3	main
asi	doc_344825459480_item	3496221	et	4	main
kui	doc_344825459480_item	3496222	et	3	main
kuulen	doc_344825459480_item	3496223	et	3	main
tähendab	doc_344825459480_item	3496235	et	3	main
kui	doc_344825459480_item	3496256	et	3	main
ta	doc_344825459480_item	3496257	et	4	main
sõimab	doc_344825459480_item	3496258	et	3	main
ja	doc_344825459480_item	3496264	et	3	main
inimestest	doc_344825459480_item	3496272	et	3	main
kui	doc_344825459480_item	3496277	et	3	main
siis	doc_344825459480_item	3496283	et	3	main
ennekõige	doc_344825459480_item	3496286	et	4	main
ja	doc_344825459480_item	3496289	et	3	main
teos	doc_344825459480_item	3496291	et	4	main
tema	doc_344825459480_item	3496290	et	4	main
kevad	doc_344825459480_item	3496292	et	3	main
see	doc_344825459480_item	3496293	et	3	main
on	doc_344825459480_item	3496294	et	4	main
vist	doc_344825459480_item	3496295	et	4	main
kõige	doc_344825459480_item	3496296	et	4	main
tuntum	doc_344825459480_item	3496297	et	4	main
eestist	doc_344825459480_item	3496338	et	3	main
ja	doc_344825459480_item	3496339	et	3	main
inimestest	doc_344825459480_item	3496340	et	3	main
kes	doc_344825459480_item	3496341	et	4	main
siin	doc_344825459480_item	3496342	et	4	main
elavad	doc_344825459480_item	3496343	et	4	main
kultuur	doc_344825459480_item	3496192	et	3	main
vastused	doc_344825459480_item	3496196	et	3	main
kui	doc_344825459480_item	3496198	et	3	main
kultuur	doc_344825459480_item	3496202	et	3	main
mulle	doc_344825459480_item	3496204	et	4	main
pealt	doc_344825459480_item	3496206	et	4	main
oluline	doc_344825459480_item	3496220	et	4	main
sõna	doc_344825459480_item	3496224	et	4	main
kultuur	doc_344825459480_item	3496225	et	3	main
on	doc_344825459480_item	3496226	et	4	main
see	doc_344825459480_item	3496227	et	3	main
kuidas	doc_344825459480_item	3496228	et	3	main
me	doc_344825459480_item	3496229	et	4	main
igapäevases	doc_344825459480_item	3496230	et	4	main
elus	doc_344825459480_item	3496231	et	4	main
toime	doc_344825459480_item	3496232	et	4	main
tuleme	doc_344825459480_item	3496233	et	3	main
kombeid	doc_344825459480_item	3496236	et	4	main
kuidas	doc_344825459480_item	3496247	et	3	main
peab	doc_344825459480_item	3496248	et	4	main
iga	doc_344825459480_item	3496249	et	4	main
inimene	doc_344825459480_item	3496250	et	3	main
käituma	doc_344825459480_item	3496251	et	3	main
näiteks	doc_344825459480_item	3496252	et	4	main
teisi	doc_344825459480_item	3496259	et	4	main
tänaval	doc_344825459480_item	3496260	et	4	main
või	doc_344825459480_item	3496261	et	4	main
sellstest	doc_344825459480_item	3496271	et	4	main
mulje	doc_344825459480_item	3496275	et	4	main
kultuur	doc_344825459480_item	3496282	et	3	main
palju	doc_344825459480_item	3496303	et	4	main
see	doc_344825459480_item	3496318	et	3	main
rääkima	doc_344825459480_item	3496336	et	3	main
kirjanik	doc_344825459480_item	3496298	et	3	main
eestis	doc_344825459480_item	3496299	et	3	main
on	doc_344825459480_item	3496300	et	4	main
veel	doc_344825459480_item	3496301	et	4	main
ka	doc_344825459480_item	3496302	et	3	main
veel	doc_344825459480_item	3496312	et	4	main
mulle	doc_344825459480_item	3496313	et	4	main
meenub	doc_344825459480_item	3496314	et	3	main
rahva	doc_344825459480_item	3496315	et	3	main
paljud	doc_344825459480_item	3496322	et	3	main
ei	doc_344825459480_item	3496324	et	4	main
isegi	doc_344825459480_item	3496326	et	4	main
kus	doc_344825459480_item	3496327	et	3	main
asub	doc_344825459480_item	3496328	et	3	main
inimesed	doc_344825459480_item	3496334	et	3	main
pildi	doc_681992022012_item	3496694	et	4	main
istuvad	doc_681992022012_item	3496701	et	4	main
hellid	doc_681992022012_item	3496715	et	3	main
raske	doc_681992022012_item	3496722	et	4	main
teisel	doc_681992022012_item	3496744	et	4	main
koer	doc_681992022012_item	3496751	et	3	main
teine	doc_681992022012_item	3496756	et	3	main
iga	doc_681992022012_item	3496767	et	4	main
õuna	doc_681992022012_item	3496795	et	4	main
iseloom	doc_681992022012_item	3496805	et	3	main
kirjeldus	doc_873901597530_item	3496813	et	4	main
siiras	doc_873901597530_item	3496825	et	4	main
seltskondlik	doc_873901597530_item	3496827	et	3	main
tõsiselt	doc_873901597530_item	3496840	et	4	main
sain	doc_873901597530_item	3496852	et	3	main
arvamus	doc_873901597530_item	3496856	et	3	main
täppi	doc_873901597530_item	3496858	et	4	main
tema	doc_873901597530_item	3496868	et	4	main
ülikooli	doc_873901597530_item	3496905	et	4	main
nii	doc_873901597530_item	3496922	et	3	main
osaniku	doc_873901597530_item	3496927	et	3	main
ja	doc_873901597530_item	3496933	et	3	main
uue	doc_873901597530_item	3496935	et	3	main
töö	doc_873901597530_item	3496936	et	4	main
uus	doc_873901597530_item	3496937	et	3	main
külli	doc_873901597530_item	3496943	et	4	main
töötab	doc_873901597530_item	3496944	et	3	main
tooteid	doc_873901597530_item	3496949	et	4	main
pildil	doc_681992022012_item	3496698	et	3	main
on	doc_681992022012_item	3496699	et	4	main
rahulikud	doc_681992022012_item	3496714	et	3	main
uhked	doc_681992022012_item	3496717	et	4	main
kassid	doc_681992022012_item	3496718	et	3	main
kord	doc_681992022012_item	3496725	et	4	main
söötmine	doc_681992022012_item	3496727	et	4	main
kui	doc_681992022012_item	3496730	et	3	main
nad	doc_681992022012_item	3496741	et	3	main
koera	doc_681992022012_item	3496749	et	4	main
on	doc_681992022012_item	3496752	et	4	main
armastavad	doc_681992022012_item	3496765	et	4	main
palju	doc_681992022012_item	3496794	et	4	main
saab	doc_681992022012_item	3496799	et	3	main
lahtiselt	doc_681992022012_item	3496801	et	4	main
ma	doc_873901597530_item	3496815	et	3	main
küllit	doc_873901597530_item	3496817	et	4	main
mulle	doc_873901597530_item	3496829	et	4	main
et	doc_873901597530_item	3496831	et	3	main
töötab	doc_873901597530_item	3496833	et	3	main
kodus	doc_873901597530_item	3496842	et	4	main
võib	doc_873901597530_item	3496844	et	3	main
olla	doc_873901597530_item	3496845	et	3	main
vallatugi	doc_873901597530_item	3496846	et	4	main
kirjeldus	doc_681992022012_item	3496695	et	4	main
2	doc_681992022012_item	3496700	et	2	main
kassi	doc_681992022012_item	3496702	et	4	main
üks	doc_681992022012_item	3496703	et	3	main
ja	doc_681992022012_item	3496716	et	3	main
hoolitsemine	doc_681992022012_item	3496719	et	4	main
ei	doc_681992022012_item	3496720	et	4	main
üks	doc_681992022012_item	3496724	et	3	main
nii	doc_681992022012_item	3496728	et	3	main
palju	doc_681992022012_item	3496729	et	4	main
nad	doc_681992022012_item	3496731	et	3	main
ja	doc_681992022012_item	3496733	et	3	main
ei	doc_681992022012_item	3496736	et	4	main
pildil	doc_681992022012_item	3496745	et	3	main
mäigivad	doc_681992022012_item	3496748	et	4	main
ja	doc_681992022012_item	3496755	et	3	main
täiskasvanud	doc_681992022012_item	3496758	et	4	main
on	doc_681992022012_item	3496761	et	4	main
aktivsed	doc_681992022012_item	3496762	et	4	main
ja	doc_681992022012_item	3496763	et	3	main
lõbusad	doc_681992022012_item	3496764	et	3	main
päev	doc_681992022012_item	3496768	et	3	main
peavad	doc_681992022012_item	3496770	et	4	main
liikuda	doc_681992022012_item	3496771	et	3	main
jooma	doc_681992022012_item	3496772	et	4	main
ta	doc_681992022012_item	3496798	et	4	main
tal	doc_681992022012_item	3496802	et	3	main
rahulik	doc_681992022012_item	3496804	et	3	main
ta	doc_681992022012_item	3496806	et	4	main
ei	doc_681992022012_item	3496807	et	4	main
armasta	doc_681992022012_item	3496808	et	4	main
liikuda	doc_681992022012_item	3496809	et	3	main
esimesel	doc_681992022012_item	3496697	et	3	main
ole	doc_681992022012_item	3496721	et	4	main
nädalas	doc_681992022012_item	3496726	et	3	main
armastavad	doc_681992022012_item	3496737	et	4	main
liikuda	doc_681992022012_item	3496738	et	3	main
aga	doc_681992022012_item	3496739	et	3	main
mõnikord	doc_681992022012_item	3496740	et	3	main
müravad	doc_681992022012_item	3496742	et	4	main
2	doc_681992022012_item	3496747	et	2	main
koera	doc_681992022012_item	3496753	et	4	main
on	doc_681992022012_item	3496757	et	4	main
koer	doc_681992022012_item	3496759	et	3	main
sööma	doc_681992022012_item	3496773	et	4	main
nad	doc_681992022012_item	3496774	et	3	main
armastavad	doc_681992022012_item	3496775	et	4	main
kurgi	doc_681992022012_item	3496796	et	4	main
elada	doc_681992022012_item	3496800	et	3	main
on	doc_681992022012_item	3496803	et	4	main
ujuda	doc_681992022012_item	3496776	et	3	main
ja	doc_681992022012_item	3496777	et	3	main
mängida	doc_681992022012_item	3496778	et	3	main
3	doc_681992022012_item	3496779	et	2	main
kolmandal	doc_681992022012_item	3496780	et	3	main
pildil	doc_681992022012_item	3496781	et	3	main
on	doc_681992022012_item	3496782	et	4	main
kilpkonn	doc_681992022012_item	3496783	et	3	main
kilpkonn	doc_681992022012_item	3496784	et	3	main
on	doc_681992022012_item	3496785	et	4	main
eksotiline	doc_681992022012_item	3496786	et	4	main
loom	doc_681992022012_item	3496787	et	3	main
ta	doc_681992022012_item	3496788	et	4	main
on	doc_681992022012_item	3496789	et	4	main
aeglane	doc_681992022012_item	3496790	et	3	main
ta	doc_681992022012_item	3496791	et	4	main
sööb	doc_681992022012_item	3496792	et	3	main
mitte	doc_681992022012_item	3496793	et	3	main
1	doc_681992022012_item	3496696	et	2	main
kass	doc_681992022012_item	3496704	et	3	main
on	doc_681992022012_item	3496705	et	4	main
siiamne	doc_681992022012_item	3496706	et	4	main
aga	doc_681992022012_item	3496707	et	3	main
teine	doc_681992022012_item	3496708	et	3	main
minu	doc_681992022012_item	3496709	et	3	main
arvamus	doc_681992022012_item	3496710	et	3	main
et	doc_681992022012_item	3496711	et	3	main
nad	doc_681992022012_item	3496712	et	3	main
on	doc_681992022012_item	3496713	et	4	main
kammimine	doc_681992022012_item	3496723	et	4	main
tahavad	doc_681992022012_item	3496732	et	3	main
jootmine	doc_681992022012_item	3496734	et	4	main
nad	doc_681992022012_item	3496735	et	3	main
2	doc_681992022012_item	3496743	et	2	main
on	doc_681992022012_item	3496746	et	4	main
üks	doc_681992022012_item	3496750	et	3	main
poeg	doc_681992022012_item	3496754	et	3	main
nad	doc_681992022012_item	3496760	et	3	main
liikuda	doc_681992022012_item	3496766	et	3	main
nad	doc_681992022012_item	3496769	et	3	main
kapsat	doc_681992022012_item	3496797	et	4	main
nägin	doc_873901597530_item	3496816	et	3	main
ja	doc_873901597530_item	3496826	et	3	main
naine	doc_873901597530_item	3496828	et	3	main
tundus	doc_873901597530_item	3496830	et	3	main
külli	doc_873901597530_item	3496832	et	4	main
ja	doc_873901597530_item	3496851	et	3	main
minu	doc_873901597530_item	3496855	et	3	main
läks	doc_873901597530_item	3496857	et	3	main
külli	doc_873901597530_item	3496859	et	4	main
ei	doc_873901597530_item	3496860	et	4	main
on	doc_873901597530_item	3496866	et	4	main
teenindusmaja	doc_873901597530_item	3496898	et	4	main
seal	doc_873901597530_item	3496899	et	4	main
oma	doc_873901597530_item	3496909	et	4	main
et	doc_873901597530_item	3496923	et	3	main
usalduse	doc_873901597530_item	3496926	et	4	main
külli	doc_873901597530_item	3496928	et	4	main
seal	doc_873901597530_item	3496932	et	4	main
leidis	doc_873901597530_item	3496934	et	4	main
kui	doc_873901597530_item	3496941	et	3	main
vana	doc_873901597530_item	3496942	et	4	main
oma	doc_873901597530_item	3496952	et	4	main
järgib	doc_873901597530_item	3496954	et	3	main
ei	doc_873901597530_item	3496963	et	4	main
ma	doc_873901597530_item	3496967	et	3	main
oma	doc_873901597530_item	3496974	et	4	main
töö	doc_873901597530_item	3496975	et	4	main
mitte	doc_873901597530_item	3496976	et	3	main
kunagi	doc_873901597530_item	3496977	et	3	main
külli	doc_873901597530_item	3496978	et	4	main
tegin	doc_873901597530_item	3496979	et	3	main
3	doc_873901597530_item	3496980	et	2	main
katset	doc_873901597530_item	3496981	et	3	main
ja	doc_873901597530_item	3496982	et	3	main
teeb	doc_873901597530_item	3496983	et	3	main
ta	doc_873901597530_item	3496984	et	4	main
kindlasti	doc_873901597530_item	3496985	et	3	main
järjekordse	doc_873901597530_item	3496986	et	3	main
kannapöörde	doc_873901597530_item	3496987	et	4	main
kui	doc_873901597530_item	3496814	et	3	main
ma	doc_873901597530_item	3496819	et	3	main
et	doc_873901597530_item	3496821	et	3	main
on	doc_873901597530_item	3496823	et	4	main
tasakaalukas	doc_873901597530_item	3496824	et	4	main
mügiesindajana	doc_873901597530_item	3496834	et	4	main
minu	doc_873901597530_item	3496835	et	3	main
arvates	doc_873901597530_item	3496836	et	4	main
ta	doc_873901597530_item	3496843	et	4	main
läbi	doc_873901597530_item	3496850	et	4	main
et	doc_873901597530_item	3496854	et	3	main
tema	doc_873901597530_item	3496864	et	4	main
energia	doc_873901597530_item	3496865	et	4	main
elus	doc_873901597530_item	3496869	et	4	main
oli	doc_873901597530_item	3496870	et	3	main
palju	doc_873901597530_item	3496871	et	4	main
muutusi	doc_873901597530_item	3496872	et	4	main
lapsepõlvest	doc_873901597530_item	3496873	et	4	main
saadik	doc_873901597530_item	3496874	et	4	main
on	doc_873901597530_item	3496875	et	4	main
ta	doc_873901597530_item	3496876	et	4	main
tahtnud	doc_873901597530_item	3496877	et	4	main
õppida	doc_873901597530_item	3496878	et	3	main
tehnikumis	doc_873901597530_item	3496879	et	3	main
ja	doc_873901597530_item	3496880	et	3	main
ölikoolis	doc_873901597530_item	3496881	et	4	main
ta	doc_873901597530_item	3496882	et	4	main
saatis	doc_873901597530_item	3496883	et	3	main
põhjalikke	doc_873901597530_item	3496884	et	3	main
teadusi	doc_873901597530_item	3496885	et	3	main
õppimise	doc_873901597530_item	3496886	et	4	main
ajal	doc_873901597530_item	3496887	et	4	main
ta	doc_873901597530_item	3496888	et	4	main
elas	doc_873901597530_item	3496889	et	3	main
kodust	doc_873901597530_item	3496890	et	4	main
eemal	doc_873901597530_item	3496891	et	3	main
ja	doc_873901597530_item	3496892	et	3	main
päses	doc_873901597530_item	3496893	et	4	main
tööte	doc_873901597530_item	3496894	et	4	main
pildi	doc_873901597530_item	3496812	et	4	main
pildil	doc_873901597530_item	3496818	et	3	main
arvasin	doc_873901597530_item	3496820	et	3	main
ta	doc_873901597530_item	3496822	et	4	main
ta	doc_873901597530_item	3496837	et	4	main
suhtub	doc_873901597530_item	3496838	et	3	main
töösse	doc_873901597530_item	3496839	et	3	main
aga	doc_873901597530_item	3496841	et	3	main
teksti	doc_873901597530_item	3496849	et	4	main
aru	doc_873901597530_item	3496853	et	4	main
ammendamatu	doc_873901597530_item	3496867	et	4	main
avas	doc_873901597530_item	3496908	et	4	main
aga	doc_873901597530_item	3496920	et	3	main
juhtus	doc_873901597530_item	3496921	et	3	main
töötada	doc_873901597530_item	3496931	et	3	main
töö	doc_873901597530_item	3496938	et	4	main
mügiesindaja	doc_873901597530_item	3496945	et	4	main
kaardifirmas	doc_873901597530_item	3496946	et	3	main
kõrgelt	doc_873901597530_item	3496951	et	4	main
külli	doc_873901597530_item	3496962	et	4	main
sarnane	doc_873901597530_item	3496966	et	4	main
tema	doc_873901597530_item	3496969	et	4	main
siis	doc_873901597530_item	3496847	et	3	main
lugesin	doc_873901597530_item	3496848	et	3	main
anna	doc_873901597530_item	3496861	et	4	main
ebaõnnestumiste	doc_873901597530_item	3496862	et	3	main
alla	doc_873901597530_item	3496863	et	3	main
tollasesse	doc_873901597530_item	3496895	et	3	main
ta	doc_873901597530_item	3496900	et	4	main
omandas	doc_873901597530_item	3496901	et	3	main
suure	doc_873901597530_item	3496902	et	3	main
kogemuse	doc_873901597530_item	3496903	et	3	main
firma	doc_873901597530_item	3496910	et	4	main
see	doc_873901597530_item	3496911	et	3	main
asi	doc_873901597530_item	3496912	et	4	main
oli	doc_873901597530_item	3496913	et	3	main
lootusrikas	doc_873901597530_item	3496914	et	4	main
ja	doc_873901597530_item	3496915	et	3	main
pidi	doc_873901597530_item	3496916	et	4	main
andma	doc_873901597530_item	3496917	et	3	main
hea	doc_873901597530_item	3496918	et	4	main
kasumi	doc_873901597530_item	3496919	et	3	main
tippkohta	doc_873901597530_item	3496896	et	4	main
tallinna	doc_873901597530_item	3496897	et	4	main
pärast	doc_873901597530_item	3496904	et	4	main
lõpitamist	doc_873901597530_item	3496906	et	4	main
ta	doc_873901597530_item	3496907	et	4	main
kadus	doc_873901597530_item	3496925	et	3	main
osutus	doc_873901597530_item	3496939	et	4	main
regio	doc_873901597530_item	3496947	et	4	main
hinnatakse	doc_873901597530_item	3496950	et	4	main
oma	doc_873901597530_item	3496956	et	4	main
näiteks	doc_873901597530_item	3496958	et	4	main
silmal	doc_873901597530_item	3496959	et	3	main
ta	doc_873901597530_item	3496924	et	4	main
ei	doc_873901597530_item	3496929	et	4	main
suutnud	doc_873901597530_item	3496930	et	4	main
etemaksem	doc_873901597530_item	3496940	et	4	main
regio	doc_873901597530_item	3496948	et	4	main
külli	doc_873901597530_item	3496955	et	4	main
põhimõtteid	doc_873901597530_item	3496957	et	3	main
peavad	doc_873901597530_item	3496960	et	4	main
särama	doc_873901597530_item	3496961	et	3	main
ole	doc_873901597530_item	3496964	et	4	main
kadestan	doc_873901597530_item	3496968	et	3	main
julguse	doc_873901597530_item	3496970	et	4	main
ma	doc_873901597530_item	3496971	et	3	main
ei	doc_873901597530_item	3496972	et	4	main
muuta	doc_873901597530_item	3496973	et	4	main
töös	doc_873901597530_item	3496953	et	3	main
minuga	doc_873901597530_item	3496965	et	3	main
näited	doc_842434202406_item	3497577	et	3	main
sõiduks	doc_842434202406_item	3497586	et	3	main
väljume	doc_842434202406_item	3497589	et	3	main
kell	doc_842434202406_item	3497593	et	3	main
olema	doc_842434202406_item	3497597	et	4	main
juba	doc_842434202406_item	3497599	et	3	main
kell	doc_842434202406_item	3497600	et	3	main
võru	doc_842434202406_item	3497608	et	4	main
tagastame	doc_842434202406_item	3497611	et	3	main
tallinna	doc_842434202406_item	3497612	et	4	main
ma	doc_842434202406_item	3497613	et	3	main
loodan	doc_842434202406_item	3497614	et	3	main
et	doc_842434202406_item	3497615	et	3	main
see	doc_842434202406_item	3497650	et	3	main
ei	doc_842434202406_item	3497659	et	4	main
sellepärast	doc_842434202406_item	3497665	et	3	main
ei	doc_842434202406_item	3497668	et	4	main
ole	doc_842434202406_item	3497669	et	4	main
eile	doc_842434202406_item	3497675	et	3	main
tulime	doc_842434202406_item	3497677	et	3	main
võimlast	doc_842434202406_item	3497679	et	4	main
püüdsin	doc_842434202406_item	3497686	et	3	main
kahekümne	doc_842434202406_item	3497695	et	4	main
tulevad	doc_842434202406_item	3497698	et	4	main
santehnikud	doc_842434202406_item	3497699	et	4	main
torude	doc_842434202406_item	3497700	et	3	main
plitka	doc_842434202406_item	3497711	et	4	main
võtma	doc_842434202406_item	3497712	et	3	main
ära	doc_842434202406_item	3497713	et	4	main
on	doc_842434202406_item	3497718	et	4	main
jõudne	doc_842434202406_item	3497721	et	4	main
ma	doc_842434202406_item	3497724	et	3	main
ei	doc_842434202406_item	3497725	et	4	main
tee	doc_842434202406_item	3497726	et	4	main
plitka	doc_842434202406_item	3497764	et	4	main
näidete	doc_842434202406_item	3497579	et	3	main
praegu	doc_842434202406_item	3497583	et	3	main
sellepärast	doc_842434202406_item	3497595	et	3	main
eesti	doc_842434202406_item	3497643	et	4	main
keeles	doc_842434202406_item	3497644	et	4	main
kuigi	doc_842434202406_item	3497645	et	3	main
kaks	doc_842434202406_item	3497646	et	3	main
korda	doc_842434202406_item	3497647	et	4	main
aega	doc_842434202406_item	3497670	et	4	main
abikaasaga	doc_842434202406_item	3497678	et	3	main
kell	doc_842434202406_item	3497680	et	3	main
kuus	doc_842434202406_item	3497681	et	4	main
no	doc_842434202406_item	3497682	et	3	main
vahetada	doc_842434202406_item	3497701	et	3	main
hääldus	doc_842434202406_item	3497720	et	4	main
aga	doc_842434202406_item	3497722	et	3	main
kui	doc_842434202406_item	3497723	et	3	main
tegi	doc_842434202406_item	3497763	et	4	main
nüüd	doc_842434202406_item	3497769	et	4	main
pean	doc_842434202406_item	3497770	et	4	main
see	doc_842434202406_item	3497772	et	3	main
no	doc_842434202406_item	3497775	et	3	main
on	doc_842434202406_item	3497779	et	4	main
praegu	doc_842434202406_item	3497781	et	3	main
ei	doc_842434202406_item	3497782	et	4	main
sinna	doc_842434202406_item	3497794	et	3	main
detsembris	doc_842434202406_item	3497796	et	3	main
töötada	doc_842434202406_item	3497798	et	3	main
on	doc_842434202406_item	3497801	et	4	main
on	doc_842434202406_item	3497812	et	4	main
vaja	doc_842434202406_item	3497813	et	4	main
detsembris	doc_842434202406_item	3497814	et	3	main
see	doc_842434202406_item	3497826	et	3	main
eile	doc_842434202406_item	3497836	et	3	main
ema	doc_842434202406_item	3497839	et	4	main
sa	doc_842434202406_item	3497842	et	3	main
et	doc_842434202406_item	3497844	et	3	main
loodavad	doc_842434202406_item	3497876	et	4	main
ma	doc_842434202406_item	3497878	et	3	main
mind	doc_842434202406_item	3497881	et	4	main
helistaks	doc_842434202406_item	3497885	et	3	main
ole	doc_842434202406_item	3497897	et	4	main
otsustasime	doc_842434202406_item	3497898	et	3	main
abikaasaga	doc_842434202406_item	3497899	et	3	main
et	doc_842434202406_item	3497900	et	3	main
lapimaa	doc_842434202406_item	3497909	et	4	main
minema	doc_842434202406_item	3497910	et	3	main
aga	doc_842434202406_item	3497911	et	3	main
esimene	doc_842434202406_item	3497912	et	3	main
tahaksin	doc_842434202406_item	3497916	et	3	main
et	doc_842434202406_item	3497922	et	3	main
seda	doc_842434202406_item	3497927	et	3	main
ma	doc_842434202406_item	3497928	et	3	main
vestlustest	doc_842434202406_item	3497581	et	4	main
valmistan	doc_842434202406_item	3497585	et	3	main
me	doc_842434202406_item	3497588	et	4	main
vara	doc_842434202406_item	3497591	et	4	main
juba	doc_842434202406_item	3497592	et	3	main
peame	doc_842434202406_item	3497596	et	4	main
kohal	doc_842434202406_item	3497598	et	4	main
kaheksa	doc_842434202406_item	3497601	et	4	main
ja	doc_842434202406_item	3497602	et	3	main
jõua	doc_842434202406_item	3497632	et	4	main
vahet	doc_842434202406_item	3497637	et	3	main
sellepärast	doc_842434202406_item	3497638	et	3	main
et	doc_842434202406_item	3497639	et	3	main
kui	doc_842434202406_item	3497640	et	3	main
me	doc_842434202406_item	3497641	et	4	main
tegeleme	doc_842434202406_item	3497642	et	3	main
ükskõik	doc_842434202406_item	3497649	et	3	main
mulle	doc_842434202406_item	3497652	et	4	main
ma	doc_842434202406_item	3497654	et	3	main
tunnen	doc_842434202406_item	3497655	et	3	main
seda	doc_842434202406_item	3497656	et	3	main
kahjuks	doc_842434202406_item	3497657	et	4	main
mul	doc_842434202406_item	3497658	et	3	main
teha	doc_842434202406_item	3497664	et	3	main
vot	doc_842434202406_item	3497667	et	3	main
natuke	doc_842434202406_item	3497683	et	4	main
teha	doc_842434202406_item	3497688	et	3	main
võtsin	doc_842434202406_item	3497691	et	3	main
novembris	doc_842434202406_item	3497697	et	3	main
torud	doc_842434202406_item	3497703	et	3	main
on	doc_842434202406_item	3497704	et	4	main
ma	doc_842434202406_item	3497714	et	3	main
proovisin	doc_842434202406_item	3497715	et	3	main
eile	doc_842434202406_item	3497716	et	3	main
see	doc_842434202406_item	3497717	et	3	main
õudne	doc_842434202406_item	3497719	et	3	main
jõudu	doc_842434202406_item	3497755	et	4	main
võtsin	doc_842434202406_item	3497759	et	3	main
ja	doc_842434202406_item	3497768	et	3	main
teha	doc_842434202406_item	3497777	et	3	main
suur	doc_842434202406_item	3497789	et	3	main
valgas	doc_842434202406_item	3497791	et	4	main
sõidan	doc_842434202406_item	3497793	et	3	main
suulise	doc_842434202406_item	3497575	et	4	main
keele	doc_842434202406_item	3497576	et	4	main
lindistus	doc_842434202406_item	3497580	et	4	main
ma	doc_842434202406_item	3497584	et	3	main
eesmaspäeval	doc_842434202406_item	3497587	et	4	main
väga	doc_842434202406_item	3497590	et	3	main
pärast	doc_842434202406_item	3497603	et	4	main
seda	doc_842434202406_item	3497604	et	3	main
pärast	doc_842434202406_item	3497609	et	4	main
tahaksin	doc_842434202406_item	3497634	et	3	main
annab	doc_842434202406_item	3497651	et	3	main
ole	doc_842434202406_item	3497660	et	4	main
võimalust	doc_842434202406_item	3497661	et	3	main
kodus	doc_842434202406_item	3497662	et	4	main
selleks	doc_842434202406_item	3497671	et	4	main
üldse	doc_842434202406_item	3497672	et	3	main
vot	doc_842434202406_item	3497673	et	3	main
kui	doc_842434202406_item	3497674	et	3	main
venemaal	doc_842434202406_item	3498150	et	4	main
elavad	doc_842434202406_item	3498151	et	4	main
ka	doc_842434202406_item	3498152	et	3	main
karjalased	doc_842434202406_item	3498153	et	3	main
ja	doc_842434202406_item	3498154	et	3	main
vepsad	doc_842434202406_item	3498155	et	4	main
nad	doc_842434202406_item	3498156	et	3	main
on	doc_842434202406_item	3498157	et	4	main
soomlastega	doc_842434202406_item	3498158	et	3	main
sugulased	doc_842434202406_item	3498159	et	3	main
õppijakeele	doc_842434202406_item	3497578	et	4	main
õpetajaga	doc_842434202406_item	3497582	et	4	main
neli	doc_842434202406_item	3497594	et	3	main
me	doc_842434202406_item	3497605	et	4	main
sõidame	doc_842434202406_item	3497606	et	3	main
võrru	doc_842434202406_item	3497607	et	3	main
me	doc_842434202406_item	3497610	et	4	main
ma	doc_842434202406_item	3497616	et	3	main
jõuan	doc_842434202406_item	3497617	et	3	main
kell	doc_842434202406_item	3497618	et	3	main
kuueks	doc_842434202406_item	3497619	et	4	main
tagasi	doc_842434202406_item	3497620	et	3	main
aga	doc_842434202406_item	3497621	et	3	main
äkki	doc_842434202406_item	3497622	et	3	main
midagi	doc_842434202406_item	3497623	et	4	main
juhtub	doc_842434202406_item	3497624	et	3	main
no	doc_842434202406_item	3497625	et	3	main
ma	doc_842434202406_item	3497626	et	3	main
helistan	doc_842434202406_item	3497627	et	3	main
kui	doc_842434202406_item	3497629	et	3	main
teile	doc_842434202406_item	3497628	et	4	main
ma	doc_842434202406_item	3497630	et	3	main
ei	doc_842434202406_item	3497631	et	4	main
ma	doc_842434202406_item	3497633	et	3	main
ei	doc_842434202406_item	3497635	et	4	main
teha	doc_842434202406_item	3497636	et	3	main
nädalas	doc_842434202406_item	3497648	et	3	main
palju	doc_842434202406_item	3497653	et	4	main
midagi	doc_842434202406_item	3497663	et	4	main
no	doc_842434202406_item	3497666	et	3	main
mina	doc_842434202406_item	3497685	et	4	main
elektripirnid	doc_842434202406_item	3497690	et	3	main
ja	doc_842434202406_item	3497693	et	3	main
pean	doc_842434202406_item	3497710	et	4	main
ta	doc_842434202406_item	3497727	et	4	main
hääldus	doc_842434202406_item	3497756	et	4	main
köögis	doc_842434202406_item	3497767	et	3	main
lammutama	doc_842434202406_item	3497771	et	4	main
on	doc_842434202406_item	3497773	et	4	main
ole	doc_842434202406_item	3497783	et	4	main
üldse	doc_842434202406_item	3497784	et	3	main
minul	doc_842434202406_item	3497785	et	3	main
on	doc_842434202406_item	3497788	et	4	main
ei	doc_842434202406_item	3497806	et	4	main
palju	doc_842434202406_item	3497815	et	4	main
töötada	doc_842434202406_item	3497816	et	3	main
nagu	doc_842434202406_item	3497823	et	3	main
üks	doc_842434202406_item	3497824	et	3	main
jaoks	doc_842434202406_item	3497832	et	4	main
vot	doc_842434202406_item	3497833	et	3	main
ma	doc_842434202406_item	3497834	et	3	main
tuled	doc_842434202406_item	3497845	et	4	main
kalendrit	doc_842434202406_item	3497849	et	3	main
me	doc_842434202406_item	3497676	et	4	main
sõime	doc_842434202406_item	3497684	et	4	main
midagi	doc_842434202406_item	3497687	et	4	main
vahetasin	doc_842434202406_item	3497689	et	3	main
veenäiteid	doc_842434202406_item	3497692	et	3	main
vormistasin	doc_842434202406_item	3497694	et	3	main
kaheksandal	doc_842434202406_item	3497696	et	3	main
meie	doc_842434202406_item	3497702	et	4	main
pandud	doc_842434202406_item	3497705	et	4	main
kinni	doc_842434202406_item	3497706	et	3	main
keeraamiplitkaga	doc_842434202406_item	3497707	et	4	main
ja	doc_842434202406_item	3497708	et	3	main
ma	doc_842434202406_item	3497709	et	3	main
tulevad	doc_842434202406_item	3497728	et	4	main
võtavad	doc_842434202406_item	3497729	et	3	main
haamri	doc_842434202406_item	3497730	et	3	main
ja	doc_842434202406_item	3497731	et	3	main
lammutavad	doc_842434202406_item	3497732	et	4	main
kõik	doc_842434202406_item	3497733	et	4	main
ära	doc_842434202406_item	3497734	et	4	main
asi	doc_842434202406_item	3497735	et	4	main
on	doc_842434202406_item	3497736	et	4	main
selles	doc_842434202406_item	3497737	et	4	main
et	doc_842434202406_item	3497738	et	3	main
ma	doc_842434202406_item	3497739	et	3	main
tegi	doc_842434202406_item	3497740	et	4	main
viis	doc_842434202406_item	3497742	et	4	main
aastat	doc_842434202406_item	3497743	et	3	main
tagasi	doc_842434202406_item	3497744	et	3	main
meie	doc_842434202406_item	3497745	et	4	main
korteris	doc_842434202406_item	3497746	et	3	main
remonti	doc_842434202406_item	3497741	et	4	main
remont	doc_842434202406_item	3497747	et	3	main
ei	doc_842434202406_item	3497748	et	4	main
ole	doc_842434202406_item	3497749	et	4	main
lõppenud	doc_842434202406_item	3497750	et	4	main
sellepärast	doc_842434202406_item	3497751	et	3	main
mul	doc_842434202406_item	3497752	et	3	main
ei	doc_842434202406_item	3497753	et	4	main
ole	doc_842434202406_item	3497754	et	4	main
õudu	doc_842434202406_item	3497757	et	4	main
ma	doc_842434202406_item	3497758	et	3	main
tööline	doc_842434202406_item	3497760	et	4	main
ja	doc_842434202406_item	3497761	et	3	main
ta	doc_842434202406_item	3497762	et	4	main
kohutav	doc_842434202406_item	3497774	et	4	main
vannas	doc_842434202406_item	3497765	et	3	main
ja	doc_842434202406_item	3497766	et	3	main
mis	doc_842434202406_item	3497776	et	4	main
see	doc_842434202406_item	3497778	et	3	main
elu	doc_842434202406_item	3497780	et	4	main
meil	doc_842434202406_item	3497787	et	4	main
objekt	doc_842434202406_item	3497790	et	3	main
homme	doc_842434202406_item	3497792	et	3	main
kahjuks	doc_842434202406_item	3497799	et	4	main
ole	doc_842434202406_item	3497807	et	4	main
rahad	doc_842434202406_item	3497810	et	4	main
minule	doc_842434202406_item	3497819	et	3	main
kiiresti	doc_842434202406_item	3497821	et	3	main
helistan	doc_842434202406_item	3497835	et	3	main
vanematele	doc_842434202406_item	3497837	et	4	main
ma	doc_842434202406_item	3497847	et	3	main
vaatan	doc_842434202406_item	3497848	et	3	main
ja	doc_842434202406_item	3497850	et	3	main
ootavad	doc_842434202406_item	3497882	et	4	main
kui	doc_842434202406_item	3497883	et	3	main
так	doc_842434202406_item	3497887	et	2	main
läheme	doc_842434202406_item	3497901	et	3	main
vaba	doc_842434202406_item	3497920	et	4	main
viisa	doc_842434202406_item	3497924	et	4	main
kolm	doc_842434202406_item	3497961	et	3	main
ma	doc_842434202406_item	3497964	et	3	main
on	doc_842434202406_item	3497973	et	4	main
kuuendal	doc_842434202406_item	3497975	et	3	main
esimene	doc_842434202406_item	3497979	et	3	main
väljumine	doc_842434202406_item	3497983	et	4	main
tallinnast	doc_842434202406_item	3497984	et	3	main
väljumine	doc_842434202406_item	3497989	et	4	main
terve	doc_842434202406_item	3497991	et	4	main
on	doc_842434202406_item	3498005	et	4	main
santa	doc_842434202406_item	3498006	et	4	main
külastamine	doc_842434202406_item	3498027	et	4	main
kompveki	doc_842434202406_item	3498030	et	4	main
külastamine	doc_842434202406_item	3498038	et	4	main
kell	doc_842434202406_item	3498039	et	3	main
kahekümne	doc_842434202406_item	3498077	et	4	main
on	doc_842434202406_item	3498083	et	4	main
kolmas	doc_842434202406_item	3498101	et	3	main
rongiga	doc_842434202406_item	3498105	et	4	main
seal	doc_842434202406_item	3498113	et	4	main
on	doc_842434202406_item	3498114	et	4	main
helsingi	doc_842434202406_item	3498123	et	4	main
ekskursioon	doc_842434202406_item	3498124	et	3	main
see	doc_842434202406_item	3498125	et	3	main
on	doc_842434202406_item	3498126	et	4	main
ka	doc_842434202406_item	3498127	et	3	main
linn	doc_842434202406_item	3498136	et	3	main
ma	doc_842434202406_item	3498137	et	3	main
miks	doc_842434202406_item	3498140	et	4	main
juhend	doc_542009824807_item	3498161	et	3	main
on	doc_542009824807_item	3498169	et	4	main
teised	doc_542009824807_item	3498183	et	4	main
võimalused	doc_542009824807_item	3498184	et	3	main
üks	doc_542009824807_item	3498185	et	3	main
seda	doc_542009824807_item	3498212	et	3	main
ka	doc_542009824807_item	3498217	et	3	main
vaadata	doc_542009824807_item	3498218	et	4	main
kui	doc_542009824807_item	3498219	et	3	main
ka	doc_542009824807_item	3498226	et	3	main
linna	doc_542009824807_item	3498227	et	4	main
saate	doc_542009824807_item	3498239	et	4	main
leida	doc_542009824807_item	3498240	et	3	main
see	doc_542009824807_item	3498256	et	3	main
on	doc_542009824807_item	3498259	et	4	main
kasulik	doc_542009824807_item	3498261	et	3	main
reisijatele	doc_542009824807_item	3498262	et	4	main
leping	doc_40918597559_item	3498267	et	3	main
a	doc_40918597559_item	3498279	et	4	main
elukoht	doc_40918597559_item	3498284	et	3	main
eesti	doc_40918597559_item	3498286	et	4	main
tallinn	doc_40918597559_item	3498287	et	4	main
ja	doc_40918597559_item	3498298	et	3	main
on	doc_40918597559_item	3498306	et	4	main
vastavalt	doc_40918597559_item	3498315	et	4	main
registreerutud	doc_40918597559_item	3498322	et	4	main
24	doc_40918597559_item	3498323	et	2	main
novembril	doc_40918597559_item	3498324	et	3	main
aega	doc_842434202406_item	3497786	et	4	main
tööd	doc_842434202406_item	3497800	et	4	main
palju	doc_842434202406_item	3497802	et	4	main
aga	doc_842434202406_item	3497803	et	3	main
raha	doc_842434202406_item	3497804	et	4	main
praegu	doc_842434202406_item	3497805	et	3	main
detsembris	doc_842434202406_item	3497809	et	3	main
detsember	doc_842434202406_item	3497817	et	3	main
läheb	doc_842434202406_item	3497818	et	3	main
on	doc_842434202406_item	3497827	et	4	main
kiirem	doc_842434202406_item	3497829	et	4	main
kuu	doc_842434202406_item	3497830	et	4	main
minu	doc_842434202406_item	3497831	et	3	main
ja	doc_842434202406_item	3497838	et	3	main
küsib	doc_842434202406_item	3497840	et	3	main
lubas	doc_842434202406_item	3497843	et	3	main
näen	doc_842434202406_item	3497851	et	3	main
et	doc_842434202406_item	3497852	et	3	main
ei	doc_842434202406_item	3497853	et	4	main
saa	doc_842434202406_item	3497854	et	4	main
esiteks	doc_842434202406_item	3497855	et	3	main
raha	doc_842434202406_item	3497856	et	4	main
ei	doc_842434202406_item	3497857	et	4	main
ole	doc_842434202406_item	3497858	et	4	main
ja	doc_842434202406_item	3497859	et	3	main
teiseks	doc_842434202406_item	3497860	et	4	main
aega	doc_842434202406_item	3497861	et	4	main
ei	doc_842434202406_item	3497862	et	4	main
ole	doc_842434202406_item	3497863	et	4	main
ma	doc_842434202406_item	3497864	et	3	main
ütlesin	doc_842434202406_item	3497865	et	3	main
kahjuks	doc_842434202406_item	3497867	et	4	main
et	doc_842434202406_item	3497866	et	3	main
ei	doc_842434202406_item	3497868	et	4	main
ole	doc_842434202406_item	3497869	et	4	main
võimalust	doc_842434202406_item	3497870	et	3	main
midagi	doc_842434202406_item	3497871	et	4	main
ei	doc_842434202406_item	3497872	et	4	main
saa	doc_842434202406_item	3497873	et	4	main
teha	doc_842434202406_item	3497874	et	3	main
et	doc_842434202406_item	3497877	et	3	main
ootavad	doc_842434202406_item	3497880	et	4	main
жалко	doc_842434202406_item	3497888	et	2	main
ei	doc_842434202406_item	3497891	et	4	main
lapimaa	doc_842434202406_item	3497902	et	4	main
jõulu	doc_842434202406_item	3497903	et	4	main
kord	doc_842434202406_item	3497913	et	4	main
ma	doc_842434202406_item	3497915	et	3	main
lehte	doc_842434202406_item	3497921	et	4	main
panna	doc_842434202406_item	3497925	et	4	main
päeva	doc_842434202406_item	3497959	et	4	main
oli	doc_842434202406_item	3497960	et	3	main
sõit	doc_842434202406_item	3497967	et	3	main
kahekümne	doc_842434202406_item	3497976	et	4	main
detsembrini	doc_842434202406_item	3497978	et	3	main
helsingi	doc_842434202406_item	3497987	et	4	main
ja	doc_842434202406_item	3497988	et	3	main
hotellis	doc_842434202406_item	3497999	et	3	main
üheteist	doc_842434202406_item	3498002	et	4	main
ja	doc_842434202406_item	3497795	et	3	main
hakkame	doc_842434202406_item	3497797	et	3	main
vot	doc_842434202406_item	3497808	et	3	main
tulevad	doc_842434202406_item	3497811	et	4	main
nii	doc_842434202406_item	3497820	et	3	main
üldse	doc_842434202406_item	3497822	et	3	main
nädalat	doc_842434202406_item	3497825	et	3	main
kõige	doc_842434202406_item	3497828	et	4	main
et	doc_842434202406_item	3497841	et	3	main
külla	doc_842434202406_item	3497846	et	4	main
nad	doc_842434202406_item	3497875	et	3	main
ma	doc_842434202406_item	3497884	et	3	main
ну	doc_842434202406_item	3497886	et	2	main
прям	doc_842434202406_item	3497890	et	2	main
midagi	doc_842434202406_item	3497894	et	4	main
teha	doc_842434202406_item	3497895	et	3	main
ei	doc_842434202406_item	3497896	et	4	main
ajal	doc_842434202406_item	3497904	et	4	main
ma	doc_842434202406_item	3497905	et	3	main
tahtsin	doc_842434202406_item	3497906	et	3	main
juba	doc_842434202406_item	3497907	et	3	main
varem	doc_842434202406_item	3497908	et	4	main
ole	doc_842434202406_item	3497918	et	4	main
passis	doc_842434202406_item	3497919	et	4	main
kolm	doc_842434202406_item	3497958	et	3	main
ja	doc_842434202406_item	3497963	et	3	main
lapimaa	doc_842434202406_item	3497969	et	4	main
vot	doc_842434202406_item	3497970	et	3	main
kahekümne	doc_842434202406_item	3497974	et	4	main
paroomiga	doc_842434202406_item	3497985	et	4	main
hommikusöök	doc_842434202406_item	3498000	et	3	main
külastamine	doc_842434202406_item	3498009	et	4	main
akvaparki	doc_842434202406_item	3498037	et	4	main
on	doc_842434202406_item	3498076	et	4	main
kolmandal	doc_842434202406_item	3498078	et	3	main
kahekümne	doc_842434202406_item	3498079	et	4	main
kaheksandani	doc_842434202406_item	3498080	et	3	main
detsembrini	doc_842434202406_item	3498081	et	3	main
kaks	doc_842434202406_item	3498088	et	3	main
öö	doc_842434202406_item	3498089	et	4	main
bussis	doc_842434202406_item	3498090	et	3	main
ja	doc_842434202406_item	3498091	et	3	main
hotell	doc_842434202406_item	3498092	et	3	main
on	doc_842434202406_item	3498093	et	4	main
ka	doc_842434202406_item	3498094	et	3	main
parem	doc_842434202406_item	3498095	et	4	main
variant	doc_842434202406_item	3498102	et	3	main
juba	doc_842434202406_item	3498104	et	3	main
ma	doc_842434202406_item	3498106	et	3	main
mulle	doc_842434202406_item	3498132	et	4	main
meeldib	doc_842434202406_item	3498133	et	3	main
väga	doc_842434202406_item	3498134	et	3	main
see	doc_842434202406_item	3498135	et	3	main
tulen	doc_842434202406_item	3497879	et	3	main
никак	doc_842434202406_item	3497889	et	2	main
saa	doc_842434202406_item	3497892	et	4	main
no	doc_842434202406_item	3497893	et	3	main
kui	doc_842434202406_item	3497914	et	3	main
ei	doc_842434202406_item	3497917	et	4	main
soome	doc_842434202406_item	3497923	et	3	main
pärast	doc_842434202406_item	3497926	et	4	main
nagu	doc_842434202406_item	3497929	et	3	main
solvusin	doc_842434202406_item	3497930	et	3	main
sellesse	doc_842434202406_item	3497931	et	4	main
ei	doc_842434202406_item	3497932	et	4	main
püüdsi	doc_842434202406_item	3497933	et	4	main
rohkem	doc_842434202406_item	3497934	et	4	main
sügisel	doc_842434202406_item	3497935	et	3	main
me	doc_842434202406_item	3497936	et	4	main
ei	doc_842434202406_item	3497937	et	4	main
käinud	doc_842434202406_item	3497938	et	4	main
kuhugi	doc_842434202406_item	3497939	et	4	main
ja	doc_842434202406_item	3497940	et	3	main
praegu	doc_842434202406_item	3497941	et	3	main
vot	doc_842434202406_item	3497942	et	3	main
ma	doc_842434202406_item	3497943	et	3	main
lootsin	doc_842434202406_item	3497944	et	4	main
et	doc_842434202406_item	3497945	et	3	main
sõidame	doc_842434202406_item	3497947	et	3	main
ukraina	doc_842434202406_item	3497948	et	4	main
me	doc_842434202406_item	3497946	et	4	main
ei	doc_842434202406_item	3497949	et	4	main
tule	doc_842434202406_item	3497950	et	4	main
välja	doc_842434202406_item	3497951	et	4	main
ma	doc_842434202406_item	3497952	et	3	main
leidsin	doc_842434202406_item	3497953	et	3	main
seda	doc_842434202406_item	3497954	et	3	main
reisi	doc_842434202406_item	3497955	et	4	main
siin	doc_842434202406_item	3497956	et	4	main
on	doc_842434202406_item	3497957	et	4	main
pakkusid	doc_842434202406_item	3497962	et	4	main
valisin	doc_842434202406_item	3497965	et	3	main
endale	doc_842434202406_item	3497966	et	4	main
bussiga	doc_842434202406_item	3497968	et	3	main
siin	doc_842434202406_item	3497971	et	4	main
see	doc_842434202406_item	3497972	et	3	main
päev	doc_842434202406_item	3497980	et	3	main
seitse	doc_842434202406_item	3497982	et	3	main
lapimaa	doc_842434202406_item	3497990	et	4	main
päev	doc_842434202406_item	3497992	et	3	main
sõidus	doc_842434202406_item	3497993	et	3	main
teine	doc_842434202406_item	3497994	et	3	main
päev	doc_842434202406_item	3497995	et	3	main
kell	doc_842434202406_item	3497996	et	3	main
kaheksa	doc_842434202406_item	3497997	et	4	main
kaheteistkümneni	doc_842434202406_item	3498004	et	4	main
käimine	doc_842434202406_item	3498015	et	4	main
neliteist	doc_842434202406_item	3498034	et	4	main
kell	doc_842434202406_item	3498035	et	3	main
kuueteistkümneni	doc_842434202406_item	3498036	et	4	main
kaks	doc_842434202406_item	3498041	et	3	main
helsingi	doc_842434202406_item	3498043	et	4	main
kaheksa	doc_842434202406_item	3498050	et	4	main
paroomiga	doc_842434202406_item	3498051	et	4	main
tallinna	doc_842434202406_item	3498052	et	4	main
kell	doc_842434202406_item	3498053	et	3	main
pool	doc_842434202406_item	3498054	et	4	main
kaksteist	doc_842434202406_item	3498055	et	4	main
juba	doc_842434202406_item	3498056	et	3	main
tallinnas	doc_842434202406_item	3498057	et	4	main
asi	doc_842434202406_item	3498058	et	4	main
on	doc_842434202406_item	3498059	et	4	main
et	doc_842434202406_item	3498061	et	3	main
see	doc_842434202406_item	3498062	et	3	main
ei	doc_842434202406_item	3498063	et	4	main
selles	doc_842434202406_item	3498060	et	4	main
ole	doc_842434202406_item	3498064	et	4	main
hea	doc_842434202406_item	3498065	et	4	main
sest	doc_842434202406_item	3498066	et	4	main
et	doc_842434202406_item	3498067	et	3	main
kaks	doc_842434202406_item	3498068	et	3	main
öö	doc_842434202406_item	3498069	et	4	main
bussis	doc_842434202406_item	3498070	et	3	main
aga	doc_842434202406_item	3498071	et	3	main
on	doc_842434202406_item	3498072	et	4	main
veel	doc_842434202406_item	3498073	et	4	main
variant	doc_842434202406_item	3498074	et	3	main
seal	doc_842434202406_item	3498082	et	4	main
ükskoik	doc_842434202406_item	3498087	et	4	main
on	doc_842434202406_item	3498103	et	4	main
kahjuks	doc_842434202406_item	3498112	et	4	main
on	doc_842434202406_item	3498121	et	4	main
ka	doc_842434202406_item	3498122	et	3	main
on	doc_842434202406_item	3498130	et	4	main
üldse	doc_842434202406_item	3498131	et	3	main
tea	doc_842434202406_item	3498139	et	4	main
mobil	doc_542009824807_item	3498162	et	4	main
leiab	doc_542009824807_item	3498164	et	3	main
mobil	doc_542009824807_item	3498166	et	4	main
muud	doc_542009824807_item	3498182	et	4	main
on	doc_542009824807_item	3498187	et	4	main
paika	doc_542009824807_item	3498213	et	4	main
on	doc_542009824807_item	3498221	et	4	main
jäänud	doc_542009824807_item	3498222	et	4	main
üheksandani	doc_842434202406_item	3497977	et	3	main
kell	doc_842434202406_item	3497981	et	3	main
tulek	doc_842434202406_item	3497986	et	3	main
on	doc_842434202406_item	3497998	et	4	main
kell	doc_842434202406_item	3498001	et	3	main
kell	doc_842434202406_item	3498003	et	3	main
klausi	doc_842434202406_item	3498007	et	4	main
maja	doc_842434202406_item	3498008	et	4	main
ringist	doc_842434202406_item	3498014	et	3	main
ja	doc_842434202406_item	3498017	et	3	main
kell	doc_842434202406_item	3498018	et	3	main
lossi	doc_842434202406_item	3498028	et	4	main
külastamine	doc_842434202406_item	3498032	et	4	main
kell	doc_842434202406_item	3498033	et	3	main
kakskümmend	doc_842434202406_item	3498040	et	4	main
öö	doc_842434202406_item	3498044	et	4	main
bussis	doc_842434202406_item	3498045	et	3	main
tulek	doc_842434202406_item	3498046	et	3	main
kell	doc_842434202406_item	3498047	et	3	main
seitse	doc_842434202406_item	3498048	et	3	main
kell	doc_842434202406_item	3498049	et	3	main
see	doc_842434202406_item	3498075	et	3	main
suur	doc_842434202406_item	3498084	et	3	main
seal	doc_842434202406_item	3498096	et	4	main
on	doc_842434202406_item	3498097	et	4	main
bassein	doc_842434202406_item	3498098	et	3	main
ja	doc_842434202406_item	3498099	et	3	main
sauna	doc_842434202406_item	3498100	et	4	main
hea	doc_842434202406_item	3498107	et	4	main
meelega	doc_842434202406_item	3498108	et	4	main
sõidaksin	doc_842434202406_item	3498109	et	3	main
ainult	doc_842434202406_item	3498115	et	4	main
üks	doc_842434202406_item	3498116	et	3	main
päev	doc_842434202406_item	3498117	et	3	main
huvitav	doc_842434202406_item	3498128	et	4	main
ei	doc_842434202406_item	3498138	et	4	main
see	doc_542009824807_item	3498168	et	3	main
saab	doc_542009824807_item	3498174	et	3	main
saada	doc_542009824807_item	3498175	et	4	main
sms-i	doc_542009824807_item	3498176	et	4	main
e-postid	doc_542009824807_item	3498177	et	3	main
postkaarteid	doc_542009824807_item	3498178	et	3	main
saab	doc_542009824807_item	3498179	et	3	main
pildistama	doc_542009824807_item	3498180	et	3	main
ja	doc_542009824807_item	3498181	et	3	main
navigatsiooni	doc_542009824807_item	3498188	et	4	main
paljukilomeetreid	doc_542009824807_item	3498220	et	4	main
kaardit	doc_542009824807_item	3498228	et	4	main
ja	doc_542009824807_item	3498229	et	3	main
kui	doc_542009824807_item	3498230	et	3	main
olete	doc_542009824807_item	3498231	et	3	main
puhkereisis	doc_542009824807_item	3498232	et	3	main
õige	doc_542009824807_item	3498241	et	4	main
popova	doc_40918597559_item	3498268	et	4	main
08041938	doc_40918597559_item	3498272	et	2	main
51	doc_40918597559_item	3498274	et	2	main
number	doc_40918597559_item	3498275	et	3	main
faehlmanni	doc_40918597559_item	3498288	et	4	main
asutatud	doc_40918597559_item	3498310	et	4	main
ja	doc_40918597559_item	3498311	et	3	main
teostab	doc_40918597559_item	3498312	et	3	main
oma	doc_40918597559_item	3498313	et	4	main
virgiinia	doc_40918597559_item	3498317	et	4	main
saarte	doc_40918597559_item	3498318	et	3	main
seadusandlusega	doc_40918597559_item	3498319	et	3	main
nr	doc_40918597559_item	3498327	et	4	main
poolt	doc_40918597559_item	3498335	et	4	main
box	doc_40918597559_item	3498339	et	4	main
146	doc_40918597559_item	3498340	et	2	main
kindlaks	doc_40918597559_item	3498374	et	3	main
posti	doc_842434202406_item	3498010	et	4	main
külastamine	doc_842434202406_item	3498011	et	4	main
ka	doc_842434202406_item	3498012	et	3	main
poijari	doc_842434202406_item	3498013	et	4	main
läbi	doc_842434202406_item	3498016	et	4	main
üheksateist	doc_842434202406_item	3498019	et	4	main
hotelli	doc_842434202406_item	3498020	et	4	main
tulek	doc_842434202406_item	3498021	et	3	main
puhkus	doc_842434202406_item	3498022	et	3	main
kolmas	doc_842434202406_item	3498023	et	3	main
päev	doc_842434202406_item	3498024	et	3	main
hommikusöök	doc_842434202406_item	3498025	et	3	main
loomaaeda	doc_842434202406_item	3498026	et	4	main
ja	doc_842434202406_item	3498029	et	3	main
vabariigi	doc_842434202406_item	3498031	et	3	main
väljumine	doc_842434202406_item	3498042	et	4	main
pidu	doc_842434202406_item	3498085	et	4	main
aga	doc_842434202406_item	3498086	et	3	main
rongiga	doc_842434202406_item	3498110	et	4	main
aga	doc_842434202406_item	3498111	et	3	main
lapimaal	doc_842434202406_item	3498118	et	4	main
kolmandas	doc_842434202406_item	3498119	et	3	main
variandis	doc_842434202406_item	3498120	et	3	main
helsingi	doc_842434202406_item	3498129	et	4	main
mulle	doc_842434202406_item	3498141	et	4	main
meeldivad	doc_842434202406_item	3498142	et	4	main
s	doc_842434202406_item	3498143	et	4	main
oomlased	doc_842434202406_item	3498144	et	2	main
vale	doc_842434202406_item	3498145	et	4	main
rõhk	doc_842434202406_item	3498146	et	3	main
ja	doc_842434202406_item	3498147	et	3	main
soome	doc_842434202406_item	3498148	et	3	main
üldse	doc_842434202406_item	3498149	et	3	main
telefon	doc_542009824807_item	3498163	et	3	main
tee	doc_542009824807_item	3498165	et	4	main
telefon	doc_542009824807_item	3498167	et	3	main
mobil	doc_542009824807_item	3498172	et	4	main
mitmest	doc_542009824807_item	3498186	et	4	main
seal	doc_542009824807_item	3498214	et	4	main
te	doc_542009824807_item	3498215	et	4	main
või	doc_542009824807_item	3498233	et	4	main
ekskursioonis	doc_542009824807_item	3498234	et	3	main
ja	doc_542009824807_item	3498235	et	3	main
tee	doc_542009824807_item	3498242	et	4	main
tarkvara	doc_542009824807_item	3498258	et	4	main
väga	doc_542009824807_item	3498260	et	3	main
tatjana	doc_40918597559_item	3498269	et	4	main
sünd	doc_40918597559_item	3498271	et	3	main
pass	doc_40918597559_item	3498273	et	3	main
3316838	doc_40918597559_item	3498276	et	2	main
väljaantud	doc_40918597559_item	3498277	et	4	main
16112007	doc_40918597559_item	3498278	et	2	main
eestis	doc_40918597559_item	3498282	et	3	main
üheltpoolt	doc_40918597559_item	3498297	et	4	main
commertional	doc_40918597559_item	3498300	et	4	main
juriidiline	doc_40918597559_item	3498307	et	3	main
isik	doc_40918597559_item	3498308	et	3	main
on	doc_40918597559_item	3498309	et	4	main
suurbritaannia	doc_40918597559_item	3498316	et	4	main
mis	doc_40918597559_item	3498320	et	4	main
on	doc_40918597559_item	3498321	et	4	main
aadressil	doc_40918597559_item	3498336	et	3	main
o	doc_40918597559_item	3498338	et	4	main
road	doc_40918597559_item	3498341	et	4	main
islands	doc_40918597559_item	3498346	et	4	main
edaspidi	doc_40918597559_item	3498347	et	3	main
määratud	doc_40918597559_item	3498375	et	4	main
tänapäevane	doc_542009824807_item	3498170	et	4	main
saavutus	doc_542009824807_item	3498171	et	4	main
telefon	doc_542009824807_item	3498173	et	3	main
tarkvara	doc_542009824807_item	3498189	et	4	main
see	doc_542009824807_item	3498190	et	3	main
funktsion	doc_542009824807_item	3498191	et	4	main
aitab	doc_542009824807_item	3498192	et	3	main
inimestele	doc_542009824807_item	3498193	et	3	main
oiget	doc_542009824807_item	3498194	et	4	main
leida	doc_542009824807_item	3498196	et	3	main
kui	doc_542009824807_item	3498197	et	3	main
te	doc_542009824807_item	3498198	et	4	main
eksite	doc_542009824807_item	3498199	et	3	main
teed	doc_542009824807_item	3498195	et	4	main
te	doc_542009824807_item	3498200	et	4	main
saate	doc_542009824807_item	3498201	et	4	main
leida	doc_542009824807_item	3498202	et	3	main
oma	doc_542009824807_item	3498203	et	4	main
asu	doc_542009824807_item	3498204	et	4	main
koht	doc_542009824807_item	3498205	et	3	main
internetis	doc_542009824807_item	3498206	et	4	main
ja	doc_542009824807_item	3498207	et	3	main
seal	doc_542009824807_item	3498208	et	4	main
on	doc_542009824807_item	3498209	et	4	main
ka	doc_542009824807_item	3498210	et	3	main
kardit	doc_542009824807_item	3498211	et	4	main
saate	doc_542009824807_item	3498216	et	4	main
seal	doc_542009824807_item	3498225	et	4	main
te	doc_542009824807_item	3498238	et	4	main
mobil	doc_542009824807_item	3498243	et	4	main
telefoni	doc_542009824807_item	3498244	et	4	main
abiga	doc_542009824807_item	3498245	et	3	main
ja	doc_542009824807_item	3498246	et	3	main
mobil	doc_542009824807_item	3498247	et	4	main
telefon	doc_542009824807_item	3498248	et	3	main
ei	doc_542009824807_item	3498249	et	4	main
ole	doc_542009824807_item	3498250	et	4	main
suur	doc_542009824807_item	3498251	et	3	main
ja	doc_542009824807_item	3498252	et	3	main
ronib	doc_542009824807_item	3498253	et	3	main
taskusse	doc_542009824807_item	3498254	et	3	main
nii	doc_542009824807_item	3498255	et	3	main
kuni	doc_542009824807_item	3498223	et	3	main
eesmärkeni	doc_542009824807_item	3498224	et	3	main
eksite	doc_542009824807_item	3498236	et	3	main
tee	doc_542009824807_item	3498237	et	4	main
navigatsiooni	doc_542009824807_item	3498257	et	4	main
müümise-ostu	doc_40918597559_item	3498266	et	4	main
semjonova	doc_40918597559_item	3498270	et	4	main
venemaa	doc_40918597559_item	3498280	et	4	main
10125	doc_40918597559_item	3498285	et	2	main
maja	doc_40918597559_item	3498290	et	4	main
international	doc_40918597559_item	3498299	et	4	main
company	doc_40918597559_item	3498301	et	4	main
rollinz	doc_40918597559_item	3498302	et	4	main
inustments	doc_40918597559_item	3498303	et	4	main
sa	doc_40918597559_item	3498304	et	3	main
a	doc_40918597559_item	3498326	et	4	main
registraatori	doc_40918597559_item	3498334	et	3	main
tortola	doc_40918597559_item	3498343	et	4	main
väärpaberid	doc_40918597559_item	3498376	et	3	main
ostja	doc_40918597559_item	3498348	et	4	main
direktor	doc_40918597559_item	3498349	et	3	main
purim	doc_40918597559_item	3498350	et	4	main
konstantin	doc_40918597559_item	3498351	et	4	main
jurjevitš	doc_40918597559_item	3498352	et	2	main
kes	doc_40918597559_item	3498353	et	4	main
tegutseb	doc_40918597559_item	3498354	et	3	main
põhikirja	doc_40918597559_item	3498355	et	4	main
alusel	doc_40918597559_item	3498356	et	4	main
teiselt	doc_40918597559_item	3498357	et	4	main
poolt	doc_40918597559_item	3498358	et	4	main
sõlminud	doc_40918597559_item	3498359	et	4	main
käesolev	doc_40918597559_item	3498360	et	3	main
leping	doc_40918597559_item	3498361	et	3	main
järgnevas	doc_40918597559_item	3498362	et	4	main
lepingu	doc_40918597559_item	3498363	et	3	main
sisu	doc_40918597559_item	3498364	et	4	main
käesoleva	doc_40918597559_item	3498365	et	3	main
lepingu	doc_40918597559_item	3498366	et	3	main
alusel	doc_40918597559_item	3498367	et	4	main
müüa	doc_40918597559_item	3498368	et	3	main
annab	doc_40918597559_item	3498369	et	3	main
ostja	doc_40918597559_item	3498370	et	4	main
omandusele	doc_40918597559_item	3498371	et	4	main
käesoleva	doc_40918597559_item	3498372	et	3	main
lepingu	doc_40918597559_item	3498373	et	3	main
leping	doc_40918597559_item	3498264	et	3	main
aktsiate	doc_40918597559_item	3498265	et	3	main
saatkonna	doc_40918597559_item	3498281	et	4	main
poolt	doc_40918597559_item	3498283	et	4	main
tn	doc_40918597559_item	3498289	et	4	main
nr	doc_40918597559_item	3498291	et	4	main
2	doc_40918597559_item	3498292	et	2	main
kr	doc_40918597559_item	3498293	et	4	main
7	doc_40918597559_item	3498294	et	2	main
edaspidi	doc_40918597559_item	3498295	et	3	main
müüa	doc_40918597559_item	3498296	et	3	main
mis	doc_40918597559_item	3498305	et	4	main
tegevust	doc_40918597559_item	3498314	et	4	main
418606	doc_40918597559_item	3498328	et	2	main
suurbritannia	doc_40918597559_item	3498329	et	4	main
virginia	doc_40918597559_item	3498330	et	4	main
saarte	doc_40918597559_item	3498331	et	3	main
korporatiivsete	doc_40918597559_item	3498332	et	3	main
küsimuste	doc_40918597559_item	3498333	et	4	main
p	doc_40918597559_item	3498337	et	4	main
british	doc_40918597559_item	3498344	et	4	main
virgin	doc_40918597559_item	3498345	et	4	main
ostu-müügi	doc_40918597560_item	3498736	et	4	main
maja	doc_40918597560_item	3498762	et	4	main
2	doc_40918597560_item	3498763	et	2	main
nr	doc_40918597560_item	3498796	et	4	main
poolt	doc_40918597560_item	3498805	et	4	main
briti	doc_40918597560_item	3498811	et	4	main
virgihi	doc_40918597560_item	3498812	et	4	main
saared	doc_40918597560_item	3498813	et	3	main
kelleks	doc_40918597560_item	3498816	et	4	main
purim	doc_40918597560_item	3498822	et	4	main
lepingu	doc_40918597560_item	3498823	et	3	main
üle	doc_40918597560_item	3498833	et	3	main
poolt	doc_40918597560_item	3498867	et	4	main
koosneb	doc_40918597560_item	3498872	et	3	main
järgmistest	doc_40918597560_item	3498873	et	3	main
aktsiad	doc_40918597560_item	3498880	et	3	main
sovstrah	doc_40918597560_item	3498883	et	4	main
asukohaga	doc_40918597560_item	3498884	et	4	main
väärt	doc_40918597560_item	3498893	et	4	main
paberite	doc_40918597560_item	3498894	et	3	main
registrinumber	doc_40918597560_item	3498895	et	3	main
eest	doc_40918597560_item	3498906	et	4	main
2000	doc_40918597559_item	3498325	et	2	main
town	doc_40918597559_item	3498342	et	4	main
moskva	doc_40918597560_item	3498738	et	4	main
tatjana	doc_40918597560_item	3498741	et	4	main
föderatsiooni	doc_40918597560_item	3498755	et	4	main
elukoha	doc_40918597560_item	3498758	et	4	main
poolt	doc_40918597560_item	3498772	et	4	main
a	doc_40918597560_item	3498795	et	4	main
briti	doc_40918597560_item	3498798	et	4	main
virgini	doc_40918597560_item	3498799	et	3	main
asukohaga	doc_40918597560_item	3498806	et	4	main
town	doc_40918597560_item	3498807	et	4	main
edaspidi	doc_40918597560_item	3498814	et	3	main
konstantin	doc_40918597560_item	3498821	et	4	main
ostjale	doc_40918597560_item	3498832	et	4	main
antud	doc_40918597560_item	3498869	et	4	main
tn	doc_40918597560_item	3498888	et	4	main
10302161a	doc_40918597560_item	3498897	et	4	main
maksumus	doc_40918597560_item	3498901	et	3	main
kogus	doc_40918597560_item	3498909	et	4	main
föderatsioon	doc_40918597560_item	3498740	et	3	main
08	doc_40918597560_item	3498743	et	2	main
1938	doc_40918597560_item	3498745	et	2	main
a	doc_40918597560_item	3498746	et	4	main
passi	doc_40918597560_item	3498747	et	4	main
number	doc_40918597560_item	3498748	et	3	main
51	doc_40918597560_item	3498749	et	2	main
3316838	doc_40918597560_item	3498750	et	2	main
korter	doc_40918597560_item	3498764	et	3	main
tallinn	doc_40918597560_item	3498765	et	4	main
10125	doc_40918597560_item	3498766	et	2	main
teiselt	doc_40918597560_item	3498771	et	4	main
tegeleva	doc_40918597560_item	3498803	et	4	main
registraatori	doc_40918597560_item	3498804	et	3	main
tortola	doc_40918597560_item	3498810	et	4	main
ostja	doc_40918597560_item	3498815	et	4	main
on	doc_40918597560_item	3498817	et	4	main
põhikirja	doc_40918597560_item	3498818	et	4	main
ese	doc_40918597560_item	3498824	et	3	main
antud	doc_40918597560_item	3498825	et	4	main
lepingu	doc_40918597560_item	3498826	et	3	main
olema	doc_40918597560_item	3498864	et	4	main
edastatud	doc_40918597560_item	3498865	et	4	main
müüja	doc_40918597560_item	3498866	et	4	main
objekt	doc_40918597560_item	3498871	et	3	main
väärt	doc_40918597560_item	3498874	et	4	main
paberitest	doc_40918597560_item	3498875	et	4	main
vene	doc_40918597560_item	3498885	et	4	main
föderatsioon	doc_40918597560_item	3498886	et	3	main
roždestvenskaja	doc_40918597560_item	3498887	et	2	main
on	doc_40918597560_item	3498896	et	4	main
nominaal	doc_40918597560_item	3498900	et	4	main
rubla	doc_40918597560_item	3498903	et	4	main
aktsia	doc_40918597560_item	3498905	et	4	main
väärt	doc_40918597560_item	3498907	et	4	main
paberite	doc_40918597560_item	3498908	et	3	main
leping	doc_40918597560_item	3498734	et	3	main
vene	doc_40918597560_item	3498739	et	4	main
väljastatud	doc_40918597560_item	3498751	et	4	main
16112007	doc_40918597560_item	3498752	et	2	main
a	doc_40918597560_item	3498753	et	4	main
saatkonna	doc_40918597560_item	3498756	et	4	main
aadress	doc_40918597560_item	3498759	et	3	main
eesti	doc_40918597560_item	3498767	et	4	main
edaspidi	doc_40918597560_item	3498768	et	3	main
müüja	doc_40918597560_item	3498769	et	4	main
ja	doc_40918597560_item	3498770	et	3	main
mis	doc_40918597560_item	3498789	et	4	main
on	doc_40918597560_item	3498790	et	4	main
registreeritud	doc_40918597560_item	3498791	et	4	main
24	doc_40918597560_item	3498792	et	2	main
november	doc_40918597560_item	3498793	et	3	main
2007	doc_40918597560_item	3498794	et	2	main
418608	doc_40918597560_item	3498797	et	2	main
saarte	doc_40918597560_item	3498800	et	3	main
korporatiiv	doc_40918597560_item	3498801	et	4	main
tegutsev	doc_40918597560_item	3498820	et	4	main
müüja	doc_40918597560_item	3498828	et	4	main
kohustub	doc_40918597560_item	3498829	et	3	main
anda	doc_40918597560_item	3498830	et	3	main
väärtpabereid	doc_40918597560_item	3498831	et	3	main
lepingu	doc_40918597560_item	3498870	et	3	main
emitent	doc_40918597560_item	3498881	et	4	main
¼	doc_40918597560_item	3498890	et	2	main
moskva	doc_40918597560_item	3498891	et	4	main
109012	doc_40918597560_item	3498892	et	2	main
paberite	doc_40918597560_item	3498899	et	3	main
1	doc_40918597560_item	3498904	et	2	main
tükki	doc_40918597560_item	3498911	et	4	main
leping	doc_40918597562_item	3499184	et	3	main
25	doc_40918597562_item	3499188	et	2	main
2007	doc_40918597562_item	3499190	et	2	main
tatjana	doc_40918597562_item	3499191	et	4	main
popova	doc_40918597562_item	3499192	et	4	main
välja	doc_40918597562_item	3499197	et	4	main
antud	doc_40918597562_item	3499198	et	4	main
2	doc_40918597562_item	3499205	et	2	main
nr	doc_40918597562_item	3499206	et	4	main
7	doc_40918597562_item	3499207	et	2	main
aktsiate	doc_40918597560_item	3498735	et	3	main
leping	doc_40918597560_item	3498737	et	3	main
popova	doc_40918597560_item	3498742	et	4	main
aprill	doc_40918597560_item	3498744	et	3	main
vene	doc_40918597560_item	3498754	et	4	main
poolt	doc_40918597560_item	3498757	et	4	main
faehlmanni	doc_40918597560_item	3498760	et	4	main
tänav	doc_40918597560_item	3498761	et	4	main
juriidilisest	doc_40918597560_item	3498773	et	3	main
isikust	doc_40918597560_item	3498774	et	4	main
rahvusvaheline	doc_40918597560_item	3498775	et	4	main
kommerts	doc_40918597560_item	3498776	et	3	main
ettevõte	doc_40918597560_item	3498777	et	3	main
rollins	doc_40918597560_item	3498778	et	4	main
investment	doc_40918597560_item	3498779	et	4	main
mille	doc_40918597560_item	3498780	et	3	main
tegevus	doc_40918597560_item	3498781	et	4	main
on	doc_40918597560_item	3498782	et	4	main
kooskõlas	doc_40918597560_item	3498783	et	3	main
briti	doc_40918597560_item	3498784	et	4	main
virgihi	doc_40918597560_item	3498785	et	4	main
saarte	doc_40918597560_item	3498786	et	3	main
seadusandlusega	doc_40918597560_item	3498787	et	3	main
ning	doc_40918597560_item	3498788	et	3	main
küsimustega	doc_40918597560_item	3498802	et	4	main
mnt	doc_40918597560_item	3498808	et	4	main
145	doc_40918597560_item	3498809	et	2	main
alusel	doc_40918597560_item	3498819	et	4	main
alusel	doc_40918597560_item	3498827	et	4	main
ostja	doc_40918597560_item	3498834	et	4	main
omakorda	doc_40918597560_item	3498835	et	3	main
kohustub	doc_40918597560_item	3498836	et	3	main
nende	doc_40918597560_item	3498837	et	4	main
eest	doc_40918597560_item	3498838	et	4	main
maksta	doc_40918597560_item	3498839	et	4	main
lähtudes	doc_40918597560_item	3498840	et	3	main
alljärgnevatest	doc_40918597560_item	3498841	et	3	main
tingimustest	doc_40918597560_item	3498842	et	3	main
lepingu	doc_40918597560_item	3498843	et	3	main
objekt	doc_40918597560_item	3498844	et	3	main
antud	doc_40918597560_item	3498845	et	4	main
lepingu	doc_40918597560_item	3498846	et	3	main
objekti	doc_40918597560_item	3498847	et	4	main
all	doc_40918597560_item	3498848	et	3	main
mõtlevad	doc_40918597560_item	3498849	et	4	main
pooled	doc_40918597560_item	3498850	et	3	main
müüjale	doc_40918597560_item	3498851	et	4	main
kuuluvaid	doc_40918597560_item	3498852	et	4	main
omandi	doc_40918597560_item	3498853	et	3	main
õiguse	doc_40918597560_item	3498854	et	4	main
alusel	doc_40918597560_item	3498855	et	4	main
ja	doc_40918597560_item	3498856	et	3	main
igasugustest	doc_40918597560_item	3498857	et	3	main
kohustustest	doc_40918597560_item	3498858	et	4	main
vabad	doc_40918597560_item	3498859	et	3	main
pabereid	doc_40918597560_item	3498861	et	3	main
väärt	doc_40918597560_item	3498860	et	4	main
mis	doc_40918597560_item	3498862	et	4	main
peaksid	doc_40918597560_item	3498863	et	4	main
ostjale	doc_40918597560_item	3498868	et	4	main
väärt	doc_40918597560_item	3498876	et	4	main
paberite	doc_40918597560_item	3498877	et	3	main
liik	doc_40918597560_item	3498878	et	3	main
tavalised	doc_40918597560_item	3498879	et	4	main
as	doc_40918597560_item	3498882	et	4	main
maja	doc_40918597560_item	3498889	et	4	main
väärt	doc_40918597560_item	3498898	et	4	main
30	doc_40918597560_item	3498902	et	2	main
545	doc_40918597560_item	3498910	et	2	main
leping	doc_40918597562_item	3499181	et	3	main
passinumber	doc_40918597562_item	3499196	et	3	main
suursaatkonnas	doc_40918597562_item	3499200	et	4	main
eesti	doc_40918597562_item	3499210	et	4	main
rahvusvaheline	doc_40918597562_item	3499218	et	4	main
rollins	doc_40918597562_item	3499220	et	4	main
investments	doc_40918597562_item	3499221	et	4	main
sa	doc_40918597562_item	3499222	et	3	main
418606	doc_40918597562_item	3499232	et	2	main
registreeritud	doc_40918597562_item	3499233	et	4	main
24112000	doc_40918597562_item	3499234	et	2	main
road	doc_40918597562_item	3499244	et	4	main
islands	doc_40918597562_item	3499249	et	4	main
edaspidi	doc_40918597562_item	3499250	et	3	main
ostja	doc_40918597562_item	3499251	et	4	main
direktor	doc_40918597562_item	3499257	et	3	main
lepingu	doc_40918597562_item	3499264	et	3	main
lepinguese	doc_40918597562_item	3499266	et	3	main
lepingule	doc_40918597562_item	3499270	et	3	main
moskva	doc_40918597563_item	3499412	et	4	main
föderatsioon	doc_40918597563_item	3499414	et	3	main
25122007	doc_40918597563_item	3499415	et	2	main
sündinud	doc_40918597563_item	3499422	et	4	main
08041938	doc_40918597563_item	3499423	et	2	main
tallinn	doc_40918597563_item	3499428	et	4	main
ja	doc_40918597563_item	3499447	et	3	main
sa	doc_40918597563_item	3499452	et	3	main
on	doc_40918597563_item	3499454	et	4	main
määratud	doc_40918597563_item	3499455	et	4	main
juriidiliseks	doc_40918597563_item	3499456	et	3	main
rigistri	doc_40918597563_item	3499463	et	4	main
number	doc_40918597563_item	3499464	et	3	main
418606	doc_40918597563_item	3499465	et	2	main
registrisse	doc_40918597563_item	3499466	et	3	main
poolt	doc_40918597563_item	3499474	et	4	main
aadress	doc_40918597563_item	3499475	et	3	main
road	doc_40918597563_item	3499485	et	4	main
islands	doc_40918597563_item	3499490	et	4	main
väärtpaberite	doc_40918597562_item	3499182	et	3	main
föderatsioon	doc_40918597562_item	3499187	et	3	main
detsember	doc_40918597562_item	3499189	et	3	main
venemaa	doc_40918597562_item	3499199	et	4	main
elukoht	doc_40918597562_item	3499202	et	3	main
tegutsev	doc_40918597562_item	3499225	et	4	main
kooskõlas	doc_40918597562_item	3499226	et	3	main
ettevõtete	doc_40918597562_item	3499236	et	3	main
briti	doc_40918597562_item	3499239	et	4	main
british	doc_40918597562_item	3499247	et	4	main
kooskõlas	doc_40918597562_item	3499255	et	3	main
purim	doc_40918597562_item	3499259	et	4	main
teiselt	doc_40918597562_item	3499260	et	4	main
poolt	doc_40918597562_item	3499261	et	4	main
semjonovna	doc_40918597563_item	3499421	et	4	main
10125	doc_40918597563_item	3499429	et	2	main
antud	doc_40918597563_item	3499435	et	4	main
asuva	doc_40918597563_item	3499439	et	4	main
müüja	doc_40918597563_item	3499445	et	4	main
äriselts	doc_40918597563_item	3499449	et	3	main
146	doc_40918597563_item	3499484	et	2	main
tortola	doc_40918597563_item	3499487	et	4	main
virgin	doc_40918597563_item	3499489	et	4	main
ostu-müügi	doc_40918597562_item	3499183	et	4	main
vene	doc_40918597562_item	3499186	et	4	main
a	doc_40918597562_item	3499195	et	4	main
tallinn	doc_40918597562_item	3499208	et	4	main
10125	doc_40918597562_item	3499209	et	2	main
asutatud	doc_40918597562_item	3499223	et	4	main
ja	doc_40918597562_item	3499224	et	3	main
a	doc_40918597562_item	3499235	et	4	main
poolt	doc_40918597562_item	3499238	et	4	main
saartel	doc_40918597562_item	3499240	et	3	main
asukoht	doc_40918597562_item	3499241	et	3	main
pobox	doc_40918597562_item	3499242	et	4	main
146	doc_40918597562_item	3499243	et	2	main
virgin	doc_40918597562_item	3499248	et	4	main
käesoleva	doc_40918597562_item	3499296	et	3	main
lepingu	doc_40918597562_item	3499297	et	3	main
objektiks	doc_40918597562_item	3499298	et	3	main
mõistavad	doc_40918597562_item	3499299	et	3	main
pooled	doc_40918597562_item	3499300	et	3	main
müüjale	doc_40918597562_item	3499301	et	4	main
omandiõigusega	doc_40918597562_item	3499302	et	4	main
kuuluvad	doc_40918597562_item	3499303	et	4	main
ja	doc_40918597562_item	3499304	et	3	main
kõiksugustest	doc_40918597562_item	3499305	et	3	main
kohustustest	doc_40918597562_item	3499306	et	4	main
vabad	doc_40918597562_item	3499307	et	3	main
väärtpaberid	doc_40918597562_item	3499308	et	3	main
mis	doc_40918597562_item	3499309	et	4	main
müüja	doc_40918597562_item	3499310	et	4	main
annab	doc_40918597562_item	3499311	et	3	main
ostja	doc_40918597562_item	3499312	et	4	main
omandisse	doc_40918597562_item	3499313	et	3	main
üle	doc_40918597562_item	3499314	et	3	main
moskva	doc_40918597562_item	3499185	et	4	main
sündinud	doc_40918597562_item	3499193	et	4	main
08041938	doc_40918597562_item	3499194	et	2	main
eestis	doc_40918597562_item	3499201	et	3	main
faelhmanni	doc_40918597562_item	3499203	et	4	main
tn	doc_40918597562_item	3499204	et	4	main
edaspidi	doc_40918597562_item	3499211	et	3	main
müüja	doc_40918597562_item	3499212	et	4	main
ühelt	doc_40918597562_item	3499213	et	3	main
poolt	doc_40918597562_item	3499214	et	4	main
isik	doc_40918597562_item	3499217	et	3	main
briti	doc_40918597562_item	3499227	et	4	main
saarte	doc_40918597562_item	3499228	et	3	main
seadustega	doc_40918597562_item	3499229	et	3	main
reg	doc_40918597562_item	3499230	et	4	main
number	doc_40918597562_item	3499231	et	3	main
registreerija	doc_40918597562_item	3499237	et	4	main
tegutsev	doc_40918597562_item	3499256	et	4	main
konstantin	doc_40918597562_item	3499258	et	4	main
vastavalt	doc_40918597562_item	3499268	et	4	main
annab	doc_40918597562_item	3499271	et	3	main
käesoleva	doc_40918597562_item	3499273	et	3	main
lepinguga	doc_40918597562_item	3499274	et	3	main
määratud	doc_40918597562_item	3499275	et	4	main
väärtpaberid	doc_40918597562_item	3499276	et	3	main
üle	doc_40918597562_item	3499277	et	3	main
ostja	doc_40918597562_item	3499278	et	4	main
omandisse	doc_40918597562_item	3499279	et	3	main
ostja	doc_40918597562_item	3499280	et	4	main
kohustub	doc_40918597562_item	3499281	et	3	main
need	doc_40918597562_item	3499282	et	3	main
vastu	doc_40918597562_item	3499283	et	3	main
võtma	doc_40918597562_item	3499284	et	3	main
ja	doc_40918597562_item	3499285	et	3	main
vastavalt	doc_40918597562_item	3499286	et	4	main
allpool	doc_40918597562_item	3499287	et	3	main
toodud	doc_40918597562_item	3499288	et	4	main
tingimustele	doc_40918597562_item	3499289	et	3	main
nende	doc_40918597562_item	3499290	et	4	main
eest	doc_40918597562_item	3499291	et	4	main
2	doc_40918597562_item	3499293	et	2	main
tasuma	doc_40918597562_item	3499292	et	3	main
lepinguobjekt	doc_40918597562_item	3499294	et	3	main
21	doc_40918597562_item	3499295	et	2	main
popova	doc_40918597563_item	3499420	et	4	main
eesti	doc_40918597563_item	3499430	et	4	main
välja	doc_40918597563_item	3499434	et	4	main
föderatsiooni	doc_40918597563_item	3499441	et	4	main
ja	doc_40918597562_item	3499215	et	3	main
juriidiline	doc_40918597562_item	3499216	et	3	main
kommertskompanii	doc_40918597562_item	3499219	et	4	main
town	doc_40918597562_item	3499245	et	4	main
tortola	doc_40918597562_item	3499246	et	4	main
keda	doc_40918597562_item	3499252	et	4	main
esindab	doc_40918597562_item	3499253	et	3	main
põhikirjaga	doc_40918597562_item	3499254	et	3	main
sõlmisid	doc_40918597562_item	3499262	et	4	main
alljärgneva	doc_40918597562_item	3499263	et	3	main
1	doc_40918597562_item	3499265	et	2	main
11	doc_40918597562_item	3499267	et	2	main
käesolevale	doc_40918597562_item	3499269	et	3	main
müüja	doc_40918597562_item	3499272	et	4	main
leping	doc_40918597563_item	3499411	et	3	main
aktsiate	doc_40918597563_item	3499416	et	3	main
tatjana	doc_40918597563_item	3499419	et	4	main
a	doc_40918597563_item	3499424	et	4	main
aadress	doc_40918597563_item	3499425	et	3	main
faehlmanni	doc_40918597563_item	3499426	et	4	main
2-7	doc_40918597563_item	3499427	et	2	main
51	doc_40918597563_item	3499432	et	2	main
vene	doc_40918597563_item	3499440	et	4	main
üheltpoolt	doc_40918597563_item	3499446	et	4	main
kantud	doc_40918597563_item	3499467	et	4	main
24112000a	doc_40918597563_item	3499468	et	4	main
briti	doc_40918597563_item	3499469	et	4	main
neitsisaarte	doc_40918597563_item	3499470	et	3	main
korporatsiooniküsimustega	doc_40918597563_item	3499471	et	3	main
tegeleva	doc_40918597563_item	3499472	et	4	main
registraatori	doc_40918597563_item	3499473	et	3	main
briti	doc_40918597563_item	3499480	et	4	main
neitsisaared	doc_40918597563_item	3499481	et	3	main
po	doc_40918597563_item	3499482	et	4	main
british	doc_40918597563_item	3499488	et	4	main
2-7	doc_40918597564_item	3499614	et	2	main
jurjevitš	doc_40918597563_item	3499495	et	2	main
kes	doc_40918597563_item	3499496	et	4	main
tegutseb	doc_40918597563_item	3499497	et	3	main
põhiseaduse	doc_40918597563_item	3499498	et	3	main
alusel	doc_40918597563_item	3499499	et	4	main
edaspidi	doc_40918597563_item	3499500	et	3	main
ostja	doc_40918597563_item	3499501	et	4	main
teiseltpoolt	doc_40918597563_item	3499502	et	4	main
sõlmiti	doc_40918597563_item	3499503	et	3	main
käesolev	doc_40918597563_item	3499504	et	3	main
leping	doc_40918597563_item	3499505	et	3	main
alljärgnevast	doc_40918597563_item	3499506	et	3	main
kohta	doc_40918597563_item	3499507	et	4	main
vene	doc_40918597563_item	3499413	et	4	main
ostu-müügi	doc_40918597563_item	3499417	et	4	main
leping	doc_40918597563_item	3499418	et	3	main
pass	doc_40918597563_item	3499431	et	3	main
3316838	doc_40918597563_item	3499433	et	2	main
16112007	doc_40918597563_item	3499436	et	2	main
a	doc_40918597563_item	3499437	et	4	main
eestis	doc_40918597563_item	3499438	et	3	main
poolt	doc_40918597563_item	3499443	et	4	main
edaspidi	doc_40918597563_item	3499444	et	3	main
rahvusvaheline	doc_40918597563_item	3499448	et	4	main
investments	doc_40918597563_item	3499451	et	4	main
kes	doc_40918597563_item	3499453	et	4	main
briti	doc_40918597563_item	3499459	et	4	main
neitsisaarte	doc_40918597563_item	3499460	et	3	main
pobox	doc_40918597563_item	3499476	et	4	main
146	doc_40918597563_item	3499477	et	2	main
road	doc_40918597563_item	3499478	et	4	main
box	doc_40918597563_item	3499483	et	4	main
keda	doc_40918597563_item	3499491	et	4	main
esindab	doc_40918597563_item	3499492	et	3	main
konstantin	doc_40918597563_item	3499493	et	4	main
purim	doc_40918597563_item	3499494	et	4	main
leping	doc_40918597564_item	3499602	et	3	main
popova	doc_40918597564_item	3499607	et	4	main
semjonovna	doc_40918597564_item	3499608	et	4	main
tallinn	doc_40918597564_item	3499616	et	4	main
investments	doc_40918597564_item	3499638	et	4	main
määratud	doc_40918597564_item	3499640	et	4	main
juriidiliseks	doc_40918597564_item	3499641	et	3	main
tegeleva	doc_40918597564_item	3499660	et	4	main
registraatoriga	doc_40918597564_item	3499661	et	3	main
aadress	doc_40918597564_item	3499662	et	3	main
town	doc_40918597564_item	3499667	et	4	main
po	doc_40918597564_item	3499671	et	4	main
box	doc_40918597564_item	3499672	et	4	main
146	doc_40918597564_item	3499673	et	2	main
british	doc_40918597564_item	3499677	et	4	main
purim	doc_40918597564_item	3499683	et	4	main
jurjevitš	doc_40918597564_item	3499684	et	2	main
aktsiate	doc_40918597566_item	3499793	et	3	main
leping	doc_40918597566_item	3499796	et	3	main
sünd	doc_40918597566_item	3499800	et	3	main
föderatsiooni	doc_40918597566_item	3499811	et	4	main
faehlmanni	doc_40918597566_item	3499818	et	4	main
2-7	doc_40918597566_item	3499819	et	2	main
tortola	doc_40918597566_item	3499865	et	4	main
direktori	doc_40918597566_item	3499873	et	3	main
saatkonna	doc_40918597563_item	3499442	et	4	main
rollinz	doc_40918597563_item	3499450	et	4	main
isikuks	doc_40918597563_item	3499457	et	4	main
tegutseb	doc_40918597563_item	3499458	et	3	main
seaduste	doc_40918597563_item	3499461	et	4	main
alusel	doc_40918597563_item	3499462	et	4	main
town	doc_40918597563_item	3499479	et	4	main
town	doc_40918597563_item	3499486	et	4	main
leping	doc_40918597564_item	3499605	et	3	main
a	doc_40918597564_item	3499611	et	4	main
elukoht	doc_40918597564_item	3499612	et	3	main
faehlmanni	doc_40918597564_item	3499613	et	4	main
edaspidi	doc_40918597564_item	3499631	et	3	main
müüja	doc_40918597564_item	3499632	et	4	main
sa	doc_40918597564_item	3499639	et	3	main
seaduste	doc_40918597564_item	3499647	et	4	main
n	doc_40918597564_item	3499651	et	4	main
box	doc_40918597564_item	3499664	et	4	main
tortola	doc_40918597564_item	3499668	et	4	main
neitsisaared	doc_40918597564_item	3499670	et	3	main
tortola	doc_40918597564_item	3499676	et	4	main
konstantin	doc_40918597564_item	3499682	et	4	main
tatjana	doc_40918597564_item	3499606	et	4	main
rollings	doc_40918597564_item	3499637	et	4	main
tegutseb	doc_40918597564_item	3499644	et	3	main
briti	doc_40918597564_item	3499645	et	4	main
neitsisaarte	doc_40918597564_item	3499646	et	3	main
number	doc_40918597564_item	3499650	et	3	main
418606	doc_40918597564_item	3499652	et	2	main
po	doc_40918597564_item	3499663	et	4	main
146	doc_40918597564_item	3499665	et	2	main
road	doc_40918597564_item	3499666	et	4	main
briti	doc_40918597564_item	3499669	et	4	main
virgin	doc_40918597564_item	3499678	et	4	main
kes	doc_40918597564_item	3499685	et	4	main
popova	doc_40918597566_item	3499797	et	4	main
semjonova	doc_40918597566_item	3499799	et	4	main
poolt	doc_40918597566_item	3499813	et	4	main
elukoht	doc_40918597566_item	3499814	et	3	main
10125	doc_40918597566_item	3499816	et	2	main
tallinn	doc_40918597566_item	3499817	et	4	main
418606	doc_40918597566_item	3499851	et	2	main
suurbritannia	doc_40918597566_item	3499852	et	4	main
virgiinite	doc_40918597566_item	3499853	et	4	main
town	doc_40918597566_item	3499864	et	4	main
ostja	doc_40918597566_item	3499872	et	4	main
leping	doc_40918597568_item	3499980	et	3	main
semjonova	doc_40918597568_item	3499982	et	4	main
3316838	doc_40918597568_item	3499987	et	2	main
161107	doc_40918597568_item	3499990	et	2	main
a	doc_40918597568_item	3499991	et	4	main
vene	doc_40918597568_item	3499992	et	4	main
ostu-müügi	doc_40918597564_item	3499604	et	4	main
08041938	doc_40918597564_item	3499610	et	2	main
eesti	doc_40918597564_item	3499615	et	4	main
rahvusvaheline	doc_40918597564_item	3499635	et	4	main
äriselts	doc_40918597564_item	3499636	et	3	main
kes	doc_40918597564_item	3499643	et	4	main
registri	doc_40918597564_item	3499649	et	3	main
kantud	doc_40918597564_item	3499654	et	4	main
road	doc_40918597564_item	3499674	et	4	main
islands	doc_40918597564_item	3499679	et	4	main
leping	doc_40918597566_item	3499792	et	3	main
ostu	doc_40918597566_item	3499794	et	4	main
3316838	doc_40918597566_item	3499804	et	2	main
saatkonna	doc_40918597566_item	3499812	et	4	main
edasi	doc_40918597566_item	3499820	et	3	main
poolt	doc_40918597566_item	3499824	et	4	main
korporatiivse	doc_40918597566_item	3499855	et	4	main
poolt	doc_40918597566_item	3499858	et	4	main
po	doc_40918597566_item	3499860	et	4	main
box	doc_40918597566_item	3499861	et	4	main
konstantin	doc_40918597566_item	3499874	et	4	main
tegutseb	doc_40918597564_item	3499686	et	3	main
põhiseaduse	doc_40918597564_item	3499687	et	3	main
alusel	doc_40918597564_item	3499688	et	4	main
edaspidi	doc_40918597564_item	3499689	et	3	main
ostja	doc_40918597564_item	3499690	et	4	main
teiseltpoolt	doc_40918597564_item	3499691	et	4	main
on	doc_40918597564_item	3499692	et	4	main
sõlminud	doc_40918597564_item	3499693	et	4	main
käesoleva	doc_40918597564_item	3499694	et	3	main
lepingu	doc_40918597564_item	3499695	et	3	main
alljärgneva	doc_40918597564_item	3499696	et	3	main
kohta	doc_40918597564_item	3499697	et	4	main
aktsiate	doc_40918597564_item	3499603	et	3	main
sünd	doc_40918597564_item	3499609	et	3	main
10125	doc_40918597564_item	3499617	et	2	main
pass	doc_40918597564_item	3499618	et	3	main
51	doc_40918597564_item	3499619	et	2	main
n	doc_40918597564_item	3499620	et	4	main
3316838	doc_40918597564_item	3499621	et	2	main
välja	doc_40918597564_item	3499622	et	4	main
antud	doc_40918597564_item	3499623	et	4	main
16112007	doc_40918597564_item	3499624	et	2	main
eestis	doc_40918597564_item	3499625	et	3	main
asuva	doc_40918597564_item	3499626	et	4	main
vene	doc_40918597564_item	3499627	et	4	main
föderatsiooni	doc_40918597564_item	3499628	et	4	main
saatkonna	doc_40918597564_item	3499629	et	4	main
poolt	doc_40918597564_item	3499630	et	4	main
üheltpoolt	doc_40918597564_item	3499633	et	4	main
ja	doc_40918597564_item	3499634	et	3	main
isikuks	doc_40918597564_item	3499642	et	4	main
järgi	doc_40918597564_item	3499648	et	4	main
registrisse	doc_40918597564_item	3499653	et	3	main
24112000	doc_40918597564_item	3499655	et	2	main
a	doc_40918597564_item	3499656	et	4	main
briti	doc_40918597564_item	3499657	et	4	main
neitsisaarte	doc_40918597564_item	3499658	et	3	main
korporatsiooniküsimustega	doc_40918597564_item	3499659	et	3	main
town	doc_40918597564_item	3499675	et	4	main
keda	doc_40918597564_item	3499680	et	4	main
esindab	doc_40918597564_item	3499681	et	3	main
müügi	doc_40918597566_item	3499795	et	4	main
08041938	doc_40918597566_item	3499801	et	2	main
number	doc_40918597566_item	3499803	et	3	main
välja	doc_40918597566_item	3499805	et	4	main
16112007	doc_40918597566_item	3499807	et	2	main
eestis	doc_40918597566_item	3499808	et	3	main
müüja	doc_40918597566_item	3499822	et	4	main
küsimuste	doc_40918597566_item	3499856	et	4	main
suurbritannia	doc_40918597566_item	3499866	et	4	main
jurjevitši	doc_40918597566_item	3499875	et	2	main
ostu-müügi	doc_40918597568_item	3499979	et	4	main
tatjana	doc_40918597568_item	3499981	et	4	main
08041938	doc_40918597568_item	3499983	et	2	main
antud	doc_40918597568_item	3499989	et	4	main
tallinn	doc_40918597568_item	3500002	et	4	main
edasi	doc_40918597568_item	3500004	et	3	main
müüja	doc_40918597568_item	3500005	et	4	main
ühelt	doc_40918597568_item	3500006	et	3	main
investmens	doc_40918597568_item	3500013	et	4	main
mis	doc_40918597568_item	3500028	et	4	main
virginia	doc_40918597568_item	3500036	et	4	main
saarte	doc_40918597568_item	3500037	et	3	main
asukoht	doc_40918597568_item	3500041	et	3	main
box	doc_40918597568_item	3500043	et	4	main
road	doc_40918597568_item	3500045	et	4	main
islands	doc_40918597568_item	3500050	et	4	main
edasi	doc_40918597568_item	3500051	et	3	main
jurjevitš	doc_40918597568_item	3500058	et	2	main
alusel	doc_40918597568_item	3500062	et	4	main
poolt	doc_40918597568_item	3500064	et	4	main
purima	doc_40918597566_item	3499876	et	4	main
näol	doc_40918597566_item	3499877	et	4	main
kehtiv	doc_40918597566_item	3499878	et	4	main
kosskõlas	doc_40918597566_item	3499879	et	4	main
põhikirjaga	doc_40918597566_item	3499880	et	3	main
teiselt	doc_40918597566_item	3499881	et	4	main
poolt	doc_40918597566_item	3499882	et	4	main
sõlmisid	doc_40918597566_item	3499883	et	4	main
lepingu	doc_40918597566_item	3499885	et	3	main
järgneva	doc_40918597566_item	3499884	et	4	main
tatjana	doc_40918597566_item	3499798	et	4	main
passi	doc_40918597566_item	3499802	et	4	main
antud	doc_40918597566_item	3499806	et	4	main
asuva	doc_40918597566_item	3499809	et	4	main
vene	doc_40918597566_item	3499810	et	4	main
eesti	doc_40918597566_item	3499815	et	4	main
nimetatud	doc_40918597566_item	3499821	et	4	main
ühelt	doc_40918597566_item	3499823	et	3	main
ning	doc_40918597566_item	3499825	et	3	main
rahvusvaheline	doc_40918597566_item	3499826	et	4	main
kommerts	doc_40918597566_item	3499827	et	3	main
firma	doc_40918597566_item	3499828	et	4	main
rollinz	doc_40918597566_item	3499829	et	4	main
investments	doc_40918597566_item	3499830	et	4	main
sa	doc_40918597566_item	3499831	et	3	main
olles	doc_40918597566_item	3499832	et	3	main
juriidiline	doc_40918597566_item	3499833	et	3	main
isik	doc_40918597566_item	3499834	et	3	main
kehtestatud	doc_40918597566_item	3499835	et	4	main
ning	doc_40918597566_item	3499836	et	3	main
teostatud	doc_40918597566_item	3499837	et	4	main
oma	doc_40918597566_item	3499838	et	4	main
tegevust	doc_40918597566_item	3499839	et	4	main
suurbritannia	doc_40918597566_item	3499840	et	4	main
virgiinia	doc_40918597566_item	3499841	et	4	main
saarte	doc_40918597566_item	3499842	et	3	main
seadustega	doc_40918597566_item	3499843	et	3	main
kooskõlas	doc_40918597566_item	3499844	et	3	main
registreeritud	doc_40918597566_item	3499845	et	4	main
24	doc_40918597566_item	3499846	et	2	main
novembril	doc_40918597566_item	3499847	et	3	main
2000	doc_40918597566_item	3499848	et	2	main
aastal	doc_40918597566_item	3499849	et	3	main
nr	doc_40918597566_item	3499850	et	4	main
saarte	doc_40918597566_item	3499854	et	3	main
registraatori	doc_40918597566_item	3499857	et	3	main
aadress	doc_40918597566_item	3499859	et	3	main
146	doc_40918597566_item	3499862	et	2	main
road	doc_40918597566_item	3499863	et	4	main
virgiinite	doc_40918597566_item	3499867	et	4	main
saared	doc_40918597566_item	3499868	et	3	main
edasi	doc_40918597566_item	3499869	et	3	main
nimetatud	doc_40918597566_item	3499870	et	4	main
kui	doc_40918597566_item	3499871	et	3	main
aktsiate	doc_40918597568_item	3499978	et	3	main
a	doc_40918597568_item	3499984	et	4	main
föderatsiooni	doc_40918597568_item	3499993	et	4	main
saatkonnaga	doc_40918597568_item	3499994	et	4	main
eestis	doc_40918597568_item	3499995	et	3	main
elab	doc_40918597568_item	3499996	et	3	main
aadressil	doc_40918597568_item	3499997	et	3	main
firma	doc_40918597568_item	3500011	et	4	main
isik	doc_40918597568_item	3500017	et	3	main
asutatud	doc_40918597568_item	3500018	et	4	main
ja	doc_40918597568_item	3500019	et	3	main
tegevust	doc_40918597568_item	3500022	et	4	main
registraatoriga	doc_40918597568_item	3500039	et	3	main
po	doc_40918597568_item	3500042	et	4	main
146	doc_40918597568_item	3500044	et	2	main
virgin	doc_40918597568_item	3500049	et	4	main
purimaa	doc_40918597568_item	3500055	et	4	main
direktor	doc_40918597568_item	3500056	et	3	main
konstantin	doc_40918597568_item	3500057	et	4	main
25122007	doc_40918597569_item	3500187	et	2	main
poolt	doc_40918597569_item	3500192	et	4	main
vf	doc_40918597569_item	3500204	et	4	main
saatkonnaga	doc_40918597569_item	3500205	et	4	main
edasi	doc_40918597569_item	3500214	et	3	main
rahvusvaheline	doc_40918597569_item	3500220	et	4	main
rollinz	doc_40918597569_item	3500223	et	4	main
investments	doc_40918597569_item	3500224	et	4	main
sa	doc_40918597569_item	3500225	et	3	main
juriidiline	doc_40918597569_item	3500226	et	3	main
isik	doc_40918597569_item	3500227	et	3	main
britannia	doc_40918597569_item	3500232	et	4	main
virgini	doc_40918597569_item	3500233	et	3	main
saarte	doc_40918597569_item	3500234	et	3	main
seadusandlusega	doc_40918597569_item	3500235	et	3	main
registreeritud	doc_40918597569_item	3500238	et	4	main
a	doc_40918597569_item	3500240	et	4	main
leping	doc_40918597568_item	3499977	et	3	main
passi	doc_40918597568_item	3499985	et	4	main
välja	doc_40918597568_item	3499988	et	4	main
rahvusvaheline	doc_40918597568_item	3500009	et	4	main
kommerts	doc_40918597568_item	3500010	et	3	main
on	doc_40918597568_item	3500015	et	4	main
juriidiline	doc_40918597568_item	3500016	et	3	main
on	doc_40918597568_item	3500029	et	4	main
korporatiiv	doc_40918597568_item	3500038	et	4	main
keda	doc_40918597568_item	3500053	et	4	main
esindab	doc_40918597568_item	3500054	et	3	main
tegutseb	doc_40918597568_item	3500060	et	3	main
leping	doc_40918597569_item	3500186	et	3	main
moskva	doc_40918597569_item	3500188	et	4	main
vene	doc_40918597569_item	3500189	et	4	main
föderatsioon	doc_40918597569_item	3500190	et	3	main
ühelt	doc_40918597569_item	3500191	et	3	main
8041938	doc_40918597569_item	3500197	et	2	main
pass	doc_40918597569_item	3500198	et	3	main
n	doc_40918597569_item	3500200	et	4	main
2-7	doc_40918597569_item	3500213	et	2	main
kes	doc_40918597569_item	3500228	et	4	main
teostab	doc_40918597569_item	3500229	et	3	main
vastavuses	doc_40918597569_item	3500236	et	4	main
ja	doc_40918597569_item	3500292	et	3	main
ostu-müügileping	doc_40918597570_item	3500450	et	3	main
föderatsioon	doc_40918597570_item	3500453	et	3	main
n	doc_40918597570_item	3500464	et	4	main
3316838	doc_40918597570_item	3500465	et	2	main
väljastatud	doc_40918597570_item	3500466	et	4	main
elukoht	doc_40918597570_item	3500472	et	3	main
10125	doc_40918597570_item	3500476	et	2	main
edaspidi	doc_40918597570_item	3500478	et	3	main
box	doc_40918597570_item	3500501	et	4	main
146	doc_40918597570_item	3500502	et	2	main
virgin	doc_40918597570_item	3500507	et	4	main
ostja	doc_40918597570_item	3500511	et	4	main
annab	doc_40918597570_item	3500535	et	3	main
nr	doc_40918597568_item	3499986	et	4	main
faehlmanni	doc_40918597568_item	3499998	et	4	main
2-7	doc_40918597568_item	3500000	et	2	main
eesti	doc_40918597568_item	3500003	et	4	main
poolt	doc_40918597568_item	3500007	et	4	main
ja	doc_40918597568_item	3500008	et	3	main
mis	doc_40918597568_item	3500014	et	4	main
oma	doc_40918597568_item	3500021	et	4	main
registreeritud	doc_40918597568_item	3500030	et	4	main
24112000	doc_40918597568_item	3500031	et	2	main
a	doc_40918597568_item	3500032	et	4	main
numbriga	doc_40918597568_item	3500033	et	3	main
418606	doc_40918597568_item	3500034	et	2	main
town	doc_40918597568_item	3500046	et	4	main
ostja	doc_40918597568_item	3500052	et	4	main
põhikirja	doc_40918597568_item	3500061	et	4	main
teiselt	doc_40918597568_item	3500063	et	4	main
sõlmisid	doc_40918597568_item	3500065	et	4	main
lepingu	doc_40918597568_item	3500066	et	3	main
tänav	doc_40918597568_item	3499999	et	4	main
10125	doc_40918597568_item	3500001	et	2	main
rollings	doc_40918597568_item	3500012	et	4	main
teostab	doc_40918597568_item	3500020	et	3	main
britti	doc_40918597568_item	3500023	et	4	main
virginia	doc_40918597568_item	3500024	et	4	main
saarte	doc_40918597568_item	3500025	et	3	main
seadusandluse	doc_40918597568_item	3500026	et	3	main
kooskõlas	doc_40918597568_item	3500027	et	3	main
britti	doc_40918597568_item	3500035	et	4	main
registreeritud	doc_40918597568_item	3500040	et	4	main
tortola	doc_40918597568_item	3500047	et	4	main
britisch	doc_40918597568_item	3500048	et	4	main
kes	doc_40918597568_item	3500059	et	4	main
t	doc_40918597569_item	3500193	et	4	main
antud	doc_40918597569_item	3500203	et	4	main
16112007	doc_40918597569_item	3500206	et	2	main
elukoht	doc_40918597569_item	3500208	et	3	main
kommerts	doc_40918597569_item	3500221	et	3	main
maksma	doc_40918597569_item	3500294	et	3	main
tingimuste	doc_40918597569_item	3500296	et	3	main
leping	doc_40918597569_item	3500183	et	3	main
ostu-müügi	doc_40918597569_item	3500185	et	4	main
s	doc_40918597569_item	3500194	et	4	main
kätte	doc_40918597569_item	3500202	et	4	main
fillmahni	doc_40918597569_item	3500212	et	4	main
nimetatud	doc_40918597569_item	3500215	et	4	main
müüja	doc_40918597569_item	3500216	et	4	main
ja	doc_40918597569_item	3500217	et	3	main
teiselt	doc_40918597569_item	3500218	et	4	main
oma	doc_40918597569_item	3500230	et	4	main
kooskõlas	doc_40918597569_item	3500237	et	3	main
välja	doc_40918597569_item	3500293	et	4	main
lepingu	doc_40918597569_item	3500295	et	3	main
vene	doc_40918597570_item	3500452	et	4	main
25	doc_40918597570_item	3500454	et	2	main
saatkonna	doc_40918597570_item	3500469	et	4	main
2-7	doc_40918597570_item	3500474	et	2	main
eesti	doc_40918597570_item	3500477	et	4	main
kommertsettevõte	doc_40918597570_item	3500485	et	3	main
rollins	doc_40918597570_item	3500486	et	4	main
investmente	doc_40918597570_item	3500487	et	4	main
vastava	doc_40918597570_item	3500493	et	4	main
seadusele	doc_40918597570_item	3500497	et	3	main
town	doc_40918597570_item	3500504	et	4	main
lepinguga	doc_40918597570_item	3500534	et	3	main
üle	doc_40918597570_item	3500536	et	3	main
ostjale	doc_40918597570_item	3500538	et	4	main
valdustesse	doc_40918597570_item	3500539	et	4	main
aktsiaid	doc_40918597570_item	3500540	et	3	main
aktsiate	doc_40918597570_item	3500545	et	3	main
tasuda	doc_40918597570_item	3500547	et	3	main
lepingu	doc_40918597570_item	3500551	et	3	main
ese	doc_40918597570_item	3500558	et	3	main
alltoodud	doc_40918597570_item	3500574	et	3	main
tavalised	doc_40918597570_item	3500578	et	4	main
sovfraht	doc_40918597570_item	3500582	et	4	main
¼	doc_40918597570_item	3500585	et	2	main
moskva	doc_40918597570_item	3500586	et	4	main
aktsiate	doc_40918597571_item	3500716	et	3	main
semjenova	doc_40918597571_item	3500721	et	4	main
a	doc_40918597571_item	3500731	et	4	main
tallinn	doc_40918597571_item	3500740	et	4	main
müüja	doc_40918597571_item	3500744	et	4	main
ja	doc_40918597571_item	3500746	et	3	main
virginia	doc_40918597571_item	3500765	et	4	main
sõlmisid	doc_40918597569_item	3500268	et	4	main
lepingu	doc_40918597569_item	3500269	et	3	main
1	doc_40918597569_item	3500270	et	2	main
lepinguaine	doc_40918597569_item	3500271	et	4	main
11	doc_40918597569_item	3500272	et	2	main
käesoleva	doc_40918597569_item	3500273	et	3	main
lepingu	doc_40918597569_item	3500274	et	3	main
kooskõlas	doc_40918597569_item	3500275	et	3	main
annab	doc_40918597569_item	3500276	et	3	main
müüja	doc_40918597569_item	3500277	et	4	main
ostja	doc_40918597569_item	3500278	et	4	main
omandusele	doc_40918597569_item	3500279	et	4	main
väärtpabereid	doc_40918597569_item	3500280	et	3	main
mis	doc_40918597569_item	3500281	et	4	main
on	doc_40918597569_item	3500282	et	4	main
kindlaks	doc_40918597569_item	3500283	et	3	main
määratud	doc_40918597569_item	3500284	et	4	main
käesoleva	doc_40918597569_item	3500285	et	3	main
lepinguga	doc_40918597569_item	3500286	et	3	main
ostja	doc_40918597569_item	3500287	et	4	main
kohustab	doc_40918597569_item	3500288	et	3	main
võtta	doc_40918597569_item	3500289	et	3	main
neid	doc_40918597569_item	3500290	et	4	main
vastu	doc_40918597569_item	3500291	et	3	main
aktsiate	doc_40918597569_item	3500184	et	3	main
popova	doc_40918597569_item	3500195	et	4	main
sünd	doc_40918597569_item	3500196	et	3	main
51	doc_40918597569_item	3500199	et	2	main
3316838	doc_40918597569_item	3500201	et	2	main
a	doc_40918597569_item	3500207	et	4	main
eesti	doc_40918597569_item	3500209	et	4	main
tallin	doc_40918597569_item	3500210	et	4	main
10125	doc_40918597569_item	3500211	et	2	main
poolt	doc_40918597569_item	3500219	et	4	main
kompanii	doc_40918597569_item	3500222	et	4	main
tegevust	doc_40918597569_item	3500231	et	4	main
24112000	doc_40918597569_item	3500239	et	2	main
n	doc_40918597569_item	3500241	et	4	main
418608	doc_40918597569_item	3500242	et	2	main
all	doc_40918597569_item	3500243	et	3	main
korporatiivküsimuste	doc_40918597569_item	3500244	et	4	main
registraatoriga	doc_40918597569_item	3500245	et	3	main
aadressiga	doc_40918597569_item	3500246	et	3	main
british	doc_40918597569_item	3500247	et	4	main
virgin	doc_40918597569_item	3500248	et	4	main
islands	doc_40918597569_item	3500249	et	4	main
tortola	doc_40918597569_item	3500250	et	4	main
road	doc_40918597569_item	3500251	et	4	main
town	doc_40918597569_item	3500252	et	4	main
box	doc_40918597569_item	3500253	et	4	main
146	doc_40918597569_item	3500254	et	2	main
edasi	doc_40918597569_item	3500255	et	3	main
nimetatud	doc_40918597569_item	3500256	et	4	main
ostja	doc_40918597569_item	3500257	et	4	main
keda	doc_40918597569_item	3500258	et	4	main
esindab	doc_40918597569_item	3500259	et	3	main
direktor	doc_40918597569_item	3500260	et	3	main
k	doc_40918597569_item	3500261	et	4	main
j	doc_40918597569_item	3500262	et	4	main
purim	doc_40918597569_item	3500263	et	4	main
kes	doc_40918597569_item	3500264	et	4	main
tegeleb	doc_40918597569_item	3500265	et	3	main
põhikirja	doc_40918597569_item	3500266	et	4	main
alusel	doc_40918597569_item	3500267	et	4	main
kooskõlas	doc_40918597569_item	3500297	et	3	main
aktsiate	doc_40918597570_item	3500449	et	3	main
detsembril	doc_40918597570_item	3500455	et	3	main
leping	doc_40918597570_item	3500448	et	3	main
2007	doc_40918597570_item	3500456	et	2	main
08112007	doc_40918597570_item	3500460	et	2	main
nr	doc_40918597570_item	3500462	et	4	main
51	doc_40918597570_item	3500463	et	2	main
16112007	doc_40918597570_item	3500471	et	2	main
tallinn	doc_40918597570_item	3500475	et	4	main
nimetatud	doc_40918597570_item	3500479	et	4	main
müüja	doc_40918597570_item	3500480	et	4	main
ja	doc_40918597570_item	3500481	et	3	main
briiti	doc_40918597570_item	3500494	et	4	main
virgiini	doc_40918597570_item	3500495	et	4	main
registreerimisekoht	doc_40918597570_item	3500499	et	4	main
tortola	doc_40918597570_item	3500505	et	4	main
esindajana	doc_40918597570_item	3500513	et	4	main
tegutseb	doc_40918597570_item	3500514	et	3	main
lisatud	doc_40918597570_item	3500516	et	4	main
poolt	doc_40918597570_item	3500542	et	4	main
ostja	doc_40918597570_item	3500543	et	4	main
vastava	doc_40918597570_item	3500548	et	4	main
objekt	doc_40918597570_item	3500552	et	3	main
on	doc_40918597570_item	3500555	et	4	main
on	doc_40918597570_item	3500559	et	4	main
omand	doc_40918597570_item	3500561	et	3	main
ning	doc_40918597570_item	3500562	et	3	main
lepingu	doc_40918597570_item	3500563	et	3	main
eseme	doc_40918597570_item	3500564	et	3	main
suhtes	doc_40918597570_item	3500565	et	4	main
ei	doc_40918597570_item	3500566	et	4	main
aktsiad	doc_40918597570_item	3500575	et	3	main
leping	doc_40918597571_item	3500718	et	3	main
poolt	doc_40918597571_item	3500734	et	4	main
edaspidi	doc_40918597571_item	3500743	et	3	main
company	doc_40918597571_item	3500749	et	4	main
investments	doc_40918597571_item	3500751	et	4	main
sa	doc_40918597571_item	3500752	et	3	main
mis	doc_40918597571_item	3500753	et	4	main
on	doc_40918597571_item	3500754	et	4	main
juriidiline	doc_40918597571_item	3500755	et	3	main
isik	doc_40918597571_item	3500756	et	3	main
teostab	doc_40918597571_item	3500760	et	3	main
ostja	doc_40918597571_item	3500823	et	4	main
kohustatud	doc_40918597571_item	3500825	et	4	main
ära	doc_40918597571_item	3500826	et	4	main
pilti	doc_464301607717_item	3500836	et	4	main
oli	doc_464301607717_item	3500843	et	3	main
aga	doc_464301607717_item	3500845	et	3	main
lehekeset	doc_464301607717_item	3500853	et	4	main
kukusit	doc_464301607717_item	3500854	et	4	main
külmund	doc_464301607717_item	3500880	et	4	main
ja	doc_464301607717_item	3500881	et	3	main
tahtis	doc_464301607717_item	3500882	et	3	main
süüa	doc_464301607717_item	3500883	et	3	main
tuli	doc_464301607717_item	3500898	et	4	main
seenemajale	doc_464301607717_item	3500899	et	3	main
ka	doc_464301607717_item	3500900	et	3	main
neli	doc_464301607717_item	3500933	et	3	main
süüa	doc_464301607717_item	3500944	et	3	main
juba	doc_534729444676_item	3500954	et	3	main
11seoses	doc_40918597570_item	3500532	et	2	main
antud	doc_40918597570_item	3500533	et	4	main
moskva	doc_40918597570_item	3500451	et	4	main
tatjana	doc_40918597570_item	3500457	et	4	main
sünd	doc_40918597570_item	3500459	et	3	main
passi	doc_40918597570_item	3500461	et	4	main
föderatsiooni	doc_40918597570_item	3500468	et	4	main
felmanni	doc_40918597570_item	3500473	et	4	main
teiselt	doc_40918597570_item	3500482	et	4	main
ca	doc_40918597570_item	3500488	et	4	main
juriidilisest	doc_40918597570_item	3500489	et	3	main
isikust	doc_40918597570_item	3500490	et	4	main
mille	doc_40918597570_item	3500491	et	3	main
road	doc_40918597570_item	3500503	et	4	main
islands	doc_40918597570_item	3500508	et	4	main
edaspidi	doc_40918597570_item	3500509	et	3	main
nimetatud	doc_40918597570_item	3500510	et	4	main
volikirja	doc_40918597570_item	3500517	et	4	main
alusel	doc_40918597570_item	3500518	et	4	main
lepingu	doc_40918597570_item	3500519	et	3	main
tõestajale	doc_40918597570_item	3500520	et	4	main
tuntud	doc_40918597570_item	3500521	et	4	main
isik	doc_40918597570_item	3500522	et	3	main
konstantin	doc_40918597570_item	3500523	et	4	main
purima	doc_40918597570_item	3500524	et	4	main
kes	doc_40918597570_item	3500525	et	4	main
sõlmivad	doc_40918597570_item	3500526	et	4	main
lepingu	doc_40918597570_item	3500527	et	3	main
alljärgnevas	doc_40918597570_item	3500528	et	3	main
1	doc_40918597570_item	3500529	et	2	main
lepingu	doc_40918597570_item	3500530	et	3	main
ese	doc_40918597570_item	3500531	et	3	main
eest	doc_40918597570_item	3500546	et	4	main
popova	doc_40918597570_item	3500458	et	4	main
vene	doc_40918597570_item	3500467	et	4	main
poolt	doc_40918597570_item	3500470	et	4	main
poolt	doc_40918597570_item	3500483	et	4	main
rahvusvaheline	doc_40918597570_item	3500484	et	4	main
tegutseb	doc_40918597570_item	3500492	et	3	main
saarte	doc_40918597570_item	3500496	et	3	main
ettevõte	doc_40918597570_item	3500498	et	3	main
po	doc_40918597570_item	3500500	et	4	main
british	doc_40918597570_item	3500506	et	4	main
mille	doc_40918597570_item	3500512	et	3	main
ostu-müügilepingule	doc_40918597570_item	3500515	et	3	main
müüja	doc_40918597570_item	3500537	et	4	main
kohustab	doc_40918597570_item	3500544	et	3	main
lepingu	doc_40918597570_item	3500557	et	3	main
22	doc_40918597570_item	3500569	et	2	main
antud	doc_40918597570_item	3500570	et	4	main
lepingu	doc_40918597570_item	3500571	et	3	main
esemeks	doc_40918597570_item	3500572	et	3	main
on	doc_40918597570_item	3500573	et	4	main
ettevõte	doc_40918597570_item	3500581	et	3	main
leping	doc_40918597571_item	3500715	et	3	main
eesti	doc_40918597571_item	3500742	et	4	main
üheltpoolt	doc_40918597571_item	3500745	et	4	main
international	doc_40918597571_item	3500747	et	4	main
commertional	doc_40918597571_item	3500748	et	4	main
ja	doc_40918597571_item	3500759	et	3	main
tegevust	doc_40918597571_item	3500762	et	4	main
maksta	doc_40918597571_item	3500827	et	4	main
pildi	doc_464301607717_item	3500833	et	4	main
lausega	doc_464301607717_item	3500838	et	3	main
seenemaja	doc_464301607717_item	3500841	et	4	main
ilus	doc_464301607717_item	3500846	et	4	main
korstenist	doc_464301607717_item	3500847	et	3	main
läks	doc_464301607717_item	3500848	et	3	main
suits	doc_464301607717_item	3500849	et	3	main
oli	doc_464301607717_item	3500850	et	3	main
talle	doc_464301607717_item	3500886	et	4	main
süüa	doc_464301607717_item	3500890	et	3	main
ta	doc_464301607717_item	3500902	et	4	main
eksis	doc_464301607717_item	3500903	et	3	main
era	doc_464301607717_item	3500904	et	4	main
ja	doc_464301607717_item	3500905	et	3	main
kena	doc_464301607717_item	3500906	et	4	main
talle	doc_464301607717_item	3500909	et	4	main
ja	doc_464301607717_item	3500936	et	3	main
koristas	doc_464301607717_item	3500939	et	3	main
sipelgas	doc_464301607717_item	3500940	et	4	main
tõtas	doc_464301607717_item	3500941	et	4	main
liblikas	doc_464301607717_item	3500942	et	4	main
tegi	doc_464301607717_item	3500943	et	4	main
omalt	doc_40918597570_item	3500541	et	4	main
kokkuleppele	doc_40918597570_item	3500549	et	3	main
2	doc_40918597570_item	3500550	et	2	main
21lepingu	doc_40918597570_item	3500553	et	2	main
aktsiad	doc_40918597570_item	3500556	et	3	main
ole	doc_40918597570_item	3500567	et	4	main
vaidlusi	doc_40918597570_item	3500568	et	3	main
aktsiate	doc_40918597570_item	3500576	et	3	main
aktsiad	doc_40918597570_item	3500579	et	3	main
asukoht	doc_40918597570_item	3500583	et	3	main
esemeks	doc_40918597570_item	3500554	et	3	main
müüja	doc_40918597570_item	3500560	et	4	main
tüüp	doc_40918597570_item	3500577	et	3	main
emitent	doc_40918597570_item	3500580	et	4	main
roždestvenna	doc_40918597570_item	3500584	et	2	main
vene	doc_40918597570_item	3500588	et	4	main
109012	doc_40918597570_item	3500587	et	2	main
föderatsioon	doc_40918597570_item	3500589	et	3	main
aktsiate	doc_40918597570_item	3500590	et	3	main
väljalase	doc_40918597570_item	3500591	et	4	main
registri	doc_40918597570_item	3500592	et	3	main
nr	doc_40918597570_item	3500593	et	4	main
1-03-02161-a	doc_40918597570_item	3500594	et	4	main
aktsiate	doc_40918597570_item	3500595	et	3	main
maksumus	doc_40918597570_item	3500596	et	3	main
30	doc_40918597570_item	3500597	et	2	main
kolmkümmend	doc_40918597570_item	3500598	et	4	main
müügi-ostu	doc_40918597571_item	3500717	et	4	main
tatjana	doc_40918597571_item	3500720	et	4	main
sünd	doc_40918597571_item	3500722	et	3	main
pass	doc_40918597571_item	3500724	et	3	main
3316838	doc_40918597571_item	3500727	et	2	main
antud	doc_40918597571_item	3500729	et	4	main
16112007	doc_40918597571_item	3500730	et	2	main
eestis	doc_40918597571_item	3500735	et	3	main
elukoht	doc_40918597571_item	3500736	et	3	main
faelhmanni	doc_40918597571_item	3500737	et	4	main
2	doc_40918597571_item	3500738	et	2	main
7	doc_40918597571_item	3500739	et	2	main
on	doc_40918597571_item	3500757	et	4	main
oma	doc_40918597571_item	3500761	et	4	main
vastavalt	doc_40918597571_item	3500763	et	4	main
suurbritannia	doc_40918597571_item	3500764	et	4	main
ja	doc_40918597571_item	3500822	et	3	main
neid	doc_40918597571_item	3500828	et	4	main
tegutseb	doc_40918597571_item	3500799	et	3	main
põhikirja	doc_40918597571_item	3500800	et	4	main
alusel	doc_40918597571_item	3500801	et	4	main
teiselt	doc_40918597571_item	3500802	et	4	main
poolt	doc_40918597571_item	3500803	et	4	main
on	doc_40918597571_item	3500804	et	4	main
sõlminud	doc_40918597571_item	3500805	et	4	main
lepingu	doc_40918597571_item	3500806	et	3	main
järgnevas	doc_40918597571_item	3500807	et	4	main
lepingu	doc_40918597571_item	3500808	et	3	main
sisu	doc_40918597571_item	3500809	et	4	main
käesoleva	doc_40918597571_item	3500810	et	3	main
lepingu	doc_40918597571_item	3500811	et	3	main
alusel	doc_40918597571_item	3500812	et	4	main
müüja	doc_40918597571_item	3500813	et	4	main
annab	doc_40918597571_item	3500814	et	3	main
ostja	doc_40918597571_item	3500815	et	4	main
omandusele	doc_40918597571_item	3500816	et	4	main
käesoleva	doc_40918597571_item	3500817	et	3	main
lepingu	doc_40918597571_item	3500818	et	3	main
popova	doc_40918597571_item	3500719	et	4	main
8041938	doc_40918597571_item	3500723	et	2	main
51	doc_40918597571_item	3500725	et	2	main
number	doc_40918597571_item	3500726	et	3	main
välja	doc_40918597571_item	3500728	et	4	main
vene	doc_40918597571_item	3500732	et	4	main
saatkonna	doc_40918597571_item	3500733	et	4	main
10215	doc_40918597571_item	3500741	et	2	main
rollings	doc_40918597571_item	3500750	et	4	main
asutatud	doc_40918597571_item	3500758	et	4	main
seadusandlusega	doc_40918597571_item	3500767	et	3	main
registreeritud	doc_40918597571_item	3500768	et	4	main
24	doc_40918597571_item	3500769	et	2	main
novembril	doc_40918597571_item	3500770	et	3	main
2000	doc_40918597571_item	3500771	et	2	main
a	doc_40918597571_item	3500772	et	4	main
number	doc_40918597571_item	3500773	et	3	main
418606	doc_40918597571_item	3500774	et	2	main
suurbritannia	doc_40918597571_item	3500775	et	4	main
virginia	doc_40918597571_item	3500776	et	4	main
saarte	doc_40918597571_item	3500777	et	3	main
korporatiivsete	doc_40918597571_item	3500778	et	3	main
küsimuste	doc_40918597571_item	3500779	et	4	main
registraatori	doc_40918597571_item	3500780	et	3	main
poolt	doc_40918597571_item	3500781	et	4	main
aadressil	doc_40918597571_item	3500782	et	3	main
po	doc_40918597571_item	3500783	et	4	main
box	doc_40918597571_item	3500784	et	4	main
146	doc_40918597571_item	3500785	et	2	main
road	doc_40918597571_item	3500786	et	4	main
town	doc_40918597571_item	3500787	et	4	main
tortola	doc_40918597571_item	3500788	et	4	main
british	doc_40918597571_item	3500789	et	4	main
virgin	doc_40918597571_item	3500790	et	4	main
islands	doc_40918597571_item	3500791	et	4	main
edaspidi	doc_40918597571_item	3500792	et	3	main
ostja	doc_40918597571_item	3500793	et	4	main
direktor	doc_40918597571_item	3500794	et	3	main
purim	doc_40918597571_item	3500795	et	4	main
konstantin	doc_40918597571_item	3500796	et	4	main
jurjevitš	doc_40918597571_item	3500797	et	2	main
kes	doc_40918597571_item	3500798	et	4	main
kindlaks	doc_40918597571_item	3500819	et	3	main
väärtpaberid	doc_40918597571_item	3500821	et	3	main
on	doc_40918597571_item	3500824	et	4	main
vastavalt	doc_40918597571_item	3500829	et	4	main
tingimustega	doc_40918597571_item	3500830	et	3	main
kirjelda	doc_464301607717_item	3500835	et	4	main
metsas	doc_464301607717_item	3500839	et	3	main
ta	doc_464301607717_item	3500842	et	4	main
ja	doc_464301607717_item	3500852	et	3	main
päkkapikk	doc_464301607717_item	3500884	et	4	main
saarte	doc_40918597571_item	3500766	et	3	main
määratud	doc_40918597571_item	3500820	et	4	main
kirjeldus	doc_464301607717_item	3500834	et	4	main
seisis	doc_464301607717_item	3500840	et	4	main
soja	doc_464301607717_item	3500887	et	4	main
küpsetatud	doc_464301607717_item	3500891	et	4	main
ja	doc_464301607717_item	3500893	et	3	main
makama	doc_464301607717_item	3500895	et	4	main
teisel	doc_464301607717_item	3500896	et	4	main
päeval	doc_464301607717_item	3500897	et	3	main
lubas	doc_464301607717_item	3500908	et	3	main
lõbusasti	doc_464301607717_item	3500937	et	3	main
ussike	doc_464301607717_item	3500938	et	4	main
ja	doc_464301607717_item	3500945	et	3	main
maasikaid	doc_464301607717_item	3500948	et	3	main
28072006	doc_534729444676_item	3500951	et	2	main
ma	doc_534729444676_item	3500971	et	3	main
õpin	doc_534729444676_item	3500972	et	3	main
linnasse	doc_534729444676_item	3500979	et	4	main
hommikusöögi	doc_534729444676_item	3500980	et	3	main
pärast	doc_534729444676_item	3500981	et	4	main
ülikoolist	doc_534729444676_item	3500991	et	4	main
keelt	doc_534729444676_item	3500999	et	4	main
me	doc_534729444676_item	3501002	et	4	main
kaksteist	doc_534729444676_item	3501008	et	4	main
lõunasööki	doc_534729444676_item	3501012	et	4	main
pubis	doc_534729444676_item	3501013	et	4	main
lõunasöök	doc_534729444676_item	3501014	et	3	main
oli	doc_534729444676_item	3501015	et	3	main
emalle	doc_534729444676_item	3501050	et	4	main
ärkasin	doc_534729444677_item	3501066	et	3	main
ja	doc_534729444677_item	3501069	et	3	main
ma	doc_534729444677_item	3501072	et	3	main
palju	doc_534729444677_item	3501078	et	4	main
ja	doc_534729444677_item	3501081	et	3	main
ma	doc_534729444677_item	3501082	et	3	main
juba	doc_534729444677_item	3501083	et	3	main
tallinnasse	doc_534729444677_item	3501102	et	3	main
mulle	doc_534729444677_item	3501114	et	4	main
me	doc_534729444677_item	3501127	et	4	main
need	doc_464301607717_item	3500913	et	3	main
kuulsid	doc_464301607717_item	3500914	et	4	main
kuidas	doc_464301607717_item	3500915	et	3	main
keegi	doc_464301607717_item	3500916	et	4	main
nuttis	doc_464301607717_item	3500917	et	3	main
väike	doc_464301607717_item	3500918	et	4	main
liblikas	doc_464301607717_item	3500919	et	4	main
lendas	doc_464301607717_item	3500920	et	3	main
ja	doc_464301607717_item	3500921	et	3	main
otsis	doc_464301607717_item	3500922	et	4	main
oma	doc_464301607717_item	3500923	et	4	main
kodu	doc_464301607717_item	3500924	et	4	main
need	doc_464301607717_item	3500925	et	3	main
võtsid	doc_464301607717_item	3500926	et	4	main
tema	doc_464301607717_item	3500927	et	4	main
ende	doc_464301607717_item	3500928	et	3	main
jurde	doc_464301607717_item	3500929	et	4	main
ja	doc_464301607717_item	3500930	et	3	main
nii	doc_464301607717_item	3500931	et	3	main
elasid	doc_464301607717_item	3500932	et	4	main
15	doc_464301607717_item	3500837	et	2	main
vana	doc_464301607717_item	3500844	et	4	main
sügis	doc_464301607717_item	3500851	et	3	main
maale	doc_464301607717_item	3500855	et	4	main
sellel	doc_464301607717_item	3500856	et	4	main
seenemajal	doc_464301607717_item	3500857	et	3	main
elas	doc_464301607717_item	3500858	et	3	main
päkkapikk	doc_464301607717_item	3500859	et	4	main
ta	doc_464301607717_item	3500860	et	4	main
oli	doc_464301607717_item	3500861	et	3	main
väga	doc_464301607717_item	3500862	et	3	main
ja	doc_464301607717_item	3500864	et	3	main
väike	doc_464301607717_item	3500863	et	4	main
väga	doc_464301607717_item	3500865	et	3	main
kena	doc_464301607717_item	3500866	et	4	main
ühel	doc_464301607717_item	3500867	et	3	main
päeval	doc_464301607717_item	3500868	et	3	main
kui	doc_464301607717_item	3500869	et	3	main
oli	doc_464301607717_item	3500870	et	3	main
juba	doc_464301607717_item	3500871	et	3	main
väga	doc_464301607717_item	3500872	et	3	main
külm	doc_464301607717_item	3500873	et	3	main
koputas	doc_464301607717_item	3500874	et	3	main
uksele	doc_464301607717_item	3500875	et	3	main
vaene	doc_464301607717_item	3500876	et	4	main
ussike	doc_464301607717_item	3500877	et	4	main
tema	doc_464301607717_item	3500878	et	4	main
oli	doc_464301607717_item	3500879	et	3	main
tegi	doc_464301607717_item	3500885	et	4	main
andis	doc_464301607717_item	3500889	et	3	main
päkkapikk	doc_464301607717_item	3500907	et	4	main
jääda	doc_464301607717_item	3500910	et	4	main
juba	doc_464301607717_item	3500911	et	3	main
õhtul	doc_464301607717_item	3500912	et	3	main
sõpra	doc_464301607717_item	3500934	et	4	main
vanni	doc_464301607717_item	3500888	et	4	main
maasikat	doc_464301607717_item	3500892	et	3	main
pani	doc_464301607717_item	3500894	et	4	main
sipelgas	doc_464301607717_item	3500901	et	4	main
kaua	doc_464301607717_item	3500935	et	3	main
küpsetas	doc_464301607717_item	3500947	et	3	main
päevik	doc_534729444676_item	3500950	et	3	main
kell	doc_534729444676_item	3500955	et	3	main
pool	doc_534729444676_item	3500956	et	4	main
olin	doc_534729444676_item	3500960	et	3	main
meil	doc_534729444676_item	3500965	et	4	main
grupp	doc_534729444676_item	3500983	et	3	main
oli	doc_534729444676_item	3500984	et	3	main
ja	doc_534729444676_item	3501000	et	3	main
läksime	doc_534729444676_item	3501004	et	3	main
kell	doc_534729444676_item	3501006	et	3	main
pool	doc_534729444676_item	3501007	et	4	main
sõime	doc_534729444676_item	3501010	et	4	main
hästi	doc_534729444676_item	3501011	et	3	main
ja	doc_534729444676_item	3501018	et	3	main
me	doc_534729444676_item	3501021	et	4	main
ta	doc_534729444676_item	3501054	et	4	main
ütlesis	doc_534729444676_item	3501055	et	4	main
et	doc_534729444676_item	3501056	et	3	main
ta	doc_534729444676_item	3501057	et	4	main
tahaksi	doc_534729444676_item	3501058	et	4	main
reisida	doc_534729444676_item	3501059	et	3	main
eestis	doc_534729444676_item	3501060	et	3	main
veel	doc_534729444676_item	3501061	et	4	main
kord	doc_534729444676_item	3501062	et	4	main
päevik	doc_534729444677_item	3501064	et	3	main
maitses	doc_534729444677_item	3501077	et	4	main
aga	doc_534729444677_item	3501087	et	3	main
täna	doc_534729444677_item	3501089	et	4	main
ainult	doc_534729444677_item	3501094	et	4	main
tassi	doc_534729444677_item	3501097	et	4	main
kell	doc_534729444677_item	3501103	et	3	main
me	doc_534729444677_item	3501105	et	4	main
paides	doc_534729444677_item	3501107	et	4	main
ja	doc_534729444677_item	3501108	et	3	main
see	doc_534729444677_item	3501115	et	3	main
ja	doc_534729444677_item	3501118	et	3	main
paides	doc_534729444677_item	3501123	et	4	main
turg	doc_534729444677_item	3501124	et	3	main
kaks	doc_534729444680_item	3501174	et	3	main
nädalatest	doc_534729444680_item	3501175	et	4	main
pea	doc_534729444680_item	3501177	et	4	main
kodus	doc_534729444680_item	3501186	et	4	main
ma	doc_534729444680_item	3501187	et	3	main
hommikueinet	doc_534729444680_item	3501192	et	3	main
kõike	doc_534729444680_item	3501196	et	4	main
ma	doc_534729444680_item	3501198	et	3	main
olin	doc_534729444680_item	3501199	et	3	main
seni	doc_534729444680_item	3501200	et	3	main
õppinud	doc_534729444680_item	3501201	et	4	main
pärastlõunal	doc_534729444680_item	3501202	et	3	main
jalutasin	doc_534729444680_item	3501204	et	3	main
ja	doc_534729444680_item	3501206	et	3	main
pärast	doc_534729444680_item	3501209	et	4	main
jalustuskäiku	doc_534729444680_item	3501210	et	4	main
ma	doc_534729444680_item	3501211	et	3	main
siis	doc_534729444680_item	3501239	et	3	main
pärast	doc_534729444680_item	3501247	et	4	main
ma	doc_534729444680_item	3501248	et	3	main
heitsin	doc_534729444680_item	3501249	et	3	main
voodisse	doc_534729444680_item	3501250	et	3	main
aga	doc_534729444680_item	3501251	et	3	main
ma	doc_534729444680_item	3501252	et	3	main
ei	doc_534729444680_item	3501253	et	4	main
ma	doc_534729444681_item	3501272	et	3	main
tõusin	doc_534729444681_item	3501273	et	3	main
käisin	doc_534729444681_item	3501276	et	3	main
läksin	doc_534729444681_item	3501281	et	3	main
pärast	doc_534729444681_item	3501285	et	4	main
õppida	doc_534729444681_item	3501297	et	3	main
eksamis	doc_534729444681_item	3501331	et	3	main
hakkama	doc_534729444681_item	3501332	et	3	main
päkkapikk	doc_464301607717_item	3500946	et	4	main
ärkasin	doc_534729444676_item	3500952	et	3	main
on	doc_534729444676_item	3500966	et	4	main
suur	doc_534729444676_item	3500967	et	3	main
programm	doc_534729444676_item	3500968	et	3	main
ka	doc_534729444676_item	3500969	et	3	main
kahjuks	doc_534729444676_item	3500992	et	4	main
see	doc_534729444676_item	3500993	et	3	main
professor	doc_534729444676_item	3500994	et	3	main
ei	doc_534729444676_item	3500995	et	4	main
rääginud	doc_534729444676_item	3500996	et	4	main
juba	doc_534729444676_item	3501003	et	3	main
ära	doc_534729444676_item	3501005	et	4	main
seapraadi	doc_534729444676_item	3501016	et	4	main
pärastlõunal	doc_534729444676_item	3501020	et	3	main
olime	doc_534729444676_item	3501022	et	3	main
meeldib	doc_534729444676_item	3501052	et	3	main
ja	doc_534729444676_item	3501029	et	3	main
ta	doc_534729444676_item	3501030	et	4	main
töötab	doc_534729444676_item	3501031	et	3	main
seal	doc_534729444676_item	3501032	et	4	main
museumis	doc_534729444676_item	3501033	et	4	main
meil	doc_534729444676_item	3501034	et	4	main
on	doc_534729444676_item	3501035	et	4	main
palju	doc_534729444676_item	3501036	et	4	main
õnne	doc_534729444676_item	3501037	et	4	main
ilmaga	doc_534729444676_item	3501038	et	3	main
eestis	doc_534729444676_item	3501039	et	3	main
see	doc_534729444676_item	3501040	et	3	main
on	doc_534729444676_item	3501041	et	4	main
soe	doc_534729444676_item	3501042	et	4	main
ja	doc_534729444676_item	3501043	et	3	main
vihma	doc_534729444676_item	3501044	et	4	main
ei	doc_534729444676_item	3501045	et	4	main
olnud	doc_534729444676_item	3501046	et	4	main
sajanud	doc_534729444676_item	3501047	et	4	main
kogu	doc_534729444676_item	3501048	et	4	main
aega	doc_534729444676_item	3501049	et	4	main
vära	doc_534729444676_item	3500953	et	4	main
ma	doc_534729444676_item	3500959	et	3	main
ja	doc_534729444676_item	3500970	et	3	main
palju	doc_534729444676_item	3500973	et	4	main
iga	doc_534729444676_item	3500974	et	4	main
päev	doc_534729444676_item	3500975	et	3	main
meie	doc_534729444676_item	3500982	et	4	main
inglise	doc_534729444676_item	3500998	et	4	main
sellepärast	doc_534729444676_item	3501001	et	3	main
me	doc_534729444676_item	3501009	et	4	main
ahjukartulid	doc_534729444676_item	3501017	et	3	main
salatit	doc_534729444676_item	3501019	et	3	main
ülikooli	doc_534729444676_item	3501023	et	4	main
tõnu	doc_534729444676_item	3501025	et	4	main
on	doc_534729444676_item	3501026	et	4	main
pärit	doc_534729444676_item	3501027	et	3	main
tartust	doc_534729444676_item	3501028	et	3	main
hommikul	doc_534729444677_item	3501068	et	3	main
palju	doc_534729444677_item	3501086	et	4	main
hommikusöök	doc_534729444677_item	3501088	et	3	main
oli	doc_534729444677_item	3501090	et	3	main
sellepärast	doc_534729444677_item	3501092	et	3	main
viis	doc_534729444677_item	3501096	et	4	main
kohvi	doc_534729444677_item	3501098	et	4	main
meie	doc_534729444677_item	3501099	et	4	main
grupp	doc_534729444677_item	3501100	et	3	main
paides	doc_534729444677_item	3501110	et	4	main
me	doc_534729444677_item	3501111	et	4	main
sõime	doc_534729444677_item	3501112	et	4	main
oli	doc_534729444677_item	3501116	et	3	main
turule	doc_534729444677_item	3501122	et	3	main
on	doc_534729444677_item	3501125	et	4	main
seespool	doc_534729444677_item	3501126	et	3	main
010806	doc_534729444680_item	3501163	et	2	main
mul	doc_534729444680_item	3501165	et	3	main
närvline	doc_534729444680_item	3501173	et	4	main
saadik	doc_534729444680_item	3501176	et	4	main
ma	doc_534729444680_item	3501178	et	3	main
olen	doc_534729444680_item	3501179	et	3	main
õppinud	doc_534729444680_item	3501180	et	4	main
ja	doc_534729444680_item	3501190	et	3	main
pärast	doc_534729444680_item	3501193	et	4	main
kordasin	doc_534729444680_item	3501195	et	3	main
marega	doc_534729444680_item	3501207	et	2	main
ja	doc_534729444680_item	3501241	et	3	main
tahnud	doc_534729444680_item	3501254	et	4	main
magama	doc_534729444680_item	3501255	et	3	main
jääma	doc_534729444680_item	3501256	et	4	main
seega	doc_534729444680_item	3501257	et	4	main
ma	doc_534729444680_item	3501258	et	3	main
oma	doc_534729444680_item	3501261	et	4	main
tõnuga	doc_534729444681_item	3501282	et	4	main
saiakest	doc_534729444681_item	3501292	et	4	main
ma	doc_534729444681_item	3501293	et	3	main
püüdsin	doc_534729444681_item	3501294	et	3	main
veel	doc_534729444681_item	3501295	et	4	main
kaaselanigutel	doc_534729444681_item	3501299	et	4	main
kaastunnet	doc_534729444681_item	3501302	et	3	main
ma	doc_534729444681_item	3501304	et	3	main
olin	doc_534729444681_item	3501305	et	3	main
väga	doc_534729444681_item	3501306	et	3	main
eksamit	doc_534729444681_item	3501348	et	3	main
olime	doc_534729444681_item	3501350	et	3	main
pärast	doc_534729444681_item	3501387	et	4	main
me	doc_534729444681_item	3501405	et	4	main
vahuveinseid	doc_534729444681_item	3501407	et	4	main
tulin	doc_534729444681_item	3501412	et	3	main
lühidalt	doc_534729444681_item	3501417	et	4	main
jalutama	doc_534729444681_item	3501418	et	3	main
päevik	doc_534729444682_item	3501424	et	3	main
ma	doc_534729444682_item	3501427	et	3	main
tundi	doc_534729444682_item	3501436	et	4	main
all	doc_534729444682_item	3501441	et	3	main
raamatuid	doc_534729444682_item	3501457	et	3	main
ma	doc_534729444682_item	3501463	et	3	main
on	doc_534729444682_item	3501468	et	4	main
jalutasime	doc_534729444682_item	3501473	et	3	main
me	doc_534729444682_item	3501476	et	4	main
seitse	doc_534729444676_item	3500957	et	3	main
sellepärast	doc_534729444676_item	3500958	et	3	main
väsinud	doc_534729444676_item	3500961	et	4	main
terve	doc_534729444676_item	3500962	et	4	main
päev	doc_534729444676_item	3500963	et	3	main
aga	doc_534729444676_item	3500964	et	3	main
täna	doc_534729444676_item	3500976	et	4	main
me	doc_534729444676_item	3500977	et	4	main
läksime	doc_534729444676_item	3500978	et	3	main
ülikoolis	doc_534729444676_item	3500985	et	4	main
teologiliises	doc_534729444676_item	3500986	et	3	main
seminaris	doc_534729444676_item	3500987	et	3	main
ja	doc_534729444676_item	3500988	et	3	main
räägisis	doc_534729444676_item	3500989	et	4	main
professoriga	doc_534729444676_item	3500990	et	3	main
hästi	doc_534729444676_item	3500997	et	3	main
museumis	doc_534729444676_item	3501024	et	4	main
ka	doc_534729444676_item	3501051	et	3	main
eesti	doc_534729444676_item	3501053	et	4	main
täna	doc_534729444677_item	3501067	et	4	main
ususin	doc_534729444677_item	3501070	et	4	main
juurde	doc_534729444677_item	3501074	et	4	main
võtnud	doc_534729444677_item	3501075	et	4	main
eesti	doc_534729444677_item	3501079	et	4	main
sööke	doc_534729444677_item	3501080	et	3	main
nii	doc_534729444677_item	3501085	et	3	main
ma	doc_534729444677_item	3501093	et	3	main
jõin	doc_534729444677_item	3501095	et	3	main
sõitsis	doc_534729444677_item	3501101	et	4	main
peatusime	doc_534729444677_item	3501106	et	4	main
põltsamaal	doc_534729444677_item	3501109	et	4	main
lõunasööki	doc_534729444677_item	3501113	et	4	main
vaarikakooki	doc_534729444677_item	3501117	et	4	main
kohvi	doc_534729444677_item	3501119	et	4	main
emaga	doc_534729444677_item	3501120	et	3	main
läksin	doc_534729444677_item	3501121	et	3	main
päevik	doc_534729444680_item	3501162	et	3	main
eksam	doc_534729444680_item	3501167	et	3	main
väga	doc_534729444680_item	3501172	et	3	main
kohvi	doc_534729444680_item	3501189	et	4	main
ma	doc_534729444680_item	3501203	et	3	main
läksime	doc_534729444680_item	3501243	et	3	main
päevik	doc_534729444681_item	3501268	et	3	main
ma	doc_534729444677_item	3501145	et	3	main
halusin	doc_534729444677_item	3501146	et	4	main
ostada	doc_534729444677_item	3501147	et	4	main
riided	doc_534729444677_item	3501148	et	3	main
ja	doc_534729444677_item	3501149	et	3	main
suveniirid	doc_534729444677_item	3501150	et	3	main
ja	doc_534729444677_item	3501151	et	3	main
ma	doc_534729444677_item	3501152	et	3	main
palju	doc_534729444677_item	3501154	et	4	main
leidsin	doc_534729444677_item	3501153	et	3	main
kesklinnas	doc_534729444677_item	3501156	et	4	main
tallinna	doc_534729444677_item	3501155	et	4	main
mulle	doc_534729444677_item	3501157	et	4	main
väga	doc_534729444677_item	3501158	et	3	main
meeldsis	doc_534729444677_item	3501159	et	4	main
linade	doc_534729444677_item	3501160	et	3	main
29072006	doc_534729444677_item	3501065	et	2	main
et	doc_534729444677_item	3501071	et	3	main
olin	doc_534729444677_item	3501073	et	3	main
mulle	doc_534729444677_item	3501076	et	4	main
sõin	doc_534729444677_item	3501084	et	3	main
normaaline	doc_534729444677_item	3501091	et	4	main
kümme	doc_534729444677_item	3501104	et	3	main
ei	doc_534729444677_item	3501128	et	4	main
ostasime	doc_534729444677_item	3501129	et	4	main
midagi	doc_534729444677_item	3501130	et	4	main
hästi	doc_534729444677_item	3501131	et	3	main
ma	doc_534729444677_item	3501132	et	3	main
ostasin	doc_534729444677_item	3501133	et	4	main
maiustused	doc_534729444677_item	3501134	et	4	main
siis	doc_534729444677_item	3501135	et	3	main
sõitsime	doc_534729444677_item	3501136	et	3	main
tallinnasse	doc_534729444677_item	3501137	et	3	main
seal	doc_534729444677_item	3501138	et	4	main
oli	doc_534729444677_item	3501139	et	3	main
külm	doc_534729444677_item	3501140	et	3	main
ilm	doc_534729444677_item	3501141	et	3	main
jakk	doc_534729444677_item	3501142	et	3	main
oli	doc_534729444677_item	3501143	et	3	main
vaja	doc_534729444677_item	3501144	et	4	main
juba	doc_534729444680_item	3501171	et	3	main
ainult	doc_534729444680_item	3501181	et	4	main
hommikul	doc_534729444680_item	3501182	et	3	main
ma	doc_534729444680_item	3501183	et	3	main
jalutasin	doc_534729444680_item	3501184	et	3	main
tõnuga	doc_534729444680_item	3501185	et	4	main
sõin	doc_534729444680_item	3501191	et	3	main
ma	doc_534729444680_item	3501194	et	3	main
mida	doc_534729444680_item	3501197	et	4	main
jooksin	doc_534729444680_item	3501212	et	4	main
mina	doc_534729444680_item	3501242	et	4	main
veel	doc_534729444680_item	3501244	et	4	main
pargis	doc_534729444680_item	3501246	et	3	main
olen	doc_534729444680_item	3501259	et	3	main
märkmeid	doc_534729444680_item	3501262	et	3	main
kuni	doc_534729444680_item	3501263	et	3	main
ma	doc_534729444680_item	3501264	et	3	main
magasin	doc_534729444680_item	3501265	et	4	main
jääma	doc_534729444680_item	3501266	et	4	main
020806	doc_534729444681_item	3501269	et	2	main
ma	doc_534729444681_item	3501280	et	3	main
pargi	doc_534729444681_item	3501284	et	4	main
piimiga	doc_534729444681_item	3501289	et	4	main
ja	doc_534729444681_item	3501290	et	3	main
sõin	doc_534729444681_item	3501291	et	3	main
minu	doc_534729444681_item	3501298	et	3	main
palju	doc_534729444681_item	3501301	et	4	main
sest	doc_534729444681_item	3501303	et	4	main
kestis	doc_534729444681_item	3501342	et	4	main
me	doc_534729444681_item	3501356	et	4	main
saime	doc_534729444681_item	3501357	et	3	main
pool	doc_534729444681_item	3501365	et	4	main
me	doc_534729444681_item	3501388	et	4	main
läksime	doc_534729444681_item	3501389	et	3	main
ostma	doc_534729444681_item	3501390	et	3	main
ja	doc_534729444681_item	3501391	et	3	main
teeme	doc_534729444681_item	3501392	et	3	main
homme	doc_534729444680_item	3501164	et	3	main
on	doc_534729444680_item	3501166	et	4	main
täna	doc_534729444680_item	3501168	et	4	main
ma	doc_534729444680_item	3501169	et	3	main
olin	doc_534729444680_item	3501170	et	3	main
keestin	doc_534729444680_item	3501188	et	4	main
tõnu	doc_534729444680_item	3501205	et	4	main
paisul	doc_534729444680_item	3501208	et	3	main
ja	doc_534729444680_item	3501213	et	3	main
siis	doc_534729444680_item	3501214	et	3	main
ma	doc_534729444680_item	3501215	et	3	main
käisin	doc_534729444680_item	3501216	et	3	main
duši	doc_534729444680_item	3501217	et	2	main
all	doc_534729444680_item	3501218	et	3	main
õhtul	doc_534729444680_item	3501219	et	3	main
ma	doc_534729444680_item	3501220	et	3	main
olen	doc_534729444680_item	3501221	et	3	main
söönud	doc_534729444680_item	3501222	et	4	main
salatit	doc_534729444680_item	3501223	et	3	main
ja	doc_534729444680_item	3501224	et	3	main
siis	doc_534729444680_item	3501225	et	3	main
ma	doc_534729444680_item	3501226	et	3	main
jutustasin	doc_534729444680_item	3501227	et	3	main
oma	doc_534729444680_item	3501228	et	4	main
kaasüürilisele	doc_534729444680_item	3501229	et	4	main
veel	doc_534729444680_item	3501230	et	4	main
kord	doc_534729444680_item	3501231	et	4	main
kõike	doc_534729444680_item	3501232	et	4	main
mida	doc_534729444680_item	3501233	et	4	main
tean	doc_534729444680_item	3501235	et	3	main
ma	doc_534729444680_item	3501234	et	3	main
teema	doc_534729444680_item	3501236	et	4	main
eksami	doc_534729444680_item	3501237	et	3	main
kohale	doc_534729444680_item	3501238	et	4	main
mare	doc_534729444680_item	3501240	et	4	main
kord	doc_534729444680_item	3501245	et	4	main
lugenud	doc_534729444680_item	3501260	et	4	main
kaheksa	doc_534729444681_item	3501271	et	4	main
ja	doc_534729444681_item	3501275	et	3	main
all	doc_534729444681_item	3501278	et	3	main
läbi	doc_534729444681_item	3501283	et	4	main
ma	doc_534729444681_item	3501286	et	3	main
jõin	doc_534729444681_item	3501287	et	3	main
kohvi	doc_534729444681_item	3501288	et	4	main
kord	doc_534729444681_item	3501296	et	4	main
kaks	doc_534729444681_item	3501345	et	3	main
oma	doc_534729444681_item	3501358	et	4	main
hindeid	doc_534729444681_item	3501359	et	3	main
kõik	doc_534729444681_item	3501360	et	4	main
said	doc_534729444681_item	3501361	et	4	main
üks	doc_534729444681_item	3501362	et	3	main
ma	doc_534729444681_item	3501367	et	3	main
baarisse	doc_534729444681_item	3501403	et	3	main
seal	doc_534729444681_item	3501404	et	4	main
pärast	doc_534729444681_item	3501419	et	4	main
ma	doc_534729444681_item	3501420	et	3	main
üles	doc_534729444682_item	3501429	et	3	main
kell	doc_534729444682_item	3501430	et	3	main
üheksa	doc_534729444682_item	3501432	et	4	main
algul	doc_534729444682_item	3501433	et	4	main
ma	doc_534729444682_item	3501434	et	3	main
ma	doc_534729444682_item	3501438	et	3	main
ma	doc_534729444682_item	3501452	et	3	main
jagrattaga	doc_534729444682_item	3501454	et	4	main
ma	doc_534729444682_item	3501459	et	3	main
sõitsin	doc_534729444682_item	3501464	et	3	main
sõbrale	doc_534729444682_item	3501466	et	3	main
ka	doc_534729444682_item	3501470	et	3	main
me	doc_534729444682_item	3501472	et	4	main
koertega	doc_534729444682_item	3501474	et	3	main
kohvi	doc_534729444682_item	3501478	et	4	main
rootsis	doc_534729444682_item	3501495	et	3	main
aga	doc_534729444682_item	3501496	et	3	main
minu	doc_534729444682_item	3501497	et	3	main
kell	doc_534729444681_item	3501270	et	3	main
üles	doc_534729444681_item	3501274	et	3	main
duši	doc_534729444681_item	3501277	et	2	main
siis	doc_534729444681_item	3501279	et	3	main
olid	doc_534729444681_item	3501300	et	4	main
närvline	doc_534729444681_item	3501307	et	4	main
kell	doc_534729444681_item	3501308	et	3	main
kaksteist	doc_534729444681_item	3501309	et	4	main
veerand	doc_534729444681_item	3501310	et	4	main
ma	doc_534729444681_item	3501311	et	3	main
läksin	doc_534729444681_item	3501312	et	3	main
instituudisse	doc_534729444681_item	3501313	et	3	main
enne	doc_534729444681_item	3501314	et	4	main
seda	doc_534729444681_item	3501315	et	3	main
ma	doc_534729444681_item	3501316	et	3	main
olen	doc_534729444681_item	3501317	et	3	main
ostnud	doc_534729444681_item	3501318	et	4	main
kohvi	doc_534729444681_item	3501319	et	4	main
pagaril	doc_534729444681_item	3501320	et	3	main
instituudis	doc_534729444681_item	3501321	et	3	main
ma	doc_534729444681_item	3501322	et	3	main
kogesin	doc_534729444681_item	3501323	et	3	main
et	doc_534729444681_item	3501324	et	3	main
me	doc_534729444681_item	3501325	et	4	main
oleme	doc_534729444681_item	3501326	et	3	main
nelja	doc_534729444681_item	3501327	et	4	main
asemele	doc_534729444681_item	3501328	et	4	main
kuus	doc_534729444681_item	3501329	et	4	main
inimest	doc_534729444681_item	3501330	et	3	main
ma	doc_534729444681_item	3501333	et	3	main
olin	doc_534729444681_item	3501334	et	3	main
natuke	doc_534729444681_item	3501335	et	4	main
pahandanud	doc_534729444681_item	3501336	et	4	main
kell	doc_534729444681_item	3501337	et	3	main
üks	doc_534729444681_item	3501338	et	3	main
eksam	doc_534729444681_item	3501339	et	3	main
algas	doc_534729444681_item	3501340	et	3	main
ta	doc_534729444681_item	3501341	et	4	main
tundi	doc_534729444681_item	3501346	et	4	main
me	doc_534729444681_item	3501349	et	4	main
väga	doc_534729444681_item	3501351	et	3	main
pärast	doc_534729444681_item	3501353	et	4	main
neli	doc_534729444681_item	3501366	et	3	main
me	doc_534729444681_item	3501401	et	4	main
ma	doc_534729444681_item	3501411	et	3	main
040806	doc_534729444682_item	3501425	et	2	main
käin	doc_534729444682_item	3501439	et	3	main
mina	doc_534729444682_item	3501449	et	4	main
sõime	doc_534729444682_item	3501450	et	4	main
hommikueinet	doc_534729444682_item	3501451	et	3	main
sõitsin	doc_534729444682_item	3501453	et	3	main
ostsin	doc_534729444682_item	3501460	et	3	main
autoga	doc_534729444682_item	3501465	et	3	main
tal	doc_534729444682_item	3501467	et	3	main
ja	doc_534729444682_item	3501479	et	3	main
kooki	doc_534729444682_item	3501481	et	4	main
veedavad	doc_534729444682_item	3501493	et	3	main
homme	doc_534729444683_item	3501530	et	3	main
ei	doc_534729444683_item	3501543	et	4	main
üles	doc_534729444683_item	3501546	et	3	main
pool	doc_534729444683_item	3501548	et	4	main
ma	doc_534729444683_item	3501550	et	3	main
tõusin	doc_534729444683_item	3501551	et	3	main
ma	doc_534729444683_item	3501560	et	3	main
läbi	doc_534729444683_item	3501567	et	4	main
me	doc_534729444683_item	3501608	et	4	main
oleme	doc_534729444683_item	3501609	et	3	main
tahtsin	doc_534729444685_item	3501786	et	3	main
väga	doc_534729444685_item	3501788	et	3	main
enne	doc_534729444685_item	3501796	et	4	main
üheksat	doc_534729444685_item	3501797	et	3	main
ma	doc_534729444685_item	3501799	et	3	main
täna	doc_534729444685_item	3501802	et	4	main
marega	doc_534729444685_item	3501813	et	2	main
mööda	doc_534729444685_item	3501815	et	4	main
mare	doc_534729444685_item	3501817	et	4	main
tõnu	doc_534729444685_item	3501818	et	4	main
ja	doc_534729444685_item	3501819	et	3	main
vanaema	doc_534729444685_item	3501826	et	4	main
jaoks	doc_534729444685_item	3501827	et	4	main
pargis	doc_534729444685_item	3501835	et	3	main
me	doc_534729444685_item	3501837	et	4	main
järvele	doc_534729444685_item	3501853	et	4	main
nuudleid	doc_534729444685_item	3501857	et	3	main
juuli	doc_534729444687_item	3501882	et	4	main
lennuk	doc_534729444687_item	3501885	et	3	main
viie	doc_534729444687_item	3501887	et	3	main
londonisse	doc_534729444687_item	3501891	et	4	main
jõudsime	doc_534729444687_item	3501902	et	3	main
läksime	doc_534729444687_item	3501910	et	3	main
me	doc_534729444687_item	3501924	et	4	main
sõbrannaga	doc_534729444687_item	3501945	et	3	main
rongiga	doc_534729444687_item	3501957	et	4	main
koju	doc_534729444687_item	3501958	et	3	main
me	doc_534729444687_item	3501959	et	4	main
olime	doc_534729444687_item	3501960	et	3	main
väga	doc_534729444687_item	3501961	et	3	main
näljane	doc_534729444687_item	3501962	et	4	main
ostsime	doc_534729444687_item	3501963	et	3	main
söögi	doc_534729444687_item	3501966	et	4	main
tegime	doc_534729444687_item	3501968	et	3	main
sõime	doc_534729444690_item	3501986	et	4	main
hommikusöök	doc_534729444690_item	3501987	et	3	main
ja	doc_534729444690_item	3501988	et	3	main
siis	doc_534729444690_item	3501989	et	3	main
pikemalt	doc_534729444681_item	3501343	et	4	main
kui	doc_534729444681_item	3501344	et	3	main
pärast	doc_534729444681_item	3501347	et	4	main
väsinud	doc_534729444681_item	3501352	et	4	main
kümnet	doc_534729444681_item	3501354	et	4	main
minutit	doc_534729444681_item	3501355	et	3	main
a	doc_534729444681_item	3501363	et	4	main
kell	doc_534729444681_item	3501364	et	3	main
tulin	doc_534729444681_item	3501368	et	3	main
lühike	doc_534729444681_item	3501370	et	4	main
kodus	doc_534729444681_item	3501369	et	4	main
pärast	doc_534729444681_item	3501371	et	4	main
mare	doc_534729444681_item	3501372	et	4	main
tuli	doc_534729444681_item	3501373	et	4	main
järele	doc_534729444681_item	3501374	et	4	main
minu	doc_534729444681_item	3501375	et	3	main
ja	doc_534729444681_item	3501376	et	3	main
me	doc_534729444681_item	3501377	et	4	main
jalutasime	doc_534729444681_item	3501378	et	3	main
marega	doc_534729444681_item	3501379	et	2	main
sest	doc_534729444681_item	3501380	et	4	main
sadas	doc_534729444681_item	3501381	et	3	main
vihma	doc_534729444681_item	3501382	et	4	main
me	doc_534729444681_item	3501383	et	4	main
olime	doc_534729444681_item	3501384	et	3	main
väga	doc_534729444681_item	3501385	et	3	main
märg	doc_534729444681_item	3501386	et	3	main
süüa	doc_534729444681_item	3501393	et	3	main
kokku	doc_534729444681_item	3501394	et	3	main
õhtul	doc_534729444681_item	3501395	et	3	main
ma	doc_534729444681_item	3501396	et	3	main
sain	doc_534729444681_item	3501397	et	3	main
kokku	doc_534729444681_item	3501398	et	3	main
sõbradega	doc_534729444681_item	3501399	et	4	main
ja	doc_534729444681_item	3501400	et	3	main
jõime	doc_534729444681_item	3501406	et	3	main
heitsin	doc_534729444681_item	3501421	et	3	main
voodisse	doc_534729444681_item	3501422	et	3	main
täna	doc_534729444682_item	3501426	et	4	main
tõusin	doc_534729444682_item	3501428	et	3	main
pool	doc_534729444682_item	3501431	et	4	main
siis	doc_534729444682_item	3501437	et	3	main
jalutasin	doc_534729444682_item	3501443	et	3	main
lühidus	doc_534729444682_item	3501445	et	4	main
pärast	doc_534729444682_item	3501446	et	4	main
laenutama	doc_534729444682_item	3501456	et	4	main
pärastlõunal	doc_534729444682_item	3501458	et	3	main
viis	doc_534729444682_item	3501462	et	4	main
jõime	doc_534729444682_item	3501477	et	3	main
sõime	doc_534729444682_item	3501480	et	4	main
pärast	doc_534729444682_item	3501482	et	4	main
ma	doc_534729444682_item	3501483	et	3	main
sõitsin	doc_534729444682_item	3501484	et	3	main
sillamäele	doc_534729444682_item	3501485	et	2	main
kus	doc_534729444682_item	3501486	et	3	main
oma	doc_534729444682_item	3501487	et	4	main
puhkust	doc_534729444682_item	3501494	et	4	main
mul	doc_534729444683_item	3501531	et	3	main
juba	doc_534729444683_item	3501537	et	3	main
olin	doc_534729444683_item	3501539	et	3	main
tõusma	doc_534729444683_item	3501545	et	3	main
kell	doc_534729444683_item	3501547	et	3	main
jooksin	doc_534729444683_item	3501556	et	4	main
pool	doc_534729444683_item	3501557	et	4	main
all	doc_534729444683_item	3501563	et	3	main
ja	doc_534729444683_item	3501602	et	3	main
jalutasime	doc_534729444683_item	3501604	et	3	main
metsasse	doc_534729444683_item	3501606	et	4	main
pärast	doc_534729444683_item	3501607	et	4	main
jääma	doc_534729444683_item	3501646	et	4	main
ärkasin	doc_534729444685_item	3501794	et	3	main
sest	doc_534729444685_item	3501798	et	4	main
pidasin	doc_534729444685_item	3501800	et	3	main
midagi	doc_534729444685_item	3501804	et	4	main
ma	doc_534729444685_item	3501805	et	3	main
jäin	doc_534729444685_item	3501806	et	3	main
voodis	doc_534729444685_item	3501807	et	3	main
umbes	doc_534729444685_item	3501808	et	4	main
kell	doc_534729444685_item	3501809	et	3	main
kümme	doc_534729444685_item	3501810	et	3	main
mina	doc_534729444685_item	3501820	et	4	main
sõitsime	doc_534729444685_item	3501821	et	3	main
autoga	doc_534729444685_item	3501822	et	3	main
tartusse	doc_534729444685_item	3501823	et	3	main
sööki	doc_534729444685_item	3501825	et	4	main
jooma	doc_534729444685_item	3501839	et	4	main
vastasin	doc_534729444685_item	3501843	et	3	main
emailisid	doc_534729444685_item	3501844	et	4	main
kell	doc_534729444685_item	3501845	et	3	main
tõnuga	doc_534729444685_item	3501852	et	4	main
ma	doc_534729444685_item	3501855	et	3	main
läksime	doc_534729444681_item	3501402	et	3	main
umbes	doc_534729444681_item	3501408	et	4	main
kell	doc_534729444681_item	3501409	et	3	main
üks	doc_534729444681_item	3501410	et	3	main
kodus	doc_534729444681_item	3501413	et	4	main
ja	doc_534729444681_item	3501414	et	3	main
läksin	doc_534729444681_item	3501415	et	3	main
marega	doc_534729444681_item	3501416	et	2	main
me	doc_534729444682_item	3501503	et	4	main
sõime	doc_534729444682_item	3501504	et	4	main
õhtust	doc_534729444682_item	3501505	et	4	main
kokku	doc_534729444682_item	3501506	et	3	main
siis	doc_534729444682_item	3501507	et	3	main
ma	doc_534729444682_item	3501508	et	3	main
läksin	doc_534729444682_item	3501509	et	3	main
vanaemaga	doc_534729444682_item	3501510	et	3	main
aiasse	doc_534729444682_item	3501511	et	4	main
ma	doc_534729444682_item	3501512	et	3	main
lugesin	doc_534729444682_item	3501513	et	3	main
raamatus	doc_534729444682_item	3501514	et	4	main
kirjaliku	doc_534729444682_item	3501515	et	3	main
jaoks	doc_534729444682_item	3501517	et	4	main
semiaritöö	doc_534729444682_item	3501516	et	4	main
ja	doc_534729444682_item	3501518	et	3	main
siis	doc_534729444682_item	3501519	et	3	main
ma	doc_534729444682_item	3501520	et	3	main
vaatasin	doc_534729444682_item	3501521	et	3	main
televiisorit	doc_534729444682_item	3501522	et	3	main
pärast	doc_534729444682_item	3501523	et	4	main
ma	doc_534729444682_item	3501524	et	3	main
heitsin	doc_534729444682_item	3501525	et	3	main
voodisse	doc_534729444682_item	3501526	et	3	main
jooksin	doc_534729444682_item	3501435	et	4	main
duši	doc_534729444682_item	3501440	et	2	main
ma	doc_534729444682_item	3501442	et	3	main
tõnuga	doc_534729444682_item	3501444	et	4	main
tõnu	doc_534729444682_item	3501447	et	4	main
ja	doc_534729444682_item	3501448	et	3	main
raamatukogusse	doc_534729444682_item	3501455	et	3	main
kell	doc_534729444682_item	3501461	et	3	main
koer	doc_534729444682_item	3501469	et	3	main
ja	doc_534729444682_item	3501471	et	3	main
siis	doc_534729444682_item	3501475	et	3	main
vanaema	doc_534729444682_item	3501498	et	4	main
ja	doc_534729444682_item	3501499	et	3	main
vend	doc_534729444682_item	3501500	et	3	main
olid	doc_534729444682_item	3501501	et	4	main
seal	doc_534729444682_item	3501502	et	4	main
päevik	doc_534729444683_item	3501528	et	3	main
ma	doc_534729444683_item	3501542	et	3	main
tundi	doc_534729444683_item	3501558	et	4	main
siis	doc_534729444683_item	3501559	et	3	main
ma	doc_534729444683_item	3501564	et	3	main
tõnuga	doc_534729444683_item	3501566	et	4	main
pargi	doc_534729444683_item	3501568	et	4	main
käinud	doc_534729444683_item	3501610	et	4	main
magama	doc_534729444683_item	3501645	et	3	main
190806	doc_534729444685_item	3501783	et	2	main
ma	doc_534729444685_item	3501785	et	3	main
päris	doc_534729444685_item	3501787	et	4	main
jääda	doc_534729444685_item	3501790	et	4	main
ma	doc_534729444685_item	3501793	et	3	main
ma	doc_534729444685_item	3501811	et	3	main
ostma	doc_534729444685_item	3501824	et	3	main
ma	doc_534729444685_item	3501830	et	3	main
kaks	doc_534729444685_item	3501833	et	3	main
ja	doc_534729444685_item	3501836	et	3	main
läksime	doc_534729444685_item	3501838	et	3	main
kohvi	doc_534729444685_item	3501840	et	4	main
pärastlõunal	doc_534729444685_item	3501841	et	3	main
ma	doc_534729444685_item	3501842	et	3	main
päevik	doc_534729444687_item	3501879	et	3	main
väljusis	doc_534729444687_item	3501886	et	4	main
minuti	doc_534729444687_item	3501888	et	3	main
üheksa	doc_534729444687_item	3501890	et	4	main
me	doc_534729444687_item	3501909	et	4	main
me	doc_534729444687_item	3501912	et	4	main
puhkama	doc_534729444687_item	3501914	et	3	main
üks	doc_534729444687_item	3501918	et	3	main
hea	doc_534729444687_item	3501919	et	4	main
ja	doc_534729444687_item	3501920	et	3	main
seal	doc_534729444687_item	3501931	et	4	main
aeg	doc_534729444687_item	3501933	et	3	main
lugesime	doc_534729444687_item	3501936	et	3	main
magasime	doc_534729444687_item	3501937	et	3	main
vanemad	doc_534729444682_item	3501488	et	4	main
elavad	doc_534729444682_item	3501489	et	4	main
just	doc_534729444682_item	3501490	et	3	main
praegu	doc_534729444682_item	3501491	et	3	main
nad	doc_534729444682_item	3501492	et	3	main
170806	doc_534729444683_item	3501529	et	2	main
on	doc_534729444683_item	3501532	et	4	main
veel	doc_534729444683_item	3501533	et	4	main
kord	doc_534729444683_item	3501534	et	4	main
eksam	doc_534729444683_item	3501535	et	3	main
hommikul	doc_534729444683_item	3501536	et	3	main
ma	doc_534729444683_item	3501538	et	3	main
närviline	doc_534729444683_item	3501540	et	4	main
sellepärast	doc_534729444683_item	3501541	et	3	main
kümme	doc_534729444683_item	3501549	et	3	main
aga	doc_534729444683_item	3501553	et	3	main
ja	doc_534729444683_item	3501555	et	3	main
duši	doc_534729444683_item	3501562	et	2	main
jalutasin	doc_534729444683_item	3501565	et	3	main
pärast	doc_534729444683_item	3501569	et	4	main
olen	doc_534729444683_item	3501639	et	3	main
kell	doc_534729444683_item	3501617	et	3	main
üheksa	doc_534729444683_item	3501618	et	4	main
minu	doc_534729444683_item	3501619	et	3	main
kaaselanik	doc_534729444683_item	3501620	et	3	main
küsitles	doc_534729444683_item	3501621	et	3	main
mind	doc_534729444683_item	3501622	et	4	main
pärast	doc_534729444683_item	3501623	et	4	main
ma	doc_534729444683_item	3501624	et	3	main
vihtisin	doc_534729444683_item	3501625	et	4	main
kahe	doc_534729444683_item	3501626	et	3	main
kaasüürilitsega	doc_534729444683_item	3501627	et	4	main
järjelugu	doc_534729444683_item	3501628	et	4	main
lost	doc_534729444683_item	3501629	et	4	main
kesköö	doc_534729444683_item	3501630	et	4	main
ma	doc_534729444683_item	3501631	et	3	main
läksim	doc_534729444683_item	3501632	et	4	main
veel	doc_534729444683_item	3501633	et	4	main
kord	doc_534729444683_item	3501634	et	4	main
tõnuga	doc_534729444683_item	3501635	et	4	main
läbi	doc_534729444683_item	3501636	et	4	main
pargi	doc_534729444683_item	3501637	et	4	main
ma	doc_534729444683_item	3501638	et	3	main
tahtnud	doc_534729444683_item	3501544	et	4	main
üles	doc_534729444683_item	3501552	et	3	main
küll	doc_534729444683_item	3501554	et	4	main
käisin	doc_534729444683_item	3501561	et	3	main
hommikusööki	doc_534729444683_item	3501570	et	4	main
ma	doc_534729444683_item	3501571	et	3	main
läksin	doc_534729444683_item	3501572	et	3	main
muuseumisse	doc_534729444683_item	3501573	et	3	main
sest	doc_534729444683_item	3501574	et	4	main
ma	doc_534729444683_item	3501575	et	3	main
tahtsin	doc_534729444683_item	3501576	et	3	main
vaadata	doc_534729444683_item	3501577	et	4	main
veel	doc_534729444683_item	3501578	et	4	main
kord	doc_534729444683_item	3501579	et	4	main
näitust	doc_534729444683_item	3501580	et	4	main
teema	doc_534729444683_item	3501581	et	4	main
eksami	doc_534729444683_item	3501582	et	3	main
jaoks	doc_534729444683_item	3501583	et	4	main
see	doc_534729444683_item	3501584	et	3	main
kests	doc_534729444683_item	3501585	et	4	main
ainult	doc_534729444683_item	3501586	et	4	main
pool	doc_534729444683_item	3501587	et	4	main
tundi	doc_534729444683_item	3501588	et	4	main
kodus	doc_534729444683_item	3501589	et	4	main
ma	doc_534729444683_item	3501590	et	3	main
õppisin	doc_534729444683_item	3501591	et	3	main
edasi	doc_534729444683_item	3501592	et	3	main
kell	doc_534729444683_item	3501593	et	3	main
pool	doc_534729444683_item	3501594	et	4	main
seitse	doc_534729444683_item	3501595	et	3	main
minu	doc_534729444683_item	3501596	et	3	main
parim	doc_534729444683_item	3501597	et	4	main
sõber	doc_534729444683_item	3501598	et	3	main
tuli	doc_534729444683_item	3501599	et	4	main
järele	doc_534729444683_item	3501600	et	4	main
minu	doc_534729444683_item	3501601	et	3	main
me	doc_534729444683_item	3501603	et	4	main
marega	doc_534729444683_item	3501605	et	2	main
talle	doc_534729444683_item	3501611	et	4	main
sest	doc_534729444683_item	3501612	et	4	main
ma	doc_534729444683_item	3501613	et	3	main
pidasin	doc_534729444683_item	3501614	et	3	main
midagi	doc_534729444683_item	3501615	et	4	main
printima	doc_534729444683_item	3501616	et	3	main
hambaid	doc_534729444683_item	3501640	et	3	main
pesnud	doc_534729444683_item	3501641	et	4	main
ja	doc_534729444683_item	3501642	et	3	main
siis	doc_534729444683_item	3501643	et	3	main
püüdsin	doc_534729444683_item	3501644	et	3	main
päevik	doc_534729444685_item	3501782	et	3	main
kaua	doc_534729444685_item	3501789	et	3	main
voodis	doc_534729444685_item	3501791	et	3	main
aga	doc_534729444685_item	3501792	et	3	main
jalutasin	doc_534729444685_item	3501812	et	3	main
pärast	doc_534729444685_item	3501816	et	4	main
sain	doc_534729444685_item	3501831	et	3	main
sõpra	doc_534729444685_item	3501834	et	4	main
pool	doc_534729444685_item	3501846	et	4	main
hommikul	doc_534729444687_item	3501883	et	3	main
pärast	doc_534729444687_item	3501889	et	4	main
alustasime	doc_534729444687_item	3501898	et	3	main
pagaslt	doc_534729444687_item	3501908	et	4	main
vaikselt	doc_534729444687_item	3501921	et	4	main
koht	doc_534729444687_item	3501922	et	3	main
sandvitšiga	doc_534729444687_item	3501923	et	2	main
james	doc_534729444687_item	3501927	et	4	main
pargisse	doc_534729444687_item	3501928	et	3	main
me	doc_534729444687_item	3501943	et	4	main
liiga	doc_534729444687_item	3501950	et	4	main
kaua	doc_534729444687_item	3501951	et	3	main
otsing	doc_534729444687_item	3501952	et	3	main
kohtumine	doc_534729444687_item	3501953	et	4	main
koht	doc_534729444687_item	3501954	et	3	main
õhtusse	doc_534729444687_item	3501975	et	4	main
vahtisin	doc_534729444685_item	3501861	et	3	main
kaaselanigutega	doc_534729444685_item	3501862	et	4	main
üks	doc_534729444685_item	3501863	et	3	main
film	doc_534729444685_item	3501864	et	3	main
kell	doc_534729444685_item	3501865	et	3	main
üksteist	doc_534729444685_item	3501866	et	4	main
ma	doc_534729444685_item	3501867	et	3	main
läksin	doc_534729444685_item	3501868	et	3	main
tõnuga	doc_534729444685_item	3501869	et	4	main
veel	doc_534729444685_item	3501870	et	4	main
kord	doc_534729444685_item	3501871	et	4	main
läbi	doc_534729444685_item	3501872	et	4	main
pargi	doc_534729444685_item	3501873	et	4	main
siis	doc_534729444685_item	3501874	et	3	main
ma	doc_534729444685_item	3501875	et	3	main
heitsin	doc_534729444685_item	3501876	et	3	main
voodisse	doc_534729444685_item	3501877	et	3	main
täna	doc_534729444685_item	3501784	et	4	main
juba	doc_534729444685_item	3501795	et	3	main
tegema	doc_534729444685_item	3501801	et	3	main
mitte	doc_534729444685_item	3501803	et	3	main
jõge	doc_534729444685_item	3501814	et	3	main
kell	doc_534729444685_item	3501828	et	3	main
kaksteist	doc_534729444685_item	3501829	et	4	main
kokku	doc_534729444685_item	3501832	et	3	main
kuus	doc_534729444685_item	3501847	et	4	main
ma	doc_534729444685_item	3501848	et	3	main
jalutasin	doc_534729444685_item	3501849	et	3	main
mare	doc_534729444685_item	3501850	et	4	main
ja	doc_534729444685_item	3501851	et	3	main
kodus	doc_534729444685_item	3501854	et	4	main
sõin	doc_534729444685_item	3501856	et	3	main
spinatiga	doc_534729444685_item	3501858	et	3	main
hiljem	doc_534729444685_item	3501859	et	3	main
ma	doc_534729444685_item	3501860	et	3	main
esmaspäev	doc_534729444687_item	3501880	et	3	main
meil	doc_534729444687_item	3501892	et	4	main
mina	doc_534729444687_item	3501895	et	4	main
puhkus	doc_534729444687_item	3501897	et	3	main
pool	doc_534729444687_item	3501899	et	4	main
kümme	doc_534729444687_item	3501900	et	3	main
me	doc_534729444687_item	3501901	et	4	main
londonis	doc_534729444687_item	3501903	et	4	main
raske	doc_534729444687_item	3501907	et	4	main
soovisime	doc_534729444687_item	3501913	et	3	main
siis	doc_534729444687_item	3501915	et	3	main
läksime	doc_534729444687_item	3501925	et	3	main
ja	doc_534729444687_item	3501929	et	3	main
meie	doc_534729444687_item	3501932	et	4	main
kohtusime	doc_534729444687_item	3501944	et	4	main
me	doc_534729444687_item	3501947	et	4	main
pärast	doc_534729444687_item	3501949	et	4	main
maitsva	doc_534729444687_item	3501965	et	4	main
ja	doc_534729444687_item	3501967	et	3	main
me	doc_534729444687_item	3501970	et	4	main
ajasime	doc_534729444687_item	3501971	et	3	main
juttu	doc_534729444687_item	3501972	et	4	main
pakkisime	doc_534729444690_item	3501991	et	3	main
me	doc_534729444690_item	3502001	et	4	main
me	doc_534729444690_item	3502008	et	4	main
kaua	doc_534729444690_item	3502014	et	3	main
nägeminel	doc_534729444690_item	3502029	et	4	main
me	doc_534729444690_item	3502030	et	4	main
pidu	doc_534729444690_item	3502050	et	4	main
liiga	doc_534729444690_item	3502056	et	4	main
kaua	doc_534729444690_item	3502057	et	3	main
sõime	doc_534729444691_item	3502086	et	4	main
aga	doc_534729444691_item	3502093	et	3	main
vaid	doc_534729444691_item	3502097	et	3	main
me	doc_534729444691_item	3502100	et	4	main
tunni	doc_534729444691_item	3502103	et	3	main
päikesepiste	doc_534729444691_item	3502118	et	4	main
oli	doc_534729444691_item	3502125	et	3	main
väga	doc_534729444691_item	3502126	et	3	main
lõbus	doc_534729444691_item	3502171	et	4	main
gruppi	doc_534729444691_item	3502175	et	4	main
võitlesime	doc_534729444691_item	3502177	et	3	main
29	doc_534729444692_item	3502190	et	2	main
ja	doc_534729444692_item	3502200	et	3	main
läksime	doc_534729444692_item	3502203	et	3	main
kesklinna	doc_534729444692_item	3502245	et	4	main
ja	doc_534729444692_item	3502246	et	3	main
siis	doc_534729444692_item	3502247	et	3	main
pärast	doc_534729444692_item	3502250	et	4	main
jõudsime	doc_534729444692_item	3502252	et	3	main
koju	doc_534729444692_item	3502253	et	3	main
me	doc_534729444692_item	3502254	et	4	main
tegime	doc_534729444692_item	3502255	et	3	main
süüa	doc_534729444692_item	3502256	et	3	main
täna	doc_534729444694_item	3502283	et	4	main
sõbranna	doc_534729444694_item	3502300	et	4	main
mathilda	doc_534729444694_item	3502301	et	2	main
ootasi	doc_534729444694_item	3502302	et	4	main
juba	doc_534729444694_item	3502303	et	3	main
sealt	doc_534729444694_item	3502311	et	4	main
meie	doc_534729444694_item	3502319	et	4	main
asub	doc_534729444694_item	3502322	et	3	main
24	doc_534729444687_item	3501881	et	2	main
meie	doc_534729444687_item	3501884	et	4	main
tõnu	doc_534729444687_item	3501893	et	4	main
ja	doc_534729444687_item	3501894	et	3	main
oma	doc_534729444687_item	3501896	et	4	main
väsinud	doc_534729444687_item	3501904	et	4	main
ja	doc_534729444687_item	3501905	et	3	main
nõrk	doc_534729444687_item	3501906	et	3	main
kesklinnasse	doc_534729444687_item	3501911	et	4	main
me	doc_534729444687_item	3501916	et	4	main
otsime	doc_534729444687_item	3501917	et	4	main
st	doc_534729444687_item	3501926	et	3	main
viibisime	doc_534729444687_item	3501930	et	3	main
seal	doc_534729444687_item	3501934	et	4	main
me	doc_534729444687_item	3501935	et	4	main
marelt	doc_534729444687_item	3501946	et	2	main
leidsime	doc_534729444687_item	3501948	et	3	main
liiga	doc_534729444687_item	3501973	et	4	main
kaua	doc_534729444687_item	3501974	et	3	main
neljapäev	doc_534729444690_item	3501978	et	3	main
kell	doc_534729444690_item	3501994	et	3	main
külastasime	doc_534729444690_item	3502002	et	3	main
sõitsime	doc_534729444690_item	3502009	et	3	main
oli	doc_534729444690_item	3502012	et	3	main
magasime	doc_534729444690_item	3502018	et	3	main
mathilda	doc_534729444690_item	3502032	et	2	main
süüa	doc_534729444690_item	3502036	et	3	main
ja	doc_534729444687_item	3501938	et	3	main
päevitasime	doc_534729444687_item	3501939	et	3	main
kell	doc_534729444687_item	3501940	et	3	main
verrand	doc_534729444687_item	3501941	et	4	main
neli	doc_534729444687_item	3501942	et	3	main
me	doc_534729444687_item	3501955	et	4	main
sõitsime	doc_534729444687_item	3501956	et	3	main
palju	doc_534729444687_item	3501964	et	4	main
süüa	doc_534729444687_item	3501969	et	3	main
juuli	doc_534729444690_item	3501980	et	4	main
pärast	doc_534729444690_item	3501981	et	4	main
me	doc_534729444690_item	3501982	et	4	main
tõusime	doc_534729444690_item	3501983	et	3	main
üles	doc_534729444690_item	3501984	et	3	main
me	doc_534729444690_item	3501985	et	4	main
meile	doc_534729444690_item	3501992	et	4	main
üksteist	doc_534729444690_item	3501995	et	4	main
mare	doc_534729444690_item	3502003	et	4	main
mathilda	doc_534729444690_item	3502005	et	2	main
tunni	doc_534729444690_item	3502007	et	3	main
liiga	doc_534729444690_item	3502013	et	4	main
me	doc_534729444690_item	3502017	et	4	main
palju	doc_534729444690_item	3502019	et	4	main
kui	doc_534729444690_item	3502020	et	3	main
me	doc_534729444690_item	3502021	et	4	main
jõudsime	doc_534729444690_item	3502022	et	3	main
bussijaam	doc_534729444690_item	3502023	et	3	main
lancesteris	doc_534729444690_item	3502024	et	4	main
rõõm	doc_534729444690_item	3502025	et	3	main
oli	doc_534729444690_item	3502026	et	3	main
väga	doc_534729444690_item	3502027	et	3	main
suur	doc_534729444690_item	3502028	et	3	main
koju	doc_534729444690_item	3502033	et	3	main
tegime	doc_534729444690_item	3502035	et	3	main
me	doc_534729444690_item	3502037	et	4	main
makaroni	doc_534729444690_item	3502039	et	4	main
jõime	doc_534729444690_item	3502040	et	3	main
vein	doc_534729444690_item	3502041	et	3	main
ja	doc_534729444690_item	3502042	et	3	main
oli	doc_534729444690_item	3502051	et	3	main
me	doc_534729444690_item	3502054	et	4	main
28	doc_534729444691_item	3502081	et	2	main
kell	doc_534729444691_item	3502083	et	3	main
hommikusöök	doc_534729444691_item	3502089	et	3	main
me	doc_534729444691_item	3502090	et	4	main
meeres	doc_534729444691_item	3502092	et	3	main
matk	doc_534729444691_item	3502099	et	3	main
matkasime	doc_534729444691_item	3502101	et	3	main
kolm	doc_534729444691_item	3502102	et	3	main
ja	doc_534729444691_item	3502105	et	3	main
läbi	doc_534729444691_item	3502107	et	4	main
valdasime	doc_534729444691_item	3502115	et	3	main
ja	doc_534729444691_item	3502121	et	3	main
mäng	doc_534729444691_item	3502163	et	3	main
oli	doc_534729444691_item	3502164	et	3	main
väga	doc_534729444691_item	3502165	et	3	main
me	doc_534729444691_item	3502172	et	4	main
õhtusse	doc_534729444690_item	3502058	et	4	main
ja	doc_534729444690_item	3502059	et	3	main
jõime	doc_534729444690_item	3502060	et	3	main
palju	doc_534729444690_item	3502061	et	4	main
õlud	doc_534729444690_item	3502062	et	4	main
kui	doc_534729444690_item	3502063	et	3	main
me	doc_534729444690_item	3502064	et	4	main
läksime	doc_534729444690_item	3502065	et	3	main
kell	doc_534729444690_item	3502066	et	3	main
kaks	doc_534729444690_item	3502067	et	3	main
koju	doc_534729444690_item	3502068	et	3	main
me	doc_534729444690_item	3502069	et	4	main
olime	doc_534729444690_item	3502070	et	3	main
natuke	doc_534729444690_item	3502071	et	4	main
purjus	doc_534729444690_item	3502072	et	3	main
aga	doc_534729444690_item	3502073	et	3	main
õhtul	doc_534729444690_item	3502074	et	3	main
oli	doc_534729444690_item	3502075	et	3	main
väga	doc_534729444690_item	3502076	et	3	main
ilus	doc_534729444690_item	3502077	et	4	main
päevik	doc_534729444690_item	3501977	et	3	main
27	doc_534729444690_item	3501979	et	2	main
me	doc_534729444690_item	3501990	et	4	main
meile	doc_534729444690_item	3501997	et	4	main
seal	doc_534729444690_item	3502000	et	4	main
bussiga	doc_534729444690_item	3502010	et	3	main
nii	doc_534729444690_item	3502015	et	3	main
läksime	doc_534729444690_item	3502031	et	3	main
sõime	doc_534729444690_item	3502038	et	4	main
ajasime	doc_534729444690_item	3502043	et	3	main
juttu	doc_534729444690_item	3502044	et	4	main
kell	doc_534729444690_item	3502045	et	3	main
kümme	doc_534729444690_item	3502046	et	3	main
väga	doc_534729444690_item	3502052	et	3	main
päevik	doc_534729444691_item	3502079	et	3	main
jalutasime	doc_534729444691_item	3502091	et	3	main
ei	doc_534729444691_item	3502094	et	4	main
oli	doc_534729444691_item	3502095	et	3	main
me	doc_534729444691_item	3502111	et	4	main
jõudsime	doc_534729444691_item	3502112	et	3	main
meeres	doc_534729444691_item	3502113	et	3	main
valutas	doc_534729444691_item	3502117	et	3	main
nina	doc_534729444691_item	3502120	et	4	main
jalga	doc_534729444691_item	3502123	et	4	main
kuum	doc_534729444691_item	3502127	et	3	main
huvitav	doc_534729444691_item	3502166	et	4	main
olime	doc_534729444691_item	3502173	et	3	main
ja	doc_534729444691_item	3502176	et	3	main
palli	doc_534729444691_item	3502178	et	4	main
päevik	doc_534729444692_item	3502188	et	3	main
natuke	doc_534729444692_item	3502199	et	4	main
me	doc_534729444692_item	3502202	et	4	main
suur	doc_534729444692_item	3502212	et	3	main
toiduaine	doc_534729444692_item	3502249	et	4	main
me	doc_534729444692_item	3502251	et	4	main
juba	doc_534729444694_item	3502285	et	3	main
ärkasin	doc_534729444694_item	3502286	et	3	main
brüsselisse	doc_534729444694_item	3502309	et	4	main
ja	doc_534729444694_item	3502310	et	3	main
montrealisse	doc_534729444694_item	3502317	et	4	main
montrealis	doc_534729444694_item	3502333	et	4	main
oli	doc_534729444694_item	3502334	et	3	main
viis	doc_534729444694_item	3502337	et	4	main
kui	doc_534729444694_item	3502338	et	3	main
ida-kanadas	doc_534729444694_item	3502341	et	4	main
ilm	doc_534729444694_item	3502342	et	3	main
oli	doc_534729444694_item	3502343	et	3	main
parem	doc_534729444694_item	3502347	et	4	main
saksamaal	doc_534729444694_item	3502349	et	4	main
sel	doc_534729444694_item	3502350	et	3	main
päeval	doc_534729444694_item	3502351	et	3	main
me	doc_534729444694_item	3502360	et	4	main
oli	doc_534729444695_item	3502398	et	3	main
magasin	doc_534729444695_item	3502401	et	4	main
kaheksa	doc_534729444695_item	3502404	et	4	main
siis	doc_534729444695_item	3502405	et	3	main
ja	doc_534729444695_item	3502409	et	3	main
ma	doc_534729444695_item	3502412	et	3	main
magogisse	doc_534729444695_item	3502417	et	4	main
ja	doc_534729444695_item	3502422	et	3	main
maria	doc_534729444695_item	3502423	et	4	main
kanadas	doc_534729444695_item	3502440	et	4	main
kanada	doc_534729444695_item	3502441	et	4	main
aasta	doc_534729444695_item	3502453	et	4	main
ja	doc_534729444695_item	3502454	et	3	main
kilometrit	doc_534729444695_item	3502461	et	4	main
stanstead	doc_534729444695_item	3502464	et	4	main
lily	doc_534729444695_item	3502471	et	2	main
armas	doc_534729444695_item	3502479	et	3	main
veel	doc_534729444699_item	3502493	et	4	main
söin	doc_534729444699_item	3502502	et	4	main
ja	doc_534729444699_item	3502506	et	3	main
tõnuga	doc_534729444699_item	3502514	et	4	main
frontenac	doc_534729444699_item	3502537	et	4	main
natuke	doc_534729444699_item	3502556	et	4	main
täna	doc_534729444699_item	3502562	et	4	main
ostasin	doc_534729444699_item	3502566	et	4	main
lady	doc_534729444699_item	3502569	et	4	main
pagasi	doc_534729444690_item	3501993	et	3	main
väljus	doc_534729444690_item	3501996	et	4	main
buss	doc_534729444690_item	3501998	et	3	main
lancesterisse	doc_534729444690_item	3501999	et	4	main
sõbrannale	doc_534729444690_item	3502004	et	3	main
kaheksa	doc_534729444690_item	3502006	et	4	main
sõit	doc_534729444690_item	3502011	et	3	main
et	doc_534729444690_item	3502016	et	3	main
ja	doc_534729444690_item	3502034	et	3	main
me	doc_534729444690_item	3502047	et	4	main
läksime	doc_534729444690_item	3502048	et	3	main
pidule	doc_534729444690_item	3502049	et	3	main
hea	doc_534729444690_item	3502053	et	4	main
tantsisime	doc_534729444690_item	3502055	et	3	main
juuli	doc_534729444691_item	3502082	et	4	main
üksteist	doc_534729444691_item	3502084	et	4	main
me	doc_534729444691_item	3502085	et	4	main
hommikust	doc_534729444691_item	3502087	et	4	main
jalutuskäik	doc_534729444691_item	3502096	et	3	main
me	doc_534729444691_item	3502114	et	4	main
valutas	doc_534729444691_item	3502122	et	3	main
päev	doc_534729444691_item	3502124	et	3	main
me	doc_534729444691_item	3502128	et	4	main
puhkasime	doc_534729444691_item	3502129	et	3	main
kõrtsi	doc_534729444691_item	3502130	et	4	main
ja	doc_534729444691_item	3502131	et	3	main
sõime	doc_534729444691_item	3502132	et	4	main
sandvitši	doc_534729444691_item	3502133	et	2	main
ja	doc_534729444691_item	3502134	et	3	main
tegime	doc_534729444691_item	3502169	et	3	main
palju	doc_534729444691_item	3502170	et	4	main
juuli	doc_534729444692_item	3502191	et	4	main
me	doc_534729444692_item	3502209	et	4	main
istusime	doc_534729444692_item	3502210	et	3	main
väga	doc_534729444692_item	3502211	et	3	main
päevik	doc_534729444694_item	3502281	et	3	main
kell	doc_534729444694_item	3502288	et	3	main
pool	doc_534729444694_item	3502289	et	4	main
neli	doc_534729444694_item	3502290	et	3	main
sest	doc_534729444694_item	3502291	et	4	main
ma	doc_534729444694_item	3502292	et	3	main
pidasin	doc_534729444694_item	3502293	et	3	main
olla	doc_534729444694_item	3502294	et	3	main
kölni	doc_534729444694_item	3502295	et	4	main
raudteejaamas	doc_534729444694_item	3502296	et	3	main
kell	doc_534729444694_item	3502297	et	3	main
seitse	doc_534729444694_item	3502298	et	3	main
minu	doc_534729444694_item	3502299	et	3	main
me	doc_534729444694_item	3502306	et	4	main
sõitsime	doc_534729444694_item	3502307	et	3	main
üheskoos	doc_534729444694_item	3502308	et	3	main
noorte	doc_534729444694_item	3502320	et	3	main
mont	doc_534729444694_item	3502323	et	4	main
royali	doc_534729444694_item	3502324	et	4	main
mäel	doc_534729444694_item	3502325	et	3	main
ja	doc_534729444694_item	3502327	et	3	main
ma	doc_534729444694_item	3502328	et	3	main
olime	doc_534729444694_item	3502329	et	3	main
väga	doc_534729444694_item	3502330	et	3	main
väsinud	doc_534729444694_item	3502331	et	4	main
aga	doc_534729444694_item	3502332	et	3	main
soe	doc_534729444694_item	3502344	et	4	main
ja	doc_534729444694_item	3502345	et	3	main
kui	doc_534729444694_item	3502348	et	3	main
jalutasime	doc_534729444694_item	3502353	et	3	main
leidsi	doc_534729444694_item	3502362	et	4	main
hommikusöögi	doc_534729444695_item	3502411	et	3	main
ja	doc_534729444695_item	3502415	et	3	main
kus	doc_534729444695_item	3502418	et	3	main
võõrustajad	doc_534729444695_item	3502420	et	4	main
peter	doc_534729444695_item	3502421	et	4	main
olin	doc_534729444695_item	3502427	et	3	main
ja	doc_534729444695_item	3502429	et	3	main
mul	doc_534729444695_item	3502438	et	3	main
kaunis	doc_534729444695_item	3502446	et	4	main
olen	doc_534729444695_item	3502449	et	3	main
asub	doc_534729444695_item	3502465	et	3	main
usa	doc_534729444695_item	3502466	et	4	main
ja	doc_534729444695_item	3502468	et	3	main
ja	doc_534729444695_item	3502470	et	3	main
seal	doc_534729444695_item	3502472	et	4	main
elavad	doc_534729444695_item	3502473	et	4	main
väsinud	doc_534729444691_item	3502183	et	4	main
me	doc_534729444691_item	3502184	et	4	main
läksime	doc_534729444691_item	3502185	et	3	main
magama	doc_534729444691_item	3502186	et	3	main
reede	doc_534729444691_item	3502080	et	4	main
pärast	doc_534729444691_item	3502088	et	4	main
üks	doc_534729444691_item	3502098	et	3	main
meeres	doc_534729444691_item	3502104	et	3	main
alati	doc_534729444691_item	3502106	et	4	main
keskpäeviti	doc_534729444691_item	3502108	et	4	main
päike	doc_534729444691_item	3502109	et	3	main
kui	doc_534729444691_item	3502110	et	3	main
kõike	doc_534729444691_item	3502116	et	4	main
punane	doc_534729444691_item	3502119	et	4	main
jäätise	doc_534729444691_item	3502135	et	3	main
ja	doc_534729444691_item	3502136	et	3	main
siis	doc_534729444691_item	3502137	et	3	main
me	doc_534729444691_item	3502138	et	4	main
asetasime	doc_534729444691_item	3502139	et	3	main
ranna	doc_534729444691_item	3502140	et	3	main
ja	doc_534729444691_item	3502141	et	3	main
ajasime	doc_534729444691_item	3502142	et	3	main
magasime	doc_534729444691_item	3502144	et	3	main
ja	doc_534729444691_item	3502145	et	3	main
tegime	doc_534729444691_item	3502146	et	3	main
foto	doc_534729444691_item	3502147	et	4	main
juttu	doc_534729444691_item	3502143	et	4	main
me	doc_534729444691_item	3502148	et	4	main
sõitsime	doc_534729444691_item	3502149	et	3	main
tagasi	doc_534729444691_item	3502150	et	3	main
bussiga	doc_534729444691_item	3502151	et	3	main
õhtul	doc_534729444691_item	3502152	et	3	main
me	doc_534729444691_item	3502153	et	4	main
olime	doc_534729444691_item	3502154	et	3	main
kutsuma	doc_534729444691_item	3502155	et	3	main
röstpidu	doc_534729444691_item	3502156	et	4	main
grillfest	doc_534729444691_item	3502157	et	4	main
pärast	doc_534729444691_item	3502158	et	4	main
söök	doc_534729444691_item	3502159	et	3	main
me	doc_534729444691_item	3502160	et	4	main
mängisime	doc_534729444691_item	3502161	et	3	main
ruckby	doc_534729444691_item	3502162	et	4	main
ja	doc_534729444691_item	3502167	et	3	main
meil	doc_534729444691_item	3502168	et	4	main
kaks	doc_534729444691_item	3502174	et	3	main
kahjuks	doc_534729444691_item	3502179	et	4	main
minu	doc_534729444691_item	3502180	et	3	main
grupp	doc_534729444691_item	3502181	et	3	main
kaotas	doc_534729444691_item	3502182	et	3	main
täna	doc_534729444692_item	3502192	et	4	main
vaatasime	doc_534729444692_item	3502194	et	3	main
me	doc_534729444692_item	3502197	et	4	main
šoppisime	doc_534729444692_item	3502198	et	2	main
oli	doc_534729444692_item	3502206	et	3	main
väga	doc_534729444692_item	3502207	et	3	main
ilus	doc_534729444692_item	3502208	et	4	main
me	doc_534729444692_item	3502242	et	4	main
otsime	doc_534729444692_item	3502248	et	4	main
192006	doc_534729444694_item	3502282	et	2	main
vara	doc_534729444694_item	3502287	et	4	main
seal	doc_534729444694_item	3502305	et	4	main
me	doc_534729444694_item	3502314	et	4	main
lendasime	doc_534729444694_item	3502315	et	3	main
siit	doc_534729444694_item	3502316	et	3	main
ainult	doc_534729444694_item	3502335	et	4	main
mont	doc_534729444694_item	3502354	et	4	main
royalil	doc_534729444694_item	3502355	et	4	main
ja	doc_534729444694_item	3502356	et	3	main
otsisime	doc_534729444694_item	3502357	et	3	main
aega	doc_534729444695_item	3502399	et	4	main
kell	doc_534729444695_item	3502403	et	3	main
võtsin	doc_534729444695_item	3502407	et	3	main
bussijaamasse	doc_534729444695_item	3502414	et	3	main
magogis	doc_534729444695_item	3502428	et	4	main
head	doc_534729444695_item	3502436	et	4	main
väga	doc_534729444695_item	3502445	et	3	main
ma	doc_534729444695_item	3502448	et	3	main
kävin	doc_534729444695_item	3502455	et	4	main
koolisse	doc_534729444695_item	3502456	et	4	main
lennoxvillesse	doc_534729444695_item	3502457	et	4	main
see	doc_534729444695_item	3502458	et	3	main
kaugel	doc_534729444695_item	3502463	et	4	main
piiril	doc_534729444695_item	3502467	et	3	main
moss	doc_534729444695_item	3502469	et	2	main
väga	doc_534729444695_item	3502478	et	3	main
ja	doc_534729444695_item	3502480	et	3	main
692006	doc_534729444699_item	3502490	et	2	main
kurb	doc_534729444699_item	3502495	et	3	main
läksin	doc_534729444699_item	3502498	et	3	main
montrealis	doc_534729444699_item	3502511	et	4	main
ma	doc_534729444699_item	3502512	et	3	main
kohtusin	doc_534729444699_item	3502513	et	4	main
on	doc_534729444699_item	3502539	et	4	main
kallis	doc_534729444699_item	3502541	et	4	main
hotell	doc_534729444699_item	3502542	et	3	main
ja	doc_534729444699_item	3502544	et	3	main
restoranidega	doc_534729444699_item	3502545	et	3	main
kesklinna	doc_534729444699_item	3502552	et	4	main
me	doc_534729444692_item	3502257	et	4	main
keetsime	doc_534729444692_item	3502258	et	3	main
kartulid	doc_534729444692_item	3502259	et	3	main
ja	doc_534729444692_item	3502260	et	3	main
oa	doc_534729444692_item	3502261	et	3	main
ja	doc_534729444692_item	3502262	et	3	main
praadisime	doc_534729444692_item	3502263	et	3	main
viineri	doc_534729444692_item	3502264	et	3	main
kell	doc_534729444692_item	3502265	et	3	main
üheksa	doc_534729444692_item	3502266	et	4	main
me	doc_534729444692_item	3502267	et	4	main
sõime	doc_534729444692_item	3502268	et	4	main
õhtust	doc_534729444692_item	3502269	et	4	main
mmh	doc_534729444692_item	3502270	et	4	main
söök	doc_534729444692_item	3502271	et	3	main
oli	doc_534729444692_item	3502272	et	3	main
maitsev	doc_534729444692_item	3502273	et	4	main
söök	doc_534729444692_item	3502275	et	3	main
pärast	doc_534729444692_item	3502274	et	4	main
me	doc_534729444692_item	3502276	et	4	main
planeerisime	doc_534729444692_item	3502277	et	3	main
järgmine	doc_534729444692_item	3502278	et	3	main
päev	doc_534729444692_item	3502279	et	3	main
laupäev	doc_534729444692_item	3502189	et	3	main
me	doc_534729444692_item	3502193	et	4	main
kesklinna	doc_534729444692_item	3502195	et	4	main
lancesteril	doc_534729444692_item	3502196	et	4	main
siis	doc_534729444692_item	3502201	et	3	main
kovhikusse	doc_534729444692_item	3502204	et	4	main
kovhik	doc_534729444692_item	3502205	et	4	main
ja	doc_534729444692_item	3502213	et	3	main
pehme	doc_534729444692_item	3502214	et	4	main
diivanil	doc_534729444692_item	3502215	et	3	main
me	doc_534729444692_item	3502216	et	4	main
katsusime	doc_534729444692_item	3502217	et	3	main
meile	doc_534729444692_item	3502218	et	4	main
kui	doc_534729444692_item	3502219	et	3	main
me	doc_534729444692_item	3502220	et	4	main
istume	doc_534729444692_item	3502221	et	3	main
elutubas	doc_534729444692_item	3502222	et	4	main
seal	doc_534729444692_item	3502223	et	4	main
veetsime	doc_534729444692_item	3502225	et	3	main
me	doc_534729444692_item	3502224	et	4	main
võib-olla	doc_534729444692_item	3502226	et	3	main
kaks	doc_534729444692_item	3502227	et	3	main
tunni	doc_534729444692_item	3502228	et	3	main
me	doc_534729444692_item	3502229	et	4	main
jõime	doc_534729444692_item	3502230	et	3	main
teed	doc_534729444692_item	3502231	et	4	main
ja	doc_534729444692_item	3502232	et	3	main
sõime	doc_534729444692_item	3502233	et	4	main
maitsev	doc_534729444692_item	3502234	et	4	main
koogi	doc_534729444692_item	3502235	et	4	main
ja	doc_534729444692_item	3502236	et	3	main
tegime	doc_534729444692_item	3502237	et	3	main
naljakas	doc_534729444692_item	3502238	et	4	main
foto	doc_534729444692_item	3502239	et	4	main
ja	doc_534729444692_item	3502240	et	3	main
siis	doc_534729444692_item	3502241	et	3	main
jalutasime	doc_534729444692_item	3502243	et	3	main
läbi	doc_534729444692_item	3502244	et	4	main
vorstid	doc_534729444694_item	3502375	et	3	main
kell	doc_534729444694_item	3502376	et	3	main
kaheksa	doc_534729444694_item	3502377	et	4	main
õhtul	doc_534729444694_item	3502378	et	3	main
me	doc_534729444694_item	3502379	et	4	main
heitsime	doc_534729444694_item	3502380	et	3	main
magama	doc_534729444694_item	3502381	et	3	main
ma	doc_534729444694_item	3502284	et	3	main
mind	doc_534729444694_item	3502304	et	4	main
pariisi	doc_534729444694_item	3502312	et	4	main
lennujaamasse	doc_534729444694_item	3502313	et	3	main
kanadasse	doc_534729444694_item	3502318	et	4	main
turismisibaas	doc_534729444694_item	3502321	et	4	main
saapusime	doc_534729444694_item	3502340	et	4	main
pilvitu	doc_534729444694_item	3502346	et	4	main
supermarketi	doc_534729444694_item	3502358	et	4	main
aga	doc_534729444694_item	3502359	et	3	main
seal	doc_534729444694_item	3502363	et	4	main
oli	doc_534729444694_item	3502364	et	3	main
ainult	doc_534729444694_item	3502365	et	4	main
väike	doc_534729444694_item	3502366	et	4	main
pood	doc_534729444694_item	3502367	et	4	main
ja	doc_534729444694_item	3502368	et	3	main
sealt	doc_534729444694_item	3502369	et	4	main
me	doc_534729444694_item	3502370	et	4	main
ostasime	doc_534729444694_item	3502371	et	4	main
leiba	doc_534729444694_item	3502372	et	4	main
ja	doc_534729444694_item	3502373	et	3	main
kaks	doc_534729444694_item	3502374	et	3	main
mul	doc_534729444695_item	3502397	et	3	main
ja	doc_534729444695_item	3502400	et	3	main
kuni	doc_534729444695_item	3502402	et	3	main
sõin	doc_534729444695_item	3502410	et	3	main
läksin	doc_534729444695_item	3502413	et	3	main
sõitsin	doc_534729444695_item	3502416	et	3	main
ootasi	doc_534729444695_item	3502424	et	4	main
mind	doc_534729444695_item	3502425	et	4	main
väikes	doc_534729444695_item	3502431	et	4	main
linnas	doc_534729444695_item	3502432	et	4	main
stansteadis	doc_534729444695_item	3502433	et	4	main
ma	doc_534729444695_item	3502434	et	3	main
mäletasin	doc_534729444695_item	3502435	et	3	main
on	doc_534729444695_item	3502442	et	4	main
suur	doc_534729444695_item	3502443	et	3	main
ja	doc_534729444695_item	3502444	et	3	main
maa	doc_534729444695_item	3502447	et	4	main
elanud	doc_534729444695_item	3502450	et	4	main
stansteadis	doc_534729444695_item	3502451	et	4	main
stansteadist	doc_534729444695_item	3502462	et	4	main
on	doc_534729444695_item	3502477	et	4	main
nende	doc_534729444695_item	3502481	et	4	main
mathilda	doc_534729444694_item	3502326	et	2	main
kell	doc_534729444694_item	3502336	et	3	main
me	doc_534729444694_item	3502339	et	4	main
me	doc_534729444694_item	3502352	et	4	main
ei	doc_534729444694_item	3502361	et	4	main
päevik	doc_534729444695_item	3502383	et	3	main
292006	doc_534729444695_item	3502384	et	2	main
täna	doc_534729444695_item	3502385	et	4	main
hommikul	doc_534729444695_item	3502386	et	3	main
mare	doc_534729444695_item	3502387	et	4	main
ärkasi	doc_534729444695_item	3502388	et	4	main
kell	doc_534729444695_item	3502389	et	3	main
kuus	doc_534729444695_item	3502390	et	4	main
sest	doc_534729444695_item	3502391	et	4	main
ta	doc_534729444695_item	3502392	et	4	main
sõitsi	doc_534729444695_item	3502393	et	4	main
north	doc_534729444695_item	3502394	et	4	main
bayle	doc_534729444695_item	3502395	et	4	main
aga	doc_534729444695_item	3502396	et	3	main
ma	doc_534729444695_item	3502406	et	3	main
dušši	doc_534729444695_item	3502408	et	2	main
minu	doc_534729444695_item	3502419	et	3	main
kui	doc_534729444695_item	3502426	et	3	main
seejäral	doc_534729444695_item	3502430	et	4	main
aega	doc_534729444695_item	3502437	et	4	main
oli	doc_534729444695_item	3502439	et	3	main
pool	doc_534729444695_item	3502452	et	4	main
on	doc_534729444695_item	3502459	et	4	main
50	doc_534729444695_item	3502460	et	2	main
maja	doc_534729444695_item	3502482	et	4	main
päevik	doc_534729444699_item	3502489	et	3	main
marega	doc_534729444699_item	3502503	et	2	main
hommikusöögi	doc_534729444699_item	3502504	et	3	main
sõidsin	doc_534729444699_item	3502508	et	4	main
bussiga	doc_534729444699_item	3502509	et	3	main
ära	doc_534729444699_item	3502510	et	4	main
linna	doc_534729444699_item	3502548	et	4	main
olime	doc_534729444699_item	3502555	et	3	main
sest	doc_534729444699_item	3502558	et	4	main
me	doc_534729444699_item	3502559	et	4	main
ärkasime	doc_534729444699_item	3502560	et	3	main
ma	doc_534729444699_item	3502564	et	3	main
ainult	doc_534729444699_item	3502565	et	4	main
uue	doc_534729444699_item	3502567	et	3	main
our	doc_534729444699_item	3502568	et	4	main
küsimusele	doc_284706151131_item	3503284	et	4	main
päevavalgust	doc_284706151131_item	3503289	et	4	main
on	doc_284706151131_item	3503291	et	4	main
kõige	doc_284706151131_item	3503292	et	4	main
laed	doc_284706151131_item	3503301	et	4	main
valgustust	doc_284706151131_item	3503304	et	4	main
valgustus	doc_284706151131_item	3503314	et	4	main
kus	doc_284706151131_item	3503323	et	3	main
viibida	doc_284706151131_item	3503325	et	3	main
on	doc_284706151131_item	3503335	et	4	main
valgust	doc_284706151131_item	3503350	et	4	main
2	doc_284706151131_item	3503351	et	2	main
töötajatele	doc_284706151131_item	3503383	et	4	main
töötavatele	doc_284706151131_item	3503394	et	4	main
inimestele	doc_284706151131_item	3503395	et	3	main
kaasaegset	doc_284706151131_item	3503396	et	3	main
kujundust	doc_284706151131_item	3503408	et	4	main
128	doc_284706151131_item	3503413	et	2	main
koosneva	doc_284706151131_item	3503416	et	4	main
lihtsaid	doc_284706151131_item	3503429	et	3	main
väikes	doc_534729444695_item	3502474	et	4	main
majas	doc_534729444695_item	3502475	et	3	main
nad	doc_534729444695_item	3502476	et	3	main
on	doc_534729444695_item	3502483	et	4	main
kui	doc_534729444695_item	3502484	et	3	main
minu	doc_534729444695_item	3502485	et	3	main
teine	doc_534729444695_item	3502486	et	3	main
kodu	doc_534729444695_item	3502487	et	4	main
olin	doc_534729444699_item	3502492	et	3	main
sest	doc_534729444699_item	3502496	et	4	main
stansteadist	doc_534729444699_item	3502499	et	4	main
montrealisse	doc_534729444699_item	3502500	et	4	main
ma	doc_534729444699_item	3502501	et	3	main
poedega	doc_534729444699_item	3502543	et	4	main
me	doc_534729444699_item	3502546	et	4	main
jalutasime	doc_534729444699_item	3502547	et	3	main
me	doc_534729444699_item	3502553	et	4	main
mõlemad	doc_534729444699_item	3502554	et	3	main
väsinud	doc_534729444699_item	3502557	et	4	main
hommikul	doc_534729444699_item	3502563	et	3	main
peace	doc_534729444699_item	3502570	et	4	main
cd-plaati	doc_534729444699_item	3502571	et	4	main
ja	doc_534729444699_item	3502572	et	3	main
midagi	doc_534729444699_item	3502573	et	4	main
söömise	doc_534729444699_item	3502574	et	4	main
seejäral	doc_534729444699_item	3502575	et	4	main
me	doc_534729444699_item	3502576	et	4	main
läksime	doc_534729444699_item	3502577	et	3	main
magama	doc_534729444699_item	3502578	et	3	main
noorte	doc_534729444699_item	3502579	et	3	main
turismisbaasisse	doc_534729444699_item	3502580	et	4	main
see	doc_534729444699_item	3502581	et	3	main
oli	doc_534729444699_item	3502582	et	3	main
ainult	doc_534729444699_item	3502583	et	4	main
meie	doc_534729444699_item	3502584	et	4	main
reisi	doc_534729444699_item	3502585	et	4	main
algus	doc_534729444699_item	3502586	et	4	main
olin	doc_534729444699_item	3502587	et	3	main
tõnuga	doc_534729444699_item	3502588	et	4	main
kanadas	doc_534729444699_item	3502589	et	4	main
pool	doc_534729444699_item	3502590	et	4	main
neljaks	doc_534729444699_item	3502591	et	4	main
nädalaks	doc_534729444699_item	3502592	et	3	main
täna	doc_534729444699_item	3502491	et	4	main
rohkem	doc_534729444699_item	3502494	et	4	main
ma	doc_534729444699_item	3502497	et	3	main
restoranis	doc_534729444699_item	3502505	et	3	main
siis	doc_534729444699_item	3502507	et	3	main
bussijaamas	doc_534729444699_item	3502515	et	3	main
ja	doc_534729444699_item	3502516	et	3	main
me	doc_534729444699_item	3502517	et	4	main
sõitsime	doc_534729444699_item	3502518	et	3	main
quebec	doc_534729444699_item	3502519	et	4	main
citysse	doc_534729444699_item	3502520	et	4	main
seal	doc_534729444699_item	3502521	et	4	main
on	doc_534729444699_item	3502522	et	4	main
nii	doc_534729444699_item	3502523	et	3	main
ilus	doc_534729444699_item	3502524	et	4	main
quebec	doc_534729444699_item	3502525	et	4	main
city	doc_534729444699_item	3502526	et	4	main
on	doc_534729444699_item	3502527	et	4	main
kui	doc_534729444699_item	3502528	et	3	main
vabaõhkumuuseum	doc_534729444699_item	3502529	et	3	main
palju	doc_534729444699_item	3502530	et	4	main
vanad	doc_534729444699_item	3502531	et	3	main
majad	doc_534729444699_item	3502532	et	3	main
ja	doc_534729444699_item	3502533	et	3	main
kõike	doc_534729444699_item	3502534	et	4	main
üle	doc_534729444699_item	3502535	et	3	main
château	doc_534729444699_item	3502536	et	4	main
see	doc_534729444699_item	3502538	et	3	main
tänapäeval	doc_534729444699_item	3502540	et	3	main
läbi	doc_534729444699_item	3502549	et	4	main
eriti	doc_534729444699_item	3502550	et	3	main
vana	doc_534729444699_item	3502551	et	4	main
vara	doc_534729444699_item	3502561	et	4	main
võimalikult	doc_284706151131_item	3503286	et	4	main
päevavalgus	doc_284706151131_item	3503290	et	4	main
ja	doc_284706151131_item	3503294	et	3	main
valgusallikas	doc_284706151131_item	3503296	et	4	main
heledates	doc_284706151131_item	3503297	et	3	main
värvitoonides	doc_284706151131_item	3503298	et	3	main
valge	doc_284706151131_item	3503309	et	4	main
värv	doc_284706151131_item	3503310	et	3	main
kuni	doc_284706151131_item	3503311	et	3	main
90	doc_284706151131_item	3503312	et	2	main
kõikides	doc_284706151131_item	3503321	et	4	main
inimesed	doc_284706151131_item	3503326	et	3	main
suuri	doc_284706151131_item	3503329	et	3	main
töökoha	doc_284706151131_item	3503332	et	4	main
valgustamisel	doc_284706151131_item	3503333	et	4	main
kohtvalgustid	doc_284706151131_item	3503334	et	3	main
ümber	doc_284706151131_item	3503342	et	3	main
kasutada	doc_284706151131_item	3503387	et	3	main
sobivaid	doc_284706151131_item	3503388	et	4	main
prille	doc_284706151131_item	3503389	et	3	main
vajalik	doc_284706151131_item	3503390	et	3	main
on	doc_284706151131_item	3503391	et	4	main
korraldada	doc_284706151131_item	3503392	et	3	main
selleks	doc_284706151131_item	3503401	et	4	main
et	doc_284706151131_item	3503402	et	3	main
nad	doc_284706151131_item	3503403	et	3	main
ergonoomilised	doc_284706151131_item	3503410	et	4	main
väljaande	doc_284706151131_item	3503417	et	4	main
eesmärgiks	doc_284706151131_item	3503418	et	3	main
ohutuse	doc_284706151131_item	3503422	et	4	main
odavaid	doc_284706151131_item	3503432	et	3	main
soovitatakse	doc_284706151131_item	3503469	et	3	main
toone	doc_284706151131_item	3503476	et	3	main
te	doc_284706151131_item	3503516	et	4	main
ei	doc_284706151131_item	3503535	et	4	main
rohkem	doc_284706151131_item	3503287	et	4	main
parem	doc_284706151131_item	3503293	et	4	main
odavam	doc_284706151131_item	3503295	et	4	main
seinad	doc_284706151131_item	3503299	et	3	main
ja	doc_284706151131_item	3503300	et	3	main
ruumi	doc_284706151131_item	3503303	et	4	main
ulatuses	doc_284706151131_item	3503313	et	4	main
kohtades	doc_284706151131_item	3503322	et	3	main
võivad	doc_284706151131_item	3503324	et	4	main
vältida	doc_284706151131_item	3503327	et	3	main
heleduste	doc_284706151131_item	3503330	et	4	main
nõudvaks	doc_284706151131_item	3503338	et	4	main
tööks	doc_284706151131_item	3503339	et	3	main
paigutada	doc_284706151131_item	3503340	et	3	main
valgusallikad	doc_284706151131_item	3503341	et	3	main
panna	doc_284706151131_item	3503344	et	4	main
on	doc_284706151131_item	3503353	et	4	main
on	doc_284706151131_item	3503379	et	4	main
arvutiga	doc_284706151131_item	3503393	et	4	main
ise	doc_284706151131_item	3503404	et	4	main
oma	doc_284706151131_item	3503406	et	4	main
vastus	doc_284706151131_item	3503283	et	3	main
valgust	doc_284706151131_item	3503308	et	4	main
koridorides	doc_284706151131_item	3503317	et	3	main
treppidel	doc_284706151131_item	3503318	et	3	main
kaldteedel	doc_284706151131_item	3503319	et	3	main
ja	doc_284706151131_item	3503320	et	3	main
erinevusi	doc_284706151131_item	3503331	et	4	main
või	doc_284706151131_item	3503343	et	4	main
nendele	doc_284706151131_item	3503345	et	4	main
katted	doc_284706151131_item	3503346	et	3	main
et	doc_284706151131_item	3503347	et	3	main
eemaldada	doc_284706151131_item	3503348	et	3	main
pimestavat	doc_284706151131_item	3503349	et	4	main
eestikeelset	doc_284706151131_item	3503537	et	3	main
arvutiajakirja	doc_284706151131_item	3503538	et	4	main
1	doc_284706151131_item	3503285	et	2	main
kasutada	doc_284706151131_item	3503288	et	3	main
parandavad	doc_284706151131_item	3503302	et	4	main
kõige	doc_284706151131_item	3503305	et	4	main
paremini	doc_284706151131_item	3503306	et	4	main
peegeldab	doc_284706151131_item	3503307	et	3	main
on	doc_284706151131_item	3503315	et	4	main
vajalik	doc_284706151131_item	3503316	et	3	main
nägemisväljas	doc_284706151131_item	3503328	et	3	main
sobivad	doc_284706151131_item	3503336	et	4	main
täpsust	doc_284706151131_item	3503337	et	4	main
soovitav	doc_284706151131_item	3503352	et	4	main
kasutada	doc_284706151131_item	3503354	et	3	main
sobiva	doc_284706151131_item	3503355	et	4	main
seljatoega	doc_284706151131_item	3503356	et	3	main
ergonoomilisi	doc_284706151131_item	3503357	et	4	main
toole	doc_284706151131_item	3503358	et	3	main
mille	doc_284706151131_item	3503359	et	3	main
istme	doc_284706151131_item	3503360	et	3	main
kõrgust	doc_284706151131_item	3503361	et	4	main
saab	doc_284706151131_item	3503362	et	3	main
iga	doc_284706151131_item	3503363	et	4	main
töötaja	doc_284706151131_item	3503364	et	4	main
endale	doc_284706151131_item	3503365	et	4	main
kohandada	doc_284706151131_item	3503366	et	3	main
soovitav	doc_284706151131_item	3503367	et	4	main
on	doc_284706151131_item	3503368	et	4	main
kasutada	doc_284706151131_item	3503369	et	3	main
sellist	doc_284706151131_item	3503370	et	4	main
arvutikohta	doc_284706151131_item	3503371	et	4	main
mid	doc_284706151131_item	3503372	et	4	main
töötajad	doc_284706151131_item	3503373	et	4	main
saavad	doc_284706151131_item	3503374	et	4	main
enda	doc_284706151131_item	3503375	et	4	main
järgi	doc_284706151131_item	3503376	et	4	main
kohandada	doc_284706151131_item	3503377	et	3	main
soovitav	doc_284706151131_item	3503378	et	4	main
regulaarselt	doc_284706151131_item	3503380	et	4	main
korraldada	doc_284706151131_item	3503381	et	3	main
arvutiga	doc_284706151131_item	3503382	et	4	main
ning	doc_284706151131_item	3503386	et	3	main
soovitused	doc_284706151131_item	3503411	et	4	main
ergonoomilisest	doc_284706151131_item	3503414	et	4	main
soovitusest	doc_284706151131_item	3503415	et	4	main
anda	doc_284706151131_item	3503420	et	3	main
tervise	doc_284706151131_item	3503423	et	3	main
töötingimuste	doc_284706151131_item	3503425	et	3	main
siin	doc_284706151131_item	3503427	et	4	main
on	doc_284706151131_item	3503428	et	4	main
selja	doc_284706151131_item	3503464	et	3	main
käte	doc_284706151131_item	3503465	et	3	main
kasutada	doc_284706151131_item	3503472	et	3	main
seinte	doc_284706151131_item	3503474	et	3	main
silmade	doc_284706151131_item	3503384	et	3	main
kontrolli	doc_284706151131_item	3503385	et	4	main
koolitust	doc_284706151131_item	3503397	et	4	main
tuleb	doc_284706151131_item	3503398	et	3	main
julgustada	doc_284706151131_item	3503399	et	3	main
töötajaid	doc_284706151131_item	3503400	et	4	main
parandaksid	doc_284706151131_item	3503405	et	4	main
3	doc_284706151131_item	3503409	et	2	main
selle	doc_284706151131_item	3503412	et	4	main
on	doc_284706151131_item	3503419	et	4	main
ja	doc_284706151131_item	3503424	et	3	main
parandamiseks	doc_284706151131_item	3503426	et	4	main
praktilisi	doc_284706151131_item	3503430	et	3	main
mida	doc_284706151131_item	3503434	et	4	main
saab	doc_284706151131_item	3503435	et	3	main
rakendada	doc_284706151131_item	3503436	et	3	main
mitmesugustes	doc_284706151131_item	3503437	et	3	main
valdkondades	doc_284706151131_item	3503438	et	3	main
abiks	doc_284706151131_item	3503439	et	3	main
on	doc_284706151131_item	3503440	et	4	main
pildid	doc_284706151131_item	3503441	et	3	main
4	doc_284706151131_item	3503442	et	2	main
ma	doc_284706151131_item	3503443	et	3	main
leidsin	doc_284706151131_item	3503444	et	3	main
internetis	doc_284706151131_item	3503445	et	4	main
veel	doc_284706151131_item	3503446	et	4	main
üks	doc_284706151131_item	3503447	et	3	main
raamatu	doc_284706151131_item	3503448	et	4	main
töökoha	doc_284706151131_item	3503449	et	4	main
ergonoomika	doc_284706151131_item	3503450	et	4	main
sari	doc_284706151131_item	3503451	et	4	main
sekretäri	doc_284706151131_item	3503452	et	4	main
käsiraamat	doc_284706151131_item	3503453	et	3	main
5	doc_284706151131_item	3503455	et	2	main
töötamiskoha	doc_284706151131_item	3503407	et	4	main
abi	doc_284706151131_item	3503421	et	4	main
ja	doc_284706151131_item	3503431	et	3	main
lahendusi	doc_284706151131_item	3503433	et	4	main
katrin	doc_284706151131_item	3503456	et	4	main
martinsoni	doc_284706151131_item	3503457	et	4	main
sõnul	doc_284706151131_item	3503458	et	3	main
ülekoormus	doc_284706151131_item	3503468	et	3	main
kontoris	doc_284706151131_item	3503470	et	3	main
soojad	doc_284706151131_item	3503475	et	3	main
tegemisel	doc_284706151131_item	3503504	et	4	main
kui	doc_284706151131_item	3503510	et	3	main
30	doc_284706151131_item	3503513	et	2	main
punkti	doc_284706151131_item	3503514	et	4	main
pole	doc_284706151131_item	3503515	et	3	main
kaitstud	doc_284706151131_item	3503520	et	4	main
korrigeerige	doc_284706151131_item	3503521	et	3	main
telli	doc_284706151131_item	3503536	et	4	main
httpwwwrahvaraamatee	doc_284706151131_item	3503454	et	4	main
silmade	doc_284706151131_item	3503467	et	3	main
kindlasti	doc_284706151131_item	3503471	et	3	main
6	doc_284706151131_item	3503477	et	2	main
on	doc_284706151131_item	3503479	et	4	main
ametnik	doc_284706151131_item	3503481	et	3	main
teostab	doc_284706151131_item	3503483	et	3	main
riklikku	doc_284706151131_item	3503484	et	4	main
töötervishoidu	doc_284706151131_item	3503486	et	4	main
järelevalvet	doc_284706151131_item	3503485	et	3	main
ja	doc_284706151131_item	3503487	et	3	main
tööohutust	doc_284706151131_item	3503488	et	4	main
ning	doc_284706151131_item	3503489	et	3	main
töösuhted	doc_284706151131_item	3503490	et	4	main
reguleerivate	doc_284706151131_item	3503491	et	4	main
õigusaktide	doc_284706151131_item	3503492	et	3	main
nõuete	doc_284706151131_item	3503493	et	4	main
täitmise	doc_284706151131_item	3503494	et	4	main
üle	doc_284706151131_item	3503495	et	3	main
tööinspektor	doc_284706151131_item	3503496	et	3	main
on	doc_284706151131_item	3503497	et	4	main
oma	doc_284706151131_item	3503498	et	4	main
ülesannete	doc_284706151131_item	3503499	et	3	main
täitmisel	doc_284706151131_item	3503500	et	4	main
sõltumatu	doc_284706151131_item	3503501	et	4	main
ja	doc_284706151131_item	3503502	et	3	main
otsuste	doc_284706151131_item	3503503	et	4	main
on	doc_284706151131_item	3503459	et	4	main
kontoritöös	doc_284706151131_item	3503460	et	3	main
peamine	doc_284706151131_item	3503461	et	3	main
probleem	doc_284706151131_item	3503462	et	3	main
sundasend	doc_284706151131_item	3503463	et	3	main
ja	doc_284706151131_item	3503466	et	3	main
heledad	doc_284706151131_item	3503473	et	3	main
tööinspektsiooni	doc_284706151131_item	3503480	et	4	main
erapooletu	doc_284706151131_item	3503505	et	4	main
tööinspektor	doc_284706151131_item	3503506	et	3	main
on	doc_284706151131_item	3503507	et	4	main
stressi	doc_284706151131_item	3503517	et	4	main
oma	doc_284706151131_item	3503522	et	4	main
ning	doc_284706151131_item	3503524	et	3	main
stressivastaseid	doc_284706151131_item	3503526	et	3	main
tööinspektor	doc_284706151131_item	3503478	et	3	main
kes	doc_284706151131_item	3503482	et	4	main
kohustatud	doc_284706151131_item	3503508	et	4	main
saite	doc_284706151131_item	3503511	et	4	main
üle	doc_284706151131_item	3503512	et	3	main
päris	doc_284706151131_item	3503519	et	4	main
kasutage	doc_284706151131_item	3503525	et	3	main
võtteid	doc_284706151131_item	3503527	et	3	main
oma	doc_284706151131_item	3503529	et	4	main
7	doc_284706151131_item	3503509	et	2	main
eest	doc_284706151131_item	3503518	et	4	main
eluhoiakut	doc_284706151131_item	3503523	et	3	main
tugevdage	doc_284706151131_item	3503528	et	3	main
keha	doc_284706151131_item	3503530	et	4	main
ja	doc_284706151131_item	3503531	et	3	main
vaimu	doc_284706151131_item	3503532	et	4	main
8	doc_284706151131_item	3503533	et	2	main
ma	doc_284706151131_item	3503534	et	3	main
seotud	doc_284706151133_item	3505040	et	4	main
rohkem	doc_284706151133_item	3505043	et	4	main
kasutada	doc_284706151133_item	3505044	et	3	main
päevavalgust	doc_284706151133_item	3505045	et	4	main
vähendab	doc_284706151133_item	3505046	et	3	main
valgustust	doc_284706151133_item	3505056	et	4	main
kus	doc_284706151133_item	3505066	et	3	main
valgustamisel	doc_284706151133_item	3505078	et	4	main
kohtvalgustid	doc_284706151133_item	3505085	et	3	main
valgust	doc_284706151133_item	3505125	et	4	main
2	doc_284706151133_item	3505126	et	2	main
kellel	doc_284706151133_item	3505134	et	4	main
2	doc_284706151133_item	3505143	et	2	main
kui	doc_284706151133_item	3505144	et	3	main
pole	doc_284706151133_item	3505145	et	3	main
kasutada	doc_284706151133_item	3505163	et	3	main
või	doc_284706151133_item	3505165	et	4	main
et	doc_284706151133_item	3505167	et	3	main
15-20cm	doc_284706151133_item	3505186	et	4	main
tahapoole	doc_284706151133_item	3505198	et	3	main
seljatugi	doc_284706151133_item	3505199	et	4	main
peab	doc_284706151133_item	3505200	et	4	main
istmepinda	doc_284706151133_item	3505219	et	4	main
vahetada	doc_284706151133_item	3505224	et	3	main
tööülesannete	doc_284706151133_item	3505227	et	3	main
kus	doc_284706151133_item	3505229	et	3	main
liikuvus	doc_284706151133_item	3505241	et	4	main
palju	doc_284706151133_item	3505242	et	4	main
sobivad	doc_284706151133_item	3505250	et	4	main
ergonoomilisest	doc_284706151133_item	3505260	et	4	main
eesmärgiks	doc_284706151133_item	3505264	et	3	main
anda	doc_284706151133_item	3505266	et	3	main
ohutuse	doc_284706151133_item	3505268	et	4	main
tervise	doc_284706151133_item	3505269	et	3	main
töötingimuste	doc_284706151133_item	3505271	et	3	main
on	doc_284706151133_item	3505274	et	4	main
tool	doc_284706151133_item	3505310	et	3	main
peaksid	doc_284706151133_item	3505312	et	4	main
kasutama	doc_284706151133_item	3505313	et	3	main
keskkond	doc_284706151133_item	3505322	et	3	main
töötajal	doc_284706151133_item	3505326	et	4	main
nagu	doc_284706151133_item	3505329	et	3	main
vastus	doc_284706151133_item	3505036	et	3	main
laed	doc_284706151133_item	3505053	et	4	main
parandavad	doc_284706151133_item	3505054	et	4	main
vajalik	doc_284706151133_item	3505059	et	3	main
koridorides	doc_284706151133_item	3505060	et	3	main
treppidel	doc_284706151133_item	3505061	et	3	main
kaldteedel	doc_284706151133_item	3505062	et	3	main
soovitav	doc_284706151133_item	3505070	et	4	main
suuri	doc_284706151133_item	3505074	et	3	main
sobivad	doc_284706151133_item	3505087	et	4	main
nõuannet	doc_284706151133_item	3505127	et	4	main
töökoha	doc_284706151133_item	3505129	et	4	main
nõuannet	doc_284706151133_item	3505039	et	4	main
võimalikult	doc_284706151133_item	3505042	et	4	main
ruumi	doc_284706151133_item	3505055	et	4	main
kõikides	doc_284706151133_item	3505064	et	4	main
võivad	doc_284706151133_item	3505067	et	4	main
on	doc_284706151133_item	3505071	et	4	main
nägemisväljas	doc_284706151133_item	3505073	et	3	main
kohtvalgustid	doc_284706151133_item	3505079	et	3	main
on	doc_284706151133_item	3505080	et	4	main
sobivad	doc_284706151133_item	3505081	et	4	main
täpsust	doc_284706151133_item	3505082	et	4	main
on	doc_284706151133_item	3505086	et	4	main
on	doc_284706151133_item	3505110	et	4	main
ümber	doc_284706151133_item	3505117	et	3	main
on	doc_284706151133_item	3505135	et	4	main
kasutada	doc_284706151133_item	3505147	et	3	main
peab	doc_284706151133_item	3505151	et	4	main
igale	doc_284706151133_item	3505153	et	3	main
võimaluse	doc_284706151133_item	3505155	et	3	main
sobiva	doc_284706151133_item	3505158	et	4	main
jalatugesid	doc_284706151133_item	3505164	et	3	main
istmepatju	doc_284706151133_item	3505166	et	3	main
kõrgemal	doc_284706151133_item	3505187	et	4	main
istudes	doc_284706151133_item	3505195	et	4	main
ettepoole	doc_284706151133_item	3505196	et	3	main
või	doc_284706151133_item	3505197	et	4	main
kaldumise	doc_284706151133_item	3505206	et	4	main
eest	doc_284706151133_item	3505207	et	4	main
taha	doc_284706151133_item	3505208	et	4	main
4	doc_284706151133_item	3505209	et	2	main
kasutada	doc_284706151133_item	3505210	et	3	main
mitte	doc_284706151133_item	3505211	et	3	main
väga	doc_284706151133_item	3505212	et	3	main
pehmet	doc_284706151133_item	3505213	et	3	main
ega	doc_284706151133_item	3505214	et	3	main
mitte	doc_284706151133_item	3505215	et	3	main
väga	doc_284706151133_item	3505216	et	3	main
kõva	doc_284706151133_item	3505217	et	4	main
5	doc_284706151133_item	3505226	et	2	main
keha	doc_284706151133_item	3505235	et	4	main
on	doc_284706151133_item	3505265	et	4	main
abi	doc_284706151133_item	3505267	et	4	main
ja	doc_284706151133_item	3505270	et	3	main
siin	doc_284706151133_item	3505273	et	4	main
lihtsaid	doc_284706151133_item	3505275	et	3	main
praktilisi	doc_284706151133_item	3505276	et	3	main
ja	doc_284706151133_item	3505277	et	3	main
odavaid	doc_284706151133_item	3505278	et	3	main
lahendusi	doc_284706151133_item	3505279	et	4	main
alaselga	doc_284706151133_item	3505308	et	4	main
steriilne	doc_284706151133_item	3505321	et	3	main
milles	doc_284706151133_item	3505334	et	3	main
valida	doc_284706151133_item	3505338	et	3	main
peab	doc_284706151133_item	3505345	et	4	main
on	doc_284706151133_item	3505351	et	4	main
insener	doc_284706151133_item	3505355	et	3	main
muu	doc_284706151133_item	3505357	et	4	main
7	doc_284706151133_item	3505371	et	2	main
kokku	doc_284706151133_item	3505374	et	3	main
ja	doc_284706151133_item	3505377	et	3	main
minu	doc_284706151133_item	3505381	et	3	main
üsna	doc_284706151133_item	3505383	et	3	main
soovitavad	doc_284706151133_item	3505385	et	4	main
võtted	doc_284706151133_item	3505391	et	3	main
autogeensest	doc_284706151133_item	3505393	et	4	main
moskva	doc_40918597561_item	3505416	et	4	main
3316838	doc_40918597561_item	3505425	et	2	main
vene	doc_40918597561_item	3505428	et	4	main
tallinnas	doc_40918597561_item	3505431	et	4	main
tallinn	doc_40918597561_item	3505435	et	4	main
tänav	doc_40918597561_item	3505437	et	4	main
ühest	doc_40918597561_item	3505445	et	4	main
poolest	doc_40918597561_item	3505446	et	4	main
ja	doc_40918597561_item	3505447	et	3	main
on	doc_40918597561_item	3505455	et	4	main
juriidiline	doc_40918597561_item	3505456	et	3	main
isik	doc_40918597561_item	3505457	et	3	main
asutav	doc_40918597561_item	3505458	et	4	main
ja	doc_40918597561_item	3505459	et	3	main
küsimusele	doc_284706151133_item	3505037	et	4	main
valgustusega	doc_284706151133_item	3505041	et	4	main
on	doc_284706151133_item	3505058	et	4	main
ja	doc_284706151133_item	3505063	et	3	main
kohtades	doc_284706151133_item	3505065	et	3	main
inimesed	doc_284706151133_item	3505069	et	3	main
erinevusi	doc_284706151133_item	3505076	et	4	main
töökoha	doc_284706151133_item	3505077	et	4	main
nõudvaks	doc_284706151133_item	3505083	et	4	main
tööks	doc_284706151133_item	3505084	et	3	main
panna	doc_284706151133_item	3505119	et	4	main
töötajatele	doc_284706151133_item	3505133	et	4	main
töö	doc_284706151133_item	3505137	et	4	main
kohandatavad	doc_284706151133_item	3505140	et	4	main
seljatoega	doc_284706151133_item	3505141	et	3	main
toolid	doc_284706151133_item	3505142	et	3	main
võimalust	doc_284706151133_item	3505146	et	3	main
toole	doc_284706151133_item	3505149	et	3	main
temale	doc_284706151133_item	3505157	et	3	main
pinnast	doc_284706151133_item	3505189	et	4	main
keha	doc_284706151133_item	3505192	et	4	main
kaldub	doc_284706151133_item	3505193	et	3	main
toolil	doc_284706151133_item	3505194	et	3	main
ühtlasi	doc_284706151133_item	3505201	et	4	main
kaitsma	doc_284706151133_item	3505202	et	3	main
selja	doc_284706151133_item	3505203	et	3	main
töötajal	doc_284706151133_item	3505222	et	4	main
puhul	doc_284706151133_item	3505228	et	4	main
tuleb	doc_284706151133_item	3505230	et	3	main
ajal	doc_284706151133_item	3505232	et	4	main
mõnikord	doc_284706151133_item	3505233	et	3	main
vahetada	doc_284706151133_item	3505234	et	3	main
oluline	doc_284706151133_item	3505238	et	4	main
istekoha	doc_284706151133_item	3505239	et	4	main
hea	doc_284706151133_item	3505240	et	4	main
on	doc_284706151133_item	3505248	et	4	main
eriti	doc_284706151133_item	3505249	et	3	main
soovitusest	doc_284706151133_item	3505261	et	4	main
mida	doc_284706151133_item	3505280	et	4	main
saab	doc_284706151133_item	3505281	et	3	main
rakendada	doc_284706151133_item	3505282	et	3	main
ja	doc_284706151133_item	3505325	et	3	main
ruumides	doc_284706151133_item	3505333	et	4	main
1	doc_284706151133_item	3505038	et	2	main
kulusid	doc_284706151133_item	3505047	et	4	main
energiale	doc_284706151133_item	3505048	et	3	main
heledates	doc_284706151133_item	3505049	et	3	main
värvitoonides	doc_284706151133_item	3505050	et	3	main
seinad	doc_284706151133_item	3505051	et	3	main
ja	doc_284706151133_item	3505052	et	3	main
valgustus	doc_284706151133_item	3505057	et	4	main
viibida	doc_284706151133_item	3505068	et	3	main
vältida	doc_284706151133_item	3505072	et	3	main
heleduste	doc_284706151133_item	3505075	et	4	main
paigutada	doc_284706151133_item	3505088	et	3	main
täpsust	doc_284706151133_item	3505089	et	4	main
nõudva	doc_284706151133_item	3505090	et	4	main
töö	doc_284706151133_item	3505091	et	4	main
lähedale	doc_284706151133_item	3505092	et	4	main
ja	doc_284706151133_item	3505093	et	3	main
sellekohale	doc_284706151133_item	3505094	et	4	main
võimalusel	doc_284706151133_item	3505095	et	3	main
kasutada	doc_284706151133_item	3505096	et	3	main
selliseid	doc_284706151133_item	3505097	et	4	main
kohtvalgusteid	doc_284706151133_item	3505098	et	4	main
mida	doc_284706151133_item	3505099	et	4	main
on	doc_284706151133_item	3505100	et	4	main
kerge	doc_284706151133_item	3505101	et	4	main
liigutada	doc_284706151133_item	3505102	et	3	main
vajalikku	doc_284706151133_item	3505103	et	4	main
asendisse	doc_284706151133_item	3505104	et	3	main
kasutada	doc_284706151133_item	3505105	et	3	main
tuleb	doc_284706151133_item	3505106	et	3	main
selliseid	doc_284706151133_item	3505107	et	4	main
kohtvalgusteid	doc_284706151133_item	3505108	et	4	main
mida	doc_284706151133_item	3505109	et	4	main
kerge	doc_284706151133_item	3505111	et	4	main
puhastada	doc_284706151133_item	3505112	et	3	main
ja	doc_284706151133_item	3505113	et	3	main
hooldada	doc_284706151133_item	3505114	et	3	main
paigutada	doc_284706151133_item	3505115	et	3	main
valgusallikad	doc_284706151133_item	3505116	et	3	main
või	doc_284706151133_item	3505118	et	4	main
nendele	doc_284706151133_item	3505120	et	4	main
katted	doc_284706151133_item	3505121	et	3	main
et	doc_284706151133_item	3505122	et	3	main
eemaldada	doc_284706151133_item	3505123	et	3	main
pimestavat	doc_284706151133_item	3505124	et	4	main
ergonoomilise	doc_284706151133_item	3505128	et	4	main
1	doc_284706151133_item	3505130	et	2	main
soovitav	doc_284706151133_item	3505131	et	4	main
on	doc_284706151133_item	3505132	et	4	main
istuv	doc_284706151133_item	3505136	et	4	main
anda	doc_284706151133_item	3505138	et	3	main
hästi	doc_284706151133_item	3505139	et	3	main
kohandatavaid	doc_284706151133_item	3505148	et	4	main
siis	doc_284706151133_item	3505150	et	3	main
või	doc_284706151133_item	3505161	et	4	main
alternatiivina	doc_284706151133_item	3505162	et	3	main
saada	doc_284706151133_item	3505168	et	4	main
sobiv	doc_284706151133_item	3505169	et	4	main
põrandapinna	doc_284706151133_item	3505170	et	3	main
ja	doc_284706151133_item	3505171	et	3	main
istekoha	doc_284706151133_item	3505172	et	4	main
istekoha	doc_284706151133_item	3505188	et	4	main
kuna	doc_284706151133_item	3505190	et	3	main
inimese	doc_284706151133_item	3505191	et	4	main
mis	doc_284706151133_item	3505220	et	4	main
võimaldab	doc_284706151133_item	3505221	et	3	main
istumisasendit	doc_284706151133_item	3505225	et	3	main
andma	doc_284706151133_item	3505152	et	3	main
töötajale	doc_284706151133_item	3505154	et	4	main
kasutada	doc_284706151133_item	3505156	et	3	main
kõrgusega	doc_284706151133_item	3505159	et	4	main
tooli	doc_284706151133_item	3505160	et	4	main
kõrguste	doc_284706151133_item	3505173	et	4	main
vahe	doc_284706151133_item	3505174	et	4	main
3	doc_284706151133_item	3505175	et	2	main
kasutada	doc_284706151133_item	3505176	et	3	main
polsterdatud	doc_284706151133_item	3505177	et	4	main
seljatugesid	doc_284706151133_item	3505178	et	3	main
mis	doc_284706151133_item	3505179	et	4	main
toetavad	doc_284706151133_item	3505180	et	4	main
selja	doc_284706151133_item	3505181	et	3	main
alumist	doc_284706151133_item	3505182	et	3	main
osa	doc_284706151133_item	3505183	et	4	main
vöö	doc_284706151133_item	3505184	et	4	main
kõrgusel	doc_284706151133_item	3505185	et	4	main
ülaosa	doc_284706151133_item	3505204	et	4	main
juhusliku	doc_284706151133_item	3505205	et	3	main
polsterdatud	doc_284706151133_item	3505218	et	4	main
kergelt	doc_284706151133_item	3505223	et	4	main
istumise	doc_284706151133_item	3505231	et	4	main
asendit	doc_284706151133_item	3505236	et	3	main
istuval	doc_284706151133_item	3505243	et	4	main
tööl	doc_284706151133_item	3505244	et	3	main
tehtavate	doc_284706151133_item	3505245	et	3	main
tööülesannete	doc_284706151133_item	3505246	et	3	main
viiejalgsed	doc_284706151133_item	3505251	et	3	main
toolid	doc_284706151133_item	3505253	et	3	main
ergonoomilised	doc_284706151133_item	3505256	et	4	main
soovitused	doc_284706151133_item	3505257	et	4	main
selle	doc_284706151133_item	3505258	et	4	main
128	doc_284706151133_item	3505259	et	2	main
väljaande	doc_284706151133_item	3505263	et	4	main
parandamiseks	doc_284706151133_item	3505272	et	4	main
pinges	doc_284706151133_item	3505305	et	4	main
ja	doc_284706151133_item	3505306	et	3	main
valusad	doc_284706151133_item	3505307	et	3	main
liiga	doc_284706151133_item	3505320	et	4	main
helehall	doc_284706151133_item	3505323	et	4	main
tekib	doc_284706151133_item	3505327	et	3	main
pimedates	doc_284706151133_item	3505332	et	3	main
värvilahendused	doc_284706151133_item	3505340	et	3	main
kui	doc_284706151133_item	3505341	et	3	main
veidi	doc_284706151133_item	3505342	et	3	main
pastelsemad	doc_284706151133_item	3505343	et	4	main
ka	doc_284706151133_item	3505344	et	3	main
alal	doc_284706151133_item	3505353	et	4	main
tööandja	doc_284706151133_item	3505363	et	4	main
ma	doc_284706151133_item	3505372	et	3	main
punkti	doc_284706151133_item	3505376	et	4	main
võtta	doc_284706151133_item	3505386	et	3	main
maksa	doc_284706151133_item	3505400	et	4	main
aktsiate	doc_40918597561_item	3505413	et	3	main
tatjana	doc_40918597561_item	3505418	et	4	main
antud	doc_40918597561_item	3505427	et	4	main
elukoht	doc_40918597561_item	3505432	et	3	main
realiseeruv	doc_40918597561_item	3505460	et	4	main
tatjana	doc_40918597567_item	3505587	et	4	main
edasi	doc_40918597567_item	3505589	et	3	main
sünd	doc_40918597567_item	3505591	et	3	main
elukoht	doc_40918597567_item	3505593	et	3	main
2-7	doc_40918597567_item	3505595	et	2	main
välja	doc_40918597567_item	3505602	et	4	main
antud	doc_40918597567_item	3505603	et	4	main
vene	doc_40918597567_item	3505604	et	4	main
rahvusvaheline	doc_40918597567_item	3505609	et	4	main
kommerts	doc_40918597567_item	3505610	et	3	main
kompanii	doc_40918597567_item	3505611	et	4	main
oma	doc_40918597567_item	3505623	et	4	main
1	doc_617668397759_item	3505998	et	2	main
kultuurpoliitilised	doc_617668397759_item	3506002	et	3	main
vabastamist	doc_617668397759_item	3506012	et	4	main
hariduselu	doc_617668397759_item	3506015	et	4	main
õpikud	doc_617668397759_item	3506016	et	3	main
liikumises	doc_617668397759_item	3506028	et	4	main
3	doc_617668397759_item	3506029	et	2	main
aastane	doc_617668397759_item	3506041	et	4	main
siis	doc_617668397759_item	3506042	et	3	main
oskas	doc_617668397759_item	3506043	et	3	main
vigadeta	doc_617668397759_item	3506044	et	3	main
perno	doc_617668397759_item	3506059	et	4	main
läks	doc_617668397759_item	3506062	et	3	main
tema	doc_617668397759_item	3506073	et	4	main
tantsu-	doc_617668397759_item	3506098	et	4	main
kuid	doc_617668397759_item	3506101	et	4	main
rahvuslus	doc_617668397759_item	3506109	et	4	main
ja	doc_617668397759_item	3506110	et	3	main
osa	doc_617668397759_item	3506118	et	4	main
meeskoorid	doc_617668397759_item	3506127	et	4	main
aitas	doc_617668397759_item	3506135	et	3	main
et	doc_617668397759_item	3506139	et	3	main
oli	doc_617668397759_item	3506141	et	3	main
on	doc_284706151133_item	3505237	et	4	main
täitmiseks	doc_284706151133_item	3505247	et	4	main
ratastega	doc_284706151133_item	3505252	et	3	main
3	doc_284706151133_item	3505254	et	2	main
raamatud	doc_284706151133_item	3505255	et	4	main
koosneva	doc_284706151133_item	3505262	et	4	main
mitmesugustes	doc_284706151133_item	3505283	et	3	main
valdkondades	doc_284706151133_item	3505284	et	3	main
tavahind	doc_284706151133_item	3505285	et	3	main
74	doc_284706151133_item	3505286	et	2	main
krooni	doc_284706151133_item	3505287	et	4	main
5	doc_284706151133_item	3505288	et	2	main
kurdetakse	doc_284706151133_item	3505289	et	3	main
silmade	doc_284706151133_item	3505290	et	3	main
väsimust	doc_284706151133_item	3505291	et	4	main
ja	doc_284706151133_item	3505292	et	3	main
kuiva	doc_284706151133_item	3505293	et	4	main
silmi	doc_284706151133_item	3505294	et	4	main
sündroomi	doc_284706151133_item	3505295	et	4	main
silmad	doc_284706151133_item	3505296	et	4	main
kipitavad	doc_284706151133_item	3505297	et	4	main
väsivad	doc_284706151133_item	3505298	et	4	main
selja-	doc_284706151133_item	3505299	et	3	main
ja	doc_284706151133_item	3505300	et	3	main
turjalihased	doc_284706151133_item	3505301	et	4	main
on	doc_284706151133_item	3505302	et	4	main
kontoritöötajail	doc_284706151133_item	3505303	et	3	main
sageli	doc_284706151133_item	3505304	et	3	main
mõjutab	doc_284706151133_item	3505309	et	3	main
pisikesekasvulised	doc_284706151133_item	3505311	et	4	main
jalatuge	doc_284706151133_item	3505314	et	3	main
ainult	doc_284706151133_item	3505315	et	4	main
valget	doc_284706151133_item	3505316	et	3	main
värvust	doc_284706151133_item	3505317	et	4	main
kasutades	doc_284706151133_item	3505318	et	3	main
kujuneb	doc_284706151133_item	3505319	et	3	main
laiutab	doc_284706151133_item	3505324	et	3	main
tunne	doc_284706151133_item	3505328	et	4	main
udus	doc_284706151133_item	3505331	et	3	main
pädev	doc_284706151133_item	3505354	et	3	main
on	doc_284706151133_item	3505364	et	4	main
volitanud	doc_284706151133_item	3505365	et	4	main
täitma	doc_284706151133_item	3505366	et	3	main
töötervishoiu-	doc_284706151133_item	3505367	et	3	main
ja	doc_284706151133_item	3505368	et	3	main
tööohutusalaseid	doc_284706151133_item	3505369	et	4	main
siin	doc_284706151133_item	3505378	et	4	main
et	doc_284706151133_item	3505380	et	3	main
stressisoodumus	doc_284706151133_item	3505382	et	3	main
suur	doc_284706151133_item	3505384	et	3	main
alustades	doc_284706151133_item	3505392	et	3	main
leping	doc_40918597561_item	3505412	et	3	main
251207	doc_40918597561_item	3505417	et	2	main
välja	doc_40918597561_item	3505426	et	4	main
161107	doc_40918597561_item	3505430	et	2	main
eesti	doc_40918597561_item	3505434	et	4	main
felmanni	doc_40918597561_item	3505436	et	4	main
rollins	doc_40918597561_item	3505451	et	4	main
sa	doc_40918597561_item	3505453	et	3	main
oma	doc_40918597561_item	3505461	et	4	main
siilil	doc_284706151133_item	3505330	et	3	main
töötatakse	doc_284706151133_item	3505335	et	4	main
tuleks	doc_284706151133_item	3505337	et	4	main
tavabüroo	doc_284706151133_item	3505339	et	4	main
parem	doc_284706151133_item	3505348	et	4	main
6	doc_284706151133_item	3505349	et	2	main
töökeskkonnaspetsialist	doc_284706151133_item	3505350	et	3	main
saanud	doc_284706151133_item	3505359	et	4	main
spetsialist	doc_284706151133_item	3505360	et	3	main
ettevõttes	doc_284706151133_item	3505361	et	3	main
keda	doc_284706151133_item	3505362	et	4	main
ülesandeid	doc_284706151133_item	3505370	et	3	main
62	doc_284706151133_item	3505375	et	2	main
õeldakse	doc_284706151133_item	3505379	et	4	main
eneseregulatsiooni	doc_284706151133_item	3505390	et	4	main
ja	doc_284706151133_item	3505395	et	3	main
ütlevad	doc_284706151133_item	3505397	et	4	main
ei	doc_284706151133_item	3505399	et	4	main
ostu-müügi	doc_40918597561_item	3505414	et	4	main
51	doc_40918597561_item	3505424	et	2	main
saatkonnaga	doc_40918597561_item	3505429	et	4	main
maja	doc_40918597561_item	3505438	et	4	main
2	doc_40918597561_item	3505439	et	2	main
korter	doc_40918597561_item	3505440	et	3	main
7	doc_40918597561_item	3505441	et	2	main
rahvusvaheline	doc_40918597561_item	3505448	et	4	main
kommerts	doc_40918597561_item	3505449	et	3	main
investments	doc_40918597561_item	3505452	et	4	main
täistööajaga	doc_284706151133_item	3505336	et	3	main
valgustus	doc_284706151133_item	3505346	et	4	main
olema	doc_284706151133_item	3505347	et	4	main
töökeskkonna	doc_284706151133_item	3505352	et	3	main
või	doc_284706151133_item	3505356	et	4	main
töökeskkonnaõpetust	doc_284706151133_item	3505358	et	3	main
sain	doc_284706151133_item	3505373	et	3	main
kohe	doc_284706151133_item	3505387	et	4	main
kasutusele	doc_284706151133_item	3505388	et	4	main
psüühilise	doc_284706151133_item	3505389	et	3	main
treeningust	doc_284706151133_item	3505394	et	4	main
veel	doc_284706151133_item	3505396	et	4	main
et	doc_284706151133_item	3505398	et	3	main
unustada	doc_284706151133_item	3505401	et	3	main
ka	doc_284706151133_item	3505402	et	3	main
füüsise	doc_284706151133_item	3505403	et	4	main
tugevdamist	doc_284706151133_item	3505404	et	4	main
8	doc_284706151133_item	3505405	et	2	main
chip	doc_284706151133_item	3505406	et	4	main
arvutimaailm	doc_284706151133_item	3505407	et	3	main
computer	doc_284706151133_item	3505408	et	4	main
bild	doc_284706151133_item	3505409	et	4	main
arvutikasutaja	doc_284706151133_item	3505410	et	4	main
leping	doc_40918597561_item	3505415	et	3	main
semjonova	doc_40918597561_item	3505419	et	4	main
popova	doc_40918597561_item	3505420	et	4	main
sündinud	doc_40918597561_item	3505421	et	4	main
1041938	doc_40918597561_item	3505422	et	2	main
pass	doc_40918597561_item	3505423	et	3	main
10125	doc_40918597561_item	3505433	et	2	main
nimetatud	doc_40918597561_item	3505442	et	4	main
edasi	doc_40918597561_item	3505443	et	3	main
müüja	doc_40918597561_item	3505444	et	4	main
kompania	doc_40918597561_item	3505450	et	4	main
kes	doc_40918597561_item	3505454	et	4	main
tegevust	doc_40918597561_item	3505462	et	4	main
britanni	doc_40918597561_item	3505463	et	4	main
virgiinisaarte	doc_40918597561_item	3505464	et	4	main
seaduse	doc_40918597561_item	3505465	et	3	main
kooskõlas	doc_40918597561_item	3505466	et	3	main
registreeritud	doc_40918597561_item	3505467	et	4	main
24112000	doc_40918597561_item	3505468	et	2	main
aadressil	doc_40918597561_item	3505469	et	3	main
po	doc_40918597561_item	3505470	et	4	main
box	doc_40918597561_item	3505471	et	4	main
146	doc_40918597561_item	3505472	et	2	main
road	doc_40918597561_item	3505473	et	4	main
town	doc_40918597561_item	3505474	et	4	main
tortola	doc_40918597561_item	3505475	et	4	main
british	doc_40918597561_item	3505476	et	4	main
virgin	doc_40918597561_item	3505477	et	4	main
islands	doc_40918597561_item	3505478	et	4	main
edasi	doc_40918597561_item	3505479	et	3	main
nimetatud	doc_40918597561_item	3505480	et	4	main
ostja	doc_40918597561_item	3505481	et	4	main
direktor	doc_40918597561_item	3505482	et	3	main
k	doc_40918597561_item	3505483	et	4	main
j	doc_40918597561_item	3505484	et	4	main
purim	doc_40918597561_item	3505485	et	4	main
isikus	doc_40918597561_item	3505486	et	3	main
tegelev	doc_40918597561_item	3505487	et	4	main
põhikiri	doc_40918597561_item	3505488	et	3	main
alusel	doc_40918597561_item	3505489	et	4	main
teisest	doc_40918597561_item	3505490	et	4	main
poolest	doc_40918597561_item	3505491	et	4	main
sõlmisid	doc_40918597561_item	3505492	et	4	main
lepingu	doc_40918597561_item	3505493	et	3	main
leping	doc_40918597567_item	3505586	et	3	main
eesti	doc_40918597567_item	3505598	et	4	main
nr	doc_40918597567_item	3505600	et	4	main
sa	doc_40918597567_item	3505614	et	3	main
edasi	doc_40918597567_item	3505615	et	3	main
ostja	doc_40918597567_item	3505616	et	4	main
on	doc_40918597567_item	3505617	et	4	main
juriidiline	doc_40918597567_item	3505618	et	3	main
isik	doc_40918597567_item	3505619	et	3	main
teostav	doc_40918597567_item	3505622	et	4	main
ostu-müügi	doc_40918597567_item	3505585	et	4	main
popova	doc_40918597567_item	3505588	et	4	main
faehlmanni	doc_40918597567_item	3505594	et	4	main
10125	doc_40918597567_item	3505596	et	2	main
tallinn	doc_40918597567_item	3505597	et	4	main
ja	doc_40918597567_item	3505621	et	3	main
eesti	doc_617668397759_item	3505996	et	4	main
ja	doc_617668397759_item	3506003	et	3	main
põhjused	doc_617668397759_item	3506005	et	3	main
2	doc_617668397759_item	3506013	et	2	main
rootsiaegne	doc_617668397759_item	3506014	et	3	main
rahvavalgustuslik	doc_617668397759_item	3506017	et	3	main
sai	doc_617668397759_item	3506051	et	4	main
pärnus	doc_617668397759_item	3506058	et	3	main
elama	doc_617668397759_item	3506064	et	3	main
ja	doc_617668397759_item	3506066	et	3	main
leping	doc_40918597567_item	3505583	et	3	main
müüja	doc_40918597567_item	3505590	et	4	main
8041938	doc_40918597567_item	3505592	et	2	main
föderatsiooni	doc_40918597567_item	3505605	et	4	main
rollins	doc_40918597567_item	3505612	et	4	main
asutatud	doc_40918597567_item	3505620	et	4	main
kontrolltöö	doc_617668397759_item	3505995	et	4	main
vabastamise	doc_617668397759_item	3506001	et	4	main
nende	doc_617668397759_item	3506011	et	4	main
väljaanded	doc_617668397759_item	3506020	et	3	main
ja	doc_617668397759_item	3506023	et	3	main
saksa	doc_617668397759_item	3506045	et	4	main
keeles	doc_617668397759_item	3506046	et	4	main
kirjutada	doc_617668397759_item	3506047	et	3	main
ja	doc_617668397759_item	3506048	et	3	main
lugeda	doc_617668397759_item	3506049	et	3	main
hiljem	doc_617668397759_item	3506050	et	3	main
ilmus	doc_617668397759_item	3506057	et	4	main
hiljem	doc_617668397759_item	3506061	et	3	main
tartusse	doc_617668397759_item	3506065	et	3	main
andis	doc_617668397759_item	3506067	et	3	main
ajalehe	doc_617668397759_item	3506069	et	3	main
tütar	doc_617668397759_item	3506074	et	3	main
vanemuine	doc_617668397759_item	3506095	et	4	main
esimese	doc_617668397759_item	3506097	et	3	main
tähtis	doc_617668397759_item	3506108	et	4	main
kohal	doc_617668397759_item	3506124	et	4	main
pidas	doc_617668397759_item	3506130	et	3	main
laulupeol	doc_617668397759_item	3506132	et	4	main
ohtlikuks	doc_617668397759_item	3506133	et	3	main
palju	doc_617668397759_item	3506137	et	4	main
see	doc_617668397759_item	3506138	et	3	main
õiguste	doc_617668397759_item	3506176	et	4	main
oli	doc_617668397759_item	3506191	et	3	main
olid	doc_617668397759_item	3506202	et	4	main
ja	doc_617668397759_item	3506219	et	3	main
raharendiga	doc_617668397759_item	3506222	et	3	main
oma	doc_617668397759_item	3506232	et	4	main
põllumajandusega	doc_617668397759_item	3506233	et	3	main
ta	doc_617668397759_item	3506234	et	4	main
suutnud	doc_617668397759_item	3506251	et	4	main
võeti	doc_617668397759_item	3506256	et	3	main
tartu	doc_617668397759_item	3506263	et	4	main
eestikeelne	doc_617668397759_item	3506292	et	3	main
saared	doc_40918597567_item	3505655	et	3	main
ostjat	doc_40918597567_item	3505656	et	4	main
esindab	doc_40918597567_item	3505657	et	3	main
direktor	doc_40918597567_item	3505658	et	3	main
konstantin	doc_40918597567_item	3505659	et	4	main
purimaa	doc_40918597567_item	3505660	et	4	main
tegutsev	doc_40918597567_item	3505661	et	4	main
põhikirja	doc_40918597567_item	3505662	et	4	main
alusel	doc_40918597567_item	3505663	et	4	main
ostja	doc_40918597567_item	3505664	et	4	main
ja	doc_40918597567_item	3505665	et	3	main
müüja	doc_40918597567_item	3505666	et	4	main
vahel	doc_40918597567_item	3505667	et	4	main
on	doc_40918597567_item	3505668	et	4	main
sõlmitud	doc_40918597567_item	3505669	et	4	main
leping	doc_40918597567_item	3505670	et	3	main
allajärgnevates	doc_40918597567_item	3505671	et	3	main
punktides	doc_40918597567_item	3505672	et	4	main
aktsiate	doc_40918597567_item	3505584	et	3	main
pass	doc_40918597567_item	3505599	et	3	main
3316838	doc_40918597567_item	3505601	et	2	main
saatkonnaga	doc_40918597567_item	3505606	et	4	main
16112007	doc_40918597567_item	3505607	et	2	main
a	doc_40918597567_item	3505608	et	4	main
investments	doc_40918597567_item	3505613	et	4	main
tegevust	doc_40918597567_item	3505624	et	4	main
briti	doc_40918597567_item	3505625	et	4	main
virginia	doc_40918597567_item	3505626	et	4	main
seadusandlusega	doc_40918597567_item	3505628	et	3	main
kooskõlas	doc_40918597567_item	3505629	et	3	main
ning	doc_40918597567_item	3505630	et	3	main
kantud	doc_40918597567_item	3505631	et	4	main
saarte	doc_40918597567_item	3505627	et	3	main
registrisse	doc_40918597567_item	3505632	et	3	main
24112000	doc_40918597567_item	3505633	et	2	main
a	doc_40918597567_item	3505634	et	4	main
reg	doc_40918597567_item	3505635	et	4	main
nr	doc_40918597567_item	3505636	et	4	main
418606	doc_40918597567_item	3505637	et	2	main
briti	doc_40918597567_item	3505638	et	4	main
virginia	doc_40918597567_item	3505639	et	4	main
saarte	doc_40918597567_item	3505640	et	3	main
korporatsiooni	doc_40918597567_item	3505641	et	4	main
küsimuste	doc_40918597567_item	3505642	et	4	main
registraatoriks	doc_40918597567_item	3505643	et	3	main
mis	doc_40918597567_item	3505644	et	4	main
asub	doc_40918597567_item	3505645	et	3	main
aadressil	doc_40918597567_item	3505646	et	3	main
po	doc_40918597567_item	3505647	et	4	main
box	doc_40918597567_item	3505648	et	4	main
146	doc_40918597567_item	3505649	et	2	main
road	doc_40918597567_item	3505650	et	4	main
town	doc_40918597567_item	3505651	et	4	main
tortola	doc_40918597567_item	3505652	et	4	main
briti	doc_40918597567_item	3505653	et	4	main
virginia	doc_40918597567_item	3505654	et	4	main
kontrolltöö	doc_617668397759_item	3505994	et	4	main
talupoegade	doc_617668397759_item	3505999	et	3	main
pärsiorjusest	doc_617668397759_item	3506000	et	4	main
muutus	doc_617668397759_item	3506007	et	4	main
talupoegade	doc_617668397759_item	3506008	et	3	main
elus	doc_617668397759_item	3506009	et	4	main
3	doc_617668397759_item	3506021	et	2	main
jannsenil	doc_617668397759_item	3506030	et	4	main
oli	doc_617668397759_item	3506031	et	3	main
rahvulikus	doc_617668397759_item	3506032	et	4	main
tema	doc_617668397759_item	3506054	et	4	main
esimene	doc_617668397759_item	3506055	et	3	main
ajaleht	doc_617668397759_item	3506056	et	3	main
ta	doc_617668397759_item	3506063	et	4	main
välja	doc_617668397759_item	3506068	et	4	main
uppsala	doc_617668397759_item	3506273	et	4	main
tartu	doc_617668397759_item	3506274	et	4	main
jne	doc_617668397759_item	3506275	et	4	main
ametnikud	doc_617668397759_item	3506276	et	3	main
kohalikele	doc_617668397759_item	3506277	et	3	main
asutustele	doc_617668397759_item	3506278	et	4	main
esimene	doc_617668397759_item	3506279	et	3	main
eestikeelne	doc_617668397759_item	3506280	et	3	main
piibel	doc_617668397759_item	3506281	et	4	main
piibel	doc_617668397759_item	3506282	et	4	main
tõlgit	doc_617668397759_item	3506283	et	4	main
linzendorffi	doc_617668397759_item	3506284	et	4	main
rahaabiga	doc_617668397759_item	3506285	et	3	main
filosoof	doc_617668397759_item	3506286	et	3	main
descartresi	doc_617668397759_item	3506287	et	4	main
ideede	doc_617668397759_item	3506288	et	3	main
võidukäik	doc_617668397759_item	3506289	et	3	main
väljaanded	doc_617668397759_item	3506290	et	3	main
kultuuriloost	doc_617668397759_item	3505997	et	4	main
majanduslikud	doc_617668397759_item	3506004	et	3	main
mis	doc_617668397759_item	3506006	et	4	main
pärast	doc_617668397759_item	3506010	et	4	main
kirjasõna	doc_617668397759_item	3506018	et	4	main
keelealased	doc_617668397759_item	3506019	et	4	main
jannsen	doc_617668397759_item	3506022	et	4	main
koidula	doc_617668397759_item	3506024	et	4	main
nende	doc_617668397759_item	3506025	et	4	main
roll	doc_617668397759_item	3506026	et	3	main
rahvuslikus	doc_617668397759_item	3506027	et	4	main
liikumises	doc_617668397759_item	3506033	et	4	main
väga	doc_617668397759_item	3506034	et	3	main
tahtis	doc_617668397759_item	3506035	et	3	main
roll	doc_617668397759_item	3506036	et	3	main
kui	doc_617668397759_item	3506037	et	3	main
ta	doc_617668397759_item	3506038	et	4	main
oli	doc_617668397759_item	3506039	et	3	main
19	doc_617668397759_item	3506040	et	2	main
ta	doc_617668397759_item	3506052	et	4	main
kirikupastoriks	doc_617668397759_item	3506053	et	3	main
postimees	doc_617668397759_item	3506060	et	4	main
lkoidula	doc_617668397759_item	3506072	et	4	main
väga	doc_617668397759_item	3506076	et	3	main
palju	doc_617668397759_item	3506077	et	4	main
isa	doc_617668397759_item	3506078	et	4	main
ja	doc_617668397759_item	3506079	et	3	main
võttis	doc_617668397759_item	3506080	et	3	main
ka	doc_617668397759_item	3506081	et	3	main
osa	doc_617668397759_item	3506082	et	4	main
rahvuslikust	doc_617668397759_item	3506083	et	4	main
liikumisest	doc_617668397759_item	3506084	et	4	main
nad	doc_617668397759_item	3506085	et	3	main
asutasid	doc_617668397759_item	3506086	et	4	main
koos	doc_617668397759_item	3506087	et	4	main
tantsu-	doc_617668397759_item	3506088	et	4	main
ja	doc_617668397759_item	3506089	et	3	main
lauluseltsi	doc_617668397759_item	3506090	et	4	main
vanemuine	doc_617668397759_item	3506091	et	4	main
50	doc_617668397759_item	3506092	et	2	main
aastapäeval	doc_617668397759_item	3506093	et	3	main
jaoks	doc_617668397759_item	3506106	et	4	main
oli	doc_617668397759_item	3506107	et	3	main
võttis	doc_617668397759_item	3506117	et	3	main
1000	doc_617668397759_item	3506120	et	2	main
tantsijat	doc_617668397759_item	3506121	et	4	main
ja	doc_617668397759_item	3506122	et	3	main
väga	doc_617668397759_item	3506136	et	3	main
ajaleht	doc_617668397759_item	3506143	et	3	main
tööd	doc_617668397759_item	3506185	et	4	main
et	doc_617668397759_item	3506186	et	3	main
saaks	doc_617668397759_item	3506187	et	3	main
oma	doc_617668397759_item	3506188	et	4	main
eesti	doc_617668397759_item	3506070	et	4	main
postimees	doc_617668397759_item	3506071	et	4	main
aitas	doc_617668397759_item	3506075	et	3	main
tahtis	doc_617668397759_item	3506094	et	3	main
korraldada	doc_617668397759_item	3506096	et	3	main
laulupeo	doc_617668397759_item	3506100	et	4	main
esialgu	doc_617668397759_item	3506102	et	3	main
ebaõnnestus	doc_617668397759_item	3506104	et	4	main
jannseni	doc_617668397759_item	3506105	et	4	main
ühtekuuluvus	doc_617668397759_item	3506111	et	4	main
toimuski	doc_617668397759_item	3506112	et	3	main
tartus	doc_617668397759_item	3506113	et	3	main
olid	doc_617668397759_item	3506125	et	4	main
vaid	doc_617668397759_item	3506126	et	3	main
jannseni	doc_617668397759_item	3506134	et	4	main
pärisorjusest	doc_617668397759_item	3506145	et	4	main
kaua	doc_617668397759_item	3506174	et	3	main
korrapärane	doc_617668397759_item	3506192	et	4	main
ja	doc_617668397759_item	3506194	et	3	main
oli	doc_617668397759_item	3506197	et	3	main
kusagil	doc_617668397759_item	3506199	et	3	main
teorent	doc_617668397759_item	3506216	et	3	main
kaduma	doc_617668397759_item	3506218	et	4	main
rahatööle	doc_617668397759_item	3506226	et	3	main
talupoeg	doc_617668397759_item	3506228	et	3	main
sai	doc_617668397759_item	3506229	et	4	main
nüüd	doc_617668397759_item	3506230	et	4	main
tegeleda	doc_617668397759_item	3506231	et	3	main
maa	doc_617668397759_item	3506245	et	4	main
päriseksostmine	doc_617668397759_item	3506246	et	3	main
siis	doc_617668397759_item	3506247	et	3	main
mitte	doc_617668397759_item	3506248	et	3	main
kõik	doc_617668397759_item	3506249	et	4	main
vaga	doc_617668397759_item	3506257	et	4	main
palju	doc_617668397759_item	3506258	et	4	main
ülikool	doc_617668397759_item	3506264	et	4	main
trükised	doc_617668397759_item	3506291	et	3	main
ja	doc_617668397759_item	3506099	et	3	main
see	doc_617668397759_item	3506103	et	3	main
esimene	doc_617668397759_item	3506114	et	3	main
üldlaulupidu	doc_617668397759_item	3506115	et	4	main
millest	doc_617668397759_item	3506116	et	3	main
u	doc_617668397759_item	3506119	et	4	main
lauljat	doc_617668397759_item	3506123	et	4	main
sest	doc_617668397759_item	3506128	et	4	main
jannsen	doc_617668397759_item	3506129	et	4	main
segakooride	doc_617668397759_item	3506131	et	3	main
tal	doc_617668397759_item	3506140	et	3	main
oma	doc_617668397759_item	3506142	et	4	main
väga	doc_617668397759_item	3506149	et	3	main
kaua	doc_617668397759_item	3506150	et	3	main
aega	doc_617668397759_item	3506151	et	4	main
1802	doc_617668397759_item	3506152	et	2	main
ja	doc_617668397759_item	3506153	et	3	main
1804	doc_617668397759_item	3506154	et	2	main
tulid	doc_617668397759_item	3506155	et	4	main
välja	doc_617668397759_item	3506156	et	4	main
uued	doc_617668397759_item	3506157	et	3	main
talurahvaseadused	doc_617668397759_item	3506158	et	3	main
kuid	doc_617668397759_item	3506159	et	4	main
need	doc_617668397759_item	3506160	et	3	main
lihtsalt	doc_617668397759_item	3506161	et	4	main
pehmendasid	doc_617668397759_item	3506162	et	4	main
talupoegade	doc_617668397759_item	3506163	et	3	main
olukorda	doc_617668397759_item	3506164	et	4	main
alles	doc_617668397759_item	3506165	et	3	main
1850ndatel	doc_617668397759_item	3506166	et	4	main
aastatel	doc_617668397759_item	3506167	et	4	main
toimusid	doc_617668397759_item	3506168	et	4	main
suuremad	doc_617668397759_item	3506169	et	4	main
muutused	doc_617668397759_item	3506170	et	4	main
talupojad	doc_617668397759_item	3506171	et	4	main
protestisid	doc_617668397759_item	3506172	et	4	main
väga	doc_617668397759_item	3506173	et	3	main
1	doc_617668397759_item	3506144	et	2	main
vabastamine	doc_617668397759_item	3506146	et	4	main
toimus	doc_617668397759_item	3506147	et	3	main
eestis	doc_617668397759_item	3506148	et	3	main
oma	doc_617668397759_item	3506175	et	4	main
maad	doc_617668397759_item	3506189	et	4	main
kasutada	doc_617668397759_item	3506190	et	3	main
muidugi	doc_617668397759_item	3506203	et	4	main
hakkas	doc_617668397759_item	3506217	et	3	main
asendus	doc_617668397759_item	3506221	et	4	main
võtsid	doc_617668397759_item	3506224	et	4	main
mõisamoonakad	doc_617668397759_item	3506227	et	3	main
ei	doc_617668397759_item	3506235	et	4	main
pidanud	doc_617668397759_item	3506236	et	4	main
enam	doc_617668397759_item	3506237	et	4	main
mõisas	doc_617668397759_item	3506238	et	3	main
ei	doc_617668397759_item	3506250	et	4	main
osta	doc_617668397759_item	3506255	et	4	main
raha	doc_617668397759_item	3506259	et	4	main
võlgu	doc_617668397759_item	3506260	et	4	main
2	doc_617668397759_item	3506261	et	2	main
seadus	doc_617668397759_item	3506270	et	4	main
juhuluule	doc_617668397759_item	3506294	et	4	main
astronoomia	doc_617668397759_item	3506295	et	4	main
ja	doc_617668397759_item	3506296	et	3	main
kopernikuse	doc_617668397759_item	3506297	et	4	main
õpetus	doc_617668397759_item	3506298	et	4	main
saksa	doc_617668397759_item	3506299	et	4	main
ja	doc_617668397759_item	3506300	et	3	main
ladina	doc_617668397759_item	3506301	et	4	main
keeled	doc_617668397759_item	3506302	et	3	main
olid	doc_617668397759_item	3506303	et	4	main
põhilised	doc_617668397759_item	3506304	et	3	main
erinevad	doc_617668397759_item	3506305	et	4	main
eesti	doc_617668397759_item	3506306	et	4	main
kultuuri	doc_617668397759_item	3506307	et	4	main
puudutavad	doc_617668397759_item	3506308	et	4	main
trükised	doc_617668397759_item	3506309	et	3	main
al	doc_617668397759_item	3506310	et	4	main
1662	doc_617668397759_item	3506311	et	2	main
eeltsentsuuri	doc_617668397759_item	3506312	et	4	main
seadus	doc_617668397759_item	3506313	et	4	main
eest	doc_617668397759_item	3506177	et	4	main
põhiline	doc_617668397759_item	3506178	et	3	main
oli	doc_617668397759_item	3506179	et	3	main
teorent	doc_617668397759_item	3506180	et	3	main
st	doc_617668397759_item	3506181	et	3	main
talupoeg	doc_617668397759_item	3506182	et	3	main
pidi	doc_617668397759_item	3506183	et	4	main
tegema	doc_617668397759_item	3506184	et	3	main
teotöö	doc_617668397759_item	3506193	et	4	main
vaja	doc_617668397759_item	3506198	et	4	main
lisajõudu	doc_617668397759_item	3506200	et	4	main
tööd	doc_617668397759_item	3506239	et	4	main
tegema	doc_617668397759_item	3506240	et	3	main
mitte	doc_617668397759_item	3506241	et	3	main
kõik	doc_617668397759_item	3506242	et	4	main
kui	doc_617668397759_item	3506243	et	3	main
algas	doc_617668397759_item	3506244	et	3	main
asutati	doc_617668397759_item	3506262	et	4	main
rootsi	doc_617668397759_item	3506271	et	4	main
ülikoolid	doc_617668397759_item	3506272	et	3	main
gramatika	doc_617668397759_item	3506293	et	4	main
erandkorras	doc_617668397759_item	3506195	et	3	main
kui	doc_617668397759_item	3506196	et	3	main
mõisnikud	doc_617668397759_item	3506201	et	3	main
väga	doc_617668397759_item	3506204	et	3	main
rahul	doc_617668397759_item	3506205	et	4	main
sellise	doc_617668397759_item	3506206	et	4	main
eluga	doc_617668397759_item	3506207	et	3	main
nii	doc_617668397759_item	3506208	et	3	main
kasvas	doc_617668397759_item	3506209	et	3	main
nende	doc_617668397759_item	3506210	et	4	main
rikkus	doc_617668397759_item	3506211	et	4	main
ja	doc_617668397759_item	3506212	et	3	main
jõukus	doc_617668397759_item	3506213	et	4	main
hiljem	doc_617668397759_item	3506214	et	3	main
kui	doc_617668397759_item	3506215	et	3	main
see	doc_617668397759_item	3506220	et	3	main
siis	doc_617668397759_item	3506223	et	3	main
mõisnikud	doc_617668397759_item	3506225	et	3	main
kohe	doc_617668397759_item	3506252	et	4	main
seda	doc_617668397759_item	3506253	et	3	main
välja	doc_617668397759_item	3506254	et	4	main
alates	doc_617668397759_item	3506265	et	3	main
gümnaasiumide	doc_617668397759_item	3506266	et	3	main
asutamine	doc_617668397759_item	3506267	et	4	main
1600	doc_617668397759_item	3506268	et	2	main
koolikorralduse	doc_617668397759_item	3506269	et	3	main
kontrolltöö	doc_980560860268_item	3507070	et	4	main
lõpeta	doc_980560860268_item	3507072	et	4	main
või	doc_980560860268_item	3507075	et	4	main
veel	doc_980560860268_item	3507081	et	4	main
ilm	doc_980560860268_item	3507100	et	3	main
lugema	doc_980560860268_item	3507084	et	4	main
tereviisorit	doc_980560860268_item	3507089	et	4	main
mulle	doc_980560860268_item	3507093	et	4	main
meeldib	doc_980560860268_item	3507094	et	3	main
ujuda	doc_980560860268_item	3507095	et	3	main
ja	doc_980560860268_item	3507096	et	3	main
süüa	doc_980560860268_item	3507097	et	3	main
kui	doc_980560860268_item	3507098	et	3	main
lähen	doc_980560860268_item	3507102	et	3	main
ja	doc_980560860268_item	3507106	et	3	main
tohi	doc_980560860268_item	3507112	et	4	main
on	doc_980560860268_item	3507132	et	4	main
teisipäev	doc_980560860268_item	3507134	et	3	main
päev	doc_980560860268_item	3507136	et	3	main
saab	doc_980560860268_item	3507138	et	3	main
sai	doc_980560860268_item	3507139	et	4	main
ta	doc_980560860268_item	3507140	et	4	main
magada	doc_980560860268_item	3507141	et	3	main
ta	doc_980560860268_item	3507150	et	4	main
joob	doc_980560860268_item	3507153	et	3	main
ta	doc_980560860268_item	3507155	et	4	main
kohvi	doc_980560860268_item	3507156	et	4	main
sööb	doc_980560860268_item	3507157	et	3	main
sõi	doc_980560860268_item	3507158	et	3	main
pidi	doc_980560860268_item	3507166	et	4	main
avab	doc_980560860268_item	3507173	et	3	main
failid	doc_980560860268_item	3507175	et	3	main
ja	doc_980560860268_item	3507176	et	3	main
kirjutab	doc_980560860268_item	3507177	et	3	main
kirjutas	doc_980560860268_item	3507178	et	3	main
pean	doc_980560860268_item	3507079	et	4	main
täna	doc_980560860268_item	3507080	et	4	main
tahan	doc_980560860268_item	3507087	et	3	main
raekoja	doc_980560860268_item	3507103	et	3	main
keele	doc_980560860268_item	3507109	et	4	main
tunnis	doc_980560860268_item	3507110	et	3	main
ega	doc_980560860268_item	3507114	et	3	main
marjul	doc_980560860268_item	3507131	et	3	main
magas	doc_980560860268_item	3507144	et	4	main
1030	doc_980560860268_item	3507147	et	2	main
ärkab	doc_980560860268_item	3507148	et	3	main
võileiba	doc_980560860268_item	3507159	et	4	main
ja	doc_980560860268_item	3507160	et	3	main
loeb	doc_980560860268_item	3507161	et	3	main
luges	doc_980560860268_item	3507162	et	3	main
e-kirju	doc_980560860268_item	3507163	et	4	main
natuke	doc_980560860268_item	3507167	et	4	main
1	doc_980560860268_item	3507071	et	2	main
laused	doc_980560860268_item	3507073	et	3	main
ja	doc_980560860268_item	3507083	et	3	main
aga	doc_980560860268_item	3507085	et	3	main
ilus	doc_980560860268_item	3507099	et	4	main
ei	doc_980560860268_item	3507111	et	4	main
vaadata	doc_980560860268_item	3507115	et	4	main
oli	doc_980560860268_item	3507133	et	3	main
vaba	doc_980560860268_item	3507135	et	4	main
lõpuks	doc_980560860268_item	3507137	et	4	main
üles	doc_980560860268_item	3507151	et	3	main
tegema	doc_980560860268_item	3507171	et	3	main
ta	doc_980560860268_item	3507172	et	4	main
pani	doc_980560860268_item	3507181	et	4	main
pesu	doc_980560860268_item	3507182	et	4	main
masinasse	doc_980560860268_item	3507183	et	4	main
ja	doc_980560860268_item	3507184	et	3	main
masina	doc_980560860268_item	3507185	et	3	main
käis	doc_980560860268_item	3507194	et	4	main
astub	doc_980560860268_item	3507200	et	3	main
trolliga	doc_980560860268_item	3507217	et	4	main
sõber	doc_980560860268_item	3507228	et	3	main
ning	doc_980560860268_item	3507229	et	3	main
jooksid	doc_980560860268_item	3507237	et	4	main
umbes	doc_980560860268_item	3507239	et	4	main
ta	doc_980560860268_item	3507246	et	4	main
vannis	doc_980560860268_item	3507247	et	3	main
ning	doc_980560860268_item	3507248	et	3	main
ära	doc_980560860268_item	3507251	et	4	main
man	doc_980560860268_item	3507261	et	3	main
on	doc_980560860268_item	3507292	et	4	main
tegid	doc_980560860268_item	3507301	et	4	main
ma	doc_980560860268_item	3507302	et	3	main
olin	doc_980560860268_item	3507303	et	3	main
me	doc_980560860268_item	3507311	et	4	main
1	doc_491521501878_item	3507324	et	2	main
eesti	doc_491521501878_item	3507329	et	4	main
üldiseloomustus	doc_491521501878_item	3507331	et	4	main
2	doc_491521501878_item	3507332	et	2	main
ega	doc_491521501878_item	3507337	et	3	main
a	doc_491521501878_item	3507374	et	4	main
tekkisid	doc_491521501878_item	3507386	et	4	main
kivi	doc_491521501878_item	3507418	et	4	main
valimine	doc_491521501878_item	3507419	et	4	main
suitsupääsuke	doc_491521501878_item	3507420	et	4	main
sini-must-valge	doc_491521501878_item	3507428	et	4	main
pandi	doc_491521501878_item	3507440	et	4	main
eriti	doc_491521501878_item	3507454	et	3	main
hinnas	doc_491521501878_item	3507455	et	3	main
oli	doc_491521501878_item	3507456	et	3	main
nt	doc_491521501878_item	3507457	et	4	main
kohv	doc_491521501878_item	3507458	et	3	main
samuti	doc_491521501878_item	3507459	et	3	main
vähenes	doc_491521501878_item	3507468	et	3	main
näod	doc_491521501878_item	3507472	et	3	main
nt	doc_491521501878_item	3507477	et	4	main
ühiskonnas	doc_491521501878_item	3507491	et	4	main
seotud	doc_491521501878_item	3507495	et	4	main
a	doc_491521501878_item	3507497	et	4	main
vaatasime	doc_980560860268_item	3507316	et	3	main
filmi	doc_980560860268_item	3507317	et	4	main
ma	doc_980560860268_item	3507318	et	3	main
magasin	doc_980560860268_item	3507319	et	4	main
kell	doc_980560860268_item	3507320	et	3	main
4	doc_980560860268_item	3507321	et	2	main
ma	doc_980560860268_item	3507074	et	3	main
da	doc_980560860268_item	3507076	et	4	main
infinitiiviga	doc_980560860268_item	3507077	et	3	main
ma	doc_980560860268_item	3507078	et	3	main
õppima	doc_980560860268_item	3507082	et	3	main
ma	doc_980560860268_item	3507086	et	3	main
täna	doc_980560860268_item	3507088	et	4	main
vaadata	doc_980560860268_item	3507090	et	4	main
ja	doc_980560860268_item	3507091	et	3	main
magada	doc_980560860268_item	3507092	et	3	main
on	doc_980560860268_item	3507101	et	4	main
platsile	doc_980560860268_item	3507104	et	4	main
sööma	doc_980560860268_item	3507107	et	4	main
eesti	doc_980560860268_item	3507108	et	4	main
helistada	doc_980560860268_item	3507113	et	3	main
kas	doc_980560860268_item	3507116	et	3	main
sa	doc_980560860268_item	3507117	et	3	main
ka	doc_980560860268_item	3507119	et	3	main
kadrioru	doc_980560860268_item	3507120	et	3	main
parki	doc_980560860268_item	3507121	et	4	main
magama	doc_980560860268_item	3507122	et	3	main
tuled	doc_980560860268_item	3507118	et	4	main
ja	doc_980560860268_item	3507123	et	3	main
lugema	doc_980560860268_item	3507124	et	4	main
2	doc_980560860268_item	3507125	et	2	main
pane	doc_980560860268_item	3507126	et	4	main
tekst	doc_980560860268_item	3507127	et	3	main
minevikku	doc_980560860268_item	3507128	et	4	main
marju	doc_980560860268_item	3507129	et	3	main
jooksma	doc_980560860268_item	3507105	et	3	main
ta	doc_980560860268_item	3507142	et	4	main
magab	doc_980560860268_item	3507143	et	3	main
kaua	doc_980560860268_item	3507145	et	3	main
kell	doc_980560860268_item	3507146	et	3	main
siis	doc_980560860268_item	3507152	et	3	main
ta	doc_980560860268_item	3507164	et	4	main
peab	doc_980560860268_item	3507165	et	4	main
arvuti	doc_980560860268_item	3507168	et	4	main
taga	doc_980560860268_item	3507169	et	4	main
tööd	doc_980560860268_item	3507170	et	4	main
avas	doc_980560860268_item	3507174	et	4	main
tööle	doc_980560860268_item	3507186	et	3	main
pärastlõunal	doc_980560860268_item	3507187	et	3	main
läheb	doc_980560860268_item	3507188	et	3	main
läks	doc_980560860268_item	3507189	et	3	main
ta	doc_980560860268_item	3507190	et	4	main
paaris	doc_980560860268_item	3507195	et	4	main
poes	doc_980560860268_item	3507196	et	3	main
koju	doc_980560860268_item	3507213	et	3	main
sõidab	doc_980560860268_item	3507214	et	3	main
sõidas	doc_980560860268_item	3507215	et	4	main
kodus	doc_980560860268_item	3507218	et	4	main
marju	doc_980560860268_item	3507221	et	3	main
helistas	doc_980560860268_item	3507225	et	3	main
üks	doc_980560860268_item	3507227	et	3	main
otsustavad	doc_980560860268_item	3507231	et	4	main
otsustad	doc_980560860268_item	3507232	et	3	main
metsas	doc_980560860268_item	3507238	et	3	main
tund	doc_980560860268_item	3507240	et	3	main
vaatas	doc_980560860268_item	3507250	et	3	main
film	doc_980560860268_item	3507254	et	3	main
räägis	doc_980560860268_item	3507256	et	3	main
üle	doc_980560860268_item	3507294	et	3	main
sobraga	doc_980560860268_item	3507310	et	4	main
eksamitöö	doc_491521501878_item	3507323	et	4	main
sulaperioodi	doc_491521501878_item	3507328	et	4	main
kauge	doc_491521501878_item	3507335	et	4	main
me	doc_491521501878_item	3507341	et	4	main
pealinnade	doc_491521501878_item	3507343	et	3	main
sisendab	doc_491521501878_item	3507351	et	3	main
hirmu	doc_491521501878_item	3507352	et	4	main
see	doc_491521501878_item	3507353	et	3	main
ahel	doc_491521501878_item	3507354	et	3	main
millisest	doc_491521501878_item	3507355	et	3	main
p	doc_491521501878_item	3507358	et	4	main
luuletuses	doc_491521501878_item	3507360	et	4	main
millal	doc_491521501878_item	3507361	et	3	main
see	doc_491521501878_item	3507362	et	3	main
toimus	doc_491521501878_item	3507363	et	3	main
ja	doc_491521501878_item	3507364	et	3	main
balti	doc_491521501878_item	3507375	et	3	main
kruusemendi	doc_491521501878_item	3507380	et	4	main
rukkilille	doc_491521501878_item	3507425	et	4	main
lipu	doc_491521501878_item	3507430	et	3	main
värvid	doc_491521501878_item	3507431	et	4	main
ja	doc_491521501878_item	3507433	et	3	main
herlsinki	doc_491521501878_item	3507434	et	4	main
vahet	doc_491521501878_item	3507435	et	3	main
hakkas	doc_491521501878_item	3507436	et	3	main
käima	doc_491521501878_item	3507437	et	4	main
reisilaev	doc_491521501878_item	3507438	et	3	main
sellega	doc_491521501878_item	3507439	et	3	main
välismaalt	doc_491521501878_item	3507449	et	3	main
vene	doc_491521501878_item	3507465	et	4	main
muusikamaailma	doc_491521501878_item	3507469	et	4	main
uued	doc_491521501878_item	3507471	et	3	main
veljo	doc_491521501878_item	3507478	et	4	main
filmikunst	doc_491521501878_item	3507486	et	3	main
levis	doc_491521501878_item	3507490	et	4	main
meeleolu	doc_491521501878_item	3507494	et	4	main
tähendas	doc_491521501878_item	3507523	et	3	main
juurde	doc_491521501878_item	3507537	et	4	main
soovitava	doc_491521501878_item	3507543	et	4	main
lisatud	doc_491521501878_item	3507546	et	4	main
luuletus	doc_491521501878_item	3507550	et	4	main
23	doc_491521501878_item	3507552	et	2	main
augustil	doc_491521501878_item	3507553	et	3	main
toimunud	doc_491521501878_item	3507556	et	4	main
inimest	doc_491521501878_item	3507563	et	3	main
ja	doc_491521501878_item	3507564	et	3	main
mis	doc_491521501878_item	3507565	et	4	main
päev	doc_980560860268_item	3507130	et	3	main
ärkas	doc_980560860268_item	3507149	et	3	main
jõi	doc_980560860268_item	3507154	et	3	main
linna	doc_980560860268_item	3507191	et	4	main
ta	doc_980560860268_item	3507216	et	4	main
õhtul	doc_980560860268_item	3507223	et	3	main
pärnography	doc_980560860268_item	3507253	et	4	main
animafilmi	doc_980560860268_item	3507258	et	4	main
priit	doc_980560860268_item	3507262	et	3	main
eesti	doc_980560860268_item	3507284	et	4	main
oli	doc_980560860268_item	3507293	et	3	main
3	doc_980560860268_item	3507296	et	2	main
räägisin	doc_980560860268_item	3507308	et	4	main
minu	doc_980560860268_item	3507309	et	3	main
keelt	doc_980560860268_item	3507314	et	4	main
me	doc_980560860268_item	3507315	et	4	main
1960	doc_491521501878_item	3507325	et	2	main
korea	doc_491521501878_item	3507336	et	4	main
hiina	doc_491521501878_item	3507338	et	3	main
nii	doc_491521501878_item	3507346	et	3	main
gediminasest	doc_491521501878_item	3507349	et	4	main
moskvale	doc_491521501878_item	3507350	et	4	main
mida	doc_491521501878_item	3507365	et	4	main
nimetage	doc_491521501878_item	3507378	et	3	main
tuntumaid	doc_491521501878_item	3507381	et	4	main
filme	doc_491521501878_item	3507382	et	3	main
suitsup	doc_491521501878_item	3507423	et	4	main
eesti	doc_491521501878_item	3507429	et	4	main
samuti	doc_491521501878_item	3507444	et	3	main
võimalik	doc_491521501878_item	3507448	et	3	main
välismaale	doc_491521501878_item	3507452	et	4	main
saata	doc_491521501878_item	3507453	et	3	main
venekeelsete	doc_491521501878_item	3507460	et	4	main
kultuuriväljaannete	doc_491521501878_item	3507461	et	3	main
tsensuur	doc_491521501878_item	3507462	et	3	main
vähenes	doc_491521501878_item	3507463	et	3	main
tõlkekirjanduses	doc_491521501878_item	3507464	et	3	main
kaasaegsemat	doc_491521501878_item	3507475	et	4	main
tol	doc_491521501878_item	3507480	et	3	main
arenes	doc_491521501878_item	3507482	et	3	main
teatri-	doc_491521501878_item	3507484	et	3	main
60	doc_491521501878_item	3507488	et	2	main
tahtsid	doc_491521501878_item	3507526	et	4	main
siis	doc_491521501878_item	3507530	et	3	main
veel	doc_491521501878_item	3507538	et	4	main
raamatu	doc_491521501878_item	3507544	et	4	main
ja	doc_491521501878_item	3507578	et	3	main
selline	doc_491521501878_item	3507581	et	4	main
lootust	doc_491521501878_item	3507585	et	4	main
eesti	doc_491521501878_item	3507604	et	4	main
kinni	doc_491521501878_item	3507615	et	3	main
küünlad	doc_491521501878_item	3507617	et	3	main
sai	doc_491521501878_item	3507623	et	4	main
et	doc_491521501878_item	3507626	et	3	main
rahvaste	doc_491521501878_item	3507628	et	4	main
rahvustunne	doc_491521501878_item	3507629	et	3	main
eesti	doc_491521501878_item	3507638	et	4	main
olid	doc_491521501878_item	3507642	et	4	main
sellised	doc_491521501878_item	3507644	et	4	main
sündmused	doc_491521501878_item	3507645	et	3	main
mis	doc_491521501878_item	3507646	et	4	main
nt	doc_491521501878_item	3507652	et	4	main
89	doc_491521501878_item	3507655	et	2	main
aastal	doc_491521501878_item	3507656	et	3	main
paneb	doc_980560860268_item	3507180	et	3	main
ja	doc_980560860268_item	3507197	et	3	main
pangas	doc_980560860268_item	3507198	et	4	main
ta	doc_980560860268_item	3507202	et	4	main
läbi	doc_980560860268_item	3507203	et	4	main
eesti	doc_980560860268_item	3507204	et	4	main
instituudist	doc_980560860268_item	3507205	et	3	main
ning	doc_980560860268_item	3507206	et	3	main
toob	doc_980560860268_item	3507207	et	3	main
tõi	doc_980560860268_item	3507208	et	3	main
sealt	doc_980560860268_item	3507209	et	4	main
ära	doc_980560860268_item	3507210	et	4	main
mõned	doc_980560860268_item	3507211	et	3	main
raamatud	doc_980560860268_item	3507212	et	4	main
ta	doc_980560860268_item	3507179	et	4	main
ta	doc_980560860268_item	3507192	et	4	main
käib	doc_980560860268_item	3507193	et	3	main
vanalinnas	doc_980560860268_item	3507199	et	4	main
astus	doc_980560860268_item	3507201	et	3	main
tei	doc_980560860268_item	3507220	et	4	main
jooksevad	doc_980560860268_item	3507236	et	4	main
aega	doc_980560860268_item	3507241	et	4	main
õhtul	doc_980560860268_item	3507242	et	3	main
kodus	doc_980560860268_item	3507243	et	4	main
istub	doc_980560860268_item	3507244	et	3	main
istus	doc_980560860268_item	3507245	et	4	main
filmi	doc_980560860268_item	3507252	et	4	main
eesti	doc_980560860268_item	3507257	et	4	main
grand	doc_980560860268_item	3507259	et	3	main
old	doc_980560860268_item	3507260	et	4	main
pärnast	doc_980560860268_item	3507263	et	4	main
siis	doc_980560860268_item	3507264	et	3	main
kuulab	doc_980560860268_item	3507265	et	3	main
kuulas	doc_980560860268_item	3507266	et	3	main
ta	doc_980560860268_item	3507267	et	4	main
uudiseid	doc_980560860268_item	3507268	et	3	main
töötab	doc_980560860268_item	3507269	et	3	main
töötas	doc_980560860268_item	3507270	et	3	main
veel	doc_980560860268_item	3507271	et	4	main
natuke	doc_980560860268_item	3507272	et	4	main
arvuti	doc_980560860268_item	3507273	et	4	main
taga	doc_980560860268_item	3507274	et	4	main
ning	doc_980560860268_item	3507275	et	3	main
jutustab	doc_980560860268_item	3507276	et	3	main
jutustas	doc_980560860268_item	3507277	et	3	main
ühe	doc_980560860268_item	3507278	et	4	main
tartu	doc_980560860268_item	3507279	et	4	main
sõbraga	doc_980560860268_item	3507280	et	3	main
teeb	doc_980560860268_item	3507281	et	3	main
tei	doc_980560860268_item	3507282	et	4	main
ning	doc_980560860268_item	3507287	et	3	main
teeb	doc_980560860268_item	3507219	et	3	main
spagette	doc_980560860268_item	3507222	et	4	main
helistab	doc_980560860268_item	3507224	et	3	main
talle	doc_980560860268_item	3507226	et	4	main
nad	doc_980560860268_item	3507230	et	3	main
minna	doc_980560860268_item	3507233	et	3	main
jooksma	doc_980560860268_item	3507234	et	3	main
nad	doc_980560860268_item	3507235	et	3	main
vaatab	doc_980560860268_item	3507249	et	3	main
räägib	doc_980560860268_item	3507255	et	3	main
valmis	doc_980560860268_item	3507283	et	4	main
testi	doc_980560860268_item	3507286	et	4	main
läks	doc_980560860268_item	3507289	et	3	main
magama	doc_980560860268_item	3507290	et	3	main
kell	doc_980560860268_item	3507291	et	3	main
südaöö	doc_980560860268_item	3507295	et	4	main
kirjuta	doc_980560860268_item	3507297	et	4	main
vene	doc_980560860268_item	3507313	et	4	main
keele	doc_980560860268_item	3507285	et	4	main
läheb	doc_980560860268_item	3507288	et	3	main
mida	doc_980560860268_item	3507298	et	4	main
sina	doc_980560860268_item	3507299	et	4	main
eile	doc_980560860268_item	3507300	et	3	main
kodus	doc_980560860268_item	3507304	et	4	main
ma	doc_980560860268_item	3507305	et	3	main
kohtusin	doc_980560860268_item	3507306	et	4	main
ja	doc_980560860268_item	3507307	et	3	main
õppisime	doc_980560860268_item	3507312	et	3	main
nn	doc_491521501878_item	3507327	et	4	main
kultuuri	doc_491521501878_item	3507330	et	4	main
ei	doc_491521501878_item	3507333	et	4	main
paelast	doc_491521501878_item	3507340	et	4	main
aga	doc_491521501878_item	3507345	et	3	main
kui	doc_491521501878_item	3507348	et	3	main
kõneldakse	doc_491521501878_item	3507357	et	3	main
balti	doc_491521501878_item	3507367	et	3	main
riikide	doc_491521501878_item	3507368	et	3	main
tähendas	doc_491521501878_item	3507370	et	3	main
august	doc_491521501878_item	3507372	et	4	main
kett	doc_491521501878_item	3507376	et	4	main
andsid	doc_491521501878_item	3507427	et	4	main
alus	doc_491521501878_item	3507441	et	4	main
nn	doc_491521501878_item	3507445	et	4	main
pakimajandus	doc_491521501878_item	3507446	et	3	main
oli	doc_491521501878_item	3507447	et	3	main
teoste	doc_491521501878_item	3507466	et	3	main
ilmusid	doc_491521501878_item	3507470	et	4	main
kes	doc_491521501878_item	3507473	et	4	main
viljelesid	doc_491521501878_item	3507474	et	4	main
tormis	doc_491521501878_item	3507479	et	3	main
nii	doc_491521501878_item	3507483	et	3	main
kui	doc_491521501878_item	3507485	et	3	main
samas	doc_491521501878_item	3507487	et	4	main
lõpul	doc_491521501878_item	3507489	et	3	main
masendav	doc_491521501878_item	3507493	et	4	main
et	doc_491521501878_item	3507524	et	3	main
raamatut	doc_491521501878_item	3507529	et	3	main
et	doc_491521501878_item	3507531	et	3	main
saada	doc_491521501878_item	3507533	et	4	main
mis	doc_491521501878_item	3507541	et	4	main
juurde	doc_491521501878_item	3507545	et	4	main
lähendas	doc_491521501878_item	3507571	et	3	main
võimu	doc_491521501878_item	3507573	et	4	main
üritus	doc_491521501878_item	3507582	et	4	main
selle	doc_491521501878_item	3507590	et	4	main
ärahoidmiseks	doc_491521501878_item	3507591	et	3	main
kajastati	doc_491521501878_item	3507596	et	3	main
välismaal	doc_491521501878_item	3507598	et	4	main
ja	doc_491521501878_item	3507599	et	3	main
said	doc_491521501878_item	3507602	et	4	main
aimu	doc_491521501878_item	3507603	et	4	main
inimesed	doc_491521501878_item	3507612	et	3	main
ensv	doc_491521501878_item	3507620	et	4	main
tolleaegne	doc_491521501878_item	3507621	et	3	main
valitsus	doc_491521501878_item	3507622	et	4	main
aastate	doc_491521501878_item	3507326	et	3	main
aima	doc_491521501878_item	3507334	et	4	main
sest	doc_491521501878_item	3507339	et	4	main
balti	doc_491521501878_item	3507342	et	3	main
vahel	doc_491521501878_item	3507344	et	4	main
toompealt	doc_491521501878_item	3507347	et	3	main
sündmusest	doc_491521501878_item	3507356	et	4	main
aimla	doc_491521501878_item	3507359	et	4	main
see	doc_491521501878_item	3507366	et	3	main
jaoks	doc_491521501878_item	3507369	et	4	main
23	doc_491521501878_item	3507371	et	2	main
1988	doc_491521501878_item	3507373	et	2	main
3	doc_491521501878_item	3507377	et	2	main
a	doc_491521501878_item	3507379	et	4	main
1	doc_491521501878_item	3507383	et	2	main
60-ndate	doc_491521501878_item	3507384	et	4	main
lõpul	doc_491521501878_item	3507385	et	3	main
multikad	doc_491521501878_item	3507387	et	4	main
nt	doc_491521501878_item	3507388	et	4	main
peetrikese	doc_491521501878_item	3507389	et	4	main
unenägu	doc_491521501878_item	3507390	et	4	main
ka	doc_491521501878_item	3507391	et	3	main
nukufilmid	doc_491521501878_item	3507392	et	3	main
60	doc_491521501878_item	3507393	et	2	main
keskel	doc_491521501878_item	3507394	et	3	main
hakati	doc_491521501878_item	3507395	et	3	main
tootma	doc_491521501878_item	3507396	et	3	main
teles	doc_491521501878_item	3507397	et	3	main
lastesaateid	doc_491521501878_item	3507398	et	3	main
ja	doc_491521501878_item	3507399	et	3	main
lavastusi	doc_491521501878_item	3507400	et	4	main
muusikasaade	doc_491521501878_item	3507401	et	4	main
horoskoop	doc_491521501878_item	3507402	et	3	main
sai	doc_491521501878_item	3507403	et	4	main
tuntuks	doc_491521501878_item	3507404	et	4	main
eriti	doc_491521501878_item	3507405	et	3	main
oluline	doc_491521501878_item	3507406	et	4	main
sündmus	doc_491521501878_item	3507407	et	3	main
mis	doc_491521501878_item	3507408	et	4	main
sai	doc_491521501878_item	3507409	et	4	main
60	doc_491521501878_item	3507410	et	2	main
aset	doc_491521501878_item	3507411	et	3	main
leidis	doc_491521501878_item	3507412	et	4	main
oli	doc_491521501878_item	3507413	et	3	main
eesti	doc_491521501878_item	3507414	et	4	main
rahvuslinnu	doc_491521501878_item	3507415	et	4	main
lille	doc_491521501878_item	3507416	et	4	main
ja	doc_491521501878_item	3507417	et	3	main
rukkilill	doc_491521501878_item	3507421	et	3	main
paekivi	doc_491521501878_item	3507422	et	4	main
ja	doc_491521501878_item	3507424	et	3	main
värvikombinatsioonid	doc_491521501878_item	3507426	et	3	main
tallinna	doc_491521501878_item	3507432	et	4	main
teeninduskultuurile	doc_491521501878_item	3507442	et	3	main
eestis	doc_491521501878_item	3507443	et	3	main
pakke	doc_491521501878_item	3507450	et	4	main
saada	doc_491521501878_item	3507451	et	4	main
osakaal	doc_491521501878_item	3507467	et	3	main
muusikat	doc_491521501878_item	3507476	et	3	main
ajal	doc_491521501878_item	3507481	et	4	main
taas	doc_491521501878_item	3507492	et	3	main
68	doc_491521501878_item	3507496	et	2	main
tšehhi	doc_491521501878_item	3507498	et	2	main
sündmustega	doc_491521501878_item	3507499	et	3	main
mil	doc_491521501878_item	3507500	et	4	main
arvati	doc_491521501878_item	3507501	et	4	main
et	doc_491521501878_item	3507502	et	3	main
iseseisvust	doc_491521501878_item	3507503	et	4	main
ei	doc_491521501878_item	3507504	et	4	main
saavutatagi	doc_491521501878_item	3507505	et	3	main
tekkis	doc_491521501878_item	3507506	et	3	main
selline	doc_491521501878_item	3507507	et	4	main
minnalaskmismeeleolu	doc_491521501878_item	3507508	et	4	main
stagnatsioon	doc_491521501878_item	3507509	et	3	main
süvenes	doc_491521501878_item	3507510	et	3	main
ülikoolides	doc_491521501878_item	3507511	et	3	main
võeti	doc_491521501878_item	3507512	et	3	main
värvimütsid	doc_491521501878_item	3507513	et	3	main
e	doc_491521501878_item	3507514	et	4	main
teklid	doc_491521501878_item	3507515	et	3	main
kasutusele	doc_491521501878_item	3507516	et	4	main
samuti	doc_491521501878_item	3507517	et	3	main
valitses	doc_491521501878_item	3507518	et	3	main
pakisüsteem	doc_491521501878_item	3507519	et	3	main
raamatute	doc_491521501878_item	3507520	et	3	main
ostmisel	doc_491521501878_item	3507521	et	4	main
mis	doc_491521501878_item	3507522	et	4	main
kui	doc_491521501878_item	3507525	et	3	main
ihaldatavat	doc_491521501878_item	3507528	et	4	main
pidid	doc_491521501878_item	3507534	et	4	main
ostma	doc_491521501878_item	3507535	et	3	main
selle	doc_491521501878_item	3507536	et	4	main
olid	doc_491521501878_item	3507542	et	4	main
p	doc_491521501878_item	3507548	et	4	main
on	doc_491521501878_item	3507551	et	4	main
1988	doc_491521501878_item	3507554	et	2	main
km	doc_491521501878_item	3507568	et	4	main
pikk	doc_491521501878_item	3507569	et	4	main
võimud	doc_491521501878_item	3507587	et	3	main
ei	doc_491521501878_item	3507588	et	4	main
midagi	doc_491521501878_item	3507592	et	4	main
teha	doc_491521501878_item	3507593	et	3	main
ka	doc_491521501878_item	3507600	et	3	main
väga	doc_491521501878_item	3507609	et	3	main
ja	doc_491521501878_item	3507616	et	3	main
põlevad	doc_491521501878_item	3507618	et	4	main
ega	doc_491521501878_item	3507619	et	3	main
on	doc_491521501878_item	3507630	et	4	main
mingit	doc_491521501878_item	3507527	et	3	main
seda	doc_491521501878_item	3507532	et	3	main
hunniku	doc_491521501878_item	3507539	et	3	main
teisigi	doc_491521501878_item	3507540	et	4	main
2	doc_491521501878_item	3507547	et	2	main
aimla	doc_491521501878_item	3507549	et	4	main
a	doc_491521501878_item	3507555	et	4	main
balti	doc_491521501878_item	3507557	et	3	main
ketist	doc_491521501878_item	3507558	et	3	main
milles	doc_491521501878_item	3507559	et	3	main
osales	doc_491521501878_item	3507560	et	3	main
mitu	doc_491521501878_item	3507561	et	4	main
miljonit	doc_491521501878_item	3507562	et	3	main
see	doc_491521501878_item	3507570	et	3	main
eestlasi	doc_491521501878_item	3507577	et	3	main
ja	doc_491521501878_item	3507580	et	3	main
ja	doc_491521501878_item	3507586	et	3	main
suutnud	doc_491521501878_item	3507589	et	4	main
balti	doc_491521501878_item	3507594	et	3	main
ka	doc_491521501878_item	3507597	et	3	main
välisriigid	doc_491521501878_item	3507601	et	3	main
südamlik	doc_491521501878_item	3507610	et	3	main
seisavad	doc_491521501878_item	3507613	et	3	main
väga	doc_491521501878_item	3507631	et	3	main
kõrge	doc_491521501878_item	3507632	et	4	main
ning	doc_491521501878_item	3507633	et	3	main
balti	doc_491521501878_item	3507640	et	3	main
kasvõi	doc_491521501878_item	3507651	et	3	main
hirvepargi	doc_491521501878_item	3507653	et	3	main
miiting	doc_491521501878_item	3507654	et	3	main
nõudis	doc_491521501878_item	3507659	et	3	main
punktide	doc_491521501878_item	3507661	et	3	main
oli	doc_491521501878_item	3507566	et	3	main
400	doc_491521501878_item	3507567	et	2	main
nõukogude	doc_491521501878_item	3507572	et	3	main
all	doc_491521501878_item	3507574	et	3	main
olevaid	doc_491521501878_item	3507575	et	4	main
rahvaid	doc_491521501878_item	3507576	et	3	main
lätlasi	doc_491521501878_item	3507579	et	3	main
andis	doc_491521501878_item	3507583	et	3	main
inimestele	doc_491521501878_item	3507584	et	3	main
ketti	doc_491521501878_item	3507595	et	4	main
olukorrast	doc_491521501878_item	3507605	et	4	main
nl-s	doc_491521501878_item	3507606	et	3	main
see	doc_491521501878_item	3507607	et	3	main
oli	doc_491521501878_item	3507608	et	3	main
üritus	doc_491521501878_item	3507611	et	4	main
kätest	doc_491521501878_item	3507614	et	3	main
ka	doc_491521501878_item	3507624	et	3	main
aru	doc_491521501878_item	3507625	et	4	main
nende	doc_491521501878_item	3507627	et	4	main
ketile	doc_491521501878_item	3507641	et	3	main
eelnenudeelnesid	doc_491521501878_item	3507643	et	4	main
iseseisvumiseni	doc_491521501878_item	3507650	et	3	main
mil	doc_491521501878_item	3507657	et	4	main
varem	doc_491521501878_item	3507634	et	4	main
või	doc_491521501878_item	3507635	et	4	main
hiljem	doc_491521501878_item	3507636	et	3	main
saab	doc_491521501878_item	3507637	et	3	main
viisid	doc_491521501878_item	3507647	et	4	main
mrp	doc_491521501878_item	3507660	et	4	main
tühistamist	doc_491521501878_item	3507662	et	4	main
eesti	doc_491521501878_item	3507663	et	4	main
suhtes	doc_491521501878_item	3507664	et	4	main
mis	doc_491521501878_item	3507665	et	4	main
sisuliselt	doc_491521501878_item	3507666	et	4	main
tähendas	doc_491521501878_item	3507667	et	3	main
et	doc_491521501878_item	3507668	et	3	main
nv	doc_491521501878_item	3507669	et	4	main
oli	doc_491521501878_item	3507670	et	3	main
eesti	doc_491521501878_item	3507671	et	4	main
allutanud	doc_491521501878_item	3507672	et	4	main
ebaseaduslikult	doc_491521501878_item	3507673	et	4	main
ja	doc_491521501878_item	3507674	et	3	main
1991	doc_491521501878_item	3507675	et	2	main
aastal	doc_491521501878_item	3507676	et	3	main
saigi	doc_491521501878_item	3507677	et	4	main
eesti	doc_491521501878_item	3507678	et	4	main
iseseisvaks	doc_491521501878_item	3507679	et	3	main
3	doc_491521501878_item	3507680	et	2	main
a	doc_491521501878_item	3507681	et	4	main
kruusemendi	doc_491521501878_item	3507682	et	4	main
tuntumad	doc_491521501878_item	3507683	et	4	main
filmid	doc_491521501878_item	3507684	et	4	main
nukitsamees	doc_491521501878_item	3507685	et	4	main
kevade	doc_491521501878_item	3507686	et	4	main
69	doc_491521501878_item	3507687	et	2	main
sügis	doc_491521501878_item	3507688	et	3	main
suvi	doc_491521501878_item	3507689	et	3	main
vist	doc_491521501878_item	3507690	et	4	main
oli	doc_491521501878_item	3507691	et	3	main
ka	doc_491521501878_item	3507692	et	3	main
nukufilm	doc_491521501878_item	3507693	et	3	main
operaator	doc_491521501878_item	3507694	et	3	main
kõps	doc_491521501878_item	3507695	et	4	main
vabaks	doc_491521501878_item	3507639	et	3	main
eesti	doc_491521501878_item	3507648	et	4	main
riigi	doc_491521501878_item	3507649	et	3	main
rahvas	doc_491521501878_item	3507658	et	4	main
aastate	doc_491521501880_item	3508118	et	3	main
aima	doc_491521501880_item	3508126	et	4	main
sündmusest	doc_491521501880_item	3508148	et	4	main
kõneldakse	doc_491521501880_item	3508149	et	3	main
toimus	doc_491521501880_item	3508155	et	3	main
see	doc_491521501880_item	3508158	et	3	main
toimus	doc_491521501880_item	3508166	et	3	main
balti	doc_491521501880_item	3508170	et	3	main
osales	doc_491521501880_item	3508180	et	3	main
2	doc_491521501880_item	3508182	et	2	main
1960	doc_491521501880_item	3508217	et	2	main
aru	doc_491521501880_item	3508245	et	4	main
et	doc_491521501880_item	3508246	et	3	main
murdeaasta	doc_491521501880_item	3508254	et	4	main
e	doc_491521501880_item	3508256	et	4	main
liidu	doc_491521501880_item	3508265	et	3	main
hakkab	doc_491521501880_item	3508278	et	3	main
moodustati	doc_491521501880_item	3508287	et	3	main
moskvas	doc_491521501880_item	3508300	et	4	main
eksamitöö	doc_491521501880_item	3508115	et	4	main
ega	doc_491521501880_item	3508129	et	3	main
vahel	doc_491521501880_item	3508136	et	4	main
toompealt	doc_491521501880_item	3508139	et	3	main
kui	doc_491521501880_item	3508140	et	3	main
moskvale	doc_491521501880_item	3508142	et	4	main
sisendab	doc_491521501880_item	3508143	et	3	main
hirmu	doc_491521501880_item	3508144	et	4	main
see	doc_491521501880_item	3508145	et	3	main
ahel	doc_491521501880_item	3508146	et	3	main
millisest	doc_491521501880_item	3508147	et	3	main
see	doc_491521501880_item	3508154	et	3	main
jaoks	doc_491521501880_item	3508161	et	4	main
kett	doc_491521501880_item	3508164	et	4	main
kett	doc_491521501880_item	3508171	et	4	main
leonid	doc_491521501880_item	3508215	et	4	main
üliõpilaste	doc_491521501880_item	3508220	et	4	main
ja	doc_491521501880_item	3508222	et	3	main
mitte	doc_491521501880_item	3508223	et	3	main
ainult	doc_491521501880_item	3508224	et	4	main
eestis	doc_491521501880_item	3508225	et	3	main
inimnäoline	doc_491521501880_item	3508247	et	4	main
dissidentid	doc_491521501880_item	3508255	et	4	main
mõtlejad	doc_491521501880_item	3508258	et	4	main
saadavad	doc_491521501880_item	3508259	et	4	main
läände	doc_491521501880_item	3508260	et	3	main
süsteemi	doc_491521501880_item	3508266	et	4	main
alguses	doc_491521501880_item	3508270	et	4	main
on	doc_491521501880_item	3508274	et	4	main
75	doc_491521501880_item	3508275	et	2	main
1960	doc_491521501880_item	3508276	et	2	main
linnastumisega	doc_491521501880_item	3508282	et	4	main
hääbus	doc_491521501880_item	3508284	et	3	main
majandust	doc_491521501880_item	3508290	et	4	main
juhtis	doc_491521501880_item	3508291	et	3	main
moskva	doc_491521501880_item	3508292	et	4	main
kohalike	doc_491521501880_item	3508301	et	4	main
huvide	doc_491521501880_item	3508302	et	3	main
regioonideks	doc_491521501880_item	3508315	et	3	main
elanikud	doc_491521501880_item	3508318	et	3	main
rohkem	doc_491521501880_item	3508323	et	4	main
kui	doc_491521501880_item	3508324	et	3	main
nl-u	doc_491521501880_item	3508326	et	4	main
elanikud	doc_491521501880_item	3508327	et	3	main
nt	doc_491521501880_item	3508339	et	4	main
horoskoop	doc_491521501880_item	3508340	et	3	main
1965	doc_491521501880_item	3508341	et	2	main
lääne	doc_491521501880_item	3508352	et	4	main
turistide	doc_491521501880_item	3508353	et	3	main
selts	doc_491521501880_item	3508368	et	3	main
tehastega	doc_491521501880_item	3508379	et	3	main
keskkonna	doc_491521501880_item	3508381	et	3	main
aastal	doc_491521501880_item	3508384	et	3	main
mis	doc_491521501880_item	3508388	et	4	main
inimene	doc_491521501880_item	3508391	et	3	main
saama	doc_491521501880_item	3508400	et	4	main
ja	doc_491521501880_item	3508407	et	3	main
elupaika	doc_491521501880_item	3508408	et	4	main
toimub	doc_491521501880_item	3508409	et	3	main
aeglasemalt	doc_491521501880_item	3508415	et	4	main
on	doc_491521501880_item	3508430	et	4	main
1	doc_491521501880_item	3508116	et	2	main
sulaperioodi	doc_491521501880_item	3508120	et	4	main
kultuuri	doc_491521501880_item	3508122	et	4	main
üldiseloomustus	doc_491521501880_item	3508123	et	4	main
2	doc_491521501880_item	3508124	et	2	main
kauge	doc_491521501880_item	3508127	et	4	main
hiina	doc_491521501880_item	3508130	et	3	main
balti	doc_491521501880_item	3508134	et	3	main
aimla	doc_491521501880_item	3508151	et	4	main
ja	doc_491521501880_item	3508156	et	3	main
riikide	doc_491521501880_item	3508160	et	3	main
tähendas	doc_491521501880_item	3508162	et	3	main
balti	doc_491521501880_item	3508163	et	3	main
1989	doc_491521501880_item	3508167	et	2	main
iseseisvuspüüde	doc_491521501880_item	3508179	et	4	main
brežnev	doc_491521501880_item	3508216	et	2	main
ndatel	doc_491521501880_item	3508218	et	4	main
rahutused	doc_491521501880_item	3508221	et	4	main
brežnevi	doc_491521501880_item	3508226	et	2	main
võimule	doc_491521501880_item	3508227	et	3	main
tulekuga	doc_491521501880_item	3508228	et	3	main
hakati	doc_491521501880_item	3508229	et	3	main
kontrollima	doc_491521501880_item	3508230	et	4	main
inimeste	doc_491521501880_item	3508231	et	3	main
aastaid	doc_491521501880_item	3508237	et	4	main
sotsialism	doc_491521501880_item	3508248	et	3	main
on	doc_491521501880_item	3508249	et	4	main
kirja	doc_491521501880_item	3508261	et	4	main
vastane	doc_491521501880_item	3508267	et	3	main
toimuma	doc_491521501880_item	3508279	et	3	main
1960	doc_491521501880_item	3508285	et	2	main
eesti	doc_491521501880_item	3508289	et	4	main
koha	doc_491521501880_item	3508295	et	4	main
eesti	doc_491521501880_item	3508317	et	4	main
käisid	doc_491521501880_item	3508319	et	4	main
kinnos	doc_491521501880_item	3508320	et	4	main
lastele	doc_491521501880_item	3508336	et	4	main
peresaated	doc_491521501880_item	3508337	et	3	main
muusikasaated	doc_491521501880_item	3508338	et	3	main
majanduses	doc_491521501880_item	3508347	et	4	main
on	doc_491521501880_item	3508371	et	4	main
liidu	doc_491521501880_item	3508378	et	3	main
ilmus	doc_491521501880_item	3508385	et	4	main
raamat	doc_491521501880_item	3508387	et	3	main
saavad	doc_491521501880_item	3508405	et	4	main
maal	doc_491521501880_item	3508412	et	4	main
nn	doc_491521501880_item	3508119	et	4	main
eesti	doc_491521501880_item	3508121	et	4	main
korea	doc_491521501880_item	3508128	et	4	main
sest	doc_491521501880_item	3508131	et	4	main
aga	doc_491521501880_item	3508137	et	3	main
nii	doc_491521501880_item	3508138	et	3	main
gediminasest	doc_491521501880_item	3508141	et	4	main
luuletuses	doc_491521501880_item	3508152	et	4	main
millal	doc_491521501880_item	3508153	et	3	main
mida	doc_491521501880_item	3508157	et	4	main
balti	doc_491521501880_item	3508159	et	3	main
aastas	doc_491521501880_item	3508168	et	3	main
äratas	doc_491521501880_item	3508172	et	3	main
kogu	doc_491521501880_item	3508174	et	4	main
maailmas	doc_491521501880_item	3508175	et	3	main
elu	doc_491521501880_item	3508232	et	4	main
tegutseb	doc_491521501880_item	3508233	et	3	main
kgb	doc_491521501880_item	3508234	et	4	main
1960	doc_491521501880_item	3508235	et	2	main
iseloomustab	doc_491521501880_item	3508238	et	4	main
inimnäoline	doc_491521501880_item	3508240	et	4	main
sotsialism	doc_491521501880_item	3508241	et	3	main
ainulttal	doc_491521501880_item	3508242	et	4	main
intelligents	doc_491521501880_item	3508243	et	3	main
saab	doc_491521501880_item	3508244	et	3	main
a	doc_491521501880_item	3508252	et	4	main
oli	doc_491521501880_item	3508253	et	3	main
teisiti	doc_491521501880_item	3508257	et	3	main
1960	doc_491521501880_item	3508268	et	2	main
ndate	doc_491521501880_item	3508269	et	4	main
eestlaste	doc_491521501880_item	3508271	et	4	main
osakaal	doc_491521501880_item	3508272	et	3	main
eestis	doc_491521501880_item	3508273	et	3	main
linnastumine	doc_491521501880_item	3508280	et	4	main
maakultuur	doc_491521501880_item	3508283	et	3	main
kõike	doc_491521501880_item	3508293	et	4	main
peal	doc_491521501880_item	3508296	et	4	main
tehti	doc_491521501880_item	3508297	et	3	main
tuli	doc_491521501880_item	3508298	et	4	main
kinnitada	doc_491521501880_item	3508299	et	3	main
1960	doc_491521501880_item	3508117	et	2	main
ei	doc_491521501880_item	3508125	et	4	main
paelast	doc_491521501880_item	3508132	et	4	main
me	doc_491521501880_item	3508133	et	4	main
pealinnade	doc_491521501880_item	3508135	et	3	main
p	doc_491521501880_item	3508150	et	4	main
mis	doc_491521501880_item	3508165	et	4	main
augustis	doc_491521501880_item	3508169	et	3	main
tähelepanu	doc_491521501880_item	3508173	et	4	main
see	doc_491521501880_item	3508176	et	3	main
oli	doc_491521501880_item	3508177	et	3	main
rahulik	doc_491521501880_item	3508178	et	3	main
umbes	doc_491521501880_item	3508181	et	4	main
milj	doc_491521501880_item	3508183	et	4	main
inimest	doc_491521501880_item	3508184	et	3	main
3	doc_491521501880_item	3508185	et	2	main
nimetage	doc_491521501880_item	3508186	et	3	main
a	doc_491521501880_item	3508187	et	4	main
kruusemendi	doc_491521501880_item	3508188	et	4	main
tuntumaid	doc_491521501880_item	3508189	et	4	main
filme	doc_491521501880_item	3508190	et	3	main
viimne	doc_491521501880_item	3508191	et	3	main
rliikvia	doc_491521501880_item	3508192	et	4	main
filmide	doc_491521501880_item	3508193	et	3	main
sari	doc_491521501880_item	3508194	et	4	main
sügis	doc_491521501880_item	3508195	et	3	main
kevad	doc_491521501880_item	3508196	et	3	main
suvi	doc_491521501880_item	3508197	et	3	main
1	doc_491521501880_item	3508198	et	2	main
1960	doc_491521501880_item	3508199	et	2	main
ndad	doc_491521501880_item	3508200	et	4	main
aastad	doc_491521501880_item	3508201	et	3	main
on	doc_491521501880_item	3508202	et	4	main
nn	doc_491521501880_item	3508203	et	4	main
kuldsed	doc_491521501880_item	3508204	et	3	main
kuuekümnendad	doc_491521501880_item	3508205	et	4	main
kuni	doc_491521501880_item	3508206	et	3	main
aastani	doc_491521501880_item	3508207	et	3	main
1964	doc_491521501880_item	3508208	et	2	main
võimul	doc_491521501880_item	3508209	et	3	main
oli	doc_491521501880_item	3508210	et	3	main
hruštšov	doc_491521501880_item	3508211	et	2	main
ja	doc_491521501880_item	3508212	et	3	main
aastatel	doc_491521501880_item	3508213	et	4	main
1964-1982	doc_491521501880_item	3508214	et	2	main
toimusid	doc_491521501880_item	3508219	et	4	main
ndaid	doc_491521501880_item	3508236	et	4	main
nn	doc_491521501880_item	3508239	et	4	main
võimatu	doc_491521501880_item	3508250	et	4	main
1968	doc_491521501880_item	3508251	et	2	main
mis	doc_491521501880_item	3508262	et	4	main
oli	doc_491521501880_item	3508263	et	3	main
nõukogude	doc_491521501880_item	3508264	et	3	main
ndatel	doc_491521501880_item	3508277	et	4	main
seoses	doc_491521501880_item	3508281	et	4	main
ndatel	doc_491521501880_item	3508286	et	4	main
kolhoose	doc_491521501880_item	3508288	et	3	main
mis	doc_491521501880_item	3508294	et	4	main
ja	doc_491521501880_item	3508303	et	3	main
vajadustega	doc_491521501880_item	3508304	et	3	main
ei	doc_491521501880_item	3508305	et	4	main
arvestatud	doc_491521501880_item	3508306	et	4	main
inimesed	doc_491521501880_item	3508307	et	3	main
üldiselt	doc_491521501880_item	3508308	et	4	main
elasid	doc_491521501880_item	3508309	et	4	main
hästi	doc_491521501880_item	3508310	et	3	main
baltimaad	doc_491521501880_item	3508311	et	4	main
olid	doc_491521501880_item	3508312	et	4	main
kõige	doc_491521501880_item	3508313	et	4	main
edukamateks	doc_491521501880_item	3508314	et	4	main
nl-s	doc_491521501880_item	3508316	et	3	main
teatris	doc_491521501880_item	3508322	et	3	main
teised	doc_491521501880_item	3508325	et	4	main
ilmuvad	doc_491521501880_item	3508333	et	4	main
erinevad	doc_491521501880_item	3508334	et	4	main
telesaated	doc_491521501880_item	3508335	et	3	main
tekib	doc_491521501880_item	3508344	et	3	main
teenindus	doc_491521501880_item	3508348	et	4	main
mis	doc_491521501880_item	3508349	et	4	main
nt	doc_491521501880_item	3508366	et	4	main
arendamisele	doc_491521501880_item	3508374	et	4	main
ja	doc_491521501880_item	3508375	et	3	main
nõukogude	doc_491521501880_item	3508377	et	3	main
1968	doc_491521501880_item	3508383	et	2	main
kui	doc_491521501880_item	3508390	et	3	main
lõpus	doc_491521501880_item	3508397	et	4	main
inimesed	doc_491521501880_item	3508398	et	3	main
hakkavad	doc_491521501880_item	3508399	et	4	main
tööd	doc_491521501880_item	3508406	et	4	main
see	doc_491521501880_item	3508413	et	3	main
toimub	doc_491521501880_item	3508414	et	3	main
kolivad	doc_491521501880_item	3508417	et	4	main
ja	doc_491521501880_item	3508419	et	3	main
tekivad	doc_491521501880_item	3508420	et	3	main
ääremaa	doc_491521501880_item	3508421	et	4	main
probleemid	doc_491521501880_item	3508422	et	3	main
paljud	doc_491521501880_item	3508423	et	3	main
koolid	doc_491521501880_item	3508424	et	3	main
ettevõtte	doc_491521501880_item	3508434	et	4	main
inimesed	doc_491521501880_item	3508436	et	3	main
kõige	doc_491521501880_item	3508467	et	4	main
paremini	doc_491521501880_item	3508468	et	4	main
kasvatatakse	doc_491521501880_item	3508469	et	3	main
loomi	doc_491521501880_item	3508470	et	4	main
1960	doc_491521501880_item	3508471	et	2	main
oli	doc_491521501880_item	3508477	et	3	main
progressiks	doc_491521501880_item	3508478	et	3	main
sel	doc_491521501880_item	3508479	et	3	main
palju	doc_491521501880_item	3508483	et	4	main
keelatuid	doc_491521501880_item	3508484	et	4	main
vene	doc_491521501880_item	3508486	et	4	main
keelne	doc_491521501880_item	3508487	et	3	main
kirjandus	doc_491521501880_item	3508488	et	3	main
oli	doc_491521501880_item	3508489	et	3	main
1960-ndate	doc_491521501880_item	3508328	et	4	main
alguses	doc_491521501880_item	3508329	et	4	main
multifilm	doc_491521501880_item	3508332	et	3	main
eestis	doc_491521501880_item	3508343	et	3	main
suund	doc_491521501880_item	3508346	et	3	main
on	doc_491521501880_item	3508350	et	4	main
seotud	doc_491521501880_item	3508351	et	4	main
vooluga	doc_491521501880_item	3508354	et	4	main
eestlastel	doc_491521501880_item	3508355	et	4	main
tekib	doc_491521501880_item	3508356	et	3	main
võimalus	doc_491521501880_item	3508357	et	3	main
kirjavahetamiseks	doc_491521501880_item	3508358	et	3	main
välismaadega	doc_491521501880_item	3508359	et	3	main
1960	doc_491521501880_item	3508360	et	2	main
ndatel	doc_491521501880_item	3508361	et	4	main
olid	doc_491521501880_item	3508362	et	4	main
populaarsed	doc_491521501880_item	3508363	et	3	main
erinevad	doc_491521501880_item	3508364	et	4	main
seltsid	doc_491521501880_item	3508365	et	4	main
ja	doc_491521501880_item	3508321	et	3	main
tekkis	doc_491521501880_item	3508330	et	3	main
kohalik	doc_491521501880_item	3508331	et	3	main
aastast	doc_491521501880_item	3508342	et	4	main
uus	doc_491521501880_item	3508345	et	3	main
kollektsionääride	doc_491521501880_item	3508367	et	3	main
eesti	doc_491521501880_item	3508369	et	4	main
majandus	doc_491521501880_item	3508370	et	4	main
seosed	doc_491521501880_item	3508376	et	3	main
algas	doc_491521501880_item	3508380	et	3	main
saastumine	doc_491521501880_item	3508382	et	4	main
üks	doc_491521501880_item	3508386	et	3	main
looduse	doc_491521501880_item	3508393	et	4	main
saastumist	doc_491521501880_item	3508394	et	4	main
1960	doc_491521501880_item	3508395	et	2	main
individuaalelamud	doc_491521501880_item	3508401	et	3	main
palju	doc_491521501880_item	3508402	et	4	main
sisserännanuid	doc_491521501880_item	3508403	et	3	main
hoonete	doc_491521501880_item	3508410	et	4	main
piirkonnas	doc_491521501880_item	3508429	et	4	main
töötavad	doc_491521501880_item	3508437	et	4	main
ndatel	doc_491521501880_item	3508472	et	4	main
tuleb	doc_491521501880_item	3508473	et	3	main
ajal	doc_491521501880_item	3508480	et	4	main
tsenseeritud	doc_491521501880_item	3508491	et	4	main
esimest	doc_491521501786_item	3508802	et	4	main
rahaliselt	doc_491521501786_item	3508805	et	4	main
toetamast	doc_491521501786_item	3508806	et	3	main
õigustades	doc_491521501786_item	3508807	et	3	main
ta	doc_491521501786_item	3508811	et	4	main
olevat	doc_491521501786_item	3508812	et	4	main
keele	doc_491521501786_item	3508821	et	4	main
koolides	doc_491521501786_item	3508822	et	3	main
vastu	doc_491521501786_item	3508824	et	3	main
kaasagi	doc_491521501786_item	3508834	et	4	main
ta	doc_491521501786_item	3508837	et	4	main
mõtted	doc_491521501786_item	3508839	et	3	main
kevadel	doc_491521501786_item	3508842	et	4	main
avalikult	doc_491521501786_item	3508843	et	4	main
välja	doc_491521501786_item	3508844	et	4	main
purskas	doc_491521501786_item	3508845	et	3	main
provotseeris	doc_491521501786_item	3508846	et	3	main
mõningaid	doc_491521501786_item	3508854	et	3	main
avati	doc_491521501786_item	3508859	et	3	main
piiritletud	doc_491521501786_item	3508864	et	4	main
1990	doc_491521501786_item	3508868	et	2	main
a	doc_491521501786_item	3508869	et	4	main
oli	doc_491521501786_item	3508877	et	3	main
suunatud	doc_491521501880_item	3508372	et	4	main
rasketööstuse	doc_491521501880_item	3508373	et	3	main
juhtub	doc_491521501880_item	3508389	et	3	main
jatkab	doc_491521501880_item	3508392	et	4	main
ndate	doc_491521501880_item	3508396	et	4	main
kes	doc_491521501880_item	3508404	et	4	main
elektrifitseerimine	doc_491521501880_item	3508411	et	4	main
inimesed	doc_491521501880_item	3508416	et	3	main
linna	doc_491521501880_item	3508418	et	4	main
maal	doc_491521501880_item	3508426	et	4	main
kus	doc_491521501880_item	3508435	et	3	main
mis	doc_491521501880_item	3508476	et	4	main
kirjanikke	doc_491521501880_item	3508485	et	3	main
seas	doc_491521501880_item	3508493	et	4	main
oli	doc_491521501880_item	3508494	et	3	main
väga	doc_491521501880_item	3508495	et	3	main
oskus	doc_491521501880_item	3508499	et	3	main
sel	doc_491521501880_item	3508502	et	3	main
suletakse	doc_491521501880_item	3508425	et	4	main
ühes	doc_491521501880_item	3508427	et	4	main
suures	doc_491521501880_item	3508428	et	3	main
maksimaalselt	doc_491521501880_item	3508431	et	4	main
üks	doc_491521501880_item	3508432	et	3	main
tööstuslik	doc_491521501880_item	3508433	et	3	main
sõltuvad	doc_491521501880_item	3508439	et	4	main
sellest	doc_491521501880_item	3508440	et	4	main
eestis	doc_491521501880_item	3508441	et	3	main
on	doc_491521501880_item	3508442	et	4	main
väga	doc_491521501880_item	3508443	et	3	main
hea	doc_491521501880_item	3508444	et	4	main
loomakasvatus	doc_491521501880_item	3508445	et	4	main
kõige	doc_491521501880_item	3508446	et	4	main
tehnilisem	doc_491521501880_item	3508447	et	4	main
oli	doc_491521501880_item	3508448	et	3	main
linnukasvatus	doc_491521501880_item	3508449	et	4	main
teisel	doc_491521501880_item	3508450	et	4	main
kohal	doc_491521501880_item	3508451	et	4	main
oli	doc_491521501880_item	3508452	et	3	main
piimakarjakasvatus	doc_491521501880_item	3508453	et	4	main
ja	doc_491521501880_item	3508454	et	3	main
kolmandal	doc_491521501880_item	3508455	et	3	main
kohal	doc_491521501880_item	3508456	et	4	main
seakasvatus	doc_491521501880_item	3508457	et	4	main
30	doc_491521501880_item	3508458	et	2	main
toidukasvatus	doc_491521501880_item	3508459	et	4	main
ja	doc_491521501880_item	3508460	et	3	main
70	doc_491521501880_item	3508461	et	2	main
loomakasvatus	doc_491521501880_item	3508462	et	4	main
jakobson	doc_491521501880_item	3508463	et	4	main
ütles	doc_491521501880_item	3508464	et	3	main
ja	doc_491521501880_item	3508438	et	3	main
et	doc_491521501880_item	3508465	et	3	main
kasutusele	doc_491521501880_item	3508474	et	4	main
vähem	doc_491521501880_item	3508490	et	4	main
vene	doc_491521501880_item	3508497	et	4	main
suurem	doc_491521501880_item	3508513	et	4	main
eestis	doc_491521501880_item	3508466	et	3	main
arvutitehnika	doc_491521501880_item	3508475	et	4	main
kirjanduselus	doc_491521501880_item	3508481	et	4	main
oli	doc_491521501880_item	3508482	et	3	main
eestlaste	doc_491521501880_item	3508492	et	4	main
keele	doc_491521501880_item	3508498	et	4	main
võrrelda	doc_491521501880_item	3508501	et	4	main
vaatamata	doc_491521501880_item	3508514	et	4	main
nõukogude	doc_491521501880_item	3508515	et	3	main
liidu	doc_491521501880_item	3508516	et	3	main
utopistliku	doc_491521501880_item	3508517	et	3	main
poliitikale	doc_491521501880_item	3508518	et	3	main
inimesed	doc_491521501880_item	3508519	et	3	main
elasid	doc_491521501880_item	3508520	et	4	main
nendel	doc_491521501880_item	3508521	et	4	main
aastatel	doc_491521501880_item	3508522	et	4	main
üsna	doc_491521501880_item	3508523	et	3	main
hästi	doc_491521501880_item	3508524	et	3	main
sest	doc_491521501880_item	3508525	et	4	main
kõikidel	doc_491521501880_item	3508526	et	4	main
oli	doc_491521501880_item	3508527	et	3	main
töö	doc_491521501880_item	3508528	et	4	main
elamiskoht	doc_491521501880_item	3508529	et	3	main
võimalus	doc_491521501880_item	3508530	et	3	main
kultuuriliseks	doc_491521501880_item	3508531	et	4	main
ajaviiteks	doc_491521501880_item	3508532	et	3	main
keeldus	doc_491521501786_item	3508801	et	3	main
moksaersa	doc_491521501786_item	3508820	et	4	main
kasutamisele	doc_491521501786_item	3508823	et	4	main
hea	doc_491521501880_item	3508496	et	4	main
kui	doc_491521501880_item	3508500	et	3	main
ajal	doc_491521501880_item	3508503	et	4	main
linna	doc_491521501880_item	3508504	et	4	main
inimeste	doc_491521501880_item	3508505	et	3	main
ja	doc_491521501880_item	3508506	et	3	main
põllumeeste	doc_491521501880_item	3508507	et	4	main
palk	doc_491521501880_item	3508508	et	3	main
siis	doc_491521501880_item	3508509	et	3	main
viimaste	doc_491521501880_item	3508510	et	3	main
palk	doc_491521501880_item	3508511	et	3	main
oli	doc_491521501880_item	3508512	et	3	main
seminaritöö	doc_491521501786_item	3508798	et	4	main
moksaersa	doc_491521501786_item	3508803	et	4	main
kõigi	doc_491521501786_item	3508813	et	4	main
keeliks	doc_491521501786_item	3508829	et	4	main
ta	doc_491521501786_item	3508847	et	4	main
sellega	doc_491521501786_item	3508848	et	3	main
nädalapikkuse	doc_491521501786_item	3508849	et	2	main
järelandmisi	doc_491521501786_item	3508855	et	2	main
ülikoolis	doc_491521501786_item	3508858	et	4	main
soomeugri	doc_491521501786_item	3508860	et	4	main
osakond	doc_491521501786_item	3508861	et	3	main
telesaated	doc_491521501786_item	3508872	et	3	main
kaks	doc_491521501786_item	3508873	et	3	main
tundi	doc_491521501786_item	3508874	et	4	main
nädalas	doc_491521501786_item	3508875	et	3	main
raadiosaateid	doc_491521501786_item	3508876	et	3	main
15	doc_491521501786_item	3508878	et	2	main
kavandati	doc_491521501786_item	3508904	et	3	main
õpet	doc_491521501786_item	3508908	et	2	main
fenno-ugria	doc_491521501786_item	3508909	et	4	main
nr	doc_491521501786_item	3508911	et	4	main
1995	doc_491521501786_item	3508913	et	2	main
lk	doc_491521501786_item	3508914	et	4	main
6	doc_491521501786_item	3508915	et	2	main
kultuurialased	doc_491521501786_item	3508933	et	4	main
pooleks	doc_491521501786_item	3508940	et	4	main
osa	doc_491521501786_item	3508952	et	4	main
osa	doc_491521501786_item	3508959	et	4	main
sest	doc_491521501786_item	3508960	et	4	main
nende	doc_491521501786_item	3508961	et	4	main
kultuurivajaduste	doc_491521501786_item	3508969	et	4	main
oli	doc_491521501786_item	3508973	et	3	main
mokserslased	doc_491521501786_item	3508978	et	4	main
ülemnõukogus	doc_491521501786_item	3508980	et	2	main
esindatud	doc_491521501786_item	3508982	et	4	main
ja	doc_491521501786_item	3509009	et	3	main
millele	doc_491521501786_item	3509011	et	3	main
reaktsionäär	doc_491521501786_item	3508799	et	2	main
mordva	doc_491521501786_item	3508814	et	3	main
elanike	doc_491521501786_item	3508815	et	3	main
president	doc_491521501786_item	3508816	et	3	main
tema	doc_491521501786_item	3508817	et	4	main
haridusminister	doc_491521501786_item	3508818	et	3	main
pidas	doc_491521501786_item	3508826	et	3	main
neid	doc_491521501786_item	3508827	et	4	main
surevaiks	doc_491521501786_item	3508828	et	4	main
ise	doc_491521501786_item	3508833	et	4	main
streigi	doc_491521501786_item	3508851	et	4	main
salo	doc_491521501786_item	3508852	et	4	main
1993	doc_491521501786_item	3508853	et	2	main
lisaks	doc_491521501786_item	3508862	et	4	main
moordva	doc_491521501786_item	3508865	et	4	main
keelte	doc_491521501786_item	3508866	et	3	main
omale	doc_491521501786_item	3508867	et	3	main
2000	doc_491521501786_item	3508903	et	2	main
3	doc_491521501786_item	3508912	et	2	main
ainult	doc_491521501786_item	3508923	et	4	main
esimeses	doc_491521501786_item	3508924	et	3	main
neljas	doc_491521501786_item	3508925	et	4	main
klassis	doc_491521501786_item	3508926	et	3	main
see	doc_491521501786_item	3508927	et	3	main
mordva	doc_491521501786_item	3508928	et	3	main
riiklik	doc_491521501786_item	3508929	et	3	main
üritused	doc_491521501786_item	3508934	et	4	main
moksad	doc_491521501786_item	3508941	et	4	main
sest	doc_491521501786_item	3508946	et	4	main
neid	doc_491521501786_item	3508947	et	4	main
elab	doc_491521501786_item	3508948	et	3	main
vabariigis	doc_491521501786_item	3508949	et	3	main
suuremat	doc_491521501786_item	3508958	et	4	main
eest	doc_491521501786_item	3508970	et	4	main
aga	doc_491521501786_item	3508972	et	3	main
mordva	doc_491521501786_item	3508979	et	3	main
põhiseadus	doc_491521501786_item	3509014	et	4	main
põlisrahva	doc_491521501786_item	3509016	et	3	main
põhiseadusist	doc_491521501786_item	3509024	et	2	main
selle	doc_491521501786_item	3509037	et	4	main
praktilisi	doc_491521501786_item	3509038	et	3	main
rein	doc_491521501786_item	3509046	et	4	main
rahvad	doc_491521501786_item	3509049	et	3	main
föderatsioonis	doc_491521501786_item	3509051	et	2	main
2	doc_491521501786_item	3509052	et	2	main
künnap	doc_491521501786_item	3509053	et	2	main
ago	doc_491521501786_item	3509054	et	2	main
venemaa	doc_491521501786_item	3509050	et	4	main
ja	doc_491521501786_item	3509055	et	3	main
palmeos	doc_491521501786_item	3509056	et	4	main
paula	doc_491521501786_item	3509057	et	4	main
ja	doc_491521501786_item	3509058	et	3	main
seilenthal	doc_491521501786_item	3509059	et	4	main
tõnu	doc_491521501786_item	3509060	et	4	main
1974	doc_491521501786_item	3509061	et	2	main
põhja	doc_491521501786_item	3509062	et	4	main
ja	doc_491521501786_item	3509063	et	3	main
itta	doc_491521501786_item	3509064	et	3	main
3	doc_491521501786_item	3509065	et	2	main
interneti	doc_491521501786_item	3509066	et	4	main
allikad	doc_491521501786_item	3509067	et	3	main
httpwwwerziasaranskru	doc_491521501786_item	3509068	et	2	main
httpwww-a-olkloreee	doc_491521501786_item	3509069	et	2	main
ta	doc_491521501786_item	3508800	et	4	main
rahvuskongressi	doc_491521501786_item	3508804	et	4	main
seda	doc_491521501786_item	3508808	et	3	main
väitega	doc_491521501786_item	3508809	et	3	main
et	doc_491521501786_item	3508810	et	3	main
oli	doc_491521501786_item	3508819	et	3	main
ilmselt	doc_491521501786_item	3508830	et	4	main
püüdis	doc_491521501786_item	3508831	et	3	main
aidata	doc_491521501786_item	3508835	et	4	main
1992	doc_491521501786_item	3508840	et	2	main
üliõpilaste	doc_491521501786_item	3508850	et	4	main
põliskultuurile	doc_491521501786_item	3508856	et	2	main
algasid	doc_491521501786_item	3508870	et	4	main
minutit	doc_491521501786_item	3508879	et	3	main
päevas	doc_491521501786_item	3508880	et	3	main
prozes	doc_491521501786_item	3508881	et	4	main
saranskis	doc_491521501786_item	3508883	et	4	main
kus	doc_491521501786_item	3508884	et	3	main
moksersa	doc_491521501786_item	3508885	et	4	main
osakaal	doc_491521501786_item	3508886	et	3	main
1995c	doc_491521501786_item	3508882	et	4	main
oli	doc_491521501786_item	3508887	et	3	main
liigi	doc_491521501786_item	3508888	et	4	main
20	doc_491521501786_item	3508889	et	2	main
märkas	doc_491521501786_item	3508890	et	3	main
as	doc_491521501786_item	3508891	et	4	main
külastaja	doc_491521501786_item	3508892	et	2	main
1995	doc_491521501786_item	3508893	et	2	main
a	doc_491521501786_item	3508894	et	4	main
ainult	doc_491521501786_item	3508895	et	4	main
kaks	doc_491521501786_item	3508896	et	3	main
põliskeelset	doc_491521501786_item	3508897	et	2	main
aastaks	doc_491521501786_item	3508902	et	4	main
ersakeelset	doc_491521501786_item	3508906	et	4	main
moksaersakeelne	doc_491521501786_item	3508920	et	4	main
õpe	doc_491521501786_item	3508921	et	3	main
mida	doc_491521501786_item	3508931	et	4	main
harilikult	doc_491521501786_item	3508937	et	4	main
kahe	doc_491521501786_item	3508938	et	3	main
keeleharu	doc_491521501786_item	3508939	et	4	main
pisut	doc_491521501786_item	3508950	et	3	main
arvukamalt	doc_491521501786_item	3508951	et	4	main
selgesti	doc_491521501786_item	3508957	et	3	main
meelest	doc_491521501786_item	3508962	et	4	main
rahvus	doc_491521501786_item	3508964	et	3	main
vabariik	doc_491521501786_item	3508965	et	3	main
ka	doc_491521501786_item	3508966	et	3	main
suure	doc_491521501786_item	3508967	et	3	main
diasporaa	doc_491521501786_item	3508968	et	4	main
diasporaa	doc_491521501786_item	3508971	et	4	main
valdavalt	doc_491521501786_item	3508974	et	4	main
ersalik	doc_491521501786_item	3508975	et	4	main
ülegi	doc_491521501786_item	3508981	et	2	main
hümni	doc_491521501786_item	3509008	et	4	main
järgnes	doc_491521501786_item	3509012	et	3	main
21091995	doc_491521501786_item	3509015	et	2	main
poolest	doc_491521501786_item	3509018	et	4	main
oli	doc_491521501786_item	3509019	et	3	main
see	doc_491521501786_item	3509020	et	3	main
kõigist	doc_491521501786_item	3509021	et	4	main
kuna	doc_491521501786_item	3508825	et	3	main
ennestusele	doc_491521501786_item	3508832	et	4	main
kui	doc_491521501786_item	3508836	et	3	main
säärased	doc_491521501786_item	3508838	et	3	main
a	doc_491521501786_item	3508841	et	4	main
tehti	doc_491521501786_item	3508857	et	3	main
kitsamalt	doc_491521501786_item	3508863	et	4	main
moksersa	doc_491521501786_item	3508871	et	4	main
silti	doc_491521501786_item	3508898	et	4	main
ja	doc_491521501786_item	3508900	et	3	main
keskastme	doc_491521501786_item	3508907	et	3	main
lubatud	doc_491521501786_item	3508922	et	4	main
moksersa	doc_491521501786_item	3508932	et	4	main
natuke	doc_491521501786_item	3508943	et	4	main
erslasi	doc_491521501786_item	3508953	et	4	main
aga	doc_491521501786_item	3508954	et	3	main
nõudis	doc_491521501786_item	3508955	et	3	main
vastutas	doc_491521501786_item	3508963	et	3	main
ilid	doc_491521501786_item	3508977	et	4	main
mordviinidest	doc_491521501786_item	3508998	et	2	main
kevadel	doc_491521501786_item	3508999	et	4	main
võttis	doc_491521501786_item	3509001	et	3	main
1995	doc_491521501786_item	3509000	et	2	main
mordva	doc_491521501786_item	3509002	et	3	main
ülemnoukogu	doc_491521501786_item	3509003	et	2	main
viimaks	doc_491521501786_item	3509004	et	4	main
vastu	doc_491521501786_item	3509005	et	3	main
uue	doc_491521501786_item	3509006	et	3	main
lipu	doc_491521501786_item	3509007	et	3	main
leiv	doc_491521501786_item	3508899	et	4	main
matuseburöö	doc_491521501786_item	3508901	et	2	main
pisut	doc_491521501786_item	3508905	et	3	main
infoleht	doc_491521501786_item	3508910	et	3	main
kuid	doc_491521501786_item	3508916	et	4	main
1995	doc_491521501786_item	3508917	et	2	main
oli	doc_491521501786_item	3508918	et	3	main
täielik	doc_491521501786_item	3508919	et	3	main
toetus	doc_491521501786_item	3508930	et	4	main
said	doc_491521501786_item	3508935	et	4	main
jagati	doc_491521501786_item	3508936	et	3	main
võiksid	doc_491521501786_item	3508942	et	4	main
rohkem	doc_491521501786_item	3508944	et	4	main
nõuda	doc_491521501786_item	3508945	et	3	main
väga	doc_491521501786_item	3508956	et	3	main
vormiliselt	doc_491521501786_item	3508976	et	4	main
30	doc_491521501786_item	3508983	et	2	main
1iiget	doc_491521501786_item	3508984	et	2	main
70st	doc_491521501786_item	3508985	et	3	main
samuti	doc_491521501786_item	3508986	et	3	main
valitsuses	doc_491521501786_item	3508987	et	4	main
1994	doc_491521501786_item	3508988	et	2	main
a	doc_491521501786_item	3508989	et	4	main
50	doc_491521501786_item	3508990	et	2	main
aga	doc_491521501786_item	3508992	et	3	main
see	doc_491521501786_item	3508991	et	3	main
johtus	doc_491521501786_item	3508993	et	3	main
suure	doc_491521501786_item	3508995	et	3	main
hulga	doc_491521501786_item	3508996	et	4	main
denatsionaliseeritud	doc_491521501786_item	3508997	et	2	main
osalt	doc_491521501786_item	3508994	et	4	main
vapi	doc_491521501786_item	3509010	et	3	main
uus	doc_491521501786_item	3509013	et	3	main
õiguste	doc_491521501786_item	3509017	et	4	main
nõrgim	doc_491521501786_item	3509025	et	2	main
moksa	doc_491521501786_item	3509028	et	4	main
kuulutati	doc_491521501786_item	3509030	et	4	main
koos	doc_491521501786_item	3509032	et	4	main
täpsustatud	doc_491521501786_item	3509041	et	2	main
2000	doc_491521501786_item	3509047	et	2	main
soomeugri	doc_491521501786_item	3509022	et	4	main
ersa	doc_491521501786_item	3509026	et	4	main
ja	doc_491521501786_item	3509027	et	3	main
keeled	doc_491521501786_item	3509029	et	3	main
järeldusi	doc_491521501786_item	3509039	et	4	main
ei	doc_491521501786_item	3509040	et	4	main
kasutatud	doc_491521501786_item	3509042	et	4	main
kirjandus	doc_491521501786_item	3509043	et	3	main
1	doc_491521501786_item	3509044	et	2	main
ühineb	doc_491521501785_item	3509373	et	3	main
rahvast	doc_491521501785_item	3509377	et	4	main
moksad	doc_491521501785_item	3509383	et	4	main
ühe	doc_491521501785_item	3509390	et	4	main
rahvas	doc_491521501785_item	3509400	et	4	main
omanäolise	doc_491521501785_item	3509409	et	2	main
üle	doc_491521501785_item	3509420	et	3	main
elab	doc_491521501785_item	3509422	et	3	main
mordvamaal	doc_491521501785_item	3509424	et	4	main
kolmandik	doc_491521501785_item	3509426	et	3	main
kõrvuti	doc_491521501785_item	3509427	et	3	main
venelaste	doc_491521501785_item	3509428	et	4	main
ning	doc_491521501785_item	3509432	et	3	main
keeleteadlased	doc_491521501785_item	3509433	et	3	main
ersasid	doc_491521501785_item	3509435	et	4	main
koos	doc_491521501785_item	3509436	et	4	main
vabariige	doc_491521501786_item	3509023	et	4	main
kill	doc_491521501786_item	3509031	et	3	main
vene	doc_491521501786_item	3509033	et	4	main
keelega	doc_491521501786_item	3509034	et	3	main
riigikeelteks	doc_491521501786_item	3509035	et	3	main
ent	doc_491521501786_item	3509036	et	3	main
taagepera	doc_491521501786_item	3509045	et	4	main
soomeugri	doc_491521501786_item	3509048	et	4	main
eessõna	doc_491521501785_item	3509370	et	4	main
kaks	doc_491521501785_item	3509375	et	3	main
on	doc_491521501785_item	3509389	et	4	main
kahe	doc_491521501785_item	3509393	et	3	main
kes	doc_491521501785_item	3509401	et	4	main
kilomeetri	doc_491521501785_item	3509414	et	4	main
kaugusel	doc_491521501785_item	3509415	et	4	main
kuigi	doc_491521501785_item	3509416	et	3	main
neist	doc_491521501785_item	3509423	et	4	main
moksadega	doc_491521501785_item	3509437	et	4	main
eri	doc_491521501785_item	3509473	et	4	main
rahvasteks	doc_491521501785_item	3509474	et	4	main
bütsantsi	doc_491521501785_item	3509485	et	2	main
keiser	doc_491521501785_item	3509486	et	3	main
rahvas	doc_491521501785_item	3509372	et	4	main
suuga	doc_491521501785_item	3509394	et	3	main
mordvalased	doc_491521501785_item	3509396	et	3	main
läänepoolseim	doc_491521501785_item	3509398	et	2	main
volgasoome	doc_491521501785_item	3509399	et	4	main
moskvast	doc_491521501785_item	3509411	et	4	main
vaevalt	doc_491521501785_item	3509412	et	4	main
küünib	doc_491521501785_item	3509419	et	2	main
end	doc_491521501785_item	3509472	et	4	main
mordvalasi	doc_491521501785_item	3509475	et	3	main
mainib	doc_491521501785_item	3509476	et	3	main
kroonikais	doc_491521501785_item	3509494	et	4	main
esineb	doc_491521501785_item	3509495	et	3	main
see	doc_491521501785_item	3509496	et	3	main
nimetavad	doc_491521501785_item	3509504	et	4	main
föderatsioonis	doc_491521501785_item	3509519	et	2	main
ja	doc_491521501785_item	3509520	et	3	main
ainult	doc_491521501785_item	3509521	et	4	main
160	doc_491521501785_item	3509522	et	2	main
elavad	doc_491521501785_item	3509533	et	4	main
sajandist	doc_491521501785_item	3509540	et	3	main
arsaija	doc_491521501785_item	3509546	et	4	main
kujul	doc_491521501785_item	3509547	et	4	main
moksad	doc_491521501785_item	3509548	et	4	main
nimetab	doc_491521501785_item	3509549	et	3	main
keelt	doc_491521501785_item	3509556	et	4	main
moksan	doc_491521501785_item	3509563	et	4	main
keele	doc_491521501785_item	3509566	et	4	main
vanimad	doc_491521501785_item	3509567	et	3	main
seminaritöö	doc_491521501785_item	3509369	et	4	main
ersad	doc_491521501785_item	3509381	et	4	main
ja	doc_491521501785_item	3509382	et	3	main
ütlevad	doc_491521501785_item	3509384	et	4	main
enda	doc_491521501785_item	3509385	et	4	main
kohta	doc_491521501785_item	3509386	et	4	main
et	doc_491521501785_item	3509387	et	3	main
nad	doc_491521501785_item	3509388	et	3	main
kuid	doc_491521501785_item	3509392	et	4	main
on	doc_491521501785_item	3509397	et	4	main
on	doc_491521501785_item	3509402	et	4	main
suutnud	doc_491521501785_item	3509403	et	4	main
püsida	doc_491521501785_item	3509404	et	3	main
säilitada	doc_491521501785_item	3509405	et	3	main
pooletuhande	doc_491521501785_item	3509413	et	4	main
rahvaarv	doc_491521501785_item	3509418	et	3	main
tatarlastega	doc_491521501785_item	3509430	et	3	main
naabrid	doc_491521501785_item	3509431	et	3	main
nimetavad	doc_491521501785_item	3509434	et	4	main
peavad	doc_491521501785_item	3509471	et	4	main
esimesena	doc_491521501785_item	3509477	et	3	main
sajandil	doc_491521501785_item	3509480	et	3	main
nimega	doc_491521501785_item	3509481	et	3	main
mordens	doc_491521501785_item	3509482	et	4	main
hiljem	doc_491521501785_item	3509483	et	3	main
nimetab	doc_491521501785_item	3509484	et	3	main
mordvalaste	doc_491521501785_item	3509490	et	3	main
maad	doc_491521501785_item	3509491	et	4	main
mordvalased	doc_491521501785_item	3509498	et	3	main
seda	doc_491521501785_item	3509500	et	3	main
ei	doc_491521501785_item	3509501	et	4	main
kasuta	doc_491521501785_item	3509502	et	4	main
ühed	doc_491521501785_item	3509503	et	3	main
teised	doc_491521501785_item	3509507	et	4	main
on	doc_491521501785_item	3509510	et	4	main
umbes	doc_491521501785_item	3509511	et	4	main
23	doc_491521501785_item	3509512	et	2	main
mordvalastest	doc_491521501785_item	3509513	et	3	main
umbes	doc_491521501785_item	3509514	et	4	main
vene	doc_491521501785_item	3509518	et	4	main
mordovias	doc_491521501785_item	3509525	et	4	main
on	doc_491521501785_item	3509527	et	4	main
tuhad	doc_491521501785_item	3509529	et	3	main
millest	doc_491521501785_item	3509530	et	3	main
vabariigis	doc_491521501785_item	3509535	et	3	main
10	doc_491521501785_item	3509539	et	2	main
segeli	doc_491521501785_item	3509542	et	4	main
kutsuvad	doc_491521501785_item	3509557	et	4	main
mordvalased	doc_491521501785_item	3509558	et	3	main
vastavalt	doc_491521501785_item	3509559	et	4	main
tolketeosed	doc_491521501785_item	3509575	et	4	main
kaks	doc_491521501785_item	3509583	et	3	main
tähestiku	doc_491521501785_item	3509585	et	3	main
alusel	doc_491521501785_item	3509586	et	4	main
järgmise	doc_491521501785_item	3509614	et	3	main
eestikeelse	doc_491521501785_item	3509615	et	3	main
nüüd	doc_491521501785_item	3509630	et	4	main
kodus	doc_491521501785_item	3509631	et	4	main
oli	doc_491521501785_item	3509636	et	3	main
vaja	doc_491521501785_item	3509637	et	4	main
naised	doc_491521501785_item	3509644	et	3	main
inimestel	doc_491521501785_item	3509648	et	3	main
rasked	doc_491521501785_item	3509655	et	3	main
mordva	doc_491521501785_item	3509371	et	3	main
ennas	doc_491521501785_item	3509374	et	4	main
era	doc_491521501785_item	3509376	et	4	main
ersa	doc_491521501785_item	3509378	et	4	main
ja	doc_491521501785_item	3509379	et	3	main
moksa	doc_491521501785_item	3509380	et	4	main
peaga	doc_491521501785_item	3509391	et	3	main
rahvas	doc_491521501785_item	3509395	et	4	main
oma	doc_491521501785_item	3509406	et	4	main
keeled	doc_491521501785_item	3509407	et	3	main
ja	doc_491521501785_item	3509408	et	3	main
kultuuri	doc_491521501785_item	3509410	et	4	main
mordvalaste	doc_491521501785_item	3509417	et	3	main
miljoni	doc_491521501785_item	3509421	et	3	main
vaid	doc_491521501785_item	3509425	et	3	main
ja	doc_491521501785_item	3509429	et	3	main
mordvalasteks	doc_491521501785_item	3509438	et	3	main
pole	doc_491521501785_item	3509439	et	3	main
teada	doc_491521501785_item	3509440	et	3	main
kas	doc_491521501785_item	3509441	et	3	main
need	doc_491521501785_item	3509442	et	3	main
kaks	doc_491521501785_item	3509443	et	3	main
lahedast	doc_491521501785_item	3509444	et	3	main
keelt	doc_491521501785_item	3509445	et	4	main
ja	doc_491521501785_item	3509446	et	3	main
kultuuri	doc_491521501785_item	3509447	et	4	main
üldse	doc_491521501785_item	3509448	et	3	main
on	doc_491521501785_item	3509449	et	4	main
kunagi	doc_491521501785_item	3509450	et	3	main
üks	doc_491521501785_item	3509451	et	3	main
olnud	doc_491521501785_item	3509452	et	4	main
ja	doc_491521501785_item	3509453	et	3	main
millal	doc_491521501785_item	3509454	et	3	main
nad	doc_491521501785_item	3509455	et	3	main
teineteist	doc_491521501785_item	3509456	et	4	main
lahknesid	doc_491521501785_item	3509457	et	4	main
ersad	doc_491521501785_item	3509458	et	4	main
ja	doc_491521501785_item	3509459	et	3	main
moksad	doc_491521501785_item	3509460	et	4	main
ise	doc_491521501785_item	3509461	et	4	main
ei	doc_491521501785_item	3509462	et	4	main
ole	doc_491521501785_item	3509463	et	4	main
mordva	doc_491521501785_item	3509464	et	3	main
nimetust	doc_491521501785_item	3509465	et	4	main
tänapäevani	doc_491521501785_item	3509466	et	3	main
oma	doc_491521501785_item	3509467	et	4	main
keelepruuki	doc_491521501785_item	3509468	et	4	main
võtnud	doc_491521501785_item	3509469	et	4	main
7	doc_491521501785_item	3509488	et	2	main
kujul	doc_491521501785_item	3509497	et	4	main
million	doc_491521501785_item	3509515	et	4	main
ning	doc_491521501785_item	3509470	et	3	main
jordanis	doc_491521501785_item	3509478	et	4	main
kuuendal	doc_491521501785_item	3509479	et	3	main
porphyrogennetor	doc_491521501785_item	3509489	et	4	main
mordia	doc_491521501785_item	3509492	et	4	main
vene	doc_491521501785_item	3509493	et	4	main
ise	doc_491521501785_item	3509499	et	4	main
ersa	doc_491521501785_item	3509506	et	4	main
ersalasi	doc_491521501785_item	3509509	et	4	main
elavad	doc_491521501785_item	3509517	et	4	main
etnonüümi	doc_491521501785_item	3509536	et	2	main
ersa	doc_491521501785_item	3509537	et	4	main
ardani	doc_491521501785_item	3509545	et	4	main
moxel	doc_491521501785_item	3509554	et	4	main
erzan	doc_491521501785_item	3509560	et	4	main
mälestised	doc_491521501785_item	3509568	et	2	main
sajandist	doc_491521501785_item	3509571	et	3	main
vaimulikud	doc_491521501785_item	3509574	et	3	main
vene	doc_491521501785_item	3509584	et	4	main
ersa	doc_491521501785_item	3509589	et	4	main
teksti	doc_491521501785_item	3509616	et	4	main
tõlked	doc_491521501785_item	3509617	et	3	main
ersa	doc_491521501785_item	3509618	et	4	main
keelte	doc_491521501785_item	3509619	et	3	main
keelte	doc_491521501785_item	3509622	et	3	main
käsitsi	doc_491521501785_item	3509638	et	3	main
ketrasid	doc_491521501785_item	3509645	et	4	main
aega	doc_491521501785_item	3509650	et	4	main
nüüd	doc_491521501785_item	3509652	et	4	main
teevad	doc_491521501785_item	3509653	et	3	main
tööd	doc_491521501785_item	3509656	et	4	main
inimestel	doc_491521501785_item	3509657	et	3	main
on	doc_491521501785_item	3509658	et	4	main
jääb	doc_491521501785_item	3509662	et	3	main
konstantinos	doc_491521501785_item	3509487	et	4	main
end	doc_491521501785_item	3509505	et	4	main
moksa	doc_491521501785_item	3509508	et	4	main
ersad	doc_491521501785_item	3509516	et	4	main
elavad	doc_491521501785_item	3509524	et	4	main
mordva	doc_491521501785_item	3509534	et	3	main
mainitakse	doc_491521501785_item	3509538	et	3	main
alates	doc_491521501785_item	3509541	et	3	main
araabia	doc_491521501785_item	3509543	et	4	main
allikais	doc_491521501785_item	3509544	et	4	main
oma	doc_491521501785_item	3509555	et	4	main
kel	doc_491521501785_item	3509561	et	3	main
ja	doc_491521501785_item	3509562	et	3	main
ersa	doc_491521501785_item	3509565	et	4	main
on	doc_491521501785_item	3509581	et	4	main
mordvalastel	doc_491521501785_item	3509582	et	3	main
moksa	doc_491521501785_item	3509621	et	4	main
enne	doc_491521501785_item	3509623	et	4	main
oli	doc_491521501785_item	3509624	et	3	main
inimeste	doc_491521501785_item	3509625	et	3	main
elu	doc_491521501785_item	3509626	et	4	main
palju	doc_491521501785_item	3509627	et	4	main
tekti	doc_491521501785_item	3509632	et	4	main
ise	doc_491521501785_item	3509633	et	4	main
külvati	doc_491521501785_item	3509639	et	2	main
peksti	doc_491521501785_item	3509642	et	3	main
polnud	doc_491521501785_item	3509649	et	3	main
õppida	doc_491521501785_item	3509651	et	3	main
masinad	doc_491521501785_item	3509654	et	3	main
elada	doc_491521501785_item	3509660	et	3	main
aega	doc_491521501785_item	3509664	et	4	main
oma	doc_491521501785_item	3509665	et	4	main
elu	doc_491521501785_item	3509666	et	4	main
parandamiseks	doc_491521501785_item	3509667	et	4	main
vigase	doc_491521501748_item	3509901	et	4	main
rõhk	doc_491521501748_item	3509909	et	3	main
artikel	doc_491521501748_item	3509914	et	4	main
komputer	doc_491521501748_item	3509915	et	4	main
soobib	doc_491521501748_item	3509923	et	4	main
tuhat	doc_491521501785_item	3509523	et	4	main
moksad	doc_491521501785_item	3509526	et	4	main
350	doc_491521501785_item	3509528	et	2	main
170	doc_491521501785_item	3509531	et	2	main
tuhat	doc_491521501785_item	3509532	et	4	main
esmakordselt	doc_491521501785_item	3509550	et	4	main
rubruquis	doc_491521501785_item	3509551	et	4	main
8	doc_491521501785_item	3509552	et	2	main
sajandil	doc_491521501785_item	3509553	et	3	main
kal	doc_491521501785_item	3509564	et	4	main
18	doc_491521501785_item	3509570	et	2	main
raamatud	doc_491521501785_item	3509573	et	4	main
on	doc_491521501785_item	3509576	et	4	main
19	doc_491521501785_item	3509578	et	2	main
sajandil	doc_491521501785_item	3509579	et	3	main
tänapaeval	doc_491521501785_item	3509580	et	4	main
raskem	doc_491521501785_item	3509628	et	4	main
kui	doc_491521501785_item	3509629	et	3	main
kõik	doc_491521501785_item	3509634	et	4	main
niideti	doc_491521501785_item	3509640	et	3	main
reht	doc_491521501785_item	3509643	et	3	main
kudusid	doc_491521501785_item	3509647	et	4	main
parinevad	doc_491521501785_item	3509569	et	4	main
esimesed	doc_491521501785_item	3509572	et	3	main
ilmunud	doc_491521501785_item	3509577	et	4	main
loodud	doc_491521501785_item	3509587	et	4	main
kirjakeelt	doc_491521501785_item	3509588	et	4	main
kirjakeel	doc_491521501785_item	3509590	et	4	main
1925	doc_491521501785_item	3509591	et	2	main
aastast	doc_491521501785_item	3509592	et	4	main
ja	doc_491521501785_item	3509593	et	3	main
moksa	doc_491521501785_item	3509594	et	4	main
1933	doc_491521501785_item	3509595	et	2	main
nende	doc_491521501785_item	3509597	et	4	main
aastast	doc_491521501785_item	3509596	et	4	main
normide	doc_491521501785_item	3509598	et	3	main
kujunemisele	doc_491521501785_item	3509599	et	4	main
avaldasid	doc_491521501785_item	3509600	et	4	main
tunduvat	doc_491521501785_item	3509601	et	4	main
mõju	doc_491521501785_item	3509602	et	4	main
kirjanikud	doc_491521501785_item	3509603	et	3	main
p	doc_491521501785_item	3509604	et	4	main
kirillov	doc_491521501785_item	3509605	et	2	main
m	doc_491521501785_item	3509606	et	4	main
bezborodov	doc_491521501785_item	3509607	et	2	main
ja	doc_491521501785_item	3509608	et	3	main
t	doc_491521501785_item	3509609	et	4	main
kirdjashkin	doc_491521501785_item	3509610	et	2	main
siin	doc_491521501785_item	3509611	et	4	main
on	doc_491521501785_item	3509612	et	4	main
näideks	doc_491521501785_item	3509613	et	3	main
ja	doc_491521501785_item	3509620	et	3	main
mida	doc_491521501785_item	3509635	et	4	main
ja	doc_491521501785_item	3509641	et	3	main
ja	doc_491521501785_item	3509646	et	3	main
kergem	doc_491521501785_item	3509659	et	4	main
rohkem	doc_491521501785_item	3509663	et	4	main
hääldusbaas	doc_491521501748_item	3509908	et	3	main
mis	doc_491521501748_item	3509937	et	4	main
on	doc_491521501748_item	3509938	et	4	main
tööid	doc_491521501748_item	3509940	et	4	main
niimodi	doc_491521501748_item	3509941	et	4	main
juhtumust	doc_491521501748_item	3509946	et	4	main
lugemisega	doc_491521501748_item	3510000	et	4	main
pildid	doc_491521501748_item	3510009	et	3	main
peate	doc_491521501748_item	3510011	et	4	main
ei	doc_491521501748_item	3510012	et	4	main
tohi	doc_491521501748_item	3510021	et	4	main
lubada	doc_491521501748_item	3510022	et	3	main
et	doc_491521501748_item	3510023	et	3	main
peate	doc_491521501748_item	3510028	et	4	main
soovin	doc_491521501748_item	3510034	et	3	main
koolis	doc_491521501748_item	3510045	et	4	main
nad	doc_491521501748_item	3510046	et	3	main
teevad	doc_491521501748_item	3510047	et	3	main
paljum	doc_491521501748_item	3510053	et	4	main
saateid	doc_491521501748_item	3510054	et	3	main
see	doc_491521501748_item	3510055	et	3	main
artikkel	doc_491521501748_item	3510056	et	3	main
meilt	doc_491521501748_item	3510063	et	3	main
mulle	doc_491521501748_item	3510077	et	4	main
sõltub	doc_491521501748_item	3510080	et	3	main
kvaliteetsest	doc_491521501748_item	3510082	et	3	main
teineteisele	doc_491521501748_item	3510084	et	3	main
neile	doc_491521501785_item	3509661	et	4	main
p	doc_491521501785_item	3509668	et	4	main
ariste	doc_491521501785_item	3509669	et	4	main
ortograafia	doc_491521501748_item	3509904	et	4	main
emakeele	doc_491521501748_item	3509906	et	4	main
grammaatika	doc_491521501748_item	3509913	et	4	main
pika	doc_491521501748_item	3509920	et	4	main
hääliku	doc_491521501748_item	3509921	et	3	main
vahekord	doc_491521501748_item	3509922	et	3	main
rühmitada	doc_491521501748_item	3509935	et	3	main
mida	doc_491521501748_item	3509947	et	4	main
oma	doc_491521501748_item	3509950	et	4	main
öelda	doc_491521501748_item	3509952	et	4	main
on	doc_491521501748_item	3509954	et	4	main
nainega	doc_491521501748_item	3509980	et	4	main
on	doc_491521501748_item	3509987	et	4	main
sinisega	doc_491521501748_item	3510001	et	4	main
lapsele	doc_491521501748_item	3510014	et	4	main
laps	doc_491521501748_item	3510024	et	4	main
harjus	doc_491521501748_item	3510025	et	4	main
minu	doc_491521501748_item	3510037	et	3	main
koolis	doc_491521501748_item	3510038	et	4	main
meie	doc_491521501748_item	3510048	et	4	main
elu	doc_491521501748_item	3510049	et	4	main
on	doc_491521501748_item	3510057	et	4	main
mitte	doc_491521501748_item	3510062	et	3	main
võtan	doc_491521501748_item	3510067	et	3	main
see	doc_491521501748_item	3510070	et	3	main
raske	doc_491521501748_item	3510076	et	4	main
poleks	doc_491521501748_item	3510111	et	3	main
huumori	doc_491521501748_item	3510113	et	3	main
kool	doc_491521501748_item	3510116	et	4	main
noor	doc_491521501748_item	3510118	et	3	main
hoone	doc_491521501748_item	3510119	et	4	main
kiitma	doc_491521501748_item	3510120	et	3	main
elada	doc_45618460769_item	3510136	et	3	main
saaks	doc_45618460769_item	3510143	et	3	main
on	doc_45618460769_item	3510145	et	4	main
ja	doc_45618460769_item	3510156	et	3	main
lennuki	doc_45618460769_item	3510180	et	3	main
võib	doc_45618460769_item	3510182	et	3	main
järeldada	doc_45618460769_item	3510183	et	3	main
et	doc_45618460769_item	3510184	et	3	main
ja	doc_45618460769_item	3510196	et	3	main
kaoksid	doc_45618460769_item	3510215	et	4	main
paanikas	doc_45618460769_item	3510218	et	3	main
mida	doc_45618460769_item	3510222	et	4	main
hakata	doc_45618460769_item	3510224	et	4	main
inimene	doc_45618460769_item	3510225	et	3	main
ei	doc_45618460769_item	3510226	et	4	main
saaks	doc_45618460769_item	3510227	et	3	main
elada	doc_45618460769_item	3510228	et	3	main
me	doc_45618460769_item	3510238	et	4	main
tänapäeva	doc_45618460769_item	3510250	et	4	main
me	doc_45618460769_item	3510261	et	4	main
teeme	doc_45618460769_item	3510262	et	3	main
on	doc_45618460769_item	3510263	et	4	main
tasulised	doc_45618460769_item	3510264	et	4	main
seega	doc_45618460769_item	3510265	et	4	main
leping	doc_40918597565_item	3510284	et	3	main
tallinn	doc_40918597565_item	3510306	et	4	main
müüja	doc_40918597565_item	3510311	et	4	main
kommerts	doc_40918597565_item	3510316	et	3	main
rollinz	doc_40918597565_item	3510318	et	4	main
investments	doc_40918597565_item	3510319	et	4	main
olles	doc_40918597565_item	3510320	et	3	main
juriidiline	doc_40918597565_item	3510321	et	3	main
isik	doc_40918597565_item	3510322	et	3	main
tegevust	doc_40918597565_item	3510329	et	4	main
kooskõlas	doc_40918597565_item	3510330	et	3	main
registreeritud	doc_40918597565_item	3510336	et	4	main
24112000	doc_40918597565_item	3510337	et	2	main
korporatiivse	doc_40918597565_item	3510343	et	4	main
po	doc_40918597565_item	3510348	et	4	main
virgiini	doc_40918597565_item	3510355	et	4	main
saared	doc_40918597565_item	3510356	et	3	main
nimetatud	doc_40918597565_item	3510358	et	4	main
kui	doc_40918597565_item	3510359	et	3	main
ostja	doc_40918597565_item	3510360	et	4	main
direktori	doc_40918597565_item	3510361	et	3	main
perekonnanimi	doc_40918597565_item	3510362	et	3	main
eesnimi	doc_40918597565_item	3510363	et	3	main
näol	doc_40918597565_item	3510364	et	4	main
mõju	doc_491521501748_item	3509907	et	4	main
reliigion	doc_491521501748_item	3509910	et	4	main
still	doc_491521501748_item	3509916	et	4	main
tingitult	doc_491521501748_item	3509926	et	4	main
tihti	doc_491521501748_item	3509927	et	3	main
kuidas	doc_491521501748_item	3509934	et	3	main
õppin	doc_491521501748_item	3509943	et	4	main
räägitakse	doc_491521501748_item	3509944	et	3	main
ühest	doc_491521501748_item	3509945	et	4	main
kõik	doc_491521501748_item	3509953	et	4	main
hommikult	doc_491521501748_item	3509976	et	3	main
koos	doc_491521501748_item	3509978	et	4	main
5000	doc_491521501748_item	3509984	et	2	main
keelekasutuse	doc_491521501748_item	3509902	et	4	main
näited	doc_491521501748_item	3509903	et	3	main
1	doc_491521501748_item	3509905	et	2	main
artikel	doc_491521501748_item	3509911	et	4	main
amerika	doc_491521501748_item	3509912	et	4	main
stiil	doc_491521501748_item	3509917	et	3	main
lühikese	doc_491521501748_item	3509918	et	4	main
ja	doc_491521501748_item	3509919	et	3	main
ü-i	doc_491521501748_item	3509928	et	4	main
ja	doc_491521501748_item	3509929	et	3	main
ö-e	doc_491521501748_item	3509930	et	3	main
segamini	doc_491521501748_item	3509931	et	4	main
vigu	doc_491521501748_item	3509936	et	3	main
põhjus	doc_491521501748_item	3509939	et	4	main
kunstnik	doc_491521501748_item	3509948	et	3	main
tehtud	doc_491521501748_item	3509955	et	4	main
inimeste	doc_491521501748_item	3509956	et	3	main
käside	doc_491521501748_item	3509957	et	4	main
abil	doc_491521501748_item	3509958	et	4	main
ma	doc_491521501748_item	3509959	et	3	main
luuan	doc_491521501748_item	3509960	et	4	main
ma	doc_491521501748_item	3509961	et	3	main
loon	doc_491521501748_item	3509962	et	3	main
mitukorruseline	doc_491521501748_item	3509963	et	4	main
purskkaevaga	doc_491521501748_item	3509964	et	4	main
palju	doc_491521501748_item	3509965	et	4	main
õppeained	doc_491521501748_item	3509966	et	3	main
palju	doc_491521501748_item	3509967	et	4	main
rubriigi	doc_491521501748_item	3509968	et	3	main
rohkem	doc_491521501748_item	3509969	et	4	main
kui	doc_491521501748_item	3509970	et	3	main
2-3	doc_491521501748_item	3509971	et	2	main
nädalad	doc_491521501748_item	3509972	et	3	main
20-30	doc_491521501748_item	3509973	et	2	main
aastad	doc_491521501748_item	3509974	et	3	main
vana	doc_491521501748_item	3509975	et	4	main
postkardid	doc_491521501748_item	3509924	et	3	main
hääldusalusest	doc_491521501748_item	3509925	et	4	main
ekoloogiline	doc_491521501748_item	3509932	et	4	main
meelsesti	doc_491521501748_item	3509933	et	4	main
õppikuid	doc_491521501748_item	3509942	et	4	main
tahab	doc_491521501748_item	3509949	et	3	main
pildidega	doc_491521501748_item	3509951	et	3	main
südamlised	doc_491521501748_item	3509981	et	4	main
lapse	doc_491521501748_item	3509989	et	4	main
sünnipäev	doc_491521501748_item	3509990	et	3	main
ma	doc_491521501748_item	3509991	et	3	main
suhtun	doc_491521501748_item	3509992	et	3	main
tunnisse	doc_491521501748_item	3509993	et	3	main
huviga	doc_491521501748_item	3509994	et	3	main
kui	doc_491521501748_item	3509995	et	3	main
inimene	doc_491521501748_item	3509996	et	3	main
kirjutab	doc_491521501748_item	3509997	et	3	main
ajalehesse	doc_491521501748_item	3509998	et	3	main
suurega	doc_491521501748_item	3509999	et	4	main
silmadega	doc_491521501748_item	3510002	et	3	main
koduseid	doc_491521501748_item	3510004	et	4	main
maksta	doc_491521501748_item	3510013	et	4	main
arvuti	doc_491521501748_item	3510016	et	4	main
ei	doc_491521501748_item	3510017	et	4	main
asendab	doc_491521501748_item	3510018	et	3	main
veenduma	doc_491521501748_item	3510029	et	4	main
oma	doc_491521501748_item	3510030	et	4	main
et	doc_491521501748_item	3510035	et	3	main
leheküljel	doc_491521501748_item	3510059	et	3	main
õpilastele	doc_491521501748_item	3510066	et	4	main
osa	doc_491521501748_item	3510068	et	4	main
oleneb	doc_491521501748_item	3510071	et	3	main
inimestega	doc_491521501748_item	3510107	et	3	main
milleta	doc_45618460769_item	3510134	et	3	main
tänapäevainimene	doc_45618460769_item	3510140	et	3	main
elada	doc_45618460769_item	3510141	et	3	main
paljudest	doc_45618460769_item	3510154	et	3	main
ei	doc_45618460769_item	3510157	et	4	main
nendeta	doc_45618460769_item	3510160	et	4	main
eriti	doc_45618460769_item	3510161	et	3	main
hakkama	doc_45618460769_item	3510163	et	3	main
tundus	doc_45618460769_item	3510166	et	3	main
ta	doc_45618460769_item	3510175	et	4	main
auto	doc_45618460769_item	3510178	et	4	main
ja	doc_45618460769_item	3510179	et	3	main
oska	doc_45618460769_item	3510195	et	4	main
muudavad	doc_45618460769_item	3510198	et	4	main
meie	doc_45618460769_item	3510199	et	4	main
oleks	doc_45618460769_item	3510216	et	3	main
maailm	doc_45618460769_item	3510217	et	3	main
teaks	doc_45618460769_item	3510221	et	3	main
õhtuni	doc_491521501748_item	3509977	et	3	main
oma	doc_491521501748_item	3509979	et	4	main
saavad	doc_491521501748_item	3509982	et	4	main
riigist	doc_491521501748_item	3509983	et	3	main
krooni	doc_491521501748_item	3509985	et	4	main
juunil	doc_491521501748_item	3509986	et	3	main
mu	doc_491521501748_item	3509988	et	3	main
palju	doc_491521501748_item	3510003	et	4	main
ülesanded	doc_491521501748_item	3510005	et	3	main
selle	doc_491521501748_item	3510006	et	4	main
saarel	doc_491521501748_item	3510007	et	3	main
see	doc_491521501748_item	3510008	et	3	main
te	doc_491521501748_item	3510010	et	4	main
raha	doc_491521501748_item	3510015	et	4	main
rahaga	doc_491521501748_item	3510026	et	4	main
last	doc_491521501748_item	3510031	et	4	main
õppis	doc_491521501748_item	3510033	et	3	main
objektiivsed	doc_491521501748_item	3510040	et	3	main
kergem	doc_491521501748_item	3510050	et	4	main
peab	doc_491521501748_item	3510051	et	4	main
pakkuma	doc_491521501748_item	3510052	et	3	main
üheksateist	doc_491521501748_item	3510058	et	4	main
sõltub	doc_491521501748_item	3510061	et	3	main
aidata	doc_491521501748_item	3510064	et	4	main
rollimängudes	doc_491521501748_item	3510069	et	3	main
on	doc_491521501748_item	3510075	et	4	main
meelde	doc_491521501748_item	3510079	et	3	main
toidu	doc_491521501748_item	3510081	et	3	main
tüütama	doc_491521501748_item	3510083	et	3	main
loodus	doc_491521501748_item	3510101	et	4	main
asendas	doc_491521501748_item	3510103	et	3	main
see	doc_491521501748_item	3510115	et	3	main
on	doc_491521501748_item	3510117	et	4	main
saaks	doc_45618460769_item	3510138	et	3	main
me	doc_45618460769_item	3510151	et	4	main
sõltume	doc_45618460769_item	3510153	et	3	main
asjadest	doc_45618460769_item	3510155	et	3	main
ilma	doc_45618460769_item	3510159	et	4	main
hästi	doc_45618460769_item	3510162	et	3	main
hobune	doc_45618460769_item	3510168	et	4	main
leiutas	doc_45618460769_item	3510176	et	3	main
paremad	doc_45618460769_item	3510188	et	4	main
masinad	doc_45618460769_item	3510189	et	3	main
millest	doc_45618460769_item	3510190	et	3	main
me	doc_45618460769_item	3510191	et	4	main
praegu	doc_45618460769_item	3510192	et	3	main
unistadagi	doc_45618460769_item	3510193	et	3	main
ei	doc_45618460769_item	3510220	et	4	main
kuskilt	doc_45618460769_item	3510234	et	4	main
saada	doc_45618460769_item	3510236	et	4	main
ei	doc_45618460769_item	3510244	et	4	main
küsi	doc_45618460769_item	3510245	et	4	main
teistelt	doc_45618460769_item	3510246	et	4	main
vaid	doc_45618460769_item	3510247	et	3	main
ei	doc_45618460769_item	3510252	et	4	main
ostu-müügi	doc_40918597565_item	3510286	et	4	main
vene	doc_40918597565_item	3510298	et	4	main
föderatsiooni	doc_40918597565_item	3510299	et	4	main
saatkonna	doc_40918597565_item	3510300	et	4	main
nagu	doc_40918597565_item	3510310	et	3	main
ja	doc_40918597565_item	3510314	et	3	main
mis	doc_40918597565_item	3510323	et	4	main
briti	doc_40918597565_item	3510331	et	4	main
virgiinia	doc_40918597565_item	3510332	et	4	main
saartega	doc_40918597565_item	3510333	et	3	main
poolt	doc_40918597565_item	3510346	et	4	main
box	doc_40918597565_item	3510349	et	4	main
road	doc_40918597565_item	3510351	et	4	main
town	doc_40918597565_item	3510352	et	4	main
kooskõlas	doc_40918597565_item	3510366	et	3	main
592006	doc_534729444698_item	3510375	et	2	main
üksinda	doc_534729444698_item	3510379	et	4	main
õhtu	doc_534729444698_item	3510437	et	4	main
söime	doc_534729444698_item	3510440	et	4	main
restoranis	doc_534729444698_item	3510441	et	3	main
magogis	doc_534729444698_item	3510442	et	4	main
olime	doc_534729444698_item	3510451	et	3	main
natuke	doc_534729444698_item	3510452	et	4	main
kurb	doc_534729444698_item	3510453	et	3	main
ma	doc_534729444698_item	3510454	et	3	main
eastern	doc_534729444698_item	3510464	et	4	main
peatükk	doc_491521501753_item	3510483	et	3	main
muistend	doc_491521501753_item	3510485	et	3	main
õpetajat	doc_491521501748_item	3510019	et	4	main
ei	doc_491521501748_item	3510020	et	4	main
te	doc_491521501748_item	3510027	et	4	main
et	doc_491521501748_item	3510032	et	3	main
õpetajad	doc_491521501748_item	3510036	et	4	main
olid	doc_491521501748_item	3510039	et	4	main
mida	doc_491521501748_item	3510041	et	4	main
te	doc_491521501748_item	3510042	et	4	main
muutuksite	doc_491521501748_item	3510043	et	3	main
tänapäeva	doc_491521501748_item	3510044	et	4	main
see	doc_491521501748_item	3510060	et	3	main
koolikartlikule	doc_491521501748_item	3510065	et	3	main
vanemates	doc_491521501748_item	3510072	et	4	main
õpetajaks	doc_491521501748_item	3510073	et	4	main
töötada	doc_491521501748_item	3510074	et	3	main
läks	doc_491521501748_item	3510078	et	3	main
laps	doc_491521501748_item	3510085	et	4	main
harjus	doc_491521501748_item	3510086	et	4	main
koolielule	doc_491521501748_item	3510087	et	3	main
kiiresti	doc_491521501748_item	3510088	et	3	main
tahab	doc_491521501748_item	3510089	et	3	main
ta	doc_491521501748_item	3510090	et	4	main
meile	doc_491521501748_item	3510091	et	4	main
mõjutada	doc_491521501748_item	3510092	et	3	main
loodan	doc_491521501748_item	3510093	et	3	main
et	doc_491521501748_item	3510094	et	3	main
teil	doc_491521501748_item	3510095	et	4	main
meeldib	doc_491521501748_item	3510096	et	3	main
vastus	doc_491521501748_item	3510097	et	3	main
osmussaarel	doc_491521501748_item	3510098	et	4	main
on	doc_491521501748_item	3510099	et	4	main
mitmesugune	doc_491521501748_item	3510100	et	3	main
tundra	doc_491521501748_item	3510102	et	4	main
metsadega	doc_491521501748_item	3510104	et	3	main
tutvustada	doc_491521501748_item	3510106	et	3	main
et	doc_491521501748_item	3510108	et	3	main
elu	doc_491521501748_item	3510110	et	4	main
igav	doc_491521501748_item	3510112	et	3	main
tunne	doc_491521501748_item	3510114	et	4	main
tänapäevainimene	doc_45618460769_item	3510135	et	3	main
ei	doc_45618460769_item	3510137	et	4	main
juba	doc_45618460769_item	3510152	et	3	main
saaks	doc_45618460769_item	3510158	et	3	main
nüüdisaegsele	doc_45618460769_item	3510164	et	3	main
et	doc_45618460769_item	3510167	et	3	main
ei	doc_45618460769_item	3510169	et	4	main
ole	doc_45618460769_item	3510170	et	4	main
eriti	doc_45618460769_item	3510171	et	3	main
efektiivne	doc_45618460769_item	3510172	et	3	main
transpordivahend	doc_45618460769_item	3510173	et	3	main
ja	doc_45618460769_item	3510174	et	3	main
rongi	doc_45618460769_item	3510177	et	4	main
sellest	doc_45618460769_item	3510181	et	4	main
tulevikus	doc_45618460769_item	3510185	et	4	main
sünnivad	doc_45618460769_item	3510186	et	3	main
ei	doc_45618460769_item	3510194	et	4	main
mis	doc_45618460769_item	3510197	et	4	main
ja	doc_45618460769_item	3510219	et	3	main
peale	doc_45618460769_item	3510223	et	4	main
või	doc_45618460769_item	3510243	et	4	main
hakkama	doc_45618460769_item	3510254	et	3	main
ilma	doc_45618460769_item	3510255	et	4	main
peaaegu	doc_45618460769_item	3510257	et	3	main
tahavad	doc_491521501748_item	3510105	et	3	main
nende	doc_491521501748_item	3510109	et	4	main
hinnete	doc_491521501748_item	3510121	et	3	main
jaoks	doc_491521501748_item	3510122	et	4	main
te	doc_491521501748_item	3510123	et	4	main
olete	doc_491521501748_item	3510124	et	3	main
päris	doc_491521501748_item	3510125	et	4	main
õige	doc_491521501748_item	3510126	et	4	main
kui	doc_491521501748_item	3510127	et	3	main
räägite	doc_491521501748_item	3510128	et	3	main
milleta	doc_45618460769_item	3510139	et	3	main
ei	doc_45618460769_item	3510142	et	4	main
see	doc_45618460769_item	3510144	et	3	main
viinud	doc_45618460769_item	3510146	et	4	main
meid	doc_45618460769_item	3510147	et	4	main
selleni	doc_45618460769_item	3510148	et	3	main
et	doc_45618460769_item	3510149	et	3	main
tänapäeval	doc_45618460769_item	3510150	et	3	main
inimesele	doc_45618460769_item	3510165	et	3	main
veelgi	doc_45618460769_item	3510187	et	4	main
elu	doc_45618460769_item	3510200	et	4	main
veelgi	doc_45618460769_item	3510201	et	4	main
paremaks	doc_45618460769_item	3510202	et	4	main
kaasaegne	doc_45618460769_item	3510203	et	3	main
inimene	doc_45618460769_item	3510204	et	3	main
ei	doc_45618460769_item	3510205	et	4	main
ole	doc_45618460769_item	3510206	et	4	main
iseseisev	doc_45618460769_item	3510207	et	3	main
ja	doc_45618460769_item	3510208	et	3	main
sõltub	doc_45618460769_item	3510209	et	3	main
teiste	doc_45618460769_item	3510210	et	4	main
abist	doc_45618460769_item	3510211	et	3	main
kui	doc_45618460769_item	3510212	et	3	main
teenused	doc_45618460769_item	3510214	et	3	main
need	doc_45618460769_item	3510213	et	3	main
ilma	doc_45618460769_item	3510229	et	4	main
tehnikata	doc_45618460769_item	3510230	et	3	main
kui	doc_45618460769_item	3510231	et	3	main
me	doc_45618460769_item	3510232	et	4	main
tahame	doc_45618460769_item	3510233	et	3	main
informatsiooni	doc_45618460769_item	3510235	et	4	main
siis	doc_45618460769_item	3510237	et	3	main
ei	doc_45618460769_item	3510239	et	4	main
enam	doc_45618460769_item	3510241	et	4	main
raamatukokku	doc_45618460769_item	3510242	et	4	main
läheme	doc_45618460769_item	3510248	et	3	main
internetti	doc_45618460769_item	3510249	et	4	main
saaks	doc_45618460769_item	3510253	et	3	main
rahata	doc_45618460769_item	3510256	et	4	main
kõik	doc_45618460769_item	3510258	et	4	main
asjad	doc_45618460769_item	3510259	et	3	main
mida	doc_45618460769_item	3510260	et	4	main
sünd	doc_40918597565_item	3510290	et	3	main
passi	doc_40918597565_item	3510292	et	4	main
edasi	doc_40918597565_item	3510308	et	3	main
nimetatud	doc_40918597565_item	3510309	et	4	main
poolt	doc_40918597565_item	3510313	et	4	main
aadress	doc_40918597565_item	3510347	et	3	main
146	doc_40918597565_item	3510350	et	2	main
edasi	doc_40918597565_item	3510357	et	3	main
olin	doc_534729444698_item	3510378	et	3	main
peter	doc_534729444698_item	3510382	et	4	main
töötasi	doc_534729444698_item	3510385	et	4	main
ma	doc_534729444698_item	3510387	et	3	main
söin	doc_534729444698_item	3510390	et	4	main
hommikusöögi	doc_534729444698_item	3510391	et	3	main
ja	doc_534729444698_item	3510392	et	3	main
pakkisin	doc_534729444698_item	3510393	et	3	main
minu	doc_534729444698_item	3510394	et	3	main
pagas	doc_534729444698_item	3510395	et	3	main
siis	doc_534729444698_item	3510396	et	3	main
ma	doc_534729444698_item	3510397	et	3	main
sest	doc_534729444698_item	3510400	et	4	main
maitsev	doc_534729444698_item	3510445	et	4	main
aga	doc_534729444698_item	3510446	et	3	main
sel	doc_534729444698_item	3510447	et	3	main
õhtul	doc_534729444698_item	3510448	et	3	main
ära	doc_534729444698_item	3510457	et	4	main
lähe	doc_45618460769_item	3510240	et	4	main
inimene	doc_45618460769_item	3510251	et	3	main
on	doc_45618460769_item	3510266	et	4	main
võimatu	doc_45618460769_item	3510267	et	4	main
kaasajal	doc_45618460769_item	3510268	et	4	main
elada	doc_45618460769_item	3510269	et	3	main
ilma	doc_45618460769_item	3510270	et	4	main
rahata	doc_45618460769_item	3510271	et	4	main
enamasti	doc_45618460769_item	3510272	et	4	main
ongi	doc_45618460769_item	3510273	et	4	main
heidikuteks	doc_45618460769_item	3510274	et	4	main
need	doc_45618460769_item	3510275	et	3	main
kes	doc_45618460769_item	3510276	et	4	main
ei	doc_45618460769_item	3510277	et	4	main
viitsi	doc_45618460769_item	3510278	et	4	main
ega	doc_45618460769_item	3510279	et	3	main
taha	doc_45618460769_item	3510280	et	4	main
vaeva	doc_45618460769_item	3510281	et	4	main
näha	doc_45618460769_item	3510282	et	3	main
nr	doc_40918597565_item	3510293	et	4	main
välja	doc_40918597565_item	3510295	et	4	main
antud	doc_40918597565_item	3510296	et	4	main
16112007	doc_40918597565_item	3510297	et	2	main
poolt	doc_40918597565_item	3510301	et	4	main
eestis	doc_40918597565_item	3510302	et	3	main
elukoht	doc_40918597565_item	3510303	et	3	main
tänav	doc_40918597565_item	3510304	et	4	main
2-7	doc_40918597565_item	3510305	et	2	main
rahvusvaheline	doc_40918597565_item	3510315	et	4	main
firma	doc_40918597565_item	3510317	et	4	main
on	doc_40918597565_item	3510324	et	4	main
kehtestatud	doc_40918597565_item	3510325	et	4	main
ja	doc_40918597565_item	3510326	et	3	main
teostab	doc_40918597565_item	3510327	et	3	main
oma	doc_40918597565_item	3510328	et	4	main
mis	doc_40918597565_item	3510334	et	4	main
on	doc_40918597565_item	3510335	et	4	main
küsimuste	doc_40918597565_item	3510344	et	4	main
registraatori	doc_40918597565_item	3510345	et	3	main
suurbritannia	doc_40918597565_item	3510354	et	4	main
põhikirjaga	doc_40918597565_item	3510367	et	3	main
teiselt	doc_40918597565_item	3510368	et	4	main
poolt	doc_40918597565_item	3510369	et	4	main
sõlmisid	doc_40918597565_item	3510370	et	4	main
järgneva	doc_40918597565_item	3510371	et	4	main
lepingu	doc_40918597565_item	3510372	et	3	main
aktsiate	doc_40918597565_item	3510285	et	3	main
leping	doc_40918597565_item	3510287	et	3	main
perekonnanimi	doc_40918597565_item	3510288	et	3	main
eesnimi	doc_40918597565_item	3510289	et	3	main
8041938	doc_40918597565_item	3510291	et	2	main
0000000	doc_40918597565_item	3510294	et	2	main
eesti	doc_40918597565_item	3510307	et	4	main
ühelt	doc_40918597565_item	3510312	et	3	main
nr	doc_40918597565_item	3510338	et	4	main
418606	doc_40918597565_item	3510339	et	2	main
suurbritannia	doc_40918597565_item	3510340	et	4	main
virhiinia	doc_40918597565_item	3510341	et	4	main
saarte	doc_40918597565_item	3510342	et	3	main
tortola	doc_40918597565_item	3510353	et	4	main
päevik	doc_534729444698_item	3510374	et	3	main
ja	doc_534729444698_item	3510383	et	3	main
kirjutasin	doc_534729444698_item	3510388	et	3	main
televiisioni	doc_534729444698_item	3510399	et	4	main
minu	doc_534729444698_item	3510435	et	3	main
stansteadis	doc_534729444698_item	3510438	et	4	main
me	doc_534729444698_item	3510449	et	4	main
sõitma	doc_534729444698_item	3510458	et	3	main
mulle	doc_534729444698_item	3510459	et	4	main
väga	doc_534729444698_item	3510460	et	3	main
meeldib	doc_534729444698_item	3510461	et	3	main
kanada	doc_534729444698_item	3510462	et	4	main
eriti	doc_534729444698_item	3510463	et	3	main
ja	doc_534729444698_item	3510474	et	3	main
huvitav	doc_534729444698_item	3510475	et	4	main
ja	doc_534729444698_item	3510476	et	3	main
ma	doc_534729444698_item	3510477	et	3	main
rõõmustasin	doc_534729444698_item	3510478	et	3	main
olla	doc_534729444698_item	3510479	et	3	main
seal	doc_534729444698_item	3510480	et	4	main
seminaritöö	doc_491521501753_item	3510481	et	4	main
on	doc_491521501753_item	3510499	et	4	main
aja	doc_491521501753_item	3510510	et	4	main
eseme	doc_491521501753_item	3510511	et	3	main
liikuda	doc_491521501753_item	3510521	et	3	main
näidatud	doc_491521501753_item	3510542	et	4	main
nende	doc_491521501753_item	3510548	et	4	main
fakti	doc_491521501753_item	3510583	et	4	main
konstanteeruv	doc_491521501753_item	3510584	et	4	main
pidav	doc_491521501753_item	3510589	et	4	main
tihti	doc_491521501753_item	3510596	et	3	main
koha	doc_491521501753_item	3510604	et	4	main
aja	doc_491521501753_item	3510606	et	4	main
täpse	doc_491521501753_item	3510607	et	3	main
toimus	doc_491521501753_item	3510611	et	3	main
еi	doc_491521501753_item	3510643	et	2	main
seletavaks	doc_491521501753_item	3510653	et	4	main
traditsiooniline	doc_491521501753_item	3510666	et	4	main
tuttava	doc_491521501753_item	3510676	et	4	main
isikuga	doc_491521501753_item	3510677	et	3	main
kivi	doc_491521501753_item	3510692	et	4	main
kuulajat	doc_491521501753_item	3510705	et	4	main
veenda	doc_491521501753_item	3510706	et	4	main
uskuma	doc_491521501753_item	3510707	et	3	main
tegutsevat	doc_40918597565_item	3510365	et	4	main
hommikul	doc_534729444698_item	3510377	et	3	main
mõlemad	doc_534729444698_item	3510381	et	3	main
maria	doc_534729444698_item	3510384	et	4	main
keskpäevani	doc_534729444698_item	3510386	et	3	main
päeviki	doc_534729444698_item	3510389	et	3	main
vaatasin	doc_534729444698_item	3510398	et	3	main
viimeine	doc_534729444698_item	3510436	et	4	main
me	doc_534729444698_item	3510439	et	4	main
kõik	doc_534729444698_item	3510450	et	4	main
stanstead	doc_534729444698_item	3510467	et	4	main
asub	doc_534729444698_item	3510468	et	3	main
aga	doc_534729444698_item	3510469	et	3	main
kogu	doc_534729444698_item	3510470	et	4	main
2	doc_491521501753_item	3510482	et	2	main
muistend	doc_491521501753_item	3510484	et	3	main
rahvajutuliigi	doc_491521501753_item	3510488	et	4	main
omab	doc_491521501753_item	3510490	et	3	main
mitmeid	doc_491521501753_item	3510491	et	4	main
tunnuseid	doc_491521501753_item	3510492	et	3	main
mille	doc_491521501753_item	3510493	et	3	main
muinasjutt	doc_491521501753_item	3510498	et	3	main
rahvuslikku	doc_491521501753_item	3510502	et	4	main
та	doc_491521501753_item	3510504	et	2	main
on	doc_491521501753_item	3510515	et	4	main
primitiivse	doc_491521501753_item	3510516	et	3	main
rahva	doc_491521501753_item	3510517	et	3	main
olendi	doc_491521501753_item	3510523	et	3	main
eseme	doc_491521501753_item	3510525	et	3	main
mingi	doc_491521501753_item	3510529	et	4	main
suure	doc_491521501753_item	3510530	et	3	main
praegu	doc_491521501753_item	3510531	et	3	main
veel	doc_491521501753_item	3510532	et	4	main
olemasoleva	doc_491521501753_item	3510533	et	3	main
ehitise	doc_491521501753_item	3510534	et	3	main
suured	doc_491521501753_item	3510535	et	3	main
rändrahnud	doc_491521501753_item	3510536	et	3	main
jne	doc_491521501753_item	3510544	et	4	main
rahvajutt	doc_491521501753_item	3510545	et	3	main
on	doc_491521501753_item	3510546	et	4	main
on	doc_491521501753_item	3510555	et	4	main
lühem	doc_491521501753_item	3510558	et	4	main
aga	doc_491521501753_item	3510560	et	3	main
täna	doc_534729444698_item	3510376	et	4	main
majas	doc_534729444698_item	3510380	et	3	main
ma	doc_534729444698_item	3510401	et	3	main
tahtsin	doc_534729444698_item	3510402	et	3	main
vaatama	doc_534729444698_item	3510403	et	3	main
kanadalast	doc_534729444698_item	3510404	et	3	main
muusikat	doc_534729444698_item	3510405	et	3	main
aga	doc_534729444698_item	3510406	et	3	main
televiisionis	doc_534729444698_item	3510407	et	4	main
oli	doc_534729444698_item	3510408	et	3	main
palju	doc_534729444698_item	3510409	et	4	main
hip-hop	doc_534729444698_item	3510410	et	4	main
ja	doc_534729444698_item	3510411	et	3	main
see	doc_534729444698_item	3510412	et	3	main
mulle	doc_534729444698_item	3510413	et	4	main
ei	doc_534729444698_item	3510414	et	4	main
meeldi	doc_534729444698_item	3510415	et	4	main
siis	doc_534729444698_item	3510416	et	3	main
maria	doc_534729444698_item	3510417	et	4	main
tulisi	doc_534729444698_item	3510418	et	3	main
koju	doc_534729444698_item	3510419	et	3	main
ja	doc_534729444698_item	3510420	et	3	main
me	doc_534729444698_item	3510421	et	4	main
söime	doc_534729444698_item	3510422	et	4	main
nuudlisalati	doc_534729444698_item	3510423	et	3	main
me	doc_534729444698_item	3510424	et	4	main
ka	doc_534729444698_item	3510425	et	3	main
räägisime	doc_534729444698_item	3510426	et	4	main
palju	doc_534729444698_item	3510427	et	4	main
kuni	doc_534729444698_item	3510428	et	3	main
peter	doc_534729444698_item	3510429	et	4	main
tulisi	doc_534729444698_item	3510430	et	3	main
koju	doc_534729444698_item	3510431	et	3	main
kuna	doc_534729444698_item	3510432	et	3	main
täna	doc_534729444698_item	3510433	et	4	main
oli	doc_534729444698_item	3510434	et	3	main
jessies	doc_534729444698_item	3510443	et	4	main
väga	doc_534729444698_item	3510444	et	3	main
ei	doc_534729444698_item	3510455	et	4	main
tahtsi	doc_534729444698_item	3510456	et	3	main
townshipis	doc_534729444698_item	3510465	et	4	main
kus	doc_534729444698_item	3510466	et	3	main
ida-kanada	doc_534729444698_item	3510471	et	4	main
on	doc_534729444698_item	3510472	et	4	main
kaunis	doc_534729444698_item	3510473	et	4	main
moodustab	doc_491521501753_item	3510486	et	3	main
muistend	doc_491521501753_item	3510489	et	3	main
muinasjutust	doc_491521501753_item	3510497	et	3	main
või	doc_491521501753_item	3510512	et	4	main
isikuga	doc_491521501753_item	3510513	et	3	main
muistend	doc_491521501753_item	3510514	et	3	main
või	doc_491521501753_item	3510524	et	4	main
hiid	doc_491521501753_item	3510527	et	4	main
paika	doc_491521501753_item	3510543	et	4	main
olemise	doc_491521501753_item	3510549	et	4	main
omast	doc_491521501753_item	3510557	et	4	main
ka	doc_491521501753_item	3510561	et	3	main
asjalikum	doc_491521501753_item	3510562	et	4	main
ühe	doc_491521501753_item	3510563	et	4	main
tegelasega	doc_491521501753_item	3510564	et	3	main
võib	doc_491521501753_item	3510565	et	3	main
vahel	doc_491521501753_item	3510566	et	4	main
seotud	doc_491521501753_item	3510567	et	4	main
olla	doc_491521501753_item	3510568	et	3	main
mitu	doc_491521501753_item	3510569	et	4	main
muistendit	doc_491521501753_item	3510570	et	3	main
koguni	doc_491521501753_item	3510571	et	4	main
terve	doc_491521501753_item	3510572	et	4	main
tsükkel	doc_491521501753_item	3510573	et	3	main
nagu	doc_491521501753_item	3510574	et	3	main
vastavalt	doc_491521501753_item	3510575	et	4	main
oma	doc_491521501753_item	3510576	et	4	main
iseloomule	doc_491521501753_item	3510577	et	3	main
on	doc_491521501753_item	3510578	et	4	main
muistend	doc_491521501753_item	3510579	et	3	main
enamasti	doc_491521501753_item	3510580	et	4	main
lühike	doc_491521501753_item	3510581	et	4	main
silmas	doc_491521501753_item	3510588	et	4	main
lapidaarne	doc_491521501753_item	3510594	et	3	main
rohkem	doc_491521501753_item	3510597	et	4	main
kui	doc_491521501753_item	3510599	et	3	main
kus	doc_491521501753_item	3510609	et	3	main
siis	doc_491521501753_item	3510612	et	3	main
tegelane	doc_491521501753_item	3510614	et	3	main
või	doc_491521501753_item	3510618	et	4	main
tavaliselt	doc_491521501753_item	3510659	et	4	main
antakse	doc_491521501753_item	3510660	et	3	main
mittekaheldav	doc_491521501753_item	3510670	et	3	main
jutustaja	doc_491521501753_item	3510680	et	4	main
fakt	doc_491521501753_item	3510691	et	3	main
järv	doc_491521501753_item	3510695	et	3	main
sellise	doc_491521501753_item	3510699	et	4	main
kaudu	doc_491521501753_item	3510701	et	3	main
mütoloogia	doc_491521501753_item	3510714	et	4	main
olulise	doc_491521501753_item	3510487	et	4	main
ta	doc_491521501753_item	3510496	et	4	main
kohalikku	doc_491521501753_item	3510501	et	4	main
algupära	doc_491521501753_item	3510503	et	4	main
tavaliselt	doc_491521501753_item	3510506	et	4	main
teadus	doc_491521501753_item	3510518	et	4	main
katk	doc_491521501753_item	3510519	et	3	main
võid	doc_491521501753_item	3510520	et	4	main
on	doc_491521501753_item	3510537	et	4	main
viskamise	doc_491521501753_item	3510539	et	4	main
tulemusena	doc_491521501753_item	3510540	et	3	main
sattunud	doc_491521501753_item	3510541	et	4	main
ainult	doc_491521501753_item	3510547	et	4	main
sündmustik	doc_491521501753_item	3510554	et	3	main
muinasjutu	doc_491521501753_item	3510556	et	3	main
staatilisemlihtsam	doc_491521501753_item	3510559	et	2	main
mingit	doc_491521501753_item	3510582	et	3	main
on	doc_491521501753_item	3510590	et	4	main
ka	doc_491521501753_item	3510591	et	3	main
stiil	doc_491521501753_item	3510593	et	3	main
kirjeldav	doc_491521501753_item	3510598	et	4	main
jutustav	doc_491521501753_item	3510600	et	4	main
muistend	doc_491521501753_item	3510601	et	3	main
algab	doc_491521501753_item	3510602	et	3	main
või	doc_491521501753_item	3510605	et	4	main
kellega	doc_491521501753_item	3510615	et	3	main
arenda	doc_491521501753_item	3510644	et	4	main
üksikpilte	doc_491521501753_item	3510645	et	3	main
nagu	doc_491521501753_item	3510646	et	3	main
teeb	doc_491521501753_item	3510647	et	3	main
muistend	doc_491521501753_item	3510650	et	3	main
ikka	doc_491521501753_item	3510652	et	4	main
seetõttu	doc_491521501753_item	3510654	et	3	main
lugu	doc_491521501753_item	3510667	et	4	main
mis	doc_491521501753_item	3510672	et	4	main
on	doc_491521501753_item	3510673	et	4	main
end	doc_491521501753_item	3510681	et	4	main
isikliki	doc_491521501753_item	3510682	et	4	main
pealtvaatajana	doc_491521501753_item	3510683	et	3	main
jutustuse	doc_491521501753_item	3510684	et	4	main
usaldatavuse	doc_491521501753_item	3510685	et	4	main
toetuseks	doc_491521501753_item	3510686	et	4	main
tuuakse	doc_491521501753_item	3510687	et	3	main
mitmes	doc_491521501753_item	3510688	et	4	main
muistendrühmas	doc_491521501753_item	3510689	et	4	main
silmnähtav	doc_491521501753_item	3510690	et	3	main
poolest	doc_491521501753_item	3510494	et	4	main
erineb	doc_491521501753_item	3510495	et	3	main
rahvusv	doc_491521501753_item	3510500	et	2	main
on	doc_491521501753_item	3510505	et	4	main
seotud	doc_491521501753_item	3510507	et	4	main
kas	doc_491521501753_item	3510508	et	3	main
koha	doc_491521501753_item	3510509	et	4	main
mingi	doc_491521501753_item	3510522	et	4	main
kujul	doc_491521501753_item	3510526	et	4	main
püstitas	doc_491521501753_item	3510528	et	3	main
hiidude	doc_491521501753_item	3510538	et	4	main
või	doc_491521501753_item	3510550	et	4	main
1986	doc_491521501753_item	3510551	et	2	main
268	doc_491521501753_item	3510552	et	2	main
muistendi	doc_491521501753_item	3510553	et	3	main
või	doc_491521501753_item	3510585	et	4	main
ühtainust	doc_491521501753_item	3510586	et	4	main
eesmärki	doc_491521501753_item	3510587	et	4	main
kokkusurutud	doc_491521501753_item	3510595	et	4	main
märkimisega	doc_491521501753_item	3510608	et	4	main
sündmus	doc_491521501753_item	3510610	et	3	main
tuleb	doc_491521501753_item	3510613	et	3	main
näidatav	doc_491521501753_item	3510617	et	4	main
seda	doc_491521501753_item	3510648	et	3	main
jääb	doc_491521501753_item	3510651	et	3	main
on	doc_491521501753_item	3510655	et	4	main
ka	doc_491521501753_item	3510656	et	3	main
stiil	doc_491521501753_item	3510657	et	3	main
värvivaesem	doc_491521501753_item	3510658	et	4	main
või	doc_491521501753_item	3510668	et	4	main
kui	doc_491521501753_item	3510669	et	3	main
harva	doc_491521501753_item	3510678	et	4	main
tutvustab	doc_491521501753_item	3510679	et	3	main
mägi	doc_491521501753_item	3510693	et	3	main
just	doc_491521501753_item	3510698	et	3	main
jutustatut	doc_491521501753_item	3510708	et	4	main
kui	doc_491521501753_item	3510709	et	3	main
alusel	doc_491521501753_item	3510715	et	4	main
päevik	doc_534729444693_item	3510980	et	3	main
kell	doc_534729444693_item	3510987	et	3	main
districtisse	doc_534729444693_item	3511001	et	4	main
ja	doc_534729444693_item	3511008	et	3	main
piknik	doc_534729444693_item	3511010	et	3	main
matkasime	doc_534729444693_item	3511015	et	3	main
viis	doc_534729444693_item	3511016	et	4	main
me	doc_534729444693_item	3511020	et	4	main
jõime	doc_534729444693_item	3511024	et	3	main
ja	doc_534729444693_item	3511026	et	3	main
selle	doc_491521501753_item	3510592	et	4	main
tavaliselt	doc_491521501753_item	3510603	et	4	main
konkreetselt	doc_491521501753_item	3510616	et	4	main
tõeks	doc_491521501753_item	3510619	et	4	main
tunnistatud	doc_491521501753_item	3510620	et	4	main
lugu	doc_491521501753_item	3510621	et	4	main
juhtus	doc_491521501753_item	3510622	et	3	main
muistendi	doc_491521501753_item	3510623	et	3	main
pikkus	doc_491521501753_item	3510624	et	4	main
kõigub	doc_491521501753_item	3510625	et	3	main
ühe	doc_491521501753_item	3510626	et	4	main
või	doc_491521501753_item	3510627	et	4	main
paari	doc_491521501753_item	3510628	et	4	main
lause	doc_491521501753_item	3510629	et	4	main
ja	doc_491521501753_item	3510630	et	3	main
küllalt	doc_491521501753_item	3510631	et	4	main
pika	doc_491521501753_item	3510632	et	4	main
eepilise	doc_491521501753_item	3510633	et	3	main
jutustuse	doc_491521501753_item	3510634	et	4	main
vahel	doc_491521501753_item	3510635	et	4	main
kuid	doc_491521501753_item	3510636	et	4	main
viimane	doc_491521501753_item	3510637	et	3	main
on	doc_491521501753_item	3510638	et	4	main
siiski	doc_491521501753_item	3510639	et	4	main
erand	doc_491521501753_item	3510640	et	3	main
muistend	doc_491521501753_item	3510641	et	3	main
harulikult	doc_491521501753_item	3510642	et	2	main
muinasjutt	doc_491521501753_item	3510649	et	3	main
jutustus	doc_491521501753_item	3510661	et	4	main
edasi	doc_491521501753_item	3510662	et	3	main
kolmandas	doc_491521501753_item	3510663	et	3	main
isikus	doc_491521501753_item	3510664	et	3	main
kui	doc_491521501753_item	3510665	et	3	main
tõsiasi	doc_491521501753_item	3510671	et	3	main
juhtunud	doc_491521501753_item	3510674	et	4	main
jutustaja	doc_491521501753_item	3510675	et	4	main
jne	doc_491521501753_item	3510697	et	4	main
konkreetsuse	doc_491521501753_item	3510700	et	4	main
muistendi	doc_491521501753_item	3510703	et	3	main
jutustaja	doc_491521501753_item	3510704	et	4	main
muistend	doc_491521501753_item	3510711	et	3	main
on	doc_491521501753_item	3510712	et	4	main
lооdud	doc_491521501753_item	3510713	et	2	main
soo	doc_491521501753_item	3510694	et	4	main
allikas	doc_491521501753_item	3510696	et	4	main
saabki	doc_491521501753_item	3510702	et	3	main
tõde	doc_491521501753_item	3510710	et	4	main
me	doc_534729444693_item	3510984	et	4	main
üles	doc_534729444693_item	3510986	et	3	main
sõime	doc_534729444693_item	3510989	et	4	main
hommikust	doc_534729444693_item	3510990	et	4	main
ja	doc_534729444693_item	3510991	et	3	main
tegime	doc_534729444693_item	3510992	et	3	main
leiva	doc_534729444693_item	3510993	et	3	main
sõitjaoks	doc_534729444693_item	3510994	et	2	main
für	doc_534729444693_item	3510995	et	2	main
me	doc_534729444693_item	3511003	et	4	main
ma	doc_534729444693_item	3511012	et	3	main
tõnu	doc_534729444693_item	3511032	et	4	main
koju	doc_534729444693_item	3511033	et	3	main
me	doc_534729444693_item	3511034	et	4	main
jõime	doc_534729444693_item	3511035	et	3	main
pakkisime	doc_534729444693_item	3511069	et	3	main
meile	doc_534729444693_item	3511070	et	4	main
kaks	doc_534729444693_item	3511074	et	3	main
mina	doc_534729444693_item	3511078	et	4	main
oli	doc_534729444693_item	3511108	et	3	main
plaanitu	doc_399014257218_item	3511118	et	4	main
kunstnikud	doc_399014257218_item	3511128	et	3	main
vaatavad	doc_399014257218_item	3511129	et	4	main
viltu	doc_399014257218_item	3511130	et	3	main
mõõdulist	doc_399014257218_item	3511138	et	4	main
jooksul	doc_399014257218_item	3511153	et	4	main
kolm	doc_399014257218_item	3511155	et	3	main
on	doc_399014257218_item	3511158	et	4	main
kavatsus	doc_399014257218_item	3511159	et	4	main
püstitada	doc_399014257218_item	3511160	et	3	main
merre	doc_399014257218_item	3511161	et	3	main
saja	doc_399014257218_item	3511162	et	4	main
linna	doc_399014257218_item	3511190	et	4	main
ja	doc_399014257218_item	3511191	et	3	main
skulptorite	doc_399014257218_item	3511192	et	3	main
idee	doc_399014257218_item	3511205	et	4	main
sobi	doc_399014257218_item	3511212	et	4	main
juuli	doc_534729444693_item	3510983	et	4	main
tõusime	doc_534729444693_item	3510985	et	3	main
die	doc_534729444693_item	3510996	et	4	main
ilus	doc_534729444693_item	3511006	et	4	main
iseloom	doc_534729444693_item	3511007	et	3	main
tegime	doc_534729444693_item	3511009	et	3	main
me	doc_534729444693_item	3511014	et	4	main
pärast	doc_534729444693_item	3511018	et	4	main
ja	doc_534729444693_item	3511023	et	3	main
õlud	doc_534729444693_item	3511025	et	4	main
sandvitši	doc_534729444693_item	3511028	et	2	main
ja	doc_534729444693_item	3511037	et	3	main
ja	doc_534729444693_item	3511077	et	3	main
bussi	doc_534729444693_item	3511080	et	4	main
londonisse	doc_534729444693_item	3511081	et	4	main
tagasi	doc_534729444693_item	3511082	et	3	main
sest	doc_534729444693_item	3511083	et	4	main
esmaspäeval	doc_534729444693_item	3511084	et	3	main
kell	doc_534729444693_item	3511085	et	3	main
kaheksa	doc_534729444693_item	3511086	et	4	main
lendas	doc_534729444693_item	3511087	et	3	main
meile	doc_534729444693_item	3511088	et	4	main
lennuk	doc_534729444693_item	3511089	et	3	main
koju	doc_534729444693_item	3511090	et	3	main
saksamaal	doc_534729444693_item	3511091	et	4	main
aga	doc_534729444693_item	3511092	et	3	main
esialgu	doc_534729444693_item	3511093	et	3	main
istusime	doc_534729444693_item	3511095	et	3	main
me	doc_534729444693_item	3511094	et	4	main
liiga	doc_534729444693_item	3511096	et	4	main
kaua	doc_534729444693_item	3511097	et	3	main
bussis	doc_534729444693_item	3511098	et	3	main
tõnu	doc_534729444693_item	3511099	et	4	main
ja	doc_534729444693_item	3511100	et	3	main
minu	doc_534729444693_item	3511101	et	3	main
pühapäev	doc_534729444693_item	3510981	et	3	main
fahrt	doc_534729444693_item	3510997	et	4	main
autoga	doc_534729444693_item	3511002	et	3	main
läbi	doc_534729444693_item	3511005	et	4	main
järvel	doc_534729444693_item	3511011	et	4	main
tunni	doc_534729444693_item	3511017	et	3	main
matk	doc_534729444693_item	3511019	et	3	main
läksime	doc_534729444693_item	3511021	et	3	main
teed	doc_534729444693_item	3511036	et	4	main
ja	doc_534729444693_item	3511072	et	3	main
ööl	doc_534729444693_item	3511075	et	3	main
oli	doc_534729444693_item	3511103	et	3	main
suurepärane	doc_534729444693_item	3511109	et	4	main
üks	doc_534729444693_item	3511059	et	3	main
kesköösöök	doc_534729444693_item	3511060	et	2	main
ein	doc_534729444693_item	3511061	et	2	main
mitternachtsessen	doc_534729444693_item	3511062	et	4	main
me	doc_534729444693_item	3511063	et	4	main
keetsime	doc_534729444693_item	3511064	et	3	main
alati	doc_534729444693_item	3511065	et	4	main
makarooni	doc_534729444693_item	3511066	et	4	main
siis	doc_534729444693_item	3511067	et	3	main
30	doc_534729444693_item	3510982	et	2	main
kaheksa	doc_534729444693_item	3510988	et	4	main
me	doc_534729444693_item	3510998	et	4	main
sõitsime	doc_534729444693_item	3510999	et	3	main
lake	doc_534729444693_item	3511000	et	4	main
matkasime	doc_534729444693_item	3511004	et	3	main
mõtlen	doc_534729444693_item	3511013	et	3	main
kõrtsi	doc_534729444693_item	3511022	et	4	main
sõime	doc_534729444693_item	3511027	et	4	main
me	doc_534729444693_item	3511030	et	4	main
jõudsime	doc_534729444693_item	3511031	et	3	main
ajaleht	doc_534729444693_item	3511039	et	3	main
kell	doc_534729444693_item	3511040	et	3	main
kümme	doc_534729444693_item	3511041	et	3	main
me	doc_534729444693_item	3511042	et	4	main
kothusime	doc_534729444693_item	3511043	et	4	main
sõbrannaga	doc_534729444693_item	3511044	et	3	main
marelt	doc_534729444693_item	3511045	et	2	main
kõrtsis	doc_534729444693_item	3511046	et	3	main
jah	doc_534729444693_item	3511047	et	3	main
me	doc_534729444693_item	3511048	et	4	main
jõime	doc_534729444693_item	3511049	et	3	main
jälle	doc_534729444693_item	3511050	et	3	main
õlud	doc_534729444693_item	3511051	et	4	main
kell	doc_534729444693_item	3511052	et	3	main
üksteist	doc_534729444693_item	3511053	et	4	main
me	doc_534729444693_item	3511054	et	4	main
läksime	doc_534729444693_item	3511055	et	3	main
koju	doc_534729444693_item	3511056	et	3	main
ja	doc_534729444693_item	3511057	et	3	main
tegime	doc_534729444693_item	3511058	et	3	main
ühingud	doc_399014257218_item	3511114	et	3	main
kujule	doc_399014257218_item	3511121	et	3	main
tallinna	doc_399014257218_item	3511122	et	4	main
jäeti	doc_399014257218_item	3511124	et	3	main
kolm	doc_399014257218_item	3511125	et	3	main
konkursitööd	doc_399014257218_item	3511126	et	4	main
plaanile	doc_399014257218_item	3511133	et	3	main
püstitada	doc_399014257218_item	3511134	et	3	main
tallinna	doc_399014257218_item	3511135	et	4	main
meetrid	doc_399014257218_item	3511140	et	3	main
eesti	doc_399014257218_item	3511143	et	4	main
rahvaeepose	doc_399014257218_item	3511145	et	3	main
vägilase	doc_399014257218_item	3511146	et	3	main
järgi	doc_399014257218_item	3511147	et	4	main
lahkarvamused	doc_399014257218_item	3511193	et	3	main
on	doc_399014257218_item	3511206	et	4	main
ka	doc_399014257218_item	3511223	et	3	main
arhitektide	doc_399014257218_item	3511224	et	3	main
esindajad	doc_399014257218_item	3511225	et	4	main
žüriist	doc_399014257218_item	3511226	et	2	main
protestiks	doc_399014257218_item	3511228	et	4	main
ametnikkude	doc_399014257218_item	3511230	et	3	main
algupärase	doc_399014257218_item	3511249	et	4	main
siiski	doc_399014257218_item	3511253	et	4	main
vaidlusealust	doc_399014257218_item	3511255	et	3	main
sümbool	doc_399014257218_item	3511272	et	4	main
on	doc_399014257218_item	3511274	et	4	main
merineitsi	doc_399014257218_item	3511276	et	4	main
oli	doc_399014257218_item	3511281	et	3	main
tallinna	doc_399014257218_item	3511282	et	4	main
kui	doc_534729444693_item	3511029	et	3	main
lugesime	doc_534729444693_item	3511038	et	3	main
me	doc_534729444693_item	3511068	et	4	main
pagasi	doc_534729444693_item	3511071	et	3	main
kell	doc_534729444693_item	3511073	et	3	main
tõnu	doc_534729444693_item	3511076	et	4	main
läksime	doc_534729444693_item	3511079	et	3	main
väga	doc_534729444693_item	3511104	et	3	main
ilus	doc_534729444693_item	3511105	et	4	main
ja	doc_534729444693_item	3511106	et	3	main
aeg	doc_534729444693_item	3511107	et	3	main
tõlge	doc_399014257218_item	3511112	et	3	main
tallinnalahte	doc_399014257218_item	3511117	et	4	main
kalevipoja	doc_399014257218_item	3511120	et	4	main
linnale	doc_399014257218_item	3511123	et	4	main
21	doc_399014257218_item	3511139	et	2	main
samanimelise	doc_399014257218_item	3511144	et	4	main
linna	doc_399014257218_item	3511148	et	4	main
ainult	doc_399014257218_item	3511154	et	4	main
kalevipoeg	doc_399014257218_item	3511157	et	3	main
eesti	doc_399014257218_item	3511202	et	4	main
kujurite	doc_399014257218_item	3511203	et	3	main
ühingu	doc_399014257218_item	3511204	et	3	main
vägilane	doc_399014257218_item	3511211	et	3	main
skuptorite	doc_399014257218_item	3511221	et	4	main
kui	doc_399014257218_item	3511222	et	3	main
jüri	doc_399014257218_item	3511233	et	4	main
ratase	doc_399014257218_item	3511234	et	4	main
maastikuarhitekt	doc_399014257218_item	3511243	et	3	main
parke	doc_399014257218_item	3511248	et	3	main
kes	doc_399014257218_item	3511259	et	4	main
hakkas	doc_399014257218_item	3511260	et	3	main
rajada	doc_399014257218_item	3511269	et	3	main
kopenhagenile	doc_399014257218_item	3511278	et	4	main
kõrge	doc_399014257218_item	3511288	et	4	main
aga	doc_399014257218_item	3511289	et	3	main
linna	doc_399014257218_item	3511290	et	4	main
ettepanek	doc_399014257218_item	3511291	et	3	main
meetrini	doc_399014257218_item	3511297	et	3	main
kuidas	doc_399014257218_item	3511299	et	3	main
parem	doc_399014257218_item	3511315	et	4	main
se	doc_399014257218_item	3511316	et	4	main
abilinnapea	doc_399014257218_item	3511321	et	4	main
see	doc_399014257218_item	3511333	et	3	main
peale	doc_399014257218_item	3511336	et	4	main
pirita	doc_399014257218_item	3511338	et	4	main
spasse	doc_399014257218_item	3511339	et	4	main
ning	doc_399014257218_item	3511340	et	3	main
vana	doc_399014257218_item	3511345	et	4	main
esmaspäevalgi	doc_399014257218_item	3511355	et	4	main
innustunud	doc_399014257218_item	3511356	et	4	main
kui	doc_399014257218_item	3511382	et	3	main
käes	doc_399014257218_item	3511390	et	4	main
paat	doc_399014257218_item	3511391	et	3	main
inimolendid	doc_399014257218_item	3511394	et	3	main
on	doc_399014257218_item	3511418	et	4	main
ainult	doc_399014257218_item	3511420	et	4	main
keskerakonna	doc_399014257218_item	3511421	et	4	main
väga	doc_399014257218_item	3511426	et	3	main
projekti	doc_399014257218_item	3511435	et	4	main
kriitika	doc_399014257218_item	3511445	et	4	main
järgi	doc_399014257218_item	3511453	et	4	main
viskas	doc_399014257218_item	3511454	et	3	main
suuri	doc_399014257218_item	3511455	et	3	main
kivi	doc_399014257218_item	3511456	et	4	main
vaenlaste	doc_399014257218_item	3511457	et	3	main
kaela	doc_399014257218_item	3511458	et	4	main
ka	doc_399014257218_item	3511462	et	3	main
merre	doc_399014257218_item	3511472	et	3	main
sümbol	doc_399014257218_item	3511474	et	3	main
tulemused	doc_399014257218_item	3511476	et	3	main
lõpus	doc_399014257218_item	3511479	et	4	main
pärast	doc_399014257218_item	3511480	et	4	main
korraldatakse	doc_399014257218_item	3511481	et	3	main
abilinnapea	doc_399014257218_item	3511484	et	4	main
rajada	doc_399014257218_item	3511490	et	3	main
järgmise	doc_399014257218_item	3511491	et	3	main
ning	doc_399014257218_item	3511492	et	3	main
ülejärgmise	doc_399014257218_item	3511493	et	3	main
aasta	doc_399014257218_item	3511494	et	4	main
puhkus	doc_534729444693_item	3511102	et	3	main
inglisemaal	doc_534729444693_item	3511110	et	4	main
kunstnike	doc_399014257218_item	3511113	et	3	main
vaatavad	doc_399014257218_item	3511115	et	4	main
hiiglaslik	doc_399014257218_item	3511119	et	3	main
tallinna	doc_399014257218_item	3511131	et	4	main
linna	doc_399014257218_item	3511132	et	4	main
korrusmaja	doc_399014257218_item	3511137	et	4	main
kalevipoega	doc_399014257218_item	3511142	et	4	main
korraldatud	doc_399014257218_item	3511149	et	4	main
tähtaja	doc_399014257218_item	3511152	et	3	main
konkursiettepanekud	doc_399014257218_item	3511156	et	3	main
rannatrepid	doc_399014257218_item	3511189	et	3	main
alguse	doc_399014257218_item	3511195	et	3	main
kuju	doc_399014257218_item	3511197	et	4	main
iseenesest	doc_399014257218_item	3511207	et	4	main
lahkusid	doc_399014257218_item	3511219	et	4	main
nii	doc_399014257218_item	3511220	et	3	main
vastu	doc_399014257218_item	3511231	et	3	main
juhitava	doc_399014257218_item	3511236	et	4	main
ainus	doc_399014257218_item	3511238	et	4	main
sõltumatu	doc_399014257218_item	3511239	et	4	main
kunstnikliige	doc_399014257218_item	3511240	et	3	main
oli	doc_399014257218_item	3511241	et	3	main
linnale	doc_399014257218_item	3511247	et	4	main
idee	doc_399014257218_item	3511250	et	4	main
kalevipoja	doc_399014257218_item	3511262	et	4	main
samasugune	doc_399014257218_item	3511271	et	3	main
väike	doc_399014257218_item	3511275	et	4	main
algupärases	doc_399014257218_item	3511279	et	4	main
plaanis	doc_399014257218_item	3511280	et	4	main
tuli	doc_399014257218_item	3511292	et	4	main
21	doc_399014257218_item	3511296	et	2	main
vaatasime	doc_399014257218_item	3511298	et	3	main
viltu	doc_399014257218_item	3511116	et	3	main
eesti	doc_399014257218_item	3511127	et	4	main
lahte	doc_399014257218_item	3511136	et	4	main
kõrget	doc_399014257218_item	3511141	et	4	main
konkursile	doc_399014257218_item	3511150	et	3	main
jäeti	doc_399014257218_item	3511151	et	3	main
meetri	doc_399014257218_item	3511163	et	3	main
kaugusele	doc_399014257218_item	3511164	et	4	main
rannast	doc_399014257218_item	3511165	et	4	main
tallinnast	doc_399014257218_item	3511166	et	3	main
pirita	doc_399014257218_item	3511167	et	4	main
poole	doc_399014257218_item	3511168	et	4	main
suunduva	doc_399014257218_item	3511169	et	4	main
rannatee	doc_399014257218_item	3511170	et	4	main
kõrvale	doc_399014257218_item	3511171	et	4	main
praegu	doc_399014257218_item	3511172	et	3	main
seisab	doc_399014257218_item	3511173	et	3	main
seal	doc_399014257218_item	3511174	et	4	main
nõukogudeajast	doc_399014257218_item	3511175	et	4	main
teise	doc_399014257218_item	3511176	et	4	main
maailmasõja	doc_399014257218_item	3511177	et	3	main
sangaritele	doc_399014257218_item	3511178	et	3	main
rajatud	doc_399014257218_item	3511179	et	4	main
mälestussammaste	doc_399014257218_item	3511180	et	4	main
kompleks	doc_399014257218_item	3511181	et	4	main
millest	doc_399014257218_item	3511182	et	3	main
on	doc_399014257218_item	3511183	et	4	main
näha	doc_399014257218_item	3511184	et	3	main
merele	doc_399014257218_item	3511185	et	3	main
kõrge	doc_399014257218_item	3511186	et	4	main
obelisk	doc_399014257218_item	3511187	et	3	main
ning	doc_399014257218_item	3511188	et	3	main
saavad	doc_399014257218_item	3511194	et	4	main
alates	doc_399014257218_item	3511196	et	3	main
suurusest	doc_399014257218_item	3511198	et	4	main
ning	doc_399014257218_item	3511199	et	3	main
asukohast	doc_399014257218_item	3511200	et	4	main
meres	doc_399014257218_item	3511201	et	3	main
vananenud	doc_399014257218_item	3511208	et	4	main
ega	doc_399014257218_item	3511209	et	3	main
rahvuseepose	doc_399014257218_item	3511210	et	3	main
kui	doc_399014257218_item	3511227	et	3	main
linnapea	doc_399014257218_item	3511232	et	4	main
32	doc_399014257218_item	3511235	et	2	main
žürii	doc_399014257218_item	3511237	et	2	main
on	doc_399014257218_item	3511245	et	4	main
planeerinud	doc_399014257218_item	3511246	et	4	main
peetakse	doc_399014257218_item	3511252	et	3	main
kunstniku	doc_399014257218_item	3511254	et	3	main
tauno	doc_399014257218_item	3511256	et	4	main
pooldama	doc_399014257218_item	3511261	et	3	main
püstitamist	doc_399014257218_item	3511263	et	4	main
1990	doc_399014257218_item	3511265	et	2	main
tallinnale	doc_399014257218_item	3511270	et	4	main
nagu	doc_399014257218_item	3511273	et	3	main
merineitsi	doc_399014257218_item	3511284	et	4	main
ainult	doc_399014257218_item	3511285	et	4	main
14	doc_399014257218_item	3511286	et	2	main
meetrid	doc_399014257218_item	3511287	et	3	main
lisada	doc_399014257218_item	3511293	et	3	main
kuni	doc_399014257218_item	3511295	et	3	main
kuju	doc_399014257218_item	3511300	et	4	main
kohe	doc_399014257218_item	3511318	et	4	main
sõtniku	doc_399014257218_item	3511324	et	4	main
parim	doc_399014257218_item	3511331	et	4	main
ei	doc_399014257218_item	3511343	et	4	main
silhuetti	doc_399014257218_item	3511347	et	4	main
on	doc_399014257218_item	3511389	et	4	main
voli	doc_399014257218_item	3511419	et	4	main
on	doc_399014257218_item	3511425	et	4	main
juba	doc_399014257218_item	3511428	et	3	main
kõrged	doc_399014257218_item	3511430	et	3	main
vastu	doc_399014257218_item	3511436	et	3	main
on	doc_399014257218_item	3511446	et	4	main
esitatud	doc_399014257218_item	3511447	et	4	main
ka	doc_399014257218_item	3511448	et	3	main
kalevipoja	doc_399014257218_item	3511449	et	4	main
vastu	doc_399014257218_item	3511450	et	3	main
kes	doc_399014257218_item	3511451	et	4	main
muinasjutu	doc_399014257218_item	3511452	et	3	main
meres	doc_399014257218_item	3511463	et	3	main
on	doc_399014257218_item	3511471	et	4	main
töödest	doc_399014257218_item	3511482	et	3	main
kuju	doc_399014257218_item	3511487	et	4	main
on	doc_399014257218_item	3511488	et	4	main
nõukogudeaja	doc_399014257218_item	3511213	et	3	main
mälestussambakompleksiga	doc_399014257218_item	3511214	et	4	main
kokku	doc_399014257218_item	3511215	et	3	main
juba	doc_399014257218_item	3511216	et	3	main
varem	doc_399014257218_item	3511217	et	4	main
sügisel	doc_399014257218_item	3511218	et	3	main
žürii	doc_399014257218_item	3511229	et	2	main
lõpuks	doc_399014257218_item	3511242	et	4	main
kes	doc_399014257218_item	3511244	et	4	main
isaks	doc_399014257218_item	3511251	et	3	main
kangro	doc_399014257218_item	3511257	et	4	main
40	doc_399014257218_item	3511258	et	2	main
juba	doc_399014257218_item	3511264	et	3	main
lõpus	doc_399014257218_item	3511266	et	4	main
idee	doc_399014257218_item	3511267	et	4	main
oli	doc_399014257218_item	3511268	et	3	main
on	doc_399014257218_item	3511277	et	4	main
visualiseerime	doc_399014257218_item	3511307	et	4	main
siis	doc_399014257218_item	3511308	et	3	main
otsustati	doc_399014257218_item	3511309	et	3	main
et	doc_399014257218_item	3511310	et	3	main
21	doc_399014257218_item	3511311	et	2	main
meetrid	doc_399014257218_item	3511312	et	3	main
kõige	doc_399014257218_item	3511314	et	4	main
põhjendab	doc_399014257218_item	3511320	et	3	main
olga	doc_399014257218_item	3511322	et	4	main
sõtnik	doc_399014257218_item	3511323	et	4	main
kõige	doc_399014257218_item	3511330	et	4	main
jääb	doc_399014257218_item	3511334	et	3	main
tauno	doc_399014257218_item	3511348	et	4	main
kangro	doc_399014257218_item	3511349	et	4	main
asuvas	doc_399014257218_item	3511351	et	4	main
galleriis	doc_399014257218_item	3511352	et	4	main
valitses	doc_399014257218_item	3511353	et	3	main
pärast	doc_399014257218_item	3511380	et	4	main
seda	doc_399014257218_item	3511381	et	3	main
ja	doc_399014257218_item	3511392	et	3	main
mis	doc_399014257218_item	3511395	et	4	main
boigoteerib	doc_399014257218_item	3511402	et	4	main
ka	doc_399014257218_item	3511404	et	3	main
tallinnas	doc_399014257218_item	3511417	et	4	main
käes	doc_399014257218_item	3511422	et	4	main
ja	doc_399014257218_item	3511423	et	3	main
kritiik	doc_399014257218_item	3511434	et	4	main
siis	doc_399014257218_item	3511438	et	3	main
sai	doc_399014257218_item	3511442	et	4	main
tema	doc_399014257218_item	3511469	et	4	main
üldse	doc_399014257218_item	3511470	et	3	main
jaanuari	doc_399014257218_item	3511478	et	4	main
väike	doc_399014257218_item	3511283	et	4	main
kõrgust	doc_399014257218_item	3511294	et	4	main
sobiks	doc_399014257218_item	3511301	et	4	main
maarjamäe	doc_399014257218_item	3511302	et	3	main
mälestuskompleksiga	doc_399014257218_item	3511303	et	4	main
kokku	doc_399014257218_item	3511304	et	3	main
kalkuleerisime	doc_399014257218_item	3511305	et	3	main
ja	doc_399014257218_item	3511306	et	3	main
silma	doc_399014257218_item	3511319	et	4	main
meelest	doc_399014257218_item	3511325	et	4	main
botaanikaaeda	doc_399014257218_item	3511341	et	4	main
ega	doc_399014257218_item	3511342	et	3	main
linna	doc_399014257218_item	3511346	et	4	main
vanalinnas	doc_399014257218_item	3511350	et	4	main
meeleolu	doc_399014257218_item	3511357	et	4	main
kunstnik	doc_399014257218_item	3511358	et	3	main
sümboliseerib	doc_399014257218_item	3511377	et	3	main
sangari	doc_399014257218_item	3511378	et	3	main
kojutulek	doc_399014257218_item	3511379	et	3	main
oli	doc_399014257218_item	3511384	et	3	main
ringi	doc_399014257218_item	3511386	et	4	main
käinud	doc_399014257218_item	3511387	et	4	main
sangaril	doc_399014257218_item	3511388	et	3	main
sümboliseerivad	doc_399014257218_item	3511396	et	4	main
eestlaste	doc_399014257218_item	3511397	et	4	main
kojutulekut	doc_399014257218_item	3511398	et	3	main
peale	doc_399014257218_item	3511399	et	4	main
skulptorite	doc_399014257218_item	3511400	et	3	main
projektit	doc_399014257218_item	3511403	et	4	main
sellele	doc_399014257218_item	3511424	et	4	main
ehitised	doc_399014257218_item	3511431	et	3	main
suurenes	doc_399014257218_item	3511437	et	4	main
suvel	doc_399014257218_item	3511441	et	3	main
keskerakonna	doc_399014257218_item	3511443	et	4	main
liige	doc_399014257218_item	3511444	et	4	main
aga	doc_399014257218_item	3511459	et	3	main
siis	doc_399014257218_item	3511460	et	3	main
vägistas	doc_399014257218_item	3511461	et	3	main
üht	doc_399014257218_item	3511464	et	3	main
neiukest	doc_399014257218_item	3511465	et	4	main
küsitakse	doc_399014257218_item	3511466	et	4	main
siis	doc_399014257218_item	3511467	et	3	main
kas	doc_399014257218_item	3511468	et	3	main
sõtniku	doc_399014257218_item	3511485	et	4	main
järgi	doc_399014257218_item	3511486	et	4	main
kavatsus	doc_399014257218_item	3511489	et	4	main
oleks	doc_399014257218_item	3511313	et	3	main
jääks	doc_399014257218_item	3511317	et	4	main
on	doc_399014257218_item	3511326	et	4	main
ka	doc_399014257218_item	3511327	et	3	main
see	doc_399014257218_item	3511328	et	3	main
koht	doc_399014257218_item	3511329	et	3	main
sest	doc_399014257218_item	3511332	et	4	main
tee	doc_399014257218_item	3511335	et	4	main
tallinnast	doc_399014257218_item	3511337	et	3	main
sega	doc_399014257218_item	3511344	et	4	main
veel	doc_399014257218_item	3511354	et	4	main
ise	doc_399014257218_item	3511359	et	4	main
polnud	doc_399014257218_item	3511360	et	3	main
linnas	doc_399014257218_item	3511361	et	4	main
aga	doc_399014257218_item	3511362	et	3	main
gallerist	doc_399014257218_item	3511363	et	4	main
pille	doc_399014257218_item	3511364	et	3	main
mägila	doc_399014257218_item	3511365	et	4	main
näitas	doc_399014257218_item	3511366	et	3	main
innukalt	doc_399014257218_item	3511367	et	4	main
pronksist	doc_399014257218_item	3511368	et	4	main
kuju	doc_399014257218_item	3511369	et	4	main
milles	doc_399014257218_item	3511370	et	3	main
suurte	doc_399014257218_item	3511371	et	3	main
kätega	doc_399014257218_item	3511372	et	3	main
kalevipoeg	doc_399014257218_item	3511373	et	3	main
kannab	doc_399014257218_item	3511374	et	3	main
paadi	doc_399014257218_item	3511375	et	3	main
kuju	doc_399014257218_item	3511376	et	4	main
ta	doc_399014257218_item	3511383	et	4	main
ilma	doc_399014257218_item	3511385	et	4	main
mõned	doc_399014257218_item	3511393	et	3	main
ühingu	doc_399014257218_item	3511401	et	3	main
mõjukam	doc_399014257218_item	3511405	et	4	main
arhitektide	doc_399014257218_item	3511406	et	3	main
ühing	doc_399014257218_item	3511407	et	3	main
mis	doc_399014257218_item	3511408	et	4	main
linnaga	doc_399014257218_item	3511409	et	3	main
vaidleb	doc_399014257218_item	3511410	et	3	main
mh	doc_399014257218_item	3511411	et	3	main
ka	doc_399014257218_item	3511412	et	3	main
uue	doc_399014257218_item	3511413	et	3	main
linnavalitsuse	doc_399014257218_item	3511414	et	3	main
hoone	doc_399014257218_item	3511415	et	4	main
asukohast	doc_399014257218_item	3511416	et	4	main
meeldinud	doc_399014257218_item	3511427	et	4	main
varem	doc_399014257218_item	3511429	et	4	main
ülejäänute	doc_399014257218_item	3511432	et	4	main
kunstnikute	doc_399014257218_item	3511433	et	4	main
kui	doc_399014257218_item	3511439	et	3	main
kangrost	doc_399014257218_item	3511440	et	4	main
sobiv	doc_399014257218_item	3511473	et	4	main
võistluse	doc_399014257218_item	3511475	et	3	main
avaldatakse	doc_399014257218_item	3511477	et	3	main
näitus	doc_399014257218_item	3511483	et	3	main
jooksul	doc_399014257218_item	3511495	et	4	main
liidud	doc_399014257225_item	3512262	et	3	main
lahte	doc_399014257225_item	3512266	et	4	main
hiigelsuure	doc_399014257225_item	3512268	et	3	main
võistlustööd	doc_399014257225_item	3512276	et	4	main
kunstnikud	doc_399014257225_item	3512278	et	3	main
eesti	doc_399014257225_item	3512293	et	4	main
ainult	doc_399014257225_item	3512306	et	4	main
plaanis	doc_399014257225_item	3512311	et	4	main
merre	doc_399014257225_item	3512314	et	3	main
meetri	doc_399014257225_item	3512316	et	3	main
kaugusele	doc_399014257225_item	3512317	et	4	main
rannast	doc_399014257225_item	3512318	et	4	main
pirita	doc_399014257225_item	3512319	et	4	main
oli	doc_399014257225_item	3512326	et	3	main
iseenesest	doc_399014257225_item	3512361	et	4	main
varem	doc_399014257225_item	3512372	et	4	main
skulptorite	doc_399014257225_item	3512375	et	3	main
ametiühingud	doc_399014257225_item	3512379	et	3	main
esindajad	doc_399014257225_item	3512383	et	4	main
linnapea	doc_399014257225_item	3512394	et	4	main
jüri	doc_399014257225_item	3512395	et	4	main
jäänud	doc_399014257225_item	3512405	et	4	main
planeerinud	doc_399014257225_item	3512409	et	4	main
oli	doc_399014257225_item	3512413	et	3	main
kõrvutada	doc_399014257225_item	3512437	et	3	main
kopenhaageni	doc_399014257225_item	3512438	et	4	main
kuju	doc_399014257225_item	3512461	et	4	main
sobib	doc_399014257225_item	3512466	et	3	main
kalkulatsioone	doc_399014257225_item	3512468	et	3	main
see	doc_399014257225_item	3512476	et	3	main
olga	doc_399014257225_item	3512482	et	4	main
koht	doc_399014257225_item	3512487	et	3	main
minnes	doc_399014257225_item	3512506	et	3	main
õhkkond	doc_399014257225_item	3512514	et	3	main
veel	doc_399014257225_item	3512522	et	4	main
viltu	doc_399014257225_item	3512264	et	3	main
tallinna	doc_399014257225_item	3512265	et	4	main
kuju	doc_399014257225_item	3512270	et	4	main
peale	doc_399014257225_item	3512271	et	4	main
linnale	doc_399014257225_item	3512273	et	4	main
laekus	doc_399014257225_item	3512274	et	3	main
kolm	doc_399014257225_item	3512275	et	3	main
viltu	doc_399014257225_item	3512280	et	3	main
plaani	doc_399014257225_item	3512283	et	4	main
peale	doc_399014257225_item	3512284	et	4	main
rajada	doc_399014257225_item	3512285	et	3	main
kõrghoone	doc_399014257225_item	3512288	et	4	main
samanimelise	doc_399014257225_item	3512294	et	4	main
rahvuseepose	doc_399014257225_item	3512295	et	3	main
korraldatud	doc_399014257225_item	3512300	et	4	main
kolm	doc_399014257225_item	3512307	et	3	main
koha	doc_399014257225_item	3512323	et	4	main
mälestuseks	doc_399014257225_item	3512332	et	4	main
idee	doc_399014257225_item	3512360	et	4	main
ei	doc_399014257225_item	3512367	et	4	main
nõukogudeaegse	doc_399014257225_item	3512369	et	3	main
kutsusid	doc_399014257225_item	3512380	et	4	main
oma	doc_399014257225_item	3512382	et	4	main
žüriis	doc_399014257225_item	3512384	et	2	main
protestina	doc_399014257225_item	3512385	et	3	main
selle	doc_399014257225_item	3512386	et	4	main
vastu	doc_399014257225_item	3512387	et	3	main
et	doc_399014257225_item	3512388	et	3	main
žürii	doc_399014257225_item	3512389	et	2	main
ülekaal	doc_399014257225_item	3512390	et	3	main
linna	doc_399014257225_item	3512410	et	4	main
tõlge	doc_399014257225_item	3512260	et	3	main
plaanitud	doc_399014257225_item	3512267	et	4	main
kalevipoja	doc_399014257225_item	3512269	et	4	main
tallinna	doc_399014257225_item	3512286	et	4	main
kõrguses	doc_399014257225_item	3512289	et	4	main
21	doc_399014257225_item	3512290	et	2	main
kangelaskuju	doc_399014257225_item	3512296	et	4	main
poolt	doc_399014257225_item	3512299	et	4	main
võistlusele	doc_399014257225_item	3512301	et	3	main
oli	doc_399014257225_item	3512302	et	3	main
tähtajaks	doc_399014257225_item	3512303	et	3	main
panna	doc_399014257225_item	3512313	et	4	main
kunstnike	doc_399014257225_item	3512261	et	3	main
eesti	doc_399014257225_item	3512277	et	4	main
tallinna	doc_399014257225_item	3512281	et	4	main
linna	doc_399014257225_item	3512282	et	4	main
lahte	doc_399014257225_item	3512287	et	4	main
kalevipoeg	doc_399014257225_item	3512292	et	3	main
esmaspäeval	doc_399014257225_item	3512304	et	3	main
laekunud	doc_399014257225_item	3512305	et	4	main
püsti	doc_399014257225_item	3512312	et	3	main
saja	doc_399014257225_item	3512315	et	4	main
äärde	doc_399014257225_item	3512321	et	4	main
rannas	doc_399014257225_item	3512325	et	3	main
ajal	doc_399014257225_item	3512328	et	4	main
vaatavad	doc_399014257225_item	3512263	et	4	main
tallinna	doc_399014257225_item	3512272	et	4	main
vaatavad	doc_399014257225_item	3512279	et	4	main
meetrine	doc_399014257225_item	3512291	et	4	main
järgi	doc_399014257225_item	3512297	et	4	main
linna	doc_399014257225_item	3512298	et	4	main
võistlustööd	doc_399014257225_item	3512308	et	4	main
kalevipoeg	doc_399014257225_item	3512309	et	3	main
on	doc_399014257225_item	3512310	et	4	main
vastava	doc_399014257225_item	3512322	et	4	main
teise	doc_399014257225_item	3512329	et	4	main
maailmasõja	doc_399014257225_item	3512330	et	3	main
kangelaste	doc_399014257225_item	3512331	et	4	main
rajatud	doc_399014257225_item	3512333	et	4	main
mälestusmärkide	doc_399014257225_item	3512334	et	3	main
kompleks	doc_399014257225_item	3512335	et	4	main
millest	doc_399014257225_item	3512336	et	3	main
oli	doc_399014257225_item	3512337	et	3	main
merele	doc_399014257225_item	3512338	et	3	main
näha	doc_399014257225_item	3512339	et	3	main
kõrge	doc_399014257225_item	3512340	et	4	main
obelisk	doc_399014257225_item	3512341	et	3	main
ning	doc_399014257225_item	3512342	et	3	main
kaldatrepp	doc_399014257225_item	3512343	et	3	main
juba	doc_399014257225_item	3512344	et	3	main
kuju	doc_399014257225_item	3512345	et	4	main
suurus	doc_399014257225_item	3512346	et	4	main
ja	doc_399014257225_item	3512347	et	3	main
koht	doc_399014257225_item	3512348	et	3	main
meres	doc_399014257225_item	3512349	et	3	main
tekitavad	doc_399014257225_item	3512350	et	4	main
erimeelsusi	doc_399014257225_item	3512351	et	4	main
linna	doc_399014257225_item	3512352	et	4	main
ja	doc_399014257225_item	3512353	et	3	main
skulptorite	doc_399014257225_item	3512354	et	3	main
ühingu	doc_399014257225_item	3512355	et	3	main
vahel	doc_399014257225_item	3512356	et	4	main
eesti	doc_399014257225_item	3512357	et	4	main
skulptorite	doc_399014257225_item	3512358	et	3	main
ühingu	doc_399014257225_item	3512359	et	3	main
vanenud	doc_399014257225_item	3512363	et	4	main
rahvuseepose	doc_399014257225_item	3512365	et	3	main
mälestusmärgi	doc_399014257225_item	3512370	et	4	main
juurde	doc_399014257225_item	3512371	et	4	main
ka	doc_399014257225_item	3512377	et	3	main
on	doc_399014257225_item	3512391	et	4	main
juhitud	doc_399014257225_item	3512398	et	4	main
ainsaks	doc_399014257225_item	3512400	et	3	main
väikese	doc_399014257225_item	3512439	et	4	main
merineitsiga	doc_399014257225_item	3512440	et	3	main
originaalplaanis	doc_399014257225_item	3512441	et	3	main
oli	doc_399014257225_item	3512442	et	3	main
tallinna	doc_399014257225_item	3512443	et	4	main
väike	doc_399014257225_item	3512444	et	4	main
tee	doc_399014257225_item	3512320	et	4	main
peal	doc_399014257225_item	3512324	et	4	main
nõukogude	doc_399014257225_item	3512327	et	3	main
on	doc_399014257225_item	3512362	et	4	main
kangelane	doc_399014257225_item	3512366	et	3	main
sobi	doc_399014257225_item	3512368	et	4	main
kui	doc_399014257225_item	3512376	et	3	main
tagasi	doc_399014257225_item	3512381	et	3	main
ametnike	doc_399014257225_item	3512392	et	3	main
ratas	doc_399014257225_item	3512396	et	3	main
žürii	doc_399014257225_item	3512399	et	2	main
maastikuarhitket	doc_399014257225_item	3512406	et	4	main
kes	doc_399014257225_item	3512407	et	4	main
on	doc_399014257225_item	3512408	et	4	main
14	doc_399014257225_item	3512447	et	2	main
kuidas	doc_399014257225_item	3512460	et	3	main
asja	doc_399014257225_item	3512480	et	4	main
järgi	doc_399014257225_item	3512485	et	4	main
on	doc_399014257225_item	3512486	et	4	main
tee	doc_399014257225_item	3512502	et	4	main
peale	doc_399014257225_item	3512503	et	4	main
see	doc_399014257225_item	3512510	et	3	main
vanalinna	doc_399014257225_item	3512517	et	4	main
galerii	doc_399014257225_item	3512518	et	4	main
linnas	doc_399014257225_item	3512526	et	4	main
galerist	doc_399014257225_item	3512530	et	4	main
pille	doc_399014257225_item	3512531	et	3	main
mäglia	doc_399014257225_item	3512532	et	4	main
mis	doc_399014257225_item	3512561	et	4	main
on	doc_399014257225_item	3512562	et	4	main
boikoteerib	doc_399014257225_item	3512569	et	3	main
mõjukam	doc_399014257225_item	3512571	et	4	main
mis	doc_399014257225_item	3512574	et	4	main
on	doc_399014257225_item	3512575	et	4	main
linnaga	doc_399014257225_item	3512576	et	3	main
asukoha	doc_399014257225_item	3512582	et	4	main
on	doc_399014257225_item	3512586	et	4	main
tallinnas	doc_399014257225_item	3512587	et	4	main
võimul	doc_399014257225_item	3512588	et	3	main
keskerakond	doc_399014257225_item	3512589	et	3	main
suurenes	doc_399014257225_item	3512601	et	4	main
liitus	doc_399014257225_item	3512611	et	4	main
ise	doc_399014257225_item	3512618	et	4	main
suurte	doc_399014257225_item	3512624	et	3	main
ka	doc_399014257225_item	3512627	et	3	main
ja	doc_399014257225_item	3512364	et	3	main
sügisel	doc_399014257225_item	3512373	et	3	main
nii	doc_399014257225_item	3512374	et	3	main
arhitektide	doc_399014257225_item	3512378	et	3	main
käes	doc_399014257225_item	3512393	et	4	main
32	doc_399014257225_item	3512397	et	2	main
sõltumatuks	doc_399014257225_item	3512401	et	4	main
kunstnikust	doc_399014257225_item	3512402	et	3	main
liikmeks	doc_399014257225_item	3512403	et	3	main
on	doc_399014257225_item	3512404	et	4	main
parke	doc_399014257225_item	3512411	et	3	main
alguses	doc_399014257225_item	3512412	et	4	main
idee	doc_399014257225_item	3512414	et	4	main
isaks	doc_399014257225_item	3512415	et	3	main
siiski	doc_399014257225_item	3512416	et	4	main
kunstnik	doc_399014257225_item	3512417	et	3	main
vaieldud	doc_399014257225_item	3512418	et	4	main
skulptor	doc_399014257225_item	3512419	et	3	main
tauno	doc_399014257225_item	3512420	et	4	main
kangro	doc_399014257225_item	3512421	et	4	main
40	doc_399014257225_item	3512422	et	2	main
kes	doc_399014257225_item	3512423	et	4	main
hakkas	doc_399014257225_item	3512424	et	3	main
kalevipoeg-projekti	doc_399014257225_item	3512425	et	4	main
turundama	doc_399014257225_item	3512426	et	4	main
juba	doc_399014257225_item	3512427	et	3	main
1990ndate	doc_399014257225_item	3512428	et	4	main
lõpus	doc_399014257225_item	3512429	et	4	main
ideeks	doc_399014257225_item	3512430	et	3	main
oli	doc_399014257225_item	3512431	et	3	main
luua	doc_399014257225_item	3512432	et	4	main
tallinnale	doc_399014257225_item	3512433	et	4	main
sümbol	doc_399014257225_item	3512434	et	3	main
mida	doc_399014257225_item	3512435	et	4	main
saaks	doc_399014257225_item	3512436	et	3	main
merineitsi	doc_399014257225_item	3512445	et	4	main
kõrgune	doc_399014257225_item	3512449	et	4	main
linna	doc_399014257225_item	3512451	et	4	main
kompleksi	doc_399014257225_item	3512464	et	4	main
visualiseerisime	doc_399014257225_item	3512470	et	4	main
tulemuseks	doc_399014257225_item	3512473	et	3	main
meetrit	doc_399014257225_item	3512475	et	3	main
sõtnik	doc_399014257225_item	3512483	et	4	main
parim	doc_399014257225_item	3512488	et	4	main
botaanikaaia	doc_399014257225_item	3512504	et	4	main
siluetti	doc_399014257225_item	3512513	et	4	main
tauno	doc_399014257225_item	3512515	et	4	main
kangro	doc_399014257225_item	3512516	et	4	main
paat	doc_399014257225_item	3512557	et	3	main
ning	doc_399014257225_item	3512558	et	3	main
mõned	doc_399014257225_item	3512559	et	3	main
eestlaste	doc_399014257225_item	3512563	et	4	main
skulptorite	doc_399014257225_item	3512567	et	3	main
uue	doc_399014257225_item	3512580	et	3	main
raekoja	doc_399014257225_item	3512581	et	3	main
kujuprojekti	doc_399014257225_item	3512599	et	4	main
vastu	doc_399014257225_item	3512600	et	3	main
ammu	doc_399014257225_item	3512606	et	4	main
osaliseks	doc_399014257225_item	3512613	et	4	main
aga	doc_399014257225_item	3512626	et	3	main
on	doc_399014257225_item	3512631	et	4	main
kalevipoja	doc_399014257225_item	3512639	et	4	main
branderi	doc_399014257226_item	3512665	et	4	main
helsingi	doc_399014257226_item	3512683	et	4	main
rahvaarv	doc_399014257226_item	3512684	et	3	main
000	doc_399014257226_item	3512687	et	2	main
see	doc_399014257226_item	3512695	et	3	main
1906	doc_399014257226_item	3512722	et	2	main
asutada	doc_399014257226_item	3512723	et	3	main
muinsuskaitsekomisjoni	doc_399014257226_item	3512724	et	4	main
on	doc_399014257226_item	3512736	et	4	main
helsingit	doc_399014257226_item	3512745	et	4	main
aastatel	doc_399014257226_item	3512749	et	4	main
tuumaks	doc_399014257226_item	3512763	et	3	main
linnamuuseum	doc_399014257226_item	3512765	et	3	main
välja	doc_399014257226_item	3512772	et	4	main
esimese	doc_399014257226_item	3512773	et	3	main
fotograaf	doc_399014257226_item	3512780	et	4	main
riitta	doc_399014257226_item	3512785	et	4	main
koostanud	doc_399014257226_item	3512788	et	4	main
branderi	doc_399014257226_item	3512790	et	4	main
milles	doc_399014257226_item	3512805	et	3	main
oleks	doc_399014257226_item	3512807	et	3	main
oma	doc_399014257226_item	3512826	et	4	main
teiste	doc_399014257226_item	3512833	et	4	main
juhatusel	doc_399014257226_item	3512840	et	4	main
toimus	doc_399014257226_item	3512841	et	3	main
planeering	doc_399014257226_item	3512844	et	4	main
muutus	doc_399014257226_item	3512862	et	4	main
töölö	doc_399014257226_item	3512865	et	4	main
alguses	doc_399014257226_item	3512872	et	4	main
ehitatud	doc_399014257226_item	3512874	et	4	main
ühe-	doc_399014257226_item	3512875	et	4	main
ja	doc_399014257226_item	3512876	et	3	main
eest	doc_399014257226_item	3512882	et	4	main
signe	doc_399014257226_item	3512888	et	4	main
maastikufotograafina	doc_399014257226_item	3512901	et	4	main
ta	doc_399014257226_item	3512909	et	4	main
selle	doc_399014257226_item	3512914	et	4	main
sai	doc_399014257226_item	3512916	et	4	main
temast	doc_399014257226_item	3512917	et	3	main
fotograaf	doc_399014257226_item	3512918	et	4	main
tegemine	doc_399014257226_item	3512923	et	4	main
ega	doc_399014257226_item	3512924	et	3	main
nende	doc_399014257226_item	3512930	et	4	main
kogemust	doc_399014257226_item	3512934	et	3	main
kaupmehi	doc_399014257226_item	3512970	et	3	main
või	doc_399014257226_item	3512972	et	4	main
helsinglastele	doc_399014257226_item	3512979	et	3	main
töölös	doc_399014257226_item	3512981	et	4	main
kohal	doc_399014257226_item	3512989	et	4	main
brander	doc_399014257226_item	3512990	et	4	main
peatuda	doc_399014257226_item	3512996	et	3	main
helsinglaste	doc_399014257226_item	3513010	et	3	main
nähtus	doc_399014257226_item	3513023	et	4	main
vahest	doc_399014257226_item	3513024	et	4	main
kõigest	doc_399014257225_item	3512446	et	4	main
ettepanekul	doc_399014257225_item	3512452	et	3	main
selle	doc_399014257225_item	3512454	et	4	main
kõrgust	doc_399014257225_item	3512455	et	4	main
kuni	doc_399014257225_item	3512456	et	3	main
21	doc_399014257225_item	3512457	et	2	main
meetrini	doc_399014257225_item	3512458	et	3	main
vaatasime	doc_399014257225_item	3512459	et	3	main
meetri	doc_399014257225_item	3512448	et	3	main
aga	doc_399014257225_item	3512450	et	3	main
lisati	doc_399014257225_item	3512453	et	3	main
maarjamäe	doc_399014257225_item	3512462	et	3	main
abilinnapea	doc_399014257225_item	3512481	et	4	main
võimalik	doc_399014257225_item	3512489	et	3	main
see	doc_399014257225_item	3512491	et	3	main
turistidele	doc_399014257225_item	3512493	et	3	main
peale	doc_399014257225_item	3512495	et	4	main
ka	doc_399014257225_item	3512507	et	3	main
hakka	doc_399014257225_item	3512509	et	4	main
varjama	doc_399014257225_item	3512511	et	3	main
ei	doc_399014257225_item	3512527	et	4	main
aga	doc_399014257225_item	3512529	et	3	main
inimsekujud	doc_399014257225_item	3512560	et	4	main
kojutuleku	doc_399014257225_item	3512564	et	3	main
kujuprojekti	doc_399014257225_item	3512570	et	4	main
arhitektide	doc_399014257225_item	3512572	et	3	main
liit	doc_399014257225_item	3512573	et	3	main
hulgas	doc_399014257225_item	3512579	et	4	main
ainsa	doc_399014257225_item	3512584	et	3	main
erakonnana	doc_399014257225_item	3512585	et	4	main
on	doc_399014257225_item	3512591	et	4	main
ennegi	doc_399014257225_item	3512592	et	4	main
kõrgeid	doc_399014257225_item	3512593	et	3	main
pärast	doc_399014257225_item	3512602	et	4	main
seda	doc_399014257225_item	3512603	et	3	main
kui	doc_399014257225_item	3512604	et	3	main
kriitika	doc_399014257225_item	3512612	et	4	main
kes	doc_399014257225_item	3512619	et	4	main
kividega	doc_399014257225_item	3512625	et	3	main
vägistas	doc_399014257225_item	3512628	et	3	main
meres	doc_399014257225_item	3512630	et	3	main
küsitud	doc_399014257225_item	3512632	et	4	main
kas	doc_399014257225_item	3512633	et	3	main
ta	doc_399014257225_item	3512634	et	4	main
võistluse	doc_399014257225_item	3512640	et	3	main
tulemused	doc_399014257225_item	3512641	et	3	main
aasta	doc_399014257225_item	3512660	et	4	main
jooksul	doc_399014257225_item	3512661	et	4	main
tõlge	doc_399014257226_item	3512663	et	3	main
kohta	doc_399014257226_item	3512673	et	4	main
100	doc_399014257226_item	3512686	et	2	main
väga	doc_399014257226_item	3512698	et	3	main
mis	doc_399014257226_item	3512725	et	4	main
järgmisel	doc_399014257226_item	3512726	et	3	main
aastal	doc_399014257226_item	3512727	et	3	main
valis	doc_399014257226_item	3512728	et	3	main
fotograaf	doc_399014257226_item	3512731	et	4	main
tagantjärgi	doc_399014257226_item	3512737	et	4	main
umbes	doc_399014257226_item	3512746	et	4	main
1907-13	doc_399014257226_item	3512750	et	2	main
tulemusena	doc_399014257226_item	3512752	et	3	main
907	doc_399014257226_item	3512754	et	2	main
pilti	doc_399014257226_item	3512755	et	4	main
annab	doc_399014257226_item	3512766	et	3	main
raamatu	doc_399014257226_item	3512774	et	4	main
jan	doc_399014257226_item	3512781	et	4	main
raamatu	doc_399014257226_item	3512789	et	4	main
pildiga	doc_399014257226_item	3512795	et	3	main
vaevalt	doc_399014257226_item	3512796	et	4	main
eriti	doc_399014257226_item	3512801	et	3	main
välja	doc_399014257226_item	3512802	et	4	main
vähemalt	doc_399014257226_item	3512808	et	4	main
helsingi	doc_399014257226_item	3512842	et	4	main
helsingi	doc_399014257226_item	3512859	et	4	main
kasvas	doc_399014257226_item	3512860	et	3	main
ning	doc_399014257226_item	3512861	et	3	main
õhinaga	doc_399014257226_item	3512863	et	3	main
ja	doc_399014257226_item	3512866	et	3	main
eira	doc_399014257226_item	3512867	et	4	main
ehitamist	doc_399014257226_item	3512868	et	4	main
ning	doc_399014257226_item	3512869	et	3	main
hakkasid	doc_399014257226_item	3512879	et	4	main
pakarineni	doc_399014257226_item	3512885	et	4	main
hinnangul	doc_399014257226_item	3512886	et	3	main
oli	doc_399014257226_item	3512887	et	3	main
fotograafina	doc_399014257226_item	3512899	et	4	main
joonistuseõpetajaks	doc_399014257226_item	3512907	et	4	main
mälestusmärkide	doc_399014257225_item	3512463	et	3	main
juurde	doc_399014257225_item	3512465	et	4	main
tegime	doc_399014257225_item	3512467	et	3	main
ning	doc_399014257225_item	3512469	et	3	main
seda	doc_399014257225_item	3512471	et	3	main
saime	doc_399014257225_item	3512472	et	3	main
21	doc_399014257225_item	3512474	et	2	main
hakaks	doc_399014257225_item	3512477	et	4	main
silma	doc_399014257225_item	3512478	et	4	main
põhjendab	doc_399014257225_item	3512479	et	3	main
sõtniku	doc_399014257225_item	3512484	et	4	main
kuna	doc_399014257225_item	3512490	et	3	main
jääb	doc_399014257225_item	3512492	et	3	main
tee	doc_399014257225_item	3512494	et	4	main
pirita	doc_399014257225_item	3512496	et	4	main
spasse	doc_399014257225_item	3512497	et	4	main
minnes	doc_399014257225_item	3512498	et	3	main
samuti	doc_399014257225_item	3512499	et	3	main
jääb	doc_399014257225_item	3512500	et	3	main
see	doc_399014257225_item	3512501	et	3	main
poole	doc_399014257225_item	3512505	et	4	main
ei	doc_399014257225_item	3512508	et	4	main
vanalinna	doc_399014257225_item	3512512	et	4	main
oli	doc_399014257225_item	3512519	et	3	main
ka	doc_399014257225_item	3512520	et	3	main
esmaspäeval	doc_399014257225_item	3512521	et	3	main
vaimustunud	doc_399014257225_item	3512523	et	4	main
kunstikku	doc_399014257225_item	3512524	et	4	main
ennast	doc_399014257225_item	3512525	et	4	main
olnud	doc_399014257225_item	3512528	et	4	main
tutvustas	doc_399014257225_item	3512533	et	3	main
vaimustunult	doc_399014257225_item	3512534	et	4	main
pronksist	doc_399014257225_item	3512535	et	4	main
kuju	doc_399014257225_item	3512536	et	4	main
suurte	doc_399014257225_item	3512537	et	3	main
kättega	doc_399014257225_item	3512538	et	4	main
kalevipoega	doc_399014257225_item	3512539	et	4	main
paati	doc_399014257225_item	3512540	et	4	main
kandmas	doc_399014257225_item	3512541	et	3	main
kuju	doc_399014257225_item	3512542	et	4	main
sümboliseerib	doc_399014257225_item	3512543	et	3	main
kangelase	doc_399014257225_item	3512544	et	3	main
kojutulekut	doc_399014257225_item	3512545	et	3	main
pärast	doc_399014257225_item	3512546	et	4	main
ilma	doc_399014257225_item	3512547	et	4	main
peal	doc_399014257225_item	3512548	et	4	main
ringi	doc_399014257225_item	3512549	et	4	main
rändamist	doc_399014257225_item	3512550	et	4	main
kunstiku	doc_399014257225_item	3512551	et	4	main
äranägemise	doc_399014257225_item	3512552	et	3	main
järgi	doc_399014257225_item	3512553	et	4	main
on	doc_399014257225_item	3512554	et	4	main
kangelase	doc_399014257225_item	3512555	et	3	main
käes	doc_399014257225_item	3512556	et	4	main
sümboliteks	doc_399014257225_item	3512565	et	3	main
ühingule	doc_399014257225_item	3512568	et	3	main
mis	doc_399014257225_item	3512590	et	4	main
eelistanud	doc_399014257225_item	3512595	et	4	main
teiste	doc_399014257225_item	3512596	et	4	main
kunstnike	doc_399014257225_item	3512597	et	3	main
kriitika	doc_399014257225_item	3512598	et	4	main
saanud	doc_399014257225_item	3512615	et	4	main
ka	doc_399014257225_item	3512616	et	3	main
kalevipoeg	doc_399014257225_item	3512617	et	3	main
vaenlasi	doc_399014257225_item	3512623	et	3	main
on	doc_399014257225_item	3512635	et	4	main
sobiv	doc_399014257225_item	3512636	et	4	main
sümbol	doc_399014257225_item	3512637	et	3	main
merre	doc_399014257225_item	3512638	et	3	main
avalikustatakse	doc_399014257225_item	3512642	et	3	main
jaanuari	doc_399014257225_item	3512643	et	4	main
lõpus	doc_399014257225_item	3512644	et	4	main
mille	doc_399014257225_item	3512645	et	3	main
järel	doc_399014257225_item	3512646	et	4	main
võistlustöödest	doc_399014257225_item	3512647	et	3	main
korraldatakse	doc_399014257225_item	3512648	et	3	main
näitus	doc_399014257225_item	3512649	et	3	main
abilinnapea	doc_399014257225_item	3512650	et	4	main
sõtniku	doc_399014257225_item	3512651	et	4	main
järgi	doc_399014257225_item	3512652	et	4	main
kavatsetakse	doc_399014257225_item	3512653	et	3	main
kuju	doc_399014257225_item	3512654	et	4	main
püsti	doc_399014257225_item	3512655	et	3	main
panna	doc_399014257225_item	3512656	et	4	main
järgmise	doc_399014257225_item	3512657	et	3	main
ja	doc_399014257225_item	3512658	et	3	main
ülejärgmise	doc_399014257225_item	3512659	et	3	main
helsingi	doc_399014257226_item	3512666	et	4	main
koostas	doc_399014257226_item	3512669	et	4	main
raamat	doc_399014257226_item	3512674	et	3	main
vaatamisväärsusi	doc_399014257226_item	3512681	et	4	main
vaatama	doc_399014257226_item	3512682	et	3	main
piiri	doc_399014257226_item	3512689	et	4	main
kolme	doc_399014257226_item	3512692	et	4	main
aastakümnega	doc_399014257226_item	3512693	et	4	main
oli	doc_399014257226_item	3512694	et	3	main
sada	doc_399014257226_item	3512713	et	4	main
aastat	doc_399014257226_item	3512714	et	3	main
tagasi	doc_399014257226_item	3512715	et	3	main
jaoks	doc_399014257226_item	3512717	et	4	main
otsustas	doc_399014257226_item	3512718	et	3	main
kiidetud	doc_399014257226_item	3512739	et	4	main
targa	doc_399014257226_item	3512740	et	3	main
ja	doc_399014257226_item	3512741	et	3	main
kaugenägelikuna	doc_399014257226_item	3512742	et	3	main
brander	doc_399014257226_item	3512743	et	4	main
pildistas	doc_399014257226_item	3512744	et	3	main
mis	doc_399014257226_item	3512756	et	4	main
linnaummseumi	doc_399014257226_item	3512761	et	4	main
nüüd	doc_399014257226_item	3512767	et	4	main
signe	doc_399014257226_item	3512768	et	4	main
mis	doc_399014257226_item	3512775	et	4	main
põhineb	doc_399014257226_item	3512776	et	3	main
ainult	doc_399014257226_item	3512777	et	4	main
tema	doc_399014257226_item	3512778	et	4	main
piltidel	doc_399014257226_item	3512779	et	3	main
helsingi-teemalise	doc_399014257226_item	3512794	et	4	main
lisaks	doc_399014257225_item	3512566	et	4	main
tülis	doc_399014257225_item	3512577	et	4	main
muu	doc_399014257225_item	3512578	et	4	main
pärast	doc_399014257225_item	3512583	et	4	main
ehitisi	doc_399014257225_item	3512594	et	3	main
ideed	doc_399014257225_item	3512605	et	4	main
turundanud	doc_399014257225_item	3512607	et	4	main
kangro	doc_399014257225_item	3512608	et	4	main
suvel	doc_399014257225_item	3512609	et	3	main
keskerakonnaga	doc_399014257225_item	3512610	et	4	main
on	doc_399014257225_item	3512614	et	4	main
legendi	doc_399014257225_item	3512620	et	4	main
järgi	doc_399014257225_item	3512621	et	4	main
pildus	doc_399014257225_item	3512622	et	3	main
neidu	doc_399014257225_item	3512629	et	4	main
signe	doc_399014257226_item	3512664	et	4	main
linnamuuseum	doc_399014257226_item	3512668	et	3	main
raamatu	doc_399014257226_item	3512670	et	4	main
legendaarse	doc_399014257226_item	3512671	et	3	main
fotograafi	doc_399014257226_item	3512672	et	4	main
lugeja	doc_399014257226_item	3512676	et	4	main
aasta	doc_399014257226_item	3512678	et	4	main
taguse	doc_399014257226_item	3512679	et	3	main
helsingi	doc_399014257226_item	3512680	et	4	main
ületas	doc_399014257226_item	3512685	et	3	main
elaniku	doc_399014257226_item	3512688	et	3	main
a	doc_399014257226_item	3512691	et	4	main
kolmekordistunud	doc_399014257226_item	3512696	et	4	main
suur	doc_399014257226_item	3512699	et	3	main
eesmargi	doc_399014257226_item	3512716	et	3	main
ülesannet	doc_399014257226_item	3512729	et	4	main
korduvalt	doc_399014257226_item	3512738	et	4	main
seitse	doc_399014257226_item	3512747	et	3	main
on	doc_399014257226_item	3512757	et	4	main
pildiarhiivi	doc_399014257226_item	3512762	et	4	main
saja	doc_399014257226_item	3513227	et	4	main
patsiendi	doc_399014257226_item	3513228	et	3	main
nende	doc_399014257226_item	3513229	et	4	main
hulgas	doc_399014257226_item	3513230	et	4	main
oli	doc_399014257226_item	3513231	et	3	main
helsingi	doc_399014257226_item	3513232	et	4	main
legendaarne	doc_399014257226_item	3513233	et	3	main
fotograaf	doc_399014257226_item	3513234	et	4	main
signe	doc_399014257226_item	3513235	et	4	main
brander	doc_399014257226_item	3513236	et	4	main
kes	doc_399014257226_item	3513237	et	4	main
maeti	doc_399014257226_item	3513238	et	3	main
koos	doc_399014257226_item	3513239	et	4	main
teiste	doc_399014257226_item	3513240	et	4	main
patsientidega	doc_399014257226_item	3513241	et	3	main
ühishauda	doc_399014257226_item	3513242	et	4	main
helsingi	doc_399014257226_item	3512667	et	4	main
viib	doc_399014257226_item	3512675	et	3	main
saja	doc_399014257226_item	3512677	et	4	main
1902	doc_399014257226_item	3512690	et	2	main
linna	doc_399014257226_item	3512697	et	4	main
kasv	doc_399014257226_item	3512700	et	3	main
ja	doc_399014257226_item	3512701	et	3	main
muutused	doc_399014257226_item	3512702	et	4	main
ergutasid	doc_399014257226_item	3512703	et	4	main
arhitekte	doc_399014257226_item	3512704	et	3	main
ja	doc_399014257226_item	3512705	et	3	main
helsingi	doc_399014257226_item	3512706	et	4	main
linna	doc_399014257226_item	3512707	et	4	main
tegelasi	doc_399014257226_item	3512708	et	3	main
dokumenteerima	doc_399014257226_item	3512709	et	3	main
kaduvat	doc_399014257226_item	3512710	et	4	main
puumajade	doc_399014257226_item	3512711	et	3	main
linna	doc_399014257226_item	3512712	et	4	main
helsingi	doc_399014257226_item	3512719	et	4	main
linnavolikogu	doc_399014257226_item	3512720	et	4	main
aastal	doc_399014257226_item	3512721	et	3	main
teostama	doc_399014257226_item	3512730	et	3	main
signe	doc_399014257226_item	3512732	et	4	main
branderi	doc_399014257226_item	3512733	et	4	main
1869-1942	doc_399014257226_item	3512734	et	2	main
otsust	doc_399014257226_item	3512735	et	4	main
aastat	doc_399014257226_item	3512748	et	3	main
töö	doc_399014257226_item	3512751	et	4	main
tekkisid	doc_399014257226_item	3512753	et	4	main
ikka	doc_399014257226_item	3512758	et	4	main
veel	doc_399014257226_item	3512759	et	4	main
helsingi	doc_399014257226_item	3512760	et	4	main
branderi	doc_399014257226_item	3512769	et	4	main
teoste	doc_399014257226_item	3512770	et	3	main
kohta	doc_399014257226_item	3512771	et	4	main
pakarinen	doc_399014257226_item	3512786	et	4	main
umbes	doc_399014257226_item	3512791	et	4	main
on	doc_399014257226_item	3512797	et	4	main
antud	doc_399014257226_item	3512803	et	4	main
ei	doc_399014257226_item	3512806	et	4	main
parimad	doc_399014257226_item	3512828	et	4	main
linnapildi	doc_399014257226_item	3512829	et	4	main
ja	doc_399014257226_item	3512830	et	3	main
kultuuriloo	doc_399014257226_item	3512831	et	4	main
asjatundjad	doc_399014257226_item	3512832	et	3	main
kelle	doc_399014257226_item	3512839	et	4	main
branderi	doc_399014257226_item	3512845	et	4	main
alustati	doc_399014257226_item	3512864	et	4	main
kahekororuselised	doc_399014257226_item	3512877	et	4	main
puumajad	doc_399014257226_item	3512878	et	3	main
kaduma	doc_399014257226_item	3512883	et	4	main
etableerunud	doc_399014257226_item	3512897	et	4	main
osava	doc_399014257226_item	3512898	et	3	main
parkanost	doc_399014257226_item	3512902	et	4	main
pärit	doc_399014257226_item	3512903	et	3	main
töötanud	doc_399014257226_item	3512911	et	4	main
ei	doc_399014257226_item	3512920	et	4	main
meeldinud	doc_399014257226_item	3512921	et	4	main
kohta	doc_399014257226_item	3512931	et	4	main
omandanud	doc_399014257226_item	3512935	et	4	main
tahtis	doc_399014257226_item	3512937	et	3	main
aasta	doc_399014257226_item	3512975	et	4	main
tagasi	doc_399014257226_item	3512976	et	3	main
pildi	doc_399014257226_item	3512984	et	4	main
juhuslikult	doc_399014257226_item	3512988	et	4	main
neil	doc_399014257226_item	3512992	et	4	main
palunud	doc_399014257226_item	3512993	et	4	main
annab	doc_399014257226_item	3513000	et	3	main
uudishimu	doc_399014257226_item	3513012	et	4	main
pildistamine	doc_399014257226_item	3513014	et	4	main
veel	doc_399014257226_item	3513016	et	4	main
detailiks	doc_399014257226_item	3513028	et	4	main
keset	doc_399014257226_item	3513037	et	4	main
pildid	doc_399014257226_item	3513041	et	3	main
lugeja	doc_399014257226_item	3513045	et	4	main
nagu	doc_399014257226_item	3513047	et	3	main
taguses	doc_399014257226_item	3513051	et	3	main
hermannist	doc_399014257226_item	3513055	et	4	main
kaudu	doc_399014257226_item	3513066	et	3	main
pildi	doc_399014257226_item	3513069	et	4	main
on	doc_399014257226_item	3513071	et	4	main
paigutatud	doc_399014257226_item	3513072	et	4	main
täpne	doc_399014257226_item	3513073	et	3	main
millise	doc_399014257226_item	3513078	et	3	main
ning	doc_399014257226_item	3513084	et	3	main
on	doc_399014257226_item	3513088	et	4	main
kaart	doc_399014257226_item	3513090	et	4	main
on	doc_399014257226_item	3513091	et	4	main
mitmest	doc_399014257226_item	3513097	et	4	main
tunne	doc_399014257226_item	3513100	et	4	main
branderi	doc_399014257226_item	3513107	et	4	main
otsustavalt	doc_399014257226_item	3513121	et	4	main
tüli	doc_399014257226_item	3513125	et	4	main
ei	doc_399014257226_item	3513127	et	4	main
ole	doc_399014257226_item	3513128	et	4	main
võis	doc_399014257226_item	3513133	et	4	main
tüliõunaks	doc_399014257226_item	3513134	et	3	main
olla	doc_399014257226_item	3513135	et	3	main
alalise	doc_399014257226_item	3513163	et	4	main
helsingi	doc_399014257226_item	3512764	et	4	main
alanco	doc_399014257226_item	3512782	et	4	main
ja	doc_399014257226_item	3512783	et	3	main
uurija	doc_399014257226_item	3512784	et	4	main
on	doc_399014257226_item	3512787	et	4	main
saja	doc_399014257226_item	3512792	et	4	main
parima	doc_399014257226_item	3512793	et	4	main
helsingi	doc_399014257226_item	3512798	et	4	main
ajaloo	doc_399014257226_item	3512799	et	4	main
raamatuid	doc_399014257226_item	3512804	et	3	main
mõned	doc_399014257226_item	3512809	et	3	main
branderi	doc_399014257226_item	3512810	et	4	main
tehtud	doc_399014257226_item	3512811	et	4	main
pildid	doc_399014257226_item	3512812	et	3	main
20	doc_399014257226_item	3512813	et	2	main
sajandi	doc_399014257226_item	3512814	et	3	main
algusest	doc_399014257226_item	3512815	et	4	main
alles	doc_399014257226_item	3512816	et	3	main
praegu	doc_399014257226_item	3512817	et	3	main
aga	doc_399014257226_item	3512818	et	3	main
pühendatakse	doc_399014257226_item	3512819	et	3	main
talle	doc_399014257226_item	3512820	et	4	main
täiesti	doc_399014257226_item	3512821	et	3	main
oma	doc_399014257226_item	3512822	et	4	main
pildiraamat	doc_399014257226_item	3512823	et	3	main
muinsuskaitsekomisjoni	doc_399014257226_item	3512824	et	4	main
kuulusid	doc_399014257226_item	3512825	et	4	main
kohta	doc_399014257226_item	3512800	et	4	main
aja	doc_399014257226_item	3512827	et	4	main
gustav	doc_399014257226_item	3512837	et	4	main
nyström	doc_399014257226_item	3512838	et	4	main
linna	doc_399014257226_item	3512843	et	4	main
komisjon	doc_399014257226_item	3512848	et	3	main
pildistamispaikadest	doc_399014257226_item	3512850	et	4	main
kus	doc_399014257226_item	3512851	et	3	main
oli	doc_399014257226_item	3512852	et	3	main
oodata	doc_399014257226_item	3512853	et	4	main
suuri	doc_399014257226_item	3512854	et	3	main
muudatusi	doc_399014257226_item	3512855	et	3	main
20	doc_399014257226_item	3512856	et	2	main
sajandi	doc_399014257226_item	3512857	et	3	main
alguse	doc_399014257226_item	3512858	et	3	main
19	doc_399014257226_item	3512870	et	2	main
linna	doc_399014257226_item	3512873	et	4	main
riitta	doc_399014257226_item	3512884	et	4	main
branderi	doc_399014257226_item	3512889	et	4	main
helsingi	doc_399014257226_item	3512891	et	4	main
eriti	doc_399014257226_item	3512900	et	3	main
brander	doc_399014257226_item	3512904	et	4	main
õppis	doc_399014257226_item	3512905	et	3	main
helsingis	doc_399014257226_item	3512906	et	4	main
ei	doc_399014257226_item	3512910	et	4	main
muidugi	doc_399014257226_item	3512926	et	4	main
oli	doc_399014257226_item	3512927	et	3	main
fotostuudiotes	doc_399014257226_item	3512933	et	3	main
piltidel	doc_399014257226_item	3512963	et	3	main
pea	doc_399014257226_item	3512965	et	4	main
politseinike	doc_399014257226_item	3512971	et	3	main
koduloomi	doc_399014257226_item	3512973	et	4	main
sata	doc_399014257226_item	3512974	et	4	main
peale	doc_399014257226_item	3512985	et	4	main
saanud	doc_399014257226_item	3512986	et	4	main
pildistamiseks	doc_399014257226_item	3512995	et	4	main
heatujulistest	doc_399014257226_item	3512998	et	4	main
järeldada	doc_399014257226_item	3513001	et	3	main
brander	doc_399014257226_item	3513003	et	4	main
oma	doc_399014257226_item	3513005	et	4	main
asja	doc_399014257226_item	3513006	et	4	main
hästi	doc_399014257226_item	3513007	et	3	main
esitada	doc_399014257226_item	3513008	et	3	main
ning	doc_399014257226_item	3513009	et	3	main
maastikufotograaf	doc_399014257226_item	3513021	et	4	main
haruldane	doc_399014257226_item	3513022	et	3	main
hobune	doc_399014257226_item	3513036	et	4	main
on	doc_399014257226_item	3513040	et	4	main
hakaniemi	doc_399014257226_item	3513057	et	4	main
ja	doc_399014257226_item	3513058	et	3	main
kamppi	doc_399014257226_item	3513065	et	4	main
originaalkaart	doc_399014257226_item	3513074	et	4	main
mis	doc_399014257226_item	3513075	et	4	main
räägib	doc_399014257226_item	3513076	et	3	main
nurga	doc_399014257226_item	3513079	et	3	main
suunast	doc_399014257226_item	3513086	et	4	main
vaadet	doc_399014257226_item	3513087	et	3	main
vajalik	doc_399014257226_item	3513095	et	3	main
ajal	doc_399014257226_item	3513108	et	4	main
maakoht	doc_399014257226_item	3513109	et	3	main
kus	doc_399014257226_item	3513110	et	3	main
venelased	doc_399014257226_item	3513111	et	3	main
sattusid	doc_399014257226_item	3513119	et	4	main
aastal	doc_399014257226_item	3513123	et	3	main
pakarise	doc_399014257226_item	3513131	et	4	main
alles	doc_399014257226_item	3513165	et	3	main
jätkas	doc_399014257226_item	3513169	et	3	main
tööd	doc_399014257226_item	3513171	et	4	main
soome	doc_399014257226_item	3513172	et	3	main
erinevates	doc_399014257226_item	3513173	et	4	main
kohtades	doc_399014257226_item	3513174	et	3	main
tema	doc_399014257226_item	3513180	et	4	main
tervis	doc_399014257226_item	3513181	et	3	main
ja	doc_399014257226_item	3513182	et	3	main
silmanägemine	doc_399014257226_item	3513183	et	3	main
sattus	doc_399014257226_item	3513191	et	3	main
brander	doc_399014257226_item	3513192	et	4	main
patsiendid	doc_399014257226_item	3513196	et	3	main
tõlge	doc_399014257229_item	3513244	et	3	main
liidud	doc_399014257229_item	3513246	et	3	main
tallinna	doc_399014257229_item	3513248	et	4	main
hulgas	doc_399014257226_item	3512834	et	4	main
arhitekt	doc_399014257226_item	3512835	et	3	main
professor	doc_399014257226_item	3512836	et	3	main
jaoks	doc_399014257226_item	3512846	et	4	main
koostas	doc_399014257226_item	3512847	et	4	main
nimekirja	doc_399014257226_item	3512849	et	4	main
sajandi	doc_399014257226_item	3512871	et	3	main
kõrgete	doc_399014257226_item	3512880	et	4	main
kivimüüride	doc_399014257226_item	3512881	et	4	main
valik	doc_399014257226_item	3512890	et	3	main
pildistajaks	doc_399014257226_item	3512892	et	4	main
enesestmõistetav	doc_399014257226_item	3512893	et	3	main
ta	doc_399014257226_item	3512894	et	4	main
oli	doc_399014257226_item	3512895	et	3	main
juba	doc_399014257226_item	3512896	et	3	main
aga	doc_399014257226_item	3512908	et	3	main
õpetajana	doc_399014257226_item	3512913	et	4	main
asemel	doc_399014257226_item	3512915	et	4	main
portreede	doc_399014257226_item	3512922	et	4	main
ta	doc_399014257226_item	3512928	et	4	main
ka	doc_399014257226_item	3512929	et	3	main
tema	doc_399014257226_item	3512936	et	4	main
objektidele	doc_399014257226_item	3512938	et	3	main
väga	doc_399014257226_item	3512939	et	3	main
osavalt	doc_399014257226_item	3512940	et	4	main
pildistas	doc_399014257226_item	3512941	et	3	main
brander	doc_399014257226_item	3512942	et	4	main
linna	doc_399014257226_item	3512943	et	4	main
ja	doc_399014257226_item	3512944	et	3	main
maastikuid	doc_399014257226_item	3512945	et	4	main
toonase	doc_399014257226_item	3512946	et	3	main
kohmaka	doc_399014257226_item	3512947	et	3	main
tehnikaga	doc_399014257226_item	3512948	et	3	main
ta	doc_399014257226_item	3512949	et	4	main
ei	doc_399014257226_item	3512950	et	4	main
piirdunud	doc_399014257226_item	3512951	et	4	main
elutu	doc_399014257226_item	3512952	et	4	main
arhitektuuripildistamisega	doc_399014257226_item	3512953	et	3	main
tema	doc_399014257226_item	3512954	et	4	main
piltide	doc_399014257226_item	3512955	et	3	main
elavuse	doc_399014257226_item	3512956	et	4	main
saladuseks	doc_399014257226_item	3512957	et	3	main
olid	doc_399014257226_item	3512958	et	4	main
inimesed	doc_399014257226_item	3512959	et	3	main
ja	doc_399014257226_item	3512960	et	3	main
detailid	doc_399014257226_item	3512961	et	3	main
tema	doc_399014257226_item	3512962	et	4	main
kunagi	doc_399014257226_item	3512912	et	3	main
kellele	doc_399014257226_item	3512919	et	4	main
ateljeetöö	doc_399014257226_item	3512925	et	4	main
helsingi	doc_399014257226_item	3512932	et	4	main
lapsi	doc_399014257226_item	3512969	et	4	main
köögivilju	doc_399014257226_item	3512980	et	3	main
enamasti	doc_399014257226_item	3512982	et	4	main
olid	doc_399014257226_item	3512983	et	4	main
inimesed	doc_399014257226_item	3512987	et	3	main
oli	doc_399014257226_item	3512991	et	3	main
inimeste	doc_399014257226_item	3512997	et	3	main
hulgas	doc_399014257226_item	3513011	et	4	main
oli	doc_399014257226_item	3513015	et	3	main
uus	doc_399014257226_item	3513017	et	3	main
mööda	doc_399014257226_item	3513029	et	4	main
või	doc_399014257226_item	3513033	et	4	main
ilma	doc_399014257226_item	3513034	et	4	main
rakmeteta	doc_399014257226_item	3513035	et	3	main
raamatus	doc_399014257226_item	3513039	et	4	main
kui	doc_399014257226_item	3513043	et	3	main
aasta	doc_399014257226_item	3513050	et	4	main
ekspeditsioon	doc_399014257226_item	3513053	et	3	main
töölösse	doc_399014257226_item	3513067	et	3	main
mis	doc_399014257226_item	3513085	et	4	main
nüüdislugeja	doc_399014257226_item	3513092	et	4	main
kohast	doc_399014257226_item	3513098	et	4	main
kasvatasid	doc_399014257226_item	3513112	et	4	main
siiski	doc_399014257226_item	3513120	et	4	main
1913	doc_399014257226_item	3513124	et	2	main
põhjust	doc_399014257226_item	3513126	et	4	main
järgi	doc_399014257226_item	3513132	et	4	main
fotograafi	doc_399014257226_item	3513164	et	4	main
hulgas	doc_399014257226_item	3513176	et	4	main
kae	doc_399014257226_item	3513185	et	4	main
haiglasse	doc_399014257226_item	3513194	et	4	main
viidi	doc_399014257226_item	3513198	et	4	main
on	doc_399014257226_item	3512964	et	4	main
alati	doc_399014257226_item	3512966	et	4	main
näha	doc_399014257226_item	3512967	et	3	main
möödujaid	doc_399014257226_item	3512968	et	4	main
kasvatasid	doc_399014257226_item	3512977	et	4	main
venelased	doc_399014257226_item	3512978	et	3	main
korraks	doc_399014257226_item	3512994	et	4	main
nägudest	doc_399014257226_item	3512999	et	3	main
et	doc_399014257226_item	3513002	et	3	main
oskas	doc_399014257226_item	3513004	et	3	main
äratada	doc_399014257226_item	3513013	et	3	main
asi	doc_399014257226_item	3513018	et	4	main
ning	doc_399014257226_item	3513019	et	3	main
naissoost	doc_399014257226_item	3513020	et	4	main
kõndiv	doc_399014257226_item	3513031	et	4	main
sightseeingul	doc_399014257226_item	3513048	et	4	main
saja	doc_399014257226_item	3513049	et	4	main
helsingis	doc_399014257226_item	3513052	et	4	main
algab	doc_399014257226_item	3513054	et	3	main
kulgeb	doc_399014257226_item	3513056	et	3	main
kruunuhaka	doc_399014257226_item	3513059	et	4	main
kaudu	doc_399014257226_item	3513060	et	3	main
lõunapoolsetesse	doc_399014257226_item	3513061	et	4	main
linnaosadesse	doc_399014257226_item	3513062	et	3	main
nendest	doc_399014257226_item	3513063	et	4	main
kõrvale	doc_399014257226_item	3513070	et	4	main
tehtud	doc_399014257226_item	3513083	et	4	main
jaoks	doc_399014257226_item	3513093	et	4	main
sest	doc_399014257226_item	3513096	et	4	main
ära	doc_399014257226_item	3513103	et	4	main
näiteks	doc_399014257226_item	3513104	et	4	main
oli	doc_399014257226_item	3513105	et	3	main
töölö	doc_399014257226_item	3513106	et	4	main
elanikele	doc_399014257226_item	3513114	et	3	main
köögivilja	doc_399014257226_item	3513115	et	4	main
brander	doc_399014257226_item	3513116	et	4	main
ja	doc_399014257226_item	3513117	et	3	main
komisjon	doc_399014257226_item	3513118	et	3	main
tülli	doc_399014257226_item	3513122	et	4	main
näha	doc_399014257226_item	3513130	et	3	main
on	doc_399014257226_item	3513025	et	4	main
pildi	doc_399014257226_item	3513026	et	4	main
pikantseks	doc_399014257226_item	3513027	et	3	main
raudteed	doc_399014257226_item	3513030	et	4	main
koer	doc_399014257226_item	3513032	et	3	main
õue	doc_399014257226_item	3513038	et	4	main
korrastatud	doc_399014257226_item	3513042	et	4	main
ekspeditsioon	doc_399014257226_item	3513044	et	3	main
liikudes	doc_399014257226_item	3513046	et	4	main
iga	doc_399014257226_item	3513068	et	4	main
edasi	doc_399014257226_item	3513064	et	3	main
sellest	doc_399014257226_item	3513077	et	4	main
pealt	doc_399014257226_item	3513080	et	4	main
pilt	doc_399014257226_item	3513081	et	3	main
on	doc_399014257226_item	3513082	et	4	main
vaadatud	doc_399014257226_item	3513089	et	4	main
väga	doc_399014257226_item	3513094	et	3	main
ei	doc_399014257226_item	3513099	et	4	main
linna	doc_399014257226_item	3513101	et	4	main
enam	doc_399014257226_item	3513102	et	4	main
helsingi	doc_399014257226_item	3513113	et	4	main
protokollidest	doc_399014257226_item	3513129	et	4	main
lihtsalt	doc_399014257226_item	3513136	et	4	main
raha	doc_399014257226_item	3513137	et	4	main
linnamuuseum	doc_399014257226_item	3513138	et	3	main
palkas	doc_399014257226_item	3513139	et	3	main
branderi	doc_399014257226_item	3513140	et	4	main
asemele	doc_399014257226_item	3513141	et	4	main
teise	doc_399014257226_item	3513142	et	4	main
fotograafi	doc_399014257226_item	3513143	et	4	main
aga	doc_399014257226_item	3513144	et	3	main
esimese	doc_399014257226_item	3513145	et	3	main
maailmasõja	doc_399014257226_item	3513146	et	3	main
algusega	doc_399014257226_item	3513147	et	3	main
1914	doc_399014257226_item	3513148	et	2	main
a	doc_399014257226_item	3513149	et	4	main
katkes	doc_399014257226_item	3513150	et	4	main
pildistamine	doc_399014257226_item	3513151	et	4	main
mitmeks	doc_399014257226_item	3513152	et	4	main
aastakümneks	doc_399014257226_item	3513153	et	4	main
süstemaatiline	doc_399014257226_item	3513154	et	3	main
linnakeskkonna	doc_399014257226_item	3513155	et	3	main
dokumenteerimine	doc_399014257226_item	3513156	et	4	main
algas	doc_399014257226_item	3513157	et	3	main
uuesti	doc_399014257226_item	3513158	et	3	main
alles	doc_399014257226_item	3513159	et	3	main
1950ndatel	doc_399014257226_item	3513160	et	4	main
linnamuuseum	doc_399014257226_item	3513161	et	3	main
sai	doc_399014257226_item	3513162	et	4	main
1981	doc_399014257226_item	3513167	et	2	main
tõttu	doc_399014257226_item	3513186	et	4	main
nõrgenema	doc_399014257226_item	3513187	et	3	main
1930ndatel	doc_399014257226_item	3513188	et	4	main
aastal	doc_399014257226_item	3513189	et	3	main
1941	doc_399014257226_item	3513190	et	2	main
hiljem	doc_399014257226_item	3513197	et	3	main
esitati	doc_399014257229_item	3513258	et	4	main
suuruse	doc_399014257229_item	3513272	et	4	main
kõrge	doc_399014257229_item	3513275	et	4	main
poolt	doc_399014257229_item	3513284	et	4	main
konkursile	doc_399014257229_item	3513286	et	3	main
langenutele	doc_399014257229_item	3513316	et	4	main
kõrge	doc_399014257229_item	3513324	et	4	main
obelisk	doc_399014257229_item	3513325	et	3	main
aastal	doc_399014257226_item	3513166	et	3	main
brander	doc_399014257226_item	3513168	et	4	main
fotograafi	doc_399014257226_item	3513170	et	4	main
pildistas	doc_399014257226_item	3513177	et	3	main
ta	doc_399014257226_item	3513178	et	4	main
mõisasid	doc_399014257226_item	3513179	et	4	main
kust	doc_399014257226_item	3513195	et	4	main
tõttu	doc_399014257226_item	3513200	et	4	main
üle	doc_399014257226_item	3513201	et	3	main
nikkilä	doc_399014257226_item	3513202	et	4	main
hullumajja	doc_399014257226_item	3513203	et	3	main
minek	doc_399014257226_item	3513204	et	3	main
nikkilässe	doc_399014257226_item	3513205	et	4	main
ei	doc_399014257226_item	3513206	et	4	main
olnud	doc_399014257226_item	3513207	et	4	main
tingitud	doc_399014257226_item	3513208	et	4	main
branderi	doc_399014257226_item	3513209	et	4	main
vaimsest	doc_399014257226_item	3513210	et	3	main
tervisest	doc_399014257226_item	3513211	et	4	main
kuigi	doc_399014257226_item	3513212	et	3	main
seda	doc_399014257226_item	3513213	et	3	main
on	doc_399014257226_item	3513214	et	4	main
aeg	doc_399014257226_item	3513215	et	3	main
ajalt	doc_399014257226_item	3513216	et	4	main
väidetud	doc_399014257226_item	3513217	et	4	main
ebaselgetes	doc_399014257226_item	3513218	et	4	main
sõjatingimustes	doc_399014257226_item	3513219	et	3	main
suri	doc_399014257226_item	3513220	et	3	main
nikkilä	doc_399014257226_item	3513221	et	4	main
haiglas	doc_399014257226_item	3513222	et	3	main
1942	doc_399014257226_item	3513223	et	2	main
a	doc_399014257226_item	3513224	et	4	main
nälga	doc_399014257226_item	3513225	et	4	main
üle	doc_399014257226_item	3513226	et	3	main
vaatavat	doc_399014257229_item	3513247	et	4	main
lahte	doc_399014257229_item	3513249	et	4	main
kavandatu	doc_399014257229_item	3513250	et	4	main
hiiglasliku	doc_399014257229_item	3513251	et	3	main
tallinna	doc_399014257229_item	3513256	et	4	main
eesti	doc_399014257229_item	3513261	et	4	main
rajada	doc_399014257229_item	3513267	et	3	main
lahte	doc_399014257229_item	3513269	et	4	main
21	doc_399014257229_item	3513273	et	2	main
eesti	doc_399014257229_item	3513278	et	4	main
kangelase	doc_399014257229_item	3513281	et	3	main
korraldatule	doc_399014257229_item	3513285	et	4	main
rannas	doc_399014257229_item	3513310	et	3	main
avastatud	doc_399014257229_item	3513317	et	4	main
memoriaalkompleks	doc_399014257229_item	3513318	et	3	main
millest	doc_399014257229_item	3513319	et	3	main
mere	doc_399014257229_item	3513320	et	3	main
kaldatrepp	doc_399014257229_item	3513327	et	3	main
linna	doc_399014257229_item	3513328	et	4	main
ja	doc_399014257229_item	3513329	et	3	main
muu	doc_399014257226_item	3513175	et	4	main
hakkasid	doc_399014257226_item	3513184	et	4	main
kivelä	doc_399014257226_item	3513193	et	4	main
sõja	doc_399014257226_item	3513199	et	3	main
kunstnike	doc_399014257229_item	3513245	et	3	main
kalevipoja	doc_399014257229_item	3513252	et	4	main
peale	doc_399014257229_item	3513254	et	4	main
konkursitööd	doc_399014257229_item	3513260	et	4	main
tõrjuvad	doc_399014257229_item	3513263	et	4	main
linna	doc_399014257229_item	3513265	et	4	main
kava	doc_399014257229_item	3513266	et	4	main
kalevipoja	doc_399014257229_item	3513276	et	4	main
samanimelise	doc_399014257229_item	3513279	et	4	main
järgi	doc_399014257229_item	3513282	et	4	main
linna	doc_399014257229_item	3513283	et	4	main
esmaspäevaks	doc_399014257229_item	3513289	et	3	main
on	doc_399014257229_item	3513311	et	4	main
teises	doc_399014257229_item	3513314	et	4	main
maailmasõjas	doc_399014257229_item	3513315	et	3	main
nähtav	doc_399014257229_item	3513323	et	4	main
kuju	doc_399014257229_item	3513335	et	4	main
eesti	doc_399014257229_item	3513340	et	4	main
ühenduse	doc_399014257229_item	3513342	et	4	main
ei	doc_399014257229_item	3513351	et	4	main
nõukogudeaegse	doc_399014257229_item	3513353	et	3	main
memoriaalkompleksi	doc_399014257229_item	3513354	et	4	main
ühingu	doc_399014257229_item	3513360	et	3	main
ratase	doc_399014257229_item	3513375	et	4	main
siiski	doc_399014257229_item	3513393	et	4	main
kunstnik	doc_399014257229_item	3513394	et	3	main
väikese	doc_399014257229_item	3513414	et	4	main
merineitsiga	doc_399014257229_item	3513415	et	3	main
abilinnapea	doc_399014257229_item	3513454	et	4	main
parim	doc_399014257229_item	3513461	et	4	main
võimalik	doc_399014257229_item	3513462	et	3	main
sest	doc_399014257229_item	3513463	et	4	main
see	doc_399014257229_item	3513464	et	3	main
botaanikaaeda	doc_399014257229_item	3513473	et	4	main
kangro	doc_399014257229_item	3513481	et	4	main
ei	doc_399014257229_item	3513491	et	4	main
pille	doc_399014257229_item	3513496	et	3	main
mägila	doc_399014257229_item	3513497	et	4	main
näitas	doc_399014257229_item	3513498	et	3	main
innukalt	doc_399014257229_item	3513499	et	4	main
kuju	doc_399014257229_item	3513508	et	4	main
sümboliseerib	doc_399014257229_item	3513509	et	3	main
kangelase	doc_399014257229_item	3513510	et	3	main
koju	doc_399014257229_item	3513511	et	3	main
naasmist	doc_399014257229_item	3513512	et	4	main
käes	doc_399014257229_item	3513520	et	4	main
paat	doc_399014257229_item	3513522	et	3	main
kes	doc_399014257229_item	3513525	et	4	main
siümboliseerivad	doc_399014257229_item	3513526	et	4	main
liit	doc_399014257229_item	3513537	et	3	main
tülitseb	doc_399014257229_item	3513539	et	3	main
ka	doc_399014257229_item	3513541	et	3	main
küsitud	doc_399014257229_item	3513599	et	4	main
kas	doc_399014257229_item	3513600	et	3	main
tema	doc_399014257229_item	3513601	et	4	main
on	doc_399014257229_item	3513602	et	4	main
sobiv	doc_399014257229_item	3513603	et	4	main
mere	doc_399014257229_item	3513604	et	3	main
sümbol	doc_399014257229_item	3513605	et	3	main
kalevipoja	doc_399014257229_item	3513606	et	4	main
konkursi	doc_399014257229_item	3513607	et	3	main
tulemused	doc_399014257229_item	3513608	et	3	main
avaldatakse	doc_399014257229_item	3513609	et	3	main
jaanuari	doc_399014257229_item	3513610	et	4	main
lõpul	doc_399014257229_item	3513611	et	3	main
pärast	doc_399014257229_item	3513612	et	4	main
mida	doc_399014257229_item	3513613	et	4	main
korraldatakse	doc_399014257229_item	3513614	et	3	main
konkursitööde	doc_399014257229_item	3513615	et	3	main
näitus	doc_399014257229_item	3513616	et	3	main
abilinnapea	doc_399014257229_item	3513617	et	4	main
linnavalitsusele	doc_399014257229_item	3513257	et	4	main
tallinna	doc_399014257229_item	3513268	et	4	main
mitmekorruselise	doc_399014257229_item	3513270	et	4	main
elamu	doc_399014257229_item	3513271	et	4	main
kuju	doc_399014257229_item	3513277	et	4	main
rahvuseepose	doc_399014257229_item	3513280	et	3	main
tähtajaks	doc_399014257229_item	3513288	et	3	main
esitatud	doc_399014257229_item	3513290	et	4	main
vaid	doc_399014257229_item	3513291	et	3	main
kolm	doc_399014257229_item	3513292	et	3	main
tööd	doc_399014257229_item	3513293	et	4	main
kalevipoja	doc_399014257229_item	3513294	et	4	main
kuju	doc_399014257229_item	3513295	et	4	main
kavatsetakse	doc_399014257229_item	3513296	et	3	main
püstitada	doc_399014257229_item	3513297	et	3	main
merre	doc_399014257229_item	3513298	et	3	main
100	doc_399014257229_item	3513299	et	2	main
meetri	doc_399014257229_item	3513300	et	3	main
kaugusele	doc_399014257229_item	3513301	et	4	main
rannajoonest	doc_399014257229_item	3513302	et	4	main
tallinnast	doc_399014257229_item	3513303	et	3	main
piritale	doc_399014257229_item	3513304	et	4	main
viiva	doc_399014257229_item	3513305	et	4	main
rannatee	doc_399014257229_item	3513306	et	4	main
äärde	doc_399014257229_item	3513307	et	4	main
sellel	doc_399014257229_item	3513308	et	4	main
kohal	doc_399014257229_item	3513309	et	4	main
kuju	doc_399014257229_item	3513253	et	4	main
viltu	doc_399014257229_item	3513255	et	3	main
kolm	doc_399014257229_item	3513259	et	3	main
kunstnikud	doc_399014257229_item	3513262	et	3	main
tallinna	doc_399014257229_item	3513264	et	4	main
meetri	doc_399014257229_item	3513274	et	3	main
oli	doc_399014257229_item	3513287	et	3	main
nõukogude	doc_399014257229_item	3513312	et	3	main
ajal	doc_399014257229_item	3513313	et	4	main
on	doc_399014257229_item	3513322	et	4	main
algavad	doc_399014257229_item	3513333	et	4	main
juba	doc_399014257229_item	3513334	et	3	main
asukohast	doc_399014257229_item	3513338	et	4	main
sobi	doc_399014257229_item	3513352	et	4	main
sügisel	doc_399014257229_item	3513357	et	3	main
kujurite	doc_399014257229_item	3513359	et	3	main
protestiks	doc_399014257229_item	3513369	et	4	main
žürii	doc_399014257229_item	3513370	et	2	main
bürokraatlikuse	doc_399014257229_item	3513371	et	4	main
vastu	doc_399014257229_item	3513372	et	3	main
32	doc_399014257229_item	3513376	et	2	main
lõpeks	doc_399014257229_item	3513384	et	4	main
vaid	doc_399014257229_item	3513385	et	3	main
linna	doc_399014257229_item	3513386	et	4	main
parke	doc_399014257229_item	3513387	et	3	main
kavandanud	doc_399014257229_item	3513388	et	4	main
maastikuarhitekt	doc_399014257229_item	3513389	et	3	main
idee	doc_399014257229_item	3513390	et	4	main
autor	doc_399014257229_item	3513391	et	3	main
kangro	doc_399014257229_item	3513398	et	4	main
40	doc_399014257229_item	3513399	et	2	main
projekti	doc_399014257229_item	3513403	et	4	main
juba	doc_399014257229_item	3513405	et	3	main
idee	doc_399014257229_item	3513409	et	4	main
luua	doc_399014257229_item	3513411	et	4	main
sümbol	doc_399014257229_item	3513417	et	3	main
tallinna	doc_399014257229_item	3513419	et	4	main
olga	doc_399014257229_item	3513455	et	4	main
sõtniku	doc_399014257229_item	3513457	et	4	main
asukoht	doc_399014257229_item	3513459	et	3	main
on	doc_399014257229_item	3513460	et	4	main
turismitee	doc_399014257229_item	3513466	et	4	main
ka	doc_399014257229_item	3513477	et	3	main
vanalinna	doc_399014257229_item	3513478	et	4	main
valitses	doc_399014257229_item	3513484	et	3	main
olnud	doc_399014257229_item	3513492	et	4	main
kohal	doc_399014257229_item	3513493	et	4	main
aga	doc_399014257229_item	3513494	et	3	main
paati	doc_399014257229_item	3513504	et	4	main
tema	doc_399014257229_item	3513514	et	4	main
eestlaste	doc_399014257229_item	3513527	et	4	main
kojutulekut	doc_399014257229_item	3513528	et	3	main
mõjukam	doc_399014257229_item	3513535	et	4	main
arhitektide	doc_399014257229_item	3513536	et	3	main
asukoha	doc_399014257229_item	3513547	et	4	main
varemgi	doc_399014257229_item	3513557	et	4	main
teiste	doc_399014257229_item	3513563	et	4	main
sõtniku	doc_399014257229_item	3513618	et	4	main
suunast	doc_399014257229_item	3513321	et	4	main
ja	doc_399014257229_item	3513337	et	3	main
idee	doc_399014257229_item	3513345	et	4	main
rahvuseepose	doc_399014257229_item	3513349	et	3	main
koosseistust	doc_399014257229_item	3513368	et	4	main
jüri	doc_399014257229_item	3513374	et	4	main
žürii	doc_399014257229_item	3513378	et	2	main
sõltumatu	doc_399014257229_item	3513380	et	4	main
kunstnikust	doc_399014257229_item	3513381	et	3	main
liige	doc_399014257229_item	3513382	et	4	main
vaidlusalune	doc_399014257229_item	3513395	et	4	main
skulptor	doc_399014257229_item	3513396	et	3	main
tauno	doc_399014257229_item	3513397	et	4	main
1990	doc_399014257229_item	3513406	et	2	main
oli	doc_399014257229_item	3513410	et	3	main
tallinnale	doc_399014257229_item	3513412	et	4	main
kopenhaageni	doc_399014257229_item	3513413	et	4	main
visualiseerisime	doc_399014257229_item	3513444	et	4	main
jõudsime	doc_399014257229_item	3513446	et	3	main
21	doc_399014257229_item	3513448	et	2	main
torkaks	doc_399014257229_item	3513451	et	3	main
seletab	doc_399014257229_item	3513453	et	3	main
hinnangul	doc_399014257229_item	3513458	et	3	main
spasse	doc_399014257229_item	3513470	et	4	main
ning	doc_399014257229_item	3513471	et	3	main
tallinna	doc_399014257229_item	3513472	et	4	main
tauno	doc_399014257229_item	3513480	et	4	main
veel	doc_399014257229_item	3513485	et	4	main
vaimustunud	doc_399014257229_item	3513487	et	4	main
kus	doc_399014257229_item	3513501	et	3	main
kalevipoeg	doc_399014257229_item	3513502	et	3	main
pärast	doc_399014257229_item	3513513	et	4	main
kangelase	doc_399014257229_item	3513519	et	3	main
boikoteerib	doc_399014257229_item	3513532	et	3	main
veel	doc_399014257229_item	3513534	et	4	main
muu	doc_399014257229_item	3513542	et	4	main
hoone	doc_399014257229_item	3513546	et	4	main
erakonnana	doc_399014257229_item	3513553	et	4	main
keskerakond	doc_399014257229_item	3513554	et	3	main
kes	doc_399014257229_item	3513555	et	4	main
kiindumust	doc_399014257229_item	3513559	et	4	main
kõrgete	doc_399014257229_item	3513560	et	4	main
skulptuuriprojekti	doc_399014257229_item	3513566	et	4	main
vastu	doc_399014257229_item	3513567	et	3	main
kuju	doc_399014257229_item	3513624	et	4	main
järgmisel	doc_399014257229_item	3513625	et	3	main
ja	doc_399014257229_item	3513626	et	3	main
viltu	doc_399014257232_item	3513634	et	3	main
mitmekorrulise	doc_399014257232_item	3513648	et	4	main
rahvaeepose	doc_399014257232_item	3513656	et	3	main
on	doc_399014257232_item	3513662	et	4	main
kolm	doc_399014257232_item	3513666	et	3	main
kaugusele	doc_399014257232_item	3513675	et	4	main
rannatee	doc_399014257232_item	3513679	et	4	main
samal	doc_399014257232_item	3513681	et	3	main
olnud	doc_399014257232_item	3513687	et	4	main
kangelastele	doc_399014257232_item	3513690	et	4	main
algavad	doc_399014257232_item	3513706	et	4	main
juba	doc_399014257232_item	3513707	et	3	main
ning	doc_399014257232_item	3513710	et	3	main
vananenud	doc_399014257232_item	3513720	et	4	main
ega	doc_399014257232_item	3513721	et	3	main
rahvaeepose	doc_399014257232_item	3513722	et	3	main
kangelane	doc_399014257232_item	3513723	et	3	main
memoriaalikompleksiga	doc_399014257232_item	3513728	et	4	main
sügisel	doc_399014257232_item	3513731	et	3	main
kujurite	doc_399014257232_item	3513733	et	3	main
esindajad	doc_399014257232_item	3513739	et	4	main
rahul	doc_399014257232_item	3513745	et	4	main
liige	doc_399014257232_item	3513751	et	4	main
juhtitud	doc_399014257232_item	3513755	et	4	main
parke	doc_399014257232_item	3513765	et	3	main
algurärase	doc_399014257232_item	3513766	et	4	main
kujur	doc_399014257232_item	3513774	et	3	main
kalevipoeg	doc_399014257232_item	3513781	et	3	main
teha	doc_399014257232_item	3513787	et	3	main
võrreldav	doc_399014257232_item	3513795	et	4	main
oli	doc_399014257232_item	3513798	et	3	main
meetri	doc_399014257232_item	3513804	et	3	main
võimalikest	doc_399014257232_item	3513843	et	4	main
ning	doc_399014257229_item	3513326	et	3	main
suurusest	doc_399014257229_item	3513336	et	4	main
hinnangul	doc_399014257229_item	3513343	et	3	main
on	doc_399014257229_item	3513344	et	4	main
tegelikult	doc_399014257229_item	3513346	et	4	main
vananenud	doc_399014257229_item	3513347	et	4	main
ning	doc_399014257229_item	3513348	et	3	main
konteksti	doc_399014257229_item	3513355	et	4	main
nii	doc_399014257229_item	3513358	et	3	main
kui	doc_399014257229_item	3513361	et	3	main
arhitektide	doc_399014257229_item	3513363	et	3	main
esindajad	doc_399014257229_item	3513365	et	4	main
juhitud	doc_399014257229_item	3513377	et	4	main
ainus	doc_399014257229_item	3513379	et	4	main
kalevipoja	doc_399014257229_item	3513402	et	4	main
aastate	doc_399014257229_item	3513407	et	3	main
selle	doc_399014257229_item	3513445	et	4	main
lõpptulemusena	doc_399014257229_item	3513447	et	3	main
meetrini	doc_399014257229_item	3513449	et	3	main
silma	doc_399014257229_item	3513452	et	4	main
on	doc_399014257229_item	3513465	et	4	main
ääres	doc_399014257229_item	3513467	et	4	main
sõites	doc_399014257229_item	3513468	et	3	main
pirita	doc_399014257229_item	3513469	et	4	main
siluetti	doc_399014257229_item	3513479	et	4	main
pronkskuju	doc_399014257229_item	3513500	et	4	main
kannab	doc_399014257229_item	3513503	et	3	main
maailmareisi	doc_399014257229_item	3513515	et	4	main
on	doc_399014257229_item	3513518	et	4	main
inimfiguuriga	doc_399014257229_item	3513524	et	3	main
ühingu	doc_399014257229_item	3513531	et	3	main
uue	doc_399014257229_item	3513544	et	3	main
tallinnas	doc_399014257229_item	3513549	et	4	main
võimul	doc_399014257229_item	3513551	et	3	main
osutanud	doc_399014257229_item	3513558	et	4	main
kunstnikute	doc_399014257229_item	3513564	et	4	main
kriitika	doc_399014257229_item	3513565	et	4	main
sellele	doc_399014257229_item	3513627	et	4	main
järgneval	doc_399014257229_item	3513628	et	4	main
aastal	doc_399014257229_item	3513629	et	3	main
tõlge	doc_399014257232_item	3513631	et	3	main
lahte	doc_399014257232_item	3513636	et	4	main
hiigelsuurele	doc_399014257232_item	3513638	et	4	main
kalevipoja-kujule	doc_399014257232_item	3513639	et	3	main
eesti	doc_399014257232_item	3513640	et	4	main
kunstnikud	doc_399014257232_item	3513641	et	3	main
lahte	doc_399014257232_item	3513647	et	4	main
kõrgune	doc_399014257232_item	3513653	et	4	main
kalevipoeg	doc_399014257232_item	3513654	et	3	main
linna	doc_399014257232_item	3513660	et	4	main
ainult	doc_399014257232_item	3513665	et	4	main
tallinn	doc_399014257232_item	3513677	et	4	main
äärde	doc_399014257232_item	3513680	et	4	main
rannatrepikoda	doc_399014257232_item	3513699	et	4	main
suurusest	doc_399014257232_item	3513709	et	4	main
kujurite	doc_399014257232_item	3513714	et	3	main
nõukogude	doc_399014257232_item	3513726	et	3	main
varem	doc_399014257232_item	3513730	et	4	main
ühendus	doc_399014257232_item	3513736	et	4	main
ära	doc_399014257232_item	3513741	et	4	main
nad	doc_399014257232_item	3513743	et	3	main
züriis	doc_399014257232_item	3513756	et	4	main
maastikuarhitekt	doc_399014257232_item	3513760	et	3	main
on	doc_399014257232_item	3513762	et	4	main
planeerinud	doc_399014257232_item	3513763	et	4	main
on	doc_399014257232_item	3513769	et	4	main
kellel	doc_399014257232_item	3513778	et	4	main
juba	doc_399014257232_item	3513782	et	3	main
ideeks	doc_399014257232_item	3513785	et	3	main
algupärases	doc_399014257232_item	3513796	et	4	main
tallinna	doc_399014257232_item	3513799	et	4	main
väike	doc_399014257232_item	3513800	et	4	main
paistab	doc_399014257232_item	3513831	et	3	main
põhjendab	doc_399014257232_item	3513833	et	3	main
sõtniku	doc_399014257232_item	3513837	et	4	main
on	doc_399014257232_item	3513839	et	4	main
koht	doc_399014257232_item	3513840	et	3	main
turistitee	doc_399014257232_item	3513847	et	4	main
tallinna	doc_399014257232_item	3513853	et	4	main
tauno	doc_399014257232_item	3513863	et	4	main
kujurite	doc_399014257229_item	3513330	et	3	main
ühingu	doc_399014257229_item	3513331	et	3	main
erimeelsused	doc_399014257229_item	3513332	et	4	main
lahes	doc_399014257229_item	3513339	et	4	main
kujurite	doc_399014257229_item	3513341	et	3	main
kangelane	doc_399014257229_item	3513350	et	3	main
varem	doc_399014257229_item	3513356	et	4	main
ka	doc_399014257229_item	3513362	et	3	main
liidu	doc_399014257229_item	3513364	et	3	main
lahkusid	doc_399014257229_item	3513366	et	4	main
konkursikomisjoni	doc_399014257229_item	3513367	et	4	main
linnapea	doc_399014257229_item	3513373	et	4	main
on	doc_399014257229_item	3513383	et	4	main
on	doc_399014257229_item	3513392	et	4	main
kes	doc_399014257229_item	3513400	et	4	main
hakkas	doc_399014257229_item	3513401	et	3	main
reklaamima	doc_399014257229_item	3513404	et	4	main
lõpul	doc_399014257229_item	3513408	et	3	main
võrreldav	doc_399014257229_item	3513416	et	4	main
originaalplaanis	doc_399014257229_item	3513418	et	3	main
väike	doc_399014257229_item	3513420	et	4	main
merineitsi	doc_399014257229_item	3513421	et	4	main
oli	doc_399014257229_item	3513422	et	3	main
ainult	doc_399014257229_item	3513423	et	4	main
14	doc_399014257229_item	3513424	et	2	main
meetrit	doc_399014257229_item	3513425	et	3	main
kõrge	doc_399014257229_item	3513426	et	4	main
aga	doc_399014257229_item	3513427	et	3	main
linna	doc_399014257229_item	3513428	et	4	main
ettepanekul	doc_399014257229_item	3513429	et	3	main
kõrgust	doc_399014257229_item	3513430	et	4	main
lisati	doc_399014257229_item	3513431	et	3	main
21	doc_399014257229_item	3513432	et	2	main
meetrini	doc_399014257229_item	3513433	et	3	main
hindasime	doc_399014257229_item	3513434	et	3	main
kuidas	doc_399014257229_item	3513435	et	3	main
skulptuur	doc_399014257229_item	3513436	et	3	main
sobib	doc_399014257229_item	3513437	et	3	main
kokku	doc_399014257229_item	3513438	et	3	main
maarjamäe	doc_399014257229_item	3513439	et	3	main
memoriaalkompleksiga	doc_399014257229_item	3513440	et	4	main
tegime	doc_399014257229_item	3513441	et	3	main
arvestusi	doc_399014257229_item	3513442	et	4	main
ja	doc_399014257229_item	3513443	et	3	main
see	doc_399014257229_item	3513450	et	3	main
sõtnik	doc_399014257229_item	3513456	et	4	main
kuju	doc_399014257229_item	3513474	et	4	main
ei	doc_399014257229_item	3513475	et	4	main
varjuta	doc_399014257229_item	3513476	et	4	main
galeriis	doc_399014257229_item	3513482	et	3	main
vanalinnas	doc_399014257229_item	3513483	et	4	main
esmaspäevalgi	doc_399014257229_item	3513486	et	4	main
meeleolu	doc_399014257229_item	3513488	et	4	main
kunstnik	doc_399014257229_item	3513489	et	3	main
ise	doc_399014257229_item	3513490	et	4	main
galeriipidaja	doc_399014257229_item	3513495	et	4	main
oma	doc_399014257229_item	3513505	et	4	main
suurtes	doc_399014257229_item	3513506	et	3	main
pihkudes	doc_399014257229_item	3513507	et	3	main
kunstniku	doc_399014257229_item	3513516	et	3	main
nägemusena	doc_399014257229_item	3513517	et	3	main
veel	doc_399014257229_item	3513521	et	4	main
mõne	doc_399014257229_item	3513523	et	3	main
peale	doc_399014257229_item	3513529	et	4	main
kujurite	doc_399014257229_item	3513530	et	3	main
skulptuuriprojekti	doc_399014257229_item	3513533	et	4	main
kes	doc_399014257229_item	3513538	et	4	main
linnaga	doc_399014257229_item	3513540	et	3	main
seas	doc_399014257229_item	3513543	et	4	main
linnavalitsuse	doc_399014257229_item	3513545	et	3	main
on	doc_399014257229_item	3513556	et	4	main
hoonete	doc_399014257229_item	3513561	et	4	main
vastu	doc_399014257229_item	3513562	et	3	main
järgi	doc_399014257229_item	3513620	et	4	main
on	doc_399014257229_item	3513621	et	4	main
kavas	doc_399014257229_item	3513622	et	3	main
rajada	doc_399014257229_item	3513623	et	3	main
kunstnikuühendused	doc_399014257232_item	3513632	et	3	main
vaatavad	doc_399014257232_item	3513642	et	4	main
viltu	doc_399014257232_item	3513643	et	3	main
kavatsusele	doc_399014257232_item	3513644	et	4	main
tallinna	doc_399014257232_item	3513646	et	4	main
suurune	doc_399014257232_item	3513650	et	4	main
21	doc_399014257232_item	3513651	et	2	main
meetri	doc_399014257232_item	3513652	et	3	main
tähtaegani	doc_399014257232_item	3513663	et	4	main
esitatud	doc_399014257232_item	3513668	et	4	main
on	doc_399014257232_item	3513670	et	4	main
püstitada	doc_399014257232_item	3513672	et	3	main
rannajoonest	doc_399014257232_item	3513676	et	4	main
kohal	doc_399014257232_item	3513682	et	4	main
rannas	doc_399014257232_item	3513683	et	3	main
on	doc_399014257232_item	3513684	et	4	main
nõukogude	doc_399014257232_item	3513685	et	3	main
teise	doc_399014257232_item	3513688	et	4	main
maailmasõja	doc_399014257232_item	3513689	et	3	main
püstitatud	doc_399014257232_item	3513691	et	4	main
linna	doc_399014257232_item	3513701	et	4	main
ja	doc_399014257232_item	3513702	et	3	main
kujurite	doc_399014257232_item	3513703	et	3	main
kuju	doc_399014257232_item	3513708	et	4	main
asukohast	doc_399014257232_item	3513711	et	4	main
eesti	doc_399014257232_item	3513713	et	4	main
ühenduse	doc_399014257232_item	3513715	et	4	main
sobi	doc_399014257232_item	3513725	et	4	main
nii	doc_399014257232_item	3513732	et	3	main
kutsusid	doc_399014257232_item	3513737	et	4	main
sõltumatu	doc_399014257232_item	3513749	et	4	main
ratase	doc_399014257232_item	3513754	et	4	main
linna	doc_399014257232_item	3513764	et	4	main
siiski	doc_399014257232_item	3513770	et	4	main
kunstnik	doc_399014257232_item	3513771	et	3	main
vaidlust	doc_399014257232_item	3513772	et	3	main
äratav	doc_399014257232_item	3513773	et	4	main
40	doc_399014257232_item	3513777	et	2	main
kavatsusel	doc_399014257232_item	3513780	et	4	main
lõpus	doc_399014257232_item	3513784	et	4	main
oli	doc_399014257232_item	3513786	et	3	main
mis	doc_399014257232_item	3513790	et	4	main
kopenhaagenist	doc_399014257232_item	3513792	et	4	main
väikese	doc_399014257232_item	3513793	et	4	main
mereneitsiga	doc_399014257232_item	3513794	et	3	main
mereneitsi	doc_399014257232_item	3513801	et	4	main
silma	doc_399014257232_item	3513832	et	4	main
pärast	doc_399014257229_item	3513548	et	4	main
on	doc_399014257229_item	3513550	et	4	main
ainsana	doc_399014257229_item	3513552	et	3	main
lisandus	doc_399014257229_item	3513568	et	4	main
kui	doc_399014257229_item	3513569	et	3	main
ideet	doc_399014257229_item	3513570	et	4	main
kaua	doc_399014257229_item	3513571	et	3	main
tuntuks	doc_399014257229_item	3513572	et	4	main
teinud	doc_399014257229_item	3513573	et	4	main
kangro	doc_399014257229_item	3513574	et	4	main
astus	doc_399014257229_item	3513575	et	3	main
suvel	doc_399014257229_item	3513576	et	3	main
keskerakonda	doc_399014257229_item	3513577	et	4	main
kriitikat	doc_399014257229_item	3513578	et	3	main
on	doc_399014257229_item	3513579	et	4	main
pälvinud	doc_399014257229_item	3513580	et	4	main
ka	doc_399014257229_item	3513581	et	3	main
kalevipoeg	doc_399014257229_item	3513582	et	3	main
ise	doc_399014257229_item	3513583	et	4	main
kes	doc_399014257229_item	3513584	et	4	main
legendi	doc_399014257229_item	3513585	et	4	main
järel	doc_399014257229_item	3513586	et	4	main
viskas	doc_399014257229_item	3513587	et	3	main
vaenlasi	doc_399014257229_item	3513588	et	3	main
suurte	doc_399014257229_item	3513589	et	3	main
kividega	doc_399014257229_item	3513590	et	3	main
aga	doc_399014257229_item	3513591	et	3	main
oli	doc_399014257229_item	3513592	et	3	main
süüdi	doc_399014257229_item	3513593	et	4	main
ka	doc_399014257229_item	3513594	et	3	main
neiu	doc_399014257229_item	3513595	et	4	main
vägistamises	doc_399014257229_item	3513596	et	4	main
meres	doc_399014257229_item	3513597	et	3	main
on	doc_399014257229_item	3513598	et	4	main
jutu	doc_399014257229_item	3513619	et	3	main
vaatavad	doc_399014257232_item	3513633	et	4	main
planeeritud	doc_399014257232_item	3513637	et	4	main
samanimelise	doc_399014257232_item	3513657	et	4	main
kangelase	doc_399014257232_item	3513658	et	3	main
järgi	doc_399014257232_item	3513659	et	4	main
esmaspäeval	doc_399014257232_item	3513664	et	3	main
plaanis	doc_399014257232_item	3513671	et	4	main
saja	doc_399014257232_item	3513673	et	4	main
meetri	doc_399014257232_item	3513674	et	3	main
ajal	doc_399014257232_item	3513686	et	4	main
memoriaalikompleks	doc_399014257232_item	3513692	et	4	main
millest	doc_399014257232_item	3513693	et	3	main
paistavad	doc_399014257232_item	3513694	et	3	main
mereni	doc_399014257232_item	3513695	et	3	main
kõrge	doc_399014257232_item	3513696	et	4	main
tallinna	doc_399014257232_item	3513635	et	4	main
püstitada	doc_399014257232_item	3513645	et	3	main
maja	doc_399014257232_item	3513649	et	4	main
eesti	doc_399014257232_item	3513655	et	4	main
konkursile	doc_399014257232_item	3513661	et	3	main
konkursikavandit	doc_399014257232_item	3513667	et	3	main
kalevipoeg	doc_399014257232_item	3513669	et	3	main
pirita	doc_399014257232_item	3513678	et	4	main
erimeelsused	doc_399014257232_item	3513700	et	4	main
idee	doc_399014257232_item	3513716	et	4	main
kui	doc_399014257232_item	3513717	et	3	main
niisugune	doc_399014257232_item	3513718	et	3	main
on	doc_399014257232_item	3513719	et	4	main
kokku	doc_399014257232_item	3513729	et	3	main
kui	doc_399014257232_item	3513734	et	3	main
oma	doc_399014257232_item	3513738	et	4	main
polnud	doc_399014257232_item	3513744	et	3	main
zürii	doc_399014257232_item	3513746	et	4	main
bürokratismiga	doc_399014257232_item	3513747	et	3	main
ainuke	doc_399014257232_item	3513748	et	4	main
on	doc_399014257232_item	3513757	et	4	main
kangro	doc_399014257232_item	3513776	et	4	main
sümbol	doc_399014257232_item	3513789	et	3	main
ainult	doc_399014257232_item	3513802	et	4	main
obelisk	doc_399014257232_item	3513697	et	3	main
ja	doc_399014257232_item	3513698	et	3	main
ühenduse	doc_399014257232_item	3513704	et	4	main
vahel	doc_399014257232_item	3513705	et	4	main
meres	doc_399014257232_item	3513712	et	3	main
mitte	doc_399014257232_item	3513724	et	3	main
aegse	doc_399014257232_item	3513727	et	3	main
arhitektide	doc_399014257232_item	3513735	et	3	main
züriist	doc_399014257232_item	3513740	et	4	main
sest	doc_399014257232_item	3513742	et	4	main
kunstnikust	doc_399014257232_item	3513750	et	3	main
linnapea	doc_399014257232_item	3513752	et	4	main
jüri	doc_399014257232_item	3513753	et	4	main
lõpuks	doc_399014257232_item	3513758	et	4	main
enam	doc_399014257232_item	3513759	et	4	main
kes	doc_399014257232_item	3513761	et	4	main
idee	doc_399014257232_item	3513767	et	4	main
isa	doc_399014257232_item	3513768	et	4	main
tauno	doc_399014257232_item	3513775	et	4	main
oli	doc_399014257232_item	3513779	et	3	main
1990aastate	doc_399014257232_item	3513783	et	3	main
tallinnasse	doc_399014257232_item	3513788	et	3	main
on	doc_399014257232_item	3513791	et	4	main
kavas	doc_399014257232_item	3513797	et	3	main
14	doc_399014257232_item	3513803	et	2	main
kõrgune	doc_399014257232_item	3513805	et	4	main
aga	doc_399014257232_item	3513806	et	3	main
linna	doc_399014257232_item	3513807	et	4	main
ettepanekul	doc_399014257232_item	3513808	et	3	main
tõsteti	doc_399014257232_item	3513809	et	3	main
kõrgus	doc_399014257232_item	3513810	et	4	main
21	doc_399014257232_item	3513811	et	2	main
meetri	doc_399014257232_item	3513812	et	3	main
selgitasime	doc_399014257232_item	3513813	et	3	main
välja	doc_399014257232_item	3513814	et	4	main
kuidas	doc_399014257232_item	3513815	et	3	main
kuju	doc_399014257232_item	3513816	et	4	main
sobib	doc_399014257232_item	3513817	et	3	main
maaarjamäe	doc_399014257232_item	3513818	et	4	main
memoriaaliga	doc_399014257232_item	3513819	et	4	main
kokku	doc_399014257232_item	3513820	et	3	main
pidasime	doc_399014257232_item	3513821	et	3	main
arvestusi	doc_399014257232_item	3513822	et	4	main
ja	doc_399014257232_item	3513823	et	3	main
tegime	doc_399014257232_item	3513824	et	3	main
selle	doc_399014257232_item	3513825	et	4	main
visuaalseks	doc_399014257232_item	3513826	et	4	main
jõudsime	doc_399014257232_item	3513827	et	3	main
21	doc_399014257232_item	3513828	et	2	main
meetrile	doc_399014257232_item	3513829	et	3	main
see	doc_399014257232_item	3513830	et	3	main
abilinnapea	doc_399014257232_item	3513834	et	4	main
kõige	doc_399014257232_item	3513841	et	4	main
parem	doc_399014257232_item	3513842	et	4	main
asub	doc_399014257232_item	3513846	et	3	main
ääres	doc_399014257232_item	3513848	et	4	main
minnes	doc_399014257232_item	3513849	et	3	main
pirita	doc_399014257232_item	3513850	et	4	main
poole	doc_399014257232_item	3513855	et	4	main
innustunud	doc_399014257232_item	3513871	et	4	main
linnas	doc_399014257232_item	3513876	et	4	main
mägila	doc_399014257232_item	3513880	et	4	main
sõtnik	doc_399014257232_item	3513836	et	4	main
sõnul	doc_399014257232_item	3513838	et	3	main
ja	doc_399014257232_item	3513852	et	3	main
see	doc_399014257232_item	3513856	et	3	main
varja	doc_399014257232_item	3513858	et	4	main
siluetti	doc_399014257232_item	3513862	et	4	main
kunstnik	doc_399014257232_item	3513873	et	3	main
aga	doc_399014257232_item	3513877	et	3	main
pille	doc_399014257232_item	3513879	et	3	main
käega	doc_399014257232_item	3513887	et	3	main
kannab	doc_399014257232_item	3513889	et	3	main
kuju	doc_399014257232_item	3513891	et	4	main
sümboliseerib	doc_399014257232_item	3513892	et	3	main
kangelase	doc_399014257232_item	3513893	et	3	main
naasmist	doc_399014257232_item	3513894	et	4	main
koju	doc_399014257232_item	3513895	et	3	main
pärast	doc_399014257232_item	3513896	et	4	main
seda	doc_399014257232_item	3513897	et	3	main
kui	doc_399014257232_item	3513898	et	3	main
ta	doc_399014257232_item	3513899	et	4	main
oli	doc_399014257232_item	3513900	et	3	main
maailma	doc_399014257232_item	3513901	et	4	main
ringi	doc_399014257232_item	3513902	et	4	main
sõitnud	doc_399014257232_item	3513903	et	4	main
kangelase	doc_399014257232_item	3513904	et	3	main
käes	doc_399014257232_item	3513905	et	4	main
on	doc_399014257232_item	3513906	et	4	main
kujuri	doc_399014257232_item	3513907	et	3	main
vaatenurga	doc_399014257232_item	3513908	et	3	main
järgi	doc_399014257232_item	3513909	et	4	main
veel	doc_399014257232_item	3513910	et	4	main
paat	doc_399014257232_item	3513911	et	3	main
ja	doc_399014257232_item	3513912	et	3	main
inimkuju	doc_399014257232_item	3513913	et	4	main
mis	doc_399014257232_item	3513914	et	4	main
sümboliseerivad	doc_399014257232_item	3513915	et	4	main
eestlaste	doc_399014257232_item	3513916	et	4	main
koju	doc_399014257232_item	3513917	et	3	main
naasmist	doc_399014257232_item	3513918	et	4	main
lisaks	doc_399014257232_item	3513919	et	4	main
kujurite	doc_399014257232_item	3513920	et	3	main
liit	doc_399014257232_item	3513926	et	3	main
olga	doc_399014257232_item	3513835	et	4	main
sest	doc_399014257232_item	3513844	et	4	main
see	doc_399014257232_item	3513845	et	3	main
botaanikaaia	doc_399014257232_item	3513854	et	4	main
ei	doc_399014257232_item	3513857	et	4	main
mitte	doc_399014257232_item	3513859	et	3	main
ka	doc_399014257232_item	3513860	et	3	main
vanalinna	doc_399014257232_item	3513861	et	4	main
valitses	doc_399014257232_item	3513867	et	3	main
veel	doc_399014257232_item	3513868	et	4	main
ka	doc_399014257232_item	3513869	et	3	main
esmaspäeval	doc_399014257232_item	3513870	et	3	main
galerist	doc_399014257232_item	3513878	et	4	main
suure	doc_399014257232_item	3513886	et	3	main
mis	doc_399014257232_item	3513927	et	4	main
linnaga	doc_399014257232_item	3513929	et	3	main
skulptuuriürituse	doc_399014257232_item	3513951	et	4	main
lisandus	doc_399014257232_item	3513953	et	4	main
pikka	doc_399014257232_item	3513958	et	4	main
astus	doc_399014257232_item	3513962	et	3	main
ka	doc_399014257232_item	3513968	et	3	main
küsitud	doc_399014257232_item	3513985	et	4	main
jaanuari	doc_399014257232_item	3513995	et	4	main
sõnul	doc_399014257232_item	3514004	et	3	main
kuju	doc_399014257232_item	3514007	et	4	main
tervisekeskuse	doc_399014257232_item	3513851	et	3	main
galeriis	doc_399014257232_item	3513865	et	3	main
vanalinnas	doc_399014257232_item	3513866	et	4	main
ise	doc_399014257232_item	3513874	et	4	main
pronksist	doc_399014257232_item	3513883	et	4	main
boikoteerib	doc_399014257232_item	3513922	et	3	main
kujuüritust	doc_399014257232_item	3513923	et	3	main
mõjuvõimsam	doc_399014257232_item	3513924	et	4	main
arhitektide	doc_399014257232_item	3513925	et	3	main
kunstnikute	doc_399014257232_item	3513949	et	4	main
suvel	doc_399014257232_item	3513963	et	3	main
kriitikat	doc_399014257232_item	3513965	et	3	main
viskas	doc_399014257232_item	3513971	et	3	main
järgi	doc_399014257232_item	3513973	et	4	main
vaenlasi	doc_399014257232_item	3513974	et	3	main
suurte	doc_399014257232_item	3513975	et	3	main
kividega	doc_399014257232_item	3513976	et	3	main
aga	doc_399014257232_item	3513977	et	3	main
oli	doc_399014257232_item	3513978	et	3	main
ka	doc_399014257232_item	3513979	et	3	main
neiu	doc_399014257232_item	3513980	et	4	main
meres	doc_399014257232_item	3513981	et	3	main
on	doc_399014257232_item	3513984	et	4	main
tuleval	doc_399014257232_item	3514008	et	4	main
ja	doc_399014257232_item	3514009	et	3	main
järgmisel	doc_399014257232_item	3514010	et	3	main
aastal	doc_399014257232_item	3514011	et	3	main
püstitada	doc_399014257232_item	3514012	et	3	main
raamatut	doc_399014257233_item	3514021	et	3	main
ringkäigule	doc_399014257233_item	3514026	et	3	main
tagusesse	doc_399014257233_item	3514029	et	4	main
helsingisse	doc_399014257233_item	3514030	et	4	main
tohutu	doc_399014257233_item	3514048	et	4	main
kasv	doc_399014257233_item	3514049	et	3	main
ja	doc_399014257233_item	3514050	et	3	main
linna	doc_399014257233_item	3514056	et	4	main
ning	doc_399014257233_item	3514059	et	3	main
kaduvaid	doc_399014257233_item	3514062	et	4	main
sada	doc_399014257233_item	3514064	et	4	main
selleks	doc_399014257233_item	3514067	et	4	main
veelgi	doc_399014257233_item	3514112	et	4	main
signe	doc_399014257233_item	3514127	et	4	main
uurija	doc_399014257233_item	3514134	et	4	main
tegid	doc_399014257233_item	3514137	et	4	main
sada	doc_399014257233_item	3514142	et	4	main
on	doc_399014257233_item	3514148	et	4	main
helsingi	doc_399014257233_item	3514149	et	4	main
vähemalt	doc_399014257233_item	3514158	et	4	main
branderi	doc_399014257233_item	3514161	et	4	main
2000	doc_399014257233_item	3514163	et	2	main
sajandi	doc_399014257233_item	3514164	et	3	main
nüüd	doc_399014257233_item	3514168	et	4	main
nõukogu	doc_399014257233_item	3514195	et	4	main
sellistest	doc_399014257233_item	3514200	et	4	main
kohtadest	doc_399014257233_item	3514201	et	3	main
mida	doc_399014257233_item	3514202	et	4	main
ta	doc_399014257233_item	3514203	et	4	main
kasvas	doc_399014257233_item	3514215	et	3	main
sajandi	doc_399014257233_item	3514221	et	3	main
ning	doc_399014257233_item	3514229	et	3	main
hakkasid	doc_399014257233_item	3514238	et	4	main
pakarinen	doc_399014257233_item	3514245	et	4	main
osava	doc_399014257233_item	3514260	et	3	main
pärit	doc_399014257233_item	3514269	et	3	main
kunagi	doc_399014257233_item	3514276	et	3	main
ametikoha	doc_399014257233_item	3514281	et	4	main
peale	doc_399014257233_item	3514282	et	4	main
õnnestus	doc_399014257233_item	3514317	et	4	main
tehnika	doc_399014257233_item	3514328	et	4	main
kohmakas	doc_399014257233_item	3514330	et	4	main
piltidest	doc_399014257233_item	3514342	et	3	main
väga	doc_399014257233_item	3514343	et	3	main
elavad	doc_399014257233_item	3514344	et	4	main
mõõdujaid	doc_399014257233_item	3514350	et	4	main
sada	doc_399014257233_item	3514356	et	4	main
aastad	doc_399014257233_item	3514357	et	3	main
tagasi	doc_399014257233_item	3514358	et	3	main
kasvatasid	doc_399014257233_item	3514359	et	4	main
venelased	doc_399014257233_item	3514360	et	3	main
töölö	doc_399014257233_item	3514361	et	4	main
linnaosas	doc_399014257233_item	3514362	et	3	main
kangro	doc_399014257232_item	3513864	et	4	main
meeleolu	doc_399014257232_item	3513872	et	4	main
polnud	doc_399014257232_item	3513875	et	3	main
kuju	doc_399014257232_item	3513884	et	4	main
millel	doc_399014257232_item	3513885	et	3	main
kalevipoeg	doc_399014257232_item	3513888	et	3	main
ühendusele	doc_399014257232_item	3513921	et	4	main
kangro	doc_399014257232_item	3513961	et	4	main
keskerakonda	doc_399014257232_item	3513964	et	4	main
kalevipoeg	doc_399014257232_item	3513969	et	3	main
süüdi	doc_399014257232_item	3513983	et	4	main
on	doc_399014257232_item	3513988	et	4	main
abilinnapea	doc_399014257232_item	3514002	et	4	main
on	doc_399014257232_item	3514005	et	4	main
raamat	doc_399014257233_item	3514024	et	3	main
aasta	doc_399014257233_item	3514028	et	4	main
kolme	doc_399014257233_item	3514041	et	4	main
jooksul	doc_399014257233_item	3514043	et	4	main
kolmekordistunud	doc_399014257233_item	3514046	et	4	main
linna	doc_399014257233_item	3514047	et	4	main
ärkama	doc_399014257233_item	3514058	et	3	main
pildistas	doc_399014257233_item	3514098	et	3	main
seitse	doc_399014257233_item	3514101	et	3	main
helsingi	doc_399014257233_item	3514113	et	4	main
esitles	doc_399014257232_item	3513881	et	3	main
innukalt	doc_399014257232_item	3513882	et	4	main
laeva	doc_399014257232_item	3513890	et	4	main
ms	doc_399014257232_item	3513931	et	4	main
uue	doc_399014257232_item	3513932	et	3	main
raekoja	doc_399014257232_item	3513933	et	3	main
asukoha	doc_399014257232_item	3513934	et	4	main
pärast	doc_399014257232_item	3513935	et	4	main
tallinnas	doc_399014257232_item	3513936	et	4	main
valitseb	doc_399014257232_item	3513937	et	3	main
keskerakond	doc_399014257232_item	3513938	et	3	main
ainsana	doc_399014257232_item	3513939	et	3	main
erakonnana	doc_399014257232_item	3513940	et	4	main
on	doc_399014257232_item	3513942	et	4	main
varemgi	doc_399014257232_item	3513943	et	4	main
see	doc_399014257232_item	3513941	et	3	main
olnud	doc_399014257232_item	3513944	et	4	main
vaimustuses	doc_399014257232_item	3513945	et	4	main
kõrgetest	doc_399014257232_item	3513946	et	4	main
ehitustest	doc_399014257232_item	3513947	et	4	main
tülitseb	doc_399014257232_item	3513928	et	3	main
ka	doc_399014257232_item	3513930	et	3	main
kriitika	doc_399014257232_item	3513950	et	4	main
ideed	doc_399014257232_item	3513957	et	4	main
aega	doc_399014257232_item	3513959	et	4	main
saanud	doc_399014257232_item	3513967	et	4	main
vägistamises	doc_399014257232_item	3513982	et	4	main
sobiv	doc_399014257232_item	3513989	et	4	main
sümbol	doc_399014257232_item	3513990	et	3	main
merre	doc_399014257232_item	3513991	et	3	main
kalevipoeg-võistluse	doc_399014257232_item	3513992	et	3	main
tulemused	doc_399014257232_item	3513993	et	3	main
kuulutatakse	doc_399014257232_item	3513994	et	3	main
kavas	doc_399014257232_item	3514006	et	3	main
tõlge	doc_399014257233_item	3514014	et	3	main
branderi	doc_399014257233_item	3514016	et	4	main
helsingi	doc_399014257233_item	3514017	et	4	main
helsingi	doc_399014257233_item	3514018	et	4	main
linnamuuseum	doc_399014257233_item	3514019	et	3	main
fotograafist	doc_399014257233_item	3514023	et	4	main
ületas	doc_399014257233_item	3514034	et	3	main
inimese	doc_399014257233_item	3514037	et	4	main
aastal	doc_399014257233_item	3514039	et	3	main
see	doc_399014257233_item	3514045	et	3	main
otsustajad	doc_399014257233_item	3514057	et	4	main
puumaju	doc_399014257233_item	3514063	et	3	main
aastad	doc_399014257233_item	3514065	et	3	main
helsingi	doc_399014257233_item	3514069	et	4	main
umbes	doc_399014257233_item	3514100	et	4	main
ajavahemikul	doc_399014257233_item	3514103	et	4	main
1913	doc_399014257233_item	3514105	et	2	main
nüüd	doc_399014257233_item	3514120	et	4	main
avaldanud	doc_399014257233_item	3514121	et	4	main
branderi	doc_399014257233_item	3514128	et	4	main
piltidele	doc_399014257233_item	3514129	et	3	main
fotograaf	doc_399014257233_item	3514130	et	4	main
raamatut	doc_399014257233_item	3514138	et	3	main
vaevalt	doc_399014257233_item	3514147	et	4	main
ühtki	doc_399014257233_item	3514153	et	4	main
raamatut	doc_399014257233_item	3514154	et	3	main
milles	doc_399014257233_item	3514155	et	3	main
aga	doc_399014257233_item	3514166	et	3	main
tema	doc_399014257233_item	3514170	et	4	main
plaani	doc_399014257233_item	3514199	et	4	main
oli	doc_399014257233_item	3514208	et	3	main
teada	doc_399014257233_item	3514209	et	3	main
et	doc_399014257233_item	3514210	et	3	main
tuleb	doc_399014257233_item	3514211	et	3	main
suuri	doc_399014257233_item	3514212	et	3	main
muudatusi	doc_399014257233_item	3514213	et	3	main
ja	doc_399014257233_item	3514216	et	3	main
2000	doc_399014257233_item	3514220	et	2	main
ehitama	doc_399014257233_item	3514228	et	4	main
alguses	doc_399014257233_item	3514232	et	4	main
ühe-	doc_399014257233_item	3514234	et	4	main
ja	doc_399014257233_item	3514235	et	3	main
kahekorrusellised	doc_399014257233_item	3514236	et	4	main
puumajad	doc_399014257233_item	3514237	et	3	main
riitta	doc_399014257233_item	3514244	et	4	main
signe	doc_399014257233_item	3514248	et	4	main
valimine	doc_399014257233_item	3514250	et	4	main
fotograafiks	doc_399014257233_item	3514252	et	4	main
oli	doc_399014257233_item	3514253	et	3	main
enesestmõistetav	doc_399014257233_item	3514254	et	3	main
tal	doc_399014257233_item	3514255	et	3	main
oli	doc_399014257233_item	3514256	et	3	main
olemas	doc_399014257233_item	3514257	et	4	main
aga	doc_399014257233_item	3514275	et	3	main
asunud	doc_399014257233_item	3514278	et	4	main
ta	doc_399014257233_item	3514279	et	4	main
selle	doc_399014257233_item	3514283	et	4	main
ei	doc_399014257233_item	3514289	et	4	main
muude	doc_399014257232_item	3513948	et	4	main
pärast	doc_399014257232_item	3513952	et	4	main
pärast	doc_399014257232_item	3513954	et	4	main
seda	doc_399014257232_item	3513955	et	3	main
kui	doc_399014257232_item	3513956	et	3	main
pakkunud	doc_399014257232_item	3513960	et	4	main
on	doc_399014257232_item	3513966	et	4	main
kes	doc_399014257232_item	3513970	et	4	main
legendi	doc_399014257232_item	3513972	et	4	main
kas	doc_399014257232_item	3513986	et	3	main
ta	doc_399014257232_item	3513987	et	4	main
lõpus	doc_399014257232_item	3513996	et	4	main
välja	doc_399014257232_item	3513997	et	4	main
seejärel	doc_399014257232_item	3513998	et	3	main
korraldatakse	doc_399014257232_item	3513999	et	3	main
võistlustööde	doc_399014257232_item	3514000	et	3	main
näitus	doc_399014257232_item	3514001	et	3	main
sõtniku	doc_399014257232_item	3514003	et	4	main
koostas	doc_399014257233_item	3514020	et	4	main
saja	doc_399014257233_item	3514027	et	4	main
arv	doc_399014257233_item	3514033	et	3	main
100	doc_399014257233_item	3514035	et	2	main
piiri	doc_399014257233_item	3514038	et	4	main
aastakümne	doc_399014257233_item	3514042	et	4	main
oli	doc_399014257233_item	3514044	et	3	main
said	doc_399014257233_item	3514052	et	4	main
arhitektid	doc_399014257233_item	3514053	et	3	main
ja	doc_399014257233_item	3514054	et	3	main
helsingi	doc_399014257233_item	3514055	et	4	main
salvestama	doc_399014257233_item	3514060	et	3	main
tagasi	doc_399014257233_item	3514066	et	3	main
otsustas	doc_399014257233_item	3514068	et	3	main
helsingit	doc_399014257233_item	3514099	et	4	main
aastad	doc_399014257233_item	3514102	et	3	main
1907	doc_399014257233_item	3514104	et	2	main
sündis	doc_399014257233_item	3514107	et	3	main
pilti	doc_399014257233_item	3514109	et	4	main
mis	doc_399014257233_item	3514110	et	4	main
peetakse	doc_399014257233_item	3514111	et	3	main
linnamuuseumi	doc_399014257233_item	3514114	et	4	main
põhiosaks	doc_399014257233_item	3514116	et	3	main
pöhineb	doc_399014257233_item	3514125	et	4	main
jan	doc_399014257233_item	3514131	et	4	main
pakarinen	doc_399014257233_item	3514136	et	4	main
helsingi-teemalistest	doc_399014257233_item	3514145	et	4	main
piltidest	doc_399014257233_item	3514146	et	3	main
avaldatud	doc_399014257233_item	3514152	et	4	main
mõned	doc_399014257233_item	3514159	et	3	main
alles	doc_399014257233_item	3514167	et	3	main
saab	doc_399014257233_item	3514169	et	3	main
branderi	doc_399014257233_item	3514197	et	4	main
helsingi	doc_399014257233_item	3514214	et	4	main
muutus	doc_399014257233_item	3514217	et	4	main
linnaosi	doc_399014257233_item	3514223	et	4	main
1900	doc_399014257233_item	3514230	et	2	main
arvab	doc_399014257233_item	3514246	et	3	main
tõestus	doc_399014257233_item	3514258	et	4	main
kui	doc_399014257233_item	3514259	et	3	main
kes	doc_399014257233_item	3514267	et	4	main
oli	doc_399014257233_item	3514268	et	3	main
parkanost	doc_399014257233_item	3514270	et	4	main
lääne-soomest	doc_399014257233_item	3514271	et	3	main
õppis	doc_399014257233_item	3514272	et	3	main
helsingis	doc_399014257233_item	3514273	et	4	main
väga	doc_399014257233_item	3514319	et	3	main
linna	doc_399014257233_item	3514321	et	4	main
ja	doc_399014257233_item	3514322	et	3	main
tol	doc_399014257233_item	3514325	et	3	main
ajal	doc_399014257233_item	3514326	et	4	main
oli	doc_399014257233_item	3514327	et	3	main
ta	doc_399014257233_item	3514331	et	4	main
erinevad	doc_399014257233_item	3514338	et	4	main
nüanssid	doc_399014257233_item	3514339	et	3	main
tegid	doc_399014257233_item	3514340	et	4	main
helsingi	doc_399014257233_item	3514363	et	4	main
elanikudele	doc_399014257233_item	3514364	et	3	main
neil	doc_399014257233_item	3514375	et	4	main
järgi	doc_399014257233_item	3514384	et	4	main
arvata	doc_399014257233_item	3514386	et	4	main
et	doc_399014257233_item	3514387	et	3	main
branderil	doc_399014257233_item	3514388	et	4	main
signe	doc_399014257233_item	3514015	et	4	main
legendaarsest	doc_399014257233_item	3514022	et	3	main
juhatab	doc_399014257233_item	3514025	et	3	main
helsingi	doc_399014257233_item	3514031	et	4	main
elanike	doc_399014257233_item	3514032	et	3	main
000	doc_399014257233_item	3514036	et	2	main
1902	doc_399014257233_item	3514040	et	2	main
muutused	doc_399014257233_item	3514051	et	4	main
linna	doc_399014257233_item	3514061	et	4	main
linnavolikogu	doc_399014257233_item	3514070	et	4	main
aastal	doc_399014257233_item	3514071	et	3	main
1906	doc_399014257233_item	3514072	et	2	main
rajada	doc_399014257233_item	3514073	et	3	main
muinsuskaitsenõukogu	doc_399014257233_item	3514074	et	4	main
mis	doc_399014257233_item	3514075	et	4	main
järgmisel	doc_399014257233_item	3514076	et	3	main
aastal	doc_399014257233_item	3514077	et	3	main
pakkus	doc_399014257233_item	3514078	et	3	main
tööd	doc_399014257233_item	3514079	et	4	main
fotograaf	doc_399014257233_item	3514080	et	4	main
signe	doc_399014257233_item	3514081	et	4	main
branderile	doc_399014257233_item	3514082	et	4	main
1869	doc_399014257233_item	3514083	et	2	main
1942	doc_399014257233_item	3514084	et	2	main
seda	doc_399014257233_item	3514085	et	3	main
otsust	doc_399014257233_item	3514086	et	4	main
on	doc_399014257233_item	3514087	et	4	main
kiidetud	doc_399014257233_item	3514088	et	4	main
mitu	doc_399014257233_item	3514089	et	4	main
korda	doc_399014257233_item	3514090	et	4	main
targaks	doc_399014257233_item	3514091	et	3	main
ja	doc_399014257233_item	3514092	et	3	main
kaugele	doc_399014257233_item	3514093	et	4	main
ulatuvaks	doc_399014257233_item	3514094	et	4	main
ka	doc_399014257233_item	3514095	et	3	main
hiljem	doc_399014257233_item	3514096	et	3	main
brander	doc_399014257233_item	3514097	et	4	main
tulemuseks	doc_399014257233_item	3514106	et	3	main
907	doc_399014257233_item	3514108	et	2	main
piltiarhiivi	doc_399014257233_item	3514115	et	4	main
esimese	doc_399014257233_item	3514122	et	3	main
raamatut	doc_399014257233_item	3514123	et	3	main
mis	doc_399014257233_item	3514124	et	4	main
riitta	doc_399014257233_item	3514135	et	4	main
on	doc_399014257233_item	3514140	et	4	main
kohta	doc_399014257233_item	3514151	et	4	main
oleks	doc_399014257233_item	3514157	et	3	main
algusest	doc_399014257233_item	3514165	et	4	main
koostas	doc_399014257233_item	3514196	et	4	main
väga	doc_399014257233_item	3514218	et	3	main
sajandi	doc_399014257233_item	3514231	et	3	main
ehitatud	doc_399014257233_item	3514233	et	4	main
kaduma	doc_399014257233_item	3514240	et	4	main
et	doc_399014257233_item	3514247	et	3	main
helsingi	doc_399014257233_item	3514251	et	4	main
maastiku	doc_399014257233_item	3514264	et	4	main
selle	doc_399014257233_item	3514280	et	4	main
asemele	doc_399014257233_item	3514284	et	4	main
temast	doc_399014257233_item	3514285	et	3	main
sai	doc_399014257233_item	3514286	et	4	main
fotograaf	doc_399014257233_item	3514287	et	4	main
kellele	doc_399014257233_item	3514288	et	4	main
tööd	doc_399014257233_item	3514314	et	4	main
pildistada	doc_399014257233_item	3514318	et	3	main
suurepäraselt	doc_399014257233_item	3514320	et	4	main
pildistanud	doc_399014257233_item	3514333	et	4	main
arhitektuuri	doc_399014257233_item	3514335	et	4	main
ja	doc_399014257233_item	3514337	et	3	main
kõikidel	doc_399014257233_item	3514346	et	4	main
piltidel	doc_399014257233_item	3514347	et	3	main
kas	doc_399014257233_item	3514349	et	3	main
müüjaid	doc_399014257233_item	3514352	et	4	main
politseinikuid	doc_399014257233_item	3514353	et	3	main
koduloomi	doc_399014257233_item	3514355	et	4	main
inimestest	doc_399014257233_item	3514367	et	3	main
on	doc_399014257233_item	3514368	et	4	main
väljendada	doc_399014257233_item	3514392	et	3	main
inimestes	doc_399014257233_item	3514395	et	3	main
asi	doc_399014257233_item	3514401	et	4	main
ja	doc_399014257233_item	3514402	et	3	main
naine	doc_399014257233_item	3514403	et	3	main
lehekülgetel	doc_399014257233_item	3514428	et	3	main
jää	doc_399014257233_item	3514432	et	4	main
nagu	doc_399014257233_item	3514434	et	3	main
aasta	doc_399014257233_item	3514440	et	4	main
taguses	doc_399014257233_item	3514441	et	3	main
siis	doc_399014257233_item	3514449	et	3	main
ja	doc_399014257233_item	3514451	et	3	main
kamppi	doc_399014257233_item	3514460	et	4	main
kuni	doc_399014257233_item	3514461	et	3	main
töölöni	doc_399014257233_item	3514462	et	4	main
kirjas	doc_399014257233_item	3514473	et	4	main
kus	doc_399014257233_item	3514474	et	3	main
on	doc_399014257233_item	3514483	et	4	main
aastal	doc_399014257233_item	3514537	et	3	main
alalise	doc_399014257233_item	3514555	et	4	main
brander	doc_399014257233_item	3514560	et	4	main
tõttu	doc_399014257233_item	3514583	et	4	main
1930	doc_399014257233_item	3514584	et	2	main
1941	doc_399014257233_item	3514589	et	2	main
kust	doc_399014257233_item	3514592	et	4	main
patsiendid	doc_399014257233_item	3514593	et	3	main
nikkilä	doc_399014257233_item	3514597	et	4	main
põhjuseks	doc_399014257233_item	3514599	et	3	main
nälga	doc_399014257233_item	3514616	et	4	main
nende	doc_399014257233_item	3514623	et	4	main
signe	doc_399014257234_item	3514639	et	4	main
helsingi	doc_399014257234_item	3514641	et	4	main
linnamuuseum	doc_399014257234_item	3514642	et	3	main
lugejat	doc_399014257234_item	3514652	et	4	main
sada	doc_399014257234_item	3514654	et	4	main
aastat	doc_399014257234_item	3514655	et	3	main
tagasi	doc_399014257234_item	3514656	et	3	main
helsingi	doc_399014257234_item	3514657	et	4	main
elanike	doc_399014257234_item	3514658	et	3	main
arv	doc_399014257234_item	3514659	et	3	main
läks	doc_399014257234_item	3514660	et	3	main
ja	doc_399014257234_item	3514676	et	3	main
helsingi	doc_399014257233_item	3514117	et	4	main
linnamuuseum	doc_399014257233_item	3514118	et	3	main
on	doc_399014257233_item	3514119	et	4	main
ainult	doc_399014257233_item	3514126	et	4	main
alanco	doc_399014257233_item	3514132	et	4	main
ja	doc_399014257233_item	3514133	et	3	main
milles	doc_399014257233_item	3514139	et	3	main
umbes	doc_399014257233_item	3514141	et	4	main
branderi	doc_399014257233_item	3514143	et	4	main
parimatest	doc_399014257233_item	3514144	et	4	main
ajaloo	doc_399014257233_item	3514150	et	4	main
ei	doc_399014257233_item	3514156	et	4	main
signe	doc_399014257233_item	3514160	et	4	main
piltid	doc_399014257233_item	3514162	et	4	main
täiesti	doc_399014257233_item	3514171	et	3	main
oma	doc_399014257233_item	3514172	et	4	main
pildiraamatu	doc_399014257233_item	3514173	et	4	main
muinsuskaitsenõukogu	doc_399014257233_item	3514174	et	4	main
liikmed	doc_399014257233_item	3514175	et	3	main
olid	doc_399014257233_item	3514176	et	4	main
omal	doc_399014257233_item	3514177	et	3	main
ajal	doc_399014257233_item	3514178	et	4	main
kõige	doc_399014257233_item	3514179	et	4	main
parimaid	doc_399014257233_item	3514180	et	4	main
linnapilti	doc_399014257233_item	3514181	et	4	main
ja	doc_399014257233_item	3514182	et	3	main
kultuuriajaloo	doc_399014257233_item	3514183	et	4	main
asjatundjaid	doc_399014257233_item	3514184	et	3	main
sh	doc_399014257233_item	3514185	et	4	main
arhitekt	doc_399014257233_item	3514186	et	3	main
professor	doc_399014257233_item	3514187	et	3	main
gustaf	doc_399014257233_item	3514188	et	4	main
nyström	doc_399014257233_item	3514189	et	4	main
kes	doc_399014257233_item	3514190	et	4	main
juhtis	doc_399014257233_item	3514191	et	3	main
helsingi	doc_399014257233_item	3514192	et	4	main
üldplaani	doc_399014257233_item	3514193	et	4	main
koostamist	doc_399014257233_item	3514194	et	4	main
jaoks	doc_399014257233_item	3514198	et	4	main
pidi	doc_399014257233_item	3514204	et	4	main
pildistama	doc_399014257233_item	3514205	et	3	main
ja	doc_399014257233_item	3514206	et	3	main
millistesse	doc_399014257233_item	3514207	et	3	main
kiiresti	doc_399014257233_item	3514219	et	3	main
alguses	doc_399014257233_item	3514222	et	4	main
töölö	doc_399014257233_item	3514224	et	4	main
ja	doc_399014257233_item	3514225	et	3	main
eira	doc_399014257233_item	3514226	et	4	main
hakati	doc_399014257233_item	3514227	et	3	main
tasapisi	doc_399014257233_item	3514239	et	3	main
kõrgete	doc_399014257233_item	3514241	et	4	main
kivimajade	doc_399014257233_item	3514242	et	3	main
eest	doc_399014257233_item	3514243	et	4	main
branderi	doc_399014257233_item	3514249	et	4	main
fotografina	doc_399014257233_item	3514261	et	4	main
ja	doc_399014257233_item	3514262	et	3	main
eriti	doc_399014257233_item	3514263	et	3	main
pildistajana	doc_399014257233_item	3514265	et	4	main
brander	doc_399014257233_item	3514266	et	4	main
joonistamiseöpetajaks	doc_399014257233_item	3514274	et	4	main
ei	doc_399014257233_item	3514277	et	4	main
meeldinud	doc_399014257233_item	3514290	et	4	main
eriti	doc_399014257233_item	3514291	et	3	main
portreede	doc_399014257233_item	3514292	et	4	main
pildistamine	doc_399014257233_item	3514293	et	4	main
ega	doc_399014257233_item	3514294	et	3	main
ateljeetöö	doc_399014257233_item	3514295	et	4	main
niisama	doc_399014257233_item	3514296	et	3	main
tõepoolest	doc_399014257233_item	3514297	et	3	main
ka	doc_399014257233_item	3514298	et	3	main
sellest	doc_399014257233_item	3514299	et	4	main
oli	doc_399014257233_item	3514300	et	3	main
tal	doc_399014257233_item	3514301	et	3	main
kogemust	doc_399014257233_item	3514302	et	3	main
sest	doc_399014257233_item	3514303	et	4	main
ta	doc_399014257233_item	3514304	et	4	main
töötas	doc_399014257233_item	3514305	et	3	main
mõnes	doc_399014257233_item	3514306	et	3	main
fotoäris	doc_399014257233_item	3514307	et	3	main
helsingis	doc_399014257233_item	3514308	et	4	main
siiski	doc_399014257233_item	3514309	et	4	main
tahtis	doc_399014257233_item	3514310	et	3	main
ta	doc_399014257233_item	3514311	et	4	main
teha	doc_399014257233_item	3514312	et	3	main
praktilist	doc_399014257233_item	3514313	et	3	main
väljas	doc_399014257233_item	3514315	et	4	main
branderil	doc_399014257233_item	3514316	et	4	main
maastiku	doc_399014257233_item	3514323	et	4	main
kuigi	doc_399014257233_item	3514324	et	3	main
ei	doc_399014257233_item	3514332	et	4	main
ainult	doc_399014257233_item	3514334	et	4	main
inimesed	doc_399014257233_item	3514336	et	3	main
peaaegu	doc_399014257233_item	3514345	et	3	main
on	doc_399014257233_item	3514348	et	4	main
lapsi	doc_399014257233_item	3514351	et	4	main
kohale	doc_399014257233_item	3514372	et	4	main
brander	doc_399014257233_item	3514373	et	4	main
palus	doc_399014257233_item	3514374	et	4	main
nägude	doc_399014257233_item	3514383	et	3	main
võib	doc_399014257233_item	3514385	et	3	main
väga	doc_399014257233_item	3514329	et	3	main
tema	doc_399014257233_item	3514341	et	4	main
või	doc_399014257233_item	3514354	et	4	main
köögivilja	doc_399014257233_item	3514365	et	4	main
piltide	doc_399014257233_item	3514366	et	3	main
korraks	doc_399014257233_item	3514376	et	4	main
peatuda	doc_399014257233_item	3514377	et	3	main
et	doc_399014257233_item	3514378	et	3	main
oskus	doc_399014257233_item	3514390	et	3	main
kui	doc_399014257233_item	3514404	et	3	main
maastikufotograaf	doc_399014257233_item	3514405	et	4	main
isegi	doc_399014257233_item	3514406	et	4	main
haruldane	doc_399014257233_item	3514407	et	3	main
mönikord	doc_399014257233_item	3514408	et	4	main
on	doc_399014257233_item	3514409	et	4	main
pikantne	doc_399014257233_item	3514410	et	3	main
detail	doc_399014257233_item	3514411	et	3	main
trammirööbastel	doc_399014257233_item	3514412	et	3	main
jooksev	doc_399014257233_item	3514413	et	4	main
koer	doc_399014257233_item	3514414	et	3	main
rakendeta	doc_399014257233_item	3514421	et	4	main
keset	doc_399014257233_item	3514422	et	4	main
hoovi	doc_399014257233_item	3514423	et	4	main
pildid	doc_399014257233_item	3514424	et	3	main
osa	doc_399014257233_item	3514437	et	4	main
ringkäigust	doc_399014257233_item	3514438	et	3	main
lõunapoolsete	doc_399014257233_item	3514455	et	4	main
linnaosadeni	doc_399014257233_item	3514456	et	3	main
ning	doc_399014257233_item	3514457	et	3	main
siis	doc_399014257233_item	3514458	et	3	main
iga	doc_399014257233_item	3514464	et	4	main
kohas	doc_399014257233_item	3514475	et	4	main
tehtud	doc_399014257233_item	3514478	et	4	main
asi	doc_399014257233_item	3514487	et	4	main
põhjust	doc_399014257233_item	3514517	et	4	main
et	doc_399014257233_item	3514522	et	3	main
lihtsalt	doc_399014257233_item	3514525	et	4	main
rahast	doc_399014257233_item	3514526	et	4	main
fotograafi	doc_399014257233_item	3514532	et	4	main
maailmasõja	doc_399014257233_item	3514535	et	3	main
lõppes	doc_399014257233_item	3514539	et	4	main
linnaümbruskonna	doc_399014257233_item	3514543	et	4	main
salvestamine	doc_399014257233_item	3514544	et	4	main
sai	doc_399014257233_item	3514552	et	4	main
aga	doc_399014257233_item	3514553	et	3	main
oma	doc_399014257233_item	3514554	et	4	main
1981	doc_399014257233_item	3514559	et	2	main
brander	doc_399014257233_item	3514586	et	4	main
kivelä	doc_399014257233_item	3514590	et	4	main
viidi	doc_399014257233_item	3514596	et	4	main
sellele	doc_399014257233_item	3514600	et	4	main
ei	doc_399014257233_item	3514601	et	4	main
kui	doc_399014257233_item	3514618	et	3	main
1942	doc_399014257233_item	3514622	et	2	main
hulgas	doc_399014257233_item	3514624	et	4	main
oli	doc_399014257233_item	3514625	et	3	main
ka	doc_399014257233_item	3514626	et	3	main
helsingi	doc_399014257233_item	3514627	et	4	main
legendaarne	doc_399014257233_item	3514628	et	3	main
branderi	doc_399014257234_item	3514640	et	4	main
legendaarsest	doc_399014257234_item	3514645	et	3	main
ringkäigule	doc_399014257234_item	3514650	et	3	main
000	doc_399014257234_item	3514662	et	2	main
1902	doc_399014257234_item	3514665	et	2	main
puust	doc_399014257234_item	3514687	et	4	main
majade	doc_399014257234_item	3514688	et	3	main
linn	doc_399014257234_item	3514689	et	3	main
jäädvustama	doc_399014257234_item	3514690	et	3	main
nagu	doc_399014257234_item	3514691	et	3	main
see	doc_399014257234_item	3514692	et	3	main
oli	doc_399014257234_item	3514693	et	3	main
enemik	doc_399014257233_item	3514369	et	4	main
lihtsalt	doc_399014257233_item	3514370	et	4	main
sattunud	doc_399014257233_item	3514371	et	4	main
pilti	doc_399014257233_item	3514379	et	4	main
teha	doc_399014257233_item	3514380	et	3	main
inimeste	doc_399014257233_item	3514381	et	3	main
rõõmsate	doc_399014257233_item	3514382	et	3	main
ennast	doc_399014257233_item	3514391	et	4	main
tekitada	doc_399014257233_item	3514394	et	3	main
kas	doc_399014257233_item	3514415	et	3	main
hobune	doc_399014257233_item	3514417	et	4	main
on	doc_399014257233_item	3514425	et	4	main
et	doc_399014257233_item	3514430	et	3	main
mulje	doc_399014257233_item	3514433	et	4	main
ta	doc_399014257233_item	3514435	et	4	main
võttaks	doc_399014257233_item	3514436	et	4	main
läheb	doc_399014257233_item	3514448	et	3	main
kaart	doc_399014257233_item	3514482	et	4	main
lugejale	doc_399014257233_item	3514485	et	4	main
on	doc_399014257233_item	3514490	et	4	main
aga	doc_399014257233_item	3514518	et	3	main
pakarinen	doc_399014257233_item	3514520	et	4	main
küsimus	doc_399014257233_item	3514523	et	4	main
oli	doc_399014257233_item	3514524	et	3	main
uue	doc_399014257233_item	3514531	et	3	main
esimese	doc_399014257233_item	3514534	et	3	main
sai	doc_399014257233_item	3514545	et	4	main
uue	doc_399014257233_item	3514546	et	3	main
hoo	doc_399014257233_item	3514547	et	4	main
alles	doc_399014257233_item	3514548	et	3	main
fotograafi	doc_399014257233_item	3514556	et	4	main
aastal	doc_399014257233_item	3514558	et	3	main
tööd	doc_399014257233_item	3514563	et	4	main
silmasisese	doc_399014257233_item	3514581	et	3	main
rõhku	doc_399014257233_item	3514582	et	4	main
aastal	doc_399014257233_item	3514588	et	3	main
haiglasse	doc_399014257233_item	3514591	et	4	main
pärast	doc_399014257233_item	3514595	et	4	main
vaimuhaiglasse	doc_399014257233_item	3514598	et	4	main
haiglas	doc_399014257233_item	3514615	et	3	main
sada	doc_399014257233_item	3514619	et	4	main
aastal	doc_399014257233_item	3514621	et	3	main
tõlge	doc_399014257234_item	3514638	et	3	main
oli	doc_399014257233_item	3514389	et	3	main
fotografeerime	doc_399014257233_item	3514397	et	3	main
suhteliselt	doc_399014257233_item	3514399	et	4	main
ja	doc_399014257233_item	3514393	et	3	main
uudishimu	doc_399014257233_item	3514396	et	4	main
oli	doc_399014257233_item	3514398	et	3	main
uus	doc_399014257233_item	3514400	et	3	main
või	doc_399014257233_item	3514416	et	4	main
mis	doc_399014257233_item	3514418	et	4	main
seisab	doc_399014257233_item	3514419	et	3	main
ilma	doc_399014257233_item	3514420	et	4	main
paigutatud	doc_399014257233_item	3514426	et	4	main
lugejal	doc_399014257233_item	3514431	et	4	main
saja	doc_399014257233_item	3514439	et	4	main
helsingis	doc_399014257233_item	3514442	et	4	main
ringkäik	doc_399014257233_item	3514443	et	3	main
saab	doc_399014257233_item	3514444	et	3	main
alguse	doc_399014257233_item	3514445	et	3	main
hermanni	doc_399014257233_item	3514446	et	4	main
läbi	doc_399014257233_item	3514459	et	4	main
pildi	doc_399014257233_item	3514465	et	4	main
on	doc_399014257233_item	3514467	et	4	main
originaalne	doc_399014257233_item	3514468	et	3	main
täpne	doc_399014257233_item	3514469	et	3	main
kaart	doc_399014257233_item	3514470	et	4	main
milles	doc_399014257233_item	3514471	et	3	main
on	doc_399014257233_item	3514472	et	4	main
on	doc_399014257233_item	3514477	et	4	main
millisesse	doc_399014257233_item	3514480	et	4	main
suunda	doc_399014257233_item	3514481	et	4	main
tingimatu	doc_399014257233_item	3514486	et	4	main
linn	doc_399014257233_item	3514489	et	3	main
paljudes	doc_399014257233_item	3514491	et	3	main
kohtades	doc_399014257233_item	3514492	et	3	main
1913	doc_399014257233_item	3514514	et	2	main
raamatu	doc_399014257233_item	3514427	et	4	main
nii	doc_399014257233_item	3514429	et	3	main
linnaosast	doc_399014257233_item	3514447	et	4	main
hakaniemi	doc_399014257233_item	3514450	et	4	main
kruununhaka	doc_399014257233_item	3514452	et	4	main
läbi	doc_399014257233_item	3514453	et	4	main
kuni	doc_399014257233_item	3514454	et	3	main
välja	doc_399014257233_item	3514463	et	4	main
kõrval	doc_399014257233_item	3514466	et	4	main
pilt	doc_399014257233_item	3514476	et	3	main
ja	doc_399014257233_item	3514479	et	3	main
tänapäeva	doc_399014257233_item	3514484	et	4	main
sest	doc_399014257233_item	3514488	et	4	main
muutunud	doc_399014257233_item	3514493	et	4	main
täiesti	doc_399014257233_item	3514494	et	3	main
tundmatuks	doc_399014257233_item	3514495	et	4	main
näiteks	doc_399014257233_item	3514496	et	4	main
töölö	doc_399014257233_item	3514497	et	4	main
oli	doc_399014257233_item	3514498	et	3	main
tol	doc_399014257233_item	3514499	et	3	main
ajal	doc_399014257233_item	3514500	et	4	main
maa	doc_399014257233_item	3514501	et	4	main
kus	doc_399014257233_item	3514502	et	3	main
venelased	doc_399014257233_item	3514503	et	3	main
kasvatasid	doc_399014257233_item	3514504	et	4	main
linnakodanikele	doc_399014257233_item	3514505	et	3	main
köögivilja	doc_399014257233_item	3514506	et	4	main
branderi	doc_399014257233_item	3514507	et	4	main
ja	doc_399014257233_item	3514508	et	3	main
nõukogu	doc_399014257233_item	3514509	et	4	main
suhted	doc_399014257233_item	3514510	et	3	main
läksid	doc_399014257233_item	3514511	et	4	main
tülli	doc_399014257233_item	3514512	et	4	main
aastla	doc_399014257233_item	3514513	et	4	main
dokumentidest	doc_399014257233_item	3514515	et	3	main
leida	doc_399014257233_item	3514519	et	3	main
arvab	doc_399014257233_item	3514521	et	3	main
asemele	doc_399014257233_item	3514528	et	4	main
aga	doc_399014257233_item	3514533	et	3	main
tõttu	doc_399014257233_item	3514536	et	4	main
aastakümneteks	doc_399014257233_item	3514541	et	4	main
1950	doc_399014257233_item	3514549	et	2	main
aastatel	doc_399014257233_item	3514550	et	4	main
alles	doc_399014257233_item	3514557	et	3	main
tasapisi	doc_399014257233_item	3514579	et	3	main
kehvemaks	doc_399014257233_item	3514580	et	4	main
pandi	doc_399014257233_item	3514587	et	4	main
nikkilä	doc_399014257233_item	3514614	et	4	main
tegi	doc_399014257234_item	3514643	et	4	main
üle100	doc_399014257234_item	3514661	et	3	main
a	doc_399014257234_item	3514664	et	4	main
kolme	doc_399014257234_item	3514666	et	4	main
tohutu	doc_399014257234_item	3514674	et	4	main
kasv	doc_399014257234_item	3514675	et	3	main
helsingi	doc_399014257234_item	3514699	et	4	main
fotograaf	doc_399014257234_item	3514708	et	4	main
1942	doc_399014257234_item	3514712	et	2	main
pildistas	doc_399014257234_item	3514723	et	3	main
umbes	doc_399014257234_item	3514725	et	4	main
seitse	doc_399014257234_item	3514726	et	3	main
pole	doc_399014257233_item	3514516	et	3	main
branderi	doc_399014257233_item	3514527	et	4	main
võttis	doc_399014257233_item	3514529	et	3	main
linnamuuseum	doc_399014257233_item	3514530	et	3	main
1914	doc_399014257233_item	3514538	et	2	main
pildistamine	doc_399014257233_item	3514540	et	4	main
regulaarne	doc_399014257233_item	3514542	et	3	main
linnamuuseum	doc_399014257233_item	3514551	et	3	main
jätkas	doc_399014257233_item	3514561	et	3	main
oma	doc_399014257233_item	3514562	et	4	main
fotograafina	doc_399014257233_item	3514564	et	4	main
erinevates	doc_399014257233_item	3514565	et	4	main
kohtades	doc_399014257233_item	3514566	et	3	main
üle	doc_399014257233_item	3514567	et	3	main
soome	doc_399014257233_item	3514568	et	3	main
ta	doc_399014257233_item	3514569	et	4	main
mh	doc_399014257233_item	3514571	et	3	main
pildistas	doc_399014257233_item	3514570	et	3	main
mõisaid	doc_399014257233_item	3514572	et	3	main
tema	doc_399014257233_item	3514573	et	4	main
tervis	doc_399014257233_item	3514574	et	3	main
ja	doc_399014257233_item	3514575	et	3	main
nägemine	doc_399014257233_item	3514576	et	4	main
läksid	doc_399014257233_item	3514577	et	4	main
aga	doc_399014257233_item	3514578	et	3	main
aastatel	doc_399014257233_item	3514585	et	4	main
sõja	doc_399014257233_item	3514594	et	3	main
olnud	doc_399014257233_item	3514602	et	4	main
branderi	doc_399014257233_item	3514603	et	4	main
vaimulik	doc_399014257233_item	3514604	et	3	main
olukord	doc_399014257233_item	3514605	et	3	main
kuigi	doc_399014257233_item	3514606	et	3	main
niimoodi	doc_399014257233_item	3514607	et	3	main
mõnikord	doc_399014257233_item	3514608	et	3	main
väidetakse	doc_399014257233_item	3514609	et	3	main
sõja	doc_399014257233_item	3514610	et	3	main
ebaselgetes	doc_399014257233_item	3514611	et	4	main
oludes	doc_399014257233_item	3514612	et	3	main
suri	doc_399014257233_item	3514613	et	3	main
rohkem	doc_399014257233_item	3514617	et	4	main
inimest	doc_399014257233_item	3514620	et	3	main
fotograaf	doc_399014257233_item	3514629	et	4	main
signe	doc_399014257233_item	3514630	et	4	main
brander	doc_399014257233_item	3514631	et	4	main
kes	doc_399014257233_item	3514632	et	4	main
teiste	doc_399014257233_item	3514633	et	4	main
patsientidega	doc_399014257233_item	3514634	et	3	main
maeti	doc_399014257233_item	3514635	et	3	main
ühishauda	doc_399014257233_item	3514636	et	4	main
raamatu	doc_399014257234_item	3514644	et	4	main
raamat	doc_399014257234_item	3514648	et	3	main
helsingiga	doc_399014257234_item	3514653	et	4	main
inimese	doc_399014257234_item	3514663	et	4	main
kolmekordseks	doc_399014257234_item	3514671	et	4	main
tagasi	doc_399014257234_item	3514696	et	3	main
muinsuskaitsekomisjoni	doc_399014257234_item	3514702	et	4	main
aastal	doc_399014257234_item	3514706	et	3	main
1869	doc_399014257234_item	3514711	et	2	main
otsus	doc_399014257234_item	3514713	et	3	main
hiljem	doc_399014257234_item	3514715	et	3	main
mitu	doc_399014257234_item	3514716	et	4	main
korda	doc_399014257234_item	3514717	et	4	main
targaks	doc_399014257234_item	3514718	et	3	main
ja	doc_399014257234_item	3514719	et	3	main
ettenägelikuks	doc_399014257234_item	3514720	et	3	main
on	doc_399014257234_item	3514736	et	4	main
helsingi	doc_399014257234_item	3514742	et	4	main
on	doc_399014257234_item	3514744	et	4	main
põhineb	doc_399014257234_item	3514754	et	3	main
raamatu	doc_399014257234_item	3514767	et	4	main
kus	doc_399014257234_item	3514768	et	3	main
ligi	doc_399014257234_item	3514770	et	3	main
ajaloost	doc_399014257234_item	3514778	et	4	main
on	doc_399014257234_item	3514779	et	4	main
palju	doc_399014257234_item	3514784	et	4	main
milles	doc_399014257234_item	3514786	et	3	main
oleks	doc_399014257234_item	3514788	et	3	main
nüüd	doc_399014257234_item	3514798	et	4	main
sai	doc_399014257234_item	3514800	et	4	main
20	doc_399014257234_item	3514838	et	2	main
alguses	doc_399014257234_item	3514840	et	4	main
ja	doc_399014257234_item	3514842	et	3	main
eirat	doc_399014257234_item	3514843	et	4	main
hakati	doc_399014257234_item	3514844	et	3	main
ehitama	doc_399014257234_item	3514845	et	4	main
ja	doc_399014257234_item	3514846	et	3	main
linnas	doc_399014257234_item	3514849	et	4	main
pakarinen	doc_399014257234_item	3514863	et	4	main
arvestas	doc_399014257234_item	3514864	et	3	main
et	doc_399014257234_item	3514865	et	3	main
fotograafina	doc_399014257234_item	3514878	et	4	main
töötada	doc_399014257234_item	3514879	et	3	main
näidanud	doc_399014257234_item	3514880	et	4	main
aga	doc_399014257234_item	3514888	et	3	main
õpetajana	doc_399014257234_item	3514891	et	4	main
töötanud	doc_399014257234_item	3514893	et	4	main
ja	doc_399014257234_item	3514938	et	3	main
ja	doc_399014257234_item	3514954	et	3	main
tavaliselt	doc_399014257234_item	3514959	et	4	main
olnud	doc_399014257234_item	3514962	et	4	main
pildistamiseks	doc_399014257234_item	3514969	et	4	main
näost	doc_399014257234_item	3514970	et	4	main
oskas	doc_399014257234_item	3514978	et	3	main
asjad	doc_399014257234_item	3514980	et	3	main
ja	doc_399014257234_item	3514983	et	3	main
naine	doc_399014257234_item	3514993	et	3	main
nähtus	doc_399014257234_item	3514996	et	4	main
seatud	doc_399014257234_item	3515014	et	4	main
kes	doc_399014257234_item	3515204	et	4	main
maeti	doc_399014257234_item	3515205	et	3	main
muude	doc_399014257234_item	3515206	et	4	main
patsientidega	doc_399014257234_item	3515207	et	3	main
ühishauda	doc_399014257234_item	3515208	et	4	main
fotograafist	doc_399014257234_item	3514646	et	4	main
see	doc_399014257234_item	3514647	et	3	main
juhatab	doc_399014257234_item	3514649	et	3	main
tutvustamaks	doc_399014257234_item	3514651	et	3	main
aastakümne	doc_399014257234_item	3514667	et	4	main
jooksul	doc_399014257234_item	3514668	et	4	main
oli	doc_399014257234_item	3514669	et	3	main
see	doc_399014257234_item	3514670	et	3	main
saanud	doc_399014257234_item	3514672	et	4	main
linna	doc_399014257234_item	3514673	et	4	main
muutumine	doc_399014257234_item	3514677	et	4	main
äratasid	doc_399014257234_item	3514678	et	4	main
arhitektid	doc_399014257234_item	3514679	et	3	main
ja	doc_399014257234_item	3514680	et	3	main
helsingi	doc_399014257234_item	3514681	et	4	main
võimud	doc_399014257234_item	3514682	et	3	main
et	doc_399014257234_item	3514683	et	3	main
peaks	doc_399014257234_item	3514684	et	4	main
kaduma	doc_399014257234_item	3514685	et	4	main
läinud	doc_399014257234_item	3514686	et	4	main
sada	doc_399014257234_item	3514694	et	4	main
aastat	doc_399014257234_item	3514695	et	3	main
selleks	doc_399014257234_item	3514697	et	4	main
otsustas	doc_399014257234_item	3514698	et	3	main
signe	doc_399014257234_item	3514709	et	4	main
on	doc_399014257234_item	3514714	et	4	main
brander	doc_399014257234_item	3514722	et	4	main
veelgi	doc_399014257234_item	3514737	et	4	main
volikogu	doc_399014257234_item	3514700	et	4	main
võttis	doc_399014257234_item	3514704	et	3	main
tööle	doc_399014257234_item	3514707	et	3	main
branderi	doc_399014257234_item	3514710	et	4	main
1907	doc_399014257234_item	3514728	et	2	main
töö	doc_399014257234_item	3514730	et	4	main
tulemuseks	doc_399014257234_item	3514731	et	3	main
oli	doc_399014257234_item	3514732	et	3	main
helsingi	doc_399014257234_item	3514738	et	4	main
fotoarhiivi	doc_399014257234_item	3514740	et	4	main
tema	doc_399014257234_item	3514756	et	4	main
riitta	doc_399014257234_item	3514763	et	4	main
pakarinen	doc_399014257234_item	3514764	et	4	main
on	doc_399014257234_item	3514765	et	4	main
on	doc_399014257234_item	3514769	et	4	main
helsingist	doc_399014257234_item	3514775	et	4	main
fotot	doc_399014257234_item	3514776	et	3	main
helsingi	doc_399014257234_item	3514777	et	4	main
branderi	doc_399014257234_item	3514792	et	4	main
alles	doc_399014257234_item	3514797	et	3	main
aga	doc_399014257234_item	3514799	et	3	main
ta	doc_399014257234_item	3514801	et	4	main
oma	doc_399014257234_item	3514802	et	4	main
aja	doc_399014257234_item	3514807	et	4	main
parimaid	doc_399014257234_item	3514808	et	4	main
sajandi	doc_399014257234_item	3514839	et	3	main
puust	doc_399014257234_item	3514854	et	4	main
majad	doc_399014257234_item	3514855	et	3	main
kivist	doc_399014257234_item	3514858	et	4	main
signe	doc_399014257234_item	3514866	et	4	main
branderi	doc_399014257234_item	3514867	et	4	main
oli	doc_399014257234_item	3514871	et	3	main
oli	doc_399014257234_item	3514874	et	3	main
juba	doc_399014257234_item	3514875	et	3	main
brander	doc_399014257234_item	3514884	et	4	main
ta	doc_399014257234_item	3514890	et	4	main
fotograaf	doc_399014257234_item	3514897	et	4	main
kes	doc_399014257234_item	3514898	et	4	main
tema	doc_399014257234_item	3514941	et	4	main
aina	doc_399014257234_item	3514949	et	4	main
möödujaid	doc_399014257234_item	3514950	et	4	main
koduloomi	doc_399014257234_item	3514955	et	4	main
palunud	doc_399014257234_item	3514965	et	4	main
heatujuliste	doc_399014257234_item	3514971	et	4	main
inimeste	doc_399014257234_item	3514972	et	3	main
fotografeerimine	doc_399014257234_item	3514988	et	4	main
oli	doc_399014257234_item	3514989	et	3	main
õue	doc_399014257234_item	3515007	et	4	main
seisab	doc_399014257234_item	3515008	et	3	main
rakmeteta	doc_399014257234_item	3515009	et	3	main
hobune	doc_399014257234_item	3515010	et	4	main
pildid	doc_399014257234_item	3515011	et	3	main
on	doc_399014257234_item	3515012	et	4	main
uurimisretkesse	doc_399014257234_item	3515015	et	4	main
nagu	doc_399014257234_item	3515019	et	3	main
kampi	doc_399014257234_item	3515038	et	4	main
kõrval	doc_399014257234_item	3515043	et	4	main
algupärane	doc_399014257234_item	3515045	et	4	main
suunas	doc_399014257234_item	3515056	et	4	main
kaart	doc_399014257234_item	3515060	et	4	main
vältimatu	doc_399014257234_item	3515062	et	4	main
tänäpäeva	doc_399014257234_item	3515063	et	4	main
linn	doc_399014257234_item	3515067	et	3	main
töölö	doc_399014257234_item	3515075	et	4	main
branderi	doc_399014257234_item	3515077	et	4	main
jaoks	doc_399014257234_item	3515086	et	4	main
1913	doc_399014257234_item	3515094	et	2	main
põhjuse	doc_399014257234_item	3515096	et	3	main
võis	doc_399014257234_item	3515106	et	4	main
lihtsalt	doc_399014257234_item	3515107	et	4	main
rahast	doc_399014257234_item	3515108	et	4	main
sõltuda	doc_399014257234_item	3515109	et	3	main
branderi	doc_399014257234_item	3515112	et	4	main
asemele	doc_399014257234_item	3515113	et	4	main
uue	doc_399014257234_item	3515114	et	3	main
ta	doc_399014257234_item	3515143	et	4	main
asutada	doc_399014257234_item	3514701	et	3	main
mis	doc_399014257234_item	3514703	et	4	main
järgmisel	doc_399014257234_item	3514705	et	3	main
kiidetud	doc_399014257234_item	3514721	et	4	main
helsingit	doc_399014257234_item	3514724	et	4	main
1913	doc_399014257234_item	3514729	et	2	main
907	doc_399014257234_item	3514733	et	2	main
fotot	doc_399014257234_item	3514734	et	3	main
mis	doc_399014257234_item	3514735	et	4	main
branderi	doc_399014257234_item	3514749	et	4	main
fotodest	doc_399014257234_item	3514750	et	3	main
fotograaf	doc_399014257234_item	3514758	et	4	main
ja	doc_399014257234_item	3514761	et	3	main
sada	doc_399014257234_item	3514771	et	4	main
välja	doc_399014257234_item	3514781	et	4	main
pildistatud	doc_399014257234_item	3514793	et	4	main
fotoraamatu	doc_399014257234_item	3514803	et	4	main
muinsuskaitsekomisjonis	doc_399014257234_item	3514804	et	3	main
asjatundjaid	doc_399014257234_item	3514809	et	3	main
linnavaate	doc_399014257234_item	3514810	et	4	main
töölöt	doc_399014257234_item	3514841	et	4	main
alguses	doc_399014257234_item	3514848	et	4	main
ehitatud	doc_399014257234_item	3514850	et	4	main
ühe-	doc_399014257234_item	3514851	et	4	main
ja	doc_399014257234_item	3514852	et	3	main
kahekorrulised	doc_399014257234_item	3514853	et	4	main
kõrgete	doc_399014257234_item	3514857	et	4	main
müüride	doc_399014257234_item	3514859	et	3	main
pildistajaks	doc_399014257234_item	3514870	et	4	main
tema	doc_399014257234_item	3514873	et	4	main
endal	doc_399014257234_item	3514876	et	4	main
võimet	doc_399014257234_item	3514877	et	3	main
õppis	doc_399014257234_item	3514885	et	3	main
helsingis	doc_399014257234_item	3514886	et	4	main
joonistusõpetajaks	doc_399014257234_item	3514887	et	3	main
seevastu	doc_399014257234_item	3514894	et	3	main
üksikasjad	doc_399014257234_item	3514939	et	3	main
olid	doc_399014257234_item	3514940	et	4	main
fotode	doc_399014257234_item	3514942	et	3	main
erkuse	doc_399014257234_item	3514943	et	4	main
saladus	doc_399014257234_item	3514944	et	3	main
lapsi	doc_399014257234_item	3514951	et	4	main
kaupmehi	doc_399014257234_item	3514952	et	3	main
pildile	doc_399014257234_item	3514956	et	3	main
kohal	doc_399014257234_item	3514961	et	4	main
hetkeks	doc_399014257234_item	3514967	et	4	main
peatuda	doc_399014257234_item	3514968	et	3	main
brander	doc_399014257234_item	3514977	et	4	main
esile	doc_399014257234_item	3514981	et	3	main
äratas	doc_399014257234_item	3514984	et	3	main
veel	doc_399014257234_item	3514990	et	4	main
uus	doc_399014257234_item	3514991	et	3	main
ja	doc_399014257234_item	3514992	et	3	main
keset	doc_399014257234_item	3515006	et	4	main
lugeja	doc_399014257234_item	3515017	et	4	main
ringkäigul	doc_399014257234_item	3515020	et	3	main
töölö	doc_399014257234_item	3515040	et	4	main
kaart	doc_399014257234_item	3515047	et	4	main
mis	doc_399014257234_item	3515048	et	4	main
näitab	doc_399014257234_item	3515049	et	3	main
kus	doc_399014257234_item	3515050	et	3	main
on	doc_399014257234_item	3515058	et	4	main
sest	doc_399014257234_item	3515066	et	4	main
täiesti	doc_399014257234_item	3515071	et	3	main
tundmatuks	doc_399014257234_item	3515072	et	4	main
muutunud	doc_399014257234_item	3515073	et	4	main
venelaste	doc_399014257234_item	3515085	et	4	main
tekkisid	doc_399014257234_item	3515091	et	4	main
erimeelsused	doc_399014257234_item	3515095	et	4	main
fotograafi	doc_399014257234_item	3515115	et	4	main
jätkas	doc_399014257234_item	3515138	et	3	main
soomes	doc_399014257234_item	3515142	et	4	main
sõltunud	doc_399014257234_item	3515175	et	4	main
pärast	doc_399014257234_item	3515185	et	4	main
oludes	doc_399014257234_item	3515187	et	3	main
patsiendi	doc_399014257234_item	3515194	et	3	main
legendaarne	doc_399014257234_item	3515200	et	3	main
fotograaf	doc_399014257234_item	3515201	et	4	main
vaatavad	doc_399014257238_item	3515213	et	4	main
linnale	doc_399014257238_item	3515221	et	4	main
linna	doc_399014257238_item	3515230	et	4	main
aastat	doc_399014257234_item	3514727	et	3	main
linnamuuseumi	doc_399014257234_item	3514739	et	4	main
tuumik	doc_399014257234_item	3514741	et	3	main
välja	doc_399014257234_item	3514751	et	4	main
andnud	doc_399014257234_item	3514752	et	4	main
raamat	doc_399014257234_item	3514753	et	3	main
fotodel	doc_399014257234_item	3514757	et	3	main
blanco	doc_399014257234_item	3514760	et	4	main
uurija	doc_399014257234_item	3514762	et	4	main
koostanud	doc_399014257234_item	3514766	et	4	main
pildistatud	doc_399014257234_item	3514774	et	4	main
vaevalt	doc_399014257234_item	3514780	et	4	main
päris	doc_399014257234_item	3514783	et	4	main
raamatuid	doc_399014257234_item	3514785	et	3	main
ei	doc_399014257234_item	3514787	et	4	main
vähemalt	doc_399014257234_item	3514789	et	4	main
mõni	doc_399014257234_item	3514790	et	3	main
signe	doc_399014257234_item	3514791	et	4	main
algusest	doc_399014257234_item	3514796	et	4	main
istus	doc_399014257234_item	3514805	et	4	main
linnamuuseum	doc_399014257234_item	3514743	et	3	main
nüüd	doc_399014257234_item	3514745	et	4	main
esimese	doc_399014257234_item	3514746	et	3	main
teose	doc_399014257234_item	3514747	et	3	main
signe	doc_399014257234_item	3514748	et	4	main
koguni	doc_399014257234_item	3514755	et	4	main
jan	doc_399014257234_item	3514759	et	4	main
parimat	doc_399014257234_item	3514772	et	4	main
branderi	doc_399014257234_item	3514773	et	4	main
antud	doc_399014257234_item	3514782	et	4	main
foto	doc_399014257234_item	3514794	et	4	main
20sajandi	doc_399014257234_item	3514795	et	3	main
oma	doc_399014257234_item	3514806	et	4	main
ja	doc_399014257234_item	3514811	et	3	main
kultuuriajaloo	doc_399014257234_item	3514812	et	4	main
alal	doc_399014257234_item	3514813	et	4	main
ms	doc_399014257234_item	3514814	et	4	main
gustaf	doc_399014257234_item	3514815	et	4	main
nyström	doc_399014257234_item	3514816	et	4	main
kes	doc_399014257234_item	3514817	et	4	main
oli	doc_399014257234_item	3514818	et	3	main
helsingi	doc_399014257234_item	3514819	et	4	main
planeerimise	doc_399014257234_item	3514820	et	4	main
juhatajana	doc_399014257234_item	3514821	et	4	main
komisjon	doc_399014257234_item	3514822	et	3	main
tegi	doc_399014257234_item	3514823	et	4	main
branderi	doc_399014257234_item	3514824	et	4	main
jaoks	doc_399014257234_item	3514825	et	4	main
fotokava	doc_399014257234_item	3514826	et	4	main
kohtadest	doc_399014257234_item	3514827	et	3	main
kus	doc_399014257234_item	3514828	et	3	main
oli	doc_399014257234_item	3514829	et	3	main
tulemas	doc_399014257234_item	3514830	et	4	main
suuri	doc_399014257234_item	3514831	et	3	main
pöördeid	doc_399014257234_item	3514832	et	3	main
helsingi	doc_399014257234_item	3514833	et	4	main
suurenes	doc_399014257234_item	3514834	et	4	main
ja	doc_399014257234_item	3514835	et	3	main
muutus	doc_399014257234_item	3514836	et	4	main
kohinal	doc_399014257234_item	3514837	et	4	main
19sajangi	doc_399014257234_item	3514847	et	3	main
hakkasid	doc_399014257234_item	3514856	et	4	main
eest	doc_399014257234_item	3514860	et	4	main
kaduma	doc_399014257234_item	3514861	et	4	main
valimine	doc_399014257234_item	3514868	et	4	main
enesestmõistetav	doc_399014257234_item	3514872	et	3	main
kunagi	doc_399014257234_item	3514889	et	3	main
ei	doc_399014257234_item	3514892	et	4	main
sai	doc_399014257234_item	3514895	et	4	main
temast	doc_399014257234_item	3514896	et	3	main
pildistamisega	doc_399014257234_item	3514936	et	4	main
inimesed	doc_399014257234_item	3514937	et	3	main
riitta	doc_399014257234_item	3514862	et	4	main
helsingi	doc_399014257234_item	3514869	et	4	main
parkano	doc_399014257234_item	3514881	et	4	main
vallas	doc_399014257234_item	3514882	et	3	main
sündinud	doc_399014257234_item	3514883	et	4	main
ei	doc_399014257234_item	3514899	et	4	main
armastanud	doc_399014257234_item	3514900	et	4	main
näopiltide	doc_399014257234_item	3514901	et	3	main
tegemist	doc_399014257234_item	3514902	et	4	main
ega	doc_399014257234_item	3514903	et	3	main
ateljeetööd	doc_399014257234_item	3514904	et	4	main
tal	doc_399014257234_item	3514905	et	3	main
oli	doc_399014257234_item	3514906	et	3	main
ometi	doc_399014257234_item	3514907	et	3	main
selles	doc_399014257234_item	3514908	et	4	main
töös	doc_399014257234_item	3514909	et	3	main
kogemust	doc_399014257234_item	3514910	et	3	main
helsingi	doc_399014257234_item	3514911	et	4	main
fotoateljeedes	doc_399014257234_item	3514912	et	3	main
ta	doc_399014257234_item	3514913	et	4	main
tahtis	doc_399014257234_item	3514914	et	3	main
lageda	doc_399014257234_item	3514915	et	4	main
taeva	doc_399014257234_item	3514916	et	3	main
all	doc_399014257234_item	3514917	et	3	main
töötada	doc_399014257234_item	3514918	et	3	main
brander	doc_399014257234_item	3514919	et	4	main
pildistas	doc_399014257234_item	3514920	et	3	main
tolleaegse	doc_399014257234_item	3514921	et	3	main
kohmaka	doc_399014257234_item	3514922	et	3	main
tehnikaga	doc_399014257234_item	3514923	et	3	main
päris	doc_399014257234_item	3514924	et	4	main
leidlikult	doc_399014257234_item	3514925	et	4	main
linna	doc_399014257234_item	3514926	et	4	main
ja	doc_399014257234_item	3514927	et	3	main
maastikuid	doc_399014257234_item	3514928	et	4	main
tema	doc_399014257234_item	3514929	et	4	main
ei	doc_399014257234_item	3514930	et	4	main
olnud	doc_399014257234_item	3514931	et	4	main
rahul	doc_399014257234_item	3514932	et	4	main
surnud	doc_399014257234_item	3514933	et	4	main
elutu	doc_399014257234_item	3514934	et	4	main
arhitektuuri	doc_399014257234_item	3514935	et	4	main
on	doc_399014257234_item	3514947	et	4	main
peaaegu	doc_399014257234_item	3514948	et	3	main
jäädvustatud	doc_399014257234_item	3514957	et	4	main
on	doc_399014257234_item	3514958	et	4	main
nendel	doc_399014257234_item	3514966	et	4	main
põhjal	doc_399014257234_item	3514973	et	4	main
võib	doc_399014257234_item	3514974	et	3	main
järeldada	doc_399014257234_item	3514975	et	3	main
maastikupildistajana	doc_399014257234_item	3514994	et	3	main
mõnikord	doc_399014257234_item	3514997	et	3	main
pikant	doc_399014257234_item	3514999	et	4	main
üksikasi	doc_399014257234_item	3515000	et	3	main
kui	doc_399014257234_item	3515001	et	3	main
koer	doc_399014257234_item	3515002	et	3	main
järgneb	doc_399014257234_item	3515003	et	3	main
raudteerööpaile	doc_399014257234_item	3515004	et	3	main
või	doc_399014257234_item	3515005	et	4	main
raamatus	doc_399014257234_item	3515013	et	4	main
millega	doc_399014257234_item	3515016	et	3	main
jalutab	doc_399014257234_item	3515018	et	3	main
saja	doc_399014257234_item	3515021	et	4	main
aasta	doc_399014257234_item	3515022	et	4	main
eest	doc_399014257234_item	3515023	et	4	main
helsingis	doc_399014257234_item	3515024	et	4	main
retk	doc_399014257234_item	3515025	et	3	main
algab	doc_399014257234_item	3515026	et	3	main
hermannist	doc_399014257234_item	3515027	et	4	main
läheb	doc_399014257234_item	3515028	et	3	main
hakanieme	doc_399014257234_item	3515029	et	4	main
ja	doc_399014257234_item	3515030	et	3	main
kruunuhaka	doc_399014257234_item	3515031	et	4	main
kaudu	doc_399014257234_item	3515032	et	3	main
lõunapoolsetele	doc_399014257234_item	3515033	et	4	main
linnaosadele	doc_399014257234_item	3515034	et	3	main
sealt	doc_399014257234_item	3515035	et	4	main
jätkub	doc_399014257234_item	3515036	et	3	main
jalutuskäik	doc_399014257234_item	3515037	et	3	main
kaudu	doc_399014257234_item	3515039	et	3	main
vaadet	doc_399014257234_item	3515057	et	3	main
on	doc_399014257234_item	3515061	et	4	main
kohas	doc_399014257234_item	3515070	et	4	main
köögivilja	doc_399014257234_item	3515084	et	4	main
vahel	doc_399014257234_item	3515090	et	4	main
a	doc_399014257234_item	3515093	et	4	main
ei	doc_399014257234_item	3515098	et	4	main
aga	doc_399014257234_item	3515116	et	3	main
esimese	doc_399014257234_item	3515117	et	3	main
maailmasõja	doc_399014257234_item	3515118	et	3	main
puhkemine	doc_399014257234_item	3515119	et	4	main
lõpetas	doc_399014257234_item	3515120	et	3	main
fotograafina	doc_399014257234_item	3515139	et	4	main
kohtadel	doc_399014257234_item	3515141	et	3	main
hingelisest	doc_399014257234_item	3515177	et	4	main
tasakaalust	doc_399014257234_item	3515178	et	3	main
suri	doc_399014257234_item	3515188	et	3	main
haiglas	doc_399014257234_item	3515190	et	3	main
a1943	doc_399014257234_item	3515191	et	4	main
üle	doc_399014257234_item	3515192	et	3	main
hulgas	doc_399014257234_item	3515197	et	4	main
helsingi	doc_399014257234_item	3515199	et	4	main
viltu	doc_399014257238_item	3515214	et	3	main
tallinna	doc_399014257238_item	3515215	et	4	main
kavandatud	doc_399014257238_item	3515217	et	4	main
hiiglaslikule	doc_399014257238_item	3515218	et	3	main
tema	doc_399014257234_item	3514945	et	4	main
piltides	doc_399014257234_item	3514946	et	3	main
politseininikke	doc_399014257234_item	3514953	et	4	main
juhuslikult	doc_399014257234_item	3514960	et	4	main
brander	doc_399014257234_item	3514963	et	4	main
on	doc_399014257234_item	3514964	et	4	main
et	doc_399014257234_item	3514976	et	3	main
oma	doc_399014257234_item	3514979	et	4	main
tuua	doc_399014257234_item	3514982	et	3	main
helsingilaste	doc_399014257234_item	3514985	et	4	main
hulgas	doc_399014257234_item	3514986	et	4	main
uudishimu	doc_399014257234_item	3514987	et	4	main
haruldane	doc_399014257234_item	3514995	et	3	main
on	doc_399014257234_item	3514998	et	4	main
pildi	doc_399014257234_item	3515042	et	4	main
foto	doc_399014257234_item	3515051	et	4	main
on	doc_399014257234_item	3515052	et	4	main
pildistatud	doc_399014257234_item	3515053	et	4	main
vaadatud	doc_399014257234_item	3515059	et	4	main
lugeja	doc_399014257234_item	3515064	et	4	main
kätte	doc_399014257234_item	3515065	et	4	main
on	doc_399014257234_item	3515068	et	4	main
mitmes	doc_399014257234_item	3515069	et	4	main
näiteks	doc_399014257234_item	3515074	et	4	main
branderi	doc_399014257234_item	3515087	et	4	main
ja	doc_399014257234_item	3515088	et	3	main
siiski	doc_399014257234_item	3515092	et	4	main
kohta	doc_399014257234_item	3515097	et	4	main
kirjutatud	doc_399014257234_item	3515101	et	4	main
linnamuuseum	doc_399014257234_item	3515110	et	3	main
erinevatel	doc_399014257234_item	3515140	et	4	main
paigutati	doc_399014257234_item	3515166	et	3	main
hiljem	doc_399014257234_item	3515167	et	3	main
sõja	doc_399014257234_item	3515168	et	3	main
tõttu	doc_399014257234_item	3515169	et	4	main
branderi	doc_399014257234_item	3515176	et	4	main
on	doc_399014257234_item	3515181	et	4	main
väidetud	doc_399014257234_item	3515183	et	4	main
saja	doc_399014257234_item	3515193	et	4	main
nende	doc_399014257234_item	3515196	et	4	main
oli	doc_399014257234_item	3515198	et	3	main
tõlge	doc_399014257238_item	3515210	et	3	main
eesti	doc_399014257238_item	3515225	et	4	main
tornmaja	doc_399014257238_item	3515235	et	4	main
kõrge	doc_399014257238_item	3515237	et	4	main
rahvaeepose	doc_399014257238_item	3515240	et	3	main
kangelase	doc_399014257238_item	3515241	et	3	main
auks	doc_399014257238_item	3515242	et	3	main
linna	doc_399014257238_item	3515243	et	4	main
poolt	doc_399014257238_item	3515244	et	4	main
ainult	doc_399014257238_item	3515252	et	4	main
on	doc_399014257238_item	3515256	et	4	main
merre	doc_399014257238_item	3515259	et	3	main
kohal	doc_399014257238_item	3515270	et	4	main
rannal	doc_399014257238_item	3515271	et	3	main
teise	doc_399014257238_item	3515275	et	4	main
monumendikompleks	doc_399014257238_item	3515280	et	4	main
vananenud	doc_399014257238_item	3515311	et	4	main
kangelane	doc_399014257238_item	3515314	et	3	main
kokku	doc_399014257238_item	3515316	et	3	main
varem	doc_399014257238_item	3515320	et	4	main
esindajad	doc_399014257238_item	3515330	et	4	main
linnapea	doc_399014257238_item	3515338	et	4	main
kes	doc_399014257238_item	3515351	et	4	main
on	doc_399014257238_item	3515352	et	4	main
isaks	doc_399014257238_item	3515358	et	3	main
on	doc_399014257238_item	3515359	et	4	main
turustama	doc_399014257238_item	3515369	et	3	main
lõpul	doc_399014257238_item	3515374	et	3	main
oli	doc_399014257238_item	3515376	et	3	main
oli	doc_399014257238_item	3515386	et	3	main
väike	doc_399014257238_item	3515388	et	4	main
merineitsi	doc_399014257238_item	3515389	et	4	main
linna	doc_399014257238_item	3515393	et	4	main
kõrgust	doc_399014257238_item	3515396	et	4	main
vaatasime	doc_399014257238_item	3515397	et	3	main
kuidas	doc_399014257238_item	3515398	et	3	main
sammas	doc_399014257238_item	3515399	et	4	main
sobib	doc_399014257238_item	3515400	et	3	main
kokku	doc_399014257238_item	3515401	et	3	main
kunstnikeliidud	doc_399014257239_item	3515447	et	3	main
igaühe	doc_399014257234_item	3515041	et	4	main
on	doc_399014257234_item	3515044	et	4	main
täpne	doc_399014257234_item	3515046	et	3	main
ja	doc_399014257234_item	3515054	et	3	main
mis	doc_399014257234_item	3515055	et	4	main
oli	doc_399014257234_item	3515076	et	3	main
piltide	doc_399014257234_item	3515078	et	3	main
ajal	doc_399014257234_item	3515079	et	4	main
provints	doc_399014257234_item	3515080	et	3	main
milles	doc_399014257234_item	3515081	et	3	main
venelased	doc_399014257234_item	3515082	et	3	main
kasvatasid	doc_399014257234_item	3515083	et	4	main
komisjoni	doc_399014257234_item	3515089	et	4	main
ole	doc_399014257234_item	3515099	et	4	main
protokolli	doc_399014257234_item	3515100	et	4	main
pakarinen	doc_399014257234_item	3515102	et	4	main
kahtleb	doc_399014257234_item	3515103	et	3	main
et	doc_399014257234_item	3515104	et	3	main
tüli	doc_399014257234_item	3515105	et	4	main
palkas	doc_399014257234_item	3515111	et	3	main
fotograafia	doc_399014257234_item	3515121	et	4	main
aastakümneteks	doc_399014257234_item	3515122	et	4	main
linnamiljööt	doc_399014257234_item	3515123	et	4	main
hakati	doc_399014257234_item	3515124	et	3	main
süstemaatiliselt	doc_399014257234_item	3515125	et	4	main
uuesti	doc_399014257234_item	3515126	et	3	main
alles	doc_399014257234_item	3515127	et	3	main
1950aastatel	doc_399014257234_item	3515128	et	4	main
jäädvustama	doc_399014257234_item	3515129	et	3	main
linnamuuseum	doc_399014257234_item	3515130	et	3	main
sai	doc_399014257234_item	3515131	et	4	main
oma	doc_399014257234_item	3515132	et	4	main
püsiva	doc_399014257234_item	3515133	et	4	main
fotograafi	doc_399014257234_item	3515134	et	4	main
alles	doc_399014257234_item	3515135	et	3	main
1981	doc_399014257234_item	3515136	et	2	main
brander	doc_399014257234_item	3515137	et	4	main
nikkilä	doc_399014257234_item	3515170	et	4	main
vaimuhaiglasse	doc_399014257234_item	3515171	et	4	main
ümber	doc_399014257234_item	3515172	et	3	main
ümberpaigutus	doc_399014257234_item	3515173	et	3	main
ei	doc_399014257234_item	3515174	et	4	main
kuigi	doc_399014257234_item	3515179	et	3	main
nälga	doc_399014257234_item	3515195	et	4	main
kunstnikkude	doc_399014257238_item	3515211	et	3	main
lahele	doc_399014257238_item	3515216	et	4	main
vaatavad	doc_399014257238_item	3515227	et	4	main
viltu	doc_399014257238_item	3515228	et	3	main
tallinna	doc_399014257238_item	3515229	et	4	main
lahele	doc_399014257238_item	3515234	et	4	main
suurune	doc_399014257238_item	3515236	et	4	main
kalevipoeg	doc_399014257238_item	3515238	et	3	main
ettepanekut	doc_399014257238_item	3515254	et	3	main
tallinnast	doc_399014257238_item	3515264	et	3	main
nõukogude	doc_399014257238_item	3515273	et	3	main
kangelaste	doc_399014257238_item	3515277	et	4	main
niisugune	doc_399014257238_item	3515310	et	3	main
tõmbasid	doc_399014257238_item	3515322	et	4	main
arhitektide	doc_399014257238_item	3515327	et	3	main
oma	doc_399014257238_item	3515329	et	4	main
ametnike	doc_399014257238_item	3515334	et	3	main
ülekaalu	doc_399014257238_item	3515335	et	4	main
jüri	doc_399014257238_item	3515339	et	4	main
juhatatud	doc_399014257238_item	3515342	et	4	main
lõpuks	doc_399014257238_item	3515348	et	4	main
pildistas	doc_399014257234_item	3515144	et	3	main
ms	doc_399014257234_item	3515145	et	4	main
mõisaid	doc_399014257234_item	3515146	et	3	main
tema	doc_399014257234_item	3515147	et	4	main
tervis	doc_399014257234_item	3515148	et	3	main
ja	doc_399014257234_item	3515149	et	3	main
nägemine	doc_399014257234_item	3515150	et	4	main
hakkasid	doc_399014257234_item	3515151	et	4	main
1930aastatel	doc_399014257234_item	3515152	et	4	main
rohelise	doc_399014257234_item	3515153	et	4	main
kae	doc_399014257234_item	3515154	et	4	main
tõttu	doc_399014257234_item	3515155	et	4	main
nõrgenema	doc_399014257234_item	3515156	et	3	main
brander	doc_399014257234_item	3515157	et	4	main
pidi	doc_399014257234_item	3515158	et	4	main
a	doc_399014257234_item	3515159	et	4	main
1941	doc_399014257234_item	3515160	et	2	main
minema	doc_399014257234_item	3515161	et	3	main
kivelä	doc_399014257234_item	3515162	et	4	main
haiglasse	doc_399014257234_item	3515163	et	4	main
patsiendid	doc_399014257234_item	3515165	et	3	main
millest	doc_399014257234_item	3515164	et	3	main
seesugust	doc_399014257234_item	3515180	et	3	main
kunagi	doc_399014257234_item	3515182	et	3	main
sõja	doc_399014257234_item	3515184	et	3	main
ebaselgetes	doc_399014257234_item	3515186	et	4	main
nikkilä	doc_399014257234_item	3515189	et	4	main
signe	doc_399014257234_item	3515202	et	4	main
brander	doc_399014257234_item	3515203	et	4	main
botaanikaaeda	doc_399014257238_item	3515436	et	4	main
peale	doc_399014257238_item	3515437	et	4	main
selle	doc_399014257238_item	3515438	et	4	main
ei	doc_399014257238_item	3515439	et	4	main
varjuta	doc_399014257238_item	3515440	et	4	main
sammas	doc_399014257238_item	3515441	et	4	main
seal	doc_399014257238_item	3515442	et	4	main
vanalinna	doc_399014257238_item	3515443	et	4	main
siluetti	doc_399014257238_item	3515444	et	4	main
ühingud	doc_399014257238_item	3515212	et	3	main
jäeti	doc_399014257238_item	3515222	et	3	main
kolm	doc_399014257238_item	3515223	et	3	main
plaanile	doc_399014257238_item	3515231	et	3	main
püstitada	doc_399014257238_item	3515232	et	3	main
püstitada	doc_399014257238_item	3515258	et	3	main
piritale	doc_399014257238_item	3515265	et	4	main
on	doc_399014257238_item	3515272	et	4	main
millest	doc_399014257238_item	3515281	et	3	main
paistavad	doc_399014257238_item	3515282	et	3	main
kaugele	doc_399014257238_item	3515283	et	4	main
merele	doc_399014257238_item	3515284	et	3	main
kõrge	doc_399014257238_item	3515285	et	4	main
obelisk	doc_399014257238_item	3515286	et	3	main
ja	doc_399014257238_item	3515287	et	3	main
ranna	doc_399014257238_item	3515288	et	3	main
trepp	doc_399014257238_item	3515289	et	3	main
linna	doc_399014257238_item	3515290	et	4	main
ja	doc_399014257238_item	3515291	et	3	main
skulptorite	doc_399014257238_item	3515292	et	3	main
ühingu	doc_399014257238_item	3515293	et	3	main
lahkarvamused	doc_399014257238_item	3515294	et	3	main
algavad	doc_399014257238_item	3515295	et	4	main
juba	doc_399014257238_item	3515296	et	3	main
samba	doc_399014257238_item	3515297	et	4	main
suurusest	doc_399014257238_item	3515298	et	4	main
ja	doc_399014257238_item	3515299	et	3	main
kohast	doc_399014257238_item	3515300	et	4	main
meres	doc_399014257238_item	3515301	et	3	main
eesti	doc_399014257238_item	3515302	et	4	main
skulptorite	doc_399014257238_item	3515303	et	3	main
ühingu	doc_399014257238_item	3515304	et	3	main
arvamuse	doc_399014257238_item	3515305	et	3	main
järgi	doc_399014257238_item	3515306	et	4	main
on	doc_399014257238_item	3515307	et	4	main
idee	doc_399014257238_item	3515308	et	4	main
kui	doc_399014257238_item	3515309	et	3	main
kalevipoeg-sambale	doc_399014257238_item	3515219	et	4	main
tallinna	doc_399014257238_item	3515220	et	4	main
võistlustööd	doc_399014257238_item	3515224	et	4	main
kunstnikud	doc_399014257238_item	3515226	et	3	main
tallinna	doc_399014257238_item	3515233	et	4	main
korraldatud	doc_399014257238_item	3515245	et	4	main
võistlusele	doc_399014257238_item	3515246	et	3	main
oli	doc_399014257238_item	3515247	et	3	main
jäetud	doc_399014257238_item	3515248	et	4	main
tähtaja	doc_399014257238_item	3515249	et	3	main
kolm	doc_399014257238_item	3515253	et	3	main
kalevipoeg	doc_399014257238_item	3515255	et	3	main
plaanis	doc_399014257238_item	3515257	et	4	main
saja	doc_399014257238_item	3515260	et	4	main
meetri	doc_399014257238_item	3515261	et	3	main
kaugusele	doc_399014257238_item	3515262	et	4	main
viiva	doc_399014257238_item	3515266	et	4	main
randtee	doc_399014257238_item	3515267	et	4	main
äärde	doc_399014257238_item	3515268	et	4	main
ajal	doc_399014257238_item	3515274	et	4	main
maailmasõja	doc_399014257238_item	3515276	et	3	main
auks	doc_399014257238_item	3515278	et	3	main
ega	doc_399014257238_item	3515312	et	3	main
nõukogude	doc_399014257238_item	3515317	et	3	main
aja	doc_399014257238_item	3515318	et	4	main
kui	doc_399014257238_item	3515325	et	3	main
et	doc_399014257238_item	3515333	et	3	main
sõltumatu	doc_399014257238_item	3515345	et	4	main
kunstnikliige	doc_399014257238_item	3515346	et	3	main
linna	doc_399014257238_item	3515354	et	4	main
parke	doc_399014257238_item	3515355	et	3	main
algpärase	doc_399014257238_item	3515356	et	4	main
idee	doc_399014257238_item	3515357	et	4	main
40	doc_399014257238_item	3515366	et	2	main
väikese	doc_399014257238_item	3515380	et	4	main
merineitsiga	doc_399014257238_item	3515381	et	3	main
ainult	doc_399014257238_item	3515390	et	4	main
maarjamäe	doc_399014257238_item	3515402	et	3	main
eesti	doc_399014257238_item	3515239	et	4	main
lõppedes	doc_399014257238_item	3515250	et	4	main
esmaspäeval	doc_399014257238_item	3515251	et	3	main
rannast	doc_399014257238_item	3515263	et	4	main
vastaval	doc_399014257238_item	3515269	et	4	main
püstitatud	doc_399014257238_item	3515279	et	4	main
monumendikompleksiga	doc_399014257238_item	3515319	et	4	main
nii	doc_399014257238_item	3515323	et	3	main
ka	doc_399014257238_item	3515326	et	3	main
ära	doc_399014257238_item	3515332	et	4	main
protesteerida	doc_399014257238_item	3515337	et	3	main
ratase	doc_399014257238_item	3515340	et	4	main
žürii	doc_399014257238_item	3515343	et	2	main
ainus	doc_399014257238_item	3515344	et	4	main
planeerinud	doc_399014257238_item	3515353	et	4	main
siiski	doc_399014257238_item	3515360	et	4	main
kunstnik	doc_399014257238_item	3515361	et	3	main
paljuvaieldud	doc_399014257238_item	3515362	et	3	main
skulptor	doc_399014257238_item	3515363	et	3	main
kes	doc_399014257238_item	3515367	et	4	main
kalevipoeg-ettevõtet	doc_399014257238_item	3515370	et	3	main
1990-ndate	doc_399014257238_item	3515372	et	4	main
luua	doc_399014257238_item	3515377	et	4	main
plaanis	doc_399014257238_item	3515385	et	4	main
tallinna	doc_399014257238_item	3515387	et	4	main
kõrge	doc_399014257238_item	3515391	et	4	main
tõlge	doc_399014257239_item	3515446	et	3	main
laekus	doc_399014257239_item	3515459	et	3	main
kunstnikud	doc_399014257239_item	3515463	et	3	main
eesti	doc_399014257239_item	3515475	et	4	main
rahvuseepose	doc_399014257239_item	3515476	et	3	main
järgi	doc_399014257239_item	3515479	et	4	main
koha	doc_399014257239_item	3515504	et	4	main
linna	doc_399014257239_item	3515522	et	4	main
ja	doc_399014257239_item	3515523	et	3	main
kujurite	doc_399014257239_item	3515524	et	3	main
juba	doc_399014257239_item	3515529	et	3	main
mis	doc_399014257239_item	3515532	et	4	main
ühenduse	doc_399014257239_item	3515541	et	4	main
hinnangul	doc_399014257239_item	3515542	et	3	main
on	doc_399014257239_item	3515543	et	4	main
selline	doc_399014257239_item	3515546	et	4	main
ega	doc_399014257239_item	3515548	et	3	main
sobi	doc_399014257239_item	3515551	et	4	main
nõukogudeaegse	doc_399014257239_item	3515552	et	3	main
memoriaaliga	doc_399014257239_item	3515553	et	4	main
kokku	doc_399014257239_item	3515554	et	3	main
sügisel	doc_399014257239_item	3515555	et	3	main
nii	doc_399014257239_item	3515556	et	3	main
kujurite	doc_399014257239_item	3515557	et	3	main
kui	doc_399014257239_item	3515558	et	3	main
ka	doc_399014257239_item	3515559	et	3	main
arhitektide	doc_399014257239_item	3515560	et	3	main
oma	doc_399014257239_item	3515563	et	4	main
maastikuarhitekt	doc_399014257239_item	3515591	et	3	main
esialgse	doc_399014257239_item	3515592	et	3	main
idee	doc_399014257239_item	3515593	et	4	main
välja	doc_399014257239_item	3515596	et	4	main
kalevipoeg-projekti	doc_399014257239_item	3515605	et	4	main
juba	doc_399014257239_item	3515606	et	3	main
1990ndate	doc_399014257239_item	3515607	et	4	main
lõpus	doc_399014257239_item	3515608	et	4	main
koht	doc_399014257239_item	3515658	et	3	main
tallinna	doc_399014257240_item	3515689	et	4	main
lahte	doc_399014257240_item	3515690	et	4	main
hiigelsuur	doc_399014257240_item	3515691	et	3	main
kalevipoja	doc_399014257240_item	3515692	et	4	main
eesti	doc_399014257240_item	3515699	et	4	main
linna	doc_399014257240_item	3515703	et	4	main
tallinna	doc_399014257240_item	3515706	et	4	main
lahte	doc_399014257240_item	3515707	et	4	main
kalevipoeg	doc_399014257240_item	3515712	et	3	main
eesti	doc_399014257240_item	3515713	et	4	main
rahvuseepose	doc_399014257240_item	3515714	et	3	main
konkursile	doc_399014257240_item	3515720	et	3	main
tähtajaks	doc_399014257240_item	3515723	et	3	main
pystitada	doc_399014257240_item	3515731	et	4	main
vastaval	doc_399014257240_item	3515741	et	4	main
nöukogude	doc_399014257240_item	3515745	et	4	main
mille	doc_399014257240_item	3515752	et	3	main
rahvaeepose	doc_399014257238_item	3515313	et	3	main
passi	doc_399014257238_item	3515315	et	4	main
sügisel	doc_399014257238_item	3515321	et	3	main
skulptorite	doc_399014257238_item	3515324	et	3	main
ametiühingud	doc_399014257238_item	3515328	et	3	main
žüriist	doc_399014257238_item	3515331	et	2	main
vastu	doc_399014257238_item	3515336	et	3	main
32	doc_399014257238_item	3515341	et	2	main
on	doc_399014257238_item	3515347	et	4	main
maastikuarhitekt	doc_399014257238_item	3515350	et	3	main
tauno	doc_399014257238_item	3515364	et	4	main
hakkas	doc_399014257238_item	3515368	et	3	main
juba	doc_399014257238_item	3515371	et	3	main
tallinnale	doc_399014257238_item	3515378	et	4	main
kopenhaageni	doc_399014257238_item	3515379	et	4	main
algpärases	doc_399014257238_item	3515384	et	4	main
lisati	doc_399014257238_item	3515395	et	3	main
tegime	doc_399014257238_item	3515404	et	3	main
ja	doc_399014257238_item	3515406	et	3	main
visualiseerisime	doc_399014257238_item	3515407	et	4	main
selle	doc_399014257238_item	3515408	et	4	main
otsustati	doc_399014257238_item	3515409	et	3	main
tallinna	doc_399014257239_item	3515449	et	4	main
peale	doc_399014257239_item	3515455	et	4	main
viltu	doc_399014257239_item	3515456	et	3	main
tallinna	doc_399014257239_item	3515457	et	4	main
võistlustööd	doc_399014257239_item	3515461	et	4	main
tallinna	doc_399014257239_item	3515469	et	4	main
samanimelise	doc_399014257239_item	3515477	et	4	main
peal	doc_399014257239_item	3515505	et	4	main
rannas	doc_399014257239_item	3515506	et	3	main
asub	doc_399014257239_item	3515507	et	3	main
teise	doc_399014257239_item	3515510	et	4	main
kangelastele	doc_399014257239_item	3515512	et	4	main
püstitatud	doc_399014257239_item	3515513	et	4	main
mälestusmärk	doc_399014257239_item	3515514	et	3	main
asukohta	doc_399014257239_item	3515537	et	4	main
meres	doc_399014257239_item	3515538	et	3	main
idee	doc_399014257239_item	3515544	et	4	main
vananenud	doc_399014257239_item	3515547	et	4	main
kutsus	doc_399014257239_item	3515562	et	4	main
esindajad	doc_399014257239_item	3515564	et	4	main
hindamiskomisjonist	doc_399014257239_item	3515565	et	3	main
tagasi	doc_399014257239_item	3515566	et	3	main
protestiks	doc_399014257239_item	3515567	et	4	main
ametnike	doc_399014257239_item	3515568	et	3	main
linnapea	doc_399014257239_item	3515575	et	4	main
sõltumatu	doc_399014257239_item	3515585	et	4	main
linna	doc_399014257239_item	3515588	et	4	main
parke	doc_399014257239_item	3515589	et	3	main
kujundanud	doc_399014257239_item	3515590	et	4	main
kes	doc_399014257239_item	3515603	et	4	main
püüdis	doc_399014257239_item	3515604	et	3	main
ideeks	doc_399014257239_item	3515611	et	3	main
oli	doc_399014257239_item	3515612	et	3	main
luua	doc_399014257239_item	3515613	et	4	main
järgi	doc_399014257239_item	3515656	et	4	main
tõlge	doc_399014257240_item	3515683	et	3	main
laekus	doc_399014257240_item	3515696	et	3	main
kolm	doc_399014257240_item	3515697	et	3	main
suurune	doc_399014257240_item	3515709	et	4	main
oli	doc_399014257240_item	3515721	et	3	main
laekunud	doc_399014257240_item	3515724	et	4	main
ainult	doc_399014257240_item	3515725	et	4	main
rannast	doc_399014257240_item	3515740	et	4	main
kangelastele	doc_399014257240_item	3515749	et	4	main
skulptorite	doc_399014257240_item	3515761	et	3	main
memoriaaliga	doc_399014257240_item	3515784	et	4	main
sygisehakul	doc_399014257240_item	3515786	et	4	main
kutsusid	doc_399014257240_item	3515787	et	4	main
oma	doc_399014257240_item	3515794	et	4	main
zyriist	doc_399014257240_item	3515796	et	4	main
liige	doc_399014257240_item	3515812	et	4	main
linna	doc_399014257240_item	3515818	et	4	main
parke	doc_399014257240_item	3515819	et	3	main
esialgse	doc_399014257240_item	3515820	et	3	main
ainult	doc_399014257238_item	3515349	et	4	main
kangro	doc_399014257238_item	3515365	et	4	main
aastate	doc_399014257238_item	3515373	et	3	main
ideeks	doc_399014257238_item	3515375	et	3	main
võrdsustuv	doc_399014257238_item	3515382	et	4	main
sümbool	doc_399014257238_item	3515383	et	4	main
aga	doc_399014257238_item	3515392	et	3	main
ettepanekul	doc_399014257238_item	3515394	et	3	main
monumendikompleksiga	doc_399014257238_item	3515403	et	4	main
arvestusi	doc_399014257238_item	3515405	et	4	main
kasuks	doc_399014257238_item	3515410	et	4	main
see	doc_399014257238_item	3515411	et	3	main
puuduks	doc_399014257238_item	3515412	et	3	main
silma	doc_399014257238_item	3515413	et	4	main
aselinnapea	doc_399014257238_item	3515415	et	4	main
olga	doc_399014257238_item	3515416	et	4	main
põhjendab	doc_399014257238_item	3515414	et	3	main
sõtnik	doc_399014257238_item	3515417	et	4	main
sõtniku	doc_399014257238_item	3515418	et	4	main
sõnade	doc_399014257238_item	3515419	et	3	main
järgi	doc_399014257238_item	3515420	et	4	main
on	doc_399014257238_item	3515421	et	4	main
ka	doc_399014257238_item	3515422	et	3	main
koht	doc_399014257238_item	3515423	et	3	main
parim	doc_399014257238_item	3515424	et	4	main
võimalik	doc_399014257238_item	3515425	et	3	main
sest	doc_399014257238_item	3515426	et	4	main
see	doc_399014257238_item	3515427	et	3	main
sattub	doc_399014257238_item	3515428	et	3	main
turistide	doc_399014257238_item	3515429	et	3	main
marsruudile	doc_399014257238_item	3515430	et	3	main
teel	doc_399014257238_item	3515431	et	4	main
pirita	doc_399014257238_item	3515432	et	4	main
kloostrisse	doc_399014257238_item	3515433	et	3	main
ja	doc_399014257238_item	3515434	et	3	main
tallinna	doc_399014257238_item	3515435	et	4	main
vaatavad	doc_399014257239_item	3515448	et	4	main
lahte	doc_399014257239_item	3515450	et	4	main
kavandatud	doc_399014257239_item	3515451	et	4	main
hiigelsuure	doc_399014257239_item	3515452	et	3	main
linnale	doc_399014257239_item	3515458	et	4	main
tallinna	doc_399014257239_item	3515465	et	4	main
suurune	doc_399014257239_item	3515472	et	4	main
kõrge	doc_399014257239_item	3515473	et	4	main
kalevipoeg	doc_399014257239_item	3515474	et	3	main
ainult	doc_399014257239_item	3515487	et	4	main
kolm	doc_399014257239_item	3515488	et	3	main
rannast	doc_399014257239_item	3515502	et	4	main
vastava	doc_399014257239_item	3515503	et	4	main
ajal	doc_399014257239_item	3515509	et	4	main
maailmasõja	doc_399014257239_item	3515511	et	3	main
arvamused	doc_399014257239_item	3515526	et	3	main
alates	doc_399014257239_item	3515530	et	3	main
monumentaalskulptuuri	doc_399014257239_item	3515534	et	4	main
suurust	doc_399014257239_item	3515535	et	4	main
parim	doc_399014257239_item	3515660	et	4	main
võimalik	doc_399014257239_item	3515661	et	3	main
sest	doc_399014257239_item	3515662	et	4	main
see	doc_399014257239_item	3515663	et	3	main
jääb	doc_399014257239_item	3515664	et	3	main
turistide	doc_399014257239_item	3515665	et	3	main
teele	doc_399014257239_item	3515666	et	3	main
pirita	doc_399014257239_item	3515667	et	4	main
sanatooriumi	doc_399014257239_item	3515668	et	4	main
ja	doc_399014257239_item	3515669	et	3	main
tallinna	doc_399014257239_item	3515670	et	4	main
botaanikaaia	doc_399014257239_item	3515671	et	4	main
suunas	doc_399014257239_item	3515672	et	4	main
sõites	doc_399014257239_item	3515673	et	3	main
samuti	doc_399014257239_item	3515674	et	3	main
ei	doc_399014257239_item	3515675	et	4	main
heida	doc_399014257239_item	3515676	et	4	main
see	doc_399014257239_item	3515677	et	3	main
ka	doc_399014257239_item	3515678	et	3	main
varju	doc_399014257239_item	3515679	et	4	main
vanalinna	doc_399014257239_item	3515680	et	4	main
siluetile	doc_399014257239_item	3515681	et	3	main
kalevipoja	doc_399014257239_item	3515453	et	4	main
kuju	doc_399014257239_item	3515454	et	4	main
kolm	doc_399014257239_item	3515460	et	3	main
kritiseerivad	doc_399014257239_item	3515464	et	4	main
linna	doc_399014257239_item	3515466	et	4	main
kava	doc_399014257239_item	3515467	et	4	main
rajada	doc_399014257239_item	3515468	et	3	main
kangelase	doc_399014257239_item	3515478	et	3	main
linna	doc_399014257239_item	3515480	et	4	main
korraldatud	doc_399014257239_item	3515481	et	4	main
konkursile	doc_399014257239_item	3515482	et	3	main
oli	doc_399014257239_item	3515483	et	3	main
pakkumist	doc_399014257239_item	3515489	et	4	main
kalevipoeg	doc_399014257239_item	3515490	et	3	main
on	doc_399014257239_item	3515491	et	4	main
kavas	doc_399014257239_item	3515492	et	3	main
püstitada	doc_399014257239_item	3515493	et	3	main
piritale	doc_399014257239_item	3515494	et	4	main
viiva	doc_399014257239_item	3515495	et	4	main
tee	doc_399014257239_item	3515496	et	4	main
äärde	doc_399014257239_item	3515497	et	4	main
merre	doc_399014257239_item	3515498	et	3	main
saja	doc_399014257239_item	3515499	et	4	main
meetri	doc_399014257239_item	3515500	et	3	main
eesti	doc_399014257239_item	3515462	et	4	main
lahte	doc_399014257239_item	3515470	et	4	main
paneelmaja	doc_399014257239_item	3515471	et	4	main
tähtajaks	doc_399014257239_item	3515484	et	3	main
esmaspäevaks	doc_399014257239_item	3515485	et	3	main
laekunud	doc_399014257239_item	3515486	et	4	main
kaugusele	doc_399014257239_item	3515501	et	4	main
mille	doc_399014257239_item	3515515	et	3	main
kõrge	doc_399014257239_item	3515516	et	4	main
obelisk	doc_399014257239_item	3515517	et	3	main
ja	doc_399014257239_item	3515518	et	3	main
trepp	doc_399014257239_item	3515519	et	3	main
paistavad	doc_399014257239_item	3515520	et	3	main
merelegi	doc_399014257239_item	3515521	et	3	main
lahku	doc_399014257239_item	3515528	et	4	main
eesti	doc_399014257239_item	3515539	et	4	main
kujurite	doc_399014257239_item	3515540	et	3	main
kui	doc_399014257239_item	3515545	et	3	main
liit	doc_399014257239_item	3515561	et	3	main
on	doc_399014257239_item	3515574	et	4	main
ratase	doc_399014257239_item	3515577	et	4	main
juhtimisel	doc_399014257239_item	3515579	et	4	main
töötavas	doc_399014257239_item	3515580	et	4	main
hindamiskomisjonis	doc_399014257239_item	3515581	et	3	main
alles	doc_399014257239_item	3515582	et	3	main
ainult	doc_399014257239_item	3515583	et	4	main
üks	doc_399014257239_item	3515584	et	3	main
liige	doc_399014257239_item	3515587	et	4	main
siiski	doc_399014257239_item	3515595	et	4	main
kunstnik	doc_399014257239_item	3515597	et	3	main
tauno	doc_399014257239_item	3515600	et	4	main
kangro	doc_399014257239_item	3515601	et	4	main
40	doc_399014257239_item	3515602	et	2	main
tuntuks	doc_399014257239_item	3515609	et	4	main
teha	doc_399014257239_item	3515610	et	3	main
kopenhaageni	doc_399014257239_item	3515615	et	4	main
merineitsiga	doc_399014257239_item	3515617	et	3	main
võrreldav	doc_399014257239_item	3515618	et	4	main
sümbol	doc_399014257239_item	3515619	et	3	main
liidud	doc_399014257240_item	3515685	et	3	main
tallinna	doc_399014257240_item	3515694	et	4	main
vöistlustööd	doc_399014257240_item	3515698	et	4	main
kunstnikud	doc_399014257240_item	3515700	et	3	main
kritiseerivad	doc_399014257240_item	3515701	et	4	main
kava	doc_399014257240_item	3515704	et	4	main
21m	doc_399014257240_item	3515710	et	4	main
körge	doc_399014257240_item	3515711	et	4	main
korraldatud	doc_399014257240_item	3515719	et	4	main
esmaspäevaseks	doc_399014257240_item	3515722	et	4	main
kavas	doc_399014257240_item	3515730	et	3	main
piritale	doc_399014257240_item	3515732	et	4	main
viiva	doc_399014257240_item	3515733	et	4	main
saja	doc_399014257240_item	3515737	et	4	main
meetri	doc_399014257240_item	3515738	et	3	main
kaugusele	doc_399014257240_item	3515739	et	4	main
asub	doc_399014257240_item	3515744	et	3	main
ajal	doc_399014257240_item	3515746	et	4	main
memoriaal	doc_399014257240_item	3515751	et	3	main
yhenduse	doc_399014257240_item	3515762	et	4	main
sobi	doc_399014257240_item	3515783	et	4	main
kokku	doc_399014257240_item	3515785	et	3	main
ka	doc_399014257240_item	3515791	et	3	main
ametiliidud	doc_399014257240_item	3515793	et	3	main
ametivöimude	doc_399014257240_item	3515799	et	4	main
zyrii	doc_399014257240_item	3515801	et	4	main
jyri	doc_399014257240_item	3515805	et	4	main
on	doc_399014257240_item	3515813	et	4	main
maastikuarhitekt	doc_399014257240_item	3515814	et	3	main
idee	doc_399014257240_item	3515821	et	4	main
on	doc_399014257240_item	3515823	et	4	main
tauno	doc_399014257240_item	3515828	et	4	main
40	doc_399014257240_item	3515830	et	2	main
kes	doc_399014257240_item	3515831	et	4	main
alustas	doc_399014257240_item	3515832	et	3	main
oleva	doc_399014257240_item	3515842	et	4	main
14m	doc_399014257240_item	3515855	et	4	main
vaatasime	doc_399014257240_item	3515863	et	3	main
kuidas	doc_399014257240_item	3515864	et	3	main
tegime	doc_399014257240_item	3515870	et	3	main
kuna	doc_399014257240_item	3515878	et	3	main
sötniku	doc_399014257240_item	3515887	et	4	main
nõukogude	doc_399014257239_item	3515508	et	3	main
ühenduse	doc_399014257239_item	3515525	et	4	main
lähevad	doc_399014257239_item	3515527	et	3	main
sellest	doc_399014257239_item	3515531	et	4	main
puudutab	doc_399014257239_item	3515533	et	3	main
ja	doc_399014257239_item	3515536	et	3	main
suure	doc_399014257239_item	3515569	et	3	main
osakaalu	doc_399014257239_item	3515570	et	4	main
vastu	doc_399014257239_item	3515571	et	3	main
komisjonis	doc_399014257239_item	3515572	et	3	main
käis	doc_399014257239_item	3515594	et	4	main
vaidlusalune	doc_399014257239_item	3515598	et	4	main
tallinnale	doc_399014257239_item	3515614	et	4	main
väikse	doc_399014257239_item	3515616	et	4	main
on	doc_399014257239_item	3515657	et	4	main
kunstnike	doc_399014257240_item	3515684	et	3	main
plaani	doc_399014257240_item	3515687	et	4	main
pystitada	doc_399014257240_item	3515688	et	4	main
kuju	doc_399014257240_item	3515693	et	4	main
paneelmaja	doc_399014257240_item	3515708	et	4	main
samanimelise	doc_399014257240_item	3515715	et	4	main
kangelase	doc_399014257240_item	3515716	et	3	main
järgi	doc_399014257240_item	3515717	et	4	main
kalevipoeg	doc_399014257240_item	3515728	et	3	main
äärde	doc_399014257240_item	3515735	et	4	main
rannas	doc_399014257240_item	3515743	et	3	main
ii	doc_399014257240_item	3515747	et	4	main
ms	doc_399014257240_item	3515748	et	4	main
paistavad	doc_399014257240_item	3515757	et	3	main
kui	doc_399014257240_item	3515790	et	3	main
vastu	doc_399014257240_item	3515800	et	3	main
ratas	doc_399014257240_item	3515806	et	3	main
autor	doc_399014257240_item	3515822	et	3	main
symbol	doc_399014257240_item	3515846	et	4	main
väike	doc_399014257240_item	3515851	et	4	main
linna	doc_399014257240_item	3515858	et	4	main
ettepanekul	doc_399014257240_item	3515859	et	3	main
sobib	doc_399014257240_item	3515866	et	3	main
memoriaaliga	doc_399014257240_item	3515868	et	4	main
arvestusi	doc_399014257240_item	3515871	et	4	main
ja	doc_399014257240_item	3515872	et	3	main
visualiseerimise	doc_399014257240_item	3515873	et	4	main
se	doc_399014257240_item	3515893	et	4	main
jääb	doc_399014257240_item	3515894	et	3	main
tallinna	doc_399014257240_item	3515901	et	4	main
viiva	doc_399014257240_item	3515903	et	4	main
tee	doc_399014257240_item	3515904	et	4	main
ei	doc_399014257240_item	3515921	et	4	main
liit	doc_399014257240_item	3515971	et	3	main
keskerakonna	doc_399014257240_item	3516011	et	4	main
liikmeks	doc_399014257240_item	3516012	et	3	main
kriitikat	doc_399014257240_item	3516013	et	3	main
samas	doc_399014257240_item	3516026	et	4	main
vägistas	doc_399014257240_item	3516027	et	3	main
meres	doc_399014257240_item	3516028	et	3	main
ka	doc_399014257240_item	3516029	et	3	main
yhe	doc_399014257240_item	3516030	et	4	main
yle	doc_399014257240_item	3516035	et	4	main
on	doc_399014257240_item	3516038	et	4	main
löpus	doc_399014257240_item	3516049	et	4	main
korraldatakse	doc_399014257240_item	3516052	et	3	main
pystitada	doc_399014257240_item	3516060	et	4	main
järgnevate	doc_399014257240_item	3516061	et	4	main
jooksul	doc_399014257240_item	3516063	et	4	main
rahvuseepose	doc_399014257239_item	3515549	et	3	main
kangelane	doc_399014257239_item	3515550	et	3	main
lõpuks	doc_399014257239_item	3515573	et	4	main
jüri	doc_399014257239_item	3515576	et	4	main
32	doc_399014257239_item	3515578	et	2	main
kunstnikust	doc_399014257239_item	3515586	et	3	main
kujur	doc_399014257239_item	3515599	et	3	main
algupärase	doc_399014257239_item	3515620	et	4	main
kohaselt	doc_399014257239_item	3515622	et	4	main
tallinna	doc_399014257239_item	3515623	et	4	main
kava	doc_399014257239_item	3515621	et	4	main
väike	doc_399014257239_item	3515624	et	4	main
merineitsi	doc_399014257239_item	3515625	et	4	main
oli	doc_399014257239_item	3515626	et	3	main
ainult	doc_399014257239_item	3515627	et	4	main
kõrge	doc_399014257239_item	3515628	et	4	main
aga	doc_399014257239_item	3515629	et	3	main
linna	doc_399014257239_item	3515630	et	4	main
ettepanekul	doc_399014257239_item	3515631	et	3	main
lisati	doc_399014257239_item	3515632	et	3	main
kõrgust	doc_399014257239_item	3515633	et	4	main
vaatasime	doc_399014257239_item	3515634	et	3	main
kuidas	doc_399014257239_item	3515635	et	3	main
kuju	doc_399014257239_item	3515636	et	4	main
sobib	doc_399014257239_item	3515637	et	3	main
maarjamäe	doc_399014257239_item	3515638	et	3	main
memoriaaliga	doc_399014257239_item	3515639	et	4	main
tegime	doc_399014257239_item	3515640	et	3	main
arvestusi	doc_399014257239_item	3515641	et	4	main
ja	doc_399014257239_item	3515642	et	3	main
visualiseerisime	doc_399014257239_item	3515643	et	4	main
selle	doc_399014257239_item	3515644	et	4	main
ja	doc_399014257239_item	3515645	et	3	main
otsustasime	doc_399014257239_item	3515646	et	3	main
kasuks	doc_399014257239_item	3515647	et	4	main
see	doc_399014257239_item	3515648	et	3	main
jääks	doc_399014257239_item	3515649	et	4	main
silma	doc_399014257239_item	3515650	et	4	main
põhjendab	doc_399014257239_item	3515651	et	3	main
abilinnapea	doc_399014257239_item	3515652	et	4	main
olga	doc_399014257239_item	3515653	et	4	main
sõtnik	doc_399014257239_item	3515654	et	4	main
sõtniku	doc_399014257239_item	3515655	et	4	main
ka	doc_399014257239_item	3515659	et	3	main
kritiseerivad	doc_399014257240_item	3515686	et	4	main
linnale	doc_399014257240_item	3515695	et	4	main
tallinna	doc_399014257240_item	3515702	et	4	main
rajada	doc_399014257240_item	3515705	et	3	main
linna	doc_399014257240_item	3515718	et	4	main
kolm	doc_399014257240_item	3515726	et	3	main
pakkumist	doc_399014257240_item	3515727	et	4	main
oli	doc_399014257240_item	3515729	et	3	main
tee	doc_399014257240_item	3515734	et	4	main
merre	doc_399014257240_item	3515736	et	3	main
kohal	doc_399014257240_item	3515742	et	4	main
pystitatud	doc_399014257240_item	3515750	et	4	main
körge	doc_399014257240_item	3515753	et	4	main
obelisk	doc_399014257240_item	3515754	et	3	main
ja	doc_399014257240_item	3515755	et	3	main
trepp	doc_399014257240_item	3515756	et	3	main
linna	doc_399014257240_item	3515759	et	4	main
arvamused	doc_399014257240_item	3515763	et	3	main
lähevad	doc_399014257240_item	3515764	et	3	main
lahku	doc_399014257240_item	3515765	et	4	main
kuju	doc_399014257240_item	3515766	et	4	main
suuruse	doc_399014257240_item	3515767	et	4	main
ja	doc_399014257240_item	3515768	et	3	main
asukoha	doc_399014257240_item	3515769	et	4	main
suhtes	doc_399014257240_item	3515770	et	4	main
meres	doc_399014257240_item	3515771	et	3	main
eesti	doc_399014257240_item	3515772	et	4	main
skulptorite	doc_399014257240_item	3515773	et	3	main
yhenduse	doc_399014257240_item	3515774	et	4	main
idee	doc_399014257240_item	3515775	et	4	main
kui	doc_399014257240_item	3515776	et	3	main
selline	doc_399014257240_item	3515777	et	4	main
on	doc_399014257240_item	3515778	et	4	main
vananenud	doc_399014257240_item	3515779	et	4	main
ega	doc_399014257240_item	3515780	et	3	main
rahvuseepose	doc_399014257240_item	3515781	et	3	main
kangelane	doc_399014257240_item	3515782	et	3	main
merelegi	doc_399014257240_item	3515758	et	3	main
ja	doc_399014257240_item	3515760	et	3	main
nii	doc_399014257240_item	3515788	et	3	main
skulptorite	doc_399014257240_item	3515789	et	3	main
arhitektide	doc_399014257240_item	3515792	et	3	main
eestkostjad	doc_399014257240_item	3515795	et	3	main
mille	doc_399014257240_item	3515802	et	3	main
on	doc_399014257240_item	3515804	et	4	main
kes	doc_399014257240_item	3515815	et	4	main
on	doc_399014257240_item	3515816	et	4	main
kujundanud	doc_399014257240_item	3515817	et	4	main
palju	doc_399014257240_item	3515825	et	4	main
1990-aastate	doc_399014257240_item	3515836	et	3	main
esialse	doc_399014257240_item	3515847	et	4	main
merineitsi	doc_399014257240_item	3515852	et	4	main
oli	doc_399014257240_item	3515853	et	3	main
vaid	doc_399014257240_item	3515854	et	3	main
lisati	doc_399014257240_item	3515860	et	3	main
selle	doc_399014257240_item	3515874	et	4	main
otsustasime	doc_399014257240_item	3515875	et	3	main
21m	doc_399014257240_item	3515876	et	4	main
torkaks	doc_399014257240_item	3515880	et	3	main
ära	doc_399014257240_item	3515797	et	4	main
protestimaks	doc_399014257240_item	3515798	et	4	main
eesotsas	doc_399014257240_item	3515803	et	4	main
32	doc_399014257240_item	3515807	et	2	main
ainus	doc_399014257240_item	3515808	et	4	main
teistest	doc_399014257240_item	3515809	et	4	main
söltumatu	doc_399014257240_item	3515810	et	4	main
kunstnikust	doc_399014257240_item	3515811	et	3	main
poleemikat	doc_399014257240_item	3515826	et	3	main
tekitanud	doc_399014257240_item	3515827	et	4	main
kangro	doc_399014257240_item	3515829	et	4	main
löpus	doc_399014257240_item	3515837	et	4	main
tallinnassa	doc_399014257240_item	3515838	et	4	main
planeeriti	doc_399014257240_item	3515839	et	3	main
luau	doc_399014257240_item	3515840	et	4	main
plaani	doc_399014257240_item	3515848	et	4	main
päraselt	doc_399014257240_item	3515849	et	4	main
körge	doc_399014257240_item	3515856	et	4	main
körgust	doc_399014257240_item	3515861	et	4	main
kuju	doc_399014257240_item	3515865	et	4	main
se	doc_399014257240_item	3515879	et	4	main
silma	doc_399014257240_item	3515882	et	4	main
pöhjendab	doc_399014257240_item	3515883	et	4	main
olga	doc_399014257240_item	3515885	et	4	main
sötnik	doc_399014257240_item	3515886	et	4	main
parim	doc_399014257240_item	3515891	et	4	main
kuna	doc_399014257240_item	3515892	et	3	main
pirita	doc_399014257240_item	3515898	et	4	main
ja	doc_399014257240_item	3515900	et	3	main
botaanika-aeda	doc_399014257240_item	3515902	et	4	main
se	doc_399014257240_item	3515907	et	4	main
vanalinnas	doc_399014257240_item	3515911	et	4	main
innustav	doc_399014257240_item	3515918	et	4	main
meeleolu	doc_399014257240_item	3515919	et	4	main
kunstnik	doc_399014257240_item	3515920	et	3	main
mägila	doc_399014257240_item	3515929	et	4	main
pronkskuju	doc_399014257240_item	3515932	et	4	main
kus	doc_399014257240_item	3515933	et	3	main
symboliseerib	doc_399014257240_item	3515940	et	4	main
möjuvöimas	doc_399014257240_item	3515969	et	4	main
kes	doc_399014257240_item	3515972	et	4	main
asukoha	doc_399014257240_item	3515979	et	4	main
sai	doc_399014257240_item	3516009	et	4	main
suvel	doc_399014257240_item	3516010	et	3	main
kalevipoeg	doc_399014257240_item	3516017	et	3	main
järgi	doc_399014257240_item	3516020	et	4	main
viskas	doc_399014257240_item	3516021	et	3	main
vaenlasi	doc_399014257240_item	3516022	et	3	main
suurte	doc_399014257240_item	3516023	et	3	main
kividega	doc_399014257240_item	3516024	et	3	main
kuid	doc_399014257240_item	3516025	et	4	main
kalevipoeg	doc_399014257240_item	3516037	et	3	main
ikka	doc_399014257240_item	3516039	et	4	main
symbol	doc_399014257240_item	3516041	et	4	main
sötniku	doc_399014257240_item	3516056	et	4	main
siiski	doc_399014257240_item	3515824	et	4	main
kalevipoeg-projekti	doc_399014257240_item	3515833	et	4	main
tutvustamist	doc_399014257240_item	3515834	et	4	main
juba	doc_399014257240_item	3515835	et	3	main
kopenhaagenis	doc_399014257240_item	3515841	et	4	main
väikse	doc_399014257240_item	3515843	et	4	main
merineitsi	doc_399014257240_item	3515844	et	4	main
taoline	doc_399014257240_item	3515845	et	3	main
tallinna	doc_399014257240_item	3515850	et	4	main
kuid	doc_399014257240_item	3515857	et	4	main
21meetrini	doc_399014257240_item	3515862	et	3	main
maarjamäe	doc_399014257240_item	3515867	et	3	main
kokku	doc_399014257240_item	3515869	et	3	main
kasuks	doc_399014257240_item	3515877	et	4	main
vaatajale	doc_399014257240_item	3515881	et	4	main
abilinnapea	doc_399014257240_item	3515884	et	4	main
turistide	doc_399014257240_item	3515895	et	3	main
ei	doc_399014257240_item	3515908	et	4	main
varja	doc_399014257240_item	3515909	et	4	main
ise	doc_399014257240_item	3515923	et	4	main
esitles	doc_399014257240_item	3515930	et	3	main
suure	doc_399014257240_item	3515934	et	3	main
kangelase	doc_399014257240_item	3515941	et	3	main
raekoja	doc_399014257240_item	3515978	et	3	main
tallinna	doc_399014257240_item	3515981	et	4	main
erakondadest	doc_399014257240_item	3515982	et	3	main
aega	doc_399014257240_item	3516006	et	4	main
on	doc_399014257240_item	3516014	et	4	main
kes	doc_399014257240_item	3516018	et	4	main
muistendi	doc_399014257240_item	3516019	et	3	main
on	doc_399014257240_item	3516032	et	4	main
mötiskletud	doc_399014257240_item	3516033	et	4	main
selle	doc_399014257240_item	3516034	et	4	main
jaoks	doc_399014257240_item	3516043	et	4	main
kalevipoeg	doc_399014257240_item	3516044	et	3	main
vöistluse	doc_399014257240_item	3516045	et	4	main
tulemused	doc_399014257240_item	3516046	et	3	main
teatatakse	doc_399014257240_item	3516047	et	3	main
seda	doc_399014257240_item	3516051	et	3	main
sönul	doc_399014257240_item	3516057	et	4	main
soositud	doc_399014257240_item	3515897	et	4	main
sanatooriumisse	doc_399014257240_item	3515899	et	3	main
juurde	doc_399014257240_item	3515905	et	4	main
samas	doc_399014257240_item	3515906	et	4	main
tauno	doc_399014257240_item	3515912	et	4	main
kangro	doc_399014257240_item	3515913	et	4	main
galeriis	doc_399014257240_item	3515914	et	3	main
valitses	doc_399014257240_item	3515915	et	3	main
veel	doc_399014257240_item	3515916	et	4	main
esmaspäevalgi	doc_399014257240_item	3515917	et	4	main
kyll	doc_399014257240_item	3515924	et	4	main
linnas	doc_399014257240_item	3515925	et	4	main
galerist	doc_399014257240_item	3515927	et	4	main
kuju	doc_399014257240_item	3515939	et	4	main
koju	doc_399014257240_item	3515942	et	3	main
naasmist	doc_399014257240_item	3515943	et	4	main
pärast	doc_399014257240_item	3515944	et	4	main
maailmarännakut	doc_399014257240_item	3515945	et	3	main
kunstniku	doc_399014257240_item	3515946	et	3	main
nägemuse	doc_399014257240_item	3515947	et	3	main
kangelasel	doc_399014257240_item	3515949	et	3	main
on	doc_399014257240_item	3515950	et	4	main
käes	doc_399014257240_item	3515951	et	4	main
paat	doc_399014257240_item	3515952	et	3	main
järgi	doc_399014257240_item	3515948	et	4	main
ja	doc_399014257240_item	3515953	et	3	main
möni	doc_399014257240_item	3515954	et	4	main
inimene	doc_399014257240_item	3515955	et	3	main
kes	doc_399014257240_item	3515956	et	4	main
symboliseerivad	doc_399014257240_item	3515957	et	4	main
koju	doc_399014257240_item	3515959	et	3	main
naasmist	doc_399014257240_item	3515960	et	4	main
lisaks	doc_399014257240_item	3515961	et	4	main
eestlaste	doc_399014257240_item	3515958	et	4	main
skulptorite	doc_399014257240_item	3515962	et	3	main
yhendusele	doc_399014257240_item	3515963	et	4	main
rajamise	doc_399014257240_item	3515965	et	4	main
kuju	doc_399014257240_item	3515964	et	4	main
projekti	doc_399014257240_item	3515966	et	4	main
vastu	doc_399014257240_item	3515967	et	3	main
arvates	doc_399014257240_item	3515888	et	4	main
koht	doc_399014257240_item	3515889	et	3	main
on	doc_399014257240_item	3515890	et	4	main
poolt	doc_399014257240_item	3515896	et	4	main
siluetti	doc_399014257240_item	3515910	et	4	main
olnud	doc_399014257240_item	3515922	et	4	main
kuid	doc_399014257240_item	3515926	et	4	main
pille	doc_399014257240_item	3515928	et	3	main
kannustavalt	doc_399014257240_item	3515931	et	4	main
käeline	doc_399014257240_item	3515935	et	4	main
kalevipoeg	doc_399014257240_item	3515936	et	3	main
kannab	doc_399014257240_item	3515937	et	3	main
vett	doc_399014257240_item	3515938	et	3	main
uue	doc_399014257240_item	3515977	et	3	main
pärast	doc_399014257240_item	3515980	et	4	main
köige	doc_399014257240_item	3515983	et	4	main
rohkem	doc_399014257240_item	3515984	et	4	main
vöimu	doc_399014257240_item	3515985	et	4	main
on	doc_399014257240_item	3515986	et	4	main
keskerakonnal	doc_399014257240_item	3515987	et	4	main
keskerakond	doc_399014257240_item	3515988	et	3	main
on	doc_399014257240_item	3515989	et	4	main
aga	doc_399014257240_item	3515990	et	3	main
ennegi	doc_399014257240_item	3515991	et	4	main
pooldanud	doc_399014257240_item	3515992	et	4	main
körgete	doc_399014257240_item	3515993	et	4	main
hoonete	doc_399014257240_item	3515994	et	4	main
rajamist	doc_399014257240_item	3515995	et	4	main
teiste	doc_399014257240_item	3515996	et	4	main
kunstnike	doc_399014257240_item	3515997	et	3	main
kriitika	doc_399014257240_item	3515998	et	4	main
kuju	doc_399014257240_item	3515999	et	4	main
rajamise	doc_399014257240_item	3516000	et	4	main
vastu	doc_399014257240_item	3516001	et	3	main
kasvas	doc_399014257240_item	3516002	et	3	main
kui	doc_399014257240_item	3516003	et	3	main
ideed	doc_399014257240_item	3516004	et	4	main
kaua	doc_399014257240_item	3516005	et	3	main
oli	doc_399014257240_item	3515968	et	3	main
arhitektide	doc_399014257240_item	3515970	et	3	main
on	doc_399014257240_item	3515973	et	4	main
linnaga	doc_399014257240_item	3515974	et	3	main
eriarvamusel	doc_399014257240_item	3515975	et	3	main
seoses	doc_399014257240_item	3515976	et	4	main
tutvustanud	doc_399014257240_item	3516007	et	4	main
saanud	doc_399014257240_item	3516015	et	4	main
sobiv	doc_399014257240_item	3516040	et	4	main
jaanuari	doc_399014257240_item	3516048	et	4	main
pärast	doc_399014257240_item	3516050	et	4	main
vöistlustöödest	doc_399014257240_item	3516053	et	4	main
näitus	doc_399014257240_item	3516054	et	3	main
abilinnapea	doc_399014257240_item	3516055	et	4	main
kuju	doc_399014257240_item	3516058	et	4	main
kangro	doc_399014257240_item	3516008	et	4	main
ka	doc_399014257240_item	3516016	et	3	main
neiu	doc_399014257240_item	3516031	et	4	main
kas	doc_399014257240_item	3516036	et	3	main
tallinna	doc_399014257240_item	3516042	et	4	main
planeeritakse	doc_399014257240_item	3516059	et	3	main
aastate	doc_399014257240_item	3516062	et	3	main
asub	doc_213943984923_item	3518529	et	3	main
ei	doc_213943984923_item	3518571	et	4	main
ole	doc_213943984923_item	3518572	et	4	main
samuti	doc_213943984923_item	3518573	et	3	main
teed	doc_213943984923_item	3518586	et	4	main
käes	doc_213943984923_item	3518526	et	4	main
lumerohke	doc_213943984923_item	3518531	et	4	main
vaimustuses	doc_213943984923_item	3518574	et	4	main
puisata	doc_213943984923_item	3518587	et	4	main
majahoidjad	doc_213943984923_item	3518588	et	3	main
ja	doc_213943984923_item	3518589	et	3	main
omanikud	doc_213943984923_item	3518590	et	3	main
võtsid	doc_213943984923_item	3518591	et	4	main
kätte	doc_213943984923_item	3518592	et	4	main
unarusse	doc_213943984923_item	3518593	et	3	main
hakkasid	doc_213943984923_item	3518597	et	4	main
majade	doc_213943984923_item	3518599	et	3	main
nende	doc_213943984923_item	3518603	et	4	main
suusatajad	doc_213943984923_item	3518607	et	4	main
ja	doc_213943984923_item	3518608	et	3	main
kellel	doc_213943984923_item	3518612	et	4	main
võimalus	doc_213943984923_item	3518615	et	3	main
tegeleda	doc_213943984923_item	3518618	et	3	main
raeküla	doc_213943984923_item	3518620	et	4	main
suusarada	doc_213943984923_item	3518621	et	4	main
talvetulek	doc_213943984923_item	3518659	et	3	main
tõlge	doc_399014257250_item	3518663	et	3	main
haakrist	doc_399014257250_item	3518668	et	3	main
teine	doc_399014257250_item	3518673	et	3	main
ajab	doc_399014257250_item	3518679	et	3	main
1940-ndaid	doc_399014257250_item	3518687	et	4	main
oli	doc_399014257250_item	3518692	et	3	main
nimetab	doc_399014257250_item	3518706	et	3	main
tõrjutud	doc_399014257250_item	3518711	et	4	main
mälestused	doc_399014257250_item	3518712	et	4	main
olid	doc_399014257250_item	3518716	et	4	main
talvekülmad	doc_213943984923_item	3518524	et	3	main
kuigi	doc_213943984923_item	3518527	et	3	main
talv	doc_213943984923_item	3518532	et	3	main
sellel	doc_213943984923_item	3518537	et	4	main
aastalgi	doc_213943984923_item	3518538	et	4	main
ei	doc_213943984923_item	3518539	et	4	main
kaasa	doc_213943984923_item	3518557	et	4	main
et	doc_213943984923_item	3518576	et	3	main
öisetelt	doc_213943984923_item	3518579	et	4	main
ja	doc_213943984923_item	3518596	et	3	main
koristama	doc_213943984923_item	3518602	et	3	main
on	doc_213943984923_item	3518613	et	4	main
tegevusalaga	doc_213943984923_item	3518617	et	3	main
on	doc_213943984923_item	3518660	et	4	main
meelepärane	doc_213943984923_item	3518662	et	4	main
tõlge	doc_213943984923_item	3518523	et	3	main
põhja-euroopas	doc_213943984923_item	3518530	et	3	main
muutunud	doc_213943984923_item	3518534	et	4	main
kiirustanud	doc_213943984923_item	3518540	et	4	main
kauaoodatud	doc_213943984923_item	3518541	et	3	main
võitlesid	doc_213943984923_item	3518567	et	4	main
lumeummistusega	doc_213943984923_item	3518568	et	3	main
tänavapuhastuse	doc_213943984923_item	3518569	et	3	main
firmad	doc_213943984923_item	3518570	et	3	main
sellest	doc_213943984923_item	3518575	et	4	main
tuleb	doc_213943984923_item	3518578	et	3	main
tänavatelt	doc_213943984923_item	3518580	et	4	main
lund	doc_213943984923_item	3518581	et	3	main
lund	doc_213943984923_item	3518582	et	3	main
koristada	doc_213943984923_item	3518583	et	3	main
ja	doc_213943984923_item	3518584	et	3	main
soolaga	doc_213943984923_item	3518585	et	4	main
teid	doc_213943984923_item	3518601	et	4	main
jääaluse	doc_213943984923_item	3518609	et	4	main
kalapüügi	doc_213943984923_item	3518610	et	4	main
armastajad	doc_213943984923_item	3518611	et	4	main
nüüd	doc_213943984923_item	3518614	et	4	main
lemmiku	doc_213943984923_item	3518616	et	3	main
ka	doc_213943984923_item	3518619	et	3	main
kannata	doc_213943984923_item	3518653	et	4	main
meeles	doc_399014257250_item	3518664	et	3	main
sümbol	doc_399014257250_item	3518675	et	3	main
ja	doc_399014257250_item	3518677	et	3	main
inimesed	doc_399014257250_item	3518680	et	3	main
juba	doc_399014257250_item	3518693	et	3	main
olemas	doc_399014257250_item	3518694	et	4	main
viis	doc_399014257250_item	3518696	et	4	main
imbi	doc_399014257250_item	3518707	et	4	main
paju	doc_399014257250_item	3518708	et	4	main
2006	doc_399014257250_item	3518713	et	2	main
juba	doc_399014257250_item	3518717	et	3	main
juutide	doc_399014257250_item	3518727	et	3	main
genotsiidile	doc_399014257250_item	3518728	et	3	main
on	doc_399014257250_item	3518729	et	4	main
muresid	doc_213943984923_item	3518604	et	3	main
ei	doc_213943984923_item	3518605	et	4	main
jaga	doc_213943984923_item	3518606	et	4	main
on	doc_213943984923_item	3518525	et	4	main
eesti	doc_213943984923_item	3518528	et	4	main
on	doc_213943984923_item	3518533	et	4	main
harukordseks	doc_213943984923_item	3518535	et	4	main
nähtuseks	doc_213943984923_item	3518536	et	4	main
lumi	doc_213943984923_item	3518542	et	3	main
maha	doc_213943984923_item	3518543	et	4	main
sadada	doc_213943984923_item	3518544	et	3	main
viimaks	doc_213943984923_item	3518545	et	4	main
aga	doc_213943984923_item	3518546	et	3	main
rõõmustas	doc_213943984923_item	3518547	et	3	main
kõiki	doc_213943984923_item	3518548	et	4	main
alles	doc_213943984923_item	3518549	et	3	main
talve	doc_213943984923_item	3518550	et	4	main
teisel	doc_213943984923_item	3518551	et	4	main
poolel	doc_213943984923_item	3518552	et	4	main
lumi	doc_213943984923_item	3518553	et	3	main
ei	doc_213943984923_item	3518554	et	4	main
toonud	doc_213943984923_item	3518555	et	4	main
endaga	doc_213943984923_item	3518556	et	4	main
mitte	doc_213943984923_item	3518558	et	3	main
ainult	doc_213943984923_item	3518559	et	4	main
rõõmu	doc_213943984923_item	3518560	et	4	main
vaid	doc_213943984923_item	3518561	et	3	main
ka	doc_213943984923_item	3518562	et	3	main
muresid	doc_213943984923_item	3518563	et	3	main
eeskätt	doc_213943984923_item	3518564	et	3	main
autoomanikele	doc_213943984923_item	3518565	et	3	main
kes	doc_213943984923_item	3518566	et	4	main
nüüd	doc_213943984923_item	3518577	et	4	main
labidad	doc_213943984923_item	3518595	et	3	main
oma	doc_213943984923_item	3518598	et	4	main
muutunud	doc_213943984923_item	3518623	et	4	main
rahvarohkeks	doc_213943984923_item	3518624	et	3	main
lapsed	doc_213943984923_item	3518625	et	3	main
vanemad	doc_213943984923_item	3518626	et	4	main
isegi	doc_213943984923_item	3518627	et	4	main
koduloomad	doc_213943984923_item	3518628	et	3	main
soovivad	doc_213943984923_item	3518629	et	4	main
värskel	doc_213943984923_item	3518630	et	4	main
õhul	doc_213943984923_item	3518631	et	3	main
sporti	doc_213943984923_item	3518632	et	4	main
teha	doc_213943984923_item	3518633	et	3	main
munamäel	doc_213943984923_item	3518634	et	3	main
mida	doc_213943984923_item	3518635	et	4	main
rahva	doc_213943984923_item	3518636	et	3	main
seas	doc_213943984923_item	3518637	et	4	main
kutsutakse	doc_213943984923_item	3518638	et	3	main
lastemäeks	doc_213943984923_item	3518639	et	3	main
on	doc_213943984923_item	3518640	et	4	main
kelgutajaid	doc_213943984923_item	3518641	et	4	main
palju	doc_213943984923_item	3518642	et	4	main
see	doc_213943984923_item	3518643	et	3	main
koht	doc_213943984923_item	3518644	et	3	main
meelitab	doc_213943984923_item	3518645	et	3	main
ligi	doc_213943984923_item	3518646	et	3	main
just	doc_213943984923_item	3518647	et	3	main
väikeseid	doc_213943984923_item	3518648	et	4	main
linnaelanikke	doc_213943984923_item	3518649	et	3	main
ka	doc_213943984923_item	3518650	et	3	main
liuväli	doc_213943984923_item	3518651	et	3	main
jäetud	doc_213943984923_item	3518594	et	4	main
ees	doc_213943984923_item	3518600	et	4	main
on	doc_213943984923_item	3518622	et	4	main
ei	doc_213943984923_item	3518652	et	4	main
soovijate	doc_213943984923_item	3518654	et	4	main
puudusest	doc_213943984923_item	3518655	et	4	main
enamikule	doc_213943984923_item	3518661	et	3	main
päike	doc_399014257250_item	3518666	et	3	main
inimesed	doc_399014257250_item	3518670	et	3	main
hirmuga	doc_399014257250_item	3518671	et	3	main
vasar	doc_399014257250_item	3518678	et	3	main
naerma	doc_399014257250_item	3518681	et	3	main
aastaid	doc_399014257250_item	3518688	et	4	main
juutidel	doc_399014257250_item	3518691	et	3	main
kirjutatud	doc_399014257250_item	3518709	et	4	main
kaasaarvatud	doc_399014257250_item	3518725	et	4	main
biiblipärane	doc_399014257250_item	3518731	et	4	main
alates	doc_399014257250_item	3518734	et	3	main
omandatud	doc_399014257250_item	3518741	et	4	main
ja	doc_399014257250_item	3518743	et	3	main
kirjutavad	doc_399014257250_item	3518745	et	4	main
nõukogude	doc_399014257250_item	3518763	et	3	main
ikka	doc_399014257250_item	3518771	et	4	main
veel	doc_399014257250_item	3518772	et	4	main
nõukogu	doc_399014257250_item	3518773	et	4	main
on	doc_399014257250_item	3518789	et	4	main
noorema	doc_399014257250_item	3518790	et	4	main
seostada	doc_399014257250_item	3518794	et	3	main
asemel	doc_399014257250_item	3518799	et	4	main
nõukogude	doc_399014257250_item	3518810	et	3	main
on	doc_213943984923_item	3518656	et	4	main
tunda	doc_213943984923_item	3518657	et	3	main
et	doc_213943984923_item	3518658	et	3	main
särav	doc_399014257250_item	3518665	et	4	main
miks	doc_399014257250_item	3518667	et	4	main
täitab	doc_399014257250_item	3518669	et	3	main
aga	doc_399014257250_item	3518672	et	3	main
sirp	doc_399014257250_item	3518676	et	3	main
selgitusprotsessi	doc_399014257250_item	3518683	et	4	main
head	doc_399014257250_item	3518689	et	4	main
mikael	doc_399014257250_item	3518704	et	4	main
raamatus	doc_399014257250_item	3518710	et	4	main
antisemitismi	doc_399014257250_item	3518714	et	4	main
biibel	doc_399014257250_item	3518726	et	4	main
holokaust	doc_399014257250_item	3518737	et	4	main
mõiste	doc_399014257250_item	3518742	et	4	main
1990-ndate	doc_399014257250_item	3518759	et	4	main
aastadel	doc_399014257250_item	3518760	et	4	main
ajalookontseptsiooni	doc_399014257250_item	3518774	et	4	main
mälestuskirjandust	doc_399014257250_item	3518785	et	3	main
põlvkonna	doc_399014257250_item	3518791	et	4	main
on	doc_399014257250_item	3518806	et	4	main
on	doc_399014257250_item	3518812	et	4	main
abil	doc_399014257250_item	3518824	et	4	main
pikem	doc_399014257250_item	3518871	et	4	main
kuna	doc_399014257250_item	3518877	et	3	main
rääkida	doc_399014257250_item	3518889	et	3	main
pool	doc_399014257250_item	3518905	et	4	main
liit	doc_399014257250_item	3518908	et	3	main
maailmasõjas	doc_399014257250_item	3518912	et	3	main
riigid	doc_399014257250_item	3518920	et	3	main
pidi	doc_399014257250_item	3518927	et	4	main
nemad	doc_399014257250_item	3518963	et	3	main
on	doc_399014257250_item	3518964	et	4	main
pidanud	doc_399014257250_item	3518965	et	4	main
tegelema	doc_399014257250_item	3518966	et	3	main
nii	doc_399014257250_item	3518967	et	3	main
palju	doc_399014257250_item	3518968	et	4	main
oma	doc_399014257250_item	3518969	et	4	main
natsiminevikuga	doc_399014257250_item	3518970	et	3	main
miks	doc_399014257249_item	3518975	et	4	main
sümbolina	doc_399014257249_item	3518977	et	3	main
haakrist	doc_399014257249_item	3518979	et	3	main
õudust	doc_399014257249_item	3518982	et	3	main
kõik	doc_399014257249_item	3518994	et	4	main
eeldused	doc_399014257249_item	3518995	et	4	main
oli	doc_399014257249_item	3519010	et	3	main
rõhumise	doc_399014257249_item	3519016	et	4	main
põhjustatud	doc_399014257249_item	3519017	et	4	main
ulatuslikku	doc_399014257249_item	3519023	et	4	main
juudi	doc_399014257249_item	3519024	et	3	main
koos	doc_399014257249_item	3519026	et	4	main
kaanoni	doc_399014257249_item	3519027	et	3	main
ja	doc_399014257249_item	3519028	et	3	main
aastast	doc_399014257249_item	3519032	et	4	main
holokausti	doc_399014257249_item	3519034	et	4	main
piibli	doc_399014257249_item	3519035	et	3	main
nimetus	doc_399014257249_item	3519036	et	4	main
sellest	doc_399014257249_item	3519045	et	4	main
kirjutavad	doc_399014257249_item	3519046	et	4	main
ohvrite	doc_399014257249_item	3519049	et	3	main
nõukogude	doc_399014257249_item	3519051	et	3	main
rahva	doc_399014257249_item	3519053	et	3	main
saatmist	doc_399014257249_item	3519055	et	4	main
on	doc_399014257249_item	3519056	et	4	main
narratiivi	doc_399014257249_item	3519073	et	4	main
vaatamata	doc_399014257249_item	3519076	et	4	main
et	doc_399014257249_item	3519078	et	3	main
endistes	doc_399014257249_item	3519079	et	3	main
terrorismi	doc_399014257249_item	3519085	et	4	main
mälestuskirjandust	doc_399014257249_item	3519087	et	3	main
on	doc_399014257249_item	3519088	et	4	main
alatooniga	doc_399014257249_item	3519099	et	3	main
massimõrvade	doc_399014257250_item	3518674	et	3	main
holokausti	doc_399014257250_item	3518682	et	4	main
käivitumisel	doc_399014257250_item	3518684	et	4	main
oli	doc_399014257250_item	3518685	et	3	main
pärast	doc_399014257250_item	3518686	et	4	main
lähtekohad	doc_399014257250_item	3518690	et	4	main
eksisteeriv	doc_399014257250_item	3518695	et	4	main
väljendada	doc_399014257250_item	3518697	et	3	main
genotsiidide	doc_399014257250_item	3518698	et	3	main
ja	doc_399014257250_item	3518699	et	3	main
represseerimise	doc_399014257250_item	3518700	et	4	main
kaasatoodud	doc_399014257250_item	3518701	et	4	main
valu	doc_399014257250_item	3518702	et	4	main
nagu	doc_399014257250_item	3518703	et	3	main
enckel	doc_399014257250_item	3518705	et	4	main
ohvrid	doc_399014257250_item	3518715	et	3	main
laiemast	doc_399014257250_item	3518719	et	4	main
traditsioonist	doc_399014257250_item	3518720	et	3	main
millel	doc_399014257250_item	3518721	et	3	main
oli	doc_399014257250_item	3518722	et	3	main
oma	doc_399014257250_item	3518723	et	4	main
kaanon	doc_399014257250_item	3518724	et	3	main
on	doc_399014257250_item	3518738	et	4	main
liidu	doc_399014257250_item	3518751	et	3	main
küüditamiseks	doc_399014257250_item	3518761	et	4	main
ja	doc_399014257250_item	3518762	et	3	main
poolt	doc_399014257250_item	3518765	et	4	main
riikide	doc_399014257250_item	3518767	et	3	main
järgi	doc_399014257250_item	3518775	et	4	main
hoolimata	doc_399014257250_item	3518776	et	4	main
sellest	doc_399014257250_item	3518777	et	4	main
et	doc_399014257250_item	3518778	et	3	main
paljudes	doc_399014257250_item	3518779	et	3	main
endistes	doc_399014257250_item	3518780	et	3	main
nõukogu	doc_399014257250_item	3518786	et	4	main
terrori	doc_399014257250_item	3518787	et	3	main
kohta	doc_399014257250_item	3518788	et	4	main
kirjanikud	doc_399014257250_item	3518792	et	3	main
oma	doc_399014257250_item	3518795	et	4	main
vangilaagrikirjanduse	doc_399014257250_item	3518797	et	3	main
kerge	doc_399014257250_item	3518807	et	4	main
valik	doc_399014257250_item	3518808	et	3	main
huumor	doc_399014257250_item	3518811	et	3	main
aastaid	doc_399014257250_item	3518814	et	4	main
saab	doc_399014257250_item	3518825	et	3	main
kirjanik	doc_399014257250_item	3518826	et	3	main
laiema	doc_399014257250_item	3518827	et	4	main
lugejaskonna	doc_399014257250_item	3518828	et	3	main
rahvusvaheline	doc_399014257250_item	3518831	et	4	main
millel	doc_399014257250_item	3518867	et	3	main
ajalugu	doc_399014257250_item	3518872	et	4	main
alates	doc_399014257250_item	3518873	et	3	main
ajalugu	doc_399014257250_item	3518878	et	4	main
on	doc_399014257250_item	3518879	et	4	main
olnud	doc_399014257250_item	3518881	et	4	main
oma	doc_399014257250_item	3518883	et	4	main
on	doc_399014257250_item	3518885	et	4	main
natsism	doc_399014257250_item	3518893	et	4	main
on	doc_399014257250_item	3518894	et	4	main
käsitletud	doc_399014257250_item	3518900	et	4	main
filmides	doc_399014257250_item	3518901	et	4	main
ja	doc_399014257250_item	3518902	et	3	main
polnud	doc_399014257250_item	3518909	et	3	main
ja	doc_399014257250_item	3518913	et	3	main
on	doc_399014257250_item	3518921	et	4	main
teises	doc_399014257250_item	3518922	et	4	main
olukorras	doc_399014257250_item	3518923	et	3	main
mõlgub	doc_399014257249_item	3518973	et	3	main
tekitab	doc_399014257249_item	3518980	et	3	main
kuid	doc_399014257249_item	3518983	et	4	main
sirp	doc_399014257249_item	3518984	et	3	main
ja	doc_399014257249_item	3518985	et	3	main
vasar	doc_399014257249_item	3518986	et	3	main
ajab	doc_399014257249_item	3518987	et	3	main
naerma	doc_399014257249_item	3518988	et	3	main
holokausti	doc_399014257249_item	3518989	et	4	main
enckell	doc_399014257249_item	3519000	et	4	main
nendib	doc_399014257249_item	3519001	et	3	main
imbi	doc_399014257249_item	3519002	et	4	main
raamatus	doc_399014257249_item	3519007	et	4	main
viis	doc_399014257249_item	3519012	et	4	main
massimõrva	doc_399014257249_item	3519014	et	4	main
ohvrid	doc_399014257249_item	3519020	et	3	main
olnud	doc_399014257249_item	3519037	et	4	main
laialdaselt	doc_399014257249_item	3519042	et	4	main
holokausti	doc_399014257249_item	3519047	et	4	main
lapselapsed	doc_399014257249_item	3519050	et	3	main
liidu	doc_399014257249_item	3519052	et	3	main
asumisele	doc_399014257249_item	3519054	et	4	main
all	doc_399014257249_item	3519075	et	3	main
idablokimaades	doc_399014257249_item	3519080	et	4	main
on	doc_399014257249_item	3519081	et	4	main
generatsiooni	doc_399014257249_item	3519090	et	4	main
humoorika	doc_399014257249_item	3519098	et	3	main
läänes	doc_399014257249_item	3519112	et	4	main
osa	doc_399014257250_item	3518718	et	4	main
nimetus	doc_399014257250_item	3518732	et	4	main
40-ndatest	doc_399014257250_item	3518735	et	4	main
aastadest	doc_399014257250_item	3518736	et	4	main
üldiselt	doc_399014257250_item	3518740	et	4	main
sellest	doc_399014257250_item	3518744	et	4	main
juba	doc_399014257250_item	3518746	et	3	main
holokausti	doc_399014257250_item	3518747	et	4	main
läbielanute	doc_399014257250_item	3518748	et	3	main
lastelapsed	doc_399014257250_item	3518749	et	3	main
nõukogude	doc_399014257250_item	3518750	et	3	main
korraldatud	doc_399014257250_item	3518753	et	4	main
olnud	doc_399014257250_item	3518730	et	4	main
shoa	doc_399014257250_item	3518733	et	4	main
tänapäeval	doc_399014257250_item	3518739	et	3	main
poolt	doc_399014257250_item	3518752	et	4	main
rahvade	doc_399014257250_item	3518754	et	4	main
sundteisaldamine	doc_399014257250_item	3518755	et	3	main
nimetati	doc_399014257250_item	3518756	et	4	main
aga	doc_399014257250_item	3518757	et	3	main
alles	doc_399014257250_item	3518758	et	3	main
liidu	doc_399014257250_item	3518764	et	3	main
ajalugu	doc_399014257250_item	3518768	et	4	main
loetakse	doc_399014257250_item	3518769	et	3	main
idablokiriikides	doc_399014257250_item	3518781	et	3	main
on	doc_399014257250_item	3518782	et	4	main
kuna	doc_399014257250_item	3518809	et	3	main
olnud	doc_399014257250_item	3518813	et	4	main
oma	doc_399014257250_item	3518815	et	4	main
liik	doc_399014257250_item	3518816	et	3	main
nii	doc_399014257250_item	3518817	et	3	main
läänes	doc_399014257250_item	3518818	et	4	main
kui	doc_399014257250_item	3518819	et	3	main
ka	doc_399014257250_item	3518820	et	3	main
idas	doc_399014257250_item	3518821	et	3	main
ida-nostalgiaga	doc_399014257250_item	3518822	et	3	main
ning	doc_399014257250_item	3518829	et	3	main
seotud	doc_399014257250_item	3518863	et	4	main
kui	doc_399014257250_item	3518865	et	3	main
on	doc_399014257250_item	3518868	et	4	main
siiski	doc_399014257250_item	3518869	et	4	main
sahalinist	doc_399014257250_item	3518875	et	4	main
mõistetud	doc_399014257250_item	3518895	et	4	main
süüdi	doc_399014257250_item	3518896	et	4	main
ja	doc_399014257250_item	3518897	et	3	main
raamatudes	doc_399014257250_item	3518903	et	4	main
igal	doc_399014257250_item	3518904	et	3	main
liidu	doc_399014257250_item	3518917	et	3	main
poolt	doc_399014257250_item	3518918	et	4	main
kes	doc_399014257250_item	3518926	et	4	main
peab	doc_399014257250_item	3518929	et	4	main
tõlge	doc_399014257249_item	3518971	et	3	main
käimalükkamiseks	doc_399014257249_item	3518991	et	3	main
olid	doc_399014257249_item	3518992	et	4	main
paju	doc_399014257249_item	3519003	et	4	main
et	doc_399014257249_item	3519008	et	3	main
nördimust	doc_399014257249_item	3519018	et	4	main
antisemitismi	doc_399014257249_item	3519019	et	4	main
olid	doc_399014257249_item	3519021	et	4	main
1940	doc_399014257249_item	3519031	et	2	main
on	doc_399014257249_item	3519033	et	4	main
on	doc_399014257249_item	3519040	et	4	main
holokausti	doc_399014257249_item	3519041	et	4	main
mõju	doc_399014257249_item	3519074	et	4	main
hulgaliselt	doc_399014257249_item	3519083	et	4	main
põlvkonna	doc_399014257249_item	3519091	et	4	main
kirjanikud	doc_399014257249_item	3519092	et	3	main
liigitada	doc_399014257249_item	3519094	et	3	main
vangilaagreid	doc_399014257249_item	3519095	et	3	main
käsitleva	doc_399014257249_item	3519096	et	4	main
see	doc_399014257249_item	3519103	et	3	main
lihtne	doc_399014257249_item	3519105	et	3	main
kuna	doc_399014257249_item	3519106	et	3	main
miks	doc_399014257249_item	3519148	et	4	main
rohkem	doc_399014257249_item	3519155	et	4	main
pikema	doc_399014257249_item	3519158	et	4	main
tšehhovi	doc_399014257249_item	3519161	et	2	main
teist	doc_399014257249_item	3519201	et	4	main
on	doc_399014257249_item	3519203	et	4	main
okupatsiooni	doc_399014257249_item	3519205	et	4	main
jubeduse	doc_399014257248_item	3519253	et	4	main
tunde	doc_399014257248_item	3519254	et	4	main
naerma	doc_399014257248_item	3519264	et	3	main
aastaid	doc_399014257248_item	3519273	et	4	main
genotsiididega	doc_399014257248_item	3519279	et	3	main
kannatusi	doc_399014257248_item	3519283	et	4	main
paju	doc_399014257248_item	3519290	et	4	main
antisemitismi	doc_399014257248_item	3519295	et	4	main
suure	doc_399014257248_item	3519298	et	3	main
nöukogude	doc_399014257248_item	3519345	et	4	main
poolt	doc_399014257248_item	3519347	et	4	main
narratiivi	doc_399014257248_item	3519354	et	4	main
kaudu	doc_399014257248_item	3519355	et	3	main
okupeeriutd	doc_399014257250_item	3518766	et	4	main
läänes	doc_399014257250_item	3518770	et	4	main
ilmunud	doc_399014257250_item	3518783	et	4	main
palju	doc_399014257250_item	3518784	et	4	main
tahtnud	doc_399014257250_item	3518793	et	4	main
teosed	doc_399014257250_item	3518796	et	3	main
žanre	doc_399014257250_item	3518798	et	2	main
nostalgilise	doc_399014257250_item	3518800	et	4	main
ja	doc_399014257250_item	3518801	et	3	main
huumorimeelse	doc_399014257250_item	3518802	et	3	main
ida-saksa	doc_399014257250_item	3518803	et	4	main
nostalgiaga	doc_399014257250_item	3518804	et	3	main
see	doc_399014257250_item	3518805	et	3	main
seondumise	doc_399014257250_item	3518823	et	4	main
ka	doc_399014257250_item	3518830	et	3	main
populaarsus	doc_399014257250_item	3518832	et	4	main
on	doc_399014257250_item	3518833	et	4	main
kindlam	doc_399014257250_item	3518834	et	4	main
ega	doc_399014257250_item	3518835	et	3	main
söbralikult	doc_399014257250_item	3518836	et	4	main
nõukogude	doc_399014257250_item	3518837	et	3	main
liidusse	doc_399014257250_item	3518838	et	3	main
suhtunud	doc_399014257250_item	3518839	et	4	main
lugeja	doc_399014257250_item	3518840	et	4	main
pea	doc_399014257250_item	3518841	et	4	main
tunnetama	doc_399014257250_item	3518842	et	3	main
igavaid	doc_399014257250_item	3518843	et	3	main
tundeid	doc_399014257250_item	3518844	et	3	main
sest	doc_399014257250_item	3518845	et	4	main
mälestusi	doc_399014257250_item	3518847	et	4	main
pole	doc_399014257250_item	3518848	et	3	main
nooruse	doc_399014257250_item	3518846	et	4	main
ära	doc_399014257250_item	3518849	et	4	main
vaid	doc_399014257250_item	3518851	et	3	main
uuesti	doc_399014257250_item	3518852	et	3	main
kullatud	doc_399014257250_item	3518853	et	4	main
miks	doc_399014257250_item	3518854	et	4	main
määritud	doc_399014257250_item	3518850	et	4	main
ida-saksa	doc_399014257250_item	3518855	et	4	main
nostalgia	doc_399014257250_item	3518856	et	4	main
tõmbab	doc_399014257250_item	3518857	et	3	main
rohkem	doc_399014257250_item	3518858	et	4	main
poole	doc_399014257250_item	3518859	et	4	main
ja	doc_399014257250_item	3518860	et	3	main
on	doc_399014257250_item	3518861	et	4	main
rohkem	doc_399014257250_item	3518862	et	4	main
olemas	doc_399014257250_item	3518870	et	4	main
1895	doc_399014257250_item	3518876	et	2	main
alati	doc_399014257250_item	3518880	et	4	main
ajalugu	doc_399014257250_item	3518884	et	4	main
meediaga	doc_399014257250_item	3518864	et	4	main
vangilaagrikirjandus	doc_399014257250_item	3518866	et	3	main
tšehovi	doc_399014257250_item	3518874	et	2	main
võitjate	doc_399014257250_item	3518882	et	4	main
kaotajate	doc_399014257250_item	3518886	et	4	main
tegudest	doc_399014257250_item	3518887	et	3	main
on	doc_399014257250_item	3518899	et	4	main
maailmas	doc_399014257250_item	3518906	et	3	main
nõukogude	doc_399014257250_item	3518907	et	3	main
okupeeritud	doc_399014257250_item	3518919	et	4	main
oma	doc_399014257250_item	3518932	et	4	main
ajalooga	doc_399014257250_item	3518933	et	4	main
saksamaa	doc_399014257250_item	3518934	et	4	main
selgitab	doc_399014257250_item	3518935	et	3	main
suure	doc_399014257250_item	3518936	et	3	main
kiiruga	doc_399014257250_item	3518937	et	4	main
oma	doc_399014257250_item	3518938	et	4	main
suhteid	doc_399014257250_item	3518939	et	3	main
ka	doc_399014257250_item	3518940	et	3	main
ida-saksamaaga	doc_399014257250_item	3518941	et	3	main
ja	doc_399014257250_item	3518942	et	3	main
ida-saksa	doc_399014257250_item	3518943	et	4	main
nostalgia	doc_399014257250_item	3518944	et	4	main
on	doc_399014257250_item	3518945	et	4	main
hakanud	doc_399014257250_item	3518946	et	4	main
lõpuks	doc_399014257250_item	3518947	et	4	main
saama	doc_399014257250_item	3518948	et	4	main
ka	doc_399014257250_item	3518949	et	3	main
kriitilisi	doc_399014257250_item	3518950	et	3	main
vorme	doc_399014257250_item	3518951	et	3	main
äkki	doc_399014257250_item	3518952	et	3	main
sakslastel	doc_399014257250_item	3518953	et	3	main
on	doc_399014257250_item	3518954	et	4	main
võib-olla	doc_399014257250_item	3518955	et	3	main
rohkem	doc_399014257250_item	3518956	et	4	main
meetodeid	doc_399014257250_item	3518957	et	3	main
käsitleda	doc_399014257250_item	3518958	et	3	main
oma	doc_399014257250_item	3518959	et	4	main
suhed	doc_399014257250_item	3518960	et	4	main
kommunismi	doc_399014257250_item	3518961	et	4	main
kuna	doc_399014257250_item	3518962	et	3	main
suudetud	doc_399014257250_item	3518888	et	4	main
hitleri	doc_399014257250_item	3518890	et	4	main
teod	doc_399014257250_item	3518891	et	4	main
ja	doc_399014257250_item	3518892	et	3	main
neid	doc_399014257250_item	3518898	et	4	main
kaotajaks	doc_399014257250_item	3518910	et	4	main
teises	doc_399014257250_item	3518911	et	4	main
selle	doc_399014257250_item	3518914	et	4	main
tõttu	doc_399014257250_item	3518915	et	4	main
nõukogude	doc_399014257250_item	3518916	et	3	main
kui	doc_399014257250_item	3518924	et	3	main
saksamaa	doc_399014257250_item	3518925	et	4	main
ja	doc_399014257250_item	3518928	et	3	main
veelgi	doc_399014257250_item	3518930	et	4	main
maadlema	doc_399014257250_item	3518931	et	3	main
meeles	doc_399014257249_item	3518972	et	3	main
lahendusprotsessi	doc_399014257249_item	3518990	et	4	main
pärast	doc_399014257249_item	3518996	et	4	main
1940	doc_399014257249_item	3518997	et	2	main
juutidel	doc_399014257249_item	3519009	et	3	main
juba	doc_399014257249_item	3519011	et	3	main
osa	doc_399014257249_item	3519022	et	4	main
tarditsiooni	doc_399014257249_item	3519025	et	4	main
piibliga	doc_399014257249_item	3519029	et	3	main
tänaseks	doc_399014257249_item	3519039	et	4	main
ning	doc_399014257249_item	3519044	et	3	main
kogenute	doc_399014257249_item	3519048	et	4	main
küüditamisteks	doc_399014257249_item	3519059	et	4	main
alles	doc_399014257249_item	3519060	et	3	main
osas	doc_399014257249_item	3519071	et	4	main
sellele	doc_399014257249_item	3519077	et	4	main
nõukogude	doc_399014257249_item	3519084	et	3	main
käsitlevat	doc_399014257249_item	3519086	et	4	main
soovinud	doc_399014257249_item	3519093	et	4	main
nostalgia	doc_399014257249_item	3519100	et	4	main
huumor	doc_399014257249_item	3519108	et	3	main
tagatud	doc_399014257249_item	3519130	et	4	main
nõukogude	doc_399014257249_item	3519131	et	3	main
tundest	doc_399014257249_item	3519139	et	4	main
kuna	doc_399014257249_item	3519140	et	3	main
on	doc_399014257249_item	3519149	et	4	main
minevikuihaldus	doc_399014257249_item	3519150	et	3	main
kaasakiskuvam	doc_399014257249_item	3519151	et	4	main
liit	doc_399014257249_item	3519198	et	3	main
oskavad	doc_399014257249_item	3519232	et	4	main
kommunismi	doc_399014257249_item	3519234	et	4	main
pädevusega	doc_399014257249_item	3519235	et	4	main
kuna	doc_399014257249_item	3519236	et	3	main
nad	doc_399014257249_item	3519237	et	3	main
on	doc_399014257249_item	3519238	et	4	main
juurdlema	doc_399014257249_item	3519244	et	3	main
kuid	doc_399014257248_item	3519255	et	4	main
teine	doc_399014257248_item	3519256	et	3	main
massimörva	doc_399014257248_item	3519257	et	4	main
sümbol	doc_399014257248_item	3519258	et	3	main
sirp	doc_399014257248_item	3519259	et	3	main
ja	doc_399014257248_item	3519260	et	3	main
vasar	doc_399014257248_item	3519261	et	3	main
paneb	doc_399014257248_item	3519262	et	3	main
kaasnenud	doc_399014257248_item	3519282	et	4	main
mikael	doc_399014257248_item	3519285	et	4	main
raamatus	doc_399014257248_item	3519291	et	4	main
ohvrid	doc_399014257248_item	3519296	et	3	main
osa	doc_399014257248_item	3519299	et	4	main
traditsioonist	doc_399014257248_item	3519300	et	3	main
millel	doc_399014257248_item	3519301	et	3	main
oli	doc_399014257248_item	3519302	et	3	main
oma	doc_399014257248_item	3519303	et	4	main
hakati	doc_399014257248_item	3519339	et	3	main
ilmunud	doc_399014257248_item	3519361	et	4	main
pölvkonna	doc_399014257248_item	3519368	et	4	main
ongi	doc_399014257248_item	3519382	et	4	main
zanriks	doc_399014257248_item	3519393	et	4	main
nii	doc_399014257248_item	3519394	et	3	main
lääne-kui	doc_399014257248_item	3519395	et	3	main
ka	doc_399014257248_item	3519396	et	3	main
rohkem	doc_399014257248_item	3519441	et	4	main
siiski	doc_399014257248_item	3519449	et	4	main
väärtustab	doc_399014257248_item	3519460	et	3	main
vöitjamaade	doc_399014257248_item	3519462	et	4	main
rahvuslikku	doc_399014257248_item	3519474	et	4	main
jäävad	doc_399014257249_item	3519214	et	4	main
minevikuvarjud	doc_399014257249_item	3519215	et	3	main
jälitama	doc_399014257249_item	3519216	et	3	main
saksamaa	doc_399014257249_item	3519217	et	4	main
on	doc_399014257249_item	3519218	et	4	main
lepitamas	doc_399014257249_item	3519219	et	3	main
suhteid	doc_399014257249_item	3519220	et	3	main
ida-saksamaaga	doc_399014257249_item	3519221	et	3	main
ning	doc_399014257249_item	3519222	et	3	main
ostalgiasse	doc_399014257249_item	3519223	et	4	main
osatakse	doc_399014257249_item	3519224	et	4	main
lõpuks	doc_399014257249_item	3519225	et	4	main
kriitilise	doc_399014257249_item	3519226	et	3	main
pilguga	doc_399014257249_item	3519227	et	3	main
pilguga	doc_399014257249_item	3519228	et	3	main
suhtuda	doc_399014257249_item	3519229	et	3	main
ilmselt	doc_399014257249_item	3519230	et	4	main
sakslased	doc_399014257249_item	3519231	et	3	main
päike	doc_399014257249_item	3518974	et	3	main
massimõrva	doc_399014257249_item	3518976	et	4	main
olev	doc_399014257249_item	3518978	et	4	main
meis	doc_399014257249_item	3518981	et	3	main
olemas	doc_399014257249_item	3518993	et	4	main
aastaid	doc_399014257249_item	3518998	et	4	main
mikael	doc_399014257249_item	3518999	et	4	main
tõrjutud	doc_399014257249_item	3519004	et	4	main
mälestused	doc_399014257249_item	3519005	et	4	main
2006	doc_399014257249_item	3519006	et	2	main
väljendamaks	doc_399014257249_item	3519013	et	3	main
ja	doc_399014257249_item	3519015	et	3	main
alates	doc_399014257249_item	3519030	et	3	main
shoah	doc_399014257249_item	3519038	et	4	main
teadvustatud	doc_399014257249_item	3519043	et	4	main
hakatud	doc_399014257249_item	3519057	et	4	main
nimetama	doc_399014257249_item	3519058	et	3	main
90	doc_399014257249_item	3519061	et	2	main
aastatel	doc_399014257249_item	3519062	et	4	main
ning	doc_399014257249_item	3519063	et	3	main
okupatsiooni	doc_399014257249_item	3519064	et	4	main
all	doc_399014257249_item	3519065	et	3	main
olnud	doc_399014257249_item	3519066	et	4	main
maade	doc_399014257249_item	3519067	et	3	main
ajaloost	doc_399014257249_item	3519068	et	4	main
suures	doc_399014257249_item	3519070	et	3	main
loetakse	doc_399014257249_item	3519069	et	3	main
nõukogude	doc_399014257249_item	3519072	et	3	main
ilmunud	doc_399014257249_item	3519082	et	4	main
noorema	doc_399014257249_item	3519089	et	4	main
loomingu	doc_399014257249_item	3519097	et	3	main
kategooriasse	doc_399014257249_item	3519101	et	3	main
on	doc_399014257249_item	3519104	et	4	main
nõukogude	doc_399014257249_item	3519107	et	3	main
on	doc_399014257249_item	3519109	et	4	main
olnud	doc_399014257249_item	3519110	et	4	main
nii	doc_399014257249_item	3519111	et	3	main
idas	doc_399014257249_item	3519115	et	3	main
omaette	doc_399014257249_item	3519116	et	3	main
kirjanduse	doc_399014257249_item	3519117	et	3	main
liik	doc_399014257249_item	3519118	et	3	main
nostalgiat	doc_399014257249_item	3519119	et	3	main
rõhutava	doc_399014257249_item	3519120	et	4	main
kirjaniku	doc_399014257249_item	3519121	et	3	main
lugejaskond	doc_399014257249_item	3519122	et	3	main
on	doc_399014257249_item	3519123	et	4	main
ulatuslik	doc_399014257249_item	3519124	et	3	main
ja	doc_399014257249_item	3519125	et	3	main
ka	doc_399014257249_item	3519126	et	3	main
rahvusvaheline	doc_399014257249_item	3519127	et	4	main
populaarsus	doc_399014257249_item	3519128	et	4	main
on	doc_399014257249_item	3519129	et	4	main
kuid	doc_399014257249_item	3519102	et	4	main
lugeja	doc_399014257249_item	3519135	et	4	main
nooruspõlve	doc_399014257249_item	3519141	et	4	main
mälestusi	doc_399014257249_item	3519142	et	4	main
ei	doc_399014257249_item	3519143	et	4	main
rüvetata	doc_399014257249_item	3519144	et	3	main
vaid	doc_399014257249_item	3519145	et	3	main
kullatakse	doc_399014257249_item	3519146	et	4	main
üle	doc_399014257249_item	3519147	et	3	main
äratab	doc_399014257249_item	3519153	et	3	main
kui	doc_399014257249_item	3519157	et	3	main
ajalugu	doc_399014257249_item	3519170	et	4	main
on	doc_399014257249_item	3519171	et	4	main
alati	doc_399014257249_item	3519172	et	4	main
võitjate	doc_399014257249_item	3519173	et	4	main
kirjutatud	doc_399014257249_item	3519174	et	4	main
ning	doc_399014257249_item	3519175	et	3	main
kaotajate	doc_399014257249_item	3519176	et	4	main
tegudest	doc_399014257249_item	3519177	et	3	main
vaikidakse	doc_399014257249_item	3519178	et	4	main
hitleri	doc_399014257249_item	3519179	et	4	main
kuriteod	doc_399014257249_item	3519180	et	4	main
tegevus	doc_399014257249_item	3519181	et	4	main
ja	doc_399014257249_item	3519182	et	3	main
rahvussotsialism	doc_399014257249_item	3519183	et	3	main
on	doc_399014257249_item	3519184	et	4	main
hukka	doc_399014257249_item	3519185	et	4	main
mõistetud	doc_399014257249_item	3519186	et	4	main
ning	doc_399014257249_item	3519187	et	3	main
leidnud	doc_399014257249_item	3519188	et	4	main
kajastust	doc_399014257249_item	3519189	et	4	main
lugematutes	doc_399014257249_item	3519190	et	4	main
linateostes	doc_399014257249_item	3519191	et	3	main
ja	doc_399014257249_item	3519192	et	3	main
raamatutes	doc_399014257249_item	3519193	et	3	main
ümber	doc_399014257249_item	3519194	et	3	main
maailma	doc_399014257249_item	3519195	et	4	main
kuna	doc_399014257249_item	3519196	et	3	main
kui	doc_399014257249_item	3519113	et	3	main
ka	doc_399014257249_item	3519114	et	3	main
liitu	doc_399014257249_item	3519132	et	4	main
sõbralikkusega	doc_399014257249_item	3519133	et	4	main
on	doc_399014257249_item	3519136	et	4	main
meedias	doc_399014257249_item	3519154	et	4	main
huvi	doc_399014257249_item	3519156	et	4	main
ajalooga-	doc_399014257249_item	3519159	et	4	main
alates	doc_399014257249_item	3519160	et	3	main
sahhalini	doc_399014257249_item	3519162	et	4	main
saarest	doc_399014257249_item	3519163	et	4	main
1895	doc_399014257249_item	3519164	et	2	main
vangilaagreid	doc_399014257249_item	3519165	et	3	main
käsitlev	doc_399014257249_item	3519166	et	4	main
kirjandus	doc_399014257249_item	3519167	et	3	main
sellepärast	doc_399014257249_item	3519168	et	3	main
et	doc_399014257249_item	3519169	et	3	main
ei	doc_399014257249_item	3519199	et	4	main
suhtuda	doc_399014257249_item	3519233	et	3	main
sunnitud	doc_399014257249_item	3519240	et	4	main
natsimineviku	doc_399014257249_item	3519241	et	3	main
kallal	doc_399014257249_item	3519242	et	4	main
suhtuv	doc_399014257249_item	3519134	et	4	main
prii	doc_399014257249_item	3519137	et	4	main
ebameeldivuse	doc_399014257249_item	3519138	et	4	main
ja	doc_399014257249_item	3519152	et	3	main
kaotanud	doc_399014257249_item	3519200	et	4	main
nõukogude	doc_399014257249_item	3519204	et	3	main
all	doc_399014257249_item	3519206	et	3	main
kui	doc_399014257249_item	3519211	et	3	main
saksamaa	doc_399014257249_item	3519212	et	4	main
keda	doc_399014257249_item	3519213	et	4	main
ohtralt	doc_399014257249_item	3519243	et	4	main
tõlge	doc_399014257248_item	3519245	et	3	main
särav	doc_399014257248_item	3519247	et	4	main
päike	doc_399014257248_item	3519248	et	3	main
holokausti	doc_399014257248_item	3519265	et	4	main
oli	doc_399014257248_item	3519268	et	3	main
lähtekoht	doc_399014257248_item	3519270	et	3	main
juutidel	doc_399014257248_item	3519274	et	3	main
tapa	doc_399014257248_item	3519277	et	4	main
ja	doc_399014257248_item	3519280	et	3	main
törjutud	doc_399014257248_item	3519292	et	4	main
mäelstused	doc_399014257248_item	3519293	et	4	main
2006	doc_399014257248_item	3519294	et	2	main
moodustasid	doc_399014257248_item	3519297	et	4	main
alles	doc_399014257248_item	3519342	et	3	main
on	doc_399014257248_item	3519360	et	4	main
nõukogude	doc_399014257249_item	3519197	et	3	main
maailmasõda	doc_399014257249_item	3519202	et	4	main
kannatanud	doc_399014257249_item	3519207	et	4	main
maade	doc_399014257249_item	3519208	et	3	main
olukord	doc_399014257249_item	3519209	et	3	main
teine	doc_399014257249_item	3519210	et	3	main
olnud	doc_399014257249_item	3519239	et	4	main
mötetes	doc_399014257248_item	3519246	et	4	main
miks	doc_399014257248_item	3519249	et	4	main
haakrist	doc_399014257248_item	3519250	et	3	main
tekitab	doc_399014257248_item	3519251	et	3	main
inimestes	doc_399014257248_item	3519252	et	3	main
inimesed	doc_399014257248_item	3519263	et	3	main
käivitumisel	doc_399014257248_item	3519267	et	4	main
hea	doc_399014257248_item	3519269	et	4	main
juba	doc_399014257248_item	3519276	et	3	main
väljendamaks	doc_399014257248_item	3519278	et	3	main
tagakiusamisega	doc_399014257248_item	3519281	et	3	main
millele	doc_399014257248_item	3519284	et	3	main
enckell	doc_399014257248_item	3519286	et	4	main
juhib	doc_399014257248_item	3519287	et	3	main
tähelepanu	doc_399014257248_item	3519288	et	4	main
küüditamiseks	doc_399014257248_item	3519341	et	4	main
liidu	doc_399014257248_item	3519346	et	3	main
okupeeritud	doc_399014257248_item	3519348	et	4	main
maade	doc_399014257248_item	3519349	et	3	main
maades	doc_399014257248_item	3519359	et	4	main
terrorit	doc_399014257248_item	3519364	et	3	main
memuaare	doc_399014257248_item	3519366	et	3	main
on	doc_399014257248_item	3519370	et	4	main
tahtnud	doc_399014257248_item	3519371	et	4	main
lisada	doc_399014257248_item	3519372	et	3	main
koonduslaagri	doc_399014257248_item	3519373	et	3	main
kirjandusliku	doc_399014257248_item	3519374	et	3	main
see	doc_399014257248_item	3519381	et	3	main
üpris	doc_399014257248_item	3519383	et	3	main
kuna	doc_399014257248_item	3519385	et	3	main
on	doc_399014257248_item	3519388	et	4	main
ole	doc_399014257248_item	3519426	et	4	main
rohkem	doc_399014257248_item	3519432	et	4	main
väärtustama	doc_399014257248_item	3519433	et	3	main
on	doc_399014257248_item	3519436	et	4	main
ja	doc_399014257248_item	3519438	et	3	main
poolt	doc_399014257248_item	3519440	et	4	main
on	doc_399014257248_item	3519448	et	4	main
ajalugu	doc_399014257248_item	3519459	et	4	main
üksnes	doc_399014257248_item	3519461	et	3	main
ajalugu	doc_399014257248_item	3519463	et	4	main
on	doc_399014257248_item	3519464	et	4	main
kaotajate	doc_399014257248_item	3519468	et	4	main
maade	doc_399014257248_item	3519469	et	3	main
tegudest	doc_399014257248_item	3519470	et	3	main
hitleri	doc_399014257248_item	3519471	et	4	main
on	doc_399014257248_item	3519476	et	4	main
möistetud	doc_399014257248_item	3519477	et	4	main
käsitlenud	doc_399014257248_item	3519483	et	4	main
arvukates	doc_399014257248_item	3519486	et	4	main
poolt	doc_399014257248_item	3519503	et	4	main
olukord	doc_399014257248_item	3519506	et	3	main
saksamaa	doc_399014257248_item	3519509	et	4	main
on	doc_399014257248_item	3519511	et	4	main
jätkuvalt	doc_399014257248_item	3519512	et	4	main
hoogsalt	doc_399014257248_item	3519519	et	4	main
ida-saksamaaga	doc_399014257248_item	3519521	et	3	main
on	doc_237632014900_item	3519554	et	4	main
bakterid	doc_237632014900_item	3519557	et	3	main
uus	doc_237632014900_item	3519561	et	3	main
leid	doc_237632014900_item	3519574	et	4	main
oli	doc_237632014900_item	3519575	et	3	main
segus	doc_237632014900_item	3519580	et	3	main
olid	doc_237632014900_item	3519582	et	4	main
jää	doc_237632014900_item	3519584	et	4	main
olemus	doc_237632014900_item	3519596	et	3	main
mis	doc_237632014900_item	3519609	et	4	main
uurida	doc_237632014900_item	3519612	et	3	main
mehhikos	doc_237632014901_item	3519651	et	4	main
mexico	doc_237632014901_item	3519659	et	4	main
äärelinna	doc_237632014901_item	3519660	et	4	main
suur	doc_237632014901_item	3519665	et	3	main
külgede	doc_237632014901_item	3519681	et	4	main
andmed	doc_237632014901_item	3519686	et	3	main
selgitamisprotsessi	doc_399014257248_item	3519266	et	4	main
pärast	doc_399014257248_item	3519271	et	4	main
1940-ndaid	doc_399014257248_item	3519272	et	4	main
oli	doc_399014257248_item	3519275	et	3	main
imbi	doc_399014257248_item	3519289	et	4	main
kaanon	doc_399014257248_item	3519304	et	3	main
kaasa	doc_399014257248_item	3519305	et	4	main
arvatud	doc_399014257248_item	3519306	et	4	main
piibel	doc_399014257248_item	3519307	et	4	main
juutide	doc_399014257248_item	3519308	et	3	main
genotsiidil	doc_399014257248_item	3519309	et	3	main
on	doc_399014257248_item	3519310	et	4	main
olnud	doc_399014257248_item	3519311	et	4	main
oma	doc_399014257248_item	3519312	et	4	main
piibellik	doc_399014257248_item	3519313	et	3	main
nimi	doc_399014257248_item	3519314	et	3	main
shoa	doc_399014257248_item	3519315	et	4	main
alates	doc_399014257248_item	3519316	et	3	main
1940-aastatest	doc_399014257248_item	3519317	et	4	main
tänapäeval	doc_399014257248_item	3519318	et	3	main
on	doc_399014257248_item	3519319	et	4	main
holokaust	doc_399014257248_item	3519320	et	4	main
üleüldiselt	doc_399014257248_item	3519321	et	4	main
omaks	doc_399014257248_item	3519322	et	4	main
vöetud	doc_399014257248_item	3519323	et	4	main
ja	doc_399014257248_item	3519324	et	3	main
sellest	doc_399014257248_item	3519325	et	4	main
kirjutavad	doc_399014257248_item	3519326	et	4	main
juba	doc_399014257248_item	3519327	et	3	main
holokausti	doc_399014257248_item	3519328	et	4	main
läbielanute	doc_399014257248_item	3519329	et	3	main
lapselapsed	doc_399014257248_item	3519330	et	3	main
nöukogude	doc_399014257248_item	3519331	et	4	main
liidu	doc_399014257248_item	3519332	et	3	main
poolt	doc_399014257248_item	3519333	et	4	main
sundviisil	doc_399014257248_item	3519334	et	3	main
läbi	doc_399014257248_item	3519335	et	4	main
viidud	doc_399014257248_item	3519336	et	4	main
rahvastiku	doc_399014257248_item	3519337	et	3	main
ümberpaigutusi	doc_399014257248_item	3519338	et	3	main
nimetama	doc_399014257248_item	3519340	et	3	main
1990-aastatel	doc_399014257248_item	3519343	et	4	main
ja	doc_399014257248_item	3519344	et	3	main
ajalugu	doc_399014257248_item	3519350	et	4	main
läänemaades	doc_399014257248_item	3519352	et	4	main
nöukogude-aegse	doc_399014257248_item	3519353	et	3	main
kuigi	doc_399014257248_item	3519356	et	3	main
endistes	doc_399014257248_item	3519357	et	3	main
idabloki	doc_399014257248_item	3519358	et	3	main
nöukogude-aegset	doc_399014257248_item	3519363	et	3	main
zanri	doc_399014257248_item	3519375	et	4	main
peetud	doc_399014257248_item	3519391	et	4	main
omaette	doc_399014257248_item	3519392	et	3	main
moodustab	doc_399014257248_item	3519399	et	3	main
rüvetatud	doc_399014257248_item	3519427	et	4	main
miks	doc_399014257248_item	3519434	et	4	main
loetakse	doc_399014257248_item	3519351	et	3	main
käsitlevaid	doc_399014257248_item	3519365	et	4	main
noorema	doc_399014257248_item	3519367	et	4	main
kirjanikud	doc_399014257248_item	3519369	et	3	main
idanostalgiat	doc_399014257248_item	3519380	et	3	main
kerge	doc_399014257248_item	3519384	et	4	main
huumorit	doc_399014257248_item	3519387	et	3	main
juba	doc_399014257248_item	3519389	et	3	main
aastakümneid	doc_399014257248_item	3519390	et	4	main
idanostalgia	doc_399014257248_item	3519398	et	4	main
suure	doc_399014257248_item	3519400	et	3	main
osa	doc_399014257248_item	3519401	et	4	main
kirjaniku	doc_399014257248_item	3519402	et	3	main
lugejaskonnast	doc_399014257248_item	3519403	et	4	main
ja	doc_399014257248_item	3519404	et	3	main
poolehoid	doc_399014257248_item	3519405	et	3	main
on	doc_399014257248_item	3519406	et	4	main
tagatud	doc_399014257248_item	3519407	et	4	main
ka	doc_399014257248_item	3519408	et	3	main
rahvusvahelisel	doc_399014257248_item	3519409	et	4	main
tasemel	doc_399014257248_item	3519410	et	3	main
lugeja	doc_399014257248_item	3519411	et	4	main
kes	doc_399014257248_item	3519412	et	4	main
on	doc_399014257248_item	3519413	et	4	main
suhtunud	doc_399014257248_item	3519414	et	4	main
nöukogude	doc_399014257248_item	3519415	et	4	main
liitu	doc_399014257248_item	3519416	et	4	main
söbralikult	doc_399014257248_item	3519417	et	4	main
ei	doc_399014257248_item	3519418	et	4	main
pea	doc_399014257248_item	3519419	et	4	main
kogema	doc_399014257248_item	3519420	et	3	main
ebameeldivaid	doc_399014257248_item	3519421	et	3	main
tundeid	doc_399014257248_item	3519422	et	3	main
nooruse	doc_399014257248_item	3519423	et	4	main
mälestusi	doc_399014257248_item	3519424	et	4	main
ei	doc_399014257248_item	3519425	et	4	main
rohkelt	doc_399014257248_item	3519362	et	4	main
asemel	doc_399014257248_item	3519376	et	4	main
nostalgilist	doc_399014257248_item	3519377	et	4	main
ja	doc_399014257248_item	3519378	et	3	main
humoorikat	doc_399014257248_item	3519379	et	3	main
nöukogude-aegset	doc_399014257248_item	3519386	et	3	main
idamaades	doc_399014257248_item	3519397	et	4	main
neid	doc_399014257248_item	3519429	et	4	main
idanostalgia	doc_399014257248_item	3519435	et	4	main
kui	doc_399014257248_item	3519443	et	3	main
käsitlev	doc_399014257248_item	3519445	et	4	main
töestab	doc_399014257248_item	3519456	et	4	main
seda	doc_399014257248_item	3519457	et	3	main
kuna	doc_399014257248_item	3519458	et	3	main
räägitud	doc_399014257248_item	3519466	et	4	main
teemasid	doc_399014257248_item	3519485	et	3	main
on	doc_399014257248_item	3519500	et	4	main
olnud	doc_399014257248_item	3519501	et	4	main
okupeeritud	doc_399014257248_item	3519504	et	4	main
viimaks	doc_399014257248_item	3519525	et	4	main
vaid	doc_399014257248_item	3519428	et	3	main
on	doc_399014257248_item	3519430	et	4	main
hakatud	doc_399014257248_item	3519431	et	4	main
köitvam	doc_399014257248_item	3519437	et	4	main
meedia	doc_399014257248_item	3519439	et	4	main
juhitavam	doc_399014257248_item	3519442	et	4	main
koonduslaagreid	doc_399014257248_item	3519444	et	3	main
millel	doc_399014257248_item	3519447	et	3	main
ajalugu	doc_399014257248_item	3519451	et	4	main
tsehhovi	doc_399014257248_item	3519453	et	4	main
romaan	doc_399014257248_item	3519454	et	3	main
sahalin	doc_399014257248_item	3519455	et	4	main
siiski	doc_399014257248_item	3519465	et	4	main
ka	doc_399014257248_item	3519467	et	3	main
sotsialismi	doc_399014257248_item	3519475	et	4	main
on	doc_399014257248_item	3519482	et	4	main
olnud	doc_399014257248_item	3519493	et	4	main
ii	doc_399014257248_item	3519494	et	4	main
ms	doc_399014257248_item	3519495	et	4	main
kui	doc_399014257248_item	3519508	et	3	main
kes	doc_399014257248_item	3519510	et	4	main
vöitlema	doc_399014257248_item	3519514	et	4	main
oma	doc_399014257248_item	3519515	et	4	main
minevikuga	doc_399014257248_item	3519516	et	3	main
saksamaa	doc_399014257248_item	3519517	et	4	main
klaarib	doc_399014257248_item	3519518	et	3	main
on	doc_399014257248_item	3519524	et	4	main
ometi	doc_399014257248_item	3519526	et	3	main
nii	doc_399014257248_item	3519545	et	3	main
palju	doc_399014257248_item	3519546	et	4	main
tööd	doc_399014257248_item	3519547	et	4	main
natsiliku	doc_399014257248_item	3519548	et	4	main
mineviku	doc_399014257248_item	3519549	et	3	main
kallal	doc_399014257248_item	3519550	et	4	main
tõlge	doc_237632014900_item	3519552	et	3	main
kinkis	doc_237632014900_item	3519559	et	3	main
mis	doc_237632014900_item	3519568	et	4	main
elada	doc_237632014900_item	3519573	et	3	main
leidud	doc_237632014900_item	3519576	et	3	main
kolmekilomeetrilise	doc_237632014900_item	3519583	et	4	main
pinnal	doc_237632014900_item	3519587	et	3	main
ja	doc_237632014900_item	3519589	et	3	main
arvavad	doc_237632014900_item	3519592	et	4	main
et	doc_237632014900_item	3519593	et	3	main
termofiili	doc_237632014900_item	3519594	et	4	main
on	doc_237632014900_item	3519605	et	4	main
aitavad	doc_237632014900_item	3519610	et	4	main
tõlge	doc_237632014901_item	3519650	et	3	main
iztapalapa	doc_237632014901_item	3519661	et	4	main
indiaanlaste	doc_237632014901_item	3519666	et	3	main
6	doc_237632014901_item	3519670	et	2	main
laius	doc_237632014901_item	3519682	et	4	main
on	doc_237632014901_item	3519683	et	4	main
või	doc_237632014901_item	3519698	et	4	main
kultuuritempel	doc_237632014901_item	3519699	et	3	main
keraamika	doc_237632014901_item	3519706	et	4	main
fragmendid	doc_237632014901_item	3519707	et	3	main
ja	doc_237632014901_item	3519708	et	3	main
väikeste	doc_237632014901_item	3519709	et	4	main
selgus	doc_237632014901_item	3519724	et	4	main
et	doc_237632014901_item	3519725	et	3	main
puutuvad	doc_237632014901_item	3519728	et	4	main
loomuliku	doc_237632014901_item	3519729	et	3	main
künkaga	doc_237632014901_item	3519730	et	3	main
kokku	doc_237632014901_item	3519731	et	3	main
kohast	doc_237632014901_item	3519732	et	4	main
kus	doc_237632014901_item	3519733	et	3	main
asub	doc_237632014901_item	3519734	et	3	main
puidust	doc_237632014901_item	3519772	et	3	main
stseeni	doc_237632014901_item	3519780	et	4	main
vaatuste	doc_237632014901_item	3519805	et	3	main
korjagina	doc_237632014902_item	3519821	et	4	main
stilist	doc_237632014902_item	3519825	et	3	main
ajalehe	doc_237632014902_item	3519831	et	3	main
lugejatele	doc_237632014902_item	3519832	et	4	main
kirjandus	doc_399014257248_item	3519446	et	3	main
pikem	doc_399014257248_item	3519450	et	4	main
juba	doc_399014257248_item	3519452	et	3	main
tegevus	doc_399014257248_item	3519472	et	4	main
ja	doc_399014257248_item	3519473	et	3	main
hukka	doc_399014257248_item	3519478	et	4	main
ei	doc_399014257248_item	3519492	et	4	main
pool	doc_399014257248_item	3519497	et	4	main
ja	doc_399014257248_item	3519498	et	3	main
seepärast	doc_399014257248_item	3519499	et	3	main
teine	doc_399014257248_item	3519507	et	3	main
suhteid	doc_399014257248_item	3519520	et	3	main
idanostalgia	doc_399014257248_item	3519523	et	4	main
omandanud	doc_399014257248_item	3519527	et	4	main
kriitilised	doc_399014257248_item	3519528	et	3	main
vormid	doc_399014257248_item	3519529	et	4	main
vöib	doc_399014257248_item	3519530	et	4	main
olla	doc_399014257248_item	3519531	et	3	main
sakslastel	doc_399014257248_item	3519532	et	3	main
on	doc_399014257248_item	3519533	et	4	main
rohkem	doc_399014257248_item	3519534	et	4	main
vahendeid	doc_399014257248_item	3519535	et	3	main
käsitlemaks	doc_399014257248_item	3519536	et	3	main
oma	doc_399014257248_item	3519537	et	4	main
suhtumist	doc_399014257248_item	3519538	et	4	main
kommunismi	doc_399014257248_item	3519539	et	4	main
kuna	doc_399014257248_item	3519540	et	3	main
nad	doc_399014257248_item	3519541	et	3	main
on	doc_399014257248_item	3519542	et	4	main
pidanud	doc_399014257248_item	3519543	et	4	main
tegema	doc_399014257248_item	3519544	et	3	main
leidud	doc_237632014900_item	3519555	et	3	main
antarktika	doc_237632014900_item	3519558	et	4	main
teadlastele	doc_237632014900_item	3519560	et	3	main
avastus	doc_237632014900_item	3519562	et	4	main
põhjal	doc_237632014900_item	3519572	et	4	main
ja	doc_237632014900_item	3519578	et	3	main
puurimised	doc_237632014900_item	3519585	et	4	main
vene	doc_237632014900_item	3519588	et	4	main
teadlased	doc_237632014900_item	3519591	et	3	main
rääkib	doc_237632014900_item	3519597	et	4	main
hüdrotermiliste	doc_237632014900_item	3519599	et	4	main
aukudest	doc_237632014900_item	3519600	et	3	main
vesistu	doc_237632014900_item	3519601	et	4	main
võetud	doc_237632014900_item	3519606	et	4	main
teadlastele	doc_237632014900_item	3519611	et	3	main
ja	doc_399014257248_item	3519479	et	3	main
kogu	doc_399014257248_item	3519480	et	4	main
maailm	doc_399014257248_item	3519481	et	3	main
neid	doc_399014257248_item	3519484	et	4	main
filmides	doc_399014257248_item	3519487	et	4	main
ja	doc_399014257248_item	3519488	et	3	main
raamatutes	doc_399014257248_item	3519489	et	3	main
nöukogude	doc_399014257248_item	3519490	et	4	main
liit	doc_399014257248_item	3519491	et	3	main
kaotaja	doc_399014257248_item	3519496	et	4	main
nl	doc_399014257248_item	3519502	et	4	main
maade	doc_399014257248_item	3519505	et	3	main
pidanud	doc_399014257248_item	3519513	et	4	main
ja	doc_399014257248_item	3519522	et	3	main
antarktikas	doc_237632014900_item	3519553	et	4	main
uurijad	doc_237632014900_item	3519563	et	4	main
leidsid	doc_237632014900_item	3519564	et	4	main
järve	doc_237632014900_item	3519571	et	4	main
jää	doc_237632014900_item	3519577	et	4	main
bakterite	doc_237632014900_item	3519595	et	3	main
meile	doc_237632014900_item	3519598	et	4	main
uued	doc_237632014900_item	3519607	et	3	main
leiti	doc_237632014901_item	3519652	et	3	main
teadlased	doc_237632014901_item	3519656	et	3	main
et	doc_237632014901_item	3519658	et	3	main
on	doc_237632014901_item	3519663	et	4	main
leitud	doc_237632014901_item	3519664	et	4	main
esitas	doc_237632014901_item	3519687	et	3	main
iztapalapas	doc_237632014901_item	3519693	et	4	main
künka	doc_237632014901_item	3519694	et	3	main
lähedal	doc_237632014901_item	3519695	et	4	main
asub	doc_237632014901_item	3519696	et	3	main
püramiid	doc_237632014901_item	3519697	et	3	main
ma	doc_237632014901_item	3519703	et	3	main
varemed	doc_237632014901_item	3519711	et	3	main
aastail	doc_237632014901_item	3519720	et	4	main
lahkusid	doc_237632014901_item	3519737	et	4	main
elanikud	doc_237632014901_item	3519738	et	3	main
pääsemise	doc_237632014901_item	3519759	et	4	main
varjatud	doc_237632014901_item	3519769	et	4	main
mille	doc_237632014901_item	3519774	et	3	main
seotakse	doc_237632014901_item	3519776	et	3	main
vabatahtlik	doc_237632014901_item	3519778	et	3	main
paganline	doc_237632014901_item	3519796	et	4	main
pühendatud	doc_237632014901_item	3519804	et	4	main
iztapalapa	doc_237632014901_item	3519808	et	4	main
arheoloog	doc_237632014901_item	3519813	et	3	main
kokkusattumuseks	doc_237632014901_item	3519817	et	3	main
kuulus	doc_237632014902_item	3519823	et	4	main
eesti	doc_237632014902_item	3519824	et	4	main
meie	doc_237632014902_item	3519830	et	4	main
soovivad	doc_237632014902_item	3519838	et	4	main
kuusk	doc_237632014902_item	3519840	et	3	main
üle	doc_237632014902_item	3519879	et	3	main
ja	doc_237632014902_item	3519880	et	3	main
juuksurid	doc_237632014902_item	3519885	et	3	main
sügis-talv	doc_237632014902_item	3519887	et	3	main
soengud	doc_237632014902_item	3519889	et	3	main
seda	doc_237632014902_item	3519898	et	3	main
jälgitakse	doc_237632014902_item	3519899	et	3	main
aga	doc_237632014902_item	3519921	et	3	main
mitte	doc_237632014902_item	3519923	et	3	main
praegu	doc_237632014902_item	3519931	et	3	main
alati	doc_237632014902_item	3519961	et	4	main
näete	doc_237632014902_item	3519962	et	3	main
tähelepanu	doc_237632014902_item	3519970	et	4	main
moodi	doc_237632014902_item	3519978	et	4	main
sel	doc_237632014902_item	3519979	et	3	main
hooajal	doc_237632014902_item	3519980	et	3	main
on	doc_237632014902_item	3519981	et	4	main
väike	doc_237632014902_item	3519984	et	4	main
kuldne	doc_237632014902_item	3519985	et	3	main
banaanivormeline	doc_237632014902_item	3519986	et	4	main
punutud	doc_237632014902_item	3519989	et	4	main
pakkus	doc_237632014902_item	3519996	et	3	main
mis	doc_237632014902_item	3520000	et	4	main
ka	doc_237632014902_item	3520003	et	3	main
euroopa	doc_237632014902_item	3520011	et	4	main
kuulsate	doc_237632014902_item	3520022	et	3	main
galjano	doc_237632014902_item	3520027	et	4	main
kaasaegse	doc_237632014902_item	3520039	et	3	main
kilomeetri	doc_237632014900_item	3519632	et	4	main
ja	doc_237632014900_item	3519633	et	3	main
see	doc_237632014900_item	3519634	et	3	main
on	doc_237632014900_item	3519635	et	4	main
kõige	doc_237632014900_item	3519636	et	4	main
suurem	doc_237632014900_item	3519637	et	4	main
järv	doc_237632014900_item	3519638	et	3	main
vesistu	doc_237632014900_item	3519639	et	4	main
on	doc_237632014900_item	3519640	et	4	main
eraldatud	doc_237632014900_item	3519641	et	4	main
atmosfäärist	doc_237632014900_item	3519642	et	4	main
kõva	doc_237632014900_item	3519643	et	4	main
jääga	doc_237632014900_item	3519644	et	3	main
juba	doc_237632014900_item	3519645	et	3	main
15	doc_237632014900_item	3519646	et	2	main
mln	doc_237632014900_item	3519647	et	4	main
aastat	doc_237632014900_item	3519648	et	3	main
soojalembesid	doc_237632014900_item	3519556	et	3	main
soojalembesite	doc_237632014900_item	3519565	et	4	main
bakterite	doc_237632014900_item	3519566	et	3	main
jäljed	doc_237632014900_item	3519567	et	3	main
võivad	doc_237632014900_item	3519569	et	4	main
vostoki	doc_237632014900_item	3519570	et	4	main
settekivimide	doc_237632014900_item	3519579	et	4	main
kui	doc_237632014900_item	3519581	et	3	main
järve	doc_237632014900_item	3519586	et	4	main
prantsuse	doc_237632014900_item	3519590	et	3	main
põhjal	doc_237632014900_item	3519602	et	4	main
sel	doc_237632014900_item	3519603	et	3	main
hooajal	doc_237632014900_item	3519604	et	3	main
jääproovid	doc_237632014900_item	3519608	et	3	main
kas	doc_237632014900_item	3519613	et	3	main
on	doc_237632014900_item	3519614	et	4	main
üldse	doc_237632014900_item	3519615	et	3	main
elu	doc_237632014900_item	3519616	et	4	main
selles	doc_237632014900_item	3519617	et	4	main
järves	doc_237632014900_item	3519618	et	4	main
tuhande	doc_237632014900_item	3519619	et	3	main
järvede	doc_237632014900_item	3519620	et	3	main
pinnad	doc_237632014900_item	3519621	et	3	main
on	doc_237632014900_item	3519622	et	4	main
kattud	doc_237632014900_item	3519623	et	3	main
antarktika	doc_237632014900_item	3519624	et	4	main
jääga	doc_237632014900_item	3519625	et	3	main
vostoki	doc_237632014900_item	3519626	et	4	main
pind	doc_237632014900_item	3519627	et	3	main
on	doc_237632014900_item	3519628	et	4	main
14	doc_237632014900_item	3519629	et	2	main
000	doc_237632014900_item	3519630	et	2	main
ruut	doc_237632014900_item	3519631	et	3	main
püramiid	doc_237632014901_item	3519654	et	3	main
mehhiko	doc_237632014901_item	3519655	et	4	main
teatasid	doc_237632014901_item	3519657	et	4	main
teadlaste	doc_237632014901_item	3519668	et	3	main
hinnangul	doc_237632014901_item	3519669	et	3	main
ma	doc_237632014901_item	3519672	et	3	main
ehitise	doc_237632014901_item	3519674	et	3	main
on	doc_237632014901_item	3519676	et	4	main
meetrit	doc_237632014901_item	3519685	et	3	main
teotihuacan	doc_237632014901_item	3519700	et	4	main
kontrollkraavi	doc_237632014901_item	3519716	et	4	main
mille	doc_237632014901_item	3519717	et	3	main
arheoloogid	doc_237632014901_item	3519718	et	3	main
kaevasid	doc_237632014901_item	3519719	et	4	main
ja	doc_237632014901_item	3519722	et	3	main
kraavid	doc_237632014901_item	3519727	et	3	main
sajandil	doc_237632014901_item	3519740	et	3	main
1833	doc_237632014901_item	3519745	et	2	main
suurel	doc_237632014901_item	3519763	et	3	main
reedel	doc_237632014901_item	3519764	et	3	main
vaid	doc_237632014901_item	3519765	et	3	main
mõni	doc_237632014901_item	3519766	et	3	main
meeter	doc_237632014901_item	3519767	et	3	main
maas	doc_237632014901_item	3519768	et	4	main
rist	doc_237632014901_item	3519773	et	3	main
evangeeliumi	doc_237632014901_item	3519779	et	4	main
oma	doc_237632014901_item	3519793	et	4	main
templid	doc_237632014901_item	3519794	et	3	main
iigsete	doc_237632014901_item	3519795	et	4	main
peab	doc_237632014901_item	3519812	et	4	main
iidne	doc_237632014901_item	3519653	et	3	main
lähedal	doc_237632014901_item	3519662	et	4	main
püramiid	doc_237632014901_item	3519667	et	3	main
saj	doc_237632014901_item	3519671	et	4	main
pärit	doc_237632014901_item	3519673	et	3	main
kõrgus	doc_237632014901_item	3519675	et	4	main
18	doc_237632014901_item	3519677	et	2	main
meetrit	doc_237632014901_item	3519678	et	3	main
ja	doc_237632014901_item	3519679	et	3	main
tema	doc_237632014901_item	3519680	et	4	main
150	doc_237632014901_item	3519684	et	2	main
associated	doc_237632014901_item	3519688	et	4	main
agentuur	doc_237632014901_item	3519690	et	3	main
et	doc_237632014901_item	3519692	et	3	main
saj	doc_237632014901_item	3519702	et	4	main
on	doc_237632014901_item	3519704	et	4	main
viitanud	doc_237632014901_item	3519705	et	4	main
hüpoteesi	doc_237632014901_item	3519712	et	4	main
püramiidist	doc_237632014901_item	3519713	et	3	main
kinnitasid	doc_237632014901_item	3519714	et	4	main
kaks	doc_237632014901_item	3519715	et	3	main
2005	doc_237632014901_item	3519721	et	2	main
2006	doc_237632014901_item	3519723	et	2	main
need	doc_237632014901_item	3519726	et	3	main
9	doc_237632014901_item	3519739	et	2	main
aastat	doc_237632014901_item	3519742	et	3	main
nimelt	doc_237632014901_item	3519744	et	4	main
aastal	doc_237632014901_item	3519746	et	3	main
iztapalapa	doc_237632014901_item	3519748	et	4	main
elanikud	doc_237632014901_item	3519749	et	3	main
eest	doc_237632014901_item	3519760	et	4	main
püramiidist	doc_237632014901_item	3519770	et	3	main
kultusehitiste	doc_237632014901_item	3519797	et	4	main
kohtades	doc_237632014901_item	3519798	et	3	main
kuid	doc_237632014901_item	3519799	et	4	main
seda	doc_237632014901_item	3519800	et	3	main
asjaolu	doc_237632014901_item	3519801	et	4	main
et	doc_237632014901_item	3519802	et	3	main
lihavõtetele	doc_237632014901_item	3519803	et	3	main
langes	doc_237632014901_item	3519807	et	4	main
püramiidi	doc_237632014901_item	3519809	et	4	main
kohaga	doc_237632014901_item	3519810	et	4	main
juan	doc_237632014901_item	3519814	et	4	main
tõlge	doc_237632014902_item	3519819	et	3	main
disainerid	doc_237632014902_item	3519837	et	3	main
ühe	doc_237632014902_item	3519841	et	4	main
burgundia	doc_237632014902_item	3519847	et	4	main
vein	doc_237632014902_item	3519848	et	3	main
või	doc_237632014902_item	3519849	et	4	main
on	doc_237632014902_item	3519854	et	4	main
need	doc_237632014902_item	3519858	et	3	main
värvid	doc_237632014902_item	3519860	et	4	main
siis	doc_237632014902_item	3519861	et	3	main
on	doc_237632014902_item	3519862	et	4	main
tuju	doc_237632014902_item	3519871	et	4	main
vajadusel	doc_237632014902_item	3519881	et	3	main
kollektsioon	doc_237632014902_item	3519883	et	3	main
lokkid	doc_237632014902_item	3519894	et	4	main
mitte	doc_237632014902_item	3519895	et	3	main
press	doc_237632014901_item	3519689	et	3	main
sellele	doc_237632014901_item	3519691	et	4	main
36	doc_237632014901_item	3519701	et	2	main
kultusehitiste	doc_237632014901_item	3519710	et	4	main
avastatud	doc_237632014901_item	3519735	et	4	main
püramiid	doc_237632014901_item	3519736	et	3	main
tuhat	doc_237632014901_item	3519741	et	4	main
hiljem	doc_237632014901_item	3519743	et	3	main
hakkasid	doc_237632014901_item	3519747	et	4	main
selles	doc_237632014901_item	3519750	et	4	main
kohas	doc_237632014901_item	3519751	et	4	main
korraldama	doc_237632014901_item	3519752	et	3	main
lihavõtetele	doc_237632014901_item	3519753	et	3	main
pühendatud	doc_237632014901_item	3519754	et	4	main
vaatusi	doc_237632014901_item	3519755	et	3	main
neid	doc_237632014901_item	3519756	et	4	main
korraldatakse	doc_237632014901_item	3519757	et	3	main
koolera	doc_237632014901_item	3519758	et	4	main
tänulikkuse	doc_237632014901_item	3519761	et	4	main
märgina	doc_237632014901_item	3519762	et	3	main
püstitakse	doc_237632014901_item	3519771	et	3	main
külge	doc_237632014901_item	3519775	et	4	main
üks	doc_237632014901_item	3519777	et	3	main
kristuse	doc_237632014901_item	3519781	et	3	main
piinadest	doc_237632014901_item	3519782	et	3	main
igal	doc_237632014901_item	3519783	et	3	main
aastal	doc_237632014901_item	3519784	et	3	main
jälgib	doc_237632014901_item	3519785	et	3	main
üle	doc_237632014901_item	3519786	et	3	main
miljoni	doc_237632014901_item	3519787	et	3	main
inimest	doc_237632014901_item	3519788	et	3	main
reeglina	doc_237632014901_item	3519789	et	3	main
püstitasid	doc_237632014901_item	3519790	et	4	main
hispaanlased	doc_237632014901_item	3519791	et	3	main
meelega	doc_237632014901_item	3519792	et	4	main
koht	doc_237632014901_item	3519806	et	3	main
kokku	doc_237632014901_item	3519811	et	3	main
sanches	doc_237632014901_item	3519815	et	4	main
tamara	doc_237632014902_item	3519820	et	4	main
tamara	doc_237632014902_item	3519826	et	4	main
korjagina	doc_237632014902_item	3519827	et	4	main
jälle	doc_237632014902_item	3519828	et	3	main
annab	doc_237632014902_item	3519829	et	3	main
aastal	doc_237632014902_item	3519836	et	3	main
punase	doc_237632014902_item	3519845	et	4	main
nagu	doc_237632014902_item	3519846	et	3	main
võimalik	doc_237632014902_item	3519855	et	3	main
teil	doc_237632014902_item	3519863	et	4	main
kõige	doc_237632014902_item	3519864	et	4	main
stiilsem	doc_237632014902_item	3519865	et	4	main
kuusk	doc_237632014902_item	3519866	et	3	main
mis	doc_237632014902_item	3519867	et	4	main
kindlasti	doc_237632014902_item	3519868	et	3	main
toob	doc_237632014902_item	3519869	et	3	main
pidulik	doc_237632014902_item	3519870	et	3	main
vaadata	doc_237632014902_item	3519874	et	4	main
kõik	doc_237632014902_item	3519875	et	4	main
kollektsiooniks	doc_237632014902_item	3519888	et	3	main
romantilises	doc_237632014902_item	3519890	et	3	main
pikkad	doc_237632014902_item	3519892	et	4	main
ühemassilised	doc_237632014902_item	3519893	et	4	main
peale	doc_237632014902_item	3519897	et	4	main
tüdruku-nooruki	doc_237632014902_item	3519919	et	3	main
vamp	doc_237632014902_item	3519925	et	3	main
juuksete	doc_237632014902_item	3519928	et	4	main
siis	doc_237632014902_item	3519930	et	3	main
kullad	doc_237632014902_item	3519936	et	3	main
et	doc_237632014902_item	3519951	et	3	main
võite	doc_237632014902_item	3519952	et	4	main
panna	doc_237632014902_item	3519954	et	4	main
korralik	doc_237632014902_item	3519955	et	3	main
must	doc_237632014902_item	3519956	et	4	main
kleit	doc_237632014902_item	3519957	et	3	main
selja	doc_237632014902_item	3519958	et	3	main
selles	doc_237632014902_item	3519959	et	4	main
te	doc_237632014902_item	3519960	et	4	main
sellel	doc_237632014902_item	3519966	et	4	main
kulla	doc_237632014902_item	3519977	et	4	main
käekott	doc_237632014902_item	3519987	et	3	main
rihmaga	doc_237632014902_item	3519990	et	3	main
vastupidi	doc_237632014902_item	3519997	et	3	main
riided	doc_237632014902_item	3519999	et	3	main
võib	doc_237632014902_item	3520001	et	3	main
kuldsete	doc_237632014902_item	3520004	et	4	main
aksessuaaridega	doc_237632014902_item	3520005	et	3	main
tähtis	doc_237632014902_item	3520006	et	4	main
moe	doc_237632014902_item	3520012	et	3	main
peaaegu	doc_237632014902_item	3520015	et	3	main
riidemudelite	doc_237632014902_item	3520023	et	3	main
kollektsioonides	doc_237632014902_item	3520025	et	3	main
pakkub	doc_237632014902_item	3520028	et	4	main
mustlaste	doc_237632014902_item	3520031	et	4	main
koos	doc_237632014902_item	3520033	et	4	main
moesse	doc_237632014902_item	3520040	et	3	main
lahutamatu	doc_237632014902_item	3520051	et	4	main
rohkem	doc_237632014902_item	3520068	et	4	main
mõned	doc_237632014902_item	3520078	et	3	main
ühiskonnas	doc_237632014902_item	3520084	et	4	main
sellised	doc_237632014902_item	3520098	et	4	main
riided	doc_237632014902_item	3520099	et	3	main
mis	doc_237632014902_item	3520106	et	4	main
ole	doc_237632014902_item	3520113	et	4	main
stiilne	doc_237632014902_item	3520123	et	3	main
juhttendentsi	doc_237632014902_item	3520132	et	4	main
ja	doc_237632014902_item	3520133	et	3	main
proovida	doc_237632014902_item	3520134	et	3	main
etteütlemine	doc_237632014902_item	3520141	et	3	main
kui	doc_237632014902_item	3520143	et	3	main
kasutada	doc_237632014902_item	3520150	et	3	main
ootamatu	doc_237632014902_item	3520161	et	4	main
usu	doc_237632014902_item	3520202	et	4	main
hullkiires	doc_237632014902_item	3520204	et	4	main
uurida	doc_237632014902_item	3520217	et	3	main
või	doc_237632014902_item	3520219	et	4	main
sõbranna	doc_237632014902_item	3520221	et	4	main
lihtsaks	doc_237632014901_item	3519816	et	4	main
ruttem	doc_237632014902_item	3520385	et	4	main
seda	doc_237632014902_item	3520386	et	3	main
avatada	doc_237632014902_item	3520387	et	4	main
heat	doc_237632014902_item	3520388	et	4	main
uut	doc_237632014902_item	3520389	et	3	main
aastat	doc_237632014902_item	3520390	et	3	main
jõulunõuanned	doc_237632014902_item	3519822	et	4	main
kaunitada	doc_237632014902_item	3519839	et	4	main
šampanja	doc_237632014902_item	3519852	et	2	main
piisad	doc_237632014902_item	3519853	et	4	main
kasulik	doc_237632014902_item	3519873	et	3	main
kaunistused	doc_237632014902_item	3519878	et	4	main
stiilis	doc_237632014902_item	3519891	et	4	main
60	doc_237632014902_item	3519900	et	2	main
aastate	doc_237632014902_item	3519901	et	3	main
tagastamine	doc_237632014902_item	3519902	et	4	main
pats	doc_237632014902_item	3519903	et	4	main
ja	doc_237632014902_item	3519904	et	3	main
paelake	doc_237632014902_item	3519905	et	4	main
pea	doc_237632014902_item	3519906	et	4	main
ümber	doc_237632014902_item	3519907	et	3	main
moodsed	doc_237632014902_item	3519908	et	3	main
on	doc_237632014902_item	3519909	et	4	main
ka	doc_237632014902_item	3519910	et	3	main
kõrg	doc_237632014902_item	3519911	et	4	main
soengud	doc_237632014902_item	3519912	et	3	main
tänasepäeval	doc_237632014902_item	3519913	et	4	main
on	doc_237632014902_item	3519914	et	4	main
stiilne	doc_237632014902_item	3519915	et	3	main
seksuaalselt	doc_237632014902_item	3519916	et	4	main
välja	doc_237632014902_item	3519917	et	4	main
näha	doc_237632014902_item	3519918	et	3	main
mis	doc_237632014902_item	3519926	et	4	main
puutub	doc_237632014902_item	3519927	et	3	main
värvi	doc_237632014902_item	3519929	et	4	main
effektselt	doc_237632014902_item	3519932	et	4	main
näevad	doc_237632014902_item	3519933	et	3	main
välja	doc_237632014902_item	3519934	et	4	main
toonid	doc_237632014902_item	3519937	et	4	main
juhul	doc_237632014902_item	3519967	et	3	main
tuleb	doc_237632014902_item	3519968	et	3	main
pöörata	doc_237632014902_item	3519969	et	4	main
mis	doc_237632014902_item	3519972	et	4	main
peavad	doc_237632014902_item	3519973	et	4	main
olema	doc_237632014902_item	3519974	et	4	main
kuld	doc_237632014902_item	3519975	et	3	main
väga	doc_237632014902_item	3519982	et	3	main
pikka	doc_237632014902_item	3519988	et	4	main
dolce	doc_237632014902_item	3519991	et	4	main
gabanna	doc_237632014902_item	3519992	et	4	main
valged	doc_237632014902_item	3519998	et	3	main
märkida	doc_237632014902_item	3520008	et	4	main
mängib	doc_237632014902_item	3520014	et	3	main
peamist	doc_237632014902_item	3520016	et	3	main
jõulunõuanned	doc_237632014902_item	3519833	et	4	main
kuusk	doc_237632014902_item	3519834	et	3	main
sel	doc_237632014902_item	3519835	et	3	main
värviga	doc_237632014902_item	3519842	et	4	main
näiteks	doc_237632014902_item	3519843	et	4	main
tume	doc_237632014902_item	3519844	et	3	main
kullasega	doc_237632014902_item	3519850	et	4	main
nagu	doc_237632014902_item	3519851	et	3	main
ka	doc_237632014902_item	3519856	et	3	main
kombineerida	doc_237632014902_item	3519857	et	3	main
rikkad	doc_237632014902_item	3519859	et	4	main
oleks	doc_237632014902_item	3519872	et	3	main
vanad	doc_237632014902_item	3519876	et	3	main
kuusk	doc_237632014902_item	3519877	et	3	main
uuendada	doc_237632014902_item	3519882	et	3	main
soeng	doc_237632014902_item	3519884	et	3	main
pakkuvad	doc_237632014902_item	3519886	et	4	main
ringadega	doc_237632014902_item	3519896	et	4	main
ladi	doc_237632014902_item	3519924	et	4	main
kõik	doc_237632014902_item	3519935	et	4	main
kohvi	doc_237632014902_item	3519938	et	4	main
kaneeli	doc_237632014902_item	3519939	et	4	main
ja	doc_237632014902_item	3519940	et	3	main
blond	doc_237632014902_item	3519941	et	3	main
metsmaasika	doc_237632014902_item	3519942	et	3	main
julgelt	doc_237632014902_item	3519953	et	4	main
effektselt	doc_237632014902_item	3519963	et	4	main
ja	doc_237632014902_item	3519964	et	3	main
või	doc_237632014902_item	3519976	et	4	main
aktuaalne	doc_237632014902_item	3519983	et	3	main
oma	doc_237632014902_item	3519993	et	4	main
kollektsiooniks	doc_237632014902_item	3519994	et	3	main
sügis-talv	doc_237632014902_item	3519995	et	3	main
kaunistada	doc_237632014902_item	3520002	et	3	main
et	doc_237632014902_item	3520009	et	3	main
etno-stiil	doc_237632014902_item	3520010	et	3	main
rolli	doc_237632014902_item	3520017	et	4	main
võime	doc_237632014902_item	3520019	et	4	main
valmistajate	doc_237632014902_item	3520024	et	4	main
džon	doc_237632014902_item	3520026	et	2	main
see	doc_237632014902_item	3520043	et	3	main
võib-olla	doc_237632014902_item	3520046	et	3	main
on	doc_237632014902_item	3520048	et	4	main
oli	doc_237632014902_item	3520054	et	3	main
ja	doc_237632014902_item	3520060	et	3	main
momentil	doc_237632014902_item	3520065	et	4	main
kujud	doc_237632014902_item	3520079	et	3	main
seda	doc_237632014902_item	3520081	et	3	main
roll	doc_237632014902_item	3520083	et	3	main
muutus	doc_237632014902_item	3520086	et	4	main
nad	doc_237632014902_item	3520087	et	3	main
tugevam	doc_237632014902_item	3520091	et	4	main
näha	doc_237632014902_item	3520095	et	3	main
riietuskappis	doc_237632014902_item	3520097	et	4	main
mis	doc_237632014902_item	3520100	et	4	main
üheaegselt	doc_237632014902_item	3520102	et	4	main
mugavad	doc_237632014902_item	3520103	et	3	main
ei	doc_237632014902_item	3520112	et	4	main
sa	doc_237632014902_item	3520119	et	3	main
õpida	doc_237632014902_item	3520126	et	4	main
naine	doc_237632014902_item	3520128	et	3	main
ennast	doc_237632014902_item	3520135	et	4	main
erinevates	doc_237632014902_item	3520136	et	4	main
väike	doc_237632014902_item	3520140	et	4	main
ootab	doc_237632014902_item	3520145	et	3	main
väga	doc_237632014902_item	3520147	et	3	main
lõbusaks	doc_237632014902_item	3520158	et	4	main
peoks	doc_237632014902_item	3520159	et	4	main
värvide	doc_237632014902_item	3520162	et	3	main
pruun	doc_237632014902_item	3520166	et	3	main
et	doc_237632014902_item	3520169	et	3	main
ei	doc_237632014902_item	3520171	et	4	main
õhtuni	doc_237632014902_item	3520200	et	3	main
moodi	doc_237632014902_item	3519920	et	4	main
kindlasti	doc_237632014902_item	3519922	et	3	main
helkuga	doc_237632014902_item	3519943	et	4	main
riided	doc_237632014902_item	3519944	et	3	main
praegu	doc_237632014902_item	3519945	et	3	main
tagastab	doc_237632014902_item	3519946	et	3	main
elegantne	doc_237632014902_item	3519947	et	3	main
must	doc_237632014902_item	3519948	et	4	main
värv	doc_237632014902_item	3519949	et	3	main
nii	doc_237632014902_item	3519950	et	3	main
stiilselt	doc_237632014902_item	3519965	et	4	main
aksesuaaridele	doc_237632014902_item	3519971	et	4	main
on	doc_237632014902_item	3520007	et	4	main
maailmas	doc_237632014902_item	3520013	et	3	main
seda	doc_237632014902_item	3520018	et	3	main
jälgida	doc_237632014902_item	3520020	et	3	main
seelikud	doc_237632014902_item	3520030	et	3	main
hispaania	doc_237632014902_item	3520037	et	4	main
nootid	doc_237632014902_item	3520038	et	4	main
millega	doc_237632014902_item	3520041	et	3	main
seotud	doc_237632014902_item	3520045	et	4	main
mood	doc_237632014902_item	3520047	et	3	main
osa	doc_237632014902_item	3520052	et	4	main
minevikus	doc_237632014902_item	3520053	et	3	main
huvitavaid	doc_237632014902_item	3520059	et	4	main
et	doc_237632014902_item	3520063	et	3	main
ei	doc_237632014902_item	3520066	et	4	main
olnud	doc_237632014902_item	3520067	et	4	main
midagi	doc_237632014902_item	3520071	et	4	main
lihtsalt	doc_237632014902_item	3520074	et	4	main
laenada	doc_237632014902_item	3520075	et	4	main
ja	doc_237632014902_item	3520076	et	3	main
uuendada	doc_237632014902_item	3520077	et	3	main
kõvasti	doc_237632014902_item	3520085	et	3	main
iga	doc_237632014902_item	3520092	et	4	main
tahab	doc_237632014902_item	3520094	et	3	main
oma	doc_237632014902_item	3520096	et	4	main
seksuaalsed	doc_237632014902_item	3520105	et	3	main
nende	doc_237632014902_item	3520108	et	4	main
vaid	doc_237632014902_item	3520121	et	3	main
seda	doc_237632014902_item	3520124	et	3	main
veel	doc_237632014902_item	3520139	et	4	main
juhul	doc_237632014902_item	3520142	et	3	main
uueaastakarneval	doc_237632014902_item	3520146	et	3	main
moodne	doc_237632014902_item	3520148	et	3	main
peodel	doc_237632014902_item	3520151	et	3	main
sobivad	doc_237632014902_item	3520160	et	4	main
violett	doc_237632014902_item	3520165	et	3	main
erilist	doc_237632014902_item	3520209	et	4	main
kingituse	doc_237632014902_item	3520215	et	4	main
kingituseks	doc_237632014902_item	3520225	et	4	main
on	doc_237632014902_item	3520226	et	4	main
komplektid	doc_237632014902_item	3520227	et	3	main
näiteks	doc_237632014902_item	3520228	et	4	main
tualettvesi	doc_237632014902_item	3520229	et	4	main
et	doc_237632014902_item	3520233	et	3	main
tema	doc_237632014902_item	3520238	et	4	main
aroomaga	doc_237632014902_item	3520240	et	4	main
võite	doc_237632014902_item	3520241	et	4	main
olla	doc_237632014902_item	3520242	et	3	main
kindel	doc_237632014902_item	3520243	et	3	main
et	doc_237632014902_item	3520244	et	3	main
see	doc_237632014902_item	3520245	et	3	main
kindlasti	doc_237632014902_item	3520252	et	3	main
mint	doc_237632014902_item	3520254	et	4	main
aastaks	doc_237632014902_item	3520256	et	4	main
on	doc_237632014902_item	3520261	et	4	main
seda	doc_237632014902_item	3520263	et	3	main
sel	doc_237632014902_item	3520269	et	3	main
mitte	doc_237632014902_item	3520278	et	3	main
spa	doc_237632014902_item	3520288	et	4	main
salongi	doc_237632014902_item	3520289	et	4	main
kinkekaart	doc_237632014902_item	3520290	et	4	main
kus	doc_237632014902_item	3520291	et	3	main
ootamatu	doc_237632014902_item	3520304	et	4	main
võib	doc_237632014902_item	3520321	et	3	main
parem	doc_237632014902_item	3520324	et	4	main
alati	doc_237632014902_item	3520343	et	4	main
väike	doc_237632014902_item	3520346	et	4	main
arusa	doc_237632014902_item	3520348	et	4	main
element	doc_237632014902_item	3520358	et	3	main
nagu	doc_237632014902_item	3520359	et	3	main
tähelepanu	doc_237632014902_item	3520365	et	4	main
särav	doc_237632014902_item	3520374	et	4	main
paljude	doc_237632014902_item	3520021	et	3	main
pikkad	doc_237632014902_item	3520029	et	4	main
motiividega	doc_237632014902_item	3520032	et	3	main
metallehedega	doc_237632014902_item	3520034	et	4	main
gotje	doc_237632014902_item	3520035	et	4	main
tõi	doc_237632014902_item	3520036	et	3	main
on	doc_237632014902_item	3520042	et	4	main
välja	doc_237632014902_item	3520055	et	4	main
kauneid	doc_237632014902_item	3520061	et	3	main
riideid	doc_237632014902_item	3520062	et	3	main
leiutada	doc_237632014902_item	3520070	et	3	main
uut	doc_237632014902_item	3520072	et	3	main
peale	doc_237632014902_item	3520080	et	4	main
naise	doc_237632014902_item	3520082	et	3	main
sõltumatum	doc_237632014902_item	3520090	et	4	main
naine	doc_237632014902_item	3520093	et	3	main
on	doc_237632014902_item	3520101	et	4	main
isegi	doc_237632014902_item	3520114	et	4	main
nii	doc_237632014902_item	3520115	et	3	main
tähtis	doc_237632014902_item	3520116	et	4	main
kui	doc_237632014902_item	3520117	et	3	main
moodne	doc_237632014902_item	3520118	et	3	main
siis	doc_237632014902_item	3520044	et	3	main
meie	doc_237632014902_item	3520049	et	4	main
ajaloo	doc_237632014902_item	3520050	et	4	main
mõeldud	doc_237632014902_item	3520056	et	4	main
nii	doc_237632014902_item	3520057	et	3	main
palju	doc_237632014902_item	3520058	et	4	main
ühel	doc_237632014902_item	3520064	et	3	main
vaja	doc_237632014902_item	3520069	et	4	main
võib	doc_237632014902_item	3520073	et	3	main
on	doc_237632014902_item	3520088	et	4	main
iseseisvam	doc_237632014902_item	3520089	et	4	main
effektsed	doc_237632014902_item	3520104	et	4	main
eraldavad	doc_237632014902_item	3520107	et	4	main
individuaalsust	doc_237632014902_item	3520109	et	4	main
arvan	doc_237632014902_item	3520110	et	3	main
et	doc_237632014902_item	3520111	et	3	main
oled	doc_237632014902_item	3520120	et	3	main
võib	doc_237632014902_item	3520125	et	3	main
on	doc_237632014902_item	3520129	et	4	main
vaja	doc_237632014902_item	3520130	et	4	main
jälgida	doc_237632014902_item	3520131	et	3	main
ja	doc_237632014902_item	3520138	et	3	main
peale	doc_237632014902_item	3520156	et	4	main
seda	doc_237632014902_item	3520157	et	3	main
ühendusega	doc_237632014902_item	3520163	et	4	main
oranž	doc_237632014902_item	3520167	et	2	main
roppult	doc_237632014902_item	3520173	et	4	main
välja	doc_237632014902_item	3520174	et	4	main
ei	doc_237632014902_item	3520201	et	4	main
lihtsam	doc_237632014902_item	3520210	et	4	main
ja	doc_237632014902_item	3520211	et	3	main
kiirem	doc_237632014902_item	3520212	et	4	main
meeste	doc_237632014902_item	3520213	et	4	main
valimisel	doc_237632014902_item	3520216	et	4	main
ta	doc_237632014902_item	3520220	et	4	main
kui	doc_237632014902_item	3520234	et	3	main
kingite	doc_237632014902_item	3520235	et	3	main
komplekt	doc_237632014902_item	3520237	et	3	main
rõõmustab	doc_237632014902_item	3520253	et	3	main
ja	doc_237632014902_item	3520260	et	3	main
konkurentsita	doc_237632014902_item	3520262	et	3	main
hooajal	doc_237632014902_item	3520270	et	3	main
meestest	doc_237632014902_item	3520276	et	4	main
naised	doc_237632014902_item	3520279	et	3	main
olla	doc_237632014902_item	3520300	et	3	main
olegi	doc_237632014902_item	3520309	et	4	main
kindlasti	doc_237632014902_item	3520319	et	3	main
ole	doc_237632014902_item	3520329	et	4	main
selgunud	doc_237632014902_item	3520330	et	4	main
kingitusega	doc_237632014902_item	3520331	et	4	main
siis	doc_237632014902_item	3520332	et	3	main
pöörduge	doc_237632014902_item	3520333	et	3	main
tähele	doc_237632014902_item	3520334	et	3	main
maiustustele	doc_237632014902_item	3520335	et	4	main
tehtud	doc_237632014902_item	3520336	et	4	main
käsitsi	doc_237632014902_item	3520337	et	3	main
šokolaadi	doc_237632014902_item	3520338	et	2	main
variant	doc_237632014902_item	3520345	et	3	main
nii	doc_237632014902_item	3520362	et	3	main
pöörduge	doc_237632014902_item	3520364	et	3	main
sellele	doc_237632014902_item	3520366	et	4	main
kuidas	doc_237632014902_item	3520367	et	3	main
näeb	doc_237632014902_item	3520368	et	3	main
teie	doc_237632014902_item	3520369	et	4	main
kink	doc_237632014902_item	3520370	et	3	main
lindike	doc_237632014902_item	3520376	et	4	main
kui	doc_237632014902_item	3520122	et	3	main
iga	doc_237632014902_item	3520127	et	4	main
stiilides	doc_237632014902_item	3520137	et	4	main
teid	doc_237632014902_item	3520144	et	4	main
on	doc_237632014902_item	3520149	et	4	main
venetsia	doc_237632014902_item	3520152	et	4	main
maskid	doc_237632014902_item	3520153	et	3	main
soengu	doc_237632014902_item	3520154	et	3	main
elementina	doc_237632014902_item	3520155	et	4	main
riided	doc_237632014902_item	3520164	et	3	main
tähtis	doc_237632014902_item	3520168	et	4	main
see	doc_237632014902_item	3520170	et	3	main
näeks	doc_237632014902_item	3520172	et	3	main
kingitused	doc_237632014902_item	3520175	et	4	main
pea	doc_237632014902_item	3520176	et	4	main
tindimus	doc_237632014902_item	3520177	et	4	main
edukate	doc_237632014902_item	3520178	et	4	main
ja	doc_237632014902_item	3520179	et	3	main
soovitavate	doc_237632014902_item	3520180	et	4	main
kingituste	doc_237632014902_item	3520181	et	4	main
ostmisel	doc_237632014902_item	3520182	et	4	main
on	doc_237632014902_item	3520183	et	4	main
nende	doc_237632014902_item	3520184	et	4	main
õigeaegne	doc_237632014902_item	3520185	et	3	main
saamine	doc_237632014902_item	3520186	et	4	main
kui	doc_237632014902_item	3520187	et	3	main
te	doc_237632014902_item	3520188	et	4	main
tõesti	doc_237632014902_item	3520189	et	3	main
tahate	doc_237632014902_item	3520190	et	3	main
rõõmustada	doc_237632014902_item	3520191	et	3	main
oma	doc_237632014902_item	3520192	et	4	main
kallist	doc_237632014902_item	3520193	et	4	main
inimest	doc_237632014902_item	3520194	et	3	main
siis	doc_237632014902_item	3520195	et	3	main
ärge	doc_237632014902_item	3520196	et	3	main
ootage	doc_237632014902_item	3520197	et	4	main
31	doc_237632014902_item	3520198	et	2	main
detsembri	doc_237632014902_item	3520199	et	3	main
et	doc_237632014902_item	3520203	et	3	main
on	doc_237632014902_item	3520205	et	4	main
võimalik	doc_237632014902_item	3520206	et	3	main
valida	doc_237632014902_item	3520207	et	3	main
midagi	doc_237632014902_item	3520208	et	4	main
lahendus	doc_237632014902_item	3520214	et	4	main
naise	doc_237632014902_item	3520218	et	3	main
nii	doc_237632014902_item	3520232	et	3	main
lemmig	doc_237632014902_item	3520239	et	4	main
mobiiltelefon	doc_237632014902_item	3520251	et	3	main
juveliirehed	doc_237632014902_item	3520257	et	4	main
alati	doc_237632014902_item	3520258	et	4	main
ennast	doc_237632014902_item	3520285	et	4	main
jälgida	doc_237632014902_item	3520286	et	3	main
ja	doc_237632014902_item	3520287	et	3	main
mees	doc_237632014902_item	3520292	et	4	main
võiks	doc_237632014902_item	3520293	et	4	main
võtta	doc_237632014902_item	3520294	et	3	main
kingitus	doc_237632014902_item	3520305	et	4	main
sel	doc_237632014902_item	3520306	et	3	main
juhul	doc_237632014902_item	3520307	et	3	main
kehatoonikuga	doc_237632014902_item	3520231	et	3	main
armsale	doc_237632014902_item	3520236	et	3	main
rõõmustab	doc_237632014902_item	3520247	et	3	main
stiilne	doc_237632014902_item	3520250	et	3	main
uueks	doc_237632014902_item	3520255	et	3	main
enam	doc_237632014902_item	3520264	et	4	main
kuldehed	doc_237632014902_item	3520265	et	4	main
on	doc_237632014902_item	3520266	et	4	main
eriti	doc_237632014902_item	3520267	et	3	main
kes	doc_237632014902_item	3520271	et	4	main
hoolitseb	doc_237632014902_item	3520273	et	3	main
lõdvestus	doc_237632014902_item	3520295	et	4	main
ja	doc_237632014902_item	3520296	et	3	main
võib	doc_237632014902_item	3520299	et	3	main
ei	doc_237632014902_item	3520308	et	4	main
vaja	doc_237632014902_item	3520310	et	4	main
osta	doc_237632014902_item	3520311	et	4	main
kallid	doc_237632014902_item	3520312	et	3	main
kaardid	doc_237632014902_item	3520313	et	3	main
pakkumine	doc_237632014902_item	3520314	et	4	main
nädalavahetuseks	doc_237632014902_item	3520315	et	4	main
toila	doc_237632014902_item	3520316	et	4	main
keskusse	doc_237632014902_item	3520317	et	4	main
oleks	doc_237632014902_item	3520318	et	3	main
olla	doc_237632014902_item	3520322	et	3	main
või	doc_237632014902_item	3520339	et	4	main
martsipaani	doc_237632014902_item	3520340	et	4	main
figuurid	doc_237632014902_item	3520341	et	3	main
on	doc_237632014902_item	3520354	et	4	main
välja	doc_237632014902_item	3520371	et	4	main
kõik	doc_237632014902_item	3520377	et	4	main
see	doc_237632014902_item	3520378	et	3	main
tualettlaud	doc_237632014902_item	3520222	et	4	main
väga	doc_237632014902_item	3520223	et	3	main
populaarsed	doc_237632014902_item	3520224	et	3	main
koos	doc_237632014902_item	3520230	et	4	main
kingitus	doc_237632014902_item	3520246	et	4	main
teda	doc_237632014902_item	3520248	et	4	main
ka	doc_237632014902_item	3520249	et	3	main
olid	doc_237632014902_item	3520259	et	4	main
aktuaalsed	doc_237632014902_item	3520268	et	3	main
veel	doc_237632014902_item	3520272	et	4	main
meie	doc_237632014902_item	3520274	et	4	main
kallide	doc_237632014902_item	3520275	et	4	main
kui	doc_237632014902_item	3520277	et	3	main
viimasel	doc_237632014902_item	3520280	et	3	main
ajal	doc_237632014902_item	3520281	et	4	main
paljud	doc_237632014902_item	3520282	et	3	main
hakkasid	doc_237632014902_item	3520283	et	4	main
tõsiselt	doc_237632014902_item	3520284	et	4	main
antistress	doc_237632014902_item	3520297	et	3	main
protseduurid	doc_237632014902_item	3520298	et	3	main
päris	doc_237632014902_item	3520301	et	4	main
meeldiv	doc_237632014902_item	3520302	et	4	main
ja	doc_237632014902_item	3520303	et	3	main
ka	doc_237632014902_item	3520323	et	3	main
te	doc_237632014902_item	3520326	et	4	main
võidukindel	doc_237632014902_item	3520344	et	3	main
aga	doc_237632014902_item	3520347	et	3	main
jõulukingituseks	doc_237632014902_item	3520349	et	4	main
ärge	doc_237632014902_item	3520350	et	3	main
unustage	doc_237632014902_item	3520351	et	3	main
et	doc_237632014902_item	3520352	et	3	main
pakkimine	doc_237632014902_item	3520353	et	4	main
ise	doc_237632014902_item	3520361	et	4	main
et	doc_237632014902_item	3520363	et	3	main
ilus	doc_237632014902_item	3520372	et	4	main
effektne	doc_237632014902_item	3520373	et	4	main
hea	doc_237632014902_item	3520320	et	4	main
kui	doc_237632014902_item	3520325	et	3	main
ikkagi	doc_237632014902_item	3520327	et	4	main
ei	doc_237632014902_item	3520328	et	4	main
on	doc_237632014902_item	3520342	et	4	main
kingituse	doc_237632014902_item	3520355	et	4	main
väga	doc_237632014902_item	3520356	et	3	main
tähtis	doc_237632014902_item	3520357	et	4	main
kingitus	doc_237632014902_item	3520360	et	4	main
toob	doc_237632014902_item	3520379	et	3	main
pidulikut	doc_237632014902_item	3520380	et	4	main
tujut	doc_237632014902_item	3520381	et	4	main
ja	doc_237632014902_item	3520382	et	3	main
annab	doc_237632014902_item	3520383	et	3	main
tahtmist	doc_237632014902_item	3520384	et	4	main
pakkimispaber	doc_237632014902_item	3520375	et	3	main
eelmisel	doc_40918597573_item	3520606	et	3	main
raskemuusika	doc_40918597573_item	3520616	et	4	main
bändi	doc_40918597573_item	3520617	et	4	main
eestit	doc_40918597573_item	3520626	et	3	main
esimest	doc_40918597573_item	3520627	et	4	main
a	doc_40918597573_item	3520634	et	4	main
turnee	doc_40918597573_item	3520637	et	4	main
organiseeritud	doc_40918597573_item	3520647	et	4	main
toetuseks	doc_40918597573_item	3520652	et	4	main
järgmisi	doc_40918597573_item	3520657	et	3	main
glaskow	doc_40918597573_item	3520659	et	4	main
birmingham	doc_40918597573_item	3520660	et	4	main
sankt-peterburg	doc_40918597573_item	3520664	et	4	main
riia	doc_40918597573_item	3520665	et	4	main
lissabon	doc_40918597573_item	3520671	et	4	main
kus	doc_40918597573_item	3520672	et	3	main
ka	doc_40918597573_item	3520673	et	3	main
27	doc_40918597573_item	3520674	et	2	main
lõpeb	doc_40918597573_item	3520677	et	4	main
mustade	doc_40918597573_item	3520689	et	3	main
tuli	doc_40918597573_item	3520691	et	4	main
metsikult	doc_40918597573_item	3520692	et	4	main
lava	doc_40918597573_item	3520702	et	4	main
ei	doc_40918597573_item	3520705	et	4	main
isa	doc_40918597573_item	3520717	et	4	main
haigestumise	doc_40918597573_item	3520718	et	4	main
kes	doc_40918597573_item	3520731	et	4	main
otsustas	doc_40918597573_item	3520732	et	3	main
teha	doc_40918597573_item	3520733	et	3	main
pausi	doc_40918597573_item	3520734	et	4	main
lühikest	doc_40918597573_item	3520744	et	4	main
laulda	doc_40918597573_item	3520781	et	4	main
sellega	doc_40918597573_item	3520783	et	3	main
bänd	doc_40918597573_item	3520790	et	3	main
viimasel	doc_40918597573_item	3520791	et	3	main
viieteistkümnel	doc_40918597573_item	3520792	et	4	main
plaati	doc_40918597573_item	3520797	et	4	main
olnud	doc_40918597573_item	3520799	et	4	main
autoriteetse	doc_40918597573_item	3520800	et	3	main
edetabeli	doc_40918597573_item	3520801	et	3	main
billboard	doc_40918597573_item	3520802	et	4	main
200	doc_40918597573_item	3520803	et	2	main
tõlge	doc_40918597573_item	3520605	et	3	main
kaliforinia	doc_40918597573_item	3520615	et	4	main
liikmed	doc_40918597573_item	3520624	et	3	main
külastasid	doc_40918597573_item	3520625	et	4	main
got	doc_40918597573_item	3520633	et	4	main
raames	doc_40918597573_item	3520638	et	4	main
plaadi	doc_40918597573_item	3520649	et	4	main
euroopa	doc_40918597573_item	3520653	et	4	main
läbib	doc_40918597573_item	3520655	et	3	main
linnasid	doc_40918597573_item	3520658	et	3	main
genf	doc_40918597573_item	3520669	et	4	main
ja	doc_40918597573_item	3520670	et	3	main
korni	doc_40918597573_item	3520682	et	4	main
liikmed	doc_40918597573_item	3520683	et	3	main
lavale	doc_40918597573_item	3520684	et	3	main
vokalist	doc_40918597573_item	3520685	et	3	main
fännide	doc_40918597573_item	3520694	et	3	main
tihedalt	doc_40918597573_item	3520700	et	4	main
james	doc_40918597573_item	3520710	et	4	main
saanud	doc_40918597573_item	3520714	et	4	main
turneele	doc_40918597573_item	3520715	et	3	main
tulla	doc_40918597573_item	3520716	et	3	main
teda	doc_40918597573_item	3520720	et	4	main
patterson	doc_40918597573_item	3520723	et	4	main
bändi	doc_40918597573_item	3520724	et	4	main
david	doc_40918597573_item	3520729	et	4	main
silveria	doc_40918597573_item	3520730	et	4	main
kontserdil	doc_40918597573_item	3520740	et	3	main
lauluks	doc_40918597573_item	3520742	et	4	main
peale	doc_40918597573_item	3520743	et	4	main
kõige	doc_40918597573_item	3520787	et	4	main
edukam	doc_40918597573_item	3520788	et	4	main
10	doc_40918597573_item	3520796	et	2	main
reedel	doc_40918597573_item	3520607	et	3	main
kes	doc_40918597573_item	3520619	et	4	main
uus-metall	doc_40918597573_item	3520621	et	3	main
korda	doc_40918597573_item	3520628	et	4	main
agressiivse	doc_40918597573_item	3520629	et	3	main
nimega	doc_40918597573_item	3520630	et	3	main
bitch	doc_40918597573_item	3520631	et	4	main
turnee	doc_40918597573_item	3520639	et	4	main
jaanuaril	doc_40918597573_item	3520642	et	3	main
iirimaalt	doc_40918597573_item	3520644	et	3	main
on	doc_40918597573_item	3520646	et	4	main
uue	doc_40918597573_item	3520648	et	3	main
amsterdam	doc_40918597573_item	3520661	et	4	main
tallinn	doc_40918597573_item	3520666	et	4	main
veebruaril	doc_40918597573_item	3520675	et	3	main
kamoflaazist	doc_40918597573_item	3520686	et	4	main
seeliku	doc_40918597573_item	3520687	et	3	main
ja	doc_40918597573_item	3520688	et	3	main
põlvikutega	doc_40918597573_item	3520690	et	3	main
ajaks	doc_40918597573_item	3520698	et	4	main
ümbritsenud	doc_40918597573_item	3520701	et	4	main
juurdepääsu	doc_40918597573_item	3520703	et	4	main
korn	doc_40918597573_item	3520704	et	4	main
10	doc_40918597573_item	3520608	et	2	main
värisesid	doc_40918597573_item	3520610	et	4	main
suurhalli	doc_40918597573_item	3520612	et	4	main
seinad	doc_40918597573_item	3520613	et	3	main
tuntud	doc_40918597573_item	3520614	et	4	main
muusikast	doc_40918597573_item	3520618	et	4	main
stiili	doc_40918597573_item	3520622	et	4	main
problem	doc_40918597573_item	3520635	et	4	main
algas	doc_40918597573_item	3520640	et	3	main
dublinist	doc_40918597573_item	3520643	et	4	main
ja	doc_40918597573_item	3520645	et	3	main
untitled	doc_40918597573_item	3520650	et	4	main
kopenhagen	doc_40918597573_item	3520662	et	4	main
stockholm	doc_40918597573_item	3520663	et	4	main
milaano	doc_40918597573_item	3520668	et	4	main
turnee	doc_40918597573_item	3520676	et	4	main
kokkulepitud	doc_40918597573_item	3520678	et	4	main
ajaks	doc_40918597573_item	3520679	et	4	main
2115	doc_40918597573_item	3520680	et	2	main
ette	doc_40918597573_item	3520695	et	4	main
olid	doc_40918597573_item	3520699	et	4	main
aga	doc_40918597573_item	3520773	et	3	main
ei	doc_40918597573_item	3520774	et	4	main
seganud	doc_40918597573_item	3520775	et	4	main
publikul	doc_40918597573_item	3520776	et	3	main
palju	doc_40918597573_item	3520777	et	4	main
laule	doc_40918597573_item	3520778	et	4	main
vokalistiga	doc_40918597573_item	3520779	et	3	main
kaasa	doc_40918597573_item	3520780	et	4	main
veebruaril	doc_40918597573_item	3520609	et	3	main
saku	doc_40918597573_item	3520611	et	4	main
mängivad	doc_40918597573_item	3520620	et	4	main
korn-i	doc_40918597573_item	3520623	et	4	main
we	doc_40918597573_item	3520632	et	4	main
euroopa	doc_40918597573_item	3520636	et	4	main
13	doc_40918597573_item	3520641	et	2	main
nimetu	doc_40918597573_item	3520651	et	4	main
turneel	doc_40918597573_item	3520654	et	3	main
korn	doc_40918597573_item	3520656	et	4	main
viin	doc_40918597573_item	3520667	et	4	main
ilmusid	doc_40918597573_item	3520681	et	4	main
röökivate	doc_40918597573_item	3520693	et	4	main
kes	doc_40918597573_item	3520696	et	4	main
selleks	doc_40918597573_item	3520697	et	4	main
tulnud	doc_40918597573_item	3520706	et	4	main
tallinnasse	doc_40918597573_item	3520707	et	3	main
täiskoosseisus	doc_40918597573_item	3520708	et	4	main
kitarrist	doc_40918597573_item	3520709	et	4	main
ei	doc_40918597573_item	3520713	et	4	main
rob	doc_40918597573_item	3520722	et	4	main
trummar	doc_40918597573_item	3520728	et	3	main
tegevuses	doc_40918597573_item	3520736	et	4	main
samuti	doc_40918597573_item	3520737	et	3	main
ei	doc_40918597573_item	3520738	et	4	main
kõik	doc_40918597573_item	3520795	et	4	main
on	doc_40918597573_item	3520798	et	4	main
korral	doc_40918597573_item	3520814	et	4	main
ka	doc_40918597573_item	3520815	et	3	main
selle	doc_40918597573_item	3520816	et	4	main
jeaffer	doc_40918597573_item	3520712	et	4	main
tõttu	doc_40918597573_item	3520719	et	4	main
muusikalises	doc_40918597573_item	3520735	et	4	main
esimeseks	doc_40918597573_item	3520741	et	3	main
instrumentaalpala	doc_40918597573_item	3520745	et	4	main
oli	doc_40918597573_item	3520746	et	3	main
right	doc_40918597573_item	3520747	et	4	main
now	doc_40918597573_item	3520748	et	4	main
bändi	doc_40918597573_item	3520749	et	4	main
kuuendalt	doc_40918597573_item	3520750	et	3	main
albumilt	doc_40918597573_item	3520751	et	3	main
take	doc_40918597573_item	3520752	et	4	main
a	doc_40918597573_item	3520753	et	4	main
look	doc_40918597573_item	3520754	et	3	main
in	doc_40918597573_item	3520755	et	4	main
the	doc_40918597573_item	3520756	et	4	main
mirror	doc_40918597573_item	3520757	et	4	main
kahjuks	doc_40918597573_item	3520758	et	4	main
polnud	doc_40918597573_item	3520759	et	3	main
esimese	doc_40918597573_item	3520760	et	3	main
teise	doc_40918597573_item	3520761	et	4	main
ega	doc_40918597573_item	3520762	et	3	main
ka	doc_40918597573_item	3520763	et	3	main
järgmise	doc_40918597573_item	3520764	et	3	main
kahekümne	doc_40918597573_item	3520765	et	4	main
laulu	doc_40918597573_item	3520766	et	4	main
sõnad	doc_40918597573_item	3520767	et	4	main
arusaadavad	doc_40918597573_item	3520768	et	3	main
liigkõva	doc_40918597573_item	3520769	et	4	main
muusika	doc_40918597573_item	3520770	et	4	main
tõttu	doc_40918597573_item	3520771	et	4	main
mis	doc_40918597573_item	3520772	et	4	main
kõige	doc_40918597573_item	3520782	et	4	main
metall-punk	doc_40918597573_item	3520789	et	4	main
sees	doc_40918597573_item	3520804	et	4	main
bänd	doc_40918597573_item	3520805	et	3	main
on	doc_40918597573_item	3520806	et	4	main
kuuel	doc_40918597573_item	3520807	et	4	main
korral	doc_40918597573_item	3520808	et	4	main
olnud	doc_40918597573_item	3520809	et	4	main
grammy	doc_40918597573_item	3520810	et	4	main
nominent	doc_40918597573_item	3520811	et	4	main
ja	doc_40918597573_item	3520812	et	3	main
kahel	doc_40918597573_item	3520813	et	4	main
munky	doc_40918597573_item	3520711	et	4	main
asendas	doc_40918597573_item	3520721	et	3	main
oter	doc_40918597573_item	3520725	et	4	main
endine	doc_40918597573_item	3520726	et	3	main
kitarrist	doc_40918597573_item	3520727	et	4	main
osalenud	doc_40918597573_item	3520739	et	4	main
on	doc_40918597573_item	3520784	et	4	main
korn	doc_40918597573_item	3520785	et	4	main
üks	doc_40918597573_item	3520786	et	3	main
aastal	doc_40918597573_item	3520793	et	3	main
bändi	doc_40918597573_item	3520794	et	4	main
võitnud	doc_40918597573_item	3520817	et	4	main
soojalembesid	doc_980560860278_item	3521033	et	3	main
baktereid	doc_980560860278_item	3521034	et	3	main
kinkis	doc_980560860278_item	3521036	et	3	main
leidsid	doc_980560860278_item	3521041	et	4	main
järve	doc_980560860278_item	3521049	et	4	main
põhjal	doc_980560860278_item	3521050	et	4	main
jääsegu	doc_980560860278_item	3521055	et	4	main
saadud	doc_980560860278_item	3521059	et	4	main
asuvad	doc_980560860278_item	3521079	et	4	main
hüdrotermaalsed	doc_980560860278_item	3521080	et	4	main
augud	doc_980560860278_item	3521081	et	3	main
selle	doc_980560860278_item	3521082	et	4	main
aitavad	doc_980560860278_item	3521086	et	4	main
välja	doc_980560860278_item	3521088	et	4	main
katab	doc_980560860278_item	3521099	et	3	main
järvi	doc_980560860278_item	3521101	et	4	main
nendest	doc_980560860278_item	3521111	et	4	main
atmosfäärist	doc_980560860278_item	3521117	et	4	main
juba	doc_980560860278_item	3521118	et	3	main
järves	doc_980560860278_item	3521129	et	4	main
uue	doc_980560860278_item	3521038	et	3	main
leid	doc_980560860278_item	3521051	et	4	main
avastati	doc_980560860278_item	3521052	et	3	main
settekivime-	doc_980560860278_item	3521053	et	4	main
jääkihi	doc_980560860278_item	3521061	et	3	main
võib	doc_980560860278_item	3521071	et	3	main
termofiilbakterite	doc_980560860278_item	3521072	et	4	main
olemasolu	doc_980560860278_item	3521073	et	4	main
tähendada	doc_980560860278_item	3521074	et	3	main
veekogu	doc_980560860278_item	3521077	et	4	main
põhjal	doc_980560860278_item	3521078	et	4	main
uued	doc_980560860278_item	3521084	et	3	main
kas	doc_980560860278_item	3521090	et	3	main
elu	doc_980560860278_item	3521094	et	4	main
jää	doc_980560860278_item	3521098	et	4	main
tuhandeid	doc_980560860278_item	3521100	et	3	main
on	doc_980560860278_item	3521110	et	4	main
järve	doc_980560860278_item	3521116	et	4	main
loota	doc_980560860278_item	3521127	et	4	main
et	doc_980560860278_item	3521128	et	3	main
eluvorm	doc_980560860278_item	3521131	et	3	main
on	doc_980560860278_item	3521133	et	4	main
ka	doc_980560860278_item	3521134	et	3	main
teistel	doc_980560860278_item	3521135	et	4	main
planeetidel	doc_980560860278_item	3521136	et	3	main
jääkihi	doc_980560860278_item	3521161	et	3	main
külmunud	doc_980560860278_item	3521169	et	4	main
settekivime	doc_980560860278_item	3521176	et	4	main
üles	doc_980560860278_item	3521182	et	3	main
nendes	doc_980560860278_item	3521184	et	4	main
leitigi	doc_980560860278_item	3521186	et	3	main
bakterite	doc_980560860278_item	3521187	et	3	main
geneetilisi	doc_980560860278_item	3521188	et	3	main
jalge	doc_980560860278_item	3521189	et	4	main
tavaliselt	doc_980560860278_item	3521192	et	4	main
kuues	doc_980560860278_item	3521200	et	4	main
peal	doc_980560860278_item	3521203	et	4	main
leida	doc_980560860278_item	3521211	et	3	main
on	doc_980560860279_item	3521245	et	4	main
leidsid	doc_980560860279_item	3521255	et	4	main
leid	doc_980560860279_item	3521264	et	4	main
avastati	doc_980560860279_item	3521265	et	3	main
uued	doc_980560860279_item	3521292	et	3	main
jääproovid	doc_980560860279_item	3521293	et	3	main
sellel	doc_980560860279_item	3521296	et	4	main
võimalust	doc_980560860279_item	3521299	et	3	main
järves	doc_980560860279_item	3521306	et	4	main
14	doc_980560860279_item	3521313	et	2	main
vostok	doc_980560860279_item	3521318	et	4	main
jääkate	doc_980560860279_item	3521322	et	3	main
aastat	doc_980560860279_item	3521329	et	3	main
tõlge	doc_980560860278_item	3521030	et	3	main
avastuse-	doc_980560860278_item	3521039	et	4	main
võivad	doc_980560860278_item	3521046	et	4	main
elada	doc_980560860278_item	3521047	et	3	main
vostok	doc_980560860278_item	3521048	et	4	main
sees	doc_980560860278_item	3521056	et	4	main
mis	doc_980560860278_item	3521057	et	4	main
seda	doc_980560860278_item	3521075	et	3	main
on	doc_980560860278_item	3521093	et	4	main
km	doc_980560860278_item	3521108	et	4	main
2	doc_980560860278_item	3521109	et	2	main
suurem	doc_980560860278_item	3521113	et	4	main
jääkate	doc_980560860278_item	3521114	et	3	main
eraldab	doc_980560860278_item	3521115	et	3	main
põhjust	doc_980560860278_item	3521126	et	4	main
jupiteri	doc_980560860278_item	3521139	et	4	main
selle	doc_980560860278_item	3521173	et	4	main
mida	doc_980560860278_item	3521178	et	4	main
maaväring	doc_980560860278_item	3521183	et	3	main
ladestustes	doc_980560860278_item	3521185	et	4	main
50-60	doc_980560860278_item	3521193	et	2	main
või	doc_980560860278_item	3521199	et	4	main
lootsid	doc_980560860278_item	3521210	et	4	main
kohendatud	doc_980560860278_item	3521212	et	4	main
külmale	doc_980560860278_item	3521213	et	4	main
elukeskkonnale	doc_980560860278_item	3521214	et	3	main
tegeleb	doc_980560860278_item	3521218	et	3	main
võimalik	doc_980560860278_item	3521222	et	3	main
uurimistulemused	doc_980560860278_item	3521224	et	3	main
tunnistada	doc_980560860278_item	3521226	et	3	main
et	doc_980560860278_item	3521229	et	3	main
antarktikas	doc_980560860278_item	3521031	et	4	main
teadlastele	doc_980560860278_item	3521037	et	3	main
uurijad	doc_980560860278_item	3521040	et	4	main
soojalembeste	doc_980560860278_item	3521042	et	4	main
bakterite	doc_980560860278_item	3521043	et	3	main
jalge	doc_980560860278_item	3521044	et	4	main
ja	doc_980560860278_item	3521054	et	3	main
oli	doc_980560860278_item	3521058	et	3	main
kolmekilomeetrilise	doc_980560860278_item	3521060	et	4	main
puurimise	doc_980560860278_item	3521062	et	4	main
käigus	doc_980560860278_item	3521063	et	4	main
järve	doc_980560860278_item	3521064	et	4	main
pinnal	doc_980560860278_item	3521065	et	3	main
et	doc_980560860278_item	3521076	et	3	main
hooaja	doc_980560860278_item	3521083	et	3	main
spetsialistidele	doc_980560860278_item	3521087	et	3	main
uurida	doc_980560860278_item	3521089	et	3	main
selles	doc_980560860278_item	3521091	et	4	main
järves	doc_980560860278_item	3521092	et	4	main
mitte	doc_980560860278_item	3521096	et	3	main
vostok	doc_980560860278_item	3521102	et	4	main
mille	doc_980560860278_item	3521103	et	3	main
pindala	doc_980560860278_item	3521104	et	4	main
moodustab	doc_980560860278_item	3521105	et	3	main
14	doc_980560860278_item	3521106	et	2	main
000	doc_980560860278_item	3521107	et	2	main
kestel	doc_980560860278_item	3521122	et	4	main
see	doc_980560860278_item	3521123	et	3	main
annab	doc_980560860278_item	3521124	et	3	main
teadlastele	doc_980560860278_item	3521125	et	3	main
mis	doc_980560860278_item	3521132	et	4	main
olemas	doc_980560860278_item	3521137	et	4	main
analüüs	doc_980560860278_item	3521164	et	3	main
näitas	doc_980560860278_item	3521165	et	3	main
need	doc_980560860278_item	3521167	et	3	main
avastati	doc_980560860278_item	3521174	et	3	main
põhjalt	doc_980560860278_item	3521181	et	3	main
kes	doc_980560860278_item	3521190	et	4	main
imestanud	doc_980560860278_item	3521208	et	4	main
kuna	doc_980560860278_item	3521209	et	3	main
praegu	doc_980560860278_item	3521219	et	3	main
soojalembesed	doc_980560860279_item	3521247	et	4	main
kinkis	doc_980560860279_item	3521250	et	3	main
teadlastele	doc_980560860279_item	3521251	et	3	main
soojalembsete	doc_980560860279_item	3521256	et	4	main
jäljed	doc_980560860279_item	3521258	et	3	main
võivad	doc_980560860279_item	3521260	et	4	main
elada	doc_980560860279_item	3521261	et	3	main
vostoki	doc_980560860279_item	3521262	et	4	main
järvepõhjas	doc_980560860279_item	3521263	et	3	main
avad	doc_980560860279_item	3521291	et	4	main
ise	doc_980560860279_item	3521307	et	4	main
antarktika	doc_980560860279_item	3521308	et	4	main
jää	doc_980560860279_item	3521309	et	4	main
katab	doc_980560860279_item	3521310	et	3	main
tuhandeid	doc_980560860279_item	3521311	et	3	main
on	doc_980560860279_item	3521319	et	4	main
eraldav	doc_980560860279_item	3521323	et	4	main
atmosfäärist	doc_980560860279_item	3521325	et	4	main
juba	doc_980560860279_item	3521326	et	3	main
annab	doc_980560860279_item	3521331	et	3	main
satteliites	doc_980560860279_item	3521349	et	4	main
koostööd	doc_213943984914_item	3521394	et	4	main
kohtla-järve	doc_213943984914_item	3521397	et	4	main
koostöös	doc_213943984914_item	3521399	et	3	main
leiti	doc_980560860278_item	3521032	et	3	main
antarktika	doc_980560860278_item	3521035	et	4	main
kes	doc_980560860278_item	3521045	et	4	main
vene	doc_980560860278_item	3521066	et	4	main
ja	doc_980560860278_item	3521067	et	3	main
prantsuse	doc_980560860278_item	3521068	et	3	main
teadlaste	doc_980560860278_item	3521069	et	3	main
arvamusel	doc_980560860278_item	3521070	et	3	main
jääproovid	doc_980560860278_item	3521085	et	3	main
või	doc_980560860278_item	3521095	et	4	main
antarktika	doc_980560860278_item	3521097	et	4	main
kõige	doc_980560860278_item	3521112	et	4	main
viieteistkümnete	doc_980560860278_item	3521119	et	4	main
miljonite	doc_980560860278_item	3521120	et	3	main
aastate	doc_980560860278_item	3521121	et	3	main
eksisteerib	doc_980560860278_item	3521130	et	3	main
lõpu	doc_980560860278_item	3521162	et	3	main
sisaldavad	doc_980560860278_item	3521168	et	4	main
järve	doc_980560860278_item	3521170	et	4	main
vett	doc_980560860278_item	3521171	et	3	main
peale	doc_980560860278_item	3521172	et	4	main
tõstis	doc_980560860278_item	3521180	et	4	main
asuvad	doc_980560860278_item	3521197	et	4	main
viies	doc_980560860278_item	3521198	et	4	main
kohas	doc_980560860278_item	3521201	et	4	main
teadlased	doc_980560860278_item	3521204	et	3	main
mudelite	doc_980560860278_item	3521220	et	3	main
valeks	doc_980560860278_item	3521227	et	3	main
vostok	doc_980560860278_item	3521230	et	4	main
on	doc_980560860278_item	3521231	et	4	main
kõige	doc_980560860278_item	3521232	et	4	main
elutu	doc_980560860278_item	3521233	et	4	main
järv	doc_980560860278_item	3521234	et	3	main
maakeral	doc_980560860278_item	3521235	et	3	main
ja	doc_980560860278_item	3521236	et	3	main
et	doc_980560860278_item	3521237	et	3	main
vesi	doc_980560860278_item	3521238	et	4	main
on	doc_980560860278_item	3521239	et	4	main
selles	doc_980560860278_item	3521240	et	4	main
steriilne	doc_980560860278_item	3521241	et	3	main
antarktikas	doc_980560860279_item	3521244	et	4	main
avastust	doc_980560860279_item	3521253	et	4	main
bakterite	doc_980560860279_item	3521257	et	3	main
jää	doc_980560860279_item	3521266	et	4	main
hüdrotermaalsed	doc_980560860279_item	3521290	et	4	main
mis	doc_980560860279_item	3521294	et	4	main
hooajal	doc_980560860279_item	3521297	et	3	main
teada	doc_980560860279_item	3521300	et	3	main
000	doc_980560860279_item	3521314	et	2	main
pindalaga	doc_980560860279_item	3521317	et	3	main
järvet	doc_980560860279_item	3521324	et	4	main
15	doc_980560860279_item	3521327	et	2	main
on	doc_980560860279_item	3521336	et	4	main
selline	doc_980560860279_item	3521338	et	4	main
eluvorm	doc_980560860279_item	3521339	et	3	main
mis	doc_980560860279_item	3521340	et	4	main
võib	doc_980560860279_item	3521341	et	3	main
olla	doc_980560860279_item	3521342	et	3	main
näiteks	doc_980560860278_item	3521138	et	4	main
kaaslasel	doc_980560860278_item	3521140	et	3	main
euroopal	doc_980560860278_item	3521141	et	3	main
algul	doc_980560860278_item	3521142	et	4	main
olid	doc_980560860278_item	3521143	et	4	main
jääproovid	doc_980560860278_item	3521144	et	3	main
mõeldud	doc_980560860278_item	3521145	et	4	main
kliima	doc_980560860278_item	3521146	et	4	main
uurimise	doc_980560860278_item	3521147	et	4	main
jaoks	doc_980560860278_item	3521148	et	4	main
minevikus	doc_980560860278_item	3521149	et	3	main
kuigi	doc_980560860278_item	3521150	et	3	main
pääseda	doc_980560860278_item	3521151	et	3	main
järve	doc_980560860278_item	3521152	et	4	main
sügavusele	doc_980560860278_item	3521153	et	4	main
ei	doc_980560860278_item	3521154	et	4	main
õnnestunud	doc_980560860278_item	3521155	et	4	main
puurimist	doc_980560860278_item	3521156	et	4	main
peatati	doc_980560860278_item	3521157	et	4	main
100	doc_980560860278_item	3521158	et	2	main
meetrit	doc_980560860278_item	3521159	et	3	main
enne	doc_980560860278_item	3521160	et	4	main
jääproovide	doc_980560860278_item	3521163	et	3	main
et	doc_980560860278_item	3521166	et	3	main
jääs	doc_980560860278_item	3521175	et	3	main
kihte	doc_980560860278_item	3521177	et	3	main
arvatavasti	doc_980560860278_item	3521179	et	3	main
elavad	doc_980560860278_item	3521191	et	4	main
kraadi	doc_980560860278_item	3521194	et	4	main
juures	doc_980560860278_item	3521195	et	4	main
ja	doc_980560860278_item	3521196	et	3	main
maa	doc_980560860278_item	3521202	et	4	main
olid	doc_980560860278_item	3521205	et	4	main
avastusega	doc_980560860278_item	3521206	et	4	main
väga	doc_980560860278_item	3521207	et	3	main
eluvorme	doc_980560860278_item	3521215	et	3	main
spetsialistide	doc_980560860278_item	3521216	et	3	main
meeskond	doc_980560860278_item	3521217	et	3	main
uurimisega	doc_980560860278_item	3521221	et	4	main
et	doc_980560860278_item	3521223	et	3	main
võimaldavad	doc_980560860278_item	3521225	et	4	main
arvamust	doc_980560860278_item	3521228	et	3	main
tõlge	doc_980560860279_item	3521243	et	3	main
bakterid	doc_980560860279_item	3521248	et	3	main
uut	doc_980560860279_item	3521252	et	3	main
uurijad	doc_980560860279_item	3521254	et	4	main
mis	doc_980560860279_item	3521259	et	4	main
elu	doc_980560860279_item	3521305	et	4	main
järvi	doc_980560860279_item	3521312	et	4	main
kilomeetri	doc_980560860279_item	3521316	et	4	main
neist	doc_980560860279_item	3521321	et	4	main
see	doc_980560860279_item	3521330	et	3	main
järves	doc_980560860279_item	3521335	et	4	main
mineviku	doc_980560860279_item	3521353	et	3	main
kohtla-järve	doc_213943984914_item	3521392	et	4	main
muuseumiga	doc_213943984914_item	3521396	et	3	main
sankt-peterburi	doc_213943984914_item	3521400	et	4	main
linnavalitsusega	doc_213943984914_item	3521405	et	3	main
uee	doc_213943984914_item	3521408	et	4	main
eesti	doc_213943984914_item	3521417	et	4	main
ja	doc_213943984914_item	3521418	et	3	main
vene	doc_213943984914_item	3521419	et	4	main
ettekavatsetud	doc_213943984914_item	3521424	et	4	main
tema	doc_213943984914_item	3521428	et	4	main
on	doc_213943984914_item	3521430	et	4	main
ligi	doc_213943984914_item	3521431	et	3	main
muuseumi	doc_213943984914_item	3521441	et	4	main
ja	doc_213943984914_item	3521442	et	3	main
jätkame	doc_213943984914_item	3521451	et	3	main
mis	doc_213943984914_item	3521454	et	4	main
meie	doc_213943984914_item	3521456	et	4	main
kohtla-järve	doc_213943984914_item	3521464	et	4	main
külastanud	doc_213943984914_item	3521465	et	4	main
filosoofia	doc_213943984914_item	3521469	et	4	main
boiko	doc_213943984914_item	3521472	et	4	main
ellu	doc_213943984914_item	3521476	et	4	main
kohtla-järve	doc_213943984914_item	3521481	et	4	main
koolinoorte	doc_213943984914_item	3521482	et	3	main
võtavad	doc_213943984914_item	3521494	et	3	main
osa	doc_213943984914_item	3521495	et	4	main
produkti	doc_213943984914_item	3521505	et	4	main
põlevkivimuuseumi	doc_213943984914_item	3521521	et	4	main
on	doc_213943984914_item	3521526	et	4	main
filiaal	doc_213943984914_item	3521528	et	3	main
arendada	doc_213943984914_item	3521530	et	3	main
luua	doc_213943984914_item	3521537	et	4	main
eesmärgil	doc_213943984914_item	3521543	et	3	main
kultuurivaldkonnas	doc_213943984914_item	3521572	et	4	main
venemaal	doc_213943984914_item	3521582	et	4	main
tegelema	doc_213943984914_item	3521589	et	3	main
leitud	doc_980560860279_item	3521246	et	4	main
antarktika	doc_980560860279_item	3521249	et	4	main
ja	doc_980560860279_item	3521267	et	3	main
settekivimi	doc_980560860279_item	3521268	et	4	main
segust	doc_980560860279_item	3521269	et	4	main
mis	doc_980560860279_item	3521270	et	4	main
oli	doc_980560860279_item	3521271	et	3	main
saanud	doc_980560860279_item	3521272	et	4	main
kolmekilomeetrilise	doc_980560860279_item	3521273	et	4	main
jääkate	doc_980560860279_item	3521274	et	3	main
puurimisega	doc_980560860279_item	3521275	et	4	main
vene	doc_980560860279_item	3521276	et	4	main
ja	doc_980560860279_item	3521277	et	3	main
prantsuse	doc_980560860279_item	3521278	et	3	main
teadlaste	doc_980560860279_item	3521279	et	3	main
arvamusel	doc_980560860279_item	3521280	et	3	main
termofiiliste	doc_980560860279_item	3521281	et	4	main
bakterite	doc_980560860279_item	3521282	et	3	main
olemasolu	doc_980560860279_item	3521283	et	4	main
võib	doc_980560860279_item	3521284	et	3	main
tõendada	doc_980560860279_item	3521285	et	3	main
seda	doc_980560860279_item	3521286	et	3	main
et	doc_980560860279_item	3521287	et	3	main
järvepõhjas	doc_980560860279_item	3521288	et	3	main
asuvad	doc_980560860279_item	3521289	et	4	main
võeti	doc_980560860279_item	3521295	et	3	main
annavad	doc_980560860279_item	3521298	et	3	main
saada	doc_980560860279_item	3521301	et	4	main
kas	doc_980560860279_item	3521302	et	3	main
on	doc_980560860279_item	3521303	et	4	main
olemas	doc_980560860279_item	3521304	et	4	main
ruut	doc_980560860279_item	3521315	et	3	main
suurim	doc_980560860279_item	3521320	et	3	main
mln	doc_980560860279_item	3521328	et	4	main
lootust	doc_980560860279_item	3521333	et	4	main
ka	doc_980560860279_item	3521343	et	3	main
planeetides	doc_980560860279_item	3521345	et	3	main
jupiteri	doc_980560860279_item	3521348	et	4	main
võeti	doc_980560860279_item	3521352	et	3	main
kliima	doc_980560860279_item	3521354	et	4	main
tõlge	doc_213943984914_item	3521391	et	3	main
põlevkivimuuseum	doc_213943984914_item	3521398	et	3	main
kohtla-järve	doc_213943984914_item	3521404	et	4	main
loomine	doc_213943984914_item	3521410	et	4	main
on	doc_213943984914_item	3521423	et	4	main
mln	doc_213943984914_item	3521433	et	4	main
interreg	doc_213943984914_item	3521437	et	4	main
programmi	doc_213943984914_item	3521438	et	4	main
kaudu	doc_213943984914_item	3521439	et	3	main
koostöö	doc_213943984914_item	3521445	et	4	main
areneb	doc_213943984914_item	3521446	et	3	main
tõepoolest	doc_213943984914_item	3521447	et	3	main
kiiresti	doc_213943984914_item	3521448	et	3	main
ja	doc_213943984914_item	3521449	et	3	main
ühistegevust	doc_213943984914_item	3521453	et	4	main
kohtla-järvel	doc_213943984914_item	3521461	et	4	main
muuseumi	doc_213943984914_item	3521467	et	4	main
koostöö	doc_213943984914_item	3521478	et	4	main
projektist	doc_213943984914_item	3521493	et	3	main
uhkuseks	doc_213943984914_item	3521509	et	4	main
see	doc_213943984914_item	3521510	et	3	main
kohtla-järvel	doc_213943984914_item	3521520	et	4	main
plaanitakse	doc_213943984914_item	3521536	et	4	main
tutvustuse	doc_213943984914_item	3521542	et	4	main
projekti	doc_213943984914_item	3521545	et	4	main
oma	doc_213943984914_item	3521570	et	4	main
nende	doc_213943984914_item	3521573	et	4	main
hakkavad	doc_213943984914_item	3521586	et	4	main
noored	doc_213943984914_item	3521588	et	3	main
virtuaalsete	doc_213943984914_item	3521590	et	3	main
osa	doc_213943984914_item	3521627	et	4	main
avaneb	doc_213943984914_item	3521631	et	3	main
teadlastele	doc_980560860279_item	3521332	et	3	main
et	doc_980560860279_item	3521334	et	3	main
olemas	doc_980560860279_item	3521337	et	4	main
teistes	doc_980560860279_item	3521344	et	4	main
nt	doc_980560860279_item	3521346	et	4	main
euroopas	doc_980560860279_item	3521347	et	3	main
jääproovid	doc_980560860279_item	3521351	et	3	main
arendab	doc_213943984914_item	3521393	et	3	main
koostasid	doc_213943984914_item	3521406	et	4	main
turistimarsruudi	doc_213943984914_item	3521409	et	3	main
vene	doc_213943984914_item	3521411	et	4	main
muuseumi	doc_213943984914_item	3521412	et	4	main
virtuaalse	doc_213943984914_item	3521413	et	3	main
noorte	doc_213943984914_item	3521420	et	3	main
abil	doc_213943984914_item	3521421	et	4	main
projekt	doc_213943984914_item	3521422	et	3	main
ja	doc_213943984914_item	3521427	et	3	main
krooni	doc_213943984914_item	3521434	et	4	main
toimub	doc_213943984914_item	3521436	et	3	main
kohtla-järve	doc_213943984914_item	3521443	et	4	main
seda	doc_213943984914_item	3521452	et	3	main
ütles	doc_213943984914_item	3521462	et	3	main
asja	doc_213943984914_item	3521463	et	4	main
esindaja	doc_213943984914_item	3521468	et	4	main
programmi	doc_213943984914_item	3521479	et	4	main
alguses	doc_980560860279_item	3521350	et	4	main
uurimiseks	doc_980560860279_item	3521355	et	4	main
kuna	doc_980560860279_item	3521356	et	3	main
jõuda	doc_980560860279_item	3521357	et	3	main
järvele	doc_980560860279_item	3521358	et	4	main
ise	doc_980560860279_item	3521359	et	4	main
ei	doc_980560860279_item	3521360	et	4	main
saanud	doc_980560860279_item	3521361	et	4	main
puurimine	doc_980560860279_item	3521362	et	4	main
oli	doc_980560860279_item	3521363	et	3	main
katkestunud	doc_980560860279_item	3521364	et	4	main
100	doc_980560860279_item	3521365	et	2	main
enne	doc_980560860279_item	3521367	et	4	main
jääkate	doc_980560860279_item	3521368	et	3	main
lõppu	doc_980560860279_item	3521369	et	4	main
proovide	doc_980560860279_item	3521370	et	3	main
analüüs	doc_980560860279_item	3521371	et	3	main
näitas	doc_980560860279_item	3521372	et	3	main
et	doc_980560860279_item	3521373	et	3	main
nad	doc_980560860279_item	3521374	et	3	main
sisaldavad	doc_980560860279_item	3521375	et	4	main
m	doc_980560860279_item	3521366	et	4	main
järvevett	doc_980560860279_item	3521376	et	3	main
peale	doc_980560860279_item	3521377	et	4	main
seda	doc_980560860279_item	3521378	et	3	main
jääs	doc_980560860279_item	3521379	et	3	main
avastati	doc_980560860279_item	3521380	et	3	main
settekivimite	doc_980560860279_item	3521381	et	4	main
kihtid	doc_980560860279_item	3521382	et	4	main
mis	doc_980560860279_item	3521383	et	4	main
nähtavasti	doc_980560860279_item	3521384	et	3	main
olid	doc_980560860279_item	3521385	et	4	main
ülesse	doc_980560860279_item	3521386	et	4	main
tõstnud	doc_980560860279_item	3521387	et	4	main
väike	doc_980560860279_item	3521388	et	4	main
maaväringuga	doc_980560860279_item	3521389	et	3	main
nende	doc_213943984914_item	3521632	et	4	main
jaoks	doc_213943984914_item	3521633	et	4	main
suurepärane	doc_213943984914_item	3521634	et	4	main
võimalus	doc_213943984914_item	3521635	et	3	main
külastada	doc_213943984914_item	3521636	et	3	main
sankt-peterburi	doc_213943984914_item	3521637	et	4	main
kultuuripärandiga	doc_213943984914_item	3521638	et	4	main
tutvustuse	doc_213943984914_item	3521639	et	4	main
eesmärgil	doc_213943984914_item	3521640	et	3	main
rääkis	doc_213943984914_item	3521641	et	3	main
projekti	doc_213943984914_item	3521642	et	4	main
töögrupi	doc_213943984914_item	3521643	et	3	main
liige	doc_213943984914_item	3521644	et	4	main
aleksandr	doc_213943984914_item	3521645	et	4	main
dusman	doc_213943984914_item	3521646	et	4	main
vene	doc_213943984914_item	3521395	et	4	main
projekti	doc_213943984914_item	3521407	et	4	main
aastaks	doc_213943984914_item	3521426	et	4	main
eelarve	doc_213943984914_item	3521429	et	4	main
4	doc_213943984914_item	3521432	et	2	main
rahastamine	doc_213943984914_item	3521435	et	4	main
linna	doc_213943984914_item	3521444	et	4	main
loomisest	doc_213943984914_item	3521460	et	4	main
vene	doc_213943984914_item	3521466	et	4	main
doktorikraadiga	doc_213943984914_item	3521470	et	3	main
aga	doc_213943984914_item	3521474	et	3	main
raamides	doc_213943984914_item	3521480	et	4	main
ja	doc_213943984914_item	3521483	et	3	main
üliõpilaste	doc_213943984914_item	3521484	et	4	main
visiidi	doc_213943984914_item	3521485	et	3	main
sankt-peterburi	doc_213943984914_item	3521486	et	4	main
ning	doc_213943984914_item	3521487	et	3	main
nedne	doc_213943984914_item	3521488	et	4	main
tutvustuse	doc_213943984914_item	3521489	et	4	main
muuseumi	doc_213943984914_item	3521490	et	4	main
väljapanekuga	doc_213943984914_item	3521491	et	3	main
peterburi	doc_213943984914_item	3521497	et	4	main
noored	doc_213943984914_item	3521498	et	3	main
ja	doc_213943984914_item	3521499	et	3	main
mis	doc_213943984914_item	3521506	et	4	main
jääb	doc_213943984914_item	3521507	et	3	main
filiaali	doc_213943984914_item	3521516	et	4	main
strukturaalseks	doc_213943984914_item	3521524	et	3	main
koostööd	doc_213943984914_item	3521532	et	4	main
abiga	doc_213943984914_item	3521534	et	3	main
toimuvad	doc_213943984914_item	3521575	et	4	main
neli	doc_213943984914_item	3521576	et	3	main
peale	doc_213943984914_item	3521583	et	4	main
lõpetamise	doc_213943984914_item	3521585	et	4	main
kohtla-järve	doc_213943984914_item	3521623	et	4	main
õpilased	doc_213943984914_item	3521625	et	3	main
erilisest	doc_213943984914_item	3521628	et	4	main
vene	doc_213943984914_item	3521401	et	4	main
muuseumi	doc_213943984914_item	3521402	et	4	main
ja	doc_213943984914_item	3521403	et	3	main
maailma	doc_213943984914_item	3521414	et	4	main
arengu	doc_213943984914_item	3521415	et	3	main
teel	doc_213943984914_item	3521416	et	4	main
kaheks	doc_213943984914_item	3521425	et	4	main
vene	doc_213943984914_item	3521440	et	4	main
me	doc_213943984914_item	3521450	et	4	main
algas	doc_213943984914_item	3521455	et	3	main
muuseumi	doc_213943984914_item	3521457	et	4	main
virtuaalse	doc_213943984914_item	3521458	et	3	main
filiaali	doc_213943984914_item	3521459	et	4	main
aleksei	doc_213943984914_item	3521471	et	4	main
praegu	doc_213943984914_item	3521473	et	3	main
viime	doc_213943984914_item	3521475	et	3	main
piirialase	doc_213943984914_item	3521477	et	4	main
sellest	doc_213943984914_item	3521492	et	4	main
ka	doc_213943984914_item	3521496	et	3	main
meie	doc_213943984914_item	3521500	et	4	main
kohtla-järve	doc_213943984914_item	3521508	et	4	main
töö	doc_213943984914_item	3521517	et	4	main
edukal	doc_213943984914_item	3521518	et	3	main
kogemusel	doc_213943984914_item	3521519	et	3	main
osaks	doc_213943984914_item	3521525	et	3	main
otsustas	doc_213943984914_item	3521529	et	3	main
seda	doc_213943984914_item	3521531	et	3	main
spetsiaalset	doc_213943984914_item	3521538	et	3	main
turistimarsruuti	doc_213943984914_item	3521539	et	4	main
eestlaste	doc_213943984914_item	3521565	et	4	main
oskusi	doc_213943984914_item	3521571	et	3	main
jaoks	doc_213943984914_item	3521574	et	4	main
eestis	doc_213943984914_item	3521579	et	3	main
kaks	doc_213943984914_item	3521581	et	3	main
kursuste	doc_213943984914_item	3521584	et	3	main
need	doc_213943984914_item	3521587	et	3	main
võtavad	doc_213943984914_item	3521626	et	3	main
olümpiaadist	doc_213943984914_item	3521629	et	3	main
samuti	doc_213943984914_item	3521630	et	3	main
saame	doc_213943984914_item	3521501	et	4	main
nii	doc_213943984914_item	3521502	et	3	main
öelda	doc_213943984914_item	3521503	et	4	main
informatiiv-kultuurset	doc_213943984914_item	3521504	et	3	main
projekt	doc_213943984914_item	3521511	et	3	main
põhineb	doc_213943984914_item	3521512	et	3	main
vene	doc_213943984914_item	3521513	et	4	main
muuseumi	doc_213943984914_item	3521514	et	4	main
virtuaalse	doc_213943984914_item	3521515	et	3	main
juhtkod	doc_213943984914_item	3521522	et	4	main
mille	doc_213943984914_item	3521523	et	3	main
virtuaalne	doc_213943984914_item	3521527	et	3	main
noorte	doc_213943984914_item	3521533	et	3	main
lisaks	doc_213943984914_item	3521535	et	4	main
sankt-peterburisse	doc_213943984914_item	3521540	et	4	main
kultuuripärandiga	doc_213943984914_item	3521541	et	4	main
selle	doc_213943984914_item	3521544	et	4	main
sihiks	doc_213943984914_item	3521546	et	4	main
on	doc_213943984914_item	3521547	et	4	main
kahe	doc_213943984914_item	3521548	et	3	main
aastaga	doc_213943984914_item	3521549	et	3	main
läbi	doc_213943984914_item	3521550	et	4	main
viia	doc_213943984914_item	3521551	et	3	main
vene	doc_213943984914_item	3521552	et	4	main
muuseumi	doc_213943984914_item	3521553	et	4	main
virtuaalne	doc_213943984914_item	3521554	et	3	main
analüüs	doc_213943984914_item	3521555	et	3	main
lisaks	doc_213943984914_item	3521556	et	4	main
valida	doc_213943984914_item	3521557	et	3	main
välja	doc_213943984914_item	3521558	et	4	main
infotehnoloogia	doc_213943984914_item	3521559	et	4	main
tudengid	doc_213943984914_item	3521560	et	3	main
nii	doc_213943984914_item	3521561	et	3	main
venelaste	doc_213943984914_item	3521562	et	4	main
kui	doc_213943984914_item	3521563	et	3	main
ka	doc_213943984914_item	3521564	et	3	main
hulgast	doc_213943984914_item	3521566	et	4	main
kes	doc_213943984914_item	3521567	et	4	main
tahavad	doc_213943984914_item	3521568	et	3	main
kasutada	doc_213943984914_item	3521569	et	3	main
õppekursust	doc_213943984914_item	3521577	et	3	main
kaks	doc_213943984914_item	3521578	et	3	main
ja	doc_213943984914_item	3521580	et	3	main
programmide	doc_213943984914_item	3521591	et	3	main
arendamisega	doc_213943984914_item	3521592	et	4	main
mida	doc_213943984914_item	3521593	et	4	main
hiljem	doc_213943984914_item	3521594	et	3	main
saame	doc_213943984914_item	3521595	et	4	main
kasutada	doc_213943984914_item	3521596	et	3	main
virtuaalses	doc_213943984914_item	3521597	et	3	main
filiaalis	doc_213943984914_item	3521598	et	3	main
kohtla-järvel	doc_213943984914_item	3521599	et	4	main
pealegi	doc_213943984914_item	3521600	et	4	main
vene	doc_213943984914_item	3521601	et	4	main
muuseumi	doc_213943984914_item	3521602	et	4	main
korraldavad	doc_213943984914_item	3521604	et	4	main
töötajad	doc_213943984914_item	3521603	et	4	main
kolm	doc_213943984914_item	3521605	et	3	main
doktorikraadiga	doc_213943984914_item	3521607	et	3	main
õppeseminari	doc_213943984914_item	3521606	et	4	main
boiko	doc_213943984914_item	3521608	et	4	main
on	doc_213943984914_item	3521609	et	4	main
juba	doc_213943984914_item	3521610	et	3	main
ühe	doc_213943984914_item	3521611	et	4	main
kursi	doc_213943984914_item	3521612	et	3	main
läbi	doc_213943984914_item	3521613	et	4	main
viinud	doc_213943984914_item	3521614	et	4	main
2006aastal	doc_213943984914_item	3521615	et	3	main
novembris	doc_213943984914_item	3521616	et	3	main
kohtla-järvel	doc_213943984914_item	3521617	et	4	main
mis	doc_213943984914_item	3521618	et	4	main
oli	doc_213943984914_item	3521619	et	3	main
äratanud	doc_213943984914_item	3521620	et	4	main
ühiskondlikku	doc_213943984914_item	3521621	et	4	main
huvi	doc_213943984914_item	3521622	et	4	main
keskkooli	doc_213943984914_item	3521624	et	4	main
xx	doc_384045275266_item	3522046	et	4	main
sajandi	doc_384045275266_item	3522047	et	3	main
3060	doc_384045275266_item	3522048	et	2	main
peipsimaa	doc_384045275266_item	3522053	et	4	main
teadlikult	doc_384045275266_item	3522058	et	4	main
mis	doc_384045275266_item	3522071	et	4	main
meie	doc_384045275266_item	3522072	et	4	main
nägemuse	doc_384045275266_item	3522073	et	3	main
vanausuliste	doc_384045275266_item	3522077	et	4	main
olulisemaid	doc_384045275266_item	3522083	et	4	main
külgi	doc_384045275266_item	3522084	et	4	main
vanasõnu	doc_384045275266_item	3522132	et	3	main
kõik	doc_384045275266_item	3522136	et	4	main
ja	doc_384045275266_item	3522144	et	3	main
pandud	doc_384045275266_item	3522158	et	4	main
on	doc_384045275266_item	3522160	et	4	main
publitseeritud	doc_384045275266_item	3522161	et	4	main
neis	doc_384045275266_item	3522164	et	4	main
kirjutatud	doc_384045275266_item	3522181	et	4	main
kirjamärke	doc_384045275266_item	3522206	et	4	main
pandud	doc_384045275266_item	3522213	et	4	main
kohaliku	doc_384045275266_item	3522214	et	3	main
märke	doc_384045275266_item	3522219	et	4	main
oleme	doc_384045275266_item	3522223	et	3	main
vanausuliste	doc_384045275266_item	3522231	et	4	main
ainult	doc_384045275266_item	3522239	et	4	main
antud	doc_384045275266_item	3522259	et	4	main
tõlge	doc_384045275266_item	3522034	et	3	main
antud	doc_384045275266_item	3522036	et	4	main
sisaldab	doc_384045275266_item	3522038	et	3	main
folkloorimaterjale	doc_384045275266_item	3522039	et	3	main
mitmest	doc_384045275266_item	3522040	et	4	main
kronoloogilisest	doc_384045275266_item	3522041	et	4	main
kihist	doc_384045275266_item	3522042	et	3	main
arhiivimaterjalid	doc_384045275266_item	3522043	et	3	main
aastatel	doc_384045275266_item	3522049	et	4	main
2006	doc_384045275266_item	3522051	et	2	main
loobusime	doc_384045275266_item	3522059	et	3	main
žanrite	doc_384045275266_item	3522063	et	2	main
valitud	doc_384045275266_item	3522065	et	4	main
tekstid	doc_384045275266_item	3522066	et	3	main
peatükkides	doc_384045275266_item	3522067	et	3	main
paigutasime	doc_384045275266_item	3522068	et	3	main
teemade	doc_384045275266_item	3522069	et	4	main
anname	doc_384045275266_item	3522085	et	3	main
et	doc_384045275266_item	3522088	et	3	main
valitud	doc_384045275266_item	3522091	et	4	main
materjali	doc_384045275266_item	3522092	et	4	main
peipsimaal	doc_384045275266_item	3522124	et	4	main
kirja	doc_384045275266_item	3522125	et	4	main
vene	doc_384045275266_item	3522133	et	4	main
folkloori	doc_384045275266_item	3522134	et	4	main
dešiffreeritud	doc_384045275266_item	3522145	et	2	main
kõik	doc_384045275266_item	3522149	et	4	main
säilitatud	doc_384045275266_item	3522166	et	4	main
kohalikule	doc_384045275266_item	3522167	et	3	main
murdekeelele	doc_384045275266_item	3522168	et	4	main
omane	doc_384045275266_item	3522169	et	3	main
tekstid	doc_384045275266_item	3522179	et	3	main
on	doc_384045275266_item	3522180	et	4	main
murdekeele	doc_384045275266_item	3522215	et	4	main
foneetilist	doc_384045275266_item	3522216	et	3	main
omapära	doc_384045275266_item	3522217	et	4	main
arhiivi	doc_384045275266_item	3522220	et	4	main
säilitanud	doc_384045275266_item	3522224	et	4	main
vaid	doc_384045275266_item	3522225	et	3	main
tseetamise	doc_384045275266_item	3522226	et	4	main
näiteid	doc_384045275266_item	3522227	et	3	main
selline	doc_384045275266_item	3522233	et	4	main
foneetiline	doc_384045275266_item	3522234	et	3	main
peipsimaal1	doc_384045275266_item	3522240	et	2	main
хх	doc_384045275266_item	3522252	et	2	main
sajandi	doc_384045275266_item	3522253	et	3	main
harilikus	doc_384045275266_item	3522261	et	4	main
haruldaste	doc_384045275266_item	3522263	et	3	main
kommentarid	doc_384045275266_item	3522270	et	4	main
on	doc_384045275266_item	3522271	et	4	main
ja	doc_384045275266_item	3522278	et	3	main
aeg	doc_384045275266_item	3522283	et	3	main
puhul	doc_384045275266_item	3522294	et	4	main
kereketkinat	doc_384045275266_item	3522342	et	4	main
vene	doc_384045275266_item	3522361	et	4	main
eriline	doc_384045275266_item	3522369	et	4	main
meie	doc_384045275266_item	3522375	et	4	main
haiglusele	doc_384045275266_item	3522383	et	4	main
ekspeditisiooni	doc_384045275266_item	3522054	et	4	main
struktuuris	doc_384045275266_item	3522057	et	3	main
esitamisviisist	doc_384045275266_item	3522062	et	3	main
peipsimaa	doc_384045275266_item	3522076	et	4	main
endale	doc_384045275266_item	3522086	et	4	main
teisi	doc_384045275266_item	3522131	et	4	main
aasta	doc_384045275266_item	3522138	et	4	main
kogumiku	doc_384045275266_item	3522146	et	4	main
on	doc_384045275266_item	3522151	et	4	main
ümbertrükitud	doc_384045275266_item	3522152	et	4	main
kirja	doc_384045275266_item	3522157	et	4	main
leksikaline	doc_384045275266_item	3522170	et	4	main
sõna-	doc_384045275266_item	3522171	et	4	main
lausemoodustuslik	doc_384045275266_item	3522173	et	4	main
omapära	doc_384045275266_item	3522174	et	4	main
on	doc_384045275266_item	3522175	et	4	main
äramärgitud	doc_384045275266_item	3522176	et	4	main
vene	doc_384045275266_item	3522182	et	4	main
kirjakeeles	doc_384045275266_item	3522183	et	4	main
samuti	doc_384045275266_item	3522184	et	3	main
materjalide	doc_384045275266_item	3522221	et	3	main
publitseerimisel	doc_384045275266_item	3522222	et	4	main
murdekeeles	doc_384045275266_item	3522232	et	4	main
nähtus	doc_384045275266_item	3522235	et	4	main
tänaseks	doc_384045275266_item	3522237	et	4	main
tekstides	doc_384045275266_item	3522241	et	3	main
tehtud	doc_384045275266_item	3522243	et	4	main
kupüüre	doc_384045275266_item	3522246	et	3	main
kommentaarid	doc_384045275266_item	3522257	et	3	main
on	doc_384045275266_item	3522258	et	4	main
kirjas	doc_384045275266_item	3522262	et	4	main
tähendus	doc_384045275266_item	3522265	et	4	main
meie	doc_384045275266_item	3522266	et	4	main
kogujate	doc_384045275266_item	3522279	et	4	main
zoja	doc_384045275266_item	3522337	et	4	main
kutkinat	doc_384045275266_item	3522338	et	4	main
korraldustöö	doc_384045275266_item	3522351	et	4	main
ja	doc_384045275266_item	3522352	et	3	main
pideva	doc_384045275266_item	3522353	et	3	main
hoolitsuse	doc_384045275266_item	3522354	et	4	main
rovnovat	doc_384045275266_item	3522358	et	4	main
potentsiaalsetest	doc_384045275266_item	3522367	et	3	main
esitajatest	doc_384045275266_item	3522368	et	4	main
kõikidele	doc_384045275266_item	3522374	et	4	main
kes	doc_384045275266_item	3522377	et	4	main
väljaanne	doc_384045275266_item	3522394	et	4	main
sai	doc_384045275266_item	3522401	et	4	main
ei	doc_384045275266_item	3522413	et	4	main
päike	doc_399014257247_item	3522423	et	3	main
käsitlemise	doc_399014257247_item	3522440	et	4	main
olemas	doc_399014257247_item	3522451	et	4	main
millega	doc_399014257247_item	3522453	et	3	main
ja	doc_399014257247_item	3522456	et	3	main
nagu	doc_399014257247_item	3522460	et	3	main
raamatus	doc_399014257247_item	3522466	et	4	main
ohvrid	doc_399014257247_item	3522471	et	3	main
juba	doc_399014257247_item	3522473	et	3	main
biibel	doc_399014257247_item	3522481	et	4	main
kaasaarvatult	doc_399014257247_item	3522482	et	4	main
juutide	doc_399014257247_item	3522483	et	3	main
genotsiidile	doc_399014257247_item	3522484	et	3	main
on	doc_399014257247_item	3522485	et	4	main
okupeeritud	doc_399014257247_item	3522521	et	4	main
kuigi	doc_399014257247_item	3522532	et	3	main
idabloki	doc_399014257247_item	3522534	et	3	main
põlvkonna	doc_399014257247_item	3522544	et	4	main
oma	doc_399014257247_item	3522549	et	4	main
koostajatelt	doc_384045275266_item	3522035	et	4	main
kogumik	doc_384045275266_item	3522037	et	3	main
ja	doc_384045275266_item	3522050	et	3	main
materjalid	doc_384045275266_item	3522055	et	3	main
materjali	doc_384045275266_item	3522060	et	4	main
traditsioonilisest	doc_384045275266_item	3522061	et	4	main
kaupa	doc_384045275266_item	3522064	et	4	main
järgi	doc_384045275266_item	3522074	et	4	main
eluolu	doc_384045275266_item	3522078	et	4	main
kombestiku	doc_384045275266_item	3522079	et	3	main
ja	doc_384045275266_item	3522080	et	3	main
vaimse	doc_384045275266_item	3522081	et	3	main
kultuuri	doc_384045275266_item	3522082	et	4	main
poolt	doc_384045275266_item	3522090	et	4	main
vene	doc_384045275266_item	3522127	et	4	main
vanasõnu	doc_384045275266_item	3522128	et	3	main
kui	doc_384045275266_item	3522129	et	3	main
ka	doc_384045275266_item	3522130	et	3	main
kirja	doc_384045275266_item	3522044	et	4	main
pandud	doc_384045275266_item	3522045	et	4	main
aasta	doc_384045275266_item	3522052	et	4	main
kogumiku	doc_384045275266_item	3522056	et	4	main
järgi	doc_384045275266_item	3522070	et	4	main
peegeldavad	doc_384045275266_item	3522075	et	4	main
aru	doc_384045275266_item	3522087	et	4	main
meie	doc_384045275266_item	3522089	et	4	main
jaotamine	doc_384045275266_item	3522093	et	4	main
on	doc_384045275266_item	3522094	et	4	main
teatud	doc_384045275266_item	3522095	et	4	main
määral	doc_384045275266_item	3522096	et	3	main
tinglik	doc_384045275266_item	3522097	et	3	main
kuna	doc_384045275266_item	3522098	et	3	main
mõned	doc_384045275266_item	3522099	et	3	main
tekstid	doc_384045275266_item	3522100	et	3	main
võivad	doc_384045275266_item	3522101	et	4	main
üheaegselt	doc_384045275266_item	3522102	et	4	main
ja	doc_384045275266_item	3522103	et	3	main
võrdsel	doc_384045275266_item	3522104	et	3	main
määral	doc_384045275266_item	3522105	et	3	main
kuuluda	doc_384045275266_item	3522106	et	4	main
mitsesse	doc_384045275266_item	3522107	et	4	main
peatükki	doc_384045275266_item	3522108	et	4	main
kuid	doc_384045275266_item	3522109	et	4	main
lõppkokkuvõttes	doc_384045275266_item	3522110	et	3	main
just	doc_384045275266_item	3522111	et	3	main
rahvakultuuri	doc_384045275266_item	3522112	et	4	main
liigendumatus	doc_384045275266_item	3522113	et	4	main
polüfunktsionaalsus	doc_384045275266_item	3522114	et	4	main
tõendab	doc_384045275266_item	3522115	et	3	main
folklooritraditsiooni	doc_384045275266_item	3522116	et	4	main
terviklikkust	doc_384045275266_item	3522117	et	4	main
ja	doc_384045275266_item	3522118	et	3	main
elujõulisust	doc_384045275266_item	3522119	et	4	main
peatükkide	doc_384045275266_item	3522120	et	3	main
pealkirjades	doc_384045275266_item	3522121	et	3	main
kasutasime	doc_384045275266_item	3522122	et	3	main
nii	doc_384045275266_item	3522123	et	3	main
pandud	doc_384045275266_item	3522126	et	4	main
kogumikes	doc_384045275266_item	3522135	et	4	main
tekstid	doc_384045275266_item	3522139	et	3	main
salvestatud	doc_384045275266_item	3522141	et	4	main
ekspeditsiooni	doc_384045275266_item	3522142	et	4	main
koostajate	doc_384045275266_item	3522147	et	4	main
poolt	doc_384045275266_item	3522148	et	4	main
arhiivimaterjalid	doc_384045275266_item	3522150	et	3	main
romanova	doc_384045275266_item	3522154	et	4	main
välitöödel	doc_384045275266_item	3522156	et	3	main
toimetamata	doc_384045275266_item	3522163	et	4	main
ja	doc_384045275266_item	3522172	et	3	main
kuna	doc_384045275266_item	3522228	et	3	main
baltikumis	doc_384045275266_item	3522229	et	4	main
2006	doc_384045275266_item	3522137	et	2	main
on	doc_384045275266_item	3522140	et	4	main
käigus	doc_384045275266_item	3522143	et	4	main
maria	doc_384045275266_item	3522153	et	4	main
poolt	doc_384045275266_item	3522155	et	4	main
tekstid	doc_384045275266_item	3522159	et	3	main
praktiliselt	doc_384045275266_item	3522162	et	4	main
on	doc_384045275266_item	3522165	et	4	main
mittenormikohane	doc_384045275266_item	3522177	et	4	main
sõnarõhk	doc_384045275266_item	3522178	et	3	main
oleme	doc_384045275266_item	3522185	et	3	main
teadlikult	doc_384045275266_item	3522186	et	4	main
loobunud	doc_384045275266_item	3522187	et	4	main
foneetilisest	doc_384045275266_item	3522188	et	2	main
transkriptsioonist	doc_384045275266_item	3522189	et	3	main
kuna	doc_384045275266_item	3522190	et	3	main
see	doc_384045275266_item	3522191	et	3	main
raskendab	doc_384045275266_item	3522192	et	3	main
folklooritekstide	doc_384045275266_item	3522193	et	3	main
lugemist	doc_384045275266_item	3522194	et	4	main
ja	doc_384045275266_item	3522195	et	3	main
tajumist	doc_384045275266_item	3522196	et	4	main
samu	doc_384045275266_item	3522197	et	3	main
põhimõtteid	doc_384045275266_item	3522198	et	3	main
oleme	doc_384045275266_item	3522199	et	3	main
kasutanud	doc_384045275266_item	3522200	et	4	main
ka	doc_384045275266_item	3522201	et	3	main
arhiivimaterjalide	doc_384045275266_item	3522202	et	3	main
publitseerimisel	doc_384045275266_item	3522203	et	4	main
lisanud	doc_384045275266_item	3522204	et	4	main
puuduvaid	doc_384045275266_item	3522205	et	4	main
parandanud	doc_384045275266_item	3522207	et	4	main
kirjavigu	doc_384045275266_item	3522208	et	3	main
ja	doc_384045275266_item	3522209	et	3	main
kõrvaldanud	doc_384045275266_item	3522210	et	4	main
kogujate	doc_384045275266_item	3522211	et	4	main
poolt	doc_384045275266_item	3522212	et	4	main
tähistavaid	doc_384045275266_item	3522218	et	4	main
elavate	doc_384045275266_item	3522230	et	4	main
fikseeritud	doc_384045275266_item	3522238	et	4	main
on	doc_384045275266_item	3522242	et	4	main
ka	doc_384045275266_item	3522244	et	3	main
kõik	doc_384045275266_item	3522247	et	4	main
nad	doc_384045275266_item	3522248	et	3	main
on	doc_384045275266_item	3522249	et	4	main
markeeritud	doc_384045275266_item	3522250	et	4	main
märgiga	doc_384045275266_item	3522251	et	3	main
esitajate	doc_384045275266_item	3522254	et	4	main
ja	doc_384045275266_item	3522255	et	3	main
kogujate	doc_384045275266_item	3522256	et	4	main
täpsustused	doc_384045275266_item	3522268	et	4	main
ja	doc_384045275266_item	3522269	et	3	main
toodud	doc_384045275266_item	3522275	et	4	main
nurksulgudes	doc_384045275266_item	3522276	et	3	main
andmed	doc_384045275266_item	3522281	et	3	main
koht	doc_384045275266_item	3522285	et	3	main
märgitud	doc_384045275266_item	3522287	et	4	main
kogujate	doc_384045275266_item	3522295	et	4	main
nimed	doc_384045275266_item	3522296	et	3	main
ei	doc_384045275266_item	3522297	et	4	main
hionia	doc_384045275266_item	3522339	et	4	main
poljakovat	doc_384045275266_item	3522344	et	4	main
olga	doc_384045275266_item	3522357	et	4	main
venemaa	doc_384045275266_item	3522359	et	4	main
teadusakadeemia	doc_384045275266_item	3522360	et	4	main
sügav	doc_384045275266_item	3522372	et	4	main
informantidele	doc_384045275266_item	3522376	et	4	main
vaatamata	doc_384045275266_item	3522378	et	4	main
oma	doc_384045275266_item	3522379	et	4	main
hõitatusele	doc_384045275266_item	3522380	et	4	main
nende	doc_384045275266_item	3522389	et	4	main
omakasupüüdmatu	doc_384045275266_item	3522390	et	4	main
abita	doc_384045275266_item	3522391	et	3	main
selle	doc_384045275266_item	3522392	et	4	main
fikseeritud	doc_384045275266_item	3522402	et	4	main
vaid	doc_384045275266_item	3522403	et	3	main
kaudne	doc_384045275266_item	3522405	et	3	main
tseetamisest	doc_384045275266_item	3522407	et	4	main
peipsiääre	doc_384045275266_item	3522408	et	3	main
informantide	doc_384045275266_item	3522418	et	4	main
külitlusel	doc_384045275266_item	3522419	et	4	main
meeles	doc_399014257247_item	3522421	et	3	main
täidab	doc_399014257247_item	3522425	et	3	main
hirmuga	doc_399014257247_item	3522428	et	3	main
teise	doc_399014257247_item	3522430	et	4	main
sümbool	doc_399014257247_item	3522432	et	4	main
sirp	doc_399014257247_item	3522433	et	3	main
ja	doc_399014257247_item	3522434	et	3	main
vasar	doc_399014257247_item	3522435	et	3	main
ajab	doc_399014257247_item	3522436	et	3	main
inimesed	doc_399014257247_item	3522437	et	3	main
naerma	doc_399014257247_item	3522438	et	3	main
holokausti	doc_399014257247_item	3522439	et	4	main
aastait	doc_399014257247_item	3522447	et	4	main
oli	doc_399014257247_item	3522449	et	3	main
märkib	doc_399014257247_item	3522463	et	4	main
mälestused	doc_399014257247_item	3522468	et	4	main
2006	doc_399014257247_item	3522469	et	2	main
olid	doc_399014257247_item	3522472	et	4	main
oma	doc_399014257247_item	3522479	et	4	main
kaanon	doc_399014257247_item	3522480	et	3	main
poolt	doc_399014257247_item	3522520	et	4	main
läänes	doc_399014257247_item	3522525	et	4	main
läbi	doc_399014257247_item	3522531	et	4	main
memuaarkirjandust	doc_399014257247_item	3522542	et	3	main
liita	doc_399014257247_item	3522548	et	4	main
sest	doc_399014257247_item	3522561	et	4	main
kes	doc_399014257247_item	3522587	et	4	main
suhtus	doc_399014257247_item	3522588	et	3	main
nõukogude	doc_399014257247_item	3522589	et	3	main
läbi	doc_399014257247_item	3522596	et	4	main
uuesti	doc_399014257247_item	3522605	et	3	main
on	doc_384045275266_item	3522236	et	4	main
mõningaid	doc_384045275266_item	3522245	et	3	main
küsimused	doc_384045275266_item	3522267	et	4	main
kirjutatud	doc_384045275266_item	3522272	et	4	main
kursiivkirjas	doc_384045275266_item	3522273	et	4	main
ja	doc_384045275266_item	3522274	et	3	main
arhiivimaterjalidest	doc_384045275266_item	3522280	et	3	main
ja	doc_384045275266_item	3522284	et	3	main
aasta	doc_384045275266_item	3522292	et	4	main
kirjapanekute	doc_384045275266_item	3522293	et	3	main
märgitud	doc_384045275266_item	3522299	et	4	main
folkloori	doc_384045275266_item	3522300	et	4	main
väkežaanrid	doc_384045275266_item	3522301	et	2	main
esitajate	doc_384045275266_item	3522302	et	4	main
põhjaliku	doc_384045275266_item	3522303	et	3	main
seletuseta	doc_384045275266_item	3522304	et	4	main
vanasõnad	doc_384045275266_item	3522305	et	3	main
kõnekäänded	doc_384045275266_item	3522306	et	3	main
mõistatused	doc_384045275266_item	3522307	et	4	main
enned	doc_384045275266_item	3522308	et	4	main
ei	doc_384045275266_item	3522309	et	4	main
ole	doc_384045275266_item	3522310	et	4	main
pasportiseeritud	doc_384045275266_item	3522311	et	4	main
juhul	doc_384045275266_item	3522312	et	3	main
kui	doc_384045275266_item	3522313	et	3	main
meetrikates	doc_384045275266_item	3522314	et	4	main
puuduvad	doc_384045275266_item	3522315	et	4	main
mingisugused	doc_384045275266_item	3522316	et	3	main
andmed	doc_384045275266_item	3522317	et	3	main
see	doc_384045275266_item	3522318	et	3	main
tähendab	doc_384045275266_item	3522319	et	3	main
et	doc_384045275266_item	3522320	et	3	main
andmed	doc_384045275266_item	3522321	et	3	main
koostajatel	doc_384045275266_item	3522322	et	4	main
puudusid	doc_384045275266_item	3522323	et	4	main
lõpetuseks	doc_384045275266_item	3522324	et	4	main
siiralt	doc_384045275266_item	3522325	et	4	main
täname	doc_384045275266_item	3522326	et	3	main
kohalike	doc_384045275266_item	3522327	et	4	main
entusiaste-koduloolasi	doc_384045275266_item	3522328	et	3	main
kohalike	doc_384045275266_item	3522329	et	4	main
vanauusliste	doc_384045275266_item	3522330	et	4	main
koguduste	doc_384045275266_item	3522331	et	4	main
juhte	doc_384045275266_item	3522332	et	4	main
ja	doc_384045275266_item	3522333	et	3	main
tegelasi	doc_384045275266_item	3522334	et	3	main
ümarsulgudes	doc_384045275266_item	3522260	et	3	main
murdesõnade	doc_384045275266_item	3522264	et	3	main
esitajate	doc_384045275266_item	3522277	et	4	main
kirjapaneku	doc_384045275266_item	3522282	et	3	main
on	doc_384045275266_item	3522286	et	4	main
iga	doc_384045275266_item	3522288	et	4	main
teksti	doc_384045275266_item	3522289	et	4	main
all	doc_384045275266_item	3522290	et	3	main
2006	doc_384045275266_item	3522291	et	2	main
ole	doc_384045275266_item	3522298	et	4	main
anastasija	doc_384045275266_item	3522335	et	4	main
olga	doc_384045275266_item	3522341	et	4	main
raissa	doc_384045275266_item	3522343	et	4	main
projektijuhte	doc_384045275266_item	3522345	et	4	main
pavel	doc_384045275266_item	3522346	et	4	main
ja	doc_384045275266_item	3522347	et	3	main
marina	doc_384045275266_item	3522348	et	3	main
eest	doc_384045275266_item	3522355	et	4	main
ja	doc_384045275266_item	3522356	et	3	main
kes	doc_384045275266_item	3522364	et	4	main
informeeris	doc_384045275266_item	3522365	et	3	main
meid	doc_384045275266_item	3522366	et	4	main
kummardus	doc_384045275266_item	3522373	et	4	main
vahel	doc_384045275266_item	3522381	et	4	main
ka	doc_384045275266_item	3522382	et	3	main
meiega	doc_384045275266_item	3522387	et	4	main
raamatu	doc_384045275266_item	3522393	et	4	main
võimatu	doc_384045275266_item	3522396	et	4	main
ekspeditsiooni	doc_384045275266_item	3522399	et	4	main
tõend	doc_384045275266_item	3522406	et	3	main
lõuna	doc_384045275266_item	3522409	et	4	main
osas	doc_384045275266_item	3522410	et	4	main
leidnud	doc_384045275266_item	3522414	et	4	main
veel	doc_384045275266_item	3522415	et	4	main
paistev	doc_399014257247_item	3522422	et	4	main
haakrist	doc_399014257247_item	3522426	et	3	main
käivitumisele	doc_399014257247_item	3522441	et	4	main
pärast	doc_399014257247_item	3522445	et	4	main
1940-ndeit	doc_399014257247_item	3522446	et	4	main
viis	doc_399014257247_item	3522452	et	4	main
genotsiidide	doc_399014257247_item	3522455	et	3	main
rõhumise	doc_399014257247_item	3522457	et	4	main
tekitatud	doc_399014257247_item	3522458	et	4	main
imbi	doc_399014257247_item	3522464	et	4	main
tradititsioonist	doc_399014257247_item	3522476	et	4	main
millel	doc_399014257247_item	3522477	et	3	main
olnud	doc_399014257247_item	3522489	et	4	main
oma	doc_399014257247_item	3522490	et	4	main
piibellik	doc_399014257247_item	3522491	et	3	main
aganitševat	doc_384045275266_item	3522336	et	2	main
tihhomirovat	doc_384045275266_item	3522340	et	4	main
varuninit	doc_384045275266_item	3522349	et	4	main
suurepärase	doc_384045275266_item	3522350	et	4	main
keele	doc_384045275266_item	3522362	et	4	main
instituut	doc_384045275266_item	3522363	et	3	main
tänu	doc_384045275266_item	3522370	et	4	main
ja	doc_384045275266_item	3522371	et	3	main
leidsid	doc_384045275266_item	3522384	et	4	main
aega	doc_384045275266_item	3522385	et	4	main
vestelda	doc_384045275266_item	3522386	et	4	main
oleks	doc_384045275266_item	3522395	et	3	main
1	doc_384045275266_item	3522397	et	2	main
üks	doc_384045275266_item	3522404	et	3	main
kinnitust	doc_384045275266_item	3522416	et	4	main
tõlge	doc_399014257247_item	3522420	et	3	main
head	doc_399014257247_item	3522443	et	4	main
eeldused	doc_399014257247_item	3522444	et	4	main
juutidel	doc_399014257247_item	3522448	et	3	main
tõrjutud	doc_399014257247_item	3522467	et	4	main
on	doc_399014257247_item	3522478	et	4	main
40-ndatest	doc_399014257247_item	3522486	et	4	main
nimetus	doc_399014257247_item	3522492	et	4	main
shoa	doc_399014257247_item	3522493	et	4	main
praegu	doc_399014257247_item	3522494	et	3	main
loetakse	doc_399014257247_item	3522524	et	3	main
ikka	doc_399014257247_item	3522526	et	4	main
veel	doc_399014257247_item	3522527	et	4	main
tihti	doc_399014257247_item	3522528	et	3	main
nõukogude	doc_399014257247_item	3522529	et	3	main
endistes	doc_399014257247_item	3522533	et	3	main
ilmunud	doc_399014257247_item	3522537	et	4	main
nõukogude	doc_399014257247_item	3522539	et	3	main
käsitlevat	doc_399014257247_item	3522541	et	4	main
asemel	doc_399014257247_item	3522553	et	4	main
ostalgiasse	doc_399014257247_item	3522557	et	4	main
see	doc_399014257247_item	3522558	et	3	main
ongi	doc_399014257247_item	3522559	et	4	main
populäärsus	doc_399014257247_item	3522582	et	4	main
nooruse	doc_399014257247_item	3522598	et	4	main
ole	doc_399014257247_item	3522601	et	4	main
kullatud	doc_399014257247_item	3522606	et	4	main
juba	doc_399014257247_item	3522623	et	3	main
võitjate	doc_399014257247_item	3522631	et	4	main
suudetud	doc_399014257247_item	3522636	et	4	main
ja	doc_399014257247_item	3522645	et	3	main
on	doc_399014257247_item	3522647	et	4	main
ja	doc_399014257247_item	3522651	et	3	main
ümber	doc_399014257247_item	3522653	et	3	main
ei	doc_399014257247_item	3522657	et	4	main
kaotanud	doc_399014257247_item	3522658	et	4	main
teist	doc_399014257247_item	3522659	et	4	main
on	doc_399014257247_item	3522663	et	4	main
oma	doc_399014257247_item	3522677	et	4	main
saama	doc_399014257247_item	3522697	et	4	main
ilma	doc_384045275266_item	3522388	et	4	main
meie	doc_384045275266_item	3522398	et	4	main
käigus	doc_384045275266_item	3522400	et	4	main
mis	doc_384045275266_item	3522411	et	4	main
aga	doc_384045275266_item	3522412	et	3	main
teiste	doc_384045275266_item	3522417	et	4	main
millepärast	doc_399014257247_item	3522424	et	3	main
inimesed	doc_399014257247_item	3522427	et	3	main
aga	doc_399014257247_item	3522429	et	3	main
massimõrva	doc_399014257247_item	3522431	et	4	main
olid	doc_399014257247_item	3522442	et	4	main
juba	doc_399014257247_item	3522450	et	3	main
väljendada	doc_399014257247_item	3522454	et	3	main
häda	doc_399014257247_item	3522459	et	4	main
mikael	doc_399014257247_item	3522461	et	4	main
enckell	doc_399014257247_item	3522462	et	4	main
paju	doc_399014257247_item	3522465	et	4	main
antisemitismi	doc_399014257247_item	3522470	et	4	main
osa	doc_399014257247_item	3522474	et	4	main
laiast	doc_399014257247_item	3522475	et	4	main
aastatest	doc_399014257247_item	3522487	et	4	main
saadik	doc_399014257247_item	3522488	et	4	main
teatakse	doc_399014257247_item	3522495	et	3	main
holokaustist	doc_399014257247_item	3522496	et	4	main
üldiselt	doc_399014257247_item	3522497	et	4	main
ja	doc_399014257247_item	3522498	et	3	main
sellest	doc_399014257247_item	3522499	et	4	main
kirjutavad	doc_399014257247_item	3522500	et	4	main
juba	doc_399014257247_item	3522501	et	3	main
holokausti	doc_399014257247_item	3522502	et	4	main
elanute	doc_399014257247_item	3522504	et	4	main
lapselapsed	doc_399014257247_item	3522505	et	3	main
nõukogude	doc_399014257247_item	3522506	et	3	main
liidus	doc_399014257247_item	3522507	et	4	main
läbi	doc_399014257247_item	3522503	et	4	main
toimunud	doc_399014257247_item	3522508	et	4	main
rahvate	doc_399014257247_item	3522509	et	4	main
sunnitud	doc_399014257247_item	3522510	et	4	main
ümberasutamist	doc_399014257247_item	3522511	et	3	main
hakati	doc_399014257247_item	3522512	et	3	main
nimetama	doc_399014257247_item	3522513	et	3	main
küüditamisteks	doc_399014257247_item	3522514	et	4	main
alles	doc_399014257247_item	3522515	et	3	main
90-ndatel	doc_399014257247_item	3522516	et	4	main
ja	doc_399014257247_item	3522517	et	3	main
nõukogude	doc_399014257247_item	3522518	et	3	main
liidu	doc_399014257247_item	3522519	et	3	main
ajalugu	doc_399014257247_item	3522523	et	4	main
narratiivi	doc_399014257247_item	3522530	et	4	main
riikides	doc_399014257247_item	3522535	et	3	main
palju	doc_399014257247_item	3522538	et	4	main
terrorit	doc_399014257247_item	3522540	et	3	main
noore	doc_399014257247_item	3522543	et	3	main
kirjanikud	doc_399014257247_item	3522545	et	3	main
on	doc_399014257247_item	3522546	et	4	main
kerge	doc_399014257247_item	3522560	et	4	main
rahvusvaheline	doc_399014257247_item	3522581	et	4	main
ka	doc_399014257247_item	3522585	et	3	main
lugeja	doc_399014257247_item	3522586	et	4	main
pea	doc_399014257247_item	3522593	et	4	main
ebameeldivaid	doc_399014257247_item	3522594	et	3	main
maade	doc_399014257247_item	3522522	et	3	main
on	doc_399014257247_item	3522536	et	4	main
tahtnud	doc_399014257247_item	3522547	et	4	main
idanostalgiasse	doc_399014257247_item	3522555	et	3	main
nõukogude	doc_399014257247_item	3522562	et	3	main
huumor	doc_399014257247_item	3522563	et	3	main
on	doc_399014257247_item	3522564	et	4	main
olnud	doc_399014257247_item	3522565	et	4	main
iseenda	doc_399014257247_item	3522566	et	3	main
liigiks	doc_399014257247_item	3522567	et	4	main
nii	doc_399014257247_item	3522568	et	3	main
läänes	doc_399014257247_item	3522569	et	4	main
kui	doc_399014257247_item	3522570	et	3	main
ka	doc_399014257247_item	3522571	et	3	main
idas	doc_399014257247_item	3522572	et	3	main
ostalgiasse	doc_399014257247_item	3522573	et	4	main
liitumine	doc_399014257247_item	3522574	et	4	main
toob	doc_399014257247_item	3522575	et	3	main
kirjanikule	doc_399014257247_item	3522576	et	3	main
laia	doc_399014257247_item	3522577	et	4	main
lugejaskonna	doc_399014257247_item	3522578	et	3	main
ja	doc_399014257247_item	3522579	et	3	main
ka	doc_399014257247_item	3522580	et	3	main
tagatud	doc_399014257247_item	3522584	et	4	main
teosed	doc_399014257247_item	3522550	et	3	main
vangilaagrikirjanduse	doc_399014257247_item	3522551	et	3	main
genre	doc_399014257247_item	3522552	et	4	main
humoristlikusse	doc_399014257247_item	3522554	et	4	main
ehk	doc_399014257247_item	3522556	et	3	main
liidusse	doc_399014257247_item	3522590	et	3	main
sõbralikult	doc_399014257247_item	3522591	et	4	main
ei	doc_399014257247_item	3522592	et	4	main
mälestusi	doc_399014257247_item	3522599	et	4	main
mustaks	doc_399014257247_item	3522603	et	4	main
ja	doc_399014257247_item	3522611	et	3	main
ka	doc_399014257247_item	3522612	et	3	main
tšehhovi	doc_399014257247_item	3522624	et	2	main
sahalinist	doc_399014257247_item	3522625	et	4	main
ajalugu	doc_399014257247_item	3522628	et	4	main
hitleri	doc_399014257247_item	3522638	et	4	main
on	doc_399014257247_item	3522642	et	4	main
neid	doc_399014257247_item	3522646	et	4	main
käsitlenud	doc_399014257247_item	3522648	et	4	main
maailma	doc_399014257247_item	3522654	et	4	main
nõukogude	doc_399014257247_item	3522655	et	3	main
kui	doc_399014257247_item	3522670	et	3	main
pidi	doc_399014257247_item	3522673	et	4	main
ikka	doc_399014257247_item	3522675	et	4	main
peab	doc_399014257247_item	3522676	et	4	main
tegema	doc_399014257247_item	3522683	et	3	main
kiire	doc_399014257247_item	3522686	et	4	main
tempoga	doc_399014257247_item	3522687	et	3	main
ka	doc_399014257247_item	3522688	et	3	main
ja	doc_399014257247_item	3522692	et	3	main
viimaks	doc_399014257247_item	3522695	et	4	main
hakanud	doc_399014257247_item	3522696	et	4	main
põhjadimensiooni	doc_399014257246_item	3522721	et	4	main
et	doc_399014257246_item	3522736	et	3	main
loode-venemaal	doc_399014257246_item	3522739	et	4	main
põhjust	doc_399014257246_item	3522741	et	4	main
kasu	doc_399014257246_item	3522750	et	4	main
eli	doc_399014257246_item	3522768	et	4	main
liikmesriigid	doc_399014257246_item	3522769	et	3	main
ja	doc_399014257246_item	3522770	et	3	main
euroopa	doc_399014257246_item	3522771	et	4	main
läänemeremaade	doc_399014257246_item	3522791	et	3	main
nõukogu	doc_399014257246_item	3522800	et	4	main
ja	doc_399014257246_item	3522801	et	3	main
nõukogu	doc_399014257246_item	3522804	et	4	main
ning	doc_399014257246_item	3522805	et	3	main
rahvusvahelised	doc_399014257246_item	3522806	et	4	main
finantsorganisatsioonid	doc_399014257246_item	3522807	et	3	main
on	doc_399014257246_item	3522812	et	4	main
majandus	doc_399014257246_item	3522813	et	4	main
inimkapital	doc_399014257246_item	3522814	et	3	main
regionaalne	doc_399014257246_item	3522824	et	3	main
koostöö	doc_399014257246_item	3522825	et	4	main
justiits-	doc_399014257246_item	3522827	et	3	main
siseküsimused	doc_399014257246_item	3522829	et	3	main
euroopa	doc_399014257246_item	3522837	et	4	main
liidu	doc_399014257246_item	3522838	et	3	main
keskkonnapartnerlus	doc_399014257246_item	3522879	et	3	main
ning	doc_399014257246_item	3522883	et	3	main
turvalisem	doc_399014257246_item	3522904	et	4	main
projekte	doc_399014257246_item	3522936	et	3	main
eestile	doc_399014257246_item	3522940	et	3	main
euroopa	doc_399014257246_item	3522945	et	4	main
venemaale	doc_399014257246_item	3522948	et	4	main
rahastamine	doc_399014257246_item	3522951	et	4	main
et	doc_399014257246_item	3522954	et	3	main
toetusfondist	doc_399014257246_item	3522958	et	3	main
ning	doc_399014257246_item	3522966	et	3	main
kanada	doc_399014257246_item	3522970	et	4	main
teinud	doc_399014257246_item	3522972	et	4	main
annetusi	doc_399014257246_item	3522973	et	4	main
ei	doc_399014257246_item	3522978	et	4	main
pärine	doc_399014257246_item	3522979	et	4	main
partnerluse	doc_399014257246_item	3523002	et	3	main
läheb	doc_399014257244_item	3523042	et	3	main
tuomioja	doc_399014257244_item	3523066	et	4	main
eli	doc_399014257244_item	3523071	et	4	main
et	doc_399014257244_item	3523080	et	3	main
aru	doc_399014257244_item	3523096	et	4	main
lisamiseks	doc_399014257244_item	3523106	et	4	main
on	doc_399014257244_item	3523121	et	4	main
on	doc_399014257247_item	3522583	et	4	main
elama	doc_399014257247_item	3522597	et	3	main
ostalgia	doc_399014257247_item	3522609	et	4	main
on	doc_399014257247_item	3522619	et	4	main
tundeid	doc_399014257247_item	3522595	et	3	main
ei	doc_399014257247_item	3522600	et	4	main
tehtud	doc_399014257247_item	3522602	et	4	main
vaid	doc_399014257247_item	3522604	et	3	main
miks	doc_399014257247_item	3522607	et	4	main
on	doc_399014257247_item	3522608	et	4	main
kui	doc_399014257247_item	3522615	et	3	main
vangilaagrikirjandus	doc_399014257247_item	3522616	et	3	main
mille	doc_399014257247_item	3522617	et	3	main
ajalugu	doc_399014257247_item	3522618	et	4	main
pikem	doc_399014257247_item	3522621	et	4	main
kuna	doc_399014257247_item	3522627	et	3	main
on	doc_399014257247_item	3522629	et	4	main
ajalugu	doc_399014257247_item	3522632	et	4	main
rääkida	doc_399014257247_item	3522637	et	3	main
mõistetud	doc_399014257247_item	3522643	et	4	main
mis	doc_399014257247_item	3522672	et	4	main
ja	doc_399014257247_item	3522674	et	3	main
ja	doc_399014257247_item	3522680	et	3	main
selgeks	doc_399014257247_item	3522682	et	3	main
selgitab	doc_399014257247_item	3522685	et	3	main
oma	doc_399014257247_item	3522689	et	4	main
suhet	doc_399014257247_item	3522690	et	3	main
ida-saksamaaga	doc_399014257247_item	3522691	et	3	main
on	doc_399014257247_item	3522694	et	4	main
vajatakse	doc_399014257246_item	3522722	et	4	main
sai	doc_399014257246_item	3522726	et	4	main
poliitika	doc_399014257246_item	3522729	et	4	main
osa	doc_399014257246_item	3522730	et	4	main
aastal	doc_399014257246_item	3522731	et	3	main
1999	doc_399014257246_item	3522732	et	2	main
taustaks	doc_399014257246_item	3522733	et	3	main
oli	doc_399014257246_item	3522734	et	3	main
koostöö	doc_399014257246_item	3522743	et	4	main
tegemiseks	doc_399014257246_item	3522744	et	4	main
ja	doc_399014257246_item	3522745	et	3	main
aru	doc_399014257246_item	3522752	et	4	main
et	doc_399014257246_item	3522753	et	3	main
on	doc_399014257246_item	3522756	et	4	main
parim	doc_399014257246_item	3522757	et	4	main
lisamiseks	doc_399014257246_item	3522762	et	4	main
on	doc_399014257246_item	3522767	et	4	main
venemaa	doc_399014257246_item	3522773	et	4	main
vaatlejad	doc_399014257246_item	3522782	et	4	main
riigid	doc_399014257246_item	3522783	et	3	main
teised	doc_399014257246_item	3522784	et	4	main
tähtsad	doc_399014257246_item	3522785	et	3	main
nõukogud	doc_399014257246_item	3522790	et	3	main
nõukogu	doc_399014257246_item	3522794	et	4	main
barentsi	doc_399014257246_item	3522795	et	4	main
põhjamaade	doc_399014257246_item	3522802	et	3	main
tegevuskava	doc_399014257246_item	3522809	et	4	main
alajaotused	doc_399014257246_item	3522811	et	4	main
piiriülene	doc_399014257246_item	3522822	et	3	main
ning	doc_399014257246_item	3522826	et	3	main
on	doc_399014257246_item	3522831	et	4	main
kirde-euroopale	doc_399014257246_item	3522841	et	3	main
mõiste	doc_399014257246_item	3522845	et	4	main
avamiseks	doc_399014257246_item	3522857	et	4	main
põhjadimensioon	doc_399014257246_item	3522859	et	3	main
on	doc_399014257246_item	3522860	et	4	main
projektidena	doc_399014257246_item	3522873	et	3	main
kaks	doc_399014257246_item	3522878	et	3	main
loodi	doc_399014257246_item	3522880	et	4	main
heaolu	doc_399014257246_item	3522887	et	4	main
keskkonnapartnerluse	doc_399014257246_item	3522891	et	3	main
on	doc_399014257246_item	3522893	et	4	main
õhu	doc_399014257246_item	3522896	et	3	main
keskkonnasõbralikum	doc_399014257246_item	3522900	et	4	main
keskkonnapartnerluse	doc_399014257246_item	3522907	et	3	main
projektide	doc_399014257246_item	3522908	et	3	main
praegune	doc_399014257246_item	3522909	et	3	main
lisada	doc_399014257246_item	3522918	et	3	main
maksumus	doc_399014257246_item	3522922	et	3	main
tõuseb	doc_399014257246_item	3522923	et	3	main
kogumaksumus	doc_399014257246_item	3522924	et	3	main
umbes	doc_399014257246_item	3522925	et	4	main
miljardi	doc_399014257246_item	3522927	et	3	main
euroni	doc_399014257246_item	3522928	et	3	main
nii	doc_399014257246_item	3522929	et	3	main
summaga	doc_399014257246_item	3522931	et	4	main
atraktiivsem	doc_399014257247_item	3522610	et	4	main
meediale	doc_399014257247_item	3522613	et	4	main
ahvatlevam	doc_399014257247_item	3522614	et	4	main
siiski	doc_399014257247_item	3522620	et	4	main
kaotanute	doc_399014257247_item	3522633	et	4	main
tegudest	doc_399014257247_item	3522634	et	3	main
tegud	doc_399014257247_item	3522639	et	4	main
ja	doc_399014257247_item	3522640	et	3	main
natsionaalsotsialism	doc_399014257247_item	3522641	et	3	main
lugematud	doc_399014257247_item	3522649	et	4	main
liit	doc_399014257247_item	3522656	et	3	main
sellepärast	doc_399014257247_item	3522662	et	3	main
poolt	doc_399014257247_item	3522665	et	4	main
okupeeritud	doc_399014257247_item	3522666	et	4	main
maade	doc_399014257247_item	3522667	et	3	main
seisund	doc_399014257247_item	3522668	et	3	main
teine	doc_399014257247_item	3522669	et	3	main
minevikku	doc_399014257247_item	3522678	et	4	main
teistele	doc_399014257247_item	3522681	et	4	main
saksa	doc_399014257247_item	3522684	et	4	main
ostalgia	doc_399014257247_item	3522693	et	4	main
ka	doc_399014257246_item	3522723	et	3	main
põhjadimensioonist	doc_399014257246_item	3522725	et	3	main
välissuhete	doc_399014257246_item	3522728	et	3	main
el-l	doc_399014257246_item	3522737	et	3	main
saadi	doc_399014257246_item	3522751	et	4	main
tugevdamine	doc_399014257246_item	3522755	et	4	main
stabiilsuse	doc_399014257246_item	3522761	et	4	main
osapooled	doc_399014257246_item	3522766	et	4	main
kanada	doc_399014257246_item	3522781	et	4	main
põhjala	doc_399014257246_item	3522788	et	4	main
piirkondlikud	doc_399014257246_item	3522789	et	3	main
nõukogu	doc_399014257246_item	3522797	et	4	main
balti	doc_399014257246_item	3522798	et	3	main
sh	doc_399014257246_item	3522815	et	4	main
tervise-	doc_399014257246_item	3522816	et	3	main
ja	doc_399014257246_item	3522817	et	3	main
sotsiaalküsimused	doc_399014257246_item	3522818	et	3	main
keskkonna-	doc_399014257246_item	3522819	et	3	main
alates	doc_399014257247_item	3522622	et	3	main
1895	doc_399014257247_item	3522626	et	2	main
alati	doc_399014257247_item	3522630	et	4	main
on	doc_399014257247_item	3522635	et	4	main
hukka	doc_399014257247_item	3522644	et	4	main
filmid	doc_399014257247_item	3522650	et	4	main
raamatud	doc_399014257247_item	3522652	et	4	main
maailmasõda	doc_399014257247_item	3522660	et	4	main
ja	doc_399014257247_item	3522661	et	3	main
selle	doc_399014257247_item	3522664	et	4	main
saksamaa	doc_399014257247_item	3522671	et	4	main
iseendale	doc_399014257247_item	3522679	et	3	main
ka	doc_399014257247_item	3522698	et	3	main
kriitilist	doc_399014257247_item	3522699	et	3	main
kuju	doc_399014257247_item	3522700	et	4	main
võibolla	doc_399014257247_item	3522701	et	4	main
on	doc_399014257247_item	3522702	et	4	main
sakslastel	doc_399014257247_item	3522703	et	3	main
rohkem	doc_399014257247_item	3522704	et	4	main
vahendeid	doc_399014257247_item	3522705	et	3	main
et	doc_399014257247_item	3522706	et	3	main
oma	doc_399014257247_item	3522707	et	4	main
suhet	doc_399014257247_item	3522708	et	3	main
kommunismiga	doc_399014257247_item	3522709	et	3	main
käsitleda	doc_399014257247_item	3522710	et	3	main
sest	doc_399014257247_item	3522711	et	4	main
nad	doc_399014257247_item	3522712	et	3	main
on	doc_399014257247_item	3522713	et	4	main
pidanud	doc_399014257247_item	3522714	et	4	main
oma	doc_399014257247_item	3522715	et	4	main
natsiminevikuga	doc_399014257247_item	3522716	et	3	main
väga	doc_399014257247_item	3522717	et	3	main
palju	doc_399014257247_item	3522718	et	4	main
tegelema	doc_399014257247_item	3522719	et	3	main
tõlge	doc_399014257246_item	3522720	et	3	main
eli	doc_399014257246_item	3522727	et	4	main
ja	doc_399014257246_item	3522738	et	3	main
on	doc_399014257246_item	3522740	et	4	main
omavahelise	doc_399014257246_item	3522742	et	4	main
heaolu	doc_399014257246_item	3522759	et	4	main
ja	doc_399014257246_item	3522760	et	3	main
komisjon	doc_399014257246_item	3522772	et	3	main
norra	doc_399014257246_item	3522774	et	4	main
island	doc_399014257246_item	3522776	et	4	main
on	doc_399014257246_item	3522777	et	4	main
partnerriigid	doc_399014257246_item	3522778	et	3	main
ühendriigid	doc_399014257246_item	3522779	et	3	main
ja	doc_399014257246_item	3522780	et	3	main
euro-arktika	doc_399014257246_item	3522796	et	4	main
põhjadimensiooni	doc_399014257246_item	3522808	et	4	main
tuumaohutusküsimused	doc_399014257246_item	3522821	et	3	main
poliitika	doc_399014257246_item	3522833	et	4	main
mille	doc_399014257246_item	3522834	et	3	main
abil	doc_399014257246_item	3522835	et	4	main
ülatasandi	doc_399014257246_item	3522842	et	3	main
on	doc_399014257246_item	3522844	et	4	main
mida	doc_399014257246_item	3522846	et	4	main
kasutatakse	doc_399014257246_item	3522847	et	3	main
poliitilistes	doc_399014257246_item	3522848	et	3	main
tulevikus	doc_399014257246_item	3522724	et	4	main
mõte	doc_399014257246_item	3522735	et	3	main
et	doc_399014257246_item	3522746	et	3	main
mõlemad	doc_399014257246_item	3522747	et	3	main
lõikavad	doc_399014257246_item	3522748	et	4	main
sellest	doc_399014257246_item	3522749	et	4	main
koostöö	doc_399014257246_item	3522754	et	4	main
viis	doc_399014257246_item	3522758	et	4	main
kogu	doc_399014257246_item	3522763	et	4	main
kirde-euroopas	doc_399014257246_item	3522764	et	3	main
põhjadimensiooni	doc_399014257246_item	3522765	et	4	main
ja	doc_399014257246_item	3522775	et	3	main
tegutsejad	doc_399014257246_item	3522786	et	4	main
on	doc_399014257246_item	3522787	et	4	main
nõukogu	doc_399014257246_item	3522792	et	4	main
arktika	doc_399014257246_item	3522793	et	4	main
ministrite	doc_399014257246_item	3522799	et	3	main
ministrite	doc_399014257246_item	3522803	et	3	main
peamised	doc_399014257246_item	3522810	et	3	main
ja	doc_399014257246_item	3522820	et	3	main
on	doc_399014257246_item	3522836	et	4	main
suunatud	doc_399014257246_item	3522840	et	4	main
on	doc_399014257246_item	3522852	et	4	main
ka	doc_399014257246_item	3522871	et	3	main
on	doc_399014257246_item	3522877	et	4	main
aastal	doc_399014257246_item	3522882	et	3	main
sotsiaalse	doc_399014257246_item	3522886	et	3	main
2003	doc_399014257246_item	3522889	et	2	main
ja	doc_399014257246_item	3522895	et	3	main
ladustamine	doc_399014257246_item	3522905	et	4	main
sellele	doc_399014257246_item	3522917	et	4	main
meie	doc_399014257246_item	3522934	et	4	main
ülejäänud	doc_399014257246_item	3522944	et	4	main
partnerluse	doc_399014257246_item	3522957	et	3	main
komisjon	doc_399014257246_item	3522961	et	3	main
hulk	doc_399014257246_item	3522963	et	3	main
liikmesriike	doc_399014257246_item	3522965	et	3	main
suurem	doc_399014257246_item	3522974	et	4	main
siiski	doc_399014257246_item	3522980	et	4	main
toetusfondist	doc_399014257246_item	3522981	et	3	main
vaid	doc_399014257246_item	3522982	et	3	main
rahvusvahelistelt	doc_399014257246_item	3522987	et	4	main
võtjateks	doc_399014257246_item	3523001	et	4	main
peterburi	doc_399014257246_item	3523005	et	4	main
edelapoolne	doc_399014257246_item	3523006	et	3	main
ja	doc_399014257246_item	3522823	et	3	main
ja	doc_399014257246_item	3522828	et	3	main
ülatasandil	doc_399014257246_item	3522830	et	3	main
põhjadimensioon	doc_399014257246_item	3522832	et	3	main
tähelepanu	doc_399014257246_item	3522839	et	4	main
põhjadimensioon	doc_399014257246_item	3522843	et	3	main
olnud	doc_399014257246_item	3522853	et	4	main
hädavajalik	doc_399014257246_item	3522854	et	3	main
mitmesuguste	doc_399014257246_item	3522855	et	3	main
finantseerimisallikate	doc_399014257246_item	3522856	et	3	main
kuid	doc_399014257246_item	3522858	et	4	main
siiski	doc_399014257246_item	3522861	et	4	main
tähtsusetu	doc_399014257246_item	3522862	et	4	main
kui	doc_399014257246_item	3522863	et	3	main
see	doc_399014257246_item	3522864	et	3	main
ei	doc_399014257246_item	3522865	et	4	main
avaldu	doc_399014257246_item	3522866	et	4	main
ka	doc_399014257246_item	3522867	et	3	main
praktikas	doc_399014257246_item	3522868	et	3	main
põhjadimensioon	doc_399014257246_item	3522869	et	3	main
avaldub	doc_399014257246_item	3522870	et	3	main
kõnedes	doc_399014257246_item	3522849	et	3	main
ja	doc_399014257246_item	3522850	et	3	main
mis	doc_399014257246_item	3522851	et	4	main
neid	doc_399014257246_item	3522876	et	4	main
2001	doc_399014257246_item	3522881	et	2	main
ja	doc_399014257246_item	3522885	et	3	main
aastal	doc_399014257246_item	3522890	et	3	main
eesmärk	doc_399014257246_item	3522892	et	3	main
vee	doc_399014257246_item	3522894	et	3	main
puhastamine	doc_399014257246_item	3522897	et	4	main
tahkete	doc_399014257246_item	3522898	et	4	main
loode-venemaal	doc_399014257246_item	3522906	et	4	main
maksumus	doc_399014257246_item	3522910	et	3	main
ka	doc_399014257246_item	3522919	et	3	main
lisaprojektide	doc_399014257246_item	3522921	et	3	main
lähipiirkondades	doc_399014257246_item	3522935	et	3	main
olulised	doc_399014257246_item	3522939	et	4	main
projektide	doc_399014257246_item	3522950	et	3	main
nii	doc_399014257246_item	3522953	et	3	main
norra	doc_399014257246_item	3522968	et	4	main
projektide	doc_399014257246_item	3522976	et	3	main
on	doc_399014257246_item	3522983	et	4	main
laenuraha	doc_399014257246_item	3522984	et	4	main
finantsasutustelt	doc_399014257246_item	3522988	et	4	main
vene	doc_399014257246_item	3522990	et	4	main
esimene	doc_399014257246_item	3523003	et	3	main
projekt	doc_399014257246_item	3523004	et	3	main
veepuhastusjaam	doc_399014257246_item	3523007	et	3	main
valminud	doc_399014257246_item	3523009	et	4	main
sellel	doc_399014257246_item	3523010	et	4	main
sügisel	doc_399014257246_item	3523011	et	3	main
tunduvalt	doc_399014257246_item	3523020	et	4	main
äsja	doc_399014257246_item	3523021	et	3	main
on	doc_399014257246_item	3523022	et	4	main
käivitunud	doc_399014257246_item	3523023	et	4	main
ka	doc_399014257246_item	3523024	et	3	main
esimesed	doc_399014257246_item	3523025	et	3	main
tuumajäätmete-alased	doc_399014257246_item	3523026	et	4	main
projektid	doc_399014257246_item	3523027	et	3	main
need	doc_399014257246_item	3523028	et	3	main
puudutavad	doc_399014257246_item	3523029	et	4	main
gremihha	doc_399014257246_item	3523030	et	4	main
piirkonna	doc_399014257246_item	3523031	et	4	main
tuumajäätmete	doc_399014257246_item	3523032	et	4	main
ladustamist	doc_399014257246_item	3523033	et	4	main
ning	doc_399014257246_item	3523034	et	3	main
murmanski	doc_399014257246_item	3523035	et	4	main
piirkonna	doc_399014257246_item	3523036	et	4	main
kiirreageerimissüsteemi	doc_399014257246_item	3523037	et	4	main
kiirgusohu	doc_399014257246_item	3523038	et	3	main
mõõdet	doc_399014257244_item	3523041	et	4	main
loob	doc_399014257244_item	3523048	et	3	main
teostusele	doc_399014257244_item	3523054	et	4	main
välispoliitika	doc_399014257244_item	3523072	et	4	main
taustal	doc_399014257244_item	3523076	et	3	main
koostöö	doc_399014257244_item	3523098	et	4	main
viis	doc_399014257244_item	3523102	et	4	main
heaolu	doc_399014257244_item	3523103	et	4	main
ja	doc_399014257244_item	3523104	et	3	main
partnerriigid	doc_399014257244_item	3523122	et	3	main
ja	doc_399014257244_item	3523124	et	3	main
konkreetsete	doc_399014257246_item	3522872	et	3	main
näiteks	doc_399014257246_item	3522874	et	4	main
partnerlusprojektidena	doc_399014257246_item	3522875	et	3	main
rahvatervise	doc_399014257246_item	3522884	et	3	main
partnerlus	doc_399014257246_item	3522888	et	3	main
jäätmete	doc_399014257246_item	3522899	et	4	main
käitlemine	doc_399014257246_item	3522901	et	4	main
ning	doc_399014257246_item	3522902	et	3	main
tuumajäätmete	doc_399014257246_item	3522903	et	4	main
on	doc_399014257246_item	3522911	et	4	main
umbes	doc_399014257246_item	3522912	et	4	main
12	doc_399014257246_item	3522913	et	2	main
miljardit	doc_399014257246_item	3522914	et	3	main
eurot	doc_399014257246_item	3522915	et	3	main
kui	doc_399014257246_item	3522916	et	3	main
kavandatavate	doc_399014257246_item	3522920	et	4	main
2	doc_399014257246_item	3522926	et	2	main
suure	doc_399014257246_item	3522930	et	3	main
on	doc_399014257246_item	3522938	et	4	main
ja	doc_399014257246_item	3522941	et	3	main
toimub	doc_399014257246_item	3522952	et	3	main
seemneraha	doc_399014257246_item	3522955	et	4	main
tuleb	doc_399014257246_item	3522956	et	3	main
euroopa	doc_399014257246_item	3522960	et	4	main
ja	doc_399014257246_item	3522962	et	3	main
eli	doc_399014257246_item	3522964	et	4	main
venemaa	doc_399014257246_item	3522967	et	4	main
osa	doc_399014257246_item	3522975	et	4	main
on	doc_399014257246_item	3523008	et	4	main
juba	doc_399014257246_item	3523012	et	3	main
tänu	doc_399014257246_item	3523013	et	4	main
sellele	doc_399014257246_item	3523014	et	4	main
esimesele	doc_399014257246_item	3523015	et	3	main
projektile	doc_399014257246_item	3523016	et	3	main
väheneb	doc_399014257246_item	3523017	et	3	main
läänemere	doc_399014257246_item	3523018	et	3	main
saastekoormus	doc_399014257246_item	3523019	et	3	main
tõlge	doc_399014257244_item	3523039	et	3	main
ka	doc_399014257244_item	3523044	et	3	main
venemaa	doc_399014257244_item	3523046	et	4	main
paremad	doc_399014257244_item	3523050	et	4	main
eeldused	doc_399014257244_item	3523051	et	4	main
soome	doc_399014257244_item	3523055	et	3	main
on	doc_399014257244_item	3523058	et	4	main
mõõde	doc_399014257244_item	3523069	et	4	main
aastal	doc_399014257244_item	3523074	et	3	main
sellest	doc_399014257244_item	3523079	et	4	main
saadi	doc_399014257244_item	3523095	et	4	main
et	doc_399014257244_item	3523097	et	3	main
on	doc_399014257244_item	3523100	et	4	main
terves	doc_399014257244_item	3523107	et	4	main
kirde-euroopas	doc_399014257244_item	3523108	et	3	main
põhja	doc_399014257244_item	3523109	et	4	main
mõõtme	doc_399014257244_item	3523110	et	3	main
osavõtjateks	doc_399014257244_item	3523111	et	3	main
on	doc_399014257244_item	3523112	et	4	main
islandi	doc_399014257244_item	3523120	et	4	main
usa	doc_399014257244_item	3523123	et	4	main
artika	doc_399014257244_item	3523136	et	4	main
barentsi	doc_399014257244_item	3523138	et	4	main
põhja	doc_399014257244_item	3523148	et	4	main
tasandil	doc_399014257244_item	3523171	et	3	main
mille	doc_399014257244_item	3523176	et	3	main
eli	doc_399014257244_item	3523178	et	4	main
tähelepanu	doc_399014257244_item	3523179	et	4	main
mõõde	doc_399014257244_item	3523187	et	4	main
mis	doc_399014257244_item	3523190	et	4	main
ei	doc_399014257244_item	3523203	et	4	main
praktikas	doc_399014257244_item	3523212	et	3	main
põhja	doc_399014257244_item	3523213	et	4	main
ja	doc_399014257244_item	3523240	et	3	main
saamine	doc_399014257244_item	3523251	et	4	main
umbes	doc_399014257244_item	3523258	et	4	main
lisaprojektide	doc_399014257244_item	3523267	et	3	main
umbes	doc_399014257244_item	3523271	et	4	main
2	doc_399014257244_item	3523273	et	2	main
projekt	doc_399014257244_item	3523342	et	3	main
tõlge	doc_399014257224_item	3523377	et	3	main
kavandatud	doc_399014257224_item	3523383	et	4	main
laekutati	doc_399014257224_item	3523388	et	4	main
viltu	doc_399014257224_item	3523394	et	3	main
korrusmaja	doc_399014257224_item	3523401	et	4	main
suurune	doc_399014257224_item	3523402	et	4	main
21	doc_399014257224_item	3523403	et	2	main
eesti	doc_399014257224_item	3523408	et	4	main
konkursikavandit	doc_399014257224_item	3523425	et	3	main
ehitada	doc_399014257224_item	3523429	et	3	main
on	doc_399014257224_item	3523441	et	4	main
realiseeritakse	doc_399014257246_item	3522932	et	3	main
praegu	doc_399014257246_item	3522933	et	3	main
mis	doc_399014257246_item	3522937	et	4	main
soomele	doc_399014257246_item	3522942	et	4	main
kogu	doc_399014257246_item	3522943	et	4	main
liidule	doc_399014257246_item	3522946	et	3	main
ja	doc_399014257246_item	3522947	et	3	main
keskkonnapartnerluse	doc_399014257246_item	3522949	et	3	main
kuhu	doc_399014257246_item	3522959	et	3	main
ja	doc_399014257246_item	3522969	et	3	main
on	doc_399014257246_item	3522971	et	4	main
finantseeringutest	doc_399014257246_item	3522977	et	4	main
laenud	doc_399014257246_item	3522985	et	4	main
saadakse	doc_399014257246_item	3522986	et	3	main
ja	doc_399014257246_item	3522989	et	3	main
asutused	doc_399014257246_item	3522991	et	4	main
nagu	doc_399014257246_item	3522992	et	3	main
kohalikud	doc_399014257246_item	3522993	et	3	main
ettevõtted	doc_399014257246_item	3522994	et	3	main
regionaalsed	doc_399014257246_item	3522995	et	3	main
ja	doc_399014257246_item	3522996	et	3	main
kohalikud	doc_399014257246_item	3522997	et	3	main
omavalitsused	doc_399014257246_item	3522998	et	3	main
on	doc_399014257246_item	3522999	et	4	main
laenude	doc_399014257246_item	3523000	et	3	main
põhja	doc_399014257244_item	3523040	et	4	main
põhja	doc_399014257244_item	3523052	et	4	main
mõõtme	doc_399014257244_item	3523053	et	3	main
eesti	doc_399014257244_item	3523057	et	4	main
selles	doc_399014257244_item	3523059	et	4	main
töös	doc_399014257244_item	3523060	et	3	main
teenäitajateks	doc_399014257244_item	3523061	et	3	main
urmas	doc_399014257244_item	3523062	et	3	main
paet	doc_399014257244_item	3523063	et	4	main
ja	doc_399014257244_item	3523064	et	3	main
erkki	doc_399014257244_item	3523065	et	3	main
sai	doc_399014257244_item	3523070	et	4	main
1999	doc_399014257244_item	3523075	et	2	main
idee	doc_399014257244_item	3523078	et	4	main
tugevdamine	doc_399014257244_item	3523099	et	4	main
paras	doc_399014257244_item	3523101	et	3	main
norra	doc_399014257244_item	3523118	et	4	main
ja	doc_399014257244_item	3523119	et	3	main
tegutsejaid	doc_399014257244_item	3523129	et	4	main
on	doc_399014257244_item	3523130	et	4	main
rahvusvahelised	doc_399014257244_item	3523146	et	4	main
finantsorganisatsioonid	doc_399014257244_item	3523147	et	3	main
majandus	doc_399014257244_item	3523153	et	4	main
inimkapital	doc_399014257244_item	3523154	et	3	main
sh	doc_399014257244_item	3523155	et	4	main
tervise-	doc_399014257244_item	3523156	et	3	main
keskkonna-	doc_399014257244_item	3523159	et	3	main
piiriülene	doc_399014257244_item	3523162	et	3	main
regionaalne	doc_399014257244_item	3523164	et	3	main
ning	doc_399014257244_item	3523166	et	3	main
ja	doc_399014257244_item	3523168	et	3	main
siseküsimused	doc_399014257244_item	3523169	et	3	main
kõrgemal	doc_399014257244_item	3523170	et	4	main
on	doc_399014257244_item	3523180	et	4	main
kõnedes	doc_399014257244_item	3523193	et	3	main
olnud	doc_399014257244_item	3523196	et	4	main
avamiseks	doc_399014257244_item	3523200	et	4	main
see	doc_399014257244_item	3523208	et	3	main
jäätme	doc_399014257244_item	3523244	et	3	main
keskkonnasõbralikumaks	doc_399014257244_item	3523246	et	4	main
loode-venemaal	doc_399014257244_item	3523252	et	4	main
keskkonnapartnerluse	doc_399014257244_item	3523253	et	3	main
12	doc_399014257244_item	3523259	et	2	main
kui	doc_399014257244_item	3523262	et	3	main
väärtus	doc_399014257244_item	3523268	et	3	main
lähiümbruses	doc_399014257244_item	3523282	et	3	main
projekte	doc_399014257244_item	3523283	et	3	main
on	doc_399014257244_item	3523285	et	4	main
tähtsad	doc_399014257244_item	3523286	et	3	main
soomele	doc_399014257244_item	3523289	et	4	main
ülejäänud	doc_399014257244_item	3523290	et	4	main
projektid	doc_399014257244_item	3523295	et	3	main
niimoodi	doc_399014257244_item	3523297	et	3	main
algkapital	doc_399014257244_item	3523299	et	3	main
partnerluse	doc_399014257244_item	3523301	et	3	main
tuumajäätmeprojektid	doc_399014257244_item	3523361	et	3	main
on	doc_399014257244_item	3523362	et	4	main
äsja	doc_399014257244_item	3523363	et	3	main
alanud	doc_399014257244_item	3523364	et	4	main
need	doc_399014257244_item	3523365	et	3	main
puudutavad	doc_399014257244_item	3523366	et	4	main
gremiha	doc_399014257244_item	3523367	et	4	main
piirkonna	doc_399014257244_item	3523368	et	4	main
tuumajäätmete	doc_399014257244_item	3523369	et	4	main
säilitamist	doc_399014257244_item	3523370	et	4	main
ning	doc_399014257244_item	3523371	et	3	main
murmanski	doc_399014257244_item	3523372	et	4	main
piirkonna	doc_399014257244_item	3523373	et	4	main
kiirguse	doc_399014257244_item	3523374	et	3	main
valmisolekusüsteemi	doc_399014257244_item	3523375	et	4	main
vaja	doc_399014257244_item	3523043	et	4	main
tulevikus	doc_399014257244_item	3523045	et	4	main
kaasatulek	doc_399014257244_item	3523047	et	3	main
endisest	doc_399014257244_item	3523049	et	3	main
ja	doc_399014257244_item	3523056	et	3	main
kirjutavad	doc_399014257244_item	3523067	et	4	main
põhja	doc_399014257244_item	3523068	et	4	main
osaks	doc_399014257244_item	3523073	et	3	main
oli	doc_399014257244_item	3523077	et	3	main
elil	doc_399014257244_item	3523081	et	4	main
ja	doc_399014257244_item	3523082	et	3	main
loode-venemaal	doc_399014257244_item	3523083	et	4	main
on	doc_399014257244_item	3523084	et	4	main
põhjust	doc_399014257244_item	3523085	et	4	main
teha	doc_399014257244_item	3523086	et	3	main
omavahel	doc_399014257244_item	3523087	et	3	main
koostööd	doc_399014257244_item	3523088	et	4	main
ja	doc_399014257244_item	3523089	et	3	main
et	doc_399014257244_item	3523090	et	3	main
mõlemad	doc_399014257244_item	3523091	et	3	main
saaksid	doc_399014257244_item	3523092	et	4	main
sellest	doc_399014257244_item	3523093	et	4	main
kasu	doc_399014257244_item	3523094	et	4	main
stabiilsuse	doc_399014257244_item	3523105	et	4	main
eli	doc_399014257244_item	3523113	et	4	main
liikmesriigid	doc_399014257244_item	3523114	et	3	main
ja	doc_399014257244_item	3523115	et	3	main
komisjon	doc_399014257244_item	3523116	et	3	main
venemaa	doc_399014257244_item	3523117	et	4	main
teisi	doc_399014257244_item	3523127	et	4	main
tähtsaid	doc_399014257244_item	3523128	et	3	main
euroarktiline	doc_399014257244_item	3523139	et	3	main
balti	doc_399014257244_item	3523141	et	3	main
mõõtme	doc_399014257244_item	3523149	et	3	main
programmi	doc_399014257244_item	3523150	et	4	main
peapiirkondi	doc_399014257244_item	3523151	et	4	main
ja	doc_399014257244_item	3523157	et	3	main
ja	doc_399014257244_item	3523160	et	3	main
ja	doc_399014257244_item	3523163	et	3	main
õigus-	doc_399014257244_item	3523167	et	4	main
on	doc_399014257244_item	3523174	et	4	main
poliitika	doc_399014257244_item	3523175	et	4	main
abil	doc_399014257244_item	3523177	et	4	main
põhja	doc_399014257244_item	3523186	et	4	main
ja	doc_399014257244_item	3523194	et	3	main
põhja	doc_399014257244_item	3523201	et	4	main
mõõtmel	doc_399014257244_item	3523202	et	3	main
kui	doc_399014257244_item	3523207	et	3	main
ka	doc_399014257244_item	3523211	et	3	main
puhastamine	doc_399014257244_item	3523242	et	4	main
tuumajäätmete	doc_399014257244_item	3523248	et	4	main
turvalisemale	doc_399014257244_item	3523249	et	4	main
hoiule	doc_399014257244_item	3523250	et	3	main
väärtus	doc_399014257244_item	3523256	et	3	main
eurot	doc_399014257244_item	3523261	et	3	main
kogusumma	doc_399014257244_item	3523270	et	4	main
kuni	doc_399014257244_item	3523272	et	3	main
nii	doc_399014257244_item	3523276	et	3	main
suure	doc_399014257244_item	3523277	et	3	main
summaga	doc_399014257244_item	3523278	et	4	main
teostatakse	doc_399014257244_item	3523279	et	3	main
praegu	doc_399014257244_item	3523280	et	3	main
mis	doc_399014257244_item	3523284	et	4	main
eestile	doc_399014257244_item	3523287	et	3	main
venemaale	doc_399014257244_item	3523293	et	4	main
regionaalnõukogud	doc_399014257244_item	3523339	et	3	main
esimene	doc_399014257244_item	3523341	et	3	main
kanada	doc_399014257244_item	3523125	et	4	main
vaadlejariigid	doc_399014257244_item	3523126	et	4	main
läänemere	doc_399014257244_item	3523133	et	3	main
riikide	doc_399014257244_item	3523134	et	3	main
nõukogu	doc_399014257244_item	3523135	et	4	main
nõukogu	doc_399014257244_item	3523140	et	4	main
ministrinõukogu	doc_399014257244_item	3523142	et	4	main
põhjamaade	doc_399014257244_item	3523143	et	3	main
ministrinõukogu	doc_399014257244_item	3523144	et	4	main
ning	doc_399014257244_item	3523145	et	3	main
on	doc_399014257244_item	3523152	et	4	main
koostöö	doc_399014257244_item	3523165	et	4	main
põhja	doc_399014257244_item	3523172	et	4	main
mõiste	doc_399014257244_item	3523189	et	4	main
poliitilistes	doc_399014257244_item	3523192	et	3	main
tähendust	doc_399014257244_item	3523206	et	4	main
ei	doc_399014257244_item	3523209	et	4	main
põhja	doc_399014257244_item	3523131	et	4	main
regionaalnõukogud	doc_399014257244_item	3523132	et	3	main
nõukogu	doc_399014257244_item	3523137	et	4	main
sotsiaalküsimused	doc_399014257244_item	3523158	et	3	main
tuumaturvaküsimused	doc_399014257244_item	3523161	et	3	main
mõõde	doc_399014257244_item	3523173	et	4	main
pööratud	doc_399014257244_item	3523181	et	4	main
kirde-euroopa	doc_399014257244_item	3523182	et	4	main
poole	doc_399014257244_item	3523183	et	4	main
kõrgemal	doc_399014257244_item	3523184	et	4	main
tasandil	doc_399014257244_item	3523185	et	3	main
on	doc_399014257244_item	3523188	et	4	main
esineb	doc_399014257244_item	3523191	et	3	main
on	doc_399014257244_item	3523195	et	4	main
hädavajalik	doc_399014257244_item	3523197	et	3	main
erinevate	doc_399014257244_item	3523198	et	4	main
finantsallikate	doc_399014257244_item	3523199	et	3	main
siiski	doc_399014257244_item	3523204	et	4	main
ole	doc_399014257244_item	3523205	et	4	main
ilmne	doc_399014257244_item	3523210	et	4	main
mõõde	doc_399014257244_item	3523214	et	4	main
on	doc_399014257244_item	3523215	et	4	main
näha	doc_399014257244_item	3523216	et	3	main
ka	doc_399014257244_item	3523217	et	3	main
konkresetes	doc_399014257244_item	3523218	et	4	main
ettevõtmistes	doc_399014257244_item	3523219	et	3	main
nagu	doc_399014257244_item	3523220	et	3	main
partnerprojektides	doc_399014257244_item	3523221	et	3	main
neid	doc_399014257244_item	3523222	et	4	main
on	doc_399014257244_item	3523223	et	4	main
kahte	doc_399014257244_item	3523224	et	4	main
viisi	doc_399014257244_item	3523225	et	4	main
keskkonnapartnerlus	doc_399014257244_item	3523226	et	3	main
asutati	doc_399014257244_item	3523227	et	4	main
aastal	doc_399014257244_item	3523228	et	3	main
2001	doc_399014257244_item	3523229	et	2	main
ja	doc_399014257244_item	3523230	et	3	main
sotsiaal-	doc_399014257244_item	3523231	et	4	main
ja	doc_399014257244_item	3523232	et	3	main
tervisepartnerlus	doc_399014257244_item	3523233	et	3	main
aastal	doc_399014257244_item	3523234	et	3	main
2003	doc_399014257244_item	3523235	et	2	main
keskkonnapartnerluse	doc_399014257244_item	3523236	et	3	main
eesmärgiks	doc_399014257244_item	3523237	et	3	main
on	doc_399014257244_item	3523238	et	4	main
vee	doc_399014257244_item	3523239	et	3	main
õhu	doc_399014257244_item	3523241	et	3	main
käitlemine	doc_399014257244_item	3523245	et	4	main
ja	doc_399014257244_item	3523247	et	3	main
projektide	doc_399014257244_item	3523254	et	3	main
on	doc_399014257244_item	3523257	et	4	main
lisatakse	doc_399014257244_item	3523264	et	4	main
meie	doc_399014257244_item	3523281	et	4	main
elile	doc_399014257244_item	3523291	et	4	main
ja	doc_399014257244_item	3523292	et	3	main
kohalikud	doc_399014257244_item	3523336	et	3	main
kindla	doc_399014257244_item	3523243	et	3	main
tänapäevane	doc_399014257244_item	3523255	et	4	main
miljardit	doc_399014257244_item	3523260	et	3	main
sellele	doc_399014257244_item	3523263	et	4	main
esialgselt	doc_399014257244_item	3523265	et	4	main
otsustatud	doc_399014257244_item	3523266	et	4	main
tõuseb	doc_399014257244_item	3523269	et	3	main
miljardi	doc_399014257244_item	3523274	et	3	main
euroni	doc_399014257244_item	3523275	et	3	main
ja	doc_399014257244_item	3523288	et	3	main
keskkonnapartnerluse	doc_399014257244_item	3523294	et	3	main
finantseeritakse	doc_399014257244_item	3523296	et	3	main
et	doc_399014257244_item	3523298	et	3	main
tuleb	doc_399014257244_item	3523300	et	3	main
kuhu	doc_399014257244_item	3523303	et	3	main
eli	doc_399014257244_item	3523304	et	4	main
komisjon	doc_399014257244_item	3523305	et	3	main
teised	doc_399014257244_item	3523306	et	4	main
el-riigid	doc_399014257244_item	3523307	et	3	main
ning	doc_399014257244_item	3523308	et	3	main
venemaa	doc_399014257244_item	3523309	et	4	main
norra	doc_399014257244_item	3523310	et	4	main
ja	doc_399014257244_item	3523311	et	3	main
kanada	doc_399014257244_item	3523312	et	4	main
on	doc_399014257244_item	3523313	et	4	main
annetanud	doc_399014257244_item	3523314	et	4	main
raha	doc_399014257244_item	3523315	et	4	main
peaosa	doc_399014257244_item	3523316	et	4	main
projektide	doc_399014257244_item	3523317	et	3	main
finantsrahast	doc_399014257244_item	3523318	et	4	main
ei	doc_399014257244_item	3523319	et	4	main
ole	doc_399014257244_item	3523320	et	4	main
aga	doc_399014257244_item	3523321	et	3	main
annetus	doc_399014257244_item	3523322	et	4	main
vaid	doc_399014257244_item	3523323	et	3	main
laen	doc_399014257244_item	3523324	et	4	main
laen	doc_399014257244_item	3523325	et	4	main
võetakse	doc_399014257244_item	3523326	et	3	main
rahvusvahelistelt	doc_399014257244_item	3523327	et	4	main
finantsorganisatsioonidelt	doc_399014257244_item	3523328	et	3	main
ja	doc_399014257244_item	3523329	et	3	main
laenu	doc_399014257244_item	3523330	et	4	main
kasutavad	doc_399014257244_item	3523331	et	4	main
vene	doc_399014257244_item	3523332	et	4	main
poolsed	doc_399014257244_item	3523333	et	3	main
fondist	doc_399014257244_item	3523302	et	3	main
partnerid	doc_399014257244_item	3523334	et	3	main
firmad	doc_399014257244_item	3523337	et	3	main
ja	doc_399014257244_item	3523338	et	3	main
partnerluse	doc_399014257244_item	3523340	et	3	main
kolm	doc_399014257224_item	3523389	et	3	main
konkursitööd	doc_399014257224_item	3523390	et	4	main
kangelase	doc_399014257224_item	3523410	et	3	main
esmaspäevani	doc_399014257224_item	3523421	et	3	main
kalevipoja	doc_399014257224_item	3523426	et	4	main
kavatsetakse	doc_399014257224_item	3523428	et	3	main
viia	doc_399014257224_item	3523436	et	3	main
rannatee	doc_399014257224_item	3523437	et	4	main
äärde	doc_399014257224_item	3523438	et	4	main
ranna	doc_399014257224_item	3523442	et	3	main
kanglastele	doc_399014257224_item	3523448	et	4	main
ehitatud	doc_399014257224_item	3523449	et	4	main
memoriaalkompleks	doc_399014257224_item	3523450	et	3	main
millest	doc_399014257224_item	3523451	et	3	main
ja	doc_399014257224_item	3523460	et	3	main
ühenduse	doc_399014257224_item	3523463	et	4	main
alates	doc_399014257224_item	3523468	et	3	main
on	doc_399014257224_item	3523475	et	4	main
ega	doc_399014257224_item	3523478	et	3	main
aegase	doc_399014257224_item	3523485	et	3	main
astusid	doc_399014257224_item	3523490	et	4	main
ning	doc_399014257224_item	3523491	et	3	main
esindajad	doc_399014257224_item	3523498	et	4	main
linnapea	doc_399014257224_item	3523511	et	4	main
linna	doc_399014257224_item	3523524	et	4	main
ikkagi	doc_399014257224_item	3523532	et	4	main
kes	doc_399014257224_item	3523540	et	4	main
tema	doc_399014257224_item	3523549	et	4	main
idee	doc_399014257224_item	3523550	et	4	main
oli	doc_399014257224_item	3523551	et	3	main
kujundada	doc_399014257224_item	3523552	et	3	main
kui	doc_399014257224_item	3523556	et	3	main
pandi	doc_399014257224_item	3523575	et	4	main
juurde	doc_399014257224_item	3523577	et	4	main
vaatasime	doc_399014257224_item	3523581	et	3	main
kuju	doc_399014257224_item	3523583	et	4	main
memoriaalkompleksi	doc_399014257224_item	3523586	et	4	main
juurde	doc_399014257224_item	3523587	et	4	main
teime	doc_399014257224_item	3523588	et	3	main
21	doc_399014257224_item	3523595	et	2	main
seletab	doc_399014257224_item	3523601	et	3	main
olga	doc_399014257224_item	3523603	et	4	main
kõige	doc_399014257224_item	3523610	et	4	main
sest	doc_399014257224_item	3523612	et	4	main
see	doc_399014257224_item	3523613	et	3	main
on	doc_399014257224_item	3523614	et	4	main
botaanikaaiasse	doc_399014257224_item	3523625	et	4	main
samuti	doc_399014257224_item	3523626	et	3	main
pole	doc_399014257224_item	3523627	et	3	main
on	doc_399014257224_item	3523659	et	4	main
ringikäimist	doc_399014257224_item	3523666	et	4	main
kangelase	doc_399014257224_item	3523667	et	3	main
veel	doc_399014257224_item	3523671	et	4	main
paadi	doc_399014257224_item	3523673	et	3	main
kujurite	doc_399014257224_item	3523683	et	3	main
mõjukam	doc_399014257224_item	3523689	et	4	main
mis	doc_399014257224_item	3523694	et	4	main
pärast	doc_399014257224_item	3523703	et	4	main
kalevipoja	doc_399014257221_item	3523713	et	4	main
lahte	doc_399014257221_item	3523724	et	4	main
paneelmaja	doc_399014257221_item	3523725	et	4	main
kavas	doc_399014257221_item	3523747	et	3	main
kohal	doc_399014257221_item	3523760	et	4	main
rajatud	doc_399014257221_item	3523767	et	4	main
rannatrepp	doc_399014257221_item	3523779	et	3	main
linna	doc_399014257221_item	3523780	et	4	main
ja	doc_399014257221_item	3523781	et	3	main
skulptorite	doc_399014257221_item	3523782	et	3	main
liidu	doc_399014257221_item	3523783	et	3	main
eriarvamused	doc_399014257221_item	3523784	et	3	main
suurusest	doc_399014257221_item	3523788	et	4	main
on	doc_399014257221_item	3523798	et	4	main
juurde	doc_399014257221_item	3523807	et	4	main
skulptorite	doc_399014257221_item	3523812	et	3	main
komisjoni	doc_399014257221_item	3523830	et	4	main
linna	doc_399014257221_item	3523842	et	4	main
nagu	doc_399014257244_item	3523335	et	3	main
kunstnikude	doc_399014257224_item	3523378	et	3	main
vildu	doc_399014257224_item	3523381	et	4	main
peale	doc_399014257224_item	3523386	et	4	main
linnavalitsusele	doc_399014257224_item	3523387	et	4	main
eesti	doc_399014257224_item	3523391	et	4	main
plaani	doc_399014257224_item	3523396	et	4	main
kõrgune	doc_399014257224_item	3523405	et	4	main
kalevipoja	doc_399014257224_item	3523406	et	4	main
linnavalitsuse	doc_399014257224_item	3523412	et	3	main
sisse	doc_399014257224_item	3523422	et	4	main
kohal	doc_399014257224_item	3523440	et	4	main
merele	doc_399014257224_item	3523453	et	3	main
on	doc_399014257224_item	3523466	et	4	main
ekü	doc_399014257224_item	3523473	et	4	main
vananenud	doc_399014257224_item	3523477	et	4	main
õige	doc_399014257224_item	3523481	et	4	main
ole	doc_399014257224_item	3523483	et	4	main
ühenduse	doc_399014257224_item	3523493	et	4	main
kui	doc_399014257224_item	3523494	et	3	main
ka	doc_399014257224_item	3523495	et	3	main
arhitektide	doc_399014257224_item	3523496	et	3	main
züriist	doc_399014257224_item	3523500	et	4	main
protesteeritades	doc_399014257224_item	3523501	et	4	main
liiga	doc_399014257224_item	3523507	et	4	main
ratase	doc_399014257224_item	3523513	et	4	main
juhtimas	doc_399014257224_item	3523515	et	4	main
lõpetuseks	doc_399014257224_item	3523518	et	4	main
ainult	doc_399014257224_item	3523519	et	4	main
üks	doc_399014257224_item	3523520	et	3	main
parke	doc_399014257224_item	3523525	et	3	main
maastiku-arhitekt	doc_399014257224_item	3523527	et	3	main
idee	doc_399014257224_item	3523529	et	4	main
kunstnik	doc_399014257224_item	3523533	et	3	main
1990aastade	doc_399014257224_item	3523545	et	4	main
merineitsi	doc_399014257224_item	3523558	et	4	main
peale	doc_399014257224_item	3523561	et	4	main
kavatsus	doc_399014257224_item	3523563	et	4	main
poolelt	doc_399014257224_item	3523574	et	4	main
meetrini	doc_399014257224_item	3523580	et	3	main
kuidas	doc_399014257224_item	3523582	et	3	main
sobib	doc_399014257224_item	3523584	et	3	main
maarjamäe	doc_399014257224_item	3523585	et	3	main
selle	doc_399014257224_item	3523593	et	4	main
jõudsime	doc_399014257224_item	3523594	et	3	main
sõtniku	doc_399014257224_item	3523605	et	4	main
parim	doc_399014257224_item	3523611	et	4	main
äärel	doc_399014257224_item	3523617	et	3	main
kui	doc_399014257224_item	3523618	et	3	main
sõitavad	doc_399014257224_item	3523620	et	4	main
kuju	doc_399014257224_item	3523628	et	4	main
siin	doc_399014257224_item	3523629	et	4	main
eesti	doc_399014257224_item	3523682	et	4	main
arhitektide	doc_399014257224_item	3523691	et	3	main
on	doc_399014257224_item	3523695	et	4	main
riius	doc_399014257224_item	3523697	et	4	main
linnavalitsuse	doc_399014257224_item	3523700	et	3	main
vaatavad	doc_399014257221_item	3523707	et	4	main
hiiglaslikule	doc_399014257221_item	3523712	et	3	main
püstitada	doc_399014257221_item	3523722	et	3	main
kalevipoeg	doc_399014257221_item	3523730	et	3	main
eesti	doc_399014257221_item	3523732	et	4	main
rahvaeepose	doc_399014257221_item	3523733	et	3	main
kangelase	doc_399014257221_item	3523734	et	3	main
järgi	doc_399014257221_item	3523735	et	4	main
merre	doc_399014257221_item	3523749	et	3	main
meetri	doc_399014257221_item	3523751	et	3	main
piritale	doc_399014257221_item	3523755	et	4	main
rannatee	doc_399014257221_item	3523757	et	4	main
äärde	doc_399014257221_item	3523758	et	4	main
samal	doc_399014257221_item	3523759	et	3	main
ajal	doc_399014257221_item	3523766	et	4	main
memoriaalkompleks	doc_399014257221_item	3523772	et	3	main
millest	doc_399014257221_item	3523773	et	3	main
paistab	doc_399014257221_item	3523774	et	3	main
merele	doc_399014257221_item	3523775	et	3	main
kõrge	doc_399014257221_item	3523776	et	4	main
obelisk	doc_399014257221_item	3523777	et	3	main
ning	doc_399014257221_item	3523778	et	3	main
idee	doc_399014257221_item	3523796	et	4	main
sobi	doc_399014257221_item	3523804	et	4	main
peterburi	doc_399014257244_item	3523343	et	4	main
loode	doc_399014257244_item	3523344	et	4	main
veepuhastusjaam	doc_399014257244_item	3523345	et	3	main
on	doc_399014257244_item	3523346	et	4	main
valminud	doc_399014257244_item	3523347	et	4	main
sellel	doc_399014257244_item	3523348	et	4	main
sügisel	doc_399014257244_item	3523349	et	3	main
tänu	doc_399014257244_item	3523350	et	4	main
sellele	doc_399014257244_item	3523351	et	4	main
esimesele	doc_399014257244_item	3523352	et	3	main
projektile	doc_399014257244_item	3523353	et	3	main
on	doc_399014257244_item	3523354	et	4	main
läänemere	doc_399014257244_item	3523355	et	3	main
jäätmekoormus	doc_399014257244_item	3523356	et	3	main
tunduvalt	doc_399014257244_item	3523357	et	4	main
vähenenud	doc_399014257244_item	3523358	et	4	main
ka	doc_399014257244_item	3523359	et	3	main
esimesed	doc_399014257244_item	3523360	et	3	main
liidud	doc_399014257224_item	3523379	et	3	main
kalevipoja	doc_399014257224_item	3523384	et	4	main
hiiglaskuju	doc_399014257224_item	3523385	et	4	main
kunstnikud	doc_399014257224_item	3523392	et	3	main
lahte	doc_399014257224_item	3523400	et	4	main
kuju	doc_399014257224_item	3523407	et	4	main
järgi	doc_399014257224_item	3523411	et	4	main
kolm	doc_399014257224_item	3523424	et	3	main
rannast	doc_399014257224_item	3523433	et	4	main
tallinnast	doc_399014257224_item	3523434	et	3	main
piritale	doc_399014257224_item	3523435	et	4	main
poolel	doc_399014257224_item	3523443	et	4	main
teise	doc_399014257224_item	3523446	et	4	main
kõrge	doc_399014257224_item	3523455	et	4	main
ja	doc_399014257224_item	3523457	et	3	main
linna	doc_399014257224_item	3523459	et	4	main
kujurite	doc_399014257224_item	3523462	et	3	main
skulptuuri	doc_399014257224_item	3523469	et	4	main
koost	doc_399014257224_item	3523470	et	4	main
tegelikult	doc_399014257224_item	3523476	et	4	main
ette	doc_399014257224_item	3523651	et	4	main
pronkskuju	doc_399014257224_item	3523652	et	4	main
vaatavad	doc_399014257224_item	3523380	et	4	main
tallinnalahte	doc_399014257224_item	3523382	et	4	main
vaatavad	doc_399014257224_item	3523393	et	4	main
linna	doc_399014257224_item	3523395	et	4	main
peale	doc_399014257224_item	3523397	et	4	main
paigutada	doc_399014257224_item	3523398	et	3	main
tallinna	doc_399014257224_item	3523399	et	4	main
meetri	doc_399014257224_item	3523404	et	3	main
rahvuseepose	doc_399014257224_item	3523409	et	3	main
poolelt	doc_399014257224_item	3523413	et	4	main
korraldatud	doc_399014257224_item	3523414	et	4	main
konkursile	doc_399014257224_item	3523415	et	3	main
andi	doc_399014257224_item	3523416	et	4	main
kuni	doc_399014257224_item	3523417	et	3	main
tähtaja	doc_399014257224_item	3523418	et	3	main
lõppeni	doc_399014257224_item	3523419	et	3	main
ehk	doc_399014257224_item	3523420	et	3	main
ainult	doc_399014257224_item	3523423	et	4	main
kuju	doc_399014257224_item	3523427	et	4	main
saja	doc_399014257224_item	3523430	et	4	main
meetri	doc_399014257224_item	3523431	et	3	main
kaugusele	doc_399014257224_item	3523432	et	4	main
sellel	doc_399014257224_item	3523439	et	4	main
nõukogude	doc_399014257224_item	3523444	et	3	main
ajal	doc_399014257224_item	3523445	et	4	main
maailmasõja	doc_399014257224_item	3523447	et	3	main
obelisk	doc_399014257224_item	3523456	et	3	main
eesti	doc_399014257224_item	3523461	et	4	main
erimeelsusi	doc_399014257224_item	3523467	et	4	main
idee	doc_399014257224_item	3523474	et	4	main
rahvuseepose	doc_399014257224_item	3523479	et	3	main
varem	doc_399014257224_item	3523488	et	4	main
liitu	doc_399014257224_item	3523497	et	4	main
tagasi	doc_399014257224_item	3523499	et	3	main
züriis	doc_399014257224_item	3523505	et	4	main
tallinna	doc_399014257224_item	3523510	et	4	main
32	doc_399014257224_item	3523514	et	2	main
komisjonis	doc_399014257224_item	3523516	et	3	main
oli	doc_399014257224_item	3523517	et	3	main
liikme	doc_399014257224_item	3523523	et	3	main
kangro	doc_399014257224_item	3523538	et	4	main
40	doc_399014257224_item	3523539	et	2	main
oma	doc_399014257224_item	3523542	et	4	main
juba	doc_399014257224_item	3523544	et	3	main
lõpul	doc_399014257224_item	3523546	et	3	main
tallinnale	doc_399014257224_item	3523553	et	4	main
kööpenhaminas	doc_399014257224_item	3523559	et	4	main
tallinna	doc_399014257224_item	3523569	et	4	main
aga	doc_399014257224_item	3523572	et	3	main
linnavalitsuse	doc_399014257224_item	3523573	et	3	main
sellest	doc_399014257224_item	3523589	et	4	main
meetrile	doc_399014257224_item	3523596	et	3	main
sõnul	doc_399014257224_item	3523606	et	3	main
tee	doc_399014257224_item	3523616	et	4	main
suurde	doc_399014257224_item	3523653	et	3	main
peodega	doc_399014257224_item	3523654	et	3	main
paadi	doc_399014257224_item	3523655	et	3	main
sümboliks	doc_399014257224_item	3523660	et	4	main
kangelase	doc_399014257224_item	3523661	et	3	main
koju	doc_399014257224_item	3523662	et	3	main
kätte	doc_399014257224_item	3523668	et	4	main
kuju	doc_399014257224_item	3523686	et	4	main
kavandust	doc_399014257224_item	3523687	et	4	main
ka	doc_399014257224_item	3523688	et	3	main
liit	doc_399014257224_item	3523692	et	3	main
linnaga	doc_399014257224_item	3523696	et	3	main
uue	doc_399014257224_item	3523699	et	3	main
on	doc_399014257224_item	3523452	et	4	main
näha	doc_399014257224_item	3523454	et	3	main
rannatrepp	doc_399014257224_item	3523458	et	3	main
ekü	doc_399014257224_item	3523464	et	4	main
vahel	doc_399014257224_item	3523465	et	4	main
ja	doc_399014257224_item	3523471	et	3	main
asukohast	doc_399014257224_item	3523472	et	4	main
ühenduses	doc_399014257224_item	3523487	et	4	main
selle	doc_399014257224_item	3523502	et	4	main
vastu	doc_399014257224_item	3523503	et	3	main
et	doc_399014257224_item	3523504	et	3	main
palju	doc_399014257224_item	3523508	et	4	main
ametnikke	doc_399014257224_item	3523509	et	3	main
jüri	doc_399014257224_item	3523512	et	4	main
sõltumatu	doc_399014257224_item	3523521	et	4	main
isa	doc_399014257224_item	3523530	et	4	main
hakkas	doc_399014257224_item	3523541	et	3	main
kalevipoeg-ideed	doc_399014257224_item	3523543	et	4	main
tuntuks	doc_399014257224_item	3523547	et	4	main
tegema	doc_399014257224_item	3523548	et	3	main
sarnane	doc_399014257224_item	3523554	et	4	main
väike	doc_399014257224_item	3523557	et	4	main
oli	doc_399014257224_item	3523562	et	3	main
ehitada	doc_399014257224_item	3523564	et	3	main
14	doc_399014257224_item	3523566	et	2	main
väike	doc_399014257224_item	3523570	et	4	main
meri-neitsi	doc_399014257224_item	3523571	et	4	main
kangelase	doc_399014257224_item	3523480	et	3	main
asu-paik	doc_399014257224_item	3523482	et	3	main
nõukogude	doc_399014257224_item	3523484	et	3	main
memoriaalkompleksi	doc_399014257224_item	3523486	et	4	main
sügisel	doc_399014257224_item	3523489	et	3	main
kujurite	doc_399014257224_item	3523492	et	3	main
on	doc_399014257224_item	3523506	et	4	main
kunstiala	doc_399014257224_item	3523522	et	4	main
projekteerinud	doc_399014257224_item	3523526	et	4	main
algupärase	doc_399014257224_item	3523528	et	4	main
on	doc_399014257224_item	3523531	et	4	main
ja	doc_399014257224_item	3523534	et	3	main
vaidlusalune	doc_399014257224_item	3523535	et	4	main
kujur	doc_399014257224_item	3523536	et	3	main
tauno	doc_399014257224_item	3523537	et	4	main
sümbol	doc_399014257224_item	3523555	et	3	main
algusest	doc_399014257224_item	3523560	et	4	main
ainult	doc_399014257224_item	3523565	et	4	main
meetri	doc_399014257224_item	3523567	et	3	main
kõrgune	doc_399014257224_item	3523568	et	4	main
selle	doc_399014257224_item	3523576	et	4	main
kuni	doc_399014257224_item	3523578	et	3	main
arvestusi	doc_399014257224_item	3523590	et	4	main
ja	doc_399014257224_item	3523591	et	3	main
visualiseerime	doc_399014257224_item	3523592	et	4	main
oleks	doc_399014257224_item	3523598	et	3	main
selgesti	doc_399014257224_item	3523599	et	3	main
on	doc_399014257224_item	3523607	et	4	main
ka	doc_399014257224_item	3523609	et	3	main
turistide	doc_399014257224_item	3523615	et	3	main
nad	doc_399014257224_item	3523619	et	3	main
pirita	doc_399014257224_item	3523621	et	4	main
spasse	doc_399014257224_item	3523622	et	4	main
ja	doc_399014257224_item	3523623	et	3	main
häireks	doc_399014257224_item	3523630	et	3	main
kandvast	doc_399014257224_item	3523656	et	4	main
kalevipojast	doc_399014257224_item	3523657	et	4	main
naasmisele	doc_399014257224_item	3523663	et	4	main
päraste	doc_399014257224_item	3523664	et	4	main
tema	doc_399014257224_item	3523665	et	4	main
kunstnik	doc_399014257224_item	3523670	et	3	main
ja	doc_399014257224_item	3523674	et	3	main
inimfiguurid	doc_399014257224_item	3523676	et	3	main
eal	doc_399014257224_item	3523693	et	4	main
tallinna	doc_399014257221_item	3523709	et	4	main
kujule	doc_399014257221_item	3523714	et	3	main
vaatavad	doc_399014257221_item	3523717	et	4	main
tallinna	doc_399014257221_item	3523719	et	4	main
linna	doc_399014257221_item	3523720	et	4	main
suurune	doc_399014257221_item	3523726	et	4	main
21	doc_399014257221_item	3523727	et	2	main
meetrit	doc_399014257221_item	3523728	et	3	main
samanimelise	doc_399014257221_item	3523731	et	4	main
ainult	doc_399014257221_item	3523742	et	4	main
kolm	doc_399014257221_item	3523743	et	3	main
ideeprojekti	doc_399014257221_item	3523744	et	4	main
kalevipoeg	doc_399014257221_item	3523745	et	3	main
rannajoonest	doc_399014257221_item	3523753	et	4	main
ääres	doc_399014257221_item	3523763	et	4	main
kangelastele	doc_399014257221_item	3523770	et	4	main
pühendatud	doc_399014257221_item	3523771	et	4	main
kuju	doc_399014257221_item	3523787	et	4	main
meres	doc_399014257221_item	3523791	et	3	main
aegunud	doc_399014257221_item	3523799	et	4	main
ja	doc_399014257221_item	3523800	et	3	main
rahvuseepose	doc_399014257221_item	3523801	et	3	main
kangelane	doc_399014257221_item	3523802	et	3	main
ei	doc_399014257221_item	3523803	et	4	main
sügisel	doc_399014257221_item	3523809	et	3	main
arhitektide	doc_399014257221_item	3523815	et	3	main
komisjonist	doc_399014257221_item	3523819	et	3	main
ratase	doc_399014257221_item	3523827	et	4	main
ainus	doc_399014257221_item	3523831	et	4	main
järele	doc_399014257221_item	3523832	et	4	main
on	doc_399014257221_item	3523837	et	4	main
maismaaarhitekt	doc_399014257221_item	3523838	et	3	main
kes	doc_399014257221_item	3523839	et	4	main
on	doc_399014257221_item	3523840	et	4	main
turustamisega	doc_399014257221_item	3523858	et	4	main
juba	doc_399014257221_item	3523859	et	3	main
1990ndate	doc_399014257221_item	3523860	et	4	main
lõpul	doc_399014257221_item	3523861	et	3	main
ideeks	doc_399014257221_item	3523862	et	3	main
tallinnale	doc_399014257221_item	3523865	et	4	main
võrreldav	doc_399014257221_item	3523869	et	4	main
algses	doc_399014257221_item	3523871	et	3	main
21	doc_399014257224_item	3523579	et	2	main
see	doc_399014257224_item	3523597	et	3	main
näha	doc_399014257224_item	3523600	et	3	main
abilinnapea	doc_399014257224_item	3523602	et	4	main
sõtnik	doc_399014257224_item	3523604	et	4	main
asupaik	doc_399014257224_item	3523608	et	3	main
tallinna	doc_399014257224_item	3523624	et	4	main
vana-linna	doc_399014257224_item	3523631	et	4	main
siluetile	doc_399014257224_item	3523632	et	3	main
tauno	doc_399014257224_item	3523633	et	4	main
kangro	doc_399014257224_item	3523634	et	4	main
galeriis	doc_399014257224_item	3523635	et	3	main
vanalinnas	doc_399014257224_item	3523636	et	4	main
valitses	doc_399014257224_item	3523637	et	3	main
veel	doc_399014257224_item	3523638	et	4	main
esmaspäevalgi	doc_399014257224_item	3523639	et	4	main
innustus	doc_399014257224_item	3523640	et	4	main
kunstnik	doc_399014257224_item	3523641	et	3	main
ise	doc_399014257224_item	3523642	et	4	main
polnud	doc_399014257224_item	3523643	et	3	main
linnas	doc_399014257224_item	3523644	et	4	main
aga	doc_399014257224_item	3523645	et	3	main
gallerist	doc_399014257224_item	3523646	et	4	main
pille	doc_399014257224_item	3523647	et	3	main
mägila	doc_399014257224_item	3523648	et	4	main
näitab	doc_399014257224_item	3523649	et	3	main
innuga	doc_399014257224_item	3523650	et	3	main
kuju	doc_399014257224_item	3523658	et	4	main
on	doc_399014257224_item	3523669	et	4	main
lisanud	doc_399014257224_item	3523672	et	4	main
möned	doc_399014257224_item	3523675	et	4	main
sümboliseerima	doc_399014257224_item	3523677	et	4	main
eestlaste	doc_399014257224_item	3523678	et	4	main
koju	doc_399014257224_item	3523679	et	3	main
naasmist	doc_399014257224_item	3523680	et	4	main
peale	doc_399014257224_item	3523681	et	4	main
ühenduse	doc_399014257224_item	3523684	et	4	main
boikottib	doc_399014257224_item	3523685	et	4	main
eesti	doc_399014257224_item	3523690	et	4	main
ka	doc_399014257224_item	3523698	et	3	main
hoone	doc_399014257224_item	3523701	et	4	main
asukoha	doc_399014257224_item	3523702	et	4	main
tõlge	doc_399014257221_item	3523705	et	3	main
viltu	doc_399014257221_item	3523708	et	3	main
kavandatud	doc_399014257221_item	3523711	et	4	main
eesti	doc_399014257221_item	3523715	et	4	main
kavatsusele	doc_399014257221_item	3523721	et	4	main
on	doc_399014257221_item	3523746	et	4	main
saja	doc_399014257221_item	3523750	et	4	main
kaugusele	doc_399014257221_item	3523752	et	4	main
viiva	doc_399014257221_item	3523756	et	4	main
kalda	doc_399014257221_item	3523762	et	3	main
nõukogude	doc_399014257221_item	3523764	et	3	main
võimu	doc_399014257221_item	3523765	et	4	main
ja	doc_399014257221_item	3523789	et	3	main
asukohast	doc_399014257221_item	3523790	et	4	main
eesti	doc_399014257221_item	3523792	et	4	main
kujurite	doc_399014257221_item	3523793	et	3	main
ühenduse	doc_399014257221_item	3523794	et	4	main
hinnangul	doc_399014257221_item	3523795	et	3	main
nõukogudeaegse	doc_399014257221_item	3523805	et	3	main
varem	doc_399014257221_item	3523808	et	4	main
kui	doc_399014257221_item	3523813	et	3	main
linnapea	doc_399014257221_item	3523825	et	4	main
jüri	doc_399014257221_item	3523826	et	4	main
kunstiline	doc_399014257221_item	3523835	et	4	main
planeerinud	doc_399014257221_item	3523841	et	4	main
on	doc_399014257221_item	3523847	et	4	main
skulptor	doc_399014257221_item	3523851	et	3	main
kangro	doc_399014257221_item	3523853	et	4	main
ainult	doc_399014257221_item	3523877	et	4	main
14	doc_399014257221_item	3523878	et	2	main
meetrit	doc_399014257221_item	3523879	et	3	main
põhjendab	doc_399014257221_item	3523907	et	3	main
olga	doc_399014257221_item	3523909	et	4	main
sest	doc_399014257221_item	3523918	et	4	main
see	doc_399014257221_item	3523919	et	3	main
jääb	doc_399014257221_item	3523920	et	3	main
turistimarsruudi	doc_399014257221_item	3523921	et	3	main
äärde	doc_399014257221_item	3523922	et	4	main
botaanikaaeda	doc_399014257221_item	3523927	et	4	main
piira	doc_399014257221_item	3523930	et	4	main
veel	doc_399014257221_item	3523938	et	4	main
ise	doc_399014257221_item	3523943	et	4	main
tutvustas	doc_399014257221_item	3523951	et	3	main
kus	doc_399014257221_item	3523954	et	3	main
kalevipoeg	doc_399014257221_item	3523957	et	3	main
visiooni	doc_399014257221_item	3523976	et	4	main
tulemusena	doc_399014257221_item	3523977	et	3	main
loomeühendused	doc_399014257221_item	3523706	et	3	main
lahte	doc_399014257221_item	3523710	et	4	main
kunstnikud	doc_399014257221_item	3523716	et	3	main
viltu	doc_399014257221_item	3523718	et	3	main
tallinna	doc_399014257221_item	3523723	et	4	main
kõrge	doc_399014257221_item	3523729	et	4	main
linna	doc_399014257221_item	3523736	et	4	main
korraldatud	doc_399014257221_item	3523737	et	4	main
konkursile	doc_399014257221_item	3523738	et	3	main
oli	doc_399014257221_item	3523739	et	3	main
tähtajaks	doc_399014257221_item	3523740	et	3	main
laekunud	doc_399014257221_item	3523741	et	4	main
püstitada	doc_399014257221_item	3523748	et	3	main
tallinnast	doc_399014257221_item	3523754	et	3	main
on	doc_399014257221_item	3523761	et	4	main
teise	doc_399014257221_item	3523768	et	4	main
maailmasõja	doc_399014257221_item	3523769	et	3	main
algasid	doc_399014257221_item	3523785	et	4	main
juba	doc_399014257221_item	3523786	et	3	main
iseenesest	doc_399014257221_item	3523797	et	4	main
nii	doc_399014257221_item	3523811	et	3	main
ka	doc_399014257221_item	3523814	et	3	main
ühenduste	doc_399014257221_item	3523816	et	4	main
ideekonkursi	doc_399014257221_item	3523818	et	3	main
protestides	doc_399014257221_item	3523821	et	4	main
32	doc_399014257221_item	3523828	et	2	main
juhitud	doc_399014257221_item	3523829	et	4	main
liige	doc_399014257221_item	3523836	et	4	main
parke	doc_399014257221_item	3523843	et	3	main
algupärase	doc_399014257221_item	3523844	et	4	main
idee	doc_399014257221_item	3523845	et	4	main
isa	doc_399014257221_item	3523846	et	4	main
kunstnik	doc_399014257221_item	3523849	et	3	main
40	doc_399014257221_item	3523854	et	2	main
kes	doc_399014257221_item	3523855	et	4	main
alustas	doc_399014257221_item	3523856	et	3	main
kalevipoja	doc_399014257221_item	3523857	et	4	main
kujundada	doc_399014257221_item	3523864	et	3	main
merineitsiga	doc_399014257221_item	3523868	et	3	main
sümbol	doc_399014257221_item	3523870	et	3	main
linna	doc_399014257221_item	3523882	et	4	main
ettepanekul	doc_399014257221_item	3523883	et	3	main
see	doc_399014257221_item	3523884	et	3	main
paistaks	doc_399014257221_item	3523905	et	3	main
arvates	doc_399014257221_item	3523912	et	4	main
teel	doc_399014257221_item	3523923	et	4	main
pirita	doc_399014257221_item	3523924	et	4	main
sanatooriumisse	doc_399014257221_item	3523925	et	3	main
või	doc_399014257221_item	3523926	et	4	main
kangro	doc_399014257221_item	3523935	et	4	main
ateljees	doc_399014257221_item	3523936	et	3	main
oli	doc_399014257221_item	3523937	et	3	main
galerist	doc_399014257221_item	3523948	et	4	main
pille	doc_399014257221_item	3523949	et	3	main
on	doc_399014257221_item	3523968	et	4	main
veel	doc_399014257221_item	3523978	et	4	main
paat	doc_399014257221_item	3523979	et	3	main
kes	doc_399014257221_item	3523983	et	4	main
teiste	doc_399014257221_item	3524018	et	4	main
kasvas	doc_399014257221_item	3524023	et	3	main
keskerakonnaga	doc_399014257221_item	3524033	et	4	main
sest	doc_399014257221_item	3524041	et	4	main
loopis	doc_399014257221_item	3524046	et	3	main
ametlik	doc_59711134398_item	3524265	et	3	main
mina	doc_59711134398_item	3524270	et	4	main
teie	doc_59711134398_item	3524272	et	4	main
vähenõudlike	doc_59711134398_item	3524274	et	3	main
põlvkond	doc_59711134398_item	3524275	et	3	main
pappi	doc_59711134398_item	3524290	et	4	main
ja	doc_59711134398_item	3524291	et	3	main
kajuks	doc_59711134398_item	3524300	et	4	main
olla	doc_59711134398_item	3524304	et	3	main
tahaks	doc_59711134398_item	3524308	et	3	main
et	doc_59711134398_item	3524310	et	3	main
ma	doc_59711134398_item	3524311	et	3	main
et	doc_59711134398_item	3524346	et	3	main
nagu	doc_59711134398_item	3524349	et	3	main
midagi	doc_59711134398_item	3524360	et	4	main
memoriaalkompleksi	doc_399014257221_item	3523806	et	4	main
astusid	doc_399014257221_item	3523810	et	4	main
esindajad	doc_399014257221_item	3523817	et	4	main
tagasi	doc_399014257221_item	3523820	et	3	main
žürii	doc_399014257221_item	3523822	et	2	main
bürokraatlikkuse	doc_399014257221_item	3523823	et	4	main
vastu	doc_399014257221_item	3523824	et	3	main
jäänud	doc_399014257221_item	3523833	et	4	main
sõltumatu	doc_399014257221_item	3523834	et	4	main
vaieldav	doc_399014257221_item	3523850	et	4	main
oli	doc_399014257221_item	3523863	et	3	main
kopenhaageni	doc_399014257221_item	3523866	et	4	main
kavandis	doc_399014257221_item	3523872	et	3	main
väike	doc_399014257221_item	3523874	et	4	main
merineitsi	doc_399014257221_item	3523875	et	4	main
oli	doc_399014257221_item	3523876	et	3	main
kasvas	doc_399014257221_item	3523885	et	3	main
21	doc_399014257221_item	3523886	et	2	main
meetriseks	doc_399014257221_item	3523887	et	4	main
vaatasime	doc_399014257221_item	3523888	et	3	main
kuidas	doc_399014257221_item	3523889	et	3	main
kuju	doc_399014257221_item	3523890	et	4	main
sobib	doc_399014257221_item	3523891	et	3	main
kokku	doc_399014257221_item	3523892	et	3	main
maarjamäe	doc_399014257221_item	3523893	et	3	main
memoriaalkompleksiga	doc_399014257221_item	3523894	et	4	main
tegime	doc_399014257221_item	3523895	et	3	main
arvestusi	doc_399014257221_item	3523896	et	4	main
ja	doc_399014257221_item	3523897	et	3	main
visualiseerisime	doc_399014257221_item	3523898	et	4	main
need	doc_399014257221_item	3523899	et	3	main
otsustasime	doc_399014257221_item	3523900	et	3	main
21	doc_399014257221_item	3523901	et	2	main
meetri	doc_399014257221_item	3523902	et	3	main
poolt	doc_399014257221_item	3523903	et	4	main
see	doc_399014257221_item	3523904	et	3	main
aselinnapea	doc_399014257221_item	3523908	et	4	main
ka	doc_399014257221_item	3523913	et	3	main
on	doc_399014257221_item	3523915	et	4	main
võimalik	doc_399014257221_item	3523917	et	3	main
see	doc_399014257221_item	3523928	et	3	main
ka	doc_399014257221_item	3523931	et	3	main
esmaspäevalgi	doc_399014257221_item	3523939	et	4	main
vaimustunud	doc_399014257221_item	3523940	et	4	main
õhkkond	doc_399014257221_item	3523941	et	3	main
ei	doc_399014257221_item	3523944	et	4	main
sümboliseerib	doc_399014257221_item	3523961	et	3	main
kojunaasmist	doc_399014257221_item	3523963	et	3	main
käes	doc_399014257221_item	3523973	et	4	main
on	doc_399014257221_item	3523974	et	4	main
kunstniku	doc_399014257221_item	3523975	et	3	main
poolehoidu	doc_399014257221_item	3524014	et	4	main
kunstnike	doc_399014257221_item	3524019	et	3	main
vastu	doc_399014257221_item	3524022	et	3	main
pärast	doc_399014257221_item	3524024	et	4	main
seda	doc_399014257221_item	3524025	et	3	main
kui	doc_399014257221_item	3524026	et	3	main
ideed	doc_399014257221_item	3524027	et	4	main
turustanud	doc_399014257221_item	3524030	et	4	main
järgi	doc_399014257221_item	3524043	et	4	main
kividega	doc_399014257221_item	3524049	et	3	main
siiski	doc_399014257221_item	3523848	et	4	main
tauno	doc_399014257221_item	3523852	et	4	main
väikse	doc_399014257221_item	3523867	et	4	main
aga	doc_399014257221_item	3523881	et	3	main
sõtnik	doc_399014257221_item	3523910	et	4	main
asukoht	doc_399014257221_item	3523914	et	3	main
parim	doc_399014257221_item	3523916	et	4	main
ei	doc_399014257221_item	3523929	et	4	main
vanalinna	doc_399014257221_item	3523932	et	4	main
siluetti	doc_399014257221_item	3523933	et	4	main
mägila	doc_399014257221_item	3523950	et	4	main
pronkskuju	doc_399014257221_item	3523953	et	4	main
kätega	doc_399014257221_item	3523956	et	3	main
paati	doc_399014257221_item	3523959	et	4	main
skulptuur	doc_399014257221_item	3523960	et	3	main
pärast	doc_399014257221_item	3523964	et	4	main
seda	doc_399014257221_item	3523965	et	3	main
kui	doc_399014257221_item	3523966	et	3	main
ta	doc_399014257221_item	3523967	et	4	main
kangelase	doc_399014257221_item	3523972	et	3	main
ja	doc_399014257221_item	3523980	et	3	main
inimkujud	doc_399014257221_item	3523982	et	3	main
on	doc_399014257221_item	3524006	et	4	main
ainuvõimul	doc_399014257221_item	3524007	et	3	main
keskerakond	doc_399014257221_item	3524008	et	3	main
mis	doc_399014257221_item	3524009	et	4	main
kõrgete	doc_399014257221_item	3524015	et	4	main
kaua	doc_399014257221_item	3524028	et	3	main
kriitika	doc_399014257221_item	3524034	et	4	main
on	doc_399014257221_item	3524036	et	4	main
ta	doc_399014257221_item	3524044	et	4	main
küll	doc_399014257221_item	3524045	et	4	main
2008	doc_399014257221_item	3524087	et	2	main
tallinna	doc_399014257221_item	3523873	et	4	main
kõrge	doc_399014257221_item	3523880	et	4	main
silma	doc_399014257221_item	3523906	et	4	main
sõtniku	doc_399014257221_item	3523911	et	4	main
tauno	doc_399014257221_item	3523934	et	4	main
kunstnik	doc_399014257221_item	3523942	et	3	main
olnud	doc_399014257221_item	3523945	et	4	main
linnas	doc_399014257221_item	3523946	et	4	main
aga	doc_399014257221_item	3523947	et	3	main
vaimustunult	doc_399014257221_item	3523952	et	4	main
suurte	doc_399014257221_item	3523955	et	3	main
tassib	doc_399014257221_item	3523958	et	3	main
kangelase	doc_399014257221_item	3523962	et	3	main
rännanud	doc_399014257221_item	3523969	et	4	main
ümber	doc_399014257221_item	3523970	et	3	main
maailma	doc_399014257221_item	3523971	et	4	main
mõned	doc_399014257221_item	3523981	et	3	main
sümboliseerivad	doc_399014257221_item	3523984	et	4	main
eestlaste	doc_399014257221_item	3523985	et	4	main
kojutulekut	doc_399014257221_item	3523986	et	3	main
peale	doc_399014257221_item	3523987	et	4	main
kujurite	doc_399014257221_item	3523988	et	3	main
ühenduse	doc_399014257221_item	3523989	et	4	main
boikoteerib	doc_399014257221_item	3523990	et	3	main
skulptuurtehingut	doc_399014257221_item	3523991	et	3	main
ka	doc_399014257221_item	3523992	et	3	main
mõjuvõimsam	doc_399014257221_item	3523993	et	4	main
arhitektideliit	doc_399014257221_item	3523994	et	4	main
mis	doc_399014257221_item	3523995	et	4	main
on	doc_399014257221_item	3523996	et	4	main
tülis	doc_399014257221_item	3523997	et	4	main
linnaga	doc_399014257221_item	3523998	et	3	main
ka	doc_399014257221_item	3523999	et	3	main
näiteks	doc_399014257221_item	3524000	et	4	main
uue	doc_399014257221_item	3524001	et	3	main
raekoja	doc_399014257221_item	3524002	et	3	main
asukoha	doc_399014257221_item	3524003	et	4	main
suhtes	doc_399014257221_item	3524004	et	4	main
on	doc_399014257221_item	3524010	et	4	main
varem	doc_399014257221_item	3524012	et	4	main
näidanud	doc_399014257221_item	3524013	et	4	main
vastu	doc_399014257221_item	3524017	et	3	main
skulptuurtehingu	doc_399014257221_item	3524021	et	3	main
aega	doc_399014257221_item	3524029	et	4	main
kangro	doc_399014257221_item	3524031	et	4	main
liitus	doc_399014257221_item	3524032	et	4	main
osaks	doc_399014257221_item	3524035	et	3	main
saanud	doc_399014257221_item	3524037	et	4	main
ka	doc_399014257221_item	3524038	et	3	main
kalevipoeg	doc_399014257221_item	3524039	et	3	main
ise	doc_399014257221_item	3524040	et	4	main
suurte	doc_399014257221_item	3524048	et	3	main
kaalep	doc_59711134398_item	3524269	et	4	main
absoluutselt	doc_59711134398_item	3524284	et	4	main
keskkonnast	doc_59711134398_item	3524297	et	4	main
see	doc_59711134398_item	3524341	et	3	main
meie	doc_59711134398_item	3524353	et	4	main
põlvkond	doc_59711134398_item	3524354	et	3	main
ma	doc_59711134398_item	3524355	et	3	main
arvan	doc_59711134398_item	3524356	et	3	main
et	doc_59711134398_item	3524357	et	3	main
vale	doc_59711134398_item	3524361	et	4	main
tallinnas	doc_399014257221_item	3524005	et	4	main
ka	doc_399014257221_item	3524011	et	3	main
ehituste	doc_399014257221_item	3524016	et	4	main
kriitika	doc_399014257221_item	3524020	et	4	main
legendi	doc_399014257221_item	3524042	et	4	main
vaenlast	doc_399014257221_item	3524047	et	3	main
aga	doc_399014257221_item	3524050	et	3	main
oli	doc_399014257221_item	3524051	et	3	main
ka	doc_399014257221_item	3524052	et	3	main
süüdlane	doc_399014257221_item	3524053	et	3	main
neiu	doc_399014257221_item	3524054	et	4	main
vägistamises	doc_399014257221_item	3524055	et	4	main
meres	doc_399014257221_item	3524056	et	3	main
on	doc_399014257221_item	3524057	et	4	main
küsitud	doc_399014257221_item	3524058	et	4	main
et	doc_399014257221_item	3524059	et	3	main
kas	doc_399014257221_item	3524060	et	3	main
ta	doc_399014257221_item	3524061	et	4	main
on	doc_399014257221_item	3524062	et	4	main
sobiv	doc_399014257221_item	3524063	et	4	main
sümbol	doc_399014257221_item	3524064	et	3	main
meres	doc_399014257221_item	3524065	et	3	main
kalevipoja	doc_399014257221_item	3524066	et	4	main
konkursi	doc_399014257221_item	3524067	et	3	main
tulemused	doc_399014257221_item	3524068	et	3	main
avaldatakse	doc_399014257221_item	3524069	et	3	main
jaanuari	doc_399014257221_item	3524070	et	4	main
lõpul	doc_399014257221_item	3524071	et	3	main
mille	doc_399014257221_item	3524072	et	3	main
järel	doc_399014257221_item	3524073	et	4	main
võitlustöödest	doc_399014257221_item	3524074	et	3	main
korraldatakse	doc_399014257221_item	3524075	et	3	main
näitus	doc_399014257221_item	3524076	et	3	main
abilinnapea	doc_399014257221_item	3524077	et	4	main
sõtniku	doc_399014257221_item	3524078	et	4	main
järgi	doc_399014257221_item	3524079	et	4	main
on	doc_399014257221_item	3524080	et	4	main
kuju	doc_399014257221_item	3524081	et	4	main
kavas	doc_399014257221_item	3524082	et	3	main
püstitada	doc_399014257221_item	3524083	et	3	main
aastate	doc_399014257221_item	3524084	et	3	main
2007	doc_399014257221_item	3524085	et	2	main
ja	doc_399014257221_item	3524086	et	3	main
jooksul	doc_399014257221_item	3524088	et	4	main
kiri	doc_59711134398_item	3524266	et	3	main
artiklit	doc_59711134398_item	3524273	et	3	main
teile	doc_59711134398_item	3524279	et	4	main
kõik	doc_59711134398_item	3524287	et	4	main
tahavad	doc_59711134398_item	3524288	et	3	main
ei	doc_59711134398_item	3524295	et	4	main
inimestest	doc_59711134398_item	3524299	et	3	main
selline	doc_59711134398_item	3524306	et	4	main
inimestest	doc_59711134398_item	3524315	et	3	main
kindlasti	doc_59711134398_item	3524358	et	3	main
veedab	doc_59711134398_item	3524364	et	3	main
ka	doc_59711134398_item	3524368	et	3	main
ju	doc_59711134398_item	3524379	et	3	main
kus	doc_59711134398_item	3524381	et	3	main
ütle	doc_59711134398_item	3524423	et	4	main
teile	doc_59711134398_item	3524430	et	4	main
ilusa	doc_59711134398_item	3524431	et	3	main
artikli	doc_59711134398_item	3524432	et	3	main
eest	doc_59711134398_item	3524433	et	4	main
see	doc_59711134398_item	3524434	et	3	main
oli	doc_59711134398_item	3524435	et	3	main
väga	doc_59711134398_item	3524436	et	3	main
teaduslik	doc_59711134398_item	3524437	et	3	main
lugupidamisega	doc_59711134398_item	3524438	et	3	main
eesnimi	doc_59711134398_item	3524439	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_59711134398_item	3524440	et	4	main
tiina	doc_59711134398_item	3524268	et	4	main
ja	doc_59711134398_item	3524276	et	3	main
kirjutada	doc_59711134398_item	3524278	et	3	main
oma	doc_59711134398_item	3524280	et	4	main
arvamusest	doc_59711134398_item	3524281	et	4	main
olen	doc_59711134398_item	3524282	et	3	main
teiega	doc_59711134398_item	3524283	et	3	main
palju	doc_59711134398_item	3524289	et	4	main
hooli	doc_59711134398_item	3524296	et	4	main
olen	doc_59711134398_item	3524301	et	3	main
võib	doc_59711134398_item	3524303	et	3	main
teistest	doc_59711134398_item	3524314	et	4	main
nagu	doc_59711134398_item	3524316	et	3	main
te	doc_59711134398_item	3524317	et	4	main
kirjutasite	doc_59711134398_item	3524318	et	3	main
vaba	doc_59711134398_item	3524319	et	4	main
aeg	doc_59711134398_item	3524320	et	3	main
on	doc_59711134398_item	3524321	et	4	main
täiesti	doc_59711134398_item	3524322	et	3	main
väärtus	doc_59711134398_item	3524323	et	3	main
ja	doc_59711134398_item	3524324	et	3	main
mina	doc_59711134398_item	3524325	et	4	main
valeks	doc_59711134398_item	3524326	et	3	main
endale	doc_59711134398_item	3524327	et	4	main
tuleviku	doc_59711134398_item	3524328	et	4	main
kus	doc_59711134398_item	3524329	et	3	main
ma	doc_59711134398_item	3524330	et	3	main
ei	doc_59711134398_item	3524331	et	4	main
pea	doc_59711134398_item	3524332	et	4	main
tööle	doc_59711134398_item	3524333	et	3	main
käima	doc_59711134398_item	3524335	et	4	main
palju	doc_59711134398_item	3524334	et	4	main
tahaks	doc_59711134398_item	3524336	et	3	main
materiaalse	doc_59711134398_item	3524337	et	3	main
kindlustust	doc_59711134398_item	3524338	et	4	main
sotsiaaltagatiseid	doc_59711134398_item	3524339	et	4	main
jne	doc_59711134398_item	3524340	et	4	main
lugupeetud	doc_59711134398_item	3524267	et	4	main
lugesin	doc_59711134398_item	3524271	et	3	main
tahan	doc_59711134398_item	3524277	et	3	main
nõus	doc_59711134398_item	3524285	et	4	main
et	doc_59711134398_item	3524286	et	3	main
kohe	doc_59711134398_item	3524292	et	4	main
keegi	doc_59711134398_item	3524293	et	4	main
eriti	doc_59711134398_item	3524294	et	3	main
teistest	doc_59711134398_item	3524298	et	4	main
ma	doc_59711134398_item	3524302	et	3	main
ka	doc_59711134398_item	3524305	et	3	main
aga	doc_59711134398_item	3524307	et	3	main
märkida	doc_59711134398_item	3524309	et	4	main
ikkagi	doc_59711134398_item	3524312	et	4	main
hoolitsen	doc_59711134398_item	3524313	et	3	main
meie	doc_59711134398_item	3524343	et	4	main
suur	doc_59711134398_item	3524344	et	3	main
tahame	doc_59711134398_item	3524347	et	3	main
neljakümnesed	doc_59711134398_item	3524350	et	3	main
on	doc_59711134398_item	3524359	et	4	main
riigieksamitega	doc_59711134398_item	3524362	et	3	main
nii	doc_59711134398_item	3524369	et	3	main
teavad	doc_59711134398_item	3524373	et	3	main
saavad	doc_59711134398_item	3524374	et	4	main
väga	doc_59711134398_item	3524375	et	3	main
vähe	doc_59711134398_item	3524376	et	3	main
palki	doc_59711134398_item	3524377	et	4	main
õpida	doc_59711134398_item	3524415	et	4	main
ja	doc_59711134398_item	3524416	et	3	main
et	doc_59711134398_item	3524424	et	3	main
oleme	doc_59711134398_item	3524425	et	3	main
vähenõudlik	doc_59711134398_item	3524426	et	3	main
põlvkond	doc_59711134398_item	3524427	et	3	main
suur	doc_59711134398_item	3524428	et	3	main
täna	doc_59711134398_item	3524429	et	4	main
kiri	doc_59711134400_item	3524443	et	3	main
minu	doc_59711134400_item	3524447	et	3	main
ma	doc_59711134400_item	3524451	et	3	main
ülikoolis	doc_59711134400_item	3524455	et	4	main
paar	doc_59711134400_item	3524456	et	3	main
tagasi	doc_59711134400_item	3524458	et	3	main
eesti	doc_59711134400_item	3524464	et	4	main
et	doc_59711134400_item	3524469	et	3	main
esimene	doc_59711134400_item	3524486	et	3	main
tea	doc_59711134400_item	3524548	et	4	main
tõttu	doc_59711134400_item	3524555	et	4	main
on	doc_59711134400_item	3524557	et	4	main
nagu	doc_59711134400_item	3524558	et	3	main
tihti	doc_59711134400_item	3524561	et	3	main
nendest	doc_59711134400_item	3524562	et	4	main
hooli	doc_59711134400_item	3524570	et	4	main
endast	doc_59711134400_item	3524599	et	4	main
head	doc_59711134400_item	3524602	et	4	main
need	doc_59711134400_item	3524605	et	3	main
olen	doc_59711134400_item	3524619	et	3	main
see	doc_59711134400_item	3524622	et	3	main
toimu	doc_59711134400_item	3524624	et	4	main
sest	doc_59711134400_item	3524625	et	4	main
need	doc_59711134400_item	3524626	et	3	main
erialad	doc_59711134400_item	3524627	et	3	main
liiga	doc_59711134400_item	3524634	et	4	main
nõus	doc_59711134400_item	3524637	et	4	main
sellega	doc_59711134400_item	3524638	et	3	main
et	doc_59711134400_item	3524639	et	3	main
teha	doc_59711134400_item	3524685	et	3	main
eesnimi	doc_59711134400_item	3524694	et	3	main
lugupeetud	doc_59711134401_item	3524886	et	4	main
te	doc_59711134401_item	3524892	et	4	main
teiega	doc_59711134401_item	3524909	et	3	main
soovib	doc_59711134401_item	3524914	et	3	main
polka	doc_59711134401_item	3524923	et	4	main
et	doc_59711134401_item	3524924	et	3	main
poleks	doc_59711134401_item	3524925	et	3	main
midagi	doc_59711134401_item	3524927	et	4	main
suurt	doc_59711134401_item	3524928	et	3	main
välja	doc_59711134401_item	3524929	et	4	main
sõnaga	doc_59711134401_item	3524934	et	3	main
veel	doc_59711134401_item	3524982	et	4	main
üks	doc_59711134401_item	3524983	et	3	main
abituriendil	doc_59711134401_item	3524986	et	3	main
tänavasel	doc_59711134401_item	3524991	et	4	main
valik	doc_59711134401_item	3524994	et	3	main
sellest	doc_59711134401_item	3524996	et	4	main
milline	doc_59711134401_item	3524998	et	3	main
ei	doc_59711134401_item	3525051	et	4	main
ja	doc_59711134401_item	3525057	et	3	main
on	doc_59711134398_item	3524342	et	4	main
probleem	doc_59711134398_item	3524345	et	3	main
elada	doc_59711134398_item	3524348	et	3	main
selline	doc_59711134398_item	3524351	et	4	main
on	doc_59711134398_item	3524352	et	4	main
mitte	doc_59711134398_item	3524366	et	3	main
et	doc_59711134398_item	3524370	et	3	main
mida	doc_59711134398_item	3524417	et	4	main
tahavad	doc_59711134398_item	3524418	et	3	main
keegi	doc_59711134398_item	3524421	et	4	main
ei	doc_59711134398_item	3524422	et	4	main
tiina	doc_59711134400_item	3524445	et	4	main
artiklit	doc_59711134400_item	3524461	et	3	main
minule	doc_59711134400_item	3524470	et	3	main
meeldis	doc_59711134400_item	3524472	et	3	main
artikkel	doc_59711134400_item	3524474	et	3	main
rühmaks	doc_59711134400_item	3524485	et	4	main
on	doc_59711134400_item	3524496	et	4	main
kõige	doc_59711134400_item	3524497	et	4	main
saada	doc_59711134400_item	3524507	et	4	main
liisida	doc_59711134400_item	3524510	et	4	main
mis	doc_59711134400_item	3524549	et	4	main
sest	doc_59711134400_item	3524567	et	4	main
käia	doc_59711134400_item	3524579	et	4	main
mingi	doc_59711134400_item	3524581	et	4	main
palk	doc_59711134400_item	3524582	et	3	main
saata	doc_59711134400_item	3524583	et	3	main
loodan	doc_59711134400_item	3524584	et	3	main
tulevikus	doc_59711134400_item	3524588	et	4	main
teiega	doc_59711134400_item	3524592	et	3	main
keskonnakaitsja	doc_59711134400_item	3524610	et	4	main
ametist	doc_59711134400_item	3524611	et	3	main
ma	doc_59711134400_item	3524618	et	3	main
on	doc_59711134400_item	3524633	et	4	main
oma	doc_59711134400_item	3524642	et	4	main
töö	doc_59711134400_item	3524643	et	4	main
eest	doc_59711134400_item	3524644	et	4	main
saama	doc_59711134400_item	3524645	et	4	main
palju	doc_59711134400_item	3524646	et	4	main
rohkem	doc_59711134400_item	3524647	et	4	main
raha	doc_59711134400_item	3524648	et	4	main
kui	doc_59711134400_item	3524649	et	3	main
täna	doc_59711134400_item	3524650	et	4	main
tänapäevas	doc_59711134400_item	3524651	et	3	main
see	doc_59711134400_item	3524652	et	3	main
on	doc_59711134400_item	3524653	et	4	main
suur	doc_59711134400_item	3524654	et	3	main
probleem	doc_59711134400_item	3524655	et	3	main
meie	doc_59711134400_item	3524656	et	4	main
riigis	doc_59711134400_item	3524657	et	3	main
varsti	doc_59711134400_item	3524658	et	3	main
võib	doc_59711134400_item	3524659	et	3	main
juhtuda	doc_59711134400_item	3524660	et	3	main
nii	doc_59711134400_item	3524661	et	3	main
kuidas	doc_59711134400_item	3524684	et	3	main
et	doc_59711134400_item	3524687	et	3	main
rühm	doc_59711134400_item	3524689	et	3	main
parimate	doc_59711134400_item	3524692	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_59711134400_item	3524695	et	4	main
kaalep	doc_59711134401_item	3524888	et	4	main
tänada	doc_59711134401_item	3524890	et	3	main
andis	doc_59711134401_item	3524900	et	3	main
uut	doc_59711134401_item	3524902	et	3	main
et	doc_59711134401_item	3524911	et	3	main
inimesi	doc_59711134401_item	3524913	et	4	main
kas	doc_59711134398_item	3524363	et	3	main
või	doc_59711134398_item	3524365	et	4	main
kes	doc_59711134398_item	3524372	et	4	main
teha	doc_59711134398_item	3524419	et	3	main
ametlik	doc_59711134400_item	3524442	et	3	main
nimi	doc_59711134400_item	3524448	et	3	main
õppin	doc_59711134400_item	3524452	et	4	main
nädalat	doc_59711134400_item	3524457	et	3	main
lugesin	doc_59711134400_item	3524459	et	3	main
põlvkond	doc_59711134400_item	3524463	et	3	main
ekspressis	doc_59711134400_item	3524465	et	4	main
kirjutan	doc_59711134400_item	3524466	et	3	main
see	doc_59711134400_item	3524473	et	3	main
sellest	doc_59711134400_item	3524479	et	4	main
jagasite	doc_59711134400_item	3524481	et	3	main
noor	doc_59711134400_item	3524482	et	3	main
arvates	doc_59711134400_item	3524488	et	4	main
selliseid	doc_59711134400_item	3524494	et	4	main
inimesi	doc_59711134400_item	3524495	et	4	main
nõus	doc_59711134400_item	3524501	et	4	main
need	doc_59711134400_item	3524502	et	3	main
noored	doc_59711134400_item	3524503	et	3	main
teine	doc_59711134400_item	3524542	et	3	main
kes	doc_59711134400_item	3524546	et	4	main
tule	doc_59711134400_item	3524564	et	4	main
spetsialistid	doc_59711134400_item	3524566	et	3	main
nad	doc_59711134400_item	3524568	et	3	main
vaid	doc_59711134400_item	3524572	et	3	main
sellest	doc_59711134400_item	3524574	et	4	main
see	doc_59711134400_item	3524586	et	3	main
tulevikus	doc_59711134400_item	3524590	et	4	main
et	doc_59711134400_item	3524594	et	3	main
eriti	doc_59711134400_item	3524601	et	3	main
rühm	doc_59711134400_item	3524604	et	3	main
tahate	doc_59711134400_item	3524613	et	3	main
et	doc_59711134400_item	3524614	et	3	main
neid	doc_59711134400_item	3524615	et	4	main
oleks	doc_59711134400_item	3524616	et	3	main
et	doc_59711134400_item	3524621	et	3	main
ei	doc_59711134400_item	3524628	et	4	main
ja	doc_59711134400_item	3524631	et	3	main
väike	doc_59711134400_item	3524635	et	4	main
nõus	doc_59711134400_item	3524679	et	4	main
mul	doc_59711134400_item	3524680	et	3	main
tiina	doc_59711134401_item	3524887	et	4	main
tahaks	doc_59711134401_item	3524889	et	3	main
on	doc_59711134401_item	3524896	et	4	main
huvitav	doc_59711134401_item	3524898	et	4	main
informatsiooni	doc_59711134401_item	3524903	et	4	main
noorte	doc_59711134401_item	3524904	et	3	main
inimeste	doc_59711134401_item	3524905	et	3	main
kohta	doc_59711134401_item	3524906	et	4	main
ma	doc_59711134401_item	3524907	et	3	main
olen	doc_59711134401_item	3524908	et	3	main
rahulikkut	doc_59711134401_item	3524916	et	4	main
ja	doc_59711134401_item	3524918	et	3	main
iga	doc_59711134401_item	3524920	et	4	main
kuu	doc_59711134401_item	3524921	et	4	main
vanemate	doc_59711134401_item	3524976	et	4	main
saada	doc_59711134401_item	3524980	et	4	main
tööd	doc_59711134401_item	3524981	et	4	main
juhtub	doc_59711134398_item	3524367	et	3	main
need	doc_59711134398_item	3524371	et	3	main
sellest	doc_59711134398_item	3524378	et	4	main
sõltub	doc_59711134398_item	3524380	et	3	main
kohas	doc_59711134398_item	3524382	et	4	main
nad	doc_59711134398_item	3524383	et	3	main
hakkavad	doc_59711134398_item	3524384	et	4	main
õppima	doc_59711134398_item	3524385	et	3	main
tulevik	doc_59711134398_item	3524387	et	3	main
pärast	doc_59711134398_item	3524388	et	4	main
lõpetamist	doc_59711134398_item	3524389	et	4	main
nad	doc_59711134398_item	3524390	et	3	main
nende	doc_59711134398_item	3524386	et	4	main
kandideerivad	doc_59711134398_item	3524391	et	4	main
suvalistele	doc_59711134398_item	3524392	et	4	main
töökohtadile	doc_59711134398_item	3524393	et	4	main
ei	doc_59711134398_item	3524394	et	4	main
naudi	doc_59711134398_item	3524395	et	4	main
oma	doc_59711134398_item	3524396	et	4	main
ametist	doc_59711134398_item	3524397	et	3	main
lõpuks	doc_59711134398_item	3524398	et	4	main
ma	doc_59711134398_item	3524399	et	3	main
ütlen	doc_59711134398_item	3524400	et	3	main
et	doc_59711134398_item	3524401	et	3	main
on	doc_59711134398_item	3524402	et	4	main
vaja	doc_59711134398_item	3524403	et	4	main
rääkida	doc_59711134398_item	3524404	et	3	main
tulevikust	doc_59711134398_item	3524405	et	4	main
juba	doc_59711134398_item	3524406	et	3	main
koolis	doc_59711134398_item	3524407	et	4	main
nii	doc_59711134398_item	3524408	et	3	main
et	doc_59711134398_item	3524409	et	3	main
kõik	doc_59711134398_item	3524410	et	4	main
teaksid	doc_59711134398_item	3524411	et	4	main
kus	doc_59711134398_item	3524412	et	3	main
nad	doc_59711134398_item	3524413	et	3	main
tahavad	doc_59711134398_item	3524414	et	3	main
ja	doc_59711134398_item	3524420	et	3	main
lp	doc_59711134400_item	3524444	et	4	main
on	doc_59711134400_item	3524449	et	4	main
eesnimi	doc_59711134400_item	3524450	et	3	main
tallinna	doc_59711134400_item	3524453	et	4	main
tehnika	doc_59711134400_item	3524454	et	4	main
teie	doc_59711134400_item	3524460	et	4	main
vähenõudlike	doc_59711134400_item	3524462	et	3	main
sellepärast	doc_59711134400_item	3524468	et	3	main
tahan	doc_59711134400_item	3524475	et	3	main
minu	doc_59711134400_item	3524477	et	3	main
teie	doc_59711134400_item	3524487	et	4	main
kes	doc_59711134400_item	3524490	et	4	main
rahulikult	doc_59711134400_item	3524492	et	4	main
rohkem	doc_59711134400_item	3524498	et	4	main
olen	doc_59711134400_item	3524499	et	3	main
teiega	doc_59711134400_item	3524500	et	3	main
tahavad	doc_59711134400_item	3524504	et	3	main
rahulikult	doc_59711134400_item	3524505	et	4	main
töötada	doc_59711134400_item	3524506	et	3	main
palka	doc_59711134400_item	3524509	et	4	main
on	doc_59711134400_item	3524544	et	4	main
see	doc_59711134400_item	3524556	et	3	main
ei	doc_59711134400_item	3524563	et	4	main
ei	doc_59711134400_item	3524569	et	4	main
ja	doc_59711134400_item	3524580	et	3	main
et	doc_59711134400_item	3524585	et	3	main
rühm	doc_59711134400_item	3524587	et	3	main
väheneb	doc_59711134400_item	3524589	et	3	main
nõus	doc_59711134400_item	3524593	et	4	main
see	doc_59711134400_item	3524595	et	3	main
ei	doc_59711134400_item	3524597	et	4	main
midagi	doc_59711134400_item	3524600	et	4	main
kolmas	doc_59711134400_item	3524603	et	3	main
kes	doc_59711134400_item	3524606	et	4	main
räägivad	doc_59711134400_item	3524607	et	3	main
sotsiaaltöötaja	doc_59711134400_item	3524608	et	4	main
ja	doc_59711134400_item	3524609	et	3	main
rohkem	doc_59711134400_item	3524617	et	4	main
ole	doc_59711134400_item	3524629	et	4	main
populaarsed	doc_59711134400_item	3524630	et	3	main
arvamusega	doc_59711134400_item	3524678	et	3	main
teine	doc_59711134400_item	3524688	et	3	main
hakkaks	doc_59711134400_item	3524690	et	3	main
vähenema	doc_59711134400_item	3524691	et	3	main
soovidega	doc_59711134400_item	3524693	et	3	main
ametlik	doc_59711134401_item	3524884	et	3	main
teid	doc_59711134401_item	3524891	et	4	main
artikle	doc_59711134401_item	3524893	et	4	main
eest	doc_59711134401_item	3524894	et	4	main
see	doc_59711134401_item	3524895	et	3	main
palju	doc_59711134401_item	3524901	et	4	main
osa	doc_59711134401_item	3524912	et	4	main
leida	doc_59711134401_item	3524915	et	3	main
vaja	doc_59711134401_item	3524926	et	4	main
ühe	doc_59711134401_item	3524933	et	4	main
ajal	doc_59711134401_item	3524977	et	4	main
oli	doc_59711134401_item	3524978	et	3	main
vastus	doc_59711134401_item	3524985	et	3	main
päeval	doc_59711134401_item	3524992	et	3	main
sõltub	doc_59711134401_item	3524995	et	3	main
et	doc_59711134401_item	3524997	et	3	main
tulevikus	doc_59711134401_item	3525001	et	4	main
raha	doc_59711134401_item	3525003	et	4	main
põhjus	doc_59711134401_item	3525007	et	4	main
miks	doc_59711134401_item	3525008	et	4	main
aitama	doc_59711134401_item	3525054	et	3	main
noori	doc_59711134401_item	3525055	et	3	main
peamiselt	doc_59711134401_item	3525058	et	4	main
midagi	doc_59711134401_item	3525065	et	4	main
muutu	doc_59711134401_item	3525066	et	4	main
isegi	doc_59711134401_item	3525067	et	4	main
aastakäikude	doc_59711134401_item	3525068	et	3	main
et	doc_59711134400_item	3524662	et	3	main
paljud	doc_59711134400_item	3524663	et	3	main
arstid	doc_59711134400_item	3524664	et	4	main
hakkavad	doc_59711134400_item	3524665	et	4	main
töötama	doc_59711134400_item	3524666	et	3	main
välismaal	doc_59711134400_item	3524667	et	4	main
kus	doc_59711134400_item	3524668	et	3	main
palk	doc_59711134400_item	3524669	et	3	main
on	doc_59711134400_item	3524670	et	4	main
normaalne	doc_59711134400_item	3524671	et	3	main
lõpuks	doc_59711134400_item	3524672	et	4	main
tahan	doc_59711134400_item	3524673	et	3	main
kirjutada	doc_59711134400_item	3524674	et	3	main
et	doc_59711134400_item	3524675	et	3	main
olen	doc_59711134400_item	3524676	et	3	main
teie	doc_59711134400_item	3524677	et	4	main
kaalepp	doc_59711134400_item	3524446	et	4	main
teile	doc_59711134400_item	3524467	et	4	main
väga	doc_59711134400_item	3524471	et	3	main
kirjutada	doc_59711134400_item	3524476	et	3	main
arvamust	doc_59711134400_item	3524478	et	3	main
teie	doc_59711134400_item	3524480	et	4	main
põlvkonna	doc_59711134400_item	3524483	et	4	main
kolmeks	doc_59711134400_item	3524484	et	4	main
need	doc_59711134400_item	3524489	et	3	main
tahavad	doc_59711134400_item	3524491	et	3	main
elada	doc_59711134400_item	3524493	et	3	main
normaalset	doc_59711134400_item	3524508	et	3	main
auto	doc_59711134400_item	3524511	et	4	main
ja	doc_59711134400_item	3524512	et	3	main
soetada	doc_59711134400_item	3524513	et	3	main
väike	doc_59711134400_item	3524514	et	4	main
kodu	doc_59711134400_item	3524515	et	4	main
minu	doc_59711134400_item	3524516	et	3	main
meelest	doc_59711134400_item	3524517	et	4	main
neid	doc_59711134400_item	3524518	et	4	main
ei	doc_59711134400_item	3524519	et	4	main
huvita	doc_59711134400_item	3524520	et	4	main
risk	doc_59711134400_item	3524521	et	3	main
ja	doc_59711134400_item	3524522	et	3	main
kõige	doc_59711134400_item	3524523	et	4	main
tähtsam	doc_59711134400_item	3524524	et	4	main
on	doc_59711134400_item	3524525	et	4	main
stabiilsus	doc_59711134400_item	3524526	et	4	main
rahu	doc_59711134400_item	3524527	et	4	main
arvan	doc_59711134400_item	3524528	et	3	main
et	doc_59711134400_item	3524529	et	3	main
see	doc_59711134400_item	3524530	et	3	main
rühm	doc_59711134400_item	3524531	et	3	main
on	doc_59711134400_item	3524532	et	4	main
meie	doc_59711134400_item	3524533	et	4	main
tulevik	doc_59711134400_item	3524534	et	3	main
just	doc_59711134400_item	3524535	et	3	main
sellised	doc_59711134400_item	3524536	et	4	main
inimesed	doc_59711134400_item	3524537	et	3	main
garanteerivad	doc_59711134400_item	3524538	et	4	main
rahu	doc_59711134400_item	3524539	et	4	main
meie	doc_59711134400_item	3524540	et	4	main
maailmas	doc_59711134400_item	3524541	et	3	main
rühm	doc_59711134400_item	3524543	et	3	main
neid	doc_59711134400_item	3524545	et	4	main
ei	doc_59711134400_item	3524547	et	4	main
neist	doc_59711134400_item	3524550	et	4	main
saab	doc_59711134400_item	3524551	et	3	main
see	doc_59711134400_item	3524552	et	3	main
juhtub	doc_59711134400_item	3524553	et	3	main
riigieksamite	doc_59711134400_item	3524554	et	3	main
loterii	doc_59711134400_item	3524559	et	4	main
noortele	doc_59711134400_item	3524560	et	3	main
head	doc_59711134400_item	3524565	et	4	main
alast	doc_59711134400_item	3524571	et	4	main
ainult	doc_59711134400_item	3524573	et	4	main
et	doc_59711134400_item	3524575	et	3	main
oleks	doc_59711134400_item	3524576	et	3	main
koht	doc_59711134400_item	3524577	et	3	main
kus	doc_59711134400_item	3524578	et	3	main
olen	doc_59711134400_item	3524591	et	3	main
valdkond	doc_59711134400_item	3524596	et	3	main
kujuta	doc_59711134400_item	3524598	et	4	main
teie	doc_59711134400_item	3524612	et	4	main
kindel	doc_59711134400_item	3524620	et	3	main
ei	doc_59711134400_item	3524623	et	4	main
palk	doc_59711134400_item	3524632	et	3	main
olen	doc_59711134400_item	3524636	et	3	main
artid	doc_59711134400_item	3524640	et	4	main
peavad	doc_59711134400_item	3524641	et	4	main
on	doc_59711134400_item	3524681	et	4	main
üks	doc_59711134400_item	3524682	et	3	main
küsimus	doc_59711134400_item	3524683	et	4	main
nii	doc_59711134400_item	3524686	et	3	main
muuta	doc_59711134401_item	3525037	et	4	main
haridussüsteemi	doc_59711134401_item	3525038	et	4	main
ja	doc_59711134401_item	3525039	et	3	main
üldse	doc_59711134401_item	3525040	et	3	main
riigi	doc_59711134401_item	3525041	et	3	main
mu	doc_59711134401_item	3525042	et	3	main
üldne	doc_59711134401_item	3525043	et	4	main
arvamus	doc_59711134401_item	3525044	et	3	main
tulevikust	doc_59711134401_item	3525045	et	4	main
on	doc_59711134401_item	3525046	et	4	main
selline	doc_59711134401_item	3525047	et	4	main
et	doc_59711134401_item	3525048	et	3	main
kui	doc_59711134401_item	3525049	et	3	main
riik	doc_59711134401_item	3525050	et	3	main
kiri	doc_59711134401_item	3524885	et	3	main
väga	doc_59711134401_item	3524897	et	3	main
ja	doc_59711134401_item	3524899	et	3	main
nõus	doc_59711134401_item	3524910	et	4	main
oma	doc_59711134401_item	3524922	et	4	main
mõelda	doc_59711134401_item	3524930	et	4	main
elada	doc_59711134401_item	3524935	et	3	main
elu	doc_59711134401_item	3524937	et	4	main
praeguses	doc_59711134401_item	3524938	et	3	main
elus	doc_59711134401_item	3524939	et	4	main
kus	doc_59711134401_item	3524940	et	3	main
sa	doc_59711134401_item	3524941	et	3	main
ise	doc_59711134401_item	3524942	et	4	main
pead	doc_59711134401_item	3524943	et	4	main
oma	doc_59711134401_item	3524944	et	4	main
heaolu	doc_59711134401_item	3524945	et	4	main
eest	doc_59711134401_item	3524946	et	4	main
hoolima	doc_59711134401_item	3524947	et	4	main
ida	doc_59711134401_item	3524948	et	4	main
üks	doc_59711134401_item	3524949	et	3	main
tahaks	doc_59711134401_item	3524950	et	3	main
olla	doc_59711134401_item	3524951	et	3	main
hoolitsev	doc_59711134401_item	3524952	et	4	main
me	doc_59711134401_item	3524954	et	4	main
vanemate	doc_59711134401_item	3524955	et	4	main
ajal	doc_59711134401_item	3524956	et	4	main
noored	doc_59711134401_item	3524957	et	3	main
tahavad	doc_59711134401_item	3524958	et	3	main
et	doc_59711134401_item	3524959	et	3	main
pärast	doc_59711134401_item	3524960	et	4	main
ülikooli	doc_59711134401_item	3524961	et	4	main
lõpetamist	doc_59711134401_item	3524962	et	4	main
nad	doc_59711134401_item	3524963	et	3	main
saaks	doc_59711134401_item	3524964	et	3	main
leida	doc_59711134401_item	3524965	et	3	main
tööd	doc_59711134401_item	3524966	et	4	main
oma	doc_59711134401_item	3524967	et	4	main
alas	doc_59711134401_item	3524968	et	3	main
ma	doc_59711134401_item	3524969	et	3	main
olen	doc_59711134401_item	3524970	et	3	main
tööd	doc_59711134401_item	3524917	et	4	main
saada	doc_59711134401_item	3524919	et	4	main
iga	doc_59711134401_item	3524931	et	4	main
päev	doc_59711134401_item	3524932	et	3	main
rahulikut	doc_59711134401_item	3524936	et	4	main
nagu	doc_59711134401_item	3524953	et	3	main
sellega	doc_59711134401_item	3524971	et	3	main
täitsa	doc_59711134401_item	3524972	et	3	main
nõus	doc_59711134401_item	3524973	et	4	main
et	doc_59711134401_item	3524974	et	3	main
lihtsam	doc_59711134401_item	3524979	et	4	main
valida	doc_59711134401_item	3524988	et	3	main
töö	doc_59711134401_item	3524999	et	4	main
arvan	doc_59711134401_item	3525005	et	3	main
hakka	doc_59711134401_item	3525052	et	4	main
me	doc_59711134401_item	3524975	et	4	main
suur	doc_59711134401_item	3524984	et	3	main
on	doc_59711134401_item	3524987	et	4	main
õiget	doc_59711134401_item	3524989	et	3	main
ameti	doc_59711134401_item	3524993	et	3	main
toob	doc_59711134401_item	3525000	et	3	main
sulle	doc_59711134401_item	3525002	et	3	main
ma	doc_59711134401_item	3525004	et	3	main
et	doc_59711134401_item	3525006	et	3	main
enam	doc_59711134401_item	3525053	et	4	main
peal	doc_59711134401_item	3525069	et	4	main
ametit	doc_59711134401_item	3524990	et	3	main
noored	doc_59711134401_item	3525009	et	3	main
lähevad	doc_59711134401_item	3525010	et	3	main
suvalistele	doc_59711134401_item	3525011	et	4	main
töökogtadele	doc_59711134401_item	3525012	et	4	main
on	doc_59711134401_item	3525013	et	4	main
see	doc_59711134401_item	3525014	et	3	main
et	doc_59711134401_item	3525015	et	3	main
nad	doc_59711134401_item	3525016	et	3	main
lihtsalt	doc_59711134401_item	3525017	et	4	main
vajavad	doc_59711134401_item	3525018	et	4	main
eluks	doc_59711134401_item	3525019	et	3	main
raha	doc_59711134401_item	3525020	et	4	main
rahasuhtes	doc_59711134401_item	3525021	et	3	main
ma	doc_59711134401_item	3525022	et	3	main
arvan	doc_59711134401_item	3525023	et	3	main
palju	doc_59711134401_item	3525024	et	4	main
raha	doc_59711134401_item	3525025	et	4	main
on	doc_59711134401_item	3525026	et	4	main
elus	doc_59711134401_item	3525027	et	4	main
vaja	doc_59711134401_item	3525028	et	4	main
kahjuks	doc_59711134401_item	3525029	et	4	main
mitte	doc_59711134401_item	3525030	et	3	main
palju	doc_59711134401_item	3525031	et	4	main
abituriendi	doc_59711134401_item	3525032	et	3	main
mõtlevad	doc_59711134401_item	3525033	et	4	main
ühiskonnast	doc_59711134401_item	3525034	et	4	main
sellest	doc_59711134401_item	3525035	et	4	main
kuidas	doc_59711134401_item	3525036	et	3	main
inimesi	doc_59711134401_item	3525056	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_59711134401_item	3525071	et	4	main
neid	doc_59711134401_item	3525059	et	4	main
kes	doc_59711134401_item	3525060	et	4	main
lähevad	doc_59711134401_item	3525061	et	3	main
ülikooli	doc_59711134401_item	3525062	et	4	main
õppima	doc_59711134401_item	3525063	et	3	main
siis	doc_59711134401_item	3525064	et	3	main
äitah	doc_59711134401_item	3525070	et	4	main
ametlik	doc_59711134405_item	3525505	et	3	main
lp	doc_59711134405_item	3525507	et	4	main
aastat	doc_59711134405_item	3525522	et	3	main
ja	doc_59711134405_item	3525524	et	3	main
tallinnas	doc_59711134405_item	3525526	et	4	main
sündinud	doc_59711134405_item	3525529	et	4	main
ma	doc_59711134405_item	3525539	et	3	main
inimestest	doc_59711134405_item	3525560	et	3	main
teie	doc_59711134405_item	3525562	et	4	main
raha	doc_59711134405_item	3525574	et	4	main
teine	doc_59711134405_item	3525575	et	3	main
rühm	doc_59711134405_item	3525576	et	3	main
teha	doc_59711134405_item	3525586	et	3	main
ja	doc_59711134405_item	3525588	et	3	main
ei	doc_59711134405_item	3525590	et	4	main
tea	doc_59711134405_item	3525591	et	4	main
saab	doc_59711134405_item	3525594	et	3	main
ja	doc_59711134405_item	3525595	et	3	main
rühm	doc_59711134405_item	3525597	et	3	main
ma	doc_59711134405_item	3525600	et	3	main
ütelda	doc_59711134405_item	3525602	et	4	main
et	doc_59711134405_item	3525603	et	3	main
et	doc_59711134405_item	3525610	et	3	main
auto	doc_59711134405_item	3525624	et	4	main
soetada	doc_59711134405_item	3525625	et	3	main
looder	doc_59711134405_item	3525631	et	3	main
rühm	doc_59711134405_item	3525649	et	3	main
aega	doc_59711134405_item	3525660	et	4	main
aga	doc_59711134405_item	3525661	et	3	main
nad	doc_59711134405_item	3525662	et	3	main
ei	doc_59711134405_item	3525663	et	4	main
see	doc_59711134405_item	3525668	et	3	main
rühm	doc_59711134405_item	3525672	et	3	main
ning	doc_59711134405_item	3525686	et	3	main
keskkonnakaitsja	doc_59711134405_item	3525687	et	4	main
ametist	doc_59711134405_item	3525688	et	3	main
kui	doc_59711134405_item	3525689	et	3	main
oleks	doc_59711134405_item	3525693	et	3	main
tuleviku	doc_59711134405_item	3525695	et	4	main
kiri	doc_59711134405_item	3525506	et	3	main
tallinna	doc_59711134405_item	3525516	et	4	main
tehnikaülikooli	doc_59711134405_item	3525517	et	4	main
üliõpilane	doc_59711134405_item	3525518	et	3	main
ma	doc_59711134405_item	3525519	et	3	main
olen	doc_59711134405_item	3525520	et	3	main
19	doc_59711134405_item	3525521	et	2	main
septembris	doc_59711134405_item	3525538	et	3	main
te	doc_59711134405_item	3525557	et	4	main
rühmidest	doc_59711134405_item	3525561	et	2	main
arvates	doc_59711134405_item	3525563	et	4	main
esimene	doc_59711134405_item	3525564	et	3	main
rühm	doc_59711134405_item	3525565	et	3	main
on	doc_59711134405_item	3525566	et	4	main
kõige	doc_59711134405_item	3525569	et	4	main
inimesed	doc_59711134405_item	3525579	et	3	main
ked	doc_59711134405_item	3525580	et	4	main
midagi	doc_59711134405_item	3525587	et	4	main
ma	doc_59711134405_item	3525604	et	3	main
nõus	doc_59711134405_item	3525606	et	4	main
minu	doc_59711134405_item	3525608	et	3	main
inimene	doc_59711134405_item	3525615	et	3	main
ja	doc_59711134405_item	3525618	et	3	main
suurt	doc_59711134405_item	3525621	et	3	main
kui	doc_59711134405_item	3525629	et	3	main
elab	doc_59711134405_item	3525632	et	3	main
rüpes	doc_59711134405_item	3525641	et	4	main
ootab	doc_59711134405_item	3525642	et	3	main
astumiseni	doc_59711134405_item	3525659	et	4	main
umbkaudu	doc_59711134405_item	3525666	et	3	main
kaalep	doc_59711134405_item	3525509	et	4	main
eesnimi	doc_59711134405_item	3525513	et	3	main
kuigi	doc_59711134405_item	3525527	et	3	main
astusin	doc_59711134405_item	3525536	et	3	main
selles	doc_59711134405_item	3525537	et	4	main
kirjutasite	doc_59711134405_item	3525558	et	3	main
kellele	doc_59711134405_item	3525568	et	4	main
oluline	doc_59711134405_item	3525570	et	4	main
asi	doc_59711134405_item	3525571	et	4	main
maailmas	doc_59711134405_item	3525572	et	3	main
alati	doc_59711134405_item	3525581	et	4	main
ootab	doc_59711134405_item	3525582	et	3	main
viimse	doc_59711134405_item	3525583	et	3	main
momendi	doc_59711134405_item	3525584	et	3	main
on	doc_59711134405_item	3525598	et	4	main
on	doc_59711134405_item	3525612	et	4	main
normaalne	doc_59711134405_item	3525613	et	3	main
palju	doc_59711134405_item	3525616	et	4	main
oma	doc_59711134405_item	3525626	et	4	main
kodu	doc_59711134405_item	3525627	et	4	main
ei	doc_59711134405_item	3525634	et	4	main
normaalne	doc_59711134405_item	3525647	et	3	main
midagi	doc_59711134405_item	3525653	et	4	main
vaid	doc_59711134405_item	3525654	et	3	main
mõni	doc_59711134405_item	3525655	et	3	main
nädal	doc_59711134405_item	3525656	et	3	main
on	doc_59711134405_item	3525657	et	4	main
ülikoolidesse	doc_59711134405_item	3525658	et	3	main
isegi	doc_59711134405_item	3525665	et	4	main
on	doc_59711134405_item	3525669	et	4	main
suur	doc_59711134405_item	3525671	et	3	main
veel	doc_59711134405_item	3525691	et	4	main
võiks	doc_59711134405_item	3525694	et	4	main
palju	doc_59711134405_item	3525676	et	4	main
sellist	doc_59711134405_item	3525677	et	4	main
inimest	doc_59711134405_item	3525678	et	3	main
kolmas	doc_59711134405_item	3525679	et	3	main
rühm	doc_59711134405_item	3525680	et	3	main
on	doc_59711134405_item	3525681	et	4	main
neid	doc_59711134405_item	3525682	et	4	main
kes	doc_59711134405_item	3525683	et	4	main
räägivad	doc_59711134405_item	3525684	et	3	main
sotsiaaltöötaja	doc_59711134405_item	3525685	et	4	main
tiina	doc_59711134405_item	3525508	et	4	main
on	doc_59711134405_item	3525512	et	4	main
ma	doc_59711134405_item	3525514	et	3	main
kirjutasin	doc_59711134405_item	3525540	et	3	main
teile	doc_59711134405_item	3525541	et	4	main
sest	doc_59711134405_item	3525542	et	4	main
mineval	doc_59711134405_item	3525543	et	4	main
nädalal	doc_59711134405_item	3525544	et	3	main
loesin	doc_59711134405_item	3525545	et	4	main
teie	doc_59711134405_item	3525546	et	4	main
juhtkirja	doc_59711134405_item	3525547	et	4	main
nädalalehtis	doc_59711134405_item	3525548	et	2	main
eesti	doc_59711134405_item	3525549	et	4	main
ekspress	doc_59711134405_item	3525550	et	4	main
see	doc_59711134405_item	3525551	et	3	main
oli	doc_59711134405_item	3525552	et	3	main
juhtkiri	doc_59711134405_item	3525553	et	3	main
vähenõudlike	doc_59711134405_item	3525554	et	3	main
põlvkond	doc_59711134405_item	3525555	et	3	main
kus	doc_59711134405_item	3525556	et	3	main
muni	doc_59711134405_item	3525510	et	4	main
nimi	doc_59711134405_item	3525511	et	3	main
olen	doc_59711134405_item	3525515	et	3	main
vana	doc_59711134405_item	3525523	et	4	main
elan	doc_59711134405_item	3525525	et	3	main
olin	doc_59711134405_item	3525528	et	3	main
narvas	doc_59711134405_item	3525530	et	4	main
ja	doc_59711134405_item	3525531	et	3	main
elasin	doc_59711134405_item	3525532	et	3	main
seal	doc_59711134405_item	3525533	et	4	main
kuni	doc_59711134405_item	3525534	et	3	main
ülikoolisse	doc_59711134405_item	3525535	et	4	main
inimesed	doc_59711134405_item	3525567	et	3	main
on	doc_59711134405_item	3525577	et	4	main
pikaldased	doc_59711134405_item	3525578	et	3	main
mis	doc_59711134405_item	3525592	et	4	main
sotsiaaltöötajad	doc_59711134405_item	3525599	et	3	main
tahan	doc_59711134405_item	3525601	et	3	main
komast	doc_59711134405_item	3525559	et	4	main
on	doc_59711134405_item	3525573	et	4	main
et	doc_59711134405_item	3525585	et	3	main
kes	doc_59711134405_item	3525589	et	4	main
neist	doc_59711134405_item	3525593	et	4	main
kolmas	doc_59711134405_item	3525596	et	3	main
olen	doc_59711134405_item	3525605	et	3	main
teiega	doc_59711134405_item	3525607	et	3	main
see	doc_59711134405_item	3525611	et	3	main
kui	doc_59711134405_item	3525614	et	3	main
töötab	doc_59711134405_item	3525617	et	3	main
saada	doc_59711134405_item	3525620	et	4	main
noor	doc_59711134405_item	3525630	et	3	main
vanemadega	doc_59711134405_item	3525633	et	4	main
tööta	doc_59711134405_item	3525635	et	4	main
ja	doc_59711134405_item	3525636	et	3	main
ei	doc_59711134405_item	3525637	et	4	main
siis	doc_59711134405_item	3525643	et	3	main
on	doc_59711134405_item	3525645	et	4	main
teine	doc_59711134405_item	3525648	et	3	main
alati	doc_59711134405_item	3525651	et	4	main
mitte	doc_59711134405_item	3525667	et	3	main
väga	doc_59711134405_item	3525670	et	3	main
osas	doc_59711134405_item	3525696	et	4	main
neile	doc_59711134405_item	3525697	et	4	main
panustada	doc_59711134405_item	3525698	et	3	main
tüüpiliselt	doc_59711134405_item	3525699	et	2	main
väiksematest	doc_59711134405_item	3525704	et	2	main
ametlik	doc_59711134407_item	3525940	et	3	main
arvamust	doc_59711134407_item	3525950	et	3	main
vahenõudlike	doc_59711134407_item	3525953	et	3	main
kohta	doc_59711134407_item	3525955	et	4	main
poolt	doc_59711134407_item	3525959	et	4	main
eelmistest	doc_59711134407_item	3525973	et	4	main
iseloomulikkud	doc_59711134407_item	3525983	et	4	main
väärtushinnangute	doc_59711134407_item	3525984	et	3	main
süsteemid	doc_59711134407_item	3525985	et	3	main
ja	doc_59711134407_item	3525986	et	3	main
arvates	doc_59711134405_item	3525609	et	4	main
tahab	doc_59711134405_item	3525619	et	3	main
palka	doc_59711134405_item	3525622	et	4	main
liisida	doc_59711134405_item	3525623	et	4	main
aga	doc_59711134405_item	3525628	et	3	main
õpi	doc_59711134405_item	3525638	et	4	main
ja	doc_59711134405_item	3525639	et	3	main
käed	doc_59711134405_item	3525640	et	3	main
see	doc_59711134405_item	3525644	et	3	main
pole	doc_59711134405_item	3525646	et	3	main
kes	doc_59711134405_item	3525650	et	4	main
ootab	doc_59711134405_item	3525652	et	3	main
tea	doc_59711134405_item	3525664	et	4	main
ja	doc_59711134405_item	3525673	et	3	main
ma	doc_59711134405_item	3525674	et	3	main
tean	doc_59711134405_item	3525675	et	3	main
neid	doc_59711134405_item	3525690	et	4	main
tulevad	doc_59711134405_item	3525700	et	4	main
kiri	doc_59711134407_item	3525941	et	3	main
tiina	doc_59711134407_item	3525943	et	4	main
tahaksin	doc_59711134407_item	3525948	et	3	main
artikli	doc_59711134407_item	3525952	et	3	main
pakkutud	doc_59711134407_item	3525960	et	4	main
paistab	doc_59711134407_item	3525962	et	3	main
ei	doc_59711134407_item	3525970	et	4	main
erine	doc_59711134407_item	3525971	et	4	main
eriti	doc_59711134407_item	3525972	et	3	main
oli	doc_59711134407_item	3525976	et	3	main
kahetsemisega	doc_59711134407_item	3525993	et	4	main
et	doc_59711134407_item	3525995	et	3	main
kindlustama	doc_59711134407_item	3526034	et	3	main
rohkem	doc_59711134405_item	3525692	et	4	main
sellest	doc_59711134405_item	3525701	et	4	main
teemast	doc_59711134405_item	3525702	et	4	main
kõnelejad	doc_59711134405_item	3525703	et	4	main
kohtadest	doc_59711134405_item	3525705	et	3	main
tahan	doc_59711134405_item	3525707	et	3	main
kokkuvõtteks	doc_59711134405_item	3525706	et	3	main
ütelda	doc_59711134405_item	3525708	et	4	main
et	doc_59711134405_item	3525709	et	3	main
mulle	doc_59711134405_item	3525710	et	4	main
väga	doc_59711134405_item	3525711	et	3	main
meeldis	doc_59711134405_item	3525712	et	3	main
teie	doc_59711134405_item	3525713	et	4	main
juhtkiri	doc_59711134405_item	3525714	et	3	main
ma	doc_59711134405_item	3525715	et	3	main
ootan	doc_59711134405_item	3525716	et	3	main
jätkumise	doc_59711134405_item	3525717	et	2	main
austusega	doc_59711134405_item	3525718	et	4	main
eesnimi	doc_59711134405_item	3525719	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_59711134405_item	3525720	et	4	main
oma	doc_59711134407_item	3525949	et	4	main
teie	doc_59711134407_item	3525951	et	4	main
sest	doc_59711134407_item	3525957	et	4	main
teema	doc_59711134407_item	3525961	et	4	main
huvitavana	doc_59711134407_item	3525964	et	4	main
et	doc_59711134407_item	3525967	et	3	main
põlvkond	doc_59711134407_item	3525969	et	3	main
oma	doc_59711134407_item	3525982	et	4	main
oma	doc_59711134407_item	3525991	et	4	main
artiklis	doc_59711134407_item	3525992	et	3	main
tänapäevastel	doc_59711134407_item	3525996	et	4	main
noortel	doc_59711134407_item	3525997	et	3	main
ei	doc_59711134407_item	3525998	et	4	main
järgi	doc_59711134407_item	3526058	et	4	main
see	doc_59711134407_item	3526059	et	3	main
põhjustab	doc_59711134407_item	3526060	et	3	main
ja	doc_59711134407_item	3526107	et	3	main
on	doc_59711134407_item	3526114	et	4	main
need	doc_59711134407_item	3526115	et	3	main
elu	doc_59711134407_item	3526123	et	4	main
ei	doc_59711134407_item	3526131	et	4	main
järgmist	doc_59711134407_item	3526143	et	3	main
veendunud	doc_59711134407_item	3526146	et	4	main
igavene	doc_59711134407_item	3526153	et	4	main
ametlik	doc_59711134408_item	3526161	et	3	main
ma	doc_59711134408_item	3526168	et	3	main
artiiklit	doc_59711134408_item	3526171	et	4	main
ajalehest	doc_59711134408_item	3526172	et	4	main
ja	doc_59711134408_item	3526173	et	3	main
otsustasin	doc_59711134408_item	3526174	et	3	main
kirjutada	doc_59711134408_item	3526175	et	3	main
oma	doc_59711134408_item	3526176	et	4	main
arvamust	doc_59711134408_item	3526177	et	3	main
nõus	doc_59711134408_item	3526184	et	4	main
alguselt	doc_59711134408_item	3526196	et	4	main
tea	doc_59711134408_item	3526199	et	4	main
kuhu	doc_59711134408_item	3526201	et	3	main
lähevad	doc_59711134408_item	3526202	et	3	main
sest	doc_59711134408_item	3526205	et	4	main
eksamid	doc_59711134408_item	3526206	et	3	main
palju	doc_59711134408_item	3526213	et	4	main
eksamipunkte	doc_59711134408_item	3526214	et	3	main
pärast	doc_59711134408_item	3526217	et	4	main
jõudu	doc_59711134408_item	3526228	et	4	main
lugupeetud	doc_59711134407_item	3525942	et	4	main
kaalep	doc_59711134407_item	3525944	et	4	main
ülikooli	doc_59711134407_item	3525945	et	4	main
õpilasena	doc_59711134407_item	3525946	et	3	main
teie	doc_59711134407_item	3525958	et	4	main
meie	doc_59711134407_item	3525968	et	4	main
alati	doc_59711134407_item	3525975	et	4	main
inimeste	doc_59711134407_item	3525977	et	3	main
rühmadeks	doc_59711134407_item	3525979	et	3	main
millistel	doc_59711134407_item	3525980	et	3	main
on	doc_59711134407_item	3525981	et	4	main
lihtsalt	doc_59711134407_item	3526038	et	4	main
on	doc_59711134407_item	3526041	et	4	main
kui	doc_59711134407_item	3526043	et	3	main
noored	doc_59711134407_item	3526045	et	3	main
teie	doc_59711134407_item	3526049	et	4	main
ütelnud	doc_59711134407_item	3526051	et	4	main
võib	doc_59711134407_item	3526098	et	3	main
jagama	doc_59711134407_item	3526099	et	3	main
rühmadeks	doc_59711134407_item	3526100	et	3	main
need	doc_59711134407_item	3526101	et	3	main
elukutse	doc_59711134407_item	3526105	et	4	main
kujutavad	doc_59711134407_item	3526108	et	4	main
teised	doc_59711134407_item	3526113	et	4	main
tehtud	doc_59711134407_item	3526129	et	4	main
kokkuvõtteks	doc_59711134407_item	3526135	et	3	main
tahaksin	doc_59711134407_item	3526136	et	3	main
ütelda	doc_59711134407_item	3526137	et	4	main
et	doc_59711134407_item	3526138	et	3	main
iga	doc_59711134407_item	3526139	et	4	main
täpselt	doc_59711134407_item	3526109	et	4	main
oma	doc_59711134407_item	3526110	et	4	main
tuleviku	doc_59711134407_item	3526111	et	4	main
ja	doc_59711134407_item	3526112	et	3	main
olles	doc_59711134407_item	3525947	et	3	main
põlvkond	doc_59711134407_item	3525954	et	3	main
väljendama	doc_59711134407_item	3525956	et	3	main
mulle	doc_59711134407_item	3525963	et	4	main
julgen	doc_59711134407_item	3525965	et	3	main
vältida	doc_59711134407_item	3525966	et	3	main
põlvkondadest	doc_59711134407_item	3525974	et	3	main
jagamine	doc_59711134407_item	3525978	et	4	main
ole	doc_59711134407_item	3525999	et	4	main
mingisugusi	doc_59711134407_item	3526000	et	4	main
suurjoonelisi	doc_59711134407_item	3526001	et	4	main
plaani	doc_59711134407_item	3526002	et	4	main
tulevikule	doc_59711134407_item	3526003	et	4	main
kuid	doc_59711134407_item	3526004	et	4	main
nad	doc_59711134407_item	3526005	et	3	main
peavad	doc_59711134407_item	3526006	et	4	main
kodust	doc_59711134407_item	3526007	et	4	main
idülli	doc_59711134407_item	3526008	et	4	main
ihaldusväärseks	doc_59711134407_item	3526009	et	4	main
minu	doc_59711134407_item	3526010	et	3	main
meelest	doc_59711134407_item	3526011	et	4	main
see	doc_59711134407_item	3526012	et	3	main
on	doc_59711134407_item	3526013	et	4	main
seotud	doc_59711134407_item	3526014	et	4	main
sellega	doc_59711134407_item	3526015	et	3	main
et	doc_59711134407_item	3526016	et	3	main
me	doc_59711134407_item	3526017	et	4	main
elame	doc_59711134407_item	3526018	et	3	main
ikkagi	doc_59711134407_item	3526019	et	4	main
ebastabiilses	doc_59711134407_item	3526020	et	3	main
ühiskonnas	doc_59711134407_item	3526021	et	4	main
kus	doc_59711134407_item	3526022	et	3	main
ei	doc_59711134407_item	3526023	et	4	main
või	doc_59711134407_item	3526024	et	4	main
olla	doc_59711134407_item	3526025	et	3	main
kindel	doc_59711134407_item	3526026	et	3	main
oma	doc_59711134407_item	3526027	et	4	main
tulevikus	doc_59711134407_item	3526028	et	4	main
ja	doc_59711134407_item	3526029	et	3	main
paljud	doc_59711134407_item	3526030	et	3	main
noored	doc_59711134407_item	3526031	et	3	main
püüavad	doc_59711134407_item	3526032	et	3	main
eelkõige	doc_59711134407_item	3526033	et	3	main
käitumise	doc_59711134407_item	3525987	et	4	main
tüüpid	doc_59711134407_item	3525988	et	4	main
teie	doc_59711134407_item	3525989	et	4	main
olete	doc_59711134407_item	3525990	et	3	main
ütelnud	doc_59711134407_item	3525994	et	4	main
endale	doc_59711134407_item	3526035	et	4	main
väärilist	doc_59711134407_item	3526036	et	4	main
elu	doc_59711134407_item	3526037	et	4	main
tõemeelseks	doc_59711134407_item	3526042	et	3	main
tahavad	doc_59711134407_item	3526046	et	3	main
nagu	doc_59711134407_item	3526052	et	3	main
nende	doc_59711134407_item	3526053	et	4	main
vanemad	doc_59711134407_item	3526054	et	4	main
ja	doc_59711134407_item	3526055	et	3	main
minu	doc_59711134407_item	3526056	et	3	main
arvamuse	doc_59711134407_item	3526057	et	3	main
kes	doc_59711134407_item	3526102	et	4	main
kes	doc_59711134407_item	3526116	et	4	main
seotada	doc_59711134407_item	3526124	et	4	main
loodan	doc_59711134407_item	3526125	et	3	main
et	doc_59711134407_item	3526126	et	3	main
minu	doc_59711134407_item	3526127	et	3	main
pane	doc_59711134407_item	3526132	et	4	main
eelnev	doc_59711134407_item	3526140	et	4	main
kritiseerib	doc_59711134407_item	3526142	et	3	main
põlvkonda	doc_59711134407_item	3526144	et	4	main
mõttetu	doc_59711134407_item	3526150	et	4	main
see	doc_59711134407_item	3526151	et	3	main
lugupeetud	doc_59711134408_item	3526164	et	4	main
küljest	doc_59711134408_item	3526181	et	4	main
ma	doc_59711134408_item	3526182	et	3	main
et	doc_59711134408_item	3526186	et	3	main
tahavad	doc_59711134408_item	3526188	et	3	main
ülikoolis	doc_59711134408_item	3526190	et	4	main
tahavad	doc_59711134408_item	3526192	et	3	main
teenida	doc_59711134408_item	3526194	et	3	main
ei	doc_59711134408_item	3526198	et	4	main
ei	doc_59711134408_item	3526211	et	4	main
ainult	doc_59711134408_item	3526216	et	4	main
on	doc_59711134408_item	3526221	et	4	main
otsustavad	doc_59711134408_item	3526224	et	4	main
ja	doc_59711134408_item	3526225	et	3	main
proovivad	doc_59711134408_item	3526226	et	4	main
arvan	doc_59711134408_item	3526244	et	3	main
mida	doc_59711134408_item	3526251	et	4	main
näiteks	doc_59711134408_item	3526261	et	4	main
kolm	doc_59711134408_item	3526273	et	3	main
liikusin	doc_59711134408_item	3526276	et	3	main
sihele	doc_59711134408_item	3526278	et	3	main
tänapäevane	doc_59711134407_item	3526039	et	4	main
põlvkond	doc_59711134407_item	3526040	et	3	main
eelmised	doc_59711134407_item	3526044	et	3	main
elada	doc_59711134407_item	3526047	et	3	main
olete	doc_59711134407_item	3526050	et	3	main
on	doc_59711134407_item	3526103	et	4	main
valinud	doc_59711134407_item	3526106	et	4	main
tea	doc_59711134407_item	3526118	et	4	main
millega	doc_59711134407_item	3526119	et	3	main
nad	doc_59711134407_item	3526120	et	3	main
tahavad	doc_59711134407_item	3526121	et	3	main
oma	doc_59711134407_item	3526122	et	4	main
valimine	doc_59711134407_item	3526130	et	4	main
see	doc_59711134407_item	3526148	et	3	main
kiri	doc_59711134408_item	3526162	et	3	main
tiina	doc_59711134408_item	3526165	et	4	main
kaalep	doc_59711134408_item	3526166	et	4	main
hiljuti	doc_59711134408_item	3526167	et	4	main
ühest	doc_59711134408_item	3526180	et	4	main
ja	doc_59711134408_item	3526191	et	3	main
tulevikus	doc_59711134408_item	3526193	et	4	main
õppima	doc_59711134408_item	3526204	et	3	main
on	doc_59711134408_item	3526207	et	4	main
saad	doc_59711134408_item	3526215	et	4	main
õpilased	doc_59711134408_item	3526223	et	3	main
see	doc_59711134408_item	3526231	et	3	main
tulevikus	doc_59711134408_item	3526240	et	4	main
ei	doc_59711134408_item	3526249	et	4	main
tea	doc_59711134408_item	3526250	et	4	main
üksendast	doc_59711134408_item	3526264	et	4	main
et	doc_59711134408_item	3526267	et	3	main
tahan	doc_59711134408_item	3526269	et	3	main
nagu	doc_59711134407_item	3526048	et	3	main
eelesitatud	doc_59711134407_item	3526061	et	3	main
olukord	doc_59711134407_item	3526062	et	3	main
mis	doc_59711134407_item	3526063	et	4	main
minusse	doc_59711134407_item	3526064	et	3	main
puutub	doc_59711134407_item	3526065	et	3	main
mina	doc_59711134407_item	3526066	et	4	main
ka	doc_59711134407_item	3526067	et	3	main
tahaksin	doc_59711134407_item	3526068	et	3	main
elada	doc_59711134407_item	3526069	et	3	main
oma	doc_59711134407_item	3526070	et	4	main
kodus	doc_59711134407_item	3526071	et	4	main
sõida	doc_59711134407_item	3526072	et	4	main
oma	doc_59711134407_item	3526073	et	4	main
autoga	doc_59711134407_item	3526074	et	3	main
ühesõnaga	doc_59711134407_item	3526075	et	3	main
omada	doc_59711134407_item	3526076	et	3	main
asju	doc_59711134407_item	3526077	et	3	main
mis	doc_59711134407_item	3526078	et	4	main
teevad	doc_59711134407_item	3526079	et	3	main
elu	doc_59711134407_item	3526080	et	4	main
mugavamaks	doc_59711134407_item	3526081	et	4	main
ja	doc_59711134407_item	3526082	et	3	main
meeldivamaks	doc_59711134407_item	3526083	et	4	main
ma	doc_59711134407_item	3526084	et	3	main
arvan	doc_59711134407_item	3526085	et	3	main
et	doc_59711134407_item	3526086	et	3	main
see	doc_59711134407_item	3526087	et	3	main
on	doc_59711134407_item	3526088	et	4	main
täitsa	doc_59711134407_item	3526089	et	3	main
normaalselt	doc_59711134407_item	3526090	et	4	main
olen	doc_59711134407_item	3526091	et	3	main
nõus	doc_59711134407_item	3526092	et	4	main
teiega	doc_59711134407_item	3526093	et	3	main
selles	doc_59711134407_item	3526094	et	4	main
et	doc_59711134407_item	3526095	et	3	main
noori	doc_59711134407_item	3526096	et	3	main
ikkagi	doc_59711134407_item	3526097	et	4	main
oma	doc_59711134407_item	3526104	et	4	main
ei	doc_59711134407_item	3526117	et	4	main
poolt	doc_59711134407_item	3526128	et	4	main
mind	doc_59711134407_item	3526133	et	4	main
kahetsema	doc_59711134407_item	3526134	et	3	main
olen	doc_59711134407_item	3526145	et	3	main
et	doc_59711134407_item	3526147	et	3	main
on	doc_59711134407_item	3526152	et	4	main
tere	doc_59711134408_item	3526163	et	3	main
lugesin	doc_59711134408_item	3526169	et	3	main
probleemi	doc_59711134408_item	3526178	et	4	main
olen	doc_59711134408_item	3526183	et	3	main
teiega	doc_59711134408_item	3526185	et	3	main
abituriendid	doc_59711134408_item	3526187	et	3	main
õppida	doc_59711134408_item	3526189	et	3	main
nad	doc_59711134408_item	3526197	et	3	main
täpselt	doc_59711134408_item	3526200	et	4	main
edasi	doc_59711134408_item	3526203	et	3	main
tea	doc_59711134408_item	3526212	et	4	main
kui	doc_59711134408_item	3526219	et	3	main
oma	doc_59711134408_item	3526227	et	4	main
teisest	doc_59711134408_item	3526241	et	4	main
nad	doc_59711134408_item	3526252	et	3	main
klassist	doc_59711134408_item	3526265	et	3	main
õppida	doc_59711134408_item	3526270	et	3	main
põlvkond	doc_59711134407_item	3526141	et	3	main
on	doc_59711134407_item	3526149	et	4	main
problem	doc_59711134407_item	3526154	et	4	main
parimate	doc_59711134407_item	3526155	et	4	main
soovitega	doc_59711134407_item	3526156	et	4	main
eesnimi	doc_59711134407_item	3526157	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_59711134407_item	3526158	et	4	main
teie	doc_59711134408_item	3526170	et	4	main
kohta	doc_59711134408_item	3526179	et	4	main
raha	doc_59711134408_item	3526195	et	4	main
loterii	doc_59711134408_item	3526208	et	4	main
ja	doc_59711134408_item	3526209	et	3	main
kunagi	doc_59711134408_item	3526210	et	3	main
seda	doc_59711134408_item	3526218	et	3	main
tulemused	doc_59711134408_item	3526220	et	3	main
käes	doc_59711134408_item	3526222	et	4	main
erinevates	doc_59711134408_item	3526229	et	4	main
ülikoolides	doc_59711134408_item	3526230	et	3	main
on	doc_59711134408_item	3526232	et	4	main
väga	doc_59711134408_item	3526233	et	3	main
tähtis	doc_59711134408_item	3526234	et	4	main
otsus	doc_59711134408_item	3526235	et	3	main
mis	doc_59711134408_item	3526236	et	4	main
määrab	doc_59711134408_item	3526237	et	3	main
nende	doc_59711134408_item	3526238	et	4	main
elu	doc_59711134408_item	3526239	et	4	main
küljest	doc_59711134408_item	3526242	et	4	main
ma	doc_59711134408_item	3526243	et	3	main
teistsmoodi	doc_59711134408_item	3526245	et	4	main
mitte	doc_59711134408_item	3526246	et	3	main
kõik	doc_59711134408_item	3526247	et	4	main
inimesed	doc_59711134408_item	3526248	et	3	main
tahavad	doc_59711134408_item	3526253	et	3	main
on	doc_59711134408_item	3526254	et	4	main
selliseid	doc_59711134408_item	3526255	et	4	main
kellel	doc_59711134408_item	3526256	et	4	main
on	doc_59711134408_item	3526257	et	4	main
kindel	doc_59711134408_item	3526258	et	3	main
elu	doc_59711134408_item	3526259	et	4	main
eesmärk	doc_59711134408_item	3526260	et	3	main
mina	doc_59711134408_item	3526262	et	4	main
ma	doc_59711134408_item	3526268	et	3	main
majandust	doc_59711134408_item	3526271	et	4	main
aastat	doc_59711134408_item	3526274	et	3	main
minu	doc_59711134408_item	3526279	et	3	main
juba	doc_59711134408_item	3526263	et	3	main
otsustasin	doc_59711134408_item	3526266	et	3	main
ja	doc_59711134408_item	3526272	et	3	main
ma	doc_59711134408_item	3526275	et	3	main
oma	doc_59711134408_item	3526277	et	4	main
arvates	doc_59711134408_item	3526280	et	4	main
kõik	doc_59711134408_item	3526281	et	4	main
sõltub	doc_59711134408_item	3526282	et	3	main
abiturientidest	doc_59711134408_item	3526283	et	3	main
iga	doc_59711134408_item	3526284	et	4	main
inimene	doc_59711134408_item	3526285	et	3	main
on	doc_59711134408_item	3526286	et	4	main
oma	doc_59711134408_item	3526287	et	4	main
õnne	doc_59711134408_item	3526288	et	4	main
looja	doc_59711134408_item	3526289	et	4	main
olen	doc_59711134408_item	3526290	et	3	main
veendunud	doc_59711134408_item	3526291	et	4	main
et	doc_59711134408_item	3526292	et	3	main
kui	doc_59711134408_item	3526293	et	3	main
midagi	doc_59711134408_item	3526294	et	4	main
väga	doc_59711134408_item	3526295	et	3	main
tahad	doc_59711134408_item	3526296	et	3	main
siis	doc_59711134408_item	3526297	et	3	main
pead	doc_59711134408_item	3526298	et	4	main
ise	doc_59711134408_item	3526299	et	4	main
kõvasti	doc_59711134408_item	3526300	et	3	main
tööd	doc_59711134408_item	3526301	et	4	main
tegema	doc_59711134408_item	3526302	et	3	main
sest	doc_59711134408_item	3526303	et	4	main
mitte	doc_59711134408_item	3526304	et	3	main
keegi	doc_59711134408_item	3526305	et	4	main
sinu	doc_59711134408_item	3526306	et	3	main
eest	doc_59711134408_item	3526307	et	4	main
seda	doc_59711134408_item	3526308	et	3	main
ei	doc_59711134408_item	3526309	et	4	main
tee	doc_59711134408_item	3526310	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_59711134408_item	3526311	et	4	main
mina	doc_59711134413_item	3526897	et	4	main
eesti	doc_59711134413_item	3526901	et	4	main
keele	doc_59711134413_item	3526902	et	4	main
tekivad	doc_59711134413_item	3526907	et	3	main
erinevaid	doc_59711134413_item	3526916	et	4	main
edusid	doc_59711134413_item	3526917	et	3	main
alati	doc_59711134413_item	3526920	et	4	main
puutub	doc_59711134413_item	3526926	et	3	main
ei	doc_59711134413_item	3526929	et	4	main
pidevalt	doc_59711134413_item	3526931	et	4	main
oma	doc_59711134413_item	3526932	et	4	main
endale	doc_59711134413_item	3526972	et	4	main
olin	doc_59711134413_item	3526974	et	3	main
eesti	doc_59711134413_item	3526976	et	4	main
keele	doc_59711134413_item	3526977	et	4	main
meist	doc_59711134413_item	3526905	et	3	main
segavad	doc_59711134413_item	3526910	et	4	main
minusse	doc_59711134413_item	3526925	et	3	main
õigustuse	doc_59711134413_item	3526971	et	4	main
mitu	doc_59711134413_item	3526975	et	4	main
me	doc_59711134414_item	3527003	et	4	main
elame	doc_59711134414_item	3527005	et	3	main
riigis	doc_59711134414_item	3527006	et	3	main
kus	doc_59711134414_item	3527007	et	3	main
seda	doc_59711134414_item	3527013	et	3	main
teadma	doc_59711134414_item	3527014	et	3	main
kui	doc_59711134414_item	3527020	et	3	main
kallimatest	doc_59711134414_item	3527058	et	4	main
teaduskondadest	doc_59711134414_item	3527059	et	3	main
ja	doc_59711134414_item	3527068	et	3	main
ei	doc_59711134414_item	3527071	et	4	main
käinud	doc_59711134414_item	3527072	et	4	main
mul	doc_59711134414_item	3527079	et	3	main
olema	doc_59711134414_item	3527134	et	4	main
ja	doc_59711134414_item	3527135	et	3	main
vanematest	doc_59711134414_item	3527140	et	4	main
kiri	doc_59711134413_item	3526895	et	3	main
kui	doc_59711134413_item	3526899	et	3	main
puudusin	doc_59711134413_item	3526900	et	3	main
aeg-ajalt	doc_59711134413_item	3526906	et	4	main
saavutada	doc_59711134413_item	3526918	et	3	main
mis	doc_59711134413_item	3526924	et	4	main
plaani	doc_59711134413_item	3526933	et	4	main
et	doc_59711134413_item	3526973	et	3	main
kiri	doc_59711134414_item	3527001	et	3	main
kõik	doc_59711134414_item	3527004	et	4	main
eesti	doc_59711134414_item	3527008	et	4	main
riigikeel	doc_59711134414_item	3527011	et	4	main
peame	doc_59711134414_item	3527012	et	4	main
on	doc_59711134414_item	3527015	et	4	main
peaaegu	doc_59711134414_item	3527016	et	3	main
ei	doc_59711134414_item	3527021	et	4	main
muidugi	doc_59711134414_item	3527025	et	4	main
kõige	doc_59711134414_item	3527057	et	4	main
pean	doc_59711134414_item	3527062	et	4	main
töötama	doc_59711134414_item	3527063	et	3	main
keele	doc_59711134414_item	3527074	et	4	main
ja	doc_59711134414_item	3527075	et	3	main
teistes	doc_59711134414_item	3527077	et	4	main
pole	doc_59711134414_item	3527080	et	3	main
oma	doc_59711134414_item	3527082	et	4	main
vastu	doc_59711134414_item	3527084	et	3	main
võtab	doc_59711134414_item	3527087	et	3	main
tööt	doc_59711134414_item	3527098	et	4	main
kõvasti	doc_59711134414_item	3527137	et	3	main
oma	doc_59711134414_item	3527139	et	4	main
oli	doc_59711134416_item	3527339	et	3	main
mina	doc_59711134416_item	3527345	et	4	main
on	doc_59711134416_item	3527351	et	4	main
video	doc_59711134416_item	3527353	et	4	main
filmidega	doc_59711134416_item	3527354	et	3	main
samal	doc_59711134416_item	3527362	et	3	main
mida	doc_59711134413_item	3526896	et	4	main
tegin	doc_59711134413_item	3526898	et	3	main
probleemid	doc_59711134413_item	3526908	et	3	main
mis	doc_59711134413_item	3526909	et	4	main
meid	doc_59711134413_item	3526911	et	4	main
normaalselt	doc_59711134413_item	3526912	et	4	main
töötada	doc_59711134413_item	3526913	et	3	main
õppida	doc_59711134413_item	3526914	et	3	main
ja	doc_59711134413_item	3526915	et	3	main
minul	doc_59711134413_item	3526927	et	3	main
ka	doc_59711134413_item	3526928	et	3	main
viia	doc_59711134413_item	3526935	et	3	main
loengutest	doc_59711134413_item	3526978	et	4	main
on	doc_59711134414_item	3527010	et	4	main
tea	doc_59711134414_item	3527022	et	4	main
keelt	doc_59711134414_item	3527024	et	4	main
on	doc_59711134414_item	3527026	et	4	main
vaja	doc_59711134414_item	3527027	et	4	main
teada	doc_59711134414_item	3527028	et	3	main
ka	doc_59711134414_item	3527029	et	3	main
keel	doc_59711134414_item	3527034	et	4	main
ja	doc_59711134414_item	3527035	et	3	main
majandusteaduskond	doc_59711134414_item	3527053	et	3	main
ma	doc_59711134414_item	3527061	et	3	main
praegu	doc_59711134414_item	3527065	et	3	main
päev	doc_59711134414_item	3527067	et	3	main
sellepärast	doc_59711134414_item	3527070	et	3	main
midagi	doc_59711134414_item	3527081	et	4	main
töö	doc_59711134414_item	3527083	et	4	main
see	doc_59711134414_item	3527086	et	3	main
mõnda	doc_59711134414_item	3527096	et	4	main
teist	doc_59711134414_item	3527097	et	4	main
ei	doc_59711134414_item	3527100	et	4	main
ei	doc_59711134414_item	3527131	et	4	main
sõltuma	doc_59711134414_item	3527138	et	3	main
sest	doc_59711134413_item	3526980	et	4	main
olen	doc_59711134413_item	3526981	et	3	main
veendunud	doc_59711134413_item	3526982	et	4	main
et	doc_59711134413_item	3526983	et	3	main
puudunud	doc_59711134413_item	3526979	et	4	main
iga	doc_59711134413_item	3526984	et	4	main
peab	doc_59711134413_item	3526985	et	4	main
ise	doc_59711134413_item	3526986	et	4	main
oma	doc_59711134413_item	3526987	et	4	main
vigade	doc_59711134413_item	3526988	et	3	main
eest	doc_59711134413_item	3526989	et	4	main
vastama	doc_59711134413_item	3526990	et	3	main
paluksin	doc_59711134413_item	3526991	et	3	main
mitte	doc_59711134413_item	3526992	et	3	main
arvada	doc_59711134413_item	3526993	et	4	main
selle	doc_59711134413_item	3526994	et	4	main
essee	doc_59711134413_item	3526995	et	4	main
õigustamise	doc_59711134413_item	3526996	et	4	main
katseks	doc_59711134413_item	3526997	et	4	main
lugupidamisega	doc_59711134413_item	3526998	et	3	main
eesnimi	doc_59711134413_item	3526999	et	3	main
loengutest	doc_59711134413_item	3526903	et	4	main
igal	doc_59711134413_item	3526904	et	3	main
mitte	doc_59711134413_item	3526919	et	3	main
voib	doc_59711134413_item	3526921	et	4	main
neid	doc_59711134413_item	3526922	et	4	main
ületada	doc_59711134413_item	3526923	et	3	main
klappi	doc_59711134413_item	3526930	et	4	main
elusse	doc_59711134413_item	3526934	et	3	main
kahjuks	doc_59711134413_item	3526936	et	4	main
ka	doc_59711134413_item	3526937	et	3	main
õppimisel	doc_59711134413_item	3526938	et	4	main
see	doc_59711134413_item	3526939	et	3	main
õppesta	doc_59711134413_item	3526940	et	4	main
on	doc_59711134413_item	3526941	et	4	main
alanud	doc_59711134413_item	3526942	et	4	main
minu	doc_59711134413_item	3526943	et	3	main
jaoks	doc_59711134413_item	3526944	et	4	main
pisavalt	doc_59711134413_item	3526945	et	4	main
raskelt	doc_59711134413_item	3526946	et	4	main
suur	doc_59711134413_item	3526947	et	3	main
materjalimaht	doc_59711134413_item	3526948	et	3	main
järsult	doc_59711134413_item	3526949	et	4	main
ilmunud	doc_59711134413_item	3526950	et	4	main
koormus	doc_59711134413_item	3526951	et	4	main
mis	doc_59711134413_item	3526952	et	4	main
oli	doc_59711134413_item	3526953	et	3	main
väga	doc_59711134413_item	3526954	et	3	main
raske	doc_59711134413_item	3526955	et	4	main
omandatud	doc_59711134413_item	3526956	et	4	main
kahe	doc_59711134413_item	3526957	et	3	main
peaaegu	doc_59711134413_item	3526958	et	3	main
oppimiseta	doc_59711134413_item	3526959	et	4	main
aastate	doc_59711134413_item	3526960	et	3	main
pärast	doc_59711134413_item	3526961	et	4	main
väike	doc_59711134413_item	3526962	et	4	main
vastupidavus	doc_59711134413_item	3526963	et	4	main
mis	doc_59711134413_item	3526964	et	4	main
tekis	doc_59711134413_item	3526965	et	3	main
haiguse	doc_59711134413_item	3526966	et	4	main
tõttu	doc_59711134413_item	3526967	et	4	main
ma	doc_59711134413_item	3526968	et	3	main
ei	doc_59711134413_item	3526969	et	4	main
leia	doc_59711134413_item	3526970	et	4	main
keel	doc_59711134414_item	3527009	et	4	main
võimatu	doc_59711134414_item	3527017	et	4	main
leida	doc_59711134414_item	3527018	et	3	main
eesti	doc_59711134414_item	3527023	et	4	main
keele	doc_59711134414_item	3527031	et	4	main
näiteks	doc_59711134414_item	3527032	et	4	main
inglise	doc_59711134414_item	3527033	et	4	main
seepärast	doc_59711134414_item	3527060	et	3	main
töötan	doc_59711134414_item	3527064	et	3	main
iga	doc_59711134414_item	3527066	et	4	main
just	doc_59711134414_item	3527069	et	3	main
mõnedes	doc_59711134414_item	3527076	et	3	main
tundides	doc_59711134414_item	3527078	et	3	main
aega	doc_59711134414_item	3527090	et	4	main
ja	doc_59711134414_item	3527091	et	3	main
ma	doc_59711134414_item	3527092	et	3	main
tahaks	doc_59711134414_item	3527093	et	3	main
leida	doc_59711134414_item	3527094	et	3	main
endale	doc_59711134414_item	3527095	et	4	main
mis	doc_59711134414_item	3527099	et	4	main
võta	doc_59711134414_item	3527101	et	4	main
nii	doc_59711134414_item	3527102	et	3	main
palju	doc_59711134414_item	3527103	et	4	main
aega	doc_59711134414_item	3527104	et	4	main
peaaegu	doc_59711134414_item	3527105	et	3	main
kõik	doc_59711134414_item	3527106	et	4	main
tudengid	doc_59711134414_item	3527107	et	3	main
keda	doc_59711134414_item	3527108	et	4	main
soovi	doc_59711134414_item	3527132	et	4	main
nii	doc_59711134414_item	3527136	et	3	main
kiri	doc_59711134416_item	3527327	et	3	main
loengul	doc_59711134416_item	3527333	et	3	main
pidin	doc_59711134416_item	3527347	et	3	main
minu	doc_59711134416_item	3527349	et	3	main
mulle	doc_59711134416_item	3527368	et	4	main
meeldib	doc_59711134416_item	3527369	et	3	main
tegevuses	doc_59711134416_item	3527375	et	4	main
pärast	doc_59711134416_item	3527395	et	4	main
seda	doc_59711134416_item	3527396	et	3	main
töötan	doc_59711134416_item	3527397	et	3	main
sellega	doc_59711134416_item	3527398	et	3	main
dvd	doc_59711134416_item	3527401	et	4	main
just	doc_59711134416_item	3527402	et	3	main
ei	doc_59711134416_item	3527440	et	4	main
ma	doc_59711134414_item	3527109	et	3	main
tean	doc_59711134414_item	3527110	et	3	main
katsuvad	doc_59711134414_item	3527111	et	4	main
ühendada	doc_59711134414_item	3527112	et	3	main
oma	doc_59711134414_item	3527113	et	4	main
tööt	doc_59711134414_item	3527114	et	4	main
ja	doc_59711134414_item	3527115	et	3	main
õpimist	doc_59711134414_item	3527116	et	4	main
muidugi	doc_59711134414_item	3527117	et	4	main
see	doc_59711134414_item	3527118	et	3	main
on	doc_59711134414_item	3527119	et	4	main
päris	doc_59711134414_item	3527120	et	4	main
raske	doc_59711134414_item	3527121	et	4	main
aga	doc_59711134414_item	3527122	et	3	main
teiseti	doc_59711134414_item	3527123	et	4	main
kui	doc_59711134414_item	3527124	et	3	main
mitte	doc_59711134414_item	3527125	et	3	main
töötada	doc_59711134414_item	3527126	et	3	main
on	doc_59711134414_item	3527127	et	4	main
veelgi	doc_59711134414_item	3527128	et	4	main
raskem	doc_59711134414_item	3527129	et	4	main
keegi	doc_59711134414_item	3527130	et	4	main
kuna	doc_59711134414_item	3527002	et	3	main
tööd	doc_59711134414_item	3527019	et	4	main
teisi	doc_59711134414_item	3527030	et	4	main
vene	doc_59711134414_item	3527036	et	4	main
keel	doc_59711134414_item	3527037	et	4	main
kuid	doc_59711134414_item	3527038	et	4	main
ikkagi	doc_59711134414_item	3527039	et	4	main
eesti	doc_59711134414_item	3527040	et	4	main
keel	doc_59711134414_item	3527041	et	4	main
on	doc_59711134414_item	3527042	et	4	main
esimesel	doc_59711134414_item	3527043	et	3	main
kohal	doc_59711134414_item	3527044	et	4	main
ma	doc_59711134414_item	3527045	et	3	main
ise	doc_59711134414_item	3527046	et	4	main
õpin	doc_59711134414_item	3527047	et	3	main
tallinna	doc_59711134414_item	3527048	et	4	main
tehnika	doc_59711134414_item	3527049	et	4	main
ülikoolis	doc_59711134414_item	3527050	et	4	main
tasulisel	doc_59711134414_item	3527051	et	4	main
kohal	doc_59711134414_item	3527052	et	4	main
kahjuks	doc_59711134414_item	3527054	et	4	main
on	doc_59711134414_item	3527055	et	4	main
üks	doc_59711134414_item	3527056	et	3	main
eesti	doc_59711134414_item	3527073	et	4	main
aga	doc_59711134414_item	3527085	et	3	main
liiga	doc_59711134414_item	3527088	et	4	main
palju	doc_59711134414_item	3527089	et	4	main
ülalpeetav	doc_59711134414_item	3527133	et	3	main
ma	doc_59711134416_item	3527329	et	3	main
tegin	doc_59711134416_item	3527330	et	3	main
kui	doc_59711134416_item	3527331	et	3	main
puutusin	doc_59711134416_item	3527332	et	3	main
meil	doc_59711134416_item	3527338	et	4	main
iga	doc_59711134416_item	3527340	et	4	main
kolmapäev	doc_59711134416_item	3527341	et	3	main
ja	doc_59711134416_item	3527342	et	3	main
sel	doc_59711134416_item	3527343	et	3	main
päeval	doc_59711134416_item	3527344	et	3	main
seotud	doc_59711134416_item	3527352	et	4	main
montaziga	doc_59711134416_item	3527358	et	4	main
väga	doc_59711134416_item	3527359	et	3	main
huvitanud	doc_59711134416_item	3527373	et	4	main
annab	doc_59711134416_item	3527384	et	3	main
mul	doc_59711134416_item	3527463	et	3	main
kontsert	doc_59711134416_item	3527473	et	3	main
minu	doc_59711134416_item	3527475	et	3	main
õppealajuhataja	doc_59711134416_item	3527476	et	4	main
mind	doc_59711134416_item	3527478	et	4	main
mina	doc_59711134416_item	3527481	et	4	main
mängisin	doc_59711134416_item	3527482	et	3	main
sellest	doc_59711134416_item	3527505	et	4	main
mida	doc_59711134416_item	3527506	et	4	main
ma	doc_59711134416_item	3527507	et	3	main
te	doc_399014257175_item	3527526	et	4	main
elate	doc_399014257175_item	3527527	et	3	main
ma	doc_399014257175_item	3527528	et	3	main
loodan	doc_399014257175_item	3527529	et	3	main
et	doc_399014257175_item	3527530	et	3	main
kesklinna	doc_399014257175_item	3527541	et	4	main
ilusam	doc_399014257175_item	3527570	et	4	main
aga	doc_399014257175_item	3527573	et	3	main
pean	doc_399014257175_item	3527575	et	4	main
loodan	doc_399014257175_item	3527622	et	3	main
peatselt	doc_399014257175_item	3527624	et	4	main
kuulda	doc_399014257175_item	3527625	et	4	main
eesnimi	doc_399014257175_item	3527626	et	3	main
tudeng	doc_213943985012_item	3527637	et	3	main
tähtsam	doc_213943985012_item	3527639	et	4	main
ja	doc_213943985012_item	3527645	et	3	main
lugeda	doc_213943985012_item	3527650	et	3	main
kinno	doc_213943985012_item	3527652	et	3	main
õppinud	doc_213943985012_item	3527657	et	4	main
varem	doc_213943985012_item	3527661	et	4	main
olin	doc_213943985012_item	3527662	et	3	main
õppinud	doc_213943985012_item	3527663	et	4	main
et	doc_213943985012_item	3527676	et	3	main
teine	doc_213943985012_item	3527681	et	3	main
et	doc_213943985012_item	3527695	et	3	main
mida	doc_59711134416_item	3527328	et	4	main
esmakordselt	doc_59711134416_item	3527334	et	4	main
mina	doc_59711134416_item	3527335	et	4	main
töötasin	doc_59711134416_item	3527336	et	3	main
loeng	doc_59711134416_item	3527337	et	3	main
tihti	doc_59711134416_item	3527346	et	3	main
töö	doc_59711134416_item	3527350	et	4	main
huvitav	doc_59711134416_item	3527360	et	4	main
ajal	doc_59711134416_item	3527363	et	4	main
töö	doc_59711134416_item	3527365	et	4	main
se	doc_59711134416_item	3527367	et	4	main
alati	doc_59711134416_item	3527371	et	4	main
olin	doc_59711134416_item	3527372	et	3	main
video	doc_59711134416_item	3527380	et	4	main
operaator	doc_59711134416_item	3527381	et	3	main
video	doc_59711134416_item	3527391	et	4	main
minu	doc_59711134416_item	3527392	et	3	main
seda	doc_59711134416_item	3527403	et	3	main
kuj	doc_59711134416_item	3527406	et	4	main
meie	doc_59711134416_item	3527442	et	4	main
sugulasi-	doc_59711134416_item	3527443	et	2	main
vaadata	doc_59711134416_item	3527448	et	4	main
päev	doc_59711134416_item	3527453	et	3	main
pean	doc_59711134416_item	3527458	et	4	main
teine	doc_59711134416_item	3527461	et	3	main
endises	doc_59711134416_item	3527467	et	3	main
nn	doc_59711134416_item	3527471	et	4	main
tähte	doc_59711134416_item	3527472	et	4	main
ka	doc_59711134416_item	3527480	et	3	main
tihti	doc_59711134416_item	3527483	et	3	main
koolis	doc_59711134416_item	3527484	et	4	main
aastat	doc_59711134416_item	3527492	et	3	main
mul	doc_59711134416_item	3527493	et	3	main
on	doc_59711134416_item	3527494	et	4	main
ja	doc_59711134416_item	3527502	et	3	main
lõbus	doc_59711134416_item	3527503	et	4	main
puutusin	doc_59711134416_item	3527510	et	3	main
kiri	doc_399014257175_item	3527513	et	3	main
lähedane	doc_399014257175_item	3527542	et	3	main
aga	doc_399014257175_item	3527546	et	3	main
väga	doc_399014257175_item	3527549	et	3	main
ümbes	doc_399014257175_item	3527551	et	4	main
linna	doc_399014257175_item	3527562	et	4	main
hiljem	doc_399014257175_item	3527563	et	3	main
ma	doc_399014257175_item	3527565	et	3	main
riia	doc_399014257175_item	3527568	et	4	main
tallinn	doc_399014257175_item	3527572	et	4	main
nädalid	doc_399014257175_item	3527614	et	3	main
kiiresti	doc_399014257175_item	3527617	et	3	main
nimi	doc_213943985012_item	3527632	et	3	main
kõige	doc_213943985012_item	3527638	et	4	main
elus	doc_213943985012_item	3527641	et	4	main
armastan	doc_213943985012_item	3527648	et	3	main
magada	doc_213943985012_item	3527649	et	3	main
kogu	doc_213943985012_item	3527658	et	4	main
töötama	doc_59711134416_item	3527348	et	3	main
mina	doc_59711134416_item	3527355	et	4	main
tegelen	doc_59711134416_item	3527356	et	3	main
vidio	doc_59711134416_item	3527357	et	4	main
ja	doc_59711134416_item	3527361	et	3	main
raske	doc_59711134416_item	3527364	et	4	main
filmistab	doc_59711134416_item	3527382	et	4	main
ja	doc_59711134416_item	3527383	et	3	main
kasetti	doc_59711134416_item	3527386	et	4	main
arvutile	doc_59711134416_item	3527393	et	4	main
ja	doc_59711134416_item	3527394	et	3	main
ja	doc_59711134416_item	3527399	et	3	main
mina	doc_59711134416_item	3527404	et	4	main
tegin	doc_59711134416_item	3527405	et	3	main
puutusin	doc_59711134416_item	3527407	et	3	main
loengust	doc_59711134416_item	3527408	et	4	main
üks	doc_59711134416_item	3527409	et	3	main
kord	doc_59711134416_item	3527410	et	4	main
mina	doc_59711134416_item	3527411	et	4	main
lihtsalt	doc_59711134416_item	3527412	et	4	main
tegin	doc_59711134416_item	3527413	et	3	main
poppi	doc_59711134416_item	3527414	et	4	main
see	doc_59711134416_item	3527415	et	3	main
oli	doc_59711134416_item	3527416	et	3	main
septembris	doc_59711134416_item	3527417	et	3	main
ja	doc_59711134416_item	3527418	et	3	main
meil	doc_59711134416_item	3527419	et	4	main
sõpradega	doc_59711134416_item	3527420	et	3	main
sündis	doc_59711134416_item	3527421	et	3	main
geniaalne	doc_59711134416_item	3527422	et	3	main
plaan	doc_59711134416_item	3527423	et	3	main
kuidas	doc_59711134416_item	3527424	et	3	main
te	doc_59711134416_item	3527425	et	4	main
arvate	doc_59711134416_item	3527426	et	3	main
otsustaime	doc_59711134416_item	3527446	et	4	main
lõbus	doc_59711134416_item	3527450	et	4	main
põnev	doc_59711134416_item	3527452	et	3	main
pragu	doc_59711134416_item	3527455	et	4	main
seepärast	doc_59711134416_item	3527456	et	3	main
kontsert	doc_59711134416_item	3527465	et	3	main
minu	doc_59711134416_item	3527466	et	3	main
koolis	doc_59711134416_item	3527468	et	4	main
oli	doc_59711134416_item	3527470	et	3	main
küsis	doc_59711134416_item	3527477	et	3	main
mängida	doc_59711134416_item	3527479	et	3	main
seal	doc_59711134416_item	3527487	et	4	main
mängin	doc_59711134416_item	3527488	et	3	main
gitari	doc_59711134416_item	3527489	et	4	main
juba	doc_59711134416_item	3527490	et	3	main
kaheksa	doc_59711134416_item	3527491	et	4	main
eesti	doc_399014257175_item	3527514	et	4	main
kõik	doc_399014257175_item	3527531	et	4	main
on	doc_399014257175_item	3527532	et	4	main
hästi	doc_399014257175_item	3527533	et	3	main
praegu	doc_399014257175_item	3527534	et	3	main
ma	doc_399014257175_item	3527535	et	3	main
olen	doc_399014257175_item	3527536	et	3	main
riias	doc_399014257175_item	3527537	et	4	main
jõudis	doc_399014257175_item	3527544	et	3	main
väsinud	doc_399014257175_item	3527557	et	4	main
täna	doc_399014257175_item	3527558	et	4	main
ma	doc_399014257175_item	3527559	et	3	main
kahtlustan	doc_399014257175_item	3527566	et	3	main
kirjuta	doc_399014257175_item	3527615	et	4	main
aga	doc_59711134416_item	3527366	et	3	main
mina	doc_59711134416_item	3527370	et	4	main
filmide	doc_59711134416_item	3527374	et	3	main
millest	doc_59711134416_item	3527376	et	3	main
koosneb	doc_59711134416_item	3527377	et	3	main
minu	doc_59711134416_item	3527378	et	3	main
töö	doc_59711134416_item	3527379	et	4	main
mulle	doc_59711134416_item	3527385	et	4	main
pärast	doc_59711134416_item	3527387	et	4	main
seda	doc_59711134416_item	3527388	et	3	main
mina	doc_59711134416_item	3527389	et	4	main
tõmban	doc_59711134416_item	3527390	et	3	main
teen	doc_59711134416_item	3527400	et	3	main
kuhu	doc_59711134416_item	3527427	et	3	main
võivad	doc_59711134416_item	3527428	et	4	main
tulla	doc_59711134416_item	3527429	et	3	main
kahekümneaastased	doc_59711134416_item	3527430	et	4	main
üliõppilased	doc_59711134416_item	3527431	et	4	main
muidugi	doc_59711134416_item	3527432	et	4	main
loomaaja	doc_59711134416_item	3527433	et	4	main
me	doc_59711134416_item	3527434	et	4	main
saime	doc_59711134416_item	3527435	et	3	main
aru	doc_59711134416_item	3527436	et	4	main
et	doc_59711134416_item	3527437	et	3	main
juba	doc_59711134416_item	3527438	et	3	main
ammu	doc_59711134416_item	3527439	et	4	main
näinud	doc_59711134416_item	3527441	et	4	main
neid	doc_59711134416_item	3527447	et	4	main
aga	doc_59711134416_item	3527454	et	3	main
kirjutama	doc_59711134416_item	3527459	et	3	main
esse	doc_59711134416_item	3527460	et	3	main
ja	doc_59711134416_item	3527474	et	3	main
noorem	doc_59711134416_item	3527495	et	4	main
jutustus	doc_59711134416_item	3527504	et	4	main
loengutest	doc_59711134416_item	3527511	et	4	main
perekonnanimi	doc_399014257175_item	3527517	et	3	main
eesti	doc_399014257175_item	3527523	et	4	main
hei	doc_399014257175_item	3527524	et	3	main
kuidas	doc_399014257175_item	3527525	et	3	main
ma	doc_399014257175_item	3527538	et	3	main
viibin	doc_399014257175_item	3527539	et	3	main
hotellis	doc_399014257175_item	3527540	et	3	main
eile	doc_399014257175_item	3527545	et	3	main
oli	doc_399014257175_item	3527548	et	3	main
loodan	doc_399014257175_item	3527560	et	3	main
tänapaeval	doc_399014257175_item	3527564	et	4	main
et	doc_399014257175_item	3527567	et	3	main
on	doc_399014257175_item	3527569	et	4	main
ma	doc_399014257175_item	3527574	et	3	main
vaadata	doc_399014257175_item	3527576	et	4	main
läti	doc_399014257175_item	3527577	et	4	main
mulle	doc_399014257175_item	3527616	et	4	main
või	doc_399014257175_item	3527618	et	4	main
helista	doc_399014257175_item	3527619	et	4	main
ma	doc_399014257175_item	3527621	et	3	main
kiri	doc_213943985012_item	3527628	et	3	main
eesnimi	doc_213943985012_item	3527634	et	3	main
sõbrad	doc_213943985012_item	3527646	et	3	main
inglise	doc_213943985012_item	3527664	et	4	main
ja	doc_213943985012_item	3527665	et	3	main
sellele	doc_213943985012_item	3527672	et	4	main
kursusele	doc_213943985012_item	3527673	et	3	main
eesti	doc_213943985012_item	3527678	et	4	main
õpetada	doc_213943985012_item	3527680	et	3	main
põhjus	doc_213943985012_item	3527682	et	4	main
et	doc_213943985012_item	3527685	et	3	main
need	doc_213943985012_item	3527686	et	3	main
on	doc_213943985012_item	3527687	et	4	main
kohustuslikud	doc_213943985012_item	3527688	et	3	main
kursused	doc_213943985012_item	3527689	et	3	main
mul	doc_213943985012_item	3527690	et	3	main
vaja	doc_213943985012_item	3527694	et	4	main
on	doc_213943985012_item	3527699	et	4	main
eesti	doc_213943985012_item	3527702	et	4	main
muusikat	doc_213943985012_item	3527705	et	3	main
natuke	doc_213943985012_item	3527728	et	4	main
ahvi	doc_59711134416_item	3527444	et	4	main
ja	doc_59711134416_item	3527445	et	3	main
oli	doc_59711134416_item	3527449	et	3	main
ja	doc_59711134416_item	3527451	et	3	main
mina	doc_59711134416_item	3527457	et	4	main
kord	doc_59711134416_item	3527462	et	4	main
oli	doc_59711134416_item	3527464	et	3	main
seal	doc_59711134416_item	3527469	et	4	main
kuj	doc_59711134416_item	3527485	et	4	main
õppisin	doc_59711134416_item	3527486	et	3	main
muusika	doc_59711134416_item	3527496	et	4	main
haridus	doc_59711134416_item	3527497	et	3	main
see	doc_59711134416_item	3527498	et	3	main
on	doc_59711134416_item	3527499	et	4	main
minu	doc_59711134416_item	3527500	et	3	main
aus	doc_59711134416_item	3527501	et	4	main
tegin	doc_59711134416_item	3527508	et	3	main
kui	doc_59711134416_item	3527509	et	3	main
siis	doc_399014257175_item	3527594	et	3	main
ma	doc_399014257175_item	3527595	et	3	main
sõidan	doc_399014257175_item	3527596	et	3	main
rongiga	doc_399014257175_item	3527597	et	4	main
berlinnasse	doc_399014257175_item	3527598	et	4	main
võib-olla	doc_399014257175_item	3527599	et	3	main
ma	doc_399014257175_item	3527600	et	3	main
helistan	doc_399014257175_item	3527601	et	3	main
sulle	doc_399014257175_item	3527602	et	3	main
kui	doc_399014257175_item	3527603	et	3	main
ma	doc_399014257175_item	3527604	et	3	main
jõudin	doc_399014257175_item	3527605	et	4	main
berlina	doc_399014257175_item	3527606	et	4	main
ma	doc_399014257175_item	3527607	et	3	main
mõtlen	doc_399014257175_item	3527608	et	3	main
ma	doc_399014257175_item	3527609	et	3	main
olen	doc_399014257175_item	3527610	et	3	main
eemal	doc_399014257175_item	3527611	et	3	main
ümbes	doc_399014257175_item	3527612	et	4	main
kirjatäht	doc_399014257175_item	3527515	et	3	main
eesnimi	doc_399014257175_item	3527516	et	3	main
juhuslik	doc_399014257175_item	3527518	et	3	main
tänav	doc_399014257175_item	3527519	et	4	main
tallinn	doc_399014257175_item	3527520	et	4	main
ee	doc_399014257175_item	3527521	et	3	main
451	doc_399014257175_item	3527522	et	2	main
ma	doc_399014257175_item	3527543	et	3	main
reis	doc_399014257175_item	3527547	et	4	main
pikk	doc_399014257175_item	3527550	et	4	main
7	doc_399014257175_item	3527552	et	2	main
tunde	doc_399014257175_item	3527553	et	4	main
sellepärast	doc_399014257175_item	3527554	et	3	main
ma	doc_399014257175_item	3527555	et	3	main
olen	doc_399014257175_item	3527556	et	3	main
vaadata	doc_399014257175_item	3527561	et	4	main
kui	doc_399014257175_item	3527571	et	3	main
pealinn	doc_399014257175_item	3527578	et	3	main
kui	doc_399014257175_item	3527579	et	3	main
ma	doc_399014257175_item	3527580	et	3	main
olen	doc_399014257175_item	3527581	et	3	main
linnas	doc_399014257175_item	3527582	et	4	main
homme	doc_399014257175_item	3527583	et	3	main
päeval	doc_399014257175_item	3527584	et	3	main
ma	doc_399014257175_item	3527585	et	3	main
pean	doc_399014257175_item	3527586	et	4	main
sõita	doc_399014257175_item	3527587	et	3	main
saksamaal	doc_399014257175_item	3527588	et	4	main
esimene	doc_399014257175_item	3527589	et	3	main
ma	doc_399014257175_item	3527590	et	3	main
viibin	doc_399014257175_item	3527591	et	3	main
leipzigis	doc_399014257175_item	3527592	et	4	main
ja	doc_399014257175_item	3527593	et	3	main
3	doc_399014257175_item	3527613	et	2	main
õhtul	doc_399014257175_item	3527620	et	3	main
sinust	doc_399014257175_item	3527623	et	3	main
minu	doc_213943985012_item	3527631	et	3	main
on	doc_213943985012_item	3527633	et	4	main
olen	doc_213943985012_item	3527635	et	3	main
minu	doc_213943985012_item	3527640	et	3	main
on	doc_213943985012_item	3527642	et	4	main
minu	doc_213943985012_item	3527643	et	3	main
vanemad	doc_213943985012_item	3527644	et	4	main
ja	doc_213943985012_item	3527651	et	3	main
eesti	doc_213943985012_item	3527654	et	4	main
mu	doc_213943985012_item	3527659	et	3	main
on	doc_213943985012_item	3527674	et	4	main
see	doc_213943985012_item	3527675	et	3	main
keel	doc_213943985012_item	3527679	et	4	main
eesti	doc_213943985012_item	3527692	et	4	main
keelt	doc_213943985012_item	3527693	et	4	main
vaja	doc_213943985012_item	3527700	et	4	main
raadio	doc_213943985012_item	3527703	et	4	main
ma	doc_213943985012_item	3527706	et	3	main
eestlastega	doc_213943985012_item	3527709	et	4	main
me	doc_213943985012_item	3527721	et	4	main
mul	doc_213943985012_item	3527730	et	3	main
on	doc_213943985012_item	3527739	et	4	main
tegema	doc_213943985012_item	3527749	et	3	main
erinevates	doc_213943985012_item	3527710	et	4	main
olukorras	doc_213943985012_item	3527711	et	3	main
ma	doc_213943985012_item	3527712	et	3	main
tahan	doc_213943985012_item	3527713	et	3	main
kirjutada	doc_213943985012_item	3527714	et	3	main
raamatut	doc_213943985012_item	3527715	et	3	main
eesti	doc_213943985012_item	3527716	et	4	main
keeles	doc_213943985012_item	3527717	et	4	main
ma	doc_213943985012_item	3527718	et	3	main
loodan	doc_213943985012_item	3527719	et	3	main
et	doc_213943985012_item	3527720	et	3	main
tere	doc_213943985012_item	3527629	et	3	main
õpetaja	doc_213943985012_item	3527630	et	4	main
tpü	doc_213943985012_item	3527636	et	4	main
ma	doc_213943985012_item	3527647	et	3	main
käia	doc_213943985012_item	3527653	et	4	main
keelt	doc_213943985012_item	3527655	et	4	main
olen	doc_213943985012_item	3527656	et	3	main
saksa	doc_213943985012_item	3527666	et	4	main
keelt	doc_213943985012_item	3527667	et	4	main
esimene	doc_213943985012_item	3527668	et	3	main
tahan	doc_213943985012_item	3527677	et	3	main
on	doc_213943985012_item	3527683	et	4	main
see	doc_213943985012_item	3527684	et	3	main
ajakirjandusi	doc_213943985012_item	3527697	et	3	main
mul	doc_213943985012_item	3527698	et	3	main
kuulata	doc_213943985012_item	3527701	et	4	main
ja	doc_213943985012_item	3527704	et	3	main
tahan	doc_213943985012_item	3527707	et	3	main
tegeleme	doc_213943985012_item	3527722	et	3	main
põhjalikult	doc_213943985012_item	3527723	et	4	main
oleks	doc_213943985012_item	3527731	et	3	main
algusel	doc_213943985012_item	3527733	et	4	main
ma	doc_213943985012_item	3527734	et	3	main
milliseid	doc_213943985012_item	3527743	et	3	main
peaksime	doc_213943985012_item	3527746	et	4	main
rahul	doc_213943985012_item	3527758	et	4	main
teiega	doc_213943985012_item	3527759	et	3	main
tere	doc_491521501669_item	3527767	et	3	main
kallis	doc_491521501669_item	3527768	et	4	main
sulle	doc_491521501669_item	3527784	et	3	main
et	doc_491521501669_item	3527786	et	3	main
avatud	doc_491521501669_item	3527788	et	4	main
kauplus	doc_491521501669_item	3527790	et	3	main
kõrval	doc_491521501669_item	3527793	et	4	main
minu	doc_491521501669_item	3527794	et	3	main
maja	doc_491521501669_item	3527795	et	4	main
see	doc_491521501669_item	3527796	et	3	main
ja	doc_491521501669_item	3527808	et	3	main
hommikul	doc_491521501669_item	3527813	et	3	main
kaheksa	doc_491521501669_item	3527815	et	4	main
kaupu	doc_491521501669_item	3527827	et	3	main
ma	doc_491521501669_item	3527836	et	3	main
kodutehnika	doc_491521501669_item	3527838	et	4	main
osakonnast	doc_491521501669_item	3527839	et	4	main
uue	doc_491521501669_item	3527840	et	3	main
et	doc_491521501669_item	3527864	et	3	main
arvasin	doc_491521501669_item	3527866	et	3	main
elu	doc_213943985012_item	3527660	et	4	main
põhjus	doc_213943985012_item	3527669	et	4	main
miks	doc_213943985012_item	3527670	et	4	main
tulin	doc_213943985012_item	3527671	et	3	main
on	doc_213943985012_item	3527691	et	4	main
lugeda	doc_213943985012_item	3527696	et	3	main
eesti	doc_213943985012_item	3527724	et	4	main
et	doc_213943985012_item	3527729	et	3	main
raskused	doc_213943985012_item	3527732	et	4	main
tahaksin	doc_213943985012_item	3527735	et	3	main
teada	doc_213943985012_item	3527736	et	3	main
mis	doc_213943985012_item	3527737	et	4	main
aastal	doc_213943985012_item	3527748	et	3	main
loodan	doc_213943985012_item	3527750	et	3	main
teie	doc_213943985012_item	3527753	et	4	main
kiri	doc_491521501669_item	3527764	et	3	main
lija	doc_491521501669_item	3527769	et	4	main
kuidas	doc_491521501669_item	3527770	et	3	main
sa	doc_491521501669_item	3527771	et	3	main
korras	doc_491521501669_item	3527781	et	4	main
tahan	doc_491521501669_item	3527783	et	3	main
on	doc_491521501669_item	3527798	et	4	main
mugav	doc_491521501669_item	3527802	et	3	main
osakond	doc_491521501669_item	3527810	et	3	main
avatud	doc_491521501669_item	3527812	et	4	main
kell	doc_491521501669_item	3527814	et	3	main
üheksa	doc_491521501669_item	3527817	et	4	main
õhtul	doc_491521501669_item	3527818	et	3	main
ma	doc_491521501669_item	3527819	et	3	main
müüjad	doc_491521501669_item	3527833	et	4	main
uus	doc_491521501669_item	3527834	et	3	main
ostin	doc_491521501669_item	3527837	et	4	main
sõitme	doc_491521501669_item	3527844	et	4	main
ma	doc_491521501669_item	3527865	et	3	main
sinu	doc_491521501669_item	3527867	et	3	main
on	doc_491521501669_item	3527868	et	4	main
ka	doc_491521501669_item	3527869	et	3	main
meeldib	doc_491521501669_item	3527870	et	3	main
tervita	doc_491521501669_item	3527871	et	4	main
sinu	doc_491521501669_item	3527872	et	3	main
oma	doc_491521501669_item	3527873	et	4	main
perekonda	doc_491521501669_item	3527874	et	4	main
ma	doc_491521501669_item	3527875	et	3	main
sovin	doc_491521501669_item	3527876	et	4	main
teile	doc_491521501669_item	3527877	et	4	main
kõike	doc_491521501669_item	3527878	et	4	main
head	doc_491521501669_item	3527879	et	4	main
ma	doc_491521501669_item	3527880	et	3	main
ootan	doc_491521501669_item	3527881	et	3	main
sinu	doc_491521501669_item	3527882	et	3	main
kijra	doc_491521501669_item	3527883	et	4	main
nägemiseni	doc_491521501669_item	3527884	et	4	main
et	doc_491521501703_item	3527892	et	3	main
käid	doc_491521501703_item	3527894	et	3	main
ja	doc_491521501703_item	3527896	et	3	main
kirjuta	doc_491521501703_item	3527900	et	4	main
sul	doc_491521501703_item	3527902	et	3	main
mida	doc_491521501703_item	3527905	et	4	main
sa	doc_491521501703_item	3527919	et	3	main
tegema	doc_491521501703_item	3527921	et	3	main
väga	doc_491521501703_item	3527940	et	3	main
meldis	doc_491521501703_item	3527941	et	3	main
õppida	doc_491521501703_item	3527942	et	3	main
õppetunde	doc_491521501703_item	3527943	et	4	main
õpetajad	doc_491521501703_item	3527947	et	4	main
rääkida	doc_213943985012_item	3527708	et	3	main
keelega	doc_213943985012_item	3527725	et	3	main
ma	doc_213943985012_item	3527726	et	3	main
kardan	doc_213943985012_item	3527727	et	4	main
vormis	doc_213943985012_item	3527738	et	4	main
tööd	doc_213943985012_item	3527744	et	4	main
saan	doc_213943985012_item	3527752	et	4	main
vastustega	doc_213943985012_item	3527760	et	4	main
260903	doc_491521501669_item	3527765	et	2	main
kauplus	doc_491521501669_item	3527797	et	3	main
ilus	doc_491521501669_item	3527800	et	4	main
toiduainete	doc_491521501669_item	3527809	et	3	main
kuni	doc_491521501669_item	3527816	et	3	main
käin	doc_491521501669_item	3527820	et	3	main
palju	doc_491521501669_item	3527826	et	4	main
kauplussers	doc_491521501669_item	3527835	et	4	main
sõbranna	doc_491521501669_item	3527843	et	4	main
oma	doc_491521501703_item	3527889	et	4	main
varsti	doc_491521501703_item	3527897	et	3	main
läks	doc_491521501703_item	3527904	et	3	main
sa	doc_491521501703_item	3527906	et	3	main
õppisid	doc_491521501703_item	3527908	et	4	main
kuhu	doc_491521501703_item	3527909	et	3	main
sa	doc_491521501703_item	3527910	et	3	main
praktikale	doc_491521501703_item	3527911	et	3	main
firma	doc_491521501703_item	3527915	et	4	main
tegeleb	doc_491521501703_item	3527916	et	3	main
ja	doc_491521501703_item	3527917	et	3	main
müügi	doc_491521501703_item	3527937	et	4	main
oli	doc_491521501703_item	3527944	et	3	main
mööbli	doc_491521501703_item	3527975	et	3	main
mida	doc_491521501703_item	3527986	et	4	main
õppetadi	doc_491521501703_item	3527988	et	4	main
hea	doc_491521501703_item	3527989	et	4	main
esti	doc_491521501703_item	3527994	et	4	main
koostama	doc_491521501703_item	3527998	et	3	main
aitab	doc_491521501703_item	3528001	et	3	main
niigi	doc_491521501703_item	3528004	et	4	main
loodust	doc_491521501703_item	3528006	et	4	main
mööblisalong	doc_491521501703_item	3528011	et	3	main
on	doc_491521501703_item	3528012	et	4	main
mugav	doc_491521501703_item	3528015	et	3	main
viie	doc_491521501703_item	3528019	et	3	main
müüvad	doc_491521501703_item	3528022	et	4	main
mööblid	doc_491521501703_item	3528023	et	3	main
ja	doc_491521501703_item	3528024	et	3	main
valmistavad	doc_491521501703_item	3528025	et	4	main
kirjuta	doc_491521501704_item	3528230	et	4	main
sõbrale	doc_491521501704_item	3528233	et	3	main
et	doc_491521501704_item	3528234	et	3	main
saa	doc_491521501704_item	3528235	et	4	main
käid	doc_491521501704_item	3528236	et	3	main
kursustel	doc_491521501704_item	3528237	et	3	main
ja	doc_491521501704_item	3528238	et	3	main
varsti	doc_491521501704_item	3528239	et	3	main
praktikale	doc_491521501704_item	3528241	et	3	main
läks	doc_491521501704_item	3528246	et	3	main
mida	doc_491521501704_item	3528260	et	4	main
hakkad	doc_491521501704_item	3528264	et	3	main
ja	doc_491521501704_item	3528309	et	3	main
meil	doc_213943985012_item	3527740	et	4	main
lõpparvestus	doc_213943985012_item	3527741	et	3	main
ja	doc_213943985012_item	3527742	et	3	main
me	doc_213943985012_item	3527745	et	4	main
sel	doc_213943985012_item	3527747	et	3	main
et	doc_213943985012_item	3527751	et	3	main
käest	doc_213943985012_item	3527754	et	4	main
vastust	doc_213943985012_item	3527755	et	4	main
ja	doc_213943985012_item	3527756	et	3	main
olen	doc_213943985012_item	3527757	et	3	main
lugupidamisega	doc_213943985012_item	3527761	et	3	main
eesnimi	doc_213943985012_item	3527762	et	3	main
a	doc_491521501669_item	3527766	et	4	main
kauplus	doc_491521501669_item	3527791	et	3	main
kodutehnika	doc_491521501669_item	3527807	et	4	main
iga	doc_491521501669_item	3527821	et	4	main
kaupluses	doc_491521501669_item	3527823	et	3	main
ostan	doc_491521501669_item	3527825	et	3	main
sealt	doc_491521501669_item	3527828	et	4	main
kaupluses	doc_491521501669_item	3527829	et	3	main
töötavad	doc_491521501669_item	3527830	et	4	main
väga	doc_491521501669_item	3527831	et	3	main
viskad	doc_491521501669_item	3527832	et	3	main
kallis	doc_491521501669_item	3527842	et	4	main
kiri	doc_491521501703_item	3527886	et	3	main
kirjuta	doc_491521501703_item	3527888	et	4	main
lähed	doc_491521501703_item	3527898	et	3	main
kuidas	doc_491521501703_item	3527901	et	3	main
kursustel	doc_491521501703_item	3527903	et	3	main
mida	doc_491521501703_item	3527918	et	4	main
sekretar	doc_491521501703_item	3527938	et	4	main
aga	doc_491521501703_item	3527946	et	3	main
nii	doc_491521501703_item	3527949	et	3	main
teavad	doc_491521501703_item	3527960	et	3	main
olen	doc_491521501703_item	3527964	et	3	main
nadalil	doc_491521501703_item	3527971	et	4	main
salongi	doc_491521501703_item	3527976	et	4	main
mulla	doc_491521501669_item	3527845	et	4	main
külasti	doc_491521501669_item	3527846	et	4	main
ja	doc_491521501669_item	3527847	et	3	main
me	doc_491521501669_item	3527848	et	4	main
lähme	doc_491521501669_item	3527849	et	3	main
koos	doc_491521501669_item	3527850	et	4	main
kaupluses	doc_491521501669_item	3527851	et	3	main
ja	doc_491521501669_item	3527852	et	3	main
siis	doc_491521501669_item	3527853	et	3	main
ma	doc_491521501669_item	3527854	et	3	main
ostin	doc_491521501669_item	3527855	et	4	main
sinu	doc_491521501669_item	3527856	et	3	main
kingitusse	doc_491521501669_item	3527857	et	4	main
kohvikeetja	doc_491521501669_item	3527858	et	4	main
mulle	doc_491521501669_item	3527859	et	4	main
väga	doc_491521501669_item	3527860	et	3	main
meeldivad	doc_491521501669_item	3527861	et	4	main
see	doc_491521501669_item	3527862	et	3	main
kauplus	doc_491521501669_item	3527863	et	3	main
elad	doc_491521501669_item	3527772	et	3	main
ma	doc_491521501669_item	3527773	et	3	main
vastusin	doc_491521501669_item	3527774	et	3	main
sinu	doc_491521501669_item	3527775	et	3	main
kirje	doc_491521501669_item	3527776	et	4	main
aitäh	doc_491521501669_item	3527777	et	3	main
mul	doc_491521501669_item	3527778	et	3	main
om	doc_491521501669_item	3527779	et	4	main
kõik	doc_491521501669_item	3527780	et	4	main
ma	doc_491521501669_item	3527782	et	3	main
teatada	doc_491521501669_item	3527785	et	3	main
meil	doc_491521501669_item	3527787	et	4	main
uus	doc_491521501669_item	3527789	et	3	main
asub	doc_491521501669_item	3527792	et	3	main
väga	doc_491521501669_item	3527799	et	3	main
ja	doc_491521501669_item	3527801	et	3	main
sellel	doc_491521501669_item	3527803	et	4	main
kauplusse	doc_491521501669_item	3527804	et	3	main
on	doc_491521501669_item	3527805	et	4	main
müügil	doc_491521501669_item	3527806	et	3	main
kauplus	doc_491521501669_item	3527811	et	3	main
päev	doc_491521501669_item	3527822	et	3	main
ja	doc_491521501669_item	3527824	et	3	main
külmkappi	doc_491521501669_item	3527841	et	4	main
kiri	doc_491521501703_item	3527887	et	3	main
eestlasest	doc_491521501703_item	3527890	et	3	main
praktikale	doc_491521501703_item	3527899	et	3	main
lähed	doc_491521501703_item	3527912	et	3	main
see	doc_491521501703_item	3527914	et	3	main
seal	doc_491521501703_item	3527920	et	4	main
hakkad	doc_491521501703_item	3527922	et	3	main
lühike	doc_491521501703_item	3527953	et	4	main
ajaga	doc_491521501703_item	3527954	et	3	main
esi	doc_491521501703_item	3527959	et	4	main
õppimist	doc_491521501703_item	3527962	et	4	main
kindel	doc_491521501703_item	3527965	et	3	main
natukene	doc_491521501703_item	3527967	et	4	main
mina	doc_491521501703_item	3527972	et	4	main
lähen	doc_491521501703_item	3527973	et	3	main
pussijaama	doc_491521501703_item	3527980	et	4	main
praktikal	doc_491521501703_item	3527982	et	3	main
meile	doc_491521501703_item	3527987	et	4	main
oskame	doc_491521501703_item	3527993	et	3	main
ja	doc_491521501703_item	3527997	et	3	main
tööl	doc_491521501703_item	3528003	et	3	main
annab	doc_491521501703_item	3528005	et	3	main
ja	doc_491521501703_item	3528014	et	3	main
mina	doc_491521501703_item	3528028	et	4	main
kaitsma	doc_491521501703_item	3528047	et	3	main
aruanne	doc_491521501703_item	3528048	et	4	main
praktikast	doc_491521501703_item	3528049	et	4	main
ja	doc_491521501703_item	3528050	et	3	main
ari	doc_491521501703_item	3528051	et	4	main
plaani	doc_491521501703_item	3528052	et	4	main
head	doc_491521501703_item	3528053	et	4	main
aega	doc_491521501703_item	3528054	et	4	main
marta	doc_491521501703_item	3528055	et	4	main
loodan	doc_491521501703_item	3528056	et	3	main
es	doc_491521501703_item	3528057	et	4	main
sull	doc_491521501703_item	3528058	et	4	main
läheb	doc_491521501703_item	3528059	et	3	main
hästi	doc_491521501703_item	3528060	et	3	main
kirjuta	doc_491521501703_item	3528061	et	4	main
mulle	doc_491521501703_item	3528062	et	4	main
mis	doc_491521501703_item	3528063	et	4	main
huvitavad	doc_491521501703_item	3528064	et	4	main
on	doc_491521501703_item	3528065	et	4	main
sull	doc_491521501703_item	3528066	et	4	main
sõbrale	doc_491521501703_item	3527891	et	3	main
saa	doc_491521501703_item	3527893	et	4	main
kursustel	doc_491521501703_item	3527895	et	3	main
seal	doc_491521501703_item	3527907	et	4	main
millega	doc_491521501703_item	3527913	et	3	main
tere	doc_491521501703_item	3527923	et	3	main
marta	doc_491521501703_item	3527924	et	4	main
sain	doc_491521501703_item	3527925	et	3	main
sinu	doc_491521501703_item	3527926	et	3	main
kirja	doc_491521501703_item	3527927	et	4	main
ja	doc_491521501703_item	3527928	et	3	main
kohe	doc_491521501703_item	3527929	et	4	main
hakkan	doc_491521501703_item	3527930	et	3	main
vastama	doc_491521501703_item	3527931	et	3	main
sellel	doc_491521501703_item	3527932	et	4	main
astal	doc_491521501703_item	3527933	et	4	main
ma	doc_491521501703_item	3527934	et	3	main
sain	doc_491521501703_item	3527935	et	3	main
kursusele	doc_491521501703_item	3527936	et	3	main
mulle	doc_491521501703_item	3527939	et	4	main
väha	doc_491521501703_item	3527945	et	4	main
olid	doc_491521501703_item	3527948	et	4	main
provisid	doc_491521501703_item	3527955	et	4	main
õpida	doc_491521501703_item	3527956	et	4	main
kõike	doc_491521501703_item	3527957	et	4	main
pärast	doc_491521501703_item	3527961	et	4	main
ma	doc_491521501703_item	3527963	et	3	main
et	doc_491521501703_item	3527966	et	3	main
sain	doc_491521501703_item	3527968	et	3	main
targemaks	doc_491521501703_item	3527969	et	4	main
praktikale	doc_491521501703_item	3527974	et	3	main
asub	doc_491521501703_item	3527978	et	3	main
näitama	doc_491521501703_item	3527985	et	3	main
on	doc_491521501703_item	3527990	et	4	main
keeld	doc_491521501703_item	3527995	et	3	main
see	doc_491521501703_item	3528000	et	3	main
nagu	doc_491521501703_item	3528002	et	3	main
sada	doc_491521501703_item	3528007	et	4	main
seal	doc_491521501703_item	3528008	et	4	main
suur	doc_491521501703_item	3528013	et	3	main
töötal	doc_491521501703_item	3528017	et	4	main
firmas	doc_491521501703_item	3528021	et	3	main
sul	doc_491521501704_item	3528244	et	3	main
sa	doc_491521501704_item	3528248	et	3	main
õppisid	doc_491521501704_item	3528250	et	4	main
kuhu	doc_491521501704_item	3528251	et	3	main
sa	doc_491521501704_item	3528252	et	3	main
praktikale	doc_491521501704_item	3528253	et	3	main
lähed	doc_491521501704_item	3528254	et	3	main
millega	doc_491521501704_item	3528255	et	3	main
see	doc_491521501704_item	3528256	et	3	main
firma	doc_491521501704_item	3528257	et	4	main
tegeleb	doc_491521501704_item	3528258	et	3	main
ja	doc_491521501704_item	3528259	et	3	main
seal	doc_491521501704_item	3528262	et	4	main
tere	doc_491521501704_item	3528265	et	3	main
sain	doc_491521501704_item	3528268	et	3	main
rohkem	doc_491521501704_item	3528312	et	4	main
mulle	doc_491521501704_item	3528313	et	4	main
meeldib	doc_491521501704_item	3528314	et	3	main
töötada	doc_491521501704_item	3528315	et	3	main
vaja	doc_491521501704_item	3528321	et	4	main
sest	doc_491521501704_item	3528323	et	4	main
tahan	doc_491521501704_item	3528324	et	3	main
saada	doc_491521501704_item	3528325	et	4	main
algtase	doc_491521501704_item	3528326	et	3	main
varsti	doc_491521501704_item	3528327	et	3	main
ma	doc_491521501704_item	3528328	et	3	main
mina	doc_491521501704_item	3528357	et	4	main
aga	doc_491521501704_item	3528368	et	3	main
mina	doc_491521501704_item	3528369	et	4	main
pean	doc_491521501704_item	3528370	et	4	main
head	doc_491521501703_item	3527950	et	4	main
et	doc_491521501703_item	3527951	et	3	main
selle	doc_491521501703_item	3527952	et	4	main
mis	doc_491521501703_item	3527958	et	4	main
tuleval	doc_491521501703_item	3527970	et	4	main
mis	doc_491521501703_item	3527977	et	4	main
jõhvis	doc_491521501703_item	3527979	et	3	main
jures	doc_491521501703_item	3527981	et	4	main
meie	doc_491521501703_item	3527983	et	4	main
peame	doc_491521501703_item	3527984	et	4	main
meier	doc_491521501703_item	3527992	et	3	main
dokumendid	doc_491521501703_item	3527999	et	3	main
ta	doc_491521501703_item	3528016	et	4	main
üle	doc_491521501703_item	3528018	et	3	main
aasta	doc_491521501703_item	3528020	et	4	main
kui	doc_491521501703_item	3527991	et	3	main
arvutid	doc_491521501703_item	3527996	et	4	main
tööd	doc_491521501703_item	3528009	et	4	main
firma	doc_491521501703_item	3528010	et	4	main
tellimuise	doc_491521501703_item	3528026	et	4	main
mööblid	doc_491521501703_item	3528027	et	3	main
hakkan	doc_491521501703_item	3528029	et	3	main
reklamerima	doc_491521501703_item	3528030	et	4	main
ja	doc_491521501703_item	3528031	et	3	main
müüma	doc_491521501703_item	3528032	et	3	main
mööblid	doc_491521501703_item	3528033	et	3	main
kui	doc_491521501703_item	3528034	et	3	main
praktika	doc_491521501703_item	3528035	et	4	main
lõppeb	doc_491521501703_item	3528036	et	3	main
meie	doc_491521501703_item	3528037	et	4	main
peame	doc_491521501703_item	3528038	et	4	main
kirjutama	doc_491521501703_item	3528039	et	3	main
aruanne	doc_491521501703_item	3528040	et	4	main
praktikast	doc_491521501703_item	3528041	et	4	main
perast	doc_491521501703_item	3528042	et	4	main
tuleme	doc_491521501703_item	3528043	et	3	main
kursusele	doc_491521501703_item	3528044	et	3	main
ja	doc_491521501703_item	3528045	et	3	main
akkame	doc_491521501703_item	3528046	et	4	main
kiri	doc_491521501704_item	3528229	et	3	main
kuidas	doc_491521501704_item	3528243	et	3	main
kursustel	doc_491521501704_item	3528245	et	3	main
mida	doc_491521501704_item	3528247	et	4	main
sa	doc_491521501704_item	3528261	et	3	main
tegema	doc_491521501704_item	3528263	et	3	main
anna	doc_491521501704_item	3528266	et	4	main
sinu	doc_491521501704_item	3528269	et	3	main
on	doc_491521501704_item	3528320	et	4	main
hulgiladusse	doc_491521501704_item	3528331	et	4	main
selgeks	doc_491521501704_item	3528367	et	3	main
kirjuta	doc_491521501704_item	3528382	et	4	main
eesnimi	doc_491521501704_item	3528387	et	3	main
kiri	doc_491521501704_item	3528228	et	3	main
kirjuta	doc_491521501704_item	3528242	et	4	main
ma	doc_491521501704_item	3528267	et	3	main
oma	doc_491521501704_item	3528231	et	4	main
eestlasest	doc_491521501704_item	3528232	et	3	main
lähed	doc_491521501704_item	3528240	et	3	main
seal	doc_491521501704_item	3528249	et	4	main
mul	doc_491521501704_item	3528278	et	3	main
on	doc_491521501704_item	3528279	et	4	main
kõik	doc_491521501704_item	3528280	et	4	main
hästi	doc_491521501704_item	3528281	et	3	main
tahan	doc_491521501704_item	3528282	et	3	main
sulle	doc_491521501704_item	3528283	et	3	main
jutustada	doc_491521501704_item	3528284	et	3	main
kuidas	doc_491521501704_item	3528285	et	3	main
ma	doc_491521501704_item	3528286	et	3	main
käisin	doc_491521501704_item	3528287	et	3	main
kursusele	doc_491521501704_item	3528288	et	3	main
ma	doc_491521501704_item	3528289	et	3	main
õppisin	doc_491521501704_item	3528290	et	3	main
kursusel	doc_491521501704_item	3528291	et	3	main
müügisekretäriks	doc_491521501704_item	3528292	et	3	main
täna	doc_491521501704_item	3528293	et	4	main
nad	doc_491521501704_item	3528294	et	3	main
lõpetavad	doc_491521501704_item	3528295	et	4	main
ja	doc_491521501704_item	3528296	et	3	main
varsti	doc_491521501704_item	3528297	et	3	main
ma	doc_491521501704_item	3528298	et	3	main
lähen	doc_491521501704_item	3528299	et	3	main
praktikale	doc_491521501704_item	3528300	et	3	main
meile	doc_491521501704_item	3528301	et	4	main
õppetatakse	doc_491521501704_item	3528302	et	4	main
arvutit	doc_491521501704_item	3528303	et	3	main
ettevõtluse	doc_491521501704_item	3528304	et	3	main
aluset	doc_491521501704_item	3528305	et	4	main
psühholoogiat	doc_491521501704_item	3528306	et	3	main
eesti	doc_491521501704_item	3528307	et	4	main
kirja	doc_491521501704_item	3528270	et	4	main
kätte	doc_491521501704_item	3528271	et	4	main
aitäh	doc_491521501704_item	3528272	et	3	main
sinule	doc_491521501704_item	3528273	et	3	main
kuidas	doc_491521501704_item	3528274	et	3	main
sinu	doc_491521501704_item	3528275	et	3	main
käsi	doc_491521501704_item	3528276	et	4	main
käib	doc_491521501704_item	3528277	et	3	main
keelt	doc_491521501704_item	3528308	et	4	main
arvutiga	doc_491521501704_item	3528316	et	4	main
ja	doc_491521501704_item	3528317	et	3	main
praktikale	doc_491521501704_item	3528330	et	3	main
mind	doc_491521501704_item	3528365	et	4	main
õpetavad	doc_491521501704_item	3528366	et	4	main
oma	doc_491521501704_item	3528376	et	4	main
ootan	doc_491521501704_item	3528378	et	3	main
eestlasest	doc_491521501706_item	3528394	et	3	main
õppisid	doc_491521501706_item	3528412	et	4	main
kuhu	doc_491521501706_item	3528413	et	3	main
sa	doc_491521501706_item	3528414	et	3	main
tiina	doc_491521501706_item	3528428	et	4	main
ma	doc_491521501706_item	3528429	et	3	main
sain	doc_491521501706_item	3528430	et	3	main
ajal	doc_491521501706_item	3528440	et	4	main
käin	doc_491521501706_item	3528442	et	3	main
kursustel	doc_491521501706_item	3528443	et	3	main
on	doc_491521501706_item	3528457	et	4	main
nendel	doc_491521501706_item	3528463	et	4	main
järgmised	doc_491521501706_item	3528466	et	3	main
suhtlemistreening	doc_491521501706_item	3528481	et	3	main
töökaitse	doc_491521501706_item	3528485	et	4	main
ja	doc_491521501706_item	3528487	et	3	main
head	doc_491521501706_item	3528522	et	4	main
aega	doc_491521501706_item	3528523	et	4	main
sinu	doc_491521501706_item	3528524	et	3	main
kiri	doc_491521501709_item	3528527	et	3	main
kursustel	doc_491521501709_item	3528536	et	3	main
kuidas	doc_491521501709_item	3528542	et	3	main
kursustel	doc_491521501709_item	3528544	et	3	main
seal	doc_491521501709_item	3528548	et	4	main
õppisid	doc_491521501709_item	3528549	et	4	main
kuhu	doc_491521501709_item	3528550	et	3	main
sa	doc_491521501709_item	3528551	et	3	main
praktikale	doc_491521501709_item	3528552	et	3	main
firma	doc_491521501709_item	3528556	et	4	main
ja	doc_491521501709_item	3528558	et	3	main
seal	doc_491521501709_item	3528561	et	4	main
tegema	doc_491521501709_item	3528562	et	3	main
hakkad	doc_491521501709_item	3528563	et	3	main
tere	doc_491521501709_item	3528564	et	3	main
kallis	doc_491521501709_item	3528565	et	4	main
on	doc_491521501709_item	3528576	et	4	main
eesti	doc_491521501709_item	3528613	et	4	main
veel	doc_491521501709_item	3528615	et	4	main
on	doc_491521501709_item	3528616	et	4	main
kõik	doc_491521501709_item	3528663	et	4	main
ne	doc_491521501704_item	3528310	et	4	main
kõige	doc_491521501704_item	3528311	et	4	main
eesti	doc_491521501704_item	3528318	et	4	main
keelt	doc_491521501704_item	3528319	et	4	main
õppiada	doc_491521501704_item	3528322	et	4	main
lähen	doc_491521501704_item	3528329	et	3	main
pean	doc_491521501704_item	3528358	et	4	main
oskama	doc_491521501704_item	3528359	et	3	main
maksedokumendi	doc_491521501704_item	3528360	et	3	main
vormistada	doc_491521501704_item	3528361	et	3	main
ma	doc_491521501704_item	3528362	et	3	main
mõtlen	doc_491521501704_item	3528363	et	3	main
et	doc_491521501704_item	3528364	et	3	main
tervita	doc_491521501704_item	3528375	et	4	main
kõike	doc_491521501704_item	3528384	et	4	main
head	doc_491521501704_item	3528385	et	4	main
saa	doc_491521501706_item	3528397	et	4	main
kursustel	doc_491521501706_item	3528399	et	3	main
varsti	doc_491521501706_item	3528401	et	3	main
kuidas	doc_491521501706_item	3528405	et	3	main
sa	doc_491521501706_item	3528423	et	3	main
ja	doc_491521501706_item	3528444	et	3	main
tööbörsist	doc_491521501706_item	3528451	et	3	main
kursustel	doc_491521501706_item	3528464	et	3	main
kaubanduses	doc_491521501706_item	3528483	et	3	main
esmaabi	doc_491521501706_item	3528486	et	4	main
ladule	doc_491521501706_item	3528513	et	4	main
ma	doc_491521501706_item	3528514	et	3	main
loodan	doc_491521501706_item	3528515	et	3	main
et	doc_491521501706_item	3528516	et	3	main
ma	doc_491521501706_item	3528517	et	3	main
toimen	doc_491521501706_item	3528518	et	4	main
seal	doc_491521501704_item	3528332	et	4	main
on	doc_491521501704_item	3528333	et	4	main
hülgimüük	doc_491521501704_item	3528334	et	4	main
seal	doc_491521501704_item	3528335	et	4	main
müüjakse	doc_491521501704_item	3528336	et	4	main
toidukaubad	doc_491521501704_item	3528337	et	3	main
ma	doc_491521501704_item	3528338	et	3	main
mõtlen	doc_491521501704_item	3528339	et	3	main
et	doc_491521501704_item	3528340	et	3	main
see	doc_491521501704_item	3528341	et	3	main
töö	doc_491521501704_item	3528342	et	4	main
on	doc_491521501704_item	3528343	et	4	main
väga	doc_491521501704_item	3528344	et	3	main
huvitav	doc_491521501704_item	3528345	et	4	main
võib	doc_491521501704_item	3528346	et	3	main
olla	doc_491521501704_item	3528347	et	3	main
see	doc_491521501704_item	3528348	et	3	main
firma	doc_491521501704_item	3528349	et	4	main
võttab	doc_491521501704_item	3528350	et	4	main
mind	doc_491521501704_item	3528351	et	4	main
tööle	doc_491521501704_item	3528352	et	3	main
aga	doc_491521501704_item	3528353	et	3	main
et	doc_491521501704_item	3528354	et	3	main
seal	doc_491521501704_item	3528355	et	4	main
töötada	doc_491521501704_item	3528356	et	3	main
püüdma	doc_491521501704_item	3528371	et	3	main
mulle	doc_491521501704_item	3528383	et	4	main
24102003	doc_491521501704_item	3528388	et	2	main
kiri	doc_491521501706_item	3528391	et	3	main
ja	doc_491521501706_item	3528400	et	3	main
kirjuta	doc_491521501706_item	3528404	et	4	main
kursustel	doc_491521501706_item	3528407	et	3	main
läks	doc_491521501706_item	3528408	et	3	main
mida	doc_491521501706_item	3528422	et	4	main
kirja	doc_491521501706_item	3528432	et	4	main
ma	doc_491521501706_item	3528441	et	3	main
varsti	doc_491521501706_item	3528445	et	3	main
väga	doc_491521501706_item	3528458	et	3	main
huvitav	doc_491521501706_item	3528459	et	4	main
ja	doc_491521501706_item	3528460	et	3	main
kasulik	doc_491521501706_item	3528461	et	3	main
arvuti	doc_491521501706_item	3528468	et	4	main
vormistamine	doc_491521501706_item	3528480	et	4	main
käid	doc_491521501709_item	3528535	et	3	main
varsti	doc_491521501709_item	3528538	et	3	main
praktikale	doc_491521501709_item	3528540	et	3	main
läks	doc_491521501709_item	3528545	et	3	main
sa	doc_491521501709_item	3528547	et	3	main
evelin	doc_491521501709_item	3528566	et	4	main
kirja	doc_491521501709_item	3528570	et	4	main
ja	doc_491521501709_item	3528572	et	3	main
vastan	doc_491521501709_item	3528574	et	3	main
vaja	doc_491521501709_item	3528617	et	4	main
sa	doc_491521501709_item	3528653	et	3	main
terved	doc_491521501709_item	3528664	et	4	main
sinu	doc_491521501709_item	3528665	et	3	main
sõbranna	doc_491521501709_item	3528666	et	4	main
eesnimi	doc_491521501709_item	3528667	et	3	main
oma	doc_491521501712_item	3528672	et	4	main
et	doc_491521501712_item	3528675	et	3	main
käid	doc_491521501712_item	3528677	et	3	main
varsti	doc_491521501712_item	3528680	et	3	main
kirjuta	doc_491521501712_item	3528683	et	4	main
kuidas	doc_491521501712_item	3528684	et	3	main
sul	doc_491521501712_item	3528685	et	3	main
kursustel	doc_491521501712_item	3528686	et	3	main
läks	doc_491521501712_item	3528687	et	3	main
mida	doc_491521501712_item	3528688	et	4	main
käin	doc_491521501712_item	3528723	et	3	main
müügisekretäär	doc_491521501712_item	3528727	et	4	main
käin	doc_491521501712_item	3528729	et	3	main
kulturimaja	doc_491521501712_item	3528731	et	4	main
ma	doc_491521501712_item	3528733	et	3	main
kursusele	doc_491521501712_item	3528738	et	3	main
eesti	doc_491521501712_item	3528743	et	4	main
sõbrale	doc_491521501713_item	3528795	et	3	main
et	doc_491521501713_item	3528796	et	3	main
saa	doc_491521501713_item	3528797	et	4	main
käid	doc_491521501713_item	3528798	et	3	main
kursustel	doc_491521501713_item	3528799	et	3	main
ja	doc_491521501713_item	3528800	et	3	main
see	doc_491521501713_item	3528818	et	3	main
sa	doc_491521501713_item	3528823	et	3	main
müügisekretäri	doc_491521501713_item	3528838	et	4	main
alused	doc_491521501713_item	3528847	et	4	main
eesti	doc_491521501713_item	3528857	et	4	main
mulle	doc_491521501713_item	3528862	et	4	main
sellega	doc_491521501704_item	3528372	et	3	main
ma	doc_491521501704_item	3528373	et	3	main
lõpetan	doc_491521501704_item	3528374	et	3	main
vanemaid	doc_491521501704_item	3528377	et	4	main
sind	doc_491521501704_item	3528379	et	4	main
külla	doc_491521501704_item	3528380	et	4	main
ja	doc_491521501704_item	3528381	et	3	main
soovides	doc_491521501704_item	3528386	et	4	main
oma	doc_491521501706_item	3528393	et	4	main
et	doc_491521501706_item	3528396	et	3	main
käid	doc_491521501706_item	3528398	et	3	main
lähed	doc_491521501706_item	3528402	et	3	main
praktikale	doc_491521501706_item	3528415	et	3	main
lähed	doc_491521501706_item	3528416	et	3	main
millega	doc_491521501706_item	3528417	et	3	main
see	doc_491521501706_item	3528418	et	3	main
firma	doc_491521501706_item	3528419	et	4	main
tegeleb	doc_491521501706_item	3528420	et	3	main
ja	doc_491521501706_item	3528421	et	3	main
seal	doc_491521501706_item	3528424	et	4	main
tegema	doc_491521501706_item	3528425	et	3	main
hakkad	doc_491521501706_item	3528426	et	3	main
tere	doc_491521501706_item	3528427	et	3	main
lähen	doc_491521501706_item	3528446	et	3	main
suunati	doc_491521501706_item	3528449	et	4	main
ma	doc_491521501706_item	3528452	et	3	main
kursustel	doc_491521501706_item	3528454	et	3	main
müügisekretarina	doc_491521501706_item	3528455	et	4	main
see	doc_491521501706_item	3528456	et	3	main
on	doc_491521501706_item	3528465	et	4	main
õppeained	doc_491521501706_item	3528467	et	3	main
ette	doc_491521501706_item	3528470	et	4	main
asjaajamise	doc_491521501706_item	3528477	et	4	main
korralgamine	doc_491521501706_item	3528478	et	4	main
maksedokumentide	doc_491521501706_item	3528479	et	3	main
töötervishoid	doc_491521501706_item	3528484	et	3	main
tulema	doc_491521501706_item	3528519	et	4	main
seda	doc_491521501706_item	3528520	et	3	main
tööst	doc_491521501706_item	3528521	et	3	main
oma	doc_491521501709_item	3528530	et	4	main
et	doc_491521501709_item	3528533	et	3	main
lähed	doc_491521501709_item	3528553	et	3	main
sa	doc_491521501709_item	3528560	et	3	main
sinu	doc_491521501709_item	3528569	et	3	main
kohe	doc_491521501709_item	3528573	et	4	main
tegelda	doc_491521501709_item	3528618	et	4	main
kursusetööga	doc_491521501709_item	3528619	et	3	main
varsti	doc_491521501709_item	3528620	et	3	main
ma	doc_491521501709_item	3528621	et	3	main
elad	doc_491521501709_item	3528654	et	3	main
peeteri	doc_491521501709_item	3528657	et	4	main
kirjuta	doc_491521501712_item	3528671	et	4	main
sõbrale	doc_491521501712_item	3528674	et	3	main
sa	doc_491521501712_item	3528693	et	3	main
ma	doc_491521501712_item	3528722	et	3	main
see	doc_491521501712_item	3528725	et	3	main
ma	doc_491521501712_item	3528739	et	3	main
kiri	doc_491521501713_item	3528791	et	3	main
varsti	doc_491521501713_item	3528801	et	3	main
kursustel	doc_491521501713_item	3528807	et	3	main
firma	doc_491521501713_item	3528819	et	4	main
seal	doc_491521501713_item	3528824	et	4	main
tegema	doc_491521501713_item	3528825	et	3	main
hakkad	doc_491521501713_item	3528826	et	3	main
tere	doc_491521501713_item	3528827	et	3	main
kallis	doc_491521501713_item	3528828	et	4	main
sõber	doc_491521501713_item	3528829	et	3	main
kuidas	doc_491521501713_item	3528830	et	3	main
elad	doc_491521501713_item	3528831	et	3	main
käin	doc_491521501713_item	3528832	et	3	main
kuud	doc_491521501713_item	3528837	et	4	main
praegu	doc_491521501713_item	3528848	et	3	main
ma	doc_491521501713_item	3528849	et	3	main
kursustel	doc_491521501713_item	3528851	et	3	main
keele	doc_491521501713_item	3528858	et	4	main
eriti	doc_491521501713_item	3528859	et	3	main
kiri	doc_491521501714_item	3528891	et	3	main
kursustel	doc_491521501714_item	3528899	et	3	main
kristina	doc_491521501714_item	3528928	et	4	main
kuidas	doc_491521501714_item	3528929	et	3	main
käime	doc_491521501714_item	3528936	et	4	main
müügisekretäri	doc_491521501714_item	3528939	et	4	main
võtluse	doc_491521501706_item	3528471	et	3	main
alused	doc_491521501706_item	3528472	et	4	main
psühholoogia	doc_491521501706_item	3528473	et	4	main
alused	doc_491521501706_item	3528474	et	4	main
turunduse	doc_491521501706_item	3528475	et	3	main
alused	doc_491521501706_item	3528476	et	4	main
kiri	doc_491521501706_item	3528390	et	3	main
kirjuta	doc_491521501706_item	3528392	et	4	main
sõbrale	doc_491521501706_item	3528395	et	3	main
praktikale	doc_491521501706_item	3528403	et	3	main
sul	doc_491521501706_item	3528406	et	3	main
mida	doc_491521501706_item	3528409	et	4	main
sa	doc_491521501706_item	3528410	et	3	main
seal	doc_491521501706_item	3528411	et	4	main
sinu	doc_491521501706_item	3528431	et	3	main
kätte	doc_491521501706_item	3528433	et	4	main
aitah	doc_491521501706_item	3528434	et	4	main
sinule	doc_491521501706_item	3528435	et	3	main
oli	doc_491521501706_item	3528436	et	3	main
väga	doc_491521501706_item	3528437	et	3	main
huvitav	doc_491521501706_item	3528438	et	4	main
samal	doc_491521501706_item	3528439	et	3	main
praktikale	doc_491521501706_item	3528447	et	3	main
mind	doc_491521501706_item	3528448	et	4	main
kursustel	doc_491521501706_item	3528450	et	3	main
õppin	doc_491521501706_item	3528453	et	4	main
eriala	doc_491521501706_item	3528462	et	4	main
õpetus	doc_491521501706_item	3528469	et	4	main
seadusandlus	doc_491521501706_item	3528482	et	3	main
eesti	doc_491521501706_item	3528488	et	4	main
keel	doc_491521501706_item	3528489	et	4	main
pärast	doc_491521501706_item	3528490	et	4	main
kursustel	doc_491521501706_item	3528491	et	3	main
me	doc_491521501706_item	3528492	et	4	main
läheme	doc_491521501706_item	3528493	et	3	main
ette	doc_491521501706_item	3528494	et	4	main
võtte	doc_491521501706_item	3528495	et	4	main
praktikale	doc_491521501706_item	3528496	et	3	main
ma	doc_491521501706_item	3528497	et	3	main
lähen	doc_491521501706_item	3528498	et	3	main
praktikale	doc_491521501706_item	3528499	et	3	main
as	doc_491521501706_item	3528500	et	4	main
toila	doc_491521501706_item	3528501	et	4	main
universal	doc_491521501706_item	3528502	et	4	main
see	doc_491521501706_item	3528503	et	3	main
firma	doc_491521501706_item	3528504	et	4	main
tegeleb	doc_491521501706_item	3528505	et	3	main
mettlli	doc_491521501706_item	3528506	et	4	main
müük	doc_491521501706_item	3528507	et	3	main
ma	doc_491521501706_item	3528508	et	3	main
hakkan	doc_491521501706_item	3528509	et	3	main
töötama	doc_491521501706_item	3528510	et	3	main
sellest	doc_491521501706_item	3528511	et	4	main
firmast	doc_491521501706_item	3528512	et	4	main
sõbranna	doc_491521501706_item	3528525	et	4	main
sõbrale	doc_491521501709_item	3528532	et	3	main
ja	doc_491521501709_item	3528537	et	3	main
kirjuta	doc_491521501709_item	3528541	et	4	main
sul	doc_491521501709_item	3528543	et	3	main
mida	doc_491521501709_item	3528546	et	4	main
see	doc_491521501709_item	3528555	et	3	main
ma	doc_491521501709_item	3528567	et	3	main
mul	doc_491521501709_item	3528575	et	3	main
psühhologia	doc_491521501709_item	3528611	et	4	main
keel	doc_491521501709_item	3528614	et	4	main
praktikale	doc_491521501709_item	3528623	et	3	main
seal	doc_491521501709_item	3528625	et	4	main
müüvad	doc_491521501709_item	3528626	et	4	main
ja	doc_491521501709_item	3528628	et	3	main
ehitusmaterjalid	doc_491521501709_item	3528627	et	3	main
majakaup	doc_491521501709_item	3528629	et	3	main
ma	doc_491521501709_item	3528630	et	3	main
hakkan	doc_491521501709_item	3528631	et	3	main
abistama	doc_491521501709_item	3528632	et	3	main
müüjale	doc_491521501709_item	3528633	et	4	main
ma	doc_491521501709_item	3528634	et	3	main
loodan	doc_491521501709_item	3528635	et	3	main
et	doc_491521501709_item	3528636	et	3	main
praktikal	doc_491521501709_item	3528637	et	3	main
mul	doc_491521501709_item	3528638	et	3	main
on	doc_491521501709_item	3528639	et	4	main
kõik	doc_491521501709_item	3528640	et	4	main
korras	doc_491521501709_item	3528641	et	4	main
ja	doc_491521501709_item	3528642	et	3	main
ma	doc_491521501709_item	3528643	et	3	main
jään	doc_491521501709_item	3528644	et	3	main
töötama	doc_491521501709_item	3528645	et	3	main
sees	doc_491521501709_item	3528646	et	4	main
kaupluses	doc_491521501709_item	3528647	et	3	main
poes	doc_491521501709_item	3528648	et	3	main
sellega	doc_491521501709_item	3528649	et	3	main
lõpetan	doc_491521501709_item	3528650	et	3	main
kirjuta	doc_491521501709_item	3528651	et	4	main
kuidas	doc_491521501709_item	3528652	et	3	main
meeldis	doc_491521501709_item	3528608	et	3	main
õppida	doc_491521501709_item	3528609	et	3	main
arvutid	doc_491521501709_item	3528610	et	4	main
kiri	doc_491521501709_item	3528528	et	3	main
kirjuta	doc_491521501709_item	3528529	et	4	main
eestlasest	doc_491521501709_item	3528531	et	3	main
saa	doc_491521501709_item	3528534	et	4	main
lähed	doc_491521501709_item	3528539	et	3	main
millega	doc_491521501709_item	3528554	et	3	main
tegeleb	doc_491521501709_item	3528557	et	3	main
mida	doc_491521501709_item	3528559	et	4	main
sain	doc_491521501709_item	3528568	et	3	main
eile	doc_491521501709_item	3528571	et	3	main
uudis	doc_491521501709_item	3528577	et	3	main
hiljuti	doc_491521501709_item	3528578	et	4	main
ma	doc_491521501709_item	3528579	et	3	main
käisin	doc_491521501709_item	3528580	et	3	main
müügisekretäri	doc_491521501709_item	3528581	et	4	main
kursustel	doc_491521501709_item	3528582	et	3	main
ja	doc_491521501709_item	3528583	et	3	main
varsti	doc_491521501709_item	3528584	et	3	main
lähen	doc_491521501709_item	3528585	et	3	main
praktikale	doc_491521501709_item	3528586	et	3	main
ma	doc_491521501709_item	3528587	et	3	main
õppisin	doc_491521501709_item	3528588	et	3	main
3010	doc_491521501709_item	3528590	et	2	main
1808	doc_491521501709_item	3528589	et	2	main
me	doc_491521501709_item	3528591	et	4	main
õppisime	doc_491521501709_item	3528592	et	3	main
arvutid	doc_491521501709_item	3528593	et	4	main
ettevõtluse	doc_491521501709_item	3528594	et	3	main
alused	doc_491521501709_item	3528595	et	4	main
psühholoogia	doc_491521501709_item	3528596	et	4	main
alused	doc_491521501709_item	3528597	et	4	main
turunduse	doc_491521501709_item	3528598	et	3	main
alused	doc_491521501709_item	3528599	et	4	main
aktiivse	doc_491521501709_item	3528600	et	3	main
müügi	doc_491521501709_item	3528601	et	4	main
alused	doc_491521501709_item	3528602	et	4	main
eesti	doc_491521501709_item	3528603	et	4	main
keel	doc_491521501709_item	3528604	et	4	main
kõige	doc_491521501709_item	3528605	et	4	main
rohkem	doc_491521501709_item	3528606	et	4	main
mulle	doc_491521501709_item	3528607	et	4	main
ja	doc_491521501709_item	3528612	et	3	main
lähen	doc_491521501709_item	3528622	et	3	main
kauplusesse	doc_491521501709_item	3528624	et	4	main
kuidas	doc_491521501709_item	3528655	et	3	main
ja	doc_491521501709_item	3528658	et	3	main
eestlasest	doc_491521501712_item	3528673	et	3	main
sa	doc_491521501712_item	3528689	et	3	main
kuhu	doc_491521501712_item	3528692	et	3	main
praktikale	doc_491521501712_item	3528694	et	3	main
on	doc_491521501709_item	3528656	et	4	main
laste	doc_491521501709_item	3528659	et	4	main
tervis	doc_491521501709_item	3528660	et	3	main
me	doc_491521501709_item	3528661	et	4	main
oleme	doc_491521501709_item	3528662	et	3	main
kiri	doc_491521501712_item	3528669	et	3	main
saa	doc_491521501712_item	3528676	et	4	main
ja	doc_491521501712_item	3528679	et	3	main
praktikale	doc_491521501712_item	3528682	et	3	main
seal	doc_491521501712_item	3528690	et	4	main
õppisid	doc_491521501712_item	3528691	et	4	main
päev	doc_491521501712_item	3528721	et	3	main
ma	doc_491521501712_item	3528728	et	3	main
pean	doc_491521501712_item	3528734	et	4	main
õppima	doc_491521501712_item	3528735	et	3	main
et	doc_491521501712_item	3528736	et	3	main
töötada	doc_491521501712_item	3528737	et	3	main
veel	doc_491521501712_item	3528746	et	4	main
kauplused	doc_491521501712_item	3528767	et	3	main
on	doc_491521501712_item	3528769	et	4	main
olnud	doc_491521501712_item	3528770	et	4	main
kokkupuuteid	doc_491521501712_item	3528771	et	4	main
kaebandusega	doc_491521501712_item	3528772	et	4	main
ja	doc_491521501712_item	3528773	et	3	main
läbinud	doc_491521501712_item	3528774	et	4	main
kaubandusalaseid	doc_491521501712_item	3528775	et	4	main
koolitusi	doc_491521501712_item	3528776	et	4	main
ning	doc_491521501712_item	3528777	et	3	main
oman	doc_491521501712_item	3528778	et	3	main
eelduse	doc_491521501712_item	3528779	et	4	main
edasiseks	doc_491521501712_item	3528780	et	4	main
tööks	doc_491521501712_item	3528781	et	3	main
selles	doc_491521501712_item	3528782	et	4	main
valdkonnas	doc_491521501712_item	3528783	et	4	main
no	doc_491521501712_item	3528784	et	3	main
kõik	doc_491521501712_item	3528785	et	4	main
kõigile	doc_491521501712_item	3528786	et	4	main
palju	doc_491521501712_item	3528787	et	4	main
tervisi	doc_491521501712_item	3528788	et	3	main
oma	doc_491521501713_item	3528793	et	4	main
kirjuta	doc_491521501713_item	3528804	et	4	main
sul	doc_491521501713_item	3528806	et	3	main
läks	doc_491521501713_item	3528808	et	3	main
sa	doc_491521501713_item	3528810	et	3	main
tegeleb	doc_491521501713_item	3528820	et	3	main
juba	doc_491521501713_item	3528835	et	3	main
meile	doc_491521501713_item	3528840	et	4	main
arvutioskus	doc_491521501713_item	3528842	et	3	main
alused	doc_491521501713_item	3528844	et	4	main
raamatupidamisega	doc_491521501713_item	3528845	et	3	main
raske	doc_491521501713_item	3528860	et	4	main
on	doc_491521501713_item	3528861	et	4	main
eestlasest	doc_491521501714_item	3528894	et	3	main
et	doc_491521501714_item	3528896	et	3	main
käid	doc_491521501714_item	3528898	et	3	main
ja	doc_491521501714_item	3528900	et	3	main
lähed	doc_491521501714_item	3528902	et	3	main
kirjuta	doc_491521501714_item	3528904	et	4	main
kursustel	doc_491521501714_item	3528907	et	3	main
õppisid	doc_491521501714_item	3528912	et	4	main
sa	doc_491521501714_item	3528914	et	3	main
mulle	doc_491521501712_item	3528748	et	4	main
meeldid	doc_491521501712_item	3528749	et	3	main
seal	doc_491521501712_item	3528750	et	4	main
kursussel	doc_491521501712_item	3528751	et	4	main
ma	doc_491521501712_item	3528752	et	3	main
tahksin	doc_491521501712_item	3528753	et	4	main
töötan	doc_491521501712_item	3528754	et	3	main
kaubandusse	doc_491521501712_item	3528755	et	3	main
praktikale	doc_491521501712_item	3528756	et	3	main
ma	doc_491521501712_item	3528757	et	3	main
lähen	doc_491521501712_item	3528758	et	3	main
oü	doc_491521501712_item	3528759	et	4	main
ahtme	doc_491521501712_item	3528760	et	4	main
voorimees	doc_491521501712_item	3528761	et	4	main
mööbel	doc_491521501712_item	3528762	et	3	main
siin	doc_491521501712_item	3528763	et	4	main
firmal	doc_491521501712_item	3528764	et	3	main
on	doc_491521501712_item	3528765	et	4	main
kolm	doc_491521501712_item	3528766	et	3	main
mul	doc_491521501712_item	3528768	et	3	main
kiri	doc_491521501712_item	3528670	et	3	main
kursustel	doc_491521501712_item	3528678	et	3	main
lähed	doc_491521501712_item	3528681	et	3	main
lähed	doc_491521501712_item	3528695	et	3	main
millega	doc_491521501712_item	3528696	et	3	main
see	doc_491521501712_item	3528697	et	3	main
firma	doc_491521501712_item	3528698	et	4	main
tegeleb	doc_491521501712_item	3528699	et	3	main
ja	doc_491521501712_item	3528700	et	3	main
mida	doc_491521501712_item	3528701	et	4	main
sa	doc_491521501712_item	3528702	et	3	main
seal	doc_491521501712_item	3528703	et	4	main
tegema	doc_491521501712_item	3528704	et	3	main
hakkad	doc_491521501712_item	3528705	et	3	main
tere	doc_491521501712_item	3528706	et	3	main
tiina	doc_491521501712_item	3528707	et	4	main
kuidas	doc_491521501712_item	3528708	et	3	main
sa	doc_491521501712_item	3528709	et	3	main
elad	doc_491521501712_item	3528710	et	3	main
mul	doc_491521501712_item	3528711	et	3	main
on	doc_491521501712_item	3528712	et	4	main
veidi	doc_491521501712_item	3528713	et	3	main
aega	doc_491521501712_item	3528714	et	4	main
kuna	doc_491521501712_item	3528715	et	3	main
ma	doc_491521501712_item	3528716	et	3	main
õppin	doc_491521501712_item	3528717	et	4	main
kõik	doc_491521501712_item	3528718	et	4	main
süsisel	doc_491521501712_item	3528719	et	4	main
iga	doc_491521501712_item	3528720	et	4	main
kursusel	doc_491521501712_item	3528724	et	3	main
kursusel	doc_491521501712_item	3528730	et	3	main
jõhvis	doc_491521501712_item	3528732	et	3	main
õppin	doc_491521501712_item	3528740	et	4	main
õppeained	doc_491521501712_item	3528747	et	3	main
kiri	doc_491521501713_item	3528790	et	3	main
kursusel	doc_491521501712_item	3528726	et	3	main
arvuti	doc_491521501712_item	3528741	et	4	main
psühologu	doc_491521501712_item	3528742	et	4	main
keel	doc_491521501712_item	3528744	et	4	main
ja	doc_491521501712_item	3528745	et	3	main
kirjuta	doc_491521501713_item	3528792	et	4	main
eestlasest	doc_491521501713_item	3528794	et	3	main
praktikale	doc_491521501713_item	3528803	et	3	main
kuidas	doc_491521501713_item	3528805	et	3	main
börsi	doc_491521501713_item	3528833	et	4	main
kursustel	doc_491521501713_item	3528834	et	3	main
õpetatakse	doc_491521501713_item	3528841	et	3	main
eesti	doc_491521501713_item	3528852	et	4	main
keelt	doc_491521501713_item	3528853	et	4	main
tahaksin	doc_491521501713_item	3528854	et	3	main
ära	doc_491521501713_item	3528855	et	4	main
õppida	doc_491521501713_item	3528856	et	3	main
varsti	doc_491521501713_item	3528864	et	3	main
kirjuta	doc_491521501714_item	3528892	et	4	main
saa	doc_491521501714_item	3528897	et	4	main
varsti	doc_491521501714_item	3528901	et	3	main
praktikale	doc_491521501714_item	3528903	et	3	main
kuidas	doc_491521501714_item	3528905	et	3	main
läks	doc_491521501714_item	3528908	et	3	main
mida	doc_491521501714_item	3528909	et	4	main
sa	doc_491521501714_item	3528910	et	3	main
ja	doc_491521501714_item	3528921	et	3	main
oled	doc_491521501714_item	3528931	et	3	main
me	doc_491521501714_item	3528935	et	4	main
kahekesi	doc_491521501714_item	3528937	et	3	main
sekretäriks	doc_491521501714_item	3528944	et	3	main
ma	doc_491521501714_item	3528945	et	3	main
eesti	doc_491521501714_item	3528947	et	4	main
me	doc_491521501714_item	3528967	et	4	main
töötame	doc_491521501714_item	3528968	et	3	main
juures	doc_491521501714_item	3528983	et	4	main
millal	doc_491521501714_item	3528984	et	3	main
palju	doc_491521501714_item	3528988	et	4	main
sul	doc_491521501716_item	3529008	et	3	main
millega	doc_491521501716_item	3529019	et	3	main
lähen	doc_491521501716_item	3529039	et	3	main
praktikale	doc_491521501716_item	3529045	et	3	main
müügi	doc_491521501716_item	3529053	et	4	main
turunduse	doc_491521501716_item	3529055	et	3	main
ma	doc_491521501716_item	3529066	et	3	main
sõbrale	doc_491521501718_item	3529096	et	3	main
seal	doc_491521501718_item	3529112	et	4	main
firma	doc_491521501718_item	3529120	et	4	main
ja	doc_491521501718_item	3529122	et	3	main
sa	doc_491521501718_item	3529124	et	3	main
seal	doc_491521501718_item	3529125	et	4	main
tegema	doc_491521501718_item	3529126	et	3	main
hakkad	doc_491521501718_item	3529127	et	3	main
tere	doc_491521501718_item	3529128	et	3	main
minu	doc_491521501718_item	3529129	et	3	main
kursus	doc_491521501718_item	3529144	et	3	main
meldib	doc_491521501718_item	3529146	et	4	main
iga	doc_491521501718_item	3529150	et	4	main
jalgsi	doc_491521501718_item	3529153	et	3	main
keel	doc_491521501718_item	3529155	et	4	main
enamasti	doc_491521501718_item	3529157	et	4	main
tund	doc_491521501718_item	3529158	et	3	main
läbi	doc_491521501718_item	3529159	et	4	main
väga	doc_491521501718_item	3529160	et	3	main
sõna	doc_491521501718_item	3529167	et	4	main
ja	doc_491521501718_item	3529168	et	3	main
on	doc_491521501718_item	3529183	et	4	main
firma	doc_491521501718_item	3529184	et	4	main
ja	doc_491521501718_item	3529190	et	3	main
arale	doc_491521501718_item	3529218	et	3	main
zepter	doc_491521501713_item	3528869	et	4	main
firmasid	doc_491521501713_item	3528870	et	3	main
firma	doc_491521501713_item	3528871	et	4	main
müügika	doc_491521501713_item	3528872	et	4	main
järelmaksuga	doc_491521501713_item	3528873	et	3	main
erinevad	doc_491521501713_item	3528874	et	4	main
kaubad	doc_491521501713_item	3528875	et	3	main
terviseselulaad	doc_491521501713_item	3528876	et	4	main
ma	doc_491521501713_item	3528877	et	3	main
kutsun	doc_491521501713_item	3528878	et	3	main
sulle	doc_491521501713_item	3528879	et	3	main
esitamine	doc_491521501713_item	3528880	et	4	main
firmat	doc_491521501713_item	3528881	et	3	main
koosnema	doc_491521501713_item	3528882	et	3	main
02112003	doc_491521501713_item	3528883	et	2	main
peatse	doc_491521501713_item	3528884	et	3	main
jällenägemiseni	doc_491521501713_item	3528885	et	4	main
sinu	doc_491521501713_item	3528886	et	3	main
sõbratar	doc_491521501713_item	3528887	et	3	main
eesnimi	doc_491521501713_item	3528888	et	3	main
lähed	doc_491521501713_item	3528802	et	3	main
mida	doc_491521501713_item	3528809	et	4	main
seal	doc_491521501713_item	3528811	et	4	main
õppisid	doc_491521501713_item	3528812	et	4	main
kuhu	doc_491521501713_item	3528813	et	3	main
sa	doc_491521501713_item	3528814	et	3	main
praktikale	doc_491521501713_item	3528815	et	3	main
lähed	doc_491521501713_item	3528816	et	3	main
millega	doc_491521501713_item	3528817	et	3	main
ja	doc_491521501713_item	3528821	et	3	main
mida	doc_491521501713_item	3528822	et	4	main
kolm	doc_491521501713_item	3528836	et	3	main
erialal	doc_491521501713_item	3528839	et	3	main
psühholoogia	doc_491521501713_item	3528843	et	4	main
ettevõtluse	doc_491521501713_item	3528846	et	3	main
opin	doc_491521501713_item	3528850	et	4	main
hääldamine	doc_491521501713_item	3528863	et	4	main
lähen	doc_491521501713_item	3528865	et	3	main
praktikale	doc_491521501713_item	3528866	et	3	main
praktikale	doc_491521501713_item	3528867	et	3	main
lähen	doc_491521501713_item	3528868	et	3	main
kiri	doc_491521501714_item	3528890	et	3	main
sõbrale	doc_491521501714_item	3528895	et	3	main
seal	doc_491521501714_item	3528911	et	4	main
kuidas	doc_491521501714_item	3528932	et	3	main
elad	doc_491521501714_item	3528934	et	3	main
inna	doc_491521501714_item	3528938	et	3	main
tahan	doc_491521501714_item	3528942	et	3	main
õpen	doc_491521501714_item	3528956	et	4	main
arvutik	doc_491521501714_item	3528958	et	3	main
rohken	doc_491521501714_item	3528961	et	4	main
sõbra	doc_491521501714_item	3528962	et	3	main
varsti	doc_491521501714_item	3528963	et	3	main
me	doc_491521501714_item	3528964	et	4	main
läheme	doc_491521501714_item	3528965	et	3	main
praktikale	doc_491521501714_item	3528966	et	3	main
ilusad	doc_491521501714_item	3528974	et	3	main
minu	doc_491521501714_item	3528976	et	3	main
kiri	doc_491521501716_item	3528993	et	3	main
läks	doc_491521501716_item	3529010	et	3	main
ja	doc_491521501716_item	3529023	et	3	main
seal	doc_491521501716_item	3529026	et	4	main
tegema	doc_491521501716_item	3529027	et	3	main
hakkad	doc_491521501716_item	3529028	et	3	main
tere	doc_491521501716_item	3529029	et	3	main
kalis	doc_491521501716_item	3529030	et	3	main
sõber	doc_491521501716_item	3529031	et	3	main
ma	doc_491521501716_item	3529032	et	3	main
käin	doc_491521501716_item	3529033	et	3	main
kursustel	doc_491521501716_item	3529034	et	3	main
müügisekretär	doc_491521501716_item	3529035	et	3	main
kuu	doc_491521501716_item	3529036	et	4	main
augustil	doc_491521501716_item	3529037	et	3	main
ma	doc_491521501716_item	3529038	et	3	main
lõppema	doc_491521501716_item	3529041	et	4	main
ma	doc_491521501716_item	3529043	et	3	main
alused	doc_491521501716_item	3529051	et	4	main
eesnimi	doc_491521501714_item	3528990	et	3	main
oma	doc_491521501714_item	3528893	et	4	main
sul	doc_491521501714_item	3528906	et	3	main
kuhu	doc_491521501714_item	3528913	et	3	main
praktikale	doc_491521501714_item	3528915	et	3	main
millega	doc_491521501714_item	3528917	et	3	main
firma	doc_491521501714_item	3528919	et	4	main
mida	doc_491521501714_item	3528922	et	4	main
sa	doc_491521501714_item	3528923	et	3	main
seal	doc_491521501714_item	3528924	et	4	main
tegema	doc_491521501714_item	3528925	et	3	main
hakkad	doc_491521501714_item	3528926	et	3	main
tere	doc_491521501714_item	3528927	et	3	main
sa	doc_491521501714_item	3528933	et	3	main
on	doc_491521501714_item	3528953	et	4	main
nimi	doc_491521501714_item	3528954	et	3	main
vell	doc_491521501714_item	3528957	et	4	main
olen	doc_491521501714_item	3528960	et	3	main
müüakse	doc_491521501714_item	3528973	et	3	main
kauplus	doc_491521501714_item	3528977	et	3	main
on	doc_491521501714_item	3528978	et	4	main
ma	doc_491521501714_item	3528980	et	3	main
ootame	doc_491521501714_item	3528981	et	3	main
sinu	doc_491521501714_item	3528982	et	3	main
kõigile	doc_491521501714_item	3528987	et	4	main
oma	doc_491521501716_item	3528995	et	4	main
kursustel	doc_491521501716_item	3529001	et	3	main
mida	doc_491521501716_item	3529011	et	4	main
firma	doc_491521501716_item	3529021	et	4	main
sa	doc_491521501716_item	3529025	et	3	main
psühholoogia	doc_491521501716_item	3529050	et	4	main
alused	doc_491521501716_item	3529056	et	4	main
eesti	doc_491521501716_item	3529057	et	4	main
kell	doc_491521501716_item	3529058	et	3	main
ja	doc_491521501716_item	3529059	et	3	main
seadusandlus	doc_491521501716_item	3529060	et	3	main
kaubanduses	doc_491521501716_item	3529061	et	3	main
kiri	doc_491521501718_item	3529091	et	3	main
oma	doc_491521501718_item	3529094	et	4	main
käid	doc_491521501718_item	3529099	et	3	main
ja	doc_491521501718_item	3529101	et	3	main
lähed	doc_491521501718_item	3529103	et	3	main
kirjuta	doc_491521501718_item	3529105	et	4	main
kursustel	doc_491521501718_item	3529108	et	3	main
õppisid	doc_491521501718_item	3529113	et	4	main
lähed	doc_491521501718_item	3529117	et	3	main
see	doc_491521501718_item	3529119	et	3	main
tegeleb	doc_491521501718_item	3529121	et	3	main
mida	doc_491521501718_item	3529123	et	4	main
kirjutan	doc_491521501718_item	3529133	et	3	main
ma	doc_491521501718_item	3529136	et	3	main
hästi	doc_491521501718_item	3529138	et	3	main
õppima	doc_491521501718_item	3529141	et	3	main
mulle	doc_491521501718_item	3529145	et	4	main
eesti	doc_491521501718_item	3529147	et	4	main
keel	doc_491521501718_item	3529148	et	4	main
ma	doc_491521501718_item	3529152	et	3	main
huvitav	doc_491521501718_item	3529161	et	4	main
sõbrale	doc_491521501718_item	3529170	et	3	main
ma	doc_491521501718_item	3529173	et	3	main
affen	doc_491521501718_item	3529185	et	4	main
töötab	doc_491521501718_item	3529187	et	3	main
külla	doc_491521501718_item	3529207	et	4	main
sinu	doc_491521501718_item	3529217	et	3	main
kiri	doc_744962874521_item	3529228	et	3	main
19	doc_744962874521_item	3529237	et	2	main
vene	doc_744962874521_item	3529263	et	4	main
esimene	doc_744962874521_item	3529265	et	3	main
riigikeel	doc_744962874521_item	3529288	et	4	main
eesti	doc_744962874521_item	3529294	et	4	main
telerit	doc_744962874521_item	3529300	et	3	main
ainult	doc_744962874521_item	3529304	et	4	main
me	doc_744962874521_item	3529320	et	4	main
sõnavaraga	doc_744962874521_item	3529323	et	3	main
natuke	doc_744962874521_item	3529326	et	4	main
lähed	doc_491521501714_item	3528916	et	3	main
see	doc_491521501714_item	3528918	et	3	main
tegeleb	doc_491521501714_item	3528920	et	3	main
sa	doc_491521501714_item	3528930	et	3	main
saada	doc_491521501714_item	3528943	et	4	main
õpin	doc_491521501714_item	3528946	et	3	main
keel	doc_491521501714_item	3528948	et	4	main
iga	doc_491521501714_item	3528949	et	4	main
päev	doc_491521501714_item	3528950	et	3	main
õpilane	doc_491521501714_item	3528951	et	3	main
nimi	doc_491521501714_item	3528952	et	3	main
on	doc_491521501714_item	3528969	et	4	main
mööblikauplus	doc_491521501714_item	3528970	et	3	main
mööblad	doc_491521501714_item	3528975	et	4	main
kohtla-järve	doc_491521501714_item	3528979	et	4	main
kohanul	doc_491521501714_item	3528986	et	4	main
tervisi	doc_491521501714_item	3528989	et	3	main
kiri	doc_491521501716_item	3528992	et	3	main
kirjuta	doc_491521501716_item	3528994	et	4	main
eestlasest	doc_491521501716_item	3528996	et	3	main
et	doc_491521501716_item	3528998	et	3	main
saa	doc_491521501716_item	3528999	et	4	main
käid	doc_491521501716_item	3529000	et	3	main
ja	doc_491521501716_item	3529002	et	3	main
varsti	doc_491521501716_item	3529003	et	3	main
lähed	doc_491521501716_item	3529004	et	3	main
praktikale	doc_491521501716_item	3529005	et	3	main
kirjuta	doc_491521501716_item	3529006	et	4	main
kuidas	doc_491521501716_item	3529007	et	3	main
sa	doc_491521501716_item	3529012	et	3	main
seal	doc_491521501716_item	3529013	et	4	main
kuhu	doc_491521501716_item	3529015	et	3	main
lähed	doc_491521501716_item	3529018	et	3	main
see	doc_491521501716_item	3529020	et	3	main
kursustel	doc_491521501716_item	3529040	et	3	main
ja	doc_491521501716_item	3529042	et	3	main
lähen	doc_491521501716_item	3529044	et	3	main
kursustel	doc_491521501716_item	3529046	et	3	main
õpisin	doc_491521501716_item	3529048	et	4	main
aktivise	doc_491521501716_item	3529052	et	3	main
alused	doc_491521501716_item	3529054	et	4	main
hakkad	doc_491521501716_item	3529063	et	3	main
aastale	doc_491521501716_item	3529065	et	3	main
kirjuta	doc_491521501718_item	3529093	et	4	main
et	doc_491521501718_item	3529097	et	3	main
kursustel	doc_491521501718_item	3529100	et	3	main
varsti	doc_491521501718_item	3529102	et	3	main
sul	doc_491521501718_item	3529107	et	3	main
mida	doc_491521501718_item	3529110	et	4	main
sa	doc_491521501718_item	3529111	et	3	main
millega	doc_491521501718_item	3529118	et	3	main
ma	doc_491521501718_item	3529132	et	3	main
sulle	doc_491521501718_item	3529134	et	3	main
praegu	doc_491521501718_item	3529139	et	3	main
õpima	doc_491521501718_item	3529149	et	4	main
räägin	doc_491521501718_item	3529169	et	3	main
värsti	doc_491521501718_item	3529172	et	4	main
naine	doc_491521501718_item	3529189	et	3	main
kirjuta	doc_491521501718_item	3529208	et	4	main
igatsen	doc_491521501718_item	3529216	et	3	main
aega	doc_491521501718_item	3529220	et	4	main
õpetaja	doc_744962874521_item	3529230	et	4	main
perekonnanimi	doc_744962874521_item	3529235	et	3	main
õppinud	doc_744962874521_item	3529256	et	4	main
7	doc_744962874521_item	3529257	et	2	main
aastat	doc_744962874521_item	3529258	et	3	main
sellele	doc_744962874521_item	3529269	et	4	main
kursusele	doc_744962874521_item	3529270	et	3	main
ma	doc_744962874521_item	3529271	et	3	main
tahan	doc_744962874521_item	3529272	et	3	main
keeles	doc_744962874521_item	3529279	et	4	main
on	doc_744962874521_item	3529282	et	4	main
elan	doc_744962874521_item	3529285	et	3	main
on	doc_744962874521_item	3529293	et	4	main
saateid	doc_744962874521_item	3529299	et	3	main
et	doc_744962874521_item	3529319	et	3	main
põhjalikult	doc_744962874521_item	3529322	et	4	main
kardan	doc_744962874521_item	3529325	et	4	main
grammatiku	doc_744962874521_item	3529331	et	3	main
teie	doc_744962874521_item	3529336	et	4	main
kursusel	doc_491521501714_item	3528940	et	3	main
ma	doc_491521501714_item	3528941	et	3	main
ma	doc_491521501714_item	3528955	et	3	main
ma	doc_491521501714_item	3528959	et	3	main
selles	doc_491521501714_item	3528971	et	4	main
kauplus	doc_491521501714_item	3528972	et	3	main
sina	doc_491521501714_item	3528985	et	4	main
kaupluses	doc_491521501716_item	3529070	et	3	main
ehituse	doc_491521501716_item	3529071	et	4	main
abc	doc_491521501716_item	3529072	et	4	main
ma	doc_491521501716_item	3529073	et	3	main
olen	doc_491521501716_item	3529074	et	3	main
töötama	doc_491521501716_item	3529075	et	3	main
klientiga	doc_491521501716_item	3529076	et	4	main
see	doc_491521501716_item	3529077	et	3	main
kauplus	doc_491521501716_item	3529078	et	3	main
müüma	doc_491521501716_item	3529079	et	3	main
ehituse	doc_491521501716_item	3529080	et	4	main
kaubad	doc_491521501716_item	3529081	et	3	main
mulle	doc_491521501716_item	3529082	et	4	main
meeldib	doc_491521501716_item	3529083	et	3	main
see	doc_491521501716_item	3529084	et	3	main
kauplus	doc_491521501716_item	3529085	et	3	main
tervita	doc_491521501716_item	3529086	et	4	main
oma	doc_491521501716_item	3529087	et	4	main
perekonda	doc_491521501716_item	3529088	et	4	main
eesnimi	doc_491521501716_item	3529089	et	3	main
sõbrale	doc_491521501716_item	3528997	et	3	main
kursustel	doc_491521501716_item	3529009	et	3	main
õppisid	doc_491521501716_item	3529014	et	4	main
sa	doc_491521501716_item	3529016	et	3	main
praktikale	doc_491521501716_item	3529017	et	3	main
tegeleb	doc_491521501716_item	3529022	et	3	main
mida	doc_491521501716_item	3529024	et	4	main
ma	doc_491521501716_item	3529047	et	3	main
arvutiõpelus	doc_491521501716_item	3529049	et	4	main
praktika	doc_491521501716_item	3529062	et	4	main
30102003	doc_491521501716_item	3529064	et	2	main
lähen	doc_491521501716_item	3529067	et	3	main
praktikale	doc_491521501716_item	3529068	et	3	main
suur	doc_491521501716_item	3529069	et	3	main
eestlasest	doc_491521501718_item	3529095	et	3	main
saa	doc_491521501718_item	3529098	et	4	main
sa	doc_491521501718_item	3529115	et	3	main
inna	doc_491521501718_item	3529131	et	3	main
kirja	doc_491521501718_item	3529135	et	4	main
elan	doc_491521501718_item	3529137	et	3	main
ma	doc_491521501718_item	3529140	et	3	main
eesti	doc_491521501718_item	3529142	et	4	main
seal	doc_491521501718_item	3529162	et	4	main
ma	doc_491521501718_item	3529163	et	3	main
loen	doc_491521501718_item	3529164	et	3	main
õppinu	doc_491521501718_item	3529165	et	4	main
e	doc_491521501718_item	3529166	et	4	main
kohe	doc_491521501718_item	3529179	et	4	main
asub	doc_491521501718_item	3529180	et	3	main
hulgiladus	doc_491521501718_item	3529181	et	3	main
see	doc_491521501718_item	3529182	et	3	main
kolm	doc_491521501718_item	3529188	et	3	main
mulle	doc_491521501718_item	3529214	et	4	main
ma	doc_491521501718_item	3529215	et	3	main
head	doc_491521501718_item	3529219	et	4	main
sind	doc_491521501718_item	3529221	et	4	main
25102003	doc_491521501718_item	3529226	et	2	main
nimi	doc_744962874521_item	3529232	et	3	main
eesnimi	doc_744962874521_item	3529234	et	3	main
olen	doc_744962874521_item	3529236	et	3	main
kõige	doc_744962874521_item	3529239	et	4	main
eesti	doc_744962874521_item	3529253	et	4	main
keelt	doc_744962874521_item	3529254	et	4	main
olen	doc_744962874521_item	3529255	et	3	main
ainult	doc_744962874521_item	3529262	et	4	main
põhjus	doc_744962874521_item	3529266	et	4	main
miks	doc_744962874521_item	3529267	et	4	main
tulin	doc_744962874521_item	3529268	et	3	main
rääkida	doc_744962874521_item	3529277	et	3	main
eesti	doc_744962874521_item	3529278	et	4	main
keel	doc_744962874521_item	3529291	et	4	main
mul	doc_744962874521_item	3529292	et	3	main
erinevad	doc_744962874521_item	3529298	et	4	main
ma	doc_744962874521_item	3529332	et	3	main
tahaksin	doc_744962874521_item	3529333	et	3	main
on	doc_901133458139_item	3529364	et	4	main
eesnimi	doc_901133458139_item	3529365	et	3	main
olen	doc_901133458139_item	3529366	et	3	main
üheksateist	doc_901133458139_item	3529367	et	4	main
aastat	doc_901133458139_item	3529368	et	3	main
vana	doc_901133458139_item	3529369	et	4	main
minu	doc_901133458139_item	3529372	et	3	main
õppimine	doc_901133458139_item	3529375	et	4	main
kolmteist	doc_901133458139_item	3529384	et	4	main
aastat	doc_901133458139_item	3529385	et	3	main
esimene	doc_901133458139_item	3529391	et	3	main
sellele	doc_901133458139_item	3529395	et	4	main
saada	doc_901133458139_item	3529402	et	4	main
et	doc_901133458139_item	3529409	et	3	main
ajaleht	doc_901133458139_item	3529411	et	3	main
tahan	doc_901133458139_item	3529413	et	3	main
ma	doc_901133458139_item	3529423	et	3	main
me	doc_901133458139_item	3529426	et	4	main
eesti	doc_901133458139_item	3529429	et	4	main
keelega	doc_901133458139_item	3529430	et	3	main
ma	doc_901133458139_item	3529431	et	3	main
kardan	doc_901133458139_item	3529432	et	4	main
raske	doc_901133458139_item	3529438	et	4	main
ma	doc_901133458139_item	3529439	et	3	main
nad	doc_491521501718_item	3529193	et	3	main
vastavad	doc_491521501718_item	3529194	et	4	main
minna	doc_491521501718_item	3529196	et	3	main
laskma	doc_491521501718_item	3529197	et	3	main
toiduained	doc_491521501718_item	3529198	et	3	main
see	doc_491521501718_item	3529199	et	3	main
ja	doc_491521501718_item	3529195	et	3	main
praktika	doc_491521501718_item	3529200	et	4	main
on	doc_491521501718_item	3529201	et	4	main
kasulik	doc_491521501718_item	3529202	et	3	main
mulle-	doc_491521501718_item	3529203	et	4	main
inna	doc_491521501718_item	3529204	et	3	main
tule	doc_491521501718_item	3529205	et	4	main
mulle	doc_491521501718_item	3529206	et	4	main
kiri	doc_491521501718_item	3529092	et	3	main
praktikale	doc_491521501718_item	3529104	et	3	main
kuidas	doc_491521501718_item	3529106	et	3	main
läks	doc_491521501718_item	3529109	et	3	main
kuhu	doc_491521501718_item	3529114	et	3	main
praktikale	doc_491521501718_item	3529116	et	3	main
sõbrana	doc_491521501718_item	3529130	et	3	main
keele	doc_491521501718_item	3529143	et	4	main
päev	doc_491521501718_item	3529151	et	3	main
kulturimajsse	doc_491521501718_item	3529154	et	4	main
830	doc_491521501718_item	3529156	et	2	main
koos	doc_491521501718_item	3529171	et	4	main
pean	doc_491521501718_item	3529174	et	4	main
käin	doc_491521501718_item	3529175	et	3	main
praktikale	doc_491521501718_item	3529176	et	3	main
minul	doc_491521501718_item	3529177	et	3	main
praktika	doc_491521501718_item	3529178	et	4	main
tal	doc_491521501718_item	3529186	et	3	main
üks	doc_491521501718_item	3529191	et	3	main
mees	doc_491521501718_item	3529192	et	4	main
mulle	doc_491521501718_item	3529209	et	4	main
ka	doc_491521501718_item	3529210	et	3	main
kirja	doc_491521501718_item	3529211	et	4	main
aga	doc_491521501718_item	3529212	et	3	main
helistab	doc_491521501718_item	3529213	et	3	main
suudledes	doc_491521501718_item	3529222	et	4	main
kallistades	doc_491521501718_item	3529223	et	3	main
sinu	doc_491521501718_item	3529224	et	3	main
eesnimi	doc_491521501718_item	3529225	et	3	main
minu	doc_744962874521_item	3529231	et	3	main
a	doc_744962874521_item	3529238	et	4	main
varem	doc_744962874521_item	3529259	et	4	main
osata	doc_744962874521_item	3529273	et	4	main
teine	doc_744962874521_item	3529280	et	3	main
eestis	doc_744962874521_item	3529286	et	3	main
keelt	doc_744962874521_item	3529295	et	4	main
vaja	doc_744962874521_item	3529296	et	4	main
et	doc_744962874521_item	3529297	et	3	main
raadiopt	doc_744962874521_item	3529302	et	4	main
tegeleme	doc_744962874521_item	3529321	et	3	main
ma	doc_744962874521_item	3529324	et	3	main
tean	doc_744962874521_item	3529329	et	3	main
kiri	doc_901133458139_item	3529359	et	3	main
on	doc_901133458139_item	3529374	et	4	main
varem	doc_901133458139_item	3529386	et	4	main
olen	doc_901133458139_item	3529387	et	3	main
õppinud	doc_901133458139_item	3529388	et	4	main
miks	doc_901133458139_item	3529393	et	4	main
kursusele	doc_901133458139_item	3529396	et	3	main
kõrgharidus	doc_901133458139_item	3529398	et	3	main
teine	doc_901133458139_item	3529399	et	3	main
mul	doc_901133458139_item	3529404	et	3	main
eesti	doc_901133458139_item	3529406	et	4	main
eesti	doc_901133458139_item	3529415	et	4	main
eesti	doc_901133458139_item	3529435	et	4	main
tere	doc_901133458142_item	3529452	et	3	main
eesnimi	doc_901133458142_item	3529457	et	3	main
kõige	doc_901133458142_item	3529462	et	4	main
keelt	doc_901133458142_item	3529472	et	4	main
10	doc_901133458142_item	3529475	et	2	main
varem	doc_901133458142_item	3529477	et	4	main
keelt	doc_901133458142_item	3529503	et	4	main
vaja	doc_901133458142_item	3529504	et	4	main
et	doc_901133458142_item	3529505	et	3	main
eesti	doc_901133458142_item	3529512	et	4	main
sadet	doc_901133458142_item	3529513	et	3	main
rääkida	doc_901133458142_item	3529516	et	3	main
mul	doc_901133458142_item	3529519	et	3	main
huvitav	doc_901133458142_item	3529521	et	4	main
ma	doc_901133458142_item	3529522	et	3	main
tahan	doc_901133458142_item	3529523	et	3	main
kirjutada	doc_901133458142_item	3529524	et	3	main
sõbrali	doc_901133458142_item	3529525	et	4	main
põhjalikult	doc_901133458142_item	3529540	et	4	main
venesatele	doc_901133458142_item	3529551	et	4	main
eestlasest	doc_901133458191_item	3529572	et	3	main
käid	doc_901133458191_item	3529575	et	3	main
mida	doc_901133458191_item	3529579	et	4	main
kursustel	doc_901133458191_item	3529581	et	3	main
et	doc_901133458191_item	3529584	et	3	main
varsti	doc_901133458191_item	3529585	et	3	main
lähete	doc_901133458191_item	3529586	et	4	main
praktikale	doc_901133458191_item	3529587	et	3	main
mis	doc_901133458191_item	3529593	et	4	main
ma	doc_744962874521_item	3529307	et	3	main
tahan	doc_744962874521_item	3529308	et	3	main
rääkida	doc_744962874521_item	3529309	et	3	main
eestlastega	doc_744962874521_item	3529310	et	4	main
sest	doc_744962874521_item	3529311	et	4	main
et	doc_744962874521_item	3529312	et	3	main
tahan	doc_744962874521_item	3529313	et	3	main
eestlastest	doc_744962874521_item	3529314	et	4	main
aru	doc_744962874521_item	3529315	et	4	main
saada	doc_744962874521_item	3529316	et	4	main
tere	doc_744962874521_item	3529229	et	3	main
on	doc_744962874521_item	3529233	et	4	main
tähtsam	doc_744962874521_item	3529240	et	4	main
minu	doc_744962874521_item	3529241	et	3	main
elus	doc_744962874521_item	3529242	et	4	main
on	doc_744962874521_item	3529243	et	4	main
minu	doc_744962874521_item	3529244	et	3	main
perekond	doc_744962874521_item	3529245	et	3	main
haridus	doc_744962874521_item	3529246	et	3	main
ma	doc_744962874521_item	3529247	et	3	main
armastan	doc_744962874521_item	3529248	et	3	main
lugeda	doc_744962874521_item	3529249	et	3	main
ajalehte	doc_744962874521_item	3529250	et	4	main
ja	doc_744962874521_item	3529251	et	3	main
raamatuid	doc_744962874521_item	3529252	et	3	main
olen	doc_744962874521_item	3529260	et	3	main
õppinud	doc_744962874521_item	3529261	et	4	main
keel	doc_744962874521_item	3529264	et	4	main
eesti	doc_744962874521_item	3529274	et	4	main
keelt	doc_744962874521_item	3529275	et	4	main
et	doc_744962874521_item	3529276	et	3	main
põhjus	doc_744962874521_item	3529281	et	4	main
et	doc_744962874521_item	3529283	et	3	main
ma	doc_744962874521_item	3529284	et	3	main
et	doc_744962874521_item	3529287	et	3	main
on	doc_744962874521_item	3529289	et	4	main
eesti	doc_744962874521_item	3529290	et	4	main
ja	doc_744962874521_item	3529301	et	3	main
rääkivad	doc_744962874521_item	3529303	et	4	main
eesti	doc_744962874521_item	3529305	et	4	main
keeles	doc_744962874521_item	3529306	et	4	main
ma	doc_744962874521_item	3529317	et	3	main
loodan	doc_744962874521_item	3529318	et	3	main
et	doc_744962874521_item	3529327	et	3	main
ma	doc_744962874521_item	3529328	et	3	main
kas	doc_744962874521_item	3529335	et	3	main
meeldib	doc_744962874521_item	3529337	et	3	main
tere	doc_901133458139_item	3529360	et	3	main
tahtsam	doc_901133458139_item	3529371	et	4	main
lugeda	doc_901133458139_item	3529378	et	3	main
eesti	doc_901133458139_item	3529380	et	4	main
keelt	doc_901133458139_item	3529381	et	4	main
olen	doc_901133458139_item	3529382	et	3	main
ahtme	doc_901133458139_item	3529389	et	4	main
tulin	doc_901133458139_item	3529394	et	3	main
on	doc_901133458139_item	3529397	et	4	main
põhjus	doc_901133458139_item	3529400	et	4	main
vaja	doc_901133458139_item	3529408	et	4	main
kuulata	doc_901133458139_item	3529414	et	4	main
raadio	doc_901133458139_item	3529416	et	4	main
ma	doc_901133458139_item	3529417	et	3	main
tahan	doc_901133458139_item	3529418	et	3	main
rääkida	doc_901133458139_item	3529419	et	3	main
oma	doc_901133458139_item	3529420	et	4	main
tegeleme	doc_901133458139_item	3529427	et	3	main
keelt	doc_901133458139_item	3529436	et	4	main
kiri	doc_901133458142_item	3529451	et	3	main
nimi	doc_901133458142_item	3529455	et	3	main
perekonnanimi	doc_901133458142_item	3529458	et	3	main
olen	doc_901133458142_item	3529459	et	3	main
22aastat	doc_901133458142_item	3529460	et	3	main
vana	doc_901133458142_item	3529461	et	4	main
pere	doc_901133458142_item	3529467	et	4	main
ma	doc_901133458142_item	3529468	et	3	main
õppinud	doc_901133458142_item	3529479	et	4	main
eesti	doc_901133458142_item	3529502	et	4	main
radio	doc_901133458142_item	3529511	et	4	main
estlastega	doc_901133458142_item	3529517	et	4	main
et	doc_901133458142_item	3529518	et	3	main
on	doc_901133458142_item	3529520	et	4	main
ma	doc_901133458142_item	3529529	et	3	main
et	doc_901133458142_item	3529531	et	3	main
tegelema	doc_901133458142_item	3529533	et	3	main
ma	doc_901133458142_item	3529535	et	3	main
loodan	doc_901133458142_item	3529536	et	3	main
et	doc_901133458142_item	3529537	et	3	main
me	doc_901133458142_item	3529538	et	4	main
tegeleme	doc_901133458142_item	3529539	et	3	main
lugemistega	doc_901133458142_item	3529544	et	4	main
see	doc_901133458142_item	3529549	et	3	main
halvasti	doc_744962874521_item	3529330	et	3	main
teada	doc_744962874521_item	3529334	et	3	main
töötada	doc_744962874521_item	3529338	et	3	main
k-i	doc_744962874521_item	3529339	et	4	main
polõtehnikumis	doc_744962874521_item	3529340	et	4	main
ja	doc_744962874521_item	3529341	et	3	main
jutustage	doc_744962874521_item	3529342	et	3	main
mulle	doc_744962874521_item	3529343	et	4	main
palun	doc_744962874521_item	3529344	et	3	main
kuidas	doc_744962874521_item	3529345	et	3	main
teie	doc_744962874521_item	3529346	et	4	main
meeldib	doc_744962874521_item	3529347	et	3	main
puhata	doc_744962874521_item	3529348	et	4	main
ja	doc_744962874521_item	3529349	et	3	main
kus	doc_744962874521_item	3529350	et	3	main
loodan	doc_744962874521_item	3529351	et	3	main
et	doc_744962874521_item	3529352	et	3	main
te	doc_744962874521_item	3529353	et	4	main
vastate	doc_744962874521_item	3529354	et	3	main
mulle	doc_744962874521_item	3529355	et	4	main
lugupidamisega	doc_744962874521_item	3529356	et	3	main
ep	doc_744962874521_item	3529357	et	3	main
elus	doc_901133458139_item	3529373	et	4	main
ma	doc_901133458139_item	3529376	et	3	main
armastan	doc_901133458139_item	3529377	et	3	main
ramatud	doc_901133458139_item	3529379	et	4	main
gümnaasiumi	doc_901133458139_item	3529390	et	4	main
on	doc_901133458139_item	3529401	et	4	main
on	doc_901133458139_item	3529405	et	4	main
keelt	doc_901133458139_item	3529407	et	4	main
loodan	doc_901133458139_item	3529424	et	3	main
natuke	doc_901133458139_item	3529433	et	4	main
et	doc_901133458139_item	3529434	et	3	main
tahaksin	doc_901133458139_item	3529440	et	3	main
teda	doc_901133458139_item	3529441	et	4	main
kõike	doc_901133458139_item	3529442	et	4	main
eestist	doc_901133458139_item	3529443	et	3	main
loodan	doc_901133458139_item	3529444	et	3	main
et	doc_901133458139_item	3529445	et	3	main
me	doc_901133458139_item	3529446	et	4	main
kohtume	doc_901133458139_item	3529447	et	3	main
eesnimi	doc_901133458139_item	3529448	et	3	main
perekonnanimi	doc_901133458139_item	3529449	et	3	main
õpetaja	doc_901133458139_item	3529361	et	4	main
minu	doc_901133458139_item	3529362	et	3	main
nimi	doc_901133458139_item	3529363	et	3	main
kõige	doc_901133458139_item	3529370	et	4	main
õppinud	doc_901133458139_item	3529383	et	4	main
põhjus	doc_901133458139_item	3529392	et	4	main
eriala	doc_901133458139_item	3529403	et	4	main
lugeda	doc_901133458139_item	3529410	et	3	main
ma	doc_901133458139_item	3529412	et	3	main
eesti	doc_901133458139_item	3529421	et	4	main
sõpradega	doc_901133458139_item	3529422	et	3	main
et	doc_901133458139_item	3529425	et	3	main
põhjalikult	doc_901133458139_item	3529428	et	4	main
on	doc_901133458139_item	3529437	et	4	main
õpetaja	doc_901133458142_item	3529453	et	4	main
on	doc_901133458142_item	3529456	et	4	main
on	doc_901133458142_item	3529465	et	4	main
minu	doc_901133458142_item	3529466	et	3	main
armastan	doc_901133458142_item	3529469	et	3	main
on	doc_901133458142_item	3529501	et	4	main
mul	doc_901133458142_item	3529507	et	3	main
kuulata	doc_901133458142_item	3529510	et	4	main
tahan	doc_901133458142_item	3529515	et	3	main
elan	doc_901133458142_item	3529528	et	3	main
me	doc_901133458142_item	3529532	et	4	main
põhjalikult	doc_901133458142_item	3529534	et	4	main
suuliste	doc_901133458142_item	3529541	et	4	main
ülesanneteg	doc_901133458142_item	3529542	et	4	main
kardan	doc_901133458142_item	3529546	et	4	main
natuke	doc_901133458142_item	3529547	et	4	main
raske	doc_901133458142_item	3529550	et	4	main
kuidas	doc_901133458142_item	3529555	et	3	main
melde	doc_901133458142_item	3529557	et	4	main
sõnad	doc_901133458142_item	3529559	et	4	main
loodan	doc_901133458142_item	3529560	et	3	main
et	doc_901133458142_item	3529561	et	3	main
ma	doc_901133458142_item	3529562	et	3	main
kirjutasin	doc_901133458142_item	3529563	et	3	main
õigesti	doc_901133458142_item	3529564	et	3	main
lugupidamisega	doc_901133458142_item	3529565	et	3	main
eesnimi	doc_901133458142_item	3529566	et	3	main
perekonnanimi	doc_901133458142_item	3529567	et	3	main
oma	doc_901133458191_item	3529571	et	4	main
kursustel	doc_901133458191_item	3529577	et	3	main
õpid	doc_901133458191_item	3529582	et	4	main
ja	doc_901133458191_item	3529583	et	3	main
praktikale	doc_901133458191_item	3529591	et	3	main
on	doc_901133458191_item	3529596	et	4	main
käin	doc_901133458191_item	3529610	et	3	main
klienditeenindaja	doc_901133458191_item	3529616	et	4	main
me	doc_901133458191_item	3529622	et	4	main
õppisime	doc_901133458191_item	3529623	et	3	main
olen	doc_901133458191_item	3529667	et	3	main
tervides	doc_901133458191_item	3529701	et	4	main
teatama	doc_491521502048_item	3529715	et	4	main
kauplus	doc_491521502048_item	3529724	et	3	main
müüjavad	doc_491521502048_item	3529727	et	4	main
pesu	doc_491521502048_item	3529730	et	4	main
mule	doc_491521502048_item	3529736	et	4	main
kõik	doc_491521502048_item	3529745	et	4	main
seial	doc_491521502048_item	3529746	et	4	main
ostan	doc_491521502048_item	3529747	et	3	main
sis	doc_491521502048_item	3529754	et	3	main
lõpima	doc_491521502048_item	3529756	et	4	main
sule	doc_491521502048_item	3529805	et	4	main
vel	doc_491521502048_item	3529810	et	4	main
tere	doc_491521502050_item	3529826	et	3	main
elan	doc_491521502050_item	3529835	et	3	main
mul	doc_491521502050_item	3529838	et	3	main
keel	doc_491521502050_item	3529862	et	4	main
kaheksast	doc_491521502050_item	3529863	et	4	main
puuvilja	doc_491521502050_item	3529871	et	4	main
on	doc_491521502050_item	3529884	et	4	main
me	doc_491521502050_item	3529891	et	4	main
läheme	doc_491521502050_item	3529892	et	3	main
kirjua	doc_491521502050_item	3529905	et	4	main
teada	doc_491521502066_item	3529946	et	3	main
pood	doc_491521502066_item	3529952	et	4	main
ta	doc_491521502066_item	3529955	et	4	main
on	doc_491521502066_item	3529956	et	4	main
kauplus	doc_491521502066_item	3529958	et	3	main
suur	doc_491521502066_item	3529971	et	3	main
aga	doc_491521502066_item	3529973	et	3	main
meldib	doc_491521502066_item	3529975	et	4	main
ja	doc_491521502066_item	3529987	et	3	main
eesti	doc_901133458142_item	3529471	et	4	main
olen	doc_901133458142_item	3529473	et	3	main
aastat	doc_901133458142_item	3529476	et	3	main
olen	doc_901133458142_item	3529478	et	3	main
saksa	doc_901133458142_item	3529480	et	4	main
keelt	doc_901133458142_item	3529481	et	4	main
esimene	doc_901133458142_item	3529482	et	3	main
põhjus	doc_901133458142_item	3529483	et	4	main
miks	doc_901133458142_item	3529484	et	4	main
tulin	doc_901133458142_item	3529485	et	3	main
sellele	doc_901133458142_item	3529486	et	4	main
kursusele	doc_901133458142_item	3529487	et	3	main
on	doc_901133458142_item	3529488	et	4	main
seleparast	doc_901133458142_item	3529489	et	4	main
ma	doc_901133458142_item	3529490	et	3	main
õpisin	doc_901133458142_item	3529491	et	4	main
varem	doc_901133458142_item	3529492	et	4	main
sellele	doc_901133458142_item	3529493	et	4	main
kursusele	doc_901133458142_item	3529494	et	3	main
teine	doc_901133458142_item	3529495	et	3	main
põhjus	doc_901133458142_item	3529496	et	4	main
on	doc_901133458142_item	3529497	et	4	main
kõrg	doc_901133458142_item	3529498	et	4	main
haridus	doc_901133458142_item	3529499	et	3	main
on	doc_901133458142_item	3529508	et	4	main
minu	doc_901133458142_item	3529454	et	3	main
tähtsam	doc_901133458142_item	3529463	et	4	main
minu	doc_901133458142_item	3529464	et	3	main
reisima	doc_901133458142_item	3529470	et	3	main
õppinud	doc_901133458142_item	3529474	et	4	main
mul	doc_901133458142_item	3529500	et	3	main
lugeda	doc_901133458142_item	3529506	et	3	main
ma	doc_901133458142_item	3529514	et	3	main
ma	doc_901133458142_item	3529527	et	3	main
loodan	doc_901133458142_item	3529530	et	3	main
ja	doc_901133458142_item	3529543	et	3	main
ma	doc_901133458142_item	3529552	et	3	main
parempi	doc_901133458142_item	3529556	et	4	main
jatma	doc_901133458142_item	3529558	et	4	main
vaja	doc_901133458142_item	3529509	et	4	main
kuidas	doc_901133458142_item	3529526	et	3	main
ma	doc_901133458142_item	3529545	et	3	main
et	doc_901133458142_item	3529548	et	3	main
tahaksin	doc_901133458142_item	3529553	et	3	main
kiri	doc_901133458191_item	3529569	et	3	main
et	doc_901133458191_item	3529574	et	3	main
praegu	doc_901133458191_item	3529576	et	3	main
kirjuta	doc_901133458191_item	3529588	et	4	main
sa	doc_901133458191_item	3529590	et	3	main
sõbranna	doc_901133458191_item	3529604	et	4	main
aitäh	doc_901133458191_item	3529605	et	3	main
sinule	doc_901133458191_item	3529606	et	3	main
kirja	doc_901133458191_item	3529607	et	4	main
praegu	doc_901133458191_item	3529611	et	3	main
nimi	doc_901133458191_item	3529614	et	3	main
ettevõttealuseid	doc_901133458191_item	3529630	et	4	main
praktika	doc_901133458191_item	3529652	et	4	main
aidu	doc_901133458191_item	3529654	et	4	main
karjääris	doc_901133458191_item	3529655	et	3	main
direktori	doc_901133458191_item	3529656	et	3	main
sekretäril	doc_901133458191_item	3529657	et	3	main
on	doc_901133458191_item	3529658	et	4	main
ja	doc_901133458191_item	3529663	et	3	main
arvan	doc_901133458191_item	3529664	et	3	main
teda	doc_901133458191_item	3529668	et	4	main
teada	doc_901133458142_item	3529554	et	3	main
kirjuta	doc_901133458191_item	3529570	et	4	main
lähed	doc_901133458191_item	3529592	et	3	main
firma	doc_901133458191_item	3529594	et	4	main
mida	doc_901133458191_item	3529597	et	4	main
sa	doc_901133458191_item	3529598	et	3	main
seal	doc_901133458191_item	3529599	et	4	main
eest	doc_901133458191_item	3529608	et	4	main
psühholoogiat	doc_901133458191_item	3529625	et	3	main
keelt	doc_901133458191_item	3529633	et	4	main
arvan	doc_901133458191_item	3529634	et	3	main
et	doc_901133458191_item	3529635	et	3	main
leidsin	doc_901133458191_item	3529651	et	3	main
kohta	doc_901133458191_item	3529653	et	4	main
lõpus	doc_901133458191_item	3529662	et	4	main
et	doc_901133458191_item	3529665	et	3	main
abistada	doc_901133458191_item	3529669	et	3	main
ma	doc_901133458191_item	3529670	et	3	main
hakkan	doc_901133458191_item	3529671	et	3	main
töötama	doc_901133458191_item	3529672	et	3	main
dokumentidega	doc_901133458191_item	3529673	et	3	main
ja	doc_901133458191_item	3529674	et	3	main
arvutiga	doc_901133458191_item	3529675	et	4	main
kuidas	doc_901133458191_item	3529676	et	3	main
sa	doc_901133458191_item	3529677	et	3	main
arvad	doc_901133458191_item	3529678	et	3	main
ma	doc_901133458191_item	3529679	et	3	main
olen	doc_901133458191_item	3529680	et	3	main
hea	doc_901133458191_item	3529681	et	4	main
sekretär	doc_901133458191_item	3529682	et	3	main
lõpetan	doc_901133458191_item	3529683	et	3	main
oma	doc_901133458191_item	3529684	et	4	main
kirja	doc_901133458191_item	3529685	et	4	main
kirjuta	doc_901133458191_item	3529686	et	4	main
mind	doc_901133458191_item	3529687	et	4	main
mida	doc_901133458191_item	3529688	et	4	main
sa	doc_901133458191_item	3529689	et	3	main
teed	doc_901133458191_item	3529690	et	4	main
kuidas	doc_901133458191_item	3529691	et	3	main
sinu	doc_901133458191_item	3529692	et	3	main
tervis	doc_901133458191_item	3529693	et	3	main
on	doc_901133458191_item	3529694	et	4	main
head	doc_901133458191_item	3529695	et	4	main
aega	doc_901133458191_item	3529696	et	4	main
jään	doc_901133458191_item	3529697	et	3	main
ootama	doc_901133458191_item	3529698	et	3	main
sinult	doc_901133458191_item	3529699	et	3	main
kirja	doc_901133458191_item	3529700	et	4	main
me	doc_901133458191_item	3529647	et	4	main
läheme	doc_901133458191_item	3529648	et	3	main
praktikale	doc_901133458191_item	3529649	et	3	main
ma	doc_901133458191_item	3529650	et	3	main
sõbrale	doc_901133458191_item	3529573	et	3	main
kirjuta	doc_901133458191_item	3529578	et	4	main
sa	doc_901133458191_item	3529580	et	3	main
kuhu	doc_901133458191_item	3529589	et	3	main
tegema	doc_901133458191_item	3529600	et	3	main
hakkad	doc_901133458191_item	3529601	et	3	main
ma	doc_901133458191_item	3529609	et	3	main
kursuste	doc_901133458191_item	3529613	et	3	main
arvutiõpetust	doc_901133458191_item	3529624	et	3	main
asjajamist	doc_901133458191_item	3529626	et	4	main
töökaitset	doc_901133458191_item	3529627	et	4	main
tööseadusandluse	doc_901133458191_item	3529628	et	3	main
minu	doc_901133458191_item	3529636	et	3	main
eesti	doc_901133458191_item	3529637	et	4	main
keel	doc_901133458191_item	3529638	et	4	main
on	doc_901133458191_item	3529639	et	4	main
parem	doc_901133458191_item	3529640	et	4	main
praegu	doc_901133458191_item	3529641	et	3	main
kuidas	doc_901133458191_item	3529642	et	3	main
sa	doc_901133458191_item	3529643	et	3	main
arvad	doc_901133458191_item	3529644	et	3	main
esimesest	doc_901133458191_item	3529645	et	3	main
detsembrist	doc_901133458191_item	3529646	et	3	main
palju	doc_901133458191_item	3529659	et	4	main
tööd	doc_901133458191_item	3529660	et	4	main
ma	doc_901133458191_item	3529666	et	3	main
kiri	doc_491521502048_item	3529704	et	3	main
eesnimi	doc_491521502048_item	3529706	et	3	main
sinu	doc_491521502048_item	3529708	et	3	main
suur	doc_491521502048_item	3529710	et	3	main
tahan	doc_491521502048_item	3529713	et	3	main
seal	doc_491521502048_item	3529725	et	4	main
toidud	doc_491521502048_item	3529735	et	3	main
se	doc_491521502048_item	3529739	et	4	main
lahen	doc_491521502048_item	3529741	et	4	main
se	doc_491521502048_item	3529742	et	4	main
ja	doc_491521502048_item	3529748	et	3	main
kirjutama	doc_491521502048_item	3529806	et	3	main
seal	doc_491521502048_item	3529808	et	4	main
sõbrale	doc_491521502050_item	3529828	et	3	main
kirjutan	doc_491521502050_item	3529831	et	3	main
ma	doc_491521502050_item	3529834	et	3	main
seal	doc_491521502050_item	3529865	et	4	main
vaga	doc_491521502050_item	3529885	et	4	main
hästi	doc_491521502050_item	3529886	et	3	main
eesnimi	doc_491521502050_item	3529887	et	3	main
koos	doc_491521502050_item	3529893	et	4	main
kingitus	doc_491521502050_item	3529899	et	4	main
lapsud	doc_491521502050_item	3529901	et	3	main
26092003	doc_491521502050_item	3529933	et	2	main
kiri	doc_491521502066_item	3529935	et	3	main
nataša	doc_491521502066_item	3529937	et	2	main
kätte	doc_491521502066_item	3529939	et	4	main
kirja	doc_491521502066_item	3529941	et	4	main
tahan	doc_491521502066_item	3529944	et	3	main
linnas	doc_491521502066_item	3529948	et	4	main
toidu	doc_491521502066_item	3529957	et	3	main
on	doc_491521502066_item	3529978	et	4	main
puurvili	doc_491521502066_item	3529984	et	3	main
ja	doc_491521502066_item	3529985	et	3	main
juurvili	doc_491521502066_item	3529986	et	3	main
muud	doc_491521502066_item	3529989	et	4	main
kui	doc_491521502066_item	3529996	et	3	main
eesnimi	doc_491521501668_item	3530047	et	3	main
elukoha	doc_491521501668_item	3530063	et	4	main
vieni	doc_491521501668_item	3530081	et	4	main
väike	doc_491521501668_item	3530085	et	4	main
seal	doc_491521501668_item	3530087	et	4	main
on	doc_491521501668_item	3530088	et	4	main
osakond	doc_491521501668_item	3530093	et	3	main
veel	doc_491521501668_item	3530095	et	4	main
see	doc_901133458191_item	3529595	et	3	main
tere	doc_901133458191_item	3529602	et	3	main
kallis	doc_901133458191_item	3529603	et	4	main
kursustel	doc_901133458191_item	3529612	et	3	main
on	doc_901133458191_item	3529615	et	4	main
kursused	doc_901133458191_item	3529617	et	3	main
algas	doc_901133458191_item	3529618	et	3	main
juba	doc_901133458191_item	3529619	et	3	main
viieteistkümnendal	doc_901133458191_item	3529620	et	4	main
septembril	doc_901133458191_item	3529621	et	3	main
aluseid	doc_901133458191_item	3529629	et	4	main
esmaabi	doc_901133458191_item	3529631	et	4	main
eesti	doc_901133458191_item	3529632	et	4	main
aasta	doc_901133458191_item	3529661	et	4	main
kiri	doc_491521502048_item	3529709	et	3	main
aitja	doc_491521502048_item	3529711	et	4	main
meil	doc_491521502048_item	3529717	et	4	main
ilus	doc_491521502048_item	3529723	et	4	main
vaga	doc_491521502048_item	3529737	et	4	main
hinad	doc_491521502048_item	3529749	et	4	main
on	doc_491521502048_item	3529750	et	4	main
akan	doc_491521502048_item	3529755	et	4	main
ilusaid	doc_491521502048_item	3529812	et	3	main
kiri	doc_491521502050_item	3529825	et	3	main
ma	doc_491521502050_item	3529830	et	3	main
eile	doc_491521502050_item	3529837	et	3	main
uus	doc_491521502050_item	3529841	et	3	main
ilus	doc_491521502050_item	3529844	et	4	main
abikasa	doc_491521502050_item	3529879	et	4	main
tegema	doc_491521502050_item	3529881	et	3	main
mulle	doc_491521502050_item	3529889	et	4	main
külla	doc_491521502050_item	3529890	et	4	main
ostame	doc_491521502050_item	3529898	et	3	main
ma	doc_491521502050_item	3529902	et	3	main
eesnimi	doc_491521502050_item	3529932	et	3	main
sain	doc_491521502066_item	3529938	et	3	main
avatud	doc_491521502066_item	3529949	et	4	main
see	doc_491521502066_item	3529951	et	3	main
anne	doc_491521502066_item	3529954	et	4	main
mida	doc_491521502066_item	3529962	et	4	main
sa	doc_491521502066_item	3529963	et	3	main
tahad	doc_491521502066_item	3529964	et	3	main
mulle	doc_491521502066_item	3529965	et	4	main
meldib	doc_491521502066_item	3529966	et	4	main
seal	doc_491521502066_item	3529967	et	4	main
osakond	doc_491521502066_item	3529968	et	3	main
valik	doc_491521502066_item	3529972	et	3	main
kommi	doc_491521502066_item	3529976	et	4	main
seal	doc_491521502066_item	3529977	et	4	main
juustm	doc_491521502066_item	3529983	et	4	main
ja	doc_491521502066_item	3529993	et	3	main
ta	doc_491521502066_item	3530001	et	4	main
aitah	doc_491521501668_item	3530053	et	4	main
sulle	doc_491521501668_item	3530054	et	3	main
oli	doc_491521501668_item	3530055	et	3	main
lähedal	doc_491521501668_item	3530064	et	4	main
avati	doc_491521501668_item	3530065	et	3	main
uus	doc_491521501668_item	3530066	et	3	main
suur	doc_491521501668_item	3530067	et	3	main
kauplus	doc_491521501668_item	3530068	et	3	main
kella	doc_491521501668_item	3530079	et	4	main
kodutexnika	doc_491521501668_item	3530090	et	4	main
lähen	doc_491521501668_item	3530099	et	3	main
suur	doc_491521501668_item	3530101	et	3	main
võtta	doc_491521501668_item	3530115	et	3	main
tule	doc_491521501668_item	3530120	et	4	main
kiri	doc_491521501711_item	3530150	et	3	main
sõbrale	doc_491521501711_item	3530154	et	3	main
saa	doc_491521501711_item	3530156	et	4	main
käid	doc_491521501711_item	3530157	et	3	main
kursustel	doc_491521501711_item	3530158	et	3	main
ja	doc_491521501711_item	3530159	et	3	main
varsti	doc_491521501711_item	3530160	et	3	main
lähed	doc_491521501711_item	3530161	et	3	main
praktikale	doc_491521501711_item	3530162	et	3	main
kursustel	doc_491521501711_item	3530166	et	3	main
tegeleb	doc_491521501711_item	3530179	et	3	main
ja	doc_491521501711_item	3530180	et	3	main
korras	doc_491521501711_item	3530200	et	4	main
ma	doc_491521501711_item	3530201	et	3	main
tahan	doc_491521501711_item	3530202	et	3	main
sulle	doc_491521501711_item	3530203	et	3	main
eesnimi	doc_901133458191_item	3529702	et	3	main
tere	doc_491521502048_item	3529705	et	3	main
sule	doc_491521502048_item	3529714	et	4	main
et	doc_491521502048_item	3529716	et	3	main
kohtla-jarvel	doc_491521502048_item	3529718	et	4	main
varsti	doc_491521502048_item	3529719	et	3	main
avatud	doc_491521502048_item	3529720	et	4	main
uus	doc_491521502048_item	3529721	et	3	main
suur	doc_491521502048_item	3529722	et	3	main
kõigist	doc_491521502048_item	3529728	et	4	main
asjad	doc_491521502048_item	3529729	et	3	main
rided	doc_491521502048_item	3529731	et	4	main
kingad	doc_491521502048_item	3529732	et	3	main
kosmetika	doc_491521502048_item	3529733	et	4	main
kauplusese	doc_491521502048_item	3529743	et	4	main
ja	doc_491521502048_item	3529744	et	3	main
vaga	doc_491521502048_item	3529751	et	4	main
oma	doc_491521502048_item	3529757	et	4	main
kiri	doc_491521502048_item	3529758	et	3	main
jään	doc_491521502048_item	3529759	et	3	main
et	doc_491521502048_item	3529807	et	3	main
müüjavad	doc_491521502048_item	3529809	et	4	main
manguasjad	doc_491521502048_item	3529813	et	4	main
võta	doc_491521502048_item	3529814	et	4	main
palun	doc_491521502048_item	3529815	et	3	main
kasa	doc_491521502048_item	3529816	et	4	main
oma	doc_491521502048_item	3529817	et	4	main
lapsed	doc_491521502048_item	3529818	et	3	main
nemad	doc_491521502048_item	3529819	et	3	main
olevad	doc_491521502048_item	3529820	et	4	main
õnnelik	doc_491521502048_item	3529821	et	3	main
260903	doc_491521502048_item	3529822	et	2	main
a	doc_491521502048_item	3529823	et	4	main
minust	doc_491521502050_item	3529827	et	3	main
kirja	doc_491521502050_item	3529833	et	4	main
avati	doc_491521502050_item	3529840	et	3	main
suur	doc_491521502050_item	3529842	et	3	main
on	doc_491521502050_item	3529866	et	4	main
odavad	doc_491521502050_item	3529867	et	3	main
kaubad	doc_491521502050_item	3529868	et	3	main
jurvilja	doc_491521502050_item	3529869	et	4	main
ja	doc_491521502050_item	3529870	et	3	main
autojaam	doc_491521502050_item	3529877	et	3	main
munu	doc_491521502050_item	3529878	et	4	main
mobilltelefoni	doc_491521502050_item	3529882	et	4	main
ta	doc_491521502050_item	3529883	et	4	main
ja	doc_491521502050_item	3529897	et	3	main
teie	doc_491521502050_item	3529900	et	4	main
ottan	doc_491521502050_item	3529903	et	4	main
sind	doc_491521502050_item	3529904	et	4	main
sinu	doc_491521502066_item	3529940	et	3	main
aitäh	doc_491521502066_item	3529942	et	3	main
sulle	doc_491521502066_item	3529943	et	3	main
sulle	doc_491521502066_item	3529945	et	3	main
kauplus	doc_491521502066_item	3529950	et	3	main
seal	doc_491521502066_item	3529959	et	4	main
müüaks	doc_491521502066_item	3529960	et	4	main
seal	doc_491521502066_item	3529970	et	4	main
sulle	doc_491521502066_item	3529974	et	3	main
juurde	doc_491521502066_item	3529992	et	4	main
rägi	doc_491521502066_item	3529994	et	4	main
hea	doc_491521502066_item	3529997	et	4	main
kaupluses	doc_491521502066_item	3529998	et	3	main
meid	doc_491521502066_item	3529999	et	4	main
kauplused	doc_491521502066_item	3530004	et	3	main
nad	doc_491521502066_item	3530005	et	3	main
ei	doc_491521502066_item	3530006	et	4	main
ja	doc_491521502048_item	3529786	et	3	main
suur	doc_491521502048_item	3529787	et	3	main
kauplus	doc_491521502048_item	3529788	et	3	main
olgu	doc_491521502048_item	3529789	et	3	main
sis	doc_491521502048_item	3529790	et	3	main
akan	doc_491521502048_item	3529791	et	4	main
lõpima	doc_491521502048_item	3529792	et	4	main
oma	doc_491521502048_item	3529793	et	4	main
kiri	doc_491521502048_item	3529794	et	3	main
jään	doc_491521502048_item	3529795	et	3	main
ootama	doc_491521502048_item	3529796	et	3	main
sinu	doc_491521502048_item	3529797	et	3	main
kiri	doc_491521502048_item	3529798	et	3	main
head	doc_491521502048_item	3529799	et	4	main
aega	doc_491521502048_item	3529800	et	4	main
eesnimi	doc_491521502048_item	3529801	et	3	main
nb	doc_491521502048_item	3529802	et	4	main
eesnimi	doc_491521502048_item	3529803	et	3	main
sain	doc_491521502048_item	3529707	et	3	main
sule	doc_491521502048_item	3529712	et	4	main
akavad	doc_491521502048_item	3529726	et	4	main
elektonika	doc_491521502048_item	3529734	et	4	main
meldib	doc_491521502048_item	3529738	et	4	main
kauplus	doc_491521502048_item	3529740	et	3	main
heiad	doc_491521502048_item	3529752	et	4	main
olgu	doc_491521502048_item	3529753	et	3	main
ootama	doc_491521502048_item	3529760	et	3	main
sinu	doc_491521502048_item	3529761	et	3	main
kiri	doc_491521502048_item	3529762	et	3	main
mina	doc_491521502048_item	3529763	et	4	main
tahsin	doc_491521502048_item	3529764	et	4	main
ka	doc_491521502048_item	3529765	et	3	main
se	doc_491521502048_item	3529766	et	4	main
kauplusese	doc_491521502048_item	3529767	et	4	main
töötama	doc_491521502048_item	3529768	et	3	main
mina	doc_491521502048_item	3529769	et	4	main
ivõibola	doc_491521502048_item	3529770	et	4	main
lahen	doc_491521502048_item	3529771	et	4	main
seal	doc_491521502048_item	3529772	et	4	main
on	doc_491521502048_item	3529773	et	4	main
vaga	doc_491521502048_item	3529774	et	4	main
hea	doc_491521502048_item	3529775	et	4	main
töötugrafik	doc_491521502048_item	3529776	et	4	main
tule	doc_491521502048_item	3529777	et	4	main
mule	doc_491521502048_item	3529778	et	4	main
ja	doc_491521502048_item	3529780	et	3	main
koos	doc_491521502048_item	3529781	et	4	main
küla	doc_491521502048_item	3529779	et	4	main
lahme	doc_491521502048_item	3529782	et	4	main
vatama	doc_491521502048_item	3529783	et	4	main
se	doc_491521502048_item	3529784	et	4	main
ilus	doc_491521502048_item	3529785	et	4	main
unustasin	doc_491521502048_item	3529804	et	3	main
palju	doc_491521502048_item	3529811	et	4	main
mulle	doc_491521502050_item	3529906	et	4	main
ka	doc_491521502050_item	3529907	et	3	main
kirja	doc_491521502050_item	3529908	et	4	main
aga	doc_491521502050_item	3529909	et	3	main
helista	doc_491521502050_item	3529910	et	4	main
mulle	doc_491521502050_item	3529911	et	4	main
munust	doc_491521502050_item	3529912	et	4	main
uu	doc_491521502050_item	3529913	et	3	main
number	doc_491521502050_item	3529914	et	3	main
telefoni	doc_491521502050_item	3529915	et	4	main
on	doc_491521502050_item	3529916	et	4	main
55	doc_491521502050_item	3529917	et	2	main
555	doc_491521502050_item	3529918	et	2	main
55	doc_491521502050_item	3529919	et	2	main
palun	doc_491521502050_item	3529920	et	3	main
tervitama	doc_491521502050_item	3529921	et	3	main
abigasa	doc_491521502050_item	3529922	et	4	main
ja	doc_491521502050_item	3529923	et	3	main
teie	doc_491521502050_item	3529924	et	4	main
lapsid	doc_491521502050_item	3529925	et	3	main
head	doc_491521502050_item	3529926	et	4	main
aega	doc_491521502050_item	3529927	et	4	main
sind	doc_491521502050_item	3529928	et	4	main
suudeldes	doc_491521502050_item	3529929	et	3	main
kallistades	doc_491521502050_item	3529930	et	3	main
sinu	doc_491521502050_item	3529931	et	3	main
eesnimi	doc_491521502050_item	3529829	et	3	main
sulle	doc_491521502050_item	3529832	et	3	main
hästi	doc_491521502050_item	3529836	et	3	main
elukoha	doc_491521502050_item	3529839	et	4	main
ja	doc_491521502050_item	3529843	et	3	main
kauplus	doc_491521502050_item	3529845	et	3	main
kauplusse	doc_491521502050_item	3529846	et	3	main
müüakse	doc_491521502050_item	3529847	et	3	main
palju	doc_491521502050_item	3529848	et	4	main
toidukaubad	doc_491521502050_item	3529849	et	3	main
ja	doc_491521502050_item	3529850	et	3	main
majakaubad	doc_491521502050_item	3529851	et	3	main
samuti	doc_491521502050_item	3529852	et	3	main
ka	doc_491521502050_item	3529853	et	3	main
müakse	doc_491521502050_item	3529854	et	4	main
kodutehnika	doc_491521502050_item	3529855	et	4	main
see	doc_491521502050_item	3529856	et	3	main
kauplus	doc_491521502050_item	3529857	et	3	main
mulle	doc_491521502050_item	3529858	et	4	main
meldib	doc_491521502050_item	3529859	et	4	main
sellepärast	doc_491521502050_item	3529860	et	3	main
töötab	doc_491521502050_item	3529861	et	3	main
kaheksani	doc_491521502050_item	3529864	et	3	main
alati	doc_491521502050_item	3529872	et	4	main
värske	doc_491521502050_item	3529873	et	4	main
kauplus	doc_491521502050_item	3529874	et	3	main
juures	doc_491521502050_item	3529875	et	4	main
asub	doc_491521502050_item	3529876	et	3	main
sisseosatb	doc_491521502050_item	3529880	et	4	main
tule	doc_491521502050_item	3529888	et	4	main
selle	doc_491521502050_item	3529894	et	4	main
uus	doc_491521502050_item	3529895	et	3	main
kauplus	doc_491521502050_item	3529896	et	3	main
lahme	doc_491521502066_item	3530017	et	4	main
poodi	doc_491521502066_item	3530018	et	4	main
ja	doc_491521502066_item	3530019	et	3	main
sa	doc_491521502066_item	3530020	et	3	main
isa	doc_491521502066_item	3530021	et	4	main
vaatad	doc_491521502066_item	3530022	et	3	main
ja	doc_491521502066_item	3530023	et	3	main
ütled	doc_491521502066_item	3530024	et	3	main
mulle	doc_491521502066_item	3530025	et	4	main
meldib	doc_491521502066_item	3530026	et	4	main
sulle	doc_491521502066_item	3530027	et	3	main
see	doc_491521502066_item	3530028	et	3	main
kauplus	doc_491521502066_item	3530029	et	3	main
või	doc_491521502066_item	3530030	et	4	main
ei	doc_491521502066_item	3530031	et	4	main
nu	doc_491521502066_item	3530032	et	4	main
olgu	doc_491521502066_item	3530033	et	3	main
ma	doc_491521502066_item	3530034	et	3	main
lõpin	doc_491521502066_item	3530035	et	4	main
oma	doc_491521502066_item	3530036	et	4	main
kiiri	doc_491521502066_item	3530037	et	4	main
otan	doc_491521502066_item	3530038	et	4	main
sinu	doc_491521502066_item	3530039	et	3	main
kiiri	doc_491521502066_item	3530040	et	4	main
head	doc_491521502066_item	3530041	et	4	main
aega	doc_491521502066_item	3530042	et	4	main
260903	doc_491521502066_item	3530043	et	2	main
tere	doc_491521502066_item	3529936	et	3	main
meie	doc_491521502066_item	3529947	et	4	main
nimi	doc_491521502066_item	3529953	et	3	main
kõik	doc_491521502066_item	3529961	et	4	main
komi	doc_491521502066_item	3529969	et	4	main
veel	doc_491521502066_item	3529979	et	4	main
osakond	doc_491521502066_item	3529980	et	3	main
vorsti	doc_491521502066_item	3529981	et	4	main
liha	doc_491521502066_item	3529982	et	4	main
palju	doc_491521502066_item	3529988	et	4	main
sõida	doc_491521502066_item	3529990	et	4	main
minu	doc_491521502066_item	3529991	et	3	main
las	doc_491521502066_item	3530000	et	4	main
hahetse	doc_491521502066_item	3530007	et	4	main
ja	doc_491521502066_item	3530008	et	3	main
sina	doc_491521502066_item	3530009	et	4	main
ka	doc_491521502066_item	3530010	et	3	main
kui	doc_491521502066_item	3530011	et	3	main
sa	doc_491521502066_item	3530012	et	3	main
tuled	doc_491521502066_item	3530013	et	4	main
minu	doc_491521502066_item	3530014	et	3	main
jurde	doc_491521502066_item	3530015	et	4	main
me	doc_491521502066_item	3530016	et	4	main
kiri	doc_491521501668_item	3530045	et	3	main
meie	doc_491521501668_item	3530062	et	4	main
ilus	doc_491521501668_item	3530073	et	4	main
ja	doc_491521501668_item	3530074	et	3	main
väga-väga	doc_491521501668_item	3530075	et	3	main
suur	doc_491521501668_item	3530076	et	3	main
kauplus	doc_491521501668_item	3530077	et	3	main
avatud	doc_491521501668_item	3530078	et	4	main
on	doc_491521501668_item	3530083	et	4	main
osakonded	doc_491521501668_item	3530089	et	4	main
ma	doc_491521501668_item	3530098	et	3	main
kõik	doc_491521501668_item	3530108	et	4	main
aga	doc_491521501668_item	3530109	et	3	main
poma	doc_491521501668_item	3530114	et	4	main
raha	doc_491521501668_item	3530118	et	4	main
ja	doc_491521501668_item	3530119	et	3	main
kirjuta	doc_491521501711_item	3530151	et	4	main
eestlasest	doc_491521501711_item	3530153	et	3	main
et	doc_491521501711_item	3530155	et	3	main
sul	doc_491521501711_item	3530165	et	3	main
seal	doc_491521501711_item	3530170	et	4	main
õppisid	doc_491521501711_item	3530171	et	4	main
kuhu	doc_491521501711_item	3530172	et	3	main
sa	doc_491521501711_item	3530173	et	3	main
praktikale	doc_491521501711_item	3530174	et	3	main
lähed	doc_491521501711_item	3530175	et	3	main
millega	doc_491521501711_item	3530176	et	3	main
sa	doc_491521501711_item	3530182	et	3	main
seal	doc_491521501711_item	3530183	et	4	main
tegema	doc_491521501711_item	3530184	et	3	main
hakkad	doc_491521501711_item	3530185	et	3	main
sõbranna	doc_491521501711_item	3530188	et	4	main
teatada	doc_491521501711_item	3530204	et	3	main
kursusse	doc_491521501711_item	3530209	et	3	main
aktiivse	doc_491521501711_item	3530223	et	3	main
kõigile	doc_491521502066_item	3529995	et	4	main
tulevad	doc_491521502066_item	3530002	et	4	main
meie	doc_491521502066_item	3530003	et	4	main
tere	doc_491521501668_item	3530046	et	3	main
ma	doc_491521501668_item	3530048	et	3	main
siin	doc_491521501668_item	3530069	et	4	main
kauplus	doc_491521501668_item	3530070	et	3	main
on	doc_491521501668_item	3530071	et	4	main
väga	doc_491521501668_item	3530072	et	3	main
kaheksast	doc_491521501668_item	3530080	et	4	main
palju	doc_491521501668_item	3530084	et	4	main
kaupluses	doc_491521501668_item	3530086	et	3	main
mänguasjad	doc_491521501668_item	3530091	et	3	main
on	doc_491521501668_item	3530107	et	4	main
raha	doc_491521501668_item	3530113	et	4	main
me	doc_491521501668_item	3530123	et	4	main
läheme	doc_491521501668_item	3530124	et	3	main
oma	doc_491521501711_item	3530152	et	4	main
see	doc_491521501711_item	3530177	et	3	main
mida	doc_491521501711_item	3530181	et	4	main
kuidas	doc_491521501711_item	3530189	et	3	main
elad	doc_491521501711_item	3530191	et	3	main
ma	doc_491521501711_item	3530206	et	3	main
sisseoste	doc_491521501668_item	3530129	et	3	main
tegema	doc_491521501668_item	3530130	et	3	main
koos	doc_491521501668_item	3530131	et	4	main
on	doc_491521501668_item	3530132	et	4	main
kõik	doc_491521501668_item	3530133	et	4	main
kingitused	doc_491521501668_item	3530134	et	4	main
kõigile	doc_491521501668_item	3530135	et	4	main
ma	doc_491521501668_item	3530136	et	3	main
ootan	doc_491521501668_item	3530137	et	3	main
sinu	doc_491521501668_item	3530138	et	3	main
me	doc_491521501668_item	3530140	et	4	main
ostame	doc_491521501668_item	3530141	et	3	main
kõik	doc_491521501668_item	3530142	et	4	main
juurde	doc_491521501668_item	3530139	et	4	main
nind	doc_491521501668_item	3530143	et	4	main
sõbrad	doc_491521501668_item	3530144	et	3	main
kingitused	doc_491521501668_item	3530145	et	4	main
hea	doc_491521501668_item	3530146	et	4	main
taega	doc_491521501668_item	3530147	et	4	main
eesnimi	doc_491521501668_item	3530148	et	3	main
sain	doc_491521501668_item	3530049	et	3	main
sinu	doc_491521501668_item	3530050	et	3	main
kirja	doc_491521501668_item	3530051	et	4	main
kätte	doc_491521501668_item	3530052	et	4	main
väga	doc_491521501668_item	3530056	et	3	main
huvitav	doc_491521501668_item	3530057	et	4	main
kirjutan	doc_491521501668_item	3530058	et	3	main
sinu	doc_491521501668_item	3530059	et	3	main
viimased	doc_491521501668_item	3530060	et	3	main
uudised	doc_491521501668_item	3530061	et	3	main
kauplus	doc_491521501668_item	3530082	et	3	main
raamatu	doc_491521501668_item	3530092	et	4	main
ja	doc_491521501668_item	3530094	et	3	main
siin	doc_491521501668_item	3530100	et	4	main
kauplus	doc_491521501668_item	3530102	et	3	main
ole	doc_491521501668_item	3530104	et	4	main
tihti	doc_491521501668_item	3530105	et	3	main
had	doc_491521501668_item	3530106	et	4	main
ei	doc_491521501668_item	3530111	et	4	main
palju	doc_491521501668_item	3530112	et	4	main
palju	doc_491521501668_item	3530117	et	4	main
koos	doc_491521501668_item	3530125	et	4	main
siis	doc_491521501668_item	3530126	et	3	main
kauplus	doc_491521501668_item	3530127	et	3	main
kirjuta	doc_491521501711_item	3530163	et	4	main
läks	doc_491521501711_item	3530167	et	3	main
sa	doc_491521501711_item	3530169	et	3	main
firma	doc_491521501711_item	3530178	et	4	main
tere	doc_491521501711_item	3530186	et	3	main
sain	doc_491521501711_item	3530193	et	3	main
kirja	doc_491521501711_item	3530195	et	4	main
et	doc_491521501711_item	3530205	et	3	main
arvuti	doc_491521501711_item	3530219	et	4	main
psühholoogia	doc_491521501711_item	3530220	et	4	main
eettevõtluse	doc_491521501711_item	3530221	et	4	main
omale	doc_491521501711_item	3530250	et	3	main
erialale	doc_491521501711_item	3530251	et	3	main
palju	doc_491521501668_item	3530096	et	4	main
osakond	doc_491521501668_item	3530097	et	3	main
ei	doc_491521501668_item	3530103	et	4	main
mina	doc_491521501668_item	3530110	et	4	main
palju	doc_491521501668_item	3530116	et	4	main
mulle	doc_491521501668_item	3530121	et	4	main
külla	doc_491521501668_item	3530122	et	4	main
ja	doc_491521501668_item	3530128	et	3	main
müügisekretarile	doc_491521501711_item	3530252	et	4	main
mulle	doc_491521501711_item	3530253	et	4	main
meeldib	doc_491521501711_item	3530254	et	3	main
suhtluseb	doc_491521501711_item	3530255	et	4	main
inimestega	doc_491521501711_item	3530256	et	3	main
ma	doc_491521501711_item	3530257	et	3	main
olen	doc_491521501711_item	3530258	et	3	main
tööta	doc_491521501711_item	3530259	et	4	main
arvutiga	doc_491521501711_item	3530260	et	4	main
ja	doc_491521501711_item	3530261	et	3	main
saatja	doc_491521501711_item	3530262	et	4	main
dokumendi	doc_491521501711_item	3530263	et	3	main
ma	doc_491521501711_item	3530264	et	3	main
soovin	doc_491521501711_item	3530265	et	3	main
sinule	doc_491521501711_item	3530266	et	3	main
kõige	doc_491521501711_item	3530267	et	4	main
head	doc_491521501711_item	3530268	et	4	main
ma	doc_491521501711_item	3530269	et	3	main
ootan	doc_491521501711_item	3530270	et	3	main
sinu	doc_491521501711_item	3530271	et	3	main
kirja	doc_491521501711_item	3530272	et	4	main
nägemiseni	doc_491521501711_item	3530273	et	4	main
eesnimi	doc_491521501711_item	3530274	et	3	main
kuidas	doc_491521501711_item	3530164	et	3	main
mida	doc_491521501711_item	3530168	et	4	main
minu	doc_491521501711_item	3530187	et	3	main
sa	doc_491521501711_item	3530190	et	3	main
ma	doc_491521501711_item	3530192	et	3	main
sinu	doc_491521501711_item	3530194	et	3	main
aitäh	doc_491521501711_item	3530196	et	3	main
mull	doc_491521501711_item	3530197	et	3	main
on	doc_491521501711_item	3530198	et	4	main
kõik	doc_491521501711_item	3530199	et	4	main
praegu	doc_491521501711_item	3530207	et	3	main
käin	doc_491521501711_item	3530208	et	3	main
pärast	doc_491521501711_item	3530211	et	4	main
müügi	doc_491521501711_item	3530224	et	4	main
ja	doc_491521501711_item	3530225	et	3	main
eesti	doc_491521501711_item	3530226	et	4	main
keelt	doc_491521501711_item	3530227	et	4	main
praktikat	doc_491521501711_item	3530228	et	3	main
ma	doc_491521501711_item	3530229	et	3	main
olin	doc_491521501711_item	3530230	et	3	main
käinud	doc_491521501711_item	3530231	et	4	main
erafirmas	doc_491521501711_item	3530232	et	3	main
seal	doc_491521501711_item	3530233	et	4	main
erafirmas	doc_491521501711_item	3530234	et	3	main
tegelevad	doc_491521501711_item	3530235	et	4	main
müügiga	doc_491521501711_item	3530236	et	3	main
erinevaid	doc_491521501711_item	3530237	et	4	main
kauputega	doc_491521501711_item	3530238	et	3	main
seal	doc_491521501711_item	3530239	et	4	main
firmas	doc_491521501711_item	3530240	et	3	main
mind	doc_491521501711_item	3530241	et	4	main
vastu	doc_491521501711_item	3530242	et	3	main
võtma	doc_491521501711_item	3530243	et	3	main
väga	doc_491521501711_item	3530244	et	3	main
hästi	doc_491521501711_item	3530245	et	3	main
praktikale	doc_491521501711_item	3530246	et	3	main
ma	doc_491521501711_item	3530247	et	3	main
olen	doc_491521501711_item	3530248	et	3	main
töötada	doc_491521501711_item	3530249	et	3	main
müügisekretäri	doc_491521501711_item	3530210	et	4	main
kursusest	doc_491521501711_item	3530212	et	4	main
ma	doc_491521501711_item	3530213	et	3	main
lähen	doc_491521501711_item	3530214	et	3	main
praktikale	doc_491521501711_item	3530215	et	3	main
kursustel	doc_491521501711_item	3530216	et	3	main
ma	doc_491521501711_item	3530217	et	3	main
õppin	doc_491521501711_item	3530218	et	4	main
maksedokumenti	doc_491521501711_item	3530222	et	4	main
lugesite	doc_491521501731_item	3530743	et	3	main
kuulutust	doc_491521501731_item	3530745	et	4	main
reisile	doc_491521501731_item	3530753	et	3	main
ka	doc_491521501731_item	3530769	et	3	main
toetusraha	doc_491521501731_item	3530772	et	4	main
teatrisse	doc_491521501731_item	3530789	et	3	main
hind	doc_491521501731_item	3530793	et	3	main
hinna	doc_491521501731_item	3530804	et	3	main
ja	doc_491521501731_item	3530810	et	3	main
teata	doc_491521501731_item	3530825	et	4	main
oma	doc_491521501731_item	3530750	et	4	main
kes	doc_491521501731_item	3530759	et	4	main
on	doc_491521501731_item	3530760	et	4	main
taotlus	doc_491521501731_item	3530768	et	4	main
selle	doc_491521501731_item	3530781	et	4	main
reisi	doc_491521501731_item	3530782	et	4	main
reisibüroo	doc_491521501731_item	3530783	et	4	main
aeg	doc_491521501731_item	3530790	et	3	main
20	doc_491521501731_item	3530803	et	2	main
edasi-tagasi	doc_491521501731_item	3530806	et	3	main
eest	doc_491521501731_item	3530822	et	4	main
5	doc_491521501731_item	3530827	et	2	main
otsusta	doc_491521501731_item	3530830	et	4	main
oli	doc_491521501731_item	3530842	et	3	main
kõik	doc_491521501731_item	3530850	et	4	main
juunis	doc_491521501731_item	3530856	et	3	main
kiri	doc_491521501920_item	3530896	et	3	main
eesnimi	doc_491521501920_item	3530898	et	3	main
ja	doc_491521501920_item	3530902	et	3	main
annan	doc_491521501920_item	3530904	et	3	main
sinu	doc_491521501920_item	3530906	et	3	main
sinu	doc_491521501920_item	3530911	et	3	main
kolisime	doc_491521501920_item	3530921	et	3	main
vanaema	doc_491521501920_item	3530923	et	4	main
tahaksin	doc_491521501923_item	3531010	et	3	main
eesnimi	doc_491521501923_item	3531019	et	3	main
te	doc_491521501731_item	3530742	et	4	main
sellele	doc_491521501731_item	3530752	et	4	main
teie	doc_491521501731_item	3530755	et	4	main
õpilaste	doc_491521501731_item	3530761	et	4	main
reise	doc_491521501731_item	3530762	et	3	main
alati	doc_491521501731_item	3530763	et	4	main
toetanud	doc_491521501731_item	3530764	et	4	main
kirjutage	doc_491521501731_item	3530765	et	3	main
vabas	doc_491521501731_item	3530766	et	3	main
selle	doc_491521501731_item	3530770	et	4	main
saamiseks	doc_491521501731_item	3530773	et	4	main
kirjeldage	doc_491521501731_item	3530774	et	3	main
reisikava	doc_491521501731_item	3530775	et	4	main
ja	doc_491521501731_item	3530776	et	3	main
põhjendage	doc_491521501731_item	3530777	et	3	main
ellenring	doc_491521501731_item	3530784	et	4	main
korraldab	doc_491521501731_item	3530785	et	3	main
maria	doc_491521501731_item	3530788	et	4	main
juuni	doc_491521501731_item	3530792	et	4	main
hinnaalandus	doc_491521501731_item	3530802	et	3	main
hommiku-	doc_491521501731_item	3530809	et	3	main
linnaekskursioon	doc_491521501731_item	3530812	et	3	main
555	doc_491521501731_item	3530828	et	2	main
meel	doc_491521501731_item	3530844	et	4	main
sinult	doc_491521501731_item	3530845	et	3	main
korras	doc_491521501731_item	3530851	et	4	main
ma	doc_491521501731_item	3530852	et	3	main
võtta	doc_491521501731_item	3530854	et	3	main
ma	doc_491521501731_item	3530857	et	3	main
peterburgi	doc_491521501731_item	3530859	et	4	main
tulla	doc_491521501731_item	3530862	et	3	main
sain	doc_491521501920_item	3530899	et	3	main
kuidas	doc_491521501920_item	3530910	et	3	main
kirjutan	doc_491521501920_item	3530914	et	3	main
et	doc_491521501920_item	3530916	et	3	main
et	doc_491521501920_item	3530919	et	3	main
ta	doc_491521501920_item	3530928	et	4	main
pärandus	doc_491521501920_item	3530930	et	4	main
nii	doc_491521501920_item	3530931	et	3	main
et	doc_491521501920_item	3530932	et	3	main
meie	doc_491521501920_item	3530933	et	4	main
elame	doc_491521501920_item	3530934	et	3	main
praegu	doc_491521501920_item	3530935	et	3	main
üks	doc_491521501920_item	3530973	et	3	main
nädala	doc_491521501920_item	3530997	et	3	main
151102	doc_491521501920_item	3531000	et	2	main
külla	doc_491521501920_item	3531004	et	4	main
kõige	doc_491521501920_item	3531005	et	4	main
head	doc_491521501920_item	3531006	et	4	main
kottasemini	doc_491521501920_item	3531007	et	4	main
kiri	doc_491521501731_item	3530741	et	3	main
ajalehest	doc_491521501731_item	3530744	et	4	main
ning	doc_491521501731_item	3530746	et	3	main
arvate	doc_491521501731_item	3530747	et	3	main
et	doc_491521501731_item	3530748	et	3	main
võiksite	doc_491521501731_item	3530749	et	3	main
vormis	doc_491521501731_item	3530767	et	4	main
miks	doc_491521501731_item	3530778	et	4	main
valisite	doc_491521501731_item	3530779	et	3	main
just	doc_491521501731_item	3530780	et	3	main
teatrireisi	doc_491521501731_item	3530786	et	4	main
2122	doc_491521501731_item	3530791	et	2	main
1500	doc_491521501731_item	3530794	et	2	main
pane	doc_491521501731_item	3530796	et	4	main
tähele	doc_491521501731_item	3530797	et	3	main
grupile	doc_491521501731_item	3530798	et	3	main
vähemalt	doc_491521501731_item	3530799	et	4	main
22	doc_491521501731_item	3530800	et	2	main
inimest	doc_491521501731_item	3530801	et	3	main
teatripiletid	doc_491521501731_item	3530808	et	3	main
telefonil	doc_491521501731_item	3530826	et	3	main
on	doc_491521501731_item	3530849	et	4	main
puhkust	doc_491521501731_item	3530855	et	4	main
tahan	doc_491521501731_item	3530858	et	3	main
juurde	doc_491521501731_item	3530861	et	4	main
on	doc_491521501731_item	3530864	et	4	main
juba	doc_491521501731_item	3530865	et	3	main
ostud	doc_491521501731_item	3530866	et	3	main
edasi-tagasi	doc_491521501731_item	3530867	et	3	main
rongipiletit	doc_491521501731_item	3530868	et	3	main
ma	doc_491521501731_item	3530869	et	3	main
tahan	doc_491521501731_item	3530870	et	3	main
et	doc_491521501731_item	3530871	et	3	main
mulle	doc_491521501731_item	3530874	et	4	main
koolikaaslastega	doc_491521501731_item	3530751	et	4	main
minna	doc_491521501731_item	3530754	et	3	main
koolil	doc_491521501731_item	3530756	et	4	main
on	doc_491521501731_item	3530757	et	4	main
sponsor	doc_491521501731_item	3530758	et	3	main
reisi	doc_491521501731_item	3530771	et	4	main
peterburi	doc_491521501731_item	3530787	et	4	main
krooni	doc_491521501731_item	3530795	et	4	main
sees	doc_491521501731_item	3530805	et	4	main
rongipilet	doc_491521501731_item	3530807	et	3	main
lõunasöök	doc_491521501731_item	3530811	et	3	main
kohaliku	doc_491521501731_item	3530813	et	3	main
giidi	doc_491521501731_item	3530814	et	4	main
juhtimisel	doc_491521501731_item	3530815	et	4	main
ermitaaži	doc_491521501731_item	3530816	et	2	main
ja	doc_491521501731_item	3530817	et	3	main
peeter-pauli	doc_491521501731_item	3530818	et	4	main
kindluse	doc_491521501731_item	3530819	et	4	main
külastamine	doc_491521501731_item	3530820	et	4	main
lisatasu	doc_491521501731_item	3530821	et	4	main
laevasõit	doc_491521501731_item	3530823	et	3	main
osavõtusoovist	doc_491521501731_item	3530824	et	4	main
555	doc_491521501731_item	3530829	et	2	main
kohe	doc_491521501731_item	3530831	et	4	main
sest	doc_491521501731_item	3530832	et	4	main
homme	doc_491521501731_item	3530833	et	3	main
on	doc_491521501731_item	3530834	et	4	main
juba	doc_491521501731_item	3530835	et	3	main
hilja	doc_491521501731_item	3530836	et	3	main
tere	doc_491521501731_item	3530837	et	3	main
kallis	doc_491521501731_item	3530838	et	4	main
sõber	doc_491521501731_item	3530839	et	3	main
pihvo	doc_491521501731_item	3530840	et	4	main
mul	doc_491521501731_item	3530841	et	3	main
hea	doc_491521501731_item	3530843	et	4	main
tahan	doc_491521501731_item	3530853	et	3	main
sinu	doc_491521501731_item	3530860	et	3	main
mul	doc_491521501731_item	3530863	et	3	main
sa	doc_491521501731_item	3530872	et	3	main
hotelli	doc_491521501731_item	3530875	et	4	main
number	doc_491521501731_item	3530876	et	3	main
kohe	doc_491521501920_item	3530903	et	4	main
asjad	doc_491521501920_item	3530912	et	3	main
sulle	doc_491521501920_item	3530915	et	3	main
rääkida	doc_491521501920_item	3530917	et	3	main
pärast	doc_491521501920_item	3530998	et	4	main
meile	doc_491521501920_item	3531003	et	4	main
kiri	doc_491521501923_item	3531009	et	3	main
sõpra	doc_491521501923_item	3531015	et	4	main
tema	doc_491521501923_item	3531016	et	4	main
nimi	doc_491521501923_item	3531017	et	3	main
see	doc_491521501923_item	3531022	et	3	main
välimusega	doc_491521501923_item	3531024	et	3	main
linnas	doc_491521501923_item	3531029	et	4	main
leida	doc_491521501923_item	3531056	et	3	main
töökoha	doc_491521501923_item	3531057	et	4	main
ta	doc_491521501923_item	3531058	et	4	main
tahaks	doc_491521501923_item	3531059	et	3	main
ta	doc_491521501923_item	3531065	et	4	main
rahulik	doc_491521501923_item	3531066	et	3	main
tagasihoidlik	doc_491521501923_item	3531067	et	3	main
on	doc_491521501923_item	3531071	et	4	main
ta	doc_491521501923_item	3531072	et	4	main
kirja	doc_491521501731_item	3530846	et	4	main
saada	doc_491521501731_item	3530847	et	4	main
mul	doc_491521501731_item	3530848	et	3	main
tellisid	doc_491521501731_item	3530873	et	4	main
kaheks	doc_491521501731_item	3530877	et	4	main
paevaks	doc_491521501731_item	3530878	et	3	main
ma	doc_491521501731_item	3530879	et	3	main
teal	doc_491521501731_item	3530880	et	3	main
tahaksin	doc_491521501731_item	3530881	et	3	main
teatri	doc_491521501731_item	3530882	et	3	main
käja	doc_491521501731_item	3530883	et	4	main
ja	doc_491521501731_item	3530884	et	3	main
küllastada	doc_491521501731_item	3530885	et	3	main
ermitaazi	doc_491521501731_item	3530886	et	4	main
ja	doc_491521501731_item	3530887	et	3	main
peeter-pauli	doc_491521501731_item	3530888	et	4	main
oota	doc_491521501731_item	3530889	et	4	main
mind	doc_491521501731_item	3530890	et	4	main
varsti	doc_491521501731_item	3530891	et	3	main
tulen	doc_491521501731_item	3530892	et	3	main
sinu	doc_491521501731_item	3530893	et	3	main
eesnimi	doc_491521501731_item	3530894	et	3	main
kirja	doc_491521501920_item	3530901	et	4	main
vastuse	doc_491521501920_item	3530905	et	3	main
kirjadst	doc_491521501920_item	3530907	et	4	main
rõõmu	doc_491521501920_item	3530909	et	4	main
eedenevad	doc_491521501920_item	3530913	et	4	main
sulle	doc_491521501920_item	3530918	et	3	main
majase	doc_491521501920_item	3530926	et	4	main
mille	doc_491521501920_item	3530927	et	3	main
meile	doc_491521501920_item	3530929	et	4	main
tuba	doc_491521501920_item	3530972	et	4	main
laupäeval	doc_491521501920_item	3530999	et	3	main
kella	doc_491521501920_item	3531001	et	4	main
kasutada	doc_491521501923_item	3531011	et	3	main
tutvustada	doc_491521501923_item	3531014	et	3	main
siin	doc_491521501923_item	3531028	et	4	main
ta	doc_491521501923_item	3531031	et	4	main
ta	doc_491521501923_item	3531054	et	4	main
tema	doc_491521501923_item	3531075	et	4	main
on	doc_491521501923_item	3531078	et	4	main
mulle	doc_491521501923_item	3531114	et	4	main
lõbus	doc_491521501923_item	3531118	et	4	main
lähetal	doc_491521501926_item	3531243	et	4	main
a-kaubad	doc_491521501926_item	3531247	et	3	main
ma	doc_491521501926_item	3531249	et	3	main
on	doc_491521501926_item	3531260	et	4	main
jääb	doc_491521501920_item	3530975	et	3	main
meie	doc_491521501920_item	3530976	et	4	main
tütre	doc_491521501920_item	3530977	et	3	main
jaoks	doc_491521501920_item	3530978	et	4	main
aga	doc_491521501920_item	3530979	et	3	main
mis	doc_491521501920_item	3530980	et	4	main
teha	doc_491521501920_item	3530981	et	3	main
teisest	doc_491521501920_item	3530982	et	4	main
toast	doc_491521501920_item	3530983	et	3	main
meie	doc_491521501920_item	3530984	et	4	main
veel	doc_491521501920_item	3530985	et	4	main
mõtleme	doc_491521501920_item	3530986	et	3	main
need	doc_491521501920_item	3530987	et	3	main
on	doc_491521501920_item	3530988	et	4	main
minu	doc_491521501920_item	3530989	et	3	main
uudised	doc_491521501920_item	3530990	et	3	main
me	doc_491521501920_item	3530991	et	4	main
mõtlesime	doc_491521501920_item	3530992	et	3	main
et	doc_491521501920_item	3530993	et	3	main
kutsume	doc_491521501920_item	3530994	et	3	main
teid	doc_491521501920_item	3530995	et	4	main
tervitust	doc_491521501920_item	3530897	et	4	main
sinult	doc_491521501920_item	3530900	et	3	main
tunnen	doc_491521501920_item	3530908	et	3	main
me	doc_491521501920_item	3530920	et	4	main
peale	doc_491521501920_item	3530922	et	4	main
surma	doc_491521501920_item	3530924	et	4	main
tema	doc_491521501920_item	3530925	et	4	main
suures	doc_491521501920_item	3530936	et	3	main
kahekorruses	doc_491521501920_item	3530937	et	3	main
oma	doc_491521501920_item	3530938	et	4	main
majas	doc_491521501920_item	3530939	et	3	main
esimesel	doc_491521501920_item	3530940	et	3	main
korrusel	doc_491521501920_item	3530941	et	3	main
asub	doc_491521501920_item	3530942	et	3	main
suur	doc_491521501920_item	3530943	et	3	main
köök	doc_491521501920_item	3530944	et	3	main
millest	doc_491521501920_item	3530945	et	3	main
ma	doc_491521501920_item	3530946	et	3	main
unistasin	doc_491521501920_item	3530947	et	3	main
eluaeg	doc_491521501920_item	3530948	et	3	main
veel	doc_491521501920_item	3530949	et	4	main
esimesel	doc_491521501920_item	3530950	et	3	main
korrusel	doc_491521501920_item	3530951	et	3	main
asuvad	doc_491521501920_item	3530952	et	4	main
kaks	doc_491521501920_item	3530953	et	3	main
tuba	doc_491521501920_item	3530954	et	4	main
estik	doc_491521501920_item	3530955	et	4	main
ja	doc_491521501920_item	3530956	et	3	main
wc	doc_491521501920_item	3530957	et	4	main
ühest	doc_491521501920_item	3530958	et	4	main
toast	doc_491521501920_item	3530959	et	3	main
saab	doc_491521501920_item	3530960	et	3	main
küülalistuba	doc_491521501920_item	3530961	et	4	main
aga	doc_491521501920_item	3530962	et	3	main
teisest	doc_491521501920_item	3530963	et	4	main
meie	doc_491521501920_item	3530964	et	4	main
abikaasaga	doc_491521501920_item	3530965	et	3	main
magamistuba	doc_491521501920_item	3530966	et	4	main
teisel	doc_491521501920_item	3530967	et	4	main
korrusel	doc_491521501920_item	3530968	et	3	main
on	doc_491521501920_item	3530969	et	4	main
samuti	doc_491521501920_item	3530970	et	3	main
kaks	doc_491521501920_item	3530971	et	3	main
tuba	doc_491521501920_item	3530974	et	4	main
kahe	doc_491521501920_item	3530996	et	3	main
1800	doc_491521501920_item	3531002	et	2	main
võimalust	doc_491521501923_item	3531012	et	3	main
on	doc_491521501923_item	3531018	et	4	main
kes	doc_491521501923_item	3531026	et	4	main
puhkusel	doc_491521501923_item	3531030	et	4	main
saada	doc_491521501923_item	3531060	et	4	main
hakkaja	doc_491521501923_item	3531068	et	4	main
tugevaks	doc_491521501923_item	3531076	et	4	main
töökus	doc_491521501923_item	3531079	et	4	main
täpsus	doc_491521501923_item	3531080	et	4	main
ei	doc_491521501923_item	3531087	et	4	main
me	doc_491521501923_item	3531110	et	4	main
diskos	doc_491521501923_item	3531112	et	4	main
temaga	doc_491521501923_item	3531113	et	3	main
huvitav	doc_491521501923_item	3531116	et	4	main
eesnimi	doc_491521501926_item	3531231	et	3	main
uudis	doc_491521501926_item	3531235	et	3	main
ilus	doc_491521501926_item	3531245	et	4	main
nimetus	doc_491521501926_item	3531248	et	4	main
töötasin	doc_491521501926_item	3531250	et	3	main
kell	doc_491521501926_item	3531252	et	3	main
töötada	doc_491521501926_item	3531258	et	3	main
palju	doc_491521501926_item	3531261	et	4	main
ja	doc_491521501926_item	3531273	et	3	main
siin	doc_491521501926_item	3531275	et	4	main
on	doc_491521501926_item	3531276	et	4	main
albumid	doc_491521501926_item	3531282	et	3	main
põhjendama	doc_491521501923_item	3531088	et	3	main
mitte	doc_491521501923_item	3531089	et	3	main
kunagi	doc_491521501923_item	3531090	et	3	main
tema	doc_491521501923_item	3531091	et	4	main
harrastuste	doc_491521501923_item	3531092	et	4	main
hulka	doc_491521501923_item	3531093	et	4	main
kuuluvad	doc_491521501923_item	3531094	et	4	main
sport	doc_491521501923_item	3531095	et	3	main
muusika	doc_491521501923_item	3531096	et	4	main
ja	doc_491521501923_item	3531097	et	3	main
tantsimine	doc_491521501923_item	3531098	et	4	main
me	doc_491521501923_item	3531099	et	4	main
alati	doc_491521501923_item	3531100	et	4	main
koos	doc_491521501923_item	3531101	et	4	main
juljaga	doc_491521501923_item	3531102	et	4	main
käime	doc_491521501923_item	3531103	et	4	main
spordisaalis	doc_491521501923_item	3531104	et	3	main
ja	doc_491521501923_item	3531105	et	3	main
kui	doc_491521501923_item	3531106	et	3	main
me	doc_491521501923_item	3531107	et	4	main
puhkame	doc_491521501923_item	3531108	et	3	main
ja	doc_491521501923_item	3531013	et	3	main
tema	doc_491521501923_item	3531020	et	4	main
meeldiva	doc_491521501923_item	3531023	et	4	main
tüdruk	doc_491521501923_item	3531025	et	3	main
on	doc_491521501923_item	3531032	et	4	main
tallinnast	doc_491521501923_item	3531033	et	3	main
ta	doc_491521501923_item	3531034	et	4	main
õppib	doc_491521501923_item	3531035	et	4	main
pedagoogi	doc_491521501923_item	3531036	et	4	main
koolis	doc_491521501923_item	3531037	et	4	main
praegu	doc_491521501923_item	3531038	et	3	main
tegeleb	doc_491521501923_item	3531039	et	3	main
ta	doc_491521501923_item	3531040	et	4	main
eesti	doc_491521501923_item	3531041	et	4	main
keele	doc_491521501923_item	3531042	et	4	main
õppimisega	doc_491521501923_item	3531043	et	4	main
aga	doc_491521501923_item	3531044	et	3	main
muiodu	doc_491521501923_item	3531045	et	4	main
on	doc_491521501923_item	3531046	et	4	main
tema	doc_491521501923_item	3531047	et	4	main
praegune	doc_491521501923_item	3531048	et	3	main
põhitegevus	doc_491521501923_item	3531049	et	4	main
kõrgkooli	doc_491521501923_item	3531050	et	4	main
lõpetamine	doc_491521501923_item	3531051	et	4	main
ja	doc_491521501923_item	3531052	et	3	main
pärast	doc_491521501923_item	3531053	et	4	main
on	doc_491521501923_item	3531021	et	4	main
on	doc_491521501923_item	3531027	et	4	main
lasteaia	doc_491521501923_item	3531061	et	4	main
aga	doc_491521501923_item	3531069	et	3	main
sõbralikkess	doc_491521501923_item	3531081	et	4	main
ma	doc_491521501923_item	3531082	et	3	main
olen	doc_491521501923_item	3531083	et	3	main
nõus	doc_491521501923_item	3531084	et	4	main
siis	doc_491521501923_item	3531109	et	3	main
käime	doc_491521501923_item	3531111	et	4	main
tere	doc_491521501926_item	3531230	et	3	main
mul	doc_491521501926_item	3531232	et	3	main
sulle	doc_491521501926_item	3531234	et	3	main
kuul	doc_491521501926_item	3531237	et	4	main
minu	doc_491521501926_item	3531241	et	3	main
kauplus	doc_491521501926_item	3531246	et	3	main
isesisvalt	doc_491521501926_item	3531251	et	4	main
kümme	doc_491521501926_item	3531253	et	3	main
kauplus	doc_491521501926_item	3531255	et	3	main
ja	doc_491521501926_item	3531256	et	3	main
poodis	doc_491521501926_item	3531259	et	4	main
majandus	doc_491521501926_item	3531262	et	4	main
kingituste	doc_491521501926_item	3531277	et	4	main
rätikud	doc_491521501926_item	3531284	et	3	main
rõmmustasin	doc_491521501926_item	3531336	et	4	main
sul	doc_491521501927_item	3531345	et	3	main
käisin	doc_491521501927_item	3531348	et	3	main
30072003	doc_491521501927_item	3531353	et	2	main
ma	doc_491521501927_item	3531357	et	3	main
käisin	doc_491521501927_item	3531358	et	3	main
selle	doc_491521501927_item	3531360	et	4	main
praktika	doc_491521501927_item	3531364	et	4	main
on	doc_491521501927_item	3531377	et	4	main
suur	doc_491521501927_item	3531378	et	3	main
seal	doc_491521501927_item	3531438	et	4	main
mulle	doc_491521501927_item	3531440	et	4	main
graffik	doc_491521501927_item	3531443	et	4	main
ehituse	doc_491521501927_item	3531444	et	4	main
kinnitatud	doc_491521501927_item	3531449	et	4	main
tere	doc_491521501929_item	3531473	et	3	main
sul	doc_491521501929_item	3531477	et	3	main
käib	doc_491521501929_item	3531479	et	3	main
aastat	doc_491521501929_item	3531486	et	3	main
tuled	doc_491521501929_item	3531489	et	4	main
tahan	doc_491521501929_item	3531493	et	3	main
mina	doc_491521501929_item	3531503	et	4	main
töötasin	doc_491521501929_item	3531510	et	3	main
väga	doc_491521501929_item	3531512	et	3	main
og	doc_491521501929_item	3531522	et	4	main
iga	doc_491521501929_item	3531524	et	4	main
päev	doc_491521501929_item	3531525	et	3	main
mina	doc_491521501929_item	3531526	et	4	main
tegin	doc_491521501929_item	3531527	et	3	main
igasugused	doc_491521501929_item	3531528	et	3	main
päevas	doc_491521501929_item	3531539	et	3	main
tulid	doc_491521501929_item	3531540	et	4	main
tahab	doc_491521501923_item	3531055	et	3	main
õpetajaks	doc_491521501923_item	3531062	et	4	main
iseloomult	doc_491521501923_item	3531063	et	3	main
on	doc_491521501923_item	3531064	et	4	main
mõnikord	doc_491521501923_item	3531070	et	3	main
natuke	doc_491521501923_item	3531073	et	4	main
närviline	doc_491521501923_item	3531074	et	4	main
küljeks	doc_491521501923_item	3531077	et	3	main
e	doc_491521501923_item	3531085	et	4	main
ta	doc_491521501923_item	3531086	et	4	main
väga	doc_491521501923_item	3531115	et	3	main
ja	doc_491521501923_item	3531117	et	3	main
kiri	doc_491521501926_item	3531229	et	3	main
juulil	doc_491521501926_item	3531236	et	3	main
ma	doc_491521501926_item	3531238	et	3	main
kodu	doc_491521501926_item	3531242	et	4	main
avasin	doc_491521501926_item	3531254	et	3	main
hakkas	doc_491521501926_item	3531257	et	3	main
aga	doc_491521501926_item	3531264	et	3	main
on	doc_491521501926_item	3531270	et	4	main
osakond	doc_491521501926_item	3531278	et	3	main
kingituste	doc_491521501926_item	3531279	et	4	main
vaasid	doc_491521501926_item	3531283	et	3	main
küünlajalad	doc_491521501926_item	3531287	et	3	main
ise	doc_491521501926_item	3531289	et	4	main
kohtumenisi	doc_491521501926_item	3531337	et	4	main
päevast	doc_491521501927_item	3531342	et	4	main
ma	doc_491521501927_item	3531347	et	3	main
juulis	doc_491521501927_item	3531350	et	3	main
207	doc_491521501927_item	3531352	et	2	main
jõhvis	doc_491521501927_item	3531366	et	3	main
jollas	doc_491521501927_item	3531370	et	4	main
maja	doc_491521501927_item	3531379	et	4	main
vanni	doc_491521501927_item	3531430	et	4	main
tsement	doc_491521501927_item	3531431	et	3	main
meeldib	doc_491521501927_item	3531441	et	3	main
830	doc_491521501927_item	3531447	et	2	main
täitme	doc_491521501927_item	3531454	et	4	main
olla	doc_491521501927_item	3531456	et	3	main
eesnimi	doc_491521501929_item	3531475	et	3	main
käsi	doc_491521501929_item	3531478	et	4	main
ei	doc_491521501929_item	3531481	et	4	main
näinud	doc_491521501929_item	3531482	et	4	main
sa	doc_491521501929_item	3531488	et	3	main
juurde	doc_491521501929_item	3531491	et	4	main
sulle	doc_491521501929_item	3531494	et	3	main
käisin	doc_491521501929_item	3531504	et	3	main
kus	doc_491521501929_item	3531508	et	3	main
suur	doc_491521501929_item	3531513	et	3	main
ilus	doc_491521501929_item	3531515	et	4	main
see	doc_491521501929_item	3531516	et	3	main
on	doc_491521501929_item	3531517	et	4	main
toidukauplus	doc_491521501929_item	3531518	et	3	main
kaupluse	doc_491521501929_item	3531519	et	3	main
nimi	doc_491521501929_item	3531520	et	3	main
elektra	doc_491521501929_item	3531523	et	4	main
oma	doc_491521501929_item	3531550	et	4	main
suur	doc_491521501929_item	3531574	et	3	main
kõige	doc_491521501929_item	3531580	et	4	main
sõidsid	doc_491521501926_item	3531311	et	4	main
mere	doc_491521501926_item	3531312	et	3	main
äärde	doc_491521501926_item	3531313	et	4	main
sellest	doc_491521501926_item	3531314	et	4	main
poodisest	doc_491521501926_item	3531315	et	4	main
ei	doc_491521501926_item	3531316	et	4	main
olnud	doc_491521501926_item	3531317	et	4	main
palju	doc_491521501926_item	3531318	et	4	main
ostjad	doc_491521501926_item	3531319	et	4	main
kell	doc_491521501926_item	3531320	et	3	main
üksteist	doc_491521501926_item	3531321	et	4	main
ma	doc_491521501926_item	3531322	et	3	main
poodi	doc_491521501926_item	3531324	et	4	main
panin	doc_491521501926_item	3531323	et	3	main
kinni	doc_491521501926_item	3531325	et	3	main
töötasin	doc_491521501926_item	3531326	et	3	main
iga	doc_491521501926_item	3531327	et	4	main
päev	doc_491521501926_item	3531328	et	3	main
müügijuhataja	doc_491521501926_item	3531329	et	4	main
sai	doc_491521501926_item	3531330	et	4	main
minu	doc_491521501926_item	3531331	et	3	main
käätte	doc_491521501926_item	3531332	et	4	main
palka	doc_491521501926_item	3531333	et	4	main
ma	doc_491521501926_item	3531334	et	3	main
väga	doc_491521501926_item	3531335	et	3	main
sinu	doc_491521501926_item	3531338	et	3	main
on	doc_491521501926_item	3531233	et	4	main
käisin	doc_491521501926_item	3531239	et	3	main
praktikal	doc_491521501926_item	3531240	et	3	main
on	doc_491521501926_item	3531244	et	4	main
kaubad	doc_491521501926_item	3531263	et	3	main
kõige	doc_491521501926_item	3531265	et	4	main
rohkem	doc_491521501926_item	3531266	et	4	main
palju	doc_491521501926_item	3531271	et	4	main
laelambid	doc_491521501926_item	3531272	et	3	main
on	doc_491521501926_item	3531281	et	4	main
pakkisin	doc_491521501926_item	3531290	et	3	main
poodes	doc_491521501926_item	3531292	et	4	main
on	doc_491521501926_item	3531293	et	4	main
üks	doc_491521501926_item	3531294	et	3	main
kassapparat	doc_491521501926_item	3531295	et	4	main
juulil	doc_491521501926_item	3531296	et	3	main
oli	doc_491521501926_item	3531297	et	3	main
väga	doc_491521501926_item	3531298	et	3	main
ilus	doc_491521501926_item	3531299	et	4	main
ilm	doc_491521501926_item	3531300	et	3	main
õhutemperatuuriga	doc_491521501926_item	3531301	et	3	main
30	doc_491521501926_item	3531302	et	2	main
c	doc_491521501926_item	3531303	et	4	main
palju	doc_491521501926_item	3531304	et	4	main
inimesed	doc_491521501926_item	3531305	et	3	main
said	doc_491521501926_item	3531306	et	4	main
puhkused	doc_491521501926_item	3531307	et	3	main
ja	doc_491521501926_item	3531308	et	3	main
iga	doc_491521501926_item	3531309	et	4	main
päev	doc_491521501926_item	3531310	et	3	main
läheb	doc_491521501927_item	3531346	et	3	main
igal	doc_491521501927_item	3531355	et	3	main
ett	doc_491521501927_item	3531362	et	3	main
oli	doc_491521501927_item	3531365	et	3	main
ma	doc_491521501927_item	3531368	et	3	main
praktikat	doc_491521501927_item	3531372	et	3	main
oli	doc_491521501927_item	3531373	et	3	main
umbes	doc_491521501927_item	3531380	et	4	main
kaubad	doc_491521501927_item	3531428	et	3	main
näiteks	doc_491521501927_item	3531429	et	4	main
on	doc_491521501926_item	3531267	et	4	main
kööginõud	doc_491521501926_item	3531268	et	3	main
veel	doc_491521501926_item	3531269	et	4	main
seinalambid	doc_491521501926_item	3531274	et	3	main
osakonnas	doc_491521501926_item	3531280	et	4	main
väga	doc_491521501926_item	3531285	et	3	main
palju	doc_491521501926_item	3531286	et	4	main
ma	doc_491521501926_item	3531288	et	3	main
kingituse	doc_491521501926_item	3531291	et	4	main
kiri	doc_491521501927_item	3531340	et	3	main
kuidas	doc_491521501927_item	3531344	et	3	main
kõik	doc_491521501927_item	3531349	et	4	main
praktikal	doc_491521501927_item	3531351	et	3	main
hommikul	doc_491521501927_item	3531356	et	3	main
jalutama	doc_491521501927_item	3531359	et	3	main
pärast	doc_491521501927_item	3531361	et	4	main
minu	doc_491521501927_item	3531363	et	3	main
aga	doc_491521501927_item	3531367	et	3	main
elan	doc_491521501927_item	3531369	et	3	main
minu	doc_491521501927_item	3531371	et	3	main
ehituse	doc_491521501927_item	3531374	et	4	main
abc	doc_491521501927_item	3531375	et	4	main
see	doc_491521501927_item	3531376	et	3	main
erinevad	doc_491521501927_item	3531432	et	4	main
torud	doc_491521501927_item	3531433	et	3	main
telliskivid	doc_491521501927_item	3531434	et	3	main
abc	doc_491521501927_item	3531445	et	4	main
1800	doc_491521501927_item	3531450	et	2	main
ankeeti	doc_491521501927_item	3531453	et	4	main
võib	doc_491521501927_item	3531455	et	3	main
kutsutamine	doc_491521501927_item	3531458	et	4	main
tööle	doc_491521501927_item	3531459	et	3	main
ma	doc_491521501927_item	3531460	et	3	main
väga	doc_491521501927_item	3531461	et	3	main
lootma	doc_491521501927_item	3531462	et	3	main
2	doc_491521501929_item	3531485	et	2	main
praktika	doc_491521501929_item	3531502	et	4	main
kauplus	doc_491521501929_item	3531507	et	3	main
mina	doc_491521501929_item	3531509	et	4	main
on	doc_491521501929_item	3531511	et	4	main
ja	doc_491521501929_item	3531514	et	3	main
iga	doc_491521501929_item	3531530	et	4	main
päev	doc_491521501929_item	3531531	et	3	main
ma	doc_491521501929_item	3531532	et	3	main
nad	doc_491521501929_item	3531542	et	3	main
meile	doc_491521501929_item	3531544	et	4	main
og	doc_491521501929_item	3531547	et	4	main
elektra	doc_491521501929_item	3531548	et	4	main
valmistab	doc_491521501929_item	3531549	et	3	main
on	doc_491521501929_item	3531573	et	4	main
sõbralik	doc_491521501929_item	3531578	et	3	main
mulle	doc_491521501929_item	3531582	et	4	main
meeldis	doc_491521501929_item	3531583	et	3	main
juhataja	doc_491521501929_item	3531584	et	4	main
tema	doc_491521501929_item	3531585	et	4	main
nimi	doc_491521501929_item	3531586	et	3	main
kui	doc_491521501929_item	3531598	et	3	main
kaupluses	doc_491521501929_item	3531599	et	3	main
korras	doc_491521501929_item	3531601	et	4	main
kõik	doc_491521501929_item	3531602	et	4	main
kellel	doc_491521501929_item	3531608	et	4	main
on	doc_491521501929_item	3531609	et	4	main
aitab	doc_491521501929_item	3531615	et	3	main
kõikidele	doc_491521501929_item	3531624	et	4	main
inimestele	doc_491521501929_item	3531625	et	3	main
meeldib	doc_491521501929_item	3531626	et	3	main
nende	doc_491521501929_item	3531627	et	4	main
töökoht	doc_491521501929_item	3531628	et	3	main
nendel	doc_491521501929_item	3531629	et	4	main
inimene	doc_491521501929_item	3531643	et	3	main
rimi	doc_491521501929_item	3531648	et	4	main
elektra	doc_491521501929_item	3531650	et	4	main
valivad	doc_491521501929_item	3531662	et	4	main
elektra	doc_491521501929_item	3531675	et	4	main
arvan	doc_491521501929_item	3531677	et	3	main
kahjuks	doc_491521501929_item	3531689	et	4	main
ma	doc_491521501929_item	3531690	et	3	main
on	doc_491521501929_item	3531694	et	4	main
veel	doc_491521501929_item	3531696	et	4	main
õppida	doc_491521501929_item	3531697	et	3	main
kallis	doc_491521501929_item	3531698	et	4	main
eesnimi	doc_491521501929_item	3531699	et	3	main
korda	doc_491521501927_item	3531419	et	4	main
ma	doc_491521501927_item	3531420	et	3	main
töötasin	doc_491521501927_item	3531421	et	3	main
ladul	doc_491521501927_item	3531422	et	4	main
seal	doc_491521501927_item	3531423	et	4	main
inimest	doc_491521501927_item	3531424	et	3	main
haarasin	doc_491521501927_item	3531425	et	3	main
oma	doc_491521501927_item	3531426	et	4	main
suur	doc_491521501927_item	3531427	et	3	main
tere	doc_491521501927_item	3531341	et	3	main
eesnimi	doc_491521501927_item	3531343	et	3	main
a	doc_491521501927_item	3531354	et	4	main
4000	doc_491521501927_item	3531381	et	2	main
м²	doc_491521501927_item	3531382	et	2	main
seal	doc_491521501927_item	3531383	et	4	main
müüvad	doc_491521501927_item	3531384	et	4	main
ehituse	doc_491521501927_item	3531385	et	4	main
materjalid	doc_491521501927_item	3531386	et	3	main
väga	doc_491521501927_item	3531387	et	3	main
palju	doc_491521501927_item	3531388	et	4	main
töötavad	doc_491521501927_item	3531389	et	4	main
inimesed	doc_491521501927_item	3531390	et	3	main
iga	doc_491521501927_item	3531391	et	4	main
juures	doc_491521501927_item	3531392	et	4	main
oma	doc_491521501927_item	3531393	et	4	main
osakond	doc_491521501927_item	3531394	et	3	main
samuti	doc_491521501927_item	3531395	et	3	main
seal	doc_491521501927_item	3531396	et	4	main
on	doc_491521501927_item	3531397	et	4	main
järelmaksuga	doc_491521501927_item	3531398	et	3	main
müük	doc_491521501927_item	3531399	et	3	main
osakonnas	doc_491521501927_item	3531400	et	4	main
on	doc_491521501927_item	3531401	et	4	main
tapediid	doc_491521501927_item	3531402	et	4	main
erinevad	doc_491521501927_item	3531403	et	4	main
liimad	doc_491521501927_item	3531404	et	4	main
ja	doc_491521501927_item	3531405	et	3	main
värvid	doc_491521501927_item	3531406	et	4	main
naelid	doc_491521501927_item	3531407	et	3	main
põrandad	doc_491521501927_item	3531408	et	3	main
kaaminad	doc_491521501927_item	3531409	et	4	main
uksed	doc_491521501927_item	3531410	et	3	main
ja	doc_491521501927_item	3531411	et	3	main
teised	doc_491521501927_item	3531412	et	4	main
ma	doc_491521501927_item	3531413	et	3	main
töötasin	doc_491521501927_item	3531414	et	3	main
tapeedid	doc_491521501927_item	3531415	et	4	main
osakonnas	doc_491521501927_item	3531416	et	4	main
samuti	doc_491521501927_item	3531417	et	3	main
kaks	doc_491521501927_item	3531418	et	3	main
ma	doc_491521501927_item	3531435	et	3	main
väga	doc_491521501927_item	3531436	et	3	main
tahan	doc_491521501927_item	3531437	et	3	main
töötama	doc_491521501927_item	3531439	et	3	main
nendel	doc_491521501927_item	3531442	et	4	main
ja	doc_491521501927_item	3531448	et	3	main
avatud	doc_491521501927_item	3531446	et	4	main
minu	doc_491521501927_item	3531451	et	3	main
palusin	doc_491521501927_item	3531452	et	3	main
minu	doc_491521501927_item	3531457	et	3	main
head	doc_491521501927_item	3531463	et	4	main
aega	doc_491521501927_item	3531464	et	4	main
ma	doc_491521501927_item	3531465	et	3	main
väga	doc_491521501927_item	3531466	et	3	main
armastan	doc_491521501927_item	3531467	et	3	main
sinu	doc_491521501927_item	3531468	et	3	main
kirjuta	doc_491521501927_item	3531469	et	4	main
mind	doc_491521501927_item	3531470	et	4	main
kiri	doc_491521501929_item	3531472	et	3	main
kallis	doc_491521501929_item	3531474	et	4	main
kuidas	doc_491521501929_item	3531476	et	3	main
ma	doc_491521501929_item	3531480	et	3	main
millal	doc_491521501929_item	3531487	et	3	main
minu	doc_491521501929_item	3531490	et	3	main
ma	doc_491521501929_item	3531492	et	3	main
öelda	doc_491521501929_item	3531495	et	4	main
et	doc_491521501929_item	3531496	et	3	main
mina	doc_491521501929_item	3531497	et	4	main
käin	doc_491521501929_item	3531498	et	3	main
kursustele	doc_491521501929_item	3531499	et	3	main
mul	doc_491521501929_item	3531500	et	3	main
praktikale	doc_491521501929_item	3531505	et	3	main
tööd	doc_491521501929_item	3531529	et	4	main
autod	doc_491521501929_item	3531541	et	3	main
kauplus	doc_491521501929_item	3531572	et	3	main
meeldik	doc_491521501929_item	3531597	et	4	main
kõik	doc_491521501929_item	3531600	et	4	main
iga	doc_491521501929_item	3531613	et	4	main
on	doc_491521501929_item	3531617	et	4	main
kõik	doc_491521501929_item	3531619	et	4	main
töötingimused	doc_491521501929_item	3531620	et	3	main
on	doc_491521501929_item	3531630	et	4	main
hakkame	doc_491521501929_item	3531645	et	3	main
teha	doc_491521501929_item	3531653	et	3	main
järeldus	doc_491521501929_item	3531655	et	4	main
on	doc_491521501929_item	3531657	et	4	main
erinevad	doc_491521501929_item	3531659	et	4	main
inimesed	doc_491521501929_item	3531660	et	3	main
ise	doc_491521501929_item	3531661	et	4	main
meeldib	doc_491521501929_item	3531667	et	3	main
sa	doc_491521501929_item	3531718	et	3	main
tuled	doc_491521501929_item	3531719	et	4	main
minu	doc_491521501929_item	3531720	et	3	main
juurde	doc_491521501929_item	3531721	et	4	main
siis	doc_491521501929_item	3531722	et	3	main
ma	doc_491521501929_item	3531723	et	3	main
jutustan	doc_491521501929_item	3531724	et	3	main
sulle	doc_491521501929_item	3531725	et	3	main
rohkem	doc_491521501929_item	3531726	et	4	main
aga	doc_491521501929_item	3531727	et	3	main
kirjas	doc_491521501929_item	3531728	et	4	main
kahjuks	doc_491521501929_item	3531729	et	4	main
kõik	doc_491521501929_item	3531730	et	4	main
ei	doc_491521501929_item	3531731	et	4	main
saa	doc_491521501929_item	3531732	et	4	main
jutustada	doc_491521501929_item	3531733	et	3	main
soovin	doc_491521501929_item	3531734	et	3	main
sulle	doc_491521501929_item	3531735	et	3	main
kõike	doc_491521501929_item	3531736	et	4	main
head	doc_491521501929_item	3531737	et	4	main
sinu	doc_491521501929_item	3531738	et	3	main
parim	doc_491521501929_item	3531739	et	4	main
sõber	doc_491521501929_item	3531740	et	3	main
sind	doc_491521501929_item	3531483	et	4	main
juba	doc_491521501929_item	3531484	et	3	main
on	doc_491521501929_item	3531501	et	4	main
jõhvisse	doc_491521501929_item	3531506	et	3	main
on	doc_491521501929_item	3531521	et	4	main
kallusin	doc_491521501929_item	3531533	et	4	main
puuviljad	doc_491521501929_item	3531534	et	3	main
ja	doc_491521501929_item	3531535	et	3	main
juurviljad	doc_491521501929_item	3531536	et	3	main
kaks	doc_491521501929_item	3531537	et	3	main
korda	doc_491521501929_item	3531538	et	4	main
tõid	doc_491521501929_item	3531543	et	4	main
kaubad	doc_491521501929_item	3531545	et	3	main
kauplus	doc_491521501929_item	3531546	et	3	main
toodet	doc_491521501929_item	3531551	et	3	main
nendel	doc_491521501929_item	3531552	et	4	main
on	doc_491521501929_item	3531553	et	4	main
suur	doc_491521501929_item	3531554	et	3	main
ladu	doc_491521501929_item	3531555	et	4	main
rakveres	doc_491521501929_item	3531556	et	4	main
iga	doc_491521501929_item	3531557	et	4	main
päev	doc_491521501929_item	3531558	et	3	main
suhtlesin	doc_491521501929_item	3531559	et	3	main
inimestega	doc_491521501929_item	3531560	et	3	main
eesti	doc_491521501929_item	3531561	et	4	main
ja	doc_491521501929_item	3531562	et	3	main
vene	doc_491521501929_item	3531563	et	4	main
keeles	doc_491521501929_item	3531564	et	4	main
mulle	doc_491521501929_item	3531565	et	4	main
väga	doc_491521501929_item	3531566	et	3	main
meeldis	doc_491521501929_item	3531567	et	3	main
seal	doc_491521501929_item	3531568	et	4	main
selle	doc_491521501929_item	3531569	et	4	main
pärast	doc_491521501929_item	3531570	et	4	main
et	doc_491521501929_item	3531571	et	3	main
mugav	doc_491521501929_item	3531576	et	3	main
kollektiiv	doc_491521501929_item	3531579	et	3	main
rohkem	doc_491521501929_item	3531581	et	4	main
eesnimi	doc_491521501929_item	3531588	et	3	main
talle	doc_491521501929_item	3531596	et	4	main
oma	doc_491521501929_item	3531605	et	4	main
abi	doc_491521501929_item	3531611	et	4	main
siis	doc_491521501929_item	3531612	et	3	main
mina	doc_491521501929_item	3531621	et	4	main
arvan	doc_491521501929_item	3531622	et	3	main
et	doc_491521501929_item	3531623	et	3	main
hea	doc_491521501929_item	3531631	et	4	main
palk	doc_491521501929_item	3531632	et	3	main
ja	doc_491521501929_item	3531633	et	3	main
väga	doc_491521501929_item	3531634	et	3	main
aus	doc_491521501929_item	3531642	et	4	main
niisuguse	doc_491521501929_item	3531654	et	3	main
kauplused	doc_491521501929_item	3531656	et	3	main
väga	doc_491521501929_item	3531658	et	3	main
valib	doc_491521501929_item	3531673	et	3	main
on	doc_491521501929_item	3531680	et	4	main
valik	doc_491521501929_item	3531682	et	3	main
mina	doc_491521501929_item	3531700	et	4	main
arvan	doc_491521501929_item	3531701	et	3	main
ja	doc_491521501929_item	3531575	et	3	main
väga	doc_491521501929_item	3531577	et	3	main
perekonnanimi	doc_491521501929_item	3531589	et	3	main
müüjad	doc_491521501929_item	3531603	et	4	main
teevad	doc_491521501929_item	3531604	et	3	main
vaja	doc_491521501929_item	3531610	et	4	main
kaupluses	doc_491521501929_item	3531616	et	3	main
tähtis	doc_491521501929_item	3531635	et	4	main
asi	doc_491521501929_item	3531636	et	4	main
et	doc_491521501929_item	3531637	et	3	main
juhataja	doc_491521501929_item	3531638	et	4	main
oli	doc_491521501929_item	3531639	et	3	main
hea	doc_491521501929_item	3531640	et	4	main
ja	doc_491521501929_item	3531641	et	3	main
võrdlema	doc_491521501929_item	3531646	et	3	main
toidukauplused	doc_491521501929_item	3531647	et	3	main
ja	doc_491521501929_item	3531649	et	3	main
siis	doc_491521501929_item	3531651	et	3	main
kõige	doc_491521501929_item	3531665	et	4	main
rohkem	doc_491521501929_item	3531666	et	4	main
ostus	doc_491521501929_item	3531668	et	3	main
käia	doc_491521501929_item	3531669	et	4	main
suurem	doc_491521501929_item	3531670	et	4	main
osa	doc_491521501929_item	3531671	et	4	main
nendest	doc_491521501929_item	3531672	et	4	main
see	doc_491521501929_item	3531679	et	3	main
mina	doc_491521501929_item	3531683	et	4	main
väga	doc_491521501929_item	3531684	et	3	main
tahan	doc_491521501929_item	3531685	et	3	main
seal	doc_491521501929_item	3531686	et	4	main
töötada	doc_491521501929_item	3531687	et	3	main
aga	doc_491521501929_item	3531688	et	3	main
saa	doc_491521501929_item	3531692	et	4	main
eesnimi	doc_491521501930_item	3531866	et	3	main
üheksa	doc_491521501930_item	3531870	et	4	main
eesnimi	doc_491521501930_item	3531885	et	3	main
on	doc_491521501930_item	3531887	et	4	main
nimi	doc_491521501930_item	3531902	et	3	main
lasteajas	doc_491521501930_item	3531907	et	3	main
elame	doc_491521501930_item	3531938	et	3	main
abikaasale	doc_491521501930_item	3531949	et	4	main
mul	doc_491521501930_item	3531950	et	3	main
on	doc_491521501930_item	3531951	et	4	main
õde	doc_491521501930_item	3531952	et	4	main
ta	doc_491521501930_item	3531953	et	4	main
on	doc_491521501929_item	3531587	et	4	main
ta	doc_491521501929_item	3531590	et	4	main
on	doc_491521501929_item	3531591	et	4	main
väga	doc_491521501929_item	3531592	et	3	main
viisakas	doc_491521501929_item	3531593	et	4	main
rahulik	doc_491521501929_item	3531594	et	3	main
inimene	doc_491521501929_item	3531595	et	3	main
tööd	doc_491521501929_item	3531606	et	4	main
kui	doc_491521501929_item	3531607	et	3	main
üks	doc_491521501929_item	3531614	et	3	main
loodud	doc_491521501929_item	3531618	et	4	main
kui	doc_491521501929_item	3531644	et	3	main
oskame	doc_491521501929_item	3531652	et	3	main
kus	doc_491521501929_item	3531663	et	3	main
neil	doc_491521501929_item	3531664	et	4	main
mina	doc_491521501929_item	3531676	et	4	main
õige	doc_491521501929_item	3531681	et	4	main
ei	doc_491521501929_item	3531691	et	4	main
et	doc_491521501929_item	3531702	et	3	main
og	doc_491521501929_item	3531674	et	4	main
et	doc_491521501929_item	3531678	et	3	main
mul	doc_491521501929_item	3531693	et	3	main
vaja	doc_491521501929_item	3531695	et	4	main
sulle	doc_491521501929_item	3531703	et	3	main
meeldib	doc_491521501929_item	3531704	et	3	main
minu	doc_491521501929_item	3531705	et	3	main
kiri	doc_491521501929_item	3531706	et	3	main
ja	doc_491521501929_item	3531707	et	3	main
sa	doc_491521501929_item	3531708	et	3	main
rõõmustad	doc_491521501929_item	3531709	et	3	main
mind	doc_491521501929_item	3531710	et	4	main
loomulikult	doc_491521501929_item	3531711	et	4	main
mina	doc_491521501929_item	3531712	et	4	main
hakkan	doc_491521501929_item	3531713	et	3	main
ootama	doc_491521501929_item	3531714	et	3	main
sinu	doc_491521501929_item	3531715	et	3	main
kiri	doc_491521501929_item	3531716	et	3	main
kui	doc_491521501929_item	3531717	et	3	main
ja	doc_491521501930_item	3531860	et	3	main
minu	doc_491521501930_item	3531861	et	3	main
pere	doc_491521501930_item	3531862	et	4	main
minu	doc_491521501930_item	3531863	et	3	main
nimi	doc_491521501930_item	3531864	et	3	main
abielus	doc_491521501930_item	3531880	et	4	main
mees	doc_491521501930_item	3531882	et	4	main
nimi	doc_491521501930_item	3531883	et	3	main
on	doc_491521501930_item	3531903	et	4	main
mänguasjad	doc_491521501930_item	3531936	et	3	main
koos	doc_491521501930_item	3531939	et	4	main
kudub	doc_491521501930_item	3531942	et	4	main
essee	doc_491521501930_item	3531858	et	4	main
olen	doc_491521501930_item	3531868	et	3	main
kahekümne	doc_491521501930_item	3531869	et	4	main
aastane	doc_491521501930_item	3531871	et	4	main
ma	doc_491521501930_item	3531872	et	3	main
elan	doc_491521501930_item	3531873	et	3	main
kohtla-järvel	doc_491521501930_item	3531874	et	4	main
mul	doc_491521501930_item	3531875	et	3	main
minu	doc_491521501930_item	3531881	et	3	main
ta	doc_491521501930_item	3531886	et	4	main
kolmekümne	doc_491521501930_item	3531888	et	4	main
üks	doc_491521501930_item	3531889	et	3	main
aastane	doc_491521501930_item	3531890	et	4	main
nad	doc_491521501930_item	3531905	et	3	main
lähevad	doc_491521501930_item	3531906	et	3	main
vanaemaga	doc_491521501930_item	3531940	et	3	main
minu	doc_491521501934_item	3532083	et	3	main
elan	doc_491521501934_item	3532094	et	3	main
mees	doc_491521501934_item	3532105	et	4	main
last	doc_491521501934_item	3532108	et	4	main
on	doc_491521501934_item	3532112	et	4	main
nelikümmend	doc_491521501934_item	3532116	et	4	main
on	doc_491521501934_item	3532132	et	4	main
me	doc_491521501934_item	3532177	et	4	main
on	doc_491521501930_item	3531865	et	4	main
ei	doc_491521501930_item	3531876	et	4	main
on	doc_491521501930_item	3531884	et	4	main
on	doc_491521501930_item	3531892	et	4	main
kaks	doc_491521501930_item	3531893	et	3	main
last	doc_491521501930_item	3531894	et	4	main
vanem	doc_491521501930_item	3531895	et	4	main
tütre	doc_491521501930_item	3531896	et	3	main
nimi	doc_491521501930_item	3531897	et	3	main
on	doc_491521501930_item	3531898	et	4	main
eesnimi	doc_491521501930_item	3531899	et	3	main
eesnimi	doc_491521501930_item	3531904	et	3	main
mulle	doc_491521501930_item	3531946	et	4	main
ja	doc_491521501930_item	3531947	et	3	main
minu	doc_491521501930_item	3531948	et	3	main
vana	doc_491521501934_item	3532092	et	4	main
mina	doc_491521501934_item	3532101	et	4	main
minu	doc_491521501934_item	3532102	et	3	main
ema	doc_491521501934_item	3532103	et	4	main
minu	doc_491521501934_item	3532104	et	3	main
ja	doc_491521501934_item	3532106	et	3	main
on	doc_491521501934_item	3532115	et	4	main
seitse	doc_491521501934_item	3532117	et	3	main
vana	doc_491521501934_item	3532119	et	4	main
ta	doc_491521501934_item	3532120	et	4	main
töötab	doc_491521501934_item	3532121	et	3	main
tehases	doc_491521501934_item	3532122	et	3	main
mul	doc_491521501934_item	3532123	et	3	main
ema	doc_491521501934_item	3532173	et	4	main
pensioner	doc_491521501934_item	3532175	et	4	main
kiri	doc_491521501979_item	3532189	et	3	main
praktikasse	doc_491521501979_item	3532200	et	4	main
ma	doc_491521501979_item	3532201	et	3	main
töötasin	doc_491521501979_item	3532202	et	3	main
kaupluses	doc_491521501979_item	3532203	et	3	main
kuus	doc_491521501979_item	3532212	et	4	main
ma	doc_491521501979_item	3532213	et	3	main
tegin	doc_491521501979_item	3532214	et	3	main
ostjadele	doc_491521501979_item	3532220	et	4	main
töötada	doc_491521501979_item	3532229	et	3	main
elab	doc_491521501930_item	3531954	et	3	main
kohtla-järvel	doc_491521501930_item	3531955	et	4	main
õde	doc_491521501930_item	3531956	et	4	main
elab	doc_491521501930_item	3531957	et	3	main
koos	doc_491521501930_item	3531958	et	4	main
tutraga	doc_491521501930_item	3531959	et	4	main
õe	doc_491521501930_item	3531960	et	4	main
nimi	doc_491521501930_item	3531961	et	3	main
on	doc_491521501930_item	3531962	et	4	main
eesnimi	doc_491521501930_item	3531963	et	3	main
tema	doc_491521501930_item	3531964	et	4	main
tütar	doc_491521501930_item	3531965	et	3	main
nimi	doc_491521501930_item	3531966	et	3	main
on	doc_491521501930_item	3531967	et	4	main
eesnimi	doc_491521501930_item	3531968	et	3	main
ta	doc_491521501930_item	3531969	et	4	main
õppib	doc_491521501930_item	3531970	et	4	main
koolis	doc_491521501930_item	3531971	et	4	main
teisel	doc_491521501930_item	3531972	et	4	main
klassil	doc_491521501930_item	3531973	et	3	main
mina	doc_491521501930_item	3531859	et	4	main
ma	doc_491521501930_item	3531867	et	3	main
oletöö	doc_491521501930_item	3531877	et	4	main
ma	doc_491521501930_item	3531878	et	3	main
olen	doc_491521501930_item	3531879	et	3	main
meil	doc_491521501930_item	3531891	et	4	main
väiksem	doc_491521501930_item	3531900	et	4	main
tütre	doc_491521501930_item	3531901	et	3	main
minu	doc_491521501930_item	3531908	et	3	main
abikasa	doc_491521501930_item	3531909	et	4	main
töötab	doc_491521501930_item	3531910	et	3	main
me	doc_491521501930_item	3531911	et	4	main
elame	doc_491521501930_item	3531912	et	3	main
oma	doc_491521501930_item	3531913	et	4	main
korteris	doc_491521501930_item	3531914	et	3	main
meil	doc_491521501930_item	3531915	et	4	main
on	doc_491521501930_item	3531916	et	4	main
kolm	doc_491521501930_item	3531917	et	3	main
tuba	doc_491521501930_item	3531918	et	4	main
me	doc_491521501930_item	3531919	et	4	main
väga	doc_491521501930_item	3531920	et	3	main
üksmeelne	doc_491521501930_item	3531921	et	3	main
pere	doc_491521501930_item	3531922	et	4	main
me	doc_491521501930_item	3531923	et	4	main
oleme	doc_491521501930_item	3531924	et	3	main
esimesel	doc_491521501930_item	3531925	et	3	main
korrusel	doc_491521501930_item	3531926	et	3	main
kolmekorruseline	doc_491521501930_item	3531927	et	4	main
majast	doc_491521501930_item	3531928	et	4	main
köögis	doc_491521501930_item	3531929	et	3	main
me	doc_491521501930_item	3531930	et	4	main
tegeme	doc_491521501930_item	3531931	et	4	main
remont	doc_491521501930_item	3531932	et	3	main
lapsed	doc_491521501930_item	3531933	et	3	main
mängivad	doc_491521501930_item	3531934	et	4	main
lastetoas	doc_491521501930_item	3531935	et	3	main
me	doc_491521501930_item	3531937	et	4	main
vanaema	doc_491521501930_item	3531941	et	4	main
sookid	doc_491521501930_item	3531943	et	4	main
lastele	doc_491521501930_item	3531944	et	4	main
ja	doc_491521501930_item	3531945	et	3	main
nimi	doc_491521501934_item	3532084	et	3	main
ma	doc_491521501934_item	3532087	et	3	main
olen	doc_491521501934_item	3532088	et	3	main
minu	doc_491521501934_item	3532096	et	3	main
minu	doc_491521501934_item	3532109	et	3	main
nimi	doc_491521501934_item	3532111	et	3	main
on	doc_491521501934_item	3532124	et	4	main
kaks	doc_491521501934_item	3532125	et	3	main
tütart	doc_491521501934_item	3532126	et	3	main
ja	doc_491521501934_item	3532127	et	3	main
vane	doc_491521501934_item	3532129	et	4	main
ljuba	doc_491521501934_item	3532133	et	4	main
minu	doc_491521501934_item	3532172	et	3	main
tere	doc_491521501979_item	3532190	et	3	main
üheksa	doc_491521501979_item	3532207	et	4	main
erinevaid	doc_491521501979_item	3532215	et	4	main
tööd	doc_491521501979_item	3532216	et	4	main
kaluun	doc_491521501979_item	3532217	et	4	main
müüjan	doc_491521501979_item	3532218	et	4	main
seletan	doc_491521501979_item	3532219	et	3	main
suhed	doc_491521501979_item	3532234	et	4	main
see	doc_491521501979_item	3532238	et	3	main
mind	doc_491521501979_item	3532253	et	4	main
ja	doc_491521501979_item	3532256	et	3	main
sest	doc_491521501979_item	3532264	et	4	main
et	doc_491521501979_item	3532265	et	3	main
olen	doc_491521501979_item	3532266	et	3	main
kiri	doc_491521501985_item	3532289	et	3	main
sõber	doc_491521501985_item	3532292	et	3	main
asub	doc_491521501985_item	3532306	et	3	main
päev	doc_491521501985_item	3532311	et	3	main
maha	doc_491521501985_item	3532313	et	4	main
mänguasjad	doc_491521501985_item	3532315	et	3	main
ja	doc_491521501985_item	3532317	et	3	main
vanemad	doc_491521501985_item	3532319	et	4	main
käisid	doc_491521501985_item	3532320	et	4	main
kaupluses	doc_491521501985_item	3532321	et	3	main
ja	doc_491521501985_item	3532322	et	3	main
osakondid	doc_491521501985_item	3532327	et	3	main
nendel	doc_491521501985_item	3532354	et	4	main
ja	doc_491521501985_item	3532363	et	3	main
sõber	doc_491521501985_item	3532367	et	3	main
kuidas	doc_491521501990_item	3532387	et	3	main
käib	doc_491521501990_item	3532389	et	3	main
ma	doc_491521501990_item	3532390	et	3	main
minu	doc_491521501990_item	3532394	et	3	main
praktiku	doc_491521501990_item	3532395	et	3	main
market	doc_491521501990_item	3532397	et	4	main
erenevat	doc_491521501990_item	3532416	et	4	main
kleidid	doc_491521501990_item	3532419	et	3	main
õpetaja	doc_744962874523_item	3532499	et	4	main
mul	doc_744962874523_item	3532504	et	3	main
väga	doc_744962874523_item	3532506	et	3	main
perekonnanimi	doc_744962874523_item	3532508	et	3	main
ütelda	doc_744962874523_item	3532513	et	4	main
minu	doc_744962874523_item	3532517	et	3	main
ja	doc_744962874523_item	3532523	et	3	main
mina	doc_744962874523_item	3532528	et	4	main
mõnikord	doc_744962874523_item	3532537	et	3	main
natuke	doc_744962874523_item	3532541	et	4	main
eesti	doc_744962874523_item	3532589	et	4	main
keel	doc_744962874523_item	3532590	et	4	main
töötan	doc_744962874523_item	3532597	et	3	main
rikkas	doc_744962874523_item	3532602	et	4	main
ka	doc_744962874523_item	3532611	et	3	main
minu	doc_761051790172_item	3532645	et	3	main
perekonnanimi	doc_761051790172_item	3532649	et	3	main
kõige	doc_761051790172_item	3532654	et	4	main
minu	doc_761051790172_item	3532656	et	3	main
õppinud	doc_761051790172_item	3532672	et	4	main
14	doc_761051790172_item	3532673	et	2	main
aastat	doc_761051790172_item	3532674	et	3	main
inglise	doc_761051790172_item	3532678	et	4	main
esimene	doc_761051790172_item	3532680	et	3	main
essee	doc_491521501934_item	3532082	et	4	main
ma	doc_491521501934_item	3532093	et	3	main
on	doc_491521501934_item	3532098	et	4	main
eesnimi	doc_491521501934_item	3532113	et	3	main
aastat	doc_491521501934_item	3532118	et	3	main
tütre	doc_491521501934_item	3532130	et	3	main
kallis	doc_491521501979_item	3532191	et	4	main
juulis	doc_491521501979_item	3532199	et	3	main
asuvad	doc_491521501979_item	3532222	et	4	main
kaubad	doc_491521501979_item	3532223	et	3	main
jne	doc_491521501979_item	3532224	et	4	main
oli	doc_491521501979_item	3532231	et	3	main
ja	doc_491521501979_item	3532236	et	3	main
asub	doc_491521501979_item	3532240	et	3	main
kodu	doc_491521501979_item	3532245	et	4	main
akberi	doc_491521501979_item	3532248	et	4	main
ja	doc_491521501979_item	3532249	et	3	main
zauri	doc_491521501979_item	3532250	et	4	main
keskus	doc_491521501979_item	3532251	et	3	main
mulle	doc_491521501979_item	3532261	et	4	main
meeldib	doc_491521501979_item	3532262	et	3	main
müügitöö	doc_491521501979_item	3532263	et	4	main
kirjutan	doc_491521501985_item	3532294	et	3	main
kauplusses	doc_491521501985_item	3532303	et	4	main
töötasin	doc_491521501985_item	3532308	et	3	main
ma	doc_491521501985_item	3532312	et	3	main
nende	doc_491521501985_item	3532318	et	4	main
kaupa	doc_491521501985_item	3532338	et	4	main
seal	doc_491521501985_item	3532345	et	4	main
päeval	doc_491521501985_item	3532348	et	3	main
iga	doc_491521501985_item	3532358	et	4	main
9ºº-15ºº	doc_491521501985_item	3532365	et	4	main
on	doc_491521501985_item	3532373	et	4	main
käib	doc_491521501934_item	3532153	et	3	main
ka	doc_491521501934_item	3532154	et	3	main
koolis	doc_491521501934_item	3532155	et	4	main
aga	doc_491521501934_item	3532156	et	3	main
poeg	doc_491521501934_item	3532157	et	3	main
on	doc_491521501934_item	3532158	et	4	main
väike	doc_491521501934_item	3532159	et	4	main
ta	doc_491521501934_item	3532160	et	4	main
nimi	doc_491521501934_item	3532161	et	3	main
on	doc_491521501934_item	3532162	et	4	main
sergei	doc_491521501934_item	3532163	et	4	main
ta	doc_491521501934_item	3532164	et	4	main
on	doc_491521501934_item	3532165	et	4	main
kuus	doc_491521501934_item	3532166	et	4	main
aastat	doc_491521501934_item	3532167	et	3	main
vana	doc_491521501934_item	3532168	et	4	main
ta	doc_491521501934_item	3532169	et	4	main
käib	doc_491521501934_item	3532170	et	3	main
lasteaega	doc_491521501934_item	3532171	et	4	main
on	doc_491521501934_item	3532085	et	4	main
eesnimi	doc_491521501934_item	3532086	et	3	main
kolmkümmend	doc_491521501934_item	3532089	et	4	main
neli	doc_491521501934_item	3532090	et	3	main
aastat	doc_491521501934_item	3532091	et	3	main
kohtla-järvel	doc_491521501934_item	3532095	et	4	main
pere	doc_491521501934_item	3532097	et	4	main
kuus	doc_491521501934_item	3532099	et	4	main
inimest	doc_491521501934_item	3532100	et	3	main
kolm	doc_491521501934_item	3532107	et	3	main
mees	doc_491521501934_item	3532110	et	4	main
ta	doc_491521501934_item	3532114	et	4	main
poeg	doc_491521501934_item	3532128	et	3	main
nimi	doc_491521501934_item	3532131	et	3	main
ta	doc_491521501934_item	3532134	et	4	main
on	doc_491521501934_item	3532135	et	4	main
üksteist	doc_491521501934_item	3532136	et	4	main
aastat	doc_491521501934_item	3532137	et	3	main
vana	doc_491521501934_item	3532138	et	4	main
ta	doc_491521501934_item	3532139	et	4	main
käib	doc_491521501934_item	3532140	et	3	main
koolis	doc_491521501934_item	3532141	et	4	main
teine	doc_491521501934_item	3532142	et	3	main
tütre	doc_491521501934_item	3532143	et	3	main
nimi	doc_491521501934_item	3532144	et	3	main
on	doc_491521501934_item	3532145	et	4	main
irina	doc_491521501934_item	3532146	et	3	main
ta	doc_491521501934_item	3532147	et	4	main
on	doc_491521501934_item	3532148	et	4	main
üheksa	doc_491521501934_item	3532149	et	4	main
aastat	doc_491521501934_item	3532150	et	3	main
vana	doc_491521501934_item	3532151	et	4	main
ta	doc_491521501934_item	3532152	et	4	main
on	doc_491521501934_item	3532174	et	4	main
õhtuni	doc_491521501934_item	3532176	et	3	main
koos	doc_491521501934_item	3532178	et	4	main
vaatame	doc_491521501934_item	3532179	et	3	main
telerit	doc_491521501934_item	3532180	et	3	main
või	doc_491521501934_item	3532181	et	4	main
loeme	doc_491521501934_item	3532182	et	3	main
raamatut	doc_491521501934_item	3532183	et	3	main
minu	doc_491521501934_item	3532184	et	3	main
pere	doc_491521501934_item	3532185	et	4	main
on	doc_491521501934_item	3532186	et	4	main
üksmeelne	doc_491521501934_item	3532187	et	3	main
mul	doc_491521501979_item	3532193	et	3	main
kauplus	doc_491521501979_item	3532204	et	3	main
kell	doc_491521501979_item	3532206	et	3	main
ja	doc_491521501979_item	3532208	et	3	main
kinni	doc_491521501979_item	3532209	et	3	main
pandud	doc_491521501979_item	3532210	et	4	main
kell	doc_491521501979_item	3532211	et	3	main
mule	doc_491521501979_item	3532225	et	4	main
väga	doc_491521501979_item	3532226	et	3	main
meeldis	doc_491521501979_item	3532227	et	3	main
seal	doc_491521501979_item	3532228	et	4	main
ostjaga	doc_491521501979_item	3532237	et	4	main
kauplus	doc_491521501979_item	3532239	et	3	main
tahaksin	doc_491521501979_item	3532270	et	3	main
seal	doc_491521501979_item	3532271	et	4	main
töötada	doc_491521501979_item	3532272	et	3	main
juutustad	doc_491521501979_item	3532273	et	4	main
mulle	doc_491521501979_item	3532274	et	4	main
kuidas	doc_491521501979_item	3532275	et	3	main
sa	doc_491521501979_item	3532276	et	3	main
lähed	doc_491521501979_item	3532277	et	3	main
ja	doc_491521501979_item	3532278	et	3	main
mida	doc_491521501979_item	3532279	et	4	main
sa	doc_491521501979_item	3532280	et	3	main
tegid	doc_491521501979_item	3532281	et	4	main
suvel	doc_491521501979_item	3532282	et	3	main
head	doc_491521501979_item	3532283	et	4	main
aega	doc_491521501979_item	3532284	et	4	main
sinu	doc_491521501979_item	3532285	et	3	main
eesnimi	doc_491521501979_item	3532286	et	3	main
29082003	doc_491521501979_item	3532287	et	2	main
olesja	doc_491521501979_item	3532192	et	4	main
on	doc_491521501979_item	3532194	et	4	main
kõik	doc_491521501979_item	3532195	et	4	main
korras	doc_491521501979_item	3532196	et	4	main
ma	doc_491521501979_item	3532197	et	3	main
käisin	doc_491521501979_item	3532198	et	3	main
avatud	doc_491521501979_item	3532205	et	4	main
kus	doc_491521501979_item	3532221	et	3	main
väga	doc_491521501979_item	3532232	et	3	main
müüjaga	doc_491521501979_item	3532235	et	4	main
mitta	doc_491521501979_item	3532242	et	4	main
kaugel	doc_491521501979_item	3532243	et	4	main
kauplus	doc_491521501979_item	3532247	et	3	main
kui	doc_491521501979_item	3532254	et	3	main
kohusetundlikku	doc_491521501979_item	3532255	et	4	main
mul	doc_491521501979_item	3532230	et	3	main
hea	doc_491521501979_item	3532233	et	4	main
kohtla-järvel	doc_491521501979_item	3532241	et	4	main
see	doc_491521501979_item	3532246	et	3	main
müüjat	doc_491521501979_item	3532260	et	4	main
suhtleja	doc_491521501979_item	3532268	et	4	main
ma	doc_491521501979_item	3532269	et	3	main
tere	doc_491521501985_item	3532290	et	3	main
jõhvis	doc_491521501985_item	3532305	et	3	main
iga	doc_491521501985_item	3532310	et	4	main
kauplussses	doc_491521501985_item	3532325	et	4	main
umbes	doc_491521501985_item	3532329	et	4	main
müüjad	doc_491521501985_item	3532331	et	4	main
riiulilaudis	doc_491521501985_item	3532339	et	4	main
töötan	doc_491521501985_item	3532346	et	3	main
ma	doc_491521501985_item	3532349	et	3	main
räõõmsalt	doc_491521501985_item	3532351	et	4	main
vanemaid	doc_491521501985_item	3532355	et	4	main
kauplus	doc_491521501985_item	3532356	et	3	main
töötab	doc_491521501985_item	3532357	et	3	main
pühapäeval	doc_491521501985_item	3532364	et	3	main
kuidas	doc_491521501985_item	3532368	et	3	main
meil	doc_491521501985_item	3532370	et	4	main
ma	doc_491521501990_item	3532399	et	3	main
seal	doc_491521501990_item	3532402	et	4	main
väga	doc_491521501990_item	3532404	et	3	main
väga	doc_491521501990_item	3532411	et	3	main
seal	doc_491521501990_item	3532414	et	4	main
kaubat	doc_491521501990_item	3532417	et	4	main
seliku	doc_491521501990_item	3532420	et	4	main
mantid	doc_491521501990_item	3532421	et	4	main
püksid	doc_491521501990_item	3532422	et	3	main
töötab	doc_491521501990_item	3532462	et	3	main
tahat	doc_491521501990_item	3532487	et	4	main
selle	doc_491521501990_item	3532489	et	4	main
head	doc_491521501990_item	3532491	et	4	main
aega	doc_491521501990_item	3532492	et	4	main
minutsi	doc_491521501979_item	3532244	et	4	main
soovitab	doc_491521501979_item	3532252	et	3	main
head	doc_491521501979_item	3532257	et	4	main
ning	doc_491521501979_item	3532258	et	3	main
arenevat	doc_491521501979_item	3532259	et	4	main
hea	doc_491521501979_item	3532267	et	4	main
kallis	doc_491521501985_item	3532291	et	4	main
ma	doc_491521501985_item	3532293	et	3	main
sulle	doc_491521501985_item	3532295	et	3	main
kirja	doc_491521501985_item	3532296	et	4	main
oma	doc_491521501985_item	3532297	et	4	main
kursuse	doc_491521501985_item	3532298	et	3	main
passaz	doc_491521501985_item	3532304	et	4	main
mänguasjadiosakonnas	doc_491521501985_item	3532309	et	4	main
ostasid	doc_491521501985_item	3532323	et	4	main
ja	doc_491521501985_item	3532328	et	3	main
kümme	doc_491521501985_item	3532330	et	3	main
tegesin	doc_491521501985_item	3532333	et	4	main
koristasin	doc_491521501985_item	3532334	et	3	main
boksi	doc_491521501985_item	3532335	et	4	main
ma	doc_491521501985_item	3532336	et	3	main
paigutasin	doc_491521501985_item	3532337	et	3	main
iga	doc_491521501985_item	3532347	et	4	main
andma	doc_491521501985_item	3532350	et	3	main
lapseid	doc_491521501985_item	3532352	et	4	main
ja	doc_491521501985_item	3532353	et	3	main
paev	doc_491521501985_item	3532359	et	4	main
kell	doc_491521501985_item	3532360	et	3	main
9ºº-18ºº	doc_491521501985_item	3532361	et	4	main
laupäeval	doc_491521501985_item	3532362	et	3	main
läheb	doc_491521501985_item	3532369	et	3	main
sügis	doc_491521501985_item	3532372	et	3	main
käes	doc_491521501985_item	3532374	et	4	main
ilmad	doc_491521501985_item	3532375	et	3	main
on	doc_491521501985_item	3532376	et	4	main
lida	doc_491521501990_item	3532386	et	4	main
töötasin	doc_491521501990_item	3532400	et	3	main
palju	doc_491521501990_item	3532405	et	4	main
inimesed	doc_491521501990_item	3532406	et	3	main
selles	doc_491521501990_item	3532407	et	4	main
müdavad	doc_491521501990_item	3532415	et	4	main
naiteks	doc_491521501990_item	3532418	et	4	main
kaupluses	doc_491521501990_item	3532490	et	3	main
minu	doc_744962874523_item	3532500	et	3	main
eesnimi	doc_744962874523_item	3532503	et	3	main
ja	doc_744962874523_item	3532510	et	3	main
tahan	doc_744962874523_item	3532512	et	3	main
et	doc_744962874523_item	3532514	et	3	main
olen	doc_744962874523_item	3532519	et	3	main
vana	doc_744962874523_item	3532522	et	4	main
lõbus	doc_744962874523_item	3532530	et	4	main
heasüdamlik	doc_744962874523_item	3532531	et	3	main
abivalmis	doc_744962874523_item	3532532	et	3	main
ja	doc_744962874523_item	3532533	et	3	main
lihtsalt	doc_744962874523_item	3532534	et	4	main
olla	doc_744962874523_item	3532539	et	3	main
tagasihoidlik	doc_744962874523_item	3532540	et	3	main
tulevikus	doc_744962874523_item	3532586	et	4	main
kahjuks	doc_744962874523_item	3532591	et	4	main
praktikast	doc_491521501985_item	3532299	et	4	main
ma	doc_491521501985_item	3532300	et	3	main
käisin	doc_491521501985_item	3532301	et	3	main
praktikal	doc_491521501985_item	3532302	et	3	main
ma	doc_491521501985_item	3532307	et	3	main
müüsin	doc_491521501985_item	3532314	et	3	main
lapsed	doc_491521501985_item	3532316	et	3	main
mängid	doc_491521501985_item	3532324	et	3	main
palju	doc_491521501985_item	3532326	et	4	main
ma	doc_491521501985_item	3532332	et	3	main
mulle	doc_491521501985_item	3532340	et	4	main
meeldis	doc_491521501985_item	3532341	et	3	main
praktika	doc_491521501985_item	3532342	et	4	main
ma	doc_491521501985_item	3532343	et	3	main
tahaksin	doc_491521501985_item	3532344	et	3	main
kallis	doc_491521501985_item	3532366	et	4	main
juba	doc_491521501985_item	3532371	et	3	main
külmad	doc_491521501985_item	3532377	et	4	main
iga	doc_491521501985_item	3532378	et	4	main
päev	doc_491521501985_item	3532379	et	3	main
vihma	doc_491521501985_item	3532380	et	4	main
sajab	doc_491521501985_item	3532381	et	3	main
29082003	doc_491521501985_item	3532382	et	2	main
kiri	doc_491521501990_item	3532384	et	3	main
käsi	doc_491521501990_item	3532388	et	4	main
kirjutan	doc_491521501990_item	3532391	et	3	main
poes	doc_491521501990_item	3532398	et	3	main
pärast	doc_491521501990_item	3532408	et	4	main
ett	doc_491521501990_item	3532409	et	3	main
suur	doc_491521501990_item	3532412	et	3	main
blusid	doc_491521501990_item	3532423	et	4	main
ja	doc_491521501990_item	3532424	et	3	main
samuti	doc_491521501990_item	3532425	et	3	main
laste	doc_491521501990_item	3532426	et	4	main
10ºº-19ºº	doc_491521501990_item	3532463	et	4	main
laupäeval	doc_491521501990_item	3532464	et	3	main
töötan	doc_491521501990_item	3532488	et	3	main
eesnimi	doc_491521501990_item	3532494	et	3	main
tere	doc_744962874523_item	3532498	et	3	main
on	doc_744962874523_item	3532505	et	4	main
perekonnanimi	doc_744962874523_item	3532509	et	3	main
sveta	doc_744962874523_item	3532515	et	4	main
rahvuselt	doc_744962874523_item	3532524	et	3	main
olen	doc_744962874523_item	3532525	et	3	main
iseloomult	doc_744962874523_item	3532527	et	3	main
küllalt	doc_744962874523_item	3532529	et	4	main
võin	doc_744962874523_item	3532538	et	3	main
eriti	doc_744962874523_item	3532578	et	3	main
ja	doc_744962874523_item	3532580	et	3	main
piiratud	doc_744962874523_item	3532582	et	4	main
kirjlikud	doc_744962874523_item	3532583	et	4	main
võimalused	doc_744962874523_item	3532584	et	3	main
loodan	doc_744962874523_item	3532585	et	3	main
kain	doc_744962874523_item	3532593	et	3	main
polütehnikumis	doc_744962874523_item	3532594	et	3	main
minu	doc_744962874523_item	3532598	et	3	main
eriti	doc_744962874523_item	3532601	et	3	main
leida	doc_744962874523_item	3532606	et	3	main
tööd	doc_744962874523_item	3532607	et	4	main
ja	doc_744962874523_item	3532608	et	3	main
õppida	doc_744962874523_item	3532609	et	3	main
turvatöötajana	doc_744962874523_item	3532614	et	3	main
on	doc_744962874523_item	3532616	et	4	main
töötada	doc_744962874523_item	3532618	et	3	main
terve	doc_744962874523_item	3532619	et	4	main
on	doc_761051790172_item	3532647	et	4	main
aastat	doc_761051790172_item	3532652	et	3	main
minu	doc_761051790172_item	3532659	et	3	main
mees	doc_761051790172_item	3532660	et	4	main
ma	doc_761051790172_item	3532662	et	3	main
loodust	doc_761051790172_item	3532668	et	4	main
õppinud	doc_761051790172_item	3532677	et	4	main
sest	doc_761051790172_item	3532697	et	4	main
ma	doc_761051790172_item	3532698	et	3	main
elan	doc_761051790172_item	3532699	et	3	main
eestis	doc_761051790172_item	3532700	et	3	main
ja	doc_491521501990_item	3532465	et	3	main
pühapäeval	doc_491521501990_item	3532466	et	3	main
töötab	doc_491521501990_item	3532467	et	3	main
10ºº-16ºº	doc_491521501990_item	3532468	et	4	main
meie	doc_491521501990_item	3532469	et	4	main
kollektiv	doc_491521501990_item	3532470	et	4	main
oli	doc_491521501990_item	3532471	et	3	main
väga	doc_491521501990_item	3532472	et	3	main
väike	doc_491521501990_item	3532473	et	4	main
kõigest	doc_491521501990_item	3532474	et	4	main
kuus	doc_491521501990_item	3532475	et	4	main
inimest	doc_491521501990_item	3532476	et	3	main
kõik	doc_491521501990_item	3532477	et	4	main
töötasid	doc_491521501990_item	3532478	et	4	main
olid	doc_491521501990_item	3532479	et	4	main
sõbralik	doc_491521501990_item	3532480	et	3	main
ma	doc_491521501990_item	3532481	et	3	main
palju	doc_491521501990_item	3532482	et	4	main
suhtlesin	doc_491521501990_item	3532483	et	3	main
inimesega	doc_491521501990_item	3532484	et	3	main
ma	doc_491521501990_item	3532485	et	3	main
tere	doc_491521501990_item	3532385	et	3	main
sulle	doc_491521501990_item	3532392	et	3	main
kiirja	doc_491521501990_item	3532393	et	3	main
oli	doc_491521501990_item	3532396	et	3	main
müüjana	doc_491521501990_item	3532401	et	4	main
alati	doc_491521501990_item	3532403	et	4	main
on	doc_491521501990_item	3532410	et	4	main
allahindlus	doc_491521501990_item	3532413	et	3	main
kaubat	doc_491521501990_item	3532427	et	4	main
erinevad	doc_491521501990_item	3532428	et	4	main
kominesonid	doc_491521501990_item	3532429	et	4	main
saapad	doc_491521501990_item	3532430	et	3	main
kauplus	doc_491521501990_item	3532431	et	3	main
market	doc_491521501990_item	3532432	et	4	main
asub	doc_491521501990_item	3532433	et	3	main
väljaku	doc_491521501990_item	3532434	et	4	main
lahedal	doc_491521501990_item	3532435	et	3	main
market	doc_491521501990_item	3532436	et	4	main
on	doc_491521501990_item	3532437	et	4	main
teine	doc_491521501990_item	3532438	et	3	main
korussel	doc_491521501990_item	3532439	et	4	main
suur	doc_491521501990_item	3532440	et	3	main
majas	doc_491521501990_item	3532441	et	3	main
samuti	doc_491521501990_item	3532442	et	3	main
seal	doc_491521501990_item	3532443	et	4	main
on	doc_491521501990_item	3532444	et	4	main
autopeatus	doc_491521501990_item	3532445	et	4	main
kõrval	doc_491521501990_item	3532446	et	4	main
pärast	doc_491521501990_item	3532447	et	4	main
välja	doc_491521501990_item	3532448	et	4	main
palju	doc_491521501990_item	3532449	et	4	main
inimesed	doc_491521501990_item	3532450	et	3	main
väga	doc_491521501990_item	3532451	et	3	main
hea	doc_491521501990_item	3532452	et	4	main
kaplus	doc_491521501990_item	3532453	et	4	main
samutti	doc_491521501990_item	3532454	et	4	main
melle	doc_491521501990_item	3532455	et	4	main
meldib	doc_491521501990_item	3532456	et	4	main
nendel	doc_491521501990_item	3532457	et	4	main
grafik	doc_491521501990_item	3532458	et	4	main
esmaspäev	doc_491521501990_item	3532459	et	3	main
reede	doc_491521501990_item	3532460	et	4	main
kaplus	doc_491521501990_item	3532461	et	4	main
valja	doc_491521501990_item	3532486	et	3	main
kohtumiseni	doc_491521501990_item	3532493	et	4	main
kiri	doc_744962874523_item	3532497	et	3	main
on	doc_744962874523_item	3532502	et	4	main
populaarne	doc_744962874523_item	3532507	et	3	main
lihtsalt	doc_744962874523_item	3532511	et	4	main
pole	doc_744962874523_item	3532516	et	3	main
19	doc_744962874523_item	3532520	et	2	main
hea	doc_744962874523_item	3532535	et	4	main
mitte	doc_744962874523_item	3532577	et	3	main
suured	doc_744962874523_item	3532579	et	3	main
paremini	doc_744962874523_item	3532587	et	4	main
teada	doc_744962874523_item	3532588	et	3	main
mina	doc_744962874523_item	3532592	et	4	main
pere	doc_744962874523_item	3532599	et	4	main
ja	doc_744962874523_item	3532603	et	3	main
mina	doc_744962874523_item	3532604	et	4	main
otsustas	doc_744962874523_item	3532605	et	3	main
töötan	doc_744962874523_item	3532613	et	3	main
eesnimi	doc_761051790172_item	3532648	et	3	main
vana	doc_761051790172_item	3532653	et	4	main
tähtsam	doc_761051790172_item	3532655	et	4	main
suhelda	doc_761051790172_item	3532664	et	4	main
lugeda	doc_761051790172_item	3532666	et	3	main
sellele	doc_761051790172_item	3532684	et	4	main
erialale	doc_761051790172_item	3532685	et	3	main
mul	doc_761051790172_item	3532692	et	3	main
lugeda	doc_761051790172_item	3532702	et	3	main
kuulata	doc_761051790172_item	3532706	et	4	main
kõnet	doc_761051790172_item	3532708	et	3	main
rääkida	doc_761051790172_item	3532711	et	3	main
õpilasega	doc_761051790172_item	3532714	et	3	main
keelt	doc_761051790172_item	3532716	et	4	main
tundides	doc_761051790172_item	3532717	et	3	main
on	doc_761051790172_item	3532740	et	4	main
raske	doc_761051790172_item	3532741	et	4	main
ma	doc_761051790172_item	3532742	et	3	main
tahaksin	doc_761051790172_item	3532743	et	3	main
teada	doc_761051790172_item	3532744	et	3	main
mis	doc_761051790172_item	3532745	et	4	main
rahvus	doc_761051790172_item	3532746	et	3	main
te	doc_761051790172_item	3532747	et	4	main
olete	doc_761051790172_item	3532748	et	3	main
kui	doc_761051790172_item	3532749	et	3	main
palju	doc_761051790172_item	3532750	et	4	main
aastat	doc_761051790172_item	3532751	et	3	main
teil	doc_761051790172_item	3532752	et	4	main
on	doc_761051790172_item	3532753	et	4	main
ja	doc_761051790172_item	3532754	et	3	main
kus	doc_761051790172_item	3532755	et	3	main
te	doc_761051790172_item	3532756	et	4	main
nimi	doc_744962874523_item	3532501	et	3	main
sugulane	doc_744962874523_item	3532518	et	3	main
aastat	doc_744962874523_item	3532521	et	3	main
venelane	doc_744962874523_item	3532526	et	3	main
inimene	doc_744962874523_item	3532536	et	3	main
keeltega	doc_744962874523_item	3532542	et	3	main
on	doc_744962874523_item	3532543	et	4	main
alati	doc_744962874523_item	3532544	et	4	main
olnud	doc_744962874523_item	3532545	et	4	main
probleemid	doc_744962874523_item	3532546	et	3	main
ja	doc_744962874523_item	3532547	et	3	main
eesti	doc_744962874523_item	3532548	et	4	main
keel	doc_744962874523_item	3532549	et	4	main
pole	doc_744962874523_item	3532550	et	3	main
erand	doc_744962874523_item	3532551	et	3	main
minu	doc_744962874523_item	3532552	et	3	main
sõprade	doc_744962874523_item	3532553	et	3	main
hulgas	doc_744962874523_item	3532554	et	4	main
on	doc_744962874523_item	3532555	et	4	main
eestlased	doc_744962874523_item	3532556	et	3	main
aga	doc_744962874523_item	3532557	et	3	main
kõik	doc_744962874523_item	3532558	et	4	main
teavad	doc_744962874523_item	3532559	et	3	main
vene	doc_744962874523_item	3532560	et	4	main
keel	doc_744962874523_item	3532561	et	4	main
ei	doc_744962874523_item	3532562	et	4	main
loe	doc_744962874523_item	3532563	et	4	main
eesti	doc_744962874523_item	3532564	et	4	main
keele	doc_744962874523_item	3532565	et	4	main
ajalehti	doc_744962874523_item	3532566	et	4	main
jne	doc_744962874523_item	3532567	et	4	main
mul	doc_744962874523_item	3532568	et	3	main
on	doc_744962874523_item	3532569	et	4	main
olemas	doc_744962874523_item	3532570	et	4	main
kesktase	doc_744962874523_item	3532571	et	3	main
aga	doc_744962874523_item	3532572	et	3	main
minu	doc_744962874523_item	3532573	et	3	main
arvates	doc_744962874523_item	3532574	et	4	main
suhtlemis	doc_744962874523_item	3532575	et	4	main
oskused	doc_744962874523_item	3532576	et	3	main
veel	doc_744962874523_item	3532581	et	4	main
ja	doc_744962874523_item	3532595	et	3	main
veel	doc_744962874523_item	3532596	et	4	main
pole	doc_744962874523_item	3532600	et	3	main
mina	doc_744962874523_item	3532610	et	4	main
ja	doc_744962874523_item	3532615	et	3	main
tahan	doc_744962874523_item	3532612	et	3	main
vaja	doc_744962874523_item	3532617	et	4	main
päeva	doc_744962874523_item	3532620	et	4	main
või	doc_744962874523_item	3532621	et	4	main
öö	doc_744962874523_item	3532622	et	4	main
selle	doc_744962874523_item	3532623	et	4	main
parast	doc_744962874523_item	3532624	et	3	main
vahel	doc_744962874523_item	3532625	et	4	main
võin	doc_744962874523_item	3532626	et	3	main
puududa	doc_744962874523_item	3532627	et	3	main
aga	doc_744962874523_item	3532628	et	3	main
püüan	doc_744962874523_item	3532629	et	3	main
võtta	doc_744962874523_item	3532630	et	3	main
vihikud	doc_744962874523_item	3532631	et	3	main
teistelt	doc_744962874523_item	3532632	et	4	main
õpilastelt	doc_744962874523_item	3532633	et	4	main
mina	doc_744962874523_item	3532634	et	4	main
elan	doc_744962874523_item	3532635	et	3	main
eestis	doc_744962874523_item	3532636	et	3	main
ja	doc_744962874523_item	3532637	et	3	main
konkurentsivõimalik	doc_744962874523_item	3532638	et	3	main
meie	doc_744962874523_item	3532639	et	4	main
ühiskonnas	doc_744962874523_item	3532640	et	4	main
22	doc_761051790172_item	3532651	et	2	main
on	doc_761051790172_item	3532658	et	4	main
inimesega	doc_761051790172_item	3532665	et	3	main
ja	doc_761051790172_item	3532667	et	3	main
eesti	doc_761051790172_item	3532669	et	4	main
keelt	doc_761051790172_item	3532670	et	4	main
olen	doc_761051790172_item	3532671	et	3	main
olen	doc_761051790172_item	3532676	et	3	main
on	doc_761051790172_item	3532686	et	4	main
õppimissoov	doc_761051790172_item	3532687	et	3	main
lihtsalt	doc_761051790172_item	3532688	et	4	main
tahaksin	doc_761051790172_item	3532689	et	3	main
on	doc_761051790172_item	3532693	et	4	main
keelt	doc_761051790172_item	3532695	et	4	main
vaja	doc_761051790172_item	3532696	et	4	main
ma	doc_761051790172_item	3532704	et	3	main
eesti	doc_761051790172_item	3532707	et	4	main
ma	doc_761051790172_item	3532709	et	3	main
mul	doc_761051790172_item	3532718	et	3	main
te	doc_761051790172_item	3532761	et	4	main
keel	doc_761051790172_item	3532764	et	4	main
et	doc_761051790172_item	3532766	et	3	main
on	doc_761051790172_item	3532768	et	4	main
laabub	doc_761051790172_item	3532769	et	3	main
lugupidamisega	doc_761051790172_item	3532770	et	3	main
eesnimi	doc_761051790172_item	3532771	et	3	main
perekonnanimi	doc_761051790172_item	3532772	et	3	main
reisi	doc_584615399785_item	3532777	et	4	main
ja	doc_584615399785_item	3532787	et	3	main
te	doc_584615399785_item	3532789	et	4	main
millega	doc_584615399785_item	3532792	et	3	main
laine	doc_584615399785_item	3532810	et	4	main
kuidas	doc_584615399785_item	3532811	et	3	main
me	doc_584615399785_item	3532818	et	4	main
ma	doc_584615399785_item	3532822	et	3	main
oma	doc_584615399785_item	3532834	et	4	main
minu	doc_584615399785_item	3532838	et	3	main
allaga	doc_584615399785_item	3532840	et	4	main
rohkem	doc_761051790172_item	3532721	et	4	main
grammatika	doc_761051790172_item	3532722	et	4	main
teadust	doc_761051790172_item	3532723	et	4	main
ma	doc_761051790172_item	3532724	et	3	main
loodan	doc_761051790172_item	3532725	et	3	main
et	doc_761051790172_item	3532726	et	3	main
me	doc_761051790172_item	3532727	et	4	main
tegeleme	doc_761051790172_item	3532728	et	3	main
põhjalikult	doc_761051790172_item	3532729	et	4	main
kiri	doc_761051790172_item	3532642	et	3	main
tere	doc_761051790172_item	3532643	et	3	main
õpetaja	doc_761051790172_item	3532644	et	4	main
nimi	doc_761051790172_item	3532646	et	3	main
olen	doc_761051790172_item	3532650	et	3	main
elus	doc_761051790172_item	3532657	et	4	main
sõbrad	doc_761051790172_item	3532661	et	3	main
armastan	doc_761051790172_item	3532663	et	3	main
varem	doc_761051790172_item	3532675	et	4	main
keelt	doc_761051790172_item	3532679	et	4	main
põhjus	doc_761051790172_item	3532681	et	4	main
miks	doc_761051790172_item	3532682	et	4	main
tulin	doc_761051790172_item	3532683	et	3	main
kusagilt	doc_761051790172_item	3532690	et	3	main
ilukirjanduse	doc_761051790172_item	3532703	et	3	main
eesti	doc_761051790172_item	3532715	et	4	main
vaja	doc_761051790172_item	3532720	et	4	main
kirjutamisega	doc_761051790172_item	3532730	et	4	main
lugeda	doc_761051790172_item	3532731	et	3	main
suhelda	doc_761051790172_item	3532732	et	4	main
ja	doc_761051790172_item	3532733	et	3	main
tõlkida	doc_761051790172_item	3532734	et	3	main
ma	doc_761051790172_item	3532735	et	3	main
oma	doc_584615399785_item	3532782	et	4	main
kirjutage	doc_584615399785_item	3532785	et	3	main
soovite	doc_584615399785_item	3532791	et	3	main
kus	doc_584615399785_item	3532794	et	3	main
maksab	doc_584615399785_item	3532799	et	3	main
kirja	doc_584615399785_item	3532803	et	4	main
nõutav	doc_584615399785_item	3532804	et	4	main
umbes	doc_584615399785_item	3532806	et	4	main
mul	doc_584615399785_item	3532814	et	3	main
venemaale	doc_584615399785_item	3532821	et	4	main
moskva	doc_584615399785_item	3532824	et	4	main
on	doc_584615399785_item	3532826	et	4	main
kirjas	doc_584615399785_item	3532835	et	4	main
valjak	doc_584615399785_item	3532876	et	4	main
me	doc_584615399785_item	3532877	et	4	main
kirjutage	doc_584615399786_item	3532905	et	3	main
ja	doc_584615399786_item	3532907	et	3	main
sõita	doc_584615399786_item	3532910	et	3	main
kus	doc_584615399786_item	3532914	et	3	main
kui	doc_584615399786_item	3532916	et	3	main
maksab	doc_584615399786_item	3532919	et	3	main
80	doc_584615399786_item	3532927	et	2	main
sõna	doc_584615399786_item	3532928	et	4	main
kõik	doc_584615399786_item	3532935	et	4	main
olen	doc_584615399786_item	3532938	et	3	main
ma	doc_584615399786_item	3532940	et	3	main
tahan	doc_584615399786_item	3532941	et	3	main
kiri	doc_584615399787_item	3533018	et	3	main
sõbrale	doc_584615399787_item	3533028	et	3	main
pikkus	doc_584615399787_item	3533049	et	4	main
marika	doc_584615399787_item	3533055	et	4	main
küll	doc_584615399787_item	3533059	et	4	main
hea	doc_584615399787_item	3533061	et	4	main
et	doc_584615399787_item	3533062	et	3	main
sa	doc_584615399787_item	3533063	et	3	main
mulle	doc_584615399787_item	3533064	et	4	main
nii	doc_584615399787_item	3533065	et	3	main
oma	doc_584615399787_item	3533072	et	4	main
kuhu	doc_584615399787_item	3533076	et	3	main
ma	doc_584615399787_item	3533081	et	3	main
nad	doc_584615399787_item	3533089	et	3	main
elavad	doc_584615399787_item	3533090	et	4	main
esimesel	doc_584615399787_item	3533095	et	3	main
olen	doc_584615399787_item	3533097	et	3	main
sina	doc_584615399787_item	3533130	et	4	main
te	doc_584615399788_item	3533138	et	4	main
sellest	doc_584615399788_item	3533143	et	4	main
oma	doc_584615399788_item	3533145	et	4	main
kirjutage	doc_584615399788_item	3533148	et	3	main
te	doc_584615399788_item	3533152	et	4	main
80	doc_584615399788_item	3533170	et	2	main
kõik	doc_584615399788_item	3533182	et	4	main
teie	doc_584615399788_item	3533187	et	4	main
plaanerin	doc_584615399788_item	3533192	et	4	main
me	doc_584615399788_item	3533204	et	4	main
reisime	doc_584615399788_item	3533205	et	3	main
aga	doc_584615399788_item	3533218	et	3	main
õhtul	doc_584615399788_item	3533219	et	3	main
sõidame	doc_584615399788_item	3533220	et	3	main
vaatame	doc_584615399788_item	3533239	et	3	main
muuseumi	doc_584615399788_item	3533253	et	4	main
koju	doc_584615399788_item	3533257	et	3	main
õppida	doc_761051790172_item	3532691	et	3	main
eesti	doc_761051790172_item	3532694	et	4	main
tahan	doc_761051790172_item	3532705	et	3	main
tahan	doc_761051790172_item	3532710	et	3	main
õpetajaga	doc_761051790172_item	3532712	et	4	main
see	doc_761051790172_item	3532739	et	3	main
kiri	doc_584615399785_item	3532774	et	3	main
eestlasest	doc_584615399785_item	3532783	et	3	main
kui	doc_584615399785_item	3532796	et	3	main
see	doc_584615399785_item	3532798	et	3	main
millistes	doc_584615399785_item	3532800	et	3	main
peatute	doc_584615399785_item	3532802	et	4	main
sõna	doc_584615399785_item	3532808	et	4	main
tere	doc_584615399785_item	3532809	et	3	main
reisi	doc_584615399785_item	3532820	et	4	main
armastan	doc_584615399785_item	3532823	et	3	main
see	doc_584615399785_item	3532825	et	3	main
väga	doc_584615399785_item	3532827	et	3	main
me	doc_584615399785_item	3532836	et	4	main
augustiks	doc_584615399785_item	3532843	et	3	main
puskino	doc_584615399785_item	3532879	et	4	main
te	doc_584615399786_item	3532895	et	4	main
venemaale	doc_584615399786_item	3532898	et	4	main
kirjutage	doc_584615399786_item	3532899	et	3	main
sõbrale	doc_584615399786_item	3532904	et	3	main
millal	doc_584615399786_item	3532906	et	3	main
millistes	doc_584615399786_item	3532920	et	3	main
peatute	doc_584615399786_item	3532922	et	4	main
nõutav	doc_584615399786_item	3532924	et	4	main
pikkus	doc_584615399786_item	3532925	et	4	main
laine	doc_584615399786_item	3532930	et	4	main
teatri	doc_584615399786_item	3532995	et	3	main
muuseumi	doc_584615399786_item	3532996	et	4	main
ja	doc_584615399786_item	3532997	et	3	main
naitusele	doc_584615399786_item	3532998	et	4	main
kõik	doc_584615399786_item	3532999	et	4	main
piletid	doc_584615399786_item	3533000	et	3	main
on	doc_584615399786_item	3533001	et	4	main
väga	doc_584615399786_item	3533002	et	3	main
kallid	doc_584615399786_item	3533003	et	3	main
läheb	doc_584615399786_item	3533004	et	3	main
maksma	doc_584615399786_item	3533005	et	3	main
puhkusele	doc_584615399786_item	3533006	et	4	main
umbes	doc_584615399786_item	3533007	et	4	main
kolm	doc_584615399786_item	3533008	et	3	main
tuhat	doc_584615399786_item	3533009	et	4	main
krooni	doc_584615399786_item	3533010	et	4	main
lähme	doc_584615399786_item	3533011	et	3	main
tagasi	doc_584615399786_item	3533012	et	3	main
kolm	doc_584615399786_item	3533013	et	3	main
nädalat	doc_584615399786_item	3533014	et	3	main
kohtumiseni	doc_584615399786_item	3533015	et	4	main
eesnimi	doc_584615399786_item	3533016	et	3	main
oma	doc_584615399787_item	3533026	et	4	main
kui	doc_584615399787_item	3533040	et	3	main
millistes	doc_584615399787_item	3533044	et	3	main
peatute	doc_584615399787_item	3533046	et	4	main
eest	doc_584615399787_item	3533058	et	4	main
on	doc_584615399787_item	3533060	et	4	main
et	doc_761051790172_item	3532701	et	3	main
ja	doc_761051790172_item	3532713	et	3	main
on	doc_761051790172_item	3532719	et	4	main
kardan	doc_761051790172_item	3532736	et	4	main
natuke	doc_761051790172_item	3532737	et	4	main
et	doc_761051790172_item	3532738	et	3	main
elate	doc_761051790172_item	3532757	et	3	main
kui	doc_761051790172_item	3532758	et	3	main
palju	doc_761051790172_item	3532759	et	4	main
aastat	doc_761051790172_item	3532760	et	3	main
õppisite	doc_761051790172_item	3532762	et	3	main
vene	doc_761051790172_item	3532763	et	4	main
loodan	doc_761051790172_item	3532765	et	3	main
kõik	doc_761051790172_item	3532767	et	4	main
plaanite	doc_584615399785_item	3532776	et	3	main
sõbrale	doc_584615399785_item	3532784	et	3	main
millal	doc_584615399785_item	3532786	et	3	main
kuhu	doc_584615399785_item	3532788	et	3	main
sõita	doc_584615399785_item	3532790	et	3	main
reisite	doc_584615399785_item	3532793	et	3	main
palju	doc_584615399785_item	3532797	et	4	main
käsi	doc_584615399785_item	3532812	et	4	main
on	doc_584615399785_item	3532815	et	4	main
kõik	doc_584615399785_item	3532816	et	4	main
hästi	doc_584615399785_item	3532817	et	3	main
ilus	doc_584615399785_item	3532828	et	4	main
linn	doc_584615399785_item	3532829	et	3	main
ma	doc_584615399785_item	3532830	et	3	main
kirjutan	doc_584615399785_item	3532831	et	3	main
moskva	doc_584615399785_item	3532832	et	4	main
sõbra	doc_584615399785_item	3532839	et	3	main
me	doc_584615399785_item	3532841	et	4	main
me	doc_584615399785_item	3532844	et	4	main
peatume	doc_584615399785_item	3532878	et	4	main
kiri	doc_584615399786_item	3532894	et	3	main
eestlasest	doc_584615399786_item	3532903	et	3	main
te	doc_584615399786_item	3532909	et	4	main
soovite	doc_584615399786_item	3532911	et	3	main
reisite	doc_584615399786_item	3532913	et	3	main
kohtades	doc_584615399786_item	3532921	et	3	main
kirja	doc_584615399786_item	3532923	et	4	main
läheb	doc_584615399786_item	3532932	et	3	main
marininski	doc_584615399786_item	3532994	et	4	main
plaanite	doc_584615399787_item	3533020	et	3	main
venemaale	doc_584615399787_item	3533022	et	4	main
kirjutage	doc_584615399787_item	3533023	et	3	main
sellest	doc_584615399787_item	3533024	et	4	main
kiri	doc_584615399787_item	3533025	et	3	main
see	doc_584615399787_item	3533042	et	3	main
80	doc_584615399787_item	3533051	et	2	main
sõna	doc_584615399787_item	3533052	et	4	main
tere	doc_584615399787_item	3533053	et	3	main
aitah	doc_584615399787_item	3533056	et	4	main
kirjas	doc_584615399787_item	3533073	et	4	main
sa	doc_584615399787_item	3533075	et	3	main
sõidan	doc_584615399787_item	3533078	et	3	main
suvel	doc_584615399787_item	3533079	et	3	main
plaanin	doc_584615399787_item	3533082	et	3	main
sõbranna	doc_584615399787_item	3533088	et	4	main
sõidan	doc_584615399787_item	3533093	et	3	main
vaadata	doc_584615399787_item	3533119	et	4	main
huvitavaid	doc_584615399787_item	3533121	et	4	main
plats	doc_584615399787_item	3533124	et	4	main
kreml	doc_584615399787_item	3533125	et	3	main
metro	doc_584615399787_item	3533126	et	4	main
külastame	doc_584615399787_item	3533127	et	3	main
teatrit	doc_584615399787_item	3533128	et	3	main
kuidas	doc_584615399787_item	3533129	et	3	main
elad	doc_584615399787_item	3533131	et	3	main
kirjutage	doc_584615399787_item	3533132	et	3	main
minule	doc_584615399787_item	3533133	et	3	main
head	doc_584615399787_item	3533134	et	4	main
aega	doc_584615399787_item	3533135	et	4	main
plaanite	doc_584615399788_item	3533139	et	3	main
kirjutage	doc_584615399788_item	3533142	et	3	main
sõna	doc_584615399788_item	3533171	et	4	main
reet	doc_584615399788_item	3533173	et	4	main
kahjuks	doc_584615399788_item	3533184	et	4	main
juurde	doc_584615399788_item	3533188	et	4	main
suvel	doc_584615399788_item	3533189	et	3	main
ma	doc_584615399788_item	3533191	et	3	main
reisi	doc_584615399788_item	3533193	et	4	main
maksavad	doc_584615399785_item	3532855	et	3	main
2000	doc_584615399785_item	3532856	et	2	main
krooni	doc_584615399785_item	3532857	et	4	main
me	doc_584615399785_item	3532858	et	4	main
plaanime	doc_584615399785_item	3532859	et	3	main
olla	doc_584615399785_item	3532860	et	3	main
moskvas	doc_584615399785_item	3532861	et	4	main
1	doc_584615399785_item	3532862	et	2	main
nädala	doc_584615399785_item	3532863	et	3	main
me	doc_584615399785_item	3532864	et	4	main
ööbime	doc_584615399785_item	3532865	et	3	main
hotellis	doc_584615399785_item	3532866	et	3	main
juznaja	doc_584615399785_item	3532867	et	4	main
ja	doc_584615399785_item	3532868	et	3	main
moskva	doc_584615399785_item	3532869	et	4	main
me	doc_584615399785_item	3532870	et	4	main
plaanime	doc_584615399785_item	3532871	et	3	main
vaadata	doc_584615399785_item	3532872	et	4	main
museumit	doc_584615399785_item	3532873	et	4	main
te	doc_584615399785_item	3532775	et	4	main
venemaale	doc_584615399785_item	3532778	et	4	main
kirjutage	doc_584615399785_item	3532779	et	3	main
sellest	doc_584615399785_item	3532780	et	4	main
kiri	doc_584615399785_item	3532781	et	3	main
ööbite	doc_584615399785_item	3532795	et	3	main
kohtades	doc_584615399785_item	3532801	et	3	main
pikkus	doc_584615399785_item	3532805	et	4	main
80	doc_584615399785_item	3532807	et	2	main
käib	doc_584615399785_item	3532813	et	3	main
plaanime	doc_584615399785_item	3532819	et	3	main
kohta	doc_584615399785_item	3532833	et	4	main
sõidame	doc_584615399785_item	3532837	et	3	main
ostsime	doc_584615399785_item	3532845	et	3	main
piletit	doc_584615399785_item	3532846	et	3	main
reisi	doc_584615399785_item	3532847	et	4	main
bööro	doc_584615399785_item	3532848	et	4	main
travel	doc_584615399785_item	3532849	et	4	main
seal	doc_584615399785_item	3532850	et	4	main
on	doc_584615399785_item	3532851	et	4	main
soodustuse	doc_584615399785_item	3532852	et	4	main
10	doc_584615399785_item	3532853	et	2	main
piletid	doc_584615399785_item	3532854	et	3	main
kremli	doc_584615399785_item	3532874	et	3	main
sõidame	doc_584615399785_item	3532842	et	3	main
punane	doc_584615399785_item	3532875	et	4	main
ma	doc_584615399785_item	3532880	et	3	main
arvan	doc_584615399785_item	3532881	et	3	main
et	doc_584615399785_item	3532882	et	3	main
reisi	doc_584615399785_item	3532883	et	4	main
on	doc_584615399785_item	3532884	et	4	main
väga	doc_584615399785_item	3532885	et	3	main
huvitav	doc_584615399785_item	3532886	et	4	main
nägemisini	doc_584615399785_item	3532887	et	4	main
sinu	doc_584615399785_item	3532888	et	3	main
eesnimi	doc_584615399785_item	3532889	et	3	main
ootan	doc_584615399785_item	3532890	et	3	main
sinu	doc_584615399785_item	3532891	et	3	main
kirja	doc_584615399785_item	3532892	et	4	main
plaanite	doc_584615399786_item	3532896	et	3	main
reisi	doc_584615399786_item	3532897	et	4	main
sellest	doc_584615399786_item	3532900	et	4	main
kiri	doc_584615399786_item	3532901	et	3	main
kuhu	doc_584615399786_item	3532908	et	3	main
millega	doc_584615399786_item	3532912	et	3	main
ööbite	doc_584615399786_item	3532915	et	3	main
palju	doc_584615399786_item	3532917	et	4	main
umbes	doc_584615399786_item	3532926	et	4	main
kuidas	doc_584615399786_item	3532931	et	3	main
on	doc_584615399786_item	3532934	et	4	main
hästi	doc_584615399786_item	3532936	et	3	main
puhkusel	doc_584615399786_item	3532939	et	4	main
te	doc_584615399787_item	3533019	et	4	main
reisi	doc_584615399787_item	3533021	et	4	main
umbes	doc_584615399787_item	3533050	et	4	main
kirja	doc_584615399787_item	3533057	et	4	main
seal	doc_584615399787_item	3533085	et	4	main
moskvas	doc_584615399787_item	3533091	et	4	main
moskva	doc_584615399787_item	3533094	et	4	main
tahan	doc_584615399787_item	3533118	et	3	main
palju	doc_584615399787_item	3533120	et	4	main
punane	doc_584615399787_item	3533123	et	4	main
kiri	doc_584615399788_item	3533137	et	3	main
kiri	doc_584615399788_item	3533144	et	3	main
eestlasest	doc_584615399788_item	3533146	et	3	main
millal	doc_584615399788_item	3533149	et	3	main
ja	doc_584615399788_item	3533150	et	3	main
kuhu	doc_584615399788_item	3533151	et	3	main
sõita	doc_584615399788_item	3533153	et	3	main
soovite	doc_584615399788_item	3533154	et	3	main
millega	doc_584615399788_item	3533155	et	3	main
reisite	doc_584615399788_item	3533156	et	3	main
kus	doc_584615399788_item	3533157	et	3	main
ööbite	doc_584615399788_item	3533158	et	3	main
kui	doc_584615399788_item	3533159	et	3	main
pikkus	doc_584615399788_item	3533168	et	4	main
hästi	doc_584615399788_item	3533183	et	3	main
ei	doc_584615399788_item	3533185	et	4	main
moskvase	doc_584615399788_item	3533203	et	4	main
päeval	doc_584615399788_item	3533210	et	3	main
moskvas	doc_584615399788_item	3533222	et	4	main
me	doc_584615399788_item	3533223	et	4	main
oleme	doc_584615399788_item	3533224	et	3	main
kaks	doc_584615399788_item	3533225	et	3	main
päeva	doc_584615399788_item	3533226	et	4	main
esimesel	doc_584615399788_item	3533227	et	3	main
õhtul	doc_584615399788_item	3533238	et	3	main
žižel	doc_584615399788_item	3533242	et	2	main
hotellis	doc_584615399788_item	3533245	et	3	main
borodinskaja	doc_584615399788_item	3533250	et	4	main
panoram	doc_584615399788_item	3533251	et	4	main
puškini	doc_584615399788_item	3533252	et	2	main
tagasi	doc_584615399788_item	3533259	et	3	main
edasi	doc_584615399786_item	3532975	et	3	main
belgorodist	doc_584615399786_item	3532976	et	4	main
rongiga	doc_584615399786_item	3532977	et	4	main
piletid	doc_584615399786_item	3532978	et	3	main
me	doc_584615399786_item	3532979	et	4	main
juba	doc_584615399786_item	3532980	et	3	main
ostsime	doc_584615399786_item	3532981	et	3	main
sinna	doc_584615399786_item	3532982	et	3	main
ja	doc_584615399786_item	3532983	et	3	main
tagasi	doc_584615399786_item	3532984	et	3	main
peterburgisse	doc_584615399786_item	3532985	et	4	main
me	doc_584615399786_item	3532986	et	4	main
tahame	doc_584615399786_item	3532987	et	3	main
klassisõbranna	doc_584615399786_item	3532988	et	4	main
juures	doc_584615399786_item	3532989	et	4	main
kolm	doc_584615399786_item	3532990	et	3	main
päevast	doc_584615399786_item	3532991	et	4	main
puhata	doc_584615399786_item	3532992	et	4	main
lähme	doc_584615399786_item	3532993	et	3	main
oma	doc_584615399786_item	3532902	et	4	main
see	doc_584615399786_item	3532918	et	3	main
tere	doc_584615399786_item	3532929	et	3	main
mul	doc_584615399786_item	3532933	et	3	main
ma	doc_584615399786_item	3532937	et	3	main
oma	doc_584615399786_item	3532942	et	4	main
perega	doc_584615399786_item	3532943	et	3	main
vanemate	doc_584615399786_item	3532944	et	4	main
abikaasa	doc_584615399786_item	3532945	et	4	main
juurde	doc_584615399786_item	3532946	et	4	main
venemaale	doc_584615399786_item	3532947	et	4	main
sõita	doc_584615399786_item	3532948	et	3	main
nad	doc_584615399786_item	3532949	et	3	main
elavad	doc_584615399786_item	3532950	et	4	main
belgorodi	doc_584615399786_item	3532951	et	4	main
linnas	doc_584615399786_item	3532952	et	4	main
see	doc_584615399786_item	3532953	et	3	main
on	doc_584615399786_item	3532954	et	4	main
piirmaa	doc_584615399786_item	3532955	et	4	main
ukrainaga	doc_584615399786_item	3532956	et	4	main
seal	doc_584615399786_item	3532957	et	4	main
suvel	doc_584615399786_item	3532958	et	3	main
on	doc_584615399786_item	3532959	et	4	main
väga	doc_584615399786_item	3532960	et	3	main
soe	doc_584615399786_item	3532961	et	4	main
ja	doc_584615399786_item	3532962	et	3	main
ei	doc_584615399786_item	3532963	et	4	main
ole	doc_584615399786_item	3532964	et	4	main
vihma	doc_584615399786_item	3532965	et	4	main
me	doc_584615399786_item	3532966	et	4	main
sõidame	doc_584615399786_item	3532967	et	3	main
puhkusele	doc_584615399786_item	3532968	et	4	main
juuli	doc_584615399786_item	3532969	et	4	main
keskel	doc_584615399786_item	3532970	et	3	main
peterburgini	doc_584615399786_item	3532971	et	4	main
me	doc_584615399786_item	3532972	et	4	main
sõidame	doc_584615399786_item	3532973	et	3	main
bussiga	doc_584615399786_item	3532974	et	3	main
kahekümnekuuenda	doc_584615399787_item	3533099	et	4	main
juulini	doc_584615399787_item	3533100	et	3	main
ma	doc_584615399787_item	3533101	et	3	main
sõidan	doc_584615399787_item	3533102	et	3	main
bussiga	doc_584615399787_item	3533103	et	3	main
sankt	doc_584615399787_item	3533104	et	4	main
peterburgisse	doc_584615399787_item	3533105	et	4	main
aga	doc_584615399787_item	3533106	et	3	main
moskva	doc_584615399787_item	3533107	et	4	main
sõidan	doc_584615399787_item	3533108	et	3	main
rongiga	doc_584615399787_item	3533109	et	4	main
see	doc_584615399787_item	3533110	et	3	main
reis	doc_584615399787_item	3533111	et	4	main
maksab	doc_584615399787_item	3533112	et	3	main
kaks	doc_584615399787_item	3533113	et	3	main
tuhad	doc_584615399787_item	3533114	et	3	main
krooni	doc_584615399787_item	3533115	et	4	main
seal	doc_584615399787_item	3533116	et	4	main
ma	doc_584615399787_item	3533117	et	3	main
eestlasest	doc_584615399787_item	3533027	et	3	main
kirjutage	doc_584615399787_item	3533029	et	3	main
millal	doc_584615399787_item	3533030	et	3	main
ja	doc_584615399787_item	3533031	et	3	main
kuhu	doc_584615399787_item	3533032	et	3	main
te	doc_584615399787_item	3533033	et	4	main
sõita	doc_584615399787_item	3533034	et	3	main
soovite	doc_584615399787_item	3533035	et	3	main
millega	doc_584615399787_item	3533036	et	3	main
reisite	doc_584615399787_item	3533037	et	3	main
kus	doc_584615399787_item	3533038	et	3	main
ööbite	doc_584615399787_item	3533039	et	3	main
palju	doc_584615399787_item	3533041	et	4	main
maksab	doc_584615399787_item	3533043	et	3	main
kohtades	doc_584615399787_item	3533045	et	3	main
kirja	doc_584615399787_item	3533047	et	4	main
nõutav	doc_584615399787_item	3533048	et	4	main
kallis	doc_584615399787_item	3533054	et	4	main
ruttu	doc_584615399787_item	3533066	et	4	main
vastasid	doc_584615399787_item	3533067	et	4	main
mul	doc_584615399787_item	3533068	et	3	main
on	doc_584615399787_item	3533069	et	4	main
elavad	doc_584615399787_item	3533086	et	4	main
minu	doc_584615399787_item	3533087	et	3	main
ma	doc_584615399787_item	3533092	et	3	main
ja	doc_584615399787_item	3533096	et	3	main
kuni	doc_584615399787_item	3533098	et	3	main
kohti	doc_584615399787_item	3533122	et	4	main
reisi	doc_584615399788_item	3533140	et	4	main
palju	doc_584615399788_item	3533160	et	4	main
see	doc_584615399788_item	3533161	et	3	main
maksab	doc_584615399788_item	3533162	et	3	main
millistes	doc_584615399788_item	3533163	et	3	main
kohtades	doc_584615399788_item	3533164	et	3	main
peatute	doc_584615399788_item	3533165	et	4	main
umbes	doc_584615399788_item	3533169	et	4	main
suur	doc_584615399788_item	3533174	et	3	main
kirja	doc_584615399788_item	3533176	et	4	main
sest	doc_584615399788_item	3533190	et	4	main
venemaale	doc_584615399788_item	3533194	et	4	main
ma	doc_584615399788_item	3533195	et	3	main
sõidan	doc_584615399788_item	3533196	et	3	main
turizmi	doc_584615399788_item	3533206	et	4	main
firma	doc_584615399788_item	3533207	et	4	main
bussiga	doc_584615399788_item	3533208	et	3	main
moskvase	doc_584615399788_item	3533221	et	4	main
aga	doc_584615399788_item	3533237	et	3	main
baletti	doc_584615399788_item	3533241	et	4	main
praga	doc_584615399788_item	3533246	et	4	main
kolmandal	doc_584615399788_item	3533247	et	3	main
päeval	doc_584615399788_item	3533248	et	3	main
lähme	doc_584615399788_item	3533249	et	3	main
reis	doc_584615399788_item	3533260	et	4	main
eek	doc_584615399788_item	3533265	et	4	main
kiri	doc_584615399789_item	3533291	et	3	main
kirjutage	doc_584615399789_item	3533302	et	3	main
millal	doc_584615399789_item	3533303	et	3	main
te	doc_584615399789_item	3533306	et	4	main
millega	doc_584615399789_item	3533309	et	3	main
reisite	doc_584615399789_item	3533310	et	3	main
see	doc_584615399789_item	3533315	et	3	main
peatute	doc_584615399789_item	3533319	et	4	main
nõutav	doc_584615399789_item	3533321	et	4	main
pikkus	doc_584615399789_item	3533322	et	4	main
on	doc_584615399789_item	3533372	et	4	main
ma	doc_584615399789_item	3533384	et	3	main
ootan	doc_584615399789_item	3533425	et	3	main
sinult	doc_584615399789_item	3533426	et	3	main
loodan	doc_584615399789_item	3533429	et	3	main
sinu	doc_584615399789_item	3533436	et	3	main
sellest	doc_584615399790_item	3533446	et	4	main
kirjutage	doc_584615399790_item	3533451	et	3	main
kuhu	doc_584615399790_item	3533454	et	3	main
soovite	doc_584615399790_item	3533457	et	3	main
pikkus	doc_584615399790_item	3533471	et	4	main
eest	doc_584615399790_item	3533483	et	4	main
kuidas	doc_584615399790_item	3533484	et	3	main
sa	doc_584615399790_item	3533485	et	3	main
elad	doc_584615399790_item	3533486	et	3	main
mis	doc_584615399790_item	3533487	et	4	main
minu	doc_584615399790_item	3533493	et	3	main
terved	doc_584615399790_item	3533498	et	4	main
ja	doc_584615399790_item	3533533	et	3	main
kõik	doc_584615399787_item	3533070	et	4	main
hästi	doc_584615399787_item	3533071	et	3	main
küsisid	doc_584615399787_item	3533074	et	4	main
ma	doc_584615399787_item	3533077	et	3	main
suvel	doc_584615399787_item	3533080	et	3	main
reisi	doc_584615399787_item	3533083	et	4	main
venemaale	doc_584615399787_item	3533084	et	4	main
venemaale	doc_584615399788_item	3533141	et	4	main
sõbrale	doc_584615399788_item	3533147	et	3	main
kirja	doc_584615399788_item	3533166	et	4	main
nõutav	doc_584615399788_item	3533167	et	4	main
tere	doc_584615399788_item	3533172	et	3	main
tänu	doc_584615399788_item	3533175	et	4	main
eest	doc_584615399788_item	3533177	et	4	main
mulle	doc_584615399788_item	3533178	et	4	main
meeldib	doc_584615399788_item	3533179	et	3	main
et	doc_584615399788_item	3533180	et	3	main
sinul	doc_584615399788_item	3533181	et	3	main
sõida	doc_584615399788_item	3533186	et	4	main
peterburise	doc_584615399788_item	3533201	et	4	main
ja	doc_584615399788_item	3533202	et	3	main
esimesel	doc_584615399788_item	3533209	et	3	main
peatume	doc_584615399788_item	3533212	et	4	main
peterburis	doc_584615399788_item	3533213	et	4	main
ja	doc_584615399788_item	3533214	et	3	main
seal	doc_584615399788_item	3533215	et	4	main
vaatame	doc_584615399788_item	3533216	et	3	main
linna	doc_584615399788_item	3533217	et	4	main
päevas	doc_584615399788_item	3533228	et	3	main
algab	doc_584615399788_item	3533229	et	3	main
ekskursion	doc_584615399788_item	3533230	et	4	main
linnast	doc_584615399788_item	3533231	et	4	main
seal	doc_584615399788_item	3533232	et	4	main
me	doc_584615399788_item	3533233	et	4	main
jalutame	doc_584615399788_item	3533234	et	3	main
punasel	doc_584615399788_item	3533235	et	4	main
väljakul	doc_584615399788_item	3533236	et	3	main
3	doc_584615399788_item	3533197	et	2	main
päevaks	doc_584615399788_item	3533198	et	3	main
juunis	doc_584615399788_item	3533199	et	3	main
tutrega	doc_584615399788_item	3533200	et	4	main
me	doc_584615399788_item	3533211	et	4	main
sõidame	doc_584615399788_item	3533256	et	3	main
on	doc_584615399788_item	3533267	et	4	main
plaanite	doc_584615399789_item	3533293	et	3	main
venemaale	doc_584615399789_item	3533295	et	4	main
kirjutage	doc_584615399789_item	3533296	et	3	main
sellest	doc_584615399789_item	3533297	et	4	main
kiri	doc_584615399789_item	3533298	et	3	main
ööbite	doc_584615399789_item	3533312	et	3	main
millistes	doc_584615399789_item	3533317	et	3	main
sõber	doc_584615399789_item	3533331	et	3	main
juurde	doc_584615399789_item	3533367	et	4	main
bussiga	doc_584615399789_item	3533370	et	3	main
s	doc_584615399789_item	3533386	et	4	main
kolm	doc_584615399789_item	3533388	et	3	main
on	doc_584615399789_item	3533422	et	4	main
kõik	doc_584615399789_item	3533435	et	4	main
eesnimi	doc_584615399789_item	3533437	et	3	main
teatris	doc_584615399788_item	3533240	et	3	main
me	doc_584615399788_item	3533243	et	4	main
ööbime	doc_584615399788_item	3533244	et	3	main
aga	doc_584615399788_item	3533254	et	3	main
õhtul	doc_584615399788_item	3533255	et	3	main
eestise	doc_584615399788_item	3533258	et	4	main
see	doc_584615399788_item	3533266	et	3	main
väga	doc_584615399788_item	3533268	et	3	main
plaan	doc_584615399788_item	3533271	et	3	main
tule	doc_584615399788_item	3533274	et	4	main
tagasi	doc_584615399788_item	3533275	et	3	main
ma	doc_584615399788_item	3533276	et	3	main
kirjutan	doc_584615399788_item	3533277	et	3	main
sulle	doc_584615399788_item	3533278	et	3	main
kirja	doc_584615399788_item	3533279	et	4	main
ja	doc_584615399788_item	3533280	et	3	main
leppime	doc_584615399788_item	3533281	et	4	main
kokku	doc_584615399788_item	3533282	et	3	main
mida	doc_584615399788_item	3533283	et	4	main
me	doc_584615399788_item	3533284	et	4	main
veel	doc_584615399788_item	3533285	et	4	main
ette	doc_584615399788_item	3533286	et	4	main
võttame	doc_584615399788_item	3533287	et	4	main
nägamiseni	doc_584615399788_item	3533288	et	4	main
eesnimi	doc_584615399788_item	3533289	et	3	main
on	doc_584615399788_item	3533261	et	4	main
kallis	doc_584615399788_item	3533263	et	4	main
suve	doc_584615399788_item	3533270	et	4	main
me	doc_584615399788_item	3533273	et	4	main
te	doc_584615399789_item	3533292	et	4	main
kuhu	doc_584615399789_item	3533305	et	3	main
sõita	doc_584615399789_item	3533307	et	3	main
kui	doc_584615399789_item	3533313	et	3	main
maksab	doc_584615399789_item	3533316	et	3	main
kallis	doc_584615399789_item	3533330	et	4	main
talle	doc_584615399789_item	3533366	et	4	main
peterburgis	doc_584615399789_item	3533382	et	4	main
odav	doc_584615399789_item	3533423	et	3	main
vastus	doc_584615399789_item	3533427	et	3	main
plaanite	doc_584615399790_item	3533442	et	3	main
venemaale	doc_584615399790_item	3533444	et	4	main
kiri	doc_584615399790_item	3533447	et	3	main
eestlasest	doc_584615399790_item	3533449	et	3	main
millal	doc_584615399790_item	3533452	et	3	main
kus	doc_584615399790_item	3533460	et	3	main
see	doc_584615399790_item	3533464	et	3	main
millistes	doc_584615399790_item	3533466	et	3	main
umbes	doc_584615399790_item	3533472	et	4	main
80	doc_584615399790_item	3533473	et	2	main
sõna	doc_584615399790_item	3533474	et	4	main
toreda	doc_584615399790_item	3533481	et	3	main
kirja	doc_584615399790_item	3533482	et	4	main
abikaasa	doc_584615399790_item	3533494	et	4	main
ja	doc_584615399790_item	3533495	et	3	main
seal	doc_584615399790_item	3533535	et	4	main
elan	doc_584615399790_item	3533537	et	3	main
ma	doc_584615399790_item	3533539	et	3	main
valjak	doc_584615399790_item	3533543	et	4	main
tahan	doc_584615399790_item	3533550	et	3	main
millal	doc_584615399791_item	3533581	et	3	main
soovite	doc_584615399791_item	3533586	et	3	main
kui	doc_584615399791_item	3533591	et	3	main
see	doc_584615399791_item	3533593	et	3	main
millistes	doc_584615399791_item	3533595	et	3	main
peatute	doc_584615399791_item	3533597	et	4	main
umbes	doc_584615399791_item	3533601	et	4	main
on	doc_584615399791_item	3533607	et	4	main
nädala	doc_584615399791_item	3533610	et	3	main
mul	doc_584615399791_item	3533612	et	3	main
plaanin	doc_584615399791_item	3533616	et	3	main
bussiga	doc_584615399791_item	3533626	et	3	main
me	doc_584615399791_item	3533662	et	4	main
et	doc_584615399791_item	3533681	et	3	main
umbes	doc_584615399791_item	3533684	et	4	main
juuli	doc_584615399791_item	3533689	et	4	main
kui	doc_584615399791_item	3533691	et	3	main
ma	doc_584615399791_item	3533692	et	3	main
helistan	doc_584615399791_item	3533695	et	3	main
te	doc_584615399792_item	3533701	et	4	main
sellest	doc_584615399792_item	3533706	et	4	main
oma	doc_584615399792_item	3533708	et	4	main
kirjutage	doc_584615399792_item	3533711	et	3	main
kuhu	doc_584615399792_item	3533714	et	3	main
reisite	doc_584615399792_item	3533719	et	3	main
me	doc_584615399792_item	3533748	et	4	main
sõidame	doc_584615399792_item	3533749	et	3	main
me	doc_584615399792_item	3533755	et	4	main
jalutame	doc_584615399792_item	3533756	et	3	main
küllas	doc_584615399792_item	3533757	et	3	main
venna	doc_584615399792_item	3533758	et	3	main
kodus	doc_584615399792_item	3533762	et	4	main
arvan	doc_584615399792_item	3533764	et	3	main
ostma	doc_584615399792_item	3533766	et	3	main
ja	doc_584615399792_item	3533768	et	3	main
reisite	doc_584615399792_item	3533771	et	3	main
5000	doc_584615399792_item	3533773	et	2	main
2000	doc_584615399792_item	3533775	et	2	main
krooni	doc_584615399792_item	3533776	et	4	main
maksab	doc_584615399792_item	3533777	et	3	main
kiri	doc_584615399793_item	3533815	et	3	main
eestlasest	doc_584615399793_item	3533817	et	3	main
millal	doc_584615399793_item	3533820	et	3	main
te	doc_584615399793_item	3533823	et	4	main
sõita	doc_584615399793_item	3533824	et	3	main
soovite	doc_584615399793_item	3533825	et	3	main
millega	doc_584615399793_item	3533826	et	3	main
reisite	doc_584615399793_item	3533827	et	3	main
natuke	doc_584615399788_item	3533262	et	4	main
6000	doc_584615399788_item	3533264	et	2	main
ilus	doc_584615399788_item	3533269	et	4	main
kui	doc_584615399788_item	3533272	et	3	main
oma	doc_584615399789_item	3533299	et	4	main
eestlasest	doc_584615399789_item	3533300	et	3	main
sõbrale	doc_584615399789_item	3533301	et	3	main
ja	doc_584615399789_item	3533304	et	3	main
palju	doc_584615399789_item	3533314	et	4	main
umbes	doc_584615399789_item	3533323	et	4	main
80	doc_584615399789_item	3533324	et	2	main
sõna	doc_584615399789_item	3533325	et	4	main
09062005	doc_584615399789_item	3533326	et	2	main
sillamäe	doc_584615399789_item	3533327	et	3	main
minu	doc_584615399789_item	3533329	et	3	main
ma	doc_584615399789_item	3533368	et	3	main
sõidan	doc_584615399789_item	3533369	et	3	main
see	doc_584615399789_item	3533371	et	3	main
odavam	doc_584615399789_item	3533373	et	4	main
kui	doc_584615399789_item	3533374	et	3	main
lennuga	doc_584615399789_item	3533375	et	3	main
ma	doc_584615399789_item	3533376	et	3	main
tahan	doc_584615399789_item	3533377	et	3	main
ka	doc_584615399789_item	3533378	et	3	main
minu	doc_584615399789_item	3533379	et	3	main
sõpra	doc_584615399789_item	3533380	et	4	main
küllalista	doc_584615399789_item	3533383	et	4	main
ja	doc_584615399789_item	3533390	et	3	main
ma	doc_584615399789_item	3533424	et	3	main
me	doc_584615399789_item	3533431	et	4	main
koos	doc_584615399789_item	3533433	et	4	main
tervita	doc_584615399789_item	3533434	et	4	main
nägamiseni	doc_584615399789_item	3533438	et	4	main
te	doc_584615399790_item	3533441	et	4	main
kirjutage	doc_584615399790_item	3533445	et	3	main
ja	doc_584615399790_item	3533453	et	3	main
sõita	doc_584615399790_item	3533456	et	3	main
peatute	doc_584615399790_item	3533468	et	4	main
minu	doc_584615399790_item	3533476	et	3	main
on	doc_584615399790_item	3533488	et	4	main
uudist	doc_584615399790_item	3533489	et	3	main
hästi	doc_584615399790_item	3533492	et	3	main
tädi	doc_584615399790_item	3533534	et	4	main
moskvas	doc_584615399790_item	3533538	et	4	main
võib	doc_584615399790_item	3533544	et	3	main
veel	doc_584615399790_item	3533546	et	4	main
muusiumi	doc_584615399790_item	3533548	et	4	main
plaanite	doc_584615399791_item	3533571	et	3	main
venemaale	doc_584615399791_item	3533573	et	4	main
sellest	doc_584615399791_item	3533575	et	4	main
kiri	doc_584615399791_item	3533576	et	3	main
sõita	doc_584615399791_item	3533585	et	3	main
millega	doc_584615399791_item	3533587	et	3	main
pikkus	doc_584615399791_item	3533600	et	4	main
peterburi	doc_584615399791_item	3533623	et	4	main
aga	doc_584615399791_item	3533627	et	3	main
moskvasse	doc_584615399791_item	3533629	et	4	main
see	doc_584615399791_item	3533631	et	3	main
on	doc_584615399791_item	3533632	et	4	main
on	doc_584615399791_item	3533659	et	4	main
ajalooliseid	doc_584615399791_item	3533667	et	4	main
5000	doc_584615399791_item	3533685	et	2	main
reisi	doc_584615399789_item	3533294	et	4	main
soovite	doc_584615399789_item	3533308	et	3	main
kus	doc_584615399789_item	3533311	et	3	main
kohtades	doc_584615399789_item	3533318	et	3	main
kirja	doc_584615399789_item	3533320	et	4	main
tere	doc_584615399789_item	3533328	et	3	main
toivo	doc_584615399789_item	3533332	et	4	main
kuidas	doc_584615399789_item	3533333	et	3	main
läheb	doc_584615399789_item	3533334	et	3	main
suur	doc_584615399789_item	3533335	et	3	main
tänu	doc_584615399789_item	3533336	et	4	main
sinu	doc_584615399789_item	3533337	et	3	main
kirja	doc_584615399789_item	3533338	et	4	main
eest	doc_584615399789_item	3533339	et	4	main
mul	doc_584615399789_item	3533340	et	3	main
on	doc_584615399789_item	3533341	et	4	main
hea	doc_584615399789_item	3533342	et	4	main
meel	doc_584615399789_item	3533343	et	4	main
et	doc_584615399789_item	3533344	et	3	main
sain	doc_584615399789_item	3533345	et	3	main
kirja	doc_584615399789_item	3533346	et	4	main
sinult	doc_584615399789_item	3533347	et	3	main
junil	doc_584615399789_item	3533348	et	4	main
mul	doc_584615399789_item	3533349	et	3	main
on	doc_584615399789_item	3533350	et	4	main
kolm	doc_584615399789_item	3533351	et	3	main
nädalat	doc_584615399789_item	3533352	et	3	main
puhkus	doc_584615399789_item	3533353	et	3	main
ma	doc_584615399789_item	3533354	et	3	main
tahaksin	doc_584615399789_item	3533355	et	3	main
sõita	doc_584615399789_item	3533356	et	3	main
minu	doc_584615399789_item	3533357	et	3	main
õde	doc_584615399789_item	3533358	et	4	main
juures	doc_584615399789_item	3533359	et	4	main
ta	doc_584615399789_item	3533360	et	4	main
elab	doc_584615399789_item	3533361	et	3	main
moskvas	doc_584615399789_item	3533362	et	4	main
ja	doc_584615399789_item	3533363	et	3	main
kutsus	doc_584615399789_item	3533364	et	4	main
mind	doc_584615399789_item	3533365	et	4	main
sank	doc_584615399789_item	3533381	et	4	main
jään	doc_584615399789_item	3533385	et	3	main
peterburgis	doc_584615399789_item	3533387	et	4	main
päeva	doc_584615399789_item	3533389	et	4	main
sõidan	doc_584615399789_item	3533391	et	3	main
edasi	doc_584615399789_item	3533392	et	3	main
minu	doc_584615399789_item	3533393	et	3	main
õde	doc_584615399789_item	3533394	et	4	main
elab	doc_584615399789_item	3533395	et	3	main
kolmtoalines	doc_584615399789_item	3533396	et	4	main
korter	doc_584615399789_item	3533397	et	3	main
kui	doc_584615399789_item	3533398	et	3	main
on	doc_584615399789_item	3533399	et	4	main
sul	doc_584615399789_item	3533401	et	3	main
saad	doc_584615399789_item	3533402	et	4	main
ka	doc_584615399789_item	3533403	et	3	main
minuga	doc_584615399789_item	3533404	et	3	main
võimalikus	doc_584615399789_item	3533400	et	4	main
sõita	doc_584615399789_item	3533405	et	3	main
minu	doc_584615399789_item	3533406	et	3	main
õel	doc_584615399789_item	3533407	et	4	main
on	doc_584615399789_item	3533408	et	4	main
palju	doc_584615399789_item	3533409	et	4	main
ruumi	doc_584615399789_item	3533410	et	4	main
sa	doc_584615399789_item	3533411	et	3	main
saad	doc_584615399789_item	3533412	et	4	main
ööbima	doc_584615399789_item	3533413	et	3	main
seal	doc_584615399789_item	3533414	et	4	main
ka	doc_584615399789_item	3533415	et	3	main
bussipilet	doc_584615399789_item	3533416	et	3	main
maksab	doc_584615399789_item	3533417	et	3	main
ainult	doc_584615399789_item	3533418	et	4	main
800	doc_584615399789_item	3533419	et	2	main
krooni	doc_584615399789_item	3533420	et	4	main
see	doc_584615399789_item	3533421	et	3	main
ja	doc_584615399789_item	3533428	et	3	main
et	doc_584615399789_item	3533430	et	3	main
sõidame	doc_584615399789_item	3533432	et	3	main
kiri	doc_584615399790_item	3533440	et	3	main
reisi	doc_584615399790_item	3533443	et	4	main
reisite	doc_584615399790_item	3533459	et	3	main
ööbite	doc_584615399790_item	3533461	et	3	main
palju	doc_584615399790_item	3533463	et	4	main
maksab	doc_584615399790_item	3533465	et	3	main
kallis	doc_584615399790_item	3533477	et	4	main
sõber	doc_584615399790_item	3533478	et	3	main
aitäh	doc_584615399790_item	3533480	et	3	main
elan	doc_584615399790_item	3533491	et	3	main
lapsed	doc_584615399790_item	3533496	et	3	main
onu	doc_584615399790_item	3533532	et	4	main
ma	doc_584615399790_item	3533536	et	3	main
kinglasti	doc_584615399790_item	3533541	et	4	main
numbri	doc_584615399790_item	3533519	et	3	main
926	doc_584615399790_item	3533520	et	2	main
pilet	doc_584615399790_item	3533521	et	3	main
maksab	doc_584615399790_item	3533522	et	3	main
250	doc_584615399790_item	3533523	et	2	main
krooni	doc_584615399790_item	3533524	et	4	main
see	doc_584615399790_item	3533525	et	3	main
ei	doc_584615399790_item	3533526	et	4	main
ole	doc_584615399790_item	3533527	et	4	main
kallis	doc_584615399790_item	3533528	et	4	main
moskvas	doc_584615399790_item	3533529	et	4	main
elavad	doc_584615399790_item	3533530	et	4	main
minu	doc_584615399790_item	3533531	et	3	main
oma	doc_584615399790_item	3533448	et	4	main
sõbrale	doc_584615399790_item	3533450	et	3	main
te	doc_584615399790_item	3533455	et	4	main
millega	doc_584615399790_item	3533458	et	3	main
kui	doc_584615399790_item	3533462	et	3	main
kohtades	doc_584615399790_item	3533467	et	3	main
kirja	doc_584615399790_item	3533469	et	4	main
nõutav	doc_584615399790_item	3533470	et	4	main
tere	doc_584615399790_item	3533475	et	3	main
siksten	doc_584615399790_item	3533479	et	4	main
ma	doc_584615399790_item	3533490	et	3	main
on	doc_584615399790_item	3533497	et	4	main
oma	doc_584615399790_item	3533499	et	4	main
kirjas	doc_584615399790_item	3533500	et	4	main
palusid	doc_584615399790_item	3533501	et	4	main
et	doc_584615399790_item	3533502	et	3	main
kirjutaksin	doc_584615399790_item	3533503	et	3	main
oma	doc_584615399790_item	3533504	et	4	main
plaanist	doc_584615399790_item	3533505	et	3	main
nüüd	doc_584615399790_item	3533506	et	4	main
kirjutan	doc_584615399790_item	3533507	et	3	main
sellest	doc_584615399790_item	3533508	et	4	main
lähemalt	doc_584615399790_item	3533509	et	4	main
ma	doc_584615399790_item	3533510	et	3	main
arvan	doc_584615399790_item	3533511	et	3	main
juulis	doc_584615399790_item	3533512	et	3	main
ma	doc_584615399790_item	3533513	et	3	main
sõidan	doc_584615399790_item	3533514	et	3	main
moskvas	doc_584615399790_item	3533515	et	4	main
ma	doc_584615399790_item	3533516	et	3	main
sõidan	doc_584615399790_item	3533517	et	3	main
bussiga	doc_584615399790_item	3533518	et	3	main
punane	doc_584615399790_item	3533542	et	4	main
kiri	doc_584615399791_item	3533569	et	3	main
reisi	doc_584615399791_item	3533572	et	4	main
kirjutage	doc_584615399791_item	3533574	et	3	main
ja	doc_584615399791_item	3533582	et	3	main
kus	doc_584615399791_item	3533589	et	3	main
80	doc_584615399791_item	3533602	et	2	main
laine	doc_584615399791_item	3533605	et	4	main
kõik	doc_584615399791_item	3533608	et	4	main
pärast	doc_584615399791_item	3533611	et	4	main
ma	doc_584615399791_item	3533615	et	3	main
ma	doc_584615399791_item	3533624	et	3	main
peterburist	doc_584615399791_item	3533628	et	4	main
odavam	doc_584615399791_item	3533633	et	4	main
puhkus	doc_584615399791_item	3533660	et	3	main
ja	doc_584615399791_item	3533661	et	3	main
sillamäel	doc_584615399791_item	3533687	et	3	main
venemaale	doc_584615399792_item	3533704	et	4	main
sõita	doc_584615399792_item	3533716	et	3	main
millega	doc_584615399792_item	3533718	et	3	main
on	doc_584615399792_item	3533741	et	4	main
suur	doc_584615399792_item	3533742	et	3	main
uudes	doc_584615399792_item	3533743	et	4	main
suvel	doc_584615399792_item	3533744	et	3	main
aga	doc_584615399792_item	3533745	et	3	main
20	doc_584615399792_item	3533746	et	2	main
oli	doc_584615399792_item	3533760	et	3	main
bilettid	doc_584615399792_item	3533778	et	4	main
nagemisine	doc_584615399792_item	3533806	et	4	main
külastan	doc_584615399790_item	3533540	et	3	main
olla	doc_584615399790_item	3533545	et	3	main
paar	doc_584615399790_item	3533547	et	3	main
ma	doc_584615399790_item	3533549	et	3	main
lihtsalt	doc_584615399790_item	3533551	et	4	main
puhkada	doc_584615399790_item	3533552	et	4	main
olen	doc_584615399790_item	3533553	et	3	main
kõigest	doc_584615399790_item	3533554	et	4	main
sulle	doc_584615399790_item	3533555	et	3	main
kirjutanud	doc_584615399790_item	3533556	et	4	main
ootan	doc_584615399790_item	3533557	et	3	main
juba	doc_584615399790_item	3533558	et	3	main
pikasilmi	doc_584615399790_item	3533559	et	4	main
sind	doc_584615399790_item	3533560	et	4	main
kalli	doc_584615399790_item	3533561	et	3	main
kalli	doc_584615399790_item	3533562	et	3	main
parimate	doc_584615399790_item	3533563	et	4	main
soovidega	doc_584615399790_item	3533564	et	3	main
sinu	doc_584615399790_item	3533565	et	3	main
sõber	doc_584615399790_item	3533566	et	3	main
eesnimi	doc_584615399790_item	3533567	et	3	main
te	doc_584615399791_item	3533570	et	4	main
te	doc_584615399791_item	3533584	et	4	main
ööbite	doc_584615399791_item	3533590	et	3	main
maksab	doc_584615399791_item	3533594	et	3	main
kohtades	doc_584615399791_item	3533596	et	3	main
kirja	doc_584615399791_item	3533598	et	4	main
nõutav	doc_584615399791_item	3533599	et	4	main
tere	doc_584615399791_item	3533604	et	3	main
mul	doc_584615399791_item	3533606	et	3	main
hästi	doc_584615399791_item	3533609	et	3	main
venemaale	doc_584615399791_item	3533618	et	4	main
ma	doc_584615399791_item	3533619	et	3	main
sõidan	doc_584615399791_item	3533620	et	3	main
sõidan	doc_584615399791_item	3533625	et	3	main
tal	doc_584615399791_item	3533658	et	3	main
koos	doc_584615399791_item	3533663	et	4	main
käime	doc_584615399791_item	3533664	et	4	main
väljas	doc_584615399791_item	3533665	et	4	main
vaatame	doc_584615399791_item	3533666	et	3	main
juurde	doc_584615399791_item	3533679	et	4	main
läheb	doc_584615399791_item	3533682	et	3	main
krooni	doc_584615399791_item	3533686	et	4	main
olen	doc_584615399791_item	3533688	et	3	main
ma	doc_584615399791_item	3533694	et	3	main
nägemiseni	doc_584615399791_item	3533697	et	4	main
eesnimi	doc_584615399791_item	3533698	et	3	main
plaanite	doc_584615399792_item	3533702	et	3	main
kiri	doc_584615399792_item	3533707	et	3	main
sõbrale	doc_584615399792_item	3533710	et	3	main
millal	doc_584615399792_item	3533712	et	3	main
soovite	doc_584615399792_item	3533717	et	3	main
moskva	doc_584615399792_item	3533750	et	4	main
seal	doc_584615399792_item	3533751	et	4	main
me	doc_584615399792_item	3533752	et	4	main
venna	doc_584615399792_item	3533761	et	3	main
ma	doc_584615399792_item	3533763	et	3	main
sest	doc_584615399792_item	3533765	et	4	main
oma	doc_584615399793_item	3533816	et	4	main
kirjutage	doc_584615399793_item	3533819	et	3	main
kuhu	doc_584615399793_item	3533822	et	3	main
pikkus	doc_584615399793_item	3533839	et	4	main
kallis	doc_584615399793_item	3533844	et	4	main
täna	doc_584615399793_item	3533850	et	4	main
rõõmustasin	doc_584615399793_item	3533853	et	3	main
krooni	doc_584615399791_item	3533648	et	4	main
seal	doc_584615399791_item	3533649	et	4	main
ma	doc_584615399791_item	3533650	et	3	main
olen	doc_584615399791_item	3533651	et	3	main
üks	doc_584615399791_item	3533652	et	3	main
nädal	doc_584615399791_item	3533653	et	3	main
ma	doc_584615399791_item	3533654	et	3	main
ööbin	doc_584615399791_item	3533655	et	3	main
sõbranna	doc_584615399791_item	3533656	et	4	main
juures	doc_584615399791_item	3533657	et	4	main
oma	doc_584615399791_item	3533577	et	4	main
eestlasest	doc_584615399791_item	3533578	et	3	main
sõbrale	doc_584615399791_item	3533579	et	3	main
kirjutage	doc_584615399791_item	3533580	et	3	main
kuhu	doc_584615399791_item	3533583	et	3	main
reisite	doc_584615399791_item	3533588	et	3	main
palju	doc_584615399791_item	3533592	et	4	main
sõna	doc_584615399791_item	3533603	et	4	main
on	doc_584615399791_item	3533613	et	4	main
puhkus	doc_584615399791_item	3533614	et	3	main
reisi	doc_584615399791_item	3533617	et	4	main
15	doc_584615399791_item	3533621	et	2	main
juunil	doc_584615399791_item	3533622	et	3	main
rongiga	doc_584615399791_item	3533630	et	4	main
buss	doc_584615399791_item	3533634	et	3	main
väljub	doc_584615399791_item	3533635	et	3	main
kell	doc_584615399791_item	3533636	et	3	main
640	doc_584615399791_item	3533637	et	2	main
hommikul	doc_584615399791_item	3533638	et	3	main
kell	doc_584615399791_item	3533639	et	3	main
12	doc_584615399791_item	3533640	et	2	main
päeval	doc_584615399791_item	3533641	et	3	main
ma	doc_584615399791_item	3533642	et	3	main
olen	doc_584615399791_item	3533643	et	3	main
peterburis	doc_584615399791_item	3533644	et	4	main
pilet	doc_584615399791_item	3533645	et	3	main
maksab	doc_584615399791_item	3533646	et	3	main
120	doc_584615399791_item	3533647	et	2	main
kohti	doc_584615399791_item	3533668	et	4	main
ma	doc_584615399791_item	3533669	et	3	main
tahaksin	doc_584615399791_item	3533670	et	3	main
minna	doc_584615399791_item	3533671	et	3	main
teatris	doc_584615399791_item	3533672	et	3	main
22	doc_584615399791_item	3533673	et	2	main
juunil	doc_584615399791_item	3533674	et	3	main
ma	doc_584615399791_item	3533675	et	3	main
sõidan	doc_584615399791_item	3533676	et	3	main
moskvasse	doc_584615399791_item	3533677	et	4	main
venna	doc_584615399791_item	3533678	et	3	main
mõtlen	doc_584615399791_item	3533680	et	3	main
maksma	doc_584615399791_item	3533683	et	3	main
alguses	doc_584615399791_item	3533690	et	4	main
tulen	doc_584615399791_item	3533693	et	3	main
sulle	doc_584615399791_item	3533696	et	3	main
kiri	doc_584615399792_item	3533700	et	3	main
kirjutage	doc_584615399792_item	3533705	et	3	main
eestlasest	doc_584615399792_item	3533709	et	3	main
ja	doc_584615399792_item	3533713	et	3	main
ööbite	doc_584615399792_item	3533759	et	3	main
torti	doc_584615399792_item	3533767	et	4	main
see	doc_584615399792_item	3533770	et	3	main
ongi	doc_584615399792_item	3533804	et	4	main
kõik	doc_584615399792_item	3533805	et	4	main
tere	doc_584615399793_item	3533843	et	3	main
aga	doc_584615399793_item	3533863	et	3	main
koolis	doc_584615399793_item	3533866	et	4	main
seal	doc_584615399793_item	3533876	et	4	main
lastega	doc_584615399793_item	3533883	et	3	main
meid	doc_584615399793_item	3533886	et	4	main
väga	doc_584615399793_item	3533895	et	3	main
maksab	doc_584615399793_item	3533898	et	3	main
mitte	doc_584615399793_item	3533899	et	3	main
1	doc_584615399793_item	3533904	et	2	main
kõige	doc_584615399793_item	3533939	et	4	main
head	doc_584615399793_item	3533940	et	4	main
nägemiseni	doc_584615399793_item	3533941	et	4	main
eesnimi	doc_584615399793_item	3533942	et	3	main
oma	doc_584615399794_item	3533952	et	4	main
sõbrale	doc_584615399794_item	3533954	et	3	main
ja	doc_584615399794_item	3533957	et	3	main
maksab	doc_584615399794_item	3533969	et	3	main
peatute	doc_584615399794_item	3533972	et	4	main
nõutav	doc_584615399794_item	3533974	et	4	main
pikkus	doc_584615399794_item	3533975	et	4	main
ammu	doc_584615399794_item	3533982	et	4	main
puškino	doc_584615399794_item	3534064	et	2	main
asub	doc_584615399794_item	3534068	et	3	main
ekateriini	doc_584615399794_item	3534070	et	4	main
seal	doc_584615399794_item	3534071	et	4	main
läheme	doc_584615399794_item	3534072	et	3	main
ekskursiooniga	doc_584615399794_item	3534073	et	3	main
speterburgis	doc_584615399794_item	3534081	et	4	main
kallid	doc_584615399794_item	3534085	et	3	main
võõrastemajas	doc_584615399794_item	3534087	et	3	main
reisima	doc_584615399794_item	3534089	et	3	main
meie	doc_584615399794_item	3534090	et	4	main
pilete	doc_584615399794_item	3534097	et	4	main
kõik	doc_584615399794_item	3534099	et	4	main
kr	doc_584615399794_item	3534101	et	4	main
mõtlen	doc_584615399794_item	3534103	et	3	main
minule	doc_584615399794_item	3534105	et	3	main
plaanite	doc_584615399795_item	3534131	et	3	main
oma	doc_584615399795_item	3534137	et	4	main
sõbrale	doc_584615399795_item	3534139	et	3	main
kohtades	doc_584615399795_item	3534156	et	3	main
kallis	doc_584615399795_item	3534166	et	4	main
kuidas	doc_584615399795_item	3534168	et	3	main
sinu	doc_584615399795_item	3534172	et	3	main
tuju	doc_584615399795_item	3534176	et	4	main
on	doc_584615399795_item	3534178	et	4	main
sa	doc_584615399795_item	3534181	et	3	main
kirjutad	doc_584615399795_item	3534182	et	3	main
mulle	doc_584615399795_item	3534183	et	4	main
ksenii	doc_584615399795_item	3534223	et	4	main
jaa	doc_584615399795_item	3534235	et	3	main
on	doc_584615399795_item	3534245	et	4	main
teatrid	doc_584615399795_item	3534246	et	3	main
kiiresti	doc_584615399795_item	3534256	et	3	main
on	doc_584615399795_item	3534261	et	4	main
pidu	doc_584615399795_item	3534262	et	4	main
kakstuhat	doc_584615399795_item	3534271	et	4	main
kohtumiseni	doc_584615399795_item	3534287	et	4	main
sinu	doc_584615399795_item	3534288	et	3	main
plaanite	doc_584615399796_item	3534295	et	3	main
venemaale	doc_584615399796_item	3534297	et	4	main
soovite	doc_584615399796_item	3534310	et	3	main
kus	doc_584615399796_item	3534313	et	3	main
ööbite	doc_584615399796_item	3534314	et	3	main
kui	doc_584615399796_item	3534315	et	3	main
see	doc_584615399796_item	3534317	et	3	main
eest	doc_584615399792_item	3533779	et	4	main
aga	doc_584615399792_item	3533780	et	3	main
3000	doc_584615399792_item	3533781	et	2	main
krooni	doc_584615399792_item	3533782	et	4	main
kindlastid	doc_584615399792_item	3533783	et	4	main
venna	doc_584615399792_item	3533784	et	3	main
muuseimid	doc_584615399792_item	3533785	et	3	main
loomapark	doc_584615399792_item	3533786	et	3	main
restoranis	doc_584615399792_item	3533787	et	3	main
kindlasti	doc_584615399792_item	3533788	et	3	main
lähme	doc_584615399792_item	3533789	et	3	main
jaalutama	doc_584615399792_item	3533790	et	4	main
punane	doc_584615399792_item	3533791	et	4	main
välijak	doc_584615399792_item	3533792	et	4	main
ja	doc_584615399792_item	3533793	et	3	main
vaatame	doc_584615399792_item	3533794	et	3	main
fontaanid	doc_584615399792_item	3533795	et	4	main
kinoteatris	doc_584615399792_item	3533796	et	3	main
praga	doc_584615399792_item	3533797	et	4	main
ma	doc_584615399792_item	3533798	et	3	main
arvan	doc_584615399792_item	3533799	et	3	main
sest	doc_584615399792_item	3533800	et	4	main
sulle	doc_584615399792_item	3533801	et	3	main
meeldib	doc_584615399792_item	3533802	et	3	main
reisit	doc_584615399792_item	3533803	et	4	main
reisi	doc_584615399792_item	3533703	et	4	main
te	doc_584615399792_item	3533715	et	4	main
kus	doc_584615399792_item	3533720	et	3	main
ööbite	doc_584615399792_item	3533721	et	3	main
kui	doc_584615399792_item	3533722	et	3	main
palju	doc_584615399792_item	3533723	et	4	main
see	doc_584615399792_item	3533724	et	3	main
maksab	doc_584615399792_item	3533725	et	3	main
millistes	doc_584615399792_item	3533726	et	3	main
kohtades	doc_584615399792_item	3533727	et	3	main
peatute	doc_584615399792_item	3533728	et	4	main
kirja	doc_584615399792_item	3533729	et	4	main
nõutav	doc_584615399792_item	3533730	et	4	main
pikkus	doc_584615399792_item	3533731	et	4	main
umbes	doc_584615399792_item	3533732	et	4	main
80	doc_584615399792_item	3533733	et	2	main
sõna	doc_584615399792_item	3533734	et	4	main
tere	doc_584615399792_item	3533735	et	3	main
minu	doc_584615399792_item	3533736	et	3	main
kallis	doc_584615399792_item	3533737	et	4	main
sõber	doc_584615399792_item	3533738	et	3	main
ilmar	doc_584615399792_item	3533739	et	4	main
minul	doc_584615399792_item	3533740	et	3	main
iuli	doc_584615399792_item	3533747	et	4	main
lähme	doc_584615399792_item	3533753	et	3	main
muuseimi	doc_584615399792_item	3533754	et	4	main
lilled	doc_584615399792_item	3533769	et	3	main
maksab	doc_584615399792_item	3533772	et	3	main
krooni	doc_584615399792_item	3533774	et	4	main
kiri	doc_584615399793_item	3533808	et	3	main
sellest	doc_584615399793_item	3533814	et	4	main
sõbrale	doc_584615399793_item	3533818	et	3	main
ja	doc_584615399793_item	3533821	et	3	main
nõutav	doc_584615399793_item	3533838	et	4	main
anneli	doc_584615399793_item	3533846	et	4	main
sain	doc_584615399793_item	3533847	et	3	main
tehases	doc_584615399793_item	3533862	et	3	main
juulis	doc_584615399793_item	3533868	et	3	main
tahaksime	doc_584615399793_item	3533870	et	3	main
kogu	doc_584615399793_item	3533872	et	4	main
perega	doc_584615399793_item	3533873	et	3	main
tema	doc_584615399793_item	3533881	et	4	main
abikaasa	doc_584615399793_item	3533882	et	4	main
nad	doc_584615399793_item	3533884	et	3	main
sõidab	doc_584615399793_item	3533894	et	3	main
ja	doc_584615399793_item	3533897	et	3	main
krooni	doc_584615399793_item	3533903	et	4	main
eest	doc_584615399793_item	3533906	et	4	main
nende	doc_584615399793_item	3533908	et	4	main
korteris	doc_584615399793_item	3533909	et	3	main
ta	doc_584615399793_item	3533910	et	4	main
väga	doc_584615399793_item	3533911	et	3	main
suur	doc_584615399793_item	3533912	et	3	main
neljatoaline	doc_584615399793_item	3533913	et	4	main
nendel	doc_584615399793_item	3533914	et	4	main
on	doc_584615399793_item	3533915	et	4	main
erinevad	doc_584615399793_item	3533916	et	4	main
toad	doc_584615399793_item	3533917	et	3	main
külaliste	doc_584615399793_item	3533918	et	4	main
jaoks	doc_584615399793_item	3533919	et	4	main
seal	doc_584615399793_item	3533920	et	4	main
me	doc_584615399793_item	3533921	et	4	main
hakkame	doc_584615399793_item	3533922	et	3	main
ööbima	doc_584615399793_item	3533923	et	3	main
peatume	doc_584615399793_item	3533924	et	4	main
veel	doc_584615399793_item	3533925	et	4	main
mitmes	doc_584615399793_item	3533926	et	4	main
kohtades	doc_584615399793_item	3533927	et	3	main
veel	doc_584615399793_item	3533928	et	4	main
ei	doc_584615399793_item	3533929	et	4	main
endale	doc_584615399793_item	3533887	et	4	main
külla	doc_584615399793_item	3533888	et	4	main
me	doc_584615399793_item	3533889	et	4	main
sõidame	doc_584615399793_item	3533890	et	3	main
kiire	doc_584615399793_item	3533891	et	4	main
te	doc_584615399793_item	3533809	et	4	main
plaanite	doc_584615399793_item	3533810	et	3	main
reisi	doc_584615399793_item	3533811	et	4	main
venemaale	doc_584615399793_item	3533812	et	4	main
kirjutage	doc_584615399793_item	3533813	et	3	main
kus	doc_584615399793_item	3533828	et	3	main
ööbite	doc_584615399793_item	3533829	et	3	main
kui	doc_584615399793_item	3533830	et	3	main
palju	doc_584615399793_item	3533831	et	4	main
see	doc_584615399793_item	3533832	et	3	main
maksab	doc_584615399793_item	3533833	et	3	main
millistes	doc_584615399793_item	3533834	et	3	main
kohtades	doc_584615399793_item	3533835	et	3	main
umbes	doc_584615399793_item	3533840	et	4	main
80	doc_584615399793_item	3533841	et	2	main
sõbratar	doc_584615399793_item	3533845	et	3	main
sinu	doc_584615399793_item	3533848	et	3	main
väga	doc_584615399793_item	3533852	et	3	main
küsid	doc_584615399793_item	3533855	et	3	main
sõita	doc_584615399793_item	3533871	et	3	main
sada	doc_584615399793_item	3533902	et	4	main
pileti	doc_584615399793_item	3533905	et	3	main
elama	doc_584615399793_item	3533907	et	3	main
ongi	doc_584615399793_item	3533932	et	4	main
kiri	doc_584615399794_item	3533944	et	3	main
plaanite	doc_584615399794_item	3533946	et	3	main
eestlasest	doc_584615399794_item	3533953	et	3	main
millal	doc_584615399794_item	3533956	et	3	main
te	doc_584615399794_item	3533959	et	4	main
sõita	doc_584615399794_item	3533960	et	3	main
soovite	doc_584615399794_item	3533961	et	3	main
ööbite	doc_584615399794_item	3533965	et	3	main
millistes	doc_584615399794_item	3533970	et	3	main
umbes	doc_584615399794_item	3533976	et	4	main
palju	doc_584615399794_item	3533987	et	4	main
töötasin	doc_584615399794_item	3533988	et	3	main
viimase	doc_584615399794_item	3533989	et	3	main
aja	doc_584615399794_item	3533990	et	4	main
jooksul	doc_584615399794_item	3533991	et	4	main
mul	doc_584615399794_item	3533992	et	3	main
on	doc_584615399794_item	3533993	et	4	main
vanaviisi	doc_584615399794_item	3533996	et	4	main
ma	doc_584615399794_item	3533999	et	3	main
külla	doc_584615399794_item	3534001	et	4	main
pargid	doc_584615399794_item	3534041	et	4	main
seal	doc_584615399794_item	3534066	et	4	main
elad	doc_584615399794_item	3534076	et	3	main
hotellid	doc_584615399794_item	3534082	et	3	main
hommikusöökid	doc_584615399794_item	3534088	et	4	main
bussi	doc_584615399794_item	3534093	et	4	main
ma	doc_584615399794_item	3534102	et	3	main
reisi	doc_584615399795_item	3534132	et	4	main
sellest	doc_584615399795_item	3534135	et	4	main
te	doc_584615399795_item	3534144	et	4	main
soovite	doc_584615399795_item	3534146	et	3	main
reisite	doc_584615399795_item	3534148	et	3	main
ööbite	doc_584615399795_item	3534150	et	3	main
palju	doc_584615399795_item	3534152	et	4	main
millistes	doc_584615399795_item	3534155	et	3	main
nõutav	doc_584615399795_item	3534159	et	4	main
tere	doc_584615399795_item	3534164	et	3	main
kuidas	doc_584615399795_item	3534174	et	3	main
moskvas	doc_584615399795_item	3534218	et	4	main
peterburgis	doc_584615399795_item	3534219	et	4	main
me	doc_584615399795_item	3534220	et	4	main
näeme	doc_584615399795_item	3534221	et	3	main
kabeli	doc_584615399795_item	3534222	et	3	main
kloosteri	doc_584615399795_item	3534234	et	3	main
museum	doc_584615399795_item	3534247	et	4	main
plats	doc_584615399795_item	3534251	et	4	main
aga	doc_584615399795_item	3534253	et	3	main
kloosterisse	doc_584615399795_item	3534260	et	3	main
maksab	doc_584615399795_item	3534270	et	3	main
ole	doc_584615399795_item	3534275	et	4	main
sõpranna	doc_584615399795_item	3534289	et	4	main
eesnimi	doc_584615399795_item	3534290	et	3	main
kiri	doc_584615399796_item	3534293	et	3	main
eestlasest	doc_584615399796_item	3534302	et	3	main
kirjutage	doc_584615399796_item	3534304	et	3	main
kuhu	doc_584615399796_item	3534307	et	3	main
sõita	doc_584615399796_item	3534309	et	3	main
reisite	doc_584615399796_item	3534312	et	3	main
palju	doc_584615399796_item	3534316	et	4	main
millistes	doc_584615399796_item	3534319	et	3	main
pikkus	doc_584615399796_item	3534324	et	4	main
kallis	doc_584615399796_item	3534329	et	4	main
eile	doc_584615399796_item	3534331	et	3	main
peatute	doc_584615399793_item	3533836	et	4	main
kirja	doc_584615399793_item	3533837	et	4	main
sõna	doc_584615399793_item	3533842	et	4	main
kirja	doc_584615399793_item	3533849	et	4	main
ma	doc_584615399793_item	3533851	et	3	main
sa	doc_584615399793_item	3533854	et	3	main
ma	doc_584615399793_item	3533857	et	3	main
elan	doc_584615399793_item	3533858	et	3	main
abikaasa	doc_584615399793_item	3533860	et	4	main
endiselt	doc_584615399793_item	3533861	et	4	main
käivad	doc_584615399793_item	3533865	et	4	main
suvel	doc_584615399793_item	3533867	et	3	main
me	doc_584615399793_item	3533869	et	4	main
elavad	doc_584615399793_item	3533877	et	4	main
minu	doc_584615399793_item	3533878	et	3	main
õde	doc_584615399793_item	3533879	et	4	main
kutsuvad	doc_584615399793_item	3533885	et	4	main
rongiga	doc_584615399793_item	3533892	et	4	main
see	doc_584615399793_item	3533893	et	3	main
kiiresti	doc_584615399793_item	3533896	et	3	main
kallis	doc_584615399793_item	3533900	et	4	main
kokku	doc_584615399793_item	3533901	et	3	main
tea	doc_584615399793_item	3533930	et	4	main
kus	doc_584615399793_item	3533931	et	3	main
kuidas	doc_584615399793_item	3533856	et	3	main
hästi	doc_584615399793_item	3533859	et	3	main
lapsed	doc_584615399793_item	3533864	et	3	main
venemaale	doc_584615399793_item	3533874	et	4	main
moskva	doc_584615399793_item	3533875	et	4	main
ja	doc_584615399793_item	3533880	et	3	main
kiri	doc_584615399794_item	3533951	et	3	main
kirjutage	doc_584615399794_item	3533955	et	3	main
kuhu	doc_584615399794_item	3533958	et	3	main
reisite	doc_584615399794_item	3533963	et	3	main
palju	doc_584615399794_item	3533967	et	4	main
kohtades	doc_584615399794_item	3533971	et	3	main
kirja	doc_584615399794_item	3533973	et	4	main
kallis	doc_584615399794_item	3533980	et	4	main
sõber	doc_584615399794_item	3533981	et	3	main
pole	doc_584615399794_item	3533983	et	3	main
sinule	doc_584615399794_item	3533984	et	3	main
kirjutanud	doc_584615399794_item	3533985	et	4	main
seest	doc_584615399794_item	3533986	et	3	main
kõik	doc_584615399794_item	3533994	et	4	main
seal	doc_584615399794_item	3533997	et	4	main
kutsun	doc_584615399794_item	3534000	et	3	main
linnas	doc_584615399794_item	3534063	et	4	main
palee	doc_584615399794_item	3534069	et	4	main
ei	doc_584615399794_item	3534078	et	4	main
on	doc_584615399794_item	3534083	et	4	main
väga	doc_584615399794_item	3534084	et	3	main
hommikuti	doc_584615399794_item	3534086	et	4	main
firmaga	doc_584615399794_item	3534094	et	3	main
hind	doc_584615399794_item	3534098	et	3	main
2200	doc_584615399794_item	3534100	et	2	main
teekond	doc_584615399794_item	3534104	et	3	main
te	doc_584615399795_item	3534130	et	4	main
eestlasest	doc_584615399795_item	3534138	et	3	main
kirjutage	doc_584615399795_item	3534140	et	3	main
sõita	doc_584615399795_item	3534145	et	3	main
millega	doc_584615399795_item	3534147	et	3	main
kus	doc_584615399795_item	3534149	et	3	main
maksab	doc_584615399795_item	3534154	et	3	main
kirja	doc_584615399795_item	3534158	et	4	main
pikkus	doc_584615399795_item	3534160	et	4	main
umbes	doc_584615399795_item	3534161	et	4	main
80	doc_584615399795_item	3534162	et	2	main
käsi	doc_584615399795_item	3534169	et	4	main
kuidas	doc_584615399795_item	3534171	et	3	main
uueneik	doc_584615399795_item	3534230	et	4	main
me	doc_584615399795_item	3534232	et	4	main
punas	doc_584615399795_item	3534250	et	4	main
augustil	doc_584615399795_item	3534259	et	3	main
uspenie	doc_584615399795_item	3534263	et	4	main
pärast	doc_584615399795_item	3534264	et	4	main
krooni	doc_584615399795_item	3534272	et	4	main
see	doc_584615399795_item	3534273	et	3	main
kallis	doc_584615399795_item	3534276	et	4	main
koos	doc_584615399795_item	3534279	et	4	main
oma	doc_584615399796_item	3534301	et	4	main
millal	doc_584615399796_item	3534305	et	3	main
te	doc_584615399796_item	3534308	et	4	main
millega	doc_584615399796_item	3534311	et	3	main
maksab	doc_584615399796_item	3534318	et	3	main
peatute	doc_584615399796_item	3534321	et	4	main
kirja	doc_584615399796_item	3534322	et	4	main
sõna	doc_584615399796_item	3534327	et	4	main
kirja	doc_584615399796_item	3534335	et	4	main
oma	doc_584615399796_item	3534342	et	4	main
kõik	doc_584615399796_item	3534353	et	4	main
me	doc_584615399796_item	3534417	et	4	main
on	doc_584615399796_item	3534425	et	4	main
väga	doc_584615399796_item	3534426	et	3	main
soe	doc_584615399796_item	3534431	et	4	main
kui	doc_584615399796_item	3534432	et	3	main
sina	doc_584615399796_item	3534433	et	4	main
võid	doc_584615399796_item	3534436	et	4	main
meiga	doc_584615399796_item	3534438	et	4	main
ma	doc_584615399796_item	3534440	et	3	main
meeldib	doc_584615399796_item	3534444	et	3	main
selleks	doc_584615399796_item	3534446	et	4	main
on	doc_584615399796_item	3534448	et	4	main
kõik	doc_584615399796_item	3534449	et	4	main
ootan	doc_584615399796_item	3534450	et	3	main
sinu	doc_584615399796_item	3534451	et	3	main
plaanite	doc_584615399797_item	3534460	et	3	main
kõik	doc_584615399793_item	3533933	et	4	main
seekord	doc_584615399793_item	3533934	et	3	main
lõpetan	doc_584615399793_item	3533935	et	3	main
ootame	doc_584615399793_item	3533936	et	3	main
sinult	doc_584615399793_item	3533937	et	3	main
vastus	doc_584615399793_item	3533938	et	3	main
te	doc_584615399794_item	3533945	et	4	main
reisi	doc_584615399794_item	3533947	et	4	main
venemaale	doc_584615399794_item	3533948	et	4	main
kirjutage	doc_584615399794_item	3533949	et	3	main
millega	doc_584615399794_item	3533962	et	3	main
kus	doc_584615399794_item	3533964	et	3	main
kui	doc_584615399794_item	3533966	et	3	main
sõna	doc_584615399794_item	3533978	et	4	main
suvel	doc_584615399794_item	3533998	et	3	main
ja	doc_584615399794_item	3534057	et	3	main
restoranis	doc_584615399794_item	3534058	et	3	main
õhtusööma	doc_584615399794_item	3534059	et	4	main
meie	doc_584615399794_item	3534060	et	4	main
plaanime	doc_584615399794_item	3534061	et	3	main
võõrastemajas	doc_584615399794_item	3534062	et	3	main
paleed	doc_584615399794_item	3534074	et	4	main
puškinos	doc_584615399794_item	3534077	et	2	main
kallis	doc_584615399794_item	3534079	et	4	main
aga	doc_584615399794_item	3534080	et	3	main
ühe	doc_584615399794_item	3534092	et	4	main
bussireisid	doc_584615399794_item	3534096	et	3	main
meeldib	doc_584615399794_item	3534106	et	3	main
ma	doc_584615399794_item	3534107	et	3	main
sinule	doc_584615399794_item	3534108	et	3	main
s	doc_584615399794_item	3534109	et	4	main
peterburgist	doc_584615399794_item	3534110	et	4	main
saatan	doc_584615399794_item	3534111	et	3	main
kirja	doc_584615399794_item	3534112	et	4	main
või	doc_584615399794_item	3534113	et	4	main
helistan	doc_584615399794_item	3534114	et	3	main
ma	doc_584615399794_item	3534115	et	3	main
sellega	doc_584615399794_item	3534116	et	3	main
lõpetan	doc_584615399794_item	3534117	et	3	main
ja	doc_584615399794_item	3534118	et	3	main
jään	doc_584615399794_item	3534119	et	3	main
ootama	doc_584615399794_item	3534120	et	3	main
sinu	doc_584615399794_item	3534121	et	3	main
kirja	doc_584615399794_item	3534122	et	4	main
südamlike	doc_584615399794_item	3534123	et	3	main
tervistustega	doc_584615399794_item	3534124	et	4	main
nägemisini	doc_584615399794_item	3534125	et	4	main
140605	doc_584615399794_item	3534126	et	2	main
perekonnanimi	doc_584615399794_item	3534127	et	3	main
sellest	doc_584615399794_item	3533950	et	4	main
see	doc_584615399794_item	3533968	et	3	main
80	doc_584615399794_item	3533977	et	2	main
tere	doc_584615399794_item	3533979	et	3	main
korras	doc_584615399794_item	3533995	et	4	main
puhata	doc_584615399794_item	3534002	et	4	main
kaks	doc_584615399794_item	3534003	et	3	main
kuud	doc_584615399794_item	3534004	et	4	main
mul	doc_584615399794_item	3534005	et	3	main
on	doc_584615399794_item	3534006	et	4	main
puhkus	doc_584615399794_item	3534007	et	3	main
juulis	doc_584615399794_item	3534008	et	3	main
ja	doc_584615399794_item	3534009	et	3	main
augustis	doc_584615399794_item	3534010	et	3	main
juulis	doc_584615399794_item	3534011	et	3	main
ma	doc_584615399794_item	3534012	et	3	main
plaanin	doc_584615399794_item	3534013	et	3	main
reisi	doc_584615399794_item	3534014	et	4	main
venemaale	doc_584615399794_item	3534015	et	4	main
võimalik	doc_584615399794_item	3534016	et	3	main
ma	doc_584615399794_item	3534017	et	3	main
sõitajan	doc_584615399794_item	3534018	et	4	main
speterburgis	doc_584615399794_item	3534019	et	4	main
ma	doc_584615399794_item	3534020	et	3	main
tahaks	doc_584615399794_item	3534021	et	3	main
koos	doc_584615399794_item	3534022	et	4	main
abikaasaga	doc_584615399794_item	3534023	et	3	main
sõita	doc_584615399794_item	3534024	et	3	main
meie	doc_584615399794_item	3534025	et	4	main
plaanime	doc_584615399794_item	3534026	et	3	main
speterburgis	doc_584615399794_item	3534027	et	4	main
viiest	doc_584615399794_item	3534028	et	4	main
juulist	doc_584615399794_item	3534029	et	4	main
kuni	doc_584615399794_item	3534030	et	3	main
kümnendal	doc_584615399794_item	3534031	et	3	main
juulini	doc_584615399794_item	3534032	et	3	main
puhata	doc_584615399794_item	3534033	et	4	main
seal	doc_584615399794_item	3534034	et	4	main
meie	doc_584615399794_item	3534035	et	4	main
vaatame	doc_584615399794_item	3534036	et	3	main
lossie	doc_584615399794_item	3534037	et	4	main
ja	doc_584615399794_item	3534038	et	3	main
paleesid	doc_584615399794_item	3534039	et	3	main
ja	doc_584615399794_item	3534040	et	3	main
aermitaži	doc_584615399794_item	3534042	et	2	main
oraninbaumi	doc_584615399794_item	3534043	et	4	main
pavlovi	doc_584615399794_item	3534044	et	4	main
petergoff	doc_584615399794_item	3534045	et	4	main
vaatame	doc_584615399794_item	3534046	et	3	main
huvitavad	doc_584615399794_item	3534047	et	4	main
ja	doc_584615399794_item	3534048	et	3	main
ilusad	doc_584615399794_item	3534049	et	3	main
looduslikult	doc_584615399794_item	3534050	et	4	main
kaunid	doc_584615399794_item	3534051	et	4	main
paigad	doc_584615399794_item	3534052	et	3	main
õhtuti	doc_584615399794_item	3534053	et	3	main
meie	doc_584615399794_item	3534054	et	4	main
läheme	doc_584615399794_item	3534055	et	3	main
teatrisse	doc_584615399794_item	3534056	et	3	main
elama	doc_584615399794_item	3534065	et	3	main
lähedal	doc_584615399794_item	3534067	et	4	main
vaatama	doc_584615399794_item	3534075	et	3	main
sõitajame	doc_584615399794_item	3534091	et	4	main
estonia	doc_584615399794_item	3534095	et	4	main
kiri	doc_584615399795_item	3534129	et	3	main
kirjutage	doc_584615399795_item	3534134	et	3	main
millal	doc_584615399795_item	3534141	et	3	main
kuhu	doc_584615399795_item	3534143	et	3	main
peatute	doc_584615399795_item	3534157	et	4	main
minu	doc_584615399795_item	3534165	et	3	main
käib	doc_584615399795_item	3534170	et	3	main
terves	doc_584615399795_item	3534173	et	4	main
mul	doc_584615399795_item	3534177	et	3	main
kõik	doc_584615399795_item	3534179	et	4	main
hästi	doc_584615399795_item	3534180	et	3	main
klooster	doc_584615399795_item	3534231	et	3	main
seal	doc_584615399795_item	3534236	et	4	main
vaja	doc_584615399795_item	3534237	et	4	main
süüja	doc_584615399795_item	3534238	et	4	main
seal	doc_584615399795_item	3534239	et	4	main
me	doc_584615399795_item	3534240	et	4	main
vaatame	doc_584615399795_item	3534241	et	3	main
relikviad	doc_584615399795_item	3534242	et	4	main
pühakupildid	doc_584615399795_item	3534243	et	4	main
moskvasse	doc_584615399795_item	3534244	et	4	main
siinagoogi	doc_584615399795_item	3534225	et	4	main
mošee	doc_584615399795_item	3534226	et	2	main
moskas	doc_584615399795_item	3534227	et	4	main
me	doc_584615399795_item	3534228	et	4	main
venemaale	doc_584615399795_item	3534133	et	4	main
kiri	doc_584615399795_item	3534136	et	3	main
ja	doc_584615399795_item	3534142	et	3	main
kui	doc_584615399795_item	3534151	et	3	main
see	doc_584615399795_item	3534153	et	3	main
sõna	doc_584615399795_item	3534163	et	4	main
leida	doc_584615399795_item	3534167	et	3	main
sinu	doc_584615399795_item	3534175	et	3	main
et	doc_584615399795_item	3534184	et	3	main
sinu	doc_584615399795_item	3534185	et	3	main
puhkus	doc_584615399795_item	3534186	et	3	main
on	doc_584615399795_item	3534187	et	4	main
ka	doc_584615399795_item	3534188	et	3	main
augustis	doc_584615399795_item	3534189	et	3	main
ma	doc_584615399795_item	3534190	et	3	main
tahaksin	doc_584615399795_item	3534191	et	3	main
sinuga	doc_584615399795_item	3534192	et	3	main
venemaale	doc_584615399795_item	3534193	et	4	main
reisida	doc_584615399795_item	3534194	et	3	main
reisibüroo	doc_584615399795_item	3534195	et	4	main
pakub	doc_584615399795_item	3534196	et	3	main
reisi	doc_584615399795_item	3534197	et	4	main
pühades	doc_584615399795_item	3534198	et	3	main
kohtad	doc_584615399795_item	3534199	et	3	main
see	doc_584615399795_item	3534200	et	3	main
reisi	doc_584615399795_item	3534201	et	4	main
sinu	doc_584615399795_item	3534202	et	3	main
meeldid	doc_584615399795_item	3534203	et	3	main
sinna	doc_584615399795_item	3534204	et	3	main
on	doc_584615399795_item	3534205	et	4	main
vaja	doc_584615399795_item	3534206	et	4	main
viisat	doc_584615399795_item	3534207	et	3	main
aga	doc_584615399795_item	3534208	et	3	main
mul	doc_584615399795_item	3534209	et	3	main
on	doc_584615399795_item	3534210	et	4	main
venekondus	doc_584615399795_item	3534211	et	4	main
me	doc_584615399795_item	3534212	et	4	main
soidame	doc_584615399795_item	3534213	et	4	main
rongiga	doc_584615399795_item	3534214	et	4	main
peterburgis	doc_584615399795_item	3534215	et	4	main
aga	doc_584615399795_item	3534216	et	3	main
siis	doc_584615399795_item	3534217	et	3	main
õndsa	doc_584615399795_item	3534224	et	3	main
asub	doc_584615399795_item	3534229	et	3	main
ööbime	doc_584615399795_item	3534233	et	3	main
me	doc_584615399795_item	3534248	et	4	main
kreml	doc_584615399795_item	3534252	et	3	main
suurem	doc_584615399795_item	3534254	et	4	main
väsimus	doc_584615399795_item	3534257	et	4	main
kahekümnekaheksandal	doc_584615399795_item	3534258	et	4	main
reisi	doc_584615399795_item	3534269	et	4	main
see	doc_584615399795_item	3534277	et	3	main
140605	doc_584615399795_item	3534291	et	2	main
te	doc_584615399796_item	3534294	et	4	main
sõbrale	doc_584615399796_item	3534303	et	3	main
ja	doc_584615399796_item	3534306	et	3	main
nõutav	doc_584615399796_item	3534323	et	4	main
laine	doc_584615399796_item	3534330	et	4	main
sind	doc_584615399796_item	3534338	et	4	main
küsid	doc_584615399796_item	3534344	et	3	main
sina	doc_584615399796_item	3534345	et	4	main
kuidas	doc_584615399796_item	3534346	et	3	main
tänan	doc_584615399796_item	3534349	et	3	main
on	doc_584615399796_item	3534356	et	4	main
ma	doc_584615399796_item	3534412	et	3	main
eestis	doc_584615399796_item	3534414	et	3	main
sõdame	doc_584615399796_item	3534418	et	4	main
tahaks	doc_584615399796_item	3534434	et	3	main
arvan	doc_584615399796_item	3534441	et	3	main
et	doc_584615399796_item	3534442	et	3	main
korraks	doc_584615399796_item	3534447	et	4	main
näeme	doc_584615399795_item	3534249	et	3	main
linnas	doc_584615399795_item	3534255	et	4	main
on	doc_584615399795_item	3534265	et	4	main
tagasi	doc_584615399795_item	3534266	et	3	main
koju	doc_584615399795_item	3534267	et	3	main
see	doc_584615399795_item	3534268	et	3	main
ei	doc_584615399795_item	3534274	et	4	main
on	doc_584615399795_item	3534278	et	4	main
viisaga	doc_584615399795_item	3534280	et	4	main
ma	doc_584615399795_item	3534281	et	3	main
ootan	doc_584615399795_item	3534282	et	3	main
sind	doc_584615399795_item	3534283	et	4	main
sillamäel	doc_584615399795_item	3534284	et	3	main
25	doc_584615399795_item	3534285	et	2	main
augustil	doc_584615399795_item	3534286	et	3	main
sillamäel	doc_584615399796_item	3534455	et	3	main
14062005	doc_584615399796_item	3534456	et	2	main
reisi	doc_584615399796_item	3534296	et	4	main
kirjutage	doc_584615399796_item	3534298	et	3	main
sellest	doc_584615399796_item	3534299	et	4	main
kiri	doc_584615399796_item	3534300	et	3	main
80	doc_584615399796_item	3534326	et	2	main
kätte	doc_584615399796_item	3534336	et	4	main
kirjas	doc_584615399796_item	3534343	et	4	main
korras	doc_584615399796_item	3534354	et	4	main
mul	doc_584615399796_item	3534355	et	3	main
juunis	doc_584615399796_item	3534360	et	3	main
mul	doc_584615399796_item	3534361	et	3	main
algab	doc_584615399796_item	3534362	et	3	main
puhkus	doc_584615399796_item	3534363	et	3	main
koos	doc_584615399796_item	3534364	et	4	main
abikaasaga	doc_584615399796_item	3534365	et	3	main
me	doc_584615399796_item	3534366	et	4	main
soovime	doc_584615399796_item	3534367	et	4	main
sõita	doc_584615399796_item	3534368	et	3	main
koos	doc_584615399796_item	3534369	et	4	main
perega	doc_584615399796_item	3534370	et	3	main
venemaale	doc_584615399796_item	3534371	et	4	main
musta	doc_584615399796_item	3534372	et	4	main
mere	doc_584615399796_item	3534373	et	3	main
äärde	doc_584615399796_item	3534374	et	4	main
me	doc_584615399796_item	3534375	et	4	main
sõidame	doc_584615399796_item	3534376	et	3	main
sinna	doc_584615399796_item	3534377	et	3	main
rongiga	doc_584615399796_item	3534378	et	4	main
sest	doc_584615399796_item	3534379	et	4	main
lennukiga	doc_584615399796_item	3534380	et	3	main
on	doc_584615399796_item	3534381	et	4	main
kallim	doc_584615399796_item	3534382	et	4	main
ja	doc_584615399796_item	3534383	et	3	main
mina	doc_584615399796_item	3534384	et	4	main
väga	doc_584615399796_item	3534385	et	3	main
kardan	doc_584615399796_item	3534386	et	4	main
lennata	doc_584615399796_item	3534387	et	4	main
lennukiga	doc_584615399796_item	3534388	et	3	main
me	doc_584615399796_item	3534389	et	4	main
sõdame	doc_584615399796_item	3534390	et	4	main
puhkasemajja	doc_584615399796_item	3534391	et	3	main
adleri	doc_584615399796_item	3534392	et	4	main
krooni	doc_584615399796_item	3534404	et	4	main
tean	doc_584615399796_item	3534413	et	3	main
on	doc_584615399796_item	3534415	et	4	main
kallim	doc_584615399796_item	3534416	et	4	main
päevaks	doc_584615399796_item	3534421	et	3	main
väga	doc_584615399796_item	3534430	et	3	main
koos	doc_584615399796_item	3534439	et	4	main
kohtades	doc_584615399796_item	3534320	et	3	main
umbes	doc_584615399796_item	3534325	et	4	main
tere	doc_584615399796_item	3534328	et	3	main
tänan	doc_584615399796_item	3534337	et	3	main
kirja	doc_584615399796_item	3534340	et	4	main
eest	doc_584615399796_item	3534341	et	4	main
mul	doc_584615399796_item	3534347	et	3	main
sulle	doc_584615399796_item	3534357	et	3	main
hea	doc_584615399796_item	3534358	et	4	main
uudis	doc_584615399796_item	3534359	et	3	main
linnasse	doc_584615399796_item	3534393	et	4	main
seal	doc_584615399796_item	3534394	et	4	main
me	doc_584615399796_item	3534395	et	4	main
hakkame	doc_584615399796_item	3534396	et	3	main
ööbima	doc_584615399796_item	3534397	et	3	main
ja	doc_584615399796_item	3534398	et	3	main
sööma	doc_584615399796_item	3534399	et	4	main
see	doc_584615399796_item	3534400	et	3	main
maksab	doc_584615399796_item	3534401	et	3	main
umbes	doc_584615399796_item	3534402	et	4	main
300	doc_584615399796_item	3534403	et	2	main
sain	doc_584615399796_item	3534332	et	3	main
mina	doc_584615399796_item	3534333	et	4	main
sinult	doc_584615399796_item	3534334	et	3	main
väga	doc_584615399796_item	3534339	et	3	main
läheb	doc_584615399796_item	3534348	et	3	main
küsimast	doc_584615399796_item	3534350	et	4	main
mul	doc_584615399796_item	3534351	et	3	main
on	doc_584615399796_item	3534352	et	4	main
päeva	doc_584615399796_item	3534405	et	4	main
see	doc_584615399796_item	3534406	et	3	main
hind	doc_584615399796_item	3534407	et	3	main
on	doc_584615399796_item	3534408	et	4	main
kahekümneks	doc_584615399796_item	3534420	et	4	main
ilus	doc_584615399796_item	3534427	et	4	main
loodus	doc_584615399796_item	3534428	et	4	main
ja	doc_584615399796_item	3534429	et	3	main
siis	doc_584615399796_item	3534435	et	3	main
sinule	doc_584615399796_item	3534443	et	3	main
vastust	doc_584615399796_item	3534452	et	4	main
sinu	doc_584615399796_item	3534453	et	3	main
eesnimi	doc_584615399796_item	3534454	et	3	main
kiri	doc_584615399797_item	3534458	et	3	main
kiri	doc_584615399797_item	3534465	et	3	main
oma	doc_584615399797_item	3534466	et	4	main
sõbrale	doc_584615399797_item	3534468	et	3	main
kirja	doc_584615399797_item	3534487	et	4	main
umbes	doc_584615399797_item	3534490	et	4	main
kallis	doc_584615399797_item	3534494	et	4	main
on	doc_584615399797_item	3534538	et	4	main
odavam	doc_584615399797_item	3534539	et	4	main
aga	doc_584615399797_item	3534540	et	3	main
mul	doc_584615399797_item	3534541	et	3	main
on	doc_584615399797_item	3534542	et	4	main
pean	doc_584615399797_item	3534546	et	4	main
tegema	doc_584615399797_item	3534547	et	3	main
viisa	doc_584615399797_item	3534549	et	4	main
maksab	doc_584615399797_item	3534550	et	3	main
viis	doc_584615399797_item	3534551	et	4	main
vähe	doc_584615399797_item	3534557	et	3	main
aega	doc_584615399797_item	3534558	et	4	main
aastal	doc_584615399797_item	3534560	et	3	main
planeerin	doc_584615399797_item	3534562	et	3	main
sõita	doc_584615399797_item	3534564	et	3	main
tulas	doc_584615399797_item	3534567	et	4	main
ööbin	doc_584615399797_item	3534569	et	3	main
moskvasse	doc_584615399797_item	3534570	et	4	main
seal	doc_584615399797_item	3534571	et	4	main
odavam	doc_584615399797_item	3534582	et	4	main
teisel	doc_584615399797_item	3534584	et	4	main
vaadata	doc_584615399797_item	3534589	et	4	main
tuju	doc_584615399797_item	3534597	et	4	main
krooni	doc_584615399797_item	3534619	et	4	main
aitab	doc_584615399797_item	3534620	et	3	main
on	doc_584615399797_item	3534639	et	4	main
sellega	doc_584615399797_item	3534646	et	3	main
tervita	doc_584615399797_item	3534649	et	4	main
vanemaid	doc_584615399797_item	3534651	et	4	main
ja	doc_584615399797_item	3534652	et	3	main
normalne	doc_584615399796_item	3534409	et	4	main
sest	doc_584615399796_item	3534410	et	4	main
kui	doc_584615399796_item	3534411	et	3	main
sinna	doc_584615399796_item	3534419	et	3	main
musta	doc_584615399796_item	3534422	et	4	main
mere	doc_584615399796_item	3534423	et	3	main
ääres	doc_584615399796_item	3534424	et	4	main
sõita	doc_584615399796_item	3534437	et	3	main
ka	doc_584615399796_item	3534445	et	3	main
venemaale	doc_584615399797_item	3534462	et	4	main
ja	doc_584615399797_item	3534471	et	3	main
soovite	doc_584615399797_item	3534475	et	3	main
ööbite	doc_584615399797_item	3534479	et	3	main
nõutav	doc_584615399797_item	3534488	et	4	main
80	doc_584615399797_item	3534491	et	2	main
tere	doc_584615399797_item	3534493	et	3	main
sõber	doc_584615399797_item	3534495	et	3	main
laine	doc_584615399797_item	3534496	et	4	main
sain	doc_584615399797_item	3534497	et	3	main
sinu	doc_584615399797_item	3534498	et	3	main
vabanda	doc_584615399797_item	3534504	et	4	main
et	doc_584615399797_item	3534505	et	3	main
ma	doc_584615399797_item	3534545	et	3	main
jatkub	doc_584615399797_item	3534556	et	4	main
reisi	doc_584615399797_item	3534461	et	4	main
kirjutage	doc_584615399797_item	3534469	et	3	main
te	doc_584615399797_item	3534473	et	4	main
kirja	doc_584615399797_item	3534499	et	4	main
ma	doc_584615399797_item	3534506	et	3	main
kaua	doc_584615399797_item	3534509	et	3	main
kirjutanud	doc_584615399797_item	3534510	et	4	main
ma	doc_584615399797_item	3534511	et	3	main
ei	doc_584615399797_item	3534512	et	4	main
saanud	doc_584615399797_item	3534513	et	4	main
sulle	doc_584615399797_item	3534514	et	3	main
kohe	doc_584615399797_item	3534515	et	4	main
vastata	doc_584615399797_item	3534516	et	4	main
mul	doc_584615399797_item	3534517	et	3	main
ei	doc_584615399797_item	3534518	et	4	main
ole	doc_584615399797_item	3534519	et	4	main
üldse	doc_584615399797_item	3534520	et	3	main
aega	doc_584615399797_item	3534521	et	4	main
varsti	doc_584615399797_item	3534522	et	3	main
mul	doc_584615399797_item	3534523	et	3	main
on	doc_584615399797_item	3534524	et	4	main
puhkus	doc_584615399797_item	3534525	et	3	main
ma	doc_584615399797_item	3534526	et	3	main
tahaksin	doc_584615399797_item	3534527	et	3	main
sõita	doc_584615399797_item	3534528	et	3	main
puhkusele	doc_584615399797_item	3534529	et	4	main
venemaale	doc_584615399797_item	3534530	et	4	main
mulle	doc_584615399797_item	3534531	et	4	main
soobib	doc_584615399797_item	3534532	et	4	main
venemaal	doc_584615399797_item	3534533	et	4	main
sõita	doc_584615399797_item	3534534	et	3	main
juulikuus	doc_584615399797_item	3534535	et	3	main
rongiga	doc_584615399797_item	3534536	et	4	main
see	doc_584615399797_item	3534537	et	3	main
te	doc_584615399797_item	3534459	et	4	main
kirjutage	doc_584615399797_item	3534463	et	3	main
eestlasest	doc_584615399797_item	3534467	et	3	main
millal	doc_584615399797_item	3534470	et	3	main
sõita	doc_584615399797_item	3534474	et	3	main
millega	doc_584615399797_item	3534476	et	3	main
kus	doc_584615399797_item	3534478	et	3	main
palju	doc_584615399797_item	3534481	et	4	main
see	doc_584615399797_item	3534482	et	3	main
maksab	doc_584615399797_item	3534483	et	3	main
millistes	doc_584615399797_item	3534484	et	3	main
pikkus	doc_584615399797_item	3534489	et	4	main
kätte	doc_584615399797_item	3534500	et	4	main
kirja	doc_584615399797_item	3534502	et	4	main
eest	doc_584615399797_item	3534503	et	4	main
sulle	doc_584615399797_item	3534508	et	3	main
sada	doc_584615399797_item	3534552	et	4	main
elavad	doc_584615399797_item	3534566	et	4	main
on	doc_584615399797_item	3534572	et	4	main
ja	doc_584615399797_item	3534574	et	3	main
kui	doc_584615399797_item	3534583	et	3	main
on	doc_584615399797_item	3534595	et	4	main
hea	doc_584615399797_item	3534596	et	4	main
seal	doc_584615399797_item	3534602	et	4	main
mul	doc_584615399797_item	3534616	et	3	main
tuhat	doc_584615399797_item	3534618	et	4	main
mõtlen	doc_584615399797_item	3534623	et	3	main
on	doc_584615399797_item	3534627	et	4	main
huvitav	doc_584615399797_item	3534629	et	4	main
kõik	doc_584615399797_item	3534640	et	4	main
mis	doc_584615399797_item	3534641	et	4	main
ma	doc_584615399797_item	3534642	et	3	main
lõpetan	doc_584615399797_item	3534648	et	3	main
kirjutage	doc_584615399798_item	3534667	et	3	main
oma	doc_584615399798_item	3534670	et	4	main
sõbrale	doc_584615399798_item	3534672	et	3	main
millal	doc_584615399798_item	3534674	et	3	main
kuhu	doc_584615399798_item	3534676	et	3	main
millega	doc_584615399798_item	3534680	et	3	main
ööbite	doc_584615399798_item	3534683	et	3	main
ülde	doc_584615399798_item	3534718	et	4	main
ma	doc_584615399798_item	3534720	et	3	main
tahan	doc_584615399798_item	3534740	et	3	main
oblasti	doc_584615399798_item	3534748	et	3	main
me	doc_584615399798_item	3534752	et	4	main
reisime	doc_584615399798_item	3534753	et	3	main
oma	doc_584615399798_item	3534754	et	4	main
sellest	doc_584615399797_item	3534464	et	4	main
kuhu	doc_584615399797_item	3534472	et	3	main
reisite	doc_584615399797_item	3534477	et	3	main
kui	doc_584615399797_item	3534480	et	3	main
kohtades	doc_584615399797_item	3534485	et	3	main
peatute	doc_584615399797_item	3534486	et	4	main
sõna	doc_584615399797_item	3534492	et	4	main
tänan	doc_584615399797_item	3534501	et	3	main
poole	doc_584615399797_item	3534507	et	4	main
välismaalase	doc_584615399797_item	3534543	et	3	main
krooni	doc_584615399797_item	3534553	et	4	main
see	doc_584615399797_item	3534555	et	3	main
hotell	doc_584615399797_item	3534576	et	3	main
seal	doc_584615399797_item	3534578	et	4	main
hotellis	doc_584615399797_item	3534585	et	3	main
ma	doc_584615399797_item	3534603	et	3	main
ei	doc_584615399797_item	3534605	et	4	main
pilet	doc_584615399797_item	3534611	et	3	main
ma	doc_584615399797_item	3534613	et	3	main
küll	doc_584615399797_item	3534621	et	4	main
ma	doc_584615399797_item	3534622	et	3	main
puhkus	doc_584615399797_item	3534626	et	3	main
väga	doc_584615399797_item	3534628	et	3	main
kuidas	doc_584615399797_item	3534630	et	3	main
ma	doc_584615399797_item	3534631	et	3	main
tulen	doc_584615399797_item	3534632	et	3	main
tagasi	doc_584615399797_item	3534633	et	3	main
ma	doc_584615399797_item	3534634	et	3	main
kirjutan	doc_584615399797_item	3534635	et	3	main
sulle	doc_584615399797_item	3534636	et	3	main
kirja	doc_584615399797_item	3534637	et	4	main
see	doc_584615399797_item	3534638	et	3	main
öelda	doc_584615399797_item	3534645	et	4	main
te	doc_584615399798_item	3534663	et	4	main
reisi	doc_584615399798_item	3534665	et	4	main
kirjutage	doc_584615399798_item	3534673	et	3	main
ja	doc_584615399798_item	3534675	et	3	main
te	doc_584615399798_item	3534677	et	4	main
soovite	doc_584615399798_item	3534679	et	3	main
kus	doc_584615399798_item	3534682	et	3	main
aga	doc_584615399798_item	3534723	et	3	main
loodan	doc_584615399798_item	3534725	et	3	main
sinul	doc_584615399798_item	3534727	et	3	main
juulis	doc_584615399798_item	3534734	et	3	main
reisi	doc_584615399798_item	3534737	et	4	main
venemaale	doc_584615399798_item	3534738	et	4	main
venemaale	doc_584615399798_item	3534746	et	4	main
linnas	doc_584615399798_item	3534751	et	4	main
ustjugi	doc_584615399798_item	3534762	et	4	main
asub	doc_584615399798_item	3534764	et	3	main
muistne	doc_584615399798_item	3534775	et	3	main
sellega	doc_584615399798_item	3534786	et	3	main
ma	doc_584615399798_item	3534789	et	3	main
vastust	doc_584615399798_item	3534792	et	4	main
pass	doc_584615399797_item	3534544	et	3	main
viisa	doc_584615399797_item	3534548	et	4	main
ja	doc_584615399797_item	3534554	et	3	main
sel	doc_584615399797_item	3534559	et	3	main
ma	doc_584615399797_item	3534561	et	3	main
nad	doc_584615399797_item	3534565	et	3	main
mina	doc_584615399797_item	3534568	et	4	main
tore	doc_584615399797_item	3534575	et	3	main
ocean	doc_584615399797_item	3534577	et	4	main
on	doc_584615399797_item	3534579	et	4	main
mugavam	doc_584615399797_item	3534580	et	4	main
ja	doc_584615399797_item	3534581	et	3	main
ma	doc_584615399797_item	3534586	et	3	main
punase	doc_584615399797_item	3534591	et	4	main
platside	doc_584615399797_item	3534592	et	4	main
minna	doc_584615399797_item	3534593	et	3	main
mul	doc_584615399797_item	3534594	et	3	main
moskvasse	doc_584615399797_item	3534601	et	4	main
arvan	doc_584615399797_item	3534614	et	3	main
et	doc_584615399797_item	3534615	et	3	main
viis	doc_584615399797_item	3534617	et	4	main
et	doc_584615399797_item	3534624	et	3	main
tahan	doc_584615399797_item	3534643	et	3	main
sulle	doc_584615399797_item	3534644	et	3	main
sinu	doc_584615399797_item	3534658	et	3	main
sõber	doc_584615399797_item	3534659	et	3	main
eesnimi	doc_584615399797_item	3534660	et	3	main
venemaale	doc_584615399798_item	3534666	et	4	main
kiri	doc_584615399798_item	3534669	et	3	main
sõita	doc_584615399798_item	3534678	et	3	main
reisite	doc_584615399798_item	3534681	et	3	main
kui	doc_584615399798_item	3534684	et	3	main
vastata	doc_584615399798_item	3534714	et	4	main
mul	doc_584615399798_item	3534715	et	3	main
aega	doc_584615399798_item	3534719	et	4	main
on	doc_584615399798_item	3534732	et	4	main
puhkus	doc_584615399798_item	3534733	et	3	main
plaanin	doc_584615399798_item	3534736	et	3	main
veliki	doc_584615399798_item	3534749	et	4	main
autoga	doc_584615399798_item	3534755	et	3	main
see	doc_584615399798_item	3534756	et	3	main
kui	doc_584615399798_item	3534759	et	3	main
linn	doc_584615399798_item	3534763	et	3	main
jõe	doc_584615399798_item	3534765	et	3	main
suhhona	doc_584615399798_item	3534767	et	4	main
veliki	doc_584615399798_item	3534772	et	4	main
kiri	doc_584615399799_item	3534798	et	3	main
kiri	doc_584615399799_item	3534805	et	3	main
eestlasest	doc_584615399799_item	3534807	et	3	main
sõbrale	doc_584615399799_item	3534808	et	3	main
ja	doc_584615399799_item	3534811	et	3	main
palju	doc_584615399799_item	3534821	et	4	main
et	doc_584615399799_item	3534846	et	3	main
tahan	doc_584615399799_item	3534847	et	3	main
julilis	doc_584615399799_item	3534862	et	4	main
ja	doc_584615399799_item	3534863	et	3	main
elab	doc_584615399799_item	3534864	et	3	main
ääres	doc_584615399799_item	3534870	et	4	main
tahan	doc_584615399799_item	3534872	et	3	main
õie	doc_584615399799_item	3534874	et	3	main
kiri	doc_584615399800_item	3534907	et	3	main
eestlasest	doc_584615399800_item	3534909	et	3	main
millal	doc_584615399800_item	3534912	et	3	main
kuhu	doc_584615399800_item	3534914	et	3	main
soovite	doc_584615399800_item	3534917	et	3	main
kui	doc_584615399800_item	3534922	et	3	main
peatute	doc_584615399800_item	3534928	et	4	main
nõutav	doc_584615399800_item	3534930	et	4	main
kirja	doc_584615399800_item	3534941	et	4	main
mulle	doc_584615399800_item	3534946	et	4	main
ka	doc_584615399800_item	3534963	et	3	main
leningradi	doc_584615399800_item	3534977	et	4	main
ja	doc_584615399800_item	3534978	et	3	main
leningradist	doc_584615399800_item	3534979	et	4	main
sõidame	doc_584615399800_item	3534994	et	3	main
trammiga	doc_584615399800_item	3534995	et	3	main
zooparkii	doc_584615399800_item	3534996	et	4	main
ja	doc_584615399800_item	3534999	et	3	main
jäätist	doc_584615399800_item	3535009	et	3	main
sugulastele	doc_584615399797_item	3534563	et	4	main
uus	doc_584615399797_item	3534573	et	3	main
tahan	doc_584615399797_item	3534587	et	3	main
linna	doc_584615399797_item	3534588	et	4	main
ja	doc_584615399797_item	3534590	et	3	main
et	doc_584615399797_item	3534598	et	3	main
ma	doc_584615399797_item	3534599	et	3	main
sõidan	doc_584615399797_item	3534600	et	3	main
veel	doc_584615399797_item	3534604	et	4	main
olnud	doc_584615399797_item	3534606	et	4	main
ma	doc_584615399797_item	3534607	et	3	main
juba	doc_584615399797_item	3534608	et	3	main
broneerin	doc_584615399797_item	3534609	et	3	main
üks	doc_584615399797_item	3534610	et	3	main
endale	doc_584615399797_item	3534612	et	4	main
see	doc_584615399797_item	3534625	et	3	main
siis	doc_584615399797_item	3534647	et	3	main
abikaasat	doc_584615399797_item	3534653	et	3	main
oma	doc_584615399797_item	3534650	et	4	main
sovin	doc_584615399797_item	3534654	et	4	main
sulle	doc_584615399797_item	3534655	et	3	main
kõike	doc_584615399797_item	3534656	et	4	main
head	doc_584615399797_item	3534657	et	4	main
kiri	doc_584615399798_item	3534662	et	3	main
plaanite	doc_584615399798_item	3534664	et	3	main
eestlasest	doc_584615399798_item	3534671	et	3	main
palju	doc_584615399798_item	3534685	et	4	main
ei	doc_584615399798_item	3534716	et	4	main
hästi	doc_584615399798_item	3534722	et	3	main
sina	doc_584615399798_item	3534724	et	4	main
on	doc_584615399798_item	3534729	et	4	main
korras	doc_584615399798_item	3534730	et	4	main
mul	doc_584615399798_item	3534731	et	3	main
ma	doc_584615399798_item	3534739	et	3	main
vologda	doc_584615399798_item	3534747	et	4	main
odavam	doc_584615399798_item	3534758	et	4	main
veliki	doc_584615399798_item	3534761	et	4	main
on	doc_584615399798_item	3534774	et	4	main
linn	doc_584615399798_item	3534776	et	3	main
helistan	doc_584615399798_item	3534785	et	3	main
lõpetan	doc_584615399798_item	3534788	et	3	main
sinu	doc_584615399798_item	3534791	et	3	main
head	doc_584615399798_item	3534794	et	4	main
plaanite	doc_584615399799_item	3534800	et	3	main
kirjutage	doc_584615399799_item	3534803	et	3	main
see	doc_584615399799_item	3534822	et	3	main
reisida	doc_584615399799_item	3534849	et	3	main
krooni	doc_584615399799_item	3534859	et	4	main
reisida	doc_584615399799_item	3534860	et	3	main
tahan	doc_584615399799_item	3534861	et	3	main
sellest	doc_584615399800_item	3534906	et	4	main
sõita	doc_584615399800_item	3534916	et	3	main
reisite	doc_584615399800_item	3534919	et	3	main
ööbite	doc_584615399800_item	3534921	et	3	main
80	doc_584615399800_item	3534933	et	2	main
kallis	doc_584615399800_item	3534936	et	4	main
laine	doc_584615399800_item	3534937	et	4	main
tänan	doc_584615399800_item	3534938	et	3	main
väga	doc_584615399800_item	3534939	et	3	main
ole	doc_584615399800_item	3534945	et	4	main
kõik	doc_584615399800_item	3534964	et	4	main
ma	doc_584615399800_item	3534967	et	3	main
sõita	doc_584615399800_item	3534969	et	3	main
oma	doc_584615399800_item	3534971	et	4	main
lapselapsega	doc_584615399800_item	3534972	et	3	main
venemaale	doc_584615399800_item	3534973	et	4	main
kurski	doc_584615399800_item	3534981	et	4	main
rong	doc_584615399800_item	3534982	et	3	main
on	doc_584615399800_item	3534989	et	4	main
ja	doc_584615399800_item	3535006	et	3	main
sõidame	doc_584615399800_item	3535012	et	3	main
rongis	doc_584615399800_item	3535013	et	4	main
vara	doc_584615399800_item	3535015	et	4	main
kurskis	doc_584615399800_item	3535018	et	4	main
tõesti	doc_584615399800_item	3535019	et	3	main
see	doc_584615399800_item	3535020	et	3	main
on	doc_584615399800_item	3535021	et	4	main
koos	doc_584615399798_item	3534741	et	4	main
abikaasa	doc_584615399798_item	3534742	et	4	main
sõita	doc_584615399798_item	3534743	et	3	main
me	doc_584615399798_item	3534744	et	4	main
sõidame	doc_584615399798_item	3534745	et	3	main
sellest	doc_584615399798_item	3534668	et	4	main
see	doc_584615399798_item	3534686	et	3	main
maksab	doc_584615399798_item	3534687	et	3	main
millistes	doc_584615399798_item	3534688	et	3	main
kohtades	doc_584615399798_item	3534689	et	3	main
peatute	doc_584615399798_item	3534690	et	4	main
kirja	doc_584615399798_item	3534691	et	4	main
nõutav	doc_584615399798_item	3534692	et	4	main
pikkus	doc_584615399798_item	3534693	et	4	main
umbes	doc_584615399798_item	3534694	et	4	main
80	doc_584615399798_item	3534695	et	2	main
sõna	doc_584615399798_item	3534696	et	4	main
tere	doc_584615399798_item	3534697	et	3	main
kallis	doc_584615399798_item	3534698	et	4	main
sõbranna	doc_584615399798_item	3534699	et	4	main
laine	doc_584615399798_item	3534700	et	4	main
sain	doc_584615399798_item	3534701	et	3	main
sinu	doc_584615399798_item	3534702	et	3	main
kirja	doc_584615399798_item	3534703	et	4	main
kätte	doc_584615399798_item	3534704	et	4	main
ma	doc_584615399798_item	3534705	et	3	main
olen	doc_584615399798_item	3534706	et	3	main
väga	doc_584615399798_item	3534707	et	3	main
rõõmus	doc_584615399798_item	3534708	et	4	main
ma	doc_584615399798_item	3534709	et	3	main
ei	doc_584615399798_item	3534710	et	4	main
saanud	doc_584615399798_item	3534711	et	4	main
sulle	doc_584615399798_item	3534712	et	3	main
kohe	doc_584615399798_item	3534713	et	4	main
olnud	doc_584615399798_item	3534717	et	4	main
elan	doc_584615399798_item	3534721	et	3	main
et	doc_584615399798_item	3534726	et	3	main
kõik	doc_584615399798_item	3534728	et	4	main
ma	doc_584615399798_item	3534735	et	3	main
ustjugi	doc_584615399798_item	3534750	et	4	main
on	doc_584615399798_item	3534757	et	4	main
rongiga	doc_584615399798_item	3534760	et	4	main
juures	doc_584615399798_item	3534771	et	4	main
asub	doc_584615399798_item	3534778	et	3	main
näärivana	doc_584615399798_item	3534780	et	4	main
ma	doc_584615399798_item	3534781	et	3	main
sinule	doc_584615399798_item	3534782	et	3	main
kohtumiseni	doc_584615399798_item	3534793	et	4	main
aega	doc_584615399798_item	3534795	et	4	main
eesnimi	doc_584615399798_item	3534796	et	3	main
reisi	doc_584615399799_item	3534801	et	4	main
sellest	doc_584615399799_item	3534804	et	4	main
oma	doc_584615399799_item	3534806	et	4	main
kirjutage	doc_584615399799_item	3534809	et	3	main
kuhu	doc_584615399799_item	3534812	et	3	main
ööbite	doc_584615399799_item	3534819	et	3	main
maksab	doc_584615399799_item	3534823	et	3	main
reisida	doc_584615399799_item	3534850	et	3	main
oma	doc_584615399799_item	3534853	et	4	main
vesjegonskis	doc_584615399799_item	3534865	et	4	main
see	doc_584615399799_item	3534866	et	3	main
asub	doc_584615399799_item	3534867	et	3	main
volga	doc_584615399799_item	3534868	et	4	main
juures	doc_584615399799_item	3534875	et	4	main
ta	doc_584615399799_item	3534876	et	4	main
elab	doc_584615399799_item	3534877	et	3	main
viie	doc_584615399799_item	3534878	et	3	main
kaldal	doc_584615399798_item	3534766	et	3	main
me	doc_584615399798_item	3534768	et	4	main
peatume	doc_584615399798_item	3534769	et	4	main
sugulane	doc_584615399798_item	3534770	et	3	main
ustjugi	doc_584615399798_item	3534773	et	4	main
seal	doc_584615399798_item	3534777	et	4	main
kodumaa	doc_584615399798_item	3534779	et	4	main
veliki	doc_584615399798_item	3534783	et	4	main
ustjugist	doc_584615399798_item	3534784	et	4	main
siis	doc_584615399798_item	3534787	et	3	main
ootan	doc_584615399798_item	3534790	et	3	main
venemaale	doc_584615399799_item	3534802	et	4	main
kui	doc_584615399799_item	3534820	et	3	main
millistes	doc_584615399799_item	3534824	et	3	main
rongiga	doc_584615399799_item	3534852	et	4	main
õie	doc_584615399799_item	3534854	et	3	main
elada	doc_584615399799_item	3534871	et	3	main
oma	doc_584615399799_item	3534873	et	4	main
kiri	doc_584615399800_item	3534900	et	3	main
reisi	doc_584615399800_item	3534903	et	4	main
see	doc_584615399800_item	3534924	et	3	main
millistes	doc_584615399800_item	3534926	et	3	main
pikkus	doc_584615399800_item	3534931	et	4	main
sõna	doc_584615399800_item	3534934	et	4	main
eest	doc_584615399800_item	3534942	et	4	main
me	doc_584615399800_item	3534974	et	4	main
sõidame	doc_584615399800_item	3534975	et	3	main
bussiga	doc_584615399800_item	3534976	et	3	main
väljub	doc_584615399800_item	3534983	et	3	main
jalutame	doc_584615399800_item	3534997	et	3	main
pargis	doc_584615399800_item	3534998	et	3	main
käime	doc_584615399800_item	3535004	et	4	main
me	doc_584615399800_item	3535011	et	4	main
hommikul	doc_584615399800_item	3535016	et	3	main
venemaale	doc_584615399801_item	3535044	et	4	main
oma	doc_584615399801_item	3535048	et	4	main
kirjutage	doc_584615399801_item	3535051	et	3	main
kuhu	doc_584615399801_item	3535054	et	3	main
kus	doc_584615399801_item	3535060	et	3	main
peatute	doc_584615399801_item	3535068	et	4	main
nõutav	doc_584615399801_item	3535070	et	4	main
pikkus	doc_584615399801_item	3535071	et	4	main
helli	doc_584615399801_item	3535077	et	4	main
kuidas	doc_584615399801_item	3535078	et	3	main
kirjutada	doc_584615399801_item	3535083	et	3	main
mul	doc_584615399801_item	3535087	et	3	main
väga	doc_584615399801_item	3535089	et	3	main
venemaale	doc_584615399802_item	3535168	et	4	main
kui	doc_584615399802_item	3535186	et	3	main
millistes	doc_584615399802_item	3535190	et	3	main
peatute	doc_584615399802_item	3535192	et	4	main
nõutav	doc_584615399802_item	3535194	et	4	main
pikkus	doc_584615399802_item	3535195	et	4	main
tere	doc_584615399802_item	3535199	et	3	main
kallis	doc_584615399802_item	3535200	et	4	main
laine	doc_584615399802_item	3535201	et	4	main
kõik	doc_584615399802_item	3535212	et	4	main
ma	doc_584615399802_item	3535214	et	3	main
kõik	doc_584615399802_item	3535219	et	4	main
minu	doc_584615399802_item	3535221	et	3	main
mees	doc_584615399802_item	3535222	et	4	main
ja	doc_584615399802_item	3535223	et	3	main
poeg	doc_584615399802_item	3535224	et	3	main
vaadata	doc_584615399802_item	3535264	et	4	main
mousoleumi	doc_584615399802_item	3535274	et	4	main
tahaksime	doc_584615399802_item	3535275	et	3	main
aga	doc_584615399802_item	3535289	et	3	main
juba	doc_584615399802_item	3535292	et	3	main
te	doc_584615399803_item	3535341	et	4	main
sõbrale	doc_584615399803_item	3535350	et	3	main
kirjutage	doc_584615399803_item	3535351	et	3	main
millal	doc_584615399803_item	3535352	et	3	main
ja	doc_584615399803_item	3535353	et	3	main
kuhu	doc_584615399803_item	3535354	et	3	main
te	doc_584615399803_item	3535355	et	4	main
sõita	doc_584615399803_item	3535356	et	3	main
soovite	doc_584615399803_item	3535357	et	3	main
millega	doc_584615399803_item	3535358	et	3	main
reisite	doc_584615399803_item	3535359	et	3	main
see	doc_584615399803_item	3535364	et	3	main
80	doc_584615399803_item	3535373	et	2	main
täna	doc_584615399803_item	3535381	et	4	main
korruselises	doc_584615399799_item	3534879	et	4	main
majas	doc_584615399799_item	3534880	et	3	main
kolmandale	doc_584615399799_item	3534881	et	3	main
korrusee	doc_584615399799_item	3534882	et	4	main
kahetoalises	doc_584615399799_item	3534883	et	4	main
korteris	doc_584615399799_item	3534884	et	3	main
ootan	doc_584615399799_item	3534885	et	3	main
juulis	doc_584615399799_item	3534886	et	3	main
et	doc_584615399799_item	3534887	et	3	main
väga	doc_584615399799_item	3534888	et	3	main
tahan	doc_584615399799_item	3534889	et	3	main
venemaale	doc_584615399799_item	3534890	et	4	main
sõita	doc_584615399799_item	3534891	et	3	main
ootan	doc_584615399799_item	3534892	et	3	main
sinust	doc_584615399799_item	3534893	et	3	main
kirja	doc_584615399799_item	3534894	et	4	main
head	doc_584615399799_item	3534895	et	4	main
aega	doc_584615399799_item	3534896	et	4	main
140605	doc_584615399799_item	3534897	et	2	main
eesnimi	doc_584615399799_item	3534898	et	3	main
te	doc_584615399799_item	3534799	et	4	main
millal	doc_584615399799_item	3534810	et	3	main
te	doc_584615399799_item	3534813	et	4	main
sõita	doc_584615399799_item	3534814	et	3	main
soovite	doc_584615399799_item	3534815	et	3	main
millega	doc_584615399799_item	3534816	et	3	main
reisite	doc_584615399799_item	3534817	et	3	main
kus	doc_584615399799_item	3534818	et	3	main
kohtades	doc_584615399799_item	3534825	et	3	main
peatute	doc_584615399799_item	3534826	et	4	main
kirja	doc_584615399799_item	3534827	et	4	main
nõutav	doc_584615399799_item	3534828	et	4	main
pikkus	doc_584615399799_item	3534829	et	4	main
umbes	doc_584615399799_item	3534830	et	4	main
80	doc_584615399799_item	3534831	et	2	main
sõna	doc_584615399799_item	3534832	et	4	main
tere	doc_584615399799_item	3534833	et	3	main
laina	doc_584615399799_item	3534834	et	4	main
kuidas	doc_584615399799_item	3534835	et	3	main
läheb	doc_584615399799_item	3534836	et	3	main
mul	doc_584615399799_item	3534837	et	3	main
on	doc_584615399799_item	3534838	et	4	main
kõik	doc_584615399799_item	3534839	et	4	main
vanavisi	doc_584615399799_item	3534840	et	4	main
töötan	doc_584615399799_item	3534841	et	3	main
poliklinikus	doc_584615399799_item	3534842	et	4	main
tahan	doc_584615399799_item	3534843	et	3	main
sinule	doc_584615399799_item	3534844	et	3	main
jutustada	doc_584615399799_item	3534845	et	3	main
venemaale	doc_584615399799_item	3534848	et	4	main
tahan	doc_584615399799_item	3534851	et	3	main
juurde	doc_584615399799_item	3534855	et	4	main
see	doc_584615399799_item	3534856	et	3	main
maksab	doc_584615399799_item	3534857	et	3	main
tuhan	doc_584615399799_item	3534858	et	4	main
jõe	doc_584615399799_item	3534869	et	3	main
te	doc_584615399800_item	3534901	et	4	main
plaanite	doc_584615399800_item	3534902	et	3	main
venemaale	doc_584615399800_item	3534904	et	4	main
kirjutage	doc_584615399800_item	3534911	et	3	main
maksab	doc_584615399800_item	3534925	et	3	main
kohtades	doc_584615399800_item	3534927	et	3	main
sind	doc_584615399800_item	3534940	et	4	main
juulis	doc_584615399800_item	3534966	et	3	main
koos	doc_584615399800_item	3534970	et	4	main
rongiga	doc_584615399800_item	3534980	et	4	main
kakskümmend	doc_584615399800_item	3534985	et	4	main
kuni	doc_584615399800_item	3534987	et	3	main
sööme	doc_584615399800_item	3535007	et	4	main
seal	doc_584615399800_item	3535008	et	4	main
palju	doc_584615399800_item	3535022	et	4	main
maksab	doc_584615399800_item	3535023	et	3	main
endale	doc_584615399800_item	3535030	et	4	main
sellega	doc_584615399800_item	3535032	et	3	main
vaatame	doc_584615399800_item	3535000	et	3	main
loomi	doc_584615399800_item	3535001	et	4	main
pärast	doc_584615399800_item	3535002	et	4	main
tingimata	doc_584615399800_item	3535003	et	4	main
kirjutage	doc_584615399800_item	3534905	et	3	main
oma	doc_584615399800_item	3534908	et	4	main
sõbrale	doc_584615399800_item	3534910	et	3	main
ja	doc_584615399800_item	3534913	et	3	main
te	doc_584615399800_item	3534915	et	4	main
millega	doc_584615399800_item	3534918	et	3	main
kus	doc_584615399800_item	3534920	et	3	main
palju	doc_584615399800_item	3534923	et	4	main
kirja	doc_584615399800_item	3534929	et	4	main
umbes	doc_584615399800_item	3534932	et	4	main
tere	doc_584615399800_item	3534935	et	3	main
sa	doc_584615399800_item	3534943	et	3	main
ei	doc_584615399800_item	3534944	et	4	main
ammu	doc_584615399800_item	3534947	et	4	main
kirjutada	doc_584615399800_item	3534948	et	3	main
mulle	doc_584615399800_item	3534949	et	4	main
väga	doc_584615399800_item	3534950	et	3	main
meeldib	doc_584615399800_item	3534951	et	3	main
et	doc_584615399800_item	3534952	et	3	main
sul	doc_584615399800_item	3534953	et	3	main
on	doc_584615399800_item	3534954	et	4	main
kõik	doc_584615399800_item	3534955	et	4	main
korras	doc_584615399800_item	3534956	et	4	main
ma	doc_584615399800_item	3534957	et	3	main
elan	doc_584615399800_item	3534958	et	3	main
vanaviisi	doc_584615399800_item	3534959	et	4	main
ja	doc_584615399800_item	3534960	et	3	main
mul	doc_584615399800_item	3534961	et	3	main
on	doc_584615399800_item	3534962	et	4	main
korras	doc_584615399800_item	3534965	et	4	main
tahaksin	doc_584615399800_item	3534968	et	3	main
kell	doc_584615399800_item	3534984	et	3	main
ja	doc_584615399800_item	3534986	et	3	main
õhtuni	doc_584615399800_item	3534988	et	3	main
vaba	doc_584615399800_item	3534990	et	4	main
aeg	doc_584615399800_item	3534991	et	3	main
kõigepealt	doc_584615399800_item	3534992	et	3	main
me	doc_584615399800_item	3534993	et	4	main
kesklinnas	doc_584615399800_item	3535005	et	4	main
öösel	doc_584615399800_item	3535010	et	4	main
ja	doc_584615399800_item	3535014	et	3	main
oleme	doc_584615399800_item	3535017	et	3	main
võib	doc_584615399800_item	3535028	et	3	main
lubada	doc_584615399800_item	3535031	et	3	main
lõpetan	doc_584615399800_item	3535033	et	3	main
kiri	doc_584615399801_item	3535040	et	3	main
kiri	doc_584615399801_item	3535047	et	3	main
sõbrale	doc_584615399801_item	3535050	et	3	main
ja	doc_584615399801_item	3535053	et	3	main
palju	doc_584615399801_item	3535063	et	4	main
umbes	doc_584615399801_item	3535072	et	4	main
80	doc_584615399801_item	3535073	et	2	main
käsi	doc_584615399801_item	3535079	et	4	main
meeldiv	doc_584615399801_item	3535090	et	4	main
et	doc_584615399801_item	3535091	et	3	main
sul	doc_584615399801_item	3535092	et	3	main
on	doc_584615399801_item	3535093	et	4	main
mälestisi	doc_584615399801_item	3535136	et	3	main
vaadata	doc_584615399801_item	3535139	et	4	main
kiri	doc_584615399802_item	3535164	et	3	main
kirjutage	doc_584615399802_item	3535169	et	3	main
sellest	doc_584615399802_item	3535170	et	4	main
oma	doc_584615399802_item	3535172	et	4	main
eestlasest	doc_584615399802_item	3535173	et	3	main
ja	doc_584615399802_item	3535177	et	3	main
palju	doc_584615399802_item	3535187	et	4	main
see	doc_584615399802_item	3535188	et	3	main
umbes	doc_584615399802_item	3535196	et	4	main
80	doc_584615399802_item	3535197	et	2	main
ei	doc_584615399802_item	3535203	et	4	main
ole	doc_584615399802_item	3535204	et	4	main
kirjutanud	doc_584615399802_item	3535207	et	4	main
kuidas	doc_584615399802_item	3535208	et	3	main
läheb	doc_584615399802_item	3535209	et	3	main
sul	doc_584615399802_item	3535210	et	3	main
läksid	doc_584615399802_item	3535225	et	4	main
magama	doc_584615399802_item	3535226	et	3	main
aga	doc_584615399802_item	3535227	et	3	main
mina	doc_584615399802_item	3535228	et	4	main
otsustasin	doc_584615399802_item	3535229	et	3	main
kirjutada	doc_584615399802_item	3535230	et	3	main
kuid	doc_584615399800_item	3535024	et	4	main
üks	doc_584615399800_item	3535025	et	3	main
kord	doc_584615399800_item	3535026	et	4	main
aastas	doc_584615399800_item	3535027	et	3	main
ootan	doc_584615399800_item	3535034	et	3	main
kirja	doc_584615399800_item	3535036	et	4	main
plaanite	doc_584615399801_item	3535042	et	3	main
sellest	doc_584615399801_item	3535046	et	4	main
see	doc_584615399801_item	3535064	et	3	main
millistes	doc_584615399801_item	3535066	et	3	main
kirja	doc_584615399801_item	3535069	et	4	main
kallis	doc_584615399801_item	3535076	et	4	main
sulle	doc_584615399801_item	3535082	et	3	main
kõik	doc_584615399801_item	3535094	et	4	main
tahaksin	doc_584615399801_item	3535137	et	3	main
seda	doc_584615399800_item	3535029	et	3	main
sinult	doc_584615399800_item	3535035	et	3	main
nägemiseni	doc_584615399800_item	3535037	et	4	main
eesnimi	doc_584615399800_item	3535038	et	3	main
reisi	doc_584615399801_item	3535043	et	4	main
kui	doc_584615399801_item	3535062	et	3	main
tere	doc_584615399801_item	3535075	et	3	main
otsustasin	doc_584615399801_item	3535081	et	3	main
ma	doc_584615399801_item	3535084	et	3	main
vanavisi	doc_584615399801_item	3535086	et	4	main
on	doc_584615399801_item	3535088	et	4	main
kõike	doc_584615399801_item	3535138	et	4	main
helli	doc_584615399801_item	3535140	et	4	main
kuidas	doc_584615399801_item	3535141	et	3	main
sa	doc_584615399801_item	3535142	et	3	main
veetsid	doc_584615399801_item	3535143	et	4	main
oma	doc_584615399801_item	3535144	et	4	main
puhkuse	doc_584615399801_item	3535145	et	3	main
aastal	doc_584615399801_item	3535147	et	3	main
soovin	doc_584615399801_item	3535148	et	3	main
edu	doc_584615399801_item	3535149	et	4	main
ja	doc_584615399801_item	3535150	et	3	main
kordaminekut	doc_584615399801_item	3535151	et	3	main
saada	doc_584615399801_item	3535152	et	4	main
edasi	doc_584615399801_item	3535153	et	3	main
möödunud	doc_584615399801_item	3535146	et	4	main
tervitusi	doc_584615399801_item	3535154	et	4	main
tütrele	doc_584615399801_item	3535155	et	3	main
jään	doc_584615399801_item	3535156	et	3	main
ootama	doc_584615399801_item	3535157	et	3	main
sinu	doc_584615399801_item	3535158	et	3	main
kirja	doc_584615399801_item	3535159	et	4	main
aega	doc_584615399801_item	3535161	et	4	main
eesnimi	doc_584615399801_item	3535162	et	3	main
head	doc_584615399801_item	3535160	et	4	main
te	doc_584615399802_item	3535165	et	4	main
kiri	doc_584615399802_item	3535171	et	3	main
kirjutage	doc_584615399802_item	3535175	et	3	main
kuhu	doc_584615399802_item	3535178	et	3	main
ööbite	doc_584615399802_item	3535185	et	3	main
maksab	doc_584615399802_item	3535189	et	3	main
mulle	doc_584615399802_item	3535205	et	4	main
ammu	doc_584615399802_item	3535206	et	4	main
vanaviisi	doc_584615399802_item	3535216	et	4	main
mul	doc_584615399802_item	3535217	et	3	main
korras	doc_584615399802_item	3535220	et	4	main
minna	doc_584615399802_item	3535268	et	3	main
vaadata	doc_584615399802_item	3535276	et	4	main
me	doc_584615399802_item	3535284	et	4	main
õhtul	doc_584615399802_item	3535287	et	3	main
plaanite	doc_584615399803_item	3535342	et	3	main
kirjutage	doc_584615399803_item	3535345	et	3	main
kiri	doc_584615399803_item	3535347	et	3	main
eestlasest	doc_584615399803_item	3535349	et	3	main
palju	doc_584615399803_item	3535363	et	4	main
kohtades	doc_584615399803_item	3535367	et	3	main
kirja	doc_584615399803_item	3535369	et	4	main
tere	doc_584615399803_item	3535375	et	3	main
hommikul	doc_584615399803_item	3535382	et	3	main
ikka	doc_584615399801_item	3535119	et	4	main
odavam	doc_584615399801_item	3535120	et	4	main
kui	doc_584615399801_item	3535121	et	3	main
hotellis	doc_584615399801_item	3535122	et	3	main
sest	doc_584615399801_item	3535123	et	4	main
et	doc_584615399801_item	3535124	et	3	main
moskva	doc_584615399801_item	3535125	et	4	main
on	doc_584615399801_item	3535126	et	4	main
väga	doc_584615399801_item	3535127	et	3	main
kallis	doc_584615399801_item	3535128	et	4	main
linn	doc_584615399801_item	3535129	et	3	main
moskvas	doc_584615399801_item	3535130	et	4	main
on	doc_584615399801_item	3535131	et	4	main
hulk	doc_584615399801_item	3535132	et	3	main
kirikuid	doc_584615399801_item	3535133	et	4	main
muuseume	doc_584615399801_item	3535134	et	3	main
vanaaja	doc_584615399801_item	3535135	et	3	main
te	doc_584615399801_item	3535041	et	4	main
kirjutage	doc_584615399801_item	3535045	et	3	main
eestlasest	doc_584615399801_item	3535049	et	3	main
millal	doc_584615399801_item	3535052	et	3	main
te	doc_584615399801_item	3535055	et	4	main
sõita	doc_584615399801_item	3535056	et	3	main
soovite	doc_584615399801_item	3535057	et	3	main
millega	doc_584615399801_item	3535058	et	3	main
reisite	doc_584615399801_item	3535059	et	3	main
ööbite	doc_584615399801_item	3535061	et	3	main
maksab	doc_584615399801_item	3535065	et	3	main
kohtades	doc_584615399801_item	3535067	et	3	main
sõna	doc_584615399801_item	3535074	et	4	main
käib	doc_584615399801_item	3535080	et	3	main
elan	doc_584615399801_item	3535085	et	3	main
korras	doc_584615399801_item	3535095	et	4	main
mul	doc_584615399801_item	3535096	et	3	main
on	doc_584615399801_item	3535097	et	4	main
hea	doc_584615399801_item	3535098	et	4	main
uudis	doc_584615399801_item	3535099	et	3	main
ma	doc_584615399801_item	3535100	et	3	main
lähen	doc_584615399801_item	3535101	et	3	main
puhkusule	doc_584615399801_item	3535102	et	3	main
esimisest	doc_584615399801_item	3535103	et	4	main
juulist	doc_584615399801_item	3535104	et	4	main
mina	doc_584615399801_item	3535105	et	4	main
ja	doc_584615399801_item	3535106	et	3	main
minu	doc_584615399801_item	3535107	et	3	main
mees	doc_584615399801_item	3535108	et	4	main
sõidame	doc_584615399801_item	3535109	et	3	main
oma	doc_584615399801_item	3535110	et	4	main
autoga	doc_584615399801_item	3535111	et	3	main
moskvasse	doc_584615399801_item	3535112	et	4	main
me	doc_584615399801_item	3535113	et	4	main
peatume	doc_584615399801_item	3535114	et	4	main
sõprade	doc_584615399801_item	3535115	et	3	main
juures	doc_584615399801_item	3535116	et	4	main
see	doc_584615399801_item	3535117	et	3	main
on	doc_584615399801_item	3535118	et	4	main
reisi	doc_584615399802_item	3535167	et	4	main
sõbrale	doc_584615399802_item	3535174	et	3	main
millal	doc_584615399802_item	3535176	et	3	main
te	doc_584615399802_item	3535179	et	4	main
sõita	doc_584615399802_item	3535180	et	3	main
soovite	doc_584615399802_item	3535181	et	3	main
millega	doc_584615399802_item	3535182	et	3	main
reisite	doc_584615399802_item	3535183	et	3	main
kus	doc_584615399802_item	3535184	et	3	main
kohtades	doc_584615399802_item	3535191	et	3	main
sina	doc_584615399802_item	3535202	et	4	main
on	doc_584615399802_item	3535211	et	4	main
korras	doc_584615399802_item	3535213	et	4	main
elan	doc_584615399802_item	3535215	et	3	main
tahaksime	doc_584615399802_item	3535267	et	3	main
restoraanis	doc_584615399802_item	3535269	et	4	main
taevas	doc_584615399802_item	3535271	et	4	main
külastaksime	doc_584615399802_item	3535272	et	3	main
lenini	doc_584615399802_item	3535273	et	4	main
ööbime	doc_584615399802_item	3535285	et	3	main
istutame	doc_584615399802_item	3535288	et	3	main
saada	doc_584615399802_item	3535327	et	4	main
edasi	doc_584615399802_item	3535328	et	3	main
tervitusi	doc_584615399802_item	3535329	et	4	main
abikaasale	doc_584615399802_item	3535330	et	4	main
jään	doc_584615399802_item	3535331	et	3	main
ootama	doc_584615399802_item	3535332	et	3	main
sinu	doc_584615399802_item	3535333	et	3	main
kirja	doc_584615399802_item	3535334	et	4	main
head	doc_584615399802_item	3535335	et	4	main
aega	doc_584615399802_item	3535336	et	4	main
140605	doc_584615399802_item	3535337	et	2	main
eesnimi	doc_584615399802_item	3535338	et	3	main
plaanite	doc_584615399802_item	3535166	et	3	main
kirja	doc_584615399802_item	3535193	et	4	main
sõna	doc_584615399802_item	3535198	et	4	main
on	doc_584615399802_item	3535218	et	4	main
sulle	doc_584615399802_item	3535231	et	3	main
kirja	doc_584615399802_item	3535232	et	4	main
ma	doc_584615399802_item	3535233	et	3	main
lähen	doc_584615399802_item	3535234	et	3	main
puhkusele	doc_584615399802_item	3535235	et	4	main
augustis	doc_584615399802_item	3535236	et	3	main
ma	doc_584615399802_item	3535237	et	3	main
plaanin	doc_584615399802_item	3535238	et	3	main
reisi	doc_584615399802_item	3535239	et	4	main
moskvasse	doc_584615399802_item	3535240	et	4	main
ma	doc_584615399802_item	3535241	et	3	main
sõidan	doc_584615399802_item	3535242	et	3	main
koos	doc_584615399802_item	3535243	et	4	main
abikaasaga	doc_584615399802_item	3535244	et	3	main
seal	doc_584615399802_item	3535245	et	4	main
elab	doc_584615399802_item	3535246	et	3	main
minu	doc_584615399802_item	3535247	et	3	main
vend	doc_584615399802_item	3535248	et	3	main
ja	doc_584615399802_item	3535249	et	3	main
me	doc_584615399802_item	3535250	et	4	main
tahame	doc_584615399802_item	3535251	et	3	main
sõita	doc_584615399802_item	3535252	et	3	main
temale	doc_584615399802_item	3535253	et	3	main
külla	doc_584615399802_item	3535254	et	4	main
me	doc_584615399802_item	3535255	et	4	main
väga	doc_584615399802_item	3535256	et	3	main
tahame	doc_584615399802_item	3535257	et	3	main
vaadata	doc_584615399802_item	3535258	et	4	main
moskva	doc_584615399802_item	3535259	et	4	main
läheme	doc_584615399802_item	3535260	et	3	main
suur	doc_584615399802_item	3535261	et	3	main
teatri	doc_584615399802_item	3535262	et	3	main
tahaksime	doc_584615399802_item	3535263	et	3	main
ostankino	doc_584615399802_item	3535265	et	4	main
rongiga	doc_584615399802_item	3535283	et	4	main
rongis	doc_584615399802_item	3535286	et	4	main
kiri	doc_584615399803_item	3535340	et	3	main
kui	doc_584615399803_item	3535362	et	3	main
peatute	doc_584615399803_item	3535368	et	4	main
nõutav	doc_584615399803_item	3535370	et	4	main
pikkus	doc_584615399803_item	3535371	et	4	main
kallis	doc_584615399803_item	3535377	et	4	main
sain	doc_584615399803_item	3535380	et	3	main
kirja	doc_584615399803_item	3535384	et	4	main
kirja	doc_584615399803_item	3535388	et	4	main
ja	doc_584615399802_item	3535266	et	3	main
seitsmes	doc_584615399802_item	3535270	et	4	main
punast	doc_584615399802_item	3535277	et	4	main
väljakut	doc_584615399802_item	3535278	et	3	main
köime	doc_584615399802_item	3535279	et	4	main
turul	doc_584615399802_item	3535280	et	3	main
me	doc_584615399802_item	3535281	et	4	main
sõidame	doc_584615399802_item	3535282	et	3	main
hommikul	doc_584615399802_item	3535290	et	3	main
oleme	doc_584615399802_item	3535291	et	3	main
moskvas	doc_584615399802_item	3535293	et	4	main
me	doc_584615399802_item	3535294	et	4	main
oleme	doc_584615399802_item	3535295	et	3	main
seal	doc_584615399802_item	3535296	et	4	main
seitse	doc_584615399802_item	3535297	et	3	main
päevas	doc_584615399802_item	3535298	et	3	main
see	doc_584615399802_item	3535299	et	3	main
ei	doc_584615399802_item	3535300	et	4	main
lähe	doc_584615399802_item	3535301	et	4	main
kallilt	doc_584615399802_item	3535302	et	4	main
maksma	doc_584615399802_item	3535303	et	3	main
tee	doc_584615399802_item	3535304	et	4	main
maksab	doc_584615399802_item	3535305	et	3	main
kaks	doc_584615399802_item	3535306	et	3	main
tuhat	doc_584615399802_item	3535307	et	4	main
krooni	doc_584615399802_item	3535308	et	4	main
me	doc_584615399802_item	3535309	et	4	main
peatume	doc_584615399802_item	3535310	et	4	main
minu	doc_584615399802_item	3535311	et	3	main
venna	doc_584615399802_item	3535312	et	3	main
kodus	doc_584615399802_item	3535313	et	4	main
ma	doc_584615399802_item	3535314	et	3	main
kutsun	doc_584615399802_item	3535315	et	3	main
teda	doc_584615399802_item	3535316	et	4	main
koos	doc_584615399802_item	3535317	et	4	main
meiega	doc_584615399802_item	3535318	et	4	main
sõidama	doc_584615399802_item	3535319	et	4	main
moskvasse	doc_584615399802_item	3535320	et	4	main
sellega	doc_584615399802_item	3535321	et	3	main
lõpetan	doc_584615399802_item	3535322	et	3	main
ma	doc_584615399802_item	3535323	et	3	main
igatsen	doc_584615399802_item	3535324	et	3	main
sinu	doc_584615399802_item	3535325	et	3	main
jarel	doc_584615399802_item	3535326	et	4	main
reisi	doc_584615399803_item	3535343	et	4	main
ööbite	doc_584615399803_item	3535361	et	3	main
maksab	doc_584615399803_item	3535365	et	3	main
laine	doc_584615399803_item	3535379	et	4	main
sellest	doc_584615399803_item	3535396	et	4	main
tulen	doc_584615399803_item	3535467	et	3	main
tagasi	doc_584615399803_item	3535468	et	3	main
venemaalt	doc_584615399803_item	3535469	et	3	main
siis	doc_584615399803_item	3535470	et	3	main
ma	doc_584615399803_item	3535471	et	3	main
kirjutan	doc_584615399803_item	3535472	et	3	main
sulle	doc_584615399803_item	3535473	et	3	main
head	doc_584615399803_item	3535474	et	4	main
aega	doc_584615399803_item	3535475	et	4	main
eesnimi	doc_584615399803_item	3535476	et	3	main
14062005	doc_584615399803_item	3535477	et	2	main
venemaale	doc_584615399803_item	3535344	et	4	main
sellest	doc_584615399803_item	3535346	et	4	main
oma	doc_584615399803_item	3535348	et	4	main
kus	doc_584615399803_item	3535360	et	3	main
millistes	doc_584615399803_item	3535366	et	3	main
umbes	doc_584615399803_item	3535372	et	4	main
sõna	doc_584615399803_item	3535374	et	4	main
minu	doc_584615399803_item	3535376	et	3	main
sõbranna	doc_584615399803_item	3535378	et	4	main
suur	doc_584615399803_item	3535385	et	3	main
sulle	doc_584615399803_item	3535387	et	3	main
eest	doc_584615399803_item	3535389	et	4	main
mul	doc_584615399803_item	3535390	et	3	main
on	doc_584615399803_item	3535391	et	4	main
uudis	doc_584615399803_item	3535392	et	3	main
ja	doc_584615399803_item	3535393	et	3	main
tahaksin	doc_584615399803_item	3535394	et	3	main
sulle	doc_584615399803_item	3535395	et	3	main
mul	doc_584615399803_item	3535400	et	3	main
seal	doc_584615399803_item	3535413	et	4	main
elavad	doc_584615399803_item	3535414	et	4	main
sugulased	doc_584615399803_item	3535416	et	3	main
sugulaste	doc_584615399803_item	3535420	et	4	main
ma	doc_584615399803_item	3535422	et	3	main
armastan	doc_584615399803_item	3535423	et	3	main
moskva	doc_584615399803_item	3535424	et	4	main
seal	doc_584615399803_item	3535425	et	4	main
on	doc_584615399803_item	3535426	et	4	main
palju	doc_584615399803_item	3535427	et	4	main
huvitavaid	doc_584615399803_item	3535428	et	4	main
kohti	doc_584615399803_item	3535429	et	4	main
mulle	doc_584615399803_item	3535430	et	4	main
meeldib	doc_584615399803_item	3535431	et	3	main
käia	doc_584615399803_item	3535432	et	4	main
tretjakovi	doc_584615399803_item	3535433	et	4	main
galeriis	doc_584615399803_item	3535434	et	3	main
jalutada	doc_584615399803_item	3535435	et	3	main
punasel	doc_584615399803_item	3535436	et	4	main
puiestel	doc_584615399803_item	3535437	et	4	main
moskvas	doc_584615399803_item	3535438	et	4	main
me	doc_584615399803_item	3535439	et	4	main
sinu	doc_584615399803_item	3535383	et	3	main
järgmisel	doc_584615399803_item	3535398	et	3	main
puhkus	doc_584615399803_item	3535402	et	3	main
muidugi	doc_584615399803_item	3535418	et	4	main
käime	doc_584615399803_item	3535440	et	4	main
sinna	doc_584615399803_item	3535444	et	3	main
autoga	doc_584615399803_item	3535446	et	3	main
sõit	doc_584615399803_item	3535448	et	3	main
sest	doc_584615399803_item	3535453	et	4	main
pereliikmetel	doc_584615399803_item	3535455	et	3	main
kodakondsus	doc_584615399803_item	3535458	et	3	main
on	doc_584615399803_item	3535460	et	4	main
te	doc_584615399804_item	3535480	et	4	main
ööbite	doc_584615399804_item	3535500	et	3	main
millistes	doc_584615399804_item	3535505	et	3	main
pikkus	doc_584615399804_item	3535510	et	4	main
80	doc_584615399804_item	3535512	et	2	main
sinult	doc_584615399804_item	3535518	et	3	main
vastan	doc_584615399804_item	3535529	et	3	main
venemaale	doc_584615399804_item	3535535	et	4	main
päeval	doc_584615399804_item	3535578	et	3	main
te	doc_584615399805_item	3535615	et	4	main
reisi	doc_584615399805_item	3535617	et	4	main
maksab	doc_584615399805_item	3535639	et	3	main
peatute	doc_584615399805_item	3535642	et	4	main
nõutav	doc_584615399805_item	3535644	et	4	main
pikkus	doc_584615399805_item	3535645	et	4	main
laine	doc_584615399805_item	3535651	et	4	main
sain	doc_584615399805_item	3535652	et	3	main
täna	doc_584615399805_item	3535653	et	4	main
sinu	doc_584615399805_item	3535654	et	3	main
tänu	doc_584615399805_item	3535657	et	4	main
nii	doc_584615399805_item	3535660	et	3	main
sõida	doc_584615399805_item	3535682	et	4	main
juulil	doc_584615399805_item	3535688	et	3	main
järgmises	doc_584615399805_item	3535718	et	3	main
purskkaevad	doc_584615399805_item	3535726	et	4	main
kiri	doc_584615399806_item	3535759	et	3	main
kiri	doc_584615399806_item	3535766	et	3	main
oma	doc_584615399806_item	3535767	et	4	main
millal	doc_584615399806_item	3535771	et	3	main
te	doc_584615399806_item	3535774	et	4	main
sõita	doc_584615399806_item	3535775	et	3	main
soovite	doc_584615399806_item	3535776	et	3	main
millega	doc_584615399806_item	3535777	et	3	main
reisite	doc_584615399806_item	3535778	et	3	main
kus	doc_584615399806_item	3535779	et	3	main
ööbite	doc_584615399806_item	3535780	et	3	main
kui	doc_584615399806_item	3535781	et	3	main
palju	doc_584615399806_item	3535782	et	4	main
see	doc_584615399806_item	3535783	et	3	main
maksab	doc_584615399806_item	3535784	et	3	main
millistes	doc_584615399806_item	3535785	et	3	main
kohtades	doc_584615399806_item	3535786	et	3	main
umbes	doc_584615399806_item	3535791	et	4	main
80	doc_584615399806_item	3535792	et	2	main
on	doc_584615399806_item	3535805	et	4	main
kõik	doc_584615399806_item	3535806	et	4	main
olen	doc_584615399806_item	3535834	et	3	main
sõidan	doc_584615399806_item	3535841	et	3	main
maksavad	doc_584615399806_item	3535844	et	3	main
sillamäe	doc_584615399806_item	3535852	et	3	main
männimets	doc_584615399806_item	3535870	et	3	main
käime	doc_584615399806_item	3535873	et	4	main
kased	doc_584615399806_item	3535884	et	3	main
palju	doc_584615399806_item	3535893	et	4	main
pajud	doc_584615399806_item	3535894	et	3	main
sõidada	doc_584615399806_item	3535897	et	4	main
puhkusel	doc_584615399806_item	3535898	et	4	main
minu	doc_584615399806_item	3535902	et	3	main
bussiga	doc_584615399806_item	3535913	et	3	main
sellega	doc_584615399806_item	3535943	et	3	main
sinu	doc_584615399806_item	3535947	et	3	main
sellest	doc_397823702000_item	3535959	et	4	main
kirjutage	doc_397823702000_item	3535964	et	3	main
millega	doc_397823702000_item	3535971	et	3	main
nõutav	doc_397823702000_item	3535983	et	4	main
tiina	doc_397823702000_item	3535991	et	4	main
puhkus	doc_397823702000_item	3536017	et	3	main
ise	doc_397823702000_item	3536028	et	4	main
ainult	doc_397823702000_item	3536033	et	4	main
danilovini	doc_397823702000_item	3536054	et	4	main
aitäh	doc_584615399803_item	3535386	et	3	main
kirjutada	doc_584615399803_item	3535397	et	3	main
on	doc_584615399803_item	3535401	et	4	main
ma	doc_584615399803_item	3535403	et	3	main
reisi	doc_584615399803_item	3535405	et	4	main
minu	doc_584615399803_item	3535415	et	3	main
teatris	doc_584615399803_item	3535441	et	3	main
ja	doc_584615399803_item	3535442	et	3	main
kontserdil	doc_584615399803_item	3535443	et	3	main
sõidame	doc_584615399803_item	3535445	et	3	main
minu	doc_584615399803_item	3535451	et	3	main
eesti	doc_584615399803_item	3535457	et	4	main
reisi	doc_584615399804_item	3535482	et	4	main
kirjutage	doc_584615399804_item	3535484	et	3	main
kui	doc_584615399804_item	3535501	et	3	main
sõna	doc_584615399804_item	3535513	et	4	main
tere	doc_584615399804_item	3535514	et	3	main
laine	doc_584615399804_item	3535515	et	4	main
sain	doc_584615399804_item	3535516	et	3	main
kirja	doc_584615399804_item	3535519	et	4	main
oli	doc_584615399804_item	3535521	et	3	main
hea	doc_584615399804_item	3535523	et	4	main
sõidata	doc_584615399804_item	3535534	et	4	main
sankt	doc_584615399804_item	3535537	et	4	main
pileti	doc_584615399804_item	3535541	et	3	main
edasi	doc_584615399804_item	3535543	et	3	main
hakkame	doc_584615399804_item	3535577	et	3	main
kirjutage	doc_584615399805_item	3535619	et	3	main
oma	doc_584615399805_item	3535622	et	4	main
sõbrale	doc_584615399805_item	3535624	et	3	main
kuhu	doc_584615399805_item	3535628	et	3	main
sõita	doc_584615399805_item	3535630	et	3	main
reisite	doc_584615399805_item	3535633	et	3	main
palju	doc_584615399805_item	3535637	et	4	main
kohtades	doc_584615399805_item	3535641	et	3	main
tere	doc_584615399805_item	3535649	et	3	main
on	doc_584615399805_item	3535665	et	4	main
uudis	doc_584615399805_item	3535666	et	3	main
ja	doc_584615399805_item	3535667	et	3	main
tahaksin	doc_584615399805_item	3535668	et	3	main
sulle	doc_584615399805_item	3535669	et	3	main
sellest	doc_584615399805_item	3535670	et	4	main
sõida	doc_584615399805_item	3535676	et	4	main
ma	doc_584615399805_item	3535685	et	3	main
10	doc_584615399805_item	3535687	et	2	main
tallinnast	doc_584615399805_item	3535689	et	3	main
esmaspäeval	doc_584615399803_item	3535399	et	3	main
plaanin	doc_584615399803_item	3535404	et	3	main
venemaale	doc_584615399803_item	3535406	et	4	main
oma	doc_584615399803_item	3535407	et	4	main
perega	doc_584615399803_item	3535408	et	3	main
ma	doc_584615399803_item	3535409	et	3	main
soovin	doc_584615399803_item	3535410	et	3	main
sõita	doc_584615399803_item	3535411	et	3	main
ja	doc_584615399803_item	3535417	et	3	main
ööbime	doc_584615399803_item	3535419	et	3	main
juures	doc_584615399803_item	3535421	et	4	main
kallis	doc_584615399803_item	3535450	et	4	main
on	doc_584615399803_item	3535456	et	4	main
ja	doc_584615399803_item	3535459	et	3	main
vaja	doc_584615399803_item	3535461	et	4	main
viisat	doc_584615399803_item	3535462	et	3	main
moskva	doc_584615399803_item	3535412	et	4	main
plaanite	doc_584615399804_item	3535481	et	3	main
sellest	doc_584615399804_item	3535485	et	4	main
oma	doc_584615399804_item	3535487	et	4	main
sõbrale	doc_584615399804_item	3535489	et	3	main
millal	doc_584615399804_item	3535491	et	3	main
kuhu	doc_584615399804_item	3535493	et	3	main
kus	doc_584615399804_item	3535499	et	3	main
kohtades	doc_584615399804_item	3535506	et	3	main
sulle	doc_584615399804_item	3535530	et	3	main
linna	doc_584615399804_item	3535536	et	4	main
peterburgi	doc_584615399804_item	3535538	et	4	main
ma	doc_584615399804_item	3535539	et	3	main
ostsin	doc_584615399804_item	3535540	et	3	main
plaanite	doc_584615399805_item	3535616	et	3	main
venemaale	doc_584615399805_item	3535618	et	4	main
see	doc_584615399805_item	3535638	et	3	main
umbes	doc_584615399805_item	3535646	et	4	main
80	doc_584615399805_item	3535647	et	2	main
kirja	doc_584615399805_item	3535655	et	4	main
et	doc_584615399805_item	3535658	et	3	main
sa	doc_584615399805_item	3535659	et	3	main
kirjutada	doc_584615399805_item	3535671	et	3	main
kuul	doc_584615399805_item	3535673	et	4	main
peterburi	doc_584615399805_item	3535691	et	4	main
võimalus	doc_584615399805_item	3535714	et	3	main
käia	doc_584615399805_item	3535715	et	4	main
petergofi	doc_584615399805_item	3535721	et	4	main
pargis	doc_584615399805_item	3535723	et	3	main
vaatame	doc_584615399805_item	3535725	et	3	main
soovid	doc_584615399805_item	3535740	et	4	main
kui	doc_584615399805_item	3535743	et	3	main
siis	doc_584615399805_item	3535745	et	3	main
see	doc_584615399803_item	3535447	et	3	main
on	doc_584615399803_item	3535449	et	4	main
jäoks	doc_584615399803_item	3535452	et	4	main
mõnedel	doc_584615399803_item	3535454	et	3	main
seekord	doc_584615399803_item	3535463	et	3	main
lõpetan	doc_584615399803_item	3535464	et	3	main
kui	doc_584615399803_item	3535465	et	3	main
ma	doc_584615399803_item	3535466	et	3	main
kiri	doc_584615399804_item	3535479	et	3	main
kiri	doc_584615399804_item	3535486	et	3	main
eestlasest	doc_584615399804_item	3535488	et	3	main
ja	doc_584615399804_item	3535492	et	3	main
palju	doc_584615399804_item	3535502	et	4	main
see	doc_584615399804_item	3535503	et	3	main
kirja	doc_584615399804_item	3535508	et	4	main
mul	doc_584615399804_item	3535520	et	3	main
väga	doc_584615399804_item	3535522	et	3	main
meel	doc_584615399804_item	3535524	et	4	main
et	doc_584615399804_item	3535525	et	3	main
sa	doc_584615399804_item	3535526	et	3	main
mulle	doc_584615399804_item	3535527	et	4	main
kohe	doc_584615399804_item	3535542	et	4	main
jalutama	doc_584615399804_item	3535579	et	3	main
linnas	doc_584615399804_item	3535580	et	4	main
käima	doc_584615399804_item	3535581	et	4	main
muuseums	doc_584615399804_item	3535582	et	4	main
me	doc_584615399804_item	3535583	et	4	main
lähme	doc_584615399804_item	3535584	et	3	main
õhtul	doc_584615399804_item	3535585	et	3	main
teatrisse	doc_584615399804_item	3535586	et	3	main
linnas	doc_584615399804_item	3535587	et	4	main
palju	doc_584615399804_item	3535588	et	4	main
vaatamisvarsast	doc_584615399804_item	3535589	et	4	main
aga	doc_584615399804_item	3535590	et	3	main
vähi	doc_584615399804_item	3535591	et	3	main
raha	doc_584615399804_item	3535592	et	4	main
hommikul	doc_584615399804_item	3535593	et	3	main
pühapäeval	doc_584615399804_item	3535594	et	3	main
ma	doc_584615399804_item	3535595	et	3	main
sõidan	doc_584615399804_item	3535596	et	3	main
koju	doc_584615399804_item	3535597	et	3	main
pean	doc_584615399804_item	3535598	et	4	main
müüd	doc_584615399804_item	3535599	et	4	main
trenni	doc_584615399804_item	3535600	et	4	main
minema	doc_584615399804_item	3535601	et	3	main
sellega	doc_584615399804_item	3535602	et	3	main
lõpetan	doc_584615399804_item	3535603	et	3	main
tervita	doc_584615399804_item	3535604	et	4	main
minu	doc_584615399804_item	3535605	et	3	main
poolt	doc_584615399804_item	3535606	et	4	main
tütre	doc_584615399804_item	3535607	et	3	main
kõike	doc_584615399804_item	3535608	et	4	main
hed	doc_584615399804_item	3535609	et	4	main
sulle	doc_584615399804_item	3535610	et	3	main
nägemisem	doc_584615399804_item	3535611	et	4	main
eesnimi	doc_584615399804_item	3535612	et	3	main
venemaale	doc_584615399804_item	3535483	et	4	main
kirjutage	doc_584615399804_item	3535490	et	3	main
te	doc_584615399804_item	3535494	et	4	main
sõita	doc_584615399804_item	3535495	et	3	main
soovite	doc_584615399804_item	3535496	et	3	main
millega	doc_584615399804_item	3535497	et	3	main
reisite	doc_584615399804_item	3535498	et	3	main
maksab	doc_584615399804_item	3535504	et	3	main
peatute	doc_584615399804_item	3535507	et	4	main
nõutav	doc_584615399804_item	3535509	et	4	main
umbes	doc_584615399804_item	3535511	et	4	main
täna	doc_584615399804_item	3535517	et	4	main
kirjutasid	doc_584615399804_item	3535528	et	4	main
kohe	doc_584615399804_item	3535531	et	4	main
ma	doc_584615399804_item	3535532	et	3	main
tahan	doc_584615399804_item	3535533	et	3	main
ja	doc_584615399804_item	3535544	et	3	main
tagasi	doc_584615399804_item	3535545	et	3	main
sest	doc_584615399804_item	3535546	et	4	main
et	doc_584615399804_item	3535547	et	3	main
see	doc_584615399804_item	3535548	et	3	main
on	doc_584615399804_item	3535549	et	4	main
odavam	doc_584615399804_item	3535550	et	4	main
ma	doc_584615399804_item	3535551	et	3	main
maksasin	doc_584615399804_item	3535552	et	4	main
500	doc_584615399804_item	3535553	et	2	main
krooni	doc_584615399804_item	3535554	et	4	main
ma	doc_584615399804_item	3535555	et	3	main
tahan	doc_584615399804_item	3535556	et	3	main
külastada	doc_584615399804_item	3535557	et	3	main
oma	doc_584615399804_item	3535558	et	4	main
sõbra	doc_584615399804_item	3535559	et	3	main
sest	doc_584615399804_item	3535560	et	4	main
et	doc_584615399804_item	3535561	et	3	main
ammu	doc_584615399804_item	3535562	et	4	main
teda	doc_584615399804_item	3535563	et	4	main
ei	doc_584615399804_item	3535564	et	4	main
ole	doc_584615399804_item	3535565	et	4	main
näinud	doc_584615399804_item	3535566	et	4	main
ma	doc_584615399804_item	3535567	et	3	main
olen	doc_584615399804_item	3535568	et	3	main
sõidama	doc_584615399804_item	3535569	et	4	main
bussiga	doc_584615399804_item	3535570	et	3	main
laupäeval	doc_584615399804_item	3535571	et	3	main
ma	doc_584615399804_item	3535572	et	3	main
olen	doc_584615399804_item	3535573	et	3	main
tema	doc_584615399804_item	3535574	et	4	main
öömajal	doc_584615399804_item	3535575	et	3	main
me	doc_584615399804_item	3535576	et	4	main
sellest	doc_584615399805_item	3535620	et	4	main
millal	doc_584615399805_item	3535626	et	3	main
soovite	doc_584615399805_item	3535631	et	3	main
kus	doc_584615399805_item	3535634	et	3	main
kui	doc_584615399805_item	3535636	et	3	main
kirja	doc_584615399805_item	3535643	et	4	main
sõna	doc_584615399805_item	3535648	et	4	main
kallis	doc_584615399805_item	3535650	et	4	main
suur	doc_584615399805_item	3535656	et	3	main
ruttu	doc_584615399805_item	3535661	et	4	main
mulle	doc_584615399805_item	3535662	et	4	main
järgmisel	doc_584615399805_item	3535672	et	3	main
ma	doc_584615399805_item	3535674	et	3	main
kas	doc_584615399805_item	3535678	et	3	main
sa	doc_584615399805_item	3535679	et	3	main
koos	doc_584615399805_item	3535683	et	4	main
rongiga	doc_584615399805_item	3535692	et	4	main
ööbin	doc_584615399805_item	3535693	et	3	main
nevski	doc_584615399805_item	3535695	et	4	main
aga	doc_584615399805_item	3535697	et	3	main
see	doc_584615399805_item	3535698	et	3	main
on	doc_584615399805_item	3535699	et	4	main
väga	doc_584615399805_item	3535700	et	3	main
kallis	doc_584615399805_item	3535701	et	4	main
võib	doc_584615399805_item	3535702	et	3	main
olla	doc_584615399805_item	3535703	et	3	main
ööbin	doc_584615399805_item	3535704	et	3	main
sugulase	doc_584615399805_item	3535705	et	3	main
juures	doc_584615399805_item	3535706	et	4	main
plaanis	doc_584615399805_item	3535707	et	4	main
on	doc_584615399805_item	3535708	et	4	main
muuseumide	doc_584615399805_item	3535709	et	3	main
külastamine	doc_584615399805_item	3535710	et	4	main
ja	doc_584615399805_item	3535711	et	3	main
ekskursionid	doc_584615399805_item	3535712	et	4	main
on	doc_584615399805_item	3535713	et	4	main
turul	doc_584615399805_item	3535716	et	3	main
päevas	doc_584615399805_item	3535719	et	3	main
ma	doc_584615399805_item	3535727	et	3	main
et	doc_584615399805_item	3535729	et	3	main
ilus	doc_584615399805_item	3535733	et	4	main
ma	doc_584615399805_item	3535734	et	3	main
saabun	doc_584615399805_item	3535735	et	3	main
koju	doc_584615399805_item	3535736	et	3	main
kas	doc_584615399805_item	3535739	et	3	main
sõita	doc_584615399805_item	3535742	et	3	main
vasta	doc_584615399805_item	3535746	et	4	main
kiiresti	doc_584615399805_item	3535747	et	3	main
ootan	doc_584615399805_item	3535748	et	3	main
sinu	doc_584615399805_item	3535749	et	3	main
venemaale	doc_584615399806_item	3535763	et	4	main
sõbrale	doc_584615399806_item	3535769	et	3	main
ja	doc_584615399806_item	3535772	et	3	main
nõutav	doc_584615399806_item	3535789	et	4	main
ole	doc_584615399806_item	3535798	et	4	main
korras	doc_584615399806_item	3535807	et	4	main
tütre	doc_584615399806_item	3535836	et	3	main
nüüd	doc_584615399806_item	3535848	et	4	main
ma	doc_584615399806_item	3535849	et	3	main
puhkan	doc_584615399806_item	3535850	et	3	main
puud	doc_584615399806_item	3535881	et	4	main
pärnad	doc_584615399806_item	3535882	et	3	main
maja	doc_584615399806_item	3535886	et	4	main
jõe	doc_584615399806_item	3535888	et	3	main
planeerin	doc_584615399806_item	3535896	et	3	main
kiri	doc_584615399805_item	3535614	et	3	main
kiri	doc_584615399805_item	3535621	et	3	main
eestlasest	doc_584615399805_item	3535623	et	3	main
kirjutage	doc_584615399805_item	3535625	et	3	main
ja	doc_584615399805_item	3535627	et	3	main
te	doc_584615399805_item	3535629	et	4	main
millega	doc_584615399805_item	3535632	et	3	main
ööbite	doc_584615399805_item	3535635	et	3	main
millistes	doc_584615399805_item	3535640	et	3	main
vastasid	doc_584615399805_item	3535663	et	4	main
mul	doc_584615399805_item	3535664	et	3	main
tahan	doc_584615399805_item	3535675	et	3	main
venemaale	doc_584615399805_item	3535677	et	4	main
ei	doc_584615399805_item	3535680	et	4	main
taha	doc_584615399805_item	3535681	et	4	main
minuga	doc_584615399805_item	3535684	et	3	main
sõidan	doc_584615399805_item	3535686	et	3	main
sankt	doc_584615399805_item	3535690	et	4	main
hotellis	doc_584615399805_item	3535694	et	3	main
prospektis	doc_584615399805_item	3535696	et	3	main
mõtlen	doc_584615399805_item	3535728	et	3	main
se	doc_584615399805_item	3535730	et	4	main
väga	doc_584615399805_item	3535732	et	3	main
12	doc_584615399805_item	3535737	et	2	main
juulil	doc_584615399805_item	3535738	et	3	main
plaanite	doc_584615399806_item	3535761	et	3	main
kirjutage	doc_584615399806_item	3535764	et	3	main
kirja	doc_584615399806_item	3535788	et	4	main
sa	doc_584615399806_item	3535796	et	3	main
sõita	doc_584615399806_item	3535831	et	3	main
kaugel	doc_584615399806_item	3535832	et	4	main
ma	doc_584615399806_item	3535833	et	3	main
jurde	doc_584615399806_item	3535837	et	4	main
ma	doc_584615399806_item	3535839	et	3	main
bussiga	doc_584615399806_item	3535842	et	3	main
ei	doc_584615399806_item	3535845	et	4	main
ole	doc_584615399806_item	3535846	et	4	main
linn	doc_584615399806_item	3535853	et	3	main
väga	doc_584615399806_item	3535855	et	3	main
sinna	doc_584615399806_item	3535871	et	3	main
oma	doc_584615399806_item	3535874	et	4	main
sõbrannaga	doc_584615399806_item	3535875	et	3	main
päevitamas	doc_584615399806_item	3535876	et	3	main
ja	doc_584615399806_item	3535877	et	3	main
suplemas	doc_584615399806_item	3535878	et	3	main
linnas	doc_584615399806_item	3535879	et	4	main
minu	doc_584615399806_item	3535885	et	3	main
maja	doc_584615399806_item	3535890	et	4	main
juures	doc_584615399806_item	3535891	et	4	main
peterburgisse	doc_584615399806_item	3535899	et	4	main
täti	doc_584615399806_item	3535903	et	4	main
peatun	doc_584615399806_item	3535907	et	3	main
täti	doc_584615399806_item	3535909	et	4	main
ma	doc_584615399806_item	3535911	et	3	main
selle	doc_584615399806_item	3535914	et	4	main
pärast	doc_584615399806_item	3535915	et	4	main
bussiga	doc_584615399806_item	3535916	et	3	main
head	doc_584615399806_item	3535949	et	4	main
plaanite	doc_397823702000_item	3535955	et	3	main
kiri	doc_397823702000_item	3535960	et	3	main
millal	doc_397823702000_item	3535965	et	3	main
kus	doc_397823702000_item	3535973	et	3	main
ööbite	doc_397823702000_item	3535974	et	3	main
kirja	doc_397823702000_item	3535982	et	4	main
kallis	doc_397823702000_item	3535989	et	4	main
sõbranna	doc_397823702000_item	3535990	et	4	main
sain	doc_397823702000_item	3535992	et	3	main
tädi	doc_397823702000_item	3536025	et	4	main
sõidan	doc_397823702000_item	3536047	et	3	main
aga	doc_584615399805_item	3535717	et	3	main
sõidame	doc_584615399805_item	3535720	et	3	main
jalutame	doc_584615399805_item	3535722	et	3	main
ja	doc_584615399805_item	3535724	et	3	main
olib	doc_584615399805_item	3535731	et	4	main
minuga	doc_584615399805_item	3535741	et	3	main
soovid	doc_584615399805_item	3535744	et	4	main
kirja	doc_584615399805_item	3535750	et	4	main
see	doc_584615399805_item	3535751	et	3	main
kord	doc_584615399805_item	3535752	et	4	main
lopetan	doc_584615399805_item	3535753	et	4	main
head	doc_584615399805_item	3535754	et	4	main
aega	doc_584615399805_item	3535755	et	4	main
140605	doc_584615399805_item	3535756	et	2	main
eesnimi	doc_584615399805_item	3535757	et	3	main
reisi	doc_584615399806_item	3535762	et	4	main
sellest	doc_584615399806_item	3535765	et	4	main
eestlasest	doc_584615399806_item	3535768	et	3	main
kirjutage	doc_584615399806_item	3535770	et	3	main
kuhu	doc_584615399806_item	3535773	et	3	main
pikkus	doc_584615399806_item	3535790	et	4	main
ei	doc_584615399806_item	3535797	et	4	main
ammu	doc_584615399806_item	3535800	et	4	main
mul	doc_584615399806_item	3535804	et	3	main
kallis	doc_584615399806_item	3535847	et	4	main
palju	doc_584615399806_item	3535880	et	4	main
kasvavad	doc_584615399806_item	3535892	et	4	main
seal	doc_584615399806_item	3535900	et	4	main
tänaval	doc_584615399806_item	3535905	et	4	main
juures	doc_584615399806_item	3535910	et	4	main
sõidaksin	doc_584615399806_item	3535912	et	3	main
asub	doc_584615399806_item	3535920	et	3	main
ma	doc_584615399806_item	3535940	et	3	main
kirja	doc_584615399806_item	3535948	et	4	main
sillamäe	doc_584615399806_item	3535921	et	3	main
linnas	doc_584615399806_item	3535922	et	4	main
keskel	doc_584615399806_item	3535923	et	3	main
piletid	doc_584615399806_item	3535924	et	3	main
maksavad	doc_584615399806_item	3535925	et	3	main
keskmises	doc_584615399806_item	3535926	et	3	main
saada	doc_584615399806_item	3535927	et	4	main
viiskümmend	doc_584615399806_item	3535928	et	4	main
krooni	doc_584615399806_item	3535929	et	4	main
ma	doc_584615399806_item	3535930	et	3	main
tahan	doc_584615399806_item	3535931	et	3	main
käja	doc_584615399806_item	3535932	et	4	main
teatrisse	doc_584615399806_item	3535933	et	3	main
külastada	doc_584615399806_item	3535934	et	3	main
muuseumi	doc_584615399806_item	3535935	et	4	main
esimeseks	doc_584615399806_item	3535936	et	3	main
ma	doc_584615399806_item	3535937	et	3	main
külastaksin	doc_584615399806_item	3535938	et	3	main
ermitaaži	doc_584615399806_item	3535939	et	2	main
te	doc_584615399806_item	3535760	et	4	main
peatute	doc_584615399806_item	3535787	et	4	main
sõna	doc_584615399806_item	3535793	et	4	main
tere	doc_584615399806_item	3535794	et	3	main
mapina	doc_584615399806_item	3535795	et	3	main
mulle	doc_584615399806_item	3535799	et	4	main
kirjutanud	doc_584615399806_item	3535801	et	4	main
kuidas	doc_584615399806_item	3535802	et	3	main
läheb	doc_584615399806_item	3535803	et	3	main
ma	doc_584615399806_item	3535808	et	3	main
elan	doc_584615399806_item	3535809	et	3	main
vanaviisi	doc_584615399806_item	3535810	et	4	main
praegu	doc_584615399806_item	3535811	et	3	main
on	doc_584615399806_item	3535812	et	4	main
suvi	doc_584615399806_item	3535813	et	3	main
mis	doc_584615399806_item	3535814	et	4	main
sina	doc_584615399806_item	3535815	et	4	main
saad	doc_584615399806_item	3535816	et	4	main
teha	doc_584615399806_item	3535817	et	3	main
ma	doc_584615399806_item	3535818	et	3	main
ei	doc_584615399806_item	3535819	et	4	main
tea	doc_584615399806_item	3535820	et	4	main
mida	doc_584615399806_item	3535821	et	4	main
hakkan	doc_584615399806_item	3535822	et	3	main
tegema	doc_584615399806_item	3535823	et	3	main
suvel	doc_584615399806_item	3535824	et	3	main
mul	doc_584615399806_item	3535825	et	3	main
ei	doc_584615399806_item	3535826	et	4	main
ole	doc_584615399806_item	3535827	et	4	main
praegu	doc_584615399806_item	3535828	et	3	main
raha	doc_584615399806_item	3535829	et	4	main
et	doc_584615399806_item	3535830	et	3	main
sõidan	doc_584615399806_item	3535835	et	3	main
tallinna	doc_584615399806_item	3535838	et	4	main
allati	doc_584615399806_item	3535840	et	3	main
piletid	doc_584615399806_item	3535843	et	3	main
kodus	doc_584615399806_item	3535851	et	4	main
on	doc_584615399806_item	3535854	et	4	main
ilus	doc_584615399806_item	3535856	et	4	main
linn	doc_584615399806_item	3535857	et	3	main
ta	doc_584615399806_item	3535858	et	4	main
asub	doc_584615399806_item	3535859	et	3	main
mere	doc_584615399806_item	3535860	et	3	main
juures	doc_584615399806_item	3535861	et	4	main
rand	doc_584615399806_item	3535862	et	3	main
asub	doc_584615399806_item	3535863	et	3	main
linnast	doc_584615399806_item	3535864	et	4	main
välja	doc_584615399806_item	3535865	et	4	main
seal	doc_584615399806_item	3535866	et	4	main
on	doc_584615399806_item	3535867	et	4	main
väga	doc_584615399806_item	3535868	et	3	main
ilus	doc_584615399806_item	3535869	et	4	main
me	doc_584615399806_item	3535872	et	4	main
paplid	doc_584615399806_item	3535883	et	3	main
asub	doc_584615399806_item	3535887	et	3	main
ääres	doc_584615399806_item	3535889	et	4	main
ma	doc_584615399806_item	3535895	et	3	main
kosmonauti	doc_584615399806_item	3535904	et	4	main
ma	doc_584615399806_item	3535906	et	3	main
mugavam	doc_584615399806_item	3535917	et	4	main
sõidada	doc_584615399806_item	3535918	et	4	main
bussijaam	doc_584615399806_item	3535919	et	3	main
käiksin	doc_584615399806_item	3535941	et	3	main
jaan	doc_584615399806_item	3535945	et	3	main
aega	doc_584615399806_item	3535950	et	4	main
eesnimi	doc_584615399806_item	3535951	et	3	main
te	doc_397823702000_item	3535954	et	4	main
eestlasest	doc_397823702000_item	3535962	et	3	main
ja	doc_397823702000_item	3535966	et	3	main
te	doc_397823702000_item	3535968	et	4	main
soovite	doc_397823702000_item	3535970	et	3	main
palju	doc_397823702000_item	3535976	et	4	main
see	doc_397823702000_item	3535977	et	3	main
maksab	doc_397823702000_item	3535978	et	3	main
juurde	doc_397823702000_item	3536026	et	4	main
sõidan	doc_397823702000_item	3536027	et	3	main
aabikaasa	doc_397823702000_item	3536030	et	4	main
elektrirong	doc_397823702000_item	3536053	et	3	main
elab	doc_397823702000_item	3536056	et	3	main
tädi	doc_397823702000_item	3536058	et	4	main
temal	doc_397823702000_item	3536059	et	3	main
te	doc_397823702001_item	3536086	et	4	main
kiri	doc_397823702001_item	3536092	et	3	main
sõbrale	doc_397823702001_item	3536095	et	3	main
soovite	doc_397823702001_item	3536102	et	3	main
reisite	doc_397823702001_item	3536104	et	3	main
kui	doc_397823702001_item	3536107	et	3	main
see	doc_397823702001_item	3536109	et	3	main
80	doc_397823702001_item	3536118	et	2	main
sõber	doc_397823702001_item	3536122	et	3	main
sain	doc_397823702001_item	3536124	et	3	main
sinult	doc_397823702001_item	3536126	et	3	main
tahan	doc_397823702001_item	3536132	et	3	main
vastata	doc_397823702001_item	3536135	et	4	main
15	doc_397823702001_item	3536148	et	2	main
ja	doc_397823702001_item	3536150	et	3	main
plaanin	doc_397823702001_item	3536152	et	3	main
sugulasi	doc_397823702001_item	3536160	et	3	main
tahan	doc_397823702001_item	3536162	et	3	main
neid	doc_397823702001_item	3536163	et	4	main
kiri	doc_397823702002_item	3536206	et	3	main
kirjutage	doc_397823702002_item	3536211	et	3	main
palju	doc_397823702002_item	3536229	et	4	main
maksab	doc_397823702002_item	3536231	et	3	main
peatute	doc_397823702002_item	3536234	et	4	main
nõutav	doc_397823702002_item	3536236	et	4	main
pikkus	doc_397823702002_item	3536237	et	4	main
planin	doc_397823702002_item	3536273	et	4	main
venemaale	doc_397823702002_item	3536275	et	4	main
ma	doc_397823702002_item	3536276	et	3	main
ja	doc_397823702002_item	3536304	et	3	main
muuseumis	doc_397823702002_item	3536306	et	3	main
olen	doc_397823702002_item	3536307	et	3	main
peterburis	doc_397823702002_item	3536308	et	4	main
elavad	doc_584615399806_item	3535901	et	4	main
allati	doc_584615399806_item	3535908	et	3	main
tsirkusse	doc_584615399806_item	3535942	et	3	main
lõppetan	doc_584615399806_item	3535944	et	4	main
ootama	doc_584615399806_item	3535946	et	3	main
kiri	doc_397823702000_item	3535953	et	3	main
reisi	doc_397823702000_item	3535956	et	4	main
kirjutage	doc_397823702000_item	3535958	et	3	main
sõbrale	doc_397823702000_item	3535963	et	3	main
sõna	doc_397823702000_item	3535987	et	4	main
tere	doc_397823702000_item	3535988	et	3	main
puhkus	doc_397823702000_item	3536031	et	3	main
rongiga	doc_397823702000_item	3536048	et	4	main
tädi	doc_397823702000_item	3536062	et	4	main
elab	doc_397823702000_item	3536063	et	3	main
sellest	doc_397823702001_item	3536091	et	4	main
ja	doc_397823702001_item	3536098	et	3	main
te	doc_397823702001_item	3536100	et	4	main
millega	doc_397823702001_item	3536103	et	3	main
ööbite	doc_397823702001_item	3536106	et	3	main
kohtades	doc_397823702001_item	3536112	et	3	main
umbes	doc_397823702001_item	3536117	et	4	main
tere	doc_397823702001_item	3536120	et	3	main
mihkel	doc_397823702001_item	3536123	et	3	main
eest	doc_397823702001_item	3536131	et	4	main
mitu	doc_397823702001_item	3536158	et	4	main
sellest	doc_397823702002_item	3536212	et	4	main
oma	doc_397823702002_item	3536214	et	4	main
see	doc_397823702002_item	3536230	et	3	main
millistes	doc_397823702002_item	3536232	et	3	main
umbes	doc_397823702002_item	3536238	et	4	main
bussireisi	doc_397823702002_item	3536274	et	4	main
poole	doc_397823702002_item	3536277	et	4	main
juba	doc_397823702002_item	3536278	et	3	main
mittu	doc_397823702002_item	3536279	et	4	main
sugulasi	doc_397823702002_item	3536281	et	3	main
külastanut	doc_397823702002_item	3536282	et	4	main
tahan	doc_397823702002_item	3536283	et	3	main
mõnes	doc_397823702002_item	3536305	et	3	main
5	doc_397823702002_item	3536309	et	2	main
sugulaste	doc_397823702002_item	3536312	et	4	main
suvepuhkust	doc_397823702002_item	3536319	et	4	main
ootan	doc_397823702002_item	3536321	et	3	main
venemaale	doc_397823702003_item	3536331	et	4	main
sellest	doc_397823702003_item	3536333	et	4	main
oma	doc_397823702003_item	3536335	et	4	main
kirjutage	doc_397823702003_item	3536338	et	3	main
kuhu	doc_397823702003_item	3536341	et	3	main
millega	doc_397823702003_item	3536345	et	3	main
reisite	doc_397823702003_item	3536346	et	3	main
kus	doc_397823702003_item	3536347	et	3	main
ööbite	doc_397823702003_item	3536348	et	3	main
peatute	doc_397823702003_item	3536355	et	4	main
80	doc_397823702003_item	3536360	et	2	main
irina	doc_397823702003_item	3536365	et	3	main
aitäh	doc_397823702003_item	3536371	et	3	main
kirjutage	doc_397823702004_item	3536454	et	3	main
kiri	doc_397823702004_item	3536456	et	3	main
sõbrale	doc_397823702004_item	3536459	et	3	main
ja	doc_397823702004_item	3536462	et	3	main
millega	doc_397823702004_item	3536467	et	3	main
kui	doc_397823702004_item	3536471	et	3	main
täna	doc_397823702004_item	3536488	et	4	main
sinud	doc_397823702004_item	3536489	et	4	main
vastata	doc_397823702004_item	3536498	et	4	main
tahan	doc_397823702004_item	3536505	et	3	main
minu	doc_397823702004_item	3536508	et	3	main
viieteistkümnendal	doc_397823702004_item	3536511	et	4	main
ja	doc_397823702004_item	3536513	et	3	main
plaanin	doc_397823702004_item	3536515	et	3	main
mittu	doc_397823702004_item	3536521	et	4	main
aastat	doc_397823702004_item	3536522	et	3	main
te	doc_397823702005_item	3536571	et	4	main
kiri	doc_397823702005_item	3536577	et	3	main
80	doc_397823702005_item	3536603	et	2	main
sõna	doc_397823702005_item	3536604	et	4	main
ja	doc_397823702005_item	3536626	et	3	main
07	doc_397823702005_item	3536634	et	2	main
mittu	doc_397823702005_item	3536643	et	4	main
külastanud	doc_397823702005_item	3536646	et	4	main
ma	doc_397823702005_item	3536647	et	3	main
mõnes	doc_397823702005_item	3536670	et	3	main
sügisel	doc_397823702000_item	3536034	et	3	main
mina	doc_397823702000_item	3536035	et	4	main
planeerin	doc_397823702000_item	3536036	et	3	main
sõita	doc_397823702000_item	3536037	et	3	main
kui	doc_397823702000_item	3536038	et	3	main
visa	doc_397823702000_item	3536039	et	4	main
on	doc_397823702000_item	3536040	et	4	main
valmis	doc_397823702000_item	3536041	et	4	main
visa	doc_397823702000_item	3536042	et	4	main
maksab	doc_397823702000_item	3536043	et	3	main
seitsesada	doc_397823702000_item	3536044	et	4	main
krooni	doc_397823702000_item	3536045	et	4	main
mina	doc_397823702000_item	3536046	et	4	main
venemaale	doc_397823702000_item	3535957	et	4	main
oma	doc_397823702000_item	3535961	et	4	main
kuhu	doc_397823702000_item	3535967	et	3	main
sõita	doc_397823702000_item	3535969	et	3	main
reisite	doc_397823702000_item	3535972	et	3	main
kui	doc_397823702000_item	3535975	et	3	main
millistes	doc_397823702000_item	3535979	et	3	main
kohtades	doc_397823702000_item	3535980	et	3	main
peatute	doc_397823702000_item	3535981	et	4	main
pikkus	doc_397823702000_item	3535984	et	4	main
umbes	doc_397823702000_item	3535985	et	4	main
80	doc_397823702000_item	3535986	et	2	main
tana	doc_397823702000_item	3535993	et	4	main
sinu	doc_397823702000_item	3535994	et	3	main
kirja	doc_397823702000_item	3535995	et	4	main
suur	doc_397823702000_item	3535996	et	3	main
aitah	doc_397823702000_item	3535997	et	4	main
kirja	doc_397823702000_item	3535998	et	4	main
eest	doc_397823702000_item	3535999	et	4	main
tahan	doc_397823702000_item	3536000	et	3	main
sulle	doc_397823702000_item	3536001	et	3	main
kohe	doc_397823702000_item	3536002	et	4	main
vastata	doc_397823702000_item	3536003	et	4	main
sest	doc_397823702000_item	3536004	et	4	main
on	doc_397823702000_item	3536005	et	4	main
mul	doc_397823702000_item	3536006	et	3	main
sulle	doc_397823702000_item	3536007	et	3	main
uudis	doc_397823702000_item	3536008	et	3	main
ja	doc_397823702000_item	3536009	et	3	main
tahan	doc_397823702000_item	3536010	et	3	main
sulle	doc_397823702000_item	3536011	et	3	main
sellest	doc_397823702000_item	3536012	et	4	main
kirjutada	doc_397823702000_item	3536013	et	3	main
varsti	doc_397823702000_item	3536014	et	3	main
mul	doc_397823702000_item	3536015	et	3	main
on	doc_397823702000_item	3536016	et	4	main
ja	doc_397823702000_item	3536018	et	3	main
ma	doc_397823702000_item	3536019	et	3	main
planeerin	doc_397823702000_item	3536020	et	3	main
reisi	doc_397823702000_item	3536021	et	4	main
venemaale	doc_397823702000_item	3536022	et	4	main
külla	doc_397823702000_item	3536023	et	4	main
minu	doc_397823702000_item	3536024	et	3	main
seest	doc_397823702000_item	3536029	et	3	main
on	doc_397823702000_item	3536032	et	4	main
moskvani	doc_397823702000_item	3536049	et	4	main
ja	doc_397823702000_item	3536050	et	3	main
moskvast	doc_397823702000_item	3536051	et	4	main
sõidab	doc_397823702000_item	3536052	et	3	main
kus	doc_397823702000_item	3536055	et	3	main
plaanite	doc_397823702001_item	3536087	et	3	main
kirjutage	doc_397823702001_item	3536090	et	3	main
millal	doc_397823702001_item	3536097	et	3	main
kuhu	doc_397823702001_item	3536099	et	3	main
sõita	doc_397823702001_item	3536101	et	3	main
kus	doc_397823702001_item	3536105	et	3	main
palju	doc_397823702001_item	3536108	et	4	main
sõna	doc_397823702001_item	3536119	et	4	main
tahan	doc_397823702001_item	3536142	et	3	main
minu	doc_397823702001_item	3536145	et	3	main
algab	doc_397823702001_item	3536147	et	3	main
ma	doc_397823702001_item	3536151	et	3	main
aastat	doc_397823702001_item	3536159	et	3	main
külastanud	doc_397823702001_item	3536161	et	4	main
ja	doc_397823702001_item	3536183	et	3	main
mõnes	doc_397823702001_item	3536184	et	3	main
te	doc_397823702002_item	3536207	et	4	main
venemaale	doc_397823702002_item	3536210	et	4	main
kiri	doc_397823702002_item	3536213	et	3	main
te	doc_397823702002_item	3536221	et	4	main
millega	doc_397823702002_item	3536224	et	3	main
kus	doc_397823702002_item	3536226	et	3	main
kohtades	doc_397823702002_item	3536233	et	3	main
seekord	doc_397823702002_item	3536314	et	3	main
sulle	doc_397823702002_item	3536317	et	3	main
minu	doc_397823702000_item	3536057	et	3	main
on	doc_397823702000_item	3536060	et	4	main
eramaja	doc_397823702000_item	3536061	et	4	main
ja	doc_397823702000_item	3536066	et	3	main
tütrega	doc_397823702000_item	3536067	et	3	main
kui	doc_397823702000_item	3536068	et	3	main
ma	doc_397823702000_item	3536069	et	3	main
sõidan	doc_397823702000_item	3536070	et	3	main
tagasi	doc_397823702000_item	3536071	et	3	main
kutsun	doc_397823702000_item	3536072	et	3	main
sulle	doc_397823702000_item	3536073	et	3	main
külla	doc_397823702000_item	3536074	et	4	main
see	doc_397823702000_item	3536075	et	3	main
kord	doc_397823702000_item	3536076	et	4	main
lõpetan	doc_397823702000_item	3536077	et	3	main
kohtla	doc_397823702000_item	3536078	et	4	main
järvel	doc_397823702000_item	3536079	et	4	main
14062005	doc_397823702000_item	3536080	et	2	main
sinu	doc_397823702000_item	3536081	et	3	main
sõbranna	doc_397823702000_item	3536082	et	4	main
eesnimi	doc_397823702000_item	3536083	et	3	main
eestlasest	doc_397823702001_item	3536094	et	3	main
kirjutage	doc_397823702001_item	3536096	et	3	main
millistes	doc_397823702001_item	3536111	et	3	main
peatute	doc_397823702001_item	3536113	et	4	main
nõutav	doc_397823702001_item	3536115	et	4	main
pikkus	doc_397823702001_item	3536116	et	4	main
sulle	doc_397823702001_item	3536133	et	3	main
kirjutada	doc_397823702001_item	3536144	et	3	main
bussireisi	doc_397823702001_item	3536153	et	4	main
ma	doc_397823702001_item	3536155	et	3	main
koos	doc_397823702000_item	3536064	et	4	main
abikaasaga	doc_397823702000_item	3536065	et	3	main
kiri	doc_397823702001_item	3536085	et	3	main
näha	doc_397823702001_item	3536164	et	3	main
nad	doc_397823702001_item	3536165	et	3	main
elavad	doc_397823702001_item	3536166	et	4	main
peterburis	doc_397823702001_item	3536167	et	4	main
tahan	doc_397823702001_item	3536168	et	3	main
kohtuda	doc_397823702001_item	3536169	et	3	main
oma	doc_397823702001_item	3536170	et	4	main
sugulastega	doc_397823702001_item	3536171	et	4	main
ja	doc_397823702001_item	3536172	et	3	main
näha	doc_397823702001_item	3536173	et	3	main
linna	doc_397823702001_item	3536174	et	4	main
seal	doc_397823702001_item	3536175	et	4	main
on	doc_397823702001_item	3536176	et	4	main
palju	doc_397823702001_item	3536177	et	4	main
huvitavad	doc_397823702001_item	3536178	et	4	main
tahaksin	doc_397823702001_item	3536179	et	3	main
käia	doc_397823702001_item	3536180	et	4	main
mõnelin	doc_397823702001_item	3536181	et	4	main
näitusel	doc_397823702001_item	3536182	et	4	main
reisi	doc_397823702001_item	3536088	et	4	main
venemaale	doc_397823702001_item	3536089	et	4	main
oma	doc_397823702001_item	3536093	et	4	main
maksab	doc_397823702001_item	3536110	et	3	main
kirja	doc_397823702001_item	3536114	et	4	main
kallis	doc_397823702001_item	3536121	et	4	main
täna	doc_397823702001_item	3536125	et	4	main
kirja	doc_397823702001_item	3536127	et	4	main
suur	doc_397823702001_item	3536128	et	3	main
aitäh	doc_397823702001_item	3536129	et	3	main
kirja	doc_397823702001_item	3536130	et	4	main
kohe	doc_397823702001_item	3536134	et	4	main
sest	doc_397823702001_item	3536136	et	4	main
mul	doc_397823702001_item	3536137	et	3	main
on	doc_397823702001_item	3536138	et	4	main
üks	doc_397823702001_item	3536139	et	3	main
uudis	doc_397823702001_item	3536140	et	3	main
ja	doc_397823702001_item	3536141	et	3	main
sellest	doc_397823702001_item	3536143	et	4	main
puhkus	doc_397823702001_item	3536146	et	3	main
juulil	doc_397823702001_item	3536149	et	3	main
venemaale	doc_397823702001_item	3536154	et	4	main
pole	doc_397823702001_item	3536156	et	3	main
juba	doc_397823702001_item	3536157	et	3	main
muuseumis	doc_397823702001_item	3536185	et	3	main
olen	doc_397823702001_item	3536186	et	3	main
peterburis	doc_397823702001_item	3536187	et	4	main
viis	doc_397823702001_item	3536188	et	4	main
päeva	doc_397823702001_item	3536189	et	4	main
ööbin	doc_397823702001_item	3536190	et	3	main
sugulaste	doc_397823702001_item	3536191	et	4	main
juures	doc_397823702001_item	3536192	et	4	main
seekord	doc_397823702001_item	3536193	et	3	main
lõpetan	doc_397823702001_item	3536194	et	3	main
soovin	doc_397823702001_item	3536195	et	3	main
sulle	doc_397823702001_item	3536196	et	3	main
ilusad	doc_397823702001_item	3536197	et	3	main
suvepukust	doc_397823702001_item	3536198	et	4	main
ja	doc_397823702001_item	3536199	et	3	main
ootan	doc_397823702001_item	3536200	et	3	main
sind	doc_397823702001_item	3536201	et	4	main
külla	doc_397823702001_item	3536202	et	4	main
sügisel	doc_397823702001_item	3536203	et	3	main
eesnimi	doc_397823702001_item	3536204	et	3	main
plaanite	doc_397823702002_item	3536208	et	3	main
eestlasest	doc_397823702002_item	3536215	et	3	main
kirjutage	doc_397823702002_item	3536217	et	3	main
ja	doc_397823702002_item	3536219	et	3	main
soovite	doc_397823702002_item	3536223	et	3	main
ööbite	doc_397823702002_item	3536227	et	3	main
kirja	doc_397823702002_item	3536235	et	4	main
algab	doc_397823702002_item	3536268	et	3	main
juulil	doc_397823702002_item	3536270	et	3	main
ja	doc_397823702002_item	3536271	et	3	main
ma	doc_397823702002_item	3536272	et	3	main
neid	doc_397823702002_item	3536284	et	4	main
ööpin	doc_397823702002_item	3536311	et	4	main
lõpetan	doc_397823702002_item	3536315	et	3	main
ilusad	doc_397823702002_item	3536318	et	3	main
sind	doc_397823702002_item	3536322	et	4	main
plaanite	doc_397823702003_item	3536329	et	3	main
sõbrale	doc_397823702003_item	3536337	et	3	main
näha	doc_397823702002_item	3536285	et	3	main
nad	doc_397823702002_item	3536286	et	3	main
elavad	doc_397823702002_item	3536287	et	4	main
peterburis	doc_397823702002_item	3536288	et	4	main
tahan	doc_397823702002_item	3536289	et	3	main
kohtuda	doc_397823702002_item	3536290	et	3	main
oma	doc_397823702002_item	3536291	et	4	main
sugulastega	doc_397823702002_item	3536292	et	4	main
ja	doc_397823702002_item	3536293	et	3	main
näha	doc_397823702002_item	3536294	et	3	main
linna	doc_397823702002_item	3536295	et	4	main
seal	doc_397823702002_item	3536296	et	4	main
on	doc_397823702002_item	3536297	et	4	main
palju	doc_397823702002_item	3536298	et	4	main
huvitavat	doc_397823702002_item	3536299	et	4	main
tahaksin	doc_397823702002_item	3536300	et	3	main
käja	doc_397823702002_item	3536301	et	4	main
mõnelin	doc_397823702002_item	3536302	et	4	main
näitusel	doc_397823702002_item	3536303	et	4	main
reisi	doc_397823702002_item	3536209	et	4	main
sõbrale	doc_397823702002_item	3536216	et	3	main
millal	doc_397823702002_item	3536218	et	3	main
kuhu	doc_397823702002_item	3536220	et	3	main
sõita	doc_397823702002_item	3536222	et	3	main
reisite	doc_397823702002_item	3536225	et	3	main
kui	doc_397823702002_item	3536228	et	3	main
80	doc_397823702002_item	3536239	et	2	main
sõna	doc_397823702002_item	3536240	et	4	main
tere	doc_397823702002_item	3536241	et	3	main
kallis	doc_397823702002_item	3536242	et	4	main
sõber	doc_397823702002_item	3536243	et	3	main
oleg	doc_397823702002_item	3536244	et	4	main
sain	doc_397823702002_item	3536245	et	3	main
täna	doc_397823702002_item	3536246	et	4	main
sinu	doc_397823702002_item	3536247	et	3	main
kirja	doc_397823702002_item	3536248	et	4	main
suur	doc_397823702002_item	3536249	et	3	main
aitäh	doc_397823702002_item	3536250	et	3	main
kirja	doc_397823702002_item	3536251	et	4	main
eest	doc_397823702002_item	3536252	et	4	main
tahan	doc_397823702002_item	3536253	et	3	main
sulle	doc_397823702002_item	3536254	et	3	main
kohe	doc_397823702002_item	3536255	et	4	main
vastata	doc_397823702002_item	3536256	et	4	main
sest	doc_397823702002_item	3536257	et	4	main
mul	doc_397823702002_item	3536258	et	3	main
on	doc_397823702002_item	3536259	et	4	main
üks	doc_397823702002_item	3536260	et	3	main
uudis	doc_397823702002_item	3536261	et	3	main
ja	doc_397823702002_item	3536262	et	3	main
tahan	doc_397823702002_item	3536263	et	3	main
sellest	doc_397823702002_item	3536264	et	4	main
kirjutada	doc_397823702002_item	3536265	et	3	main
minu	doc_397823702002_item	3536266	et	3	main
puhkus	doc_397823702002_item	3536267	et	3	main
15	doc_397823702002_item	3536269	et	2	main
aastat	doc_397823702002_item	3536280	et	3	main
soovin	doc_397823702002_item	3536316	et	3	main
ja	doc_397823702002_item	3536320	et	3	main
külla	doc_397823702002_item	3536323	et	4	main
sügisel	doc_397823702002_item	3536324	et	3	main
eesnimi	doc_397823702002_item	3536325	et	3	main
kiri	doc_397823702003_item	3536327	et	3	main
kirjutage	doc_397823702003_item	3536332	et	3	main
kiri	doc_397823702003_item	3536334	et	3	main
eestlasest	doc_397823702003_item	3536336	et	3	main
millal	doc_397823702003_item	3536339	et	3	main
te	doc_397823702003_item	3536342	et	4	main
sõita	doc_397823702003_item	3536343	et	3	main
soovite	doc_397823702003_item	3536344	et	3	main
palju	doc_397823702003_item	3536350	et	4	main
maksab	doc_397823702003_item	3536352	et	3	main
umbes	doc_397823702003_item	3536359	et	4	main
tänan	doc_397823702003_item	3536367	et	3	main
kirja	doc_397823702003_item	3536369	et	4	main
eest	doc_397823702003_item	3536373	et	4	main
muuseumis	doc_397823702003_item	3536427	et	3	main
te	doc_397823702004_item	3536450	et	4	main
oma	doc_397823702004_item	3536457	et	4	main
eestlasest	doc_397823702004_item	3536458	et	3	main
millal	doc_397823702004_item	3536461	et	3	main
te	doc_397823702004_item	3536464	et	4	main
kus	doc_397823702004_item	3536469	et	3	main
nõutav	doc_397823702004_item	3536479	et	4	main
80	doc_397823702004_item	3536482	et	2	main
kirja	doc_397823702004_item	3536490	et	4	main
sest	doc_397823702004_item	3536499	et	4	main
mull	doc_397823702004_item	3536500	et	3	main
algab	doc_397823702004_item	3536510	et	3	main
muuseumis	doc_397823702004_item	3536548	et	3	main
olen	doc_397823702004_item	3536549	et	3	main
peterburis	doc_397823702004_item	3536550	et	4	main
viis	doc_397823702004_item	3536551	et	4	main
päeva	doc_397823702004_item	3536552	et	4	main
ööbin	doc_397823702004_item	3536553	et	3	main
sugulaste	doc_397823702004_item	3536554	et	4	main
juures	doc_397823702004_item	3536555	et	4	main
see	doc_397823702004_item	3536556	et	3	main
kord	doc_397823702004_item	3536557	et	4	main
lõpetan	doc_397823702004_item	3536558	et	3	main
soovin	doc_397823702004_item	3536559	et	3	main
ilusad	doc_397823702004_item	3536561	et	3	main
sulle	doc_397823702004_item	3536560	et	3	main
suvepuhkust	doc_397823702004_item	3536562	et	4	main
ja	doc_397823702004_item	3536563	et	3	main
ootan	doc_397823702004_item	3536564	et	3	main
sind	doc_397823702004_item	3536565	et	4	main
külla	doc_397823702004_item	3536566	et	4	main
sügisel	doc_397823702004_item	3536567	et	3	main
eesnimi	doc_397823702004_item	3536568	et	3	main
päeva	doc_397823702002_item	3536310	et	4	main
juures	doc_397823702002_item	3536313	et	4	main
reisi	doc_397823702003_item	3536330	et	4	main
kui	doc_397823702003_item	3536349	et	3	main
kohtades	doc_397823702003_item	3536354	et	3	main
kirja	doc_397823702003_item	3536356	et	4	main
nõutav	doc_397823702003_item	3536357	et	4	main
sõna	doc_397823702003_item	3536361	et	4	main
sinu	doc_397823702003_item	3536368	et	3	main
5	doc_397823702003_item	3536430	et	2	main
päeva	doc_397823702003_item	3536431	et	4	main
ööbin	doc_397823702003_item	3536432	et	3	main
sugulaste	doc_397823702003_item	3536433	et	4	main
juures	doc_397823702003_item	3536434	et	4	main
seekord	doc_397823702003_item	3536435	et	3	main
lõpetan	doc_397823702003_item	3536436	et	3	main
soovin	doc_397823702003_item	3536437	et	3	main
sulle	doc_397823702003_item	3536438	et	3	main
ilusat	doc_397823702003_item	3536439	et	3	main
suvepuhkust	doc_397823702003_item	3536440	et	4	main
ja	doc_397823702003_item	3536441	et	3	main
ootan	doc_397823702003_item	3536442	et	3	main
sind	doc_397823702003_item	3536443	et	4	main
külla	doc_397823702003_item	3536444	et	4	main
sügisel	doc_397823702003_item	3536445	et	3	main
eesnimi	doc_397823702003_item	3536446	et	3	main
10062005	doc_397823702003_item	3536447	et	2	main
reisi	doc_397823702004_item	3536452	et	4	main
reisite	doc_397823702004_item	3536468	et	3	main
see	doc_397823702004_item	3536473	et	3	main
millistes	doc_397823702004_item	3536475	et	3	main
peatute	doc_397823702004_item	3536477	et	4	main
kohe	doc_397823702004_item	3536497	et	4	main
ja	doc_397823702004_item	3536504	et	3	main
kirjutada	doc_397823702004_item	3536507	et	3	main
juulil	doc_397823702004_item	3536512	et	3	main
ma	doc_397823702004_item	3536514	et	3	main
bussireisi	doc_397823702004_item	3536516	et	4	main
pole	doc_397823702004_item	3536519	et	3	main
reisi	doc_397823702005_item	3536573	et	4	main
sellest	doc_397823702005_item	3536576	et	4	main
nõutav	doc_397823702005_item	3536600	et	4	main
kirja	doc_397823702005_item	3536615	et	4	main
eest	doc_397823702005_item	3536616	et	4	main
sest	doc_397823702005_item	3536621	et	4	main
üks	doc_397823702005_item	3536624	et	3	main
kirjutada	doc_397823702005_item	3536629	et	3	main
puhkus	doc_397823702005_item	3536631	et	3	main
plaanin	doc_397823702005_item	3536637	et	3	main
venemaale	doc_397823702005_item	3536639	et	4	main
ma	doc_397823702005_item	3536640	et	3	main
poole	doc_397823702005_item	3536641	et	4	main
juba	doc_397823702005_item	3536642	et	3	main
muuseumis	doc_397823702005_item	3536671	et	3	main
elavad	doc_397823702003_item	3536408	et	4	main
peterburis	doc_397823702003_item	3536409	et	4	main
tahan	doc_397823702003_item	3536410	et	3	main
kohtuda	doc_397823702003_item	3536411	et	3	main
oma	doc_397823702003_item	3536412	et	4	main
sugulastega	doc_397823702003_item	3536413	et	4	main
ja	doc_397823702003_item	3536414	et	3	main
näha	doc_397823702003_item	3536415	et	3	main
linna	doc_397823702003_item	3536416	et	4	main
seal	doc_397823702003_item	3536417	et	4	main
on	doc_397823702003_item	3536418	et	4	main
palju	doc_397823702003_item	3536419	et	4	main
huvitavad	doc_397823702003_item	3536420	et	4	main
tahaksin	doc_397823702003_item	3536421	et	3	main
käia	doc_397823702003_item	3536422	et	4	main
mõnelik	doc_397823702003_item	3536423	et	4	main
näitusel	doc_397823702003_item	3536424	et	4	main
ja	doc_397823702003_item	3536425	et	3	main
mõnes	doc_397823702003_item	3536426	et	3	main
te	doc_397823702003_item	3536328	et	4	main
pikkus	doc_397823702003_item	3536358	et	4	main
tere	doc_397823702003_item	3536362	et	3	main
sõbranna	doc_397823702003_item	3536364	et	4	main
kirja	doc_397823702003_item	3536372	et	4	main
sulle	doc_397823702003_item	3536375	et	3	main
kohe	doc_397823702003_item	3536376	et	4	main
vastata	doc_397823702003_item	3536377	et	4	main
sest	doc_397823702003_item	3536378	et	4	main
mul	doc_397823702003_item	3536379	et	3	main
on	doc_397823702003_item	3536380	et	4	main
üks	doc_397823702003_item	3536381	et	3	main
uudis	doc_397823702003_item	3536382	et	3	main
ja	doc_397823702003_item	3536383	et	3	main
tahan	doc_397823702003_item	3536384	et	3	main
sellest	doc_397823702003_item	3536385	et	4	main
kirjutada	doc_397823702003_item	3536386	et	3	main
minu	doc_397823702003_item	3536387	et	3	main
puhkus	doc_397823702003_item	3536388	et	3	main
algab	doc_397823702003_item	3536389	et	3	main
15	doc_397823702003_item	3536390	et	2	main
juulil	doc_397823702003_item	3536391	et	3	main
ja	doc_397823702003_item	3536392	et	3	main
ma	doc_397823702003_item	3536393	et	3	main
plaanin	doc_397823702003_item	3536394	et	3	main
bussireisi	doc_397823702003_item	3536395	et	4	main
venemaale	doc_397823702003_item	3536396	et	4	main
ma	doc_397823702003_item	3536397	et	3	main
pole	doc_397823702003_item	3536398	et	3	main
juba	doc_397823702003_item	3536399	et	3	main
mittu	doc_397823702003_item	3536400	et	4	main
aastat	doc_397823702003_item	3536401	et	3	main
sugulasi	doc_397823702003_item	3536402	et	3	main
külastanud	doc_397823702003_item	3536403	et	4	main
tahan	doc_397823702003_item	3536404	et	3	main
neid	doc_397823702003_item	3536405	et	4	main
näha	doc_397823702003_item	3536406	et	3	main
nad	doc_397823702003_item	3536407	et	3	main
olen	doc_397823702003_item	3536428	et	3	main
kiri	doc_397823702004_item	3536449	et	3	main
kirjutage	doc_397823702004_item	3536460	et	3	main
kuhu	doc_397823702004_item	3536463	et	3	main
sõita	doc_397823702004_item	3536465	et	3	main
pikkus	doc_397823702004_item	3536480	et	4	main
suur	doc_397823702004_item	3536491	et	3	main
aitäh	doc_397823702004_item	3536492	et	3	main
kirja	doc_397823702004_item	3536493	et	4	main
on	doc_397823702004_item	3536501	et	4	main
üks	doc_397823702004_item	3536502	et	3	main
ja	doc_397823702003_item	3536340	et	3	main
see	doc_397823702003_item	3536351	et	3	main
millistes	doc_397823702003_item	3536353	et	3	main
kallis	doc_397823702003_item	3536363	et	4	main
sain	doc_397823702003_item	3536366	et	3	main
suur	doc_397823702003_item	3536370	et	3	main
tahan	doc_397823702003_item	3536374	et	3	main
peterburis	doc_397823702003_item	3536429	et	4	main
nad	doc_397823702004_item	3536528	et	3	main
elevad	doc_397823702004_item	3536529	et	3	main
peterburis	doc_397823702004_item	3536530	et	4	main
tahan	doc_397823702004_item	3536531	et	3	main
kohtuda	doc_397823702004_item	3536532	et	3	main
oma	doc_397823702004_item	3536533	et	4	main
sugulastega	doc_397823702004_item	3536534	et	4	main
ja	doc_397823702004_item	3536535	et	3	main
näha	doc_397823702004_item	3536536	et	3	main
linna	doc_397823702004_item	3536537	et	4	main
seal	doc_397823702004_item	3536538	et	4	main
on	doc_397823702004_item	3536539	et	4	main
palju	doc_397823702004_item	3536540	et	4	main
huvitavad	doc_397823702004_item	3536541	et	4	main
tahaksin	doc_397823702004_item	3536542	et	3	main
käia	doc_397823702004_item	3536543	et	4	main
mõnel	doc_397823702004_item	3536544	et	3	main
näitusel	doc_397823702004_item	3536545	et	4	main
ja	doc_397823702004_item	3536546	et	3	main
mõnes	doc_397823702004_item	3536547	et	3	main
plaanite	doc_397823702004_item	3536451	et	3	main
venemaale	doc_397823702004_item	3536453	et	4	main
sellest	doc_397823702004_item	3536455	et	4	main
soovite	doc_397823702004_item	3536466	et	3	main
ööbite	doc_397823702004_item	3536470	et	3	main
palju	doc_397823702004_item	3536472	et	4	main
maksab	doc_397823702004_item	3536474	et	3	main
kohtades	doc_397823702004_item	3536476	et	3	main
kirja	doc_397823702004_item	3536478	et	4	main
umbes	doc_397823702004_item	3536481	et	4	main
sõna	doc_397823702004_item	3536483	et	4	main
tere	doc_397823702004_item	3536484	et	3	main
kallis	doc_397823702004_item	3536485	et	4	main
sõber	doc_397823702004_item	3536486	et	3	main
sain	doc_397823702004_item	3536487	et	3	main
eest	doc_397823702004_item	3536494	et	4	main
tahan	doc_397823702004_item	3536495	et	3	main
sulle	doc_397823702004_item	3536496	et	3	main
uudis	doc_397823702004_item	3536503	et	3	main
puhkus	doc_397823702004_item	3536509	et	3	main
venemaale	doc_397823702004_item	3536517	et	4	main
ma	doc_397823702004_item	3536518	et	3	main
sugulasi	doc_397823702004_item	3536523	et	3	main
külastanud	doc_397823702004_item	3536524	et	4	main
tahan	doc_397823702004_item	3536525	et	3	main
neid	doc_397823702004_item	3536526	et	4	main
näha	doc_397823702004_item	3536527	et	3	main
kiri	doc_397823702005_item	3536570	et	3	main
kirjutage	doc_397823702005_item	3536575	et	3	main
kirja	doc_397823702005_item	3536599	et	4	main
kallis	doc_397823702005_item	3536606	et	4	main
tiiju	doc_397823702005_item	3536608	et	4	main
sain	doc_397823702005_item	3536609	et	3	main
tänan	doc_397823702005_item	3536610	et	3	main
sinu	doc_397823702005_item	3536611	et	3	main
kirja	doc_397823702005_item	3536612	et	4	main
suur	doc_397823702005_item	3536613	et	3	main
aitäh	doc_397823702005_item	3536614	et	3	main
vastata	doc_397823702005_item	3536620	et	4	main
on	doc_397823702005_item	3536623	et	4	main
neid	doc_397823702005_item	3536649	et	4	main
näha	doc_397823702005_item	3536650	et	3	main
kirjutage	doc_397823702006_item	3536699	et	3	main
eestlasest	doc_397823702006_item	3536703	et	3	main
reisite	doc_397823702006_item	3536713	et	3	main
kus	doc_397823702006_item	3536714	et	3	main
ööbite	doc_397823702006_item	3536715	et	3	main
kui	doc_397823702006_item	3536716	et	3	main
palju	doc_397823702006_item	3536717	et	4	main
umbes	doc_397823702006_item	3536726	et	4	main
venemaale	doc_397823702006_item	3536735	et	4	main
puhkus	doc_397823702006_item	3536738	et	3	main
ööreisiga	doc_397823702006_item	3536742	et	3	main
tahan	doc_397823702006_item	3536748	et	3	main
ermitaži	doc_397823702006_item	3536750	et	2	main
tahan	doc_397823702006_item	3536756	et	3	main
ajalooline	doc_397823702006_item	3536758	et	4	main
ma	doc_397823702006_item	3536760	et	3	main
elamine	doc_397823702006_item	3536772	et	4	main
oma	doc_397823702006_item	3536773	et	4	main
näinud	doc_397823702006_item	3536790	et	4	main
10	doc_397823702006_item	3536792	et	2	main
aastat	doc_397823702006_item	3536793	et	3	main
reisi	doc_397823702007_item	3536828	et	4	main
kuhu	doc_397823702007_item	3536839	et	3	main
millega	doc_397823702007_item	3536843	et	3	main
ööbite	doc_397823702007_item	3536846	et	3	main
kirja	doc_397823702007_item	3536854	et	4	main
nõutav	doc_397823702007_item	3536855	et	4	main
80	doc_397823702007_item	3536858	et	2	main
tere	doc_397823702007_item	3536860	et	3	main
kallis	doc_397823702007_item	3536861	et	4	main
eest	doc_397823702007_item	3536866	et	4	main
sa	doc_397823702007_item	3536867	et	3	main
pole	doc_397823702007_item	3536868	et	3	main
mulle	doc_397823702007_item	3536869	et	4	main
on	doc_397823702007_item	3536882	et	4	main
selest	doc_397823702004_item	3536506	et	4	main
juba	doc_397823702004_item	3536520	et	3	main
plaanite	doc_397823702005_item	3536572	et	3	main
sõita	doc_397823702005_item	3536586	et	3	main
soovite	doc_397823702005_item	3536587	et	3	main
millega	doc_397823702005_item	3536588	et	3	main
reisite	doc_397823702005_item	3536589	et	3	main
kus	doc_397823702005_item	3536590	et	3	main
ööbite	doc_397823702005_item	3536591	et	3	main
kui	doc_397823702005_item	3536592	et	3	main
palju	doc_397823702005_item	3536593	et	4	main
see	doc_397823702005_item	3536594	et	3	main
maksab	doc_397823702005_item	3536595	et	3	main
millistes	doc_397823702005_item	3536596	et	3	main
kohtades	doc_397823702005_item	3536597	et	3	main
umbes	doc_397823702005_item	3536602	et	4	main
tere	doc_397823702005_item	3536605	et	3	main
lapsepõlvessõbranna	doc_397823702005_item	3536607	et	4	main
mul	doc_397823702005_item	3536622	et	3	main
uudis	doc_397823702005_item	3536625	et	3	main
sellest	doc_397823702005_item	3536628	et	4	main
algab	doc_397823702005_item	3536632	et	3	main
ma	doc_397823702005_item	3536636	et	3	main
bussireisi	doc_397823702005_item	3536638	et	4	main
sugulasi	doc_397823702005_item	3536645	et	3	main
sellest	doc_397823702006_item	3536700	et	4	main
peatute	doc_397823702006_item	3536722	et	4	main
nõutav	doc_397823702006_item	3536724	et	4	main
pikkus	doc_397823702006_item	3536725	et	4	main
linda	doc_397823702006_item	3536730	et	4	main
augustis	doc_397823702006_item	3536731	et	3	main
ma	doc_397823702006_item	3536732	et	3	main
tahan	doc_397823702006_item	3536733	et	3	main
sõita	doc_397823702006_item	3536734	et	3	main
on	doc_397823702006_item	3536737	et	4	main
ma	doc_397823702006_item	3536747	et	3	main
juurde	doc_397823702006_item	3536753	et	4	main
ja	doc_397823702006_item	3536754	et	3	main
rahakotti	doc_397823702006_item	3536774	et	4	main
kirjutage	doc_397823702007_item	3536830	et	3	main
oma	doc_397823702007_item	3536833	et	4	main
kirjutage	doc_397823702007_item	3536836	et	3	main
ammu	doc_397823702007_item	3536870	et	4	main
kirjutanud	doc_397823702007_item	3536871	et	4	main
ja	doc_397823702007_item	3536872	et	3	main
ma	doc_397823702007_item	3536873	et	3	main
korras	doc_397823702007_item	3536884	et	4	main
oli	doc_397823702007_item	3536896	et	3	main
260	doc_397823702007_item	3536917	et	2	main
ma	doc_397823702007_item	3536919	et	3	main
nagämiseni	doc_397823702007_item	3536950	et	4	main
te	doc_397823702008_item	3536958	et	4	main
kirjutage	doc_397823702008_item	3536962	et	3	main
millistes	doc_397823702008_item	3536983	et	3	main
plaanerinme	doc_397823702008_item	3537001	et	4	main
venemale	doc_397823702008_item	3537003	et	4	main
sankt	doc_397823702008_item	3537004	et	4	main
vanalinn	doc_397823702008_item	3537010	et	3	main
sadamalinn	doc_397823702008_item	3537011	et	3	main
on	doc_397823702008_item	3537050	et	4	main
sa	doc_397823702008_item	3537068	et	3	main
kõike	doc_397823702008_item	3537080	et	4	main
head	doc_397823702008_item	3537081	et	4	main
venemaale	doc_397823702009_item	3537096	et	4	main
sõbrale	doc_397823702009_item	3537102	et	3	main
sõita	doc_397823702009_item	3537108	et	3	main
millistes	doc_397823702009_item	3537118	et	3	main
peatute	doc_397823702009_item	3537120	et	4	main
tere	doc_397823702009_item	3537127	et	3	main
sõber	doc_397823702009_item	3537130	et	3	main
mind	doc_397823702009_item	3537132	et	4	main
kas	doc_397823702009_item	3537133	et	3	main
kiire	doc_397823702009_item	3537134	et	4	main
pere	doc_397823702009_item	3537142	et	4	main
plaanite	doc_397823702010_item	3537215	et	3	main
kallis	doc_397823702010_item	3537248	et	4	main
vabandage	doc_397823702010_item	3537250	et	3	main
et	doc_397823702010_item	3537251	et	3	main
ma	doc_397823702010_item	3537252	et	3	main
viis	doc_397823702010_item	3537259	et	4	main
peterburis	doc_397823702010_item	3537261	et	4	main
teen	doc_397823702010_item	3537273	et	3	main
nad	doc_397823702005_item	3536651	et	3	main
elavad	doc_397823702005_item	3536652	et	4	main
peterburis	doc_397823702005_item	3536653	et	4	main
tahan	doc_397823702005_item	3536654	et	3	main
kohtuda	doc_397823702005_item	3536655	et	3	main
oma	doc_397823702005_item	3536656	et	4	main
sugulastega	doc_397823702005_item	3536657	et	4	main
ja	doc_397823702005_item	3536658	et	3	main
näha	doc_397823702005_item	3536659	et	3	main
linna	doc_397823702005_item	3536660	et	4	main
seal	doc_397823702005_item	3536661	et	4	main
on	doc_397823702005_item	3536662	et	4	main
palju	doc_397823702005_item	3536663	et	4	main
huvitavad	doc_397823702005_item	3536664	et	4	main
tahaksin	doc_397823702005_item	3536665	et	3	main
käija	doc_397823702005_item	3536666	et	4	main
mõnel	doc_397823702005_item	3536667	et	3	main
näitusel	doc_397823702005_item	3536668	et	4	main
ja	doc_397823702005_item	3536669	et	3	main
venemaale	doc_397823702005_item	3536574	et	4	main
oma	doc_397823702005_item	3536578	et	4	main
eestlasest	doc_397823702005_item	3536579	et	3	main
sõbrale	doc_397823702005_item	3536580	et	3	main
kirjutage	doc_397823702005_item	3536581	et	3	main
millal	doc_397823702005_item	3536582	et	3	main
ja	doc_397823702005_item	3536583	et	3	main
kuhu	doc_397823702005_item	3536584	et	3	main
te	doc_397823702005_item	3536585	et	4	main
peatute	doc_397823702005_item	3536598	et	4	main
pikkus	doc_397823702005_item	3536601	et	4	main
tahan	doc_397823702005_item	3536617	et	3	main
sulle	doc_397823702005_item	3536618	et	3	main
kohe	doc_397823702005_item	3536619	et	4	main
tahan	doc_397823702005_item	3536627	et	3	main
minu	doc_397823702005_item	3536630	et	3	main
15	doc_397823702005_item	3536633	et	2	main
ja	doc_397823702005_item	3536635	et	3	main
aastat	doc_397823702005_item	3536644	et	3	main
tahan	doc_397823702005_item	3536648	et	3	main
olen	doc_397823702005_item	3536672	et	3	main
peterburis	doc_397823702005_item	3536673	et	4	main
viis	doc_397823702005_item	3536674	et	4	main
päeva	doc_397823702005_item	3536675	et	4	main
ööpin	doc_397823702005_item	3536676	et	4	main
sugulaste	doc_397823702005_item	3536677	et	4	main
juures	doc_397823702005_item	3536678	et	4	main
see	doc_397823702005_item	3536679	et	3	main
kord	doc_397823702005_item	3536680	et	4	main
lõpetan	doc_397823702005_item	3536681	et	3	main
soovin	doc_397823702005_item	3536682	et	3	main
sulle	doc_397823702005_item	3536683	et	3	main
ilusad	doc_397823702005_item	3536684	et	3	main
suvepuhkust	doc_397823702005_item	3536685	et	4	main
ja	doc_397823702005_item	3536686	et	3	main
ootan	doc_397823702005_item	3536687	et	3	main
sind	doc_397823702005_item	3536688	et	4	main
külla	doc_397823702005_item	3536689	et	4	main
sügisel	doc_397823702005_item	3536690	et	3	main
eesnimi	doc_397823702005_item	3536691	et	3	main
10062005	doc_397823702005_item	3536692	et	2	main
kiri	doc_397823702006_item	3536694	et	3	main
plaanite	doc_397823702006_item	3536696	et	3	main
oma	doc_397823702006_item	3536702	et	4	main
kohtades	doc_397823702006_item	3536721	et	3	main
peterburisse	doc_397823702006_item	3536740	et	4	main
seal	doc_397823702006_item	3536743	et	4	main
ma	doc_397823702006_item	3536744	et	3	main
ööbin	doc_397823702006_item	3536745	et	3	main
hotellis	doc_397823702006_item	3536746	et	3	main
minna	doc_397823702006_item	3536749	et	3	main
sõita	doc_397823702006_item	3536751	et	3	main
maksab	doc_397823702006_item	3536767	et	3	main
krooni	doc_397823702006_item	3536769	et	4	main
söömine	doc_397823702006_item	3536770	et	4	main
ja	doc_397823702006_item	3536771	et	3	main
pole	doc_397823702006_item	3536789	et	3	main
kiri	doc_397823702007_item	3536825	et	3	main
kiri	doc_397823702007_item	3536832	et	3	main
peatute	doc_397823702007_item	3536853	et	4	main
mari	doc_397823702007_item	3536862	et	4	main
aite	doc_397823702007_item	3536863	et	3	main
sulle	doc_397823702007_item	3536864	et	3	main
kirja	doc_397823702007_item	3536865	et	4	main
pärast	doc_397823702007_item	3536876	et	4	main
väga	doc_397823702007_item	3536878	et	3	main
et	doc_397823702007_item	3536880	et	3	main
kõik	doc_397823702007_item	3536883	et	4	main
8	doc_397823702007_item	3536913	et	2	main
ekskursion	doc_397823702007_item	3536946	et	4	main
võib	doc_397823702006_item	3536775	et	3	main
olla	doc_397823702006_item	3536776	et	3	main
sa	doc_397823702006_item	3536777	et	3	main
tahad	doc_397823702006_item	3536778	et	3	main
minuga	doc_397823702006_item	3536779	et	3	main
sõita	doc_397823702006_item	3536780	et	3	main
kirjuta	doc_397823702006_item	3536781	et	4	main
mulle	doc_397823702006_item	3536782	et	4	main
vastust	doc_397823702006_item	3536783	et	4	main
peterburis	doc_397823702006_item	3536784	et	4	main
elab	doc_397823702006_item	3536785	et	3	main
minu	doc_397823702006_item	3536786	et	3	main
koolisõbrana	doc_397823702006_item	3536787	et	3	main
mina	doc_397823702006_item	3536788	et	4	main
reisi	doc_397823702006_item	3536697	et	4	main
venemaale	doc_397823702006_item	3536698	et	4	main
sõbrale	doc_397823702006_item	3536704	et	3	main
kirjutage	doc_397823702006_item	3536705	et	3	main
millal	doc_397823702006_item	3536706	et	3	main
ja	doc_397823702006_item	3536707	et	3	main
kuhu	doc_397823702006_item	3536708	et	3	main
te	doc_397823702006_item	3536709	et	4	main
sõita	doc_397823702006_item	3536710	et	3	main
soovite	doc_397823702006_item	3536711	et	3	main
millega	doc_397823702006_item	3536712	et	3	main
te	doc_397823702006_item	3536695	et	4	main
kiri	doc_397823702006_item	3536701	et	3	main
maksab	doc_397823702006_item	3536719	et	3	main
kirja	doc_397823702006_item	3536723	et	4	main
fantani	doc_397823702006_item	3536752	et	4	main
väga	doc_397823702006_item	3536755	et	3	main
külastada	doc_397823702006_item	3536757	et	3	main
museumi	doc_397823702006_item	3536759	et	4	main
reisimine	doc_397823702006_item	3536763	et	4	main
tuleb	doc_397823702006_item	3536764	et	3	main
põnevalt	doc_397823702006_item	3536765	et	4	main
reisipilet	doc_397823702006_item	3536766	et	3	main
500	doc_397823702006_item	3536768	et	2	main
teda	doc_397823702006_item	3536791	et	4	main
tahan	doc_397823702006_item	3536794	et	3	main
teda	doc_397823702006_item	3536795	et	4	main
näha	doc_397823702006_item	3536796	et	3	main
ta	doc_397823702006_item	3536797	et	4	main
töötab	doc_397823702006_item	3536798	et	3	main
puškini	doc_397823702006_item	3536799	et	2	main
teatris	doc_397823702006_item	3536800	et	3	main
ta	doc_397823702006_item	3536801	et	4	main
on	doc_397823702006_item	3536802	et	4	main
näitleija	doc_397823702006_item	3536803	et	4	main
mõtlen	doc_397823702006_item	3536804	et	3	main
et	doc_397823702006_item	3536805	et	3	main
saan	doc_397823702006_item	3536806	et	4	main
näha	doc_397823702006_item	3536807	et	3	main
uutmed	doc_397823702006_item	3536808	et	4	main
ettendusi	doc_397823702006_item	3536809	et	4	main
see	doc_397823702006_item	3536810	et	3	main
on	doc_397823702006_item	3536811	et	4	main
kõik	doc_397823702006_item	3536812	et	4	main
väga	doc_397823702006_item	3536813	et	3	main
igatsen	doc_397823702006_item	3536814	et	3	main
tahan	doc_397823702006_item	3536815	et	3	main
sind	doc_397823702006_item	3536816	et	4	main
näha	doc_397823702006_item	3536817	et	3	main
kirjuta	doc_397823702006_item	3536818	et	4	main
mulle	doc_397823702006_item	3536819	et	4	main
ja	doc_397823702006_item	3536820	et	3	main
helista	doc_397823702006_item	3536821	et	4	main
head	doc_397823702006_item	3536822	et	4	main
aega	doc_397823702006_item	3536823	et	4	main
te	doc_397823702007_item	3536826	et	4	main
plaanite	doc_397823702007_item	3536827	et	3	main
venemaale	doc_397823702007_item	3536829	et	4	main
eestlasest	doc_397823702007_item	3536834	et	3	main
millal	doc_397823702007_item	3536837	et	3	main
te	doc_397823702007_item	3536840	et	4	main
soovite	doc_397823702007_item	3536842	et	3	main
reisite	doc_397823702007_item	3536844	et	3	main
see	doc_397823702006_item	3536718	et	3	main
millistes	doc_397823702006_item	3536720	et	3	main
80	doc_397823702006_item	3536727	et	2	main
sõna	doc_397823702006_item	3536728	et	4	main
tere	doc_397823702006_item	3536729	et	3	main
mul	doc_397823702006_item	3536736	et	3	main
sõitan	doc_397823702006_item	3536739	et	4	main
bussiga	doc_397823702006_item	3536741	et	3	main
mõtlen	doc_397823702006_item	3536761	et	3	main
et	doc_397823702006_item	3536762	et	3	main
nad	doc_397823702007_item	3536904	et	3	main
elavad	doc_397823702007_item	3536905	et	4	main
novgorodi	doc_397823702007_item	3536906	et	4	main
linnas	doc_397823702007_item	3536907	et	4	main
ma	doc_397823702007_item	3536908	et	3	main
sõidsin	doc_397823702007_item	3536909	et	4	main
busiga	doc_397823702007_item	3536910	et	4	main
buss	doc_397823702007_item	3536911	et	3	main
sõidab	doc_397823702007_item	3536912	et	3	main
sellest	doc_397823702007_item	3536831	et	4	main
sõbrale	doc_397823702007_item	3536835	et	3	main
ja	doc_397823702007_item	3536838	et	3	main
sõita	doc_397823702007_item	3536841	et	3	main
kus	doc_397823702007_item	3536845	et	3	main
pikkus	doc_397823702007_item	3536856	et	4	main
hakkasin	doc_397823702007_item	3536874	et	3	main
hea	doc_397823702007_item	3536879	et	4	main
sunul	doc_397823702007_item	3536881	et	4	main
tee	doc_397823702007_item	3536885	et	4	main
küsin	doc_397823702007_item	3536886	et	3	main
millal	doc_397823702007_item	3536887	et	3	main
ja	doc_397823702007_item	3536888	et	3	main
kuhu	doc_397823702007_item	3536889	et	3	main
ma	doc_397823702007_item	3536890	et	3	main
soovin	doc_397823702007_item	3536891	et	3	main
sõita	doc_397823702007_item	3536892	et	3	main
puhkas	doc_397823702007_item	3536897	et	3	main
ma	doc_397823702007_item	3536898	et	3	main
plaanilist	doc_397823702007_item	3536899	et	4	main
reisi	doc_397823702007_item	3536900	et	4	main
venemaale	doc_397823702007_item	3536901	et	4	main
vanemate	doc_397823702007_item	3536902	et	4	main
jurde	doc_397823702007_item	3536903	et	4	main
sevel	doc_397823702007_item	3536924	et	4	main
novgorod	doc_397823702007_item	3536925	et	4	main
väga	doc_397823702007_item	3536926	et	3	main
ilus	doc_397823702007_item	3536927	et	4	main
linn	doc_397823702007_item	3536928	et	3	main
rohiliset	doc_397823702007_item	3536929	et	4	main
ja	doc_397823702007_item	3536930	et	3	main
puhkas	doc_397823702007_item	3536931	et	3	main
novgorodi	doc_397823702007_item	3536932	et	4	main
asub	doc_397823702007_item	3536933	et	3	main
palju	doc_397823702007_item	3536934	et	4	main
kirikud	doc_397823702007_item	3536935	et	3	main
sofia	doc_397823702007_item	3536936	et	4	main
petri	doc_397823702007_item	3536937	et	4	main
ja	doc_397823702007_item	3536938	et	3	main
paveli	doc_397823702007_item	3536939	et	4	main
ja	doc_397823702007_item	3536940	et	3	main
mud	doc_397823702007_item	3536941	et	4	main
vana	doc_397823702007_item	3536942	et	4	main
linnas	doc_397823702007_item	3536943	et	4	main
kui	doc_397823702007_item	3536847	et	3	main
palju	doc_397823702007_item	3536848	et	4	main
see	doc_397823702007_item	3536849	et	3	main
maksab	doc_397823702007_item	3536850	et	3	main
millistes	doc_397823702007_item	3536851	et	3	main
kohtades	doc_397823702007_item	3536852	et	3	main
umbes	doc_397823702007_item	3536857	et	4	main
sõna	doc_397823702007_item	3536859	et	4	main
sinu	doc_397823702007_item	3536875	et	3	main
muretsema	doc_397823702007_item	3536877	et	3	main
mil	doc_397823702007_item	3536894	et	4	main
tundi	doc_397823702007_item	3536914	et	4	main
maksab	doc_397823702007_item	3536916	et	3	main
eek	doc_397823702007_item	3536918	et	4	main
elada	doc_397823702007_item	3536921	et	3	main
vagä	doc_397823702007_item	3536944	et	4	main
kõige	doc_397823702007_item	3536951	et	4	main
venemaale	doc_397823702007_item	3536893	et	4	main
mulle	doc_397823702007_item	3536895	et	4	main
pilet	doc_397823702007_item	3536915	et	3	main
hakkan	doc_397823702007_item	3536920	et	3	main
ema	doc_397823702007_item	3536922	et	4	main
jurde	doc_397823702007_item	3536923	et	4	main
huvitav	doc_397823702007_item	3536945	et	4	main
sõidsin	doc_397823702007_item	3536947	et	4	main
kohale	doc_397823702007_item	3536948	et	4	main
heag	doc_397823702007_item	3536952	et	4	main
sulle	doc_397823702007_item	3536953	et	3	main
soovin	doc_397823702007_item	3536954	et	3	main
edu	doc_397823702007_item	3536955	et	4	main
kiri	doc_397823702008_item	3536957	et	3	main
reisi	doc_397823702008_item	3536960	et	4	main
kiri	doc_397823702008_item	3536964	et	3	main
soovite	doc_397823702008_item	3536974	et	3	main
ööbite	doc_397823702008_item	3536978	et	3	main
umbes	doc_397823702008_item	3536989	et	4	main
80	doc_397823702008_item	3536990	et	2	main
sest	doc_397823702008_item	3536999	et	4	main
ma	doc_397823702008_item	3537000	et	3	main
peeterburg	doc_397823702008_item	3537007	et	4	main
on	doc_397823702008_item	3537008	et	4	main
suurlinn	doc_397823702008_item	3537009	et	3	main
kuulturikeskus	doc_397823702008_item	3537012	et	4	main
ja	doc_397823702008_item	3537013	et	3	main
turismikeskus	doc_397823702008_item	3537014	et	3	main
seal	doc_397823702008_item	3537015	et	4	main
lasteteater	doc_397823702008_item	3537020	et	3	main
sõprad	doc_397823702008_item	3537040	et	4	main
sinuga	doc_397823702008_item	3537043	et	3	main
sõidama	doc_397823702008_item	3537044	et	4	main
lennuga	doc_397823702008_item	3537045	et	3	main
me	doc_397823702008_item	3537046	et	4	main
elame	doc_397823702008_item	3537047	et	3	main
sugulas	doc_397823702008_item	3537048	et	4	main
see	doc_397823702008_item	3537049	et	3	main
või	doc_397823702008_item	3537056	et	4	main
kullas	doc_397823702008_item	3537057	et	3	main
ma	doc_397823702008_item	3537058	et	3	main
plaanerin	doc_397823702008_item	3537059	et	4	main
reisi	doc_397823702008_item	3537060	et	4	main
juulis	doc_397823702008_item	3537061	et	3	main
kirja	doc_397823702008_item	3537062	et	4	main
palun	doc_397823702008_item	3537063	et	3	main
mulle	doc_397823702008_item	3537064	et	4	main
või	doc_397823702008_item	3537065	et	4	main
kirju	doc_397823702007_item	3536949	et	4	main
plaanite	doc_397823702008_item	3536959	et	3	main
eestlasest	doc_397823702008_item	3536966	et	3	main
kuhu	doc_397823702008_item	3536971	et	3	main
sõita	doc_397823702008_item	3536973	et	3	main
reisite	doc_397823702008_item	3536976	et	3	main
kui	doc_397823702008_item	3536979	et	3	main
maksab	doc_397823702008_item	3536982	et	3	main
sõna	doc_397823702008_item	3536991	et	4	main
tere	doc_397823702008_item	3536992	et	3	main
peeterburgisse	doc_397823702008_item	3537005	et	4	main
draamteater	doc_397823702008_item	3537019	et	4	main
tahan	doc_397823702008_item	3537042	et	3	main
tasuta	doc_397823702008_item	3537051	et	4	main
tihti	doc_397823702008_item	3537052	et	3	main
õhtuti	doc_397823702008_item	3537053	et	3	main
isega	doc_397823702008_item	3537072	et	4	main
abikaasa	doc_397823702008_item	3537073	et	4	main
ja	doc_397823702008_item	3537074	et	3	main
lapsed	doc_397823702008_item	3537075	et	3	main
seekord	doc_397823702008_item	3537076	et	3	main
lõpetan	doc_397823702008_item	3537077	et	3	main
soovin	doc_397823702008_item	3537078	et	3	main
sulle	doc_397823702008_item	3537079	et	3	main
võta	doc_397823702008_item	3537085	et	4	main
minuga	doc_397823702008_item	3537086	et	3	main
eesnimi	doc_397823702008_item	3537090	et	3	main
peterburgist	doc_397823702008_item	3537035	et	4	main
ja	doc_397823702008_item	3537036	et	3	main
mul	doc_397823702008_item	3537037	et	3	main
seal	doc_397823702008_item	3537038	et	4	main
sellest	doc_397823702008_item	3536963	et	4	main
kirjutage	doc_397823702008_item	3536968	et	3	main
ja	doc_397823702008_item	3536970	et	3	main
kohtades	doc_397823702008_item	3536984	et	3	main
kirja	doc_397823702008_item	3536986	et	4	main
kallis	doc_397823702008_item	3536993	et	4	main
ma	doc_397823702008_item	3536995	et	3	main
kirjutan	doc_397823702008_item	3536996	et	3	main
sulle	doc_397823702008_item	3536997	et	3	main
kirja	doc_397823702008_item	3536998	et	4	main
reisi	doc_397823702008_item	3537002	et	4	main
kunstimuuseum	doc_397823702008_item	3537021	et	3	main
eermitaž	doc_397823702008_item	3537022	et	2	main
väga	doc_397823702008_item	3537023	et	3	main
palju	doc_397823702008_item	3537024	et	4	main
vanaväljakud	doc_397823702008_item	3537025	et	3	main
vanatänavad	doc_397823702008_item	3537026	et	4	main
bootanikaaed	doc_397823702008_item	3537027	et	4	main
lossid	doc_397823702008_item	3537028	et	4	main
sa	doc_397823702008_item	3537029	et	3	main
teed	doc_397823702008_item	3537030	et	4	main
mis	doc_397823702008_item	3537031	et	4	main
ma	doc_397823702008_item	3537032	et	3	main
õpisin	doc_397823702008_item	3537033	et	4	main
sankt	doc_397823702008_item	3537034	et	4	main
ühendust	doc_397823702008_item	3537087	et	4	main
kiri	doc_397823702009_item	3537092	et	3	main
kirjutage	doc_397823702009_item	3537097	et	3	main
sellest	doc_397823702009_item	3537098	et	4	main
eestlasest	doc_397823702009_item	3537101	et	3	main
kus	doc_397823702009_item	3537112	et	3	main
kui	doc_397823702009_item	3537114	et	3	main
see	doc_397823702009_item	3537116	et	3	main
pikkus	doc_397823702009_item	3537123	et	4	main
ei	doc_397823702009_item	3537135	et	4	main
reisi	doc_397823702010_item	3537216	et	4	main
sellest	doc_397823702010_item	3537219	et	4	main
oma	doc_397823702010_item	3537221	et	4	main
kirjutage	doc_397823702010_item	3537224	et	3	main
kuhu	doc_397823702010_item	3537227	et	3	main
80	doc_397823702010_item	3537246	et	2	main
ei	doc_397823702010_item	3537254	et	4	main
ma	doc_397823702010_item	3537258	et	3	main
kell	doc_397823702010_item	3537271	et	3	main
söögi	doc_397823702010_item	3537275	et	4	main
kunstliknäitakse	doc_397823702010_item	3537279	et	4	main
loomaajas	doc_397823702010_item	3537281	et	4	main
peterburis	doc_397823702010_item	3537288	et	4	main
väga	doc_397823702010_item	3537289	et	3	main
ilus	doc_397823702010_item	3537290	et	4	main
soovin	doc_397823702010_item	3537315	et	3	main
teile	doc_397823702010_item	3537316	et	4	main
venemaale	doc_397823702008_item	3536961	et	4	main
oma	doc_397823702008_item	3536965	et	4	main
sõbrale	doc_397823702008_item	3536967	et	3	main
millal	doc_397823702008_item	3536969	et	3	main
te	doc_397823702008_item	3536972	et	4	main
millega	doc_397823702008_item	3536975	et	3	main
kus	doc_397823702008_item	3536977	et	3	main
palju	doc_397823702008_item	3536980	et	4	main
see	doc_397823702008_item	3536981	et	3	main
peatute	doc_397823702008_item	3536985	et	4	main
nõutav	doc_397823702008_item	3536987	et	4	main
pikkus	doc_397823702008_item	3536988	et	4	main
sõprana	doc_397823702008_item	3536994	et	4	main
sankt	doc_397823702008_item	3537006	et	4	main
on	doc_397823702008_item	3537016	et	4	main
ooperi	doc_397823702008_item	3537017	et	3	main
balletiteater	doc_397823702008_item	3537018	et	3	main
palju	doc_397823702008_item	3537039	et	4	main
ma	doc_397823702008_item	3537041	et	3	main
käime	doc_397823702008_item	3537054	et	4	main
restoranise	doc_397823702008_item	3537055	et	4	main
helista	doc_397823702008_item	3537066	et	4	main
millal	doc_397823702008_item	3537067	et	3	main
sõidama	doc_397823702008_item	3537070	et	4	main
võta	doc_397823702008_item	3537071	et	4	main
kui	doc_397823702008_item	3537082	et	3	main
oled	doc_397823702008_item	3537083	et	3	main
huvitatut	doc_397823702008_item	3537084	et	4	main
aega	doc_397823702008_item	3537089	et	4	main
plaanite	doc_397823702009_item	3537094	et	3	main
reisite	doc_397823702009_item	3537111	et	3	main
minu	doc_397823702009_item	3537128	et	3	main
tahan	doc_397823702009_item	3537144	et	3	main
sinul	doc_397823702009_item	3537146	et	3	main
te	doc_397823702010_item	3537214	et	4	main
kirjutage	doc_397823702010_item	3537218	et	3	main
sõna	doc_397823702010_item	3537247	et	4	main
kirjatanud	doc_397823702010_item	3537255	et	3	main
nädalat	doc_397823702010_item	3537260	et	3	main
tütare	doc_397823702010_item	3537262	et	4	main
ruures	doc_397823702010_item	3537263	et	4	main
see	doc_397823702010_item	3537264	et	3	main
oli	doc_397823702010_item	3537265	et	3	main
tore	doc_397823702010_item	3537266	et	3	main
aeg	doc_397823702010_item	3537267	et	3	main
tõusin	doc_397823702010_item	3537268	et	3	main
omale	doc_397823702010_item	3537274	et	3	main
käisin	doc_397823702010_item	3537277	et	3	main
teatris	doc_397823702010_item	3537280	et	3	main
praegu	doc_397823702010_item	3537282	et	3	main
head	doc_397823702010_item	3537318	et	4	main
tervist	doc_397823702010_item	3537320	et	4	main
kirjutage	doc_397823702010_item	3537321	et	3	main
kiri	doc_397823702011_item	3537338	et	3	main
te	doc_397823702011_item	3537346	et	4	main
sõita	doc_397823702011_item	3537347	et	3	main
palju	doc_397823702011_item	3537354	et	4	main
pikkus	doc_397823702011_item	3537362	et	4	main
on	doc_397823702011_item	3537371	et	4	main
ma	doc_397823702011_item	3537380	et	3	main
sõita	doc_397823702011_item	3537382	et	3	main
mul	doc_397823702011_item	3537393	et	3	main
on	doc_397823702011_item	3537394	et	4	main
eek	doc_397823702011_item	3537401	et	4	main
number	doc_397823702011_item	3537406	et	3	main
see	doc_397823702011_item	3537408	et	3	main
veel	doc_397823702011_item	3537421	et	4	main
teatris	doc_397823702011_item	3537424	et	3	main
tahad	doc_397823702008_item	3537069	et	3	main
head	doc_397823702008_item	3537088	et	4	main
te	doc_397823702009_item	3537093	et	4	main
kiri	doc_397823702009_item	3537099	et	3	main
kirjutage	doc_397823702009_item	3537103	et	3	main
ja	doc_397823702009_item	3537105	et	3	main
te	doc_397823702009_item	3537107	et	4	main
millega	doc_397823702009_item	3537110	et	3	main
ööbite	doc_397823702009_item	3537113	et	3	main
palju	doc_397823702009_item	3537115	et	4	main
maksab	doc_397823702009_item	3537117	et	3	main
kohtades	doc_397823702009_item	3537119	et	3	main
kirja	doc_397823702009_item	3537121	et	4	main
nõutav	doc_397823702009_item	3537122	et	4	main
kallis	doc_397823702009_item	3537129	et	4	main
vabanda	doc_397823702009_item	3537131	et	4	main
kuidas	doc_397823702009_item	3537137	et	3	main
sa	doc_397823702009_item	3537138	et	3	main
elad	doc_397823702009_item	3537139	et	3	main
sinu	doc_397823702009_item	3537141	et	3	main
ma	doc_397823702009_item	3537143	et	3	main
räägin	doc_397823702009_item	3537145	et	3	main
seal	doc_397823702009_item	3537193	et	4	main
ja	doc_397823702009_item	3537195	et	3	main
sööma	doc_397823702009_item	3537196	et	4	main
purskaevud	doc_397823702009_item	3537197	et	4	main
see	doc_397823702009_item	3537198	et	3	main
on	doc_397823702009_item	3537199	et	4	main
kõik	doc_397823702009_item	3537200	et	4	main
ma	doc_397823702009_item	3537201	et	3	main
ootan	doc_397823702009_item	3537202	et	3	main
vastus	doc_397823702009_item	3537203	et	3	main
ma	doc_397823702009_item	3537204	et	3	main
helista	doc_397823702009_item	3537205	et	4	main
kas	doc_397823702009_item	3537206	et	3	main
nägin	doc_397823702009_item	3537207	et	3	main
kõik	doc_397823702009_item	3537208	et	4	main
see	doc_397823702009_item	3537209	et	3	main
head	doc_397823702009_item	3537210	et	4	main
aega	doc_397823702009_item	3537211	et	4	main
kiri	doc_397823702010_item	3537213	et	3	main
kiri	doc_397823702010_item	3537220	et	3	main
sõbrale	doc_397823702010_item	3537223	et	3	main
ja	doc_397823702010_item	3537226	et	3	main
suvel	doc_397823702010_item	3537256	et	3	main
elasin	doc_397823702010_item	3537257	et	3	main
kaheksa	doc_397823702010_item	3537272	et	4	main
muuseimus	doc_397823702010_item	3537278	et	3	main
orlov	doc_397823702010_item	3537287	et	4	main
ma	doc_397823702010_item	3537314	et	3	main
ja	doc_397823702010_item	3537319	et	3	main
mulle	doc_397823702010_item	3537322	et	4	main
ma	doc_397823702010_item	3537323	et	3	main
ootan	doc_397823702010_item	3537324	et	3	main
hüvasti	doc_397823702010_item	3537325	et	3	main
teile	doc_397823702010_item	3537326	et	4	main
sõbraga	doc_397823702010_item	3537327	et	3	main
eesnimi	doc_397823702010_item	3537328	et	3	main
140605	doc_397823702010_item	3537329	et	2	main
plaanite	doc_397823702011_item	3537333	et	3	main
venemaale	doc_397823702011_item	3537335	et	4	main
kirjutage	doc_397823702011_item	3537336	et	3	main
kuhu	doc_397823702011_item	3537345	et	3	main
reisite	doc_397823702011_item	3537350	et	3	main
ööbite	doc_397823702011_item	3537352	et	3	main
see	doc_397823702011_item	3537355	et	3	main
kohtades	doc_397823702011_item	3537358	et	3	main
maksab	doc_397823702009_item	3537173	et	3	main
ainult	doc_397823702009_item	3537174	et	4	main
sööma	doc_397823702009_item	3537175	et	4	main
ja	doc_397823702009_item	3537176	et	3	main
jooma	doc_397823702009_item	3537177	et	4	main
ma	doc_397823702009_item	3537178	et	3	main
tahan	doc_397823702009_item	3537179	et	3	main
vaata	doc_397823702009_item	3537180	et	4	main
moskvasse	doc_397823702009_item	3537181	et	4	main
loomaaias	doc_397823702009_item	3537182	et	4	main
punane	doc_397823702009_item	3537183	et	4	main
väljak	doc_397823702009_item	3537184	et	3	main
muvsolei	doc_397823702009_item	3537185	et	4	main
televiska	doc_397823702009_item	3537186	et	4	main
ostankino	doc_397823702009_item	3537187	et	4	main
seal	doc_397823702009_item	3537188	et	4	main
on	doc_397823702009_item	3537189	et	4	main
restoraan	doc_397823702009_item	3537190	et	4	main
ma	doc_397823702009_item	3537191	et	3	main
reisi	doc_397823702009_item	3537095	et	4	main
oma	doc_397823702009_item	3537100	et	4	main
millal	doc_397823702009_item	3537104	et	3	main
kuhu	doc_397823702009_item	3537106	et	3	main
soovite	doc_397823702009_item	3537109	et	3	main
umbes	doc_397823702009_item	3537124	et	4	main
80	doc_397823702009_item	3537125	et	2	main
sõna	doc_397823702009_item	3537126	et	4	main
kirja	doc_397823702009_item	3537136	et	4	main
ja	doc_397823702009_item	3537140	et	3	main
mis	doc_397823702009_item	3537147	et	4	main
minu	doc_397823702009_item	3537148	et	3	main
plaanit	doc_397823702009_item	3537149	et	4	main
reisi	doc_397823702009_item	3537150	et	4	main
venemaale	doc_397823702009_item	3537151	et	4	main
ma	doc_397823702009_item	3537152	et	3	main
tahan	doc_397823702009_item	3537153	et	3	main
sõita	doc_397823702009_item	3537154	et	3	main
moskvasse	doc_397823702009_item	3537155	et	4	main
suvel	doc_397823702009_item	3537156	et	3	main
ja	doc_397823702009_item	3537157	et	3	main
talvel	doc_397823702009_item	3537158	et	4	main
ma	doc_397823702009_item	3537159	et	3	main
sõidan	doc_397823702009_item	3537160	et	3	main
üks	doc_397823702009_item	3537161	et	3	main
ma	doc_397823702009_item	3537162	et	3	main
tahan	doc_397823702009_item	3537163	et	3	main
sõidan	doc_397823702009_item	3537164	et	3	main
rongiga	doc_397823702009_item	3537165	et	4	main
ja	doc_397823702009_item	3537166	et	3	main
bussiga	doc_397823702009_item	3537167	et	3	main
ma	doc_397823702009_item	3537168	et	3	main
olen	doc_397823702009_item	3537169	et	3	main
ööbin	doc_397823702009_item	3537170	et	3	main
sugulasel	doc_397823702009_item	3537171	et	3	main
see	doc_397823702009_item	3537172	et	3	main
tahan	doc_397823702009_item	3537192	et	3	main
jooma	doc_397823702009_item	3537194	et	4	main
palju	doc_397823702010_item	3537292	et	4	main
huvitavat	doc_397823702010_item	3537293	et	4	main
ilusad	doc_397823702010_item	3537294	et	3	main
purskkaevud	doc_397823702010_item	3537295	et	3	main
ma	doc_397823702010_item	3537296	et	3	main
sõidan	doc_397823702010_item	3537297	et	3	main
koos	doc_397823702010_item	3537298	et	4	main
poega	doc_397823702010_item	3537299	et	4	main
bussiga	doc_397823702010_item	3537300	et	3	main
tee	doc_397823702010_item	3537301	et	4	main
maksab	doc_397823702010_item	3537302	et	3	main
kaks	doc_397823702010_item	3537303	et	3	main
sada	doc_397823702010_item	3537304	et	4	main
krooni	doc_397823702010_item	3537305	et	4	main
see	doc_397823702010_item	3537306	et	3	main
on	doc_397823702010_item	3537307	et	4	main
ovadav	doc_397823702010_item	3537308	et	4	main
elavad	doc_397823702010_item	3537309	et	4	main
kivimaja	doc_397823702010_item	3537310	et	4	main
kõik	doc_397823702010_item	3537311	et	4	main
oli	doc_397823702010_item	3537312	et	3	main
venemaale	doc_397823702010_item	3537217	et	4	main
eestlasest	doc_397823702010_item	3537222	et	3	main
millal	doc_397823702010_item	3537225	et	3	main
te	doc_397823702010_item	3537228	et	4	main
sõita	doc_397823702010_item	3537229	et	3	main
soovite	doc_397823702010_item	3537230	et	3	main
millega	doc_397823702010_item	3537231	et	3	main
reisite	doc_397823702010_item	3537232	et	3	main
kus	doc_397823702010_item	3537233	et	3	main
ööbite	doc_397823702010_item	3537234	et	3	main
kui	doc_397823702010_item	3537235	et	3	main
palju	doc_397823702010_item	3537236	et	4	main
see	doc_397823702010_item	3537237	et	3	main
maksab	doc_397823702010_item	3537238	et	3	main
millistes	doc_397823702010_item	3537239	et	3	main
kohtades	doc_397823702010_item	3537240	et	3	main
peatute	doc_397823702010_item	3537241	et	4	main
kirja	doc_397823702010_item	3537242	et	4	main
nõutav	doc_397823702010_item	3537243	et	4	main
pikkus	doc_397823702010_item	3537244	et	4	main
umbes	doc_397823702010_item	3537245	et	4	main
rimmi	doc_397823702010_item	3537249	et	4	main
kaua	doc_397823702010_item	3537253	et	3	main
iga	doc_397823702010_item	3537269	et	4	main
päev	doc_397823702010_item	3537270	et	3	main
näitakse	doc_397823702010_item	3537285	et	4	main
kunstlinik	doc_397823702010_item	3537286	et	3	main
hästi	doc_397823702010_item	3537313	et	3	main
kiri	doc_397823702011_item	3537331	et	3	main
oma	doc_397823702011_item	3537339	et	4	main
eestlasest	doc_397823702011_item	3537340	et	3	main
sõbrale	doc_397823702011_item	3537341	et	3	main
ja	doc_397823702011_item	3537344	et	3	main
soovite	doc_397823702011_item	3537348	et	3	main
kus	doc_397823702011_item	3537351	et	3	main
kui	doc_397823702011_item	3537353	et	3	main
millistes	doc_397823702011_item	3537357	et	3	main
kirja	doc_397823702011_item	3537360	et	4	main
juunil	doc_397823702011_item	3537372	et	3	main
venemaalle	doc_397823702011_item	3537379	et	4	main
sovin	doc_397823702011_item	3537381	et	4	main
eek	doc_397823702011_item	3537390	et	4	main
aga	doc_397823702011_item	3537391	et	3	main
linnas	doc_397823702011_item	3537392	et	4	main
maksab	doc_397823702011_item	3537399	et	3	main
öö	doc_397823702011_item	3537403	et	4	main
ööd	doc_397823702011_item	3537419	et	4	main
kontserdil	doc_397823702011_item	3537426	et	3	main
tulen	doc_397823702011_item	3537428	et	3	main
kirjutage	doc_397823702013_item	3537470	et	3	main
kirjutage	doc_397823702013_item	3537476	et	3	main
ja	doc_397823702013_item	3537478	et	3	main
te	doc_397823702013_item	3537480	et	4	main
millega	doc_397823702013_item	3537483	et	3	main
ööbite	doc_397823702013_item	3537486	et	3	main
pikkus	doc_397823702013_item	3537496	et	4	main
aitäh	doc_397823702013_item	3537508	et	3	main
eest	doc_397823702013_item	3537510	et	4	main
on	doc_397823702013_item	3537512	et	4	main
kõik	doc_397823702013_item	3537513	et	4	main
hästi	doc_397823702013_item	3537514	et	3	main
mul	doc_397823702013_item	3537515	et	3	main
kirikud	doc_397823702013_item	3537567	et	3	main
kiri	doc_397823702014_item	3537584	et	3	main
eestlasest	doc_397823702014_item	3537593	et	3	main
ja	doc_397823702014_item	3537597	et	3	main
vastata	doc_397823702014_item	3537635	et	4	main
suvel	doc_397823702014_item	3537641	et	3	main
mõtlen	doc_397823702014_item	3537644	et	3	main
seal	doc_397823702014_item	3537672	et	4	main
väga	doc_397823702014_item	3537673	et	3	main
puud	doc_397823702014_item	3537677	et	4	main
liivarand	doc_397823702014_item	3537678	et	3	main
päivitama	doc_397823702014_item	3537680	et	4	main
ujuda	doc_397823702014_item	3537681	et	3	main
tutvuda	doc_397823702014_item	3537682	et	3	main
hommiku	doc_397823702010_item	3537276	et	3	main
on	doc_397823702010_item	3537283	et	4	main
avatud	doc_397823702010_item	3537284	et	4	main
seal	doc_397823702010_item	3537291	et	4	main
kõike	doc_397823702010_item	3537317	et	4	main
te	doc_397823702011_item	3537332	et	4	main
kirjutage	doc_397823702011_item	3537342	et	3	main
maksab	doc_397823702011_item	3537356	et	3	main
peatute	doc_397823702011_item	3537359	et	4	main
pärast	doc_397823702011_item	3537373	et	4	main
jaani	doc_397823702011_item	3537374	et	4	main
tuba	doc_397823702011_item	3537395	et	4	main
krooni	doc_397823702011_item	3537402	et	4	main
minu	doc_397823702011_item	3537404	et	3	main
ja	doc_397823702011_item	3537420	et	3	main
ma	doc_397823702011_item	3537427	et	3	main
esmaspäeval	doc_397823702011_item	3537430	et	3	main
palun	doc_397823702011_item	3537432	et	3	main
ja	doc_397823702011_item	3537438	et	3	main
kuidas	doc_397823702011_item	3537441	et	3	main
venemaale	doc_397823702013_item	3537469	et	4	main
eestlasest	doc_397823702013_item	3537474	et	3	main
sõita	doc_397823702013_item	3537481	et	3	main
reisite	doc_397823702013_item	3537484	et	3	main
kui	doc_397823702013_item	3537487	et	3	main
umbes	doc_397823702013_item	3537497	et	4	main
80	doc_397823702013_item	3537498	et	2	main
sõna	doc_397823702013_item	3537499	et	4	main
tere	doc_397823702013_item	3537500	et	3	main
suur	doc_397823702013_item	3537507	et	3	main
plaanerin	doc_397823702013_item	3537521	et	4	main
reisi	doc_397823702013_item	3537522	et	4	main
tahan	doc_397823702013_item	3537531	et	3	main
vanalinn	doc_397823702013_item	3537533	et	3	main
petergoffi	doc_397823702013_item	3537534	et	4	main
vadata	doc_397823702013_item	3537565	et	4	main
reisi	doc_397823702014_item	3537587	et	4	main
oma	doc_397823702014_item	3537592	et	4	main
kirjutage	doc_397823702014_item	3537595	et	3	main
sõita	doc_397823702014_item	3537600	et	3	main
kallis	doc_397823702014_item	3537621	et	4	main
täna	doc_397823702014_item	3537625	et	4	main
sinu	doc_397823702014_item	3537626	et	3	main
sest	doc_397823702014_item	3537636	et	4	main
mul	doc_397823702014_item	3537637	et	3	main
juulil	doc_397823702014_item	3537642	et	3	main
ma	doc_397823702014_item	3537643	et	3	main
venemaale	doc_397823702014_item	3537646	et	4	main
meere	doc_397823702014_item	3537648	et	4	main
äärde	doc_397823702014_item	3537649	et	4	main
ma	doc_397823702014_item	3537650	et	3	main
sõidan	doc_397823702014_item	3537651	et	3	main
tagasi	doc_397823702014_item	3537659	et	3	main
olime	doc_397823702014_item	3537661	et	3	main
me	doc_397823702014_item	3537663	et	4	main
oleme	doc_397823702014_item	3537664	et	3	main
mererannal	doc_397823702014_item	3537671	et	3	main
mulle	doc_397823702014_item	3537710	et	4	main
kolmandal	doc_397823702011_item	3537410	et	3	main
korrusel	doc_397823702011_item	3537411	et	3	main
ma	doc_397823702011_item	3537412	et	3	main
tahan	doc_397823702011_item	3537413	et	3	main
vaadata	doc_397823702011_item	3537414	et	4	main
museumi	doc_397823702011_item	3537415	et	4	main
ja	doc_397823702011_item	3537416	et	3	main
reisi	doc_397823702011_item	3537334	et	4	main
sellest	doc_397823702011_item	3537337	et	4	main
millal	doc_397823702011_item	3537343	et	3	main
millega	doc_397823702011_item	3537349	et	3	main
80	doc_397823702011_item	3537364	et	2	main
tere	doc_397823702011_item	3537366	et	3	main
niina	doc_397823702011_item	3537368	et	4	main
minu	doc_397823702011_item	3537369	et	3	main
puhkus	doc_397823702011_item	3537370	et	3	main
päel	doc_397823702011_item	3537375	et	4	main
ma	doc_397823702011_item	3537376	et	3	main
sõidan	doc_397823702011_item	3537377	et	3	main
reisi	doc_397823702011_item	3537378	et	4	main
sankt	doc_397823702011_item	3537383	et	4	main
peterburgis	doc_397823702011_item	3537384	et	4	main
autoga	doc_397823702011_item	3537385	et	3	main
pilet	doc_397823702011_item	3537386	et	3	main
maksad	doc_397823702011_item	3537387	et	4	main
200	doc_397823702011_item	3537389	et	2	main
tuba	doc_397823702011_item	3537397	et	4	main
hotellis	doc_397823702011_item	3537398	et	3	main
300	doc_397823702011_item	3537400	et	2	main
taa	doc_397823702011_item	3537405	et	4	main
17	doc_397823702011_item	3537407	et	2	main
asub	doc_397823702011_item	3537409	et	3	main
helistage	doc_397823702011_item	3537433	et	3	main
hommikul	doc_397823702011_item	3537435	et	3	main
juunil	doc_397823702011_item	3537437	et	3	main
palun	doc_397823702011_item	3537440	et	3	main
plaanite	doc_397823702013_item	3537467	et	3	main
sellest	doc_397823702013_item	3537471	et	4	main
nõutav	doc_397823702013_item	3537495	et	4	main
sain	doc_397823702013_item	3537503	et	3	main
su	doc_397823702013_item	3537504	et	3	main
kirja	doc_397823702013_item	3537505	et	4	main
kirja	doc_397823702013_item	3537509	et	4	main
mul	doc_397823702013_item	3537511	et	3	main
venemaale	doc_397823702013_item	3537523	et	4	main
ma	doc_397823702013_item	3537524	et	3	main
sõidan	doc_397823702013_item	3537525	et	3	main
autoga	doc_397823702013_item	3537526	et	3	main
koos	doc_397823702013_item	3537527	et	4	main
loosid	doc_397823702013_item	3537569	et	4	main
mulle	doc_397823702013_item	3537571	et	4	main
te	doc_397823702014_item	3537585	et	4	main
venemaale	doc_397823702014_item	3537588	et	4	main
kirjutage	doc_397823702014_item	3537589	et	3	main
sõbrale	doc_397823702014_item	3537594	et	3	main
millal	doc_397823702014_item	3537596	et	3	main
kuhu	doc_397823702014_item	3537598	et	3	main
millega	doc_397823702014_item	3537602	et	3	main
sõbranna	doc_397823702014_item	3537622	et	4	main
sain	doc_397823702014_item	3537624	et	3	main
kirja	doc_397823702014_item	3537627	et	4	main
suur	doc_397823702014_item	3537628	et	3	main
aitäh	doc_397823702014_item	3537629	et	3	main
kirja	doc_397823702014_item	3537630	et	4	main
on	doc_397823702014_item	3537638	et	4	main
sõitma	doc_397823702014_item	3537645	et	3	main
musta	doc_397823702014_item	3537647	et	4	main
me	doc_397823702014_item	3537660	et	4	main
seal	doc_397823702014_item	3537662	et	4	main
mäed	doc_397823702014_item	3537676	et	3	main
turul	doc_397823702014_item	3537685	et	3	main
pirnid	doc_397823702014_item	3537693	et	3	main
hotellis	doc_397823702014_item	3537696	et	3	main
see	doc_397823702014_item	3537701	et	3	main
kiri	doc_986203247114_item	3537722	et	3	main
kallis	doc_986203247114_item	3537724	et	4	main
huvitavamaks	doc_986203247114_item	3537731	et	4	main
sellest	doc_986203247114_item	3537732	et	4	main
et	doc_986203247114_item	3537733	et	3	main
ma	doc_986203247114_item	3537734	et	3	main
käin	doc_986203247114_item	3537735	et	3	main
jõhvis	doc_986203247114_item	3537736	et	3	main
kursusel	doc_986203247114_item	3537737	et	3	main
ma	doc_986203247114_item	3537738	et	3	main
juba	doc_986203247114_item	3537739	et	3	main
kirjutasin	doc_986203247114_item	3537740	et	3	main
sulle	doc_986203247114_item	3537741	et	3	main
igatahes	doc_986203247114_item	3537745	et	3	main
nõutav	doc_397823702011_item	3537361	et	4	main
umbes	doc_397823702011_item	3537363	et	4	main
sõna	doc_397823702011_item	3537365	et	4	main
kallis	doc_397823702011_item	3537367	et	4	main
ümbes	doc_397823702011_item	3537388	et	4	main
reserveeritud	doc_397823702011_item	3537396	et	4	main
vaata	doc_397823702011_item	3537417	et	4	main
valget	doc_397823702011_item	3537418	et	3	main
ma	doc_397823702011_item	3537422	et	3	main
käin	doc_397823702011_item	3537423	et	3	main
ja	doc_397823702011_item	3537425	et	3	main
tagasi	doc_397823702011_item	3537429	et	3	main
niina	doc_397823702011_item	3537431	et	4	main
mulle	doc_397823702011_item	3537434	et	4	main
24	doc_397823702011_item	3537436	et	2	main
ütelge	doc_397823702011_item	3537439	et	3	main
elavad	doc_397823702011_item	3537442	et	4	main
meie	doc_397823702011_item	3537443	et	4	main
sugulased	doc_397823702011_item	3537444	et	3	main
veel	doc_397823702011_item	3537445	et	4	main
ma	doc_397823702011_item	3537446	et	3	main
käin	doc_397823702011_item	3537447	et	3	main
teatris	doc_397823702011_item	3537448	et	3	main
kus	doc_397823702011_item	3537449	et	3	main
mängis	doc_397823702011_item	3537450	et	3	main
suurepärased	doc_397823702011_item	3537451	et	4	main
näitlejad	doc_397823702011_item	3537452	et	4	main
aleksei	doc_397823702011_item	3537453	et	4	main
žarov	doc_397823702011_item	3537454	et	2	main
ja	doc_397823702011_item	3537455	et	3	main
oleg	doc_397823702011_item	3537456	et	4	main
bassilašbilli	doc_397823702011_item	3537457	et	2	main
nad	doc_397823702011_item	3537458	et	3	main
mängivad	doc_397823702011_item	3537459	et	4	main
etendust	doc_397823702011_item	3537460	et	4	main
tšehhovi	doc_397823702011_item	3537461	et	2	main
nägemiseni	doc_397823702011_item	3537462	et	4	main
eesnimi	doc_397823702011_item	3537463	et	3	main
kiri	doc_397823702013_item	3537465	et	3	main
kiri	doc_397823702013_item	3537472	et	3	main
oma	doc_397823702013_item	3537473	et	4	main
sõbrale	doc_397823702013_item	3537475	et	3	main
millal	doc_397823702013_item	3537477	et	3	main
kuhu	doc_397823702013_item	3537479	et	3	main
soovite	doc_397823702013_item	3537482	et	3	main
kus	doc_397823702013_item	3537485	et	3	main
palju	doc_397823702013_item	3537488	et	4	main
see	doc_397823702013_item	3537489	et	3	main
maksab	doc_397823702013_item	3537490	et	3	main
millistes	doc_397823702013_item	3537491	et	3	main
kohtades	doc_397823702013_item	3537492	et	3	main
peatute	doc_397823702013_item	3537493	et	4	main
kätte	doc_397823702013_item	3537506	et	4	main
ma	doc_397823702013_item	3537530	et	3	main
ermitaži	doc_397823702013_item	3537566	et	2	main
on	doc_397823702013_item	3537546	et	4	main
väga	doc_397823702013_item	3537547	et	3	main
ilusa	doc_397823702013_item	3537548	et	3	main
park	doc_397823702013_item	3537549	et	3	main
õhtuti	doc_397823702013_item	3537550	et	3	main
on	doc_397823702013_item	3537551	et	4	main
palju	doc_397823702013_item	3537552	et	4	main
rahvast	doc_397823702013_item	3537553	et	4	main
nii	doc_397823702013_item	3537554	et	3	main
turiste	doc_397823702013_item	3537555	et	3	main
kui	doc_397823702013_item	3537556	et	3	main
kohalikke	doc_397823702013_item	3537557	et	4	main
kõik	doc_397823702013_item	3537558	et	4	main
on	doc_397823702013_item	3537559	et	4	main
rõõmsad	doc_397823702013_item	3537560	et	3	main
ja	doc_397823702013_item	3537561	et	3	main
sõralikud	doc_397823702013_item	3537562	et	4	main
ma	doc_397823702013_item	3537563	et	3	main
tahan	doc_397823702013_item	3537564	et	3	main
te	doc_397823702013_item	3537466	et	4	main
reisi	doc_397823702013_item	3537468	et	4	main
kirja	doc_397823702013_item	3537494	et	4	main
kallis	doc_397823702013_item	3537501	et	4	main
ma	doc_397823702013_item	3537502	et	3	main
on	doc_397823702013_item	3537516	et	4	main
varsti	doc_397823702013_item	3537517	et	3	main
puhkus	doc_397823702013_item	3537518	et	3	main
augustis	doc_397823702013_item	3537519	et	3	main
ma	doc_397823702013_item	3537520	et	3	main
oma	doc_397823702013_item	3537528	et	4	main
perega	doc_397823702013_item	3537529	et	3	main
nägeda	doc_397823702013_item	3537532	et	4	main
seal	doc_397823702013_item	3537535	et	4	main
on	doc_397823702013_item	3537536	et	4	main
palju	doc_397823702013_item	3537537	et	4	main
nägemisvöörsuseid	doc_397823702013_item	3537538	et	4	main
see	doc_397823702013_item	3537539	et	3	main
missugused	doc_397823702013_item	3537540	et	3	main
purskkaevud	doc_397823702013_item	3537541	et	3	main
purskkaevud	doc_397823702013_item	3537542	et	3	main
asuvad	doc_397823702013_item	3537543	et	4	main
pargis	doc_397823702013_item	3537544	et	3	main
see	doc_397823702013_item	3537545	et	3	main
ja	doc_397823702013_item	3537568	et	3	main
kirjuta	doc_397823702013_item	3537570	et	4	main
sageli	doc_397823702013_item	3537572	et	3	main
tervita	doc_397823702013_item	3537573	et	4	main
palun	doc_397823702013_item	3537574	et	3	main
kõigele	doc_397823702013_item	3537575	et	4	main
palju	doc_397823702013_item	3537576	et	4	main
tervisi	doc_397823702013_item	3537577	et	3	main
kõike	doc_397823702013_item	3537578	et	4	main
head	doc_397823702013_item	3537579	et	4	main
kallis	doc_397823702013_item	3537580	et	4	main
130605	doc_397823702013_item	3537581	et	2	main
eesnimi	doc_397823702013_item	3537582	et	3	main
sellest	doc_397823702014_item	3537590	et	4	main
te	doc_397823702014_item	3537599	et	4	main
soovite	doc_397823702014_item	3537601	et	3	main
eest	doc_397823702014_item	3537631	et	4	main
tahan	doc_397823702014_item	3537632	et	3	main
sulle	doc_397823702014_item	3537633	et	3	main
sulle	doc_397823702014_item	3537639	et	3	main
koos	doc_397823702014_item	3537652	et	4	main
perega	doc_397823702014_item	3537653	et	3	main
me	doc_397823702014_item	3537654	et	4	main
sõidame	doc_397823702014_item	3537655	et	3	main
aastat	doc_397823702014_item	3537658	et	3	main
loodus	doc_397823702014_item	3537675	et	4	main
võib	doc_397823702014_item	3537679	et	3	main
on	doc_397823702014_item	3537686	et	4	main
puuvilju	doc_397823702014_item	3537688	et	3	main
juurvilju	doc_397823702014_item	3537690	et	3	main
õunad	doc_397823702014_item	3537691	et	3	main
üks	doc_397823702014_item	3537694	et	3	main
päev	doc_397823702014_item	3537695	et	3	main
kuus	doc_397823702014_item	3537698	et	4	main
on	doc_397823702014_item	3537702	et	4	main
hind	doc_397823702014_item	3537704	et	3	main
elada	doc_397823702014_item	3537665	et	3	main
hotellis	doc_397823702014_item	3537666	et	3	main
kolmekohalikus	doc_397823702014_item	3537667	et	4	main
numbris	doc_397823702014_item	3537668	et	3	main
hotell	doc_397823702014_item	3537669	et	3	main
asub	doc_397823702014_item	3537670	et	3	main
plaanite	doc_397823702014_item	3537586	et	3	main
kiri	doc_397823702014_item	3537591	et	3	main
reisite	doc_397823702014_item	3537603	et	3	main
kus	doc_397823702014_item	3537604	et	3	main
ööbite	doc_397823702014_item	3537605	et	3	main
kui	doc_397823702014_item	3537606	et	3	main
palju	doc_397823702014_item	3537607	et	4	main
see	doc_397823702014_item	3537608	et	3	main
maksab	doc_397823702014_item	3537609	et	3	main
millistes	doc_397823702014_item	3537610	et	3	main
kohtades	doc_397823702014_item	3537611	et	3	main
peatute	doc_397823702014_item	3537612	et	4	main
kirja	doc_397823702014_item	3537613	et	4	main
nõutav	doc_397823702014_item	3537614	et	4	main
pikkus	doc_397823702014_item	3537615	et	4	main
umbes	doc_397823702014_item	3537616	et	4	main
80	doc_397823702014_item	3537617	et	2	main
sõna	doc_397823702014_item	3537618	et	4	main
tere	doc_397823702014_item	3537619	et	3	main
minu	doc_397823702014_item	3537620	et	3	main
marika	doc_397823702014_item	3537623	et	4	main
kohe	doc_397823702014_item	3537634	et	4	main
uudis	doc_397823702014_item	3537640	et	3	main
rongiga	doc_397823702014_item	3537656	et	4	main
kaks	doc_397823702014_item	3537657	et	3	main
ilus	doc_397823702014_item	3537674	et	4	main
vaatamisväärsustega	doc_397823702014_item	3537683	et	4	main
juulil	doc_397823702014_item	3537684	et	3	main
palju	doc_397823702014_item	3537687	et	4	main
ja	doc_397823702014_item	3537689	et	3	main
viinamarjad	doc_397823702014_item	3537692	et	3	main
maksab	doc_397823702014_item	3537697	et	3	main
krooni	doc_397823702014_item	3537700	et	4	main
kui	doc_397823702014_item	3537705	et	3	main
tere	doc_986203247114_item	3537723	et	3	main
päevaga	doc_986203247114_item	3537730	et	3	main
olid	doc_986203247114_item	3537744	et	4	main
esimesed	doc_986203247114_item	3537757	et	3	main
mulle	doc_986203247114_item	3537765	et	4	main
koha	doc_986203247114_item	3537768	et	4	main
leidmises	doc_986203247114_item	3537769	et	4	main
eile	doc_986203247114_item	3537770	et	3	main
käisin	doc_986203247114_item	3537771	et	3	main
ekskursioonil	doc_986203247114_item	3537772	et	3	main
külastasime	doc_986203247114_item	3537773	et	3	main
muuseumit	doc_986203247114_item	3537775	et	3	main
kus	doc_986203247114_item	3537776	et	3	main
võis	doc_986203247114_item	3537777	et	4	main
näha	doc_986203247114_item	3537778	et	3	main
koolituba	doc_986203247114_item	3537784	et	4	main
olime	doc_986203247114_item	3537785	et	3	main
ka	doc_986203247114_item	3537786	et	3	main
kirikus	doc_986203247114_item	3537787	et	3	main
kursustel	doc_986203247114_item	3537788	et	3	main
rohkem	doc_986203247114_item	3537796	et	4	main
dokumente	doc_986203247114_item	3537811	et	3	main
ikkagi	doc_986203247114_item	3537813	et	4	main
arvan	doc_986203247114_item	3537818	et	3	main
võiks	doc_986203247114_item	3537820	et	4	main
selline	doc_986203247114_item	3537823	et	4	main
inimene	doc_986203247114_item	3537827	et	3	main
teab	doc_986203247114_item	3537829	et	3	main
küllaltki	doc_986203247114_item	3537832	et	4	main
hästi	doc_986203247114_item	3537833	et	3	main
saaks	doc_986203247114_item	3537834	et	3	main
aega	doc_986203247114_item	3537850	et	4	main
tudengitel	doc_986203247114_item	3537852	et	3	main
on	doc_986203247114_item	3537862	et	4	main
õpivad	doc_986203247114_item	3537867	et	3	main
tea	doc_986203247114_item	3537869	et	4	main
lõpus	doc_986203247114_item	3537871	et	4	main
pöörduda	doc_986203247114_item	3537878	et	3	main
sest	doc_986203247114_item	3537879	et	4	main
ei	doc_986203247114_item	3537880	et	4	main
oma	doc_600559928978_item	3537898	et	4	main
sa	doc_600559928978_item	3537907	et	3	main
kursustel	doc_600559928978_item	3537908	et	3	main
õpid	doc_600559928978_item	3537909	et	4	main
seal	doc_600559928978_item	3537926	et	4	main
sinu	doc_600559928978_item	3537933	et	3	main
on	doc_600559928978_item	3537943	et	4	main
ma	doc_600559928978_item	3538001	et	3	main
pärast	doc_600559928978_item	3538007	et	4	main
oma	doc_600559928979_item	3538026	et	4	main
kursustel	doc_600559928979_item	3538032	et	3	main
mida	doc_600559928979_item	3538034	et	4	main
õpid	doc_600559928979_item	3538037	et	4	main
ja	doc_600559928979_item	3538038	et	3	main
et	doc_600559928979_item	3538039	et	3	main
varsti	doc_600559928979_item	3538040	et	3	main
see	doc_600559928979_item	3538050	et	3	main
tere	doc_600559928979_item	3538058	et	3	main
sinu	doc_600559928979_item	3538061	et	3	main
käsi	doc_600559928979_item	3538065	et	4	main
kaib	doc_600559928979_item	3538066	et	4	main
mul	doc_600559928979_item	3538067	et	3	main
mis	doc_600559928979_item	3538071	et	4	main
sul	doc_600559928979_item	3538072	et	3	main
uudist	doc_600559928979_item	3538073	et	3	main
teate	doc_600559928979_item	3538074	et	4	main
mulle	doc_600559928979_item	3538075	et	4	main
ta	doc_600559928979_item	3538076	et	4	main
sada	doc_397823702014_item	3537699	et	4	main
hea	doc_397823702014_item	3537703	et	4	main
sul	doc_397823702014_item	3537706	et	3	main
külla	doc_397823702014_item	3537711	et	4	main
siis	doc_397823702014_item	3537712	et	3	main
saame	doc_397823702014_item	3537713	et	4	main
sellest	doc_397823702014_item	3537714	et	4	main
räkida	doc_397823702014_item	3537715	et	4	main
seekord	doc_397823702014_item	3537716	et	3	main
lõpetan	doc_397823702014_item	3537717	et	3	main
head	doc_397823702014_item	3537718	et	4	main
aega	doc_397823702014_item	3537719	et	4	main
eesnimi	doc_397823702014_item	3537720	et	3	main
minu	doc_986203247114_item	3537726	et	3	main
läheb	doc_986203247114_item	3537728	et	3	main
kursused	doc_986203247114_item	3537743	et	3	main
kursused	doc_986203247114_item	3537758	et	3	main
soovi	doc_986203247114_item	3537764	et	4	main
iisakus	doc_986203247114_item	3537774	et	4	main
võis	doc_986203247114_item	3537794	et	4	main
ka	doc_986203247114_item	3537795	et	3	main
toime	doc_986203247114_item	3537801	et	4	main
vaja	doc_986203247114_item	3537816	et	4	main
võimalus	doc_986203247114_item	3537824	et	3	main
teist	doc_986203247114_item	3537835	et	4	main
keelt	doc_986203247114_item	3537836	et	4	main
näiteks	doc_986203247114_item	3537838	et	4	main
meeldiv	doc_986203247114_item	3537842	et	4	main
oleks	doc_986203247114_item	3537843	et	3	main
kui	doc_986203247114_item	3537844	et	3	main
terve	doc_986203247114_item	3537845	et	4	main
kuu	doc_986203247114_item	3537846	et	4	main
võimalus	doc_986203247114_item	3537854	et	3	main
vabalt	doc_986203247114_item	3537857	et	4	main
selline	doc_986203247114_item	3537860	et	4	main
võimlus	doc_986203247114_item	3537861	et	4	main
kes	doc_986203247114_item	3537866	et	4	main
kuid	doc_986203247114_item	3537876	et	4	main
kardad	doc_986203247114_item	3537877	et	4	main
et	doc_600559928978_item	3537911	et	3	main
sa	doc_600559928978_item	3537917	et	3	main
lähed	doc_600559928978_item	3537919	et	3	main
firma	doc_600559928978_item	3537921	et	4	main
tere	doc_600559928978_item	3537929	et	3	main
kirja	doc_600559928978_item	3537934	et	4	main
tänan	doc_600559928978_item	3537936	et	3	main
sinu	doc_600559928978_item	3537937	et	3	main
kiri	doc_600559928978_item	3537938	et	3	main
oli	doc_600559928978_item	3537939	et	3	main
väga	doc_600559928978_item	3537940	et	3	main
huvitav	doc_600559928978_item	3537941	et	4	main
mul	doc_600559928978_item	3537942	et	3	main
on	doc_397823702014_item	3537707	et	4	main
võimalik	doc_397823702014_item	3537708	et	3	main
tuli	doc_397823702014_item	3537709	et	4	main
sõber	doc_986203247114_item	3537725	et	3	main
iga	doc_986203247114_item	3537729	et	4	main
ma	doc_986203247114_item	3537746	et	3	main
minu	doc_986203247114_item	3537756	et	3	main
praktika	doc_986203247114_item	3537767	et	4	main
tuba	doc_986203247114_item	3537782	et	4	main
vana	doc_986203247114_item	3537783	et	4	main
seda	doc_986203247114_item	3537793	et	3	main
sest	doc_986203247114_item	3537798	et	4	main
sellega	doc_986203247114_item	3537799	et	3	main
tulevasel	doc_986203247114_item	3537803	et	4	main
asjaajajal	doc_986203247114_item	3537804	et	3	main
selleks	doc_986203247114_item	3537805	et	4	main
et	doc_986203247114_item	3537806	et	3	main
õpetada	doc_986203247114_item	3537807	et	3	main
inimest	doc_986203247114_item	3537808	et	3	main
koostada	doc_986203247114_item	3537810	et	3	main
rohkem	doc_986203247114_item	3537814	et	4	main
aega	doc_986203247114_item	3537815	et	4	main
see	doc_986203247114_item	3537883	et	3	main
on	doc_986203247114_item	3537884	et	4	main
sobilik	doc_986203247114_item	3537885	et	3	main
kursuse	doc_986203247114_item	3537886	et	3	main
juhatajal	doc_986203247114_item	3537887	et	4	main
on	doc_986203247114_item	3537888	et	4	main
ikka	doc_986203247114_item	3537889	et	4	main
vaja	doc_986203247114_item	3537890	et	4	main
rohkem	doc_986203247114_item	3537891	et	4	main
õppivate	doc_986203247114_item	3537892	et	4	main
inimestega	doc_986203247114_item	3537893	et	3	main
suhelda	doc_986203247114_item	3537894	et	4	main
elu	doc_986203247114_item	3537727	et	4	main
huvitavad	doc_986203247114_item	3537742	et	4	main
arvan	doc_986203247114_item	3537747	et	3	main
mul	doc_986203247114_item	3537749	et	3	main
ei	doc_986203247114_item	3537750	et	4	main
ole	doc_986203247114_item	3537751	et	4	main
millegagi	doc_986203247114_item	3537752	et	4	main
võrrelda	doc_986203247114_item	3537753	et	4	main
need	doc_986203247114_item	3537754	et	3	main
on	doc_986203247114_item	3537755	et	4	main
nii	doc_986203247114_item	3537748	et	3	main
nüüd	doc_986203247114_item	3537759	et	4	main
loomade	doc_986203247114_item	3537779	et	4	main
topiseid	doc_986203247114_item	3537780	et	3	main
meistrite	doc_986203247114_item	3537781	et	3	main
huvitav	doc_986203247114_item	3537789	et	4	main
oli	doc_986203247114_item	3537790	et	3	main
olla	doc_986203247114_item	3537797	et	3	main
tuleb	doc_986203247114_item	3537800	et	3	main
tulla	doc_986203247114_item	3537802	et	3	main
on	doc_986203247114_item	3537812	et	4	main
et	doc_986203247114_item	3537819	et	3	main
ka	doc_986203247114_item	3537822	et	3	main
see	doc_986203247114_item	3537826	et	3	main
õppida	doc_986203247114_item	3537837	et	3	main
keelt	doc_986203247114_item	3537840	et	4	main
enne	doc_986203247114_item	3537848	et	4	main
olla	doc_986203247114_item	3537853	et	3	main
aga	doc_986203247114_item	3537863	et	3	main
ei	doc_986203247114_item	3537868	et	4	main
kiri	doc_600559928978_item	3537896	et	3	main
tuli	doc_986203247114_item	3537760	et	4	main
ette	doc_986203247114_item	3537761	et	4	main
ka	doc_986203247114_item	3537762	et	3	main
praktikaaeg	doc_986203247114_item	3537763	et	3	main
edu	doc_986203247114_item	3537766	et	4	main
asjaajamine	doc_986203247114_item	3537791	et	4	main
aga	doc_986203247114_item	3537792	et	3	main
kuidas	doc_986203247114_item	3537809	et	3	main
ma	doc_986203247114_item	3537817	et	3	main
olla	doc_986203247114_item	3537821	et	3	main
eesti	doc_986203247114_item	3537830	et	4	main
keelt	doc_986203247114_item	3537831	et	4	main
jooksul	doc_986203247114_item	3537847	et	4	main
võiks	doc_986203247114_item	3537851	et	4	main
olla	doc_986203247114_item	3537859	et	3	main
need	doc_986203247114_item	3537865	et	3	main
kursuse	doc_986203247114_item	3537870	et	3	main
on	doc_986203247114_item	3537872	et	4	main
väga	doc_986203247114_item	3537873	et	3	main
palju	doc_986203247114_item	3537874	et	4	main
eestlasest	doc_600559928978_item	3537899	et	3	main
sõbrale	doc_600559928978_item	3537900	et	3	main
et	doc_600559928978_item	3537901	et	3	main
käid	doc_600559928978_item	3537902	et	3	main
praegu	doc_600559928978_item	3537903	et	3	main
kursustel	doc_600559928978_item	3537904	et	3	main
ja	doc_600559928978_item	3537910	et	3	main
lähete	doc_600559928978_item	3537913	et	4	main
kirjuta	doc_600559928978_item	3537915	et	4	main
on	doc_600559928978_item	3537923	et	4	main
hakkad	doc_600559928978_item	3537928	et	3	main
sain	doc_600559928978_item	3537932	et	3	main
kätte	doc_600559928978_item	3537935	et	4	main
on	doc_600559928978_item	3537948	et	4	main
uus	doc_600559928978_item	3537949	et	3	main
uudis	doc_600559928978_item	3537950	et	3	main
praegu	doc_600559928978_item	3537951	et	3	main
ma	doc_600559928978_item	3537952	et	3	main
käin	doc_600559928978_item	3537953	et	3	main
kursustel	doc_600559928978_item	3537954	et	3	main
kursustel	doc_600559928978_item	3537955	et	3	main
nimi	doc_600559928978_item	3537956	et	3	main
on	doc_600559928978_item	3537957	et	4	main
üldse	doc_600559928978_item	3538000	et	3	main
inimeseidega	doc_600559928978_item	3538003	et	4	main
ma	doc_600559928978_item	3538008	et	3	main
töö	doc_600559928978_item	3538010	et	4	main
kiri	doc_600559928979_item	3538024	et	3	main
et	doc_600559928979_item	3538029	et	3	main
praegu	doc_600559928979_item	3538031	et	3	main
lähete	doc_600559928979_item	3538041	et	4	main
praktikale	doc_600559928979_item	3538042	et	3	main
kuhu	doc_600559928979_item	3538044	et	3	main
sa	doc_600559928979_item	3538045	et	3	main
mida	doc_600559928979_item	3538052	et	4	main
sa	doc_600559928979_item	3538053	et	3	main
anja	doc_600559928979_item	3538059	et	4	main
klienditeenindaja	doc_600559928979_item	3538078	et	4	main
raske	doc_600559928979_item	3538086	et	4	main
gramatika	doc_600559928979_item	3538089	et	4	main
kursusele	doc_600559928979_item	3538096	et	3	main
on	doc_600559928979_item	3538106	et	4	main
firmas	doc_600559928979_item	3538108	et	3	main
töötan	doc_600559928979_item	3538111	et	3	main
hea	doc_600559928979_item	3538120	et	4	main
arvutitehnika	doc_600559928979_item	3538124	et	4	main
ja	doc_600559928979_item	3538132	et	3	main
rakvere	doc_600559928979_item	3538134	et	4	main
tänaval	doc_600559928979_item	3538135	et	4	main
asub	doc_600559928979_item	3538136	et	3	main
12	doc_600559928979_item	3538137	et	2	main
soovin	doc_600559928979_item	3538148	et	3	main
ootan	doc_600559928979_item	3538150	et	3	main
sinult	doc_600559928979_item	3538152	et	3	main
tervitades	doc_600559928979_item	3538154	et	3	main
õpid	doc_600559928980_item	3538173	et	4	main
ja	doc_600559928980_item	3538174	et	3	main
mida	doc_600559928980_item	3538188	et	4	main
sa	doc_600559928980_item	3538189	et	3	main
on	doc_600559928980_item	3538199	et	4	main
kõik	doc_600559928980_item	3538208	et	4	main
mul	doc_600559928980_item	3538213	et	3	main
et	doc_986203247114_item	3537825	et	3	main
kes	doc_986203247114_item	3537828	et	4	main
inglise	doc_986203247114_item	3537839	et	4	main
väga	doc_986203247114_item	3537841	et	3	main
praktika	doc_986203247114_item	3537849	et	4	main
informatsiooni	doc_986203247114_item	3537855	et	4	main
saada	doc_986203247114_item	3537856	et	4	main
võib	doc_986203247114_item	3537858	et	3	main
sellest	doc_986203247114_item	3537864	et	4	main
küsimusi	doc_986203247114_item	3537875	et	4	main
tea	doc_986203247114_item	3537881	et	4	main
kas	doc_986203247114_item	3537882	et	3	main
varsti	doc_600559928978_item	3537912	et	3	main
praktikale	doc_600559928978_item	3537918	et	3	main
mis	doc_600559928978_item	3537920	et	4	main
see	doc_600559928978_item	3537922	et	3	main
tegema	doc_600559928978_item	3537927	et	3	main
kõik	doc_600559928978_item	3537944	et	4	main
nagu	doc_600559928978_item	3537945	et	3	main
vanasti	doc_600559928978_item	3537946	et	3	main
ainult	doc_600559928978_item	3537947	et	4	main
ja	doc_600559928978_item	3537997	et	3	main
armastan	doc_600559928978_item	3538002	et	3	main
teha	doc_600559928978_item	3538004	et	3	main
praktika	doc_600559928978_item	3538006	et	4	main
võin	doc_600559928978_item	3538009	et	3	main
saada	doc_600559928978_item	3538011	et	4	main
aga	doc_600559928978_item	3538012	et	3	main
kuidas	doc_600559928978_item	3538013	et	3	main
läheb	doc_600559928978_item	3538014	et	3	main
kirjuta	doc_600559928978_item	3538015	et	4	main
sõbrale	doc_600559928979_item	3538028	et	3	main
käid	doc_600559928979_item	3538030	et	3	main
kirjuta	doc_600559928979_item	3538033	et	4	main
kursustel	doc_600559928979_item	3538036	et	3	main
praktikale	doc_600559928979_item	3538046	et	3	main
mis	doc_600559928979_item	3538048	et	4	main
firma	doc_600559928979_item	3538049	et	4	main
on	doc_600559928979_item	3538051	et	4	main
21112004	doc_600559928979_item	3538057	et	2	main
on	doc_600559928979_item	3538068	et	4	main
hästi	doc_600559928979_item	3538070	et	3	main
kelle	doc_600559928979_item	3538084	et	4	main
erite	doc_600559928979_item	3538085	et	4	main
kelle	doc_600559928979_item	3538093	et	4	main
praktika	doc_600559928979_item	3538105	et	4	main
ordi	doc_600559928979_item	3538109	et	4	main
ma	doc_600559928979_item	3538110	et	3	main
seal	doc_600559928979_item	3538113	et	4	main
kirjuta	doc_600559928979_item	3538114	et	4	main
sõbranna	doc_600559928978_item	3538021	et	4	main
eesnimi	doc_600559928978_item	3538022	et	3	main
kirjuta	doc_600559928978_item	3537897	et	4	main
kirjuta	doc_600559928978_item	3537905	et	4	main
mida	doc_600559928978_item	3537906	et	4	main
praktikale	doc_600559928978_item	3537914	et	3	main
kuhu	doc_600559928978_item	3537916	et	3	main
mida	doc_600559928978_item	3537924	et	4	main
sa	doc_600559928978_item	3537925	et	3	main
marika	doc_600559928978_item	3537930	et	4	main
ma	doc_600559928978_item	3537931	et	3	main
klienditeenindaja	doc_600559928978_item	3537958	et	4	main
me	doc_600559928978_item	3537959	et	4	main
õppime	doc_600559928978_item	3537960	et	4	main
arvutit	doc_600559928978_item	3537961	et	3	main
eesti	doc_600559928978_item	3537962	et	4	main
keelt	doc_600559928978_item	3537963	et	4	main
asjaajamist	doc_600559928978_item	3537964	et	4	main
ja	doc_600559928978_item	3537965	et	3	main
muud	doc_600559928978_item	3537966	et	4	main
varsti	doc_600559928978_item	3537967	et	3	main
ma	doc_600559928978_item	3537968	et	3	main
lähen	doc_600559928978_item	3537969	et	3	main
praktikale	doc_600559928978_item	3537970	et	3	main
firmas	doc_600559928978_item	3537971	et	3	main
viru	doc_600559928978_item	3537972	et	4	main
keemia	doc_600559928978_item	3537973	et	4	main
grupp	doc_600559928978_item	3537974	et	3	main
seal	doc_600559928978_item	3537975	et	4	main
ma	doc_600559928978_item	3537976	et	3	main
hakkan	doc_600559928978_item	3537977	et	3	main
arvutiga	doc_600559928978_item	3537978	et	4	main
tegema	doc_600559928978_item	3537979	et	3	main
minu	doc_600559928978_item	3537980	et	3	main
töökohustused	doc_600559928978_item	3537981	et	3	main
on	doc_600559928978_item	3537982	et	4	main
klienditeedamine	doc_600559928978_item	3537983	et	4	main
ka	doc_600559928978_item	3537984	et	3	main
mulle	doc_600559928978_item	3537985	et	4	main
meeldib	doc_600559928978_item	3537986	et	3	main
selle	doc_600559928978_item	3537987	et	4	main
tööd	doc_600559928978_item	3537988	et	4	main
ja	doc_600559928978_item	3537989	et	3	main
selle	doc_600559928978_item	3537990	et	4	main
firma	doc_600559928978_item	3537991	et	4	main
ka	doc_600559928978_item	3537992	et	3	main
ma	doc_600559928978_item	3537993	et	3	main
oli	doc_600559928978_item	3537994	et	3	main
juba	doc_600559928978_item	3537995	et	3	main
seal	doc_600559928978_item	3537996	et	4	main
kõik	doc_600559928978_item	3537999	et	4	main
vaatasin	doc_600559928978_item	3537998	et	3	main
arvan	doc_600559928978_item	3538005	et	3	main
või	doc_600559928978_item	3538016	et	4	main
helista	doc_600559928978_item	3538017	et	4	main
mulle	doc_600559928978_item	3538018	et	4	main
nägesemini	doc_600559928978_item	3538019	et	4	main
sinu	doc_600559928978_item	3538020	et	3	main
eestlasest	doc_600559928979_item	3538027	et	3	main
sa	doc_600559928979_item	3538035	et	3	main
kirjuta	doc_600559928979_item	3538043	et	4	main
lähed	doc_600559928979_item	3538047	et	3	main
seal	doc_600559928979_item	3538054	et	4	main
tegema	doc_600559928979_item	3538055	et	3	main
hakkad	doc_600559928979_item	3538056	et	3	main
kätte	doc_600559928979_item	3538063	et	4	main
ma	doc_600559928979_item	3538090	et	3	main
eesti	doc_600559928979_item	3538092	et	4	main
lõpetasin	doc_600559928979_item	3538097	et	3	main
see	doc_600559928979_item	3538107	et	3	main
kliendit	doc_600559928979_item	3538119	et	4	main
firma	doc_600559928979_item	3538128	et	4	main
ord	doc_600559928979_item	3538129	et	4	main
ja	doc_600559928979_item	3538147	et	3	main
teele	doc_600559928979_item	3538149	et	3	main
kas	doc_600559928979_item	3538151	et	3	main
vastust	doc_600559928979_item	3538153	et	4	main
oma	doc_600559928980_item	3538162	et	4	main
praegu	doc_600559928980_item	3538167	et	3	main
kirjuta	doc_600559928980_item	3538169	et	4	main
mida	doc_600559928980_item	3538170	et	4	main
sa	doc_600559928980_item	3538171	et	3	main
kursustel	doc_600559928980_item	3538172	et	3	main
lähete	doc_600559928980_item	3538177	et	4	main
praktikale	doc_600559928980_item	3538182	et	3	main
mis	doc_600559928980_item	3538184	et	4	main
marika	doc_600559928980_item	3538194	et	4	main
aega	doc_600559928980_item	3538201	et	4	main
ma	doc_600559928980_item	3538202	et	3	main
kirjutan	doc_600559928980_item	3538203	et	3	main
sulle	doc_600559928980_item	3538204	et	3	main
kirja	doc_600559928980_item	3538205	et	4	main
mul	doc_600559928980_item	3538206	et	3	main
on	doc_600559928980_item	3538207	et	4	main
hea	doc_600559928980_item	3538212	et	4	main
ma	doc_600559928980_item	3538216	et	3	main
õpin	doc_600559928980_item	3538217	et	3	main
keele	doc_600559928980_item	3538219	et	4	main
kursustel	doc_600559928980_item	3538220	et	3	main
rühmas	doc_600559928980_item	3538221	et	4	main
kõigel	doc_600559928980_item	3538226	et	4	main
on	doc_600559928980_item	3538227	et	4	main
eestlasest	doc_600559928983_item	3538287	et	3	main
käid	doc_600559928983_item	3538290	et	3	main
kirjuta	doc_600559928983_item	3538303	et	4	main
praktikale	doc_600559928983_item	3538306	et	3	main
on	doc_600559928983_item	3538311	et	4	main
sa	doc_600559928983_item	3538313	et	3	main
tegema	doc_600559928983_item	3538315	et	3	main
reet	doc_600559928983_item	3538318	et	4	main
otsustasin	doc_600559928983_item	3538319	et	3	main
sulle	doc_600559928983_item	3538320	et	3	main
kirjutada	doc_600559928983_item	3538321	et	3	main
selgeks	doc_600559928983_item	3538344	et	3	main
nüüd	doc_600559928983_item	3538350	et	4	main
arvuti	doc_600559928983_item	3538351	et	4	main
juures	doc_600559928983_item	3538352	et	4	main
õpetas	doc_600559928983_item	3538359	et	3	main
kuidas	doc_600559928983_item	3538366	et	3	main
kasutama	doc_600559928983_item	3538368	et	3	main
veel	doc_600559928983_item	3538370	et	4	main
kursustel	doc_600559928983_item	3538371	et	3	main
oli	doc_600559928983_item	3538372	et	3	main
selline	doc_600559928983_item	3538373	et	4	main
kirjuta	doc_600559928979_item	3538025	et	4	main
sain	doc_600559928979_item	3538060	et	3	main
kirja	doc_600559928979_item	3538062	et	4	main
kuidas	doc_600559928979_item	3538064	et	3	main
koik	doc_600559928979_item	3538069	et	4	main
eesti	doc_600559928979_item	3538083	et	4	main
mulle	doc_600559928979_item	3538088	et	4	main
õppin	doc_600559928979_item	3538091	et	4	main
arvuti	doc_600559928979_item	3538094	et	4	main
pärast	doc_600559928979_item	3538095	et	4	main
kiviõlis	doc_600559928979_item	3538098	et	4	main
ja	doc_600559928979_item	3538099	et	3	main
et	doc_600559928979_item	3538100	et	3	main
varsti	doc_600559928979_item	3538101	et	3	main
lähete	doc_600559928979_item	3538102	et	4	main
praktikale	doc_600559928979_item	3538103	et	3	main
minul	doc_600559928979_item	3538104	et	3	main
oli	doc_600559928979_item	3538112	et	3	main
müüma	doc_600559928979_item	3538121	et	3	main
sisseoste	doc_600559928979_item	3538122	et	3	main
tegema	doc_600559928979_item	3538123	et	3	main
suurem	doc_600559928979_item	3538125	et	4	main
killometris	doc_600559928979_item	3538138	et	4	main
kiri	doc_600559928980_item	3538160	et	3	main
käid	doc_600559928980_item	3538166	et	3	main
varsti	doc_600559928980_item	3538176	et	3	main
kirjuta	doc_600559928980_item	3538179	et	4	main
sa	doc_600559928980_item	3538181	et	3	main
lähed	doc_600559928980_item	3538183	et	3	main
tere	doc_600559928980_item	3538193	et	3	main
kirja	doc_600559928980_item	3538196	et	4	main
eest	doc_600559928980_item	3538197	et	4	main
mul	doc_600559928980_item	3538198	et	3	main
on	doc_600559928980_item	3538214	et	4	main
eesti	doc_600559928980_item	3538218	et	4	main
on	doc_600559928980_item	3538261	et	4	main
õpib	doc_600559928979_item	3538077	et	3	main
kiviõlis	doc_600559928979_item	3538079	et	4	main
tahaksin	doc_600559928979_item	3538080	et	3	main
ära	doc_600559928979_item	3538081	et	4	main
õppida	doc_600559928979_item	3538082	et	3	main
on	doc_600559928979_item	3538087	et	4	main
oma	doc_600559928979_item	3538115	et	4	main
vihikud	doc_600559928979_item	3538116	et	3	main
ma	doc_600559928979_item	3538117	et	3	main
soovin	doc_600559928979_item	3538118	et	3	main
on	doc_600559928979_item	3538126	et	4	main
jõhvis	doc_600559928979_item	3538131	et	3	main
aadres	doc_600559928979_item	3538133	et	4	main
orule	doc_600559928979_item	3538140	et	3	main
sõita	doc_600559928979_item	3538141	et	3	main
17	doc_600559928979_item	3538143	et	2	main
lõpetan	doc_600559928979_item	3538146	et	3	main
et	doc_600559928980_item	3538175	et	3	main
kuhu	doc_600559928980_item	3538180	et	3	main
seal	doc_600559928980_item	3538190	et	4	main
tegema	doc_600559928980_item	3538191	et	3	main
hakkad	doc_600559928980_item	3538192	et	3	main
vaba	doc_600559928980_item	3538200	et	4	main
korras	doc_600559928980_item	3538209	et	4	main
tervis	doc_600559928980_item	3538210	et	3	main
on	doc_600559928980_item	3538222	et	4	main
12	doc_600559928980_item	3538223	et	2	main
oma	doc_600559928983_item	3538286	et	4	main
kursustel	doc_600559928983_item	3538292	et	3	main
mida	doc_600559928983_item	3538294	et	4	main
õpid	doc_600559928983_item	3538297	et	4	main
ja	doc_600559928983_item	3538298	et	3	main
et	doc_600559928983_item	3538299	et	3	main
kuhu	doc_600559928983_item	3538304	et	3	main
sa	doc_600559928983_item	3538305	et	3	main
see	doc_600559928983_item	3538310	et	3	main
hakkad	doc_600559928983_item	3538316	et	3	main
erilist	doc_600559928983_item	3538323	et	4	main
ei	doc_600559928983_item	3538325	et	4	main
olnud	doc_600559928983_item	3538347	et	4	main
tunnen	doc_600559928983_item	3538353	et	3	main
ennast	doc_600559928983_item	3538354	et	4	main
ja	doc_600559928983_item	3538365	et	3	main
psühholoogia	doc_600559928983_item	3538376	et	4	main
väga	doc_600559928983_item	3538377	et	3	main
palju	doc_600559928983_item	3538380	et	4	main
teada	doc_600559928983_item	3538382	et	3	main
ennast	doc_600559928983_item	3538384	et	4	main
harjutusi	doc_600559928983_item	3538419	et	4	main
praktika	doc_600559928983_item	3538422	et	4	main
mina	doc_600559928983_item	3538423	et	4	main
lähen	doc_600559928983_item	3538424	et	3	main
praktikale	doc_600559928983_item	3538427	et	3	main
et	doc_600559928983_item	3538429	et	3	main
õppin	doc_600559928983_item	3538431	et	4	main
midagi	doc_600559928983_item	3538432	et	4	main
ka	doc_600559928983_item	3538443	et	3	main
klieditajad	doc_600559928979_item	3538127	et	4	main
asub	doc_600559928979_item	3538130	et	3	main
enne	doc_600559928979_item	3538139	et	4	main
bussiga	doc_600559928979_item	3538142	et	3	main
sellega	doc_600559928979_item	3538144	et	3	main
ma	doc_600559928979_item	3538145	et	3	main
sõpranna	doc_600559928979_item	3538155	et	4	main
head	doc_600559928979_item	3538156	et	4	main
aega	doc_600559928979_item	3538157	et	4	main
eesnimi	doc_600559928979_item	3538158	et	3	main
kirjutame	doc_600559928980_item	3538241	et	3	main
kirjad	doc_600559928980_item	3538242	et	4	main
varsti	doc_600559928980_item	3538243	et	3	main
me	doc_600559928980_item	3538244	et	4	main
läheme	doc_600559928980_item	3538245	et	3	main
ma	doc_600559928980_item	3538247	et	3	main
praktikale	doc_600559928980_item	3538246	et	3	main
lähen	doc_600559928980_item	3538248	et	3	main
praktikale	doc_600559928980_item	3538249	et	3	main
kaupluses	doc_600559928980_item	3538250	et	3	main
see	doc_600559928980_item	3538251	et	3	main
on	doc_600559928980_item	3538252	et	4	main
astar	doc_600559928980_item	3538254	et	4	main
seal	doc_600559928980_item	3538255	et	4	main
ma	doc_600559928980_item	3538256	et	3	main
hakkan	doc_600559928980_item	3538257	et	3	main
firma	doc_600559928980_item	3538253	et	4	main
müüjana	doc_600559928980_item	3538258	et	4	main
töötama	doc_600559928980_item	3538259	et	3	main
kirjuta	doc_600559928980_item	3538161	et	4	main
eestlasest	doc_600559928980_item	3538163	et	3	main
sõbrale	doc_600559928980_item	3538164	et	3	main
et	doc_600559928980_item	3538165	et	3	main
kursustel	doc_600559928980_item	3538168	et	3	main
praktikale	doc_600559928980_item	3538178	et	3	main
firma	doc_600559928980_item	3538185	et	4	main
see	doc_600559928980_item	3538186	et	3	main
on	doc_600559928980_item	3538187	et	4	main
tänan	doc_600559928980_item	3538195	et	3	main
on	doc_600559928980_item	3538211	et	4	main
uue	doc_600559928980_item	3538228	et	3	main
nimid	doc_600559928980_item	3538229	et	4	main
rühmas	doc_600559928980_item	3538230	et	4	main
on	doc_600559928980_item	3538231	et	4	main
eraldavaid	doc_600559928980_item	3538232	et	4	main
inimesed	doc_600559928980_item	3538233	et	3	main
kursustele	doc_600559928980_item	3538234	et	3	main
me	doc_600559928980_item	3538235	et	4	main
õppime	doc_600559928980_item	3538236	et	4	main
sõnad	doc_600559928980_item	3538237	et	4	main
räägime	doc_600559928980_item	3538238	et	3	main
sõbra	doc_600559928980_item	3538239	et	3	main
sõbraga	doc_600559928980_item	3538240	et	3	main
kõik	doc_600559928980_item	3538262	et	4	main
uudist	doc_600559928980_item	3538263	et	3	main
kirjuta	doc_600559928980_item	3538264	et	4	main
kuidas	doc_600559928980_item	3538265	et	3	main
sulle	doc_600559928980_item	3538266	et	3	main
lähed	doc_600559928980_item	3538267	et	3	main
mis	doc_600559928980_item	3538268	et	4	main
on	doc_600559928980_item	3538269	et	4	main
uudist	doc_600559928980_item	3538270	et	3	main
mis	doc_600559928980_item	3538271	et	4	main
tervis	doc_600559928980_item	3538272	et	3	main
on	doc_600559928980_item	3538273	et	4	main
tahaksin	doc_600559928980_item	3538274	et	3	main
sullega	doc_600559928980_item	3538275	et	4	main
kohtuda	doc_600559928980_item	3538276	et	3	main
sõida	doc_600559928980_item	3538277	et	4	main
mulle	doc_600559928980_item	3538278	et	4	main
külla	doc_600559928980_item	3538279	et	4	main
kohtume	doc_600559928980_item	3538280	et	3	main
varsti	doc_600559928980_item	3538281	et	3	main
eesnimi	doc_600559928980_item	3538282	et	3	main
sõbrale	doc_600559928983_item	3538288	et	3	main
et	doc_600559928983_item	3538289	et	3	main
lähete	doc_600559928983_item	3538301	et	4	main
uudist	doc_600559928980_item	3538215	et	3	main
õppelased	doc_600559928980_item	3538224	et	4	main
meil	doc_600559928980_item	3538225	et	4	main
need	doc_600559928980_item	3538260	et	3	main
kiri	doc_600559928983_item	3538284	et	3	main
praegu	doc_600559928983_item	3538291	et	3	main
kirjuta	doc_600559928983_item	3538293	et	4	main
sa	doc_600559928983_item	3538295	et	3	main
praktikale	doc_600559928983_item	3538302	et	3	main
lähed	doc_600559928983_item	3538307	et	3	main
kirja	doc_600559928983_item	3538322	et	4	main
ole	doc_600559928983_item	3538326	et	4	main
õpida	doc_600559928983_item	3538345	et	4	main
ei	doc_600559928983_item	3538346	et	4	main
sest	doc_600559928983_item	3538356	et	4	main
mind	doc_600559928983_item	3538360	et	4	main
juurde	doc_600559928983_item	3538362	et	4	main
igasuguseid	doc_600559928983_item	3538363	et	3	main
neid	doc_600559928983_item	3538367	et	4	main
pean	doc_600559928983_item	3538369	et	4	main
saan	doc_600559928983_item	3538383	et	4	main
meile	doc_600559928983_item	3538411	et	4	main
eesti	doc_600559928983_item	3538413	et	4	main
keele	doc_600559928983_item	3538414	et	4	main
tundides	doc_600559928983_item	3538415	et	3	main
tegime	doc_600559928983_item	3538416	et	3	main
raamatu	doc_600559928983_item	3538425	et	4	main
jaoks	doc_600559928983_item	3538442	et	4	main
midagi	doc_600559928983_item	3538444	et	4	main
oma	doc_600559928984_item	3538462	et	4	main
kirjuta	doc_600559928984_item	3538479	et	4	main
kuhu	doc_600559928984_item	3538480	et	3	main
sa	doc_600559928984_item	3538481	et	3	main
praktikale	doc_600559928984_item	3538482	et	3	main
lähed	doc_600559928984_item	3538483	et	3	main
vastust	doc_600559928984_item	3538498	et	4	main
sind	doc_600559928984_item	3538499	et	4	main
kursustel	doc_600559928984_item	3538507	et	3	main
on	doc_600559928984_item	3538509	et	4	main
väga	doc_600559928984_item	3538510	et	3	main
huvitav	doc_600559928984_item	3538511	et	4	main
kursustel	doc_600559928984_item	3538512	et	3	main
ma	doc_600559928984_item	3538513	et	3	main
meil	doc_600559928984_item	3538517	et	4	main
selle	doc_600559928984_item	3538519	et	4	main
aja	doc_600559928984_item	3538520	et	4	main
arvutiõpetus	doc_600559928984_item	3538527	et	3	main
konsum	doc_600559928984_item	3538549	et	4	main
kiri	doc_600559928985_item	3538578	et	3	main
praegu	doc_600559928985_item	3538585	et	3	main
kuhu	doc_600559928985_item	3538598	et	3	main
mis	doc_600559928985_item	3538602	et	4	main
hakkad	doc_600559928985_item	3538610	et	3	main
ma	doc_600559928985_item	3538614	et	3	main
õhtul	doc_600559928985_item	3538668	et	3	main
kui	doc_600559928985_item	3538691	et	3	main
raske	doc_600559928985_item	3538693	et	4	main
ma	doc_600559928985_item	3538694	et	3	main
olen	doc_600559928985_item	3538695	et	3	main
tulevukus	doc_600559928985_item	3538699	et	4	main
sain	doc_600559928985_item	3538701	et	3	main
töö	doc_600559928985_item	3538704	et	4	main
tervitusi	doc_600559928985_item	3538705	et	4	main
et	doc_600559928983_item	3538447	et	3	main
kõik	doc_600559928983_item	3538448	et	4	main
läheb	doc_600559928983_item	3538449	et	3	main
hästi	doc_600559928983_item	3538450	et	3	main
ps	doc_600559928983_item	3538451	et	4	main
siin	doc_600559928983_item	3538452	et	4	main
kursustel	doc_600559928983_item	3538453	et	3	main
sain	doc_600559928983_item	3538454	et	3	main
uusi	doc_600559928983_item	3538455	et	3	main
tuttavaid	doc_600559928983_item	3538456	et	3	main
lugupidamisega	doc_600559928983_item	3538457	et	3	main
eesnimi	doc_600559928983_item	3538458	et	3	main
kirjuta	doc_600559928983_item	3538285	et	4	main
kursustel	doc_600559928983_item	3538296	et	3	main
varsti	doc_600559928983_item	3538300	et	3	main
mis	doc_600559928983_item	3538308	et	4	main
mida	doc_600559928983_item	3538312	et	4	main
seal	doc_600559928983_item	3538314	et	4	main
tere	doc_600559928983_item	3538317	et	3	main
nagu	doc_600559928983_item	3538324	et	3	main
midagi	doc_600559928983_item	3538327	et	4	main
aga	doc_600559928983_item	3538328	et	3	main
siiski	doc_600559928983_item	3538329	et	4	main
kain	doc_600559928983_item	3538330	et	3	main
klienditeenindaja	doc_600559928983_item	3538331	et	4	main
kursustel	doc_600559928983_item	3538332	et	3	main
kursused	doc_600559928983_item	3538333	et	3	main
on	doc_600559928983_item	3538334	et	4	main
väga	doc_600559928983_item	3538335	et	3	main
huvitavad	doc_600559928983_item	3538336	et	4	main
kõigepealt	doc_600559928983_item	3538337	et	3	main
õpisin	doc_600559928983_item	3538338	et	4	main
arvuti	doc_600559928983_item	3538339	et	4	main
selgeks	doc_600559928983_item	3538340	et	3	main
ammu	doc_600559928983_item	3538341	et	4	main
tahtsin	doc_600559928983_item	3538342	et	3	main
arvuti	doc_600559928983_item	3538343	et	4	main
firma	doc_600559928983_item	3538309	et	4	main
kodus	doc_600559928983_item	3538357	et	4	main
õppeaine	doc_600559928983_item	3538374	et	4	main
nagu	doc_600559928983_item	3538375	et	3	main
rahulikult	doc_600559928983_item	3538385	et	4	main
analüüsida	doc_600559928983_item	3538386	et	3	main
milline	doc_600559928983_item	3538387	et	3	main
kõigile	doc_600559928983_item	3538412	et	4	main
varsti	doc_600559928983_item	3538420	et	3	main
hakkab	doc_600559928983_item	3538421	et	3	main
poodi	doc_600559928983_item	3538426	et	4	main
rohkem	doc_600559928983_item	3538435	et	4	main
klientidega	doc_600559928983_item	3538436	et	3	main
suhelda	doc_600559928983_item	3538437	et	4	main
raamatu	doc_600559928983_item	3538438	et	4	main
kirjuta	doc_600559928984_item	3538461	et	4	main
käid	doc_600559928984_item	3538466	et	3	main
mida	doc_600559928984_item	3538470	et	4	main
õpid	doc_600559928984_item	3538473	et	4	main
ja	doc_600559928984_item	3538474	et	3	main
et	doc_600559928984_item	3538475	et	3	main
varsti	doc_600559928984_item	3538476	et	3	main
lähete	doc_600559928984_item	3538477	et	4	main
praktikale	doc_600559928984_item	3538478	et	3	main
käin	doc_600559928984_item	3538506	et	3	main
klienditeenindaja	doc_600559928984_item	3538508	et	4	main
jooksul	doc_600559928984_item	3538521	et	4	main
arvan	doc_600559928984_item	3538538	et	3	main
sobiks	doc_600559928984_item	3538541	et	4	main
seal	doc_600559928984_item	3538550	et	4	main
lihtsalt	doc_600559928983_item	3538348	et	4	main
võimalust	doc_600559928983_item	3538349	et	3	main
julgelt	doc_600559928983_item	3538355	et	4	main
poja	doc_600559928983_item	3538358	et	4	main
veel	doc_600559928983_item	3538361	et	4	main
programme	doc_600559928983_item	3538364	et	3	main
huvitav	doc_600559928983_item	3538378	et	4	main
ja	doc_600559928983_item	3538379	et	3	main
sain	doc_600559928983_item	3538381	et	3	main
arvan	doc_600559928983_item	3538428	et	3	main
seal	doc_600559928983_item	3538430	et	4	main
enda	doc_600559928983_item	3538441	et	4	main
loodan	doc_600559928983_item	3538446	et	3	main
kiri	doc_600559928984_item	3538460	et	3	main
kirjuta	doc_600559928984_item	3538469	et	4	main
sa	doc_600559928984_item	3538471	et	3	main
kursustel	doc_600559928984_item	3538472	et	3	main
huvitab	doc_600559928984_item	3538500	et	3	main
ma	doc_600559928984_item	3538502	et	3	main
praegu	doc_600559928984_item	3538504	et	3	main
inimestega	doc_600559928984_item	3538516	et	3	main
olid	doc_600559928984_item	3538518	et	4	main
meeldis	doc_600559928984_item	3538526	et	3	main
alused	doc_600559928984_item	3538533	et	4	main
varsti	doc_600559928984_item	3538534	et	3	main
ma	doc_600559928984_item	3538537	et	3	main
ma	doc_600559928984_item	3538540	et	3	main
teenindada	doc_600559928984_item	3538542	et	3	main
on	doc_600559928984_item	3538551	et	4	main
palju	doc_600559928984_item	3538552	et	4	main
osakondi	doc_600559928984_item	3538553	et	4	main
ja	doc_600559928984_item	3538554	et	3	main
kirjuta	doc_600559928985_item	3538579	et	4	main
praktikale	doc_600559928985_item	3538600	et	3	main
mida	doc_600559928985_item	3538606	et	4	main
seal	doc_600559928985_item	3538608	et	4	main
ma	doc_600559928985_item	3538618	et	3	main
aga	doc_600559928985_item	3538629	et	3	main
töö	doc_600559928985_item	3538677	et	4	main
nõub	doc_600559928985_item	3538678	et	4	main
täpsust	doc_600559928985_item	3538679	et	4	main
ja	doc_600559928985_item	3538680	et	3	main
kiirust	doc_600559928985_item	3538681	et	4	main
ma	doc_600559928985_item	3538682	et	3	main
kuuldsin	doc_600559928985_item	3538683	et	4	main
et	doc_600559928985_item	3538684	et	3	main
peremees	doc_600559928985_item	3538685	et	4	main
on	doc_600559928985_item	3538686	et	4	main
tore	doc_600559928985_item	3538687	et	3	main
inimene	doc_600559928985_item	3538688	et	3	main
ja	doc_600559928985_item	3538689	et	3	main
aitasid	doc_600559928985_item	3538690	et	4	main
ma	doc_600559928983_item	3538388	et	3	main
olen	doc_600559928983_item	3538389	et	3	main
ja	doc_600559928983_item	3538390	et	3	main
palju	doc_600559928983_item	3538391	et	4	main
muud	doc_600559928983_item	3538392	et	4	main
kursustel	doc_600559928983_item	3538393	et	3	main
oli	doc_600559928983_item	3538394	et	3	main
veel	doc_600559928983_item	3538395	et	4	main
selliseid	doc_600559928983_item	3538396	et	4	main
õppeained	doc_600559928983_item	3538397	et	3	main
nagu	doc_600559928983_item	3538398	et	3	main
asjaajamine	doc_600559928983_item	3538399	et	4	main
esmaabi	doc_600559928983_item	3538400	et	4	main
seaduseandlus	doc_600559928983_item	3538401	et	3	main
kaubanduses	doc_600559928983_item	3538402	et	3	main
veel	doc_600559928983_item	3538403	et	4	main
õpisime	doc_600559928983_item	3538404	et	4	main
eesti	doc_600559928983_item	3538405	et	4	main
keelt	doc_600559928983_item	3538406	et	4	main
see	doc_600559928983_item	3538407	et	3	main
on	doc_600559928983_item	3538408	et	4	main
väga	doc_600559928983_item	3538409	et	3	main
vajalik	doc_600559928983_item	3538410	et	3	main
igasugusi	doc_600559928983_item	3538417	et	4	main
teste	doc_600559928983_item	3538418	et	3	main
juurde	doc_600559928983_item	3538433	et	4	main
õpin	doc_600559928983_item	3538434	et	3	main
müümist	doc_600559928983_item	3538439	et	4	main
ja	doc_600559928983_item	3538440	et	3	main
ma	doc_600559928983_item	3538445	et	3	main
sõbrale	doc_600559928984_item	3538464	et	3	main
et	doc_600559928984_item	3538465	et	3	main
kursustel	doc_600559928984_item	3538468	et	3	main
mis	doc_600559928984_item	3538484	et	4	main
kohe	doc_600559928984_item	3538497	et	4	main
millega	doc_600559928984_item	3538501	et	3	main
tegelen	doc_600559928984_item	3538503	et	3	main
ma	doc_600559928984_item	3538505	et	3	main
uute	doc_600559928984_item	3538515	et	3	main
erinevad	doc_600559928984_item	3538522	et	4	main
lektorid	doc_600559928984_item	3538523	et	3	main
mulle	doc_600559928984_item	3538524	et	4	main
väga	doc_600559928984_item	3538525	et	3	main
eesti	doc_600559928984_item	3538528	et	4	main
keel	doc_600559928984_item	3538529	et	4	main
turunduse	doc_600559928984_item	3538530	et	3	main
ja	doc_600559928984_item	3538531	et	3	main
lähen	doc_600559928984_item	3538535	et	3	main
et	doc_600559928984_item	3538539	et	3	main
palju	doc_600559928984_item	3538555	et	4	main
eestlasest	doc_600559928985_item	3538581	et	3	main
et	doc_600559928985_item	3538583	et	3	main
õpid	doc_600559928985_item	3538591	et	4	main
ja	doc_600559928985_item	3538592	et	3	main
et	doc_600559928985_item	3538593	et	3	main
sa	doc_600559928985_item	3538599	et	3	main
lähed	doc_600559928985_item	3538601	et	3	main
kirja	doc_600559928985_item	3538617	et	4	main
tööta	doc_600559928985_item	3538628	et	4	main
minu	doc_600559928985_item	3538669	et	3	main
ma	doc_600559928985_item	3538697	et	3	main
poes	doc_600559928985_item	3538703	et	3	main
eestlasest	doc_600559928984_item	3538463	et	3	main
praegu	doc_600559928984_item	3538467	et	3	main
firma	doc_600559928984_item	3538485	et	4	main
see	doc_600559928984_item	3538486	et	3	main
on	doc_600559928984_item	3538487	et	4	main
mida	doc_600559928984_item	3538488	et	4	main
sa	doc_600559928984_item	3538489	et	3	main
seal	doc_600559928984_item	3538490	et	4	main
tegema	doc_600559928984_item	3538491	et	3	main
hakkad	doc_600559928984_item	3538492	et	3	main
tere	doc_600559928984_item	3538493	et	3	main
terje	doc_600559928984_item	3538494	et	4	main
kirjutan	doc_600559928984_item	3538495	et	3	main
sulle	doc_600559928984_item	3538496	et	3	main
tutvusin	doc_600559928984_item	3538514	et	3	main
reklaami	doc_600559928984_item	3538532	et	4	main
praktikale	doc_600559928984_item	3538536	et	3	main
inimesi	doc_600559928984_item	3538543	et	4	main
ma	doc_600559928984_item	3538544	et	3	main
tahan	doc_600559928984_item	3538545	et	3	main
minna	doc_600559928984_item	3538546	et	3	main
praktikale	doc_600559928984_item	3538547	et	3	main
kauplusesse	doc_600559928984_item	3538548	et	4	main
kaupa	doc_600559928984_item	3538556	et	4	main
ma	doc_600559928984_item	3538557	et	3	main
tahan	doc_600559928984_item	3538558	et	3	main
teenindada	doc_600559928984_item	3538559	et	3	main
kliente	doc_600559928984_item	3538560	et	3	main
soovitada	doc_600559928984_item	3538561	et	3	main
sobivaid	doc_600559928984_item	3538562	et	4	main
asju	doc_600559928984_item	3538563	et	3	main
ja	doc_600559928984_item	3538564	et	3	main
toiduaineid	doc_600559928984_item	3538565	et	3	main
olla	doc_600559928984_item	3538566	et	3	main
kliendidele	doc_600559928984_item	3538567	et	4	main
kasulik	doc_600559928984_item	3538568	et	3	main
sellega	doc_600559928984_item	3538569	et	3	main
lõpetan	doc_600559928984_item	3538570	et	3	main
kirjuta	doc_600559928984_item	3538571	et	4	main
millega	doc_600559928984_item	3538572	et	3	main
sa	doc_600559928984_item	3538573	et	3	main
tegeled	doc_600559928984_item	3538574	et	3	main
nägemiseni	doc_600559928984_item	3538575	et	4	main
eesnimi	doc_600559928984_item	3538576	et	3	main
oma	doc_600559928985_item	3538580	et	4	main
käid	doc_600559928985_item	3538584	et	3	main
kursustel	doc_600559928985_item	3538586	et	3	main
mida	doc_600559928985_item	3538588	et	4	main
kursustel	doc_600559928985_item	3538590	et	3	main
varsti	doc_600559928985_item	3538594	et	3	main
lähete	doc_600559928985_item	3538595	et	4	main
praktikale	doc_600559928985_item	3538596	et	3	main
firma	doc_600559928985_item	3538603	et	4	main
see	doc_600559928985_item	3538604	et	3	main
on	doc_600559928985_item	3538605	et	4	main
kairi	doc_600559928985_item	3538612	et	4	main
sain	doc_600559928985_item	3538615	et	3	main
on	doc_600559928985_item	3538619	et	4	main
sul	doc_600559928985_item	3538621	et	3	main
kõik	doc_600559928985_item	3538623	et	4	main
5	doc_600559928985_item	3538667	et	2	main
on	doc_600559928985_item	3538671	et	4	main
vormistan	doc_600559928985_item	3538672	et	3	main
dokumendid	doc_600559928985_item	3538673	et	3	main
ja	doc_600559928985_item	3538674	et	3	main
vastu	doc_600559928985_item	3538675	et	3	main
kaupad	doc_600559928985_item	3538676	et	4	main
on	doc_600559928985_item	3538692	et	4	main
kõigile	doc_600559928985_item	3538706	et	4	main
eesnimi	doc_600559928985_item	3538707	et	3	main
pood	doc_600559928985_item	3538657	et	4	main
minu	doc_600559928985_item	3538658	et	3	main
tööpäev	doc_600559928985_item	3538659	et	3	main
algab	doc_600559928985_item	3538660	et	3	main
kell	doc_600559928985_item	3538661	et	3	main
9	doc_600559928985_item	3538662	et	2	main
hommikust	doc_600559928985_item	3538663	et	4	main
ja	doc_600559928985_item	3538664	et	3	main
lõpeb	doc_600559928985_item	3538665	et	4	main
kell	doc_600559928985_item	3538666	et	3	main
sõbrale	doc_600559928985_item	3538582	et	3	main
kirjuta	doc_600559928985_item	3538587	et	4	main
sa	doc_600559928985_item	3538589	et	3	main
kirjuta	doc_600559928985_item	3538597	et	4	main
sa	doc_600559928985_item	3538607	et	3	main
tegema	doc_600559928985_item	3538609	et	3	main
tere	doc_600559928985_item	3538611	et	3	main
teisipäeval	doc_600559928985_item	3538613	et	3	main
sinu	doc_600559928985_item	3538616	et	3	main
rahulik	doc_600559928985_item	3538620	et	3	main
on	doc_600559928985_item	3538622	et	4	main
hästi	doc_600559928985_item	3538624	et	3	main
praegu	doc_600559928985_item	3538625	et	3	main
ma	doc_600559928985_item	3538626	et	3	main
ei	doc_600559928985_item	3538627	et	4	main
tööhoiveamet	doc_600559928985_item	3538630	et	4	main
pakusid	doc_600559928985_item	3538631	et	4	main
klienditeenindaja	doc_600559928985_item	3538632	et	4	main
kursus	doc_600559928985_item	3538633	et	3	main
ma	doc_600559928985_item	3538634	et	3	main
sõidan	doc_600559928985_item	3538635	et	3	main
iga	doc_600559928985_item	3538636	et	4	main
päev	doc_600559928985_item	3538637	et	3	main
bussiga	doc_600559928985_item	3538638	et	3	main
kivilisse	doc_600559928985_item	3538639	et	4	main
kursusel	doc_600559928985_item	3538640	et	3	main
ma	doc_600559928985_item	3538641	et	3	main
õpin	doc_600559928985_item	3538642	et	3	main
eesti	doc_600559928985_item	3538643	et	4	main
keel	doc_600559928985_item	3538644	et	4	main
ja	doc_600559928985_item	3538645	et	3	main
arvuti	doc_600559928985_item	3538646	et	4	main
varsti	doc_600559928985_item	3538647	et	3	main
mul	doc_600559928985_item	3538648	et	3	main
on	doc_600559928985_item	3538649	et	4	main
praktika	doc_600559928985_item	3538650	et	4	main
ma	doc_600559928985_item	3538651	et	3	main
leidsin	doc_600559928985_item	3538652	et	3	main
praktika	doc_600559928985_item	3538653	et	4	main
koht	doc_600559928985_item	3538654	et	3	main
väike	doc_600559928985_item	3538655	et	4	main
toidu	doc_600559928985_item	3538656	et	3	main
kohustused	doc_600559928985_item	3538670	et	4	main
loodan	doc_600559928985_item	3538698	et	3	main
ma	doc_600559928985_item	3538700	et	3	main
selle	doc_600559928985_item	3538702	et	4	main
rahul	doc_600559928985_item	3538696	et	4	main
kirjuta	doc_600559928987_item	3538841	et	4	main
et	doc_600559928987_item	3538845	et	3	main
praegu	doc_600559928987_item	3538847	et	3	main
kirjuta	doc_600559928987_item	3538849	et	4	main
sa	doc_600559928987_item	3538851	et	3	main
praktikale	doc_600559928987_item	3538862	et	3	main
kuidas	doc_600559928987_item	3538883	et	3	main
mul	doc_600559928987_item	3538886	et	3	main
väga	doc_600559928987_item	3538888	et	3	main
ma	doc_600559928987_item	3538894	et	3	main
kursusel	doc_600559928987_item	3538896	et	3	main
septembrist	doc_600559928987_item	3538898	et	3	main
jaanuarni	doc_600559928987_item	3538900	et	4	main
arvutiõpetus	doc_600559928987_item	3538909	et	3	main
selle	doc_600559928987_item	3538939	et	4	main
kirjuta	doc_600559928988_item	3538968	et	4	main
kirjuta	doc_600559928988_item	3538976	et	4	main
sa	doc_600559928988_item	3538978	et	3	main
kuhu	doc_600559928988_item	3538987	et	3	main
firma	doc_600559928988_item	3538992	et	4	main
tere	doc_600559928988_item	3539000	et	3	main
kirjutan	doc_600559928988_item	3539003	et	3	main
lähen	doc_600559928988_item	3539008	et	3	main
esimesel	doc_600559928988_item	3539010	et	3	main
ma	doc_600559928988_item	3539013	et	3	main
eesti	doc_600559928988_item	3539015	et	4	main
keel	doc_600559928988_item	3539016	et	4	main
on	doc_600559928988_item	3539019	et	4	main
paräst	doc_600559928988_item	3539028	et	4	main
on	doc_600559928988_item	3539065	et	4	main
keel	doc_600559928988_item	3539073	et	4	main
ma	doc_600559928988_item	3539074	et	3	main
ma	doc_600559928988_item	3539088	et	3	main
proovi	doc_600559928988_item	3539089	et	4	main
et	doc_600559928988_item	3539090	et	3	main
või	doc_600559928988_item	3539097	et	4	main
normaalset	doc_600559928988_item	3539098	et	3	main
tulge	doc_600559928988_item	3539099	et	3	main
homme	doc_600559928988_item	3539100	et	3	main
kuud	doc_600559928988_item	3539112	et	4	main
praktikasse	doc_600559928988_item	3539117	et	4	main
missugune	doc_600559928988_item	3539135	et	3	main
sinu	doc_600559928988_item	3539143	et	3	main
väga	doc_600559928988_item	3539149	et	3	main
praktikasse	doc_600559928988_item	3539152	et	4	main
21112003	doc_600559928988_item	3539167	et	2	main
sinu	doc_600559928988_item	3539168	et	3	main
sõber	doc_600559928988_item	3539169	et	3	main
et	doc_600559928989_item	3539186	et	3	main
kuhu	doc_600559928989_item	3539191	et	3	main
kiri	doc_600559928987_item	3538840	et	3	main
mida	doc_600559928987_item	3538850	et	4	main
õpid	doc_600559928987_item	3538853	et	4	main
firma	doc_600559928987_item	3538865	et	4	main
see	doc_600559928987_item	3538866	et	3	main
mida	doc_600559928987_item	3538868	et	4	main
kuidas	doc_600559928987_item	3538876	et	3	main
sinu	doc_600559928987_item	3538884	et	3	main
palju	doc_600559928987_item	3538889	et	4	main
uudiseid	doc_600559928987_item	3538890	et	3	main
kõige	doc_600559928987_item	3538891	et	4	main
olnud	doc_600559928987_item	3538902	et	4	main
huvitavad	doc_600559928987_item	3538904	et	4	main
kursused	doc_600559928987_item	3538905	et	3	main
seal	doc_600559928987_item	3538906	et	4	main
sõbanna	doc_600559928987_item	3538963	et	4	main
eesnimi	doc_600559928987_item	3538964	et	3	main
kiri	doc_600559928988_item	3538967	et	3	main
et	doc_600559928988_item	3538972	et	3	main
mida	doc_600559928988_item	3538977	et	4	main
õpid	doc_600559928988_item	3538980	et	4	main
ja	doc_600559928988_item	3538981	et	3	main
et	doc_600559928988_item	3538982	et	3	main
varsti	doc_600559928988_item	3538983	et	3	main
lähed	doc_600559928988_item	3538990	et	3	main
sõbra	doc_600559928988_item	3539001	et	3	main
ja	doc_600559928988_item	3539017	et	3	main
et	doc_600559928988_item	3539027	et	3	main
pahe	doc_600559928988_item	3539063	et	4	main
see	doc_600559928988_item	3539064	et	3	main
olen	doc_600559928988_item	3539075	et	3	main
väga	doc_600559928988_item	3539076	et	3	main
rõmus	doc_600559928988_item	3539077	et	4	main
see	doc_600559928988_item	3539078	et	3	main
firma	doc_600559928988_item	3539081	et	4	main
mul	doc_600559928988_item	3539083	et	3	main
klienditeenindaja	doc_600559928988_item	3539095	et	4	main
ot	doc_600559928988_item	3539102	et	4	main
minu	doc_600559928988_item	3539105	et	3	main
pean	doc_600559928988_item	3539119	et	4	main
kes	doc_600559928988_item	3539122	et	4	main
ja	doc_600559928988_item	3539124	et	3	main
riiule	doc_600559928988_item	3539137	et	3	main
saan	doc_600559928988_item	3539141	et	4	main
auto	doc_600559928988_item	3539144	et	4	main
bmw	doc_600559928988_item	3539145	et	4	main
535	doc_600559928988_item	3539146	et	2	main
olid	doc_600559928988_item	3539154	et	4	main
kuud	doc_600559928988_item	3539156	et	4	main
mulle	doc_600559928988_item	3539166	et	4	main
kiri	doc_600559928989_item	3539171	et	3	main
et	doc_600559928989_item	3539176	et	3	main
õpid	doc_600559928989_item	3539184	et	4	main
kirjuta	doc_600559928989_item	3539190	et	4	main
praktikale	doc_600559928989_item	3539193	et	3	main
tegema	doc_600559928989_item	3539202	et	3	main
mida	doc_600559928989_item	3539209	et	4	main
varsti	doc_600559928989_item	3539250	et	3	main
piletimüja	doc_600559928989_item	3539256	et	4	main
oma	doc_600559928987_item	3538842	et	4	main
käid	doc_600559928987_item	3538846	et	3	main
kirjuta	doc_600559928987_item	3538859	et	4	main
kuhu	doc_600559928987_item	3538860	et	3	main
sa	doc_600559928987_item	3538861	et	3	main
seal	doc_600559928987_item	3538870	et	4	main
tegema	doc_600559928987_item	3538871	et	3	main
hakkad	doc_600559928987_item	3538872	et	3	main
tere	doc_600559928987_item	3538873	et	3	main
kallis	doc_600559928987_item	3538874	et	4	main
kuidas	doc_600559928987_item	3538879	et	3	main
tervis	doc_600559928987_item	3538881	et	3	main
töö	doc_600559928987_item	3538885	et	4	main
on	doc_600559928987_item	3538887	et	4	main
et	doc_600559928987_item	3538893	et	3	main
me	doc_600559928987_item	3538907	et	4	main
õppisime	doc_600559928987_item	3538908	et	3	main
eestlasest	doc_600559928987_item	3538843	et	3	main
kursustel	doc_600559928987_item	3538848	et	3	main
kursustel	doc_600559928987_item	3538852	et	3	main
ja	doc_600559928987_item	3538854	et	3	main
et	doc_600559928987_item	3538855	et	3	main
varsti	doc_600559928987_item	3538856	et	3	main
lähete	doc_600559928987_item	3538857	et	4	main
praktikale	doc_600559928987_item	3538858	et	3	main
mis	doc_600559928987_item	3538864	et	4	main
sõbranna	doc_600559928987_item	3538875	et	4	main
käsi	doc_600559928987_item	3538877	et	4	main
käib	doc_600559928987_item	3538878	et	3	main
on	doc_600559928987_item	3538882	et	4	main
sõbrale	doc_600559928988_item	3538971	et	3	main
kursustel	doc_600559928988_item	3538975	et	3	main
praktikale	doc_600559928988_item	3538985	et	3	main
mis	doc_600559928988_item	3538991	et	4	main
see	doc_600559928988_item	3538993	et	3	main
on	doc_600559928988_item	3538994	et	4	main
mida	doc_600559928988_item	3538995	et	4	main
sa	doc_600559928988_item	3538996	et	3	main
ma	doc_600559928988_item	3539002	et	3	main
et	doc_600559928988_item	3539006	et	3	main
detsembris	doc_600559928988_item	3539011	et	3	main
õpin	doc_600559928988_item	3539014	et	3	main
arvan	doc_600559928988_item	3539026	et	3	main
ei	doc_600559928988_item	3539079	et	4	main
seal	doc_600559928988_item	3539082	et	4	main
on	doc_600559928988_item	3539093	et	4	main
amet	doc_600559928988_item	3539094	et	3	main
nii	doc_600559928988_item	3539103	et	3	main
praktika	doc_600559928988_item	3539106	et	4	main
kuni	doc_600559928988_item	3539107	et	3	main
jaanuaris	doc_600559928988_item	3539108	et	3	main
üks	doc_600559928988_item	3539109	et	3	main
ja	doc_600559928988_item	3539110	et	3	main
pool	doc_600559928988_item	3539111	et	4	main
muidugi	doc_600559928988_item	3539116	et	4	main
võta	doc_600559928988_item	3539123	et	4	main
peale	doc_600559928988_item	3539136	et	4	main
tunnen	doc_600559928987_item	3538921	et	3	main
palju-palju	doc_600559928987_item	3538922	et	4	main
uued	doc_600559928987_item	3538923	et	3	main
mis	doc_600559928987_item	3538924	et	4	main
tarvis	doc_600559928987_item	3538925	et	3	main
minul	doc_600559928987_item	3538926	et	3	main
elu	doc_600559928987_item	3538927	et	4	main
detsembril	doc_600559928987_item	3538928	et	3	main
me	doc_600559928987_item	3538929	et	4	main
tuleme	doc_600559928987_item	3538930	et	3	main
praktikal	doc_600559928987_item	3538931	et	3	main
veel	doc_600559928987_item	3538932	et	4	main
ma	doc_600559928987_item	3538933	et	3	main
ei	doc_600559928987_item	3538934	et	4	main
leidan	doc_600559928987_item	3538935	et	4	main
praktikat	doc_600559928987_item	3538936	et	3	main
ma	doc_600559928987_item	3538937	et	3	main
otsin	doc_600559928987_item	3538938	et	3	main
sõbrale	doc_600559928987_item	3538844	et	3	main
lähed	doc_600559928987_item	3538863	et	3	main
on	doc_600559928987_item	3538867	et	4	main
sa	doc_600559928987_item	3538869	et	3	main
sinu	doc_600559928987_item	3538880	et	3	main
tähtsam	doc_600559928987_item	3538892	et	4	main
käisin	doc_600559928987_item	3538895	et	3	main
klienditeenindajaks	doc_600559928987_item	3538897	et	3	main
kuni	doc_600559928987_item	3538899	et	3	main
see	doc_600559928987_item	3538901	et	3	main
väga	doc_600559928987_item	3538903	et	3	main
psüholoogia	doc_600559928987_item	3538910	et	4	main
protokoll	doc_600559928987_item	3538911	et	4	main
ja	doc_600559928987_item	3538912	et	3	main
etikett	doc_600559928987_item	3538913	et	3	main
esmaabi	doc_600559928987_item	3538914	et	4	main
meil	doc_600559928987_item	3538915	et	4	main
olid	doc_600559928987_item	3538916	et	4	main
juriist	doc_600559928987_item	3538917	et	4	main
õigusnõuandla	doc_600559928987_item	3538918	et	4	main
ma	doc_600559928987_item	3538919	et	3	main
ära	doc_600559928987_item	3538920	et	4	main
pärast	doc_600559928987_item	3538940	et	4	main
mulle	doc_600559928987_item	3538941	et	4	main
ei	doc_600559928987_item	3538942	et	4	main
andma	doc_600559928987_item	3538943	et	3	main
diplomi	doc_600559928987_item	3538944	et	3	main
hea	doc_600559928987_item	3538945	et	4	main
küll	doc_600559928987_item	3538946	et	4	main
minu	doc_600559928987_item	3538947	et	3	main
sõbranna	doc_600559928987_item	3538948	et	4	main
ma	doc_600559928987_item	3538949	et	3	main
lõpetan	doc_600559928987_item	3538950	et	3	main
heat	doc_600559928987_item	3538951	et	4	main
aega	doc_600559928987_item	3538952	et	4	main
ootan	doc_600559928987_item	3538953	et	3	main
sinu	doc_600559928987_item	3538954	et	3	main
kirja	doc_600559928987_item	3538955	et	4	main
ja	doc_600559928987_item	3538956	et	3	main
ootan	doc_600559928987_item	3538957	et	3	main
millal	doc_600559928987_item	3538958	et	3	main
sa	doc_600559928987_item	3538959	et	3	main
tuled	doc_600559928987_item	3538960	et	4	main
puhkuselt	doc_600559928987_item	3538961	et	4	main
sinu	doc_600559928987_item	3538962	et	3	main
21112003	doc_600559928987_item	3538965	et	2	main
eestlasest	doc_600559928988_item	3538970	et	3	main
käid	doc_600559928988_item	3538973	et	3	main
lähete	doc_600559928988_item	3538984	et	4	main
praktikale	doc_600559928988_item	3538989	et	3	main
tegema	doc_600559928988_item	3538998	et	3	main
leidma	doc_600559928988_item	3539005	et	3	main
ma	doc_600559928988_item	3539007	et	3	main
praktikasse	doc_600559928988_item	3539009	et	4	main
praegu	doc_600559928988_item	3539012	et	3	main
tana	doc_600559928988_item	3539018	et	4	main
reede	doc_600559928988_item	3539020	et	4	main
viimane	doc_600559928988_item	3539021	et	3	main
eesti	doc_600559928988_item	3539022	et	4	main
kui	doc_600559928988_item	3539067	et	3	main
sa	doc_600559928988_item	3539068	et	3	main
abistab	doc_600559928988_item	3539069	et	3	main
mind	doc_600559928988_item	3539070	et	4	main
õpetab	doc_600559928988_item	3539071	et	3	main
eesti	doc_600559928988_item	3539072	et	4	main
ma	doc_600559928988_item	3539130	et	3	main
pean	doc_600559928988_item	3539131	et	4	main
tead	doc_600559928988_item	3539132	et	4	main
millal	doc_600559928988_item	3539133	et	3	main
raamat	doc_600559928988_item	3539134	et	3	main
oma	doc_600559928988_item	3538969	et	4	main
praegu	doc_600559928988_item	3538974	et	3	main
kursustel	doc_600559928988_item	3538979	et	3	main
kirjuta	doc_600559928988_item	3538986	et	4	main
sa	doc_600559928988_item	3538988	et	3	main
seal	doc_600559928988_item	3538997	et	4	main
hakkad	doc_600559928988_item	3538999	et	3	main
aega	doc_600559928988_item	3539004	et	4	main
keele	doc_600559928988_item	3539023	et	4	main
tund	doc_600559928988_item	3539024	et	3	main
ma	doc_600559928988_item	3539025	et	3	main
kursus	doc_600559928988_item	3539029	et	3	main
ma	doc_600559928988_item	3539030	et	3	main
leidan	doc_600559928988_item	3539031	et	4	main
tööta	doc_600559928988_item	3539032	et	4	main
ma	doc_600559928988_item	3539033	et	3	main
ei	doc_600559928988_item	3539034	et	4	main
tea	doc_600559928988_item	3539035	et	4	main
kuhu	doc_600559928988_item	3539036	et	3	main
ma	doc_600559928988_item	3539037	et	3	main
läksima	doc_600559928988_item	3539038	et	4	main
töötan	doc_600559928988_item	3539039	et	3	main
aga	doc_600559928988_item	3539040	et	3	main
ma	doc_600559928988_item	3539041	et	3	main
loodan	doc_600559928988_item	3539042	et	3	main
et	doc_600559928988_item	3539043	et	3	main
see	doc_600559928988_item	3539044	et	3	main
tööta	doc_600559928988_item	3539045	et	4	main
on	doc_600559928988_item	3539046	et	4	main
meeldib	doc_600559928988_item	3539047	et	3	main
mulle	doc_600559928988_item	3539048	et	4	main
ma	doc_600559928988_item	3539049	et	3	main
ei	doc_600559928988_item	3539050	et	4	main
oska	doc_600559928988_item	3539051	et	4	main
eesti	doc_600559928988_item	3539052	et	4	main
keel	doc_600559928988_item	3539053	et	4	main
natukene	doc_600559928988_item	3539054	et	4	main
räägi	doc_600559928988_item	3539055	et	4	main
ja	doc_600559928988_item	3539056	et	3	main
kõik	doc_600559928988_item	3539057	et	4	main
aga	doc_600559928988_item	3539058	et	3	main
grammatika	doc_600559928988_item	3539059	et	4	main
ma	doc_600559928988_item	3539060	et	3	main
õpin	doc_600559928988_item	3539061	et	3	main
väga	doc_600559928988_item	3539062	et	3	main
raske	doc_600559928988_item	3539066	et	4	main
ole	doc_600559928988_item	3539080	et	4	main
on	doc_600559928988_item	3539084	et	4	main
üks	doc_600559928988_item	3539085	et	3	main
sõber	doc_600559928988_item	3539086	et	3	main
praktikast	doc_600559928988_item	3539087	et	4	main
raske	doc_600559928988_item	3539096	et	4	main
jah	doc_600559928988_item	3539104	et	3	main
veel	doc_600559928988_item	3539114	et	4	main
ah	doc_600559928988_item	3539115	et	3	main
kirjutama	doc_600559928988_item	3539120	et	3	main
inimesed	doc_600559928988_item	3539121	et	3	main
ära	doc_600559928988_item	3539125	et	4	main
anda	doc_600559928988_item	3539126	et	3	main
raamat	doc_600559928988_item	3539127	et	3	main
ja	doc_600559928988_item	3539128	et	3	main
millal	doc_600559928988_item	3539129	et	3	main
ka	doc_600559928988_item	3539139	et	3	main
ma	doc_600559928988_item	3539140	et	3	main
võta	doc_600559928988_item	3539142	et	4	main
mulle	doc_600559928988_item	3539148	et	4	main
tuleb	doc_600559928988_item	3539151	et	3	main
see	doc_600559928988_item	3539153	et	3	main
pärast	doc_600559928988_item	3539157	et	4	main
minu	doc_600559928988_item	3539158	et	3	main
auto	doc_600559928988_item	3539159	et	4	main
tagasi	doc_600559928988_item	3539160	et	3	main
remonditeenindus	doc_600559928988_item	3539161	et	3	main
okey	doc_600559928988_item	3539162	et	4	main
homseni	doc_600559928988_item	3539163	et	3	main
kursustel	doc_600559928989_item	3539183	et	3	main
varsti	doc_600559928989_item	3539187	et	3	main
lähed	doc_600559928989_item	3539194	et	3	main
hakkad	doc_600559928989_item	3539203	et	3	main
sa	doc_600559928989_item	3539210	et	3	main
hommikul	doc_600559928989_item	3539246	et	3	main
lõpevad	doc_600559928989_item	3539248	et	4	main
ma	doc_600559928989_item	3539251	et	3	main
ujulas	doc_600559928989_item	3539257	et	3	main
koolis	doc_600559928989_item	3539259	et	4	main
see	doc_600559928989_item	3539260	et	3	main
töö	doc_600559928989_item	3539261	et	4	main
asub	doc_600559928989_item	3539262	et	3	main
mis	doc_600559928988_item	3539091	et	4	main
see	doc_600559928988_item	3539092	et	3	main
külla	doc_600559928988_item	3539101	et	4	main
mis	doc_600559928988_item	3539113	et	4	main
ma	doc_600559928988_item	3539118	et	3	main
kule	doc_600559928988_item	3539138	et	4	main
sellepärast	doc_600559928988_item	3539147	et	3	main
kaugeselt	doc_600559928988_item	3539150	et	4	main
üks	doc_600559928988_item	3539155	et	3	main
nägemist	doc_600559928988_item	3539164	et	4	main
helistage	doc_600559928988_item	3539165	et	3	main
kirjuta	doc_600559928989_item	3539172	et	4	main
käid	doc_600559928989_item	3539177	et	3	main
kirjuta	doc_600559928989_item	3539180	et	4	main
mida	doc_600559928989_item	3539181	et	4	main
sa	doc_600559928989_item	3539182	et	3	main
praktikale	doc_600559928989_item	3539189	et	3	main
firma	doc_600559928989_item	3539196	et	4	main
on	doc_600559928989_item	3539198	et	4	main
mida	doc_600559928989_item	3539199	et	4	main
sa	doc_600559928989_item	3539200	et	3	main
meire	doc_600559928989_item	3539205	et	4	main
ja	doc_600559928989_item	3539247	et	3	main
õhtul	doc_600559928989_item	3539249	et	3	main
eesti	doc_600559928989_item	3539258	et	4	main
väga	doc_600559928989_item	3539266	et	3	main
kell	doc_600559928989_item	3539271	et	3	main
2100	doc_600559928989_item	3539274	et	2	main
õhtul	doc_600559928989_item	3539276	et	3	main
ei	doc_600559928989_item	3539278	et	4	main
see	doc_600559928989_item	3539286	et	3	main
hommikul	doc_600559928989_item	3539288	et	3	main
kodutööd	doc_600559928989_item	3539290	et	4	main
keel	doc_600559928989_item	3539296	et	4	main
natuke	doc_600559928989_item	3539298	et	4	main
räägin	doc_600559928989_item	3539299	et	3	main
varsti	doc_600559928989_item	3539300	et	3	main
on	doc_600559928989_item	3539301	et	4	main
pühi	doc_600559928989_item	3539304	et	4	main
vaba	doc_600559928989_item	3539308	et	4	main
ajal	doc_600559928989_item	3539309	et	4	main
reisi	doc_600559928991_item	3539317	et	4	main
sellest	doc_600559928991_item	3539320	et	4	main
oma	doc_600559928991_item	3539322	et	4	main
sõbrale	doc_600559928991_item	3539324	et	3	main
ja	doc_600559928991_item	3539327	et	3	main
kuhu	doc_600559928991_item	3539328	et	3	main
millega	doc_600559928991_item	3539332	et	3	main
pikkus	doc_600559928991_item	3539345	et	4	main
järve	doc_600559928991_item	3539351	et	4	main
viimase	doc_600559928991_item	3539359	et	3	main
ümbes	doc_600559928991_item	3539381	et	4	main
te	doc_600559928992_item	3539420	et	4	main
plaanite	doc_600559928992_item	3539421	et	3	main
kiri	doc_600559928992_item	3539426	et	3	main
eestlasest	doc_600559928992_item	3539428	et	3	main
sõbrale	doc_600559928992_item	3539429	et	3	main
millal	doc_600559928992_item	3539431	et	3	main
te	doc_600559928992_item	3539434	et	4	main
sõita	doc_600559928992_item	3539435	et	3	main
soovite	doc_600559928992_item	3539436	et	3	main
millega	doc_600559928992_item	3539437	et	3	main
reisite	doc_600559928992_item	3539438	et	3	main
kus	doc_600559928992_item	3539439	et	3	main
ööbite	doc_600559928992_item	3539440	et	3	main
kui	doc_600559928992_item	3539441	et	3	main
maksab	doc_600559928992_item	3539444	et	3	main
nõutav	doc_600559928992_item	3539449	et	4	main
1306	doc_600559928992_item	3539454	et	2	main
tere	doc_600559928992_item	3539455	et	3	main
väga	doc_600559928992_item	3539463	et	3	main
et	doc_600559928992_item	3539466	et	3	main
kallis	doc_600559928992_item	3539507	et	4	main
kiri	doc_600559928993_item	3539542	et	3	main
reisi	doc_600559928993_item	3539545	et	4	main
venemaale	doc_600559928993_item	3539546	et	4	main
kirjutage	doc_600559928993_item	3539547	et	3	main
te	doc_600559928993_item	3539557	et	4	main
sõita	doc_600559928993_item	3539558	et	3	main
soovite	doc_600559928993_item	3539559	et	3	main
maksab	doc_600559928993_item	3539567	et	3	main
kirja	doc_600559928993_item	3539571	et	4	main
lähen	doc_600559928989_item	3539252	et	3	main
praktikale	doc_600559928989_item	3539253	et	3	main
oma	doc_600559928989_item	3539173	et	4	main
eestlasest	doc_600559928989_item	3539174	et	3	main
sõbrale	doc_600559928989_item	3539175	et	3	main
praegu	doc_600559928989_item	3539178	et	3	main
kursustel	doc_600559928989_item	3539179	et	3	main
ja	doc_600559928989_item	3539185	et	3	main
lähete	doc_600559928989_item	3539188	et	4	main
seal	doc_600559928989_item	3539201	et	4	main
tere	doc_600559928989_item	3539204	et	3	main
elad	doc_600559928989_item	3539208	et	3	main
teed	doc_600559928989_item	3539211	et	4	main
kas	doc_600559928989_item	3539212	et	3	main
sa	doc_600559928989_item	3539213	et	3	main
veel	doc_600559928989_item	3539214	et	4	main
õpid	doc_600559928989_item	3539215	et	4	main
või	doc_600559928989_item	3539216	et	4	main
lõpenud	doc_600559928989_item	3539217	et	4	main
see	doc_600559928989_item	3539218	et	3	main
kesk-eri	doc_600559928989_item	3539219	et	4	main
kool	doc_600559928989_item	3539220	et	4	main
kuidas	doc_600559928989_item	3539221	et	3	main
teie	doc_600559928989_item	3539222	et	4	main
tervis	doc_600559928989_item	3539223	et	3	main
mina	doc_600559928989_item	3539224	et	4	main
ka	doc_600559928989_item	3539225	et	3	main
lõpetama	doc_600559928989_item	3539226	et	4	main
õppesid	doc_600559928989_item	3539227	et	4	main
ma	doc_600559928989_item	3539228	et	3	main
õpisin	doc_600559928989_item	3539229	et	4	main
klienditeenindaja	doc_600559928989_item	3539230	et	4	main
kursusel	doc_600559928989_item	3539231	et	3	main
see	doc_600559928989_item	3539232	et	3	main
kursus	doc_600559928989_item	3539233	et	3	main
oli	doc_600559928989_item	3539234	et	3	main
kiviõlis	doc_600559928989_item	3539235	et	4	main
ma	doc_600559928989_item	3539236	et	3	main
õpisin	doc_600559928989_item	3539237	et	4	main
eesti	doc_600559928989_item	3539238	et	4	main
keel	doc_600559928989_item	3539239	et	4	main
arvuti	doc_600559928989_item	3539240	et	4	main
esmaabi	doc_600559928989_item	3539241	et	4	main
ja	doc_600559928989_item	3539242	et	3	main
sa	doc_600559928989_item	3539192	et	3	main
mis	doc_600559928989_item	3539195	et	4	main
see	doc_600559928989_item	3539197	et	3	main
kuidas	doc_600559928989_item	3539206	et	3	main
sa	doc_600559928989_item	3539207	et	3	main
psühholoogia	doc_600559928989_item	3539243	et	4	main
kursus	doc_600559928989_item	3539244	et	3	main
ole	doc_600559928989_item	3539279	et	4	main
vaba	doc_600559928989_item	3539280	et	4	main
aeg	doc_600559928989_item	3539281	et	3	main
aga	doc_600559928989_item	3539282	et	3	main
tööaeg	doc_600559928989_item	3539287	et	3	main
palju	doc_600559928989_item	3539289	et	4	main
ma	doc_600559928989_item	3539291	et	3	main
ei	doc_600559928989_item	3539292	et	4	main
valde	doc_600559928989_item	3539293	et	3	main
hästi	doc_600559928989_item	3539294	et	3	main
kiri	doc_600559928991_item	3539314	et	3	main
kiri	doc_600559928991_item	3539321	et	3	main
kirjutage	doc_600559928991_item	3539325	et	3	main
millal	doc_600559928991_item	3539326	et	3	main
te	doc_600559928991_item	3539329	et	4	main
sõita	doc_600559928991_item	3539330	et	3	main
soovite	doc_600559928991_item	3539331	et	3	main
see	doc_600559928991_item	3539338	et	3	main
sõna	doc_600559928991_item	3539348	et	4	main
kohtla	doc_600559928991_item	3539350	et	4	main
soovin	doc_600559928991_item	3539370	et	3	main
sõidan	doc_600559928991_item	3539375	et	3	main
juulis	doc_600559928991_item	3539377	et	3	main
buusiga	doc_600559928991_item	3539378	et	4	main
pilet	doc_600559928991_item	3539379	et	3	main
maksab	doc_600559928991_item	3539380	et	3	main
kirjutage	doc_600559928992_item	3539424	et	3	main
kirjutage	doc_600559928992_item	3539430	et	3	main
ja	doc_600559928992_item	3539432	et	3	main
kuhu	doc_600559928992_item	3539433	et	3	main
kohtades	doc_600559928992_item	3539446	et	3	main
umbes	doc_600559928992_item	3539451	et	4	main
nora	doc_600559928992_item	3539457	et	4	main
aitäh	doc_600559928992_item	3539458	et	3	main
tore	doc_600559928992_item	3539465	et	3	main
sul	doc_600559928992_item	3539467	et	3	main
piletid	doc_600559928992_item	3539502	et	3	main
nad	doc_600559928992_item	3539503	et	3	main
väga	doc_600559928992_item	3539506	et	3	main
sest	doc_600559928992_item	3539508	et	4	main
ostsin	doc_600559928992_item	3539510	et	3	main
internetis	doc_600559928992_item	3539511	et	4	main
ma	doc_600559928992_item	3539512	et	3	main
plaanite	doc_600559928993_item	3539544	et	3	main
kus	doc_600559928993_item	3539562	et	3	main
ööbite	doc_600559928993_item	3539563	et	3	main
palju	doc_600559928993_item	3539565	et	4	main
millistes	doc_600559928993_item	3539568	et	3	main
moskvas	doc_600559928993_item	3539613	et	4	main
novgorodisse	doc_600559928993_item	3539625	et	4	main
stardib	doc_600559928993_item	3539627	et	3	main
päeva	doc_600559928993_item	3539634	et	4	main
algavad	doc_600559928989_item	3539245	et	4	main
ma	doc_600559928989_item	3539254	et	3	main
olen	doc_600559928989_item	3539255	et	3	main
kiviolis	doc_600559928989_item	3539263	et	4	main
töökoht	doc_600559928989_item	3539264	et	3	main
rahulik	doc_600559928989_item	3539267	et	3	main
ujula	doc_600559928989_item	3539268	et	4	main
töö	doc_600559928989_item	3539269	et	4	main
õhtul	doc_600559928989_item	3539270	et	3	main
kuni	doc_600559928989_item	3539273	et	3	main
meeldib	doc_600559928989_item	3539285	et	3	main
aga	doc_600559928989_item	3539297	et	3	main
head	doc_600559928989_item	3539303	et	4	main
ma	doc_600559928989_item	3539305	et	3	main
sulle	doc_600559928989_item	3539307	et	3	main
te	doc_600559928991_item	3539315	et	4	main
reisite	doc_600559928991_item	3539333	et	3	main
kui	doc_600559928991_item	3539336	et	3	main
kirja	doc_600559928991_item	3539343	et	4	main
nõutav	doc_600559928991_item	3539344	et	4	main
13062005	doc_600559928991_item	3539349	et	2	main
armas	doc_600559928991_item	3539353	et	3	main
anu	doc_600559928991_item	3539355	et	4	main
kätte	doc_600559928991_item	3539357	et	4	main
ma	doc_600559928991_item	3539369	et	3	main
peteerburgis	doc_600559928991_item	3539373	et	4	main
krooni	doc_600559928991_item	3539383	et	4	main
ma	doc_600559928991_item	3539384	et	3	main
ööbin	doc_600559928991_item	3539385	et	3	main
oma	doc_600559928991_item	3539386	et	4	main
sugulased	doc_600559928991_item	3539387	et	3	main
kiri	doc_600559928992_item	3539419	et	3	main
sellest	doc_600559928992_item	3539425	et	4	main
see	doc_600559928992_item	3539443	et	3	main
millistes	doc_600559928992_item	3539445	et	3	main
kirja	doc_600559928992_item	3539448	et	4	main
80	doc_600559928992_item	3539452	et	2	main
sõna	doc_600559928992_item	3539453	et	4	main
seda	doc_600559928992_item	3539462	et	3	main
ammu	doc_600559928992_item	3539464	et	4	main
ei	doc_600559928992_item	3539504	et	4	main
ole	doc_600559928992_item	3539505	et	4	main
on	doc_600559928989_item	3539265	et	4	main
1600	doc_600559928989_item	3539272	et	2	main
väga	doc_600559928989_item	3539284	et	3	main
eesti	doc_600559928989_item	3539295	et	4	main
jõulupidu	doc_600559928989_item	3539302	et	4	main
helistan	doc_600559928989_item	3539306	et	3	main
plaanite	doc_600559928991_item	3539316	et	3	main
kirjutage	doc_600559928991_item	3539319	et	3	main
kus	doc_600559928991_item	3539334	et	3	main
millistes	doc_600559928991_item	3539340	et	3	main
peatute	doc_600559928991_item	3539342	et	4	main
80	doc_600559928991_item	3539347	et	2	main
sõbranna	doc_600559928991_item	3539354	et	4	main
on	doc_600559928991_item	3539367	et	4	main
puhkus	doc_600559928991_item	3539368	et	3	main
venemaale	doc_600559928991_item	3539372	et	4	main
ma	doc_600559928991_item	3539374	et	3	main
peteerburgis	doc_600559928991_item	3539376	et	4	main
venemaale	doc_600559928992_item	3539423	et	4	main
palju	doc_600559928992_item	3539442	et	4	main
peatute	doc_600559928992_item	3539447	et	4	main
pikkus	doc_600559928992_item	3539450	et	4	main
kirja	doc_600559928992_item	3539459	et	4	main
ootasin	doc_600559928992_item	3539461	et	3	main
me	doc_600559928992_item	3539496	et	4	main
vastust	doc_600559928992_item	3539540	et	4	main
sellest	doc_600559928993_item	3539548	et	4	main
kiri	doc_600559928993_item	3539549	et	3	main
80	doc_600559928993_item	3539575	et	2	main
kätte	doc_600559928993_item	3539581	et	4	main
huvitavat	doc_600559928993_item	3539607	et	4	main
ja	doc_600559928993_item	3539614	et	3	main
kohti	doc_600559928993_item	3539647	et	4	main
sellepärast	doc_600559928989_item	3539275	et	3	main
mul	doc_600559928989_item	3539277	et	3	main
mulle	doc_600559928989_item	3539283	et	4	main
head	doc_600559928989_item	3539310	et	4	main
aega	doc_600559928989_item	3539311	et	4	main
eesnimi	doc_600559928989_item	3539312	et	3	main
on	doc_600559928991_item	3539395	et	4	main
palju	doc_600559928991_item	3539396	et	4	main
ja	doc_600559928991_item	3539398	et	3	main
ilusaid	doc_600559928991_item	3539399	et	3	main
kohad	doc_600559928991_item	3539400	et	4	main
ma	doc_600559928991_item	3539401	et	3	main
tahan	doc_600559928991_item	3539402	et	3	main
huuvitavaid	doc_600559928991_item	3539397	et	4	main
jalutada	doc_600559928991_item	3539403	et	3	main
tanaval	doc_600559928991_item	3539404	et	4	main
lähen	doc_600559928991_item	3539405	et	3	main
muuseumis	doc_600559928991_item	3539406	et	3	main
järgmine	doc_600559928991_item	3539407	et	3	main
kirja	doc_600559928991_item	3539408	et	4	main
ma	doc_600559928991_item	3539409	et	3	main
kirjutan	doc_600559928991_item	3539410	et	3	main
teile	doc_600559928991_item	3539411	et	4	main
ma	doc_600559928991_item	3539413	et	3	main
mida	doc_600559928991_item	3539412	et	4	main
vaatasin	doc_600559928991_item	3539414	et	3	main
head	doc_600559928991_item	3539415	et	4	main
aega	doc_600559928991_item	3539416	et	4	main
eesnimi	doc_600559928991_item	3539417	et	3	main
venemaale	doc_600559928991_item	3539318	et	4	main
eestlasest	doc_600559928991_item	3539323	et	3	main
ööbite	doc_600559928991_item	3539335	et	3	main
palju	doc_600559928991_item	3539337	et	4	main
maksab	doc_600559928991_item	3539339	et	3	main
kohtades	doc_600559928991_item	3539341	et	3	main
umbes	doc_600559928991_item	3539346	et	4	main
tere	doc_600559928991_item	3539352	et	3	main
sain	doc_600559928991_item	3539356	et	3	main
sinu	doc_600559928991_item	3539358	et	3	main
kirja	doc_600559928991_item	3539360	et	4	main
ja	doc_600559928991_item	3539361	et	3	main
kohe	doc_600559928991_item	3539362	et	4	main
kirjutan	doc_600559928991_item	3539363	et	3	main
vastuse	doc_600559928991_item	3539364	et	3	main
mul	doc_600559928991_item	3539365	et	3	main
suvel	doc_600559928991_item	3539366	et	3	main
reisi	doc_600559928991_item	3539371	et	4	main
saada	doc_600559928991_item	3539382	et	4	main
peteerburgis	doc_600559928991_item	3539388	et	4	main
meil	doc_600559928991_item	3539389	et	4	main
elan	doc_600559928991_item	3539390	et	3	main
vanaema	doc_600559928991_item	3539391	et	4	main
ja	doc_600559928991_item	3539392	et	3	main
vanaisa	doc_600559928991_item	3539393	et	4	main
peteerburgis	doc_600559928991_item	3539394	et	4	main
tahan	doc_600559928992_item	3539513	et	3	main
puhata	doc_600559928992_item	3539514	et	4	main
3	doc_600559928992_item	3539515	et	2	main
nädalat	doc_600559928992_item	3539516	et	3	main
me	doc_600559928992_item	3539517	et	4	main
reesirverisime	doc_600559928992_item	3539518	et	4	main
üks	doc_600559928992_item	3539519	et	3	main
kahetoaline	doc_600559928992_item	3539520	et	4	main
number	doc_600559928992_item	3539521	et	3	main
hoteelis	doc_600559928992_item	3539522	et	4	main
see	doc_600559928992_item	3539523	et	3	main
on	doc_600559928992_item	3539524	et	4	main
väga	doc_600559928992_item	3539525	et	3	main
ilus	doc_600559928992_item	3539526	et	4	main
hoteel	doc_600559928992_item	3539527	et	4	main
mere	doc_600559928992_item	3539528	et	3	main
ääres	doc_600559928992_item	3539529	et	4	main
ma	doc_600559928992_item	3539530	et	3	main
kirjutan	doc_600559928992_item	3539531	et	3	main
kuidas	doc_600559928992_item	3539532	et	3	main
ma	doc_600559928992_item	3539533	et	3	main
puhkan	doc_600559928992_item	3539534	et	3	main
ja	doc_600559928992_item	3539535	et	3	main
reeisin	doc_600559928992_item	3539536	et	4	main
augustis	doc_600559928992_item	3539537	et	3	main
ootan	doc_600559928992_item	3539538	et	3	main
reisi	doc_600559928992_item	3539422	et	4	main
oma	doc_600559928992_item	3539427	et	4	main
kallis	doc_600559928992_item	3539456	et	4	main
eest	doc_600559928992_item	3539460	et	4	main
on	doc_600559928992_item	3539468	et	4	main
kõik	doc_600559928992_item	3539469	et	4	main
kõrras	doc_600559928992_item	3539470	et	4	main
ja	doc_600559928992_item	3539471	et	3	main
mul	doc_600559928992_item	3539472	et	3	main
kõik	doc_600559928992_item	3539474	et	4	main
hästi	doc_600559928992_item	3539475	et	3	main
täna	doc_600559928992_item	3539476	et	4	main
mul	doc_600559928992_item	3539477	et	3	main
on	doc_600559928992_item	3539473	et	4	main
on	doc_600559928992_item	3539478	et	4	main
puhkus	doc_600559928992_item	3539479	et	3	main
ma	doc_600559928992_item	3539480	et	3	main
puhkan	doc_600559928992_item	3539481	et	3	main
suvilas	doc_600559928992_item	3539482	et	3	main
peipsi	doc_600559928992_item	3539483	et	4	main
järve	doc_600559928992_item	3539484	et	4	main
ääres	doc_600559928992_item	3539485	et	4	main
ma	doc_600559928992_item	3539486	et	3	main
soovin	doc_600559928992_item	3539487	et	3	main
sõita	doc_600559928992_item	3539488	et	3	main
venemaale	doc_600559928992_item	3539489	et	4	main
juulis	doc_600559928992_item	3539490	et	3	main
ma	doc_600559928992_item	3539491	et	3	main
sõidan	doc_600559928992_item	3539492	et	3	main
oma	doc_600559928992_item	3539493	et	4	main
perega	doc_600559928992_item	3539494	et	3	main
odessasse	doc_600559928992_item	3539495	et	4	main
läheme	doc_600559928992_item	3539497	et	3	main
lennukiga	doc_600559928992_item	3539498	et	3	main
ja	doc_600559928992_item	3539499	et	3	main
ma	doc_600559928992_item	3539500	et	3	main
ostsin	doc_600559928992_item	3539501	et	3	main
ma	doc_600559928992_item	3539509	et	3	main
sinu	doc_600559928992_item	3539539	et	3	main
reisite	doc_600559928993_item	3539561	et	3	main
peatute	doc_600559928993_item	3539570	et	4	main
umbes	doc_600559928993_item	3539574	et	4	main
moskvasse	doc_600559928993_item	3539609	et	4	main
pihkvasse	doc_600559928993_item	3539610	et	4	main
ja	doc_600559928993_item	3539611	et	3	main
novgorodisse	doc_600559928993_item	3539612	et	4	main
aastal	doc_600559928993_item	3539620	et	3	main
reisima	doc_600559928993_item	3539624	et	3	main
27	doc_600559928993_item	3539628	et	2	main
kohtla-järvelt	doc_600559928993_item	3539630	et	4	main
saan	doc_600559928993_item	3539642	et	4	main
hotelis	doc_600559928993_item	3539649	et	4	main
vaatama	doc_600559928993_item	3539655	et	3	main
et	doc_600559928993_item	3539660	et	3	main
ta	doc_600559928993_item	3539661	et	4	main
väga	doc_600559928993_item	3539662	et	3	main
ilus	doc_600559928993_item	3539663	et	4	main
see	doc_600559928993_item	3539664	et	3	main
kuhu	doc_600559928994_item	3539695	et	3	main
sõita	doc_600559928994_item	3539697	et	3	main
palju	doc_600559928994_item	3539704	et	4	main
puhkekodu	doc_600559928994_item	3539725	et	4	main
asub	doc_600559928994_item	3539726	et	3	main
ma	doc_600559928994_item	3539784	et	3	main
huvitan	doc_600559928994_item	3539788	et	3	main
kohtumeni	doc_600559928994_item	3539791	et	4	main
eesnimi	doc_600559928994_item	3539792	et	3	main
te	doc_600559928998_item	3539795	et	4	main
venemaale	doc_600559928998_item	3539798	et	4	main
kirjutage	doc_600559928998_item	3539799	et	3	main
reisite	doc_600559928998_item	3539813	et	3	main
ööbite	doc_600559928998_item	3539815	et	3	main
palju	doc_600559928998_item	3539817	et	4	main
umbes	doc_600559928998_item	3539826	et	4	main
sõna	doc_600559928998_item	3539828	et	4	main
sulle	doc_600559928998_item	3539840	et	3	main
ootavad	doc_600559928998_item	3539855	et	4	main
ei	doc_600559928998_item	3539859	et	4	main
sõidan	doc_600559928998_item	3539876	et	3	main
sõidab	doc_600559928998_item	3539881	et	3	main
praegu	doc_600559928998_item	3539883	et	3	main
on	doc_600559928998_item	3539885	et	4	main
töölagris	doc_600559928998_item	3539886	et	4	main
üks	doc_600559928998_item	3539887	et	3	main
pilet	doc_600559928998_item	3539888	et	3	main
maksab	doc_600559928998_item	3539889	et	3	main
siis	doc_600559928993_item	3539621	et	3	main
ma	doc_600559928993_item	3539622	et	3	main
te	doc_600559928993_item	3539543	et	4	main
oma	doc_600559928993_item	3539550	et	4	main
eestlasest	doc_600559928993_item	3539551	et	3	main
sõbrale	doc_600559928993_item	3539552	et	3	main
kirjutage	doc_600559928993_item	3539553	et	3	main
millal	doc_600559928993_item	3539554	et	3	main
ja	doc_600559928993_item	3539555	et	3	main
kuhu	doc_600559928993_item	3539556	et	3	main
millega	doc_600559928993_item	3539560	et	3	main
kui	doc_600559928993_item	3539564	et	3	main
see	doc_600559928993_item	3539566	et	3	main
kohtades	doc_600559928993_item	3539569	et	3	main
nõutav	doc_600559928993_item	3539572	et	4	main
pikkus	doc_600559928993_item	3539573	et	4	main
tere	doc_600559928993_item	3539577	et	3	main
sõbranna	doc_600559928993_item	3539578	et	4	main
signe	doc_600559928993_item	3539579	et	4	main
sain	doc_600559928993_item	3539580	et	3	main
sinu	doc_600559928993_item	3539582	et	3	main
viimase	doc_600559928993_item	3539583	et	3	main
kirju	doc_600559928993_item	3539584	et	4	main
kus	doc_600559928993_item	3539585	et	3	main
sa	doc_600559928993_item	3539586	et	3	main
kirjeldasid	doc_600559928993_item	3539588	et	4	main
oma	doc_600559928993_item	3539589	et	4	main
huvitavalt	doc_600559928993_item	3539587	et	4	main
reisi	doc_600559928993_item	3539591	et	4	main
venemaale	doc_600559928993_item	3539592	et	4	main
mul	doc_600559928993_item	3539593	et	3	main
on	doc_600559928993_item	3539594	et	4	main
varsti	doc_600559928993_item	3539595	et	3	main
puhkus	doc_600559928993_item	3539596	et	3	main
suvist	doc_600559928993_item	3539590	et	4	main
mida	doc_600559928993_item	3539597	et	4	main
ma	doc_600559928993_item	3539598	et	3	main
tahaksin	doc_600559928993_item	3539599	et	3	main
ka	doc_600559928993_item	3539600	et	3	main
veeta	doc_600559928993_item	3539601	et	4	main
reiside	doc_600559928993_item	3539602	et	3	main
venemaale	doc_600559928993_item	3539603	et	4	main
reisibüroos	doc_600559928993_item	3539604	et	3	main
mulle	doc_600559928993_item	3539605	et	4	main
pakkus	doc_600559928993_item	3539606	et	3	main
sõna	doc_600559928993_item	3539576	et	4	main
reisi	doc_600559928993_item	3539608	et	4	main
pihkvas	doc_600559928993_item	3539615	et	4	main
ma	doc_600559928993_item	3539616	et	3	main
juba	doc_600559928993_item	3539617	et	3	main
käisin	doc_600559928993_item	3539618	et	3	main
eestimisel	doc_600559928993_item	3539619	et	4	main
mõtlen	doc_600559928993_item	3539623	et	3	main
juunil	doc_600559928993_item	3539629	et	3	main
kuus	doc_600559928993_item	3539633	et	4	main
tore	doc_600559928993_item	3539635	et	3	main
et	doc_600559928993_item	3539636	et	3	main
reisin	doc_600559928993_item	3539637	et	3	main
bussiga	doc_600559928993_item	3539638	et	3	main
loodan	doc_600559928993_item	3539639	et	3	main
et	doc_600559928993_item	3539640	et	3	main
ma	doc_600559928993_item	3539641	et	3	main
ööbime	doc_600559928993_item	3539648	et	3	main
ma	doc_600559928993_item	3539653	et	3	main
novgorodi	doc_600559928993_item	3539656	et	4	main
kremle	doc_600559928993_item	3539657	et	4	main
plaanite	doc_600559928994_item	3539683	et	3	main
venemaale	doc_600559928994_item	3539685	et	4	main
kirjutage	doc_600559928994_item	3539686	et	3	main
sellest	doc_600559928994_item	3539687	et	4	main
kiri	doc_600559928994_item	3539688	et	3	main
te	doc_600559928994_item	3539696	et	4	main
soovite	doc_600559928994_item	3539698	et	3	main
kus	doc_600559928994_item	3539701	et	3	main
kui	doc_600559928994_item	3539703	et	3	main
maksab	doc_600559928994_item	3539706	et	3	main
kohtades	doc_600559928994_item	3539708	et	3	main
kirja	doc_600559928994_item	3539710	et	4	main
nõutav	doc_600559928994_item	3539711	et	4	main
me	doc_600559928994_item	3539720	et	4	main
musta	doc_600559928994_item	3539727	et	4	main
mere	doc_600559928994_item	3539728	et	3	main
kiri	doc_600559928998_item	3539801	et	3	main
millistes	doc_600559928998_item	3539820	et	3	main
80	doc_600559928998_item	3539827	et	2	main
kallis	doc_600559928998_item	3539830	et	4	main
aivar	doc_600559928998_item	3539831	et	4	main
ma	doc_600559928998_item	3539832	et	3	main
sain	doc_600559928998_item	3539833	et	3	main
eile	doc_600559928998_item	3539834	et	3	main
sinu	doc_600559928998_item	3539835	et	3	main
kirja	doc_600559928998_item	3539836	et	4	main
ja	doc_600559928998_item	3539837	et	3	main
elavad	doc_600559928998_item	3539851	et	4	main
minu	doc_600559928998_item	3539852	et	3	main
väga	doc_600559928998_item	3539857	et	3	main
ma	doc_600559928998_item	3539858	et	3	main
ole	doc_600559928998_item	3539860	et	4	main
ma	doc_600559928998_item	3539875	et	3	main
võib-olla	doc_600559928998_item	3539878	et	3	main
poeg	doc_600559928998_item	3539880	et	3	main
minuga	doc_600559928998_item	3539882	et	3	main
ta	doc_600559928998_item	3539884	et	4	main
kroni	doc_600559928998_item	3539892	et	4	main
on	doc_600559928998_item	3539894	et	4	main
aga	doc_600559928998_item	3539896	et	3	main
ma	doc_600559928998_item	3539897	et	3	main
tahaksin	doc_600559928998_item	3539898	et	3	main
puhata	doc_600559928998_item	3539901	et	4	main
ja	doc_600559928998_item	3539902	et	3	main
venemaale	doc_600559928998_item	3539903	et	4	main
elavad	doc_600559928998_item	3539908	et	4	main
võime	doc_600559928998_item	3539917	et	4	main
seal	doc_600559928998_item	3539918	et	4	main
peatuma	doc_600559928998_item	3539919	et	4	main
sõidab	doc_600559928998_item	3539926	et	3	main
reis	doc_600559928993_item	3539626	et	4	main
ta	doc_600559928993_item	3539631	et	4	main
kestab	doc_600559928993_item	3539632	et	4	main
kesk	doc_600559928993_item	3539651	et	3	main
selle	doc_600559928993_item	3539658	et	4	main
pärast	doc_600559928993_item	3539659	et	4	main
oma	doc_600559928994_item	3539689	et	4	main
eestlasest	doc_600559928994_item	3539690	et	3	main
sõbrale	doc_600559928994_item	3539691	et	3	main
ja	doc_600559928994_item	3539694	et	3	main
see	doc_600559928994_item	3539705	et	3	main
millistes	doc_600559928994_item	3539707	et	3	main
peatute	doc_600559928994_item	3539709	et	4	main
umbes	doc_600559928994_item	3539713	et	4	main
13062005	doc_600559928994_item	3539716	et	2	main
anu	doc_600559928994_item	3539719	et	4	main
planime	doc_600559928994_item	3539721	et	4	main
reisi	doc_600559928994_item	3539722	et	4	main
arvan	doc_600559928994_item	3539785	et	3	main
puhkus	doc_600559928994_item	3539787	et	3	main
kallid	doc_600559928994_item	3539790	et	3	main
kiri	doc_600559928998_item	3539794	et	3	main
plaanite	doc_600559928998_item	3539796	et	3	main
reisi	doc_600559928998_item	3539797	et	4	main
oma	doc_600559928998_item	3539802	et	4	main
te	doc_600559928998_item	3539809	et	4	main
maksab	doc_600559928998_item	3539819	et	3	main
nüüd	doc_600559928998_item	3539838	et	4	main
esimisel	doc_600559928998_item	3539841	et	4	main
juulil	doc_600559928998_item	3539842	et	3	main
algab	doc_600559928998_item	3539843	et	3	main
minu	doc_600559928998_item	3539844	et	3	main
puhkus	doc_600559928998_item	3539845	et	3	main
ma	doc_600559928998_item	3539846	et	3	main
tahaksin	doc_600559928998_item	3539847	et	3	main
moskvas	doc_600559928998_item	3539861	et	4	main
jüba	doc_600559928998_item	3539862	et	4	main
7	doc_600559928998_item	3539863	et	2	main
aastat	doc_600559928998_item	3539864	et	3	main
reisirong	doc_600559928998_item	3539865	et	3	main
et	doc_600559928998_item	3539874	et	3	main
pealinna	doc_600559928998_item	3539904	et	4	main
kolmetoaline	doc_600559928998_item	3539910	et	4	main
on	doc_600559928998_item	3539913	et	4	main
sa	doc_600559928998_item	3539925	et	3	main
te	doc_600559928999_item	3540061	et	4	main
kirjutage	doc_600559928999_item	3540065	et	3	main
see	doc_600559928999_item	3540084	et	3	main
peatute	doc_600559928999_item	3540088	et	4	main
nõutav	doc_600559928999_item	3540090	et	4	main
kallis	doc_600559928999_item	3540098	et	4	main
sain	doc_600559928999_item	3540101	et	3	main
sinult	doc_600559928999_item	3540105	et	3	main
me	doc_600559928999_item	3540163	et	4	main
12072005	doc_600559928999_item	3540166	et	2	main
venemaale	doc_600559929000_item	3540183	et	4	main
kirjutage	doc_600559929000_item	3540184	et	3	main
kiri	doc_600559929000_item	3540186	et	3	main
sõbrale	doc_600559929000_item	3540189	et	3	main
ja	doc_600559929000_item	3540192	et	3	main
palju	doc_600559929000_item	3540202	et	4	main
isa	doc_600559929000_item	3540227	et	4	main
ja	doc_600559929000_item	3540228	et	3	main
kostromas	doc_600559929000_item	3540231	et	4	main
rongi	doc_600559929000_item	3540239	et	4	main
rongi	doc_600559929000_item	3540247	et	4	main
pilet	doc_600559929000_item	3540248	et	3	main
kaks	doc_600559929000_item	3540249	et	3	main
saada	doc_600559929000_item	3540250	et	4	main
palju	doc_600559928993_item	3539643	et	4	main
ilusaid	doc_600559928993_item	3539644	et	3	main
ja	doc_600559928993_item	3539645	et	3	main
huvitavaid	doc_600559928993_item	3539646	et	4	main
novgorod	doc_600559928993_item	3539650	et	4	main
linnas	doc_600559928993_item	3539652	et	4	main
sõidan	doc_600559928993_item	3539654	et	3	main
maksab	doc_600559928993_item	3539665	et	3	main
1000	doc_600559928993_item	3539666	et	2	main
krooni	doc_600559928993_item	3539667	et	4	main
kuhu	doc_600559928993_item	3539668	et	3	main
sa	doc_600559928993_item	3539669	et	3	main
plaanid	doc_600559928993_item	3539670	et	4	main
reisi	doc_600559928993_item	3539671	et	4	main
ootan	doc_600559928993_item	3539672	et	3	main
sinu	doc_600559928993_item	3539673	et	3	main
järgmine	doc_600559928993_item	3539674	et	3	main
kirju	doc_600559928993_item	3539675	et	4	main
sinu	doc_600559928993_item	3539676	et	3	main
sõbranna	doc_600559928993_item	3539677	et	4	main
eesnimi	doc_600559928993_item	3539678	et	3	main
13062005	doc_600559928993_item	3539679	et	2	main
kiri	doc_600559928994_item	3539681	et	3	main
millal	doc_600559928994_item	3539693	et	3	main
reisite	doc_600559928994_item	3539700	et	3	main
ööbite	doc_600559928994_item	3539702	et	3	main
80	doc_600559928994_item	3539714	et	2	main
armas	doc_600559928994_item	3539718	et	3	main
lähedal	doc_600559928994_item	3539729	et	4	main
sind	doc_600559928994_item	3539782	et	4	main
puhkedust	doc_600559928994_item	3539783	et	4	main
see	doc_600559928994_item	3539786	et	3	main
aga	doc_600559928994_item	3539789	et	3	main
sõita	doc_600559928998_item	3539810	et	3	main
millega	doc_600559928998_item	3539812	et	3	main
kus	doc_600559928998_item	3539814	et	3	main
kui	doc_600559928998_item	3539816	et	3	main
see	doc_600559928998_item	3539818	et	3	main
peatute	doc_600559928998_item	3539822	et	4	main
nõutav	doc_600559928998_item	3539824	et	4	main
pikkus	doc_600559928998_item	3539825	et	4	main
venemaale	doc_600559928998_item	3539848	et	4	main
sõita	doc_600559928998_item	3539849	et	3	main
moskvas	doc_600559928998_item	3539850	et	4	main
mind	doc_600559928998_item	3539856	et	4	main
moskva	doc_600559928998_item	3539867	et	4	main
läheb	doc_600559928998_item	3539868	et	3	main
iga	doc_600559928998_item	3539869	et	4	main
päev	doc_600559928998_item	3539870	et	3	main
ja	doc_600559928998_item	3539871	et	3	main
ma	doc_600559928998_item	3539872	et	3	main
mõtlen	doc_600559928998_item	3539873	et	3	main
rongiga	doc_600559928998_item	3539877	et	4	main
minu	doc_600559928998_item	3539879	et	3	main
see	doc_600559928998_item	3539893	et	3	main
vaadata	doc_600559928998_item	3539905	et	4	main
minu	doc_600559928998_item	3539906	et	3	main
korteris	doc_600559928998_item	3539911	et	3	main
800	doc_600559928994_item	3539762	et	2	main
krooni	doc_600559928994_item	3539763	et	4	main
öösel	doc_600559928994_item	3539764	et	4	main
korteris	doc_600559928994_item	3539765	et	3	main
on	doc_600559928994_item	3539766	et	4	main
oma	doc_600559928994_item	3539767	et	4	main
dušš	doc_600559928994_item	3539768	et	2	main
puhkekodu	doc_600559928994_item	3539769	et	4	main
lähedal	doc_600559928994_item	3539770	et	4	main
on	doc_600559928994_item	3539771	et	4	main
liivane	doc_600559928994_item	3539772	et	4	main
rand	doc_600559928994_item	3539773	et	3	main
mänguplats	doc_600559928994_item	3539774	et	3	main
ja	doc_600559928994_item	3539775	et	3	main
tennis	doc_600559928994_item	3539776	et	3	main
on	doc_600559928994_item	3539778	et	4	main
puhkekodus	doc_600559928994_item	3539777	et	3	main
ööklubi	doc_600559928994_item	3539779	et	4	main
ma	doc_600559928994_item	3539780	et	3	main
kirjutan	doc_600559928994_item	3539781	et	3	main
te	doc_600559928994_item	3539682	et	4	main
reisi	doc_600559928994_item	3539684	et	4	main
kirjutage	doc_600559928994_item	3539692	et	3	main
millega	doc_600559928994_item	3539699	et	3	main
pikkus	doc_600559928994_item	3539712	et	4	main
sõna	doc_600559928994_item	3539715	et	4	main
tere	doc_600559928994_item	3539717	et	3	main
venemaale	doc_600559928994_item	3539723	et	4	main
puhkekodus	doc_600559928994_item	3539724	et	3	main
seal	doc_600559928994_item	3539730	et	4	main
on	doc_600559928994_item	3539731	et	4	main
väga	doc_600559928994_item	3539732	et	3	main
ilus	doc_600559928994_item	3539733	et	4	main
loodus	doc_600559928994_item	3539734	et	4	main
me	doc_600559928994_item	3539735	et	4	main
soovime	doc_600559928994_item	3539736	et	4	main
sõidata	doc_600559928994_item	3539737	et	4	main
rongiga	doc_600559928994_item	3539738	et	4	main
üks	doc_600559928994_item	3539739	et	3	main
pilet	doc_600559928994_item	3539740	et	3	main
maksab	doc_600559928994_item	3539741	et	3	main
500	doc_600559928994_item	3539742	et	2	main
krooni	doc_600559928994_item	3539743	et	4	main
me	doc_600559928994_item	3539744	et	4	main
planime	doc_600559928994_item	3539745	et	4	main
elada	doc_600559928994_item	3539746	et	3	main
puhkekodus	doc_600559928994_item	3539747	et	3	main
kaks	doc_600559928994_item	3539748	et	3	main
nädalas	doc_600559928994_item	3539749	et	3	main
see	doc_600559928994_item	3539750	et	3	main
on	doc_600559928994_item	3539751	et	4	main
ilus	doc_600559928994_item	3539752	et	4	main
kivi	doc_600559928994_item	3539753	et	4	main
maja	doc_600559928994_item	3539754	et	4	main
me	doc_600559928994_item	3539755	et	4	main
elame	doc_600559928994_item	3539756	et	3	main
neljakesi	doc_600559928994_item	3539757	et	3	main
kahetoaline	doc_600559928994_item	3539758	et	4	main
korteris	doc_600559928994_item	3539759	et	3	main
me	doc_600559928994_item	3539760	et	4	main
maksame	doc_600559928994_item	3539761	et	3	main
sellest	doc_600559928998_item	3539800	et	4	main
eestlasest	doc_600559928998_item	3539803	et	3	main
sõbrale	doc_600559928998_item	3539804	et	3	main
kirjutage	doc_600559928998_item	3539805	et	3	main
millal	doc_600559928998_item	3539806	et	3	main
ja	doc_600559928998_item	3539807	et	3	main
kuhu	doc_600559928998_item	3539808	et	3	main
soovite	doc_600559928998_item	3539811	et	3	main
kohtades	doc_600559928998_item	3539821	et	3	main
kirja	doc_600559928998_item	3539823	et	4	main
tere	doc_600559928998_item	3539829	et	3	main
kirjutan	doc_600559928998_item	3539839	et	3	main
sugulased	doc_600559928998_item	3539853	et	3	main
nad	doc_600559928998_item	3539854	et	3	main
tallinn	doc_600559928998_item	3539866	et	4	main
moskvasse	doc_600559928998_item	3539890	et	4	main
800	doc_600559928998_item	3539891	et	2	main
kallis	doc_600559928998_item	3539895	et	4	main
üks	doc_600559928998_item	3539899	et	3	main
sugulased	doc_600559928998_item	3539907	et	3	main
korteris	doc_600559928998_item	3539912	et	3	main
palju	doc_600559928998_item	3539914	et	4	main
ruumi	doc_600559928998_item	3539915	et	4	main
me	doc_600559928998_item	3539916	et	4	main
kallis	doc_600559928998_item	3539920	et	4	main
aivar	doc_600559928998_item	3539921	et	4	main
kuidas	doc_600559928998_item	3539922	et	3	main
läheb	doc_600559928998_item	3539923	et	3	main
kuhu	doc_600559928998_item	3539924	et	3	main
nädal	doc_600559928998_item	3539900	et	3	main
kesklinnas	doc_600559928998_item	3539909	et	4	main
juulil	doc_600559928998_item	3539927	et	3	main
ma	doc_600559928998_item	3539928	et	3	main
tulen	doc_600559928998_item	3539929	et	3	main
tagasi	doc_600559928998_item	3539930	et	3	main
kaheteistkümmnendal	doc_600559928998_item	3539931	et	4	main
juulil	doc_600559928998_item	3539932	et	3	main
ja	doc_600559928998_item	3539933	et	3	main
helistan	doc_600559928998_item	3539934	et	3	main
sulle	doc_600559928998_item	3539935	et	3	main
palju	doc_600559928998_item	3539936	et	4	main
õnne	doc_600559928998_item	3539937	et	4	main
eesnimi	doc_600559928998_item	3539938	et	3	main
poeg	doc_600559928998_item	3539939	et	3	main
8062005	doc_600559928998_item	3539940	et	2	main
venemaale	doc_600559928999_item	3540064	et	4	main
sellest	doc_600559928999_item	3540066	et	4	main
oma	doc_600559928999_item	3540068	et	4	main
eestlasest	doc_600559928999_item	3540069	et	3	main
sõbrale	doc_600559928999_item	3540070	et	3	main
kirjutage	doc_600559928999_item	3540071	et	3	main
millal	doc_600559928999_item	3540072	et	3	main
ja	doc_600559928999_item	3540073	et	3	main
kuhu	doc_600559928999_item	3540074	et	3	main
te	doc_600559928999_item	3540075	et	4	main
sõita	doc_600559928999_item	3540076	et	3	main
soovite	doc_600559928999_item	3540077	et	3	main
millega	doc_600559928999_item	3540078	et	3	main
reisite	doc_600559928999_item	3540079	et	3	main
kus	doc_600559928999_item	3540080	et	3	main
ööbite	doc_600559928999_item	3540081	et	3	main
kui	doc_600559928999_item	3540082	et	3	main
millistes	doc_600559928999_item	3540086	et	3	main
umbes	doc_600559928999_item	3540092	et	4	main
kiri	doc_600559928999_item	3540060	et	3	main
kiri	doc_600559928999_item	3540067	et	3	main
kohtades	doc_600559928999_item	3540087	et	3	main
kirja	doc_600559928999_item	3540089	et	4	main
pikkus	doc_600559928999_item	3540091	et	4	main
tere	doc_600559928999_item	3540097	et	3	main
päeva	doc_600559928999_item	3540103	et	4	main
tuleme	doc_600559928999_item	3540164	et	3	main
mul	doc_600559928999_item	3540168	et	3	main
ole	doc_600559928999_item	3540170	et	4	main
vaba	doc_600559928999_item	3540171	et	4	main
aega	doc_600559928999_item	3540172	et	4	main
ma	doc_600559928999_item	3540173	et	3	main
tööle	doc_600559928999_item	3540175	et	3	main
kohtumiseni	doc_600559928999_item	3540176	et	4	main
eesnimi	doc_600559928999_item	3540177	et	3	main
kiirestan	doc_600559928999_item	3540174	et	4	main
e	doc_600559928999_item	3540142	et	4	main
oleme	doc_600559928999_item	3540143	et	3	main
elada	doc_600559928999_item	3540144	et	3	main
hotell	doc_600559928999_item	3540145	et	3	main
venemaa	doc_600559928999_item	3540146	et	4	main
viiendal	doc_600559928999_item	3540147	et	3	main
korrusel	doc_600559928999_item	3540148	et	3	main
neljatoaline	doc_600559928999_item	3540149	et	4	main
kohta	doc_600559928999_item	3540150	et	4	main
numbritoas	doc_600559928999_item	3540151	et	3	main
see	doc_600559928999_item	3540152	et	3	main
maksab	doc_600559928999_item	3540153	et	3	main
umbes	doc_600559928999_item	3540154	et	4	main
3000	doc_600559928999_item	3540155	et	2	main
kroni	doc_600559928999_item	3540156	et	4	main
me	doc_600559928999_item	3540157	et	4	main
tahame	doc_600559928999_item	3540158	et	3	main
minna	doc_600559928999_item	3540159	et	3	main
plaanite	doc_600559928999_item	3540062	et	3	main
palju	doc_600559928999_item	3540083	et	4	main
sõna	doc_600559928999_item	3540094	et	4	main
a	doc_600559928999_item	3540096	et	4	main
paar	doc_600559928999_item	3540102	et	3	main
kirja	doc_600559928999_item	3540106	et	4	main
ja	doc_600559928999_item	3540107	et	3	main
mul	doc_600559928999_item	3540108	et	3	main
on	doc_600559928999_item	3540109	et	4	main
väga	doc_600559928999_item	3540110	et	3	main
hea	doc_600559928999_item	3540111	et	4	main
meel	doc_600559928999_item	3540112	et	4	main
et	doc_600559928999_item	3540113	et	3	main
sul	doc_600559928999_item	3540114	et	3	main
kõik	doc_600559928999_item	3540115	et	4	main
on	doc_600559928999_item	3540116	et	4	main
korras	doc_600559928999_item	3540117	et	4	main
mul	doc_600559928999_item	3540118	et	3	main
on	doc_600559928999_item	3540119	et	4	main
ka	doc_600559928999_item	3540120	et	3	main
hästi	doc_600559928999_item	3540121	et	3	main
mul	doc_600559928999_item	3540122	et	3	main
on	doc_600559928999_item	3540123	et	4	main
uudis	doc_600559928999_item	3540124	et	3	main
ma	doc_600559928999_item	3540125	et	3	main
plaanin	doc_600559928999_item	3540126	et	3	main
reisi	doc_600559928999_item	3540127	et	4	main
venemaale	doc_600559928999_item	3540128	et	4	main
oma	doc_600559928999_item	3540129	et	4	main
perega	doc_600559928999_item	3540130	et	3	main
me	doc_600559928999_item	3540131	et	4	main
sõidame	doc_600559928999_item	3540132	et	3	main
05072005	doc_600559928999_item	3540133	et	2	main
aastal	doc_600559928999_item	3540134	et	3	main
moskvasse	doc_600559928999_item	3540135	et	4	main
me	doc_600559928999_item	3540136	et	4	main
soovime	doc_600559928999_item	3540137	et	4	main
sõita	doc_600559928999_item	3540138	et	3	main
pongiga	doc_600559928999_item	3540139	et	4	main
või	doc_600559928999_item	3540140	et	4	main
bussiga	doc_600559928999_item	3540141	et	3	main
kunstimuuseumis	doc_600559928999_item	3540160	et	3	main
kiri	doc_600559929000_item	3540179	et	3	main
see	doc_600559929000_item	3540203	et	3	main
junil	doc_600559929000_item	3540220	et	4	main
elab	doc_600559929000_item	3540230	et	3	main
ma	doc_600559929000_item	3540232	et	3	main
reisi	doc_600559928999_item	3540063	et	4	main
maksab	doc_600559928999_item	3540085	et	3	main
80	doc_600559928999_item	3540093	et	2	main
08062005	doc_600559928999_item	3540095	et	2	main
tagasi	doc_600559928999_item	3540104	et	3	main
suur	doc_600559928999_item	3540161	et	3	main
teatris	doc_600559928999_item	3540162	et	3	main
aastal	doc_600559928999_item	3540167	et	3	main
reisi	doc_600559929000_item	3540182	et	4	main
oma	doc_600559929000_item	3540187	et	4	main
kirjutage	doc_600559929000_item	3540190	et	3	main
kuhu	doc_600559929000_item	3540193	et	3	main
ööbite	doc_600559929000_item	3540200	et	3	main
peterburi	doc_600559929000_item	3540236	et	4	main
ja	doc_600559929000_item	3540237	et	3	main
maksab	doc_600559929000_item	3540243	et	3	main
viiskümmend	doc_600559929000_item	3540251	et	4	main
rubla	doc_600559929000_item	3540252	et	4	main
ma	doc_600559929000_item	3540253	et	3	main
plaaniten	doc_600559929000_item	3540254	et	4	main
minuga	doc_600559929000_item	3540259	et	3	main
aega	doc_600559929000_item	3540283	et	4	main
sõber	doc_600559929000_item	3540285	et	3	main
k	doc_600559929000_item	3540287	et	4	main
järve	doc_600559929000_item	3540288	et	4	main
kiri	doc_600559929003_item	3540298	et	3	main
millal	doc_600559929003_item	3540303	et	3	main
kuhu	doc_600559929003_item	3540305	et	3	main
sõita	doc_600559929003_item	3540307	et	3	main
millega	doc_600559929003_item	3540309	et	3	main
see	doc_600559929003_item	3540315	et	3	main
80	doc_600559929003_item	3540324	et	2	main
kallis	doc_600559929003_item	3540327	et	4	main
päeva	doc_600559929003_item	3540331	et	4	main
korras	doc_600559929003_item	3540338	et	4	main
kõik	doc_600559929003_item	3540341	et	4	main
hästi	doc_600559929003_item	3540342	et	3	main
varsti	doc_600559929003_item	3540343	et	3	main
minul	doc_600559929003_item	3540344	et	3	main
on	doc_600559929003_item	3540345	et	4	main
puhkus	doc_600559929003_item	3540346	et	3	main
ma	doc_600559929003_item	3540347	et	3	main
plaanin	doc_600559929003_item	3540348	et	3	main
vanaema	doc_600559929003_item	3540353	et	4	main
vologdas	doc_600559929003_item	3540355	et	4	main
mind	doc_600559929003_item	3540359	et	4	main
sooritab	doc_600559929003_item	3540363	et	3	main
kahekümne	doc_600559929003_item	3540365	et	4	main
juuni	doc_600559929003_item	3540366	et	4	main
tere	doc_873901597529_item	3540415	et	3	main
eesnimi	doc_873901597529_item	3540420	et	3	main
õpetaja	doc_873901597529_item	3540424	et	4	main
minu	doc_873901597529_item	3540430	et	3	main
armastan	doc_873901597529_item	3540433	et	3	main
ja	doc_873901597529_item	3540436	et	3	main
lugeda	doc_873901597529_item	3540478	et	3	main
ajalehti	doc_873901597529_item	3540479	et	4	main
ülemusega	doc_873901597529_item	3540497	et	4	main
ja	doc_873901597529_item	3540498	et	3	main
tuttavatega	doc_873901597529_item	3540499	et	3	main
me	doc_873901597529_item	3540505	et	4	main
rääkimisega	doc_873901597529_item	3540510	et	4	main
ma	doc_873901597529_item	3540511	et	3	main
kardan	doc_873901597529_item	3540512	et	4	main
tõnu	doc_600559928999_item	3540099	et	4	main
ma	doc_600559928999_item	3540100	et	3	main
venemaalt	doc_600559928999_item	3540165	et	3	main
ei	doc_600559928999_item	3540169	et	4	main
te	doc_600559929000_item	3540180	et	4	main
kui	doc_600559929000_item	3540201	et	3	main
või	doc_600559929000_item	3540221	et	4	main
ma	doc_600559929000_item	3540223	et	3	main
reisid	doc_600559929000_item	3540224	et	4	main
venemaale	doc_600559929000_item	3540225	et	4	main
minu	doc_600559929000_item	3540226	et	3	main
kostroma	doc_600559929000_item	3540238	et	4	main
saada	doc_600559929000_item	3540244	et	4	main
krooni	doc_600559929000_item	3540245	et	4	main
ja	doc_600559929000_item	3540246	et	3	main
ja	doc_600559929000_item	3540258	et	3	main
sõbrale	doc_600559929003_item	3540301	et	3	main
kirjutage	doc_600559929003_item	3540302	et	3	main
millistes	doc_600559929003_item	3540317	et	3	main
umbes	doc_600559929003_item	3540323	et	4	main
reisi	doc_600559929003_item	3540349	et	4	main
elab	doc_600559929003_item	3540354	et	3	main
üksi	doc_600559929003_item	3540356	et	4	main
ootab	doc_600559929003_item	3540358	et	3	main
praegu	doc_600559929003_item	3540361	et	3	main
me	doc_600559929003_item	3540368	et	4	main
plaanime	doc_600559929003_item	3540369	et	3	main
kiri	doc_873901597529_item	3540414	et	3	main
õpetaja	doc_873901597529_item	3540416	et	4	main
matemaatika	doc_873901597529_item	3540423	et	4	main
kõige	doc_873901597529_item	3540425	et	4	main
tähtsam	doc_873901597529_item	3540426	et	4	main
minu	doc_873901597529_item	3540427	et	3	main
lastega	doc_873901597529_item	3540434	et	3	main
mängida	doc_873901597529_item	3540437	et	3	main
nõue	doc_873901597529_item	3540467	et	3	main
keel	doc_873901597529_item	3540475	et	4	main
vaja	doc_873901597529_item	3540476	et	4	main
et	doc_873901597529_item	3540477	et	3	main
ja	doc_873901597529_item	3540487	et	3	main
eest	doc_873901597529_item	3540500	et	4	main
keelt	doc_873901597529_item	3540501	et	4	main
ma	doc_873901597529_item	3540502	et	3	main
et	doc_873901597529_item	3540504	et	3	main
kuulamisega	doc_873901597529_item	3540508	et	4	main
ei	doc_873901597529_item	3540516	et	4	main
ole	doc_873901597529_item	3540517	et	4	main
jaoks	doc_873901597529_item	3540521	et	4	main
ma	doc_873901597529_item	3540522	et	3	main
tahaksin	doc_873901597529_item	3540523	et	3	main
eesti	doc_873901597529_item	3540526	et	4	main
viibite	doc_464301607718_item	3540542	et	3	main
eestlasest	doc_464301607718_item	3540549	et	3	main
talle	doc_464301607718_item	3540552	et	4	main
te	doc_464301607718_item	3540554	et	4	main
olete	doc_464301607718_item	3540555	et	3	main
käinud	doc_464301607718_item	3540556	et	4	main
millal	doc_464301607718_item	3540563	et	3	main
koju	doc_464301607718_item	3540564	et	3	main
saabute	doc_464301607718_item	3540565	et	3	main
kirjutage	doc_464301607718_item	3540566	et	3	main
on	doc_464301607718_item	3540573	et	4	main
minu	doc_464301607718_item	3540578	et	3	main
mari	doc_464301607718_item	3540581	et	4	main
kuidas	doc_464301607718_item	3540595	et	3	main
kuidas	doc_464301607718_item	3540598	et	3	main
tere	doc_491521501949_item	3540644	et	3	main
kirjuta	doc_491521501949_item	3540645	et	4	main
palun	doc_491521501949_item	3540646	et	3	main
päeva	doc_491521501949_item	3540653	et	4	main
poega	doc_600559929000_item	3540260	et	4	main
me	doc_600559929000_item	3540261	et	4	main
läheme	doc_600559929000_item	3540262	et	3	main
museum	doc_600559929000_item	3540263	et	4	main
kino	doc_600559929000_item	3540264	et	4	main
vana	doc_600559929000_item	3540265	et	4	main
linnas	doc_600559929000_item	3540266	et	4	main
ja	doc_600559929000_item	3540267	et	3	main
teatrid	doc_600559929000_item	3540268	et	3	main
ma	doc_600559929000_item	3540269	et	3	main
elab	doc_600559929000_item	3540270	et	3	main
kostromas	doc_600559929000_item	3540271	et	4	main
juks	doc_600559929000_item	3540272	et	4	main
kolmas	doc_600559929000_item	3540273	et	3	main
nedelas	doc_600559929000_item	3540274	et	4	main
ja	doc_600559929000_item	3540275	et	3	main
juks	doc_600559929000_item	3540276	et	4	main
nedelas	doc_600559929000_item	3540277	et	4	main
peterburis	doc_600559929000_item	3540278	et	4	main
minul	doc_600559929000_item	3540279	et	3	main
vene	doc_600559929000_item	3540280	et	4	main
sõbral	doc_600559929000_item	3540281	et	3	main
heat	doc_600559929000_item	3540282	et	4	main
plaanite	doc_600559929000_item	3540181	et	3	main
sellest	doc_600559929000_item	3540185	et	4	main
eestlasest	doc_600559929000_item	3540188	et	3	main
millal	doc_600559929000_item	3540191	et	3	main
te	doc_600559929000_item	3540194	et	4	main
sõita	doc_600559929000_item	3540195	et	3	main
soovite	doc_600559929000_item	3540196	et	3	main
millega	doc_600559929000_item	3540197	et	3	main
reisite	doc_600559929000_item	3540198	et	3	main
kus	doc_600559929000_item	3540199	et	3	main
maksab	doc_600559929000_item	3540204	et	3	main
millistes	doc_600559929000_item	3540205	et	3	main
kohtades	doc_600559929000_item	3540206	et	3	main
peatute	doc_600559929000_item	3540207	et	4	main
kirja	doc_600559929000_item	3540208	et	4	main
nõutav	doc_600559929000_item	3540209	et	4	main
pikkus	doc_600559929000_item	3540210	et	4	main
umbes	doc_600559929000_item	3540211	et	4	main
80	doc_600559929000_item	3540212	et	2	main
sõna	doc_600559929000_item	3540213	et	4	main
tere	doc_600559929000_item	3540214	et	3	main
mart	doc_600559929000_item	3540215	et	3	main
ma	doc_600559929000_item	3540216	et	3	main
mõtlen	doc_600559929000_item	3540217	et	3	main
et	doc_600559929000_item	3540218	et	3	main
ma	doc_600559929000_item	3540219	et	3	main
julil	doc_600559929000_item	3540222	et	4	main
ema	doc_600559929000_item	3540229	et	4	main
plaanite	doc_600559929000_item	3540233	et	3	main
raudutee	doc_600559929000_item	3540240	et	4	main
reisi	doc_600559929000_item	3540255	et	4	main
minuga	doc_600559929000_item	3540256	et	3	main
eestlasest	doc_600559929003_item	3540300	et	3	main
maksab	doc_600559929003_item	3540316	et	3	main
peatute	doc_600559929003_item	3540319	et	4	main
nõutav	doc_600559929003_item	3540321	et	4	main
pikkus	doc_600559929003_item	3540322	et	4	main
kirja	doc_600559929003_item	3540334	et	4	main
mul	doc_600559929003_item	3540335	et	3	main
venemaale	doc_600559929003_item	3540350	et	4	main
vanaemale	doc_600559929003_item	3540351	et	3	main
hakkame	doc_600559929003_item	3540390	et	3	main
päevitama	doc_600559929003_item	3540391	et	3	main
suplema	doc_600559929003_item	3540392	et	3	main
ja	doc_600559929003_item	3540393	et	3	main
muidugi	doc_600559929003_item	3540394	et	4	main
aitama	doc_600559929003_item	3540395	et	3	main
vanaemale	doc_600559929003_item	3540396	et	3	main
tööd	doc_600559929003_item	3540397	et	4	main
maale	doc_600559929003_item	3540398	et	4	main
on	doc_600559929003_item	3540399	et	4	main
alati	doc_600559929003_item	3540400	et	4	main
palju	doc_600559929003_item	3540401	et	4	main
tulen	doc_600559929003_item	3540402	et	3	main
tagasi	doc_600559929003_item	3540403	et	3	main
ja	doc_600559929003_item	3540404	et	3	main
kindlasti	doc_600559929003_item	3540405	et	3	main
helistan	doc_600559929003_item	3540406	et	3	main
sinule	doc_600559929003_item	3540407	et	3	main
nägemiseni	doc_600559929003_item	3540408	et	4	main
eesnimi	doc_600559929003_item	3540409	et	3	main
08062005	doc_600559929003_item	3540410	et	2	main
reisi	doc_600559929000_item	3540234	et	4	main
busisa	doc_600559929000_item	3540235	et	4	main
pilet	doc_600559929000_item	3540241	et	3	main
peterburis	doc_600559929000_item	3540242	et	4	main
aabikasa	doc_600559929000_item	3540257	et	4	main
teie	doc_600559929000_item	3540284	et	4	main
eesnimi	doc_600559929000_item	3540286	et	3	main
8062005	doc_600559929000_item	3540289	et	2	main
kiri	doc_600559929003_item	3540291	et	3	main
kirjutage	doc_600559929003_item	3540296	et	3	main
sellest	doc_600559929003_item	3540297	et	4	main
ja	doc_600559929003_item	3540304	et	3	main
kus	doc_600559929003_item	3540311	et	3	main
kui	doc_600559929003_item	3540313	et	3	main
kirja	doc_600559929003_item	3540320	et	4	main
sõna	doc_600559929003_item	3540325	et	4	main
aino	doc_600559929003_item	3540328	et	4	main
sain	doc_600559929003_item	3540329	et	3	main
neli	doc_600559929003_item	3540330	et	3	main
tagasi	doc_600559929003_item	3540332	et	3	main
sinult	doc_600559929003_item	3540333	et	3	main
kõik	doc_600559929003_item	3540337	et	4	main
ka	doc_600559929003_item	3540340	et	3	main
ja	doc_600559929003_item	3540357	et	3	main
pärast	doc_600559929003_item	3540367	et	4	main
isiklik	doc_873901597529_item	3540413	et	3	main
nimi	doc_873901597529_item	3540418	et	3	main
elus	doc_873901597529_item	3540428	et	4	main
on	doc_873901597529_item	3540429	et	4	main
on	doc_873901597529_item	3540465	et	4	main
amet	doc_873901597529_item	3540466	et	3	main
eesti	doc_873901597529_item	3540469	et	4	main
raadiot	doc_873901597529_item	3540486	et	3	main
arstidega	doc_873901597529_item	3540496	et	3	main
küllaldaselt	doc_873901597529_item	3540518	et	4	main
keele	doc_873901597529_item	3540527	et	4	main
ja	doc_464301607718_item	3540545	et	3	main
saadate	doc_464301607718_item	3540546	et	3	main
kirjutage	doc_464301607718_item	3540551	et	3	main
mida	doc_464301607718_item	3540557	et	4	main
joonitud	doc_464301607718_item	3540567	et	4	main
sisse	doc_464301607718_item	3540569	et	4	main
kirjutanud	doc_464301607718_item	3540586	et	4	main
suur	doc_464301607718_item	3540587	et	3	main
elad	doc_464301607718_item	3540594	et	3	main
käib	doc_464301607718_item	3540597	et	3	main
perekond	doc_464301607718_item	3540600	et	3	main
läbi	doc_491521501949_item	3540633	et	4	main
ja	doc_491521501949_item	3540636	et	3	main
tallinnasse	doc_491521501949_item	3540650	et	3	main
lugege	doc_491521502032_item	3540709	et	3	main
ja	doc_491521502032_item	3540713	et	3	main
kirjutage	doc_491521502032_item	3540714	et	3	main
palun	doc_491521502032_item	3540723	et	3	main
mulle	doc_491521502032_item	3540724	et	4	main
sa	doc_491521502032_item	3540726	et	3	main
tuled	doc_491521502032_item	3540728	et	4	main
kuhu	doc_491521502032_item	3540736	et	3	main
tallinnas	doc_491521502032_item	3540738	et	4	main
kiri	doc_600559929004_item	3540781	et	3	main
venemaale	doc_600559929004_item	3540785	et	4	main
maria	doc_600559929004_item	3540836	et	4	main
armastab	doc_600559929004_item	3540837	et	3	main
me	doc_600559929004_item	3540840	et	4	main
reisi	doc_600559929004_item	3540844	et	4	main
kaks	doc_600559929004_item	3540846	et	3	main
kavatseme	doc_600559929004_item	3540850	et	3	main
ja	doc_600559929004_item	3540857	et	3	main
linna	doc_600559929004_item	3540859	et	4	main
kirjuta	doc_901133458188_item	3540881	et	4	main
neile	doc_901133458188_item	3540895	et	4	main
näitasid	doc_901133458188_item	3540896	et	4	main
kirja	doc_901133458188_item	3540908	et	4	main
käisid	doc_901133458188_item	3540931	et	4	main
külas	doc_901133458188_item	3540932	et	3	main
lutherikirikus	doc_901133458188_item	3540948	et	4	main
vaatasime	doc_901133458188_item	3540952	et	3	main
forelli	doc_901133458188_item	3540958	et	4	main
tee	doc_901133458188_item	3540967	et	4	main
ajal	doc_901133458188_item	3540968	et	4	main
tulime	doc_901133458188_item	3540970	et	3	main
kõike	doc_901133458188_item	3540973	et	4	main
sõita	doc_600559929003_item	3540370	et	3	main
piletid	doc_600559929003_item	3540371	et	3	main
on	doc_600559929003_item	3540372	et	4	main
väga	doc_600559929003_item	3540373	et	3	main
kallis	doc_600559929003_item	3540374	et	4	main
nad	doc_600559929003_item	3540375	et	3	main
maksavad	doc_600559929003_item	3540376	et	3	main
tuhat	doc_600559929003_item	3540377	et	4	main
krooni	doc_600559929003_item	3540378	et	4	main
me	doc_600559929003_item	3540379	et	4	main
sõidame	doc_600559929003_item	3540380	et	3	main
rongiga	doc_600559929003_item	3540381	et	4	main
meile	doc_600559929003_item	3540382	et	4	main
on	doc_600559929003_item	3540383	et	4	main
vaja	doc_600559929003_item	3540384	et	4	main
sõita	doc_600559929003_item	3540385	et	3	main
kaks	doc_600559929003_item	3540386	et	3	main
päeva	doc_600559929003_item	3540387	et	4	main
seal	doc_600559929003_item	3540388	et	4	main
me	doc_600559929003_item	3540389	et	4	main
te	doc_600559929003_item	3540292	et	4	main
plaanite	doc_600559929003_item	3540293	et	3	main
reisi	doc_600559929003_item	3540294	et	4	main
venemaale	doc_600559929003_item	3540295	et	4	main
oma	doc_600559929003_item	3540299	et	4	main
te	doc_600559929003_item	3540306	et	4	main
soovite	doc_600559929003_item	3540308	et	3	main
reisite	doc_600559929003_item	3540310	et	3	main
ööbite	doc_600559929003_item	3540312	et	3	main
palju	doc_600559929003_item	3540314	et	4	main
kohtades	doc_600559929003_item	3540318	et	3	main
tere	doc_600559929003_item	3540326	et	3	main
on	doc_600559929003_item	3540336	et	4	main
sinule	doc_600559929003_item	3540339	et	3	main
külas	doc_600559929003_item	3540352	et	3	main
tütrega	doc_600559929003_item	3540360	et	3	main
tütar	doc_600559929003_item	3540362	et	3	main
eksaamit	doc_600559929003_item	3540364	et	4	main
on	doc_873901597529_item	3540419	et	4	main
perekonnanimi	doc_873901597529_item	3540421	et	3	main
eesti	doc_873901597529_item	3540474	et	4	main
internetis	doc_873901597529_item	3540482	et	4	main
ma	doc_873901597529_item	3540483	et	3	main
tahan	doc_873901597529_item	3540484	et	3	main
kuulata	doc_873901597529_item	3540485	et	4	main
vaata	doc_873901597529_item	3540488	et	4	main
loodan	doc_873901597529_item	3540503	et	3	main
põhjalikult	doc_873901597529_item	3540507	et	4	main
ja	doc_873901597529_item	3540509	et	3	main
aja	doc_873901597529_item	3540519	et	4	main
jaoks	doc_873901597529_item	3540529	et	4	main
loodan	doc_873901597529_item	3540530	et	3	main
oma	doc_464301607718_item	3540548	et	4	main
kus	doc_464301607718_item	3540553	et	3	main
kasti	doc_464301607718_item	3540568	et	4	main
umbes	doc_464301607718_item	3540574	et	4	main
100	doc_464301607718_item	3540575	et	2	main
kallis	doc_464301607718_item	3540579	et	4	main
tänu	doc_464301607718_item	3540588	et	4	main
lugege	doc_491521501949_item	3540632	et	3	main
kiri	doc_491521501949_item	3540635	et	3	main
kirjutage	doc_491521501949_item	3540637	et	3	main
vastus	doc_491521501949_item	3540639	et	3	main
kus	doc_491521501949_item	3540640	et	3	main
mulle	doc_491521501949_item	3540647	et	4	main
mitu	doc_491521501949_item	3540652	et	4	main
sa	doc_491521501949_item	3540654	et	3	main
juures	doc_491521501949_item	3540656	et	4	main
kuhu	doc_491521501949_item	3540659	et	3	main
tallinnas	doc_491521501949_item	3540661	et	4	main
marguse	doc_491521502032_item	3540711	et	4	main
tere	doc_491521502032_item	3540721	et	3	main
tallinnasse	doc_491521502032_item	3540727	et	3	main
mitu	doc_491521502032_item	3540729	et	4	main
päeva	doc_491521502032_item	3540730	et	4	main
sa	doc_491521502032_item	3540731	et	3	main
minu	doc_491521502032_item	3540732	et	3	main
teatrisse	doc_491521502032_item	3540778	et	3	main
kirjutage	doc_600559929004_item	3540786	et	3	main
sõbrale	doc_600559929004_item	3540791	et	3	main
ja	doc_600559929004_item	3540794	et	3	main
ma	doc_600559929004_item	3540831	et	3	main
sõidan	doc_600559929004_item	3540832	et	3	main
minu	doc_600559929004_item	3540833	et	3	main
vanaema	doc_600559929004_item	3540839	et	4	main
maksab	doc_600559929004_item	3540845	et	3	main
on	doc_600559929004_item	3540855	et	4	main
suur	doc_600559929004_item	3540856	et	3	main
kiri	doc_901133458188_item	3540884	et	3	main
et	doc_901133458188_item	3540885	et	3	main
sugulased	doc_901133458188_item	3540889	et	3	main
missuguseid	doc_901133458188_item	3540891	et	3	main
kirjuta	doc_901133458188_item	3540897	et	4	main
kus	doc_901133458188_item	3540898	et	3	main
te	doc_901133458188_item	3540899	et	4	main
käisite	doc_901133458188_item	3540900	et	3	main
mida	doc_901133458188_item	3540901	et	4	main
tegite	doc_901133458188_item	3540902	et	3	main
ja	doc_901133458188_item	3540903	et	3	main
kuidas	doc_901133458188_item	3540904	et	3	main
pikkus	doc_901133458188_item	3540909	et	4	main
100	doc_901133458188_item	3540911	et	2	main
tere	doc_901133458188_item	3540915	et	3	main
muuseumi	doc_901133458188_item	3540944	et	4	main
ümbruskonda	doc_901133458188_item	3540953	et	4	main
hea	doc_901133458188_item	3540959	et	4	main
telerit	doc_873901597529_item	3540489	et	3	main
eesti	doc_873901597529_item	3540490	et	4	main
kanalidel	doc_873901597529_item	3540491	et	4	main
ma	doc_873901597529_item	3540492	et	3	main
tahan	doc_873901597529_item	3540493	et	3	main
rääkida	doc_873901597529_item	3540494	et	3	main
kollegidega	doc_873901597529_item	3540495	et	4	main
minu	doc_873901597529_item	3540417	et	3	main
olen	doc_873901597529_item	3540422	et	3	main
pere	doc_873901597529_item	3540431	et	4	main
ma	doc_873901597529_item	3540432	et	3	main
jalutada	doc_873901597529_item	3540435	et	3	main
mulle	doc_873901597529_item	3540438	et	4	main
meeldib	doc_873901597529_item	3540439	et	3	main
minu	doc_873901597529_item	3540440	et	3	main
töö	doc_873901597529_item	3540441	et	4	main
eesti	doc_873901597529_item	3540442	et	4	main
keelt	doc_873901597529_item	3540443	et	4	main
olen	doc_873901597529_item	3540444	et	3	main
õppinud	doc_873901597529_item	3540445	et	4	main
kaks	doc_873901597529_item	3540446	et	3	main
aastat	doc_873901597529_item	3540447	et	3	main
aga	doc_873901597529_item	3540448	et	3	main
viis	doc_873901597529_item	3540449	et	4	main
aastat	doc_873901597529_item	3540450	et	3	main
tagasi	doc_873901597529_item	3540451	et	3	main
esimene	doc_873901597529_item	3540452	et	3	main
põhjus	doc_873901597529_item	3540453	et	4	main
miks	doc_873901597529_item	3540454	et	4	main
tulin	doc_873901597529_item	3540455	et	3	main
sellele	doc_873901597529_item	3540456	et	4	main
kursustele	doc_873901597529_item	3540457	et	3	main
on	doc_873901597529_item	3540458	et	4	main
soov	doc_873901597529_item	3540459	et	3	main
rääkida	doc_873901597529_item	3540460	et	3	main
eesti	doc_873901597529_item	3540461	et	4	main
keelt	doc_873901597529_item	3540462	et	4	main
teine	doc_873901597529_item	3540463	et	3	main
põhjus	doc_873901597529_item	3540464	et	4	main
osata	doc_873901597529_item	3540468	et	4	main
kellt	doc_873901597529_item	3540470	et	4	main
kesktasel	doc_873901597529_item	3540471	et	4	main
mul	doc_873901597529_item	3540472	et	3	main
on	doc_873901597529_item	3540473	et	4	main
ja	doc_873901597529_item	3540480	et	3	main
artikleid	doc_873901597529_item	3540481	et	3	main
tegeleme	doc_873901597529_item	3540506	et	3	main
natuke	doc_873901597529_item	3540513	et	4	main
kõnepraktika	doc_873901597529_item	3540520	et	4	main
teada	doc_873901597529_item	3540524	et	3	main
arvutiprogrammidest	doc_873901597529_item	3540525	et	3	main
kiri	doc_464301607718_item	3540540	et	3	main
eestimaal	doc_464301607718_item	3540544	et	4	main
sõbrale	doc_464301607718_item	3540550	et	3	main
näinud	doc_464301607718_item	3540559	et	4	main
ja	doc_464301607718_item	3540560	et	3	main
teinud	doc_464301607718_item	3540561	et	4	main
ning	doc_464301607718_item	3540562	et	3	main
kirja	doc_464301607718_item	3540570	et	4	main
nõutav	doc_464301607718_item	3540571	et	4	main
sõna	doc_464301607718_item	3540576	et	4	main
sulle	doc_464301607718_item	3540589	et	3	main
kirja	doc_464301607718_item	3540590	et	4	main
eest	doc_464301607718_item	3540591	et	4	main
kuidas	doc_464301607718_item	3540592	et	3	main
käsi	doc_464301607718_item	3540596	et	4	main
lapsed	doc_464301607718_item	3540602	et	3	main
kiri	doc_491521501949_item	3540631	et	3	main
marguse	doc_491521501949_item	3540634	et	4	main
talle	doc_491521501949_item	3540638	et	4	main
on	doc_491521501949_item	3540641	et	4	main
20-25	doc_491521501949_item	3540642	et	2	main
millal	doc_491521501949_item	3540648	et	3	main
tuled	doc_491521501949_item	3540651	et	4	main
minu	doc_491521501949_item	3540655	et	3	main
oled	doc_491521501949_item	3540657	et	3	main
sõna	doc_491521502032_item	3540720	et	4	main
millal	doc_491521502032_item	3540725	et	3	main
sa	doc_491521502032_item	3540737	et	3	main
plaanite	doc_600559929004_item	3540783	et	3	main
oma	doc_600559929004_item	3540838	et	4	main
see	doc_600559929004_item	3540843	et	3	main
tuhand	doc_600559929004_item	3540847	et	4	main
elada	doc_600559929004_item	3540851	et	3	main
et	doc_873901597529_item	3540514	et	3	main
meil	doc_873901597529_item	3540515	et	4	main
õppimise	doc_873901597529_item	3540528	et	4	main
et	doc_873901597529_item	3540531	et	3	main
me	doc_873901597529_item	3540532	et	4	main
teeme	doc_873901597529_item	3540533	et	3	main
kaastööd	doc_873901597529_item	3540534	et	4	main
hästi	doc_873901597529_item	3540535	et	3	main
lugupidamisega	doc_873901597529_item	3540536	et	3	main
eesnimi	doc_873901597529_item	3540537	et	3	main
perekonnanimi	doc_873901597529_item	3540538	et	3	main
sõidanut	doc_464301607718_item	3540621	et	4	main
hommikul	doc_464301607718_item	3540622	et	3	main
laupäeval	doc_464301607718_item	3540623	et	3	main
autoga	doc_464301607718_item	3540624	et	3	main
haapsalu	doc_464301607718_item	3540625	et	4	main
ja	doc_464301607718_item	3540626	et	3	main
haapsalust	doc_464301607718_item	3540627	et	4	main
praamuga	doc_464301607718_item	3540628	et	4	main
saaremaale	doc_464301607718_item	3540629	et	4	main
te	doc_464301607718_item	3540541	et	4	main
puhkusereisil	doc_464301607718_item	3540543	et	3	main
kirja	doc_464301607718_item	3540547	et	4	main
huvitavat	doc_464301607718_item	3540558	et	4	main
pikkus	doc_464301607718_item	3540572	et	4	main
tere	doc_464301607718_item	3540577	et	3	main
sõber	doc_464301607718_item	3540580	et	3	main
vabanda	doc_464301607718_item	3540582	et	4	main
et	doc_464301607718_item	3540583	et	3	main
kaua	doc_464301607718_item	3540584	et	3	main
ei	doc_464301607718_item	3540585	et	4	main
sa	doc_464301607718_item	3540593	et	3	main
sinu	doc_464301607718_item	3540599	et	3	main
ja	doc_464301607718_item	3540601	et	3	main
mul	doc_464301607718_item	3540603	et	3	main
on	doc_464301607718_item	3540604	et	4	main
kõik	doc_464301607718_item	3540605	et	4	main
korras	doc_464301607718_item	3540606	et	4	main
ma	doc_464301607718_item	3540607	et	3	main
elan	doc_464301607718_item	3540608	et	3	main
hästi	doc_464301607718_item	3540609	et	3	main
ma	doc_464301607718_item	3540610	et	3	main
olen	doc_464301607718_item	3540611	et	3	main
käinud	doc_464301607718_item	3540612	et	4	main
puhkusel	doc_464301607718_item	3540613	et	4	main
saaremaale	doc_464301607718_item	3540614	et	4	main
minu	doc_464301607718_item	3540615	et	3	main
abikaasaga	doc_464301607718_item	3540616	et	3	main
ja	doc_464301607718_item	3540617	et	3	main
sõpraga	doc_464301607718_item	3540618	et	4	main
me	doc_464301607718_item	3540619	et	4	main
oleme	doc_464301607718_item	3540620	et	3	main
sa	doc_491521501949_item	3540683	et	3	main
oled	doc_491521501949_item	3540684	et	3	main
nõus	doc_491521501949_item	3540685	et	4	main
siis	doc_491521501949_item	3540686	et	3	main
elan	doc_491521501949_item	3540687	et	3	main
sinu	doc_491521501949_item	3540688	et	3	main
juures	doc_491521501949_item	3540689	et	4	main
terve	doc_491521501949_item	3540690	et	4	main
nädal	doc_491521501949_item	3540691	et	3	main
sellepärast	doc_491521501949_item	3540692	et	3	main
et	doc_491521501949_item	3540693	et	3	main
tahan	doc_491521501949_item	3540694	et	3	main
väga	doc_491521501949_item	3540695	et	3	main
palju	doc_491521501949_item	3540696	et	4	main
vaadata	doc_491521501949_item	3540697	et	4	main
näiteks	doc_491521501949_item	3540698	et	4	main
loomaaed	doc_491521501949_item	3540699	et	3	main
vanalinn	doc_491521501949_item	3540700	et	3	main
mälestuskivid	doc_491521501949_item	3540701	et	3	main
pirita	doc_491521501949_item	3540702	et	4	main
ja	doc_491521501949_item	3540703	et	3	main
palju	doc_491521501949_item	3540704	et	4	main
muud	doc_491521501949_item	3540705	et	4	main
eesnimi	doc_491521501949_item	3540706	et	3	main
sõna	doc_491521501949_item	3540643	et	4	main
sa	doc_491521501949_item	3540649	et	3	main
ja	doc_491521501949_item	3540658	et	3	main
sa	doc_491521501949_item	3540660	et	3	main
minna	doc_491521501949_item	3540662	et	3	main
tahad	doc_491521501949_item	3540663	et	3	main
jään	doc_491521501949_item	3540664	et	3	main
vastust	doc_491521501949_item	3540665	et	4	main
ootama	doc_491521501949_item	3540666	et	3	main
margus	doc_491521501949_item	3540667	et	3	main
tere	doc_491521501949_item	3540668	et	3	main
margus	doc_491521501949_item	3540669	et	3	main
sain	doc_491521501949_item	3540670	et	3	main
sinust	doc_491521501949_item	3540671	et	3	main
kirju	doc_491521501949_item	3540672	et	4	main
tallinnasse	doc_491521501949_item	3540673	et	3	main
mina	doc_491521501949_item	3540674	et	4	main
planeerin	doc_491521501949_item	3540675	et	3	main
tulla	doc_491521501949_item	3540676	et	3	main
järgmisel	doc_491521501949_item	3540677	et	3	main
nädalal	doc_491521501949_item	3540678	et	3	main
mõtlen	doc_491521501949_item	3540679	et	3	main
et	doc_491521501949_item	3540680	et	3	main
reede	doc_491521501949_item	3540681	et	4	main
kui	doc_491521501949_item	3540682	et	3	main
kiri	doc_491521502032_item	3540708	et	3	main
läbi	doc_491521502032_item	3540710	et	4	main
kiri	doc_491521502032_item	3540712	et	3	main
talle	doc_491521502032_item	3540715	et	4	main
vastus	doc_491521502032_item	3540716	et	3	main
kus	doc_491521502032_item	3540717	et	3	main
on	doc_491521502032_item	3540718	et	4	main
20-25	doc_491521502032_item	3540719	et	2	main
juures	doc_491521502032_item	3540733	et	4	main
oled	doc_491521502032_item	3540734	et	3	main
nägemiseni	doc_491521502032_item	3540779	et	4	main
kirjuta	doc_491521502032_item	3540722	et	4	main
ja	doc_491521502032_item	3540735	et	3	main
minna	doc_491521502032_item	3540739	et	3	main
tahad	doc_491521502032_item	3540740	et	3	main
jään	doc_491521502032_item	3540741	et	3	main
vastust	doc_491521502032_item	3540742	et	4	main
ootama	doc_491521502032_item	3540743	et	3	main
margus	doc_491521502032_item	3540744	et	3	main
tere	doc_491521502032_item	3540745	et	3	main
margus	doc_491521502032_item	3540746	et	3	main
sain	doc_491521502032_item	3540747	et	3	main
sinu	doc_491521502032_item	3540748	et	3	main
kirja	doc_491521502032_item	3540749	et	4	main
kätte	doc_491521502032_item	3540750	et	4	main
ja	doc_491521502032_item	3540751	et	3	main
kohe	doc_491521502032_item	3540752	et	4	main
kirjuatan	doc_491521502032_item	3540753	et	4	main
vastust	doc_491521502032_item	3540754	et	4	main
ma	doc_491521502032_item	3540755	et	3	main
tulen	doc_491521502032_item	3540756	et	3	main
sinu	doc_491521502032_item	3540757	et	3	main
juurde	doc_491521502032_item	3540758	et	4	main
tallinnasse	doc_491521502032_item	3540759	et	3	main
kahe	doc_491521502032_item	3540760	et	3	main
päeva	doc_491521502032_item	3540761	et	4	main
pärast	doc_491521502032_item	3540762	et	4	main
ja	doc_491521502032_item	3540763	et	3	main
san	doc_491521502032_item	3540764	et	4	main
olla	doc_491521502032_item	3540765	et	3	main
sinu	doc_491521502032_item	3540766	et	3	main
juures	doc_491521502032_item	3540767	et	4	main
neli	doc_491521502032_item	3540768	et	3	main
päeva	doc_491521502032_item	3540769	et	4	main
ma	doc_491521502032_item	3540770	et	3	main
väga	doc_491521502032_item	3540771	et	3	main
tahan	doc_491521502032_item	3540772	et	3	main
vaadata	doc_491521502032_item	3540773	et	4	main
vanalinna	doc_491521502032_item	3540774	et	4	main
ja	doc_491521502032_item	3540775	et	3	main
tingimalt	doc_491521502032_item	3540776	et	3	main
minna	doc_491521502032_item	3540777	et	3	main
seal	doc_600559929004_item	3540860	et	4	main
on	doc_600559929004_item	3540861	et	4	main
ilus	doc_600559929004_item	3540862	et	4	main
kunstimuseum	doc_600559929004_item	3540863	et	4	main
seal	doc_600559929004_item	3540864	et	4	main
on	doc_600559929004_item	3540865	et	4	main
minu	doc_600559929004_item	3540866	et	3	main
ülikooli	doc_600559929004_item	3540867	et	4	main
ja	doc_600559929004_item	3540868	et	3	main
palju	doc_600559929004_item	3540869	et	4	main
minu	doc_600559929004_item	3540870	et	3	main
sõpru	doc_600559929004_item	3540871	et	3	main
me	doc_600559929004_item	3540872	et	4	main
oleme	doc_600559929004_item	3540873	et	3	main
seal	doc_600559929004_item	3540874	et	4	main
üks	doc_600559929004_item	3540875	et	3	main
nädel	doc_600559929004_item	3540876	et	4	main
nägemisene	doc_600559929004_item	3540877	et	4	main
eesnimi	doc_600559929004_item	3540878	et	3	main
reisi	doc_600559929004_item	3540784	et	4	main
sellest	doc_600559929004_item	3540787	et	4	main
oma	doc_600559929004_item	3540789	et	4	main
kirjutage	doc_600559929004_item	3540792	et	3	main
kuhu	doc_600559929004_item	3540795	et	3	main
millistes	doc_600559929004_item	3540807	et	3	main
kohtades	doc_600559929004_item	3540808	et	3	main
peatute	doc_600559929004_item	3540809	et	4	main
kirja	doc_600559929004_item	3540810	et	4	main
nõutav	doc_600559929004_item	3540811	et	4	main
pikkus	doc_600559929004_item	3540812	et	4	main
umbes	doc_600559929004_item	3540813	et	4	main
80	doc_600559929004_item	3540814	et	2	main
sõna	doc_600559929004_item	3540815	et	4	main
kohtla	doc_600559929004_item	3540816	et	4	main
jarve	doc_600559929004_item	3540817	et	4	main
8062005г	doc_600559929004_item	3540818	et	2	main
tere	doc_600559929004_item	3540819	et	3	main
anu	doc_600559929004_item	3540820	et	4	main
ma	doc_600559929004_item	3540821	et	3	main
plaanin	doc_600559929004_item	3540822	et	3	main
reisi	doc_600559929004_item	3540823	et	4	main
venemaale	doc_600559929004_item	3540824	et	4	main
ma	doc_600559929004_item	3540825	et	3	main
sõidan	doc_600559929004_item	3540826	et	3	main
mordvasse	doc_600559929004_item	3540827	et	4	main
minu	doc_600559929004_item	3540828	et	3	main
ema	doc_600559929004_item	3540829	et	4	main
juurde	doc_600559929004_item	3540830	et	4	main
te	doc_600559929004_item	3540782	et	4	main
kiri	doc_600559929004_item	3540788	et	3	main
eestlasest	doc_600559929004_item	3540790	et	3	main
millal	doc_600559929004_item	3540793	et	3	main
te	doc_600559929004_item	3540796	et	4	main
sõita	doc_600559929004_item	3540797	et	3	main
soovite	doc_600559929004_item	3540798	et	3	main
millega	doc_600559929004_item	3540799	et	3	main
reisite	doc_600559929004_item	3540800	et	3	main
kus	doc_600559929004_item	3540801	et	3	main
ööbite	doc_600559929004_item	3540802	et	3	main
kui	doc_600559929004_item	3540803	et	3	main
palju	doc_600559929004_item	3540804	et	4	main
see	doc_600559929004_item	3540805	et	3	main
maksab	doc_600559929004_item	3540806	et	3	main
tütruga	doc_600559929004_item	3540834	et	4	main
maria	doc_600559929004_item	3540835	et	4	main
sõidame	doc_600559929004_item	3540841	et	3	main
kroni	doc_600559929004_item	3540848	et	4	main
me	doc_600559929004_item	3540849	et	4	main
saranski	doc_600559929004_item	3540852	et	4	main
linnas	doc_600559929004_item	3540853	et	4	main
ilus	doc_600559929004_item	3540858	et	4	main
oma	doc_901133458188_item	3540882	et	4	main
käisid	doc_901133458188_item	3540887	et	4	main
neile	doc_901133458188_item	3540905	et	4	main
kallis	doc_901133458188_item	3540913	et	4	main
aitäh	doc_901133458188_item	3540916	et	3	main
me	doc_901133458188_item	3540933	et	4	main
vaatasin	doc_901133458188_item	3540936	et	3	main
väga	doc_901133458188_item	3540938	et	3	main
värvikas	doc_901133458188_item	3540940	et	4	main
linn	doc_901133458188_item	3540941	et	3	main
me	doc_901133458188_item	3540942	et	4	main
külastasime	doc_901133458188_item	3540943	et	3	main
kus	doc_901133458188_item	3540956	et	3	main
kirja	doc_901133458188_item	3540978	et	4	main
ootan	doc_901133458188_item	3540979	et	3	main
sinu	doc_901133458188_item	3540980	et	3	main
vastust	doc_901133458188_item	3540981	et	4	main
tervita	doc_901133458188_item	3540982	et	4	main
minu	doc_901133458188_item	3540983	et	3	main
autos	doc_600559929004_item	3540842	et	3	main
saransk	doc_600559929004_item	3540854	et	4	main
kiri	doc_901133458188_item	3540880	et	3	main
sul	doc_901133458188_item	3540886	et	3	main
narva	doc_901133458188_item	3540892	et	4	main
vaatamisväärsusi	doc_901133458188_item	3540893	et	4	main
sa	doc_901133458188_item	3540894	et	3	main
meeldis	doc_901133458188_item	3540907	et	3	main
sõna	doc_901133458188_item	3540912	et	4	main
alla	doc_901133458188_item	3540914	et	3	main
jalutasime	doc_901133458188_item	3540934	et	3	main
narvat	doc_901133458188_item	3540937	et	4	main
ilus	doc_901133458188_item	3540939	et	4	main
käisime	doc_901133458188_item	3540947	et	3	main
kuulsime	doc_901133458188_item	3540949	et	3	main
elusat	doc_901133458188_item	3540950	et	3	main
orelimuusikat	doc_901133458188_item	3540951	et	3	main
puhketsooni	doc_901133458188_item	3540955	et	4	main
päike	doc_901133458188_item	3540963	et	3	main
koju	doc_901133458188_item	3540969	et	3	main
täis	doc_901133458188_item	3540972	et	4	main
tiina	doc_685122975262_item	3541259	et	4	main
eesnimi	doc_685122975262_item	3541264	et	3	main
ja	doc_685122975262_item	3541266	et	3	main
ja	doc_685122975262_item	3541271	et	3	main
nimega	doc_685122975262_item	3541279	et	3	main
sa	doc_685122975262_item	3541282	et	3	main
lähed	doc_685122975262_item	3541284	et	3	main
palju	doc_685122975262_item	3541287	et	4	main
et	doc_685122975262_item	3541294	et	3	main
on	doc_685122975262_item	3541296	et	4	main
tagasisidet	doc_685122975262_item	3541299	et	4	main
selle	doc_685122975262_item	3541302	et	4	main
kohta	doc_685122975262_item	3541303	et	4	main
mul	doc_685122975262_item	3541304	et	3	main
oli	doc_685122975262_item	3541305	et	3	main
väga	doc_685122975262_item	3541306	et	3	main
huvitav	doc_685122975262_item	3541307	et	4	main
lugeda	doc_685122975262_item	3541308	et	3	main
see	doc_685122975262_item	3541309	et	3	main
artikel	doc_685122975262_item	3541310	et	4	main
ma	doc_685122975262_item	3541322	et	3	main
elan	doc_685122975262_item	3541323	et	3	main
nagu	doc_685122975262_item	3541341	et	3	main
vaba	doc_685122975262_item	3541356	et	4	main
ja	doc_685122975262_item	3541358	et	3	main
suurt	doc_685122975262_item	3541359	et	3	main
poolt	doc_901133458188_item	3540984	et	4	main
oma	doc_901133458188_item	3540985	et	4	main
abikaasat	doc_901133458188_item	3540986	et	3	main
heat	doc_901133458188_item	3540987	et	4	main
aega	doc_901133458188_item	3540988	et	4	main
eesnimi	doc_901133458188_item	3540989	et	3	main
sõbrale	doc_901133458188_item	3540883	et	3	main
külas	doc_901133458188_item	3540888	et	3	main
kirjuta	doc_901133458188_item	3540890	et	4	main
narvas	doc_901133458188_item	3540906	et	4	main
kuni	doc_901133458188_item	3540910	et	3	main
kirja	doc_901133458188_item	3540917	et	4	main
eest	doc_901133458188_item	3540918	et	4	main
on	doc_901133458188_item	3540919	et	4	main
meeldiv	doc_901133458188_item	3540920	et	4	main
et	doc_901133458188_item	3540921	et	3	main
sa	doc_901133458188_item	3540922	et	3	main
nii	doc_901133458188_item	3540923	et	3	main
kiiresti	doc_901133458188_item	3540924	et	3	main
vastasid	doc_901133458188_item	3540925	et	4	main
mul	doc_901133458188_item	3540926	et	3	main
on	doc_901133458188_item	3540927	et	4	main
kõik	doc_901133458188_item	3540928	et	4	main
korras	doc_901133458188_item	3540929	et	4	main
pühapäevasse	doc_901133458188_item	3540930	et	4	main
ma	doc_901133458188_item	3540935	et	3	main
ja	doc_901133458188_item	3540945	et	3	main
kunstimuuseumi	doc_901133458188_item	3540946	et	4	main
sõitsime	doc_901133458188_item	3540954	et	3	main
kasvatatakse	doc_901133458188_item	3540957	et	3	main
ilm	doc_901133458188_item	3540960	et	3	main
kevadine	doc_901133458188_item	3540962	et	4	main
olid	doc_901133458188_item	3540964	et	4	main
ka	doc_901133458188_item	3540961	et	3	main
meiega	doc_901133458188_item	3540965	et	4	main
kogu	doc_901133458188_item	3540966	et	4	main
muljeid	doc_901133458188_item	3540971	et	3	main
head	doc_901133458188_item	3540974	et	4	main
sulle	doc_901133458188_item	3540975	et	3	main
sellega	doc_901133458188_item	3540976	et	3	main
lõpetan	doc_901133458188_item	3540977	et	3	main
kiri	doc_685122975262_item	3541257	et	3	main
minu	doc_685122975262_item	3541261	et	3	main
tulevikus	doc_685122975262_item	3541288	et	4	main
palka	doc_685122975262_item	3541289	et	4	main
tahad	doc_685122975262_item	3541290	et	3	main
huvitav	doc_685122975262_item	3541297	et	4	main
arvamust	doc_685122975262_item	3541301	et	3	main
pärast	doc_685122975262_item	3541311	et	4	main
lugemist	doc_685122975262_item	3541312	et	4	main
palju	doc_685122975262_item	3541332	et	4	main
nõudlused	doc_685122975262_item	3541340	et	3	main
kooli	doc_685122975262_item	3541362	et	4	main
raskustega	doc_685122975262_item	3541368	et	4	main
tutvuvad	doc_685122975262_item	3541370	et	4	main
selliste	doc_685122975262_item	3541371	et	4	main
mõistetega	doc_685122975262_item	3541372	et	3	main
nagu	doc_685122975262_item	3541373	et	3	main
konkurents	doc_685122975262_item	3541374	et	3	main
ja	doc_685122975262_item	3541375	et	3	main
kooli	doc_685122975262_item	3541382	et	4	main
000	doc_685122975262_item	3541396	et	2	main
kuni	doc_685122975262_item	3541397	et	3	main
000	doc_685122975262_item	3541399	et	2	main
saades	doc_685122975262_item	3541403	et	3	main
spetsialistid	doc_685122975262_item	3541417	et	3	main
et	doc_685122975262_item	3541421	et	3	main
saavad	doc_685122975262_item	3541424	et	4	main
12	doc_685122975262_item	3541433	et	2	main
mina	doc_685122975262_item	3541435	et	4	main
arvan	doc_685122975262_item	3541436	et	3	main
nemad	doc_685122975262_item	3541438	et	3	main
oma	doc_685122975262_item	3541440	et	4	main
õppimine	doc_685122975262_item	3541445	et	4	main
lp	doc_685122975262_item	3541258	et	4	main
teie	doc_685122975262_item	3541276	et	4	main
artikli	doc_685122975262_item	3541277	et	3	main
kohta	doc_685122975262_item	3541278	et	4	main
õpima	doc_685122975262_item	3541283	et	4	main
ja	doc_685122975262_item	3541285	et	3	main
omapärane	doc_685122975262_item	3541314	et	4	main
arusaamine	doc_685122975262_item	3541315	et	4	main
on	doc_685122975262_item	3541338	et	4	main
ametlik	doc_685122975262_item	3541256	et	3	main
nimi	doc_685122975262_item	3541262	et	3	main
on	doc_685122975262_item	3541263	et	4	main
perekonnanimi	doc_685122975262_item	3541265	et	3	main
olen	doc_685122975262_item	3541268	et	3	main
tudeng	doc_685122975262_item	3541270	et	3	main
on	doc_685122975262_item	3541273	et	4	main
mõned	doc_685122975262_item	3541274	et	3	main
mõted	doc_685122975262_item	3541275	et	4	main
mis	doc_685122975262_item	3541280	et	4	main
saada	doc_685122975262_item	3541291	et	4	main
ma	doc_685122975262_item	3541292	et	3	main
usun	doc_685122975262_item	3541293	et	3	main
teil	doc_685122975262_item	3541295	et	4	main
saada	doc_685122975262_item	3541298	et	4	main
ja	doc_685122975262_item	3541300	et	3	main
sellest	doc_685122975262_item	3541316	et	4	main
mis	doc_685122975262_item	3541317	et	4	main
kui	doc_685122975262_item	3541333	et	3	main
ka	doc_685122975262_item	3541334	et	3	main
inimesi	doc_685122975262_item	3541335	et	4	main
maailmas	doc_685122975262_item	3541336	et	3	main
noortel	doc_685122975262_item	3541337	et	3	main
aega	doc_685122975262_item	3541357	et	4	main
lõpetades	doc_685122975262_item	3541363	et	3	main
elu	doc_685122975262_item	3541367	et	4	main
nad	doc_685122975262_item	3541369	et	3	main
kui	doc_685122975262_item	3541378	et	3	main
arvamusi	doc_685122975262_item	3541384	et	3	main
siis	doc_685122975262_item	3541385	et	3	main
tundub	doc_685122975262_item	3541386	et	3	main
suur	doc_685122975262_item	3541387	et	3	main
raha	doc_685122975262_item	3541401	et	4	main
jälgides	doc_685122975262_item	3541405	et	4	main
abiturienditel	doc_685122975262_item	3541407	et	4	main
pole	doc_685122975262_item	3541408	et	3	main
aimu	doc_685122975262_item	3541409	et	4	main
nad	doc_685122975262_item	3541419	et	3	main
7000	doc_685122975262_item	3541426	et	2	main
igakuiselt	doc_685122975262_item	3541428	et	4	main
tegelikult	doc_685122975262_item	3541429	et	4	main
et	doc_685122975262_item	3541437	et	3	main
liigvähendavad	doc_685122975262_item	3541439	et	3	main
ülikooli	doc_685122975262_item	3541442	et	4	main
iga	doc_685122975262_item	3541447	et	4	main
aastaga	doc_685122975262_item	3541448	et	3	main
raskemaks	doc_685122975262_item	3541449	et	4	main
oma	doc_685122975262_item	3541456	et	4	main
peab	doc_685122975262_item	3541467	et	4	main
tudengiga	doc_685122975262_item	3541470	et	3	main
15	doc_685122975262_item	3541501	et	2	main
000	doc_685122975262_item	3541502	et	2	main
krooni	doc_685122975262_item	3541503	et	4	main
igakuiselt	doc_685122975262_item	3541504	et	4	main
peale	doc_685122975262_item	3541505	et	4	main
õppimist	doc_685122975262_item	3541506	et	4	main
ma	doc_685122975262_item	3541507	et	3	main
tegelen	doc_685122975262_item	3541508	et	3	main
tantsimisega	doc_685122975262_item	3541509	et	4	main
ja	doc_685122975262_item	3541510	et	3	main
vabal	doc_685122975262_item	3541511	et	3	main
ajal	doc_685122975262_item	3541512	et	4	main
pildistan	doc_685122975262_item	3541513	et	3	main
ma	doc_685122975262_item	3541514	et	3	main
olen	doc_685122975262_item	3541515	et	3	main
rahul	doc_685122975262_item	3541516	et	4	main
oma	doc_685122975262_item	3541517	et	4	main
eluga	doc_685122975262_item	3541518	et	3	main
lugupidamisega	doc_685122975262_item	3541519	et	3	main
eesnimi	doc_685122975262_item	3541520	et	3	main
perekonnanimi	doc_685122975262_item	3541521	et	3	main
kaalep	doc_685122975262_item	3541260	et	4	main
ma	doc_685122975262_item	3541267	et	3	main
ttü	doc_685122975262_item	3541269	et	4	main
mul	doc_685122975262_item	3541272	et	3	main
eriala	doc_685122975262_item	3541281	et	4	main
kui	doc_685122975262_item	3541286	et	3	main
tuli	doc_685122975262_item	3541313	et	4	main
moodi	doc_685122975262_item	3541318	et	4	main
see	doc_685122975262_item	3541319	et	3	main
põlvkond	doc_685122975262_item	3541320	et	3	main
milles	doc_685122975262_item	3541321	et	3	main
üldvaates	doc_685122975262_item	3541324	et	3	main
välja	doc_685122975262_item	3541325	et	4	main
näeb	doc_685122975262_item	3541326	et	3	main
nagu	doc_685122975262_item	3541327	et	3	main
räägitakse	doc_685122975262_item	3541328	et	3	main
arvamusi	doc_685122975262_item	3541329	et	3	main
on	doc_685122975262_item	3541330	et	4	main
niisama	doc_685122975262_item	3541331	et	3	main
suured	doc_685122975262_item	3541339	et	3	main
ma	doc_685122975262_item	3541342	et	3	main
aru	doc_685122975262_item	3541343	et	4	main
sain	doc_685122975262_item	3541344	et	3	main
ühest	doc_685122975262_item	3541345	et	4	main
artiklist	doc_685122975262_item	3541346	et	4	main
nemad	doc_685122975262_item	3541347	et	3	main
tahavad	doc_685122975262_item	3541348	et	3	main
väärtusliku	doc_685122975262_item	3541349	et	3	main
ja	doc_685122975262_item	3541350	et	3	main
hinnatud	doc_685122975262_item	3541351	et	4	main
teiste	doc_685122975262_item	3541352	et	4	main
poolt	doc_685122975262_item	3541353	et	4	main
tööd	doc_685122975262_item	3541354	et	4	main
palju	doc_685122975262_item	3541355	et	4	main
putuvad	doc_685122975262_item	3541365	et	4	main
kokku	doc_685122975262_item	3541366	et	3	main
jäämine	doc_685122975262_item	3541377	et	4	main
võrrelda	doc_685122975262_item	3541379	et	4	main
abituriendite	doc_685122975262_item	3541380	et	4	main
ning	doc_685122975262_item	3541381	et	3	main
vahe	doc_685122975262_item	3541388	et	4	main
nende	doc_685122975262_item	3541389	et	4	main
vahel	doc_685122975262_item	3541390	et	4	main
kooli	doc_685122975262_item	3541391	et	4	main
õpilased	doc_685122975262_item	3541392	et	3	main
saades	doc_685122975262_item	3541422	et	3	main
arsti	doc_685122975262_item	3541430	et	4	main
palk	doc_685122975262_item	3541431	et	3	main
ületab	doc_685122975262_item	3541432	et	3	main
000	doc_685122975262_item	3541434	et	2	main
tekkivad	doc_685122975262_item	3541450	et	4	main
püüdlema	doc_685122975262_item	3541460	et	3	main
suurema	doc_685122975262_item	3541461	et	4	main
saamiseks	doc_685122975262_item	3541463	et	4	main
suhtlema	doc_685122975262_item	3541469	et	3	main
palka	doc_685122975262_item	3541360	et	4	main
kuid	doc_685122975262_item	3541361	et	4	main
000	doc_685122975262_item	3541400	et	2	main
ühikut	doc_685122975262_item	3541402	et	3	main
kõrgharidust	doc_685122975262_item	3541404	et	4	main
artiklit	doc_685122975262_item	3541406	et	3	main
peavad	doc_685122975262_item	3541413	et	4	main
saada	doc_685122975262_item	3541414	et	4	main
kindlate	doc_685122975262_item	3541415	et	3	main
ametite	doc_685122975262_item	3541416	et	3	main
arstiks	doc_685122975262_item	3541423	et	4	main
ligikaudu	doc_685122975262_item	3541425	et	3	main
ning	doc_685122975262_item	3541444	et	3	main
saab	doc_685122975262_item	3541446	et	3	main
uued	doc_685122975262_item	3541451	et	3	main
õppeained	doc_685122975262_item	3541452	et	3	main
hindamine	doc_685122975262_item	3541453	et	4	main
läheb	doc_685122975262_item	3541454	et	3	main
rangemaks	doc_685122975262_item	3541455	et	4	main
peavad	doc_685122975262_item	3541459	et	4	main
palga	doc_685122975262_item	3541462	et	3	main
õppejõud	doc_685122975262_item	3541464	et	4	main
oma	doc_685122975262_item	3541465	et	4	main
riigist	doc_685122975262_item	3541466	et	3	main
nemad	doc_685122975262_item	3541364	et	3	main
ellu	doc_685122975262_item	3541376	et	4	main
õpilaste	doc_685122975262_item	3541383	et	4	main
eelistaksid	doc_685122975262_item	3541393	et	4	main
saada	doc_685122975262_item	3541394	et	4	main
10	doc_685122975262_item	3541395	et	2	main
1	doc_685122975262_item	3541398	et	2	main
palju	doc_685122975262_item	3541410	et	4	main
saavad	doc_685122975262_item	3541411	et	4	main
või	doc_685122975262_item	3541412	et	4	main
näiteks	doc_685122975262_item	3541418	et	4	main
arvavad	doc_685122975262_item	3541420	et	4	main
krooni	doc_685122975262_item	3541427	et	4	main
nõudmisi	doc_685122975262_item	3541441	et	4	main
sisseastumine	doc_685122975262_item	3541443	et	3	main
spetsialistid	doc_685122975262_item	3541458	et	3	main
kiri	doc_685122975256_item	3541740	et	3	main
artikli	doc_685122975256_item	3541747	et	3	main
nõus	doc_685122975256_item	3541749	et	4	main
otsustavad	doc_685122975256_item	3541760	et	4	main
oma	doc_685122975256_item	3541761	et	4	main
artiklis	doc_685122975256_item	3541766	et	3	main
on	doc_685122975256_item	3541767	et	4	main
tea	doc_685122975256_item	3541773	et	4	main
tulnud	doc_685122975256_item	3541795	et	4	main
nende	doc_685122975256_item	3541803	et	4	main
punktidega	doc_685122975256_item	3541804	et	3	main
üldse	doc_685122975256_item	3541805	et	3	main
saab	doc_685122975256_item	3541806	et	3	main
minna	doc_685122975256_item	3541807	et	3	main
eriala	doc_685122975262_item	3541457	et	4	main
rohkem	doc_685122975262_item	3541468	et	4	main
sarnasel	doc_685122975262_item	3541471	et	4	main
teemal	doc_685122975262_item	3541472	et	3	main
et	doc_685122975262_item	3541473	et	3	main
õppijal	doc_685122975262_item	3541474	et	4	main
kujutleks	doc_685122975262_item	3541475	et	3	main
vaade	doc_685122975262_item	3541476	et	3	main
erialast	doc_685122975262_item	3541477	et	4	main
ja	doc_685122975262_item	3541478	et	3	main
palgast	doc_685122975262_item	3541479	et	4	main
praegu	doc_685122975262_item	3541480	et	3	main
ma	doc_685122975262_item	3541481	et	3	main
õpin	doc_685122975262_item	3541482	et	3	main
ehitajaks	doc_685122975262_item	3541483	et	4	main
aga	doc_685122975262_item	3541484	et	3	main
ei	doc_685122975262_item	3541485	et	4	main
ole	doc_685122975262_item	3541486	et	4	main
veel	doc_685122975262_item	3541487	et	4	main
otsustanud	doc_685122975262_item	3541488	et	4	main
kelleks	doc_685122975262_item	3541489	et	4	main
ma	doc_685122975262_item	3541490	et	3	main
tahan	doc_685122975262_item	3541491	et	3	main
täpselt	doc_685122975262_item	3541492	et	4	main
saada	doc_685122975262_item	3541493	et	4	main
oleks	doc_685122975262_item	3541494	et	3	main
hea	doc_685122975262_item	3541495	et	4	main
kui	doc_685122975262_item	3541496	et	3	main
esiteks	doc_685122975262_item	3541497	et	3	main
ma	doc_685122975262_item	3541498	et	3	main
saaks	doc_685122975262_item	3541499	et	3	main
umbes	doc_685122975262_item	3541500	et	4	main
lõplikud	doc_685122975255_item	3542040	et	3	main
19	doc_685122975255_item	3542041	et	2	main
juuniks	doc_685122975255_item	3542042	et	3	main
siis	doc_685122975255_item	3542043	et	3	main
jääb	doc_685122975255_item	3542044	et	3	main
vaid	doc_685122975255_item	3542045	et	3	main
mõni	doc_685122975255_item	3542046	et	3	main
päev	doc_685122975255_item	3542047	et	3	main
et	doc_685122975255_item	3542048	et	3	main
teha	doc_685122975255_item	3542049	et	3	main
otsus	doc_685122975255_item	3542050	et	3	main
mis	doc_685122975255_item	3542051	et	4	main
saadab	doc_685122975255_item	3542052	et	3	main
neid	doc_685122975255_item	3542053	et	4	main
kogu	doc_685122975255_item	3542054	et	4	main
elu	doc_685122975255_item	3542055	et	4	main
mina	doc_685122975255_item	3542056	et	4	main
rohkem	doc_685122975255_item	3542057	et	4	main
kaalep	doc_685122975256_item	3541743	et	4	main
riigieksamist	doc_685122975256_item	3541755	et	4	main
õpimist	doc_685122975256_item	3541763	et	4	main
saab	doc_685122975256_item	3541776	et	3	main
vaid	doc_685122975256_item	3541777	et	3	main
nädal	doc_685122975256_item	3541779	et	3	main
ülikoolidesse	doc_685122975256_item	3541781	et	3	main
see	doc_685122975256_item	3541791	et	3	main
uus	doc_685122975256_item	3541793	et	3	main
aasta	doc_685122975256_item	3541837	et	4	main
teine	doc_685122975256_item	3541838	et	3	main
rühm	doc_685122975256_item	3541839	et	3	main
rahulikult	doc_685122975256_item	3541845	et	4	main
noored	doc_685122975256_item	3541858	et	3	main
ega	doc_685122975256_item	3541865	et	3	main
teistkümnetunniseid	doc_685122975256_item	3541886	et	4	main
olid	doc_685122975256_item	3541891	et	4	main
kodune	doc_685122975256_item	3541892	et	4	main
idüll	doc_685122975256_item	3541893	et	3	main
mida	doc_685122975256_item	3541894	et	4	main
lastena	doc_685122975256_item	3541895	et	3	main
suurt	doc_685122975256_item	3541903	et	3	main
ma	doc_685122975256_item	3541913	et	3	main
nõus	doc_685122975256_item	3541914	et	4	main
palju	doc_685122975256_item	3541921	et	4	main
on	doc_685122975256_item	3541932	et	4	main
artikel	doc_685122975256_item	3541946	et	4	main
on	doc_685122975256_item	3541947	et	4	main
väga	doc_685122975256_item	3541948	et	3	main
artikel	doc_685122975256_item	3541955	et	4	main
mõtleksid	doc_685122975256_item	3541958	et	4	main
tiina	doc_685122975255_item	3541967	et	4	main
nõus	doc_685122975255_item	3541981	et	4	main
teega	doc_685122975255_item	3541982	et	3	main
see	doc_685122975255_item	3542017	et	3	main
teiga	doc_685122975255_item	3542064	et	4	main
lootus	doc_685122975255_item	3542066	et	4	main
on	doc_685122975255_item	3542067	et	4	main
katarina	doc_491521501797_item	3542074	et	3	main
sulle	doc_491521501797_item	3542080	et	3	main
sa	doc_491521501797_item	3542087	et	3	main
norras	doc_491521501797_item	3542096	et	4	main
tema	doc_491521501797_item	3542120	et	4	main
kuidas	doc_491521501797_item	3542121	et	3	main
ajal	doc_491521501797_item	3542146	et	4	main
minu	doc_491521501797_item	3542147	et	3	main
sõbranna	doc_491521501797_item	3542148	et	4	main
elab	doc_491521501797_item	3542149	et	3	main
praegu	doc_491521501797_item	3542150	et	3	main
seal	doc_491521501797_item	3542162	et	4	main
väga	doc_491521501797_item	3542163	et	3	main
meeldib	doc_491521501797_item	3542164	et	3	main
ja	doc_491521501797_item	3542165	et	3	main
et	doc_491521501797_item	3542166	et	3	main
et	doc_491521501797_item	3542173	et	3	main
ja	doc_491521501797_item	3542179	et	3	main
tiina	doc_685122975256_item	3541742	et	4	main
teie	doc_685122975256_item	3541746	et	4	main
ja	doc_685122975256_item	3541748	et	3	main
kõigega	doc_685122975256_item	3541750	et	3	main
nad	doc_685122975256_item	3541759	et	3	main
teie	doc_685122975256_item	3541765	et	4	main
mis	doc_685122975256_item	3541774	et	4	main
on	doc_685122975256_item	3541780	et	4	main
astumiseni	doc_685122975256_item	3541782	et	4	main
isegi	doc_685122975256_item	3541788	et	4	main
umbkaudu	doc_685122975256_item	3541789	et	3	main
mitte	doc_685122975256_item	3541790	et	3	main
koos	doc_685122975256_item	3541796	et	4	main
loteriiga	doc_685122975256_item	3541798	et	3	main
olen	doc_685122975256_item	3541822	et	3	main
sellega	doc_685122975256_item	3541824	et	3	main
aastas	doc_685122975256_item	3541826	et	3	main
ja	doc_685122975256_item	3541831	et	3	main
olen	doc_685122975256_item	3541833	et	3	main
kes	doc_685122975256_item	3541842	et	4	main
auto	doc_685122975256_item	3541853	et	4	main
soetada	doc_685122975256_item	3541854	et	3	main
oma	doc_685122975256_item	3541861	et	4	main
taha	doc_685122975256_item	3541866	et	4	main
tänased	doc_685122975256_item	3541869	et	3	main
olid	doc_685122975256_item	3541871	et	4	main
põnnid	doc_685122975256_item	3541872	et	3	main
kui	doc_685122975256_item	3541873	et	3	main
poed	doc_685122975256_item	3541874	et	4	main
lugupeetud	doc_685122975256_item	3541741	et	4	main
lugesin	doc_685122975256_item	3541745	et	3	main
mida	doc_685122975256_item	3541751	et	4	main
te	doc_685122975256_item	3541752	et	4	main
kirjutasite	doc_685122975256_item	3541753	et	3	main
noorest	doc_685122975256_item	3541754	et	3	main
tuleviku	doc_685122975256_item	3541762	et	4	main
kirjeldatud	doc_685122975256_item	3541768	et	4	main
üks	doc_685122975256_item	3541769	et	3	main
rühm	doc_685122975256_item	3541770	et	3	main
neist	doc_685122975256_item	3541775	et	4	main
mõni	doc_685122975256_item	3541778	et	3	main
aega	doc_685122975256_item	3541783	et	4	main
aga	doc_685122975256_item	3541784	et	3	main
neid	doc_685122975256_item	3541785	et	4	main
on	doc_685122975256_item	3541792	et	4	main
see	doc_685122975256_item	3541799	et	3	main
arvestus	doc_685122975256_item	3541801	et	4	main
aasta	doc_685122975256_item	3541827	et	4	main
situatsion	doc_685122975256_item	3541829	et	4	main
mina	doc_685122975256_item	3541832	et	4	main
inemesed	doc_685122975256_item	3541841	et	4	main
ja	doc_685122975256_item	3541847	et	3	main
täiesti	doc_685122975256_item	3541849	et	3	main
palka	doc_685122975256_item	3541851	et	4	main
liisida	doc_685122975256_item	3541852	et	4	main
on	doc_685122975256_item	3541859	et	4	main
näinud	doc_685122975256_item	3541860	et	4	main
90-ndatel	doc_685122975256_item	3541864	et	4	main
korrata	doc_685122975256_item	3541868	et	4	main
vaesed	doc_685122975256_item	3541879	et	4	main
tööpäevi	doc_685122975256_item	3541887	et	4	main
väga	doc_685122975256_item	3541888	et	3	main
palju	doc_685122975256_item	3541889	et	4	main
ei	doc_685122975256_item	3541896	et	4	main
kogetud	doc_685122975256_item	3541897	et	4	main
ihaldusväärne	doc_685122975256_item	3541901	et	3	main
võitlust	doc_685122975256_item	3541904	et	3	main
oma	doc_685122975256_item	3541905	et	4	main
ellu	doc_685122975256_item	3541906	et	4	main
aega	doc_685122975256_item	3541912	et	4	main
kui	doc_685122975256_item	3541916	et	3	main
oli	doc_685122975256_item	3541924	et	3	main
mulle	doc_685122975256_item	3541926	et	4	main
stabiilsus	doc_685122975256_item	3541931	et	4	main
ka	doc_685122975256_item	3541937	et	3	main
mõtlen	doc_685122975256_item	3541952	et	3	main
hakkas	doc_685122975256_item	3541956	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975256_item	3541962	et	4	main
tere	doc_685122975255_item	3541965	et	3	main
minu	doc_685122975255_item	3541969	et	3	main
nimi	doc_685122975255_item	3541970	et	3	main
eesnimi	doc_685122975255_item	3541972	et	3	main
õpin	doc_685122975255_item	3541975	et	3	main
et	doc_685122975255_item	3541983	et	3	main
arstid	doc_685122975255_item	3541984	et	4	main
teise	doc_685122975255_item	3542059	et	4	main
aastakäikude	doc_685122975255_item	3542069	et	3	main
peal	doc_685122975255_item	3542070	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975255_item	3542071	et	4	main
vabanda	doc_491521501797_item	3542075	et	4	main
luban	doc_491521501797_item	3542082	et	3	main
aeg	doc_491521501797_item	3542084	et	3	main
lendab	doc_491521501797_item	3542086	et	3	main
kes	doc_491521501797_item	3542094	et	4	main
elab	doc_491521501797_item	3542095	et	3	main
tahad	doc_491521501797_item	3542105	et	3	main
ta	doc_491521501797_item	3542122	et	4	main
elab	doc_491521501797_item	3542123	et	3	main
helena	doc_491521501797_item	3542124	et	4	main
kirjutas	doc_491521501797_item	3542125	et	3	main
ametlik	doc_685122975256_item	3541739	et	3	main
ma	doc_685122975256_item	3541744	et	3	main
ja	doc_685122975256_item	3541756	et	3	main
ajast	doc_685122975256_item	3541757	et	4	main
kui	doc_685122975256_item	3541758	et	3	main
kohast	doc_685122975256_item	3541764	et	4	main
kes	doc_685122975256_item	3541771	et	4	main
ei	doc_685122975256_item	3541772	et	4	main
ei	doc_685122975256_item	3541786	et	4	main
tea	doc_685122975256_item	3541787	et	4	main
asi	doc_685122975256_item	3541794	et	4	main
riigieksamite	doc_685122975256_item	3541797	et	3	main
kaine	doc_685122975256_item	3541800	et	4	main
kuhu	doc_685122975256_item	3541802	et	3	main
neil	doc_685122975256_item	3541808	et	4	main
abiturientidel	doc_685122975256_item	3541809	et	3	main
pole	doc_685122975256_item	3541810	et	3	main
peale	doc_685122975256_item	3541811	et	4	main
sisetunde	doc_685122975256_item	3541812	et	4	main
kuidas	doc_685122975256_item	3541813	et	3	main
eksamid	doc_685122975256_item	3541814	et	3	main
läksid	doc_685122975256_item	3541815	et	4	main
tegelikult	doc_685122975256_item	3541816	et	4	main
midagi	doc_685122975256_item	3541817	et	4	main
millele	doc_685122975256_item	3541818	et	3	main
tulevikuplaane	doc_685122975256_item	3541819	et	3	main
rajada	doc_685122975256_item	3541820	et	3	main
ma	doc_685122975256_item	3541821	et	3	main
nõus	doc_685122975256_item	3541823	et	4	main
et	doc_685122975256_item	3541825	et	3	main
on	doc_685122975256_item	3541830	et	4	main
selle	doc_685122975256_item	3541834	et	4	main
situatsion	doc_685122975256_item	3541835	et	4	main
eelmine	doc_685122975256_item	3541836	et	3	main
takaks	doc_685122975256_item	3541843	et	4	main
töötada	doc_685122975256_item	3541844	et	3	main
sada	doc_685122975256_item	3541848	et	4	main
väike	doc_685122975256_item	3541855	et	4	main
vanemate	doc_685122975256_item	3541862	et	4	main
olid	doc_685122975256_item	3541875	et	4	main
tühjad	doc_685122975256_item	3541876	et	3	main
ja	doc_685122975256_item	3541877	et	3	main
kodud	doc_685122975256_item	3541878	et	3	main
kodus	doc_685122975256_item	3541890	et	4	main
on	doc_685122975256_item	3541898	et	4	main
ei	doc_685122975256_item	3541907	et	4	main
taheta	doc_685122975256_item	3541908	et	3	main
ma	doc_685122975256_item	3541909	et	3	main
mäletan	doc_685122975256_item	3541910	et	3	main
vanemad	doc_685122975256_item	3541918	et	4	main
minul	doc_685122975256_item	3541923	et	3	main
hüvang	doc_685122975256_item	3541933	et	3	main
tahaksin	doc_685122975256_item	3541935	et	3	main
teie	doc_685122975256_item	3541945	et	4	main
ja	doc_685122975256_item	3541950	et	3	main
see	doc_685122975256_item	3541954	et	3	main
ametlik	doc_685122975255_item	3541963	et	3	main
kiri	doc_685122975255_item	3541964	et	3	main
kaalep	doc_685122975255_item	3541968	et	4	main
on	doc_685122975255_item	3541971	et	4	main
ma	doc_685122975255_item	3541974	et	3	main
oma	doc_685122975255_item	3541986	et	4	main
on	doc_685122975255_item	3542018	et	4	main
uus	doc_685122975255_item	3542019	et	3	main
see	doc_685122975256_item	3541828	et	3	main
on	doc_685122975256_item	3541840	et	4	main
rabelemata	doc_685122975256_item	3541846	et	4	main
normaalselt	doc_685122975256_item	3541850	et	4	main
kodu	doc_685122975256_item	3541856	et	4	main
need	doc_685122975256_item	3541857	et	3	main
rapsimisi	doc_685122975256_item	3541863	et	4	main
seda	doc_685122975256_item	3541867	et	3	main
18-aastased	doc_685122975256_item	3541870	et	4	main
vaevalt	doc_685122975256_item	3541880	et	4	main
vanemad	doc_685122975256_item	3541882	et	4	main
kes	doc_685122975256_item	3541883	et	4	main
sageli	doc_685122975256_item	3541884	et	3	main
tegid	doc_685122975256_item	3541885	et	4	main
silmis	doc_685122975256_item	3541900	et	4	main
ja	doc_685122975256_item	3541902	et	3	main
minu	doc_685122975256_item	3541917	et	3	main
väga	doc_685122975256_item	3541920	et	3	main
et	doc_685122975256_item	3541881	et	3	main
laste	doc_685122975256_item	3541899	et	4	main
seda	doc_685122975256_item	3541911	et	3	main
seda	doc_685122975256_item	3541915	et	3	main
töötasid	doc_685122975256_item	3541919	et	4	main
et	doc_685122975256_item	3541922	et	3	main
hea	doc_685122975256_item	3541925	et	4	main
sest	doc_685122975256_item	3541930	et	4	main
ma	doc_685122975256_item	3541934	et	3	main
just	doc_685122975256_item	3541936	et	3	main
erimaja	doc_685122975256_item	3541939	et	4	main
ma	doc_685122975256_item	3541951	et	3	main
lasteajast	doc_685122975256_item	3541961	et	4	main
ülikoolis	doc_685122975255_item	3541978	et	4	main
ma	doc_685122975255_item	3541979	et	3	main
olen	doc_685122975255_item	3541980	et	3	main
tea	doc_685122975255_item	3542016	et	4	main
koos	doc_685122975255_item	3542022	et	4	main
riigieksamite	doc_685122975255_item	3542023	et	3	main
loteriiga	doc_685122975255_item	3542024	et	3	main
see	doc_685122975255_item	3542025	et	3	main
kaine	doc_685122975255_item	3542026	et	4	main
arvestus	doc_685122975255_item	3542027	et	4	main
kuhu	doc_685122975255_item	3542028	et	3	main
nende	doc_685122975255_item	3542029	et	4	main
punktidega	doc_685122975255_item	3542030	et	3	main
üldse	doc_685122975255_item	3542031	et	3	main
saab	doc_685122975255_item	3542032	et	3	main
minna	doc_685122975255_item	3542033	et	3	main
esimesed	doc_685122975255_item	3542034	et	3	main
tulemused	doc_685122975255_item	3542035	et	3	main
tulevad	doc_685122975255_item	3542036	et	4	main
selle	doc_685122975255_item	3542037	et	4	main
nädala	doc_685122975255_item	3542038	et	3	main
lõpuks	doc_685122975255_item	3542039	et	4	main
kulun	doc_685122975255_item	3542058	et	3	main
gruppi	doc_685122975255_item	3542060	et	4	main
ma	doc_685122975255_item	3542061	et	3	main
olen	doc_685122975255_item	3542062	et	3	main
nõus	doc_685122975255_item	3542063	et	4	main
järgmiste	doc_685122975255_item	3542068	et	3	main
meeldib	doc_685122975256_item	3541927	et	3	main
stabiilne	doc_685122975256_item	3541928	et	3	main
elu	doc_685122975256_item	3541929	et	4	main
oma	doc_685122975256_item	3541938	et	4	main
kus	doc_685122975256_item	3541940	et	3	main
ma	doc_685122975256_item	3541941	et	3	main
elaksin	doc_685122975256_item	3541942	et	3	main
oma	doc_685122975256_item	3541943	et	4	main
perega	doc_685122975256_item	3541944	et	3	main
hea	doc_685122975256_item	3541949	et	4	main
et	doc_685122975256_item	3541953	et	3	main
noored	doc_685122975256_item	3541957	et	3	main
oma	doc_685122975256_item	3541959	et	4	main
tuleviku	doc_685122975256_item	3541960	et	4	main
lugupeetud	doc_685122975255_item	3541966	et	4	main
perekonnanimi	doc_685122975255_item	3541973	et	3	main
tallinna	doc_685122975255_item	3541976	et	4	main
tehnika	doc_685122975255_item	3541977	et	4	main
peavad	doc_685122975255_item	3541985	et	4	main
töö	doc_685122975255_item	3541987	et	4	main
eest	doc_685122975255_item	3541988	et	4	main
saama	doc_685122975255_item	3541989	et	4	main
väga	doc_685122975255_item	3541990	et	3	main
palju	doc_685122975255_item	3541991	et	4	main
rohkem	doc_685122975255_item	3541992	et	4	main
raha	doc_685122975255_item	3541993	et	4	main
kui	doc_685122975255_item	3541994	et	3	main
täna	doc_685122975255_item	3541995	et	4	main
olen	doc_685122975255_item	3541996	et	3	main
nõus	doc_685122975255_item	3541997	et	4	main
et	doc_685122975255_item	3541998	et	3	main
mõned	doc_685122975255_item	3541999	et	3	main
inimesed	doc_685122975255_item	3542000	et	3	main
ei	doc_685122975255_item	3542001	et	4	main
tea	doc_685122975255_item	3542002	et	4	main
mis	doc_685122975255_item	3542003	et	4	main
neist	doc_685122975255_item	3542004	et	4	main
saab	doc_685122975255_item	3542005	et	3	main
vaid	doc_685122975255_item	3542006	et	3	main
mõni	doc_685122975255_item	3542007	et	3	main
nädal	doc_685122975255_item	3542008	et	3	main
on	doc_685122975255_item	3542009	et	4	main
ülikoolidesse	doc_685122975255_item	3542010	et	3	main
astumiseni	doc_685122975255_item	3542011	et	4	main
aega	doc_685122975255_item	3542012	et	4	main
aga	doc_685122975255_item	3542013	et	3	main
nad	doc_685122975255_item	3542014	et	3	main
ei	doc_685122975255_item	3542015	et	4	main
asi	doc_685122975255_item	3542020	et	4	main
et	doc_685122975255_item	3542065	et	3	main
kallis	doc_491521501797_item	3542073	et	4	main
pole	doc_491521501797_item	3542077	et	3	main
kirjutanud	doc_491521501797_item	3542081	et	4	main
sõbrannast	doc_491521501797_item	3542093	et	4	main
tean	doc_491521501797_item	3542102	et	3	main
välismaale	doc_491521501797_item	3542106	et	4	main
selleks	doc_491521501797_item	3542108	et	4	main
tahtsid	doc_491521501797_item	3542133	et	4	main
sulle	doc_491521501797_item	3542136	et	3	main
elust	doc_491521501797_item	3542138	et	3	main
ühes	doc_491521501797_item	3542151	et	4	main
peres	doc_491521501797_item	3542152	et	3	main
ja	doc_491521501797_item	3542153	et	3	main
ta	doc_491521501797_item	3542167	et	4	main
tahab	doc_491521501797_item	3542168	et	3	main
sellepärast	doc_491521501797_item	3542172	et	3	main
tulnud	doc_685122975255_item	3542021	et	4	main
kiri	doc_491521501797_item	3542072	et	3	main
kaua	doc_491521501797_item	3542079	et	3	main
teen	doc_491521501797_item	3542097	et	3	main
seda	doc_491521501797_item	3542098	et	3	main
sa	doc_491521501797_item	3542104	et	3	main
sõita	doc_491521501797_item	3542107	et	3	main
et	doc_491521501797_item	3542109	et	3	main
mulle	doc_491521501797_item	3542126	et	4	main
tagasi	doc_491521501797_item	3542127	et	3	main
väga	doc_491521501797_item	3542128	et	3	main
kiiresti	doc_491521501797_item	3542129	et	3	main
ja	doc_491521501797_item	3542130	et	3	main
nagu	doc_491521501797_item	3542131	et	3	main
helena	doc_491521501797_item	3542140	et	4	main
seal	doc_491521501797_item	3542155	et	4	main
helena	doc_491521501797_item	3542158	et	4	main
kirjutab	doc_491521501797_item	3542159	et	3	main
et	doc_491521501797_item	3542160	et	3	main
talle	doc_491521501797_item	3542161	et	4	main
elada	doc_491521501797_item	3542170	et	3	main
arhitektuurisse	doc_491521501797_item	3542178	et	3	main
kõik	doc_491521501797_item	3542186	et	4	main
teistsugune	doc_491521501797_item	3542187	et	3	main
linna	doc_491521501797_item	3542191	et	4	main
suurem	doc_491521501797_item	3542200	et	4	main
ja	doc_491521501797_item	3542201	et	3	main
pärast	doc_491521501797_item	3542213	et	4	main
ootama	doc_491521501797_item	3542221	et	3	main
kirjuta	doc_491521501797_item	3542222	et	4	main
palju	doc_491521501797_item	3542232	et	4	main
praktikale	doc_491521501722_item	3542259	et	3	main
kirjuta	doc_491521501722_item	3542260	et	4	main
mida	doc_491521501722_item	3542278	et	4	main
tere	doc_491521501722_item	3542283	et	3	main
seal	doc_491521501722_item	3542287	et	4	main
väga	doc_491521501722_item	3542296	et	3	main
õppilases	doc_491521501722_item	3542301	et	4	main
veel	doc_491521501722_item	3542304	et	4	main
õppilane	doc_491521501722_item	3542305	et	4	main
on	doc_491521501722_item	3542343	et	4	main
ka	doc_491521501722_item	3542344	et	3	main
pole	doc_491521501722_item	3542345	et	3	main
sul	doc_491521501722_item	3542347	et	3	main
midagi	doc_491521501722_item	3542346	et	4	main
on	doc_491521501722_item	3542348	et	4	main
kõike	doc_491521501797_item	3542236	et	4	main
head	doc_491521501797_item	3542237	et	4	main
tallinna	doc_491521501797_item	3542238	et	4	main
10	doc_491521501797_item	3542239	et	2	main
oktoobril	doc_491521501797_item	3542240	et	3	main
2003	doc_491521501797_item	3542241	et	2	main
a	doc_491521501797_item	3542242	et	4	main
armastusega	doc_491521501797_item	3542243	et	4	main
eesnimi	doc_491521501797_item	3542244	et	3	main
et	doc_491521501797_item	3542076	et	3	main
nii	doc_491521501797_item	3542078	et	3	main
parandama	doc_491521501797_item	3542083	et	3	main
laula	doc_491521501797_item	3542085	et	4	main
palusid	doc_491521501797_item	3542088	et	4	main
mind	doc_491521501797_item	3542089	et	4	main
kirjutada	doc_491521501797_item	3542090	et	3	main
midagi	doc_491521501797_item	3542091	et	4	main
minu	doc_491521501797_item	3542092	et	3	main
hea	doc_491521501797_item	3542099	et	4	main
meelega	doc_491521501797_item	3542100	et	4	main
ma	doc_491521501797_item	3542101	et	3	main
et	doc_491521501797_item	3542103	et	3	main
seal	doc_491521501797_item	3542110	et	4	main
õppida	doc_491521501797_item	3542111	et	3	main
sellepärast	doc_491521501797_item	3542112	et	3	main
ma	doc_491521501797_item	3542113	et	3	main
kirjutasin	doc_491521501797_item	3542114	et	3	main
minu	doc_491521501797_item	3542115	et	3	main
sõbrannale	doc_491521501797_item	3542116	et	3	main
norrasse	doc_491521501797_item	3542117	et	4	main
ja	doc_491521501797_item	3542118	et	3	main
küsisin	doc_491521501797_item	3542119	et	3	main
sa	doc_491521501797_item	3542132	et	3	main
kirjutan	doc_491521501797_item	3542135	et	3	main
temast	doc_491521501797_item	3542137	et	3	main
praegu	doc_491521501797_item	3542139	et	3	main
ja	doc_491521501797_item	3542142	et	3	main
töötab	doc_491521501797_item	3542143	et	3	main
töötab	doc_491521501797_item	3542154	et	3	main
lastehoidjana	doc_491521501797_item	3542157	et	3	main
seal	doc_491521501797_item	3542169	et	4	main
ta	doc_491521501797_item	3542174	et	4	main
armus	doc_491521501797_item	3542176	et	4	main
on	doc_491521501797_item	3542185	et	4	main
vana	doc_491521501797_item	3542190	et	4	main
tallinna	doc_491521501797_item	3542194	et	4	main
seal	doc_491521501797_item	3542197	et	4	main
on	doc_491521501797_item	3542198	et	4	main
metsad	doc_491521501797_item	3542204	et	3	main
tumedam	doc_491521501797_item	3542207	et	4	main
mejed	doc_491521501797_item	3542209	et	4	main
ja	doc_491521501797_item	3542210	et	3	main
põhjamere	doc_491521501797_item	3542211	et	3	main
läheduse	doc_491521501797_item	3542212	et	4	main
jään	doc_491521501797_item	3542219	et	3	main
vastust	doc_491521501797_item	3542220	et	4	main
kiiresti	doc_491521501797_item	3542225	et	3	main
tervitusi	doc_491521501797_item	3542233	et	4	main
sinu	doc_491521501797_item	3542234	et	3	main
sugulasi	doc_491521501797_item	3542235	et	3	main
oma	doc_491521501722_item	3542249	et	4	main
eestlasest	doc_491521501722_item	3542250	et	3	main
sõbrale	doc_491521501722_item	3542251	et	3	main
et	doc_491521501722_item	3542252	et	3	main
kursustel	doc_491521501722_item	3542263	et	3	main
sa	doc_491521501722_item	3542279	et	3	main
on	doc_491521501722_item	3542295	et	4	main
uues	doc_491521501722_item	3542299	et	3	main
soovitan	doc_491521501722_item	3542303	et	3	main
koolis	doc_491521501722_item	3542351	et	4	main
mida	doc_491521501722_item	3542359	et	4	main
on	doc_491521501722_item	3542362	et	4	main
korras	doc_491521501722_item	3542365	et	4	main
sind	doc_491521501722_item	3542366	et	4	main
armastan	doc_491521501722_item	3542367	et	3	main
eesnimi	doc_491521501722_item	3542368	et	3	main
ja	doc_491521501722_item	3542378	et	3	main
kiri	doc_491521501720_item	3542389	et	3	main
et	doc_491521501720_item	3542394	et	3	main
ja	doc_491521501720_item	3542398	et	3	main
praktikale	doc_491521501720_item	3542401	et	3	main
kuidas	doc_491521501720_item	3542403	et	3	main
sul	doc_491521501720_item	3542404	et	3	main
õppisid	doc_491521501720_item	3542410	et	4	main
ja	doc_491521501720_item	3542419	et	3	main
minu	doc_491521501720_item	3542426	et	3	main
arvutiõpetus	doc_491521501720_item	3542447	et	3	main
soovivad	doc_491521501720_item	3542466	et	4	main
ma	doc_491521501720_item	3542470	et	3	main
mina	doc_491521501720_item	3542474	et	4	main
väga	doc_491521501720_item	3542475	et	3	main
igatsen	doc_491521501720_item	3542476	et	3	main
sinu	doc_491521501720_item	3542477	et	3	main
järel	doc_491521501720_item	3542478	et	4	main
väga	doc_491521501720_item	3542479	et	3	main
ja	doc_491521501720_item	3542480	et	3	main
ma	doc_491521501797_item	3542134	et	3	main
õpib	doc_491521501797_item	3542141	et	3	main
norras	doc_491521501797_item	3542144	et	4	main
ühel	doc_491521501797_item	3542145	et	3	main
nagu	doc_491521501797_item	3542156	et	3	main
jääda	doc_491521501797_item	3542171	et	4	main
lausa	doc_491521501797_item	3542175	et	4	main
ta	doc_491521501797_item	3542181	et	4	main
vanalinnast	doc_491521501797_item	3542195	et	4	main
väga	doc_491521501797_item	3542196	et	3	main
kõik	doc_491521501797_item	3542199	et	4	main
on	doc_491521501797_item	3542205	et	4	main
küljem	doc_491521501797_item	3542216	et	4	main
sellega	doc_491521501797_item	3542217	et	3	main
lõpetan	doc_491521501797_item	3542218	et	3	main
palun	doc_491521501797_item	3542224	et	3	main
parem	doc_491521501797_item	3542227	et	4	main
minu	doc_491521501797_item	3542229	et	3	main
norra	doc_491521501797_item	3542177	et	4	main
loodusse	doc_491521501797_item	3542180	et	4	main
kirjutab	doc_491521501797_item	3542182	et	3	main
et	doc_491521501797_item	3542183	et	3	main
seal	doc_491521501797_item	3542184	et	4	main
nende	doc_491521501797_item	3542189	et	4	main
erineb	doc_491521501797_item	3542193	et	3	main
rangem	doc_491521501797_item	3542202	et	4	main
palju	doc_491521501797_item	3542206	et	4	main
kui	doc_491521501797_item	3542208	et	3	main
tagasi	doc_491521501797_item	3542226	et	3	main
tule	doc_491521501797_item	3542228	et	4	main
juurde	doc_491521501797_item	3542230	et	4	main
koolivahetusel	doc_491521501797_item	3542231	et	4	main
saa	doc_491521501722_item	3542253	et	4	main
käid	doc_491521501722_item	3542254	et	3	main
kursustel	doc_491521501722_item	3542255	et	3	main
ja	doc_491521501722_item	3542256	et	3	main
varsti	doc_491521501722_item	3542257	et	3	main
lähed	doc_491521501722_item	3542258	et	3	main
läks	doc_491521501722_item	3542264	et	3	main
mida	doc_491521501722_item	3542265	et	4	main
õppisid	doc_491521501722_item	3542268	et	4	main
kuhu	doc_491521501722_item	3542269	et	3	main
see	doc_491521501722_item	3542274	et	3	main
firma	doc_491521501722_item	3542275	et	4	main
tegeleb	doc_491521501722_item	3542276	et	3	main
ja	doc_491521501722_item	3542277	et	3	main
tegema	doc_491521501722_item	3542281	et	3	main
mina	doc_491521501722_item	3542288	et	4	main
eesnimi	doc_491521501722_item	3542289	et	3	main
minul	doc_491521501722_item	3542290	et	3	main
on	doc_491521501722_item	3542291	et	4	main
meeldiv	doc_491521501722_item	3542297	et	4	main
ilus	doc_491521501722_item	3542308	et	4	main
30102003	doc_491521501722_item	3542309	et	2	main
terviseks	doc_491521501722_item	3542349	et	3	main
uudis	doc_491521501722_item	3542358	et	3	main
mul	doc_491521501722_item	3542361	et	3	main
alused	doc_491521501722_item	3542381	et	4	main
eestlasest	doc_491521501720_item	3542392	et	3	main
saa	doc_491521501720_item	3542395	et	4	main
kirjuta	doc_491521501720_item	3542402	et	4	main
sa	doc_491521501720_item	3542412	et	3	main
firma	doc_491521501720_item	3542417	et	4	main
sõbranna	doc_491521501720_item	3542428	et	4	main
marina	doc_491521501720_item	3542429	et	3	main
suure	doc_491521501720_item	3542430	et	3	main
austusega	doc_491521501720_item	3542431	et	4	main
lähen	doc_491521501720_item	3542440	et	3	main
praktikale	doc_491521501720_item	3542442	et	3	main
ma	doc_491521501720_item	3542444	et	3	main
remonti	doc_491521501720_item	3542462	et	4	main
korteris	doc_491521501720_item	3542463	et	3	main
ja	doc_491521501720_item	3542464	et	3	main
nad	doc_491521501720_item	3542465	et	3	main
seal	doc_491521501720_item	3542469	et	4	main
olen	doc_491521501720_item	3542471	et	3	main
raamatupidajana	doc_491521501720_item	3542473	et	3	main
külla	doc_491521501720_item	3542486	et	4	main
lugupetud	doc_685122975257_item	3542498	et	3	main
hiljuti	doc_685122975257_item	3542501	et	4	main
artikel	doc_685122975257_item	3542505	et	4	main
ja	doc_685122975257_item	3542506	et	3	main
arvan	doc_685122975257_item	3542507	et	3	main
inimesi	doc_685122975257_item	3542520	et	4	main
kelleks	doc_685122975257_item	3542526	et	4	main
ja	doc_685122975257_item	3542530	et	3	main
lähevad	doc_685122975257_item	3542534	et	3	main
liisida	doc_685122975257_item	3542566	et	4	main
või	doc_685122975257_item	3542568	et	4	main
nõus	doc_685122975257_item	3542572	et	4	main
elada	doc_685122975257_item	3542577	et	3	main
olen	doc_685122975257_item	3542586	et	3	main
kõikke	doc_685122975257_item	3542622	et	4	main
ja	doc_685122975257_item	3542623	et	3	main
neil	doc_685122975257_item	3542631	et	4	main
tuleb	doc_685122975257_item	3542639	et	3	main
mis	doc_685122975257_item	3542642	et	4	main
kiri	doc_685122975258_item	3542654	et	3	main
kaalep	doc_685122975258_item	3542657	et	4	main
minu	doc_685122975258_item	3542658	et	3	main
isegi	doc_491521501797_item	3542188	et	4	main
osa	doc_491521501797_item	3542192	et	4	main
nende	doc_491521501797_item	3542203	et	4	main
seal	doc_491521501797_item	3542214	et	4	main
väga	doc_491521501797_item	3542215	et	3	main
mulle	doc_491521501797_item	3542223	et	4	main
kiri	doc_491521501722_item	3542246	et	3	main
kirjuta	doc_491521501722_item	3542248	et	4	main
sul	doc_491521501722_item	3542262	et	3	main
sa	doc_491521501722_item	3542266	et	3	main
hakkad	doc_491521501722_item	3542282	et	3	main
kallis	doc_491521501722_item	3542284	et	4	main
kirjutama	doc_491521501722_item	3542286	et	3	main
need	doc_491521501722_item	3542294	et	3	main
palju	doc_491521501722_item	3542298	et	4	main
koolis	doc_491521501722_item	3542300	et	4	main
ma	doc_491521501722_item	3542302	et	3	main
mis	doc_491521501722_item	3542357	et	4	main
kuulukse	doc_491521501722_item	3542360	et	4	main
unistav	doc_491521501722_item	3542370	et	4	main
konsultatsiooni	doc_491521501722_item	3542376	et	4	main
kursusetöö	doc_491521501722_item	3542377	et	4	main
ja	doc_491521501722_item	3542382	et	3	main
või	doc_491521501722_item	3542383	et	4	main
palju	doc_491521501722_item	3542384	et	4	main
mõned	doc_491521501722_item	3542385	et	3	main
okkei	doc_491521501722_item	3542386	et	4	main
kiri	doc_491521501722_item	3542247	et	3	main
kuidas	doc_491521501722_item	3542261	et	3	main
seal	doc_491521501722_item	3542267	et	4	main
sa	doc_491521501722_item	3542270	et	3	main
praktikale	doc_491521501722_item	3542271	et	3	main
lähed	doc_491521501722_item	3542272	et	3	main
millega	doc_491521501722_item	3542273	et	3	main
seal	doc_491521501722_item	3542280	et	4	main
sõbra	doc_491521501722_item	3542285	et	3	main
kõik	doc_491521501722_item	3542292	et	4	main
kursusse	doc_491521501722_item	3542293	et	3	main
eestikeelles	doc_491521501722_item	3542306	et	4	main
väga	doc_491521501722_item	3542307	et	3	main
ma	doc_491521501722_item	3542310	et	3	main
käin	doc_491521501722_item	3542311	et	3	main
praktikale	doc_491521501722_item	3542312	et	3	main
firmas	doc_491521501722_item	3542313	et	3	main
lehti-maja	doc_491521501722_item	3542314	et	4	main
eesti	doc_491521501722_item	3542315	et	4	main
as	doc_491521501722_item	3542316	et	4	main
ma	doc_491521501722_item	3542317	et	3	main
olen	doc_491521501722_item	3542318	et	3	main
nii	doc_491521501722_item	3542319	et	3	main
rõõmus	doc_491521501722_item	3542320	et	4	main
detsember	doc_491521501722_item	3542321	et	3	main
pole	doc_491521501722_item	3542322	et	3	main
ma	doc_491521501722_item	3542323	et	3	main
kirjutama	doc_491521501722_item	3542324	et	3	main
sul	doc_491521501722_item	3542325	et	3	main
kirja	doc_491521501722_item	3542326	et	4	main
tänan	doc_491521501722_item	3542327	et	3	main
on	doc_491521501722_item	3542328	et	4	main
ilm	doc_491521501722_item	3542329	et	3	main
ilus	doc_491521501722_item	3542330	et	4	main
kõige	doc_491521501722_item	3542331	et	4	main
puu	doc_491521501722_item	3542332	et	4	main
valgavad	doc_491521501722_item	3542333	et	3	main
kõik	doc_491521501722_item	3542334	et	4	main
on	doc_491521501722_item	3542335	et	4	main
kena	doc_491521501722_item	3542336	et	4	main
mul	doc_491521501722_item	3542337	et	3	main
on	doc_491521501722_item	3542338	et	4	main
terviseks	doc_491521501722_item	3542339	et	3	main
hästi	doc_491521501722_item	3542340	et	3	main
pois	doc_491521501722_item	3542341	et	3	main
vitalial	doc_491521501722_item	3542342	et	4	main
vitali	doc_491521501722_item	3542350	et	4	main
algab	doc_491521501722_item	3542352	et	3	main
vahendus	doc_491521501722_item	3542353	et	4	main
kirjutage	doc_491521501722_item	3542354	et	3	main
kuidas	doc_491521501722_item	3542355	et	3	main
läheb	doc_491521501722_item	3542356	et	3	main
on	doc_491521501722_item	3542364	et	4	main
sul	doc_491521501722_item	3542371	et	3	main
et	doc_491521501722_item	3542373	et	3	main
või	doc_491521501722_item	3542379	et	4	main
kirjuta	doc_491521501720_item	3542390	et	4	main
praktikale	doc_491521501720_item	3542413	et	3	main
lähed	doc_491521501720_item	3542414	et	3	main
kallis	doc_491521501720_item	3542427	et	4	main
tuleks	doc_491521501720_item	3542484	et	4	main
tere	doc_685122975257_item	3542497	et	3	main
väga	doc_685122975257_item	3542511	et	3	main
tea	doc_685122975257_item	3542525	et	4	main
saada	doc_685122975257_item	3542529	et	4	main
see	doc_685122975257_item	3542531	et	3	main
nad	doc_685122975257_item	3542533	et	3	main
kuhu	doc_685122975257_item	3542536	et	3	main
neid	doc_685122975257_item	3542537	et	4	main
võetakse	doc_685122975257_item	3542538	et	3	main
tänane	doc_685122975257_item	3542539	et	3	main
ma	doc_685122975257_item	3542570	et	3	main
noored	doc_685122975257_item	3542575	et	3	main
saada	doc_685122975257_item	3542580	et	4	main
sellist	doc_685122975257_item	3542626	et	4	main
tööt	doc_685122975257_item	3542627	et	4	main
leida	doc_685122975257_item	3542628	et	3	main
viivida	doc_685122975257_item	3542634	et	4	main
ma	doc_685122975257_item	3542635	et	3	main
usun	doc_685122975257_item	3542636	et	3	main
et	doc_685122975257_item	3542637	et	3	main
tulevikus	doc_685122975257_item	3542638	et	4	main
ja	doc_685122975257_item	3542646	et	3	main
kõik	doc_491521501722_item	3542363	et	4	main
ma	doc_491521501722_item	3542369	et	3	main
räägima	doc_491521501722_item	3542372	et	4	main
kursusel	doc_491521501722_item	3542374	et	3	main
õppilane	doc_491521501722_item	3542375	et	4	main
psühholoogia	doc_491521501722_item	3542380	et	4	main
kiri	doc_491521501720_item	3542388	et	3	main
sõbrale	doc_491521501720_item	3542393	et	3	main
lähed	doc_491521501720_item	3542400	et	3	main
seal	doc_491521501720_item	3542409	et	4	main
see	doc_491521501720_item	3542416	et	3	main
mida	doc_491521501720_item	3542420	et	4	main
sa	doc_491521501720_item	3542421	et	3	main
seal	doc_491521501720_item	3542422	et	4	main
tegema	doc_491521501720_item	3542423	et	3	main
hakkad	doc_491521501720_item	3542424	et	3	main
tere	doc_491521501720_item	3542425	et	3	main
kursustel	doc_491521501720_item	3542443	et	3	main
seal	doc_491521501720_item	3542445	et	4	main
ka	doc_491521501720_item	3542467	et	3	main
tuletaksime	doc_491521501720_item	3542488	et	3	main
vanu	doc_491521501720_item	3542489	et	4	main
aegu	doc_491521501720_item	3542490	et	4	main
meelde	doc_491521501720_item	3542491	et	3	main
sinu	doc_491521501720_item	3542492	et	3	main
sõbranna	doc_491521501720_item	3542493	et	4	main
eesnimi	doc_491521501720_item	3542494	et	3	main
ametlik	doc_685122975257_item	3542495	et	3	main
et	doc_685122975257_item	3542508	et	3	main
seal	doc_685122975257_item	3542509	et	4	main
palju	doc_685122975257_item	3542512	et	4	main
huvitavaid	doc_685122975257_item	3542513	et	4	main
ideid	doc_685122975257_item	3542514	et	3	main
ma	doc_685122975257_item	3542515	et	3	main
olen	doc_685122975257_item	3542516	et	3	main
nõus	doc_685122975257_item	3542517	et	4	main
et	doc_685122975257_item	3542518	et	3	main
paljud	doc_685122975257_item	3542519	et	3	main
ei	doc_685122975257_item	3542524	et	4	main
et	doc_685122975257_item	3542574	et	3	main
tahavad	doc_685122975257_item	3542576	et	3	main
nagu	doc_685122975257_item	3542578	et	3	main
olla	doc_685122975257_item	3542582	et	3	main
materiaalne	doc_685122975257_item	3542583	et	3	main
kindlustatus	doc_685122975257_item	3542584	et	4	main
mittu	doc_685122975257_item	3542589	et	4	main
korda	doc_685122975257_item	3542590	et	4	main
kokku	doc_685122975257_item	3542591	et	3	main
ja	doc_685122975257_item	3542614	et	3	main
tulevikus	doc_685122975257_item	3542624	et	4	main
tahavad	doc_685122975257_item	3542625	et	3	main
muuta	doc_685122975257_item	3542644	et	4	main
perekonnanimi	doc_685122975257_item	3542651	et	3	main
lugupeetud	doc_685122975258_item	3542655	et	4	main
septembrist	doc_685122975258_item	3542667	et	3	main
majandusteatusosakonnas	doc_685122975258_item	3542671	et	4	main
te	doc_685122975258_item	3542719	et	4	main
selliseid	doc_685122975258_item	3542721	et	4	main
kahekümneaastased	doc_685122975258_item	3542725	et	4	main
mässavad	doc_685122975258_item	3542726	et	4	main
neljakümnesed	doc_685122975258_item	3542732	et	3	main
vanemad	doc_685122975258_item	3542735	et	4	main
ma	doc_685122975258_item	3542736	et	3	main
olen	doc_685122975258_item	3542737	et	3	main
kindel	doc_685122975258_item	3542738	et	3	main
et	doc_685122975258_item	3542739	et	3	main
on	doc_685122975258_item	3542740	et	4	main
juba	doc_685122975258_item	3542741	et	3	main
tõendada	doc_685122975258_item	3542749	et	3	main
niisama	doc_685122975258_item	3542775	et	3	main
alati	doc_685122975258_item	3542777	et	4	main
ei	doc_685122975258_item	3542780	et	4	main
saa	doc_685122975258_item	3542781	et	4	main
mitte	doc_685122975258_item	3542782	et	3	main
ma	doc_491521501720_item	3542454	et	3	main
lähen	doc_491521501720_item	3542455	et	3	main
firmas	doc_491521501720_item	3542457	et	3	main
praktikale	doc_491521501720_item	3542456	et	3	main
fie	doc_491521501720_item	3542458	et	4	main
žukov	doc_491521501720_item	3542459	et	2	main
nad	doc_491521501720_item	3542460	et	3	main
oma	doc_491521501720_item	3542391	et	4	main
käid	doc_491521501720_item	3542396	et	3	main
kursustel	doc_491521501720_item	3542397	et	3	main
varsti	doc_491521501720_item	3542399	et	3	main
kursustel	doc_491521501720_item	3542405	et	3	main
läks	doc_491521501720_item	3542406	et	3	main
mida	doc_491521501720_item	3542407	et	4	main
sa	doc_491521501720_item	3542408	et	3	main
kuhu	doc_491521501720_item	3542411	et	3	main
millega	doc_491521501720_item	3542415	et	3	main
tegeleb	doc_491521501720_item	3542418	et	3	main
teie	doc_491521501720_item	3542432	et	4	main
eesnimi	doc_491521501720_item	3542433	et	3	main
ma	doc_491521501720_item	3542434	et	3	main
käin	doc_491521501720_item	3542435	et	3	main
kursustel	doc_491521501720_item	3542436	et	3	main
müügisekretär	doc_491521501720_item	3542437	et	3	main
ja	doc_491521501720_item	3542438	et	3	main
ma	doc_491521501720_item	3542439	et	3	main
varsti	doc_491521501720_item	3542441	et	3	main
õppisin	doc_491521501720_item	3542446	et	3	main
psühholoogia	doc_491521501720_item	3542448	et	4	main
alused	doc_491521501720_item	3542449	et	4	main
turunduse	doc_491521501720_item	3542450	et	3	main
alused	doc_491521501720_item	3542451	et	4	main
eesti	doc_491521501720_item	3542452	et	4	main
keel	doc_491521501720_item	3542453	et	4	main
tegevad	doc_491521501720_item	3542461	et	4	main
materjalid	doc_491521501720_item	3542468	et	3	main
tööta	doc_491521501720_item	3542472	et	4	main
mulle	doc_491521501720_item	3542485	et	4	main
tahaksin	doc_491521501720_item	3542481	et	3	main
et	doc_491521501720_item	3542482	et	3	main
sa	doc_491521501720_item	3542483	et	3	main
et	doc_491521501720_item	3542487	et	3	main
tiina	doc_685122975257_item	3542499	et	4	main
oli	doc_685122975257_item	3542510	et	3	main
kes	doc_685122975257_item	3542521	et	4	main
lõpetas	doc_685122975257_item	3542522	et	3	main
kooli	doc_685122975257_item	3542523	et	4	main
tahavad	doc_685122975257_item	3542528	et	3	main
pärast	doc_685122975257_item	3542532	et	4	main
õppida	doc_685122975257_item	3542535	et	3	main
korteri	doc_685122975257_item	3542567	et	3	main
majja	doc_685122975257_item	3542569	et	3	main
olen	doc_685122975257_item	3542571	et	3	main
vanemad	doc_685122975257_item	3542579	et	4	main
sotsiaaltagatised	doc_685122975257_item	3542581	et	3	main
ise	doc_685122975257_item	3542587	et	4	main
puutunuud	doc_685122975257_item	3542592	et	4	main
on	doc_685122975257_item	3542593	et	4	main
rohkem	doc_685122975257_item	3542632	et	4	main
kodus	doc_685122975257_item	3542633	et	4	main
selline	doc_685122975257_item	3542640	et	4	main
suudab	doc_685122975257_item	3542643	et	3	main
elu	doc_685122975257_item	3542648	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975257_item	3542652	et	4	main
ametlik	doc_685122975258_item	3542653	et	3	main
kaheksateisaastane	doc_685122975258_item	3542664	et	4	main
tudeng	doc_685122975258_item	3542665	et	3	main
alates	doc_685122975258_item	3542666	et	3	main
artikli	doc_685122975258_item	3542677	et	3	main
küllaltki	doc_685122975258_item	3542686	et	4	main
aga	doc_685122975258_item	3542692	et	3	main
ka	doc_685122975258_item	3542694	et	3	main
saa	doc_685122975258_item	3542716	et	4	main
asju	doc_685122975258_item	3542722	et	3	main
tänapäeval	doc_685122975258_item	3542724	et	3	main
nagu	doc_685122975258_item	3542731	et	3	main
õigused	doc_685122975258_item	3542744	et	4	main
rohkem	doc_685122975258_item	3542750	et	4	main
kiri	doc_685122975257_item	3542496	et	3	main
kaalep	doc_685122975257_item	3542500	et	4	main
ma	doc_685122975257_item	3542502	et	3	main
lugesin	doc_685122975257_item	3542503	et	3	main
teie	doc_685122975257_item	3542504	et	4	main
nad	doc_685122975257_item	3542527	et	3	main
põlvkond	doc_685122975257_item	3542540	et	3	main
ei	doc_685122975257_item	3542541	et	4	main
saa	doc_685122975257_item	3542542	et	4	main
endale	doc_685122975257_item	3542543	et	4	main
lubada	doc_685122975257_item	3542544	et	3	main
osta	doc_685122975257_item	3542545	et	4	main
korteri	doc_685122975257_item	3542546	et	3	main
maja	doc_685122975257_item	3542548	et	4	main
või	doc_685122975257_item	3542547	et	4	main
sellepärast	doc_685122975257_item	3542549	et	3	main
et	doc_685122975257_item	3542550	et	3	main
saavad	doc_685122975257_item	3542551	et	4	main
väike	doc_685122975257_item	3542552	et	4	main
palka	doc_685122975257_item	3542553	et	4	main
ainult	doc_685122975257_item	3542554	et	4	main
mõne	doc_685122975257_item	3542555	et	3	main
aja	doc_685122975257_item	3542556	et	4	main
möödas	doc_685122975257_item	3542557	et	3	main
nad	doc_685122975257_item	3542558	et	3	main
võivad	doc_685122975257_item	3542559	et	4	main
teenida	doc_685122975257_item	3542560	et	3	main
palju	doc_685122975257_item	3542561	et	4	main
raha	doc_685122975257_item	3542562	et	4	main
ja	doc_685122975257_item	3542563	et	3	main
saavad	doc_685122975257_item	3542564	et	4	main
endale	doc_685122975257_item	3542565	et	4	main
sellega	doc_685122975257_item	3542573	et	3	main
ma	doc_685122975257_item	3542585	et	3	main
sellega	doc_685122975257_item	3542588	et	3	main
osa	doc_685122975257_item	3542594	et	4	main
selliseid	doc_685122975257_item	3542595	et	4	main
noori	doc_685122975257_item	3542596	et	3	main
tahavad	doc_685122975257_item	3542598	et	3	main
rohkem	doc_685122975257_item	3542599	et	4	main
kes	doc_685122975257_item	3542597	et	4	main
aega	doc_685122975257_item	3542600	et	4	main
veeta	doc_685122975257_item	3542601	et	4	main
kodus	doc_685122975257_item	3542602	et	4	main
nagu	doc_685122975257_item	3542603	et	3	main
oli	doc_685122975257_item	3542604	et	3	main
näidendis	doc_685122975257_item	3542605	et	3	main
õpetajate	doc_685122975257_item	3542606	et	4	main
kohta	doc_685122975257_item	3542607	et	4	main
on	doc_685122975257_item	3542608	et	4	main
inimesi	doc_685122975257_item	3542609	et	4	main
kes	doc_685122975257_item	3542610	et	4	main
töötavad	doc_685122975257_item	3542611	et	4	main
väga	doc_685122975257_item	3542612	et	3	main
palju	doc_685122975257_item	3542613	et	4	main
kodus	doc_685122975257_item	3542615	et	4	main
peaaegu	doc_685122975257_item	3542616	et	3	main
ei	doc_685122975257_item	3542617	et	4	main
ilmne	doc_685122975257_item	3542618	et	4	main
lapsed	doc_685122975257_item	3542619	et	3	main
näevad	doc_685122975257_item	3542620	et	3	main
seda	doc_685122975257_item	3542621	et	3	main
mis	doc_685122975257_item	3542629	et	4	main
lubaks	doc_685122975257_item	3542630	et	3	main
põlvkond	doc_685122975257_item	3542641	et	3	main
haridussüsteemi	doc_685122975257_item	3542645	et	4	main
meie	doc_685122975257_item	3542647	et	4	main
lugupidamisega	doc_685122975257_item	3542649	et	3	main
eesnimi	doc_685122975257_item	3542650	et	3	main
tiina	doc_685122975258_item	3542656	et	4	main
õpin	doc_685122975258_item	3542668	et	3	main
ärinduse	doc_685122975258_item	3542672	et	3	main
ja	doc_685122975258_item	3542679	et	3	main
ei	doc_685122975258_item	3542715	et	4	main
aru	doc_685122975258_item	3542717	et	4	main
miks	doc_685122975258_item	3542718	et	4	main
õiguse	doc_685122975258_item	3542727	et	4	main
kõikidel	doc_685122975258_item	3542742	et	4	main
ühesugused	doc_685122975258_item	3542743	et	3	main
tea	doc_685122975258_item	3542754	et	4	main
kuhu	doc_685122975258_item	3542756	et	3	main
astuda	doc_685122975258_item	3542757	et	3	main
tahan	doc_685122975258_item	3542764	et	3	main
õpivad	doc_685122975258_item	3542774	et	3	main
kõige	doc_685122975258_item	3542785	et	4	main
meeldis	doc_685122975258_item	3542787	et	3	main
rohkem	doc_685122975258_item	3542817	et	4	main
palka	doc_685122975258_item	3542818	et	4	main
alustab	doc_685122975258_item	3542835	et	3	main
kiri	doc_685122975259_item	3542875	et	3	main
tiina	doc_685122975259_item	3542878	et	4	main
artikkel	doc_685122975259_item	3542883	et	3	main
ja	doc_685122975259_item	3542885	et	3	main
teie	doc_685122975259_item	3542892	et	4	main
ma	doc_685122975259_item	3542904	et	3	main
tulevikus	doc_685122975259_item	3542925	et	4	main
seepärast	doc_685122975259_item	3542926	et	3	main
ma	doc_685122975259_item	3542927	et	3	main
arvan	doc_685122975259_item	3542928	et	3	main
minu	doc_685122975259_item	3542946	et	3	main
kodu	doc_685122975259_item	3542947	et	4	main
mõtlen	doc_685122975259_item	3542948	et	3	main
et	doc_685122975259_item	3542949	et	3	main
see	doc_685122975259_item	3542950	et	3	main
ehkki	doc_685122975259_item	3542955	et	3	main
tunne	doc_685122975259_item	3542958	et	4	main
sisse	doc_685122975259_item	3542966	et	4	main
astuda	doc_685122975259_item	3542967	et	3	main
või	doc_685122975259_item	3542968	et	4	main
õppida	doc_685122975259_item	3542972	et	3	main
ees	doc_685122975259_item	3542982	et	4	main
äkki	doc_685122975259_item	3542985	et	3	main
on	doc_685122975259_item	3542987	et	4	main
mõted	doc_685122975259_item	3542997	et	4	main
arvamus	doc_685122975259_item	3542999	et	3	main
vastutav	doc_685122975259_item	3543009	et	4	main
samm	doc_685122975259_item	3543010	et	3	main
mis	doc_685122975259_item	3543011	et	4	main
saadab	doc_685122975259_item	3543012	et	3	main
ma	doc_685122975259_item	3543016	et	3	main
enda	doc_685122975259_item	3543019	et	4	main
ja	doc_685122975259_item	3543021	et	3	main
tiina	doc_685122975260_item	3543053	et	4	main
mina	doc_685122975260_item	3543055	et	4	main
üliõpilane	doc_685122975260_item	3543057	et	3	main
õpin	doc_685122975260_item	3543059	et	3	main
ülikoolis	doc_685122975260_item	3543062	et	4	main
nimi	doc_685122975260_item	3543064	et	3	main
eesnimi	doc_685122975260_item	3543066	et	3	main
läbi	doc_685122975260_item	3543070	et	4	main
teie	doc_685122975260_item	3543071	et	4	main
palju	doc_685122975260_item	3543086	et	4	main
praegu	doc_685122975260_item	3543121	et	3	main
ja	doc_685122975260_item	3543123	et	3	main
hakkida	doc_685122975260_item	3543131	et	4	main
on	doc_685122975260_item	3543135	et	4	main
meie	doc_685122975260_item	3543136	et	4	main
tallina	doc_685122975258_item	3542669	et	3	main
erialal	doc_685122975258_item	3542673	et	3	main
olen	doc_685122975258_item	3542674	et	3	main
ära	doc_685122975258_item	3542678	et	4	main
oma	doc_685122975258_item	3542681	et	4	main
avaldada	doc_685122975258_item	3542683	et	3	main
oli	doc_685122975258_item	3542685	et	3	main
nõus	doc_685122975258_item	3542691	et	4	main
selleseid	doc_685122975258_item	3542695	et	4	main
asju	doc_685122975258_item	3542696	et	3	main
millist	doc_685122975258_item	3542697	et	3	main
ma	doc_685122975258_item	3542698	et	3	main
ei	doc_685122975258_item	3542699	et	4	main
saa	doc_685122975258_item	3542700	et	4	main
aru	doc_685122975258_item	3542701	et	4	main
saada	doc_685122975258_item	3542702	et	4	main
olen	doc_685122975258_item	3542703	et	3	main
teiega	doc_685122975258_item	3542704	et	3	main
täpselt	doc_685122975258_item	3542705	et	4	main
nõus	doc_685122975258_item	3542706	et	4	main
et	doc_685122975258_item	3542707	et	3	main
kahekümneaastased	doc_685122975258_item	3542708	et	4	main
tahavad	doc_685122975258_item	3542709	et	3	main
elada	doc_685122975258_item	3542710	et	3	main
nagu	doc_685122975258_item	3542711	et	3	main
neljakümnesed	doc_685122975258_item	3542712	et	3	main
aga	doc_685122975258_item	3542713	et	3	main
nimi	doc_685122975258_item	3542659	et	3	main
on	doc_685122975258_item	3542660	et	4	main
eesnimi	doc_685122975258_item	3542661	et	3	main
perekonnanimi	doc_685122975258_item	3542662	et	3	main
olen	doc_685122975258_item	3542663	et	3	main
tehnikaülikoolis	doc_685122975258_item	3542670	et	4	main
lugenud	doc_685122975258_item	3542675	et	4	main
teie	doc_685122975258_item	3542676	et	4	main
tahaks	doc_685122975258_item	3542680	et	3	main
arvamust	doc_685122975258_item	3542682	et	3	main
artikkel	doc_685122975258_item	3542684	et	3	main
huvitav	doc_685122975258_item	3542687	et	4	main
enamuses	doc_685122975258_item	3542688	et	4	main
olen	doc_685122975258_item	3542689	et	3	main
teiega	doc_685122975258_item	3542690	et	3	main
on	doc_685122975258_item	3542693	et	4	main
eest	doc_685122975258_item	3542728	et	4	main
olla	doc_685122975258_item	3542729	et	3	main
samusugune	doc_685122975258_item	3542730	et	4	main
teiseks	doc_685122975258_item	3542745	et	4	main
tahaks	doc_685122975258_item	3542746	et	3	main
teie	doc_685122975258_item	3542747	et	4	main
arvamust	doc_685122975258_item	3542748	et	3	main
osa	doc_685122975258_item	3542751	et	4	main
et	doc_685122975258_item	3542763	et	3	main
õppida	doc_685122975258_item	3542765	et	3	main
rohkem	doc_685122975258_item	3542767	et	4	main
osa	doc_685122975258_item	3542768	et	4	main
teeb	doc_685122975258_item	3542769	et	3	main
niimodi	doc_685122975258_item	3542770	et	4	main
kuhu	doc_685122975258_item	3542771	et	3	main
võtavad	doc_685122975258_item	3542772	et	3	main
sellega	doc_685122975258_item	3542779	et	3	main
osa	doc_685122975258_item	3542791	et	4	main
kus	doc_685122975258_item	3542792	et	3	main
räägiti	doc_685122975258_item	3542793	et	3	main
välja	doc_685122975258_item	3542821	et	4	main
mõista	doc_685122975258_item	3542824	et	4	main
töötada	doc_685122975258_item	3542836	et	3	main
siis	doc_685122975258_item	3542837	et	3	main
otsustasin	doc_685122975259_item	3542891	et	3	main
sellel	doc_685122975259_item	3542902	et	4	main
lõpetasin	doc_685122975259_item	3542905	et	3	main
lapsepõlvest	doc_685122975259_item	3542916	et	4	main
kuhu	doc_685122975259_item	3542918	et	3	main
õppida	doc_685122975259_item	3542921	et	3	main
et	doc_685122975259_item	3542929	et	3	main
suhtun	doc_685122975259_item	3542930	et	3	main
esimene	doc_685122975259_item	3542931	et	3	main
tahan	doc_685122975259_item	3542934	et	3	main
rahulikult	doc_685122975259_item	3542936	et	4	main
ja	doc_685122975259_item	3542938	et	3	main
auto	doc_685122975259_item	3542944	et	4	main
ja	doc_685122975259_item	3542945	et	3	main
noored	doc_685122975259_item	3542953	et	3	main
et	doc_685122975259_item	3542959	et	3	main
ma	doc_685122975259_item	3542960	et	3	main
ei	doc_685122975259_item	3542961	et	4	main
parem	doc_685122975259_item	3542965	et	4	main
saa	doc_685122975259_item	3542971	et	4	main
ma	doc_685122975259_item	3542983	et	3	main
kuskil	doc_685122975259_item	3542994	et	3	main
stressist	doc_685122975259_item	3543001	et	3	main
et	doc_685122975259_item	3543003	et	3	main
tõepoolest	doc_685122975259_item	3543005	et	3	main
tähtis	doc_685122975259_item	3543007	et	4	main
aga	doc_685122975259_item	3543015	et	3	main
võtta	doc_685122975259_item	3543018	et	3	main
lihtsalt	doc_685122975259_item	3543022	et	4	main
valmistada	doc_685122975259_item	3543023	et	3	main
paanika	doc_685122975259_item	3543024	et	4	main
inimesi	doc_685122975259_item	3543036	et	4	main
lp	doc_685122975260_item	3543052	et	4	main
ma	doc_685122975260_item	3543058	et	3	main
tallinna	doc_685122975260_item	3543060	et	4	main
ma	doc_685122975260_item	3543068	et	3	main
selle	doc_685122975260_item	3543076	et	4	main
tänavatest	doc_685122975260_item	3543087	et	4	main
targad	doc_685122975260_item	3543092	et	3	main
püüab	doc_685122975260_item	3543126	et	3	main
eluks	doc_685122975260_item	3543127	et	3	main
vajalikuid	doc_685122975260_item	3543128	et	4	main
ma	doc_685122975258_item	3542714	et	3	main
kirjutasite	doc_685122975258_item	3542720	et	3	main
nagu	doc_685122975258_item	3542723	et	3	main
või	doc_685122975258_item	3542733	et	4	main
nende	doc_685122975258_item	3542734	et	4	main
abituriendidest	doc_685122975258_item	3542752	et	4	main
ei	doc_685122975258_item	3542753	et	4	main
täpselt	doc_685122975258_item	3542755	et	4	main
mina	doc_685122975258_item	3542758	et	4	main
aga	doc_685122975258_item	3542759	et	3	main
vastupidi	doc_685122975258_item	3542760	et	3	main
sain	doc_685122975258_item	3542761	et	3	main
midagi	doc_685122975258_item	3542783	et	4	main
teha	doc_685122975258_item	3542784	et	3	main
mulle	doc_685122975258_item	3542788	et	4	main
teie	doc_685122975258_item	3542789	et	4	main
võimalikult	doc_685122975258_item	3542816	et	4	main
seda	doc_685122975258_item	3542820	et	3	main
ei	doc_685122975258_item	3542823	et	4	main
enamus	doc_685122975258_item	3542825	et	4	main
kui	doc_685122975258_item	3542826	et	3	main
raske	doc_685122975258_item	3542827	et	4	main
millal	doc_685122975258_item	3542833	et	3	main
ta	doc_685122975258_item	3542838	et	4	main
ametlik	doc_685122975259_item	3542874	et	3	main
tere	doc_685122975259_item	3542876	et	3	main
see	doc_685122975259_item	3542886	et	3	main
ma	doc_685122975259_item	3542890	et	3	main
kirjutada	doc_685122975259_item	3542893	et	3	main
mul	doc_685122975259_item	3542896	et	3	main
keeruline	doc_685122975259_item	3542898	et	4	main
valik	doc_685122975259_item	3542899	et	3	main
minus	doc_685122975259_item	3542900	et	3	main
elus	doc_685122975259_item	3542901	et	4	main
tean	doc_685122975259_item	3542917	et	3	main
tahan	doc_685122975259_item	3542920	et	3	main
ja	doc_685122975259_item	3542922	et	3	main
rühmasse	doc_685122975259_item	3542932	et	3	main
palka	doc_685122975259_item	3542942	et	4	main
inimest	doc_685122975259_item	3542954	et	3	main
tea	doc_685122975259_item	3542962	et	4	main
selles	doc_685122975259_item	3542973	et	4	main
oli	doc_685122975259_item	3542979	et	3	main
saa	doc_685122975259_item	3542993	et	4	main
niisugune	doc_685122975259_item	3542996	et	3	main
kogu	doc_685122975259_item	3543013	et	4	main
kättes	doc_685122975259_item	3543020	et	4	main
ja	doc_685122975259_item	3543037	et	3	main
kaalep	doc_685122975260_item	3543054	et	4	main
on	doc_685122975260_item	3543065	et	4	main
perekonnanimi	doc_685122975260_item	3543067	et	3	main
lugesin	doc_685122975260_item	3543069	et	3	main
kohta	doc_685122975260_item	3543077	et	4	main
oma	doc_685122975260_item	3543078	et	4	main
et	doc_685122975260_item	3543085	et	3	main
üsna	doc_685122975260_item	3543090	et	3	main
ja	doc_685122975260_item	3543094	et	3	main
lihtsalt	doc_685122975260_item	3543117	et	4	main
minna	doc_685122975260_item	3543119	et	3	main
nendest	doc_685122975260_item	3543124	et	4	main
kes	doc_685122975260_item	3543125	et	4	main
kuritegu	doc_685122975260_item	3543132	et	4	main
meie	doc_685122975260_item	3543143	et	4	main
elu	doc_685122975260_item	3543144	et	4	main
nende	doc_685122975260_item	3543149	et	4	main
paremaks	doc_685122975260_item	3543195	et	4	main
ei	doc_685122975260_item	3543203	et	4	main
heas	doc_685122975260_item	3543209	et	3	main
on	doc_685122975260_item	3543211	et	4	main
hakkame	doc_685122975260_item	3543221	et	3	main
31112004	doc_685122975260_item	3543229	et	2	main
kalev	doc_685122975261_item	3543235	et	3	main
nõus	doc_685122975261_item	3543237	et	4	main
tänapäevane	doc_685122975261_item	3543240	et	4	main
põlvkond	doc_685122975261_item	3543241	et	3	main
normaalselt	doc_685122975261_item	3543250	et	4	main
maja	doc_685122975261_item	3543255	et	4	main
nendel	doc_685122975261_item	3543259	et	4	main
mis	doc_685122975261_item	3543266	et	4	main
riigieksami	doc_685122975261_item	3543267	et	3	main
nad	doc_685122975261_item	3543268	et	3	main
peavad	doc_685122975261_item	3543269	et	4	main
aru	doc_685122975258_item	3542762	et	4	main
majandust	doc_685122975258_item	3542766	et	4	main
siin	doc_685122975258_item	3542773	et	4	main
oli	doc_685122975258_item	3542776	et	3	main
ja	doc_685122975258_item	3542778	et	3	main
artiki	doc_685122975258_item	3542790	et	4	main
olen	doc_685122975258_item	3542795	et	3	main
juba	doc_685122975258_item	3542796	et	3	main
lugenud	doc_685122975258_item	3542797	et	4	main
sellest	doc_685122975258_item	3542798	et	4	main
suuremat	doc_685122975258_item	3542799	et	4	main
artiklit	doc_685122975258_item	3542800	et	3	main
kus	doc_685122975258_item	3542801	et	3	main
oli	doc_685122975258_item	3542802	et	3	main
samasugune	doc_685122975258_item	3542803	et	3	main
informatsiion	doc_685122975258_item	3542804	et	4	main
rahaasjus	doc_685122975258_item	3542805	et	3	main
on	doc_685122975258_item	3542806	et	4	main
meie	doc_685122975258_item	3542807	et	4	main
abituriendid	doc_685122975258_item	3542808	et	3	main
samas	doc_685122975258_item	3542809	et	4	main
väga	doc_685122975258_item	3542810	et	3	main
realistlikud	doc_685122975258_item	3542811	et	3	main
aga	doc_685122975258_item	3542812	et	3	main
kõik	doc_685122975258_item	3542813	et	4	main
soovivad	doc_685122975258_item	3542814	et	4	main
saada	doc_685122975258_item	3542815	et	4	main
kuid	doc_685122975258_item	3542819	et	4	main
on	doc_685122975258_item	3542828	et	4	main
seda	doc_685122975258_item	3542829	et	3	main
iga	doc_685122975258_item	3542834	et	4	main
kõik	doc_685122975258_item	3542839	et	4	main
aru	doc_685122975258_item	3542840	et	4	main
sai	doc_685122975258_item	3542841	et	4	main
te	doc_685122975258_item	3542842	et	4	main
olete	doc_685122975258_item	3542843	et	3	main
vaga	doc_685122975258_item	3542844	et	4	main
huvitav	doc_685122975258_item	3542845	et	4	main
ajakirjanik	doc_685122975258_item	3542846	et	3	main
mulle	doc_685122975258_item	3542847	et	4	main
meeldivad	doc_685122975258_item	3542848	et	4	main
väga	doc_685122975258_item	3542849	et	3	main
teie	doc_685122975258_item	3542850	et	4	main
artiklid	doc_685122975258_item	3542851	et	3	main
lõpuks	doc_685122975258_item	3542852	et	4	main
teie	doc_685122975259_item	3542882	et	4	main
ajalehest	doc_685122975259_item	3542884	et	4	main
rohkem	doc_685122975258_item	3542786	et	4	main
palgast	doc_685122975258_item	3542794	et	4	main
öeldes	doc_685122975258_item	3542822	et	3	main
reaalselt	doc_685122975258_item	3542830	et	4	main
saada	doc_685122975258_item	3542831	et	4	main
mõtlen	doc_685122975258_item	3542832	et	3	main
tahaksin	doc_685122975258_item	3542853	et	3	main
lisada	doc_685122975258_item	3542854	et	3	main
et	doc_685122975258_item	3542855	et	3	main
minu	doc_685122975258_item	3542856	et	3	main
poolt	doc_685122975258_item	3542857	et	4	main
loetud	doc_685122975258_item	3542858	et	4	main
artikkel	doc_685122975258_item	3542859	et	3	main
oli	doc_685122975258_item	3542860	et	3	main
huvitav	doc_685122975258_item	3542861	et	4	main
ning	doc_685122975258_item	3542862	et	3	main
ma	doc_685122975258_item	3542863	et	3	main
sooviksin	doc_685122975258_item	3542864	et	3	main
teile	doc_685122975258_item	3542865	et	4	main
kõike	doc_685122975258_item	3542866	et	4	main
head	doc_685122975258_item	3542867	et	4	main
lugupidamisega	doc_685122975258_item	3542868	et	3	main
teie	doc_685122975258_item	3542869	et	4	main
lugeja	doc_685122975258_item	3542870	et	4	main
eesnimi	doc_685122975258_item	3542871	et	3	main
perekonnanimi	doc_685122975258_item	3542872	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975258_item	3542873	et	4	main
tänan	doc_685122975259_item	3543038	et	3	main
te	doc_685122975259_item	3543040	et	4	main
leidsite	doc_685122975259_item	3543041	et	3	main
aeg	doc_685122975259_item	3543042	et	3	main
lugeda	doc_685122975259_item	3543043	et	3	main
minu	doc_685122975259_item	3543044	et	3	main
kirju	doc_685122975259_item	3543045	et	4	main
lugupidamisega	doc_685122975259_item	3543046	et	3	main
eesnimi	doc_685122975259_item	3543047	et	3	main
perekonnanimi	doc_685122975259_item	3543048	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975259_item	3543049	et	4	main
et	doc_685122975259_item	3543039	et	3	main
lugupeetud	doc_685122975259_item	3542877	et	4	main
kaalep	doc_685122975259_item	3542879	et	4	main
ma	doc_685122975259_item	3542880	et	3	main
lugesin	doc_685122975259_item	3542881	et	3	main
sellepärast	doc_685122975259_item	3542889	et	3	main
veel	doc_685122975259_item	3542894	et	4	main
oli	doc_685122975259_item	3542897	et	3	main
ja	doc_685122975259_item	3542907	et	3	main
ma	doc_685122975259_item	3542908	et	3	main
tahaksin	doc_685122975259_item	3542909	et	3	main
sisse	doc_685122975259_item	3542910	et	4	main
astuda	doc_685122975259_item	3542911	et	3	main
ülikooli	doc_685122975259_item	3542912	et	4	main
aga	doc_685122975259_item	3542913	et	3	main
ma	doc_685122975259_item	3542914	et	3	main
mind	doc_685122975259_item	3542887	et	4	main
huvitab	doc_685122975259_item	3542888	et	3	main
hiljuti	doc_685122975259_item	3542895	et	4	main
aastal	doc_685122975259_item	3542903	et	3	main
kool	doc_685122975259_item	3542906	et	4	main
saada	doc_685122975259_item	3542939	et	4	main
täiesti	doc_685122975259_item	3542940	et	3	main
normaalset	doc_685122975259_item	3542941	et	3	main
uut	doc_685122975259_item	3542943	et	3	main
mul	doc_685122975259_item	3542956	et	3	main
kuhu	doc_685122975259_item	3542963	et	3	main
mulle	doc_685122975259_item	3542964	et	4	main
ei	doc_685122975259_item	3542970	et	4	main
ülikoolis	doc_685122975259_item	3542974	et	4	main
või	doc_685122975259_item	3542975	et	4	main
sellel	doc_685122975259_item	3542976	et	4	main
ametil	doc_685122975259_item	3542977	et	3	main
see	doc_685122975259_item	3542978	et	3	main
juba	doc_685122975259_item	3542915	et	3	main
ma	doc_685122975259_item	3542919	et	3	main
kelleks	doc_685122975259_item	3542923	et	4	main
saada	doc_685122975259_item	3542924	et	4	main
ma	doc_685122975259_item	3542933	et	3	main
töötada	doc_685122975259_item	3542935	et	3	main
rabelemata	doc_685122975259_item	3542937	et	4	main
tavalised	doc_685122975259_item	3542951	et	4	main
soovid	doc_685122975259_item	3542952	et	4	main
tekkis	doc_685122975259_item	3542957	et	3	main
isegi	doc_685122975259_item	3542969	et	4	main
periood	doc_685122975259_item	3542980	et	3	main
eksamite	doc_685122975259_item	3542981	et	3	main
mul	doc_685122975259_item	3542986	et	3	main
pahad	doc_685122975259_item	3542988	et	4	main
tulemused	doc_685122975259_item	3542989	et	3	main
ja	doc_685122975259_item	3542990	et	3	main
ma	doc_685122975259_item	3542991	et	3	main
ei	doc_685122975259_item	3542992	et	4	main
minu	doc_685122975259_item	3542998	et	3	main
tekkisid	doc_685122975259_item	3543000	et	4	main
sellepärast	doc_685122975259_item	3543002	et	3	main
see	doc_685122975259_item	3543004	et	3	main
väga	doc_685122975259_item	3543006	et	3	main
ja	doc_685122975259_item	3543008	et	3	main
elu	doc_685122975259_item	3543014	et	4	main
tegemata	doc_685122975259_item	3543025	et	4	main
ja	doc_685122975259_item	3543026	et	3	main
mul	doc_685122975259_item	3543027	et	3	main
kõik	doc_685122975259_item	3543028	et	4	main
ma	doc_685122975259_item	3543029	et	3	main
loodan	doc_685122975259_item	3543030	et	3	main
et	doc_685122975259_item	3543031	et	3	main
minu	doc_685122975259_item	3543032	et	3	main
kiri	doc_685122975259_item	3543033	et	3	main
aitab	doc_685122975259_item	3543034	et	3	main
mõtlesin	doc_685122975259_item	3542984	et	3	main
õppida	doc_685122975259_item	3542995	et	3	main
saaksin	doc_685122975259_item	3543017	et	3	main
teistesse	doc_685122975259_item	3543035	et	4	main
ametlik	doc_685122975260_item	3543050	et	3	main
tehnika	doc_685122975260_item	3543061	et	4	main
minu	doc_685122975260_item	3543063	et	3	main
ja	doc_685122975260_item	3543073	et	3	main
mul	doc_685122975260_item	3543074	et	3	main
on	doc_685122975260_item	3543075	et	4	main
küll	doc_685122975260_item	3543082	et	4	main
on	doc_685122975260_item	3543089	et	4	main
sellest	doc_685122975260_item	3543115	et	4	main
pärivett	doc_685122975260_item	3543118	et	3	main
vahendusi	doc_685122975260_item	3543129	et	4	main
see	doc_685122975260_item	3543134	et	3	main
osa	doc_685122975260_item	3543138	et	4	main
mis	doc_685122975260_item	3543139	et	4	main
teil	doc_685122975260_item	3543145	et	4	main
on	doc_685122975260_item	3543146	et	4	main
on	doc_685122975260_item	3543180	et	4	main
keskkonna	doc_685122975260_item	3543181	et	3	main
kas	doc_685122975260_item	3543183	et	3	main
nendele	doc_685122975260_item	3543190	et	4	main
meie	doc_685122975260_item	3543193	et	4	main
sotsiaalsfääri	doc_685122975260_item	3543194	et	4	main
positiivsemalt	doc_685122975260_item	3543214	et	4	main
mõtlema	doc_685122975260_item	3543215	et	3	main
ja	doc_685122975260_item	3543216	et	3	main
seepärast	doc_685122975260_item	3543217	et	3	main
parimate	doc_685122975260_item	3543225	et	4	main
soovidega	doc_685122975260_item	3543226	et	3	main
lugupetud	doc_685122975261_item	3543233	et	3	main
olen	doc_685122975261_item	3543236	et	3	main
teiega	doc_685122975261_item	3543238	et	3	main
rahulikult	doc_685122975261_item	3543248	et	4	main
saada	doc_685122975261_item	3543249	et	4	main
osta	doc_685122975261_item	3543254	et	4	main
aga	doc_685122975261_item	3543258	et	3	main
tea	doc_685122975261_item	3543265	et	4	main
otsus	doc_685122975261_item	3543279	et	3	main
saadab	doc_685122975261_item	3543283	et	3	main
kogu	doc_685122975261_item	3543285	et	4	main
elu	doc_685122975261_item	3543286	et	4	main
saavad	doc_685122975261_item	3543289	et	4	main
ei	doc_685122975261_item	3543294	et	4	main
aastat	doc_685122975261_item	3543313	et	3	main
eestis	doc_685122975261_item	3543335	et	3	main
niimodi	doc_685122975261_item	3543336	et	4	main
vähem	doc_685122975261_item	3543345	et	4	main
ja	doc_685122975261_item	3543346	et	3	main
tahavad	doc_685122975261_item	3543358	et	3	main
et	doc_685122975261_item	3543359	et	3	main
nooret	doc_685122975261_item	3543369	et	4	main
töölast	doc_685122975261_item	3543370	et	4	main
eelistavad	doc_685122975261_item	3543372	et	4	main
töölast	doc_685122975261_item	3543373	et	4	main
põhjus	doc_685122975261_item	3543383	et	4	main
kiri	doc_685122975260_item	3543051	et	3	main
olen	doc_685122975260_item	3543056	et	3	main
artikli	doc_685122975260_item	3543072	et	3	main
seisukoht	doc_685122975260_item	3543079	et	3	main
ma	doc_685122975260_item	3543080	et	3	main
olen	doc_685122975260_item	3543081	et	3	main
teiega	doc_685122975260_item	3543083	et	3	main
nõus	doc_685122975260_item	3543084	et	4	main
noortest	doc_685122975260_item	3543088	et	4	main
asjalikud	doc_685122975260_item	3543091	et	3	main
sihiteadlikud	doc_685122975260_item	3543093	et	3	main
heameelsed	doc_685122975260_item	3543095	et	3	main
inimesed	doc_685122975260_item	3543096	et	3	main
on	doc_685122975260_item	3543097	et	4	main
aga	doc_685122975260_item	3543098	et	3	main
ka	doc_685122975260_item	3543099	et	3	main
need	doc_685122975260_item	3543100	et	3	main
kes	doc_685122975260_item	3543101	et	4	main
ei	doc_685122975260_item	3543102	et	4	main
suuda	doc_685122975260_item	3543103	et	4	main
meie	doc_685122975260_item	3543104	et	4	main
elu	doc_685122975260_item	3543105	et	4	main
teha	doc_685122975260_item	3543107	et	3	main
paremaks	doc_685122975260_item	3543106	et	4	main
ja	doc_685122975260_item	3543108	et	3	main
üldse	doc_685122975260_item	3543109	et	3	main
midagi	doc_685122975260_item	3543110	et	4	main
teha	doc_685122975260_item	3543111	et	3	main
et	doc_685122975260_item	3543116	et	3	main
nende	doc_685122975260_item	3543112	et	4	main
elumõte	doc_685122975260_item	3543113	et	3	main
koosneb	doc_685122975260_item	3543114	et	3	main
räägin	doc_685122975260_item	3543120	et	3	main
laiskjatest	doc_685122975260_item	3543122	et	4	main
lihtsam	doc_685122975260_item	3543130	et	4	main
kogu	doc_685122975260_item	3543140	et	4	main
aeg	doc_685122975260_item	3543141	et	3	main
segab	doc_685122975260_item	3543142	et	3	main
õigus	doc_685122975260_item	3543147	et	4	main
või	doc_685122975260_item	3543177	et	4	main
vatamata	doc_685122975260_item	3543189	et	4	main
kes	doc_685122975260_item	3543191	et	4	main
kogu	doc_685122975260_item	3543197	et	4	main
aeg	doc_685122975260_item	3543198	et	3	main
öelda	doc_685122975260_item	3543207	et	4	main
saame	doc_685122975260_item	3543218	et	4	main
eesnimi	doc_685122975260_item	3543227	et	3	main
tegemas	doc_685122975260_item	3543133	et	3	main
keskkonna	doc_685122975260_item	3543137	et	3	main
sama	doc_685122975260_item	3543148	et	4	main
öelda	doc_685122975260_item	3543178	et	4	main
see	doc_685122975260_item	3543179	et	3	main
saab	doc_685122975260_item	3543184	et	3	main
muuta	doc_685122975260_item	3543196	et	4	main
luba	doc_685122975260_item	3543204	et	4	main
elada	doc_685122975260_item	3543205	et	3	main
piltlikult	doc_685122975260_item	3543206	et	4	main
seeiloos	doc_685122975260_item	3543210	et	4	main
vaja	doc_685122975260_item	3543212	et	4	main
küll	doc_685122975260_item	3543213	et	4	main
optimistidek	doc_685122975260_item	3543219	et	4	main
paremast	doc_685122975260_item	3543222	et	4	main
tulevikust	doc_685122975260_item	3543223	et	4	main
unistama	doc_685122975260_item	3543224	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975260_item	3543230	et	4	main
kiri	doc_685122975261_item	3543232	et	3	main
palka	doc_685122975261_item	3543251	et	4	main
lisada	doc_685122975261_item	3543252	et	3	main
auto	doc_685122975261_item	3543253	et	4	main
korter	doc_685122975261_item	3543257	et	3	main
tulevikuplaanit	doc_685122975261_item	3543262	et	4	main
ei	doc_685122975261_item	3543264	et	4	main
teevad	doc_685122975261_item	3543278	et	3	main
viimasel	doc_685122975261_item	3543280	et	3	main
sisse	doc_685122975261_item	3543290	et	4	main
elu	doc_685122975261_item	3543314	et	4	main
kaunis	doc_685122975261_item	3543332	et	4	main
on	doc_685122975261_item	3543344	et	4	main
töölased	doc_685122975261_item	3543361	et	4	main
teised	doc_685122975261_item	3543371	et	4	main
on	doc_685122975261_item	3543382	et	4	main
ametlik	doc_685122975263_item	3543390	et	3	main
teiele	doc_685122975263_item	3543397	et	4	main
kui	doc_685122975263_item	3543406	et	3	main
ma	doc_685122975263_item	3543407	et	3	main
ei	doc_685122975263_item	3543408	et	4	main
tallinna	doc_685122975263_item	3543424	et	4	main
tehnika	doc_685122975263_item	3543425	et	4	main
kui	doc_685122975263_item	3543437	et	3	main
ma	doc_685122975263_item	3543438	et	3	main
põlvkond	doc_685122975263_item	3543443	et	3	main
problemmid	doc_685122975263_item	3543446	et	4	main
midagi	doc_685122975263_item	3543459	et	4	main
nõus	doc_685122975263_item	3543467	et	4	main
noored	doc_685122975263_item	3543471	et	3	main
oma	doc_685122975263_item	3543473	et	4	main
õigused	doc_685122975263_item	3543474	et	4	main
õigused	doc_685122975263_item	3543482	et	4	main
riiklik	doc_685122975263_item	3543488	et	3	main
kui	doc_685122975263_item	3543494	et	3	main
siis	doc_685122975263_item	3543499	et	3	main
vanematel	doc_685122975263_item	3543501	et	4	main
on	doc_685122975263_item	3543502	et	4	main
ja	doc_685122975263_item	3543505	et	3	main
nad	doc_685122975263_item	3543506	et	3	main
hakkavad	doc_685122975263_item	3543507	et	4	main
veel	doc_685122975263_item	3543513	et	4	main
õigused	doc_685122975263_item	3543515	et	4	main
nagu	doc_685122975263_item	3543516	et	3	main
ja	doc_685122975263_item	3543523	et	3	main
praegu	doc_685122975263_item	3543524	et	3	main
uued	doc_685122975263_item	3543525	et	3	main
tehnologiad	doc_685122975263_item	3543526	et	4	main
aga	doc_685122975263_item	3543527	et	3	main
ei	doc_685122975263_item	3543552	et	4	main
uru	doc_685122975263_item	3543554	et	3	main
rühm	doc_685122975263_item	3543559	et	3	main
neist	doc_685122975263_item	3543567	et	4	main
kuidas	doc_685122975263_item	3543574	et	3	main
mõtlevad	doc_685122975263_item	3543581	et	4	main
olema	doc_685122975263_item	3543583	et	4	main
mitte	doc_685122975263_item	3543585	et	3	main
kohta	doc_685122975260_item	3543150	et	4	main
kes	doc_685122975260_item	3543151	et	4	main
ei	doc_685122975260_item	3543152	et	4	main
suutnud	doc_685122975260_item	3543153	et	4	main
vajalikuks	doc_685122975260_item	3543154	et	3	main
hetkeks	doc_685122975260_item	3543155	et	4	main
endale	doc_685122975260_item	3543156	et	4	main
panna	doc_685122975260_item	3543158	et	4	main
nad	doc_685122975260_item	3543159	et	3	main
eesmärgi	doc_685122975260_item	3543157	et	4	main
tegelikult	doc_685122975260_item	3543160	et	4	main
meie	doc_685122975260_item	3543161	et	4	main
ühiskonna	doc_685122975260_item	3543162	et	4	main
ebamääratud	doc_685122975260_item	3543163	et	4	main
osa	doc_685122975260_item	3543164	et	4	main
keegi	doc_685122975260_item	3543165	et	4	main
ei	doc_685122975260_item	3543166	et	4	main
tea	doc_685122975260_item	3543167	et	4	main
mida	doc_685122975260_item	3543168	et	4	main
võib	doc_685122975260_item	3543169	et	3	main
nissugusest	doc_685122975260_item	3543170	et	4	main
inimest	doc_685122975260_item	3543171	et	3	main
välja	doc_685122975260_item	3543172	et	4	main
tulla	doc_685122975260_item	3543173	et	3	main
ta	doc_685122975260_item	3543174	et	4	main
ise	doc_685122975260_item	3543175	et	4	main
ei	doc_685122975260_item	3543176	et	4	main
riskigrupp	doc_685122975260_item	3543182	et	3	main
ta	doc_685122975260_item	3543185	et	4	main
teadlaseks	doc_685122975260_item	3543186	et	3	main
või	doc_685122975260_item	3543187	et	4	main
kuritegijaks	doc_685122975260_item	3543188	et	3	main
püüab	doc_685122975260_item	3543192	et	3	main
hakkavad	doc_685122975260_item	3543199	et	4	main
tegutsema	doc_685122975260_item	3543200	et	3	main
need	doc_685122975260_item	3543201	et	3	main
kes	doc_685122975260_item	3543202	et	4	main
nagu	doc_685122975260_item	3543208	et	3	main
ja	doc_685122975260_item	3543220	et	3	main
perekonnanimi	doc_685122975260_item	3543228	et	3	main
ametlik	doc_685122975261_item	3543231	et	3	main
tiina	doc_685122975261_item	3543234	et	4	main
ei	doc_685122975261_item	3543260	et	4	main
ole	doc_685122975261_item	3543261	et	4	main
palju	doc_685122975261_item	3543263	et	4	main
minna	doc_685122975261_item	3543276	et	3	main
päeval	doc_685122975261_item	3543281	et	3	main
kutsekoolisse	doc_685122975261_item	3543291	et	4	main
nendel	doc_685122975261_item	3543293	et	4	main
kodus	doc_685122975261_item	3543316	et	4	main
palk	doc_685122975261_item	3543331	et	3	main
et	doc_685122975261_item	3543239	et	3	main
on	doc_685122975261_item	3543242	et	4	main
väga	doc_685122975261_item	3543243	et	3	main
vähenõudlik	doc_685122975261_item	3543244	et	3	main
noored	doc_685122975261_item	3543245	et	3	main
tahavad	doc_685122975261_item	3543246	et	3	main
töötada	doc_685122975261_item	3543247	et	3	main
või	doc_685122975261_item	3543256	et	4	main
nad	doc_685122975261_item	3543277	et	3	main
palju	doc_685122975261_item	3543287	et	4	main
noored	doc_685122975261_item	3543288	et	3	main
ole	doc_685122975261_item	3543295	et	4	main
valikut	doc_685122975261_item	3543296	et	3	main
aga	doc_685122975261_item	3543297	et	3	main
seal	doc_685122975261_item	3543298	et	4	main
ei	doc_685122975261_item	3543299	et	4	main
anna	doc_685122975261_item	3543300	et	4	main
kõrgharidust	doc_685122975261_item	3543301	et	4	main
mis	doc_685122975261_item	3543302	et	4	main
praegu	doc_685122975261_item	3543303	et	3	main
tähtsalt	doc_685122975261_item	3543304	et	4	main
pärast	doc_685122975261_item	3543305	et	4	main
õppust	doc_685122975261_item	3543306	et	3	main
noored	doc_685122975261_item	3543307	et	3	main
spetsialistid	doc_685122975261_item	3543308	et	3	main
ootavad	doc_685122975261_item	3543309	et	4	main
vaba	doc_685122975261_item	3543310	et	4	main
töökohta	doc_685122975261_item	3543311	et	4	main
mõned	doc_685122975261_item	3543312	et	3	main
toimub	doc_685122975261_item	3543315	et	3	main
tänavatel	doc_685122975261_item	3543317	et	4	main
igatahes	doc_685122975261_item	3543318	et	3	main
mitte	doc_685122975261_item	3543319	et	3	main
tööga	doc_685122975261_item	3543320	et	3	main
seoses	doc_685122975261_item	3543321	et	4	main
väga	doc_685122975261_item	3543322	et	3	main
palju	doc_685122975261_item	3543323	et	4	main
lähevad	doc_685122975261_item	3543324	et	3	main
ära	doc_685122975261_item	3543325	et	4	main
sest	doc_685122975261_item	3543328	et	4	main
riigsse	doc_685122975261_item	3543327	et	4	main
teisesse	doc_685122975261_item	3543326	et	4	main
seal	doc_685122975261_item	3543329	et	4	main
on	doc_685122975261_item	3543330	et	4	main
tööandjad	doc_685122975261_item	3543357	et	3	main
staaziga	doc_685122975261_item	3543374	et	4	main
aga	doc_685122975261_item	3543375	et	3	main
miks	doc_685122975261_item	3543384	et	4	main
lugupeetud	doc_685122975263_item	3543392	et	4	main
ülesanne	doc_685122975263_item	3543405	et	4	main
sooritada	doc_685122975261_item	3543270	et	3	main
ja	doc_685122975261_item	3543271	et	3	main
kuhu	doc_685122975261_item	3543272	et	3	main
eksami	doc_685122975261_item	3543273	et	3	main
punktidega	doc_685122975261_item	3543274	et	3	main
saab	doc_685122975261_item	3543275	et	3	main
mis	doc_685122975261_item	3543282	et	4	main
neid	doc_685122975261_item	3543284	et	4	main
sest	doc_685122975261_item	3543292	et	4	main
kui	doc_685122975261_item	3543334	et	3	main
tihti	doc_685122975261_item	3543337	et	3	main
vähem	doc_685122975261_item	3543347	et	4	main
töölist	doc_685122975261_item	3543348	et	3	main
ja	doc_685122975261_item	3543349	et	3	main
see	doc_685122975261_item	3543350	et	3	main
on	doc_685122975261_item	3543351	et	4	main
suur	doc_685122975261_item	3543352	et	3	main
peaks	doc_685122975261_item	3543362	et	4	main
olla	doc_685122975261_item	3543363	et	3	main
kõrgekvalifitsiooniga	doc_685122975261_item	3543364	et	4	main
üksikud	doc_685122975261_item	3543365	et	3	main
firmad	doc_685122975261_item	3543366	et	3	main
õppetavad	doc_685122975261_item	3543367	et	3	main
uut	doc_685122975261_item	3543368	et	3	main
töölast	doc_685122975261_item	3543377	et	4	main
vähe	doc_685122975261_item	3543378	et	3	main
arvan	doc_685122975261_item	3543379	et	3	main
et	doc_685122975261_item	3543380	et	3	main
see	doc_685122975261_item	3543381	et	3	main
on	doc_685122975261_item	3543387	et	4	main
kaalep	doc_685122975263_item	3543394	et	4	main
sest	doc_685122975263_item	3543399	et	4	main
et	doc_685122975263_item	3543400	et	3	main
see	doc_685122975263_item	3543401	et	3	main
on	doc_685122975263_item	3543402	et	4	main
minu	doc_685122975263_item	3543403	et	3	main
seda	doc_685122975263_item	3543410	et	3	main
siis	doc_685122975263_item	3543411	et	3	main
taha	doc_685122975263_item	3543418	et	4	main
olen	doc_685122975263_item	3543421	et	3	main
vaja	doc_685122975263_item	3543436	et	4	main
lugesin	doc_685122975263_item	3543439	et	3	main
teie	doc_685122975263_item	3543440	et	4	main
mu	doc_685122975263_item	3543444	et	3	main
midagi	doc_685122975263_item	3543451	et	4	main
aru	doc_685122975263_item	3543454	et	4	main
ei	doc_685122975263_item	3543457	et	4	main
saa	doc_685122975263_item	3543458	et	4	main
sellest	doc_685122975263_item	3543463	et	4	main
et	doc_685122975263_item	3543464	et	3	main
ma	doc_685122975263_item	3543465	et	3	main
olen	doc_685122975263_item	3543466	et	3	main
vanematest	doc_685122975263_item	3543476	et	4	main
aga	doc_685122975263_item	3543477	et	3	main
praegu	doc_685122975263_item	3543478	et	3	main
tahavad	doc_685122975263_item	3543480	et	3	main
on	doc_685122975263_item	3543492	et	4	main
lähevad	doc_685122975263_item	3543496	et	3	main
raha	doc_685122975263_item	3543508	et	4	main
nendel	doc_685122975263_item	3543514	et	4	main
raske	doc_685122975263_item	3543521	et	4	main
petta	doc_685122975263_item	3543522	et	3	main
tegite	doc_685122975263_item	3543557	et	3	main
noored	doc_685122975263_item	3543562	et	3	main
ei	doc_685122975263_item	3543564	et	4	main
keegi	doc_685122975263_item	3543570	et	4	main
elu	doc_685122975263_item	3543576	et	4	main
jaa	doc_685122975263_item	3543578	et	3	main
keegi	doc_685122975263_item	3543586	et	4	main
ei	doc_685122975263_item	3543587	et	4	main
mida	doc_685122975263_item	3543590	et	4	main
tuleb	doc_685122975263_item	3543592	et	3	main
suur	doc_685122975261_item	3543333	et	3	main
lahendakse	doc_685122975261_item	3543338	et	4	main
rahaasju	doc_685122975261_item	3543339	et	3	main
probleemi	doc_685122975261_item	3543340	et	4	main
aga	doc_685122975261_item	3543341	et	3	main
eestis	doc_685122975261_item	3543342	et	3	main
juba	doc_685122975261_item	3543343	et	3	main
probleem	doc_685122975261_item	3543353	et	3	main
eest	doc_685122975261_item	3543354	et	4	main
firmad	doc_685122975261_item	3543355	et	3	main
ja	doc_685122975261_item	3543356	et	3	main
nende	doc_685122975261_item	3543360	et	4	main
seelist	doc_685122975261_item	3543376	et	4	main
täna	doc_685122975261_item	3543385	et	4	main
põlvkond	doc_685122975261_item	3543386	et	3	main
vähenõudlik	doc_685122975261_item	3543388	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975261_item	3543389	et	4	main
kiri	doc_685122975263_item	3543391	et	3	main
kirjutan	doc_685122975263_item	3543396	et	3	main
kiri	doc_685122975263_item	3543398	et	3	main
tee	doc_685122975263_item	3543409	et	4	main
mul	doc_685122975263_item	3543412	et	3	main
ei	doc_685122975263_item	3543417	et	4	main
ma	doc_685122975263_item	3543420	et	3	main
perekonnanimi	doc_685122975263_item	3543423	et	3	main
tea	doc_685122975263_item	3543430	et	4	main
aga	doc_685122975263_item	3543432	et	3	main
artikle	doc_685122975263_item	3543441	et	4	main
ma	doc_685122975263_item	3543452	et	3	main
öelda	doc_685122975263_item	3543460	et	4	main
teiest	doc_685122975263_item	3543461	et	4	main
artiklist	doc_685122975263_item	3543462	et	4	main
et	doc_685122975263_item	3543469	et	3	main
vanemad	doc_685122975263_item	3543484	et	4	main
materiaalne	doc_685122975263_item	3543485	et	3	main
kindlustatus	doc_685122975263_item	3543486	et	4	main
eesnimi	doc_685122975263_item	3543637	et	3	main
perekonnanimi	doc_685122975263_item	3543638	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975263_item	3543639	et	4	main
tiina	doc_685122975263_item	3543393	et	4	main
ma	doc_685122975263_item	3543395	et	3	main
kodu	doc_685122975263_item	3543404	et	4	main
probleemid	doc_685122975263_item	3543414	et	3	main
aga	doc_685122975263_item	3543415	et	3	main
ma	doc_685122975263_item	3543416	et	3	main
tueb	doc_685122975263_item	3543413	et	4	main
need	doc_685122975263_item	3543419	et	3	main
eesnimi	doc_685122975263_item	3543422	et	3	main
ülikooli	doc_685122975263_item	3543426	et	4	main
tudeng	doc_685122975263_item	3543427	et	3	main
te	doc_685122975263_item	3543428	et	4	main
mind	doc_685122975263_item	3543431	et	4	main
ei	doc_685122975263_item	3543434	et	4	main
ole	doc_685122975263_item	3543435	et	4	main
olla	doc_685122975263_item	3543450	et	3	main
sain	doc_685122975263_item	3543453	et	3	main
valesti	doc_685122975263_item	3543455	et	3	main
eraldav	doc_685122975263_item	3543475	et	4	main
sotsiaaltagatised	doc_685122975263_item	3543487	et	3	main
tore	doc_685122975263_item	3543493	et	3	main
noored	doc_685122975263_item	3543495	et	3	main
vähem	doc_685122975263_item	3543503	et	4	main
koju	doc_685122975263_item	3543509	et	3	main
aga	doc_685122975263_item	3543511	et	3	main
vanemad	doc_685122975263_item	3543528	et	4	main
kuidas	doc_685122975263_item	3543555	et	3	main
on	doc_685122975263_item	3543561	et	4	main
tema	doc_685122975263_item	3543575	et	4	main
kellena	doc_685122975263_item	3543582	et	3	main
aga	doc_685122975263_item	3543584	et	3	main
täpselt	doc_685122975263_item	3543589	et	4	main
ametlik	doc_685122975265_item	3543640	et	3	main
teie	doc_685122975265_item	3543647	et	4	main
põlvkond	doc_685122975265_item	3543650	et	3	main
kuidas	doc_685122975265_item	3543657	et	3	main
te	doc_685122975265_item	3543658	et	4	main
sest	doc_685122975265_item	3543665	et	4	main
oma	doc_685122975265_item	3543669	et	4	main
mõnidel	doc_685122975265_item	3543671	et	4	main
kohtadel	doc_685122975265_item	3543672	et	3	main
olen	doc_685122975265_item	3543673	et	3	main
nõus	doc_685122975265_item	3543674	et	4	main
teiega	doc_685122975265_item	3543675	et	3	main
ja	doc_685122975265_item	3543676	et	3	main
te	doc_685122975265_item	3543681	et	4	main
väidate	doc_685122975265_item	3543682	et	3	main
et	doc_685122975265_item	3543683	et	3	main
praegune	doc_685122975265_item	3543684	et	3	main
põlvkond	doc_685122975265_item	3543685	et	3	main
need	doc_685122975265_item	3543686	et	3	main
jõulisemat	doc_685122975265_item	3543698	et	4	main
suuremaid	doc_685122975265_item	3543703	et	4	main
mõtet	doc_685122975265_item	3543707	et	3	main
saada	doc_685122975265_item	3543720	et	4	main
täiesti	doc_685122975265_item	3543721	et	3	main
normaalset	doc_685122975265_item	3543722	et	3	main
palka	doc_685122975265_item	3543723	et	4	main
olen	doc_685122975265_item	3543724	et	3	main
sest	doc_685122975265_item	3543728	et	4	main
see	doc_685122975265_item	3543729	et	3	main
täiesti	doc_685122975265_item	3543730	et	3	main
rahuldab	doc_685122975265_item	3543731	et	3	main
mitte	doc_685122975265_item	3543749	et	3	main
võib	doc_685122975265_item	3543752	et	3	main
nad	doc_685122975265_item	3543757	et	3	main
muutumisest	doc_685122975265_item	3543761	et	4	main
tahavad	doc_685122975265_item	3543763	et	3	main
praegustest	doc_685122975265_item	3543785	et	4	main
tingimustest	doc_685122975265_item	3543786	et	3	main
juba	doc_685122975265_item	3543795	et	3	main
õppida	doc_685122975265_item	3543800	et	3	main
kuidas	doc_685122975265_item	3543802	et	3	main
keskonnakaitsja	doc_685122975265_item	3543825	et	4	main
ametist	doc_685122975265_item	3543826	et	3	main
on	doc_685122975265_item	3543838	et	4	main
põlvkond	doc_685122975267_item	3543876	et	3	main
on	doc_685122975267_item	3543878	et	4	main
väga	doc_685122975267_item	3543879	et	3	main
huvitav	doc_685122975267_item	3543880	et	4	main
ja	doc_685122975267_item	3543881	et	3	main
tõsi	doc_685122975267_item	3543887	et	4	main
aga	doc_685122975267_item	3543888	et	3	main
ole	doc_685122975267_item	3543917	et	4	main
on	doc_685122975267_item	3543926	et	4	main
ole	doc_685122975267_item	3543931	et	4	main
et	doc_685122975267_item	3543933	et	3	main
tasuta	doc_685122975267_item	3543943	et	4	main
ei	doc_685122975263_item	3543429	et	4	main
see	doc_685122975263_item	3543433	et	3	main
vähenõudike	doc_685122975263_item	3543442	et	4	main
oli	doc_685122975263_item	3543445	et	3	main
tõlkimisest	doc_685122975263_item	3543447	et	4	main
sellest	doc_685122975263_item	3543448	et	4	main
võib	doc_685122975263_item	3543449	et	3	main
ma	doc_685122975263_item	3543456	et	3	main
teiege	doc_685122975263_item	3543468	et	4	main
minevikus	doc_685122975263_item	3543470	et	3	main
thaksid	doc_685122975263_item	3543472	et	4	main
nad	doc_685122975263_item	3543479	et	3	main
samasugune	doc_685122975263_item	3543481	et	3	main
nagu	doc_685122975263_item	3543483	et	3	main
hoollekanne	doc_685122975263_item	3543489	et	4	main
ja	doc_685122975263_item	3543490	et	3	main
varem	doc_685122975263_item	3543498	et	4	main
nendel	doc_685122975263_item	3543500	et	4	main
tegivusi	doc_685122975263_item	3543504	et	4	main
vanematel	doc_685122975263_item	3543517	et	4	main
siis	doc_685122975263_item	3543518	et	3	main
nemad	doc_685122975263_item	3543519	et	3	main
on	doc_685122975263_item	3543520	et	4	main
ma	doc_685122975263_item	3543551	et	3	main
te	doc_685122975263_item	3543556	et	4	main
kus	doc_685122975263_item	3543560	et	3	main
kes	doc_685122975263_item	3543563	et	4	main
saab	doc_685122975263_item	3543568	et	3	main
mitte	doc_685122975263_item	3543569	et	3	main
noortest	doc_685122975263_item	3543571	et	4	main
ei	doc_685122975263_item	3543572	et	4	main
tea	doc_685122975263_item	3543573	et	4	main
noored	doc_685122975263_item	3543580	et	3	main
tea	doc_685122975263_item	3543588	et	4	main
tulevikus	doc_685122975263_item	3543591	et	4	main
teiseks	doc_685122975263_item	3543593	et	4	main
sõnadeks	doc_685122975263_item	3543594	et	3	main
noored	doc_685122975263_item	3543595	et	3	main
lp	doc_685122975265_item	3543642	et	4	main
mulle	doc_685122975265_item	3543654	et	4	main
väga	doc_685122975265_item	3543655	et	3	main
meeldis	doc_685122975265_item	3543656	et	3	main
praegune	doc_685122975265_item	3543661	et	3	main
kirjutan	doc_685122975265_item	3543663	et	3	main
jagada	doc_685122975265_item	3543667	et	3	main
arvamusega	doc_685122975265_item	3543670	et	3	main
nõus	doc_685122975265_item	3543680	et	4	main
unistusi	doc_685122975265_item	3543701	et	4	main
ka	doc_685122975265_item	3543702	et	3	main
julgemat	doc_685122975265_item	3543706	et	4	main
tulevikust	doc_685122975265_item	3543709	et	4	main
aga	doc_685122975265_item	3543710	et	3	main
saite	doc_685122975265_item	3543711	et	4	main
töötada	doc_685122975265_item	3543716	et	3	main
rabelemata	doc_685122975265_item	3543718	et	4	main
ja	doc_685122975265_item	3543719	et	3	main
selle	doc_685122975265_item	3543726	et	4	main
see	doc_685122975263_item	3543491	et	3	main
töötama	doc_685122975263_item	3543497	et	3	main
tooma	doc_685122975263_item	3543510	et	3	main
kui	doc_685122975263_item	3543512	et	3	main
ei	doc_685122975263_item	3543529	et	4	main
tahavad	doc_685122975263_item	3543530	et	3	main
õppima	doc_685122975263_item	3543531	et	3	main
selle	doc_685122975263_item	3543532	et	4	main
tehnologiad	doc_685122975263_item	3543533	et	4	main
sellest	doc_685122975263_item	3543534	et	4	main
mõnikord	doc_685122975263_item	3543535	et	3	main
noored	doc_685122975263_item	3543536	et	3	main
tarkem	doc_685122975263_item	3543537	et	4	main
vanemate	doc_685122975263_item	3543538	et	4	main
aga	doc_685122975263_item	3543539	et	3	main
kui	doc_685122975263_item	3543540	et	3	main
noored	doc_685122975263_item	3543541	et	3	main
tark	doc_685122975263_item	3543542	et	3	main
nagu	doc_685122975263_item	3543543	et	3	main
vannemad	doc_685122975263_item	3543544	et	4	main
siis	doc_685122975263_item	3543545	et	3	main
õigused	doc_685122975263_item	3543546	et	4	main
peavad	doc_685122975263_item	3543547	et	4	main
olema	doc_685122975263_item	3543548	et	4	main
sarnane	doc_685122975263_item	3543549	et	4	main
aga	doc_685122975263_item	3543550	et	3	main
saa	doc_685122975263_item	3543553	et	4	main
teine	doc_685122975263_item	3543558	et	3	main
tea	doc_685122975263_item	3543565	et	4	main
mis	doc_685122975263_item	3543566	et	4	main
tuleb	doc_685122975263_item	3543577	et	3	main
mõni	doc_685122975263_item	3543579	et	3	main
kiri	doc_685122975265_item	3543641	et	3	main
lugenud	doc_685122975265_item	3543646	et	4	main
artiklit	doc_685122975265_item	3543648	et	3	main
ühest	doc_685122975265_item	3543651	et	4	main
ajalehest	doc_685122975265_item	3543652	et	4	main
ja	doc_685122975265_item	3543653	et	3	main
kujutate	doc_685122975265_item	3543659	et	3	main
teile	doc_685122975265_item	3543664	et	4	main
tahan	doc_685122975265_item	3543666	et	3	main
ole	doc_685122975265_item	3543679	et	4	main
jaganeb	doc_685122975265_item	3543691	et	4	main
kolmandale	doc_685122975265_item	3543692	et	3	main
rühmadele	doc_685122975265_item	3543693	et	3	main
esimene	doc_685122975265_item	3543694	et	3	main
rühm	doc_685122975265_item	3543695	et	3	main
te	doc_685122975265_item	3543696	et	4	main
ootasite	doc_685122975265_item	3543697	et	3	main
portree	doc_685122975265_item	3543712	et	4	main
inimesest	doc_685122975265_item	3543713	et	3	main
nõus	doc_685122975265_item	3543725	et	4	main
väidega	doc_685122975265_item	3543727	et	3	main
et	doc_685122975265_item	3543740	et	3	main
inimesed	doc_685122975265_item	3543742	et	3	main
laisad	doc_685122975265_item	3543744	et	3	main
nad	doc_685122975265_item	3543746	et	3	main
taha	doc_685122975265_item	3543748	et	4	main
ka	doc_685122975265_item	3543754	et	3	main
et	doc_685122975265_item	3543756	et	3	main
lähtuvad	doc_685122975265_item	3543784	et	4	main
sii	doc_685122975265_item	3543794	et	4	main
otsustavad	doc_685122975265_item	3543804	et	4	main
edasi	doc_685122975265_item	3543806	et	3	main
kuidas	doc_685122975265_item	3543809	et	3	main
kõik	doc_685122975265_item	3543812	et	4	main
see	doc_685122975265_item	3543813	et	3	main
kuid	doc_685122975265_item	3543827	et	4	main
tuleviku	doc_685122975265_item	3543833	et	4	main
osas	doc_685122975265_item	3543834	et	4	main
neile	doc_685122975265_item	3543835	et	4	main
panustada	doc_685122975265_item	3543836	et	3	main
nad	doc_685122975265_item	3543837	et	3	main
kiri	doc_685122975267_item	3543867	et	3	main
kõigest	doc_685122975267_item	3543892	et	4	main
on	doc_685122975267_item	3543894	et	4	main
sellised	doc_685122975267_item	3543896	et	4	main
üleõpilased	doc_685122975267_item	3543897	et	3	main
kes	doc_685122975267_item	3543898	et	4	main
tahavad	doc_685122975267_item	3543899	et	3	main
ülikoolis	doc_685122975267_item	3543924	et	4	main
ei	doc_685122975267_item	3543930	et	4	main
elada	doc_685122975267_item	3543934	et	3	main
artiklis	doc_685122975267_item	3543946	et	3	main
asi	doc_685122975267_item	3543949	et	4	main
20	doc_685122975267_item	3543951	et	2	main
40	doc_685122975267_item	3543957	et	2	main
hariduseta	doc_685122975267_item	3543970	et	3	main
on	doc_685122975267_item	3543972	et	4	main
vähe	doc_685122975267_item	3543973	et	3	main
võimalusi	doc_685122975267_item	3543974	et	3	main
häid	doc_685122975267_item	3543975	et	3	main
spetsiolisti	doc_685122975267_item	3543976	et	4	main
vaatavad	doc_685122975267_item	3543981	et	4	main
kallid	doc_685122975267_item	3543985	et	3	main
suured	doc_685122975267_item	3543987	et	3	main
ja	doc_685122975267_item	3543989	et	3	main
miks	doc_685122975267_item	3543991	et	4	main
temal	doc_685122975267_item	3543992	et	3	main
tahan	doc_685122975267_item	3544000	et	3	main
null	doc_685122975267_item	3544013	et	3	main
keegi	doc_685122975267_item	3544033	et	4	main
tab	doc_685122975267_item	3544034	et	4	main
ta	doc_685122975267_item	3544036	et	4	main
taha	doc_685122975267_item	3544087	et	4	main
töötada	doc_685122975267_item	3544088	et	3	main
nendel	doc_685122975267_item	3544089	et	4	main
meeldib	doc_685122975267_item	3544090	et	3	main
kes	doc_685122975263_item	3543596	et	4	main
ei	doc_685122975263_item	3543597	et	4	main
tea	doc_685122975263_item	3543598	et	4	main
mis	doc_685122975263_item	3543599	et	4	main
neid	doc_685122975263_item	3543600	et	4	main
saab	doc_685122975263_item	3543601	et	3	main
on	doc_685122975263_item	3543602	et	4	main
juba	doc_685122975263_item	3543603	et	3	main
esimeses	doc_685122975263_item	3543604	et	3	main
teines	doc_685122975263_item	3543605	et	4	main
ja	doc_685122975263_item	3543606	et	3	main
kolmas	doc_685122975263_item	3543607	et	3	main
rühmades	doc_685122975263_item	3543608	et	3	main
teised	doc_685122975263_item	3543609	et	4	main
pretensioonid	doc_685122975263_item	3543610	et	3	main
tekstist	doc_685122975263_item	3543611	et	3	main
mul	doc_685122975263_item	3543612	et	3	main
ei	doc_685122975263_item	3543613	et	4	main
ole	doc_685122975263_item	3543614	et	4	main
aga	doc_685122975263_item	3543615	et	3	main
ma	doc_685122975263_item	3543616	et	3	main
veel	doc_685122975263_item	3543617	et	4	main
tahaksin	doc_685122975263_item	3543618	et	3	main
öelda	doc_685122975263_item	3543619	et	4	main
et	doc_685122975263_item	3543620	et	3	main
kui	doc_685122975263_item	3543621	et	3	main
ma	doc_685122975263_item	3543622	et	3	main
olin	doc_685122975263_item	3543623	et	3	main
lugenud	doc_685122975263_item	3543624	et	4	main
viimase	doc_685122975263_item	3543625	et	3	main
lause	doc_685122975263_item	3543626	et	4	main
tuli	doc_685122975263_item	3543627	et	4	main
meelde	doc_685122975263_item	3543628	et	3	main
et	doc_685122975263_item	3543629	et	3	main
lootus	doc_685122975263_item	3543630	et	4	main
alati	doc_685122975263_item	3543631	et	4	main
sureb	doc_685122975263_item	3543632	et	3	main
viimane	doc_685122975263_item	3543633	et	3	main
kõige	doc_685122975263_item	3543634	et	4	main
paremide	doc_685122975263_item	3543635	et	4	main
soovidega	doc_685122975263_item	3543636	et	3	main
kaalep	doc_685122975265_item	3543644	et	4	main
tiina	doc_685122975265_item	3543643	et	4	main
olen	doc_685122975265_item	3543645	et	3	main
vähenõudlike	doc_685122975265_item	3543649	et	3	main
põlvkond	doc_685122975265_item	3543662	et	3	main
teiega	doc_685122975265_item	3543668	et	3	main
ei	doc_685122975265_item	3543678	et	4	main
tulemist	doc_685122975265_item	3543699	et	4	main
ootusi	doc_685122975265_item	3543704	et	3	main
visiooni	doc_685122975265_item	3543708	et	4	main
tahaks	doc_685122975265_item	3543715	et	3	main
mind	doc_685122975265_item	3543732	et	4	main
mina	doc_685122975265_item	3543733	et	4	main
ise	doc_685122975265_item	3543734	et	4	main
olen	doc_685122975265_item	3543735	et	3	main
niisugune	doc_685122975265_item	3543736	et	3	main
võib	doc_685122975265_item	3543737	et	3	main
ka	doc_685122975265_item	3543738	et	3	main
öelda	doc_685122975265_item	3543739	et	4	main
ei	doc_685122975265_item	3543747	et	4	main
olla	doc_685122975265_item	3543753	et	3	main
on	doc_685122975265_item	3543758	et	4	main
ja	doc_685122975265_item	3543762	et	3	main
elada	doc_685122975265_item	3543764	et	3	main
näiteks	doc_685122975265_item	3543787	et	4	main
kas	doc_685122975265_item	3543788	et	3	main
sooritan	doc_685122975265_item	3543789	et	3	main
eksameid	doc_685122975265_item	3543790	et	3	main
või	doc_685122975265_item	3543791	et	4	main
vaatan	doc_685122975265_item	3543796	et	3	main
minna	doc_685122975265_item	3543799	et	3	main
nii	doc_685122975265_item	3543801	et	3	main
on	doc_685122975265_item	3543814	et	4	main
ja	doc_685122975265_item	3543817	et	3	main
rühm	doc_685122975265_item	3543819	et	3	main
kes	doc_685122975265_item	3543821	et	4	main
räägivad	doc_685122975265_item	3543822	et	3	main
sotsiaaltöötaja	doc_685122975265_item	3543823	et	4	main
ning	doc_685122975265_item	3543824	et	3	main
rohkem	doc_685122975265_item	3543830	et	4	main
oleks	doc_685122975265_item	3543831	et	3	main
endale	doc_685122975265_item	3543660	et	4	main
mõnidel	doc_685122975265_item	3543677	et	4	main
kes	doc_685122975265_item	3543687	et	4	main
tänavu	doc_685122975265_item	3543688	et	3	main
ülikooli	doc_685122975265_item	3543689	et	4	main
lähevad	doc_685122975265_item	3543690	et	3	main
erilisemaid	doc_685122975265_item	3543700	et	4	main
palgale	doc_685122975265_item	3543705	et	3	main
kes	doc_685122975265_item	3543714	et	4	main
rahulikult	doc_685122975265_item	3543717	et	4	main
need	doc_685122975265_item	3543741	et	3	main
on	doc_685122975265_item	3543743	et	4	main
ja	doc_685122975265_item	3543745	et	3	main
muutuda	doc_685122975265_item	3543751	et	3	main
see	doc_685122975265_item	3543755	et	3	main
väsinud	doc_685122975265_item	3543760	et	4	main
ole	doc_685122975265_item	3543779	et	4	main
kindlaid	doc_685122975265_item	3543780	et	3	main
plaane	doc_685122975265_item	3543781	et	3	main
tulevikus	doc_685122975265_item	3543782	et	4	main
nad	doc_685122975265_item	3543783	et	3	main
ei	doc_685122975265_item	3543792	et	4	main
ja	doc_685122975265_item	3543793	et	3	main
kuhu	doc_685122975265_item	3543797	et	3	main
teha	doc_685122975265_item	3543807	et	3	main
edasi	doc_685122975265_item	3543810	et	3	main
päris	doc_685122975265_item	3543815	et	4	main
võiks	doc_685122975265_item	3543832	et	4	main
ametlik	doc_685122975267_item	3543866	et	3	main
l	doc_685122975267_item	3543868	et	4	main
tiina	doc_685122975267_item	3543870	et	4	main
artikel	doc_685122975267_item	3543877	et	4	main
te	doc_685122975267_item	3543883	et	4	main
seal	doc_685122975267_item	3543884	et	4	main
kirjutasite	doc_685122975267_item	3543885	et	3	main
ei	doc_685122975267_item	3543890	et	4	main
kuskilt	doc_685122975267_item	3543911	et	4	main
eestis	doc_685122975267_item	3543913	et	3	main
temal	doc_685122975267_item	3543915	et	3	main
asi	doc_685122975267_item	3543925	et	4	main
õppimine	doc_685122975267_item	3543938	et	4	main
võib	doc_685122975267_item	3543939	et	3	main
võib	doc_685122975267_item	3543940	et	3	main
olla	doc_685122975267_item	3543941	et	3	main
noormehed	doc_685122975267_item	3543953	et	3	main
aastased	doc_685122975267_item	3543958	et	4	main
see	doc_685122975267_item	3543960	et	3	main
nii	doc_685122975267_item	3543962	et	3	main
saada	doc_685122975267_item	3543977	et	4	main
et	doc_685122975267_item	3543982	et	3	main
on	doc_685122975267_item	3543984	et	4	main
autod	doc_685122975267_item	3543986	et	3	main
majad	doc_685122975267_item	3543988	et	3	main
ei	doc_685122975267_item	3543996	et	4	main
porshe	doc_685122975267_item	3544001	et	4	main
ferrari	doc_685122975267_item	3544003	et	4	main
tahtmine	doc_685122975267_item	3544004	et	4	main
ilma	doc_685122975267_item	3544009	et	4	main
tegevusega	doc_685122975267_item	3544010	et	4	main
see	doc_685122975267_item	3544011	et	3	main
te	doc_685122975267_item	3544015	et	4	main
veel	doc_685122975267_item	3544026	et	4	main
individuaalne	doc_685122975267_item	3544032	et	3	main
tahab	doc_685122975267_item	3544037	et	3	main
kui	doc_685122975267_item	3544041	et	3	main
on	doc_685122975267_item	3544043	et	4	main
ütelda	doc_685122975267_item	3544108	et	4	main
midagi	doc_685122975265_item	3543750	et	4	main
juba	doc_685122975265_item	3543759	et	3	main
rahulikult	doc_685122975265_item	3543765	et	4	main
teine	doc_685122975265_item	3543766	et	3	main
suur	doc_685122975265_item	3543767	et	3	main
rühm	doc_685122975265_item	3543768	et	3	main
on	doc_685122975265_item	3543769	et	4	main
neid	doc_685122975265_item	3543770	et	4	main
kes	doc_685122975265_item	3543771	et	4	main
ei	doc_685122975265_item	3543772	et	4	main
tea	doc_685122975265_item	3543773	et	4	main
mis	doc_685122975265_item	3543774	et	4	main
neist	doc_685122975265_item	3543775	et	4	main
saab	doc_685122975265_item	3543776	et	3	main
nendel	doc_685122975265_item	3543777	et	4	main
ei	doc_685122975265_item	3543778	et	4	main
edasi	doc_685122975265_item	3543798	et	3	main
nad	doc_685122975265_item	3543803	et	3	main
mida	doc_685122975265_item	3543805	et	4	main
ja	doc_685122975265_item	3543808	et	3	main
elada	doc_685122975265_item	3543811	et	3	main
kurb	doc_685122975265_item	3543816	et	3	main
viimane	doc_685122975265_item	3543818	et	3	main
neid	doc_685122975265_item	3543820	et	4	main
neid	doc_685122975265_item	3543828	et	4	main
veel	doc_685122975265_item	3543829	et	4	main
valmis	doc_685122975265_item	3543839	et	4	main
riskiks	doc_685122975265_item	3543840	et	4	main
võivad	doc_685122975265_item	3543841	et	4	main
muutuda	doc_685122975265_item	3543842	et	3	main
maailma	doc_685122975265_item	3543843	et	4	main
aga	doc_685122975265_item	3543844	et	3	main
problem	doc_685122975265_item	3543845	et	4	main
on	doc_685122975265_item	3543846	et	4	main
selles	doc_685122975265_item	3543847	et	4	main
asjas	doc_685122975265_item	3543848	et	3	main
et	doc_685122975265_item	3543849	et	3	main
neid	doc_685122975265_item	3543850	et	4	main
on	doc_685122975265_item	3543851	et	4	main
vähe	doc_685122975265_item	3543852	et	3	main
ja	doc_685122975265_item	3543853	et	3	main
seepärast	doc_685122975265_item	3543854	et	3	main
nad	doc_685122975265_item	3543855	et	3	main
ei	doc_685122975265_item	3543856	et	4	main
saa	doc_685122975265_item	3543857	et	4	main
mitte	doc_685122975265_item	3543858	et	3	main
midagi	doc_685122975265_item	3543859	et	4	main
teha	doc_685122975265_item	3543860	et	3	main
parimate	doc_685122975265_item	3543861	et	4	main
soovidega	doc_685122975265_item	3543862	et	3	main
eesnimi	doc_685122975265_item	3543863	et	3	main
perekonnanimi	doc_685122975265_item	3543864	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975265_item	3543865	et	4	main
p	doc_685122975267_item	3543869	et	4	main
kaalep	doc_685122975267_item	3543871	et	4	main
lugesin	doc_685122975267_item	3543872	et	3	main
mida	doc_685122975267_item	3543882	et	4	main
on	doc_685122975267_item	3543886	et	4	main
ma	doc_685122975267_item	3543889	et	3	main
lõuna	doc_685122975267_item	3543912	et	4	main
ja	doc_685122975267_item	3543914	et	3	main
ei	doc_685122975267_item	3543916	et	4	main
et	doc_685122975267_item	3543919	et	3	main
tartu	doc_685122975267_item	3543921	et	4	main
sellest	doc_685122975267_item	3543927	et	4	main
et	doc_685122975267_item	3543928	et	3	main
tal	doc_685122975267_item	3543929	et	3	main
raha	doc_685122975267_item	3543932	et	4	main
tallinnas	doc_685122975267_item	3543935	et	4	main
või	doc_685122975267_item	3543936	et	4	main
tartus	doc_685122975267_item	3543937	et	3	main
teie	doc_685122975267_item	3543873	et	4	main
artikli	doc_685122975267_item	3543874	et	3	main
vähenõudlik	doc_685122975267_item	3543875	et	3	main
ole	doc_685122975267_item	3543891	et	4	main
nõus	doc_685122975267_item	3543893	et	4	main
ka	doc_685122975267_item	3543895	et	3	main
õppida	doc_685122975267_item	3543900	et	3	main
aga	doc_685122975267_item	3543901	et	3	main
nendel	doc_685122975267_item	3543902	et	4	main
ültse	doc_685122975267_item	3543903	et	4	main
ei	doc_685122975267_item	3543904	et	4	main
ole	doc_685122975267_item	3543905	et	4	main
võimalisi	doc_685122975267_item	3543906	et	4	main
näiteks	doc_685122975267_item	3543907	et	4	main
et	doc_685122975267_item	3543908	et	3	main
ta	doc_685122975267_item	3543909	et	4	main
elab	doc_685122975267_item	3543910	et	3	main
raha	doc_685122975267_item	3543918	et	4	main
õppida	doc_685122975267_item	3543920	et	3	main
või	doc_685122975267_item	3543922	et	4	main
tallinna	doc_685122975267_item	3543923	et	4	main
on	doc_685122975267_item	3543942	et	4	main
sjukune	doc_685122975267_item	3543948	et	4	main
et	doc_685122975267_item	3543950	et	3	main
aastased	doc_685122975267_item	3543952	et	4	main
nagu	doc_685122975267_item	3543956	et	3	main
muidugi	doc_685122975267_item	3543959	et	4	main
on	doc_685122975267_item	3543961	et	4	main
ja	doc_685122975267_item	3543967	et	3	main
palju	doc_685122975267_item	3543978	et	4	main
noor	doc_685122975267_item	3543979	et	3	main
on	doc_685122975267_item	3543993	et	4	main
aga	doc_685122975267_item	3543994	et	3	main
mul	doc_685122975267_item	3543995	et	3	main
on	doc_685122975267_item	3544005	et	4	main
on	doc_685122975267_item	3544012	et	4	main
nendest	doc_685122975267_item	3544017	et	4	main
kes	doc_685122975267_item	3544018	et	4	main
tea	doc_685122975267_item	3544020	et	4	main
keda	doc_685122975267_item	3544021	et	4	main
nad	doc_685122975267_item	3544022	et	3	main
tahavad	doc_685122975267_item	3544023	et	3	main
et	doc_685122975267_item	3544035	et	3	main
tahavad	doc_685122975267_item	3544082	et	3	main
ja	doc_685122975267_item	3544083	et	3	main
nad	doc_685122975267_item	3544084	et	3	main
ültse	doc_685122975267_item	3544085	et	4	main
vanemad	doc_685122975267_item	3544093	et	4	main
annavad	doc_685122975267_item	3544094	et	3	main
elu	doc_685122975267_item	3544098	et	4	main
on	doc_685122975267_item	3544099	et	4	main
tahan	doc_685122975267_item	3544107	et	3	main
artikli	doc_685122975267_item	3544110	et	3	main
20051212	doc_685122975267_item	3544112	et	2	main
tiina	doc_573958253415_item	3544117	et	4	main
hiljuti	doc_573958253415_item	3544120	et	4	main
teie	doc_573958253415_item	3544122	et	4	main
artikel	doc_573958253415_item	3544123	et	4	main
minu	doc_573958253415_item	3544124	et	3	main
teema	doc_573958253415_item	3544127	et	4	main
jagatud	doc_573958253415_item	3544151	et	4	main
siia	doc_573958253415_item	3544157	et	4	main
maani	doc_573958253415_item	3544158	et	3	main
ei	doc_573958253415_item	3544159	et	4	main
öelda	doc_573958253415_item	3544161	et	4	main
gruppi	doc_573958253415_item	3544163	et	4	main
seotud	doc_573958253415_item	3544174	et	4	main
sellega	doc_573958253415_item	3544175	et	3	main
suurem	doc_573958253415_item	3544186	et	4	main
palk	doc_573958253415_item	3544187	et	3	main
selliseid	doc_573958253415_item	3544212	et	4	main
mingisugust	doc_573958253415_item	3544215	et	3	main
marguse	doc_491521502035_item	3544252	et	4	main
ja	doc_491521502035_item	3544254	et	3	main
20-25	doc_491521502035_item	3544260	et	2	main
minna	doc_491521502035_item	3544280	et	3	main
tahad	doc_491521502035_item	3544281	et	3	main
jään	doc_491521502035_item	3544282	et	3	main
kirju	doc_491521502035_item	3544290	et	4	main
mina	doc_491521502035_item	3544292	et	4	main
järgmisel	doc_491521502035_item	3544295	et	3	main
nädalal	doc_491521502035_item	3544296	et	3	main
reede	doc_491521502035_item	3544299	et	4	main
kui	doc_491521502035_item	3544300	et	3	main
sa	doc_491521502035_item	3544301	et	3	main
juures	doc_491521502035_item	3544307	et	4	main
ja	doc_491521502035_item	3544321	et	3	main
eesnimi	doc_491521502035_item	3544324	et	3	main
ka	doc_685122975267_item	3543944	et	3	main
tahavad	doc_685122975267_item	3543954	et	3	main
elada	doc_685122975267_item	3543955	et	3	main
palju	doc_685122975267_item	3543963	et	4	main
inimesed	doc_685122975267_item	3543964	et	3	main
teie	doc_685122975267_item	3543945	et	4	main
oli	doc_685122975267_item	3543947	et	3	main
tahavad	doc_685122975267_item	3543965	et	3	main
kõike	doc_685122975267_item	3543966	et	4	main
kiiresti	doc_685122975267_item	3543968	et	3	main
aga	doc_685122975267_item	3543969	et	3	main
nendel	doc_685122975267_item	3543971	et	4	main
inimesed	doc_685122975267_item	3543980	et	3	main
ka	doc_685122975267_item	3543999	et	3	main
või	doc_685122975267_item	3544002	et	4	main
hea	doc_685122975267_item	3544006	et	4	main
asi	doc_685122975267_item	3544007	et	4	main
aga	doc_685122975267_item	3544008	et	3	main
ka	doc_685122975267_item	3544014	et	3	main
saada	doc_685122975267_item	3544024	et	4	main
nad	doc_685122975267_item	3544025	et	3	main
on	doc_685122975267_item	3544031	et	4	main
tuletõrjajaka	doc_685122975267_item	3544039	et	4	main
meeldib	doc_685122975267_item	3544066	et	3	main
diskole	doc_685122975267_item	3544067	et	4	main
käia	doc_685122975267_item	3544068	et	4	main
ja	doc_685122975267_item	3544069	et	3	main
alkohooli	doc_685122975267_item	3544070	et	3	main
jooma	doc_685122975267_item	3544071	et	4	main
nad	doc_685122975267_item	3544072	et	3	main
elavad	doc_685122975267_item	3544073	et	4	main
koos	doc_685122975267_item	3544074	et	4	main
oma	doc_685122975267_item	3544075	et	4	main
vanematega	doc_685122975267_item	3544076	et	4	main
nendel	doc_685122975267_item	3544077	et	4	main
on	doc_685122975267_item	3544078	et	4	main
kõik	doc_685122975267_item	3544079	et	4	main
mida	doc_685122975267_item	3544080	et	4	main
nad	doc_685122975267_item	3544081	et	3	main
inimesel	doc_685122975267_item	3543983	et	3	main
mõtlevad	doc_685122975267_item	3543990	et	4	main
ole	doc_685122975267_item	3543997	et	4	main
ma	doc_685122975267_item	3543998	et	3	main
kirjutasite	doc_685122975267_item	3544016	et	3	main
ei	doc_685122975267_item	3544019	et	4	main
ei	doc_685122975267_item	3544027	et	4	main
tea	doc_685122975267_item	3544028	et	4	main
see	doc_685122975267_item	3544029	et	3	main
asi	doc_685122975267_item	3544030	et	4	main
saada	doc_685122975267_item	3544038	et	4	main
juba	doc_685122975267_item	3544040	et	3	main
ta	doc_685122975267_item	3544042	et	4	main
5	doc_685122975267_item	3544044	et	2	main
aastat	doc_685122975267_item	3544045	et	3	main
vana	doc_685122975267_item	3544046	et	4	main
teine	doc_685122975267_item	3544047	et	3	main
kui	doc_685122975267_item	3544048	et	3	main
ta	doc_685122975267_item	3544049	et	4	main
on	doc_685122975267_item	3544050	et	4	main
22	doc_685122975267_item	3544051	et	2	main
aga	doc_685122975267_item	3544052	et	3	main
on	doc_685122975267_item	3544053	et	4	main
ka	doc_685122975267_item	3544054	et	3	main
sellised	doc_685122975267_item	3544055	et	4	main
noormehed	doc_685122975267_item	3544056	et	3	main
ja	doc_685122975267_item	3544057	et	3	main
naised	doc_685122975267_item	3544058	et	3	main
kes	doc_685122975267_item	3544059	et	4	main
ültse	doc_685122975267_item	3544060	et	4	main
ei	doc_685122975267_item	3544061	et	4	main
taha	doc_685122975267_item	3544062	et	4	main
kedagi	doc_685122975267_item	3544063	et	4	main
saada	doc_685122975267_item	3544064	et	4	main
nendel	doc_685122975267_item	3544065	et	4	main
nendela	doc_685122975267_item	3544095	et	4	main
ja	doc_685122975267_item	3544097	et	3	main
on	doc_685122975267_item	3544102	et	4	main
ma	doc_685122975267_item	3544106	et	3	main
teie	doc_685122975267_item	3544109	et	4	main
järgi	doc_685122975267_item	3544111	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975267_item	3544113	et	4	main
ametlik	doc_573958253415_item	3544114	et	3	main
lugesin	doc_573958253415_item	3544119	et	3	main
on	doc_573958253415_item	3544128	et	4	main
tuleviku	doc_573958253415_item	3544142	et	4	main
artiklis	doc_573958253415_item	3544144	et	3	main
on	doc_573958253415_item	3544145	et	4	main
väga	doc_573958253415_item	3544146	et	3	main
rühma	doc_573958253415_item	3544153	et	4	main
ma	doc_573958253415_item	3544155	et	3	main
et	doc_573958253415_item	3544170	et	3	main
tööt	doc_573958253415_item	3544176	et	4	main
kohta	doc_573958253415_item	3544178	et	4	main
mida	doc_573958253415_item	3544185	et	4	main
ei	doc_685122975267_item	3544086	et	4	main
mesi	doc_685122975267_item	3544100	et	4	main
see	doc_685122975267_item	3544101	et	3	main
sõnu	doc_685122975267_item	3544104	et	4	main
kiri	doc_573958253415_item	3544115	et	3	main
läbi	doc_573958253415_item	3544121	et	4	main
see	doc_573958253415_item	3544126	et	3	main
täpselt	doc_573958253415_item	3544147	et	4	main
kolme	doc_573958253415_item	3544152	et	4	main
mis	doc_573958253415_item	3544162	et	4	main
ma	doc_573958253415_item	3544164	et	3	main
õpin	doc_573958253415_item	3544167	et	3	main
loodan	doc_573958253415_item	3544169	et	3	main
tulevikus	doc_573958253415_item	3544171	et	4	main
saan	doc_573958253415_item	3544172	et	4	main
leida	doc_573958253415_item	3544173	et	3	main
muidugi	doc_573958253415_item	3544184	et	4	main
tea	doc_573958253415_item	3544195	et	4	main
on	doc_573958253415_item	3544210	et	4	main
ka	doc_573958253415_item	3544211	et	3	main
õpib	doc_573958253415_item	3544214	et	3	main
ainult	doc_573958253415_item	3544217	et	4	main
sellepärast	doc_573958253415_item	3544218	et	3	main
läbi	doc_491521502035_item	3544251	et	4	main
mulle	doc_491521502035_item	3544265	et	4	main
millal	doc_491521502035_item	3544266	et	3	main
tuled	doc_491521502035_item	3544269	et	4	main
vastust	doc_491521502035_item	3544283	et	4	main
vaadata	doc_491521502035_item	3544315	et	4	main
lp	doc_573958253417_item	3544328	et	4	main
kaalep	doc_573958253417_item	3544330	et	4	main
olen	doc_573958253417_item	3544332	et	3	main
ma	doc_573958253417_item	3544334	et	3	main
teie	doc_573958253417_item	3544348	et	4	main
artikkel	doc_573958253417_item	3544349	et	3	main
vähenõudlike	doc_573958253417_item	3544350	et	3	main
põlvkond	doc_573958253417_item	3544351	et	3	main
arvamus	doc_573958253417_item	3544360	et	3	main
nõus	doc_573958253417_item	3544364	et	4	main
palju	doc_573958253417_item	3544366	et	4	main
tahavad	doc_573958253417_item	3544382	et	3	main
on	doc_573958253417_item	3544398	et	4	main
või	doc_573958253417_item	3544403	et	4	main
töötada	doc_573958253417_item	3544404	et	3	main
sellele	doc_573958253417_item	3544406	et	4	main
see	doc_685122975267_item	3544091	et	3	main
elu	doc_685122975267_item	3544092	et	4	main
raha	doc_685122975267_item	3544096	et	4	main
paar	doc_685122975267_item	3544103	et	3	main
mida	doc_685122975267_item	3544105	et	4	main
kaalep	doc_573958253415_item	3544118	et	4	main
kõik	doc_573958253415_item	3544148	et	4	main
noored	doc_573958253415_item	3544149	et	3	main
inimesed	doc_573958253415_item	3544150	et	3	main
ise	doc_573958253415_item	3544156	et	4	main
kuulun	doc_573958253415_item	3544165	et	3	main
ma	doc_573958253415_item	3544166	et	3	main
majandust	doc_573958253415_item	3544168	et	4	main
palga	doc_573958253415_item	3544177	et	3	main
ei	doc_573958253415_item	3544179	et	4	main
oska	doc_573958253415_item	3544180	et	4	main
parem	doc_573958253415_item	3544189	et	4	main
aga	doc_573958253415_item	3544190	et	3	main
täpset	doc_573958253415_item	3544191	et	3	main
summat	doc_573958253415_item	3544192	et	3	main
ma	doc_573958253415_item	3544193	et	3	main
ei	doc_573958253415_item	3544194	et	4	main
kuid	doc_573958253415_item	3544209	et	4	main
kiri	doc_491521502035_item	3544253	et	3	main
tallinnasse	doc_491521502035_item	3544268	et	3	main
mitu	doc_491521502035_item	3544270	et	4	main
päeva	doc_491521502035_item	3544271	et	4	main
sa	doc_491521502035_item	3544272	et	3	main
ootama	doc_491521502035_item	3544284	et	3	main
nõus	doc_491521502035_item	3544303	et	4	main
elan	doc_491521502035_item	3544305	et	3	main
näiteks	doc_491521502035_item	3544316	et	4	main
loomaaed	doc_491521502035_item	3544317	et	3	main
vanalinn	doc_491521502035_item	3544318	et	3	main
mälestuskivid	doc_491521502035_item	3544319	et	3	main
ametlik	doc_573958253417_item	3544325	et	3	main
tallinna	doc_573958253417_item	3544336	et	4	main
teiega	doc_573958253417_item	3544361	et	3	main
et	doc_573958253417_item	3544365	et	3	main
ei	doc_573958253417_item	3544368	et	4	main
tea	doc_573958253417_item	3544369	et	4	main
juba	doc_573958253417_item	3544373	et	3	main
kui	doc_573958253417_item	3544375	et	3	main
ma	doc_573958253417_item	3544376	et	3	main
küsisin	doc_573958253417_item	3544377	et	3	main
oma	doc_573958253417_item	3544378	et	4	main
sõpru	doc_573958253417_item	3544379	et	3	main
siis	doc_573958253417_item	3544384	et	3	main
sain	doc_573958253417_item	3544386	et	3	main
üks	doc_573958253417_item	3544388	et	3	main
omapärane	doc_573958253417_item	3544399	et	4	main
kuhu	doc_573958253417_item	3544401	et	3	main
mulle	doc_573958253417_item	3544429	et	4	main
ja	doc_573958253417_item	3544430	et	3	main
valik	doc_573958253417_item	3544438	et	3	main
see	doc_573958253417_item	3544442	et	3	main
midagi	doc_573958253417_item	3544447	et	4	main
valite	doc_573958253417_item	3544448	et	3	main
ja	doc_573958253417_item	3544449	et	3	main
lasete	doc_573958253417_item	3544450	et	4	main
tähenda	doc_573958253417_item	3544456	et	4	main
et	doc_573958253417_item	3544457	et	3	main
elule	doc_573958253417_item	3544458	et	3	main
ei	doc_573958253417_item	3544476	et	4	main
tahavad	doc_573958253417_item	3544484	et	3	main
siis	doc_573958253417_item	3544488	et	3	main
halb	doc_573958253417_item	3544491	et	3	main
osta	doc_573958253417_item	3544514	et	4	main
nad	doc_573958253417_item	3544515	et	3	main
kõik	doc_573958253415_item	3544196	et	4	main
minu	doc_573958253415_item	3544197	et	3	main
tuttavad	doc_573958253415_item	3544198	et	4	main
õpivad	doc_573958253415_item	3544199	et	3	main
just	doc_573958253415_item	3544200	et	3	main
seda	doc_573958253415_item	3544201	et	3	main
eriala	doc_573958253415_item	3544202	et	4	main
millega	doc_573958253415_item	3544203	et	3	main
nad	doc_573958253415_item	3544204	et	3	main
tahavad	doc_573958253415_item	3544205	et	3	main
tegeleda	doc_573958253415_item	3544206	et	3	main
lugupeetud	doc_573958253415_item	3544116	et	4	main
arvates	doc_573958253415_item	3544125	et	4	main
tänapäeval	doc_573958253415_item	3544129	et	3	main
aktuaalne	doc_573958253415_item	3544131	et	3	main
eriti	doc_573958253415_item	3544130	et	3	main
ja	doc_573958253415_item	3544132	et	3	main
tähtis	doc_573958253415_item	3544133	et	4	main
tõsi	doc_573958253415_item	3544134	et	4	main
küll	doc_573958253415_item	3544135	et	4	main
et	doc_573958253415_item	3544136	et	3	main
praegu	doc_573958253415_item	3544137	et	3	main
on	doc_573958253415_item	3544138	et	4	main
raske	doc_573958253415_item	3544139	et	4	main
valida	doc_573958253415_item	3544140	et	3	main
enda	doc_573958253415_item	3544141	et	4	main
teie	doc_573958253415_item	3544143	et	4	main
kahjuks	doc_573958253415_item	3544154	et	4	main
oska	doc_573958253415_item	3544160	et	4	main
öelda	doc_573958253415_item	3544181	et	4	main
mitte	doc_573958253415_item	3544182	et	3	main
midagi	doc_573958253415_item	3544183	et	4	main
seda	doc_573958253415_item	3544188	et	3	main
kogu	doc_573958253415_item	3544207	et	4	main
elu	doc_573958253415_item	3544208	et	4	main
kes	doc_573958253415_item	3544213	et	4	main
lugege	doc_491521502035_item	3544250	et	3	main
kirjutage	doc_491521502035_item	3544255	et	3	main
erialat	doc_573958253415_item	3544216	et	4	main
et	doc_573958253415_item	3544219	et	3	main
ta	doc_573958253415_item	3544220	et	4	main
pääses	doc_573958253415_item	3544221	et	4	main
sellele	doc_573958253415_item	3544222	et	4	main
kohale	doc_573958253415_item	3544223	et	4	main
olen	doc_573958253415_item	3544224	et	3	main
kindel	doc_573958253415_item	3544225	et	3	main
et	doc_573958253415_item	3544226	et	3	main
kõik	doc_573958253415_item	3544227	et	4	main
need	doc_573958253415_item	3544228	et	3	main
abiturientide	doc_573958253415_item	3544229	et	3	main
kahtlustused	doc_573958253415_item	3544230	et	4	main
tekivad	doc_573958253415_item	3544231	et	3	main
üsna	doc_573958253415_item	3544232	et	3	main
suure	doc_573958253415_item	3544233	et	3	main
valiku	doc_573958253415_item	3544234	et	3	main
pärast	doc_573958253415_item	3544235	et	4	main
mida	doc_573958253415_item	3544236	et	4	main
vähem	doc_573958253415_item	3544237	et	4	main
valik	doc_573958253415_item	3544238	et	3	main
seda	doc_573958253415_item	3544239	et	3	main
suurem	doc_573958253415_item	3544240	et	4	main
veendumus	doc_573958253415_item	3544241	et	4	main
ootan	doc_573958253415_item	3544242	et	3	main
teie	doc_573958253415_item	3544243	et	4	main
uusi	doc_573958253415_item	3544244	et	3	main
artikle	doc_573958253415_item	3544245	et	4	main
lugupidamisega	doc_573958253415_item	3544246	et	3	main
eesnimi	doc_573958253415_item	3544247	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_573958253415_item	3544248	et	4	main
kiri	doc_491521502035_item	3544249	et	3	main
talle	doc_491521502035_item	3544256	et	4	main
kus	doc_491521502035_item	3544258	et	3	main
sa	doc_491521502035_item	3544267	et	3	main
tallinnas	doc_491521502035_item	3544279	et	4	main
tere	doc_491521502035_item	3544286	et	3	main
margus	doc_491521502035_item	3544287	et	3	main
sinust	doc_491521502035_item	3544289	et	3	main
tallinnasse	doc_491521502035_item	3544291	et	3	main
planeerin	doc_491521502035_item	3544293	et	3	main
mõtlen	doc_491521502035_item	3544297	et	3	main
siis	doc_491521502035_item	3544304	et	3	main
sinu	doc_491521502035_item	3544306	et	3	main
terve	doc_491521502035_item	3544308	et	4	main
nädal	doc_491521502035_item	3544309	et	3	main
sellepärast	doc_491521502035_item	3544310	et	3	main
et	doc_491521502035_item	3544311	et	3	main
tahan	doc_491521502035_item	3544312	et	3	main
väga	doc_491521502035_item	3544313	et	3	main
palju	doc_491521502035_item	3544314	et	4	main
vastus	doc_491521502035_item	3544257	et	3	main
on	doc_491521502035_item	3544259	et	4	main
sõna	doc_491521502035_item	3544261	et	4	main
tere	doc_491521502035_item	3544262	et	3	main
kirjuta	doc_491521502035_item	3544263	et	4	main
palun	doc_491521502035_item	3544264	et	3	main
minu	doc_491521502035_item	3544273	et	3	main
juures	doc_491521502035_item	3544274	et	4	main
oled	doc_491521502035_item	3544275	et	3	main
ja	doc_491521502035_item	3544276	et	3	main
kuhu	doc_491521502035_item	3544277	et	3	main
sa	doc_491521502035_item	3544278	et	3	main
margus	doc_491521502035_item	3544285	et	3	main
sain	doc_491521502035_item	3544288	et	3	main
tulla	doc_491521502035_item	3544294	et	3	main
et	doc_491521502035_item	3544298	et	3	main
oled	doc_491521502035_item	3544302	et	3	main
palju	doc_491521502035_item	3544322	et	4	main
kiri	doc_573958253417_item	3544326	et	3	main
teile	doc_573958253417_item	3544344	et	4	main
et	doc_573958253417_item	3544345	et	3	main
ma	doc_573958253417_item	3544346	et	3	main
lugesin	doc_573958253417_item	3544347	et	3	main
läbi	doc_573958253417_item	3544352	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_573958253417_item	3544353	et	4	main
8062006	doc_573958253417_item	3544354	et	2	main
ja	doc_573958253417_item	3544355	et	3	main
ma	doc_573958253417_item	3544362	et	3	main
mis	doc_573958253417_item	3544370	et	4	main
koolis	doc_573958253417_item	3544374	et	4	main
saada	doc_573958253417_item	3544383	et	4	main
vastus	doc_573958253417_item	3544389	et	3	main
valik	doc_573958253417_item	3544400	et	3	main
saite	doc_573958253417_item	3544413	et	4	main
erinevaid	doc_573958253417_item	3544414	et	4	main
punktide	doc_573958253417_item	3544415	et	3	main
kogusi	doc_573958253417_item	3544416	et	3	main
kui	doc_573958253417_item	3544437	et	3	main
on	doc_573958253417_item	3544439	et	4	main
suur	doc_573958253417_item	3544441	et	3	main
tähendab	doc_573958253417_item	3544443	et	3	main
te	doc_573958253417_item	3544445	et	4	main
mööda	doc_573958253417_item	3544453	et	4	main
aga	doc_573958253417_item	3544454	et	3	main
kahekümneaastased	doc_573958253417_item	3544483	et	4	main
nagu	doc_573958253417_item	3544486	et	3	main
on	doc_573958253417_item	3544490	et	4	main
ma	doc_573958253417_item	3544492	et	3	main
et	doc_573958253417_item	3544494	et	3	main
neile	doc_573958253417_item	3544496	et	4	main
oma	doc_573958253417_item	3544503	et	4	main
põhjus	doc_573958253417_item	3544504	et	4	main
kakskümmend	doc_573958253417_item	3544509	et	4	main
pappi	doc_573958253417_item	3544518	et	4	main
ei	doc_573958253417_item	3544523	et	4	main
pangast	doc_573958253417_item	3544526	et	4	main
osta	doc_573958253417_item	3544528	et	4	main
intressiga	doc_573958253417_item	3544537	et	3	main
lp	doc_685122975269_item	3544578	et	4	main
kaalep	doc_685122975269_item	3544580	et	4	main
elektroenergeetika	doc_685122975269_item	3544588	et	4	main
teile	doc_685122975269_item	3544591	et	4	main
lugesin	doc_685122975269_item	3544593	et	3	main
praegu	doc_685122975269_item	3544616	et	3	main
tee	doc_685122975269_item	3544626	et	4	main
kes	doc_685122975269_item	3544632	et	4	main
nii	doc_685122975269_item	3544645	et	3	main
meeldis	doc_685122975269_item	3544648	et	3	main
kus	doc_685122975269_item	3544651	et	3	main
kirjutasite	doc_685122975269_item	3544653	et	3	main
midagi	doc_685122975269_item	3544669	et	4	main
mujal	doc_685122975269_item	3544670	et	3	main
ma	doc_685122975269_item	3544671	et	3	main
tean	doc_685122975269_item	3544676	et	3	main
võimaliku	doc_685122975269_item	3544682	et	3	main
ja	doc_685122975269_item	3544683	et	3	main
läksid	doc_685122975269_item	3544684	et	4	main
õppida	doc_685122975269_item	3544685	et	3	main
pirita	doc_491521502035_item	3544320	et	4	main
muud	doc_491521502035_item	3544323	et	4	main
tere	doc_573958253417_item	3544327	et	3	main
oma	doc_573958253417_item	3544359	et	4	main
kelleks	doc_573958253417_item	3544380	et	4	main
nad	doc_573958253417_item	3544381	et	3	main
ma	doc_573958253417_item	3544385	et	3	main
ainult	doc_573958253417_item	3544387	et	4	main
ei	doc_573958253417_item	3544390	et	4	main
tea	doc_573958253417_item	3544391	et	4	main
riigieksamitega	doc_573958253417_item	3544392	et	3	main
ma	doc_573958253417_item	3544393	et	3	main
olen	doc_573958253417_item	3544394	et	3	main
ka	doc_573958253417_item	3544395	et	3	main
õppida	doc_573958253417_item	3544402	et	3	main
minna	doc_573958253417_item	3544405	et	3	main
aitavad	doc_573958253417_item	3544407	et	4	main
need	doc_573958253417_item	3544408	et	3	main
eksamite	doc_573958253417_item	3544409	et	3	main
punktid	doc_573958253417_item	3544410	et	4	main
kui	doc_573958253417_item	3544411	et	3	main
teie	doc_573958253417_item	3544417	et	4	main
võimalus	doc_573958253417_item	3544418	et	3	main
arukat	doc_573958253417_item	3544425	et	3	main
näidis	doc_573958253417_item	3544428	et	4	main
võib-olla	doc_573958253417_item	3544431	et	3	main
valida	doc_573958253417_item	3544435	et	3	main
väga	doc_573958253417_item	3544440	et	3	main
et	doc_573958253417_item	3544444	et	3	main
mitte	doc_573958253417_item	3544446	et	3	main
ei	doc_573958253417_item	3544455	et	4	main
see	doc_573958253417_item	3544489	et	3	main
on	doc_573958253417_item	3544498	et	4	main
sobil	doc_573958253417_item	3544499	et	3	main
siis	doc_573958253417_item	3544500	et	3	main
sellele	doc_573958253417_item	3544501	et	4	main
taha	doc_573958253417_item	3544507	et	4	main
tahavad	doc_573958253417_item	3544516	et	3	main
palju	doc_573958253417_item	3544517	et	4	main
neile	doc_573958253417_item	3544522	et	4	main
liising	doc_573958253417_item	3544527	et	3	main
midagi	doc_573958253417_item	3544529	et	4	main
ja	doc_573958253417_item	3544530	et	3	main
pealegi	doc_573958253417_item	3544531	et	4	main
tagastada	doc_573958253417_item	3544532	et	3	main
suurt	doc_573958253417_item	3544533	et	3	main
nad	doc_573958253417_item	3544538	et	3	main
ametlik	doc_685122975269_item	3544576	et	3	main
teaduskonnas	doc_685122975269_item	3544589	et	4	main
te	doc_685122975269_item	3544601	et	4	main
on	doc_685122975269_item	3544605	et	4	main
põhiliselt	doc_685122975269_item	3544612	et	4	main
olen	doc_685122975269_item	3544613	et	3	main
teiega	doc_685122975269_item	3544614	et	3	main
nõus	doc_685122975269_item	3544615	et	4	main
aga	doc_685122975269_item	3544627	et	3	main
kes	doc_685122975269_item	3544654	et	4	main
lähevad	doc_685122975269_item	3544655	et	3	main
kuhu	doc_685122975269_item	3544656	et	3	main
sisse	doc_685122975269_item	3544657	et	4	main
ole	doc_685122975269_item	3544672	et	4	main
30	doc_573958253417_item	3544572	et	2	main
dets	doc_573958253417_item	3544573	et	4	main
2006	doc_573958253417_item	3544574	et	2	main
a	doc_573958253417_item	3544575	et	4	main
tiina	doc_573958253417_item	3544329	et	4	main
ma	doc_573958253417_item	3544331	et	3	main
eesnimi	doc_573958253417_item	3544333	et	3	main
õpin	doc_573958253417_item	3544335	et	3	main
tehnikaülikooli	doc_573958253417_item	3544337	et	4	main
informaatika	doc_573958253417_item	3544338	et	4	main
instituudis	doc_573958253417_item	3544339	et	3	main
esimeses	doc_573958253417_item	3544340	et	3	main
kursuses	doc_573958253417_item	3544341	et	3	main
ma	doc_573958253417_item	3544342	et	3	main
kirjutan	doc_573958253417_item	3544343	et	3	main
nüüd	doc_573958253417_item	3544356	et	4	main
tahan	doc_573958253417_item	3544357	et	3	main
jaguda	doc_573958253417_item	3544358	et	3	main
olen	doc_573958253417_item	3544363	et	3	main
abituriente	doc_573958253417_item	3544367	et	3	main
neist	doc_573958253417_item	3544371	et	4	main
saab	doc_573958253417_item	3544372	et	3	main
nõus	doc_573958253417_item	3544396	et	4	main
paljudel	doc_573958253417_item	3544397	et	3	main
te	doc_573958253417_item	3544412	et	4	main
kuhu	doc_573958253417_item	3544419	et	3	main
minna	doc_573958253417_item	3544420	et	3	main
väheneb	doc_573958253417_item	3544421	et	3	main
ja	doc_573958253417_item	3544422	et	3	main
aitab	doc_573958253417_item	3544423	et	3	main
teile	doc_573958253417_item	3544424	et	4	main
teha	doc_573958253417_item	3544427	et	3	main
paljudele	doc_573958253417_item	3544432	et	3	main
meeldi	doc_573958253417_item	3544434	et	4	main
head	doc_573958253417_item	3544451	et	4	main
tuli	doc_573958253417_item	3544459	et	4	main
ole	doc_573958253417_item	3544477	et	4	main
nõus	doc_573958253417_item	3544478	et	4	main
et	doc_573958253417_item	3544479	et	3	main
neljakümnesed	doc_573958253417_item	3544487	et	3	main
arvan	doc_573958253417_item	3544493	et	3	main
kui	doc_573958253417_item	3544495	et	3	main
see	doc_573958253417_item	3544497	et	3	main
paljud	doc_573958253417_item	3544505	et	3	main
töötada	doc_573958253417_item	3544508	et	3	main
ainult	doc_573958253417_item	3544511	et	4	main
et	doc_573958253417_item	3544512	et	3	main
kodu	doc_573958253417_item	3544513	et	4	main
võtta	doc_573958253417_item	3544525	et	3	main
koos	doc_573958253417_item	3544535	et	4	main
suure	doc_573958253417_item	3544536	et	3	main
õpin	doc_685122975269_item	3544586	et	3	main
kirjutan	doc_685122975269_item	3544590	et	3	main
ära	doc_685122975269_item	3544594	et	4	main
põnevat	doc_685122975269_item	3544595	et	3	main
artiiklit	doc_685122975269_item	3544596	et	4	main
vähenõudlike	doc_685122975269_item	3544597	et	3	main
põlvkond	doc_685122975269_item	3544598	et	3	main
uurisin	doc_685122975269_item	3544599	et	3	main
et	doc_685122975269_item	3544600	et	3	main
võimalus	doc_685122975269_item	3544606	et	3	main
öelda	doc_685122975269_item	3544610	et	4	main
ei	doc_685122975269_item	3544625	et	4	main
kirjutasite	doc_685122975269_item	3544629	et	3	main
inimestest	doc_685122975269_item	3544631	et	3	main
on	doc_685122975269_item	3544633	et	4	main
tõesti	doc_685122975269_item	3544634	et	3	main
püüavad	doc_685122975269_item	3544635	et	3	main
õppida	doc_685122975269_item	3544636	et	3	main
ja	doc_685122975269_item	3544637	et	3	main
olla	doc_685122975269_item	3544638	et	3	main
meie	doc_685122975269_item	3544639	et	4	main
põlvkonnale	doc_685122975269_item	3544640	et	4	main
saavad	doc_685122975269_item	3544658	et	4	main
tööd	doc_685122975269_item	3544664	et	4	main
seotud	doc_685122975269_item	3544665	et	4	main
erialaga	doc_685122975269_item	3544666	et	3	main
ja	doc_685122975269_item	3544667	et	3	main
teevad	doc_685122975269_item	3544668	et	3	main
selle	doc_685122975269_item	3544673	et	4	main
valikut	doc_573958253417_item	3544426	et	3	main
ei	doc_573958253417_item	3544433	et	4	main
eriti	doc_573958253417_item	3544436	et	3	main
juhust	doc_573958253417_item	3544452	et	4	main
lõpp	doc_573958253417_item	3544460	et	3	main
sellepärast	doc_573958253417_item	3544461	et	3	main
te	doc_573958253417_item	3544462	et	4	main
võite	doc_573958253417_item	3544463	et	4	main
küsida	doc_573958253417_item	3544464	et	3	main
oma	doc_573958253417_item	3544465	et	4	main
sugulasi	doc_573958253417_item	3544466	et	3	main
või	doc_573958253417_item	3544467	et	4	main
sõpru	doc_573958253417_item	3544468	et	3	main
kuhu	doc_573958253417_item	3544469	et	3	main
minna	doc_573958253417_item	3544470	et	3	main
nad	doc_573958253417_item	3544471	et	3	main
kindlasti	doc_573958253417_item	3544472	et	3	main
annavad	doc_573958253417_item	3544473	et	3	main
nõu	doc_573958253417_item	3544474	et	4	main
ma	doc_573958253417_item	3544475	et	3	main
te	doc_573958253417_item	3544480	et	4	main
arvate	doc_573958253417_item	3544481	et	3	main
kui	doc_573958253417_item	3544482	et	3	main
elada	doc_573958253417_item	3544485	et	3	main
on	doc_573958253417_item	3544502	et	4	main
ei	doc_573958253417_item	3544506	et	4	main
aastat	doc_573958253417_item	3544510	et	3	main
ja	doc_573958253417_item	3544519	et	3	main
kohe	doc_573958253417_item	3544520	et	4	main
sest	doc_573958253417_item	3544521	et	4	main
sobi	doc_573958253417_item	3544524	et	4	main
rahasumma	doc_573958253417_item	3544534	et	4	main
kiri	doc_685122975269_item	3544577	et	3	main
tiina	doc_685122975269_item	3544579	et	4	main
minu	doc_685122975269_item	3544581	et	3	main
nimi	doc_685122975269_item	3544582	et	3	main
on	doc_685122975269_item	3544583	et	4	main
eesnimi	doc_685122975269_item	3544584	et	3	main
perekonnanimi	doc_685122975269_item	3544585	et	3	main
sest	doc_685122975269_item	3544592	et	4	main
ja	doc_685122975269_item	3544604	et	3	main
kirjutada	doc_685122975269_item	3544608	et	3	main
noormehed	doc_685122975269_item	3544617	et	3	main
raha	doc_685122975269_item	3544620	et	4	main
teenida	doc_685122975269_item	3544621	et	3	main
ja	doc_685122975269_item	3544622	et	3	main
mitte	doc_685122975269_item	3544623	et	3	main
midagi	doc_685122975269_item	3544624	et	4	main
te	doc_685122975269_item	3544628	et	4	main
ka	doc_685122975269_item	3544630	et	3	main
kasulikum	doc_685122975269_item	3544641	et	4	main
see	doc_685122975269_item	3544642	et	3	main
on	doc_685122975269_item	3544643	et	4	main
tõesti	doc_685122975269_item	3544644	et	3	main
mulle	doc_685122975269_item	3544647	et	4	main
koht	doc_685122975269_item	3544650	et	3	main
teie	doc_685122975269_item	3544659	et	4	main
arvamusel	doc_685122975269_item	3544660	et	3	main
nad	doc_685122975269_item	3544661	et	3	main
ei	doc_685122975269_item	3544662	et	4	main
otsi	doc_685122975269_item	3544663	et	4	main
siise	doc_685122975269_item	3544687	et	4	main
et	doc_685122975269_item	3544694	et	3	main
tahavad	doc_573958253417_item	3544539	et	3	main
osta	doc_573958253417_item	3544540	et	4	main
midagi	doc_573958253417_item	3544541	et	4	main
ja	doc_573958253417_item	3544542	et	3	main
laska	doc_573958253417_item	3544543	et	4	main
seda	doc_573958253417_item	3544544	et	3	main
meelest	doc_573958253417_item	3544545	et	4	main
ma	doc_573958253417_item	3544546	et	3	main
arvan	doc_573958253417_item	3544547	et	3	main
et	doc_573958253417_item	3544548	et	3	main
kedagi	doc_573958253417_item	3544549	et	4	main
ei	doc_573958253417_item	3544550	et	4	main
taha	doc_573958253417_item	3544551	et	4	main
võlgades	doc_573958253417_item	3544552	et	3	main
jääda	doc_573958253417_item	3544553	et	4	main
ma	doc_573958253417_item	3544554	et	3	main
loodan	doc_573958253417_item	3544555	et	3	main
et	doc_573958253417_item	3544556	et	3	main
te	doc_573958253417_item	3544557	et	4	main
nõustute	doc_573958253417_item	3544558	et	3	main
minu	doc_573958253417_item	3544559	et	3	main
arvamusega	doc_573958253417_item	3544560	et	3	main
või	doc_573958253417_item	3544561	et	4	main
kirjutate	doc_573958253417_item	3544562	et	3	main
kus	doc_573958253417_item	3544563	et	3	main
mul	doc_573958253417_item	3544564	et	3	main
ei	doc_573958253417_item	3544565	et	4	main
ole	doc_573958253417_item	3544566	et	4	main
õigust	doc_573958253417_item	3544567	et	4	main
loodan	doc_573958253417_item	3544568	et	3	main
teie	doc_573958253417_item	3544569	et	4	main
vastust	doc_573958253417_item	3544570	et	4	main
eesnimi	doc_573958253417_item	3544571	et	3	main
see	doc_685122975269_item	3544728	et	3	main
on	doc_685122975269_item	3544729	et	4	main
elu	doc_685122975269_item	3544730	et	4	main
eesmärk	doc_685122975269_item	3544731	et	3	main
lõppuks	doc_685122975269_item	3544732	et	3	main
tahaks	doc_685122975269_item	3544733	et	3	main
ütelda	doc_685122975269_item	3544734	et	4	main
teile	doc_685122975269_item	3544735	et	4	main
suur	doc_685122975269_item	3544736	et	3	main
aitäh	doc_685122975269_item	3544737	et	3	main
artiikli	doc_685122975269_item	3544738	et	4	main
eest	doc_685122975269_item	3544739	et	4	main
lugupidamisega	doc_685122975269_item	3544740	et	3	main
eesnimi	doc_685122975269_item	3544741	et	3	main
perekonnanimi	doc_685122975269_item	3544742	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975269_item	3544743	et	4	main
ttü-s	doc_685122975269_item	3544587	et	3	main
olete	doc_685122975269_item	3544602	et	3	main
autor	doc_685122975269_item	3544603	et	3	main
vastust	doc_685122975269_item	3544607	et	4	main
tahaks	doc_685122975269_item	3544609	et	3	main
et	doc_685122975269_item	3544611	et	3	main
soovivad	doc_685122975269_item	3544618	et	4	main
palju	doc_685122975269_item	3544619	et	4	main
eriti	doc_685122975269_item	3544646	et	3	main
see	doc_685122975269_item	3544649	et	3	main
te	doc_685122975269_item	3544652	et	4	main
väitega	doc_685122975269_item	3544674	et	3	main
nõus	doc_685122975269_item	3544675	et	4	main
inimesi	doc_685122975269_item	3544678	et	4	main
kellel	doc_685122975269_item	3544679	et	4	main
kuhu	doc_685122975269_item	3544686	et	3	main
palju	doc_685122975269_item	3544677	et	4	main
olnud	doc_685122975269_item	3544681	et	4	main
saanud	doc_685122975269_item	3544688	et	4	main
nendest	doc_685122975269_item	3544690	et	4	main
rõõmsad	doc_685122975269_item	3544693	et	3	main
mis	doc_685122975269_item	3544697	et	4	main
tõesti	doc_685122975269_item	3544698	et	3	main
meeldib	doc_685122975269_item	3544699	et	3	main
arvan	doc_685122975269_item	3544700	et	3	main
et	doc_685122975269_item	3544701	et	3	main
pole	doc_685122975269_item	3544702	et	3	main
oluline	doc_685122975269_item	3544703	et	4	main
kuhu	doc_685122975269_item	3544704	et	3	main
sa	doc_685122975269_item	3544705	et	3	main
lähed	doc_685122975269_item	3544706	et	3	main
õppida	doc_685122975269_item	3544707	et	3	main
oluline	doc_685122975269_item	3544708	et	4	main
on	doc_685122975269_item	3544709	et	4	main
see	doc_685122975269_item	3544710	et	3	main
et	doc_685122975269_item	3544711	et	3	main
inimene	doc_685122975269_item	3544712	et	3	main
oleks	doc_685122975269_item	3544713	et	3	main
sihikindel	doc_685122975269_item	3544714	et	3	main
ja	doc_685122975269_item	3544715	et	3	main
teaks	doc_685122975269_item	3544716	et	3	main
mida	doc_685122975269_item	3544717	et	4	main
tahab	doc_685122975269_item	3544718	et	3	main
abiturientile	doc_685122975269_item	3544719	et	4	main
on	doc_685122975269_item	3544720	et	4	main
oluline	doc_685122975269_item	3544721	et	4	main
kõrgharidust	doc_685122975269_item	3544722	et	4	main
saada	doc_685122975269_item	3544723	et	4	main
ja	doc_685122975269_item	3544724	et	3	main
minu	doc_685122975269_item	3544725	et	3	main
jaoks	doc_685122975269_item	3544726	et	4	main
praegu	doc_685122975269_item	3544727	et	3	main
ei	doc_685122975269_item	3544680	et	4	main
enamus	doc_685122975269_item	3544689	et	4	main
on	doc_685122975269_item	3544691	et	4	main
väga	doc_685122975269_item	3544692	et	3	main
leidsid	doc_685122975269_item	3544695	et	4	main
midagi	doc_685122975269_item	3544696	et	4	main
minu	doc_432051777927_item	3545085	et	3	main
vana	doc_432051777927_item	3545093	et	4	main
kõige	doc_432051777927_item	3545094	et	4	main
neli	doc_432051777927_item	3545113	et	3	main
varem	doc_432051777927_item	3545115	et	4	main
kursusele	doc_432051777927_item	3545125	et	3	main
keel	doc_432051777927_item	3545128	et	4	main
on	doc_432051777927_item	3545129	et	4	main
mina	doc_432051777927_item	3545134	et	4	main
elan	doc_432051777927_item	3545135	et	3	main
eestis	doc_432051777927_item	3545136	et	3	main
ja	doc_432051777927_item	3545137	et	3	main
sellepärast	doc_432051777927_item	3545138	et	3	main
on	doc_432051777927_item	3545144	et	4	main
kiri	doc_432051777928_item	3545181	et	3	main
nimi	doc_432051777928_item	3545185	et	3	main
ma	doc_432051777928_item	3545199	et	3	main
arvuti	doc_432051777928_item	3545205	et	4	main
ja	doc_432051777928_item	3545206	et	3	main
miks	doc_432051777928_item	3545223	et	4	main
tulin	doc_432051777928_item	3545224	et	3	main
uudised	doc_432051777928_item	3545255	et	3	main
me	doc_432051777928_item	3545270	et	4	main
põhjalikult	doc_432051777928_item	3545272	et	4	main
ma	doc_432051777928_item	3545274	et	3	main
ametlik	doc_432051777927_item	3545081	et	3	main
õpetaja	doc_432051777927_item	3545084	et	4	main
eesnimi	doc_432051777927_item	3545087	et	3	main
üheksateist	doc_432051777927_item	3545091	et	4	main
on	doc_432051777927_item	3545126	et	4	main
eesti	doc_432051777927_item	3545127	et	4	main
mul	doc_432051777927_item	3545143	et	3	main
perekonnanimi	doc_432051777928_item	3545187	et	3	main
elus	doc_432051777928_item	3545194	et	4	main
on	doc_432051777928_item	3545195	et	4	main
samuti	doc_432051777928_item	3545204	et	3	main
vaatada	doc_432051777928_item	3545207	et	4	main
eesti	doc_432051777928_item	3545209	et	4	main
keelt	doc_432051777928_item	3545210	et	4	main
olen	doc_432051777928_item	3545211	et	3	main
õppinud	doc_432051777928_item	3545212	et	4	main
varem	doc_432051777928_item	3545216	et	4	main
saksa	doc_432051777928_item	3545219	et	4	main
on	doc_432051777928_item	3545227	et	4	main
ma	doc_432051777928_item	3545256	et	3	main
ma	doc_432051777928_item	3545261	et	3	main
kirjutada	doc_432051777928_item	3545263	et	3	main
eesti	doc_432051777928_item	3545265	et	4	main
loodan	doc_432051777928_item	3545268	et	3	main
eesnimi	doc_51880851200_item	3545401	et	3	main
turismifirma	doc_51880851200_item	3545404	et	4	main
11-4	doc_51880851200_item	3545407	et	2	main
infot	doc_51880851200_item	3545417	et	3	main
riiga	doc_51880851200_item	3545424	et	4	main
meie	doc_51880851200_item	3545425	et	4	main
meile	doc_51880851200_item	3545461	et	4	main
kohta	doc_51880851200_item	3545465	et	4	main
täpne	doc_51880851200_item	3545466	et	3	main
ekskursiooniprogramm	doc_51880851200_item	3545467	et	4	main
reiside	doc_51880851200_item	3545468	et	3	main
hind	doc_51880851200_item	3545469	et	3	main
järelepärimiskirja	doc_51880851200_item	3545481	et	4	main
tere	doc_432051777927_item	3545083	et	3	main
mina	doc_432051777927_item	3545089	et	4	main
aastat	doc_432051777927_item	3545114	et	3	main
olen	doc_432051777927_item	3545116	et	3	main
õppinud	doc_432051777927_item	3545117	et	4	main
saksa	doc_432051777927_item	3545118	et	4	main
tulin	doc_432051777927_item	3545123	et	3	main
põhjus	doc_432051777927_item	3545132	et	4	main
on	doc_432051777927_item	3545133	et	4	main
eesti	doc_432051777927_item	3545141	et	4	main
eesti	doc_432051777927_item	3545145	et	4	main
et	doc_432051777927_item	3545148	et	3	main
kiri	doc_432051777927_item	3545082	et	3	main
tähtsam	doc_432051777927_item	3545095	et	4	main
põhjus	doc_432051777927_item	3545121	et	4	main
miks	doc_432051777927_item	3545122	et	4	main
riigikeel	doc_432051777927_item	3545130	et	4	main
teine	doc_432051777927_item	3545131	et	3	main
pean	doc_432051777927_item	3545139	et	4	main
keel	doc_432051777927_item	3545142	et	4	main
keelt	doc_432051777927_item	3545146	et	4	main
lugeda	doc_432051777927_item	3545149	et	3	main
ametlik	doc_432051777928_item	3545180	et	3	main
eesnimi	doc_432051777928_item	3545186	et	3	main
üheksateist	doc_432051777928_item	3545189	et	4	main
õppimine	doc_432051777928_item	3545196	et	4	main
mängida	doc_432051777928_item	3545201	et	3	main
teleri	doc_432051777928_item	3545208	et	3	main
olen	doc_432051777928_item	3545217	et	3	main
tahan	doc_432051777928_item	3545257	et	3	main
elust	doc_432051777928_item	3545260	et	3	main
järelepärimiskiri	doc_51880851200_item	3545403	et	3	main
vojaž	doc_51880851200_item	3545405	et	2	main
soovime	doc_51880851200_item	3545415	et	4	main
täpsemat	doc_51880851200_item	3545416	et	4	main
teie	doc_51880851200_item	3545418	et	4	main
firma	doc_51880851200_item	3545419	et	4	main
ühe	doc_51880851200_item	3545470	et	4	main
kohta	doc_51880851200_item	3545472	et	4	main
ootame	doc_51880851200_item	3545473	et	3	main
teie	doc_51880851200_item	3545474	et	4	main
lugege	doc_491521502051_item	3545647	et	3	main
vastake	doc_491521502051_item	3545651	et	3	main
sõna	doc_491521502051_item	3545658	et	4	main
tutvustage	doc_491521502051_item	3545659	et	3	main
ennast	doc_491521502051_item	3545660	et	4	main
ja	doc_491521502051_item	3545668	et	3	main
vajatakse	doc_491521502051_item	3545689	et	4	main
oskust	doc_491521502051_item	3545701	et	3	main
head	doc_491521502051_item	3545702	et	4	main
suhtlemisoskust	doc_491521502051_item	3545703	et	3	main
soovitav	doc_491521502051_item	3545704	et	4	main
kakuke	doc_491521502051_item	3545718	et	4	main
kuulutus	doc_491521502051_item	3545729	et	4	main
töötada	doc_491521502051_item	3545733	et	3	main
tahan	doc_432051777927_item	3545157	et	3	main
rääkida	doc_432051777927_item	3545158	et	3	main
eestlastega	doc_432051777927_item	3545159	et	4	main
ma	doc_432051777927_item	3545160	et	3	main
kardan	doc_432051777927_item	3545161	et	4	main
natuke	doc_432051777927_item	3545162	et	4	main
et	doc_432051777927_item	3545163	et	3	main
mul	doc_432051777927_item	3545164	et	3	main
probleemid	doc_432051777927_item	3545165	et	3	main
sõnumitega	doc_432051777927_item	3545166	et	3	main
ma	doc_432051777927_item	3545167	et	3	main
tahaksin	doc_432051777927_item	3545168	et	3	main
teada	doc_432051777927_item	3545169	et	3	main
natuke	doc_432051777927_item	3545170	et	4	main
eesti	doc_432051777927_item	3545171	et	4	main
keelest	doc_432051777927_item	3545172	et	4	main
loodan	doc_432051777927_item	3545173	et	3	main
et	doc_432051777927_item	3545174	et	3	main
kõik	doc_432051777927_item	3545175	et	4	main
on	doc_432051777927_item	3545176	et	4	main
korras	doc_432051777927_item	3545177	et	4	main
nimi	doc_432051777927_item	3545086	et	3	main
perekonnanimi	doc_432051777927_item	3545088	et	3	main
olen	doc_432051777927_item	3545090	et	3	main
aastat	doc_432051777927_item	3545092	et	3	main
minu	doc_432051777927_item	3545096	et	3	main
elus	doc_432051777927_item	3545097	et	4	main
on	doc_432051777927_item	3545098	et	4	main
eesti	doc_432051777927_item	3545099	et	4	main
keele	doc_432051777927_item	3545100	et	4	main
tund	doc_432051777927_item	3545101	et	3	main
ma	doc_432051777927_item	3545102	et	3	main
armastan	doc_432051777927_item	3545103	et	3	main
suhelda	doc_432051777927_item	3545104	et	4	main
ja	doc_432051777927_item	3545105	et	3	main
lugeda	doc_432051777927_item	3545106	et	3	main
eesti	doc_432051777927_item	3545107	et	4	main
keeles	doc_432051777927_item	3545108	et	4	main
eesti	doc_432051777927_item	3545109	et	4	main
keelt	doc_432051777927_item	3545110	et	4	main
olen	doc_432051777927_item	3545111	et	3	main
õppinud	doc_432051777927_item	3545112	et	4	main
keelt	doc_432051777927_item	3545119	et	4	main
esimene	doc_432051777927_item	3545120	et	3	main
sellele	doc_432051777927_item	3545124	et	4	main
teata	doc_432051777927_item	3545140	et	4	main
vaja	doc_432051777927_item	3545147	et	4	main
raskuseid	doc_432051777927_item	3545150	et	4	main
tekstid	doc_432051777927_item	3545151	et	3	main
ma	doc_432051777927_item	3545152	et	3	main
tahan	doc_432051777927_item	3545153	et	3	main
kuulata	doc_432051777927_item	3545154	et	4	main
uudiseid	doc_432051777927_item	3545155	et	3	main
ma	doc_432051777927_item	3545156	et	3	main
tere	doc_432051777928_item	3545182	et	3	main
minu	doc_432051777928_item	3545184	et	3	main
kõige	doc_432051777928_item	3545191	et	4	main
sport	doc_432051777928_item	3545198	et	3	main
armastan	doc_432051777928_item	3545200	et	3	main
spordialad	doc_432051777928_item	3545202	et	3	main
aastat	doc_432051777928_item	3545215	et	3	main
sellele	doc_432051777928_item	3545225	et	4	main
kursusele	doc_432051777928_item	3545226	et	3	main
eesti	doc_432051777928_item	3545228	et	4	main
keel	doc_432051777928_item	3545229	et	4	main
riigikeel	doc_432051777928_item	3545230	et	4	main
teine	doc_432051777928_item	3545231	et	3	main
rääkida	doc_432051777928_item	3545258	et	3	main
eestlasega	doc_432051777928_item	3545259	et	3	main
tahan	doc_432051777928_item	3545262	et	3	main
luletused	doc_432051777928_item	3545264	et	4	main
keelt	doc_432051777928_item	3545266	et	4	main
ma	doc_432051777928_item	3545267	et	3	main
elusega	doc_432051777928_item	3545273	et	3	main
on	doc_432051777928_item	3545279	et	4	main
probleemid	doc_432051777928_item	3545280	et	3	main
sõnumidega	doc_432051777928_item	3545281	et	4	main
ma	doc_432051777928_item	3545282	et	3	main
tahaksin	doc_432051777928_item	3545283	et	3	main
teada	doc_432051777928_item	3545284	et	3	main
elust	doc_432051777928_item	3545285	et	3	main
ja	doc_432051777928_item	3545286	et	3	main
tööst	doc_432051777928_item	3545287	et	3	main
loodan	doc_432051777928_item	3545288	et	3	main
et	doc_432051777928_item	3545289	et	3	main
on	doc_432051777928_item	3545290	et	4	main
mina	doc_432051777928_item	3545291	et	4	main
väga	doc_432051777928_item	3545292	et	3	main
laisk	doc_432051777928_item	3545293	et	3	main
lugupidamisega	doc_432051777928_item	3545294	et	3	main
eesnimi	doc_432051777928_item	3545295	et	3	main
perekonnanimi	doc_432051777928_item	3545296	et	3	main
õpetaja	doc_432051777928_item	3545183	et	4	main
olen	doc_432051777928_item	3545188	et	3	main
aastat	doc_432051777928_item	3545190	et	3	main
tähtsam	doc_432051777928_item	3545192	et	4	main
minu	doc_432051777928_item	3545193	et	3	main
ja	doc_432051777928_item	3545197	et	3	main
aga	doc_432051777928_item	3545203	et	3	main
umbes	doc_432051777928_item	3545213	et	4	main
üјheksa	doc_432051777928_item	3545214	et	2	main
õppinud	doc_432051777928_item	3545218	et	4	main
keelt	doc_432051777928_item	3545220	et	4	main
esimene	doc_432051777928_item	3545221	et	3	main
põhjus	doc_432051777928_item	3545222	et	4	main
põhjus	doc_432051777928_item	3545232	et	4	main
on	doc_432051777928_item	3545233	et	4	main
õppida	doc_432051777928_item	3545234	et	3	main
tartus	doc_432051777928_item	3545235	et	3	main
mul	doc_432051777928_item	3545236	et	3	main
on	doc_432051777928_item	3545237	et	4	main
eesti	doc_432051777928_item	3545238	et	4	main
keelt	doc_432051777928_item	3545239	et	4	main
vaja	doc_432051777928_item	3545240	et	4	main
et	doc_432051777928_item	3545241	et	3	main
lugeda	doc_432051777928_item	3545242	et	3	main
ajakirjad	doc_432051777928_item	3545243	et	3	main
ja	doc_432051777928_item	3545244	et	3	main
raamatud	doc_432051777928_item	3545245	et	4	main
ma	doc_432051777928_item	3545246	et	3	main
tahan	doc_432051777928_item	3545247	et	3	main
kuulata	doc_432051777928_item	3545248	et	4	main
eestlane	doc_432051777928_item	3545249	et	3	main
raadio	doc_432051777928_item	3545250	et	4	main
ja	doc_432051777928_item	3545251	et	3	main
tahan	doc_432051777928_item	3545252	et	3	main
vaatada	doc_432051777928_item	3545253	et	4	main
eesti	doc_432051777928_item	3545254	et	4	main
et	doc_432051777928_item	3545269	et	3	main
tegeleme	doc_432051777928_item	3545271	et	3	main
kardan	doc_432051777928_item	3545275	et	4	main
natuke	doc_432051777928_item	3545276	et	4	main
et	doc_432051777928_item	3545277	et	3	main
minu	doc_432051777928_item	3545278	et	3	main
kiri	doc_51880851200_item	3545400	et	3	main
13817	doc_51880851200_item	3545408	et	2	main
lugupeetud	doc_51880851200_item	3545410	et	4	main
firmajuht	doc_51880851200_item	3545411	et	3	main
20	doc_51880851200_item	3545412	et	2	main
reiside	doc_51880851200_item	3545422	et	3	main
kohta	doc_51880851200_item	3545423	et	4	main
teie	doc_51880851200_item	3545457	et	4	main
püsikliendiks	doc_51880851200_item	3545458	et	3	main
palun	doc_51880851200_item	3545459	et	3	main
teatage	doc_51880851200_item	3545460	et	3	main
riiga	doc_51880851200_item	3545463	et	4	main
jooksul	doc_51880851200_item	3545478	et	4	main
oleme	doc_51880851200_item	3545479	et	3	main
ametlik	doc_51880851200_item	3545399	et	3	main
mai	doc_51880851200_item	3545413	et	4	main
2004	doc_51880851200_item	3545414	et	2	main
poolt	doc_51880851200_item	3545420	et	4	main
firma	doc_51880851200_item	3545426	et	4	main
osutab	doc_51880851200_item	3545427	et	3	main
teenuseid	doc_51880851200_item	3545428	et	3	main
vastust	doc_51880851200_item	3545475	et	4	main
järgmise	doc_51880851200_item	3545476	et	3	main
nädala	doc_51880851200_item	3545477	et	3	main
mitmesse	doc_51880851200_item	3545482	et	4	main
läbi	doc_491521502051_item	3545648	et	4	main
ja	doc_491521502051_item	3545650	et	3	main
umbes	doc_491521502051_item	3545656	et	4	main
60	doc_491521502051_item	3545657	et	2	main
autojuhiload	doc_491521502051_item	3545666	et	4	main
müüjat	doc_491521502051_item	3545690	et	4	main
kanditaatidelt	doc_491521502051_item	3545695	et	3	main
eesti	doc_491521502051_item	3545697	et	4	main
ja	doc_491521502051_item	3545698	et	3	main
vene	doc_491521502051_item	3545699	et	4	main
teile	doc_491521502051_item	3545711	et	4	main
as	doc_491521502051_item	3545717	et	4	main
juhuslik	doc_491521502051_item	3545719	et	3	main
3	doc_491521502051_item	3545721	et	2	main
tallinn	doc_491521502051_item	3545722	et	4	main
teie	doc_491521502051_item	3545734	et	4	main
kaupluses	doc_491521502051_item	3545735	et	3	main
kahekümnekaheksaneaastane	doc_491521502051_item	3545739	et	4	main
töötada	doc_491521502051_item	3545774	et	3	main
nädalas	doc_491521502051_item	3545783	et	3	main
eesnimi	doc_491521502051_item	3545790	et	3	main
reisidefirmasse	doc_51880851200_item	3545483	et	4	main
oma	doc_51880851200_item	3545484	et	4	main
valikust	doc_51880851200_item	3545485	et	4	main
teatame	doc_51880851200_item	3545486	et	3	main
hiljemalt	doc_51880851200_item	3545487	et	3	main
20	doc_51880851200_item	3545488	et	2	main
juuniks	doc_51880851200_item	3545489	et	3	main
2004	doc_51880851200_item	3545490	et	2	main
meeldivale	doc_51880851200_item	3545491	et	4	main
koostööle	doc_51880851200_item	3545492	et	3	main
eesnimi	doc_51880851200_item	3545494	et	3	main
lootes	doc_51880851200_item	3545493	et	4	main
perekonnanimi	doc_51880851200_item	3545495	et	3	main
oü	doc_51880851200_item	3545496	et	4	main
lll	doc_51880851200_item	3545497	et	4	main
personalijuhataja	doc_51880851200_item	3545498	et	4	main
perekonnanimi	doc_51880851200_item	3545402	et	3	main
juhuslik	doc_51880851200_item	3545406	et	3	main
tallinn	doc_51880851200_item	3545409	et	4	main
pakutavate	doc_51880851200_item	3545421	et	4	main
oma	doc_51880851200_item	3545429	et	4	main
personalile	doc_51880851200_item	3545430	et	3	main
puhkuse	doc_51880851200_item	3545431	et	3	main
kohta	doc_51880851200_item	3545432	et	4	main
meil	doc_51880851200_item	3545433	et	4	main
on	doc_51880851200_item	3545434	et	4	main
kokku	doc_51880851200_item	3545435	et	3	main
10	doc_51880851200_item	3545436	et	2	main
000	doc_51880851200_item	3545437	et	2	main
töötajat	doc_51880851200_item	3545438	et	4	main
ja	doc_51880851200_item	3545439	et	3	main
iga	doc_51880851200_item	3545440	et	4	main
nädalavahetused	doc_51880851200_item	3545441	et	4	main
meie	doc_51880851200_item	3545442	et	4	main
firma	doc_51880851200_item	3545443	et	4	main
korraldab	doc_51880851200_item	3545444	et	3	main
töötajate	doc_51880851200_item	3545445	et	4	main
grupile	doc_51880851200_item	3545446	et	3	main
ekskursiooni	doc_51880851200_item	3545447	et	4	main
riiga	doc_51880851200_item	3545448	et	4	main
me	doc_51880851200_item	3545449	et	4	main
tahaksime	doc_51880851200_item	3545450	et	3	main
rohkem	doc_51880851200_item	3545451	et	4	main
teada	doc_51880851200_item	3545452	et	3	main
teie	doc_51880851200_item	3545453	et	4	main
pakkumistest	doc_51880851200_item	3545454	et	4	main
et	doc_51880851200_item	3545455	et	3	main
saada	doc_51880851200_item	3545456	et	4	main
pakkumised	doc_51880851200_item	3545462	et	4	main
reiside	doc_51880851200_item	3545464	et	3	main
inimese	doc_51880851200_item	3545471	et	4	main
saatnud	doc_51880851200_item	3545480	et	4	main
kuulutus	doc_491521502051_item	3545649	et	4	main
sellele	doc_491521502051_item	3545652	et	4	main
kirjas	doc_491521502051_item	3545653	et	4	main
arvutioskus	doc_491521502051_item	3545665	et	3	main
hobid	doc_491521502051_item	3545667	et	3	main
toidukauplus	doc_491521502051_item	3545687	et	3	main
kauplusse	doc_491521502051_item	3545688	et	3	main
kassapidajat	doc_491521502051_item	3545691	et	3	main
keele	doc_491521502051_item	3545700	et	4	main
sobivat	doc_491521502051_item	3545712	et	4	main
töögraafikut	doc_491521502051_item	3545713	et	3	main
teie	doc_491521502051_item	3545728	et	4	main
ma	doc_491521502051_item	3545737	et	3	main
ma	doc_491521502051_item	3545740	et	3	main
vallaline	doc_491521502051_item	3545742	et	4	main
ma	doc_491521502051_item	3545772	et	3	main
päeva	doc_491521502051_item	3545782	et	4	main
mõtlen	doc_491521502051_item	3545785	et	3	main
teile	doc_491521502051_item	3545787	et	4	main
kiri	doc_491521502051_item	3545646	et	3	main
perekonnaseis	doc_491521502051_item	3545661	et	4	main
haridus	doc_491521502051_item	3545662	et	3	main
töökogemused	doc_491521502051_item	3545663	et	3	main
turvamehi	doc_491521502051_item	3545692	et	3	main
koristajaid	doc_491521502051_item	3545693	et	4	main
ootame	doc_491521502051_item	3545696	et	3	main
on	doc_491521502051_item	3545705	et	4	main
ka	doc_491521502051_item	3545706	et	3	main
arvutikasutusoskus	doc_491521502051_item	3545707	et	3	main
pakume	doc_491521502051_item	3545708	et	3	main
mugavaid	doc_491521502051_item	3545709	et	3	main
töötingimusi	doc_491521502051_item	3545710	et	3	main
lugupeetud	doc_491521502051_item	3545723	et	4	main
kaupluse	doc_491521502051_item	3545724	et	3	main
direktor	doc_491521502051_item	3545725	et	3	main
ma	doc_491521502051_item	3545726	et	3	main
lugesin	doc_491521502051_item	3545727	et	3	main
müüjana	doc_491521502051_item	3545736	et	4	main
on	doc_491521502051_item	3545744	et	4	main
keskharidus	doc_491521502051_item	3545745	et	3	main
iga	doc_491521502051_item	3545775	et	4	main
kaheksa	doc_491521502051_item	3545777	et	4	main
tundi	doc_491521502051_item	3545778	et	4	main
ja	doc_491521502051_item	3545779	et	3	main
puhkada	doc_491521502051_item	3545780	et	4	main
kaks	doc_491521502051_item	3545781	et	3	main
austusega	doc_491521502051_item	3545789	et	4	main
ja	doc_491521502054_item	3545969	et	3	main
vastake	doc_491521502054_item	3545970	et	3	main
sõna	doc_491521502054_item	3545977	et	4	main
keelteoskus	doc_491521502054_item	3545983	et	3	main
autojuhiload	doc_491521502054_item	3545985	et	4	main
hobid	doc_491521502054_item	3545986	et	3	main
ja	doc_491521502054_item	3545987	et	3	main
kirjutage	doc_491521502054_item	3545988	et	3	main
oma	doc_491521502054_item	3545989	et	4	main
soovidest	doc_491521502054_item	3545990	et	3	main
millist	doc_491521502054_item	3545991	et	3	main
peab	doc_491521502051_item	3545654	et	4	main
olema	doc_491521502051_item	3545655	et	4	main
keelteoskus	doc_491521502051_item	3545664	et	3	main
kirjutage	doc_491521502051_item	3545669	et	3	main
oma	doc_491521502051_item	3545670	et	4	main
soovidest	doc_491521502051_item	3545671	et	3	main
millist	doc_491521502051_item	3545672	et	3	main
tööd	doc_491521502051_item	3545673	et	4	main
soovite	doc_491521502051_item	3545674	et	3	main
kui	doc_491521502051_item	3545675	et	3	main
suurt	doc_491521502051_item	3545676	et	3	main
töötasu	doc_491521502051_item	3545677	et	4	main
soovite	doc_491521502051_item	3545678	et	3	main
milline	doc_491521502051_item	3545679	et	3	main
töögraafik	doc_491521502051_item	3545680	et	3	main
sobib	doc_491521502051_item	3545681	et	3	main
kahe	doc_491521502051_item	3545682	et	3	main
kuu	doc_491521502051_item	3545683	et	4	main
pärast	doc_491521502051_item	3545684	et	4	main
avatakse	doc_491521502051_item	3545685	et	4	main
uus	doc_491521502051_item	3545686	et	3	main
pakkijaid	doc_491521502051_item	3545694	et	4	main
kindlat	doc_491521502051_item	3545714	et	3	main
palka	doc_491521502051_item	3545715	et	4	main
lisainfo	doc_491521502051_item	3545716	et	4	main
mnt	doc_491521502051_item	3545720	et	4	main
ajalehes	doc_491521502051_item	3545730	et	3	main
ma	doc_491521502051_item	3545731	et	3	main
tahaksin	doc_491521502051_item	3545732	et	3	main
olen	doc_491521502051_item	3545738	et	3	main
olen	doc_491521502051_item	3545741	et	3	main
mul	doc_491521502051_item	3545743	et	3	main
ja	doc_491521502051_item	3545746	et	3	main
mina	doc_491521502051_item	3545747	et	4	main
töötasin	doc_491521502051_item	3545748	et	3	main
toidukaupluses	doc_491521502051_item	3545749	et	3	main
viis	doc_491521502051_item	3545750	et	4	main
aastat	doc_491521502051_item	3545751	et	3	main
ma	doc_491521502051_item	3545752	et	3	main
räägin	doc_491521502051_item	3545753	et	3	main
vene	doc_491521502051_item	3545754	et	4	main
ja	doc_491521502051_item	3545755	et	3	main
eesti	doc_491521502051_item	3545756	et	4	main
keelt	doc_491521502051_item	3545757	et	4	main
ning	doc_491521502051_item	3545758	et	3	main
oskan	doc_491521502051_item	3545759	et	3	main
töötada	doc_491521502051_item	3545760	et	3	main
arvutil	doc_491521502051_item	3545761	et	4	main
natukene	doc_491521502051_item	3545762	et	4	main
veel	doc_491521502051_item	3545763	et	4	main
mul	doc_491521502051_item	3545764	et	3	main
on	doc_491521502051_item	3545765	et	4	main
autojuhiload	doc_491521502051_item	3545766	et	4	main
ma	doc_491521502051_item	3545767	et	3	main
olen	doc_491521502051_item	3545768	et	3	main
täpne	doc_491521502051_item	3545769	et	3	main
ja	doc_491521502051_item	3545770	et	3	main
sõbralik	doc_491521502051_item	3545771	et	3	main
ma	doc_491521502051_item	3545784	et	3	main
perekonnanimi	doc_491521502051_item	3545791	et	3	main
tahaksin	doc_491521502051_item	3545773	et	3	main
päev	doc_491521502051_item	3545776	et	3	main
et	doc_491521502051_item	3545786	et	3	main
sobin	doc_491521502051_item	3545788	et	3	main
kiri	doc_491521502054_item	3545965	et	3	main
kirjas	doc_491521502054_item	3545972	et	4	main
60	doc_491521502054_item	3545976	et	2	main
töökogemused	doc_491521502054_item	3545982	et	3	main
milline	doc_491521502054_item	3545998	et	3	main
kahe	doc_491521502054_item	3546001	et	3	main
toidukauplus	doc_491521502054_item	3546006	et	3	main
töötingimusi	doc_491521502054_item	3546029	et	3	main
lisainfo	doc_491521502054_item	3546035	et	4	main
lugesin	doc_491521502054_item	3546043	et	3	main
et	doc_491521502054_item	3546046	et	3	main
eesnimi	doc_491521502054_item	3546121	et	3	main
kuulutuse	doc_491521501670_item	3546135	et	4	main
ajalehest	doc_491521501670_item	3546136	et	4	main
et	doc_491521501670_item	3546139	et	3	main
teil	doc_491521501670_item	3546144	et	4	main
töökohta	doc_491521501670_item	3546145	et	4	main
perekonnanimi	doc_491521501670_item	3546154	et	3	main
elan	doc_491521501670_item	3546155	et	3	main
olen	doc_491521501670_item	3546162	et	3	main
on	doc_491521501670_item	3546166	et	4	main
tütar	doc_491521501670_item	3546168	et	3	main
kuidas	doc_491521501670_item	3546180	et	3	main
keelt	doc_491521501670_item	3546192	et	4	main
13	doc_491521501903_item	3546236	et	2	main
postimees	doc_491521501903_item	3546245	et	4	main
olen	doc_491521501903_item	3546249	et	3	main
teie	doc_491521501903_item	3546263	et	4	main
kõrgharidust	doc_491521501903_item	3546266	et	4	main
vene	doc_491521501903_item	3546274	et	4	main
inglise	doc_491521501903_item	3546275	et	4	main
olen	doc_491521501903_item	3546282	et	3	main
jooned	doc_491521501903_item	3546297	et	3	main
armastan	doc_491521501903_item	3546304	et	3	main
oma	doc_491521501903_item	3546305	et	4	main
töö	doc_491521501903_item	3546306	et	4	main
ja	doc_491521501903_item	3546307	et	3	main
olen	doc_491521501903_item	3546308	et	3	main
palju	doc_491521501903_item	3546311	et	4	main
loodan	doc_491521501903_item	3546334	et	3	main
teie	doc_491521501903_item	3546340	et	4	main
lugege	doc_491521502054_item	3545966	et	3	main
ennast	doc_491521502054_item	3545979	et	4	main
perekonnaseis	doc_491521502054_item	3545980	et	4	main
suurt	doc_491521502054_item	3545995	et	3	main
soovite	doc_491521502054_item	3545997	et	3	main
töögraafik	doc_491521502054_item	3545999	et	3	main
kuu	doc_491521502054_item	3546002	et	4	main
kauplusse	doc_491521502054_item	3546007	et	3	main
mugavaid	doc_491521502054_item	3546028	et	3	main
tere	doc_491521502054_item	3546042	et	3	main
kuulutuse	doc_491521502054_item	3546045	et	4	main
teie	doc_491521502054_item	3546047	et	4	main
toidukauplusse	doc_491521502054_item	3546048	et	3	main
on	doc_491521502054_item	3546049	et	4	main
töötada	doc_491521502054_item	3546054	et	3	main
kaupluses	doc_491521502054_item	3546056	et	3	main
ma	doc_491521502054_item	3546058	et	3	main
lõpenud	doc_491521502054_item	3546060	et	4	main
ja	doc_491521502054_item	3546062	et	3	main
2	doc_491521502054_item	3546064	et	2	main
tööl	doc_491521502054_item	3546110	et	3	main
kodus	doc_491521502054_item	3546112	et	4	main
arvan	doc_491521502054_item	3546114	et	3	main
perekonnanimi	doc_491521502054_item	3546122	et	3	main
as	doc_491521501670_item	3546125	et	4	main
mnt	doc_491521501670_item	3546128	et	4	main
arvan	doc_491521501670_item	3546138	et	3	main
on	doc_491521501670_item	3546141	et	4	main
saada	doc_491521501670_item	3546148	et	4	main
müüaks	doc_491521501670_item	3546149	et	4	main
minu	doc_491521501670_item	3546150	et	3	main
nimi	doc_491521501670_item	3546151	et	3	main
aastat	doc_491521501670_item	3546160	et	3	main
ja	doc_491521501670_item	3546164	et	3	main
mul	doc_491521501670_item	3546169	et	3	main
on	doc_491521501670_item	3546181	et	4	main
töötada	doc_491521501670_item	3546183	et	3	main
mina	doc_491521501670_item	3546185	et	4	main
olen	doc_491521501670_item	3546186	et	3	main
venelane	doc_491521501670_item	3546187	et	3	main
aga	doc_491521501670_item	3546188	et	3	main
valdan	doc_491521501670_item	3546189	et	3	main
juhuslik	doc_491521501903_item	3546234	et	3	main
teie	doc_491521501903_item	3546246	et	4	main
ja	doc_491521501903_item	3546248	et	3	main
lõpetanud	doc_491521501903_item	3546256	et	4	main
majandus	doc_491521501903_item	3546257	et	4	main
valdan	doc_491521501903_item	3546267	et	3	main
vabalt	doc_491521501903_item	3546269	et	4	main
ja	doc_491521501903_item	3546271	et	3	main
natuke	doc_491521501903_item	3546277	et	4	main
oskan	doc_491521501903_item	3546278	et	3	main
saksa	doc_491521501903_item	3546279	et	4	main
müügiesindajana	doc_491521501903_item	3546284	et	3	main
soovitus	doc_491521501903_item	3546292	et	4	main
sellised	doc_491521501903_item	3546296	et	4	main
algatusvõimeline	doc_491521501903_item	3546298	et	4	main
iseseisvane	doc_491521501903_item	3546299	et	4	main
täpne	doc_491521501903_item	3546300	et	3	main
ja	doc_491521501903_item	3546301	et	3	main
krooni	doc_491521501903_item	3546332	et	4	main
kanditatuur	doc_491521501903_item	3546337	et	4	main
soobib	doc_491521501903_item	3546339	et	4	main
ametlik	doc_491521501904_item	3546348	et	3	main
mnt	doc_491521501904_item	3546355	et	4	main
kolleegidega	doc_491521501904_item	3546381	et	3	main
konsultandid	doc_491521501904_item	3546393	et	3	main
läbi	doc_491521502054_item	3545967	et	4	main
sellele	doc_491521502054_item	3545971	et	4	main
peab	doc_491521502054_item	3545973	et	4	main
olema	doc_491521502054_item	3545974	et	4	main
tutvustage	doc_491521502054_item	3545978	et	3	main
haridus	doc_491521502054_item	3545981	et	3	main
arvutioskus	doc_491521502054_item	3545984	et	3	main
töötasu	doc_491521502054_item	3545996	et	4	main
sobib	doc_491521502054_item	3546000	et	3	main
uus	doc_491521502054_item	3546005	et	3	main
arvutikasutusoskus	doc_491521502054_item	3546026	et	3	main
pakume	doc_491521502054_item	3546027	et	3	main
sobivat	doc_491521502054_item	3546031	et	4	main
töögraafikut	doc_491521502054_item	3546032	et	3	main
kindlat	doc_491521502054_item	3546033	et	3	main
palka	doc_491521502054_item	3546034	et	4	main
3	doc_491521502054_item	3546040	et	2	main
tallinn	doc_491521502054_item	3546041	et	4	main
ma	doc_491521502054_item	3546052	et	3	main
pr	doc_491521502054_item	3546120	et	4	main
kiri	doc_491521501670_item	3546124	et	3	main
kakuke	doc_491521501670_item	3546126	et	4	main
lugesin	doc_491521501670_item	3546132	et	3	main
läbi	doc_491521501670_item	3546133	et	4	main
teie	doc_491521501670_item	3546134	et	4	main
võimalus	doc_491521501670_item	3546142	et	3	main
ida-virumaal	doc_491521501670_item	3546156	et	4	main
ma	doc_491521501670_item	3546157	et	3	main
olen	doc_491521501670_item	3546158	et	3	main
abielus	doc_491521501670_item	3546163	et	4	main
vaja	doc_491521501670_item	3546182	et	4	main
müüana	doc_491521501670_item	3546184	et	4	main
ametlik	doc_491521501903_item	3546231	et	3	main
cwb	doc_491521501903_item	3546233	et	4	main
15098	doc_491521501903_item	3546238	et	2	main
eest	doc_491521501903_item	3546253	et	4	main
ma	doc_491521501903_item	3546254	et	3	main
olen	doc_491521501903_item	3546255	et	3	main
kaubandusalast	doc_491521501903_item	3546265	et	4	main
keelt	doc_491521501903_item	3546280	et	4	main
2000-2002	doc_491521501903_item	3546281	et	2	main
on	doc_491521501903_item	3546290	et	4	main
mul	doc_491521501903_item	3546291	et	3	main
loovat	doc_491521501903_item	3546302	et	4	main
alati	doc_491521501903_item	3546309	et	4	main
kuus	doc_491521501903_item	3546333	et	4	main
juhuslik	doc_491521501904_item	3546354	et	3	main
tartu	doc_491521501904_item	3546357	et	4	main
12	doc_491521501904_item	3546388	et	2	main
keeleõppijat	doc_491521501904_item	3546389	et	3	main
firmas	doc_491521501904_item	3546390	et	3	main
sekretärid	doc_491521501904_item	3546392	et	3	main
meiepoolesed	doc_491521501904_item	3546396	et	3	main
õppimine	doc_491521501904_item	3546399	et	4	main
algaks	doc_491521501904_item	3546400	et	3	main
oktoobrist	doc_491521501904_item	3546401	et	3	main
kuni	doc_491521501904_item	3546402	et	3	main
kell	doc_491521501904_item	3546412	et	3	main
veel	doc_491521501904_item	3546427	et	4	main
õpetaja	doc_744962874520_item	3546474	et	4	main
nimi	doc_744962874520_item	3546476	et	3	main
19	doc_744962874520_item	3546481	et	2	main
eesti	doc_744962874520_item	3546522	et	4	main
soov	doc_744962874520_item	3546525	et	3	main
keelt	doc_744962874520_item	3546538	et	4	main
mul	doc_744962874520_item	3546543	et	3	main
sõita	doc_491521502054_item	3546091	et	3	main
minu	doc_491521502054_item	3546092	et	3	main
soovides	doc_491521502054_item	3546093	et	4	main
on	doc_491521502054_item	3546094	et	4	main
hea	doc_491521502054_item	3546095	et	4	main
töö	doc_491521502054_item	3546096	et	4	main
mis	doc_491521502054_item	3546097	et	4	main
mulle	doc_491521502054_item	3546098	et	4	main
meeldib	doc_491521502054_item	3546099	et	3	main
töötasu	doc_491521502054_item	3546100	et	4	main
ümbes	doc_491521502054_item	3546101	et	4	main
kolm	doc_491521502054_item	3546102	et	3	main
tuhat	doc_491521502054_item	3546103	et	4	main
krooni	doc_491521502054_item	3546104	et	4	main
töögraafik	doc_491521502054_item	3546105	et	3	main
tahaksin	doc_491521502054_item	3546106	et	3	main
saata	doc_491521502054_item	3546107	et	3	main
üks	doc_491521502054_item	3546108	et	3	main
kuulutus	doc_491521502054_item	3545968	et	4	main
umbes	doc_491521502054_item	3545975	et	4	main
tööd	doc_491521502054_item	3545992	et	4	main
soovite	doc_491521502054_item	3545993	et	3	main
kui	doc_491521502054_item	3545994	et	3	main
pärast	doc_491521502054_item	3546003	et	4	main
vajatakse	doc_491521502054_item	3546008	et	4	main
müüjat	doc_491521502054_item	3546009	et	4	main
kassapidajat	doc_491521502054_item	3546010	et	3	main
turvamehi	doc_491521502054_item	3546011	et	3	main
koristajaid	doc_491521502054_item	3546012	et	4	main
pakkijaid	doc_491521502054_item	3546013	et	4	main
kanditaatidelt	doc_491521502054_item	3546014	et	3	main
ootame	doc_491521502054_item	3546015	et	3	main
eesti	doc_491521502054_item	3546016	et	4	main
ja	doc_491521502054_item	3546017	et	3	main
vene	doc_491521502054_item	3546018	et	4	main
oskust	doc_491521502054_item	3546020	et	3	main
keele	doc_491521502054_item	3546019	et	4	main
head	doc_491521502054_item	3546021	et	4	main
suhtlemisoskust	doc_491521502054_item	3546022	et	3	main
soovitav	doc_491521502054_item	3546023	et	4	main
on	doc_491521502054_item	3546024	et	4	main
ka	doc_491521502054_item	3546025	et	3	main
avatakse	doc_491521502054_item	3546004	et	4	main
as	doc_491521502054_item	3546036	et	4	main
kakuke	doc_491521502054_item	3546037	et	4	main
juhuslik	doc_491521502054_item	3546038	et	3	main
mnt	doc_491521502054_item	3546039	et	4	main
teie	doc_491521502054_item	3546044	et	4	main
tahaksin	doc_491521502054_item	3546053	et	3	main
olin	doc_491521502054_item	3546059	et	3	main
töötasin	doc_491521502054_item	3546063	et	3	main
päev	doc_491521502054_item	3546109	et	3	main
üks	doc_491521502054_item	3546111	et	3	main
et	doc_491521502054_item	3546115	et	3	main
teile	doc_491521502054_item	3546030	et	4	main
vaja	doc_491521502054_item	3546050	et	4	main
töölised	doc_491521502054_item	3546051	et	3	main
teil	doc_491521502054_item	3546055	et	4	main
müüjana	doc_491521502054_item	3546057	et	4	main
kooledž	doc_491521502054_item	3546061	et	2	main
aastat	doc_491521502054_item	3546065	et	3	main
toiduageentina	doc_491521502054_item	3546066	et	4	main
ma	doc_491521502054_item	3546067	et	3	main
voldan	doc_491521502054_item	3546068	et	4	main
eesti	doc_491521502054_item	3546069	et	4	main
keelt	doc_491521502054_item	3546070	et	4	main
vene	doc_491521502054_item	3546072	et	4	main
ja	doc_491521502054_item	3546071	et	3	main
keelt	doc_491521502054_item	3546073	et	4	main
natukene	doc_491521502054_item	3546074	et	4	main
oskan	doc_491521502054_item	3546075	et	3	main
arvutiga	doc_491521502054_item	3546076	et	4	main
praegu	doc_491521502054_item	3546077	et	3	main
ma	doc_491521502054_item	3546078	et	3	main
kõin	doc_491521502054_item	3546079	et	4	main
arvuti	doc_491521502054_item	3546080	et	4	main
kursustele	doc_491521502054_item	3546081	et	3	main
ma	doc_491521502054_item	3546082	et	3	main
olen	doc_491521502054_item	3546083	et	3	main
valaline	doc_491521502054_item	3546084	et	4	main
minu	doc_491521502054_item	3546085	et	3	main
hobbi	doc_491521502054_item	3546086	et	4	main
on	doc_491521502054_item	3546087	et	4	main
sport	doc_491521502054_item	3546088	et	3	main
autoga	doc_491521502054_item	3546090	et	3	main
oskan	doc_491521502054_item	3546089	et	3	main
ma	doc_491521502054_item	3546113	et	3	main
teie	doc_491521502054_item	3546116	et	4	main
võtsite	doc_491521502054_item	3546117	et	3	main
mind	doc_491521502054_item	3546118	et	4	main
tööle	doc_491521502054_item	3546119	et	3	main
juhuslik	doc_491521501670_item	3546127	et	3	main
3	doc_491521501670_item	3546129	et	2	main
tallinn	doc_491521501670_item	3546130	et	4	main
saada	doc_491521501670_item	3546143	et	4	main
eriti	doc_491521501670_item	3546146	et	3	main
soovin	doc_491521501670_item	3546147	et	3	main
25	doc_491521501670_item	3546159	et	2	main
muidugi	doc_491521501670_item	3546178	et	4	main
tean	doc_491521501670_item	3546179	et	3	main
hiljuti	doc_491521501670_item	3546193	et	4	main
ei	doc_491521501670_item	3546203	et	4	main
ole	doc_491521501670_item	3546204	et	4	main
nii	doc_491521501670_item	3546205	et	3	main
tähtsamalt	doc_491521501670_item	3546206	et	4	main
kui	doc_491521501670_item	3546207	et	3	main
minu	doc_491521501670_item	3546208	et	3	main
suhtlemisoskust	doc_491521501670_item	3546209	et	3	main
olen	doc_491521501670_item	3546210	et	3	main
aus	doc_491521501670_item	3546211	et	4	main
ja	doc_491521501670_item	3546212	et	3	main
viisakas	doc_491521501670_item	3546213	et	4	main
ja	doc_491521501670_item	3546214	et	3	main
loodan	doc_491521501670_item	3546215	et	3	main
et	doc_491521501670_item	3546216	et	3	main
saan	doc_491521501670_item	3546217	et	4	main
töökohta	doc_491521501670_item	3546218	et	4	main
teie	doc_491521501670_item	3546219	et	4	main
toidukaupluses	doc_491521501670_item	3546220	et	3	main
minu	doc_491521501670_item	3546221	et	3	main
telefoninimber	doc_491521501670_item	3546222	et	4	main
55	doc_491521501670_item	3546223	et	2	main
555	doc_491521501670_item	3546224	et	2	main
55	doc_491521501670_item	3546225	et	2	main
eesnimi	doc_491521501670_item	3546226	et	3	main
perekonnanimi	doc_491521501670_item	3546227	et	3	main
290900	doc_491521501670_item	3546228	et	2	main
mina	doc_491521501670_item	3546131	et	4	main
ja	doc_491521501670_item	3546137	et	3	main
mul	doc_491521501670_item	3546140	et	3	main
on	doc_491521501670_item	3546152	et	4	main
eesnimi	doc_491521501670_item	3546153	et	3	main
vana	doc_491521501670_item	3546161	et	4	main
mul	doc_491521501670_item	3546165	et	3	main
viieaastane	doc_491521501670_item	3546167	et	4	main
on	doc_491521501670_item	3546170	et	4	main
keskharidus	doc_491521501670_item	3546171	et	3	main
enne	doc_491521501670_item	3546172	et	4	main
ma	doc_491521501670_item	3546173	et	3	main
töötasin	doc_491521501670_item	3546174	et	3	main
juba	doc_491521501670_item	3546175	et	3	main
kaupluses	doc_491521501670_item	3546176	et	3	main
ja	doc_491521501670_item	3546177	et	3	main
vabalt	doc_491521501670_item	3546190	et	4	main
eesti	doc_491521501670_item	3546191	et	4	main
ma	doc_491521501670_item	3546194	et	3	main
lõpetas	doc_491521501670_item	3546195	et	3	main
arvutikursused	doc_491521501670_item	3546196	et	3	main
on	doc_491521501670_item	3546197	et	4	main
ka	doc_491521501670_item	3546198	et	3	main
autojuhi	doc_491521501670_item	3546199	et	3	main
load	doc_491521501670_item	3546200	et	4	main
aga	doc_491521501670_item	3546201	et	3	main
see	doc_491521501670_item	3546202	et	3	main
mnt	doc_491521501903_item	3546235	et	4	main
kuulutust	doc_491521501903_item	3546247	et	4	main
huvitatud	doc_491521501903_item	3546250	et	4	main
selle	doc_491521501903_item	3546251	et	4	main
poolt	doc_491521501903_item	3546264	et	4	main
ka	doc_491521501903_item	3546268	et	3	main
rääkimises	doc_491521501903_item	3546272	et	4	main
eesti	doc_491521501903_item	3546273	et	4	main
firmas	doc_491521501903_item	3546285	et	3	main
ao	doc_491521501903_item	3546286	et	3	main
on	doc_491521501903_item	3546294	et	4	main
valmis	doc_491521501903_item	3546310	et	4	main
5000-6000	doc_491521501903_item	3546331	et	2	main
on	doc_491521501903_item	3546338	et	4	main
turism	doc_491521501904_item	3546353	et	3	main
tel	doc_491521501904_item	3546358	et	4	main
soome	doc_491521501904_item	3546375	et	3	main
õppida	doc_491521501904_item	3546377	et	3	main
on	doc_491521501904_item	3546387	et	4	main
jaanuarini	doc_491521501904_item	3546403	et	3	main
alates	doc_491521501904_item	3546411	et	3	main
13-ni	doc_491521501904_item	3546415	et	3	main
toimumise	doc_491521501904_item	3546417	et	4	main
kiri	doc_744962874520_item	3546472	et	3	main
töötada	doc_491521501903_item	3546312	et	3	main
ametireisides	doc_491521501903_item	3546314	et	3	main
mul	doc_491521501903_item	3546315	et	3	main
ei	doc_491521501903_item	3546316	et	4	main
ole	doc_491521501903_item	3546317	et	4	main
ka	doc_491521501903_item	3546313	et	3	main
auto	doc_491521501903_item	3546318	et	4	main
aga	doc_491521501903_item	3546319	et	3	main
on	doc_491521501903_item	3546320	et	4	main
olemas	doc_491521501903_item	3546321	et	4	main
autojuhiload	doc_491521501903_item	3546322	et	4	main
oleks	doc_491521501903_item	3546323	et	3	main
hea	doc_491521501903_item	3546324	et	4	main
et	doc_491521501903_item	3546325	et	3	main
saaksin	doc_491521501903_item	3546326	et	3	main
ametiauto	doc_491521501903_item	3546327	et	4	main
minu	doc_491521501903_item	3546328	et	3	main
palgasoov	doc_491521501903_item	3546329	et	3	main
on	doc_491521501903_item	3546330	et	4	main
kiri	doc_491521501903_item	3546232	et	3	main
tallinn	doc_491521501903_item	3546237	et	4	main
cwb	doc_491521501903_item	3546239	et	4	main
personaliosakond	doc_491521501903_item	3546240	et	3	main
olen	doc_491521501903_item	3546241	et	3	main
lugenud	doc_491521501903_item	3546242	et	4	main
ajalehest	doc_491521501903_item	3546243	et	4	main
eesti	doc_491521501903_item	3546244	et	4	main
töökohta	doc_491521501903_item	3546252	et	4	main
ülikooli	doc_491521501903_item	3546258	et	4	main
ja	doc_491521501903_item	3546259	et	3	main
omanaan	doc_491521501903_item	3546260	et	4	main
ja	doc_491521501903_item	3546261	et	3	main
soovitatav	doc_491521501903_item	3546262	et	4	main
kirjas	doc_491521501903_item	3546270	et	4	main
keelt	doc_491521501903_item	3546276	et	4	main
töötanud	doc_491521501903_item	3546283	et	4	main
abc	doc_491521501903_item	3546287	et	4	main
eelmisest	doc_491521501903_item	3546288	et	3	main
töökohast	doc_491521501903_item	3546289	et	4	main
mulle	doc_491521501903_item	3546293	et	4	main
omased	doc_491521501903_item	3546295	et	3	main
mõtlemine	doc_491521501903_item	3546303	et	4	main
et	doc_491521501903_item	3546335	et	3	main
minu	doc_491521501903_item	3546336	et	3	main
nõudmisele	doc_491521501903_item	3546341	et	4	main
ootan	doc_491521501903_item	3546342	et	3	main
teilt	doc_491521501903_item	3546343	et	4	main
vastust	doc_491521501903_item	3546344	et	4	main
lugupidamisega	doc_491521501903_item	3546345	et	3	main
kiri	doc_491521501904_item	3546349	et	3	main
perekonnanimi	doc_491521501904_item	3546351	et	3	main
15	doc_491521501904_item	3546356	et	2	main
6666666	doc_491521501904_item	3546359	et	2	main
turism	doc_491521501904_item	3546372	et	3	main
hakata	doc_491521501904_item	3546382	et	4	main
õppima	doc_491521501904_item	3546383	et	3	main
keelekursustel	doc_491521501904_item	3546384	et	3	main
meie	doc_491521501904_item	3546385	et	4	main
firmas	doc_491521501904_item	3546386	et	3	main
ja	doc_491521501904_item	3546394	et	3	main
klienditeenindajad	doc_491521501904_item	3546395	et	3	main
soovid	doc_491521501904_item	3546397	et	4	main
kuni	doc_491521501904_item	3546414	et	3	main
koht	doc_491521501904_item	3546418	et	3	main
as	doc_491521501904_item	3546420	et	4	main
turism	doc_491521501904_item	3546421	et	3	main
ja	doc_491521501904_item	3546422	et	3	main
tasume	doc_491521501904_item	3546423	et	3	main
ülekandega	doc_491521501904_item	3546424	et	3	main
me	doc_491521501904_item	3546425	et	4	main
tahaksime	doc_491521501904_item	3546426	et	3	main
minu	doc_744962874520_item	3546475	et	3	main
olen	doc_744962874520_item	3546480	et	3	main
on	doc_744962874520_item	3546488	et	4	main
minu	doc_744962874520_item	3546489	et	3	main
sõbrad	doc_744962874520_item	3546490	et	3	main
ja	doc_744962874520_item	3546491	et	3	main
vanemad	doc_744962874520_item	3546493	et	4	main
on	doc_744962874520_item	3546530	et	4	main
töötada	doc_744962874520_item	3546533	et	3	main
eestis	doc_744962874520_item	3546534	et	3	main
mul	doc_744962874520_item	3546535	et	3	main
on	doc_744962874520_item	3546536	et	4	main
ma	doc_744962874520_item	3546549	et	3	main
loodan	doc_744962874520_item	3546550	et	3	main
tahaksin	doc_744962874520_item	3546572	et	3	main
mida	doc_744962874520_item	3546574	et	4	main
hakkame	doc_744962874520_item	3546576	et	3	main
vastaksite	doc_744962874520_item	3546582	et	3	main
teid	doc_491521501904_item	3546428	et	4	main
küsida	doc_491521501904_item	3546429	et	3	main
kui	doc_491521501904_item	3546430	et	3	main
palju	doc_491521501904_item	3546431	et	4	main
maksavad	doc_491521501904_item	3546432	et	3	main
kursused	doc_491521501904_item	3546433	et	3	main
kas	doc_491521501904_item	3546434	et	3	main
teil	doc_491521501904_item	3546435	et	4	main
on	doc_491521501904_item	3546436	et	4	main
mingid	doc_491521501904_item	3546437	et	4	main
soodustused	doc_491521501904_item	3546438	et	4	main
kui	doc_491521501904_item	3546439	et	3	main
kaua	doc_491521501904_item	3546440	et	3	main
kestavad	doc_491521501904_item	3546441	et	4	main
need	doc_491521501904_item	3546442	et	3	main
kursused	doc_491521501904_item	3546443	et	3	main
me	doc_491521501904_item	3546444	et	4	main
tahaksime	doc_491521501904_item	3546445	et	3	main
veel	doc_491521501904_item	3546446	et	4	main
e	doc_491521501904_item	3546350	et	4	main
as	doc_491521501904_item	3546352	et	4	main
gsm	doc_491521501904_item	3546360	et	4	main
5	doc_491521501904_item	3546361	et	2	main
555	doc_491521501904_item	3546362	et	2	main
55	doc_491521501904_item	3546363	et	2	main
55	doc_491521501904_item	3546364	et	2	main
55	doc_491521501904_item	3546365	et	2	main
lugupeetud	doc_491521501904_item	3546366	et	4	main
keelekeskus	doc_491521501904_item	3546367	et	3	main
me	doc_491521501904_item	3546368	et	4	main
töötame	doc_491521501904_item	3546369	et	3	main
firmas	doc_491521501904_item	3546370	et	3	main
as	doc_491521501904_item	3546371	et	4	main
ja	doc_491521501904_item	3546373	et	3	main
tahame	doc_491521501904_item	3546374	et	3	main
keelt	doc_491521501904_item	3546376	et	4	main
me	doc_491521501904_item	3546378	et	4	main
soovime	doc_491521501904_item	3546379	et	4	main
koos	doc_491521501904_item	3546380	et	4	main
töötavad	doc_491521501904_item	3546391	et	4	main
käia	doc_491521501904_item	3546406	et	4	main
kursustel	doc_491521501904_item	3546407	et	3	main
esmaspäevini	doc_491521501904_item	3546408	et	4	main
ja	doc_491521501904_item	3546409	et	3	main
reedeni	doc_491521501904_item	3546410	et	3	main
on	doc_491521501904_item	3546419	et	4	main
tere	doc_744962874520_item	3546473	et	3	main
on	doc_744962874520_item	3546477	et	4	main
minu	doc_744962874520_item	3546492	et	3	main
ma	doc_744962874520_item	3546494	et	3	main
põhjus	doc_744962874520_item	3546517	et	4	main
elada	doc_744962874520_item	3546531	et	3	main
ja	doc_744962874520_item	3546532	et	3	main
lugeda	doc_744962874520_item	3546541	et	3	main
on	doc_744962874520_item	3546544	et	4	main
me	doc_744962874520_item	3546575	et	4	main
sellel	doc_744962874520_item	3546577	et	4	main
te	doc_744962874520_item	3546581	et	4	main
et	doc_491521501904_item	3546398	et	3	main
me	doc_491521501904_item	3546404	et	4	main
võime	doc_491521501904_item	3546405	et	4	main
11	doc_491521501904_item	3546413	et	2	main
tundide	doc_491521501904_item	3546416	et	3	main
teada	doc_491521501904_item	3546447	et	3	main
saama	doc_491521501904_item	3546448	et	4	main
et	doc_491521501904_item	3546449	et	3	main
missuguse	doc_491521501904_item	3546450	et	3	main
töökogemusega	doc_491521501904_item	3546451	et	3	main
on	doc_491521501904_item	3546452	et	4	main
teie	doc_491521501904_item	3546453	et	4	main
õpetajad	doc_491521501904_item	3546454	et	4	main
kui	doc_491521501904_item	3546455	et	3	main
kaua	doc_491521501904_item	3546456	et	3	main
nad	doc_491521501904_item	3546457	et	3	main
töötavad	doc_491521501904_item	3546458	et	4	main
keelekeskuses	doc_491521501904_item	3546459	et	4	main
loodame	doc_491521501904_item	3546460	et	3	main
et	doc_491521501904_item	3546461	et	3	main
te	doc_491521501904_item	3546462	et	4	main
vastate	doc_491521501904_item	3546463	et	3	main
meie	doc_491521501904_item	3546464	et	4	main
kirjale	doc_491521501904_item	3546465	et	3	main
lähemal	doc_491521501904_item	3546466	et	4	main
ajal	doc_491521501904_item	3546467	et	4	main
meeldivad	doc_491521501904_item	3546468	et	4	main
koostööd	doc_491521501904_item	3546469	et	4	main
juhataja	doc_491521501904_item	3546470	et	4	main
eesnimi	doc_744962874520_item	3546478	et	3	main
õpilane	doc_744962874520_item	3546483	et	3	main
kõige	doc_744962874520_item	3546484	et	4	main
esimene	doc_744962874520_item	3546516	et	3	main
miks	doc_744962874520_item	3546518	et	4	main
ma	doc_744962874520_item	3546519	et	3	main
tahan	doc_744962874520_item	3546520	et	3	main
õppida	doc_744962874520_item	3546521	et	3	main
on	doc_744962874520_item	3546524	et	4	main
eesti	doc_744962874520_item	3546537	et	4	main
aimekirjandus	doc_744962874520_item	3546542	et	4	main
vaja	doc_744962874520_item	3546545	et	4	main
kirjutada	doc_744962874520_item	3546546	et	3	main
gramaatilised	doc_744962874520_item	3546547	et	4	main
ülesandeid	doc_744962874520_item	3546548	et	3	main
õppeaastal	doc_744962874520_item	3546578	et	3	main
minu	doc_744962874520_item	3546583	et	3	main
et	doc_744962874520_item	3546551	et	3	main
me	doc_744962874520_item	3546552	et	4	main
tegeleme	doc_744962874520_item	3546553	et	3	main
põhjalikult	doc_744962874520_item	3546554	et	4	main
kuulamine	doc_744962874520_item	3546555	et	4	main
tõlkimine	doc_744962874520_item	3546556	et	4	main
ja	doc_744962874520_item	3546557	et	3	main
kirjutamine	doc_744962874520_item	3546558	et	4	main
ma	doc_744962874520_item	3546559	et	3	main
kardan	doc_744962874520_item	3546560	et	4	main
natuke	doc_744962874520_item	3546561	et	4	main
et	doc_744962874520_item	3546562	et	3	main
minu	doc_744962874520_item	3546563	et	3	main
teadmised	doc_744962874520_item	3546564	et	4	main
eesti	doc_744962874520_item	3546565	et	4	main
keele	doc_744962874520_item	3546566	et	4	main
gramaatikal	doc_744962874520_item	3546567	et	4	main
on	doc_744962874520_item	3546568	et	4	main
väga	doc_744962874520_item	3546569	et	3	main
halb	doc_744962874520_item	3546570	et	3	main
ma	doc_744962874520_item	3546571	et	3	main
ma	doc_744962874520_item	3546479	et	3	main
aastane	doc_744962874520_item	3546482	et	4	main
tähtsam	doc_744962874520_item	3546485	et	4	main
minu	doc_744962874520_item	3546486	et	3	main
elus	doc_744962874520_item	3546487	et	4	main
armastan	doc_744962874520_item	3546495	et	3	main
lugeda	doc_744962874520_item	3546496	et	3	main
ja	doc_744962874520_item	3546497	et	3	main
joonistada	doc_744962874520_item	3546498	et	3	main
ma	doc_744962874520_item	3546499	et	3	main
joonistan	doc_744962874520_item	3546500	et	3	main
loodus	doc_744962874520_item	3546501	et	4	main
inimesed	doc_744962874520_item	3546502	et	3	main
ja	doc_744962874520_item	3546503	et	3	main
teised	doc_744962874520_item	3546504	et	4	main
eesti	doc_744962874520_item	3546505	et	4	main
keelt	doc_744962874520_item	3546506	et	4	main
olen	doc_744962874520_item	3546507	et	3	main
õppinud	doc_744962874520_item	3546508	et	4	main
9	doc_744962874520_item	3546509	et	2	main
aastat	doc_744962874520_item	3546510	et	3	main
varem	doc_744962874520_item	3546511	et	4	main
olen	doc_744962874520_item	3546512	et	3	main
õppinud	doc_744962874520_item	3546513	et	4	main
inglise	doc_744962874520_item	3546514	et	4	main
keel	doc_744962874520_item	3546515	et	4	main
keel	doc_744962874520_item	3546523	et	4	main
rägida	doc_744962874520_item	3546526	et	4	main
inimestega	doc_744962874520_item	3546527	et	3	main
teine	doc_744962874520_item	3546528	et	3	main
põhjus	doc_744962874520_item	3546529	et	4	main
vaja	doc_744962874520_item	3546539	et	4	main
et	doc_744962874520_item	3546540	et	3	main
loodan	doc_744962874520_item	3546579	et	3	main
teada	doc_744962874520_item	3546573	et	3	main
et	doc_744962874520_item	3546580	et	3	main
küsimusele	doc_744962874520_item	3546584	et	4	main
lugupidamisega	doc_744962874520_item	3546585	et	3	main
eesnimi	doc_744962874520_item	3546586	et	3	main
perekonnanimi	doc_744962874520_item	3546587	et	3	main
pr	doc_973441205342_item	3546849	et	4	main
perekonnanimi	doc_973441205342_item	3546851	et	3	main
klassi	doc_973441205342_item	3546859	et	4	main
õpilane	doc_973441205342_item	3546860	et	3	main
eesnimi	doc_973441205342_item	3546861	et	3	main
viibisin	doc_973441205342_item	3546863	et	3	main
üldhariduskoolidele	doc_973441205342_item	3546864	et	3	main
mis	doc_973441205342_item	3546868	et	4	main
toimutud	doc_973441205342_item	3546869	et	4	main
osa	doc_973441205342_item	3546876	et	4	main
ida	doc_973441205342_item	3546885	et	4	main
phare	doc_973441205342_item	3546890	et	4	main
saabumist	doc_973441205342_item	3546901	et	4	main
vene	doc_973441205342_item	3546918	et	4	main
hommikut	doc_973441205342_item	3546950	et	3	main
lõppusime	doc_973441205342_item	3546953	et	4	main
rühmatööst	doc_973441205342_item	3546954	et	3	main
ja	doc_973441205342_item	3546955	et	3	main
kirjutasime	doc_973441205342_item	3546956	et	3	main
meid	doc_973441205342_item	3546957	et	4	main
me	doc_973441205342_item	3546990	et	4	main
järgmisel	doc_973441205342_item	3546993	et	3	main
niisugust	doc_973441205342_item	3546995	et	3	main
õpilased	doc_973441205342_item	3546999	et	3	main
kiri	doc_973441205343_item	3547022	et	3	main
mis	doc_973441205343_item	3547042	et	4	main
jõhvis	doc_973441205343_item	3547048	et	3	main
kell	doc_973441205343_item	3547064	et	3	main
meil	doc_973441205343_item	3547066	et	4	main
ametlik	doc_973441205342_item	3546847	et	3	main
eesnimi	doc_973441205342_item	3546850	et	3	main
eesti	doc_973441205342_item	3546855	et	4	main
jõhvis	doc_973441205342_item	3546870	et	3	main
seminaril	doc_973441205342_item	3546874	et	3	main
ja	doc_973441205342_item	3546881	et	3	main
viru	doc_973441205342_item	3546886	et	4	main
maavalitsus	doc_973441205342_item	3546887	et	3	main
me	doc_973441205342_item	3546906	et	4	main
läksime	doc_973441205342_item	3546907	et	3	main
lektori	doc_973441205342_item	3546908	et	3	main
saali	doc_973441205342_item	3546909	et	4	main
ja	doc_973441205342_item	3546910	et	3	main
mis	doc_973441205342_item	3546916	et	4	main
päeval	doc_973441205342_item	3546948	et	3	main
pärast	doc_973441205342_item	3546949	et	4	main
me	doc_973441205342_item	3546952	et	4	main
peame	doc_973441205342_item	3546991	et	4	main
seal	doc_973441205342_item	3546998	et	4	main
kuulata	doc_973441205342_item	3547001	et	4	main
uut	doc_973441205342_item	3547002	et	3	main
projekte	doc_973441205342_item	3547003	et	3	main
ja	doc_973441205342_item	3547004	et	3	main
teada	doc_973441205342_item	3547005	et	3	main
midagi	doc_973441205342_item	3547006	et	4	main
lugupeetud	doc_973441205343_item	3547023	et	4	main
perekonnanimi	doc_973441205343_item	3547026	et	3	main
pähklimäe	doc_973441205343_item	3547028	et	3	main
klassi	doc_973441205343_item	3547031	et	4	main
klassijuhataja	doc_973441205343_item	3547032	et	4	main
olin	doc_973441205343_item	3547033	et	3	main
kahepäevasel	doc_973441205343_item	3547040	et	4	main
seminaril	doc_973441205343_item	3547041	et	3	main
palju	doc_973441205343_item	3547051	et	4	main
kuulsin	doc_973441205343_item	3547053	et	3	main
kaks	doc_973441205343_item	3547060	et	3	main
11	doc_973441205343_item	3547065	et	2	main
phare	doc_973441205343_item	3547075	et	4	main
projektid	doc_973441205343_item	3547076	et	3	main
võimalikku	doc_973441205343_item	3547096	et	4	main
me	doc_973441205343_item	3547134	et	4	main
kuulasime	doc_973441205343_item	3547135	et	3	main
kes	doc_973441205343_item	3547138	et	4	main
mida	doc_973441205343_item	3547154	et	4	main
narva	doc_973441205342_item	3546852	et	4	main
perekonnanimi	doc_973441205342_item	3546862	et	3	main
kahepäevasel	doc_973441205342_item	3546866	et	4	main
jaanuarini	doc_973441205342_item	3546873	et	3	main
õpetajad	doc_973441205342_item	3546880	et	4	main
el	doc_973441205342_item	3546889	et	4	main
kell	doc_973441205342_item	3546897	et	3	main
hommikul	doc_973441205342_item	3546899	et	3	main
me	doc_973441205342_item	3546902	et	4	main
end	doc_973441205342_item	3546904	et	4	main
jutustatud	doc_973441205342_item	3546917	et	4	main
süüjamist	doc_973441205342_item	3546951	et	4	main
ametlik	doc_973441205343_item	3547021	et	3	main
selle	doc_973441205343_item	3547034	et	4	main
viibiste	doc_973441205343_item	3547038	et	4	main
09	doc_973441205343_item	3547044	et	2	main
väga	doc_973441205343_item	3547050	et	3	main
uudisi	doc_973441205343_item	3547052	et	4	main
päeva	doc_973441205343_item	3547061	et	4	main
el	doc_973441205343_item	3547074	et	4	main
1300	doc_973441205343_item	3547081	et	2	main
aasta	doc_973441205343_item	3547085	et	4	main
esimene	doc_973441205343_item	3547088	et	3	main
rühmatööks	doc_973441205343_item	3547091	et	3	main
arutame	doc_973441205343_item	3547094	et	3	main
kõige	doc_973441205343_item	3547095	et	4	main
esimese	doc_973441205343_item	3547099	et	3	main
rühmatööst	doc_973441205343_item	3547124	et	3	main
ajalehtede	doc_973441205343_item	3547136	et	4	main
ei	doc_973441205343_item	3547157	et	4	main
mida	doc_973441205343_item	3547159	et	4	main
meeldib	doc_973441205343_item	3547160	et	3	main
ma	doc_973441205343_item	3547161	et	3	main
arvan	doc_973441205343_item	3547162	et	3	main
et	doc_973441205343_item	3547163	et	3	main
see	doc_973441205343_item	3547164	et	3	main
seminar	doc_973441205343_item	3547165	et	3	main
oli	doc_973441205343_item	3547166	et	3	main
väga	doc_973441205343_item	3547167	et	3	main
kasulik	doc_973441205343_item	3547168	et	3	main
minu	doc_973441205343_item	3547169	et	3	main
infot	doc_973441205343_item	3547175	et	3	main
võin	doc_973441205343_item	3547177	et	3	main
elus	doc_973441205343_item	3547179	et	4	main
kasutada	doc_973441205343_item	3547180	et	3	main
austamisega	doc_973441205343_item	3547181	et	4	main
eesnimi	doc_973441205343_item	3547182	et	3	main
perekonnanimi	doc_973441205343_item	3547183	et	3	main
24102006	doc_973441205343_item	3547184	et	2	main
kiri	doc_973441205342_item	3546848	et	3	main
gümnaasiumi	doc_973441205342_item	3546854	et	4	main
õpetaja	doc_973441205342_item	3546857	et	4	main
mina	doc_973441205342_item	3546858	et	4	main
mõeldud	doc_973441205342_item	3546865	et	4	main
seminaril	doc_973441205342_item	3546867	et	3	main
üheksast	doc_973441205342_item	3546871	et	4	main
võtsid	doc_973441205342_item	3546875	et	4	main
kooli	doc_973441205342_item	3546877	et	4	main
omavalitsuse	doc_973441205342_item	3546878	et	3	main
esimeested	doc_973441205342_item	3546879	et	4	main
olid	doc_973441205342_item	3546884	et	4	main
programm	doc_973441205342_item	3546891	et	3	main
saabusime	doc_973441205342_item	3546893	et	3	main
üheksandal	doc_973441205342_item	3546895	et	3	main
pärast	doc_973441205342_item	3546900	et	4	main
seal	doc_973441205342_item	3546911	et	4	main
tutvustime	doc_973441205342_item	3546912	et	4	main
el	doc_973441205342_item	3546913	et	4	main
jargmisel	doc_973441205342_item	3546947	et	4	main
tegema	doc_973441205342_item	3546992	et	3	main
seminari	doc_973441205342_item	3546996	et	4	main
eesnimi	doc_973441205343_item	3547025	et	3	main
narva	doc_973441205343_item	3547027	et	4	main
gümnaasiumi	doc_973441205343_item	3547029	et	4	main
poolaasta	doc_973441205343_item	3547035	et	4	main
esimesel	doc_973441205343_item	3547036	et	3	main
toimus	doc_973441205343_item	3547043	et	3	main
2004	doc_973441205343_item	3547047	et	2	main
ma	doc_973441205343_item	3547049	et	3	main
nüüd	doc_973441205343_item	3547054	et	4	main
räägin	doc_973441205343_item	3547055	et	3	main
meie	doc_973441205343_item	3547056	et	4	main
esimesel	doc_973441205343_item	3547062	et	3	main
registreerimine	doc_973441205343_item	3547068	et	4	main
1130	doc_973441205343_item	3547071	et	2	main
me	doc_973441205343_item	3547072	et	4	main
vaatasime	doc_973441205343_item	3547073	et	3	main
kell	doc_973441205343_item	3547080	et	3	main
arutasime	doc_973441205343_item	3547083	et	3	main
projektid	doc_973441205343_item	3547087	et	3	main
lõpetas	doc_973441205343_item	3547090	et	3	main
oli	doc_973441205343_item	3547122	et	3	main
ja	doc_973441205343_item	3547125	et	3	main
see	doc_973441205343_item	3547127	et	3	main
kestab	doc_973441205343_item	3547128	et	4	main
kaks	doc_973441205343_item	3547129	et	3	main
tundi	doc_973441205343_item	3547130	et	4	main
ja	doc_973441205343_item	3547131	et	3	main
kell	doc_973441205343_item	3547132	et	3	main
1300	doc_973441205343_item	3547133	et	2	main
rääkisid	doc_973441205343_item	3547139	et	4	main
seminari	doc_973441205343_item	3547147	et	4	main
kokkuvõte	doc_973441205343_item	3547148	et	3	main
kus	doc_973441205343_item	3547149	et	3	main
me	doc_973441205343_item	3547150	et	4	main
vestleme	doc_973441205343_item	3547151	et	3	main
mida	doc_973441205343_item	3547156	et	4	main
uudi	doc_973441205343_item	3547174	et	4	main
tulevikus	doc_973441205343_item	3547178	et	4	main
huvitavat	doc_973441205342_item	3547007	et	4	main
eesnimi	doc_973441205342_item	3547008	et	3	main
perekonnanimi	doc_973441205342_item	3547009	et	3	main
narva	doc_973441205342_item	3547010	et	4	main
ida	doc_973441205342_item	3547011	et	4	main
virumaa	doc_973441205342_item	3547012	et	4	main
eesti	doc_973441205342_item	3547013	et	4	main
narva	doc_973441205342_item	3547014	et	4	main
pähklimäe	doc_973441205342_item	3547015	et	3	main
gümnaasium	doc_973441205342_item	3547016	et	3	main
24102006	doc_973441205342_item	3547017	et	2	main
aastat	doc_973441205342_item	3547018	et	3	main
pähklimäe	doc_973441205342_item	3546853	et	3	main
keele	doc_973441205342_item	3546856	et	4	main
kümnenda	doc_973441205342_item	3546872	et	3	main
huvijuhtid	doc_973441205342_item	3546882	et	4	main
läbiiviijad	doc_973441205342_item	3546883	et	4	main
ja	doc_973441205342_item	3546888	et	3	main
me	doc_973441205342_item	3546892	et	4	main
jõhvisse	doc_973441205342_item	3546894	et	3	main
jaanuaril	doc_973441205342_item	3546896	et	3	main
vaha	doc_973441205342_item	3546898	et	4	main
reegistreerisime	doc_973441205342_item	3546903	et	4	main
edaspidiseks	doc_973441205342_item	3546905	et	4	main
phare	doc_973441205342_item	3546914	et	4	main
projektidega	doc_973441205342_item	3546915	et	3	main
õppekeelega	doc_973441205342_item	3546919	et	3	main
kooolidele	doc_973441205342_item	3546920	et	4	main
kella	doc_973441205342_item	3546921	et	4	main
kaksteistkümmeil	doc_973441205342_item	3546922	et	4	main
oli	doc_973441205342_item	3546923	et	3	main
magus	doc_973441205342_item	3546924	et	3	main
lõun	doc_973441205342_item	3546925	et	4	main
ja	doc_973441205342_item	3546926	et	3	main
pärast	doc_973441205342_item	3546927	et	4	main
lõunat	doc_973441205342_item	3546928	et	3	main
me	doc_973441205342_item	3546929	et	4	main
tagasi	doc_973441205342_item	3546930	et	3	main
lektori	doc_973441205342_item	3546931	et	3	main
saali	doc_973441205342_item	3546932	et	4	main
ja	doc_973441205342_item	3546933	et	3	main
arutasime	doc_973441205342_item	3546934	et	3	main
teistega	doc_973441205342_item	3546935	et	4	main
projektiga	doc_973441205342_item	3546936	et	4	main
2004	doc_973441205342_item	3546937	et	2	main
aasta	doc_973441205342_item	3546938	et	4	main
võimalikke	doc_973441205342_item	3546939	et	3	main
projektide	doc_973441205342_item	3546940	et	3	main
pärast	doc_973441205342_item	3546941	et	4	main
me	doc_973441205342_item	3546942	et	4	main
uurisime	doc_973441205342_item	3546943	et	3	main
kõike	doc_973441205342_item	3546944	et	4	main
projekte	doc_973441205342_item	3546945	et	3	main
rühmades	doc_973441205342_item	3546946	et	3	main
tagasiside	doc_973441205342_item	3546958	et	4	main
seminaarist	doc_973441205342_item	3546959	et	4	main
kella	doc_973441205342_item	3546960	et	4	main
kolmteist	doc_973441205342_item	3546961	et	4	main
kõik	doc_973441205342_item	3546962	et	4	main
osavõtjad	doc_973441205342_item	3546963	et	3	main
saaid	doc_973441205342_item	3546964	et	4	main
rääkida	doc_973441205342_item	3546965	et	3	main
oma	doc_973441205342_item	3546966	et	4	main
arvamus	doc_973441205342_item	3546967	et	3	main
mikrofonile	doc_973441205342_item	3546968	et	3	main
see	doc_973441205342_item	3546969	et	3	main
kõik	doc_973441205342_item	3546970	et	4	main
lõputas	doc_973441205342_item	3546971	et	4	main
kella	doc_973441205342_item	3546972	et	4	main
viisteist	doc_973441205342_item	3546973	et	4	main
me	doc_973441205342_item	3546974	et	4	main
tänasime	doc_973441205342_item	3546975	et	3	main
seminari	doc_973441205342_item	3546976	et	4	main
juhatajaid	doc_973441205342_item	3546977	et	4	main
ja	doc_973441205342_item	3546978	et	3	main
sõitsime	doc_973441205342_item	3546979	et	3	main
narvasse	doc_973441205342_item	3546980	et	4	main
mulle	doc_973441205342_item	3546981	et	4	main
väga	doc_973441205342_item	3546982	et	3	main
meeldis	doc_973441205342_item	3546983	et	3	main
seda	doc_973441205342_item	3546984	et	3	main
seminar	doc_973441205342_item	3546985	et	3	main
ja	doc_973441205342_item	3546986	et	3	main
ma	doc_973441205342_item	3546987	et	3	main
arvan	doc_973441205342_item	3546988	et	3	main
et	doc_973441205342_item	3546989	et	3	main
aastal	doc_973441205342_item	3546994	et	3	main
sest	doc_973441205342_item	3546997	et	4	main
saavad	doc_973441205342_item	3547000	et	4	main
meil	doc_973441205343_item	3547145	et	4	main
oli	doc_973441205343_item	3547146	et	3	main
pr	doc_973441205343_item	3547024	et	4	main
kümnenda	doc_973441205343_item	3547030	et	3	main
nädalalõpul	doc_973441205343_item	3547037	et	3	main
üldhariduskoolidele	doc_973441205343_item	3547039	et	3	main
10	doc_973441205343_item	3547045	et	2	main
jaanuaril	doc_973441205343_item	3547046	et	3	main
kavast	doc_973441205343_item	3547057	et	4	main
seminar	doc_973441205343_item	3547058	et	3	main
kestas	doc_973441205343_item	3547059	et	4	main
päeval	doc_973441205343_item	3547063	et	3	main
oli	doc_973441205343_item	3547067	et	3	main
pärast	doc_973441205343_item	3547069	et	4	main
kell	doc_973441205343_item	3547070	et	3	main
koolidele	doc_973441205343_item	3547079	et	3	main
2004	doc_973441205343_item	3547084	et	2	main
võimalikud	doc_973441205343_item	3547086	et	3	main
päev	doc_973441205343_item	3547089	et	3	main
kus	doc_973441205343_item	3547092	et	3	main
me	doc_973441205343_item	3547093	et	4	main
pärast	doc_973441205343_item	3547098	et	4	main
päeva	doc_973441205343_item	3547100	et	4	main
seminari	doc_973441205343_item	3547101	et	4	main
me	doc_973441205343_item	3547102	et	4	main
sõitsime	doc_973441205343_item	3547103	et	3	main
hotellisse	doc_973441205343_item	3547104	et	4	main
kus	doc_973441205343_item	3547105	et	3	main
sõime	doc_973441205343_item	3547106	et	4	main
ja	doc_973441205343_item	3547107	et	3	main
magasime	doc_973441205343_item	3547108	et	3	main
kümnendal	doc_973441205343_item	3547109	et	3	main
jaanuaril	doc_973441205343_item	3547110	et	3	main
seminar	doc_973441205343_item	3547111	et	3	main
jätkus	doc_973441205343_item	3547112	et	4	main
aga	doc_973441205343_item	3547113	et	3	main
programm	doc_973441205343_item	3547114	et	3	main
ei	doc_973441205343_item	3547115	et	4	main
ole	doc_973441205343_item	3547116	et	4	main
väga	doc_973441205343_item	3547117	et	3	main
suur	doc_973441205343_item	3547118	et	3	main
kell	doc_973441205343_item	3547119	et	3	main
kümme	doc_973441205343_item	3547120	et	3	main
vene	doc_973441205343_item	3547077	et	4	main
õppekeelega	doc_973441205343_item	3547078	et	3	main
me	doc_973441205343_item	3547082	et	4	main
projekt	doc_973441205343_item	3547097	et	3	main
meil	doc_973441205343_item	3547121	et	4	main
kokkuvõtted	doc_973441205343_item	3547123	et	3	main
oma	doc_973441205343_item	3547140	et	4	main
kokku	doc_973441205343_item	3547153	et	3	main
huvitab	doc_973441205343_item	3547155	et	3	main
huvita	doc_973441205343_item	3547158	et	4	main
poolest	doc_973441205343_item	3547170	et	4	main
as	doc_973441205348_item	3547797	et	4	main
61	doc_973441205348_item	3547801	et	2	main
333	doc_973441205348_item	3547803	et	2	main
tallinn	doc_973441205348_item	3547804	et	4	main
olen	doc_973441205348_item	3547806	et	3	main
lugenud	doc_973441205348_item	3547807	et	4	main
meie	doc_973441205348_item	3547821	et	4	main
tagasiside	doc_973441205343_item	3547126	et	4	main
ajakirjanikuid	doc_973441205343_item	3547137	et	4	main
tööst	doc_973441205343_item	3547141	et	3	main
lõpuks	doc_973441205343_item	3547142	et	4	main
kell	doc_973441205343_item	3547143	et	3	main
1500	doc_973441205343_item	3547144	et	2	main
seminari	doc_973441205343_item	3547152	et	4	main
ma	doc_973441205343_item	3547171	et	3	main
sain	doc_973441205343_item	3547172	et	3	main
palju	doc_973441205343_item	3547173	et	4	main
mida	doc_973441205343_item	3547176	et	4	main
kiri	doc_973441205348_item	3547796	et	3	main
333	doc_973441205348_item	3547802	et	2	main
suvel	doc_973441205348_item	3547811	et	3	main
muusikafestival	doc_973441205348_item	3547813	et	3	main
infot	doc_973441205348_item	3547815	et	3	main
õpilastele	doc_973441205348_item	3547823	et	4	main
te	doc_973441205348_item	3547832	et	4	main
aga	doc_973441205348_item	3547838	et	3	main
aga	doc_973441205348_item	3547849	et	3	main
teil	doc_973441205348_item	3547880	et	4	main
on	doc_973441205348_item	3547881	et	4	main
millal	doc_973441205348_item	3547900	et	3	main
algus	doc_973441205348_item	3547902	et	4	main
juba	doc_973441205348_item	3547909	et	3	main
teil	doc_973441205348_item	3547918	et	4	main
on	doc_973441205348_item	3547923	et	4	main
kas	doc_973441205348_item	3547927	et	3	main
tel	doc_973441205348_item	3547952	et	4	main
187687	doc_973441205348_item	3547953	et	2	main
juhuslik	doc_973441205348_item	3547954	et	3	main
ametlik	doc_973441205348_item	3547795	et	3	main
internetist	doc_973441205348_item	3547808	et	4	main
teil	doc_973441205348_item	3547810	et	4	main
tahaksin	doc_973441205348_item	3547814	et	3	main
teada	doc_973441205348_item	3547828	et	3	main
see	doc_973441205348_item	3547835	et	3	main
millal	doc_973441205348_item	3547839	et	3	main
tahtsin	doc_973441205348_item	3547841	et	3	main
kus	doc_973441205348_item	3547843	et	3	main
kes	doc_973441205348_item	3547876	et	4	main
nad	doc_973441205348_item	3547877	et	3	main
ajal	doc_973441205348_item	3547885	et	4	main
on	doc_973441205348_item	3547901	et	4	main
lõpp	doc_973441205348_item	3547903	et	3	main
praegu	doc_973441205348_item	3547910	et	3	main
veel	doc_973441205348_item	3547913	et	4	main
meid	doc_973441205348_item	3547914	et	4	main
huvitab	doc_973441205348_item	3547915	et	3	main
piletiinfo	doc_973441205348_item	3547916	et	4	main
kas	doc_973441205348_item	3547917	et	3	main
gruppidele	doc_973441205348_item	3547921	et	3	main
klassis	doc_973441205348_item	3547926	et	3	main
veel	doc_973441205348_item	3547937	et	4	main
tahame	doc_973441205348_item	3547938	et	3	main
on	doc_973441205348_item	3547942	et	4	main
majustus	doc_973441205348_item	3547944	et	4	main
pileti	doc_973441205348_item	3547945	et	3	main
hind	doc_973441205348_item	3547946	et	3	main
palun	doc_973441205348_item	3547947	et	3	main
kirjutage	doc_973441205348_item	3547948	et	3	main
meile	doc_973441205348_item	3547949	et	4	main
vastu	doc_973441205348_item	3547950	et	3	main
kontakt	doc_973441205348_item	3547951	et	3	main
narva	doc_973441205348_item	3547957	et	4	main
20456	doc_973441205348_item	3547958	et	2	main
fbi	doc_973441205348_item	3547798	et	4	main
klassi	doc_973441205348_item	3547822	et	4	main
soovin	doc_973441205348_item	3547827	et	3	main
aeg	doc_973441205348_item	3547831	et	3	main
et	doc_973441205348_item	3547834	et	3	main
suvel	doc_973441205348_item	3547837	et	3	main
veel	doc_973441205348_item	3547840	et	4	main
teada	doc_973441205348_item	3547842	et	3	main
toimub	doc_973441205348_item	3547844	et	3	main
kirjutasite	doc_973441205348_item	3547846	et	3	main
kus	doc_973441205348_item	3547850	et	3	main
tallinnas	doc_973441205348_item	3547848	et	4	main
täpselt	doc_973441205348_item	3547851	et	4	main
klassi	doc_973441205348_item	3547853	et	4	main
õpilased	doc_973441205348_item	3547854	et	3	main
tahavad	doc_973441205348_item	3547855	et	3	main
teada	doc_973441205348_item	3547856	et	3	main
missugused	doc_973441205348_item	3547857	et	3	main
muusikastiilid	doc_973441205348_item	3547858	et	3	main
meie	doc_973441205348_item	3547852	et	4	main
on	doc_973441205348_item	3547859	et	4	main
festivalil	doc_973441205348_item	3547860	et	3	main
neile	doc_973441205348_item	3547861	et	4	main
meeldivad	doc_973441205348_item	3547862	et	4	main
ainult	doc_973441205348_item	3547863	et	4	main
rokkfestivalid	doc_973441205348_item	3547864	et	3	main
soovin	doc_973441205348_item	3547865	et	3	main
teada	doc_973441205348_item	3547866	et	3	main
kas	doc_973441205348_item	3547867	et	3	main
teil	doc_973441205348_item	3547868	et	4	main
on	doc_973441205348_item	3547869	et	4	main
juba	doc_973441205348_item	3547870	et	3	main
kutsutud	doc_973441205348_item	3547871	et	4	main
esinejad	doc_973441205348_item	3547872	et	4	main
kui	doc_973441205348_item	3547873	et	3	main
on	doc_973441205348_item	3547874	et	4	main
kirjutage	doc_973441205348_item	3547875	et	3	main
juhuslik	doc_973441205348_item	3547799	et	3	main
tee	doc_973441205348_item	3547800	et	4	main
70406	doc_973441205348_item	3547805	et	2	main
et	doc_973441205348_item	3547809	et	3	main
toimub	doc_973441205348_item	3547812	et	3	main
saada	doc_973441205348_item	3547816	et	4	main
sest	doc_973441205348_item	3547817	et	4	main
et	doc_973441205348_item	3547818	et	3	main
planeerime	doc_973441205348_item	3547819	et	3	main
korraldama	doc_973441205348_item	3547820	et	3	main
teie	doc_973441205348_item	3547824	et	4	main
toimumise	doc_973441205348_item	3547830	et	4	main
muusikaüritused	doc_973441205348_item	3547891	et	3	main
missugused	doc_973441205348_item	3547892	et	3	main
kontserdid	doc_973441205348_item	3547893	et	3	main
teil	doc_973441205348_item	3547894	et	4	main
on	doc_973441205348_item	3547895	et	4	main
päevased	doc_973441205348_item	3547896	et	4	main
või	doc_973441205348_item	3547897	et	4	main
õhtused	doc_973441205348_item	3547898	et	4	main
muusikafestivali	doc_973441205348_item	3547825	et	4	main
ühiskülastuse	doc_973441205348_item	3547826	et	3	main
festivali	doc_973441205348_item	3547829	et	4	main
kirjutasite	doc_973441205348_item	3547833	et	3	main
toimub	doc_973441205348_item	3547836	et	3	main
festival	doc_973441205348_item	3547845	et	3	main
et	doc_973441205348_item	3547847	et	3	main
on	doc_973441205348_item	3547878	et	4	main
kas	doc_973441205348_item	3547879	et	3	main
midagi	doc_973441205348_item	3547886	et	4	main
veel	doc_973441205348_item	3547887	et	4	main
teha	doc_973441205348_item	3547888	et	3	main
meid	doc_973441205348_item	3547889	et	4	main
huvitab	doc_973441205348_item	3547890	et	3	main
meil	doc_973441205348_item	3547904	et	4	main
on	doc_973441205348_item	3547905	et	4	main
vähe	doc_973441205348_item	3547906	et	3	main
soodustused	doc_973441205348_item	3547920	et	4	main
inimest	doc_973441205348_item	3547925	et	3	main
lisainfot	doc_973441205348_item	3547939	et	3	main
toitlustamine	doc_973441205348_item	3547943	et	4	main
joonitud	doc_986203247095_item	3548105	et	4	main
100	doc_986203247095_item	3548113	et	2	main
te	doc_986203247095_item	3548123	et	4	main
see	doc_986203247095_item	3548135	et	3	main
21-22	doc_986203247095_item	3548138	et	2	main
ühele	doc_986203247095_item	3548142	et	3	main
grupis	doc_986203247095_item	3548165	et	3	main
on	doc_986203247095_item	3548166	et	4	main
22	doc_986203247095_item	3548167	et	2	main
teeb	doc_986203247095_item	3548176	et	3	main
vene	doc_986203247095_item	3548188	et	4	main
riigi	doc_986203247095_item	3548189	et	3	main
vahel	doc_986203247095_item	3548190	et	4	main
on	doc_986203247095_item	3548191	et	4	main
lõpetamine	doc_986203247095_item	3548195	et	4	main
26	doc_986203247095_item	3548230	et	2	main
üritused	doc_973441205348_item	3547882	et	4	main
tahame	doc_973441205348_item	3547883	et	3	main
vabal	doc_973441205348_item	3547884	et	3	main
aega	doc_973441205348_item	3547907	et	4	main
tahame	doc_973441205348_item	3547908	et	3	main
plaani	doc_973441205348_item	3547911	et	4	main
on	doc_973441205348_item	3547919	et	4	main
26	doc_973441205348_item	3547924	et	2	main
vaja	doc_973441205348_item	3547929	et	4	main
saada	doc_973441205348_item	3547940	et	4	main
ja	doc_973441205348_item	3547899	et	3	main
teha	doc_973441205348_item	3547912	et	3	main
meil	doc_973441205348_item	3547922	et	4	main
on	doc_973441205348_item	3547928	et	4	main
festivali	doc_973441205348_item	3547930	et	4	main
pass	doc_973441205348_item	3547931	et	3	main
teha	doc_973441205348_item	3547932	et	3	main
et	doc_973441205348_item	3547933	et	3	main
mugavam	doc_973441205348_item	3547934	et	4	main
oleks	doc_973441205348_item	3547935	et	3	main
ja	doc_973441205348_item	3547936	et	3	main
missugused	doc_973441205348_item	3547941	et	3	main
mnt	doc_973441205348_item	3547955	et	4	main
87	doc_973441205348_item	3547956	et	2	main
sisse	doc_986203247095_item	3548107	et	4	main
nõutav	doc_986203247095_item	3548109	et	4	main
pikkus	doc_986203247095_item	3548110	et	4	main
meie	doc_986203247095_item	3548120	et	4	main
alati	doc_986203247095_item	3548125	et	4	main
reise	doc_986203247095_item	3548127	et	3	main
reis	doc_986203247095_item	3548140	et	4	main
maksab	doc_986203247095_item	3548141	et	3	main
1500	doc_986203247095_item	3548144	et	2	main
hinna	doc_986203247095_item	3548146	et	3	main
meie	doc_986203247095_item	3548164	et	4	main
et	doc_986203247095_item	3548174	et	3	main
valisime	doc_986203247095_item	3548181	et	3	main
kooli	doc_986203247095_item	3548194	et	4	main
meil	doc_986203247095_item	3548196	et	4	main
ei	doc_986203247095_item	3548197	et	4	main
meie	doc_986203247095_item	3548226	et	4	main
ärge	doc_986203247095_item	3548237	et	3	main
allapoole	doc_986203247095_item	3548241	et	3	main
joonitud	doc_986203247097_item	3548389	et	4	main
karu	doc_986203247097_item	3548401	et	4	main
me	doc_986203247097_item	3548402	et	4	main
lugesime	doc_986203247097_item	3548403	et	3	main
ajalehest	doc_986203247097_item	3548404	et	4	main
u	doc_986203247095_item	3548112	et	4	main
tere	doc_986203247095_item	3548115	et	3	main
perekonnanimi	doc_986203247095_item	3548117	et	3	main
sponsor	doc_986203247095_item	3548122	et	3	main
toetate	doc_986203247095_item	3548124	et	3	main
meie	doc_986203247095_item	3548128	et	4	main
grupp	doc_986203247095_item	3548129	et	3	main
tahab	doc_986203247095_item	3548130	et	3	main
sõita	doc_986203247095_item	3548131	et	3	main
sankt-peterburi	doc_986203247095_item	3548132	et	4	main
juuni	doc_986203247095_item	3548139	et	4	main
inimesele	doc_986203247095_item	3548143	et	3	main
sees	doc_986203247095_item	3548147	et	4	main
on	doc_986203247095_item	3548148	et	4	main
edasi-tagasi	doc_986203247095_item	3548149	et	3	main
rongipilet	doc_986203247095_item	3548150	et	3	main
juhtimisel	doc_986203247095_item	3548158	et	4	main
ja	doc_986203247095_item	3548160	et	3	main
õpilast	doc_986203247095_item	3548168	et	4	main
ja	doc_986203247095_item	3548169	et	3	main
reisifirma	doc_986203247095_item	3548175	et	4	main
20	doc_986203247095_item	3548179	et	2	main
selle	doc_986203247095_item	3548182	et	4	main
piir	doc_986203247095_item	3548192	et	3	main
pärast	doc_986203247095_item	3548193	et	4	main
koos	doc_986203247095_item	3548225	et	4	main
19112002	doc_986203247095_item	3548236	et	2	main
kiri	doc_986203247095_item	3548103	et	3	main
on	doc_986203247095_item	3548111	et	4	main
sõna	doc_986203247095_item	3548114	et	4	main
härra	doc_986203247095_item	3548116	et	4	main
kooli	doc_986203247095_item	3548121	et	4	main
teatrisse	doc_986203247095_item	3548134	et	3	main
reis	doc_986203247095_item	3548136	et	4	main
toimub	doc_986203247095_item	3548137	et	3	main
krooni	doc_986203247095_item	3548145	et	4	main
giidi	doc_986203247095_item	3548157	et	4	main
peeter	doc_986203247095_item	3548161	et	3	main
eesti	doc_986203247095_item	3548186	et	4	main
ja	doc_986203247095_item	3548187	et	3	main
ole	doc_986203247095_item	3548198	et	4	main
võimalusi	doc_986203247095_item	3548199	et	3	main
et	doc_986203247095_item	3548220	et	3	main
tahame	doc_986203247095_item	3548222	et	3	main
sõida	doc_986203247095_item	3548223	et	4	main
kõik	doc_986203247095_item	3548224	et	4	main
vaja	doc_986203247095_item	3548229	et	4	main
400	doc_986203247095_item	3548231	et	2	main
krooni	doc_986203247095_item	3548232	et	4	main
lugupidamisega	doc_986203247095_item	3548233	et	3	main
eesnimi	doc_986203247095_item	3548234	et	3	main
perekonnanimi	doc_986203247095_item	3548235	et	3	main
sellest	doc_986203247095_item	3548239	et	4	main
joonest	doc_986203247095_item	3548240	et	4	main
pikkus	doc_986203247097_item	3548394	et	4	main
on	doc_986203247097_item	3548395	et	4	main
u	doc_986203247097_item	3548396	et	4	main
sooviksime	doc_986203247097_item	3548410	et	4	main
on	doc_986203247097_item	3548421	et	4	main
õpilaste	doc_986203247097_item	3548425	et	4	main
sooviksime	doc_986203247097_item	3548437	et	4	main
ettendust	doc_986203247097_item	3548441	et	4	main
22	doc_986203247097_item	3548444	et	2	main
kuu	doc_986203247097_item	3548446	et	4	main
juuni	doc_986203247097_item	3548450	et	4	main
kuu	doc_986203247097_item	3548451	et	4	main
me	doc_986203247097_item	3548475	et	4	main
summas	doc_986203247097_item	3548486	et	4	main
sees	doc_986203247097_item	3548488	et	4	main
ja	doc_986203247097_item	3548490	et	3	main
juhtimisel	doc_986203247097_item	3548495	et	4	main
ja	doc_986203247097_item	3548497	et	3	main
peeter-pauli	doc_986203247097_item	3548498	et	4	main
lisatasu	doc_986203247097_item	3548502	et	4	main
eest	doc_986203247097_item	3548503	et	4	main
laevasõit	doc_986203247097_item	3548504	et	3	main
minna	doc_986203247097_item	3548511	et	3	main
kirjutage	doc_986203247095_item	3548104	et	3	main
reisi	doc_986203247095_item	3548183	et	4	main
sellepärast	doc_986203247095_item	3548184	et	3	main
et	doc_986203247095_item	3548185	et	3	main
kasti	doc_986203247095_item	3548106	et	4	main
kirja	doc_986203247095_item	3548108	et	4	main
te	doc_986203247095_item	3548118	et	4	main
olete	doc_986203247095_item	3548119	et	3	main
õpilaste	doc_986203247095_item	3548126	et	4	main
maria	doc_986203247095_item	3548133	et	4	main
teatribilet	doc_986203247095_item	3548151	et	4	main
hommiku-	doc_986203247095_item	3548152	et	3	main
ja	doc_986203247095_item	3548153	et	3	main
lõunasöök	doc_986203247095_item	3548154	et	3	main
linnaekskursioon	doc_986203247095_item	3548155	et	3	main
kohaliku	doc_986203247095_item	3548156	et	3	main
ermitaaži	doc_986203247095_item	3548159	et	2	main
kindluse	doc_986203247095_item	3548162	et	4	main
külastamine	doc_986203247095_item	3548163	et	4	main
kõig	doc_986203247095_item	3548170	et	4	main
tahavad	doc_986203247095_item	3548171	et	3	main
minna	doc_986203247095_item	3548172	et	3	main
sellepärast	doc_986203247095_item	3548173	et	3	main
meile	doc_986203247095_item	3548177	et	4	main
hinnasoodus	doc_986203247095_item	3548178	et	3	main
me	doc_986203247095_item	3548180	et	4	main
venemaal	doc_986203247095_item	3548200	et	4	main
ekskursioonile	doc_986203247095_item	3548201	et	3	main
sõita	doc_986203247095_item	3548202	et	3	main
aga	doc_986203247095_item	3548203	et	3	main
kui	doc_986203247095_item	3548204	et	3	main
kegi	doc_986203247095_item	3548205	et	4	main
sõidab	doc_986203247095_item	3548206	et	3	main
sinna	doc_986203247095_item	3548207	et	3	main
poole	doc_986203247095_item	3548208	et	4	main
selles	doc_986203247095_item	3548209	et	4	main
on	doc_986203247095_item	3548210	et	4	main
tööpõhjus	doc_986203247095_item	3548211	et	4	main
aga	doc_986203247095_item	3548212	et	3	main
mitte	doc_986203247095_item	3548213	et	3	main
vabaaeg	doc_986203247095_item	3548214	et	3	main
me	doc_986203247095_item	3548215	et	4	main
valisime	doc_986203247095_item	3548216	et	3	main
selle	doc_986203247095_item	3548217	et	4	main
reisi	doc_986203247095_item	3548218	et	4	main
sellepärast	doc_986203247095_item	3548219	et	3	main
me	doc_986203247095_item	3548221	et	4	main
grupile	doc_986203247095_item	3548227	et	3	main
on	doc_986203247095_item	3548228	et	4	main
kirjutage	doc_986203247095_item	3548238	et	3	main
nõutav	doc_986203247097_item	3548393	et	4	main
lugupeetud	doc_986203247097_item	3548399	et	4	main
tots	doc_986203247097_item	3548400	et	3	main
me	doc_986203247097_item	3548409	et	4	main
me	doc_986203247097_item	3548416	et	4	main
tahame	doc_986203247097_item	3548417	et	3	main
et	doc_986203247097_item	3548418	et	3	main
meie	doc_986203247097_item	3548419	et	4	main
toetanud	doc_986203247097_item	3548428	et	4	main
me	doc_986203247097_item	3548436	et	4	main
see	doc_986203247097_item	3548440	et	3	main
21	doc_986203247097_item	3548443	et	2	main
tuhat	doc_986203247097_item	3548458	et	4	main
kakskümmend	doc_986203247097_item	3548473	et	4	main
inimest	doc_986203247097_item	3548474	et	3	main
on	doc_986203247097_item	3548482	et	4	main
linnaekskursioon	doc_986203247097_item	3548492	et	3	main
giidi	doc_986203247097_item	3548494	et	4	main
ermitaaži	doc_986203247097_item	3548496	et	2	main
reisile	doc_986203247097_item	3548510	et	3	main
huvitav	doc_986203247097_item	3548515	et	4	main
palju	doc_986203247097_item	3548519	et	4	main
võimalusi	doc_986203247097_item	3548520	et	3	main
jääme	doc_986203247097_item	3548522	et	4	main
lootma	doc_986203247097_item	3548523	et	3	main
teie	doc_986203247097_item	3548524	et	4	main
abile	doc_986203247097_item	3548525	et	3	main
ärge	doc_986203247097_item	3548526	et	3	main
kirjutage	doc_986203247097_item	3548527	et	3	main
kiri	doc_986203247100_item	3548532	et	3	main
u	doc_986203247100_item	3548541	et	4	main
kultuuri	doc_986203247100_item	3548548	et	4	main
ja	doc_986203247100_item	3548554	et	3	main
tegevusega	doc_986203247100_item	3548563	et	4	main
kus	doc_986203247100_item	3548564	et	3	main
oli	doc_986203247100_item	3548568	et	3	main
teatrite	doc_986203247100_item	3548570	et	3	main
kandis	doc_986203247100_item	3548573	et	4	main
klassi	doc_986203247100_item	3548591	et	4	main
õpilased	doc_986203247100_item	3548592	et	3	main
nägemisega	doc_986203247100_item	3548603	et	4	main
see	doc_986203247100_item	3548604	et	3	main
kindlasti	doc_986203247100_item	3548605	et	3	main
aitaks	doc_986203247100_item	3548606	et	3	main
meie	doc_986203247100_item	3548607	et	4	main
hinnad	doc_986203247100_item	3548635	et	3	main
on	doc_986203247100_item	3548636	et	4	main
kõige	doc_986203247100_item	3548637	et	4	main
sest	doc_986203247100_item	3548645	et	4	main
meie	doc_986203247100_item	3548649	et	4	main
õppimist	doc_986203247100_item	3548650	et	4	main
nõutav	doc_986203247102_item	3548722	et	4	main
pikkus	doc_986203247102_item	3548723	et	4	main
sponsor	doc_986203247102_item	3548729	et	3	main
me	doc_986203247102_item	3548730	et	4	main
grupiga	doc_986203247102_item	3548731	et	3	main
lugesime	doc_986203247102_item	3548732	et	3	main
ajalehest	doc_986203247102_item	3548733	et	4	main
on	doc_986203247102_item	3548757	et	4	main
hommiku-	doc_986203247102_item	3548769	et	3	main
ja	doc_986203247102_item	3548773	et	3	main
kiri	doc_986203247097_item	3548387	et	3	main
oma	doc_986203247097_item	3548411	et	4	main
sponsor	doc_986203247097_item	3548422	et	3	main
sooviksid	doc_986203247097_item	3548431	et	4	main
üldse	doc_986203247097_item	3548452	et	3	main
krooni	doc_986203247097_item	3548459	et	4	main
vaja	doc_986203247097_item	3548462	et	4	main
sõita	doc_986203247097_item	3548477	et	3	main
edasi	doc_986203247097_item	3548478	et	3	main
meil	doc_986203247097_item	3548481	et	4	main
ka	doc_986203247097_item	3548483	et	3	main
teatripiletid	doc_986203247097_item	3548484	et	3	main
juba	doc_986203247097_item	3548485	et	3	main
väga	doc_986203247097_item	3548507	et	3	main
sooviksid	doc_986203247097_item	3548508	et	4	main
reisibüroo	doc_986203247097_item	3548513	et	4	main
me	doc_986203247097_item	3548521	et	4	main
joonest	doc_986203247097_item	3548529	et	4	main
joonitud	doc_986203247100_item	3548534	et	4	main
ajaloo	doc_986203247100_item	3548549	et	4	main
meie	doc_986203247100_item	3548551	et	4	main
huvitavat	doc_986203247100_item	3548555	et	4	main
millal	doc_986203247100_item	3548565	et	3	main
selles	doc_986203247100_item	3548572	et	4	main
selle	doc_986203247100_item	3548574	et	4	main
õppetöö	doc_986203247100_item	3548575	et	4	main
on	doc_986203247100_item	3548581	et	4	main
tahaksime	doc_986203247100_item	3548596	et	3	main
kinnitada	doc_986203247100_item	3548597	et	3	main
meie	doc_986203247100_item	3548598	et	4	main
kinni	doc_986203247100_item	3548610	et	3	main
soodsamad	doc_986203247100_item	3548638	et	4	main
see	doc_986203247100_item	3548646	et	3	main
katkesta	doc_986203247100_item	3548648	et	4	main
joonitud	doc_986203247102_item	3548718	et	4	main
u	doc_986203247102_item	3548725	et	4	main
100	doc_986203247102_item	3548726	et	2	main
sõna	doc_986203247102_item	3548727	et	4	main
reisibüroo	doc_986203247102_item	3548736	et	4	main
reis	doc_986203247102_item	3548756	et	4	main
kahepäevane	doc_986203247102_item	3548758	et	4	main
sinna	doc_986203247102_item	3548760	et	3	main
peeter-pauli	doc_986203247102_item	3548774	et	4	main
kindluse	doc_986203247102_item	3548775	et	4	main
linnast	doc_986203247102_item	3548793	et	4	main
22	doc_986203247102_item	3548808	et	2	main
vähemalt	doc_986203247102_item	3548819	et	4	main
inimest	doc_986203247102_item	3548821	et	3	main
on	doc_986203247102_item	3548822	et	4	main
hinnaalandus	doc_986203247102_item	3548823	et	3	main
grupp	doc_986203247102_item	3548837	et	3	main
sõita	doc_986203247102_item	3548840	et	3	main
ja	doc_986203247104_item	3548879	et	3	main
ei	doc_986203247104_item	3548885	et	4	main
pöörguda	doc_986203247104_item	3548894	et	4	main
peterburi	doc_986203247104_item	3548902	et	4	main
pange	doc_986203247104_item	3548915	et	4	main
vähemalt	doc_986203247104_item	3548919	et	4	main
linnaekskursioon	doc_986203247104_item	3548933	et	3	main
kohaliku	doc_986203247104_item	3548934	et	3	main
ermitaaži	doc_986203247104_item	3548937	et	2	main
kunagil	doc_986203247104_item	3548949	et	4	main
saime	doc_986203247104_item	3548954	et	3	main
vene	doc_986203247104_item	3548957	et	4	main
1500	doc_986203247097_item	3548469	et	2	main
kirjutage	doc_986203247097_item	3548388	et	3	main
kasti	doc_986203247097_item	3548390	et	4	main
sisse	doc_986203247097_item	3548391	et	4	main
kirja	doc_986203247097_item	3548392	et	4	main
100	doc_986203247097_item	3548397	et	2	main
sõna	doc_986203247097_item	3548398	et	4	main
koolikaaslastega	doc_986203247097_item	3548412	et	4	main
koolil	doc_986203247097_item	3548420	et	4	main
on	doc_986203247097_item	3548424	et	4	main
reisi	doc_986203247097_item	3548426	et	4	main
alati	doc_986203247097_item	3548427	et	4	main
sõita	doc_986203247097_item	3548432	et	3	main
sõita	doc_986203247097_item	3548438	et	3	main
algab	doc_986203247097_item	3548442	et	3	main
juuni	doc_986203247097_item	3548445	et	4	main
meie	doc_986203247097_item	3548447	et	4	main
soobivusaeg	doc_986203247097_item	3548448	et	4	main
on	doc_986203247097_item	3548449	et	4	main
teatrireis	doc_986203247097_item	3548454	et	4	main
maksab	doc_986203247097_item	3548455	et	3	main
000	doc_986203247097_item	3548457	et	2	main
meil	doc_986203247097_item	3548460	et	4	main
see	doc_986203247097_item	3548463	et	3	main
summa	doc_986203247097_item	3548464	et	4	main
umbes	doc_986203247097_item	3548465	et	4	main
üks	doc_986203247097_item	3548466	et	3	main
pilet	doc_986203247097_item	3548467	et	3	main
maksab	doc_986203247097_item	3548468	et	3	main
krooni	doc_986203247097_item	3548470	et	4	main
meil	doc_986203247097_item	3548471	et	4	main
on	doc_986203247097_item	3548472	et	4	main
tagasi	doc_986203247097_item	3548479	et	3	main
hinna	doc_986203247097_item	3548487	et	3	main
kuulutust	doc_986203247097_item	3548405	et	4	main
ning	doc_986203247097_item	3548406	et	3	main
arvame	doc_986203247097_item	3548407	et	3	main
et	doc_986203247097_item	3548408	et	3	main
sellele	doc_986203247097_item	3548413	et	4	main
reisile	doc_986203247097_item	3548414	et	3	main
minna	doc_986203247097_item	3548415	et	3	main
kes	doc_986203247097_item	3548423	et	4	main
meie	doc_986203247097_item	3548429	et	4	main
kooligrupp	doc_986203247097_item	3548430	et	3	main
peterburi	doc_986203247097_item	3548433	et	4	main
maria	doc_986203247097_item	3548434	et	4	main
teatrisse	doc_986203247097_item	3548435	et	3	main
rongiga	doc_986203247097_item	3548439	et	4	main
kõik	doc_986203247097_item	3548453	et	4	main
30	doc_986203247097_item	3548456	et	2	main
on	doc_986203247097_item	3548461	et	4	main
sooviksime	doc_986203247097_item	3548476	et	4	main
rongipiletiga	doc_986203247097_item	3548480	et	3	main
hommiku-	doc_986203247097_item	3548489	et	3	main
lõunasöök	doc_986203247097_item	3548491	et	3	main
kohaliku	doc_986203247097_item	3548493	et	3	main
külastamine	doc_986203247097_item	3548500	et	4	main
veel	doc_986203247097_item	3548501	et	4	main
sellele	doc_986203247097_item	3548509	et	4	main
on	doc_986203247097_item	3548518	et	4	main
kirjutage	doc_986203247100_item	3548533	et	3	main
100	doc_986203247100_item	3548542	et	2	main
sõna	doc_986203247100_item	3548543	et	4	main
õppetöö	doc_986203247100_item	3548546	et	4	main
käigus	doc_986203247100_item	3548547	et	4	main
saime	doc_986203247100_item	3548552	et	3	main
teoreetilist	doc_986203247100_item	3548556	et	3	main
mis	doc_986203247100_item	3548558	et	4	main
ja	doc_986203247100_item	3548566	et	3	main
on	doc_986203247100_item	3548577	et	4	main
120	doc_986203247100_item	3548578	et	2	main
t	doc_986203247100_item	3548585	et	4	main
ja	doc_986203247100_item	3548586	et	3	main
seoses	doc_986203247100_item	3548587	et	4	main
õppetöö	doc_986203247100_item	3548588	et	4	main
teadmisi	doc_986203247100_item	3548599	et	4	main
ka	doc_986203247100_item	3548600	et	3	main
oma	doc_986203247100_item	3548601	et	4	main
silmade	doc_986203247100_item	3548602	et	3	main
reisi	doc_986203247100_item	3548639	et	4	main
seoses	doc_986203247100_item	3548651	et	4	main
sellega	doc_986203247100_item	3548652	et	3	main
et	doc_986203247100_item	3548653	et	3	main
kindluse	doc_986203247097_item	3548499	et	4	main
meie	doc_986203247097_item	3548505	et	4	main
kooligrupp	doc_986203247097_item	3548506	et	3	main
see	doc_986203247097_item	3548512	et	3	main
sellest	doc_986203247097_item	3548528	et	4	main
allapoole	doc_986203247097_item	3548530	et	3	main
sisse	doc_986203247100_item	3548536	et	4	main
kirja	doc_986203247100_item	3548537	et	4	main
pikkus	doc_986203247100_item	3548539	et	4	main
on	doc_986203247100_item	3548540	et	4	main
lp	doc_986203247100_item	3548544	et	4	main
peterburi	doc_986203247100_item	3548561	et	4	main
teatrite	doc_986203247100_item	3548562	et	3	main
kestvus	doc_986203247100_item	3548576	et	4	main
läbi	doc_986203247100_item	3548582	et	4	main
juba	doc_986203247100_item	3548583	et	3	main
95	doc_986203247100_item	3548584	et	2	main
lõppemisega	doc_986203247100_item	3548589	et	4	main
meie	doc_986203247100_item	3548590	et	4	main
mälus	doc_986203247100_item	3548608	et	4	main
tuntud	doc_986203247100_item	3548632	et	4	main
ja	doc_986203247100_item	3548634	et	3	main
aeg	doc_986203247100_item	3548640	et	3	main
on	doc_986203247100_item	3548641	et	4	main
ka	doc_986203247100_item	3548642	et	3	main
väga	doc_986203247100_item	3548643	et	3	main
sobiv	doc_986203247100_item	3548644	et	4	main
kiri	doc_986203247102_item	3548716	et	3	main
kasti	doc_986203247102_item	3548719	et	4	main
on	doc_986203247102_item	3548724	et	4	main
teatrireisi	doc_986203247102_item	3548739	et	4	main
peterburi	doc_986203247102_item	3548740	et	4	main
teatripiletid	doc_986203247102_item	3548768	et	3	main
lõunasöök	doc_986203247102_item	3548771	et	3	main
sees	doc_986203247102_item	3548780	et	4	main
giidi	doc_986203247102_item	3548786	et	4	main
ta	doc_986203247102_item	3548788	et	4	main
ütleb	doc_986203247102_item	3548789	et	3	main
meile	doc_986203247102_item	3548790	et	4	main
ja	doc_986203247102_item	3548794	et	3	main
reis	doc_986203247102_item	3548798	et	4	main
inimest	doc_986203247102_item	3548809	et	3	main
aga	doc_986203247102_item	3548817	et	3	main
grupile	doc_986203247102_item	3548818	et	3	main
22	doc_986203247102_item	3548820	et	2	main
ja	doc_986203247102_item	3548826	et	3	main
reis	doc_986203247102_item	3548829	et	4	main
maksab	doc_986203247102_item	3548830	et	3	main
kiri	doc_986203247104_item	3548861	et	3	main
joonitud	doc_986203247104_item	3548863	et	4	main
kasti	doc_986203247104_item	3548864	et	4	main
on	doc_986203247104_item	3548869	et	4	main
u	doc_986203247104_item	3548870	et	4	main
100	doc_986203247104_item	3548871	et	2	main
nagu	doc_986203247104_item	3548880	et	3	main
õpilased	doc_986203247104_item	3548883	et	3	main
ja	doc_986203247104_item	3548890	et	3	main
otsustasime	doc_986203247104_item	3548891	et	3	main
et	doc_986203247104_item	3548917	et	3	main
inimest	doc_986203247104_item	3548921	et	3	main
20	doc_986203247104_item	3548923	et	2	main
sees	doc_986203247104_item	3548925	et	4	main
teatripiletid	doc_986203247104_item	3548929	et	3	main
juhtimisel	doc_986203247104_item	3548936	et	4	main
ja	doc_986203247104_item	3548938	et	3	main
valisime	doc_986203247104_item	3548943	et	3	main
reisi	doc_986203247104_item	3548945	et	4	main
sest	doc_986203247104_item	3548946	et	4	main
teatrid	doc_986203247104_item	3548958	et	3	main
väga	doc_986203247104_item	3548960	et	3	main
ilus	doc_986203247104_item	3548965	et	4	main
peeter-pauli	doc_986203247104_item	3548971	et	4	main
arvame	doc_986203247104_item	3548973	et	3	main
kohe	doc_986203247104_item	3549008	et	4	main
juba	doc_986203247104_item	3549012	et	3	main
lugupidamisega	doc_986203247104_item	3549014	et	3	main
s	doc_986203247104_item	3549016	et	4	main
ärge	doc_986203247104_item	3549018	et	3	main
pakkub	doc_986203247097_item	3548514	et	4	main
reis	doc_986203247097_item	3548516	et	4	main
seal	doc_986203247097_item	3548517	et	4	main
meie	doc_986203247100_item	3548693	et	4	main
taotlus	doc_986203247100_item	3548694	et	4	main
on	doc_986203247100_item	3548695	et	4	main
teid	doc_986203247100_item	3548696	et	4	main
veendunud	doc_986203247100_item	3548697	et	4	main
ja	doc_986203247100_item	3548698	et	3	main
ootame	doc_986203247100_item	3548699	et	3	main
teie	doc_986203247100_item	3548700	et	4	main
abi	doc_986203247100_item	3548701	et	4	main
25	doc_986203247100_item	3548702	et	2	main
mai	doc_986203247100_item	3548703	et	4	main
2002	doc_986203247100_item	3548704	et	2	main
a	doc_986203247100_item	3548705	et	4	main
10	doc_986203247100_item	3548706	et	2	main
a	doc_986203247100_item	3548707	et	4	main
kl-si	doc_986203247100_item	3548708	et	4	main
õpilased	doc_986203247100_item	3548709	et	3	main
ärge	doc_986203247100_item	3548710	et	3	main
kirjutage	doc_986203247100_item	3548711	et	3	main
sellest	doc_986203247100_item	3548712	et	4	main
joonest	doc_986203247100_item	3548713	et	4	main
allapoole	doc_986203247100_item	3548714	et	3	main
kasti	doc_986203247100_item	3548535	et	4	main
nõutav	doc_986203247100_item	3548538	et	4	main
sponsor	doc_986203247100_item	3548545	et	3	main
tunnil	doc_986203247100_item	3548550	et	3	main
suurt	doc_986203247100_item	3548553	et	3	main
kogemust	doc_986203247100_item	3548557	et	3	main
on	doc_986203247100_item	3548559	et	4	main
seotud	doc_986203247100_item	3548560	et	4	main
kuidas	doc_986203247100_item	3548567	et	3	main
alustatud	doc_986203247100_item	3548569	et	4	main
tegevus	doc_986203247100_item	3548571	et	4	main
tundi	doc_986203247100_item	3548579	et	4	main
meil	doc_986203247100_item	3548580	et	4	main
10	doc_986203247100_item	3548593	et	2	main
a	doc_986203247100_item	3548594	et	4	main
klass	doc_986203247100_item	3548595	et	3	main
paremini	doc_986203247100_item	3548609	et	4	main
hoida	doc_986203247100_item	3548611	et	3	main
kõike	doc_986203247100_item	3548612	et	4	main
seda	doc_986203247100_item	3548613	et	3	main
mis	doc_986203247100_item	3548614	et	4	main
oleme	doc_986203247100_item	3548615	et	3	main
tunnites	doc_986203247100_item	3548616	et	4	main
suure	doc_986203247100_item	3548617	et	3	main
huviga	doc_986203247100_item	3548618	et	3	main
läbi	doc_986203247100_item	3548619	et	4	main
rääginud	doc_986203247100_item	3548620	et	4	main
meie	doc_986203247100_item	3548621	et	4	main
arvatest	doc_986203247100_item	3548622	et	3	main
kõige	doc_986203247100_item	3548623	et	4	main
sobim	doc_986203247100_item	3548624	et	4	main
reis	doc_986203247100_item	3548625	et	4	main
oleks	doc_986203247100_item	3548626	et	3	main
reisibüroo-st	doc_986203247100_item	3548627	et	3	main
elenringi	doc_986203247100_item	3548628	et	4	main
oma	doc_986203247100_item	3548629	et	4	main
see	doc_986203247100_item	3548630	et	3	main
on	doc_986203247100_item	3548631	et	4	main
reisibüroo	doc_986203247100_item	3548633	et	4	main
ei	doc_986203247100_item	3548647	et	4	main
meie	doc_986203247100_item	3548654	et	4	main
klassis	doc_986203247100_item	3548655	et	3	main
on	doc_986203247100_item	3548656	et	4	main
23	doc_986203247100_item	3548657	et	2	main
inimest	doc_986203247100_item	3548658	et	3	main
meie	doc_986203247100_item	3548659	et	4	main
rühm	doc_986203247100_item	3548660	et	3	main
saab	doc_986203247100_item	3548661	et	3	main
veel	doc_986203247100_item	3548662	et	4	main
20st	doc_986203247100_item	3548663	et	3	main
allahindlust	doc_986203247100_item	3548664	et	4	main
see	doc_986203247100_item	3548665	et	3	main
on	doc_986203247100_item	3548666	et	4	main
suurepäärane	doc_986203247100_item	3548667	et	4	main
võimalus	doc_986203247100_item	3548668	et	3	main
meie	doc_986203247100_item	3548669	et	4	main
õpilastele	doc_986203247100_item	3548670	et	4	main
kõigis	doc_986203247100_item	3548671	et	4	main
mõttes	doc_986203247100_item	3548672	et	3	main
kui	doc_986203247100_item	3548673	et	3	main
meile	doc_986203247100_item	3548674	et	4	main
ei	doc_986203247100_item	3548675	et	4	main
sobiks	doc_986203247100_item	3548676	et	4	main
meie	doc_986203247100_item	3548677	et	4	main
ei	doc_986203247100_item	3548678	et	4	main
vajaksime	doc_986203247100_item	3548679	et	3	main
see	doc_986203247100_item	3548680	et	3	main
reis	doc_986203247100_item	3548681	et	4	main
nii	doc_986203247100_item	3548682	et	3	main
hästi	doc_986203247100_item	3548683	et	3	main
siis	doc_986203247100_item	3548684	et	3	main
meie	doc_986203247100_item	3548685	et	4	main
ei	doc_986203247100_item	3548686	et	4	main
julgeks	doc_986203247100_item	3548687	et	4	main
teid	doc_986203247100_item	3548688	et	4	main
segada	doc_986203247100_item	3548689	et	3	main
meie	doc_986203247100_item	3548690	et	4	main
loodame	doc_986203247100_item	3548691	et	3	main
et	doc_986203247100_item	3548692	et	3	main
lugupeetud	doc_986203247102_item	3548728	et	4	main
ellenring	doc_986203247102_item	3548737	et	4	main
korraldab	doc_986203247102_item	3548738	et	3	main
maksaks	doc_986203247102_item	3548812	et	4	main
kolmkümmend	doc_986203247102_item	3548813	et	4	main
kolm	doc_986203247102_item	3548814	et	3	main
tuhat	doc_986203247102_item	3548815	et	4	main
kirjutage	doc_986203247102_item	3548717	et	3	main
sisse	doc_986203247102_item	3548720	et	4	main
kirja	doc_986203247102_item	3548721	et	4	main
kuulutust	doc_986203247102_item	3548734	et	4	main
et	doc_986203247102_item	3548735	et	3	main
maria	doc_986203247102_item	3548741	et	4	main
teatrisse	doc_986203247102_item	3548742	et	3	main
ja	doc_986203247102_item	3548743	et	3	main
mõtlesime	doc_986203247102_item	3548744	et	3	main
et	doc_986203247102_item	3548745	et	3	main
võiksime	doc_986203247102_item	3548746	et	3	main
oma	doc_986203247102_item	3548747	et	4	main
koolikaaslastega	doc_986203247102_item	3548748	et	4	main
sellele	doc_986203247102_item	3548749	et	4	main
reisile	doc_986203247102_item	3548750	et	3	main
minna	doc_986203247102_item	3548751	et	3	main
ja	doc_986203247102_item	3548752	et	3	main
arvestame	doc_986203247102_item	3548753	et	3	main
teie	doc_986203247102_item	3548754	et	4	main
rongiga	doc_986203247102_item	3548759	et	4	main
poole	doc_986203247102_item	3548761	et	4	main
ja	doc_986203247102_item	3548762	et	3	main
tagasi	doc_986203247102_item	3548763	et	3	main
hinna	doc_986203247102_item	3548764	et	3	main
sees	doc_986203247102_item	3548765	et	4	main
reisi	doc_986203247102_item	3548778	et	4	main
hinna	doc_986203247102_item	3548779	et	3	main
on	doc_986203247102_item	3548781	et	4	main
linnaekskursioon	doc_986203247102_item	3548782	et	3	main
mis	doc_986203247102_item	3548783	et	4	main
on	doc_986203247102_item	3548784	et	4	main
juhtimisel	doc_986203247102_item	3548787	et	4	main
kõige	doc_986203247102_item	3548795	et	4	main
selle	doc_986203247102_item	3548796	et	4	main
maksab	doc_986203247102_item	3548799	et	3	main
inimesele	doc_986203247102_item	3548801	et	3	main
krooni	doc_986203247102_item	3548803	et	4	main
aga	doc_986203247102_item	3548804	et	3	main
meie	doc_986203247102_item	3548805	et	4	main
grupp	doc_986203247102_item	3548806	et	3	main
kakskümend	doc_986203247102_item	3548824	et	4	main
sisse	doc_986203247104_item	3548865	et	4	main
kirja	doc_986203247104_item	3548866	et	4	main
sõna	doc_986203247104_item	3548872	et	4	main
oleme	doc_986203247104_item	3548882	et	3	main
teie	doc_986203247104_item	3548892	et	4	main
ettendus	doc_986203247104_item	3548905	et	4	main
toimub	doc_986203247104_item	3548906	et	3	main
2122	doc_986203247104_item	3548907	et	2	main
juunil	doc_986203247104_item	3548908	et	3	main
pilet	doc_986203247104_item	3548909	et	3	main
1500	doc_986203247104_item	3548911	et	2	main
hommiku-	doc_986203247104_item	3548930	et	3	main
me	doc_986203247104_item	3548942	et	4	main
selle	doc_986203247104_item	3548944	et	4	main
ei	doc_986203247104_item	3548950	et	4	main
ja	doc_986203247104_item	3548953	et	3	main
et	doc_986203247104_item	3548956	et	3	main
peterburg	doc_986203247104_item	3548963	et	4	main
me	doc_986203247104_item	3548972	et	4	main
et	doc_986203247104_item	3548974	et	3	main
sest	doc_986203247104_item	3549009	et	4	main
19112002	doc_986203247104_item	3549017	et	2	main
sellest	doc_986203247104_item	3549020	et	4	main
kiri	doc_986203247106_item	3549149	et	3	main
u	doc_986203247106_item	3549158	et	4	main
lugupeetud	doc_986203247106_item	3549161	et	4	main
ma	doc_986203247106_item	3549163	et	3	main
mulle	doc_986203247106_item	3549168	et	4	main
tahaks	doc_986203247106_item	3549170	et	3	main
koolikaaslastega	doc_986203247106_item	3549172	et	4	main
see	doc_986203247106_item	3549176	et	3	main
organiseerib	doc_986203247106_item	3549178	et	3	main
reisibüroo	doc_986203247106_item	3549179	et	4	main
ellenring	doc_986203247106_item	3549180	et	4	main
ja	doc_986203247106_item	3549181	et	3	main
see	doc_986203247106_item	3549182	et	3	main
vähemalt	doc_986203247106_item	3549200	et	4	main
22	doc_986203247106_item	3549201	et	2	main
inimest	doc_986203247106_item	3549202	et	3	main
sees	doc_986203247106_item	3549206	et	4	main
rongipilet	doc_986203247106_item	3549208	et	3	main
hommiku	doc_986203247106_item	3549210	et	3	main
lõunasöök	doc_986203247106_item	3549212	et	3	main
eest	doc_986203247106_item	3549223	et	4	main
võib	doc_986203247106_item	3549224	et	3	main
kiri	doc_986203247108_item	3549275	et	3	main
kirja	doc_986203247108_item	3549280	et	4	main
lugesime	doc_986203247108_item	3549290	et	3	main
ajalehest	doc_986203247108_item	3549291	et	4	main
reisile	doc_986203247108_item	3549298	et	3	main
selle	doc_986203247108_item	3549300	et	4	main
on	doc_986203247108_item	3549307	et	4	main
peterburi	doc_986203247108_item	3549308	et	4	main
maria	doc_986203247108_item	3549309	et	4	main
teatrisse	doc_986203247108_item	3549310	et	3	main
juuni	doc_986203247108_item	3549314	et	4	main
maksab	doc_986203247108_item	3549316	et	3	main
krooni	doc_986203247108_item	3549318	et	4	main
meil	doc_986203247108_item	3549321	et	4	main
abil	doc_986203247102_item	3548755	et	4	main
on	doc_986203247102_item	3548766	et	4	main
samuti	doc_986203247102_item	3548767	et	3	main
ja	doc_986203247102_item	3548770	et	3	main
ermitaaži	doc_986203247102_item	3548772	et	2	main
külastamine	doc_986203247102_item	3548776	et	4	main
samuti	doc_986203247102_item	3548777	et	3	main
kõik	doc_986203247102_item	3548791	et	4	main
eest	doc_986203247102_item	3548797	et	4	main
ühe	doc_986203247102_item	3548800	et	4	main
1500	doc_986203247102_item	3548802	et	2	main
ja	doc_986203247102_item	3548810	et	3	main
krooni	doc_986203247102_item	3548816	et	4	main
protsenti	doc_986203247102_item	3548825	et	4	main
pärast	doc_986203247102_item	3548828	et	4	main
kolmkümmend	doc_986203247102_item	3548831	et	4	main
tuhat	doc_986203247102_item	3548832	et	4	main
väga	doc_986203247102_item	3548838	et	3	main
kirjutage	doc_986203247104_item	3548862	et	3	main
pikkus	doc_986203247104_item	3548868	et	4	main
me	doc_986203247104_item	3548881	et	4	main
meil	doc_986203247104_item	3548884	et	4	main
ole	doc_986203247104_item	3548886	et	4	main
nii	doc_986203247104_item	3548887	et	3	main
palju	doc_986203247104_item	3548888	et	4	main
poole	doc_986203247104_item	3548893	et	4	main
maksab	doc_986203247104_item	3548910	et	3	main
krooni	doc_986203247104_item	3548912	et	4	main
kallis	doc_986203247104_item	3548913	et	4	main
sponsor	doc_986203247104_item	3548914	et	3	main
grupile	doc_986203247104_item	3548918	et	3	main
22	doc_986203247104_item	3548920	et	2	main
hinnaalandus	doc_986203247104_item	3548922	et	3	main
hinna	doc_986203247104_item	3548924	et	3	main
on	doc_986203247104_item	3548926	et	4	main
edasi-tagasi	doc_986203247104_item	3548927	et	3	main
rongipilet	doc_986203247104_item	3548928	et	3	main
ja	doc_986203247104_item	3548931	et	3	main
giidi	doc_986203247104_item	3548935	et	4	main
peeter-pauli	doc_986203247104_item	3548939	et	4	main
kindluse	doc_986203247104_item	3548940	et	4	main
olnud	doc_986203247104_item	3548951	et	4	main
venemaal	doc_986203247104_item	3548952	et	4	main
teada	doc_986203247104_item	3548955	et	3	main
on	doc_986203247104_item	3548959	et	4	main
huvitavad	doc_986203247104_item	3548961	et	4	main
ermitaaži	doc_986203247104_item	3548969	et	2	main
kirjutage	doc_986203247106_item	3549150	et	3	main
on	doc_986203247106_item	3549157	et	4	main
sõna	doc_986203247106_item	3549160	et	4	main
sponsor	doc_986203247106_item	3549162	et	3	main
ajalehest	doc_986203247106_item	3549165	et	4	main
kuulutust	doc_986203247106_item	3549166	et	4	main
minna	doc_986203247106_item	3549175	et	3	main
krooni	doc_986203247106_item	3549196	et	4	main
aga	doc_986203247106_item	3549197	et	3	main
kui	doc_986203247106_item	3549198	et	3	main
gruppa	doc_986203247106_item	3549199	et	4	main
giidi	doc_986203247106_item	3549215	et	4	main
osta	doc_986203247106_item	3549225	et	4	main
laevasõit	doc_986203247106_item	3549226	et	3	main
et	doc_986203247106_item	3549229	et	3	main
joonitud	doc_986203247108_item	3549277	et	4	main
pikkus	doc_986203247108_item	3549282	et	4	main
austatud	doc_986203247108_item	3549287	et	4	main
sponsor	doc_986203247108_item	3549288	et	3	main
me	doc_986203247108_item	3549289	et	4	main
minna	doc_986203247108_item	3549299	et	3	main
reisi	doc_986203247108_item	3549301	et	4	main
reisibüroo	doc_986203247108_item	3549303	et	4	main
reisiaeg	doc_986203247108_item	3549311	et	3	main
kohaliku	doc_986203247102_item	3548785	et	3	main
peterburi	doc_986203247102_item	3548792	et	4	main
on	doc_986203247102_item	3548807	et	4	main
reis	doc_986203247102_item	3548811	et	4	main
selle	doc_986203247102_item	3548827	et	4	main
krooni	doc_986203247102_item	3548833	et	4	main
lugupeetud	doc_986203247102_item	3548834	et	4	main
sponsor	doc_986203247102_item	3548835	et	3	main
meie	doc_986203247102_item	3548836	et	4	main
tahab	doc_986203247102_item	3548839	et	3	main
selle	doc_986203247102_item	3548841	et	4	main
reisile	doc_986203247102_item	3548842	et	3	main
ja	doc_986203247102_item	3548843	et	3	main
palub	doc_986203247102_item	3548844	et	3	main
teilt	doc_986203247102_item	3548845	et	4	main
materiaalne	doc_986203247102_item	3548846	et	3	main
toetust	doc_986203247102_item	3548847	et	4	main
me	doc_986203247102_item	3548848	et	4	main
arvestame	doc_986203247102_item	3548849	et	3	main
teie	doc_986203247102_item	3548850	et	4	main
abil	doc_986203247102_item	3548851	et	4	main
12	doc_986203247102_item	3548852	et	2	main
a	doc_986203247102_item	3548853	et	4	main
klass	doc_986203247102_item	3548854	et	3	main
ärge	doc_986203247102_item	3548855	et	3	main
kirjutage	doc_986203247102_item	3548856	et	3	main
sellest	doc_986203247102_item	3548857	et	4	main
joonest	doc_986203247102_item	3548858	et	4	main
allapoole	doc_986203247102_item	3548859	et	3	main
nõutav	doc_986203247104_item	3548867	et	4	main
lugupeetud	doc_986203247104_item	3548873	et	4	main
sponsor	doc_986203247104_item	3548874	et	3	main
otsustasime	doc_986203247104_item	3548875	et	3	main
koolikaaslastega	doc_986203247104_item	3548876	et	4	main
reisile	doc_986203247104_item	3548877	et	3	main
minna	doc_986203247104_item	3548878	et	3	main
raha	doc_986203247104_item	3548889	et	4	main
ja	doc_986203247104_item	3548895	et	3	main
küsida	doc_986203247104_item	3548896	et	3	main
abi	doc_986203247104_item	3548897	et	4	main
reisibüroo	doc_986203247104_item	3548898	et	4	main
ellenring	doc_986203247104_item	3548899	et	4	main
korraldab	doc_986203247104_item	3548900	et	3	main
teatrireisi	doc_986203247104_item	3548901	et	4	main
maria	doc_986203247104_item	3548903	et	4	main
teatrisse	doc_986203247104_item	3548904	et	3	main
tähele	doc_986203247104_item	3548916	et	3	main
lõunasöök	doc_986203247104_item	3548932	et	3	main
külastamine	doc_986203247104_item	3548941	et	4	main
me	doc_986203247104_item	3548947	et	4	main
mitte	doc_986203247104_item	3548948	et	3	main
samuti	doc_986203247104_item	3548962	et	3	main
linn	doc_986203247104_item	3548966	et	3	main
külastada	doc_986203247104_item	3548968	et	3	main
homme	doc_986203247104_item	3549010	et	3	main
nõutav	doc_986203247106_item	3549155	et	4	main
on	doc_986203247106_item	3549183	et	4	main
maria	doc_986203247106_item	3549186	et	4	main
teatrisse	doc_986203247106_item	3549187	et	3	main
hinnaalandus	doc_986203247106_item	3549203	et	3	main
ja	doc_986203247106_item	3549211	et	3	main
kohaliku	doc_986203247106_item	3549214	et	3	main
kirjutage	doc_986203247108_item	3549276	et	3	main
nõutav	doc_986203247108_item	3549281	et	4	main
on	doc_986203247108_item	3549283	et	4	main
100	doc_986203247108_item	3549285	et	2	main
kuulutust	doc_986203247108_item	3549292	et	4	main
mina	doc_986203247108_item	3549293	et	4	main
pakub	doc_986203247108_item	3549302	et	3	main
ellenring	doc_986203247108_item	3549304	et	4	main
see	doc_986203247108_item	3549305	et	3	main
reis	doc_986203247108_item	3549306	et	4	main
kui	doc_986203247108_item	3549320	et	3	main
taha	doc_986203247108_item	3549346	et	4	main
minna	doc_986203247108_item	3549347	et	3	main
kindluse	doc_986203247108_item	3549368	et	4	main
ametlik	doc_432051777900_item	3549532	et	3	main
perekonnanimi	doc_432051777900_item	3549540	et	3	main
ma	doc_432051777900_item	3549555	et	3	main
oma	doc_432051777900_item	3549557	et	4	main
olen	doc_432051777900_item	3549561	et	3	main
varem	doc_432051777900_item	3549565	et	4	main
õppinud	doc_432051777900_item	3549567	et	4	main
vaja	doc_432051777900_item	3549573	et	4	main
on	doc_986203247104_item	3548964	et	4	main
tahame	doc_986203247104_item	3548967	et	3	main
ja	doc_986203247104_item	3548970	et	3	main
see	doc_986203247104_item	3548975	et	3	main
võib	doc_986203247104_item	3548976	et	3	main
olla	doc_986203247104_item	3548977	et	3	main
nii	doc_986203247104_item	3548978	et	3	main
ja	doc_986203247104_item	3548980	et	3	main
huvitav	doc_986203247104_item	3548979	et	4	main
jääb	doc_986203247104_item	3548981	et	3	main
mulje	doc_986203247104_item	3548982	et	4	main
terve	doc_986203247104_item	3548983	et	4	main
eluks	doc_986203247104_item	3548984	et	3	main
veel	doc_986203247104_item	3548985	et	4	main
reisibüroo	doc_986203247104_item	3548986	et	4	main
pakkub	doc_986203247104_item	3548987	et	4	main
lisatasu	doc_986203247104_item	3548988	et	4	main
eest	doc_986203247104_item	3548989	et	4	main
laevasõit	doc_986203247104_item	3548990	et	3	main
kui	doc_986203247104_item	3548991	et	3	main
te	doc_986203247104_item	3548992	et	4	main
tahate	doc_986203247104_item	3548993	et	3	main
teada	doc_986203247104_item	3548994	et	3	main
rohkem	doc_986203247104_item	3548995	et	4	main
informatsiooni	doc_986203247104_item	3548996	et	4	main
ja	doc_986203247104_item	3548997	et	3	main
osavõtusoovist	doc_986203247104_item	3548998	et	4	main
teata	doc_986203247104_item	3548999	et	4	main
võite	doc_986203247104_item	3549000	et	4	main
helistada	doc_986203247104_item	3549001	et	3	main
telefonil	doc_986203247104_item	3549002	et	3	main
3	doc_986203247104_item	3549003	et	2	main
456	doc_986203247104_item	3549004	et	2	main
789	doc_986203247104_item	3549005	et	2	main
ja	doc_986203247104_item	3549006	et	3	main
otsustage	doc_986203247104_item	3549007	et	3	main
on	doc_986203247104_item	3549011	et	4	main
hilja	doc_986203247104_item	3549013	et	3	main
32	doc_986203247104_item	3549015	et	2	main
kirjutage	doc_986203247104_item	3549019	et	3	main
joonest	doc_986203247104_item	3549021	et	4	main
allapoole	doc_986203247104_item	3549022	et	3	main
joonitud	doc_986203247106_item	3549151	et	4	main
sisse	doc_986203247106_item	3549153	et	4	main
100	doc_986203247106_item	3549159	et	2	main
lugesin	doc_986203247106_item	3549164	et	3	main
väga	doc_986203247106_item	3549169	et	3	main
oma	doc_986203247106_item	3549171	et	4	main
sellele	doc_986203247106_item	3549173	et	4	main
reisile	doc_986203247106_item	3549174	et	3	main
reis	doc_986203247106_item	3549177	et	4	main
peterburi	doc_986203247106_item	3549185	et	4	main
see	doc_986203247106_item	3549189	et	3	main
2122	doc_986203247106_item	3549191	et	2	main
juuni	doc_986203247106_item	3549192	et	4	main
pilet	doc_986203247106_item	3549193	et	3	main
maksab	doc_986203247106_item	3549194	et	3	main
20	doc_986203247106_item	3549204	et	2	main
edasi-tagasi	doc_986203247106_item	3549207	et	3	main
teatripiletid	doc_986203247106_item	3549209	et	3	main
linnaekskursioon	doc_986203247106_item	3549213	et	3	main
juhtimisel	doc_986203247106_item	3549216	et	4	main
ja	doc_986203247106_item	3549218	et	3	main
kindluse	doc_986203247106_item	3549220	et	4	main
mulle	doc_986203247106_item	3549227	et	4	main
see	doc_986203247106_item	3549230	et	3	main
on	doc_986203247106_item	3549231	et	4	main
väga	doc_986203247106_item	3549232	et	3	main
huvitav	doc_986203247106_item	3549233	et	4	main
gruupi	doc_986203247106_item	3549264	et	4	main
koolivanem	doc_986203247106_item	3549265	et	4	main
eesnimi	doc_986203247106_item	3549266	et	3	main
perekonnanimi	doc_986203247106_item	3549267	et	3	main
191102	doc_986203247106_item	3549268	et	2	main
ärge	doc_986203247106_item	3549269	et	3	main
kirjutage	doc_986203247106_item	3549270	et	3	main
sellest	doc_986203247106_item	3549271	et	4	main
joonest	doc_986203247106_item	3549272	et	4	main
allapoole	doc_986203247106_item	3549273	et	3	main
kasti	doc_986203247106_item	3549152	et	4	main
kirja	doc_986203247106_item	3549154	et	4	main
pikkus	doc_986203247106_item	3549156	et	4	main
ja	doc_986203247106_item	3549167	et	3	main
teatrireis	doc_986203247106_item	3549184	et	4	main
ja	doc_986203247106_item	3549188	et	3	main
toimub	doc_986203247106_item	3549190	et	3	main
1500	doc_986203247106_item	3549195	et	2	main
hinna	doc_986203247106_item	3549205	et	3	main
ermitaaži	doc_986203247106_item	3549217	et	2	main
peeter-pauli	doc_986203247106_item	3549219	et	4	main
külastamine	doc_986203247106_item	3549221	et	4	main
lisatasu	doc_986203247106_item	3549222	et	4	main
tundub	doc_986203247106_item	3549228	et	3	main
ettepaneku	doc_986203247106_item	3549234	et	3	main
ja	doc_986203247106_item	3549235	et	3	main
me	doc_986203247106_item	3549236	et	4	main
oma	doc_986203247106_item	3549237	et	4	main
koolikaaslastega	doc_986203247106_item	3549238	et	4	main
väga	doc_986203247106_item	3549239	et	3	main
hästi	doc_986203247106_item	3549240	et	3	main
veedaks	doc_986203247106_item	3549241	et	3	main
aega	doc_986203247106_item	3549242	et	4	main
ja	doc_986203247106_item	3549243	et	3	main
sellepärast	doc_986203247106_item	3549244	et	3	main
et	doc_986203247106_item	3549245	et	3	main
ma	doc_986203247106_item	3549246	et	3	main
palun	doc_986203247106_item	3549247	et	3	main
aidata	doc_986203247106_item	3549248	et	4	main
meile	doc_986203247106_item	3549249	et	4	main
rahaga	doc_986203247106_item	3549250	et	4	main
sest	doc_986203247106_item	3549251	et	4	main
me	doc_986203247106_item	3549252	et	4	main
saaksime	doc_986203247106_item	3549253	et	3	main
selle	doc_986203247106_item	3549254	et	4	main
teatrireisi	doc_986203247106_item	3549255	et	4	main
minna	doc_986203247106_item	3549256	et	3	main
lugupeetud	doc_986203247106_item	3549257	et	4	main
sponsor	doc_986203247106_item	3549258	et	3	main
ja	doc_986203247106_item	3549259	et	3	main
väga	doc_986203247106_item	3549260	et	3	main
loodan	doc_986203247106_item	3549261	et	3	main
teie	doc_986203247106_item	3549262	et	4	main
abile	doc_986203247106_item	3549263	et	3	main
sisse	doc_986203247108_item	3549279	et	4	main
u	doc_986203247108_item	3549284	et	4	main
koolikaaslased	doc_986203247108_item	3549296	et	3	main
on	doc_986203247108_item	3549312	et	4	main
kuulutuks	doc_986203247108_item	3549349	et	4	main
teatripiletid	doc_986203247108_item	3549356	et	3	main
lõunasöök	doc_986203247108_item	3549359	et	3	main
teie	doc_986203247108_item	3549405	et	4	main
abi	doc_986203247108_item	3549406	et	4	main
gruppivanem	doc_986203247108_item	3549407	et	4	main
eesnimi	doc_986203247108_item	3549408	et	3	main
19112002	doc_986203247108_item	3549409	et	2	main
ärge	doc_986203247108_item	3549410	et	3	main
kirjutage	doc_986203247108_item	3549411	et	3	main
sellest	doc_986203247108_item	3549412	et	4	main
joonest	doc_986203247108_item	3549413	et	4	main
allapoole	doc_986203247108_item	3549414	et	3	main
kasti	doc_986203247108_item	3549278	et	4	main
sõna	doc_986203247108_item	3549286	et	4	main
ja	doc_986203247108_item	3549294	et	3	main
oma	doc_986203247108_item	3549295	et	4	main
tahame	doc_986203247108_item	3549297	et	3	main
2122	doc_986203247108_item	3549313	et	2	main
reis	doc_986203247108_item	3549315	et	4	main
1500	doc_986203247108_item	3549317	et	2	main
aga	doc_986203247108_item	3549319	et	3	main
grupp	doc_986203247108_item	3549323	et	3	main
oleks	doc_986203247108_item	3549324	et	3	main
vähemalt	doc_986203247108_item	3549325	et	4	main
22	doc_986203247108_item	3549326	et	2	main
inimest	doc_986203247108_item	3549327	et	3	main
sest	doc_986203247108_item	3549328	et	4	main
me	doc_986203247108_item	3549329	et	4	main
saaksime	doc_986203247108_item	3549330	et	3	main
hinnaalandus	doc_986203247108_item	3549331	et	3	main
20	doc_986203247108_item	3549332	et	2	main
see	doc_986203247108_item	3549333	et	3	main
väga	doc_986203247108_item	3549334	et	3	main
sobib	doc_986203247108_item	3549335	et	3	main
meile	doc_986203247108_item	3549336	et	4	main
meie	doc_986203247108_item	3549337	et	4	main
klassis	doc_986203247108_item	3549338	et	3	main
on	doc_986203247108_item	3549339	et	4	main
23	doc_986203247108_item	3549340	et	2	main
inimest	doc_986203247108_item	3549341	et	3	main
ja	doc_986203247108_item	3549342	et	3	main
üks	doc_986203247108_item	3549343	et	3	main
on	doc_986203247108_item	3549322	et	4	main
reisile	doc_986203247108_item	3549348	et	3	main
et	doc_986203247108_item	3549351	et	3	main
sees	doc_986203247108_item	3549353	et	4	main
rongipilet	doc_986203247108_item	3549355	et	3	main
ja	doc_986203247108_item	3549358	et	3	main
külastamine	doc_986203247108_item	3549369	et	4	main
firma	doc_986203247108_item	3549370	et	4	main
ka	doc_986203247108_item	3549371	et	3	main
õpetaja	doc_432051777900_item	3549535	et	4	main
on	doc_432051777900_item	3549538	et	4	main
19	doc_432051777900_item	3549542	et	2	main
sugulased	doc_432051777900_item	3549554	et	3	main
keelt	doc_432051777900_item	3549560	et	4	main
eesti	doc_432051777900_item	3549571	et	4	main
mul	doc_432051777900_item	3549578	et	3	main
kuulata	doc_432051777900_item	3549581	et	4	main
eesti	doc_432051777900_item	3549582	et	4	main
rääkima	doc_432051777900_item	3549583	et	3	main
ma	doc_432051777900_item	3549584	et	3	main
tahan	doc_432051777900_item	3549585	et	3	main
rääkida	doc_432051777900_item	3549586	et	3	main
see	doc_432051777900_item	3549596	et	3	main
tüdruk	doc_986203247108_item	3549344	et	3	main
ei	doc_986203247108_item	3549345	et	4	main
kirjutatakse	doc_986203247108_item	3549350	et	3	main
hinna	doc_986203247108_item	3549352	et	3	main
edasi-tagasi	doc_986203247108_item	3549354	et	3	main
hommiku-	doc_986203247108_item	3549357	et	3	main
kohaliku	doc_986203247108_item	3549361	et	3	main
juhtimisel	doc_986203247108_item	3549363	et	4	main
ja	doc_986203247108_item	3549364	et	3	main
tere	doc_432051777900_item	3549534	et	3	main
kõige	doc_432051777900_item	3549545	et	4	main
tähtsam	doc_432051777900_item	3549546	et	4	main
minu	doc_432051777900_item	3549547	et	3	main
on	doc_432051777900_item	3549549	et	4	main
sport	doc_432051777900_item	3549550	et	3	main
ja	doc_432051777900_item	3549551	et	3	main
õppimine	doc_432051777900_item	3549552	et	4	main
eesti	doc_432051777900_item	3549559	et	4	main
aastat	doc_432051777900_item	3549564	et	3	main
keelt	doc_432051777900_item	3549572	et	4	main
oma	doc_432051777900_item	3549587	et	4	main
sõpradega	doc_432051777900_item	3549588	et	3	main
ja	doc_432051777900_item	3549589	et	3	main
ma	doc_432051777900_item	3549591	et	3	main
tahan	doc_432051777900_item	3549592	et	3	main
keelt	doc_432051777900_item	3549598	et	4	main
õppida	doc_432051777900_item	3549599	et	3	main
loodan	doc_432051777900_item	3549601	et	3	main
me	doc_432051777900_item	3549603	et	4	main
2004	doc_51880851201_item	3549750	et	2	main
saadame	doc_51880851201_item	3549761	et	3	main
loetelu	doc_51880851201_item	3549763	et	4	main
kell	doc_51880851201_item	3549771	et	3	main
tuleb	doc_51880851201_item	3549777	et	3	main
2355	doc_51880851201_item	3549780	et	2	main
ekskursioon	doc_51880851201_item	3549781	et	3	main
reisi	doc_51880851201_item	3549820	et	4	main
pakkumine	doc_51880851201_item	3549833	et	4	main
lugupidamisega	doc_51880851201_item	3549837	et	3	main
vojaž	doc_51880851201_item	3549841	et	2	main
peajuht	doc_51880851201_item	3549842	et	3	main
linnaekskursioon	doc_986203247108_item	3549360	et	3	main
giidi	doc_986203247108_item	3549362	et	4	main
ermitaaži	doc_986203247108_item	3549365	et	2	main
ja	doc_986203247108_item	3549366	et	3	main
peeter-pauli	doc_986203247108_item	3549367	et	4	main
pakkub	doc_986203247108_item	3549372	et	4	main
laevasõit	doc_986203247108_item	3549373	et	3	main
lisatasu	doc_986203247108_item	3549374	et	4	main
eest	doc_986203247108_item	3549375	et	4	main
ma	doc_986203247108_item	3549376	et	3	main
mõtlen	doc_986203247108_item	3549377	et	3	main
et	doc_986203247108_item	3549378	et	3	main
on	doc_986203247108_item	3549380	et	4	main
see	doc_986203247108_item	3549379	et	3	main
väga	doc_986203247108_item	3549381	et	3	main
huvitav	doc_986203247108_item	3549382	et	4	main
ja	doc_986203247108_item	3549383	et	3	main
põnev	doc_986203247108_item	3549384	et	3	main
reis	doc_986203247108_item	3549385	et	4	main
me	doc_986203247108_item	3549386	et	4	main
loodame	doc_986203247108_item	3549387	et	3	main
et	doc_986203247108_item	3549388	et	3	main
te	doc_986203247108_item	3549389	et	4	main
aidate	doc_986203247108_item	3549390	et	4	main
meile	doc_986203247108_item	3549391	et	4	main
sellega	doc_986203247108_item	3549392	et	3	main
reisiga	doc_986203247108_item	3549393	et	3	main
reisis	doc_986203247108_item	3549394	et	4	main
me	doc_986203247108_item	3549395	et	4	main
veedaksime	doc_986203247108_item	3549396	et	3	main
aeg	doc_986203247108_item	3549397	et	3	main
lõbusalt	doc_986203247108_item	3549398	et	4	main
me	doc_986203247108_item	3549399	et	4	main
ootame	doc_986203247108_item	3549400	et	3	main
sinust	doc_986203247108_item	3549401	et	3	main
vastus	doc_986203247108_item	3549402	et	3	main
ja	doc_986203247108_item	3549403	et	3	main
loodame	doc_986203247108_item	3549404	et	3	main
minu	doc_432051777900_item	3549536	et	3	main
nimi	doc_432051777900_item	3549537	et	3	main
olen	doc_432051777900_item	3549541	et	3	main
a	doc_432051777900_item	3549543	et	4	main
vana	doc_432051777900_item	3549544	et	4	main
elus	doc_432051777900_item	3549548	et	4	main
elu	doc_432051777900_item	3549558	et	4	main
10	doc_432051777900_item	3549563	et	2	main
on	doc_432051777900_item	3549579	et	4	main
aitab	doc_432051777900_item	3549597	et	3	main
ma	doc_432051777900_item	3549600	et	3	main
et	doc_432051777900_item	3549602	et	3	main
mai	doc_51880851201_item	3549749	et	4	main
lugupeetud	doc_51880851201_item	3549751	et	4	main
perekonnanimi	doc_51880851201_item	3549753	et	3	main
teie	doc_51880851201_item	3549755	et	4	main
laupäev	doc_51880851201_item	3549774	et	3	main
jalutuskäigust	doc_51880851201_item	3549783	et	3	main
456	doc_51880851201_item	3549828	et	2	main
kardan	doc_432051777900_item	3549608	et	4	main
natuke	doc_432051777900_item	3549609	et	4	main
et	doc_432051777900_item	3549610	et	3	main
minu	doc_432051777900_item	3549611	et	3	main
jaoks	doc_432051777900_item	3549612	et	4	main
on	doc_432051777900_item	3549613	et	4	main
see	doc_432051777900_item	3549614	et	3	main
raske	doc_432051777900_item	3549615	et	4	main
aga	doc_432051777900_item	3549616	et	3	main
ma	doc_432051777900_item	3549617	et	3	main
olen	doc_432051777900_item	3549618	et	3	main
väga	doc_432051777900_item	3549619	et	3	main
hea	doc_432051777900_item	3549620	et	4	main
õppima	doc_432051777900_item	3549621	et	3	main
ma	doc_432051777900_item	3549622	et	3	main
tahaksin	doc_432051777900_item	3549623	et	3	main
teada	doc_432051777900_item	3549624	et	3	main
kui	doc_432051777900_item	3549625	et	3	main
tihti	doc_432051777900_item	3549626	et	3	main
meil	doc_432051777900_item	3549627	et	4	main
kiri	doc_432051777900_item	3549533	et	3	main
eesnimi	doc_432051777900_item	3549539	et	3	main
oma	doc_432051777900_item	3549553	et	4	main
armastan	doc_432051777900_item	3549556	et	3	main
õppinud	doc_432051777900_item	3549562	et	4	main
olen	doc_432051777900_item	3549566	et	3	main
koolis	doc_432051777900_item	3549568	et	4	main
mul	doc_432051777900_item	3549569	et	3	main
on	doc_432051777900_item	3549570	et	4	main
raske	doc_432051777900_item	3549576	et	4	main
eestlastega	doc_432051777900_item	3549590	et	4	main
kirjutada	doc_432051777900_item	3549593	et	3	main
arutluseid	doc_432051777900_item	3549594	et	4	main
sest	doc_432051777900_item	3549595	et	4	main
tegeleme	doc_432051777900_item	3549604	et	3	main
põhjalikult	doc_432051777900_item	3549605	et	4	main
grammatikaga	doc_432051777900_item	3549606	et	3	main
ma	doc_432051777900_item	3549607	et	3	main
on	doc_432051777900_item	3549628	et	4	main
eesti	doc_432051777900_item	3549629	et	4	main
järelepärimiskirjale	doc_51880851201_item	3549747	et	3	main
teile	doc_51880851201_item	3549762	et	4	main
reisidest	doc_51880851201_item	3549764	et	3	main
riiga	doc_51880851201_item	3549765	et	4	main
teenindusmajast	doc_51880851201_item	3549775	et	4	main
kell	doc_51880851201_item	3549779	et	3	main
ledo	doc_51880851201_item	3549790	et	4	main
visiitist	doc_51880851201_item	3549791	et	4	main
reisi	doc_51880851201_item	3549792	et	4	main
hind	doc_51880851201_item	3549793	et	3	main
restorani	doc_51880851201_item	3549817	et	4	main
on	doc_51880851201_item	3549822	et	4	main
et	doc_432051777900_item	3549574	et	3	main
lugeda	doc_432051777900_item	3549575	et	3	main
tekste	doc_432051777900_item	3549577	et	3	main
vaja	doc_432051777900_item	3549580	et	4	main
keele	doc_432051777900_item	3549630	et	4	main
tunnid	doc_432051777900_item	3549631	et	3	main
kas	doc_432051777900_item	3549632	et	3	main
meil	doc_432051777900_item	3549633	et	4	main
on	doc_432051777900_item	3549634	et	4	main
erinevaid	doc_432051777900_item	3549635	et	4	main
rollimängud	doc_432051777900_item	3549636	et	3	main
loodan	doc_432051777900_item	3549637	et	3	main
et	doc_432051777900_item	3549638	et	3	main
eesti	doc_432051777900_item	3549639	et	4	main
keele	doc_432051777900_item	3549640	et	4	main
tunnid	doc_432051777900_item	3549641	et	3	main
oli	doc_432051777900_item	3549642	et	3	main
huvitavad	doc_432051777900_item	3549643	et	4	main
lugupidamisega	doc_432051777900_item	3549644	et	3	main
eesnimi	doc_432051777900_item	3549645	et	3	main
perekonnanimi	doc_432051777900_item	3549646	et	3	main
23	doc_51880851201_item	3549748	et	2	main
eesnimi	doc_51880851201_item	3549752	et	3	main
vastuseks	doc_51880851201_item	3549754	et	4	main
20	doc_51880851201_item	3549756	et	2	main
mail	doc_51880851201_item	3549757	et	4	main
2004	doc_51880851201_item	3549758	et	2	main
reis	doc_51880851201_item	3549766	et	4	main
iga	doc_51880851201_item	3549773	et	4	main
koosneb	doc_51880851201_item	3549782	et	3	main
vana	doc_51880851201_item	3549784	et	4	main
mööda	doc_51880851201_item	3549786	et	4	main
akvapargi	doc_51880851201_item	3549787	et	3	main
ja	doc_51880851201_item	3549788	et	3	main
restorani	doc_51880851201_item	3549789	et	4	main
on	doc_51880851201_item	3549794	et	4	main
250	doc_51880851201_item	3549795	et	2	main
krooni	doc_51880851201_item	3549796	et	4	main
reis	doc_51880851201_item	3549797	et	4	main
riiga	doc_51880851201_item	3549798	et	4	main
kaheks	doc_51880851201_item	3549799	et	4	main
päevaks	doc_51880851201_item	3549800	et	3	main
laupäev	doc_51880851201_item	3549801	et	3	main
pühapäev	doc_51880851201_item	3549802	et	3	main
ekskursioonis	doc_51880851201_item	3549803	et	3	main
on	doc_51880851201_item	3549804	et	4	main
majutus	doc_51880851201_item	3549805	et	4	main
hotellis	doc_51880851201_item	3549806	et	3	main
toitlus	doc_51880851201_item	3549807	et	4	main
kolm	doc_51880851201_item	3549808	et	3	main
korda	doc_51880851201_item	3549809	et	4	main
päevas	doc_51880851201_item	3549810	et	3	main
jalutuskäik	doc_51880851201_item	3549811	et	3	main
vanalinna	doc_51880851201_item	3549812	et	4	main
mööda	doc_51880851201_item	3549813	et	4	main
muuseumide	doc_51880851201_item	3549814	et	3	main
akvapargi	doc_51880851201_item	3549815	et	3	main
ja	doc_51880851201_item	3549816	et	3	main
vastus	doc_51880851201_item	3549746	et	3	main
saadetud	doc_51880851201_item	3549759	et	4	main
järelepärimiskirjale	doc_51880851201_item	3549760	et	3	main
riiga	doc_51880851201_item	3549767	et	4	main
buss	doc_51880851201_item	3549768	et	3	main
sõidab	doc_51880851201_item	3549769	et	3	main
välja	doc_51880851201_item	3549770	et	4	main
700	doc_51880851201_item	3549772	et	2	main
ja	doc_51880851201_item	3549776	et	3	main
tagasi	doc_51880851201_item	3549778	et	3	main
linna	doc_51880851201_item	3549785	et	4	main
hind	doc_51880851201_item	3549821	et	3	main
lisainfo	doc_51880851201_item	3549825	et	4	main
123	doc_51880851201_item	3549827	et	2	main
jääme	doc_51880851201_item	3549829	et	4	main
lootma	doc_51880851201_item	3549830	et	3	main
et	doc_51880851201_item	3549831	et	3	main
meie	doc_51880851201_item	3549832	et	4	main
teie	doc_51880851201_item	3549835	et	4	main
eesnimi	doc_51880851201_item	3549838	et	3	main
ledo	doc_51880851201_item	3549818	et	4	main
visiit	doc_51880851201_item	3549819	et	3	main
400	doc_51880851201_item	3549823	et	2	main
krooni	doc_51880851201_item	3549824	et	4	main
telefonil	doc_51880851201_item	3549826	et	3	main
vastab	doc_51880851201_item	3549834	et	3	main
soovidele	doc_51880851201_item	3549836	et	3	main
perekonnanimi	doc_51880851201_item	3549839	et	3	main
turismifirma	doc_51880851201_item	3549840	et	4	main
olen	doc_542009824799_item	3550321	et	3	main
3	doc_542009824799_item	3550332	et	2	main
kuupäeval	doc_542009824799_item	3550337	et	3	main
läksin	doc_542009824799_item	3550339	et	3	main
täis	doc_542009824799_item	3550346	et	4	main
ja	doc_542009824799_item	3550347	et	3	main
3	doc_542009824799_item	3550355	et	2	main
öeldi	doc_542009824799_item	3550357	et	3	main
et	doc_542009824799_item	3550365	et	3	main
kursused	doc_542009824799_item	3550366	et	3	main
algavad	doc_542009824799_item	3550367	et	4	main
kindlasti	doc_542009824799_item	3550368	et	3	main
15	doc_542009824799_item	3550371	et	2	main
oktoobril	doc_542009824799_item	3550372	et	3	main
keele	doc_542009824799_item	3550408	et	4	main
liiga	doc_542009824799_item	3550410	et	4	main
palju	doc_542009824799_item	3550411	et	4	main
ja	doc_542009824799_item	3550412	et	3	main
samuti	doc_542009824799_item	3550423	et	3	main
on	doc_542009824799_item	3550424	et	4	main
mul	doc_542009824799_item	3550425	et	3	main
ja	doc_542009824799_item	3550432	et	3	main
maksta	doc_542009824799_item	3550456	et	4	main
kiri	doc_542009824799_item	3550309	et	3	main
eest	doc_542009824799_item	3550324	et	4	main
mulle	doc_542009824799_item	3550327	et	4	main
et	doc_542009824799_item	3550329	et	3	main
kui	doc_542009824799_item	3550334	et	3	main
öeldi	doc_542009824799_item	3550340	et	3	main
ei	doc_542009824799_item	3550343	et	4	main
lükati	doc_542009824799_item	3550349	et	4	main
kuu	doc_542009824799_item	3550353	et	4	main
hiina	doc_542009824799_item	3550359	et	3	main
õpetaja	doc_542009824799_item	3550361	et	4	main
ja	doc_542009824799_item	3550377	et	3	main
õpetaja	doc_542009824799_item	3550413	et	4	main
ei	doc_542009824799_item	3550414	et	4	main
pretensioon	doc_542009824799_item	3550426	et	3	main
kõrvaklapid	doc_542009824799_item	3550433	et	3	main
mõni	doc_542009824799_item	3550437	et	3	main
saanud	doc_542009824799_item	3550445	et	4	main
pärast	doc_542009824799_item	3550448	et	4	main
palusin	doc_542009824799_item	3550453	et	3	main
keeldus	doc_542009824799_item	3550458	et	3	main
see	doc_542009824799_item	3550463	et	3	main
enam	doc_542009824799_item	3550465	et	4	main
ametlik	doc_542009824799_item	3550308	et	3	main
teie	doc_542009824799_item	3550314	et	4	main
firma	doc_542009824799_item	3550316	et	4	main
hiina	doc_542009824799_item	3550317	et	3	main
keele	doc_542009824799_item	3550318	et	4	main
õppimiskursustele	doc_542009824799_item	3550319	et	3	main
ja	doc_542009824799_item	3550320	et	3	main
3000	doc_542009824799_item	3550325	et	2	main
krooni	doc_542009824799_item	3550326	et	4	main
lubati	doc_542009824799_item	3550328	et	3	main
ma	doc_542009824799_item	3550335	et	3	main
algus	doc_542009824799_item	3550348	et	4	main
kuu	doc_542009824799_item	3550351	et	4	main
pärast	doc_542009824799_item	3550354	et	4	main
oktoobril	doc_542009824799_item	3550356	et	3	main
et	doc_542009824799_item	3550358	et	3	main
keele	doc_542009824799_item	3550360	et	4	main
on	doc_542009824799_item	3550362	et	4	main
haige	doc_542009824799_item	3550363	et	4	main
lubati	doc_542009824799_item	3550364	et	3	main
kuulata	doc_542009824799_item	3550418	et	4	main
ja	doc_542009824799_item	3550419	et	3	main
nende	doc_542009824799_item	3550420	et	4	main
küsimustele	doc_542009824799_item	3550421	et	4	main
lingofonikabineti	doc_542009824799_item	3550427	et	4	main
tehnimuse	doc_542009824799_item	3550428	et	4	main
kuulanud	doc_542009824799_item	3550441	et	4	main
õpetajad	doc_542009824799_item	3550442	et	4	main
ja	doc_542009824799_item	3550443	et	3	main
ei	doc_542009824799_item	3550444	et	4	main
raha	doc_542009824799_item	3550454	et	4	main
ja	doc_542009824799_item	3550459	et	3	main
et	doc_542009824799_item	3550462	et	3	main
lugupeetud	doc_542009824799_item	3550310	et	4	main
firmajuht	doc_542009824799_item	3550312	et	3	main
maksnud	doc_542009824799_item	3550322	et	4	main
keelekursused	doc_542009824799_item	3550330	et	3	main
ole	doc_542009824799_item	3550344	et	4	main
veel	doc_542009824799_item	3550345	et	4	main
üks	doc_542009824799_item	3550350	et	3	main
edasi	doc_542009824799_item	3550352	et	3	main
15	doc_542009824799_item	3550369	et	2	main
oktoobril	doc_542009824799_item	3550370	et	3	main
kursused	doc_542009824799_item	3550373	et	3	main
tõesti	doc_542009824799_item	3550374	et	3	main
algasid	doc_542009824799_item	3550375	et	4	main
õpetaja	doc_542009824799_item	3550376	et	4	main
lingofonikabinetiga	doc_542009824799_item	3550378	et	4	main
jäin	doc_542009824799_item	3550379	et	3	main
sooviga	doc_542009824799_item	3550471	et	4	main
oma	doc_542009824799_item	3550472	et	4	main
raha	doc_542009824799_item	3550473	et	4	main
tagasi	doc_542009824799_item	3550474	et	3	main
saada	doc_542009824799_item	3550475	et	4	main
eesnimi	doc_542009824799_item	3550476	et	3	main
perekonnanimi	doc_542009824799_item	3550477	et	3	main
kontaktandmed	doc_542009824799_item	3550478	et	3	main
tel	doc_542009824799_item	3550479	et	4	main
555	doc_542009824799_item	3550480	et	2	main
555	doc_542009824799_item	3550481	et	2	main
keelekursuste	doc_542009824799_item	3550311	et	3	main
registreerusin	doc_542009824799_item	3550313	et	3	main
keelekursuste	doc_542009824799_item	3550315	et	3	main
kvartali	doc_542009824799_item	3550323	et	3	main
algavad	doc_542009824799_item	3550331	et	4	main
septembril	doc_542009824799_item	3550333	et	3	main
sellel	doc_542009824799_item	3550336	et	4	main
kohale	doc_542009824799_item	3550338	et	4	main
et	doc_542009824799_item	3550341	et	3	main
rühm	doc_542009824799_item	3550342	et	3	main
väga	doc_542009824799_item	3550380	et	3	main
rahule	doc_542009824799_item	3550381	et	4	main
ma	doc_542009824799_item	3550382	et	3	main
ei	doc_542009824799_item	3550383	et	4	main
ole	doc_542009824799_item	3550384	et	4	main
aga	doc_542009824799_item	3550385	et	3	main
rahul	doc_542009824799_item	3550386	et	4	main
sellega	doc_542009824799_item	3550387	et	3	main
et	doc_542009824799_item	3550388	et	3	main
nüüd	doc_542009824799_item	3550389	et	4	main
on	doc_542009824799_item	3550390	et	4	main
meie	doc_542009824799_item	3550391	et	4	main
grupis	doc_542009824799_item	3550392	et	3	main
kakskümmend	doc_542009824799_item	3550393	et	4	main
inimest	doc_542009824799_item	3550394	et	3	main
varem	doc_542009824799_item	3550395	et	4	main
lubati	doc_542009824799_item	3550396	et	3	main
et	doc_542009824799_item	3550397	et	3	main
üle	doc_542009824799_item	3550398	et	3	main
kümne	doc_542009824799_item	3550399	et	4	main
inimese	doc_542009824799_item	3550400	et	4	main
gruppi	doc_542009824799_item	3550401	et	4	main
ei	doc_542009824799_item	3550402	et	4	main
võeta	doc_542009824799_item	3550403	et	3	main
kakskümmend	doc_542009824799_item	3550404	et	4	main
inimest	doc_542009824799_item	3550405	et	3	main
on	doc_542009824799_item	3550406	et	4	main
hiina	doc_542009824799_item	3550407	et	3	main
õppimiseks	doc_542009824799_item	3550409	et	4	main
jõua	doc_542009824799_item	3550415	et	4	main
magnetofonid	doc_542009824799_item	3550430	et	3	main
mikrofonid	doc_542009824799_item	3550431	et	3	main
korras	doc_542009824799_item	3550435	et	4	main
kord	doc_542009824799_item	3550438	et	4	main
ma	doc_542009824799_item	3550439	et	3	main
ei	doc_542009824799_item	3550440	et	4	main
lindistada	doc_542009824799_item	3550446	et	3	main
õppinguid	doc_542009824799_item	3550449	et	4	main
rääkisin	doc_542009824799_item	3550450	et	3	main
administratsiooniga	doc_542009824799_item	3550451	et	3	main
ja	doc_542009824799_item	3550452	et	3	main
selgitas	doc_542009824799_item	3550460	et	3	main
mulle	doc_542009824799_item	3550461	et	4	main
pole	doc_542009824799_item	3550464	et	3	main
kõiki	doc_542009824799_item	3550416	et	4	main
õpilasi	doc_542009824799_item	3550417	et	3	main
vastata	doc_542009824799_item	3550422	et	4	main
talgastamise	doc_542009824799_item	3550429	et	4	main
on	doc_542009824799_item	3550434	et	4	main
aga	doc_542009824799_item	3550436	et	3	main
end	doc_542009824799_item	3550447	et	4	main
tagasi	doc_542009824799_item	3550455	et	3	main
administratsioon	doc_542009824799_item	3550457	et	3	main
pöördun	doc_542009824799_item	3550467	et	3	main
nüüd	doc_542009824799_item	3550468	et	4	main
teile	doc_542009824799_item	3550469	et	4	main
poole	doc_542009824799_item	3550470	et	4	main
võimalik	doc_542009824799_item	3550466	et	3	main
aine	doc_384045275262_item	3551241	et	4	main
refistreeruda	doc_384045275262_item	3551253	et	4	main
töötas	doc_384045275262_item	3551268	et	3	main
mulle	doc_384045275262_item	3551271	et	4	main
mind	doc_384045275262_item	3551273	et	4	main
selgus	doc_384045275262_item	3551289	et	4	main
sisse	doc_384045275262_item	3551300	et	4	main
vaid	doc_384045275262_item	3551301	et	3	main
käisin	doc_384045275262_item	3551305	et	3	main
100	doc_986203247110_item	3551381	et	2	main
lgp	doc_986203247110_item	3551383	et	4	main
mul	doc_986203247110_item	3551385	et	3	main
teile	doc_986203247110_item	3551387	et	4	main
palve	doc_986203247110_item	3551388	et	4	main
peterburi	doc_986203247110_item	3551397	et	4	main
on	doc_986203247110_item	3551433	et	4	main
hommiku-	doc_986203247110_item	3551437	et	3	main
lõunasöök	doc_986203247110_item	3551439	et	3	main
kohaliku	doc_986203247110_item	3551441	et	3	main
juhtimisel	doc_986203247110_item	3551443	et	4	main
ja	doc_986203247110_item	3551445	et	3	main
peeter-pauli	doc_986203247110_item	3551446	et	4	main
kindluse	doc_986203247110_item	3551447	et	4	main
kiri	doc_491521502055_item	3551476	et	3	main
peab	doc_491521502055_item	3551484	et	4	main
tutvustage	doc_491521502055_item	3551489	et	3	main
ja	doc_491521502055_item	3551498	et	3	main
oma	doc_491521502055_item	3551500	et	4	main
tööd	doc_491521502055_item	3551503	et	4	main
soovite	doc_491521502055_item	3551504	et	3	main
kui	doc_491521502055_item	3551505	et	3	main
perekonnanimi	doc_384045275262_item	3551229	et	3	main
eesti	doc_384045275262_item	3551239	et	4	main
eesti	doc_384045275262_item	3551247	et	4	main
võõrkeelena	doc_384045275262_item	3551249	et	3	main
ennast	doc_384045275262_item	3551254	et	4	main
eesti	doc_384045275262_item	3551259	et	4	main
filoloogia	doc_384045275262_item	3551260	et	4	main
seal	doc_384045275262_item	3551269	et	4	main
ise	doc_384045275262_item	3551281	et	4	main
lehte	doc_384045275262_item	3551285	et	4	main
on	doc_384045275262_item	3551288	et	4	main
lehte	doc_384045275262_item	3551299	et	4	main
ma	doc_384045275262_item	3551304	et	3	main
nõutav	doc_986203247110_item	3551377	et	4	main
sõna	doc_986203247110_item	3551382	et	4	main
sooviks	doc_986203247110_item	3551391	et	4	main
sõita	doc_986203247110_item	3551392	et	3	main
sees	doc_986203247110_item	3551431	et	4	main
teatripiletid	doc_986203247110_item	3551436	et	3	main
külastamine	doc_986203247110_item	3551448	et	4	main
palun	doc_986203247110_item	3551449	et	3	main
dd-3	doc_384045275262_item	3551230	et	2	main
ainele	doc_384045275262_item	3551258	et	4	main
neiu	doc_384045275262_item	3551266	et	4	main
ütles	doc_384045275262_item	3551270	et	3	main
paneb	doc_384045275262_item	3551282	et	3	main
mind	doc_384045275262_item	3551283	et	4	main
et	doc_384045275262_item	3551290	et	3	main
eksis	doc_384045275262_item	3551292	et	3	main
panis	doc_384045275262_item	3551294	et	4	main
minu	doc_384045275262_item	3551295	et	3	main
nimi	doc_384045275262_item	3551296	et	3	main
semesteer	doc_384045275262_item	3551303	et	4	main
kiri	doc_986203247110_item	3551371	et	3	main
joonitud	doc_986203247110_item	3551373	et	4	main
sisse	doc_986203247110_item	3551375	et	4	main
kirja	doc_986203247110_item	3551376	et	4	main
on	doc_986203247110_item	3551379	et	4	main
sponsor	doc_986203247110_item	3551384	et	3	main
on	doc_986203247110_item	3551386	et	4	main
me	doc_986203247110_item	3551394	et	4	main
tahaksime	doc_986203247110_item	3551395	et	3	main
kaia	doc_986203247110_item	3551396	et	4	main
vaja	doc_986203247110_item	3551427	et	4	main
juba	doc_986203247110_item	3551432	et	3	main
rongipilet	doc_986203247110_item	3551435	et	3	main
giidi	doc_986203247110_item	3551442	et	4	main
läbi	doc_491521502055_item	3551478	et	4	main
vastake	doc_491521502055_item	3551481	et	3	main
olema	doc_491521502055_item	3551485	et	4	main
60	doc_491521502055_item	3551487	et	2	main
ennast	doc_491521502055_item	3551490	et	4	main
töögraafik	doc_491521502055_item	3551510	et	3	main
pärast	doc_491521502055_item	3551514	et	4	main
uus	doc_491521502055_item	3551516	et	3	main
avaldus	doc_384045275262_item	3551225	et	4	main
mina	doc_384045275262_item	3551227	et	4	main
eesnimi	doc_384045275262_item	3551228	et	3	main
isikukood	doc_384045275262_item	3551231	et	4	main
panna	doc_384045275262_item	3551243	et	4	main
keel	doc_384045275262_item	3551248	et	4	main
eesti	doc_384045275262_item	3551255	et	4	main
teduskonnale	doc_384045275262_item	3551261	et	4	main
septembri	doc_384045275262_item	3551262	et	3	main
2007	doc_384045275262_item	3551263	et	2	main
kes	doc_384045275262_item	3551267	et	4	main
huvitab	doc_384045275262_item	3551274	et	3	main
sisse	doc_384045275262_item	3551286	et	4	main
õige	doc_384045275262_item	3551298	et	4	main
kogu	doc_384045275262_item	3551302	et	4	main
eesti	doc_384045275262_item	3551306	et	4	main
keel	doc_384045275262_item	3551307	et	4	main
võõrkeelena	doc_384045275262_item	3551308	et	3	main
loengusele	doc_384045275262_item	3551309	et	3	main
ja	doc_384045275262_item	3551310	et	3	main
minu	doc_384045275262_item	3551311	et	3	main
õpperaamatus	doc_384045275262_item	3551312	et	4	main
hinne	doc_384045275262_item	3551314	et	3	main
on	doc_384045275262_item	3551313	et	4	main
mida	doc_384045275262_item	3551316	et	4	main
oma	doc_384045275262_item	3551317	et	4	main
käega	doc_384045275262_item	3551318	et	3	main
c	doc_384045275262_item	3551315	et	4	main
pani	doc_384045275262_item	3551319	et	4	main
mulle	doc_384045275262_item	3551320	et	4	main
naana	doc_384045275262_item	3551321	et	4	main
povskaja	doc_384045275262_item	3551322	et	4	main
essti	doc_384045275262_item	3551323	et	4	main
keel	doc_384045275262_item	3551324	et	4	main
võõrkeelena	doc_384045275262_item	3551325	et	3	main
õppetaja	doc_384045275262_item	3551326	et	4	main
eesnimi	doc_384045275262_item	3551327	et	3	main
perekonnanimi	doc_384045275262_item	3551328	et	3	main
avaldus	doc_384045275262_item	3551226	et	4	main
palun	doc_384045275262_item	3551232	et	3	main
minu	doc_384045275262_item	3551233	et	3	main
õppekaardis	doc_384045275262_item	3551234	et	3	main
võtta	doc_384045275262_item	3551235	et	3	main
maha	doc_384045275262_item	3551236	et	4	main
bbb1111	doc_384045275262_item	3551237	et	2	main
erialane	doc_384045275262_item	3551238	et	4	main
keel	doc_384045275262_item	3551240	et	4	main
ja	doc_384045275262_item	3551242	et	3	main
selle	doc_384045275262_item	3551244	et	4	main
asemel	doc_384045275262_item	3551245	et	4	main
bbb1122	doc_384045275262_item	3551246	et	2	main
aine	doc_384045275262_item	3551250	et	4	main
ma	doc_384045275262_item	3551251	et	3	main
tulin	doc_384045275262_item	3551252	et	3	main
keel	doc_384045275262_item	3551256	et	4	main
võõrkeelena	doc_384045275262_item	3551257	et	3	main
algusel	doc_384045275262_item	3551264	et	4	main
ja	doc_384045275262_item	3551265	et	3	main
kirjutada	doc_384045275262_item	3551272	et	3	main
aine	doc_384045275262_item	3551275	et	4	main
ja	doc_384045275262_item	3551276	et	3	main
minu	doc_384045275262_item	3551277	et	3	main
nimi	doc_384045275262_item	3551278	et	3	main
ja	doc_384045275262_item	3551279	et	3	main
ta	doc_384045275262_item	3551280	et	4	main
registrerumise	doc_384045275262_item	3551284	et	4	main
nüüd	doc_384045275262_item	3551287	et	4	main
neiu	doc_384045275262_item	3551291	et	4	main
ja	doc_384045275262_item	3551293	et	3	main
pole	doc_384045275262_item	3551297	et	3	main
kirjutage	doc_986203247110_item	3551372	et	3	main
kasti	doc_986203247110_item	3551374	et	4	main
pikkus	doc_986203247110_item	3551378	et	4	main
maria	doc_986203247110_item	3551398	et	4	main
on	doc_986203247110_item	3551426	et	4	main
30000	doc_986203247110_item	3551428	et	2	main
eek	doc_986203247110_item	3551429	et	4	main
ja	doc_986203247110_item	3551438	et	3	main
linnaekskursioon	doc_986203247110_item	3551440	et	3	main
lugege	doc_491521502055_item	3551477	et	3	main
ja	doc_491521502055_item	3551480	et	3	main
perekonnaseis	doc_491521502055_item	3551491	et	4	main
sobib	doc_491521502055_item	3551511	et	3	main
kauplusse	doc_491521502055_item	3551518	et	3	main
vajatakse	doc_491521502055_item	3551519	et	4	main
kassapidajat	doc_491521502055_item	3551521	et	3	main
on	doc_491521502055_item	3551535	et	4	main
ka	doc_491521502055_item	3551536	et	3	main
arvutikasutusoskus	doc_491521502055_item	3551537	et	3	main
pakume	doc_491521502055_item	3551538	et	3	main
mugavaid	doc_491521502055_item	3551539	et	3	main
töötingimusi	doc_491521502055_item	3551540	et	3	main
teile	doc_491521502055_item	3551541	et	4	main
kakuke	doc_491521502055_item	3551555	et	4	main
direktor	doc_491521502055_item	3551556	et	3	main
lugesin	doc_491521502055_item	3551557	et	3	main
teie	doc_491521502055_item	3551558	et	4	main
avatakse	doc_491521502055_item	3551564	et	4	main
uus	doc_491521502055_item	3551565	et	3	main
toidukauplus	doc_491521502055_item	3551566	et	3	main
kauplusesse	doc_491521502055_item	3551567	et	4	main
poes	doc_491521502055_item	3551573	et	3	main
aidake	doc_986203247110_item	3551450	et	4	main
meile	doc_986203247110_item	3551451	et	4	main
sest	doc_986203247110_item	3551452	et	4	main
see	doc_986203247110_item	3551453	et	3	main
on	doc_986203247110_item	3551454	et	4	main
väga	doc_986203247110_item	3551455	et	3	main
oluline	doc_986203247110_item	3551456	et	4	main
meile	doc_986203247110_item	3551457	et	4	main
jaoks	doc_986203247110_item	3551458	et	4	main
olla	doc_986203247110_item	3551459	et	3	main
kultuuri	doc_986203247110_item	3551460	et	4	main
ettendusel	doc_986203247110_item	3551461	et	4	main
jääme	doc_986203247110_item	3551462	et	4	main
ootama	doc_986203247110_item	3551463	et	3	main
teie	doc_986203247110_item	3551464	et	4	main
vastus	doc_986203247110_item	3551465	et	3	main
ja	doc_986203247110_item	3551466	et	3	main
loodame	doc_986203247110_item	3551467	et	3	main
paremat	doc_986203247110_item	3551468	et	4	main
grupivanem	doc_986203247110_item	3551469	et	4	main
ärge	doc_986203247110_item	3551470	et	3	main
kirjutage	doc_986203247110_item	3551471	et	3	main
sellest	doc_986203247110_item	3551472	et	4	main
joonest	doc_986203247110_item	3551473	et	4	main
allapoole	doc_986203247110_item	3551474	et	3	main
u	doc_986203247110_item	3551380	et	4	main
meie	doc_986203247110_item	3551389	et	4	main
grupp	doc_986203247110_item	3551390	et	3	main
teatrireisile	doc_986203247110_item	3551393	et	3	main
teatrisse	doc_986203247110_item	3551399	et	3	main
reis	doc_986203247110_item	3551400	et	4	main
toimub	doc_986203247110_item	3551401	et	3	main
2122	doc_986203247110_item	3551402	et	2	main
juunil	doc_986203247110_item	3551403	et	3	main
ja	doc_986203247110_item	3551404	et	3	main
reisi	doc_986203247110_item	3551405	et	4	main
hind	doc_986203247110_item	3551406	et	3	main
on	doc_986203247110_item	3551407	et	4	main
1500	doc_986203247110_item	3551408	et	2	main
eek	doc_986203247110_item	3551409	et	4	main
ühe	doc_986203247110_item	3551410	et	4	main
inimesele	doc_986203247110_item	3551411	et	3	main
meie	doc_986203247110_item	3551412	et	4	main
grupis	doc_986203247110_item	3551413	et	3	main
on	doc_986203247110_item	3551414	et	4	main
22	doc_986203247110_item	3551415	et	2	main
inimest	doc_986203247110_item	3551416	et	3	main
kui	doc_986203247110_item	3551417	et	3	main
te	doc_986203247110_item	3551418	et	4	main
saaksite	doc_986203247110_item	3551419	et	3	main
meile	doc_986203247110_item	3551420	et	4	main
aidata	doc_986203247110_item	3551421	et	4	main
me	doc_986203247110_item	3551422	et	4	main
oleksime	doc_986203247110_item	3551423	et	3	main
rõõmsaid	doc_986203247110_item	3551424	et	3	main
meil	doc_986203247110_item	3551425	et	4	main
hinna	doc_986203247110_item	3551430	et	3	main
edasi-tagasi	doc_986203247110_item	3551434	et	3	main
ermitaaži	doc_986203247110_item	3551444	et	2	main
kuulutus	doc_491521502055_item	3551479	et	4	main
sellele	doc_491521502055_item	3551482	et	4	main
umbes	doc_491521502055_item	3551486	et	4	main
hobid	doc_491521502055_item	3551497	et	3	main
soovidest	doc_491521502055_item	3551501	et	3	main
kahe	doc_491521502055_item	3551512	et	3	main
avatakse	doc_491521502055_item	3551515	et	4	main
toidukauplus	doc_491521502055_item	3551517	et	3	main
lisainfo	doc_491521502055_item	3551546	et	4	main
as	doc_491521502055_item	3551547	et	4	main
kakuke	doc_491521502055_item	3551548	et	4	main
juhuslik	doc_491521502055_item	3551549	et	3	main
lugupeetud	doc_491521502055_item	3551553	et	4	main
as	doc_491521502055_item	3551554	et	4	main
tahan	doc_491521502055_item	3551572	et	3	main
olen	doc_491521502055_item	3551575	et	3	main
kolm	doc_491521502055_item	3551577	et	3	main
on	doc_491521502055_item	3551595	et	4	main
mul	doc_491521502055_item	3551596	et	3	main
lugege	doc_491521502057_item	3551636	et	3	main
ennast	doc_491521502057_item	3551649	et	4	main
haridus	doc_491521502057_item	3551651	et	3	main
autojuhiload	doc_491521502057_item	3551655	et	4	main
ja	doc_491521502057_item	3551657	et	3	main
milline	doc_491521502057_item	3551668	et	3	main
kahe	doc_491521502057_item	3551671	et	3	main
avatakse	doc_491521502057_item	3551674	et	4	main
uus	doc_491521502057_item	3551675	et	3	main
toidukauplus	doc_491521502057_item	3551676	et	3	main
kauplusse	doc_491521502057_item	3551677	et	3	main
vajatakse	doc_491521502057_item	3551678	et	4	main
ootame	doc_491521502057_item	3551685	et	3	main
mul	doc_491521502057_item	3551727	et	3	main
on	doc_491521502057_item	3551728	et	4	main
oma	doc_491521502057_item	3551745	et	4	main
5	doc_491521502057_item	3551762	et	2	main
ma	doc_491521502057_item	3551765	et	3	main
nagemiseni	doc_491521502057_item	3551778	et	4	main
kiri	doc_491521502060_item	3551973	et	3	main
olema	doc_491521502060_item	3551982	et	4	main
oma	doc_491521502060_item	3551997	et	4	main
kuu	doc_491521502060_item	3552010	et	4	main
kassapidajat	doc_491521502060_item	3552018	et	3	main
palka	doc_491521502060_item	3552042	et	4	main
lisainfo	doc_491521502060_item	3552043	et	4	main
tallinn	doc_491521502060_item	3552049	et	4	main
olen	doc_491521502060_item	3552058	et	3	main
mul	doc_491521502060_item	3552060	et	3	main
töökogemust	doc_491521502060_item	3552066	et	3	main
ma	doc_491521502060_item	3552068	et	3	main
mul	doc_491521502060_item	3552111	et	3	main
kirjas	doc_491521502055_item	3551483	et	4	main
sõna	doc_491521502055_item	3551488	et	4	main
haridus	doc_491521502055_item	3551492	et	3	main
töökogemused	doc_491521502055_item	3551493	et	3	main
keelteoskus	doc_491521502055_item	3551494	et	3	main
arvutioskus	doc_491521502055_item	3551495	et	3	main
autojuhiload	doc_491521502055_item	3551496	et	4	main
kirjutage	doc_491521502055_item	3551499	et	3	main
millist	doc_491521502055_item	3551502	et	3	main
kuu	doc_491521502055_item	3551513	et	4	main
turvamehi	doc_491521502055_item	3551522	et	3	main
keele	doc_491521502055_item	3551530	et	4	main
head	doc_491521502055_item	3551532	et	4	main
suhtlemisoskust	doc_491521502055_item	3551533	et	3	main
soovitav	doc_491521502055_item	3551534	et	4	main
palka	doc_491521502055_item	3551545	et	4	main
kuulutuse	doc_491521502055_item	3551559	et	4	main
et	doc_491521502055_item	3551560	et	3	main
kahe	doc_491521502055_item	3551561	et	3	main
vajatakse	doc_491521502055_item	3551568	et	4	main
töötada	doc_491521502055_item	3551574	et	3	main
õppinud	doc_491521502055_item	3551576	et	4	main
müüja	doc_491521502055_item	3551579	et	4	main
erialat	doc_491521502055_item	3551580	et	4	main
vene	doc_491521502055_item	3551585	et	4	main
keelt	doc_491521502055_item	3551586	et	4	main
arvutikasutamisoskus	doc_491521502055_item	3551587	et	3	main
mul	doc_491521502055_item	3551588	et	3	main
hobbi	doc_491521502055_item	3551593	et	4	main
ja	doc_491521502055_item	3551600	et	3	main
suurt	doc_491521502055_item	3551506	et	3	main
töötasu	doc_491521502055_item	3551507	et	4	main
soovite	doc_491521502055_item	3551508	et	3	main
milline	doc_491521502055_item	3551509	et	3	main
müüjat	doc_491521502055_item	3551520	et	4	main
koristajaid	doc_491521502055_item	3551523	et	4	main
pakkijaid	doc_491521502055_item	3551524	et	4	main
kanditaatidelt	doc_491521502055_item	3551525	et	3	main
ootame	doc_491521502055_item	3551526	et	3	main
oskust	doc_491521502055_item	3551531	et	3	main
mnt	doc_491521502055_item	3551550	et	4	main
3	doc_491521502055_item	3551551	et	2	main
kuu	doc_491521502055_item	3551562	et	4	main
müüjat	doc_491521502055_item	3551569	et	4	main
väga	doc_491521502055_item	3551571	et	3	main
aastad	doc_491521502055_item	3551578	et	3	main
eesti	doc_491521502055_item	3551583	et	4	main
minu	doc_491521502055_item	3551592	et	3	main
olen	doc_491521502055_item	3551598	et	3	main
kiri	doc_491521502057_item	3551635	et	3	main
vastake	doc_491521502057_item	3551640	et	3	main
sellele	doc_491521502057_item	3551641	et	4	main
keelteoskus	doc_491521502057_item	3551653	et	3	main
oma	doc_491521502057_item	3551659	et	4	main
millist	doc_491521502057_item	3551661	et	3	main
kui	doc_491521502057_item	3551664	et	3	main
töögraafik	doc_491521502057_item	3551669	et	3	main
müüjat	doc_491521502057_item	3551679	et	4	main
ma	doc_491521502057_item	3551724	et	3	main
veel	doc_491521502057_item	3551742	et	4	main
autojuhiload	doc_491521502057_item	3551743	et	4	main
ja	doc_491521502057_item	3551744	et	3	main
nädalas	doc_491521502057_item	3551769	et	3	main
läbi	doc_491521502060_item	3551975	et	4	main
vastake	doc_491521502060_item	3551978	et	3	main
umbes	doc_491521502060_item	3551983	et	4	main
perekonnaseis	doc_491521502060_item	3551988	et	4	main
haridus	doc_491521502060_item	3551989	et	3	main
töökogemused	doc_491521502060_item	3551990	et	3	main
keelteoskus	doc_491521502060_item	3551991	et	3	main
arvutioskus	doc_491521502060_item	3551992	et	3	main
autojuhiload	doc_491521502060_item	3551993	et	4	main
hobid	doc_491521502060_item	3551994	et	3	main
ja	doc_491521502060_item	3551995	et	3	main
kirjutage	doc_491521502060_item	3551996	et	3	main
milline	doc_491521502060_item	3552006	et	3	main
sobib	doc_491521502060_item	3552008	et	3	main
turvamehi	doc_491521502060_item	3552019	et	3	main
mnt	doc_491521502060_item	3552047	et	4	main
eesnimi	doc_491521502060_item	3552055	et	3	main
mina	doc_491521502060_item	3552057	et	4	main
vallaline	doc_491521502060_item	3552059	et	4	main
ole	doc_491521502060_item	3552065	et	4	main
lõpetasin	doc_491521502060_item	3552069	et	3	main
sellel	doc_491521502060_item	3552071	et	4	main
eesti	doc_491521502055_item	3551527	et	4	main
ja	doc_491521502055_item	3551528	et	3	main
vene	doc_491521502055_item	3551529	et	4	main
sobivat	doc_491521502055_item	3551542	et	4	main
töögraafikut	doc_491521502055_item	3551543	et	3	main
kindlat	doc_491521502055_item	3551544	et	3	main
tallinn	doc_491521502055_item	3551552	et	4	main
pärast	doc_491521502055_item	3551563	et	4	main
ma	doc_491521502055_item	3551570	et	3	main
ma	doc_491521502055_item	3551581	et	3	main
ja	doc_491521502055_item	3551584	et	3	main
autojuhiload	doc_491521502055_item	3551594	et	4	main
olemas	doc_491521502055_item	3551597	et	4	main
vallaline	doc_491521502055_item	3551599	et	4	main
ja	doc_491521502057_item	3551639	et	3	main
kirjas	doc_491521502057_item	3551642	et	4	main
peab	doc_491521502057_item	3551643	et	4	main
tutvustage	doc_491521502057_item	3551648	et	3	main
perekonnaseis	doc_491521502057_item	3551650	et	4	main
arvutioskus	doc_491521502057_item	3551654	et	3	main
soovidest	doc_491521502057_item	3551660	et	3	main
tööd	doc_491521502057_item	3551662	et	4	main
suurt	doc_491521502057_item	3551665	et	3	main
soovite	doc_491521502057_item	3551667	et	3	main
kuu	doc_491521502057_item	3551672	et	4	main
kassapidajat	doc_491521502057_item	3551680	et	3	main
turvamehi	doc_491521502057_item	3551681	et	3	main
koristajaid	doc_491521502057_item	3551682	et	4	main
ja	doc_491521502057_item	3551687	et	3	main
keele	doc_491521502057_item	3551689	et	4	main
töötada	doc_491521502057_item	3551720	et	3	main
vene	doc_491521502057_item	3551735	et	4	main
keelt	doc_491521502057_item	3551736	et	4	main
ja	doc_491521502057_item	3551737	et	3	main
inglise	doc_491521502057_item	3551738	et	4	main
keelt	doc_491521502057_item	3551739	et	4	main
mul	doc_491521502057_item	3551740	et	3	main
on	doc_491521502057_item	3551741	et	4	main
valdan	doc_491521502055_item	3551582	et	3	main
on	doc_491521502055_item	3551589	et	4	main
see	doc_491521502055_item	3551590	et	3	main
on	doc_491521502055_item	3551591	et	4	main
selle	doc_491521502055_item	3551601	et	4	main
päras	doc_491521502055_item	3551602	et	3	main
töögraatik	doc_491521502055_item	3551603	et	4	main
mind	doc_491521502055_item	3551604	et	4	main
huvita	doc_491521502055_item	3551606	et	4	main
võin	doc_491521502055_item	3551607	et	3	main
töötada	doc_491521502055_item	3551608	et	3	main
iga	doc_491521502055_item	3551609	et	4	main
päev	doc_491521502055_item	3551610	et	3	main
800-2000	doc_491521502055_item	3551611	et	2	main
ei	doc_491521502055_item	3551605	et	4	main
tahaks	doc_491521502055_item	3551612	et	3	main
saada	doc_491521502055_item	3551613	et	4	main
4000-5000	doc_491521502055_item	3551614	et	2	main
krooni	doc_491521502055_item	3551615	et	4	main
kindlat	doc_491521502055_item	3551616	et	3	main
palka	doc_491521502055_item	3551617	et	4	main
olen	doc_491521502055_item	3551618	et	3	main
väga	doc_491521502055_item	3551619	et	3	main
viisakas	doc_491521502055_item	3551620	et	4	main
ei	doc_491521502055_item	3551621	et	4	main
joo	doc_491521502055_item	3551622	et	4	main
jua	doc_491521502055_item	3551623	et	4	main
ei	doc_491521502055_item	3551624	et	4	main
suitseta	doc_491521502055_item	3551625	et	4	main
väga	doc_491521502055_item	3551626	et	3	main
loodan	doc_491521502055_item	3551627	et	3	main
et	doc_491521502055_item	3551628	et	3	main
saan	doc_491521502055_item	3551629	et	4	main
teie	doc_491521502055_item	3551630	et	4	main
poes	doc_491521502055_item	3551631	et	3	main
tööd	doc_491521502055_item	3551632	et	4	main
aitäh	doc_491521502055_item	3551633	et	3	main
läbi	doc_491521502057_item	3551637	et	4	main
umbes	doc_491521502057_item	3551645	et	4	main
sõna	doc_491521502057_item	3551647	et	4	main
töökogemused	doc_491521502057_item	3551652	et	3	main
hobid	doc_491521502057_item	3551656	et	3	main
sobib	doc_491521502057_item	3551670	et	3	main
eesti	doc_491521502057_item	3551686	et	4	main
kauplusejuht	doc_491521502057_item	3551713	et	3	main
ma	doc_491521502057_item	3551714	et	3	main
lugesin	doc_491521502057_item	3551715	et	3	main
ajalehest	doc_491521502057_item	3551716	et	4	main
kuulutust	doc_491521502057_item	3551717	et	4	main
kuulutus	doc_491521502057_item	3551638	et	4	main
olema	doc_491521502057_item	3551644	et	4	main
60	doc_491521502057_item	3551646	et	2	main
kirjutage	doc_491521502057_item	3551658	et	3	main
soovite	doc_491521502057_item	3551663	et	3	main
töötasu	doc_491521502057_item	3551666	et	4	main
pärast	doc_491521502057_item	3551673	et	4	main
pakkijaid	doc_491521502057_item	3551683	et	4	main
kanditaatidelt	doc_491521502057_item	3551684	et	3	main
vene	doc_491521502057_item	3551688	et	4	main
oskust	doc_491521502057_item	3551690	et	3	main
head	doc_491521502057_item	3551691	et	4	main
suhtlemisoskust	doc_491521502057_item	3551692	et	3	main
soovitav	doc_491521502057_item	3551693	et	4	main
on	doc_491521502057_item	3551694	et	4	main
ka	doc_491521502057_item	3551695	et	3	main
arvutikasutusoskus	doc_491521502057_item	3551696	et	3	main
pakume	doc_491521502057_item	3551697	et	3	main
mugavaid	doc_491521502057_item	3551698	et	3	main
töötingimusi	doc_491521502057_item	3551699	et	3	main
teile	doc_491521502057_item	3551700	et	4	main
sobivat	doc_491521502057_item	3551701	et	4	main
töögraafikut	doc_491521502057_item	3551702	et	3	main
kindlat	doc_491521502057_item	3551703	et	3	main
palka	doc_491521502057_item	3551704	et	4	main
lisainfo	doc_491521502057_item	3551705	et	4	main
as	doc_491521502057_item	3551706	et	4	main
kakuke	doc_491521502057_item	3551707	et	4	main
tartu	doc_491521502057_item	3551708	et	4	main
mnt	doc_491521502057_item	3551709	et	4	main
3	doc_491521502057_item	3551710	et	2	main
tallinn	doc_491521502057_item	3551711	et	4	main
lugupeetud	doc_491521502057_item	3551712	et	4	main
elan	doc_491521502057_item	3551725	et	3	main
keskeri	doc_491521502057_item	3551729	et	4	main
haridus	doc_491521502057_item	3551730	et	3	main
ma	doc_491521502057_item	3551731	et	3	main
oskan	doc_491521502057_item	3551732	et	3	main
eesti	doc_491521502057_item	3551733	et	4	main
keelt	doc_491521502057_item	3551734	et	4	main
et	doc_491521502057_item	3551757	et	3	main
töötasu	doc_491521502057_item	3551758	et	4	main
oli	doc_491521502057_item	3551759	et	3	main
rohkem	doc_491521502057_item	3551760	et	4	main
kui	doc_491521502057_item	3551761	et	3	main
teineks	doc_491521502057_item	3551764	et	4	main
töötada5	doc_491521502057_item	3551767	et	3	main
tundi	doc_491521502057_item	3551771	et	4	main
ja	doc_491521502057_item	3551718	et	3	main
tahaksin	doc_491521502057_item	3551719	et	3	main
müüjana	doc_491521502057_item	3551721	et	4	main
teie	doc_491521502057_item	3551722	et	4	main
kaupluses	doc_491521502057_item	3551723	et	3	main
üksinda	doc_491521502057_item	3551726	et	4	main
soovitakse	doc_491521502057_item	3551756	et	4	main
tuhat	doc_491521502057_item	3551763	et	4	main
tahaksin	doc_491521502057_item	3551766	et	3	main
kaheksa-üheksa	doc_491521502057_item	3551770	et	4	main
päevas	doc_491521502057_item	3551772	et	3	main
pole	doc_491521502057_item	3551773	et	3	main
auto	doc_491521502057_item	3551746	et	4	main
palun	doc_491521502057_item	3551747	et	3	main
vastake	doc_491521502057_item	3551748	et	3	main
esiteks	doc_491521502057_item	3551749	et	3	main
kui	doc_491521502057_item	3551750	et	3	main
suur	doc_491521502057_item	3551751	et	3	main
saab	doc_491521502057_item	3551752	et	3	main
olla	doc_491521502057_item	3551753	et	3	main
minu	doc_491521502057_item	3551754	et	3	main
palk	doc_491521502057_item	3551755	et	3	main
päeva	doc_491521502057_item	3551768	et	4	main
rohkem	doc_491521502057_item	3551774	et	4	main
ma	doc_491521502057_item	3551775	et	3	main
ootan	doc_491521502057_item	3551776	et	3	main
vastust	doc_491521502057_item	3551777	et	4	main
lugege	doc_491521502060_item	3551974	et	3	main
peab	doc_491521502060_item	3551981	et	4	main
sõna	doc_491521502060_item	3551985	et	4	main
ennast	doc_491521502060_item	3551987	et	4	main
millist	doc_491521502060_item	3551999	et	3	main
kindlat	doc_491521502060_item	3552041	et	3	main
3	doc_491521502060_item	3552048	et	2	main
lugupeetud	doc_491521502060_item	3552050	et	4	main
olen	doc_491521502060_item	3552054	et	3	main
perekonnanimi	doc_491521502060_item	3552056	et	3	main
on	doc_491521502060_item	3552061	et	4	main
kõrgharidus	doc_491521502060_item	3552062	et	3	main
mul	doc_491521502060_item	3552063	et	3	main
tpü-i	doc_491521502060_item	3552070	et	4	main
aastal	doc_491521502060_item	3552072	et	3	main
ma	doc_491521502060_item	3552106	et	3	main
kaupluses	doc_491521502060_item	3552110	et	3	main
müüja	doc_491521502060_item	3552114	et	4	main
et	doc_491521502060_item	3552117	et	3	main
4	doc_491521502060_item	3552124	et	2	main
kuus	doc_491521502060_item	3552126	et	4	main
et	doc_491521502060_item	3552129	et	3	main
lugege	doc_491521502061_item	3552152	et	3	main
peab	doc_491521502061_item	3552159	et	4	main
millist	doc_491521502061_item	3552177	et	3	main
soovite	doc_491521502061_item	3552179	et	3	main
kui	doc_491521502061_item	3552180	et	3	main
milline	doc_491521502061_item	3552184	et	3	main
keele	doc_491521502061_item	3552205	et	4	main
oskust	doc_491521502061_item	3552206	et	3	main
head	doc_491521502061_item	3552207	et	4	main
suhtlemisoskust	doc_491521502061_item	3552208	et	3	main
sobivat	doc_491521502061_item	3552217	et	4	main
et	doc_491521502061_item	3552253	et	3	main
tahaksin	doc_491521502061_item	3552255	et	3	main
töökoht	doc_491521502061_item	3552257	et	3	main
mul	doc_491521502061_item	3552258	et	3	main
ma	doc_491521502061_item	3552263	et	3	main
firmas	doc_491521502061_item	3552265	et	3	main
ma	doc_491521502061_item	3552267	et	3	main
töötama	doc_491521502061_item	3552269	et	3	main
arvutiga	doc_491521502061_item	3552270	et	4	main
keelt	doc_491521502061_item	3552275	et	4	main
mul	doc_491521502061_item	3552277	et	3	main
ole	doc_491521502061_item	3552279	et	4	main
abikaasa	doc_491521502061_item	3552280	et	4	main
ja	doc_491521502061_item	3552281	et	3	main
on	doc_491521502061_item	3552292	et	4	main
tahaksin	doc_491521502061_item	3552298	et	3	main
ma	doc_491521502061_item	3552301	et	3	main
väga	doc_491521502061_item	3552308	et	3	main
ja	doc_491521502061_item	3552316	et	3	main
autojuhiloa	doc_491521502061_item	3552317	et	4	main
ma	doc_491521502061_item	3552318	et	3	main
oleks	doc_491521502061_item	3552323	et	3	main
5000	doc_491521502061_item	3552325	et	2	main
arvan	doc_491521502061_item	3552327	et	3	main
soobib	doc_491521502061_item	3552330	et	4	main
kandidaat	doc_491521502061_item	3552331	et	3	main
teile	doc_491521502061_item	3552332	et	4	main
läbi	doc_491521501950_item	3552354	et	4	main
kuulutus	doc_491521502060_item	3551976	et	4	main
ja	doc_491521502060_item	3551977	et	3	main
sellele	doc_491521502060_item	3551979	et	4	main
60	doc_491521502060_item	3551984	et	2	main
soovidest	doc_491521502060_item	3551998	et	3	main
soovite	doc_491521502060_item	3552001	et	3	main
töötasu	doc_491521502060_item	3552004	et	4	main
kahe	doc_491521502060_item	3552009	et	3	main
pärast	doc_491521502060_item	3552011	et	4	main
avatakse	doc_491521502060_item	3552012	et	4	main
uus	doc_491521502060_item	3552013	et	3	main
toidukauplus	doc_491521502060_item	3552014	et	3	main
kauplusse	doc_491521502060_item	3552015	et	3	main
vajatakse	doc_491521502060_item	3552016	et	4	main
as	doc_491521502060_item	3552044	et	4	main
kakuke	doc_491521502060_item	3552045	et	4	main
mina	doc_491521502060_item	3552053	et	4	main
ei	doc_491521502060_item	3552064	et	4	main
ma	doc_491521502060_item	3552073	et	3	main
rääkida	doc_491521502060_item	3552075	et	3	main
keelt	doc_491521502060_item	3552077	et	4	main
ja	doc_491521502060_item	3552078	et	3	main
sobiks	doc_491521502060_item	3552112	et	4	main
töö	doc_491521502060_item	3552131	et	4	main
kiri	doc_491521502061_item	3552151	et	3	main
vastake	doc_491521502061_item	3552156	et	3	main
sõna	doc_491521502061_item	3552163	et	4	main
tutvustage	doc_491521502061_item	3552164	et	3	main
perekonnaseis	doc_491521502061_item	3552166	et	4	main
haridus	doc_491521502061_item	3552167	et	3	main
töökogemused	doc_491521502061_item	3552168	et	3	main
keelteoskus	doc_491521502061_item	3552169	et	3	main
arvutioskus	doc_491521502061_item	3552170	et	3	main
autojuhiload	doc_491521502061_item	3552171	et	4	main
hobid	doc_491521502061_item	3552172	et	3	main
ja	doc_491521502061_item	3552173	et	3	main
kirjutage	doc_491521502061_item	3552174	et	3	main
töötasu	doc_491521502061_item	3552182	et	4	main
kahe	doc_491521502061_item	3552187	et	3	main
pärast	doc_491521502061_item	3552189	et	4	main
pakkijaid	doc_491521502061_item	3552199	et	4	main
ootame	doc_491521502061_item	3552201	et	3	main
ja	doc_491521502061_item	3552203	et	3	main
vene	doc_491521502061_item	3552204	et	4	main
mugavaid	doc_491521502061_item	3552214	et	3	main
töötingimusi	doc_491521502061_item	3552215	et	3	main
sellepärast	doc_491521502061_item	3552252	et	3	main
kaubandus	doc_491521502061_item	3552260	et	3	main
ei	doc_491521502061_item	3552282	et	4	main
ei	doc_491521502061_item	3552289	et	4	main
töötama	doc_491521502061_item	3552294	et	3	main
olen	doc_491521502061_item	3552302	et	3	main
aus	doc_491521502061_item	3552305	et	4	main
mulle	doc_491521502061_item	3552307	et	4	main
suheltada	doc_491521502061_item	3552310	et	4	main
on	doc_491521502061_item	3552313	et	4	main
oma	doc_491521502061_item	3552314	et	4	main
minu	doc_491521502061_item	3552321	et	3	main
kell	doc_491521502060_item	3552133	et	3	main
800	doc_491521502060_item	3552134	et	2	main
hommikul	doc_491521502060_item	3552135	et	3	main
ja	doc_491521502060_item	3552136	et	3	main
lõpeb	doc_491521502060_item	3552137	et	4	main
kell	doc_491521502060_item	3552138	et	3	main
1700	doc_491521502060_item	3552139	et	2	main
õhtul	doc_491521502060_item	3552140	et	3	main
aga	doc_491521502060_item	3552141	et	3	main
pühapäevadel	doc_491521502060_item	3552142	et	3	main
ma	doc_491521502060_item	3552143	et	3	main
tahaksin	doc_491521502060_item	3552144	et	3	main
alati	doc_491521502060_item	3552145	et	4	main
puhata	doc_491521502060_item	3552146	et	4	main
lugupidamisega	doc_491521502060_item	3552147	et	3	main
eesnimi	doc_491521502060_item	3552148	et	3	main
perekonnanimi	doc_491521502060_item	3552149	et	3	main
kirjas	doc_491521502060_item	3551980	et	4	main
tutvustage	doc_491521502060_item	3551986	et	3	main
tööd	doc_491521502060_item	3552000	et	4	main
kui	doc_491521502060_item	3552002	et	3	main
suurt	doc_491521502060_item	3552003	et	3	main
soovite	doc_491521502060_item	3552005	et	3	main
töögraafik	doc_491521502060_item	3552007	et	3	main
müüjat	doc_491521502060_item	3552017	et	4	main
koristajaid	doc_491521502060_item	3552020	et	4	main
pakkijaid	doc_491521502060_item	3552021	et	4	main
kanditaatidelt	doc_491521502060_item	3552022	et	3	main
ootame	doc_491521502060_item	3552023	et	3	main
eesti	doc_491521502060_item	3552024	et	4	main
ja	doc_491521502060_item	3552025	et	3	main
vene	doc_491521502060_item	3552026	et	4	main
keele	doc_491521502060_item	3552027	et	4	main
oskust	doc_491521502060_item	3552028	et	3	main
head	doc_491521502060_item	3552029	et	4	main
suhtlemisoskust	doc_491521502060_item	3552030	et	3	main
soovitav	doc_491521502060_item	3552031	et	4	main
on	doc_491521502060_item	3552032	et	4	main
ka	doc_491521502060_item	3552033	et	3	main
arvutikasutusoskus	doc_491521502060_item	3552034	et	3	main
pakume	doc_491521502060_item	3552035	et	3	main
mugavaid	doc_491521502060_item	3552036	et	3	main
töötingimusi	doc_491521502060_item	3552037	et	3	main
teile	doc_491521502060_item	3552038	et	4	main
sobivat	doc_491521502060_item	3552039	et	4	main
töögraafikut	doc_491521502060_item	3552040	et	3	main
tartu	doc_491521502060_item	3552046	et	4	main
as	doc_491521502060_item	3552051	et	4	main
kakuke	doc_491521502060_item	3552052	et	4	main
sest	doc_491521502060_item	3552067	et	4	main
tahaksin	doc_491521502060_item	3552107	et	3	main
teie	doc_491521502060_item	3552109	et	4	main
ma	doc_491521502060_item	3552115	et	3	main
tahaksin	doc_491521502060_item	3552116	et	3	main
töötasu	doc_491521502060_item	3552119	et	4	main
umbes	doc_491521502060_item	3552121	et	4	main
tuhat	doc_491521502060_item	3552125	et	4	main
ma	doc_491521502060_item	3552127	et	3	main
minu	doc_491521502060_item	3552130	et	3	main
algab	doc_491521502060_item	3552132	et	3	main
oskan	doc_491521502060_item	3552074	et	3	main
vene	doc_491521502060_item	3552076	et	4	main
eesti	doc_491521502060_item	3552079	et	4	main
keelt	doc_491521502060_item	3552080	et	4	main
aga	doc_491521502060_item	3552081	et	3	main
eesti	doc_491521502060_item	3552082	et	4	main
keelt	doc_491521502060_item	3552083	et	4	main
pole	doc_491521502060_item	3552084	et	3	main
eriti	doc_491521502060_item	3552085	et	3	main
hästi	doc_491521502060_item	3552086	et	3	main
mul	doc_491521502060_item	3552087	et	3	main
ei	doc_491521502060_item	3552088	et	4	main
ole	doc_491521502060_item	3552089	et	4	main
autojuhiload	doc_491521502060_item	3552090	et	4	main
sest	doc_491521502060_item	3552091	et	4	main
mul	doc_491521502060_item	3552092	et	3	main
ei	doc_491521502060_item	3552093	et	4	main
ole	doc_491521502060_item	3552094	et	4	main
autot	doc_491521502060_item	3552095	et	3	main
mul	doc_491521502060_item	3552096	et	3	main
on	doc_491521502060_item	3552097	et	4	main
hobid	doc_491521502060_item	3552098	et	3	main
ma	doc_491521502060_item	3552099	et	3	main
armastan	doc_491521502060_item	3552100	et	3	main
õmmelda	doc_491521502060_item	3552101	et	4	main
ja	doc_491521502060_item	3552102	et	3	main
kuududa	doc_491521502060_item	3552103	et	4	main
igasuguseid	doc_491521502060_item	3552104	et	3	main
riideid	doc_491521502060_item	3552105	et	3	main
töötada	doc_491521502060_item	3552108	et	3	main
või	doc_491521502060_item	3552123	et	4	main
tahaksin	doc_491521502060_item	3552128	et	3	main
kuulutus	doc_491521502061_item	3552154	et	4	main
sellele	doc_491521502061_item	3552157	et	4	main
soovite	doc_491521502061_item	3552183	et	3	main
töögraafik	doc_491521502061_item	3552185	et	3	main
müüjat	doc_491521502061_item	3552195	et	4	main
turvamehi	doc_491521502061_item	3552197	et	3	main
pakume	doc_491521502061_item	3552213	et	3	main
teile	doc_491521502061_item	3552216	et	4	main
on	doc_491521502061_item	3552259	et	4	main
ja	doc_491521502061_item	3552271	et	3	main
rääkima	doc_491521502061_item	3552276	et	3	main
ole	doc_491521502061_item	3552283	et	4	main
joo	doc_491521502061_item	3552290	et	4	main
mul	doc_491521502061_item	3552291	et	3	main
iga	doc_491521502061_item	3552295	et	4	main
ma	doc_491521502061_item	3552297	et	3	main
inimestega	doc_491521502061_item	3552311	et	3	main
et	doc_491521502061_item	3552320	et	3	main
umbes	doc_491521502061_item	3552324	et	4	main
ma	doc_491521502061_item	3552329	et	3	main
kiri	doc_491521501950_item	3552352	et	3	main
ja	doc_491521501950_item	3552356	et	3	main
tutvustage	doc_491521501950_item	3552365	et	3	main
haridus	doc_491521501950_item	3552368	et	3	main
keelteoskus	doc_491521501950_item	3552370	et	3	main
hobid	doc_491521501950_item	3552373	et	3	main
kirjutage	doc_491521501950_item	3552375	et	3	main
soovidest	doc_491521501950_item	3552377	et	3	main
tööd	doc_491521501950_item	3552379	et	4	main
soovite	doc_491521501950_item	3552380	et	3	main
kui	doc_491521501950_item	3552381	et	3	main
suurt	doc_491521501950_item	3552382	et	3	main
müüjat	doc_491521501950_item	3552396	et	4	main
turvamehi	doc_491521501950_item	3552398	et	3	main
eesti	doc_491521501950_item	3552403	et	4	main
ja	doc_491521501950_item	3552404	et	3	main
keele	doc_491521501950_item	3552406	et	4	main
oskust	doc_491521501950_item	3552407	et	3	main
head	doc_491521501950_item	3552408	et	4	main
suhtlemisoskust	doc_491521501950_item	3552409	et	3	main
sobivat	doc_491521501950_item	3552418	et	4	main
mnt	doc_491521501950_item	3552426	et	4	main
tallinn	doc_491521501950_item	3552428	et	4	main
lugupeetud	doc_491521501950_item	3552429	et	4	main
tahaksin	doc_491521501950_item	3552436	et	3	main
keelt	doc_491521501950_item	3552463	et	4	main
jua	doc_491521501950_item	3552465	et	4	main
keelt	doc_491521501950_item	3552467	et	4	main
arvuti	doc_491521501950_item	3552471	et	4	main
ja	doc_491521501950_item	3552473	et	3	main
ma	doc_491521501950_item	3552482	et	3	main
ja	doc_491521501950_item	3552485	et	3	main
13-aastane	doc_491521501950_item	3552492	et	4	main
ma	doc_491521501950_item	3552493	et	3	main
on	doc_491521501950_item	3552502	et	4	main
päeviti	doc_491521501950_item	3552503	et	3	main
üheksast	doc_491521501950_item	3552504	et	4	main
kiri	doc_491521501951_item	3552523	et	3	main
vastake	doc_491521501951_item	3552528	et	3	main
kirjas	doc_491521501951_item	3552530	et	4	main
peab	doc_491521501951_item	3552531	et	4	main
tutvustage	doc_491521501951_item	3552536	et	3	main
haridus	doc_491521501951_item	3552539	et	3	main
keelteoskus	doc_491521501951_item	3552541	et	3	main
autojuhiload	doc_491521501951_item	3552543	et	4	main
kirjutage	doc_491521501951_item	3552546	et	3	main
soovidest	doc_491521501951_item	3552548	et	3	main
pärast	doc_491521501951_item	3552561	et	4	main
pakkijaid	doc_491521501951_item	3552571	et	4	main
kanditaatidelt	doc_491521501951_item	3552572	et	3	main
ootame	doc_491521501951_item	3552573	et	3	main
soovitav	doc_491521501951_item	3552581	et	4	main
teile	doc_491521501951_item	3552588	et	4	main
müüjat	doc_491521501951_item	3552623	et	4	main
mul	doc_491521501951_item	3552650	et	3	main
autojuhiload	doc_491521501951_item	3552652	et	4	main
hobi	doc_491521501951_item	3552654	et	4	main
on	doc_491521501951_item	3552655	et	4	main
näiteks	doc_491521502060_item	3552113	et	4	main
minu	doc_491521502060_item	3552118	et	3	main
oleks	doc_491521502060_item	3552120	et	3	main
3	doc_491521502060_item	3552122	et	2	main
läbi	doc_491521502061_item	3552153	et	4	main
ennast	doc_491521502061_item	3552165	et	4	main
kuu	doc_491521502061_item	3552188	et	4	main
avatakse	doc_491521502061_item	3552190	et	4	main
uus	doc_491521502061_item	3552191	et	3	main
toidukauplus	doc_491521502061_item	3552192	et	3	main
kauplusse	doc_491521502061_item	3552193	et	3	main
vajatakse	doc_491521502061_item	3552194	et	4	main
kanditaatidelt	doc_491521502061_item	3552200	et	3	main
soovitav	doc_491521502061_item	3552209	et	4	main
mind	doc_491521502061_item	3552251	et	4	main
vene	doc_491521502061_item	3552274	et	4	main
ei	doc_491521502061_item	3552278	et	4	main
ma	doc_491521502061_item	3552285	et	3	main
ei	doc_491521502061_item	3552286	et	4	main
suitseta	doc_491521502061_item	3552287	et	4	main
ja	doc_491521502061_item	3552288	et	3	main
võimalus	doc_491521502061_item	3552293	et	3	main
paev	doc_491521502061_item	3552296	et	4	main
töötada	doc_491521502061_item	3552299	et	3	main
viisakas	doc_491521502061_item	3552303	et	4	main
auto	doc_491521502061_item	3552315	et	4	main
kuulutus	doc_491521501950_item	3552355	et	4	main
sellele	doc_491521501950_item	3552358	et	4	main
perekonnaseis	doc_491521501950_item	3552367	et	4	main
töötasu	doc_491521501950_item	3552383	et	4	main
töögraafik	doc_491521501950_item	3552386	et	3	main
kahe	doc_491521501950_item	3552388	et	3	main
pärast	doc_491521501950_item	3552390	et	4	main
ootame	doc_491521501950_item	3552402	et	3	main
vene	doc_491521501950_item	3552405	et	4	main
töötingimusi	doc_491521501950_item	3552416	et	3	main
palka	doc_491521501950_item	3552421	et	4	main
perekonnanimi	doc_491521501950_item	3552435	et	3	main
müüana	doc_491521501950_item	3552438	et	4	main
viis	doc_491521501950_item	3552442	et	4	main
tagasi	doc_491521501950_item	3552444	et	3	main
ja	doc_491521501950_item	3552447	et	3	main
kaubamajas	doc_491521501950_item	3552452	et	3	main
müüana	doc_491521501950_item	3552453	et	4	main
mul	doc_491521501950_item	3552454	et	3	main
on	doc_491521501950_item	3552455	et	4	main
suur	doc_491521501950_item	3552456	et	3	main
töökogemus	doc_491521501950_item	3552457	et	3	main
ma	doc_491521501950_item	3552458	et	3	main
oskan	doc_491521501950_item	3552459	et	3	main
vene	doc_491521501950_item	3552460	et	4	main
ja	doc_491521501950_item	3552461	et	3	main
eesti	doc_491521501950_item	3552462	et	4	main
on	doc_491521502061_item	3552341	et	4	main
sillamäe	doc_491521502061_item	3552342	et	3	main
juhuslik	doc_491521502061_item	3552343	et	3	main
tn	doc_491521502061_item	3552344	et	4	main
11-11	doc_491521502061_item	3552345	et	2	main
lugupidamisega	doc_491521502061_item	3552346	et	3	main
tel	doc_491521502061_item	3552347	et	4	main
55-555	doc_491521502061_item	3552348	et	2	main
eesnimi	doc_491521502061_item	3552349	et	3	main
allkiri	doc_491521502061_item	3552350	et	3	main
ja	doc_491521502061_item	3552155	et	3	main
kirjas	doc_491521502061_item	3552158	et	4	main
olema	doc_491521502061_item	3552160	et	4	main
umbes	doc_491521502061_item	3552161	et	4	main
60	doc_491521502061_item	3552162	et	2	main
oma	doc_491521502061_item	3552175	et	4	main
soovidest	doc_491521502061_item	3552176	et	3	main
tööd	doc_491521502061_item	3552178	et	4	main
suurt	doc_491521502061_item	3552181	et	3	main
sobib	doc_491521502061_item	3552186	et	3	main
kassapidajat	doc_491521502061_item	3552196	et	3	main
koristajaid	doc_491521502061_item	3552198	et	4	main
eesti	doc_491521502061_item	3552202	et	4	main
on	doc_491521502061_item	3552210	et	4	main
ka	doc_491521502061_item	3552211	et	3	main
arvutikasutusoskus	doc_491521502061_item	3552212	et	3	main
töögraafikut	doc_491521502061_item	3552218	et	3	main
kindlat	doc_491521502061_item	3552219	et	3	main
palka	doc_491521502061_item	3552220	et	4	main
lisainfo	doc_491521502061_item	3552221	et	4	main
as	doc_491521502061_item	3552222	et	4	main
kakuke	doc_491521502061_item	3552223	et	4	main
tartu	doc_491521502061_item	3552224	et	4	main
mnt	doc_491521502061_item	3552225	et	4	main
3	doc_491521502061_item	3552226	et	2	main
tallinn	doc_491521502061_item	3552227	et	4	main
as	doc_491521502061_item	3552228	et	4	main
kakuke	doc_491521502061_item	3552229	et	4	main
tartu	doc_491521502061_item	3552230	et	4	main
mnt	doc_491521502061_item	3552231	et	4	main
3	doc_491521502061_item	3552232	et	2	main
tallinn	doc_491521502061_item	3552233	et	4	main
18092000	doc_491521502061_item	3552234	et	2	main
a	doc_491521502061_item	3552235	et	4	main
avaldus	doc_491521502061_item	3552236	et	4	main
lugupeetud	doc_491521502061_item	3552237	et	4	main
direktor	doc_491521502061_item	3552238	et	3	main
ma	doc_491521502061_item	3552239	et	3	main
lugesin	doc_491521502061_item	3552240	et	3	main
läbi	doc_491521502061_item	3552241	et	4	main
teie	doc_491521502061_item	3552242	et	4	main
kuulutuse	doc_491521502061_item	3552243	et	4	main
et	doc_491521502061_item	3552244	et	3	main
varsti	doc_491521502061_item	3552245	et	3	main
avatakse	doc_491521502061_item	3552246	et	4	main
uus	doc_491521502061_item	3552247	et	3	main
toidukauplus	doc_491521502061_item	3552248	et	3	main
see	doc_491521502061_item	3552249	et	3	main
huvitub	doc_491521502061_item	3552250	et	3	main
ma	doc_491521502061_item	3552254	et	3	main
saada	doc_491521502061_item	3552256	et	4	main
kõrgharidus	doc_491521502061_item	3552261	et	3	main
varem	doc_491521502061_item	3552262	et	4	main
töötasin	doc_491521502061_item	3552264	et	3	main
raamatupidajana	doc_491521502061_item	3552266	et	3	main
oskan	doc_491521502061_item	3552268	et	3	main
eesti	doc_491521502061_item	3552272	et	4	main
ja	doc_491521502061_item	3552273	et	3	main
lapsi	doc_491521502061_item	3552284	et	4	main
müüjana	doc_491521502061_item	3552300	et	4	main
ja	doc_491521502061_item	3552304	et	3	main
inimene	doc_491521502061_item	3552306	et	3	main
meeldib	doc_491521502061_item	3552309	et	3	main
mul	doc_491521502061_item	3552312	et	3	main
tahaksin	doc_491521502061_item	3552319	et	3	main
palk	doc_491521502061_item	3552322	et	3	main
krooni	doc_491521502061_item	3552326	et	4	main
et	doc_491521502061_item	3552328	et	3	main
toidukauplusele	doc_491521502061_item	3552333	et	3	main
jaoks	doc_491521502061_item	3552334	et	4	main
ootan	doc_491521502061_item	3552335	et	3	main
teid	doc_491521502061_item	3552336	et	4	main
vastu	doc_491521502061_item	3552337	et	3	main
kiri	doc_491521502061_item	3552338	et	3	main
minu	doc_491521502061_item	3552339	et	3	main
aadress	doc_491521502061_item	3552340	et	3	main
peab	doc_491521501950_item	3552360	et	4	main
sõna	doc_491521501950_item	3552364	et	4	main
töökogemused	doc_491521501950_item	3552369	et	3	main
millist	doc_491521501950_item	3552378	et	3	main
avatakse	doc_491521501950_item	3552391	et	4	main
uus	doc_491521501950_item	3552392	et	3	main
toidukauplus	doc_491521501950_item	3552393	et	3	main
kauplusse	doc_491521501950_item	3552394	et	3	main
vajatakse	doc_491521501950_item	3552395	et	4	main
kanditaatidelt	doc_491521501950_item	3552401	et	3	main
on	doc_491521501950_item	3552411	et	4	main
mugavaid	doc_491521501950_item	3552415	et	3	main
kakuke	doc_491521501950_item	3552424	et	4	main
tartu	doc_491521501950_item	3552425	et	4	main
kakuke	doc_491521501950_item	3552431	et	4	main
lõpetasin	doc_491521501950_item	3552441	et	3	main
tehnikum	doc_491521501950_item	3552446	et	3	main
inglise	doc_491521501950_item	3552466	et	4	main
natukene	doc_491521501950_item	3552468	et	4	main
ma	doc_491521501950_item	3552469	et	3	main
inimestega	doc_491521501950_item	3552481	et	3	main
on	doc_491521501950_item	3552487	et	4	main
12-	doc_491521501950_item	3552490	et	4	main
kuueni	doc_491521501950_item	3552505	et	4	main
õhtul	doc_491521501950_item	3552506	et	3	main
vastas	doc_491521501950_item	3552521	et	4	main
kuulutus	doc_491521501951_item	3552526	et	4	main
olema	doc_491521501951_item	3552532	et	4	main
umbes	doc_491521501951_item	3552533	et	4	main
60	doc_491521501951_item	3552534	et	2	main
perekonnaseis	doc_491521501951_item	3552538	et	4	main
töökogemused	doc_491521501951_item	3552540	et	3	main
ja	doc_491521501951_item	3552545	et	3	main
millist	doc_491521501951_item	3552549	et	3	main
kui	doc_491521501951_item	3552552	et	3	main
suurt	doc_491521501951_item	3552553	et	3	main
soovite	doc_491521501951_item	3552555	et	3	main
eesti	doc_491521501951_item	3552574	et	4	main
ja	doc_491521501951_item	3552575	et	3	main
tahaksin	doc_491521501951_item	3552659	et	3	main
sooviksin	doc_491521501951_item	3552670	et	3	main
krooni	doc_491521501951_item	3552673	et	4	main
mulle	doc_491521501951_item	3552676	et	4	main
pst	doc_491521501951_item	3552680	et	3	main
johvi	doc_491521501951_item	3552682	et	4	main
t	doc_491521501951_item	3552683	et	4	main
lugege	doc_491521501950_item	3552353	et	3	main
olema	doc_491521501950_item	3552361	et	4	main
umbes	doc_491521501950_item	3552362	et	4	main
60	doc_491521501950_item	3552363	et	2	main
autojuhiload	doc_491521501950_item	3552372	et	4	main
ja	doc_491521501950_item	3552374	et	3	main
soovite	doc_491521501950_item	3552384	et	3	main
kuu	doc_491521501950_item	3552389	et	4	main
koristajaid	doc_491521501950_item	3552399	et	4	main
pakkijaid	doc_491521501950_item	3552400	et	4	main
ka	doc_491521501950_item	3552412	et	3	main
arvutikasutusoskus	doc_491521501950_item	3552413	et	3	main
pakume	doc_491521501950_item	3552414	et	3	main
teile	doc_491521501950_item	3552417	et	4	main
töögraafikut	doc_491521501950_item	3552419	et	3	main
lisainfo	doc_491521501950_item	3552422	et	4	main
3	doc_491521501950_item	3552427	et	2	main
juhing	doc_491521501950_item	3552432	et	4	main
ma	doc_491521501950_item	3552433	et	3	main
eesnimi	doc_491521501950_item	3552434	et	3	main
kaupluses	doc_491521501950_item	3552437	et	3	main
töötada	doc_491521501950_item	3552439	et	3	main
viis	doc_491521501950_item	3552449	et	4	main
abc	doc_491521501950_item	3552451	et	4	main
lõpetasin	doc_491521501950_item	3552470	et	3	main
kursused	doc_491521501950_item	3552472	et	3	main
oskan	doc_491521501950_item	3552474	et	3	main
töötada	doc_491521501950_item	3552476	et	3	main
ma	doc_491521501950_item	3552477	et	3	main
suhtleda	doc_491521501950_item	3552480	et	4	main
teie	doc_491521501950_item	3552495	et	4	main
töötada	doc_491521501950_item	3552497	et	3	main
soobib	doc_491521501950_item	3552508	et	4	main
2	doc_491521501950_item	3552510	et	2	main
krooni	doc_491521501950_item	3552512	et	4	main
meie	doc_491521501950_item	3552513	et	4	main
ja	doc_491521501951_item	3552527	et	3	main
sellele	doc_491521501951_item	3552529	et	4	main
ennast	doc_491521501951_item	3552537	et	4	main
oma	doc_491521501951_item	3552547	et	4	main
soovite	doc_491521501951_item	3552551	et	3	main
avatakse	doc_491521501951_item	3552562	et	4	main
keele	doc_491521501951_item	3552577	et	4	main
oskust	doc_491521501951_item	3552578	et	3	main
head	doc_491521501951_item	3552579	et	4	main
suhtlemisoskust	doc_491521501951_item	3552580	et	3	main
arvutikasutusoskus	doc_491521501951_item	3552584	et	3	main
mugavaid	doc_491521501951_item	3552586	et	3	main
sobivat	doc_491521501951_item	3552589	et	4	main
töögraafikut	doc_491521501951_item	3552590	et	3	main
kassapidajaid	doc_491521501951_item	3552624	et	3	main
töötada	doc_491521501951_item	3552648	et	3	main
ma	doc_491521501951_item	3552658	et	3	main
müüjana	doc_491521501951_item	3552661	et	4	main
mulle	doc_491521501951_item	3552662	et	4	main
töötasu	doc_491521501951_item	3552671	et	4	main
palun	doc_491521501951_item	3552675	et	3	main
minu	doc_491521501951_item	3552677	et	3	main
juhuslik	doc_491521501951_item	3552679	et	3	main
vastake	doc_491521501950_item	3552357	et	3	main
kirjas	doc_491521501950_item	3552359	et	4	main
ennast	doc_491521501950_item	3552366	et	4	main
arvutioskus	doc_491521501950_item	3552371	et	3	main
oma	doc_491521501950_item	3552376	et	4	main
milline	doc_491521501950_item	3552385	et	3	main
sobib	doc_491521501950_item	3552387	et	3	main
kassapidajat	doc_491521501950_item	3552397	et	3	main
soovitav	doc_491521501950_item	3552410	et	4	main
kindlat	doc_491521501950_item	3552420	et	3	main
as	doc_491521501950_item	3552423	et	4	main
as	doc_491521501950_item	3552430	et	4	main
ma	doc_491521501950_item	3552440	et	3	main
aastat	doc_491521501950_item	3552443	et	3	main
kaubandus	doc_491521501950_item	3552445	et	3	main
töötasin	doc_491521501950_item	3552448	et	3	main
aastat	doc_491521501950_item	3552450	et	3	main
arvutiga	doc_491521501950_item	3552475	et	4	main
olen	doc_491521501950_item	3552483	et	3	main
abielus	doc_491521501950_item	3552484	et	4	main
mul	doc_491521501950_item	3552486	et	3	main
kaks	doc_491521501950_item	3552488	et	3	main
tütart	doc_491521501950_item	3552489	et	3	main
ja	doc_491521501950_item	3552491	et	3	main
kaupluses	doc_491521501950_item	3552496	et	3	main
minu	doc_491521501950_item	3552499	et	3	main
töögraafik	doc_491521501950_item	3552501	et	3	main
palk	doc_491521501950_item	3552509	et	3	main
tuhat	doc_491521501950_item	3552511	et	4	main
teie	doc_491521501950_item	3552520	et	4	main
läbi	doc_491521501951_item	3552525	et	4	main
töötasu	doc_491521501951_item	3552554	et	4	main
milline	doc_491521501951_item	3552556	et	3	main
töögraafik	doc_491521501951_item	3552557	et	3	main
sobib	doc_491521501951_item	3552558	et	3	main
kahe	doc_491521501951_item	3552559	et	3	main
kuu	doc_491521501951_item	3552560	et	4	main
vene	doc_491521501951_item	3552576	et	4	main
on	doc_491521501951_item	3552582	et	4	main
pakume	doc_491521501951_item	3552585	et	3	main
töötingimusi	doc_491521501951_item	3552587	et	3	main
sobiks	doc_491521501951_item	3552663	et	4	main
töögraafiku	doc_491521501951_item	3552664	et	3	main
esmapäevast	doc_491521501951_item	3552665	et	4	main
reedeni	doc_491521501951_item	3552666	et	3	main
kuulutus	doc_584615399810_item	3552897	et	4	main
sellele	doc_584615399810_item	3552900	et	4	main
arvutioskus	doc_584615399810_item	3552913	et	3	main
hobid	doc_584615399810_item	3552915	et	3	main
millist	doc_584615399810_item	3552920	et	3	main
kahe	doc_584615399810_item	3552930	et	3	main
müüjat	doc_584615399810_item	3552938	et	4	main
head	doc_584615399810_item	3552950	et	4	main
hästi	doc_491521501950_item	3552464	et	3	main
oskan	doc_491521501950_item	3552478	et	3	main
hästi	doc_491521501950_item	3552479	et	3	main
tahaksin	doc_491521501950_item	3552494	et	3	main
ja	doc_491521501950_item	3552498	et	3	main
sobivat	doc_491521501950_item	3552500	et	4	main
minu	doc_491521501950_item	3552507	et	3	main
aadres	doc_491521501950_item	3552514	et	4	main
ja	doc_491521501950_item	3552515	et	3	main
telefon	doc_491521501950_item	3552516	et	3	main
ma	doc_491521501950_item	3552517	et	3	main
olen	doc_491521501950_item	3552518	et	3	main
oodanud	doc_491521501950_item	3552519	et	4	main
loodan	doc_491521501951_item	3552685	et	3	main
koostööle	doc_491521501951_item	3552686	et	3	main
lugupidamisega	doc_491521501951_item	3552687	et	3	main
eesnimi	doc_491521501951_item	3552688	et	3	main
perekonnanimi	doc_491521501951_item	3552689	et	3	main
lugege	doc_491521501951_item	3552524	et	3	main
sõna	doc_491521501951_item	3552535	et	4	main
arvutioskus	doc_491521501951_item	3552542	et	3	main
hobid	doc_491521501951_item	3552544	et	3	main
tööd	doc_491521501951_item	3552550	et	4	main
uus	doc_491521501951_item	3552563	et	3	main
toidukauplus	doc_491521501951_item	3552564	et	3	main
kauplusse	doc_491521501951_item	3552565	et	3	main
vajatakse	doc_491521501951_item	3552566	et	4	main
müüjat	doc_491521501951_item	3552567	et	4	main
kassapidajat	doc_491521501951_item	3552568	et	3	main
turvamehi	doc_491521501951_item	3552569	et	3	main
koristajaid	doc_491521501951_item	3552570	et	4	main
ka	doc_491521501951_item	3552583	et	3	main
kindlat	doc_491521501951_item	3552591	et	3	main
palka	doc_491521501951_item	3552592	et	4	main
lisainfo	doc_491521501951_item	3552593	et	4	main
as	doc_491521501951_item	3552594	et	4	main
kakuke	doc_491521501951_item	3552595	et	4	main
tartu	doc_491521501951_item	3552596	et	4	main
mnt	doc_491521501951_item	3552597	et	4	main
3	doc_491521501951_item	3552598	et	2	main
tallinn	doc_491521501951_item	3552599	et	4	main
as	doc_491521501951_item	3552600	et	4	main
kakuke	doc_491521501951_item	3552601	et	4	main
tartu	doc_491521501951_item	3552602	et	4	main
mnt	doc_491521501951_item	3552603	et	4	main
3	doc_491521501951_item	3552604	et	2	main
tallinn	doc_491521501951_item	3552605	et	4	main
proua	doc_491521501951_item	3552606	et	4	main
e	doc_491521501951_item	3552607	et	4	main
perekonnanimi	doc_491521501951_item	3552608	et	3	main
lugupeetud	doc_491521501951_item	3552609	et	4	main
firma	doc_491521501951_item	3552610	et	4	main
fuht	doc_491521501951_item	3552611	et	4	main
teile	doc_491521501951_item	3552612	et	4	main
kirjutab	doc_491521501951_item	3552613	et	3	main
eesnimi	doc_491521501951_item	3552614	et	3	main
perekonnanimi	doc_491521501951_item	3552615	et	3	main
ma	doc_491521501951_item	3552616	et	3	main
lugesin	doc_491521501951_item	3552617	et	3	main
välja	doc_491521501951_item	3552618	et	4	main
ajalehest	doc_491521501951_item	3552619	et	4	main
et	doc_491521501951_item	3552620	et	3	main
toidukauplusesse	doc_491521501951_item	3552621	et	4	main
vajatakse	doc_491521501951_item	3552622	et	4	main
mina	doc_491521501951_item	3552625	et	4	main
olen	doc_491521501951_item	3552626	et	3	main
abielus	doc_491521501951_item	3552627	et	4	main
mul	doc_491521501951_item	3552628	et	3	main
on	doc_491521501951_item	3552629	et	4	main
kõrgharidus	doc_491521501951_item	3552630	et	3	main
ma	doc_491521501951_item	3552631	et	3	main
töötasin	doc_491521501951_item	3552632	et	3	main
müüjana	doc_491521501951_item	3552633	et	4	main
5	doc_491521501951_item	3552634	et	2	main
aastat	doc_491521501951_item	3552635	et	3	main
ma	doc_491521501951_item	3552636	et	3	main
oskan	doc_491521501951_item	3552637	et	3	main
eesti	doc_491521501951_item	3552638	et	4	main
ja	doc_491521501951_item	3552639	et	3	main
vene	doc_491521501951_item	3552640	et	4	main
kelt	doc_491521501951_item	3552641	et	3	main
mul	doc_491521501951_item	3552642	et	3	main
hea	doc_491521501951_item	3552644	et	4	main
on	doc_491521501951_item	3552643	et	4	main
suhtlemisoskust	doc_491521501951_item	3552645	et	3	main
ma	doc_491521501951_item	3552646	et	3	main
oskan	doc_491521501951_item	3552647	et	3	main
arvutiga	doc_491521501951_item	3552649	et	4	main
on	doc_491521501951_item	3552651	et	4	main
minu	doc_491521501951_item	3552653	et	3	main
3000	doc_491521501951_item	3552672	et	2	main
kirjutage	doc_491521501951_item	3552674	et	3	main
hea	doc_491521501951_item	3552656	et	4	main
raamat	doc_491521501951_item	3552657	et	3	main
töötada	doc_491521501951_item	3552660	et	3	main
kella	doc_491521501951_item	3552667	et	4	main
8-17	doc_491521501951_item	3552668	et	2	main
ma	doc_491521501951_item	3552669	et	3	main
andmed	doc_491521501951_item	3552678	et	3	main
11-11	doc_491521501951_item	3552681	et	2	main
6-6666	doc_491521501951_item	3552684	et	2	main
kiri	doc_584615399810_item	3552894	et	3	main
läbi	doc_584615399810_item	3552896	et	4	main
ja	doc_584615399810_item	3552898	et	3	main
töökogemused	doc_584615399810_item	3552911	et	3	main
milline	doc_584615399810_item	3552927	et	3	main
pärast	doc_584615399810_item	3552932	et	4	main
kassapidajaid	doc_584615399810_item	3552939	et	3	main
turvamehi	doc_584615399810_item	3552940	et	3	main
kandidaatidelt	doc_584615399810_item	3552943	et	3	main
ja	doc_584615399810_item	3552946	et	3	main
mnt	doc_584615399810_item	3552968	et	4	main
3	doc_584615399810_item	3552969	et	2	main
tallinn	doc_584615399810_item	3552970	et	4	main
väga	doc_584615399810_item	3553002	et	3	main
aastat	doc_584615399810_item	3553008	et	3	main
eesti	doc_584615399810_item	3553010	et	4	main
kodus	doc_584615399810_item	3553021	et	4	main
ma	doc_584615399810_item	3553022	et	3	main
kasvatan	doc_584615399810_item	3553023	et	3	main
saada	doc_584615399810_item	3553030	et	4	main
loodan	doc_584615399810_item	3553034	et	3	main
sobiv	doc_584615399810_item	3553037	et	4	main
inimene	doc_584615399810_item	3553038	et	3	main
minu	doc_584615399810_item	3553039	et	3	main
kontaktandmeid	doc_584615399810_item	3553040	et	3	main
k	doc_584615399810_item	3553041	et	4	main
perekonnanimi	doc_584615399810_item	3553051	et	3	main
ametlik	doc_397823701992_item	3553054	et	3	main
ja	doc_397823701992_item	3553059	et	3	main
sõna	doc_397823701992_item	3553067	et	4	main
töökogemused	doc_397823701992_item	3553072	et	3	main
autojuhiload	doc_397823701992_item	3553075	et	4	main
hobid	doc_397823701992_item	3553076	et	3	main
ja	doc_397823701992_item	3553077	et	3	main
kirjutage	doc_397823701992_item	3553078	et	3	main
oma	doc_397823701992_item	3553079	et	4	main
soovidest	doc_397823701992_item	3553080	et	3	main
millist	doc_397823701992_item	3553081	et	3	main
soovite	doc_397823701992_item	3553087	et	3	main
kandidaatidelt	doc_397823701992_item	3553104	et	3	main
on	doc_397823701992_item	3553114	et	4	main
ka	doc_397823701992_item	3553115	et	3	main
mugavaid	doc_397823701992_item	3553118	et	3	main
tartu	doc_397823701992_item	3553128	et	4	main
tartu	doc_397823701992_item	3553134	et	4	main
lugege	doc_584615399810_item	3552895	et	3	main
vastake	doc_584615399810_item	3552899	et	3	main
kirjas	doc_584615399810_item	3552901	et	4	main
ennast	doc_584615399810_item	3552908	et	4	main
ja	doc_584615399810_item	3552916	et	3	main
oma	doc_584615399810_item	3552918	et	4	main
tööd	doc_584615399810_item	3552921	et	4	main
soovite	doc_584615399810_item	3552922	et	3	main
kui	doc_584615399810_item	3552923	et	3	main
suurt	doc_584615399810_item	3552924	et	3	main
töötasu	doc_584615399810_item	3552925	et	4	main
soovite	doc_584615399810_item	3552926	et	3	main
kauplusesse	doc_584615399810_item	3552936	et	4	main
koristajaid	doc_584615399810_item	3552941	et	4	main
ootame	doc_584615399810_item	3552944	et	3	main
vene	doc_584615399810_item	3552947	et	4	main
pakume	doc_584615399810_item	3552956	et	3	main
teile	doc_584615399810_item	3552959	et	4	main
sobivat	doc_584615399810_item	3552960	et	4	main
töögraafikut	doc_584615399810_item	3552961	et	3	main
kindlat	doc_584615399810_item	3552962	et	3	main
tartu	doc_584615399810_item	3552967	et	4	main
mnt	doc_584615399810_item	3552973	et	4	main
on	doc_584615399810_item	3553001	et	4	main
minu	doc_584615399810_item	3553005	et	3	main
oskan	doc_584615399810_item	3553009	et	3	main
vene	doc_584615399810_item	3553012	et	4	main
arvutitöötada	doc_584615399810_item	3553017	et	4	main
mul	doc_584615399810_item	3553018	et	3	main
olen	doc_584615399810_item	3553026	et	3	main
olen	doc_584615399810_item	3553036	et	3	main
55	doc_584615399810_item	3553049	et	2	main
lugege	doc_397823701992_item	3553056	et	3	main
ametlik	doc_584615399810_item	3552893	et	3	main
olema	doc_584615399810_item	3552903	et	4	main
umbes	doc_584615399810_item	3552904	et	4	main
60	doc_584615399810_item	3552905	et	2	main
sõna	doc_584615399810_item	3552906	et	4	main
tutvustage	doc_584615399810_item	3552907	et	3	main
kirjutage	doc_584615399810_item	3552917	et	3	main
soovidest	doc_584615399810_item	3552919	et	3	main
töögraafik	doc_584615399810_item	3552928	et	3	main
vajatakse	doc_584615399810_item	3552937	et	4	main
eesti	doc_584615399810_item	3552945	et	4	main
arvutikasutamisoskus	doc_584615399810_item	3552955	et	3	main
töötingimusi	doc_584615399810_item	3552958	et	3	main
kakuke	doc_584615399810_item	3552966	et	4	main
kakuke	doc_584615399810_item	3552972	et	4	main
fakultet	doc_584615399810_item	3552993	et	4	main
peab	doc_584615399810_item	3552902	et	4	main
perekonnaseis	doc_584615399810_item	3552909	et	4	main
haridus	doc_584615399810_item	3552910	et	3	main
keelteoskus	doc_584615399810_item	3552912	et	3	main
autojuhiload	doc_584615399810_item	3552914	et	4	main
sobib	doc_584615399810_item	3552929	et	3	main
kuu	doc_584615399810_item	3552931	et	4	main
avatakse	doc_584615399810_item	3552933	et	4	main
uus	doc_584615399810_item	3552934	et	3	main
toidukauplus	doc_584615399810_item	3552935	et	3	main
pakkijaid	doc_584615399810_item	3552942	et	4	main
keele	doc_584615399810_item	3552948	et	4	main
oskust	doc_584615399810_item	3552949	et	3	main
palka	doc_584615399810_item	3552963	et	4	main
lisainfo	doc_584615399810_item	3552964	et	4	main
as	doc_584615399810_item	3552971	et	4	main
3	doc_584615399810_item	3552974	et	2	main
tallinn	doc_584615399810_item	3552975	et	4	main
avaldus	doc_584615399810_item	3552976	et	4	main
ma	doc_584615399810_item	3552977	et	3	main
tahaksin	doc_584615399810_item	3552978	et	3	main
töötada	doc_584615399810_item	3552979	et	3	main
teie	doc_584615399810_item	3552980	et	4	main
kaupluses	doc_584615399810_item	3552981	et	3	main
müüjana	doc_584615399810_item	3552982	et	4	main
mina	doc_584615399810_item	3552983	et	4	main
on	doc_584615399810_item	3552984	et	4	main
abielus	doc_584615399810_item	3552985	et	4	main
kaks	doc_584615399810_item	3552986	et	3	main
last	doc_584615399810_item	3552987	et	4	main
ma	doc_584615399810_item	3552988	et	3	main
lõpetasin	doc_584615399810_item	3552989	et	3	main
tallinna	doc_584615399810_item	3552990	et	4	main
ülikooli	doc_584615399810_item	3552991	et	4	main
ekonoomika	doc_584615399810_item	3552992	et	4	main
praegu	doc_584615399810_item	3552994	et	3	main
ma	doc_584615399810_item	3552995	et	3	main
ka	doc_584615399810_item	3552997	et	3	main
aga	doc_584615399810_item	3552999	et	3	main
palk	doc_584615399810_item	3553004	et	3	main
5	doc_584615399810_item	3553007	et	2	main
oskan	doc_584615399810_item	3553016	et	3	main
lilli	doc_584615399810_item	3553024	et	4	main
heasuhtlemisaldis	doc_584615399810_item	3553027	et	4	main
ma	doc_584615399810_item	3553028	et	3	main
järve	doc_584615399810_item	3553042	et	4	main
juhuslik	doc_584615399810_item	3553043	et	3	main
1	doc_584615399810_item	3553044	et	2	main
e	doc_584615399810_item	3553050	et	4	main
suhtlemisoskust	doc_584615399810_item	3552951	et	3	main
soovitav	doc_584615399810_item	3552952	et	4	main
on	doc_584615399810_item	3552953	et	4	main
ka	doc_584615399810_item	3552954	et	3	main
mugavaid	doc_584615399810_item	3552957	et	3	main
as	doc_584615399810_item	3552965	et	4	main
siin	doc_584615399810_item	3553000	et	4	main
on	doc_584615399810_item	3553019	et	4	main
autojuhiload	doc_584615399810_item	3553020	et	4	main
tahaksin	doc_584615399810_item	3553029	et	3	main
eek	doc_584615399810_item	3553032	et	4	main
1	doc_584615399810_item	3553045	et	2	main
tel	doc_584615399810_item	3553046	et	4	main
555	doc_584615399810_item	3553048	et	2	main
kiri	doc_397823701992_item	3553055	et	3	main
sellele	doc_397823701992_item	3553061	et	4	main
olema	doc_397823701992_item	3553064	et	4	main
tutvustage	doc_397823701992_item	3553068	et	3	main
perekonnaseis	doc_397823701992_item	3553070	et	4	main
keelteoskus	doc_397823701992_item	3553073	et	3	main
müüjat	doc_397823701992_item	3553099	et	4	main
kassapidajaid	doc_397823701992_item	3553100	et	3	main
turvamehi	doc_397823701992_item	3553101	et	3	main
ootame	doc_397823701992_item	3553105	et	3	main
ja	doc_397823701992_item	3553107	et	3	main
sobivat	doc_397823701992_item	3553121	et	4	main
mnt	doc_397823701992_item	3553129	et	4	main
3	doc_397823701992_item	3553130	et	2	main
tallinn	doc_397823701992_item	3553131	et	4	main
tallinn	doc_397823701992_item	3553137	et	4	main
78	doc_397823701992_item	3553139	et	2	main
oskan	doc_397823701992_item	3553176	et	3	main
ja	doc_397823701992_item	3553178	et	3	main
olen	doc_397823701992_item	3553196	et	3	main
elukohta	doc_397823701992_item	3553209	et	4	main
kiri	doc_397823701998_item	3553226	et	3	main
sellele	doc_397823701998_item	3553232	et	4	main
umbes	doc_397823701998_item	3553236	et	4	main
tutvustage	doc_397823701998_item	3553239	et	3	main
kirjutage	doc_397823701998_item	3553249	et	3	main
koristajaid	doc_397823701998_item	3553273	et	4	main
pakkijaid	doc_397823701998_item	3553274	et	4	main
kandidaatidelt	doc_397823701998_item	3553275	et	3	main
ootame	doc_397823701998_item	3553276	et	3	main
töötingimusi	doc_397823701998_item	3553290	et	3	main
teile	doc_397823701998_item	3553291	et	4	main
sobivat	doc_397823701998_item	3553292	et	4	main
soobib	doc_397823701998_item	3553326	et	4	main
töötada	doc_397823701998_item	3553329	et	3	main
müüjana	doc_397823701998_item	3553330	et	4	main
mulle	doc_397823701998_item	3553331	et	4	main
väga	doc_397823701998_item	3553332	et	3	main
on	doc_397823701998_item	3553344	et	4	main
väike	doc_397823701998_item	3553345	et	4	main
ma	doc_397823701998_item	3553347	et	3	main
cwb	doc_491521501734_item	3553383	et	4	main
võtta	doc_491521501734_item	3553388	et	3	main
tööle	doc_491521501734_item	3553390	et	3	main
mul	doc_491521501734_item	3553400	et	3	main
on	doc_491521501734_item	3553412	et	4	main
kirjas	doc_491521501734_item	3553421	et	4	main
suhtlemiskeelena	doc_491521501734_item	3553422	et	3	main
on	doc_491521501734_item	3553440	et	4	main
aastatel	doc_491521501734_item	3553444	et	4	main
aastatel	doc_491521501734_item	3553449	et	4	main
müüjana	doc_491521501734_item	3553452	et	4	main
kaubamajas	doc_491521501734_item	3553453	et	3	main
jooned	doc_491521501734_item	3553459	et	3	main
ettevõtlikkus	doc_491521501734_item	3553462	et	4	main
ma	doc_491521501734_item	3553463	et	3	main
töötan	doc_584615399810_item	3552996	et	3	main
kaupluses	doc_584615399810_item	3552998	et	3	main
vähe	doc_584615399810_item	3553003	et	3	main
staaž	doc_584615399810_item	3553006	et	2	main
ja	doc_584615399810_item	3553011	et	3	main
keelt	doc_584615399810_item	3553013	et	4	main
ja	doc_584615399810_item	3553014	et	3	main
ma	doc_584615399810_item	3553015	et	3	main
ma	doc_584615399810_item	3553025	et	3	main
34	doc_584615399810_item	3553031	et	2	main
tunnis	doc_584615399810_item	3553033	et	3	main
so	doc_584615399810_item	3553035	et	4	main
55	doc_584615399810_item	3553047	et	2	main
kuulutus	doc_397823701992_item	3553058	et	4	main
vastake	doc_397823701992_item	3553060	et	3	main
tööd	doc_397823701992_item	3553082	et	4	main
soovite	doc_397823701992_item	3553083	et	3	main
kui	doc_397823701992_item	3553084	et	3	main
sobib	doc_397823701992_item	3553090	et	3	main
kuu	doc_397823701992_item	3553092	et	4	main
avatakse	doc_397823701992_item	3553094	et	4	main
uus	doc_397823701992_item	3553095	et	3	main
pakkijaid	doc_397823701992_item	3553103	et	4	main
arvutikasutamisoskus	doc_397823701992_item	3553116	et	3	main
töötingimusi	doc_397823701992_item	3553119	et	3	main
kindlat	doc_397823701992_item	3553123	et	3	main
lisainfo	doc_397823701992_item	3553125	et	4	main
kakuke	doc_397823701992_item	3553133	et	4	main
virumaa	doc_397823701992_item	3553145	et	4	main
eesnimi	doc_397823701992_item	3553146	et	3	main
perekonnanimi	doc_397823701992_item	3553147	et	3	main
sain	doc_397823701992_item	3553172	et	3	main
müüja	doc_397823701992_item	3553174	et	4	main
eesti	doc_397823701992_item	3553177	et	4	main
kategooria	doc_397823701992_item	3553185	et	4	main
töötasin	doc_397823701992_item	3553189	et	3	main
haiglas	doc_397823701992_item	3553191	et	3	main
hästi	doc_397823701992_item	3553194	et	3	main
lapsed	doc_397823701992_item	3553198	et	3	main
koolis	doc_397823701992_item	3553200	et	4	main
minu	doc_397823701992_item	3553208	et	3	main
lähedal	doc_397823701992_item	3553210	et	4	main
kuulutus	doc_397823701998_item	3553229	et	4	main
ja	doc_397823701998_item	3553230	et	3	main
haridus	doc_397823701998_item	3553242	et	3	main
töökogemused	doc_397823701998_item	3553243	et	3	main
arvutioskus	doc_397823701998_item	3553245	et	3	main
hobid	doc_397823701998_item	3553247	et	3	main
millist	doc_397823701998_item	3553252	et	3	main
soovite	doc_397823701998_item	3553254	et	3	main
töötasu	doc_397823701998_item	3553257	et	4	main
soovite	doc_397823701998_item	3553258	et	3	main
milline	doc_397823701998_item	3553259	et	3	main
töögraafik	doc_397823701998_item	3553260	et	3	main
sobib	doc_397823701998_item	3553261	et	3	main
kahe	doc_397823701998_item	3553262	et	3	main
kuu	doc_397823701998_item	3553263	et	4	main
toidukauplus	doc_397823701998_item	3553267	et	3	main
eesti	doc_397823701998_item	3553277	et	4	main
ja	doc_397823701998_item	3553278	et	3	main
vene	doc_397823701998_item	3553279	et	4	main
suhtlemisoskust	doc_397823701998_item	3553283	et	3	main
on	doc_397823701998_item	3553285	et	4	main
ka	doc_397823701998_item	3553286	et	3	main
arvutikasutamisoskus	doc_397823701998_item	3553287	et	3	main
pakume	doc_397823701998_item	3553288	et	3	main
mulle	doc_397823701998_item	3553325	et	4	main
ma	doc_397823701998_item	3553327	et	3	main
tahan	doc_397823701998_item	3553328	et	3	main
kauplus	doc_397823701998_item	3553338	et	3	main
asub	doc_397823701998_item	3553339	et	3	main
minu	doc_397823701998_item	3553341	et	3	main
problem	doc_397823701998_item	3553346	et	4	main
räägin	doc_397823701998_item	3553348	et	3	main
paha	doc_397823701998_item	3553349	et	4	main
eestikelt	doc_397823701998_item	3553350	et	4	main
aga	doc_397823701998_item	3553351	et	3	main
olla	doc_397823701992_item	3553215	et	3	main
ükskõik	doc_397823701992_item	3553216	et	3	main
millised	doc_397823701992_item	3553217	et	3	main
28062005	doc_397823701992_item	3553218	et	2	main
a	doc_397823701992_item	3553219	et	4	main
lugupidamisega	doc_397823701992_item	3553220	et	3	main
eesnimi	doc_397823701992_item	3553221	et	3	main
perekonnanimi	doc_397823701992_item	3553222	et	3	main
läbi	doc_397823701992_item	3553057	et	4	main
kirjas	doc_397823701992_item	3553062	et	4	main
umbes	doc_397823701992_item	3553065	et	4	main
ennast	doc_397823701992_item	3553069	et	4	main
haridus	doc_397823701992_item	3553071	et	3	main
arvutioskus	doc_397823701992_item	3553074	et	3	main
töötasu	doc_397823701992_item	3553086	et	4	main
töögraafik	doc_397823701992_item	3553089	et	3	main
kahe	doc_397823701992_item	3553091	et	3	main
pärast	doc_397823701992_item	3553093	et	4	main
toidukauplus	doc_397823701992_item	3553096	et	3	main
kauplusesse	doc_397823701992_item	3553097	et	4	main
koristajaid	doc_397823701992_item	3553102	et	4	main
keele	doc_397823701992_item	3553109	et	4	main
head	doc_397823701992_item	3553111	et	4	main
suhtlemisoskust	doc_397823701992_item	3553112	et	3	main
soovitav	doc_397823701992_item	3553113	et	4	main
teile	doc_397823701992_item	3553120	et	4	main
töögraafikut	doc_397823701992_item	3553122	et	3	main
as	doc_397823701992_item	3553126	et	4	main
kakuke	doc_397823701992_item	3553127	et	4	main
as	doc_397823701992_item	3553132	et	4	main
juhuslik	doc_397823701992_item	3553138	et	3	main
56	doc_397823701992_item	3553140	et	2	main
järve	doc_397823701992_item	3553142	et	4	main
avaldus	doc_397823701992_item	3553148	et	4	main
lugesin	doc_397823701992_item	3553149	et	3	main
teie	doc_397823701992_item	3553150	et	4	main
kuulutust	doc_397823701992_item	3553151	et	4	main
ajalehes	doc_397823701992_item	3553152	et	3	main
infopress	doc_397823701992_item	3553153	et	3	main
vene	doc_397823701992_item	3553179	et	4	main
mul	doc_397823701992_item	3553182	et	3	main
on	doc_397823701992_item	3553183	et	4	main
juhiload	doc_397823701992_item	3553186	et	4	main
sest	doc_397823701992_item	3553205	et	4	main
see	doc_397823701992_item	3553206	et	3	main
ametlik	doc_397823701998_item	3553225	et	3	main
olema	doc_397823701998_item	3553235	et	4	main
60	doc_397823701998_item	3553237	et	2	main
ennast	doc_397823701998_item	3553240	et	4	main
ja	doc_397823701998_item	3553248	et	3	main
soovidest	doc_397823701998_item	3553251	et	3	main
pärast	doc_397823701998_item	3553264	et	4	main
kauplusesse	doc_397823701998_item	3553268	et	4	main
oskust	doc_397823701998_item	3553281	et	3	main
töögraafikut	doc_397823701998_item	3553293	et	3	main
peab	doc_397823701992_item	3553063	et	4	main
60	doc_397823701992_item	3553066	et	2	main
suurt	doc_397823701992_item	3553085	et	3	main
milline	doc_397823701992_item	3553088	et	3	main
vajatakse	doc_397823701992_item	3553098	et	4	main
eesti	doc_397823701992_item	3553106	et	4	main
vene	doc_397823701992_item	3553108	et	4	main
oskust	doc_397823701992_item	3553110	et	3	main
pakume	doc_397823701992_item	3553117	et	3	main
palka	doc_397823701992_item	3553124	et	4	main
mnt	doc_397823701992_item	3553135	et	4	main
3	doc_397823701992_item	3553136	et	2	main
ida	doc_397823701992_item	3553144	et	4	main
kätte	doc_397823701992_item	3553173	et	4	main
sertifikaadi	doc_397823701992_item	3553175	et	3	main
keeles	doc_397823701992_item	3553180	et	4	main
suhelda	doc_397823701992_item	3553181	et	4	main
varem	doc_397823701992_item	3553187	et	4	main
arvutit	doc_397823701992_item	3553192	et	3	main
mina	doc_397823701992_item	3553195	et	4	main
õppivad	doc_397823701992_item	3553199	et	4	main
tahaksin	doc_397823701992_item	3553201	et	3	main
töötada	doc_397823701992_item	3553202	et	3	main
teie	doc_397823701992_item	3553203	et	4	main
toidukaupluses	doc_397823701992_item	3553204	et	3	main
saavad	doc_397823701992_item	3553214	et	4	main
lugege	doc_397823701998_item	3553227	et	3	main
vastake	doc_397823701998_item	3553231	et	3	main
kirjas	doc_397823701998_item	3553233	et	4	main
peab	doc_397823701998_item	3553234	et	4	main
sõna	doc_397823701998_item	3553238	et	4	main
keelteoskus	doc_397823701998_item	3553244	et	3	main
oma	doc_397823701998_item	3553250	et	4	main
kui	doc_397823701998_item	3553255	et	3	main
avatakse	doc_397823701998_item	3553265	et	4	main
vajatakse	doc_397823701998_item	3553269	et	4	main
müüjat	doc_397823701998_item	3553270	et	4	main
kassapidajaid	doc_397823701998_item	3553271	et	3	main
turvamehi	doc_397823701998_item	3553272	et	3	main
keele	doc_397823701998_item	3553280	et	4	main
kindlat	doc_397823701998_item	3553294	et	3	main
palka	doc_397823701998_item	3553295	et	4	main
maja	doc_397823701998_item	3553342	et	4	main
kiri	doc_491521501734_item	3553379	et	3	main
cwb	doc_491521501734_item	3553385	et	4	main
mind	doc_491521501734_item	3553389	et	4	main
müügiesindaja	doc_491521501734_item	3553391	et	4	main
ametikohale	doc_491521501734_item	3553392	et	4	main
ma	doc_491521501734_item	3553393	et	3	main
tunnen	doc_491521501734_item	3553394	et	3	main
et	doc_491521501734_item	3553395	et	3	main
ma	doc_491521501734_item	3553403	et	3	main
emakeel	doc_491521501734_item	3553411	et	4	main
keelt	doc_491521501734_item	3553418	et	4	main
kõnes	doc_491521501734_item	3553419	et	3	main
ja	doc_491521501734_item	3553420	et	3	main
keelt	doc_491521501734_item	3553424	et	4	main
ülikooli	doc_491521501734_item	3553428	et	4	main
stockman	doc_491521501734_item	3553454	et	4	main
vallaline	doc_491521501734_item	3553479	et	4	main
soovin	doc_491521501734_item	3553498	et	3	main
austusega	doc_491521501734_item	3553506	et	4	main
eesnimi	doc_491521501734_item	3553507	et	3	main
perekonnanimi	doc_491521501734_item	3553508	et	3	main
avaldus	doc_491521501767_item	3553515	et	4	main
meile	doc_491521501767_item	3553518	et	4	main
semestris	doc_491521501767_item	3553522	et	3	main
a	doc_491521501767_item	3553524	et	4	main
lõppus	doc_491521501767_item	3553526	et	4	main
meil	doc_491521501767_item	3553527	et	4	main
oli	doc_491521501767_item	3553528	et	3	main
arvestustöö	doc_491521501767_item	3553529	et	4	main
2	doc_491521501767_item	3553530	et	2	main
tulin	doc_491521501767_item	3553537	et	3	main
juurde	doc_491521501767_item	3553539	et	4	main
tahaksin	doc_491521501767_item	3553541	et	3	main
teada	doc_491521501767_item	3553544	et	3	main
üles	doc_491521501767_item	3553582	et	3	main
aga	doc_491521501767_item	3553583	et	3	main
korral	doc_491521501767_item	3553587	et	4	main
ütles	doc_491521501767_item	3553589	et	3	main
kohtla	doc_397823701992_item	3553141	et	4	main
linn	doc_397823701992_item	3553143	et	3	main
mina	doc_397823701992_item	3553154	et	4	main
olen	doc_397823701992_item	3553155	et	3	main
eesnimi	doc_397823701992_item	3553156	et	3	main
perekonnanimi	doc_397823701992_item	3553157	et	3	main
lõpetasin	doc_397823701992_item	3553158	et	3	main
kooli	doc_397823701992_item	3553159	et	4	main
kümme	doc_397823701992_item	3553160	et	3	main
aastat	doc_397823701992_item	3553161	et	3	main
tagasi	doc_397823701992_item	3553162	et	3	main
õppisin	doc_397823701992_item	3553163	et	3	main
1998	doc_397823701992_item	3553164	et	2	main
aastal	doc_397823701992_item	3553165	et	3	main
müüjade	doc_397823701992_item	3553166	et	4	main
kursustel	doc_397823701992_item	3553167	et	3	main
sooritasin	doc_397823701992_item	3553168	et	3	main
edukalt	doc_397823701992_item	3553169	et	4	main
eksamit	doc_397823701992_item	3553170	et	3	main
ja	doc_397823701992_item	3553171	et	3	main
b	doc_397823701992_item	3553184	et	4	main
ma	doc_397823701992_item	3553188	et	3	main
registratorina	doc_397823701992_item	3553190	et	4	main
oskab	doc_397823701992_item	3553193	et	3	main
abielus	doc_397823701992_item	3553197	et	4	main
on	doc_397823701992_item	3553207	et	4	main
töögraafik	doc_397823701992_item	3553211	et	3	main
ja	doc_397823701992_item	3553212	et	3	main
palka	doc_397823701992_item	3553213	et	4	main
kaks	doc_397823701998_item	3553358	et	3	main
last	doc_397823701998_item	3553359	et	4	main
nad	doc_397823701998_item	3553360	et	3	main
juba	doc_397823701998_item	3553361	et	3	main
sured	doc_397823701998_item	3553362	et	3	main
kauplus	doc_397823701998_item	3553363	et	3	main
töötab	doc_397823701998_item	3553364	et	3	main
iga	doc_397823701998_item	3553365	et	4	main
päev	doc_397823701998_item	3553366	et	3	main
8-st	doc_397823701998_item	3553367	et	3	main
21-ni	doc_397823701998_item	3553368	et	3	main
see	doc_397823701998_item	3553369	et	3	main
graafik	doc_397823701998_item	3553370	et	3	main
minule	doc_397823701998_item	3553371	et	3	main
soobib	doc_397823701998_item	3553372	et	4	main
ma	doc_397823701998_item	3553373	et	3	main
loodan	doc_397823701998_item	3553374	et	3	main
ett	doc_397823701998_item	3553375	et	3	main
saan	doc_397823701998_item	3553376	et	4	main
selleholda	doc_397823701998_item	3553377	et	4	main
läbi	doc_397823701998_item	3553228	et	4	main
perekonnaseis	doc_397823701998_item	3553241	et	4	main
autojuhiload	doc_397823701998_item	3553246	et	4	main
tööd	doc_397823701998_item	3553253	et	4	main
suurt	doc_397823701998_item	3553256	et	3	main
uus	doc_397823701998_item	3553266	et	3	main
head	doc_397823701998_item	3553282	et	4	main
soovitav	doc_397823701998_item	3553284	et	4	main
mugavaid	doc_397823701998_item	3553289	et	3	main
lisainfo	doc_397823701998_item	3553296	et	4	main
as	doc_397823701998_item	3553297	et	4	main
kakuke	doc_397823701998_item	3553298	et	4	main
tartu	doc_397823701998_item	3553299	et	4	main
mnt	doc_397823701998_item	3553300	et	4	main
3	doc_397823701998_item	3553301	et	2	main
tallinn	doc_397823701998_item	3553302	et	4	main
ma	doc_397823701998_item	3553303	et	3	main
lugesin	doc_397823701998_item	3553304	et	3	main
ajalehest	doc_397823701998_item	3553305	et	4	main
kulutuse	doc_397823701998_item	3553306	et	4	main
ett	doc_397823701998_item	3553307	et	3	main
avatakse	doc_397823701998_item	3553308	et	4	main
tööle	doc_397823701998_item	3553309	et	3	main
töölise	doc_397823701998_item	3553310	et	3	main
uus	doc_397823701998_item	3553311	et	3	main
kauplus	doc_397823701998_item	3553312	et	3	main
ja	doc_397823701998_item	3553313	et	3	main
cutsutakse	doc_397823701998_item	3553314	et	4	main
tööle	doc_397823701998_item	3553315	et	3	main
töölise	doc_397823701998_item	3553316	et	3	main
mina	doc_397823701998_item	3553317	et	4	main
praegu	doc_397823701998_item	3553318	et	3	main
ei	doc_397823701998_item	3553319	et	4	main
tööta	doc_397823701998_item	3553320	et	4	main
ja	doc_397823701998_item	3553321	et	3	main
see	doc_397823701998_item	3553322	et	3	main
töö	doc_397823701998_item	3553323	et	4	main
koht	doc_397823701998_item	3553324	et	3	main
meldib	doc_397823701998_item	3553333	et	4	main
töötada	doc_397823701998_item	3553334	et	3	main
müüjana	doc_397823701998_item	3553335	et	4	main
ja	doc_397823701998_item	3553336	et	3	main
see	doc_397823701998_item	3553337	et	3	main
lähedal	doc_397823701998_item	3553340	et	4	main
mina	doc_397823701998_item	3553352	et	4	main
mnt13	doc_491521501734_item	3553381	et	4	main
personaliosakond	doc_491521501734_item	3553386	et	3	main
see	doc_491521501734_item	3553396	et	3	main
töö	doc_491521501734_item	3553397	et	4	main
sobib	doc_491521501734_item	3553398	et	3	main
kõrgharidus	doc_491521501734_item	3553402	et	3	main
ülikooli	doc_491521501734_item	3553406	et	4	main
keel	doc_491521501734_item	3553414	et	4	main
ma	doc_491521501734_item	3553415	et	3	main
aga	doc_397823701998_item	3553343	et	3	main
praegu	doc_397823701998_item	3553353	et	3	main
kein	doc_397823701998_item	3553354	et	4	main
kursustel	doc_397823701998_item	3553355	et	3	main
mul	doc_397823701998_item	3553356	et	3	main
on	doc_397823701998_item	3553357	et	4	main
15098	doc_491521501734_item	3553382	et	2	main
personaliosakond	doc_491521501734_item	3553384	et	3	main
mulle	doc_491521501734_item	3553399	et	4	main
on	doc_491521501734_item	3553401	et	4	main
vene	doc_491521501734_item	3553413	et	4	main
lõpetamist	doc_491521501734_item	3553426	et	4	main
müügitöö	doc_491521501734_item	3553442	et	4	main
töötasin	doc_491521501734_item	3553446	et	3	main
kaubamajas	doc_491521501734_item	3553448	et	3	main
1998-2001	doc_491521501734_item	3553450	et	2	main
töötasin	doc_491521501734_item	3553451	et	3	main
ametireisidesse	doc_491521501734_item	3553482	et	3	main
mulle	doc_491521501734_item	3553484	et	4	main
meeldib	doc_491521501734_item	3553485	et	3	main
reisida	doc_491521501734_item	3553486	et	3	main
ning	doc_491521501734_item	3553487	et	3	main
inimestega	doc_491521501734_item	3553488	et	3	main
töötasuks	doc_491521501734_item	3553499	et	4	main
avaldus	doc_491521501767_item	3553511	et	4	main
luges	doc_491521501767_item	3553517	et	3	main
2003	doc_491521501767_item	3553523	et	2	main
tema	doc_491521501767_item	3553538	et	4	main
kord	doc_491521501767_item	3553559	et	4	main
ei	doc_491521501767_item	3553569	et	4	main
ta	doc_491521501767_item	3553573	et	4	main
ja	doc_491521501767_item	3553577	et	3	main
mitu	doc_491521501767_item	3553580	et	4	main
korda	doc_491521501767_item	3553581	et	4	main
leiab	doc_491521501767_item	3553563	et	3	main
minu	doc_491521501767_item	3553564	et	3	main
tööd	doc_491521501767_item	3553565	et	4	main
aga	doc_491521501767_item	3553566	et	3	main
kahjuks	doc_491521501767_item	3553567	et	4	main
ta	doc_491521501767_item	3553568	et	4	main
narva	doc_491521501734_item	3553380	et	4	main
palun	doc_491521501734_item	3553387	et	3	main
olin	doc_491521501734_item	3553404	et	3	main
lõpetanud	doc_491521501734_item	3553405	et	4	main
ma	doc_491521501734_item	3553407	et	3	main
õppisin	doc_491521501734_item	3553408	et	3	main
majandusteaduskonnas	doc_491521501734_item	3553409	et	4	main
minu	doc_491521501734_item	3553410	et	3	main
eesti	doc_491521501734_item	3553423	et	4	main
tartu	doc_491521501734_item	3553427	et	4	main
õppisin	doc_491521501734_item	3553429	et	3	main
amerikas	doc_491521501734_item	3553430	et	4	main
kaks	doc_491521501734_item	3553431	et	3	main
aastat	doc_491521501734_item	3553432	et	3	main
ma	doc_491521501734_item	3553433	et	3	main
õppisin	doc_491521501734_item	3553434	et	3	main
ka	doc_491521501734_item	3553435	et	3	main
venemaal	doc_491521501734_item	3553436	et	4	main
kaks	doc_491521501734_item	3553437	et	3	main
aastat	doc_491521501734_item	3553438	et	3	main
mul	doc_491521501734_item	3553439	et	3	main
kogemus	doc_491521501734_item	3553443	et	3	main
müüjana	doc_491521501734_item	3553447	et	4	main
on	doc_491521501734_item	3553456	et	4	main
omased	doc_491521501734_item	3553457	et	3	main
sellesed	doc_491521501734_item	3553458	et	4	main
tagasihoidlikkus	doc_491521501734_item	3553461	et	4	main
olen	doc_491521501734_item	3553464	et	3	main
väga	doc_491521501734_item	3553465	et	3	main
mitmekülgne	doc_491521501734_item	3553466	et	3	main
taibukas	doc_491521501734_item	3553467	et	4	main
virk	doc_491521501734_item	3553468	et	3	main
ning	doc_491521501734_item	3553469	et	3	main
asjalik	doc_491521501734_item	3553470	et	3	main
inimene	doc_491521501734_item	3553471	et	3	main
mul	doc_491521501734_item	3553472	et	3	main
on	doc_491521501734_item	3553473	et	4	main
auto	doc_491521501734_item	3553474	et	4	main
ning	doc_491521501734_item	3553475	et	3	main
autojuhiluba	doc_491521501734_item	3553476	et	4	main
ma	doc_491521501734_item	3553477	et	3	main
olen	doc_491521501734_item	3553478	et	3	main
kuus	doc_491521501734_item	3553501	et	4	main
koostööle	doc_491521501734_item	3553503	et	3	main
lootma	doc_491521501734_item	3553504	et	3	main
jäädes	doc_491521501734_item	3553505	et	4	main
juhatajale	doc_491521501767_item	3553514	et	4	main
esteetika	doc_491521501767_item	3553519	et	4	main
esseed	doc_491521501767_item	3553531	et	4	main
1	doc_491521501767_item	3553533	et	2	main
kui	doc_491521501767_item	3553536	et	3	main
ja	doc_491521501767_item	3553540	et	3	main
ta	doc_491521501767_item	3553545	et	4	main
ütles	doc_491521501767_item	3553546	et	3	main
et	doc_491521501767_item	3553547	et	3	main
tal	doc_491521501767_item	3553548	et	3	main
pole	doc_491521501767_item	3553549	et	3	main
minu	doc_491521501767_item	3553550	et	3	main
töid	doc_491521501767_item	3553551	et	3	main
käisin	doc_491521501767_item	3553552	et	3	main
iga	doc_491521501767_item	3553553	et	4	main
juurde	doc_491521501767_item	3553556	et	4	main
esimesel	doc_491521501767_item	3553586	et	3	main
ta	doc_491521501767_item	3553588	et	4	main
et	doc_491521501767_item	3553590	et	3	main
ja	doc_491521501767_item	3553594	et	3	main
ma	doc_491521501767_item	3553596	et	3	main
valdan	doc_491521501734_item	3553416	et	3	main
inglise	doc_491521501734_item	3553417	et	4	main
pärast	doc_491521501734_item	3553425	et	4	main
suur	doc_491521501734_item	3553441	et	3	main
1995-1998	doc_491521501734_item	3553445	et	2	main
mulle	doc_491521501734_item	3553455	et	4	main
iseseisvus	doc_491521501734_item	3553460	et	4	main
ja	doc_491521501734_item	3553480	et	3	main
võin	doc_491521501734_item	3553481	et	3	main
14032002a	doc_491521501734_item	3553509	et	4	main
kursuse	doc_491521501767_item	3553520	et	3	main
kursuse	doc_491521501767_item	3553525	et	3	main
ja	doc_491521501767_item	3553532	et	3	main
kirjalik	doc_491521501767_item	3553534	et	3	main
nädal	doc_491521501767_item	3553554	et	3	main
ja	doc_491521501767_item	3553557	et	3	main
tööd	doc_491521501767_item	3553572	et	4	main
kirjutas	doc_491521501767_item	3553574	et	3	main
nimi	doc_491521501767_item	3553576	et	3	main
oli	doc_491521501767_item	3553592	et	3	main
b	doc_491521501767_item	3553593	et	4	main
õppinguraamatule	doc_491521501767_item	3553599	et	4	main
seda	doc_491521501767_item	3553604	et	3	main
teha	doc_491521501767_item	3553605	et	3	main
ega	doc_491521501767_item	3553606	et	3	main
kursusel	doc_491521501767_item	3553608	et	3	main
ta	doc_491521501767_item	3553611	et	4	main
tal	doc_491521501767_item	3553614	et	3	main
tööd	doc_491521501767_item	3553617	et	4	main
me	doc_491521501733_item	3553627	et	4	main
ja	doc_491521501733_item	3553632	et	3	main
koolikaaslased	doc_491521501733_item	3553634	et	3	main
reis	doc_491521501733_item	3553644	et	4	main
on	doc_491521501733_item	3553645	et	4	main
meil	doc_491521501733_item	3553659	et	4	main
on	doc_491521501733_item	3553660	et	4	main
grupp	doc_491521501733_item	3553661	et	3	main
oleks	doc_491521501733_item	3553662	et	3	main
vähemalt	doc_491521501733_item	3553663	et	4	main
väga	doc_491521501733_item	3553672	et	3	main
meile	doc_491521501733_item	3553674	et	4	main
23	doc_491521501733_item	3553678	et	2	main
inimest	doc_491521501733_item	3553679	et	3	main
ja	doc_491521501733_item	3553680	et	3	main
üks	doc_491521501733_item	3553681	et	3	main
hinna	doc_491521501733_item	3553690	et	3	main
edasi-tagasi	doc_491521501733_item	3553692	et	3	main
as	doc_491521501730_item	3553751	et	4	main
555	doc_491521501730_item	3553759	et	2	main
555555555	doc_491521501730_item	3553761	et	2	main
inglise	doc_491521501730_item	3553772	et	4	main
keelt	doc_491521501730_item	3553773	et	4	main
kollegidega	doc_491521501730_item	3553778	et	4	main
me	doc_491521501730_item	3553782	et	4	main
12	doc_491521501730_item	3553791	et	2	main
jaanuarini	doc_491521501730_item	3553797	et	3	main
esmaspäeval	doc_491521501730_item	3553801	et	3	main
reedel	doc_491521501730_item	3553804	et	3	main
saada	doc_491521501730_item	3553854	et	4	main
vastuse	doc_491521501730_item	3553855	et	3	main
lähemal	doc_491521501730_item	3553856	et	4	main
sõida	doc_491521501734_item	3553483	et	4	main
suhelda	doc_491521501734_item	3553489	et	4	main
ma	doc_491521501734_item	3553490	et	3	main
võin	doc_491521501734_item	3553491	et	3	main
rahvusvahelises	doc_491521501734_item	3553492	et	4	main
firmas	doc_491521501734_item	3553493	et	3	main
ja	doc_491521501734_item	3553494	et	3	main
euroopas	doc_491521501734_item	3553495	et	3	main
töötada	doc_491521501734_item	3553496	et	3	main
ma	doc_491521501734_item	3553497	et	3	main
10000	doc_491521501734_item	3553500	et	2	main
meeldivale	doc_491521501734_item	3553502	et	4	main
juhusliku	doc_491521501767_item	3553512	et	3	main
osakonna	doc_491521501767_item	3553513	et	4	main
härra	doc_491521501767_item	3553516	et	4	main
esimeses	doc_491521501767_item	3553521	et	3	main
töö	doc_491521501767_item	3553535	et	4	main
oma	doc_491521501767_item	3553542	et	4	main
hinne	doc_491521501767_item	3553543	et	3	main
tema	doc_491521501767_item	3553555	et	4	main
iga	doc_491521501767_item	3553558	et	4	main
ta	doc_491521501767_item	3553560	et	4	main
lubas	doc_491521501767_item	3553561	et	3	main
et	doc_491521501767_item	3553562	et	3	main
leidnud	doc_491521501767_item	3553570	et	4	main
minu	doc_491521501767_item	3553571	et	3	main
minu	doc_491521501767_item	3553575	et	3	main
telefoni	doc_491521501767_item	3553578	et	4	main
number	doc_491521501767_item	3553579	et	3	main
helistas	doc_491521501767_item	3553585	et	3	main
kui	doc_491521501767_item	3553595	et	3	main
palusin	doc_491521501767_item	3553597	et	3	main
tahtnud	doc_491521501767_item	3553603	et	4	main
järgmisel	doc_491521501767_item	3553609	et	3	main
pole	doc_491521501767_item	3553615	et	3	main
kiri	doc_491521501733_item	3553624	et	3	main
sponsor	doc_491521501733_item	3553626	et	3	main
lugesime	doc_491521501733_item	3553628	et	3	main
reisile	doc_491521501733_item	3553636	et	3	main
selle	doc_491521501733_item	3553638	et	4	main
reisibüroo	doc_491521501733_item	3553641	et	4	main
peterburi	doc_491521501733_item	3553646	et	4	main
2122	doc_491521501733_item	3553651	et	2	main
reis	doc_491521501733_item	3553653	et	4	main
maksab	doc_491521501733_item	3553654	et	3	main
22	doc_491521501733_item	3553664	et	2	main
sest	doc_491521501733_item	3553666	et	4	main
see	doc_491521501733_item	3553671	et	3	main
sees	doc_491521501733_item	3553691	et	4	main
rongipilet	doc_491521501733_item	3553693	et	3	main
on	doc_491521501733_item	3553718	et	4	main
turism	doc_491521501730_item	3553752	et	3	main
tel	doc_491521501730_item	3553756	et	4	main
töötame	doc_491521501730_item	3553766	et	3	main
ja	doc_491521501730_item	3553770	et	3	main
käia	doc_491521501730_item	3553805	et	4	main
11-13	doc_491521501730_item	3553807	et	2	main
as	doc_491521501730_item	3553815	et	4	main
teilt	doc_491521501730_item	3553853	et	4	main
ei	doc_491521501767_item	3553584	et	4	main
mul	doc_491521501767_item	3553591	et	3	main
hinna	doc_491521501767_item	3553598	et	3	main
panna	doc_491521501767_item	3553600	et	4	main
ta	doc_491521501767_item	3553601	et	4	main
korral	doc_491521501767_item	3553610	et	4	main
ütles	doc_491521501767_item	3553612	et	3	main
minu	doc_491521501767_item	3553616	et	3	main
eesnimi	doc_491521501767_item	3553618	et	3	main
perekonnanimi	doc_491521501767_item	3553619	et	3	main
2004a	doc_491521501767_item	3553622	et	4	main
ei	doc_491521501767_item	3553602	et	4	main
aprill	doc_491521501767_item	3553621	et	3	main
austatud	doc_491521501733_item	3553625	et	4	main
ajalehest	doc_491521501733_item	3553629	et	4	main
oma	doc_491521501733_item	3553633	et	4	main
tahame	doc_491521501733_item	3553635	et	3	main
maria	doc_491521501733_item	3553647	et	4	main
juuni	doc_491521501733_item	3553652	et	4	main
1500	doc_491521501733_item	3553655	et	2	main
krooni	doc_491521501733_item	3553656	et	4	main
aga	doc_491521501733_item	3553657	et	3	main
kui	doc_491521501733_item	3553658	et	3	main
inimest	doc_491521501733_item	3553665	et	3	main
sobib	doc_491521501733_item	3553673	et	3	main
klassis	doc_491521501733_item	3553676	et	3	main
et	doc_491521501733_item	3553689	et	3	main
järgmisel	doc_491521501767_item	3553607	et	3	main
et	doc_491521501767_item	3553613	et	3	main
22	doc_491521501767_item	3553620	et	2	main
mina	doc_491521501733_item	3553631	et	4	main
minna	doc_491521501733_item	3553637	et	3	main
reisi	doc_491521501733_item	3553639	et	4	main
pakub	doc_491521501733_item	3553640	et	3	main
teatrisse	doc_491521501733_item	3553648	et	3	main
saaksime	doc_491521501733_item	3553668	et	3	main
20	doc_491521501733_item	3553670	et	2	main
meie	doc_491521501733_item	3553675	et	4	main
on	doc_491521501733_item	3553677	et	4	main
tüdruk	doc_491521501733_item	3553682	et	3	main
ei	doc_491521501733_item	3553683	et	4	main
väga	doc_491521501733_item	3553719	et	3	main
huvitav	doc_491521501733_item	3553720	et	4	main
ja	doc_491521501733_item	3553721	et	3	main
põnev	doc_491521501733_item	3553722	et	3	main
reis	doc_491521501733_item	3553723	et	4	main
me	doc_491521501733_item	3553724	et	4	main
loodame	doc_491521501733_item	3553725	et	3	main
te	doc_491521501733_item	3553727	et	4	main
et	doc_491521501733_item	3553726	et	3	main
aidate	doc_491521501733_item	3553728	et	4	main
meile	doc_491521501733_item	3553729	et	4	main
sellega	doc_491521501733_item	3553730	et	3	main
reisiga	doc_491521501733_item	3553731	et	3	main
reisis	doc_491521501733_item	3553732	et	4	main
me	doc_491521501733_item	3553733	et	4	main
veedaksime	doc_491521501733_item	3553734	et	3	main
aeg	doc_491521501733_item	3553735	et	3	main
lõbusalt	doc_491521501733_item	3553736	et	4	main
me	doc_491521501733_item	3553737	et	4	main
ootame	doc_491521501733_item	3553738	et	3	main
sinust	doc_491521501733_item	3553739	et	3	main
vastus	doc_491521501733_item	3553740	et	3	main
ja	doc_491521501733_item	3553741	et	3	main
loodame	doc_491521501733_item	3553742	et	3	main
teie	doc_491521501733_item	3553743	et	4	main
abi	doc_491521501733_item	3553744	et	4	main
gruppivanem	doc_491521501733_item	3553745	et	4	main
eesnimi	doc_491521501733_item	3553746	et	3	main
perekonnanimi	doc_491521501733_item	3553747	et	3	main
19112002	doc_491521501733_item	3553748	et	2	main
tallinna	doc_491521501730_item	3553753	et	4	main
5	doc_491521501730_item	3553757	et	2	main
gsm	doc_491521501730_item	3553760	et	4	main
lugupeetud	doc_491521501730_item	3553762	et	4	main
as	doc_491521501730_item	3553763	et	4	main
keelekeskus	doc_491521501730_item	3553764	et	3	main
as	doc_491521501730_item	3553768	et	4	main
tahame	doc_491521501730_item	3553771	et	3	main
me	doc_491521501730_item	3553775	et	4	main
hakata	doc_491521501730_item	3553779	et	4	main
klienditeenindajana	doc_491521501730_item	3553785	et	3	main
konsultandina	doc_491521501730_item	3553787	et	3	main
arv	doc_491521501730_item	3553789	et	3	main
ermitaaži	doc_491521501733_item	3553703	et	2	main
ja	doc_491521501733_item	3553704	et	3	main
peeter-pauli	doc_491521501733_item	3553705	et	4	main
kindluse	doc_491521501733_item	3553706	et	4	main
firma	doc_491521501733_item	3553708	et	4	main
ka	doc_491521501733_item	3553709	et	3	main
külastamine	doc_491521501733_item	3553707	et	4	main
pakkub	doc_491521501733_item	3553710	et	4	main
laevasõit	doc_491521501733_item	3553711	et	3	main
lisatasu	doc_491521501733_item	3553712	et	4	main
eest	doc_491521501733_item	3553713	et	4	main
ma	doc_491521501733_item	3553714	et	3	main
mõtlen	doc_491521501733_item	3553715	et	3	main
et	doc_491521501733_item	3553716	et	3	main
see	doc_491521501733_item	3553717	et	3	main
kuulutust	doc_491521501733_item	3553630	et	4	main
ellenring	doc_491521501733_item	3553642	et	4	main
see	doc_491521501733_item	3553643	et	3	main
reisiaeg	doc_491521501733_item	3553649	et	3	main
on	doc_491521501733_item	3553650	et	4	main
me	doc_491521501733_item	3553667	et	4	main
hinnaalandus	doc_491521501733_item	3553669	et	3	main
taha	doc_491521501733_item	3553684	et	4	main
minna	doc_491521501733_item	3553685	et	3	main
reisile	doc_491521501733_item	3553686	et	3	main
kuulutuses	doc_491521501733_item	3553687	et	4	main
kirjutatakse	doc_491521501733_item	3553688	et	3	main
teatripiletid	doc_491521501733_item	3553694	et	3	main
hommiku-	doc_491521501733_item	3553695	et	3	main
lõunasöök	doc_491521501733_item	3553697	et	3	main
ja	doc_491521501733_item	3553696	et	3	main
linnaekskursioon	doc_491521501733_item	3553698	et	3	main
kohaliku	doc_491521501733_item	3553699	et	3	main
giidi	doc_491521501733_item	3553700	et	4	main
juhtimisel	doc_491521501733_item	3553701	et	4	main
ja	doc_491521501733_item	3553702	et	3	main
mnt	doc_491521501730_item	3553754	et	4	main
me	doc_491521501730_item	3553765	et	4	main
soovime	doc_491521501730_item	3553776	et	4	main
koos	doc_491521501730_item	3553777	et	4	main
keelekursustel	doc_491521501730_item	3553781	et	3	main
töötame	doc_491521501730_item	3553783	et	3	main
me	doc_491521501730_item	3553798	et	4	main
keelekursustel	doc_491521501730_item	3553800	et	3	main
ja	doc_491521501730_item	3553803	et	3	main
on	doc_491521501730_item	3553814	et	4	main
veel	doc_491521501730_item	3553829	et	4	main
pakutavad	doc_491521501730_item	3553830	et	4	main
kursused	doc_491521501730_item	3553831	et	3	main
me	doc_491521501730_item	3553832	et	4	main
tahaksime	doc_491521501730_item	3553833	et	3	main
veel	doc_491521501730_item	3553834	et	4	main
teada	doc_491521501730_item	3553835	et	3	main
kursuste	doc_491521501730_item	3553836	et	3	main
pikkus	doc_491521501730_item	3553837	et	4	main
ja	doc_491521501730_item	3553838	et	3	main
õpetajate	doc_491521501730_item	3553839	et	4	main
töökogemus	doc_491521501730_item	3553840	et	3	main
kui	doc_491521501730_item	3553841	et	3	main
palju	doc_491521501730_item	3553842	et	4	main
aega	doc_491521501730_item	3553843	et	4	main
nad	doc_491521501730_item	3553844	et	3	main
töötavad	doc_491521501730_item	3553845	et	4	main
keelekursustel	doc_491521501730_item	3553846	et	3	main
kui	doc_491521501730_item	3553847	et	3	main
pikk	doc_491521501730_item	3553848	et	4	main
on	doc_491521501730_item	3553849	et	4	main
nende	doc_491521501730_item	3553850	et	4	main
töökogemus	doc_491521501730_item	3553851	et	3	main
loodame	doc_491521501730_item	3553852	et	3	main
kiri	doc_491521501730_item	3553750	et	3	main
15	doc_491521501730_item	3553755	et	2	main
555	doc_491521501730_item	3553758	et	2	main
turismifirmas	doc_491521501730_item	3553767	et	3	main
turism	doc_491521501730_item	3553769	et	3	main
õppida	doc_491521501730_item	3553774	et	3	main
õppima	doc_491521501730_item	3553780	et	3	main
sekretärina	doc_491521501730_item	3553784	et	3	main
ja	doc_491521501730_item	3553786	et	3	main
keeleõppijate	doc_491521501730_item	3553788	et	3	main
on	doc_491521501730_item	3553790	et	4	main
me	doc_491521501730_item	3553792	et	4	main
tahaksime	doc_491521501730_item	3553793	et	3	main
õppida	doc_491521501730_item	3553794	et	3	main
oktoobrist	doc_491521501730_item	3553795	et	3	main
kuni	doc_491521501730_item	3553796	et	3	main
võime	doc_491521501730_item	3553799	et	4	main
kolmapäeval	doc_491521501730_item	3553802	et	3	main
kell	doc_491521501730_item	3553806	et	3	main
tasumine	doc_491521501730_item	3553808	et	4	main
on	doc_491521501730_item	3553809	et	4	main
ülekandega	doc_491521501730_item	3553810	et	3	main
tundide	doc_491521501730_item	3553811	et	3	main
turism	doc_491521501730_item	3553816	et	3	main
meil	doc_491521501730_item	3553817	et	4	main
on	doc_491521501730_item	3553818	et	4	main
küsimus	doc_491521501730_item	3553819	et	4	main
kui	doc_491521501730_item	3553820	et	3	main
palju	doc_491521501730_item	3553821	et	4	main
maksavad	doc_491521501730_item	3553822	et	3	main
kursuseid	doc_491521501730_item	3553823	et	3	main
kas	doc_491521501730_item	3553824	et	3	main
on	doc_491521501730_item	3553825	et	4	main
soodustused	doc_491521501730_item	3553826	et	4	main
meid	doc_491521501730_item	3553827	et	4	main
huvitavad	doc_491521501730_item	3553828	et	4	main
ajal	doc_491521501730_item	3553857	et	4	main
toimumise	doc_491521501730_item	3553812	et	4	main
koht	doc_491521501730_item	3553813	et	3	main
ametlik	doc_634572338221_item	3554884	et	3	main
arvamuse	doc_634572338221_item	3554886	et	3	main
toimetaja	doc_634572338221_item	3554889	et	4	main
tiina	doc_634572338221_item	3554890	et	4	main
arvates	doc_634572338221_item	3554906	et	4	main
küll	doc_634572338221_item	3554916	et	4	main
et	doc_634572338221_item	3554917	et	3	main
teie	doc_634572338221_item	3554924	et	4	main
jagatud	doc_634572338221_item	3554932	et	4	main
rühma	doc_634572338221_item	3554934	et	4	main
kahjuks	doc_634572338221_item	3554935	et	4	main
mis	doc_634572338221_item	3554943	et	4	main
arvamuse	doc_634572338217_item	3555033	et	3	main
tiina	doc_634572338217_item	3555037	et	4	main
vt	doc_634572338217_item	3555042	et	4	main
lp	doc_634572338217_item	3555044	et	4	main
ma	doc_634572338217_item	3555051	et	3	main
tallinna	doc_634572338217_item	3555053	et	4	main
aastat	doc_634572338217_item	3555059	et	3	main
artikli	doc_634572338221_item	3554892	et	3	main
see	doc_634572338221_item	3554907	et	3	main
valida	doc_634572338221_item	3554921	et	3	main
ma	doc_634572338221_item	3554936	et	3	main
ise	doc_634572338221_item	3554937	et	4	main
majandust	doc_634572338221_item	3554949	et	4	main
loodan	doc_634572338221_item	3554950	et	3	main
kiri	doc_634572338221_item	3554885	et	3	main
ekspressi	doc_634572338221_item	3554888	et	4	main
arikkel	doc_634572338221_item	3554894	et	2	main
kaalep	doc_634572338221_item	3554899	et	4	main
teema	doc_634572338221_item	3554908	et	4	main
aktuaalne	doc_634572338221_item	3554912	et	3	main
tähtis	doc_634572338221_item	3554914	et	4	main
enda	doc_634572338221_item	3554922	et	4	main
tuleviku	doc_634572338221_item	3554923	et	4	main
täpselt	doc_634572338221_item	3554928	et	4	main
noored	doc_634572338221_item	3554930	et	3	main
siia	doc_634572338221_item	3554938	et	4	main
maani	doc_634572338221_item	3554939	et	3	main
gruppi	doc_634572338221_item	3554944	et	4	main
kuulun	doc_634572338221_item	3554946	et	3	main
kohta	doc_634572338221_item	3554893	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338221_item	3554896	et	4	main
lugesin	doc_634572338221_item	3554900	et	3	main
läbi	doc_634572338221_item	3554902	et	4	main
on	doc_634572338221_item	3554909	et	4	main
eriti	doc_634572338221_item	3554911	et	3	main
ja	doc_634572338221_item	3554913	et	3	main
tõsi	doc_634572338221_item	3554915	et	4	main
praegu	doc_634572338221_item	3554918	et	3	main
on	doc_634572338221_item	3554919	et	4	main
raske	doc_634572338221_item	3554920	et	4	main
inimesed	doc_634572338221_item	3554931	et	3	main
kolme	doc_634572338221_item	3554933	et	4	main
ei	doc_634572338221_item	3554940	et	4	main
oska	doc_634572338221_item	3554941	et	4	main
ma	doc_634572338221_item	3554945	et	3	main
õpin	doc_634572338221_item	3554948	et	3	main
nad	doc_634572338221_item	3554985	et	3	main
millega	doc_634572338221_item	3554984	et	3	main
tahavad	doc_634572338221_item	3554986	et	3	main
tegeleda	doc_634572338221_item	3554987	et	3	main
kogu	doc_634572338221_item	3554988	et	4	main
elu	doc_634572338221_item	3554989	et	4	main
kuid	doc_634572338221_item	3554990	et	4	main
on	doc_634572338221_item	3554991	et	4	main
ka	doc_634572338221_item	3554992	et	3	main
selliseid	doc_634572338221_item	3554993	et	4	main
kes	doc_634572338221_item	3554994	et	4	main
õpib	doc_634572338221_item	3554995	et	3	main
mingisugust	doc_634572338221_item	3554996	et	3	main
erialat	doc_634572338221_item	3554997	et	4	main
ainult	doc_634572338221_item	3554998	et	4	main
sellepärast	doc_634572338221_item	3554999	et	3	main
et	doc_634572338221_item	3555000	et	3	main
ta	doc_634572338221_item	3555001	et	4	main
pääses	doc_634572338221_item	3555002	et	4	main
sellele	doc_634572338221_item	3555003	et	4	main
kohale	doc_634572338221_item	3555004	et	4	main
ametlik	doc_634572338217_item	3555031	et	3	main
eesti	doc_634572338217_item	3555034	et	4	main
toimetaja	doc_634572338217_item	3555036	et	4	main
kohta	doc_634572338217_item	3555040	et	4	main
tallinnas	doc_634572338217_item	3555063	et	4	main
astusin	doc_634572338217_item	3555073	et	3	main
kirjutasin	doc_634572338217_item	3555077	et	3	main
juhtkirja	doc_634572338217_item	3555084	et	4	main
põlvkond	doc_634572338217_item	3555092	et	3	main
kirjutasite	doc_634572338217_item	3555095	et	3	main
rühmidest	doc_634572338217_item	3555098	et	2	main
oluline	doc_634572338217_item	3555107	et	4	main
maailmas	doc_634572338217_item	3555109	et	3	main
on	doc_634572338217_item	3555110	et	4	main
raha	doc_634572338217_item	3555111	et	4	main
teine	doc_634572338217_item	3555112	et	3	main
viimse	doc_634572338217_item	3555120	et	3	main
teha	doc_634572338217_item	3555123	et	3	main
mis	doc_634572338217_item	3555129	et	4	main
neist	doc_634572338217_item	3555130	et	4	main
olen	doc_634572338221_item	3555005	et	3	main
kindel	doc_634572338221_item	3555006	et	3	main
et	doc_634572338221_item	3555007	et	3	main
kõik	doc_634572338221_item	3555008	et	4	main
need	doc_634572338221_item	3555009	et	3	main
abiturientide	doc_634572338221_item	3555010	et	3	main
kahtlustused	doc_634572338221_item	3555011	et	4	main
tekivad	doc_634572338221_item	3555012	et	3	main
üsna	doc_634572338221_item	3555013	et	3	main
suure	doc_634572338221_item	3555014	et	3	main
valiku	doc_634572338221_item	3555015	et	3	main
pärast	doc_634572338221_item	3555016	et	4	main
mida	doc_634572338221_item	3555017	et	4	main
vähem	doc_634572338221_item	3555018	et	4	main
valik	doc_634572338221_item	3555019	et	3	main
seda	doc_634572338221_item	3555020	et	3	main
suurem	doc_634572338221_item	3555021	et	4	main
veendumus	doc_634572338221_item	3555022	et	4	main
ootan	doc_634572338221_item	3555023	et	3	main
teie	doc_634572338221_item	3555024	et	4	main
uusi	doc_634572338221_item	3555025	et	3	main
artikle	doc_634572338221_item	3555026	et	4	main
lugupidamisega	doc_634572338221_item	3555027	et	3	main
eesnimi	doc_634572338221_item	3555028	et	3	main
eesti	doc_634572338221_item	3554887	et	4	main
kaalepi	doc_634572338221_item	3554891	et	4	main
vt	doc_634572338221_item	3554895	et	4	main
lugupeetud	doc_634572338221_item	3554897	et	4	main
tiina	doc_634572338221_item	3554898	et	4	main
hiljuti	doc_634572338221_item	3554901	et	4	main
teie	doc_634572338221_item	3554903	et	4	main
artikel	doc_634572338221_item	3554904	et	4	main
minu	doc_634572338221_item	3554905	et	3	main
tänapäeval	doc_634572338221_item	3554910	et	3	main
artiklis	doc_634572338221_item	3554925	et	3	main
on	doc_634572338221_item	3554926	et	4	main
väga	doc_634572338221_item	3554927	et	3	main
kõik	doc_634572338221_item	3554929	et	4	main
öelda	doc_634572338221_item	3554942	et	4	main
et	doc_634572338221_item	3554951	et	3	main
tulevikus	doc_634572338221_item	3554952	et	4	main
saan	doc_634572338221_item	3554953	et	4	main
leida	doc_634572338221_item	3554954	et	3	main
seotud	doc_634572338221_item	3554955	et	4	main
sellega	doc_634572338221_item	3554956	et	3	main
tööt	doc_634572338221_item	3554957	et	4	main
palga	doc_634572338221_item	3554958	et	3	main
kohta	doc_634572338221_item	3554959	et	4	main
ei	doc_634572338221_item	3554960	et	4	main
oska	doc_634572338221_item	3554961	et	4	main
öelda	doc_634572338221_item	3554962	et	4	main
mitte	doc_634572338221_item	3554963	et	3	main
midagi	doc_634572338221_item	3554964	et	4	main
muidugi	doc_634572338221_item	3554965	et	4	main
mida	doc_634572338221_item	3554966	et	4	main
suurem	doc_634572338221_item	3554967	et	4	main
palk	doc_634572338221_item	3554968	et	3	main
seda	doc_634572338221_item	3554969	et	3	main
parem	doc_634572338221_item	3554970	et	4	main
aga	doc_634572338221_item	3554971	et	3	main
täpset	doc_634572338221_item	3554972	et	3	main
summat	doc_634572338221_item	3554973	et	3	main
ma	doc_634572338221_item	3554974	et	3	main
ei	doc_634572338221_item	3554975	et	4	main
tea	doc_634572338221_item	3554976	et	4	main
kõik	doc_634572338221_item	3554977	et	4	main
minu	doc_634572338221_item	3554978	et	3	main
tuttavad	doc_634572338221_item	3554979	et	4	main
õpivad	doc_634572338221_item	3554980	et	3	main
just	doc_634572338221_item	3554981	et	3	main
seda	doc_634572338221_item	3554982	et	3	main
eriala	doc_634572338221_item	3554983	et	4	main
kiri	doc_634572338217_item	3555032	et	3	main
ma	doc_634572338221_item	3554947	et	3	main
kaalepi	doc_634572338217_item	3555038	et	4	main
tiina	doc_634572338217_item	3555045	et	4	main
tehnikaülikooli	doc_634572338217_item	3555054	et	4	main
19	doc_634572338217_item	3555058	et	2	main
olin	doc_634572338217_item	3555065	et	3	main
sündinud	doc_634572338217_item	3555066	et	4	main
narvas	doc_634572338217_item	3555067	et	4	main
ja	doc_634572338217_item	3555068	et	3	main
elasin	doc_634572338217_item	3555069	et	3	main
selles	doc_634572338217_item	3555074	et	4	main
sest	doc_634572338217_item	3555079	et	4	main
mineval	doc_634572338217_item	3555080	et	4	main
nädalal	doc_634572338217_item	3555081	et	3	main
kus	doc_634572338217_item	3555093	et	3	main
te	doc_634572338217_item	3555094	et	4	main
komast	doc_634572338217_item	3555096	et	4	main
kõige	doc_634572338217_item	3555106	et	4	main
ootab	doc_634572338217_item	3555119	et	3	main
midagi	doc_634572338217_item	3555124	et	4	main
ei	doc_634572338217_item	3555127	et	4	main
tea	doc_634572338217_item	3555128	et	4	main
ja	doc_634572338217_item	3555132	et	3	main
rühm	doc_634572338217_item	3555134	et	3	main
ma	doc_634572338217_item	3555137	et	3	main
tahan	doc_634572338217_item	3555138	et	3	main
normaalne	doc_634572338217_item	3555150	et	3	main
palju	doc_634572338217_item	3555153	et	4	main
tahab	doc_634572338217_item	3555156	et	3	main
õpi	doc_634572338217_item	3555175	et	4	main
ja	doc_634572338217_item	3555176	et	3	main
käed	doc_634572338217_item	3555177	et	3	main
rüpes	doc_634572338217_item	3555178	et	4	main
ootab	doc_634572338217_item	3555179	et	3	main
siis	doc_634572338217_item	3555180	et	3	main
see	doc_634572338217_item	3555181	et	3	main
on	doc_634572338217_item	3555182	et	4	main
pole	doc_634572338217_item	3555183	et	3	main
rühm	doc_634572338217_item	3555186	et	3	main
kes	doc_634572338217_item	3555220	et	4	main
keskkonnakaitsja	doc_634572338217_item	3555224	et	4	main
ekspressi	doc_634572338217_item	3555035	et	4	main
kaalep	doc_634572338217_item	3555046	et	4	main
olen	doc_634572338217_item	3555052	et	3	main
artikli	doc_634572338217_item	3555039	et	3	main
arikkel	doc_634572338217_item	3555041	et	2	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338217_item	3555043	et	4	main
muni	doc_634572338217_item	3555047	et	4	main
nimi	doc_634572338217_item	3555048	et	3	main
on	doc_634572338217_item	3555049	et	4	main
eesnimi	doc_634572338217_item	3555050	et	3	main
ma	doc_634572338217_item	3555056	et	3	main
olen	doc_634572338217_item	3555057	et	3	main
seal	doc_634572338217_item	3555070	et	4	main
kuni	doc_634572338217_item	3555071	et	3	main
ülikoolisse	doc_634572338217_item	3555072	et	4	main
ma	doc_634572338217_item	3555076	et	3	main
vähenõudlike	doc_634572338217_item	3555091	et	3	main
arvates	doc_634572338217_item	3555100	et	4	main
esimene	doc_634572338217_item	3555101	et	3	main
rühm	doc_634572338217_item	3555102	et	3	main
inimesed	doc_634572338217_item	3555104	et	3	main
on	doc_634572338217_item	3555114	et	4	main
pikaldased	doc_634572338217_item	3555115	et	3	main
inimesed	doc_634572338217_item	3555116	et	3	main
ked	doc_634572338217_item	3555117	et	4	main
et	doc_634572338217_item	3555122	et	3	main
kes	doc_634572338217_item	3555126	et	4	main
üliõpilane	doc_634572338217_item	3555055	et	3	main
vana	doc_634572338217_item	3555060	et	4	main
elan	doc_634572338217_item	3555062	et	3	main
kuigi	doc_634572338217_item	3555064	et	3	main
teile	doc_634572338217_item	3555078	et	4	main
loesin	doc_634572338217_item	3555082	et	4	main
juhtkiri	doc_634572338217_item	3555090	et	3	main
inimestest	doc_634572338217_item	3555097	et	3	main
rühm	doc_634572338217_item	3555113	et	3	main
momendi	doc_634572338217_item	3555121	et	3	main
et	doc_634572338217_item	3555147	et	3	main
töötab	doc_634572338217_item	3555154	et	3	main
saada	doc_634572338217_item	3555157	et	4	main
suurt	doc_634572338217_item	3555158	et	3	main
liisida	doc_634572338217_item	3555160	et	4	main
looder	doc_634572338217_item	3555168	et	3	main
ei	doc_634572338217_item	3555171	et	4	main
tööta	doc_634572338217_item	3555172	et	4	main
ja	doc_634572338217_item	3555173	et	3	main
teine	doc_634572338217_item	3555185	et	3	main
isegi	doc_634572338217_item	3555202	et	4	main
ning	doc_634572338217_item	3555223	et	3	main
kui	doc_634572338217_item	3555226	et	3	main
veel	doc_634572338217_item	3555228	et	4	main
ja	doc_634572338217_item	3555061	et	3	main
septembris	doc_634572338217_item	3555075	et	3	main
teie	doc_634572338217_item	3555083	et	4	main
nädalalehtis	doc_634572338217_item	3555085	et	2	main
eesti	doc_634572338217_item	3555086	et	4	main
ekspress	doc_634572338217_item	3555087	et	4	main
see	doc_634572338217_item	3555088	et	3	main
oli	doc_634572338217_item	3555089	et	3	main
teie	doc_634572338217_item	3555099	et	4	main
on	doc_634572338217_item	3555103	et	4	main
kellele	doc_634572338217_item	3555105	et	4	main
asi	doc_634572338217_item	3555108	et	4	main
alati	doc_634572338217_item	3555118	et	4	main
ja	doc_634572338217_item	3555125	et	3	main
on	doc_634572338217_item	3555135	et	4	main
sotsiaaltöötajad	doc_634572338217_item	3555136	et	3	main
see	doc_634572338217_item	3555148	et	3	main
inimene	doc_634572338217_item	3555152	et	3	main
oma	doc_634572338217_item	3555163	et	4	main
kodu	doc_634572338217_item	3555164	et	4	main
noor	doc_634572338217_item	3555167	et	3	main
kes	doc_634572338217_item	3555187	et	4	main
umbkaudu	doc_634572338217_item	3555203	et	3	main
mitte	doc_634572338217_item	3555204	et	3	main
see	doc_634572338217_item	3555205	et	3	main
on	doc_634572338217_item	3555206	et	4	main
on	doc_634572338217_item	3555218	et	4	main
neid	doc_634572338217_item	3555219	et	4	main
kaalepi	doc_634572338215_item	3555502	et	4	main
artikli	doc_634572338215_item	3555503	et	3	main
arikkel	doc_634572338215_item	3555505	et	2	main
vt	doc_634572338215_item	3555506	et	4	main
õpilasena	doc_634572338215_item	3555512	et	3	main
teie	doc_634572338215_item	3555524	et	4	main
huvitavana	doc_634572338215_item	3555530	et	4	main
julgen	doc_634572338215_item	3555531	et	3	main
vältida	doc_634572338215_item	3555532	et	3	main
et	doc_634572338215_item	3555533	et	3	main
meie	doc_634572338215_item	3555534	et	4	main
põlvkond	doc_634572338215_item	3555535	et	3	main
ei	doc_634572338215_item	3555536	et	4	main
erine	doc_634572338215_item	3555537	et	4	main
eriti	doc_634572338215_item	3555538	et	3	main
rühmadeks	doc_634572338215_item	3555545	et	3	main
on	doc_634572338215_item	3555547	et	4	main
me	doc_634572338215_item	3555583	et	4	main
on	doc_634572338215_item	3555607	et	4	main
ütelda	doc_634572338217_item	3555139	et	4	main
et	doc_634572338217_item	3555140	et	3	main
ma	doc_634572338217_item	3555141	et	3	main
olen	doc_634572338217_item	3555142	et	3	main
nõus	doc_634572338217_item	3555143	et	4	main
teiega	doc_634572338217_item	3555144	et	3	main
arvates	doc_634572338217_item	3555146	et	4	main
kui	doc_634572338217_item	3555151	et	3	main
ja	doc_634572338217_item	3555155	et	3	main
palka	doc_634572338217_item	3555159	et	4	main
aga	doc_634572338217_item	3555165	et	3	main
kui	doc_634572338217_item	3555166	et	3	main
vanemadega	doc_634572338217_item	3555170	et	4	main
ei	doc_634572338217_item	3555174	et	4	main
normaalne	doc_634572338217_item	3555184	et	3	main
alati	doc_634572338217_item	3555188	et	4	main
ootab	doc_634572338217_item	3555189	et	3	main
midagi	doc_634572338217_item	3555190	et	4	main
vaid	doc_634572338217_item	3555191	et	3	main
mõni	doc_634572338217_item	3555192	et	3	main
nädal	doc_634572338217_item	3555193	et	3	main
on	doc_634572338217_item	3555194	et	4	main
ülikoolidesse	doc_634572338217_item	3555195	et	3	main
astumiseni	doc_634572338217_item	3555196	et	4	main
aega	doc_634572338217_item	3555197	et	4	main
aga	doc_634572338217_item	3555198	et	3	main
nad	doc_634572338217_item	3555199	et	3	main
ei	doc_634572338217_item	3555200	et	4	main
tea	doc_634572338217_item	3555201	et	4	main
sellist	doc_634572338217_item	3555214	et	4	main
inimest	doc_634572338217_item	3555215	et	3	main
kolmas	doc_634572338217_item	3555216	et	3	main
rühm	doc_634572338217_item	3555217	et	3	main
sotsiaaltöötaja	doc_634572338217_item	3555222	et	4	main
ametist	doc_634572338217_item	3555225	et	3	main
rohkem	doc_634572338217_item	3555229	et	4	main
oleks	doc_634572338217_item	3555230	et	3	main
saab	doc_634572338217_item	3555131	et	3	main
kolmas	doc_634572338217_item	3555133	et	3	main
minu	doc_634572338217_item	3555145	et	3	main
on	doc_634572338217_item	3555149	et	4	main
auto	doc_634572338217_item	3555161	et	4	main
soetada	doc_634572338217_item	3555162	et	3	main
elab	doc_634572338217_item	3555169	et	3	main
vaga	doc_634572338217_item	3555207	et	4	main
suur	doc_634572338217_item	3555208	et	3	main
rühm	doc_634572338217_item	3555209	et	3	main
ja	doc_634572338217_item	3555210	et	3	main
ma	doc_634572338217_item	3555211	et	3	main
tean	doc_634572338217_item	3555212	et	3	main
palju	doc_634572338217_item	3555213	et	4	main
räägivad	doc_634572338217_item	3555221	et	3	main
neid	doc_634572338217_item	3555227	et	4	main
võiks	doc_634572338217_item	3555231	et	4	main
tuleviku	doc_634572338217_item	3555232	et	4	main
osas	doc_634572338217_item	3555233	et	4	main
neile	doc_634572338217_item	3555234	et	4	main
panustada	doc_634572338217_item	3555235	et	3	main
tüüpiliselt	doc_634572338217_item	3555236	et	2	main
tulevad	doc_634572338217_item	3555237	et	4	main
sellest	doc_634572338217_item	3555238	et	4	main
teemast	doc_634572338217_item	3555239	et	4	main
kõnelejad	doc_634572338217_item	3555240	et	4	main
väiksematest	doc_634572338217_item	3555241	et	2	main
kohtadest	doc_634572338217_item	3555242	et	3	main
kokkuvõtteks	doc_634572338217_item	3555243	et	3	main
tahan	doc_634572338217_item	3555244	et	3	main
ütelda	doc_634572338217_item	3555245	et	4	main
et	doc_634572338217_item	3555246	et	3	main
mulle	doc_634572338217_item	3555247	et	4	main
meeldis	doc_634572338217_item	3555249	et	3	main
teie	doc_634572338217_item	3555250	et	4	main
juhtkiri	doc_634572338217_item	3555251	et	3	main
väga	doc_634572338217_item	3555248	et	3	main
ma	doc_634572338217_item	3555252	et	3	main
ootan	doc_634572338217_item	3555253	et	3	main
jätkumise	doc_634572338217_item	3555254	et	2	main
austusega	doc_634572338217_item	3555255	et	4	main
eesnimi	doc_634572338217_item	3555256	et	3	main
ametlik	doc_634572338215_item	3555495	et	3	main
eesti	doc_634572338215_item	3555498	et	4	main
toimetaja	doc_634572338215_item	3555500	et	4	main
tiina	doc_634572338215_item	3555501	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338215_item	3555507	et	4	main
lugupeetud	doc_634572338215_item	3555508	et	4	main
ülikooli	doc_634572338215_item	3555511	et	4	main
arvamust	doc_634572338215_item	3555516	et	3	main
teie	doc_634572338215_item	3555517	et	4	main
põlvkond	doc_634572338215_item	3555520	et	3	main
pakkutud	doc_634572338215_item	3555526	et	4	main
teema	doc_634572338215_item	3555527	et	4	main
oli	doc_634572338215_item	3555542	et	3	main
inimeste	doc_634572338215_item	3555543	et	3	main
ühiskonnas	doc_634572338215_item	3555587	et	4	main
kus	doc_634572338215_item	3555588	et	3	main
tulevikus	doc_634572338215_item	3555594	et	4	main
arvamuse	doc_634572338215_item	3555497	et	3	main
tiina	doc_634572338215_item	3555509	et	4	main
tahaksin	doc_634572338215_item	3555514	et	3	main
poolt	doc_634572338215_item	3555525	et	4	main
kohta	doc_634572338215_item	3555504	et	4	main
olles	doc_634572338215_item	3555513	et	3	main
artikli	doc_634572338215_item	3555518	et	3	main
kohta	doc_634572338215_item	3555521	et	4	main
väljendama	doc_634572338215_item	3555522	et	3	main
sest	doc_634572338215_item	3555523	et	4	main
paistab	doc_634572338215_item	3555528	et	3	main
mulle	doc_634572338215_item	3555529	et	4	main
alati	doc_634572338215_item	3555541	et	4	main
jagamine	doc_634572338215_item	3555544	et	4	main
millistel	doc_634572338215_item	3555546	et	3	main
ei	doc_634572338215_item	3555589	et	4	main
ja	doc_634572338215_item	3555595	et	3	main
noored	doc_634572338215_item	3555597	et	3	main
eelkõige	doc_634572338215_item	3555599	et	3	main
tänapäevane	doc_634572338215_item	3555605	et	4	main
elada	doc_634572338215_item	3555613	et	3	main
nagu	doc_634572338215_item	3555618	et	3	main
mina	doc_634572338215_item	3555632	et	4	main
ikkagi	doc_634572338215_item	3555663	et	4	main
võib	doc_634572338215_item	3555664	et	3	main
jagama	doc_634572338215_item	3555665	et	3	main
rühmadeks	doc_634572338215_item	3555666	et	3	main
need	doc_634572338215_item	3555667	et	3	main
kiri	doc_634572338215_item	3555496	et	3	main
ekspressi	doc_634572338215_item	3555499	et	4	main
kaalep	doc_634572338215_item	3555510	et	4	main
oma	doc_634572338215_item	3555515	et	4	main
vahenõudlike	doc_634572338215_item	3555519	et	3	main
eelmistest	doc_634572338215_item	3555539	et	4	main
oma	doc_634572338215_item	3555548	et	4	main
iseloomulikkud	doc_634572338215_item	3555549	et	4	main
väärtushinnangute	doc_634572338215_item	3555550	et	3	main
süsteemid	doc_634572338215_item	3555551	et	3	main
ja	doc_634572338215_item	3555552	et	3	main
käitumise	doc_634572338215_item	3555553	et	4	main
tüüpid	doc_634572338215_item	3555554	et	4	main
teie	doc_634572338215_item	3555555	et	4	main
olete	doc_634572338215_item	3555556	et	3	main
oma	doc_634572338215_item	3555557	et	4	main
artiklis	doc_634572338215_item	3555558	et	3	main
kahetsemisega	doc_634572338215_item	3555559	et	4	main
ütelnud	doc_634572338215_item	3555560	et	4	main
et	doc_634572338215_item	3555561	et	3	main
tänapäevastel	doc_634572338215_item	3555562	et	4	main
noortel	doc_634572338215_item	3555563	et	3	main
ei	doc_634572338215_item	3555564	et	4	main
ole	doc_634572338215_item	3555565	et	4	main
mingisugusi	doc_634572338215_item	3555566	et	4	main
suurjoonelisi	doc_634572338215_item	3555567	et	4	main
plaani	doc_634572338215_item	3555568	et	4	main
tulevikule	doc_634572338215_item	3555569	et	4	main
kuid	doc_634572338215_item	3555570	et	4	main
nad	doc_634572338215_item	3555571	et	3	main
peavad	doc_634572338215_item	3555572	et	4	main
kodust	doc_634572338215_item	3555573	et	4	main
idülli	doc_634572338215_item	3555574	et	4	main
ihaldusväärseks	doc_634572338215_item	3555575	et	4	main
minu	doc_634572338215_item	3555576	et	3	main
meelest	doc_634572338215_item	3555577	et	4	main
see	doc_634572338215_item	3555578	et	3	main
põlvkondadest	doc_634572338215_item	3555540	et	3	main
on	doc_634572338215_item	3555579	et	4	main
et	doc_634572338215_item	3555582	et	3	main
elame	doc_634572338215_item	3555584	et	3	main
ikkagi	doc_634572338215_item	3555585	et	4	main
ebastabiilses	doc_634572338215_item	3555586	et	3	main
oma	doc_634572338215_item	3555593	et	4	main
püüavad	doc_634572338215_item	3555598	et	3	main
väärilist	doc_634572338215_item	3555602	et	4	main
tõemeelseks	doc_634572338215_item	3555608	et	3	main
kui	doc_634572338215_item	3555609	et	3	main
mis	doc_634572338215_item	3555629	et	4	main
minusse	doc_634572338215_item	3555630	et	3	main
puutub	doc_634572338215_item	3555631	et	3	main
oma	doc_634572338215_item	3555639	et	4	main
tere	doc_634572338211_item	3555893	et	3	main
tallinna	doc_634572338211_item	3555902	et	4	main
kursuses	doc_634572338211_item	3555907	et	3	main
kirjutan	doc_634572338211_item	3555909	et	3	main
lugesin	doc_634572338211_item	3555913	et	3	main
artikkel	doc_634572338211_item	3555915	et	3	main
vähenõudlike	doc_634572338211_item	3555916	et	3	main
põlvkond	doc_634572338211_item	3555917	et	3	main
tahan	doc_634572338211_item	3555923	et	3	main
oma	doc_634572338211_item	3555925	et	4	main
ma	doc_634572338211_item	3555928	et	3	main
et	doc_634572338211_item	3555931	et	3	main
palju	doc_634572338211_item	3555932	et	4	main
küsisin	doc_634572338211_item	3555943	et	3	main
sõpru	doc_634572338211_item	3555945	et	3	main
nad	doc_634572338211_item	3555947	et	3	main
tahavad	doc_634572338211_item	3555948	et	3	main
saada	doc_634572338211_item	3555949	et	4	main
siis	doc_634572338211_item	3555950	et	3	main
kuhu	doc_634572338211_item	3555985	et	3	main
väheneb	doc_634572338211_item	3555987	et	3	main
seotud	doc_634572338215_item	3555580	et	4	main
sellega	doc_634572338215_item	3555581	et	3	main
või	doc_634572338215_item	3555590	et	4	main
olla	doc_634572338215_item	3555591	et	3	main
kindel	doc_634572338215_item	3555592	et	3	main
endale	doc_634572338215_item	3555601	et	4	main
elu	doc_634572338215_item	3555603	et	4	main
lihtsalt	doc_634572338215_item	3555604	et	4	main
noored	doc_634572338215_item	3555611	et	3	main
olete	doc_634572338215_item	3555616	et	3	main
vanemad	doc_634572338215_item	3555620	et	4	main
ja	doc_634572338215_item	3555621	et	3	main
minu	doc_634572338215_item	3555622	et	3	main
arvamuse	doc_634572338215_item	3555623	et	3	main
järgi	doc_634572338215_item	3555624	et	4	main
see	doc_634572338215_item	3555625	et	3	main
põhjustab	doc_634572338215_item	3555626	et	3	main
eelesitatud	doc_634572338215_item	3555627	et	3	main
olukord	doc_634572338215_item	3555628	et	3	main
tahaksin	doc_634572338215_item	3555634	et	3	main
kodus	doc_634572338215_item	3555637	et	4	main
sõida	doc_634572338215_item	3555638	et	4	main
autoga	doc_634572338215_item	3555640	et	3	main
ühesõnaga	doc_634572338215_item	3555641	et	3	main
omada	doc_634572338215_item	3555642	et	3	main
asju	doc_634572338215_item	3555643	et	3	main
mis	doc_634572338215_item	3555644	et	4	main
normaalselt	doc_634572338215_item	3555656	et	4	main
nõus	doc_634572338215_item	3555658	et	4	main
teiega	doc_634572338215_item	3555659	et	3	main
selles	doc_634572338215_item	3555660	et	4	main
et	doc_634572338215_item	3555661	et	3	main
noori	doc_634572338215_item	3555662	et	3	main
paljud	doc_634572338215_item	3555596	et	3	main
kindlustama	doc_634572338215_item	3555600	et	3	main
põlvkond	doc_634572338215_item	3555606	et	3	main
eelmised	doc_634572338215_item	3555610	et	3	main
teie	doc_634572338215_item	3555615	et	4	main
elada	doc_634572338215_item	3555635	et	3	main
teevad	doc_634572338215_item	3555645	et	3	main
elu	doc_634572338215_item	3555646	et	4	main
mugavamaks	doc_634572338215_item	3555647	et	4	main
ja	doc_634572338215_item	3555648	et	3	main
meeldivamaks	doc_634572338215_item	3555649	et	4	main
ma	doc_634572338215_item	3555650	et	3	main
arvan	doc_634572338215_item	3555651	et	3	main
et	doc_634572338215_item	3555652	et	3	main
see	doc_634572338215_item	3555653	et	3	main
on	doc_634572338215_item	3555654	et	4	main
täitsa	doc_634572338215_item	3555655	et	3	main
olen	doc_634572338215_item	3555657	et	3	main
kes	doc_634572338215_item	3555668	et	4	main
on	doc_634572338215_item	3555669	et	4	main
oma	doc_634572338215_item	3555670	et	4	main
elukutse	doc_634572338215_item	3555671	et	4	main
valinud	doc_634572338215_item	3555672	et	4	main
ja	doc_634572338215_item	3555673	et	3	main
kujutavad	doc_634572338215_item	3555674	et	4	main
täpselt	doc_634572338215_item	3555675	et	4	main
oma	doc_634572338215_item	3555676	et	4	main
tuleviku	doc_634572338215_item	3555677	et	4	main
ja	doc_634572338215_item	3555678	et	3	main
teised	doc_634572338215_item	3555679	et	4	main
on	doc_634572338215_item	3555680	et	4	main
need	doc_634572338215_item	3555681	et	3	main
kes	doc_634572338215_item	3555682	et	4	main
ei	doc_634572338215_item	3555683	et	4	main
tea	doc_634572338215_item	3555684	et	4	main
millega	doc_634572338215_item	3555685	et	3	main
nad	doc_634572338215_item	3555686	et	3	main
tahavad	doc_634572338215_item	3555687	et	3	main
oma	doc_634572338215_item	3555688	et	4	main
elu	doc_634572338215_item	3555689	et	4	main
seotada	doc_634572338215_item	3555690	et	4	main
loodan	doc_634572338215_item	3555691	et	3	main
et	doc_634572338215_item	3555692	et	3	main
minu	doc_634572338215_item	3555693	et	3	main
poolt	doc_634572338215_item	3555694	et	4	main
tahavad	doc_634572338215_item	3555612	et	3	main
nagu	doc_634572338215_item	3555614	et	3	main
ütelnud	doc_634572338215_item	3555617	et	4	main
nende	doc_634572338215_item	3555619	et	4	main
ka	doc_634572338215_item	3555633	et	3	main
oma	doc_634572338215_item	3555636	et	4	main
tehtud	doc_634572338215_item	3555695	et	4	main
valimine	doc_634572338215_item	3555696	et	4	main
ei	doc_634572338215_item	3555697	et	4	main
pane	doc_634572338215_item	3555698	et	4	main
mind	doc_634572338215_item	3555699	et	4	main
kahetsema	doc_634572338215_item	3555700	et	3	main
kokkuvõtteks	doc_634572338215_item	3555701	et	3	main
tahaksin	doc_634572338215_item	3555702	et	3	main
ütelda	doc_634572338215_item	3555703	et	4	main
et	doc_634572338215_item	3555704	et	3	main
eelnev	doc_634572338215_item	3555706	et	4	main
iga	doc_634572338215_item	3555705	et	4	main
põlvkond	doc_634572338215_item	3555707	et	3	main
kritiseerib	doc_634572338215_item	3555708	et	3	main
järgmist	doc_634572338215_item	3555709	et	3	main
põlvkonda	doc_634572338215_item	3555710	et	4	main
olen	doc_634572338215_item	3555711	et	3	main
veendunud	doc_634572338215_item	3555712	et	4	main
et	doc_634572338215_item	3555713	et	3	main
see	doc_634572338215_item	3555714	et	3	main
on	doc_634572338215_item	3555715	et	4	main
mõttetu	doc_634572338215_item	3555716	et	4	main
see	doc_634572338215_item	3555717	et	3	main
on	doc_634572338215_item	3555718	et	4	main
igavene	doc_634572338215_item	3555719	et	4	main
problem	doc_634572338215_item	3555720	et	4	main
parimate	doc_634572338215_item	3555721	et	4	main
soovitega	doc_634572338215_item	3555722	et	4	main
eesnimi	doc_634572338215_item	3555723	et	3	main
tiina	doc_634572338211_item	3555895	et	4	main
õpin	doc_634572338211_item	3555901	et	3	main
esimeses	doc_634572338211_item	3555906	et	3	main
ja	doc_634572338211_item	3555921	et	3	main
teiega	doc_634572338211_item	3555927	et	3	main
mis	doc_634572338211_item	3555936	et	4	main
neist	doc_634572338211_item	3555937	et	4	main
saab	doc_634572338211_item	3555938	et	3	main
juba	doc_634572338211_item	3555939	et	3	main
teile	doc_634572338211_item	3555990	et	4	main
teha	doc_634572338211_item	3555993	et	3	main
ja	doc_634572338211_item	3555996	et	3	main
ei	doc_634572338211_item	3555999	et	4	main
valida	doc_634572338211_item	3556001	et	3	main
on	doc_634572338211_item	3556005	et	4	main
väga	doc_634572338211_item	3556006	et	3	main
suur	doc_634572338211_item	3556007	et	3	main
see	doc_634572338211_item	3556008	et	3	main
tähendab	doc_634572338211_item	3556009	et	3	main
juhust	doc_634572338211_item	3556018	et	4	main
kuhu	doc_634572338211_item	3556035	et	3	main
annavad	doc_634572338211_item	3556039	et	3	main
neljakümnesed	doc_634572338211_item	3556053	et	3	main
halb	doc_634572338211_item	3556057	et	3	main
neile	doc_634572338211_item	3556062	et	4	main
on	doc_634572338211_item	3556064	et	4	main
sobil	doc_634572338211_item	3556065	et	3	main
on	doc_634572338211_item	3556068	et	4	main
kakskümmend	doc_634572338211_item	3556075	et	4	main
aastat	doc_634572338211_item	3556076	et	3	main
ja	doc_634572338211_item	3556085	et	3	main
ametlik	doc_634572338211_item	3555891	et	3	main
kaalep	doc_634572338211_item	3555896	et	4	main
instituudis	doc_634572338211_item	3555905	et	3	main
ma	doc_634572338211_item	3555908	et	3	main
et	doc_634572338211_item	3555911	et	3	main
teie	doc_634572338211_item	3555914	et	4	main
läbi	doc_634572338211_item	3555918	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338211_item	3555919	et	4	main
8062006	doc_634572338211_item	3555920	et	2	main
tea	doc_634572338211_item	3555935	et	4	main
kui	doc_634572338211_item	3555941	et	3	main
kelleks	doc_634572338211_item	3555946	et	4	main
ma	doc_634572338211_item	3555951	et	3	main
võimalus	doc_634572338211_item	3555984	et	3	main
aitab	doc_634572338211_item	3555989	et	3	main
valikut	doc_634572338211_item	3555992	et	3	main
midagi	doc_634572338211_item	3556013	et	4	main
valite	doc_634572338211_item	3556014	et	3	main
kiri	doc_634572338211_item	3555892	et	3	main
olen	doc_634572338211_item	3555898	et	3	main
ma	doc_634572338211_item	3555900	et	3	main
informaatika	doc_634572338211_item	3555904	et	4	main
teile	doc_634572338211_item	3555910	et	4	main
nüüd	doc_634572338211_item	3555922	et	4	main
abituriente	doc_634572338211_item	3555933	et	3	main
ei	doc_634572338211_item	3555934	et	4	main
koolis	doc_634572338211_item	3555940	et	4	main
minna	doc_634572338211_item	3555986	et	3	main
ja	doc_634572338211_item	3555988	et	3	main
arukat	doc_634572338211_item	3555991	et	3	main
paljudele	doc_634572338211_item	3555998	et	3	main
eriti	doc_634572338211_item	3556002	et	3	main
valik	doc_634572338211_item	3556004	et	3	main
et	doc_634572338211_item	3556010	et	3	main
te	doc_634572338211_item	3556011	et	4	main
mitte	doc_634572338211_item	3556012	et	3	main
mööda	doc_634572338211_item	3556019	et	4	main
aga	doc_634572338211_item	3556020	et	3	main
või	doc_634572338211_item	3556033	et	4	main
nad	doc_634572338211_item	3556037	et	3	main
kindlasti	doc_634572338211_item	3556038	et	3	main
te	doc_634572338211_item	3556046	et	4	main
arvate	doc_634572338211_item	3556047	et	3	main
elada	doc_634572338211_item	3556051	et	3	main
see	doc_634572338211_item	3556055	et	3	main
et	doc_634572338211_item	3556060	et	3	main
sellele	doc_634572338211_item	3556067	et	4	main
taha	doc_634572338211_item	3556073	et	4	main
palju	doc_634572338211_item	3556083	et	4	main
ei	doc_634572338211_item	3556089	et	4	main
ametlik	doc_634572338207_item	3556332	et	3	main
eesti	doc_634572338207_item	3556335	et	4	main
kaalepi	doc_634572338207_item	3556339	et	4	main
kaalep	doc_634572338207_item	3556347	et	4	main
tahaks	doc_634572338207_item	3556348	et	3	main
on	doc_634572338207_item	3556355	et	4	main
väga	doc_634572338207_item	3556356	et	3	main
noorte	doc_634572338207_item	3556363	et	3	main
teiega	doc_634572338207_item	3556368	et	3	main
ja	doc_634572338207_item	3556377	et	3	main
saada	doc_634572338207_item	3556378	et	4	main
iga	doc_634572338207_item	3556390	et	4	main
päev	doc_634572338207_item	3556391	et	3	main
kus	doc_634572338207_item	3556399	et	3	main
sa	doc_634572338207_item	3556400	et	3	main
ise	doc_634572338207_item	3556401	et	4	main
pead	doc_634572338207_item	3556402	et	4	main
ida	doc_634572338207_item	3556407	et	4	main
üks	doc_634572338207_item	3556408	et	3	main
tahaks	doc_634572338207_item	3556409	et	3	main
olla	doc_634572338207_item	3556410	et	3	main
ajal	doc_634572338207_item	3556415	et	4	main
saada	doc_634572338207_item	3556439	et	4	main
või	doc_634572338211_item	3556127	et	4	main
kirjutate	doc_634572338211_item	3556128	et	3	main
kus	doc_634572338211_item	3556129	et	3	main
mul	doc_634572338211_item	3556130	et	3	main
ei	doc_634572338211_item	3556131	et	4	main
ole	doc_634572338211_item	3556132	et	4	main
õigust	doc_634572338211_item	3556133	et	4	main
loodan	doc_634572338211_item	3556134	et	3	main
teie	doc_634572338211_item	3556135	et	4	main
vastust	doc_634572338211_item	3556136	et	4	main
eesnimi	doc_634572338211_item	3556137	et	3	main
30	doc_634572338211_item	3556138	et	2	main
dets	doc_634572338211_item	3556139	et	4	main
2006	doc_634572338211_item	3556140	et	2	main
a	doc_634572338211_item	3556141	et	4	main
lp	doc_634572338211_item	3555894	et	4	main
ma	doc_634572338211_item	3555897	et	3	main
eesnimi	doc_634572338211_item	3555899	et	3	main
tehnikaülikooli	doc_634572338211_item	3555903	et	4	main
ma	doc_634572338211_item	3555912	et	3	main
jaguda	doc_634572338211_item	3555924	et	3	main
arvamus	doc_634572338211_item	3555926	et	3	main
olen	doc_634572338211_item	3555929	et	3	main
nõus	doc_634572338211_item	3555930	et	4	main
ma	doc_634572338211_item	3555942	et	3	main
oma	doc_634572338211_item	3555944	et	4	main
sain	doc_634572338211_item	3555952	et	3	main
ainult	doc_634572338211_item	3555953	et	4	main
vastus	doc_634572338211_item	3555955	et	3	main
üks	doc_634572338211_item	3555954	et	3	main
ei	doc_634572338211_item	3555956	et	4	main
ma	doc_634572338211_item	3555959	et	3	main
olen	doc_634572338211_item	3555960	et	3	main
riigieksamitega	doc_634572338211_item	3555958	et	3	main
tea	doc_634572338211_item	3555957	et	4	main
ka	doc_634572338211_item	3555961	et	3	main
nõus	doc_634572338211_item	3555962	et	4	main
paljudel	doc_634572338211_item	3555963	et	3	main
on	doc_634572338211_item	3555964	et	4	main
omapärane	doc_634572338211_item	3555965	et	4	main
valik	doc_634572338211_item	3555966	et	3	main
kuhu	doc_634572338211_item	3555967	et	3	main
õppida	doc_634572338211_item	3555968	et	3	main
või	doc_634572338211_item	3555969	et	4	main
töötada	doc_634572338211_item	3555970	et	3	main
minna	doc_634572338211_item	3555971	et	3	main
sellele	doc_634572338211_item	3555972	et	4	main
aitavad	doc_634572338211_item	3555973	et	4	main
need	doc_634572338211_item	3555974	et	3	main
eksamite	doc_634572338211_item	3555975	et	3	main
kui	doc_634572338211_item	3555977	et	3	main
punktid	doc_634572338211_item	3555976	et	4	main
te	doc_634572338211_item	3555978	et	4	main
saite	doc_634572338211_item	3555979	et	4	main
erinevaid	doc_634572338211_item	3555980	et	4	main
punktide	doc_634572338211_item	3555981	et	3	main
kogusi	doc_634572338211_item	3555982	et	3	main
teie	doc_634572338211_item	3555983	et	4	main
näidis	doc_634572338211_item	3555994	et	4	main
võib-olla	doc_634572338211_item	3555997	et	3	main
ei	doc_634572338211_item	3556021	et	4	main
tähenda	doc_634572338211_item	3556022	et	4	main
et	doc_634572338211_item	3556023	et	3	main
elule	doc_634572338211_item	3556024	et	3	main
tuli	doc_634572338211_item	3556025	et	4	main
lõpp	doc_634572338211_item	3556026	et	3	main
sellepärast	doc_634572338211_item	3556027	et	3	main
te	doc_634572338211_item	3556028	et	4	main
võite	doc_634572338211_item	3556029	et	4	main
küsida	doc_634572338211_item	3556030	et	3	main
oma	doc_634572338211_item	3556031	et	4	main
sugulasi	doc_634572338211_item	3556032	et	3	main
mulle	doc_634572338211_item	3555995	et	4	main
meeldi	doc_634572338211_item	3556000	et	4	main
kui	doc_634572338211_item	3556003	et	3	main
nõus	doc_634572338211_item	3556044	et	4	main
et	doc_634572338211_item	3556045	et	3	main
tahavad	doc_634572338211_item	3556050	et	3	main
nagu	doc_634572338211_item	3556052	et	3	main
ei	doc_634572338211_item	3556072	et	4	main
osta	doc_634572338211_item	3556080	et	4	main
nad	doc_634572338211_item	3556081	et	3	main
tahavad	doc_634572338211_item	3556082	et	3	main
tiina	doc_634572338207_item	3556338	et	4	main
kohta	doc_634572338207_item	3556341	et	4	main
te	doc_634572338207_item	3556351	et	4	main
artikle	doc_634572338207_item	3556352	et	4	main
andis	doc_634572338207_item	3556359	et	3	main
inimeste	doc_634572338207_item	3556364	et	3	main
nõus	doc_634572338207_item	3556369	et	4	main
iga	doc_634572338207_item	3556379	et	4	main
et	doc_634572338207_item	3556383	et	3	main
ühe	doc_634572338207_item	3556392	et	4	main
hoolima	doc_634572338207_item	3556406	et	4	main
ja	doc_634572338211_item	3556015	et	3	main
lasete	doc_634572338211_item	3556016	et	4	main
head	doc_634572338211_item	3556017	et	4	main
sõpru	doc_634572338211_item	3556034	et	3	main
minna	doc_634572338211_item	3556036	et	3	main
nõu	doc_634572338211_item	3556040	et	4	main
ei	doc_634572338211_item	3556042	et	4	main
ole	doc_634572338211_item	3556043	et	4	main
kahekümneaastased	doc_634572338211_item	3556049	et	4	main
siis	doc_634572338211_item	3556054	et	3	main
arvan	doc_634572338211_item	3556059	et	3	main
kui	doc_634572338211_item	3556061	et	3	main
see	doc_634572338211_item	3556063	et	3	main
siis	doc_634572338211_item	3556066	et	3	main
oma	doc_634572338211_item	3556069	et	4	main
põhjus	doc_634572338211_item	3556070	et	4	main
paljud	doc_634572338211_item	3556071	et	3	main
pappi	doc_634572338211_item	3556084	et	4	main
kohe	doc_634572338211_item	3556086	et	4	main
sest	doc_634572338211_item	3556087	et	4	main
neile	doc_634572338211_item	3556088	et	4	main
kiri	doc_634572338207_item	3556333	et	3	main
arvamuse	doc_634572338207_item	3556334	et	3	main
tiina	doc_634572338207_item	3556346	et	4	main
eest	doc_634572338207_item	3556353	et	4	main
see	doc_634572338207_item	3556354	et	3	main
informatsiooni	doc_634572338207_item	3556362	et	4	main
ma	doc_634572338207_item	3556366	et	3	main
oma	doc_634572338207_item	3556381	et	4	main
midagi	doc_634572338207_item	3556386	et	4	main
välja	doc_634572338207_item	3556388	et	4	main
rahulikut	doc_634572338207_item	3556395	et	4	main
heaolu	doc_634572338207_item	3556404	et	4	main
me	doc_634572338207_item	3556413	et	4	main
et	doc_634572338207_item	3556433	et	3	main
valida	doc_634572338207_item	3556447	et	3	main
valik	doc_634572338207_item	3556453	et	3	main
sellest	doc_634572338207_item	3556455	et	4	main
töö	doc_634572338207_item	3556458	et	4	main
sellest	doc_634572338207_item	3556494	et	4	main
kuidas	doc_634572338207_item	3556495	et	3	main
üldne	doc_634572338207_item	3556502	et	4	main
tulevikust	doc_634572338207_item	3556504	et	4	main
peamiselt	doc_634572338207_item	3556517	et	4	main
ülikooli	doc_634572338207_item	3556521	et	4	main
õppima	doc_634572338207_item	3556522	et	3	main
siis	doc_634572338207_item	3556523	et	3	main
midagi	doc_634572338207_item	3556524	et	4	main
tere	doc_432051777921_item	3556532	et	3	main
on	doc_432051777921_item	3556545	et	4	main
olen	doc_432051777921_item	3556559	et	3	main
aastat	doc_432051777921_item	3556562	et	3	main
sellel	doc_432051777921_item	3556572	et	4	main
eestlastega	doc_432051777921_item	3556583	et	4	main
mul	doc_432051777921_item	3556584	et	3	main
ajalehed	doc_432051777921_item	3556595	et	3	main
keel	doc_432051777921_item	3556618	et	4	main
ma	doc_634572338211_item	3556041	et	3	main
kui	doc_634572338211_item	3556048	et	3	main
on	doc_634572338211_item	3556056	et	4	main
ma	doc_634572338211_item	3556058	et	3	main
töötada	doc_634572338211_item	3556074	et	3	main
ainult	doc_634572338211_item	3556077	et	4	main
et	doc_634572338211_item	3556078	et	3	main
kodu	doc_634572338211_item	3556079	et	4	main
sobi	doc_634572338211_item	3556090	et	4	main
võtta	doc_634572338211_item	3556091	et	3	main
pangast	doc_634572338211_item	3556092	et	4	main
liising	doc_634572338211_item	3556093	et	3	main
osta	doc_634572338211_item	3556094	et	4	main
midagi	doc_634572338211_item	3556095	et	4	main
ja	doc_634572338211_item	3556096	et	3	main
pealegi	doc_634572338211_item	3556097	et	4	main
suurt	doc_634572338211_item	3556099	et	3	main
tagastada	doc_634572338211_item	3556098	et	3	main
rahasumma	doc_634572338211_item	3556100	et	4	main
koos	doc_634572338211_item	3556101	et	4	main
suure	doc_634572338211_item	3556102	et	3	main
intressiga	doc_634572338211_item	3556103	et	3	main
nad	doc_634572338211_item	3556104	et	3	main
tahavad	doc_634572338211_item	3556105	et	3	main
osta	doc_634572338211_item	3556106	et	4	main
midagi	doc_634572338211_item	3556107	et	4	main
ja	doc_634572338211_item	3556108	et	3	main
laska	doc_634572338211_item	3556109	et	4	main
seda	doc_634572338211_item	3556110	et	3	main
meelest	doc_634572338211_item	3556111	et	4	main
ma	doc_634572338211_item	3556112	et	3	main
arvan	doc_634572338211_item	3556113	et	3	main
et	doc_634572338211_item	3556114	et	3	main
kedagi	doc_634572338211_item	3556115	et	4	main
ei	doc_634572338211_item	3556116	et	4	main
taha	doc_634572338211_item	3556117	et	4	main
võlgades	doc_634572338211_item	3556118	et	3	main
jääda	doc_634572338211_item	3556119	et	4	main
ma	doc_634572338211_item	3556120	et	3	main
loodan	doc_634572338211_item	3556121	et	3	main
et	doc_634572338211_item	3556122	et	3	main
te	doc_634572338211_item	3556123	et	4	main
nõustute	doc_634572338211_item	3556124	et	3	main
minu	doc_634572338211_item	3556125	et	3	main
arvamusega	doc_634572338211_item	3556126	et	3	main
toimetaja	doc_634572338207_item	3556337	et	4	main
arikkel	doc_634572338207_item	3556342	et	2	main
vt	doc_634572338207_item	3556343	et	4	main
tänada	doc_634572338207_item	3556349	et	3	main
teid	doc_634572338207_item	3556350	et	4	main
huvitav	doc_634572338207_item	3556357	et	4	main
ja	doc_634572338207_item	3556358	et	3	main
kohta	doc_634572338207_item	3556365	et	4	main
olen	doc_634572338207_item	3556367	et	3	main
osa	doc_634572338207_item	3556371	et	4	main
inimesi	doc_634572338207_item	3556372	et	4	main
soovib	doc_634572338207_item	3556373	et	3	main
leida	doc_634572338207_item	3556374	et	3	main
rahulikkut	doc_634572338207_item	3556375	et	4	main
tööd	doc_634572338207_item	3556376	et	4	main
polka	doc_634572338207_item	3556382	et	4	main
vaja	doc_634572338207_item	3556385	et	4	main
suurt	doc_634572338207_item	3556387	et	3	main
mõelda	doc_634572338207_item	3556389	et	4	main
oma	doc_634572338207_item	3556403	et	4	main
hoolitsev	doc_634572338207_item	3556411	et	4	main
nagu	doc_634572338207_item	3556412	et	3	main
noored	doc_634572338207_item	3556416	et	3	main
õiget	doc_634572338207_item	3556448	et	3	main
päeval	doc_634572338207_item	3556451	et	3	main
ameti	doc_634572338207_item	3556452	et	3	main
sõltub	doc_634572338207_item	3556454	et	3	main
et	doc_634572338207_item	3556456	et	3	main
muuta	doc_634572338207_item	3556496	et	4	main
riigi	doc_634572338207_item	3556500	et	3	main
et	doc_634572338207_item	3556507	et	3	main
kui	doc_634572338207_item	3556508	et	3	main
muutu	doc_634572338207_item	3556525	et	4	main
õpetaja	doc_432051777921_item	3556533	et	4	main
oma	doc_432051777921_item	3556546	et	4	main
pere	doc_432051777921_item	3556547	et	4	main
sõbrad	doc_432051777921_item	3556548	et	3	main
ja	doc_432051777921_item	3556549	et	3	main
õppinud	doc_432051777921_item	3556560	et	4	main
inglise	doc_432051777921_item	3556566	et	4	main
eesti	doc_432051777921_item	3556577	et	4	main
on	doc_432051777921_item	3556585	et	4	main
eesti	doc_432051777921_item	3556586	et	4	main
eesti	doc_432051777921_item	3556596	et	4	main
vaja	doc_432051777921_item	3556600	et	4	main
keel	doc_432051777921_item	3556602	et	4	main
et	doc_432051777921_item	3556603	et	3	main
tahan	doc_432051777921_item	3556612	et	3	main
rääkida	doc_432051777921_item	3556613	et	3	main
naabriga	doc_432051777921_item	3556614	et	3	main
kes	doc_432051777921_item	3556615	et	4	main
teavad	doc_432051777921_item	3556616	et	3	main
paremini	doc_432051777921_item	3556619	et	4	main
artiklid	doc_432051777921_item	3556624	et	3	main
keeles	doc_432051777921_item	3556628	et	4	main
ma	doc_432051777921_item	3556629	et	3	main
loodan	doc_432051777921_item	3556630	et	3	main
raske	doc_432051777921_item	3556644	et	4	main
ma	doc_432051777921_item	3556645	et	3	main
tahaksin	doc_432051777921_item	3556646	et	3	main
teada	doc_432051777921_item	3556647	et	3	main
kui	doc_432051777921_item	3556648	et	3	main
kaua	doc_432051777921_item	3556649	et	3	main
need	doc_432051777921_item	3556650	et	3	main
kursused	doc_432051777921_item	3556651	et	3	main
kastavad	doc_432051777921_item	3556652	et	4	main
ja	doc_432051777921_item	3556653	et	3	main
teine	doc_432051777921_item	3556654	et	3	main
mind	doc_432051777921_item	3556668	et	4	main
millal	doc_317833399028_item	3556698	et	3	main
jaoks	doc_317833399028_item	3556703	et	4	main
seminaritööd	doc_317833399027_item	3556712	et	4	main
verbisüsteemis	doc_317833399027_item	3556718	et	2	main
mulle	doc_317833399027_item	3556724	et	4	main
valima	doc_317833399027_item	3556736	et	3	main
järgi	doc_317833399027_item	3556742	et	4	main
ma	doc_317833399027_item	3556743	et	3	main
neid	doc_317833399027_item	3556744	et	4	main
valin	doc_317833399027_item	3556745	et	3	main
sellepärast	doc_317833399027_item	3556746	et	3	main
sõnastiku	doc_317833399027_item	3556748	et	3	main
palju	doc_634572338207_item	3556490	et	4	main
ja	doc_634572338207_item	3556498	et	3	main
ekspressi	doc_634572338207_item	3556336	et	4	main
artikli	doc_634572338207_item	3556340	et	3	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338207_item	3556344	et	4	main
lugupeetud	doc_634572338207_item	3556345	et	4	main
palju	doc_634572338207_item	3556360	et	4	main
uut	doc_634572338207_item	3556361	et	3	main
et	doc_634572338207_item	3556370	et	3	main
kuu	doc_634572338207_item	3556380	et	4	main
poleks	doc_634572338207_item	3556384	et	3	main
sõnaga	doc_634572338207_item	3556393	et	3	main
elada	doc_634572338207_item	3556394	et	3	main
elu	doc_634572338207_item	3556396	et	4	main
praeguses	doc_634572338207_item	3556397	et	3	main
elus	doc_634572338207_item	3556398	et	4	main
eest	doc_634572338207_item	3556405	et	4	main
vanemate	doc_634572338207_item	3556414	et	4	main
tahavad	doc_634572338207_item	3556417	et	3	main
et	doc_634572338207_item	3556418	et	3	main
pärast	doc_634572338207_item	3556419	et	4	main
lõpetamist	doc_634572338207_item	3556421	et	4	main
nad	doc_634572338207_item	3556422	et	3	main
ülikooli	doc_634572338207_item	3556420	et	4	main
saaks	doc_634572338207_item	3556423	et	3	main
leida	doc_634572338207_item	3556424	et	3	main
tööd	doc_634572338207_item	3556425	et	4	main
oma	doc_634572338207_item	3556426	et	4	main
alas	doc_634572338207_item	3556427	et	3	main
ma	doc_634572338207_item	3556428	et	3	main
olen	doc_634572338207_item	3556429	et	3	main
sellega	doc_634572338207_item	3556430	et	3	main
täitsa	doc_634572338207_item	3556431	et	3	main
nõus	doc_634572338207_item	3556432	et	4	main
me	doc_634572338207_item	3556434	et	4	main
vanemate	doc_634572338207_item	3556435	et	4	main
ajal	doc_634572338207_item	3556436	et	4	main
oli	doc_634572338207_item	3556437	et	3	main
on	doc_634572338207_item	3556446	et	4	main
ühiskonnast	doc_634572338207_item	3556493	et	4	main
haridussüsteemi	doc_634572338207_item	3556497	et	4	main
mu	doc_634572338207_item	3556501	et	3	main
selline	doc_634572338207_item	3556506	et	4	main
ei	doc_634572338207_item	3556510	et	4	main
neid	doc_634572338207_item	3556518	et	4	main
lähevad	doc_634572338207_item	3556520	et	3	main
äitah	doc_634572338207_item	3556529	et	4	main
kiri	doc_432051777921_item	3556531	et	3	main
sündinud	doc_432051777921_item	3556539	et	4	main
eestis	doc_432051777921_item	3556540	et	3	main
kõige	doc_432051777921_item	3556541	et	4	main
eesti	doc_432051777921_item	3556557	et	4	main
põhjus	doc_432051777921_item	3556569	et	4	main
miks	doc_432051777921_item	3556570	et	4	main
tulin	doc_432051777921_item	3556571	et	3	main
kursusele	doc_432051777921_item	3556573	et	3	main
on	doc_432051777921_item	3556574	et	4	main
keel	doc_432051777921_item	3556578	et	4	main
teine	doc_432051777921_item	3556579	et	3	main
mõned	doc_432051777921_item	3556594	et	3	main
suhtleda	doc_432051777921_item	3556604	et	4	main
eestlastega	doc_432051777921_item	3556605	et	4	main
ja	doc_432051777921_item	3556606	et	3	main
õppida	doc_432051777921_item	3556607	et	3	main
ma	doc_432051777921_item	3556620	et	3	main
küsimus	doc_432051777921_item	3556655	et	4	main
pean	doc_432051777921_item	3556660	et	4	main
saada	doc_432051777921_item	3556661	et	4	main
riigi	doc_432051777921_item	3556662	et	3	main
lihtsam	doc_634572338207_item	3556438	et	4	main
ametit	doc_634572338207_item	3556449	et	3	main
tänavasel	doc_634572338207_item	3556450	et	4	main
milline	doc_634572338207_item	3556457	et	3	main
toob	doc_634572338207_item	3556459	et	3	main
tulevikus	doc_634572338207_item	3556460	et	4	main
sulle	doc_634572338207_item	3556461	et	3	main
raha	doc_634572338207_item	3556462	et	4	main
ma	doc_634572338207_item	3556463	et	3	main
arvan	doc_634572338207_item	3556464	et	3	main
et	doc_634572338207_item	3556465	et	3	main
põhjus	doc_634572338207_item	3556466	et	4	main
miks	doc_634572338207_item	3556467	et	4	main
noored	doc_634572338207_item	3556468	et	3	main
lähevad	doc_634572338207_item	3556469	et	3	main
suvalistele	doc_634572338207_item	3556470	et	4	main
töökogtadele	doc_634572338207_item	3556471	et	4	main
on	doc_634572338207_item	3556472	et	4	main
see	doc_634572338207_item	3556473	et	3	main
et	doc_634572338207_item	3556474	et	3	main
nad	doc_634572338207_item	3556475	et	3	main
lihtsalt	doc_634572338207_item	3556476	et	4	main
vajavad	doc_634572338207_item	3556477	et	4	main
eluks	doc_634572338207_item	3556478	et	3	main
raha	doc_634572338207_item	3556479	et	4	main
rahasuhtes	doc_634572338207_item	3556480	et	3	main
ma	doc_634572338207_item	3556481	et	3	main
arvan	doc_634572338207_item	3556482	et	3	main
palju	doc_634572338207_item	3556483	et	4	main
raha	doc_634572338207_item	3556484	et	4	main
on	doc_634572338207_item	3556485	et	4	main
elus	doc_634572338207_item	3556486	et	4	main
vaja	doc_634572338207_item	3556487	et	4	main
kahjuks	doc_634572338207_item	3556488	et	4	main
mitte	doc_634572338207_item	3556489	et	3	main
abituriendi	doc_634572338207_item	3556491	et	3	main
mõtlevad	doc_634572338207_item	3556492	et	4	main
üldse	doc_634572338207_item	3556499	et	3	main
arvamus	doc_634572338207_item	3556503	et	3	main
on	doc_634572338207_item	3556505	et	4	main
riik	doc_634572338207_item	3556509	et	3	main
hakka	doc_634572338207_item	3556511	et	4	main
enam	doc_634572338207_item	3556512	et	4	main
aitama	doc_634572338207_item	3556513	et	3	main
noori	doc_634572338207_item	3556514	et	3	main
isegi	doc_634572338207_item	3556526	et	4	main
aastakäikude	doc_634572338207_item	3556527	et	3	main
tööd	doc_634572338207_item	3556440	et	4	main
veel	doc_634572338207_item	3556441	et	4	main
üks	doc_634572338207_item	3556442	et	3	main
suur	doc_634572338207_item	3556443	et	3	main
vastus	doc_634572338207_item	3556444	et	3	main
abituriendil	doc_634572338207_item	3556445	et	3	main
inimesi	doc_634572338207_item	3556515	et	4	main
ja	doc_634572338207_item	3556516	et	3	main
kes	doc_634572338207_item	3556519	et	4	main
peal	doc_634572338207_item	3556528	et	4	main
elus	doc_432051777921_item	3556544	et	4	main
spordi	doc_432051777921_item	3556555	et	4	main
tegelema	doc_432051777921_item	3556556	et	3	main
8	doc_432051777921_item	3556561	et	2	main
varem	doc_432051777921_item	3556563	et	4	main
õppinud	doc_432051777921_item	3556565	et	4	main
keel	doc_432051777921_item	3556567	et	4	main
esimene	doc_432051777921_item	3556568	et	3	main
parem	doc_432051777921_item	3556575	et	4	main
teada	doc_432051777921_item	3556576	et	3	main
põhjus	doc_432051777921_item	3556580	et	4	main
on	doc_432051777921_item	3556581	et	4	main
keelt	doc_432051777921_item	3556587	et	4	main
mul	doc_432051777921_item	3556598	et	3	main
eesti	doc_432051777921_item	3556617	et	4	main
kirjutada	doc_432051777921_item	3556622	et	3	main
ja	doc_432051777921_item	3556625	et	3	main
eesti	doc_432051777921_item	3556627	et	4	main
et	doc_432051777921_item	3556631	et	3	main
tegeleme	doc_432051777921_item	3556633	et	3	main
põhjalikult	doc_432051777921_item	3556634	et	4	main
me	doc_432051777921_item	3556632	et	4	main
eesti	doc_432051777921_item	3556635	et	4	main
keelega	doc_432051777921_item	3556636	et	3	main
ma	doc_432051777921_item	3556637	et	3	main
kardan	doc_432051777921_item	3556638	et	4	main
et	doc_432051777921_item	3556639	et	3	main
õppida	doc_432051777921_item	3556640	et	3	main
eesti	doc_432051777921_item	3556641	et	4	main
keel	doc_432051777921_item	3556642	et	4	main
minu	doc_432051777921_item	3556534	et	3	main
nimi	doc_432051777921_item	3556535	et	3	main
on	doc_432051777921_item	3556536	et	4	main
olen	doc_432051777921_item	3556538	et	3	main
eesnimi	doc_432051777921_item	3556537	et	3	main
tähtsam	doc_432051777921_item	3556542	et	4	main
minu	doc_432051777921_item	3556543	et	3	main
õppimine	doc_432051777921_item	3556550	et	4	main
ma	doc_432051777921_item	3556551	et	3	main
armastan	doc_432051777921_item	3556552	et	3	main
jalutama	doc_432051777921_item	3556553	et	3	main
ja	doc_432051777921_item	3556554	et	3	main
keelt	doc_432051777921_item	3556558	et	4	main
olen	doc_432051777921_item	3556564	et	3	main
suhtleda	doc_432051777921_item	3556582	et	4	main
vaja	doc_432051777921_item	3556588	et	4	main
et	doc_432051777921_item	3556589	et	3	main
lugeda	doc_432051777921_item	3556590	et	3	main
doklaadid	doc_432051777921_item	3556591	et	3	main
referaadid	doc_432051777921_item	3556592	et	3	main
ja	doc_432051777921_item	3556593	et	3	main
keeles	doc_432051777921_item	3556597	et	4	main
on	doc_432051777921_item	3556599	et	4	main
eesti	doc_432051777921_item	3556601	et	4	main
tallinnas	doc_432051777921_item	3556608	et	4	main
või	doc_432051777921_item	3556609	et	4	main
tartus	doc_432051777921_item	3556610	et	3	main
ma	doc_432051777921_item	3556611	et	3	main
tahan	doc_432051777921_item	3556621	et	3	main
on	doc_432051777921_item	3556643	et	4	main
palju	doc_432051777921_item	3556657	et	4	main
eksamil	doc_432051777921_item	3556663	et	3	main
saite	doc_432051777921_item	3556666	et	4	main
aru	doc_432051777921_item	3556667	et	4	main
oleks	doc_317833399028_item	3556700	et	3	main
aega	doc_317833399028_item	3556701	et	4	main
austusega	doc_317833399028_item	3556704	et	4	main
õppejõud	doc_317833399027_item	3556708	et	4	main
kirjutan	doc_317833399027_item	3556709	et	3	main
teie	doc_317833399027_item	3556710	et	4	main
aspektivastanduse	doc_317833399027_item	3556714	et	2	main
te	doc_317833399027_item	3556723	et	4	main
välja	doc_317833399027_item	3556737	et	4	main
verbid	doc_317833399027_item	3556752	et	3	main
märgitud	doc_317833399027_item	3556755	et	4	main
teie	doc_317833399027_item	3556756	et	4	main
ilma	doc_317833399027_item	3556763	et	4	main
mitu	doc_317833399027_item	3556769	et	4	main
korda	doc_317833399027_item	3556770	et	4	main
saa	doc_317833399027_item	3556774	et	4	main
mitte	doc_317833399027_item	3556775	et	3	main
avaldus	doc_40918597557_item	3556787	et	4	main
6	doc_40918597557_item	3556792	et	2	main
eesnimi	doc_40918597557_item	3556795	et	3	main
18997	doc_40918597557_item	3556799	et	2	main
teie	doc_40918597557_item	3556814	et	4	main
vastavaid	doc_40918597557_item	3556825	et	4	main
mina	doc_40918597557_item	3556827	et	4	main
ma	doc_40918597557_item	3556830	et	3	main
olen	doc_40918597557_item	3556831	et	3	main
sobiv	doc_40918597557_item	3556832	et	4	main
pildistaja	doc_40918597557_item	3556834	et	4	main
kohale	doc_40918597557_item	3556835	et	4	main
ma	doc_40918597557_item	3556843	et	3	main
ja	doc_40918597557_item	3556848	et	3	main
minu	doc_40918597557_item	3556854	et	3	main
keelt	doc_40918597557_item	3556877	et	4	main
aastat	doc_40918597557_item	3556880	et	3	main
pildistaja	doc_40918597557_item	3556883	et	4	main
kursustel	doc_40918597557_item	3556884	et	3	main
ja	doc_40918597557_item	3556885	et	3	main
pärast	doc_40918597557_item	3556886	et	4	main
kirjad	doc_432051777921_item	3556623	et	4	main
referaadid	doc_432051777921_item	3556626	et	3	main
on	doc_432051777921_item	3556656	et	4	main
loodan	doc_432051777921_item	3556664	et	3	main
eesnimi	doc_432051777921_item	3556671	et	3	main
perekonnanimi	doc_432051777921_item	3556672	et	3	main
kokku	doc_317833399028_item	3556693	et	3	main
saada	doc_317833399028_item	3556694	et	4	main
ja	doc_317833399028_item	3556695	et	3	main
rääkida	doc_317833399028_item	3556696	et	3	main
läbi	doc_317833399028_item	3556697	et	4	main
austatud	doc_317833399027_item	3556707	et	4	main
juhendamisel	doc_317833399027_item	3556711	et	4	main
imperfektiivne	doc_317833399027_item	3556726	et	3	main
ning	doc_317833399027_item	3556728	et	3	main
tekkis	doc_317833399027_item	3556730	et	3	main
arusaamatusi	doc_317833399027_item	3556732	et	4	main
kas	doc_317833399027_item	3556733	et	3	main
tärniga	doc_317833399027_item	3556738	et	2	main
või	doc_317833399027_item	3556740	et	4	main
et	doc_317833399027_item	3556747	et	3	main
alguses	doc_317833399027_item	3556749	et	4	main
kus	doc_317833399027_item	3556750	et	3	main
mõningad	doc_317833399027_item	3556751	et	3	main
ära	doc_317833399027_item	3556754	et	4	main
tärniga	doc_317833399027_item	3556761	et	2	main
mõned	doc_317833399027_item	3556762	et	3	main
ma	doc_317833399027_item	3556764	et	3	main
kuidagi	doc_317833399027_item	3556776	et	3	main
ajakirjanduslevi	doc_40918597557_item	3556789	et	4	main
10626	doc_40918597557_item	3556793	et	2	main
6	doc_40918597557_item	3556798	et	2	main
kuulutuse	doc_40918597557_item	3556812	et	4	main
et	doc_40918597557_item	3556813	et	3	main
ajakirjanduslevi	doc_40918597557_item	3556817	et	4	main
lugesin	doc_40918597557_item	3556820	et	3	main
nõudmisi	doc_40918597557_item	3556826	et	4	main
arvan	doc_40918597557_item	3556828	et	3	main
sest	doc_40918597557_item	3556836	et	4	main
et	doc_40918597557_item	3556837	et	3	main
mul	doc_40918597557_item	3556838	et	3	main
valdan	doc_40918597557_item	3556844	et	3	main
kursustel	doc_40918597557_item	3556878	et	3	main
käisin	doc_40918597557_item	3556881	et	3	main
19788	doc_40918597556_item	3556942	et	2	main
postimees	doc_40918597556_item	3556951	et	4	main
teie	doc_40918597556_item	3556952	et	4	main
kuulutust	doc_40918597556_item	3556953	et	4	main
ja	doc_40918597556_item	3556954	et	3	main
tahan	doc_40918597556_item	3556955	et	3	main
kandideerida	doc_40918597556_item	3556956	et	3	main
pildistaja	doc_40918597556_item	3556957	et	4	main
fotofirmas	doc_40918597556_item	3556961	et	3	main
aastat	doc_40918597556_item	3556963	et	3	main
selle	doc_40918597556_item	3556970	et	4	main
valdan	doc_40918597556_item	3556971	et	3	main
heal	doc_40918597556_item	3556972	et	3	main
eesti	doc_40918597556_item	3556974	et	4	main
vene	doc_40918597556_item	3556975	et	4	main
ja	doc_40918597556_item	3556976	et	3	main
inglise	doc_40918597556_item	3556977	et	4	main
keele	doc_40918597556_item	3556985	et	4	main
lisakursustel	doc_40918597556_item	3556986	et	3	main
ja	doc_40918597556_item	3556987	et	3	main
elasin	doc_40918597556_item	3556988	et	3	main
aastal	doc_634572338237_item	3557046	et	3	main
perekonnanimi	doc_634572338237_item	3557051	et	3	main
naisel	doc_634572338237_item	3557069	et	3	main
ja	doc_634572338237_item	3557089	et	3	main
ta	doc_634572338237_item	3557097	et	4	main
kaupluse	doc_542009824800_item	3557105	et	3	main
juurest	doc_542009824800_item	3557107	et	4	main
käpaotsad	doc_542009824800_item	3557117	et	3	main
punktid	doc_432051777921_item	3556658	et	4	main
ma	doc_432051777921_item	3556659	et	3	main
lugupidamisega	doc_432051777921_item	3556670	et	3	main
kiri	doc_317833399027_item	3556706	et	3	main
teemal	doc_317833399027_item	3556713	et	3	main
keele	doc_317833399027_item	3556717	et	4	main
vaatasin	doc_317833399027_item	3556719	et	3	main
verbisõnastikku	doc_317833399027_item	3556721	et	2	main
mida	doc_317833399027_item	3556722	et	4	main
aspekt	doc_317833399027_item	3556727	et	3	main
mul	doc_317833399027_item	3556729	et	3	main
pean	doc_317833399027_item	3556735	et	4	main
mille	doc_317833399027_item	3556741	et	3	main
on	doc_317833399027_item	3556753	et	4	main
on	doc_317833399027_item	3556760	et	4	main
läbi	doc_317833399027_item	3556771	et	4	main
ja	doc_317833399027_item	3556772	et	3	main
mind	doc_317833399027_item	3556781	et	4	main
sellega	doc_317833399027_item	3556782	et	3	main
palun	doc_317833399027_item	3556783	et	3	main
as	doc_40918597557_item	3556788	et	4	main
tallinn	doc_40918597557_item	3556794	et	4	main
perekonnanimi	doc_40918597557_item	3556796	et	3	main
jahu	doc_40918597557_item	3556797	et	4	main
narva	doc_40918597557_item	3556800	et	4	main
tel	doc_40918597557_item	3556801	et	4	main
555	doc_40918597557_item	3556802	et	2	main
555	doc_40918597557_item	3556803	et	2	main
eesti	doc_40918597557_item	3556810	et	4	main
päevaleht	doc_40918597557_item	3556811	et	3	main
firma	doc_40918597557_item	3556815	et	4	main
kandidat	doc_40918597557_item	3556833	et	4	main
oskused	doc_40918597557_item	3556842	et	3	main
keelt	doc_40918597557_item	3556846	et	4	main
kirjas	doc_40918597557_item	3556849	et	4	main
sest	doc_40918597557_item	3556850	et	4	main
et	doc_40918597557_item	3556851	et	3	main
pool	doc_40918597557_item	3556888	et	4	main
töötasin	doc_40918597557_item	3556890	et	3	main
narva	doc_40918597557_item	3556891	et	4	main
as	doc_40918597556_item	3556930	et	4	main
personaliosakond	doc_40918597556_item	3556932	et	3	main
kadastiku	doc_40918597556_item	3556933	et	3	main
10626	doc_40918597556_item	3556935	et	2	main
tallinn	doc_40918597556_item	3556936	et	4	main
konkurss	doc_40918597556_item	3556937	et	3	main
eesnimi	doc_40918597556_item	3556938	et	3	main
narva	doc_40918597556_item	3556943	et	4	main
peale	doc_40918597556_item	3556969	et	4	main
inglise	doc_40918597556_item	3556984	et	4	main
ma	doc_634572338237_item	3557050	et	3	main
eesnimi	doc_634572338237_item	3557052	et	3	main
varguse	doc_634572338237_item	3557056	et	3	main
õlapeal	doc_634572338237_item	3557071	et	3	main
lõi	doc_634572338237_item	3557084	et	4	main
ründajat	doc_634572338237_item	3557085	et	4	main
jalaga	doc_634572338237_item	3557086	et	3	main
laskis	doc_634572338237_item	3557090	et	4	main
lahti	doc_634572338237_item	3557092	et	4	main
mõne	doc_634572338237_item	3557093	et	3	main
aja	doc_634572338237_item	3557094	et	4	main
kuulutus	doc_542009824800_item	3557102	et	4	main
süsimusta	doc_542009824800_item	3557110	et	4	main
värvi	doc_542009824800_item	3557111	et	4	main
labrador	doc_542009824800_item	3557113	et	3	main
on	doc_542009824800_item	3557115	et	4	main
kontaktnumer	doc_542009824800_item	3557128	et	4	main
55	doc_542009824800_item	3557129	et	2	main
77	doc_542009824800_item	3557131	et	2	main
tasu	doc_542009824800_item	3557143	et	4	main
1000	doc_542009824800_item	3557144	et	2	main
eek-i	doc_542009824800_item	3557145	et	4	main
läbi	doc_397823701988_item	3557151	et	4	main
tööd	doc_397823701988_item	3557176	et	4	main
soovite	doc_397823701988_item	3557177	et	3	main
töötasu	doc_397823701988_item	3557180	et	4	main
milline	doc_397823701988_item	3557182	et	3	main
sobib	doc_397823701988_item	3557184	et	3	main
kuu	doc_397823701988_item	3557186	et	4	main
pakkijaid	doc_397823701988_item	3557197	et	4	main
head	doc_397823701988_item	3557205	et	4	main
on	doc_397823701988_item	3557208	et	4	main
as	doc_397823701988_item	3557220	et	4	main
et	doc_432051777921_item	3556665	et	3	main
aru	doc_432051777921_item	3556669	et	4	main
teil	doc_317833399028_item	3556699	et	4	main
minu	doc_317833399028_item	3556702	et	3	main
kiri	doc_317833399028_item	3556674	et	3	main
õppejõud	doc_317833399028_item	3556676	et	4	main
austatud	doc_317833399028_item	3556675	et	4	main
üritasin	doc_317833399028_item	3556677	et	3	main
valida	doc_317833399028_item	3556678	et	3	main
verbide	doc_317833399028_item	3556679	et	3	main
hulgast	doc_317833399028_item	3556680	et	4	main
õigeid	doc_317833399028_item	3556681	et	3	main
kuid	doc_317833399028_item	3556682	et	4	main
tea	doc_317833399028_item	3556684	et	4	main
kas	doc_317833399028_item	3556685	et	3	main
valisin	doc_317833399028_item	3556686	et	3	main
ikka	doc_317833399028_item	3556687	et	4	main
ei	doc_317833399028_item	3556683	et	4	main
neid	doc_317833399028_item	3556688	et	4	main
mida	doc_317833399028_item	3556689	et	4	main
peab	doc_317833399028_item	3556690	et	4	main
tahaksin	doc_317833399028_item	3556691	et	3	main
teiega	doc_317833399028_item	3556692	et	3	main
ette	doc_317833399027_item	3556785	et	4	main
kujunemisest	doc_317833399027_item	3556715	et	2	main
eesti	doc_317833399027_item	3556716	et	4	main
läbi	doc_317833399027_item	3556720	et	4	main
andsite	doc_317833399027_item	3556725	et	3	main
palju	doc_317833399027_item	3556731	et	4	main
ma	doc_317833399027_item	3556734	et	3	main
verbid	doc_317833399027_item	3556739	et	3	main
poolt	doc_317833399027_item	3556757	et	4	main
mõned	doc_317833399027_item	3556758	et	3	main
olen	doc_317833399027_item	3556765	et	3	main
vaatasin	doc_317833399027_item	3556767	et	3	main
ei	doc_317833399027_item	3556773	et	4	main
tänan	doc_317833399027_item	3556784	et	3	main
neist	doc_317833399027_item	3556759	et	4	main
hädas	doc_317833399027_item	3556766	et	3	main
sõnastikku	doc_317833399027_item	3556768	et	4	main
aru	doc_317833399027_item	3556777	et	4	main
kas	doc_317833399027_item	3556778	et	3	main
te	doc_317833399027_item	3556779	et	4	main
aitaksite	doc_317833399027_item	3556780	et	2	main
personaliosakond	doc_40918597557_item	3556790	et	3	main
avaldus	doc_40918597557_item	3556804	et	4	main
tööd	doc_40918597557_item	3556819	et	4	main
et	doc_40918597557_item	3556821	et	3	main
peavad	doc_40918597557_item	3556823	et	4	main
et	doc_40918597557_item	3556829	et	3	main
on	doc_40918597557_item	3556839	et	4	main
see	doc_40918597557_item	3556852	et	3	main
emakeel	doc_40918597557_item	3556855	et	4	main
käisin	doc_40918597557_item	3556874	et	3	main
aasta	doc_40918597557_item	3556889	et	4	main
11	doc_40918597557_item	3556868	et	2	main
aastat	doc_40918597557_item	3556869	et	3	main
õppisin	doc_40918597557_item	3556870	et	3	main
neid	doc_40918597557_item	3556871	et	4	main
koolis	doc_40918597557_item	3556872	et	4	main
ja	doc_40918597557_item	3556873	et	3	main
kadastiku	doc_40918597557_item	3556791	et	3	main
lugupeetud	doc_40918597557_item	3556805	et	4	main
personaliosakonna	doc_40918597557_item	3556806	et	4	main
juht	doc_40918597557_item	3556807	et	3	main
lugesin	doc_40918597557_item	3556808	et	3	main
ajalehest	doc_40918597557_item	3556809	et	4	main
as	doc_40918597557_item	3556816	et	4	main
pakub	doc_40918597557_item	3556818	et	3	main
kandidadile	doc_40918597557_item	3556822	et	4	main
esitata	doc_40918597557_item	3556824	et	3	main
kõik	doc_40918597557_item	3556840	et	4	main
vajalikud	doc_40918597557_item	3556841	et	3	main
vene	doc_40918597557_item	3556845	et	4	main
kõnes	doc_40918597557_item	3556847	et	3	main
on	doc_40918597557_item	3556853	et	4	main
valdan	doc_40918597557_item	3556856	et	3	main
ka	doc_40918597557_item	3556857	et	3	main
eesti	doc_40918597557_item	3556858	et	4	main
soome	doc_40918597557_item	3556859	et	3	main
ja	doc_40918597557_item	3556860	et	3	main
inglise	doc_40918597557_item	3556861	et	4	main
keelt	doc_40918597557_item	3556862	et	4	main
kõnes	doc_40918597557_item	3556863	et	3	main
ja	doc_40918597557_item	3556864	et	3	main
kirjas	doc_40918597557_item	3556865	et	4	main
sest	doc_40918597557_item	3556866	et	4	main
et	doc_40918597557_item	3556867	et	3	main
ka	doc_40918597557_item	3556875	et	3	main
soome	doc_40918597557_item	3556876	et	3	main
paar	doc_40918597557_item	3556879	et	3	main
ka	doc_40918597557_item	3556882	et	3	main
seda	doc_40918597557_item	3556887	et	3	main
ajalehes	doc_40918597557_item	3556892	et	3	main
pildistajana	doc_40918597557_item	3556893	et	4	main
avaldus	doc_40918597556_item	3556929	et	4	main
ajakirjanduslevi	doc_40918597556_item	3556931	et	4	main
6	doc_40918597556_item	3556934	et	2	main
8	doc_40918597556_item	3556941	et	2	main
avaldus	doc_40918597556_item	3556944	et	4	main
personaliosakonna	doc_40918597556_item	3556946	et	4	main
juht	doc_40918597556_item	3556947	et	3	main
eile	doc_40918597556_item	3556948	et	3	main
lugesin	doc_40918597556_item	3556949	et	3	main
töötasin	doc_40918597556_item	3556960	et	3	main
ja	doc_40918597556_item	3556964	et	3	main
aasta	doc_40918597556_item	3556966	et	4	main
käisin	doc_40918597556_item	3556967	et	3	main
täiendkoolitusel	doc_40918597556_item	3556968	et	4	main
käinud	doc_40918597556_item	3556981	et	4	main
eesti	doc_40918597556_item	3556982	et	4	main
ja	doc_40918597556_item	3556983	et	3	main
kell	doc_634572338237_item	3557047	et	3	main
olin	doc_634572338237_item	3557053	et	3	main
kotti	doc_634572338237_item	3557055	et	4	main
puhul	doc_634572338237_item	3557057	et	4	main
mees	doc_634572338237_item	3557058	et	4	main
keskmises	doc_634572338237_item	3557059	et	3	main
kes	doc_634572338237_item	3557066	et	4	main
seisis	doc_634572338237_item	3557067	et	4	main
rippus	doc_634572338237_item	3557070	et	3	main
haaras	doc_634572338237_item	3557074	et	4	main
ja	doc_634572338237_item	3557076	et	3	main
hakkas	doc_634572338237_item	3557077	et	3	main
endal	doc_634572338237_item	3557078	et	4	main
pärast	doc_634572338237_item	3557095	et	4	main
oli	doc_634572338237_item	3557096	et	3	main
veebruaril	doc_542009824800_item	3557104	et	3	main
kadus	doc_542009824800_item	3557108	et	3	main
valged	doc_542009824800_item	3557116	et	3	main
66	doc_542009824800_item	3557130	et	2	main
88	doc_542009824800_item	3557132	et	2	main
vaevatasu	doc_542009824800_item	3557133	et	4	main
kohale	doc_542009824800_item	3557140	et	4	main
sellel	doc_40918597557_item	3556894	et	4	main
tööl	doc_40918597557_item	3556895	et	3	main
mul	doc_40918597557_item	3556896	et	3	main
oli	doc_40918597557_item	3556897	et	3	main
ka	doc_40918597557_item	3556898	et	3	main
kogemus	doc_40918597557_item	3556899	et	3	main
suhtlemisoskuses	doc_40918597557_item	3556900	et	3	main
ja	doc_40918597557_item	3556901	et	3	main
meeskonnatöödes	doc_40918597557_item	3556902	et	3	main
mina	doc_40918597557_item	3556903	et	4	main
olen	doc_40918597557_item	3556904	et	3	main
ka	doc_40918597557_item	3556905	et	3	main
väga	doc_40918597557_item	3556906	et	3	main
töökas	doc_40918597557_item	3556907	et	4	main
ja	doc_40918597557_item	3556908	et	3	main
rõõmsameelne	doc_40918597557_item	3556909	et	3	main
inimene	doc_40918597557_item	3556910	et	3	main
loodan	doc_40918597557_item	3556911	et	3	main
et	doc_40918597557_item	3556912	et	3	main
mina	doc_40918597557_item	3556913	et	4	main
olen	doc_40918597557_item	3556914	et	3	main
sobiv	doc_40918597557_item	3556915	et	4	main
kandidat	doc_40918597557_item	3556916	et	4	main
sest	doc_40918597557_item	3556917	et	4	main
olen	doc_40918597557_item	3556918	et	3	main
väga	doc_40918597557_item	3556919	et	3	main
töökas	doc_40918597557_item	3556920	et	4	main
ja	doc_40918597557_item	3556921	et	3	main
rõõmsameelne	doc_40918597557_item	3556922	et	3	main
inimene	doc_40918597557_item	3556923	et	3	main
lugupidamisega	doc_40918597557_item	3556924	et	3	main
eesnimi	doc_40918597557_item	3556925	et	3	main
perekonnanimi	doc_40918597557_item	3556926	et	3	main
12052008	doc_40918597557_item	3556927	et	2	main
perekonnanimi	doc_40918597556_item	3556939	et	3	main
lugupeetud	doc_40918597556_item	3556945	et	4	main
ajalehest	doc_40918597556_item	3556950	et	4	main
töökohale	doc_40918597556_item	3556958	et	4	main
2	doc_40918597556_item	3556962	et	2	main
iga	doc_40918597556_item	3556965	et	4	main
keelt	doc_40918597556_item	3556978	et	4	main
inglismaal	doc_40918597556_item	3556989	et	4	main
kuna	doc_40918597556_item	3556990	et	3	main
palju	doc_40918597556_item	3556994	et	4	main
päival	doc_634572338237_item	3557049	et	4	main
vanuses	doc_634572338237_item	3557060	et	4	main
tugeva	doc_634572338237_item	3557061	et	4	main
bussipeatuses	doc_634572338237_item	3557068	et	4	main
poole	doc_634572338237_item	3557079	et	4	main
embama	doc_634572338237_item	3557080	et	3	main
naine	doc_634572338237_item	3557081	et	3	main
hakkas	doc_634572338237_item	3557082	et	3	main
vastu	doc_634572338237_item	3557083	et	3	main
karjatas	doc_634572338237_item	3557088	et	3	main
kotti	doc_634572338237_item	3557091	et	4	main
arateeritud	doc_634572338237_item	3557098	et	4	main
kahekümneviiendal	doc_542009824800_item	3557103	et	4	main
t-market	doc_542009824800_item	3557106	et	4	main
eritingimused	doc_542009824800_item	3557114	et	3	main
jätkata	doc_40918597556_item	3557013	et	4	main
tööd	doc_40918597556_item	3557014	et	4	main
rühma	doc_40918597556_item	3557015	et	4	main
mina	doc_40918597556_item	3557016	et	4	main
arvan	doc_40918597556_item	3557017	et	3	main
et	doc_40918597556_item	3557018	et	3	main
olen	doc_40918597556_item	3557019	et	3	main
sobiv	doc_40918597556_item	3557020	et	4	main
kandidaat	doc_40918597556_item	3557021	et	3	main
sest	doc_40918597556_item	3557022	et	4	main
olen	doc_40918597556_item	3557023	et	3	main
aus	doc_40918597556_item	3557024	et	4	main
töökas	doc_40918597556_item	3557025	et	4	main
ja	doc_40918597556_item	3557026	et	3	main
energiline	doc_40918597556_item	3557027	et	3	main
inimene	doc_40918597556_item	3557028	et	3	main
mina	doc_40918597556_item	3557029	et	4	main
loodan	doc_40918597556_item	3557030	et	3	main
et	doc_40918597556_item	3557031	et	3	main
teie	doc_40918597556_item	3557032	et	4	main
võtate	doc_40918597556_item	3557033	et	3	main
mind	doc_40918597556_item	3557034	et	4	main
tööle	doc_40918597556_item	3557035	et	3	main
lugupidamisega	doc_40918597556_item	3557036	et	3	main
eesnimi	doc_40918597556_item	3557037	et	3	main
perekonnanimi	doc_40918597556_item	3557038	et	3	main
jahu	doc_40918597556_item	3556940	et	4	main
mina	doc_40918597556_item	3556959	et	4	main
tasemel	doc_40918597556_item	3556973	et	3	main
ma	doc_40918597556_item	3556979	et	3	main
olen	doc_40918597556_item	3556980	et	3	main
meie	doc_40918597556_item	3556991	et	4	main
firmas	doc_40918597556_item	3556992	et	3	main
töötab	doc_40918597556_item	3556993	et	3	main
inimesi	doc_40918597556_item	3556995	et	4	main
siis	doc_40918597556_item	3556996	et	3	main
pean	doc_40918597556_item	3556997	et	4	main
kogu	doc_40918597556_item	3556998	et	4	main
aeg	doc_40918597556_item	3556999	et	3	main
suhtlema	doc_40918597556_item	3557000	et	3	main
ja	doc_40918597556_item	3557002	et	3	main
nendega	doc_40918597556_item	3557001	et	4	main
oma	doc_40918597556_item	3557004	et	4	main
arendama	doc_40918597556_item	3557003	et	3	main
suhtlemisoskust	doc_40918597556_item	3557005	et	3	main
mina	doc_40918597556_item	3557006	et	4	main
olen	doc_40918597556_item	3557007	et	3	main
harjunud	doc_40918597556_item	3557008	et	4	main
meeskonnatööga	doc_40918597556_item	3557009	et	3	main
ja	doc_40918597556_item	3557010	et	3	main
sellepärast	doc_40918597556_item	3557011	et	3	main
tahan	doc_40918597556_item	3557012	et	3	main
seletuskiri	doc_634572338237_item	3557041	et	3	main
14	doc_634572338237_item	3557043	et	2	main
seletuskiri	doc_634572338237_item	3557042	et	3	main
mail	doc_634572338237_item	3557044	et	4	main
2006	doc_634572338237_item	3557045	et	2	main
kaksteist	doc_634572338237_item	3557048	et	4	main
tunnistajaks	doc_634572338237_item	3557054	et	4	main
kehaehitusega	doc_634572338237_item	3557062	et	3	main
lähemes	doc_634572338237_item	3557063	et	4	main
tagant	doc_634572338237_item	3557064	et	3	main
naisele	doc_634572338237_item	3557065	et	3	main
kott	doc_634572338237_item	3557072	et	3	main
ta	doc_634572338237_item	3557073	et	4	main
kottist	doc_634572338237_item	3557075	et	4	main
kurjategija	doc_634572338237_item	3557087	et	4	main
kuulutus	doc_542009824800_item	3557101	et	4	main
koer	doc_542009824800_item	3557109	et	3	main
tõug	doc_542009824800_item	3557112	et	3	main
toimetamise	doc_542009824800_item	3557141	et	4	main
kuulutus	doc_397823701988_item	3557152	et	4	main
peab	doc_397823701988_item	3557157	et	4	main
sõna	doc_397823701988_item	3557161	et	4	main
keelteoskus	doc_397823701988_item	3557167	et	3	main
suurt	doc_397823701988_item	3557179	et	3	main
soovite	doc_397823701988_item	3557181	et	3	main
vajatakse	doc_397823701988_item	3557192	et	4	main
kandidaatidelt	doc_397823701988_item	3557198	et	3	main
eesti	doc_397823701988_item	3557200	et	4	main
arvutikasutamisoskus	doc_397823701988_item	3557210	et	3	main
sobivat	doc_397823701988_item	3557215	et	4	main
kindlat	doc_397823701988_item	3557217	et	3	main
palka	doc_397823701988_item	3557218	et	4	main
lisainfo	doc_397823701988_item	3557219	et	4	main
räkida	doc_397823701988_item	3557254	et	4	main
vene	doc_397823701988_item	3557257	et	4	main
keeles	doc_397823701988_item	3557258	et	4	main
tuba	doc_15203423349_item	3557334	et	4	main
metsalinn	doc_15203423349_item	3557336	et	3	main
järelepärimine	doc_15203423349_item	3557338	et	3	main
soovib	doc_15203423349_item	3557343	et	3	main
erialaste	doc_15203423349_item	3557345	et	4	main
konkurssil	doc_15203423349_item	3557347	et	4	main
trükis	doc_15203423349_item	3557349	et	4	main
millest	doc_15203423349_item	3557350	et	3	main
enne	doc_15203423349_item	3557359	et	4	main
lisainfot	doc_15203423349_item	3557364	et	3	main
vastuseid	doc_15203423349_item	3557373	et	3	main
me	doc_15203423349_item	3557374	et	4	main
must-valgeid	doc_15203423349_item	3557382	et	3	main
me	doc_15203423349_item	3557388	et	4	main
vüitjatele	doc_15203423349_item	3557404	et	4	main
on	doc_15203423349_item	3557405	et	4	main
ta	doc_542009824800_item	3557118	et	4	main
hea	doc_542009824800_item	3557123	et	4	main
koer	doc_542009824800_item	3557124	et	3	main
nimi	doc_542009824800_item	3557125	et	3	main
on	doc_542009824800_item	3557126	et	4	main
reks	doc_542009824800_item	3557127	et	3	main
igale	doc_542009824800_item	3557135	et	3	main
eest	doc_542009824800_item	3557142	et	4	main
on	doc_542009824800_item	3557119	et	4	main
väga	doc_542009824800_item	3557120	et	3	main
sõbralik	doc_542009824800_item	3557121	et	3	main
ja	doc_542009824800_item	3557122	et	3	main
on	doc_542009824800_item	3557134	et	4	main
teatele	doc_542009824800_item	3557136	et	3	main
meie	doc_542009824800_item	3557137	et	4	main
lemmiku	doc_542009824800_item	3557138	et	3	main
asukohast	doc_542009824800_item	3557139	et	4	main
kiri	doc_397823701988_item	3557149	et	3	main
vastake	doc_397823701988_item	3557154	et	3	main
umbes	doc_397823701988_item	3557159	et	4	main
perekonnaseis	doc_397823701988_item	3557164	et	4	main
töökogemused	doc_397823701988_item	3557166	et	3	main
autojuhiload	doc_397823701988_item	3557169	et	4	main
hobid	doc_397823701988_item	3557170	et	3	main
ja	doc_397823701988_item	3557171	et	3	main
kirjutage	doc_397823701988_item	3557172	et	3	main
oma	doc_397823701988_item	3557173	et	4	main
soovidest	doc_397823701988_item	3557174	et	3	main
millist	doc_397823701988_item	3557175	et	3	main
töögraafik	doc_397823701988_item	3557183	et	3	main
kahe	doc_397823701988_item	3557185	et	3	main
pärast	doc_397823701988_item	3557187	et	4	main
avatakse	doc_397823701988_item	3557188	et	4	main
uus	doc_397823701988_item	3557189	et	3	main
toidukauplus	doc_397823701988_item	3557190	et	3	main
koristajaid	doc_397823701988_item	3557196	et	4	main
ootame	doc_397823701988_item	3557199	et	3	main
ja	doc_397823701988_item	3557201	et	3	main
suhtlemisoskust	doc_397823701988_item	3557206	et	3	main
ka	doc_397823701988_item	3557209	et	3	main
teile	doc_397823701988_item	3557214	et	4	main
töögraafikut	doc_397823701988_item	3557216	et	3	main
20	doc_397823701988_item	3557250	et	2	main
mina	doc_397823701988_item	3557252	et	4	main
eesti	doc_397823701988_item	3557255	et	4	main
sobib	doc_397823701988_item	3557300	et	3	main
töötasu	doc_397823701988_item	3557303	et	4	main
töögraafik	doc_397823701988_item	3557304	et	3	main
järelpärimine	doc_15203423349_item	3557325	et	3	main
meie	doc_15203423349_item	3557339	et	4	main
osaleda	doc_15203423349_item	3557344	et	3	main
osalemist	doc_15203423349_item	3557360	et	4	main
ei	doc_15203423349_item	3557371	et	4	main
trükis	doc_15203423349_item	3557380	et	4	main
kuidas	doc_15203423349_item	3557387	et	3	main
võime	doc_15203423349_item	3557389	et	4	main
tuitvuda	doc_15203423349_item	3557390	et	4	main
austusega	doc_15203423349_item	3557425	et	4	main
nimi	doc_15203423349_item	3557426	et	3	main
perekonnanimi	doc_15203423349_item	3557427	et	3	main
õpilane	doc_15203423349_item	3557428	et	3	main
as	doc_15203423349_item	3557429	et	4	main
inimeste	doc_15203423349_item	3557430	et	3	main
käed	doc_15203423349_item	3557431	et	3	main
eesti	doc_973441205341_item	3557439	et	4	main
keele	doc_973441205341_item	3557440	et	4	main
klassi	doc_973441205341_item	3557447	et	4	main
toimunud	doc_973441205341_item	3557454	et	4	main
seminarist	doc_973441205341_item	3557455	et	4	main
soovin	doc_973441205341_item	3557459	et	3	main
teile	doc_973441205341_item	3557461	et	4	main
esimees	doc_973441205341_item	3557484	et	4	main
kuna	doc_973441205341_item	3557485	et	3	main
meie	doc_973441205341_item	3557499	et	4	main
esimese	doc_973441205341_item	3557500	et	3	main
oli	doc_973441205341_item	3557516	et	3	main
rühmades	doc_973441205341_item	3557527	et	3	main
mingi	doc_973441205341_item	3557528	et	4	main
võimaliku	doc_973441205341_item	3557529	et	3	main
lõppeski	doc_973441205341_item	3557534	et	4	main
meie	doc_973441205341_item	3557535	et	4	main
esimene	doc_973441205341_item	3557536	et	3	main
päev	doc_973441205341_item	3557537	et	3	main
k	doc_397823701988_item	3557305	et	4	main
7	doc_397823701988_item	3557306	et	2	main
st	doc_397823701988_item	3557307	et	3	main
kuni	doc_397823701988_item	3557308	et	3	main
k	doc_397823701988_item	3557309	et	4	main
20	doc_397823701988_item	3557310	et	2	main
ni	doc_397823701988_item	3557311	et	4	main
eesnimi	doc_397823701988_item	3557312	et	3	main
perekonnanimi	doc_397823701988_item	3557313	et	3	main
järve	doc_397823701988_item	3557314	et	4	main
mnt	doc_397823701988_item	3557315	et	4	main
40	doc_397823701988_item	3557316	et	2	main
23	doc_397823701988_item	3557318	et	2	main
k	doc_397823701988_item	3557317	et	4	main
tallinn	doc_397823701988_item	3557319	et	4	main
30320	doc_397823701988_item	3557320	et	2	main
e-mail	doc_397823701988_item	3557321	et	4	main
eesnimihotmailcom	doc_397823701988_item	3557322	et	2	main
lugege	doc_397823701988_item	3557150	et	3	main
sellele	doc_397823701988_item	3557155	et	4	main
kirjas	doc_397823701988_item	3557156	et	4	main
olema	doc_397823701988_item	3557158	et	4	main
tutvustage	doc_397823701988_item	3557162	et	3	main
kui	doc_397823701988_item	3557178	et	3	main
müüjat	doc_397823701988_item	3557193	et	4	main
kassapidajaid	doc_397823701988_item	3557194	et	3	main
turvamehi	doc_397823701988_item	3557195	et	3	main
vene	doc_397823701988_item	3557202	et	4	main
keele	doc_397823701988_item	3557203	et	4	main
oskust	doc_397823701988_item	3557204	et	3	main
soovitav	doc_397823701988_item	3557207	et	4	main
mugavaid	doc_397823701988_item	3557212	et	3	main
kakuke	doc_397823701988_item	3557221	et	4	main
tartu	doc_397823701988_item	3557222	et	4	main
mnt	doc_397823701988_item	3557223	et	4	main
3	doc_397823701988_item	3557224	et	2	main
tallinn	doc_397823701988_item	3557225	et	4	main
as	doc_397823701988_item	3557226	et	4	main
kakuke	doc_397823701988_item	3557227	et	4	main
tartu	doc_397823701988_item	3557228	et	4	main
mnt	doc_397823701988_item	3557229	et	4	main
3	doc_397823701988_item	3557230	et	2	main
mina	doc_397823701988_item	3557232	et	4	main
soovin	doc_397823701988_item	3557233	et	3	main
töötada	doc_397823701988_item	3557234	et	3	main
müüjana	doc_397823701988_item	3557235	et	4	main
tallinn	doc_397823701988_item	3557231	et	4	main
mina	doc_397823701988_item	3557236	et	4	main
abielus	doc_397823701988_item	3557237	et	4	main
meil	doc_397823701988_item	3557238	et	4	main
on	doc_397823701988_item	3557239	et	4	main
täiskasvane	doc_397823701988_item	3557240	et	4	main
poeg	doc_397823701988_item	3557241	et	3	main
elame	doc_397823701988_item	3557242	et	3	main
kolmekesi	doc_397823701988_item	3557243	et	3	main
mul	doc_397823701988_item	3557244	et	3	main
on	doc_397823701988_item	3557245	et	4	main
kõrg	doc_397823701988_item	3557246	et	4	main
haridus	doc_397823701988_item	3557247	et	3	main
ametlik	doc_397823701988_item	3557148	et	3	main
ja	doc_397823701988_item	3557153	et	3	main
60	doc_397823701988_item	3557160	et	2	main
ennast	doc_397823701988_item	3557163	et	4	main
haridus	doc_397823701988_item	3557165	et	3	main
arvutioskus	doc_397823701988_item	3557168	et	3	main
kauplusesse	doc_397823701988_item	3557191	et	4	main
pakume	doc_397823701988_item	3557211	et	3	main
töötingimusi	doc_397823701988_item	3557213	et	3	main
on	doc_397823701988_item	3557260	et	4	main
arvuti	doc_397823701988_item	3557261	et	4	main
pr	doc_15203423349_item	3557326	et	4	main
perekonnanimi	doc_15203423349_item	3557328	et	3	main
asutus	doc_15203423349_item	3557340	et	4	main
me	doc_15203423349_item	3557351	et	4	main
reeklaamist	doc_15203423349_item	3557354	et	4	main
ajalehest	doc_15203423349_item	3557355	et	4	main
konkurssid	doc_15203423349_item	3557356	et	4	main
ja	doc_15203423349_item	3557357	et	3	main
auhinnad	doc_15203423349_item	3557358	et	3	main
küsida	doc_15203423349_item	3557363	et	3	main
külastasime	doc_15203423349_item	3557366	et	3	main
kodulehekülge	doc_15203423349_item	3557368	et	4	main
aga	doc_15203423349_item	3557369	et	3	main
kahjuks	doc_15203423349_item	3557370	et	4	main
või	doc_15203423349_item	3557383	et	4	main
millal	doc_15203423349_item	3557385	et	3	main
konkurssi	doc_15203423349_item	3557391	et	4	main
tulemustega	doc_15203423349_item	3557392	et	3	main
kas	doc_15203423349_item	3557393	et	3	main
peab	doc_15203423349_item	3557399	et	4	main
auhinnad	doc_15203423349_item	3557406	et	3	main
aitäh	doc_15203423349_item	3557407	et	3	main
vastuste	doc_15203423349_item	3557408	et	4	main
aruanne	doc_973441205341_item	3557442	et	4	main
võtsin	doc_973441205341_item	3557449	et	3	main
osa	doc_973441205341_item	3557456	et	4	main
koolinoorte	doc_973441205341_item	3557469	et	3	main
antud	doc_973441205341_item	3557486	et	4	main
üritus	doc_973441205341_item	3557487	et	4	main
oli	doc_973441205341_item	3557488	et	3	main
omavalitsuse	doc_973441205341_item	3557489	et	3	main
esimeestele	doc_973441205341_item	3557490	et	4	main
õpetajatele	doc_973441205341_item	3557491	et	4	main
ja	doc_973441205341_item	3557492	et	3	main
huvijuhtidele	doc_973441205341_item	3557493	et	3	main
peale	doc_973441205341_item	3557497	et	4	main
hakkasid	doc_973441205341_item	3557498	et	4	main
toimus	doc_973441205341_item	3557506	et	3	main
registreerimine	doc_973441205341_item	3557507	et	4	main
ning	doc_973441205341_item	3557508	et	3	main
edasi	doc_973441205341_item	3557509	et	3	main
toimus	doc_973441205341_item	3557510	et	3	main
erinevate	doc_973441205341_item	3557511	et	4	main
projektide	doc_973441205341_item	3557512	et	3	main
ülevaade	doc_973441205341_item	3557513	et	3	main
seas	doc_973441205341_item	3557515	et	4	main
vene	doc_973441205341_item	3557518	et	4	main
õppekeelega	doc_973441205341_item	3557519	et	3	main
koolidele	doc_973441205341_item	3557520	et	3	main
mõeldud	doc_973441205341_item	3557521	et	4	main
projektid	doc_973441205341_item	3557522	et	3	main
välja	doc_973441205341_item	3557531	et	4	main
on	doc_397823701988_item	3557249	et	4	main
kodus	doc_397823701988_item	3557259	et	4	main
mina	doc_397823701988_item	3557262	et	4	main
oskan	doc_397823701988_item	3557263	et	3	main
kasutada	doc_397823701988_item	3557264	et	3	main
arvutit	doc_397823701988_item	3557265	et	3	main
tööl	doc_397823701988_item	3557266	et	3	main
ka	doc_397823701988_item	3557267	et	3	main
meil	doc_397823701988_item	3557268	et	4	main
on	doc_397823701988_item	3557269	et	4	main
oma	doc_397823701988_item	3557270	et	4	main
auto	doc_397823701988_item	3557271	et	4	main
kui	doc_397823701988_item	3557272	et	3	main
mulle	doc_397823701988_item	3557273	et	4	main
on	doc_397823701988_item	3557274	et	4	main
vaja	doc_397823701988_item	3557275	et	4	main
töö	doc_397823701988_item	3557276	et	4	main
jaoks	doc_397823701988_item	3557277	et	4	main
kuhu	doc_397823701988_item	3557278	et	3	main
sõita	doc_397823701988_item	3557279	et	3	main
siis	doc_397823701988_item	3557280	et	3	main
mina	doc_397823701988_item	3557281	et	4	main
võib	doc_397823701988_item	3557282	et	3	main
kasutada	doc_397823701988_item	3557283	et	3	main
meie	doc_397823701988_item	3557284	et	4	main
autot	doc_397823701988_item	3557285	et	3	main
mul	doc_397823701988_item	3557286	et	3	main
on	doc_397823701988_item	3557287	et	4	main
autojuhiload	doc_397823701988_item	3557288	et	4	main
minu	doc_397823701988_item	3557289	et	3	main
hobi	doc_397823701988_item	3557290	et	4	main
on	doc_397823701988_item	3557291	et	4	main
raamatuid	doc_397823701988_item	3557293	et	3	main
ajaloost	doc_397823701988_item	3557294	et	4	main
lugeda	doc_397823701988_item	3557292	et	3	main
mina	doc_397823701988_item	3557295	et	4	main
soovin	doc_397823701988_item	3557296	et	3	main
töötada	doc_397823701988_item	3557297	et	3	main
müüjana	doc_397823701988_item	3557298	et	4	main
5000	doc_397823701988_item	3557301	et	2	main
töökogemus	doc_397823701988_item	3557248	et	3	main
aastad	doc_397823701988_item	3557251	et	3	main
oskan	doc_397823701988_item	3557253	et	3	main
ja	doc_397823701988_item	3557256	et	3	main
mulle	doc_397823701988_item	3557299	et	4	main
eesnimi	doc_15203423349_item	3557327	et	3	main
peatoimetaja	doc_15203423349_item	3557329	et	4	main
as	doc_15203423349_item	3557330	et	4	main
ajakirjanduslevi	doc_15203423349_item	3557331	et	4	main
mustika	doc_15203423349_item	3557332	et	2	main
30	doc_15203423349_item	3557333	et	2	main
inimeste	doc_15203423349_item	3557341	et	3	main
põnevaim	doc_15203423349_item	3557348	et	4	main
me	doc_15203423349_item	3557361	et	4	main
me	doc_15203423349_item	3557365	et	4	main
teie	doc_15203423349_item	3557367	et	4	main
soovime	doc_15203423349_item	3557375	et	4	main
teada	doc_15203423349_item	3557376	et	3	main
missuguseid	doc_15203423349_item	3557377	et	3	main
fotosid	doc_15203423349_item	3557378	et	3	main
peab	doc_15203423349_item	3557379	et	4	main
värvilisi	doc_15203423349_item	3557384	et	4	main
konkurssil	doc_15203423349_item	3557395	et	4	main
on	doc_15203423349_item	3557396	et	4	main
tasuta	doc_15203423349_item	3557397	et	4	main
milline	doc_15203423349_item	3557398	et	3	main
pr	doc_973441205341_item	3557433	et	4	main
eesnimi	doc_973441205341_item	3557444	et	3	main
õpilane	doc_973441205341_item	3557448	et	3	main
poolaasta	doc_973441205341_item	3557451	et	4	main
esimesel	doc_973441205341_item	3557452	et	3	main
nädalalõpul	doc_973441205341_item	3557453	et	3	main
nüüd	doc_973441205341_item	3557458	et	4	main
virumaa	doc_973441205341_item	3557468	et	4	main
ühenduses	doc_973441205341_item	3557470	et	4	main
mõeldud	doc_973441205341_item	3557494	et	4	main
üheteistkümnest	doc_973441205341_item	3557496	et	3	main
alguses	doc_973441205341_item	3557503	et	4	main
kell	doc_973441205341_item	3557504	et	3	main
1100	doc_973441205341_item	3557505	et	2	main
kolmest	doc_973441205341_item	3557524	et	4	main
aga	doc_973441205341_item	3557525	et	3	main
püüdsime	doc_973441205341_item	3557526	et	3	main
meie	doc_973441205341_item	3557581	et	4	main
kooli	doc_973441205341_item	3557582	et	4	main
neist	doc_973441205341_item	3557588	et	4	main
osa	doc_973441205341_item	3557589	et	4	main
võtmine	doc_973441205341_item	3557590	et	4	main
osutub	doc_973441205341_item	3557591	et	3	main
väga	doc_973441205341_item	3557592	et	3	main
5	doc_973441205351_item	3557607	et	2	main
lugesin	doc_973441205351_item	3557612	et	3	main
toimub	doc_973441205351_item	3557627	et	3	main
esindatud	doc_973441205351_item	3557649	et	4	main
et	doc_973441205351_item	3557653	et	3	main
oleks	doc_973441205351_item	3557658	et	3	main
teilt	doc_973441205351_item	3557661	et	4	main
kui	doc_973441205351_item	3557663	et	3	main
kui	doc_973441205351_item	3557671	et	3	main
rääkida	doc_973441205351_item	3557690	et	3	main
hind	doc_973441205351_item	3557696	et	3	main
omavalitsuse	doc_460280307200_item	3557728	et	3	main
tallinn	doc_460280307200_item	3557734	et	4	main
teade	doc_460280307200_item	3557740	et	4	main
võimalike	doc_460280307200_item	3557751	et	4	main
lahenduste	doc_460280307200_item	3557752	et	4	main
suurtest	doc_460280307200_item	3557772	et	4	main
probleemidest	doc_460280307200_item	3557773	et	3	main
eriti	doc_460280307200_item	3557804	et	3	main
peab	doc_460280307200_item	3557814	et	4	main
paigaldama	doc_460280307200_item	3557815	et	3	main
oleks	doc_460280307200_item	3557819	et	3	main
ja	doc_460280307200_item	3557821	et	3	main
kuritegevuste	doc_460280307200_item	3557831	et	4	main
lisaks	doc_460280307200_item	3557833	et	4	main
transpordi	doc_460280307200_item	3557844	et	4	main
ja	doc_460280307200_item	3557845	et	3	main
puude	doc_460280307200_item	3557853	et	4	main
meie	doc_460280307200_item	3557862	et	4	main
et	doc_460280307200_item	3557872	et	3	main
meil	doc_460280307200_item	3557875	et	4	main
lahendada	doc_460280307200_item	3557876	et	3	main
kr	doc_397823701988_item	3557302	et	4	main
8	doc_15203423349_item	3557335	et	2	main
6022005	doc_15203423349_item	3557337	et	2	main
käed	doc_15203423349_item	3557342	et	3	main
trükiste	doc_15203423349_item	3557346	et	3	main
saime	doc_15203423349_item	3557352	et	3	main
teada	doc_15203423349_item	3557353	et	3	main
tahame	doc_15203423349_item	3557362	et	3	main
leidnud	doc_15203423349_item	3557372	et	4	main
sisaldama	doc_15203423349_item	3557381	et	3	main
ja	doc_15203423349_item	3557386	et	3	main
osalemine	doc_15203423349_item	3557394	et	4	main
olema	doc_15203423349_item	3557400	et	4	main
informatsiooni	doc_15203423349_item	3557401	et	4	main
maht	doc_15203423349_item	3557402	et	3	main
kas	doc_15203423349_item	3557403	et	3	main
eest	doc_15203423349_item	3557409	et	4	main
ootan	doc_15203423349_item	3557410	et	3	main
teie	doc_15203423349_item	3557411	et	4	main
poolset	doc_15203423349_item	3557412	et	3	main
vastust	doc_15203423349_item	3557413	et	4	main
oma	doc_15203423349_item	3557414	et	4	main
kodusel	doc_15203423349_item	3557415	et	4	main
aadressil	doc_15203423349_item	3557416	et	3	main
tänav	doc_15203423349_item	3557417	et	4	main
14	doc_15203423349_item	3557418	et	2	main
46	doc_15203423349_item	3557419	et	2	main
20406	doc_15203423349_item	3557420	et	2	main
narva	doc_15203423349_item	3557421	et	4	main
ida-virumaa	doc_15203423349_item	3557422	et	4	main
e-mailil	doc_15203423349_item	3557423	et	4	main
eesnimimktee	doc_15203423349_item	3557424	et	2	main
perekonnanimi	doc_973441205341_item	3557435	et	3	main
õpetaja	doc_973441205341_item	3557441	et	4	main
perekonnanimi	doc_973441205341_item	3557445	et	3	main
ja	doc_973441205341_item	3557457	et	3	main
jutustada	doc_973441205341_item	3557460	et	3	main
sellest	doc_973441205341_item	3557462	et	4	main
üritusest	doc_973441205341_item	3557463	et	4	main
seminar	doc_973441205341_item	3557464	et	3	main
toimus	doc_973441205341_item	3557465	et	3	main
jõhvis	doc_973441205341_item	3557466	et	3	main
kooli	doc_973441205341_item	3557482	et	4	main
omavalitsuse	doc_973441205341_item	3557483	et	3	main
kella	doc_973441205341_item	3557495	et	4	main
tegevused	doc_973441205341_item	3557502	et	4	main
kella	doc_973441205341_item	3557523	et	4	main
sellega	doc_973441205341_item	3557533	et	3	main
jõhvis	doc_973441205341_item	3557538	et	3	main
jaanuaril	doc_973441205341_item	3557540	et	3	main
kella	doc_973441205341_item	3557541	et	4	main
õpilastele	doc_973441205341_item	3557583	et	4	main
tn	doc_973441205351_item	3557606	et	4	main
11314	doc_973441205351_item	3557608	et	2	main
saada	doc_973441205351_item	3557624	et	4	main
gruppis	doc_973441205351_item	3557636	et	4	main
inimest	doc_973441205351_item	3557640	et	3	main
ma	doc_973441205351_item	3557642	et	3	main
muusikastüülid	doc_973441205351_item	3557647	et	4	main
seal	doc_973441205351_item	3557648	et	4	main
tähtis	doc_973441205351_item	3557652	et	4	main
ja	doc_973441205351_item	3557656	et	3	main
tahaksin	doc_973441205351_item	3557660	et	3	main
olema	doc_973441205351_item	3557669	et	4	main
neid	doc_973441205351_item	3557673	et	4	main
kindlasti	doc_973441205351_item	3557691	et	3	main
tähtis	doc_973441205351_item	3557693	et	4	main
piletite	doc_973441205351_item	3557695	et	3	main
ja	doc_973441205341_item	3557594	et	3	main
arengule	doc_973441205341_item	3557595	et	3	main
kasulikuks	doc_973441205341_item	3557596	et	3	main
lugupidamisega	doc_973441205341_item	3557597	et	3	main
eesnimi	doc_973441205341_item	3557598	et	3	main
perekonnanimi	doc_973441205341_item	3557599	et	3	main
24102006	doc_973441205341_item	3557600	et	2	main
aruanne	doc_973441205341_item	3557432	et	4	main
eesnimi	doc_973441205341_item	3557434	et	3	main
narva	doc_973441205341_item	3557436	et	4	main
pähklimäe	doc_973441205341_item	3557437	et	3	main
gümnaasiumi	doc_973441205341_item	3557438	et	4	main
mina	doc_973441205341_item	3557443	et	4	main
10a	doc_973441205341_item	3557446	et	4	main
selle	doc_973441205341_item	3557450	et	4	main
ida	doc_973441205341_item	3557467	et	4	main
elutee	doc_973441205341_item	3557471	et	4	main
mis	doc_973441205341_item	3557472	et	4	main
asub	doc_973441205341_item	3557473	et	3	main
keskväljaku	doc_973441205341_item	3557474	et	3	main
tänaval	doc_973441205341_item	3557475	et	4	main
nr	doc_973441205341_item	3557476	et	4	main
5	doc_973441205341_item	3557477	et	2	main
võtsin	doc_973441205341_item	3557478	et	3	main
sellest	doc_973441205341_item	3557479	et	4	main
osa	doc_973441205341_item	3557480	et	4	main
kui	doc_973441205341_item	3557481	et	3	main
päeva	doc_973441205341_item	3557501	et	4	main
nende	doc_973441205341_item	3557514	et	4	main
ka	doc_973441205341_item	3557517	et	3	main
projekti	doc_973441205341_item	3557530	et	4	main
mõelda	doc_973441205341_item	3557532	et	4	main
eesti	doc_973441205351_item	3557603	et	4	main
järelepäremine	doc_973441205351_item	3557611	et	4	main
et	doc_973441205351_item	3557614	et	3	main
toimub	doc_973441205351_item	3557616	et	3	main
see	doc_973441205351_item	3557628	et	3	main
et	doc_973441205351_item	3557631	et	3	main
tahaksin	doc_973441205351_item	3557632	et	3	main
reisi	doc_973441205351_item	3557633	et	4	main
organiseerida	doc_973441205351_item	3557634	et	3	main
meie	doc_973441205351_item	3557635	et	4	main
kaheksa	doc_973441205351_item	3557639	et	4	main
samuti	doc_973441205351_item	3557641	et	3	main
teada	doc_973441205351_item	3557644	et	3	main
millised	doc_973441205351_item	3557646	et	3	main
progressivne	doc_973441205351_item	3557657	et	4	main
jaoks	doc_973441205351_item	3557680	et	4	main
teada	doc_973441205351_item	3557681	et	3	main
esinejate	doc_973441205351_item	3557682	et	4	main
arv	doc_973441205351_item	3557683	et	3	main
et	doc_973441205351_item	3557684	et	3	main
ma	doc_973441205351_item	3557685	et	3	main
võiksin	doc_973441205351_item	3557686	et	3	main
erinevat	doc_973441205351_item	3557687	et	4	main
tarkuse	doc_460280307200_item	3557730	et	4	main
interneti	doc_460280307200_item	3557741	et	4	main
ettepanekud	doc_460280307200_item	3557746	et	3	main
kohta	doc_460280307200_item	3557753	et	4	main
minu	doc_460280307200_item	3557754	et	3	main
narva	doc_460280307200_item	3557757	et	4	main
on	doc_460280307200_item	3557774	et	4	main
see	doc_460280307200_item	3557775	et	3	main
et	doc_460280307200_item	3557776	et	3	main
väga	doc_460280307200_item	3557777	et	3	main
tihti	doc_460280307200_item	3557778	et	3	main
narva-jõesuusse	doc_460280307200_item	3557807	et	3	main
probleem	doc_460280307200_item	3557810	et	3	main
laternaid	doc_460280307200_item	3557817	et	3	main
mõnusam	doc_460280307200_item	3557822	et	4	main
pimedal	doc_460280307200_item	3557823	et	3	main
ajal	doc_460280307200_item	3557824	et	4	main
see	doc_460280307200_item	3557828	et	3	main
ka	doc_460280307200_item	3557830	et	3	main
taset	doc_460280307200_item	3557832	et	3	main
tahan	doc_460280307200_item	3557834	et	3	main
poolt	doc_460280307200_item	3557847	et	4	main
hulk	doc_460280307200_item	3557854	et	3	main
üha	doc_460280307200_item	3557856	et	3	main
inimestel	doc_460280307200_item	3557865	et	3	main
jalutada	doc_460280307200_item	3557868	et	3	main
teie	doc_460280307200_item	3557873	et	4	main
aidate	doc_460280307200_item	3557874	et	4	main
juhataja	doc_52744525863_item	3557908	et	4	main
interneti	doc_52744525863_item	3557926	et	4	main
reklaamist	doc_52744525863_item	3557945	et	4	main
talus	doc_52744525863_item	3557950	et	4	main
telkimise	doc_52744525863_item	3557952	et	4	main
on	doc_52744525863_item	3557954	et	4	main
me	doc_52744525863_item	3557957	et	4	main
ilma	doc_52744525863_item	3557966	et	4	main
teid	doc_285078626584_item	3558033	et	4	main
hr	doc_285078626584_item	3558040	et	4	main
diplomi	doc_285078626584_item	3558046	et	3	main
augustil	doc_285078626584_item	3558049	et	3	main
tööle	doc_285078626584_item	3558055	et	3	main
augustil	doc_285078626584_item	3558065	et	3	main
10626	doc_40918597555_item	3558074	et	2	main
juhuslik	doc_40918597555_item	3558078	et	3	main
narva	doc_40918597555_item	3558081	et	4	main
et	doc_40918597555_item	3558089	et	3	main
firma	doc_40918597555_item	3558091	et	4	main
as	doc_40918597555_item	3558092	et	4	main
kümnest	doc_973441205341_item	3557542	et	4	main
toimus	doc_973441205341_item	3557543	et	3	main
tagasiside	doc_973441205341_item	3557544	et	4	main
ja	doc_973441205341_item	3557545	et	3	main
kokkuvõtte	doc_973441205341_item	3557546	et	4	main
rühmatööst	doc_973441205341_item	3557547	et	3	main
millele	doc_973441205341_item	3557548	et	3	main
järgnes	doc_973441205341_item	3557549	et	3	main
1300	doc_973441205341_item	3557551	et	2	main
vaba	doc_973441205341_item	3557552	et	4	main
mikrofon	doc_973441205341_item	3557553	et	3	main
kus	doc_973441205341_item	3557554	et	3	main
võis	doc_973441205341_item	3557555	et	4	main
kuulda	doc_973441205341_item	3557556	et	4	main
vaabariiklike	doc_973441205341_item	3557557	et	4	main
ajalehtede	doc_973441205341_item	3557558	et	4	main
ajakirjanikuid	doc_973441205341_item	3557559	et	4	main
kell	doc_973441205341_item	3557560	et	3	main
1500	doc_973441205341_item	3557561	et	2	main
oli	doc_973441205341_item	3557562	et	3	main
kokkuvõte	doc_973441205341_item	3557564	et	3	main
ja	doc_973441205341_item	3557565	et	3	main
seminari	doc_973441205341_item	3557563	et	4	main
seega	doc_973441205341_item	3557566	et	4	main
kahepäevane	doc_973441205341_item	3557567	et	4	main
seminar	doc_973441205341_item	3557568	et	3	main
lõppes	doc_973441205341_item	3557569	et	4	main
arvan	doc_973441205341_item	3557570	et	3	main
et	doc_973441205341_item	3557571	et	3	main
seminar	doc_973441205341_item	3557572	et	3	main
oli	doc_973441205341_item	3557573	et	3	main
üsna	doc_973441205341_item	3557574	et	3	main
kasulik	doc_973441205341_item	3557575	et	3	main
ning	doc_973441205341_item	3557576	et	3	main
mõnede	doc_973441205341_item	3557577	et	3	main
projektide	doc_973441205341_item	3557578	et	3	main
toimumisest	doc_973441205341_item	3557579	et	4	main
võib	doc_973441205341_item	3557580	et	3	main
10	doc_973441205341_item	3557539	et	2	main
kell	doc_973441205341_item	3557550	et	3	main
saadud	doc_973441205341_item	3557584	et	4	main
infot	doc_973441205341_item	3557585	et	3	main
edastama	doc_973441205341_item	3557586	et	3	main
sest	doc_973441205341_item	3557587	et	4	main
järelpärimine	doc_973441205351_item	3557601	et	3	main
muusika	doc_973441205351_item	3557604	et	4	main
lilleküla	doc_973441205351_item	3557605	et	4	main
70406a	doc_973441205351_item	3557610	et	4	main
millal	doc_973441205351_item	3557625	et	3	main
konkreetselt	doc_973441205351_item	3557626	et	4	main
üritus	doc_973441205351_item	3557629	et	4	main
sellepärast	doc_973441205351_item	3557630	et	3	main
olema	doc_973441205351_item	3557638	et	4	main
väga	doc_973441205351_item	3557651	et	3	main
tänapäevane	doc_973441205351_item	3557655	et	4	main
küsida	doc_973441205351_item	3557662	et	3	main
saal	doc_973441205351_item	3557665	et	3	main
lava	doc_973441205351_item	3557667	et	4	main
peab	doc_973441205351_item	3557668	et	4	main
palju	doc_973441205351_item	3557672	et	4	main
olema	doc_973441205351_item	3557675	et	4	main
on	doc_973441205351_item	3557676	et	4	main
väga	doc_973441205351_item	3557677	et	3	main
tähtis	doc_973441205351_item	3557678	et	4	main
minu	doc_973441205351_item	3557679	et	3	main
informatsiooni	doc_973441205351_item	3557688	et	4	main
on	doc_973441205351_item	3557692	et	4	main
teada	doc_973441205351_item	3557694	et	3	main
ning	doc_973441205351_item	3557701	et	3	main
info	doc_973441205351_item	3557702	et	4	main
majutusest	doc_973441205351_item	3557703	et	4	main
palun	doc_973441205351_item	3557704	et	3	main
teatage	doc_973441205351_item	3557705	et	3	main
mind	doc_973441205351_item	3557706	et	4	main
kui	doc_973441205351_item	3557707	et	3	main
informatsiooni	doc_973441205351_item	3557708	et	4	main
kohta	doc_973441205351_item	3557709	et	4	main
loodan	doc_973441205351_item	3557710	et	3	main
et	doc_973441205351_item	3557711	et	3	main
vastate	doc_973441205351_item	3557712	et	3	main
üksikasjalikult	doc_973441205351_item	3557713	et	4	main
kõigile	doc_973441205351_item	3557714	et	4	main
minu	doc_973441205351_item	3557715	et	3	main
küsimustele	doc_973441205351_item	3557716	et	4	main
lisaandmed	doc_973441205351_item	3557717	et	3	main
kontaktelefon	doc_973441205351_item	3557718	et	4	main
55	doc_973441205351_item	3557719	et	2	main
555	doc_973441205351_item	3557720	et	2	main
55	doc_973441205351_item	3557721	et	2	main
e	doc_973441205351_item	3557722	et	4	main
mail	doc_973441205351_item	3557723	et	4	main
eesnimimailru	doc_973441205351_item	3557724	et	2	main
eesnimi	doc_973441205351_item	3557725	et	3	main
huvitavaks	doc_973441205341_item	3557593	et	4	main
as	doc_973441205351_item	3557602	et	4	main
tallinn	doc_973441205351_item	3557609	et	4	main
internetist	doc_973441205351_item	3557613	et	4	main
varsti	doc_973441205351_item	3557615	et	3	main
igaaastane	doc_973441205351_item	3557617	et	4	main
roskilde	doc_973441205351_item	3557618	et	4	main
festival	doc_973441205351_item	3557619	et	3	main
taanis	doc_973441205351_item	3557620	et	4	main
ma	doc_973441205351_item	3557621	et	3	main
tahaksin	doc_973441205351_item	3557622	et	3	main
teada	doc_973441205351_item	3557623	et	3	main
peab	doc_973441205351_item	3557637	et	4	main
tahaksin	doc_973441205351_item	3557643	et	3	main
saada	doc_973441205351_item	3557645	et	4	main
on	doc_973441205351_item	3557650	et	4	main
muusika	doc_973441205351_item	3557654	et	4	main
veel	doc_973441205351_item	3557659	et	4	main
suur	doc_973441205351_item	3557664	et	3	main
või	doc_973441205351_item	3557666	et	4	main
ning	doc_973441205351_item	3557670	et	3	main
peab	doc_973441205351_item	3557674	et	4	main
turistidele	doc_973441205351_item	3557689	et	3	main
soodustused	doc_973441205351_item	3557697	et	4	main
mis	doc_973441205351_item	3557698	et	4	main
hind	doc_973441205351_item	3557699	et	3	main
sisaldab	doc_973441205351_item	3557700	et	3	main
perekonnanimi	doc_973441205351_item	3557726	et	3	main
15	doc_460280307200_item	3557731	et	2	main
ettepanek	doc_460280307200_item	3557736	et	3	main
leidsin	doc_460280307200_item	3557738	et	3	main
leheküljelt	doc_460280307200_item	3557742	et	3	main
teha	doc_460280307200_item	3557745	et	3	main
koduümbrusega	doc_460280307200_item	3557748	et	3	main
seotud	doc_460280307200_item	3557749	et	4	main
probleemide	doc_460280307200_item	3557750	et	3	main
tänavatel	doc_460280307200_item	3557765	et	4	main
teed	doc_460280307200_item	3557805	et	4	main
seotud	doc_460280307200_item	3557812	et	4	main
valgustusega	doc_460280307200_item	3557813	et	4	main
jalutada	doc_460280307200_item	3557827	et	3	main
panna	doc_460280307200_item	3557836	et	4	main
sellele	doc_460280307200_item	3557837	et	4	main
on	doc_460280307200_item	3557841	et	4	main
see	doc_460280307200_item	3557848	et	3	main
haigusi	doc_460280307200_item	3557850	et	4	main
väiksem	doc_460280307200_item	3557857	et	4	main
ja	doc_460280307200_item	3557858	et	3	main
väiksem	doc_460280307200_item	3557859	et	4	main
põnev	doc_460280307200_item	3557867	et	3	main
parimate	doc_460280307200_item	3557879	et	4	main
soovidega	doc_460280307200_item	3557880	et	3	main
ja	doc_460280307200_item	3557881	et	3	main
järelpärimine	doc_52744525863_item	3557904	et	3	main
pansionaat	doc_52744525863_item	3557911	et	3	main
ma	doc_52744525863_item	3557922	et	3	main
wwwheapuhkusee	doc_52744525863_item	3557928	et	4	main
teada	doc_52744525863_item	3557948	et	3	main
huvitav	doc_52744525863_item	3557955	et	4	main
telkides	doc_52744525863_item	3557959	et	4	main
kas	doc_52744525863_item	3557960	et	3	main
kiirendatud	doc_285078626584_item	3558034	et	4	main
välja	doc_285078626584_item	3558036	et	4	main
sündinud	doc_285078626584_item	3558043	et	4	main
22101971	doc_285078626584_item	3558044	et	2	main
25	doc_285078626584_item	3558048	et	2	main
kuna	doc_285078626584_item	3558052	et	3	main
laevandusfirmasse	doc_285078626584_item	3558057	et	3	main
avaldus	doc_40918597555_item	3558068	et	4	main
as	doc_40918597555_item	3558069	et	4	main
tallinn	doc_40918597555_item	3558075	et	4	main
suur	doc_40918597555_item	3558132	et	3	main
ma	doc_40918597555_item	3558135	et	3	main
keelt	doc_40918597555_item	3558171	et	4	main
sest	doc_40918597555_item	3558172	et	4	main
ma	doc_40918597555_item	3558173	et	3	main
ja	doc_40918597555_item	3558178	et	3	main
emakeel	doc_40918597555_item	3558183	et	4	main
töökas	doc_40918597555_item	3558209	et	4	main
te	doc_40918597555_item	3558212	et	4	main
allkiri	doc_40918597555_item	3558222	et	3	main
avaldus	doc_40918597554_item	3558224	et	4	main
6	doc_40918597554_item	3558229	et	2	main
juhataja	doc_40918597554_item	3558235	et	4	main
oma	doc_40918597554_item	3558245	et	4	main
inimesi	doc_40918597554_item	3558247	et	4	main
mina	doc_40918597554_item	3558248	et	4	main
pildistaja	doc_40918597554_item	3558257	et	4	main
ametikohale	doc_40918597554_item	3558258	et	4	main
lõpetasin	doc_40918597554_item	3558261	et	3	main
mis	doc_40918597554_item	3558264	et	4	main
kestsid	doc_40918597554_item	3558265	et	4	main
2	doc_40918597554_item	3558266	et	2	main
aastat	doc_40918597554_item	3558267	et	3	main
aastani	doc_40918597554_item	3558275	et	3	main
emakeel	doc_40918597554_item	3558281	et	4	main
keele	doc_40918597554_item	3558285	et	4	main
kesktaseme	doc_40918597554_item	3558286	et	3	main
eksamit	doc_40918597554_item	3558287	et	3	main
oodates	doc_40918597554_item	3558333	et	3	main
5	doc_40918597554_item	3558337	et	2	main
pähklimäe	doc_460280307200_item	3557889	et	3	main
gümnaasium	doc_460280307200_item	3557890	et	3	main
virmalise	doc_460280307200_item	3557891	et	3	main
11	doc_460280307200_item	3557892	et	2	main
1	doc_460280307200_item	3557893	et	2	main
20	doc_460280307200_item	3557894	et	2	main
306	doc_460280307200_item	3557895	et	2	main
narva	doc_460280307200_item	3557896	et	4	main
ida-virumaa	doc_460280307200_item	3557897	et	4	main
telefon	doc_460280307200_item	3557898	et	3	main
nr	doc_460280307200_item	3557899	et	4	main
55	doc_460280307200_item	3557900	et	2	main
555	doc_460280307200_item	3557901	et	2	main
55	doc_460280307200_item	3557902	et	2	main
19092006	doc_460280307200_item	3557903	et	2	main
10	doc_460280307200_item	3557732	et	2	main
ma	doc_460280307200_item	3557737	et	3	main
teie	doc_460280307200_item	3557739	et	4	main
oma	doc_460280307200_item	3557747	et	4	main
on	doc_460280307200_item	3557756	et	4	main
see	doc_460280307200_item	3557758	et	3	main
on	doc_460280307200_item	3557759	et	4	main
on	doc_460280307200_item	3557766	et	4	main
vägivald	doc_460280307200_item	3557767	et	3	main
juhtuvad	doc_460280307200_item	3557779	et	4	main
avariid	doc_460280307200_item	3557780	et	4	main
seepärast	doc_460280307200_item	3557781	et	3	main
et	doc_460280307200_item	3557782	et	3	main
teede	doc_460280307200_item	3557783	et	3	main
seisund	doc_460280307200_item	3557784	et	3	main
on	doc_460280307200_item	3557785	et	4	main
hirmus	doc_460280307200_item	3557786	et	4	main
igalpool	doc_460280307200_item	3557787	et	4	main
on	doc_460280307200_item	3557788	et	4	main
augud	doc_460280307200_item	3557789	et	3	main
jalgrattasõitjad	doc_460280307200_item	3557790	et	3	main
on	doc_460280307200_item	3557791	et	4	main
ohus	doc_460280307200_item	3557792	et	3	main
minu	doc_460280307200_item	3557793	et	3	main
arvates	doc_460280307200_item	3557794	et	4	main
peab	doc_460280307200_item	3557795	et	4	main
uuesti	doc_460280307200_item	3557796	et	3	main
asfalteerima	doc_460280307200_item	3557797	et	3	main
ja	doc_460280307200_item	3557798	et	3	main
renoveerima	doc_460280307200_item	3557799	et	4	main
teid	doc_460280307200_item	3557800	et	4	main
ja	doc_460280307200_item	3557801	et	3	main
tänavaid	doc_460280307200_item	3557802	et	4	main
narvas	doc_460280307200_item	3557803	et	4	main
ettepanek	doc_460280307200_item	3557727	et	3	main
liit	doc_460280307200_item	3557729	et	3	main
355	doc_460280307200_item	3557733	et	2	main
harjumaa	doc_460280307200_item	3557735	et	4	main
wwwaktiivsednooredee	doc_460280307200_item	3557743	et	4	main
soovin	doc_460280307200_item	3557744	et	3	main
kodukoht	doc_460280307200_item	3557755	et	3	main
piirilinn	doc_460280307200_item	3557760	et	3	main
kus	doc_460280307200_item	3557761	et	3	main
on	doc_460280307200_item	3557762	et	4	main
hulk	doc_460280307200_item	3557763	et	3	main
probleeme	doc_460280307200_item	3557764	et	3	main
müra	doc_460280307200_item	3557768	et	4	main
ja	doc_460280307200_item	3557769	et	3	main
ebakord	doc_460280307200_item	3557770	et	4	main
üks	doc_460280307200_item	3557771	et	3	main
teine	doc_460280307200_item	3557808	et	3	main
käia	doc_460280307200_item	3557825	et	4	main
ja	doc_460280307200_item	3557826	et	3	main
narvast	doc_460280307200_item	3557806	et	4	main
tähtis	doc_460280307200_item	3557809	et	4	main
on	doc_460280307200_item	3557811	et	4	main
rohkem	doc_460280307200_item	3557816	et	4	main
et	doc_460280307200_item	3557818	et	3	main
ohutum	doc_460280307200_item	3557820	et	4	main
saastatud	doc_460280307200_item	3557842	et	4	main
heitgaasidega	doc_460280307200_item	3557843	et	3	main
peab	doc_460280307200_item	3557860	et	4	main
haljastama	doc_460280307200_item	3557861	et	3	main
loodan	doc_460280307200_item	3557871	et	3	main
vastust	doc_460280307200_item	3557882	et	4	main
oodates	doc_460280307200_item	3557883	et	3	main
perekonnanimi	doc_460280307200_item	3557886	et	3	main
õpilane	doc_460280307200_item	3557887	et	3	main
e	doc_52744525863_item	3557906	et	4	main
talu	doc_52744525863_item	3557910	et	4	main
küla	doc_52744525863_item	3557917	et	4	main
mihkli	doc_52744525863_item	3557918	et	3	main
talu	doc_52744525863_item	3557919	et	4	main
28052005	doc_52744525863_item	3557920	et	2	main
soovin	doc_52744525863_item	3557929	et	3	main
mihkli	doc_52744525863_item	3557931	et	3	main
koos	doc_52744525863_item	3557934	et	4	main
oma	doc_52744525863_item	3557935	et	4	main
perega	doc_52744525863_item	3557936	et	3	main
perioodil	doc_52744525863_item	3557937	et	3	main
esimeselt	doc_52744525863_item	3557938	et	3	main
kuni	doc_52744525863_item	3557939	et	3	main
kümnenda	doc_52744525863_item	3557940	et	3	main
juunini	doc_52744525863_item	3557941	et	3	main
sain	doc_52744525863_item	3557947	et	3	main
külma	doc_52744525863_item	3557963	et	4	main
ja	doc_52744525863_item	3557964	et	3	main
ööbida	doc_52744525863_item	3557968	et	3	main
lastele	doc_52744525863_item	3558004	et	4	main
ja	doc_52744525863_item	3558005	et	3	main
kas	doc_52744525863_item	3558007	et	3	main
õpilastele	doc_52744525863_item	3558006	et	4	main
on	doc_52744525863_item	3558008	et	4	main
võimalus	doc_52744525863_item	3558009	et	3	main
maksta	doc_52744525863_item	3558010	et	4	main
panga	doc_52744525863_item	3558011	et	3	main
ülekandega	doc_52744525863_item	3558012	et	3	main
tänan	doc_52744525863_item	3558013	et	3	main
ettepanekute	doc_52744525863_item	3558014	et	3	main
eest	doc_52744525863_item	3558015	et	4	main
parimate	doc_52744525863_item	3558016	et	4	main
soovidega	doc_52744525863_item	3558017	et	3	main
ja	doc_52744525863_item	3558018	et	3	main
vastust	doc_52744525863_item	3558019	et	4	main
oodates	doc_52744525863_item	3558020	et	3	main
eesnimi	doc_52744525863_item	3558021	et	3	main
perekonnanimi	doc_52744525863_item	3558022	et	3	main
kreegipuu	doc_52744525863_item	3558023	et	4	main
8	doc_52744525863_item	3558024	et	2	main
41	doc_52744525863_item	3558025	et	2	main
20406	doc_52744525863_item	3558026	et	2	main
taotlus	doc_285078626584_item	3558030	et	4	main
korras	doc_285078626584_item	3558035	et	4	main
meie	doc_285078626584_item	3558038	et	4	main
vähendaks	doc_460280307200_item	3557829	et	3	main
tähele	doc_460280307200_item	3557835	et	3	main
et	doc_460280307200_item	3557838	et	3	main
õhk	doc_460280307200_item	3557839	et	3	main
narvas	doc_460280307200_item	3557840	et	4	main
suurettevõtete	doc_460280307200_item	3557846	et	3	main
tekitab	doc_460280307200_item	3557849	et	3	main
inimestel	doc_460280307200_item	3557851	et	3	main
taimede	doc_460280307200_item	3557852	et	4	main
on	doc_460280307200_item	3557855	et	4	main
linna	doc_460280307200_item	3557863	et	4	main
et	doc_460280307200_item	3557864	et	3	main
oleks	doc_460280307200_item	3557866	et	3	main
oma	doc_460280307200_item	3557869	et	4	main
koduümbuuses	doc_460280307200_item	3557870	et	4	main
austusega	doc_460280307200_item	3557884	et	4	main
eesnimi	doc_460280307200_item	3557885	et	3	main
narva	doc_460280307200_item	3557888	et	4	main
neid	doc_460280307200_item	3557877	et	4	main
probleeme	doc_460280307200_item	3557878	et	3	main
pr	doc_52744525863_item	3557905	et	4	main
lääne	doc_52744525863_item	3557912	et	4	main
ridala	doc_52744525863_item	3557914	et	4	main
vald	doc_52744525863_item	3557915	et	3	main
topu	doc_52744525863_item	3557916	et	4	main
teie	doc_52744525863_item	3557924	et	4	main
leheküljelt	doc_52744525863_item	3557927	et	3	main
puhata	doc_52744525863_item	3557930	et	4	main
talu	doc_52744525863_item	3557932	et	4	main
pansionaadis	doc_52744525863_item	3557933	et	3	main
ma	doc_52744525863_item	3557946	et	3	main
et	doc_52744525863_item	3557949	et	3	main
on	doc_52744525863_item	3557951	et	4	main
võimalus	doc_52744525863_item	3557953	et	3	main
vihmase	doc_52744525863_item	3557965	et	4	main
majas	doc_52744525863_item	3557969	et	3	main
narva	doc_52744525863_item	3558027	et	4	main
ida-virumaa	doc_52744525863_item	3558028	et	4	main
28052005	doc_52744525863_item	3558029	et	2	main
perekonnanimi	doc_52744525863_item	3557907	et	3	main
mihkli	doc_52744525863_item	3557909	et	3	main
maakond	doc_52744525863_item	3557913	et	3	main
järelepärimine	doc_52744525863_item	3557921	et	3	main
leidsin	doc_52744525863_item	3557923	et	3	main
reklaami	doc_52744525863_item	3557925	et	4	main
me	doc_52744525863_item	3557942	et	4	main
tuleme	doc_52744525863_item	3557943	et	3	main
kolmekesi	doc_52744525863_item	3557944	et	3	main
kui	doc_52744525863_item	3557956	et	3	main
elame	doc_52744525863_item	3557958	et	3	main
on	doc_52744525863_item	3557961	et	4	main
võimalik	doc_52744525863_item	3557962	et	3	main
ajal	doc_52744525863_item	3557967	et	4	main
ma	doc_52744525863_item	3557970	et	3	main
valisin	doc_52744525863_item	3557971	et	3	main
just	doc_52744525863_item	3557972	et	3	main
teie	doc_52744525863_item	3557973	et	4	main
pansionaadi	doc_52744525863_item	3557974	et	3	main
sest	doc_52744525863_item	3557975	et	4	main
arvan	doc_52744525863_item	3557976	et	3	main
et	doc_52744525863_item	3557977	et	3	main
see	doc_52744525863_item	3557978	et	3	main
on	doc_52744525863_item	3557979	et	4	main
rahulik	doc_52744525863_item	3557980	et	3	main
ja	doc_52744525863_item	3557981	et	3	main
maalik	doc_52744525863_item	3557982	et	3	main
koht	doc_52744525863_item	3557983	et	3	main
kus	doc_52744525863_item	3557984	et	3	main
võib	doc_52744525863_item	3557985	et	3	main
mõnusalt	doc_52744525863_item	3557986	et	4	main
veeta	doc_52744525863_item	3557987	et	4	main
oma	doc_52744525863_item	3557988	et	4	main
puhkust	doc_52744525863_item	3557989	et	4	main
tahaksime	doc_52744525863_item	3557990	et	3	main
proovida	doc_52744525863_item	3557991	et	3	main
puhast	doc_52744525863_item	3557992	et	3	main
talutoodangut	doc_52744525863_item	3557993	et	3	main
ja	doc_52744525863_item	3557994	et	3	main
kalu	doc_52744525863_item	3557995	et	4	main
püüda	doc_52744525863_item	3557996	et	3	main
tahan	doc_52744525863_item	3557997	et	3	main
küsida	doc_52744525863_item	3557998	et	3	main
lisainfot	doc_52744525863_item	3557999	et	3	main
kas	doc_52744525863_item	3558000	et	3	main
teil	doc_52744525863_item	3558001	et	4	main
on	doc_52744525863_item	3558002	et	4	main
soodustused	doc_52744525863_item	3558003	et	4	main
taotlus	doc_285078626584_item	3558031	et	4	main
a	doc_285078626584_item	3558045	et	4	main
2006	doc_285078626584_item	3558050	et	2	main
vabalt	doc_40918597555_item	3558190	et	4	main
alati	doc_40918597555_item	3558191	et	4	main
taha	doc_40918597555_item	3558192	et	4	main
töötada	doc_40918597555_item	3558193	et	3	main
gruuppides	doc_40918597555_item	3558194	et	4	main
ja	doc_40918597555_item	3558195	et	3	main
teha	doc_40918597555_item	3558196	et	3	main
meeskonna	doc_40918597555_item	3558197	et	4	main
tööd	doc_40918597555_item	3558198	et	4	main
kui	doc_40918597555_item	3558199	et	3	main
ma	doc_40918597555_item	3558200	et	3	main
töötan	doc_40918597555_item	3558201	et	3	main
grupis	doc_40918597555_item	3558202	et	3	main
siis	doc_40918597555_item	3558203	et	3	main
ma	doc_40918597555_item	3558204	et	3	main
olen	doc_40918597555_item	3558205	et	3	main
väga	doc_40918597555_item	3558206	et	3	main
ja	doc_40918597555_item	3558208	et	3	main
palun	doc_285078626584_item	3558032	et	3	main
anda	doc_285078626584_item	3558037	et	3	main
töötaja	doc_285078626584_item	3558039	et	4	main
a	doc_285078626584_item	3558051	et	4	main
ta	doc_285078626584_item	3558053	et	4	main
cicbrevers	doc_285078626584_item	3558063	et	4	main
26	doc_285078626584_item	3558064	et	2	main
2006	doc_285078626584_item	3558066	et	2	main
a	doc_285078626584_item	3558067	et	4	main
personalikond	doc_40918597555_item	3558071	et	4	main
6	doc_40918597555_item	3558073	et	2	main
teie	doc_40918597555_item	3558087	et	4	main
teie	doc_40918597555_item	3558090	et	4	main
tööd	doc_40918597555_item	3558095	et	4	main
ma	doc_40918597555_item	3558096	et	3	main
tahaksin	doc_40918597555_item	3558097	et	3	main
töötada	doc_40918597555_item	3558098	et	3	main
pildistajana	doc_40918597555_item	3558099	et	4	main
tahan	doc_40918597555_item	3558100	et	3	main
öelda	doc_40918597555_item	3558101	et	4	main
et	doc_40918597555_item	3558102	et	3	main
mul	doc_40918597555_item	3558103	et	3	main
on	doc_40918597555_item	3558104	et	4	main
suur	doc_40918597555_item	3558105	et	3	main
eriala	doc_40918597555_item	3558106	et	4	main
töökogemust	doc_40918597555_item	3558107	et	3	main
ja	doc_40918597555_item	3558108	et	3	main
ma	doc_40918597555_item	3558109	et	3	main
arvan	doc_40918597555_item	3558110	et	3	main
et	doc_40918597555_item	3558111	et	3	main
ma	doc_40918597555_item	3558112	et	3	main
olen	doc_40918597555_item	3558113	et	3	main
sobiv	doc_40918597555_item	3558114	et	4	main
kandidad	doc_40918597555_item	3558115	et	4	main
sellele	doc_40918597555_item	3558116	et	4	main
ametikohale	doc_40918597555_item	3558117	et	4	main
sest	doc_40918597555_item	3558118	et	4	main
et	doc_40918597555_item	3558119	et	3	main
ma	doc_40918597555_item	3558120	et	3	main
olen	doc_40918597555_item	3558121	et	3	main
väga	doc_40918597555_item	3558122	et	3	main
vastutab	doc_40918597555_item	3558123	et	3	main
isik	doc_40918597555_item	3558124	et	3	main
ma	doc_40918597555_item	3558125	et	3	main
lõpetasin	doc_40918597555_item	3558126	et	3	main
pildistaja	doc_40918597555_item	3558127	et	4	main
kursuste	doc_40918597555_item	3558128	et	3	main
ja	doc_40918597555_item	3558129	et	3	main
mul	doc_40918597555_item	3558130	et	3	main
aastat	doc_40918597555_item	3558176	et	3	main
lev	doc_285078626584_item	3558041	et	4	main
tolstoi	doc_285078626584_item	3558042	et	4	main
vaheleht	doc_285078626584_item	3558047	et	3	main
asub	doc_285078626584_item	3558054	et	3	main
ship	doc_285078626584_item	3558059	et	4	main
management	doc_285078626584_item	3558060	et	4	main
juhuslik	doc_40918597555_item	3558072	et	3	main
perekonnanimi	doc_40918597555_item	3558077	et	3	main
6	doc_40918597555_item	3558079	et	2	main
ajakirjanduslevi	doc_40918597555_item	3558093	et	4	main
pakub	doc_40918597555_item	3558094	et	3	main
töökogemus	doc_40918597555_item	3558133	et	3	main
töötasin	doc_40918597555_item	3558136	et	3	main
käesin	doc_40918597555_item	3558174	et	4	main
2	doc_40918597555_item	3558175	et	2	main
suhelda	doc_40918597555_item	3558189	et	4	main
sobiv	doc_40918597555_item	3558219	et	4	main
kandidaat	doc_40918597555_item	3558220	et	3	main
lugupidamisega	doc_40918597555_item	3558221	et	3	main
rahvusvahelisse	doc_285078626584_item	3558056	et	4	main
cec	doc_285078626584_item	3558058	et	4	main
as	doc_285078626584_item	3558061	et	4	main
laeval	doc_285078626584_item	3558062	et	3	main
ajakirjanduslevi	doc_40918597555_item	3558070	et	4	main
eesnimi	doc_40918597555_item	3558076	et	3	main
10234	doc_40918597555_item	3558080	et	2	main
avaldus	doc_40918597555_item	3558082	et	4	main
lugupeetud	doc_40918597555_item	3558083	et	4	main
personaliosakond	doc_40918597555_item	3558084	et	3	main
ma	doc_40918597555_item	3558085	et	3	main
lugesin	doc_40918597555_item	3558086	et	3	main
kuulutuse	doc_40918597555_item	3558088	et	4	main
sest	doc_40918597555_item	3558134	et	4	main
kursustel	doc_40918597555_item	3558177	et	3	main
ja	doc_40918597555_item	3558181	et	3	main
aktiivne	doc_40918597555_item	3558207	et	3	main
et	doc_40918597555_item	3558211	et	3	main
võtate	doc_40918597555_item	3558213	et	3	main
mind	doc_40918597555_item	3558214	et	4	main
tööle	doc_40918597555_item	3558215	et	3	main
ja	doc_40918597555_item	3558216	et	3	main
mina	doc_40918597555_item	3558217	et	4	main
olen	doc_40918597555_item	3558218	et	3	main
as	doc_40918597554_item	3558225	et	4	main
ajakirjanduslevi	doc_40918597554_item	3558226	et	4	main
personaliosakond	doc_40918597554_item	3558227	et	3	main
juhuslik	doc_40918597554_item	3558228	et	3	main
10626	doc_40918597554_item	3558230	et	2	main
tallinn	doc_40918597554_item	3558231	et	4	main
personaliosakonna	doc_40918597554_item	3558234	et	4	main
postimehes	doc_40918597554_item	3558238	et	3	main
tahan	doc_40918597554_item	3558255	et	3	main
aastal	doc_40918597554_item	3558260	et	3	main
tean	doc_40918597554_item	3558276	et	3	main
kolm	doc_40918597554_item	3558277	et	3	main
on	doc_40918597554_item	3558280	et	4	main
vastust	doc_40918597554_item	3558332	et	4	main
narva	doc_40918597554_item	3558339	et	4	main
tallinn	doc_40918597553_item	3558347	et	4	main
avaldus	doc_40918597553_item	3558348	et	4	main
te	doc_40918597553_item	3558357	et	4	main
tööd	doc_40918597553_item	3558359	et	4	main
praaegu	doc_40918597553_item	3558360	et	4	main
ma	doc_40918597553_item	3558361	et	3	main
otsin	doc_40918597553_item	3558362	et	3	main
ma	doc_40918597553_item	3558370	et	3	main
valdan	doc_40918597553_item	3558377	et	3	main
vaja	doc_40918597553_item	3558389	et	4	main
pildistajana	doc_40918597553_item	3558396	et	4	main
võtta	doc_40918597553_item	3558405	et	3	main
on	doc_40918597553_item	3558410	et	4	main
tallinnas	doc_40918597553_item	3558415	et	4	main
avaldus	doc_40918597552_item	3558447	et	4	main
ajakirjanduslevi	doc_40918597552_item	3558449	et	4	main
juhatajale	doc_40918597552_item	3558450	et	4	main
juhuslik	doc_40918597552_item	3558451	et	3	main
6	doc_40918597552_item	3558452	et	2	main
10626	doc_40918597552_item	3558453	et	2	main
lugupeetud	doc_40918597552_item	3558456	et	4	main
olen	doc_40918597552_item	3558476	et	3	main
kandidat	doc_40918597552_item	3558479	et	4	main
valdan	doc_40918597552_item	3558481	et	3	main
eesti	doc_40918597552_item	3558482	et	4	main
soome	doc_40918597552_item	3558483	et	3	main
inglise	doc_40918597552_item	3558484	et	4	main
ja	doc_40918597552_item	3558485	et	3	main
mul	doc_40918597552_item	3558494	et	3	main
tunistus	doc_40918597552_item	3558497	et	4	main
kuna	doc_40918597552_item	3558498	et	3	main
keeli	doc_40918597552_item	3558501	et	4	main
eksamit	doc_40918597552_item	3558502	et	3	main
ma	doc_40918597552_item	3558503	et	3	main
oskan	doc_40918597552_item	3558504	et	3	main
rääkida	doc_40918597552_item	3558505	et	3	main
vene	doc_40918597552_item	3558506	et	4	main
ja	doc_40918597552_item	3558507	et	3	main
teaduskonna	doc_40918597552_item	3558523	et	4	main
ma	doc_40918597552_item	3558524	et	3	main
töötasin	doc_40918597552_item	3558525	et	3	main
pärast	doc_40918597552_item	3558530	et	4	main
kohalik	doc_40918597552_item	3558535	et	3	main
mulle	doc_40918597552_item	3558537	et	4	main
on	doc_40918597555_item	3558131	et	4	main
juba	doc_40918597555_item	3558137	et	3	main
pildistajana	doc_40918597555_item	3558138	et	4	main
liisaks	doc_40918597555_item	3558139	et	4	main
sellele	doc_40918597555_item	3558140	et	4	main
ma	doc_40918597555_item	3558141	et	3	main
olen	doc_40918597555_item	3558142	et	3	main
väga	doc_40918597555_item	3558143	et	3	main
komunikaabilne	doc_40918597555_item	3558144	et	4	main
ja	doc_40918597555_item	3558145	et	3	main
vestlev	doc_40918597555_item	3558146	et	4	main
inimene	doc_40918597555_item	3558147	et	3	main
ja	doc_40918597555_item	3558148	et	3	main
ei	doc_40918597555_item	3558149	et	4	main
karda	doc_40918597555_item	3558150	et	4	main
suhelda	doc_40918597555_item	3558151	et	4	main
teiste	doc_40918597555_item	3558152	et	4	main
inimestega	doc_40918597555_item	3558153	et	3	main
koolis	doc_40918597555_item	3558154	et	4	main
ma	doc_40918597555_item	3558155	et	3	main
õpisin	doc_40918597555_item	3558156	et	4	main
inglise	doc_40918597555_item	3558157	et	4	main
eesti	doc_40918597555_item	3558159	et	4	main
ja	doc_40918597555_item	3558158	et	3	main
keelt	doc_40918597555_item	3558160	et	4	main
ja	doc_40918597555_item	3558161	et	3	main
oskan	doc_40918597555_item	3558162	et	3	main
praegu	doc_40918597555_item	3558163	et	3	main
oskan	doc_40918597555_item	3558164	et	3	main
seda	doc_40918597555_item	3558165	et	3	main
hästi	doc_40918597555_item	3558166	et	3	main
ma	doc_40918597555_item	3558167	et	3	main
ka	doc_40918597555_item	3558168	et	3	main
valdan	doc_40918597555_item	3558169	et	3	main
soome	doc_40918597555_item	3558170	et	3	main
sain	doc_40918597555_item	3558179	et	3	main
minu	doc_40918597555_item	3558182	et	3	main
on	doc_40918597555_item	3558184	et	4	main
venekell	doc_40918597555_item	3558185	et	3	main
siis	doc_40918597555_item	3558186	et	3	main
ma	doc_40918597555_item	3558187	et	3	main
saan	doc_40918597555_item	3558188	et	4	main
12052008	doc_40918597555_item	3558223	et	2	main
lugupeetud	doc_40918597554_item	3558233	et	4	main
te	doc_40918597554_item	3558243	et	4	main
kutsute	doc_40918597554_item	3558244	et	3	main
ja	doc_40918597554_item	3558254	et	3	main
1996	doc_40918597554_item	3558274	et	2	main
olin	doc_40918597554_item	3558282	et	3	main
18778	doc_40918597554_item	3558338	et	2	main
pakkute	doc_40918597553_item	3558358	et	4	main
sobiv	doc_40918597553_item	3558374	et	4	main
eesti	doc_40918597553_item	3558378	et	4	main
ja	doc_40918597553_item	3558380	et	3	main
inglise	doc_40918597553_item	3558381	et	4	main
keelt	doc_40918597553_item	3558382	et	4	main
aga	doc_40918597553_item	3558383	et	3	main
kui	doc_40918597553_item	3558384	et	3	main
soome	doc_40918597553_item	3558385	et	3	main
õppida	doc_40918597553_item	3558393	et	3	main
olen	doc_40918597553_item	3558394	et	3	main
intervjuule	doc_40918597553_item	3558408	et	3	main
aga	doc_40918597553_item	3558412	et	3	main
eksamid	doc_40918597553_item	3558414	et	3	main
ka	doc_40918597553_item	3558419	et	3	main
as	doc_40918597552_item	3558448	et	4	main
personaliosakonna	doc_40918597552_item	3558457	et	4	main
ajalehest	doc_40918597552_item	3558460	et	4	main
postimees	doc_40918597552_item	3558461	et	4	main
et	doc_40918597552_item	3558463	et	3	main
et	doc_40918597552_item	3558474	et	3	main
sobivam	doc_40918597552_item	3558478	et	4	main
eksamit	doc_40918597552_item	3558492	et	3	main
eesti	doc_40918597552_item	3558508	et	4	main
aga	doc_40918597552_item	3558511	et	3	main
keeli	doc_40918597552_item	3558515	et	4	main
kooliõppimise	doc_40918597552_item	3558526	et	3	main
ülikooli	doc_40918597552_item	3558531	et	4	main
aastat	doc_40918597552_item	3558534	et	3	main
meeldib	doc_40918597552_item	3558538	et	3	main
juhuslik	doc_542009824801_item	3558562	et	3	main
teie	doc_542009824801_item	3558580	et	4	main
lõpetasin	doc_542009824801_item	3558590	et	3	main
õpingud	doc_542009824801_item	3558592	et	3	main
laomajandaja	doc_542009824801_item	3558593	et	4	main
erialal	doc_542009824801_item	3558594	et	3	main
ja	doc_542009824801_item	3558595	et	3	main
läbisin	doc_542009824801_item	3558596	et	3	main
müügilaos	doc_542009824801_item	3558599	et	4	main
keemilise	doc_542009824801_item	3558633	et	4	main
500	doc_542009824801_item	3558662	et	2	main
taotlus	doc_842434202402_item	3558678	et	4	main
pangafirma	doc_842434202402_item	3558681	et	4	main
direktorile	doc_842434202402_item	3558682	et	3	main
kuupäev	doc_842434202402_item	3558707	et	3	main
juhatusele	doc_842434202402_item	3558710	et	4	main
juhuslik	doc_842434202402_item	3558715	et	3	main
50000	doc_842434202402_item	3558722	et	2	main
väikefirma	doc_842434202402_item	3558729	et	4	main
väikeettevõte	doc_842434202402_item	3558734	et	3	main
laenuraha	doc_842434202402_item	3558739	et	4	main
puidutööpingi	doc_842434202402_item	3558743	et	4	main
algkapitalist	doc_842434202402_item	3558750	et	4	main
on	doc_842434202402_item	3558751	et	4	main
politseile	doc_842434202396_item	3558774	et	3	main
kolmapäeval	doc_842434202396_item	3558778	et	3	main
kuni	doc_842434202396_item	3558784	et	3	main
kuritegu	doc_842434202396_item	3558788	et	4	main
juhtus	doc_842434202396_item	3558790	et	3	main
kaugudeliinide	doc_842434202396_item	3558792	et	4	main
bussi	doc_842434202396_item	3558793	et	4	main
nahast	doc_842434202396_item	3558800	et	4	main
püksid	doc_842434202396_item	3558804	et	3	main
hele	doc_842434202396_item	3558806	et	3	main
ta	doc_842434202396_item	3558808	et	4	main
sinine	doc_842434202396_item	3558810	et	4	main
tunnistus	doc_40918597555_item	3558180	et	4	main
loodan	doc_40918597555_item	3558210	et	3	main
avaldus	doc_40918597554_item	3558232	et	4	main
ajalehest	doc_40918597554_item	3558239	et	4	main
tööle	doc_40918597554_item	3558246	et	3	main
kandideerida	doc_40918597554_item	3558256	et	3	main
1989	doc_40918597554_item	3558259	et	2	main
pildistaja	doc_40918597554_item	3558262	et	4	main
kursused	doc_40918597554_item	3558263	et	3	main
ajalehes	doc_40918597554_item	3558271	et	3	main
kuni	doc_40918597554_item	3558273	et	3	main
keelt	doc_40918597554_item	3558278	et	4	main
eesnimi	doc_40918597554_item	3558334	et	3	main
juhuslik	doc_40918597554_item	3558336	et	3	main
ja	doc_40918597553_item	3558364	et	3	main
töötada	doc_40918597553_item	3558366	et	3	main
olen	doc_40918597553_item	3558373	et	3	main
keel	doc_40918597553_item	3558386	et	4	main
on	doc_40918597553_item	3558387	et	4	main
ka	doc_40918597553_item	3558388	et	3	main
seda	doc_40918597553_item	3558392	et	3	main
töid	doc_40918597553_item	3558407	et	3	main
keskharidus	doc_40918597553_item	3558411	et	3	main
sooritasin	doc_40918597553_item	3558413	et	3	main
vastan	doc_40918597553_item	3558418	et	3	main
nõudmistele	doc_40918597553_item	3558421	et	4	main
tallinn	doc_40918597552_item	3558454	et	4	main
inimesi	doc_40918597552_item	3558467	et	4	main
kes	doc_40918597552_item	3558468	et	4	main
tahab	doc_40918597552_item	3558469	et	3	main
töötada	doc_40918597552_item	3558470	et	3	main
uudisteajakirjanikuna	doc_40918597552_item	3558471	et	3	main
ma	doc_40918597552_item	3558472	et	3	main
arvan	doc_40918597552_item	3558473	et	3	main
vene	doc_40918597552_item	3558486	et	4	main
keeli	doc_40918597552_item	3558487	et	4	main
ma	doc_40918597552_item	3558490	et	3	main
sooritasin	doc_40918597552_item	3558491	et	3	main
ma	doc_40918597552_item	3558499	et	3	main
inglise	doc_40918597552_item	3558512	et	4	main
ja	doc_40918597552_item	3558513	et	3	main
räägin	doc_40918597552_item	3558516	et	3	main
lõpetasin	doc_40918597552_item	3558519	et	3	main
tartu	doc_40918597552_item	3558520	et	4	main
ja	doc_40918597552_item	3558529	et	3	main
töötasin	doc_40918597552_item	3558532	et	3	main
2	doc_40918597552_item	3558533	et	2	main
ajalehes	doc_40918597552_item	3558536	et	3	main
radelina	doc_542009824801_item	3558560	et	4	main
mnt	doc_542009824801_item	3558563	et	4	main
555555	doc_542009824801_item	3558566	et	2	main
15	doc_542009824801_item	3558567	et	2	main
oktoober	doc_542009824801_item	3558568	et	3	main
ma	doc_542009824801_item	3558577	et	3	main
kuid	doc_542009824801_item	3558582	et	4	main
mul	doc_542009824801_item	3558583	et	3	main
on	doc_542009824801_item	3558584	et	4	main
keemiline	doc_542009824801_item	3558585	et	4	main
keskharidus	doc_542009824801_item	3558586	et	3	main
kolmeaastased	doc_542009824801_item	3558591	et	4	main
täpselt	doc_542009824801_item	3558621	et	4	main
efektiivsult	doc_542009824801_item	3558623	et	4	main
oskan	doc_542009824801_item	3558625	et	3	main
organiseerid	doc_542009824801_item	3558626	et	3	main
ja	doc_542009824801_item	3558628	et	3	main
ja	doc_542009824801_item	3558635	et	3	main
kutsekoolide	doc_542009824801_item	3558658	et	3	main
ujumisvõistluse	doc_542009824801_item	3558660	et	3	main
alati	doc_40918597554_item	3558309	et	4	main
töötasin	doc_40918597554_item	3558310	et	3	main
meeskonnas	doc_40918597554_item	3558311	et	4	main
kõik	doc_40918597554_item	3558312	et	4	main
viimased	doc_40918597554_item	3558313	et	3	main
töötajad	doc_40918597554_item	3558314	et	4	main
ja	doc_40918597554_item	3558315	et	3	main
töö	doc_40918597554_item	3558316	et	4	main
juhatajad	doc_40918597554_item	3558317	et	4	main
olid	doc_40918597554_item	3558318	et	4	main
minuga	doc_40918597554_item	3558319	et	3	main
rahul	doc_40918597554_item	3558320	et	4	main
loodan	doc_40918597554_item	3558321	et	3	main
mina	doc_40918597554_item	3558323	et	4	main
et	doc_40918597554_item	3558322	et	3	main
olen	doc_40918597554_item	3558324	et	3	main
sobiv	doc_40918597554_item	3558325	et	4	main
kandidaat	doc_40918597554_item	3558326	et	3	main
ja	doc_40918597554_item	3558327	et	3	main
te	doc_40918597554_item	3558328	et	4	main
võtate	doc_40918597554_item	3558329	et	3	main
mind	doc_40918597554_item	3558330	et	4	main
tööle	doc_40918597554_item	3558331	et	3	main
eile	doc_40918597554_item	3558236	et	3	main
lugesin	doc_40918597554_item	3558237	et	3	main
teie	doc_40918597554_item	3558240	et	4	main
kuulutuse	doc_40918597554_item	3558241	et	4	main
kus	doc_40918597554_item	3558242	et	3	main
arvan	doc_40918597554_item	3558249	et	3	main
et	doc_40918597554_item	3558250	et	3	main
olen	doc_40918597554_item	3558251	et	3	main
sobiv	doc_40918597554_item	3558252	et	4	main
kandidaat	doc_40918597554_item	3558253	et	3	main
pärast	doc_40918597554_item	3558268	et	4	main
seda	doc_40918597554_item	3558269	et	3	main
töötasin	doc_40918597554_item	3558270	et	3	main
narva	doc_40918597554_item	3558272	et	4	main
venekeel	doc_40918597554_item	3558279	et	4	main
sooritanud	doc_40918597554_item	3558283	et	4	main
eesti	doc_40918597554_item	3558284	et	4	main
ja	doc_40918597554_item	3558288	et	3	main
said	doc_40918597554_item	3558289	et	4	main
kinnitav	doc_40918597554_item	3558290	et	4	main
tunnistus	doc_40918597554_item	3558291	et	4	main
inglise	doc_40918597554_item	3558292	et	4	main
keel	doc_40918597554_item	3558293	et	4	main
on	doc_40918597554_item	3558294	et	4	main
heal	doc_40918597554_item	3558295	et	3	main
tasemel	doc_40918597554_item	3558296	et	3	main
kiiresti	doc_40918597554_item	3558297	et	3	main
saan	doc_40918597554_item	3558298	et	4	main
inimestega	doc_40918597554_item	3558299	et	3	main
läbi	doc_40918597554_item	3558300	et	4	main
ka	doc_40918597554_item	3558301	et	3	main
mina	doc_40918597554_item	3558302	et	4	main
olen	doc_40918597554_item	3558303	et	3	main
positiivne	doc_40918597554_item	3558304	et	3	main
töökas	doc_40918597554_item	3558305	et	4	main
inimene	doc_40918597554_item	3558306	et	3	main
eelmisel	doc_40918597554_item	3558307	et	3	main
ametikohal	doc_40918597554_item	3558308	et	4	main
perekonnanimi	doc_40918597554_item	3558335	et	3	main
avaldus	doc_40918597553_item	3558340	et	4	main
ajakirjanduslevi	doc_40918597553_item	3558342	et	4	main
juhatajale	doc_40918597553_item	3558343	et	4	main
juhuslik	doc_40918597553_item	3558344	et	3	main
6	doc_40918597553_item	3558345	et	2	main
10626	doc_40918597553_item	3558346	et	2	main
taha	doc_40918597553_item	3558365	et	4	main
teie	doc_40918597553_item	3558367	et	4	main
firmas	doc_40918597553_item	3558368	et	3	main
pildistajana	doc_40918597553_item	3558369	et	4	main
arvan	doc_40918597553_item	3558371	et	3	main
kandidaat	doc_40918597553_item	3558375	et	3	main
vene	doc_40918597553_item	3558379	et	4	main
ma	doc_40918597553_item	3558390	et	3	main
saan	doc_40918597553_item	3558404	et	4	main
mul	doc_40918597553_item	3558409	et	3	main
ajakirjanduse	doc_40918597553_item	3558416	et	3	main
teistele	doc_40918597553_item	3558420	et	4	main
töötasin	doc_40918597553_item	3558424	et	3	main
ajalehes	doc_40918597553_item	3558425	et	3	main
postimees	doc_40918597553_item	3558426	et	4	main
me	doc_40918597553_item	3558427	et	4	main
töötasime	doc_40918597553_item	3558428	et	3	main
meeskonnas	doc_40918597553_item	3558429	et	4	main
ja	doc_40918597553_item	3558430	et	3	main
ma	doc_40918597553_item	3558431	et	3	main
arvan	doc_40918597553_item	3558432	et	3	main
et	doc_40918597553_item	3558433	et	3	main
töötamine	doc_40918597553_item	3558434	et	4	main
gruppis	doc_40918597553_item	3558435	et	4	main
on	doc_40918597553_item	3558436	et	4	main
lihtsam	doc_40918597553_item	3558437	et	4	main
ootan	doc_40918597553_item	3558438	et	3	main
teie	doc_40918597553_item	3558439	et	4	main
vaastust	doc_40918597553_item	3558440	et	4	main
eesnimi	doc_40918597553_item	3558441	et	3	main
perekonnanimi	doc_40918597553_item	3558442	et	3	main
juhuslik	doc_40918597553_item	3558443	et	3	main
5	doc_40918597553_item	3558444	et	2	main
10223	doc_40918597553_item	3558445	et	2	main
tallinn	doc_40918597553_item	3558446	et	4	main
as	doc_40918597553_item	3558341	et	4	main
lugupeetud	doc_40918597553_item	3558349	et	4	main
personalosakonna	doc_40918597553_item	3558350	et	4	main
juhataja	doc_40918597553_item	3558351	et	4	main
lugesin	doc_40918597553_item	3558352	et	3	main
ajalehest	doc_40918597553_item	3558353	et	4	main
teie	doc_40918597553_item	3558354	et	4	main
kuulutuse	doc_40918597553_item	3558355	et	4	main
et	doc_40918597553_item	3558356	et	3	main
tööd	doc_40918597553_item	3558363	et	4	main
et	doc_40918597553_item	3558372	et	3	main
ma	doc_40918597553_item	3558376	et	3	main
saan	doc_40918597553_item	3558391	et	4	main
töötanud	doc_40918597553_item	3558395	et	4	main
ajalehes	doc_40918597553_item	3558397	et	3	main
postimees	doc_40918597553_item	3558398	et	4	main
ja	doc_40918597553_item	3558399	et	3	main
kui	doc_40918597553_item	3558400	et	3	main
te	doc_40918597553_item	3558401	et	4	main
tahate	doc_40918597553_item	3558402	et	3	main
ma	doc_40918597553_item	3558403	et	3	main
oma	doc_40918597553_item	3558406	et	4	main
teaduskonnas	doc_40918597553_item	3558417	et	4	main
kui	doc_40918597553_item	3558422	et	3	main
ma	doc_40918597553_item	3558423	et	3	main
juht	doc_40918597552_item	3558458	et	3	main
firma	doc_40918597552_item	3558465	et	4	main
otsib	doc_40918597552_item	3558466	et	3	main
kõige	doc_40918597552_item	3558477	et	4	main
on	doc_40918597552_item	3558495	et	4	main
ülikooli	doc_40918597552_item	3558521	et	4	main
ajakirjanduse	doc_40918597552_item	3558522	et	3	main
ootan	doc_40918597552_item	3558548	et	3	main
avaldus	doc_542009824801_item	3558558	et	4	main
kohale	doc_542009824801_item	3558576	et	4	main
vastan	doc_542009824801_item	3558578	et	3	main
veel	doc_542009824801_item	3558587	et	4	main
ma	doc_542009824801_item	3558603	et	3	main
kiiresti	doc_542009824801_item	3558620	et	3	main
ma	doc_542009824801_item	3558624	et	3	main
laotööd	doc_542009824801_item	3558627	et	4	main
säilitada	doc_542009824801_item	3558629	et	3	main
reaktiivided	doc_542009824801_item	3558630	et	4	main
ma	doc_542009824801_item	3558631	et	3	main
lõpetasin	doc_542009824801_item	3558632	et	3	main
esimene	doc_542009824801_item	3558639	et	3	main
vahelise	doc_542009824801_item	3558659	et	4	main
metrit	doc_542009824801_item	3558663	et	4	main
taotlus	doc_842434202402_item	3558685	et	4	main
kui	doc_842434202402_item	3558704	et	3	main
hansapanga	doc_842434202402_item	3558709	et	3	main
kohtla-järve	doc_842434202402_item	3558713	et	4	main
aadress	doc_842434202402_item	3558717	et	3	main
mulle	doc_842434202402_item	3558720	et	4	main
viiskümmend	doc_842434202402_item	3558724	et	4	main
töö	doc_842434202402_item	3558731	et	4	main
käivitamiseks	doc_842434202402_item	3558732	et	4	main
saunasiseseid	doc_842434202402_item	3558737	et	3	main
firma	doc_842434202402_item	3558752	et	4	main
lisad	doc_842434202402_item	3558756	et	4	main
koopia	doc_842434202402_item	3558758	et	4	main
12102006	doc_842434202402_item	3558765	et	2	main
kuupäev	doc_842434202402_item	3558766	et	3	main
eesnimi	doc_842434202402_item	3558767	et	3	main
perekonnanimi	doc_842434202402_item	3558768	et	3	main
allkiri	doc_842434202402_item	3558769	et	3	main
kohtla-jarve	doc_842434202396_item	3558777	et	4	main
14	doc_842434202396_item	3558782	et	2	main
45	doc_842434202396_item	3558786	et	2	main
kohtla-jarves	doc_842434202396_item	3558791	et	4	main
oli	doc_842434202396_item	3558798	et	3	main
mustest	doc_842434202396_item	3558799	et	3	main
nelikümmend	doc_842434202396_item	3558834	et	4	main
bussijaamas	doc_842434202396_item	3558841	et	3	main
inimest	doc_842434202396_item	3558845	et	3	main
nad	doc_842434202396_item	3558847	et	3	main
ei	doc_842434202396_item	3558849	et	4	main
aitanud	doc_842434202396_item	3558850	et	4	main
naisele	doc_842434202396_item	3558851	et	3	main
jai	doc_842434202396_item	3558857	et	4	main
naine	doc_842434202396_item	3558860	et	3	main
jai	doc_842434202396_item	3558861	et	4	main
lugupidamisega	doc_40918597552_item	3558551	et	3	main
eesnimi	doc_40918597552_item	3558552	et	3	main
perekonnanimi	doc_40918597552_item	3558553	et	3	main
juhuslik	doc_40918597552_item	3558554	et	3	main
6	doc_40918597552_item	3558555	et	2	main
10987	doc_40918597552_item	3558556	et	2	main
narva	doc_40918597552_item	3558557	et	4	main
avaldus	doc_40918597552_item	3558455	et	4	main
lugesin	doc_40918597552_item	3558459	et	3	main
kuulutuse	doc_40918597552_item	3558462	et	4	main
teie	doc_40918597552_item	3558464	et	4	main
ma	doc_40918597552_item	3558475	et	3	main
ma	doc_40918597552_item	3558480	et	3	main
heal	doc_40918597552_item	3558488	et	3	main
tasemel	doc_40918597552_item	3558489	et	3	main
ja	doc_40918597552_item	3558493	et	3	main
kinnitav	doc_40918597552_item	3558496	et	4	main
sooritasin	doc_40918597552_item	3558500	et	3	main
keeli	doc_40918597552_item	3558509	et	4	main
vabalt	doc_40918597552_item	3558510	et	4	main
soome	doc_40918597552_item	3558514	et	3	main
halvem	doc_40918597552_item	3558517	et	4	main
ma	doc_40918597552_item	3558518	et	3	main
ajal	doc_40918597552_item	3558527	et	4	main
kooliajalehes	doc_40918597552_item	3558528	et	3	main
töötada	doc_40918597552_item	3558539	et	3	main
meeskonnas	doc_40918597552_item	3558540	et	4	main
sest	doc_40918597552_item	3558541	et	4	main
arvan	doc_40918597552_item	3558542	et	3	main
et	doc_40918597552_item	3558543	et	3	main
meeskonnatöö	doc_40918597552_item	3558544	et	4	main
aitab	doc_40918597552_item	3558545	et	3	main
lahendama	doc_40918597552_item	3558546	et	3	main
problemi	doc_40918597552_item	3558547	et	4	main
teie	doc_40918597552_item	3558549	et	4	main
vastust	doc_40918597552_item	3558550	et	4	main
direktorile	doc_542009824801_item	3558561	et	3	main
22	doc_542009824801_item	3558564	et	2	main
soovin	doc_542009824801_item	3558571	et	3	main
kandideerida	doc_542009824801_item	3558572	et	3	main
teie	doc_542009824801_item	3558573	et	4	main
firmasse	doc_542009824801_item	3558574	et	3	main
keemiku	doc_542009824801_item	3558575	et	3	main
kõikidele	doc_542009824801_item	3558579	et	4	main
eeldustele	doc_542009824801_item	3558581	et	4	main
ma	doc_542009824801_item	3558589	et	3	main
lolgi	doc_542009824801_item	3558598	et	4	main
as-s	doc_542009824801_item	3558600	et	3	main
saan	doc_542009824801_item	3558604	et	4	main
töötad	doc_542009824801_item	3558605	et	3	main
see	doc_542009824801_item	3558636	et	3	main
minu	doc_542009824801_item	3558638	et	3	main
olen	doc_542009824801_item	3558664	et	3	main
saamiseks	doc_842434202402_item	3558684	et	4	main
neid	doc_842434202402_item	3558705	et	4	main
maakond	doc_842434202402_item	3558712	et	3	main
palun	doc_842434202402_item	3558719	et	3	main
tuhat	doc_842434202402_item	3558725	et	4	main
valmistama	doc_842434202402_item	3558736	et	3	main
ostmiseks	doc_842434202402_item	3558744	et	4	main
tööruumid	doc_842434202402_item	3558745	et	3	main
on	doc_842434202402_item	3558746	et	4	main
olemas	doc_842434202402_item	3558747	et	4	main
samuti	doc_842434202402_item	3558748	et	3	main
töövahendid	doc_842434202402_item	3558749	et	3	main
rahastanud	doc_842434202402_item	3558753	et	4	main
b-kaart	doc_842434202402_item	3558757	et	4	main
tõend	doc_842434202402_item	3558759	et	3	main
toll-	doc_842434202402_item	3558760	et	3	main
ja	doc_842434202402_item	3558761	et	3	main
maksuamet	doc_842434202402_item	3558762	et	3	main
tõend	doc_842434202402_item	3558763	et	3	main
linnavalitsus	doc_842434202402_item	3558764	et	3	main
nimi	doc_842434202402_item	3558770	et	3	main
seletuskiri	doc_842434202396_item	3558772	et	3	main
eesnimi	doc_842434202396_item	3558775	et	3	main
detsembril	doc_842434202396_item	3558780	et	3	main
15	doc_842434202396_item	3558785	et	2	main
kellel	doc_842434202396_item	3558797	et	4	main
seljas	doc_842434202396_item	3558802	et	4	main
kampsun	doc_842434202396_item	3558807	et	3	main
krabas	doc_842434202396_item	3558809	et	3	main
kott	doc_842434202396_item	3558811	et	3	main
jalaga	doc_842434202396_item	3558826	et	3	main
vastu	doc_842434202396_item	3558827	et	3	main
keha	doc_842434202396_item	3558828	et	4	main
lööma	doc_842434202396_item	3558829	et	4	main
naise	doc_842434202396_item	3558830	et	3	main
aasta	doc_842434202396_item	3558835	et	4	main
tugeva	doc_842434202396_item	3558839	et	4	main
kümme	doc_842434202396_item	3558844	et	3	main
kõik	doc_842434202396_item	3558848	et	4	main
on	doc_842434202396_item	3558853	et	4	main
lõpetatud	doc_842434202396_item	3558854	et	4	main
sinise	doc_842434202396_item	3558864	et	4	main
muusika	doc_973441205350_item	3558870	et	4	main
tallinn	doc_973441205350_item	3558875	et	4	main
et	doc_973441205350_item	3558879	et	3	main
kui	doc_973441205350_item	3558899	et	3	main
kuues	doc_973441205350_item	3558907	et	4	main
junnil	doc_973441205350_item	3558908	et	3	main
kuues	doc_973441205350_item	3558917	et	4	main
minu	doc_973441205350_item	3558919	et	3	main
esindatud	doc_973441205350_item	3558925	et	4	main
alternatiivmuusika	doc_973441205350_item	3558929	et	4	main
hip	doc_973441205350_item	3558930	et	4	main
kutsutud	doc_973441205350_item	3558937	et	4	main
leningrad	doc_973441205350_item	3558947	et	4	main
midagi	doc_973441205350_item	3558954	et	4	main
kas	doc_973441205350_item	3558972	et	3	main
võime	doc_973441205350_item	3558978	et	4	main
olema	doc_973441205350_item	3558984	et	4	main
kui	doc_973441205350_item	3558986	et	3	main
as	doc_542009824801_item	3558559	et	4	main
jõhvi	doc_542009824801_item	3558565	et	4	main
2006	doc_542009824801_item	3558569	et	2	main
avaldus	doc_542009824801_item	3558570	et	4	main
lõpetamata	doc_542009824801_item	3558588	et	4	main
õppepraktika	doc_542009824801_item	3558597	et	4	main
silbet	doc_542009824801_item	3558601	et	4	main
sellepärast	doc_542009824801_item	3558602	et	3	main
keemiliste	doc_542009824801_item	3558606	et	4	main
reaktiividega	doc_542009824801_item	3558607	et	3	main
laos	doc_542009824801_item	3558608	et	4	main
me	doc_542009824801_item	3558609	et	4	main
õppisime	doc_542009824801_item	3558610	et	3	main
intensiivselt	doc_542009824801_item	3558611	et	4	main
majandust	doc_542009824801_item	3558612	et	4	main
marketingi	doc_542009824801_item	3558613	et	4	main
ja	doc_542009824801_item	3558614	et	3	main
logistikat	doc_542009824801_item	3558615	et	3	main
sellepärast	doc_542009824801_item	3558616	et	3	main
ma	doc_542009824801_item	3558617	et	3	main
saan	doc_542009824801_item	3558618	et	4	main
töötad	doc_542009824801_item	3558619	et	3	main
ja	doc_542009824801_item	3558622	et	3	main
keskhariduse	doc_542009824801_item	3558634	et	3	main
oleks	doc_542009824801_item	3558637	et	3	main
töökoht	doc_542009824801_item	3558640	et	3	main
sellepärast	doc_542009824801_item	3558641	et	3	main
ma	doc_542009824801_item	3558642	et	3	main
olen	doc_542009824801_item	3558643	et	3	main
eriti	doc_542009824801_item	3558644	et	3	main
ettevaatlik	doc_542009824801_item	3558645	et	3	main
ja	doc_542009824801_item	3558646	et	3	main
tähelepanelik	doc_542009824801_item	3558647	et	4	main
mulle	doc_542009824801_item	3558648	et	4	main
väga	doc_542009824801_item	3558649	et	3	main
meeldib	doc_542009824801_item	3558650	et	3	main
töötada	doc_542009824801_item	3558651	et	3	main
keemiliste	doc_542009824801_item	3558652	et	4	main
reaktiividega	doc_542009824801_item	3558653	et	3	main
keemilises	doc_542009824801_item	3558654	et	4	main
sfääris	doc_542009824801_item	3558655	et	3	main
kutsekoolis	doc_542009824801_item	3558656	et	4	main
võitsin	doc_542009824801_item	3558657	et	3	main
distansil	doc_542009824801_item	3558661	et	4	main
kindel	doc_542009824801_item	3558665	et	3	main
et	doc_542009824801_item	3558666	et	3	main
minu	doc_542009824801_item	3558667	et	3	main
meeldib	doc_542009824801_item	3558669	et	3	main
kandidatuur	doc_542009824801_item	3558668	et	3	main
teile	doc_542009824801_item	3558670	et	4	main
ja	doc_542009824801_item	3558671	et	3	main
te	doc_542009824801_item	3558672	et	4	main
võtate	doc_542009824801_item	3558673	et	3	main
mind	doc_542009824801_item	3558674	et	4	main
tööle	doc_542009824801_item	3558675	et	3	main
eesnimi	doc_542009824801_item	3558676	et	3	main
perekonnanimi	doc_542009824801_item	3558677	et	3	main
avaldus	doc_842434202402_item	3558680	et	4	main
peab	doc_842434202402_item	3558686	et	4	main
sisaldama	doc_842434202402_item	3558687	et	3	main
järgmisi	doc_842434202402_item	3558688	et	3	main
andmeid	doc_842434202402_item	3558689	et	3	main
kes	doc_842434202402_item	3558692	et	4	main
on	doc_842434202402_item	3558706	et	4	main
5-6	doc_842434202402_item	3558716	et	2	main
võimaldada	doc_842434202402_item	3558721	et	3	main
laenu	doc_842434202402_item	3558728	et	4	main
meie	doc_842434202402_item	3558733	et	4	main
60	doc_842434202402_item	3558755	et	2	main
kirjutage	doc_842434202402_item	3558679	et	3	main
laenu	doc_842434202402_item	3558683	et	4	main
kellele	doc_842434202402_item	3558690	et	4	main
esitatakse	doc_842434202402_item	3558691	et	3	main
esitab	doc_842434202402_item	3558693	et	3	main
mida	doc_842434202402_item	3558694	et	4	main
taotleb	doc_842434202402_item	3558695	et	3	main
mille	doc_842434202402_item	3558696	et	3	main
jaoks	doc_842434202402_item	3558697	et	4	main
märkusi	doc_842434202402_item	3558699	et	3	main
taotleb	doc_842434202402_item	3558698	et	3	main
taotlusele	doc_842434202402_item	3558700	et	4	main
lisatud	doc_842434202402_item	3558701	et	4	main
dokumentidele	doc_842434202402_item	3558702	et	3	main
kohta	doc_842434202402_item	3558703	et	4	main
allkiri	doc_842434202402_item	3558708	et	3	main
ida-viru	doc_842434202402_item	3558711	et	4	main
valdlinn	doc_842434202402_item	3558714	et	3	main
taotlus	doc_842434202402_item	3558718	et	4	main
krooni	doc_842434202402_item	3558723	et	4	main
krooni	doc_842434202402_item	3558726	et	4	main
pikaajalist	doc_842434202402_item	3558727	et	4	main
omega	doc_842434202402_item	3558730	et	4	main
hakkab	doc_842434202402_item	3558735	et	3	main
puitdetaile	doc_842434202402_item	3558738	et	3	main
on	doc_842434202402_item	3558740	et	4	main
vaja	doc_842434202402_item	3558741	et	4	main
uue	doc_842434202402_item	3558742	et	3	main
umbes	doc_842434202402_item	3558754	et	4	main
allkiri	doc_842434202402_item	3558771	et	3	main
seletuskiri	doc_842434202396_item	3558773	et	3	main
00	doc_842434202396_item	3558783	et	2	main
toimus	doc_842434202396_item	3558787	et	3	main
see	doc_842434202396_item	3558789	et	3	main
mees	doc_842434202396_item	3558796	et	4	main
mustad	doc_842434202396_item	3558803	et	4	main
teda	doc_842434202396_item	3558825	et	4	main
ümbes	doc_842434202396_item	3558833	et	4	main
ja	doc_842434202396_item	3558838	et	3	main
iseloomuga	doc_842434202396_item	3558840	et	3	main
kõik	doc_842434202396_item	3558852	et	4	main
mees	doc_842434202396_item	3558856	et	4	main
aga	doc_842434202396_item	3558859	et	3	main
koos	doc_842434202396_item	3558862	et	4	main
juhuslik	doc_973441205350_item	3558871	et	3	main
65	doc_973441205350_item	3558873	et	2	main
internetis	doc_973441205350_item	3558884	et	4	main
oli	doc_973441205350_item	3558885	et	3	main
infot	doc_973441205350_item	3558887	et	3	main
mul	doc_973441205350_item	3558889	et	3	main
kestab	doc_973441205350_item	3558901	et	4	main
tahtnud	doc_973441205350_item	3558912	et	4	main
junnil	doc_973441205350_item	3558918	et	3	main
tahavad	doc_973441205350_item	3558921	et	3	main
esinejad	doc_973441205350_item	3558936	et	4	main
õpilastele	doc_973441205350_item	3558940	et	4	main
vene	doc_973441205350_item	3558942	et	4	main
näiteks	doc_973441205350_item	3558944	et	4	main
faktor	doc_973441205350_item	3558945	et	3	main
2	doc_973441205350_item	3558946	et	2	main
tea	doc_973441205350_item	3558952	et	4	main
mitte	doc_973441205350_item	3558953	et	3	main
võib	doc_973441205350_item	3558968	et	3	main
missugused	doc_973441205350_item	3558970	et	3	main
festivalil	doc_973441205350_item	3558973	et	3	main
ööbida	doc_973441205350_item	3558979	et	3	main
teil	doc_973441205350_item	3558991	et	4	main
narva	doc_973441205347_item	3559008	et	4	main
pähklimäe	doc_973441205347_item	3559009	et	3	main
aruanne	doc_973441205347_item	3559016	et	4	main
seminar	doc_973441205347_item	3559031	et	3	main
toimus	doc_973441205347_item	3559032	et	3	main
üheksast	doc_973441205347_item	3559033	et	4	main
jaanuarist	doc_973441205347_item	3559034	et	3	main
kümnenda	doc_973441205347_item	3559035	et	3	main
veel	doc_973441205347_item	3559050	et	4	main
õpetajad	doc_973441205347_item	3559054	et	4	main
vara	doc_973441205347_item	3559062	et	4	main
tulles	doc_973441205347_item	3559064	et	4	main
me	doc_973441205347_item	3559066	et	4	main
perekonnanimi	doc_842434202396_item	3558776	et	3	main
8	doc_842434202396_item	3558779	et	2	main
kella	doc_842434202396_item	3558781	et	4	main
peatuses	doc_842434202396_item	3558794	et	4	main
purjus	doc_842434202396_item	3558795	et	3	main
jakk	doc_842434202396_item	3558801	et	3	main
ja	doc_842434202396_item	3558805	et	3	main
naistest	doc_842434202396_item	3558812	et	4	main
aga	doc_842434202396_item	3558813	et	3	main
naine	doc_842434202396_item	3558814	et	3	main
hakkas	doc_842434202396_item	3558815	et	3	main
vastu	doc_842434202396_item	3558816	et	3	main
ja	doc_842434202396_item	3558817	et	3	main
löös	doc_842434202396_item	3558818	et	4	main
teda	doc_842434202396_item	3558819	et	4	main
pikali	doc_842434202396_item	3558820	et	3	main
seda	doc_842434202396_item	3558822	et	3	main
naine	doc_842434202396_item	3558823	et	3	main
hakkas	doc_842434202396_item	3558824	et	3	main
pärast	doc_842434202396_item	3558821	et	4	main
kirjeldus	doc_842434202396_item	3558831	et	4	main
pikka	doc_842434202396_item	3558836	et	4	main
oli	doc_842434202396_item	3558842	et	3	main
oma	doc_842434202396_item	3558863	et	4	main
kottiga	doc_842434202396_item	3558865	et	4	main
allkiri	doc_842434202396_item	3558866	et	3	main
as	doc_973441205350_item	3558868	et	4	main
21006	doc_973441205350_item	3558874	et	2	main
vähe	doc_973441205350_item	3558886	et	3	main
on	doc_973441205350_item	3558890	et	4	main
mõned	doc_973441205350_item	3558891	et	3	main
küsimused	doc_973441205350_item	3558892	et	4	main
tahan	doc_973441205350_item	3558893	et	3	main
teada	doc_973441205350_item	3558894	et	3	main
millal	doc_973441205350_item	3558895	et	3	main
festival	doc_973441205350_item	3558896	et	3	main
algab	doc_973441205350_item	3558897	et	3	main
kaua	doc_973441205350_item	3558900	et	3	main
viimane	doc_973441205350_item	3558904	et	3	main
ja	doc_973441205350_item	3558909	et	3	main
me	doc_973441205350_item	3558910	et	4	main
sõita	doc_973441205350_item	3558913	et	3	main
varem	doc_973441205350_item	3558915	et	4	main
teada	doc_973441205350_item	3558922	et	3	main
muusikastiilid	doc_973441205350_item	3558924	et	3	main
hop	doc_973441205350_item	3558931	et	4	main
festivali	doc_973441205350_item	3558938	et	4	main
meeldivad	doc_973441205350_item	3558941	et	4	main
lauljad	doc_973441205350_item	3558943	et	4	main
klassis	doc_973441205350_item	3558957	et	3	main
vanus	doc_842434202396_item	3558832	et	4	main
kasvuga	doc_842434202396_item	3558837	et	3	main
ümbes	doc_842434202396_item	3558843	et	4	main
ja	doc_842434202396_item	3558846	et	3	main
hästi	doc_842434202396_item	3558855	et	3	main
terveks	doc_842434202396_item	3558858	et	4	main
eesti	doc_973441205350_item	3558869	et	4	main
järelepäremine	doc_973441205350_item	3558876	et	4	main
lugesin	doc_973441205350_item	3558877	et	3	main
internetist	doc_973441205350_item	3558878	et	4	main
8	doc_973441205350_item	3558880	et	2	main
mail	doc_973441205350_item	3558881	et	4	main
toimub	doc_973441205350_item	3558882	et	3	main
muusikafestival	doc_973441205350_item	3558883	et	3	main
ja	doc_973441205350_item	3558898	et	3	main
ei	doc_973441205350_item	3558911	et	4	main
millised	doc_973441205350_item	3558923	et	3	main
õpilastele	doc_973441205350_item	3558927	et	4	main
meeldib	doc_973441205350_item	3558928	et	3	main
rock	doc_973441205350_item	3558934	et	4	main
millised	doc_973441205350_item	3558935	et	3	main
piletiostamisest	doc_973441205350_item	3558955	et	4	main
minu	doc_973441205350_item	3558956	et	3	main
soodustused	doc_973441205350_item	3558971	et	4	main
kus	doc_973441205350_item	3558976	et	3	main
see	doc_973441205350_item	3558982	et	3	main
peab	doc_973441205350_item	3558983	et	4	main
odavam	doc_973441205350_item	3558985	et	4	main
mulle	doc_973441205350_item	3558996	et	4	main
minu	doc_973441205350_item	3558997	et	3	main
aruanne	doc_973441205347_item	3559007	et	4	main
pr	doc_973441205347_item	3559013	et	4	main
eesnimi	doc_973441205347_item	3559014	et	3	main
perekonnanimi	doc_973441205347_item	3559015	et	3	main
10	doc_973441205347_item	3559020	et	2	main
jaanuarini	doc_973441205347_item	3559036	et	3	main
mõeldud	doc_973441205347_item	3559040	et	4	main
meie	doc_973441205347_item	3559051	et	4	main
ja	doc_973441205347_item	3559055	et	3	main
me	doc_973441205347_item	3559057	et	4	main
jõhvisse	doc_973441205347_item	3559059	et	3	main
jaanuaril	doc_973441205347_item	3559061	et	3	main
pakuti	doc_973441205347_item	3559071	et	3	main
el	doc_973441205347_item	3559072	et	4	main
projektide	doc_973441205347_item	3559074	et	3	main
24102006	doc_973441205347_item	3559143	et	2	main
aruanne	doc_973441205346_item	3559144	et	4	main
matemaatika	doc_973441205346_item	3559151	et	4	main
perekonnanimi	doc_973441205346_item	3559156	et	3	main
klassi	doc_973441205346_item	3559158	et	4	main
pähklimäe	doc_973441205346_item	3559159	et	3	main
gümnaasiumi	doc_973441205346_item	3559160	et	4	main
õpilane	doc_973441205346_item	3559161	et	3	main
viibisin	doc_973441205346_item	3559162	et	3	main
seminar	doc_973441205346_item	3559170	et	3	main
üldhariduskoolidele	doc_973441205346_item	3559180	et	3	main
esitasid	doc_973441205346_item	3559183	et	4	main
mina	doc_973441205346_item	3559184	et	4	main
kui	doc_973441205346_item	3559185	et	3	main
kell	doc_973441205346_item	3559202	et	3	main
tulles	doc_973441205346_item	3559204	et	4	main
kohale	doc_973441205346_item	3559205	et	4	main
kell	doc_973441205346_item	3559211	et	3	main
õppekeelega	doc_973441205346_item	3559215	et	3	main
projektide	doc_973441205346_item	3559217	et	3	main
viieteistkümnest	doc_973441205346_item	3559229	et	3	main
me	doc_973441205346_item	3559264	et	4	main
väga	doc_973441205346_item	3559277	et	3	main
ma	doc_973441205346_item	3559280	et	3	main
ja	doc_973441205346_item	3559293	et	3	main
õpetajatele	doc_973441205346_item	3559294	et	4	main
edastama	doc_973441205346_item	3559295	et	3	main
sellega	doc_973441205346_item	3559296	et	3	main
keele	doc_973441205345_item	3559312	et	4	main
perekonnanimi	doc_973441205345_item	3559317	et	3	main
seminaril	doc_973441205345_item	3559327	et	3	main
teile	doc_973441205345_item	3559330	et	4	main
keele	doc_973441205345_item	3559358	et	4	main
kooli	doc_973441205345_item	3559364	et	4	main
üksteist	doc_973441205345_item	3559373	et	4	main
end	doc_973441205345_item	3559377	et	4	main
me	doc_973441205347_item	3559111	et	4	main
sõitsime	doc_973441205347_item	3559112	et	3	main
koju	doc_973441205347_item	3559113	et	3	main
see	doc_973441205347_item	3559114	et	3	main
seminar	doc_973441205347_item	3559115	et	3	main
mulle	doc_973441205347_item	3559116	et	4	main
oli	doc_973441205347_item	3559117	et	3	main
väga	doc_973441205347_item	3559118	et	3	main
kasulik	doc_973441205347_item	3559119	et	3	main
sest	doc_973441205347_item	3559120	et	4	main
ma	doc_973441205347_item	3559121	et	3	main
sain	doc_973441205347_item	3559122	et	3	main
teadma	doc_973441205347_item	3559123	et	3	main
palju	doc_973441205347_item	3559124	et	4	main
uut	doc_973441205347_item	3559125	et	3	main
ma	doc_973441205347_item	3559126	et	3	main
järelpärimine	doc_973441205350_item	3558867	et	3	main
mnt	doc_973441205350_item	3558872	et	4	main
ja	doc_973441205350_item	3558888	et	3	main
meil	doc_973441205350_item	3558902	et	4	main
on	doc_973441205350_item	3558903	et	4	main
koolipäev	doc_973441205350_item	3558905	et	3	main
on	doc_973441205350_item	3558906	et	4	main
festivali	doc_973441205350_item	3558914	et	4	main
kui	doc_973441205350_item	3558916	et	3	main
õpilased	doc_973441205350_item	3558920	et	3	main
festivalil	doc_973441205350_item	3558926	et	3	main
ja	doc_973441205350_item	3558932	et	3	main
hard	doc_973441205350_item	3558933	et	4	main
minu	doc_973441205350_item	3558939	et	3	main
hi	doc_973441205350_item	3558948	et	4	main
fi	doc_973441205350_item	3558949	et	4	main
ma	doc_973441205350_item	3558950	et	3	main
ei	doc_973441205350_item	3558951	et	4	main
on	doc_973441205350_item	3558958	et	4	main
kakskümmend	doc_973441205350_item	3558959	et	4	main
viis	doc_973441205350_item	3558960	et	4	main
õpilast	doc_973441205350_item	3558961	et	4	main
tahan	doc_973441205350_item	3558962	et	3	main
teada	doc_973441205350_item	3558963	et	3	main
kas	doc_973441205350_item	3558964	et	3	main
võin	doc_973441205350_item	3558965	et	3	main
broneerida	doc_973441205350_item	3558966	et	3	main
piletid	doc_973441205350_item	3558967	et	3	main
olla	doc_973441205350_item	3558969	et	3	main
on	doc_973441205350_item	3558974	et	4	main
me	doc_973441205350_item	3558977	et	4	main
arvan	doc_973441205350_item	3558980	et	3	main
on	doc_973441205350_item	3558999	et	4	main
suur	doc_973441205350_item	3559001	et	3	main
eest	doc_973441205350_item	3559004	et	4	main
perekonnanimi	doc_973441205347_item	3559019	et	3	main
õpilane	doc_973441205347_item	3559022	et	3	main
seminaril	doc_973441205347_item	3559025	et	3	main
seminar	doc_973441205347_item	3559038	et	3	main
esimees	doc_973441205347_item	3559049	et	4	main
hommikul	doc_973441205347_item	3559063	et	3	main
registreerusime	doc_973441205347_item	3559068	et	3	main
2004	doc_973441205347_item	3559083	et	2	main
perekonnanimi	doc_973441205347_item	3559142	et	3	main
gümnaasiumi	doc_973441205346_item	3559150	et	4	main
eesnimi	doc_973441205346_item	3559155	et	3	main
kahepäevasel	doc_973441205346_item	3559167	et	4	main
seminaril	doc_973441205346_item	3559168	et	3	main
jõhvis	doc_973441205346_item	3559176	et	3	main
oli	doc_973441205346_item	3559178	et	3	main
meie	doc_973441205346_item	3559181	et	4	main
kooli	doc_973441205346_item	3559186	et	4	main
omavalitsuse	doc_973441205346_item	3559187	et	3	main
keele	doc_973441205346_item	3559192	et	4	main
ja	doc_973441205346_item	3559194	et	3	main
me	doc_973441205346_item	3559198	et	4	main
saabusime	doc_973441205346_item	3559199	et	3	main
jõhvisse	doc_973441205346_item	3559200	et	3	main
9jaanuaril	doc_973441205346_item	3559201	et	3	main
kümme	doc_973441205346_item	3559203	et	3	main
1130	doc_973441205346_item	3559212	et	2	main
pärast	doc_973441205346_item	3559219	et	4	main
võimalikke	doc_973441205346_item	3559226	et	3	main
projekte	doc_973441205346_item	3559227	et	3	main
kaheksateistkümneni	doc_973441205346_item	3559231	et	4	main
töötasime	doc_973441205346_item	3559233	et	3	main
võimaliku	doc_973441205346_item	3559235	et	3	main
projektiga	doc_973441205346_item	3559236	et	4	main
pärast	doc_973441205346_item	3559237	et	4	main
oli	doc_973441205346_item	3559238	et	3	main
õhtusöök	doc_973441205346_item	3559239	et	3	main
ja	doc_973441205346_item	3559240	et	3	main
koht	doc_973441205350_item	3558975	et	3	main
et	doc_973441205350_item	3558981	et	3	main
on	doc_973441205350_item	3558992	et	4	main
lisainfo	doc_973441205350_item	3558993	et	4	main
siis	doc_973441205350_item	3558994	et	3	main
helistage	doc_973441205350_item	3558995	et	3	main
00000	doc_973441205350_item	3559000	et	2	main
info	doc_973441205350_item	3559003	et	4	main
head	doc_973441205350_item	3559005	et	4	main
aega	doc_973441205350_item	3559006	et	4	main
matemaatika	doc_973441205347_item	3559011	et	4	main
õpetaja	doc_973441205347_item	3559012	et	4	main
eesnimi	doc_973441205347_item	3559018	et	3	main
selle	doc_973441205347_item	3559026	et	4	main
poolaasta	doc_973441205347_item	3559027	et	4	main
esimesel	doc_973441205347_item	3559028	et	3	main
nädalalõpul	doc_973441205347_item	3559029	et	3	main
see	doc_973441205347_item	3559030	et	3	main
oli	doc_973441205347_item	3559039	et	3	main
ja	doc_973441205347_item	3559042	et	3	main
olin	doc_973441205347_item	3559044	et	3	main
kooli	doc_973441205347_item	3559052	et	4	main
huvijuhid	doc_973441205347_item	3559056	et	3	main
saabusime	doc_973441205347_item	3559058	et	3	main
9	doc_973441205347_item	3559060	et	2	main
meile	doc_973441205347_item	3559070	et	4	main
me	doc_973441205347_item	3559081	et	4	main
arutasime	doc_973441205347_item	3559082	et	3	main
arvan	doc_973441205347_item	3559127	et	3	main
peaks	doc_973441205347_item	3559131	et	4	main
igale	doc_973441205347_item	3559132	et	3	main
ma	doc_973441205347_item	3559136	et	3	main
oma	doc_973441205347_item	3559138	et	4	main
aruande	doc_973441205347_item	3559139	et	4	main
lugupidamisega	doc_973441205347_item	3559140	et	3	main
eesnimi	doc_973441205347_item	3559141	et	3	main
pr	doc_973441205346_item	3559145	et	4	main
eesnimi	doc_973441205346_item	3559146	et	3	main
perekonnanimi	doc_973441205346_item	3559147	et	3	main
aruanne	doc_973441205346_item	3559153	et	4	main
10a	doc_973441205346_item	3559157	et	4	main
üheksandal	doc_973441205346_item	3559172	et	3	main
seminar	doc_973441205346_item	3559177	et	3	main
mõeldud	doc_973441205346_item	3559179	et	4	main
eesnimi	doc_973441205346_item	3559196	et	3	main
perekonnanimi	doc_973441205346_item	3559197	et	3	main
juba	doc_973441205346_item	3559210	et	3	main
aasta	doc_973441205346_item	3559225	et	4	main
kella	doc_973441205346_item	3559230	et	4	main
me	doc_973441205346_item	3559232	et	4	main
rühmas	doc_973441205346_item	3559234	et	4	main
kell	doc_973441205346_item	3559262	et	3	main
võtsime	doc_973441205346_item	3559265	et	3	main
sõitsime	doc_973441205346_item	3559270	et	3	main
oli	doc_973441205346_item	3559274	et	3	main
kasulik	doc_973441205346_item	3559278	et	3	main
sest	doc_973441205346_item	3559279	et	4	main
teadma	doc_973441205346_item	3559282	et	3	main
uut	doc_973441205346_item	3559284	et	3	main
mina	doc_973441205346_item	3559285	et	4	main
arvan	doc_973441205346_item	3559286	et	3	main
et	doc_973441205346_item	3559287	et	3	main
ma	doc_973441205346_item	3559297	et	3	main
lõpetan	doc_973441205346_item	3559298	et	3	main
oma	doc_973441205346_item	3559299	et	4	main
aruanne	doc_973441205345_item	3559304	et	4	main
eesnimi	doc_973441205345_item	3559306	et	3	main
eesti	doc_973441205345_item	3559311	et	4	main
aruanne	doc_973441205345_item	3559314	et	4	main
eesnimi	doc_973441205345_item	3559316	et	3	main
kümnenda	doc_973441205345_item	3559318	et	3	main
kirjutada	doc_973441205345_item	3559329	et	3	main
sellest	doc_973441205345_item	3559331	et	4	main
ida	doc_973441205345_item	3559346	et	4	main
meie	doc_973441205345_item	3559349	et	4	main
mina	doc_973441205345_item	3559352	et	4	main
kooli	doc_973441205345_item	3559354	et	4	main
eesnimi	doc_973441205345_item	3559360	et	3	main
umbes	doc_973441205345_item	3559371	et	4	main
kell	doc_973441205345_item	3559372	et	3	main
1600	doc_973441205345_item	3559426	et	2	main
see	doc_973441205345_item	3559432	et	3	main
minule	doc_973441205345_item	3559437	et	3	main
magada	doc_973441205350_item	3558987	et	3	main
linnas	doc_973441205350_item	3558988	et	4	main
hotellis	doc_973441205350_item	3558989	et	3	main
kui	doc_973441205350_item	3558990	et	3	main
telefoninumber	doc_973441205350_item	3558998	et	3	main
aitäh	doc_973441205350_item	3559002	et	3	main
gumnaasiumi	doc_973441205347_item	3559010	et	4	main
mina	doc_973441205347_item	3559017	et	4	main
klassi	doc_973441205347_item	3559021	et	4	main
viibisin	doc_973441205347_item	3559023	et	3	main
kahepäevasel	doc_973441205347_item	3559024	et	4	main
jõhvis	doc_973441205347_item	3559037	et	3	main
üldhariduskoolidele	doc_973441205347_item	3559041	et	3	main
ma	doc_973441205347_item	3559043	et	3	main
seal	doc_973441205347_item	3559045	et	4	main
kui	doc_973441205347_item	3559046	et	3	main
kooli	doc_973441205347_item	3559047	et	4	main
omavalitsuse	doc_973441205347_item	3559048	et	3	main
esitasid	doc_973441205347_item	3559053	et	4	main
kohale	doc_973441205347_item	3559065	et	4	main
kohe	doc_973441205347_item	3559067	et	4	main
phare	doc_973441205347_item	3559073	et	4	main
vene	doc_973441205347_item	3559075	et	4	main
õppekeelega	doc_973441205347_item	3559076	et	3	main
koolidele	doc_973441205347_item	3559077	et	3	main
ülevaate	doc_973441205347_item	3559078	et	4	main
kell	doc_973441205347_item	3559079	et	3	main
1300	doc_973441205347_item	3559080	et	2	main
saadud	doc_973441205347_item	3559129	et	4	main
lõpetan	doc_973441205347_item	3559137	et	3	main
õpetaja	doc_973441205346_item	3559152	et	4	main
mina	doc_973441205346_item	3559154	et	4	main
toimus	doc_973441205346_item	3559171	et	3	main
kümnendal	doc_973441205346_item	3559174	et	3	main
kooli	doc_973441205346_item	3559182	et	4	main
eesti	doc_973441205346_item	3559191	et	4	main
õpetaja	doc_973441205346_item	3559193	et	4	main
huvijuht	doc_973441205346_item	3559195	et	3	main
end	doc_973441205346_item	3559208	et	4	main
ja	doc_973441205346_item	3559209	et	3	main
vene	doc_973441205346_item	3559214	et	4	main
koolidele	doc_973441205346_item	3559216	et	3	main
ülevaade	doc_973441205346_item	3559218	et	3	main
ülevaade	doc_973441205346_item	3559220	et	3	main
me	doc_973441205346_item	3559222	et	4	main
arutasime	doc_973441205346_item	3559223	et	3	main
2004	doc_973441205346_item	3559224	et	2	main
seminari	doc_973441205346_item	3559266	et	4	main
kokku	doc_973441205346_item	3559267	et	3	main
ja	doc_973441205346_item	3559268	et	3	main
see	doc_973441205346_item	3559272	et	3	main
minu	doc_973441205346_item	3559275	et	3	main
sain	doc_973441205346_item	3559281	et	3	main
õpilastele	doc_973441205346_item	3559292	et	4	main
perekonnanimi	doc_973441205346_item	3559303	et	3	main
gümnaasiumi	doc_973441205345_item	3559310	et	4	main
mina	doc_973441205345_item	3559315	et	4	main
klassi	doc_973441205345_item	3559319	et	4	main
õpilane	doc_973441205345_item	3559320	et	3	main
viibisin	doc_973441205345_item	3559321	et	3	main
selle	doc_973441205345_item	3559322	et	4	main
viru	doc_973441205345_item	3559347	et	4	main
esitasid	doc_973441205345_item	3559351	et	4	main
kohale	doc_973441205345_item	3559370	et	4	main
juba	doc_973441205345_item	3559375	et	3	main
registreerised	doc_973441205345_item	3559376	et	4	main
pärast	doc_973441205345_item	3559427	et	4	main
seminar	doc_973441205345_item	3559433	et	3	main
väga	doc_973441205345_item	3559435	et	3	main
teada	doc_973441205345_item	3559442	et	3	main
omavalitsuste	doc_973441205345_item	3559447	et	3	main
et	doc_973441205345_item	3559454	et	3	main
ülejäänud	doc_973441205345_item	3559459	et	4	main
meie	doc_973441205345_item	3559460	et	4	main
pr	doc_973441205344_item	3559481	et	4	main
aruanne	doc_973441205344_item	3559487	et	4	main
õpilane	doc_973441205344_item	3559491	et	3	main
osa	doc_973441205344_item	3559493	et	4	main
kahepäevasest	doc_973441205344_item	3559494	et	4	main
võtjad	doc_973441205344_item	3559506	et	4	main
jaanuaril	doc_973441205344_item	3559519	et	3	main
ja	doc_973441205347_item	3559069	et	3	main
aasta	doc_973441205347_item	3559084	et	4	main
võimalikke	doc_973441205347_item	3559085	et	3	main
projekte	doc_973441205347_item	3559086	et	3	main
edasi	doc_973441205347_item	3559087	et	3	main
meil	doc_973441205347_item	3559088	et	4	main
oli	doc_973441205347_item	3559089	et	3	main
rühmatöö	doc_973441205347_item	3559090	et	4	main
10	doc_973441205347_item	3559091	et	2	main
jaanuaril	doc_973441205347_item	3559092	et	3	main
me	doc_973441205347_item	3559093	et	4	main
tegime	doc_973441205347_item	3559094	et	3	main
mitmesuguseid	doc_973441205347_item	3559095	et	3	main
kokkuvõtteid	doc_973441205347_item	3559096	et	3	main
rühmatööst	doc_973441205347_item	3559097	et	3	main
kell	doc_973441205347_item	3559098	et	3	main
1300	doc_973441205347_item	3559099	et	2	main
esinesid	doc_973441205347_item	3559100	et	4	main
vabariiklike	doc_973441205347_item	3559101	et	3	main
ajalehtede	doc_973441205347_item	3559102	et	4	main
ajakirjanikud	doc_973441205347_item	3559103	et	3	main
pärast	doc_973441205347_item	3559104	et	4	main
meil	doc_973441205347_item	3559105	et	4	main
seminari	doc_973441205347_item	3559107	et	4	main
kokkuvõte	doc_973441205347_item	3559108	et	3	main
oli	doc_973441205347_item	3559106	et	3	main
ja	doc_973441205347_item	3559109	et	3	main
õhtul	doc_973441205347_item	3559110	et	3	main
et	doc_973441205347_item	3559128	et	3	main
infot	doc_973441205347_item	3559130	et	3	main
õpilasele	doc_973441205347_item	3559133	et	3	main
edastama	doc_973441205347_item	3559134	et	3	main
sellega	doc_973441205347_item	3559135	et	3	main
narva	doc_973441205346_item	3559148	et	4	main
pähklimäe	doc_973441205346_item	3559149	et	3	main
selle	doc_973441205346_item	3559163	et	4	main
esimesel	doc_973441205346_item	3559165	et	3	main
poolaasta	doc_973441205346_item	3559164	et	4	main
nädalalõpul	doc_973441205346_item	3559166	et	3	main
see	doc_973441205346_item	3559169	et	3	main
ja	doc_973441205346_item	3559173	et	3	main
jaanuaril	doc_973441205346_item	3559175	et	3	main
esimees	doc_973441205346_item	3559188	et	4	main
eesnimi	doc_973441205346_item	3559189	et	3	main
perekonnanimi	doc_973441205346_item	3559190	et	3	main
me	doc_973441205346_item	3559206	et	4	main
registreerisime	doc_973441205346_item	3559207	et	3	main
algas	doc_973441205346_item	3559213	et	3	main
lõpetamist	doc_973441205346_item	3559221	et	4	main
kella	doc_973441205346_item	3559228	et	4	main
jaoks	doc_973441205346_item	3559276	et	4	main
palju	doc_973441205346_item	3559283	et	4	main
saadud	doc_973441205346_item	3559288	et	4	main
infot	doc_973441205346_item	3559289	et	3	main
aruande	doc_973441205346_item	3559300	et	4	main
lugupidamisega	doc_973441205346_item	3559301	et	3	main
õpetaja	doc_973441205345_item	3559313	et	4	main
üritusest	doc_973441205345_item	3559332	et	4	main
seminar	doc_973441205345_item	3559333	et	3	main
toimus	doc_973441205345_item	3559334	et	3	main
jõhvis	doc_973441205345_item	3559335	et	3	main
üheksandast	doc_973441205345_item	3559336	et	3	main
kümnenda	doc_973441205345_item	3559337	et	3	main
jaanuarini	doc_973441205345_item	3559338	et	3	main
see	doc_973441205345_item	3559339	et	3	main
mõeldud	doc_973441205345_item	3559340	et	4	main
üldhariduskoolidele	doc_973441205345_item	3559341	et	3	main
seminar	doc_973441205345_item	3559342	et	3	main
oli	doc_973441205345_item	3559343	et	3	main
läbi	doc_973441205345_item	3559344	et	4	main
maavalitsusena	doc_973441205345_item	3559348	et	3	main
omavalitsuse	doc_973441205345_item	3559355	et	3	main
esimees	doc_973441205345_item	3559356	et	4	main
eesti	doc_973441205345_item	3559357	et	4	main
perekonnanimi	doc_973441205345_item	3559361	et	3	main
ja	doc_973441205345_item	3559362	et	3	main
seminar	doc_973441205345_item	3559423	et	3	main
sest	doc_973441205345_item	3559438	et	4	main
sain	doc_973441205345_item	3559440	et	3	main
palju	doc_973441205345_item	3559443	et	4	main
huvitavaid	doc_973441205345_item	3559451	et	4	main
projekte	doc_973441205345_item	3559452	et	3	main
kooli	doc_973441205345_item	3559461	et	4	main
omavalitsuse	doc_973441205345_item	3559462	et	3	main
lõpetuseks	doc_973441205345_item	3559464	et	4	main
tahan	doc_973441205345_item	3559465	et	3	main
aruanne	doc_973441205344_item	3559480	et	4	main
kümnenda	doc_973441205344_item	3559489	et	3	main
seminarist	doc_973441205344_item	3559495	et	4	main
see	doc_973441205344_item	3559496	et	3	main
seminar	doc_973441205344_item	3559497	et	3	main
toimus	doc_973441205344_item	3559498	et	3	main
jõhvis	doc_973441205344_item	3559499	et	3	main
üheksandast	doc_973441205344_item	3559500	et	3	main
kümnenda	doc_973441205344_item	3559501	et	3	main
jaanuarini	doc_973441205344_item	3559502	et	3	main
olid	doc_973441205344_item	3559507	et	4	main
üheksandal	doc_973441205344_item	3559518	et	3	main
phare	doc_973441205344_item	3559530	et	4	main
projekte	doc_973441205344_item	3559531	et	3	main
õppekeelega	doc_973441205344_item	3559533	et	3	main
rühmas	doc_973441205344_item	3559537	et	4	main
seda	doc_973441205344_item	3559539	et	3	main
me	doc_973441205344_item	3559548	et	4	main
võttame	doc_973441205344_item	3559549	et	4	main
kokku	doc_973441205344_item	3559550	et	3	main
rühmatööst	doc_973441205344_item	3559551	et	3	main
pärast	doc_973441205344_item	3559554	et	4	main
toimus	doc_973441205344_item	3559555	et	3	main
4	doc_973441205338_item	3559607	et	2	main
kuulutuse	doc_973441205338_item	3559615	et	4	main
et	doc_973441205338_item	3559616	et	3	main
sellel	doc_973441205338_item	3559617	et	4	main
suvel	doc_973441205338_item	3559618	et	3	main
toimub	doc_973441205338_item	3559619	et	3	main
jazz	doc_973441205338_item	3559620	et	4	main
see	doc_973441205338_item	3559638	et	3	main
vabaaeg	doc_973441205346_item	3559241	et	3	main
teine	doc_973441205346_item	3559242	et	3	main
päev	doc_973441205346_item	3559243	et	3	main
algas	doc_973441205346_item	3559244	et	3	main
kell	doc_973441205346_item	3559245	et	3	main
kümme	doc_973441205346_item	3559246	et	3	main
rühmatööst	doc_973441205346_item	3559247	et	3	main
kokkuvõttetest	doc_973441205346_item	3559248	et	3	main
ja	doc_973441205346_item	3559249	et	3	main
tagasisidest	doc_973441205346_item	3559250	et	4	main
kella	doc_973441205346_item	3559251	et	4	main
kolmteist	doc_973441205346_item	3559252	et	4	main
kella	doc_973441205346_item	3559253	et	4	main
viieteistkümneni	doc_973441205346_item	3559254	et	4	main
igal	doc_973441205346_item	3559255	et	3	main
vabariiklike	doc_973441205346_item	3559256	et	3	main
ajalehtede	doc_973441205346_item	3559257	et	4	main
ajakirjanikul	doc_973441205346_item	3559258	et	3	main
oli	doc_973441205346_item	3559259	et	3	main
võimalus	doc_973441205346_item	3559260	et	3	main
esineda	doc_973441205346_item	3559261	et	3	main
1500	doc_973441205346_item	3559263	et	2	main
õhtul	doc_973441205346_item	3559269	et	3	main
koju	doc_973441205346_item	3559271	et	3	main
seminar	doc_973441205346_item	3559273	et	3	main
peaks	doc_973441205346_item	3559290	et	4	main
igale	doc_973441205346_item	3559291	et	3	main
eesnimi	doc_973441205346_item	3559302	et	3	main
öelda	doc_973441205345_item	3559466	et	4	main
et	doc_973441205345_item	3559467	et	3	main
meie	doc_973441205345_item	3559468	et	4	main
kooli	doc_973441205345_item	3559469	et	4	main
esitajad	doc_973441205345_item	3559470	et	4	main
peavad	doc_973441205345_item	3559471	et	4	main
osalema	doc_973441205345_item	3559472	et	3	main
niisugustel	doc_973441205345_item	3559473	et	3	main
üritustel	doc_973441205345_item	3559474	et	4	main
tulevikus	doc_973441205345_item	3559475	et	4	main
ka	doc_973441205345_item	3559476	et	3	main
24102006	doc_973441205345_item	3559477	et	2	main
eesnimi	doc_973441205345_item	3559478	et	3	main
perekonnanimi	doc_973441205345_item	3559479	et	3	main
pr	doc_973441205345_item	3559305	et	4	main
perekonnanimi	doc_973441205345_item	3559307	et	3	main
narva	doc_973441205345_item	3559308	et	4	main
pähklimäe	doc_973441205345_item	3559309	et	3	main
poolaasta	doc_973441205345_item	3559323	et	4	main
esimesel	doc_973441205345_item	3559324	et	3	main
nädalalõpul	doc_973441205345_item	3559325	et	3	main
kahepäevasel	doc_973441205345_item	3559326	et	4	main
tahan	doc_973441205345_item	3559328	et	3	main
viidud	doc_973441205345_item	3559345	et	4	main
kooli	doc_973441205345_item	3559350	et	4	main
kui	doc_973441205345_item	3559353	et	3	main
õpetaja	doc_973441205345_item	3559359	et	4	main
meie	doc_973441205345_item	3559363	et	4	main
huvijuht	doc_973441205345_item	3559365	et	3	main
eesnimi	doc_973441205345_item	3559366	et	3	main
perekonnanimi	doc_973441205345_item	3559367	et	3	main
meie	doc_973441205345_item	3559368	et	4	main
saabusime	doc_973441205345_item	3559369	et	3	main
osavõtjad	doc_973441205345_item	3559374	et	3	main
meil	doc_973441205345_item	3559378	et	4	main
tuli	doc_973441205345_item	3559379	et	4	main
natuke	doc_973441205345_item	3559380	et	4	main
kiirustada	doc_973441205345_item	3559381	et	3	main
et	doc_973441205345_item	3559382	et	3	main
jõuda	doc_973441205345_item	3559383	et	3	main
projektide	doc_973441205345_item	3559384	et	3	main
ülevaateks	doc_973441205345_item	3559385	et	3	main
el	doc_973441205345_item	3559386	et	4	main
phare	doc_973441205345_item	3559387	et	4	main
projektide	doc_973441205345_item	3559388	et	3	main
vene	doc_973441205345_item	3559389	et	4	main
õppekeelega	doc_973441205345_item	3559390	et	3	main
koolidele	doc_973441205345_item	3559391	et	3	main
ülevaade	doc_973441205345_item	3559392	et	3	main
alustati	doc_973441205345_item	3559393	et	4	main
kohe	doc_973441205345_item	3559394	et	4	main
pärast	doc_973441205345_item	3559395	et	4	main
registreerimist	doc_973441205345_item	3559396	et	4	main
seminar	doc_973441205345_item	3559397	et	3	main
jatkus	doc_973441205345_item	3559398	et	4	main
rühmatööga	doc_973441205345_item	3559399	et	3	main
mille	doc_973441205345_item	3559400	et	3	main
jooksul	doc_973441205345_item	3559401	et	4	main
meie	doc_973441205345_item	3559402	et	4	main
arutasime	doc_973441205345_item	3559403	et	3	main
lõpetas	doc_973441205345_item	3559424	et	3	main
selle	doc_973441205345_item	3559428	et	4	main
kokkuvõtet	doc_973441205345_item	3559429	et	3	main
leian	doc_973441205345_item	3559430	et	3	main
et	doc_973441205345_item	3559431	et	3	main
oli	doc_973441205345_item	3559434	et	3	main
kasulik	doc_973441205345_item	3559436	et	3	main
palju	doc_973441205345_item	3559441	et	4	main
teiste	doc_973441205345_item	3559445	et	4	main
projekte	doc_973441205345_item	3559405	et	3	main
võimalikuid	doc_973441205345_item	3559404	et	4	main
teisel	doc_973441205345_item	3559406	et	4	main
päeval	doc_973441205345_item	3559407	et	3	main
oled	doc_973441205345_item	3559408	et	3	main
tehtud	doc_973441205345_item	3559409	et	4	main
rühmatööst	doc_973441205345_item	3559410	et	3	main
kokkuvõtted	doc_973441205345_item	3559411	et	3	main
kell	doc_973441205345_item	3559412	et	3	main
1300	doc_973441205345_item	3559413	et	2	main
toimus	doc_973441205345_item	3559414	et	3	main
vaba	doc_973441205345_item	3559415	et	4	main
mikrofon	doc_973441205345_item	3559416	et	3	main
kõik	doc_973441205345_item	3559417	et	4	main
soovijad	doc_973441205345_item	3559418	et	4	main
võiksid	doc_973441205345_item	3559419	et	4	main
rääkida	doc_973441205345_item	3559420	et	3	main
oma	doc_973441205345_item	3559421	et	4	main
arvamuse	doc_973441205345_item	3559422	et	3	main
kell	doc_973441205345_item	3559425	et	3	main
arutlesin	doc_973441205345_item	3559449	et	3	main
võiks	doc_973441205345_item	3559457	et	4	main
edastada	doc_973441205345_item	3559458	et	3	main
tallinna	doc_973441205344_item	3559484	et	4	main
klassijuhataja	doc_973441205344_item	3559486	et	4	main
selle	doc_973441205344_item	3559503	et	4	main
kell	doc_973441205344_item	3559520	et	3	main
siis	doc_973441205344_item	3559522	et	3	main
registreerimine	doc_973441205344_item	3559525	et	4	main
el	doc_973441205344_item	3559529	et	4	main
edaspidiseks	doc_973441205344_item	3559535	et	4	main
pärast	doc_973441205344_item	3559538	et	4	main
as	doc_973441205338_item	3559604	et	4	main
10141	doc_973441205338_item	3559608	et	2	main
70406a	doc_973441205338_item	3559610	et	4	main
ajalehest	doc_973441205338_item	3559613	et	4	main
festival	doc_973441205338_item	3559621	et	3	main
oma	doc_973441205338_item	3559625	et	4	main
atraktsioonid	doc_973441205338_item	3559648	et	3	main
ja	doc_973441205338_item	3559651	et	3	main
veel	doc_973441205338_item	3559653	et	4	main
mind	doc_973441205338_item	3559654	et	4	main
huvitab	doc_973441205338_item	3559655	et	3	main
kus	doc_973441205338_item	3559656	et	3	main
toimub	doc_973441205338_item	3559657	et	3	main
pidu	doc_973441205338_item	3559658	et	4	main
kas	doc_973441205338_item	3559659	et	3	main
või	doc_973441205338_item	3559666	et	4	main
rajakoja	doc_973441205338_item	3559667	et	3	main
seal	doc_973441205338_item	3559676	et	4	main
kas	doc_973441205338_item	3559677	et	3	main
nad	doc_973441205338_item	3559678	et	3	main
on	doc_973441205338_item	3559679	et	4	main
välismaalt	doc_973441205338_item	3559680	et	3	main
mind	doc_973441205338_item	3559686	et	4	main
huvitab	doc_973441205338_item	3559687	et	3	main
kas	doc_973441205338_item	3559688	et	3	main
toivo	doc_973441205338_item	3559689	et	4	main
gitarri	doc_973441205338_item	3559701	et	4	main
ja	doc_973441205338_item	3559702	et	3	main
festevalil	doc_973441205338_item	3559709	et	4	main
hotell	doc_973441205338_item	3559713	et	3	main
mina	doc_973441205345_item	3559439	et	4	main
uut	doc_973441205345_item	3559444	et	3	main
koolide	doc_973441205345_item	3559446	et	3	main
kohta	doc_973441205345_item	3559448	et	4	main
arvan	doc_973441205345_item	3559453	et	3	main
infot	doc_973441205345_item	3559456	et	3	main
liikmetele	doc_973441205345_item	3559463	et	3	main
perekonnanimi	doc_973441205344_item	3559483	et	3	main
kõrgkooli	doc_973441205344_item	3559485	et	4	main
klassi	doc_973441205344_item	3559490	et	4	main
seminari	doc_973441205344_item	3559504	et	4	main
osa	doc_973441205344_item	3559505	et	4	main
teised	doc_973441205344_item	3559512	et	4	main
omavalitsused	doc_973441205344_item	3559513	et	3	main
esimehed	doc_973441205344_item	3559514	et	3	main
kui	doc_973441205344_item	3559515	et	3	main
saabusime	doc_973441205344_item	3559516	et	3	main
osavõtjate	doc_973441205344_item	3559524	et	3	main
töötasime	doc_973441205344_item	3559536	et	3	main
homikul	doc_973441205344_item	3559547	et	4	main
seminar	doc_973441205344_item	3559580	et	3	main
oli	doc_973441205344_item	3559581	et	3	main
minule	doc_973441205344_item	3559582	et	3	main
kasulik	doc_973441205344_item	3559583	et	3	main
sest	doc_973441205344_item	3559584	et	4	main
kuulsin	doc_973441205344_item	3559585	et	3	main
väga	doc_973441205344_item	3559586	et	3	main
palju	doc_973441205344_item	3559587	et	4	main
vajalikke	doc_973441205344_item	3559588	et	3	main
teadmisi	doc_973441205344_item	3559589	et	4	main
arvan	doc_973441205344_item	3559590	et	3	main
et	doc_973441205344_item	3559591	et	3	main
uued	doc_973441205344_item	3559592	et	3	main
teadmised	doc_973441205344_item	3559593	et	4	main
edastan	doc_973441205344_item	3559594	et	3	main
teisele	doc_973441205344_item	3559595	et	4	main
õpetajale	doc_973441205344_item	3559596	et	4	main
ja	doc_973441205344_item	3559597	et	3	main
õpilastele	doc_973441205344_item	3559598	et	4	main
lugupidamisega	doc_973441205344_item	3559599	et	3	main
järelpärimine	doc_973441205338_item	3559603	et	3	main
lugesin	doc_973441205338_item	3559612	et	3	main
postimees	doc_973441205338_item	3559614	et	4	main
ma	doc_973441205338_item	3559622	et	3	main
on	doc_973441205338_item	3559644	et	4	main
peol	doc_973441205338_item	3559649	et	4	main
või	doc_973441205338_item	3559681	et	4	main
nad	doc_973441205338_item	3559682	et	3	main
ta	doc_973441205338_item	3559694	et	4	main
on	doc_973441205338_item	3559695	et	4	main
palju	doc_973441205345_item	3559450	et	4	main
saadud	doc_973441205345_item	3559455	et	4	main
eesnimi	doc_973441205344_item	3559600	et	3	main
perekonnanimi	doc_973441205344_item	3559601	et	3	main
24102006	doc_973441205344_item	3559602	et	2	main
eesnimi	doc_973441205344_item	3559482	et	3	main
mina	doc_973441205344_item	3559488	et	4	main
võtsin	doc_973441205344_item	3559492	et	3	main
õpetajad	doc_973441205344_item	3559508	et	4	main
huvijuhid	doc_973441205344_item	3559509	et	3	main
mina	doc_973441205344_item	3559510	et	4	main
ja	doc_973441205344_item	3559511	et	3	main
jõhvisse	doc_973441205344_item	3559517	et	3	main
toimus	doc_973441205344_item	3559523	et	3	main
vene	doc_973441205344_item	3559532	et	4	main
vara	doc_973441205344_item	3559546	et	4	main
tagasisidest	doc_973441205344_item	3559553	et	4	main
vaba	doc_973441205344_item	3559556	et	4	main
mikrofon	doc_973441205344_item	3559557	et	3	main
kus	doc_973441205344_item	3559558	et	3	main
vabariiklike	doc_973441205344_item	3559559	et	3	main
ajalehtede	doc_973441205344_item	3559560	et	4	main
ajakirjanikud	doc_973441205344_item	3559561	et	3	main
osalesid	doc_973441205344_item	3559562	et	4	main
pärast	doc_973441205344_item	3559563	et	4	main
seda	doc_973441205344_item	3559564	et	3	main
meil	doc_973441205344_item	3559565	et	4	main
oli	doc_973441205344_item	3559566	et	3	main
seminari	doc_973441205344_item	3559567	et	4	main
kokkuvõted	doc_973441205344_item	3559568	et	4	main
see	doc_973441205344_item	3559569	et	3	main
kõik	doc_973441205344_item	3559570	et	4	main
lõpes	doc_973441205344_item	3559571	et	3	main
kell	doc_973441205344_item	3559572	et	3	main
kuueteistkümnes	doc_973441205344_item	3559573	et	4	main
ja	doc_973441205344_item	3559574	et	3	main
me	doc_973441205344_item	3559575	et	4	main
väljume	doc_973441205344_item	3559576	et	3	main
jõhvist	doc_973441205344_item	3559577	et	4	main
koju	doc_973441205344_item	3559578	et	3	main
see	doc_973441205344_item	3559579	et	3	main
üksteist	doc_973441205344_item	3559521	et	4	main
pärast	doc_973441205344_item	3559526	et	4	main
me	doc_973441205344_item	3559527	et	4	main
vaatasime	doc_973441205344_item	3559528	et	3	main
koolidele	doc_973441205344_item	3559534	et	3	main
meil	doc_973441205344_item	3559540	et	4	main
oli	doc_973441205344_item	3559541	et	3	main
vaba	doc_973441205344_item	3559542	et	4	main
aeg	doc_973441205344_item	3559543	et	3	main
kümnendal	doc_973441205344_item	3559544	et	3	main
jaanuaril	doc_973441205344_item	3559545	et	3	main
ja	doc_973441205344_item	3559552	et	3	main
jazzmuusika	doc_973441205338_item	3559605	et	4	main
tallinn	doc_973441205338_item	3559609	et	4	main
järelepärimine	doc_973441205338_item	3559611	et	3	main
korraldada	doc_973441205338_item	3559624	et	3	main
toimub	doc_973441205338_item	3559640	et	3	main
missugusel	doc_973441205338_item	3559641	et	3	main
kuul	doc_973441205338_item	3559642	et	4	main
ta	doc_973441205338_item	3559643	et	4	main
niisugused	doc_973441205338_item	3559647	et	3	main
avapäeval	doc_973441205338_item	3559650	et	3	main
lõpupäeval	doc_973441205338_item	3559652	et	3	main
akadeemia	doc_973441205338_item	3559664	et	4	main
parklas	doc_973441205338_item	3559665	et	3	main
ma	doc_973441205338_item	3559670	et	3	main
tahaksin	doc_973441205338_item	3559671	et	3	main
missugused	doc_973441205338_item	3559673	et	3	main
ansamblid	doc_973441205338_item	3559675	et	3	main
gruppid	doc_973441205338_item	3559685	et	4	main
osa	doc_973441205338_item	3559693	et	4	main
esineja	doc_973441205338_item	3559697	et	4	main
eestis	doc_973441205338_item	3559698	et	3	main
toivo	doc_973441205338_item	3559699	et	4	main
mängib	doc_973441205338_item	3559700	et	3	main
veel	doc_973441205338_item	3559704	et	4	main
ma	doc_973441205338_item	3559705	et	3	main
juhuslik	doc_973441205338_item	3559606	et	3	main
sooviksin	doc_973441205338_item	3559623	et	3	main
klassi	doc_973441205338_item	3559626	et	4	main
õpilastele	doc_973441205338_item	3559627	et	4	main
reisi	doc_973441205338_item	3559628	et	4	main
festivalil	doc_973441205338_item	3559629	et	3	main
seoses	doc_973441205338_item	3559630	et	4	main
mul	doc_973441205338_item	3559631	et	3	main
on	doc_973441205338_item	3559632	et	4	main
küsimuseid	doc_973441205338_item	3559633	et	4	main
mina	doc_973441205338_item	3559634	et	4	main
tahaksin	doc_973441205338_item	3559635	et	3	main
teada	doc_973441205338_item	3559636	et	3	main
millal	doc_973441205338_item	3559637	et	3	main
pidu	doc_973441205338_item	3559639	et	4	main
toimub	doc_973441205338_item	3559646	et	3	main
on	doc_973441205338_item	3559661	et	4	main
lauluväljakul	doc_973441205338_item	3559662	et	3	main
politsei	doc_973441205338_item	3559663	et	4	main
kolmandaks	doc_973441205338_item	3559669	et	4	main
teada	doc_973441205338_item	3559672	et	3	main
on	doc_973441205338_item	3559674	et	4	main
eesti	doc_973441205338_item	3559684	et	4	main
tuntuim	doc_973441205338_item	3559696	et	4	main
kontrobassi	doc_973441205338_item	3559703	et	4	main
teada	doc_973441205338_item	3559707	et	3	main
on	doc_973441205338_item	3559710	et	4	main
missugune	doc_973441205338_item	3559712	et	3	main
kas	doc_973441205338_item	3559645	et	3	main
ta	doc_973441205338_item	3559660	et	4	main
platsil	doc_973441205338_item	3559668	et	3	main
on	doc_973441205338_item	3559683	et	4	main
unt	doc_973441205338_item	3559690	et	4	main
võttis	doc_973441205338_item	3559691	et	3	main
festevalist	doc_973441205338_item	3559692	et	4	main
tahaksin	doc_973441205338_item	3559706	et	3	main
kas	doc_973441205338_item	3559708	et	3	main
toitlustamine	doc_973441205338_item	3559711	et	4	main
te	doc_973441205338_item	3559714	et	4	main
nõute	doc_973441205338_item	3559715	et	4	main
ma	doc_973441205338_item	3559716	et	3	main
tahaksin	doc_973441205338_item	3559717	et	3	main
et	doc_973441205338_item	3559718	et	3	main
ta	doc_973441205338_item	3559719	et	4	main
asub	doc_973441205338_item	3559720	et	3	main
lähedal	doc_973441205338_item	3559721	et	4	main
toimumise	doc_973441205338_item	3559722	et	4	main
kohta	doc_973441205338_item	3559723	et	4	main
lõppuks	doc_973441205338_item	3559724	et	3	main
ma	doc_973441205338_item	3559725	et	3	main
tahaksin	doc_973441205338_item	3559726	et	3	main
teada	doc_973441205338_item	3559727	et	3	main
kui	doc_973441205338_item	3559728	et	3	main
palju	doc_973441205338_item	3559729	et	4	main
maksavad	doc_973441205338_item	3559730	et	3	main
piletid	doc_973441205338_item	3559731	et	3	main
kas	doc_973441205338_item	3559732	et	3	main
teil	doc_973441205338_item	3559733	et	4	main
on	doc_973441205338_item	3559734	et	4	main
soodustused	doc_973441205338_item	3559735	et	4	main
lastele	doc_973441205338_item	3559736	et	4	main
täisvanustele	doc_973441205338_item	3559737	et	4	main
või	doc_973441205338_item	3559738	et	4	main
grupile	doc_973441205338_item	3559739	et	3	main
loodan	doc_973441205338_item	3559740	et	3	main
et	doc_973441205338_item	3559741	et	3	main
vastate	doc_973441205338_item	3559742	et	3	main
üksikasjalikult	doc_973441205338_item	3559743	et	4	main
kõigile	doc_973441205338_item	3559744	et	4	main
minu	doc_973441205338_item	3559745	et	3	main
küsimustele	doc_973441205338_item	3559746	et	4	main
eesnimi	doc_973441205338_item	3559747	et	3	main
perekonnanimi	doc_973441205338_item	3559748	et	3	main
eesti	doc_973441205356_item	3560114	et	4	main
pikk	doc_973441205356_item	3560116	et	4	main
tänav	doc_973441205356_item	3560117	et	4	main
17	doc_973441205356_item	3560118	et	2	main
11463	doc_973441205356_item	3560119	et	2	main
valgs	doc_973441205356_item	3560128	et	4	main
toimub	doc_973441205356_item	3560129	et	3	main
muusikat	doc_973441205356_item	3560152	et	3	main
veel	doc_973441205356_item	3560153	et	4	main
ma	doc_973441205356_item	3560154	et	3	main
tahan	doc_973441205356_item	3560155	et	3	main
seal	doc_973441205356_item	3560159	et	4	main
ja	doc_973441205356_item	3560161	et	3	main
mängivad	doc_973441205356_item	3560165	et	4	main
ma	doc_973441205356_item	3560166	et	3	main
lugesin	doc_973441205356_item	3560167	et	3	main
et	doc_973441205356_item	3560168	et	3	main
see	doc_973441205356_item	3560169	et	3	main
suvefestival	doc_973441205356_item	3560170	et	3	main
toimub	doc_973441205356_item	3560171	et	3	main
viiendat	doc_973441205356_item	3560172	et	3	main
korda	doc_973441205356_item	3560173	et	4	main
ma	doc_973441205356_item	3560175	et	3	main
palju	doc_973441205356_item	3560180	et	4	main
nad	doc_973441205356_item	3560198	et	3	main
toimub	doc_973441205356_item	3560203	et	3	main
sellel	doc_973441205356_item	3560204	et	4	main
maksavad	doc_973441205356_item	3560213	et	3	main
ja	doc_973441205356_item	3560215	et	3	main
kakskümmend	doc_973441205356_item	3560222	et	4	main
ja	doc_973441205356_item	3560224	et	3	main
seal	doc_973441205356_item	3560239	et	4	main
mulle	doc_973441205356_item	3560249	et	4	main
see	doc_973441205356_item	3560251	et	3	main
muusikafestivalist	doc_973441205356_item	3560252	et	4	main
eesnimi	doc_973441205356_item	3560253	et	3	main
vana	doc_973441205356_item	3560120	et	4	main
vigala	doc_973441205356_item	3560121	et	4	main
7042006	doc_973441205356_item	3560122	et	2	main
rock	doc_973441205356_item	3560131	et	4	main
festival	doc_973441205356_item	3560132	et	3	main
ja	doc_973441205356_item	3560174	et	3	main
õpilased	doc_973441205356_item	3560184	et	3	main
algavad	doc_973441205356_item	3560193	et	4	main
õhtused	doc_973441205356_item	3560194	et	4	main
missugused	doc_973441205356_item	3560216	et	3	main
seal	doc_973441205356_item	3560218	et	4	main
teada	doc_973441205356_item	3560227	et	3	main
toitlustamine	doc_973441205356_item	3560229	et	4	main
seal	doc_973441205356_item	3560232	et	4	main
telgid	doc_973441205356_item	3560241	et	4	main
see	doc_973441205356_item	3560245	et	3	main
aadres	doc_973441205356_item	3560259	et	4	main
6	doc_973441205356_item	3560262	et	2	main
hard	doc_973441205356_item	3560130	et	4	main
ansamblid	doc_973441205356_item	3560158	et	3	main
arvan	doc_973441205356_item	3560176	et	3	main
kooli	doc_973441205356_item	3560183	et	4	main
teada	doc_973441205356_item	3560186	et	3	main
palju	doc_973441205356_item	3560188	et	4	main
seal	doc_973441205356_item	3560190	et	4	main
on	doc_973441205356_item	3560191	et	4	main
millal	doc_973441205356_item	3560192	et	3	main
ja	doc_973441205356_item	3560196	et	3	main
lõppuvad	doc_973441205356_item	3560199	et	4	main
palun	doc_973441205356_item	3560201	et	3	main
mis	doc_973441205356_item	3560202	et	4	main
ma	doc_973441205356_item	3560225	et	3	main
on	doc_973441205356_item	3560240	et	4	main
kui	doc_973441205356_item	3560243	et	3	main
perekonnanimi	doc_973441205356_item	3560254	et	3	main
tel	doc_973441205356_item	3560255	et	4	main
55	doc_973441205356_item	3560256	et	2	main
555	doc_973441205356_item	3560257	et	2	main
55	doc_973441205356_item	3560258	et	2	main
pahklimae	doc_973441205356_item	3560261	et	4	main
seletuskiri	doc_634572338236_item	3560411	et	3	main
on	doc_634572338236_item	3560419	et	4	main
perekonnanimi	doc_634572338236_item	3560421	et	3	main
30-aastat	doc_634572338236_item	3560424	et	3	main
sündmus	doc_634572338236_item	3560429	et	3	main
pargis	doc_634572338236_item	3560434	et	3	main
mees	doc_634572338236_item	3560444	et	4	main
tea	doc_634572338236_item	3560490	et	4	main
11	doc_634572338236_item	3560520	et	2	main
perekonnanimi	doc_634572338236_item	3560526	et	3	main
tere	doc_432051777919_item	3560529	et	3	main
õpetaja	doc_432051777919_item	3560530	et	4	main
on	doc_432051777919_item	3560533	et	4	main
jalutada	doc_432051777919_item	3560556	et	3	main
hästi	doc_432051777919_item	3560563	et	3	main
saksa	doc_432051777919_item	3560575	et	4	main
põhjus	doc_432051777919_item	3560578	et	4	main
miks	doc_432051777919_item	3560579	et	4	main
järelpärimine	doc_973441205356_item	3560113	et	3	main
muusika	doc_973441205356_item	3560115	et	4	main
järelepärimine	doc_973441205356_item	3560123	et	3	main
internetist	doc_973441205356_item	3560125	et	4	main
et	doc_973441205356_item	3560126	et	3	main
vana	doc_973441205356_item	3560127	et	4	main
meie	doc_973441205356_item	3560133	et	4	main
missugused	doc_973441205356_item	3560157	et	3	main
muusikastiilid	doc_973441205356_item	3560163	et	3	main
et	doc_973441205356_item	3560177	et	3	main
tahavad	doc_973441205356_item	3560185	et	3	main
kui	doc_973441205356_item	3560187	et	3	main
üritused	doc_973441205356_item	3560189	et	4	main
millal	doc_973441205356_item	3560197	et	3	main
päevasel	doc_973441205356_item	3560206	et	4	main
tahan	doc_973441205356_item	3560209	et	3	main
küsida	doc_973441205356_item	3560210	et	3	main
kui	doc_973441205356_item	3560211	et	3	main
palju	doc_973441205356_item	3560212	et	4	main
lugesin	doc_973441205356_item	3560124	et	3	main
klass	doc_973441205356_item	3560134	et	3	main
soovib	doc_973441205356_item	3560135	et	3	main
külastada	doc_973441205356_item	3560136	et	3	main
see	doc_973441205356_item	3560137	et	3	main
muusikafestival	doc_973441205356_item	3560138	et	3	main
me	doc_973441205356_item	3560139	et	4	main
tahame	doc_973441205356_item	3560140	et	3	main
teada	doc_973441205356_item	3560141	et	3	main
kus	doc_973441205356_item	3560142	et	3	main
toimub	doc_973441205356_item	3560143	et	3	main
festival	doc_973441205356_item	3560144	et	3	main
ja	doc_973441205356_item	3560145	et	3	main
millal	doc_973441205356_item	3560146	et	3	main
klass	doc_973441205356_item	3560148	et	3	main
armastab	doc_973441205356_item	3560149	et	3	main
meie	doc_973441205356_item	3560147	et	4	main
kuulada	doc_973441205356_item	3560150	et	4	main
rock	doc_973441205356_item	3560151	et	4	main
teada	doc_973441205356_item	3560156	et	3	main
mängivad	doc_973441205356_item	3560160	et	4	main
missugused	doc_973441205356_item	3560162	et	3	main
nad	doc_973441205356_item	3560164	et	3	main
seal	doc_973441205356_item	3560178	et	4	main
on	doc_973441205356_item	3560179	et	4	main
valastajaid	doc_973441205356_item	3560181	et	4	main
meie	doc_973441205356_item	3560182	et	4	main
kontserdid	doc_973441205356_item	3560195	et	3	main
räägike	doc_973441205356_item	3560200	et	4	main
festivalil	doc_973441205356_item	3560205	et	3	main
veel	doc_973441205356_item	3560207	et	4	main
ma	doc_973441205356_item	3560208	et	3	main
soodustused	doc_973441205356_item	3560217	et	4	main
on	doc_973441205356_item	3560219	et	4	main
meie	doc_973441205356_item	3560220	et	4	main
klassis	doc_973441205356_item	3560221	et	3	main
on	doc_973441205356_item	3560231	et	4	main
on	doc_973441205356_item	3560233	et	4	main
küsida	doc_973441205356_item	3560237	et	3	main
ja	doc_973441205356_item	3560242	et	3	main
palun	doc_973441205356_item	3560247	et	3	main
narva	doc_973441205356_item	3560260	et	4	main
politseile	doc_634572338236_item	3560413	et	3	main
olen	doc_634572338236_item	3560415	et	3	main
nimi	doc_634572338236_item	3560418	et	3	main
tallinnas	doc_634572338236_item	3560427	et	4	main
27	doc_634572338236_item	3560431	et	2	main
istusin	doc_634572338236_item	3560436	et	3	main
kes	doc_634572338236_item	3560445	et	4	main
jooksis	doc_634572338236_item	3560486	et	4	main
asub	doc_634572338236_item	3560517	et	3	main
oli	doc_634572338236_item	3560522	et	3	main
eesnimi	doc_634572338236_item	3560525	et	3	main
minu	doc_432051777919_item	3560531	et	3	main
olen	doc_432051777919_item	3560536	et	3	main
õppinud	doc_432051777919_item	3560568	et	4	main
juba	doc_432051777919_item	3560569	et	3	main
kümme	doc_432051777919_item	3560570	et	3	main
aastat	doc_432051777919_item	3560571	et	3	main
sellele	doc_432051777919_item	3560581	et	4	main
kursusele	doc_432051777919_item	3560582	et	3	main
saada	doc_432051777919_item	3560589	et	4	main
on	doc_432051777919_item	3560594	et	4	main
tahan	doc_432051777919_item	3560603	et	3	main
kuulata	doc_432051777919_item	3560604	et	4	main
eesti	doc_432051777919_item	3560615	et	4	main
tegeleme	doc_432051777919_item	3560631	et	3	main
tähtis	doc_432051777919_item	3560642	et	4	main
ja	doc_432051777919_item	3560643	et	3	main
rääkimisega	doc_432051777919_item	3560644	et	4	main
suhtlemine	doc_432051777919_item	3560649	et	4	main
palun	doc_432051777919_item	3560665	et	3	main
juhuslik	doc_491521501723_item	3560698	et	3	main
pr	doc_491521501723_item	3560703	et	4	main
lugesin	doc_491521501723_item	3560705	et	3	main
ajalehest	doc_491521501723_item	3560706	et	4	main
kooleegidega	doc_491521501723_item	3560719	et	4	main
inglise	doc_491521501723_item	3560720	et	4	main
aeg	doc_491521501723_item	3560727	et	3	main
kogenud	doc_491521501723_item	3560771	et	4	main
piletid	doc_973441205356_item	3560214	et	3	main
õpilasi	doc_973441205356_item	3560223	et	3	main
tahan	doc_973441205356_item	3560226	et	3	main
missugune	doc_973441205356_item	3560228	et	3	main
festivalil	doc_973441205356_item	3560230	et	3	main
restoraanid	doc_973441205356_item	3560234	et	4	main
ma	doc_973441205356_item	3560235	et	3	main
tahan	doc_973441205356_item	3560236	et	3	main
kas	doc_973441205356_item	3560238	et	3	main
palju	doc_973441205356_item	3560244	et	4	main
maksab	doc_973441205356_item	3560246	et	3	main
kirjutage	doc_973441205356_item	3560248	et	3	main
oma	doc_973441205356_item	3560250	et	4	main
40	doc_973441205356_item	3560263	et	2	main
eesnimimailru	doc_973441205356_item	3560264	et	2	main
seletuskiri	doc_634572338236_item	3560412	et	3	main
minu	doc_634572338236_item	3560417	et	3	main
olen	doc_634572338236_item	3560423	et	3	main
see	doc_634572338236_item	3560428	et	3	main
aprillil	doc_634572338236_item	3560432	et	3	main
pingi	doc_634572338236_item	3560438	et	4	main
meie	doc_634572338236_item	3560447	et	4	main
jooksis	doc_634572338236_item	3560449	et	4	main
teise	doc_634572338236_item	3560450	et	4	main
juurde	doc_634572338236_item	3560515	et	4	main
mis	doc_634572338236_item	3560516	et	4	main
2315	doc_634572338236_item	3560524	et	2	main
ma	doc_634572338236_item	3560414	et	3	main
eesnimi	doc_634572338236_item	3560420	et	3	main
ma	doc_634572338236_item	3560422	et	3	main
elan	doc_634572338236_item	3560426	et	3	main
sõbradega	doc_634572338236_item	3560437	et	4	main
peal	doc_634572338236_item	3560439	et	4	main
ja	doc_634572338236_item	3560440	et	3	main
suhtlesime	doc_634572338236_item	3560441	et	3	main
järsku	doc_634572338236_item	3560442	et	4	main
üks	doc_634572338236_item	3560443	et	3	main
käis	doc_634572338236_item	3560446	et	4	main
juures	doc_634572338236_item	3560448	et	4	main
kes	doc_634572338236_item	3560491	et	4	main
see	doc_634572338236_item	3560492	et	3	main
oli	doc_634572338236_item	3560493	et	3	main
ühispanga	doc_634572338236_item	3560514	et	3	main
mante	doc_634572338236_item	3560519	et	3	main
nimi	doc_432051777919_item	3560532	et	3	main
kaheksateist	doc_432051777919_item	3560537	et	4	main
elus	doc_432051777919_item	3560543	et	4	main
on	doc_432051777919_item	3560544	et	4	main
õues	doc_432051777919_item	3560557	et	4	main
sõpradega	doc_432051777919_item	3560558	et	3	main
arvuti	doc_432051777919_item	3560560	et	4	main
mängida	doc_432051777919_item	3560561	et	3	main
viibida	doc_432051777919_item	3560564	et	3	main
olen	doc_432051777919_item	3560573	et	3	main
keelt	doc_432051777919_item	3560576	et	4	main
on	doc_432051777919_item	3560583	et	4	main
eriala	doc_432051777919_item	3560590	et	4	main
ja	doc_432051777919_item	3560591	et	3	main
eesti	doc_432051777919_item	3560608	et	4	main
saadet	doc_432051777919_item	3560609	et	3	main
om	doc_432051777919_item	3560614	et	4	main
tutvastega	doc_432051777919_item	3560618	et	4	main
eesti	doc_432051777919_item	3560633	et	4	main
keele	doc_432051777919_item	3560634	et	4	main
tundis	doc_432051777919_item	3560635	et	3	main
grammatikaga	doc_432051777919_item	3560636	et	3	main
sest	doc_432051777919_item	3560645	et	4	main
ma	doc_432051777919_item	3560650	et	3	main
väike	doc_432051777919_item	3560658	et	4	main
ma	doc_432051777919_item	3560659	et	3	main
tahaksin	doc_432051777919_item	3560660	et	3	main
teada	doc_432051777919_item	3560661	et	3	main
kallis	doc_432051777919_item	3560662	et	4	main
kiri	doc_491521501723_item	3560695	et	3	main
turisme	doc_491521501723_item	3560697	et	3	main
lugupetud	doc_491521501723_item	3560702	et	3	main
perekonnanimi	doc_491521501723_item	3560704	et	3	main
postemes	doc_491521501723_item	3560707	et	4	main
pöördus	doc_491521501723_item	3560713	et	4	main
kursuse	doc_491521501723_item	3560726	et	3	main
meile	doc_491521501723_item	3560730	et	4	main
õppimisiks	doc_491521501723_item	3560732	et	4	main
esmaspäev	doc_491521501723_item	3560733	et	3	main
kolmapäev	doc_491521501723_item	3560734	et	3	main
ja	doc_491521501723_item	3560735	et	3	main
reede	doc_491521501723_item	3560736	et	4	main
tunnid	doc_491521501723_item	3560737	et	3	main
võimalikud	doc_491521501723_item	3560766	et	3	main
loodame	doc_491521501723_item	3560768	et	3	main
et	doc_491521501723_item	3560769	et	3	main
teie	doc_491521501723_item	3560770	et	4	main
kursuste	doc_491521501723_item	3560777	et	3	main
koostöö	doc_491521501723_item	3560783	et	4	main
inglise	doc_491521501723_item	3560790	et	4	main
keele	doc_491521501723_item	3560791	et	4	main
kursuste	doc_491521501723_item	3560792	et	3	main
oleme	doc_491521501723_item	3560793	et	3	main
soovime	doc_491521501723_item	3560794	et	4	main
keele	doc_491521501723_item	3560799	et	4	main
kursustest	doc_491521501723_item	3560800	et	4	main
koostööle	doc_491521501723_item	3560802	et	3	main
lootes	doc_491521501723_item	3560803	et	4	main
eesnimi	doc_491521501723_item	3560804	et	3	main
perekonnanimi	doc_491521501723_item	3560805	et	3	main
essee	doc_59711134412_item	3560813	et	4	main
aga	doc_634572338236_item	3560494	et	3	main
tal	doc_634572338236_item	3560495	et	3	main
olid	doc_634572338236_item	3560496	et	4	main
isikukirjeldused	doc_634572338236_item	3560498	et	3	main
must	doc_634572338236_item	3560499	et	4	main
oma	doc_634572338236_item	3560497	et	4	main
jope	doc_634572338236_item	3560500	et	4	main
sinised	doc_634572338236_item	3560501	et	4	main
teksapüksid	doc_634572338236_item	3560502	et	3	main
ja	doc_634572338236_item	3560503	et	3	main
valge	doc_634572338236_item	3560504	et	4	main
soni	doc_634572338236_item	3560505	et	4	main
tal	doc_634572338236_item	3560506	et	3	main
oli	doc_634572338236_item	3560507	et	3	main
pikkad	doc_634572338236_item	3560508	et	4	main
tumedad	doc_634572338236_item	3560509	et	3	main
juuksed	doc_634572338236_item	3560510	et	3	main
see	doc_634572338236_item	3560511	et	3	main
pealtnägija	doc_634572338236_item	3560416	et	4	main
vana	doc_634572338236_item	3560425	et	4	main
oli	doc_634572338236_item	3560430	et	3	main
männiku	doc_634572338236_item	3560433	et	3	main
ma	doc_634572338236_item	3560435	et	3	main
pingile	doc_634572338236_item	3560451	et	3	main
kus	doc_634572338236_item	3560452	et	3	main
istus	doc_634572338236_item	3560453	et	4	main
kaks	doc_634572338236_item	3560454	et	3	main
naist	doc_634572338236_item	3560455	et	3	main
ja	doc_634572338236_item	3560456	et	3	main
ta	doc_634572338236_item	3560457	et	4	main
haarab	doc_634572338236_item	3560458	et	3	main
sülle	doc_634572338236_item	3560459	et	3	main
üht	doc_634572338236_item	3560460	et	3	main
naine	doc_634572338236_item	3560461	et	3	main
naine	doc_634572338236_item	3560462	et	3	main
hakkas	doc_634572338236_item	3560463	et	3	main
vastu	doc_634572338236_item	3560464	et	3	main
ta	doc_634572338236_item	3560465	et	4	main
panis	doc_634572338236_item	3560466	et	4	main
ära	doc_634572338236_item	3560467	et	4	main
oma	doc_634572338236_item	3560468	et	4	main
kingi	doc_634572338236_item	3560469	et	4	main
ja	doc_634572338236_item	3560470	et	3	main
ta	doc_634572338236_item	3560471	et	4	main
lüüa	doc_634572338236_item	3560472	et	3	main
teda	doc_634572338236_item	3560473	et	4	main
kingakotsiga	doc_634572338236_item	3560474	et	4	main
pähe	doc_634572338236_item	3560475	et	4	main
mees	doc_634572338236_item	3560476	et	4	main
ei	doc_634572338236_item	3560477	et	4	main
oota	doc_634572338236_item	3560478	et	4	main
selle	doc_634572338236_item	3560479	et	4	main
reaktsiooni	doc_634572338236_item	3560480	et	4	main
ja	doc_634572338236_item	3560481	et	3	main
pani	doc_634572338236_item	3560482	et	4	main
teda	doc_634572338236_item	3560483	et	4	main
maha	doc_634572338236_item	3560484	et	4	main
ja	doc_634572338236_item	3560485	et	3	main
ära	doc_634572338236_item	3560487	et	4	main
ma	doc_634572338236_item	3560488	et	3	main
ei	doc_634572338236_item	3560489	et	4	main
mees	doc_634572338236_item	3560512	et	4	main
jooksid	doc_634572338236_item	3560513	et	4	main
tallinna	doc_634572338236_item	3560518	et	4	main
kell	doc_634572338236_item	3560521	et	3	main
umbes	doc_634572338236_item	3560523	et	4	main
kiri	doc_432051777919_item	3560528	et	3	main
eesnimi	doc_432051777919_item	3560534	et	3	main
aastat	doc_432051777919_item	3560538	et	3	main
kõige	doc_432051777919_item	3560540	et	4	main
tähtsam	doc_432051777919_item	3560541	et	4	main
minu	doc_432051777919_item	3560542	et	3	main
hele	doc_432051777919_item	3560550	et	3	main
tulevik	doc_432051777919_item	3560551	et	3	main
ma	doc_432051777919_item	3560552	et	3	main
armastan	doc_432051777919_item	3560553	et	3	main
tegeleda	doc_432051777919_item	3560554	et	3	main
varem	doc_432051777919_item	3560572	et	4	main
soovitus	doc_432051777919_item	3560584	et	4	main
põhjus	doc_432051777919_item	3560587	et	4	main
on	doc_432051777919_item	3560588	et	4	main
eesti	doc_432051777919_item	3560600	et	4	main
telerist	doc_432051777919_item	3560610	et	4	main
ma	doc_432051777919_item	3560611	et	3	main
sõpradega	doc_432051777919_item	3560616	et	3	main
loodan	doc_432051777919_item	3560628	et	3	main
me	doc_432051777919_item	3560630	et	4	main
et	doc_432051777919_item	3560638	et	3	main
et	doc_432051777919_item	3560646	et	3	main
algab	doc_432051777919_item	3560648	et	3	main
kardan	doc_432051777919_item	3560651	et	4	main
natuke	doc_432051777919_item	3560652	et	4	main
et	doc_432051777919_item	3560653	et	3	main
minu	doc_432051777919_item	3560654	et	3	main
õpetaja	doc_432051777919_item	3560663	et	4	main
mida	doc_432051777919_item	3560666	et	4	main
lugupidamisega	doc_432051777919_item	3560691	et	3	main
eesnimi	doc_432051777919_item	3560692	et	3	main
perekonnanimi	doc_432051777919_item	3560693	et	3	main
perekonnanimi	doc_432051777919_item	3560535	et	3	main
vana	doc_432051777919_item	3560539	et	4	main
õppimine	doc_432051777919_item	3560545	et	4	main
minu	doc_432051777919_item	3560546	et	3	main
perekond	doc_432051777919_item	3560547	et	3	main
armastus	doc_432051777919_item	3560548	et	4	main
ja	doc_432051777919_item	3560549	et	3	main
spordiga	doc_432051777919_item	3560555	et	3	main
töötada	doc_432051777919_item	3560559	et	3	main
ja	doc_432051777919_item	3560562	et	3	main
eesti	doc_432051777919_item	3560565	et	4	main
keelt	doc_432051777919_item	3560566	et	4	main
olen	doc_432051777919_item	3560567	et	3	main
õppinud	doc_432051777919_item	3560574	et	4	main
esimene	doc_432051777919_item	3560577	et	3	main
õppida	doc_432051777919_item	3560585	et	3	main
teine	doc_432051777919_item	3560586	et	3	main
mul	doc_432051777919_item	3560593	et	3	main
eesti	doc_432051777919_item	3560595	et	4	main
raamatud	doc_432051777919_item	3560601	et	4	main
eesti	doc_432051777919_item	3560605	et	4	main
raadiot	doc_432051777919_item	3560606	et	3	main
vaada	doc_432051777919_item	3560607	et	4	main
rääkida	doc_432051777919_item	3560613	et	3	main
ainult	doc_432051777919_item	3560619	et	4	main
eesti	doc_432051777919_item	3560620	et	4	main
keeles	doc_432051777919_item	3560621	et	4	main
ma	doc_432051777919_item	3560622	et	3	main
tahan	doc_432051777919_item	3560623	et	3	main
kirjutada	doc_432051777919_item	3560624	et	3	main
eesti	doc_432051777919_item	3560625	et	4	main
luuletusi	doc_432051777919_item	3560626	et	4	main
ma	doc_432051777919_item	3560627	et	3	main
tulin	doc_432051777919_item	3560580	et	3	main
kõrgharidus	doc_432051777919_item	3560592	et	3	main
keelt	doc_432051777919_item	3560596	et	4	main
vaja	doc_432051777919_item	3560597	et	4	main
et	doc_432051777919_item	3560598	et	3	main
lugeda	doc_432051777919_item	3560599	et	3	main
ma	doc_432051777919_item	3560602	et	3	main
tahan	doc_432051777919_item	3560612	et	3	main
ja	doc_432051777919_item	3560617	et	3	main
sest	doc_432051777919_item	3560637	et	4	main
see	doc_432051777919_item	3560639	et	3	main
on	doc_432051777919_item	3560640	et	4	main
sõnavara	doc_432051777919_item	3560655	et	4	main
mnt	doc_491521501723_item	3560699	et	4	main
firma	doc_491521501723_item	3560710	et	4	main
keele	doc_491521501723_item	3560721	et	4	main
kursustel	doc_491521501723_item	3560722	et	3	main
meiepooleseks	doc_491521501723_item	3560723	et	4	main
oktoober-kuni	doc_491521501723_item	3560728	et	3	main
sobiksid	doc_491521501723_item	3560731	et	4	main
meie	doc_491521501723_item	3560774	et	4	main
keeleoskust	doc_491521501723_item	3560775	et	3	main
tasuda	doc_491521501723_item	3560780	et	3	main
ülekandega	doc_491521501723_item	3560781	et	3	main
ka	doc_491521501723_item	3560795	et	3	main
19	doc_491521501723_item	3560810	et	2	main
tallinn	doc_491521501723_item	3560811	et	4	main
kus	doc_59711134412_item	3560814	et	3	main
isal	doc_59711134412_item	3560824	et	3	main
ja	doc_59711134412_item	3560827	et	3	main
ja	doc_59711134412_item	3560836	et	3	main
aastat	doc_59711134412_item	3560840	et	3	main
tagasi	doc_59711134412_item	3560843	et	3	main
sõitsin	doc_59711134412_item	3560845	et	3	main
on	doc_59711134412_item	3560859	et	4	main
see	doc_59711134412_item	3560872	et	3	main
vaja	doc_59711134412_item	3560889	et	4	main
mutub	doc_59711134412_item	3560919	et	4	main
isa	doc_59711134412_item	3560926	et	4	main
ma	doc_59711134412_item	3560936	et	3	main
õpisin	doc_59711134412_item	3560937	et	4	main
inglisekeele	doc_59711134412_item	3560938	et	4	main
me	doc_59711134412_item	3560949	et	4	main
jõudsime	doc_59711134412_item	3560950	et	3	main
koju	doc_59711134412_item	3560951	et	3	main
see	doc_59711134412_item	3560952	et	3	main
mida	doc_59711134412_item	3560968	et	4	main
teha	doc_59711134412_item	3560969	et	3	main
ääres	doc_59711134412_item	3560991	et	4	main
ja	doc_59711134412_item	3560995	et	3	main
ei	doc_59711134412_item	3561001	et	4	main
ühegi	doc_59711134412_item	3561003	et	4	main
kalu	doc_59711134412_item	3561004	et	4	main
see	doc_59711134412_item	3561005	et	3	main
oli	doc_59711134412_item	3561006	et	3	main
väga	doc_59711134412_item	3561007	et	3	main
vanalinna	doc_59711134412_item	3561030	et	4	main
suurt	doc_59711134412_item	3561033	et	3	main
jõululinn	doc_59711134412_item	3561035	et	3	main
girljandid	doc_59711134412_item	3561045	et	4	main
ja	doc_59711134412_item	3561046	et	3	main
siin	doc_59711134412_item	3561059	et	4	main
niimodi	doc_59711134412_item	3561064	et	4	main
käis	doc_59711134412_item	3561067	et	4	main
oli	doc_59711134412_item	3561097	et	3	main
õnnelik	doc_59711134412_item	3561098	et	3	main
käin	doc_193540241556_item	3561113	et	3	main
rimis	doc_193540241556_item	3561115	et	4	main
ja	doc_193540241556_item	3561122	et	3	main
ja	doc_193540241556_item	3561132	et	3	main
järgmine	doc_193540241556_item	3561137	et	3	main
belgiasse	doc_193540241556_item	3561141	et	4	main
peol	doc_193540241556_item	3561144	et	4	main
et	doc_193540241556_item	3561145	et	3	main
tähistama	doc_193540241556_item	3561146	et	3	main
uusaasta	doc_193540241556_item	3561147	et	4	main
ma	doc_193540241556_item	3561150	et	3	main
võib-olla	doc_193540241556_item	3561159	et	3	main
sõbraga	doc_193540241556_item	3561164	et	3	main
perekonnaringis	doc_193540241556_item	3561166	et	3	main
olen	doc_193540241556_item	3561169	et	3	main
alates	doc_193540241556_item	3561179	et	3	main
olen	doc_193540241556_item	3561182	et	3	main
puhkusel	doc_193540241556_item	3561183	et	4	main
et	doc_432051777919_item	3560629	et	3	main
põhjalikult	doc_432051777919_item	3560632	et	4	main
väga	doc_432051777919_item	3560641	et	3	main
rääkimisega	doc_432051777919_item	3560647	et	4	main
on	doc_432051777919_item	3560656	et	4	main
väga	doc_432051777919_item	3560657	et	3	main
ütlege	doc_432051777919_item	3560664	et	4	main
te	doc_432051777919_item	3560667	et	4	main
mõtlete	doc_432051777919_item	3560668	et	3	main
eesti	doc_432051777919_item	3560669	et	4	main
keele	doc_432051777919_item	3560670	et	4	main
õppimisest	doc_432051777919_item	3560671	et	4	main
vene	doc_432051777919_item	3560672	et	4	main
koolis	doc_432051777919_item	3560673	et	4	main
kas	doc_432051777919_item	3560674	et	3	main
se	doc_432051777919_item	3560675	et	4	main
õpe	doc_432051777919_item	3560676	et	3	main
asub	doc_432051777919_item	3560677	et	3	main
kõrgel	doc_432051777919_item	3560678	et	4	main
tasel	doc_432051777919_item	3560679	et	4	main
mis	doc_432051777919_item	3560680	et	4	main
teid	doc_432051777919_item	3560681	et	4	main
häirib	doc_432051777919_item	3560682	et	3	main
meie	doc_432051777919_item	3560683	et	4	main
riigis	doc_432051777919_item	3560684	et	3	main
loodan	doc_432051777919_item	3560685	et	3	main
et	doc_432051777919_item	3560686	et	3	main
minu	doc_432051777919_item	3560687	et	3	main
õppimise	doc_432051777919_item	3560688	et	4	main
inspiraatsion	doc_432051777919_item	3560689	et	4	main
tekkib	doc_432051777919_item	3560690	et	3	main
as	doc_491521501723_item	3560696	et	4	main
leht	doc_491521501723_item	3560708	et	3	main
kulutust	doc_491521501723_item	3560711	et	4	main
teie	doc_491521501723_item	3560714	et	4	main
osaleda	doc_491521501723_item	3560717	et	3	main
koos	doc_491521501723_item	3560718	et	4	main
sooviks	doc_491521501723_item	3560724	et	4	main
oleks	doc_491521501723_item	3560725	et	3	main
võiksid	doc_491521501723_item	3560738	et	4	main
teie	doc_491521501723_item	3560787	et	4	main
koolitussekretäriga	doc_491521501723_item	3560788	et	3	main
kursuste	doc_491521501723_item	3560764	et	3	main
hind	doc_491521501723_item	3560765	et	3	main
15	doc_491521501723_item	3560700	et	2	main
tartu	doc_491521501723_item	3560701	et	4	main
teie	doc_491521501723_item	3560709	et	4	main
ja	doc_491521501723_item	3560712	et	3	main
poole	doc_491521501723_item	3560715	et	4	main
soovimaks	doc_491521501723_item	3560716	et	4	main
jaanuar	doc_491521501723_item	3560729	et	3	main
toimuda	doc_491521501723_item	3560739	et	3	main
meie	doc_491521501723_item	3560740	et	4	main
firmas	doc_491521501723_item	3560741	et	3	main
sest	doc_491521501723_item	3560742	et	4	main
meie	doc_491521501723_item	3560743	et	4	main
on	doc_491521501723_item	3560744	et	4	main
kaasaegne	doc_491521501723_item	3560745	et	3	main
õppe-klass	doc_491521501723_item	3560746	et	3	main
ja	doc_491521501723_item	3560747	et	3	main
head	doc_491521501723_item	3560748	et	4	main
tehnilised	doc_491521501723_item	3560749	et	3	main
vahendid	doc_491521501723_item	3560750	et	3	main
meid	doc_491521501723_item	3560751	et	4	main
huvitab	doc_491521501723_item	3560752	et	3	main
informatsioon	doc_491521501723_item	3560753	et	3	main
õpetajate	doc_491521501723_item	3560754	et	4	main
töökogemuse	doc_491521501723_item	3560755	et	3	main
kohta	doc_491521501723_item	3560756	et	4	main
paluma	doc_491521501723_item	3560757	et	3	main
teilt	doc_491521501723_item	3560758	et	4	main
järgmist	doc_491521501723_item	3560759	et	3	main
teavet	doc_491521501723_item	3560760	et	3	main
teised	doc_491521501723_item	3560761	et	4	main
pakutavad	doc_491521501723_item	3560762	et	4	main
kursused	doc_491521501723_item	3560763	et	3	main
soodustused	doc_491521501723_item	3560767	et	4	main
parandada	doc_491521501723_item	3560776	et	3	main
soovime	doc_491521501723_item	3560779	et	4	main
edaspidise	doc_491521501723_item	3560782	et	3	main
huvides	doc_491521501723_item	3560784	et	3	main
soovime	doc_491521501723_item	3560785	et	4	main
kohtuda	doc_491521501723_item	3560786	et	3	main
hispaania	doc_491521501723_item	3560798	et	4	main
mnt	doc_491521501723_item	3560809	et	4	main
ja	doc_59711134412_item	3560817	et	3	main
näinud	doc_59711134412_item	3560820	et	4	main
oli	doc_59711134412_item	3560825	et	3	main
ta	doc_59711134412_item	3560828	et	4	main
otsustas	doc_59711134412_item	3560829	et	3	main
sõita	doc_59711134412_item	3560830	et	3	main
vanaisa	doc_59711134412_item	3560837	et	4	main
kaks	doc_59711134412_item	3560841	et	3	main
seal	doc_59711134412_item	3560854	et	4	main
eriti	doc_59711134412_item	3560855	et	3	main
reisida	doc_59711134412_item	3560856	et	3	main
lennukiga	doc_59711134412_item	3560857	et	3	main
see	doc_59711134412_item	3560858	et	3	main
isa	doc_59711134412_item	3560861	et	4	main
pärast	doc_59711134412_item	3560868	et	4	main
berliini	doc_59711134412_item	3560877	et	4	main
õpetajad	doc_491521501723_item	3560772	et	4	main
suudavad	doc_491521501723_item	3560773	et	3	main
eest	doc_491521501723_item	3560778	et	4	main
peale	doc_491521501723_item	3560789	et	4	main
ja	doc_491521501723_item	3560797	et	3	main
käinud	doc_59711134412_item	3560816	et	4	main
olin	doc_59711134412_item	3560819	et	3	main
saksamaale	doc_59711134412_item	3560831	et	4	main
saksamaal	doc_59711134412_item	3560832	et	4	main
juba	doc_59711134412_item	3560838	et	3	main
aastat	doc_59711134412_item	3560842	et	3	main
unustamatu	doc_59711134412_item	3560860	et	4	main
külla	doc_59711134412_item	3560864	et	4	main
esimene	doc_59711134412_item	3560865	et	3	main
kord	doc_59711134412_item	3560866	et	4	main
selle	doc_59711134412_item	3560867	et	4	main
aluseks	doc_59711134412_item	3560876	et	4	main
rongiga	doc_59711134412_item	3560880	et	4	main
ümberistumisega	doc_59711134412_item	3560892	et	3	main
väsinud	doc_59711134412_item	3560920	et	4	main
oska	doc_59711134412_item	3560928	et	4	main
selle	doc_59711134412_item	3560930	et	4	main
suhtlemine	doc_59711134412_item	3560932	et	4	main
ühe	doc_59711134412_item	3560956	et	4	main
nädala	doc_59711134412_item	3560957	et	3	main
esimesed	doc_59711134412_item	3560958	et	3	main
kaks	doc_59711134412_item	3560959	et	3	main
päevad	doc_59711134412_item	3560960	et	3	main
olid	doc_59711134412_item	3560961	et	4	main
igavad	doc_59711134412_item	3560962	et	3	main
me	doc_59711134412_item	3560965	et	4	main
teadnud	doc_59711134412_item	3560967	et	4	main
melle	doc_59711134412_item	3560986	et	4	main
meeldib	doc_59711134412_item	3560987	et	3	main
see	doc_59711134412_item	3560988	et	3	main
kiud	doc_59711134412_item	3560989	et	4	main
jõe	doc_59711134412_item	3560990	et	3	main
sai	doc_59711134412_item	3560997	et	4	main
päev	doc_59711134412_item	3561010	et	3	main
juba	doc_59711134412_item	3561012	et	3	main
ja	doc_59711134412_item	3561031	et	3	main
kauplust	doc_59711134412_item	3561034	et	4	main
ajal	doc_59711134412_item	3561042	et	4	main
raekojaplatsil	doc_59711134412_item	3561048	et	3	main
inimesi	doc_59711134412_item	3561052	et	4	main
et	doc_59711134412_item	3561053	et	3	main
näikse	doc_59711134412_item	3561054	et	3	main
nagu	doc_59711134412_item	3561055	et	3	main
ühesõnaga	doc_59711134412_item	3561060	et	3	main
kõikjal	doc_59711134412_item	3561063	et	3	main
vannis	doc_193540241556_item	3561111	et	3	main
üks	doc_193540241556_item	3561119	et	3	main
üks	doc_193540241556_item	3561123	et	3	main
pudel	doc_193540241556_item	3561124	et	3	main
muusikat	doc_193540241556_item	3561135	et	3	main
nädalal	doc_193540241556_item	3561138	et	3	main
olen	doc_193540241556_item	3561151	et	3	main
ma	doc_193540241556_item	3561153	et	3	main
ja	doc_193540241556_item	3561162	et	3	main
pikka	doc_193540241556_item	3561193	et	4	main
juuksed	doc_193540241556_item	3561201	et	3	main
on	doc_193540241556_item	3561203	et	4	main
ma	doc_193540241556_item	3561210	et	3	main
ma	doc_193540241557_item	3561248	et	3	main
käiaksin	doc_193540241557_item	3561249	et	3	main
kui	doc_193540241557_item	3561253	et	3	main
euroopa	doc_193540241557_item	3561268	et	4	main
keelt	doc_193540241557_item	3561281	et	4	main
ma	doc_193540241557_item	3561285	et	3	main
on	doc_193540241557_item	3561332	et	4	main
palju	doc_193540241557_item	3561334	et	4	main
ma	doc_193540241557_item	3561335	et	3	main
armastan	doc_193540241557_item	3561336	et	3	main
kõndida	doc_193540241557_item	3561337	et	3	main
ma	doc_193540241557_item	3561338	et	3	main
lähen	doc_193540241557_item	3561339	et	3	main
tulevikus	doc_193540241558_item	3561395	et	4	main
praegu	doc_193540241558_item	3561396	et	3	main
ja	doc_193540241558_item	3561400	et	3	main
oppima	doc_193540241558_item	3561404	et	4	main
veel	doc_193540241558_item	3561405	et	4	main
ole	doc_193540241558_item	3561431	et	4	main
elanud	doc_193540241558_item	3561433	et	4	main
näiteks	doc_193540241558_item	3561434	et	4	main
sakse	doc_491521501723_item	3560796	et	3	main
meeldivale	doc_491521501723_item	3560801	et	4	main
as	doc_491521501723_item	3560806	et	4	main
siil	doc_491521501723_item	3560807	et	3	main
juhuslik	doc_491521501723_item	3560808	et	3	main
kiiresti	doc_59711134412_item	3561069	et	3	main
tagasi	doc_59711134412_item	3561070	et	3	main
sõtsime	doc_59711134412_item	3561071	et	4	main
ka	doc_59711134412_item	3561072	et	3	main
aluseks	doc_59711134412_item	3561073	et	4	main
rongiga	doc_59711134412_item	3561074	et	4	main
seejarel	doc_59711134412_item	3561075	et	4	main
lennukiga	doc_59711134412_item	3561076	et	3	main
see	doc_59711134412_item	3561077	et	3	main
kord	doc_59711134412_item	3561078	et	4	main
ilm	doc_59711134412_item	3561079	et	3	main
oli	doc_59711134412_item	3561080	et	3	main
tore	doc_59711134412_item	3561081	et	3	main
ja	doc_59711134412_item	3561082	et	3	main
ma	doc_59711134412_item	3561083	et	3	main
võin	doc_59711134412_item	3561084	et	3	main
teha	doc_59711134412_item	3561085	et	3	main
palju	doc_59711134412_item	3561086	et	4	main
ilusaid	doc_59711134412_item	3561087	et	3	main
fotosid	doc_59711134412_item	3561088	et	3	main
nagu	doc_59711134412_item	3561089	et	3	main
see	doc_59711134412_item	3561090	et	3	main
üldse	doc_59711134412_item	3561091	et	3	main
tahaksin	doc_59711134412_item	3561092	et	3	main
öelda	doc_59711134412_item	3561093	et	4	main
et	doc_59711134412_item	3561094	et	3	main
olin	doc_59711134412_item	3560815	et	3	main
eelmisel	doc_59711134412_item	3560821	et	3	main
kuul	doc_59711134412_item	3560822	et	4	main
minu	doc_59711134412_item	3560823	et	3	main
puhkus	doc_59711134412_item	3560826	et	3	main
minu	doc_59711134412_item	3560834	et	3	main
kolm	doc_59711134412_item	3560839	et	3	main
bremeni	doc_59711134412_item	3560847	et	4	main
minu	doc_59711134412_item	3560849	et	3	main
õega	doc_59711134412_item	3560850	et	3	main
ja	doc_59711134412_item	3560851	et	3	main
mulle	doc_59711134412_item	3560852	et	4	main
meeldis	doc_59711134412_item	3560853	et	3	main
kõik	doc_59711134412_item	3560869	et	4	main
oli	doc_59711134412_item	3560870	et	3	main
kord	doc_59711134412_item	3560873	et	4	main
me	doc_59711134412_item	3560874	et	4	main
lendasime	doc_59711134412_item	3560875	et	3	main
bremeni	doc_59711134412_item	3560881	et	4	main
liiga	doc_59711134412_item	3560884	et	4	main
ja	doc_59711134412_item	3560886	et	3	main
teise	doc_59711134412_item	3560893	et	4	main
rongisse	doc_59711134412_item	3560894	et	4	main
kokku	doc_59711134412_item	3560895	et	3	main
neid	doc_59711134412_item	3560896	et	4	main
oli	doc_59711134412_item	3560897	et	3	main
kolm	doc_59711134412_item	3560898	et	3	main
võib	doc_59711134412_item	3560899	et	3	main
see	doc_59711134412_item	3560901	et	3	main
olla	doc_59711134412_item	3560900	et	3	main
on	doc_59711134412_item	3560902	et	4	main
vaid	doc_59711134412_item	3560904	et	3	main
tore	doc_59711134412_item	3560903	et	3	main
kui	doc_59711134412_item	3560905	et	3	main
sõidab	doc_59711134412_item	3560906	et	3	main
kokku	doc_59711134412_item	3560907	et	3	main
5	doc_59711134412_item	3560908	et	2	main
tunni	doc_59711134412_item	3560909	et	3	main
ilma	doc_59711134412_item	3560910	et	4	main
peatusi	doc_59711134412_item	3560911	et	4	main
see	doc_59711134412_item	3560912	et	3	main
mis	doc_59711134412_item	3560818	et	4	main
elavad	doc_59711134412_item	3560833	et	4	main
vanaema	doc_59711134412_item	3560835	et	4	main
ma	doc_59711134412_item	3560844	et	3	main
juba	doc_59711134412_item	3560846	et	3	main
koos	doc_59711134412_item	3560848	et	4	main
sõitsin	doc_59711134412_item	3560862	et	3	main
nende	doc_59711134412_item	3560863	et	4	main
uus	doc_59711134412_item	3560871	et	3	main
pärast	doc_59711134412_item	3560879	et	4	main
kiirpilet	doc_59711134412_item	3560882	et	3	main
osta	doc_59711134412_item	3560890	et	4	main
pileteid	doc_59711134412_item	3560891	et	3	main
edahujutav	doc_59711134412_item	3560915	et	4	main
peale	doc_59711134412_item	3560921	et	4	main
ei	doc_59711134412_item	3560927	et	4	main
pärast	doc_59711134412_item	3560931	et	4	main
oli	doc_59711134412_item	3560933	et	3	main
raske	doc_59711134412_item	3560934	et	4	main
me	doc_59711134412_item	3560954	et	4	main
sõitsime	doc_59711134412_item	3560955	et	3	main
et	doc_59711134412_item	3560964	et	3	main
ja	doc_59711134412_item	3560971	et	3	main
istusime	doc_59711134412_item	3560972	et	3	main
vaatamas	doc_59711134412_item	3560974	et	3	main
telerit	doc_59711134412_item	3560975	et	3	main
kolmandal	doc_59711134412_item	3560976	et	3	main
päeval	doc_59711134412_item	3560977	et	3	main
koos	doc_59711134412_item	3560982	et	4	main
tuttavaga	doc_59711134412_item	3560984	et	4	main
oli	doc_59711134412_item	3560992	et	3	main
külm	doc_59711134412_item	3560994	et	3	main
lisaks	doc_59711134412_item	3560999	et	4	main
ma	doc_59711134412_item	3561000	et	3	main
oli	doc_59711134412_item	3561011	et	3	main
peakirikut	doc_59711134412_item	3561029	et	3	main
mittu	doc_59711134412_item	3561032	et	4	main
ilus	doc_59711134412_item	3561040	et	4	main
sell	doc_59711134412_item	3561041	et	3	main
kõik	doc_59711134412_item	3561056	et	4	main
elanikud	doc_59711134412_item	3561057	et	3	main
see	doc_59711134412_item	3561065	et	3	main
väga	doc_59711134412_item	3561068	et	3	main
see	doc_59711134412_item	3561095	et	3	main
reisimine	doc_59711134412_item	3561096	et	4	main
essee	doc_193540241556_item	3561100	et	4	main
ma	doc_193540241556_item	3561102	et	3	main
hommikust	doc_193540241556_item	3561104	et	4	main
pärast	doc_193540241556_item	3561105	et	4	main
ma	doc_193540241556_item	3561106	et	3	main
magan	doc_193540241556_item	3561107	et	3	main
ja	doc_193540241556_item	3561108	et	3	main
ma	doc_193540241556_item	3561109	et	3	main
poes	doc_193540241556_item	3561114	et	3	main
ja	doc_193540241556_item	3561116	et	3	main
ostan	doc_193540241556_item	3561118	et	3	main
kilo	doc_193540241556_item	3561120	et	4	main
tomatit	doc_193540241556_item	3561121	et	3	main
vesi	doc_193540241556_item	3561125	et	4	main
ma	doc_193540241556_item	3561126	et	3	main
käin	doc_193540241556_item	3561127	et	3	main
kodus	doc_193540241556_item	3561128	et	4	main
ma	doc_193540241556_item	3561129	et	3	main
ma	doc_193540241556_item	3561133	et	3	main
käin	doc_193540241556_item	3561140	et	3	main
ma	doc_193540241556_item	3561142	et	3	main
puhkusel	doc_193540241556_item	3561152	et	4	main
vaatan	doc_193540241556_item	3561154	et	3	main
koristan	doc_193540241556_item	3561156	et	3	main
tuba	doc_193540241556_item	3561157	et	4	main
käin	doc_193540241556_item	3561160	et	3	main
sõber	doc_193540241556_item	3561191	et	3	main
aga	doc_59711134412_item	3560878	et	3	main
oli	doc_59711134412_item	3560883	et	3	main
kallis	doc_59711134412_item	3560885	et	4	main
meil	doc_59711134412_item	3560887	et	4	main
oli	doc_59711134412_item	3560888	et	3	main
on	doc_59711134412_item	3560913	et	4	main
ja	doc_59711134412_item	3560916	et	3	main
pärast	doc_59711134412_item	3560917	et	4	main
seda	doc_59711134412_item	3560922	et	3	main
ehk	doc_59711134412_item	3560923	et	3	main
mina	doc_59711134412_item	3560924	et	4	main
ega	doc_59711134412_item	3560925	et	3	main
õnneks	doc_59711134412_item	3560935	et	4	main
lõpuks	doc_59711134412_item	3560948	et	4	main
seal	doc_59711134412_item	3560970	et	4	main
ebamugavaks	doc_59711134412_item	3560998	et	3	main
kahju	doc_59711134412_item	3561008	et	4	main
järgmine	doc_59711134412_item	3561009	et	3	main
eriri	doc_59711134412_item	3561036	et	4	main
kesklinn	doc_59711134412_item	3561037	et	3	main
on	doc_59711134412_item	3561038	et	4	main
kõikjal	doc_59711134412_item	3561043	et	3	main
kogunesid	doc_59711134412_item	3561058	et	4	main
homme	doc_193540241556_item	3561101	et	3	main
söön	doc_193540241556_item	3561103	et	3	main
käin	doc_193540241556_item	3561110	et	3	main
ma	doc_193540241556_item	3561117	et	3	main
lõunat	doc_193540241556_item	3561131	et	3	main
kuulan	doc_193540241556_item	3561134	et	3	main
ma	doc_193540241556_item	3561139	et	3	main
olen	doc_193540241556_item	3561143	et	3	main
sõbraga	doc_193540241556_item	3561148	et	3	main
jaanuaris	doc_193540241556_item	3561149	et	3	main
telekat	doc_193540241556_item	3561155	et	3	main
ja	doc_193540241556_item	3561158	et	3	main
pubis	doc_193540241556_item	3561163	et	4	main
veebruaris	doc_193540241556_item	3561167	et	3	main
ülikoolis	doc_193540241556_item	3561170	et	4	main
brüsselis	doc_193540241556_item	3561171	et	4	main
ma	doc_193540241556_item	3561172	et	3	main
juuli	doc_193540241556_item	3561180	et	4	main
ma	doc_193540241556_item	3561181	et	3	main
reisin	doc_193540241556_item	3561185	et	3	main
rootsis	doc_193540241556_item	3561186	et	3	main
sõbraga	doc_193540241556_item	3561187	et	3	main
pruunid	doc_193540241556_item	3561200	et	3	main
reisija	doc_193540241557_item	3561261	et	4	main
ma	doc_193540241557_item	3561262	et	3	main
olen	doc_193540241557_item	3561263	et	3	main
inimesedega	doc_193540241557_item	3561269	et	4	main
ma	doc_193540241557_item	3561272	et	3	main
minu	doc_193540241557_item	3561275	et	3	main
ma	doc_193540241557_item	3561277	et	3	main
ja	doc_193540241557_item	3561284	et	3	main
olen	doc_193540241557_item	3561286	et	3	main
eesti	doc_193540241557_item	3561288	et	4	main
vene	doc_193540241557_item	3561289	et	4	main
ja	doc_193540241557_item	3561290	et	3	main
saksa	doc_193540241557_item	3561291	et	4	main
maailma	doc_193540241557_item	3561340	et	4	main
kakskümmend	doc_193540241557_item	3561347	et	4	main
mulle	doc_193540241557_item	3561349	et	4	main
juba	doc_59711134412_item	3560914	et	3	main
selle	doc_59711134412_item	3560918	et	4	main
saksakeelt	doc_59711134412_item	3560929	et	4	main
ja	doc_59711134412_item	3560939	et	3	main
võin	doc_59711134412_item	3560940	et	3	main
selgitada	doc_59711134412_item	3560941	et	3	main
taksojuhile	doc_59711134412_item	3560942	et	3	main
kuhu	doc_59711134412_item	3560943	et	3	main
sõta	doc_59711134412_item	3560944	et	4	main
noh	doc_59711134412_item	3560945	et	3	main
vaatamata	doc_59711134412_item	3560946	et	4	main
kõkile	doc_59711134412_item	3560947	et	4	main
kord	doc_59711134412_item	3560953	et	4	main
sest	doc_59711134412_item	3560963	et	4	main
ei	doc_59711134412_item	3560966	et	4	main
kodus	doc_59711134412_item	3560973	et	4	main
me	doc_59711134412_item	3560978	et	4	main
sõitsime	doc_59711134412_item	3560979	et	3	main
kalu	doc_59711134412_item	3560980	et	4	main
püüa	doc_59711134412_item	3560981	et	4	main
vanaemade	doc_59711134412_item	3560983	et	3	main
üldse	doc_59711134412_item	3560985	et	3	main
väga	doc_59711134412_item	3560993	et	3	main
kalapüük	doc_59711134412_item	3560996	et	3	main
püüi	doc_59711134412_item	3561002	et	4	main
huvitavam	doc_59711134412_item	3561013	et	4	main
ja	doc_59711134412_item	3561014	et	3	main
kõik	doc_59711134412_item	3561015	et	4	main
teised	doc_59711134412_item	3561016	et	4	main
ka	doc_59711134412_item	3561017	et	3	main
vanaema	doc_59711134412_item	3561018	et	4	main
tutvustas	doc_59711134412_item	3561019	et	3	main
minu	doc_59711134412_item	3561020	et	3	main
ühe	doc_59711134412_item	3561021	et	4	main
ta	doc_59711134412_item	3561023	et	4	main
neiuga	doc_59711134412_item	3561022	et	4	main
näitas	doc_59711134412_item	3561024	et	3	main
mulle	doc_59711134412_item	3561025	et	4	main
jõululinna	doc_59711134412_item	3561026	et	4	main
me	doc_59711134412_item	3561027	et	4	main
küllastasime	doc_59711134412_item	3561028	et	3	main
erakordselt	doc_59711134412_item	3561039	et	4	main
on	doc_59711134412_item	3561044	et	4	main
jõuluehted	doc_59711134412_item	3561047	et	3	main
on	doc_59711134412_item	3561049	et	4	main
nii	doc_59711134412_item	3561050	et	3	main
palju	doc_59711134412_item	3561051	et	4	main
jõulupüha	doc_59711134412_item	3561061	et	4	main
tuntakse	doc_59711134412_item	3561062	et	3	main
nädal	doc_59711134412_item	3561066	et	3	main
ma	doc_193540241556_item	3561112	et	3	main
söön	doc_193540241556_item	3561130	et	3	main
üle	doc_193540241556_item	3561136	et	3	main
restoranis	doc_193540241556_item	3561161	et	3	main
või	doc_193540241556_item	3561165	et	4	main
ma	doc_193540241556_item	3561168	et	3	main
õppin	doc_193540241556_item	3561173	et	4	main
vene	doc_193540241556_item	3561174	et	4	main
keelt	doc_193540241556_item	3561175	et	4	main
ja	doc_193540241556_item	3561176	et	3	main
hispaania	doc_193540241556_item	3561177	et	4	main
keelt	doc_193540241556_item	3561178	et	4	main
kasvu	doc_193540241556_item	3561194	et	4	main
tal	doc_193540241556_item	3561195	et	3	main
on	doc_193540241556_item	3561196	et	4	main
rohelised	doc_193540241556_item	3561197	et	4	main
silmad	doc_193540241556_item	3561198	et	4	main
ja	doc_193540241556_item	3561199	et	3	main
august	doc_193540241556_item	3561209	et	4	main
ma	doc_193540241556_item	3561184	et	3	main
bussiga	doc_193540241556_item	3561188	et	3	main
ja	doc_193540241556_item	3561189	et	3	main
teotahteline	doc_193540241556_item	3561190	et	4	main
on	doc_193540241556_item	3561192	et	4	main
tal	doc_193540241556_item	3561202	et	3	main
prillid	doc_193540241556_item	3561204	et	3	main
talle	doc_193540241556_item	3561205	et	4	main
meeldivad	doc_193540241556_item	3561206	et	4	main
reisid	doc_193540241556_item	3561207	et	4	main
alates	doc_193540241556_item	3561208	et	3	main
saanud	doc_193540241557_item	3561264	et	4	main
sõpradeks	doc_193540241557_item	3561265	et	3	main
aastat	doc_193540241557_item	3561283	et	3	main
on	doc_193540241557_item	3561297	et	4	main
inimesedega	doc_193540241557_item	3561326	et	4	main
sõpradeks	doc_193540241557_item	3561329	et	3	main
ma	doc_193540241557_item	3561343	et	3	main
aastat	doc_193540241557_item	3561348	et	3	main
meeldib	doc_193540241557_item	3561350	et	3	main
ma	doc_193540241558_item	3561393	et	3	main
ma	doc_193540241558_item	3561397	et	3	main
kahjuks	doc_193540241558_item	3561401	et	4	main
peab	doc_193540241558_item	3561403	et	4	main
õpingud	doc_193540241558_item	3561411	et	3	main
hollandis	doc_193540241558_item	3561435	et	4	main
keelt	doc_193540241558_item	3561442	et	4	main
võib-olla	doc_193540241558_item	3561443	et	3	main
meeldib	doc_193540241558_item	3561455	et	3	main
ma	doc_193540241558_item	3561489	et	3	main
pere	doc_193540241558_item	3561517	et	4	main
ja	doc_193540241558_item	3561518	et	3	main
oma	doc_193540241558_item	3561519	et	4	main
aga	doc_193540241558_item	3561526	et	3	main
tulevikuplaanid	doc_193540241558_item	3561529	et	3	main
olen	doc_193540241556_item	3561211	et	3	main
kodus	doc_193540241556_item	3561212	et	4	main
ma	doc_193540241556_item	3561213	et	3	main
pesen	doc_193540241556_item	3561214	et	3	main
pesu	doc_193540241556_item	3561215	et	4	main
ma	doc_193540241556_item	3561216	et	3	main
mängin	doc_193540241556_item	3561217	et	3	main
tennist	doc_193540241556_item	3561218	et	3	main
räägin	doc_193540241556_item	3561219	et	3	main
sõbraga	doc_193540241556_item	3561220	et	3	main
ma	doc_193540241556_item	3561221	et	3	main
olen	doc_193540241556_item	3561222	et	3	main
peol	doc_193540241556_item	3561223	et	4	main
kui	doc_193540241556_item	3561224	et	3	main
ilm	doc_193540241556_item	3561225	et	3	main
on	doc_193540241556_item	3561226	et	4	main
ilus	doc_193540241556_item	3561227	et	4	main
ma	doc_193540241556_item	3561228	et	3	main
lähen	doc_193540241556_item	3561229	et	3	main
randa	doc_193540241556_item	3561230	et	4	main
ma	doc_193540241556_item	3561231	et	3	main
ujun	doc_193540241556_item	3561232	et	3	main
ma	doc_193540241556_item	3561233	et	3	main
mängin	doc_193540241556_item	3561234	et	3	main
ma	doc_193540241556_item	3561235	et	3	main
päevitan	doc_193540241556_item	3561236	et	3	main
ja	doc_193540241556_item	3561237	et	3	main
õhtul	doc_193540241556_item	3561238	et	3	main
ma	doc_193540241556_item	3561239	et	3	main
söön	doc_193540241556_item	3561240	et	3	main
grillpraadi	doc_193540241556_item	3561241	et	4	main
ja	doc_193540241556_item	3561242	et	3	main
ma	doc_193540241556_item	3561243	et	3	main
lähen	doc_193540241556_item	3561244	et	3	main
kodus	doc_193540241556_item	3561245	et	4	main
essee	doc_193540241557_item	3561247	et	4	main
üle	doc_193540241557_item	3561250	et	3	main
maailmas	doc_193540241557_item	3561252	et	3	main
oleks	doc_193540241557_item	3561255	et	3	main
küllaldase	doc_193540241557_item	3561256	et	3	main
tahan	doc_193540241557_item	3561259	et	3	main
eesti	doc_193540241557_item	3561266	et	4	main
palju	doc_193540241557_item	3561270	et	4	main
külastada	doc_193540241557_item	3561274	et	3	main
olen	doc_193540241557_item	3561278	et	3	main
õpinud	doc_193540241557_item	3561279	et	4	main
inglise	doc_193540241557_item	3561280	et	4	main
õpinud	doc_193540241557_item	3561287	et	4	main
keelt	doc_193540241557_item	3561292	et	4	main
kogu	doc_193540241557_item	3561251	et	4	main
mul	doc_193540241557_item	3561254	et	3	main
raha	doc_193540241557_item	3561257	et	4	main
ma	doc_193540241557_item	3561258	et	3	main
oleda	doc_193540241557_item	3561260	et	4	main
ja	doc_193540241557_item	3561267	et	3	main
tallinnas	doc_193540241557_item	3561271	et	4	main
tahan	doc_193540241557_item	3561273	et	3	main
sõpradega	doc_193540241557_item	3561276	et	3	main
kaheksa	doc_193540241557_item	3561282	et	4	main
keel	doc_193540241557_item	3561296	et	4	main
väga	doc_193540241557_item	3561298	et	3	main
raske	doc_193540241557_item	3561299	et	4	main
nii	doc_193540241557_item	3561300	et	3	main
ma	doc_193540241557_item	3561301	et	3	main
ei	doc_193540241557_item	3561302	et	4	main
oska	doc_193540241557_item	3561303	et	4	main
rääkida	doc_193540241557_item	3561304	et	3	main
eesti	doc_193540241557_item	3561305	et	4	main
keelt	doc_193540241557_item	3561306	et	4	main
hästi	doc_193540241557_item	3561307	et	3	main
veel	doc_193540241557_item	3561308	et	4	main
see	doc_193540241557_item	3561309	et	3	main
on	doc_193540241557_item	3561310	et	4	main
huvitav	doc_193540241557_item	3561311	et	4	main
aga	doc_193540241557_item	3561312	et	3	main
võimatu	doc_193540241557_item	3561313	et	4	main
ma	doc_193540241557_item	3561314	et	3	main
oskan	doc_193540241557_item	3561315	et	3	main
rääkida	doc_193540241557_item	3561316	et	3	main
kolm	doc_193540241557_item	3561317	et	3	main
keelt	doc_193540241557_item	3561318	et	4	main
tulevikus	doc_193540241557_item	3561319	et	4	main
ma	doc_193540241557_item	3561320	et	3	main
käin	doc_193540241557_item	3561321	et	3	main
venemaal	doc_193540241557_item	3561322	et	4	main
saksamaal	doc_193540241557_item	3561323	et	4	main
ja	doc_193540241557_item	3561324	et	3	main
räägin	doc_193540241557_item	3561325	et	3	main
ja	doc_193540241557_item	3561327	et	3	main
jala	doc_193540241557_item	3561341	et	4	main
aga	doc_193540241557_item	3561342	et	3	main
olen	doc_193540241557_item	3561344	et	3	main
elanud	doc_193540241557_item	3561345	et	4	main
jaapanis	doc_193540241557_item	3561346	et	4	main
pool	doc_193540241557_item	3561293	et	4	main
aastat	doc_193540241557_item	3561294	et	3	main
eesti	doc_193540241557_item	3561295	et	4	main
saame	doc_193540241557_item	3561328	et	4	main
nendega	doc_193540241557_item	3561330	et	4	main
mul	doc_193540241557_item	3561331	et	3	main
sõbrad	doc_193540241557_item	3561333	et	3	main
essee	doc_193540241558_item	3561391	et	4	main
olen	doc_193540241558_item	3561398	et	3	main
pärast	doc_193540241558_item	3561409	et	4	main
minu	doc_193540241558_item	3561410	et	3	main
kui	doc_193540241558_item	3561438	et	3	main
ma	doc_193540241558_item	3561439	et	3	main
opin	doc_193540241558_item	3561440	et	4	main
leida	doc_193540241558_item	3561451	et	3	main
veel	doc_193540241558_item	3561459	et	4	main
vene	doc_193540241558_item	3561486	et	4	main
tulevikus	doc_193540241558_item	3561513	et	4	main
mul	doc_193540241558_item	3561514	et	3	main
väike	doc_193540241558_item	3561520	et	4	main
ja	doc_193540241558_item	3561521	et	3	main
essee	doc_193540241559_item	3561534	et	4	main
tulevik	doc_193540241559_item	3561536	et	3	main
ma	doc_193540241559_item	3561538	et	3	main
ma	doc_193540241559_item	3561542	et	3	main
ma	doc_193540241559_item	3561553	et	3	main
kivimaja	doc_193540241559_item	3561558	et	4	main
lapsega	doc_193540241559_item	3561560	et	3	main
kassiga	doc_193540241559_item	3561562	et	4	main
maja	doc_193540241559_item	3561563	et	4	main
keskaias	doc_193540241559_item	3561574	et	4	main
jaapan	doc_193540241557_item	3561351	et	4	main
nii	doc_193540241557_item	3561352	et	3	main
ma	doc_193540241557_item	3561353	et	3	main
tulen	doc_193540241557_item	3561354	et	3	main
tagasi	doc_193540241557_item	3561355	et	3	main
jaapanisse	doc_193540241557_item	3561356	et	4	main
ja	doc_193540241557_item	3561357	et	3	main
ma	doc_193540241557_item	3561358	et	3	main
elan	doc_193540241557_item	3561359	et	3	main
minu	doc_193540241557_item	3561360	et	3	main
perega	doc_193540241557_item	3561361	et	3	main
elatud	doc_193540241557_item	3561362	et	4	main
maja	doc_193540241557_item	3561363	et	4	main
on	doc_193540241557_item	3561364	et	4	main
vana	doc_193540241557_item	3561365	et	4	main
ja	doc_193540241557_item	3561366	et	3	main
väike	doc_193540241557_item	3561367	et	4	main
aga	doc_193540241557_item	3561368	et	3	main
ilus	doc_193540241557_item	3561369	et	4	main
ja	doc_193540241557_item	3561370	et	3	main
mugav	doc_193540241557_item	3561371	et	3	main
minu	doc_193540241557_item	3561372	et	3	main
sõbrad	doc_193540241557_item	3561373	et	3	main
tulevad	doc_193540241557_item	3561374	et	4	main
minu	doc_193540241557_item	3561375	et	3	main
koju	doc_193540241557_item	3561376	et	3	main
ja	doc_193540241557_item	3561377	et	3	main
me	doc_193540241557_item	3561378	et	4	main
rääkime	doc_193540241557_item	3561379	et	4	main
me	doc_193540241557_item	3561380	et	4	main
sõime	doc_193540241557_item	3561381	et	4	main
hommikust	doc_193540241557_item	3561382	et	4	main
lõunat	doc_193540241557_item	3561383	et	3	main
ja	doc_193540241557_item	3561384	et	3	main
õhtust	doc_193540241557_item	3561385	et	4	main
kokku	doc_193540241557_item	3561386	et	3	main
me	doc_193540241557_item	3561387	et	4	main
oleme	doc_193540241557_item	3561388	et	3	main
õnnelik	doc_193540241557_item	3561389	et	3	main
teen	doc_193540241558_item	3561394	et	3	main
mitu	doc_193540241558_item	3561406	et	4	main
aastat	doc_193540241558_item	3561407	et	3	main
aga	doc_193540241558_item	3561408	et	3	main
või	doc_193540241558_item	3561436	et	4	main
ma	doc_193540241558_item	3561449	et	3	main
mis	doc_193540241558_item	3561453	et	4	main
rahvusvahelises	doc_193540241558_item	3561472	et	4	main
organisatsioonis	doc_193540241558_item	3561473	et	3	main
mis	doc_193540241558_item	3561392	et	4	main
üliõpilane	doc_193540241558_item	3561399	et	3	main
minu	doc_193540241558_item	3561402	et	3	main
ma	doc_193540241558_item	3561412	et	3	main
sooviksin	doc_193540241558_item	3561413	et	3	main
elada	doc_193540241558_item	3561414	et	3	main
välismaal	doc_193540241558_item	3561415	et	4	main
ma	doc_193540241558_item	3561416	et	3	main
olen	doc_193540241558_item	3561417	et	3	main
juba	doc_193540241558_item	3561418	et	3	main
elanud	doc_193540241558_item	3561419	et	4	main
välismaal	doc_193540241558_item	3561420	et	4	main
viis	doc_193540241558_item	3561421	et	4	main
aastat	doc_193540241558_item	3561422	et	3	main
aga	doc_193540241558_item	3561423	et	3	main
ma	doc_193540241558_item	3561424	et	3	main
tahan	doc_193540241558_item	3561425	et	3	main
elada	doc_193540241558_item	3561426	et	3	main
seal	doc_193540241558_item	3561427	et	4	main
kus	doc_193540241558_item	3561428	et	3	main
ma	doc_193540241558_item	3561429	et	3	main
ei	doc_193540241558_item	3561430	et	4	main
veel	doc_193540241558_item	3561432	et	4	main
sveitsis	doc_193540241558_item	3561437	et	4	main
sooviksin	doc_193540241558_item	3561450	et	3	main
töö	doc_193540241558_item	3561452	et	4	main
mul	doc_193540241558_item	3561454	et	3	main
tulevikus	doc_193540241558_item	3561465	et	4	main
võib-olla	doc_193540241558_item	3561467	et	3	main
töötada	doc_193540241558_item	3561471	et	3	main
tulevikus	doc_193540241558_item	3561474	et	4	main
opin	doc_193540241558_item	3561476	et	4	main
ma	doc_193540241558_item	3561479	et	3	main
räägida	doc_193540241558_item	3561481	et	4	main
parem	doc_193540241558_item	3561482	et	4	main
prantsuse	doc_193540241558_item	3561483	et	3	main
eesti	doc_193540241558_item	3561484	et	4	main
ja	doc_193540241558_item	3561485	et	3	main
oma	doc_193540241558_item	3561516	et	4	main
tavaliselt	doc_193540241558_item	3561527	et	4	main
minu	doc_193540241559_item	3561535	et	3	main
praegu	doc_193540241559_item	3561537	et	3	main
õpin	doc_193540241559_item	3561539	et	3	main
ajakirjandus	doc_193540241559_item	3561540	et	3	main
ei	doc_193540241559_item	3561543	et	4	main
taha	doc_193540241559_item	3561544	et	4	main
töötada	doc_193540241559_item	3561545	et	3	main
ajakirjanikuks	doc_193540241559_item	3561546	et	3	main
ma	doc_193540241559_item	3561547	et	3	main
tahan	doc_193540241559_item	3561548	et	3	main
kirjutada	doc_193540241559_item	3561549	et	3	main
suures	doc_193540241559_item	3561556	et	3	main
ja	doc_193540241559_item	3561561	et	3	main
tamm	doc_193540241559_item	3561573	et	3	main
on	doc_193540241559_item	3561576	et	4	main
maja	doc_193540241559_item	3561577	et	4	main
spordiauto	doc_193540241559_item	3561581	et	4	main
essee	doc_193540241560_item	3561637	et	4	main
mees	doc_193540241560_item	3561661	et	4	main
ja	doc_193540241560_item	3561662	et	3	main
lapsid	doc_193540241560_item	3561663	et	3	main
ma	doc_193540241560_item	3561664	et	3	main
elan	doc_193540241560_item	3561665	et	3	main
ilus	doc_193540241560_item	3561666	et	4	main
meri	doc_193540241560_item	3561672	et	3	main
päevitan	doc_193540241560_item	3561680	et	3	main
sõbraga	doc_193540241560_item	3561714	et	3	main
ma	doc_193540241560_item	3561715	et	3	main
ka	doc_193540241560_item	3561716	et	3	main
ma	doc_193540241560_item	3561719	et	3	main
tants	doc_193540241560_item	3561721	et	3	main
võimlemine	doc_193540241560_item	3561722	et	4	main
ma	doc_193540241560_item	3561723	et	3	main
loodan	doc_193540241560_item	3561724	et	3	main
olema	doc_193540241560_item	3561725	et	4	main
õnnelik	doc_193540241560_item	3561726	et	3	main
mõned	doc_193540241560_item	3561731	et	3	main
prantsuse	doc_193540241558_item	3561441	et	3	main
et	doc_193540241558_item	3561444	et	3	main
ma	doc_193540241558_item	3561445	et	3	main
elan	doc_193540241558_item	3561446	et	3	main
ka	doc_193540241558_item	3561447	et	3	main
prantsusmaal	doc_193540241558_item	3561448	et	4	main
missugune	doc_193540241558_item	3561460	et	3	main
töö	doc_193540241558_item	3561461	et	4	main
ma	doc_193540241558_item	3561462	et	3	main
sooviksin	doc_193540241558_item	3561463	et	3	main
leida	doc_193540241558_item	3561464	et	3	main
et	doc_193540241558_item	3561468	et	3	main
ma	doc_193540241558_item	3561469	et	3	main
ma	doc_193540241558_item	3561475	et	3	main
ka	doc_193540241558_item	3561477	et	3	main
keeled	doc_193540241558_item	3561478	et	3	main
keelt	doc_193540241558_item	3561487	et	4	main
ning	doc_193540241558_item	3561488	et	3	main
ka	doc_193540241558_item	3561491	et	3	main
oppida	doc_193540241558_item	3561492	et	4	main
portugali	doc_193540241558_item	3561493	et	4	main
keelt	doc_193540241558_item	3561494	et	4	main
kuni	doc_193540241558_item	3561495	et	3	main
ma	doc_193540241558_item	3561496	et	3	main
oskan	doc_193540241558_item	3561497	et	3	main
mitu	doc_193540241558_item	3561498	et	4	main
keelt	doc_193540241558_item	3561499	et	4	main
ja	doc_193540241558_item	3561500	et	3	main
kui	doc_193540241558_item	3561501	et	3	main
mul	doc_193540241558_item	3561502	et	3	main
oliks	doc_193540241558_item	3561503	et	4	main
palju	doc_193540241558_item	3561504	et	4	main
rahad	doc_193540241558_item	3561505	et	4	main
ma	doc_193540241558_item	3561506	et	3	main
võin	doc_193540241558_item	3561507	et	3	main
reisida	doc_193540241558_item	3561508	et	3	main
paljuseid	doc_193540241558_item	3561509	et	4	main
maaid	doc_193540241558_item	3561510	et	4	main
sellele	doc_193540241558_item	3561511	et	4	main
lisaks	doc_193540241558_item	3561512	et	4	main
ma	doc_193540241558_item	3561456	et	3	main
ei	doc_193540241558_item	3561457	et	4	main
tea	doc_193540241558_item	3561458	et	4	main
aga	doc_193540241558_item	3561466	et	3	main
sooviksin	doc_193540241558_item	3561470	et	3	main
tahan	doc_193540241558_item	3561480	et	3	main
tahan	doc_193540241558_item	3561490	et	3	main
ääres	doc_193540241558_item	3561525	et	4	main
kuid	doc_193540241559_item	3561541	et	4	main
ja	doc_193540241559_item	3561551	et	3	main
tahan	doc_193540241559_item	3561554	et	3	main
mehega	doc_193540241559_item	3561559	et	3	main
kirsipuud	doc_193540241559_item	3561570	et	4	main
ja	doc_193540241559_item	3561571	et	3	main
ta	doc_193540241559_item	3561579	et	4	main
on	doc_193540241559_item	3561580	et	4	main
ma	doc_193540241560_item	3561639	et	3	main
mulle	doc_193540241560_item	3561643	et	4	main
inglise	doc_193540241560_item	3561657	et	4	main
kodus	doc_193540241560_item	3561667	et	4	main
perega	doc_193540241560_item	3561668	et	3	main
mulle	doc_193540241560_item	3561669	et	4	main
meeldiksin	doc_193540241560_item	3561670	et	3	main
hommikust	doc_193540241560_item	3561681	et	4	main
jalutan	doc_193540241560_item	3561717	et	3	main
õppima	doc_193540241560_item	3561730	et	3	main
külla	doc_193540241560_item	3561735	et	4	main
ma	doc_193540241561_item	3561752	et	3	main
ulikooli	doc_193540241561_item	3561764	et	4	main
õpetaja	doc_193540241561_item	3561765	et	4	main
räägida	doc_193540241561_item	3561771	et	4	main
ja	doc_193540241561_item	3561772	et	3	main
olen	doc_193540241561_item	3561780	et	3	main
praegu	doc_193540241561_item	3561781	et	3	main
juba	doc_193540241561_item	3561788	et	3	main
käinud	doc_193540241561_item	3561802	et	4	main
ja	doc_193540241561_item	3561805	et	3	main
aga	doc_193540241561_item	3561820	et	3	main
maakohtis	doc_193540241561_item	3561829	et	4	main
ei	doc_193540241561_item	3561830	et	4	main
tokios	doc_193540241561_item	3561837	et	4	main
umbes	doc_193540241561_item	3561844	et	4	main
ja	doc_193540241561_item	3561871	et	3	main
iga	doc_193540241561_item	3561883	et	4	main
öösel	doc_193540241561_item	3561899	et	4	main
ma	doc_193540241561_item	3561900	et	3	main
taevas	doc_193540241561_item	3561906	et	4	main
üles	doc_193540241561_item	3561907	et	3	main
see	doc_193540241561_item	3561908	et	3	main
mis	doc_193540241562_item	3561923	et	4	main
ma	doc_193540241562_item	3561933	et	3	main
kõneleda	doc_193540241562_item	3561935	et	3	main
ja	doc_193540241562_item	3561939	et	3	main
kaks	doc_193540241562_item	3561948	et	3	main
vanaema	doc_193540241562_item	3561949	et	4	main
ja	doc_193540241562_item	3561950	et	3	main
kaks	doc_193540241562_item	3561951	et	3	main
osta	doc_193540241562_item	3561957	et	4	main
kalevi	doc_193540241562_item	3561963	et	3	main
ma	doc_193540241562_item	3561972	et	3	main
eriti	doc_193540241562_item	3561976	et	3	main
jaapani	doc_193540241562_item	3561979	et	4	main
töö	doc_193540241562_item	3562011	et	4	main
leidma	doc_193540241562_item	3562017	et	3	main
palju	doc_193540241562_item	3562023	et	4	main
aga	doc_193540241562_item	3562025	et	3	main
enne	doc_193540241562_item	3562030	et	4	main
töö	doc_193540241562_item	3562031	et	4	main
mis	doc_193540241563_item	3562113	et	4	main
ma	doc_193540241563_item	3562114	et	3	main
teen	doc_193540241563_item	3562119	et	3	main
näiteks	doc_193540241563_item	3562122	et	4	main
reisin	doc_193540241563_item	3562124	et	3	main
on	doc_193540241563_item	3562133	et	4	main
ei	doc_193540241563_item	3562164	et	4	main
küllaldane	doc_193540241563_item	3562169	et	3	main
elan	doc_193540241563_item	3562173	et	3	main
mulle	doc_193540241563_item	3562185	et	4	main
külla	doc_193540241563_item	3562186	et	4	main
mul	doc_193540241563_item	3562189	et	3	main
abikaasa	doc_193540241563_item	3562191	et	4	main
kohvi	doc_193540241563_item	3562202	et	4	main
on	doc_193540241558_item	3561515	et	4	main
ilus	doc_193540241558_item	3561522	et	4	main
maja	doc_193540241558_item	3561523	et	4	main
mere	doc_193540241558_item	3561524	et	3	main
minu	doc_193540241558_item	3561528	et	3	main
ei	doc_193540241558_item	3561530	et	4	main
ole	doc_193540241558_item	3561531	et	4	main
täitunud	doc_193540241558_item	3561532	et	4	main
juttu	doc_193540241559_item	3561552	et	4	main
elada	doc_193540241559_item	3561555	et	3	main
juures	doc_193540241559_item	3561564	et	4	main
on	doc_193540241559_item	3561565	et	4	main
aed	doc_193540241559_item	3561566	et	3	main
suur	doc_193540241559_item	3561572	et	3	main
auto	doc_193540241559_item	3561575	et	4	main
tulevikus	doc_193540241560_item	3561641	et	4	main
meeldiksin	doc_193540241560_item	3561644	et	3	main
töötama	doc_193540241560_item	3561645	et	3	main
keelt	doc_193540241560_item	3561658	et	4	main
mul	doc_193540241560_item	3561659	et	3	main
juures	doc_193540241560_item	3561673	et	4	main
ma	doc_193540241560_item	3561675	et	3	main
jäätis	doc_193540241560_item	3561677	et	3	main
õhtuni	doc_193540241560_item	3561682	et	3	main
ujun	doc_193540241560_item	3561685	et	3	main
ja	doc_193540241560_item	3561687	et	3	main
ka	doc_193540241560_item	3561729	et	3	main
teised	doc_193540241560_item	3561732	et	4	main
tulevikus	doc_193540241561_item	3561754	et	4	main
olema	doc_193540241561_item	3561766	et	4	main
mulle	doc_193540241561_item	3561767	et	4	main
26	doc_193540241561_item	3561782	et	2	main
asia	doc_193540241561_item	3561795	et	4	main
ida	doc_193540241561_item	3561797	et	4	main
ja	doc_193540241561_item	3561798	et	3	main
olen	doc_193540241561_item	3561801	et	3	main
koht	doc_193540241561_item	3561804	et	3	main
ma	doc_193540241561_item	3561821	et	3	main
maakohti	doc_193540241561_item	3561824	et	4	main
elaks	doc_193540241561_item	3561839	et	3	main
lapsed	doc_193540241561_item	3561872	et	3	main
ma	doc_193540241561_item	3561893	et	3	main
vootaks	doc_193540241561_item	3561894	et	3	main
ostaks	doc_193540241561_item	3561896	et	3	main
valia	doc_193540241561_item	3561903	et	4	main
ilus	doc_193540241561_item	3561911	et	4	main
ma	doc_193540241561_item	3561913	et	3	main
ei	doc_193540241561_item	3561914	et	4	main
et	doc_193540241561_item	3561916	et	3	main
kuht	doc_193540241561_item	3561917	et	4	main
minu	doc_193540241561_item	3561918	et	3	main
tulevikus	doc_193540241562_item	3561926	et	4	main
ma	doc_193540241562_item	3561930	et	3	main
ema	doc_193540241562_item	3561946	et	4	main
ma	doc_193540241562_item	3561955	et	3	main
šokolaadid	doc_193540241562_item	3561964	et	2	main
käsitööd	doc_193540241562_item	3561966	et	4	main
meeldib	doc_193540241562_item	3561968	et	3	main
sest	doc_193540241562_item	3561978	et	4	main
et	doc_193540241562_item	3562016	et	3	main
kuigi	doc_193540241562_item	3562020	et	3	main
seal	doc_193540241562_item	3562021	et	4	main
kirjutada	doc_193540241559_item	3561615	et	3	main
eluloost	doc_193540241559_item	3561616	et	4	main
ma	doc_193540241559_item	3561617	et	3	main
tahan	doc_193540241559_item	3561618	et	3	main
õppida	doc_193540241559_item	3561619	et	3	main
keelt	doc_193540241559_item	3561621	et	4	main
eesti	doc_193540241559_item	3561620	et	4	main
ja	doc_193540241559_item	3561622	et	3	main
võimalikult	doc_193540241559_item	3561623	et	4	main
kirjutada	doc_193540241559_item	3561624	et	3	main
jutt	doc_193540241559_item	3561625	et	3	main
eesti	doc_193540241559_item	3561626	et	4	main
keelel	doc_193540241559_item	3561627	et	4	main
ma	doc_193540241559_item	3561628	et	3	main
tahan	doc_193540241559_item	3561629	et	3	main
olla	doc_193540241559_item	3561630	et	3	main
tubli	doc_193540241559_item	3561631	et	4	main
inimene	doc_193540241559_item	3561632	et	3	main
ja	doc_193540241559_item	3561633	et	3	main
pakkuma	doc_193540241559_item	3561634	et	3	main
rahuldust	doc_193540241559_item	3561635	et	4	main
muinasjuttu	doc_193540241559_item	3561550	et	4	main
ilusas	doc_193540241559_item	3561557	et	3	main
aias	doc_193540241559_item	3561567	et	4	main
on	doc_193540241559_item	3561568	et	4	main
õunapuud	doc_193540241559_item	3561569	et	4	main
ees	doc_193540241559_item	3561578	et	4	main
audi	doc_193540241559_item	3561582	et	3	main
tt	doc_193540241559_item	3561583	et	4	main
ja	doc_193540241559_item	3561584	et	3	main
ta	doc_193540241559_item	3561585	et	4	main
on	doc_193540241559_item	3561586	et	4	main
punane	doc_193540241559_item	3561587	et	4	main
minu	doc_193540241559_item	3561588	et	3	main
kass	doc_193540241559_item	3561589	et	3	main
on	doc_193540241559_item	3561590	et	4	main
suur	doc_193540241559_item	3561591	et	3	main
ja	doc_193540241559_item	3561592	et	3	main
kohev	doc_193540241559_item	3561593	et	3	main
ta	doc_193540241559_item	3561594	et	4	main
meeldib	doc_193540241559_item	3561595	et	3	main
magada	doc_193540241559_item	3561596	et	3	main
ja	doc_193540241559_item	3561597	et	3	main
süüa	doc_193540241559_item	3561598	et	3	main
seepärast	doc_193540241559_item	3561599	et	3	main
ta	doc_193540241559_item	3561600	et	4	main
on	doc_193540241559_item	3561601	et	4	main
suur	doc_193540241559_item	3561602	et	3	main
ma	doc_193540241559_item	3561603	et	3	main
tahan	doc_193540241559_item	3561604	et	3	main
kirjutada	doc_193540241559_item	3561605	et	3	main
hea	doc_193540241559_item	3561606	et	4	main
juttu	doc_193540241559_item	3561607	et	4	main
tahan	doc_193540241559_item	3561609	et	3	main
ma	doc_193540241559_item	3561608	et	3	main
kirjutada	doc_193540241559_item	3561610	et	3	main
elust	doc_193540241559_item	3561611	et	3	main
ja	doc_193540241559_item	3561612	et	3	main
ma	doc_193540241559_item	3561613	et	3	main
tahan	doc_193540241559_item	3561614	et	3	main
teen	doc_193540241560_item	3561640	et	3	main
tulevikus	doc_193540241560_item	3561642	et	4	main
seeleks	doc_193540241560_item	3561646	et	4	main
elatist	doc_193540241560_item	3561647	et	3	main
teenima	doc_193540241560_item	3561648	et	3	main
ma	doc_193540241560_item	3561649	et	3	main
olen	doc_193540241560_item	3561650	et	3	main
tõlkija	doc_193540241560_item	3561651	et	4	main
ma	doc_193540241560_item	3561652	et	3	main
räägin	doc_193540241560_item	3561653	et	3	main
on	doc_193540241560_item	3561660	et	4	main
peregi	doc_193540241560_item	3561737	et	4	main
belgias	doc_193540241560_item	3561738	et	4	main
see	doc_193540241560_item	3561739	et	3	main
suvel	doc_193540241560_item	3561740	et	3	main
ma	doc_193540241560_item	3561741	et	3	main
kutsun	doc_193540241560_item	3561742	et	3	main
sõbragi	doc_193540241560_item	3561743	et	3	main
kodus	doc_193540241560_item	3561744	et	4	main
mis	doc_193540241560_item	3561638	et	4	main
eesti	doc_193540241560_item	3561654	et	4	main
vene	doc_193540241560_item	3561655	et	4	main
ja	doc_193540241560_item	3561656	et	3	main
mereäärnes	doc_193540241560_item	3561674	et	4	main
ma	doc_193540241560_item	3561679	et	3	main
meris	doc_193540241560_item	3561686	et	4	main
loen	doc_193540241560_item	3561688	et	3	main
raamatud	doc_193540241560_item	3561689	et	4	main
ma	doc_193540241560_item	3561690	et	3	main
väga	doc_193540241560_item	3561691	et	3	main
reisin	doc_193540241560_item	3561692	et	3	main
ma	doc_193540241560_item	3561693	et	3	main
käin	doc_193540241560_item	3561694	et	3	main
aasias	doc_193540241560_item	3561695	et	4	main
aafrikas	doc_193540241560_item	3561696	et	4	main
ja	doc_193540241560_item	3561697	et	3	main
lõuna-ameerikas	doc_193540241560_item	3561698	et	4	main
mul	doc_193540241560_item	3561699	et	3	main
on	doc_193540241560_item	3561700	et	4	main
sõbrad	doc_193540241560_item	3561701	et	3	main
ma	doc_193540241560_item	3561702	et	3	main
lähen	doc_193540241560_item	3561703	et	3	main
poes	doc_193540241560_item	3561704	et	3	main
käin	doc_193540241560_item	3561705	et	3	main
restoranis	doc_193540241560_item	3561706	et	3	main
kinos	doc_193540241560_item	3561707	et	3	main
olen	doc_193540241560_item	3561708	et	3	main
peol	doc_193540241560_item	3561709	et	4	main
kuulan	doc_193540241560_item	3561710	et	3	main
muusikat	doc_193540241560_item	3561711	et	3	main
ja	doc_193540241560_item	3561712	et	3	main
räägin	doc_193540241560_item	3561713	et	3	main
elama	doc_193540241560_item	3561671	et	3	main
söön	doc_193540241560_item	3561676	et	3	main
ja	doc_193540241560_item	3561678	et	3	main
ma	doc_193540241560_item	3561683	et	3	main
ka	doc_193540241560_item	3561684	et	3	main
parkis	doc_193540241560_item	3561718	et	3	main
sportin	doc_193540241560_item	3561720	et	4	main
meeldiksin	doc_193540241560_item	3561728	et	3	main
ma	doc_193540241560_item	3561734	et	3	main
essee	doc_193540241561_item	3561746	et	4	main
ei	doc_193540241561_item	3561748	et	4	main
tea	doc_193540241561_item	3561749	et	4	main
et	doc_193540241561_item	3561750	et	3	main
mis	doc_193540241561_item	3561751	et	4	main
palju	doc_193540241561_item	3561758	et	4	main
tegelda	doc_193540241561_item	3561760	et	4	main
esimenel	doc_193540241561_item	3561761	et	4	main
ma	doc_193540241561_item	3561762	et	3	main
soovin	doc_193540241561_item	3561763	et	3	main
meldiv	doc_193540241561_item	3561768	et	4	main
noore	doc_193540241561_item	3561769	et	3	main
aastat	doc_193540241561_item	3561783	et	3	main
olen	doc_193540241561_item	3561787	et	3	main
palju	doc_193540241561_item	3561790	et	4	main
korea	doc_193540241561_item	3561793	et	4	main
eesti	doc_193540241561_item	3561799	et	4	main
ma	doc_193540241561_item	3561800	et	3	main
ilusam	doc_193540241561_item	3561803	et	4	main
saanud	doc_193540241561_item	3561806	et	4	main
palju	doc_193540241561_item	3561807	et	4	main
võiks	doc_193540241561_item	3561815	et	4	main
minu	doc_193540241561_item	3561816	et	3	main
kogemus	doc_193540241561_item	3561817	et	3	main
loengus	doc_193540241561_item	3561818	et	3	main
töötaks	doc_193540241561_item	3561836	et	4	main
maakohtis	doc_193540241561_item	3561840	et	4	main
oleks	doc_193540241561_item	3561842	et	3	main
oma	doc_193540241561_item	3561869	et	4	main
sooviks	doc_193540241561_item	3561874	et	4	main
puumaja	doc_193540241561_item	3561875	et	4	main
ostada	doc_193540241561_item	3561877	et	4	main
minu	doc_193540241561_item	3561878	et	3	main
pere	doc_193540241561_item	3561879	et	4	main
läheks	doc_193540241561_item	3561880	et	3	main
see	doc_193540241561_item	3561881	et	3	main
puumajale	doc_193540241561_item	3561882	et	3	main
maakohtis	doc_193540241561_item	3561892	et	4	main
mägile	doc_193540241561_item	3561895	et	4	main
oleks	doc_193540241561_item	3561909	et	3	main
aga	doc_193540241561_item	3561912	et	3	main
essee	doc_193540241562_item	3561922	et	4	main
kui	doc_193540241562_item	3561929	et	3	main
on	doc_193540241562_item	3561945	et	4	main
jaapanis	doc_193540241562_item	3561953	et	4	main
ja	doc_193540241562_item	3561954	et	3	main
palju	doc_193540241562_item	3561958	et	4	main
minu	doc_193540241562_item	3561960	et	3	main
näiteks	doc_193540241562_item	3561962	et	4	main
ning	doc_193540241562_item	3561965	et	3	main
tallinn	doc_193540241562_item	3561970	et	4	main
tahan	doc_193540241562_item	3561973	et	3	main
suvel	doc_193540241562_item	3561977	et	3	main
on	doc_193540241562_item	3562014	et	4	main
raske	doc_193540241562_item	3562015	et	4	main
lõpetama	doc_193540241562_item	3562029	et	4	main
on	doc_193540241562_item	3562033	et	4	main
raske	doc_193540241562_item	3562080	et	4	main
ja	doc_193540241562_item	3562081	et	3	main
aega	doc_193540241562_item	3562086	et	4	main
mulle	doc_193540241560_item	3561727	et	4	main
keeled	doc_193540241560_item	3561733	et	3	main
lähen	doc_193540241560_item	3561736	et	3	main
ma	doc_193540241561_item	3561747	et	3	main
aga	doc_193540241561_item	3561755	et	3	main
ma	doc_193540241561_item	3561756	et	3	main
õpliopilasele	doc_193540241561_item	3561770	et	4	main
aga	doc_193540241561_item	3561785	et	3	main
ma	doc_193540241561_item	3561786	et	3	main
kagu	doc_193540241561_item	3561794	et	4	main
sõbrid	doc_193540241561_item	3561808	et	4	main
kasutada	doc_193540241561_item	3561819	et	3	main
jaapani	doc_193540241561_item	3561823	et	4	main
ole	doc_193540241561_item	3561831	et	4	main
palju	doc_193540241561_item	3561832	et	4	main
töötid	doc_193540241561_item	3561833	et	4	main
kui	doc_193540241561_item	3561834	et	3	main
ma	doc_193540241561_item	3561835	et	3	main
see	doc_193540241561_item	3561841	et	3	main
tavaliselt	doc_193540241561_item	3561843	et	4	main
3	doc_193540241561_item	3561845	et	2	main
tundi	doc_193540241561_item	3561846	et	4	main
koju	doc_193540241561_item	3561847	et	3	main
töötale	doc_193540241561_item	3561848	et	4	main
bussiga	doc_193540241561_item	3561849	et	3	main
ja	doc_193540241561_item	3561850	et	3	main
jaamga	doc_193540241561_item	3561851	et	4	main
see	doc_193540241561_item	3561852	et	3	main
oleks	doc_193540241561_item	3561853	et	3	main
halb	doc_193540241561_item	3561854	et	3	main
võib-olla	doc_193540241561_item	3561855	et	3	main
ma	doc_193540241561_item	3561856	et	3	main
peaks	doc_193540241561_item	3561857	et	4	main
töötama	doc_193540241561_item	3561859	et	3	main
õpetajani	doc_193540241561_item	3561860	et	4	main
aga	doc_193540241561_item	3561861	et	3	main
ma	doc_193540241561_item	3561862	et	3	main
mõtlen	doc_193540241561_item	3561863	et	3	main
et	doc_193540241561_item	3561864	et	3	main
kui	doc_193540241561_item	3561865	et	3	main
mul	doc_193540241561_item	3561866	et	3	main
oleks	doc_193540241561_item	3561867	et	3	main
minu	doc_193540241561_item	3561868	et	3	main
tokios	doc_193540241561_item	3561858	et	4	main
nädalalõppis	doc_193540241561_item	3561884	et	4	main
või	doc_193540241561_item	3561885	et	4	main
iga	doc_193540241561_item	3561886	et	4	main
suvis	doc_193540241561_item	3561887	et	4	main
minu	doc_193540241561_item	3561888	et	3	main
isa	doc_193540241561_item	3561889	et	4	main
ja	doc_193540241561_item	3561890	et	3	main
emaga	doc_193540241561_item	3561891	et	3	main
oleks	doc_193540241561_item	3561753	et	3	main
tahan	doc_193540241561_item	3561757	et	3	main
midagi	doc_193540241561_item	3561759	et	4	main
õpetada	doc_193540241561_item	3561773	et	3	main
ma	doc_193540241561_item	3561774	et	3	main
olen	doc_193540241561_item	3561775	et	3	main
ka	doc_193540241561_item	3561776	et	3	main
noor	doc_193540241561_item	3561777	et	3	main
sest	doc_193540241561_item	3561778	et	4	main
ma	doc_193540241561_item	3561779	et	3	main
vana	doc_193540241561_item	3561784	et	4	main
reisinud	doc_193540241561_item	3561789	et	4	main
maad	doc_193540241561_item	3561791	et	4	main
hiina	doc_193540241561_item	3561792	et	3	main
keskmine	doc_193540241561_item	3561796	et	3	main
läbi	doc_193540241561_item	3561809	et	4	main
kui	doc_193540241561_item	3561810	et	3	main
ma	doc_193540241561_item	3561811	et	3	main
oleks	doc_193540241561_item	3561812	et	3	main
õpetaja	doc_193540241561_item	3561813	et	4	main
i	doc_193540241561_item	3561814	et	4	main
tahan	doc_193540241561_item	3561822	et	3	main
elada	doc_193540241561_item	3561825	et	3	main
ja	doc_193540241561_item	3561826	et	3	main
puhkada	doc_193540241561_item	3561827	et	4	main
tavaliselt	doc_193540241561_item	3561828	et	4	main
aga	doc_193540241561_item	3561838	et	3	main
pere	doc_193540241561_item	3561870	et	4	main
ma	doc_193540241561_item	3561873	et	3	main
maakohtis	doc_193540241561_item	3561876	et	4	main
tuleks	doc_193540241561_item	3561901	et	4	main
maja	doc_193540241561_item	3561902	et	4	main
väga	doc_193540241561_item	3561910	et	3	main
tea	doc_193540241561_item	3561915	et	4	main
värske	doc_193540241561_item	3561897	et	4	main
toiduaised	doc_193540241561_item	3561898	et	4	main
ja	doc_193540241561_item	3561904	et	3	main
nägeks	doc_193540241561_item	3561905	et	4	main
tulevikus	doc_193540241561_item	3561919	et	4	main
läheks	doc_193540241561_item	3561920	et	3	main
teen	doc_193540241562_item	3561925	et	3	main
tulevik	doc_193540241562_item	3561928	et	3	main
tulen	doc_193540241562_item	3561931	et	3	main
minu	doc_193540241562_item	3561937	et	3	main
ütelda	doc_193540241562_item	3561940	et	4	main
nende	doc_193540241562_item	3561941	et	4	main
elust	doc_193540241562_item	3561942	et	3	main
eestis	doc_193540241562_item	3561943	et	3	main
mul	doc_193540241562_item	3561944	et	3	main
vanaisa	doc_193540241562_item	3561952	et	4	main
asjad	doc_193540241562_item	3561959	et	3	main
ja	doc_193540241562_item	3561971	et	3	main
tulla	doc_193540241562_item	3561974	et	3	main
pean	doc_193540241562_item	3562009	et	4	main
otsima	doc_193540241562_item	3562010	et	4	main
pean	doc_193540241562_item	3562027	et	4	main
see	doc_193540241562_item	3562032	et	3	main
rahvuslik	doc_193540241562_item	3562034	et	3	main
asi	doc_193540241562_item	3562072	et	4	main
aga	doc_193540241562_item	3562073	et	3	main
ma	doc_193540241562_item	3562074	et	3	main
tean	doc_193540241562_item	3562075	et	3	main
ka	doc_193540241562_item	3562076	et	3	main
see	doc_193540241562_item	3562077	et	3	main
pean	doc_193540241562_item	3562083	et	4	main
kasutama	doc_193540241562_item	3562084	et	3	main
ma	doc_193540241563_item	3562118	et	3	main
lapimaale	doc_193540241563_item	3562129	et	4	main
ja	doc_193540241563_item	3562130	et	3	main
mul	doc_193540241563_item	3562140	et	3	main
autot	doc_193540241563_item	3562143	et	3	main
viis	doc_193540241563_item	3562146	et	4	main
hobusest	doc_193540241563_item	3562147	et	4	main
ja	doc_193540241563_item	3562148	et	3	main
kaks	doc_193540241563_item	3562149	et	3	main
palju	doc_193540241563_item	3562166	et	4	main
mul	doc_193540241563_item	3562167	et	3	main
vaba	doc_193540241563_item	3562170	et	4	main
ma	doc_193540241563_item	3562172	et	3	main
minu	doc_193540241563_item	3562181	et	3	main
kaks	doc_193540241563_item	3562182	et	3	main
venda	doc_193540241563_item	3562183	et	4	main
lähevad	doc_193540241563_item	3562184	et	3	main
tulevikus	doc_193540241563_item	3562188	et	4	main
nad	doc_193540241563_item	3562195	et	3	main
suusakuurortisse	doc_193540241563_item	3562230	et	4	main
tulevikus	doc_193540241564_item	3562236	et	4	main
palk	doc_193540241564_item	3562256	et	3	main
neli	doc_193540241564_item	3562263	et	3	main
nädalas	doc_193540241564_item	3562265	et	3	main
töö	doc_193540241564_item	3562267	et	4	main
mulle	doc_193540241564_item	3562276	et	4	main
ja	doc_193540241564_item	3562291	et	3	main
vähemalt	doc_193540241564_item	3562309	et	4	main
kaks	doc_193540241564_item	3562310	et	3	main
nädalat	doc_193540241564_item	3562311	et	3	main
kui	doc_193540241564_item	3562312	et	3	main
kauem	doc_193540241564_item	3562315	et	4	main
sõidan	doc_193540241564_item	3562318	et	3	main
kui	doc_193540241564_item	3562326	et	3	main
tagasi	doc_193540241564_item	3562335	et	3	main
et	doc_193540241564_item	3562345	et	3	main
on	doc_193540241564_item	3562348	et	4	main
nii	doc_193540241564_item	3562349	et	3	main
perfektne	doc_193540241564_item	3562350	et	3	main
ma	doc_193540241564_item	3562351	et	3	main
abiellun	doc_193540241564_item	3562352	et	3	main
kuud	doc_193540241564_item	3562357	et	4	main
midagi	doc_193540241564_item	3562374	et	4	main
ostame	doc_193540241564_item	3562377	et	3	main
essee	doc_193540241565_item	3562380	et	4	main
tean	doc_193540241565_item	3562383	et	3	main
mulle	doc_193540241565_item	3562394	et	4	main
uus	doc_193540241565_item	3562397	et	3	main
meeldib	doc_193540241565_item	3562400	et	3	main
lähen	doc_193540241565_item	3562419	et	3	main
seal	doc_193540241562_item	3562087	et	4	main
on	doc_193540241562_item	3562088	et	4	main
palju	doc_193540241562_item	3562089	et	4	main
asjad	doc_193540241562_item	3562090	et	3	main
et	doc_193540241562_item	3562091	et	3	main
ma	doc_193540241562_item	3562092	et	3	main
pean	doc_193540241562_item	3562093	et	4	main
kirjutama	doc_193540241562_item	3562094	et	3	main
ja	doc_193540241562_item	3562095	et	3	main
mäletama	doc_193540241562_item	3562096	et	3	main
aga	doc_193540241562_item	3562097	et	3	main
minu	doc_193540241562_item	3562098	et	3	main
sünnipäev	doc_193540241562_item	3562099	et	3	main
tuleb	doc_193540241562_item	3562100	et	3	main
veebruaril	doc_193540241562_item	3562101	et	3	main
aasta	doc_193540241562_item	3562103	et	4	main
järgmine	doc_193540241562_item	3562102	et	3	main
ja	doc_193540241562_item	3562104	et	3	main
ma	doc_193540241562_item	3562105	et	3	main
tahaks	doc_193540241562_item	3562106	et	3	main
pühitsetakse	doc_193540241562_item	3562107	et	3	main
palju	doc_193540241562_item	3562108	et	4	main
minu	doc_193540241562_item	3562109	et	3	main
sõbraga	doc_193540241562_item	3562110	et	3	main
ma	doc_193540241562_item	3561924	et	3	main
minu	doc_193540241562_item	3561927	et	3	main
jaapanisse	doc_193540241562_item	3561932	et	4	main
tahan	doc_193540241562_item	3561934	et	3	main
palju	doc_193540241562_item	3561936	et	4	main
sõbraga	doc_193540241562_item	3561938	et	3	main
isa	doc_193540241562_item	3561947	et	4	main
tahan	doc_193540241562_item	3561956	et	3	main
pereks	doc_193540241562_item	3561961	et	3	main
mulle	doc_193540241562_item	3561967	et	4	main
siin	doc_193540241562_item	3561969	et	4	main
sisse	doc_193540241562_item	3561975	et	4	main
suvi	doc_193540241562_item	3561980	et	3	main
väga	doc_193540241562_item	3561982	et	3	main
kuum	doc_193540241562_item	3561983	et	3	main
mulle	doc_193540241562_item	3561984	et	4	main
meeldib	doc_193540241562_item	3561985	et	3	main
on	doc_193540241562_item	3561981	et	4	main
jaapani	doc_193540241562_item	3561986	et	4	main
suve	doc_193540241562_item	3561987	et	4	main
sündmusid	doc_193540241562_item	3561988	et	4	main
aga	doc_193540241562_item	3561989	et	3	main
ei	doc_193540241562_item	3561990	et	4	main
meeldi	doc_193540241562_item	3561991	et	4	main
ilm	doc_193540241562_item	3561992	et	3	main
ma	doc_193540241562_item	3561993	et	3	main
samuti	doc_193540241562_item	3561994	et	3	main
ei	doc_193540241562_item	3561995	et	4	main
tea	doc_193540241562_item	3561996	et	4	main
eesti	doc_193540241562_item	3561997	et	4	main
suvi	doc_193540241562_item	3561998	et	3	main
ja	doc_193540241562_item	3561999	et	3	main
ma	doc_193540241562_item	3562000	et	3	main
tahaks	doc_193540241562_item	3562001	et	3	main
näe	doc_193540241562_item	3562002	et	4	main
seda	doc_193540241562_item	3562003	et	3	main
kui	doc_193540241562_item	3562004	et	3	main
ma	doc_193540241562_item	3562005	et	3	main
tulen	doc_193540241562_item	3562006	et	3	main
jaapanisse	doc_193540241562_item	3562007	et	4	main
ma	doc_193540241562_item	3562008	et	3	main
jaapanis	doc_193540241562_item	3562012	et	4	main
see	doc_193540241562_item	3562013	et	3	main
hea	doc_193540241562_item	3562018	et	4	main
töö	doc_193540241562_item	3562019	et	4	main
on	doc_193540241562_item	3562022	et	4	main
kompaniid	doc_193540241562_item	3562024	et	4	main
ma	doc_193540241562_item	3562026	et	3	main
on	doc_193540241562_item	3562078	et	4	main
väga	doc_193540241562_item	3562079	et	3	main
palju	doc_193540241562_item	3562085	et	4	main
tulevikus	doc_193540241563_item	3562117	et	4	main
asjad	doc_193540241563_item	3562121	et	3	main
hiinasse	doc_193540241563_item	3562126	et	4	main
see	doc_193540241563_item	3562132	et	3	main
võimalik	doc_193540241563_item	3562134	et	3	main
ma	doc_193540241563_item	3562136	et	3	main
väga	doc_193540241563_item	3562138	et	3	main
maja	doc_193540241563_item	3562150	et	4	main
meeldivad	doc_193540241563_item	3562152	et	4	main
minu	doc_193540241563_item	3562153	et	3	main
autod	doc_193540241563_item	3562154	et	3	main
ja	doc_193540241563_item	3562192	et	3	main
kolm	doc_193540241563_item	3562193	et	3	main
palju	doc_193540241563_item	3562201	et	4	main
mis	doc_193540241564_item	3562233	et	4	main
ma	doc_193540241564_item	3562234	et	3	main
korteris	doc_193540241564_item	3562246	et	3	main
oma	doc_193540241564_item	3562248	et	4	main
ma	doc_193540241564_item	3562250	et	3	main
psühholoogiana	doc_193540241564_item	3562252	et	3	main
haiglas	doc_193540241564_item	3562254	et	3	main
ma	doc_193540241564_item	3562260	et	3	main
päeva	doc_193540241564_item	3562264	et	4	main
töötama	doc_193540241564_item	3562266	et	3	main
on	doc_193540241564_item	3562268	et	4	main
väga	doc_193540241564_item	3562269	et	3	main
huvitav	doc_193540241564_item	3562270	et	4	main
ja	doc_193540241564_item	3562271	et	3	main
mõnikord	doc_193540241564_item	3562272	et	3	main
ma	doc_193540241564_item	3562278	et	3	main
saan	doc_193540241564_item	3562279	et	4	main
aega	doc_193540241564_item	3562286	et	4	main
ma	doc_193540241564_item	3562287	et	3	main
reisin	doc_193540241564_item	3562288	et	3	main
ma	doc_193540241564_item	3562295	et	3	main
võimalik	doc_193540241564_item	3562313	et	3	main
münchenisse	doc_193540241564_item	3562320	et	4	main
kohtun	doc_193540241564_item	3562322	et	3	main
oma	doc_193540241564_item	3562324	et	4	main
igav	doc_193540241564_item	3562332	et	3	main
sõidan	doc_193540241564_item	3562334	et	3	main
lähen	doc_193540241564_item	3562339	et	3	main
ja	doc_193540241564_item	3562355	et	3	main
on	doc_193540241564_item	3562366	et	4	main
rõõmsad	doc_193540241564_item	3562367	et	3	main
ja	doc_193540241564_item	3562368	et	3	main
rahul	doc_193540241564_item	3562369	et	4	main
ja	doc_193540241564_item	3562370	et	3	main
selleks	doc_193540241564_item	3562371	et	4	main
et	doc_193540241564_item	3562372	et	3	main
ei	doc_193540241564_item	3562373	et	4	main
kooli	doc_193540241562_item	3562028	et	4	main
jaapanis	doc_193540241562_item	3562035	et	4	main
ja	doc_193540241562_item	3562036	et	3	main
ma	doc_193540241562_item	3562037	et	3	main
väga	doc_193540241562_item	3562038	et	3	main
üllatasin	doc_193540241562_item	3562039	et	3	main
kui	doc_193540241562_item	3562040	et	3	main
ma	doc_193540241562_item	3562041	et	3	main
teasin	doc_193540241562_item	3562042	et	4	main
eestlased	doc_193540241562_item	3562043	et	3	main
lähevad	doc_193540241562_item	3562044	et	3	main
ülikoolis	doc_193540241562_item	3562045	et	4	main
ja	doc_193540241562_item	3562046	et	3	main
õpivad	doc_193540241562_item	3562047	et	3	main
ja	doc_193540241562_item	3562048	et	3	main
töötavad	doc_193540241562_item	3562049	et	4	main
samal	doc_193540241562_item	3562050	et	3	main
ajal	doc_193540241562_item	3562051	et	4	main
ma	doc_193540241562_item	3562052	et	3	main
pean	doc_193540241562_item	3562053	et	4	main
ka	doc_193540241562_item	3562054	et	3	main
kirjutama	doc_193540241562_item	3562055	et	3	main
väga	doc_193540241562_item	3562056	et	3	main
pika	doc_193540241562_item	3562057	et	4	main
essee	doc_193540241562_item	3562058	et	4	main
enne	doc_193540241562_item	3562059	et	4	main
kooli	doc_193540241562_item	3562060	et	4	main
lõpetanu	doc_193540241562_item	3562061	et	4	main
see	doc_193540241562_item	3562062	et	3	main
on	doc_193540241562_item	3562063	et	4	main
minu	doc_193540241562_item	3562064	et	3	main
viimane	doc_193540241562_item	3562065	et	3	main
asi	doc_193540241562_item	3562066	et	4	main
ülikoolis	doc_193540241562_item	3562067	et	4	main
ma	doc_193540241562_item	3562068	et	3	main
tahaks	doc_193540241562_item	3562069	et	3	main
kirjutada	doc_193540241562_item	3562070	et	3	main
hea	doc_193540241562_item	3562071	et	4	main
ma	doc_193540241562_item	3562082	et	3	main
essee	doc_193540241563_item	3562112	et	4	main
ma	doc_193540241563_item	3562123	et	3	main
venemaale	doc_193540241563_item	3562127	et	4	main
alaskasse	doc_193540241563_item	3562128	et	3	main
rikas	doc_193540241563_item	3562139	et	4	main
on	doc_193540241563_item	3562141	et	4	main
üks	doc_193540241563_item	3562144	et	3	main
mulle	doc_193540241563_item	3562151	et	4	main
ja	doc_193540241563_item	3562155	et	3	main
jaht	doc_193540241563_item	3562156	et	3	main
tulevikus	doc_193540241563_item	3562157	et	4	main
ma	doc_193540241563_item	3562158	et	3	main
töötan	doc_193540241563_item	3562159	et	3	main
suures	doc_193540241563_item	3562160	et	3	main
kompaniis	doc_193540241563_item	3562161	et	3	main
aga	doc_193540241563_item	3562162	et	3	main
ma	doc_193540241563_item	3562163	et	3	main
on	doc_193540241563_item	3562168	et	4	main
aeg	doc_193540241563_item	3562171	et	3	main
hollandis	doc_193540241563_item	3562174	et	4	main
aga	doc_193540241563_item	3562175	et	3	main
minu	doc_193540241563_item	3562176	et	3	main
teine	doc_193540241563_item	3562177	et	3	main
maja	doc_193540241563_item	3562178	et	4	main
on	doc_193540241563_item	3562179	et	4	main
lähevad	doc_193540241563_item	3562196	et	3	main
ma	doc_193540241563_item	3562199	et	3	main
joon	doc_193540241563_item	3562200	et	4	main
ma	doc_193540241564_item	3562238	et	3	main
elan	doc_193540241564_item	3562239	et	3	main
töötan	doc_193540241564_item	3562241	et	3	main
ma	doc_193540241564_item	3562243	et	3	main
suures	doc_193540241564_item	3562245	et	3	main
kus	doc_193540241564_item	3562255	et	3	main
küllalt	doc_193540241564_item	3562258	et	4	main
pean	doc_193540241564_item	3562261	et	4	main
meeldib	doc_193540241564_item	3562277	et	3	main
inimesi	doc_193540241564_item	3562280	et	4	main
aidata	doc_193540241564_item	3562281	et	4	main
maailma	doc_193540241564_item	3562290	et	4	main
käin	doc_193540241564_item	3562296	et	3	main
eesti	doc_193540241564_item	3562302	et	4	main
keelt	doc_193540241564_item	3562303	et	4	main
siis	doc_193540241564_item	3562314	et	3	main
ka	doc_193540241564_item	3562319	et	3	main
seal	doc_193540241564_item	3562337	et	4	main
oma	doc_193540241564_item	3562353	et	4	main
sõbraga	doc_193540241564_item	3562354	et	3	main
kõik	doc_193540241564_item	3562365	et	4	main
võõras	doc_193540241565_item	3562392	et	4	main
parem	doc_193540241565_item	3562427	et	4	main
sõbraga	doc_193540241565_item	3562428	et	3	main
ja	doc_193540241565_item	3562429	et	3	main
me	doc_193540241565_item	3562433	et	4	main
suur	doc_193540241565_item	3562435	et	3	main
võivad	doc_193540241565_item	3562447	et	4	main
aitame	doc_193540241565_item	3562459	et	3	main
suhkruta	doc_193540241563_item	3562203	et	3	main
minu	doc_193540241563_item	3562204	et	3	main
ema	doc_193540241563_item	3562205	et	4	main
ja	doc_193540241563_item	3562206	et	3	main
isa	doc_193540241563_item	3562207	et	4	main
elavad	doc_193540241563_item	3562208	et	4	main
hollandis	doc_193540241563_item	3562209	et	4	main
buksterwaagis	doc_193540241563_item	3562210	et	4	main
nende	doc_193540241563_item	3562211	et	4	main
maja	doc_193540241563_item	3562212	et	4	main
on	doc_193540241563_item	3562213	et	4	main
suur	doc_193540241563_item	3562214	et	3	main
ja	doc_193540241563_item	3562215	et	3	main
vana	doc_193540241563_item	3562216	et	4	main
see	doc_193540241563_item	3562217	et	3	main
on	doc_193540241563_item	3562218	et	4	main
väga	doc_193540241563_item	3562219	et	3	main
ilus	doc_193540241563_item	3562220	et	4	main
maja	doc_193540241563_item	3562221	et	4	main
talvel	doc_193540241563_item	3562222	et	4	main
nad	doc_193540241563_item	3562223	et	3	main
elavad	doc_193540241563_item	3562224	et	4	main
teneriifil	doc_193540241563_item	3562225	et	4	main
talvel	doc_193540241563_item	3562226	et	4	main
ma	doc_193540241563_item	3562227	et	3	main
lähen	doc_193540241563_item	3562228	et	3	main
teen	doc_193540241563_item	3562115	et	3	main
tulevikus	doc_193540241563_item	3562116	et	4	main
palju	doc_193540241563_item	3562120	et	4	main
uruguayasse	doc_193540241563_item	3562125	et	4	main
austraaliasse	doc_193540241563_item	3562131	et	4	main
et	doc_193540241563_item	3562135	et	3	main
olen	doc_193540241563_item	3562137	et	3	main
kolm	doc_193540241563_item	3562142	et	3	main
jaht	doc_193540241563_item	3562145	et	3	main
tööta	doc_193540241563_item	3562165	et	4	main
prantsusmaal	doc_193540241563_item	3562180	et	4	main
palju	doc_193540241563_item	3562187	et	4	main
on	doc_193540241563_item	3562190	et	4	main
last	doc_193540241563_item	3562194	et	4	main
ülikoolisse	doc_193540241563_item	3562197	et	4	main
bussiga	doc_193540241563_item	3562198	et	3	main
prantsusmaale	doc_193540241563_item	3562229	et	4	main
essee	doc_193540241564_item	3562232	et	4	main
tulevikus	doc_193540241564_item	3562237	et	4	main
ja	doc_193540241564_item	3562240	et	3	main
ühes	doc_193540241564_item	3562253	et	4	main
on	doc_193540241564_item	3562257	et	4	main
et	doc_193540241564_item	3562259	et	3	main
raske	doc_193540241564_item	3562273	et	4	main
ka	doc_193540241564_item	3562274	et	3	main
aga	doc_193540241564_item	3562275	et	3	main
vaba	doc_193540241564_item	3562285	et	4	main
ümber	doc_193540241564_item	3562289	et	3	main
loomulikult	doc_193540241564_item	3562294	et	4	main
aastal	doc_193540241564_item	3562298	et	3	main
et	doc_193540241564_item	3562300	et	3	main
ei	doc_193540241564_item	3562304	et	4	main
unusta	doc_193540241564_item	3562305	et	4	main
ma	doc_193540241564_item	3562306	et	3	main
jään	doc_193540241564_item	3562307	et	3	main
sinna	doc_193540241564_item	3562308	et	3	main
mõnikord	doc_193540241564_item	3562316	et	3	main
ja	doc_193540241564_item	3562321	et	3	main
seal	doc_193540241564_item	3562323	et	4	main
münchen	doc_193540241564_item	3562327	et	4	main
teen	doc_193540241564_item	3562235	et	3	main
viinis	doc_193540241564_item	3562242	et	3	main
elan	doc_193540241564_item	3562244	et	3	main
kesklinnas	doc_193540241564_item	3562247	et	4	main
sõbraga	doc_193540241564_item	3562249	et	3	main
töötan	doc_193540241564_item	3562251	et	3	main
ainult	doc_193540241564_item	3562262	et	4	main
kui	doc_193540241564_item	3562282	et	3	main
mul	doc_193540241564_item	3562283	et	3	main
on	doc_193540241564_item	3562284	et	4	main
külastan	doc_193540241564_item	3562292	et	3	main
sõpru	doc_193540241564_item	3562293	et	3	main
igal	doc_193540241564_item	3562297	et	3	main
eestis	doc_193540241564_item	3562299	et	3	main
ma	doc_193540241564_item	3562301	et	3	main
ma	doc_193540241564_item	3562317	et	3	main
perega	doc_193540241564_item	3562325	et	3	main
on	doc_193540241564_item	3562328	et	4	main
mulle	doc_193540241564_item	3562329	et	4	main
jälle	doc_193540241564_item	3562330	et	3	main
liiga	doc_193540241564_item	3562331	et	4	main
ma	doc_193540241564_item	3562333	et	3	main
ma	doc_193540241564_item	3562338	et	3	main
muuseumisse	doc_193540241564_item	3562340	et	3	main
teatrisse	doc_193540241564_item	3562342	et	3	main
sellepärast	doc_193540241564_item	3562344	et	3	main
kõik	doc_193540241564_item	3562346	et	4	main
elus	doc_193540241564_item	3562347	et	4	main
pärast	doc_193540241564_item	3562358	et	4	main
on	doc_193540241564_item	3562360	et	4	main
kaks	doc_193540241564_item	3562361	et	3	main
ilusat	doc_193540241564_item	3562362	et	3	main
last	doc_193540241564_item	3562363	et	4	main
kaksikud	doc_193540241564_item	3562364	et	3	main
puudu	doc_193540241564_item	3562375	et	4	main
me	doc_193540241564_item	3562376	et	4	main
ei	doc_193540241565_item	3562387	et	4	main
elan	doc_193540241565_item	3562388	et	3	main
saksamaal	doc_193540241565_item	3562389	et	4	main
ma	doc_193540241565_item	3562390	et	3	main
elan	doc_193540241565_item	3562391	et	3	main
meeldib	doc_193540241565_item	3562395	et	3	main
inimesed	doc_193540241565_item	3562398	et	3	main
ma	doc_193540241565_item	3562418	et	3	main
kutsuda	doc_193540241565_item	3562430	et	3	main
elame	doc_193540241565_item	3562434	et	3	main
palju	doc_193540241565_item	3562437	et	4	main
aeg	doc_193540241565_item	3562450	et	3	main
meie	doc_193540241565_item	3562451	et	4	main
räägitakse	doc_193540241565_item	3562454	et	3	main
süütakse	doc_193540241565_item	3562457	et	3	main
vaene	doc_193540241565_item	3562460	et	4	main
teie	doc_193540241565_item	3562481	et	4	main
olla	doc_193540241565_item	3562484	et	3	main
sõbrad	doc_193540241565_item	3562491	et	3	main
tahan	doc_193540241565_item	3562493	et	3	main
õppida	doc_193540241565_item	3562494	et	3	main
ja	doc_193540241565_item	3562496	et	3	main
kui	doc_193540241565_item	3562498	et	3	main
tulevikus	doc_193540241565_item	3562499	et	4	main
see	doc_193540241565_item	3562500	et	3	main
juhtus	doc_193540241565_item	3562501	et	3	main
mul	doc_193540241565_item	3562502	et	3	main
on	doc_193540241565_item	3562503	et	4	main
viinisse	doc_193540241564_item	3562336	et	3	main
või	doc_193540241564_item	3562341	et	4	main
ja	doc_193540241564_item	3562343	et	3	main
üheksa	doc_193540241564_item	3562356	et	4	main
meil	doc_193540241564_item	3562359	et	4	main
koera	doc_193540241564_item	3562378	et	4	main
ma	doc_193540241565_item	3562382	et	3	main
kohtuda	doc_193540241565_item	3562396	et	3	main
võõrasse	doc_193540241565_item	3562420	et	4	main
maalle	doc_193540241565_item	3562421	et	4	main
soovin	doc_193540241565_item	3562424	et	3	main
elada	doc_193540241565_item	3562425	et	3	main
kõige	doc_193540241565_item	3562426	et	4	main
on	doc_193540241565_item	3562440	et	4	main
suur	doc_193540241565_item	3562441	et	3	main
köök	doc_193540241565_item	3562442	et	3	main
ja	doc_193540241565_item	3562443	et	3	main
suur	doc_193540241565_item	3562444	et	3	main
keematakse	doc_193540241565_item	3562455	et	4	main
ja	doc_193540241565_item	3562456	et	3	main
aidata	doc_193540241565_item	3562480	et	4	main
ma	doc_193540241565_item	3562482	et	3	main
hea	doc_193540241565_item	3562490	et	4	main
ma	doc_193540241565_item	3562492	et	3	main
inimesest	doc_193540241565_item	3562495	et	3	main
essee	doc_399014257167_item	3562507	et	4	main
nii	doc_399014257167_item	3562512	et	3	main
ei	doc_399014257167_item	3562524	et	4	main
näiteks	doc_399014257167_item	3562535	et	4	main
turus	doc_399014257167_item	3562536	et	3	main
neil	doc_399014257167_item	3562543	et	4	main
kogu	doc_399014257167_item	3562547	et	4	main
nondes	doc_399014257167_item	3562550	et	3	main
et	doc_399014257167_item	3562557	et	3	main
täituks	doc_399014257167_item	3562559	et	4	main
hs	doc_399014257167_item	3562560	et	4	main
et	doc_399014257167_item	3562565	et	3	main
et	doc_399014257167_item	3562568	et	3	main
kõik	doc_399014257167_item	3562569	et	4	main
mida	doc_399014257167_item	3562570	et	4	main
sõnadega	doc_399014257167_item	3562579	et	3	main
muud	doc_399014257167_item	3562582	et	4	main
ajalehed	doc_399014257167_item	3562583	et	3	main
kirjutavad	doc_399014257167_item	3562584	et	4	main
ei	doc_399014257167_item	3562585	et	4	main
peale	doc_399014257167_item	3562596	et	4	main
samuti	doc_399014257167_item	3562597	et	3	main
kui	doc_399014257167_item	3562607	et	3	main
sest	doc_399014257167_item	3562616	et	4	main
et	doc_399014257167_item	3562617	et	3	main
soovivad	doc_399014257167_item	3562618	et	4	main
peatoimetaja	doc_399014257167_item	3562631	et	4	main
arvamus	doc_399014257167_item	3562645	et	3	main
kõik	doc_399014257167_item	3562648	et	4	main
mind	doc_399014257167_item	3562656	et	4	main
ärritama	doc_399014257167_item	3562657	et	3	main
helsingin	doc_399014257167_item	3562658	et	4	main
kirjutamisest	doc_399014257167_item	3562690	et	4	main
või	doc_399014257167_item	3562700	et	4	main
inimesed	doc_193540241565_item	3562461	et	3	main
ma	doc_193540241565_item	3562462	et	3	main
töötan	doc_193540241565_item	3562463	et	3	main
et	doc_193540241565_item	3562464	et	3	main
ma	doc_193540241565_item	3562465	et	3	main
olen	doc_193540241565_item	3562466	et	3	main
küllalt	doc_193540241565_item	3562467	et	4	main
raha	doc_193540241565_item	3562468	et	4	main
aga	doc_193540241565_item	3562469	et	3	main
ma	doc_193540241565_item	3562470	et	3	main
ei	doc_193540241565_item	3562471	et	4	main
elaks	doc_193540241565_item	3562472	et	3	main
töötaks	doc_193540241565_item	3562473	et	4	main
ma	doc_193540241565_item	3562474	et	3	main
tahan	doc_193540241565_item	3562475	et	3	main
elada	doc_193540241565_item	3562476	et	3	main
teine	doc_193540241565_item	3562477	et	3	main
inimesedeks	doc_193540241565_item	3562478	et	4	main
ja	doc_193540241565_item	3562479	et	3	main
mis	doc_193540241565_item	3562381	et	4	main
tulevikus	doc_193540241565_item	3562384	et	4	main
tulevikus	doc_193540241565_item	3562385	et	4	main
ma	doc_193540241565_item	3562386	et	3	main
maal	doc_193540241565_item	3562393	et	4	main
mulle	doc_193540241565_item	3562399	et	4	main
nägeda	doc_193540241565_item	3562401	et	4	main
kui	doc_193540241565_item	3562402	et	3	main
nad	doc_193540241565_item	3562403	et	3	main
elavad	doc_193540241565_item	3562404	et	4	main
töötavad	doc_193540241565_item	3562405	et	4	main
ja	doc_193540241565_item	3562406	et	3	main
söövad	doc_193540241565_item	3562407	et	4	main
seal	doc_193540241565_item	3562408	et	4	main
me	doc_193540241565_item	3562409	et	4	main
rääkime	doc_193540241565_item	3562410	et	4	main
elust	doc_193540241565_item	3562411	et	3	main
ja	doc_193540241565_item	3562412	et	3	main
jumalast	doc_193540241565_item	3562413	et	4	main
ma	doc_193540241565_item	3562414	et	3	main
soovin	doc_193540241565_item	3562415	et	3	main
õppida	doc_193540241565_item	3562416	et	3	main
inimesest	doc_193540241565_item	3562417	et	3	main
uus	doc_193540241565_item	3562431	et	3	main
majas	doc_193540241565_item	3562436	et	3	main
tubaga	doc_193540241565_item	3562438	et	4	main
meile	doc_193540241565_item	3562439	et	4	main
tuleda	doc_193540241565_item	3562448	et	4	main
majas	doc_193540241565_item	3562452	et	3	main
mängitakse	doc_193540241565_item	3562453	et	3	main
me	doc_193540241565_item	3562458	et	4	main
hea	doc_193540241565_item	3562504	et	4	main
meediast	doc_399014257167_item	3562508	et	4	main
üle	doc_399014257167_item	3562514	et	3	main
ilmub	doc_399014257167_item	3562516	et	3	main
ja	doc_399014257167_item	3562518	et	3	main
helsingin	doc_399014257167_item	3562521	et	4	main
olnud	doc_399014257167_item	3562527	et	4	main
küll	doc_399014257167_item	3562530	et	4	main
ilmub	doc_399014257167_item	3562531	et	3	main
kuopios	doc_399014257167_item	3562539	et	4	main
ja	doc_399014257167_item	3562540	et	3	main
oulus	doc_399014257167_item	3562541	et	4	main
aga	doc_399014257167_item	3562542	et	3	main
ajakirjanduse	doc_399014257167_item	3562553	et	3	main
on	doc_399014257167_item	3562561	et	4	main
saanud	doc_399014257167_item	3562562	et	4	main
selle	doc_399014257167_item	3562571	et	4	main
tähendust	doc_399014257167_item	3562589	et	4	main
sellepärast	doc_399014257167_item	3562590	et	3	main
et	doc_399014257167_item	3562591	et	3	main
lugejad	doc_399014257167_item	3562592	et	4	main
kriitikad	doc_399014257167_item	3562601	et	3	main
ilmuvad	doc_399014257167_item	3562609	et	4	main
niisiis	doc_399014257167_item	3562611	et	3	main
silmas	doc_399014257167_item	3562621	et	4	main
kultuurtoimetuse	doc_399014257167_item	3562629	et	4	main
uus	doc_399014257167_item	3562630	et	3	main
tekst	doc_399014257167_item	3562640	et	3	main
ainult	doc_399014257167_item	3562642	et	4	main
inimese	doc_399014257167_item	3562644	et	4	main
üritus	doc_399014257167_item	3562662	et	4	main
kui	doc_399014257167_item	3562691	et	3	main
sellist	doc_399014257167_item	3562692	et	4	main
oleks	doc_399014257167_item	3562693	et	3	main
aga	doc_399014257167_item	3562694	et	3	main
helsingin	doc_399014257167_item	3562695	et	4	main
neid	doc_399014257167_item	3562701	et	4	main
kõrvale	doc_399014257167_item	3562702	et	4	main
jätta	doc_399014257167_item	3562703	et	3	main
ja	doc_399014257167_item	3562704	et	3	main
et	doc_399014257167_item	3562705	et	3	main
inimesed	doc_399014257167_item	3562706	et	3	main
et	doc_399014257167_item	3562716	et	3	main
praegu	doc_399014257167_item	3562717	et	3	main
ajalehte	doc_399014257167_item	3562720	et	4	main
loe	doc_399014257167_item	3562721	et	4	main
kuus	doc_399014257167_item	3562724	et	4	main
tahtis	doc_399014257167_item	3562731	et	3	main
tellimise	doc_399014257167_item	3562740	et	4	main
lõpetada	doc_399014257167_item	3562741	et	3	main
ja	doc_399014257167_item	3562742	et	3	main
hakada	doc_399014257167_item	3562743	et	4	main
nädal	doc_399014257167_item	3562749	et	3	main
hbl	doc_399014257167_item	3562755	et	4	main
meeldi	doc_399014257167_item	3562757	et	4	main
ei	doc_399014257167_item	3562758	et	4	main
igatahes	doc_399014257167_item	3562759	et	3	main
harjunud	doc_399014257167_item	3562769	et	4	main
kõik	doc_399014257167_item	3562782	et	4	main
soomlased	doc_399014257167_item	3562783	et	3	main
nägid	doc_399014257167_item	3562784	et	4	main
käimas	doc_399014257167_item	3562796	et	4	main
ja	doc_399014257167_item	3562797	et	3	main
tähele	doc_399014257167_item	3562798	et	3	main
panin	doc_399014257167_item	3562799	et	3	main
et	doc_399014257167_item	3562800	et	3	main
tema	doc_399014257167_item	3562801	et	4	main
televiisoris	doc_399014257167_item	3562802	et	3	main
oli	doc_399014257167_item	3562803	et	3	main
sõbraga	doc_193540241565_item	3562422	et	3	main
ma	doc_193540241565_item	3562423	et	3	main
sõbraga	doc_193540241565_item	3562432	et	3	main
elutuba	doc_193540241565_item	3562445	et	4	main
inimesed	doc_193540241565_item	3562446	et	3	main
iga	doc_193540241565_item	3562449	et	4	main
on	doc_193540241565_item	3562489	et	4	main
soomes	doc_399014257167_item	3562511	et	4	main
et	doc_399014257167_item	3562513	et	3	main
ajaleht	doc_399014257167_item	3562520	et	3	main
sanomat	doc_399014257167_item	3562522	et	4	main
olukord	doc_399014257167_item	3562523	et	3	main
selline	doc_399014257167_item	3562528	et	4	main
teisi	doc_399014257167_item	3562532	et	4	main
ajalehte	doc_399014257167_item	3562533	et	4	main
ka	doc_399014257167_item	3562534	et	3	main
tähendust	doc_399014257167_item	3562546	et	4	main
ainult	doc_399014257167_item	3562549	et	4	main
mitmekülgne	doc_399014257167_item	3562556	et	3	main
sönavabadus	doc_399014257167_item	3562558	et	4	main
sellise	doc_399014257167_item	3562563	et	4	main
usuvad	doc_399014257167_item	3562567	et	3	main
on	doc_399014257167_item	3562574	et	4	main
või	doc_399014257167_item	3562577	et	4	main
ole	doc_399014257167_item	3562586	et	4	main
ei	doc_399014257167_item	3562593	et	4	main
näiteks	doc_399014257167_item	3562598	et	4	main
sõbrad	doc_399014257167_item	3562612	et	3	main
oulus	doc_399014257167_item	3562613	et	4	main
soome	doc_399014257167_item	3562619	et	3	main
on	doc_399014257167_item	3562624	et	4	main
nii	doc_399014257167_item	3562625	et	3	main
kui	doc_399014257167_item	3562626	et	3	main
räägis	doc_399014257167_item	3562632	et	3	main
pühapäeva	doc_399014257167_item	3562633	et	4	main
on	doc_399014257167_item	3562641	et	4	main
ühe	doc_399014257167_item	3562643	et	4	main
isiklikult	doc_399014257167_item	3562654	et	4	main
hakkas	doc_399014257167_item	3562655	et	3	main
palju	doc_399014257167_item	3562715	et	4	main
käis	doc_399014257167_item	3562727	et	4	main
nii	doc_399014257167_item	3562728	et	3	main
et	doc_399014257167_item	3562729	et	3	main
abikaasa	doc_399014257167_item	3562730	et	4	main
ilma	doc_399014257167_item	3562733	et	4	main
soomerooslaste	doc_399014257167_item	3562744	et	4	main
ajalehte	doc_399014257167_item	3562745	et	4	main
ka	doc_399014257167_item	3562746	et	3	main
lugema	doc_399014257167_item	3562747	et	4	main
läinud	doc_399014257167_item	3562752	et	4	main
veel	doc_399014257167_item	3562760	et	4	main
sest	doc_399014257167_item	3562767	et	4	main
helsingin	doc_399014257167_item	3562770	et	4	main
kui	doc_399014257167_item	3562772	et	3	main
televiisorit	doc_399014257167_item	3562774	et	3	main
sarnased	doc_399014257167_item	3562785	et	4	main
kavad	doc_399014257167_item	3562786	et	3	main
konkreetselt	doc_399014257167_item	3562787	et	4	main
programmid	doc_399014257167_item	3562806	et	4	main
mul	doc_399014257167_item	3562808	et	3	main
kodus	doc_399014257167_item	3562810	et	4	main
et	doc_399014257167_item	3562814	et	3	main
gümnaasiumiõpilast	doc_399014257167_item	3562826	et	4	main
vaatasime	doc_399014257167_item	3562827	et	3	main
oleks	doc_399014257167_item	3562838	et	3	main
olnud	doc_399014257167_item	3562839	et	4	main
kahju	doc_399014257167_item	3562840	et	4	main
oli	doc_399014257167_item	3562841	et	3	main
kui	doc_399014257167_item	3562846	et	3	main
olnud	doc_399014257167_item	3562859	et	4	main
praegu	doc_399014257167_item	3562883	et	3	main
on	doc_399014257167_item	3562885	et	4	main
on	doc_399014257167_item	3562890	et	4	main
tahan	doc_193540241565_item	3562483	et	3	main
hea	doc_193540241565_item	3562485	et	4	main
sõber	doc_193540241565_item	3562486	et	3	main
ja	doc_193540241565_item	3562487	et	3	main
mul	doc_193540241565_item	3562488	et	3	main
jumalast	doc_193540241565_item	3562497	et	4	main
meel	doc_193540241565_item	3562505	et	4	main
on	doc_399014257167_item	3562510	et	4	main
üks	doc_399014257167_item	3562517	et	3	main
sama	doc_399014257167_item	3562519	et	4	main
ole	doc_399014257167_item	3562526	et	4	main
tampereel	doc_399014257167_item	3562537	et	4	main
ei	doc_399014257167_item	3562544	et	4	main
ümbrusega	doc_399014257167_item	3562552	et	3	main
peaks	doc_399014257167_item	3562554	et	4	main
jalaaseme	doc_399014257167_item	3562564	et	3	main
inimesed	doc_399014257167_item	3562566	et	3	main
leheküljetel	doc_399014257167_item	3562572	et	4	main
täielikult	doc_399014257167_item	3562575	et	4	main
tõtt	doc_399014257167_item	3562576	et	4	main
sellel	doc_399014257167_item	3562580	et	4	main
midagi	doc_399014257167_item	3562587	et	4	main
erilist	doc_399014257167_item	3562588	et	4	main
nende	doc_399014257167_item	3562595	et	4	main
raamatute	doc_399014257167_item	3562600	et	3	main
praegu	doc_399014257167_item	3562509	et	3	main
maa	doc_399014257167_item	3562515	et	4	main
alati	doc_399014257167_item	3562525	et	4	main
tõsi	doc_399014257167_item	3562529	et	4	main
jyväskyläs	doc_399014257167_item	3562538	et	4	main
ole	doc_399014257167_item	3562545	et	4	main
maas	doc_399014257167_item	3562548	et	4	main
linnades	doc_399014257167_item	3562551	et	3	main
olema	doc_399014257167_item	3562555	et	4	main
kirjutatakse	doc_399014257167_item	3562573	et	3	main
teiste	doc_399014257167_item	3562578	et	4	main
mida	doc_399014257167_item	3562581	et	4	main
loota	doc_399014257167_item	3562594	et	4	main
uute	doc_399014257167_item	3562599	et	3	main
on	doc_399014257167_item	3562602	et	4	main
tähtisad	doc_399014257167_item	3562603	et	3	main
ja	doc_399014257167_item	3562604	et	3	main
loetud	doc_399014257167_item	3562605	et	4	main
ainult	doc_399014257167_item	3562606	et	4	main
nad	doc_399014257167_item	3562608	et	3	main
hss	doc_399014257167_item	3562610	et	4	main
tellivad	doc_399014257167_item	3562614	et	4	main
kultuurielu	doc_399014257167_item	3562620	et	4	main
pidada	doc_399014257167_item	3562622	et	4	main
ikkagi	doc_399014257167_item	3562623	et	4	main
sanomate	doc_399014257167_item	3562628	et	4	main
ajalehe	doc_399014257167_item	3562639	et	3	main
aga	doc_399014257167_item	3562646	et	3	main
lugevad	doc_399014257167_item	3562650	et	4	main
see	doc_399014257167_item	3562651	et	3	main
läheb	doc_399014257167_item	3562652	et	3	main
sanomate	doc_399014257167_item	3562659	et	4	main
objektiivsest	doc_399014257167_item	3562688	et	3	main
sanomate	doc_399014257167_item	3562696	et	4	main
tavas	doc_399014257167_item	3562697	et	3	main
kirjutada	doc_399014257167_item	3562698	et	3	main
asjadest	doc_399014257167_item	3562699	et	3	main
seepärast	doc_399014257167_item	3562707	et	3	main
on	doc_399014257167_item	3562710	et	4	main
mind	doc_399014257167_item	3562712	et	4	main
ärritama	doc_399014257167_item	3562713	et	3	main
nii	doc_399014257167_item	3562714	et	3	main
tellisin	doc_399014257167_item	3562722	et	3	main
olla	doc_399014257167_item	3562735	et	3	main
eesmas	doc_399014257167_item	3562748	et	4	main
temal	doc_399014257167_item	3562754	et	3	main
ei	doc_399014257167_item	3562756	et	4	main
käib	doc_399014257167_item	3562763	et	3	main
on	doc_399014257167_item	3562768	et	4	main
hakkatas	doc_399014257167_item	3562775	et	4	main
vaatama	doc_399014257167_item	3562776	et	3	main
oli	doc_399014257167_item	3562777	et	3	main
pikk	doc_399014257167_item	3562778	et	4	main
aeg	doc_399014257167_item	3562779	et	3	main
üks	doc_399014257167_item	3562790	et	3	main
kord	doc_399014257167_item	3562791	et	4	main
ema	doc_399014257167_item	3562794	et	4	main
juures	doc_399014257167_item	3562795	et	4	main
no	doc_399014257167_item	3562811	et	3	main
inimesed	doc_399014257167_item	3562816	et	3	main
mina	doc_399014257167_item	3562821	et	4	main
kui	doc_399014257167_item	3562822	et	3	main
meid	doc_399014257167_item	3562823	et	4	main
külastas	doc_399014257167_item	3562824	et	3	main
kaks	doc_399014257167_item	3562825	et	3	main
idols-kavat	doc_399014257167_item	3562829	et	4	main
oleks	doc_399014257167_item	3562832	et	3	main
kätte	doc_399014257167_item	3562857	et	4	main
oleks	doc_399014257167_item	3562858	et	3	main
oleks	doc_399014257167_item	3562864	et	3	main
meedia	doc_399014257167_item	3562879	et	4	main
mulle	doc_399014257167_item	3562888	et	4	main
huvitavat	doc_399014257167_item	3562891	et	4	main
võimalik	doc_399014257167_item	3562907	et	3	main
muusikat	doc_399014257167_item	3562909	et	3	main
ühe	doc_399014257167_item	3562924	et	4	main
küll	doc_399014257167_item	3562929	et	4	main
hs	doc_399014257167_item	3562615	et	4	main
helsingin	doc_399014257167_item	3562627	et	4	main
hufvudstadsbladeti	doc_399014257167_item	3562634	et	4	main
leheküljel	doc_399014257167_item	3562635	et	3	main
et	doc_399014257167_item	3562636	et	3	main
ka	doc_399014257167_item	3562637	et	3	main
suure	doc_399014257167_item	3562638	et	3	main
kui	doc_399014257167_item	3562647	et	3	main
selle	doc_399014257167_item	3562649	et	4	main
tõeks	doc_399014257167_item	3562653	et	4	main
komme	doc_399014257167_item	3562660	et	4	main
ja	doc_399014257167_item	3562661	et	3	main
mõjuda	doc_399014257167_item	3562663	et	3	main
lugijate	doc_399014257167_item	3562664	et	4	main
mõtlemisesse	doc_399014257167_item	3562665	et	4	main
või	doc_399014257167_item	3562666	et	4	main
arvamustesse	doc_399014257167_item	3562667	et	3	main
on	doc_399014257167_item	3562668	et	4	main
muidugi	doc_399014257167_item	3562669	et	4	main
kui	doc_399014257167_item	3562670	et	3	main
vette	doc_399014257167_item	3562671	et	3	main
joonistatud	doc_399014257167_item	3562672	et	4	main
joon	doc_399014257167_item	3562673	et	4	main
see	doc_399014257167_item	3562674	et	3	main
millal	doc_399014257167_item	3562675	et	3	main
on	doc_399014257167_item	3562676	et	4	main
küsimus	doc_399014257167_item	3562677	et	4	main
tahtlikult	doc_399014257167_item	3562678	et	4	main
mõjumisest	doc_399014257167_item	3562679	et	4	main
või	doc_399014257167_item	3562680	et	4	main
ainult	doc_399014257167_item	3562681	et	4	main
teadmise	doc_399014257167_item	3562682	et	4	main
jagamisest	doc_399014257167_item	3562683	et	4	main
ma	doc_399014257167_item	3562684	et	3	main
ei	doc_399014257167_item	3562685	et	4	main
taha	doc_399014257167_item	3562686	et	4	main
räägida	doc_399014257167_item	3562687	et	4	main
ajalehte	doc_399014257167_item	3562689	et	4	main
arvavad	doc_399014257167_item	3562709	et	4	main
en	doc_399014257167_item	3562718	et	4	main
ka	doc_399014257167_item	3562732	et	3	main
hs	doc_399014257167_item	3562734	et	4	main
ja	doc_399014257167_item	3562736	et	3	main
soovis	doc_399014257167_item	3562737	et	4	main
helsingin	doc_399014257167_item	3562738	et	4	main
nüüd	doc_399014257167_item	3562751	et	4	main
aga	doc_399014257167_item	3562753	et	3	main
raamatukogus	doc_399014257167_item	3562764	et	4	main
ajalehte	doc_399014257167_item	3562765	et	4	main
lugemas	doc_399014257167_item	3562766	et	4	main
sanomatega	doc_399014257167_item	3562771	et	4	main
soomes	doc_399014257167_item	3562773	et	4	main
selle	doc_399014257167_item	3562789	et	4	main
kui	doc_399014257167_item	3562792	et	3	main
olin	doc_399014257167_item	3562793	et	3	main
erinevad	doc_399014257167_item	3562805	et	4	main
samuti	doc_399014257167_item	3562812	et	3	main
nägemata	doc_399014257167_item	3562836	et	4	main
see	doc_399014257167_item	3562837	et	3	main
sellest	doc_399014257167_item	3562844	et	4	main
programmit	doc_399014257167_item	3562845	et	4	main
sattusid	doc_399014257167_item	3562849	et	4	main
siirade	doc_399014257167_item	3562851	et	4	main
juhul	doc_399014257167_item	3562854	et	3	main
ei	doc_399014257167_item	3562863	et	4	main
avalikkuses	doc_399014257167_item	3562866	et	4	main
niisiis	doc_399014257167_item	3562868	et	3	main
hea	doc_399014257167_item	3562869	et	4	main
vahetada	doc_399014257167_item	3562870	et	3	main
kanalit	doc_399014257167_item	3562871	et	3	main
mu	doc_399014257167_item	3562875	et	3	main
oma	doc_399014257167_item	3562876	et	4	main
sellest	doc_399014257167_item	3562884	et	4	main
tulnud	doc_399014257167_item	3562886	et	4	main
jälle	doc_399014257167_item	3562887	et	3	main
kuulata	doc_399014257167_item	3562908	et	4	main
kuuldub	doc_399014257167_item	3562910	et	3	main
oleks	doc_399014257167_item	3562913	et	3	main
kerge	doc_399014257167_item	3562925	et	4	main
ei	doc_399014257167_item	3562936	et	4	main
soome	doc_399014257168_item	3562980	et	3	main
linna	doc_399014257168_item	3562983	et	4	main
omakeelne	doc_399014257168_item	3562993	et	3	main
ka	doc_399014257168_item	3562996	et	3	main
on	doc_399014257168_item	3563002	et	4	main
sunninud	doc_399014257168_item	3563003	et	4	main
meediat	doc_399014257168_item	3563005	et	3	main
jälgima	doc_399014257168_item	3563006	et	4	main
on	doc_399014257168_item	3563036	et	4	main
keeruline	doc_399014257168_item	3563037	et	4	main
ja	doc_399014257168_item	3563038	et	3	main
on	doc_399014257168_item	3563043	et	4	main
ära	doc_399014257168_item	3563056	et	4	main
interneti	doc_399014257168_item	3563066	et	4	main
ja	doc_399014257168_item	3563067	et	3	main
teine	doc_399014257168_item	3563068	et	3	main
tv	doc_399014257168_item	3563069	et	4	main
kaheksa	doc_399014257168_item	3563073	et	4	main
prantsuse	doc_399014257168_item	3563081	et	3	main
inglise	doc_399014257168_item	3563096	et	4	main
huvitab	doc_399014257168_item	3563103	et	3	main
kõige	doc_399014257168_item	3563104	et	4	main
kuulada	doc_399014257168_item	3563106	et	4	main
interneti	doc_399014257168_item	3563107	et	4	main
kaudu	doc_399014257168_item	3563108	et	3	main
eesti	doc_399014257168_item	3563115	et	4	main
sügisel	doc_399014257168_item	3563133	et	3	main
sündmuseks	doc_399014257168_item	3563139	et	3	main
big	doc_399014257168_item	3563142	et	4	main
anda	doc_399014257168_item	3563146	et	3	main
kõrgeim	doc_399014257168_item	3563148	et	4	main
igavaid	doc_399014257168_item	3563172	et	3	main
päevakajasaateid	doc_399014257168_item	3563173	et	3	main
tsensuuri	doc_399014257168_item	3563186	et	4	main
konsentreerumist	doc_399014257168_item	3563198	et	4	main
televisioonile	doc_399014257168_item	3563199	et	4	main
minu	doc_399014257168_item	3563211	et	3	main
valmistuda	doc_399014257168_item	3563214	et	3	main
samuti	doc_399014257167_item	3562708	et	3	main
hakkanud	doc_399014257167_item	3562711	et	4	main
seda	doc_399014257167_item	3562719	et	3	main
läinud	doc_399014257167_item	3562723	et	4	main
hufvudstadsbladetit	doc_399014257167_item	3562725	et	4	main
kodus	doc_399014257167_item	3562726	et	4	main
sanomate	doc_399014257167_item	3562739	et	4	main
on	doc_399014257167_item	3562750	et	4	main
ja	doc_399014257167_item	3562761	et	3	main
ta	doc_399014257167_item	3562762	et	4	main
sellist	doc_399014257167_item	3562780	et	4	main
et	doc_399014257167_item	3562781	et	3	main
tajusin	doc_399014257167_item	3562788	et	3	main
täielikult	doc_399014257167_item	3562804	et	4	main
kui	doc_399014257167_item	3562807	et	3	main
noored	doc_399014257167_item	3562815	et	3	main
vaatavad	doc_399014257167_item	3562817	et	4	main
muud	doc_399014257167_item	3562819	et	4	main
ilma	doc_399014257167_item	3562830	et	4	main
programm	doc_399014257167_item	3562833	et	3	main
inimesed	doc_399014257167_item	3562848	et	3	main
võib-olla	doc_399014257167_item	3562850	et	3	main
aga	doc_399014257167_item	3562852	et	3	main
vastutamatute	doc_399014257167_item	3562855	et	4	main
arvustajate	doc_399014257167_item	3562856	et	4	main
räägitud	doc_399014257167_item	3562865	et	4	main
on	doc_399014257167_item	3562867	et	4	main
raadio	doc_399014257167_item	3562873	et	4	main
mida	doc_399014257167_item	3562880	et	4	main
kasutasin	doc_399014257167_item	3562881	et	3	main
ja	doc_399014257167_item	3562882	et	3	main
tähtis	doc_399014257167_item	3562889	et	4	main
kuulata	doc_399014257167_item	3562892	et	4	main
enam	doc_399014257167_item	3562922	et	4	main
kui	doc_399014257167_item	3562923	et	3	main
päevas	doc_399014257167_item	3562927	et	3	main
harilikult	doc_399014257167_item	3562933	et	4	main
mulle	doc_399014257167_item	3562935	et	4	main
oma	doc_399014257167_item	3562809	et	4	main
tean	doc_399014257167_item	3562813	et	3	main
täiesti	doc_399014257167_item	3562818	et	3	main
kui	doc_399014257167_item	3562820	et	3	main
nendega	doc_399014257167_item	3562828	et	4	main
neid	doc_399014257167_item	3562831	et	4	main
jäänud	doc_399014257167_item	3562834	et	4	main
ilma	doc_399014257167_item	3562835	et	4	main
uskumatu	doc_399014257167_item	3562842	et	4	main
vaadata	doc_399014257167_item	3562843	et	4	main
noored	doc_399014257167_item	3562847	et	3	main
igal	doc_399014257167_item	3562853	et	3	main
ime	doc_399014257167_item	3562860	et	4	main
kui	doc_399014257167_item	3562861	et	3	main
programmist	doc_399014257167_item	3562862	et	4	main
aeg-ajalt	doc_399014257167_item	3562872	et	4	main
oli	doc_399014257167_item	3562874	et	3	main
elu	doc_399014257167_item	3562877	et	4	main
eesmas	doc_399014257167_item	3562878	et	4	main
erinevaid	doc_399014257167_item	3562893	et	4	main
kavu	doc_399014257167_item	3562894	et	3	main
ja	doc_399014257167_item	3562895	et	3	main
samal	doc_399014257167_item	3562896	et	3	main
ajal	doc_399014257167_item	3562897	et	4	main
suudab	doc_399014257167_item	3562898	et	3	main
teha	doc_399014257167_item	3562899	et	3	main
midagi	doc_399014257167_item	3562900	et	4	main
muud	doc_399014257167_item	3562901	et	4	main
on	doc_399014257167_item	3562902	et	4	main
mitmeid	doc_399014257167_item	3562903	et	4	main
kanalit	doc_399014257167_item	3562904	et	3	main
keid	doc_399014257167_item	3562905	et	4	main
on	doc_399014257167_item	3562906	et	4	main
kui	doc_399014257167_item	3562912	et	3	main
nooreks	doc_399014257167_item	3562914	et	3	main
aeg	doc_399014257167_item	3562918	et	3	main
millal	doc_399014257167_item	3562919	et	3	main
raadio	doc_399014257167_item	3562920	et	4	main
saadab	doc_399014257167_item	3562921	et	3	main
pooltundise	doc_399014257167_item	3562926	et	4	main
tulnud	doc_399014257167_item	3562939	et	4	main
lugeda	doc_399014257167_item	3562940	et	3	main
kodumaa	doc_399014257167_item	3562941	et	4	main
essee	doc_399014257168_item	3562972	et	4	main
minu	doc_399014257168_item	3562974	et	3	main
asub	doc_399014257168_item	3562978	et	3	main
raadio-	doc_399014257168_item	3562990	et	4	main
ajakirjadus	doc_399014257168_item	3562994	et	4	main
puutub	doc_399014257168_item	3562995	et	3	main
pärast	doc_399014257168_item	3562998	et	4	main
loomulikult	doc_399014257168_item	3563010	et	4	main
selle	doc_399014257168_item	3563019	et	4	main
pärast	doc_399014257168_item	3563041	et	4	main
sageli	doc_399014257168_item	3563044	et	3	main
üks	doc_399014257168_item	3563046	et	3	main
tund	doc_399014257168_item	3563047	et	3	main
mis	doc_399014257168_item	3563057	et	4	main
ma	doc_399014257168_item	3563058	et	3	main
lugenud	doc_399014257168_item	3563059	et	4	main
jaoks	doc_399014257168_item	3563070	et	4	main
kaheteistkümnest	doc_399014257168_item	3563071	et	3	main
palju	doc_399014257167_item	3562911	et	4	main
teadnud	doc_399014257167_item	3562915	et	4	main
et	doc_399014257167_item	3562916	et	3	main
tuleb	doc_399014257167_item	3562917	et	3	main
tõsi	doc_399014257167_item	3562928	et	4	main
mulle	doc_399014257167_item	3562930	et	4	main
kõnekavad	doc_399014257167_item	3562932	et	3	main
internetist	doc_399014257167_item	3562934	et	4	main
kombeks	doc_399014257167_item	3562938	et	4	main
uudiseid	doc_399014257167_item	3562942	et	3	main
aga	doc_399014257167_item	3562943	et	3	main
kui	doc_399014257167_item	3562944	et	3	main
tahan	doc_399014257167_item	3562945	et	3	main
näiteks	doc_399014257167_item	3562946	et	4	main
eestist	doc_399014257167_item	3562947	et	3	main
midagi	doc_399014257167_item	3562948	et	4	main
teada	doc_399014257167_item	3562949	et	3	main
lahti	doc_399014257167_item	3562950	et	4	main
teen	doc_399014257167_item	3562951	et	3	main
arvutit	doc_399014257167_item	3562952	et	3	main
internet	doc_399014257167_item	3562953	et	4	main
võimalikuks	doc_399014257167_item	3562955	et	3	main
on	doc_399014257167_item	3562954	et	4	main
teinud	doc_399014257167_item	3562956	et	4	main
lugijate	doc_399014257167_item	3562957	et	4	main
ja	doc_399014257167_item	3562958	et	3	main
kuulijte	doc_399014257167_item	3562959	et	4	main
ning	doc_399014257167_item	3562960	et	3	main
meedia	doc_399014257167_item	3562961	et	4	main
vestlemise	doc_399014257167_item	3562963	et	4	main
omavahelise	doc_399014257167_item	3562962	et	4	main
ja	doc_399014257167_item	3562964	et	3	main
arvan	doc_399014257167_item	3562965	et	3	main
et	doc_399014257167_item	3562966	et	3	main
see	doc_399014257167_item	3562967	et	3	main
tuleb	doc_399014257167_item	3562968	et	3	main
veel	doc_399014257167_item	3562969	et	4	main
tähtisam	doc_399014257167_item	3562970	et	4	main
keset	doc_399014257168_item	3562979	et	4	main
ega	doc_399014257168_item	3562991	et	3	main
tv-saateid	doc_399014257168_item	3562992	et	3	main
mina	doc_399014257168_item	3563001	et	4	main
mulle	doc_399014257168_item	3563008	et	4	main
on	doc_399014257168_item	3563009	et	4	main
aeganõudev	doc_399014257168_item	3563039	et	3	main
mille	doc_399014257168_item	3563040	et	3	main
hommiku	doc_399014257168_item	3563048	et	3	main
teised	doc_399014257168_item	3563077	et	4	main
ja	doc_399014257168_item	3563083	et	3	main
on	doc_399014257168_item	3563093	et	4	main
soome	doc_399014257168_item	3563094	et	3	main
rootsi	doc_399014257168_item	3563095	et	4	main
keeles	doc_399014257168_item	3563100	et	4	main
meeldib	doc_399014257167_item	3562931	et	3	main
ole	doc_399014257167_item	3562937	et	4	main
meedia	doc_399014257168_item	3562973	et	4	main
linnaosas	doc_399014257168_item	3562985	et	3	main
kahjuks	doc_399014257168_item	3562986	et	4	main
riigis	doc_399014257168_item	3562987	et	3	main
pole	doc_399014257168_item	3562988	et	3	main
omakeelseid	doc_399014257168_item	3562989	et	3	main
selle	doc_399014257168_item	3562997	et	4	main
elanikud	doc_399014257168_item	3563000	et	3	main
riigipeana	doc_399014257168_item	3563007	et	3	main
toimub	doc_399014257168_item	3563018	et	3	main
kahjuks	doc_399014257168_item	3563052	et	4	main
unustan	doc_399014257168_item	3563053	et	3	main
väga	doc_399014257168_item	3563054	et	3	main
kiiresti	doc_399014257168_item	3563055	et	3	main
kaabelühendust	doc_399014257168_item	3563064	et	4	main
üks	doc_399014257168_item	3563065	et	3	main
telekanalist	doc_399014257168_item	3563072	et	4	main
on	doc_399014257168_item	3563074	et	4	main
soome	doc_399014257168_item	3563075	et	3	main
keeles	doc_399014257168_item	3563076	et	4	main
saksa	doc_399014257168_item	3563082	et	4	main
analoogseid	doc_399014257168_item	3563086	et	3	main
elanikkonda	doc_399014257168_item	3563102	et	4	main
enam	doc_399014257168_item	3563105	et	4	main
uunot	doc_399014257168_item	3563111	et	4	main
internetis	doc_399014257168_item	3563112	et	4	main
loetakse	doc_399014257168_item	3563113	et	3	main
ka	doc_399014257168_item	3563114	et	3	main
tv-saateid	doc_399014257168_item	3563120	et	3	main
sel	doc_399014257168_item	3563132	et	3	main
kultuurielus	doc_399014257168_item	3563136	et	4	main
tõsielusari	doc_399014257168_item	3563141	et	4	main
riigi	doc_399014257168_item	3563147	et	3	main
autasu	doc_399014257168_item	3563149	et	4	main
kultuuri-	doc_399014257168_item	3563150	et	4	main
alal	doc_399014257168_item	3563153	et	4	main
riikis	doc_399014257168_item	3562975	et	4	main
minu	doc_399014257168_item	3562976	et	3	main
riik	doc_399014257168_item	3562977	et	3	main
vabariiki	doc_399014257168_item	3562981	et	4	main
helsingi	doc_399014257168_item	3562982	et	4	main
11ndas	doc_399014257168_item	3562984	et	4	main
riigi	doc_399014257168_item	3562999	et	3	main
soome	doc_399014257168_item	3563004	et	3	main
tähtis	doc_399014257168_item	3563011	et	4	main
teada	doc_399014257168_item	3563012	et	3	main
mis	doc_399014257168_item	3563013	et	4	main
naaberriigis	doc_399014257168_item	3563014	et	3	main
ja	doc_399014257168_item	3563015	et	3	main
mujal	doc_399014257168_item	3563016	et	3	main
maailmas	doc_399014257168_item	3563017	et	3	main
pärast	doc_399014257168_item	3563020	et	4	main
loen	doc_399014257168_item	3563021	et	3	main
soome	doc_399014257168_item	3563022	et	3	main
kõige	doc_399014257168_item	3563023	et	4	main
suuremat	doc_399014257168_item	3563024	et	4	main
ajalehte	doc_399014257168_item	3563025	et	4	main
helsingin	doc_399014257168_item	3563026	et	4	main
sanomat	doc_399014257168_item	3563027	et	4	main
igal	doc_399014257168_item	3563028	et	3	main
hommikul	doc_399014257168_item	3563029	et	3	main
samal	doc_399014257168_item	3563030	et	3	main
ajal	doc_399014257168_item	3563031	et	4	main
kuulan	doc_399014257168_item	3563032	et	3	main
raadiot	doc_399014257168_item	3563033	et	3	main
riigi	doc_399014257168_item	3563034	et	3	main
valitsemissüsteem	doc_399014257168_item	3563035	et	3	main
mul	doc_399014257168_item	3563042	et	3	main
ainult	doc_399014257168_item	3563045	et	4	main
kohta	doc_399014257168_item	3563049	et	4	main
ajalehte	doc_399014257168_item	3563050	et	4	main
lugeda	doc_399014257168_item	3563051	et	3	main
olen	doc_399014257168_item	3563060	et	3	main
riigis	doc_399014257168_item	3563061	et	3	main
on	doc_399014257168_item	3563062	et	4	main
kaks	doc_399014257168_item	3563063	et	3	main
palju	doc_399014257168_item	3563090	et	4	main
ja	doc_399014257168_item	3563091	et	3	main
need	doc_399014257168_item	3563092	et	3	main
eesti	doc_399014257168_item	3563099	et	4	main
raadio	doc_399014257168_item	3563110	et	4	main
peetakse	doc_399014257168_item	3563122	et	3	main
minu	doc_399014257168_item	3563123	et	3	main
enam	doc_399014257168_item	3563131	et	4	main
olnud	doc_399014257168_item	3563140	et	4	main
brother	doc_399014257168_item	3563143	et	4	main
kavatsetakse	doc_399014257168_item	3563145	et	3	main
praegu	doc_399014257168_item	3563177	et	3	main
komöödiasarju	doc_399014257168_item	3563179	et	3	main
all	doc_399014257168_item	3563187	et	3	main
varase	doc_399014257168_item	3563189	et	4	main
esitusaja	doc_399014257168_item	3563190	et	3	main
eksameid	doc_399014257168_item	3563210	et	3	main
nendeks	doc_399014257168_item	3563213	et	4	main
ka	doc_399014257168_item	3563215	et	3	main
kuigi	doc_399014257168_item	3563217	et	3	main
kirjandus	doc_399014257168_item	3563247	et	3	main
muusikata	doc_399014257168_item	3563253	et	3	main
paremaks	doc_399014257168_item	3563258	et	4	main
on	doc_399014257168_item	3563260	et	4	main
kompenseeritakse	doc_399014257168_item	3563268	et	3	main
revolutsioone	doc_399014257168_item	3563275	et	3	main
hakkan	doc_399014257168_item	3563277	et	3	main
essee	doc_399014257170_item	3563291	et	4	main
on	doc_399014257170_item	3563302	et	4	main
sõltub	doc_399014257170_item	3563309	et	3	main
varem	doc_399014257170_item	3563323	et	4	main
räägiti	doc_399014257170_item	3563325	et	3	main
paremaks	doc_399014257170_item	3563333	et	4	main
meedia	doc_399014257170_item	3563342	et	4	main
milles	doc_399014257170_item	3563343	et	3	main
seda	doc_399014257170_item	3563344	et	3	main
kasutatakse	doc_399014257170_item	3563345	et	3	main
ka	doc_399014257170_item	3563350	et	3	main
miks	doc_399014257170_item	3563352	et	4	main
teada	doc_399014257170_item	3563411	et	3	main
aja	doc_399014257170_item	3563413	et	4	main
keelest	doc_399014257170_item	3563414	et	4	main
ja	doc_399014257170_item	3563415	et	3	main
kultuurist	doc_399014257170_item	3563416	et	3	main
ka	doc_399014257170_item	3563417	et	3	main
pärast	doc_399014257170_item	3563424	et	4	main
see	doc_399014257170_item	3563425	et	3	main
ja	doc_399014257170_item	3563429	et	3	main
olemas	doc_399014257170_item	3563446	et	4	main
on	doc_399014257170_item	3563451	et	4	main
suhed	doc_399014257170_item	3563453	et	4	main
keelel	doc_399014257170_item	3563455	et	4	main
kirjutamise	doc_399014257170_item	3563460	et	4	main
ja	doc_399014257170_item	3563461	et	3	main
meedia	doc_399014257170_item	3563462	et	4	main
traditsioon	doc_399014257170_item	3563463	et	3	main
soome	doc_399014257170_item	3563464	et	3	main
1500-ndail	doc_399014257170_item	3563468	et	4	main
kirjutised	doc_399014257170_item	3563471	et	3	main
usulised	doc_399014257170_item	3563474	et	4	main
kui	doc_399014257170_item	3563493	et	3	main
aga	doc_399014257170_item	3563497	et	3	main
muidugi	doc_399014257170_item	3563500	et	4	main
väga	doc_399014257170_item	3563501	et	3	main
ka	doc_399014257170_item	3563514	et	3	main
kui	doc_399014257170_item	3563520	et	3	main
tavaliselt	doc_399014257170_item	3563533	et	4	main
kasutatakse	doc_399014257170_item	3563548	et	3	main
teiste	doc_399014257170_item	3563551	et	4	main
sattuvad	doc_399014257170_item	3563554	et	4	main
selle	doc_399014257170_item	3563555	et	4	main
kanalid	doc_399014257168_item	3563078	et	3	main
on	doc_399014257168_item	3563079	et	4	main
rootsi	doc_399014257168_item	3563080	et	4	main
inglise	doc_399014257168_item	3563084	et	4	main
keeles	doc_399014257168_item	3563085	et	4	main
raadiokanaleid	doc_399014257168_item	3563087	et	4	main
on	doc_399014257168_item	3563088	et	4	main
riigis	doc_399014257168_item	3563089	et	3	main
vene	doc_399014257168_item	3563097	et	4	main
ja	doc_399014257168_item	3563098	et	3	main
siiski	doc_399014257168_item	3563101	et	4	main
eesti	doc_399014257168_item	3563109	et	4	main
ajalehti	doc_399014257168_item	3563116	et	4	main
ja	doc_399014257168_item	3563117	et	3	main
televisiooni	doc_399014257168_item	3563121	et	4	main
riigis	doc_399014257168_item	3563124	et	3	main
selle	doc_399014257168_item	3563126	et	4	main
tähtsamaks	doc_399014257168_item	3563138	et	4	main
ja	doc_399014257168_item	3563151	et	3	main
tõsielusarjad	doc_399014257168_item	3563156	et	3	main
populaarsed	doc_399014257168_item	3563160	et	3	main
nende	doc_399014257168_item	3563161	et	4	main
hulkas	doc_399014257168_item	3563162	et	4	main
seikkailijat	doc_399014257168_item	3563163	et	4	main
ja	doc_399014257168_item	3563164	et	3	main
amazing	doc_399014257168_item	3563165	et	4	main
race	doc_399014257168_item	3563166	et	4	main
on	doc_399014257168_item	3563167	et	4	main
kõrgelt	doc_399014257168_item	3563168	et	4	main
austatud	doc_399014257168_item	3563169	et	4	main
uutiseid	doc_399014257168_item	3563170	et	4	main
ja	doc_399014257168_item	3563171	et	3	main
minu	doc_399014257168_item	3563175	et	3	main
ja	doc_399014257168_item	3563180	et	3	main
enam	doc_399014257168_item	3563182	et	4	main
liiga	doc_399014257168_item	3563188	et	4	main
tõttu	doc_399014257168_item	3563191	et	4	main
keele	doc_399014257168_item	3563194	et	4	main
tuleb	doc_399014257168_item	3563212	et	3	main
vahele	doc_399014257168_item	3563231	et	4	main
detsembrikuu	doc_399014257168_item	3563233	et	4	main
eksamhooaeg	doc_399014257168_item	3563234	et	4	main
ei	doc_399014257168_item	3563235	et	4	main
tekkida	doc_399014257168_item	3563236	et	3	main
meeleavaldusi	doc_399014257168_item	3563237	et	3	main
ja	doc_399014257168_item	3563238	et	3	main
lööminguid	doc_399014257168_item	3563239	et	3	main
sel	doc_399014257168_item	3563240	et	3	main
aastal	doc_399014257168_item	3563241	et	3	main
minu	doc_399014257168_item	3563242	et	3	main
peetakse	doc_399014257168_item	3563256	et	3	main
meedial	doc_399014257168_item	3563259	et	4	main
väga	doc_399014257168_item	3563261	et	3	main
tähtis	doc_399014257168_item	3563262	et	4	main
roll	doc_399014257168_item	3563263	et	3	main
riigi	doc_399014257168_item	3563264	et	3	main
riigi	doc_399014257168_item	3563269	et	3	main
vaatatakse	doc_399014257168_item	3563118	et	4	main
eesti	doc_399014257168_item	3563119	et	4	main
kõrgkultuuriks	doc_399014257168_item	3563125	et	4	main
pärast	doc_399014257168_item	3563127	et	4	main
jälgitakse	doc_399014257168_item	3563128	et	3	main
seda	doc_399014257168_item	3563129	et	3	main
kõige	doc_399014257168_item	3563130	et	4	main
ongi	doc_399014257168_item	3563134	et	4	main
riigi	doc_399014257168_item	3563135	et	3	main
kõige	doc_399014257168_item	3563137	et	4	main
millele	doc_399014257168_item	3563144	et	3	main
meedia	doc_399014257168_item	3563152	et	4	main
ka	doc_399014257168_item	3563154	et	3	main
teised	doc_399014257168_item	3563155	et	4	main
on	doc_399014257168_item	3563157	et	4	main
riigis	doc_399014257168_item	3563158	et	3	main
eriti	doc_399014257168_item	3563159	et	3	main
riigis	doc_399014257168_item	3563176	et	3	main
aeg-ajalt	doc_399014257168_item	3563192	et	4	main
õppingud	doc_399014257168_item	3563195	et	4	main
häirivad	doc_399014257168_item	3563196	et	4	main
minu	doc_399014257168_item	3563197	et	3	main
riigis	doc_399014257168_item	3563243	et	3	main
meedia	doc_399014257168_item	3563244	et	4	main
raadio	doc_399014257168_item	3563249	et	4	main
igavad	doc_399014257168_item	3563250	et	3	main
ilma	doc_399014257168_item	3563252	et	4	main
tavalist	doc_399014257168_item	3563257	et	4	main
elus	doc_399014257168_item	3563266	et	4	main
kultuurielu	doc_399014257168_item	3563271	et	4	main
puudust	doc_399014257168_item	3563272	et	4	main
big	doc_399014257168_item	3563279	et	4	main
ja	doc_399014257170_item	3563293	et	3	main
kahetised	doc_399014257170_item	3563303	et	3	main
teistesse	doc_399014257170_item	3563305	et	4	main
sellesse	doc_399014257170_item	3563306	et	4	main
muidugi	doc_399014257170_item	3563310	et	4	main
vaatevinklist	doc_399014257170_item	3563311	et	4	main
ja	doc_399014257170_item	3563312	et	3	main
kui	doc_399014257170_item	3563320	et	3	main
kirjakeel	doc_399014257170_item	3563327	et	4	main
see	doc_399014257170_item	3563328	et	3	main
muidugi	doc_399014257170_item	3563329	et	4	main
saab	doc_399014257170_item	3563330	et	3	main
ja	doc_399014257170_item	3563334	et	3	main
on	doc_399014257170_item	3563347	et	4	main
selles	doc_399014257170_item	3563351	et	4	main
kirjakeelt	doc_399014257170_item	3563353	et	4	main
arendatakse	doc_399014257170_item	3563354	et	3	main
keeleline	doc_399014257170_item	3563392	et	4	main
areneb	doc_399014257170_item	3563394	et	3	main
sellesse	doc_399014257170_item	3563397	et	4	main
liitub	doc_399014257170_item	3563398	et	3	main
ka	doc_399014257170_item	3563399	et	3	main
palju	doc_399014257170_item	3563418	et	4	main
hiljem	doc_399014257170_item	3563419	et	3	main
kasvõi	doc_399014257170_item	3563420	et	3	main
on	doc_399014257170_item	3563426	et	4	main
keeli	doc_399014257170_item	3563444	et	4	main
millised	doc_399014257170_item	3563450	et	3	main
ei	doc_399014257170_item	3563456	et	4	main
hakati	doc_399014257170_item	3563466	et	3	main
siis	doc_399014257170_item	3563491	et	3	main
keel	doc_399014257170_item	3563508	et	4	main
erineb	doc_399014257170_item	3563509	et	3	main
ilmalikust	doc_399014257170_item	3563510	et	4	main
teistsugune	doc_399014257170_item	3563515	et	3	main
on	doc_399014257170_item	3563522	et	4	main
kui	doc_399014257170_item	3563525	et	3	main
ainult	doc_399014257170_item	3563526	et	4	main
üks	doc_399014257170_item	3563527	et	3	main
olukord	doc_399014257170_item	3563532	et	3	main
suurima	doc_399014257170_item	3563556	et	4	main
rohkem	doc_399014257170_item	3563572	et	4	main
tahavad	doc_399014257170_item	3563575	et	3	main
keelt	doc_399014257170_item	3563583	et	4	main
osata	doc_399014257170_item	3563584	et	4	main
et	doc_399014257170_item	3563585	et	3	main
ajalehti	doc_399014257170_item	3563586	et	4	main
lugeda	doc_399014257170_item	3563587	et	3	main
kui	doc_399014257170_item	3563588	et	3	main
nad	doc_399014257170_item	3563589	et	3	main
vaatatakse	doc_399014257168_item	3563174	et	4	main
vähem	doc_399014257168_item	3563178	et	4	main
filme	doc_399014257168_item	3563181	et	3	main
hommiku-tv	doc_399014257168_item	3563183	et	4	main
on	doc_399014257168_item	3563184	et	4	main
riikliku	doc_399014257168_item	3563185	et	3	main
eesti	doc_399014257168_item	3563193	et	4	main
õpejõud	doc_399014257168_item	3563200	et	4	main
käsivad	doc_399014257168_item	3563201	et	3	main
mind	doc_399014257168_item	3563202	et	4	main
kirjutama	doc_399014257168_item	3563203	et	3	main
igavaid	doc_399014257168_item	3563204	et	3	main
ja	doc_399014257168_item	3563205	et	3	main
aegnõudevaid	doc_399014257168_item	3563206	et	3	main
tekste	doc_399014257168_item	3563207	et	3	main
ja	doc_399014257168_item	3563208	et	3	main
korraldavad	doc_399014257168_item	3563209	et	4	main
riigipeana	doc_399014257168_item	3563220	et	3	main
olla	doc_399014257168_item	3563221	et	3	main
tuleks	doc_399014257168_item	3563219	et	4	main
huvitatud	doc_399014257168_item	3563222	et	4	main
kõrgkultturist	doc_399014257168_item	3563223	et	4	main
sel	doc_399014257168_item	3563224	et	3	main
õhtulgi	doc_399014257168_item	3563225	et	3	main
on	doc_399014257168_item	3563226	et	4	main
mitmeid	doc_399014257168_item	3563227	et	4	main
tähtsaid	doc_399014257168_item	3563228	et	3	main
saateid	doc_399014257168_item	3563229	et	3	main
jäänud	doc_399014257168_item	3563230	et	4	main
õhtutel	doc_399014257168_item	3563216	et	3	main
minu	doc_399014257168_item	3563218	et	3	main
madalkihti	doc_399014257168_item	3563245	et	4	main
ja	doc_399014257168_item	3563248	et	3	main
saated	doc_399014257168_item	3563251	et	3	main
kollast	doc_399014257168_item	3563254	et	4	main
ajakirjandust	doc_399014257168_item	3563255	et	3	main
sellega	doc_399014257168_item	3563267	et	3	main
muu	doc_399014257168_item	3563270	et	4	main
ja	doc_399014257168_item	3563273	et	3	main
tõkestatakse	doc_399014257168_item	3563274	et	3	main
nüüd	doc_399014257168_item	3563276	et	4	main
jälle	doc_399014257168_item	3563278	et	3	main
brotheriks	doc_399014257168_item	3563280	et	4	main
valmistuma	doc_399014257168_item	3563281	et	3	main
ordenid	doc_399014257168_item	3563282	et	3	main
rinnale	doc_399014257168_item	3563283	et	3	main
loodetavasti	doc_399014257168_item	3563232	et	3	main
kuulub	doc_399014257168_item	3563246	et	3	main
elanikkonda	doc_399014257168_item	3563265	et	4	main
nende	doc_399014257170_item	3563294	et	4	main
meedia	doc_399014257170_item	3563298	et	4	main
tavaliselt	doc_399014257170_item	3563299	et	4	main
igal	doc_399014257170_item	3563300	et	3	main
nähtusel	doc_399014257170_item	3563301	et	4	main
liituvatesse	doc_399014257170_item	3563307	et	4	main
sellest	doc_399014257170_item	3563313	et	4	main
kelle	doc_399014257170_item	3563314	et	4	main
mida	doc_399014257170_item	3563322	et	4	main
ainult	doc_399014257170_item	3563324	et	4	main
tehakse	doc_399014257170_item	3563326	et	3	main
seisukorra	doc_399014257170_item	3563332	et	3	main
üks	doc_399014257170_item	3563348	et	3	main
teadlikkus	doc_399014257170_item	3563393	et	4	main
ja	doc_399014257170_item	3563395	et	3	main
võimalik	doc_399014257170_item	3563409	et	3	main
selle	doc_399014257170_item	3563412	et	4	main
mitme	doc_399014257170_item	3563421	et	4	main
saja	doc_399014257170_item	3563422	et	4	main
aasta	doc_399014257170_item	3563423	et	4	main
selle	doc_399014257170_item	3563430	et	4	main
iseennale	doc_399014257170_item	3563432	et	4	main
üldises	doc_399014257170_item	3563436	et	3	main
keelte	doc_399014257170_item	3563437	et	3	main
uurimises	doc_399014257170_item	3563438	et	4	main
ja	doc_399014257170_item	3563449	et	3	main
nende	doc_399014257170_item	3563452	et	4	main
soome	doc_399014257170_item	3563454	et	3	main
kirjutama	doc_399014257170_item	3563467	et	3	main
esimesed	doc_399014257170_item	3563470	et	3	main
enamasti	doc_399014257170_item	3563473	et	4	main
kirjutatud	doc_399014257170_item	3563494	et	4	main
usulik	doc_399014257170_item	3563507	et	4	main
keele	doc_399014257170_item	3563517	et	4	main
olla	doc_399014257170_item	3563519	et	3	main
riigis	doc_399014257170_item	3563521	et	3	main
elus	doc_399014257170_item	3563550	et	4	main
keele	doc_399014257170_item	3563557	et	4	main
peavad	doc_399014257170_item	3563560	et	4	main
saada	doc_399014257170_item	3563579	et	4	main
tahavad	doc_399014257170_item	3563590	et	3	main
tööd	doc_399014257170_item	3563592	et	4	main
peavad	doc_399014257170_item	3563598	et	4	main
kahjuks	doc_399014257170_item	3563605	et	4	main
see	doc_399014257170_item	3563607	et	3	main
teiste	doc_399014257170_item	3563609	et	4	main
sest	doc_399014257170_item	3563615	et	4	main
lähemas	doc_399014257170_item	3563629	et	4	main
suremist	doc_399014257170_item	3563637	et	4	main
oleks	doc_399014257170_item	3563638	et	3	main
veel	doc_399014257170_item	3563662	et	4	main
ja	doc_399014257168_item	3563284	et	3	main
riigipea	doc_399014257168_item	3563285	et	4	main
diivani	doc_399014257168_item	3563286	et	4	main
peale	doc_399014257168_item	3563287	et	4	main
head	doc_399014257168_item	3563288	et	4	main
ööd	doc_399014257168_item	3563289	et	4	main
seisukorra	doc_399014257170_item	3563295	et	3	main
arenemine	doc_399014257170_item	3563296	et	4	main
nähtustesse	doc_399014257170_item	3563308	et	4	main
poolele	doc_399014257170_item	3563315	et	4	main
asetutakse	doc_399014257170_item	3563316	et	3	main
millisena	doc_399014257170_item	3563317	et	3	main
nähtus	doc_399014257170_item	3563318	et	4	main
keelele	doc_399014257170_item	3563321	et	4	main
kui	doc_399014257170_item	3563335	et	3	main
kirjakeel	doc_399014257170_item	3563337	et	4	main
peaaegu	doc_399014257170_item	3563339	et	3	main
ka	doc_399014257170_item	3563341	et	3	main
meedia	doc_399014257170_item	3563346	et	4	main
meedias	doc_399014257170_item	3563405	et	4	main
ja	doc_399014257170_item	3563406	et	3	main
mujal	doc_399014257170_item	3563407	et	3	main
on	doc_399014257170_item	3563408	et	4	main
hea	doc_399014257170_item	3563427	et	4	main
näiteks	doc_399014257170_item	3563439	et	4	main
keeletüpoloogias	doc_399014257170_item	3563440	et	3	main
saadakse	doc_399014257170_item	3563441	et	3	main
teada	doc_399014257170_item	3563442	et	3	main
millisi	doc_399014257170_item	3563443	et	4	main
kui	doc_399014257170_item	3563447	et	3	main
keelt	doc_399014257170_item	3563465	et	4	main
aastail	doc_399014257170_item	3563469	et	4	main
keelte	doc_399014257170_item	3563292	et	3	main
ja	doc_399014257170_item	3563297	et	3	main
mõjutused	doc_399014257170_item	3563304	et	4	main
näib	doc_399014257170_item	3563319	et	3	main
keele	doc_399014257170_item	3563331	et	4	main
on	doc_399014257170_item	3563336	et	4	main
on	doc_399014257170_item	3563338	et	4	main
alati	doc_399014257170_item	3563340	et	4	main
tegur	doc_399014257170_item	3563349	et	3	main
tahtakse	doc_399014257170_item	3563355	et	4	main
et	doc_399014257170_item	3563356	et	3	main
oma	doc_399014257170_item	3563357	et	4	main
rahval	doc_399014257170_item	3563358	et	3	main
oleks	doc_399014257170_item	3563359	et	3	main
sama	doc_399014257170_item	3563360	et	4	main
hea	doc_399014257170_item	3563361	et	4	main
aja-	doc_399014257170_item	3563362	et	4	main
ja	doc_399014257170_item	3563363	et	3	main
ilukirjandus	doc_399014257170_item	3563364	et	3	main
kui	doc_399014257170_item	3563365	et	3	main
teistelgi	doc_399014257170_item	3563366	et	4	main
rahvastel	doc_399014257170_item	3563367	et	4	main
keel	doc_399014257170_item	3563368	et	4	main
hakatakse	doc_399014257170_item	3563369	et	3	main
kasutama	doc_399014257170_item	3563370	et	3	main
rohkem	doc_399014257170_item	3563371	et	4	main
ja	doc_399014257170_item	3563372	et	3	main
seda	doc_399014257170_item	3563373	et	3	main
koos	doc_399014257170_item	3563374	et	4	main
lugemise	doc_399014257170_item	3563375	et	4	main
ja	doc_399014257170_item	3563376	et	3	main
kirjutamisega	doc_399014257170_item	3563377	et	4	main
hakatakse	doc_399014257170_item	3563378	et	3	main
õpetama	doc_399014257170_item	3563379	et	3	main
lastele	doc_399014257170_item	3563380	et	4	main
keele	doc_399014257170_item	3563381	et	4	main
seisukord	doc_399014257170_item	3563382	et	3	main
saab	doc_399014257170_item	3563384	et	3	main
siis	doc_399014257170_item	3563383	et	3	main
palju	doc_399014257170_item	3563385	et	4	main
paremaks	doc_399014257170_item	3563386	et	4	main
kui	doc_399014257170_item	3563387	et	3	main
see	doc_399014257170_item	3563388	et	3	main
varem	doc_399014257170_item	3563389	et	4	main
oli	doc_399014257170_item	3563390	et	3	main
inimeste	doc_399014257170_item	3563391	et	3	main
kasvab	doc_399014257170_item	3563396	et	3	main
see	doc_399014257170_item	3563400	et	3	main
et	doc_399014257170_item	3563401	et	3	main
kui	doc_399014257170_item	3563402	et	3	main
keelt	doc_399014257170_item	3563403	et	4	main
kirjutatakse	doc_399014257170_item	3563404	et	3	main
saada	doc_399014257170_item	3563410	et	4	main
keelele	doc_399014257170_item	3563428	et	4	main
uurimisele	doc_399014257170_item	3563431	et	4	main
aga	doc_399014257170_item	3563433	et	3	main
kasuks	doc_399014257170_item	3563434	et	4	main
ka	doc_399014257170_item	3563435	et	3	main
on	doc_399014257170_item	3563445	et	4	main
palju	doc_399014257170_item	3563448	et	4	main
ole	doc_399014257170_item	3563457	et	4	main
väga	doc_399014257170_item	3563458	et	3	main
vana	doc_399014257170_item	3563459	et	4	main
olid	doc_399014257170_item	3563472	et	4	main
näiteks	doc_399014257170_item	3563475	et	4	main
piibel	doc_399014257170_item	3563476	et	4	main
ja	doc_399014257170_item	3563477	et	3	main
palveraamat	doc_399014257170_item	3563478	et	3	main
hiljem	doc_399014257170_item	3563479	et	3	main
keelt	doc_399014257170_item	3563480	et	4	main
hakati	doc_399014257170_item	3563481	et	3	main
kirjutama	doc_399014257170_item	3563482	et	3	main
ka	doc_399014257170_item	3563483	et	3	main
mitteusulistes	doc_399014257170_item	3563484	et	4	main
ühendustes	doc_399014257170_item	3563485	et	4	main
näiteks	doc_399014257170_item	3563486	et	4	main
meedias	doc_399014257170_item	3563487	et	4	main
esimesed	doc_399014257170_item	3563488	et	3	main
ajalehed	doc_399014257170_item	3563489	et	3	main
tulid	doc_399014257170_item	3563490	et	4	main
keel	doc_399014257170_item	3563495	et	4	main
olid	doc_399014257170_item	3563499	et	4	main
tähtsad	doc_399014257170_item	3563502	et	3	main
keelest	doc_399014257170_item	3563511	et	4	main
mõju	doc_399014257170_item	3563516	et	4	main
rohkem	doc_399014257170_item	3563523	et	4	main
keeli	doc_399014257170_item	3563524	et	4	main
üldisem	doc_399014257170_item	3563531	et	4	main
ja	doc_399014257170_item	3563547	et	3	main
keelte	doc_399014257170_item	3563552	et	3	main
räägijad	doc_399014257170_item	3563553	et	4	main
nad	doc_399014257170_item	3563559	et	3	main
seda	doc_399014257170_item	3563561	et	3	main
osama	doc_399014257170_item	3563562	et	4	main
et	doc_399014257170_item	3563563	et	3	main
kooli	doc_399014257170_item	3563564	et	4	main
minna	doc_399014257170_item	3563565	et	3	main
on	doc_399014257170_item	3563580	et	4	main
tarvis	doc_399014257170_item	3563581	et	3	main
suurimat	doc_399014257170_item	3563582	et	3	main
jällegi	doc_399014257170_item	3563599	et	4	main
avalikkuse	doc_399014257170_item	3563600	et	4	main
sellest	doc_399014257170_item	3563603	et	4	main
tavaliselt	doc_399014257170_item	3563606	et	4	main
et	doc_399014257170_item	3563608	et	3	main
keelte	doc_399014257170_item	3563610	et	3	main
sellele	doc_399014257170_item	3563623	et	4	main
lisaks	doc_399014257170_item	3563624	et	4	main
toredam	doc_399014257170_item	3563627	et	4	main
olevat	doc_399014257170_item	3563628	et	4	main
hiljem	doc_399014257170_item	3563492	et	3	main
üldse	doc_399014257170_item	3563496	et	3	main
nad	doc_399014257170_item	3563498	et	3	main
ühiskonnale	doc_399014257170_item	3563503	et	4	main
ja	doc_399014257170_item	3563504	et	3	main
keelekasutusele	doc_399014257170_item	3563505	et	4	main
ka	doc_399014257170_item	3563506	et	3	main
meedial	doc_399014257170_item	3563512	et	4	main
võib	doc_399014257170_item	3563513	et	3	main
arenemisele	doc_399014257170_item	3563518	et	4	main
mis	doc_399014257170_item	3563528	et	4	main
on	doc_399014257170_item	3563529	et	4	main
kõige	doc_399014257170_item	3563530	et	4	main
ühel	doc_399014257170_item	3563534	et	3	main
kõige	doc_399014257170_item	3563535	et	4	main
suurimal	doc_399014257170_item	3563536	et	4	main
nendest	doc_399014257170_item	3563537	et	4	main
on	doc_399014257170_item	3563538	et	4	main
parim	doc_399014257170_item	3563539	et	4	main
seisukord	doc_399014257170_item	3563540	et	3	main
ja	doc_399014257170_item	3563541	et	3	main
ainult	doc_399014257170_item	3563542	et	4	main
seda	doc_399014257170_item	3563543	et	3	main
kirjutatakse	doc_399014257170_item	3563544	et	3	main
õpetatakse	doc_399014257170_item	3563545	et	3	main
koolides	doc_399014257170_item	3563546	et	3	main
avalikus	doc_399014257170_item	3563549	et	4	main
ja	doc_399014257170_item	3563566	et	3	main
koolis	doc_399014257170_item	3563567	et	4	main
nad	doc_399014257170_item	3563568	et	3	main
õppivad	doc_399014257170_item	3563569	et	4	main
seda	doc_399014257170_item	3563570	et	3	main
nad	doc_399014257170_item	3563574	et	3	main
midagi	doc_399014257170_item	3563576	et	4	main
maailmast	doc_399014257170_item	3563577	et	4	main
teada	doc_399014257170_item	3563578	et	3	main
midagi	doc_399014257170_item	3563591	et	4	main
eriti	doc_399014257170_item	3563593	et	3	main
avalikku	doc_399014257170_item	3563594	et	4	main
tööd	doc_399014257170_item	3563595	et	4	main
teha	doc_399014257170_item	3563596	et	3	main
nad	doc_399014257170_item	3563597	et	3	main
järgneb	doc_399014257170_item	3563604	et	3	main
keelest	doc_399014257170_item	3563614	et	4	main
ja	doc_399014257170_item	3563622	et	3	main
aeglustada	doc_399014257170_item	3563640	et	3	main
kui	doc_399014257170_item	3563642	et	3	main
tehaks	doc_399014257170_item	3563644	et	4	main
üks	doc_399014257170_item	3563663	et	3	main
meedias	doc_399014257170_item	3563670	et	4	main
keeltest	doc_399014257170_item	3563672	et	4	main
mille	doc_399014257170_item	3563673	et	3	main
inimesed	doc_399014257170_item	3563677	et	3	main
minu	doc_399014257172_item	3563690	et	3	main
tavaliselt	doc_399014257172_item	3563692	et	4	main
kell	doc_399014257172_item	3563695	et	3	main
kaheksa	doc_399014257172_item	3563696	et	4	main
ja	doc_399014257172_item	3563697	et	3	main
söön	doc_399014257172_item	3563698	et	3	main
ma	doc_399014257172_item	3563703	et	3	main
jalgsi	doc_399014257172_item	3563712	et	3	main
3	doc_399014257172_item	3563721	et	2	main
on	doc_399014257172_item	3563724	et	4	main
eesti	doc_399014257172_item	3563725	et	4	main
keelt	doc_399014257172_item	3563728	et	4	main
poliitikat	doc_399014257172_item	3563730	et	3	main
on	doc_399014257172_item	3563733	et	4	main
eesti	doc_399014257172_item	3563734	et	4	main
keelt	doc_399014257172_item	3563735	et	4	main
loeng	doc_399014257172_item	3563736	et	3	main
hakkab	doc_399014257172_item	3563737	et	3	main
kell	doc_399014257172_item	3563738	et	3	main
kümme	doc_399014257172_item	3563739	et	3	main
ja	doc_399014257172_item	3563740	et	3	main
lõppeb	doc_399014257172_item	3563741	et	3	main
kell	doc_399014257172_item	3563742	et	3	main
kaksteist	doc_399014257172_item	3563743	et	4	main
loen	doc_399014257172_item	3563758	et	3	main
ma	doc_399014257172_item	3563761	et	3	main
lähen	doc_399014257172_item	3563762	et	3	main
ülikooli	doc_399014257172_item	3563763	et	4	main
on	doc_399014257172_item	3563766	et	4	main
see	doc_399014257172_item	3563769	et	3	main
loeng	doc_399014257172_item	3563782	et	3	main
viisteist	doc_399014257172_item	3563785	et	4	main
lähen	doc_399014257172_item	3563792	et	3	main
õppimiseks	doc_399014257172_item	3563794	et	4	main
koju	doc_399014257172_item	3563797	et	3	main
pitsat	doc_399014257172_item	3563816	et	4	main
sündis	doc_399014257173_item	3563880	et	3	main
junnil	doc_399014257173_item	3563882	et	3	main
kapsovari	doc_399014257173_item	3563883	et	4	main
ungaris	doc_399014257173_item	3563884	et	4	main
talupoegad	doc_399014257173_item	3563888	et	4	main
õpib	doc_399014257173_item	3563891	et	3	main
hapsburgi	doc_399014257173_item	3563903	et	4	main
impeerium	doc_399014257173_item	3563904	et	3	main
on	doc_399014257173_item	3563907	et	4	main
ta	doc_399014257173_item	3563909	et	4	main
tagastasib	doc_399014257173_item	3563916	et	4	main
palju	doc_399014257173_item	3563924	et	4	main
1934	doc_399014257173_item	3563928	et	2	main
nagy	doc_399014257173_item	3563931	et	4	main
pole	doc_399014257173_item	3563932	et	3	main
riivasib	doc_399014257173_item	3563973	et	4	main
mõjupiirkonda	doc_399014257170_item	3563558	et	4	main
veel	doc_399014257170_item	3563571	et	4	main
kui	doc_399014257170_item	3563573	et	3	main
keelt	doc_399014257170_item	3563601	et	4	main
oma	doc_399014257170_item	3563613	et	4	main
oskamisest	doc_399014257170_item	3563618	et	4	main
on	doc_399014257170_item	3563619	et	4	main
rohkem	doc_399014257170_item	3563620	et	4	main
ajaloos	doc_399014257170_item	3563630	et	4	main
võimalik	doc_399014257170_item	3563639	et	3	main
nendele	doc_399014257170_item	3563643	et	4	main
kirjakeel	doc_399014257170_item	3563645	et	4	main
ja	doc_399014257170_item	3563646	et	3	main
kui	doc_399014257170_item	3563647	et	3	main
seda	doc_399014257170_item	3563648	et	3	main
ja	doc_399014257170_item	3563658	et	3	main
meedial	doc_399014257170_item	3563660	et	4	main
on	doc_399014257170_item	3563661	et	4	main
mõjutustava	doc_399014257170_item	3563665	et	4	main
keelte	doc_399014257170_item	3563666	et	3	main
arenemises	doc_399014257170_item	3563668	et	4	main
kui	doc_399014257170_item	3563669	et	3	main
kirjutatakse	doc_399014257170_item	3563671	et	3	main
tuleks	doc_399014257170_item	3563675	et	4	main
parandada	doc_399014257170_item	3563676	et	3	main
teaksid	doc_399014257170_item	3563678	et	4	main
nendest	doc_399014257170_item	3563679	et	4	main
rohkem	doc_399014257170_item	3563680	et	4	main
ja	doc_399014257170_item	3563681	et	3	main
midagi	doc_399014257170_item	3563682	et	4	main
võiks	doc_399014257170_item	3563683	et	4	main
teha	doc_399014257170_item	3563684	et	3	main
avalikkus	doc_399014257170_item	3563685	et	4	main
võib	doc_399014257170_item	3563686	et	3	main
aidata	doc_399014257170_item	3563687	et	4	main
üheksa	doc_399014257172_item	3563702	et	4	main
käin	doc_399014257172_item	3563706	et	3	main
lähen	doc_399014257172_item	3563710	et	3	main
kolmveerand	doc_399014257172_item	3563714	et	4	main
ja	doc_399014257172_item	3563749	et	3	main
jälle	doc_399014257172_item	3563764	et	3	main
loeng	doc_399014257172_item	3563768	et	3	main
lõppeb	doc_399014257172_item	3563778	et	3	main
kell	doc_399014257172_item	3563779	et	3	main
viisteist	doc_399014257172_item	3563780	et	4	main
kolmas	doc_399014257172_item	3563781	et	3	main
kell	doc_399014257172_item	3563784	et	3	main
on	doc_399014257172_item	3563787	et	4	main
poliitikat	doc_399014257172_item	3563788	et	3	main
pärast	doc_399014257172_item	3563789	et	4	main
oma	doc_399014257172_item	3563803	et	4	main
kui	doc_399014257172_item	3563805	et	3	main
pärast	doc_399014257172_item	3563817	et	4	main
kitarri	doc_399014257172_item	3563821	et	4	main
võib-olla	doc_399014257172_item	3563822	et	3	main
mangin	doc_399014257172_item	3563824	et	4	main
kolm	doc_399014257172_item	3563826	et	3	main
essee	doc_399014257173_item	3563875	et	4	main
nagy	doc_399014257173_item	3563877	et	4	main
imre	doc_399014257173_item	3563878	et	4	main
tema	doc_399014257173_item	3563885	et	4	main
noorema	doc_399014257173_item	3563889	et	4	main
sai	doc_399014257173_item	3563910	et	4	main
ungari	doc_399014257173_item	3563917	et	4	main
stalin	doc_399014257173_item	3563922	et	4	main
kommunistud	doc_399014257173_item	3563925	et	4	main
1939	doc_399014257173_item	3563929	et	2	main
siiski	doc_399014257173_item	3563930	et	4	main
ungari	doc_399014257173_item	3563974	et	4	main
revolutsioon	doc_399014257173_item	3563976	et	3	main
surmanuhtuse	doc_399014257173_item	3564002	et	4	main
ta	doc_399014257173_item	3564003	et	4	main
junnil	doc_399014257173_item	3564008	et	3	main
üks	doc_399014257173_item	3564009	et	3	main
nädal	doc_399014257173_item	3564010	et	3	main
osata	doc_399014257170_item	3563602	et	4	main
räägijad	doc_399014257170_item	3563611	et	4	main
loobuvad	doc_399014257170_item	3563612	et	4	main
suurema	doc_399014257170_item	3563616	et	4	main
keele	doc_399014257170_item	3563617	et	4	main
kasu	doc_399014257170_item	3563621	et	4	main
see	doc_399014257170_item	3563625	et	3	main
tundub	doc_399014257170_item	3563626	et	3	main
on	doc_399014257170_item	3563631	et	4	main
väga	doc_399014257170_item	3563632	et	3	main
palju	doc_399014257170_item	3563633	et	4	main
näiteid	doc_399014257170_item	3563634	et	3	main
sellest	doc_399014257170_item	3563635	et	4	main
keelte	doc_399014257170_item	3563636	et	3	main
natuke	doc_399014257170_item	3563641	et	4	main
meedias	doc_399014257170_item	3563653	et	4	main
ja	doc_399014257170_item	3563654	et	3	main
sellel	doc_399014257170_item	3563655	et	4	main
kirjutataks	doc_399014257170_item	3563656	et	3	main
aja-	doc_399014257170_item	3563657	et	4	main
võimalik	doc_399014257170_item	3563664	et	3	main
seisukorra	doc_399014257170_item	3563667	et	3	main
seisukorda	doc_399014257170_item	3563674	et	4	main
kell	doc_399014257172_item	3563700	et	3	main
all	doc_399014257172_item	3563705	et	3	main
ülikooli	doc_399014257172_item	3563711	et	4	main
kell	doc_399014257172_item	3563713	et	3	main
kümme	doc_399014257172_item	3563715	et	3	main
keelt	doc_399014257172_item	3563726	et	4	main
loeng	doc_399014257172_item	3563732	et	3	main
koju	doc_399014257172_item	3563748	et	3	main
söön	doc_399014257172_item	3563750	et	3	main
mul	doc_399014257172_item	3563765	et	3	main
teine	doc_399014257172_item	3563767	et	3	main
on	doc_399014257172_item	3563770	et	4	main
vene	doc_399014257172_item	3563771	et	4	main
keelt	doc_399014257172_item	3563772	et	4	main
loeng	doc_399014257172_item	3563773	et	3	main
hakkab	doc_399014257172_item	3563774	et	3	main
kell	doc_399014257172_item	3563775	et	3	main
see	doc_399014257172_item	3563786	et	3	main
hakataks	doc_399014257170_item	3563649	et	4	main
õpetama	doc_399014257170_item	3563650	et	3	main
koolides	doc_399014257170_item	3563651	et	3	main
kasutama	doc_399014257170_item	3563652	et	3	main
ilukirjandust	doc_399014257170_item	3563659	et	3	main
essee	doc_399014257172_item	3563689	et	4	main
ärkan	doc_399014257172_item	3563694	et	3	main
pool	doc_399014257172_item	3563701	et	4	main
duši	doc_399014257172_item	3563704	et	2	main
üheksa	doc_399014257172_item	3563708	et	4	main
2	doc_399014257172_item	3563720	et	2	main
loengut	doc_399014257172_item	3563722	et	3	main
ma	doc_399014257172_item	3563757	et	3	main
ajalehte	doc_399014257172_item	3563759	et	4	main
siis	doc_399014257172_item	3563760	et	3	main
hakkab	doc_399014257172_item	3563783	et	3	main
ikka	doc_399014257172_item	3563813	et	4	main
ma	doc_399014257172_item	3563814	et	3	main
söön	doc_399014257172_item	3563815	et	3	main
mangin	doc_399014257172_item	3563820	et	4	main
ma	doc_399014257172_item	3563823	et	3	main
kitarri	doc_399014257172_item	3563825	et	4	main
tundi	doc_399014257172_item	3563827	et	4	main
päeval	doc_399014257172_item	3563828	et	3	main
ma	doc_399014257172_item	3563829	et	3	main
lapsevenamad	doc_399014257173_item	3563886	et	4	main
luppsekk	doc_399014257173_item	3563893	et	4	main
aga	doc_399014257173_item	3563894	et	3	main
kui	doc_399014257173_item	3563895	et	3	main
tal	doc_399014257173_item	3563896	et	3	main
on	doc_399014257173_item	3563897	et	4	main
18	doc_399014257173_item	3563898	et	2	main
aastat	doc_399014257173_item	3563899	et	3	main
pärast	doc_399014257173_item	3563905	et	4	main
vangistanud	doc_399014257173_item	3563908	et	4	main
venemaa	doc_399014257173_item	3563914	et	4	main
ja	doc_399014257173_item	3563915	et	3	main
bela	doc_399014257173_item	3563920	et	4	main
kunni	doc_399014257173_item	3563921	et	4	main
mõrvanud	doc_399014257173_item	3563933	et	4	main
ungaris	doc_399014257173_item	3563963	et	4	main
sest	doc_399014257173_item	3563964	et	4	main
nõukogude	doc_399014257173_item	3563965	et	3	main
tundsib	doc_399014257173_item	3564021	et	4	main
oma	doc_399014257173_item	3564024	et	4	main
haud	doc_399014257173_item	3564025	et	4	main
nagy	doc_399014257173_item	3564030	et	4	main
teenindasib	doc_399014257173_item	3564039	et	4	main
matus	doc_399014257173_item	3564041	et	3	main
essee	doc_399014257174_item	3564043	et	4	main
järjekindlusetu	doc_399014257174_item	3564050	et	4	main
vihma	doc_399014257174_item	3564053	et	4	main
aga	doc_399014257174_item	3564060	et	3	main
vahel	doc_399014257174_item	3564061	et	4	main
päike	doc_399014257174_item	3564062	et	3	main
on	doc_399014257174_item	3564065	et	4	main
kraadi	doc_399014257174_item	3564068	et	4	main
isa	doc_399014257174_item	3564080	et	4	main
kreekasse	doc_399014257174_item	3564082	et	4	main
meelest	doc_399014257174_item	3564086	et	4	main
on	doc_399014257174_item	3564087	et	4	main
meeldib	doc_399014257174_item	3564093	et	3	main
ilm	doc_399014257174_item	3564098	et	3	main
mängidakse	doc_399014257174_item	3564103	et	4	main
jalgpalli	doc_399014257174_item	3564112	et	4	main
vaadata	doc_399014257174_item	3564126	et	4	main
vaadata	doc_399014257174_item	3564132	et	4	main
telekasid	doc_399014257174_item	3564133	et	3	main
suvel	doc_399014257174_item	3564144	et	3	main
mulle	doc_399014257174_item	3564155	et	4	main
meeldib	doc_399014257174_item	3564156	et	3	main
suvel	doc_399014257174_item	3564158	et	3	main
ilusad	doc_399014257174_item	3564161	et	3	main
sõitma	doc_399014257174_item	3564170	et	3	main
rongiga	doc_399014257174_item	3564171	et	4	main
bussiga	doc_399014257174_item	3564173	et	3	main
või	doc_399014257174_item	3564179	et	4	main
metroga	doc_399014257176_item	3564226	et	4	main
sauchiehall	doc_399014257176_item	3564235	et	4	main
tänavas	doc_399014257176_item	3564236	et	4	main
tavaliselt	doc_399014257176_item	3564242	et	4	main
ma	doc_399014257176_item	3564243	et	3	main
mulle	doc_399014257172_item	3563850	et	4	main
meeldib	doc_399014257172_item	3563851	et	3	main
minna	doc_399014257172_item	3563852	et	3	main
kino	doc_399014257172_item	3563853	et	4	main
sõbraga	doc_399014257172_item	3563854	et	3	main
sest	doc_399014257172_item	3563855	et	4	main
mulle	doc_399014257172_item	3563856	et	4	main
meeldib	doc_399014257172_item	3563857	et	3	main
vaadata	doc_399014257172_item	3563858	et	4	main
filme	doc_399014257172_item	3563859	et	3	main
peamiselt	doc_399014257172_item	3563860	et	4	main
ma	doc_399014257172_item	3563861	et	3	main
lähen	doc_399014257172_item	3563862	et	3	main
magama	doc_399014257172_item	3563863	et	3	main
ümbes	doc_399014257172_item	3563864	et	4	main
kell	doc_399014257172_item	3563865	et	3	main
vara	doc_399014257172_item	3563866	et	4	main
sest	doc_399014257172_item	3563867	et	4	main
õhtul	doc_399014257172_item	3563868	et	3	main
mulle	doc_399014257172_item	3563869	et	4	main
meeldib	doc_399014257172_item	3563870	et	3	main
vaadata	doc_399014257172_item	3563871	et	4	main
filme	doc_399014257172_item	3563872	et	3	main
kui	doc_399014257172_item	3563873	et	3	main
päev	doc_399014257172_item	3563691	et	3	main
ma	doc_399014257172_item	3563693	et	3	main
hommikusöök	doc_399014257172_item	3563699	et	3	main
kell	doc_399014257172_item	3563707	et	3	main
ja	doc_399014257172_item	3563709	et	3	main
igal	doc_399014257172_item	3563716	et	3	main
paeval	doc_399014257172_item	3563717	et	4	main
mul	doc_399014257172_item	3563718	et	3	main
on	doc_399014257172_item	3563719	et	4	main
nad	doc_399014257172_item	3563723	et	3	main
vene	doc_399014257172_item	3563727	et	4	main
ja	doc_399014257172_item	3563729	et	3	main
esimene	doc_399014257172_item	3563731	et	3	main
pärast	doc_399014257172_item	3563744	et	4	main
loeng	doc_399014257172_item	3563745	et	3	main
ma	doc_399014257172_item	3563746	et	3	main
tulen	doc_399014257172_item	3563747	et	3	main
keskpäevaeina	doc_399014257172_item	3563751	et	4	main
ma	doc_399014257172_item	3563752	et	3	main
söön	doc_399014257172_item	3563753	et	3	main
võileiba	doc_399014257172_item	3563754	et	4	main
juustuga	doc_399014257172_item	3563755	et	3	main
ja	doc_399014257172_item	3563756	et	3	main
neliteist	doc_399014257172_item	3563776	et	4	main
ja	doc_399014257172_item	3563777	et	3	main
loeng	doc_399014257172_item	3563790	et	3	main
ma	doc_399014257172_item	3563791	et	3	main
küpsetan	doc_399014257172_item	3563802	et	3	main
ma	doc_399014257172_item	3563809	et	3	main
vaatan	doc_399014257172_item	3563810	et	3	main
telekasi	doc_399014257172_item	3563811	et	4	main
nagu	doc_399014257172_item	3563812	et	3	main
raamatukogusse	doc_399014257172_item	3563793	et	3	main
ma	doc_399014257172_item	3563795	et	3	main
tulen	doc_399014257172_item	3563796	et	3	main
kell	doc_399014257172_item	3563798	et	3	main
seitseteist	doc_399014257172_item	3563799	et	4	main
ja	doc_399014257172_item	3563800	et	3	main
ma	doc_399014257172_item	3563801	et	3	main
lõunasööki	doc_399014257172_item	3563804	et	4	main
ma	doc_399014257172_item	3563806	et	3	main
söön	doc_399014257172_item	3563807	et	3	main
lõunasööki	doc_399014257172_item	3563808	et	4	main
lõuna	doc_399014257172_item	3563818	et	4	main
ma	doc_399014257172_item	3563819	et	3	main
võin	doc_399014257172_item	3563830	et	3	main
õppida	doc_399014257172_item	3563831	et	3	main
sest	doc_399014257172_item	3563832	et	4	main
ma	doc_399014257172_item	3563833	et	3	main
olen	doc_399014257172_item	3563834	et	3	main
üliõpilane	doc_399014257172_item	3563835	et	3	main
ja	doc_399014257172_item	3563836	et	3	main
ma	doc_399014257172_item	3563837	et	3	main
õpin	doc_399014257172_item	3563838	et	3	main
eesti	doc_399014257172_item	3563839	et	4	main
keelt	doc_399014257172_item	3563840	et	4	main
ja	doc_399014257172_item	3563841	et	3	main
vene	doc_399014257172_item	3563842	et	4	main
keelt	doc_399014257172_item	3563843	et	4	main
sellepärast	doc_399014257172_item	3563844	et	3	main
mul	doc_399014257172_item	3563845	et	3	main
pole	doc_399014257172_item	3563846	et	3	main
vaba	doc_399014257172_item	3563847	et	4	main
aega	doc_399014257172_item	3563848	et	4	main
laupäeval	doc_399014257172_item	3563849	et	3	main
nagy	doc_399014257173_item	3563879	et	4	main
7	doc_399014257173_item	3563881	et	2	main
nagy	doc_399014257173_item	3563890	et	4	main
värbasib	doc_399014257173_item	3563901	et	4	main
sõjavägis	doc_399014257173_item	3563902	et	4	main
ta	doc_399014257173_item	3563906	et	4	main
töötamiseks	doc_399014257173_item	3563918	et	4	main
mõrvas	doc_399014257173_item	3563923	et	4	main
liidu	doc_399014257173_item	3563972	et	3	main
ta	doc_399014257173_item	3564000	et	4	main
saib	doc_399014257173_item	3564001	et	4	main
kõtkumamisega	doc_399014257173_item	3564006	et	4	main
16	doc_399014257173_item	3564007	et	2	main
oma	doc_399014257173_item	3564011	et	4	main
inimeseid	doc_399014257173_item	3564020	et	4	main
kus	doc_399014257173_item	3564022	et	3	main
ida-europaad	doc_399014257173_item	3564028	et	4	main
imre	doc_399014257173_item	3563876	et	4	main
olid	doc_399014257173_item	3563887	et	4	main
saamiseks	doc_399014257173_item	3563892	et	4	main
ta	doc_399014257173_item	3563900	et	4	main
liige	doc_399014257173_item	3563911	et	4	main
kommunistliku	doc_399014257173_item	3563912	et	3	main
partei	doc_399014257173_item	3563913	et	4	main
valitsusid	doc_399014257173_item	3563919	et	4	main
omal	doc_399014257173_item	3563926	et	3	main
puhastusil	doc_399014257173_item	3563927	et	4	main
ja	doc_399014257173_item	3563934	et	3	main
pärast	doc_399014257173_item	3563935	et	4	main
sõja	doc_399014257173_item	3563936	et	3	main
tagastasib	doc_399014257173_item	3563937	et	4	main
ungari	doc_399014257173_item	3563938	et	4	main
töötamiseks	doc_399014257173_item	3563939	et	4	main
uus	doc_399014257173_item	3563940	et	3	main
kommunistikis	doc_399014257173_item	3563941	et	4	main
valitsusil	doc_399014257173_item	3563942	et	4	main
ungaris	doc_399014257173_item	3563943	et	4	main
nagy	doc_399014257173_item	3563944	et	4	main
saib	doc_399014257173_item	3563945	et	4	main
peaminister	doc_399014257173_item	3563946	et	3	main
ungaris	doc_399014257173_item	3563947	et	4	main
ja	doc_399014257173_item	3563948	et	3	main
algasib	doc_399014257173_item	3563949	et	4	main
uuendata	doc_399014257173_item	3563950	et	3	main
valitsus	doc_399014257173_item	3563951	et	4	main
nagy	doc_399014257173_item	3563952	et	4	main
langesib	doc_399014257173_item	3563953	et	4	main
välja	doc_399014257173_item	3563954	et	4	main
khružčevaga	doc_399014257173_item	3563955	et	2	main
liider	doc_399014257173_item	3563956	et	3	main
nõukogude	doc_399014257173_item	3563957	et	3	main
liidu	doc_399014257173_item	3563958	et	3	main
nagy	doc_399014257173_item	3563959	et	4	main
tahtsib	doc_399014257173_item	3563960	et	4	main
lõppeda	doc_399014257173_item	3563961	et	3	main
kommunism	doc_399014257173_item	3563962	et	3	main
liidu	doc_399014257173_item	3563966	et	3	main
pole	doc_399014257173_item	3563967	et	3	main
lubanud	doc_399014257173_item	3563968	et	4	main
4	doc_399014257173_item	3563969	et	2	main
novembril	doc_399014257173_item	3563970	et	3	main
nõukogude	doc_399014257173_item	3563971	et	3	main
lõppemiseks	doc_399014257173_item	3563975	et	4	main
ja	doc_399014257173_item	3563977	et	3	main
on	doc_399014257173_item	3563996	et	4	main
riigireetmisega	doc_399014257173_item	3563998	et	3	main
ja	doc_399014257173_item	3563999	et	3	main
on	doc_399014257173_item	3564004	et	4	main
pärast	doc_399014257173_item	3564026	et	4	main
revalutsioonid	doc_399014257173_item	3564027	et	4	main
on	doc_399014257174_item	3564049	et	4	main
kraadi	doc_399014257174_item	3564058	et	4	main
soja	doc_399014257174_item	3564059	et	4	main
paistab	doc_399014257174_item	3564063	et	3	main
ja	doc_399014257174_item	3564064	et	3	main
maadesse	doc_399014257174_item	3564076	et	4	main
minu	doc_399014257174_item	3564077	et	3	main
ema	doc_399014257174_item	3564078	et	4	main
ja	doc_399014257174_item	3564079	et	3	main
liiga	doc_399014257174_item	3564088	et	4	main
mulle	doc_399014257174_item	3564092	et	4	main
kui	doc_399014257174_item	3564097	et	3	main
palju	doc_399014257174_item	3564107	et	4	main
šotimaal	doc_399014257174_item	3564109	et	2	main
mängidakse	doc_399014257174_item	3564110	et	4	main
ka	doc_399014257174_item	3564111	et	3	main
kui	doc_399014257174_item	3564117	et	3	main
ilm	doc_399014257174_item	3564118	et	3	main
on	doc_399014257174_item	3564119	et	4	main
halb	doc_399014257174_item	3564120	et	3	main
viibidakse	doc_399014257174_item	3564123	et	4	main
kodus	doc_399014257174_item	3564124	et	4	main
ja	doc_399014257174_item	3564125	et	3	main
palju	doc_399014257174_item	3564130	et	4	main
sporti	doc_399014257174_item	3564131	et	4	main
eile	doc_399014257174_item	3564135	et	3	main
pälju	doc_399014257173_item	3563978	et	4	main
inimeseid	doc_399014257173_item	3563979	et	4	main
on	doc_399014257173_item	3563980	et	4	main
tapenud	doc_399014257173_item	3563981	et	4	main
nagy	doc_399014257173_item	3563982	et	4	main
püüdusib	doc_399014257173_item	3563983	et	4	main
pageda	doc_399014257173_item	3563984	et	3	main
ungarist	doc_399014257173_item	3563985	et	4	main
aga	doc_399014257173_item	3563986	et	3	main
ta	doc_399014257173_item	3563987	et	4	main
on	doc_399014257173_item	3563988	et	4	main
arreteerinud	doc_399014257173_item	3563989	et	4	main
juba	doc_399014257173_item	3563990	et	3	main
enne	doc_399014257173_item	3563991	et	4	main
tal	doc_399014257173_item	3563992	et	3	main
oli	doc_399014257173_item	3563993	et	3	main
voimalus	doc_399014257173_item	3563994	et	4	main
ta	doc_399014257173_item	3563995	et	4	main
süüdistanud	doc_399014257173_item	3563997	et	4	main
esitanud	doc_399014257173_item	3564005	et	4	main
tema	doc_399014257173_item	3564014	et	4	main
matus	doc_399014257173_item	3564015	et	3	main
oli	doc_399014257173_item	3564016	et	3	main
salajane	doc_399014257173_item	3564017	et	3	main
ja	doc_399014257173_item	3564018	et	3	main
mõned	doc_399014257173_item	3564019	et	3	main
oli	doc_399014257173_item	3564023	et	3	main
imre	doc_399014257173_item	3564029	et	4	main
ungarlased	doc_399014257173_item	3564038	et	3	main
šotimaal	doc_399014257174_item	3564045	et	2	main
šotimaal	doc_399014257174_item	3564047	et	2	main
vahel	doc_399014257174_item	3564051	et	4	main
ja	doc_399014257174_item	3564054	et	3	main
ümbes	doc_399014257174_item	3564056	et	4	main
15	doc_399014257174_item	3564057	et	2	main
25	doc_399014257174_item	3564067	et	2	main
šotimaal	doc_399014257174_item	3564095	et	2	main
suvel	doc_399014257174_item	3564096	et	3	main
šotimaal	doc_399014257174_item	3564101	et	2	main
golfi	doc_399014257174_item	3564104	et	4	main
või	doc_399014257174_item	3564113	et	4	main
jalgsi	doc_399014257174_item	3564114	et	3	main
minna	doc_399014257174_item	3564115	et	3	main
šotimaal	doc_399014257174_item	3564121	et	2	main
on	doc_399014257174_item	3564129	et	4	main
näiteks	doc_399014257174_item	3564134	et	4	main
minnakse	doc_399014257174_item	3564146	et	3	main
sõbraga	doc_399014257174_item	3564148	et	3	main
päeval	doc_399014257174_item	3564159	et	3	main
kohtusse	doc_399014257174_item	3564162	et	4	main
maal	doc_399014257174_item	3564163	et	4	main
mul	doc_399014257174_item	3564164	et	3	main
pean	doc_399014257174_item	3564169	et	4	main
nad	doc_399014257174_item	3564187	et	3	main
töötavad	doc_399014257174_item	3564188	et	4	main
essee	doc_399014257176_item	3564216	et	4	main
millal	doc_399014257176_item	3564218	et	3	main
uued	doc_399014257176_item	3564222	et	3	main
glasgow	doc_399014257176_item	3564227	et	4	main
tänavas	doc_399014257176_item	3564241	et	4	main
teksad	doc_399014257176_item	3564245	et	4	main
ja	doc_399014257176_item	3564247	et	3	main
seljas	doc_399014257176_item	3564249	et	4	main
seal	doc_399014257176_item	3564261	et	4	main
mulle	doc_399014257176_item	3564266	et	4	main
meeldib	doc_399014257176_item	3564267	et	3	main
sinised	doc_399014257176_item	3564268	et	4	main
ostma	doc_399014257176_item	3564304	et	3	main
ma	doc_399014257176_item	3564307	et	3	main
muus	doc_399014257176_item	3564309	et	4	main
mulle	doc_399014257176_item	3564311	et	4	main
meeldib	doc_399014257176_item	3564312	et	3	main
kuulama	doc_399014257176_item	3564313	et	3	main
mul	doc_399014257176_item	3564362	et	3	main
paari	doc_399014257176_item	3564367	et	4	main
paari	doc_399014257176_item	3564370	et	4	main
rohkem	doc_399014257176_item	3564376	et	4	main
kakskümend	doc_399014257176_item	3564380	et	4	main
t-sarkid	doc_399014257176_item	3564382	et	4	main
sünnipäeva	doc_399014257173_item	3564012	et	4	main
pärast	doc_399014257173_item	3564013	et	4	main
saib	doc_399014257173_item	3564031	et	4	main
teine	doc_399014257173_item	3564032	et	3	main
matus	doc_399014257173_item	3564033	et	3	main
ja	doc_399014257173_item	3564034	et	3	main
ümbes	doc_399014257173_item	3564035	et	4	main
100	doc_399014257173_item	3564036	et	2	main
000	doc_399014257173_item	3564037	et	2	main
oma	doc_399014257173_item	3564040	et	4	main
suvel	doc_399014257174_item	3564046	et	3	main
kaugetesse	doc_399014257174_item	3564075	et	4	main
soja	doc_399014257174_item	3564089	et	4	main
viibida	doc_399014257174_item	3564094	et	3	main
on	doc_399014257174_item	3564099	et	4	main
suvel	doc_399014257174_item	3564122	et	3	main
aastal	doc_399014257174_item	3564136	et	3	main
šotimaal	doc_399014257174_item	3564143	et	2	main
ja	doc_399014257174_item	3564151	et	3	main
jüüakse	doc_399014257174_item	3564152	et	4	main
õlut	doc_399014257174_item	3564153	et	3	main
see	doc_399014257174_item	3564154	et	3	main
nii	doc_399014257174_item	3564167	et	3	main
ma	doc_399014257174_item	3564175	et	3	main
tahan	doc_399014257174_item	3564176	et	3	main
ei	doc_399014257174_item	3564184	et	4	main
ei	doc_399014257174_item	3564206	et	4	main
tea	doc_399014257174_item	3564207	et	4	main
kus	doc_399014257174_item	3564208	et	3	main
töödadakse	doc_399014257174_item	3564209	et	4	main
glasgows	doc_399014257174_item	3564210	et	4	main
võib-olla	doc_399014257174_item	3564211	et	3	main
töödadakse	doc_399014257174_item	3564212	et	4	main
poodis	doc_399014257174_item	3564213	et	4	main
kesklinas	doc_399014257174_item	3564214	et	4	main
suvel	doc_399014257174_item	3564044	et	3	main
ilm	doc_399014257174_item	3564048	et	3	main
sajab	doc_399014257174_item	3564052	et	3	main
on	doc_399014257174_item	3564055	et	4	main
ümbes	doc_399014257174_item	3564066	et	4	main
soja	doc_399014257174_item	3564069	et	4	main
kui	doc_399014257174_item	3564070	et	3	main
ilm	doc_399014257174_item	3564071	et	3	main
on	doc_399014257174_item	3564072	et	4	main
halb	doc_399014257174_item	3564073	et	3	main
sõidetakse	doc_399014257174_item	3564074	et	3	main
sõidavad	doc_399014257174_item	3564081	et	3	main
igal	doc_399014257174_item	3564083	et	3	main
aastal	doc_399014257174_item	3564084	et	3	main
minu	doc_399014257174_item	3564085	et	3	main
kreekasse	doc_399014257174_item	3564090	et	4	main
nii	doc_399014257174_item	3564091	et	3	main
ilus	doc_399014257174_item	3564100	et	4	main
suvel	doc_399014257174_item	3564102	et	3	main
sest	doc_399014257174_item	3564105	et	4	main
on	doc_399014257174_item	3564106	et	4	main
golfiväljak	doc_399014257174_item	3564108	et	3	main
maale	doc_399014257174_item	3564116	et	4	main
telekas	doc_399014257174_item	3564127	et	4	main
suvel	doc_399014257174_item	3564128	et	3	main
oli	doc_399014257174_item	3564137	et	3	main
jalgpall	doc_399014257174_item	3564138	et	3	main
suvel	doc_399014257174_item	3564139	et	3	main
ja	doc_399014257174_item	3564140	et	3	main
ka	doc_399014257174_item	3564141	et	3	main
tennis	doc_399014257174_item	3564142	et	3	main
pubisse	doc_399014257174_item	3564147	et	4	main
šotimaal	doc_399014257174_item	3564157	et	2	main
sõidetakse	doc_399014257174_item	3564160	et	3	main
ma	doc_399014257174_item	3564168	et	3	main
või	doc_399014257174_item	3564172	et	4	main
kui	doc_399014257174_item	3564174	et	3	main
minna	doc_399014257174_item	3564177	et	3	main
maale	doc_399014257174_item	3564178	et	4	main
õpi	doc_399014257174_item	3564185	et	4	main
pean	doc_399014257176_item	3564220	et	4	main
ostma	doc_399014257176_item	3564221	et	3	main
sõidan	doc_399014257176_item	3564225	et	3	main
seal	doc_399014257176_item	3564229	et	4	main
paljud	doc_399014257176_item	3564231	et	3	main
poodid	doc_399014257176_item	3564232	et	4	main
poodid	doc_399014257176_item	3564233	et	4	main
ma	doc_399014257176_item	3564251	et	3	main
vajan	doc_399014257176_item	3564252	et	3	main
uued	doc_399014257176_item	3564254	et	3	main
ma	doc_399014257176_item	3564256	et	3	main
ei	doc_399014257176_item	3564298	et	4	main
uued	doc_399014257176_item	3564305	et	3	main
lähen	doc_399014257176_item	3564308	et	3	main
poodi	doc_399014257176_item	3564310	et	4	main
markid	doc_399014257176_item	3564352	et	4	main
nike	doc_399014257176_item	3564353	et	4	main
paarid	doc_399014257176_item	3564360	et	4	main
paari	doc_399014257176_item	3564365	et	4	main
siiski	doc_399014257176_item	3564371	et	4	main
tõenäoliselt	doc_399014257176_item	3564379	et	4	main
mul	doc_399014257177_item	3564400	et	3	main
mul	doc_399014257177_item	3564405	et	3	main
ma	doc_399014257177_item	3564413	et	3	main
lugeda	doc_399014257177_item	3564415	et	3	main
poliitilisi	doc_399014257177_item	3564424	et	3	main
raamatuid	doc_399014257177_item	3564425	et	3	main
hiljuti	doc_399014257177_item	3564426	et	4	main
ma	doc_399014257177_item	3564427	et	3	main
lugesin	doc_399014257177_item	3564428	et	3	main
ida-virumaal	doc_399014257177_item	3564431	et	4	main
raamatuid	doc_399014257177_item	3564435	et	3	main
pean	doc_399014257177_item	3564438	et	4	main
mulle	doc_399014257177_item	3564454	et	4	main
kirjutasi	doc_399014257177_item	3564460	et	4	main
sõda	doc_399014257177_item	3564464	et	4	main
õhtul	doc_399014257174_item	3564145	et	3	main
istudakse	doc_399014257174_item	3564149	et	4	main
õlu-aedis	doc_399014257174_item	3564150	et	4	main
pole	doc_399014257174_item	3564165	et	3	main
auto	doc_399014257174_item	3564166	et	4	main
linna	doc_399014257174_item	3564180	et	4	main
šotimaal	doc_399014257174_item	3564181	et	2	main
suvel	doc_399014257174_item	3564182	et	3	main
üliõpilased	doc_399014257174_item	3564183	et	3	main
ülikoolis	doc_399014257174_item	3564186	et	4	main
poodis	doc_399014257174_item	3564189	et	4	main
linas	doc_399014257174_item	3564190	et	4	main
või	doc_399014257174_item	3564191	et	4	main
nad	doc_399014257174_item	3564192	et	3	main
sõidavad	doc_399014257174_item	3564193	et	3	main
kaugetesse	doc_399014257174_item	3564194	et	4	main
maadesse	doc_399014257174_item	3564195	et	4	main
selle	doc_399014257174_item	3564196	et	4	main
asemal	doc_399014257174_item	3564197	et	4	main
see	doc_399014257174_item	3564198	et	3	main
aastal	doc_399014257174_item	3564199	et	3	main
ma	doc_399014257174_item	3564200	et	3	main
tahan	doc_399014257174_item	3564201	et	3	main
töödata	doc_399014257174_item	3564202	et	4	main
aga	doc_399014257174_item	3564204	et	3	main
ma	doc_399014257174_item	3564205	et	3	main
glasgows	doc_399014257174_item	3564203	et	4	main
sisseostude	doc_399014257176_item	3564217	et	3	main
glasgows	doc_399014257176_item	3564228	et	4	main
on	doc_399014257176_item	3564230	et	4	main
buchanan	doc_399014257176_item	3564237	et	4	main
tänavas	doc_399014257176_item	3564238	et	4	main
ja	doc_399014257176_item	3564239	et	3	main
kalun	doc_399014257176_item	3564244	et	4	main
t-sark	doc_399014257176_item	3564248	et	3	main
teksad	doc_399014257176_item	3564255	et	4	main
on	doc_399014257176_item	3564262	et	4	main
pood	doc_399014257176_item	3564263	et	4	main
teksad	doc_399014257176_item	3564271	et	4	main
neid	doc_399014257176_item	3564300	et	4	main
millal	doc_399014257176_item	3564301	et	3	main
ma	doc_399014257176_item	3564302	et	3	main
t-särkid	doc_399014257176_item	3564306	et	4	main
ostan	doc_399014257176_item	3564351	et	3	main
on	doc_399014257176_item	3564358	et	4	main
palju	doc_399014257176_item	3564359	et	4	main
on	doc_399014257176_item	3564363	et	4	main
sinine	doc_399014257176_item	3564366	et	4	main
ja	doc_399014257176_item	3564368	et	3	main
punane	doc_399014257176_item	3564369	et	4	main
t-särkid	doc_399014257176_item	3564374	et	4	main
kõige	doc_399014257176_item	3564375	et	4	main
mul	doc_399014257176_item	3564384	et	3	main
pulloverid	doc_399014257176_item	3564387	et	3	main
ja	doc_399014257176_item	3564388	et	3	main
nii	doc_399014257176_item	3564389	et	3	main
ma	doc_399014257176_item	3564390	et	3	main
pean	doc_399014257176_item	3564391	et	4	main
essee	doc_399014257177_item	3564396	et	4	main
lemmik	doc_399014257177_item	3564398	et	3	main
raamat	doc_399014257177_item	3564403	et	3	main
pole	doc_399014257177_item	3564406	et	3	main
olen	doc_399014257177_item	3564410	et	3	main
või	doc_399014257177_item	3564423	et	4	main
lugesin	doc_399014257177_item	3564433	et	3	main
ma	doc_399014257176_item	3564219	et	3	main
riided	doc_399014257176_item	3564223	et	3	main
ma	doc_399014257176_item	3564224	et	3	main
istuvad	doc_399014257176_item	3564234	et	4	main
argyll	doc_399014257176_item	3564240	et	4	main
kui	doc_399014257176_item	3564250	et	3	main
ostma	doc_399014257176_item	3564253	et	3	main
lähen	doc_399014257176_item	3564257	et	3	main
buchanani	doc_399014257176_item	3564259	et	4	main
tänavas	doc_399014257176_item	3564260	et	4	main
levi	doc_399014257176_item	3564264	et	4	main
kaukemajas	doc_399014257176_item	3564265	et	4	main
ei	doc_399014257176_item	3564272	et	4	main
ole	doc_399014257176_item	3564273	et	4	main
kallised	doc_399014257176_item	3564274	et	4	main
siis	doc_399014257176_item	3564275	et	3	main
ma	doc_399014257176_item	3564276	et	3	main
ostan	doc_399014257176_item	3564277	et	3	main
paari	doc_399014257176_item	3564278	et	4	main
mõnikord	doc_399014257176_item	3564279	et	3	main
teksad	doc_399014257176_item	3564280	et	4	main
maksavad	doc_399014257176_item	3564281	et	3	main
viisteist	doc_399014257176_item	3564282	et	4	main
naelid	doc_399014257176_item	3564283	et	3	main
ma	doc_399014257176_item	3564284	et	3	main
olen	doc_399014257176_item	3564285	et	3	main
üliõpilane	doc_399014257176_item	3564286	et	3	main
nii	doc_399014257176_item	3564287	et	3	main
mul	doc_399014257176_item	3564288	et	3	main
ei	doc_399014257176_item	3564289	et	4	main
ole	doc_399014257176_item	3564290	et	4	main
raha	doc_399014257176_item	3564292	et	4	main
millal	doc_399014257176_item	3564293	et	3	main
palju	doc_399014257176_item	3564291	et	4	main
teksad	doc_399014257176_item	3564294	et	4	main
on	doc_399014257176_item	3564295	et	4	main
kallised	doc_399014257176_item	3564296	et	4	main
ma	doc_399014257176_item	3564297	et	3	main
jalas	doc_399014257176_item	3564246	et	4	main
kaukemajasse	doc_399014257176_item	3564258	et	4	main
teksad	doc_399014257176_item	3564269	et	4	main
kui	doc_399014257176_item	3564270	et	3	main
osta	doc_399014257176_item	3564299	et	4	main
muusika	doc_399014257176_item	3564314	et	4	main
ja	doc_399014257176_item	3564315	et	3	main
nii	doc_399014257176_item	3564316	et	3	main
ostma	doc_399014257176_item	3564317	et	3	main
t-sätkid	doc_399014257176_item	3564318	et	4	main
muus	doc_399014257176_item	3564319	et	4	main
ansembli	doc_399014257176_item	3564320	et	4	main
ma	doc_399014257176_item	3564321	et	3	main
eelistan	doc_399014257176_item	3564322	et	3	main
ostan	doc_399014257176_item	3564323	et	3	main
internetaga	doc_399014257176_item	3564325	et	4	main
sellepärast	doc_399014257176_item	3564326	et	3	main
t-särkid	doc_399014257176_item	3564324	et	4	main
et	doc_399014257176_item	3564327	et	3	main
nad	doc_399014257176_item	3564328	et	3	main
on	doc_399014257176_item	3564329	et	4	main
odavamad	doc_399014257176_item	3564330	et	4	main
hiljuti	doc_399014257176_item	3564331	et	4	main
ma	doc_399014257176_item	3564332	et	3	main
ostin	doc_399014257176_item	3564333	et	4	main
paljud	doc_399014257176_item	3564334	et	3	main
t-särkid	doc_399014257176_item	3564335	et	4	main
ja	doc_399014257176_item	3564336	et	3	main
uued	doc_399014257176_item	3564337	et	3	main
kingad	doc_399014257176_item	3564338	et	3	main
alati	doc_399014257176_item	3564339	et	4	main
ma	doc_399014257176_item	3564340	et	3	main
kolun	doc_399014257176_item	3564341	et	4	main
spordid	doc_399014257176_item	3564342	et	4	main
kingad	doc_399014257176_item	3564343	et	3	main
nad	doc_399014257176_item	3564344	et	3	main
on	doc_399014257176_item	3564345	et	4	main
mugavusamad	doc_399014257176_item	3564346	et	4	main
kui	doc_399014257176_item	3564347	et	3	main
tavalised	doc_399014257176_item	3564348	et	4	main
ma	doc_399014257176_item	3564350	et	3	main
lingad	doc_399014257176_item	3564349	et	4	main
pean	doc_399014257176_item	3564303	et	4	main
puma	doc_399014257176_item	3564354	et	4	main
ja	doc_399014257176_item	3564355	et	3	main
convese	doc_399014257176_item	3564356	et	4	main
mul	doc_399014257176_item	3564357	et	3	main
convese	doc_399014257176_item	3564361	et	4	main
mul	doc_399014257176_item	3564372	et	3	main
mul	doc_399014257176_item	3564377	et	3	main
kolmkümend	doc_399014257176_item	3564381	et	4	main
praegu	doc_399014257176_item	3564383	et	3	main
minu	doc_399014257177_item	3564397	et	3	main
raamat	doc_399014257177_item	3564399	et	3	main
sest	doc_399014257177_item	3564404	et	4	main
vaba	doc_399014257177_item	3564407	et	4	main
aega	doc_399014257177_item	3564408	et	4	main
ma	doc_399014257177_item	3564409	et	3	main
iga	doc_399014257177_item	3564416	et	4	main
ajalagaraamatudid	doc_399014257177_item	3564422	et	4	main
ma	doc_399014257177_item	3564432	et	3	main
sest	doc_399014257177_item	3564436	et	4	main
aega	doc_399014257177_item	3564447	et	4	main
ma	doc_399014257177_item	3564448	et	3	main
loeksin	doc_399014257177_item	3564449	et	3	main
raamatuid	doc_399014257177_item	3564450	et	3	main
jõulukinkina	doc_399014257177_item	3564451	et	4	main
oma	doc_399014257177_item	3564452	et	4	main
vanavanemadist	doc_399014257177_item	3564453	et	4	main
boris	doc_399014257177_item	3564461	et	4	main
pasternak	doc_399014257177_item	3564462	et	4	main
ja	doc_399014257177_item	3564463	et	3	main
tolstoi	doc_399014257177_item	3564469	et	4	main
aga	doc_399014257177_item	3564476	et	3	main
noorena	doc_399014257177_item	3564482	et	3	main
olin	doc_399014257177_item	3564493	et	3	main
must	doc_399014257176_item	3564364	et	4	main
on	doc_399014257176_item	3564373	et	4	main
on	doc_399014257176_item	3564378	et	4	main
ei	doc_399014257176_item	3564385	et	4	main
ole	doc_399014257176_item	3564386	et	4	main
ostma	doc_399014257176_item	3564392	et	3	main
rohkem	doc_399014257176_item	3564393	et	4	main
pulloverid	doc_399014257176_item	3564394	et	3	main
lemmik	doc_399014257177_item	3564402	et	3	main
u	doc_399014257177_item	3564412	et	4	main
pean	doc_399014257177_item	3564414	et	4	main
raamatuid	doc_399014257177_item	3564429	et	3	main
need	doc_399014257177_item	3564434	et	3	main
mul	doc_399014257177_item	3564443	et	3	main
raamatuid	doc_399014257177_item	3564457	et	3	main
živago	doc_399014257177_item	3564459	et	2	main
lev	doc_399014257177_item	3564468	et	4	main
suvel	doc_399014257177_item	3564475	et	3	main
on	doc_399014257177_item	3564478	et	4	main
pikke	doc_399014257177_item	3564480	et	4	main
mulle	doc_399014257177_item	3564483	et	4	main
meeldib	doc_399014257177_item	3564484	et	3	main
lugeda	doc_399014257177_item	3564485	et	3	main
u	doc_399014257177_item	3564486	et	4	main
ma	doc_399014257177_item	3564487	et	3	main
lugesin	doc_399014257177_item	3564488	et	3	main
õpilane	doc_399014257177_item	3564494	et	3	main
koolis	doc_399014257177_item	3564495	et	4	main
inglise	doc_399014257177_item	3564498	et	4	main
sai	doc_399014257177_item	3564517	et	4	main
kuulus	doc_399014257177_item	3564518	et	4	main
film	doc_399014257177_item	3564519	et	3	main
kreen	doc_399014257177_item	3564521	et	3	main
krakovil	doc_399014257177_item	3564528	et	4	main
poolas	doc_399014257177_item	3564529	et	4	main
teine	doc_399014257177_item	3564573	et	3	main
sest	doc_399014257177_item	3564587	et	4	main
ta	doc_399014257177_item	3564588	et	4	main
saada	doc_399014257178_item	3564601	et	4	main
taksin	doc_399014257178_item	3564607	et	4	main
palju	doc_399014257178_item	3564609	et	4	main
ase	doc_399014257178_item	3564610	et	3	main
kui	doc_399014257178_item	3564611	et	3	main
ma	doc_399014257178_item	3564612	et	3	main
olin	doc_399014257178_item	3564613	et	3	main
rongi	doc_399014257178_item	3564622	et	4	main
ja	doc_399014257178_item	3564627	et	3	main
mudel-ronge	doc_399014257178_item	3564630	et	3	main
7	doc_399014257178_item	3564637	et	2	main
ma	doc_399014257178_item	3564647	et	3	main
7	doc_399014257178_item	3564650	et	2	main
ma	doc_399014257178_item	3564698	et	3	main
sest	doc_399014257178_item	3564702	et	4	main
saada	doc_399014257178_item	3564723	et	4	main
lendur	doc_399014257178_item	3564724	et	3	main
haiget	doc_399014257178_item	3564746	et	3	main
viibida	doc_399014257178_item	3564750	et	3	main
saada	doc_399014257178_item	3564783	et	4	main
ma	doc_399014257178_item	3564801	et	3	main
õpetaja	doc_399014257178_item	3564803	et	4	main
tagajärg	doc_399014257177_item	3564559	et	3	main
vanemast	doc_399014257177_item	3564560	et	4	main
raamatust	doc_399014257177_item	3564561	et	4	main
mis	doc_399014257177_item	3564562	et	4	main
on	doc_399014257177_item	3564563	et	4	main
hüüd	doc_399014257177_item	3564564	et	3	main
poiss	doc_399014257177_item	3564565	et	3	main
raamatud	doc_399014257177_item	3564566	et	4	main
pole	doc_399014257177_item	3564401	et	3	main
üliõpilane	doc_399014257177_item	3564411	et	3	main
päev	doc_399014257177_item	3564417	et	3	main
tavaliselt	doc_399014257177_item	3564418	et	4	main
ma	doc_399014257177_item	3564419	et	3	main
pean	doc_399014257177_item	3564420	et	4	main
lugeda	doc_399014257177_item	3564421	et	3	main
venelased	doc_399014257177_item	3564430	et	3	main
ma	doc_399014257177_item	3564437	et	3	main
kirjutama	doc_399014257177_item	3564439	et	3	main
eesti	doc_399014257177_item	3564440	et	4	main
oleks	doc_399014257177_item	3564444	et	3	main
oli	doc_399014257177_item	3564455	et	3	main
arst	doc_399014257177_item	3564458	et	3	main
raamatuid	doc_399014257177_item	3564474	et	3	main
nad	doc_399014257177_item	3564477	et	3	main
väga	doc_399014257177_item	3564479	et	3	main
raamatuid	doc_399014257177_item	3564481	et	3	main
kui	doc_399014257177_item	3564491	et	3	main
ma	doc_399014257177_item	3564496	et	3	main
ma	doc_399014257177_item	3564501	et	3	main
pidi	doc_399014257177_item	3564502	et	4	main
palju	doc_399014257177_item	3564504	et	4	main
kirjanduid	doc_399014257177_item	3564505	et	4	main
kirjandi	doc_399014257177_item	3564509	et	3	main
kirjutatud	doc_399014257177_item	3564512	et	4	main
tomas	doc_399014257177_item	3564513	et	4	main
shidler	doc_399014257177_item	3564520	et	4	main
suunatud	doc_399014257177_item	3564522	et	4	main
püüdsa	doc_399014257177_item	3564533	et	4	main
neid	doc_399014257177_item	3564535	et	4	main
ütleb	doc_399014257177_item	3564567	et	3	main
lugu	doc_399014257177_item	3564568	et	4	main
raamatut	doc_399014257177_item	3564574	et	3	main
lugu	doc_399014257177_item	3564578	et	4	main
tapsi	doc_399014257177_item	3564589	et	4	main
mees	doc_399014257177_item	3564590	et	4	main
ta	doc_399014257177_item	3564592	et	4	main
kirjutab	doc_399014257177_item	3564593	et	3	main
luguid	doc_399014257177_item	3564594	et	4	main
lapse	doc_399014257177_item	3564595	et	4	main
taksin	doc_399014257178_item	3564600	et	4	main
kui	doc_399014257178_item	3564602	et	3	main
taksin	doc_399014257178_item	3564619	et	4	main
saada	doc_399014257178_item	3564620	et	4	main
juht	doc_399014257178_item	3564621	et	3	main
ronged	doc_399014257178_item	3564626	et	4	main
ma	doc_399014257178_item	3564633	et	3	main
vana	doc_399014257178_item	3564639	et	4	main
olin	doc_399014257178_item	3564648	et	3	main
vana	doc_399014257178_item	3564652	et	4	main
taksin	doc_399014257178_item	3564654	et	4	main
taksin	doc_399014257178_item	3564658	et	4	main
ei	doc_399014257178_item	3564688	et	4	main
saada	doc_399014257178_item	3564690	et	4	main
kui	doc_399014257178_item	3564692	et	3	main
10	doc_399014257178_item	3564695	et	2	main
kirjad	doc_399014257177_item	3564441	et	4	main
kui	doc_399014257177_item	3564442	et	3	main
rohkem	doc_399014257177_item	3564445	et	4	main
vaba	doc_399014257177_item	3564446	et	4	main
2	doc_399014257177_item	3564456	et	2	main
rahu	doc_399014257177_item	3564466	et	4	main
kirjutatud	doc_399014257177_item	3564467	et	4	main
need	doc_399014257177_item	3564473	et	3	main
palju	doc_399014257177_item	3564489	et	4	main
raamatuid	doc_399014257177_item	3564490	et	3	main
keelt	doc_399014257177_item	3564499	et	4	main
kirjutama	doc_399014257177_item	3564503	et	3	main
spielberg	doc_399014257177_item	3564524	et	4	main
raamat	doc_399014257177_item	3564525	et	3	main
millest	doc_399014257177_item	3564526	et	3	main
juutid	doc_399014257177_item	3564527	et	4	main
mees	doc_399014257177_item	3564531	et	4	main
lugu	doc_399014257177_item	3564540	et	4	main
mulle	doc_399014257177_item	3564542	et	4	main
meeldib	doc_399014257177_item	3564543	et	3	main
on	doc_399014257177_item	3564585	et	4	main
irooniline	doc_399014257177_item	3564586	et	3	main
kelleks	doc_399014257178_item	3564598	et	4	main
noorem	doc_399014257178_item	3564605	et	4	main
4	doc_399014257178_item	3564615	et	2	main
sest	doc_399014257178_item	3564623	et	4	main
ma	doc_399014257178_item	3564624	et	3	main
mul	doc_399014257178_item	3564628	et	3	main
aga	doc_399014257178_item	3564631	et	3	main
6	doc_399014257178_item	3564636	et	2	main
saada	doc_399014257178_item	3564643	et	4	main
hakanud	doc_399014257178_item	3564689	et	4	main
bokser	doc_399014257178_item	3564691	et	3	main
ma	doc_399014257178_item	3564693	et	3	main
olin	doc_399014257178_item	3564694	et	3	main
kui	doc_399014257178_item	3564714	et	3	main
ma	doc_399014257178_item	3564715	et	3	main
olin	doc_399014257178_item	3564716	et	3	main
ka	doc_399014257178_item	3564717	et	3	main
ma	doc_399014257178_item	3564748	et	3	main
kuues	doc_399014257178_item	3564753	et	4	main
kuud	doc_399014257178_item	3564754	et	4	main
ei	doc_399014257178_item	3564759	et	4	main
mängida	doc_399014257178_item	3564761	et	3	main
ragbit	doc_399014257178_item	3564762	et	3	main
minu	doc_399014257178_item	3564768	et	3	main
olin	doc_399014257178_item	3564775	et	3	main
ümbes	doc_399014257178_item	3564776	et	4	main
17	doc_399014257178_item	3564778	et	2	main
aastat	doc_399014257178_item	3564779	et	3	main
vana	doc_399014257178_item	3564780	et	4	main
ma	doc_399014257178_item	3564781	et	3	main
sest	doc_399014257178_item	3564785	et	4	main
kitarri	doc_399014257178_item	3564788	et	4	main
minu	doc_399014257178_item	3564790	et	3	main
head	doc_399014257178_item	3564796	et	4	main
töö	doc_399014257178_item	3564797	et	4	main
ma	doc_399014257178_item	3564799	et	3	main
mõtlen	doc_399014257178_item	3564800	et	3	main
essee	doc_399014257179_item	3564834	et	4	main
linnapea	doc_399014257179_item	3564844	et	4	main
valimines	doc_399014257179_item	3564847	et	4	main
tegeksin	doc_399014257179_item	3564849	et	4	main
tähtisem	doc_399014257179_item	3564859	et	4	main
mehena	doc_399014257179_item	3564860	et	3	main
ümbes	doc_399014257179_item	3564865	et	4	main
kontorid	doc_399014257179_item	3564869	et	3	main
nõukogu	doc_399014257179_item	3564871	et	4	main
on	doc_399014257179_item	3564872	et	4	main
kesklinnas	doc_399014257179_item	3564881	et	4	main
palju	doc_399014257179_item	3564883	et	4	main
ma	doc_399014257179_item	3564885	et	3	main
tean	doc_399014257179_item	3564886	et	3	main
aga	doc_399014257179_item	3564890	et	3	main
oleksid	doc_399014257179_item	3564893	et	4	main
rohkem	doc_399014257179_item	3564894	et	4	main
glasgow	doc_399014257179_item	3564902	et	4	main
ilus	doc_399014257179_item	3564910	et	4	main
šoti	doc_399014257179_item	3564914	et	2	main
ligilähedane	doc_399014257179_item	3564917	et	3	main
glasgow	doc_399014257179_item	3564921	et	4	main
linnapea	doc_399014257179_item	3564922	et	4	main
ja	doc_399014257177_item	3564465	et	3	main
mulle	doc_399014257177_item	3564470	et	4	main
meeldib	doc_399014257177_item	3564471	et	3	main
lugeda	doc_399014257177_item	3564472	et	3	main
ma	doc_399014257177_item	3564492	et	3	main
sellepärast	doc_399014257177_item	3564500	et	3	main
naiteks	doc_399014257177_item	3564506	et	4	main
ma	doc_399014257177_item	3564507	et	3	main
keneeli	doc_399014257177_item	3564514	et	4	main
seda	doc_399014257177_item	3564515	et	3	main
raamat	doc_399014257177_item	3564516	et	3	main
steven	doc_399014257177_item	3564523	et	4	main
ja	doc_399014257177_item	3564530	et	3	main
raamat	doc_399014257177_item	3564537	et	3	main
põhineb	doc_399014257177_item	3564538	et	3	main
tema	doc_399014257177_item	3564569	et	4	main
lapsepõlv	doc_399014257177_item	3564570	et	3	main
ma	doc_399014257177_item	3564571	et	3	main
sest	doc_399014257177_item	3564575	et	4	main
ütleb	doc_399014257177_item	3564577	et	3	main
aga	doc_399014257177_item	3564591	et	3	main
õpisin	doc_399014257177_item	3564497	et	4	main
lugisin	doc_399014257177_item	3564508	et	4	main
shidleri	doc_399014257177_item	3564510	et	4	main
laev	doc_399014257177_item	3564511	et	3	main
mis	doc_399014257177_item	3564532	et	4	main
korda	doc_399014257177_item	3564534	et	4	main
natsest	doc_399014257177_item	3564536	et	3	main
õige	doc_399014257177_item	3564539	et	4	main
noorena	doc_399014257177_item	3564541	et	3	main
ka	doc_399014257177_item	3564544	et	3	main
lugeda	doc_399014257177_item	3564545	et	3	main
raamatuid	doc_399014257177_item	3564546	et	3	main
roal	doc_399014257177_item	3564547	et	4	main
dahli	doc_399014257177_item	3564548	et	4	main
minu	doc_399014257177_item	3564549	et	3	main
lemmikraamat	doc_399014257177_item	3564550	et	3	main
roal	doc_399014257177_item	3564551	et	4	main
dahli	doc_399014257177_item	3564552	et	4	main
on	doc_399014257177_item	3564553	et	4	main
võib-olla	doc_399014257177_item	3564554	et	3	main
lahkumine	doc_399014257177_item	3564555	et	4	main
saab	doc_399014257177_item	3564556	et	3	main
raamat	doc_399014257177_item	3564557	et	3	main
on	doc_399014257177_item	3564558	et	4	main
eelistan	doc_399014257177_item	3564572	et	3	main
ta	doc_399014257177_item	3564576	et	4	main
tema	doc_399014257177_item	3564579	et	4	main
roll	doc_399014257177_item	3564580	et	3	main
sõjas	doc_399014257177_item	3564581	et	3	main
ma	doc_399014257177_item	3564582	et	3	main
mõtlen	doc_399014257177_item	3564583	et	3	main
raamat	doc_399014257177_item	3564584	et	3	main
essee	doc_399014257178_item	3564597	et	4	main
ma	doc_399014257178_item	3564603	et	3	main
ümbes	doc_399014257178_item	3564614	et	4	main
aastat	doc_399014257178_item	3564616	et	3	main
ma	doc_399014257178_item	3564618	et	3	main
oli	doc_399014257178_item	3564629	et	3	main
olin	doc_399014257178_item	3564634	et	3	main
juht	doc_399014257178_item	3564644	et	3	main
rongi	doc_399014257178_item	3564645	et	4	main
kui	doc_399014257178_item	3564646	et	3	main
aastat	doc_399014257178_item	3564651	et	3	main
ma	doc_399014257178_item	3564687	et	3	main
aastat	doc_399014257178_item	3564696	et	3	main
ragbit	doc_399014257178_item	3564701	et	3	main
minu	doc_399014257178_item	3564703	et	3	main
juba	doc_399014257178_item	3564706	et	3	main
ragbit	doc_399014257178_item	3564707	et	3	main
ma	doc_399014257178_item	3564708	et	3	main
taksin	doc_399014257178_item	3564709	et	4	main
mängida	doc_399014257178_item	3564710	et	3	main
ragbit	doc_399014257178_item	3564711	et	3	main
minu	doc_399014257178_item	3564712	et	3	main
jooksul	doc_399014257178_item	3564755	et	4	main
vaadata	doc_399014257178_item	3564767	et	4	main
ikka	doc_399014257178_item	3564772	et	4	main
15	doc_399014257178_item	3564777	et	2	main
mängin	doc_399014257178_item	3564787	et	3	main
ei	doc_399014257178_item	3564795	et	4	main
ma	doc_399014257178_item	3564599	et	3	main
olin	doc_399014257178_item	3564604	et	3	main
ma	doc_399014257178_item	3564606	et	3	main
saada	doc_399014257178_item	3564608	et	4	main
vana	doc_399014257178_item	3564617	et	4	main
huvitasid	doc_399014257178_item	3564625	et	4	main
kui	doc_399014257178_item	3564632	et	3	main
ümbes	doc_399014257178_item	3564635	et	4	main
aastat	doc_399014257178_item	3564638	et	3	main
ma	doc_399014257178_item	3564640	et	3	main
ei	doc_399014257178_item	3564641	et	4	main
taksinud	doc_399014257178_item	3564642	et	4	main
6	doc_399014257178_item	3564649	et	2	main
ma	doc_399014257178_item	3564653	et	3	main
saada	doc_399014257178_item	3564655	et	4	main
bokser	doc_399014257178_item	3564656	et	3	main
ma	doc_399014257178_item	3564657	et	3	main
saada	doc_399014257178_item	3564659	et	4	main
bokser	doc_399014257178_item	3564660	et	3	main
sest	doc_399014257178_item	3564661	et	4	main
ma	doc_399014257178_item	3564662	et	3	main
mängisin	doc_399014257178_item	3564663	et	3	main
arvutimänge	doc_399014257178_item	3564664	et	3	main
bokseriga	doc_399014257178_item	3564665	et	3	main
ja	doc_399014257178_item	3564666	et	3	main
ma	doc_399014257178_item	3564667	et	3	main
vaadasin	doc_399014257178_item	3564668	et	4	main
poksi	doc_399014257178_item	3564669	et	4	main
telekasit	doc_399014257178_item	3564670	et	3	main
siiski	doc_399014257178_item	3564671	et	4	main
ma	doc_399014257178_item	3564672	et	3	main
poksisin	doc_399014257178_item	3564673	et	3	main
sest	doc_399014257178_item	3564674	et	4	main
ma	doc_399014257178_item	3564675	et	3	main
olin	doc_399014257178_item	3564676	et	3	main
liiga	doc_399014257178_item	3564677	et	4	main
noor	doc_399014257178_item	3564678	et	3	main
nii	doc_399014257178_item	3564679	et	3	main
kui	doc_399014257178_item	3564680	et	3	main
ma	doc_399014257178_item	3564681	et	3	main
olin	doc_399014257178_item	3564682	et	3	main
ümbes	doc_399014257178_item	3564683	et	4	main
10	doc_399014257178_item	3564684	et	2	main
aastat	doc_399014257178_item	3564685	et	3	main
vana	doc_399014257178_item	3564686	et	4	main
mängida	doc_399014257178_item	3564700	et	3	main
vana	doc_399014257178_item	3564720	et	4	main
ma	doc_399014257178_item	3564721	et	3	main
taksin	doc_399014257178_item	3564722	et	4	main
sest	doc_399014257178_item	3564725	et	4	main
mulle	doc_399014257178_item	3564726	et	4	main
meeldi	doc_399014257178_item	3564727	et	4	main
tegeda	doc_399014257178_item	3564728	et	4	main
mudel-lennuk	doc_399014257178_item	3564729	et	3	main
ja	doc_399014257178_item	3564730	et	3	main
poisid	doc_399014257178_item	3564731	et	4	main
tihti	doc_399014257178_item	3564732	et	3	main
tahavad	doc_399014257178_item	3564733	et	3	main
ühendada	doc_399014257178_item	3564734	et	3	main
sõjaväelased	doc_399014257178_item	3564735	et	3	main
aga	doc_399014257178_item	3564736	et	3	main
kui	doc_399014257178_item	3564737	et	3	main
ma	doc_399014257178_item	3564738	et	3	main
olin	doc_399014257178_item	3564739	et	3	main
13	doc_399014257178_item	3564740	et	2	main
vana	doc_399014257178_item	3564742	et	4	main
aastat	doc_399014257178_item	3564741	et	3	main
ma	doc_399014257178_item	3564743	et	3	main
vana	doc_399014257178_item	3564697	et	4	main
alustasin	doc_399014257178_item	3564699	et	3	main
sõber	doc_399014257178_item	3564704	et	3	main
mängib	doc_399014257178_item	3564705	et	3	main
maale	doc_399014257178_item	3564713	et	4	main
10	doc_399014257178_item	3564718	et	2	main
aastat	doc_399014257178_item	3564719	et	3	main
sain	doc_399014257178_item	3564744	et	3	main
väga	doc_399014257178_item	3564745	et	3	main
pesu	doc_399014257178_item	3564749	et	4	main
haiglas	doc_399014257178_item	3564751	et	3	main
seal	doc_399014257178_item	3564756	et	4	main
järel	doc_399014257178_item	3564757	et	4	main
ma	doc_399014257178_item	3564758	et	3	main
võinud	doc_399014257178_item	3564760	et	4	main
aga	doc_399014257178_item	3564763	et	3	main
ma	doc_399014257178_item	3564764	et	3	main
armastan	doc_399014257178_item	3564766	et	3	main
mängib	doc_399014257178_item	3564770	et	3	main
ragbit	doc_399014257178_item	3564771	et	3	main
kui	doc_399014257178_item	3564773	et	3	main
ma	doc_399014257178_item	3564774	et	3	main
muusik	doc_399014257178_item	3564784	et	3	main
aga	doc_399014257178_item	3564789	et	3	main
mulle	doc_399014257178_item	3564793	et	4	main
muusik	doc_399014257178_item	3564794	et	3	main
saan	doc_399014257178_item	3564802	et	4	main
glasgow	doc_399014257179_item	3564838	et	4	main
ma	doc_399014257179_item	3564841	et	3	main
ma	doc_399014257179_item	3564845	et	3	main
ma	doc_399014257179_item	3564856	et	3	main
tegeksin	doc_399014257179_item	3564857	et	4	main
nõukogus	doc_399014257179_item	3564861	et	4	main
võib-olla	doc_399014257179_item	3564862	et	3	main
saja	doc_399014257179_item	3564867	et	4	main
inimesed	doc_399014257179_item	3564868	et	3	main
glasgow	doc_399014257179_item	3564870	et	4	main
sõitma	doc_399014257179_item	3564877	et	3	main
metrooga	doc_399014257179_item	3564878	et	3	main
pole	doc_399014257179_item	3564882	et	3	main
parklad	doc_399014257179_item	3564884	et	3	main
ma	doc_399014257179_item	3564887	et	3	main
raha	doc_399014257179_item	3564895	et	4	main
meelest	doc_399014257179_item	3564901	et	4	main
ilus	doc_399014257179_item	3564904	et	4	main
elaksin	doc_399014257179_item	3564913	et	3	main
iga	doc_399014257179_item	3564925	et	4	main
päev	doc_399014257179_item	3564926	et	3	main
ja	doc_399014257179_item	3564927	et	3	main
väsinud	doc_399014257179_item	3564930	et	4	main
õhtul	doc_399014257179_item	3564937	et	3	main
kulutusid	doc_399014257179_item	3564952	et	4	main
väga	doc_399014257179_item	3564956	et	3	main
huvitatud	doc_399014257179_item	3564969	et	4	main
kiire	doc_399014257179_item	3564977	et	4	main
glasgow	doc_399014257179_item	3564995	et	4	main
võib-olla	doc_399014257179_item	3565007	et	3	main
ma	doc_399014257179_item	3565008	et	3	main
tegeksin	doc_399014257179_item	3565009	et	4	main
üsna	doc_399014257179_item	3565019	et	3	main
liiga	doc_399014257179_item	3565039	et	4	main
avavad	doc_399014257179_item	3565043	et	4	main
kuus	doc_399014257179_item	3565053	et	4	main
õhtul	doc_399014257179_item	3565054	et	3	main
ma	doc_399014257179_item	3565055	et	3	main
teen	doc_399014257179_item	3565056	et	3	main
ja	doc_399014257178_item	3564747	et	3	main
ümbes	doc_399014257178_item	3564752	et	4	main
ikka	doc_399014257178_item	3564765	et	4	main
maa	doc_399014257178_item	3564769	et	4	main
taksin	doc_399014257178_item	3564782	et	4	main
ma	doc_399014257178_item	3564786	et	3	main
õpetaja	doc_399014257178_item	3564791	et	4	main
ütlesi	doc_399014257178_item	3564792	et	4	main
ma	doc_399014257179_item	3564836	et	3	main
valiksin	doc_399014257179_item	3564846	et	3	main
ma	doc_399014257179_item	3564848	et	3	main
glasgows	doc_399014257179_item	3564854	et	4	main
kõige	doc_399014257179_item	3564858	et	4	main
poole	doc_399014257179_item	3564866	et	4	main
teosesse	doc_399014257179_item	3564879	et	4	main
maal	doc_399014257179_item	3564898	et	4	main
ma	doc_399014257179_item	3564912	et	3	main
lomondi	doc_399014257179_item	3564916	et	4	main
kui	doc_399014257179_item	3564918	et	3	main
oleksin	doc_399014257179_item	3564920	et	3	main
kui	doc_399014257179_item	3564931	et	3	main
nii	doc_399014257179_item	3564936	et	3	main
kodus	doc_399014257179_item	3564940	et	4	main
ostaksin	doc_399014257179_item	3564951	et	3	main
sõidutaksin	doc_399014257179_item	3564955	et	3	main
glasgow	doc_399014257179_item	3564963	et	4	main
ma	doc_399014257179_item	3564965	et	3	main
või	doc_399014257179_item	3564978	et	4	main
muidu	doc_399014257179_item	3564979	et	3	main
nad	doc_399014257179_item	3564980	et	3	main
ja	doc_399014257179_item	3564983	et	3	main
oleksit	doc_399014257179_item	3564985	et	4	main
suure	doc_399014257179_item	3564986	et	3	main
skandaal	doc_399014257179_item	3564987	et	3	main
ja	doc_399014257179_item	3564988	et	3	main
ma	doc_399014257179_item	3564989	et	3	main
peaksin	doc_399014257179_item	3564990	et	4	main
lahkuma	doc_399014257179_item	3564991	et	3	main
kui	doc_399014257179_item	3564992	et	3	main
ma	doc_399014257179_item	3564993	et	3	main
oleksin	doc_399014257179_item	3564994	et	3	main
tegeksin	doc_399014257179_item	3564998	et	4	main
odavem	doc_399014257179_item	3565010	et	4	main
sõitma	doc_399014257179_item	3565011	et	3	main
bussiga	doc_399014257179_item	3565012	et	3	main
odav	doc_399014257179_item	3565020	et	3	main
tean	doc_399014257179_item	3565031	et	3	main
praegu	doc_399014257179_item	3565032	et	3	main
ja	doc_399014257179_item	3565034	et	3	main
kõrtsid	doc_399014257179_item	3565035	et	3	main
avavad	doc_399014257179_item	3565036	et	4	main
praegu	doc_399014257178_item	3564798	et	3	main
sest	doc_399014257178_item	3564804	et	4	main
see	doc_399014257178_item	3564805	et	3	main
on	doc_399014257178_item	3564806	et	4	main
head	doc_399014257178_item	3564807	et	4	main
töö	doc_399014257178_item	3564808	et	4	main
kui	doc_399014257178_item	3564809	et	3	main
ma	doc_399014257178_item	3564810	et	3	main
saaksin	doc_399014257178_item	3564811	et	3	main
õpetaja	doc_399014257178_item	3564812	et	4	main
mul	doc_399014257178_item	3564813	et	3	main
on	doc_399014257178_item	3564814	et	4	main
pikkad	doc_399014257178_item	3564815	et	4	main
puhkusid	doc_399014257178_item	3564816	et	3	main
ja	doc_399014257178_item	3564817	et	3	main
töö	doc_399014257178_item	3564818	et	4	main
kergem	doc_399014257178_item	3564819	et	4	main
kui	doc_399014257178_item	3564820	et	3	main
poliitik	doc_399014257178_item	3564821	et	3	main
või	doc_399014257178_item	3564822	et	4	main
lendur	doc_399014257178_item	3564823	et	3	main
aga	doc_399014257178_item	3564824	et	3	main
ma	doc_399014257178_item	3564825	et	3	main
mõtlen	doc_399014257178_item	3564826	et	3	main
olema	doc_399014257178_item	3564827	et	4	main
õpetaja	doc_399014257178_item	3564828	et	4	main
on	doc_399014257178_item	3564829	et	4	main
ka	doc_399014257178_item	3564830	et	3	main
nõudlik	doc_399014257178_item	3564831	et	3	main
töö	doc_399014257178_item	3564832	et	4	main
kui	doc_399014257179_item	3564835	et	3	main
linnapea	doc_399014257179_item	3564839	et	4	main
oleksin	doc_399014257179_item	3564842	et	3	main
kohta	doc_399014257179_item	3564852	et	4	main
inimesed	doc_399014257179_item	3564853	et	3	main
seal	doc_399014257179_item	3564863	et	4	main
on	doc_399014257179_item	3564864	et	4	main
peaksin	doc_399014257179_item	3564876	et	4	main
läänes-glasgows	doc_399014257179_item	3564889	et	4	main
mul	doc_399014257179_item	3564892	et	3	main
elaksin	doc_399014257179_item	3564897	et	3	main
läärkeris	doc_399014257179_item	3564899	et	4	main
pole	doc_399014257179_item	3564903	et	3	main
aga	doc_399014257179_item	3564906	et	3	main
šotimaal	doc_399014257179_item	3564908	et	2	main
tõenäoliselt	doc_399014257179_item	3564911	et	4	main
ma	doc_399014257179_item	3564928	et	3	main
oleksin	doc_399014257179_item	3564929	et	3	main
maja	doc_399014257179_item	3564934	et	4	main
oleksin	doc_399014257179_item	3564837	et	3	main
kui	doc_399014257179_item	3564840	et	3	main
glasgow	doc_399014257179_item	3564843	et	4	main
palju	doc_399014257179_item	3564850	et	4	main
otsusid	doc_399014257179_item	3564851	et	4	main
see	doc_399014257179_item	3564855	et	3	main
kesklinnas	doc_399014257179_item	3564873	et	4	main
nii	doc_399014257179_item	3564874	et	3	main
ma	doc_399014257179_item	3564875	et	3	main
sest	doc_399014257179_item	3564880	et	4	main
elaksin	doc_399014257179_item	3564888	et	3	main
kui	doc_399014257179_item	3564891	et	3	main
ma	doc_399014257179_item	3564896	et	3	main
minu	doc_399014257179_item	3564900	et	3	main
linn	doc_399014257179_item	3564905	et	3	main
maa	doc_399014257179_item	3564907	et	4	main
väga	doc_399014257179_item	3564909	et	3	main
järve	doc_399014257179_item	3564915	et	4	main
ma	doc_399014257179_item	3564919	et	3	main
tuleksin	doc_399014257179_item	3564933	et	3	main
jööksin	doc_399014257179_item	3564944	et	4	main
vein	doc_399014257179_item	3564945	et	3	main
kui	doc_399014257179_item	3564946	et	3	main
mul	doc_399014257179_item	3564947	et	3	main
sportautod	doc_399014257179_item	3564953	et	3	main
maal	doc_399014257179_item	3564958	et	4	main
tean	doc_399014257179_item	3564966	et	3	main
linnapea	doc_399014257179_item	3564996	et	4	main
kuidas	doc_399014257179_item	3565003	et	3	main
voi	doc_399014257179_item	3565013	et	4	main
metrooga	doc_399014257179_item	3565014	et	3	main
aga	doc_399014257179_item	3565015	et	3	main
praegu	doc_399014257179_item	3565016	et	3	main
sest	doc_399014257179_item	3565029	et	4	main
ma	doc_399014257179_item	3565030	et	3	main
poodid	doc_399014257179_item	3565033	et	4	main
ja	doc_399014257179_item	3565037	et	3	main
poodid	doc_399014257179_item	3565042	et	4	main
ümbes	doc_399014257179_item	3565044	et	4	main
kell	doc_399014257179_item	3565045	et	3	main
üheksa	doc_399014257179_item	3565046	et	4	main
hommikul	doc_399014257179_item	3565047	et	3	main
ja	doc_399014257179_item	3565048	et	3	main
kõrtsid	doc_399014257179_item	3565057	et	3	main
ümbes	doc_399014257179_item	3565060	et	4	main
kolm	doc_399014257179_item	3565062	et	3	main
šotimaal	doc_399014257180_item	3565069	et	2	main
kõige	doc_399014257180_item	3565080	et	4	main
parem	doc_399014257180_item	3565081	et	4	main
aga	doc_399014257180_item	3565086	et	3	main
süvel	doc_399014257180_item	3565089	et	4	main
šotimaal	doc_399014257180_item	3565097	et	2	main
mõnikord	doc_399014257180_item	3565098	et	3	main
on	doc_399014257180_item	3565099	et	4	main
igal	doc_399014257180_item	3565104	et	3	main
väga	doc_399014257180_item	3565107	et	3	main
aga	doc_399014257180_item	3565109	et	3	main
mul	doc_399014257180_item	3565110	et	3	main
oli	doc_399014257180_item	3565111	et	3	main
ma	doc_399014257180_item	3565114	et	3	main
läksin	doc_399014257180_item	3565115	et	3	main
raamatukoju	doc_399014257180_item	3565116	et	4	main
mul	doc_399014257180_item	3565117	et	3	main
oli	doc_399014257180_item	3565118	et	3	main
šotimaal	doc_399014257180_item	3565123	et	2	main
aga	doc_399014257180_item	3565126	et	3	main
juunil	doc_399014257180_item	3565128	et	3	main
viis	doc_399014257180_item	3565136	et	4	main
šotimaal	doc_399014257180_item	3565162	et	2	main
on	doc_399014257180_item	3565163	et	4	main
vihma	doc_399014257180_item	3565174	et	4	main
iga	doc_399014257180_item	3565175	et	4	main
päev	doc_399014257180_item	3565176	et	3	main
tuuline	doc_399014257180_item	3565184	et	3	main
miks	doc_399014257180_item	3565189	et	4	main
mõtlen	doc_399014257180_item	3565191	et	3	main
kõige	doc_399014257180_item	3565194	et	4	main
rohkem	doc_399014257180_item	3565195	et	4	main
talvel	doc_399014257180_item	3565205	et	4	main
rohkem	doc_399014257180_item	3565208	et	4	main
ema	doc_399014257180_item	3565211	et	4	main
ja	doc_399014257180_item	3565212	et	3	main
ema	doc_399014257181_item	3565249	et	4	main
ja	doc_399014257181_item	3565250	et	3	main
nad	doc_399014257181_item	3565274	et	3	main
alustasid	doc_399014257181_item	3565275	et	4	main
ka	doc_399014257181_item	3565276	et	3	main
ma	doc_399014257179_item	3564923	et	3	main
töötaski	doc_399014257179_item	3564924	et	3	main
ma	doc_399014257179_item	3564932	et	3	main
ma	doc_399014257179_item	3564938	et	3	main
lõõgastaksin	doc_399014257179_item	3564939	et	3	main
oleksib	doc_399014257179_item	3564948	et	4	main
rikas	doc_399014257179_item	3564949	et	4	main
ma	doc_399014257179_item	3564950	et	3	main
kiire	doc_399014257179_item	3564957	et	4	main
siiski	doc_399014257179_item	3564959	et	4	main
sest	doc_399014257179_item	3564960	et	4	main
ma	doc_399014257179_item	3564961	et	3	main
oleksin	doc_399014257179_item	3564962	et	3	main
kohta	doc_399014257179_item	3564970	et	4	main
ma	doc_399014257179_item	3564971	et	3	main
seetõttu	doc_399014257179_item	3564972	et	3	main
ma	doc_399014257179_item	3564973	et	3	main
ei	doc_399014257179_item	3564974	et	4	main
sõidataks	doc_399014257179_item	3564975	et	4	main
teataksivad	doc_399014257179_item	3564981	et	4	main
see	doc_399014257179_item	3564984	et	3	main
odavem	doc_399014257179_item	3564999	et	4	main
elada	doc_399014257179_item	3565000	et	3	main
ma	doc_399014257179_item	3565004	et	3	main
kõik	doc_399014257179_item	3565025	et	4	main
päev	doc_399014257179_item	3565026	et	3	main
ka	doc_399014257179_item	3565027	et	3	main
kõrtsid	doc_399014257179_item	3565028	et	3	main
glasgows	doc_399014257179_item	3565041	et	4	main
sulgevad	doc_399014257179_item	3565049	et	4	main
kuni	doc_399014257179_item	3565059	et	3	main
kell	doc_399014257179_item	3565061	et	3	main
meelest	doc_399014257180_item	3565076	et	4	main
šotimaal	doc_399014257180_item	3565077	et	2	main
kevad	doc_399014257180_item	3565078	et	3	main
on	doc_399014257180_item	3565084	et	4	main
jalgas	doc_399014257180_item	3565119	et	4	main
on	doc_399014257180_item	3565133	et	4	main
sooja	doc_399014257180_item	3565138	et	4	main
juulil	doc_399014257180_item	3565139	et	3	main
ja	doc_399014257180_item	3565140	et	3	main
kuivem	doc_399014257180_item	3565143	et	4	main
kakskümmend	doc_399014257180_item	3565149	et	4	main
viis	doc_399014257180_item	3565150	et	4	main
kroodi	doc_399014257180_item	3565151	et	4	main
juulil	doc_399014257180_item	3565159	et	3	main
glasgow	doc_399014257180_item	3565182	et	4	main
et	doc_399014257180_item	3565192	et	3	main
šotimaal	doc_399014257180_item	3565206	et	2	main
maal	doc_399014257180_item	3565215	et	4	main
on	doc_399014257180_item	3565225	et	4	main
linnas	doc_399014257180_item	3565228	et	4	main
õhtul	doc_399014257179_item	3564935	et	3	main
vaadak	doc_399014257179_item	3564941	et	4	main
telekas	doc_399014257179_item	3564942	et	4	main
ja	doc_399014257179_item	3564943	et	3	main
ma	doc_399014257179_item	3564954	et	3	main
linnapea	doc_399014257179_item	3564964	et	4	main
ajakirjankid	doc_399014257179_item	3564967	et	4	main
oleksivad	doc_399014257179_item	3564968	et	4	main
liiga	doc_399014257179_item	3564976	et	4	main
politseis	doc_399014257179_item	3564982	et	3	main
ma	doc_399014257179_item	3564997	et	3	main
glasgows	doc_399014257179_item	3565001	et	4	main
aga	doc_399014257179_item	3565002	et	3	main
ei	doc_399014257179_item	3565005	et	4	main
tea	doc_399014257179_item	3565006	et	4	main
sõitma	doc_399014257179_item	3565017	et	3	main
glasgows	doc_399014257179_item	3565018	et	4	main
ma	doc_399014257179_item	3565021	et	3	main
lubaskin	doc_399014257179_item	3565022	et	4	main
poodid	doc_399014257179_item	3565023	et	4	main
avada	doc_399014257179_item	3565024	et	3	main
vara	doc_399014257179_item	3565040	et	4	main
ümbes	doc_399014257179_item	3565050	et	4	main
kell	doc_399014257179_item	3565051	et	3	main
poole	doc_399014257179_item	3565052	et	4	main
avaksivad	doc_399014257179_item	3565058	et	4	main
kell	doc_399014257179_item	3565063	et	3	main
nelj	doc_399014257179_item	3565064	et	4	main
hommikul	doc_399014257179_item	3565065	et	3	main
essee	doc_399014257180_item	3565067	et	4	main
ilm	doc_399014257180_item	3565068	et	3	main
šotimaal	doc_399014257180_item	3565071	et	2	main
on	doc_399014257180_item	3565079	et	4	main
kuivem	doc_399014257180_item	3565087	et	4	main
kõige	doc_399014257180_item	3565090	et	4	main
parem	doc_399014257180_item	3565091	et	4	main
kuu	doc_399014257180_item	3565092	et	4	main
mail	doc_399014257180_item	3565096	et	4	main
sooja	doc_399014257180_item	3565103	et	4	main
on	doc_399014257180_item	3565106	et	4	main
soe	doc_399014257180_item	3565108	et	4	main
eksamad	doc_399014257180_item	3565112	et	3	main
millal	doc_399014257180_item	3565113	et	3	main
süvel	doc_399014257180_item	3565122	et	4	main
alati	doc_399014257180_item	3565129	et	4	main
sajab	doc_399014257180_item	3565130	et	3	main
vihma	doc_399014257180_item	3565131	et	4	main
aga	doc_399014257180_item	3565132	et	3	main
kroodi	doc_399014257180_item	3565137	et	4	main
on	doc_399014257180_item	3565142	et	4	main
ja	doc_399014257180_item	3565144	et	3	main
on	doc_399014257180_item	3565158	et	4	main
sooja	doc_399014257180_item	3565171	et	4	main
aga	doc_399014257180_item	3565172	et	3	main
sajab	doc_399014257180_item	3565173	et	3	main
ma	doc_399014257180_item	3565186	et	3	main
läänel-glasgows	doc_399014257180_item	3565196	et	4	main
detsembril	doc_399014257180_item	3565197	et	3	main
saab	doc_399014257180_item	3565198	et	3	main
väga	doc_399014257180_item	3565199	et	3	main
külm	doc_399014257180_item	3565200	et	3	main
seitse	doc_399014257180_item	3565202	et	3	main
on	doc_399014257180_item	3565207	et	4	main
maal	doc_399014257180_item	3565209	et	4	main
mu	doc_399014257180_item	3565210	et	3	main
seal	doc_399014257180_item	3565216	et	4	main
sajab	doc_399014257180_item	3565217	et	3	main
lund	doc_399014257180_item	3565218	et	3	main
jaanuaril	doc_399014257180_item	3565219	et	3	main
ja	doc_399014257180_item	3565220	et	3	main
veebruaril	doc_399014257180_item	3565221	et	3	main
igal	doc_399014257180_item	3565222	et	3	main
aastal	doc_399014257180_item	3565223	et	3	main
kui	doc_399014257180_item	3565227	et	3	main
minu	doc_399014257181_item	3565238	et	3	main
isa	doc_399014257181_item	3565251	et	4	main
linn	doc_399014257181_item	3565256	et	3	main
üks	doc_399014257181_item	3565263	et	3	main
kalustasid	doc_399014257181_item	3565283	et	4	main
meile	doc_399014257181_item	3565284	et	4	main
minu	doc_399014257181_item	3565285	et	3	main
on	doc_399014257181_item	3565291	et	4	main
ma	doc_399014257181_item	3565300	et	3	main
sulgevad	doc_399014257179_item	3565038	et	4	main
ilm	doc_399014257180_item	3565070	et	3	main
hea	doc_399014257180_item	3565074	et	4	main
minu	doc_399014257180_item	3565075	et	3	main
kevadel	doc_399014257180_item	3565082	et	4	main
šotimaal	doc_399014257180_item	3565083	et	2	main
kui	doc_399014257180_item	3565088	et	3	main
mai	doc_399014257180_item	3565095	et	4	main
kroodi	doc_399014257180_item	3565102	et	4	main
lühikesed	doc_399014257180_item	3565120	et	4	main
on	doc_399014257180_item	3565124	et	4	main
kuiv	doc_399014257180_item	3565125	et	3	main
umbes	doc_399014257180_item	3565134	et	4	main
augustil	doc_399014257180_item	3565141	et	3	main
on	doc_399014257180_item	3565145	et	4	main
umbes	doc_399014257180_item	3565146	et	4	main
ka	doc_399014257180_item	3565147	et	3	main
sooja	doc_399014257180_item	3565152	et	4	main
kui	doc_399014257180_item	3565153	et	3	main
ma	doc_399014257180_item	3565154	et	3	main
sõidan	doc_399014257180_item	3565155	et	3	main
tavaliselt	doc_399014257180_item	3565160	et	4	main
on	doc_399014257180_item	3565167	et	4	main
neliteist	doc_399014257180_item	3565169	et	4	main
kroodi	doc_399014257180_item	3565170	et	4	main
on	doc_399014257180_item	3565183	et	4	main
ei	doc_399014257180_item	3565187	et	4	main
umbes	doc_399014257180_item	3565201	et	4	main
isa	doc_399014257180_item	3565213	et	4	main
maal	doc_399014257180_item	3565224	et	4	main
külmim	doc_399014257180_item	3565226	et	3	main
puhkepäevad	doc_399014257181_item	3565241	et	3	main
viisteistkümnesal	doc_399014257181_item	3565243	et	4	main
detsembril	doc_399014257181_item	3565244	et	3	main
ma	doc_399014257181_item	3565245	et	3	main
viibin	doc_399014257181_item	3565246	et	3	main
oma	doc_399014257181_item	3565248	et	4	main
maja	doc_399014257181_item	3565252	et	4	main
venda	doc_399014257181_item	3565262	et	4	main
õde	doc_399014257181_item	3565264	et	4	main
õde	doc_399014257181_item	3565279	et	4	main
ja	doc_399014257181_item	3565280	et	3	main
vanem	doc_399014257181_item	3565281	et	4	main
vend	doc_399014257181_item	3565282	et	3	main
puhkepäevadis	doc_399014257181_item	3565299	et	4	main
siiski	doc_399014257181_item	3565307	et	4	main
tegen	doc_399014257181_item	3565309	et	4	main
oma	doc_399014257181_item	3565310	et	4	main
jõulud	doc_399014257181_item	3565311	et	3	main
detsembril	doc_399014257181_item	3565315	et	3	main
sõitin	doc_399014257181_item	3565317	et	4	main
rongiga	doc_399014257181_item	3565318	et	4	main
edinburghi	doc_399014257181_item	3565319	et	4	main
ma	doc_399014257181_item	3565320	et	3	main
sisseostude	doc_399014257181_item	3565324	et	3	main
maja	doc_399014257181_item	3565328	et	4	main
kohtin	doc_399014257181_item	3565339	et	4	main
maja	doc_399014257181_item	3565353	et	4	main
ja	doc_399014257181_item	3565362	et	3	main
tubakorter	doc_399014257183_item	3565415	et	3	main
xxx	doc_399014257183_item	3565430	et	4	main
on	doc_399014257183_item	3565438	et	4	main
ja	doc_399014257183_item	3565441	et	3	main
on	doc_399014257183_item	3565460	et	4	main
seal	doc_399014257183_item	3565466	et	4	main
ole	doc_399014257183_item	3565504	et	4	main
on	doc_399014257183_item	3565512	et	4	main
juures	doc_399014257183_item	3565537	et	4	main
cds	doc_399014257183_item	3565543	et	4	main
ja	doc_399014257183_item	3565544	et	3	main
rüüli	doc_399014257183_item	3565547	et	4	main
ei	doc_399014257183_item	3565556	et	4	main
ole	doc_399014257183_item	3565557	et	4	main
mu	doc_399014257183_item	3565558	et	3	main
mu	doc_399014257183_item	3565565	et	3	main
käpp	doc_399014257183_item	3565566	et	3	main
essee	doc_399014257184_item	3565596	et	4	main
nadal	doc_399014257184_item	3565598	et	4	main
jah	doc_399014257184_item	3565605	et	3	main
elan	doc_399014257184_item	3565609	et	3	main
esmaspäev	doc_399014257184_item	3565614	et	3	main
ärkan	doc_399014257184_item	3565616	et	3	main
sajab	doc_399014257180_item	3565230	et	3	main
lund	doc_399014257180_item	3565231	et	3	main
võib-olla	doc_399014257180_item	3565232	et	3	main
kolme	doc_399014257180_item	3565233	et	4	main
päevad	doc_399014257180_item	3565234	et	3	main
talvel	doc_399014257180_item	3565235	et	4	main
ei	doc_399014257180_item	3565072	et	4	main
ole	doc_399014257180_item	3565073	et	4	main
soe	doc_399014257180_item	3565085	et	4	main
kevadel	doc_399014257180_item	3565093	et	4	main
on	doc_399014257180_item	3565094	et	4	main
kakskümmend	doc_399014257180_item	3565100	et	4	main
kaheksa	doc_399014257180_item	3565101	et	4	main
mail	doc_399014257180_item	3565105	et	4	main
püksid	doc_399014257180_item	3565121	et	3	main
soe	doc_399014257180_item	3565127	et	4	main
kakskümmend	doc_399014257180_item	3565135	et	4	main
kakskümmend	doc_399014257180_item	3565148	et	4	main
puhkusesse	doc_399014257180_item	3565156	et	4	main
see	doc_399014257180_item	3565157	et	3	main
sügisel	doc_399014257180_item	3565161	et	3	main
ei	doc_399014257180_item	3565164	et	4	main
hea	doc_399014257180_item	3565165	et	4	main
aastaaeg	doc_399014257180_item	3565166	et	3	main
ümbes	doc_399014257180_item	3565168	et	4	main
glasgows	doc_399014257180_item	3565177	et	4	main
on	doc_399014257180_item	3565178	et	4	main
ka	doc_399014257180_item	3565179	et	3	main
puhub	doc_399014257180_item	3565180	et	3	main
tuul	doc_399014257180_item	3565181	et	3	main
linn	doc_399014257180_item	3565185	et	3	main
tea	doc_399014257180_item	3565188	et	4	main
ma	doc_399014257180_item	3565190	et	3	main
tuul	doc_399014257180_item	3565193	et	3	main
kroodi	doc_399014257180_item	3565203	et	4	main
sooja	doc_399014257180_item	3565204	et	4	main
elavad	doc_399014257180_item	3565214	et	4	main
glasgows	doc_399014257180_item	3565229	et	4	main
essee	doc_399014257181_item	3565237	et	4	main
puhkepäevad	doc_399014257181_item	3565239	et	3	main
minu	doc_399014257181_item	3565240	et	3	main
alusta	doc_399014257181_item	3565242	et	4	main
majas	doc_399014257181_item	3565247	et	3	main
on	doc_399014257181_item	3565253	et	4	main
väike	doc_399014257181_item	3565255	et	4	main
ligidal	doc_399014257181_item	3565257	et	4	main
mul	doc_399014257181_item	3565259	et	3	main
isa	doc_399014257181_item	3565266	et	4	main
maja	doc_399014257181_item	3565277	et	4	main
minu	doc_399014257181_item	3565278	et	3	main
vennatütar	doc_399014257181_item	3565287	et	3	main
tule	doc_399014257181_item	3565288	et	4	main
ka	doc_399014257181_item	3565289	et	3	main
ta	doc_399014257181_item	3565290	et	4	main
kuud	doc_399014257181_item	3565293	et	4	main
ihfluentsa	doc_399014257181_item	3565306	et	4	main
tegen	doc_399014257181_item	3565321	et	4	main
ja	doc_399014257181_item	3565325	et	3	main
sõitime	doc_399014257181_item	3565335	et	4	main
kõrts	doc_399014257181_item	3565336	et	3	main
kolmandal	doc_399014257181_item	3565382	et	3	main
januaril	doc_399014257181_item	3565383	et	4	main
sellepärast	doc_399014257181_item	3565384	et	3	main
et	doc_399014257181_item	3565385	et	3	main
ma	doc_399014257181_item	3565386	et	3	main
pean	doc_399014257181_item	3565387	et	4	main
õppima	doc_399014257181_item	3565388	et	3	main
mulle	doc_399014257181_item	3565389	et	4	main
on	doc_399014257181_item	3565390	et	4	main
vene	doc_399014257181_item	3565391	et	4	main
keel	doc_399014257181_item	3565392	et	4	main
uurimise	doc_399014257181_item	3565393	et	4	main
üheteistkümnesal	doc_399014257181_item	3565394	et	4	main
jaanuaril	doc_399014257181_item	3565395	et	3	main
ja	doc_399014257181_item	3565396	et	3	main
esitamine	doc_399014257181_item	3565397	et	4	main
mulle	doc_399014257181_item	3565398	et	4	main
ei	doc_399014257181_item	3565399	et	4	main
hea	doc_399014257181_item	3565400	et	4	main
vene	doc_399014257181_item	3565401	et	4	main
grammatika	doc_399014257181_item	3565402	et	4	main
nii	doc_399014257181_item	3565403	et	3	main
durfemlines	doc_399014257181_item	3565254	et	4	main
edinburghi	doc_399014257181_item	3565258	et	4	main
on	doc_399014257181_item	3565260	et	4	main
kolm	doc_399014257181_item	3565261	et	3	main
ema	doc_399014257181_item	3565265	et	4	main
ja	doc_399014257181_item	3565267	et	3	main
vennatütar	doc_399014257181_item	3565268	et	3	main
kaks	doc_399014257181_item	3565269	et	3	main
venda	doc_399014257181_item	3565270	et	4	main
olevad	doc_399014257181_item	3565271	et	4	main
minust	doc_399014257181_item	3565272	et	3	main
noorem	doc_399014257181_item	3565273	et	4	main
oma	doc_399014257181_item	3565286	et	4	main
neli	doc_399014257181_item	3565292	et	3	main
vana	doc_399014257181_item	3565294	et	4	main
ma	doc_399014257181_item	3565295	et	3	main
ei	doc_399014257181_item	3565296	et	4	main
mulle	doc_399014257181_item	3565304	et	4	main
oli	doc_399014257181_item	3565305	et	3	main
ma	doc_399014257181_item	3565308	et	3	main
kahekümnesal	doc_399014257181_item	3565314	et	4	main
ma	doc_399014257181_item	3565316	et	3	main
oma	doc_399014257181_item	3565322	et	4	main
sõitin	doc_399014257181_item	3565327	et	4	main
ja	doc_399014257181_item	3565337	et	3	main
ja	doc_399014257181_item	3565354	et	3	main
söösin	doc_399014257181_item	3565355	et	4	main
palju	doc_399014257181_item	3565360	et	4	main
õlu	doc_399014257181_item	3565363	et	3	main
me	doc_399014257181_item	3565369	et	4	main
me	doc_399014257181_item	3565373	et	4	main
külastasime	doc_399014257181_item	3565374	et	3	main
elavad	doc_399014257181_item	3565377	et	4	main
ma	doc_399014257181_item	3565379	et	3	main
elan	doc_399014257183_item	3565417	et	3	main
glasgows	doc_399014257183_item	3565419	et	4	main
minu	doc_399014257183_item	3565422	et	3	main
korter	doc_399014257183_item	3565423	et	3	main
suur	doc_399014257183_item	3565424	et	3	main
ja	doc_399014257183_item	3565425	et	3	main
seal	doc_399014257183_item	3565437	et	4	main
tubased	doc_399014257183_item	3565440	et	4	main
suur	doc_399014257183_item	3565442	et	3	main
korteris	doc_399014257183_item	3565445	et	3	main
on	doc_399014257183_item	3565447	et	4	main
magamistuba	doc_399014257183_item	3565448	et	4	main
ma	doc_399014257183_item	3565449	et	3	main
elan	doc_399014257183_item	3565450	et	3	main
2	doc_399014257183_item	3565451	et	2	main
nimide	doc_399014257183_item	3565454	et	4	main
on	doc_399014257183_item	3565455	et	4	main
voodi	doc_399014257183_item	3565511	et	4	main
on	doc_399014257183_item	3565551	et	4	main
tubas	doc_399014257183_item	3565559	et	4	main
mu	doc_399014257183_item	3565560	et	3	main
käpp	doc_399014257183_item	3565561	et	3	main
mu	doc_399014257183_item	3565562	et	3	main
on	doc_399014257183_item	3565571	et	4	main
mu	doc_399014257183_item	3565572	et	3	main
riided	doc_399014257183_item	3565573	et	3	main
mu	doc_399014257183_item	3565574	et	3	main
tegenud	doc_399014257181_item	3565297	et	4	main
minu	doc_399014257181_item	3565298	et	3	main
sisseostude	doc_399014257181_item	3565312	et	3	main
jõulud	doc_399014257181_item	3565323	et	3	main
ma	doc_399014257181_item	3565326	et	3	main
sõitin	doc_399014257181_item	3565331	et	4	main
ma	doc_399014257181_item	3565338	et	3	main
ma	doc_399014257181_item	3565343	et	3	main
koolis	doc_399014257181_item	3565345	et	4	main
noorem	doc_399014257181_item	3565349	et	4	main
jõulupäev	doc_399014257181_item	3565350	et	3	main
ma	doc_399014257181_item	3565351	et	3	main
viibin	doc_399014257181_item	3565352	et	3	main
joosin	doc_399014257181_item	3565359	et	4	main
oma	doc_399014257181_item	3565364	et	4	main
söösime	doc_399014257181_item	3565366	et	4	main
nad	doc_399014257181_item	3565376	et	3	main
glasgows	doc_399014257181_item	3565378	et	4	main
ma	doc_399014257181_item	3565404	et	3	main
õppima	doc_399014257181_item	3565406	et	3	main
nohu	doc_399014257181_item	3565411	et	4	main
lääs	doc_399014257183_item	3565418	et	3	main
tänav	doc_399014257183_item	3565431	et	4	main
ja	doc_399014257183_item	3565432	et	3	main
minu	doc_399014257183_item	3565433	et	3	main
telefoninumber	doc_399014257183_item	3565434	et	3	main
7	doc_399014257183_item	3565439	et	2	main
nende	doc_399014257183_item	3565453	et	4	main
eesnimi	doc_399014257183_item	3565456	et	3	main
ja	doc_399014257183_item	3565457	et	3	main
eesnimi	doc_399014257183_item	3565458	et	3	main
seal	doc_399014257183_item	3565459	et	4	main
kööki	doc_399014257183_item	3565464	et	4	main
elatubas	doc_399014257183_item	3565465	et	4	main
suur	doc_399014257183_item	3565505	et	3	main
ja	doc_399014257183_item	3565506	et	3	main
ei	doc_399014257183_item	3565507	et	4	main
ole	doc_399014257183_item	3565508	et	4	main
väike	doc_399014257183_item	3565509	et	4	main
mu	doc_399014257183_item	3565510	et	3	main
räämatude	doc_399014257183_item	3565538	et	4	main
on	doc_399014257183_item	3565539	et	4	main
dvds	doc_399014257183_item	3565545	et	4	main
juures	doc_399014257183_item	3565553	et	4	main
mu	doc_399014257183_item	3565554	et	3	main
käpp	doc_399014257183_item	3565555	et	3	main
kõrval	doc_399014257183_item	3565564	et	4	main
suur	doc_399014257183_item	3565568	et	3	main
mina	doc_399014257184_item	3565608	et	4	main
aastat	doc_399014257184_item	3565613	et	3	main
mina	doc_399014257184_item	3565615	et	4	main
lähen	doc_399014257184_item	3565626	et	3	main
ülikool	doc_399014257184_item	3565627	et	4	main
õhtul	doc_399014257184_item	3565640	et	3	main
mina	doc_399014257184_item	3565641	et	4	main
kussteist	doc_399014257184_item	3565645	et	4	main
üksteist	doc_399014257184_item	3565657	et	4	main
olevad	doc_399014257184_item	3565666	et	4	main
kaksteist	doc_399014257184_item	3565679	et	4	main
mina	doc_399014257184_item	3565691	et	4	main
olin	doc_399014257181_item	3565301	et	3	main
palavikus	doc_399014257181_item	3565302	et	3	main
haige	doc_399014257181_item	3565303	et	4	main
tegemina	doc_399014257181_item	3565313	et	4	main
õhtul	doc_399014257181_item	3565329	et	3	main
ma	doc_399014257181_item	3565330	et	3	main
linnas	doc_399014257181_item	3565332	et	4	main
sõbraga	doc_399014257181_item	3565333	et	3	main
meie	doc_399014257181_item	3565334	et	4	main
sõbrad	doc_399014257181_item	3565341	et	3	main
kohtin	doc_399014257181_item	3565344	et	4	main
millal	doc_399014257181_item	3565346	et	3	main
ma	doc_399014257181_item	3565347	et	3	main
olin	doc_399014257181_item	3565348	et	3	main
vein	doc_399014257181_item	3565361	et	3	main
ning	doc_399014257181_item	3565368	et	3	main
vaaltesime	doc_399014257181_item	3565370	et	4	main
filmid	doc_399014257181_item	3565371	et	4	main
jõulupühal	doc_399014257181_item	3565372	et	3	main
tulesin	doc_399014257181_item	3565380	et	4	main
glasgow	doc_399014257181_item	3565381	et	4	main
palju	doc_399014257181_item	3565407	et	4	main
mul	doc_399014257181_item	3565409	et	3	main
minu	doc_399014257183_item	3565414	et	3	main
palju	doc_399014257181_item	3565340	et	4	main
kes	doc_399014257181_item	3565342	et	4	main
palju	doc_399014257181_item	3565356	et	4	main
toit	doc_399014257181_item	3565357	et	3	main
ja	doc_399014257181_item	3565358	et	3	main
perekond	doc_399014257181_item	3565365	et	3	main
õhtul	doc_399014257181_item	3565367	et	3	main
vanavanemad	doc_399014257181_item	3565375	et	4	main
pean	doc_399014257181_item	3565405	et	4	main
aga	doc_399014257181_item	3565408	et	3	main
on	doc_399014257181_item	3565410	et	4	main
essee	doc_399014257183_item	3565413	et	4	main
lähedal	doc_399014257183_item	3565420	et	4	main
üliokooli	doc_399014257183_item	3565421	et	4	main
vana	doc_399014257183_item	3565426	et	4	main
minu	doc_399014257183_item	3565427	et	3	main
aadress	doc_399014257183_item	3565428	et	3	main
on	doc_399014257183_item	3565435	et	4	main
sõberdega	doc_399014257183_item	3565452	et	4	main
elatuba	doc_399014257183_item	3565462	et	4	main
ja	doc_399014257183_item	3565463	et	3	main
juures	doc_399014257183_item	3565471	et	4	main
rüüli	doc_399014257183_item	3565540	et	4	main
on	doc_399014257183_item	3565546	et	4	main
peal	doc_399014257183_item	3565548	et	4	main
mu	doc_399014257183_item	3565549	et	3	main
kitarrite	doc_399014257183_item	3565550	et	4	main
räämatude	doc_399014257183_item	3565575	et	4	main
ja	doc_399014257183_item	3565576	et	3	main
mu	doc_399014257183_item	3565577	et	3	main
vene	doc_399014257184_item	3565603	et	4	main
keelt	doc_399014257184_item	3565604	et	4	main
juba	doc_399014257184_item	3565611	et	3	main
sään	doc_399014257184_item	3565623	et	4	main
vene	doc_399014257184_item	3565637	et	4	main
kell	doc_399014257184_item	3565644	et	3	main
mina	doc_399014257184_item	3565646	et	4	main
seed	doc_399014257184_item	3565665	et	4	main
kirjandus	doc_399014257184_item	3565668	et	3	main
mina	doc_399014257184_item	3565680	et	4	main
hommikusööki	doc_399014257184_item	3565683	et	4	main
sään	doc_399014257184_item	3565692	et	4	main
veerand	doc_399014257184_item	3565712	et	4	main
neljapäev	doc_399014257184_item	3565717	et	3	main
vene	doc_399014257184_item	3565726	et	4	main
grammar	doc_399014257184_item	3565727	et	4	main
mina	doc_399014257184_item	3565728	et	4	main
lähen	doc_399014257184_item	3565729	et	3	main
laupäev	doc_399014257184_item	3565762	et	3	main
mina	doc_399014257184_item	3565763	et	4	main
magan	doc_399014257184_item	3565764	et	3	main
kaua	doc_399014257184_item	3565765	et	3	main
mina	doc_399014257184_item	3565766	et	4	main
lähen	doc_399014257184_item	3565767	et	3	main
neliteist	doc_399014257184_item	3565770	et	4	main
seto	doc_399014257185_item	3565785	et	4	main
kohta	doc_399014257185_item	3565786	et	4	main
elustada	doc_399014257185_item	3565791	et	3	main
traditsioone	doc_399014257185_item	3565792	et	3	main
kagu-eestis	doc_399014257185_item	3565800	et	3	main
eesti	doc_399014257185_item	3565804	et	4	main
nad	doc_399014257185_item	3565807	et	3	main
harrastavad	doc_399014257185_item	3565808	et	4	main
sõidid	doc_399014257185_item	3565818	et	3	main
pottsepatöökodat	doc_399014257185_item	3565822	et	4	main
palju	doc_399014257185_item	3565829	et	4	main
ja	doc_399014257185_item	3565839	et	3	main
oma	doc_399014257185_item	3565878	et	4	main
kingad	doc_399014257183_item	3565578	et	3	main
seinad	doc_399014257183_item	3565579	et	3	main
mu	doc_399014257183_item	3565580	et	3	main
magamistubas	doc_399014257183_item	3565581	et	4	main
on	doc_399014257183_item	3565582	et	4	main
valge	doc_399014257183_item	3565583	et	4	main
mu	doc_399014257183_item	3565584	et	3	main
voodi	doc_399014257183_item	3565585	et	4	main
on	doc_399014257183_item	3565586	et	4	main
punane	doc_399014257183_item	3565587	et	4	main
ja	doc_399014257183_item	3565588	et	3	main
sinise	doc_399014257183_item	3565589	et	4	main
ja	doc_399014257183_item	3565590	et	3	main
mu	doc_399014257183_item	3565591	et	3	main
rüül	doc_399014257183_item	3565592	et	3	main
on	doc_399014257183_item	3565593	et	4	main
hõbe	doc_399014257183_item	3565594	et	3	main
ma	doc_399014257183_item	3565416	et	3	main
on	doc_399014257183_item	3565429	et	4	main
000000	doc_399014257183_item	3565436	et	2	main
esik	doc_399014257183_item	3565443	et	3	main
mu	doc_399014257183_item	3565444	et	3	main
tubate	doc_399014257183_item	3565446	et	4	main
vannituba	doc_399014257183_item	3565461	et	4	main
on	doc_399014257183_item	3565467	et	4	main
2	doc_399014257183_item	3565468	et	2	main
suur	doc_399014257183_item	3565469	et	3	main
sohvade	doc_399014257183_item	3565470	et	3	main
seinade	doc_399014257183_item	3565472	et	3	main
mu	doc_399014257183_item	3565473	et	3	main
telekas	doc_399014257183_item	3565474	et	4	main
on	doc_399014257183_item	3565475	et	4	main
laua	doc_399014257183_item	3565476	et	3	main
peal	doc_399014257183_item	3565477	et	4	main
ja	doc_399014257183_item	3565478	et	3	main
all	doc_399014257183_item	3565480	et	3	main
kell	doc_399014257183_item	3565481	et	3	main
akenad	doc_399014257183_item	3565479	et	4	main
on	doc_399014257183_item	3565482	et	4	main
rüül	doc_399014257183_item	3565483	et	3	main
peal	doc_399014257183_item	3565484	et	4	main
köökis	doc_399014257183_item	3565485	et	4	main
seal	doc_399014257183_item	3565486	et	4	main
on	doc_399014257183_item	3565487	et	4	main
3	doc_399014257183_item	3565488	et	2	main
tooli	doc_399014257183_item	3565489	et	4	main
laua	doc_399014257183_item	3565490	et	3	main
kõrval	doc_399014257183_item	3565491	et	4	main
seal	doc_399014257183_item	3565492	et	4	main
on	doc_399014257183_item	3565493	et	4	main
20	doc_399014257183_item	3565494	et	2	main
kappi	doc_399014257183_item	3565495	et	4	main
mu	doc_399014257183_item	3565496	et	3	main
kappi	doc_399014257183_item	3565497	et	4	main
on	doc_399014257183_item	3565498	et	4	main
juures	doc_399014257183_item	3565500	et	4	main
aken	doc_399014257183_item	3565499	et	3	main
mu	doc_399014257183_item	3565501	et	3	main
tuba	doc_399014257183_item	3565502	et	4	main
ei	doc_399014257183_item	3565503	et	4	main
seinade	doc_399014257183_item	3565513	et	3	main
juures	doc_399014257183_item	3565514	et	4	main
mu	doc_399014257183_item	3565515	et	3	main
voodi	doc_399014257183_item	3565516	et	4	main
on	doc_399014257183_item	3565517	et	4	main
suur	doc_399014257183_item	3565518	et	3	main
laud	doc_399014257183_item	3565519	et	4	main
on	doc_399014257183_item	3565520	et	4	main
voodi	doc_399014257183_item	3565521	et	4	main
kõrval	doc_399014257183_item	3565522	et	4	main
mu	doc_399014257183_item	3565523	et	3	main
arvuti	doc_399014257183_item	3565524	et	4	main
on	doc_399014257183_item	3565525	et	4	main
laua	doc_399014257183_item	3565526	et	3	main
peal	doc_399014257183_item	3565527	et	4	main
lamp	doc_399014257183_item	3565528	et	3	main
laua	doc_399014257183_item	3565530	et	3	main
on	doc_399014257183_item	3565529	et	4	main
peal	doc_399014257183_item	3565531	et	4	main
rüüli	doc_399014257183_item	3565532	et	4	main
sein	doc_399014257183_item	3565533	et	3	main
juures	doc_399014257183_item	3565534	et	4	main
ja	doc_399014257183_item	3565535	et	3	main
aken	doc_399014257183_item	3565536	et	3	main
peal	doc_399014257183_item	3565541	et	4	main
ja	doc_399014257183_item	3565542	et	3	main
voodi	doc_399014257183_item	3565552	et	4	main
magamistuba	doc_399014257183_item	3565563	et	4	main
väga	doc_399014257183_item	3565567	et	3	main
käppis	doc_399014257183_item	3565569	et	4	main
seal	doc_399014257183_item	3565570	et	4	main
ülikoolis	doc_399014257184_item	3565602	et	4	main
eesti	doc_399014257184_item	3565606	et	4	main
mina	doc_399014257184_item	3565622	et	4	main
mina	doc_399014257184_item	3565625	et	4	main
jalgsi	doc_399014257184_item	3565628	et	3	main
esmaspäev	doc_399014257184_item	3565629	et	3	main
keelt	doc_399014257184_item	3565638	et	4	main
esmaspäev	doc_399014257184_item	3565639	et	3	main
sään	doc_399014257184_item	3565647	et	4	main
lõunasööki	doc_399014257184_item	3565648	et	4	main
üheksateist	doc_399014257184_item	3565649	et	4	main
teispäev	doc_399014257184_item	3565650	et	3	main
mina	doc_399014257184_item	3565651	et	4	main
ärkan	doc_399014257184_item	3565652	et	3	main
kell	doc_399014257184_item	3565653	et	3	main
kümme	doc_399014257184_item	3565654	et	3	main
kell	doc_399014257184_item	3565655	et	3	main
veerand	doc_399014257184_item	3565656	et	4	main
hommikusööki	doc_399014257184_item	3565660	et	4	main
loengud	doc_399014257184_item	3565664	et	3	main
jah	doc_399014257184_item	3565669	et	3	main
kolmapäev	doc_399014257184_item	3565676	et	3	main
mina	doc_399014257184_item	3565677	et	4	main
ärkan	doc_399014257184_item	3565678	et	3	main
sää	doc_399014257184_item	3565682	et	4	main
üks	doc_399014257184_item	3565685	et	3	main
see	doc_399014257184_item	3565687	et	3	main
eesti	doc_399014257184_item	3565689	et	4	main
keel	doc_399014257184_item	3565690	et	4	main
viisteist	doc_399014257184_item	3565694	et	4	main
jah	doc_399014257184_item	3565695	et	3	main
film	doc_399014257184_item	3565699	et	3	main
lähen	doc_399014257184_item	3565701	et	3	main
kell	doc_399014257184_item	3565703	et	3	main
kaheksateist	doc_399014257184_item	3565705	et	4	main
neljapäev	doc_399014257184_item	3565706	et	3	main
sään	doc_399014257184_item	3565715	et	4	main
kaks	doc_399014257184_item	3565719	et	3	main
olevad	doc_399014257184_item	3565722	et	4	main
mina	doc_399014257184_item	3565757	et	4	main
koju	doc_399014257184_item	3565759	et	3	main
raamatukogus	doc_399014257184_item	3565768	et	4	main
jah	doc_399014257184_item	3565771	et	3	main
pühapäeval	doc_399014257184_item	3565774	et	3	main
õpin	doc_399014257184_item	3565776	et	3	main
essee	doc_399014257185_item	3565779	et	4	main
hiljuti	doc_399014257185_item	3565781	et	4	main
ma	doc_399014257185_item	3565782	et	3	main
vaatasin	doc_399014257185_item	3565783	et	3	main
tahtasid	doc_399014257185_item	3565789	et	4	main
ja	doc_399014257185_item	3565801	et	3	main
räägivad	doc_399014257185_item	3565803	et	3	main
ortodaksiat	doc_399014257185_item	3565809	et	4	main
sest	doc_399014257185_item	3565810	et	4	main
nad	doc_399014257185_item	3565811	et	3	main
elavad	doc_399014257185_item	3565812	et	4	main
venemaa	doc_399014257185_item	3565813	et	4	main
lähedal	doc_399014257185_item	3565814	et	4	main
eelmistel	doc_399014257185_item	3565815	et	3	main
külalt	doc_399014257185_item	3565819	et	3	main
tavalised	doc_399014257185_item	3565827	et	4	main
aga	doc_399014257185_item	3565828	et	3	main
hobustega	doc_399014257185_item	3565838	et	4	main
vankeritega	doc_399014257185_item	3565840	et	3	main
aga	doc_399014257185_item	3565880	et	3	main
mõnikord	doc_399014257185_item	3565881	et	3	main
setulaste	doc_399014257185_item	3565931	et	4	main
pärn	doc_399014257186_item	3565951	et	3	main
minu	doc_399014257184_item	3565597	et	3	main
mina	doc_399014257184_item	3565599	et	4	main
õpin	doc_399014257184_item	3565600	et	3	main
glasgow	doc_399014257184_item	3565601	et	4	main
keelt	doc_399014257184_item	3565607	et	4	main
glasgows	doc_399014257184_item	3565610	et	4	main
2	doc_399014257184_item	3565612	et	2	main
veerand	doc_399014257184_item	3565620	et	4	main
kümme	doc_399014257184_item	3565621	et	3	main
minu	doc_399014257184_item	3565630	et	3	main
kaks	doc_399014257184_item	3565631	et	3	main
loengud	doc_399014257184_item	3565632	et	3	main
seed	doc_399014257184_item	3565633	et	4	main
olevad	doc_399014257184_item	3565634	et	4	main
eesti	doc_399014257184_item	3565635	et	4	main
jah	doc_399014257184_item	3565636	et	3	main
kell	doc_399014257184_item	3565617	et	3	main
üheksa	doc_399014257184_item	3565618	et	4	main
kell	doc_399014257184_item	3565619	et	3	main
hommikusööki	doc_399014257184_item	3565624	et	4	main
koju	doc_399014257184_item	3565643	et	3	main
mina	doc_399014257184_item	3565658	et	4	main
sään	doc_399014257184_item	3565659	et	4	main
vene	doc_399014257184_item	3565667	et	4	main
mina	doc_399014257184_item	3565671	et	4	main
lähen	doc_399014257184_item	3565672	et	3	main
koju	doc_399014257184_item	3565673	et	3	main
kell	doc_399014257184_item	3565674	et	3	main
kussteist	doc_399014257184_item	3565675	et	4	main
ei	doc_399014257184_item	3565681	et	4	main
lõunasööki	doc_399014257184_item	3565693	et	4	main
nähan	doc_399014257184_item	3565697	et	4	main
üksteist	doc_399014257184_item	3565713	et	4	main
minu	doc_399014257184_item	3565718	et	3	main
lähen	doc_399014257184_item	3565642	et	3	main
teispäev	doc_399014257184_item	3565661	et	3	main
minu	doc_399014257184_item	3565662	et	3	main
kaks	doc_399014257184_item	3565663	et	3	main
politik	doc_399014257184_item	3565670	et	4	main
minu	doc_399014257184_item	3565684	et	3	main
loeng	doc_399014257184_item	3565686	et	3	main
on	doc_399014257184_item	3565688	et	4	main
mina	doc_399014257184_item	3565696	et	4	main
eesti	doc_399014257184_item	3565698	et	4	main
mina	doc_399014257184_item	3565714	et	4	main
loengud	doc_399014257184_item	3565720	et	3	main
seed	doc_399014257184_item	3565721	et	4	main
eesti	doc_399014257184_item	3565723	et	4	main
keelt	doc_399014257184_item	3565724	et	4	main
jah	doc_399014257184_item	3565725	et	3	main
keelt	doc_399014257184_item	3565756	et	4	main
lähen	doc_399014257184_item	3565758	et	3	main
kell	doc_399014257184_item	3565760	et	3	main
mina	doc_399014257184_item	3565775	et	4	main
taas	doc_399014257185_item	3565790	et	3	main
nad	doc_399014257185_item	3565794	et	3	main
setutena	doc_399014257185_item	3565796	et	4	main
nädal	doc_399014257185_item	3565797	et	3	main
keelt	doc_399014257185_item	3565805	et	4	main
külale	doc_399014257185_item	3565820	et	3	main
müüa	doc_399014257185_item	3565821	et	3	main
tänapäeval	doc_399014257185_item	3565823	et	3	main
setulased	doc_399014257185_item	3565824	et	4	main
ei	doc_399014257185_item	3565825	et	4	main
kägu-eestis	doc_399014257185_item	3565832	et	3	main
10	doc_399014257185_item	3565835	et	2	main
sõidavad	doc_399014257185_item	3565837	et	3	main
külalt	doc_399014257185_item	3565841	et	3	main
nahuvankeris	doc_399014257185_item	3565879	et	4	main
endistes	doc_399014257185_item	3565885	et	3	main
ei	doc_399014257185_item	3565929	et	4	main
kohta	doc_399014257185_item	3565932	et	4	main
siiski	doc_399014257185_item	3565933	et	4	main
mu	doc_399014257185_item	3565934	et	3	main
setulased	doc_399014257185_item	3565936	et	4	main
mina	doc_399014257184_item	3565700	et	4	main
koju	doc_399014257184_item	3565702	et	3	main
pool	doc_399014257184_item	3565704	et	4	main
mina	doc_399014257184_item	3565707	et	4	main
ärkan	doc_399014257184_item	3565708	et	3	main
kell	doc_399014257184_item	3565709	et	3	main
kümme	doc_399014257184_item	3565710	et	3	main
kell	doc_399014257184_item	3565711	et	3	main
hommikusööki	doc_399014257184_item	3565716	et	4	main
koju	doc_399014257184_item	3565730	et	3	main
kell	doc_399014257184_item	3565731	et	3	main
kussteist	doc_399014257184_item	3565732	et	4	main
reede	doc_399014257184_item	3565733	et	4	main
mina	doc_399014257184_item	3565734	et	4	main
ärkan	doc_399014257184_item	3565735	et	3	main
kell	doc_399014257184_item	3565736	et	3	main
käheksa	doc_399014257184_item	3565737	et	4	main
mina	doc_399014257184_item	3565738	et	4	main
ei	doc_399014257184_item	3565739	et	4	main
hommikusööki	doc_399014257184_item	3565741	et	4	main
sää	doc_399014257184_item	3565740	et	4	main
jah	doc_399014257184_item	3565742	et	3	main
mina	doc_399014257184_item	3565743	et	4	main
lähen	doc_399014257184_item	3565744	et	3	main
ülikooli	doc_399014257184_item	3565745	et	4	main
kolmveerand	doc_399014257184_item	3565746	et	4	main
üheksa	doc_399014257184_item	3565747	et	4	main
minu	doc_399014257184_item	3565748	et	3	main
kaks	doc_399014257184_item	3565749	et	3	main
loengud	doc_399014257184_item	3565750	et	3	main
seed	doc_399014257184_item	3565751	et	4	main
on	doc_399014257184_item	3565752	et	4	main
politika	doc_399014257184_item	3565753	et	4	main
jah	doc_399014257184_item	3565754	et	3	main
vene	doc_399014257184_item	3565755	et	4	main
kussteist	doc_399014257184_item	3565761	et	4	main
kell	doc_399014257184_item	3565769	et	3	main
mina	doc_399014257184_item	3565772	et	4	main
õpin	doc_399014257184_item	3565773	et	3	main
kodus	doc_399014257184_item	3565777	et	4	main
inimesed	doc_399014257185_item	3565787	et	3	main
setu	doc_399014257185_item	3565793	et	4	main
elavid	doc_399014257185_item	3565795	et	4	main
setulased	doc_399014257185_item	3565798	et	4	main
siiski	doc_399014257185_item	3565806	et	4	main
setulased	doc_399014257185_item	3565817	et	4	main
elab	doc_399014257185_item	3565831	et	3	main
umbes	doc_399014257185_item	3565834	et	4	main
meest	doc_399014257185_item	3565836	et	4	main
nad	doc_399014257185_item	3565882	et	3	main
peavad	doc_399014257185_item	3565883	et	4	main
lõpuks	doc_399014257185_item	3565887	et	4	main
jõudavad	doc_399014257185_item	3565889	et	4	main
tartus	doc_399014257185_item	3565890	et	3	main
ja	doc_399014257185_item	3565891	et	3	main
osa	doc_399014257185_item	3565892	et	4	main
tea	doc_399014257185_item	3565930	et	4	main
on	doc_399014257185_item	3565937	et	4	main
kummalised	doc_399014257185_item	3565938	et	3	main
sest	doc_399014257185_item	3565939	et	4	main
nad	doc_399014257185_item	3565940	et	3	main
priit	doc_399014257186_item	3565950	et	3	main
ta	doc_399014257186_item	3565972	et	4	main
rein	doc_399014257186_item	3565975	et	4	main
ta	doc_399014257186_item	3565977	et	4	main
töötas	doc_399014257186_item	3565978	et	3	main
ka	doc_399014257186_item	3565979	et	3	main
ja	doc_399014257186_item	3566009	et	3	main
e	doc_399014257186_item	3566011	et	4	main
priiti	doc_399014257186_item	3566013	et	4	main
pärni	doc_399014257186_item	3566014	et	4	main
ta	doc_399014257186_item	3566018	et	4	main
kasutab	doc_399014257186_item	3566019	et	3	main
imelikut	doc_399014257186_item	3566020	et	4	main
väga	doc_399014257186_item	3566025	et	3	main
kaasa	doc_399014257186_item	3566042	et	4	main
aitas	doc_399014257186_item	3566043	et	3	main
palju	doc_399014257186_item	3566044	et	4	main
arvestamata	doc_399014257186_item	3566071	et	4	main
vene	doc_399014257186_item	3566078	et	4	main
ei	doc_399014257186_item	3566082	et	4	main
võisime	doc_399014257186_item	3566088	et	3	main
kohtuda	doc_399014257186_item	3566089	et	3	main
priit	doc_399014257186_item	3566090	et	3	main
pärn	doc_399014257186_item	3566091	et	3	main
aga	doc_399014257186_item	3566092	et	3	main
näitleja	doc_399014257188_item	3566127	et	4	main
suurbritannias	doc_399014257188_item	3566138	et	4	main
tuhat	doc_399014257188_item	3566144	et	4	main
draamat	doc_399014257188_item	3566152	et	3	main
üheksakümmend	doc_399014257188_item	3566157	et	4	main
kolm	doc_399014257188_item	3566158	et	3	main
kaasa	doc_399014257188_item	3566164	et	4	main
varupaik	doc_399014257188_item	3566169	et	3	main
kuulus	doc_399014257188_item	3566186	et	4	main
ja	doc_399014257188_item	3566224	et	3	main
isamees	doc_399014257188_item	3566231	et	4	main
mõlemad	doc_399014257188_item	3566232	et	3	main
peggi	doc_399014257188_item	3566233	et	4	main
ema	doc_399014257188_item	3566234	et	4	main
ja	doc_399014257188_item	3566235	et	3	main
õe	doc_399014257188_item	3566236	et	4	main
lühikesti	doc_399014257188_item	3566237	et	4	main
ilmusid	doc_399014257188_item	3566238	et	4	main
spacedes	doc_399014257188_item	3566239	et	4	main
jõulud	doc_399014257189_item	3566247	et	3	main
väga	doc_399014257189_item	3566249	et	3	main
on	doc_399014257185_item	3565941	et	4	main
eestlast	doc_399014257185_item	3565942	et	4	main
aga	doc_399014257185_item	3565943	et	3	main
harrastavad	doc_399014257185_item	3565944	et	4	main
ortodoksiat	doc_399014257185_item	3565945	et	3	main
setos	doc_399014257185_item	3565780	et	4	main
filmi	doc_399014257185_item	3565784	et	4	main
setulased	doc_399014257185_item	3565788	et	4	main
elavad	doc_399014257185_item	3565799	et	4	main
nad	doc_399014257185_item	3565802	et	3	main
aastatel	doc_399014257185_item	3565816	et	4	main
ole	doc_399014257185_item	3565826	et	4	main
setulasi	doc_399014257185_item	3565830	et	4	main
filmis	doc_399014257185_item	3565833	et	4	main
tartusse	doc_399014257185_item	3565842	et	3	main
nad	doc_399014257185_item	3565843	et	3	main
söövad	doc_399014257185_item	3565844	et	4	main
kalat	doc_399014257185_item	3565845	et	4	main
ja	doc_399014257185_item	3565846	et	3	main
joovad	doc_399014257185_item	3565847	et	4	main
õlut	doc_399014257185_item	3565848	et	3	main
nad	doc_399014257185_item	3565849	et	3	main
samuti	doc_399014257185_item	3565850	et	3	main
laulavad	doc_399014257185_item	3565851	et	4	main
aga	doc_399014257185_item	3565852	et	3	main
nad	doc_399014257185_item	3565853	et	3	main
laulavad	doc_399014257185_item	3565854	et	4	main
vaga	doc_399014257185_item	3565855	et	4	main
halvasti	doc_399014257185_item	3565856	et	3	main
nad	doc_399014257185_item	3565857	et	3	main
külastuvad	doc_399014257185_item	3565858	et	4	main
palju	doc_399014257185_item	3565859	et	4	main
külu	doc_399014257185_item	3565860	et	4	main
ja	doc_399014257185_item	3565861	et	3	main
müüvad	doc_399014257185_item	3565862	et	4	main
pottsepatöökodat	doc_399014257185_item	3565863	et	4	main
öödel	doc_399014257185_item	3565864	et	3	main
nad	doc_399014257185_item	3565865	et	3	main
püüdavad	doc_399014257185_item	3565866	et	4	main
inimest	doc_399014257185_item	3565867	et	3	main
kui	doc_399014257185_item	3565868	et	3	main
nad	doc_399014257185_item	3565869	et	3	main
luhavad	doc_399014257185_item	3565870	et	4	main
laageris	doc_399014257185_item	3565871	et	3	main
olla	doc_399014257185_item	3565872	et	3	main
nende	doc_399014257185_item	3565873	et	4	main
eramaal	doc_399014257185_item	3565874	et	4	main
mõnikord	doc_399014257185_item	3565875	et	3	main
nad	doc_399014257185_item	3565876	et	3	main
magavad	doc_399014257185_item	3565877	et	4	main
magada	doc_399014257185_item	3565884	et	3	main
võtavad	doc_399014257185_item	3565893	et	3	main
festivalis	doc_399014257185_item	3565894	et	3	main
teised	doc_399014257185_item	3565895	et	4	main
sõidavad	doc_399014257185_item	3565896	et	3	main
ka	doc_399014257185_item	3565897	et	3	main
setulastega	doc_399014257185_item	3565898	et	3	main
aga	doc_399014257185_item	3565899	et	3	main
sõidavad	doc_399014257185_item	3565900	et	3	main
autotega	doc_399014257185_item	3565901	et	4	main
nad	doc_399014257185_item	3565902	et	3	main
on	doc_399014257185_item	3565903	et	4	main
naist	doc_399014257185_item	3565904	et	3	main
setulaste	doc_399014257185_item	3565905	et	4	main
ja	doc_399014257185_item	3565906	et	3	main
nad	doc_399014257185_item	3565907	et	3	main
räägivad	doc_399014257185_item	3565908	et	3	main
nende	doc_399014257185_item	3565909	et	4	main
meeste	doc_399014257185_item	3565910	et	4	main
kohta	doc_399014257185_item	3565911	et	4	main
vestlusi	doc_399014257185_item	3565912	et	3	main
naine	doc_399014257185_item	3565913	et	3	main
räägib	doc_399014257185_item	3565914	et	3	main
et	doc_399014257185_item	3565915	et	3	main
eestlased	doc_399014257185_item	3565916	et	3	main
ei	doc_399014257185_item	3565917	et	4	main
armasta	doc_399014257185_item	3565918	et	4	main
setulast	doc_399014257185_item	3565919	et	4	main
sest	doc_399014257185_item	3565920	et	4	main
nad	doc_399014257185_item	3565921	et	3	main
on	doc_399014257185_item	3565922	et	4	main
venelastena	doc_399014257185_item	3565923	et	4	main
film	doc_399014257185_item	3565924	et	3	main
oli	doc_399014257185_item	3565925	et	3	main
autotes	doc_399014257185_item	3565886	et	4	main
nad	doc_399014257185_item	3565888	et	3	main
meelest	doc_399014257185_item	3565935	et	4	main
essee	doc_399014257186_item	3565947	et	4	main
tallinnas	doc_399014257186_item	3565960	et	4	main
noorena	doc_399014257186_item	3565961	et	3	main
ta	doc_399014257186_item	3565962	et	4	main
töötas	doc_399014257186_item	3565963	et	3	main
ökolooguna	doc_399014257186_item	3565964	et	4	main
aga	doc_399014257186_item	3565965	et	3	main
kui	doc_399014257186_item	3565971	et	3	main
filmid	doc_399014257186_item	3566012	et	4	main
siiski	doc_399014257186_item	3566022	et	4	main
tal	doc_399014257186_item	3566023	et	3	main
on	doc_399014257186_item	3566024	et	4	main
ka	doc_399014257186_item	3566031	et	3	main
eestis	doc_399014257186_item	3566034	et	3	main
peal	doc_399014257186_item	3566074	et	4	main
see	doc_399014257186_item	3566075	et	3	main
alapealkiri	doc_399014257186_item	3566079	et	3	main
filmid	doc_399014257186_item	3566086	et	4	main
me	doc_399014257186_item	3566087	et	4	main
ei	doc_399014257186_item	3566094	et	4	main
koomik	doc_399014257188_item	3566128	et	3	main
ja	doc_399014257188_item	3566129	et	3	main
ta	doc_399014257188_item	3566139	et	4	main
on	doc_399014257188_item	3566140	et	4	main
seitsekümmend	doc_399014257188_item	3566146	et	4	main
ja	doc_399014257188_item	3566153	et	3	main
lõpetanud	doc_399014257188_item	3566154	et	4	main
televisiooni	doc_399014257188_item	3566160	et	4	main
esines	doc_399014257188_item	3566161	et	3	main
palju	doc_399014257188_item	3566162	et	4	main
korda	doc_399014257188_item	3566163	et	4	main
on	doc_399014257188_item	3566175	et	4	main
on	doc_399014257188_item	3566184	et	4	main
huvitav	doc_399014257185_item	3565926	et	4	main
sest	doc_399014257185_item	3565927	et	4	main
ma	doc_399014257185_item	3565928	et	3	main
pärn	doc_399014257186_item	3565949	et	3	main
on	doc_399014257186_item	3565952	et	4	main
eesti	doc_399014257186_item	3565954	et	4	main
direktor	doc_399014257186_item	3565955	et	3	main
ta	doc_399014257186_item	3565956	et	4	main
sündis	doc_399014257186_item	3565957	et	3	main
26	doc_399014257186_item	3565958	et	2	main
augustil	doc_399014257186_item	3565959	et	3	main
ta	doc_399014257186_item	3565966	et	4	main
hakkas	doc_399014257186_item	3565967	et	3	main
hakkas	doc_399014257186_item	3565973	et	3	main
lühikest	doc_399014257186_item	3565982	et	4	main
ja	doc_399014257186_item	3565983	et	3	main
tema	doc_399014257186_item	3565984	et	4	main
esimine	doc_399014257186_item	3565985	et	4	main
film	doc_399014257186_item	3565986	et	3	main
kirjastas	doc_399014257186_item	3565987	et	3	main
näiteks	doc_399014257186_item	3566004	et	4	main
kolmnurk	doc_399014257186_item	3566005	et	3	main
hommikusöök	doc_399014257186_item	3566006	et	3	main
on	doc_399014257186_item	3566015	et	4	main
sest	doc_399014257186_item	3566017	et	4	main
unikaalne	doc_399014257186_item	3566026	et	3	main
auhind	doc_399014257186_item	3566039	et	3	main
ma	doc_399014257186_item	3566046	et	3	main
filmis	doc_399014257186_item	3566076	et	4	main
oli	doc_399014257186_item	3566077	et	3	main
simon	doc_399014257188_item	3566124	et	4	main
ta	doc_399014257188_item	3566131	et	4	main
ja	doc_399014257188_item	3566134	et	3	main
väga	doc_399014257188_item	3566135	et	3	main
sündinud	doc_399014257188_item	3566141	et	4	main
gloucestoris	doc_399014257188_item	3566147	et	4	main
ülikoolis	doc_399014257188_item	3566151	et	4	main
spaced	doc_399014257188_item	3566166	et	4	main
suur	doc_399014257188_item	3566167	et	3	main
mustad	doc_399014257188_item	3566171	et	4	main
enne	doc_399014257188_item	3566173	et	4	main
komöödia	doc_399014257188_item	3566177	et	4	main
londons	doc_399014257188_item	3566178	et	4	main
ja	doc_399014257188_item	3566179	et	3	main
töötas	doc_399014257188_item	3566180	et	3	main
raadios	doc_399014257188_item	3566181	et	3	main
praegu	doc_399014257188_item	3566182	et	3	main
ta	doc_399014257188_item	3566183	et	4	main
olema	doc_399014257188_item	3566187	et	4	main
oma	doc_399014257188_item	3566188	et	4	main
minu	doc_399014257189_item	3566246	et	3	main
oli	doc_399014257189_item	3566248	et	3	main
vaikne	doc_399014257189_item	3566250	et	3	main
läksin	doc_399014257189_item	3566255	et	3	main
ema	doc_399014257189_item	3566257	et	4	main
majja	doc_399014257189_item	3566258	et	3	main
ma	doc_399014257189_item	3566259	et	3	main
vaatasin	doc_399014257189_item	3566260	et	3	main
jõulud-tv	doc_399014257189_item	3566261	et	4	main
oli	doc_399014257189_item	3566275	et	3	main
me	doc_399014257189_item	3566277	et	4	main
äru	doc_399014257189_item	3566283	et	4	main
arvama	doc_399014257189_item	3566284	et	3	main
me	doc_399014257189_item	3566320	et	4	main
vahetasime	doc_399014257189_item	3566321	et	3	main
lõunasöök	doc_399014257189_item	3566326	et	3	main
oli	doc_399014257189_item	3566328	et	3	main
aga	doc_399014257189_item	3566330	et	3	main
söövisin	doc_399014257189_item	3566332	et	4	main
liiga	doc_399014257189_item	3566333	et	4	main
palju	doc_399014257189_item	3566334	et	4	main
ja	doc_399014257189_item	3566335	et	3	main
tundusin	doc_399014257189_item	3566336	et	3	main
rohkem	doc_399014257189_item	3566346	et	4	main
kinks	doc_399014257189_item	3566347	et	4	main
siis	doc_399014257189_item	3566351	et	3	main
üksteist	doc_399014257189_item	3566354	et	4	main
oma	doc_399014257189_item	3566357	et	4	main
majja	doc_399014257189_item	3566358	et	3	main
minu	doc_399014257189_item	3566359	et	3	main
uut	doc_399014257189_item	3566360	et	3	main
aastat	doc_399014257189_item	3566361	et	3	main
räägi	doc_399014257186_item	3566095	et	4	main
temaga	doc_399014257186_item	3566096	et	3	main
ma	doc_399014257186_item	3566097	et	3	main
ei	doc_399014257186_item	3566098	et	4	main
tea	doc_399014257186_item	3566099	et	4	main
palju	doc_399014257186_item	3566100	et	4	main
elustasi	doc_399014257186_item	3566101	et	4	main
kohta	doc_399014257186_item	3566102	et	4	main
aga	doc_399014257186_item	3566103	et	3	main
ma	doc_399014257186_item	3566104	et	3	main
õpin	doc_399014257186_item	3566105	et	3	main
eesti	doc_399014257186_item	3566106	et	4	main
keelt	doc_399014257186_item	3566107	et	4	main
sellepärast	doc_399014257186_item	3566108	et	3	main
ma	doc_399014257186_item	3566109	et	3	main
mõtlen	doc_399014257186_item	3566110	et	3	main
et	doc_399014257186_item	3566111	et	3	main
ma	doc_399014257186_item	3566112	et	3	main
pean	doc_399014257186_item	3566113	et	4	main
vaatama	doc_399014257186_item	3566114	et	3	main
palju	doc_399014257186_item	3566115	et	4	main
eeste	doc_399014257186_item	3566116	et	4	main
filme	doc_399014257186_item	3566117	et	3	main
sest	doc_399014257186_item	3566118	et	4	main
ma	doc_399014257186_item	3566119	et	3	main
õpin	doc_399014257186_item	3566120	et	3	main
nendest	doc_399014257186_item	3566121	et	4	main
priit	doc_399014257186_item	3565948	et	3	main
oma	doc_399014257186_item	3565968	et	4	main
karjäär	doc_399014257186_item	3565969	et	3	main
töötada	doc_399014257186_item	3565974	et	3	main
raamatuga	doc_399014257186_item	3565976	et	4	main
joonis	doc_399014257186_item	3565980	et	4	main
filmiga	doc_399014257186_item	3565981	et	3	main
tänapäeval	doc_399014257186_item	3565988	et	3	main
me	doc_399014257186_item	3565989	et	4	main
kaalutleme	doc_399014257186_item	3565990	et	3	main
priit	doc_399014257186_item	3565991	et	3	main
pärn	doc_399014257186_item	3565992	et	3	main
kõige	doc_399014257186_item	3565993	et	4	main
kuulusam	doc_399014257186_item	3565994	et	4	main
direktor	doc_399014257186_item	3565995	et	3	main
alla	doc_399014257186_item	3565996	et	3	main
priit	doc_399014257186_item	3565997	et	3	main
pärn	doc_399014257186_item	3565998	et	3	main
on	doc_399014257186_item	3565999	et	4	main
juhatanud	doc_399014257186_item	3566000	et	4	main
palju	doc_399014257186_item	3566001	et	4	main
kuulusi	doc_399014257186_item	3566002	et	3	main
filme	doc_399014257186_item	3566003	et	3	main
kuulus	doc_399014257186_item	3565953	et	4	main
elustasis	doc_399014257186_item	3565970	et	4	main
rohi	doc_399014257186_item	3566007	et	4	main
hotell	doc_399014257186_item	3566010	et	3	main
elustast	doc_399014257186_item	3566021	et	4	main
stiil	doc_399014257186_item	3566027	et	3	main
ta	doc_399014257186_item	3566029	et	4	main
väga	doc_399014257186_item	3566032	et	3	main
mõjukas	doc_399014257186_item	3566033	et	4	main
valismaal	doc_399014257186_item	3566036	et	4	main
elustasisse	doc_399014257186_item	3566045	et	4	main
vaatasin	doc_399014257186_item	3566047	et	3	main
umbes	doc_399014257186_item	3566048	et	4	main
neli	doc_399014257186_item	3566049	et	3	main
filmi	doc_399014257186_item	3566050	et	4	main
priit	doc_399014257186_item	3566051	et	3	main
pärnilt	doc_399014257186_item	3566052	et	4	main
sel	doc_399014257186_item	3566053	et	3	main
aastal	doc_399014257186_item	3566054	et	3	main
ma	doc_399014257186_item	3566055	et	3	main
läksin	doc_399014257186_item	3566056	et	3	main
kui	doc_399014257186_item	3566058	et	3	main
vaadata	doc_399014257186_item	3566059	et	4	main
edinburgisse	doc_399014257186_item	3566057	et	4	main
teda	doc_399014257186_item	3566060	et	4	main
ja	doc_399014257186_item	3566061	et	3	main
tema	doc_399014257186_item	3566062	et	4	main
filme	doc_399014257186_item	3566063	et	3	main
ma	doc_399014257186_item	3566064	et	3	main
ei	doc_399014257186_item	3566065	et	4	main
mäleta	doc_399014257186_item	3566066	et	4	main
millised	doc_399014257186_item	3566067	et	3	main
filmed	doc_399014257186_item	3566068	et	4	main
me	doc_399014257186_item	3566069	et	4	main
peal	doc_399014257186_item	3566008	et	4	main
märkimisväärne	doc_399014257186_item	3566016	et	3	main
ja	doc_399014257186_item	3566028	et	3	main
on	doc_399014257186_item	3566030	et	4	main
ja	doc_399014257186_item	3566035	et	3	main
ta	doc_399014257186_item	3566037	et	4	main
võitas	doc_399014257186_item	3566038	et	3	main
sest	doc_399014257186_item	3566040	et	4	main
ta	doc_399014257186_item	3566041	et	4	main
hommikusöök	doc_399014257186_item	3566072	et	3	main
rohi	doc_399014257186_item	3566073	et	4	main
aga	doc_399014257186_item	3566080	et	3	main
ma	doc_399014257186_item	3566081	et	3	main
tea	doc_399014257186_item	3566083	et	4	main
miks	doc_399014257186_item	3566084	et	4	main
ma	doc_399014257186_item	3566093	et	3	main
vaatasime	doc_399014257186_item	3566070	et	3	main
pärast	doc_399014257186_item	3566085	et	4	main
essee	doc_399014257188_item	3566123	et	4	main
pegg	doc_399014257188_item	3566125	et	4	main
kirjanik	doc_399014257188_item	3566130	et	3	main
on	doc_399014257188_item	3566132	et	4	main
inglise	doc_399014257188_item	3566133	et	4	main
tunnev	doc_399014257188_item	3566136	et	4	main
inimene	doc_399014257188_item	3566137	et	3	main
neliteistkünendal	doc_399014257188_item	3566142	et	4	main
veebruaril	doc_399014257188_item	3566143	et	3	main
ta	doc_399014257188_item	3566148	et	4	main
õppis	doc_399014257188_item	3566149	et	3	main
ta	doc_399014257188_item	3566159	et	4	main
arvam	doc_399014257188_item	3566165	et	4	main
ja	doc_399014257188_item	3566170	et	3	main
teostanud	doc_399014257188_item	3566176	et	4	main
kõige	doc_399014257188_item	3566185	et	4	main
peggaga	doc_399014257188_item	3566223	et	4	main
kes	doc_399014257188_item	3566225	et	4	main
on	doc_399014257188_item	3566226	et	4	main
ka	doc_399014257188_item	3566227	et	3	main
väga	doc_399014257188_item	3566228	et	3	main
naljakas	doc_399014257188_item	3566229	et	4	main
oli	doc_399014257188_item	3566230	et	3	main
essee	doc_399014257189_item	3566241	et	4	main
ja	doc_399014257189_item	3566243	et	3	main
ma	doc_399014257189_item	3566254	et	3	main
me	doc_399014257189_item	3566281	et	4	main
meheõde	doc_399014257189_item	3566313	et	4	main
kaks	doc_399014257189_item	3566314	et	3	main
vennapoeg	doc_399014257189_item	3566315	et	3	main
olid	doc_399014257189_item	3566318	et	4	main
seal	doc_399014257189_item	3566319	et	4	main
jõulud	doc_399014257189_item	3566325	et	3	main
natuke	doc_399014257189_item	3566337	et	4	main
kinkisin	doc_399014257189_item	3566344	et	3	main
jahisaaki	doc_399014257189_item	3566350	et	4	main
kell	doc_399014257189_item	3566353	et	3	main
ma	doc_399014257189_item	3566355	et	3	main
läksin	doc_399014257189_item	3566356	et	3	main
schwimmeraga	doc_399014257188_item	3566204	et	4	main
pegg	doc_399014257188_item	3566205	et	4	main
abiellus	doc_399014257188_item	3566206	et	3	main
maureen	doc_399014257188_item	3566207	et	4	main
mccanniga	doc_399014257188_item	3566208	et	4	main
glasgows	doc_399014257188_item	3566209	et	4	main
tuhandes	doc_399014257188_item	3566210	et	4	main
viiendas	doc_399014257188_item	3566211	et	3	main
aastas	doc_399014257188_item	3566212	et	3	main
ja	doc_399014257188_item	3566213	et	3	main
nick	doc_399014257188_item	3566214	et	4	main
frost	doc_399014257188_item	3566215	et	4	main
kes	doc_399014257188_item	3566216	et	4	main
on	doc_399014257188_item	3566217	et	4	main
ilmunud	doc_399014257188_item	3566218	et	4	main
palju	doc_399014257188_item	3566219	et	4	main
meelelahutussaades	doc_399014257188_item	3566220	et	4	main
ja	doc_399014257188_item	3566221	et	3	main
filmas	doc_399014257188_item	3566222	et	4	main
on	doc_399014257188_item	3566126	et	4	main
üheksasada	doc_399014257188_item	3566145	et	4	main
bristols	doc_399014257188_item	3566150	et	4	main
tuhat	doc_399014257188_item	3566155	et	4	main
üheksasada	doc_399014257188_item	3566156	et	4	main
rongi	doc_399014257188_item	3566168	et	4	main
raamatud	doc_399014257188_item	3566172	et	4	main
ta	doc_399014257188_item	3566174	et	4	main
filmaks	doc_399014257188_item	3566189	et	4	main
shaun	doc_399014257188_item	3566190	et	4	main
surnu	doc_399014257188_item	3566191	et	4	main
ja	doc_399014257188_item	3566192	et	3	main
populaarne	doc_399014257188_item	3566193	et	3	main
saama	doc_399014257188_item	3566194	et	4	main
ameerikas	doc_399014257188_item	3566195	et	4	main
kui	doc_399014257188_item	3566196	et	3	main
pärast	doc_399014257188_item	3566197	et	4	main
ilmus	doc_399014257188_item	3566198	et	4	main
film	doc_399014257188_item	3566199	et	3	main
tom	doc_399014257188_item	3566200	et	4	main
cruisega	doc_399014257188_item	3566201	et	4	main
ja	doc_399014257188_item	3566202	et	3	main
david	doc_399014257188_item	3566203	et	4	main
jõulud	doc_399014257189_item	3566242	et	3	main
aastat	doc_399014257189_item	3566245	et	3	main
jõululaupäev	doc_399014257189_item	3566253	et	3	main
jõulud	doc_399014257189_item	3566268	et	3	main
et	doc_399014257189_item	3566270	et	3	main
meelde	doc_399014257189_item	3566272	et	3	main
laps	doc_399014257189_item	3566276	et	4	main
mängisme	doc_399014257189_item	3566278	et	4	main
jahisaak	doc_399014257189_item	3566279	et	3	main
ka	doc_399014257189_item	3566280	et	3	main
laul	doc_399014257189_item	3566285	et	4	main
vennatütar	doc_399014257189_item	3566317	et	3	main
söömasime	doc_399014257189_item	3566324	et	4	main
õhtul	doc_399014257189_item	3566339	et	3	main
uut	doc_399014257189_item	3566244	et	3	main
lõõgastav	doc_399014257189_item	3566252	et	4	main
oma	doc_399014257189_item	3566256	et	4	main
emaga	doc_399014257189_item	3566262	et	3	main
ja	doc_399014257189_item	3566263	et	3	main
õega	doc_399014257189_item	3566264	et	3	main
mulle	doc_399014257189_item	3566265	et	4	main
meeldib	doc_399014257189_item	3566266	et	3	main
tv	doc_399014257189_item	3566269	et	4	main
see	doc_399014257189_item	3566271	et	3	main
tuletama	doc_399014257189_item	3566273	et	3	main
ma	doc_399014257189_item	3566274	et	3	main
peasime	doc_399014257189_item	3566282	et	4	main
laserplaatilt	doc_399014257189_item	3566286	et	4	main
ma	doc_399014257189_item	3566287	et	3	main
kaotasin	doc_399014257189_item	3566288	et	3	main
hommikujõulud	doc_399014257189_item	3566289	et	3	main
ma	doc_399014257189_item	3566290	et	3	main
läks	doc_399014257189_item	3566291	et	3	main
oma	doc_399014257189_item	3566292	et	4	main
isa	doc_399014257189_item	3566293	et	4	main
majja	doc_399014257189_item	3566294	et	3	main
me	doc_399014257189_item	3566295	et	4	main
vahetasime	doc_399014257189_item	3566296	et	3	main
kinks	doc_399014257189_item	3566297	et	4	main
ja	doc_399014257189_item	3566298	et	3	main
söömasime	doc_399014257189_item	3566299	et	4	main
hommikusöök	doc_399014257189_item	3566300	et	3	main
siis	doc_399014257189_item	3566301	et	3	main
ma	doc_399014257189_item	3566302	et	3	main
läksin	doc_399014257189_item	3566303	et	3	main
taga	doc_399014257189_item	3566304	et	4	main
oma	doc_399014257189_item	3566305	et	4	main
ema	doc_399014257189_item	3566306	et	4	main
majja	doc_399014257189_item	3566307	et	3	main
mu	doc_399014257189_item	3566308	et	3	main
kaks	doc_399014257189_item	3566309	et	3	main
õd	doc_399014257189_item	3566310	et	4	main
ja	doc_399014257189_item	3566251	et	3	main
vaatama	doc_399014257189_item	3566267	et	3	main
ja	doc_399014257189_item	3566316	et	3	main
see	doc_399014257189_item	3566327	et	3	main
hiilgav	doc_399014257189_item	3566329	et	4	main
ma	doc_399014257189_item	3566331	et	3	main
ma	doc_399014257189_item	3566340	et	3	main
olnud	doc_399014257189_item	3566363	et	4	main
niivaikne	doc_399014257189_item	3566364	et	3	main
ma	doc_399014257189_item	3566365	et	3	main
läksin	doc_399014257189_item	3566366	et	3	main
saada	doc_399014257190_item	3566399	et	4	main
reisi	doc_399014257190_item	3566410	et	4	main
kooli	doc_399014257190_item	3566417	et	4	main
juhtimine	doc_399014257190_item	3566423	et	4	main
ma	doc_399014257190_item	3566429	et	3	main
kiiresti	doc_399014257190_item	3566432	et	3	main
ja	doc_399014257190_item	3566434	et	3	main
mida	doc_399014257191_item	3566488	et	4	main
päevitatakse	doc_399014257191_item	3566497	et	3	main
suvel	doc_399014257191_item	3566499	et	3	main
sõbrega	doc_399014257191_item	3566518	et	4	main
ja	doc_399014257191_item	3566519	et	3	main
tolknema	doc_399014257191_item	3566520	et	3	main
ei	doc_399014257191_item	3566527	et	4	main
šotimaal	doc_399014257191_item	3566534	et	2	main
sõidetakse	doc_399014257191_item	3566538	et	3	main
palju	doc_399014257191_item	3566544	et	4	main
armastan	doc_399014257191_item	3566547	et	3	main
palju	doc_399014257191_item	3566561	et	4	main
on	doc_399014257191_item	3566576	et	4	main
palju	doc_399014257191_item	3566583	et	4	main
t	doc_399014257191_item	3566586	et	4	main
vend	doc_399014257189_item	3566311	et	3	main
mehevend	doc_399014257189_item	3566312	et	3	main
kinks	doc_399014257189_item	3566322	et	4	main
siis	doc_399014257189_item	3566323	et	3	main
haige	doc_399014257189_item	3566338	et	4	main
riietusin	doc_399014257189_item	3566341	et	3	main
ja	doc_399014257189_item	3566343	et	3	main
laps	doc_399014257189_item	3566345	et	4	main
me	doc_399014257189_item	3566348	et	4	main
ma	doc_399014257190_item	3566401	et	3	main
kooli	doc_399014257190_item	3566402	et	4	main
tahaksin	doc_399014257190_item	3566404	et	3	main
või	doc_399014257190_item	3566407	et	4	main
midagi	doc_399014257190_item	3566408	et	4	main
kaasnema	doc_399014257190_item	3566409	et	3	main
kooliks	doc_399014257190_item	3566413	et	4	main
ülikoolis	doc_399014257190_item	3566424	et	4	main
ja	doc_399014257191_item	3566496	et	3	main
šotimaal	doc_399014257191_item	3566500	et	2	main
palju	doc_399014257191_item	3566524	et	4	main
suvel	doc_399014257191_item	3566533	et	3	main
ka	doc_399014257191_item	3566536	et	3	main
kaugetesse	doc_399014257191_item	3566539	et	4	main
ja	doc_399014257191_item	3566541	et	3	main
no	doc_399014257191_item	3566542	et	3	main
alkoholi	doc_399014257191_item	3566545	et	4	main
sõitma	doc_399014257191_item	3566548	et	3	main
ma	doc_399014257191_item	3566550	et	3	main
prantsusmaasse	doc_399014257191_item	3566552	et	3	main
hiinasse	doc_399014257191_item	3566556	et	4	main
lätisse	doc_399014257191_item	3566558	et	4	main
minnakse	doc_399014257191_item	3566566	et	3	main
see	doc_399014257191_item	3566570	et	3	main
suurem	doc_399014257191_item	3566572	et	4	main
festival	doc_399014257191_item	3566573	et	3	main
muusika	doc_399014257191_item	3566574	et	4	main
šotimaas	doc_399014257191_item	3566575	et	2	main
ja	doc_399014257192_item	3566601	et	3	main
pean	doc_399014257192_item	3566604	et	4	main
ilmast	doc_399014257192_item	3566606	et	4	main
kui	doc_399014257192_item	3566607	et	3	main
ma	doc_399014257192_item	3566608	et	3	main
kirjutan	doc_399014257192_item	3566609	et	3	main
glasgow	doc_399014257192_item	3566610	et	4	main
ilmast	doc_399014257192_item	3566611	et	4	main
aeg	doc_399014257192_item	3566624	et	3	main
sajab	doc_399014257192_item	3566625	et	3	main
vahel	doc_399014257192_item	3566636	et	4	main
väga	doc_399014257192_item	3566639	et	3	main
talvena	doc_399014257192_item	3566702	et	4	main
kauplustes	doc_399014257193_item	3566720	et	4	main
ole	doc_399014257193_item	3566727	et	4	main
segakauplusete	doc_399014257193_item	3566735	et	4	main
ma	doc_399014257193_item	3566739	et	3	main
kolm	doc_399014257193_item	3566741	et	3	main
grammi	doc_399014257193_item	3566747	et	4	main
muna	doc_399014257193_item	3566752	et	4	main
üks	doc_399014257193_item	3566753	et	3	main
purk	doc_399014257193_item	3566754	et	3	main
üks	doc_399014257193_item	3566766	et	3	main
toober	doc_399014257193_item	3566767	et	3	main
jäätist	doc_399014257193_item	3566768	et	3	main
cd	doc_399014257193_item	3566816	et	4	main
ja	doc_399014257193_item	3566817	et	3	main
filmad	doc_399014257193_item	3566818	et	4	main
mul	doc_399014257193_item	3566819	et	3	main
on	doc_399014257193_item	3566820	et	4	main
tahtma	doc_399014257193_item	3566826	et	3	main
tere	doc_399014257194_item	3566832	et	3	main
ma	doc_399014257194_item	3566836	et	3	main
uuriminet	doc_399014257194_item	3566843	et	4	main
ma	doc_399014257194_item	3566844	et	3	main
glasgows	doc_399014257194_item	3566847	et	4	main
aastat	doc_399014257194_item	3566850	et	3	main
mu	doc_399014257194_item	3566851	et	3	main
pool	doc_399014257194_item	3566870	et	4	main
suhkur	doc_399014257194_item	3566877	et	3	main
eesti	doc_399014257194_item	3566890	et	4	main
loengusse	doc_399014257194_item	3566892	et	4	main
loeng	doc_399014257194_item	3566914	et	3	main
raamatukokku	doc_399014257194_item	3566922	et	4	main
ma	doc_399014257194_item	3566934	et	3	main
jõuluvanana	doc_399014257189_item	3566342	et	3	main
mängisme	doc_399014257189_item	3566349	et	4	main
ja	doc_399014257189_item	3566352	et	3	main
pubisse	doc_399014257189_item	3566367	et	4	main
sõbraga	doc_399014257189_item	3566368	et	3	main
ja	doc_399014257189_item	3566369	et	3	main
kell	doc_399014257189_item	3566370	et	3	main
pool	doc_399014257189_item	3566371	et	4	main
kaksteist	doc_399014257189_item	3566372	et	4	main
me	doc_399014257189_item	3566373	et	4	main
läksime	doc_399014257189_item	3566374	et	3	main
klubisse	doc_399014257189_item	3566375	et	3	main
millegi	doc_399014257189_item	3566376	et	4	main
uut	doc_399014257189_item	3566377	et	3	main
aastat	doc_399014257189_item	3566378	et	3	main
me	doc_399014257189_item	3566379	et	4	main
juuasime	doc_399014257189_item	3566380	et	4	main
palju	doc_399014257189_item	3566381	et	4	main
ja	doc_399014257189_item	3566382	et	3	main
see	doc_399014257189_item	3566383	et	3	main
oli	doc_399014257189_item	3566384	et	3	main
rohkesti	doc_399014257189_item	3566385	et	3	main
lõbus	doc_399014257189_item	3566386	et	4	main
aga	doc_399014257189_item	3566387	et	3	main
ma	doc_399014257189_item	3566388	et	3	main
oli	doc_399014257189_item	3566389	et	3	main
pohmell	doc_399014257189_item	3566390	et	4	main
kahe	doc_399014257189_item	3566391	et	3	main
päeva	doc_399014257189_item	3566392	et	4	main
jooksul	doc_399014257189_item	3566393	et	4	main
essee	doc_399014257190_item	3566395	et	4	main
ma	doc_399014257190_item	3566397	et	3	main
ma	doc_399014257190_item	3566411	et	3	main
sõitasin	doc_399014257190_item	3566416	et	4	main
ragbimeeskondiga	doc_399014257190_item	3566418	et	4	main
aga	doc_399014257190_item	3566419	et	3	main
ma	doc_399014257190_item	3566420	et	3	main
osastasin	doc_399014257190_item	3566421	et	3	main
õppisin	doc_399014257190_item	3566422	et	3	main
miks	doc_399014257190_item	3566428	et	4	main
veidi	doc_399014257190_item	3566435	et	3	main
aasta	doc_399014257190_item	3566473	et	4	main
see	doc_399014257190_item	3566474	et	3	main
ei	doc_399014257189_item	3566362	et	4	main
kelleks	doc_399014257190_item	3566396	et	4	main
tahan	doc_399014257190_item	3566398	et	3	main
lõpetasin	doc_399014257190_item	3566403	et	3	main
töötada	doc_399014257190_item	3566405	et	3	main
kirjutasin	doc_399014257190_item	3566412	et	3	main
ja	doc_399014257190_item	3566415	et	3	main
ma	doc_399014257190_item	3566425	et	3	main
tea	doc_399014257190_item	3566427	et	4	main
kurssu	doc_399014257190_item	3566431	et	4	main
poliitaks	doc_399014257190_item	3566433	et	4	main
essee	doc_399014257191_item	3566487	et	4	main
tehakse	doc_399014257191_item	3566489	et	3	main
šotimaal	doc_399014257191_item	3566491	et	2	main
suvel	doc_399014257191_item	3566492	et	3	main
minnakse	doc_399014257191_item	3566494	et	3	main
natuke	doc_399014257191_item	3566498	et	4	main
rannaid	doc_399014257191_item	3566525	et	4	main
no	doc_399014257191_item	3566526	et	3	main
rannaid	doc_399014257191_item	3566530	et	4	main
jooakse	doc_399014257191_item	3566543	et	4	main
maadesse	doc_399014257191_item	3566549	et	4	main
iirimasse	doc_399014257191_item	3566553	et	3	main
teine	doc_399014257191_item	3566562	et	3	main
maaid	doc_399014257191_item	3566563	et	4	main
suvel	doc_399014257191_item	3566564	et	3	main
ka	doc_399014257191_item	3566567	et	3	main
kõige	doc_399014257191_item	3566571	et	4	main
in	doc_399014257191_item	3566578	et	4	main
the	doc_399014257191_item	3566579	et	4	main
park	doc_399014257191_item	3566580	et	3	main
t	doc_399014257191_item	3566581	et	4	main
parkis	doc_399014257191_item	3566582	et	3	main
minnavad	doc_399014257191_item	3566585	et	4	main
in	doc_399014257191_item	3566587	et	4	main
the	doc_399014257191_item	3566588	et	4	main
park	doc_399014257191_item	3566589	et	3	main
ja	doc_399014257191_item	3566590	et	3	main
umbes	doc_399014257191_item	3566591	et	4	main
kuus	doc_399014257191_item	3566592	et	4	main
tuhat	doc_399014257191_item	3566593	et	4	main
inimese	doc_399014257191_item	3566594	et	4	main
minema	doc_399014257191_item	3566595	et	3	main
iga	doc_399014257191_item	3566596	et	4	main
aasta	doc_399014257191_item	3566597	et	4	main
ma	doc_399014257192_item	3566603	et	3	main
ainult	doc_399014257192_item	3566612	et	4	main
see	doc_399014257192_item	3566613	et	3	main
oleks	doc_399014257192_item	3566614	et	3	main
väga	doc_399014257192_item	3566615	et	3	main
küll	doc_399014257192_item	3566617	et	4	main
külm	doc_399014257192_item	3566630	et	3	main
aeg	doc_399014257192_item	3566632	et	3	main
aga	doc_399014257192_item	3566637	et	3	main
ei	doc_399014257192_item	3566638	et	4	main
kena	doc_399014257192_item	3566643	et	4	main
ilm	doc_399014257192_item	3566644	et	3	main
suvel	doc_399014257192_item	3566645	et	3	main
aga	doc_399014257192_item	3566646	et	3	main
suvi	doc_399014257192_item	3566647	et	3	main
ei	doc_399014257192_item	3566699	et	4	main
vihmane	doc_399014257192_item	3566706	et	4	main
kogu	doc_399014257192_item	3566707	et	4	main
aeg	doc_399014257192_item	3566708	et	3	main
essee	doc_399014257193_item	3566715	et	4	main
vihkan	doc_399014257193_item	3566722	et	3	main
see	doc_399014257193_item	3566725	et	3	main
suur	doc_399014257193_item	3566734	et	3	main
toit	doc_399014257193_item	3566738	et	3	main
piima	doc_399014257193_item	3566743	et	4	main
pakk	doc_399014257193_item	3566770	et	3	main
sada	doc_399014257193_item	3566823	et	4	main
ma	doc_399014257190_item	3566476	et	3	main
järell	doc_399014257190_item	3566475	et	4	main
lootan	doc_399014257190_item	3566477	et	4	main
töötada	doc_399014257190_item	3566478	et	3	main
uurimines	doc_399014257190_item	3566479	et	4	main
aga	doc_399014257190_item	3566480	et	3	main
viis	doc_399014257190_item	3566481	et	4	main
aastat	doc_399014257190_item	3566482	et	3	main
on	doc_399014257190_item	3566483	et	4	main
palju	doc_399014257190_item	3566484	et	4	main
aeg	doc_399014257190_item	3566485	et	3	main
kui	doc_399014257190_item	3566400	et	3	main
ajakirjanikuna	doc_399014257190_item	3566406	et	3	main
lahteks	doc_399014257190_item	3566414	et	4	main
ei	doc_399014257190_item	3566426	et	4	main
vahetasin	doc_399014257190_item	3566430	et	3	main
hiljem	doc_399014257190_item	3566436	et	3	main
ma	doc_399014257190_item	3566437	et	3	main
alustasin	doc_399014257190_item	3566438	et	3	main
õppima	doc_399014257190_item	3566439	et	3	main
ka	doc_399014257190_item	3566440	et	3	main
keskne-	doc_399014257190_item	3566441	et	3	main
ja	doc_399014257190_item	3566442	et	3	main
ida-euroopa	doc_399014257190_item	3566443	et	4	main
ma	doc_399014257190_item	3566444	et	3	main
lõpetasin	doc_399014257190_item	3566445	et	3	main
ülikooli	doc_399014257190_item	3566446	et	4	main
juunis	doc_399014257190_item	3566447	et	3	main
teine	doc_399014257190_item	3566448	et	3	main
tuhande	doc_399014257190_item	3566449	et	3	main
viiendal	doc_399014257190_item	3566450	et	3	main
aastal	doc_399014257190_item	3566451	et	3	main
ma	doc_399014257190_item	3566452	et	3	main
töötasin	doc_399014257190_item	3566453	et	3	main
palju	doc_399014257190_item	3566454	et	4	main
töid	doc_399014257190_item	3566455	et	3	main
ajutiseid	doc_399014257190_item	3566456	et	4	main
kaheksa	doc_399014257190_item	3566457	et	4	main
kuud	doc_399014257190_item	3566458	et	4	main
jooksul	doc_399014257190_item	3566459	et	4	main
siis	doc_399014257190_item	3566460	et	3	main
osastasin	doc_399014257190_item	3566461	et	3	main
jätkama	doc_399014257190_item	3566462	et	3	main
õppima	doc_399014257190_item	3566463	et	3	main
praegu	doc_399014257190_item	3566464	et	3	main
ma	doc_399014257190_item	3566465	et	3	main
õpin	doc_399014257190_item	3566466	et	3	main
magistrant	doc_399014257190_item	3566467	et	4	main
ja	doc_399014257190_item	3566468	et	3	main
lootma	doc_399014257190_item	3566469	et	3	main
saama	doc_399014257190_item	3566470	et	4	main
filosoofiadoktor	doc_399014257190_item	3566471	et	3	main
viie	doc_399014257190_item	3566472	et	3	main
suvel	doc_399014257191_item	3566490	et	3	main
šotimaal	doc_399014257191_item	3566493	et	2	main
väga	doc_399014257191_item	3566503	et	3	main
pikk	doc_399014257191_item	3566504	et	4	main
nii	doc_399014257191_item	3566505	et	3	main
šotlased	doc_399014257191_item	3566506	et	2	main
rõõmutundavad	doc_399014257191_item	3566507	et	4	main
see	doc_399014257191_item	3566508	et	3	main
kelvingroves	doc_399014257191_item	3566509	et	4	main
parkis	doc_399014257191_item	3566510	et	3	main
jooakse	doc_399014257191_item	3566511	et	4	main
palju	doc_399014257191_item	3566512	et	4	main
alkohol	doc_399014257191_item	3566513	et	3	main
inimesed	doc_399014257191_item	3566514	et	3	main
minnavad	doc_399014257191_item	3566515	et	4	main
parkisse	doc_399014257191_item	3566516	et	4	main
kohtuma	doc_399014257191_item	3566517	et	3	main
parkisse	doc_399014257191_item	3566495	et	4	main
ei	doc_399014257191_item	3566501	et	4	main
ole	doc_399014257191_item	3566502	et	4	main
šotimaas	doc_399014257191_item	3566521	et	2	main
ei	doc_399014257191_item	3566522	et	4	main
ole	doc_399014257191_item	3566528	et	4	main
meeldiv	doc_399014257191_item	3566531	et	4	main
reisile	doc_399014257191_item	3566537	et	3	main
austraaliasse	doc_399014257191_item	3566555	et	4	main
šotimaal	doc_399014257191_item	3566565	et	2	main
muusika	doc_399014257191_item	3566569	et	4	main
essee	doc_399014257192_item	3566599	et	4	main
tuuline	doc_399014257192_item	3566626	et	3	main
kogu	doc_399014257192_item	3566631	et	4	main
on	doc_399014257192_item	3566634	et	4	main
ole	doc_399014257192_item	3566700	et	4	main
on	doc_399014257192_item	3566705	et	4	main
ma	doc_399014257192_item	3566709	et	3	main
kauplustes	doc_399014257193_item	3566716	et	4	main
ma	doc_399014257193_item	3566721	et	3	main
minema	doc_399014257193_item	3566733	et	3	main
ostan	doc_399014257193_item	3566740	et	3	main
moosi	doc_399014257193_item	3566755	et	4	main
üks	doc_399014257193_item	3566756	et	3	main
pakk	doc_399014257193_item	3566757	et	3	main
peekonit	doc_399014257193_item	3566758	et	3	main
aedsalat	doc_399014257193_item	3566759	et	3	main
üks	doc_399014257193_item	3566760	et	3	main
pakk	doc_399014257193_item	3566761	et	3	main
võid	doc_399014257193_item	3566762	et	4	main
riisipuder	doc_399014257193_item	3566771	et	3	main
dvd	doc_399014257193_item	3566815	et	4	main
kui	doc_399014257193_item	3566822	et	3	main
mu	doc_399014257194_item	3566830	et	3	main
kuidas	doc_399014257194_item	3566833	et	3	main
sa	doc_399014257194_item	3566834	et	3	main
õpin	doc_399014257194_item	3566837	et	3	main
keelt	doc_399014257194_item	3566841	et	4	main
raske	doc_399014257194_item	3566858	et	4	main
üheksa	doc_399014257194_item	3566871	et	4	main
ja	doc_399014257194_item	3566879	et	3	main
ma	doc_399014257194_item	3566881	et	3	main
uuriminet	doc_399014257194_item	3566896	et	4	main
see	doc_399014257194_item	3566898	et	3	main
olnud	doc_399014257194_item	3566900	et	4	main
huvitav	doc_399014257194_item	3566901	et	4	main
aga	doc_399014257194_item	3566902	et	3	main
ma	doc_399014257194_item	3566903	et	3	main
esimene	doc_399014257194_item	3566913	et	3	main
kell	doc_399014257194_item	3566916	et	3	main
kuusteist	doc_399014257194_item	3566918	et	4	main
pärastlõuna	doc_399014257194_item	3566919	et	4	main
sest	doc_399014257194_item	3566923	et	4	main
keelt	doc_399014257194_item	3566929	et	4	main
minnesin	doc_399014257194_item	3566935	et	4	main
oli	doc_399014257194_item	3566943	et	3	main
lõbu	doc_399014257194_item	3566944	et	4	main
palju	doc_399014257194_item	3566950	et	4	main
kolmapäev	doc_399014257194_item	3566952	et	3	main
eesti	doc_399014257194_item	3566968	et	4	main
ühiskonnateaduse	doc_399014257194_item	3566997	et	3	main
minnesin	doc_399014257194_item	3567001	et	4	main
sest	doc_399014257194_item	3567003	et	4	main
mu	doc_399014257194_item	3567004	et	3	main
socker	doc_399014257194_item	3567005	et	4	main
meeskond	doc_399014257194_item	3567006	et	3	main
õhtul	doc_399014257194_item	3567018	et	3	main
oli	doc_399014257194_item	3567020	et	3	main
ole	doc_399014257191_item	3566523	et	4	main
palju	doc_399014257191_item	3566529	et	4	main
nii	doc_399014257191_item	3566532	et	3	main
minnakse	doc_399014257191_item	3566535	et	3	main
maadesse	doc_399014257191_item	3566540	et	4	main
ma	doc_399014257191_item	3566546	et	3	main
sõitsin	doc_399014257191_item	3566551	et	3	main
usasse	doc_399014257191_item	3566554	et	4	main
eestisse	doc_399014257191_item	3566557	et	4	main
leedusse	doc_399014257191_item	3566559	et	4	main
ja	doc_399014257191_item	3566560	et	3	main
festival	doc_399014257191_item	3566568	et	3	main
t	doc_399014257191_item	3566577	et	4	main
ansambeluid	doc_399014257191_item	3566584	et	4	main
aastaajad	doc_399014257192_item	3566602	et	3	main
kirjutama	doc_399014257192_item	3566605	et	3	main
lühike	doc_399014257192_item	3566616	et	4	main
on	doc_399014257192_item	3566618	et	4	main
vastik	doc_399014257192_item	3566619	et	3	main
ilm	doc_399014257192_item	3566620	et	3	main
sajab	doc_399014257192_item	3566621	et	3	main
vihma	doc_399014257192_item	3566622	et	4	main
see	doc_399014257192_item	3566633	et	3	main
aga	doc_399014257192_item	3566703	et	3	main
see	doc_399014257192_item	3566704	et	3	main
ole	doc_399014257192_item	3566680	et	4	main
palav	doc_399014257192_item	3566681	et	4	main
küllalt	doc_399014257192_item	3566682	et	4	main
mulle	doc_399014257192_item	3566683	et	4	main
ei	doc_399014257192_item	3566684	et	4	main
meeldi	doc_399014257192_item	3566685	et	4	main
talv	doc_399014257192_item	3566686	et	3	main
sest	doc_399014257192_item	3566687	et	4	main
ilm	doc_399014257192_item	3566688	et	3	main
on	doc_399014257192_item	3566689	et	4	main
liiga	doc_399014257192_item	3566690	et	4	main
külm	doc_399014257192_item	3566691	et	3	main
tuuline	doc_399014257192_item	3566692	et	3	main
ja	doc_399014257192_item	3566693	et	3	main
pilves	doc_399014257192_item	3566694	et	4	main
kevade	doc_399014257192_item	3566695	et	4	main
on	doc_399014257192_item	3566696	et	4	main
hea	doc_399014257192_item	3566697	et	4	main
sest	doc_399014257192_item	3566698	et	4	main
ilm	doc_399014257192_item	3566600	et	3	main
kogu	doc_399014257192_item	3566623	et	4	main
kogu	doc_399014257192_item	3566627	et	4	main
aeg	doc_399014257192_item	3566628	et	3	main
sajab	doc_399014257192_item	3566629	et	3	main
päikesepaisteline	doc_399014257192_item	3566635	et	4	main
pikk	doc_399014257192_item	3566640	et	4	main
meil	doc_399014257192_item	3566641	et	4	main
oleme	doc_399014257192_item	3566642	et	3	main
ei	doc_399014257192_item	3566648	et	4	main
ole	doc_399014257192_item	3566649	et	4	main
valtama	doc_399014257192_item	3566650	et	4	main
pikk	doc_399014257192_item	3566651	et	4	main
viis	doc_399014257192_item	3566652	et	4	main
või	doc_399014257192_item	3566653	et	4	main
kuus	doc_399014257192_item	3566654	et	4	main
nädalad	doc_399014257192_item	3566655	et	3	main
võib-olla	doc_399014257192_item	3566656	et	3	main
suvi	doc_399014257192_item	3566657	et	3	main
on	doc_399014257192_item	3566658	et	4	main
kõige	doc_399014257192_item	3566659	et	4	main
parem	doc_399014257192_item	3566660	et	4	main
aastaaeg	doc_399014257192_item	3566661	et	3	main
ja	doc_399014257192_item	3566662	et	3	main
mulle	doc_399014257192_item	3566663	et	4	main
meeldib	doc_399014257192_item	3566664	et	3	main
suvi	doc_399014257192_item	3566665	et	3	main
kõige	doc_399014257192_item	3566666	et	4	main
rohkem	doc_399014257192_item	3566667	et	4	main
ma	doc_399014257192_item	3566668	et	3	main
lähen	doc_399014257192_item	3566669	et	3	main
parki	doc_399014257192_item	3566670	et	4	main
sõpradega	doc_399014257192_item	3566671	et	3	main
mängin	doc_399014257192_item	3566672	et	3	main
jalgpalli	doc_399014257192_item	3566673	et	4	main
ja	doc_399014257192_item	3566674	et	3	main
püüdlema	doc_399014257192_item	3566675	et	3	main
helepruunile	doc_399014257192_item	3566676	et	3	main
aga	doc_399014257192_item	3566677	et	3	main
ilm	doc_399014257192_item	3566678	et	3	main
ei	doc_399014257192_item	3566679	et	4	main
külm	doc_399014257192_item	3566701	et	3	main
soovin	doc_399014257192_item	3566710	et	3	main
elama	doc_399014257192_item	3566711	et	3	main
maas	doc_399014257192_item	3566712	et	4	main
soojem	doc_399014257192_item	3566713	et	3	main
mõnikord	doc_399014257193_item	3566796	et	3	main
aga	doc_399014257193_item	3566797	et	3	main
ei	doc_399014257193_item	3566798	et	4	main
tihti	doc_399014257193_item	3566799	et	3	main
mulle	doc_399014257193_item	3566800	et	4	main
meeldis	doc_399014257193_item	3566801	et	3	main
spordikampsunad	doc_399014257193_item	3566802	et	4	main
ja	doc_399014257193_item	3566803	et	3	main
mul	doc_399014257193_item	3566804	et	3	main
on	doc_399014257193_item	3566805	et	4	main
palju	doc_399014257193_item	3566806	et	4	main
ma	doc_399014257193_item	3566807	et	3	main
ostan	doc_399014257193_item	3566808	et	3	main
on	doc_399014257193_item	3566809	et	4	main
the	doc_399014257193_item	3566810	et	4	main
internet	doc_399014257193_item	3566811	et	4	main
tihti	doc_399014257193_item	3566812	et	3	main
ma	doc_399014257193_item	3566813	et	3	main
ostan	doc_399014257193_item	3566814	et	3	main
mu	doc_399014257193_item	3566717	et	3	main
ei	doc_399014257193_item	3566718	et	4	main
meeldi	doc_399014257193_item	3566719	et	4	main
pean	doc_399014257193_item	3566732	et	4	main
ostan	doc_399014257193_item	3566737	et	3	main
liitrit	doc_399014257193_item	3566742	et	3	main
või	doc_399014257193_item	3566745	et	4	main
nelisada	doc_399014257193_item	3566746	et	4	main
õunad	doc_399014257193_item	3566763	et	3	main
banaanad	doc_399014257193_item	3566764	et	4	main
kaks	doc_399014257193_item	3566772	et	3	main
kartong	doc_399014257193_item	3566773	et	3	main
õunamahla	doc_399014257193_item	3566774	et	4	main
riisi	doc_399014257193_item	3566775	et	4	main
porgandud	doc_399014257193_item	3566776	et	4	main
kurg	doc_399014257193_item	3566777	et	3	main
tomatipüreesupp	doc_399014257193_item	3566778	et	3	main
kolm	doc_399014257193_item	3566779	et	3	main
tinad	doc_399014257193_item	3566780	et	3	main
juurviljasuppi	doc_399014257193_item	3566781	et	4	main
ja	doc_399014257193_item	3566782	et	3	main
kaks	doc_399014257193_item	3566783	et	3	main
pitsat	doc_399014257193_item	3566784	et	4	main
juustuga	doc_399014257193_item	3566785	et	3	main
see	doc_399014257193_item	3566786	et	3	main
maksab	doc_399014257193_item	3566787	et	3	main
kolmkümmend	doc_399014257193_item	3566788	et	4	main
või	doc_399014257193_item	3566789	et	4	main
nelikümmend	doc_399014257193_item	3566790	et	4	main
ma	doc_399014257193_item	3566792	et	3	main
ostan	doc_399014257193_item	3566793	et	3	main
naela	doc_399014257193_item	3566791	et	4	main
ka	doc_399014257193_item	3566794	et	3	main
riideid	doc_399014257193_item	3566795	et	3	main
rohkem	doc_399014257193_item	3566821	et	4	main
küll	doc_399014257193_item	3566723	et	4	main
kauplustes	doc_399014257193_item	3566724	et	4	main
ei	doc_399014257193_item	3566726	et	4	main
väga	doc_399014257193_item	3566728	et	3	main
huvitav	doc_399014257193_item	3566729	et	4	main
iganädal	doc_399014257193_item	3566730	et	3	main
ma	doc_399014257193_item	3566731	et	3	main
ja	doc_399014257193_item	3566736	et	3	main
kolmsada	doc_399014257193_item	3566744	et	4	main
juustu	doc_399014257193_item	3566748	et	4	main
üks	doc_399014257193_item	3566749	et	3	main
leib	doc_399014257193_item	3566750	et	3	main
kaksteist	doc_399014257193_item	3566751	et	4	main
apelsinad	doc_399014257193_item	3566765	et	4	main
üks	doc_399014257193_item	3566769	et	3	main
dvd	doc_399014257193_item	3566824	et	4	main
aga	doc_399014257193_item	3566825	et	3	main
ja	doc_399014257194_item	3566842	et	3	main
päev	doc_399014257194_item	3566859	et	3	main
esmaspäeva	doc_399014257194_item	3566863	et	4	main
hommikusööki	doc_399014257194_item	3566874	et	4	main
riisipuder	doc_399014257194_item	3566878	et	3	main
ülikoolisse	doc_399014257194_item	3566882	et	4	main
veel	doc_399014257194_item	3566884	et	4	main
üksteist	doc_399014257194_item	3566885	et	4	main
ja	doc_399014257194_item	3566886	et	3	main
ma	doc_399014257194_item	3566887	et	3	main
oli	doc_399014257194_item	3566888	et	3	main
hilist	doc_399014257194_item	3566889	et	3	main
ma	doc_399014257194_item	3566894	et	3	main
loengusse	doc_399014257194_item	3566897	et	4	main
ei	doc_399014257194_item	3566899	et	4	main
ma	doc_399014257194_item	3566908	et	3	main
magada	doc_399014257194_item	3566911	et	3	main
lähesin	doc_399014257194_item	3566920	et	4	main
ma	doc_399014257194_item	3566921	et	3	main
eesti	doc_399014257194_item	3566928	et	4	main
rohkem	doc_399014257193_item	3566827	et	4	main
essee	doc_399014257194_item	3566829	et	4	main
nadal	doc_399014257194_item	3566831	et	4	main
elad	doc_399014257194_item	3566835	et	3	main
glasgow	doc_399014257194_item	3566838	et	4	main
ülikoolis	doc_399014257194_item	3566839	et	4	main
elanud	doc_399014257194_item	3566846	et	4	main
juba	doc_399014257194_item	3566848	et	3	main
seitse	doc_399014257194_item	3566849	et	3	main
veidi	doc_399014257194_item	3566855	et	3	main
esmaspäev	doc_399014257194_item	3566856	et	3	main
oli	doc_399014257194_item	3566857	et	3	main
ei	doc_399014257194_item	3566861	et	4	main
nauti	doc_399014257194_item	3566862	et	4	main
ma	doc_399014257194_item	3566864	et	3	main
ärkasin	doc_399014257194_item	3566865	et	3	main
hommikul	doc_399014257194_item	3566866	et	3	main
kell	doc_399014257194_item	3566867	et	3	main
kaheksa	doc_399014257194_item	3566868	et	4	main
kell	doc_399014257194_item	3566869	et	3	main
kohv	doc_399014257194_item	3566875	et	3	main
piimaga	doc_399014257194_item	3566876	et	3	main
minnesin	doc_399014257194_item	3566883	et	4	main
lähesin	doc_399014257194_item	3566895	et	4	main
peas	doc_399014257194_item	3566904	et	4	main
minema	doc_399014257194_item	3566905	et	3	main
teisipäeval	doc_399014257194_item	3566906	et	3	main
saasin	doc_399014257194_item	3566907	et	4	main
kaua	doc_399014257194_item	3566910	et	3	main
algas	doc_399014257194_item	3566915	et	3	main
pool	doc_399014257194_item	3566917	et	4	main
peasin	doc_399014257194_item	3566925	et	4	main
kirjutama	doc_399014257194_item	3566926	et	3	main
kodutöö	doc_399014257194_item	3566927	et	4	main
ja	doc_399014257194_item	3566930	et	3	main
uuriminet	doc_399014257194_item	3566931	et	4	main
teisipäeva	doc_399014257194_item	3566932	et	4	main
palju	doc_399014257194_item	3566945	et	4	main
aga	doc_399014257194_item	3566946	et	3	main
ma	doc_399014257194_item	3566947	et	3	main
joomasin	doc_399014257194_item	3566948	et	4	main
ma	doc_399014257194_item	3566953	et	3	main
loengust	doc_399014257194_item	3566959	et	4	main
vabanda	doc_399014257194_item	3566960	et	4	main
neljapäeval	doc_399014257194_item	3566961	et	3	main
üks	doc_399014257194_item	3566972	et	3	main
ma	doc_399014257194_item	3567000	et	3	main
võitsid	doc_399014257194_item	3567012	et	4	main
üks	doc_399014257194_item	3567013	et	3	main
värav	doc_399014257194_item	3567014	et	3	main
ma	doc_399014257194_item	3567015	et	3	main
ma	doc_399014257195_item	3567037	et	3	main
palju	doc_399014257195_item	3567042	et	4	main
siiski	doc_399014257195_item	3567062	et	4	main
ma	doc_399014257195_item	3567063	et	3	main
kontori	doc_399014257195_item	3567070	et	4	main
ja	doc_399014257195_item	3567071	et	3	main
glasgow	doc_399014257195_item	3567090	et	4	main
hea	doc_399014257195_item	3567096	et	4	main
inimese	doc_399014257195_item	3567104	et	4	main
käituvad	doc_399014257195_item	3567105	et	4	main
terry	doc_399014257198_item	3567148	et	4	main
sündis	doc_399014257198_item	3567150	et	3	main
ta	doc_399014257198_item	3567153	et	4	main
iiri	doc_399014257198_item	3567155	et	4	main
keel	doc_399014257198_item	3567156	et	4	main
ja	doc_399014257198_item	3567157	et	3	main
olema	doc_399014257198_item	3567162	et	4	main
on	doc_399014257198_item	3567183	et	4	main
raaddiktor	doc_399014257198_item	3567190	et	4	main
bbc	doc_399014257198_item	3567191	et	4	main
aastast	doc_399014257198_item	3567201	et	4	main
tal	doc_399014257198_item	3567202	et	3	main
tema	doc_399014257198_item	3567215	et	4	main
avameelne	doc_399014257198_item	3567244	et	3	main
see	doc_399014257198_item	3567252	et	3	main
minu	doc_399014257200_item	3567262	et	3	main
on	doc_399014257200_item	3567266	et	4	main
palju	doc_399014257200_item	3567270	et	4	main
raamatut	doc_399014257200_item	3567288	et	3	main
ole	doc_399014257200_item	3567290	et	4	main
lugeda	doc_399014257200_item	3567292	et	3	main
eesti	doc_399014257194_item	3566992	et	4	main
keelt	doc_399014257194_item	3566993	et	4	main
ja	doc_399014257194_item	3566994	et	3	main
eesti	doc_399014257194_item	3566840	et	4	main
on	doc_399014257194_item	3566845	et	4	main
nädala	doc_399014257194_item	3566852	et	3	main
oli	doc_399014257194_item	3566853	et	3	main
hõivatud	doc_399014257194_item	3566854	et	4	main
ma	doc_399014257194_item	3566860	et	3	main
süüasin	doc_399014257194_item	3566872	et	4	main
mu	doc_399014257194_item	3566873	et	3	main
sigaret	doc_399014257194_item	3566880	et	3	main
keelt	doc_399014257194_item	3566891	et	4	main
õhtul	doc_399014257194_item	3566893	et	3	main
hommikul	doc_399014257194_item	3566909	et	3	main
sest	doc_399014257194_item	3566912	et	4	main
ma	doc_399014257194_item	3566924	et	3	main
kolmkümmend	doc_399014257194_item	3566941	et	4	main
see	doc_399014257194_item	3566942	et	3	main
ja	doc_399014257194_item	3566951	et	3	main
haiglast	doc_399014257194_item	3566955	et	4	main
ma	doc_399014257194_item	3566957	et	3	main
oli	doc_399014257194_item	3566962	et	3	main
mul	doc_399014257194_item	3566963	et	3	main
üks	doc_399014257194_item	3566964	et	3	main
loeng	doc_399014257194_item	3566965	et	3	main
see	doc_399014257194_item	3566966	et	3	main
keelt	doc_399014257194_item	3566969	et	4	main
tõlkisime	doc_399014257194_item	3566971	et	3	main
ma	doc_399014257194_item	3566995	et	3	main
lugesin	doc_399014257194_item	3566996	et	3	main
united	doc_399014257194_item	3567008	et	4	main
mängimaid	doc_399014257194_item	3567009	et	4	main
nad	doc_399014257194_item	3567010	et	3	main
mängu	doc_399014257194_item	3567011	et	4	main
see	doc_399014257194_item	3567019	et	3	main
reis	doc_399014257194_item	3567022	et	4	main
pühapäeval	doc_399014257194_item	3567023	et	3	main
kodutöö	doc_399014257194_item	3567026	et	4	main
eesti	doc_399014257194_item	3567027	et	4	main
essee	doc_399014257195_item	3567035	et	4	main
linnapea	doc_399014257195_item	3567040	et	4	main
ma	doc_399014257195_item	3567044	et	3	main
suurema	doc_399014257195_item	3567046	et	4	main
nõukogu	doc_399014257195_item	3567060	et	4	main
teeninduid	doc_399014257195_item	3567061	et	4	main
on	doc_399014257195_item	3567068	et	4	main
suur	doc_399014257195_item	3567069	et	3	main
raha	doc_399014257195_item	3567073	et	4	main
ma	doc_399014257195_item	3567074	et	3	main
vahetaks	doc_399014257195_item	3567075	et	4	main
nimi	doc_399014257195_item	3567076	et	3	main
linnapealt	doc_399014257195_item	3567077	et	3	main
kuningaale	doc_399014257195_item	3567078	et	4	main
see	doc_399014257195_item	3567091	et	3	main
sest	doc_399014257195_item	3567110	et	4	main
see	doc_399014257195_item	3567111	et	3	main
essee	doc_399014257198_item	3567144	et	4	main
inglise	doc_399014257198_item	3567158	et	4	main
kulus	doc_399014257198_item	3567161	et	4	main
ta	doc_399014257198_item	3567186	et	4	main
töötan	doc_399014257198_item	3567187	et	3	main
tema	doc_399014257198_item	3567192	et	4	main
on	doc_399014257198_item	3567203	et	4	main
ja	doc_399014257198_item	3567206	et	3	main
lapselapse	doc_399014257198_item	3567208	et	4	main
on	doc_399014257198_item	3567216	et	4	main
ta	doc_399014257198_item	3567218	et	4	main
on	doc_399014257198_item	3567219	et	4	main
publikta	doc_399014257198_item	3567248	et	4	main
raamatuid	doc_399014257200_item	3567269	et	3	main
raamatuid	doc_399014257200_item	3567271	et	3	main
on	doc_399014257200_item	3567282	et	4	main
vahel	doc_399014257200_item	3567283	et	4	main
rasked	doc_399014257200_item	3567286	et	3	main
viis	doc_399014257200_item	3567309	et	4	main
tales	doc_399014257200_item	3567371	et	4	main
huvitav	doc_399014257200_item	3567386	et	4	main
seal	doc_399014257200_item	3567387	et	4	main
on	doc_399014257200_item	3567388	et	4	main
keeli	doc_399014257200_item	3567397	et	4	main
ja	doc_399014257200_item	3567398	et	3	main
saama	doc_399014257200_item	3567399	et	4	main
midagi	doc_399014257200_item	3567418	et	4	main
legema	doc_399014257200_item	3567420	et	4	main
ma	doc_399014257200_item	3567421	et	3	main
loodan	doc_399014257200_item	3567422	et	3	main
nii	doc_399014257200_item	3567423	et	3	main
essee	doc_399014257201_item	3567425	et	4	main
šotimaal	doc_399014257201_item	3567429	et	2	main
õhtul	doc_399014257194_item	3566933	et	3	main
mu	doc_399014257194_item	3566936	et	3	main
ta	doc_399014257194_item	3566939	et	4	main
oli	doc_399014257194_item	3566940	et	3	main
liiga	doc_399014257194_item	3566949	et	4	main
oli	doc_399014257194_item	3566967	et	3	main
me	doc_399014257194_item	3566970	et	4	main
tekst	doc_399014257194_item	3566973	et	3	main
see	doc_399014257194_item	3566974	et	3	main
oli	doc_399014257194_item	3566975	et	3	main
sarnane	doc_399014257194_item	3566976	et	4	main
see	doc_399014257194_item	3566977	et	3	main
tekst	doc_399014257194_item	3566978	et	3	main
mingist	doc_399014257194_item	3566979	et	4	main
eesti	doc_399014257194_item	3566980	et	4	main
keelest	doc_399014257194_item	3566981	et	4	main
mingisse	doc_399014257194_item	3566982	et	4	main
inglise	doc_399014257194_item	3566983	et	4	main
keelde	doc_399014257194_item	3566984	et	4	main
nelijapäeval	doc_399014257194_item	3566985	et	4	main
pärastlõunal	doc_399014257194_item	3566986	et	3	main
ja	doc_399014257194_item	3566987	et	3	main
reedel	doc_399014257194_item	3566988	et	3	main
ma	doc_399014257194_item	3566989	et	3	main
tegin	doc_399014257194_item	3566990	et	3	main
kodutööd	doc_399014257194_item	3566991	et	4	main
raamatut	doc_399014257194_item	3566998	et	3	main
dundeesse	doc_399014257194_item	3567002	et	4	main
olin	doc_399014257194_item	3567016	et	3	main
pikk	doc_399014257194_item	3567021	et	4	main
ma	doc_399014257194_item	3567024	et	3	main
kirjutasin	doc_399014257194_item	3567025	et	3	main
oleksin	doc_399014257195_item	3567038	et	3	main
vahetama	doc_399014257195_item	3567041	et	3	main
ei	doc_399014257195_item	3567064	et	4	main
hooliks	doc_399014257195_item	3567065	et	4	main
palju	doc_399014257195_item	3567072	et	4	main
kuningas	doc_399014257195_item	3567089	et	4	main
meeldiv	doc_399014257195_item	3567093	et	4	main
ma	doc_399014257195_item	3567094	et	3	main
ja	doc_399014257195_item	3567097	et	3	main
lahke	doc_399014257195_item	3567098	et	4	main
kuningas	doc_399014257195_item	3567099	et	4	main
aga	doc_399014257195_item	3567100	et	3	main
õe	doc_399014257194_item	3566937	et	4	main
sünnipäevale	doc_399014257194_item	3566938	et	4	main
olin	doc_399014257194_item	3566954	et	3	main
väga	doc_399014257194_item	3566956	et	3	main
puudumasin	doc_399014257194_item	3566958	et	3	main
laupäeval	doc_399014257194_item	3566999	et	3	main
dundee	doc_399014257194_item	3567007	et	4	main
õnneliku	doc_399014257194_item	3567017	et	3	main
keelt	doc_399014257194_item	3567028	et	4	main
ja	doc_399014257194_item	3567029	et	3	main
õhtul	doc_399014257194_item	3567030	et	3	main
lähesid	doc_399014257194_item	3567031	et	4	main
sõbraga	doc_399014257194_item	3567032	et	3	main
kinno	doc_399014257194_item	3567033	et	3	main
glasgow	doc_399014257195_item	3567039	et	4	main
siis	doc_399014257195_item	3567079	et	3	main
ma	doc_399014257195_item	3567080	et	3	main
võiksin	doc_399014257195_item	3567081	et	3	main
kandma	doc_399014257195_item	3567082	et	3	main
krooni	doc_399014257195_item	3567083	et	4	main
ja	doc_399014257195_item	3567084	et	3	main
istuma	doc_399014257195_item	3567085	et	3	main
trooni	doc_399014257195_item	3567086	et	4	main
ma	doc_399014257195_item	3567087	et	3	main
oleksin	doc_399014257195_item	3567088	et	3	main
ainult	doc_399014257195_item	3567101	et	4	main
kui	doc_399014257195_item	3567102	et	3	main
mu	doc_399014257195_item	3567103	et	3	main
buckfasti	doc_399014257195_item	3567109	et	4	main
wogan	doc_399014257198_item	3567146	et	4	main
wogan	doc_399014257198_item	3567149	et	4	main
1938	doc_399014257198_item	3567151	et	2	main
iirimaalt	doc_399014257198_item	3567152	et	3	main
tema	doc_399014257198_item	3567163	et	4	main
tal	doc_399014257198_item	3567182	et	3	main
raske	doc_399014257198_item	3567184	et	4	main
töökoormus	doc_399014257198_item	3567185	et	3	main
häälis	doc_399014257198_item	3567194	et	4	main
tescos	doc_399014257198_item	3567195	et	4	main
briti	doc_399014257198_item	3567220	et	4	main
ellukutsumine	doc_399014257198_item	3567221	et	3	main
aga	doc_399014257198_item	3567245	et	3	main
ta	doc_399014257198_item	3567250	et	4	main
mida	doc_399014257198_item	3567256	et	4	main
hiline	doc_399014257198_item	3567257	et	4	main
seda	doc_399014257198_item	3567258	et	3	main
parem	doc_399014257198_item	3567259	et	4	main
palju	doc_399014257200_item	3567267	et	4	main
mulle	doc_399014257200_item	3567276	et	4	main
meeldib	doc_399014257200_item	3567277	et	3	main
sünged	doc_399014257200_item	3567284	et	3	main
ja	doc_399014257200_item	3567285	et	3	main
ei	doc_399014257200_item	3567289	et	4	main
kerge	doc_399014257200_item	3567291	et	4	main
tõenäoliselt	doc_399014257200_item	3567299	et	4	main
eelistama	doc_399014257200_item	3567300	et	3	main
raamatud	doc_399014257200_item	3567303	et	4	main
potter	doc_399014257200_item	3567311	et	4	main
ja	doc_399014257200_item	3567312	et	3	main
ma	doc_399014257200_item	3567317	et	3	main
jõudma	doc_399014257200_item	3567320	et	3	main
mina	doc_399014257200_item	3567321	et	4	main
minu	doc_399014257200_item	3567322	et	3	main
absoluutne	doc_399014257200_item	3567323	et	3	main
lemmik	doc_399014257200_item	3567324	et	3	main
raamat	doc_399014257200_item	3567325	et	3	main
ma	doc_399014257200_item	3567326	et	3	main
oleks	doc_399014257200_item	3567327	et	3	main
city	doc_399014257200_item	3567374	et	4	main
millelgi	doc_399014257200_item	3567376	et	4	main
eluviis	doc_399014257200_item	3567378	et	3	main
san	doc_399014257200_item	3567379	et	4	main
franciscos	doc_399014257200_item	3567380	et	4	main
palju	doc_399014257195_item	3567116	et	4	main
probleemuid	doc_399014257195_item	3567117	et	4	main
glasgowks	doc_399014257195_item	3567118	et	4	main
ma	doc_399014257195_item	3567119	et	3	main
ära	doc_399014257195_item	3567120	et	4	main
keelaksin	doc_399014257195_item	3567121	et	3	main
celtic	doc_399014257195_item	3567122	et	4	main
ja	doc_399014257195_item	3567123	et	3	main
rangers	doc_399014257195_item	3567124	et	4	main
sest	doc_399014257195_item	3567125	et	4	main
nad	doc_399014257195_item	3567126	et	3	main
võitma	doc_399014257195_item	3567127	et	3	main
liiga	doc_399014257195_item	3567128	et	4	main
palju	doc_399014257195_item	3567129	et	4	main
siis	doc_399014257195_item	3567130	et	3	main
dundee	doc_399014257195_item	3567131	et	4	main
united	doc_399014257195_item	3567132	et	4	main
võime	doc_399014257195_item	3567133	et	4	main
võitma	doc_399014257195_item	3567134	et	3	main
miski	doc_399014257195_item	3567135	et	4	main
aga	doc_399014257195_item	3567136	et	3	main
ma	doc_399014257195_item	3567137	et	3	main
ei	doc_399014257195_item	3567138	et	4	main
usu	doc_399014257195_item	3567139	et	4	main
et	doc_399014257195_item	3567140	et	3	main
ta	doc_399014257195_item	3567141	et	4	main
on	doc_399014257195_item	3567142	et	4	main
kui	doc_399014257195_item	3567036	et	3	main
esimene	doc_399014257195_item	3567043	et	3	main
saan	doc_399014257195_item	3567045	et	4	main
kontori	doc_399014257195_item	3567047	et	4	main
ja	doc_399014257195_item	3567048	et	3	main
maksuma	doc_399014257195_item	3567049	et	4	main
endale	doc_399014257195_item	3567050	et	4	main
rohkem	doc_399014257195_item	3567051	et	4	main
raha	doc_399014257195_item	3567052	et	4	main
ma	doc_399014257195_item	3567053	et	3	main
alandaksin	doc_399014257195_item	3567054	et	3	main
aga	doc_399014257195_item	3567056	et	3	main
maksu	doc_399014257195_item	3567055	et	4	main
see	doc_399014257195_item	3567057	et	3	main
oleks	doc_399014257195_item	3567058	et	3	main
vähem	doc_399014257195_item	3567059	et	4	main
sest	doc_399014257195_item	3567066	et	4	main
mul	doc_399014257195_item	3567067	et	3	main
oleks	doc_399014257195_item	3567092	et	3	main
oleksin	doc_399014257195_item	3567095	et	3	main
hea	doc_399014257195_item	3567106	et	4	main
ma	doc_399014257195_item	3567107	et	3	main
keelustaksin	doc_399014257195_item	3567108	et	3	main
on	doc_399014257195_item	3567112	et	4	main
kuri	doc_399014257195_item	3567113	et	4	main
ja	doc_399014257195_item	3567114	et	3	main
põhjustama	doc_399014257195_item	3567115	et	3	main
terry	doc_399014257198_item	3567145	et	4	main
räägib	doc_399014257198_item	3567154	et	3	main
terry	doc_399014257198_item	3567160	et	4	main
ka	doc_399014257198_item	3567193	et	3	main
reklaam	doc_399014257198_item	3567196	et	3	main
terry	doc_399014257198_item	3567197	et	4	main
abielus	doc_399014257198_item	3567198	et	4	main
kolm	doc_399014257198_item	3567204	et	3	main
kaks	doc_399014257198_item	3567207	et	3	main
terry	doc_399014257198_item	3567210	et	4	main
tahe	doc_399014257198_item	3567211	et	4	main
pensionile	doc_399014257198_item	3567212	et	3	main
minema	doc_399014257198_item	3567213	et	3	main
varsti	doc_399014257198_item	3567214	et	3	main
igivana	doc_399014257198_item	3567217	et	4	main
kunagi	doc_399014257198_item	3567247	et	3	main
päev	doc_399014257198_item	3567254	et	3	main
essee	doc_399014257200_item	3567261	et	4	main
lemmik	doc_399014257200_item	3567263	et	3	main
mul	doc_399014257200_item	3567265	et	3	main
lugemine	doc_399014257200_item	3567278	et	4	main
aga	doc_399014257200_item	3567279	et	3	main
akadeemiline	doc_399014257200_item	3567280	et	3	main
raamatud	doc_399014257200_item	3567281	et	4	main
seda	doc_399014257200_item	3567287	et	3	main
oleks	doc_399014257200_item	3567298	et	3	main
tüüpiline	doc_399014257200_item	3567301	et	3	main
lapsed	doc_399014257200_item	3567302	et	3	main
säärased	doc_399014257200_item	3567304	et	3	main
tere	doc_399014257200_item	3567313	et	3	main
tere	doc_399014257200_item	3567314	et	3	main
kui	doc_399014257200_item	3567316	et	3	main
of	doc_399014257200_item	3567372	et	4	main
põhinema	doc_399014257200_item	3567375	et	3	main
raamatud	doc_399014257200_item	3567390	et	4	main
raamatud	doc_399014257200_item	3567393	et	4	main
menukas	doc_399014257200_item	3567401	et	4	main
raamat	doc_399014257200_item	3567402	et	3	main
kogu	doc_399014257200_item	3567403	et	4	main
maailmas	doc_399014257200_item	3567404	et	3	main
ma	doc_399014257200_item	3567409	et	3	main
suvel	doc_399014257201_item	3567426	et	3	main
mulle	doc_399014257201_item	3567433	et	4	main
rahvad	doc_399014257201_item	3567437	et	3	main
sõidedakse	doc_399014257201_item	3567441	et	4	main
rongiga	doc_399014257201_item	3567442	et	4	main
ilusad	doc_399014257201_item	3567448	et	3	main
tahaksin	doc_399014257201_item	3567451	et	3	main
halvas	doc_399014257201_item	3567471	et	4	main
sooda	doc_399014257201_item	3567477	et	4	main
kelvingrovesse	doc_399014257201_item	3567484	et	4	main
parem	doc_399014257201_item	3567494	et	4	main
aastaaeg	doc_399014257201_item	3567495	et	3	main
palju	doc_399014257201_item	3567496	et	4	main
puhkusele	doc_399014257201_item	3567498	et	4	main
täna	doc_399014257201_item	3567499	et	4	main
suvi	doc_399014257201_item	3567500	et	3	main
minema	doc_399014257201_item	3567501	et	3	main
celine	doc_399014257201_item	3567522	et	4	main
tööl	doc_399014257201_item	3567553	et	3	main
kui	doc_399014257203_item	3567558	et	3	main
glasgow	doc_399014257203_item	3567566	et	4	main
must	doc_399014257203_item	3567576	et	4	main
tegema	doc_399014257203_item	3567583	et	3	main
muidugi	doc_399014257203_item	3567596	et	4	main
naljatama	doc_399014257203_item	3567597	et	3	main
glasgows	doc_399014257203_item	3567598	et	4	main
ilus	doc_399014257203_item	3567601	et	4	main
roheline	doc_399014257203_item	3567603	et	4	main
ma	doc_399014257203_item	3567605	et	3	main
mulle	doc_399014257198_item	3567226	et	4	main
meeldib	doc_399014257198_item	3567227	et	3	main
palju	doc_399014257198_item	3567228	et	4	main
väga	doc_399014257198_item	3567229	et	3	main
naljakas	doc_399014257198_item	3567230	et	4	main
ja	doc_399014257198_item	3567231	et	3	main
sõbralik	doc_399014257198_item	3567232	et	3	main
on	doc_399014257198_item	3567234	et	4	main
tal	doc_399014257198_item	3567233	et	3	main
oma	doc_399014257198_item	3567235	et	4	main
auto	doc_399014257198_item	3567236	et	4	main
ka	doc_399014257198_item	3567237	et	3	main
autojuhtaga	doc_399014257198_item	3567238	et	4	main
vahel	doc_399014257198_item	3567239	et	4	main
ta	doc_399014257198_item	3567240	et	4	main
on	doc_399014257198_item	3567241	et	4	main
vaieldav	doc_399014257198_item	3567242	et	4	main
vahel	doc_399014257198_item	3567243	et	4	main
elulugu	doc_399014257198_item	3567147	et	4	main
keelt	doc_399014257198_item	3567159	et	4	main
raadio	doc_399014257198_item	3567164	et	4	main
ja	doc_399014257198_item	3567166	et	3	main
oma	doc_399014257198_item	3567167	et	4	main
eurovisiooni	doc_399014257198_item	3567168	et	4	main
kommentaar	doc_399014257198_item	3567169	et	3	main
programm	doc_399014257198_item	3567165	et	3	main
ma	doc_399014257198_item	3567170	et	3	main
kohtasid	doc_399014257198_item	3567171	et	4	main
tema	doc_399014257198_item	3567172	et	4	main
mais	doc_399014257198_item	3567173	et	4	main
2000	doc_399014257198_item	3567174	et	2	main
väga	doc_399014257198_item	3567175	et	3	main
õnnelik	doc_399014257198_item	3567176	et	3	main
mälu	doc_399014257198_item	3567177	et	4	main
ta	doc_399014257198_item	3567178	et	4	main
on	doc_399014257198_item	3567179	et	4	main
väga	doc_399014257198_item	3567180	et	3	main
rikas	doc_399014257198_item	3567181	et	4	main
telev	doc_399014257198_item	3567188	et	4	main
ja	doc_399014257198_item	3567189	et	3	main
helen	doc_399014257198_item	3567199	et	4	main
1965	doc_399014257198_item	3567200	et	2	main
lapsed	doc_399014257198_item	3567205	et	3	main
räägitakse	doc_399014257198_item	3567209	et	3	main
palju	doc_399014257198_item	3567222	et	4	main
inimesed	doc_399014257198_item	3567223	et	3	main
austama	doc_399014257198_item	3567224	et	3	main
temad	doc_399014257198_item	3567225	et	4	main
mitte	doc_399014257198_item	3567246	et	3	main
millal	doc_399014257198_item	3567249	et	3	main
suremas	doc_399014257198_item	3567251	et	3	main
kurb	doc_399014257198_item	3567253	et	3	main
kurbusaga	doc_399014257198_item	3567255	et	4	main
raamat	doc_399014257200_item	3567264	et	3	main
lemmik	doc_399014257200_item	3567268	et	3	main
on	doc_399014257200_item	3567272	et	4	main
põnevusromaanid	doc_399014257200_item	3567273	et	3	main
või	doc_399014257200_item	3567274	et	4	main
biograafiad	doc_399014257200_item	3567275	et	3	main
ma	doc_399014257200_item	3567297	et	3	main
harry	doc_399014257200_item	3567310	et	4	main
pean	doc_399014257200_item	3567318	et	4	main
otsusele	doc_399014257200_item	3567319	et	4	main
välja	doc_399014257200_item	3567328	et	4	main
korjama	doc_399014257200_item	3567329	et	3	main
tales	doc_399014257200_item	3567330	et	4	main
of	doc_399014257200_item	3567331	et	4	main
the	doc_399014257200_item	3567332	et	4	main
city	doc_399014257200_item	3567333	et	4	main
armistead	doc_399014257200_item	3567334	et	4	main
maupini	doc_399014257200_item	3567335	et	4	main
maupin	doc_399014257200_item	3567337	et	4	main
kirjutud	doc_399014257200_item	3567336	et	4	main
on	doc_399014257200_item	3567338	et	4	main
ameeriklane	doc_399014257200_item	3567339	et	3	main
kirjanik	doc_399014257200_item	3567340	et	3	main
väga	doc_399014257200_item	3567341	et	3	main
hea	doc_399014257200_item	3567342	et	4	main
kõige	doc_399014257200_item	3567343	et	4	main
parem	doc_399014257200_item	3567344	et	4	main
minu	doc_399014257200_item	3567345	et	3	main
arvates	doc_399014257200_item	3567346	et	4	main
tales	doc_399014257200_item	3567347	et	4	main
of	doc_399014257200_item	3567348	et	4	main
the	doc_399014257200_item	3567349	et	4	main
the	doc_399014257200_item	3567350	et	4	main
city	doc_399014257200_item	3567351	et	4	main
keelepeksi	doc_399014257200_item	3567352	et	4	main
linn	doc_399014257200_item	3567353	et	3	main
on	doc_399014257200_item	3567354	et	4	main
algama	doc_399014257200_item	3567355	et	3	main
san	doc_399014257200_item	3567356	et	4	main
franciscos	doc_399014257200_item	3567357	et	4	main
on	doc_399014257200_item	3567358	et	4	main
linn	doc_399014257200_item	3567359	et	3	main
ameerika	doc_399014257200_item	3567360	et	3	main
the	doc_399014257200_item	3567373	et	4	main
on	doc_399014257200_item	3567382	et	4	main
tark	doc_399014257200_item	3567384	et	3	main
kuus	doc_399014257200_item	3567389	et	4	main
üldiselt	doc_399014257200_item	3567392	et	4	main
oli	doc_399014257200_item	3567394	et	3	main
kui	doc_399014257200_item	3567293	et	3	main
ma	doc_399014257200_item	3567294	et	3	main
oleksin	doc_399014257200_item	3567295	et	3	main
noorem	doc_399014257200_item	3567296	et	4	main
raamatud	doc_399014257200_item	3567305	et	4	main
nagu	doc_399014257200_item	3567306	et	3	main
need	doc_399014257200_item	3567307	et	3	main
kuulsus	doc_399014257200_item	3567308	et	4	main
lambatall	doc_399014257200_item	3567315	et	3	main
ühendriikides	doc_399014257200_item	3567361	et	3	main
california	doc_399014257200_item	3567362	et	4	main
osariigis	doc_399014257200_item	3567363	et	3	main
lühidalt	doc_399014257200_item	3567364	et	4	main
öeldes	doc_399014257200_item	3567365	et	3	main
on	doc_399014257200_item	3567366	et	4	main
kuulda	doc_399014257200_item	3567367	et	4	main
et	doc_399014257200_item	3567368	et	3	main
räägitakse	doc_399014257200_item	3567369	et	3	main
et	doc_399014257200_item	3567370	et	3	main
inemesee	doc_399014257200_item	3567377	et	4	main
väga	doc_399014257200_item	3567383	et	3	main
ja	doc_399014257200_item	3567385	et	3	main
paljusse	doc_399014257200_item	3567396	et	4	main
maupinil	doc_399014257200_item	3567405	et	4	main
unikaalne	doc_399014257200_item	3567406	et	3	main
keelt	doc_399014257200_item	3567417	et	4	main
raamatust	doc_399014257200_item	3567419	et	4	main
nauditav	doc_399014257201_item	3567432	et	4	main
või	doc_399014257201_item	3567443	et	4	main
šotimaal	doc_399014257201_item	3567446	et	2	main
ma	doc_399014257201_item	3567450	et	3	main
kuningriikt	doc_399014257201_item	3567458	et	4	main
šotlased	doc_399014257201_item	3567459	et	2	main
jüüakse	doc_399014257201_item	3567460	et	4	main
palju	doc_399014257201_item	3567461	et	4	main
olukoras	doc_399014257201_item	3567472	et	4	main
ilma	doc_399014257201_item	3567478	et	4	main
kõige	doc_399014257201_item	3567493	et	4	main
puhkusele	doc_399014257201_item	3567502	et	4	main
dion	doc_399014257201_item	3567523	et	4	main
ma	doc_399014257201_item	3567551	et	3	main
kaida	doc_399014257201_item	3567552	et	4	main
ma	doc_399014257203_item	3567559	et	3	main
nende	doc_399014257203_item	3567574	et	4	main
koerad	doc_399014257203_item	3567575	et	3	main
vihane	doc_399014257203_item	3567582	et	4	main
ka	doc_399014257203_item	3567586	et	3	main
parem	doc_399014257203_item	3567614	et	4	main
tana	doc_399014257203_item	3567615	et	4	main
poolased	doc_399014257203_item	3567632	et	4	main
meel	doc_399014257203_item	3567660	et	4	main
avalikult	doc_399014257203_item	3567663	et	4	main
suitsetamine	doc_399014257203_item	3567664	et	4	main
suitsetamine	doc_399014257203_item	3567665	et	4	main
keelatud	doc_399014257203_item	3567666	et	4	main
lähme	doc_399014257203_item	3567667	et	3	main
pühitsema	doc_399014257203_item	3567668	et	3	main
kogu	doc_399014257203_item	3567669	et	4	main
maailmas	doc_399014257203_item	3567670	et	3	main
oleksid	doc_399014257203_item	3567671	et	4	main
püsivalt	doc_399014257203_item	3567672	et	4	main
jälgima	doc_399014257203_item	3567673	et	4	main
näide	doc_399014257203_item	3567674	et	3	main
glasgows	doc_399014257203_item	3567675	et	4	main
essee	doc_399014257204_item	3567677	et	4	main
mõõdukas	doc_399014257204_item	3567686	et	4	main
millal	doc_399014257204_item	3567687	et	3	main
paike	doc_399014257204_item	3567688	et	4	main
äärmiselt	doc_399014257204_item	3567699	et	4	main
rõhuv	doc_399014257204_item	3567700	et	4	main
talumatu	doc_399014257204_item	3567709	et	4	main
luupainaja	doc_399014257204_item	3567719	et	4	main
ma	doc_399014257204_item	3567720	et	3	main
pohmell	doc_399014257204_item	3567762	et	4	main
glasgows	doc_399014257204_item	3567764	et	4	main
roheline	doc_399014257204_item	3567769	et	4	main
ja	doc_399014257204_item	3567770	et	3	main
raamat	doc_399014257200_item	3567381	et	3	main
seerias	doc_399014257200_item	3567391	et	3	main
kirjutus	doc_399014257200_item	3567407	et	4	main
soovitama	doc_399014257200_item	3567410	et	4	main
neid	doc_399014257200_item	3567411	et	4	main
võib	doc_399014257200_item	3567412	et	3	main
olla	doc_399014257200_item	3567413	et	3	main
ma	doc_399014257200_item	3567414	et	3	main
võima	doc_399014257200_item	3567415	et	3	main
eesti	doc_399014257200_item	3567416	et	4	main
kõik	doc_399014257201_item	3567435	et	4	main
šotimaale	doc_399014257201_item	3567439	et	2	main
lennukiga	doc_399014257201_item	3567444	et	3	main
räägitakse	doc_399014257201_item	3567445	et	3	main
alkohol	doc_399014257201_item	3567462	et	3	main
suvel	doc_399014257201_item	3567463	et	3	main
parteid	doc_399014257201_item	3567464	et	4	main
muusika	doc_399014257201_item	3567467	et	4	main
tantsimakse	doc_399014257201_item	3567468	et	4	main
raskes	doc_399014257201_item	3567469	et	3	main
või	doc_399014257201_item	3567470	et	4	main
kõige	doc_399014257201_item	3567485	et	4	main
glasgows	doc_399014257201_item	3567488	et	4	main
ma	doc_399014257201_item	3567519	et	3	main
vaatama	doc_399014257201_item	3567521	et	3	main
ühiselt	doc_399014257201_item	3567524	et	4	main
oleksin	doc_399014257203_item	3567560	et	3	main
oleksin	doc_399014257203_item	3567565	et	3	main
linnapea	doc_399014257203_item	3567567	et	4	main
väga	doc_399014257203_item	3567578	et	3	main
vastik	doc_399014257203_item	3567579	et	3	main
ja	doc_399014257203_item	3567580	et	3	main
tänavelt	doc_399014257203_item	3567589	et	4	main
vaga	doc_399014257203_item	3567592	et	4	main
aeglane	doc_399014257203_item	3567593	et	3	main
ma	doc_399014257203_item	3567594	et	3	main
olen	doc_399014257203_item	3567595	et	3	main
vaga	doc_399014257203_item	3567600	et	4	main
oleksin	doc_399014257203_item	3567606	et	3	main
glasgows	doc_399014257203_item	3567616	et	4	main
koige	doc_399014257203_item	3567620	et	4	main
suurem	doc_399014257203_item	3567621	et	4	main
glasgows	doc_399014257203_item	3567623	et	4	main
mida	doc_399014257203_item	3567634	et	4	main
hea	doc_399014257203_item	3567659	et	4	main
on	doc_399014257204_item	3567684	et	4	main
harilikult	doc_399014257204_item	3567685	et	4	main
tulema	doc_399014257204_item	3567692	et	4	main
järsku	doc_399014257204_item	3567702	et	4	main
igal	doc_399014257204_item	3567704	et	3	main
öösel	doc_399014257204_item	3567705	et	4	main
vahel	doc_399014257204_item	3567708	et	4	main
glasgows	doc_399014257204_item	3567711	et	4	main
väga	doc_399014257204_item	3567713	et	3	main
suvel	doc_399014257204_item	3567766	et	3	main
väga	doc_399014257204_item	3567768	et	3	main
kõige	doc_399014257204_item	3567771	et	4	main
ilusam	doc_399014257204_item	3567772	et	4	main
ühesõnaga	doc_399014257204_item	3567773	et	3	main
roheline	doc_399014257204_item	3567777	et	4	main
aga	doc_399014257204_item	3567779	et	3	main
glasgows	doc_399014257205_item	3567833	et	4	main
buchana	doc_399014257205_item	3567836	et	4	main
kesk-glasgows	doc_399014257205_item	3567838	et	4	main
sarnased	doc_399014257205_item	3567844	et	4	main
aga	doc_399014257205_item	3567845	et	3	main
kui	doc_399014257205_item	3567852	et	3	main
topman	doc_399014257205_item	3567860	et	4	main
kulukas	doc_399014257205_item	3567866	et	4	main
aga	doc_399014257205_item	3567867	et	3	main
kõlba	doc_399014257205_item	3567877	et	4	main
ole	doc_399014257205_item	3567884	et	4	main
ainudainus	doc_399014257205_item	3567887	et	4	main
samuti	doc_399014257205_item	3567891	et	3	main
riietatud	doc_399014257205_item	3567905	et	4	main
kindel	doc_399014257205_item	3567908	et	3	main
mulle	doc_399014257205_item	3567914	et	4	main
püha	doc_399014257205_item	3567944	et	4	main
venelane	doc_399014257205_item	3567955	et	3	main
laulud	doc_399014257205_item	3567958	et	3	main
setu	doc_399014257210_item	3567971	et	4	main
inimesi	doc_399014257210_item	3567989	et	4	main
tõlkimasin	doc_399014257200_item	3567395	et	4	main
bestseller	doc_399014257200_item	3567400	et	3	main
style	doc_399014257200_item	3567408	et	4	main
suvel	doc_399014257201_item	3567505	et	3	main
lähen	doc_399014257201_item	3567506	et	3	main
ma	doc_399014257201_item	3567507	et	3	main
puhkusele	doc_399014257201_item	3567508	et	4	main
ameerikasse	doc_399014257201_item	3567509	et	4	main
san	doc_399014257201_item	3567510	et	4	main
franciscosse	doc_399014257201_item	3567511	et	4	main
las	doc_399014257201_item	3567512	et	4	main
vegasse	doc_399014257201_item	3567513	et	4	main
new	doc_399014257201_item	3567514	et	4	main
yorksse	doc_399014257201_item	3567515	et	4	main
šotimaal	doc_399014257201_item	3567427	et	2	main
suvel	doc_399014257201_item	3567428	et	3	main
on	doc_399014257201_item	3567430	et	4	main
meeldib	doc_399014257201_item	3567434	et	3	main
suvel	doc_399014257201_item	3567449	et	3	main
sõidan	doc_399014257201_item	3567452	et	3	main
nevisse	doc_399014257201_item	3567454	et	4	main
vali	doc_399014257201_item	3567466	et	4	main
ei	doc_399014257201_item	3567473	et	4	main
eesti	doc_399014257201_item	3567474	et	4	main
laulud	doc_399014257201_item	3567475	et	3	main
õnnetuseks	doc_399014257201_item	3567476	et	4	main
parki	doc_399014257201_item	3567487	et	4	main
minu	doc_399014257201_item	3567489	et	3	main
arvates	doc_399014257201_item	3567490	et	4	main
suvi	doc_399014257201_item	3567491	et	3	main
on	doc_399014257201_item	3567492	et	4	main
minnakse	doc_399014257201_item	3567497	et	3	main
ameerikasse	doc_399014257201_item	3567503	et	4	main
tänavu	doc_399014257201_item	3567504	et	3	main
vegast	doc_399014257201_item	3567518	et	4	main
lähen	doc_399014257201_item	3567520	et	3	main
vahel	doc_399014257201_item	3567525	et	4	main
räägitakse	doc_399014257201_item	3567526	et	3	main
celine	doc_399014257201_item	3567527	et	4	main
on	doc_399014257201_item	3567528	et	4	main
keskpärane	doc_399014257201_item	3567529	et	4	main
aga	doc_399014257201_item	3567530	et	3	main
ma	doc_399014257201_item	3567531	et	3	main
armistan	doc_399014257201_item	3567532	et	4	main
temad	doc_399014257201_item	3567533	et	4	main
glasgows	doc_399014257201_item	3567534	et	4	main
ülikoolis	doc_399014257201_item	3567535	et	4	main
on	doc_399014257201_item	3567536	et	4	main
väga	doc_399014257201_item	3567537	et	3	main
vaikne	doc_399014257201_item	3567538	et	3	main
suvel	doc_399014257201_item	3567539	et	3	main
vähe	doc_399014257201_item	3567540	et	3	main
õpitakse	doc_399014257201_item	3567541	et	4	main
ja	doc_399014257201_item	3567542	et	3	main
õpetatakse	doc_399014257201_item	3567543	et	3	main
palju	doc_399014257201_item	3567544	et	4	main
minnakse	doc_399014257201_item	3567545	et	3	main
koju	doc_399014257201_item	3567546	et	3	main
kohtutakse	doc_399014257201_item	3567547	et	4	main
perekondakse	doc_399014257201_item	3567548	et	4	main
ja	doc_399014257201_item	3567549	et	3	main
sõprusadkse	doc_399014257201_item	3567550	et	4	main
väga	doc_399014257201_item	3567431	et	3	main
maailma	doc_399014257201_item	3567436	et	4	main
tallakse	doc_399014257201_item	3567438	et	4	main
paljud	doc_399014257201_item	3567440	et	3	main
kõige	doc_399014257201_item	3567447	et	4	main
ben	doc_399014257201_item	3567453	et	4	main
kõige	doc_399014257201_item	3567455	et	4	main
suurem	doc_399014257201_item	3567456	et	4	main
mägi	doc_399014257201_item	3567457	et	3	main
parkist	doc_399014257201_item	3567465	et	4	main
puhul	doc_399014257201_item	3567479	et	4	main
ujukakse	doc_399014257201_item	3567480	et	4	main
ja	doc_399014257201_item	3567481	et	3	main
päevitatakse	doc_399014257201_item	3567482	et	3	main
minnakse	doc_399014257201_item	3567483	et	3	main
ilusam	doc_399014257201_item	3567486	et	4	main
augustis	doc_399014257201_item	3567516	et	3	main
las	doc_399014257201_item	3567517	et	4	main
tervislik	doc_399014257201_item	3567555	et	3	main
essee	doc_399014257203_item	3567557	et	4	main
linnapea	doc_399014257203_item	3567562	et	4	main
ma	doc_399014257203_item	3567564	et	3	main
tanavad	doc_399014257203_item	3567577	et	4	main
ma	doc_399014257203_item	3567581	et	3	main
oleksin	doc_399014257203_item	3567585	et	3	main
keelustama	doc_399014257203_item	3567587	et	3	main
on	doc_399014257203_item	3567599	et	4	main
linn	doc_399014257203_item	3567619	et	3	main
enam	doc_399014257203_item	3567635	et	4	main
seda	doc_399014257203_item	3567636	et	3	main
parem	doc_399014257203_item	3567637	et	4	main
on	doc_399014257203_item	3567658	et	4	main
sunnitöö	doc_399014257201_item	3567554	et	4	main
kui	doc_399014257203_item	3567638	et	3	main
ma	doc_399014257203_item	3567639	et	3	main
oleksin	doc_399014257203_item	3567640	et	3	main
linnapea	doc_399014257203_item	3567642	et	4	main
ma	doc_399014257203_item	3567643	et	3	main
oleksin	doc_399014257203_item	3567644	et	3	main
otsa	doc_399014257203_item	3567645	et	4	main
glasgow	doc_399014257203_item	3567641	et	4	main
lõppema	doc_399014257203_item	3567646	et	4	main
palju	doc_399014257203_item	3567647	et	4	main
raha	doc_399014257203_item	3567648	et	4	main
ülikoolis	doc_399014257203_item	3567649	et	4	main
tasuta	doc_399014257203_item	3567650	et	4	main
haridus	doc_399014257203_item	3567651	et	3	main
ja	doc_399014257203_item	3567652	et	3	main
üldharidus	doc_399014257203_item	3567653	et	3	main
on	doc_399014257203_item	3567654	et	4	main
vaga	doc_399014257203_item	3567655	et	4	main
tähtis	doc_399014257203_item	3567656	et	4	main
glasgow	doc_399014257203_item	3567561	et	4	main
kui	doc_399014257203_item	3567563	et	3	main
ma	doc_399014257203_item	3567568	et	3	main
teeksin	doc_399014257203_item	3567569	et	3	main
lõppu	doc_399014257203_item	3567570	et	4	main
tegema	doc_399014257203_item	3567571	et	3	main
inimesed	doc_399014257203_item	3567572	et	3	main
lubamasin	doc_399014257203_item	3567573	et	3	main
ma	doc_399014257203_item	3567584	et	3	main
pensionäri	doc_399014257203_item	3567588	et	4	main
nad	doc_399014257203_item	3567590	et	3	main
on	doc_399014257203_item	3567591	et	4	main
ja	doc_399014257203_item	3567602	et	3	main
linn	doc_399014257203_item	3567604	et	3	main
kindlustama	doc_399014257203_item	3567607	et	3	main
on	doc_399014257203_item	3567617	et	4	main
on	doc_399014257203_item	3567624	et	4	main
estlased	doc_399014257203_item	3567633	et	4	main
šotimaal	doc_399014257203_item	3567661	et	2	main
keelustama	doc_399014257203_item	3567662	et	3	main
paista	doc_399014257204_item	3567689	et	4	main
pimedus	doc_399014257204_item	3567706	et	4	main
on	doc_399014257204_item	3567707	et	4	main
talvel	doc_399014257204_item	3567710	et	4	main
on	doc_399014257204_item	3567712	et	4	main
tuuline	doc_399014257204_item	3567714	et	3	main
see	doc_399014257204_item	3567715	et	3	main
segatud	doc_399014257204_item	3567716	et	4	main
vihmaga	doc_399014257204_item	3567717	et	3	main
armistan	doc_399014257204_item	3567726	et	4	main
plats	doc_399014257204_item	3567778	et	4	main
essee	doc_399014257205_item	3567818	et	4	main
ma	doc_399014257205_item	3567821	et	3	main
tegema	doc_399014257205_item	3567823	et	3	main
minema	doc_399014257205_item	3567824	et	3	main
kain	doc_399014257205_item	3567826	et	3	main
aegajalt	doc_399014257205_item	3567827	et	3	main
kaubamajas	doc_399014257205_item	3567834	et	3	main
glasgows	doc_399014257205_item	3567839	et	4	main
palju	doc_399014257205_item	3567841	et	4	main
kaubamaja	doc_399014257205_item	3567842	et	4	main
väga	doc_399014257205_item	3567843	et	3	main
minema	doc_399014257205_item	3567851	et	3	main
mul	doc_399014257205_item	3567853	et	3	main
zara	doc_399014257205_item	3567862	et	4	main
on	doc_399014257205_item	3567870	et	4	main
alati	doc_399014257205_item	3567871	et	4	main
zara	doc_399014257205_item	3567873	et	4	main
püksid	doc_399014257205_item	3567874	et	3	main
kandmiseks	doc_399014257205_item	3567886	et	4	main
ameeriklane	doc_399014257205_item	3567893	et	3	main
abercrombie	doc_399014257205_item	3567895	et	4	main
riided	doc_399014257205_item	3567898	et	3	main
ma	doc_399014257205_item	3567899	et	3	main
ma	doc_399014257205_item	3567901	et	3	main
järgi	doc_399014257205_item	3567904	et	4	main
olen	doc_399014257205_item	3567907	et	3	main
teised	doc_399014257205_item	3567909	et	4	main
nõustuma	doc_399014257205_item	3567912	et	3	main
palju	doc_399014257205_item	3567935	et	4	main
on	doc_399014257205_item	3567939	et	4	main
kõige	doc_399014257205_item	3567940	et	4	main
üles	doc_399014257205_item	3567947	et	3	main
või	doc_399014257205_item	3567948	et	4	main
kokku	doc_399014257205_item	3567949	et	3	main
ostma	doc_399014257205_item	3567950	et	3	main
kohalik	doc_399014257205_item	3567951	et	3	main
produtseerima	doc_399014257205_item	3567952	et	3	main
viin	doc_399014257205_item	3567956	et	4	main
ameeriklane	doc_399014257205_item	3567959	et	3	main
ma	doc_399014257205_item	3567961	et	3	main
glasgows	doc_399014257203_item	3567608	et	4	main
jäänused	doc_399014257203_item	3567609	et	3	main
see	doc_399014257203_item	3567610	et	3	main
tee	doc_399014257203_item	3567611	et	4	main
nii	doc_399014257203_item	3567612	et	3	main
oleks	doc_399014257203_item	3567613	et	3	main
suur	doc_399014257203_item	3567618	et	3	main
šotimaal	doc_399014257203_item	3567622	et	2	main
väga	doc_399014257203_item	3567625	et	3	main
paljurassiline	doc_399014257203_item	3567626	et	4	main
mulle	doc_399014257203_item	3567627	et	4	main
meeldib	doc_399014257203_item	3567628	et	3	main
ma	doc_399014257203_item	3567629	et	3	main
oskama	doc_399014257203_item	3567630	et	3	main
palju	doc_399014257203_item	3567631	et	4	main
mul	doc_399014257203_item	3567657	et	3	main
glasgows	doc_399014257204_item	3567678	et	4	main
minu	doc_399014257204_item	3567680	et	3	main
meie	doc_399014257204_item	3567690	et	4	main
talvet	doc_399014257204_item	3567694	et	4	main
päeva	doc_399014257204_item	3567701	et	4	main
on	doc_399014257204_item	3567718	et	4	main
halvasti	doc_399014257204_item	3567763	et	3	main
linn	doc_399014257204_item	3567765	et	3	main
on	doc_399014257204_item	3567767	et	4	main
tõlgitsema	doc_399014257204_item	3567775	et	3	main
armas	doc_399014257204_item	3567776	et	3	main
ma	doc_399014257205_item	3567825	et	3	main
ostma	doc_399014257205_item	3567830	et	3	main
tegema	doc_399014257205_item	3567850	et	3	main
on	doc_399014257205_item	3567854	et	4	main
mulle	doc_399014257205_item	3567856	et	4	main
ka	doc_399014257205_item	3567861	et	3	main
zara	doc_399014257205_item	3567863	et	4	main
on	doc_399014257205_item	3567864	et	4	main
riided	doc_399014257205_item	3567869	et	3	main
heakvaliteediline	doc_399014257205_item	3567872	et	4	main
ja	doc_399014257205_item	3567875	et	3	main
kuubi	doc_399014257205_item	3567876	et	4	main
riidedi	doc_399014257205_item	3567882	et	4	main
ei	doc_399014257205_item	3567883	et	4	main
juhust	doc_399014257205_item	3567889	et	4	main
ma	doc_399014257205_item	3567890	et	3	main
meeldib	doc_399014257205_item	3567892	et	3	main
kaubamärk	doc_399014257205_item	3567894	et	3	main
fitch	doc_399014257205_item	3567896	et	4	main
tahaksin	doc_399014257205_item	3567900	et	3	main
moe	doc_399014257205_item	3567903	et	3	main
amazoncouk	doc_399014257205_item	3567933	et	4	main
nii	doc_399014257205_item	3567934	et	3	main
mina	doc_399014257205_item	3567937	et	4	main
pidama	doc_399014257205_item	3567945	et	4	main
ma	doc_399014257205_item	3567946	et	3	main
inimesed	doc_399014257210_item	3567972	et	3	main
peipsi	doc_399014257210_item	3567976	et	4	main
nad	doc_399014257210_item	3567977	et	3	main
on	doc_399014257210_item	3567978	et	4	main
ei	doc_399014257210_item	3567991	et	4	main
setumaa	doc_399014257210_item	3568000	et	4	main
traditsioon	doc_399014257210_item	3568004	et	3	main
tugev	doc_399014257210_item	3568012	et	4	main
on	doc_399014257210_item	3568022	et	4	main
tagasi	doc_399014257210_item	3568028	et	3	main
oli	doc_399014257210_item	3568030	et	3	main
deklareerimas	doc_399014257210_item	3568031	et	3	main
kuningriik	doc_399014257210_item	3568032	et	3	main
aga	doc_399014257210_item	3568033	et	3	main
see	doc_399014257210_item	3568034	et	3	main
oli	doc_399014257210_item	3568035	et	3	main
ühel	doc_399014257210_item	3568036	et	3	main
midagi	doc_399014257210_item	3568043	et	4	main
on	doc_399014257210_item	3568068	et	4	main
vähesed	doc_399014257210_item	3568070	et	3	main
saama	doc_399014257210_item	3568072	et	4	main
neid	doc_399014257210_item	3568073	et	4	main
teine	doc_399014257210_item	3568074	et	3	main
tallinnas	doc_399014257211_item	3568093	et	4	main
suvel	doc_399014257211_item	3568094	et	3	main
ebaharilik	doc_399014257211_item	3568110	et	3	main
keerukas	doc_399014257211_item	3568113	et	4	main
rohkem	doc_399014257211_item	3568121	et	4	main
on	doc_399014257211_item	3568128	et	4	main
arvatud	doc_399014257204_item	3567758	et	4	main
kui	doc_399014257204_item	3567759	et	3	main
ma	doc_399014257204_item	3567760	et	3	main
olen	doc_399014257204_item	3567761	et	3	main
ilm	doc_399014257204_item	3567679	et	3	main
meelest	doc_399014257204_item	3567681	et	4	main
glasgows	doc_399014257204_item	3567682	et	4	main
ilm	doc_399014257204_item	3567683	et	3	main
võidumeheks	doc_399014257204_item	3567691	et	3	main
glasgows	doc_399014257204_item	3567693	et	4	main
on	doc_399014257204_item	3567695	et	4	main
väga	doc_399014257204_item	3567696	et	3	main
pikk	doc_399014257204_item	3567697	et	4	main
ja	doc_399014257204_item	3567698	et	3	main
katkestama	doc_399014257204_item	3567703	et	3	main
olen	doc_399014257204_item	3567721	et	3	main
niiske	doc_399014257204_item	3567722	et	4	main
luudest	doc_399014257204_item	3567723	et	3	main
vabastama	doc_399014257204_item	3567724	et	3	main
ma	doc_399014257204_item	3567725	et	3	main
glasgows	doc_399014257204_item	3567727	et	4	main
suvel	doc_399014257204_item	3567728	et	3	main
on	doc_399014257204_item	3567730	et	4	main
videvik	doc_399014257204_item	3567729	et	3	main
umbes	doc_399014257204_item	3567731	et	4	main
poole	doc_399014257204_item	3567732	et	4	main
üksteist	doc_399014257204_item	3567733	et	4	main
kell	doc_399014257204_item	3567734	et	3	main
ja	doc_399014257204_item	3567735	et	3	main
tihti	doc_399014257204_item	3567736	et	3	main
hiljem	doc_399014257204_item	3567737	et	3	main
paikesetõus	doc_399014257204_item	3567738	et	4	main
on	doc_399014257204_item	3567739	et	4	main
umbes	doc_399014257204_item	3567740	et	4	main
poole	doc_399014257204_item	3567741	et	4	main
neli	doc_399014257204_item	3567742	et	3	main
kell	doc_399014257204_item	3567743	et	3	main
väga	doc_399014257204_item	3567744	et	3	main
hästi	doc_399014257204_item	3567745	et	3	main
ehkki	doc_399014257204_item	3567746	et	3	main
magama	doc_399014257204_item	3567747	et	3	main
jäama	doc_399014257204_item	3567748	et	4	main
oskan	doc_399014257204_item	3567749	et	3	main
raske	doc_399014257204_item	3567750	et	4	main
suvel	doc_399014257204_item	3567751	et	3	main
ma	doc_399014257204_item	3567752	et	3	main
olen	doc_399014257204_item	3567753	et	3	main
tõuseb	doc_399014257204_item	3567754	et	3	main
vara	doc_399014257204_item	3567755	et	4	main
üles	doc_399014257204_item	3567756	et	3	main
välja	doc_399014257204_item	3567757	et	4	main
glasgows	doc_399014257204_item	3567774	et	4	main
ainus	doc_399014257204_item	3567780	et	4	main
tõeline	doc_399014257204_item	3567781	et	4	main
suvel	doc_399014257204_item	3567782	et	3	main
ma	doc_399014257204_item	3567783	et	3	main
armistan	doc_399014257204_item	3567784	et	4	main
päike	doc_399014257204_item	3567785	et	3	main
paista	doc_399014257204_item	3567786	et	4	main
suvel	doc_399014257204_item	3567787	et	3	main
ma	doc_399014257204_item	3567788	et	3	main
olen	doc_399014257204_item	3567789	et	3	main
tuju	doc_399014257204_item	3567791	et	4	main
kellgi	doc_399014257204_item	3567790	et	3	main
heaks	doc_399014257204_item	3567792	et	4	main
tegema	doc_399014257204_item	3567793	et	3	main
töömeeleolus	doc_399014257204_item	3567794	et	3	main
ma	doc_399014257204_item	3567795	et	3	main
rõõmuga	doc_399014257204_item	3567796	et	3	main
ootama	doc_399014257204_item	3567797	et	3	main
suvi	doc_399014257204_item	3567798	et	3	main
aga	doc_399014257204_item	3567799	et	3	main
ka	doc_399014257204_item	3567800	et	3	main
kevadine	doc_399014257204_item	3567801	et	4	main
kui	doc_399014257204_item	3567803	et	3	main
ilm	doc_399014257204_item	3567804	et	3	main
parandama	doc_399014257204_item	3567805	et	3	main
aeg	doc_399014257204_item	3567802	et	3	main
tähendusrikasaline	doc_399014257204_item	3567806	et	4	main
ma	doc_399014257204_item	3567807	et	3	main
kartma	doc_399014257204_item	3567808	et	3	main
talv	doc_399014257204_item	3567809	et	3	main
vihaga	doc_399014257204_item	3567810	et	4	main
sügis	doc_399014257204_item	3567811	et	3	main
on	doc_399014257204_item	3567812	et	4	main
allpool	doc_399014257204_item	3567813	et	3	main
asetsev	doc_399014257204_item	3567814	et	4	main
teekonda	doc_399014257204_item	3567815	et	4	main
talv	doc_399014257204_item	3567816	et	3	main
tegema	doc_399014257205_item	3567820	et	3	main
linnas	doc_399014257205_item	3567832	et	4	main
nimeline	doc_399014257205_item	3567835	et	4	main
galerii	doc_399014257205_item	3567837	et	4	main
oste	doc_399014257205_item	3567849	et	3	main
zara	doc_399014257205_item	3567868	et	4	main
spetsiaalne	doc_399014257205_item	3567888	et	3	main
ma	doc_399014257205_item	3567906	et	3	main
oste	doc_399014257205_item	3567819	et	3	main
harva	doc_399014257205_item	3567822	et	4	main
harilikult	doc_399014257205_item	3567828	et	4	main
ma	doc_399014257205_item	3567829	et	3	main
riided	doc_399014257205_item	3567831	et	3	main
on	doc_399014257205_item	3567840	et	4	main
vaga	doc_399014257205_item	3567846	et	4	main
hästi	doc_399014257205_item	3567847	et	3	main
ma	doc_399014257205_item	3567848	et	3	main
aega	doc_399014257205_item	3567855	et	4	main
meeldiv	doc_399014257205_item	3567857	et	4	main
hm	doc_399014257205_item	3567858	et	3	main
ja	doc_399014257205_item	3567859	et	3	main
vahel	doc_399014257205_item	3567865	et	4	main
hästi	doc_399014257205_item	3567878	et	3	main
hea	doc_399014257205_item	3567879	et	4	main
lõikama	doc_399014257205_item	3567880	et	3	main
zara	doc_399014257205_item	3567881	et	4	main
igapäevaseks	doc_399014257205_item	3567885	et	4	main
ebaharilik	doc_399014257205_item	3567897	et	3	main
viimase	doc_399014257205_item	3567902	et	3	main
mitte	doc_399014257205_item	3567911	et	3	main
ütelge	doc_399014257205_item	3567913	et	3	main
tingimata	doc_399014257205_item	3567915	et	4	main
ma	doc_399014257205_item	3567916	et	3	main
tegelikult	doc_399014257205_item	3567917	et	4	main
pida	doc_399014257205_item	3567918	et	4	main
eelistama	doc_399014257205_item	3567919	et	3	main
oste	doc_399014257205_item	3567920	et	3	main
tegema	doc_399014257205_item	3567921	et	3	main
interneril	doc_399014257205_item	3567922	et	4	main
tihti	doc_399014257205_item	3567923	et	3	main
muusika	doc_399014257205_item	3567924	et	4	main
ja	doc_399014257205_item	3567925	et	3	main
raamatu	doc_399014257205_item	3567926	et	4	main
on	doc_399014257205_item	3567927	et	4	main
odavem	doc_399014257205_item	3567928	et	4	main
inimesed	doc_399014257205_item	3567910	et	3	main
mulle	doc_399014257205_item	3567929	et	4	main
meeldib	doc_399014257205_item	3567930	et	3	main
see	doc_399014257205_item	3567931	et	3	main
väga	doc_399014257205_item	3567932	et	3	main
odavam	doc_399014257205_item	3567941	et	4	main
millal	doc_399014257205_item	3567942	et	3	main
ma	doc_399014257205_item	3567943	et	3	main
kalkunil	doc_399014257205_item	3567953	et	3	main
setu	doc_399014257210_item	3567969	et	4	main
järv	doc_399014257210_item	3567975	et	3	main
rohkem	doc_399014257210_item	3568006	et	4	main
kui	doc_399014257210_item	3568007	et	3	main
teine	doc_399014257210_item	3568008	et	3	main
setu	doc_399014257210_item	3568009	et	4	main
inimesed	doc_399014257210_item	3568010	et	3	main
eestiga	doc_399014257210_item	3568017	et	4	main
ja	doc_399014257210_item	3568018	et	3	main
arutama	doc_399014257210_item	3568025	et	3	main
aastat	doc_399014257210_item	3568027	et	3	main
setumaa	doc_399014257210_item	3568029	et	4	main
päeval	doc_399014257210_item	3568037	et	3	main
inimesed	doc_399014257210_item	3568045	et	3	main
reps	doc_399014257210_item	3568047	et	4	main
poliitik	doc_399014257210_item	3568048	et	3	main
teada	doc_399014257210_item	3568071	et	3	main
on	doc_399014257210_item	3568079	et	4	main
võru	doc_399014257210_item	3568080	et	4	main
kui	doc_399014257205_item	3567936	et	3	main
tean	doc_399014257205_item	3567938	et	3	main
rõõmu	doc_399014257205_item	3567954	et	4	main
eesti	doc_399014257205_item	3567957	et	4	main
riided	doc_399014257205_item	3567960	et	3	main
pean	doc_399014257205_item	3567962	et	4	main
lõppu	doc_399014257205_item	3567963	et	4	main
tegema	doc_399014257205_item	3567964	et	3	main
võlgadesse	doc_399014257205_item	3567965	et	3	main
sattuma	doc_399014257205_item	3567966	et	3	main
essee	doc_399014257210_item	3567968	et	4	main
elab	doc_399014257210_item	3567973	et	3	main
eestis	doc_399014257210_item	3567990	et	3	main
elab	doc_399014257210_item	3567994	et	3	main
on	doc_399014257210_item	3568011	et	4	main
venemaaga	doc_399014257210_item	3568019	et	3	main
rohkem	doc_399014257210_item	3568042	et	4	main
pindala	doc_399014257210_item	3568075	et	4	main
eestis	doc_399014257210_item	3568076	et	3	main
dialektiline	doc_399014257210_item	3568077	et	4	main
linn	doc_399014257210_item	3568078	et	3	main
pärn	doc_399014257211_item	3568084	et	3	main
pärn	doc_399014257211_item	3568086	et	3	main
eestlane	doc_399014257211_item	3568088	et	3	main
oli	doc_399014257211_item	3568090	et	3	main
tema	doc_399014257211_item	3568096	et	4	main
ta	doc_399014257211_item	3568100	et	4	main
tegisin	doc_399014257211_item	3568101	et	4	main
film	doc_399014257211_item	3568102	et	3	main
kolmnurk	doc_399014257211_item	3568103	et	3	main
kolmnurk	doc_399014257211_item	3568104	et	3	main
on	doc_399014257211_item	3568105	et	4	main
väga	doc_399014257211_item	3568106	et	3	main
priit	doc_399014257211_item	3568115	et	3	main
on	doc_399014257211_item	3568188	et	4	main
hiljuti	doc_399014257210_item	3568049	et	4	main
räägisin	doc_399014257210_item	3568050	et	4	main
eestima	doc_399014257210_item	3568051	et	4	main
mitte	doc_399014257210_item	3568052	et	3	main
sugugi	doc_399014257210_item	3568053	et	4	main
ära	doc_399014257210_item	3568054	et	4	main
tundma	doc_399014257210_item	3568055	et	3	main
setu	doc_399014257210_item	3568056	et	4	main
keeles	doc_399014257210_item	3568057	et	4	main
kohaliks	doc_399014257210_item	3568058	et	3	main
elaniks	doc_399014257210_item	3568059	et	4	main
eesti	doc_399014257210_item	3568060	et	4	main
keelt	doc_399014257210_item	3568061	et	4	main
on	doc_399014257210_item	3568062	et	4	main
teenistuskeel	doc_399014257210_item	3568063	et	4	main
eestimaa	doc_399014257210_item	3568064	et	4	main
räägitakse	doc_399014257210_item	3568065	et	3	main
setu	doc_399014257210_item	3568066	et	4	main
inimesed	doc_399014257210_item	3568067	et	3	main
inimesed	doc_399014257210_item	3567970	et	3	main
kõrval	doc_399014257210_item	3567974	et	4	main
estlane	doc_399014257210_item	3567979	et	4	main
aga	doc_399014257210_item	3567980	et	3	main
räägib	doc_399014257210_item	3567981	et	3	main
nende	doc_399014257210_item	3567982	et	4	main
oma	doc_399014257210_item	3567983	et	4	main
dialekt	doc_399014257210_item	3567984	et	3	main
nad	doc_399014257210_item	3567985	et	3	main
on	doc_399014257210_item	3567986	et	4	main
ortodoksne	doc_399014257210_item	3567987	et	3	main
enamik	doc_399014257210_item	3567988	et	3	main
ole	doc_399014257210_item	3567992	et	4	main
lõuna	doc_399014257210_item	3567995	et	4	main
kõrval	doc_399014257210_item	3567997	et	4	main
venemaa	doc_399014257210_item	3567998	et	4	main
piirjoon	doc_399014257210_item	3567999	et	3	main
pühitsema	doc_399014257210_item	3568003	et	3	main
millegi	doc_399014257210_item	3568013	et	4	main
ees	doc_399014257210_item	3568014	et	4	main
võim	doc_399014257210_item	3568015	et	3	main
heitlema	doc_399014257210_item	3568016	et	3	main
väljuma	doc_399014257210_item	3568021	et	3	main
praegu	doc_399014257210_item	3568023	et	3	main
kolmteist	doc_399014257210_item	3568026	et	4	main
praegu	doc_399014257210_item	3568039	et	3	main
teatatakse	doc_399014257210_item	3568041	et	3	main
suremine	doc_399014257210_item	3568069	et	4	main
on	doc_399014257211_item	3568087	et	4	main
on	doc_399014257211_item	3568097	et	4	main
tootja	doc_399014257211_item	3568099	et	4	main
armulugu	doc_399014257211_item	3568114	et	4	main
kõige	doc_399014257211_item	3568120	et	4	main
oma	doc_399014257211_item	3568122	et	4	main
filmid	doc_399014257211_item	3568123	et	4	main
on	doc_399014257211_item	3568124	et	4	main
aga	doc_399014257211_item	3568130	et	3	main
mõnikord	doc_399014257211_item	3568131	et	3	main
tema	doc_399014257211_item	3568187	et	4	main
nad	doc_399014257210_item	3567993	et	3	main
eestis	doc_399014257210_item	3567996	et	3	main
setu	doc_399014257210_item	3568001	et	4	main
inimesed	doc_399014257210_item	3568002	et	3	main
laulja	doc_399014257210_item	3568005	et	4	main
setu	doc_399014257210_item	3568020	et	4	main
avalikult	doc_399014257210_item	3568024	et	4	main
ainus	doc_399014257210_item	3568038	et	4	main
massimeedi	doc_399014257210_item	3568040	et	4	main
setu	doc_399014257210_item	3568044	et	4	main
meilis	doc_399014257210_item	3568046	et	4	main
essee	doc_399014257211_item	3568082	et	4	main
priit	doc_399014257211_item	3568085	et	3	main
1946	doc_399014257211_item	3568095	et	2	main
huvitav	doc_399014257211_item	3568107	et	4	main
väga	doc_399014257211_item	3568109	et	3	main
inimesed	doc_399014257211_item	3568112	et	3	main
karjäär	doc_399014257211_item	3568117	et	3	main
1974	doc_399014257211_item	3568119	et	2	main
elustusi	doc_399014257211_item	3568125	et	4	main
tema	doc_399014257211_item	3568126	et	4	main
stiil	doc_399014257211_item	3568127	et	3	main
elas	doc_399014257211_item	3568184	et	3	main
väga	doc_399014257211_item	3568189	et	3	main
mees	doc_399014257211_item	3568192	et	4	main
aeg	doc_399014257211_item	3568163	et	3	main
saavutus	doc_399014257211_item	3568164	et	4	main
määrama	doc_399014257211_item	3568165	et	3	main
talle	doc_399014257211_item	3568166	et	4	main
anti	doc_399014257211_item	3568167	et	3	main
kuldmedal	doc_399014257211_item	3568168	et	3	main
rahvusvahelisest	doc_399014257211_item	3568169	et	4	main
elavist	doc_399014257211_item	3568170	et	4	main
filmist	doc_399014257211_item	3568171	et	4	main
läbikäiminest	doc_399014257211_item	3568172	et	4	main
alates	doc_399014257211_item	3568173	et	3	main
1994	doc_399014257211_item	3568174	et	2	main
priit	doc_399014257211_item	3568175	et	3	main
pärn	doc_399014257211_item	3568176	et	3	main
õpetas	doc_399014257211_item	3568177	et	3	main
elustus	doc_399014257211_item	3568178	et	4	main
kunstikoolis	doc_399014257211_item	3568179	et	4	main
kunst	doc_399014257211_item	3568180	et	3	main
akadeemias	doc_399014257211_item	3568181	et	3	main
tema	doc_399014257211_item	3568183	et	4	main
soomes	doc_399014257211_item	3568182	et	4	main
priit	doc_399014257211_item	3568083	et	3	main
tema	doc_399014257211_item	3568089	et	4	main
sündinud	doc_399014257211_item	3568091	et	4	main
eestis	doc_399014257211_item	3568092	et	3	main
film	doc_399014257211_item	3568098	et	3	main
ja	doc_399014257211_item	3568108	et	3	main
kolm	doc_399014257211_item	3568111	et	3	main
pärn	doc_399014257211_item	3568116	et	3	main
algas	doc_399014257211_item	3568118	et	3	main
raske	doc_399014257211_item	3568132	et	4	main
järgmine	doc_399014257211_item	3568133	et	3	main
tema	doc_399014257211_item	3568134	et	4	main
teine	doc_399014257211_item	3568135	et	3	main
filmid	doc_399014257211_item	3568136	et	4	main
sisadama	doc_399014257211_item	3568137	et	4	main
hommikusöök	doc_399014257211_item	3568138	et	3	main
peale	doc_399014257211_item	3568139	et	4	main
kaeba1987	doc_399014257211_item	3568140	et	4	main
ja	doc_399014257211_item	3568141	et	3	main
porgandite	doc_399014257211_item	3568142	et	3	main
öö	doc_399014257211_item	3568143	et	4	main
1998	doc_399014257211_item	3568144	et	2	main
priit	doc_399014257211_item	3568145	et	3	main
parnil	doc_399014257211_item	3568146	et	4	main
still	doc_399014257211_item	3568147	et	4	main
on	doc_399014257211_item	3568148	et	4	main
samasugune	doc_399014257211_item	3568149	et	3	main
rugrats	doc_399014257211_item	3568150	et	4	main
ja	doc_399014257211_item	3568151	et	3	main
teine	doc_399014257211_item	3568152	et	3	main
elustusi	doc_399014257211_item	3568153	et	4	main
tema	doc_399014257211_item	3568154	et	4	main
võitsin	doc_399014257211_item	3568155	et	3	main
palju	doc_399014257211_item	3568156	et	4	main
määrama	doc_399014257211_item	3568157	et	3	main
aaastal	doc_399014257211_item	3568158	et	4	main
2002	doc_399014257211_item	3568159	et	2	main
tema	doc_399014257211_item	3568160	et	4	main
üldkehtiv	doc_399014257211_item	3568161	et	3	main
elu	doc_399014257211_item	3568162	et	4	main
turkus	doc_399014257211_item	3568185	et	4	main
soomes	doc_399014257211_item	3568186	et	4	main
eestlane	doc_399014257211_item	3568191	et	3	main
huvitav	doc_399014257211_item	3568129	et	4	main
kuulsus	doc_399014257211_item	3568190	et	4	main
seepärast	doc_120968879146_item	3568700	et	3	main
liidu	doc_120968879146_item	3568704	et	3	main
30	doc_120968879146_item	3568716	et	2	main
septembril	doc_120968879146_item	3568717	et	3	main
e	doc_120968879146_item	3568721	et	4	main
korteris	doc_120968879146_item	3568723	et	3	main
sõbranna	doc_120968879146_item	3568733	et	4	main
tulime	doc_120968879146_item	3568734	et	3	main
peaaegu	doc_120968879146_item	3568735	et	3	main
algusel	doc_120968879146_item	3568736	et	4	main
kõk	doc_120968879146_item	3568740	et	4	main
me	doc_120968879146_item	3568744	et	4	main
ainult	doc_120968879146_item	3568745	et	4	main
vestlesime	doc_120968879146_item	3568746	et	3	main
ja	doc_120968879146_item	3568747	et	3	main
teinud	doc_120968879146_item	3568774	et	4	main
lugesid	doc_120968879146_item	3568778	et	4	main
oli	doc_120968879146_item	3568798	et	3	main
vaatamata	doc_120968879146_item	3568802	et	4	main
see	doc_120968879146_item	3568804	et	3	main
oli	doc_120968879146_item	3568809	et	3	main
õhku	doc_120968879146_item	3568827	et	4	main
mitmekesisus	doc_120968879146_item	3568831	et	4	main
olen	doc_120968879146_item	3568690	et	3	main
otsustasin	doc_120968879146_item	3568702	et	3	main
xxx	doc_120968879146_item	3568705	et	4	main
avamise	doc_120968879146_item	3568707	et	4	main
oli	doc_120968879146_item	3568710	et	3	main
mina	doc_120968879146_item	3568730	et	4	main
ja	doc_120968879146_item	3568731	et	3	main
minu	doc_120968879146_item	3568732	et	3	main
et	doc_120968879146_item	3568739	et	3	main
hilineb	doc_120968879146_item	3568741	et	3	main
tund	doc_120968879146_item	3568743	et	3	main
ma	doc_120968879146_item	3568772	et	3	main
stiilis	doc_120968879146_item	3568781	et	4	main
lõpetaks	doc_120968879146_item	3568782	et	4	main
seda	doc_120968879146_item	3568783	et	3	main
proosast	doc_120968879146_item	3568784	et	4	main
see	doc_120968879146_item	3568797	et	3	main
atmosfäärne	doc_120968879146_item	3568800	et	3	main
toimub	doc_120968879146_item	3568805	et	3	main
korteris	doc_120968879146_item	3568806	et	3	main
väga	doc_120968879146_item	3568810	et	3	main
natuke	doc_120968879146_item	3568816	et	4	main
jalle	doc_120968879146_item	3568817	et	4	main
ja	doc_120968879146_item	3568828	et	3	main
muljate	doc_120968879146_item	3568830	et	3	main
essee	doc_120968879146_item	3568688	et	4	main
mida	doc_120968879146_item	3568693	et	4	main
kirjanduse	doc_120968879146_item	3568703	et	3	main
kõik	doc_120968879146_item	3568714	et	4	main
juhtus	doc_120968879146_item	3568715	et	3	main
õhtul	doc_120968879146_item	3568718	et	3	main
tutvusime	doc_120968879146_item	3568748	et	4	main
aga	doc_120968879146_item	3568775	et	3	main
kõik	doc_120968879146_item	3568777	et	4	main
luuletusi	doc_120968879146_item	3568779	et	4	main
avangardi	doc_120968879146_item	3568780	et	4	main
mulle	doc_120968879146_item	3568785	et	4	main
ka	doc_120968879146_item	3568786	et	3	main
teinud	doc_120968879146_item	3568788	et	4	main
autor	doc_120968879146_item	3568789	et	3	main
viimaks	doc_120968879146_item	3568790	et	4	main
me	doc_120968879146_item	3568791	et	4	main
bandi	doc_120968879146_item	3568792	et	4	main
nimi	doc_120968879146_item	3568793	et	3	main
ära	doc_120968879146_item	3568794	et	4	main
kus	doc_120968879146_item	3568689	et	3	main
käinud	doc_120968879146_item	3568691	et	4	main
ja	doc_120968879146_item	3568692	et	3	main
olen	doc_120968879146_item	3568694	et	3	main
näinud	doc_120968879146_item	3568695	et	4	main
september	doc_120968879146_item	3568696	et	3	main
oli	doc_120968879146_item	3568697	et	3	main
üsna	doc_120968879146_item	3568698	et	3	main
igav	doc_120968879146_item	3568699	et	3	main
hooaja	doc_120968879146_item	3568706	et	3	main
külastada	doc_120968879146_item	3568708	et	3	main
see	doc_120968879146_item	3568711	et	3	main
kel	doc_120968879146_item	3568719	et	3	main
perekonnanimi	doc_120968879146_item	3568722	et	3	main
ta	doc_120968879146_item	3568724	et	4	main
on	doc_120968879146_item	3568725	et	4	main
see	doc_120968879146_item	3568726	et	3	main
kirjanduse	doc_120968879146_item	3568727	et	3	main
liidu	doc_120968879146_item	3568728	et	3	main
aga	doc_120968879146_item	3568737	et	3	main
pole	doc_120968879146_item	3568773	et	3	main
pole	doc_120968879146_item	3568787	et	3	main
esinemine	doc_120968879146_item	3568801	et	4	main
et	doc_120968879146_item	3568803	et	3	main
bandi	doc_120968879146_item	3568807	et	4	main
hea	doc_120968879146_item	3568811	et	4	main
nende	doc_120968879146_item	3568813	et	4	main
esinemiseks	doc_120968879146_item	3568814	et	4	main
lugejaste	doc_120968879146_item	3568770	et	4	main
nimi	doc_120968879146_item	3568771	et	3	main
ma	doc_120968879146_item	3568701	et	3	main
nimi	doc_120968879146_item	3568709	et	3	main
ürituse	doc_120968879146_item	3568712	et	4	main
nimitus	doc_120968879146_item	3568713	et	4	main
viis	doc_120968879146_item	3568720	et	4	main
asustaja	doc_120968879146_item	3568729	et	4	main
sellepärast	doc_120968879146_item	3568738	et	3	main
esimine	doc_120968879146_item	3568742	et	4	main
uuega	doc_120968879146_item	3568749	et	3	main
inimestega	doc_120968879146_item	3568750	et	3	main
kõik	doc_120968879146_item	3568751	et	4	main
algas	doc_120968879146_item	3568752	et	3	main
umbes	doc_120968879146_item	3568753	et	4	main
kell	doc_120968879146_item	3568754	et	3	main
seitse	doc_120968879146_item	3568755	et	3	main
millal	doc_120968879146_item	3568756	et	3	main
e	doc_120968879146_item	3568757	et	4	main
perekonnanimi	doc_120968879146_item	3568758	et	3	main
alustas	doc_120968879146_item	3568759	et	3	main
luuletusi	doc_120968879146_item	3568760	et	4	main
lugema	doc_120968879146_item	3568761	et	4	main
tema	doc_120968879146_item	3568762	et	4	main
luuletused	doc_120968879146_item	3568763	et	4	main
oli	doc_120968879146_item	3568764	et	3	main
lüürilised	doc_120968879146_item	3568765	et	3	main
ja	doc_120968879146_item	3568766	et	3	main
natuke	doc_120968879146_item	3568767	et	4	main
süngused	doc_120968879146_item	3568768	et	4	main
teiste	doc_120968879146_item	3568769	et	4	main
nad	doc_120968879146_item	3568776	et	3	main
ootasime	doc_120968879146_item	3568795	et	3	main
nii	doc_120968879146_item	3568799	et	3	main
me	doc_120968879146_item	3568815	et	4	main
vaat	doc_120968879146_item	3568796	et	4	main
heli	doc_120968879146_item	3568808	et	4	main
pärast	doc_120968879146_item	3568812	et	4	main
vestlisime	doc_120968879146_item	3568818	et	4	main
uue	doc_120968879146_item	3568819	et	3	main
sõpradega	doc_120968879146_item	3568820	et	3	main
ja	doc_120968879146_item	3568821	et	3	main
lähme	doc_120968879146_item	3568822	et	3	main
koju	doc_120968879146_item	3568823	et	3	main
see	doc_120968879146_item	3568824	et	3	main
oli	doc_120968879146_item	3568825	et	3	main
suurepärane	doc_120968879146_item	3568826	et	4	main
hea	doc_120968879146_item	3568829	et	4	main
ülikool	doc_187964557905_item	3569099	et	4	main
selle	doc_187964557905_item	3569119	et	4	main
ülikooli	doc_187964557905_item	3569126	et	4	main
võrkpalli	doc_187964557905_item	3569127	et	4	main
minu	doc_187964557905_item	3569129	et	3	main
eriala	doc_187964557905_item	3569130	et	4	main
nimi	doc_187964557905_item	3569131	et	3	main
on	doc_187964557905_item	3569132	et	4	main
sest	doc_187964557905_item	3569139	et	4	main
arvates	doc_187964557905_item	3569141	et	4	main
see	doc_187964557905_item	3569142	et	3	main
on	doc_187964557905_item	3569143	et	4	main
väga	doc_187964557905_item	3569144	et	3	main
sisteemid	doc_187964557905_item	3569150	et	4	main
robotid	doc_187964557905_item	3569151	et	3	main
ja	doc_187964557905_item	3569152	et	3	main
mina	doc_187964557909_item	3569219	et	4	main
elas	doc_187964557909_item	3569229	et	3	main
linn	doc_187964557909_item	3569244	et	3	main
valin	doc_187964557909_item	3569247	et	3	main
mulle	doc_187964557909_item	3569252	et	4	main
et	doc_187964557909_item	3569293	et	3	main
suhtlemis	doc_187964557909_item	3569311	et	4	main
väga	doc_187964557909_item	3569315	et	3	main
ma	doc_187964557909_item	3569322	et	3	main
siin	doc_187964557909_item	3569325	et	4	main
essee	doc_213943984911_item	3569368	et	4	main
rongiga	doc_213943984911_item	3569370	et	4	main
essee	doc_187964557905_item	3569096	et	4	main
eesnimi	doc_187964557905_item	3569103	et	3	main
pähklimäe	doc_187964557905_item	3569108	et	3	main
umbes	doc_187964557905_item	3569112	et	4	main
kuus	doc_187964557905_item	3569113	et	4	main
aastat	doc_187964557905_item	3569114	et	3	main
ma	doc_187964557905_item	3569115	et	3	main
tegelen	doc_187964557905_item	3569116	et	3	main
spordiga	doc_187964557905_item	3569117	et	3	main
võrkpallis	doc_187964557905_item	3569118	et	3	main
tallinna	doc_187964557905_item	3569124	et	4	main
minu	doc_187964557905_item	3569140	et	3	main
erinevad	doc_187964557905_item	3569149	et	4	main
sündin	doc_187964557909_item	3569227	et	4	main
mulle	doc_187964557909_item	3569231	et	4	main
oma	doc_187964557909_item	3569243	et	4	main
ma	doc_187964557909_item	3569246	et	3	main
õppima	doc_187964557909_item	3569249	et	3	main
huvitav	doc_187964557909_item	3569285	et	4	main
on	doc_187964557909_item	3569288	et	4	main
kombeid	doc_187964557909_item	3569290	et	4	main
ma	doc_187964557909_item	3569291	et	3	main
arvan	doc_187964557909_item	3569292	et	3	main
väga	doc_187964557909_item	3569296	et	3	main
siin	doc_187964557909_item	3569298	et	4	main
on	doc_187964557909_item	3569299	et	4	main
ka	doc_187964557909_item	3569300	et	3	main
tahan	doc_187964557909_item	3569307	et	3	main
oskus	doc_187964557909_item	3569312	et	3	main
ka	doc_187964557909_item	3569314	et	3	main
õppida	doc_187964557909_item	3569321	et	3	main
kirjutama	doc_187964557909_item	3569366	et	3	main
rongis	doc_213943984911_item	3569369	et	4	main
meeldiv	doc_213943984911_item	3569373	et	4	main
sõita	doc_213943984911_item	3569374	et	3	main
lugusid	doc_213943984911_item	3569392	et	3	main
nende	doc_213943984911_item	3569393	et	4	main
elust	doc_213943984911_item	3569394	et	3	main
koos	doc_213943984911_item	3569409	et	4	main
olid	doc_213943984911_item	3569416	et	4	main
rääkides	doc_213943984911_item	3569422	et	4	main
peterburis	doc_213943984911_item	3569428	et	4	main
looduseannetega	doc_213943984911_item	3569441	et	3	main
rääkisid	doc_213943984911_item	3569444	et	4	main
naised	doc_213943984911_item	3569457	et	3	main
välja	doc_213943984911_item	3569466	et	4	main
et	doc_213943984911_item	3569467	et	3	main
minu	doc_187964557905_item	3569100	et	3	main
on	doc_187964557905_item	3569102	et	4	main
narvas	doc_187964557905_item	3569106	et	4	main
lõpetan	doc_187964557905_item	3569107	et	3	main
2006	doc_187964557905_item	3569110	et	2	main
aastas	doc_187964557905_item	3569111	et	3	main
tehnika	doc_187964557905_item	3569125	et	4	main
veel	doc_187964557905_item	3569146	et	4	main
klassikaaslased	doc_187964557905_item	3569175	et	3	main
minu	doc_187964557905_item	3569176	et	3	main
arvates	doc_187964557905_item	3569177	et	4	main
et	doc_187964557905_item	3569178	et	3	main
see	doc_187964557905_item	3569179	et	3	main
on	doc_187964557905_item	3569180	et	4	main
väga	doc_187964557905_item	3569181	et	3	main
mugav	doc_187964557905_item	3569182	et	3	main
kui	doc_187964557905_item	3569183	et	3	main
kõik	doc_187964557905_item	3569184	et	4	main
loengud	doc_187964557905_item	3569185	et	3	main
ja	doc_187964557905_item	3569186	et	3	main
koduneülesandeid	doc_187964557905_item	3569187	et	4	main
internetis	doc_187964557905_item	3569189	et	4	main
asuvad	doc_187964557905_item	3569188	et	4	main
veel	doc_187964557905_item	3569190	et	4	main
ttü-s	doc_187964557905_item	3569191	et	3	main
asub	doc_187964557905_item	3569192	et	3	main
suur	doc_187964557905_item	3569193	et	3	main
ja	doc_187964557905_item	3569098	et	3	main
ma	doc_187964557905_item	3569104	et	3	main
pärast	doc_187964557905_item	3569120	et	4	main
ma	doc_187964557905_item	3569121	et	3	main
tahan	doc_187964557905_item	3569122	et	3	main
tootarendus	doc_187964557905_item	3569133	et	4	main
ja	doc_187964557905_item	3569134	et	3	main
tootmistehnika	doc_187964557905_item	3569135	et	4	main
ma	doc_187964557905_item	3569136	et	3	main
valin	doc_187964557905_item	3569137	et	3	main
seda	doc_187964557905_item	3569138	et	3	main
mulle	doc_187964557905_item	3569147	et	4	main
meeldib	doc_187964557905_item	3569148	et	3	main
autod	doc_187964557905_item	3569153	et	3	main
mulle	doc_187964557905_item	3569154	et	4	main
väga	doc_187964557905_item	3569155	et	3	main
meeldib	doc_187964557905_item	3569156	et	3	main
ttü-s	doc_187964557905_item	3569157	et	3	main
sest	doc_187964557905_item	3569158	et	4	main
see	doc_187964557905_item	3569159	et	3	main
on	doc_187964557905_item	3569160	et	4	main
kõige	doc_187964557905_item	3569161	et	4	main
parem	doc_187964557905_item	3569162	et	4	main
ülikool	doc_187964557905_item	3569163	et	4	main
eestis	doc_187964557905_item	3569164	et	3	main
siin	doc_187964557905_item	3569165	et	4	main
on	doc_187964557905_item	3569166	et	4	main
sõbralikud	doc_187964557905_item	3569167	et	3	main
inimesed	doc_187964557905_item	3569168	et	3	main
veel	doc_187964557905_item	3569169	et	4	main
ttü	doc_187964557905_item	3569170	et	4	main
õppivad	doc_187964557905_item	3569171	et	4	main
minu	doc_187964557905_item	3569172	et	3	main
sõbrad	doc_187964557905_item	3569173	et	3	main
ja	doc_187964557905_item	3569174	et	3	main
ja	doc_187964557909_item	3569228	et	3	main
meeldib	doc_187964557909_item	3569233	et	3	main
sportiga	doc_187964557909_item	3569235	et	4	main
on	doc_187964557909_item	3569238	et	4	main
jalgpall	doc_187964557909_item	3569239	et	3	main
meeldib	doc_187964557909_item	3569242	et	3	main
aga	doc_187964557909_item	3569245	et	3	main
ka	doc_187964557909_item	3569283	et	3	main
sest	doc_187964557909_item	3569286	et	4	main
on	doc_187964557909_item	3569295	et	4	main
sõbralikumad	doc_187964557909_item	3569297	et	4	main
keele	doc_187964557909_item	3569304	et	4	main
tunnis	doc_187964557909_item	3569305	et	3	main
ma	doc_187964557909_item	3569306	et	3	main
õppida	doc_187964557909_item	3569308	et	3	main
gramaatikat	doc_187964557909_item	3569309	et	4	main
suhtlemiseta	doc_187964557909_item	3569318	et	4	main
võimalik	doc_187964557909_item	3569320	et	3	main
mina	doc_187964557905_item	3569097	et	4	main
nimi	doc_187964557905_item	3569101	et	3	main
elan	doc_187964557905_item	3569105	et	3	main
gümnaasium	doc_187964557905_item	3569109	et	3	main
mängida	doc_187964557905_item	3569123	et	3	main
meeskonnas	doc_187964557905_item	3569128	et	4	main
huuvitav	doc_187964557905_item	3569145	et	4	main
raamatukogu	doc_187964557905_item	3569194	et	4	main
ja	doc_187964557905_item	3569195	et	3	main
see	doc_187964557905_item	3569196	et	3	main
tore	doc_187964557905_item	3569198	et	3	main
on	doc_187964557905_item	3569197	et	4	main
ka	doc_187964557905_item	3569199	et	3	main
arvan	doc_187964557905_item	3569201	et	3	main
ma	doc_187964557905_item	3569200	et	3	main
et	doc_187964557905_item	3569202	et	3	main
pärast	doc_187964557905_item	3569203	et	4	main
eesti	doc_187964557905_item	3569204	et	4	main
keele	doc_187964557905_item	3569205	et	4	main
loengud	doc_187964557905_item	3569206	et	3	main
ma	doc_187964557905_item	3569207	et	3	main
võin	doc_187964557905_item	3569208	et	3	main
rääkida	doc_187964557905_item	3569209	et	3	main
eesti	doc_187964557905_item	3569210	et	4	main
keeles	doc_187964557905_item	3569211	et	4	main
kaupluses	doc_187964557905_item	3569212	et	3	main
ülikoolis	doc_187964557905_item	3569213	et	4	main
ja	doc_187964557905_item	3569214	et	3	main
eesti	doc_187964557905_item	3569215	et	4	main
sõbraga	doc_187964557905_item	3569216	et	3	main
essee	doc_187964557909_item	3569218	et	4	main
ja	doc_187964557909_item	3569220	et	3	main
ma	doc_187964557909_item	3569222	et	3	main
olen	doc_187964557909_item	3569223	et	3	main
vana	doc_187964557909_item	3569226	et	4	main
narvas	doc_187964557909_item	3569230	et	4	main
tegelda	doc_187964557909_item	3569234	et	4	main
lemmik	doc_187964557909_item	3569236	et	3	main
mäng	doc_187964557909_item	3569237	et	3	main
mulle	doc_187964557909_item	3569240	et	4	main
väga	doc_187964557909_item	3569241	et	3	main
edasi	doc_187964557909_item	3569248	et	3	main
meeldib	doc_187964557909_item	3569254	et	3	main
selle	doc_187964557909_item	3569255	et	4	main
siin	doc_187964557909_item	3569287	et	4	main
oma	doc_187964557909_item	3569289	et	4	main
kasaaegne	doc_187964557909_item	3569301	et	4	main
aga	doc_187964557909_item	3569310	et	3	main
on	doc_187964557909_item	3569313	et	4	main
tähtis	doc_187964557909_item	3569316	et	4	main
sest	doc_187964557909_item	3569317	et	4	main
ülikool	doc_187964557909_item	3569221	et	4	main
19	doc_187964557909_item	3569224	et	2	main
aastat	doc_187964557909_item	3569225	et	3	main
väga	doc_187964557909_item	3569232	et	3	main
minna	doc_187964557909_item	3569250	et	3	main
mehaanika	doc_187964557909_item	3569251	et	4	main
väga	doc_187964557909_item	3569253	et	3	main
est	doc_187964557909_item	3569256	et	4	main
ma	doc_187964557909_item	3569257	et	3	main
valin	doc_187964557909_item	3569258	et	3	main
eriala	doc_187964557909_item	3569259	et	4	main
soojustehnika	doc_187964557909_item	3569260	et	4	main
narvas	doc_187964557909_item	3569261	et	4	main
on	doc_187964557909_item	3569262	et	4	main
ka	doc_187964557909_item	3569263	et	3	main
väga	doc_187964557909_item	3569264	et	3	main
kerge	doc_187964557909_item	3569265	et	4	main
leida	doc_187964557909_item	3569266	et	3	main
tööd	doc_187964557909_item	3569267	et	4	main
kui	doc_187964557909_item	3569268	et	3	main
sa	doc_187964557909_item	3569269	et	3	main
oled	doc_187964557909_item	3569270	et	3	main
soojustehnik	doc_187964557909_item	3569271	et	3	main
ma	doc_187964557909_item	3569272	et	3	main
elistan	doc_187964557909_item	3569273	et	4	main
ttü	doc_187964557909_item	3569274	et	4	main
sest	doc_187964557909_item	3569275	et	4	main
see	doc_187964557909_item	3569276	et	3	main
on	doc_187964557909_item	3569277	et	4	main
väga	doc_187964557909_item	3569278	et	3	main
pristizne	doc_187964557909_item	3569279	et	4	main
ülikool	doc_187964557909_item	3569280	et	4	main
ta	doc_187964557909_item	3569281	et	4	main
on	doc_187964557909_item	3569282	et	4	main
väga	doc_187964557909_item	3569284	et	3	main
studengid	doc_187964557909_item	3569294	et	4	main
tehnika	doc_187964557909_item	3569302	et	4	main
eesti	doc_187964557909_item	3569303	et	4	main
ajal	doc_213943984911_item	3569385	et	4	main
saab	doc_213943984911_item	3569386	et	3	main
ka	doc_213943984911_item	3569398	et	3	main
olid	doc_213943984911_item	3569412	et	4	main
tuli	doc_213943984911_item	3569423	et	4	main
ja	doc_213943984911_item	3569431	et	3	main
sõitsid	doc_213943984911_item	3569433	et	4	main
koju	doc_213943984911_item	3569435	et	3	main
palavasse	doc_213943984911_item	3569436	et	4	main
nad	doc_213943984911_item	3569443	et	3	main
võivad	doc_213943984911_item	3569458	et	4	main
niimoodi	doc_213943984911_item	3569459	et	3	main
perekonnanimi	doc_213943984939_item	3569499	et	3	main
tuhande	doc_213943984939_item	3569505	et	3	main
üheksasaja	doc_213943984939_item	3569506	et	4	main
venemaal	doc_213943984939_item	3569510	et	4	main
ma	doc_213943984939_item	3569511	et	3	main
üheksasaja	doc_213943984939_item	3569518	et	4	main
üheksasaja	doc_213943984939_item	3569523	et	4	main
aastal	doc_213943984939_item	3569526	et	3	main
pihkva	doc_213943984939_item	3569528	et	4	main
pedagoogiline	doc_213943984939_item	3569529	et	4	main
instituut	doc_213943984939_item	3569530	et	3	main
vene	doc_213943984939_item	3569539	et	4	main
mull	doc_213943984939_item	3569543	et	3	main
kolmas	doc_213943984939_item	3569545	et	3	main
mina	doc_213943984939_item	3569547	et	4	main
teises	doc_213943984939_item	3569549	et	4	main
üksteist	doc_213943984939_item	3569555	et	4	main
tüdrukud	doc_213943984939_item	3569556	et	3	main
mull	doc_213943984939_item	3569576	et	3	main
klassis	doc_213943984939_item	3569595	et	3	main
on	doc_213943984939_item	3569606	et	4	main
ülesanned	doc_213943984939_item	3569613	et	4	main
ja	doc_213943984939_item	3569614	et	3	main
kõige	doc_213943984939_item	3569621	et	4	main
kauplustele	doc_213943984955_item	3569654	et	4	main
minu	doc_213943984955_item	3569671	et	3	main
kodu	doc_213943984955_item	3569672	et	4	main
lähedal	doc_213943984955_item	3569673	et	4	main
on	doc_213943984955_item	3569680	et	4	main
ma	doc_213943984955_item	3569687	et	3	main
eriti	doc_213943984955_item	3569693	et	3	main
kaupluse	doc_213943984955_item	3569696	et	3	main
järjekorrad	doc_213943984955_item	3569756	et	3	main
ümberkorraldamist	doc_213943984955_item	3569760	et	3	main
pole	doc_187964557909_item	3569319	et	3	main
arvan	doc_187964557909_item	3569323	et	3	main
et	doc_187964557909_item	3569324	et	3	main
on	doc_187964557909_item	3569326	et	4	main
kergem	doc_187964557909_item	3569327	et	4	main
õppida	doc_187964557909_item	3569328	et	3	main
eesti	doc_187964557909_item	3569329	et	4	main
keelt	doc_187964557909_item	3569330	et	4	main
sest	doc_187964557909_item	3569331	et	4	main
siin	doc_187964557909_item	3569332	et	4	main
on	doc_187964557909_item	3569333	et	4	main
rohkem	doc_187964557909_item	3569334	et	4	main
inimesed	doc_187964557909_item	3569335	et	3	main
kellega	doc_187964557909_item	3569336	et	3	main
sa	doc_187964557909_item	3569337	et	3	main
võid	doc_187964557909_item	3569338	et	4	main
räägida	doc_187964557909_item	3569339	et	4	main
ainult	doc_187964557909_item	3569340	et	4	main
eesti	doc_187964557909_item	3569341	et	4	main
keeles	doc_187964557909_item	3569342	et	4	main
ja	doc_187964557909_item	3569343	et	3	main
eesti	doc_187964557909_item	3569344	et	4	main
keele	doc_187964557909_item	3569345	et	4	main
tunnid	doc_187964557909_item	3569346	et	3	main
annavad	doc_187964557909_item	3569347	et	3	main
2	doc_187964557909_item	3569348	et	2	main
ap	doc_187964557909_item	3569349	et	4	main
mis	doc_187964557909_item	3569350	et	4	main
on	doc_187964557909_item	3569351	et	4	main
ka	doc_187964557909_item	3569352	et	3	main
väga	doc_187964557909_item	3569353	et	3	main
tähtis	doc_187964557909_item	3569354	et	4	main
ma	doc_187964557909_item	3569355	et	3	main
arvan	doc_187964557909_item	3569356	et	3	main
et	doc_187964557909_item	3569357	et	3	main
info	doc_187964557909_item	3569358	et	4	main
raamatukogus	doc_187964557909_item	3569359	et	4	main
ja	doc_187964557909_item	3569360	et	3	main
internetis	doc_187964557909_item	3569361	et	4	main
aitab	doc_187964557909_item	3569362	et	3	main
eesti	doc_187964557909_item	3569363	et	4	main
keele	doc_187964557909_item	3569364	et	4	main
exam	doc_187964557909_item	3569365	et	4	main
aktsendiga	doc_213943984911_item	3569446	et	3	main
asendades	doc_213943984911_item	3569447	et	3	main
g	doc_213943984911_item	3569448	et	4	main
häälikut	doc_213943984911_item	3569449	et	3	main
h-ga	doc_213943984911_item	3569450	et	3	main
mis	doc_213943984911_item	3569451	et	4	main
alguses	doc_213943984911_item	3569452	et	4	main
tundus	doc_213943984911_item	3569453	et	3	main
naljakas	doc_213943984911_item	3569454	et	4	main
et	doc_213943984911_item	3569455	et	3	main
täiskasvanud	doc_213943984911_item	3569456	et	4	main
kaugetele	doc_213943984911_item	3569375	et	4	main
maadele	doc_213943984911_item	3569376	et	4	main
eriti	doc_213943984911_item	3569377	et	3	main
siis	doc_213943984911_item	3569378	et	3	main
kui	doc_213943984911_item	3569379	et	3	main
sõidukaaslased	doc_213943984911_item	3569380	et	3	main
on	doc_213943984911_item	3569381	et	4	main
erirahvustest	doc_213943984911_item	3569382	et	4	main
inimesed	doc_213943984911_item	3569383	et	3	main
reisi	doc_213943984911_item	3569384	et	4	main
on	doc_213943984911_item	3569371	et	4	main
väga	doc_213943984911_item	3569372	et	3	main
sain	doc_213943984911_item	3569397	et	3	main
mina	doc_213943984911_item	3569399	et	4	main
suvel	doc_213943984911_item	3569401	et	3	main
me	doc_213943984911_item	3569403	et	4	main
kaks	doc_213943984911_item	3569413	et	3	main
vodõ	doc_213943984911_item	3569418	et	4	main
et	doc_213943984911_item	3569425	et	3	main
nemad	doc_213943984911_item	3569426	et	3	main
praegu	doc_213943984911_item	3569432	et	3	main
rongiga	doc_213943984911_item	3569434	et	4	main
kuid	doc_213943984911_item	3569437	et	4	main
ilusa	doc_213943984911_item	3569438	et	3	main
hääldada	doc_213943984911_item	3569461	et	3	main
pärast	doc_213943984911_item	3569464	et	4	main
tuli	doc_213943984911_item	3569465	et	4	main
meie	doc_213943984911_item	3569468	et	4	main
g-na	doc_213943984911_item	3569475	et	3	main
tuttavaks	doc_213943984911_item	3569387	et	4	main
kaassõitjate	doc_213943984911_item	3569388	et	3	main
iseloomuga	doc_213943984911_item	3569389	et	3	main
võib	doc_213943984911_item	3569390	et	3	main
kuulda	doc_213943984911_item	3569391	et	4	main
elamust	doc_213943984911_item	3569396	et	4	main
sel	doc_213943984911_item	3569400	et	3	main
kui	doc_213943984911_item	3569402	et	3	main
abikaasaga	doc_213943984911_item	3569404	et	3	main
sõitsime	doc_213943984911_item	3569405	et	3	main
venemaa	doc_213943984911_item	3569406	et	4	main
lõunaossa	doc_213943984911_item	3569407	et	3	main
meiega	doc_213943984911_item	3569408	et	4	main
naist	doc_213943984911_item	3569414	et	3	main
mineralnije	doc_213943984911_item	3569417	et	4	main
linnast	doc_213943984911_item	3569419	et	4	main
pärit	doc_213943984911_item	3569420	et	3	main
nendega	doc_213943984911_item	3569421	et	4	main
välja	doc_213943984911_item	3569424	et	4	main
vaatamisväärsusi	doc_213943984911_item	3569429	et	4	main
looduse	doc_213943984911_item	3569439	et	4	main
ja	doc_213943984911_item	3569440	et	3	main
kohta	doc_213943984911_item	3569442	et	4	main
imeliku	doc_213943984911_item	3569445	et	3	main
sõnu	doc_213943984911_item	3569460	et	4	main
olime	doc_213943984911_item	3569469	et	3	main
hääldasime	doc_213943984911_item	3569473	et	3	main
essee	doc_213943984939_item	3569495	et	4	main
kahekümnendal	doc_213943984939_item	3569503	et	4	main
lõppetasin	doc_213943984939_item	3569512	et	4	main
seitsekümne	doc_213943984939_item	3569519	et	4	main
kaheksandal	doc_213943984939_item	3569520	et	3	main
kaheksakümne	doc_213943984939_item	3569524	et	4	main
kesklina	doc_213943984939_item	3569538	et	4	main
õpetajana	doc_213943984939_item	3569542	et	4	main
kakskümmend	doc_213943984939_item	3569553	et	4	main
on	doc_213943984939_item	3569577	et	4	main
tema	doc_213943984939_item	3569579	et	4	main
tema	doc_213943984939_item	3569596	et	4	main
eesti	doc_213943984939_item	3569601	et	4	main
kodus	doc_213943984939_item	3569604	et	4	main
mull	doc_213943984939_item	3569605	et	3	main
olulisemat	doc_213943984939_item	3569622	et	4	main
on	doc_213943984939_item	3569626	et	4	main
suurtele	doc_213943984955_item	3569653	et	3	main
asuvad	doc_213943984955_item	3569661	et	4	main
eelis	doc_213943984955_item	3569676	et	3	main
kohtade	doc_213943984955_item	3569678	et	3	main
seal	doc_213943984955_item	3569683	et	4	main
on	doc_213943984955_item	3569684	et	4	main
kvaliteetiga	doc_213943984955_item	3569692	et	4	main
on	doc_213943984955_item	3569695	et	4	main
juures	doc_213943984955_item	3569697	et	4	main
see	doc_213943984955_item	3569698	et	3	main
et	doc_213943984955_item	3569699	et	3	main
lähedal	doc_213943984955_item	3569700	et	4	main
saa	doc_213943984955_item	3569752	et	4	main
jääda	doc_213943984955_item	3569754	et	4	main
tipptundidel	doc_213943984955_item	3569757	et	3	main
ta	doc_213943984955_item	3569764	et	4	main
avab	doc_213943984955_item	3569765	et	3	main
uksed	doc_213943984955_item	3569766	et	3	main
liiga	doc_213943984955_item	3569767	et	4	main
hilja	doc_213943984955_item	3569768	et	3	main
niisugust	doc_213943984911_item	3569395	et	3	main
üleval	doc_213943984911_item	3569410	et	4	main
pingil	doc_213943984911_item	3569411	et	3	main
kes	doc_213943984911_item	3569415	et	4	main
käisid	doc_213943984911_item	3569427	et	4	main
uurima	doc_213943984911_item	3569430	et	3	main
natukese	doc_213943984911_item	3569462	et	4	main
aja	doc_213943984911_item	3569463	et	4	main
vist	doc_213943984911_item	3569470	et	4	main
vähemuses	doc_213943984911_item	3569471	et	4	main
kui	doc_213943984911_item	3569472	et	3	main
mina	doc_213943984939_item	3569496	et	4	main
mina	doc_213943984939_item	3569500	et	4	main
augustil	doc_213943984939_item	3569504	et	3	main
aastal	doc_213943984939_item	3569521	et	3	main
lõpetan	doc_213943984939_item	3569527	et	3	main
ja	doc_213943984939_item	3569531	et	3	main
töötan	doc_213943984939_item	3569532	et	3	main
koolis	doc_213943984939_item	3569533	et	4	main
praegu	doc_213943984939_item	3569534	et	3	main
ma	doc_213943984939_item	3569535	et	3	main
töötan	doc_213943984939_item	3569536	et	3	main
gümnaasiumis	doc_213943984939_item	3569540	et	3	main
on	doc_213943984939_item	3569544	et	4	main
klass	doc_213943984939_item	3569546	et	3	main
töötan	doc_213943984939_item	3569548	et	3	main
last	doc_213943984939_item	3569554	et	4	main
lugevad	doc_213943984939_item	3569575	et	4	main
klaaverit	doc_213943984939_item	3569598	et	4	main
palju	doc_213943984939_item	3569607	et	4	main
asi	doc_213943984939_item	3569608	et	4	main
elust	doc_213943984939_item	3569625	et	3	main
g-d	doc_213943984911_item	3569474	et	4	main
nii	doc_213943984911_item	3569476	et	3	main
õppisime	doc_213943984911_item	3569477	et	3	main
me	doc_213943984911_item	3569478	et	4	main
tundma	doc_213943984911_item	3569479	et	3	main
ja	doc_213943984911_item	3569480	et	3	main
ka	doc_213943984911_item	3569481	et	3	main
austama	doc_213943984911_item	3569482	et	3	main
teistele	doc_213943984911_item	3569483	et	4	main
rahvustele	doc_213943984911_item	3569484	et	3	main
iseloomulikku	doc_213943984911_item	3569485	et	4	main
mis	doc_213943984911_item	3569486	et	4	main
praeguses	doc_213943984911_item	3569487	et	3	main
kosmopoliitses	doc_213943984911_item	3569488	et	3	main
elus	doc_213943984911_item	3569489	et	4	main
läheb	doc_213943984911_item	3569490	et	3	main
päris	doc_213943984911_item	3569491	et	4	main
sagedasti	doc_213943984911_item	3569492	et	3	main
vaja	doc_213943984911_item	3569493	et	4	main
eesnimi	doc_213943984939_item	3569498	et	3	main
sündinud	doc_213943984939_item	3569502	et	4	main
kuue	doc_213943984939_item	3569507	et	4	main
kümneesimesel	doc_213943984939_item	3569508	et	4	main
aastal	doc_213943984939_item	3569509	et	3	main
keskkool	doc_213943984939_item	3569516	et	4	main
tuhande	doc_213943984939_item	3569517	et	3	main
tallinna	doc_213943984939_item	3569537	et	4	main
algklasside	doc_213943984939_item	3569541	et	3	main
on	doc_213943984939_item	3569552	et	4	main
poeg	doc_213943984939_item	3569578	et	3	main
nimi	doc_213943984939_item	3569580	et	3	main
olen	doc_213943984939_item	3569497	et	3	main
olen	doc_213943984939_item	3569501	et	3	main
tallinna	doc_213943984939_item	3569513	et	4	main
neljakümne	doc_213943984939_item	3569514	et	4	main
kuuendal	doc_213943984939_item	3569515	et	3	main
tuhande	doc_213943984939_item	3569522	et	3	main
kuuendal	doc_213943984939_item	3569525	et	3	main
vahetus	doc_213943984939_item	3569550	et	4	main
klassis	doc_213943984939_item	3569551	et	3	main
ja	doc_213943984939_item	3569557	et	3	main
üheksa	doc_213943984939_item	3569558	et	4	main
poisid	doc_213943984939_item	3569559	et	4	main
nad	doc_213943984939_item	3569560	et	3	main
on	doc_213943984939_item	3569561	et	4	main
vaga	doc_213943984939_item	3569562	et	4	main
sõpralikud	doc_213943984939_item	3569563	et	4	main
suured	doc_213943984939_item	3569564	et	3	main
probleemid	doc_213943984939_item	3569565	et	3	main
nendega	doc_213943984939_item	3569566	et	4	main
mull	doc_213943984939_item	3569567	et	3	main
ei	doc_213943984939_item	3569568	et	4	main
ole	doc_213943984939_item	3569569	et	4	main
nad	doc_213943984939_item	3569570	et	3	main
õppivad	doc_213943984939_item	3569571	et	4	main
hästi	doc_213943984939_item	3569572	et	3	main
ja	doc_213943984939_item	3569573	et	3	main
palju	doc_213943984939_item	3569574	et	4	main
on	doc_213943984939_item	3569581	et	4	main
eesnimi	doc_213943984939_item	3569582	et	3	main
ta	doc_213943984939_item	3569583	et	4	main
on	doc_213943984939_item	3569584	et	4	main
kuusteist	doc_213943984939_item	3569585	et	4	main
aastat	doc_213943984939_item	3569586	et	3	main
vana	doc_213943984939_item	3569587	et	4	main
ja	doc_213943984939_item	3569588	et	3	main
ta	doc_213943984939_item	3569589	et	4	main
õpib	doc_213943984939_item	3569590	et	3	main
tallinna	doc_213943984939_item	3569591	et	4	main
mahtra	doc_213943984939_item	3569592	et	4	main
gümnaasiumis	doc_213943984939_item	3569593	et	3	main
üheksas	doc_213943984939_item	3569594	et	4	main
mängib	doc_213943984939_item	3569597	et	3	main
teised	doc_213943984939_item	3569615	et	4	main
minu	doc_213943984939_item	3569616	et	3	main
hobi	doc_213943984939_item	3569617	et	4	main
on	doc_213943984939_item	3569618	et	4	main
kuudumine	doc_213943984939_item	3569619	et	4	main
kolm	doc_213943984939_item	3569620	et	3	main
minu	doc_213943984939_item	3569624	et	3	main
plussiks	doc_213943984955_item	3569656	et	4	main
ja	doc_213943984939_item	3569599	et	3	main
õpib	doc_213943984939_item	3569600	et	3	main
keelt	doc_213943984939_item	3569602	et	4	main
hommikul	doc_213943984939_item	3569603	et	3	main
valmistada	doc_213943984939_item	3569609	et	3	main
söögi	doc_213943984939_item	3569610	et	4	main
tegin	doc_213943984939_item	3569611	et	3	main
kooli	doc_213943984939_item	3569612	et	4	main
positiivset	doc_213943984939_item	3569623	et	3	main
laste	doc_213943984939_item	3569627	et	4	main
sünniaeg	doc_213943984939_item	3569628	et	3	main
lemmiktöö	doc_213943984939_item	3569629	et	4	main
vanaemaks	doc_213943984939_item	3569630	et	3	main
saada	doc_213943984939_item	3569631	et	4	main
minu	doc_213943984939_item	3569632	et	3	main
õie	doc_213943984939_item	3569633	et	3	main
tüttar	doc_213943984939_item	3569634	et	4	main
sündis	doc_213943984939_item	3569635	et	3	main
lapsi	doc_213943984939_item	3569636	et	4	main
kõige	doc_213943984939_item	3569637	et	4	main
olulisemat	doc_213943984939_item	3569638	et	4	main
negatiivset	doc_213943984939_item	3569639	et	3	main
minu	doc_213943984939_item	3569640	et	3	main
elust	doc_213943984939_item	3569641	et	3	main
on	doc_213943984939_item	3569642	et	4	main
vanemate	doc_213943984939_item	3569643	et	4	main
surm	doc_213943984939_item	3569644	et	3	main
ei	doc_213943984939_item	3569645	et	4	main
ole	doc_213943984939_item	3569646	et	4	main
võimalusi	doc_213943984939_item	3569647	et	3	main
sugulaste	doc_213943984939_item	3569648	et	4	main
külastamine	doc_213943984939_item	3569649	et	4	main
venemaal	doc_213943984939_item	3569650	et	4	main
essee	doc_213943984955_item	3569652	et	4	main
ta	doc_213943984955_item	3569669	et	4	main
citymarketi	doc_213943984955_item	3569674	et	4	main
ees	doc_213943984955_item	3569679	et	4	main
see	doc_213943984955_item	3569681	et	3	main
et	doc_213943984955_item	3569682	et	3	main
on	doc_213943984955_item	3569701	et	4	main
kindlasti	doc_213943984955_item	3569758	et	3	main
tööaeg	doc_213943984955_item	3569762	et	3	main
valmistada	doc_213943984955_item	3569733	et	3	main
rohkem	doc_213943984955_item	3569734	et	4	main
soodustusi	doc_213943984955_item	3569735	et	4	main
tarbijaid	doc_213943984955_item	3569736	et	4	main
võib	doc_213943984955_item	3569737	et	3	main
ehmatada	doc_213943984955_item	3569738	et	3	main
riiete	doc_213943984955_item	3569739	et	3	main
kvaliteet	doc_213943984955_item	3569740	et	3	main
sest	doc_213943984955_item	3569741	et	4	main
on	doc_213943984955_item	3569743	et	4	main
madal	doc_213943984955_item	3569744	et	3	main
aga	doc_213943984955_item	3569745	et	3	main
ta	doc_213943984955_item	3569742	et	4	main
riide	doc_213943984955_item	3569746	et	4	main
on	doc_213943984955_item	3569747	et	4	main
väga	doc_213943984955_item	3569748	et	3	main
kallis	doc_213943984955_item	3569749	et	4	main
kuidagi	doc_213943984955_item	3569750	et	3	main
ei	doc_213943984955_item	3569751	et	4	main
suureks	doc_213943984955_item	3569655	et	4	main
on	doc_213943984955_item	3569657	et	4	main
et	doc_213943984955_item	3569659	et	3	main
on	doc_213943984955_item	3569670	et	4	main
peamine	doc_213943984955_item	3569675	et	3	main
toiduained	doc_213943984955_item	3569686	et	3	main
olen	doc_213943984955_item	3569688	et	3	main
rahul	doc_213943984955_item	3569690	et	4	main
toidu	doc_213943984955_item	3569691	et	3	main
suur	doc_213943984955_item	3569702	et	3	main
parkla	doc_213943984955_item	3569703	et	4	main
ma	doc_213943984955_item	3569704	et	3	main
naudin	doc_213943984955_item	3569705	et	3	main
osta	doc_213943984955_item	3569706	et	4	main
sealt	doc_213943984955_item	3569707	et	4	main
toidu	doc_213943984955_item	3569708	et	3	main
teenindus	doc_213943984955_item	3569709	et	4	main
on	doc_213943984955_item	3569710	et	4	main
heal	doc_213943984955_item	3569711	et	3	main
tasemel	doc_213943984955_item	3569712	et	3	main
citymarketi	doc_213943984955_item	3569713	et	4	main
puuduseks	doc_213943984955_item	3569714	et	4	main
on	doc_213943984955_item	3569715	et	4	main
vähe	doc_213943984955_item	3569716	et	3	main
ostukorvi	doc_213943984955_item	3569717	et	4	main
pisut	doc_213943984955_item	3569718	et	3	main
häirib	doc_213943984955_item	3569719	et	3	main
inimeste	doc_213943984955_item	3569720	et	3	main
arv	doc_213943984955_item	3569721	et	3	main
õhtudel	doc_213943984955_item	3569722	et	4	main
kui	doc_213943984955_item	3569723	et	3	main
kõik	doc_213943984955_item	3569724	et	4	main
lähevad	doc_213943984955_item	3569725	et	3	main
koju	doc_213943984955_item	3569726	et	3	main
kauplus	doc_213943984955_item	3569727	et	3	main
ei	doc_213943984955_item	3569728	et	4	main
võimalda	doc_213943984955_item	3569729	et	4	main
kassapidajat	doc_213943984955_item	3569730	et	3	main
pettumuse	doc_213943984955_item	3569731	et	4	main
võib	doc_213943984955_item	3569732	et	3	main
rahule	doc_213943984955_item	3569753	et	4	main
see	doc_213943984955_item	3569658	et	3	main
nad	doc_213943984955_item	3569660	et	3	main
igas	doc_213943984955_item	3569662	et	3	main
rajoonis	doc_213943984955_item	3569663	et	4	main
ma	doc_213943984955_item	3569664	et	3	main
eelistan	doc_213943984955_item	3569665	et	3	main
citymarkest	doc_213943984955_item	3569666	et	4	main
sellepärast	doc_213943984955_item	3569667	et	3	main
et	doc_213943984955_item	3569668	et	3	main
teiste	doc_213943984955_item	3569677	et	4	main
oodavad	doc_213943984955_item	3569685	et	4	main
ülimatu	doc_213943984955_item	3569689	et	4	main
meeldiv	doc_213943984955_item	3569694	et	4	main
pikkad	doc_213943984955_item	3569755	et	4	main
vajaks	doc_213943984955_item	3569759	et	4	main
kaupluse	doc_213943984955_item	3569761	et	3	main
sest	doc_213943984955_item	3569763	et	4	main
nimi	doc_213943984957_item	3570063	et	3	main
ma	doc_213943984957_item	3570067	et	3	main
huvitav	doc_213943984957_item	3570075	et	4	main
ja	doc_213943984957_item	3570076	et	3	main
põhjamaal	doc_213943984957_item	3570082	et	4	main
elanud	doc_213943984957_item	3570093	et	4	main
perekond	doc_213943984957_item	3570098	et	3	main
minu	doc_213943984957_item	3570114	et	3	main
see	doc_213943984957_item	3570119	et	3	main
tulin	doc_213943984957_item	3570139	et	3	main
oma	doc_213943984957_item	3570141	et	4	main
kodulinna	doc_213943984957_item	3570142	et	4	main
kus	doc_213943984957_item	3570143	et	3	main
olen	doc_213943984957_item	3570144	et	3	main
vana	doc_213943984957_item	3570153	et	4	main
sõitsin	doc_213943984957_item	3570155	et	3	main
töötama	doc_213943984957_item	3570157	et	3	main
olen	doc_213943984957_item	3570160	et	3	main
töötanud	doc_213943984957_item	3570161	et	4	main
ka	doc_213943984957_item	3570168	et	3	main
moment	doc_213943984957_item	3570170	et	3	main
minu	doc_213943984957_item	3570171	et	3	main
elus	doc_213943984957_item	3570185	et	4	main
sündmine	doc_213943984957_item	3570189	et	4	main
tegi	doc_213943984957_item	3570191	et	4	main
täis	doc_213943984957_item	3570192	et	4	main
mu	doc_213943984957_item	3570193	et	3	main
ja	doc_213943984957_item	3570202	et	3	main
me	doc_213943984957_item	3570203	et	4	main
tallinna	doc_213943984957_item	3570214	et	4	main
see	doc_213943984957_item	3570222	et	3	main
on	doc_213943984957_item	3570064	et	4	main
elu	doc_213943984957_item	3570073	et	4	main
on	doc_213943984957_item	3570074	et	4	main
venemaal	doc_213943984957_item	3570081	et	4	main
pool	doc_213943984957_item	3570090	et	4	main
elu	doc_213943984957_item	3570091	et	4	main
olen	doc_213943984957_item	3570092	et	3	main
hea	doc_213943984957_item	3570097	et	4	main
tugev	doc_213943984957_item	3570108	et	4	main
aga	doc_213943984957_item	3570109	et	3	main
kannatlik	doc_213943984957_item	3570110	et	3	main
naine	doc_213943984957_item	3570111	et	3	main
nad	doc_213943984957_item	3570112	et	3	main
rõõmsaks	doc_213943984957_item	3570116	et	3	main
muidugi	doc_213943984957_item	3570120	et	4	main
positivne	doc_213943984957_item	3570121	et	4	main
moment	doc_213943984957_item	3570122	et	3	main
minu	doc_213943984957_item	3570123	et	3	main
elus	doc_213943984957_item	3570124	et	4	main
pedagoogika	doc_213943984957_item	3570129	et	4	main
ülikoolis	doc_213943984957_item	3570130	et	4	main
ja	doc_213943984957_item	3570131	et	3	main
sain	doc_213943984957_item	3570132	et	3	main
pärast	doc_213943984957_item	3570136	et	4	main
instituudi	doc_213943984957_item	3570137	et	3	main
ma	doc_213943984957_item	3570138	et	3	main
aastat	doc_213943984957_item	3570152	et	3	main
ma	doc_213943984957_item	3570154	et	3	main
3	doc_213943984957_item	3570164	et	2	main
parem	doc_213943984957_item	3570182	et	4	main
sündmus	doc_213943984957_item	3570183	et	3	main
minu	doc_213943984957_item	3570184	et	3	main
temaga	doc_213943984957_item	3570205	et	3	main
saabimine	doc_213943984957_item	3570215	et	4	main
uus	doc_213943984957_item	3570224	et	3	main
uued	doc_213943984957_item	3570226	et	3	main
uus	doc_213943984957_item	3570228	et	3	main
tallinnas	doc_213943984957_item	3570230	et	4	main
aga	doc_213943984957_item	3570261	et	3	main
minu	doc_213943984957_item	3570270	et	3	main
elus	doc_213943984957_item	3570271	et	4	main
ma	doc_213943984957_item	3570280	et	3	main
siiamani	doc_213943984957_item	3570286	et	4	main
mul	doc_213943984957_item	3570287	et	3	main
eesti	doc_213943984957_item	3570330	et	4	main
keeles	doc_213943984957_item	3570331	et	4	main
ja	doc_213943984957_item	3570332	et	3	main
sellepärast	doc_213943984957_item	3570333	et	3	main
unustan	doc_213943984957_item	3570334	et	3	main
ma	doc_213943984957_item	3570341	et	3	main
meie	doc_213943984963_item	3570356	et	4	main
see	doc_213943984963_item	3570362	et	3	main
normaalse	doc_213943984963_item	3570364	et	3	main
seinakapiga	doc_213943984963_item	3570366	et	3	main
peegliga	doc_213943984963_item	3570369	et	3	main
esikust	doc_213943984963_item	3570382	et	4	main
teine	doc_213943984963_item	3570383	et	3	main
koridoori	doc_213943984963_item	3570384	et	4	main
koridooris	doc_213943984963_item	3570399	et	4	main
sellises	doc_213943984963_item	3570400	et	4	main
korteris	doc_213943984963_item	3570401	et	3	main
on	doc_213943984963_item	3570402	et	4	main
teises	doc_213943984963_item	3570415	et	4	main
siit	doc_213943984963_item	3570416	et	3	main
on	doc_213943984963_item	3570417	et	4	main
võimalik	doc_213943984963_item	3570418	et	3	main
kas	doc_213943984963_item	3570420	et	3	main
venna	doc_213943984963_item	3570422	et	3	main
ebamugav	doc_213943984963_item	3570434	et	3	main
süüa	doc_213943984963_item	3570438	et	3	main
kak	doc_213943984963_item	3570448	et	4	main
minu	doc_213943984957_item	3570062	et	3	main
aastat	doc_213943984957_item	3570070	et	3	main
minu	doc_213943984957_item	3570072	et	3	main
linnas	doc_213943984957_item	3570084	et	4	main
minu	doc_213943984957_item	3570099	et	3	main
elu	doc_213943984957_item	3570115	et	4	main
ma	doc_213943984957_item	3570127	et	3	main
õppesin	doc_213943984957_item	3570128	et	4	main
algklassiõpetaja	doc_213943984957_item	3570134	et	4	main
ja	doc_213943984957_item	3570135	et	3	main
tagasi	doc_213943984957_item	3570140	et	3	main
algklassde	doc_213943984957_item	3570162	et	4	main
see	doc_213943984957_item	3570166	et	3	main
positivne	doc_213943984957_item	3570169	et	4	main
poja	doc_213943984957_item	3570188	et	4	main
elu	doc_213943984957_item	3570194	et	4	main
oleme	doc_213943984957_item	3570204	et	3	main
ka	doc_213943984957_item	3570208	et	3	main
külg	doc_213943984957_item	3570210	et	3	main
elus	doc_213943984957_item	3570212	et	4	main
on	doc_213943984957_item	3570213	et	4	main
tähtis	doc_213943984957_item	3570218	et	4	main
ei	doc_213943984957_item	3570263	et	4	main
lähe	doc_213943984957_item	3570264	et	4	main
koguaeg	doc_213943984957_item	3570265	et	3	main
oli	doc_213943984957_item	3570272	et	3	main
minu	doc_213943984957_item	3570273	et	3	main
isa	doc_213943984957_item	3570274	et	4	main
surm	doc_213943984957_item	3570275	et	3	main
kui	doc_213943984957_item	3570276	et	3	main
väga	doc_213943984957_item	3570282	et	3	main
inimest	doc_213943984957_item	3570284	et	3	main
nõusi	doc_213943984957_item	3570291	et	4	main
teine	doc_213943984957_item	3570292	et	3	main
ja	doc_213943984957_item	3570309	et	3	main
veel	doc_213943984957_item	3570310	et	4	main
üks	doc_213943984957_item	3570311	et	3	main
moment	doc_213943984957_item	3570312	et	3	main
minul	doc_213943984957_item	3570313	et	3	main
elus	doc_213943984957_item	3570314	et	4	main
eesti	doc_213943984957_item	3570322	et	4	main
keele	doc_213943984957_item	3570323	et	4	main
keelekursustel	doc_213943984957_item	3570337	et	3	main
loodan	doc_213943984957_item	3570339	et	3	main
essee	doc_213943984957_item	3570061	et	4	main
olen	doc_213943984957_item	3570068	et	3	main
vana	doc_213943984957_item	3570071	et	4	main
väikeses	doc_213943984957_item	3570083	et	4	main
seal	doc_213943984957_item	3570094	et	4	main
mul	doc_213943984957_item	3570095	et	3	main
tegid	doc_213943984957_item	3570113	et	4	main
pärast	doc_213943984957_item	3570125	et	4	main
elukutset	doc_213943984957_item	3570133	et	3	main
25	doc_213943984957_item	3570151	et	2	main
õpetajana	doc_213943984957_item	3570163	et	4	main
on	doc_213943984957_item	3570167	et	4	main
kõige	doc_213943984957_item	3570181	et	4	main
arvates	doc_213943984957_item	3570186	et	4	main
minu	doc_213943984957_item	3570195	et	3	main
pojal	doc_213943984957_item	3570196	et	4	main
juba	doc_213943984957_item	3570197	et	3	main
on	doc_213943984957_item	3570198	et	4	main
14	doc_213943984957_item	3570199	et	2	main
suured	doc_213943984957_item	3570206	et	3	main
positivne	doc_213943984957_item	3570209	et	4	main
minu	doc_213943984957_item	3570211	et	3	main
oli	doc_213943984957_item	3570223	et	3	main
kautasin	doc_213943984957_item	3570281	et	4	main
kallist	doc_213943984957_item	3570283	et	4	main
ja	doc_213943984957_item	3570285	et	3	main
ei	doc_213943984957_item	3570288	et	4	main
jatku	doc_213943984957_item	3570289	et	4	main
on	doc_213943984957_item	3570320	et	4	main
vahe	doc_213943984957_item	3570327	et	4	main
räägin	doc_213943984957_item	3570328	et	3	main
elus	doc_213943984957_item	3570329	et	4	main
mida	doc_213943984957_item	3570335	et	4	main
et	doc_213943984957_item	3570340	et	3	main
ära	doc_213943984957_item	3570343	et	4	main
ekskursioon	doc_213943984963_item	3570357	et	3	main
praegu	doc_213943984963_item	3570359	et	3	main
ja	doc_213943984963_item	3570392	et	3	main
armasta	doc_213943984963_item	3570394	et	4	main
palju	doc_213943984963_item	3570395	et	4	main
üks	doc_213943984963_item	3570405	et	3	main
neist	doc_213943984963_item	3570406	et	4	main
või	doc_213943984963_item	3570424	et	4	main
koridoori	doc_213943984963_item	3570426	et	4	main
meie	doc_213943984963_item	3570429	et	4	main
köök	doc_213943984963_item	3570430	et	3	main
on	doc_213943984963_item	3570431	et	4	main
aga	doc_213943984963_item	3570435	et	3	main
siis	doc_213943984963_item	3570440	et	3	main
ei	doc_213943984963_item	3570442	et	4	main
teda	doc_213943984963_item	3570444	et	4	main
see	doc_213943984963_item	3570445	et	3	main
liiga	doc_213943984963_item	3570451	et	4	main
venna	doc_213943984963_item	3570458	et	3	main
tüüpiline	doc_213943984963_item	3570462	et	3	main
mehe	doc_213943984963_item	3570464	et	3	main
arvutiga	doc_213943984963_item	3570466	et	4	main
ja	doc_213943984963_item	3570467	et	3	main
suure	doc_213943984963_item	3570468	et	3	main
diivaniga	doc_213943984963_item	3570469	et	3	main
nii	doc_213943984963_item	3570470	et	3	main
praegu	doc_213943984963_item	3570471	et	3	main
oleme	doc_213943984963_item	3570472	et	3	main
kolmandas	doc_213943984963_item	3570473	et	3	main
koridooris	doc_213943984963_item	3570474	et	4	main
ja	doc_213943984963_item	3570475	et	3	main
on	doc_213943984963_item	3570486	et	4	main
paremale	doc_213943984963_item	3570493	et	4	main
kõik	doc_213943984963_item	3570503	et	4	main
on	doc_213943984963_item	3570510	et	4	main
ja	doc_213943984963_item	3570514	et	3	main
võib	doc_213943984963_item	3570516	et	3	main
rõdu	doc_213943984963_item	3570523	et	4	main
on	doc_213943984963_item	3570524	et	4	main
kinnine	doc_213943984963_item	3570525	et	3	main
ja	doc_213943984963_item	3570526	et	3	main
põrandal	doc_213943984963_item	3570527	et	3	main
mõelda	doc_213943984963_item	3570537	et	4	main
eesnimi	doc_213943984957_item	3570065	et	3	main
perekonnanimi	doc_213943984957_item	3570066	et	3	main
41	doc_213943984957_item	3570069	et	2	main
täis	doc_213943984957_item	3570077	et	4	main
ma	doc_213943984957_item	3570078	et	3	main
sündinud	doc_213943984957_item	3570079	et	4	main
on	doc_213943984957_item	3570080	et	4	main
aga	doc_213943984957_item	3570085	et	3	main
ma	doc_213943984957_item	3570086	et	3	main
olen	doc_213943984957_item	3570087	et	3	main
õnnelik	doc_213943984957_item	3570088	et	3	main
et	doc_213943984957_item	3570089	et	3	main
oli	doc_213943984957_item	3570096	et	3	main
isa	doc_213943984957_item	3570100	et	4	main
oli	doc_213943984957_item	3570101	et	3	main
tark	doc_213943984957_item	3570102	et	3	main
ja	doc_213943984957_item	3570103	et	3	main
energiline	doc_213943984957_item	3570104	et	3	main
inimene	doc_213943984957_item	3570105	et	3	main
ema	doc_213943984957_item	3570106	et	4	main
on	doc_213943984957_item	3570107	et	4	main
ja	doc_213943984957_item	3570117	et	3	main
huvitavaks	doc_213943984957_item	3570118	et	4	main
keskkooli	doc_213943984957_item	3570126	et	4	main
töötanud	doc_213943984957_item	3570145	et	4	main
5	doc_213943984957_item	3570146	et	2	main
aastat	doc_213943984957_item	3570147	et	3	main
kui	doc_213943984957_item	3570148	et	3	main
ma	doc_213943984957_item	3570149	et	3	main
olin	doc_213943984957_item	3570150	et	3	main
ära	doc_213943984957_item	3570156	et	4	main
tšehhimaale	doc_213943984957_item	3570158	et	2	main
kus	doc_213943984957_item	3570159	et	3	main
aastat	doc_213943984957_item	3570165	et	3	main
elus	doc_213943984957_item	3570172	et	4	main
sellepärast	doc_213943984957_item	3570173	et	3	main
et	doc_213943984957_item	3570174	et	3	main
seal	doc_213943984957_item	3570175	et	4	main
ma	doc_213943984957_item	3570176	et	3	main
tutvustasin	doc_213943984957_item	3570177	et	3	main
paljude	doc_213943984957_item	3570178	et	3	main
inimestega	doc_213943984957_item	3570179	et	3	main
aga	doc_213943984957_item	3570180	et	3	main
on	doc_213943984957_item	3570187	et	4	main
ta	doc_213943984957_item	3570190	et	4	main
aastat	doc_213943984957_item	3570200	et	3	main
vana	doc_213943984957_item	3570201	et	4	main
sõbrad	doc_213943984957_item	3570207	et	3	main
se	doc_213943984957_item	3570216	et	4	main
oli	doc_213943984957_item	3570217	et	3	main
moment	doc_213943984957_item	3570219	et	3	main
minu	doc_213943984957_item	3570220	et	3	main
jaoks	doc_213943984957_item	3570221	et	4	main
maa	doc_213943984957_item	3570225	et	4	main
muljed	doc_213943984957_item	3570227	et	3	main
perekond	doc_213943984957_item	3570229	et	3	main
ma	doc_213943984957_item	3570231	et	3	main
tootan	doc_213943984957_item	3570232	et	4	main
tartu	doc_213943984957_item	3570233	et	4	main
gümnaasiumis	doc_213943984957_item	3570234	et	3	main
juba	doc_213943984957_item	3570235	et	3	main
13	doc_213943984957_item	3570236	et	2	main
aastat	doc_213943984957_item	3570237	et	3	main
see	doc_213943984957_item	3570238	et	3	main
on	doc_213943984957_item	3570239	et	4	main
hea	doc_213943984957_item	3570240	et	4	main
kool	doc_213943984957_item	3570241	et	4	main
ja	doc_213943984957_item	3570242	et	3	main
mul	doc_213943984957_item	3570243	et	3	main
on	doc_213943984957_item	3570244	et	4	main
huvitav	doc_213943984957_item	3570245	et	4	main
töö	doc_213943984957_item	3570246	et	4	main
praegu	doc_213943984957_item	3570247	et	3	main
ma	doc_213943984957_item	3570248	et	3	main
olen	doc_213943984957_item	3570249	et	3	main
õnnelik	doc_213943984957_item	3570250	et	3	main
sest	doc_213943984957_item	3570251	et	4	main
ninul	doc_213943984957_item	3570252	et	3	main
on	doc_213943984957_item	3570253	et	4	main
hea	doc_213943984957_item	3570254	et	4	main
perekond	doc_213943984957_item	3570255	et	3	main
loomulik	doc_213943984957_item	3570256	et	3	main
ja	doc_213943984957_item	3570258	et	3	main
töö	doc_213943984957_item	3570257	et	4	main
suurepärased	doc_213943984957_item	3570259	et	4	main
sõbrad	doc_213943984957_item	3570260	et	3	main
elu	doc_213943984957_item	3570262	et	4	main
korras	doc_213943984957_item	3570266	et	4	main
isa	doc_213943984957_item	3570277	et	4	main
suri	doc_213943984957_item	3570278	et	3	main
teda	doc_213943984957_item	3570290	et	4	main
monent	doc_213943984957_item	3570294	et	4	main
see	doc_213943984957_item	3570295	et	3	main
on	doc_213943984957_item	3570296	et	4	main
esimise	doc_213943984957_item	3570297	et	4	main
pere	doc_213943984957_item	3570298	et	4	main
lahkumine	doc_213943984957_item	3570299	et	4	main
kui	doc_213943984957_item	3570300	et	3	main
perekond	doc_213943984957_item	3570301	et	3	main
ei	doc_213943984957_item	3570302	et	4	main
koos	doc_213943984957_item	3570304	et	4	main
see	doc_213943984957_item	3570305	et	3	main
ela	doc_213943984957_item	3570303	et	4	main
on	doc_213943984957_item	3570306	et	4	main
alati	doc_213943984957_item	3570307	et	4	main
raske	doc_213943984957_item	3570308	et	4	main
raskused	doc_213943984957_item	3570321	et	4	main
õpin	doc_213943984957_item	3570336	et	3	main
ma	doc_213943984957_item	3570338	et	3	main
õpin	doc_213943984957_item	3570342	et	3	main
seda	doc_213943984957_item	3570344	et	3	main
keelt	doc_213943984957_item	3570345	et	4	main
varsti	doc_213943984957_item	3570346	et	3	main
ja	doc_213943984957_item	3570347	et	3	main
siis	doc_213943984957_item	3570348	et	3	main
ma	doc_213943984957_item	3570349	et	3	main
oleks	doc_213943984957_item	3570350	et	3	main
õnnelikuks	doc_213943984957_item	3570351	et	3	main
essee	doc_213943984963_item	3570353	et	4	main
algas	doc_213943984963_item	3570358	et	3	main
suurusega	doc_213943984963_item	3570365	et	4	main
suure	doc_213943984963_item	3570368	et	3	main
vasakule	doc_213943984963_item	3570371	et	4	main
pöördes	doc_213943984963_item	3570372	et	3	main
näeme	doc_213943984963_item	3570373	et	3	main
käia	doc_213943984963_item	3570396	et	4	main
kolm	doc_213943984963_item	3570403	et	3	main
ja	doc_213943984963_item	3570409	et	3	main
on	doc_213943984963_item	3570411	et	4	main
jagatud	doc_213943984963_item	3570412	et	4	main
minna	doc_213943984963_item	3570419	et	3	main
tuppa	doc_213943984963_item	3570423	et	3	main
kolmanda	doc_213943984963_item	3570425	et	3	main
lähme	doc_213943984963_item	3570427	et	3	main
ja	doc_213943984963_item	3570433	et	3	main
ema	doc_213943984963_item	3570437	et	4	main
pärast	doc_213943984963_item	3570446	et	4	main
et	doc_213943984963_item	3570447	et	3	main
palju	doc_213943984963_item	3570452	et	4	main
nüüd	doc_213943984963_item	3570456	et	4	main
on	doc_213943984963_item	3570461	et	4	main
noor	doc_213943984963_item	3570463	et	3	main
tuba	doc_213943984963_item	3570465	et	4	main
ees	doc_213943984963_item	3570477	et	4	main
on	doc_213943984963_item	3570478	et	4	main
minu	doc_213943984963_item	3570495	et	3	main
niimodi	doc_213943984963_item	3570504	et	4	main
tehtud	doc_213943984963_item	3570511	et	4	main
isegi	doc_213943984963_item	3570528	et	4	main
vaip	doc_213943984963_item	3570529	et	3	main
kõige	doc_213943984957_item	3570267	et	4	main
tragiline	doc_213943984957_item	3570268	et	4	main
moment	doc_213943984957_item	3570269	et	3	main
ära	doc_213943984957_item	3570279	et	4	main
negativne	doc_213943984957_item	3570293	et	4	main
mis	doc_213943984957_item	3570315	et	4	main
segab	doc_213943984957_item	3570316	et	3	main
olla	doc_213943984957_item	3570317	et	3	main
õnnelikuks	doc_213943984957_item	3570318	et	3	main
need	doc_213943984957_item	3570319	et	3	main
õpimisega	doc_213943984957_item	3570324	et	4	main
ma	doc_213943984957_item	3570325	et	3	main
väga	doc_213943984957_item	3570326	et	3	main
korter	doc_213943984963_item	3570355	et	3	main
esikus	doc_213943984963_item	3570361	et	3	main
on	doc_213943984963_item	3570363	et	4	main
ja	doc_213943984963_item	3570367	et	3	main
ruum	doc_213943984963_item	3570370	et	3	main
eluruumi	doc_213943984963_item	3570374	et	4	main
see	doc_213943984963_item	3570375	et	3	main
nüüd	doc_213943984963_item	3570397	et	4	main
oleme	doc_213943984963_item	3570398	et	3	main
me	doc_213943984963_item	3570413	et	4	main
oleme	doc_213943984963_item	3570414	et	3	main
väike	doc_213943984963_item	3570432	et	4	main
lähme	doc_213943984963_item	3570457	et	3	main
veel	doc_213943984963_item	3570479	et	4	main
neli	doc_213943984963_item	3570480	et	3	main
ukse	doc_213943984963_item	3570481	et	3	main
kaks	doc_213943984963_item	3570482	et	3	main
wc	doc_213943984963_item	3570489	et	4	main
kõige	doc_213943984963_item	3570490	et	4	main
vasakule	doc_213943984963_item	3570497	et	4	main
magamistuba	doc_213943984963_item	3570499	et	4	main
minu	doc_213943984963_item	3570500	et	3	main
toas	doc_213943984963_item	3570501	et	3	main
on	doc_213943984963_item	3570502	et	4	main
meeldib	doc_213943984963_item	3570507	et	3	main
mulle	doc_213943984963_item	3570508	et	4	main
magamistuba	doc_213943984963_item	3570509	et	4	main
toonides	doc_213943984963_item	3570513	et	4	main
rõdule	doc_213943984963_item	3570517	et	3	main
kus	doc_213943984963_item	3570519	et	3	main
koera	doc_213943984963_item	3570521	et	4	main
välja	doc_213943984963_item	3570536	et	4	main
ekskursioon	doc_213943984963_item	3570541	et	3	main
on	doc_213943984963_item	3570545	et	4	main
liiga	doc_213943984963_item	3570546	et	4	main
palju	doc_213943984963_item	3570547	et	4	main
mida	doc_213943984988_item	3570799	et	4	main
ootan	doc_213943984988_item	3570800	et	3	main
mõlemat	doc_213943984988_item	3570811	et	3	main
ja	doc_213943984988_item	3570815	et	3	main
oma	doc_213943984988_item	3570820	et	4	main
mõtted	doc_213943984988_item	3570821	et	3	main
paberile	doc_213943984988_item	3570822	et	3	main
koolis	doc_213943984988_item	3570823	et	4	main
tihti	doc_213943984988_item	3570824	et	3	main
mind	doc_213943984988_item	3570829	et	4	main
sõbradele	doc_213943984988_item	3570832	et	4	main
seda	doc_213943984988_item	3570848	et	3	main
loodan	doc_213943984988_item	3570873	et	3	main
sest	doc_213943984988_item	3570884	et	4	main
palju	doc_213943984988_item	3570887	et	4	main
oskab	doc_213943984988_item	3570890	et	3	main
mu	doc_213943984988_item	3570892	et	3	main
ööelda	doc_213943984988_item	3570895	et	4	main
heaks	doc_213943984988_item	3570901	et	4	main
kirjanikuks	doc_213943984988_item	3570902	et	3	main
õpimisest	doc_213943984988_item	3570904	et	4	main
paranda	doc_213943984988_item	3570909	et	4	main
kuidas	doc_213943984988_item	3570927	et	3	main
selles	doc_213943984988_item	3570949	et	4	main
erialas	doc_213943984988_item	3570950	et	3	main
töödada	doc_213943984988_item	3570951	et	4	main
valisin	doc_213943984988_item	3570952	et	3	main
lõpetasid	doc_213943984988_item	3570958	et	4	main
nägu	doc_213943984988_item	3570963	et	4	main
teada	doc_213943984988_item	3571003	et	3	main
kultuur	doc_213943985014_item	3571013	et	3	main
viisi	doc_213943985014_item	3571020	et	4	main
kuidas	doc_213943985014_item	3571021	et	3	main
minu	doc_213943984963_item	3570354	et	3	main
oleme	doc_213943984963_item	3570360	et	3	main
on	doc_213943984963_item	3570376	et	4	main
kaasaaegne	doc_213943984963_item	3570377	et	3	main
tuba	doc_213943984963_item	3570378	et	4	main
kahe	doc_213943984963_item	3570379	et	3	main
uksega	doc_213943984963_item	3570380	et	3	main
üks	doc_213943984963_item	3570381	et	3	main
eriti	doc_213943984963_item	3570385	et	3	main
mugav	doc_213943984963_item	3570386	et	3	main
kui	doc_213943984963_item	3570387	et	3	main
sa	doc_213943984963_item	3570388	et	3	main
oled	doc_213943984963_item	3570389	et	3	main
inimene	doc_213943984963_item	3570391	et	3	main
laisk	doc_213943984963_item	3570390	et	3	main
ei	doc_213943984963_item	3570393	et	4	main
koridoori	doc_213943984963_item	3570404	et	4	main
esik	doc_213943984963_item	3570407	et	3	main
teine	doc_213943984963_item	3570408	et	3	main
kolmas	doc_213943984963_item	3570410	et	3	main
köögi	doc_213943984963_item	3570421	et	3	main
köögi	doc_213943984963_item	3570428	et	3	main
kui	doc_213943984963_item	3570436	et	3	main
teeb	doc_213943984963_item	3570439	et	3	main
keegi	doc_213943984963_item	3570441	et	4	main
häire	doc_213943984963_item	3570443	et	4	main
inimest	doc_213943984963_item	3570449	et	3	main
on	doc_213943984963_item	3570450	et	4	main
selle	doc_213943984963_item	3570453	et	4	main
tuppa	doc_213943984963_item	3570459	et	3	main
meie	doc_213943984963_item	3570476	et	4	main
vannituba	doc_213943984963_item	3570487	et	4	main
ja	doc_213943984963_item	3570488	et	3	main
on	doc_213943984963_item	3570494	et	4	main
on	doc_213943984963_item	3570498	et	4	main
sealt	doc_213943984963_item	3570515	et	4	main
asub	doc_213943984963_item	3570520	et	3	main
ruum	doc_213943984963_item	3570522	et	3	main
paremat	doc_213943984963_item	3570531	et	4	main
vist	doc_213943984963_item	3570539	et	4	main
kõik	doc_213943984963_item	3570540	et	4	main
meie	doc_213943984963_item	3570543	et	4	main
vabalt	doc_213943984963_item	3570553	et	4	main
neljale	doc_213943984963_item	3570554	et	4	main
inimesele	doc_213943984963_item	3570555	et	3	main
koeraga	doc_213943984963_item	3570556	et	3	main
ning	doc_213943984963_item	3570557	et	3	main
isegi	doc_213943984963_item	3570558	et	4	main
mängida	doc_213943984963_item	3570559	et	3	main
trepikoda	doc_213943984963_item	3570560	et	4	main
meil	doc_213943984963_item	3570561	et	4	main
on	doc_213943984963_item	3570562	et	4	main
lukus	doc_213943984963_item	3570563	et	3	main
puhas	doc_213943984963_item	3570564	et	3	main
ja	doc_213943984963_item	3570565	et	3	main
remonteeritud	doc_213943984963_item	3570566	et	4	main
mina	doc_213943984963_item	3570567	et	4	main
olen	doc_213943984963_item	3570568	et	3	main
rahul	doc_213943984963_item	3570569	et	4	main
oma	doc_213943984963_item	3570570	et	4	main
korteriga	doc_213943984963_item	3570571	et	3	main
õpimisest	doc_213943984988_item	3570801	et	4	main
raamatuid	doc_213943984988_item	3570812	et	3	main
õpetajad	doc_213943984988_item	3570827	et	4	main
palusid	doc_213943984988_item	3570828	et	4	main
teada	doc_213943984988_item	3570849	et	3	main
õigus	doc_213943984988_item	3570872	et	4	main
seal	doc_213943984988_item	3570885	et	4	main
inimesi	doc_213943984988_item	3570888	et	4	main
köögi	doc_213943984963_item	3570454	et	3	main
jaoks	doc_213943984963_item	3570455	et	4	main
see	doc_213943984963_item	3570460	et	3	main
neist	doc_213943984963_item	3570483	et	4	main
otse	doc_213943984963_item	3570484	et	4	main
see	doc_213943984963_item	3570485	et	3	main
tavalisemad	doc_213943984963_item	3570491	et	4	main
siis	doc_213943984963_item	3570492	et	3	main
tuba	doc_213943984963_item	3570496	et	4	main
pantud	doc_213943984963_item	3570505	et	4	main
kuidas	doc_213943984963_item	3570506	et	3	main
valge	doc_213943984963_item	3570512	et	4	main
minna	doc_213943984963_item	3570518	et	3	main
olemas	doc_213943984963_item	3570530	et	4	main
ei	doc_213943984963_item	3570534	et	4	main
saa	doc_213943984963_item	3570535	et	4	main
koridoori	doc_213943984963_item	3570548	et	4	main
aga	doc_213943984963_item	3570549	et	3	main
võimalus	doc_213943984963_item	3570551	et	3	main
liikuda	doc_213943984963_item	3570552	et	3	main
kohta	doc_213943984963_item	3570532	et	4	main
koerale	doc_213943984963_item	3570533	et	3	main
nüüd	doc_213943984963_item	3570538	et	4	main
lõppes	doc_213943984963_item	3570542	et	4	main
korteris	doc_213943984963_item	3570544	et	3	main
on	doc_213943984963_item	3570550	et	4	main
1	doc_213943984988_item	3570793	et	2	main
valisin	doc_213943984988_item	3570795	et	3	main
ja	doc_213943984988_item	3570813	et	3	main
kõik	doc_213943984988_item	3570825	et	4	main
uudiseid	doc_213943984988_item	3570826	et	3	main
neid	doc_213943984988_item	3570844	et	4	main
et	doc_213943984988_item	3570845	et	3	main
igaüks	doc_213943984988_item	3570846	et	3	main
saaks	doc_213943984988_item	3570847	et	3	main
muinastuttud	doc_213943984988_item	3570882	et	4	main
on	doc_213943984988_item	3570886	et	4	main
kas	doc_213943984988_item	3570897	et	3	main
ma	doc_213943984988_item	3570899	et	3	main
kõik	doc_213943984988_item	3570943	et	4	main
abitseb	doc_213943984988_item	3570946	et	4	main
selle	doc_213943984988_item	3570953	et	4	main
ülikooli	doc_213943984988_item	3570954	et	4	main
sest	doc_213943984988_item	3570955	et	4	main
siin	doc_213943984988_item	3570961	et	4	main
ja	doc_213943984988_item	3570962	et	3	main
kõik	doc_213943984988_item	3570972	et	4	main
oma	doc_213943984988_item	3570973	et	4	main
inimeseid	doc_213943984988_item	3570998	et	4	main
nii	doc_213943984988_item	3571004	et	3	main
palju	doc_213943984988_item	3571005	et	4	main
infot	doc_213943984988_item	3571007	et	3	main
ei	doc_213943985014_item	3571014	et	4	main
meid	doc_213943985014_item	3571028	et	4	main
pikema	doc_213943985014_item	3571035	et	4	main
küll	doc_213943985014_item	3571042	et	4	main
arendamiseks	doc_213943985014_item	3571055	et	4	main
meie	doc_213943985014_item	3571056	et	4	main
b	doc_213943985014_item	3571067	et	4	main
jõuda	doc_213943985014_item	3571112	et	3	main
sageli	doc_213943985014_item	3571115	et	3	main
ja	doc_213943985014_item	3571118	et	3	main
kultuur	doc_213943985018_item	3571127	et	3	main
käitume	doc_213943985018_item	3571139	et	3	main
end	doc_213943985018_item	3571140	et	4	main
vaid	doc_213943985018_item	3571142	et	3	main
mida	doc_213943985018_item	3571145	et	4	main
me	doc_213943985018_item	3571146	et	4	main
arendame	doc_213943985018_item	3571147	et	3	main
otsimisele	doc_213943985018_item	3571175	et	4	main
tõest	doc_213943985018_item	3571185	et	4	main
pakuvad	doc_213943985018_item	3571186	et	3	main
aga	doc_213943985018_item	3571187	et	3	main
erinevaid	doc_213943985018_item	3571188	et	4	main
teised	doc_213943985018_item	3571195	et	4	main
b	doc_213943985018_item	3571209	et	4	main
aga	doc_213943985018_item	3571210	et	3	main
ma	doc_213943985029_item	3571240	et	3	main
eriala	doc_213943985029_item	3571243	et	4	main
mida	doc_213943985029_item	3571245	et	4	main
ootan	doc_213943985029_item	3571246	et	3	main
õppimisest	doc_213943985029_item	3571247	et	4	main
eriala	doc_213943985029_item	3571255	et	4	main
ajakirjandus	doc_213943985029_item	3571256	et	3	main
selle	doc_213943985029_item	3571257	et	4	main
keeles	doc_213943985029_item	3571264	et	4	main
halb	doc_213943985029_item	3571268	et	3	main
keeles	doc_213943985029_item	3571271	et	4	main
ootan	doc_213943985029_item	3571276	et	3	main
meie	doc_213943985029_item	3571278	et	4	main
teadmised	doc_213943985029_item	3571279	et	4	main
ma	doc_213943985029_item	3571284	et	3	main
õpetajaks	doc_213943985029_item	3571288	et	4	main
ainult	doc_213943985029_item	3571291	et	4	main
valisin	doc_213943985029_item	3571303	et	3	main
ülikool	doc_213943985029_item	3571305	et	4	main
valisin	doc_213943985029_item	3571314	et	3	main
kõik	doc_213943984988_item	3570979	et	4	main
mis	doc_213943984988_item	3570980	et	4	main
on	doc_213943984988_item	3570981	et	4	main
vaja	doc_213943984988_item	3570982	et	4	main
hea	doc_213943984988_item	3570983	et	4	main
kirjanikule	doc_213943984988_item	3570984	et	3	main
ülikoolist	doc_213943984988_item	3570985	et	4	main
kõige	doc_213943984988_item	3570986	et	4	main
rohkem	doc_213943984988_item	3570987	et	4	main
tahan	doc_213943984988_item	3570988	et	3	main
saada	doc_213943984988_item	3570989	et	4	main
hea	doc_213943984988_item	3570990	et	4	main
õpimise	doc_213943984988_item	3570991	et	4	main
aja	doc_213943984988_item	3570992	et	4	main
veetmine	doc_213943984988_item	3570993	et	4	main
ja	doc_213943984988_item	3570994	et	3	main
tahan	doc_213943984988_item	3570995	et	3	main
tutvustada	doc_213943984988_item	3570996	et	3	main
miks	doc_213943984988_item	3570794	et	4	main
selles	doc_213943984988_item	3570802	et	4	main
erialal	doc_213943984988_item	3570803	et	3	main
ja	doc_213943984988_item	3570804	et	3	main
tü	doc_213943984988_item	3570805	et	4	main
1	doc_213943984988_item	3570806	et	2	main
valisin	doc_213943984988_item	3570807	et	3	main
sest	doc_213943984988_item	3570808	et	4	main
armastan	doc_213943984988_item	3570809	et	3	main
lugeda	doc_213943984988_item	3570810	et	3	main
mulle	doc_213943984988_item	3570817	et	4	main
meeldib	doc_213943984988_item	3570818	et	3	main
oma	doc_213943984988_item	3570831	et	4	main
mulle	doc_213943984988_item	3570835	et	4	main
meeldis	doc_213943984988_item	3570836	et	3	main
tahaksin	doc_213943984988_item	3570837	et	3	main
teada	doc_213943984988_item	3570838	et	3	main
kõik	doc_213943984988_item	3570839	et	4	main
viimaseid	doc_213943984988_item	3570840	et	3	main
uudiseid	doc_213943984988_item	3570841	et	3	main
ja	doc_213943984988_item	3570842	et	3	main
kirjutada	doc_213943984988_item	3570843	et	3	main
et	doc_213943984988_item	3570851	et	3	main
ajakirjanikud	doc_213943984988_item	3570852	et	3	main
meie	doc_213943984988_item	3570853	et	4	main
ajas	doc_213943984988_item	3570854	et	4	main
on	doc_213943984988_item	3570855	et	4	main
väga	doc_213943984988_item	3570856	et	3	main
vajalikud	doc_213943984988_item	3570857	et	3	main
inimesed	doc_213943984988_item	3570858	et	3	main
sest	doc_213943984988_item	3570859	et	4	main
informatsioon	doc_213943984988_item	3570860	et	3	main
annab	doc_213943984988_item	3570861	et	3	main
palju	doc_213943984988_item	3570862	et	4	main
võimalusi	doc_213943984988_item	3570863	et	3	main
ma	doc_213943984988_item	3570864	et	3	main
tahan	doc_213943984988_item	3570865	et	3	main
infoormeerida	doc_213943984988_item	3570866	et	4	main
inimesed	doc_213943984988_item	3570867	et	3	main
ja	doc_213943984988_item	3570868	et	3	main
anda	doc_213943984988_item	3570869	et	3	main
veel	doc_213943984988_item	3570874	et	4	main
essee	doc_213943984988_item	3570792	et	4	main
selle	doc_213943984988_item	3570796	et	4	main
eriala	doc_213943984988_item	3570797	et	4	main
2	doc_213943984988_item	3570798	et	2	main
artikleid	doc_213943984988_item	3570814	et	3	main
veel	doc_213943984988_item	3570816	et	4	main
kirjutada	doc_213943984988_item	3570819	et	3	main
rääkida	doc_213943984988_item	3570830	et	3	main
ja	doc_213943984988_item	3570833	et	3	main
seda	doc_213943984988_item	3570834	et	3	main
arvan	doc_213943984988_item	3570850	et	3	main
nendele	doc_213943984988_item	3570870	et	4	main
et	doc_213943984988_item	3570875	et	3	main
tulevikus	doc_213943984988_item	3570876	et	4	main
hakkan	doc_213943984988_item	3570877	et	3	main
kirjutada	doc_213943984988_item	3570878	et	3	main
oma	doc_213943984988_item	3570879	et	4	main
artikleid	doc_213943984988_item	3570880	et	3	main
ja	doc_213943984988_item	3570881	et	3	main
kes	doc_213943984988_item	3570889	et	4	main
parandada	doc_213943984988_item	3570891	et	3	main
ja	doc_213943984988_item	3570894	et	3	main
saada	doc_213943984988_item	3570900	et	4	main
2	doc_213943984988_item	3570903	et	2	main
ootan	doc_213943984988_item	3570905	et	3	main
väga	doc_213943984988_item	3570906	et	3	main
kirjutavad	doc_213943984988_item	3570926	et	4	main
valida	doc_213943984988_item	3570929	et	3	main
artiklid	doc_213943984988_item	3570931	et	3	main
inimestele	doc_213943984988_item	3570932	et	3	main
või	doc_213943984988_item	3570934	et	4	main
saan	doc_213943984988_item	3570942	et	4	main
palju	doc_213943984988_item	3570956	et	4	main
sõbrad	doc_213943984988_item	3570957	et	3	main
sest	doc_213943984988_item	3570970	et	4	main
teavad	doc_213943984988_item	3570971	et	3	main
tahan	doc_213943984988_item	3571002	et	3	main
on	doc_213943984988_item	3571009	et	4	main
võimalikult	doc_213943984988_item	3571010	et	4	main
mõjuta	doc_213943985014_item	3571015	et	4	main
meie	doc_213943985014_item	3571018	et	4	main
me	doc_213943985014_item	3571025	et	4	main
aja	doc_213943985014_item	3571036	et	4	main
tegeleb	doc_213943985014_item	3571044	et	3	main
tasandil	doc_213943985014_item	3571048	et	3	main
a	doc_213943985014_item	3571061	et	4	main
ei	doc_213943985014_item	3571068	et	4	main
konfliktideni	doc_213943985014_item	3571119	et	3	main
kultuur	doc_213943985018_item	3571122	et	3	main
meie	doc_213943985018_item	3571138	et	4	main
tegude	doc_213943985018_item	3571149	et	3	main
on	doc_213943985018_item	3571178	et	4	main
a	doc_213943985018_item	3571206	et	4	main
1	doc_213943985029_item	3571238	et	2	main
2	doc_213943985029_item	3571244	et	2	main
ma	doc_213943985029_item	3571253	et	3	main
valisin	doc_213943985029_item	3571254	et	3	main
kahjuks	doc_213943985029_item	3571265	et	4	main
olnud	doc_213943985029_item	3571280	et	4	main
väga	doc_213943985029_item	3571281	et	3	main
tahaksin	doc_213943985029_item	3571285	et	3	main
ajaloo	doc_213943985029_item	3571287	et	4	main
aga	doc_213943985029_item	3571289	et	3	main
ma	doc_213943985029_item	3571302	et	3	main
palju	doc_213943985029_item	3571338	et	4	main
ajaloos	doc_213943985029_item	3571340	et	4	main
ma	doc_213943985029_item	3571369	et	3	main
radios	doc_213943985029_item	3571376	et	4	main
praegu	doc_213943985029_item	3571377	et	3	main
aga	doc_213943985029_item	3571389	et	3	main
loodan	doc_213943985029_item	3571390	et	3	main
õppida	doc_213943985029_item	3571391	et	3	main
sellel	doc_213943985029_item	3571392	et	4	main
ülikoolis	doc_213943985029_item	3571393	et	4	main
pakub	doc_213943985029_item	3571411	et	3	main
erialast	doc_213943985029_item	3571413	et	4	main
et	doc_213943985029_item	3571417	et	3	main
ja	doc_213943985029_item	3571425	et	3	main
raske	doc_213943985029_item	3571428	et	4	main
valida	doc_213943985029_item	3571429	et	3	main
ülikool	doc_213943985029_item	3571430	et	4	main
aga	doc_213943985029_item	3571431	et	3	main
ainult	doc_213943984988_item	3570871	et	4	main
internetis	doc_213943984988_item	3570883	et	4	main
vead	doc_213943984988_item	3570893	et	4	main
võin	doc_213943984988_item	3570898	et	3	main
palju	doc_213943984988_item	3570907	et	4	main
vene	doc_213943984988_item	3570911	et	4	main
kuidas	doc_213943984988_item	3570923	et	3	main
artikleid	doc_213943984988_item	3570925	et	3	main
meeldivad	doc_213943984988_item	3570933	et	4	main
ei	doc_213943984988_item	3570935	et	4	main
meeldi	doc_213943984988_item	3570936	et	4	main
üldse	doc_213943984988_item	3570937	et	3	main
loodan	doc_213943984988_item	3570938	et	3	main
et	doc_213943984988_item	3570939	et	3	main
infot	doc_213943984988_item	3570944	et	3	main
mulle	doc_213943984988_item	3570947	et	4	main
tulevikus	doc_213943984988_item	3570948	et	4	main
ma	doc_213943984988_item	3570964	et	3	main
on	doc_213943984988_item	3570967	et	4	main
erialast	doc_213943984988_item	3570974	et	4	main
uued	doc_213943984988_item	3570997	et	3	main
aga	doc_213943984988_item	3570999	et	3	main
õpimisest	doc_213943984988_item	3571000	et	4	main
mitte	doc_213943985014_item	3571016	et	3	main
ainult	doc_213943985014_item	3571017	et	4	main
igapäevatoimingud	doc_213943985014_item	3571019	et	3	main
juhime	doc_213943985014_item	3571026	et	3	main
kasvatatakse	doc_213943985014_item	3571029	et	3	main
dünaamika	doc_213943985014_item	3571031	et	4	main
ehk	doc_213943985014_item	3571032	et	3	main
küsimuse	doc_213943985014_item	3571039	et	4	main
tõest	doc_213943985014_item	3571040	et	4	main
otsimisega	doc_213943985014_item	3571046	et	4	main
oluline	doc_213943985014_item	3571049	et	4	main
kuidas	doc_213943985014_item	3571051	et	3	main
loogika	doc_213943985014_item	3571057	et	4	main
puudub	doc_213943985014_item	3571058	et	3	main
et	doc_213943985014_item	3571059	et	3	main
kui	doc_213943985014_item	3571060	et	3	main
tõde	doc_213943985014_item	3571070	et	4	main
aga	doc_213943985014_item	3571071	et	3	main
idaloogikas	doc_213943985014_item	3571072	et	3	main
sellinne	doc_213943985014_item	3571073	et	4	main
põhimõtte	doc_213943985014_item	3571074	et	3	main
puudub	doc_213943985014_item	3571075	et	3	main
mulle	doc_213943984988_item	3570896	et	4	main
tahan	doc_213943984988_item	3570908	et	3	main
oma	doc_213943984988_item	3570910	et	4	main
keele	doc_213943984988_item	3570912	et	4	main
oskus	doc_213943984988_item	3570913	et	3	main
grammatika	doc_213943984988_item	3570914	et	4	main
jne	doc_213943984988_item	3570915	et	4	main
tahan	doc_213943984988_item	3570916	et	3	main
teada	doc_213943984988_item	3570917	et	3	main
kõik	doc_213943984988_item	3570918	et	4	main
tööd	doc_213943984988_item	3570919	et	4	main
mida	doc_213943984988_item	3570920	et	4	main
teevad	doc_213943984988_item	3570921	et	3	main
ajakirjanikud	doc_213943984988_item	3570922	et	3	main
nad	doc_213943984988_item	3570924	et	3	main
uudiseid	doc_213943984988_item	3570928	et	3	main
missuguseid	doc_213943984988_item	3570930	et	3	main
tallinna	doc_213943984988_item	3570940	et	4	main
ülikoolis	doc_213943984988_item	3570941	et	4	main
mis	doc_213943984988_item	3570945	et	4	main
või	doc_213943984988_item	3570959	et	4	main
õppevad	doc_213943984988_item	3570960	et	4	main
arvan	doc_213943984988_item	3570965	et	3	main
nad	doc_213943984988_item	3570966	et	3	main
head	doc_213943984988_item	3570968	et	4	main
töötaja	doc_213943984988_item	3570969	et	4	main
mina	doc_213943984988_item	3570975	et	4	main
ka	doc_213943984988_item	3570976	et	3	main
tahan	doc_213943984988_item	3570977	et	3	main
teada	doc_213943984988_item	3570978	et	3	main
kõigepealt	doc_213943984988_item	3571001	et	3	main
uut	doc_213943984988_item	3571006	et	3	main
kui	doc_213943984988_item	3571008	et	3	main
essee	doc_213943985014_item	3571012	et	4	main
kuidas	doc_213943985014_item	3571027	et	3	main
konfutsiaanlik	doc_213943985014_item	3571030	et	4	main
lühema	doc_213943985014_item	3571033	et	4	main
või	doc_213943985014_item	3571034	et	4	main
lahtiseks	doc_213943985014_item	3571041	et	4	main
hüve	doc_213943985014_item	3571045	et	4	main
on	doc_213943985014_item	3571054	et	4	main
vastand	doc_213943985014_item	3571066	et	4	main
et	doc_213943985014_item	3571076	et	3	main
kui	doc_213943985014_item	3571077	et	3	main
a	doc_213943985014_item	3571078	et	4	main
on	doc_213943985014_item	3571079	et	4	main
tõde	doc_213943985014_item	3571080	et	4	main
siis	doc_213943985014_item	3571081	et	3	main
selle	doc_213943985014_item	3571082	et	4	main
vastand	doc_213943985014_item	3571083	et	4	main
b	doc_213943985014_item	3571084	et	4	main
võib	doc_213943985014_item	3571085	et	3	main
samuti	doc_213943985014_item	3571086	et	3	main
tõde	doc_213943985014_item	3571087	et	4	main
olla	doc_213943985014_item	3571088	et	3	main
inimene	doc_213943985014_item	3571089	et	3	main
ei	doc_213943985014_item	3571090	et	4	main
saa	doc_213943985014_item	3571091	et	4	main
kunagi	doc_213943985014_item	3571092	et	3	main
jõuda	doc_213943985014_item	3571093	et	3	main
täieliku	doc_213943985014_item	3571094	et	3	main
tõeni	doc_213943985014_item	3571095	et	4	main
lääne	doc_213943985014_item	3571096	et	4	main
mõtteviisi	doc_213943985014_item	3571097	et	4	main
võib	doc_213943985014_item	3571098	et	3	main
pidada	doc_213943985014_item	3571099	et	4	main
pigem	doc_213943985014_item	3571100	et	3	main
analüüsivaks	doc_213943985014_item	3571101	et	4	main
ning	doc_213943985014_item	3571102	et	3	main
ida	doc_213943985014_item	3571103	et	4	main
mõtteviisi	doc_213943985014_item	3571104	et	4	main
sünteesivaks	doc_213943985014_item	3571105	et	4	main
läänes	doc_213943985014_item	3571106	et	4	main
püütakse	doc_213943985014_item	3571107	et	3	main
iga	doc_213943985014_item	3571108	et	4	main
hinna	doc_213943985014_item	3571109	et	3	main
eest	doc_213943985014_item	3571110	et	4	main
välja	doc_213943985014_item	3571111	et	4	main
tõeni	doc_213943985014_item	3571113	et	4	main
me	doc_213943985014_item	3571022	et	4	main
elame	doc_213943985014_item	3571023	et	3	main
kuidas	doc_213943985014_item	3571024	et	3	main
orientatsioon	doc_213943985014_item	3571037	et	3	main
jätab	doc_213943985014_item	3571038	et	3	main
aga	doc_213943985014_item	3571043	et	3	main
ühiskonna	doc_213943985014_item	3571047	et	4	main
on	doc_213943985014_item	3571050	et	4	main
leida	doc_213943985014_item	3571052	et	3	main
viis	doc_213943985014_item	3571053	et	4	main
on	doc_213943985014_item	3571062	et	4	main
tõde	doc_213943985014_item	3571063	et	4	main
siis	doc_213943985014_item	3571064	et	3	main
selle	doc_213943985014_item	3571065	et	4	main
ole	doc_213943985014_item	3571069	et	4	main
mis	doc_213943985014_item	3571114	et	4	main
viib	doc_213943985014_item	3571116	et	3	main
räägitakse	doc_213943985018_item	3571124	et	3	main
et	doc_213943985018_item	3571126	et	3	main
tänapäeva	doc_213943985018_item	3571132	et	4	main
elu	doc_213943985018_item	3571133	et	4	main
kuidas	doc_213943985018_item	3571134	et	3	main
meie	doc_213943985018_item	3571135	et	4	main
elame	doc_213943985018_item	3571136	et	3	main
oma	doc_213943985018_item	3571148	et	4	main
otsi	doc_213943985018_item	3571183	et	4	main
absoluutse	doc_213943985018_item	3571184	et	3	main
juba	doc_213943985018_item	3571194	et	3	main
on	doc_213943985018_item	3571207	et	4	main
otsimine	doc_213943985018_item	3571212	et	4	main
essee	doc_213943985029_item	3571237	et	4	main
sellel	doc_213943985029_item	3571248	et	4	main
erialal	doc_213943985029_item	3571249	et	3	main
pärast	doc_213943985029_item	3571258	et	4	main
väga	doc_213943985029_item	3571267	et	3	main
hea	doc_213943985029_item	3571282	et	4	main
eesti	doc_213943985029_item	3571294	et	4	main
keeles	doc_213943985029_item	3571295	et	4	main
ja	doc_213943985029_item	3571296	et	3	main
ma	doc_213943985029_item	3571298	et	3	main
selle	doc_213943985029_item	3571300	et	4	main
tallinna	doc_213943985029_item	3571304	et	4	main
selle	doc_213943985029_item	3571306	et	4	main
pärast	doc_213943985029_item	3571307	et	4	main
et	doc_213943985029_item	3571308	et	3	main
see	doc_213943985029_item	3571309	et	3	main
ka	doc_213943985029_item	3571337	et	3	main
tundi	doc_213943985029_item	3571339	et	4	main
või	doc_213943985029_item	3571375	et	4	main
kõige	doc_213943985029_item	3571434	et	4	main
miks	doc_213943985048_item	3571438	et	4	main
selle	doc_213943985048_item	3571453	et	4	main
eriala	doc_213943985048_item	3571454	et	4	main
saavad	doc_213943985048_item	3571471	et	4	main
sest	doc_213943985048_item	3571486	et	4	main
eestlastega	doc_213943985048_item	3571491	et	4	main
töö	doc_213943985048_item	3571504	et	4	main
lapsepõlvest	doc_213943985048_item	3571505	et	4	main
ma	doc_213943985048_item	3571506	et	3	main
unustasin	doc_213943985048_item	3571507	et	3	main
töötada	doc_213943985048_item	3571511	et	3	main
minu	doc_213943985048_item	3571513	et	3	main
teises	doc_213943985048_item	3571569	et	4	main
linnades	doc_213943985048_item	3571570	et	3	main
ei	doc_213943985048_item	3571587	et	4	main
hea	doc_213943985048_item	3571593	et	4	main
töö	doc_213943985048_item	3571594	et	4	main
suure	doc_213943985048_item	3571595	et	3	main
palgaga	doc_213943985048_item	3571596	et	3	main
on	doc_213943985048_item	3571599	et	4	main
kes	doc_213943985048_item	3571609	et	4	main
õppivad	doc_213943985048_item	3571610	et	4	main
õppida	doc_213943985048_item	3571630	et	3	main
mul	doc_213943985048_item	3571633	et	3	main
õpitajatega	doc_213943985048_item	3571637	et	4	main
selles	doc_213943985048_item	3571638	et	4	main
ülikoolis	doc_213943985048_item	3571639	et	4	main
kuulan	doc_213943985071_item	3571645	et	3	main
on	doc_213943985071_item	3571674	et	4	main
essee	doc_213943985018_item	3571121	et	4	main
tekstis	doc_213943985018_item	3571123	et	3	main
seletamiseks	doc_213943985018_item	3571150	et	4	main
siin	doc_213943985018_item	3571151	et	4	main
ka	doc_213943985018_item	3571152	et	3	main
kirjutatakse	doc_213943985018_item	3571153	et	3	main
et	doc_213943985018_item	3571154	et	3	main
kultuurid	doc_213943985018_item	3571155	et	3	main
saavad	doc_213943985018_item	3571156	et	4	main
olla	doc_213943985018_item	3571157	et	3	main
väga	doc_213943985018_item	3571158	et	3	main
erinevad	doc_213943985018_item	3571159	et	4	main
näiteks	doc_213943985018_item	3571160	et	4	main
lääne	doc_213943985018_item	3571161	et	4	main
kultuurid	doc_213943985018_item	3571162	et	3	main
usuvad	doc_213943985018_item	3571163	et	3	main
et	doc_213943985018_item	3571164	et	3	main
on	doc_213943985018_item	3571165	et	4	main
olemas	doc_213943985018_item	3571166	et	4	main
absoluutne	doc_213943985018_item	3571167	et	3	main
tõde	doc_213943985018_item	3571168	et	4	main
ja	doc_213943985018_item	3571169	et	3	main
sellepärast	doc_213943985018_item	3571170	et	3	main
need	doc_213943985018_item	3571171	et	3	main
kultuurid	doc_213943985018_item	3571172	et	3	main
pühenduvad	doc_213943985018_item	3571173	et	4	main
tõe	doc_213943985018_item	3571174	et	4	main
ida	doc_213943985018_item	3571176	et	4	main
kultuurides	doc_213943985018_item	3571177	et	3	main
teine	doc_213943985018_item	3571179	et	3	main
kultuurid	doc_213943985018_item	3571196	et	3	main
kelle	doc_213943985018_item	3571197	et	4	main
mõtteviis	doc_213943985018_item	3571198	et	3	main
eraldab	doc_213943985018_item	3571199	et	3	main
ida	doc_213943985018_item	3571200	et	4	main
kultuuridest	doc_213943985018_item	3571201	et	3	main
kui	doc_213943985018_item	3571202	et	3	main
näiteks	doc_213943985018_item	3571203	et	4	main
võtame	doc_213943985018_item	3571204	et	3	main
vaidlusteni	doc_213943985014_item	3571117	et	3	main
selles	doc_213943985018_item	3571125	et	4	main
on	doc_213943985018_item	3571128	et	4	main
mitte	doc_213943985018_item	3571129	et	3	main
ainult	doc_213943985018_item	3571130	et	4	main
meie	doc_213943985018_item	3571131	et	4	main
kuidas	doc_213943985018_item	3571137	et	3	main
jne	doc_213943985018_item	3571141	et	4	main
ka	doc_213943985018_item	3571143	et	3	main
seda	doc_213943985018_item	3571144	et	3	main
filosoofia	doc_213943985018_item	3571180	et	4	main
nad	doc_213943985018_item	3571181	et	3	main
ei	doc_213943985018_item	3571182	et	4	main
enesearendamisvõimalusi	doc_213943985018_item	3571189	et	4	main
st	doc_213943985018_item	3571190	et	3	main
et	doc_213943985018_item	3571191	et	3	main
need	doc_213943985018_item	3571192	et	3	main
on	doc_213943985018_item	3571193	et	4	main
enesearendamisvõimalused	doc_213943985018_item	3571208	et	4	main
ütleme	doc_213943985018_item	3571214	et	3	main
ja	doc_213943985018_item	3571213	et	3	main
et	doc_213943985018_item	3571215	et	3	main
a	doc_213943985018_item	3571216	et	4	main
on	doc_213943985018_item	3571217	et	4	main
õige	doc_213943985018_item	3571218	et	4	main
siis	doc_213943985018_item	3571219	et	3	main
tähendab	doc_213943985018_item	3571220	et	3	main
see	doc_213943985018_item	3571221	et	3	main
seda	doc_213943985018_item	3571222	et	3	main
et	doc_213943985018_item	3571223	et	3	main
b	doc_213943985018_item	3571224	et	4	main
on	doc_213943985018_item	3571225	et	4	main
vale	doc_213943985018_item	3571226	et	4	main
viisil	doc_213943985018_item	3571228	et	4	main
võib	doc_213943985018_item	3571229	et	3	main
nii	doc_213943985018_item	3571227	et	3	main
olla	doc_213943985018_item	3571230	et	3	main
kas	doc_213943985018_item	3571231	et	3	main
a	doc_213943985018_item	3571232	et	4	main
või	doc_213943985018_item	3571233	et	4	main
b	doc_213943985018_item	3571234	et	4	main
mõtteviis	doc_213943985018_item	3571235	et	3	main
valisin	doc_213943985029_item	3571241	et	3	main
ja	doc_213943985029_item	3571250	et	3	main
et	doc_213943985029_item	3571259	et	3	main
see	doc_213943985029_item	3571260	et	3	main
oli	doc_213943985029_item	3571261	et	3	main
eriala	doc_213943985029_item	3571262	et	4	main
veene	doc_213943985029_item	3571263	et	4	main
eesti	doc_213943985029_item	3571270	et	4	main
ja	doc_213943985029_item	3571272	et	3	main
ma	doc_213943985029_item	3571273	et	3	main
loodan	doc_213943985029_item	3571274	et	3	main
esimiseks	doc_213943985029_item	3571283	et	4	main
mul	doc_213943985029_item	3571290	et	3	main
43	doc_213943985029_item	3571292	et	2	main
punkti	doc_213943985029_item	3571293	et	4	main
on	doc_213943985029_item	3571310	et	4	main
riigi	doc_213943985029_item	3571311	et	3	main
ülikool	doc_213943985029_item	3571312	et	4	main
et	doc_213943985018_item	3571205	et	3	main
tõe	doc_213943985018_item	3571211	et	4	main
nii	doc_213943985029_item	3571400	et	3	main
raske	doc_213943985029_item	3571401	et	4	main
õppida	doc_213943985029_item	3571402	et	3	main
ülikoolis	doc_213943985029_item	3571403	et	4	main
palju	doc_213943985029_item	3571404	et	4	main
raskeid	doc_213943985029_item	3571405	et	3	main
asju	doc_213943985029_item	3571406	et	3	main
naiteks	doc_213943985029_item	3571407	et	4	main
ap	doc_213943985029_item	3571408	et	4	main
tallinna	doc_213943985029_item	3571409	et	4	main
miks	doc_213943985029_item	3571239	et	4	main
selle	doc_213943985029_item	3571242	et	4	main
tallinna	doc_213943985029_item	3571251	et	4	main
ülikoolis	doc_213943985029_item	3571252	et	4	main
ma	doc_213943985029_item	3571266	et	3	main
rägin	doc_213943985029_item	3571269	et	3	main
ja	doc_213943985029_item	3571275	et	3	main
et	doc_213943985029_item	3571277	et	3	main
astuda	doc_213943985029_item	3571286	et	3	main
siis	doc_213943985029_item	3571297	et	3	main
valisin	doc_213943985029_item	3571299	et	3	main
eriala	doc_213943985029_item	3571301	et	4	main
ma	doc_213943985029_item	3571313	et	3	main
sest	doc_213943985029_item	3571317	et	4	main
mulle	doc_213943985029_item	3571318	et	4	main
tuntub	doc_213943985029_item	3571319	et	4	main
et	doc_213943985029_item	3571320	et	3	main
see	doc_213943985029_item	3571321	et	3	main
on	doc_213943985029_item	3571322	et	4	main
väga	doc_213943985029_item	3571323	et	3	main
huvitav	doc_213943985029_item	3571324	et	4	main
mulle	doc_213943985029_item	3571325	et	4	main
meeldib	doc_213943985029_item	3571326	et	3	main
ajalugu	doc_213943985029_item	3571327	et	4	main
kahjuks	doc_213943985029_item	3571328	et	4	main
ma	doc_213943985029_item	3571329	et	3	main
ei	doc_213943985029_item	3571330	et	4	main
astuda	doc_213943985029_item	3571331	et	3	main
ajaloo	doc_213943985029_item	3571332	et	4	main
õpetajaks	doc_213943985029_item	3571333	et	4	main
aga	doc_213943985029_item	3571334	et	3	main
eriala	doc_213943985029_item	3571335	et	4	main
ajakirjandus	doc_213943985029_item	3571336	et	3	main
ülikooli	doc_213943985029_item	3571368	et	4	main
loodan	doc_213943985029_item	3571370	et	3	main
töö	doc_213943985029_item	3571372	et	4	main
veene	doc_213943985029_item	3571373	et	4	main
ajalehes	doc_213943985029_item	3571374	et	3	main
ei	doc_213943985029_item	3571379	et	4	main
ootan	doc_213943985029_item	3571383	et	3	main
viis	doc_213943985029_item	3571394	et	4	main
mulle	doc_213943985029_item	3571397	et	4	main
et	doc_213943985029_item	3571399	et	3	main
palju	doc_213943985029_item	3571412	et	4	main
ma	doc_213943985029_item	3571415	et	3	main
eraülikoolid	doc_213943985029_item	3571424	et	3	main
et	doc_213943985029_item	3571427	et	3	main
valisin	doc_213943985048_item	3571440	et	3	main
keel	doc_213943985048_item	3571459	et	4	main
ma	doc_213943985048_item	3571460	et	3	main
õppitada	doc_213943985048_item	3571462	et	4	main
teised	doc_213943985048_item	3571463	et	4	main
inimesed	doc_213943985048_item	3571464	et	3	main
tahaksin	doc_213943985048_item	3571465	et	3	main
nad	doc_213943985048_item	3571467	et	3	main
oskavad	doc_213943985048_item	3571468	et	4	main
ja	doc_213943985048_item	3571469	et	3	main
aru	doc_213943985048_item	3571470	et	4	main
vene	doc_213943985048_item	3571474	et	4	main
veel	doc_213943985048_item	3571487	et	4	main
tahan	doc_213943985048_item	3571489	et	3	main
saan	doc_213943985048_item	3571493	et	4	main
selle	doc_213943985029_item	3571315	et	4	main
eriala	doc_213943985029_item	3571316	et	4	main
tallinna	doc_213943985029_item	3571367	et	4	main
tea	doc_213943985029_item	3571380	et	4	main
mida	doc_213943985029_item	3571381	et	4	main
sellel	doc_213943985029_item	3571384	et	4	main
erialal	doc_213943985029_item	3571385	et	3	main
ja	doc_213943985029_item	3571386	et	3	main
tallinna	doc_213943985029_item	3571387	et	4	main
ülikoolis	doc_213943985029_item	3571388	et	4	main
tänapäeval	doc_213943985029_item	3571396	et	3	main
huvitavam	doc_213943985029_item	3571419	et	4	main
ajakirjandus	doc_213943985029_item	3571420	et	3	main
paremat	doc_213943985029_item	3571435	et	4	main
selle	doc_213943985048_item	3571441	et	4	main
mulle	doc_213943985048_item	3571456	et	4	main
meeldib	doc_213943985048_item	3571457	et	3	main
et	doc_213943985048_item	3571466	et	3	main
räägivad	doc_213943985048_item	3571473	et	3	main
ülikoolis	doc_213943985048_item	3571476	et	4	main
saan	doc_213943985048_item	3571478	et	4	main
mitmesugune	doc_213943985048_item	3571480	et	3	main
inimestega	doc_213943985048_item	3571481	et	3	main
mõtlen	doc_213943985048_item	3571498	et	3	main
et	doc_213943985048_item	3571499	et	3	main
on	doc_213943985048_item	3571501	et	4	main
väga	doc_213943985048_item	3571502	et	3	main
hea	doc_213943985048_item	3571503	et	4	main
teised	doc_213943985048_item	3571509	et	4	main
kes	doc_213943985048_item	3571516	et	4	main
õppid	doc_213943985048_item	3571554	et	4	main
ülikoolis	doc_213943985048_item	3571555	et	4	main
sa	doc_213943985048_item	3571556	et	3	main
huvitav	doc_213943985048_item	3571561	et	4	main
kohtud	doc_213943985048_item	3571564	et	4	main
üliõpilased	doc_213943985048_item	3571566	et	3	main
kes	doc_213943985048_item	3571567	et	4	main
elavad	doc_213943985048_item	3571568	et	4	main
hea	doc_213943985048_item	3571575	et	4	main
eriala	doc_213943985048_item	3571576	et	4	main
ja	doc_213943985048_item	3571577	et	3	main
hea	doc_213943985048_item	3571580	et	4	main
inimesed	doc_213943985048_item	3571582	et	3	main
on	doc_213943985048_item	3571584	et	4	main
teadmused	doc_213943985048_item	3571585	et	3	main
aga	doc_213943985048_item	3571586	et	3	main
ülikoolis	doc_213943985048_item	3571611	et	4	main
oled	doc_213943985048_item	3571612	et	3	main
targat	doc_213943985048_item	3571613	et	4	main
haridused	doc_213943985048_item	3571614	et	3	main
võib	doc_213943985048_item	3571615	et	3	main
arvan	doc_213943985048_item	3571618	et	3	main
minu	doc_213943985048_item	3571624	et	3	main
loodan	doc_213943985048_item	3571627	et	3	main
essee	doc_213943985071_item	3571641	et	4	main
siis	doc_213943985071_item	3571648	et	3	main
missugust	doc_213943985071_item	3571651	et	3	main
mina	doc_213943985071_item	3571683	et	4	main
lugemine	doc_213943985071_item	3571686	et	4	main
hea	doc_213943985071_item	3571710	et	4	main
võimalust	doc_213943985071_item	3571711	et	3	main
kõigepealt	doc_213943985075_item	3571761	et	3	main
õnnelik	doc_213943985075_item	3571772	et	3	main
lootusrikas	doc_213943985075_item	3571805	et	4	main
sisseastus	doc_213943985075_item	3571807	et	4	main
judoga	doc_213943985075_item	3571811	et	4	main
teine	doc_213943985075_item	3571813	et	3	main
oli	doc_213943985075_item	3571815	et	3	main
maali	doc_213943985075_item	3571827	et	4	main
ja	doc_213943985075_item	3571842	et	3	main
ma	doc_213943985075_item	3571847	et	3	main
kõigepealt	doc_213943985075_item	3571858	et	3	main
tulevikus	doc_213943985029_item	3571341	et	4	main
ma	doc_213943985029_item	3571342	et	3	main
loodan	doc_213943985029_item	3571343	et	3	main
saada	doc_213943985029_item	3571344	et	4	main
veel	doc_213943985029_item	3571345	et	4	main
üks	doc_213943985029_item	3571346	et	3	main
eriala	doc_213943985029_item	3571347	et	4	main
võib	doc_213943985029_item	3571348	et	3	main
olla	doc_213943985029_item	3571349	et	3	main
see	doc_213943985029_item	3571350	et	3	main
on	doc_213943985029_item	3571351	et	4	main
ajaloo	doc_213943985029_item	3571352	et	4	main
õpetaja	doc_213943985029_item	3571353	et	4	main
pärast	doc_213943985029_item	3571354	et	4	main
lõpetamis	doc_213943985029_item	3571355	et	4	main
filoloogia	doc_213943985029_item	3571356	et	4	main
teaduskonnades	doc_213943985029_item	3571357	et	3	main
ma	doc_213943985029_item	3571358	et	3	main
tahaksin	doc_213943985029_item	3571359	et	3	main
astuda	doc_213943985029_item	3571360	et	3	main
magistratuuris	doc_213943985029_item	3571361	et	4	main
ka	doc_213943985029_item	3571362	et	3	main
eriala	doc_213943985029_item	3571363	et	4	main
ajakirjandus	doc_213943985029_item	3571364	et	3	main
pärast	doc_213943985029_item	3571365	et	4	main
lõpetamis	doc_213943985029_item	3571366	et	4	main
otsida	doc_213943985029_item	3571371	et	4	main
ma	doc_213943985029_item	3571378	et	3	main
ma	doc_213943985029_item	3571382	et	3	main
astad	doc_213943985029_item	3571395	et	4	main
tuntub	doc_213943985029_item	3571398	et	4	main
ülikool	doc_213943985029_item	3571410	et	4	main
aga	doc_213943985029_item	3571414	et	3	main
arvan	doc_213943985029_item	3571416	et	3	main
kõige	doc_213943985029_item	3571418	et	4	main
präegu	doc_213943985029_item	3571421	et	4	main
nii	doc_213943985029_item	3571422	et	3	main
palju	doc_213943985029_item	3571423	et	4	main
kõrgkoolid	doc_213943985029_item	3571426	et	3	main
essee	doc_213943985048_item	3571437	et	4	main
eriala	doc_213943985048_item	3571442	et	4	main
mida	doc_213943985048_item	3571443	et	4	main
õppimisest	doc_213943985048_item	3571445	et	4	main
ülikoolis	doc_213943985048_item	3571446	et	4	main
kõigipealt	doc_213943985048_item	3571447	et	4	main
ma	doc_213943985048_item	3571448	et	3	main
tahan	doc_213943985048_item	3571449	et	3	main
rääkida	doc_213943985048_item	3571450	et	3	main
et	doc_213943985048_item	3571451	et	3	main
valisin	doc_213943985048_item	3571452	et	3	main
vene	doc_213943985048_item	3571458	et	4	main
keelt	doc_213943985048_item	3571475	et	4	main
et	doc_213943985048_item	3571488	et	3	main
ma	doc_213943985048_item	3571492	et	3	main
töötada	doc_213943985048_item	3571494	et	3	main
koolis	doc_213943985048_item	3571496	et	4	main
õppitada	doc_213943985048_item	3571508	et	4	main
koolis	doc_213943985048_item	3571512	et	4	main
arvamus	doc_213943985048_item	3571514	et	3	main
on	doc_213943985048_item	3571557	et	4	main
üliõpilane	doc_213943985048_item	3571558	et	3	main
sul	doc_213943985048_item	3571559	et	3	main
saan	doc_213943985048_item	3571573	et	4	main
ole	doc_213943985048_item	3571588	et	4	main
kõrghariduse	doc_213943985048_item	3571589	et	3	main
tänapäeval	doc_213943985048_item	3571597	et	3	main
ma	doc_213943985048_item	3571617	et	3	main
on	doc_213943985048_item	3571623	et	4	main
saan	doc_213943985048_item	3571629	et	4	main
ja	doc_213943985048_item	3571632	et	3	main
oleb	doc_213943985048_item	3571634	et	4	main
ma	doc_213943985071_item	3571644	et	3	main
niisugust	doc_213943985071_item	3571646	et	3	main
mõtlen	doc_213943985071_item	3571650	et	3	main
minu	doc_213943985071_item	3571653	et	3	main
huvitav	doc_213943985071_item	3571675	et	4	main
ajalehti	doc_213943985071_item	3571678	et	4	main
saan	doc_213943985071_item	3571700	et	4	main
info	doc_213943985071_item	3571701	et	4	main
ajal	doc_213943985071_item	3571707	et	4	main
lugemine	doc_213943985071_item	3571708	et	4	main
annab	doc_213943985071_item	3571709	et	3	main
riigi	doc_213943985029_item	3571432	et	3	main
ülikoolid	doc_213943985029_item	3571433	et	3	main
väga	doc_213943985048_item	3571600	et	3	main
tahtis	doc_213943985048_item	3571601	et	3	main
eestis	doc_213943985048_item	3571602	et	3	main
inimesed	doc_213943985048_item	3571603	et	3	main
kellel	doc_213943985048_item	3571604	et	4	main
ma	doc_213943985048_item	3571439	et	3	main
ootan	doc_213943985048_item	3571444	et	3	main
sest	doc_213943985048_item	3571455	et	4	main
tahaksin	doc_213943985048_item	3571461	et	3	main
ja	doc_213943985048_item	3571472	et	3	main
ma	doc_213943985048_item	3571477	et	3	main
suhelda	doc_213943985048_item	3571479	et	4	main
ma	doc_213943985048_item	3571482	et	3	main
valin	doc_213943985048_item	3571483	et	3	main
niisugune	doc_213943985048_item	3571484	et	3	main
eriala	doc_213943985048_item	3571485	et	4	main
suhelda	doc_213943985048_item	3571490	et	4	main
eesti	doc_213943985048_item	3571495	et	4	main
ja	doc_213943985048_item	3571497	et	3	main
see	doc_213943985048_item	3571500	et	3	main
tahavad	doc_213943985048_item	3571517	et	3	main
et	doc_213943985048_item	3571518	et	3	main
nendel	doc_213943985048_item	3571519	et	4	main
oli	doc_213943985048_item	3571520	et	3	main
hea	doc_213943985048_item	3571521	et	4	main
töökoht	doc_213943985048_item	3571522	et	3	main
ja	doc_213943985048_item	3571523	et	3	main
palk	doc_213943985048_item	3571524	et	3	main
peavad	doc_213943985048_item	3571525	et	4	main
õppima	doc_213943985048_item	3571526	et	3	main
ülikoolis	doc_213943985048_item	3571527	et	4	main
nad	doc_213943985048_item	3571528	et	3	main
saavad	doc_213943985048_item	3571529	et	4	main
kõrgharidust	doc_213943985048_item	3571530	et	4	main
ja	doc_213943985048_item	3571531	et	3	main
pärast	doc_213943985048_item	3571532	et	4	main
võivad	doc_213943985048_item	3571533	et	4	main
leida	doc_213943985048_item	3571534	et	3	main
hea	doc_213943985048_item	3571535	et	4	main
töökohta	doc_213943985048_item	3571536	et	4	main
elu	doc_213943985048_item	3571562	et	4	main
näiteks	doc_213943985048_item	3571571	et	4	main
ma	doc_213943985048_item	3571572	et	3	main
pärast	doc_213943985048_item	3571578	et	4	main
töökoht	doc_213943985048_item	3571581	et	3	main
ei	doc_213943985048_item	3571590	et	4	main
kõrgharidus	doc_213943985048_item	3571598	et	3	main
on	doc_213943985048_item	3571605	et	4	main
kõrgharidus	doc_213943985048_item	3571606	et	3	main
või	doc_213943985048_item	3571607	et	4	main
need	doc_213943985048_item	3571608	et	3	main
mitte	doc_213943985048_item	3571619	et	3	main
aga	doc_213943985048_item	3571621	et	3	main
arusaamine	doc_213943985048_item	3571635	et	4	main
inimesed	doc_213943985048_item	3571510	et	3	main
inimesed	doc_213943985048_item	3571515	et	3	main
inimesed	doc_213943985048_item	3571538	et	3	main
see	doc_213943985048_item	3571537	et	3	main
kes	doc_213943985048_item	3571539	et	4	main
ei	doc_213943985048_item	3571540	et	4	main
õpita	doc_213943985048_item	3571541	et	4	main
ülikoolis	doc_213943985048_item	3571542	et	4	main
töötavad	doc_213943985048_item	3571544	et	4	main
ma	doc_213943985048_item	3571545	et	3	main
mõtlen	doc_213943985048_item	3571546	et	3	main
nad	doc_213943985048_item	3571543	et	3	main
et	doc_213943985048_item	3571547	et	3	main
see	doc_213943985048_item	3571548	et	3	main
on	doc_213943985048_item	3571549	et	4	main
õige	doc_213943985048_item	3571551	et	4	main
kui	doc_213943985048_item	3571552	et	3	main
mitte	doc_213943985048_item	3571550	et	3	main
sa	doc_213943985048_item	3571553	et	3	main
on	doc_213943985048_item	3571560	et	4	main
sa	doc_213943985048_item	3571563	et	3	main
mitmesugused	doc_213943985048_item	3571565	et	3	main
saata	doc_213943985048_item	3571574	et	3	main
leida	doc_213943985048_item	3571579	et	3	main
kellel	doc_213943985048_item	3571583	et	4	main
saa	doc_213943985048_item	3571591	et	4	main
leida	doc_213943985048_item	3571592	et	3	main
olla	doc_213943985048_item	3571616	et	3	main
õige	doc_213943985048_item	3571620	et	4	main
see	doc_213943985048_item	3571622	et	3	main
arvamus	doc_213943985048_item	3571625	et	3	main
ma	doc_213943985048_item	3571626	et	3	main
et	doc_213943985048_item	3571628	et	3	main
hästi	doc_213943985048_item	3571631	et	3	main
üliõpilastega	doc_213943985048_item	3571636	et	4	main
kui	doc_213943985071_item	3571643	et	3	main
pealkirja	doc_213943985071_item	3571647	et	4	main
ma	doc_213943985071_item	3571649	et	3	main
koht	doc_213943985071_item	3571652	et	3	main
loevad	doc_213943985071_item	3571670	et	3	main
see	doc_213943985071_item	3571673	et	3	main
loevad	doc_213943985071_item	3571677	et	3	main
info	doc_213943985071_item	3571680	et	4	main
ka	doc_213943985071_item	3571685	et	3	main
on	doc_213943985071_item	3571687	et	4	main
minu	doc_213943985071_item	3571688	et	3	main
elus	doc_213943985071_item	3571689	et	4	main
väga	doc_213943985071_item	3571690	et	3	main
tähtis	doc_213943985071_item	3571691	et	4	main
kui	doc_213943985071_item	3571702	et	3	main
ma	doc_213943985071_item	3571703	et	3	main
loen	doc_213943985071_item	3571704	et	3	main
ja	doc_213943985071_item	3571705	et	3	main
väsinud	doc_213943985071_item	3571717	et	4	main
või	doc_213943985071_item	3571718	et	4	main
mul	doc_213943985071_item	3571719	et	3	main
ilukirjandusest	doc_213943985071_item	3571741	et	4	main
essee	doc_213943985075_item	3571760	et	4	main
ma	doc_213943985075_item	3571762	et	3	main
kõige	doc_213943985075_item	3571766	et	4	main
lapsepõlves	doc_213943985075_item	3571768	et	4	main
nii	doc_213943985075_item	3571771	et	3	main
kassipoega	doc_213943985075_item	3571775	et	4	main
see	doc_213943985075_item	3571777	et	3	main
oli	doc_213943985075_item	3571778	et	3	main
juba	doc_213943985075_item	3571779	et	3	main
üheksa	doc_213943985075_item	3571780	et	4	main
aastat	doc_213943985075_item	3571781	et	3	main
tagasi	doc_213943985075_item	3571782	et	3	main
aga	doc_213943985075_item	3571783	et	3	main
nii	doc_213943985075_item	3571799	et	3	main
ja	doc_213943985075_item	3571801	et	3	main
ootusärev	doc_213943985075_item	3571803	et	3	main
ja	doc_213943985075_item	3571809	et	3	main
võtsin	doc_213943985075_item	3571826	et	3	main
ja	doc_213943985075_item	3571829	et	3	main
ma	doc_213943985075_item	3571831	et	3	main
aktiivseks	doc_213943985075_item	3571834	et	4	main
ja	doc_213943985075_item	3571835	et	3	main
energiliseks	doc_213943985075_item	3571836	et	3	main
kõva	doc_213943985075_item	3571837	et	4	main
sport	doc_213943985075_item	3571838	et	3	main
nagu	doc_213943985075_item	3571839	et	3	main
kickboxing	doc_213943985075_item	3571840	et	4	main
valisin	doc_213943985075_item	3571848	et	3	main
ma	doc_213943985075_item	3571859	et	3	main
ei	doc_213943985075_item	3571862	et	4	main
kunstiakadeemiasse	doc_213943985075_item	3571864	et	3	main
sisseastuda	doc_213943985075_item	3571865	et	4	main
treeningus	doc_213943985075_item	3571906	et	3	main
suusakuurorti	doc_333816885025_item	3571924	et	4	main
thorens	doc_333816885025_item	3571929	et	4	main
3	doc_333816885025_item	3571932	et	2	main
tipus	doc_333816885025_item	3571934	et	3	main
kõrgemal	doc_333816885025_item	3571938	et	4	main
euroopa	doc_333816885025_item	3571940	et	4	main
suusakuurort	doc_333816885025_item	3571941	et	3	main
muud	doc_333816885025_item	3571948	et	4	main
kui	doc_333816885025_item	3571949	et	3	main
maailma	doc_333816885025_item	3571950	et	4	main
suurim	doc_333816885025_item	3571951	et	3	main
on	doc_213943985071_item	3571720	et	4	main
paha	doc_213943985071_item	3571721	et	4	main
tuju	doc_213943985071_item	3571722	et	4	main
siis	doc_213943985071_item	3571723	et	3	main
lugemine	doc_213943985071_item	3571724	et	4	main
on	doc_213943985071_item	3571725	et	4	main
parim	doc_213943985071_item	3571726	et	4	main
vahend	doc_213943985071_item	3571727	et	3	main
minu	doc_213943985071_item	3571728	et	3	main
jaoks	doc_213943985071_item	3571729	et	4	main
lugemine	doc_213943985071_item	3571730	et	4	main
teeb	doc_213943985071_item	3571731	et	3	main
minu	doc_213943985071_item	3571732	et	3	main
elu	doc_213943985071_item	3571733	et	4	main
rikaks	doc_213943985071_item	3571734	et	4	main
aitab	doc_213943985071_item	3571735	et	3	main
mind	doc_213943985071_item	3571736	et	4	main
annab	doc_213943985071_item	3571737	et	3	main
võimalust	doc_213943985071_item	3571738	et	3	main
palju	doc_213943985071_item	3571739	et	4	main
teada	doc_213943985071_item	3571740	et	3	main
lugemiselamus	doc_213943985071_item	3571642	et	4	main
elus	doc_213943985071_item	3571654	et	4	main
võtab	doc_213943985071_item	3571655	et	3	main
lugemine	doc_213943985071_item	3571656	et	4	main
praegu	doc_213943985071_item	3571657	et	3	main
ei	doc_213943985071_item	3571658	et	4	main
oleks	doc_213943985071_item	3571659	et	3	main
normaalne	doc_213943985071_item	3571660	et	3	main
kui	doc_213943985071_item	3571661	et	3	main
täiskasvanu	doc_213943985071_item	3571662	et	4	main
inimene	doc_213943985071_item	3571663	et	3	main
ei	doc_213943985071_item	3571664	et	4	main
oska	doc_213943985071_item	3571665	et	4	main
lugeda	doc_213943985071_item	3571666	et	3	main
inimesed	doc_213943985071_item	3571667	et	3	main
kogu	doc_213943985071_item	3571668	et	4	main
et	doc_213943985071_item	3571672	et	3	main
maailmas	doc_213943985071_item	3571669	et	3	main
iluskirjandus	doc_213943985071_item	3571671	et	4	main
et	doc_213943985071_item	3571679	et	3	main
saada	doc_213943985071_item	3571681	et	4	main
ja	doc_213943985071_item	3571682	et	3	main
mina	doc_213943985071_item	3571692	et	4	main
vaatan	doc_213943985071_item	3571693	et	3	main
telerit	doc_213943985071_item	3571694	et	3	main
ja	doc_213943985071_item	3571695	et	3	main
kuulan	doc_213943985071_item	3571696	et	3	main
raadiot	doc_213943985071_item	3571697	et	3	main
aga	doc_213943985071_item	3571698	et	3	main
samal	doc_213943985071_item	3571706	et	3	main
puhata	doc_213943985071_item	3571712	et	4	main
kui	doc_213943985071_item	3571713	et	3	main
ma	doc_213943985071_item	3571714	et	3	main
olen	doc_213943985071_item	3571715	et	3	main
väga	doc_213943985071_item	3571716	et	3	main
saan	doc_213943985071_item	3571743	et	4	main
ilusad	doc_213943985071_item	3571744	et	3	main
tunned	doc_213943985071_item	3571745	et	3	main
ja	doc_213943985071_item	3571746	et	3	main
mõtted	doc_213943985071_item	3571747	et	3	main
teada	doc_213943985071_item	3571748	et	3	main
raamatud	doc_213943985071_item	3571749	et	4	main
on	doc_213943985071_item	3571750	et	4	main
head	doc_213943985071_item	3571751	et	4	main
sõbrad	doc_213943985071_item	3571752	et	3	main
minu	doc_213943985071_item	3571753	et	3	main
elus	doc_213943985071_item	3571754	et	4	main
ja	doc_213943985071_item	3571755	et	3	main
see	doc_213943985071_item	3571756	et	3	main
huvitab	doc_213943985071_item	3571757	et	3	main
mind	doc_213943985071_item	3571758	et	4	main
sündmust	doc_213943985075_item	3571765	et	3	main
olulisemaid	doc_213943985075_item	3571767	et	4	main
ma	doc_213943985075_item	3571769	et	3	main
olin	doc_213943985075_item	3571770	et	3	main
ema	doc_213943985075_item	3571774	et	4	main
ostis	doc_213943985075_item	3571776	et	4	main
õnnelik	doc_213943985075_item	3571800	et	3	main
ja	doc_213943985075_item	3571804	et	3	main
kui	doc_213943985075_item	3571806	et	3	main
lapsepõlvest	doc_213943985075_item	3571824	et	4	main
millal	doc_213943985075_item	3571825	et	3	main
väga	doc_213943985075_item	3571833	et	3	main
tugevat	doc_213943985075_item	3571854	et	4	main
räägites	doc_213943985075_item	3571855	et	4	main
negatiivset	doc_213943985075_item	3571856	et	3	main
sündmust	doc_213943985075_item	3571857	et	3	main
olin	doc_213943985075_item	3571867	et	3	main
aga	doc_213943985075_item	3571907	et	3	main
kogemusse	doc_213943985075_item	3571912	et	3	main
val	doc_333816885025_item	3571928	et	4	main
seega	doc_333816885025_item	3571936	et	4	main
ei	doc_333816885025_item	3571944	et	4	main
tõstukitega	doc_333816885025_item	3571952	et	3	main
lumi	doc_333816885025_item	3571955	et	3	main
val	doc_333816885025_item	3571957	et	4	main
thorensis	doc_333816885025_item	3571958	et	4	main
selle	doc_333816885025_item	3571964	et	4	main
lõbusaima	doc_333816885025_item	3571969	et	4	main
ja	doc_333816885025_item	3571970	et	3	main
kogu	doc_333816885025_item	3571974	et	4	main
ning	doc_333816885025_item	3571976	et	3	main
seal	doc_333816885025_item	3571977	et	4	main
nad	doc_213943985071_item	3571676	et	3	main
muidugi	doc_213943985071_item	3571684	et	4	main
rohkem	doc_213943985071_item	3571699	et	4	main
mina	doc_213943985071_item	3571742	et	4	main
posittivset	doc_213943985075_item	3571764	et	4	main
kui	doc_213943985075_item	3571773	et	3	main
oli	doc_213943985075_item	3571802	et	3	main
hakkasin	doc_213943985075_item	3571810	et	3	main
aasta	doc_213943985075_item	3571817	et	4	main
hiljem	doc_213943985075_item	3571818	et	3	main
kunstikoolis	doc_213943985075_item	3571819	et	4	main
ma	doc_213943985075_item	3571820	et	3	main
tahtsin	doc_213943985075_item	3571821	et	3	main
õppida	doc_213943985075_item	3571822	et	3	main
juba	doc_213943985075_item	3571823	et	3	main
eritunni	doc_213943985075_item	3571828	et	3	main
muidugi	doc_213943985075_item	3571830	et	4	main
muutsin	doc_213943985075_item	3571832	et	3	main
taekwondo	doc_213943985075_item	3571841	et	4	main
judo	doc_213943985075_item	3571843	et	4	main
oli	doc_213943985075_item	3571844	et	3	main
ma	doc_213943985075_item	3571866	et	3	main
sellesse	doc_213943985075_item	3571909	et	4	main
kui	doc_213943985075_item	3571910	et	3	main
kasulikku	doc_213943985075_item	3571911	et	4	main
selel	doc_333816885025_item	3571919	et	4	main
vaheajal	doc_333816885025_item	3571920	et	3	main
ma	doc_333816885025_item	3571921	et	3	main
olin	doc_333816885025_item	3571922	et	3	main
suusakuurortis	doc_333816885025_item	3571923	et	4	main
nimi	doc_333816885025_item	3571925	et	3	main
olles	doc_333816885025_item	3571935	et	3	main
on	doc_333816885025_item	3571959	et	4	main
novembrist	doc_333816885025_item	3571960	et	3	main
on	doc_333816885025_item	3571965	et	4	main
metsikuima	doc_333816885025_item	3571971	et	4	main
ei	doc_333816885025_item	3571978	et	4	main
ja	doc_333816885025_item	3571996	et	3	main
after	doc_333816885025_item	3571997	et	4	main
el	doc_333816885025_item	3572003	et	4	main
baaride	doc_333816885025_item	3572008	et	3	main
maailma	doc_333816885025_item	3572056	et	4	main
ajal	doc_392411160215_item	3572061	et	4	main
pööratatud	doc_392411160215_item	3572065	et	4	main
elukeskkonnale	doc_392411160215_item	3572067	et	3	main
ning	doc_392411160215_item	3572068	et	3	main
selle	doc_392411160215_item	3572069	et	4	main
mõjust	doc_392411160215_item	3572070	et	3	main
postimees	doc_392411160215_item	3572081	et	4	main
välja	doc_392411160215_item	3572085	et	4	main
lühendab	doc_392411160215_item	3572087	et	3	main
3	doc_392411160215_item	3572091	et	2	main
esitatud	doc_392411160215_item	3572095	et	4	main
näha	doc_392411160215_item	3572098	et	3	main
on	doc_392411160215_item	3572100	et	4	main
rohkem	doc_392411160215_item	3572112	et	4	main
moodustab	doc_392411160215_item	3572114	et	3	main
küsitlustest	doc_392411160215_item	3572116	et	4	main
vastati	doc_392411160215_item	3572117	et	4	main
et	doc_392411160215_item	3572118	et	3	main
ebatervislik	doc_392411160215_item	3572119	et	3	main
eluviis	doc_392411160215_item	3572120	et	3	main
on	doc_392411160215_item	3572121	et	4	main
üks	doc_392411160215_item	3572122	et	3	main
peamisest	doc_392411160215_item	3572123	et	3	main
arsti	doc_392411160215_item	3572158	et	4	main
vastajatest	doc_392411160215_item	3572168	et	4	main
moodustab	doc_392411160215_item	3572170	et	3	main
et	doc_392411160215_item	3572174	et	3	main
mitmel	doc_392411160215_item	3572187	et	4	main
töökohtadel	doc_392411160215_item	3572188	et	3	main
nõuab	doc_392411160215_item	3572191	et	3	main
tarvitades	doc_392411160215_item	3572201	et	3	main
töötu	doc_392411160215_item	3572205	et	4	main
ei	doc_392411160215_item	3572207	et	4	main
tea	doc_392411160215_item	3572208	et	4	main
kuhu	doc_392411160215_item	3572209	et	3	main
kiir	doc_392411160215_item	3572249	et	4	main
autosõit	doc_392411160215_item	3572250	et	3	main
taga	doc_392411160215_item	3572253	et	4	main
mäng	doc_392411160215_item	3572255	et	3	main
eestis	doc_392411160219_item	3572315	et	3	main
jutustan	doc_213943985075_item	3571763	et	3	main
ma	doc_213943985075_item	3571784	et	3	main
mäletan	doc_213943985075_item	3571785	et	3	main
oma	doc_213943985075_item	3571786	et	4	main
rõõmutunne	doc_213943985075_item	3571787	et	3	main
praegugi	doc_213943985075_item	3571788	et	3	main
mina	doc_213943985075_item	3571789	et	4	main
olin	doc_213943985075_item	3571790	et	3	main
koos	doc_213943985075_item	3571791	et	4	main
kassiga	doc_213943985075_item	3571792	et	4	main
kõike	doc_213943985075_item	3571793	et	4	main
koodus	doc_213943985075_item	3571794	et	4	main
teinud	doc_213943985075_item	3571795	et	4	main
veel	doc_213943985075_item	3571796	et	4	main
ma	doc_213943985075_item	3571797	et	3	main
olin	doc_213943985075_item	3571798	et	3	main
kunstikooli	doc_213943985075_item	3571808	et	4	main
tegelema	doc_213943985075_item	3571812	et	3	main
sündmus	doc_213943985075_item	3571814	et	3	main
kolme	doc_213943985075_item	3571816	et	4	main
minu	doc_213943985075_item	3571845	et	3	main
unistus	doc_213943985075_item	3571846	et	4	main
judo	doc_213943985075_item	3571849	et	4	main
ja	doc_213943985075_item	3571850	et	3	main
tundsin	doc_213943985075_item	3571851	et	3	main
end	doc_213943985075_item	3571852	et	4	main
nii	doc_213943985075_item	3571853	et	3	main
kahtlen	doc_213943985075_item	3571860	et	3	main
saanud	doc_213943985075_item	3571863	et	4	main
et	doc_213943985075_item	3571861	et	3	main
väga	doc_213943985075_item	3571868	et	3	main
kuri	doc_213943985075_item	3571869	et	4	main
ja	doc_213943985075_item	3571870	et	3	main
tegi	doc_213943985075_item	3571871	et	4	main
suure	doc_213943985075_item	3571872	et	3	main
skandaali	doc_213943985075_item	3571873	et	4	main
dekanaadis	doc_213943985075_item	3571874	et	4	main
aga	doc_213943985075_item	3571875	et	3	main
ma	doc_213943985075_item	3571876	et	3	main
ei	doc_213943985075_item	3571877	et	4	main
andis	doc_213943985075_item	3571878	et	3	main
alla	doc_213943985075_item	3571879	et	3	main
ja	doc_213943985075_item	3571880	et	3	main
järgmisel	doc_213943985075_item	3571881	et	3	main
aastal	doc_213943985075_item	3571882	et	3	main
proovin	doc_213943985075_item	3571883	et	3	main
veel	doc_213943985075_item	3571884	et	4	main
sisseastuda	doc_213943985075_item	3571885	et	4	main
muidugi	doc_213943985075_item	3571886	et	4	main
ma	doc_213943985075_item	3571887	et	3	main
analüüsin	doc_213943985075_item	3571888	et	3	main
ebaõnnestumise	doc_213943985075_item	3571889	et	3	main
põhjusi	doc_213943985075_item	3571890	et	3	main
mitte	doc_213943985075_item	3571891	et	3	main
ainult	doc_213943985075_item	3571892	et	4	main
tülitsin	doc_213943985075_item	3571893	et	4	main
aga	doc_213943985075_item	3571894	et	3	main
hakkasin	doc_213943985075_item	3571895	et	3	main
välja	doc_213943985075_item	3571896	et	4	main
pääsu	doc_213943985075_item	3571897	et	4	main
otsima	doc_213943985075_item	3571898	et	4	main
veel	doc_213943985075_item	3571899	et	4	main
sellel	doc_213943985075_item	3571900	et	4	main
aastal	doc_213943985075_item	3571901	et	3	main
ma	doc_213943985075_item	3571902	et	3	main
murdsin	doc_213943985075_item	3571903	et	3	main
rangluu	doc_213943985075_item	3571904	et	4	main
judo	doc_213943985075_item	3571905	et	4	main
suhtlus	doc_213943985075_item	3571908	et	3	main
essee	doc_333816885025_item	3571914	et	4	main
thorens	doc_333816885025_item	3571927	et	4	main
kõrgusel	doc_333816885025_item	3571931	et	4	main
3	doc_333816885025_item	3571942	et	2	main
orgu	doc_333816885025_item	3571943	et	4	main
suusapiirkond	doc_333816885025_item	3571954	et	3	main
thorens	doc_333816885025_item	3571967	et	4	main
koht	doc_333816885025_item	3571973	et	3	main
saloon	doc_333816885025_item	3572001	et	4	main
lumelaua	doc_333816885025_item	3572052	et	3	main
fännid	doc_333816885025_item	3572053	et	3	main
üle	doc_333816885025_item	3572054	et	3	main
terve	doc_333816885025_item	3572055	et	4	main
viimasel	doc_392411160215_item	3572060	et	3	main
tahaksin	doc_392411160215_item	3572073	et	3	main
küsitlust	doc_392411160215_item	3572075	et	4	main
et	doc_392411160215_item	3572083	et	3	main
selgitada	doc_392411160215_item	3572084	et	3	main
meeste	doc_392411160215_item	3572089	et	4	main
eluiga	doc_392411160215_item	3572090	et	4	main
võib	doc_392411160215_item	3572097	et	3	main
vähem	doc_392411160215_item	3572128	et	4	main
kui	doc_392411160215_item	3572129	et	3	main
mida	doc_333816885025_item	3571915	et	4	main
käinud	doc_333816885025_item	3571916	et	4	main
ja	doc_333816885025_item	3571917	et	3	main
näinud	doc_333816885025_item	3571918	et	4	main
val	doc_333816885025_item	3571926	et	4	main
asub	doc_333816885025_item	3571930	et	3	main
oru	doc_333816885025_item	3571933	et	3	main
kõige	doc_333816885025_item	3571937	et	4	main
paiknev	doc_333816885025_item	3571939	et	4	main
ole	doc_333816885025_item	3571945	et	4	main
aga	doc_333816885025_item	3571946	et	3	main
midagi	doc_333816885025_item	3571947	et	4	main
ühendatud	doc_333816885025_item	3571953	et	4	main
on	doc_333816885025_item	3571956	et	4	main
val	doc_333816885025_item	3571966	et	4	main
ööeluga	doc_333816885025_item	3571972	et	3	main
alpides	doc_333816885025_item	3571975	et	4	main
ajata	doc_333816885025_item	3571982	et	4	main
ei	doc_333816885025_item	3571983	et	4	main
ole	doc_333816885025_item	3571984	et	4	main
val	doc_333816885025_item	3571985	et	4	main
thorensi	doc_333816885025_item	3571986	et	4	main
teine	doc_333816885025_item	3571987	et	3	main
nimi	doc_333816885025_item	3571988	et	3	main
ski	doc_333816885025_item	3571989	et	4	main
biza	doc_333816885025_item	3571990	et	4	main
linnas	doc_333816885025_item	3571991	et	4	main
on	doc_333816885025_item	3571992	et	4	main
hulgi	doc_333816885025_item	3571993	et	4	main
häid	doc_333816885025_item	3571994	et	3	main
baare	doc_333816885025_item	3571995	et	3	main
bar	doc_333816885025_item	3572002	et	4	main
peale	doc_333816885025_item	3572007	et	4	main
elava	doc_333816885025_item	3572010	et	4	main
muusikaga	doc_333816885025_item	3572011	et	3	main
ööklubid	doc_333816885025_item	3572012	et	3	main
malaysia	doc_333816885025_item	3572013	et	4	main
kuna	doc_392411160215_item	3572059	et	3	main
palju	doc_392411160215_item	3572064	et	4	main
tähelepanu	doc_392411160215_item	3572066	et	4	main
poolt	doc_392411160215_item	3572082	et	4	main
eesti	doc_392411160215_item	3572088	et	4	main
295	doc_392411160215_item	3572092	et	2	main
vastajatest	doc_392411160215_item	3572093	et	4	main
kõige	doc_392411160215_item	3572111	et	4	main
miks	doc_392411160215_item	3572125	et	4	main
mehed	doc_392411160215_item	3572126	et	3	main
elavad	doc_392411160215_item	3572127	et	4	main
arv	doc_392411160215_item	3572167	et	3	main
27	doc_392411160215_item	3572171	et	2	main
arvab	doc_392411160215_item	3572173	et	3	main
ületöötamine	doc_392411160215_item	3572178	et	3	main
meeste	doc_392411160215_item	3572180	et	4	main
elukestvust	doc_392411160215_item	3572181	et	4	main
see	doc_392411160215_item	3572182	et	3	main
võib	doc_392411160215_item	3572183	et	3	main
olla	doc_392411160215_item	3572184	et	3	main
kahjuks	doc_392411160215_item	3572196	et	4	main
alkoholi	doc_392411160215_item	3572202	et	4	main
on	doc_392411160215_item	3572248	et	4	main
maini	doc_333816885025_item	3571961	et	4	main
peale	doc_333816885025_item	3571962	et	4	main
kõige	doc_333816885025_item	3571963	et	4	main
üks	doc_333816885025_item	3571968	et	3	main
ole	doc_333816885025_item	3571979	et	4	main
kunagi	doc_333816885025_item	3571980	et	3	main
igav	doc_333816885025_item	3571981	et	3	main
gringo	doc_333816885025_item	3572004	et	4	main
ja	doc_333816885025_item	3572005	et	3	main
sulgemist	doc_333816885025_item	3572009	et	4	main
ja	doc_333816885025_item	3572014	et	3	main
underground	doc_333816885025_item	3572015	et	4	main
val	doc_333816885025_item	3572016	et	4	main
thorensis	doc_333816885025_item	3572017	et	4	main
on	doc_333816885025_item	3572018	et	4	main
ka	doc_333816885025_item	3572019	et	3	main
spordikeskus	doc_333816885025_item	3572020	et	3	main
suuruses	doc_333816885025_item	3572021	et	4	main
spordihallis	doc_333816885025_item	3572022	et	4	main
mul	doc_333816885025_item	3572023	et	3	main
oli	doc_333816885025_item	3572024	et	3	main
võimalus	doc_333816885025_item	3572025	et	3	main
mängida	doc_333816885025_item	3572026	et	3	main
tennist	doc_333816885025_item	3572027	et	3	main
lauatennist	doc_333816885025_item	3572028	et	3	main
sulgpalli	doc_333816885025_item	3572029	et	4	main
jalgpalli	doc_333816885025_item	3572030	et	4	main
võrkpalli	doc_333816885025_item	3572031	et	4	main
jne	doc_333816885025_item	3572032	et	4	main
tervisekeskuses	doc_333816885025_item	3572033	et	4	main
on	doc_333816885025_item	3572034	et	4	main
ujula	doc_333816885025_item	3572035	et	4	main
mullibasseinid	doc_333816885025_item	3572036	et	4	main
soome	doc_333816885025_item	3572037	et	3	main
ja	doc_333816885025_item	3572038	et	3	main
türgi	doc_333816885025_item	3572039	et	4	main
saun	doc_333816885025_item	3572040	et	3	main
solaarium	doc_333816885025_item	3572041	et	3	main
ski	doc_333816885025_item	3571998	et	4	main
kohti	doc_333816885025_item	3571999	et	4	main
nagu	doc_333816885025_item	3572000	et	3	main
tango	doc_333816885025_item	3572006	et	4	main
val	doc_333816885025_item	3572042	et	4	main
essee	doc_392411160215_item	3572058	et	4	main
küllaltki	doc_392411160215_item	3572063	et	4	main
tutvustada	doc_392411160215_item	3572074	et	3	main
mis	doc_392411160215_item	3572076	et	4	main
oli	doc_392411160215_item	3572077	et	3	main
läbi	doc_392411160215_item	3572078	et	4	main
viidud	doc_392411160215_item	3572079	et	4	main
mis	doc_392411160215_item	3572086	et	4	main
põhjusest	doc_392411160215_item	3572124	et	4	main
juurde	doc_392411160215_item	3572159	et	4	main
ja	doc_392411160215_item	3572160	et	3	main
ilmub	doc_392411160215_item	3572162	et	3	main
stress	doc_392411160215_item	3572163	et	3	main
seejärel	doc_392411160215_item	3572164	et	3	main
näeme	doc_392411160215_item	3572165	et	3	main
tubakas	doc_392411160215_item	3572176	et	4	main
mõjub	doc_392411160215_item	3572179	et	3	main
kuna	doc_392411160215_item	3572189	et	3	main
erinevaid	doc_392411160215_item	3572192	et	4	main
vajalike	doc_392411160215_item	3572193	et	3	main
asju	doc_392411160215_item	3572194	et	3	main
praegu	doc_392411160215_item	3572195	et	3	main
makstatakse	doc_392411160215_item	3572197	et	4	main
tööl	doc_392411160215_item	3572198	et	3	main
peamiselt	doc_392411160215_item	3572199	et	4	main
inimene	doc_392411160215_item	3572204	et	3	main
mees	doc_392411160215_item	3572206	et	4	main
jõudu	doc_392411160215_item	3572212	et	4	main
minu	doc_392411160215_item	3572246	et	3	main
meelest	doc_392411160215_item	3572247	et	4	main
rooli	doc_392411160215_item	3572252	et	4	main
azaartne	doc_392411160215_item	3572254	et	4	main
kasinos	doc_392411160215_item	3572256	et	4	main
ja	doc_392411160215_item	3572257	et	3	main
mõjuvad	doc_392411160215_item	3572299	et	4	main
inimeste	doc_392411160215_item	3572300	et	3	main
essee	doc_392411160219_item	3572311	et	4	main
õigused	doc_392411160219_item	3572313	et	4	main
see	doc_392411160219_item	3572317	et	3	main
mind	doc_392411160219_item	3572319	et	4	main
arvan	doc_392411160219_item	3572356	et	3	main
see	doc_392411160219_item	3572359	et	3	main
raske	doc_392411160219_item	3572363	et	4	main
te	doc_392411160219_item	3572369	et	4	main
arvate	doc_392411160219_item	3572370	et	3	main
kas	doc_392411160219_item	3572371	et	3	main
võim	doc_392411160219_item	3572372	et	3	main
ligitiimne	doc_392411160219_item	3572375	et	4	main
on	doc_392411160219_item	3572378	et	4	main
nii	doc_392411160219_item	3572379	et	3	main
tihti	doc_392411160219_item	3572386	et	3	main
aga	doc_392411160219_item	3572387	et	3	main
kaks	doc_392411160219_item	3572391	et	3	main
tugev	doc_392411160219_item	3572394	et	4	main
siis	doc_392411160219_item	3572396	et	3	main
olla	doc_392411160219_item	3572399	et	3	main
naiteks	doc_392411160219_item	3572401	et	4	main
essee	doc_392411160220_item	3572405	et	4	main
minu	doc_392411160220_item	3572407	et	3	main
on	doc_392411160220_item	3572409	et	4	main
koos	doc_392411160220_item	3572415	et	4	main
teeb	doc_392411160220_item	3572418	et	3	main
murelikum	doc_392411160220_item	3572446	et	4	main
erinevatele	doc_392411160220_item	3572453	et	4	main
rahvusvähemusega	doc_392411160220_item	3572462	et	4	main
vähem	doc_392411160220_item	3572470	et	4	main
pinnas	doc_392411160220_item	3572499	et	4	main
ei	doc_392411160220_item	3572523	et	4	main
kes	doc_392411160220_item	3572525	et	4	main
on	doc_392411160220_item	3572526	et	4	main
meil	doc_392411160223_item	3572539	et	4	main
sest	doc_392411160223_item	3572557	et	4	main
see	doc_392411160223_item	3572558	et	3	main
sest	doc_392411160223_item	3572574	et	4	main
tema	doc_392411160223_item	3572581	et	4	main
thorens	doc_333816885025_item	3572043	et	4	main
on	doc_333816885025_item	3572044	et	4	main
koht	doc_333816885025_item	3572045	et	3	main
euroopa	doc_333816885025_item	3572046	et	4	main
tipus	doc_333816885025_item	3572047	et	3	main
kus	doc_333816885025_item	3572048	et	3	main
kogunevad	doc_333816885025_item	3572049	et	4	main
suusa-	doc_333816885025_item	3572050	et	3	main
ja	doc_333816885025_item	3572051	et	3	main
tervist	doc_392411160215_item	3572301	et	4	main
ja	doc_392411160215_item	3572302	et	3	main
me	doc_392411160215_item	3572303	et	4	main
ei	doc_392411160215_item	3572304	et	4	main
saa	doc_392411160215_item	3572305	et	4	main
leida	doc_392411160215_item	3572306	et	3	main
eluga	doc_392411160215_item	3572307	et	3	main
ühest	doc_392411160215_item	3572308	et	4	main
keelt	doc_392411160215_item	3572309	et	4	main
on	doc_392411160215_item	3572062	et	4	main
inimese	doc_392411160215_item	3572071	et	4	main
elueale	doc_392411160215_item	3572072	et	3	main
ajalehe	doc_392411160215_item	3572080	et	3	main
allpool	doc_392411160215_item	3572094	et	3	main
skeemilt	doc_392411160215_item	3572096	et	3	main
kuidas	doc_392411160215_item	3572099	et	3	main
jagunenud	doc_392411160215_item	3572101	et	4	main
erinevate	doc_392411160215_item	3572102	et	4	main
elanike	doc_392411160215_item	3572103	et	3	main
gruppide	doc_392411160215_item	3572104	et	3	main
arvamus	doc_392411160215_item	3572105	et	3	main
vaadates	doc_392411160215_item	3572106	et	3	main
esitatud	doc_392411160215_item	3572107	et	4	main
andmeid	doc_392411160215_item	3572108	et	3	main
selgub	doc_392411160215_item	3572109	et	3	main
et	doc_392411160215_item	3572110	et	3	main
mis	doc_392411160215_item	3572113	et	4	main
29	doc_392411160215_item	3572115	et	2	main
naised	doc_392411160215_item	3572130	et	3	main
siinjuures	doc_392411160215_item	3572131	et	3	main
tuleb	doc_392411160215_item	3572132	et	3	main
arvestada	doc_392411160215_item	3572133	et	3	main
et	doc_392411160215_item	3572134	et	3	main
mehed	doc_392411160215_item	3572135	et	3	main
vähe	doc_392411160215_item	3572136	et	3	main
liigutavad	doc_392411160215_item	3572137	et	4	main
neil	doc_392411160215_item	3572138	et	4	main
on	doc_392411160215_item	3572139	et	4	main
istuv	doc_392411160215_item	3572140	et	4	main
eluviis	doc_392411160215_item	3572141	et	3	main
ja	doc_392411160215_item	3572142	et	3	main
tervist	doc_392411160215_item	3572143	et	4	main
töötingimused	doc_392411160215_item	3572145	et	3	main
kahjustavad	doc_392411160215_item	3572144	et	4	main
lisaks	doc_392411160215_item	3572146	et	4	main
võib	doc_392411160215_item	3572147	et	3	main
mõelda	doc_392411160215_item	3572148	et	4	main
ja	doc_392411160215_item	3572150	et	3	main
vale-	doc_392411160215_item	3572149	et	4	main
mitteregulaarsest	doc_392411160215_item	3572151	et	3	main
toitumisest	doc_392411160215_item	3572152	et	4	main
nad	doc_392411160215_item	3572153	et	3	main
ei	doc_392411160215_item	3572154	et	4	main
taha	doc_392411160215_item	3572155	et	4	main
eriti	doc_392411160215_item	3572156	et	3	main
minna	doc_392411160215_item	3572157	et	3	main
mis	doc_392411160215_item	3572169	et	4	main
seotud	doc_392411160215_item	3572185	et	4	main
tööga	doc_392411160215_item	3572186	et	3	main
jääb	doc_392411160215_item	3572203	et	3	main
panna	doc_392411160215_item	3572210	et	4	main
oma	doc_392411160215_item	3572211	et	4	main
lõpuks	doc_392411160215_item	3572161	et	4	main
võrdne	doc_392411160215_item	3572166	et	3	main
kes	doc_392411160215_item	3572172	et	4	main
alkohol	doc_392411160215_item	3572175	et	3	main
ja	doc_392411160215_item	3572177	et	3	main
peret	doc_392411160215_item	3572190	et	3	main
minimaalpalka	doc_392411160215_item	3572200	et	4	main
valutab	doc_392411160215_item	3572214	et	3	main
süda	doc_392411160215_item	3572215	et	3	main
nagu	doc_392411160215_item	3572216	et	3	main
reeglena	doc_392411160215_item	3572217	et	4	main
tunnevad	doc_392411160215_item	3572218	et	3	main
mehed	doc_392411160215_item	3572219	et	3	main
end	doc_392411160215_item	3572220	et	4	main
ebakindlalt	doc_392411160215_item	3572221	et	4	main
ja	doc_392411160215_item	3572222	et	3	main
välja	doc_392411160215_item	3572223	et	4	main
pääsu	doc_392411160215_item	3572224	et	4	main
leiavad	doc_392411160215_item	3572225	et	3	main
sõprade	doc_392411160215_item	3572226	et	3	main
seltskonnas	doc_392411160215_item	3572227	et	3	main
kus	doc_392411160215_item	3572228	et	3	main
jöövad	doc_392411160215_item	3572229	et	4	main
ja	doc_392411160215_item	3572230	et	3	main
suitsetavad	doc_392411160215_item	3572231	et	4	main
tohutult	doc_392411160215_item	3572232	et	4	main
palju	doc_392411160215_item	3572233	et	4	main
kõige	doc_392411160215_item	3572234	et	4	main
väiksem	doc_392411160215_item	3572235	et	4	main
vastajatest	doc_392411160215_item	3572236	et	4	main
ütles	doc_392411160215_item	3572237	et	3	main
et	doc_392411160215_item	3572238	et	3	main
liigne	doc_392411160215_item	3572239	et	3	main
riskimine	doc_392411160215_item	3572240	et	4	main
lühendab	doc_392411160215_item	3572241	et	3	main
meeste	doc_392411160215_item	3572242	et	4	main
eluiga	doc_392411160215_item	3572243	et	4	main
seetõttu	doc_392411160215_item	3572213	et	3	main
selle	doc_392411160215_item	3572244	et	4	main
põhjuseks	doc_392411160215_item	3572245	et	3	main
kaotamine	doc_392411160215_item	3572258	et	4	main
oma	doc_392411160215_item	3572259	et	4	main
vara	doc_392411160215_item	3572260	et	4	main
fie	doc_392411160215_item	3572261	et	4	main
rajades	doc_392411160215_item	3572262	et	4	main
jne	doc_392411160215_item	3572263	et	4	main
moment	doc_392411160215_item	3572265	et	3	main
üllatus	doc_392411160215_item	3572264	et	4	main
minu	doc_392411160215_item	3572266	et	3	main
jaoks	doc_392411160215_item	3572267	et	4	main
et	doc_392411160215_item	3572268	et	3	main
ürimuses	doc_392411160215_item	3572269	et	4	main
on	doc_392411160215_item	3572270	et	4	main
eraldatud	doc_392411160215_item	3572271	et	4	main
alkoholi	doc_392411160215_item	3572272	et	4	main
ja	doc_392411160215_item	3572273	et	3	main
tubaka	doc_392411160215_item	3572274	et	3	main
tarvitamine	doc_392411160215_item	3572275	et	4	main
ning	doc_392411160215_item	3572276	et	3	main
ebatervislik	doc_392411160215_item	3572277	et	3	main
eluviis	doc_392411160215_item	3572278	et	3	main
minu	doc_392411160215_item	3572279	et	3	main
arvamus	doc_392411160215_item	3572280	et	3	main
need	doc_392411160215_item	3572281	et	3	main
kaht	doc_392411160215_item	3572282	et	3	main
mõistmist	doc_392411160215_item	3572283	et	4	main
on	doc_392411160215_item	3572284	et	4	main
samasugused	doc_392411160215_item	3572285	et	3	main
kahjuks	doc_392411160215_item	3572286	et	4	main
see	doc_392411160215_item	3572287	et	3	main
on	doc_392411160215_item	3572288	et	4	main
käesoleva	doc_392411160215_item	3572289	et	3	main
reaalne	doc_392411160215_item	3572291	et	3	main
pilt	doc_392411160215_item	3572292	et	3	main
aja	doc_392411160215_item	3572290	et	4	main
ja	doc_392411160215_item	3572293	et	3	main
teedel	doc_392411160215_item	3572251	et	3	main
kõik	doc_392411160215_item	3572294	et	4	main
need	doc_392411160215_item	3572295	et	3	main
üleval	doc_392411160215_item	3572296	et	4	main
missugused	doc_392411160219_item	3572312	et	3	main
et	doc_392411160219_item	3572358	et	3	main
on	doc_392411160219_item	3572361	et	4	main
on	doc_392411160219_item	3572374	et	4	main
valitsus	doc_392411160219_item	3572383	et	4	main
väga	doc_392411160219_item	3572385	et	3	main
oli	doc_392411160219_item	3572389	et	3	main
meil	doc_392411160219_item	3572390	et	4	main
see	doc_392411160219_item	3572397	et	3	main
on	doc_392411160220_item	3572406	et	4	main
arvates	doc_392411160220_item	3572408	et	4	main
seotud	doc_392411160220_item	3572414	et	4	main
murelikuks	doc_392411160220_item	3572419	et	3	main
eestis	doc_392411160220_item	3572421	et	3	main
palju	doc_392411160220_item	3572423	et	4	main
raha	doc_392411160220_item	3572437	et	4	main
siis	doc_392411160220_item	3572438	et	3	main
sest	doc_392411160220_item	3572447	et	4	main
nende	doc_392411160220_item	3572448	et	4	main
inimestele	doc_392411160220_item	3572454	et	3	main
tähtis	doc_392411160220_item	3572457	et	4	main
seotud	doc_392411160220_item	3572460	et	4	main
nendel	doc_392411160220_item	3572468	et	4	main
eestlased	doc_392411160220_item	3572477	et	3	main
eestis	doc_392411160220_item	3572479	et	3	main
on	doc_392411160220_item	3572501	et	4	main
minu	doc_392411160220_item	3572502	et	3	main
arvates	doc_392411160220_item	3572503	et	4	main
tänapäeval	doc_392411160220_item	3572504	et	3	main
on	doc_392411160220_item	3572505	et	4	main
tühistus	doc_392411160220_item	3572506	et	4	main
kõik	doc_392411160220_item	3572507	et	4	main
mis	doc_392411160220_item	3572508	et	4	main
seotud	doc_392411160220_item	3572509	et	4	main
võimuga	doc_392411160220_item	3572510	et	3	main
eestis	doc_392411160220_item	3572511	et	3	main
ja	doc_392411160220_item	3572512	et	3	main
valimiskorraga	doc_392411160220_item	3572513	et	3	main
eestis	doc_392411160220_item	3572514	et	3	main
noored	doc_392411160220_item	3572516	et	3	main
ei	doc_392411160220_item	3572517	et	4	main
huvita	doc_392411160220_item	3572518	et	4	main
sest	doc_392411160220_item	3572515	et	4	main
seda	doc_392411160220_item	3572519	et	3	main
infot	doc_392411160220_item	3572520	et	3	main
ja	doc_392411160220_item	3572521	et	3	main
mõned	doc_392411160220_item	3572522	et	3	main
mainitud	doc_392411160215_item	3572297	et	4	main
tingimused	doc_392411160215_item	3572298	et	3	main
on	doc_392411160219_item	3572314	et	4	main
liiga	doc_392411160219_item	3572362	et	4	main
erakonnad	doc_392411160219_item	3572381	et	4	main
ja	doc_392411160219_item	3572382	et	3	main
kolm	doc_392411160219_item	3572393	et	3	main
usa	doc_392411160219_item	3572403	et	4	main
kõige	doc_392411160220_item	3572410	et	4	main
kuritegevusega	doc_392411160220_item	3572416	et	4	main
ei	doc_392411160220_item	3572428	et	4	main
tahavad	doc_392411160220_item	3572429	et	3	main
õppida	doc_392411160220_item	3572430	et	3	main
ja	doc_392411160220_item	3572431	et	3	main
töötada	doc_392411160220_item	3572432	et	3	main
aga	doc_392411160220_item	3572433	et	3	main
tahavad	doc_392411160220_item	3572434	et	3	main
omandada	doc_392411160220_item	3572435	et	3	main
eestis	doc_392411160220_item	3572439	et	3	main
palju	doc_392411160220_item	3572441	et	4	main
kuritegevusi	doc_392411160220_item	3572442	et	4	main
see	doc_392411160220_item	3572443	et	3	main
tegevused	doc_392411160220_item	3572449	et	4	main
on	doc_392411160220_item	3572456	et	4	main
eestis	doc_392411160220_item	3572463	et	3	main
venelased	doc_392411160220_item	3572464	et	3	main
õigused	doc_392411160220_item	3572471	et	4	main
kui	doc_392411160220_item	3572473	et	3	main
meie	doc_392411160220_item	3572527	et	4	main
aga	doc_392411160220_item	3572529	et	3	main
vajab	doc_392411160219_item	3572365	et	3	main
palju	doc_392411160219_item	3572366	et	4	main
aega	doc_392411160219_item	3572367	et	4	main
kuidas	doc_392411160219_item	3572368	et	3	main
rahvusvähemused	doc_392411160219_item	3572316	et	4	main
kõigepeale	doc_392411160219_item	3572320	et	3	main
sest	doc_392411160219_item	3572321	et	4	main
ma	doc_392411160219_item	3572322	et	3	main
olen	doc_392411160219_item	3572323	et	3	main
venelane	doc_392411160219_item	3572324	et	3	main
kas	doc_392411160219_item	3572325	et	3	main
kuritegevus	doc_392411160219_item	3572326	et	4	main
teeb	doc_392411160219_item	3572327	et	3	main
murelikuks	doc_392411160219_item	3572328	et	3	main
arvan	doc_392411160219_item	3572329	et	3	main
ma	doc_392411160219_item	3572330	et	3	main
et	doc_392411160219_item	3572331	et	3	main
narvas	doc_392411160219_item	3572332	et	4	main
on	doc_392411160219_item	3572333	et	4	main
küllalki	doc_392411160219_item	3572334	et	4	main
palju	doc_392411160219_item	3572335	et	4	main
kuritegevused	doc_392411160219_item	3572336	et	4	main
toimub	doc_392411160219_item	3572337	et	3	main
ja	doc_392411160219_item	3572338	et	3	main
see	doc_392411160219_item	3572339	et	3	main
mind	doc_392411160219_item	3572340	et	4	main
muret	doc_392411160219_item	3572341	et	3	main
aga	doc_392411160219_item	3572342	et	3	main
kuidas	doc_392411160219_item	3572343	et	3	main
te	doc_392411160219_item	3572344	et	4	main
arvate	doc_392411160219_item	3572345	et	3	main
kuidas	doc_392411160219_item	3572346	et	3	main
te	doc_392411160219_item	3572347	et	4	main
arvate	doc_392411160219_item	3572348	et	3	main
kas	doc_392411160219_item	3572349	et	3	main
eesti	doc_392411160219_item	3572350	et	4	main
presidenti	doc_392411160219_item	3572351	et	4	main
välimiskord	doc_392411160219_item	3572352	et	3	main
protsess	doc_392411160219_item	3572353	et	3	main
vajab	doc_392411160219_item	3572354	et	3	main
muutuses	doc_392411160219_item	3572355	et	4	main
huvitab	doc_392411160219_item	3572318	et	3	main
ma	doc_392411160219_item	3572357	et	3	main
protsess	doc_392411160219_item	3572360	et	3	main
ja	doc_392411160219_item	3572364	et	3	main
palju	doc_392411160219_item	3572380	et	4	main
või	doc_392411160219_item	3572392	et	4	main
erakonnad	doc_392411160219_item	3572395	et	4	main
võib	doc_392411160219_item	3572398	et	3	main
efektivsem	doc_392411160219_item	3572400	et	4	main
tähtsam	doc_392411160220_item	3572411	et	4	main
probleem	doc_392411160220_item	3572412	et	3	main
on	doc_392411160220_item	3572413	et	4	main
mis	doc_392411160220_item	3572417	et	4	main
palju	doc_392411160220_item	3572436	et	4	main
on	doc_392411160220_item	3572440	et	4	main
perekonnale	doc_392411160220_item	3572451	et	4	main
ja	doc_392411160220_item	3572452	et	3	main
koos	doc_392411160220_item	3572461	et	4	main
on	doc_392411160220_item	3572469	et	4	main
kasvada	doc_392411160220_item	3572474	et	4	main
ainult	doc_392411160220_item	3572476	et	4	main
aga	doc_392411160220_item	3572500	et	3	main
president	doc_392411160220_item	3572528	et	3	main
peavad	doc_392411160220_item	3572531	et	4	main
häletama	doc_392411160220_item	3572532	et	4	main
ja	doc_392411160220_item	3572533	et	3	main
käima	doc_392411160220_item	3572534	et	4	main
välimisel	doc_392411160220_item	3572535	et	3	main
kui	doc_392411160223_item	3572538	et	3	main
ning	doc_392411160223_item	3572545	et	3	main
ühiskonna	doc_392411160223_item	3572548	et	4	main
väga	doc_392411160223_item	3572560	et	3	main
teada	doc_392411160223_item	3572564	et	3	main
päeval	doc_392411160223_item	3572576	et	3	main
väga	doc_392411160223_item	3572579	et	3	main
ma	doc_392411160223_item	3572583	et	3	main
eesti	doc_392411160223_item	3572585	et	4	main
väidet	doc_397823701999_item	3572638	et	3	main
kas	doc_397823701999_item	3572641	et	3	main
või	doc_397823701999_item	3572645	et	4	main
töö	doc_397823701999_item	3572651	et	4	main
edasi	doc_397823701999_item	3572664	et	3	main
ja	doc_397823701999_item	3572676	et	3	main
järve	doc_397823701999_item	3572690	et	4	main
med	doc_397823701999_item	3572691	et	4	main
jäin	doc_397823701999_item	3572697	et	3	main
elama	doc_397823701999_item	3572698	et	3	main
kele	doc_397823701999_item	3572707	et	4	main
kolm	doc_397823701999_item	3572710	et	3	main
ja	doc_397823701999_item	3572712	et	3	main
ukraina	doc_397823701999_item	3572718	et	4	main
keeli	doc_397823701999_item	3572765	et	4	main
ja	doc_397823701999_item	3572766	et	3	main
püüavad	doc_397823701999_item	3572767	et	3	main
ei	doc_397823701999_item	3572772	et	4	main
eestis	doc_392411160219_item	3572373	et	3	main
ja	doc_392411160219_item	3572376	et	3	main
effektiivne	doc_392411160219_item	3572377	et	4	main
vahetub	doc_392411160219_item	3572384	et	3	main
kui	doc_392411160219_item	3572388	et	3	main
inglismaa	doc_392411160219_item	3572402	et	4	main
rahva	doc_392411160220_item	3572486	et	3	main
ei	doc_392411160220_item	3572487	et	4	main
pea	doc_392411160220_item	3572488	et	4	main
eestis	doc_392411160220_item	3572489	et	3	main
see	doc_392411160220_item	3572490	et	3	main
on	doc_392411160220_item	3572491	et	4	main
väga	doc_392411160220_item	3572492	et	3	main
suur	doc_392411160220_item	3572493	et	3	main
probleem	doc_392411160220_item	3572494	et	3	main
mõned	doc_392411160220_item	3572495	et	3	main
konfliktid	doc_392411160220_item	3572496	et	3	main
tekkivad	doc_392411160220_item	3572497	et	4	main
rahvus	doc_392411160220_item	3572498	et	3	main
tänapäeval	doc_392411160220_item	3572420	et	3	main
on	doc_392411160220_item	3572422	et	4	main
noori	doc_392411160220_item	3572424	et	3	main
ja	doc_392411160220_item	3572425	et	3	main
narkomaane	doc_392411160220_item	3572426	et	3	main
kes	doc_392411160220_item	3572427	et	4	main
on	doc_392411160220_item	3572444	et	4	main
väga	doc_392411160220_item	3572445	et	3	main
kahjustavad	doc_392411160220_item	3572450	et	4	main
veel	doc_392411160220_item	3572455	et	4	main
probleem	doc_392411160220_item	3572458	et	3	main
on	doc_392411160220_item	3572459	et	4	main
on	doc_392411160220_item	3572465	et	4	main
vähemus	doc_392411160220_item	3572466	et	4	main
ja	doc_392411160220_item	3572467	et	3	main
ja	doc_392411160220_item	3572472	et	3	main
põlvkonna	doc_392411160220_item	3572475	et	4	main
siis	doc_392411160220_item	3572478	et	3	main
peavad	doc_392411160220_item	3572480	et	4	main
elama	doc_392411160220_item	3572481	et	3	main
ainult	doc_392411160220_item	3572482	et	4	main
eestlased	doc_392411160220_item	3572483	et	3	main
aga	doc_392411160220_item	3572484	et	3	main
erinevaid	doc_392411160220_item	3572485	et	4	main
tea	doc_392411160220_item	3572524	et	4	main
inimesed	doc_392411160220_item	3572530	et	3	main
teha	doc_392411160223_item	3572541	et	3	main
meie	doc_392411160223_item	3572546	et	4	main
riigi	doc_392411160223_item	3572547	et	3	main
erinevatest	doc_392411160223_item	3572549	et	4	main
valdkondadest	doc_392411160223_item	3572550	et	3	main
siis	doc_392411160223_item	3572551	et	3	main
kõigepealt	doc_392411160223_item	3572552	et	3	main
ma	doc_392411160223_item	3572553	et	3	main
teatan	doc_392411160223_item	3572554	et	3	main
valimiskordest	doc_392411160223_item	3572555	et	4	main
eestis	doc_392411160223_item	3572556	et	3	main
inimesed	doc_392411160223_item	3572562	et	3	main
mis	doc_392411160223_item	3572565	et	4	main
valimiskord	doc_392411160223_item	3572566	et	3	main
on	doc_392411160223_item	3572567	et	4	main
eestis	doc_392411160223_item	3572568	et	3	main
samuti	doc_392411160223_item	3572569	et	3	main
ma	doc_392411160223_item	3572570	et	3	main
kirjutan	doc_392411160223_item	3572571	et	3	main
rahvusvähemusest	doc_392411160223_item	3572572	et	4	main
eestis	doc_392411160223_item	3572573	et	3	main
see	doc_392411160223_item	3572577	et	3	main
teatan	doc_392411160223_item	3572584	et	3	main
elukeskkonast	doc_392411160223_item	3572586	et	4	main
eestis	doc_392411160223_item	3572587	et	3	main
poolt-	doc_397823701999_item	3572648	et	4	main
peab	doc_397823701999_item	3572653	et	4	main
võõrkeelte	doc_397823701999_item	3572659	et	3	main
arvan	doc_397823701999_item	3572666	et	3	main
teatmine	doc_397823701999_item	3572669	et	4	main
tähtis	doc_397823701999_item	3572672	et	4	main
ma	doc_397823701999_item	3572673	et	3	main
sündisin	doc_397823701999_item	3572674	et	3	main
õppisin	doc_397823701999_item	3572688	et	3	main
k	doc_397823701999_item	3572689	et	4	main
peale	doc_397823701999_item	3572693	et	4	main
kooli	doc_397823701999_item	3572694	et	4	main
siis	doc_397823701999_item	3572700	et	3	main
problemid	doc_397823701999_item	3572703	et	4	main
ma	doc_397823701999_item	3572704	et	3	main
keisin	doc_397823701999_item	3572705	et	4	main
korda	doc_397823701999_item	3572711	et	4	main
d	doc_397823701999_item	3572714	et	4	main
kategooria	doc_397823701999_item	3572715	et	4	main
ma	doc_397823701999_item	3572716	et	3	main
keel	doc_397823701999_item	3572719	et	4	main
ainult	doc_397823701999_item	3572751	et	4	main
populaarne	doc_397823701999_item	3572757	et	3	main
kelte	doc_397823701999_item	3572758	et	3	main
päeva	doc_397823701999_item	3572761	et	4	main
on	doc_392411160223_item	3572618	et	4	main
suur	doc_392411160223_item	3572619	et	3	main
kuritegevus	doc_392411160223_item	3572620	et	4	main
ma	doc_392411160223_item	3572621	et	3	main
arvan	doc_392411160223_item	3572622	et	3	main
et	doc_392411160223_item	3572623	et	3	main
minu	doc_392411160223_item	3572624	et	3	main
ettekanne	doc_392411160223_item	3572625	et	4	main
on	doc_392411160223_item	3572626	et	4	main
väga	doc_392411160223_item	3572627	et	3	main
huvitav	doc_392411160223_item	3572628	et	4	main
sest	doc_392411160223_item	3572629	et	4	main
ma	doc_392411160223_item	3572630	et	3	main
pudutan	doc_392411160223_item	3572631	et	4	main
väga	doc_392411160223_item	3572632	et	3	main
tõsineid	doc_392411160223_item	3572633	et	3	main
temaid	doc_392411160223_item	3572634	et	4	main
ettekanne	doc_392411160223_item	3572542	et	4	main
haldussüsteemist	doc_392411160223_item	3572544	et	4	main
tõsine	doc_392411160223_item	3572561	et	4	main
peaksid	doc_392411160223_item	3572563	et	4	main
on	doc_392411160223_item	3572578	et	4	main
väga	doc_392411160223_item	3572588	et	3	main
omapärane	doc_392411160223_item	3572589	et	4	main
elu	doc_392411160223_item	3572590	et	4	main
ma	doc_392411160223_item	3572591	et	3	main
arvan	doc_392411160223_item	3572592	et	3	main
et	doc_392411160223_item	3572593	et	3	main
hakkab	doc_392411160223_item	3572595	et	3	main
lugeja	doc_392411160223_item	3572594	et	4	main
loeb	doc_392411160223_item	3572596	et	3	main
huvitaga	doc_392411160223_item	3572597	et	4	main
veel	doc_392411160223_item	3572598	et	4	main
ma	doc_392411160223_item	3572599	et	3	main
teatan	doc_392411160223_item	3572600	et	3	main
et	doc_392411160223_item	3572601	et	3	main
kuritegevus	doc_392411160223_item	3572602	et	4	main
teeb	doc_392411160223_item	3572603	et	3	main
murelikuks	doc_392411160223_item	3572604	et	3	main
see	doc_392411160223_item	3572605	et	3	main
on	doc_392411160223_item	3572606	et	4	main
väga	doc_392411160223_item	3572607	et	3	main
aktuaalne	doc_392411160223_item	3572608	et	3	main
tema	doc_392411160223_item	3572609	et	4	main
eestis	doc_392411160223_item	3572610	et	3	main
palju	doc_392411160223_item	3572611	et	4	main
inimesed	doc_392411160223_item	3572612	et	3	main
kartavad	doc_392411160223_item	3572613	et	4	main
õhtul	doc_392411160223_item	3572614	et	3	main
jalutama	doc_392411160223_item	3572615	et	3	main
sest	doc_392411160223_item	3572616	et	4	main
meil	doc_392411160223_item	3572617	et	4	main
ja	doc_397823701999_item	3572649	et	3	main
pikkus	doc_397823701999_item	3572652	et	4	main
olema	doc_397823701999_item	3572654	et	4	main
umbes	doc_397823701999_item	3572655	et	4	main
120	doc_397823701999_item	3572656	et	2	main
elus	doc_397823701999_item	3572663	et	4	main
ukrainas	doc_397823701999_item	3572675	et	4	main
elasin	doc_397823701999_item	3572677	et	3	main
abielusin	doc_397823701999_item	3572695	et	4	main
ja	doc_397823701999_item	3572696	et	3	main
tekkisid	doc_397823701999_item	3572701	et	4	main
kursused	doc_397823701999_item	3572708	et	3	main
sain	doc_397823701999_item	3572713	et	3	main
akadeemias	doc_397823701999_item	3572749	et	3	main
praegu	doc_397823701999_item	3572753	et	3	main
intensivselt	doc_397823701999_item	3572763	et	4	main
õppivad	doc_397823701999_item	3572764	et	4	main
essee	doc_392411160223_item	3572537	et	4	main
tuleb	doc_392411160223_item	3572540	et	3	main
eesti	doc_392411160223_item	3572543	et	4	main
on	doc_392411160223_item	3572559	et	4	main
täna	doc_392411160223_item	3572575	et	4	main
aktuaalne	doc_392411160223_item	3572580	et	3	main
kindlasti	doc_392411160223_item	3572582	et	3	main
essee	doc_397823701999_item	3572636	et	4	main
vastuargumente	doc_397823701999_item	3572650	et	3	main
oskamine	doc_397823701999_item	3572660	et	4	main
aitab	doc_397823701999_item	3572661	et	3	main
meid	doc_397823701999_item	3572662	et	4	main
ett	doc_397823701999_item	3572667	et	3	main
kelete	doc_397823701999_item	3572668	et	4	main
on	doc_397823701999_item	3572670	et	4	main
väga	doc_397823701999_item	3572671	et	3	main
1980	doc_397823701999_item	3572682	et	2	main
aastal	doc_397823701999_item	3572683	et	3	main
ma	doc_397823701999_item	3572684	et	3	main
sõitsin	doc_397823701999_item	3572685	et	3	main
õppima	doc_397823701999_item	3572686	et	3	main
eestise	doc_397823701999_item	3572687	et	4	main
eesti	doc_397823701999_item	3572706	et	4	main
tean	doc_397823701999_item	3572717	et	3	main
õppisin	doc_397823701999_item	3572736	et	3	main
eesti	doc_397823701999_item	3572737	et	4	main
koolis	doc_397823701999_item	3572738	et	4	main
poeg	doc_397823701999_item	3572739	et	3	main
eesti	doc_397823701999_item	3572740	et	4	main
keele	doc_397823701999_item	3572741	et	4	main
õppis	doc_397823701999_item	3572742	et	3	main
seeaves	doc_397823701999_item	3572743	et	4	main
nad	doc_397823701999_item	3572744	et	3	main
praegu	doc_397823701999_item	3572745	et	3	main
õppinud	doc_397823701999_item	3572746	et	4	main
eestis	doc_397823701999_item	3572747	et	3	main
ja	doc_397823701999_item	3572750	et	3	main
väga	doc_397823701999_item	3572754	et	3	main
oskus	doc_397823701999_item	3572759	et	3	main
läida	doc_397823701999_item	3572768	et	4	main
ta	doc_397823701999_item	3572776	et	4	main
töötab	doc_397823701999_item	3572777	et	3	main
seal	doc_397823701999_item	3572778	et	4	main
kus	doc_397823701999_item	3572779	et	3	main
eriti	doc_397823701999_item	3572780	et	3	main
keelte	doc_397823701999_item	3572781	et	3	main
oskust	doc_397823701999_item	3572782	et	3	main
ma	doc_397823701999_item	3572783	et	3	main
arvan	doc_397823701999_item	3572784	et	3	main
ett	doc_397823701999_item	3572785	et	3	main
kõik	doc_397823701999_item	3572786	et	4	main
kes	doc_397823701999_item	3572787	et	4	main
elavad	doc_397823701999_item	3572788	et	4	main
eestis	doc_397823701999_item	3572789	et	3	main
päavad	doc_397823701999_item	3572790	et	4	main
eesti	doc_397823701999_item	3572791	et	4	main
keeles	doc_397823701999_item	3572792	et	4	main
rääkkima	doc_397823701999_item	3572793	et	4	main
ja	doc_532115409095_item	3572799	et	3	main
ohtlikud	doc_532115409095_item	3572801	et	3	main
lugege	doc_397823701999_item	3572637	et	3	main
ja	doc_397823701999_item	3572639	et	3	main
kirjutage	doc_397823701999_item	3572640	et	3	main
olete	doc_397823701999_item	3572642	et	3	main
sellega	doc_397823701999_item	3572643	et	3	main
nõus	doc_397823701999_item	3572644	et	4	main
mitte	doc_397823701999_item	3572646	et	3	main
esitage	doc_397823701999_item	3572647	et	3	main
sõna	doc_397823701999_item	3572657	et	4	main
väide	doc_397823701999_item	3572658	et	4	main
ma	doc_397823701999_item	3572665	et	3	main
seal	doc_397823701999_item	3572678	et	4	main
kuni	doc_397823701999_item	3572679	et	3	main
kaheksateist	doc_397823701999_item	3572680	et	4	main
aastani	doc_397823701999_item	3572681	et	3	main
koolis	doc_397823701999_item	3572692	et	4	main
eestisse	doc_397823701999_item	3572699	et	4	main
keele	doc_397823701999_item	3572702	et	4	main
juba	doc_397823701999_item	3572709	et	3	main
ja	doc_397823701999_item	3572720	et	3	main
natukene	doc_397823701999_item	3572721	et	4	main
saaksakele	doc_397823701999_item	3572722	et	4	main
mul	doc_397823701999_item	3572723	et	3	main
on	doc_397823701999_item	3572724	et	4	main
kaks	doc_397823701999_item	3572725	et	3	main
last	doc_397823701999_item	3572726	et	4	main
nad	doc_397823701999_item	3572727	et	3	main
teavad	doc_397823701999_item	3572728	et	3	main
venekeelt	doc_397823701999_item	3572729	et	4	main
saksakeelt	doc_397823701999_item	3572730	et	4	main
eestikeelt	doc_397823701999_item	3572731	et	4	main
minu	doc_397823701999_item	3572732	et	3	main
tütar	doc_397823701999_item	3572733	et	3	main
kümmendast	doc_397823701999_item	3572734	et	4	main
klasist	doc_397823701999_item	3572735	et	4	main
mere	doc_397823701999_item	3572748	et	3	main
eestikeeles	doc_397823701999_item	3572752	et	4	main
moodne	doc_397823701999_item	3572755	et	3	main
ja	doc_397823701999_item	3572756	et	3	main
tänase	doc_397823701999_item	3572760	et	3	main
oska	doc_397823701999_item	3572773	et	4	main
on	doc_532115409095_item	3572797	et	4	main
kasutades	doc_532115409095_item	3572802	et	3	main
lihtsamaks	doc_532115409095_item	3572808	et	4	main
allergoologid	doc_532115409095_item	3572818	et	4	main
keemiatoodetes	doc_532115409095_item	3572821	et	3	main
allergoologile	doc_532115409095_item	3572847	et	4	main
või	doc_532115409095_item	3572848	et	4	main
vahetada	doc_532115409095_item	3572849	et	3	main
soovitavad	doc_532115409095_item	3572853	et	4	main
pesu	doc_532115409095_item	3572856	et	4	main
tihtihoida	doc_532115409095_item	3572878	et	4	main
korral	doc_532115409095_item	3572884	et	4	main
ma	doc_532115409095_item	3572926	et	3	main
linnas	doc_532115409095_item	3572929	et	4	main
ohtlike	doc_532115409095_item	3572931	et	3	main
selles	doc_446717232819_item	3572940	et	4	main
filmis	doc_446717232819_item	3572941	et	4	main
taasiseseisvumise	doc_446717232819_item	3572943	et	3	main
margit	doc_446717232819_item	3572948	et	4	main
materjal	doc_446717232819_item	3572960	et	3	main
korrastamiseks	doc_446717232819_item	3572962	et	4	main
annab	doc_446717232819_item	3572967	et	3	main
emotsiooni	doc_446717232819_item	3572971	et	4	main
paraku	doc_446717232819_item	3572974	et	3	main
noored	doc_397823701999_item	3572762	et	3	main
tööd	doc_397823701999_item	3572769	et	4	main
velismaal	doc_397823701999_item	3572770	et	4	main
abikaasa	doc_397823701999_item	3572771	et	4	main
aga	doc_397823701999_item	3572775	et	3	main
keemiatooted	doc_532115409095_item	3572796	et	3	main
aga	doc_532115409095_item	3572809	et	3	main
tekkivad	doc_532115409095_item	3572810	et	4	main
ääritus	doc_532115409095_item	3572817	et	4	main
on	doc_532115409095_item	3572871	et	4	main
eest	doc_532115409095_item	3572880	et	4	main
tuleohtlik	doc_532115409095_item	3572881	et	3	main
siilma	doc_532115409095_item	3572886	et	4	main
et	doc_532115409095_item	3572891	et	3	main
inimene	doc_532115409095_item	3572893	et	3	main
peab	doc_532115409095_item	3572894	et	4	main
ära	doc_532115409095_item	3572921	et	4	main
rikkuda	doc_532115409095_item	3572922	et	3	main
joogivee	doc_532115409095_item	3572923	et	3	main
et	doc_532115409095_item	3572928	et	3	main
jäätmete	doc_532115409095_item	3572932	et	4	main
essee	doc_446717232819_item	3572936	et	4	main
filmi	doc_446717232819_item	3572953	et	4	main
kohta	doc_446717232819_item	3572954	et	4	main
august	doc_446717232819_item	3572955	et	4	main
1991	doc_446717232819_item	3572956	et	2	main
hea	doc_446717232819_item	3572959	et	4	main
see	doc_446717232819_item	3572965	et	3	main
mängivad	doc_446717232819_item	3572987	et	4	main
väga	doc_446717232819_item	3572988	et	3	main
hästi	doc_446717232819_item	3572989	et	3	main
taasiseseisvumine	doc_446717232819_item	3573029	et	3	main
filmi	doc_446717232819_item	3573054	et	4	main
vaadates	doc_446717232819_item	3573055	et	3	main
kuna	doc_446717232819_item	3573056	et	3	main
saa	doc_446717232819_item	3573062	et	4	main
pilti	doc_446717232819_item	3573067	et	4	main
tulid	doc_446717232819_item	3573079	et	4	main
iga	doc_446717232819_item	3573085	et	4	main
lõi	doc_446717232819_item	3573088	et	4	main
välja	doc_446717232819_item	3573089	et	4	main
võimas	doc_446717232819_item	3573097	et	4	main
eestikeelt	doc_397823701999_item	3572774	et	4	main
essee	doc_532115409095_item	3572795	et	4	main
elu	doc_532115409095_item	3572807	et	4	main
naha	doc_532115409095_item	3572816	et	3	main
oma	doc_532115409095_item	3572850	et	4	main
keemiatoodet	doc_532115409095_item	3572851	et	3	main
enne	doc_532115409095_item	3572869	et	4	main
kasutamist	doc_532115409095_item	3572870	et	4	main
vaja	doc_532115409095_item	3572872	et	4	main
kasutumisjuhist	doc_532115409095_item	3572873	et	4	main
siilma	doc_532115409095_item	3572882	et	4	main
rohke	doc_532115409095_item	3572887	et	4	main
veega	doc_532115409095_item	3572888	et	3	main
arvan	doc_532115409095_item	3572927	et	3	main
tuleb	doc_532115409095_item	3572930	et	3	main
kajastuvad	doc_446717232819_item	3572939	et	4	main
eesti	doc_446717232819_item	3572942	et	4	main
eesti	doc_446717232819_item	3572945	et	4	main
päevalehe	doc_446717232819_item	3572946	et	3	main
ajakirjanik	doc_446717232819_item	3572947	et	3	main
tõnson	doc_446717232819_item	3572949	et	4	main
on	doc_446717232819_item	3572950	et	4	main
et	doc_446717232819_item	3572964	et	3	main
edasi	doc_446717232819_item	3572969	et	3	main
sündmusi	doc_446717232819_item	3572973	et	3	main
saa	doc_446717232819_item	3572980	et	4	main
etv	doc_446717232819_item	3572985	et	4	main
töötajad	doc_446717232819_item	3572986	et	4	main
nendel	doc_446717232819_item	3573030	et	4	main
sündmustel	doc_446717232819_item	3573031	et	3	main
kogu	doc_446717232819_item	3573032	et	4	main
see	doc_446717232819_item	3573033	et	3	main
film	doc_446717232819_item	3573034	et	3	main
ju	doc_446717232819_item	3573035	et	3	main
silme	doc_446717232819_item	3573050	et	4	main
lugedes	doc_446717232819_item	3573058	et	3	main
sellest	doc_446717232819_item	3573059	et	4	main
säärast	doc_446717232819_item	3573064	et	3	main
ausad	doc_446717232819_item	3573069	et	3	main
on	doc_446717232819_item	3573093	et	4	main
lugeda	doc_532115409095_item	3572875	et	3	main
tervisele	doc_532115409095_item	3572798	et	3	main
loodusele	doc_532115409095_item	3572800	et	4	main
probleemid	doc_532115409095_item	3572811	et	3	main
need	doc_532115409095_item	3572812	et	3	main
arvestavad	doc_532115409095_item	3572819	et	4	main
sisaldatakse	doc_532115409095_item	3572822	et	3	main
erinevaid	doc_532115409095_item	3572823	et	4	main
lisaaineteid	doc_532115409095_item	3572824	et	3	main
millisest	doc_532115409095_item	3572825	et	3	main
tekib	doc_532115409095_item	3572826	et	3	main
allergiat	doc_532115409095_item	3572827	et	3	main
need	doc_532115409095_item	3572828	et	3	main
on	doc_532115409095_item	3572829	et	4	main
lõhna	doc_532115409095_item	3572830	et	4	main
värv	doc_532115409095_item	3572831	et	3	main
ja	doc_532115409095_item	3572832	et	3	main
valgendavad	doc_532115409095_item	3572833	et	4	main
ained	doc_532115409095_item	3572834	et	3	main
lisaained	doc_532115409095_item	3572835	et	3	main
on	doc_532115409095_item	3572836	et	4	main
väga	doc_532115409095_item	3572837	et	3	main
tugevad	doc_532115409095_item	3572838	et	4	main
kui	doc_532115409095_item	3572839	et	3	main
inimistel	doc_532115409095_item	3572840	et	4	main
tekib	doc_532115409095_item	3572841	et	3	main
allergiat	doc_532115409095_item	3572842	et	3	main
siis	doc_532115409095_item	3572843	et	3	main
on	doc_532115409095_item	3572844	et	4	main
keemiatoodeteid	doc_532115409095_item	3572803	et	4	main
me	doc_532115409095_item	3572804	et	4	main
teeme	doc_532115409095_item	3572805	et	3	main
meie	doc_532115409095_item	3572806	et	4	main
on	doc_532115409095_item	3572813	et	4	main
allergia	doc_532115409095_item	3572814	et	4	main
ja	doc_532115409095_item	3572815	et	3	main
et	doc_532115409095_item	3572820	et	3	main
ka	doc_532115409095_item	3572854	et	3	main
läbi	doc_532115409095_item	3572874	et	4	main
kasutamisjuhisel	doc_532115409095_item	3572876	et	3	main
kirjutatakse	doc_532115409095_item	3572877	et	3	main
suttumise	doc_532115409095_item	3572883	et	4	main
ma	doc_532115409095_item	3572889	et	3	main
iga	doc_532115409095_item	3572892	et	4	main
oma	doc_532115409095_item	3572895	et	4	main
valikut	doc_532115409095_item	3572896	et	3	main
teha	doc_532115409095_item	3572897	et	3	main
missugust	doc_532115409095_item	3572898	et	3	main
keemiatoodet	doc_532115409095_item	3572899	et	3	main
sobib	doc_532115409095_item	3572900	et	3	main
temale	doc_532115409095_item	3572901	et	3	main
keemiatoodete	doc_532115409095_item	3572902	et	3	main
jäätmed	doc_532115409095_item	3572903	et	3	main
on	doc_532115409095_item	3572904	et	4	main
ohtlikud	doc_532115409095_item	3572905	et	3	main
ka	doc_532115409095_item	3572906	et	3	main
loodusele	doc_532115409095_item	3572907	et	4	main
sest	doc_532115409095_item	3572908	et	4	main
sattudes	doc_532115409095_item	3572909	et	3	main
tavalisse	doc_532115409095_item	3572910	et	4	main
prügikasti	doc_532115409095_item	3572911	et	4	main
nind	doc_532115409095_item	3572912	et	4	main
sealt	doc_532115409095_item	3572913	et	4	main
edasi	doc_532115409095_item	3572914	et	3	main
prügimäele	doc_532115409095_item	3572915	et	3	main
need	doc_532115409095_item	3572916	et	3	main
kahjustavad	doc_532115409095_item	3572917	et	4	main
ja	doc_532115409095_item	3572919	et	3	main
pinnast	doc_532115409095_item	3572918	et	4	main
võivad	doc_532115409095_item	3572920	et	4	main
vaja	doc_532115409095_item	3572845	et	4	main
pöörduda	doc_532115409095_item	3572846	et	3	main
allergoologid	doc_532115409095_item	3572852	et	4	main
käsitsi	doc_532115409095_item	3572855	et	3	main
või	doc_532115409095_item	3572857	et	4	main
nõusid	doc_532115409095_item	3572858	et	3	main
pestes	doc_532115409095_item	3572859	et	3	main
tuleks	doc_532115409095_item	3572860	et	4	main
kindlasti	doc_532115409095_item	3572861	et	3	main
kasutada	doc_532115409095_item	3572862	et	3	main
kummikindaid	doc_532115409095_item	3572863	et	3	main
mõned	doc_532115409095_item	3572864	et	3	main
keemiatooted	doc_532115409095_item	3572865	et	3	main
on	doc_532115409095_item	3572866	et	4	main
ohtlikud	doc_532115409095_item	3572867	et	3	main
ja	doc_532115409095_item	3572868	et	3	main
laste	doc_532115409095_item	3572879	et	4	main
pese	doc_532115409095_item	3572885	et	4	main
arva	doc_532115409095_item	3572890	et	4	main
seoses	doc_532115409095_item	3572924	et	4	main
sellega	doc_532115409095_item	3572925	et	3	main
hoidla	doc_532115409095_item	3572933	et	4	main
ehitada	doc_532115409095_item	3572934	et	3	main
kui	doc_446717232819_item	3572937	et	3	main
ütelnud	doc_446717232819_item	3572951	et	4	main
järgmised	doc_446717232819_item	3572957	et	3	main
mälu	doc_446717232819_item	3572961	et	4	main
ideaalselt	doc_446717232819_item	3572968	et	4	main
tollast	doc_446717232819_item	3572970	et	3	main
osasid	doc_446717232819_item	3572972	et	3	main
samas	doc_446717232819_item	3572981	et	4	main
ühiskonnas	doc_446717232819_item	3572993	et	4	main
kahtlused	doc_446717232819_item	3572994	et	4	main
kõhklused	doc_446717232819_item	3572995	et	3	main
säärased	doc_446717232819_item	3572996	et	3	main
eesti	doc_446717232819_item	3573028	et	4	main
raamatust	doc_446717232819_item	3573057	et	4	main
ikkagi	doc_446717232819_item	3573063	et	4	main
emotsiooni	doc_446717232819_item	3573065	et	4	main
eestlase	doc_446717232819_item	3573086	et	3	main
film	doc_446717232819_item	3573098	et	3	main
hästi	doc_446717232819_item	3572938	et	3	main
sündmused	doc_446717232819_item	3572944	et	3	main
selle	doc_446717232819_item	3572952	et	4	main
sõnad	doc_446717232819_item	3572958	et	4	main
arvan	doc_446717232819_item	3572963	et	3	main
film	doc_446717232819_item	3572966	et	3	main
päris	doc_446717232819_item	3572977	et	4	main
võtta	doc_446717232819_item	3572978	et	3	main
ei	doc_446717232819_item	3572979	et	4	main
filmi	doc_446717232819_item	3572982	et	4	main
näiteks	doc_446717232819_item	3572984	et	4	main
emotsioonid	doc_446717232819_item	3572997	et	3	main
olid	doc_446717232819_item	3572998	et	4	main
tollasele	doc_446717232819_item	3572999	et	3	main
kodanikule	doc_446717232819_item	3573000	et	3	main
vägagi	doc_446717232819_item	3573001	et	3	main
omased	doc_446717232819_item	3573002	et	3	main
sellest	doc_446717232819_item	3573003	et	4	main
järeldan	doc_446717232819_item	3573004	et	3	main
et	doc_446717232819_item	3573005	et	3	main
emotsiooni	doc_446717232819_item	3573006	et	4	main
roll	doc_446717232819_item	3573007	et	3	main
selles	doc_446717232819_item	3573008	et	4	main
filmis	doc_446717232819_item	3573009	et	4	main
oli	doc_446717232819_item	3573010	et	3	main
märksa	doc_446717232819_item	3573011	et	3	main
suurem	doc_446717232819_item	3573012	et	4	main
kui	doc_446717232819_item	3573013	et	3	main
sündmuste	doc_446717232819_item	3573014	et	3	main
oma	doc_446717232819_item	3573015	et	4	main
siiski	doc_446717232819_item	3573016	et	4	main
oli	doc_446717232819_item	3573017	et	3	main
põhisündmused	doc_446717232819_item	3573018	et	3	main
selles	doc_446717232819_item	3573019	et	4	main
filmis	doc_446717232819_item	3573020	et	4	main
aset	doc_446717232819_item	3573021	et	3	main
leidnud	doc_446717232819_item	3573022	et	4	main
1991	doc_446717232819_item	3573023	et	2	main
a	doc_446717232819_item	3573024	et	4	main
augustiputsh	doc_446717232819_item	3573025	et	4	main
ning	doc_446717232819_item	3573026	et	3	main
20081991a	doc_446717232819_item	3573027	et	4	main
tõe	doc_446717232819_item	3572975	et	4	main
pähe	doc_446717232819_item	3572976	et	4	main
tegelased	doc_446717232819_item	3572983	et	3	main
välja	doc_446717232819_item	3572990	et	4	main
emotsiooni	doc_446717232819_item	3572991	et	4	main
segadus	doc_446717232819_item	3572992	et	3	main
tegelikult	doc_446717232819_item	3573036	et	4	main
põhinebki	doc_446717232819_item	3573037	et	3	main
arvan	doc_446717232819_item	3573038	et	3	main
et	doc_446717232819_item	3573039	et	3	main
ilmar	doc_446717232819_item	3573040	et	4	main
raag	doc_446717232819_item	3573041	et	3	main
kajastab	doc_446717232819_item	3573042	et	3	main
seda	doc_446717232819_item	3573043	et	3	main
väga	doc_446717232819_item	3573044	et	3	main
hästi	doc_446717232819_item	3573045	et	3	main
mina	doc_446717232819_item	3573046	et	4	main
isiklikult	doc_446717232819_item	3573047	et	4	main
sain	doc_446717232819_item	3573048	et	3	main
pildi	doc_446717232819_item	3573049	et	4	main
ette	doc_446717232819_item	3573051	et	4	main
küll	doc_446717232819_item	3573052	et	4	main
seda	doc_446717232819_item	3573053	et	3	main
ei	doc_446717232819_item	3573061	et	4	main
ega	doc_446717232819_item	3573066	et	3	main
ikka	doc_446717232819_item	3573071	et	4	main
kõlas	doc_446717232819_item	3573073	et	4	main
nn	doc_446717232819_item	3573074	et	4	main
taasiseseisvumise	doc_446717232819_item	3573075	et	3	main
hümn	doc_446717232819_item	3573076	et	3	main
koit	doc_446717232819_item	3573077	et	3	main
siis	doc_446717232819_item	3573078	et	3	main
patrotism	doc_446717232819_item	3573090	et	4	main
kuna	doc_446717232819_item	3573091	et	3	main
see	doc_446717232819_item	3573092	et	3	main
kõigest	doc_446717232819_item	3573060	et	4	main
olgem	doc_446717232819_item	3573068	et	3	main
kui	doc_446717232819_item	3573070	et	3	main
filmis	doc_446717232819_item	3573072	et	4	main
ikka	doc_446717232819_item	3573080	et	4	main
külmavärinad	doc_446717232819_item	3573081	et	3	main
peale	doc_446717232819_item	3573082	et	4	main
küll	doc_446717232819_item	3573083	et	4	main
ning	doc_446717232819_item	3573084	et	3	main
hingest	doc_446717232819_item	3573087	et	4	main
ikka	doc_446717232819_item	3573094	et	4	main
emotsionaalselt	doc_446717232819_item	3573095	et	4	main
väga	doc_446717232819_item	3573096	et	3	main
tallinna	doc_491521501770_item	3574767	et	4	main
e	doc_491521501770_item	3574775	et	4	main
koostaja	doc_491521501770_item	3574777	et	4	main
rahvakultuur	doc_491521501770_item	3574787	et	3	main
on	doc_491521501770_item	3574795	et	4	main
ja	doc_491521501770_item	3574801	et	3	main
ühiskonnategelasi	doc_491521501770_item	3574810	et	3	main
täitnud	doc_491521501770_item	3574813	et	4	main
ühiskonnas	doc_491521501770_item	3574814	et	4	main
riigi	doc_491521501770_item	3574815	et	3	main
rollis	doc_491521501770_item	3574821	et	3	main
vaadelda	doc_491521501770_item	3574824	et	4	main
inimene	doc_491521501770_item	3574838	et	3	main
mis	doc_491521501770_item	3574842	et	4	main
jaoks	doc_491521501770_item	3574875	et	4	main
väga	doc_491521501770_item	3574876	et	3	main
tähtsal	doc_491521501770_item	3574877	et	3	main
kohal	doc_491521501770_item	3574878	et	4	main
see	doc_491521501770_item	3574879	et	3	main
toob	doc_491521501770_item	3574886	et	3	main
kõike	doc_491521501770_item	3574888	et	4	main
eluks	doc_491521501770_item	3574891	et	3	main
hoiakuid	doc_491521501770_item	3574892	et	3	main
essee	doc_491521501770_item	3574766	et	4	main
ajas	doc_491521501770_item	3574772	et	4	main
essee	doc_491521501770_item	3574773	et	4	main
õppejõud	doc_491521501770_item	3574774	et	4	main
mina	doc_491521501770_item	3574782	et	4	main
hakkan	doc_491521501770_item	3574783	et	3	main
käsitlema	doc_491521501770_item	3574784	et	3	main
teemat	doc_491521501770_item	3574785	et	3	main
pere	doc_491521501770_item	3574791	et	4	main
riigi	doc_491521501770_item	3574800	et	3	main
temast	doc_491521501770_item	3574804	et	3	main
on	doc_491521501770_item	3574805	et	4	main
jaoks	doc_491521501770_item	3574816	et	4	main
ma	doc_491521501770_item	3574822	et	3	main
läbi	doc_491521501770_item	3574831	et	4	main
aegade	doc_491521501770_item	3574832	et	3	main
ja	doc_491521501770_item	3574833	et	3	main
eesti	doc_491521501770_item	3574836	et	4	main
rahvakultuuriga	doc_491521501770_item	3574837	et	4	main
iga	doc_491521501770_item	3574873	et	4	main
inimese	doc_491521501770_item	3574874	et	4	main
elus	doc_491521501770_item	3574883	et	4	main
tema	doc_491521501770_item	3574909	et	4	main
peab	doc_491521501770_item	3574915	et	4	main
oli	doc_491521501770_item	3574941	et	3	main
olla	doc_491521501770_item	3574946	et	3	main
kas	doc_491521501770_item	3574947	et	3	main
vennad-õed	doc_491521501770_item	3574949	et	3	main
lihtpered	doc_491521501770_item	3574951	et	3	main
üksiksugulane	doc_491521501770_item	3574969	et	3	main
mis	doc_491521501770_item	3574972	et	4	main
mitmest	doc_491521501770_item	3574974	et	4	main
sugulasperekonnast	doc_491521501770_item	3574975	et	4	main
taluperel	doc_491521501770_item	3574976	et	3	main
oli	doc_491521501770_item	3574977	et	3	main
ta	doc_491521501770_item	3574982	et	4	main
maatükilt	doc_491521501770_item	3574996	et	3	main
riietuse	doc_491521501770_item	3575003	et	4	main
ja	doc_491521501770_item	3575004	et	3	main
jalatsite	doc_491521501770_item	3575005	et	3	main
jaoks	doc_491521501770_item	3575006	et	4	main
ka	doc_491521501770_item	3575011	et	3	main
ei	doc_491521501770_item	3575030	et	4	main
sellest	doc_491521501770_item	3575041	et	4	main
kuni	doc_491521501770_item	3575073	et	3	main
olid	doc_491521501770_item	3575085	et	4	main
sugulus-	doc_491521501770_item	3575086	et	4	main
põimusid	doc_491521501770_item	3575091	et	4	main
kuulus	doc_491521501770_item	3575095	et	4	main
peremehele	doc_491521501770_item	3575096	et	3	main
ja	doc_491521501770_item	3575097	et	3	main
peremehe	doc_491521501770_item	3575104	et	3	main
terveid	doc_491521501770_item	3575117	et	4	main
sugulaste	doc_491521501770_item	3575118	et	4	main
perekondi	doc_491521501770_item	3575119	et	4	main
poegade	doc_491521501770_item	3575120	et	3	main
võõraid	doc_491521501770_item	3575138	et	3	main
sugulasi	doc_491521501770_item	3575141	et	3	main
metsa-	doc_491521501770_item	3575155	et	4	main
pedagoogikaülikool	doc_491521501770_item	3574768	et	4	main
e	doc_491521501770_item	3574778	et	4	main
perekonnanimi	doc_491521501770_item	3574779	et	3	main
tallinn	doc_491521501770_item	3574780	et	4	main
2000	doc_491521501770_item	3574781	et	2	main
eesti	doc_491521501770_item	3574790	et	4	main
eesti	doc_491521501770_item	3574793	et	4	main
aegade	doc_491521501770_item	3574797	et	3	main
kandjaks	doc_491521501770_item	3574803	et	4	main
ta	doc_491521501770_item	3574811	et	4	main
stabiilsuse	doc_491521501770_item	3574819	et	4	main
on	doc_491521501770_item	3574839	et	4	main
sellele	doc_491521501770_item	3574844	et	4	main
rahvakultuur	doc_491521501770_item	3574770	et	3	main
seisukohast	doc_491521501770_item	3574792	et	4	main
kultuuri-	doc_491521501770_item	3574808	et	4	main
ja	doc_491521501770_item	3574809	et	3	main
on	doc_491521501770_item	3574812	et	4	main
tagaja	doc_491521501770_item	3574820	et	4	main
selle	doc_491521501770_item	3574834	et	4	main
seost	doc_491521501770_item	3574835	et	3	main
olend	doc_491521501770_item	3574841	et	3	main
viitab	doc_491521501770_item	3574843	et	3	main
bioloogiline	doc_491521501770_item	3574866	et	4	main
mida	doc_491521501770_item	3574868	et	4	main
rahuldama	doc_491521501770_item	3574870	et	3	main
perekond	doc_491521501770_item	3574871	et	3	main
on	doc_491521501770_item	3574872	et	4	main
põhitugi	doc_491521501770_item	3574882	et	3	main
vajalikku	doc_491521501770_item	3574889	et	4	main
iseendast	doc_491521501770_item	3574899	et	3	main
rahvusest	doc_491521501770_item	3574912	et	4	main
samuti	doc_491521501770_item	3574913	et	3	main
ta	doc_491521501770_item	3574914	et	4	main
peresid	doc_491521501770_item	3574942	et	3	main
talupered	doc_491521501770_item	3574944	et	3	main
kooselurühmad	doc_491521501770_item	3574948	et	3	main
muud	doc_491521501770_item	3574950	et	4	main
lapsega	doc_491521501770_item	3574960	et	3	main
pered	doc_491521501770_item	3574963	et	3	main
kuulus	doc_491521501770_item	3574967	et	4	main
koosnesid	doc_491521501770_item	3574973	et	4	main
pidi	doc_491521501770_item	3574988	et	4	main
sellelt	doc_491521501770_item	3574995	et	4	main
perele	doc_491521501770_item	3574998	et	3	main
ning	doc_491521501770_item	3575001	et	3	main
mis	doc_491521501770_item	3575007	et	4	main
vajaminevatest	doc_491521501770_item	3575014	et	3	main
suudetud	doc_491521501770_item	3575031	et	4	main
kasutati	doc_491521501770_item	3575037	et	4	main
suurem	doc_491521501770_item	3575039	et	4	main
osa	doc_491521501770_item	3575040	et	4	main
19	doc_491521501770_item	3575074	et	2	main
tootmis-	doc_491521501770_item	3575077	et	4	main
kui	doc_491521501770_item	3575079	et	3	main
talupere	doc_491521501770_item	3575082	et	4	main
liikmete	doc_491521501770_item	3575083	et	3	main
vahel	doc_491521501770_item	3575084	et	4	main
mõnikord	doc_491521501770_item	3575090	et	3	main
tegevuse	doc_491521501770_item	3575093	et	4	main
õde	doc_491521501770_item	3575111	et	4	main
perekonnad	doc_491521501770_item	3575121	et	4	main
vendade-õdede	doc_491521501770_item	3575122	et	3	main
peale	doc_491521501770_item	3575132	et	4	main
või	doc_491521501770_item	3575139	et	4	main
need	doc_491521501770_item	3575142	et	3	main
sulased	doc_491521501770_item	3575144	et	3	main
peredes	doc_491521501770_item	3575147	et	3	main
kindel	doc_491521501770_item	3575149	et	3	main
mehed	doc_491521501770_item	3575151	et	3	main
hobuste	doc_491521501770_item	3575159	et	4	main
toitu	doc_491521501770_item	3575164	et	4	main
lugemist	doc_491521501770_item	3575178	et	4	main
mehed	doc_491521501770_item	3575191	et	3	main
ja	doc_491521501770_item	3575192	et	3	main
pere	doc_491521501770_item	3575212	et	4	main
töödes	doc_491521501770_item	3575213	et	3	main
osalema	doc_491521501770_item	3575214	et	3	main
laste	doc_491521501770_item	3575217	et	4	main
teenijatüdrukuid	doc_491521501770_item	3575240	et	4	main
palgati	doc_491521501770_item	3575241	et	3	main
teised	doc_491521501770_item	3575253	et	4	main
tihti	doc_491521501770_item	3575256	et	3	main
jne	doc_491521501770_item	3575271	et	4	main
nooremad	doc_491521501770_item	3575283	et	4	main
püsinud	doc_491521501770_item	3575289	et	4	main
tihtipeale	doc_491521501770_item	3575290	et	3	main
oma	doc_491521501770_item	3575296	et	4	main
talu	doc_491521501770_item	3575297	et	4	main
sulaseks	doc_491521501770_item	3575300	et	4	main
vabadikuks	doc_491521501770_item	3575304	et	3	main
kõige	doc_491521501770_item	3575305	et	4	main
püsivamad	doc_491521501770_item	3575306	et	4	main
eesti	doc_491521501770_item	3574769	et	4	main
muutuvas	doc_491521501770_item	3574771	et	4	main
perekonnanimi	doc_491521501770_item	3574776	et	3	main
eesti	doc_491521501770_item	3574786	et	4	main
muutuvas	doc_491521501770_item	3574788	et	4	main
ajas	doc_491521501770_item	3574789	et	4	main
talupere	doc_491521501770_item	3574794	et	4	main
läbi	doc_491521501770_item	3574796	et	4	main
olnud	doc_491521501770_item	3574798	et	4	main
eesti	doc_491521501770_item	3574799	et	4	main
eestluse	doc_491521501770_item	3574802	et	4	main
võrsunud	doc_491521501770_item	3574806	et	4	main
silmapaistvaid	doc_491521501770_item	3574807	et	3	main
üliolulist	doc_491521501770_item	3574817	et	4	main
sotsiaalse	doc_491521501770_item	3574818	et	3	main
tahaksin	doc_491521501770_item	3574823	et	3	main
eesti	doc_491521501770_item	3574825	et	4	main
peret	doc_491521501770_item	3574826	et	3	main
selle	doc_491521501770_item	3574827	et	4	main
liikmete	doc_491521501770_item	3574828	et	3	main
vahelisi	doc_491521501770_item	3574829	et	4	main
suhteid	doc_491521501770_item	3574830	et	3	main
sotsiaalne	doc_491521501770_item	3574840	et	3	main
et	doc_491521501770_item	3574845	et	3	main
ta	doc_491521501770_item	3574846	et	4	main
ei	doc_491521501770_item	3574847	et	4	main
või	doc_491521501770_item	3574848	et	4	main
elada	doc_491521501770_item	3574849	et	3	main
üksinda	doc_491521501770_item	3574850	et	4	main
loodusega	doc_491521501770_item	3574851	et	4	main
on	doc_491521501770_item	3574852	et	4	main
ette	doc_491521501770_item	3574853	et	4	main
määratud	doc_491521501770_item	3574854	et	4	main
et	doc_491521501770_item	3574855	et	3	main
inimesed	doc_491521501770_item	3574856	et	3	main
elaksid	doc_491521501770_item	3574857	et	4	main
peredes	doc_491521501770_item	3574858	et	3	main
et	doc_491521501770_item	3574859	et	3	main
kuuluksid	doc_491521501770_item	3574860	et	4	main
inimrühmadesse	doc_491521501770_item	3574862	et	3	main
mingitesse	doc_491521501770_item	3574861	et	3	main
see	doc_491521501770_item	3574863	et	3	main
on	doc_491521501770_item	3574864	et	4	main
tema	doc_491521501770_item	3574865	et	4	main
on	doc_491521501770_item	3574880	et	4	main
siit	doc_491521501770_item	3574884	et	3	main
edasiseks	doc_491521501770_item	3574890	et	4	main
arvamusi	doc_491521501770_item	3574893	et	3	main
nii	doc_491521501770_item	3574895	et	3	main
kui	doc_491521501770_item	3574897	et	3	main
kes	doc_491521501770_item	3574907	et	4	main
olid	doc_491521501770_item	3574908	et	4	main
nüüd	doc_491521501770_item	3574934	et	4	main
ühest	doc_491521501770_item	3574954	et	4	main
lesk	doc_491521501770_item	3574961	et	3	main
peale	doc_491521501770_item	3574965	et	4	main
ja	doc_491521501770_item	3574970	et	3	main
haris	doc_491521501770_item	3574983	et	3	main
ja	doc_491521501770_item	3574984	et	3	main
mille	doc_491521501770_item	3574985	et	3	main
eest	doc_491521501770_item	3574986	et	4	main
vajadus	doc_491521501770_item	3574867	et	3	main
peab	doc_491521501770_item	3574869	et	4	main
tema	doc_491521501770_item	3574881	et	4	main
ta	doc_491521501770_item	3574885	et	4	main
välja	doc_491521501770_item	3574887	et	4	main
arusaamu	doc_491521501770_item	3574894	et	3	main
elust	doc_491521501770_item	3574896	et	3	main
ka	doc_491521501770_item	3574898	et	3	main
inimene	doc_491521501770_item	3574900	et	3	main
teadma	doc_491521501770_item	3574902	et	3	main
ta	doc_491521501770_item	3574904	et	4	main
on	doc_491521501770_item	3574905	et	4	main
ja	doc_491521501770_item	3574906	et	3	main
mis	doc_491521501770_item	3574911	et	4	main
tundma	doc_491521501770_item	3574916	et	3	main
oma	doc_491521501770_item	3574917	et	4	main
rahvuse	doc_491521501770_item	3574918	et	3	main
kultuuri	doc_491521501770_item	3574919	et	4	main
ja	doc_491521501770_item	3574920	et	3	main
seda	doc_491521501770_item	3574921	et	3	main
kuidas	doc_491521501770_item	3574922	et	3	main
elasid	doc_491521501770_item	3574923	et	4	main
ta	doc_491521501770_item	3574924	et	4	main
esivanemad	doc_491521501770_item	3574925	et	4	main
tänapäeva	doc_491521501770_item	3574926	et	4	main
perekond	doc_491521501770_item	3574927	et	3	main
on	doc_491521501770_item	3574928	et	4	main
tavaliselt	doc_491521501770_item	3574929	et	4	main
abielupaar	doc_491521501770_item	3574930	et	4	main
koos	doc_491521501770_item	3574931	et	4	main
lastega	doc_491521501770_item	3574932	et	3	main
vaatlen	doc_491521501770_item	3574933	et	3	main
peab	doc_491521501770_item	3574901	et	4	main
kes	doc_491521501770_item	3574903	et	4	main
esivanemad	doc_491521501770_item	3574910	et	4	main
lähemalt	doc_491521501770_item	3574935	et	4	main
kuidas	doc_491521501770_item	3574936	et	3	main
elasid	doc_491521501770_item	3574937	et	4	main
vanasti	doc_491521501770_item	3574938	et	3	main
ja	doc_491521501770_item	3574939	et	3	main
milliseid	doc_491521501770_item	3574940	et	3	main
eesti	doc_491521501770_item	3574943	et	4	main
mis	doc_491521501770_item	3574952	et	4	main
koosnesid	doc_491521501770_item	3574953	et	4	main
lastega	doc_491521501770_item	3574958	et	3	main
laienenud	doc_491521501770_item	3574962	et	4	main
kuhu	doc_491521501770_item	3574964	et	3	main
perekonna	doc_491521501770_item	3574966	et	4	main
liitpered	doc_491521501770_item	3574971	et	3	main
teatav	doc_491521501770_item	3574978	et	4	main
maavaldus	doc_491521501770_item	3574979	et	3	main
talu	doc_491521501770_item	3574980	et	4	main
mida	doc_491521501770_item	3574981	et	4	main
ta	doc_491521501770_item	3574987	et	4	main
saadi	doc_491521501770_item	3574997	et	4	main
vajalikud	doc_491521501770_item	3574999	et	3	main
talus	doc_491521501770_item	3575008	et	4	main
tööriistadest	doc_491521501770_item	3575015	et	3	main
tarbeesemetest	doc_491521501770_item	3575017	et	3	main
toodangust	doc_491521501770_item	3575020	et	3	main
et	doc_491521501770_item	3575023	et	3	main
muretseda	doc_491521501770_item	3575024	et	3	main
seadusi	doc_491521501770_item	3575026	et	3	main
ise	doc_491521501770_item	3575028	et	4	main
toota	doc_491521501770_item	3575029	et	3	main
tarbimisüksus	doc_491521501770_item	3575035	et	3	main
ära	doc_491521501770_item	3575038	et	4	main
lastele	doc_491521501770_item	3575066	et	4	main
selgeks	doc_491521501770_item	3575069	et	3	main
talupere	doc_491521501770_item	3575072	et	4	main
nii	doc_491521501770_item	3575076	et	3	main
ka	doc_491521501770_item	3575080	et	3	main
kasvatusüksus	doc_491521501770_item	3575081	et	3	main
teised	doc_491521501770_item	3575102	et	4	main
onu	doc_491521501770_item	3575112	et	4	main
tädi	doc_491521501770_item	3575113	et	4	main
isa	doc_491521501770_item	3575124	et	4	main
kaugeid	doc_491521501770_item	3575140	et	3	main
olid	doc_491521501770_item	3575143	et	4	main
tööjaotus	doc_491521501770_item	3575150	et	4	main
veotöid	doc_491521501770_item	3575157	et	3	main
eest	doc_491521501770_item	3575160	et	4	main
perele	doc_491521501770_item	3575163	et	3	main
võisid	doc_491521501770_item	3574945	et	4	main
perekonnast	doc_491521501770_item	3574955	et	4	main
mees-naine	doc_491521501770_item	3574956	et	3	main
mees-naine-lapsed	doc_491521501770_item	3574957	et	3	main
või	doc_491521501770_item	3574959	et	4	main
mõni	doc_491521501770_item	3574968	et	3	main
maksma	doc_491521501770_item	3574989	et	3	main
mõisale	doc_491521501770_item	3574990	et	3	main
renti	doc_491521501770_item	3574991	et	4	main
ja	doc_491521501770_item	3574992	et	3	main
tegema	doc_491521501770_item	3574993	et	3	main
toiduained	doc_491521501770_item	3575000	et	3	main
tooraine	doc_491521501770_item	3575002	et	4	main
ja	doc_491521501770_item	3575016	et	3	main
osa	doc_491521501770_item	3575018	et	4	main
müügiks	doc_491521501770_item	3575022	et	3	main
mida	doc_491521501770_item	3575027	et	4	main
kus	doc_491521501770_item	3575036	et	3	main
mida	doc_491521501770_item	3575042	et	4	main
talus	doc_491521501770_item	3575043	et	4	main
toodeti	doc_491521501770_item	3575044	et	3	main
taluperes	doc_491521501770_item	3575045	et	3	main
sündis	doc_491521501770_item	3575046	et	3	main
virgus	doc_491521501770_item	3575047	et	4	main
ja	doc_491521501770_item	3575048	et	3	main
kasvas	doc_491521501770_item	3575049	et	3	main
uus	doc_491521501770_item	3575050	et	3	main
põlvkond	doc_491521501770_item	3575051	et	3	main
lapsed	doc_491521501770_item	3575052	et	3	main
omandasid	doc_491521501770_item	3575053	et	4	main
vanemate	doc_491521501770_item	3575054	et	4	main
juhendamisel	doc_491521501770_item	3575055	et	4	main
talus	doc_491521501770_item	3575056	et	4	main
vajalikke	doc_491521501770_item	3575057	et	3	main
töökogemusi	doc_491521501770_item	3575058	et	3	main
18	doc_491521501770_item	3575059	et	2	main
sajandi	doc_491521501770_item	3575060	et	3	main
teisest	doc_491521501770_item	3575061	et	4	main
poolest	doc_491521501770_item	3575062	et	4	main
peale	doc_491521501770_item	3575063	et	4	main
õpetati	doc_491521501770_item	3575064	et	3	main
kodus	doc_491521501770_item	3575065	et	4	main
tegu	doc_491521501770_item	3574994	et	4	main
valmistati	doc_491521501770_item	3575009	et	4	main
nagu	doc_491521501770_item	3575010	et	3	main
suurem	doc_491521501770_item	3575012	et	4	main
osa	doc_491521501770_item	3575013	et	4	main
talu	doc_491521501770_item	3575019	et	4	main
läks	doc_491521501770_item	3575021	et	3	main
vajalikke	doc_491521501770_item	3575025	et	3	main
talupere	doc_491521501770_item	3575032	et	4	main
oli	doc_491521501770_item	3575033	et	3	main
ka	doc_491521501770_item	3575034	et	3	main
ka	doc_491521501770_item	3575067	et	3	main
niisiis	doc_491521501770_item	3575070	et	3	main
oli	doc_491521501770_item	3575071	et	3	main
tarbimis-	doc_491521501770_item	3575078	et	4	main
või	doc_491521501770_item	3575087	et	4	main
alluvussuhted	doc_491521501770_item	3575088	et	3	main
mis	doc_491521501770_item	3575089	et	4	main
sugulased	doc_491521501770_item	3575103	et	3	main
või	doc_491521501770_item	3575106	et	4	main
siis	doc_491521501770_item	3575115	et	3	main
koguni	doc_491521501770_item	3575116	et	4	main
perekond	doc_491521501770_item	3575125	et	3	main
pidid	doc_491521501770_item	3575126	et	4	main
neile	doc_491521501770_item	3575127	et	4	main
alluma	doc_491521501770_item	3575128	et	3	main
talutöödes	doc_491521501770_item	3575129	et	3	main
ja	doc_491521501770_item	3575130	et	3	main
toimingutes	doc_491521501770_item	3575131	et	3	main
teenijatüdrukud	doc_491521501770_item	3575146	et	3	main
valitses	doc_491521501770_item	3575148	et	3	main
töötasid	doc_491521501770_item	3575152	et	4	main
põllul	doc_491521501770_item	3575153	et	3	main
tegid	doc_491521501770_item	3575154	et	4	main
hoolitsesid	doc_491521501770_item	3575158	et	4	main
valmistasid	doc_491521501770_item	3575162	et	4	main
ja	doc_491521501770_item	3575165	et	3	main
kariloomi	doc_491521501770_item	3575168	et	4	main
ja	doc_491521501770_item	3575169	et	3	main
lastega	doc_491521501770_item	3575171	et	3	main
18	doc_491521501770_item	3575173	et	2	main
sajandi	doc_491521501770_item	3575174	et	3	main
lõpust	doc_491521501770_item	3575175	et	4	main
alates	doc_491521501770_item	3575176	et	3	main
sajandi	doc_491521501770_item	3575181	et	3	main
teisel	doc_491521501770_item	3575182	et	4	main
tihti	doc_491521501770_item	3575184	et	3	main
hakkasid	doc_491521501770_item	3575205	et	4	main
varakult	doc_491521501770_item	3575207	et	4	main
6-7-aastaselt	doc_491521501770_item	3575208	et	4	main
loomi	doc_491521501770_item	3575221	et	4	main
hiljem	doc_491521501770_item	3575222	et	3	main
koosseisus	doc_491521501770_item	3575232	et	4	main
vähem	doc_491521501770_item	3575236	et	4	main
püsivad	doc_491521501770_item	3575237	et	4	main
sulaseid	doc_491521501770_item	3575238	et	3	main
ja	doc_491521501770_item	3575239	et	3	main
ainult	doc_491521501770_item	3575245	et	4	main
suveks	doc_491521501770_item	3575246	et	3	main
ka	doc_491521501770_item	3575247	et	3	main
suurperes	doc_491521501770_item	3575248	et	3	main
peremehe	doc_491521501770_item	3575249	et	3	main
perekonnaga	doc_491521501770_item	3575250	et	4	main
kõrvu	doc_491521501770_item	3575251	et	4	main
laadi	doc_491521501770_item	3575258	et	4	main
võisid	doc_491521501770_item	3575260	et	4	main
oma	doc_491521501770_item	3575265	et	4	main
lugemine	doc_491521501770_item	3575068	et	4	main
sajandini	doc_491521501770_item	3575075	et	3	main
ühise	doc_491521501770_item	3575092	et	3	main
kooskõlastamine	doc_491521501770_item	3575094	et	3	main
peamiselt	doc_491521501770_item	3575098	et	4	main
naistetööd	doc_491521501770_item	3575099	et	4	main
perenaisele	doc_491521501770_item	3575100	et	3	main
ning	doc_491521501770_item	3575101	et	3	main
ema	doc_491521501770_item	3575105	et	4	main
isa	doc_491521501770_item	3575107	et	4	main
mõni	doc_491521501770_item	3575108	et	3	main
vend	doc_491521501770_item	3575109	et	3	main
või	doc_491521501770_item	3575110	et	4	main
või	doc_491521501770_item	3575114	et	4	main
perekonnad	doc_491521501770_item	3575123	et	4	main
sugulaste	doc_491521501770_item	3575133	et	4	main
elas	doc_491521501770_item	3575134	et	3	main
talus	doc_491521501770_item	3575135	et	4	main
tihtipeale	doc_491521501770_item	3575136	et	3	main
ka	doc_491521501770_item	3575137	et	3	main
ja	doc_491521501770_item	3575145	et	3	main
ja	doc_491521501770_item	3575156	et	3	main
naised	doc_491521501770_item	3575161	et	3	main
talitasid	doc_491521501770_item	3575167	et	4	main
tegelesid	doc_491521501770_item	3575170	et	4	main
sealhulgas	doc_491521501770_item	3575172	et	3	main
19	doc_491521501770_item	3575180	et	2	main
poolel	doc_491521501770_item	3575183	et	4	main
heinamaal	doc_491521501770_item	3575187	et	4	main
ja	doc_491521501770_item	3575188	et	3	main
viljakoristamisel	doc_491521501770_item	3575189	et	3	main
isegi	doc_491521501770_item	3575210	et	4	main
varem	doc_491521501770_item	3575211	et	4	main
olid	doc_491521501770_item	3575233	et	4	main
kõige	doc_491521501770_item	3575235	et	4	main
või	doc_491521501770_item	3575244	et	4	main
elavad	doc_491521501770_item	3575252	et	4	main
ajutist	doc_491521501770_item	3575257	et	3	main
nad	doc_491521501770_item	3575259	et	3	main
minna	doc_491521501770_item	3575261	et	3	main
teise	doc_491521501770_item	3575262	et	4	main
tallu	doc_491521501770_item	3575263	et	3	main
seada	doc_491521501770_item	3575264	et	3	main
minna	doc_491521501770_item	3575269	et	3	main
varem	doc_491521501770_item	3575275	et	4	main
või	doc_491521501770_item	3575285	et	4	main
mõni	doc_491521501770_item	3575293	et	3	main
teine	doc_491521501770_item	3575298	et	3	main
pere	doc_491521501770_item	3575307	et	4	main
liikmed	doc_491521501770_item	3575308	et	3	main
olid	doc_491521501770_item	3575309	et	4	main
pärija	doc_491521501770_item	3575316	et	4	main
harilikult	doc_491521501770_item	3575317	et	4	main
hulka	doc_491521501770_item	3575323	et	4	main
sõltus	doc_491521501770_item	3575330	et	4	main
ja	doc_491521501770_item	3575334	et	3	main
olid	doc_491521501770_item	3575339	et	4	main
võimalus	doc_491521501770_item	3575342	et	3	main
lahkusid	doc_491521501770_item	3575351	et	4	main
meessoost	doc_491521501770_item	3575354	et	4	main
kergemini	doc_491521501770_item	3575357	et	4	main
õpetasid	doc_491521501770_item	3575177	et	4	main
ka	doc_491521501770_item	3575185	et	3	main
kirjutamist	doc_491521501770_item	3575186	et	4	main
koos	doc_491521501770_item	3575194	et	4	main
kaluriperedes	doc_491521501770_item	3575196	et	3	main
jäi	doc_491521501770_item	3575197	et	3	main
põlluharimine	doc_491521501770_item	3575198	et	3	main
kalastushooaegadel	doc_491521501770_item	3575199	et	4	main
osalt	doc_491521501770_item	3575200	et	4	main
ka	doc_491521501770_item	3575201	et	3	main
naiste	doc_491521501770_item	3575202	et	3	main
riideid	doc_491521501770_item	3575166	et	3	main
ja	doc_491521501770_item	3575179	et	3	main
tegid	doc_491521501770_item	3575190	et	4	main
naised	doc_491521501770_item	3575193	et	3	main
tööd	doc_491521501770_item	3575195	et	4	main
õlgadele	doc_491521501770_item	3575203	et	3	main
nooremate	doc_491521501770_item	3575216	et	4	main
järele	doc_491521501770_item	3575218	et	4	main
ja	doc_491521501770_item	3575219	et	3	main
karjatasid	doc_491521501770_item	3575220	et	4	main
ja	doc_491521501770_item	3575228	et	3	main
tüdrukud	doc_491521501770_item	3575229	et	3	main
naistetöid	doc_491521501770_item	3575230	et	3	main
talupere	doc_491521501770_item	3575231	et	4	main
harilikult	doc_491521501770_item	3575242	et	4	main
perekonnad	doc_491521501770_item	3575254	et	4	main
hiljem	doc_491521501770_item	3575277	et	3	main
ja	doc_491521501770_item	3575279	et	3	main
lahkusid	doc_491521501770_item	3575280	et	4	main
talust	doc_491521501770_item	3575281	et	3	main
ka	doc_491521501770_item	3575282	et	3	main
sai	doc_491521501770_item	3575295	et	4	main
kuuluvad	doc_491521501770_item	3575324	et	4	main
inimesed	doc_491521501770_item	3575325	et	3	main
suuresti	doc_491521501770_item	3575331	et	4	main
sotsiaalsest	doc_491521501770_item	3575335	et	3	main
olud	doc_491521501770_item	3575338	et	3	main
ja	doc_491521501770_item	3575341	et	3	main
uut	doc_491521501770_item	3575343	et	3	main
suur	doc_491521501770_item	3575346	et	3	main
pere	doc_491521501770_item	3575352	et	4	main
talust	doc_491521501770_item	3575356	et	3	main
olude	doc_491521501770_item	3575359	et	3	main
koos	doc_491521501770_item	3575397	et	4	main
sajandi	doc_491521501770_item	3575405	et	3	main
linna	doc_491521501770_item	3575412	et	4	main
selle	doc_491521501770_item	3575416	et	4	main
tagajärjel	doc_491521501770_item	3575417	et	3	main
vähenes	doc_491521501770_item	3575418	et	3	main
öelda	doc_491521501770_item	3575423	et	4	main
talupered	doc_491521501770_item	3575427	et	3	main
lihtpered	doc_491521501770_item	3575429	et	3	main
varasemad	doc_491521501770_item	3575431	et	4	main
kohal	doc_491521501770_item	3575433	et	4	main
nõukogude	doc_491521501770_item	3575441	et	3	main
kui	doc_491521501770_item	3575443	et	3	main
talumajandid	doc_491521501770_item	3575445	et	3	main
ja	doc_491521501770_item	3575447	et	3	main
talunikud	doc_491521501770_item	3575453	et	3	main
ja	doc_491521501770_item	3575455	et	3	main
töölisperedeks	doc_491521501770_item	3575457	et	3	main
lapsed	doc_491521501770_item	3575472	et	3	main
asuvad	doc_491521501770_item	3575473	et	4	main
need	doc_491521501770_item	3575483	et	3	main
valdavalt	doc_491521501770_item	3575485	et	4	main
palju	doc_491521501770_item	3575491	et	4	main
vähem	doc_491521501770_item	3575499	et	4	main
mõned	doc_491521501770_item	3575500	et	3	main
meditsiini	doc_491521501770_item	3575507	et	4	main
tingimustes	doc_491521501770_item	3575508	et	3	main
juba	doc_491521501770_item	3575518	et	3	main
ilma	doc_491521501770_item	3575522	et	4	main
jaoks	doc_491521501770_item	3575571	et	4	main
lapsi	doc_491521501770_item	3575577	et	4	main
siis	doc_491521501770_item	3575579	et	3	main
vanasti	doc_491521501770_item	3575584	et	3	main
see	doc_491521501770_item	3575586	et	3	main
täiesti	doc_491521501770_item	3575603	et	3	main
seoses	doc_491521501770_item	3575605	et	4	main
teiste	doc_491521501770_item	3575606	et	4	main
ei	doc_491521501770_item	3575614	et	4	main
rahvas	doc_491521501770_item	3575620	et	4	main
nende	doc_491521501770_item	3575622	et	4	main
ülesandeks	doc_491521501770_item	3575623	et	4	main
kultuuri	doc_491521501770_item	3575630	et	4	main
ja	doc_491521501770_item	3575631	et	3	main
eest	doc_491521501770_item	3575637	et	4	main
teadvustaksid	doc_491521501770_item	3575649	et	4	main
esile	doc_491521501770_item	3575658	et	3	main
eraldi	doc_491521501770_item	3575668	et	4	main
suhtlevad	doc_491521501770_item	3575671	et	4	main
lapsed	doc_491521501770_item	3575204	et	3	main
juba	doc_491521501770_item	3575206	et	3	main
vahel	doc_491521501770_item	3575209	et	4	main
vaatasid	doc_491521501770_item	3575215	et	4	main
hakkasid	doc_491521501770_item	3575223	et	4	main
poisid	doc_491521501770_item	3575224	et	4	main
järk-järgult	doc_491521501770_item	3575225	et	3	main
tegema	doc_491521501770_item	3575226	et	3	main
meeste-	doc_491521501770_item	3575227	et	4	main
palgalised	doc_491521501770_item	3575234	et	4	main
aastaks	doc_491521501770_item	3575243	et	4	main
olid	doc_491521501770_item	3575255	et	4	main
talu	doc_491521501770_item	3575266	et	4	main
mõisa	doc_491521501770_item	3575268	et	3	main
vabadikuks	doc_491521501770_item	3575270	et	3	main
peremehe	doc_491521501770_item	3575272	et	3	main
tütred	doc_491521501770_item	3575273	et	3	main
või	doc_491521501770_item	3575276	et	4	main
nooremad	doc_491521501770_item	3575286	et	4	main
vennad	doc_491521501770_item	3575287	et	3	main
ei	doc_491521501770_item	3575288	et	4	main
neist	doc_491521501770_item	3575294	et	4	main
läks	doc_491521501770_item	3575299	et	3	main
mõisameheks	doc_491521501770_item	3575302	et	3	main
peremees	doc_491521501770_item	3575310	et	4	main
ja	doc_491521501770_item	3575311	et	3	main
perenaine	doc_491521501770_item	3575312	et	3	main
ning	doc_491521501770_item	3575313	et	3	main
talu	doc_491521501770_item	3575314	et	4	main
talus	doc_491521501770_item	3575326	et	4	main
kauemat	doc_491521501770_item	3575327	et	3	main
üldisest	doc_491521501770_item	3575332	et	3	main
lahedamad	doc_491521501770_item	3575340	et	4	main
talu	doc_491521501770_item	3575344	et	4	main
seada	doc_491521501770_item	3575345	et	3	main
nagu	doc_491521501770_item	3575347	et	3	main
nt	doc_491521501770_item	3575348	et	4	main
raskemate	doc_491521501770_item	3575358	et	4	main
alanud	doc_491521501770_item	3575385	et	4	main
põhjustas	doc_491521501770_item	3575388	et	3	main
liitperede	doc_491521501770_item	3575391	et	3	main
kasvu	doc_491521501770_item	3575393	et	4	main
inimestel	doc_491521501770_item	3575394	et	3	main
tuli	doc_491521501770_item	3575395	et	4	main
elada	doc_491521501770_item	3575396	et	3	main
polnud	doc_491521501770_item	3575402	et	3	main
teisel	doc_491521501770_item	3575406	et	4	main
talupojad	doc_491521501770_item	3575408	et	4	main
said	doc_491521501770_item	3575409	et	4	main
rännata	doc_491521501770_item	3575414	et	4	main
venemaale	doc_491521501770_item	3575415	et	4	main
eestis	doc_491521501770_item	3575425	et	3	main
olid	doc_491521501770_item	3575426	et	4	main
valdavalt	doc_491521501770_item	3575428	et	4	main
ning	doc_491521501770_item	3575430	et	3	main
tähtsal	doc_491521501770_item	3575432	et	3	main
kadunud	doc_491521501770_item	3575440	et	4	main
põllumajandus	doc_491521501770_item	3575448	et	3	main
vähesed	doc_491521501770_item	3575461	et	3	main
pered	doc_491521501770_item	3575462	et	3	main
nende	doc_491521501770_item	3575471	et	4	main
lapsi	doc_491521501770_item	3575492	et	4	main
siis	doc_491521501770_item	3575493	et	3	main
praegu	doc_491521501770_item	3575494	et	3	main
naised	doc_491521501770_item	3575495	et	3	main
varem	doc_491521501770_item	3575505	et	4	main
kõrge	doc_491521501770_item	3575513	et	4	main
ka	doc_491521501770_item	3575514	et	3	main
suhe	doc_491521501770_item	3575515	et	3	main
peret	doc_491521501770_item	3575521	et	3	main
lasteta	doc_491521501770_item	3575523	et	3	main
asuda	doc_491521501770_item	3575267	et	3	main
enamasti	doc_491521501770_item	3575274	et	4	main
abiellusid	doc_491521501770_item	3575278	et	4	main
pojad	doc_491521501770_item	3575284	et	4	main
talus	doc_491521501770_item	3575291	et	4	main
kaua	doc_491521501770_item	3575292	et	3	main
või	doc_491521501770_item	3575301	et	4	main
kolmas	doc_491521501770_item	3575303	et	3	main
vanem	doc_491521501770_item	3575318	et	4	main
poeg	doc_491521501770_item	3575319	et	3	main
see	doc_491521501770_item	3575320	et	3	main
kas	doc_491521501770_item	3575321	et	3	main
pererahva	doc_491521501770_item	3575322	et	3	main
püsisid	doc_491521501770_item	3575329	et	4	main
majanduslikust	doc_491521501770_item	3575333	et	4	main
kui	doc_491521501770_item	3575337	et	3	main
pärast	doc_491521501770_item	3575349	et	4	main
põhjasõda	doc_491521501770_item	3575350	et	4	main
korral	doc_491521501770_item	3575360	et	4	main
nt	doc_491521501770_item	3575361	et	4	main
19	doc_491521501770_item	3575362	et	2	main
sajandi	doc_491521501770_item	3575363	et	3	main
algupoolel	doc_491521501770_item	3575364	et	3	main
olid	doc_491521501770_item	3575365	et	4	main
inimesed	doc_491521501770_item	3575366	et	3	main
pärisorjusest	doc_491521501770_item	3575373	et	4	main
vabastamist	doc_491521501770_item	3575374	et	4	main
jätkunud	doc_491521501770_item	3575375	et	4	main
teoorjuse	doc_491521501770_item	3575376	et	3	main
oludes	doc_491521501770_item	3575377	et	3	main
süvenes	doc_491521501770_item	3575378	et	3	main
kogu	doc_491521501770_item	3575379	et	4	main
eestis	doc_491521501770_item	3575380	et	3	main
talurahva	doc_491521501770_item	3575381	et	3	main
olukorra	doc_491521501770_item	3575382	et	3	main
juba	doc_491521501770_item	3575383	et	3	main
varem	doc_491521501770_item	3575384	et	4	main
mis	doc_491521501770_item	3575387	et	4	main
struktuuris	doc_491521501770_item	3575390	et	3	main
sest	doc_491521501770_item	3575398	et	4	main
omaette	doc_491521501770_item	3575399	et	3	main
võimalik	doc_491521501770_item	3575403	et	3	main
suurus	doc_491521501770_item	3575420	et	4	main
siitpeale	doc_491521501770_item	3575421	et	3	main
senised	doc_491521501770_item	3575452	et	3	main
talupered	doc_491521501770_item	3575456	et	3	main
need	doc_491521501770_item	3575460	et	3	main
peamiselt	doc_491521501770_item	3575467	et	4	main
inimestest	doc_491521501770_item	3575469	et	3	main
linna	doc_491521501770_item	3575474	et	4	main
meie	doc_491521501770_item	3575476	et	4	main
aja	doc_491521501770_item	3575477	et	4	main
pered	doc_491521501770_item	3575478	et	3	main
on	doc_491521501770_item	3575479	et	4	main
juba	doc_491521501770_item	3575480	et	3	main
linnapered	doc_491521501770_item	3575481	et	3	main
sünnitavad	doc_491521501770_item	3575496	et	4	main
isegi	doc_491521501770_item	3575501	et	4	main
soovi	doc_491521501770_item	3575503	et	4	main
lapsi	doc_491521501770_item	3575504	et	4	main
on	doc_491521501770_item	3575517	et	4	main
teine	doc_491521501770_item	3575519	et	3	main
ei	doc_491521501770_item	3575525	et	4	main
soovivad	doc_491521501770_item	3575567	et	4	main
ainult	doc_491521501770_item	3575569	et	4	main
oska	doc_491521501770_item	3575592	et	4	main
on	doc_491521501770_item	3575602	et	4	main
asjaolu	doc_491521501770_item	3575612	et	4	main
mida	doc_491521501770_item	3575613	et	4	main
on	doc_491521501770_item	3575624	et	4	main
oma	doc_491521501770_item	3575625	et	4	main
rahva	doc_491521501770_item	3575626	et	3	main
nii	doc_491521501770_item	3575638	et	3	main
ka	doc_491521501770_item	3575642	et	3	main
oluline	doc_491521501770_item	3575645	et	4	main
linnades	doc_491521501770_item	3575667	et	3	main
pidamine	doc_491521501770_item	3575681	et	4	main
elulaadiga	doc_491521501770_item	3575686	et	3	main
tulevane	doc_491521501770_item	3575315	et	3	main
aega	doc_491521501770_item	3575328	et	4	main
olukorrast	doc_491521501770_item	3575336	et	4	main
nooremad	doc_491521501770_item	3575353	et	4	main
liikmed	doc_491521501770_item	3575355	et	3	main
sunnitud	doc_491521501770_item	3575367	et	4	main
koos	doc_491521501770_item	3575369	et	4	main
edasi	doc_491521501770_item	3575370	et	3	main
elama	doc_491521501770_item	3575371	et	3	main
osa	doc_491521501770_item	3575392	et	4	main
talu	doc_491521501770_item	3575400	et	4	main
seada	doc_491521501770_item	3575401	et	3	main
19	doc_491521501770_item	3575404	et	2	main
poolel	doc_491521501770_item	3575407	et	4	main
ja	doc_491521501770_item	3575413	et	3	main
võib	doc_491521501770_item	3575422	et	3	main
ajal	doc_491521501770_item	3575442	et	4	main
iseseisvad	doc_491521501770_item	3575444	et	3	main
likvideeriti	doc_491521501770_item	3575446	et	3	main
muutusid	doc_491521501770_item	3575451	et	4	main
praegusel	doc_491521501770_item	3575458	et	3	main
mis	doc_491521501770_item	3575463	et	4	main
ja	doc_491521501770_item	3575482	et	3	main
lihtpered	doc_491521501770_item	3575486	et	3	main
kui	doc_491521501770_item	3575487	et	3	main
vanasti	doc_491521501770_item	3575488	et	3	main
naised	doc_491521501770_item	3575489	et	3	main
sünnitasid	doc_491521501770_item	3575490	et	4	main
aina	doc_491521501770_item	3575498	et	4	main
ei	doc_491521501770_item	3575502	et	4	main
laste	doc_491521501770_item	3575509	et	4	main
surelikkus	doc_491521501770_item	3575510	et	4	main
oli	doc_491521501770_item	3575511	et	3	main
väga	doc_491521501770_item	3575512	et	3	main
vanasti	doc_491521501770_item	3575520	et	3	main
üldsegi	doc_491521501770_item	3575524	et	3	main
kujutletud	doc_491521501770_item	3575526	et	4	main
lapsed	doc_491521501770_item	3575527	et	3	main
olid	doc_491521501770_item	3575528	et	4	main
need	doc_491521501770_item	3575529	et	3	main
ja	doc_491521501770_item	3575576	et	3	main
muretseda	doc_491521501770_item	3575578	et	3	main
mitte	doc_491521501770_item	3575580	et	3	main
varakult	doc_491521501770_item	3575582	et	4	main
kui	doc_491521501770_item	3575583	et	3	main
on	doc_491521501770_item	3575585	et	4	main
öelda	doc_491521501770_item	3575593	et	4	main
võib	doc_491521501770_item	3575594	et	3	main
lihtsalt	doc_491521501770_item	3575595	et	4	main
on	doc_491521501770_item	3575610	et	4	main
üks	doc_491521501770_item	3575611	et	3	main
on	doc_491521501770_item	3575618	et	4	main
jääda	doc_491521501770_item	3575632	et	4	main
eestlasteks	doc_491521501770_item	3575633	et	4	main
nad	doc_491521501770_item	3575634	et	3	main
oma	doc_491521501770_item	3575639	et	4	main
kui	doc_491521501770_item	3575641	et	3	main
lapselaste	doc_491521501770_item	3575643	et	4	main
ees	doc_491521501770_item	3575644	et	4	main
elavad	doc_491521501770_item	3575666	et	4	main
üksteisega	doc_491521501770_item	3575672	et	3	main
näiteks	doc_491521501770_item	3575688	et	4	main
pühapäeval	doc_491521501770_item	3575690	et	3	main
ei	doc_491521501770_item	3575692	et	4	main
töötanud	doc_491521501770_item	3575693	et	4	main
ja	doc_491521501770_item	3575694	et	3	main
inimesed	doc_491521501770_item	3575695	et	3	main
kultuur	doc_491521501770_item	3575706	et	3	main
oma	doc_491521501770_item	3575732	et	4	main
lastega	doc_491521501770_item	3575733	et	3	main
lapsed	doc_491521501770_item	3575734	et	3	main
töökogemusi	doc_491521501770_item	3575743	et	3	main
ühtse	doc_491521501770_item	3575768	et	3	main
jätku	doc_491521501770_item	3575780	et	4	main
teadmiste	doc_491521501770_item	3575787	et	4	main
edasiandmiseks	doc_491521501770_item	3575788	et	3	main
ka	doc_491521501770_item	3575789	et	3	main
elulaad	doc_491521501770_item	3575790	et	3	main
mis	doc_491521501770_item	3575794	et	4	main
soodusta	doc_491521501770_item	3575796	et	4	main
arendamist	doc_491521501770_item	3575798	et	4	main
kogu	doc_491521501770_item	3575807	et	4	main
talus	doc_491521501770_item	3575368	et	4	main
pärast	doc_491521501770_item	3575372	et	4	main
halvenemine	doc_491521501770_item	3575386	et	4	main
perede	doc_491521501770_item	3575389	et	3	main
õiguse	doc_491521501770_item	3575410	et	4	main
asuda	doc_491521501770_item	3575411	et	3	main
talupere	doc_491521501770_item	3575419	et	4	main
et	doc_491521501770_item	3575424	et	3	main
olnud	doc_491521501770_item	3575434	et	4	main
liit-	doc_491521501770_item	3575435	et	3	main
ehk	doc_491521501770_item	3575436	et	3	main
suurpered	doc_491521501770_item	3575437	et	3	main
olid	doc_491521501770_item	3575438	et	4	main
peaaegu	doc_491521501770_item	3575439	et	3	main
sunniviisiliselt	doc_491521501770_item	3575449	et	4	main
kollektiviseeriti	doc_491521501770_item	3575450	et	3	main
maatöölisteks	doc_491521501770_item	3575454	et	4	main
ajal	doc_491521501770_item	3575459	et	4	main
elavad	doc_491521501770_item	3575464	et	4	main
maal	doc_491521501770_item	3575465	et	4	main
koosnevad	doc_491521501770_item	3575466	et	4	main
vanematest	doc_491521501770_item	3575468	et	4	main
sest	doc_491521501770_item	3575470	et	4	main
elama	doc_491521501770_item	3575475	et	3	main
on	doc_491521501770_item	3575484	et	4	main
lapsi	doc_491521501770_item	3575497	et	4	main
mittearenenud	doc_491521501770_item	3575506	et	4	main
lastesse	doc_491521501770_item	3575516	et	4	main
kellele	doc_491521501770_item	3575530	et	4	main
pärandati	doc_491521501770_item	3575531	et	4	main
kogu	doc_491521501770_item	3575532	et	4	main
oma	doc_491521501770_item	3575533	et	4	main
majapidamine	doc_491521501770_item	3575534	et	3	main
kultuur	doc_491521501770_item	3575535	et	3	main
traditsioonid	doc_491521501770_item	3575536	et	3	main
ja	doc_491521501770_item	3575537	et	3	main
kombed	doc_491521501770_item	3575538	et	3	main
tähtis	doc_491521501770_item	3575539	et	4	main
oli	doc_491521501770_item	3575540	et	3	main
et	doc_491521501770_item	3575541	et	3	main
sünniks	doc_491521501770_item	3575542	et	4	main
poeg	doc_491521501770_item	3575543	et	3	main
keda	doc_491521501770_item	3575544	et	4	main
peeti	doc_491521501770_item	3575545	et	4	main
oma	doc_491521501770_item	3575546	et	4	main
elamise	doc_491521501770_item	3575547	et	4	main
põhiliseks	doc_491521501770_item	3575548	et	3	main
pärijaks	doc_491521501770_item	3575549	et	4	main
praegu	doc_491521501770_item	3575550	et	3	main
laste	doc_491521501770_item	3575551	et	4	main
vanemad	doc_491521501770_item	3575552	et	4	main
seda	doc_491521501770_item	3575553	et	3	main
seisukohta	doc_491521501770_item	3575554	et	4	main
nii	doc_491521501770_item	3575555	et	3	main
tõsiselt	doc_491521501770_item	3575556	et	4	main
ei	doc_491521501770_item	3575557	et	4	main
võta	doc_491521501770_item	3575558	et	4	main
tänapäeva	doc_491521501770_item	3575559	et	4	main
inimestel	doc_491521501770_item	3575560	et	3	main
on	doc_491521501770_item	3575561	et	4	main
juba	doc_491521501770_item	3575562	et	3	main
teised	doc_491521501770_item	3575563	et	4	main
eelistused	doc_491521501770_item	3575564	et	4	main
ees	doc_491521501770_item	3575565	et	4	main
mõned	doc_491521501770_item	3575566	et	3	main
abielluda	doc_491521501770_item	3575575	et	3	main
nii	doc_491521501770_item	3575581	et	3	main
hea	doc_491521501770_item	3575587	et	4	main
või	doc_491521501770_item	3575588	et	4	main
halb	doc_491521501770_item	3575589	et	3	main
ma	doc_491521501770_item	3575590	et	3	main
ei	doc_491521501770_item	3575591	et	4	main
elutingimustega	doc_491521501770_item	3575607	et	3	main
kuid	doc_491521501770_item	3575608	et	4	main
seejuures	doc_491521501770_item	3575609	et	3	main
tohi	doc_491521501770_item	3575615	et	4	main
unustada	doc_491521501770_item	3575616	et	3	main
eestlased	doc_491521501770_item	3575617	et	3	main
ja	doc_491521501770_item	3575621	et	3	main
esindajatena	doc_491521501770_item	3575627	et	4	main
säilitada	doc_491521501770_item	3575628	et	3	main
oma	doc_491521501770_item	3575629	et	4	main
on	doc_491521501770_item	3575646	et	4	main
et	doc_491521501770_item	3575647	et	3	main
nad	doc_491521501770_item	3575648	et	3	main
kerkib	doc_491521501770_item	3575657	et	3	main
küsimus	doc_491521501770_item	3575659	et	4	main
kuidas	doc_491521501770_item	3575660	et	3	main
nendes	doc_491521501770_item	3575661	et	4	main
tingimustes	doc_491521501770_item	3575662	et	3	main
kus	doc_491521501770_item	3575663	et	3	main
enamik	doc_491521501770_item	3575664	et	3	main
eestlasi	doc_491521501770_item	3575665	et	3	main
elada	doc_491521501770_item	3575568	et	3	main
iseenda	doc_491521501770_item	3575570	et	3	main
kui	doc_491521501770_item	3575572	et	3	main
nad	doc_491521501770_item	3575573	et	3	main
otsustavad	doc_491521501770_item	3575574	et	4	main
öelda	doc_491521501770_item	3575596	et	4	main
et	doc_491521501770_item	3575597	et	3	main
inimeste	doc_491521501770_item	3575598	et	3	main
eluviis	doc_491521501770_item	3575599	et	3	main
ja	doc_491521501770_item	3575600	et	3	main
hoiakud	doc_491521501770_item	3575601	et	3	main
muutunud	doc_491521501770_item	3575604	et	4	main
väike	doc_491521501770_item	3575619	et	4	main
vastutavad	doc_491521501770_item	3575635	et	4	main
selle	doc_491521501770_item	3575636	et	4	main
esivanemate	doc_491521501770_item	3575640	et	4	main
seda	doc_491521501770_item	3575650	et	3	main
vastutust	doc_491521501770_item	3575651	et	4	main
ja	doc_491521501770_item	3575652	et	3	main
oleksid	doc_491521501770_item	3575653	et	4	main
võimelised	doc_491521501770_item	3575654	et	4	main
seda	doc_491521501770_item	3575655	et	3	main
täitma	doc_491521501770_item	3575656	et	3	main
korterites	doc_491521501770_item	3575669	et	3	main
vähe	doc_491521501770_item	3575673	et	3	main
see	doc_491521501770_item	3575675	et	3	main
sest	doc_491521501770_item	3575677	et	4	main
vastuolus	doc_491521501770_item	3575683	et	3	main
kui	doc_491521501770_item	3575687	et	3	main
käisid	doc_491521501770_item	3575696	et	4	main
praegu	doc_491521501770_item	3575699	et	3	main
inimesed	doc_491521501770_item	3575701	et	3	main
töötama	doc_491521501770_item	3575703	et	3	main
pidevalt	doc_491521501770_item	3575731	et	4	main
kodustes	doc_491521501770_item	3575738	et	4	main
töödes	doc_491521501770_item	3575739	et	3	main
osalema	doc_491521501770_item	3575740	et	3	main
ja	doc_491521501770_item	3575741	et	3	main
saama	doc_491521501770_item	3575742	et	4	main
kommete	doc_491521501770_item	3575751	et	4	main
järgi	doc_491521501770_item	3575752	et	4	main
mille	doc_491521501770_item	3575753	et	3	main
kaudu	doc_491521501770_item	3575754	et	3	main
nende	doc_491521501770_item	3575755	et	4	main
samastasid	doc_491521501770_item	3575762	et	4	main
sellega	doc_491521501770_item	3575764	et	3	main
tundsid	doc_491521501770_item	3575766	et	4	main
aega	doc_491521501770_item	3575781	et	4	main
on	doc_491521501770_item	3575791	et	4	main
käivad	doc_491521501770_item	3575810	et	4	main
et	doc_491521501770_item	3575818	et	3	main
siit	doc_491521501770_item	3575834	et	3	main
ja	doc_491521501770_item	3575670	et	3	main
on	doc_491521501770_item	3575674	et	4	main
võimalik	doc_491521501770_item	3575676	et	3	main
eesti	doc_491521501770_item	3575678	et	4	main
rahva	doc_491521501770_item	3575679	et	3	main
traditsioonide	doc_491521501770_item	3575680	et	3	main
tänapäeva	doc_491521501770_item	3575685	et	4	main
varem	doc_491521501770_item	3575689	et	4	main
mõned	doc_491521501770_item	3575700	et	3	main
peavad	doc_491521501770_item	3575702	et	4	main
antakse	doc_491521501770_item	3575707	et	3	main
hariduse	doc_491521501770_item	3575709	et	3	main
kaudu	doc_491521501770_item	3575712	et	3	main
nii	doc_491521501770_item	3575713	et	3	main
et	doc_491521501770_item	3575714	et	3	main
praegu	doc_491521501770_item	3575716	et	3	main
kui	doc_491521501770_item	3575715	et	3	main
elulaad	doc_491521501770_item	3575717	et	3	main
ei	doc_491521501770_item	3575718	et	4	main
soodusta	doc_491521501770_item	3575719	et	4	main
rahvakultuuri	doc_491521501770_item	3575720	et	4	main
levikut	doc_491521501770_item	3575721	et	3	main
siis	doc_491521501770_item	3575722	et	3	main
põhikoormus	doc_491521501770_item	3575723	et	3	main
langeb	doc_491521501770_item	3575724	et	3	main
koolile	doc_491521501770_item	3575725	et	4	main
ja	doc_491521501770_item	3575726	et	3	main
on	doc_491521501770_item	3575682	et	4	main
nende	doc_491521501770_item	3575684	et	4	main
kirikus	doc_491521501770_item	3575697	et	3	main
siis	doc_491521501770_item	3575698	et	3	main
ka	doc_491521501770_item	3575704	et	3	main
edasi	doc_491521501770_item	3575708	et	3	main
kasvatuse	doc_491521501770_item	3575711	et	4	main
vanasti	doc_491521501770_item	3575728	et	3	main
vanemad	doc_491521501770_item	3575729	et	4	main
suhtlesid	doc_491521501770_item	3575730	et	4	main
tähistasid	doc_491521501770_item	3575745	et	4	main
tähtpäevi	doc_491521501770_item	3575746	et	4	main
ennast	doc_491521501770_item	3575767	et	4	main
see	doc_491521501770_item	3575772	et	3	main
ja	doc_491521501770_item	3575776	et	3	main
vanematel	doc_491521501770_item	3575778	et	4	main
ei	doc_491521501770_item	3575779	et	4	main
oma	doc_491521501770_item	3575786	et	4	main
ei	doc_491521501770_item	3575795	et	4	main
teadvustamise	doc_491521501770_item	3575797	et	4	main
et	doc_491521501770_item	3575799	et	3	main
meie	doc_491521501770_item	3575800	et	4	main
oleme	doc_491521501770_item	3575801	et	3	main
eestlased	doc_491521501770_item	3575802	et	3	main
aeg	doc_491521501770_item	3575808	et	3	main
kinni	doc_491521501770_item	3575809	et	3	main
aega	doc_491521501770_item	3575822	et	4	main
lapsed	doc_491521501770_item	3575826	et	3	main
aita	doc_491521501770_item	3575828	et	4	main
on	doc_491521501770_item	3575868	et	4	main
roll	doc_491521501770_item	3575871	et	3	main
nende	doc_491521501770_item	3575874	et	4	main
kultuurist	doc_491521501770_item	3575876	et	3	main
tundides	doc_491521501770_item	3575878	et	3	main
selle	doc_491521501770_item	3575883	et	4	main
hea	doc_491521501770_item	3575886	et	4	main
kui	doc_491521501770_item	3575887	et	3	main
nad	doc_491521501770_item	3575888	et	3	main
et	doc_491521501770_item	3575907	et	3	main
osaleksid	doc_491521501770_item	3575908	et	4	main
rahvatoitu	doc_491521501770_item	3575921	et	4	main
ei	doc_491521501770_item	3575934	et	4	main
inimesed	doc_491521501770_item	3575935	et	3	main
võivad	doc_491521501770_item	3575936	et	4	main
märgata	doc_491521501770_item	3575944	et	4	main
et	doc_491521501770_item	3575945	et	3	main
need	doc_491521501770_item	3575946	et	3	main
erinevate	doc_491521501770_item	3575958	et	4	main
abielluvad	doc_491521501770_item	3575965	et	4	main
kultuurivaim	doc_491521501770_item	3575968	et	3	main
siiski	doc_491521501770_item	3575970	et	4	main
märkamatult	doc_491521501770_item	3575972	et	4	main
kuid	doc_491521501770_item	3575978	et	4	main
viisil	doc_491521501770_item	3575989	et	4	main
majanduslikult	doc_491521501770_item	3575992	et	4	main
sest	doc_491521501770_item	3576007	et	4	main
praegu	doc_491521501770_item	3576008	et	3	main
praktiliselt	doc_491521501770_item	3576011	et	4	main
väide	doc_491521501770_item	3576051	et	4	main
küsitluste	doc_491521501770_item	3576057	et	4	main
elada	doc_491521501770_item	3576068	et	3	main
tunnevad	doc_491521501770_item	3576080	et	3	main
inimese	doc_491521501770_item	3576095	et	4	main
bioloogilistele	doc_491521501770_item	3576096	et	4	main
seda	doc_491521501770_item	3576106	et	3	main
vajadust	doc_491521501770_item	3576107	et	4	main
käies	doc_491521501770_item	3576108	et	3	main
ja	doc_491521501770_item	3576115	et	3	main
mõned	doc_491521501770_item	3576143	et	3	main
rohkem	doc_491521501770_item	3576149	et	4	main
kui	doc_491521501770_item	3576150	et	3	main
2	doc_491521501770_item	3576151	et	2	main
seal	doc_491521501770_item	3576168	et	4	main
alguse	doc_491521501770_item	3576172	et	3	main
uurijad	doc_491521501770_item	3576173	et	4	main
on	doc_491521501770_item	3576186	et	4	main
vaja	doc_491521501770_item	3576187	et	4	main
rahva	doc_491521501770_item	3576194	et	3	main
ülesandeks	doc_491521501770_item	3576198	et	4	main
oli	doc_491521501770_item	3576199	et	3	main
ta	doc_491521501770_item	3576228	et	4	main
oli	doc_491521501770_item	3576229	et	3	main
keegi	doc_491521501770_item	3575691	et	4	main
pühapäeviti	doc_491521501770_item	3575705	et	4	main
ja	doc_491521501770_item	3575710	et	3	main
kultuuri	doc_491521501770_item	3575750	et	4	main
jaoks	doc_491521501770_item	3575759	et	4	main
loomulikuks	doc_491521501770_item	3575760	et	3	main
nad	doc_491521501770_item	3575761	et	3	main
ja	doc_491521501770_item	3575765	et	3	main
kaasaegses	doc_491521501770_item	3575770	et	3	main
oma	doc_491521501770_item	3575782	et	4	main
hoopis	doc_491521501770_item	3575792	et	3	main
on	doc_491521501770_item	3575804	et	4	main
nende	doc_491521501770_item	3575805	et	4	main
sõnul	doc_491521501770_item	3575806	et	3	main
teevad	doc_491521501770_item	3575812	et	3	main
süüa	doc_491521501770_item	3575813	et	3	main
väga	doc_491521501770_item	3575823	et	3	main
vähe	doc_491521501770_item	3575824	et	3	main
ei	doc_491521501770_item	3575827	et	4	main
muidugi	doc_491521501770_item	3575835	et	4	main
siinjuures	doc_491521501770_item	3575869	et	3	main
mis	doc_491521501770_item	3575879	et	4	main
eraldatud	doc_491521501770_item	3575882	et	4	main
jaoks	doc_491521501770_item	3575884	et	4	main
oleks	doc_491521501770_item	3575885	et	3	main
ainult	doc_491521501770_item	3575894	et	4	main
vaadata	doc_491521501770_item	3575895	et	4	main
üritustest	doc_491521501770_item	3575906	et	4	main
vanemate	doc_491521501770_item	3575913	et	4	main
inimeste	doc_491521501770_item	3575914	et	3	main
juhatusel	doc_491521501770_item	3575915	et	4	main
maitseksid	doc_491521501770_item	3575920	et	4	main
kuulnud	doc_491521501770_item	3575924	et	4	main
ilma	doc_491521501770_item	3575939	et	4	main
nendeta	doc_491521501770_item	3575940	et	4	main
huvitav	doc_491521501770_item	3575943	et	4	main
siis	doc_491521501770_item	3575955	et	3	main
lähemalt	doc_491521501770_item	3575961	et	4	main
tähendab	doc_491521501770_item	3575966	et	3	main
eksisteerib	doc_491521501770_item	3575969	et	3	main
ainult	doc_491521501770_item	3575971	et	4	main
inimeste	doc_491521501770_item	3575973	et	3	main
jaoks	doc_491521501770_item	3575974	et	4	main
inimesed	doc_491521501770_item	3575979	et	3	main
äärealadel	doc_491521501770_item	3575990	et	3	main
mahajäänud	doc_491521501770_item	3575993	et	4	main
külades	doc_491521501770_item	3575994	et	3	main
kuhu	doc_491521501770_item	3575995	et	3	main
elektrivalgus	doc_491521501770_item	3575996	et	4	main
jõudis	doc_491521501770_item	3575997	et	3	main
20	doc_491521501770_item	3575998	et	2	main
sajandi	doc_491521501770_item	3575999	et	3	main
lõpus	doc_491521501770_item	3576000	et	4	main
riik	doc_491521501770_item	3576001	et	3	main
peab	doc_491521501770_item	3576002	et	4	main
tagama	doc_491521501770_item	3576003	et	3	main
tingimused	doc_491521501770_item	3576004	et	3	main
eluks	doc_491521501770_item	3576005	et	3	main
elanikel	doc_491521501770_item	3576010	et	3	main
pole	doc_491521501770_item	3576012	et	3	main
võimalust	doc_491521501770_item	3576013	et	3	main
see	doc_491521501770_item	3576050	et	3	main
täiesti	doc_491521501770_item	3576054	et	3	main
ühelt	doc_491521501770_item	3576055	et	3	main
poolt	doc_491521501770_item	3576056	et	4	main
inimesed	doc_491521501770_item	3576063	et	3	main
inimesed	doc_491521501770_item	3576066	et	3	main
juures	doc_491521501770_item	3576078	et	4	main
ennast	doc_491521501770_item	3576081	et	4	main
vabamalt	doc_491521501770_item	3576082	et	4	main
ruumis	doc_491521501770_item	3576091	et	4	main
vajadustele	doc_491521501770_item	3576097	et	4	main
suvilates	doc_491521501770_item	3576109	et	4	main
ei	doc_491521501770_item	3576144	et	4	main
taha	doc_491521501770_item	3576145	et	4	main
et	doc_491521501770_item	3576146	et	3	main
mis	doc_491521501770_item	3576155	et	4	main
puudutab	doc_491521501770_item	3576156	et	3	main
looduse	doc_491521501770_item	3576158	et	4	main
ta	doc_491521501770_item	3576170	et	4	main
esindajaks	doc_491521501770_item	3576195	et	4	main
kasvatusele	doc_491521501770_item	3575727	et	4	main
hakkasid	doc_491521501770_item	3575735	et	4	main
juba	doc_491521501770_item	3575736	et	3	main
varakult	doc_491521501770_item	3575737	et	4	main
nad	doc_491521501770_item	3575744	et	3	main
ja	doc_491521501770_item	3575747	et	3	main
elasid	doc_491521501770_item	3575748	et	4	main
oma	doc_491521501770_item	3575749	et	4	main
rahvakultuur	doc_491521501770_item	3575756	et	3	main
kujunes	doc_491521501770_item	3575757	et	3	main
nende	doc_491521501770_item	3575758	et	4	main
ennast	doc_491521501770_item	3575763	et	4	main
rahvana	doc_491521501770_item	3575769	et	3	main
ühiskonnas	doc_491521501770_item	3575771	et	4	main
pole	doc_491521501770_item	3575773	et	3	main
nii	doc_491521501770_item	3575774	et	3	main
loomulik	doc_491521501770_item	3575775	et	3	main
lihtne	doc_491521501770_item	3575777	et	3	main
lastega	doc_491521501770_item	3575783	et	3	main
suhtlemiseks	doc_491521501770_item	3575784	et	4	main
ja	doc_491521501770_item	3575785	et	3	main
teine	doc_491521501770_item	3575793	et	3	main
vanemad	doc_491521501770_item	3575803	et	4	main
tööl	doc_491521501770_item	3575811	et	3	main
ja	doc_491521501770_item	3575814	et	3	main
vajalikku	doc_491521501770_item	3575816	et	4	main
ka	doc_491521501770_item	3575825	et	3	main
tuleneb	doc_491521501770_item	3575836	et	3	main
järeldus	doc_491521501770_item	3575837	et	4	main
et	doc_491521501770_item	3575838	et	3	main
suhe	doc_491521501770_item	3575839	et	3	main
vanemate	doc_491521501770_item	3575840	et	4	main
ja	doc_491521501770_item	3575841	et	3	main
laste	doc_491521501770_item	3575842	et	4	main
vahel	doc_491521501770_item	3575843	et	4	main
on	doc_491521501770_item	3575844	et	4	main
mitte	doc_491521501770_item	3575845	et	3	main
nii	doc_491521501770_item	3575846	et	3	main
lähedane	doc_491521501770_item	3575847	et	3	main
kui	doc_491521501770_item	3575848	et	3	main
varem	doc_491521501770_item	3575849	et	4	main
oli	doc_491521501770_item	3575850	et	3	main
lapsed	doc_491521501770_item	3575851	et	3	main
ja	doc_491521501770_item	3575852	et	3	main
vanemad	doc_491521501770_item	3575853	et	4	main
kaotavad	doc_491521501770_item	3575854	et	4	main
esivanemate	doc_491521501770_item	3575855	et	4	main
ja	doc_491521501770_item	3575856	et	3	main
lapselaste	doc_491521501770_item	3575857	et	4	main
ees	doc_491521501770_item	3575858	et	4	main
vastutuse	doc_491521501770_item	3575859	et	4	main
teadvustamist	doc_491521501770_item	3575860	et	4	main
millega	doc_491521501770_item	3575861	et	3	main
kaob	doc_491521501770_item	3575862	et	3	main
ka	doc_491521501770_item	3575863	et	3	main
rahvuslik	doc_491521501770_item	3575864	et	3	main
identiteet	doc_491521501770_item	3575865	et	4	main
koolil	doc_491521501770_item	3575867	et	4	main
lastele	doc_491521501770_item	3575872	et	4	main
spetsiaalselt	doc_491521501770_item	3575881	et	4	main
muuseumides	doc_491521501770_item	3575890	et	3	main
ja	doc_491521501770_item	3575891	et	3	main
osa	doc_491521501770_item	3575902	et	4	main
muud	doc_491521501770_item	3575815	et	4	main
nii	doc_491521501770_item	3575817	et	3	main
lastele	doc_491521501770_item	3575819	et	4	main
neil	doc_491521501770_item	3575820	et	4	main
jätkub	doc_491521501770_item	3575821	et	3	main
oma	doc_491521501770_item	3575829	et	4	main
vanemaid	doc_491521501770_item	3575830	et	4	main
niipalju	doc_491521501770_item	3575831	et	3	main
kui	doc_491521501770_item	3575832	et	3	main
vanasti	doc_491521501770_item	3575833	et	3	main
eesti	doc_491521501770_item	3575866	et	4	main
tuleb	doc_491521501770_item	3575873	et	3	main
rahva	doc_491521501770_item	3575875	et	3	main
on	doc_491521501770_item	3575880	et	4	main
võtta	doc_491521501770_item	3575903	et	3	main
rahvakultuuriga	doc_491521501770_item	3575904	et	4	main
seotud	doc_491521501770_item	3575905	et	4	main
kohalike	doc_491521501770_item	3575912	et	4	main
ja	doc_491521501770_item	3575919	et	3	main
olen	doc_491521501770_item	3575923	et	3	main
arvamusi	doc_491521501770_item	3575925	et	3	main
rahvakultuuri	doc_491521501770_item	3575927	et	4	main
kombeid	doc_491521501770_item	3575930	et	4	main
ka	doc_491521501770_item	3575938	et	3	main
kuid	doc_491521501770_item	3575941	et	4	main
erinevused	doc_491521501770_item	3575947	et	4	main
esile	doc_491521501770_item	3575954	et	3	main
tähtis	doc_491521501770_item	3575870	et	4	main
rääkida	doc_491521501770_item	3575877	et	3	main
käiksid	doc_491521501770_item	3575889	et	4	main
saaksid	doc_491521501770_item	3575892	et	4	main
mitte	doc_491521501770_item	3575893	et	3	main
ja	doc_491521501770_item	3575896	et	3	main
tutvuda	doc_491521501770_item	3575897	et	3	main
sellega	doc_491521501770_item	3575898	et	3	main
vaid	doc_491521501770_item	3575899	et	3	main
ka	doc_491521501770_item	3575900	et	3	main
vahetult	doc_491521501770_item	3575901	et	4	main
erinevates	doc_491521501770_item	3575909	et	4	main
töödes	doc_491521501770_item	3575910	et	3	main
omandaksid	doc_491521501770_item	3575911	et	4	main
traditsioonilisi	doc_491521501770_item	3575916	et	4	main
töövõtteid	doc_491521501770_item	3575917	et	3	main
valmistaksid	doc_491521501770_item	3575918	et	4	main
et	doc_491521501770_item	3575926	et	3	main
elada	doc_491521501770_item	3575937	et	3	main
teistest	doc_491521501770_item	3575952	et	4	main
tulevad	doc_491521501770_item	3575953	et	4	main
kui	doc_491521501770_item	3575956	et	3	main
kultuuride	doc_491521501770_item	3575959	et	3	main
kokku	doc_491521501770_item	3575962	et	3	main
ta	doc_491521501770_item	3575975	et	4	main
on	doc_491521501770_item	3575976	et	4	main
lihtsalt	doc_491521501770_item	3575980	et	4	main
sellele	doc_491521501770_item	3575983	et	4	main
eesti	doc_491521501770_item	3575985	et	4	main
rahvakultuur	doc_491521501770_item	3575986	et	3	main
elab	doc_491521501770_item	3575987	et	3	main
nendes	doc_491521501770_item	3575991	et	4	main
maal	doc_491521501770_item	3576006	et	4	main
palju	doc_491521501770_item	3576018	et	4	main
majanduslikke	doc_491521501770_item	3576019	et	3	main
õigustab	doc_491521501770_item	3576052	et	3	main
ennast	doc_491521501770_item	3576053	et	4	main
et	doc_491521501770_item	3576061	et	3	main
rohkem	doc_491521501770_item	3576064	et	4	main
vanemad	doc_491521501770_item	3576065	et	4	main
ma	doc_491521501770_item	3575922	et	3	main
traditsioone	doc_491521501770_item	3575928	et	3	main
ja	doc_491521501770_item	3575929	et	3	main
pole	doc_491521501770_item	3575931	et	3	main
üldsegi	doc_491521501770_item	3575932	et	3	main
vaja	doc_491521501770_item	3575933	et	4	main
on	doc_491521501770_item	3575942	et	4	main
mis	doc_491521501770_item	3575948	et	4	main
eristavad	doc_491521501770_item	3575949	et	4	main
üht	doc_491521501770_item	3575950	et	3	main
rahvast	doc_491521501770_item	3575951	et	4	main
kaks	doc_491521501770_item	3575957	et	3	main
esindajat	doc_491521501770_item	3575960	et	4	main
puutuvad	doc_491521501770_item	3575963	et	4	main
nt	doc_491521501770_item	3575964	et	4	main
see	doc_491521501770_item	3575967	et	3	main
ei	doc_491521501770_item	3575981	et	4	main
riigi	doc_491521501770_item	3576024	et	3	main
põhjal	doc_491521501770_item	3576058	et	4	main
tehti	doc_491521501770_item	3576059	et	3	main
maal	doc_491521501770_item	3576069	et	4	main
neil	doc_491521501770_item	3576071	et	4	main
oma	doc_491521501770_item	3576073	et	4	main
sest	doc_491521501770_item	3576083	et	4	main
kuidas	doc_491521501770_item	3576084	et	3	main
elamine	doc_491521501770_item	3576092	et	4	main
ta	doc_491521501770_item	3576098	et	4	main
pole	doc_491521501770_item	3576099	et	3	main
õnnelik	doc_491521501770_item	3576100	et	3	main
olles	doc_491521501770_item	3576101	et	3	main
kuid	doc_491521501770_item	3576110	et	4	main
see	doc_491521501770_item	3576111	et	3	main
võrreldav	doc_491521501770_item	3576117	et	4	main
neil	doc_491521501770_item	3576147	et	4	main
oleksid	doc_491521501770_item	3576148	et	4	main
teine	doc_491521501770_item	3576153	et	3	main
olemas	doc_491521501770_item	3575977	et	4	main
pööra	doc_491521501770_item	3575982	et	4	main
tähelepanu	doc_491521501770_item	3575984	et	4	main
traditsioonilisel	doc_491521501770_item	3575988	et	4	main
siinsetel	doc_491521501770_item	3576009	et	4	main
ennast	doc_491521501770_item	3576014	et	4	main
elatada	doc_491521501770_item	3576015	et	3	main
neil	doc_491521501770_item	3576016	et	4	main
on	doc_491521501770_item	3576017	et	4	main
probleeme	doc_491521501770_item	3576020	et	3	main
mida	doc_491521501770_item	3576021	et	4	main
saab	doc_491521501770_item	3576022	et	3	main
lahendada	doc_491521501770_item	3576023	et	3	main
tasandil	doc_491521501770_item	3576025	et	3	main
tänapäevane	doc_491521501770_item	3576026	et	4	main
elukutse	doc_491521501770_item	3576027	et	4	main
kõlab	doc_491521501770_item	3576028	et	3	main
tagasi	doc_491521501770_item	3576029	et	3	main
looduse	doc_491521501770_item	3576030	et	4	main
juurde	doc_491521501770_item	3576031	et	4	main
nagu	doc_491521501770_item	3576032	et	3	main
see	doc_491521501770_item	3576033	et	3	main
oli	doc_491521501770_item	3576034	et	3	main
valgustusajal	doc_491521501770_item	3576035	et	3	main
mil	doc_491521501770_item	3576036	et	4	main
hakati	doc_491521501770_item	3576037	et	3	main
hindama	doc_491521501770_item	3576038	et	3	main
kõike	doc_491521501770_item	3576039	et	4	main
looduslikku	doc_491521501770_item	3576040	et	4	main
ja	doc_491521501770_item	3576041	et	3	main
inimene	doc_491521501770_item	3576042	et	3	main
oli	doc_491521501770_item	3576043	et	3	main
kõrgeim	doc_491521501770_item	3576044	et	4	main
väärtus	doc_491521501770_item	3576045	et	3	main
ja	doc_491521501770_item	3576046	et	3	main
ma	doc_491521501770_item	3576047	et	3	main
arvan	doc_491521501770_item	3576048	et	3	main
et	doc_491521501770_item	3576049	et	3	main
järeldus	doc_491521501770_item	3576060	et	4	main
paljud	doc_491521501770_item	3576062	et	3	main
sooviksid	doc_491521501770_item	3576067	et	4	main
talu	doc_491521501770_item	3576074	et	4	main
ja	doc_491521501770_item	3576075	et	3	main
majapidamine	doc_491521501770_item	3576076	et	3	main
looduse	doc_491521501770_item	3576077	et	4	main
inimesed	doc_491521501770_item	3576085	et	3	main
elavad	doc_491521501770_item	3576086	et	4	main
linnades	doc_491521501770_item	3576087	et	3	main
korteris	doc_491521501770_item	3576088	et	3	main
on	doc_491521501770_item	3576093	et	4	main
vastu	doc_491521501770_item	3576094	et	3	main
loodusest	doc_491521501770_item	3576102	et	4	main
eemal	doc_491521501770_item	3576103	et	3	main
mõned	doc_491521501770_item	3576104	et	3	main
on	doc_491521501770_item	3576112	et	4	main
asjaolu	doc_491521501770_item	3576154	et	4	main
tagasi	doc_491521501770_item	3576157	et	3	main
juurde	doc_491521501770_item	3576159	et	4	main
pöördumist	doc_491521501770_item	3576160	et	4	main
on	doc_491521501770_item	3576161	et	4	main
see	doc_491521501770_item	3576162	et	3	main
et	doc_491521501770_item	3576163	et	3	main
säilinud	doc_491521501770_item	3576167	et	4	main
sai	doc_491521501770_item	3576171	et	4	main
teada	doc_491521501770_item	3576188	et	3	main
eelkõige	doc_491521501770_item	3576189	et	3	main
selleks	doc_491521501770_item	3576190	et	4	main
et	doc_491521501770_item	3576191	et	3	main
ja	doc_491521501770_item	3576196	et	3	main
esivanemate	doc_491521501770_item	3576207	et	4	main
lood	doc_491521501770_item	3576208	et	4	main
ja	doc_491521501770_item	3576209	et	3	main
arendada	doc_491521501770_item	3576210	et	3	main
neis	doc_491521501770_item	3576211	et	4	main
pere	doc_491521501770_item	3576230	et	4	main
sest	doc_491521501770_item	3576232	et	4	main
õigused	doc_491521501770_item	3576248	et	4	main
mõnes	doc_491521501770_item	3576249	et	3	main
peres	doc_491521501770_item	3576250	et	3	main
on	doc_491521501770_item	3576251	et	4	main
isegi	doc_491521501770_item	3576258	et	4	main
et	doc_491521501770_item	3576070	et	3	main
oleks	doc_491521501770_item	3576072	et	3	main
nad	doc_491521501770_item	3576079	et	3	main
selles	doc_491521501770_item	3576089	et	4	main
kinnises	doc_491521501770_item	3576090	et	4	main
kompenseerivad	doc_491521501770_item	3576105	et	4	main
muidugi	doc_491521501770_item	3576113	et	4	main
vähe	doc_491521501770_item	3576114	et	3	main
pole	doc_491521501770_item	3576116	et	3	main
külaeluga	doc_491521501770_item	3576118	et	3	main
kui	doc_491521501770_item	3576119	et	3	main
vanasti	doc_491521501770_item	3576120	et	3	main
inimesed	doc_491521501770_item	3576121	et	3	main
elasid	doc_491521501770_item	3576122	et	4	main
koos	doc_491521501770_item	3576123	et	4	main
oma	doc_491521501770_item	3576124	et	4	main
vanematega	doc_491521501770_item	3576125	et	4	main
või	doc_491521501770_item	3576126	et	4	main
teiste	doc_491521501770_item	3576127	et	4	main
sugulaste	doc_491521501770_item	3576128	et	4	main
perekondadega	doc_491521501770_item	3576129	et	3	main
siis	doc_491521501770_item	3576130	et	3	main
praegused	doc_491521501770_item	3576131	et	3	main
tingimused	doc_491521501770_item	3576132	et	3	main
piiravad	doc_491521501770_item	3576133	et	4	main
seda	doc_491521501770_item	3576134	et	3	main
inimeste	doc_491521501770_item	3576135	et	3	main
soovi	doc_491521501770_item	3576136	et	4	main
inimesed	doc_491521501770_item	3576137	et	3	main
ei	doc_491521501770_item	3576138	et	4	main
või	doc_491521501770_item	3576139	et	4	main
endale	doc_491521501770_item	3576140	et	4	main
lubada	doc_491521501770_item	3576141	et	3	main
ja	doc_491521501770_item	3576142	et	3	main
last	doc_491521501770_item	3576152	et	4	main
eesti	doc_491521501770_item	3576164	et	4	main
rahvakultuur	doc_491521501770_item	3576165	et	3	main
on	doc_491521501770_item	3576166	et	4	main
kombeid	doc_491521501770_item	3576184	et	4	main
seda	doc_491521501770_item	3576185	et	3	main
oma	doc_491521501770_item	3576193	et	4	main
vanemate	doc_491521501770_item	3576197	et	4	main
ja	doc_491521501770_item	3576200	et	3	main
raskemaid	doc_491521501770_item	3576235	et	4	main
töid	doc_491521501770_item	3576236	et	3	main
rohkem	doc_491521501770_item	3576241	et	4	main
siis	doc_491521501770_item	3576243	et	3	main
mõnedes	doc_491521501770_item	3576253	et	3	main
palka	doc_491521501770_item	3576257	et	4	main
rohkem	doc_491521501770_item	3576259	et	4	main
kui	doc_491521501770_item	3576260	et	3	main
mees	doc_491521501770_item	3576261	et	4	main
sest	doc_491521501770_item	3576268	et	4	main
vajadus	doc_491521501770_item	3576271	et	3	main
kehtimast	doc_491521501770_item	3576276	et	3	main
kui	doc_491521501770_item	3576287	et	3	main
tahavad	doc_491521501770_item	3576294	et	3	main
ja	doc_491521501770_item	3576297	et	3	main
vaja	doc_491521501770_item	3576300	et	4	main
rahuldada	doc_491521501770_item	3576301	et	3	main
kõiki	doc_491521501770_item	3576302	et	4	main
90	doc_491521501770_item	3576322	et	2	main
a-te	doc_491521501770_item	3576323	et	3	main
alguses	doc_491521501770_item	3576324	et	4	main
noorpaarid	doc_491521501770_item	3576329	et	4	main
jätkata	doc_491521501770_item	3576332	et	4	main
vanemad	doc_491521501770_item	3576339	et	4	main
tähtsal	doc_491521501770_item	3576344	et	3	main
hea	doc_491521501770_item	3576350	et	4	main
kui	doc_491521501770_item	3576351	et	3	main
perekonnad	doc_491521501770_item	3576352	et	4	main
et	doc_491521501770_item	3576359	et	3	main
eriti	doc_491521501770_item	3576363	et	3	main
kus	doc_491521501770_item	3576370	et	3	main
on	doc_491521501770_item	3576378	et	4	main
istuvad	doc_491521501770_item	3576387	et	4	main
pere	doc_491521501770_item	3576396	et	4	main
kuhu	doc_491521501770_item	3576400	et	3	main
huvi	doc_491521501770_item	3576406	et	4	main
kui	doc_491521501770_item	3576416	et	3	main
vägivalda	doc_491521501789_item	3576438	et	4	main
probleem	doc_491521501789_item	3576440	et	3	main
olnud	doc_491521501789_item	3576442	et	4	main
on	doc_491521501789_item	3576447	et	4	main
vägivald	doc_491521501789_item	3576463	et	3	main
vägivalla	doc_491521501789_item	3576466	et	3	main
süüdi	doc_491521501789_item	3576488	et	4	main
saa	doc_491521501789_item	3576500	et	4	main
aru	doc_491521501789_item	3576501	et	4	main
et	doc_491521501789_item	3576502	et	3	main
eeskujud	doc_491521501789_item	3576506	et	3	main
inimesed	doc_491521501789_item	3576522	et	3	main
vaenlikult	doc_491521501789_item	3576525	et	4	main
arvates	doc_491521501789_item	3576528	et	4	main
kõige	doc_491521501789_item	3576529	et	4	main
kui	doc_491521501789_item	3576534	et	3	main
niisugustel	doc_491521501789_item	3576535	et	3	main
oma	doc_491521501789_item	3576543	et	4	main
et	doc_491521501789_item	3576551	et	3	main
probleem	doc_491521501789_item	3576553	et	3	main
lõppe	doc_491521501789_item	3576555	et	4	main
naiste	doc_491521501789_item	3576565	et	3	main
kajastub	doc_491521501789_item	3576599	et	3	main
ning	doc_491521501789_item	3576602	et	3	main
vägivalla	doc_491521501789_item	3576604	et	3	main
arvan	doc_491521501789_item	3576606	et	3	main
ning	doc_491521501789_item	3576610	et	3	main
rahulik	doc_491521501789_item	3576611	et	3	main
eluviis	doc_491521501789_item	3576612	et	3	main
kuuluvad	doc_491521501789_item	3576613	et	4	main
ei	doc_491521501789_item	3576632	et	4	main
on	doc_491521501796_item	3576649	et	4	main
vähe	doc_491521501796_item	3576650	et	3	main
kes	doc_491521501796_item	3576651	et	4	main
arvan	doc_491521501796_item	3576656	et	3	main
on	doc_491521501796_item	3576661	et	4	main
kust	doc_491521501770_item	3576169	et	4	main
kiirustavad	doc_491521501770_item	3576174	et	4	main
maale	doc_491521501770_item	3576175	et	4	main
et	doc_491521501770_item	3576176	et	3	main
koguda	doc_491521501770_item	3576177	et	3	main
ja	doc_491521501770_item	3576178	et	3	main
üles	doc_491521501770_item	3576179	et	3	main
kirjutada	doc_491521501770_item	3576180	et	3	main
rahva	doc_491521501770_item	3576181	et	3	main
traditsioone	doc_491521501770_item	3576182	et	3	main
ja	doc_491521501770_item	3576183	et	3	main
jääda	doc_491521501770_item	3576192	et	4	main
oma	doc_491521501770_item	3576206	et	4	main
loomulik	doc_491521501770_item	3576212	et	3	main
huvi	doc_491521501770_item	3576213	et	4	main
ja	doc_491521501770_item	3576214	et	3	main
oma	doc_491521501770_item	3576216	et	4	main
armastus	doc_491521501770_item	3576215	et	4	main
maa	doc_491521501770_item	3576217	et	4	main
ja	doc_491521501770_item	3576218	et	3	main
rahva	doc_491521501770_item	3576219	et	3	main
vastu	doc_491521501770_item	3576220	et	3	main
kui	doc_491521501770_item	3576221	et	3	main
vanasti	doc_491521501770_item	3576222	et	3	main
mehe	doc_491521501770_item	3576223	et	3	main
osatähtsus	doc_491521501770_item	3576224	et	4	main
peres	doc_491521501770_item	3576225	et	3	main
oli	doc_491521501770_item	3576226	et	3	main
suur	doc_491521501770_item	3576227	et	3	main
on	doc_491521501770_item	3576201	et	4	main
praegu	doc_491521501770_item	3576202	et	3	main
edasi	doc_491521501770_item	3576203	et	3	main
anda	doc_491521501770_item	3576204	et	3	main
lastele	doc_491521501770_item	3576205	et	4	main
kui	doc_491521501770_item	3576237	et	3	main
naine	doc_491521501770_item	3576238	et	3	main
võrdsed	doc_491521501770_item	3576252	et	3	main
teenib	doc_491521501770_item	3576256	et	3	main
selle	doc_491521501770_item	3576265	et	4	main
bioloogiline	doc_491521501770_item	3576270	et	4	main
olla	doc_491521501770_item	3576272	et	3	main
eesotsas	doc_491521501770_item	3576274	et	4	main
mees	doc_491521501770_item	3576277	et	4	main
ei	doc_491521501770_item	3576278	et	4	main
see	doc_491521501770_item	3576283	et	3	main
näitab	doc_491521501770_item	3576285	et	3	main
oleme	doc_491521501770_item	3576291	et	3	main
inimesed	doc_491521501770_item	3576293	et	3	main
vabariik	doc_491521501770_item	3576319	et	3	main
sai	doc_491521501770_item	3576320	et	4	main
iseseisvaks	doc_491521501770_item	3576321	et	3	main
ja	doc_491521501770_item	3576328	et	3	main
said	doc_491521501770_item	3576330	et	4	main
võimaluse	doc_491521501770_item	3576331	et	3	main
lapsi	doc_491521501770_item	3576348	et	4	main
tähtpäevi	doc_491521501770_item	3576354	et	4	main
rahvakalendri	doc_491521501770_item	3576355	et	3	main
see	doc_491521501770_item	3576365	et	3	main
veel	doc_491521501770_item	3576367	et	4	main
pere	doc_491521501770_item	3576372	et	4	main
kogunevad	doc_491521501770_item	3576376	et	4	main
koos	doc_491521501770_item	3576377	et	4	main
omavahel	doc_491521501770_item	3576384	et	3	main
tihedamini	doc_491521501770_item	3576385	et	4	main
ja	doc_491521501770_item	3576386	et	3	main
nii	doc_491521501770_item	3576394	et	3	main
kultuuri	doc_491521501770_item	3576403	et	4	main
rahvameditsiini	doc_491521501770_item	3576407	et	4	main
abil	doc_491521501770_item	3576410	et	4	main
ka	doc_491521501770_item	3576417	et	3	main
on	doc_491521501789_item	3576441	et	4	main
eesotsas	doc_491521501770_item	3576231	et	4	main
ta	doc_491521501770_item	3576233	et	4	main
tegi	doc_491521501770_item	3576234	et	4	main
tõi	doc_491521501770_item	3576240	et	3	main
palka	doc_491521501770_item	3576242	et	4	main
meeste	doc_491521501770_item	3576245	et	4	main
ja	doc_491521501770_item	3576246	et	3	main
naiste	doc_491521501770_item	3576247	et	3	main
naine	doc_491521501770_item	3576255	et	3	main
mees	doc_491521501770_item	3576262	et	4	main
pole	doc_491521501770_item	3576264	et	3	main
asjaoluga	doc_491521501770_item	3576266	et	3	main
pere	doc_491521501770_item	3576273	et	4	main
lakkab	doc_491521501770_item	3576275	et	3	main
ennast	doc_491521501770_item	3576280	et	4	main
juba	doc_491521501770_item	3576281	et	3	main
jälle	doc_491521501770_item	3576284	et	3	main
seda	doc_491521501770_item	3576286	et	3	main
kaugel	doc_491521501770_item	3576288	et	4	main
olla	doc_491521501770_item	3576295	et	3	main
on	doc_491521501770_item	3576299	et	4	main
taastus	doc_491521501770_item	3576325	et	4	main
kirikuga	doc_491521501770_item	3576327	et	3	main
esivanemate	doc_491521501770_item	3576334	et	4	main
jaoks	doc_491521501770_item	3576341	et	4	main
kirik	doc_491521501770_item	3576342	et	3	main
kohal	doc_491521501770_item	3576345	et	4	main
lastele	doc_491521501770_item	3576360	et	4	main
see	doc_491521501770_item	3576361	et	3	main
ja	doc_491521501770_item	3576239	et	3	main
praegu	doc_491521501770_item	3576244	et	3	main
peredes	doc_491521501770_item	3576254	et	3	main
aga	doc_491521501770_item	3576263	et	3	main
rahul	doc_491521501770_item	3576267	et	4	main
tunne	doc_491521501770_item	3576279	et	4	main
peremehena	doc_491521501770_item	3576282	et	3	main
me	doc_491521501770_item	3576290	et	4	main
aga	doc_491521501770_item	3576292	et	3	main
selleks	doc_491521501770_item	3576298	et	4	main
oma	doc_491521501770_item	3576333	et	4	main
kelle	doc_491521501770_item	3576340	et	4	main
on	doc_491521501770_item	3576349	et	4	main
järgi	doc_491521501770_item	3576356	et	4	main
ma	doc_491521501770_item	3576357	et	3	main
usun	doc_491521501770_item	3576358	et	3	main
sest	doc_491521501770_item	3576364	et	4	main
üks	doc_491521501770_item	3576368	et	3	main
kõik	doc_491521501770_item	3576371	et	4	main
liikmed	doc_491521501770_item	3576373	et	3	main
ka	doc_491521501770_item	3576374	et	3	main
pere	doc_491521501770_item	3576381	et	4	main
liikmed	doc_491521501770_item	3576382	et	3	main
suhtlevad	doc_491521501770_item	3576383	et	4	main
nende	doc_491521501770_item	3576395	et	4	main
kui	doc_491521501770_item	3576397	et	3	main
kuuluvad	doc_491521501770_item	3576402	et	4	main
on	doc_491521501770_item	3576404	et	4	main
olemas	doc_491521501770_item	3576405	et	4	main
vastu	doc_491521501770_item	3576408	et	3	main
nii	doc_491521501770_item	3576414	et	3	main
sünnitab	doc_491521501789_item	3576437	et	3	main
see	doc_491521501789_item	3576446	et	3	main
sünnitab	doc_491521501789_item	3576464	et	3	main
võib	doc_491521501789_item	3576468	et	3	main
palju	doc_491521501789_item	3576470	et	4	main
alkhoholism	doc_491521501789_item	3576472	et	4	main
lahendamata	doc_491521501789_item	3576494	et	4	main
probleeme	doc_491521501789_item	3576495	et	3	main
käitudes	doc_491521501789_item	3576496	et	3	main
nii	doc_491521501789_item	3576497	et	3	main
vanemad	doc_491521501789_item	3576498	et	4	main
rohkem	doc_491521501789_item	3576517	et	4	main
minu	doc_491521501789_item	3576527	et	3	main
tema	doc_491521501770_item	3576269	et	4	main
loodusest	doc_491521501770_item	3576289	et	4	main
õnnelikud	doc_491521501770_item	3576296	et	3	main
ta	doc_491521501770_item	3576303	et	4	main
vajadusi	doc_491521501770_item	3576304	et	3	main
poleks	doc_491521501770_item	3576305	et	3	main
õige	doc_491521501770_item	3576306	et	4	main
öeldes	doc_491521501770_item	3576307	et	3	main
et	doc_491521501770_item	3576308	et	3	main
suhe	doc_491521501770_item	3576309	et	3	main
oma	doc_491521501770_item	3576310	et	4	main
enam	doc_491521501770_item	3576312	et	4	main
rahvakultuuriga	doc_491521501770_item	3576311	et	4	main
ei	doc_491521501770_item	3576313	et	4	main
eksisteeri	doc_491521501770_item	3576314	et	4	main
pärast	doc_491521501770_item	3576315	et	4	main
seda	doc_491521501770_item	3576316	et	3	main
kui	doc_491521501770_item	3576317	et	3	main
eesti	doc_491521501770_item	3576318	et	4	main
suhe	doc_491521501770_item	3576326	et	3	main
traditsiooni	doc_491521501770_item	3576335	et	4	main
laulatus	doc_491521501770_item	3576336	et	4	main
kirikus	doc_491521501770_item	3576337	et	3	main
mõned	doc_491521501770_item	3576338	et	3	main
on	doc_491521501770_item	3576343	et	4	main
ristivad	doc_491521501770_item	3576346	et	4	main
oma	doc_491521501770_item	3576347	et	4	main
tähistavad	doc_491521501770_item	3576353	et	4	main
meeldib	doc_491521501770_item	3576362	et	3	main
on	doc_491521501770_item	3576366	et	4	main
tähtis	doc_491521501770_item	3576379	et	4	main
aitab	doc_491521501770_item	3576391	et	3	main
säilitada	doc_491521501770_item	3576393	et	3	main
ka	doc_491521501770_item	3576398	et	3	main
nad	doc_491521501770_item	3576401	et	3	main
mille	doc_491521501770_item	3576409	et	3	main
ravivad	doc_491521501770_item	3576413	et	4	main
essee	doc_491521501789_item	3576435	et	4	main
aktuaalne	doc_491521501789_item	3576443	et	3	main
tihti	doc_491521501789_item	3576448	et	3	main
kui	doc_491521501789_item	3576452	et	3	main
tihti	doc_491521501789_item	3576487	et	3	main
et	doc_491521501789_item	3576490	et	3	main
vanematel	doc_491521501789_item	3576491	et	4	main
ei	doc_491521501789_item	3576499	et	4	main
pingulik	doc_491521501789_item	3576515	et	4	main
atmosfäär	doc_491521501789_item	3576516	et	3	main
käituvad	doc_491521501789_item	3576523	et	4	main
on	doc_491521501789_item	3576531	et	4	main
et	doc_491521501789_item	3576533	et	3	main
oma	doc_491521501789_item	3576538	et	4	main
siis	doc_491521501789_item	3576540	et	3	main
käituvad	doc_491521501789_item	3576542	et	4	main
arvan	doc_491521501789_item	3576550	et	3	main
see	doc_491521501789_item	3576552	et	3	main
organisatsioonid	doc_491521501789_item	3576562	et	3	main
ühiskonnas	doc_491521501789_item	3576598	et	4	main
et	doc_491521501789_item	3576607	et	3	main
kõrg	doc_491521501789_item	3576608	et	4	main
elutase	doc_491521501789_item	3576609	et	3	main
mis	doc_491521501789_item	3576617	et	4	main
sellesse	doc_491521501789_item	3576622	et	4	main
see	doc_491521501789_item	3576625	et	3	main
probleem	doc_491521501789_item	3576626	et	3	main
et	doc_491521501796_item	3576657	et	3	main
sõber	doc_491521501796_item	3576674	et	3	main
nii	doc_491521501796_item	3576695	et	3	main
mingi	doc_491521501796_item	3576708	et	4	main
tal	doc_491521501796_item	3576716	et	3	main
ole	doc_491521501796_item	3576718	et	4	main
võimalus	doc_491521501770_item	3576369	et	3	main
sugulased	doc_491521501770_item	3576375	et	3	main
kui	doc_491521501770_item	3576380	et	3	main
ühes	doc_491521501770_item	3576388	et	4	main
lauas	doc_491521501770_item	3576389	et	3	main
see	doc_491521501770_item	3576390	et	3	main
neil	doc_491521501770_item	3576392	et	4	main
rahva-	doc_491521501770_item	3576399	et	3	main
tavaliselt	doc_491521501770_item	3576411	et	4	main
naised	doc_491521501770_item	3576412	et	3	main
iseenda	doc_491521501770_item	3576415	et	3	main
oma	doc_491521501770_item	3576418	et	4	main
sugulasi	doc_491521501770_item	3576419	et	3	main
on	doc_491521501770_item	3576420	et	4	main
ka	doc_491521501770_item	3576422	et	3	main
vaimne	doc_491521501770_item	3576423	et	3	main
rahvakultuur	doc_491521501770_item	3576424	et	3	main
säilinud	doc_491521501770_item	3576421	et	4	main
nt	doc_491521501770_item	3576425	et	4	main
vanasõnad	doc_491521501770_item	3576426	et	3	main
mehe	doc_491521501770_item	3576427	et	3	main
ja	doc_491521501770_item	3576428	et	3	main
naise	doc_491521501770_item	3576429	et	3	main
vanemate	doc_491521501770_item	3576430	et	4	main
ja	doc_491521501770_item	3576431	et	3	main
laste	doc_491521501770_item	3576432	et	4	main
kohta	doc_491521501770_item	3576433	et	4	main
vägivalla	doc_491521501789_item	3576439	et	3	main
alati	doc_491521501789_item	3576444	et	4	main
nii	doc_491521501789_item	3576450	et	3	main
ka	doc_491521501789_item	3576453	et	3	main
perekondades	doc_491521501789_item	3576454	et	3	main
see	doc_491521501789_item	3576459	et	3	main
kasvab	doc_491521501789_item	3576461	et	3	main
sest	doc_491521501789_item	3576462	et	4	main
vägivalda	doc_491521501789_item	3576465	et	4	main
põhjuseks	doc_491521501789_item	3576467	et	3	main
olla	doc_491521501789_item	3576469	et	3	main
lapsed	doc_491521501789_item	3576485	et	3	main
on	doc_491521501789_item	3576486	et	4	main
selles	doc_491521501789_item	3576489	et	4	main
on	doc_491521501789_item	3576492	et	4	main
mingit	doc_491521501789_item	3576493	et	3	main
tegud	doc_491521501789_item	3576504	et	4	main
on	doc_491521501789_item	3576513	et	4	main
kodus	doc_491521501789_item	3576514	et	4	main
nukreim	doc_491521501789_item	3576530	et	4	main
ilmub	doc_491521501789_item	3576537	et	3	main
nad	doc_491521501789_item	3576541	et	3	main
oma	doc_491521501789_item	3576545	et	4	main
vaatamata	doc_491521501789_item	3576558	et	4	main
et	doc_491521501789_item	3576559	et	3	main
praegu	doc_491521501789_item	3576560	et	3	main
ja	doc_491521501789_item	3576564	et	3	main
ning	doc_491521501789_item	3576567	et	3	main
distabiliseerimine	doc_491521501789_item	3576597	et	4	main
peal	doc_491521501789_item	3576601	et	4	main
viib	doc_491521501789_item	3576603	et	3	main
selliste	doc_491521501789_item	3576614	et	4	main
uskuda	doc_491521501789_item	3576621	et	3	main
vähetatakse	doc_491521501789_item	3576627	et	4	main
minimaalseks	doc_491521501789_item	3576628	et	4	main
tasandiks	doc_491521501789_item	3576629	et	3	main
ning	doc_491521501789_item	3576630	et	3	main
inimesed	doc_491521501789_item	3576631	et	3	main
või	doc_491521501789_item	3576596	et	4	main
vägivald	doc_491521501789_item	3576436	et	3	main
sest	doc_491521501789_item	3576445	et	4	main
asi	doc_491521501789_item	3576449	et	4	main
tänavatel	doc_491521501789_item	3576451	et	4	main
mulle	doc_491521501789_item	3576455	et	4	main
tundub	doc_491521501789_item	3576456	et	3	main
et	doc_491521501789_item	3576457	et	3	main
ajaga	doc_491521501789_item	3576458	et	3	main
probleem	doc_491521501789_item	3576460	et	3	main
asju	doc_491521501789_item	3576471	et	3	main
narkomaania	doc_491521501789_item	3576473	et	4	main
igasugused	doc_491521501789_item	3576474	et	3	main
probleemid	doc_491521501789_item	3576475	et	3	main
perekonnas	doc_491521501789_item	3576476	et	4	main
või	doc_491521501789_item	3576477	et	4	main
tööl	doc_491521501789_item	3576478	et	3	main
näiteks	doc_491521501789_item	3576479	et	4	main
lapsed	doc_491521501789_item	3576480	et	3	main
kannatavad	doc_491521501789_item	3576481	et	4	main
joodiku	doc_491521501789_item	3576482	et	3	main
vanematelt	doc_491521501789_item	3576483	et	4	main
või	doc_491521501789_item	3576484	et	4	main
nende	doc_491521501789_item	3576503	et	4	main
on	doc_491521501789_item	3576505	et	4	main
lastele	doc_491521501789_item	3576507	et	4	main
statistika	doc_491521501789_item	3576508	et	4	main
näitab	doc_491521501789_item	3576509	et	3	main
et	doc_491521501789_item	3576510	et	3	main
noorukid	doc_491521501789_item	3576511	et	3	main
kellel	doc_491521501789_item	3576512	et	4	main
kalduvad	doc_491521501789_item	3576518	et	4	main
kuritegude	doc_491521501789_item	3576519	et	3	main
vastu	doc_491521501789_item	3576520	et	3	main
niisugused	doc_491521501789_item	3576521	et	3	main
sageli	doc_491521501789_item	3576524	et	3	main
kurjalt	doc_491521501789_item	3576526	et	3	main
see	doc_491521501789_item	3576532	et	3	main
perekond	doc_491521501789_item	3576539	et	3	main
lastega	doc_491521501789_item	3576544	et	3	main
järgi	doc_491521501789_item	3576548	et	4	main
tegutsevad	doc_491521501789_item	3576561	et	4	main
vägivalda	doc_491521501789_item	3576619	et	4	main
tahaks	doc_491521501789_item	3576620	et	3	main
selle	doc_491521501789_item	3576634	et	4	main
üle	doc_491521501789_item	3576635	et	3	main
enam	doc_491521501789_item	3576636	et	4	main
essee	doc_491521501796_item	3576638	et	4	main
hädas	doc_491521501796_item	3576641	et	3	main
mul	doc_491521501796_item	3576642	et	3	main
tõeline	doc_491521501796_item	3576653	et	4	main
sõber	doc_491521501796_item	3576654	et	3	main
sõber	doc_491521501796_item	3576659	et	3	main
mõistab	doc_491521501796_item	3576664	et	3	main
austab	doc_491521501796_item	3576665	et	3	main
mind	doc_491521501796_item	3576667	et	4	main
kui	doc_491521501796_item	3576668	et	3	main
mul	doc_491521501796_item	3576669	et	3	main
on	doc_491521501796_item	3576670	et	4	main
probleemid	doc_491521501796_item	3576671	et	3	main
ka	doc_491521501796_item	3576672	et	3	main
annab	doc_491521501796_item	3576676	et	3	main
head	doc_491521501796_item	3576678	et	4	main
arvan	doc_491521501796_item	3576682	et	3	main
ta	doc_491521501796_item	3576684	et	4	main
kunagi	doc_491521501796_item	3576685	et	3	main
mind	doc_491521501796_item	3576686	et	4	main
kuid	doc_491521501796_item	3576689	et	4	main
ka	doc_491521501796_item	3576694	et	3	main
mul	doc_491521501796_item	3576707	et	3	main
mure	doc_491521501796_item	3576709	et	4	main
tähendab	doc_491521501796_item	3576714	et	3	main
mures	doc_491521501796_item	3576726	et	3	main
vahest	doc_491521501796_item	3576727	et	4	main
piisab	doc_491521501796_item	3576728	et	3	main
kas	doc_491521501796_item	3576739	et	3	main
on	doc_491521501796_item	3576741	et	4	main
sõber	doc_491521501796_item	3576743	et	3	main
vastust	doc_491521501796_item	3576744	et	4	main
et	doc_491521501796_item	3576747	et	3	main
tõelist	doc_491521501796_item	3576756	et	4	main
tõeline	doc_491521501796_item	3576761	et	4	main
sõber	doc_491521501796_item	3576762	et	3	main
ei	doc_491521501796_item	3576763	et	4	main
jätta	doc_491521501796_item	3576764	et	3	main
kunagi	doc_491521501796_item	3576765	et	3	main
inimestel	doc_491521501789_item	3576536	et	3	main
vanemate	doc_491521501789_item	3576546	et	4	main
mudeli	doc_491521501789_item	3576547	et	3	main
sellepärast	doc_491521501789_item	3576549	et	3	main
ei	doc_491521501789_item	3576554	et	4	main
kunagi	doc_491521501789_item	3576556	et	3	main
selle	doc_491521501789_item	3576557	et	4	main
laste	doc_491521501789_item	3576563	et	4	main
kaitsmiseks	doc_491521501789_item	3576566	et	4	main
kehtivad	doc_491521501789_item	3576568	et	4	main
igasugused	doc_491521501789_item	3576569	et	3	main
seadused	doc_491521501789_item	3576570	et	3	main
mulle	doc_491521501789_item	3576571	et	4	main
tundub	doc_491521501789_item	3576572	et	3	main
et	doc_491521501789_item	3576573	et	3	main
vägivald	doc_491521501789_item	3576574	et	3	main
on	doc_491521501789_item	3576575	et	4	main
ühiskonna	doc_491521501789_item	3576576	et	4	main
haigus	doc_491521501789_item	3576577	et	4	main
mis	doc_491521501789_item	3576578	et	4	main
peab	doc_491521501789_item	3576579	et	4	main
olema	doc_491521501789_item	3576580	et	4	main
ravitud	doc_491521501789_item	3576581	et	4	main
olen	doc_491521501789_item	3576582	et	3	main
kindel	doc_491521501789_item	3576583	et	3	main
et	doc_491521501789_item	3576584	et	3	main
vägivald	doc_491521501789_item	3576585	et	3	main
rohkem	doc_491521501789_item	3576587	et	4	main
on	doc_491521501789_item	3576586	et	4	main
levinud	doc_491521501789_item	3576588	et	4	main
riikides	doc_491521501789_item	3576589	et	3	main
kus	doc_491521501789_item	3576590	et	3	main
on	doc_491521501789_item	3576591	et	4	main
püsimata	doc_491521501789_item	3576592	et	4	main
olukord	doc_491521501789_item	3576593	et	3	main
tööpuudus	doc_491521501789_item	3576594	et	3	main
rahapuudus	doc_491521501789_item	3576595	et	3	main
elanikke	doc_491521501789_item	3576600	et	3	main
poole	doc_491521501789_item	3576605	et	4	main
asjade	doc_491521501789_item	3576615	et	3	main
hulka	doc_491521501789_item	3576616	et	4	main
takistavad	doc_491521501789_item	3576618	et	4	main
et	doc_491521501789_item	3576623	et	3	main
tulevikus	doc_491521501789_item	3576624	et	4	main
kannata	doc_491521501789_item	3576633	et	4	main
sõpra	doc_491521501796_item	3576639	et	4	main
on	doc_491521501796_item	3576643	et	4	main
palju	doc_491521501796_item	3576644	et	4	main
häid	doc_491521501796_item	3576645	et	3	main
tuttavaid	doc_491521501796_item	3576646	et	3	main
aga	doc_491521501796_item	3576647	et	3	main
sõpru	doc_491521501796_item	3576648	et	3	main
ma	doc_491521501796_item	3576655	et	3	main
see	doc_491521501796_item	3576660	et	3	main
inimene	doc_491521501796_item	3576662	et	3	main
aitab	doc_491521501796_item	3576666	et	3	main
alati	doc_491521501796_item	3576675	et	4	main
ja	doc_491521501796_item	3576680	et	3	main
ma	doc_491521501796_item	3576681	et	3	main
tuntakse	doc_491521501796_item	3576640	et	3	main
on	doc_491521501796_item	3576652	et	4	main
tõeline	doc_491521501796_item	3576658	et	4	main
tõeline	doc_491521501796_item	3576673	et	4	main
ei	doc_491521501796_item	3576687	et	4	main
see	doc_491521501796_item	3576697	et	3	main
kõige	doc_491521501796_item	3576699	et	4	main
parem	doc_491521501796_item	3576700	et	4	main
sõber	doc_491521501796_item	3576701	et	3	main
aga	doc_491521501796_item	3576702	et	3	main
ta	doc_491521501796_item	3576710	et	4	main
on	doc_491521501796_item	3576711	et	4	main
et	doc_491521501796_item	3576715	et	3	main
mind	doc_491521501796_item	3576725	et	4	main
toetusest	doc_491521501796_item	3576733	et	4	main
nii	doc_491521501796_item	3576734	et	3	main
ma	doc_491521501796_item	3576735	et	3	main
arvan	doc_491521501796_item	3576736	et	3	main
tekkib	doc_491521501796_item	3576737	et	3	main
sõber	doc_491521501796_item	3576752	et	3	main
minu	doc_491521501796_item	3576753	et	3	main
arvates	doc_491521501796_item	3576754	et	4	main
et	doc_491521501796_item	3576755	et	3	main
ära	doc_491521501796_item	3576759	et	4	main
hädas	doc_491521501796_item	3576760	et	3	main
kes	doc_491521501796_item	3576663	et	4	main
ka	doc_491521501796_item	3576677	et	3	main
nõu	doc_491521501796_item	3576679	et	4	main
reeda	doc_491521501796_item	3576688	et	4	main
elu	doc_491521501796_item	3576690	et	4	main
näitab	doc_491521501796_item	3576691	et	3	main
et	doc_491521501796_item	3576692	et	3	main
juhtub	doc_491521501796_item	3576693	et	3	main
kadunud	doc_491521501796_item	3576712	et	4	main
see	doc_491521501796_item	3576713	et	3	main
ei	doc_491521501796_item	3576717	et	4	main
aega	doc_491521501796_item	3576719	et	4	main
minuga	doc_491521501796_item	3576720	et	3	main
kohtuda	doc_491521501796_item	3576721	et	3	main
vestelda	doc_491521501796_item	3576722	et	4	main
sõpra	doc_491521501796_item	3576729	et	4	main
mästmine	doc_491521501796_item	3576730	et	4	main
ja	doc_491521501796_item	3576731	et	3	main
sõbra	doc_491521501796_item	3576732	et	3	main
küsimus	doc_491521501796_item	3576738	et	4	main
tõeline	doc_491521501796_item	3576751	et	4	main
maha	doc_491521501796_item	3576768	et	4	main
et	doc_491521501796_item	3576683	et	3	main
arvad	doc_491521501796_item	3576696	et	3	main
on	doc_491521501796_item	3576698	et	4	main
selgub	doc_491521501796_item	3576703	et	3	main
et	doc_491521501796_item	3576704	et	3	main
kui	doc_491521501796_item	3576705	et	3	main
on	doc_491521501796_item	3576706	et	4	main
ja	doc_491521501796_item	3576723	et	3	main
aidata	doc_491521501796_item	3576724	et	4	main
see	doc_491521501796_item	3576740	et	3	main
tõeline	doc_491521501796_item	3576742	et	4	main
see	doc_491521501796_item	3576748	et	3	main
ei	doc_491521501796_item	3576749	et	4	main
ole	doc_491521501796_item	3576750	et	4	main
sõpra	doc_491521501796_item	3576757	et	4	main
mind	doc_491521501796_item	3576766	et	4	main
hädas	doc_491521501796_item	3576767	et	3	main
ma	doc_491521501796_item	3576745	et	3	main
arvan	doc_491521501796_item	3576746	et	3	main
tuntakse	doc_491521501796_item	3576758	et	3	main
tõeline	doc_491521501796_item	3576769	et	4	main
sõber	doc_491521501796_item	3576770	et	3	main
leiab	doc_491521501796_item	3576771	et	3	main
alati	doc_491521501796_item	3576772	et	4	main
aega	doc_491521501796_item	3576773	et	4	main
oma	doc_491521501796_item	3576774	et	4	main
sõbra	doc_491521501796_item	3576775	et	3	main
jaoks	doc_491521501796_item	3576776	et	4	main
ta	doc_491521501796_item	3576777	et	4	main
kuulab	doc_491521501796_item	3576778	et	3	main
mind	doc_491521501796_item	3576779	et	4	main
ära	doc_491521501796_item	3576780	et	4	main
annab	doc_491521501796_item	3576781	et	3	main
head	doc_491521501796_item	3576782	et	4	main
nõu	doc_491521501796_item	3576783	et	4	main
ja	doc_491521501796_item	3576784	et	3	main
aitab	doc_491521501796_item	3576785	et	3	main
kindlasti	doc_491521501796_item	3576786	et	3	main
mind	doc_491521501796_item	3576787	et	4	main
ma	doc_491521501796_item	3576788	et	3	main
olen	doc_491521501796_item	3576789	et	3	main
sellest	doc_491521501796_item	3576790	et	4	main
kindal	doc_491521501796_item	3576791	et	3	main
õnn	doc_491521501917_item	3577343	et	3	main
perekond	doc_491521501917_item	3577348	et	3	main
me	doc_491521501917_item	3577352	et	4	main
ruumi	doc_491521501917_item	3577356	et	4	main
rahuldav	doc_491521501917_item	3577362	et	4	main
alati	doc_491521501917_item	3577368	et	4	main
kõrgelt	doc_491521501917_item	3577369	et	4	main
ei	doc_491521501917_item	3577415	et	4	main
ma	doc_491521501991_item	3577442	et	3	main
eesti	doc_491521501991_item	3577445	et	4	main
kolmas	doc_491521501991_item	3577447	et	3	main
sõnu	doc_491521501991_item	3577456	et	4	main
sõltub	doc_491521501917_item	3577344	et	3	main
küttetud	doc_491521501917_item	3577355	et	4	main
eest	doc_491521501917_item	3577357	et	4	main
õuest	doc_491521501917_item	3577372	et	4	main
said	doc_491521501917_item	3577377	et	4	main
täiskasvanuteks	doc_491521501917_item	3577378	et	3	main
keskmisel	doc_491521501917_item	3577379	et	3	main
rahuldavad	doc_491521501917_item	3577416	et	4	main
essee	doc_491521501991_item	3577435	et	4	main
algasin	doc_491521501991_item	3577443	et	3	main
klassini	doc_491521501991_item	3577450	et	3	main
ültse	doc_491521501991_item	3577452	et	4	main
ühtegi	doc_491521501991_item	3577455	et	4	main
olid	doc_491521501991_item	3577458	et	4	main
kahed	doc_491521501991_item	3577461	et	3	main
koolivaheag	doc_491521501991_item	3577474	et	4	main
ma	doc_491521501991_item	3577475	et	3	main
tutvustasin	doc_491521501991_item	3577476	et	3	main
käis	doc_491521501991_item	3577483	et	4	main
minu	doc_491521501991_item	3577484	et	3	main
saa	doc_491521501991_item	3577496	et	4	main
mida	doc_491521501991_item	3577498	et	4	main
räägid	doc_491521501991_item	3577500	et	4	main
õppida	doc_491521501991_item	3577536	et	3	main
pärast	doc_491521501991_item	3577541	et	4	main
minu	doc_491521501991_item	3577547	et	3	main
vend	doc_491521501991_item	3577548	et	3	main
mind	doc_491521501991_item	3577555	et	4	main
ma	doc_491521501991_item	3577570	et	3	main
aitasid	doc_491521501991_item	3577574	et	4	main
mind	doc_491521501991_item	3577575	et	4	main
pärast	doc_491521501991_item	3577576	et	4	main
ma	doc_491521501991_item	3577577	et	3	main
käisin	doc_491521501991_item	3577578	et	3	main
keelt	doc_491521501991_item	3577586	et	4	main
ma	doc_491521501991_item	3577587	et	3	main
käisin	doc_491521501991_item	3577588	et	3	main
tead	doc_491521501991_item	3577594	et	4	main
nüüd	doc_491521501991_item	3577600	et	4	main
ma	doc_491521501991_item	3577601	et	3	main
räägin	doc_491521501991_item	3577602	et	3	main
essee	doc_491521501917_item	3577342	et	4	main
meie	doc_491521501917_item	3577347	et	4	main
mitmekorruselises	doc_491521501917_item	3577350	et	4	main
on	doc_491521501917_item	3577361	et	4	main
on	doc_491521501917_item	3577367	et	4	main
kuuldud	doc_491521501917_item	3577371	et	4	main
mugavuste	doc_491521501917_item	3577417	et	4	main
ma	doc_491521501991_item	3577437	et	3	main
eesti	doc_491521501991_item	3577439	et	4	main
keelt	doc_491521501991_item	3577440	et	4	main
ma	doc_491521501991_item	3577451	et	3	main
ma	doc_491521501991_item	3577462	et	3	main
saanud	doc_491521501991_item	3577464	et	4	main
mul	doc_491521501991_item	3577466	et	3	main
tütrukuga	doc_491521501991_item	3577478	et	4	main
ja	doc_491521501991_item	3577486	et	3	main
keeles	doc_491521501991_item	3577490	et	4	main
need	doc_491521501991_item	3577537	et	3	main
ma	doc_491521501991_item	3577542	et	3	main
keeles	doc_491521501991_item	3577551	et	4	main
aitab	doc_491521501991_item	3577554	et	3	main
mul	doc_491521501991_item	3577557	et	3	main
ei	doc_491521501991_item	3577558	et	4	main
suhtlesin	doc_491521501991_item	3577571	et	3	main
nad	doc_491521501991_item	3577573	et	3	main
pärast	doc_491521501991_item	3577591	et	4	main
ma	doc_491521501991_item	3577592	et	3	main
saan	doc_491521501991_item	3577593	et	4	main
parem	doc_491521501991_item	3577599	et	4	main
vigu	doc_491521501991_item	3577609	et	3	main
sooritada	doc_491521501991_item	3577613	et	3	main
käin	doc_491521501991_item	3577635	et	3	main
kursusele	doc_491521501991_item	3577636	et	3	main
nimi	doc_491521501993_item	3577659	et	3	main
olen	doc_491521501993_item	3577663	et	3	main
ei	doc_491521501993_item	3577672	et	4	main
tööta	doc_491521501993_item	3577673	et	4	main
ma	doc_491521501993_item	3577674	et	3	main
käin	doc_491521501993_item	3577675	et	3	main
jõhvis	doc_491521501993_item	3577676	et	3	main
kursusel	doc_491521501993_item	3577677	et	3	main
kaks	doc_491521501993_item	3577698	et	3	main
last	doc_491521501993_item	3577699	et	4	main
esimene	doc_491521501993_item	3577700	et	3	main
laps	doc_491521501993_item	3577706	et	4	main
nikolai	doc_491521501993_item	3577707	et	4	main
kaks	doc_491521501993_item	3577708	et	3	main
ja	doc_491521501993_item	3577709	et	3	main
kolm	doc_491521501993_item	3577710	et	3	main
veel	doc_491521501993_item	3577723	et	4	main
pisiasjadest	doc_491521501917_item	3577346	et	3	main
elab	doc_491521501917_item	3577349	et	3	main
halvasti	doc_491521501917_item	3577354	et	3	main
abielus	doc_491521501917_item	3577358	et	4	main
elavad	doc_491521501917_item	3577359	et	4	main
inimesed	doc_491521501917_item	3577360	et	3	main
head	doc_491521501917_item	3577365	et	4	main
elutingimused	doc_491521501917_item	3577366	et	3	main
rikub	doc_491521501917_item	3577374	et	3	main
lapsed	doc_491521501917_item	3577376	et	3	main
puudumistega	doc_491521501917_item	3577418	et	4	main
kaebame	doc_491521501917_item	3577420	et	3	main
kõrge	doc_491521501917_item	3577421	et	4	main
elatud	doc_491521501917_item	3577422	et	4	main
korterist	doc_491521501917_item	3577423	et	3	main
noored	doc_491521501917_item	3577424	et	3	main
perekonnad	doc_491521501917_item	3577425	et	4	main
elavad	doc_491521501917_item	3577426	et	4	main
eraldi	doc_491521501917_item	3577427	et	4	main
tolmu	doc_491521501917_item	3577428	et	4	main
segab	doc_491521501917_item	3577429	et	3	main
majapidamises	doc_491521501917_item	3577430	et	3	main
autogaasid	doc_491521501917_item	3577431	et	3	main
on	doc_491521501917_item	3577432	et	4	main
kahjulikud	doc_491521501917_item	3577433	et	3	main
sageli	doc_491521501917_item	3577345	et	3	main
majas	doc_491521501917_item	3577351	et	3	main
kaebame	doc_491521501917_item	3577353	et	3	main
teineteise	doc_491521501917_item	3577363	et	4	main
suhtudega	doc_491521501917_item	3577364	et	4	main
hinnatud	doc_491521501917_item	3577370	et	4	main
müra	doc_491521501917_item	3577373	et	4	main
kodukorda	doc_491521501917_item	3577375	et	4	main
perekonnal	doc_491521501917_item	3577380	et	4	main
on	doc_491521501917_item	3577381	et	4	main
keskküte	doc_491521501917_item	3577382	et	3	main
olemas	doc_491521501917_item	3577383	et	4	main
pereliikmete	doc_491521501917_item	3577384	et	3	main
arv	doc_491521501917_item	3577385	et	3	main
suureneb	doc_491521501917_item	3577386	et	3	main
ruumide	doc_491521501917_item	3577387	et	3	main
arvu	doc_491521501917_item	3577388	et	4	main
kõige	doc_491521501917_item	3577389	et	4	main
rohkem	doc_491521501917_item	3577390	et	4	main
ma	doc_491521501917_item	3577391	et	3	main
hoolitsen	doc_491521501917_item	3577392	et	3	main
oma	doc_491521501917_item	3577393	et	4	main
perekonnaliikmete	doc_491521501917_item	3577394	et	3	main
tervise	doc_491521501917_item	3577395	et	3	main
eest	doc_491521501917_item	3577396	et	4	main
korteri	doc_491521501917_item	3577397	et	3	main
sisustus	doc_491521501917_item	3577398	et	4	main
mööbel	doc_491521501917_item	3577399	et	3	main
on	doc_491521501917_item	3577400	et	4	main
vana	doc_491521501917_item	3577401	et	4	main
noortel	doc_491521501917_item	3577402	et	3	main
peredel	doc_491521501917_item	3577403	et	3	main
on	doc_491521501917_item	3577404	et	4	main
raske	doc_491521501917_item	3577405	et	4	main
omandada	doc_491521501917_item	3577406	et	3	main
eraldit	doc_491521501917_item	3577407	et	3	main
eluruumi	doc_491521501917_item	3577408	et	4	main
olmetehnika	doc_491521501917_item	3577409	et	4	main
on	doc_491521501917_item	3577410	et	4	main
heas	doc_491521501917_item	3577411	et	3	main
seisundis	doc_491521501917_item	3577412	et	3	main
paljud	doc_491521501917_item	3577413	et	3	main
perekonnad	doc_491521501917_item	3577414	et	4	main
me	doc_491521501917_item	3577419	et	4	main
kuidas	doc_491521501991_item	3577436	et	3	main
õpin	doc_491521501991_item	3577438	et	3	main
280803	doc_491521501991_item	3577441	et	2	main
keelt	doc_491521501991_item	3577446	et	4	main
kaheksani	doc_491521501991_item	3577449	et	3	main
ei	doc_491521501991_item	3577453	et	4	main
teadnu	doc_491521501991_item	3577454	et	4	main
oli	doc_491521501991_item	3577467	et	3	main
vigu	doc_491521501991_item	3577469	et	3	main
meil	doc_491521501991_item	3577472	et	4	main
olik	doc_491521501991_item	3577473	et	4	main
minuga	doc_491521501991_item	3577488	et	3	main
mind	doc_491521501991_item	3577535	et	4	main
ma	doc_491521501991_item	3577539	et	3	main
eestkeelt	doc_491521501991_item	3577546	et	4	main
eesti	doc_491521501991_item	3577550	et	4	main
elavad	doc_491521501991_item	3577567	et	4	main
nengega	doc_491521501991_item	3577572	et	4	main
olid	doc_491521501991_item	3577582	et	4	main
kooli	doc_491521501991_item	3577590	et	4	main
eesti	doc_491521501991_item	3577595	et	4	main
mul	doc_491521501991_item	3577607	et	3	main
on	doc_491521501991_item	3577615	et	4	main
ta	doc_491521501991_item	3577617	et	4	main
ma	doc_491521501991_item	3577621	et	3	main
räägin	doc_491521501991_item	3577622	et	3	main
essee	doc_491521501993_item	3577650	et	4	main
ja	doc_491521501993_item	3577652	et	3	main
pere	doc_491521501993_item	3577654	et	4	main
minu	doc_491521501993_item	3577655	et	3	main
tere	doc_491521501993_item	3577657	et	3	main
kahekümne	doc_491521501993_item	3577664	et	4	main
kohtla-järvel	doc_491521501993_item	3577669	et	4	main
praegu	doc_491521501993_item	3577670	et	3	main
ma	doc_491521501993_item	3577671	et	3	main
armastan	doc_491521501993_item	3577686	et	3	main
ja	doc_491521501993_item	3577704	et	3	main
teine	doc_491521501993_item	3577705	et	3	main
vanemad	doc_491521501993_item	3577718	et	4	main
ja	doc_491521501993_item	3577719	et	3	main
vend	doc_491521501993_item	3577720	et	3	main
minu	doc_491521501993_item	3577721	et	3	main
vanemad	doc_491521501993_item	3577722	et	4	main
asatane	doc_491521501993_item	3577734	et	4	main
ja	doc_491521501993_item	3577735	et	3	main
venale	doc_491521501993_item	3577736	et	4	main
töötab	doc_491521501993_item	3577747	et	3	main
vara	doc_491521501993_item	3577782	et	4	main
tõusema	doc_491521501993_item	3577783	et	4	main
ja	doc_491521501993_item	3577784	et	3	main
ma	doc_491521501993_item	3577789	et	3	main
seal	doc_491521501993_item	3577793	et	4	main
õpin	doc_491521501993_item	3577795	et	3	main
keelt	doc_491521501993_item	3577797	et	4	main
hiljem	doc_491521501993_item	3577798	et	3	main
ma	doc_491521501993_item	3577799	et	3	main
lähen	doc_491521501993_item	3577800	et	3	main
koju	doc_491521501993_item	3577801	et	3	main
aga	doc_491521501993_item	3577802	et	3	main
kodus	doc_491521501993_item	3577803	et	4	main
minul	doc_491521501993_item	3577804	et	3	main
väga	doc_491521501993_item	3577805	et	3	main
tööd	doc_491521501993_item	3577808	et	4	main
ramatiud	doc_491521501993_item	3577822	et	4	main
filmist	doc_491521502149_item	3577825	et	4	main
leninid	doc_491521502149_item	3577832	et	4	main
natuke	doc_491521502149_item	3577833	et	4	main
rääkida	doc_491521502149_item	3577834	et	3	main
taas	doc_491521502149_item	3577835	et	3	main
kogesin	doc_491521502149_item	3577836	et	3	main
seaduspärasusi	doc_491521502149_item	3577857	et	4	main
traditsioone	doc_491521502149_item	3577861	et	3	main
tehakse	doc_491521502149_item	3577865	et	3	main
nüüd	doc_491521502149_item	3577867	et	4	main
volmeri	doc_491521502149_item	3577869	et	4	main
filmis	doc_491521502149_item	3577870	et	4	main
film	doc_491521502149_item	3577871	et	3	main
minu	doc_491521502149_item	3577872	et	3	main
asjad	doc_491521502149_item	3577879	et	3	main
kes	doc_491521501991_item	3577637	et	4	main
me	doc_491521501991_item	3577638	et	4	main
õpime	doc_491521501991_item	3577639	et	3	main
eesti	doc_491521501991_item	3577640	et	4	main
keelt	doc_491521501991_item	3577641	et	4	main
juba	doc_491521501991_item	3577642	et	3	main
kuu	doc_491521501991_item	3577643	et	4	main
nüüd	doc_491521501991_item	3577644	et	4	main
ma	doc_491521501991_item	3577645	et	3	main
saan	doc_491521501991_item	3577646	et	4	main
kõik	doc_491521501991_item	3577647	et	4	main
aru	doc_491521501991_item	3577648	et	4	main
õpima	doc_491521501991_item	3577444	et	4	main
klassis	doc_491521501991_item	3577448	et	3	main
ei	doc_491521501991_item	3577463	et	4	main
kirjutada	doc_491521501991_item	3577465	et	3	main
ühe	doc_491521501991_item	3577477	et	4	main
ta	doc_491521501991_item	3577479	et	4	main
oli	doc_491521501991_item	3577480	et	3	main
eestlane	doc_491521501991_item	3577481	et	3	main
ta	doc_491521501991_item	3577482	et	4	main
rääkis	doc_491521501991_item	3577487	et	3	main
ta	doc_491521501991_item	3577501	et	4	main
ütles	doc_491521501991_item	3577502	et	3	main
aga	doc_491521501991_item	3577503	et	3	main
kuida	doc_491521501991_item	3577504	et	4	main
sa	doc_491521501991_item	3577505	et	3	main
koolis	doc_491521501991_item	3577506	et	4	main
õpid	doc_491521501991_item	3577507	et	4	main
eesti	doc_491521501991_item	3577508	et	4	main
keel	doc_491521501991_item	3577509	et	4	main
et	doc_491521501991_item	3577510	et	3	main
sa	doc_491521501991_item	3577511	et	3	main
midagi	doc_491521501991_item	3577512	et	4	main
ei	doc_491521501991_item	3577513	et	4	main
tea	doc_491521501991_item	3577514	et	4	main
ta	doc_491521501991_item	3577515	et	4	main
aitas	doc_491521501991_item	3577516	et	3	main
mind	doc_491521501991_item	3577517	et	4	main
ta	doc_491521501991_item	3577518	et	4	main
kirjutas	doc_491521501991_item	3577519	et	3	main
mulle	doc_491521501991_item	3577520	et	4	main
palju	doc_491521501991_item	3577521	et	4	main
harjutusi	doc_491521501991_item	3577522	et	4	main
ja	doc_491521501991_item	3577523	et	3	main
ma	doc_491521501991_item	3577524	et	3	main
tegin	doc_491521501991_item	3577525	et	3	main
mul	doc_491521501991_item	3577526	et	3	main
oli	doc_491521501991_item	3577527	et	3	main
palju	doc_491521501991_item	3577528	et	4	main
vigu	doc_491521501991_item	3577529	et	3	main
ta	doc_491521501991_item	3577530	et	4	main
parandas	doc_491521501991_item	3577531	et	3	main
ja	doc_491521501991_item	3577532	et	3	main
ta	doc_491521501991_item	3577533	et	4	main
sundis	doc_491521501991_item	3577534	et	3	main
mul	doc_491521501991_item	3577457	et	3	main
kolmed	doc_491521501991_item	3577459	et	3	main
ja	doc_491521501991_item	3577460	et	3	main
palju	doc_491521501991_item	3577468	et	4	main
pärast	doc_491521501991_item	3577470	et	4	main
kui	doc_491521501991_item	3577471	et	3	main
juurde	doc_491521501991_item	3577485	et	4	main
eesti	doc_491521501991_item	3577489	et	4	main
ma	doc_491521501991_item	3577491	et	3	main
ütles	doc_491521501991_item	3577492	et	3	main
et	doc_491521501991_item	3577493	et	3	main
ma	doc_491521501991_item	3577494	et	3	main
ei	doc_491521501991_item	3577495	et	4	main
aru	doc_491521501991_item	3577497	et	4	main
sa	doc_491521501991_item	3577499	et	3	main
juba	doc_491521501991_item	3577543	et	3	main
temaga	doc_491521501991_item	3577545	et	3	main
räägib	doc_491521501991_item	3577549	et	3	main
ta	doc_491521501991_item	3577553	et	4	main
ainult	doc_491521501991_item	3577568	et	4	main
eestlased	doc_491521501991_item	3577569	et	3	main
spestialid	doc_491521501991_item	3577583	et	4	main
tunnid	doc_491521501991_item	3577584	et	3	main
eesti	doc_491521501991_item	3577585	et	4	main
parem	doc_491521501991_item	3577597	et	4	main
ja	doc_491521501991_item	3577598	et	3	main
ja	doc_491521501991_item	3577610	et	3	main
tahan	doc_491521501991_item	3577611	et	3	main
õepoeg	doc_491521501991_item	3577616	et	3	main
on	doc_491521501991_item	3577618	et	4	main
eestlane	doc_491521501991_item	3577619	et	3	main
ja	doc_491521501991_item	3577620	et	3	main
mina	doc_491521501993_item	3577651	et	4	main
on	doc_491521501993_item	3577660	et	4	main
kuue	doc_491521501993_item	3577665	et	4	main
ma	doc_491521501993_item	3577667	et	3	main
on	doc_491521501993_item	3577702	et	4	main
dimitri	doc_491521501993_item	3577703	et	4	main
käevad	doc_491521501993_item	3577713	et	4	main
minul	doc_491521501993_item	3577716	et	3	main
on	doc_491521501993_item	3577717	et	4	main
on	doc_491521501993_item	3577726	et	4	main
neljakümne	doc_491521501993_item	3577727	et	4	main
ja	doc_491521501993_item	3577730	et	3	main
viiekümne	doc_491521501993_item	3577733	et	4	main
aastane	doc_491521501993_item	3577739	et	4	main
vanemad	doc_491521501993_item	3577740	et	4	main
töötavad	doc_491521501993_item	3577741	et	4	main
aga	doc_491521501993_item	3577742	et	3	main
vend	doc_491521501993_item	3577743	et	3	main
eesti	doc_491521501993_item	3577748	et	4	main
minu	doc_491521501993_item	3577777	et	3	main
päev	doc_491521501993_item	3577778	et	3	main
hommikul	doc_491521501993_item	3577779	et	3	main
ma	doc_491521501993_item	3577780	et	3	main
pean	doc_491521501993_item	3577781	et	4	main
posisd	doc_491521501993_item	3577785	et	4	main
lasteada	doc_491521501993_item	3577786	et	4	main
viima	doc_491521501993_item	3577787	et	3	main
väga	doc_491521501993_item	3577809	et	3	main
ma	doc_491521501993_item	3577811	et	3	main
essee	doc_491521502149_item	3577824	et	4	main
sellist	doc_491521502149_item	3577837	et	4	main
gumpi	doc_491521502149_item	3577844	et	4	main
fenomeniks	doc_491521502149_item	3577845	et	3	main
nii	doc_491521502149_item	3577846	et	3	main
nagu	doc_491521502149_item	3577847	et	3	main
selle	doc_491521502149_item	3577848	et	4	main
ameerika	doc_491521502149_item	3577849	et	3	main
filmi	doc_491521502149_item	3577850	et	4	main
kohta	doc_491521502149_item	3577851	et	4	main
selle	doc_491521502149_item	3577858	et	4	main
maa	doc_491521502149_item	3577859	et	4	main
seda	doc_491521502149_item	3577866	et	3	main
mis	doc_491521502149_item	3577880	et	4	main
on	doc_491521502149_item	3577890	et	4	main
filmis	doc_491521502149_item	3577895	et	4	main
on	doc_491521502149_item	3577896	et	4	main
kesküla	doc_491521502149_item	3577926	et	4	main
arvasid	doc_491521502149_item	3577927	et	4	main
et	doc_491521502149_item	3577928	et	3	main
asemel	doc_491521502149_item	3577943	et	4	main
mis	doc_491521502149_item	3577952	et	4	main
vigud	doc_491521501991_item	3577538	et	4	main
õpisin	doc_491521501991_item	3577540	et	4	main
rääkisin	doc_491521501991_item	3577544	et	3	main
ja	doc_491521501991_item	3577552	et	3	main
kui	doc_491521501991_item	3577556	et	3	main
ole	doc_491521501991_item	3577559	et	4	main
õigeta	doc_491521501991_item	3577560	et	3	main
räägib	doc_491521501991_item	3577561	et	3	main
minuga	doc_491521501991_item	3577562	et	3	main
ma	doc_491521501991_item	3577563	et	3	main
elan	doc_491521501991_item	3577564	et	3	main
külas	doc_491521501991_item	3577565	et	3	main
kus	doc_491521501991_item	3577566	et	3	main
kooli	doc_491521501991_item	3577579	et	4	main
kus	doc_491521501991_item	3577580	et	3	main
mul	doc_491521501991_item	3577581	et	3	main
eesti	doc_491521501991_item	3577589	et	4	main
keelt	doc_491521501991_item	3577596	et	4	main
on	doc_491521501991_item	3577608	et	4	main
eksamit	doc_491521501991_item	3577612	et	3	main
mul	doc_491521501991_item	3577614	et	3	main
temaga	doc_491521501991_item	3577623	et	3	main
ta	doc_491521501991_item	3577624	et	4	main
käib	doc_491521501991_item	3577625	et	3	main
minu	doc_491521501991_item	3577626	et	3	main
iga	doc_491521501991_item	3577627	et	4	main
päev	doc_491521501991_item	3577628	et	3	main
ja	doc_491521501991_item	3577629	et	3	main
m	doc_491521501991_item	3577630	et	4	main
e	doc_491521501991_item	3577631	et	4	main
suhleme	doc_491521501991_item	3577632	et	4	main
nüüd	doc_491521501991_item	3577633	et	4	main
ma	doc_491521501991_item	3577634	et	3	main
aga	doc_491521501991_item	3577603	et	3	main
ma	doc_491521501991_item	3577604	et	3	main
tean	doc_491521501991_item	3577605	et	3	main
et	doc_491521501991_item	3577606	et	3	main
minu	doc_491521501993_item	3577658	et	3	main
ma	doc_491521501993_item	3577662	et	3	main
aastane	doc_491521501993_item	3577666	et	4	main
elan	doc_491521501993_item	3577668	et	3	main
väga	doc_491521501993_item	3577685	et	3	main
nad	doc_491521501993_item	3577712	et	3	main
samuti	doc_491521501993_item	3577715	et	3	main
kaheksa	doc_491521501993_item	3577728	et	4	main
käin	doc_491521501993_item	3577790	et	3	main
ja	doc_491521501993_item	3577792	et	3	main
ma	doc_491521501993_item	3577794	et	3	main
eesti	doc_491521501993_item	3577796	et	4	main
harv	doc_491521501993_item	3577810	et	3	main
saan	doc_491521501993_item	3577812	et	4	main
leninid	doc_491521502149_item	3577827	et	4	main
filmi	doc_491521502149_item	3577829	et	4	main
minu	doc_491521502149_item	3577831	et	3	main
jaoks	doc_491521502149_item	3577840	et	4	main
olen	doc_491521502149_item	3577841	et	3	main
ameerika	doc_491521502149_item	3577855	et	3	main
elu	doc_491521502149_item	3577856	et	4	main
ajaloolisi	doc_491521502149_item	3577860	et	4	main
ka	doc_491521502149_item	3577868	et	3	main
leninid	doc_491521502149_item	3577873	et	4	main
meeldis	doc_491521502149_item	3577874	et	3	main
volmeri	doc_491521502149_item	3577891	et	4	main
suur-eestimaa	doc_491521502149_item	3577924	et	4	main
venemaa	doc_491521502149_item	3577942	et	4	main
väikseid	doc_491521502149_item	3577949	et	4	main
riike	doc_491521502149_item	3577950	et	3	main
rahvusriike	doc_491521502149_item	3577951	et	3	main
puutub	doc_491521502149_item	3577953	et	3	main
oli	doc_491521502149_item	3577960	et	3	main
teine	doc_491521502149_item	3577962	et	3	main
ei	doc_491521502149_item	3577976	et	4	main
saa	doc_491521502149_item	3577986	et	4	main
seletada	doc_491521502149_item	3577987	et	3	main
sellele	doc_491521502149_item	3577994	et	4	main
et	doc_491521502149_item	3577995	et	3	main
inimene	doc_491521502149_item	3577999	et	3	main
berliini	doc_491521502149_item	3578025	et	4	main
ülikoolis	doc_491521502149_item	3578030	et	4	main
tähtsam	doc_491521502149_item	3578039	et	4	main
suurest-eestimaast	doc_491521502149_item	3578043	et	3	main
komöödias	doc_491521502150_item	3578083	et	4	main
mängib	doc_491521502150_item	3578088	et	3	main
revolutsionäär	doc_491521502150_item	3578090	et	3	main
kesküla	doc_491521502150_item	3578092	et	4	main
revolütsionääridel	doc_491521502150_item	3578098	et	4	main
võtta	doc_491521502150_item	3578099	et	3	main
võimu	doc_491521502150_item	3578100	et	4	main
muutsid	doc_491521502150_item	3578107	et	4	main
ajalugu	doc_491521502150_item	3578108	et	4	main
ja	doc_491521502150_item	3578109	et	3	main
palju	doc_491521502150_item	3578116	et	4	main
õppetunnid	doc_491521502150_item	3578129	et	3	main
teisikute	doc_491521502150_item	3578130	et	3	main
koolis	doc_491521502150_item	3578131	et	4	main
mõte	doc_491521502150_item	3578133	et	3	main
väga	doc_491521502150_item	3578137	et	3	main
leninite	doc_491521502150_item	3578148	et	4	main
revolütsionäärist	doc_491521502150_item	3578184	et	4	main
ta	doc_491521502150_item	3578201	et	4	main
kujutab	doc_491521502150_item	3578202	et	3	main
suurt	doc_491521502150_item	3578203	et	3	main
inimesed	doc_491521502150_item	3578234	et	3	main
see	doc_491521502155_item	3578244	et	3	main
vastandlikud	doc_491521502155_item	3578246	et	4	main
mulje	doc_491521502155_item	3578247	et	4	main
mis	doc_491521502155_item	3578252	et	4	main
ja	doc_491521502155_item	3578257	et	3	main
tema	doc_491521502155_item	3578273	et	4	main
panusel	doc_491521502155_item	3578274	et	3	main
sotsialistliku	doc_491521502155_item	3578276	et	3	main
oktoobrirevolutsiooni	doc_491521502155_item	3578277	et	4	main
venemaa	doc_491521502155_item	3578287	et	4	main
jätkuvalt	doc_491521502155_item	3578299	et	4	main
minu	doc_491521501993_item	3577653	et	3	main
päev	doc_491521501993_item	3577656	et	3	main
eesnimi	doc_491521501993_item	3577661	et	3	main
mulle	doc_491521501993_item	3577678	et	4	main
meeldib	doc_491521501993_item	3577679	et	3	main
iga	doc_491521501993_item	3577680	et	4	main
päevad	doc_491521501993_item	3577681	et	3	main
käisin	doc_491521501993_item	3577682	et	3	main
spordisaalis	doc_491521501993_item	3577683	et	3	main
ma	doc_491521501993_item	3577684	et	3	main
tegin	doc_491521501993_item	3577687	et	3	main
erinevad	doc_491521501993_item	3577688	et	4	main
pehme	doc_491521501993_item	3577689	et	4	main
mänguasjad	doc_491521501993_item	3577690	et	3	main
mul	doc_491521501993_item	3577691	et	3	main
ei	doc_491521501993_item	3577692	et	4	main
ole	doc_491521501993_item	3577693	et	4	main
suur	doc_491521501993_item	3577694	et	3	main
pere	doc_491521501993_item	3577695	et	4	main
meil	doc_491521501993_item	3577696	et	4	main
on	doc_491521501993_item	3577697	et	4	main
laps	doc_491521501993_item	3577701	et	4	main
aastat	doc_491521501993_item	3577711	et	3	main
lasteaias	doc_491521501993_item	3577714	et	4	main
noored	doc_491521501993_item	3577724	et	3	main
isale	doc_491521501993_item	3577731	et	3	main
ühe	doc_491521501993_item	3577738	et	4	main
isa	doc_491521501993_item	3577746	et	4	main
ema	doc_491521501993_item	3577750	et	4	main
ka	doc_491521501993_item	3577751	et	3	main
minu	doc_491521501993_item	3577752	et	3	main
vanemad	doc_491521501993_item	3577753	et	4	main
elavad	doc_491521501993_item	3577754	et	4	main
oma	doc_491521501993_item	3577755	et	4	main
majas	doc_491521501993_item	3577756	et	3	main
temal	doc_491521501993_item	3577757	et	3	main
on	doc_491521501993_item	3577758	et	4	main
suur	doc_491521501993_item	3577759	et	3	main
maja	doc_491521501993_item	3577760	et	4	main
ja	doc_491521501993_item	3577761	et	3	main
samuti	doc_491521501993_item	3577762	et	3	main
suur	doc_491521501993_item	3577763	et	3	main
aeg	doc_491521501993_item	3577764	et	3	main
suvel	doc_491521501993_item	3577765	et	3	main
me	doc_491521501993_item	3577766	et	4	main
armastame	doc_491521501993_item	3577767	et	3	main
kõik	doc_491521501993_item	3577768	et	4	main
koos	doc_491521501993_item	3577769	et	4	main
puhkavad	doc_491521501993_item	3577770	et	4	main
meere	doc_491521501993_item	3577771	et	4	main
ääres	doc_491521501993_item	3577772	et	4	main
minul	doc_491521501993_item	3577773	et	3	main
on	doc_491521501993_item	3577774	et	4	main
alati	doc_491521501993_item	3577775	et	4	main
raske	doc_491521501993_item	3577776	et	4	main
kursusele	doc_491521501993_item	3577791	et	3	main
erinevad	doc_491521501993_item	3577807	et	4	main
vaatama	doc_491521501993_item	3577813	et	3	main
telerit	doc_491521501993_item	3577814	et	3	main
see-eest	doc_491521501993_item	3577816	et	4	main
ööel	doc_491521501993_item	3577817	et	4	main
aga	doc_491521501993_item	3577815	et	3	main
väga	doc_491521501993_item	3577818	et	3	main
tihti	doc_491521501993_item	3577819	et	3	main
ma	doc_491521501993_item	3577820	et	3	main
lugen	doc_491521501993_item	3577821	et	4	main
emale	doc_491521501993_item	3577725	et	3	main
aastane	doc_491521501993_item	3577729	et	4	main
on	doc_491521501993_item	3577732	et	4	main
kahekümne	doc_491521501993_item	3577737	et	4	main
veel	doc_491521501993_item	3577744	et	4	main
õppib	doc_491521501993_item	3577745	et	4	main
kaevanuse	doc_491521501993_item	3577749	et	4	main
pärast	doc_491521501993_item	3577788	et	4	main
palju	doc_491521501993_item	3577806	et	4	main
film	doc_491521502149_item	3578066	et	3	main
mulle	doc_491521502149_item	3578067	et	4	main
meeldis	doc_491521502149_item	3578068	et	3	main
ja	doc_491521502149_item	3578069	et	3	main
et	doc_491521502149_item	3578070	et	3	main
volmer	doc_491521502149_item	3578071	et	4	main
minu	doc_491521502149_item	3578072	et	3	main
arvates	doc_491521502149_item	3578073	et	4	main
on	doc_491521502149_item	3578074	et	4	main
geniaalne	doc_491521502149_item	3578075	et	3	main
režisöör	doc_491521502149_item	3578076	et	2	main
minu	doc_491521502149_item	3577826	et	3	main
kohta	doc_491521502149_item	3577830	et	4	main
tundmata	doc_491521502149_item	3577854	et	4	main
poliitikad	doc_491521502149_item	3577863	et	3	main
mulle	doc_491521502149_item	3577875	et	4	main
on	doc_491521502149_item	3577876	et	4	main
arva	doc_491521502149_item	3577887	et	4	main
et	doc_491521502149_item	3577888	et	3	main
see	doc_491521502149_item	3577889	et	3	main
esiplaanil	doc_491521502149_item	3577894	et	4	main
see	doc_491521502149_item	3577897	et	3	main
et	doc_491521502149_item	3577898	et	3	main
volmer	doc_491521502149_item	3577899	et	4	main
näitab	doc_491521502149_item	3577900	et	3	main
meile	doc_491521502149_item	3577901	et	4	main
kuidas	doc_491521502149_item	3577902	et	3	main
saksamaa	doc_491521502149_item	3577903	et	4	main
kõigepealt	doc_491521502149_item	3577904	et	3	main
püüab	doc_491521502149_item	3577905	et	3	main
olla	doc_491521502149_item	3577906	et	3	main
kõige	doc_491521502149_item	3577907	et	4	main
võimsam	doc_491521502149_item	3577908	et	4	main
riik	doc_491521502149_item	3577909	et	3	main
saksamaa	doc_491521502149_item	3577910	et	4	main
tahtis	doc_491521502149_item	3577911	et	3	main
haitada	doc_491521502149_item	3577912	et	4	main
venemaa	doc_491521502149_item	3577913	et	4	main
omakorda	doc_491521502149_item	3577914	et	3	main
kesküla	doc_491521502149_item	3577915	et	4	main
eestlane	doc_491521502149_item	3577916	et	3	main
revolutsionist	doc_491521502149_item	3577917	et	4	main
tahtis	doc_491521502149_item	3577918	et	3	main
rajada	doc_491521502149_item	3577919	et	3	main
vene	doc_491521502149_item	3577920	et	4	main
tsaaririigi	doc_491521502149_item	3577921	et	3	main
loodeosa	doc_491521502149_item	3577922	et	4	main
jäänustele	doc_491521502149_item	3577923	et	3	main
sõda	doc_491521502149_item	3577929	et	4	main
ole	doc_491521502149_item	3577935	et	4	main
sõjas	doc_491521502149_item	3577937	et	3	main
on	doc_491521502149_item	3577944	et	4	main
ma	doc_491521502149_item	3577956	et	3	main
on	doc_491521502149_item	3577965	et	4	main
meeldinud	doc_491521502149_item	3577977	et	4	main
miks	doc_491521502149_item	3577988	et	4	main
aga	doc_491521502149_item	3577989	et	3	main
ta	doc_491521502149_item	3577996	et	4	main
õpis	doc_491521502149_item	3578024	et	3	main
leipzigi	doc_491521502149_item	3578026	et	4	main
zürichi	doc_491521502149_item	3578027	et	4	main
berne	doc_491521502149_item	3578029	et	4	main
šveitslannaga	doc_491521502149_item	3578032	et	2	main
on	doc_491521502149_item	3578034	et	4	main
olemas	doc_491521502149_item	3578035	et	4	main
tütar	doc_491521502149_item	3578036	et	3	main
tahaks	doc_491521502149_item	3577828	et	3	main
mille	doc_491521502149_item	3577838	et	3	main
enda	doc_491521502149_item	3577839	et	4	main
ristinud	doc_491521502149_item	3577842	et	4	main
forrest	doc_491521502149_item	3577843	et	4	main
kirjutati	doc_491521502149_item	3577852	et	3	main
meil	doc_491521502149_item	3577853	et	4	main
ja	doc_491521502149_item	3577862	et	3	main
nii	doc_491521502149_item	3577864	et	3	main
olemas	doc_491521502149_item	3577877	et	4	main
mõned	doc_491521502149_item	3577878	et	3	main
ei	doc_491521502149_item	3577881	et	4	main
töö	doc_491521502149_item	3577892	et	4	main
minuseid	doc_491521502149_item	3577893	et	4	main
on	doc_491521502149_item	3577930	et	4	main
hädavajalik	doc_491521502149_item	3577931	et	3	main
selles	doc_491521502149_item	3577932	et	4	main
selles	doc_491521502149_item	3577936	et	4	main
võitjad	doc_491521502149_item	3577938	et	4	main
pärast	doc_491521502149_item	3577945	et	4	main
sõda	doc_491521502149_item	3577946	et	4	main
hulk	doc_491521502149_item	3577947	et	3	main
uusi	doc_491521502149_item	3577948	et	3	main
siis	doc_491521502149_item	3577955	et	3	main
et	doc_491521502149_item	3577958	et	3	main
iga	doc_491521502149_item	3577968	et	4	main
karjub	doc_491521502149_item	3577970	et	3	main
halvasti	doc_491521502149_item	3577971	et	3	main
käitub	doc_491521502149_item	3577972	et	3	main
nadjaga	doc_491521502149_item	3577973	et	4	main
see	doc_491521502149_item	3577974	et	3	main
muuta	doc_491521502149_item	3577980	et	4	main
imperialistliku	doc_491521502149_item	3577981	et	3	main
sõja	doc_491521502149_item	3577982	et	3	main
kodusõjaks	doc_491521502149_item	3577983	et	3	main
ma	doc_491521502149_item	3577984	et	3	main
ei	doc_491521502149_item	3577985	et	4	main
kesküla	doc_491521502149_item	3577992	et	4	main
fiks	doc_491521502149_item	3578042	et	4	main
essee	doc_491521502150_item	3578078	et	4	main
minu	doc_491521502150_item	3578080	et	3	main
leninid	doc_491521502150_item	3578085	et	4	main
osa	doc_491521502150_item	3578087	et	4	main
eesti	doc_491521502150_item	3578089	et	4	main
kaudu	doc_491521502150_item	3578096	et	3	main
inimeste	doc_491521502150_item	3578112	et	3	main
filmis	doc_491521502150_item	3578114	et	4	main
on	doc_491521502150_item	3578115	et	4	main
kesküla	doc_491521502150_item	3578122	et	4	main
ja	doc_491521502150_item	3578123	et	3	main
mülleri	doc_491521502150_item	3578124	et	4	main
režissööri	doc_491521502150_item	3578132	et	2	main
ja	doc_491521502150_item	3578139	et	3	main
kuigi	doc_491521502150_item	3578141	et	3	main
kooli	doc_491521502150_item	3578178	et	4	main
meeldinud	doc_491521502149_item	3577882	et	4	main
mulle	doc_491521502149_item	3577883	et	4	main
aga	doc_491521502149_item	3577884	et	3	main
ma	doc_491521502149_item	3577885	et	3	main
ei	doc_491521502149_item	3577886	et	4	main
saksamaa	doc_491521502149_item	3577925	et	4	main
mõttes	doc_491521502149_item	3577933	et	3	main
ei	doc_491521502149_item	3577934	et	4	main
impeeriumid	doc_491521502149_item	3577939	et	3	main
langevad	doc_491521502149_item	3577940	et	4	main
austria-ungari	doc_491521502149_item	3577941	et	4	main
leninit	doc_491521502149_item	3577954	et	4	main
filmis	doc_491521502149_item	3577963	et	4	main
lenin	doc_491521502149_item	3577964	et	4	main
närviline	doc_491521502149_item	3577967	et	4	main
kord	doc_491521502149_item	3577969	et	4	main
lenin	doc_491521502149_item	3577978	et	4	main
tahtis	doc_491521502149_item	3577979	et	3	main
vaatamata	doc_491521502149_item	3577993	et	4	main
kaval	doc_491521502149_item	3577998	et	4	main
ta	doc_491521502149_item	3578000	et	4	main
meeldis	doc_491521502149_item	3578001	et	3	main
mulle	doc_491521502149_item	3578002	et	4	main
mis	doc_491521502149_item	3578003	et	4	main
puutub	doc_491521502149_item	3578004	et	3	main
tema	doc_491521502149_item	3578005	et	4	main
elulood	doc_491521502149_item	3578006	et	4	main
võin	doc_491521502149_item	3578007	et	3	main
öelda	doc_491521502149_item	3578008	et	4	main
et	doc_491521502149_item	3578009	et	3	main
ta	doc_491521502149_item	3578010	et	4	main
katkestas	doc_491521502149_item	3578011	et	3	main
dorpati	doc_491521502149_item	3578012	et	4	main
ülikoolis	doc_491521502149_item	3578013	et	4	main
elas	doc_491521502149_item	3578014	et	3	main
siis	doc_491521502149_item	3578015	et	3	main
illegaalselt	doc_491521502149_item	3578016	et	4	main
moskvas	doc_491521502149_item	3578017	et	4	main
ja	doc_491521502149_item	3578018	et	3	main
lahkus	doc_491521502149_item	3578019	et	4	main
sealt	doc_491521502149_item	3578020	et	4	main
1908	doc_491521502149_item	3578021	et	2	main
pärast	doc_491521502149_item	3578023	et	4	main
a	doc_491521502149_item	3578022	et	4	main
arvasin	doc_491521502149_item	3577957	et	3	main
ta	doc_491521502149_item	3577959	et	4	main
natuke	doc_491521502149_item	3577961	et	4	main
karm	doc_491521502149_item	3577966	et	4	main
mulle	doc_491521502149_item	3577975	et	4	main
mulle	doc_491521502149_item	3577990	et	4	main
meeldis	doc_491521502149_item	3577991	et	3	main
oli	doc_491521502149_item	3577997	et	3	main
teda	doc_491521502149_item	3578037	et	4	main
kõige	doc_491521502149_item	3578038	et	4	main
ja	doc_491521502149_item	3578028	et	3	main
abielus	doc_491521502149_item	3578031	et	4	main
tal	doc_491521502149_item	3578033	et	3	main
idee	doc_491521502149_item	3578040	et	4	main
ta	doc_491521502149_item	3578044	et	4	main
saatis	doc_491521502149_item	3578045	et	3	main
oma	doc_491521502149_item	3578046	et	4	main
ülejäänud	doc_491521502149_item	3578047	et	4	main
elupäevad	doc_491521502149_item	3578048	et	3	main
mööda	doc_491521502149_item	3578049	et	4	main
pageduses	doc_491521502149_item	3578050	et	4	main
šveitsis	doc_491521502149_item	3578051	et	2	main
ja	doc_491521502149_item	3578052	et	3	main
hiljem	doc_491521502149_item	3578053	et	3	main
hispaanias	doc_491521502149_item	3578054	et	4	main
kus	doc_491521502149_item	3578055	et	3	main
ta	doc_491521502149_item	3578056	et	4	main
aastal	doc_491521502149_item	3578058	et	3	main
suri	doc_491521502149_item	3578059	et	3	main
1963	doc_491521502149_item	3578057	et	2	main
oma	doc_491521502149_item	3578060	et	4	main
esse	doc_491521502149_item	3578061	et	3	main
lõpus	doc_491521502149_item	3578062	et	4	main
tahaks	doc_491521502149_item	3578063	et	3	main
öelda	doc_491521502149_item	3578064	et	4	main
et	doc_491521502149_item	3578065	et	3	main
minu	doc_491521502150_item	3578084	et	3	main
venemaal	doc_491521502150_item	3578101	et	4	main
see	doc_491521502150_item	3578102	et	3	main
film	doc_491521502150_item	3578103	et	3	main
räägib	doc_491521502150_item	3578104	et	3	main
mõjutasid	doc_491521502150_item	3578110	et	4	main
paljude	doc_491521502150_item	3578111	et	3	main
saatust	doc_491521502150_item	3578113	et	4	main
iroonilisi	doc_491521502150_item	3578119	et	3	main
otsimine	doc_491521502150_item	3578126	et	4	main
samuti	doc_491521502150_item	3578127	et	3	main
leninlikkuse	doc_491521502150_item	3578128	et	4	main
tundub	doc_491521502150_item	3578136	et	3	main
huvitav	doc_491521502150_item	3578140	et	4	main
programmis	doc_491521502150_item	3578179	et	4	main
eesti	doc_491521502150_item	3578183	et	4	main
kesküla	doc_491521502150_item	3578187	et	4	main
nõukogude	doc_491521502150_item	3578196	et	3	main
teda	doc_491521502150_item	3578198	et	4	main
idealiseeriti	doc_491521502150_item	3578199	et	3	main
nüüd	doc_491521502150_item	3578200	et	4	main
all	doc_491521502150_item	3578231	et	3	main
leninid	doc_491521502155_item	3578242	et	4	main
jättis	doc_491521502155_item	3578243	et	3	main
küljest	doc_491521502155_item	3578249	et	4	main
ajalooline	doc_491521502155_item	3578250	et	4	main
moment	doc_491521502155_item	3578251	et	3	main
küljest	doc_491521502155_item	3578263	et	4	main
a	doc_491521502155_item	3578270	et	4	main
ettevalmistamise	doc_491521502155_item	3578278	et	3	main
1917	doc_491521502155_item	3578280	et	2	main
jõudnud	doc_491521502155_item	3578288	et	4	main
mitu	doc_491521502155_item	3578291	et	4	main
seisis	doc_491521502155_item	3578294	et	4	main
idee	doc_491521502149_item	3578041	et	4	main
suurt	doc_491521502150_item	3578086	et	3	main
aleksander	doc_491521502150_item	3578091	et	4	main
sündmustest	doc_491521502150_item	3578105	et	4	main
naljakaid	doc_491521502150_item	3578117	et	4	main
ja	doc_491521502150_item	3578118	et	3	main
leninite	doc_491521502150_item	3578125	et	4	main
kaksikutest	doc_491521502150_item	3578135	et	4	main
ajaloolised	doc_491521502150_item	3578142	et	4	main
allikad	doc_491521502150_item	3578143	et	3	main
ei	doc_491521502150_item	3578144	et	4	main
kinnita	doc_491521502150_item	3578145	et	4	main
seda	doc_491521502150_item	3578146	et	3	main
sagedased	doc_491521502150_item	3578147	et	3	main
juttu	doc_491521502150_item	3578182	et	4	main
aleksander	doc_491521502150_item	3578186	et	4	main
leninist	doc_491521502150_item	3578188	et	4	main
on	doc_491521502150_item	3578189	et	4	main
palju	doc_491521502150_item	3578192	et	4	main
öeldud	doc_491521502150_item	3578193	et	4	main
kannatasid	doc_491521502150_item	3578232	et	4	main
seotud	doc_491521502155_item	3578254	et	4	main
jelitš	doc_491521502155_item	3578259	et	2	main
kesküla	doc_491521502155_item	3578271	et	4	main
suure	doc_491521502155_item	3578275	et	3	main
saksamaa	doc_491521502155_item	3578284	et	4	main
ja	doc_491521502155_item	3578285	et	3	main
ja	doc_491521502155_item	3578338	et	3	main
sõja	doc_491521502155_item	3578340	et	3	main
praeguseks	doc_491521502155_item	3578344	et	3	main
nii	doc_491521502155_item	3578347	et	3	main
lenin	doc_491521502155_item	3578353	et	4	main
selle	doc_491521502155_item	3578354	et	4	main
ülesandega	doc_491521502155_item	3578355	et	3	main
veel	doc_491521502155_item	3578359	et	4	main
ulatus	doc_491521502155_item	3578369	et	4	main
ettenäha	doc_491521502155_item	3578384	et	4	main
millele	doc_491521502155_item	3578385	et	3	main
kaasa	doc_491521502155_item	3578389	et	4	main
sündmustikust	doc_491521502155_item	3578395	et	4	main
asemel	doc_491521502155_item	3578404	et	4	main
meelest	doc_491521502155_item	3578414	et	4	main
filmile	doc_491521502155_item	3578415	et	3	main
parajat	doc_491521502155_item	3578416	et	3	main
see	doc_491521502150_item	3578205	et	3	main
mees	doc_491521502150_item	3578206	et	4	main
muutis	doc_491521502150_item	3578207	et	3	main
oma	doc_491521502150_item	3578208	et	4	main
tegudega	doc_491521502150_item	3578209	et	3	main
mitte	doc_491521502150_item	3578210	et	3	main
ainult	doc_491521502150_item	3578211	et	4	main
venemaa	doc_491521502150_item	3578212	et	4	main
saatust	doc_491521502150_item	3578213	et	4	main
vaid	doc_491521502150_item	3578214	et	3	main
ka	doc_491521502150_item	3578215	et	3	main
palju	doc_491521502150_item	3578216	et	4	main
teisi	doc_491521502150_item	3578217	et	4	main
riike	doc_491521502150_item	3578218	et	3	main
kus	doc_491521502150_item	3578219	et	3	main
samuti	doc_491521502150_item	3578220	et	3	main
toimusid	doc_491521502150_item	3578221	et	4	main
riigi	doc_491521502150_item	3578222	et	3	main
pöörded	doc_491521502150_item	3578223	et	3	main
lenin	doc_491521502150_item	3578224	et	4	main
oli	doc_491521502150_item	3578225	et	3	main
vaieldamatu	doc_491521502150_item	3578226	et	4	main
film	doc_491521502150_item	3578079	et	3	main
leninid	doc_491521502150_item	3578081	et	4	main
ajaloolises	doc_491521502150_item	3578082	et	4	main
kes	doc_491521502150_item	3578093	et	4	main
aitas	doc_491521502150_item	3578094	et	3	main
saksamaa	doc_491521502150_item	3578095	et	4	main
vene	doc_491521502150_item	3578097	et	4	main
mis	doc_491521502150_item	3578106	et	4	main
hetki	doc_491521502150_item	3578120	et	4	main
näiteks	doc_491521502150_item	3578121	et	4	main
lenini	doc_491521502150_item	3578134	et	4	main
originaalne	doc_491521502150_item	3578138	et	3	main
äravahetamised	doc_491521502150_item	3578149	et	3	main
ajavad	doc_491521502150_item	3578150	et	4	main
vaatajat	doc_491521502150_item	3578151	et	4	main
segadusse	doc_491521502150_item	3578152	et	3	main
ja	doc_491521502150_item	3578153	et	3	main
mõnikord	doc_491521502150_item	3578154	et	3	main
on	doc_491521502150_item	3578155	et	4	main
aru	doc_491521502150_item	3578157	et	4	main
saada	doc_491521502150_item	3578158	et	4	main
võimatu	doc_491521502150_item	3578156	et	4	main
kes	doc_491521502150_item	3578159	et	4	main
neist	doc_491521502150_item	3578160	et	4	main
on	doc_491521502150_item	3578161	et	4	main
tõeline	doc_491521502150_item	3578162	et	4	main
lenin	doc_491521502150_item	3578163	et	4	main
mõned	doc_491521502150_item	3578164	et	3	main
lõigud	doc_491521502150_item	3578165	et	4	main
sellest	doc_491521502150_item	3578166	et	4	main
filmist	doc_491521502150_item	3578167	et	4	main
jäid	doc_491521502150_item	3578168	et	4	main
mulle	doc_491521502150_item	3578169	et	4	main
arusaamatuks	doc_491521502150_item	3578170	et	4	main
kuigi	doc_491521502150_item	3578171	et	3	main
film	doc_491521502150_item	3578172	et	3	main
on	doc_491521502150_item	3578173	et	4	main
huvitav	doc_491521502150_item	3578174	et	4	main
ajaloolisest	doc_491521502150_item	3578175	et	4	main
aspektist	doc_491521502150_item	3578176	et	3	main
sest	doc_491521502150_item	3578177	et	4	main
nimega	doc_491521502150_item	3578185	et	3	main
aja	doc_491521502150_item	3578190	et	4	main
jooksul	doc_491521502150_item	3578191	et	4	main
kirjutatud	doc_491521502150_item	3578195	et	4	main
kurjust	doc_491521502150_item	3578204	et	4	main
suur	doc_491521502150_item	3578227	et	3	main
türann	doc_491521502150_item	3578228	et	3	main
miljonid	doc_491521502150_item	3578233	et	3	main
essee	doc_491521502155_item	3578236	et	4	main
mulle	doc_491521502155_item	3578245	et	4	main
a	doc_491521502155_item	3578255	et	4	main
ei	doc_491521502150_item	3578180	et	4	main
olnud	doc_491521502150_item	3578181	et	4	main
ja	doc_491521502150_item	3578194	et	3	main
ajal	doc_491521502150_item	3578197	et	4	main
kelle	doc_491521502150_item	3578229	et	4	main
käe	doc_491521502150_item	3578230	et	3	main
minu	doc_491521502155_item	3578237	et	3	main
leninid	doc_491521502155_item	3578238	et	4	main
vaadanud	doc_491521502155_item	3578239	et	4	main
filmi	doc_491521502155_item	3578240	et	4	main
minu	doc_491521502155_item	3578241	et	3	main
ühest	doc_491521502155_item	3578248	et	4	main
oli	doc_491521502155_item	3578253	et	3	main
kesküla	doc_491521502155_item	3578256	et	4	main
v	doc_491521502155_item	3578258	et	4	main
isikutega	doc_491521502155_item	3578260	et	4	main
ja	doc_491521502155_item	3578261	et	3	main
teisest	doc_491521502155_item	3578262	et	4	main
paroodia	doc_491521502155_item	3578267	et	4	main
film	doc_491521502155_item	3578268	et	3	main
peatub	doc_491521502155_item	3578269	et	3	main
kaasaitamisel	doc_491521502155_item	3578279	et	3	main
aastaks	doc_491521502155_item	3578281	et	4	main
olid	doc_491521502155_item	3578282	et	4	main
keiserlik	doc_491521502155_item	3578283	et	3	main
sõdida	doc_491521502155_item	3578289	et	3	main
aastat	doc_491521502155_item	3578292	et	3	main
rindel	doc_491521502155_item	3578307	et	3	main
vastupanu	doc_491521502155_item	3578312	et	4	main
otsustati	doc_491521502155_item	3578313	et	3	main
toetada	doc_491521502155_item	3578314	et	3	main
tsaarivastaseid	doc_491521502155_item	3578315	et	3	main
revolutsionääre	doc_491521502155_item	3578316	et	3	main
eesotsas	doc_491521502155_item	3578317	et	4	main
v	doc_491521502155_item	3578318	et	4	main
j	doc_491521502155_item	3578319	et	4	main
leniniga	doc_491521502155_item	3578320	et	4	main
ülesanne	doc_491521502155_item	3578321	et	4	main
tehti	doc_491521502155_item	3578322	et	3	main
a	doc_491521502155_item	3578323	et	4	main
kesküla	doc_491521502155_item	3578324	et	4	main
kes	doc_491521502155_item	3578325	et	4	main
pidi	doc_491521502155_item	3578326	et	4	main
revolutsionäärid	doc_491521502155_item	3578327	et	3	main
koos	doc_491521502155_item	3578328	et	4	main
leniniga	doc_491521502155_item	3578329	et	4	main
ja	doc_491521502155_item	3578330	et	3	main
saksamaa	doc_491521502155_item	3578331	et	4	main
poolt	doc_491521502155_item	3578332	et	4	main
annetatud	doc_491521502155_item	3578333	et	4	main
rahaga	doc_491521502155_item	3578334	et	4	main
venemaal	doc_491521502155_item	3578335	et	4	main
võimule	doc_491521502155_item	3578336	et	3	main
me	doc_491521502155_item	3578343	et	4	main
teame	doc_491521502155_item	3578345	et	3	main
mis	doc_491521502155_item	3578368	et	4	main
aastakümneid	doc_491521502155_item	3578378	et	4	main
ajal	doc_491521502155_item	3578388	et	4	main
aitas	doc_491521502155_item	3578390	et	3	main
koomilise	doc_491521502155_item	3578397	et	3	main
kogus	doc_491521502155_item	3578409	et	4	main
lõbusaid	doc_491521502155_item	3578410	et	3	main
õpilane	doc_491521502155_item	3578437	et	3	main
filmist	doc_491521502155_item	3578264	et	4	main
tehtud	doc_491521502155_item	3578265	et	4	main
hea	doc_491521502155_item	3578266	et	4	main
isikul	doc_491521502155_item	3578272	et	3	main
tsaari	doc_491521502155_item	3578286	et	4	main
oma	doc_491521502155_item	3578290	et	4	main
rinne	doc_491521502155_item	3578293	et	3	main
venemaa	doc_491521502155_item	3578300	et	4	main
võitu	doc_491521502155_item	3578301	et	4	main
kuna	doc_491521502155_item	3578302	et	3	main
saksamaa	doc_491521502155_item	3578303	et	4	main
selleks	doc_491521502155_item	3578308	et	4	main
venemaa	doc_491521502155_item	3578311	et	4	main
saksamaaga	doc_491521502155_item	3578341	et	3	main
a	doc_491521502155_item	3578348	et	4	main
kesküla	doc_491521502155_item	3578349	et	4	main
ja	doc_491521502155_item	3578350	et	3	main
v	doc_491521502155_item	3578351	et	4	main
v	doc_491521502155_item	3578360	et	4	main
vaiksest	doc_491521502155_item	3578370	et	3	main
põhja	doc_491521502155_item	3578372	et	4	main
mereni	doc_491521502155_item	3578373	et	3	main
ja	doc_491521502155_item	3578374	et	3	main
maailma	doc_491521502155_item	3578376	et	4	main
poliitikat	doc_491521502155_item	3578377	et	3	main
härra	doc_491521502155_item	3578380	et	4	main
on	doc_491521502155_item	3578393	et	4	main
pujändi	doc_491521502155_item	3578398	et	4	main
tegevusse	doc_491521502155_item	3578401	et	4	main
10	doc_491521502155_item	3578406	et	2	main
teisikut	doc_491521502155_item	3578407	et	3	main
selline	doc_491521502155_item	3578408	et	4	main
agar	doc_491521502155_item	3578436	et	4	main
perfektselt	doc_491521502155_item	3578448	et	4	main
suutnud	doc_491521502155_item	3578454	et	4	main
filmi	doc_491521502155_item	3578461	et	4	main
head	doc_491521502155_item	3578464	et	4	main
näitlejad	doc_491521502155_item	3578465	et	4	main
ja	doc_491521502155_item	3578466	et	3	main
tõelise	doc_491521502155_item	3578482	et	4	main
leninina	doc_491521502155_item	3578483	et	4	main
ja	doc_491521502155_item	3578484	et	3	main
oli	doc_491521502155_item	3578485	et	3	main
väga	doc_491521502155_item	3578486	et	3	main
sarnane	doc_491521502155_item	3578487	et	4	main
dokumentaalfilmidest	doc_491521502155_item	3578488	et	3	main
ei	doc_491521502155_item	3578502	et	4	main
hirmsamat	doc_527420171751_item	3578532	et	4	main
iseendale	doc_527420171751_item	3578539	et	3	main
teha	doc_527420171751_item	3578541	et	3	main
see	doc_527420171751_item	3578547	et	3	main
aus	doc_527420171751_item	3578550	et	4	main
ees	doc_527420171751_item	3578552	et	4	main
oma	doc_527420171751_item	3578553	et	4	main
ainult	doc_527420171751_item	3578575	et	4	main
isikuse	doc_527420171751_item	3578584	et	4	main
saavad	doc_527420171751_item	3578591	et	4	main
aga	doc_527420171751_item	3578600	et	3	main
inimeste	doc_527420171751_item	3578603	et	3	main
aus	doc_527420171751_item	3578605	et	4	main
on	doc_527420171751_item	3578606	et	4	main
hirmus	doc_527420171751_item	3578607	et	4	main
kardavad	doc_527420171751_item	3578616	et	4	main
teha	doc_527420171751_item	3578637	et	3	main
ja	doc_527420171751_item	3578638	et	3	main
nende	doc_527420171751_item	3578650	et	4	main
mõjutada	doc_527420171751_item	3578654	et	3	main
tõde	doc_527420171751_item	3578658	et	4	main
ja	doc_527420171751_item	3578659	et	3	main
igaühel	doc_527420171751_item	3578663	et	3	main
ei	doc_527420171751_item	3578667	et	4	main
kindlasti	doc_527420171751_item	3578669	et	3	main
olen	doc_527420171751_item	3578673	et	3	main
aus	doc_527420171751_item	3578675	et	4	main
inimene	doc_527420171751_item	3578676	et	3	main
või	doc_527420171751_item	3578677	et	4	main
kindlasti	doc_527420171751_item	3578680	et	3	main
tunnistada	doc_527420171751_item	3578682	et	3	main
et	doc_527420171751_item	3578683	et	3	main
mind	doc_527420171751_item	3578686	et	4	main
arvates	doc_527420171751_item	3578691	et	4	main
alati	doc_542009824793_item	3578707	et	4	main
paigal	doc_491521502155_item	3578295	et	4	main
ja	doc_491521502155_item	3578296	et	3	main
saksamaa	doc_491521502155_item	3578297	et	4	main
kartis	doc_491521502155_item	3578298	et	3	main
ise	doc_491521502155_item	3578304	et	4	main
sõdis	doc_491521502155_item	3578305	et	3	main
et	doc_491521502155_item	3578309	et	3	main
murda	doc_491521502155_item	3578310	et	3	main
lõpetama	doc_491521502155_item	3578339	et	4	main
j	doc_491521502155_item	3578352	et	4	main
enamgi	doc_491521502155_item	3578358	et	4	main
õnnestus	doc_491521502155_item	3578363	et	4	main
luua	doc_491521502155_item	3578364	et	4	main
suur	doc_491521502155_item	3578365	et	3	main
totalitaarne	doc_491521502155_item	3578366	et	3	main
riik	doc_491521502155_item	3578367	et	3	main
vaevalt	doc_491521502155_item	3578379	et	4	main
a	doc_491521502155_item	3578381	et	4	main
kesküla	doc_491521502155_item	3578382	et	4	main
oskas	doc_491521502155_item	3578383	et	3	main
ajalooliselt	doc_491521502155_item	3578394	et	4	main
ja	doc_491521502155_item	3578399	et	3	main
koguni	doc_491521502155_item	3578405	et	4	main
leninit	doc_491521502155_item	3578446	et	4	main
nii	doc_491521502155_item	3578447	et	3	main
ei	doc_491521502155_item	3578453	et	4	main
vahet	doc_491521502155_item	3578459	et	3	main
nauditavaks	doc_491521502155_item	3578463	et	4	main
nende	doc_491521502155_item	3578467	et	4	main
roll	doc_491521502155_item	3578479	et	3	main
ta	doc_491521502155_item	3578480	et	4	main
mõjus	doc_491521502155_item	3578481	et	4	main
nähtud	doc_491521502155_item	3578489	et	4	main
ühtegi	doc_491521502155_item	3578504	et	4	main
teist	doc_491521502155_item	3578505	et	4	main
ole	doc_527420171751_item	3578530	et	4	main
üks	doc_527420171751_item	3578534	et	3	main
inimene	doc_527420171751_item	3578536	et	3	main
tahaks	doc_527420171751_item	3578538	et	3	main
kes	doc_527420171751_item	3578542	et	4	main
on	doc_527420171751_item	3578543	et	4	main
mis	doc_527420171751_item	3578546	et	4	main
ees	doc_527420171751_item	3578556	et	4	main
võib	doc_527420171751_item	3578557	et	3	main
ühes	doc_527420171751_item	3578567	et	4	main
tõde	doc_527420171751_item	3578576	et	4	main
ausus	doc_527420171751_item	3578578	et	4	main
ühiskonnast	doc_527420171751_item	3578588	et	4	main
ei	doc_527420171751_item	3578598	et	4	main
ole	doc_527420171751_item	3578599	et	4	main
teised	doc_527420171751_item	3578614	et	4	main
nende	doc_527420171751_item	3578640	et	4	main
jaoks	doc_527420171751_item	3578641	et	4	main
ausad	doc_527420171751_item	3578642	et	3	main
inimesed	doc_527420171751_item	3578643	et	3	main
võivad	doc_527420171751_item	3578644	et	4	main
olla	doc_527420171751_item	3578645	et	3	main
ohtlikud	doc_527420171751_item	3578646	et	3	main
küsimus	doc_527420171751_item	3578661	et	4	main
ma	doc_527420171751_item	3578666	et	3	main
kas	doc_527420171751_item	3578672	et	3	main
ei	doc_527420171751_item	3578687	et	4	main
ma	doc_542009824793_item	3578705	et	3	main
sõpradega	doc_542009824793_item	3578719	et	3	main
veeta	doc_542009824793_item	3578721	et	4	main
lapsega	doc_542009824793_item	3578722	et	3	main
mängida	doc_542009824793_item	3578723	et	3	main
vanemates	doc_542009824793_item	3578751	et	4	main
sünnipäev	doc_542009824793_item	3578758	et	3	main
ma	doc_542009824793_item	3578760	et	3	main
teda	doc_542009824793_item	3578764	et	4	main
meeldib	doc_542009824793_item	3578768	et	3	main
sünnipäevadel	doc_542009824793_item	3578769	et	3	main
teisele	doc_542009824793_item	3578772	et	4	main
kingitust	doc_542009824793_item	3578773	et	4	main
teha	doc_542009824793_item	3578774	et	3	main
sünnipäeva	doc_542009824793_item	3578780	et	4	main
sõber	doc_542009824793_item	3578786	et	3	main
lihtsalt	doc_542009824793_item	3578818	et	4	main
lesin	doc_542009824793_item	3578819	et	3	main
mitmel	doc_491521502155_item	3578306	et	4	main
tooma	doc_491521502155_item	3578337	et	3	main
nagu	doc_491521502155_item	3578342	et	3	main
said	doc_491521502155_item	3578346	et	4	main
suurepäraselt	doc_491521502155_item	3578356	et	4	main
hakkama	doc_491521502155_item	3578357	et	3	main
j	doc_491521502155_item	3578361	et	4	main
leninil	doc_491521502155_item	3578362	et	4	main
ookeanist	doc_491521502155_item	3578371	et	3	main
kujundas	doc_491521502155_item	3578375	et	3	main
ta	doc_491521502155_item	3578386	et	4	main
omal	doc_491521502155_item	3578387	et	3	main
filmi	doc_491521502155_item	3578391	et	4	main
loojad	doc_491521502155_item	3578392	et	4	main
teinud	doc_491521502155_item	3578396	et	4	main
toonud	doc_491521502155_item	3578400	et	4	main
ühe	doc_491521502155_item	3578402	et	4	main
lenini	doc_491521502155_item	3578403	et	4	main
lenineid	doc_491521502155_item	3578411	et	4	main
annab	doc_491521502155_item	3578412	et	3	main
minu	doc_491521502155_item	3578413	et	3	main
vürtsi	doc_491521502155_item	3578417	et	4	main
eriti	doc_491521502155_item	3578418	et	3	main
koomiline	doc_491521502155_item	3578419	et	3	main
tegevus	doc_491521502155_item	3578420	et	4	main
oli	doc_491521502155_item	3578421	et	3	main
filmis	doc_491521502155_item	3578422	et	4	main
see	doc_491521502155_item	3578423	et	3	main
kuidas	doc_491521502155_item	3578424	et	3	main
õige	doc_491521502155_item	3578425	et	4	main
lenin	doc_491521502155_item	3578426	et	4	main
õpetas	doc_491521502155_item	3578427	et	3	main
teistele	doc_491521502155_item	3578428	et	4	main
vale	doc_491521502155_item	3578429	et	4	main
lenitele	doc_491521502155_item	3578430	et	4	main
enda	doc_491521502155_item	3578431	et	4	main
miimikat	doc_491521502155_item	3578432	et	3	main
ja	doc_491521502155_item	3578433	et	3	main
kõnepidamist	doc_491521502155_item	3578434	et	3	main
eriti	doc_491521502155_item	3578435	et	3	main
oli	doc_491521502155_item	3578438	et	3	main
üks	doc_491521502155_item	3578439	et	3	main
et	doc_491521502155_item	3578449	et	3	main
isegi	doc_491521502155_item	3578450	et	4	main
ja	doc_491521502155_item	3578456	et	3	main
poolt	doc_491521502155_item	3578468	et	4	main
hästi	doc_491521502155_item	3578469	et	3	main
üldmulje	doc_491521502155_item	3578493	et	4	main
oli	doc_491521502155_item	3578494	et	3	main
minu	doc_491521502155_item	3578495	et	3	main
arvates	doc_491521502155_item	3578496	et	4	main
mulle	doc_491521502155_item	3578501	et	4	main
essee	doc_527420171751_item	3578528	et	4	main
aus	doc_527420171751_item	3578535	et	4	main
selgeks	doc_527420171751_item	3578540	et	3	main
võib	doc_527420171751_item	3578548	et	3	main
olla	doc_527420171751_item	3578558	et	3	main
ka	doc_527420171751_item	3578559	et	3	main
jumala	doc_527420171751_item	3578560	et	3	main
ees	doc_527420171751_item	3578561	et	4	main
ausas	doc_527420171751_item	3578568	et	3	main
inimeses	doc_527420171751_item	3578569	et	3	main
ausus	doc_527420171751_item	3578570	et	4	main
aga	doc_527420171751_item	3578571	et	3	main
kes	doc_491521502155_item	3578441	et	4	main
tema	doc_491521502155_item	3578451	et	4	main
sugulased	doc_491521502155_item	3578452	et	3	main
valel	doc_491521502155_item	3578457	et	3	main
teevad	doc_491521502155_item	3578462	et	3	main
mängitud	doc_491521502155_item	3578470	et	4	main
rollid	doc_491521502155_item	3578471	et	3	main
eriti	doc_491521502155_item	3578472	et	3	main
meeldib	doc_491521502155_item	3578473	et	3	main
mulle	doc_491521502155_item	3578474	et	4	main
a	doc_491521502155_item	3578475	et	4	main
sunorukovi	doc_491521502155_item	3578476	et	4	main
poolt	doc_491521502155_item	3578477	et	4	main
mängitud	doc_491521502155_item	3578478	et	4	main
revolutsiooni	doc_491521502155_item	3578490	et	4	main
juhile	doc_491521502155_item	3578491	et	3	main
filmi	doc_491521502155_item	3578492	et	4	main
mõjus	doc_491521502155_item	3578499	et	4	main
eesti	doc_491521502155_item	3578506	et	4	main
komöödiat	doc_491521502155_item	3578507	et	3	main
mis	doc_491521502155_item	3578508	et	4	main
oleks	doc_491521502155_item	3578509	et	3	main
tehtud	doc_491521502155_item	3578510	et	4	main
analoogses	doc_491521502155_item	3578511	et	3	main
žanris	doc_491521502155_item	3578512	et	2	main
usun	doc_491521502155_item	3578513	et	3	main
et	doc_491521502155_item	3578514	et	3	main
teistkordsel	doc_491521502155_item	3578515	et	3	main
vaatamisel	doc_491521502155_item	3578516	et	4	main
pakub	doc_491521502155_item	3578517	et	3	main
see	doc_491521502155_item	3578518	et	3	main
film	doc_491521502155_item	3578519	et	3	main
veelgi	doc_491521502155_item	3578520	et	4	main
rohkem	doc_491521502155_item	3578521	et	4	main
avastamisrõõmu	doc_491521502155_item	3578522	et	4	main
ja	doc_491521502155_item	3578523	et	3	main
head	doc_491521502155_item	3578524	et	4	main
poliitilist	doc_491521502155_item	3578525	et	3	main
huumorit	doc_491521502155_item	3578526	et	3	main
teisikuteist	doc_491521502155_item	3578440	et	4	main
koguni	doc_491521502155_item	3578442	et	4	main
suutis	doc_491521502155_item	3578443	et	3	main
jäljendada	doc_491521502155_item	3578444	et	3	main
õiget	doc_491521502155_item	3578445	et	3	main
õigel	doc_491521502155_item	3578455	et	3	main
leninil	doc_491521502155_item	3578458	et	4	main
teha	doc_491521502155_item	3578460	et	3	main
hea	doc_491521502155_item	3578497	et	4	main
paroodiana	doc_491521502155_item	3578498	et	3	main
muljetavaldavalt	doc_491521502155_item	3578500	et	3	main
meenugi	doc_491521502155_item	3578503	et	4	main
midagi	doc_527420171751_item	3578531	et	4	main
inimene	doc_527420171751_item	3578545	et	3	main
tähendada	doc_527420171751_item	3578549	et	3	main
muidugi	doc_527420171751_item	3578562	et	4	main
see	doc_527420171751_item	3578563	et	3	main
kõik	doc_527420171751_item	3578564	et	4	main
mitte	doc_527420171751_item	3578574	et	3	main
meie	doc_527420171751_item	3578586	et	4	main
praegusest	doc_527420171751_item	3578587	et	3	main
end	doc_527420171751_item	3578592	et	4	main
pidada	doc_527420171751_item	3578594	et	4	main
rüütleid	doc_527420171751_item	3578595	et	3	main
juba	doc_527420171751_item	3578596	et	3	main
nende	doc_527420171751_item	3578602	et	4	main
lihtsalt	doc_527420171751_item	3578615	et	4	main
vaadata	doc_527420171751_item	3578617	et	4	main
oma	doc_527420171751_item	3578618	et	4	main
elule	doc_527420171751_item	3578619	et	3	main
ja	doc_527420171751_item	3578620	et	3	main
oma	doc_527420171751_item	3578621	et	4	main
see	doc_527420171751_item	3578648	et	3	main
eluviisile	doc_527420171751_item	3578653	et	3	main
kes	doc_527420171751_item	3578655	et	4	main
kuiodas	doc_527420171751_item	3578657	et	3	main
aususe	doc_527420171751_item	3578660	et	4	main
ja	doc_527420171751_item	3578665	et	3	main
saa	doc_527420171751_item	3578668	et	4	main
praegu	doc_527420171751_item	3578670	et	3	main
aga	doc_527420171751_item	3578679	et	3	main
minu	doc_527420171751_item	3578690	et	3	main
essee	doc_542009824793_item	3578704	et	4	main
olen	doc_542009824793_item	3578713	et	3	main
ja	doc_542009824793_item	3578715	et	3	main
või	doc_542009824793_item	3578724	et	4	main
mul	doc_542009824793_item	3578728	et	3	main
väga	doc_542009824793_item	3578730	et	3	main
sõprad	doc_542009824793_item	3578732	et	4	main
ja	doc_542009824793_item	3578733	et	3	main
sellepärast	doc_542009824793_item	3578734	et	3	main
aidata	doc_542009824793_item	3578742	et	4	main
mu	doc_542009824793_item	3578754	et	3	main
ei	doc_542009824793_item	3578762	et	4	main
õnnitleda	doc_542009824793_item	3578765	et	3	main
mulle	doc_542009824793_item	3578767	et	4	main
aasta	doc_542009824793_item	3578776	et	4	main
tähistan	doc_542009824793_item	3578777	et	3	main
ise	doc_542009824793_item	3578778	et	4	main
oma	doc_542009824793_item	3578779	et	4	main
mu	doc_542009824793_item	3578785	et	3	main
divanil	doc_542009824793_item	3578820	et	4	main
vaatan	doc_542009824793_item	3578821	et	3	main
telerit	doc_542009824793_item	3578822	et	3	main
ja	doc_542009824793_item	3578823	et	3	main
laisklen	doc_542009824793_item	3578824	et	3	main
selle	doc_567528375368_item	3578838	et	4	main
väitega	doc_567528375368_item	3578839	et	3	main
oma	doc_567528375368_item	3578857	et	4	main
halvas	doc_567528375368_item	3578877	et	4	main
kohas	doc_567528375368_item	3578884	et	4	main
ilmas	doc_567528375368_item	3578885	et	4	main
inimese	doc_567528375368_item	3578891	et	4	main
impressioon	doc_567528375368_item	3578892	et	3	main
sõltub	doc_567528375368_item	3578893	et	3	main
vaieldav	doc_567528375368_item	3578898	et	4	main
et	doc_567528375368_item	3578899	et	3	main
oma	doc_567528375368_item	3578909	et	4	main
paljude	doc_567528375368_item	3578910	et	3	main
inimeste	doc_567528375368_item	3578911	et	3	main
sinu	doc_567528375368_item	3578916	et	3	main
inimesed	doc_567528375368_item	3578920	et	3	main
on	doc_527420171751_item	3578692	et	4	main
maailmas	doc_527420171751_item	3578693	et	3	main
palju	doc_527420171751_item	3578694	et	4	main
rphkem	doc_527420171751_item	3578695	et	4	main
teist	doc_527420171751_item	3578696	et	4	main
inimesi	doc_527420171751_item	3578697	et	4	main
keda	doc_527420171751_item	3578698	et	4	main
tuleb	doc_527420171751_item	3578699	et	3	main
pidada	doc_527420171751_item	3578700	et	4	main
tõesti	doc_527420171751_item	3578701	et	3	main
hirmsamat	doc_527420171751_item	3578702	et	4	main
ei	doc_527420171751_item	3578529	et	4	main
kui	doc_527420171751_item	3578533	et	3	main
kõigepealt	doc_527420171751_item	3578537	et	3	main
aus	doc_527420171751_item	3578544	et	4	main
omaenda	doc_527420171751_item	3578551	et	3	main
ümbritsevate	doc_527420171751_item	3578554	et	4	main
inimeste	doc_527420171751_item	3578555	et	3	main
peab	doc_527420171751_item	3578565	et	4	main
ühendama	doc_527420171751_item	3578566	et	3	main
koosnema	doc_527420171751_item	3578573	et	3	main
printsiipist	doc_527420171751_item	3578577	et	4	main
on	doc_527420171751_item	3578579	et	4	main
omamoodi	doc_527420171751_item	3578580	et	3	main
eluviis	doc_527420171751_item	3578581	et	3	main
iselooma	doc_527420171751_item	3578582	et	4	main
ja	doc_527420171751_item	3578583	et	3	main
ainult	doc_527420171751_item	3578589	et	4	main
üksused	doc_527420171751_item	3578590	et	3	main
ausaks	doc_527420171751_item	3578593	et	4	main
peaaegu	doc_527420171751_item	3578597	et	3	main
teistele	doc_527420171751_item	3578608	et	4	main
võib	doc_527420171751_item	3578609	et	3	main
olla	doc_527420171751_item	3578610	et	3	main
sellepärast	doc_527420171751_item	3578611	et	3	main
et	doc_527420171751_item	3578612	et	3	main
need	doc_527420171751_item	3578613	et	3	main
muidugi	doc_527420171751_item	3578639	et	4	main
sest	doc_527420171751_item	3578647	et	4	main
ja	doc_527420171751_item	3578652	et	3	main
teab	doc_527420171751_item	3578656	et	3	main
oma	doc_527420171751_item	3578664	et	4	main
öelda	doc_527420171751_item	3578671	et	4	main
mitte	doc_527420171751_item	3578678	et	3	main
saan	doc_527420171751_item	3578681	et	4	main
ausad	doc_527420171751_item	3578684	et	3	main
inimesed	doc_527420171751_item	3578685	et	3	main
olen	doc_542009824793_item	3578706	et	3	main
inimene	doc_542009824793_item	3578709	et	3	main
tähendab	doc_542009824793_item	3578711	et	3	main
seltsiv	doc_542009824793_item	3578714	et	4	main
rõõmsameelne	doc_542009824793_item	3578716	et	3	main
meeldib	doc_542009824793_item	3578718	et	3	main
aega	doc_542009824793_item	3578720	et	4	main
lihtsalt	doc_542009824793_item	3578725	et	4	main
poole	doc_542009824793_item	3578739	et	4	main
kui	doc_542009824793_item	3578740	et	3	main
sõbrad	doc_542009824793_item	3578741	et	3	main
saa	doc_542009824793_item	3578744	et	4	main
siis	doc_542009824793_item	3578745	et	3	main
saamiseks	doc_542009824793_item	3578750	et	4	main
tuttavalt	doc_542009824793_item	3578756	et	4	main
siis	doc_542009824793_item	3578759	et	3	main
kindlasti	doc_542009824793_item	3578761	et	3	main
oma	doc_542009824793_item	3578782	et	4	main
sõpradega	doc_542009824793_item	3578783	et	3	main
essee	doc_567528375368_item	3578826	et	4	main
elamusi	doc_567528375368_item	3578831	et	3	main
ja	doc_567528375368_item	3578832	et	3	main
osaliselt	doc_567528375368_item	3578840	et	4	main
muljeid	doc_567528375368_item	3578847	et	3	main
asjal	doc_567528375368_item	3578861	et	3	main
on	doc_567528375368_item	3578862	et	4	main
teine	doc_567528375368_item	3578864	et	3	main
pool	doc_567528375368_item	3578865	et	4	main
pole	doc_567528375368_item	3578867	et	3	main
kuigi	doc_567528375368_item	3578868	et	3	main
reisi	doc_567528375368_item	3578882	et	4	main
korraldamises	doc_567528375368_item	3578883	et	4	main
ka	doc_567528375368_item	3578894	et	3	main
on	doc_567528375368_item	3578902	et	4	main
romantika	doc_567528375368_item	3578904	et	4	main
on	doc_567528375368_item	3578906	et	4	main
igaühe	doc_567528375368_item	3578907	et	4	main
jaoks	doc_567528375368_item	3578908	et	4	main
kui	doc_567528375368_item	3578915	et	3	main
imelisem	doc_567528375368_item	3578960	et	4	main
jagada	doc_567528375368_item	3578961	et	3	main
on	doc_567528375368_item	3578975	et	4	main
essee	doc_567528375369_item	3579106	et	4	main
kõige	doc_567528375369_item	3579109	et	4	main
kaupa	doc_567528375369_item	3579124	et	4	main
osakonnad	doc_567528375369_item	3579134	et	4	main
et	doc_567528375369_item	3579135	et	3	main
igaüks	doc_567528375369_item	3579136	et	3	main
veel	doc_567528375369_item	3579141	et	4	main
peab	doc_527420171751_item	3578572	et	4	main
kooskõla	doc_527420171751_item	3578585	et	4	main
miks	doc_527420171751_item	3578601	et	4	main
puhas	doc_527420171751_item	3578604	et	3	main
käitumisele	doc_527420171751_item	3578622	et	4	main
teistmoodi	doc_527420171751_item	3578623	et	3	main
õigesti	doc_527420171751_item	3578624	et	3	main
võib	doc_527420171751_item	3578625	et	3	main
olla	doc_527420171751_item	3578626	et	3	main
nad	doc_527420171751_item	3578627	et	3	main
ei	doc_527420171751_item	3578628	et	4	main
anna	doc_527420171751_item	3578629	et	4	main
oma	doc_527420171751_item	3578630	et	4	main
tegudest	doc_527420171751_item	3578631	et	3	main
aru	doc_527420171751_item	3578632	et	4	main
nii	doc_527420171751_item	3578633	et	3	main
nagu	doc_527420171751_item	3578634	et	3	main
see	doc_527420171751_item	3578635	et	3	main
tuleb	doc_527420171751_item	3578636	et	3	main
võib	doc_527420171751_item	3578649	et	3	main
elu	doc_527420171751_item	3578651	et	4	main
on	doc_527420171751_item	3578662	et	4	main
ma	doc_527420171751_item	3578674	et	3	main
hirmusta	doc_527420171751_item	3578688	et	4	main
ja	doc_527420171751_item	3578689	et	3	main
lõbus	doc_542009824793_item	3578708	et	4	main
see	doc_542009824793_item	3578710	et	3	main
et	doc_542009824793_item	3578712	et	3	main
istuda	doc_542009824793_item	3578727	et	3	main
on	doc_542009824793_item	3578729	et	4	main
head	doc_542009824793_item	3578731	et	4	main
pingelises	doc_542009824793_item	3578735	et	4	main
olukorras	doc_542009824793_item	3578736	et	3	main
pöördun	doc_542009824793_item	3578737	et	3	main
võin	doc_542009824793_item	3578746	et	3	main
pöörduda	doc_542009824793_item	3578748	et	3	main
abi	doc_542009824793_item	3578749	et	4	main
heal	doc_542009824793_item	3578755	et	3	main
iga	doc_542009824793_item	3578775	et	4	main
koos	doc_542009824793_item	3578781	et	4	main
palub	doc_542009824793_item	3578787	et	3	main
mind	doc_542009824793_item	3578788	et	4	main
appi	doc_542009824793_item	3578789	et	4	main
siis	doc_542009824793_item	3578790	et	3	main
tavaliselt	doc_542009824793_item	3578791	et	4	main
ma	doc_542009824793_item	3578792	et	3	main
ikka	doc_542009824793_item	3578793	et	4	main
lähen	doc_542009824793_item	3578794	et	3	main
appi	doc_542009824793_item	3578795	et	4	main
alati	doc_542009824793_item	3578796	et	4	main
püüan	doc_542009824793_item	3578797	et	3	main
aidata	doc_542009824793_item	3578798	et	4	main
teist	doc_542009824793_item	3578799	et	4	main
kui	doc_542009824793_item	3578800	et	3	main
saan	doc_542009824793_item	3578801	et	4	main
selliseit	doc_542009824793_item	3578802	et	4	main
olukordi	doc_542009824793_item	3578803	et	4	main
juhtub	doc_542009824793_item	3578804	et	3	main
küll	doc_542009824793_item	3578805	et	4	main
harva	doc_542009824793_item	3578806	et	4	main
kuid	doc_542009824793_item	3578807	et	4	main
ikka	doc_542009824793_item	3578808	et	4	main
juhtub	doc_542009824793_item	3578809	et	3	main
kui	doc_542009824793_item	3578810	et	3	main
mul	doc_542009824793_item	3578811	et	3	main
pole	doc_542009824793_item	3578812	et	3	main
mingeid	doc_542009824793_item	3578813	et	3	main
kohustusi	doc_542009824793_item	3578814	et	4	main
siis	doc_542009824793_item	3578815	et	3	main
mulle	doc_542009824793_item	3578717	et	4	main
internetis	doc_542009824793_item	3578726	et	4	main
nende	doc_542009824793_item	3578738	et	4	main
ei	doc_542009824793_item	3578743	et	4	main
alati	doc_542009824793_item	3578747	et	4	main
poole	doc_542009824793_item	3578752	et	4	main
kui	doc_542009824793_item	3578753	et	3	main
on	doc_542009824793_item	3578757	et	4	main
unusta	doc_542009824793_item	3578763	et	4	main
sest	doc_542009824793_item	3578766	et	4	main
käia	doc_542009824793_item	3578770	et	4	main
ja	doc_542009824793_item	3578771	et	3	main
kui	doc_542009824793_item	3578784	et	3	main
ma	doc_542009824793_item	3578816	et	3	main
tavaliselt	doc_542009824793_item	3578817	et	4	main
iga	doc_567528375368_item	3578827	et	4	main
reis	doc_567528375368_item	3578828	et	4	main
pakub	doc_567528375368_item	3578829	et	3	main
uusi	doc_567528375368_item	3578830	et	3	main
on	doc_567528375368_item	3578833	et	4	main
omamoodi	doc_567528375368_item	3578834	et	3	main
praktiliselt	doc_567528375368_item	3578842	et	4	main
annab	doc_567528375368_item	3578845	et	3	main
silmaringi	doc_567528375368_item	3578858	et	4	main
tujus	doc_567528375368_item	3578878	et	3	main
on	doc_567528375368_item	3578880	et	4	main
on	doc_567528375368_item	3578887	et	4	main
lihtsalt	doc_567528375368_item	3578888	et	4	main
väga	doc_567528375368_item	3578889	et	3	main
romantika	doc_567528375368_item	3578913	et	4	main
on	doc_567528375368_item	3578914	et	4	main
oma	doc_567528375368_item	3578962	et	4	main
kõrval	doc_567528375368_item	3578976	et	4	main
minu	doc_567528375369_item	3579107	et	3	main
tähtsam	doc_567528375369_item	3579110	et	4	main
aspekt	doc_567528375369_item	3579111	et	3	main
uue	doc_567528375369_item	3579112	et	3	main
kaubanduskeskuse	doc_567528375369_item	3579113	et	3	main
on	doc_567528375369_item	3579122	et	4	main
leida	doc_567528375369_item	3579138	et	3	main
sobivat	doc_567528375369_item	3579139	et	4	main
on	doc_567528375369_item	3579142	et	4	main
et	doc_567528375369_item	3579144	et	3	main
oleks	doc_567528375369_item	3579146	et	3	main
on	doc_567528375369_item	3579187	et	4	main
tähtsad	doc_567528375369_item	3579188	et	3	main
ka	doc_567528375369_item	3579189	et	3	main
firmad	doc_567528375369_item	3579190	et	3	main
ja	doc_567528375369_item	3579191	et	3	main
teenused	doc_567528375369_item	3579192	et	3	main
mitmefunktsionaalne	doc_567528375369_item	3579199	et	3	main
oleks	doc_567528375369_item	3579202	et	3	main
juures	doc_567528375369_item	3579204	et	4	main
lõpuks	doc_567528375369_item	3579205	et	4	main
essee	doc_617668397762_item	3579234	et	4	main
komöödiasugemetega	doc_617668397762_item	3579239	et	3	main
13	doc_617668397762_item	3579244	et	2	main
eestis	doc_617668397762_item	3579247	et	3	main
suured	doc_617668397762_item	3579259	et	3	main
võimsad	doc_617668397762_item	3579260	et	3	main
ja	doc_617668397762_item	3579261	et	3	main
verised	doc_617668397762_item	3579262	et	4	main
väed	doc_617668397762_item	3579263	et	3	main
on	doc_617668397762_item	3579275	et	4	main
uru	doc_617668397762_item	3579276	et	3	main
tema	doc_617668397762_item	3579277	et	4	main
näol	doc_617668397762_item	3579278	et	4	main
on	doc_617668397762_item	3579279	et	4	main
tasakaalu	doc_617668397762_item	3579291	et	4	main
eestlaseks	doc_617668397762_item	3579292	et	3	main
ei	doc_617668397762_item	3579300	et	4	main
sugugi	doc_617668397762_item	3579303	et	4	main
sisemise	doc_617668397762_item	3579306	et	3	main
käigus	doc_617668397762_item	3579308	et	4	main
satub	doc_617668397762_item	3579309	et	3	main
uru	doc_617668397762_item	3579310	et	3	main
mitmete	doc_617668397762_item	3579311	et	4	main
et	doc_617668397762_item	3579340	et	3	main
peab	doc_617668397762_item	3579348	et	4	main
kasvõi	doc_617668397762_item	3579349	et	3	main
kultuurilooga	doc_617668397762_item	3579356	et	4	main
samas	doc_617668397762_item	3579357	et	4	main
nõus	doc_567528375368_item	3578841	et	4	main
igal	doc_567528375368_item	3578860	et	3	main
mis	doc_567528375368_item	3578866	et	4	main
meeldiv	doc_567528375368_item	3578869	et	4	main
mõnikord	doc_567528375368_item	3578870	et	3	main
juhtub	doc_567528375368_item	3578871	et	3	main
nii	doc_567528375368_item	3578872	et	3	main
et	doc_567528375368_item	3578873	et	3	main
inimene	doc_567528375368_item	3578874	et	3	main
tuleb	doc_567528375368_item	3578875	et	3	main
reisist	doc_567528375368_item	3578876	et	3	main
ta	doc_567528375368_item	3578879	et	4	main
väsinud	doc_567528375368_item	3578890	et	4	main
maitsetest	doc_567528375368_item	3578896	et	4	main
on	doc_567528375368_item	3578897	et	4	main
iga	doc_567528375368_item	3578900	et	4	main
reis	doc_567528375368_item	3578901	et	4	main
romantika	doc_567528375368_item	3578905	et	4	main
on	doc_567528375368_item	3578918	et	4	main
vaadata	doc_567528375368_item	3578921	et	4	main
päikeseloojangut	doc_567528375368_item	3578922	et	3	main
istuda	doc_567528375368_item	3578923	et	3	main
kaminatule	doc_567528375368_item	3578924	et	4	main
valgel	doc_567528375368_item	3578925	et	4	main
mida	doc_567528375368_item	3578957	et	4	main
lähedaste	doc_567528375368_item	3578963	et	3	main
inimestega	doc_567528375368_item	3578964	et	3	main
arvates	doc_567528375369_item	3579108	et	4	main
valik	doc_567528375369_item	3579117	et	3	main
iga	doc_567528375369_item	3579118	et	4	main
kauplus	doc_567528375369_item	3579119	et	3	main
peamine	doc_567528375369_item	3579120	et	3	main
ülesanne	doc_567528375369_item	3579121	et	4	main
kaubakeskuses	doc_567528375369_item	3579126	et	4	main
olema	doc_567528375369_item	3579128	et	4	main
suur	doc_567528375369_item	3579129	et	3	main
kvaliteet-kaupade	doc_567528375369_item	3579130	et	3	main
valik	doc_567528375369_item	3579131	et	3	main
ja	doc_567528375369_item	3579132	et	3	main
erinevad	doc_567528375369_item	3579133	et	4	main
on	doc_567528375369_item	3579180	et	4	main
kaupluses	doc_567528375369_item	3579183	et	3	main
tekki	doc_567528375369_item	3579185	et	4	main
järjekordi	doc_567528375369_item	3579186	et	4	main
kaubakeskuses	doc_567528375369_item	3579195	et	4	main
siis	doc_567528375369_item	3579196	et	3	main
see	doc_567528375369_item	3579197	et	3	main
kõik	doc_567528375369_item	3579201	et	4	main
ma	doc_567528375369_item	3579206	et	3	main
nimetaksin	doc_567528375369_item	3579207	et	3	main
sisekujundust	doc_567528375369_item	3579208	et	3	main
kauba	doc_567528375369_item	3579209	et	3	main
keskus	doc_567528375369_item	3579210	et	3	main
peab	doc_567528375369_item	3579211	et	4	main
vastama	doc_567528375369_item	3579212	et	3	main
sanitaarnõuetele	doc_567528375369_item	3579213	et	4	main
ruumid	doc_567528375369_item	3579214	et	4	main
peavad	doc_567528375369_item	3579215	et	4	main
olema	doc_567528375369_item	3579216	et	4	main
remonditud	doc_567528375369_item	3579217	et	4	main
puhtad	doc_567528375369_item	3579218	et	3	main
ja	doc_567528375369_item	3579219	et	3	main
romantika	doc_567528375368_item	3578835	et	4	main
ma	doc_567528375368_item	3578836	et	3	main
olen	doc_567528375368_item	3578837	et	3	main
iga	doc_567528375368_item	3578843	et	4	main
reis	doc_567528375368_item	3578844	et	4	main
uusi	doc_567528375368_item	3578846	et	3	main
tutvumisi	doc_567528375368_item	3578848	et	4	main
inimene	doc_567528375368_item	3578849	et	3	main
külastab	doc_567528375368_item	3578850	et	3	main
muuseume	doc_567528375368_item	3578851	et	3	main
ekskursioone	doc_567528375368_item	3578852	et	3	main
üritusi	doc_567528375368_item	3578853	et	4	main
vaatab	doc_567528375368_item	3578854	et	3	main
vaatamisväärsusi	doc_567528375368_item	3578855	et	4	main
avardab	doc_567528375368_item	3578856	et	3	main
kuid	doc_567528375368_item	3578859	et	4	main
ka	doc_567528375368_item	3578863	et	3	main
pettunud	doc_567528375368_item	3578881	et	4	main
või	doc_567528375368_item	3578886	et	4	main
tema	doc_567528375368_item	3578895	et	4	main
omamoodi	doc_567528375368_item	3578903	et	3	main
arvates	doc_567528375368_item	3578912	et	4	main
ümber	doc_567528375368_item	3578917	et	3	main
meeldivad	doc_567528375368_item	3578919	et	4	main
on	doc_567528375368_item	3578958	et	4	main
kahjuks	doc_567528375368_item	3578965	et	4	main
mitte	doc_567528375368_item	3578966	et	3	main
alati	doc_567528375368_item	3578967	et	4	main
need	doc_567528375368_item	3578968	et	3	main
elamused	doc_567528375368_item	3578969	et	3	main
on	doc_567528375368_item	3578970	et	4	main
põnevad	doc_567528375368_item	3578971	et	3	main
ja	doc_567528375368_item	3578972	et	3	main
armsad	doc_567528375368_item	3578973	et	3	main
inimesed	doc_567528375368_item	3578974	et	3	main
jalutada	doc_567528375368_item	3578926	et	3	main
mere	doc_567528375368_item	3578927	et	3	main
kaldas	doc_567528375368_item	3578928	et	3	main
on	doc_567528375368_item	3578929	et	4	main
romantiline	doc_567528375368_item	3578930	et	3	main
mitte	doc_567528375368_item	3578931	et	3	main
igas	doc_567528375368_item	3578932	et	3	main
on	doc_567528375368_item	3578934	et	4	main
reisis	doc_567528375368_item	3578933	et	4	main
võimalus	doc_567528375368_item	3578935	et	3	main
olla	doc_567528375368_item	3578936	et	3	main
koos	doc_567528375368_item	3578937	et	4	main
suhelda	doc_567528375368_item	3578938	et	4	main
meeldivate	doc_567528375368_item	3578939	et	4	main
inimestega	doc_567528375368_item	3578940	et	3	main
ja	doc_567528375368_item	3578941	et	3	main
vaadata	doc_567528375368_item	3578942	et	4	main
mõnusaid	doc_567528375368_item	3578943	et	3	main
maalisi	doc_567528375368_item	3578944	et	4	main
kohti	doc_567528375368_item	3578945	et	4	main
kokkuvõtteks	doc_567528375368_item	3578946	et	3	main
võiks	doc_567528375368_item	3578947	et	4	main
öelda	doc_567528375368_item	3578948	et	4	main
et	doc_567528375368_item	3578949	et	3	main
iga	doc_567528375368_item	3578950	et	4	main
reis	doc_567528375368_item	3578951	et	4	main
toob	doc_567528375368_item	3578952	et	3	main
uusi	doc_567528375368_item	3578953	et	3	main
elamusi	doc_567528375368_item	3578954	et	3	main
ja	doc_567528375368_item	3578955	et	3	main
avastusi	doc_567528375368_item	3578956	et	4	main
kõige	doc_567528375368_item	3578959	et	4	main
on	doc_567528375369_item	3579115	et	4	main
kaupade	doc_567528375369_item	3579116	et	3	main
hias	doc_567528375369_item	3579125	et	4	main
peab	doc_567528375369_item	3579127	et	4	main
asja	doc_567528375369_item	3579140	et	4	main
tähtis	doc_567528375369_item	3579143	et	4	main
kaubakeskus	doc_567528375369_item	3579145	et	3	main
hea	doc_567528375369_item	3579181	et	4	main
mis	doc_567528375369_item	3579193	et	4	main
malev	doc_617668397762_item	3579236	et	3	main
mille	doc_617668397762_item	3579241	et	3	main
ordu	doc_617668397762_item	3579258	et	4	main
loodusrahvaid	doc_617668397762_item	3579267	et	3	main
allutada	doc_617668397762_item	3579269	et	3	main
haritud	doc_617668397762_item	3579283	et	4	main
kes	doc_617668397762_item	3579286	et	4	main
justkui	doc_617668397762_item	3579287	et	3	main
peab	doc_617668397762_item	3579288	et	4	main
leidma	doc_617668397762_item	3579289	et	3	main
vahel	doc_617668397762_item	3579297	et	4	main
see	doc_617668397762_item	3579298	et	3	main
aga	doc_617668397762_item	3579302	et	3	main
lihtne	doc_617668397762_item	3579304	et	3	main
võitluse	doc_617668397762_item	3579307	et	3	main
film	doc_617668397762_item	3579334	et	3	main
nüüdisaja	doc_617668397762_item	3579336	et	3	main
ajaloo	doc_617668397762_item	3579354	et	4	main
ajalooteadmistega	doc_617668397762_item	3579361	et	3	main
mõnikord	doc_617668397762_item	3579363	et	3	main
peale	doc_617668397762_item	3579365	et	4	main
hakata	doc_617668397762_item	3579366	et	4	main
ajaloolise	doc_617668397762_item	3579377	et	4	main
filmiteost	doc_617668397762_item	3579421	et	4	main
et	doc_617668397762_item	3579447	et	3	main
et	doc_617668397762_item	3579458	et	3	main
see	doc_617668397762_item	3579459	et	3	main
eesti	doc_617668397762_item	3579469	et	4	main
komöödia	doc_617668397765_item	3579476	et	4	main
üritavad	doc_617668397765_item	3579489	et	4	main
mis	doc_617668397765_item	3579499	et	4	main
noormees	doc_617668397765_item	3579517	et	4	main
jõudu	doc_617668397765_item	3579520	et	4	main
kannatust	doc_617668397765_item	3579522	et	4	main
eelkõige	doc_617668397765_item	3579541	et	3	main
oma	doc_617668397765_item	3579555	et	4	main
rahva	doc_617668397765_item	3579560	et	3	main
tegutseda	doc_617668397765_item	3579564	et	3	main
rahva	doc_617668397765_item	3579576	et	3	main
laulsid	doc_617668397765_item	3579581	et	4	main
põldudel	doc_617668397765_item	3579582	et	3	main
töötades	doc_617668397765_item	3579583	et	3	main
ei	doc_617668397765_item	3579590	et	4	main
nende	doc_617668397765_item	3579592	et	4	main
elu	doc_617668397765_item	3579593	et	4	main
viist	doc_617668397765_item	3579598	et	4	main
millekski	doc_617668397765_item	3579623	et	4	main
usku	doc_617668397765_item	3579655	et	4	main
vanemate	doc_617668397765_item	3579657	et	4	main
poole	doc_617668397765_item	3579658	et	4	main
paljude	doc_617668397765_item	3579666	et	3	main
vanemate	doc_617668397765_item	3579667	et	4	main
selle	doc_617668397765_item	3579683	et	4	main
kooskõla	doc_617668397765_item	3579697	et	4	main
aga	doc_617668397765_item	3579698	et	3	main
tõeliselt	doc_617668397765_item	3579699	et	4	main
teevad	doc_617668397765_item	3579703	et	3	main
filmi	doc_617668397765_item	3579713	et	4	main
essee	doc_634572338226_item	3579726	et	4	main
kelder	doc_634572338226_item	3579735	et	3	main
pikkus	doc_634572338226_item	3579753	et	4	main
magamistuba	doc_634572338226_item	3579757	et	4	main
keskkonda	doc_634572338226_item	3579774	et	4	main
imitatsioon	doc_634572338226_item	3579775	et	3	main
ja	doc_634572338226_item	3579801	et	3	main
jaoks	doc_634572338226_item	3579803	et	4	main
edasi	doc_634572338226_item	3579804	et	3	main
on	doc_634572338226_item	3579805	et	4	main
katta	doc_634572338226_item	3579812	et	3	main
esteetilised	doc_567528375369_item	3579220	et	3	main
see	doc_567528375369_item	3579221	et	3	main
on	doc_567528375369_item	3579222	et	4	main
meeldiv	doc_567528375369_item	3579223	et	4	main
meie	doc_567528375369_item	3579224	et	4	main
silmadele	doc_567528375369_item	3579225	et	3	main
ja	doc_567528375369_item	3579226	et	3	main
tujule	doc_567528375369_item	3579227	et	3	main
aga	doc_567528375369_item	3579228	et	3	main
see	doc_567528375369_item	3579229	et	3	main
ei	doc_567528375369_item	3579230	et	4	main
muutu	doc_567528375369_item	3579231	et	4	main
olemust	doc_567528375369_item	3579232	et	3	main
projekteerimises	doc_567528375369_item	3579114	et	4	main
müüa	doc_567528375369_item	3579123	et	3	main
võiks	doc_567528375369_item	3579137	et	4	main
seal	doc_567528375369_item	3579152	et	4	main
oleksid	doc_567528375369_item	3579153	et	4	main
head	doc_567528375369_item	3579154	et	4	main
hinnad	doc_567528375369_item	3579155	et	3	main
toimuksid	doc_567528375369_item	3579156	et	4	main
soodutused	doc_567528375369_item	3579157	et	4	main
praktiliselt	doc_567528375369_item	3579158	et	4	main
iga	doc_567528375369_item	3579159	et	4	main
klient	doc_567528375369_item	3579160	et	3	main
on	doc_567528375369_item	3579161	et	4	main
huvitatud	doc_567528375369_item	3579162	et	4	main
kauba	doc_567528375369_item	3579163	et	3	main
hinnast	doc_567528375369_item	3579164	et	4	main
lisaks	doc_567528375369_item	3579165	et	4	main
kaubakeskuse	doc_567528375369_item	3579166	et	3	main
hoones	doc_567528375369_item	3579167	et	4	main
peavad	doc_567528375369_item	3579168	et	4	main
olema	doc_567528375369_item	3579169	et	4	main
mugavad	doc_567528375369_item	3579170	et	3	main
ja	doc_567528375369_item	3579171	et	3	main
avarad	doc_567528375369_item	3579172	et	3	main
ruumid	doc_567528375369_item	3579173	et	4	main
et	doc_567528375369_item	3579174	et	3	main
võiks	doc_567528375369_item	3579175	et	4	main
mõeldud	doc_567528375369_item	3579147	et	4	main
erineva	doc_567528375369_item	3579148	et	4	main
sissetulekuga	doc_567528375369_item	3579149	et	3	main
inimestele	doc_567528375369_item	3579150	et	3	main
et	doc_567528375369_item	3579151	et	3	main
kui	doc_567528375369_item	3579182	et	3	main
ei	doc_567528375369_item	3579184	et	4	main
oleksid	doc_567528375369_item	3579194	et	4	main
oleks	doc_567528375369_item	3579198	et	3	main
käe-jala	doc_567528375369_item	3579203	et	2	main
ajalooline	doc_617668397762_item	3579238	et	4	main
toimub	doc_617668397762_item	3579243	et	3	main
alguse	doc_617668397762_item	3579246	et	3	main
liivimaal	doc_617668397762_item	3579249	et	4	main
film	doc_617668397762_item	3579251	et	3	main
käsitleb	doc_617668397762_item	3579252	et	3	main
ning	doc_617668397762_item	3579253	et	3	main
näitab	doc_617668397762_item	3579254	et	3	main
olukordi	doc_617668397762_item	3579255	et	4	main
kus	doc_617668397762_item	3579256	et	3	main
üritavad	doc_617668397762_item	3579264	et	4	main
euroopas	doc_617668397762_item	3579282	et	3	main
noormehega	doc_617668397762_item	3579285	et	3	main
ja	doc_617668397762_item	3579294	et	3	main
eurooplaseks	doc_617668397762_item	3579295	et	3	main
saamise	doc_617668397762_item	3579296	et	4	main
keeruliste	doc_617668397762_item	3579312	et	4	main
intriigide	doc_617668397762_item	3579313	et	3	main
ning	doc_617668397762_item	3579314	et	3	main
vabalt	doc_567528375369_item	3579176	et	4	main
ja	doc_567528375369_item	3579177	et	3	main
mõnusalt	doc_567528375369_item	3579178	et	4	main
liikuda	doc_567528375369_item	3579179	et	3	main
ja	doc_567528375369_item	3579200	et	3	main
on	doc_617668397762_item	3579237	et	4	main
seiklusfilm	doc_617668397762_item	3579240	et	3	main
sajandi	doc_617668397762_item	3579245	et	3	main
ja	doc_617668397762_item	3579248	et	3	main
saksa	doc_617668397762_item	3579257	et	4	main
siinseid	doc_617668397762_item	3579265	et	3	main
endale	doc_617668397762_item	3579268	et	4	main
ning	doc_617668397762_item	3579270	et	3	main
filmi	doc_617668397762_item	3579272	et	4	main
keskseks	doc_617668397762_item	3579273	et	4	main
tegelaskujuks	doc_617668397762_item	3579274	et	3	main
tegemist	doc_617668397762_item	3579280	et	4	main
esimese	doc_617668397762_item	3579281	et	3	main
eesti	doc_617668397762_item	3579284	et	4	main
jäämise	doc_617668397762_item	3579293	et	4	main
ole	doc_617668397762_item	3579301	et	4	main
suure	doc_617668397762_item	3579305	et	3	main
seda	doc_617668397762_item	3579346	et	3	main
mõista	doc_617668397762_item	3579347	et	4	main
ning	doc_617668397762_item	3579355	et	3	main
õpitud	doc_617668397762_item	3579360	et	4	main
mängufilmide	doc_617668397762_item	3579372	et	3	main
siis	doc_617668397762_item	3579380	et	3	main
film	doc_617668397762_item	3579384	et	3	main
meie	doc_617668397762_item	3579409	et	4	main
rahvalikke	doc_617668397762_item	3579410	et	3	main
ajaloomüüte	doc_617668397762_item	3579411	et	3	main
ja	doc_617668397762_item	3579412	et	3	main
stampseisukohti	doc_617668397762_item	3579413	et	4	main
antud	doc_617668397762_item	3579420	et	4	main
kõigil	doc_617668397762_item	3579423	et	4	main
soovivad	doc_617668397762_item	3579425	et	4	main
teada	doc_617668397762_item	3579426	et	3	main
eestlased	doc_617668397762_item	3579430	et	3	main
ning	doc_617668397762_item	3579432	et	3	main
kuna	doc_617668397762_item	3579434	et	3	main
ise	doc_617668397762_item	3579435	et	4	main
peab	doc_617668397762_item	3579456	et	4	main
ei	doc_617668397762_item	3579461	et	4	main
ole	doc_617668397762_item	3579462	et	4	main
puhas	doc_617668397762_item	3579463	et	3	main
ajaloost	doc_617668397762_item	3579470	et	4	main
õpin	doc_617668397762_item	3579436	et	3	main
tallinna	doc_617668397762_item	3579437	et	4	main
ülikoolis	doc_617668397762_item	3579438	et	4	main
eesti	doc_617668397762_item	3579439	et	4	main
keelt	doc_617668397762_item	3579440	et	4	main
võõrkeelena	doc_617668397762_item	3579441	et	3	main
ja	doc_617668397762_item	3579442	et	3	main
eesti	doc_617668397762_item	3579443	et	4	main
kultuuri	doc_617668397762_item	3579444	et	4	main
siis	doc_617668397762_item	3579445	et	3	main
leian	doc_617668397762_item	3579446	et	3	main
malev	doc_617668397762_item	3579235	et	3	main
tegevus	doc_617668397762_item	3579242	et	4	main
antud	doc_617668397762_item	3579250	et	4	main
muistseid	doc_617668397762_item	3579266	et	3	main
ristida	doc_617668397762_item	3579271	et	4	main
endas	doc_617668397762_item	3579290	et	4	main
kõik	doc_617668397762_item	3579299	et	4	main
pööraste	doc_617668397762_item	3579315	et	4	main
sündmuste	doc_617668397762_item	3579316	et	3	main
keerisesse	doc_617668397762_item	3579317	et	4	main
kus	doc_617668397762_item	3579318	et	3	main
temast	doc_617668397762_item	3579319	et	3	main
sõltub	doc_617668397762_item	3579320	et	3	main
isegi	doc_617668397762_item	3579321	et	4	main
sünnimaa	doc_617668397762_item	3579322	et	4	main
tulevik	doc_617668397762_item	3579323	et	3	main
malev	doc_617668397762_item	3579324	et	3	main
üks	doc_617668397762_item	3579326	et	3	main
ehe	doc_617668397762_item	3579327	et	4	main
on	doc_617668397762_item	3579325	et	4	main
eesti	doc_617668397762_item	3579328	et	4	main
asi	doc_617668397762_item	3579329	et	4	main
omamoodi	doc_617668397762_item	3579330	et	3	main
takune	doc_617668397762_item	3579331	et	4	main
ja	doc_617668397762_item	3579332	et	3	main
maavillane	doc_617668397762_item	3579333	et	4	main
muinaseestlastest	doc_617668397762_item	3579335	et	4	main
vaatevinklist	doc_617668397762_item	3579338	et	4	main
vaadatuna	doc_617668397762_item	3579339	et	4	main
filmiteosest	doc_617668397762_item	3579342	et	4	main
vähekenegi	doc_617668397762_item	3579350	et	4	main
olema	doc_617668397762_item	3579351	et	4	main
kursis	doc_617668397762_item	3579352	et	3	main
pole	doc_617668397762_item	3579358	et	3	main
koolis	doc_617668397762_item	3579359	et	4	main
ja	doc_617668397762_item	3579371	et	3	main
üritavad	doc_617668397762_item	3579374	et	4	main
alati	doc_617668397762_item	3579375	et	4	main
kajastab	doc_617668397762_item	3579381	et	3	main
ajalooteemaline	doc_617668397762_item	3579383	et	4	main
lisada	doc_617668397762_item	3579417	et	3	main
et	doc_617668397762_item	3579418	et	3	main
vaadata	doc_617668397762_item	3579422	et	4	main
kes	doc_617668397762_item	3579424	et	4	main
on	doc_617668397762_item	3579429	et	4	main
tõde	doc_617668397762_item	3579464	et	4	main
vaid	doc_617668397762_item	3579465	et	3	main
malev	doc_617668397765_item	3579474	et	3	main
tegevus	doc_617668397765_item	3579478	et	4	main
alguse	doc_617668397765_item	3579482	et	3	main
ja	doc_617668397765_item	3579484	et	3	main
kus	doc_617668397765_item	3579486	et	3	main
saksa	doc_617668397765_item	3579487	et	4	main
ordu	doc_617668397765_item	3579488	et	4	main
filmis	doc_617668397765_item	3579495	et	4	main
käsitletakse	doc_617668397765_item	3579496	et	3	main
paljusid	doc_617668397765_item	3579497	et	3	main
teemasid	doc_617668397765_item	3579498	et	3	main
eesti	doc_617668397765_item	3579503	et	4	main
vapper	doc_617668397765_item	3579513	et	3	main
andekas	doc_617668397765_item	3579514	et	4	main
ja	doc_617668397765_item	3579515	et	3	main
leidis	doc_617668397765_item	3579518	et	4	main
eestlaste	doc_617668397762_item	3579337	et	4	main
antud	doc_617668397762_item	3579341	et	4	main
aru	doc_617668397762_item	3579343	et	4	main
saada	doc_617668397762_item	3579344	et	4	main
ning	doc_617668397762_item	3579345	et	3	main
eestimaa	doc_617668397762_item	3579353	et	4	main
sest	doc_617668397762_item	3579367	et	4	main
kuigi	doc_617668397762_item	3579368	et	3	main
püüelda	doc_617668397762_item	3579376	et	4	main
poole	doc_617668397762_item	3579379	et	4	main
iga	doc_617668397762_item	3579382	et	4	main
ikkagi	doc_617668397762_item	3579385	et	4	main
eelkõige	doc_617668397762_item	3579386	et	3	main
tegijate	doc_617668397762_item	3579387	et	4	main
arusaama	doc_617668397762_item	3579388	et	4	main
minevikust	doc_617668397762_item	3579389	et	3	main
maleva	doc_617668397762_item	3579390	et	3	main
tegijad	doc_617668397762_item	3579391	et	4	main
näivad	doc_617668397762_item	3579392	et	4	main
olevat	doc_617668397762_item	3579393	et	4	main
asja	doc_617668397762_item	3579394	et	4	main
eriti	doc_617668397762_item	3579395	et	3	main
põhjalikult	doc_617668397762_item	3579396	et	4	main
ette	doc_617668397762_item	3579397	et	4	main
võtnud	doc_617668397762_item	3579398	et	4	main
sest	doc_617668397762_item	3579399	et	4	main
nad	doc_617668397762_item	3579400	et	3	main
ei	doc_617668397762_item	3579401	et	4	main
käsitle	doc_617668397762_item	3579402	et	4	main
mitte	doc_617668397762_item	3579403	et	3	main
lihtsalt	doc_617668397762_item	3579404	et	4	main
eestlaste	doc_617668397762_item	3579405	et	4	main
ajalugu	doc_617668397762_item	3579406	et	4	main
kunstis	doc_617668397762_item	3579362	et	3	main
midagi	doc_617668397762_item	3579364	et	4	main
ajalooteemaliste	doc_617668397762_item	3579369	et	4	main
romaanide	doc_617668397762_item	3579370	et	3	main
tegijad	doc_617668397762_item	3579373	et	4	main
tõepära	doc_617668397762_item	3579378	et	4	main
vaid	doc_617668397762_item	3579407	et	3	main
ka	doc_617668397762_item	3579408	et	3	main
võiks	doc_617668397762_item	3579415	et	4	main
veel	doc_617668397762_item	3579416	et	4	main
soovitan	doc_617668397762_item	3579419	et	3	main
kes	doc_617668397762_item	3579428	et	4	main
ajalooliselt	doc_617668397762_item	3579431	et	4	main
kultuuriliselt	doc_617668397762_item	3579433	et	4	main
malev	doc_617668397762_item	3579448	et	3	main
just	doc_617668397762_item	3579450	et	3	main
vaatamiseks	doc_617668397762_item	3579452	et	4	main
minusugustele	doc_617668397762_item	3579453	et	3	main
samas	doc_617668397762_item	3579455	et	4	main
mõistma	doc_617668397762_item	3579457	et	3	main
film	doc_617668397762_item	3579460	et	3	main
tõlgendus	doc_617668397762_item	3579468	et	4	main
ajaloolise	doc_617668397765_item	3579475	et	4	main
malev	doc_617668397765_item	3579477	et	3	main
13	doc_617668397765_item	3579480	et	2	main
sajandi	doc_617668397765_item	3579481	et	3	main
seotud	doc_617668397765_item	3579502	et	4	main
tõestada	doc_617668397765_item	3579524	et	3	main
vabaduse	doc_617668397765_item	3579533	et	4	main
nimel	doc_617668397765_item	3579534	et	3	main
uru	doc_617668397765_item	3579535	et	3	main
veenas	doc_617668397765_item	3579536	et	4	main
selle	doc_617668397765_item	3579547	et	4	main
noormehe	doc_617668397765_item	3579548	et	3	main
maal	doc_617668397765_item	3579556	et	4	main
peremehed	doc_617668397765_item	3579557	et	3	main
kultuuri	doc_617668397765_item	3579561	et	4	main
ja	doc_617668397765_item	3579572	et	3	main
või	doc_617668397765_item	3579586	et	4	main
ilma	doc_617668397765_item	3579594	et	4	main
lauluta	doc_617668397765_item	3579595	et	3	main
ette	doc_617668397765_item	3579596	et	4	main
sajandist	doc_617668397765_item	3579601	et	3	main
rahvasümbolid	doc_617668397765_item	3579613	et	3	main
on	doc_617668397765_item	3579614	et	4	main
austusväärsed	doc_617668397765_item	3579615	et	3	main
ei	doc_617668397765_item	3579620	et	4	main
eesti	doc_617668397765_item	3579626	et	4	main
rahvas	doc_617668397765_item	3579627	et	4	main
hindab	doc_617668397765_item	3579628	et	3	main
ja	doc_617668397765_item	3579654	et	3	main
et	doc_617668397765_item	3579671	et	3	main
kokku	doc_617668397765_item	3579681	et	3	main
koguda	doc_617668397765_item	3579682	et	3	main
on	doc_617668397765_item	3579686	et	4	main
komöödia	doc_617668397765_item	3579688	et	4	main
pilgul	doc_617668397765_item	3579690	et	4	main
võib	doc_617668397765_item	3579691	et	3	main
tunduda	doc_617668397765_item	3579692	et	3	main
et	doc_617668397765_item	3579693	et	3	main
humorimeelsus	doc_617668397765_item	3579700	et	4	main
ja	doc_617668397765_item	3579701	et	3	main
naljad	doc_617668397765_item	3579702	et	3	main
veel	doc_617668397765_item	3579705	et	4	main
ja	doc_617668397765_item	3579707	et	3	main
kergesti	doc_617668397765_item	3579708	et	3	main
episoodid	doc_617668397765_item	3579714	et	3	main
kirjeldus	doc_634572338226_item	3579732	et	4	main
ainult	doc_634572338226_item	3579738	et	4	main
plaan	doc_634572338226_item	3579744	et	3	main
andmed	doc_634572338226_item	3579747	et	3	main
lae	doc_634572338226_item	3579752	et	4	main
tuba	doc_634572338226_item	3579756	et	4	main
minu	doc_634572338226_item	3579759	et	3	main
proekti	doc_634572338226_item	3579760	et	4	main
stilistikas	doc_634572338226_item	3579761	et	3	main
on	doc_634572338226_item	3579762	et	4	main
lihtne	doc_634572338226_item	3579763	et	3	main
mõte	doc_634572338226_item	3579764	et	3	main
peaaegu	doc_634572338226_item	3579765	et	3	main
suur	doc_634572338226_item	3579766	et	3	main
kokkuvõtvalt	doc_617668397762_item	3579414	et	4	main
saada	doc_617668397762_item	3579427	et	4	main
on	doc_617668397762_item	3579449	et	4	main
sobiv	doc_617668397762_item	3579451	et	4	main
estofiilidele	doc_617668397762_item	3579454	et	3	main
teatud	doc_617668397762_item	3579466	et	4	main
inimeste	doc_617668397762_item	3579467	et	3	main
essee	doc_617668397765_item	3579472	et	4	main
toimub	doc_617668397765_item	3579479	et	3	main
neid	doc_617668397765_item	3579490	et	4	main
loodusrahvaid	doc_617668397765_item	3579491	et	3	main
allutada	doc_617668397765_item	3579492	et	3	main
ja	doc_617668397765_item	3579493	et	3	main
on	doc_617668397765_item	3579500	et	4	main
endas	doc_617668397765_item	3579519	et	4	main
oma	doc_617668397765_item	3579531	et	4	main
rahva	doc_617668397765_item	3579532	et	3	main
saavutamiseks	doc_617668397765_item	3579540	et	4	main
peab	doc_617668397765_item	3579543	et	4	main
said	doc_617668397765_item	3579550	et	4	main
eestlased	doc_617668397765_item	3579551	et	3	main
säilitada	doc_617668397765_item	3579559	et	3	main
tervikuna	doc_617668397765_item	3579563	et	3	main
on	doc_617668397765_item	3579567	et	4	main
lahingud	doc_617668397765_item	3579715	et	3	main
ei	doc_617668397765_item	3579716	et	4	main
tundu	doc_617668397765_item	3579717	et	4	main
nii	doc_617668397765_item	3579718	et	3	main
hirmuäravateks	doc_617668397765_item	3579719	et	3	main
niisugusteks	doc_617668397765_item	3579720	et	3	main
võiksid	doc_617668397765_item	3579721	et	4	main
olla	doc_617668397765_item	3579722	et	3	main
ilma	doc_617668397765_item	3579723	et	4	main
naljateta	doc_617668397765_item	3579724	et	4	main
kultuuriajakiri	doc_617668397765_item	3579473	et	3	main
eestis	doc_617668397765_item	3579483	et	3	main
liivimaal	doc_617668397765_item	3579485	et	4	main
ristida	doc_617668397765_item	3579494	et	4	main
tihedasti	doc_617668397765_item	3579501	et	3	main
eestlaste	doc_617668397765_item	3579505	et	4	main
vabadusega	doc_617668397765_item	3579506	et	4	main
ja	doc_617668397765_item	3579507	et	3	main
rahvaga	doc_617668397765_item	3579504	et	3	main
kultuuriga	doc_617668397765_item	3579508	et	4	main
peategija	doc_617668397765_item	3579509	et	4	main
uru	doc_617668397765_item	3579510	et	3	main
kes	doc_617668397765_item	3579511	et	4	main
on	doc_617668397765_item	3579512	et	4	main
haritud	doc_617668397765_item	3579516	et	4	main
kõigile	doc_617668397765_item	3579525	et	4	main
eesti	doc_617668397765_item	3579526	et	4	main
võime	doc_617668397765_item	3579528	et	4	main
vastu	doc_617668397765_item	3579529	et	3	main
hakkata	doc_617668397765_item	3579530	et	4	main
rahvas	doc_617668397765_item	3579542	et	4	main
ühine	doc_617668397765_item	3579544	et	4	main
võitlusvaim	doc_617668397765_item	3579545	et	3	main
olema	doc_617668397765_item	3579546	et	4	main
aru	doc_617668397765_item	3579552	et	4	main
et	doc_617668397765_item	3579553	et	3	main
olla	doc_617668397765_item	3579554	et	3	main
nähtud	doc_617668397765_item	3579568	et	4	main
et	doc_617668397765_item	3579569	et	3	main
vanasti	doc_617668397765_item	3579570	et	3	main
laulud	doc_617668397765_item	3579571	et	3	main
mängisid	doc_617668397765_item	3579574	et	4	main
käides	doc_617668397765_item	3579585	et	4	main
siit	doc_617668397765_item	3579599	et	3	main
alust	doc_617668397765_item	3579602	et	4	main
suuliste	doc_617668397765_item	3579604	et	4	main
traditsioonile	doc_617668397765_item	3579605	et	3	main
mida	doc_617668397765_item	3579606	et	4	main
hiljem	doc_617668397765_item	3579607	et	3	main
oma	doc_617668397765_item	3579612	et	4	main
jaoks	doc_617668397765_item	3579617	et	4	main
pidada	doc_617668397765_item	3579624	et	4	main
kuidas	doc_617668397765_item	3579625	et	3	main
nõu	doc_617668397765_item	3579660	et	4	main
küsida	doc_617668397765_item	3579661	et	3	main
nii	doc_617668397765_item	3579662	et	3	main
on	doc_617668397765_item	3579663	et	4	main
ei	doc_617668397765_item	3579672	et	4	main
saa	doc_617668397765_item	3579673	et	4	main
sakslastega	doc_617668397765_item	3579674	et	3	main
rahu	doc_617668397765_item	3579675	et	4	main
teha	doc_617668397765_item	3579676	et	3	main
et	doc_617668397765_item	3579677	et	3	main
ja	doc_617668397765_item	3579521	et	3	main
et	doc_617668397765_item	3579523	et	3	main
rahva	doc_617668397765_item	3579527	et	3	main
eestlasi	doc_617668397765_item	3579537	et	3	main
et	doc_617668397765_item	3579538	et	3	main
eesmärki	doc_617668397765_item	3579539	et	4	main
abil	doc_617668397765_item	3579549	et	4	main
et	doc_617668397765_item	3579558	et	3	main
tuleb	doc_617668397765_item	3579562	et	3	main
malev	doc_617668397765_item	3579565	et	3	main
filmist	doc_617668397765_item	3579566	et	4	main
eestlaste	doc_617668397765_item	3579575	et	4	main
elus	doc_617668397765_item	3579577	et	4	main
rolli	doc_617668397765_item	3579579	et	4	main
muu	doc_617668397765_item	3579587	et	4	main
tegeledes	doc_617668397765_item	3579589	et	3	main
saa	doc_617668397765_item	3579591	et	4	main
kujutada	doc_617668397765_item	3579597	et	3	main
on	doc_617668397765_item	3579608	et	4	main
saa	doc_617668397765_item	3579621	et	4	main
mitte	doc_617668397765_item	3579622	et	3	main
lembitu	doc_617668397765_item	3579659	et	4	main
juurde	doc_617668397765_item	3579668	et	4	main
et	doc_617668397765_item	3579669	et	3	main
tõestada	doc_617668397765_item	3579670	et	3	main
žanr	doc_617668397765_item	3579685	et	2	main
ajalooline	doc_617668397765_item	3579687	et	4	main
esimesel	doc_617668397765_item	3579689	et	3	main
tantsud	doc_617668397765_item	3579573	et	3	main
suurt	doc_617668397765_item	3579578	et	3	main
muinaseestlased	doc_617668397765_item	3579580	et	3	main
jahil	doc_617668397765_item	3579584	et	3	main
tööga	doc_617668397765_item	3579588	et	3	main
13	doc_617668397765_item	3579600	et	2	main
pandi	doc_617668397765_item	3579603	et	4	main
hakatud	doc_617668397765_item	3579609	et	4	main
nimetama	doc_617668397765_item	3579610	et	3	main
rahvaluuleks	doc_617668397765_item	3579611	et	4	main
eestlaste	doc_617668397765_item	3579616	et	4	main
ja	doc_617668397765_item	3579618	et	3	main
neid	doc_617668397765_item	3579619	et	4	main
ja	doc_617668397765_item	3579629	et	3	main
austab	doc_617668397765_item	3579630	et	3	main
rahvussümbole	doc_617668397765_item	3579631	et	4	main
on	doc_617668397765_item	3579632	et	4	main
arusaadav	doc_617668397765_item	3579633	et	4	main
episoodist	doc_617668397765_item	3579634	et	3	main
kus	doc_617668397765_item	3579635	et	3	main
jurmala	doc_617668397765_item	3579636	et	4	main
foogt	doc_617668397765_item	3579637	et	3	main
hippolyt	doc_617668397765_item	3579638	et	4	main
rukkilille	doc_617668397765_item	3579639	et	4	main
maha	doc_617668397765_item	3579640	et	4	main
tallas	doc_617668397765_item	3579641	et	4	main
sattusid	doc_617668397765_item	3579642	et	4	main
siis	doc_617668397765_item	3579643	et	3	main
eestlased	doc_617668397765_item	3579644	et	3	main
raevu	doc_617668397765_item	3579645	et	4	main
ja	doc_617668397765_item	3579646	et	3	main
hakkasid	doc_617668397765_item	3579647	et	4	main
vaenlasi	doc_617668397765_item	3579648	et	3	main
ründama	doc_617668397765_item	3579649	et	3	main
muinaseestlased	doc_617668397765_item	3579650	et	3	main
pidid	doc_617668397765_item	3579651	et	4	main
oma	doc_617668397765_item	3579652	et	4	main
traditsioone	doc_617668397765_item	3579653	et	3	main
pöörasid	doc_617668397765_item	3579656	et	4	main
uru	doc_617668397765_item	3579664	et	3	main
käinud	doc_617668397765_item	3579665	et	4	main
loal	doc_617668397765_item	3579679	et	4	main
inimesi	doc_617668397765_item	3579680	et	4	main
on	doc_617668397765_item	3579694	et	4	main
veider	doc_617668397765_item	3579696	et	3	main
filmi	doc_617668397765_item	3579704	et	4	main
huvitatavamaks	doc_617668397765_item	3579706	et	4	main
mõned	doc_617668397765_item	3579710	et	3	main
verised	doc_617668397765_item	3579712	et	4	main
keldri	doc_634572338226_item	3579727	et	3	main
remontimise	doc_634572338226_item	3579728	et	4	main
proekt	doc_634572338226_item	3579729	et	4	main
kasuliku	doc_634572338226_item	3579730	et	3	main
pindala	doc_634572338226_item	3579731	et	4	main
milles	doc_634572338226_item	3579736	et	3	main
köök	doc_634572338226_item	3579751	et	3	main
ja	doc_634572338226_item	3579810	et	3	main
soendus	doc_634572338226_item	3579824	et	4	main
süsteem	doc_634572338226_item	3579825	et	3	main
on	doc_634572338226_item	3579840	et	4	main
plaadid	doc_634572338226_item	3579848	et	4	main
põrandal	doc_634572338226_item	3579849	et	3	main
uustega	doc_634572338226_item	3579868	et	4	main
vaatamiseks	doc_634572338226_item	3579878	et	4	main
ja	doc_634572338226_item	3579879	et	3	main
akkustika	doc_634572338226_item	3579889	et	4	main
krohvliga	doc_634572338226_item	3579896	et	4	main
planeeritakse	doc_634572338226_item	3579899	et	3	main
kamin	doc_634572338226_item	3579901	et	3	main
jõhkrast	doc_634572338226_item	3579903	et	3	main
on	doc_634572338233_item	3579944	et	4	main
on	doc_634572338233_item	3579948	et	4	main
põrand	doc_634572338233_item	3579950	et	3	main
tehtud	doc_634572338233_item	3579954	et	4	main
ruumis	doc_634572338233_item	3579962	et	4	main
laud	doc_634572338233_item	3579975	et	4	main
ümber	doc_634572338233_item	3579976	et	3	main
essee	doc_634572338244_item	3580035	et	4	main
ajal	doc_634572338244_item	3580043	et	4	main
on	doc_634572338244_item	3580050	et	4	main
ei	doc_634572338244_item	3580054	et	4	main
inimesega	doc_634572338244_item	3580070	et	3	main
mugavalt	doc_634572338244_item	3580073	et	4	main
võib	doc_634572338244_item	3580075	et	3	main
mõned	doc_634572338244_item	3580084	et	3	main
täht	doc_634572338244_item	3580085	et	3	main
nende	doc_634572338244_item	3580086	et	4	main
kõrvaldama	doc_634572338244_item	3580091	et	3	main
mängid	doc_634572338244_item	3580099	et	3	main
väike	doc_634572338244_item	3580104	et	4	main
ja	doc_634572338244_item	3580106	et	3	main
ta	doc_634572338244_item	3580108	et	4	main
kottisse	doc_634572338244_item	3580112	et	4	main
või	doc_634572338244_item	3580113	et	4	main
plastmassist	doc_634572338244_item	3580117	et	3	main
ja	doc_634572338244_item	3580125	et	3	main
on	doc_634572338244_item	3580127	et	4	main
eesnimi	doc_724355862916_item	3580141	et	3	main
perekonnanimi	doc_724355862916_item	3580142	et	3	main
olen	doc_724355862916_item	3580143	et	3	main
ja	doc_724355862916_item	3580146	et	3	main
oli	doc_724355862916_item	3580152	et	3	main
vanemad	doc_724355862916_item	3580156	et	4	main
ma	doc_724355862916_item	3580158	et	3	main
ole	doc_724355862916_item	3580166	et	4	main
lasteaed	doc_724355862916_item	3580167	et	3	main
eesti	doc_724355862916_item	3580171	et	4	main
astusin	doc_724355862916_item	3580179	et	3	main
58	doc_724355862916_item	3580182	et	2	main
gümnaasium	doc_724355862916_item	3580189	et	3	main
möödunud	doc_724355862916_item	3580191	et	4	main
emakeel	doc_724355862916_item	3580238	et	4	main
oma	doc_724355862916_item	3580247	et	4	main
eriala	doc_724355862916_item	3580248	et	4	main
see	doc_724355862916_item	3580258	et	3	main
sellel	doc_724355862916_item	3580267	et	4	main
vanemate	doc_617668397765_item	3579678	et	4	main
filmi	doc_617668397765_item	3579684	et	4	main
see	doc_617668397765_item	3579695	et	3	main
arusaadavaks	doc_617668397765_item	3579709	et	4	main
tõsised	doc_617668397765_item	3579711	et	4	main
majaalune	doc_634572338226_item	3579734	et	4	main
kiviseinad	doc_634572338226_item	3579739	et	3	main
betoneeritud	doc_634572338226_item	3579740	et	4	main
katkine	doc_634572338226_item	3579742	et	4	main
eksplikatsioon	doc_634572338226_item	3579745	et	3	main
esik	doc_634572338226_item	3579748	et	3	main
pind	doc_634572338226_item	3579750	et	3	main
26-	doc_634572338226_item	3579754	et	4	main
abstrageerimine	doc_634572338226_item	3579767	et	4	main
ja	doc_634572338226_item	3579771	et	3	main
loomine	doc_634572338226_item	3579772	et	4	main
köögi	doc_634572338226_item	3579802	et	3	main
vaja	doc_634572338226_item	3579806	et	4	main
seinad	doc_634572338226_item	3579813	et	3	main
isolerivate	doc_634572338226_item	3579818	et	4	main
põrandas	doc_634572338226_item	3579821	et	3	main
peale	doc_634572338226_item	3579826	et	4	main
töö	doc_634572338226_item	3579828	et	4	main
tegemist	doc_634572338226_item	3579829	et	4	main
alustame	doc_634572338226_item	3579830	et	3	main
toa	doc_634572338226_item	3579831	et	3	main
wc	doc_634572338226_item	3579836	et	4	main
toaga	doc_634572338226_item	3579837	et	3	main
vannitoa	doc_634572338226_item	3579838	et	3	main
värvilahendus	doc_634572338226_item	3579839	et	3	main
santehnika	doc_634572338226_item	3579846	et	4	main
valged	doc_634572338226_item	3579847	et	3	main
kappi	doc_634572338226_item	3579866	et	4	main
peegel	doc_634572338226_item	3579867	et	3	main
kino	doc_634572338226_item	3579877	et	4	main
faktuurse	doc_634572338226_item	3579895	et	4	main
elektri	doc_634572338226_item	3579900	et	3	main
tugitooli	doc_634572338226_item	3579908	et	4	main
ja	doc_634572338226_item	3579909	et	3	main
ajakirja	doc_634572338226_item	3579911	et	4	main
lauast	doc_634572338226_item	3579912	et	4	main
magamistoa	doc_634572338226_item	3579913	et	3	main
seinad	doc_634572338226_item	3579914	et	3	main
essee	doc_634572338233_item	3579932	et	4	main
kus	doc_634572338233_item	3579943	et	3	main
pladitud	doc_634572338233_item	3579949	et	4	main
on	doc_634572338233_item	3579953	et	4	main
puust	doc_634572338233_item	3579955	et	4	main
laag	doc_634572338233_item	3579956	et	3	main
on	doc_634572338233_item	3579963	et	4	main
laag	doc_634572338233_item	3579969	et	3	main
lauda	doc_634572338233_item	3579977	et	4	main
seisavad	doc_634572338233_item	3579978	et	3	main
diivanid	doc_634572338233_item	3579979	et	3	main
vasakul	doc_634572338233_item	3579980	et	4	main
seinal	doc_634572338233_item	3579981	et	3	main
suurune	doc_634572338226_item	3579733	et	4	main
on	doc_634572338226_item	3579737	et	4	main
põrand	doc_634572338226_item	3579741	et	3	main
keldri	doc_634572338226_item	3579743	et	3	main
tehnilised	doc_634572338226_item	3579746	et	3	main
pea	doc_634572338226_item	3579749	et	4	main
suur	doc_634572338226_item	3579755	et	3	main
vannituba	doc_634572338226_item	3579758	et	4	main
askeldusest	doc_634572338226_item	3579768	et	4	main
linna	doc_634572338226_item	3579769	et	4	main
elust	doc_634572338226_item	3579770	et	3	main
looduse	doc_634572338226_item	3579773	et	4	main
enne	doc_634572338226_item	3579779	et	4	main
töö	doc_634572338226_item	3579780	et	4	main
alustamist	doc_634572338226_item	3579781	et	4	main
on	doc_634572338226_item	3579782	et	4	main
vaja	doc_634572338226_item	3579783	et	4	main
puhastada	doc_634572338226_item	3579784	et	3	main
keldri	doc_634572338226_item	3579785	et	3	main
edasi	doc_634572338226_item	3579786	et	3	main
on	doc_634572338226_item	3579787	et	4	main
vaja	doc_634572338226_item	3579788	et	4	main
paigaldada	doc_634572338226_item	3579789	et	3	main
uued	doc_634572338226_item	3579790	et	3	main
elektri	doc_634572338226_item	3579791	et	3	main
võrgud	doc_634572338226_item	3579792	et	3	main
sisustada	doc_634572338226_item	3579793	et	3	main
ventilatsiooni	doc_634572338226_item	3579794	et	4	main
tehakse	doc_634572338226_item	3579795	et	3	main
ja	doc_634572338226_item	3579797	et	3	main
kanalistsioon	doc_634572338226_item	3579796	et	4	main
vee	doc_634572338226_item	3579798	et	3	main
torud	doc_634572338226_item	3579799	et	3	main
vannitoa	doc_634572338226_item	3579800	et	3	main
elu	doc_634572338226_item	3579776	et	4	main
koopa	doc_634572338226_item	3579777	et	3	main
kujutis	doc_634572338226_item	3579778	et	3	main
seina	doc_634572338226_item	3579809	et	4	main
põranda	doc_634572338226_item	3579811	et	3	main
karkassi	doc_634572338226_item	3579815	et	4	main
pehmest	doc_634572338226_item	3579817	et	3	main
materjalidest	doc_634572338226_item	3579819	et	3	main
on	doc_634572338226_item	3579822	et	4	main
paigaldatud	doc_634572338226_item	3579823	et	4	main
töötlemise	doc_634572338226_item	3579832	et	4	main
vannituba	doc_634572338226_item	3579833	et	4	main
halli	doc_634572338226_item	3579841	et	4	main
plaadist	doc_634572338226_item	3579842	et	3	main
ja	doc_634572338226_item	3579850	et	3	main
seintel	doc_634572338226_item	3579851	et	3	main
esikus	doc_634572338226_item	3579852	et	3	main
on	doc_634572338226_item	3579853	et	4	main
valged	doc_634572338226_item	3579854	et	3	main
seinad	doc_634572338226_item	3579855	et	3	main
valged	doc_634572338226_item	3579857	et	3	main
valesvomis	doc_634572338226_item	3579870	et	4	main
vaheseinas	doc_634572338226_item	3579871	et	3	main
jagab	doc_634572338226_item	3579872	et	3	main
suure	doc_634572338226_item	3579873	et	3	main
toa	doc_634572338226_item	3579874	et	3	main
kinotuba	doc_634572338226_item	3579882	et	4	main
süsteemi	doc_634572338226_item	3579890	et	4	main
kaljudesse	doc_634572338226_item	3579891	et	3	main
seinad	doc_634572338226_item	3579892	et	3	main
kaetakse	doc_634572338226_item	3579893	et	4	main
dekoratiivse	doc_634572338226_item	3579894	et	3	main
puhke	doc_634572338226_item	3579897	et	4	main
tehtud	doc_634572338226_item	3579902	et	4	main
kivist	doc_634572338226_item	3579910	et	4	main
saunas	doc_634572338233_item	3579935	et	3	main
tuba	doc_634572338233_item	3579942	et	4	main
toas	doc_634572338233_item	3579947	et	3	main
seinad	doc_634572338233_item	3579952	et	3	main
seinad	doc_634572338233_item	3579967	et	3	main
see	doc_634572338244_item	3580036	et	3	main
inimesele	doc_634572338244_item	3580041	et	3	main
praktiliselt	doc_634572338244_item	3580046	et	4	main
inimesel	doc_634572338244_item	3580052	et	3	main
abil	doc_634572338244_item	3580067	et	4	main
oma	doc_634572338244_item	3580080	et	4	main
sest	doc_634572338244_item	3580087	et	4	main
kamber	doc_634572338244_item	3580092	et	3	main
abil	doc_634572338244_item	3580095	et	4	main
võib	doc_634572338244_item	3580096	et	3	main
suurused	doc_634572338244_item	3580103	et	4	main
on	doc_634572338244_item	3580109	et	4	main
temal	doc_634572338244_item	3580118	et	3	main
väheldase	doc_634572338244_item	3580121	et	3	main
hulk	doc_634572338244_item	3580123	et	3	main
on	doc_724355862916_item	3580140	et	4	main
sündinud	doc_724355862916_item	3580144	et	4	main
eestis	doc_724355862916_item	3580145	et	3	main
siin	doc_724355862916_item	3580148	et	4	main
koguaeg	doc_724355862916_item	3580149	et	3	main
aastat	doc_724355862916_item	3580154	et	3	main
ostutaksid	doc_724355862916_item	3580155	et	3	main
eesti	doc_724355862916_item	3580161	et	4	main
oli	doc_724355862916_item	3580168	et	3	main
1993	doc_724355862916_item	3580177	et	2	main
mahtra	doc_724355862916_item	3580181	et	4	main
tallinna	doc_724355862916_item	3580187	et	4	main
mahtra	doc_724355862916_item	3580188	et	4	main
pealt	doc_724355862916_item	3580201	et	4	main
vaja	doc_724355862916_item	3580234	et	4	main
kelle	doc_724355862916_item	3580237	et	4	main
on	doc_724355862916_item	3580239	et	4	main
tutvuja	doc_724355862916_item	3580254	et	4	main
sooviks	doc_724355862916_item	3580263	et	4	main
väga	doc_724355862916_item	3580281	et	3	main
ja	doc_724355862920_item	3580313	et	3	main
ülikool	doc_724355862920_item	3580314	et	4	main
väga	doc_724355862920_item	3580326	et	3	main
ole	doc_724355862920_item	3580353	et	4	main
õige	doc_724355862920_item	3580354	et	4	main
mul	doc_724355862920_item	3580355	et	3	main
raske	doc_724355862920_item	3580364	et	4	main
soendadus	doc_634572338226_item	3579807	et	4	main
isolatsiooniga	doc_634572338226_item	3579808	et	3	main
isoleeritakse	doc_634572338226_item	3579814	et	3	main
ja	doc_634572338226_item	3579816	et	3	main
aga	doc_634572338226_item	3579820	et	3	main
selle	doc_634572338226_item	3579827	et	4	main
koos	doc_634572338226_item	3579835	et	4	main
põrandal	doc_634572338226_item	3579844	et	3	main
valge	doc_634572338226_item	3579845	et	4	main
plaadid	doc_634572338226_item	3579858	et	4	main
põrandal	doc_634572338226_item	3579859	et	3	main
esikus	doc_634572338226_item	3579860	et	3	main
planeritakse	doc_634572338226_item	3579861	et	4	main
asendada	doc_634572338226_item	3579862	et	3	main
tumbat	doc_634572338226_item	3579863	et	3	main
ja	doc_634572338226_item	3579864	et	3	main
suure	doc_634572338226_item	3579865	et	3	main
kaheks	doc_634572338226_item	3579875	et	4	main
zooniks	doc_634572338226_item	3579876	et	3	main
vormitakse	doc_634572338226_item	3579883	et	4	main
koopa	doc_634572338226_item	3579884	et	3	main
välimuses	doc_634572338226_item	3579885	et	3	main
diivan	doc_634572338226_item	3579886	et	3	main
paigaldatakse	doc_634572338226_item	3579887	et	3	main
tühendusse	doc_634572338226_item	3579888	et	4	main
kõrval	doc_634572338226_item	3579906	et	4	main
kaks	doc_634572338226_item	3579907	et	3	main
kivist	doc_634572338226_item	3579926	et	4	main
seinad	doc_634572338226_item	3579927	et	3	main
varustatakse	doc_634572338226_item	3579928	et	3	main
peidetud	doc_634572338226_item	3579929	et	4	main
valgustajaga	doc_634572338226_item	3579930	et	4	main
minu	doc_634572338233_item	3579933	et	3	main
tuba	doc_634572338233_item	3579938	et	4	main
duši	doc_634572338233_item	3579939	et	2	main
ruum	doc_634572338233_item	3579940	et	3	main
ja	doc_634572338233_item	3579941	et	3	main
rietus	doc_634572338233_item	3579946	et	4	main
on	doc_634572338233_item	3579957	et	4	main
ka	doc_634572338233_item	3579958	et	3	main
ni	doc_634572338233_item	3579964	et	4	main
põrand	doc_634572338233_item	3579965	et	3	main
kui	doc_634572338233_item	3579966	et	3	main
on	doc_634572338233_item	3579970	et	4	main
saalis	doc_634572338233_item	3579972	et	4	main
on	doc_634572338233_item	3579973	et	4	main
suur	doc_634572338233_item	3579974	et	3	main
väga	doc_634572338244_item	3580038	et	3	main
tema	doc_634572338244_item	3580044	et	4	main
ei	doc_634572338244_item	3580047	et	4	main
ta	doc_634572338244_item	3580049	et	4	main
ta	doc_634572338244_item	3580053	et	4	main
ohutult	doc_634572338244_item	3580055	et	4	main
tekitab	doc_634572338244_item	3580056	et	3	main
probleemid	doc_634572338244_item	3580057	et	3	main
terviselt	doc_634572338244_item	3580058	et	3	main
ta	doc_634572338244_item	3580059	et	4	main
mis	doc_634572338244_item	3580071	et	4	main
peale	doc_634572338244_item	3580093	et	4	main
tema	doc_634572338244_item	3580094	et	4	main
erinevad	doc_634572338244_item	3580098	et	4	main
mugavalt	doc_634572338244_item	3580100	et	4	main
suur	doc_634572338244_item	3580107	et	3	main
samuti	doc_634572338244_item	3580119	et	3	main
ta	doc_634572338244_item	3580126	et	4	main
erinevad	doc_634572338244_item	3580128	et	4	main
mina	doc_724355862916_item	3580135	et	4	main
elan	doc_724355862916_item	3580147	et	3	main
kui	doc_724355862916_item	3580150	et	3	main
ei	doc_724355862916_item	3580165	et	4	main
keelde	doc_724355862916_item	3580172	et	4	main
aastal	doc_724355862916_item	3580178	et	3	main
soojustehnika	doc_724355862916_item	3580249	et	4	main
sest	doc_724355862916_item	3580250	et	4	main
et	doc_724355862916_item	3580251	et	3	main
üks	doc_724355862916_item	3580252	et	3	main
minu	doc_724355862916_item	3580253	et	3	main
on	doc_634572338226_item	3579834	et	4	main
tee	doc_634572338226_item	3579843	et	4	main
ja	doc_634572338226_item	3579856	et	3	main
ava	doc_634572338226_item	3579869	et	4	main
puhke	doc_634572338226_item	3579880	et	4	main
zooniks	doc_634572338226_item	3579881	et	3	main
ruumis	doc_634572338226_item	3579898	et	4	main
töötlevast	doc_634572338226_item	3579904	et	4	main
kivist	doc_634572338226_item	3579905	et	4	main
ka	doc_634572338226_item	3579915	et	3	main
dekoreritakse	doc_634572338226_item	3579916	et	4	main
faktuurse	doc_634572338226_item	3579917	et	4	main
krohvliga	doc_634572338226_item	3579918	et	4	main
voodi	doc_634572338226_item	3579919	et	4	main
vastas	doc_634572338226_item	3579920	et	4	main
seisab	doc_634572338226_item	3579921	et	3	main
plasma	doc_634572338226_item	3579922	et	4	main
telekas	doc_634572338226_item	3579923	et	4	main
töödeldud	doc_634572338226_item	3579924	et	4	main
metsikust	doc_634572338226_item	3579925	et	4	main
on	doc_634572338233_item	3580013	et	4	main
lillad	doc_634572338233_item	3580014	et	3	main
taapedid	doc_634572338233_item	3580015	et	4	main
laag	doc_634572338233_item	3580016	et	3	main
on	doc_634572338233_item	3580017	et	4	main
ka	doc_634572338233_item	3580018	et	3	main
malitud	doc_634572338233_item	3580019	et	4	main
lilla	doc_634572338233_item	3580020	et	4	main
värviga	doc_634572338233_item	3580021	et	4	main
magamis	doc_634572338233_item	3580022	et	4	main
toas	doc_634572338233_item	3580023	et	3	main
seisab	doc_634572338233_item	3580024	et	3	main
kahekohaline	doc_634572338233_item	3580025	et	4	main
vood	doc_634572338233_item	3580026	et	3	main
seinal	doc_634572338233_item	3580027	et	3	main
on	doc_634572338233_item	3580028	et	4	main
pildid	doc_634572338233_item	3580029	et	3	main
kus	doc_634572338233_item	3580030	et	3	main
on	doc_634572338233_item	3580031	et	4	main
jonistatud	doc_634572338233_item	3580032	et	4	main
loodus	doc_634572338233_item	3580033	et	4	main
kelder	doc_634572338233_item	3579934	et	3	main
on	doc_634572338233_item	3579936	et	4	main
rietus	doc_634572338233_item	3579937	et	4	main
basein	doc_634572338233_item	3579945	et	4	main
sojundusega	doc_634572338233_item	3579951	et	4	main
tehtud	doc_634572338233_item	3579959	et	4	main
puust	doc_634572338233_item	3579960	et	4	main
duši	doc_634572338233_item	3579961	et	2	main
pladitud	doc_634572338233_item	3579968	et	4	main
krohvitud	doc_634572338233_item	3579971	et	4	main
on	doc_634572338233_item	3579982	et	4	main
paigaldatud	doc_634572338233_item	3579983	et	4	main
teler	doc_634572338233_item	3579984	et	3	main
paremal	doc_634572338233_item	3579985	et	4	main
seinal	doc_634572338233_item	3579986	et	3	main
on	doc_634572338233_item	3579987	et	4	main
suur	doc_634572338233_item	3579988	et	3	main
vaip	doc_634572338233_item	3579989	et	3	main
keldris	doc_634572338233_item	3579991	et	3	main
põrandad	doc_634572338233_item	3579992	et	3	main
on	doc_634572338233_item	3579993	et	4	main
terves	doc_634572338233_item	3579990	et	4	main
tehtud	doc_634572338233_item	3579994	et	4	main
puust	doc_634572338233_item	3579995	et	4	main
koridooris	doc_634572338233_item	3579996	et	4	main
on	doc_634572338233_item	3579997	et	4	main
seinad	doc_634572338233_item	3579998	et	3	main
mis	doc_634572338233_item	3579999	et	4	main
tehtud	doc_634572338233_item	3580000	et	4	main
kivist	doc_634572338233_item	3580001	et	4	main
nagu	doc_634572338233_item	3580002	et	3	main
vanal	doc_634572338233_item	3580003	et	3	main
ajal	doc_634572338233_item	3580004	et	4	main
sama	doc_634572338233_item	3580005	et	4	main
sugused	doc_634572338233_item	3580006	et	3	main
seinad	doc_634572338233_item	3580007	et	3	main
on	doc_634572338233_item	3580008	et	4	main
ka	doc_634572338233_item	3580009	et	3	main
saalis	doc_634572338233_item	3580010	et	4	main
magamis	doc_634572338233_item	3580011	et	4	main
toas	doc_634572338233_item	3580012	et	3	main
asi	doc_634572338244_item	3580037	et	4	main
iga	doc_634572338244_item	3580040	et	4	main
meie	doc_634572338244_item	3580042	et	4	main
on	doc_634572338244_item	3580060	et	4	main
suhtleda	doc_634572338244_item	3580069	et	4	main
väga	doc_634572338244_item	3580072	et	3	main
samuti	doc_634572338244_item	3580074	et	3	main
tema	doc_634572338244_item	3580076	et	4	main
abil	doc_634572338244_item	3580077	et	4	main
kuulma	doc_634572338244_item	3580078	et	3	main
ilm	doc_634572338244_item	3580079	et	3	main
talgud	doc_634572338244_item	3580039	et	3	main
ilma	doc_634572338244_item	3580045	et	4	main
kohtle	doc_634572338244_item	3580048	et	4	main
igal	doc_634572338244_item	3580051	et	3	main
erineva	doc_634572338244_item	3580061	et	4	main
vorm	doc_634572338244_item	3580062	et	3	main
ovaalne	doc_634572338244_item	3580063	et	3	main
kvadraatne	doc_634572338244_item	3580064	et	3	main
ristkülikuline	doc_634572338244_item	3580065	et	4	main
tema	doc_634572338244_item	3580066	et	4	main
võib	doc_634572338244_item	3580068	et	3	main
horoskop	doc_634572338244_item	3580081	et	4	main
päev	doc_634572338244_item	3580082	et	3	main
peale	doc_634572338244_item	3580083	et	4	main
on	doc_634572338244_item	3580088	et	4	main
pildistada	doc_634572338244_item	3580090	et	3	main
kasutamisest	doc_634572338244_item	3580101	et	4	main
erinevad	doc_634572338244_item	3580102	et	4	main
taskuse	doc_634572338244_item	3580114	et	4	main
ta	doc_634572338244_item	3580115	et	4	main
värvid	doc_634572338244_item	3580129	et	4	main
55	doc_634572338244_item	3580130	et	2	main
555	doc_634572338244_item	3580131	et	2	main
55	doc_634572338244_item	3580132	et	2	main
võimalik	doc_634572338244_item	3580089	et	3	main
mängida	doc_634572338244_item	3580097	et	3	main
keskmine	doc_634572338244_item	3580105	et	3	main
hästi	doc_634572338244_item	3580110	et	3	main
paigutab	doc_634572338244_item	3580111	et	3	main
tegeb	doc_634572338244_item	3580116	et	4	main
on	doc_634572338244_item	3580120	et	4	main
ekraan	doc_634572338244_item	3580122	et	3	main
knopkad	doc_634572338244_item	3580124	et	3	main
essee	doc_724355862916_item	3580134	et	4	main
ja	doc_724355862916_item	3580136	et	3	main
ülikool	doc_724355862916_item	3580137	et	4	main
mini	doc_724355862916_item	3580138	et	4	main
nimi	doc_724355862916_item	3580139	et	3	main
mul	doc_724355862916_item	3580151	et	3	main
et	doc_724355862916_item	3580157	et	3	main
vene	doc_724355862916_item	3580169	et	4	main
see	doc_724355862916_item	3580174	et	3	main
soobi	doc_724355862916_item	3580176	et	3	main
tallinna	doc_724355862916_item	3580180	et	4	main
kool	doc_724355862916_item	3580183	et	4	main
pärast	doc_724355862916_item	3580184	et	4	main
nimetakse	doc_724355862916_item	3580185	et	3	main
aeg	doc_724355862916_item	3580190	et	3	main
kiiresti	doc_724355862916_item	3580192	et	3	main
praegu	doc_724355862916_item	3580193	et	3	main
eesti	doc_724355862916_item	3580195	et	4	main
keele	doc_724355862916_item	3580196	et	4	main
tunnis	doc_724355862916_item	3580197	et	3	main
ttü-s	doc_724355862916_item	3580198	et	3	main
tahan	doc_724355862916_item	3580199	et	3	main
kõige	doc_724355862916_item	3580200	et	4	main
tutvujad	doc_724355862916_item	3580295	et	4	main
sõbrad	doc_724355862916_item	3580296	et	3	main
loodan	doc_724355862916_item	3580297	et	3	main
et	doc_724355862916_item	3580298	et	3	main
saan	doc_724355862916_item	3580299	et	4	main
õppida	doc_724355862916_item	3580300	et	3	main
eesti	doc_724355862916_item	3580301	et	4	main
keelt	doc_724355862916_item	3580302	et	4	main
korralikult	doc_724355862916_item	3580303	et	4	main
ja	doc_724355862916_item	3580304	et	3	main
võin	doc_724355862916_item	3580305	et	3	main
lõpetada	doc_724355862916_item	3580306	et	3	main
hästi	doc_724355862916_item	3580307	et	3	main
see	doc_724355862916_item	3580308	et	3	main
ülikool	doc_724355862916_item	3580309	et	4	main
seitse	doc_724355862916_item	3580153	et	3	main
pean	doc_724355862916_item	3580159	et	4	main
õppima	doc_724355862916_item	3580160	et	3	main
koolis	doc_724355862916_item	3580162	et	4	main
aga	doc_724355862916_item	3580163	et	3	main
võimalusi	doc_724355862916_item	3580164	et	3	main
ja	doc_724355862916_item	3580170	et	3	main
koolidel	doc_724355862916_item	3580173	et	3	main
ei	doc_724355862916_item	3580175	et	4	main
ta	doc_724355862916_item	3580186	et	4	main
istun	doc_724355862916_item	3580194	et	3	main
kirjutada	doc_724355862916_item	3580202	et	3	main
et	doc_724355862916_item	3580203	et	3	main
loengutel	doc_724355862916_item	3580204	et	4	main
ma	doc_724355862916_item	3580205	et	3	main
tahan	doc_724355862916_item	3580206	et	3	main
oskada	doc_724355862916_item	3580207	et	4	main
rääkida	doc_724355862916_item	3580208	et	3	main
eesti	doc_724355862916_item	3580209	et	4	main
keelt	doc_724355862916_item	3580210	et	4	main
selle	doc_724355862916_item	3580211	et	4	main
pärast	doc_724355862916_item	3580212	et	4	main
arvan	doc_724355862916_item	3580213	et	3	main
et	doc_724355862916_item	3580214	et	3	main
see	doc_724355862916_item	3580215	et	3	main
on	doc_724355862916_item	3580216	et	4	main
kõige	doc_724355862916_item	3580217	et	4	main
tähtsam	doc_724355862916_item	3580218	et	4	main
ma	doc_724355862916_item	3580219	et	3	main
elan	doc_724355862916_item	3580220	et	3	main
eestis	doc_724355862916_item	3580221	et	3	main
riigis	doc_724355862916_item	3580222	et	3	main
kus	doc_724355862916_item	3580223	et	3	main
riigikeel	doc_724355862916_item	3580224	et	4	main
on	doc_724355862916_item	3580225	et	4	main
eesti	doc_724355862916_item	3580226	et	4	main
keel	doc_724355862916_item	3580227	et	4	main
iga	doc_724355862916_item	3580228	et	4	main
päev	doc_724355862916_item	3580229	et	3	main
igal	doc_724355862916_item	3580230	et	3	main
kohal	doc_724355862916_item	3580231	et	4	main
mul	doc_724355862916_item	3580232	et	3	main
on	doc_724355862916_item	3580233	et	4	main
suhelda	doc_724355862916_item	3580235	et	4	main
lõpetas	doc_724355862916_item	3580257	et	3	main
mul	doc_724355862916_item	3580264	et	3	main
õppida	doc_724355862916_item	3580265	et	3	main
raske	doc_724355862916_item	3580282	et	4	main
kool	doc_724355862920_item	3580319	et	4	main
läksin	doc_724355862920_item	3580330	et	3	main
inimestel	doc_724355862916_item	3580236	et	3	main
eesti	doc_724355862916_item	3580240	et	4	main
keel	doc_724355862916_item	3580241	et	4	main
võin	doc_724355862916_item	3580242	et	3	main
täpselt	doc_724355862916_item	3580243	et	4	main
öelda	doc_724355862916_item	3580244	et	4	main
ma	doc_724355862916_item	3580245	et	3	main
valiksin	doc_724355862916_item	3580246	et	3	main
selles	doc_724355862916_item	3580255	et	4	main
aastas	doc_724355862916_item	3580256	et	3	main
ülikool	doc_724355862916_item	3580259	et	4	main
samasuguses	doc_724355862916_item	3580260	et	3	main
erialal	doc_724355862916_item	3580261	et	3	main
ta	doc_724355862916_item	3580262	et	4	main
siin	doc_724355862916_item	3580266	et	4	main
kohal	doc_724355862916_item	3580268	et	4	main
otsisid	doc_724355862916_item	3580284	et	4	main
midagi	doc_724355862916_item	3580285	et	4	main
jooksisid	doc_724355862916_item	3580286	et	3	main
kuskilt	doc_724355862916_item	3580287	et	4	main
mind	doc_724355862916_item	3580288	et	4	main
see	doc_724355862916_item	3580289	et	3	main
ei	doc_724355862916_item	3580290	et	4	main
meeldi	doc_724355862916_item	3580291	et	4	main
praegu	doc_724355862916_item	3580292	et	3	main
leian	doc_724355862916_item	3580293	et	3	main
uued	doc_724355862916_item	3580294	et	3	main
essee	doc_724355862920_item	3580311	et	4	main
lasnamäe	doc_724355862920_item	3580323	et	3	main
gümnasium	doc_724355862920_item	3580324	et	4	main
lõpetan	doc_724355862920_item	3580325	et	3	main
mõtlen	doc_724355862920_item	3580329	et	3	main
oli	doc_724355862920_item	3580344	et	3	main
juulis	doc_724355862920_item	3580345	et	3	main
ja	doc_724355862920_item	3580346	et	3	main
ma	doc_724355862920_item	3580347	et	3	main
see	doc_724355862920_item	3580350	et	3	main
käheteistkümne	doc_724355862920_item	3580357	et	4	main
siis	doc_724355862920_item	3580366	et	3	main
sõbrad	doc_724355862920_item	3580368	et	3	main
ja	doc_724355862920_item	3580376	et	3	main
ma	doc_724355862920_item	3580377	et	3	main
saan	doc_724355862920_item	3580378	et	4	main
dokumente	doc_724355862920_item	3580379	et	3	main
vastuvõtt	doc_724355862920_item	3580380	et	3	main
tahan	doc_724355862920_item	3580393	et	3	main
tallinna	doc_724355862920_item	3580396	et	4	main
vene	doc_724355862920_item	3580428	et	4	main
sest	doc_724355862920_item	3580438	et	4	main
ülikooli	doc_724355862920_item	3580448	et	4	main
väga	doc_724355862920_item	3580450	et	3	main
muugav	doc_724355862920_item	3580451	et	4	main
seal	doc_724355862920_item	3580452	et	4	main
a	doc_724355862923_item	3580492	et	4	main
v	doc_724355862923_item	3580493	et	4	main
gümnaasiumis	doc_724355862923_item	3580510	et	3	main
sellel	doc_724355862923_item	3580511	et	4	main
lõpetasin	doc_724355862923_item	3580514	et	3	main
ja	doc_724355862923_item	3580516	et	3	main
ttüs	doc_724355862923_item	3580518	et	4	main
peale	doc_724355862923_item	3580519	et	4	main
seda	doc_724355862923_item	3580520	et	3	main
ma	doc_724355862923_item	3580521	et	3	main
tegelen	doc_724355862923_item	3580522	et	3	main
spordiga	doc_724355862923_item	3580523	et	3	main
mängin	doc_724355862923_item	3580524	et	3	main
tennist	doc_724355862923_item	3580525	et	3	main
eriala	doc_724355862923_item	3580540	et	4	main
tööstus	doc_724355862923_item	3580542	et	3	main
seda	doc_724355862923_item	3580547	et	3	main
muljed	doc_724355862923_item	3580581	et	3	main
see	doc_724355862916_item	3580269	et	3	main
tutvuja	doc_724355862916_item	3580270	et	4	main
juba	doc_724355862916_item	3580271	et	3	main
töötab	doc_724355862916_item	3580272	et	3	main
ja	doc_724355862916_item	3580273	et	3	main
saab	doc_724355862916_item	3580274	et	3	main
normaalne	doc_724355862916_item	3580275	et	3	main
palk	doc_724355862916_item	3580276	et	3	main
esimene	doc_724355862916_item	3580277	et	3	main
päev	doc_724355862916_item	3580278	et	3	main
ttü-l	doc_724355862916_item	3580279	et	3	main
oli	doc_724355862916_item	3580280	et	3	main
kõik	doc_724355862916_item	3580283	et	4	main
mina	doc_724355862920_item	3580312	et	4	main
sellel	doc_724355862920_item	3580315	et	4	main
aastal	doc_724355862920_item	3580316	et	3	main
lõpetan	doc_724355862920_item	3580318	et	3	main
paha	doc_724355862920_item	3580327	et	4	main
tööle	doc_724355862920_item	3580331	et	3	main
mõtlen	doc_724355862920_item	3580333	et	3	main
see	doc_724355862920_item	3580335	et	3	main
ilus	doc_724355862920_item	3580337	et	4	main
muugav	doc_724355862920_item	3580338	et	4	main
huvitav	doc_724355862920_item	3580339	et	4	main
vaatasin	doc_724355862920_item	3580348	et	3	main
on	doc_724355862920_item	3580351	et	4	main
ei	doc_724355862920_item	3580352	et	4	main
aastani	doc_724355862920_item	3580358	et	3	main
ja	doc_724355862920_item	3580359	et	3	main
juba	doc_724355862920_item	3580360	et	3	main
ma	doc_724355862920_item	3580361	et	3	main
tahan	doc_724355862920_item	3580362	et	3	main
ainult	doc_724355862920_item	3580363	et	4	main
ole	doc_724355862920_item	3580374	et	4	main
jarigmesel	doc_724355862920_item	3580383	et	4	main
nädal	doc_724355862920_item	3580384	et	3	main
leidsin	doc_724355862920_item	3580385	et	3	main
mis	doc_724355862920_item	3580391	et	4	main
müüjage	doc_724355862920_item	3580433	et	4	main
teha	doc_724355862920_item	3580434	et	3	main
õppida	doc_724355862920_item	3580435	et	3	main
me	doc_724355862920_item	3580439	et	4	main
huvitav	doc_724355862920_item	3580453	et	4	main
haridus	doc_724355862920_item	3580475	et	3	main
olla	doc_724355862920_item	3580477	et	3	main
essee	doc_724355862923_item	3580481	et	4	main
ja	doc_724355862923_item	3580483	et	3	main
ülikool	doc_724355862923_item	3580484	et	4	main
minu	doc_724355862923_item	3580485	et	3	main
nimi	doc_724355862923_item	3580486	et	3	main
on	doc_724355862923_item	3580490	et	4	main
klassi	doc_724355862923_item	3580504	et	4	main
1993	doc_724355862923_item	3580505	et	2	main
aastal	doc_724355862923_item	3580506	et	3	main
vene	doc_724355862923_item	3580509	et	4	main
aastal	doc_724355862923_item	3580512	et	3	main
kooli	doc_724355862923_item	3580515	et	4	main
on	doc_724355862923_item	3580541	et	4	main
tsivil	doc_724355862923_item	3580544	et	4	main
ttüst	doc_724355862923_item	3580582	et	4	main
väga	doc_724355862923_item	3580584	et	3	main
sõbralik	doc_724355862923_item	3580586	et	3	main
lektorid	doc_724355862923_item	3580587	et	3	main
aitavad	doc_724355862923_item	3580588	et	4	main
kui	doc_724355862923_item	3580589	et	3	main
ma	doc_724355862923_item	3580590	et	3	main
midagi	doc_724355862923_item	3580591	et	4	main
ei	doc_724355862923_item	3580592	et	4	main
saa	doc_724355862923_item	3580593	et	4	main
ma	doc_724355862920_item	3580317	et	3	main
mis	doc_724355862920_item	3580320	et	4	main
nimi	doc_724355862920_item	3580321	et	3	main
oli	doc_724355862920_item	3580322	et	3	main
mina	doc_724355862920_item	3580328	et	4	main
ja	doc_724355862920_item	3580332	et	3	main
et	doc_724355862920_item	3580334	et	3	main
elu	doc_724355862920_item	3580340	et	4	main
ja	doc_724355862920_item	3580341	et	3	main
nüüd	doc_724355862920_item	3580342	et	4	main
tänaval	doc_724355862920_item	3580343	et	4	main
et	doc_724355862920_item	3580349	et	3	main
on	doc_724355862920_item	3580356	et	4	main
töötada	doc_724355862920_item	3580365	et	3	main
ütle	doc_724355862920_item	3580369	et	4	main
et	doc_724355862920_item	3580371	et	3	main
kõik	doc_724355862920_item	3580372	et	4	main
ei	doc_724355862920_item	3580373	et	4	main
ülikooli	doc_724355862920_item	3580382	et	4	main
õpida	doc_724355862920_item	3580394	et	4	main
näen	doc_724355862920_item	3580395	et	3	main
tehnika	doc_724355862920_item	3580397	et	4	main
ülikooli	doc_724355862920_item	3580398	et	4	main
ja	doc_724355862920_item	3580399	et	3	main
arvan	doc_724355862920_item	3580400	et	3	main
et	doc_724355862920_item	3580401	et	3	main
bakalauris	doc_724355862920_item	3580402	et	4	main
mehanikale	doc_724355862920_item	3580403	et	4	main
on	doc_724355862920_item	3580404	et	4	main
huvitab	doc_724355862920_item	3580405	et	3	main
tuleb	doc_724355862920_item	3580406	et	3	main
august	doc_724355862920_item	3580407	et	4	main
ja	doc_724355862920_item	3580408	et	3	main
mille	doc_724355862920_item	3580409	et	3	main
helistab	doc_724355862920_item	3580410	et	3	main
elame	doc_724355862920_item	3580440	et	3	main
eesti	doc_724355862920_item	3580443	et	4	main
jäin	doc_724355862920_item	3580445	et	3	main
autorium	doc_724355862920_item	3580454	et	4	main
millal	doc_724355862920_item	3580455	et	3	main
tähtsam	doc_724355862920_item	3580473	et	4	main
võib	doc_724355862920_item	3580476	et	3	main
on	doc_724355862923_item	3580487	et	4	main
eesnimi	doc_724355862923_item	3580488	et	3	main
õpisin	doc_724355862923_item	3580507	et	4	main
kui	doc_724355862923_item	3580526	et	3	main
aeg	doc_724355862923_item	3580530	et	3	main
ja	doc_724355862923_item	3580543	et	3	main
keele	doc_724355862923_item	3580599	et	4	main
mina	doc_802069853714_item	3580606	et	4	main
olen	doc_802069853714_item	3580607	et	3	main
kes	doc_802069853714_item	3580611	et	4	main
sel	doc_802069853714_item	3580612	et	3	main
aast	doc_802069853714_item	3580613	et	4	main
lõpetas	doc_802069853714_item	3580614	et	3	main
õnnelik	doc_802069853714_item	3580621	et	3	main
ma	doc_802069853714_item	3580630	et	3	main
nüüd	doc_802069853714_item	3580634	et	4	main
ja	doc_802069853714_item	3580639	et	3	main
huvitav	doc_802069853714_item	3580641	et	4	main
on	doc_802069853714_item	3580642	et	4	main
tahtnud	doc_802069853714_item	3580648	et	4	main
saada	doc_802069853714_item	3580650	et	4	main
aga	doc_802069853714_item	3580651	et	3	main
erinevaid	doc_802069853714_item	3580660	et	4	main
ülikooli	doc_802069853714_item	3580666	et	4	main
kus	doc_802069853714_item	3580667	et	3	main
just	doc_802069853714_item	3580670	et	3	main
mida	doc_802069853714_item	3580672	et	4	main
on	doc_724355862920_item	3580336	et	4	main
hea	doc_724355862920_item	3580381	et	4	main
mis	doc_724355862920_item	3580387	et	4	main
mulle	doc_724355862920_item	3580388	et	4	main
meeldib	doc_724355862920_item	3580389	et	3	main
ja	doc_724355862920_item	3580390	et	3	main
oli	doc_724355862920_item	3580427	et	3	main
rühmas	doc_724355862920_item	3580429	et	4	main
ja	doc_724355862920_item	3580430	et	3	main
saan	doc_724355862920_item	3580431	et	4	main
proovida	doc_724355862920_item	3580432	et	3	main
kus	doc_724355862920_item	3580442	et	3	main
keel	doc_724355862920_item	3580444	et	4	main
väga	doc_724355862920_item	3580446	et	3	main
hoone	doc_724355862920_item	3580449	et	4	main
minule	doc_724355862920_item	3580479	et	3	main
minu	doc_724355862920_item	3580367	et	3	main
mulle	doc_724355862920_item	3580370	et	4	main
paha	doc_724355862920_item	3580375	et	4	main
ülikooli	doc_724355862920_item	3580386	et	4	main
ma	doc_724355862920_item	3580392	et	3	main
ütleb	doc_724355862920_item	3580411	et	3	main
kus	doc_724355862920_item	3580412	et	3	main
oli	doc_724355862920_item	3580413	et	3	main
selgeks	doc_724355862920_item	3580414	et	3	main
et	doc_724355862920_item	3580415	et	3	main
ma	doc_724355862920_item	3580416	et	3	main
võin	doc_724355862920_item	3580417	et	3	main
õpitada	doc_724355862920_item	3580418	et	4	main
tehnika	doc_724355862920_item	3580420	et	4	main
tallinna	doc_724355862920_item	3580419	et	4	main
ülikooli	doc_724355862920_item	3580421	et	4	main
tasuta	doc_724355862920_item	3580422	et	4	main
mulle	doc_724355862920_item	3580423	et	4	main
meeldib	doc_724355862920_item	3580424	et	3	main
et	doc_724355862920_item	3580425	et	3	main
mina	doc_724355862920_item	3580426	et	4	main
eesti	doc_724355862920_item	3580436	et	4	main
keel	doc_724355862920_item	3580437	et	4	main
eestis	doc_724355862920_item	3580441	et	3	main
tähtsam	doc_724355862920_item	3580447	et	4	main
ma	doc_724355862920_item	3580456	et	3	main
ei	doc_724355862920_item	3580457	et	4	main
näe	doc_724355862920_item	3580458	et	4	main
varem	doc_724355862920_item	3580459	et	4	main
tahan	doc_724355862920_item	3580460	et	3	main
seal	doc_724355862920_item	3580461	et	4	main
õpida	doc_724355862920_item	3580462	et	4	main
ja	doc_724355862920_item	3580463	et	3	main
mõtlen	doc_724355862920_item	3580464	et	3	main
et	doc_724355862920_item	3580465	et	3	main
sain	doc_724355862920_item	3580466	et	3	main
lõpetada	doc_724355862920_item	3580467	et	3	main
bakalaurisse	doc_724355862920_item	3580468	et	4	main
võin	doc_724355862920_item	3580469	et	3	main
tänan	doc_724355862920_item	3580470	et	3	main
on	doc_724355862920_item	3580471	et	4	main
kõige	doc_724355862920_item	3580472	et	4	main
kõrk	doc_724355862920_item	3580474	et	3	main
ainult	doc_724355862920_item	3580478	et	4	main
mul	doc_724355862923_item	3580489	et	3	main
olin	doc_724355862923_item	3580495	et	3	main
haabersti	doc_724355862923_item	3580508	et	4	main
ma	doc_724355862923_item	3580513	et	3	main
astusin	doc_724355862923_item	3580517	et	3	main
on	doc_724355862923_item	3580528	et	4	main
siis	doc_724355862923_item	3580531	et	3	main
veedan	doc_724355862923_item	3580533	et	3	main
seda	doc_724355862923_item	3580534	et	3	main
valisin	doc_724355862923_item	3580546	et	3	main
eesi	doc_724355862923_item	3580598	et	4	main
ülikool	doc_802069853714_item	3580605	et	4	main
ülikooli	doc_802069853714_item	3580618	et	4	main
olen	doc_802069853714_item	3580619	et	3	main
sel	doc_802069853714_item	3580628	et	3	main
saan	doc_802069853714_item	3580635	et	4	main
raske	doc_802069853714_item	3580638	et	4	main
see	doc_802069853714_item	3580643	et	3	main
eriala	doc_802069853714_item	3580644	et	4	main
olen	doc_802069853714_item	3580645	et	3	main
kunagi	doc_802069853714_item	3580646	et	3	main
kõige	doc_802069853714_item	3580656	et	4	main
rohkem	doc_802069853714_item	3580657	et	4	main
maailmas	doc_802069853714_item	3580658	et	3	main
tahan	doc_802069853714_item	3580659	et	3	main
sisseastumist	doc_802069853714_item	3580676	et	3	main
sellest	doc_802069853714_item	3580678	et	4	main
hakkab	doc_802069853714_item	3580690	et	3	main
täitsa	doc_802069853714_item	3580692	et	3	main
meeldima	doc_802069853714_item	3580693	et	3	main
tudengielu	doc_802069853714_item	3580694	et	4	main
kuna	doc_802069853714_item	3580697	et	3	main
on	doc_802069853714_item	3580700	et	4	main
rasked	doc_802069853714_item	3580701	et	3	main
saan	doc_802069853714_item	3580704	et	4	main
kui	doc_802069853714_item	3580706	et	3	main
et	doc_802069853714_item	3580713	et	3	main
esimesest	doc_802069853714_item	3580717	et	3	main
ülikool	doc_802069853725_item	3580744	et	4	main
vene	doc_802069853725_item	3580755	et	4	main
gümnaasium	doc_802069853725_item	3580756	et	3	main
seda	doc_802069853725_item	3580760	et	3	main
käisin	doc_802069853725_item	3580762	et	3	main
eesti	doc_802069853725_item	3580772	et	4	main
ja	doc_802069853725_item	3580775	et	3	main
ma	doc_802069853725_item	3580776	et	3	main
vaja	doc_802069853725_item	3580791	et	4	main
sest	doc_802069853725_item	3580793	et	4	main
ttüst	doc_802069853725_item	3580796	et	4	main
arvuti	doc_802069853725_item	3580797	et	4	main
on	doc_802069853725_item	3580842	et	4	main
sellel	doc_802069853726_item	3580861	et	4	main
mina	doc_802069853726_item	3580863	et	4	main
54	doc_802069853726_item	3580866	et	2	main
keskkool	doc_802069853726_item	3580867	et	4	main
pärast	doc_802069853726_item	3580868	et	4	main
ma	doc_802069853726_item	3580869	et	3	main
mõtlen	doc_802069853726_item	3580870	et	3	main
kuhu	doc_802069853726_item	3580871	et	3	main
tulin	doc_802069853726_item	3580872	et	3	main
elus	doc_802069853726_item	3580910	et	4	main
kõrg	doc_802069853726_item	3580924	et	4	main
haridus	doc_802069853726_item	3580925	et	3	main
töötasin	doc_802069853726_item	3580931	et	3	main
abivad	doc_802069853726_item	3580954	et	4	main
õpetajad	doc_802069853726_item	3580955	et	4	main
ootan	doc_802069853726_item	3580977	et	3	main
keele	doc_802069853726_item	3580979	et	4	main
ma	doc_802069853726_item	3580984	et	3	main
ma	doc_802069853726_item	3580988	et	3	main
eestis	doc_802069853726_item	3580992	et	3	main
leian	doc_802069853726_item	3580995	et	3	main
ja	doc_802069853726_item	3580997	et	3	main
seal	doc_802069853726_item	3580998	et	4	main
mulle	doc_802069853726_item	3580999	et	4	main
mina	doc_802069853733_item	3581004	et	4	main
on	doc_802069853733_item	3581009	et	4	main
põlju	doc_802069853733_item	3581023	et	4	main
võivad	doc_802069853733_item	3581027	et	4	main
aja	doc_802069853733_item	3581044	et	4	main
endale	doc_724355862923_item	3580562	et	4	main
tööt	doc_724355862923_item	3580563	et	4	main
ttu	doc_724355862923_item	3580564	et	4	main
ma	doc_724355862923_item	3580565	et	3	main
tean	doc_724355862923_item	3580566	et	3	main
väga	doc_724355862923_item	3580567	et	3	main
ammu	doc_724355862923_item	3580568	et	4	main
minu	doc_724355862923_item	3580569	et	3	main
ema	doc_724355862923_item	3580570	et	4	main
veel	doc_724355862923_item	3580571	et	4	main
lõpetas	doc_724355862923_item	3580572	et	3	main
seda	doc_724355862923_item	3580573	et	3	main
ülikooli	doc_724355862923_item	3580574	et	4	main
mõned	doc_724355862923_item	3580575	et	3	main
sõbrad	doc_724355862923_item	3580576	et	3	main
õpivad	doc_724355862923_item	3580577	et	3	main
ka	doc_724355862923_item	3580578	et	3	main
siin	doc_724355862923_item	3580579	et	4	main
minu	doc_724355862923_item	3580580	et	3	main
mina	doc_724355862923_item	3580482	et	4	main
19	doc_724355862923_item	3580491	et	2	main
ma	doc_724355862923_item	3580494	et	3	main
sündinud	doc_724355862923_item	3580496	et	4	main
eesti	doc_724355862923_item	3580497	et	4	main
vabariigis	doc_724355862923_item	3580498	et	3	main
aga	doc_724355862923_item	3580499	et	3	main
olen	doc_724355862923_item	3580500	et	3	main
venelane	doc_724355862923_item	3580501	et	3	main
astusin	doc_724355862923_item	3580502	et	3	main
1-sse	doc_724355862923_item	3580503	et	3	main
mul	doc_724355862923_item	3580527	et	3	main
vaba	doc_724355862923_item	3580529	et	4	main
ma	doc_724355862923_item	3580532	et	3	main
aja	doc_724355862923_item	3580535	et	4	main
kodus	doc_724355862923_item	3580536	et	4	main
oma	doc_724355862923_item	3580537	et	4	main
sõpradega	doc_724355862923_item	3580538	et	3	main
minu	doc_724355862923_item	3580539	et	3	main
ehitus	doc_724355862923_item	3580545	et	4	main
eriala	doc_724355862923_item	3580548	et	4	main
sellepärast	doc_724355862923_item	3580549	et	3	main
et	doc_724355862923_item	3580550	et	3	main
ehitus	doc_724355862923_item	3580551	et	4	main
on	doc_724355862923_item	3580552	et	4	main
alati	doc_724355862923_item	3580553	et	4	main
aktuaalne	doc_724355862923_item	3580554	et	3	main
arvan	doc_724355862923_item	3580555	et	3	main
et	doc_724355862923_item	3580556	et	3	main
saan	doc_724355862923_item	3580557	et	4	main
pärast	doc_724355862923_item	3580558	et	4	main
ülikooli	doc_724355862923_item	3580559	et	4	main
lõpetamist	doc_724355862923_item	3580560	et	4	main
leida	doc_724355862923_item	3580561	et	3	main
parandamist	doc_724355862923_item	3580600	et	4	main
mina	doc_802069853714_item	3580603	et	4	main
tavaline	doc_802069853714_item	3580609	et	4	main
päris	doc_802069853714_item	3580620	et	4	main
aastal	doc_802069853714_item	3580629	et	3	main
õppima	doc_802069853714_item	3580632	et	3	main
kui	doc_802069853714_item	3580637	et	3	main
algkoolis	doc_802069853714_item	3580647	et	4	main
arstiks	doc_802069853714_item	3580649	et	4	main
ma	doc_802069853714_item	3580673	et	3	main
tahan	doc_802069853714_item	3580674	et	3	main
enne	doc_802069853714_item	3580675	et	4	main
kui	doc_802069853714_item	3580686	et	3	main
ja	doc_802069853714_item	3580695	et	3	main
õppimisprotsess	doc_802069853714_item	3580696	et	3	main
ained	doc_802069853714_item	3580699	et	3	main
on	doc_724355862923_item	3580583	et	4	main
head	doc_724355862923_item	3580585	et	4	main
loengutelt	doc_724355862923_item	3580595	et	4	main
ma	doc_724355862923_item	3580596	et	3	main
ootan	doc_724355862923_item	3580597	et	3	main
aru	doc_724355862923_item	3580594	et	4	main
essee	doc_802069853714_item	3580602	et	4	main
inimene	doc_802069853714_item	3580610	et	3	main
kooli	doc_802069853714_item	3580615	et	4	main
ja	doc_802069853714_item	3580616	et	3	main
astus	doc_802069853714_item	3580617	et	3	main
täitis	doc_802069853714_item	3580627	et	3	main
inseneriks	doc_802069853714_item	3580633	et	3	main
güümnaasiumis	doc_802069853714_item	3580652	et	4	main
sain	doc_802069853714_item	3580653	et	3	main
hoone	doc_802069853714_item	3580661	et	4	main
projekteerida	doc_802069853714_item	3580662	et	3	main
seepärast	doc_802069853714_item	3580663	et	3	main
valisingi	doc_802069853714_item	3580664	et	3	main
saab	doc_802069853714_item	3580668	et	3	main
seda	doc_802069853714_item	3580671	et	3	main
kuulnud	doc_802069853714_item	3580684	et	4	main
nüüd	doc_802069853714_item	3580685	et	4	main
õpin	doc_802069853714_item	3580688	et	3	main
loodan	doc_802069853714_item	3580702	et	3	main
keelest	doc_802069853714_item	3580709	et	4	main
saan	doc_802069853714_item	3580711	et	4	main
õppinud	doc_802069853714_item	3580715	et	4	main
klassist	doc_802069853714_item	3580718	et	3	main
essee	doc_802069853725_item	3580741	et	4	main
ja	doc_802069853725_item	3580743	et	3	main
on	doc_802069853725_item	3580748	et	4	main
lenusin	doc_802069853725_item	3580752	et	4	main
kolist	doc_802069853725_item	3580753	et	4	main
pärist	doc_802069853725_item	3580759	et	3	main
erialast	doc_802069853725_item	3580767	et	4	main
natukene	doc_802069853725_item	3580778	et	4	main
tunne	doc_802069853725_item	3580843	et	4	main
et	doc_802069853725_item	3580844	et	3	main
ei	doc_802069853725_item	3580846	et	4	main
tegi	doc_802069853725_item	3580847	et	4	main
essee	doc_802069853726_item	3580857	et	4	main
aastal	doc_802069853726_item	3580862	et	3	main
lõpetasin	doc_802069853726_item	3580864	et	3	main
et	doc_802069853726_item	3580894	et	3	main
seal	doc_802069853726_item	3580895	et	4	main
hea	doc_802069853726_item	3580897	et	4	main
haridus	doc_802069853726_item	3580898	et	3	main
ja	doc_802069853726_item	3580899	et	3	main
lõpetada	doc_802069853726_item	3580904	et	3	main
mina	doc_802069853726_item	3580912	et	4	main
kvalitetsid	doc_802069853726_item	3580920	et	4	main
kadrid	doc_802069853726_item	3580921	et	3	main
mehanika	doc_802069853726_item	3580928	et	4	main
autodega	doc_802069853726_item	3580932	et	3	main
autoremondid	doc_802069853726_item	3580941	et	3	main
mulje	doc_802069853726_item	3580948	et	4	main
ja	doc_802069853726_item	3580956	et	3	main
kõrgharidus	doc_802069853726_item	3580975	et	3	main
praktika	doc_802069853726_item	3580983	et	4	main
et	doc_802069853726_item	3580986	et	3	main
ma	doc_802069853726_item	3580993	et	3	main
palju	doc_802069853714_item	3580681	et	4	main
häid	doc_802069853714_item	3580682	et	3	main
ja	doc_802069853714_item	3580604	et	3	main
täitsa	doc_802069853714_item	3580608	et	3	main
sest	doc_802069853714_item	3580622	et	4	main
juba	doc_802069853714_item	3580623	et	3	main
üks	doc_802069853714_item	3580624	et	3	main
minu	doc_802069853714_item	3580625	et	3	main
unistusest	doc_802069853714_item	3580626	et	4	main
hakkan	doc_802069853714_item	3580631	et	3	main
aru	doc_802069853714_item	3580636	et	4	main
kui	doc_802069853714_item	3580640	et	3	main
aru	doc_802069853714_item	3580654	et	4	main
et	doc_802069853714_item	3580655	et	3	main
ttü	doc_802069853714_item	3580665	et	4	main
õppida	doc_802069853714_item	3580669	et	3	main
ülikoolist	doc_802069853714_item	3580679	et	4	main
päris	doc_802069853714_item	3580680	et	4	main
mõned	doc_802069853714_item	3580698	et	3	main
hakkama	doc_802069853714_item	3580705	et	3	main
rääkida	doc_802069853714_item	3580707	et	3	main
eesti	doc_802069853714_item	3580708	et	4	main
siis	doc_802069853714_item	3580710	et	3	main
seda	doc_802069853714_item	3580716	et	3	main
ja	doc_802069853714_item	3580719	et	3	main
olen	doc_802069853714_item	3580677	et	3	main
asju	doc_802069853714_item	3580683	et	3	main
juba	doc_802069853714_item	3580687	et	3	main
siin	doc_802069853714_item	3580689	et	4	main
mulle	doc_802069853714_item	3580691	et	4	main
et	doc_802069853714_item	3580703	et	3	main
olen	doc_802069853714_item	3580714	et	3	main
tere	doc_802069853725_item	3580745	et	3	main
eesnimi	doc_802069853725_item	3580749	et	3	main
ma	doc_802069853725_item	3580751	et	3	main
2000	doc_802069853725_item	3580757	et	2	main
polütehnikumist	doc_802069853725_item	3580765	et	4	main
infotehnologia	doc_802069853725_item	3580766	et	4	main
keele	doc_802069853725_item	3580773	et	4	main
õpetaja	doc_802069853725_item	3580774	et	4	main
õppisin	doc_802069853725_item	3580777	et	3	main
eesti	doc_802069853725_item	3580779	et	4	main
2003	doc_802069853725_item	3580781	et	2	main
lõpetasin	doc_802069853725_item	3580784	et	3	main
polütehnikum	doc_802069853725_item	3580785	et	3	main
ja	doc_802069853725_item	3580786	et	3	main
lahen	doc_802069853725_item	3580787	et	4	main
toosel	doc_802069853725_item	3580788	et	3	main
mul	doc_802069853725_item	3580789	et	3	main
on	doc_802069853725_item	3580790	et	4	main
mull	doc_802069853725_item	3580841	et	3	main
ma	doc_802069853725_item	3580845	et	3	main
ülikool	doc_802069853726_item	3580860	et	4	main
mina	doc_802069853726_item	3580873	et	4	main
annan	doc_802069853726_item	3580874	et	3	main
annab	doc_802069853726_item	3580896	et	3	main
töö	doc_802069853726_item	3580900	et	4	main
kogemus	doc_802069853726_item	3580901	et	3	main
tahan	doc_802069853726_item	3580903	et	3	main
suvil	doc_802069853726_item	3580911	et	4	main
problem	doc_802069853726_item	3580916	et	4	main
oli	doc_802069853726_item	3580917	et	3	main
pole	doc_802069853726_item	3580919	et	3	main
see	doc_802069853726_item	3580934	et	3	main
mulle	doc_802069853726_item	3580936	et	4	main
meile	doc_802069853726_item	3580953	et	4	main
saada	doc_802069853726_item	3580974	et	4	main
tean	doc_802069853726_item	3580985	et	3	main
kui	doc_802069853726_item	3580987	et	3	main
ei	doc_802069853726_item	3580989	et	4	main
rigikeel	doc_802069853726_item	3580991	et	4	main
minu	doc_802069853733_item	3581007	et	3	main
ma	doc_802069853733_item	3581011	et	3	main
pärit	doc_802069853733_item	3581013	et	3	main
oma	doc_802069853733_item	3581015	et	4	main
lapsepõlva	doc_802069853733_item	3581016	et	4	main
veedan	doc_802069853733_item	3581018	et	3	main
kus	doc_802069853733_item	3581020	et	3	main
mul	doc_802069853733_item	3581021	et	3	main
on	doc_802069853733_item	3581022	et	4	main
nad	doc_802069853733_item	3581026	et	3	main
breakdanceiga	doc_802069853733_item	3581049	et	4	main
ma	doc_802069853733_item	3581050	et	3	main
olen	doc_802069853733_item	3581051	et	3	main
juba	doc_802069853733_item	3581052	et	3	main
ei	doc_802069853733_item	3581059	et	4	main
sellepärast	doc_802069853733_item	3581063	et	3	main
autode	doc_802069853733_item	3581072	et	3	main
sõlmides	doc_802069853733_item	3581087	et	4	main
mul	doc_802069853733_item	3581088	et	3	main
erineb	doc_802069853733_item	3581099	et	3	main
keel	doc_802069853733_item	3581128	et	4	main
olen	doc_802069853733_item	3581132	et	3	main
see	doc_802069853733_item	3581135	et	3	main
suure	doc_802069853733_item	3581147	et	3	main
ootan	doc_802069853781_item	3581154	et	3	main
uuelt	doc_802069853781_item	3581160	et	4	main
on	doc_802069853781_item	3581163	et	4	main
hea	doc_802069853781_item	3581164	et	4	main
ma	doc_802069853781_item	3581171	et	3	main
eesmärgid	doc_802069853781_item	3581173	et	3	main
ma	doc_802069853781_item	3581175	et	3	main
tea	doc_802069853781_item	3581177	et	4	main
millal	doc_802069853781_item	3581178	et	3	main
ja	doc_802069853781_item	3581179	et	3	main
tean	doc_802069853781_item	3581181	et	3	main
mitte	doc_802069853781_item	3581183	et	3	main
ööelda	doc_802069853714_item	3580712	et	4	main
praktikat	doc_802069853714_item	3580720	et	3	main
mul	doc_802069853714_item	3580721	et	3	main
olnud	doc_802069853714_item	3580722	et	4	main
palju	doc_802069853714_item	3580723	et	4	main
seepärast	doc_802069853714_item	3580724	et	3	main
mina	doc_802069853714_item	3580725	et	4	main
sooviks	doc_802069853714_item	3580726	et	4	main
rohkem	doc_802069853714_item	3580727	et	4	main
õppida	doc_802069853714_item	3580728	et	3	main
just	doc_802069853714_item	3580729	et	3	main
seda	doc_802069853714_item	3580730	et	3	main
osa	doc_802069853714_item	3580731	et	4	main
eesti	doc_802069853714_item	3580732	et	4	main
keelest	doc_802069853714_item	3580733	et	4	main
mis	doc_802069853714_item	3580734	et	4	main
on	doc_802069853714_item	3580735	et	4	main
seotud	doc_802069853714_item	3580736	et	4	main
minu	doc_802069853714_item	3580737	et	3	main
tulevase	doc_802069853714_item	3580738	et	4	main
erialaga	doc_802069853714_item	3580739	et	3	main
mina	doc_802069853725_item	3580742	et	4	main
nimi	doc_802069853725_item	3580747	et	3	main
valga	doc_802069853725_item	3580754	et	4	main
ma	doc_802069853725_item	3580761	et	3	main
kohtla	doc_802069853725_item	3580763	et	4	main
jarve	doc_802069853725_item	3580764	et	4	main
oli	doc_802069853725_item	3580769	et	3	main
väga	doc_802069853725_item	3580770	et	3	main
keel	doc_802069853725_item	3580780	et	4	main
aastal	doc_802069853725_item	3580782	et	3	main
ma	doc_802069853725_item	3580783	et	3	main
kõrgharidus	doc_802069853725_item	3580792	et	3	main
astun	doc_802069853725_item	3580795	et	3	main
arvestus	doc_802069853725_item	3580848	et	4	main
ja	doc_802069853725_item	3580849	et	3	main
ja	doc_802069853726_item	3580859	et	3	main
tallinna	doc_802069853726_item	3580865	et	4	main
vaja	doc_802069853726_item	3580909	et	4	main
pea	doc_802069853726_item	3580915	et	4	main
kelel	doc_802069853726_item	3580922	et	4	main
on	doc_802069853726_item	3580923	et	4	main
eriala	doc_802069853726_item	3580929	et	4	main
mina	doc_802069853726_item	3580930	et	4	main
servisil	doc_802069853726_item	3580944	et	4	main
mul	doc_802069853726_item	3580945	et	3	main
on	doc_802069853726_item	3580946	et	4	main
hea	doc_802069853726_item	3580947	et	4	main
ma	doc_802069853726_item	3580976	et	3	main
eesti	doc_802069853726_item	3580978	et	4	main
loengudele	doc_802069853726_item	3580980	et	4	main
õppimeene	doc_802069853726_item	3580981	et	4	main
ja	doc_802069853726_item	3580982	et	3	main
tean	doc_802069853726_item	3580990	et	3	main
ei	doc_802069853726_item	3580994	et	4	main
töö	doc_802069853726_item	3580996	et	4	main
elada	doc_802069853726_item	3581001	et	3	main
nimi	doc_802069853733_item	3581008	et	3	main
ma	doc_802069853733_item	3581017	et	3	main
tõelist	doc_802069853733_item	3581024	et	4	main
lõpetanud	doc_802069853733_item	3581053	et	4	main
tahtnud	doc_802069853733_item	3581060	et	4	main
õppekava	doc_802069853725_item	3580822	et	4	main
aga	doc_802069853725_item	3580823	et	3	main
liga	doc_802069853725_item	3580824	et	4	main
palju	doc_802069853725_item	3580825	et	4	main
ained	doc_802069853725_item	3580826	et	3	main
on	doc_802069853725_item	3580827	et	4	main
kohustlik	doc_802069853725_item	3580828	et	4	main
sest	doc_802069853725_item	3580829	et	4	main
1	doc_802069853725_item	3580830	et	2	main
kursustel	doc_802069853725_item	3580831	et	3	main
vähe	doc_802069853725_item	3580832	et	3	main
vabadust	doc_802069853725_item	3580833	et	4	main
mina	doc_802069853725_item	3580834	et	4	main
tahan	doc_802069853725_item	3580835	et	3	main
käisi	doc_802069853725_item	3580836	et	4	main
eesti	doc_802069853725_item	3580837	et	4	main
keele	doc_802069853725_item	3580838	et	4	main
loengud	doc_802069853725_item	3580839	et	3	main
aga	doc_802069853725_item	3580840	et	3	main
minu	doc_802069853725_item	3580746	et	3	main
ja	doc_802069853725_item	3580750	et	3	main
aastal	doc_802069853725_item	3580758	et	3	main
seal	doc_802069853725_item	3580768	et	4	main
ilusaid	doc_802069853725_item	3580771	et	3	main
ma	doc_802069853725_item	3580794	et	3	main
ja	doc_802069853725_item	3580798	et	3	main
süstemitehnika	doc_802069853725_item	3580799	et	4	main
see	doc_802069853725_item	3580800	et	3	main
on	doc_802069853725_item	3580801	et	4	main
eriala	doc_802069853725_item	3580802	et	4	main
kust	doc_802069853725_item	3580803	et	4	main
on	doc_802069853725_item	3580804	et	4	main
paljust	doc_802069853725_item	3580805	et	4	main
tasuta	doc_802069853725_item	3580806	et	4	main
vene	doc_802069853725_item	3580807	et	4	main
keelne	doc_802069853725_item	3580808	et	3	main
koht	doc_802069853725_item	3580809	et	3	main
siis	doc_802069853725_item	3580810	et	3	main
ma	doc_802069853725_item	3580811	et	3	main
panesin	doc_802069853725_item	3580812	et	4	main
dokumendid	doc_802069853725_item	3580813	et	3	main
seal	doc_802069853725_item	3580814	et	4	main
minu	doc_802069853725_item	3580815	et	3	main
esimene	doc_802069853725_item	3580816	et	3	main
muljet	doc_802069853725_item	3580817	et	3	main
tudengid	doc_802069853725_item	3580818	et	3	main
peaks	doc_802069853725_item	3580819	et	4	main
ise	doc_802069853725_item	3580820	et	4	main
konstruerib	doc_802069853725_item	3580821	et	4	main
õpetaja	doc_802069853725_item	3580850	et	4	main
ütles	doc_802069853725_item	3580851	et	3	main
et	doc_802069853725_item	3580852	et	3	main
ta	doc_802069853725_item	3580853	et	4	main
on	doc_802069853725_item	3580854	et	4	main
kuri	doc_802069853725_item	3580855	et	4	main
mina	doc_802069853726_item	3580858	et	4	main
dokumendid	doc_802069853726_item	3580875	et	3	main
kõigile	doc_802069853726_item	3580876	et	4	main
ttusse	doc_802069853726_item	3580877	et	4	main
audentesse	doc_802069853726_item	3580878	et	4	main
tartu	doc_802069853726_item	3580879	et	4	main
ülikolisse	doc_802069853726_item	3580880	et	3	main
ja	doc_802069853726_item	3580881	et	3	main
nii	doc_802069853726_item	3580882	et	3	main
edasi	doc_802069853726_item	3580883	et	3	main
mina	doc_802069853726_item	3580884	et	4	main
annan	doc_802069853726_item	3580885	et	3	main
dokumentid	doc_802069853726_item	3580886	et	4	main
tasulisel	doc_802069853726_item	3580887	et	4	main
ja	doc_802069853726_item	3580888	et	3	main
tasuline	doc_802069853726_item	3580889	et	4	main
fakultedil	doc_802069853726_item	3580890	et	4	main
mulle	doc_802069853726_item	3580891	et	4	main
meeldin	doc_802069853726_item	3580892	et	3	main
ttü	doc_802069853726_item	3580893	et	4	main
ma	doc_802069853726_item	3580902	et	3	main
ülikool	doc_802069853726_item	3580905	et	4	main
et	doc_802069853726_item	3580906	et	3	main
see	doc_802069853726_item	3580907	et	3	main
on	doc_802069853726_item	3580908	et	4	main
töötan	doc_802069853726_item	3580913	et	3	main
ja	doc_802069853726_item	3580914	et	3	main
et	doc_802069853726_item	3580918	et	3	main
mulle	doc_802069853726_item	3580926	et	4	main
meeldin	doc_802069853726_item	3580927	et	3	main
ja	doc_802069853726_item	3580933	et	3	main
on	doc_802069853726_item	3580935	et	4	main
meeldin	doc_802069853726_item	3580937	et	3	main
mina	doc_802069853726_item	3580938	et	4	main
tihti	doc_802069853726_item	3580939	et	3	main
teen	doc_802069853726_item	3580940	et	3	main
garažis	doc_802069853726_item	3580942	et	2	main
või	doc_802069853726_item	3580943	et	4	main
ttüst	doc_802069853726_item	3580949	et	4	main
et	doc_802069853726_item	3580950	et	3	main
esimesel	doc_802069853726_item	3580951	et	3	main
päeval	doc_802069853726_item	3580952	et	3	main
õpilased	doc_802069853726_item	3580957	et	3	main
seal	doc_802069853726_item	3580958	et	4	main
on	doc_802069853726_item	3580959	et	4	main
head	doc_802069853726_item	3580960	et	4	main
kabinetid	doc_802069853726_item	3580961	et	3	main
ja	doc_802069853726_item	3580962	et	3	main
õppekollektiiv	doc_802069853726_item	3580963	et	3	main
ma	doc_802069853726_item	3580964	et	3	main
tean	doc_802069853726_item	3580965	et	3	main
et	doc_802069853726_item	3580966	et	3	main
õppimine	doc_802069853726_item	3580967	et	4	main
ülikoolis	doc_802069853726_item	3580968	et	4	main
on	doc_802069853726_item	3580969	et	4	main
raske	doc_802069853726_item	3580970	et	4	main
aga	doc_802069853726_item	3580971	et	3	main
ma	doc_802069853726_item	3580972	et	3	main
tahan	doc_802069853726_item	3580973	et	3	main
raske	doc_802069853726_item	3581000	et	4	main
essee	doc_802069853733_item	3581003	et	4	main
ja	doc_802069853733_item	3581005	et	3	main
olen	doc_802069853733_item	3581012	et	3	main
veetmise	doc_802069853733_item	3581045	et	4	main
huvitas	doc_802069853733_item	3581070	et	3	main
põhjusi	doc_802069853733_item	3581074	et	3	main
arvan	doc_802069853733_item	3581076	et	3	main
see	doc_802069853733_item	3581078	et	3	main
nõutav	doc_802069853733_item	3581082	et	4	main
pärast	doc_802069853733_item	3581085	et	4	main
lepingu	doc_802069853733_item	3581086	et	3	main
ta	doc_802069853733_item	3581097	et	4	main
teha	doc_802069853733_item	3581103	et	3	main
igavat	doc_802069853733_item	3581104	et	3	main
asju	doc_802069853733_item	3581105	et	3	main
aga	doc_802069853733_item	3581106	et	3	main
nüüd	doc_802069853733_item	3581107	et	4	main
on	doc_802069853733_item	3581108	et	4	main
teised	doc_802069853733_item	3581109	et	4	main
põhjused	doc_802069853733_item	3581110	et	3	main
ja	doc_802069853733_item	3581111	et	3	main
nad	doc_802069853733_item	3581112	et	3	main
on	doc_802069853733_item	3581113	et	4	main
väga	doc_802069853733_item	3581114	et	3	main
kohustuslikud	doc_802069853733_item	3581115	et	3	main
siin	doc_802069853733_item	3581116	et	4	main
mul	doc_802069853733_item	3581117	et	3	main
on	doc_802069853733_item	3581118	et	4	main
palju	doc_802069853733_item	3581119	et	4	main
loenguid	doc_802069853733_item	3581120	et	4	main
ülikool	doc_802069853733_item	3581006	et	4	main
eesnimi	doc_802069853733_item	3581010	et	3	main
eestist	doc_802069853733_item	3581014	et	3	main
narvas	doc_802069853733_item	3581019	et	4	main
sõpru	doc_802069853733_item	3581025	et	3	main
ütelda	doc_802069853733_item	3581028	et	4	main
minule	doc_802069853733_item	3581029	et	3	main
kõik	doc_802069853733_item	3581030	et	4	main
neid	doc_802069853733_item	3581031	et	4	main
saladusi	doc_802069853733_item	3581032	et	3	main
ja	doc_802069853733_item	3581033	et	3	main
aitada	doc_802069853733_item	3581034	et	4	main
raskedes	doc_802069853733_item	3581035	et	4	main
olukordades	doc_802069853733_item	3581036	et	3	main
ma	doc_802069853733_item	3581037	et	3	main
armastasin	doc_802069853733_item	3581038	et	3	main
ekstimsporti	doc_802069853733_item	3581039	et	4	main
ja	doc_802069853733_item	3581040	et	3	main
minu	doc_802069853733_item	3581041	et	3	main
lemmik	doc_802069853733_item	3581042	et	3	main
vaba	doc_802069853733_item	3581043	et	4	main
viis	doc_802069853733_item	3581046	et	4	main
gümnaasiumi	doc_802069853733_item	3581054	et	4	main
ja	doc_802069853733_item	3581055	et	3	main
saanud	doc_802069853733_item	3581056	et	4	main
teha	doc_802069853733_item	3581061	et	3	main
mind	doc_802069853733_item	3581069	et	4	main
autod	doc_802069853733_item	3581071	et	3	main
tööde	doc_802069853733_item	3581073	et	3	main
on	doc_802069853733_item	3581080	et	4	main
tunda	doc_802069853733_item	3581091	et	3	main
eluviisi	doc_802069853733_item	3581093	et	4	main
eldist	doc_802069853733_item	3581100	et	4	main
pole	doc_802069853733_item	3581101	et	3	main
neist	doc_802069853733_item	3581123	et	4	main
eesti	doc_802069853733_item	3581127	et	4	main
keele	doc_802069853733_item	3581142	et	4	main
oskusi	doc_802069853733_item	3581143	et	3	main
ma	doc_802069853733_item	3581144	et	3	main
ootan	doc_802069853733_item	3581145	et	3	main
saata	doc_802069853733_item	3581146	et	3	main
essee	doc_802069853781_item	3581151	et	4	main
ma	doc_802069853781_item	3581158	et	3	main
see	doc_802069853781_item	3581162	et	3	main
isegi	doc_802069853781_item	3581168	et	4	main
järgmisel	doc_802069853781_item	3581184	et	3	main
uues	doc_802069853781_item	3581195	et	3	main
on	doc_802069853733_item	3581047	et	4	main
tegelda	doc_802069853733_item	3581048	et	4	main
keskharidust	doc_802069853733_item	3581057	et	4	main
aga	doc_802069853733_item	3581058	et	3	main
peatust	doc_802069853733_item	3581062	et	4	main
sisse	doc_802069853733_item	3581065	et	4	main
ma	doc_802069853733_item	3581075	et	3	main
et	doc_802069853733_item	3581077	et	3	main
väga	doc_802069853733_item	3581081	et	3	main
tanapäeva	doc_802069853733_item	3581083	et	4	main
elus	doc_802069853733_item	3581084	et	4	main
võimalust	doc_802069853733_item	3581090	et	3	main
on	doc_802069853733_item	3581124	et	4	main
tund	doc_802069853733_item	3581126	et	3	main
riigikeel	doc_802069853733_item	3581130	et	4	main
ma	doc_802069853733_item	3581131	et	3	main
et	doc_802069853733_item	3581134	et	3	main
tund	doc_802069853733_item	3581136	et	3	main
mulle	doc_802069853733_item	3581138	et	4	main
oma	doc_802069853733_item	3581140	et	4	main
päraseid	doc_802069853733_item	3581148	et	4	main
otsustanud	doc_802069853733_item	3581064	et	4	main
astuda	doc_802069853733_item	3581066	et	3	main
ttü	doc_802069853733_item	3581067	et	4	main
sse	doc_802069853733_item	3581068	et	4	main
eriala	doc_802069853733_item	3581079	et	4	main
ilmus	doc_802069853733_item	3581089	et	4	main
tudengi	doc_802069853733_item	3581092	et	3	main
ja	doc_802069853733_item	3581094	et	3	main
märkan	doc_802069853733_item	3581095	et	3	main
et	doc_802069853733_item	3581096	et	3	main
väga	doc_802069853733_item	3581098	et	3	main
vaja	doc_802069853733_item	3581102	et	4	main
üks	doc_802069853733_item	3581122	et	3	main
vabatahtlik	doc_802069853733_item	3581125	et	3	main
eesti	doc_802069853733_item	3581141	et	4	main
muljeid	doc_802069853733_item	3581149	et	3	main
mida	doc_802069853781_item	3581152	et	4	main
aastalt	doc_802069853781_item	3581156	et	3	main
küsimus	doc_802069853781_item	3581165	et	4	main
ma	doc_802069853781_item	3581167	et	3	main
elus	doc_802069853781_item	3581174	et	4	main
aega	doc_802069853781_item	3581190	et	4	main
aastas	doc_802069853781_item	3581196	et	3	main
et	doc_802069853781_item	3581204	et	3	main
saada	doc_802069853781_item	3581206	et	4	main
oota	doc_802069853781_item	3581247	et	4	main
midagi	doc_802069853781_item	3581248	et	4	main
ootan	doc_802069853785_item	3581282	et	3	main
pidistavad	doc_802069853785_item	3581289	et	4	main
lemmik	doc_802069853785_item	3581291	et	3	main
nagu	doc_802069853785_item	3581295	et	3	main
selles	doc_802069853785_item	3581306	et	4	main
püüan	doc_802069853785_item	3581307	et	3	main
tähistada	doc_802069853785_item	3581308	et	3	main
kõigem	doc_802069853785_item	3581309	et	4	main
pärast	doc_802069853785_item	3581312	et	4	main
detsembris	doc_802069853785_item	3581325	et	3	main
minu	doc_802069853785_item	3581331	et	3	main
unistus	doc_802069853785_item	3581333	et	4	main
veel	doc_802069853785_item	3581334	et	4	main
ma	doc_802069853786_item	3581371	et	3	main
aastast	doc_802069853786_item	3581381	et	4	main
kingitusi	doc_802069853786_item	3581388	et	4	main
sest	doc_802069853786_item	3581389	et	4	main
on	doc_802069853786_item	3581393	et	4	main
peot	doc_802069853786_item	3581403	et	4	main
sest	doc_802069853786_item	3581404	et	4	main
sel	doc_802069853786_item	3581405	et	3	main
mida	doc_802069853786_item	3581414	et	4	main
on	doc_802069853786_item	3581425	et	4	main
jään	doc_802069853786_item	3581437	et	3	main
ja	doc_802069853786_item	3581442	et	3	main
et	doc_802069853786_item	3581444	et	3	main
aastal	doc_802069853786_item	3581446	et	3	main
elus	doc_802069853786_item	3581455	et	4	main
et	doc_802069853786_item	3581464	et	3	main
uue	doc_802069853795_item	3581523	et	3	main
aasta	doc_802069853795_item	3581524	et	4	main
ees	doc_802069853795_item	3581525	et	4	main
midagi	doc_802069853795_item	3581532	et	4	main
et	doc_802069853795_item	3581537	et	3	main
või	doc_802069853795_item	3581548	et	4	main
inimesed	doc_802069853795_item	3581551	et	3	main
ole	doc_802069853795_item	3581567	et	4	main
see	doc_802069853795_item	3581569	et	3	main
sada	doc_802069853795_item	3581573	et	4	main
aastat	doc_802069853795_item	3581574	et	3	main
aastal	doc_802069853795_item	3581582	et	3	main
kui	doc_802069853795_item	3581586	et	3	main
loodan	doc_802069853795_item	3581600	et	3	main
et	doc_802069853795_item	3581601	et	3	main
jõulupühad	doc_802069853795_item	3581604	et	3	main
hästi	doc_802069853795_item	3581608	et	3	main
vanematega	doc_802069853795_item	3581619	et	4	main
ja	doc_802069853733_item	3581121	et	3	main
kui	doc_802069853733_item	3581129	et	3	main
veendunud	doc_802069853733_item	3581133	et	4	main
aitab	doc_802069853733_item	3581137	et	3	main
tugevdada	doc_802069853733_item	3581139	et	3	main
uuelt	doc_802069853781_item	3581155	et	4	main
aga	doc_802069853781_item	3581166	et	3	main
tea	doc_802069853781_item	3581170	et	4	main
panin	doc_802069853781_item	3581172	et	3	main
on	doc_802069853781_item	3581187	et	4	main
liiga	doc_802069853781_item	3581188	et	4	main
vähe	doc_802069853781_item	3581189	et	3	main
ma	doc_802069853781_item	3581192	et	3	main
võin	doc_802069853781_item	3581193	et	3	main
töötama	doc_802069853781_item	3581203	et	3	main
järgmiselt	doc_802069853781_item	3581249	et	4	main
aastalt	doc_802069853781_item	3581250	et	3	main
mis	doc_802069853781_item	3581251	et	4	main
tuleb	doc_802069853781_item	3581252	et	3	main
see	doc_802069853781_item	3581253	et	3	main
tuleb	doc_802069853781_item	3581254	et	3	main
ma	doc_802069853781_item	3581255	et	3	main
elan	doc_802069853781_item	3581256	et	3	main
täna	doc_802069853781_item	3581257	et	4	main
praegu	doc_802069853781_item	3581258	et	3	main
ja	doc_802069853781_item	3581259	et	3	main
mõtlen	doc_802069853781_item	3581260	et	3	main
mida	doc_802069853781_item	3581261	et	4	main
ma	doc_802069853781_item	3581262	et	3	main
teen	doc_802069853781_item	3581263	et	3	main
täna	doc_802069853781_item	3581264	et	4	main
võib	doc_802069853781_item	3581265	et	3	main
olla	doc_802069853781_item	3581266	et	3	main
sellel	doc_802069853781_item	3581267	et	4	main
nädal	doc_802069853781_item	3581268	et	3	main
aga	doc_802069853781_item	3581269	et	3	main
mitte	doc_802069853781_item	3581270	et	3	main
mida	doc_802069853781_item	3581271	et	4	main
ma	doc_802069853781_item	3581272	et	3	main
teen	doc_802069853781_item	3581273	et	3	main
või	doc_802069853781_item	3581274	et	4	main
saan	doc_802069853781_item	3581275	et	4	main
järgmisel	doc_802069853781_item	3581276	et	3	main
aastal	doc_802069853781_item	3581277	et	3	main
essee	doc_802069853785_item	3581279	et	4	main
aastalt	doc_802069853785_item	3581284	et	3	main
varsti	doc_802069853785_item	3581286	et	3	main
aasta	doc_802069853785_item	3581294	et	4	main
kuidas	doc_802069853785_item	3581297	et	3	main
niisuugune	doc_802069853785_item	3581299	et	4	main
parem	doc_802069853785_item	3581310	et	4	main
lähen	doc_802069853785_item	3581327	et	3	main
sinna	doc_802069853785_item	3581328	et	3	main
on	doc_802069853785_item	3581330	et	4	main
alati	doc_802069853786_item	3581377	et	4	main
näen	doc_802069853781_item	3581231	et	3	main
paha	doc_802069853781_item	3581232	et	4	main
ja	doc_802069853781_item	3581233	et	3	main
hea	doc_802069853781_item	3581234	et	4	main
asjad	doc_802069853781_item	3581235	et	3	main
kõikides	doc_802069853781_item	3581236	et	4	main
ja	doc_802069853781_item	3581237	et	3	main
valitsen	doc_802069853781_item	3581238	et	3	main
hea	doc_802069853781_item	3581239	et	4	main
sellejärel	doc_802069853781_item	3581240	et	3	main
ma	doc_802069853781_item	3581241	et	3	main
armastan	doc_802069853781_item	3581242	et	3	main
oma	doc_802069853781_item	3581243	et	4	main
elu	doc_802069853781_item	3581244	et	4	main
ja	doc_802069853781_item	3581245	et	3	main
ei	doc_802069853781_item	3581246	et	4	main
ma	doc_802069853781_item	3581153	et	3	main
mida	doc_802069853781_item	3581157	et	4	main
ootan	doc_802069853781_item	3581159	et	3	main
aastalt	doc_802069853781_item	3581161	et	3	main
ei	doc_802069853781_item	3581169	et	4	main
ei	doc_802069853781_item	3581176	et	4	main
tõesti	doc_802069853781_item	3581180	et	3	main
et	doc_802069853781_item	3581182	et	3	main
see	doc_802069853781_item	3581186	et	3	main
mida	doc_802069853781_item	3581191	et	4	main
teha	doc_802069853781_item	3581194	et	3	main
ainult	doc_802069853781_item	3581197	et	4	main
hea	doc_802069853781_item	3581198	et	4	main
õppima	doc_802069853781_item	3581199	et	3	main
ja	doc_802069853781_item	3581200	et	3	main
võib	doc_802069853781_item	3581201	et	3	main
juba	doc_802069853781_item	3581213	et	3	main
rõõmus	doc_802069853781_item	3581214	et	4	main
keegi	doc_802069853781_item	3581215	et	4	main
näeb	doc_802069853781_item	3581216	et	3	main
omas	doc_802069853781_item	3581217	et	4	main
elus	doc_802069853781_item	3581218	et	4	main
ainult	doc_802069853781_item	3581219	et	4	main
halb	doc_802069853781_item	3581220	et	3	main
asjad	doc_802069853781_item	3581221	et	3	main
ja	doc_802069853781_item	3581222	et	3	main
miks	doc_802069853781_item	3581224	et	4	main
mõtlevad	doc_802069853781_item	3581223	et	4	main
elama	doc_802069853781_item	3581225	et	3	main
kui	doc_802069853781_item	3581226	et	3	main
kõik	doc_802069853781_item	3581227	et	4	main
on	doc_802069853781_item	3581228	et	4	main
halb	doc_802069853781_item	3581229	et	3	main
ma	doc_802069853781_item	3581230	et	3	main
uuelt	doc_802069853785_item	3581283	et	4	main
juba	doc_802069853785_item	3581285	et	3	main
inimesed	doc_802069853785_item	3581288	et	3	main
aasta	doc_802069853785_item	3581302	et	4	main
ja	doc_802069853785_item	3581303	et	3	main
ma	doc_802069853785_item	3581304	et	3	main
usun	doc_802069853785_item	3581305	et	3	main
ma	doc_802069853785_item	3581313	et	3	main
uuelt	doc_802069853785_item	3581316	et	4	main
tahan	doc_802069853785_item	3581321	et	3	main
juba	doc_802069853785_item	3581324	et	3	main
see	doc_802069853785_item	3581329	et	3	main
essee	doc_802069853786_item	3581369	et	4	main
uuest	doc_802069853786_item	3581373	et	3	main
aastast	doc_802069853786_item	3581374	et	4	main
iga	doc_802069853786_item	3581375	et	4	main
inimene	doc_802069853786_item	3581376	et	3	main
alati	doc_802069853786_item	3581385	et	4	main
ootasin	doc_802069853786_item	3581386	et	3	main
see	doc_802069853786_item	3581392	et	3	main
palju	doc_802069853786_item	3581409	et	4	main
kingitusi	doc_802069853786_item	3581417	et	4	main
peaaegu	doc_802069853786_item	3581418	et	3	main
oota	doc_802069853786_item	3581420	et	4	main
sest	doc_802069853786_item	3581421	et	4	main
kõik	doc_802069853786_item	3581422	et	4	main
aastal	doc_802069853786_item	3581431	et	3	main
mu	doc_802069853786_item	3581432	et	3	main
jaoks	doc_802069853786_item	3581433	et	4	main
algab	doc_802069853786_item	3581434	et	3	main
kõik	doc_802069853786_item	3581435	et	4	main
aastal	doc_802069853781_item	3581185	et	3	main
olla	doc_802069853781_item	3581202	et	3	main
raha	doc_802069853781_item	3581205	et	4	main
võib	doc_802069853781_item	3581207	et	3	main
olla	doc_802069853781_item	3581208	et	3	main
rõõmus	doc_802069853781_item	3581209	et	4	main
aga	doc_802069853781_item	3581210	et	3	main
ma	doc_802069853781_item	3581211	et	3	main
olen	doc_802069853781_item	3581212	et	3	main
mida	doc_802069853785_item	3581280	et	4	main
kõik	doc_802069853785_item	3581287	et	4	main
kõigem	doc_802069853785_item	3581290	et	4	main
pidu	doc_802069853785_item	3581292	et	4	main
selle	doc_802069853785_item	3581311	et	4	main
paljud	doc_802069853785_item	3581315	et	3	main
aastalt	doc_802069853785_item	3581317	et	3	main
järjekorras	doc_802069853785_item	3581319	et	3	main
ma	doc_802069853785_item	3581320	et	3	main
saada	doc_802069853785_item	3581322	et	4	main
juhiluba	doc_802069853785_item	3581323	et	4	main
ammune	doc_802069853785_item	3581332	et	4	main
ootab	doc_802069853786_item	3581378	et	3	main
midagi	doc_802069853786_item	3581379	et	4	main
uuest	doc_802069853786_item	3581380	et	3	main
ka	doc_802069853786_item	3581384	et	3	main
tavaliselt	doc_802069853786_item	3581387	et	4	main
laste	doc_802069853786_item	3581390	et	4	main
lihtsalt	doc_802069853786_item	3581402	et	4	main
vabadusi	doc_802069853786_item	3581410	et	4	main
ja	doc_802069853786_item	3581411	et	3	main
sain	doc_802069853786_item	3581412	et	3	main
teha	doc_802069853786_item	3581413	et	3	main
ei	doc_802069853786_item	3581419	et	4	main
vaja	doc_802069853786_item	3581426	et	4	main
mul	doc_802069853786_item	3581427	et	3	main
on	doc_802069853786_item	3581428	et	4	main
juba	doc_802069853786_item	3581429	et	3	main
uuel	doc_802069853786_item	3581430	et	3	main
kõik	doc_802069853786_item	3581438	et	4	main
pahat	doc_802069853786_item	3581439	et	4	main
aastas	doc_802069853786_item	3581441	et	3	main
tahan	doc_802069853786_item	3581443	et	3	main
kõik	doc_802069853786_item	3581447	et	4	main
oleks	doc_802069853786_item	3581448	et	3	main
hästi	doc_802069853786_item	3581449	et	3	main
järgmisest	doc_802069853786_item	3581450	et	3	main
aastast	doc_802069853786_item	3581451	et	4	main
ootan	doc_802069853786_item	3581452	et	3	main
ootan	doc_802069853786_item	3581463	et	3	main
olla	doc_802069853785_item	3581358	et	3	main
üle	doc_802069853785_item	3581359	et	3	main
minna	doc_802069853785_item	3581360	et	3	main
tasuta	doc_802069853785_item	3581361	et	4	main
kohal	doc_802069853785_item	3581362	et	4	main
mul	doc_802069853785_item	3581364	et	3	main
niisugume	doc_802069853785_item	3581363	et	4	main
on	doc_802069853785_item	3581365	et	4	main
tagasihoidlikud	doc_802069853785_item	3581366	et	3	main
unitused	doc_802069853785_item	3581367	et	4	main
ma	doc_802069853785_item	3581281	et	3	main
uus	doc_802069853785_item	3581293	et	3	main
räägivad	doc_802069853785_item	3581296	et	3	main
tähistab	doc_802069853785_item	3581298	et	3	main
on	doc_802069853785_item	3581300	et	4	main
kõik	doc_802069853785_item	3581301	et	4	main
ootan	doc_802069853785_item	3581314	et	3	main
esimeses	doc_802069853785_item	3581318	et	3	main
ma	doc_802069853785_item	3581326	et	3	main
ma	doc_802069853785_item	3581335	et	3	main
tahan	doc_802069853785_item	3581336	et	3	main
sõida	doc_802069853785_item	3581337	et	4	main
uues	doc_802069853785_item	3581338	et	3	main
aastas	doc_802069853785_item	3581339	et	3	main
englisemaal	doc_802069853785_item	3581340	et	4	main
koos	doc_802069853785_item	3581341	et	4	main
sõbrannaga	doc_802069853785_item	3581342	et	3	main
seal	doc_802069853785_item	3581343	et	4	main
elab	doc_802069853785_item	3581344	et	3	main
meie	doc_802069853785_item	3581345	et	4	main
ühine	doc_802069853785_item	3581346	et	4	main
sõber	doc_802069853785_item	3581347	et	3	main
ja	doc_802069853785_item	3581348	et	3	main
muidugi	doc_802069853785_item	3581349	et	4	main
minu	doc_802069853785_item	3581350	et	3	main
jaoks	doc_802069853785_item	3581351	et	4	main
on	doc_802069853785_item	3581352	et	4	main
tähtis	doc_802069853785_item	3581353	et	4	main
õppida	doc_802069853785_item	3581354	et	3	main
hästi	doc_802069853785_item	3581355	et	3	main
ja	doc_802069853785_item	3581356	et	3	main
võib	doc_802069853785_item	3581357	et	3	main
aastast	doc_802069853786_item	3581502	et	4	main
et	doc_802069853786_item	3581503	et	3	main
ta	doc_802069853786_item	3581504	et	4	main
on	doc_802069853786_item	3581505	et	4	main
parem	doc_802069853786_item	3581506	et	4	main
kui	doc_802069853786_item	3581507	et	3	main
eelmine	doc_802069853786_item	3581508	et	3	main
aasta	doc_802069853786_item	3581509	et	4	main
ja	doc_802069853786_item	3581510	et	3	main
kõik	doc_802069853786_item	3581511	et	4	main
igal	doc_802069853786_item	3581512	et	3	main
on	doc_802069853786_item	3581513	et	4	main
hästi	doc_802069853786_item	3581514	et	3	main
nagu	doc_802069853786_item	3581515	et	3	main
nad	doc_802069853786_item	3581516	et	3	main
ise	doc_802069853786_item	3581517	et	4	main
soovivad	doc_802069853786_item	3581518	et	4	main
mida	doc_802069853786_item	3581370	et	4	main
ootan	doc_802069853786_item	3581372	et	3	main
ja	doc_802069853786_item	3581382	et	3	main
jaoks	doc_802069853786_item	3581391	et	4	main
varem	doc_802069853786_item	3581396	et	4	main
ka	doc_802069853786_item	3581397	et	3	main
ootasin	doc_802069853786_item	3581398	et	3	main
seda	doc_802069853786_item	3581399	et	3	main
aga	doc_802069853786_item	3581400	et	3	main
pärast	doc_802069853786_item	3581401	et	4	main
mina	doc_802069853786_item	3581383	et	4	main
parim	doc_802069853786_item	3581394	et	4	main
asi	doc_802069853786_item	3581395	et	4	main
alati	doc_802069853786_item	3581408	et	4	main
mis	doc_802069853786_item	3581423	et	4	main
mul	doc_802069853786_item	3581424	et	3	main
vanas	doc_802069853786_item	3581440	et	3	main
järgmisel	doc_802069853786_item	3581445	et	3	main
töö	doc_802069853786_item	3581460	et	4	main
isik	doc_802069853786_item	3581461	et	3	main
minu	doc_802069853795_item	3581521	et	3	main
soov	doc_802069853795_item	3581535	et	3	main
on	doc_802069853795_item	3581536	et	4	main
kõik	doc_802069853795_item	3581538	et	4	main
peab	doc_802069853795_item	3581539	et	4	main
olla	doc_802069853795_item	3581540	et	3	main
hästi	doc_802069853795_item	3581541	et	3	main
järgmisel	doc_802069853795_item	3581542	et	3	main
aastal	doc_802069853795_item	3581543	et	3	main
tänapäeval	doc_802069853795_item	3581544	et	3	main
rahat	doc_802069853795_item	3581545	et	4	main
autot	doc_802069853795_item	3581546	et	3	main
ei	doc_802069853795_item	3581552	et	4	main
oli	doc_802069853795_item	3581570	et	3	main
soovima	doc_802069853795_item	3581580	et	4	main
siis	doc_802069853795_item	3581592	et	3	main
kõik	doc_802069853795_item	3581596	et	4	main
aasta	doc_802069853795_item	3581598	et	4	main
essee	doc_802069853801_item	3581635	et	4	main
meie	doc_802069853801_item	3581651	et	4	main
jaoks	doc_802069853801_item	3581652	et	4	main
aasta	doc_802069853801_item	3581675	et	4	main
ja	doc_802069853801_item	3581676	et	3	main
jälle	doc_802069853801_item	3581678	et	3	main
ka	doc_802069853801_item	3581683	et	3	main
ootan	doc_802069853801_item	3581686	et	3	main
aasta	doc_802069853801_item	3581689	et	4	main
toob	doc_802069853801_item	3581690	et	3	main
midagi	doc_802069853801_item	3581701	et	4	main
ise	doc_802069853801_item	3581707	et	4	main
teeme	doc_802069853801_item	3581708	et	3	main
või	doc_802069853801_item	3581711	et	4	main
palju	doc_802069853801_item	3581713	et	4	main
oleneb	doc_802069853801_item	3581714	et	3	main
aasta	doc_802069853801_item	3581735	et	4	main
elu	doc_802069853801_item	3581737	et	4	main
töö	doc_802069853801_item	3581746	et	4	main
et	doc_802069853801_item	3581748	et	3	main
ja	doc_802069853801_item	3581770	et	3	main
võimalus	doc_802069853801_item	3581773	et	3	main
essee	doc_802069853804_item	3581800	et	4	main
öteppäle	doc_802069853804_item	3581811	et	4	main
mägisse	doc_802069853804_item	3581812	et	4	main
jaanuar	doc_802069853804_item	3581843	et	3	main
et	doc_802069853804_item	3581845	et	3	main
eeksamid	doc_802069853804_item	3581847	et	4	main
mai	doc_802069853804_item	3581858	et	4	main
reisin	doc_802069853804_item	3581861	et	3	main
küllustada	doc_802069853804_item	3581863	et	4	main
ja	doc_802069853804_item	3581868	et	3	main
essee	doc_873901597537_item	3581898	et	4	main
ja	doc_873901597537_item	3581915	et	3	main
ja	doc_873901597537_item	3581952	et	3	main
pärast	doc_873901597537_item	3581959	et	4	main
kohtumine	doc_873901597537_item	3581964	et	4	main
sõbradega	doc_873901597537_item	3581966	et	4	main
mul	doc_873901597537_item	3581982	et	3	main
ülekolis	doc_873901597537_item	3581985	et	3	main
mina	doc_873901597537_item	3581987	et	4	main
essee	doc_873901597544_item	3581991	et	4	main
peod	doc_873901597544_item	3582000	et	4	main
käib	doc_873901597544_item	3582007	et	3	main
pidustan	doc_873901597544_item	3582034	et	4	main
vanemate	doc_873901597544_item	3582043	et	4	main
ma	doc_873901597544_item	3582050	et	3	main
et	doc_873901597544_item	3582052	et	3	main
on	doc_873901597544_item	3582054	et	4	main
hakkan	doc_873901597544_item	3582058	et	3	main
õppimisest	doc_873901597544_item	3582060	et	4	main
sest	doc_873901597544_item	3582061	et	4	main
hindade	doc_873901597544_item	3582067	et	3	main
on	doc_873901597544_item	3582070	et	4	main
ajal	doc_802069853786_item	3581406	et	4	main
oli	doc_802069853786_item	3581407	et	3	main
soovisin	doc_802069853786_item	3581415	et	4	main
praegu	doc_802069853786_item	3581416	et	3	main
et	doc_802069853786_item	3581453	et	3	main
läheb	doc_802069853786_item	3581457	et	3	main
paremaks	doc_802069853786_item	3581458	et	4	main
õppimine	doc_802069853786_item	3581459	et	4	main
kõik	doc_802069853795_item	3581526	et	4	main
see	doc_802069853795_item	3581534	et	3	main
uut	doc_802069853795_item	3581549	et	3	main
korterit	doc_802069853795_item	3581550	et	3	main
ei	doc_802069853795_item	3581566	et	4	main
näiteks	doc_802069853795_item	3581571	et	4	main
mida	doc_802069853795_item	3581579	et	4	main
usun	doc_802069853795_item	3581584	et	3	main
veedan	doc_802069853795_item	3581588	et	3	main
uues	doc_802069853795_item	3581590	et	3	main
samasugune	doc_802069853795_item	3581593	et	3	main
järgmine	doc_802069853795_item	3581597	et	3	main
ma	doc_802069853795_item	3581602	et	3	main
uue	doc_802069853795_item	3581606	et	3	main
tahaksin	doc_802069853795_item	3581611	et	3	main
aasta	doc_802069853795_item	3581614	et	4	main
koos	doc_802069853795_item	3581615	et	4	main
sõpradega	doc_802069853795_item	3581616	et	3	main
ja	doc_802069853795_item	3581617	et	3	main
minu	doc_802069853801_item	3581636	et	3	main
uus	doc_802069853801_item	3581641	et	3	main
me	doc_802069853801_item	3581644	et	4	main
ootame	doc_802069853801_item	3581645	et	3	main
et	doc_802069853801_item	3581646	et	3	main
just	doc_802069853801_item	3581647	et	3	main
see	doc_802069853801_item	3581648	et	3	main
kõige	doc_802069853801_item	3581653	et	4	main
saanu	doc_802069853801_item	3581660	et	4	main
tuleb	doc_802069853801_item	3581672	et	3	main
mina	doc_802069853801_item	3581682	et	4	main
ja	doc_802069853801_item	3581685	et	3	main
see	doc_802069853801_item	3581688	et	3	main
eelmine	doc_802069853801_item	3581695	et	3	main
ma	doc_802069853801_item	3581697	et	3	main
saan	doc_802069853801_item	3581698	et	4	main
me	doc_802069853801_item	3581717	et	4	main
võtame	doc_802069853801_item	3581718	et	3	main
vastu	doc_802069853801_item	3581719	et	3	main
jooksul	doc_802069853801_item	3581725	et	4	main
aga	doc_802069853801_item	3581726	et	3	main
endale	doc_802069853801_item	3581744	et	4	main
kõrgema	doc_802069853801_item	3581751	et	4	main
kursuse	doc_802069853801_item	3581757	et	3	main
loodan	doc_802069853801_item	3581758	et	3	main
et	doc_802069853801_item	3581759	et	3	main
loodavad	doc_802069853801_item	3581777	et	4	main
ja	doc_802069853801_item	3581778	et	3	main
unistavad	doc_802069853801_item	3581779	et	4	main
minu	doc_802069853801_item	3581780	et	3	main
minu	doc_802069853804_item	3581801	et	3	main
suusatada	doc_802069853804_item	3581813	et	3	main
ma	doc_802069853804_item	3581860	et	3	main
moskvas	doc_802069853804_item	3581866	et	4	main
pskovil	doc_802069853804_item	3581867	et	4	main
kurskus	doc_802069853804_item	3581869	et	4	main
selleparast	doc_802069853804_item	3581870	et	3	main
et	doc_802069853804_item	3581871	et	3	main
seal	doc_802069853804_item	3581872	et	4	main
mul	doc_802069853804_item	3581873	et	3	main
minu	doc_873901597537_item	3581899	et	3	main
varem	doc_873901597537_item	3581901	et	4	main
ja	doc_873901597537_item	3581904	et	3	main
kõik	doc_873901597537_item	3581905	et	4	main
inimesed	doc_873901597537_item	3581906	et	3	main
teegevad	doc_873901597537_item	3581907	et	4	main
see	doc_873901597537_item	3581908	et	3	main
peres	doc_873901597537_item	3581913	et	3	main
see	doc_873901597537_item	3581917	et	3	main
teismoodi	doc_873901597537_item	3581919	et	4	main
näide	doc_873901597537_item	3581921	et	3	main
inglismaal	doc_873901597537_item	3581922	et	4	main
me	doc_873901597537_item	3581947	et	4	main
istume	doc_873901597537_item	3581948	et	3	main
jõululaude	doc_873901597537_item	3581949	et	3	main
uuesti	doc_802069853786_item	3581436	et	3	main
mu	doc_802069853786_item	3581454	et	3	main
kõik	doc_802069853786_item	3581456	et	4	main
elu	doc_802069853786_item	3581462	et	4	main
seesia	doc_802069853786_item	3581465	et	4	main
läheb	doc_802069853786_item	3581466	et	3	main
läbi	doc_802069853786_item	3581467	et	4	main
hästi	doc_802069853786_item	3581468	et	3	main
sooritan	doc_802069853786_item	3581470	et	3	main
ja	doc_802069853786_item	3581469	et	3	main
kõike	doc_802069853786_item	3581471	et	4	main
hästi	doc_802069853786_item	3581473	et	3	main
ja	doc_802069853786_item	3581474	et	3	main
saan	doc_802069853786_item	3581475	et	4	main
eksami	doc_802069853786_item	3581472	et	3	main
õppida	doc_802069853786_item	3581476	et	3	main
edasi	doc_802069853786_item	3581477	et	3	main
järgmisel	doc_802069853786_item	3581478	et	3	main
semestril	doc_802069853786_item	3581479	et	3	main
tahan	doc_802069853786_item	3581480	et	3	main
hakkata	doc_802069853786_item	3581481	et	4	main
töötada	doc_802069853786_item	3581482	et	3	main
et	doc_802069853786_item	3581483	et	3	main
võiks	doc_802069853786_item	3581484	et	4	main
veel	doc_802069853786_item	3581485	et	4	main
normaalselt	doc_802069853786_item	3581486	et	4	main
tennida	doc_802069853786_item	3581487	et	4	main
raha	doc_802069853786_item	3581488	et	4	main
ja	doc_802069853786_item	3581489	et	3	main
õppida	doc_802069853786_item	3581490	et	3	main
sest	doc_802069853786_item	3581491	et	4	main
tahan	doc_802069853786_item	3581492	et	3	main
olla	doc_802069853786_item	3581493	et	3	main
vanematelt	doc_802069853786_item	3581495	et	4	main
ja	doc_802069853786_item	3581496	et	3	main
iseisav	doc_802069853786_item	3581494	et	4	main
üldse	doc_802069853786_item	3581497	et	3	main
ma	doc_802069853786_item	3581498	et	3	main
alati	doc_802069853786_item	3581499	et	4	main
ootan	doc_802069853786_item	3581500	et	3	main
uuest	doc_802069853786_item	3581501	et	3	main
essee	doc_802069853795_item	3581520	et	4	main
uus-aastasooviat	doc_802069853795_item	3581522	et	4	main
vanemad	doc_802069853795_item	3581530	et	4	main
soovivad	doc_802069853795_item	3581531	et	4	main
majat	doc_802069853795_item	3581547	et	4	main
uues	doc_802069853795_item	3581564	et	3	main
aastal	doc_802069853795_item	3581565	et	3	main
ei	doc_802069853795_item	3581577	et	4	main
inimesed	doc_802069853795_item	3581527	et	3	main
lapsed	doc_802069853795_item	3581528	et	3	main
ja	doc_802069853795_item	3581529	et	3	main
tihti	doc_802069853795_item	3581533	et	3	main
soovi	doc_802069853795_item	3581553	et	4	main
lapsed	doc_802069853795_item	3581554	et	3	main
tihti	doc_802069853795_item	3581555	et	3	main
soovivad	doc_802069853795_item	3581556	et	4	main
mänguasju	doc_802069853795_item	3581557	et	3	main
arvan	doc_802069853795_item	3581558	et	3	main
et	doc_802069853795_item	3581559	et	3	main
praegu	doc_802069853795_item	3581560	et	3	main
traditsiooni	doc_802069853795_item	3581561	et	4	main
soovima	doc_802069853795_item	3581562	et	4	main
midagi	doc_802069853795_item	3581563	et	4	main
kui	doc_802069853795_item	3581568	et	3	main
2	doc_802069853795_item	3581572	et	2	main
tagasi	doc_802069853795_item	3581575	et	3	main
mina	doc_802069853795_item	3581576	et	4	main
uues	doc_802069853795_item	3581581	et	3	main
ma	doc_802069853795_item	3581587	et	3	main
aeg	doc_802069853795_item	3581589	et	3	main
olla	doc_802069853795_item	3581595	et	3	main
ja	doc_802069853795_item	3581605	et	3	main
tore	doc_802069853795_item	3581610	et	3	main
minu	doc_802069853795_item	3581618	et	3	main
lootused	doc_802069853801_item	3581637	et	4	main
iga	doc_802069853801_item	3581640	et	4	main
parem	doc_802069853801_item	3581654	et	4	main
aru	doc_802069853801_item	3581661	et	4	main
et	doc_802069853801_item	3581662	et	3	main
üldiselt	doc_802069853801_item	3581663	et	4	main
uus	doc_802069853801_item	3581674	et	3	main
mulle	doc_802069853801_item	3581691	et	4	main
kui	doc_802069853801_item	3581694	et	3	main
ei	doc_802069853801_item	3581702	et	4	main
sõltu	doc_802069853801_item	3581703	et	4	main
aastast	doc_802069853801_item	3581704	et	4	main
et	doc_802069853801_item	3581705	et	3	main
mis	doc_802069853801_item	3581721	et	4	main
meiega	doc_802069853801_item	3581722	et	4	main
juhtub	doc_802069853801_item	3581723	et	3	main
aasta	doc_802069853801_item	3581724	et	4	main
parima	doc_802069853801_item	3581745	et	4	main
loodan	doc_802069853801_item	3581747	et	3	main
saama	doc_802069853801_item	3581750	et	4	main
palka	doc_802069853801_item	3581752	et	4	main
loodan	doc_802069853801_item	3581753	et	3	main
et	doc_802069853801_item	3581754	et	3	main
lõpetan	doc_802069853801_item	3581755	et	3	main
esimese	doc_802069853801_item	3581756	et	3	main
endale	doc_802069853801_item	3581762	et	4	main
suvel	doc_802069853801_item	3581766	et	3	main
hakkab	doc_802069853801_item	3581767	et	3	main
päike	doc_802069853801_item	3581768	et	3	main
siis	doc_802069853801_item	3581771	et	3	main
matkata	doc_802069853801_item	3581774	et	4	main
kõik	doc_802069853801_item	3581775	et	4	main
inimesed	doc_802069853801_item	3581776	et	3	main
uusaasta	doc_802069853804_item	3581802	et	4	main
aastal	doc_802069853804_item	3581805	et	3	main
ja	doc_802069853804_item	3581807	et	3	main
kooligid	doc_802069853804_item	3581809	et	4	main
se	doc_802069853804_item	3581814	et	4	main
vene	doc_802069853804_item	3581836	et	4	main
7	doc_802069853804_item	3581842	et	2	main
hakkavad	doc_802069853804_item	3581846	et	4	main
ja	doc_802069853804_item	3581848	et	3	main
ma	doc_802069853804_item	3581849	et	3	main
tahan	doc_802069853804_item	3581850	et	3	main
sooritada	doc_802069853804_item	3581851	et	3	main
kõik	doc_802069853804_item	3581852	et	4	main
tea	doc_802069853795_item	3581578	et	4	main
aga	doc_802069853795_item	3581583	et	3	main
et	doc_802069853795_item	3581585	et	3	main
aastal	doc_802069853795_item	3581591	et	3	main
võib	doc_802069853795_item	3581594	et	3	main
ma	doc_802069853795_item	3581599	et	3	main
veedan	doc_802069853795_item	3581603	et	3	main
aasta	doc_802069853795_item	3581607	et	4	main
ja	doc_802069853795_item	3581609	et	3	main
veeda	doc_802069853795_item	3581612	et	4	main
uue	doc_802069853795_item	3581613	et	3	main
kui	doc_802069853795_item	3581620	et	3	main
see	doc_802069853795_item	3581621	et	3	main
oli	doc_802069853795_item	3581622	et	3	main
tavaliselt	doc_802069853795_item	3581623	et	4	main
veel	doc_802069853795_item	3581624	et	4	main
soovin	doc_802069853795_item	3581625	et	3	main
et	doc_802069853795_item	3581626	et	3	main
jargmisel	doc_802069853795_item	3581627	et	4	main
aastal	doc_802069853795_item	3581629	et	3	main
2007	doc_802069853795_item	3581628	et	2	main
kõik	doc_802069853795_item	3581630	et	4	main
mul	doc_802069853795_item	3581631	et	3	main
olla	doc_802069853795_item	3581632	et	3	main
hästi	doc_802069853795_item	3581633	et	3	main
uues	doc_802069853801_item	3581638	et	3	main
aasta	doc_802069853801_item	3581642	et	4	main
kõik	doc_802069853801_item	3581643	et	4	main
edukam	doc_802069853801_item	3581656	et	4	main
aga	doc_802069853801_item	3581657	et	3	main
aasta	doc_802069853801_item	3581658	et	4	main
lõpus	doc_802069853801_item	3581659	et	4	main
aasta	doc_802069853801_item	3581664	et	4	main
oli	doc_802069853801_item	3581665	et	3	main
samasugune	doc_802069853801_item	3581666	et	3	main
nagu	doc_802069853801_item	3581667	et	3	main
kõik	doc_802069853801_item	3581668	et	4	main
eelmised	doc_802069853801_item	3581669	et	3	main
aastad	doc_802069853801_item	3581670	et	3	main
siis	doc_802069853801_item	3581671	et	3	main
ja	doc_802069853801_item	3581680	et	3	main
aru	doc_802069853801_item	3581699	et	4	main
et	doc_802069853801_item	3581700	et	3	main
me	doc_802069853801_item	3581706	et	4	main
heaks	doc_802069853801_item	3581710	et	4	main
kõik	doc_802069853801_item	3581720	et	4	main
muutub	doc_802069853801_item	3581738	et	3	main
leian	doc_802069853801_item	3581743	et	3	main
saan	doc_802069853801_item	3581760	et	4	main
on	doc_802069853801_item	3581772	et	4	main
meelest	doc_802069853801_item	3581781	et	4	main
see	doc_802069853801_item	3581782	et	3	main
uuelt	doc_802069853801_item	3581797	et	4	main
aastalt	doc_802069853801_item	3581798	et	3	main
aastas	doc_802069853801_item	3581639	et	3	main
aasta	doc_802069853801_item	3581649	et	4	main
on	doc_802069853801_item	3581650	et	4	main
ja	doc_802069853801_item	3581655	et	3	main
jälle	doc_802069853801_item	3581673	et	3	main
me	doc_802069853801_item	3581677	et	4	main
loodame	doc_802069853801_item	3581679	et	3	main
ootame	doc_802069853801_item	3581681	et	3	main
loodan	doc_802069853801_item	3581684	et	3	main
et	doc_802069853801_item	3581687	et	3	main
palju	doc_802069853801_item	3581692	et	4	main
paremat	doc_802069853801_item	3581693	et	4	main
muidugi	doc_802069853801_item	3581696	et	4	main
aasta	doc_802069853801_item	3581709	et	4	main
halvaks	doc_802069853801_item	3581712	et	4	main
sellest	doc_802069853801_item	3581715	et	4	main
kuidas	doc_802069853801_item	3581716	et	3	main
hoolimata	doc_802069853801_item	3581727	et	4	main
sellele	doc_802069853801_item	3581728	et	4	main
kõigile	doc_802069853801_item	3581729	et	4	main
ikkagi	doc_802069853801_item	3581731	et	4	main
ma	doc_802069853801_item	3581730	et	3	main
loodan	doc_802069853801_item	3581732	et	3	main
et	doc_802069853801_item	3581733	et	3	main
see	doc_802069853801_item	3581734	et	3	main
minu	doc_802069853801_item	3581736	et	3	main
keeruliselt	doc_802069853801_item	3581739	et	4	main
loodan	doc_802069853801_item	3581740	et	3	main
et	doc_802069853801_item	3581741	et	3	main
ma	doc_802069853801_item	3581742	et	3	main
hakkan	doc_802069853801_item	3581749	et	3	main
osta	doc_802069853801_item	3581761	et	4	main
auto	doc_802069853801_item	3581763	et	4	main
loodan	doc_802069853801_item	3581764	et	3	main
et	doc_802069853801_item	3581765	et	3	main
paistma	doc_802069853801_item	3581769	et	3	main
ongi	doc_802069853801_item	3581783	et	4	main
see	doc_802069853801_item	3581784	et	3	main
mis	doc_802069853801_item	3581785	et	4	main
meid	doc_802069853801_item	3581786	et	4	main
inimesi	doc_802069853801_item	3581787	et	4	main
loomadest	doc_802069853801_item	3581788	et	3	main
erineb	doc_802069853801_item	3581789	et	3	main
just	doc_802069853801_item	3581790	et	3	main
see	doc_802069853801_item	3581791	et	3	main
aitab	doc_802069853801_item	3581792	et	3	main
meil	doc_802069853801_item	3581793	et	4	main
saada	doc_802069853801_item	3581794	et	4	main
erinevaid	doc_802069853801_item	3581795	et	4	main
kingitusi	doc_802069853801_item	3581796	et	4	main
uuel	doc_802069853804_item	3581804	et	3	main
firma	doc_802069853804_item	3581816	et	4	main
saunasse	doc_802069853804_item	3581837	et	3	main
mul	doc_802069853804_item	3581838	et	3	main
tuleb	doc_802069853804_item	3581839	et	3	main
sõita	doc_802069853804_item	3581840	et	3	main
tagasi	doc_802069853804_item	3581841	et	3	main
sellepärast	doc_802069853804_item	3581844	et	3	main
eeriti	doc_802069853804_item	3581854	et	4	main
füüsika	doc_802069853804_item	3581855	et	4	main
kui	doc_802069853804_item	3581856	et	3	main
tuleb	doc_802069853804_item	3581857	et	3	main
iga	doc_873901597537_item	3581910	et	4	main
puduma	doc_873901597537_item	3581914	et	4	main
piidu	doc_873901597537_item	3581918	et	4	main
omaparune	doc_873901597537_item	3581920	et	4	main
peres	doc_873901597537_item	3581945	et	3	main
tavalisel	doc_873901597537_item	3581946	et	4	main
kingitus	doc_873901597537_item	3581951	et	4	main
soovita	doc_873901597537_item	3581953	et	4	main
õus	doc_873901597537_item	3581962	et	3	main
minu	doc_873901597537_item	3581965	et	3	main
iga	doc_873901597537_item	3581967	et	4	main
sõber	doc_873901597537_item	3581968	et	3	main
räkib	doc_873901597537_item	3581969	et	4	main
kuidas	doc_873901597537_item	3581970	et	3	main
aast	doc_873901597537_item	3581981	et	4	main
eksamid	doc_873901597537_item	3581984	et	3	main
ja	doc_873901597537_item	3581986	et	3	main
valimista	doc_873901597537_item	3581988	et	4	main
eksamid	doc_873901597537_item	3581989	et	3	main
palju	doc_802069853804_item	3581875	et	4	main
sõbrad	doc_802069853804_item	3581876	et	3	main
iga	doc_802069853804_item	3581877	et	4	main
aastal	doc_802069853804_item	3581878	et	3	main
me	doc_802069853804_item	3581879	et	4	main
kohtusime	doc_802069853804_item	3581880	et	4	main
aga	doc_802069853804_item	3581882	et	3	main
ma	doc_802069853804_item	3581883	et	3	main
sõidan	doc_802069853804_item	3581884	et	3	main
nendele	doc_802069853804_item	3581885	et	4	main
pskkovil	doc_802069853804_item	3581881	et	4	main
külla	doc_802069853804_item	3581886	et	4	main
ma	doc_802069853804_item	3581887	et	3	main
tahan	doc_802069853804_item	3581888	et	3	main
eesitada	doc_802069853804_item	3581889	et	4	main
teisele	doc_802069853804_item	3581890	et	4	main
kursusule	doc_802069853804_item	3581891	et	4	main
ja	doc_802069853804_item	3581892	et	3	main
teenite	doc_802069853804_item	3581893	et	3	main
palju	doc_802069853804_item	3581894	et	4	main
ained	doc_802069853804_item	3581895	et	3	main
punktid	doc_802069853804_item	3581896	et	4	main
soovid	doc_802069853804_item	3581803	et	4	main
mina	doc_802069853804_item	3581806	et	4	main
minu	doc_802069853804_item	3581808	et	3	main
sõidame	doc_802069853804_item	3581810	et	3	main
tuleb	doc_802069853804_item	3581815	et	3	main
vaheajad	doc_802069853804_item	3581817	et	3	main
ka	doc_802069853804_item	3581818	et	3	main
ma	doc_802069853804_item	3581819	et	3	main
sõdan	doc_802069853804_item	3581820	et	4	main
venemaale	doc_802069853804_item	3581821	et	4	main
minu	doc_802069853804_item	3581822	et	3	main
vanaemale	doc_802069853804_item	3581823	et	3	main
ja	doc_802069853804_item	3581824	et	3	main
vanaisale	doc_802069853804_item	3581825	et	3	main
ma	doc_802069853804_item	3581827	et	3	main
aitan	doc_802069853804_item	3581828	et	3	main
nendelt	doc_802069853804_item	3581829	et	4	main
ja	doc_802069853804_item	3581830	et	3	main
seal	doc_802069853804_item	3581826	et	4	main
puhkan	doc_802069853804_item	3581831	et	3	main
joon	doc_802069853804_item	3581832	et	4	main
elu	doc_802069853804_item	3581833	et	4	main
ja	doc_802069853804_item	3581834	et	3	main
minnen	doc_802069853804_item	3581835	et	4	main
eeksamid	doc_802069853804_item	3581853	et	4	main
siis	doc_802069853804_item	3581859	et	3	main
venemaale	doc_802069853804_item	3581862	et	4	main
sankt	doc_802069853804_item	3581864	et	4	main
peterbiri	doc_802069853804_item	3581865	et	4	main
on	doc_802069853804_item	3581874	et	4	main
pidu	doc_873901597537_item	3581909	et	4	main
valmistatud	doc_873901597537_item	3581916	et	4	main
alati	doc_873901597537_item	3581923	et	4	main
puhke	doc_873901597537_item	3581938	et	4	main
aeg	doc_873901597537_item	3581939	et	3	main
ja	doc_873901597537_item	3581940	et	3	main
ma	doc_873901597537_item	3581941	et	3	main
läheb	doc_873901597537_item	3581942	et	3	main
koju	doc_873901597537_item	3581943	et	3	main
minu	doc_873901597537_item	3581944	et	3	main
teisele	doc_873901597537_item	3581955	et	4	main
õnne	doc_873901597537_item	3581956	et	4	main
et	doc_873901597537_item	3581963	et	3	main
magama	doc_873901597537_item	3581979	et	3	main
jõulu	doc_873901597544_item	3581995	et	4	main
ajas	doc_873901597544_item	3581996	et	4	main
kõige	doc_873901597544_item	3581998	et	4	main
toredam	doc_873901597544_item	3581999	et	4	main
sest	doc_873901597544_item	3582004	et	4	main
selle	doc_873901597544_item	3582008	et	4	main
üks	doc_873901597544_item	3582019	et	3	main
mõttetest	doc_873901597544_item	3582021	et	3	main
mu	doc_873901597544_item	3582023	et	3	main
perekond	doc_873901597544_item	3582024	et	3	main
tähtsam	doc_873901597544_item	3582029	et	4	main
minu	doc_873901597544_item	3582030	et	3	main
vanematega	doc_873901597544_item	3582040	et	4	main
ja	doc_873901597544_item	3582041	et	3	main
nagu	doc_873901597544_item	3582047	et	3	main
arvan	doc_873901597544_item	3582051	et	3	main
peo	doc_873901597544_item	3582062	et	4	main
pärast	doc_873901597544_item	3582063	et	4	main
holitseda	doc_873901597544_item	3582066	et	4	main
kõige	doc_873901597544_item	3582077	et	4	main
sõprad	doc_873901597544_item	3582084	et	4	main
pidu	doc_873901597544_item	3582092	et	4	main
mõtlema	doc_873901597544_item	3582104	et	3	main
valge	doc_873901597544_item	3582119	et	4	main
lumi	doc_873901597544_item	3582120	et	3	main
kaunistab	doc_873901597544_item	3582121	et	3	main
talv	doc_873901597544_item	3582128	et	3	main
paremast	doc_873901597544_item	3582142	et	4	main
asjadest	doc_873901597544_item	3582143	et	3	main
ja	doc_873901597544_item	3582144	et	3	main
juba	doc_873901597547_item	3582165	et	3	main
aga	doc_873901597547_item	3582167	et	3	main
on	doc_873901597547_item	3582181	et	4	main
üks	doc_873901597547_item	3582182	et	3	main
kõik	doc_873901597547_item	3582194	et	4	main
perega	doc_873901597547_item	3582210	et	3	main
siiski	doc_873901597547_item	3582211	et	4	main
istun	doc_873901597547_item	3582219	et	3	main
kallidega	doc_873901597547_item	3582220	et	4	main
siis	doc_873901597547_item	3582221	et	3	main
ma	doc_873901597547_item	3582231	et	3	main
valmistamine	doc_873901597547_item	3582240	et	4	main
jaoks	doc_873901597547_item	3582241	et	4	main
mulle	doc_873901597547_item	3582242	et	4	main
meeldib	doc_873901597547_item	3582243	et	3	main
see	doc_873901597547_item	3582244	et	3	main
jõulu	doc_873901597547_item	3582245	et	4	main
atmosfäär	doc_873901597547_item	3582246	et	3	main
millal	doc_873901597547_item	3582247	et	3	main
inimesed	doc_873901597547_item	3582248	et	3	main
naeratavad	doc_873901597547_item	3582249	et	4	main
teine	doc_873901597547_item	3582250	et	3	main
rohkem	doc_873901597547_item	3582256	et	4	main
jõulu	doc_873901597547_item	3582262	et	4	main
ja	doc_873901597547_item	3582271	et	3	main
sellel	doc_873901597547_item	3582272	et	4	main
ostavad	doc_873901597547_item	3582283	et	3	main
ehted	doc_873901597547_item	3582284	et	3	main
et	doc_873901597547_item	3582285	et	3	main
kõik	doc_873901597547_item	3582291	et	4	main
kõige	doc_873901597547_item	3582295	et	4	main
essee	doc_873901597551_item	3582340	et	4	main
jõulumõtted	doc_873901597537_item	3581900	et	3	main
tuleb	doc_873901597537_item	3581902	et	3	main
jõuluaeg	doc_873901597537_item	3581903	et	3	main
riikas	doc_873901597537_item	3581911	et	4	main
iga	doc_873901597537_item	3581912	et	4	main
teegib	doc_873901597537_item	3581924	et	4	main
indeika	doc_873901597537_item	3581925	et	4	main
jõuludel	doc_873901597537_item	3581926	et	3	main
ma	doc_873901597537_item	3581927	et	3	main
mõtlen	doc_873901597537_item	3581928	et	3	main
et	doc_873901597537_item	3581929	et	3	main
minu	doc_873901597537_item	3581930	et	3	main
jõuluaeg	doc_873901597537_item	3581931	et	3	main
tuleb	doc_873901597537_item	3581932	et	3	main
tavaliset	doc_873901597537_item	3581933	et	4	main
seelel	doc_873901597537_item	3581934	et	4	main
ajal	doc_873901597537_item	3581935	et	4	main
mul	doc_873901597537_item	3581936	et	3	main
on	doc_873901597537_item	3581937	et	4	main
kingima	doc_873901597537_item	3581950	et	4	main
teine	doc_873901597537_item	3581954	et	3	main
ja	doc_873901597537_item	3581957	et	3	main
mina	doc_873901597537_item	3581960	et	4	main
tuleb	doc_873901597537_item	3581961	et	3	main
tuleb	doc_873901597537_item	3581977	et	3	main
koju	doc_873901597537_item	3581978	et	3	main
on	doc_873901597537_item	3581983	et	4	main
mõttet	doc_873901597544_item	3581994	et	4	main
asjadest	doc_873901597544_item	3582017	et	3	main
jõulut	doc_873901597544_item	3582035	et	4	main
ja	doc_873901597544_item	3582036	et	3	main
uut	doc_873901597544_item	3582037	et	3	main
aastat	doc_873901597544_item	3582038	et	3	main
oma	doc_873901597544_item	3582039	et	4	main
see	doc_873901597544_item	3582045	et	3	main
ja	doc_873901597544_item	3582049	et	3	main
see	doc_873901597544_item	3582053	et	3	main
edasi	doc_873901597544_item	3582056	et	3	main
mõtlema	doc_873901597544_item	3582059	et	3	main
eest	doc_873901597544_item	3582068	et	4	main
pidu	doc_873901597544_item	3582069	et	4	main
küll	doc_873901597544_item	3582072	et	4	main
tore	doc_873901597544_item	3582073	et	3	main
aga	doc_873901597544_item	3582074	et	3	main
veel	doc_873901597544_item	3582079	et	4	main
üks	doc_873901597544_item	3582080	et	3	main
mu	doc_873901597544_item	3582081	et	3	main
mõtte	doc_873901597544_item	3582082	et	3	main
see	doc_873901597544_item	3582086	et	3	main
oluline	doc_873901597544_item	3582091	et	4	main
on	doc_873901597544_item	3582093	et	4	main
tähtis	doc_873901597544_item	3582094	et	4	main
ka	doc_873901597544_item	3582095	et	3	main
sõpradega	doc_873901597544_item	3582096	et	3	main
olla	doc_873901597544_item	3582097	et	3	main
kas	doc_873901597544_item	3582098	et	3	main
pole	doc_873901597544_item	3582099	et	3	main
nii	doc_873901597544_item	3582100	et	3	main
siis	doc_873901597544_item	3582101	et	3	main
ilma	doc_873901597544_item	3582105	et	4	main
maa	doc_873901597544_item	3582122	et	4	main
ma	doc_873901597544_item	3582123	et	3	main
arvan	doc_873901597544_item	3582124	et	3	main
et	doc_873901597544_item	3582125	et	3	main
ainult	doc_873901597544_item	3582140	et	4	main
ka	doc_873901597544_item	3582146	et	3	main
terveks	doc_873901597537_item	3581958	et	4	main
ta	doc_873901597537_item	3581971	et	4	main
õpib	doc_873901597537_item	3581972	et	3	main
ja	doc_873901597537_item	3581973	et	3	main
elab	doc_873901597537_item	3581974	et	3	main
parast	doc_873901597537_item	3581975	et	3	main
ma	doc_873901597537_item	3581976	et	3	main
seelel	doc_873901597537_item	3581980	et	4	main
jõulu	doc_873901597544_item	3581993	et	4	main
on	doc_873901597544_item	3581997	et	4	main
ma	doc_873901597544_item	3582002	et	3	main
kui	doc_873901597544_item	3582005	et	3	main
näiteks	doc_873901597544_item	3582018	et	4	main
minust	doc_873901597544_item	3582020	et	3	main
on	doc_873901597544_item	3582022	et	4	main
miks	doc_873901597544_item	3582025	et	4	main
see	doc_873901597544_item	3582026	et	3	main
on	doc_873901597544_item	3582027	et	4	main
jaoks	doc_873901597544_item	3582031	et	4	main
sest	doc_873901597544_item	3582032	et	4	main
ma	doc_873901597544_item	3582033	et	3	main
kahe	doc_873901597544_item	3582042	et	3	main
on	doc_873901597544_item	3582046	et	4	main
traditsioon	doc_873901597544_item	3582048	et	3	main
alatiselt	doc_873901597544_item	3582055	et	4	main
ma	doc_873901597544_item	3582057	et	3	main
on	doc_873901597544_item	3582064	et	4	main
õppimine	doc_873901597544_item	3582075	et	4	main
on	doc_873901597544_item	3582083	et	4	main
ma	doc_873901597544_item	3582102	et	3	main
eest	doc_873901597544_item	3582106	et	4	main
jõulu	doc_873901597544_item	3582107	et	4	main
on	doc_873901597544_item	3582109	et	4	main
see	doc_873901597544_item	3582114	et	3	main
ja	doc_873901597544_item	3582129	et	3	main
peod	doc_873901597544_item	3582130	et	4	main
see	doc_873901597544_item	3582133	et	3	main
on	doc_873901597544_item	3582135	et	4	main
mina	doc_873901597544_item	3582145	et	4	main
inimene	doc_873901597544_item	3582148	et	3	main
jõulu	doc_873901597547_item	3582164	et	4	main
ei	doc_873901597547_item	3582170	et	4	main
mida	doc_873901597547_item	3582172	et	4	main
tähendavad	doc_873901597547_item	3582185	et	4	main
pidu	doc_873901597547_item	3582186	et	4	main
aastas	doc_873901597547_item	3582187	et	3	main
inimesed	doc_873901597547_item	3582195	et	3	main
perepidu	doc_873901597547_item	3582214	et	4	main
jah	doc_873901597547_item	3582215	et	3	main
kui	doc_873901597547_item	3582216	et	3	main
ma	doc_873901597547_item	3582217	et	3	main
sõbradega	doc_873901597547_item	3582229	et	4	main
ja	doc_873901597547_item	3582234	et	3	main
teist	doc_873901597547_item	3582251	et	4	main
mulle	doc_873901597547_item	3582257	et	4	main
on	doc_873901597547_item	3582268	et	4	main
valmistama	doc_873901597547_item	3582276	et	3	main
ilusam	doc_873901597547_item	3582289	et	4	main
ja	doc_873901597547_item	3582290	et	3	main
aastal	doc_873901597551_item	3582344	et	3	main
sest	doc_873901597551_item	3582351	et	4	main
2-teisel	doc_873901597551_item	3582352	et	4	main
jaanuaril	doc_873901597551_item	3582353	et	3	main
pidutsema	doc_873901597551_item	3582362	et	3	main
niikaua	doc_873901597551_item	3582363	et	3	main
kui	doc_873901597551_item	3582364	et	3	main
vaja	doc_873901597551_item	3582365	et	4	main
üsna	doc_873901597551_item	3582369	et	3	main
perega	doc_873901597551_item	3582379	et	3	main
ega	doc_873901597551_item	3582381	et	3	main
puudub	doc_873901597551_item	3582385	et	3	main
aasta	doc_873901597551_item	3582388	et	4	main
aja	doc_873901597551_item	3582429	et	4	main
kuidas	doc_873901597551_item	3582440	et	3	main
mis	doc_873901597551_item	3582452	et	4	main
sooritatud	doc_873901597551_item	3582468	et	4	main
ja	doc_873901597551_item	3582469	et	3	main
essee	doc_873901597553_item	3582484	et	4	main
varsti	doc_873901597553_item	3582491	et	3	main
tuleb	doc_873901597553_item	3582492	et	3	main
detsember	doc_873901597553_item	3582493	et	3	main
jõulupühid	doc_873901597553_item	3582494	et	4	main
mälitatud	doc_873901597544_item	3582156	et	4	main
kogu	doc_873901597544_item	3582157	et	4	main
elu	doc_873901597544_item	3582158	et	4	main
ajal	doc_873901597544_item	3582159	et	4	main
minu	doc_873901597544_item	3581992	et	3	main
mis	doc_873901597544_item	3582001	et	4	main
tean	doc_873901597544_item	3582003	et	3	main
aeg	doc_873901597544_item	3582006	et	3	main
peo	doc_873901597544_item	3582009	et	4	main
juurde	doc_873901597544_item	3582010	et	4	main
siis	doc_873901597544_item	3582011	et	3	main
ma	doc_873901597544_item	3582012	et	3	main
hakkan	doc_873901597544_item	3582013	et	3	main
mõtlema	doc_873901597544_item	3582014	et	3	main
ainult	doc_873901597544_item	3582015	et	4	main
headest	doc_873901597544_item	3582016	et	3	main
kõige	doc_873901597544_item	3582028	et	4	main
vennatega	doc_873901597544_item	3582044	et	4	main
vaja	doc_873901597544_item	3582065	et	4	main
on	doc_873901597544_item	3582076	et	4	main
on	doc_873901597544_item	3582087	et	4	main
õige	doc_873901597544_item	3582088	et	4	main
sest	doc_873901597544_item	3582089	et	4	main
iga	doc_873901597544_item	3582090	et	4	main
seda	doc_873901597544_item	3582071	et	3	main
ette	doc_873901597544_item	3582078	et	4	main
ja	doc_873901597544_item	3582085	et	3	main
hakkan	doc_873901597544_item	3582103	et	3	main
tihti	doc_873901597544_item	3582110	et	3	main
palju	doc_873901597544_item	3582111	et	4	main
lund	doc_873901597544_item	3582112	et	3	main
ja	doc_873901597544_item	3582113	et	3	main
on	doc_873901597544_item	3582115	et	4	main
nii	doc_873901597544_item	3582116	et	3	main
ilus	doc_873901597544_item	3582117	et	4	main
kui	doc_873901597544_item	3582118	et	3	main
sümbooliseerib	doc_873901597544_item	3582127	et	4	main
kui	doc_873901597544_item	3582132	et	3	main
aeg	doc_873901597544_item	3582134	et	3	main
kõigest	doc_873901597544_item	3582141	et	4	main
minu	doc_873901597547_item	3582162	et	3	main
veel	doc_873901597547_item	3582168	et	4	main
piduma	doc_873901597547_item	3582176	et	4	main
palju	doc_873901597547_item	3582188	et	4	main
ja	doc_873901597547_item	3582196	et	3	main
on	doc_873901597547_item	3582213	et	4	main
jalutama	doc_873901597547_item	3582226	et	3	main
koos	doc_873901597547_item	3582227	et	4	main
minu	doc_873901597547_item	3582228	et	3	main
jõulus	doc_873901597547_item	3582233	et	3	main
mul	doc_873901597547_item	3582235	et	3	main
kõikidele	doc_873901597547_item	3582254	et	4	main
selles	doc_873901597547_item	3582263	et	4	main
aastas	doc_873901597547_item	3582264	et	3	main
pärast	doc_873901597547_item	3582265	et	4	main
jõulu	doc_873901597547_item	3582266	et	4	main
mul	doc_873901597547_item	3582267	et	3	main
ma	doc_873901597547_item	3582274	et	3	main
pakkivad	doc_873901597547_item	3582293	et	4	main
sel	doc_873901597551_item	3582343	et	3	main
mõtted	doc_873901597551_item	3582347	et	3	main
õppes	doc_873901597551_item	3582350	et	3	main
puhata	doc_873901597551_item	3582359	et	4	main
rohkem	doc_873901597551_item	3582360	et	4	main
ja	doc_873901597551_item	3582361	et	3	main
kas	doc_873901597551_item	3582371	et	3	main
aasta	doc_873901597551_item	3582374	et	4	main
sõbradega	doc_873901597551_item	3582376	et	4	main
või	doc_873901597551_item	3582377	et	4	main
aga	doc_873901597551_item	3582386	et	3	main
endale	doc_873901597551_item	3582428	et	4	main
saaks	doc_873901597551_item	3582432	et	3	main
kuidagi	doc_873901597551_item	3582434	et	3	main
välismaale	doc_873901597551_item	3582436	et	4	main
sõbradega	doc_873901597551_item	3582438	et	4	main
näha	doc_873901597551_item	3582439	et	3	main
ajas	doc_873901597544_item	3582108	et	4	main
jõuluaeg	doc_873901597544_item	3582126	et	3	main
ja	doc_873901597544_item	3582131	et	3	main
käis	doc_873901597544_item	3582136	et	4	main
siis	doc_873901597544_item	3582137	et	3	main
inimesed	doc_873901597544_item	3582138	et	3	main
mõtlevad	doc_873901597544_item	3582139	et	4	main
iga	doc_873901597544_item	3582147	et	4	main
tahab	doc_873901597544_item	3582149	et	3	main
et	doc_873901597544_item	3582150	et	3	main
peod	doc_873901597544_item	3582151	et	4	main
oleks	doc_873901597544_item	3582152	et	3	main
tore	doc_873901597544_item	3582153	et	3	main
ja	doc_873901597544_item	3582154	et	3	main
oleks	doc_873901597544_item	3582155	et	3	main
essee	doc_873901597547_item	3582161	et	4	main
ma	doc_873901597547_item	3582169	et	3	main
kuidas	doc_873901597547_item	3582175	et	3	main
selle	doc_873901597547_item	3582177	et	4	main
tore	doc_873901597547_item	3582178	et	3	main
pidu	doc_873901597547_item	3582179	et	4	main
see	doc_873901597547_item	3582180	et	3	main
kasvad	doc_873901597547_item	3582189	et	3	main
ja	doc_873901597547_item	3582190	et	3	main
lapsed	doc_873901597547_item	3582191	et	3	main
ootab	doc_873901597547_item	3582192	et	3	main
jõulu	doc_873901597547_item	3582193	et	4	main
koos	doc_873901597547_item	3582208	et	4	main
minu	doc_873901597547_item	3582209	et	3	main
natuke	doc_873901597547_item	3582218	et	4	main
kahjuks	doc_873901597547_item	3582230	et	4	main
ole	doc_873901597547_item	3582237	et	4	main
ja	doc_873901597547_item	3582252	et	3	main
rõõmustavad	doc_873901597547_item	3582253	et	4	main
meeldib	doc_873901597547_item	3582258	et	3	main
uus	doc_873901597547_item	3582259	et	3	main
aasta	doc_873901597547_item	3582260	et	4	main
ei	doc_873901597547_item	3582313	et	4	main
tea	doc_873901597547_item	3582314	et	4	main
mida	doc_873901597547_item	3582315	et	4	main
kingitema	doc_873901597547_item	3582316	et	4	main
nendele	doc_873901597547_item	3582317	et	4	main
jõulus	doc_873901597547_item	3582318	et	3	main
palju	doc_873901597547_item	3582319	et	4	main
inimesed	doc_873901597547_item	3582320	et	3	main
ootavad	doc_873901597547_item	3582321	et	4	main
hea	doc_873901597547_item	3582322	et	4	main
ja	doc_873901597547_item	3582323	et	3	main
soovitavad	doc_873901597547_item	3582324	et	4	main
palju	doc_873901597547_item	3582325	et	4	main
head	doc_873901597547_item	3582326	et	4	main
ja	doc_873901597547_item	3582327	et	3	main
õnne	doc_873901597547_item	3582328	et	4	main
oma	doc_873901597547_item	3582329	et	4	main
sõbrale	doc_873901597547_item	3582330	et	3	main
ma	doc_873901597547_item	3582331	et	3	main
loodan	doc_873901597547_item	3582332	et	3	main
et	doc_873901597547_item	3582333	et	3	main
sellel	doc_873901597547_item	3582334	et	4	main
ajal	doc_873901597547_item	3582335	et	4	main
soovid	doc_873901597547_item	3582336	et	4	main
täitusid	doc_873901597547_item	3582337	et	4	main
kõikide	doc_873901597547_item	3582338	et	4	main
jõulumõtted	doc_873901597547_item	3582163	et	3	main
varsti	doc_873901597547_item	3582166	et	3	main
tea	doc_873901597547_item	3582171	et	4	main
teha	doc_873901597547_item	3582173	et	3	main
ja	doc_873901597547_item	3582174	et	3	main
suurtes	doc_873901597547_item	3582183	et	3	main
ja	doc_873901597547_item	3582184	et	3	main
mina	doc_873901597547_item	3582197	et	4	main
ka	doc_873901597547_item	3582198	et	3	main
armastame	doc_873901597547_item	3582199	et	3	main
kingitused	doc_873901597547_item	3582200	et	4	main
saavutama	doc_873901597547_item	3582201	et	3	main
võib	doc_873901597547_item	3582202	et	3	main
olla	doc_873901597547_item	3582203	et	3	main
ma	doc_873901597547_item	3582204	et	3	main
pidun	doc_873901597547_item	3582205	et	4	main
see	doc_873901597547_item	3582206	et	3	main
pidu	doc_873901597547_item	3582207	et	4	main
jõulu	doc_873901597547_item	3582212	et	4	main
pärast	doc_873901597547_item	3582222	et	4	main
ma	doc_873901597547_item	3582223	et	3	main
tahan	doc_873901597547_item	3582224	et	3	main
minna	doc_873901597547_item	3582225	et	3	main
töötan	doc_873901597547_item	3582232	et	3	main
ei	doc_873901597547_item	3582236	et	4	main
piisav	doc_873901597547_item	3582238	et	4	main
aega	doc_873901597547_item	3582239	et	4	main
asja	doc_873901597547_item	3582255	et	4	main
kui	doc_873901597547_item	3582261	et	3	main
nädalal	doc_873901597547_item	3582273	et	3	main
sessijaks	doc_873901597547_item	3582277	et	4	main
ja	doc_873901597547_item	3582279	et	3	main
minu	doc_873901597547_item	3582280	et	3	main
sõbrad	doc_873901597547_item	3582281	et	3	main
oma	doc_873901597547_item	3582287	et	4	main
maja	doc_873901597547_item	3582288	et	4	main
kingitused	doc_873901597547_item	3582294	et	4	main
raskem	doc_873901597547_item	3582296	et	4	main
minu	doc_873901597547_item	3582297	et	3	main
jaoks	doc_873901597547_item	3582298	et	4	main
valida	doc_873901597547_item	3582299	et	3	main
jõulu	doc_873901597551_item	3582341	et	4	main
jõulu	doc_873901597551_item	3582346	et	4	main
on	doc_873901597551_item	3582348	et	4	main
täitsa	doc_873901597551_item	3582349	et	3	main
küll	doc_873901597551_item	3582357	et	4	main
tahaks	doc_873901597551_item	3582358	et	3	main
on	doc_873901597551_item	3582368	et	4	main
koos	doc_873901597551_item	3582378	et	4	main
kodus	doc_873901597551_item	3582380	et	4	main
jõulu	doc_873901597551_item	3582382	et	4	main
õhustik	doc_873901597551_item	3582383	et	3	main
üldse	doc_873901597551_item	3582384	et	3	main
see	doc_873901597551_item	3582387	et	3	main
mu	doc_873901597551_item	3582442	et	3	main
on	doc_873901597551_item	3582445	et	4	main
olukord	doc_873901597551_item	3582446	et	3	main
teises	doc_873901597551_item	3582447	et	4	main
riigis	doc_873901597551_item	3582448	et	3	main
raske	doc_873901597551_item	3582449	et	4	main
tuleb	doc_873901597551_item	3582453	et	3	main
minu	doc_873901597551_item	3582457	et	3	main
tuleb	doc_873901597551_item	3582459	et	3	main
veel	doc_873901597551_item	3582461	et	4	main
tahan	doc_873901597551_item	3582462	et	3	main
et	doc_873901597551_item	3582463	et	3	main
kõik	doc_873901597551_item	3582464	et	4	main
kahjuks	doc_873901597553_item	3582495	et	4	main
et	doc_873901597553_item	3582496	et	3	main
lund	doc_873901597553_item	3582497	et	3	main
tegime	doc_873901597553_item	3582508	et	3	main
lumememme	doc_873901597553_item	3582509	et	4	main
uisutasime	doc_873901597553_item	3582510	et	3	main
aga	doc_873901597553_item	3582518	et	3	main
õues	doc_873901597553_item	3582520	et	4	main
mulle	doc_873901597553_item	3582523	et	4	main
kohkem	doc_873901597553_item	3582524	et	4	main
meeldib	doc_873901597553_item	3582525	et	3	main
õues	doc_873901597553_item	3582529	et	4	main
essee	doc_873901597564_item	3582583	et	4	main
käib	doc_873901597564_item	3582591	et	3	main
2006	doc_873901597564_item	3582602	et	2	main
meelde	doc_873901597564_item	3582606	et	3	main
muidugi	doc_873901597564_item	3582612	et	4	main
kõik	doc_873901597564_item	3582616	et	4	main
õppin	doc_873901597564_item	3582645	et	4	main
siin	doc_873901597564_item	3582646	et	4	main
2006	doc_873901597564_item	3582647	et	2	main
sõitideses	doc_873901597564_item	3582651	et	4	main
suvi	doc_873901597564_item	3582653	et	3	main
pepsi	doc_873901597564_item	3582659	et	4	main
telkidega	doc_873901597564_item	3582661	et	3	main
kuulsime	doc_873901597564_item	3582668	et	3	main
algavad	doc_873901597547_item	3582269	et	4	main
vaheaeg	doc_873901597547_item	3582270	et	3	main
pean	doc_873901597547_item	3582275	et	4	main
mina	doc_873901597547_item	3582278	et	4	main
juba	doc_873901597547_item	3582282	et	3	main
teha	doc_873901597547_item	3582286	et	3	main
juba	doc_873901597547_item	3582292	et	3	main
hea	doc_873901597547_item	3582300	et	4	main
kingitused	doc_873901597547_item	3582301	et	4	main
sõbrale	doc_873901597547_item	3582302	et	3	main
ja	doc_873901597547_item	3582303	et	3	main
kallile	doc_873901597547_item	3582304	et	3	main
mul	doc_873901597547_item	3582305	et	3	main
on	doc_873901597547_item	3582306	et	4	main
palju	doc_873901597547_item	3582307	et	4	main
ja	doc_873901597547_item	3582309	et	3	main
vennaõe	doc_873901597547_item	3582310	et	3	main
et	doc_873901597547_item	3582311	et	3	main
ma	doc_873901597547_item	3582312	et	3	main
vennapoeg	doc_873901597547_item	3582308	et	3	main
ajal	doc_873901597551_item	3582423	et	4	main
kuidas	doc_873901597551_item	3582424	et	3	main
mul	doc_873901597551_item	3582425	et	3	main
järgmisel	doc_873901597551_item	3582426	et	3	main
aastal	doc_873901597551_item	3582427	et	3	main
mõtted	doc_873901597551_item	3582342	et	3	main
on	doc_873901597551_item	3582354	et	4	main
eksam	doc_873901597551_item	3582356	et	3	main
erinevad	doc_873901597551_item	3582370	et	4	main
uue	doc_873901597551_item	3582373	et	3	main
oma	doc_873901597551_item	3582375	et	4	main
minu	doc_873901597551_item	3582390	et	3	main
jaoks	doc_873901597551_item	3582391	et	4	main
normaalne	doc_873901597551_item	3582392	et	3	main
võib	doc_873901597551_item	3582393	et	3	main
olla	doc_873901597551_item	3582394	et	3	main
lähen	doc_873901597551_item	3582395	et	3	main
ja	doc_873901597551_item	3582397	et	3	main
ostan	doc_873901597551_item	3582398	et	3	main
kellegile	doc_873901597551_item	3582399	et	4	main
poodi	doc_873901597551_item	3582396	et	4	main
kinki	doc_873901597551_item	3582400	et	4	main
mulle	doc_873901597551_item	3582401	et	4	main
meeldib	doc_873901597551_item	3582402	et	3	main
valida	doc_873901597551_item	3582403	et	3	main
aga	doc_873901597551_item	3582404	et	3	main
ei	doc_873901597551_item	3582405	et	4	main
meeldi	doc_873901597551_item	3582406	et	4	main
kaua	doc_873901597551_item	3582407	et	3	main
poes	doc_873901597551_item	3582408	et	3	main
käia	doc_873901597551_item	3582409	et	4	main
panen	doc_873901597551_item	3582410	et	3	main
aknale	doc_873901597551_item	3582411	et	3	main
eliktri	doc_873901597551_item	3582412	et	4	main
küünlad	doc_873901597551_item	3582413	et	3	main
ema	doc_873901597551_item	3582414	et	4	main
kattab	doc_873901597551_item	3582415	et	4	main
laua	doc_873901597551_item	3582416	et	3	main
teeb	doc_873901597551_item	3582417	et	3	main
palju	doc_873901597551_item	3582418	et	4	main
süüa	doc_873901597551_item	3582419	et	3	main
ma	doc_873901597551_item	3582420	et	3	main
mõtlen	doc_873901597551_item	3582421	et	3	main
jõulude	doc_873901597551_item	3582422	et	3	main
panna	doc_873901597551_item	3582430	et	4	main
ikka	doc_873901597551_item	3582433	et	4	main
sõita	doc_873901597551_item	3582435	et	3	main
öelda	doc_873901597551_item	3582450	et	4	main
aga	doc_873901597551_item	3582455	et	3	main
soov	doc_873901597551_item	3582458	et	3	main
jõulumõtted	doc_873901597553_item	3582486	et	3	main
ei	doc_873901597553_item	3582498	et	4	main
lumepalli	doc_873901597553_item	3582507	et	4	main
oli	doc_873901597553_item	3582514	et	3	main
mu	doc_873901597551_item	3582345	et	3	main
esimene	doc_873901597551_item	3582355	et	3	main
on	doc_873901597551_item	3582366	et	4	main
mõtted	doc_873901597551_item	3582367	et	3	main
kohtuda	doc_873901597551_item	3582372	et	3	main
oli	doc_873901597551_item	3582389	et	3	main
et	doc_873901597551_item	3582431	et	3	main
oma	doc_873901597551_item	3582437	et	4	main
sugulased	doc_873901597551_item	3582443	et	3	main
milline	doc_873901597551_item	3582444	et	3	main
edasi	doc_873901597551_item	3582454	et	3	main
reaalselt	doc_873901597551_item	3582460	et	4	main
minu	doc_873901597553_item	3582485	et	3	main
november	doc_873901597553_item	3582489	et	3	main
kuu	doc_873901597553_item	3582490	et	4	main
lapsepõlve	doc_873901597553_item	3582503	et	4	main
kuidas	doc_873901597553_item	3582504	et	3	main
me	doc_873901597553_item	3582505	et	4	main
mängisime	doc_873901597553_item	3582506	et	3	main
see	doc_873901597553_item	3582513	et	3	main
tore	doc_873901597553_item	3582516	et	3	main
praegune	doc_873901597553_item	3582526	et	3	main
on	doc_873901597553_item	3582530	et	4	main
poolest	doc_873901597564_item	3582585	et	4	main
2006	doc_873901597564_item	3582590	et	2	main
uus	doc_873901597564_item	3582592	et	3	main
aasta	doc_873901597564_item	3582594	et	4	main
ta	doc_873901597564_item	3582595	et	4	main
algusi	doc_873901597564_item	3582599	et	3	main
head	doc_873901597564_item	3582613	et	4	main
minu	doc_873901597564_item	3582617	et	3	main
soovitused	doc_873901597564_item	3582618	et	4	main
kooli	doc_873901597564_item	3582622	et	4	main
hästi	doc_873901597564_item	3582624	et	3	main
ma	doc_873901597564_item	3582626	et	3	main
teised	doc_873901597564_item	3582632	et	4	main
ttü-s	doc_873901597564_item	3582636	et	3	main
tahaksin	doc_873901597564_item	3582641	et	3	main
õppida	doc_873901597564_item	3582642	et	3	main
praegu	doc_873901597564_item	3582644	et	3	main
tegisime	doc_873901597564_item	3582666	et	4	main
lobisime	doc_873901597564_item	3582670	et	4	main
oli	doc_873901597564_item	3582672	et	3	main
aga	doc_873901597564_item	3582674	et	3	main
rakveresse	doc_873901597564_item	3582685	et	4	main
ja	doc_873901597564_item	3582687	et	3	main
mitmedes	doc_873901597564_item	3582688	et	4	main
mööda	doc_873901597564_item	3582703	et	4	main
rohkem	doc_873901597564_item	3582713	et	4	main
halba	doc_873901597564_item	3582714	et	4	main
kontserdil	doc_919500587383_item	3582760	et	3	main
see	doc_919500587383_item	3582774	et	3	main
eestis	doc_919500587383_item	3582779	et	3	main
mulle	doc_919500587383_item	3582780	et	4	main
kõik	doc_919500587383_item	3582782	et	4	main
eesti	doc_919500587383_item	3582783	et	4	main
pool	doc_919500587383_item	3582795	et	4	main
keel	doc_919500587383_item	3582807	et	4	main
tahtsin	doc_919500587383_item	3582815	et	3	main
minna	doc_919500587383_item	3582817	et	3	main
et	doc_919500587383_item	3582821	et	3	main
on	doc_919500587383_item	3582830	et	4	main
raske	doc_919500587383_item	3582837	et	4	main
siin	doc_919500587383_item	3582838	et	4	main
elada	doc_919500587383_item	3582839	et	3	main
külmem	doc_919500587383_item	3582842	et	4	main
meeldib	doc_919500587383_item	3582845	et	3	main
ja	doc_919500587383_item	3582852	et	3	main
on	doc_919500587383_item	3582856	et	4	main
mõnikord	doc_919500587383_item	3582857	et	3	main
raske	doc_919500587383_item	3582858	et	4	main
tellida	doc_919500587383_item	3582861	et	3	main
siin	doc_919500587383_item	3582874	et	4	main
tule	doc_919500587383_item	3582878	et	4	main
välja	doc_919500587383_item	3582907	et	4	main
oleks	doc_919500587383_item	3582910	et	3	main
sarnased	doc_919500587383_item	3582912	et	4	main
eesti	doc_919500587383_item	3582913	et	4	main
õlu	doc_919500587383_item	3582914	et	3	main
mitu	doc_919500587383_item	3582920	et	4	main
pärast	doc_919500587383_item	3582923	et	4	main
ja	doc_919500587383_item	3582937	et	3	main
elavad	doc_873901597551_item	3582441	et	4	main
ikka	doc_873901597551_item	3582451	et	4	main
äkki	doc_873901597551_item	3582456	et	3	main
ained	doc_873901597551_item	3582465	et	3	main
mul	doc_873901597551_item	3582466	et	3	main
oleksid	doc_873901597551_item	3582467	et	4	main
polnudki	doc_873901597551_item	3582470	et	3	main
probleemi	doc_873901597551_item	3582471	et	4	main
nende	doc_873901597551_item	3582472	et	4	main
sooritamisega	doc_873901597551_item	3582473	et	4	main
püüan	doc_873901597551_item	3582474	et	3	main
ikka	doc_873901597551_item	3582475	et	4	main
hakkam	doc_873901597551_item	3582476	et	4	main
saada	doc_873901597551_item	3582477	et	4	main
ja	doc_873901597551_item	3582478	et	3	main
edasi	doc_873901597551_item	3582479	et	3	main
elada	doc_873901597551_item	3582480	et	3	main
suure	doc_873901597551_item	3582481	et	3	main
hooga	doc_873901597551_item	3582482	et	3	main
tulevikkus	doc_873901597553_item	3582565	et	4	main
on	doc_873901597553_item	3582566	et	4	main
jõulud	doc_873901597553_item	3582567	et	3	main
uus	doc_873901597553_item	3582568	et	3	main
aasta	doc_873901597553_item	3582569	et	4	main
aga	doc_873901597553_item	3582570	et	3	main
mul	doc_873901597553_item	3582571	et	3	main
on	doc_873901597553_item	3582572	et	4	main
esimisel	doc_873901597553_item	3582573	et	4	main
jaanuaril	doc_873901597553_item	3582574	et	3	main
sünnipäev	doc_873901597553_item	3582575	et	3	main
väga	doc_873901597553_item	3582576	et	3	main
palju	doc_873901597553_item	3582577	et	4	main
peod	doc_873901597553_item	3582578	et	4	main
head	doc_873901597553_item	3582579	et	4	main
uut	doc_873901597553_item	3582580	et	3	main
aasta	doc_873901597553_item	3582581	et	4	main
praegu	doc_873901597553_item	3582487	et	3	main
on	doc_873901597553_item	3582488	et	4	main
ole	doc_873901597553_item	3582499	et	4	main
ma	doc_873901597553_item	3582500	et	3	main
mäletan	doc_873901597553_item	3582501	et	3	main
minu	doc_873901597553_item	3582502	et	3	main
kelgutasime	doc_873901597553_item	3582511	et	3	main
on	doc_873901597553_item	3582521	et	4	main
lumelörts	doc_873901597553_item	3582522	et	3	main
lemehanged	doc_873901597553_item	3582532	et	4	main
sajab	doc_873901597553_item	3582534	et	3	main
ilus	doc_873901597553_item	3582535	et	4	main
ja	doc_873901597553_item	3582536	et	3	main
pehme	doc_873901597553_item	3582537	et	4	main
lund	doc_873901597553_item	3582538	et	3	main
aga	doc_873901597553_item	3582539	et	3	main
sa	doc_873901597553_item	3582540	et	3	main
ootad	doc_873901597553_item	3582541	et	3	main
bussi-peatuses	doc_873901597553_item	3582542	et	4	main
ja	doc_873901597553_item	3582543	et	3	main
vaatan	doc_873901597553_item	3582544	et	3	main
oma	doc_873901597553_item	3582545	et	4	main
sallis	doc_873901597553_item	3582546	et	4	main
lumehelved	doc_873901597553_item	3582547	et	4	main
kuidas	doc_873901597553_item	3582548	et	3	main
nad	doc_873901597553_item	3582549	et	3	main
kukkuvad	doc_873901597553_item	3582550	et	4	main
ja	doc_873901597553_item	3582551	et	3	main
kuidas	doc_873901597553_item	3582552	et	3	main
nad	doc_873901597553_item	3582553	et	3	main
sulavad	doc_873901597553_item	3582554	et	4	main
ma	doc_873901597553_item	3582555	et	3	main
arvan	doc_873901597553_item	3582556	et	3	main
et	doc_873901597553_item	3582557	et	3	main
talv	doc_873901597553_item	3582558	et	3	main
on	doc_873901597553_item	3582559	et	4	main
väga	doc_873901597553_item	3582560	et	3	main
romaantiline	doc_873901597553_item	3582561	et	4	main
aasta	doc_873901597553_item	3582562	et	4	main
aeg	doc_873901597553_item	3582563	et	3	main
veel	doc_873901597553_item	3582564	et	4	main
suusatasime	doc_873901597553_item	3582512	et	3	main
väga	doc_873901597553_item	3582515	et	3	main
aeg	doc_873901597553_item	3582517	et	3	main
praegu	doc_873901597553_item	3582519	et	3	main
talv	doc_873901597553_item	3582527	et	3	main
jäi	doc_873901597564_item	3582586	et	3	main
aasta	doc_873901597564_item	3582589	et	4	main
toob	doc_873901597564_item	3582596	et	3	main
uusi	doc_873901597564_item	3582597	et	3	main
võimalusi	doc_873901597564_item	3582598	et	3	main
aga	doc_873901597564_item	3582611	et	3	main
ma	doc_873901597564_item	3582620	et	3	main
tahaksin	doc_873901597564_item	3582634	et	3	main
astusin	doc_873901597564_item	3582638	et	3	main
eriti	doc_873901597564_item	3582652	et	3	main
suvel	doc_873901597564_item	3582654	et	3	main
koos	doc_873901597564_item	3582656	et	4	main
šašlõkki	doc_873901597564_item	3582667	et	2	main
muusikat	doc_873901597564_item	3582669	et	3	main
augustis	doc_873901597564_item	3582673	et	3	main
tartusse	doc_873901597564_item	3582684	et	3	main
linnades	doc_873901597564_item	3582689	et	3	main
sõit	doc_873901597564_item	3582695	et	3	main
aasta	doc_873901597564_item	3582704	et	4	main
ma	doc_873901597564_item	3582705	et	3	main
olin	doc_873901597564_item	3582706	et	3	main
ma	doc_873901597564_item	3582709	et	3	main
et	doc_873901597564_item	3582717	et	3	main
lahkusin	doc_873901597564_item	3582719	et	4	main
poissiga	doc_873901597564_item	3582721	et	4	main
ammu	doc_873901597564_item	3582723	et	4	main
ma	doc_873901597564_item	3582724	et	3	main
kui	doc_873901597553_item	3582528	et	3	main
suured	doc_873901597553_item	3582531	et	3	main
ja	doc_873901597553_item	3582533	et	3	main
mille	doc_873901597564_item	3582584	et	3	main
ja	doc_873901597564_item	3582600	et	3	main
aasta	doc_873901597564_item	3582603	et	4	main
mulle	doc_873901597564_item	3582605	et	4	main
head	doc_873901597564_item	3582608	et	4	main
ka	doc_873901597564_item	3582609	et	3	main
halba	doc_873901597564_item	3582610	et	4	main
teostusid	doc_873901597564_item	3582619	et	4	main
lõpetada	doc_873901597564_item	3582623	et	3	main
ja	doc_873901597564_item	3582625	et	3	main
lõpetasin	doc_873901597564_item	3582627	et	3	main
nelisega	doc_873901597564_item	3582629	et	4	main
nelgaga	doc_873901597564_item	3582630	et	4	main
aga	doc_873901597564_item	3582631	et	3	main
ja	doc_873901597564_item	3582637	et	3	main
kõige	doc_873901597564_item	3582639	et	4	main
rohkem	doc_873901597564_item	3582640	et	4	main
majandusteaduskondis	doc_873901597564_item	3582643	et	3	main
erinevades	doc_873901597564_item	3582650	et	4	main
ma	doc_873901597564_item	3582655	et	3	main
sõpradega	doc_873901597564_item	3582657	et	3	main
puhkasin	doc_873901597564_item	3582658	et	3	main
jäärves	doc_873901597564_item	3582660	et	4	main
me	doc_873901597564_item	3582662	et	4	main
päevitasime	doc_873901597564_item	3582663	et	3	main
suplesime	doc_873901597564_item	3582664	et	3	main
õhtuti	doc_873901597564_item	3582665	et	3	main
see	doc_873901597564_item	3582671	et	3	main
võrusse	doc_873901597564_item	3582686	et	3	main
see	doc_873901597564_item	3582694	et	3	main
päeva	doc_873901597564_item	3582698	et	4	main
sõitsime	doc_873901597564_item	3582700	et	3	main
kodus	doc_873901597564_item	3582701	et	4	main
puhkanud	doc_873901597564_item	3582702	et	4	main
kolmas	doc_873901597564_item	3582707	et	3	main
mäletan	doc_873901597564_item	3582710	et	3	main
kõige	doc_873901597564_item	3582712	et	4	main
ma	doc_873901597564_item	3582718	et	3	main
ja	doc_919500587383_item	3582749	et	3	main
naiskoori	doc_919500587383_item	3582759	et	4	main
oli	doc_919500587383_item	3582775	et	3	main
olnud	doc_919500587383_item	3582812	et	4	main
tallinna	doc_919500587383_item	3582816	et	4	main
nüüd	doc_919500587383_item	3582818	et	4	main
näen	doc_919500587383_item	3582820	et	3	main
püüdud	doc_919500587383_item	3582823	et	4	main
sellepärast	doc_919500587383_item	3582833	et	3	main
ei	doc_919500587383_item	3582835	et	4	main
ole	doc_919500587383_item	3582836	et	4	main
kevadel	doc_919500587383_item	3582848	et	4	main
eestlased	doc_919500587383_item	3582850	et	3	main
maitsevat	doc_919500587383_item	3582859	et	4	main
see	doc_919500587383_item	3582863	et	3	main
ole	doc_919500587383_item	3582865	et	4	main
veidi	doc_919500587383_item	3582875	et	3	main
eksootiline	doc_919500587383_item	3582876	et	3	main
põhjustab	doc_919500587383_item	3582879	et	3	main
imelikud	doc_919500587383_item	3582881	et	3	main
ei	doc_919500587383_item	3582915	et	4	main
on	doc_919500587383_item	3582934	et	4	main
väga	doc_919500587383_item	3582935	et	3	main
noor	doc_919500587383_item	3582936	et	3	main
maitseb	doc_919500587383_item	3582943	et	4	main
ma	doc_919500587385_item	3582990	et	3	main
ma	doc_919500587385_item	3583000	et	3	main
ainult	doc_919500587385_item	3583011	et	4	main
2	doc_919500587385_item	3583012	et	2	main
eestland	doc_919500587385_item	3583016	et	4	main
inimesed	doc_919500587385_item	3583020	et	3	main
poliitikat	doc_919500587385_item	3583029	et	3	main
ma	doc_919500587385_item	3583033	et	3	main
siin	doc_919500587385_item	3583035	et	4	main
võiks	doc_919500587385_item	3583041	et	4	main
keele	doc_919500587385_item	3583043	et	4	main
parem	doc_919500587385_item	3583082	et	4	main
toit	doc_919500587385_item	3583083	et	3	main
eestis	doc_919500587385_item	3583084	et	3	main
karttulidega	doc_919500587385_item	3583087	et	4	main
ma	doc_919500587385_item	3583089	et	3	main
mulle	doc_873901597564_item	3582587	et	4	main
meelde	doc_873901597564_item	3582588	et	3	main
2007	doc_873901597564_item	3582593	et	2	main
lootusi	doc_873901597564_item	3582601	et	4	main
jäi	doc_873901597564_item	3582604	et	3	main
kui	doc_873901597564_item	3582607	et	3	main
oli	doc_873901597564_item	3582614	et	3	main
rohkem	doc_873901597564_item	3582615	et	4	main
tahaksin	doc_873901597564_item	3582621	et	3	main
kool	doc_873901597564_item	3582628	et	4	main
viied	doc_873901597564_item	3582633	et	3	main
astuda	doc_873901597564_item	3582635	et	3	main
aasta	doc_873901597564_item	3582648	et	4	main
möödas	doc_873901597564_item	3582649	et	3	main
juunis	doc_873901597564_item	3582675	et	3	main
me	doc_873901597564_item	3582676	et	4	main
sõitsime	doc_873901597564_item	3582677	et	3	main
ümber	doc_873901597564_item	3582678	et	3	main
eestisse	doc_873901597564_item	3582679	et	4	main
me	doc_873901597564_item	3582680	et	4	main
olime	doc_873901597564_item	3582681	et	3	main
pärnusse	doc_873901597564_item	3582682	et	4	main
alatskivisse	doc_873901597564_item	3582683	et	3	main
3	doc_873901597564_item	3582697	et	2	main
oli	doc_873901597564_item	3582715	et	3	main
oma	doc_873901597564_item	3582720	et	4	main
mitte	doc_873901597564_item	3582722	et	3	main
essee	doc_919500587383_item	3582747	et	4	main
eesti	doc_919500587383_item	3582758	et	4	main
ma	doc_919500587383_item	3582762	et	3	main
tegin	doc_919500587383_item	3582772	et	3	main
mul	doc_919500587383_item	3582776	et	3	main
tagasi	doc_919500587383_item	3582793	et	3	main
ma	doc_919500587383_item	3582814	et	3	main
olid	doc_919500587383_item	3582824	et	4	main
väärt	doc_919500587383_item	3582826	et	4	main
ja	doc_919500587383_item	3582828	et	3	main
sloveenia	doc_919500587383_item	3582829	et	4	main
natuke	doc_919500587383_item	3582841	et	4	main
me	doc_873901597564_item	3582690	et	4	main
ööbisime	doc_873901597564_item	3582691	et	3	main
pärnus	doc_873901597564_item	3582692	et	3	main
suvimajas	doc_873901597564_item	3582693	et	3	main
kestab	doc_873901597564_item	3582696	et	4	main
me	doc_873901597564_item	3582699	et	4	main
pulmades	doc_873901597564_item	3582708	et	3	main
seda	doc_873901597564_item	3582711	et	3	main
see	doc_873901597564_item	3582716	et	3	main
jätsin	doc_873901597564_item	3582725	et	3	main
oma	doc_873901597564_item	3582726	et	4	main
endine	doc_873901597564_item	3582727	et	3	main
suhted	doc_873901597564_item	3582728	et	3	main
2006	doc_873901597564_item	3582729	et	2	main
aastal	doc_873901597564_item	3582730	et	3	main
ja	doc_873901597564_item	3582731	et	3	main
loodan	doc_873901597564_item	3582732	et	3	main
et	doc_873901597564_item	3582733	et	3	main
2007	doc_873901597564_item	3582734	et	2	main
aastal	doc_873901597564_item	3582735	et	3	main
mulle	doc_873901597564_item	3582736	et	4	main
vedab	doc_873901597564_item	3582737	et	4	main
rohkem	doc_873901597564_item	3582738	et	4	main
ma	doc_873901597564_item	3582739	et	3	main
loodan	doc_873901597564_item	3582740	et	3	main
et	doc_873901597564_item	3582741	et	3	main
järgmine	doc_873901597564_item	3582742	et	3	main
aastat	doc_873901597564_item	3582743	et	3	main
tuleb	doc_873901597564_item	3582744	et	3	main
parem	doc_873901597564_item	3582745	et	4	main
sloveenias	doc_919500587383_item	3582757	et	4	main
kui	doc_919500587383_item	3582761	et	3	main
seid	doc_919500587383_item	3582764	et	4	main
2	doc_919500587383_item	3582767	et	2	main
ma	doc_919500587383_item	3582771	et	3	main
baltireisi	doc_919500587383_item	3582773	et	4	main
esimene	doc_919500587383_item	3582777	et	3	main
meeldis	doc_919500587383_item	3582781	et	3	main
eestisse	doc_919500587383_item	3582792	et	4	main
minema	doc_919500587383_item	3582794	et	3	main
aastat	doc_919500587383_item	3582796	et	3	main
maailmas	doc_919500587383_item	3582808	et	3	main
aga	doc_919500587383_item	3582809	et	3	main
see	doc_919500587383_item	3582810	et	3	main
ei	doc_919500587383_item	3582811	et	4	main
hinda	doc_919500587383_item	3582825	et	4	main
eesti	doc_919500587383_item	3582827	et	4	main
riigid	doc_919500587383_item	3582832	et	3	main
mul	doc_919500587383_item	3582834	et	3	main
aga	doc_919500587383_item	3582843	et	3	main
kui	doc_919500587383_item	3582847	et	3	main
naeravad	doc_919500587383_item	3582851	et	3	main
kaifivad	doc_919500587383_item	3582854	et	4	main
praadi	doc_919500587383_item	3582860	et	4	main
aga	doc_919500587383_item	3582862	et	3	main
tihti	doc_919500587383_item	3582880	et	3	main
inimesed	doc_919500587383_item	3582909	et	3	main
mina	doc_919500587383_item	3582748	et	4	main
eesti	doc_919500587383_item	3582750	et	4	main
umbes	doc_919500587383_item	3582751	et	4	main
7	doc_919500587383_item	3582752	et	2	main
aastat	doc_919500587383_item	3582753	et	3	main
tagasi	doc_919500587383_item	3582754	et	3	main
ma	doc_919500587383_item	3582755	et	3	main
olin	doc_919500587383_item	3582756	et	3	main
näin	doc_919500587383_item	3582763	et	3	main
ilusaid	doc_919500587383_item	3582765	et	3	main
tüdrukuid	doc_919500587383_item	3582766	et	4	main
aastat	doc_919500587383_item	3582768	et	3	main
tagasi	doc_919500587383_item	3582769	et	3	main
suvel	doc_919500587383_item	3582770	et	3	main
kord	doc_919500587383_item	3582778	et	4	main
keel	doc_919500587383_item	3582784	et	4	main
linnad	doc_919500587383_item	3582785	et	3	main
inimesed	doc_919500587383_item	3582786	et	3	main
meri	doc_919500587383_item	3582787	et	3	main
pidud	doc_919500587383_item	3582788	et	3	main
sellepärast	doc_919500587383_item	3582789	et	3	main
ma	doc_919500587383_item	3582790	et	3	main
otsustasin	doc_919500587383_item	3582791	et	3	main
ma	doc_919500587383_item	3582797	et	3	main
õppisin	doc_919500587383_item	3582798	et	3	main
eesti	doc_919500587383_item	3582799	et	4	main
keelt	doc_919500587383_item	3582800	et	4	main
viini	doc_919500587383_item	3582801	et	4	main
ülikoolis	doc_919500587383_item	3582802	et	4	main
võib-olla	doc_919500587383_item	3582803	et	3	main
see	doc_919500587383_item	3582804	et	3	main
on	doc_919500587383_item	3582805	et	4	main
raskim	doc_919500587383_item	3582806	et	4	main
oluline	doc_919500587383_item	3582813	et	4	main
ma	doc_919500587383_item	3582819	et	3	main
mu	doc_919500587383_item	3582822	et	3	main
väikesed	doc_919500587383_item	3582831	et	4	main
on	doc_919500587383_item	3582840	et	4	main
mulle	doc_919500587383_item	3582844	et	4	main
väga	doc_919500587383_item	3582846	et	3	main
elu	doc_919500587383_item	3582853	et	4	main
restoranides	doc_919500587383_item	3582855	et	3	main
ei	doc_919500587383_item	3582864	et	4	main
suur	doc_919500587383_item	3582866	et	3	main
probleem	doc_919500587383_item	3582867	et	3	main
ma	doc_919500587383_item	3582868	et	3	main
alles	doc_919500587383_item	3582870	et	3	main
mu	doc_919500587383_item	3582871	et	3	main
karakter	doc_919500587383_item	3582872	et	3	main
on	doc_919500587383_item	3582873	et	4	main
näeks	doc_919500587383_item	3582906	et	3	main
klaasi	doc_919500587383_item	3582921	et	4	main
unustatakse	doc_919500587383_item	3582924	et	3	main
koplita	doc_919500587383_item	3582940	et	3	main
soolane	doc_919500587383_item	3582946	et	4	main
mina	doc_919500587385_item	3582987	et	4	main
kõigal	doc_919500587383_item	3582849	et	4	main
pean	doc_919500587383_item	3582869	et	4	main
minu	doc_919500587383_item	3582877	et	3	main
reatsoone	doc_919500587383_item	3582882	et	3	main
nägudel	doc_919500587383_item	3582883	et	3	main
aga	doc_919500587383_item	3582884	et	3	main
ma	doc_919500587383_item	3582885	et	3	main
juba	doc_919500587383_item	3582886	et	3	main
võtsin	doc_919500587383_item	3582887	et	3	main
eesti	doc_919500587383_item	3582888	et	4	main
mõnu	doc_919500587383_item	3582889	et	4	main
ka	doc_919500587383_item	3582891	et	3	main
vastu	doc_919500587383_item	3582890	et	3	main
peaasja	doc_919500587383_item	3582892	et	4	main
ma	doc_919500587383_item	3582893	et	3	main
kohtusin	doc_919500587383_item	3582894	et	4	main
mitu	doc_919500587383_item	3582895	et	4	main
eesti	doc_919500587383_item	3582896	et	4	main
tüdrukutega	doc_919500587383_item	3582897	et	4	main
nemad	doc_919500587383_item	3582898	et	3	main
ei	doc_919500587383_item	3582899	et	4	main
ole	doc_919500587383_item	3582900	et	4	main
alati	doc_919500587383_item	3582901	et	4	main
lihtsad	doc_919500587383_item	3582902	et	3	main
aga	doc_919500587383_item	3582903	et	3	main
kuidas	doc_919500587383_item	3582904	et	3	main
maailm	doc_919500587383_item	3582905	et	3	main
kui	doc_919500587383_item	3582908	et	3	main
liiga	doc_919500587383_item	3582911	et	4	main
alati	doc_919500587383_item	3582917	et	4	main
parim	doc_919500587383_item	3582918	et	4	main
aga	doc_919500587383_item	3582919	et	3	main
viini	doc_919500587383_item	3582922	et	4	main
kõik	doc_919500587383_item	3582925	et	4	main
ma	doc_919500587383_item	3582926	et	3	main
arvan	doc_919500587383_item	3582927	et	3	main
ma	doc_919500587383_item	3582928	et	3	main
jaksan	doc_919500587383_item	3582929	et	3	main
eestis	doc_919500587383_item	3582930	et	3	main
kauam	doc_919500587383_item	3582931	et	4	main
elada	doc_919500587383_item	3582932	et	3	main
linn	doc_919500587383_item	3582939	et	3	main
elu	doc_919500587383_item	3582942	et	4	main
natuke	doc_919500587383_item	3582944	et	4	main
liiga	doc_919500587383_item	3582945	et	4	main
essee	doc_919500587385_item	3582986	et	4	main
juulis	doc_919500587385_item	3582993	et	3	main
siis	doc_919500587385_item	3582995	et	3	main
8	doc_919500587385_item	3582997	et	2	main
päeva	doc_919500587385_item	3583013	et	4	main
mulle	doc_919500587385_item	3583014	et	4	main
ja	doc_919500587385_item	3583018	et	3	main
õpin	doc_919500587385_item	3583022	et	3	main
eesti	doc_919500587385_item	3583031	et	4	main
ma	doc_919500587385_item	3583037	et	3	main
ei	doc_919500587385_item	3583076	et	4	main
mul	doc_919500587385_item	3583078	et	3	main
olnud	doc_919500587385_item	3583079	et	4	main
kotiigatsus	doc_919500587385_item	3583080	et	3	main
kõige	doc_919500587385_item	3583081	et	4	main
on	doc_919500587385_item	3583100	et	4	main
nendega	doc_919500587385_item	3583104	et	4	main
ma	doc_919500587385_item	3583105	et	3	main
või	doc_919500587385_item	3583109	et	4	main
mängin	doc_919500587385_item	3583112	et	3	main
korvpalli	doc_919500587385_item	3583114	et	4	main
inimesi	doc_919500587385_item	3583120	et	4	main
palju	doc_919500587385_item	3583132	et	4	main
soomlased	doc_919500587385_item	3583133	et	3	main
kes	doc_919500587385_item	3583134	et	4	main
ma	doc_919500587385_item	3583135	et	3	main
tunnen	doc_919500587385_item	3583136	et	3	main
nad	doc_919500587385_item	3583137	et	3	main
ma	doc_919500587385_item	3583142	et	3	main
seal	doc_919500587385_item	3583145	et	4	main
ma	doc_919500587385_item	3583147	et	3	main
18	doc_919500587385_item	3583160	et	2	main
minu	doc_919500587385_item	3583162	et	3	main
parem	doc_919500587385_item	3583164	et	4	main
sõber	doc_919500587385_item	3583165	et	3	main
ole	doc_919500587383_item	3582916	et	4	main
tallinn	doc_919500587383_item	3582933	et	4	main
huvitav	doc_919500587383_item	3582938	et	4	main
kus	doc_919500587383_item	3582941	et	3	main
eesti	doc_919500587385_item	3582989	et	4	main
eestisse	doc_919500587385_item	3582992	et	4	main
umbes	doc_919500587385_item	3582996	et	4	main
ma	doc_919500587385_item	3583007	et	3	main
seal	doc_919500587385_item	3583009	et	4	main
siin	doc_919500587385_item	3583010	et	4	main
toid	doc_919500587385_item	3583017	et	4	main
ja	doc_919500587385_item	3583030	et	3	main
mõtlesin	doc_919500587385_item	3583038	et	3	main
eesti	doc_919500587385_item	3583042	et	4	main
õppida	doc_919500587385_item	3583044	et	3	main
kui	doc_919500587385_item	3583069	et	3	main
ole	doc_919500587385_item	3583077	et	4	main
hakklihapallid	doc_919500587385_item	3583086	et	3	main
neid	doc_919500587385_item	3583088	et	4	main
on	doc_919500587385_item	3583096	et	4	main
pankoogid	doc_919500587385_item	3583097	et	4	main
maasikamoosiga	doc_919500587385_item	3583098	et	3	main
mul	doc_919500587385_item	3583099	et	3	main
on	doc_919500587385_item	3583125	et	4	main
minu	doc_919500587385_item	3583126	et	3	main
lemmik	doc_919500587385_item	3583127	et	3	main
linn	doc_919500587385_item	3583128	et	3	main
eestis	doc_919500587385_item	3583129	et	3	main
käivad	doc_919500587385_item	3583138	et	4	main
käin	doc_919500587385_item	3583143	et	3	main
olin	doc_919500587385_item	3583148	et	3	main
viimati	doc_919500587385_item	3583149	et	3	main
juba	doc_919500587385_item	3583159	et	3	main
kõige	doc_919500587385_item	3583163	et	4	main
kena	doc_919500587385_item	3583191	et	4	main
on	doc_919500587385_item	3583194	et	4	main
hea	doc_919500587385_item	3583196	et	4	main
kokk	doc_919500587385_item	3583197	et	3	main
nad	doc_919500587385_item	3583198	et	3	main
elavad	doc_919500587385_item	3583199	et	4	main
on	doc_919500587385_item	3583204	et	4	main
üks	doc_919500587385_item	3583205	et	3	main
maale	doc_919500587385_item	3583212	et	4	main
eelmisel	doc_919500587388_item	3583240	et	3	main
õpin	doc_919500587388_item	3583245	et	3	main
ülikoolis	doc_919500587388_item	3583248	et	4	main
ja	doc_919500587388_item	3583249	et	3	main
sellepärast	doc_919500587388_item	3583250	et	3	main
et	doc_919500587388_item	3583251	et	3	main
tahtsin	doc_919500587388_item	3583259	et	3	main
tahtsin	doc_919500587388_item	3583264	et	3	main
õppida	doc_919500587388_item	3583266	et	3	main
elan	doc_919500587388_item	3583270	et	3	main
on	doc_919500587388_item	3583277	et	4	main
väga	doc_919500587388_item	3583281	et	3	main
maja	doc_919500587388_item	3583283	et	4	main
soomes	doc_919500587388_item	3583287	et	4	main
elu	doc_919500587388_item	3583312	et	4	main
tallinnas	doc_919500587388_item	3583313	et	4	main
väga	doc_919500587388_item	3583314	et	3	main
hästi	doc_919500587388_item	3583315	et	3	main
sügis	doc_919500587388_item	3583316	et	3	main
oli	doc_919500587388_item	3583317	et	3	main
üsna	doc_919500587388_item	3583318	et	3	main
raske	doc_919500587388_item	3583319	et	4	main
ja	doc_919500587388_item	3583320	et	3	main
ma	doc_919500587388_item	3583321	et	3	main
olin	doc_919500587388_item	3583322	et	3	main
nüüd	doc_919500587388_item	3583329	et	4	main
kõik	doc_919500587388_item	3583331	et	4	main
vanalinn	doc_919500587388_item	3583352	et	3	main
kus	doc_919500587388_item	3583353	et	3	main
on	doc_919500587388_item	3583354	et	4	main
tallinnas	doc_919500587388_item	3583372	et	4	main
6	doc_919500587388_item	3583373	et	2	main
eesti	doc_919500587388_item	3583380	et	4	main
seda	doc_919500587388_item	3583388	et	3	main
rääkida	doc_919500587388_item	3583390	et	3	main
ja	doc_919500587388_item	3583391	et	3	main
aga	doc_919500587383_item	3582947	et	3	main
kenad	doc_919500587383_item	3582948	et	3	main
tüdrukud	doc_919500587383_item	3582949	et	3	main
teevad	doc_919500587383_item	3582950	et	3	main
seda	doc_919500587383_item	3582951	et	3	main
küllalt	doc_919500587383_item	3582952	et	4	main
magus	doc_919500587383_item	3582953	et	3	main
nüüd	doc_919500587383_item	3582954	et	4	main
mulle	doc_919500587383_item	3582955	et	4	main
tuli	doc_919500587383_item	3582956	et	4	main
meelde	doc_919500587383_item	3582957	et	3	main
veel	doc_919500587383_item	3582958	et	4	main
üks	doc_919500587383_item	3582959	et	3	main
asja	doc_919500587383_item	3582960	et	4	main
kui	doc_919500587383_item	3582961	et	3	main
eestlased	doc_919500587383_item	3582962	et	3	main
on	doc_919500587383_item	3582963	et	4	main
paha	doc_919500587383_item	3582964	et	4	main
tuju	doc_919500587383_item	3582965	et	4	main
või	doc_919500587383_item	3582966	et	4	main
kui	doc_919500587383_item	3582967	et	3	main
nad	doc_919500587383_item	3582968	et	3	main
on	doc_919500587383_item	3582969	et	4	main
ebaviisakad	doc_919500587383_item	3582970	et	4	main
ma	doc_919500587383_item	3582971	et	3	main
ainult	doc_919500587383_item	3582972	et	4	main
ütlen	doc_919500587383_item	3582973	et	3	main
hed	doc_919500587383_item	3582974	et	4	main
aega	doc_919500587383_item	3582975	et	4	main
ja	doc_919500587383_item	3582976	et	3	main
naeratan	doc_919500587383_item	3582977	et	3	main
võib	doc_919500587383_item	3582978	et	3	main
olla	doc_919500587383_item	3582979	et	3	main
nad	doc_919500587383_item	3582980	et	3	main
naeratavad	doc_919500587383_item	3582981	et	4	main
järgmine	doc_919500587383_item	3582982	et	3	main
kord	doc_919500587383_item	3582983	et	4	main
ka	doc_919500587383_item	3582984	et	3	main
kuud	doc_919500587385_item	3582998	et	4	main
olin	doc_919500587385_item	3583001	et	3	main
eestis	doc_919500587385_item	3583003	et	3	main
varem	doc_919500587385_item	3583005	et	4	main
õpin	doc_919500587385_item	3583028	et	3	main
keelt	doc_919500587385_item	3583032	et	4	main
tulin	doc_919500587385_item	3583034	et	3	main
ja	doc_919500587385_item	3582988	et	3	main
tulin	doc_919500587385_item	3582991	et	3	main
2006	doc_919500587385_item	3582994	et	2	main
tagasi	doc_919500587385_item	3582999	et	3	main
käinud	doc_919500587385_item	3583002	et	4	main
juba	doc_919500587385_item	3583004	et	3	main
aga	doc_919500587385_item	3583006	et	3	main
olin	doc_919500587385_item	3583008	et	3	main
meeldib	doc_919500587385_item	3583015	et	3	main
eestlased	doc_919500587385_item	3583019	et	3	main
ma	doc_919500587385_item	3583021	et	3	main
tallinna	doc_919500587385_item	3583023	et	4	main
ülikoolis	doc_919500587385_item	3583024	et	4	main
ning	doc_919500587385_item	3583025	et	3	main
seal	doc_919500587385_item	3583026	et	4	main
ma	doc_919500587385_item	3583027	et	3	main
sest	doc_919500587385_item	3583036	et	4	main
ma	doc_919500587385_item	3583040	et	3	main
kergesti	doc_919500587385_item	3583045	et	3	main
tallinna	doc_919500587385_item	3583046	et	4	main
ülikool	doc_919500587385_item	3583047	et	4	main
on	doc_919500587385_item	3583048	et	4	main
väga	doc_919500587385_item	3583049	et	3	main
erinev	doc_919500587385_item	3583050	et	4	main
kui	doc_919500587385_item	3583051	et	3	main
see	doc_919500587385_item	3583052	et	3	main
kool	doc_919500587385_item	3583053	et	4	main
kus	doc_919500587385_item	3583054	et	3	main
ma	doc_919500587385_item	3583055	et	3	main
soomes	doc_919500587385_item	3583056	et	4	main
õpin	doc_919500587385_item	3583057	et	3	main
aga	doc_919500587385_item	3583058	et	3	main
mulle	doc_919500587385_item	3583059	et	4	main
meeldib	doc_919500587385_item	3583060	et	3	main
siin	doc_919500587385_item	3583061	et	4	main
õpida	doc_919500587385_item	3583062	et	4	main
inimesed	doc_919500587385_item	3583063	et	3	main
ja	doc_919500587385_item	3583064	et	3	main
ilm	doc_919500587385_item	3583065	et	3	main
on	doc_919500587385_item	3583066	et	4	main
eestis	doc_919500587385_item	3583067	et	3	main
samasugused	doc_919500587385_item	3583068	et	3	main
et	doc_919500587385_item	3583039	et	3	main
on	doc_919500587385_item	3583085	et	4	main
soomes	doc_919500587385_item	3583070	et	4	main
ja	doc_919500587385_item	3583071	et	3	main
ma	doc_919500587385_item	3583072	et	3	main
arvan	doc_919500587385_item	3583073	et	3	main
et	doc_919500587385_item	3583074	et	3	main
sellepärast	doc_919500587385_item	3583075	et	3	main
igal	doc_919500587385_item	3583091	et	3	main
nädalal	doc_919500587385_item	3583092	et	3	main
minu	doc_919500587385_item	3583093	et	3	main
lemmik	doc_919500587385_item	3583094	et	3	main
palju	doc_919500587385_item	3583102	et	4	main
baaris	doc_919500587385_item	3583108	et	3	main
seal	doc_919500587385_item	3583130	et	4	main
tihti	doc_919500587385_item	3583139	et	3	main
ja	doc_919500587385_item	3583141	et	3	main
ka	doc_919500587385_item	3583144	et	3	main
kui	doc_919500587385_item	3583146	et	3	main
seal	doc_919500587385_item	3583150	et	4	main
nii	doc_919500587385_item	3583151	et	3	main
me	doc_919500587385_item	3583152	et	4	main
käisime	doc_919500587385_item	3583153	et	3	main
ujumas	doc_919500587385_item	3583154	et	3	main
ta	doc_919500587385_item	3583193	et	4	main
väga	doc_919500587385_item	3583195	et	3	main
koer	doc_919500587385_item	3583208	et	3	main
eesnimi	doc_919500587385_item	3583210	et	3	main
eestis	doc_919500587385_item	3583101	et	3	main
tihti	doc_919500587385_item	3583107	et	3	main
kinos	doc_919500587385_item	3583110	et	3	main
kes	doc_919500587385_item	3583121	et	4	main
on	doc_919500587385_item	3583131	et	4	main
järves	doc_919500587385_item	3583155	et	4	main
kuigi	doc_919500587385_item	3583156	et	3	main
oli	doc_919500587385_item	3583157	et	3	main
graadi	doc_919500587385_item	3583161	et	4	main
eestis	doc_919500587385_item	3583166	et	3	main
on	doc_919500587385_item	3583167	et	4	main
eesnimi	doc_919500587385_item	3583168	et	3	main
ta	doc_919500587385_item	3583169	et	4	main
elab	doc_919500587385_item	3583170	et	3	main
tallinnas	doc_919500587385_item	3583171	et	4	main
ja	doc_919500587385_item	3583172	et	3	main
ta	doc_919500587385_item	3583173	et	4	main
ka	doc_919500587385_item	3583174	et	3	main
õpib	doc_919500587385_item	3583175	et	3	main
tallinna	doc_919500587385_item	3583176	et	4	main
ülikoolis	doc_919500587385_item	3583177	et	4	main
ta	doc_919500587385_item	3583178	et	4	main
23	doc_919500587385_item	3583180	et	2	main
on	doc_919500587385_item	3583179	et	4	main
aastat	doc_919500587385_item	3583181	et	3	main
vana	doc_919500587385_item	3583182	et	4	main
ja	doc_919500587385_item	3583183	et	3	main
elab	doc_919500587385_item	3583184	et	3	main
koos	doc_919500587385_item	3583185	et	4	main
tema	doc_919500587385_item	3583186	et	4	main
tema	doc_919500587385_item	3583188	et	4	main
on	doc_919500587385_item	3583190	et	4	main
lõuna-tallinnas	doc_919500587385_item	3583202	et	4	main
neil	doc_919500587385_item	3583203	et	4	main
kass	doc_919500587385_item	3583206	et	3	main
kolida	doc_919500587385_item	3583213	et	3	main
tulin	doc_919500587388_item	3583237	et	3	main
käsitööt	doc_919500587388_item	3583246	et	4	main
helsingi	doc_919500587388_item	3583247	et	4	main
ka	doc_919500587388_item	3583255	et	3	main
ma	doc_919500587388_item	3583260	et	3	main
pindala	doc_919500587388_item	3583276	et	4	main
on	doc_919500587388_item	3583280	et	4	main
ja	doc_919500587388_item	3583309	et	3	main
meeldib	doc_919500587388_item	3583311	et	3	main
ja	doc_919500587388_item	3583325	et	3	main
palju	doc_919500587388_item	3583355	et	4	main
hubasid	doc_919500587388_item	3583356	et	4	main
restorane	doc_919500587388_item	3583357	et	3	main
ja	doc_919500587388_item	3583358	et	3	main
olen	doc_919500587388_item	3583362	et	3	main
kuud	doc_919500587388_item	3583374	et	4	main
õppinud	doc_919500587388_item	3583379	et	4	main
nii	doc_919500587388_item	3583382	et	3	main
söön	doc_919500587385_item	3583090	et	3	main
magustoit	doc_919500587385_item	3583095	et	3	main
sõpru	doc_919500587385_item	3583103	et	3	main
käin	doc_919500587385_item	3583106	et	3	main
ma	doc_919500587385_item	3583111	et	3	main
ka	doc_919500587385_item	3583113	et	3	main
ja	doc_919500587385_item	3583115	et	3	main
ma	doc_919500587385_item	3583116	et	3	main
tunnen	doc_919500587385_item	3583117	et	3	main
ka	doc_919500587385_item	3583118	et	3	main
palju	doc_919500587385_item	3583119	et	4	main
mängivad	doc_919500587385_item	3583122	et	4	main
korvpalli	doc_919500587385_item	3583123	et	4	main
tarto	doc_919500587385_item	3583124	et	4	main
tallinnas	doc_919500587385_item	3583140	et	4	main
külm	doc_919500587385_item	3583158	et	3	main
sõbratariga	doc_919500587385_item	3583187	et	3	main
tüdruk	doc_919500587385_item	3583189	et	3	main
väikeses	doc_919500587385_item	3583200	et	4	main
majas	doc_919500587385_item	3583201	et	3	main
ja	doc_919500587385_item	3583207	et	3	main
soovib	doc_919500587385_item	3583211	et	3	main
essee	doc_919500587388_item	3583232	et	4	main
ja	doc_919500587388_item	3583234	et	3	main
sügisel	doc_919500587388_item	3583239	et	3	main
soomest	doc_919500587388_item	3583242	et	3	main
ma	doc_919500587388_item	3583244	et	3	main
ülikoolis	doc_919500587388_item	3583253	et	4	main
õppida	doc_919500587388_item	3583258	et	3	main
tallinnasse	doc_919500587388_item	3583261	et	3	main
ma	doc_919500587388_item	3583263	et	3	main
ka	doc_919500587388_item	3583265	et	3	main
eesti	doc_919500587388_item	3583267	et	4	main
maja	doc_919500587388_item	3583275	et	4	main
see	doc_919500587388_item	3583279	et	3	main
olin	doc_919500587388_item	3583286	et	3	main
mulle	doc_919500587388_item	3583310	et	4	main
üksik	doc_919500587388_item	3583324	et	3	main
ilus	doc_919500587388_item	3583351	et	4	main
huvitavaid	doc_919500587388_item	3583359	et	4	main
ka	doc_919500587388_item	3583363	et	3	main
mugavate	doc_919500587388_item	3583365	et	3	main
mul	doc_919500587388_item	3583368	et	3	main
ajadel	doc_919500587388_item	3583375	et	4	main
ma	doc_919500587388_item	3583376	et	3	main
hästi	doc_919500587388_item	3583383	et	3	main
ma	doc_919500587388_item	3583385	et	3	main
käsitööt	doc_919500587388_item	3583393	et	4	main
ja	doc_919500587388_item	3583394	et	3	main
ning	doc_986203247107_item	3583609	et	3	main
väide	doc_986203247107_item	3583622	et	4	main
igal	doc_986203247107_item	3583624	et	3	main
tarkus	doc_986203247107_item	3583640	et	4	main
käivad	doc_986203247107_item	3583641	et	4	main
ning	doc_919500587385_item	3583192	et	3	main
ning	doc_919500587385_item	3583209	et	3	main
ma	doc_919500587385_item	3583214	et	3	main
arvan	doc_919500587385_item	3583215	et	3	main
et	doc_919500587385_item	3583216	et	3	main
elan	doc_919500587385_item	3583218	et	3	main
ma	doc_919500587385_item	3583217	et	3	main
eestis	doc_919500587385_item	3583219	et	3	main
veel	doc_919500587385_item	3583220	et	4	main
ainult	doc_919500587385_item	3583221	et	4	main
kaks	doc_919500587385_item	3583222	et	3	main
kuud	doc_919500587385_item	3583223	et	4	main
ja	doc_919500587385_item	3583224	et	3	main
ma	doc_919500587385_item	3583225	et	3	main
pean	doc_919500587385_item	3583226	et	4	main
siis	doc_919500587385_item	3583227	et	3	main
tagasi	doc_919500587385_item	3583228	et	3	main
soome	doc_919500587385_item	3583229	et	3	main
minema	doc_919500587385_item	3583230	et	3	main
mina	doc_919500587388_item	3583233	et	4	main
eestisse	doc_919500587388_item	3583238	et	4	main
tallinna	doc_919500587388_item	3583252	et	4	main
käsitööt	doc_919500587388_item	3583257	et	4	main
sageli	doc_919500587388_item	3583323	et	3	main
koju	doc_919500587388_item	3583327	et	3	main
siin	doc_919500587388_item	3583348	et	4	main
kunstigaleriit	doc_919500587388_item	3583360	et	4	main
ma	doc_919500587388_item	3583361	et	3	main
tutvunud	doc_919500587388_item	3583364	et	4	main
ja	doc_919500587388_item	3583367	et	3	main
olen	doc_919500587388_item	3583377	et	3	main
et	doc_919500587388_item	3583384	et	3	main
nüüd	doc_919500587388_item	3583387	et	4	main
inimestega	doc_919500587388_item	3583389	et	3	main
õppida	doc_919500587388_item	3583392	et	3	main
joonistamist	doc_919500587388_item	3583395	et	4	main
eesti	doc_919500587388_item	3583396	et	4	main
keelel	doc_919500587388_item	3583397	et	4	main
kõik	doc_919500587388_item	3583398	et	4	main
lõpeb	doc_919500587388_item	3583399	et	4	main
omal	doc_919500587388_item	3583400	et	3	main
ajal	doc_919500587388_item	3583401	et	4	main
ja	doc_919500587388_item	3583402	et	3	main
kahe	doc_919500587388_item	3583403	et	3	main
kuu	doc_919500587388_item	3583404	et	4	main
pärast	doc_919500587388_item	3583405	et	4	main
ma	doc_919500587388_item	3583406	et	3	main
kolin	doc_919500587388_item	3583407	et	4	main
tagasi	doc_919500587388_item	3583408	et	3	main
soome	doc_919500587388_item	3583409	et	3	main
õnneks	doc_919500587388_item	3583410	et	4	main
soome	doc_919500587388_item	3583411	et	3	main
on	doc_919500587388_item	3583412	et	4	main
nii	doc_919500587388_item	3583413	et	3	main
lähedal	doc_919500587388_item	3583414	et	4	main
et	doc_919500587388_item	3583415	et	3	main
ma	doc_919500587388_item	3583416	et	3	main
võin	doc_919500587388_item	3583417	et	3	main
kergesti	doc_919500587388_item	3583418	et	3	main
tagasi	doc_919500587388_item	3583419	et	3	main
eestisse	doc_919500587388_item	3583420	et	4	main
tulla	doc_919500587388_item	3583421	et	3	main
eesti	doc_919500587388_item	3583235	et	4	main
mina	doc_919500587388_item	3583236	et	4	main
aastal	doc_919500587388_item	3583241	et	3	main
soomes	doc_919500587388_item	3583243	et	4	main
on	doc_919500587388_item	3583254	et	4	main
võimalik	doc_919500587388_item	3583256	et	3	main
tulla	doc_919500587388_item	3583262	et	3	main
keelt	doc_919500587388_item	3583268	et	4	main
ma	doc_919500587388_item	3583269	et	3	main
tallinnas	doc_919500587388_item	3583271	et	4	main
kristiines	doc_919500587388_item	3583272	et	4	main
üürimajas	doc_919500587388_item	3583273	et	3	main
minu	doc_919500587388_item	3583274	et	3	main
ja	doc_919500587388_item	3583278	et	3	main
hubane	doc_919500587388_item	3583282	et	3	main
kui	doc_919500587388_item	3583284	et	3	main
ma	doc_919500587388_item	3583285	et	3	main
elasin	doc_919500587388_item	3583288	et	3	main
ma	doc_919500587388_item	3583289	et	3	main
suures	doc_919500587388_item	3583290	et	3	main
majas	doc_919500587388_item	3583291	et	3	main
6	doc_919500587388_item	3583292	et	2	main
oma	doc_919500587388_item	3583293	et	4	main
sõbratega	doc_919500587388_item	3583294	et	4	main
aga	doc_919500587388_item	3583295	et	3	main
nüüd	doc_919500587388_item	3583296	et	4	main
mulle	doc_919500587388_item	3583297	et	4	main
meeldib	doc_919500587388_item	3583298	et	3	main
elada	doc_919500587388_item	3583299	et	3	main
üksinda	doc_919500587388_item	3583300	et	4	main
nüüd	doc_919500587388_item	3583301	et	4	main
ma	doc_919500587388_item	3583302	et	3	main
olen	doc_919500587388_item	3583303	et	3	main
olnud	doc_919500587388_item	3583304	et	4	main
eestis	doc_919500587388_item	3583305	et	3	main
juba	doc_919500587388_item	3583306	et	3	main
6	doc_919500587388_item	3583307	et	2	main
kuud	doc_919500587388_item	3583308	et	4	main
igatsesin	doc_919500587388_item	3583326	et	3	main
aga	doc_919500587388_item	3583328	et	3	main
kevadel	doc_919500587388_item	3583330	et	4	main
on	doc_919500587388_item	3583332	et	4	main
hästi	doc_919500587388_item	3583334	et	3	main
ja	doc_919500587388_item	3583335	et	3	main
päris	doc_919500587388_item	3583333	et	4	main
ma	doc_919500587388_item	3583336	et	3	main
ei	doc_919500587388_item	3583337	et	4	main
tahaks	doc_919500587388_item	3583338	et	3	main
veel	doc_919500587388_item	3583339	et	4	main
tagasi	doc_919500587388_item	3583340	et	3	main
soome	doc_919500587388_item	3583341	et	3	main
minna	doc_919500587388_item	3583342	et	3	main
tallinna	doc_919500587388_item	3583343	et	4	main
meeldib	doc_919500587388_item	3583344	et	3	main
mulle	doc_919500587388_item	3583345	et	4	main
sest	doc_919500587388_item	3583346	et	4	main
kui	doc_919500587388_item	3583347	et	3	main
on	doc_919500587388_item	3583349	et	4	main
väga	doc_919500587388_item	3583350	et	3	main
inimestega	doc_919500587388_item	3583366	et	3	main
on	doc_919500587388_item	3583369	et	4	main
palju	doc_919500587388_item	3583370	et	4	main
sõpru	doc_919500587388_item	3583371	et	3	main
ka	doc_919500587388_item	3583378	et	3	main
keelt	doc_919500587388_item	3583381	et	4	main
võin	doc_919500587388_item	3583386	et	3	main
valige	doc_986203247107_item	3583606	et	3	main
selle	doc_986203247107_item	3583613	et	4	main
nõus	doc_986203247107_item	3583615	et	4	main
peaks	doc_986203247107_item	3583626	et	4	main
olema	doc_986203247107_item	3583627	et	4	main
koolivorm	doc_986203247107_item	3583629	et	3	main
tekkimisele	doc_986203247107_item	3583635	et	4	main
rikkus	doc_986203247107_item	3583638	et	4	main
ja	doc_986203247107_item	3583639	et	3	main
joonitud	doc_986203247107_item	3583645	et	4	main
kasti	doc_986203247107_item	3583646	et	4	main
sõna	doc_986203247107_item	3583654	et	4	main
ma	doc_986203247107_item	3583655	et	3	main
arvan	doc_986203247107_item	3583656	et	3	main
et	doc_986203247107_item	3583657	et	3	main
oma	doc_986203247107_item	3583663	et	4	main
koolivorm	doc_986203247107_item	3583664	et	3	main
meenutab	doc_986203247107_item	3583667	et	3	main
väiteid	doc_986203247109_item	3583733	et	4	main
üks	doc_986203247109_item	3583736	et	3	main
esitage	doc_986203247109_item	3583746	et	3	main
ja	doc_986203247109_item	3583748	et	3	main
vastuargumente	doc_986203247109_item	3583749	et	3	main
väide	doc_986203247109_item	3583750	et	4	main
igal	doc_986203247109_item	3583752	et	3	main
alati	doc_986203247109_item	3583770	et	4	main
teksti	doc_986203247109_item	3583776	et	4	main
160	doc_986203247109_item	3583781	et	2	main
koolil	doc_986203247109_item	3583784	et	4	main
kaasa	doc_986203247109_item	3583791	et	4	main
ei	doc_986203247109_item	3583797	et	4	main
igaüks	doc_986203247109_item	3583801	et	3	main
peab	doc_986203247109_item	3583839	et	4	main
liikselt	doc_986203247109_item	3583845	et	4	main
kaunistada	doc_986203247109_item	3583846	et	3	main
iga	doc_986203247109_item	3583847	et	4	main
oma	doc_986203247109_item	3583869	et	4	main
koolis	doc_986203247109_item	3583872	et	4	main
koolivorm	doc_986203247109_item	3583874	et	3	main
väga	doc_986203247109_item	3583878	et	3	main
väiteid	doc_986203247107_item	3583605	et	4	main
üks	doc_986203247107_item	3583608	et	3	main
kas	doc_986203247107_item	3583611	et	3	main
väitega	doc_986203247107_item	3583614	et	3	main
või	doc_986203247107_item	3583616	et	4	main
mitte	doc_986203247107_item	3583617	et	3	main
esitage	doc_986203247107_item	3583618	et	3	main
poolt-	doc_986203247107_item	3583619	et	4	main
ja	doc_986203247107_item	3583620	et	3	main
vastuargumente	doc_986203247107_item	3583621	et	3	main
alati	doc_986203247107_item	3583642	et	4	main
u	doc_986203247107_item	3583652	et	4	main
160	doc_986203247107_item	3583653	et	2	main
olema	doc_986203247107_item	3583662	et	4	main
valige	doc_986203247109_item	3583734	et	3	main
ning	doc_986203247109_item	3583737	et	3	main
olete	doc_986203247109_item	3583740	et	3	main
väitega	doc_986203247109_item	3583742	et	3	main
poolt-	doc_986203247109_item	3583747	et	4	main
koolil	doc_986203247109_item	3583753	et	4	main
peaks	doc_986203247109_item	3583754	et	4	main
omakoolitunde	doc_986203247109_item	3583762	et	4	main
2	doc_986203247109_item	3583765	et	2	main
rikkus	doc_986203247109_item	3583766	et	4	main
ja	doc_986203247109_item	3583767	et	3	main
tarkus	doc_986203247109_item	3583768	et	4	main
sõna	doc_986203247109_item	3583782	et	4	main
koolis	doc_986203247109_item	3583796	et	4	main
koolivorm	doc_986203247109_item	3583800	et	3	main
arvamus	doc_986203247107_item	3583603	et	3	main
neist	doc_986203247107_item	3583607	et	4	main
olete	doc_986203247107_item	3583612	et	3	main
1	doc_986203247107_item	3583623	et	2	main
omakoolitunde	doc_986203247107_item	3583634	et	4	main
2	doc_986203247107_item	3583637	et	2	main
teksti	doc_986203247107_item	3583648	et	4	main
pikkus	doc_986203247107_item	3583650	et	4	main
on	doc_986203247107_item	3583651	et	4	main
olla	doc_986203247107_item	3583702	et	3	main
tagasihoidlik	doc_986203247107_item	3583703	et	3	main
sest	doc_986203247107_item	3583705	et	4	main
riidetud	doc_986203247107_item	3583704	et	4	main
ära	doc_986203247107_item	3583706	et	4	main
enda	doc_986203247107_item	3583708	et	4	main
poole	doc_986203247107_item	3583709	et	4	main
tähelepaneku	doc_986203247107_item	3583710	et	3	main
pöörata	doc_986203247107_item	3583707	et	4	main
kõige	doc_986203247107_item	3583711	et	4	main
tähtsam	doc_986203247107_item	3583712	et	4	main
alati	doc_986203247107_item	3583713	et	4	main
on	doc_986203247107_item	3583714	et	4	main
olla	doc_986203247107_item	3583715	et	3	main
puhtana	doc_986203247107_item	3583716	et	3	main
kas	doc_986203247109_item	3583739	et	3	main
mitte	doc_986203247109_item	3583745	et	3	main
1	doc_986203247109_item	3583751	et	2	main
tekkimisele	doc_986203247109_item	3583763	et	4	main
koos	doc_986203247109_item	3583771	et	4	main
kirjutage	doc_986203247109_item	3583772	et	3	main
joonitud	doc_986203247109_item	3583773	et	4	main
kasti	doc_986203247109_item	3583774	et	4	main
sest	doc_986203247109_item	3583788	et	4	main
see	doc_986203247109_item	3583789	et	3	main
aitab	doc_986203247109_item	3583790	et	3	main
arvates	doc_986203247109_item	3583795	et	4	main
olema	doc_986203247109_item	3583799	et	4	main
sarnane	doc_986203247109_item	3583804	et	4	main
ei	doc_986203247109_item	3583806	et	4	main
aga	doc_986203247109_item	3583832	et	3	main
iga	doc_986203247109_item	3583837	et	4	main
inimine	doc_986203247109_item	3583838	et	4	main
tohi	doc_986203247109_item	3583844	et	4	main
on	doc_986203247109_item	3583849	et	4	main
koolis	doc_986203247109_item	3583861	et	4	main
see	doc_986203247109_item	3583862	et	3	main
on	doc_986203247109_item	3583863	et	4	main
väga	doc_986203247109_item	3583864	et	3	main
on	doc_986203247109_item	3583868	et	4	main
mõnes	doc_986203247109_item	3583871	et	3	main
on	doc_986203247109_item	3583876	et	4	main
ja	doc_986203247107_item	3583717	et	3	main
korralikuna	doc_986203247107_item	3583718	et	3	main
see	doc_986203247107_item	3583719	et	3	main
on	doc_986203247107_item	3583720	et	4	main
minu	doc_986203247107_item	3583721	et	3	main
arvamus	doc_986203247107_item	3583722	et	3	main
aga	doc_986203247107_item	3583723	et	3	main
kui	doc_986203247107_item	3583724	et	3	main
palju	doc_986203247107_item	3583725	et	4	main
inimesi	doc_986203247107_item	3583726	et	4	main
nii	doc_986203247107_item	3583727	et	3	main
palju	doc_986203247107_item	3583728	et	4	main
arvumusi	doc_986203247107_item	3583729	et	4	main
lugege	doc_986203247107_item	3583604	et	3	main
kirjutage	doc_986203247107_item	3583610	et	3	main
koolil	doc_986203247107_item	3583625	et	4	main
oma	doc_986203247107_item	3583628	et	4	main
sest	doc_986203247107_item	3583630	et	4	main
see	doc_986203247107_item	3583631	et	3	main
aitab	doc_986203247107_item	3583632	et	3	main
kaasa	doc_986203247107_item	3583633	et	4	main
väide	doc_986203247107_item	3583636	et	4	main
koos	doc_986203247107_item	3583643	et	4	main
kirjutage	doc_986203247107_item	3583644	et	3	main
nõutav	doc_986203247107_item	3583649	et	4	main
sest	doc_986203247107_item	3583665	et	4	main
haigla	doc_986203247107_item	3583668	et	4	main
kus	doc_986203247107_item	3583669	et	3	main
kõik	doc_986203247107_item	3583670	et	4	main
lähevad	doc_986203247107_item	3583671	et	3	main
ühteviisi	doc_986203247107_item	3583672	et	3	main
haiglakittelistes	doc_986203247107_item	3583673	et	4	main
ja	doc_986203247107_item	3583674	et	3	main
kool	doc_986203247107_item	3583675	et	4	main
muutub	doc_986203247107_item	3583676	et	3	main
hallis	doc_986203247107_item	3583677	et	4	main
ja	doc_986203247107_item	3583678	et	3	main
samasuguses	doc_986203247107_item	3583679	et	3	main
aga	doc_986203247107_item	3583680	et	3	main
koolis	doc_986203247107_item	3583681	et	4	main
peab	doc_986203247107_item	3583683	et	4	main
alati	doc_986203247107_item	3583682	et	4	main
olema	doc_986203247107_item	3583684	et	4	main
väga	doc_986203247107_item	3583685	et	3	main
hea	doc_986203247107_item	3583686	et	4	main
ja	doc_986203247107_item	3583687	et	3	main
lõbus	doc_986203247107_item	3583688	et	4	main
tuju	doc_986203247107_item	3583689	et	4	main
koolis	doc_986203247107_item	3583690	et	4	main
peab	doc_986203247107_item	3583691	et	4	main
olena	doc_986203247107_item	3583692	et	4	main
hea	doc_986203247107_item	3583693	et	4	main
atmosfäär	doc_986203247107_item	3583694	et	3	main
aga	doc_986203247107_item	3583695	et	3	main
tohi	doc_986203247107_item	3583697	et	4	main
liiksed	doc_986203247107_item	3583698	et	4	main
ei	doc_986203247107_item	3583696	et	4	main
kaunistada	doc_986203247107_item	3583699	et	3	main
on	doc_986203247107_item	3583700	et	4	main
vaja	doc_986203247107_item	3583701	et	4	main
sisse	doc_986203247107_item	3583647	et	4	main
igal	doc_986203247107_item	3583658	et	3	main
koolil	doc_986203247107_item	3583659	et	4	main
ei	doc_986203247107_item	3583660	et	4	main
peaks	doc_986203247107_item	3583661	et	4	main
see	doc_986203247107_item	3583666	et	3	main
lugege	doc_986203247109_item	3583732	et	3	main
kirjutage	doc_986203247109_item	3583738	et	3	main
või	doc_986203247109_item	3583744	et	4	main
käivad	doc_986203247109_item	3583769	et	4	main
sisse	doc_986203247109_item	3583775	et	4	main
u	doc_986203247109_item	3583780	et	4	main
omakoolitunde	doc_986203247109_item	3583792	et	4	main
pea	doc_986203247109_item	3583798	et	4	main
teineteisega	doc_986203247109_item	3583803	et	3	main
õpilasel	doc_986203247109_item	3583805	et	3	main
ole	doc_986203247109_item	3583807	et	4	main
erinemusi	doc_986203247109_item	3583808	et	4	main
see	doc_986203247109_item	3583809	et	3	main
on	doc_986203247109_item	3583810	et	4	main
väga	doc_986203247109_item	3583811	et	3	main
paha	doc_986203247109_item	3583812	et	4	main
koolivorm	doc_986203247109_item	3583813	et	3	main
on	doc_986203247109_item	3583814	et	4	main
väga	doc_986203247109_item	3583815	et	3	main
ühesugune	doc_986203247109_item	3583816	et	3	main
ja	doc_986203247109_item	3583817	et	3	main
hall	doc_986203247109_item	3583818	et	4	main
see	doc_986203247109_item	3583819	et	3	main
muutub	doc_986203247109_item	3583820	et	3	main
inimise	doc_986203247109_item	3583821	et	4	main
kurvaks	doc_986203247109_item	3583822	et	3	main
igalajal	doc_986203247109_item	3583823	et	3	main
koolis	doc_986203247109_item	3583824	et	4	main
peab	doc_986203247109_item	3583825	et	4	main
oleme	doc_986203247109_item	3583826	et	3	main
heatuju	doc_986203247109_item	3583827	et	4	main
iga	doc_986203247109_item	3583828	et	4	main
laps	doc_986203247109_item	3583829	et	4	main
peab	doc_986203247109_item	3583830	et	4	main
anna	doc_986203247109_item	3583835	et	4	main
igapärane	doc_986203247109_item	3583841	et	4	main
aga	doc_986203247109_item	3583842	et	3	main
ei	doc_986203247109_item	3583843	et	4	main
inimene	doc_986203247109_item	3583848	et	3	main
ei	doc_986203247109_item	3583852	et	4	main
inimesele	doc_986203247109_item	3583855	et	3	main
inimene	doc_986203247109_item	3583857	et	3	main
tagasihoidlikult	doc_986203247109_item	3583860	et	4	main
ajal	doc_986203247109_item	3583867	et	4	main
pöördub	doc_986203247109_item	3583877	et	3	main
ma	doc_986203247109_item	3583880	et	3	main
pean	doc_881412446071_item	3583912	et	4	main
ökoloogia	doc_881412446071_item	3583913	et	4	main
meie	doc_881412446071_item	3583916	et	4	main
elu	doc_881412446071_item	3583917	et	4	main
teguriks	doc_881412446071_item	3583918	et	3	main
hea	doc_881412446071_item	3583926	et	4	main
kasulik	doc_881412446071_item	3583932	et	3	main
puhast	doc_881412446071_item	3583936	et	3	main
on	doc_881412446071_item	3583942	et	4	main
arvestatakse	doc_881412446071_item	3583962	et	3	main
elektrijaami	doc_881412446071_item	3583971	et	4	main
põlevkivi	doc_881412446071_item	3583977	et	4	main
arvamus	doc_986203247109_item	3583731	et	3	main
neist	doc_986203247109_item	3583735	et	4	main
selle	doc_986203247109_item	3583741	et	4	main
nõus	doc_986203247109_item	3583743	et	4	main
olema	doc_986203247109_item	3583755	et	4	main
oma	doc_986203247109_item	3583756	et	4	main
koolivorm	doc_986203247109_item	3583757	et	3	main
sest	doc_986203247109_item	3583758	et	4	main
see	doc_986203247109_item	3583759	et	3	main
aitab	doc_986203247109_item	3583760	et	3	main
kaasa	doc_986203247109_item	3583761	et	4	main
väide	doc_986203247109_item	3583764	et	4	main
nõutav	doc_986203247109_item	3583777	et	4	main
pikkus	doc_986203247109_item	3583778	et	4	main
on	doc_986203247109_item	3583779	et	4	main
igal	doc_986203247109_item	3583783	et	3	main
peaks	doc_986203247109_item	3583785	et	4	main
olema	doc_986203247109_item	3583786	et	4	main
koolivorm	doc_986203247109_item	3583787	et	3	main
tekkimisele	doc_986203247109_item	3583793	et	4	main
minu	doc_986203247109_item	3583794	et	3	main
on	doc_986203247109_item	3583802	et	4	main
naeratama	doc_986203247109_item	3583831	et	3	main
koolivorm	doc_986203247109_item	3583833	et	3	main
olema	doc_986203247109_item	3583840	et	4	main
individuaalne	doc_986203247109_item	3583850	et	3	main
koolivorm	doc_986203247109_item	3583851	et	3	main
segada	doc_986203247109_item	3583854	et	3	main
avada	doc_986203247109_item	3583856	et	3	main
tähtis	doc_986203247109_item	3583865	et	4	main
igal	doc_986203247109_item	3583866	et	3	main
on	doc_986203247109_item	3583873	et	4	main
see	doc_986203247109_item	3583875	et	3	main
essee	doc_881412446071_item	3583906	et	4	main
puutub	doc_881412446071_item	3583911	et	3	main
üks	doc_881412446071_item	3583914	et	3	main
sõna	doc_881412446071_item	3583919	et	4	main
ökoloogia	doc_881412446071_item	3583920	et	4	main
tähendab	doc_881412446071_item	3583921	et	3	main
elukord	doc_881412446071_item	3583928	et	3	main
paljud	doc_881412446071_item	3583940	et	3	main
ja	doc_881412446071_item	3583956	et	3	main
tööstuskeskus	doc_881412446071_item	3583965	et	3	main
palju	doc_881412446071_item	3583968	et	4	main
tööstusettevõteid	doc_881412446071_item	3583969	et	4	main
kaks	doc_881412446071_item	3583970	et	3	main
tuhka	doc_881412446071_item	3583975	et	4	main
ja	doc_881412446071_item	3583976	et	3	main
kopsuvähki	doc_881412446071_item	3583984	et	4	main
mõjuvad	doc_881412446071_item	3583992	et	4	main
põhja	doc_881412446071_item	3584021	et	4	main
mina	doc_881412446071_item	3584031	et	4	main
olen	doc_881412446071_item	3584032	et	3	main
varem	doc_881412446071_item	3584042	et	4	main
siis	doc_881412446071_item	3584051	et	3	main
kõige	doc_881412446071_item	3584058	et	4	main
vesi	doc_881412446071_item	3584064	et	4	main
et	doc_881412446071_item	3584065	et	3	main
kirjeldatud	doc_881412446071_item	3584066	et	4	main
probleeme	doc_881412446071_item	3584067	et	3	main
lahendada	doc_881412446071_item	3584068	et	3	main
tööstuses	doc_881412446071_item	3584077	et	3	main
töötleda	doc_881412446071_item	3584078	et	4	main
uusi	doc_881412446071_item	3584079	et	3	main
transpordivahendeid	doc_881412446071_item	3584080	et	3	main
ei	doc_986203247109_item	3583834	et	4	main
seda	doc_986203247109_item	3583836	et	3	main
pea	doc_986203247109_item	3583853	et	4	main
peab	doc_986203247109_item	3583858	et	4	main
riietuma	doc_986203247109_item	3583859	et	3	main
reegleid	doc_986203247109_item	3583870	et	3	main
vaja	doc_986203247109_item	3583886	et	4	main
meie	doc_986203247109_item	3583887	et	4	main
ajal	doc_986203247109_item	3583888	et	4	main
koolitus	doc_986203247109_item	3583889	et	4	main
ei	doc_986203247109_item	3583890	et	4	main
pea	doc_986203247109_item	3583891	et	4	main
sõltuma	doc_986203247109_item	3583892	et	3	main
koolivormilt	doc_986203247109_item	3583893	et	3	main
igaüks	doc_986203247109_item	3583894	et	3	main
valib	doc_986203247109_item	3583895	et	3	main
ise	doc_986203247109_item	3583896	et	4	main
mida	doc_986203247109_item	3583897	et	4	main
riietuma	doc_986203247109_item	3583898	et	3	main
ma	doc_986203247109_item	3583899	et	3	main
on	doc_986203247109_item	3583900	et	4	main
mitte	doc_986203247109_item	3583901	et	3	main
nõus	doc_986203247109_item	3583902	et	4	main
sellega	doc_986203247109_item	3583903	et	3	main
väitega	doc_986203247109_item	3583904	et	3	main
harva	doc_986203247109_item	3583879	et	4	main
mõtlen	doc_986203247109_item	3583881	et	3	main
et	doc_986203247109_item	3583882	et	3	main
ei	doc_986203247109_item	3583884	et	4	main
ole	doc_986203247109_item	3583885	et	4	main
minusse	doc_881412446071_item	3583910	et	3	main
minu	doc_881412446071_item	3583922	et	3	main
tagastab	doc_881412446071_item	3583929	et	3	main
toitumine	doc_881412446071_item	3583933	et	4	main
võimalust	doc_881412446071_item	3583934	et	3	main
maakond	doc_881412446071_item	3583961	et	3	main
eestima	doc_881412446071_item	3583964	et	4	main
asub	doc_881412446071_item	3583967	et	3	main
põlemisjäätmeid	doc_881412446071_item	3583978	et	3	main
meie	doc_881412446071_item	3583982	et	4	main
kui	doc_881412446071_item	3583986	et	3	main
eestis	doc_881412446071_item	3583988	et	3	main
ettevõted	doc_881412446071_item	3583991	et	4	main
see	doc_881412446071_item	3584006	et	3	main
viinud	doc_881412446071_item	3584008	et	4	main
sellele	doc_881412446071_item	3584009	et	4	main
et	doc_881412446071_item	3584010	et	3	main
on	doc_881412446071_item	3584018	et	4	main
balti	doc_881412446071_item	3584019	et	3	main
aina	doc_881412446071_item	3584029	et	4	main
probleemid	doc_881412446071_item	3584036	et	3	main
ei	doc_881412446071_item	3584049	et	4	main
pean	doc_881412446071_item	3584053	et	4	main
et	doc_881412446071_item	3584055	et	3	main
rohkem	doc_881412446071_item	3584070	et	4	main
kasutada	doc_881412446071_item	3584071	et	3	main
alternatiivseid	doc_881412446071_item	3584072	et	3	main
näfta	doc_881412446071_item	3584106	et	4	main
keegi	doc_881412446071_item	3584121	et	4	main
peavad	doc_881412446071_item	3584157	et	4	main
võimalikult	doc_881412446071_item	3584166	et	4	main
kindlasti	doc_881412446071_item	3584171	et	3	main
mida	doc_881412446071_item	3584181	et	4	main
ma	doc_881412446071_item	3584182	et	3	main
võin	doc_881412446071_item	3584183	et	3	main
olukorrast	doc_881412446071_item	3584193	et	4	main
sõltub	doc_881412446071_item	3584194	et	3	main
meie	doc_881412446071_item	3584195	et	4	main
ja	doc_881412446071_item	3584196	et	3	main
järgmiste	doc_881412446071_item	3584197	et	3	main
see	doc_986203247109_item	3583883	et	3	main
mis	doc_881412446071_item	3583909	et	4	main
tähtsamateks	doc_881412446071_item	3583915	et	4	main
jaoks	doc_881412446071_item	3583923	et	4	main
eelkõge	doc_881412446071_item	3583924	et	4	main
tervis	doc_881412446071_item	3583925	et	3	main
ja	doc_881412446071_item	3583931	et	3	main
vett	doc_881412446071_item	3583937	et	3	main
õhuta	doc_881412446071_item	3583939	et	4	main
haigestumised	doc_881412446071_item	3583941	et	4	main
see	doc_881412446071_item	3583960	et	3	main
mis	doc_881412446071_item	3583972	et	4	main
paiskavad	doc_881412446071_item	3583973	et	4	main
pärast	doc_881412446071_item	3583980	et	4	main
mujal	doc_881412446071_item	3583987	et	3	main
ka	doc_881412446071_item	3583989	et	3	main
ainult	doc_881412446071_item	3583994	et	4	main
inimeste	doc_881412446071_item	3583995	et	3	main
kuid	doc_881412446071_item	3583997	et	4	main
pöördamatult	doc_881412446071_item	3584014	et	4	main
häivinud	doc_881412446071_item	3584015	et	4	main
lasknud	doc_881412446071_item	3584022	et	4	main
mis	doc_881412446071_item	3584025	et	4	main
veendunud	doc_881412446071_item	3584033	et	4	main
et	doc_881412446071_item	3584034	et	3	main
need	doc_881412446071_item	3584035	et	3	main
seda	doc_881412446071_item	3584043	et	3	main
keskkona	doc_881412446071_item	3584046	et	4	main
säästumise	doc_881412446071_item	3584047	et	4	main
tendents	doc_881412446071_item	3584048	et	3	main
ma	doc_881412446071_item	3584052	et	3	main
võimalikuks	doc_881412446071_item	3584054	et	3	main
saab	doc_881412446071_item	3584056	et	3	main
võiks	doc_881412446071_item	3584069	et	4	main
mis	doc_881412446071_item	3584081	et	4	main
maagaas	doc_881412446071_item	3584108	et	3	main
paljudele	doc_881412446071_item	3584113	et	3	main
mitte	doc_881412446071_item	3584150	et	3	main
prahi	doc_881412446071_item	3584153	et	4	main
korras	doc_881412446071_item	3584161	et	4	main
hoida	doc_881412446071_item	3584162	et	3	main
et	doc_881412446071_item	3584163	et	3	main
heitgaasi	doc_881412446071_item	3584168	et	4	main
mina	doc_881412446071_item	3584169	et	4	main
ütelda	doc_881412446071_item	3584172	et	4	main
et	doc_881412446071_item	3584173	et	3	main
suhtun	doc_881412446071_item	3584174	et	3	main
loodusele	doc_881412446071_item	3584175	et	4	main
hoida	doc_881412446071_item	3584185	et	3	main
minu	doc_881412446071_item	3583907	et	3	main
ökoelu	doc_881412446071_item	3583908	et	4	main
ökoloogiline	doc_881412446071_item	3583927	et	4	main
tervislik	doc_881412446071_item	3583930	et	3	main
juua	doc_881412446071_item	3583935	et	3	main
ja	doc_881412446071_item	3583938	et	3	main
põhjustatud	doc_881412446071_item	3583943	et	4	main
sellega	doc_881412446071_item	3583944	et	3	main
et	doc_881412446071_item	3583945	et	3	main
rohkemal	doc_881412446071_item	3583946	et	4	main
inimkonna	doc_881412446071_item	3583947	et	4	main
osal	doc_881412446071_item	3583948	et	3	main
ei	doc_881412446071_item	3583949	et	4	main
ole	doc_881412446071_item	3583950	et	4	main
niisugust	doc_881412446071_item	3583951	et	3	main
võimalust	doc_881412446071_item	3583952	et	3	main
ma	doc_881412446071_item	3583953	et	3	main
olen	doc_881412446071_item	3583954	et	3	main
sündinud	doc_881412446071_item	3583955	et	4	main
elanud	doc_881412446071_item	3583957	et	4	main
seniajani	doc_881412446071_item	3583958	et	3	main
ida-virumaal	doc_881412446071_item	3583959	et	4	main
nagu	doc_881412446071_item	3583963	et	3	main
siin	doc_881412446071_item	3583966	et	4	main
õhku	doc_881412446071_item	3583974	et	4	main
selle	doc_881412446071_item	3583979	et	4	main
esineb	doc_881412446071_item	3583981	et	3	main
piirkonnas	doc_881412446071_item	3583983	et	4	main
need	doc_881412446071_item	3583990	et	3	main
loodust	doc_881412446071_item	3583999	et	4	main
tehased	doc_881412446071_item	3584000	et	3	main
ja	doc_881412446071_item	3584001	et	3	main
vabrikud	doc_881412446071_item	3584002	et	3	main
lasevad	doc_881412446071_item	3584003	et	3	main
reovett	doc_881412446071_item	3584004	et	3	main
veekogudesse	doc_881412446071_item	3584005	et	3	main
globaalsem	doc_881412446071_item	3584016	et	4	main
probleem	doc_881412446071_item	3584017	et	3	main
keemilist	doc_881412446071_item	3584023	et	4	main
suplemine	doc_881412446071_item	3584027	et	4	main
meeres	doc_881412446071_item	3584028	et	3	main
ohtlikumaks	doc_881412446071_item	3584030	et	4	main
ja	doc_881412446071_item	3584040	et	3	main
mida	doc_881412446071_item	3584041	et	4	main
kui	doc_881412446071_item	3584045	et	3	main
ei	doc_881412446071_item	3584082	et	4	main
küttemaavarad	doc_881412446071_item	3584110	et	3	main
lõket	doc_881412446071_item	3584149	et	4	main
jääda	doc_881412446071_item	3584152	et	4	main
mitte	doc_881412446071_item	3584154	et	3	main
visata	doc_881412446071_item	3584155	et	4	main
autojuhid	doc_881412446071_item	3584156	et	3	main
transpordivahendid	doc_881412446071_item	3584164	et	3	main
paiskaksid	doc_881412446071_item	3584165	et	4	main
võin	doc_881412446071_item	3584170	et	3	main
et	doc_881412446071_item	3584184	et	3	main
meie	doc_881412446071_item	3584186	et	4	main
loodust	doc_881412446071_item	3584187	et	4	main
kokkuvõtteks	doc_881412446071_item	3584188	et	3	main
tahaksin	doc_881412446071_item	3584189	et	3	main
põlvkondade	doc_881412446071_item	3584198	et	3	main
tervis	doc_881412446071_item	3584199	et	3	main
sagedamini	doc_881412446071_item	3583985	et	4	main
mitte	doc_881412446071_item	3583993	et	3	main
tervist	doc_881412446071_item	3583996	et	4	main
ka	doc_881412446071_item	3583998	et	3	main
on	doc_881412446071_item	3584007	et	4	main
paljud	doc_881412446071_item	3584011	et	3	main
veekogud	doc_881412446071_item	3584012	et	3	main
on	doc_881412446071_item	3584013	et	4	main
meere	doc_881412446071_item	3584020	et	4	main
relva	doc_881412446071_item	3584024	et	4	main
teeb	doc_881412446071_item	3584026	et	3	main
on	doc_881412446071_item	3584037	et	4	main
vaja	doc_881412446071_item	3584038	et	4	main
lahendada	doc_881412446071_item	3584039	et	3	main
parem	doc_881412446071_item	3584044	et	4	main
muutu	doc_881412446071_item	3584050	et	4	main
varsti	doc_881412446071_item	3584057	et	3	main
kaillimaks	doc_881412446071_item	3584059	et	4	main
ja	doc_881412446071_item	3584060	et	3	main
kindlaks	doc_881412446071_item	3584061	et	3	main
valuutaks	doc_881412446071_item	3584062	et	3	main
puhas	doc_881412446071_item	3584063	et	3	main
eheergiaallikaid	doc_881412446071_item	3584073	et	4	main
kasutada	doc_881412446071_item	3584074	et	3	main
turvalisi	doc_881412446071_item	3584075	et	4	main
töövahendeid	doc_881412446071_item	3584076	et	3	main
paistaks	doc_881412446071_item	3584083	et	3	main
õhku	doc_881412446071_item	3584084	et	4	main
heitgaasi	doc_881412446071_item	3584085	et	4	main
ehituses	doc_881412446071_item	3584086	et	4	main
on	doc_881412446071_item	3584087	et	4	main
vaja	doc_881412446071_item	3584088	et	4	main
kasutada	doc_881412446071_item	3584089	et	3	main
keskkonnasõbralikke	doc_881412446071_item	3584090	et	3	main
materjalli	doc_881412446071_item	3584091	et	4	main
kuid	doc_881412446071_item	3584092	et	4	main
peamine	doc_881412446071_item	3584093	et	3	main
raskus	doc_881412446071_item	3584094	et	4	main
on	doc_881412446071_item	3584095	et	4	main
selles	doc_881412446071_item	3584096	et	4	main
et	doc_881412446071_item	3584097	et	3	main
paljude	doc_881412446071_item	3584098	et	3	main
maade	doc_881412446071_item	3584099	et	3	main
majandused	doc_881412446071_item	3584100	et	4	main
on	doc_881412446071_item	3584101	et	4	main
rajatud	doc_881412446071_item	3584102	et	4	main
nissugustel	doc_881412446071_item	3584103	et	4	main
energiaallikatel	doc_881412446071_item	3584104	et	4	main
nagu	doc_881412446071_item	3584105	et	3	main
ja	doc_881412446071_item	3584107	et	3	main
kindlustanud	doc_881412446071_item	3584112	et	4	main
riigidele	doc_881412446071_item	3584114	et	4	main
firmadele	doc_881412446071_item	3584116	et	3	main
suured	doc_881412446071_item	3584117	et	3	main
tulud	doc_881412446071_item	3584118	et	3	main
kustutatud	doc_881412446071_item	3584151	et	4	main
aotosid	doc_881412446071_item	3584159	et	4	main
heas	doc_881412446071_item	3584160	et	3	main
sõbralikult	doc_881412446071_item	3584176	et	4	main
ja	doc_881412446071_item	3584177	et	3	main
püüan	doc_881412446071_item	3584178	et	3	main
teha	doc_881412446071_item	3584179	et	3	main
need	doc_881412446071_item	3584109	et	3	main
on	doc_881412446071_item	3584111	et	4	main
ja	doc_881412446071_item	3584115	et	3	main
millestest	doc_881412446071_item	3584119	et	4	main
mitte	doc_881412446071_item	3584120	et	3	main
ei	doc_881412446071_item	3584122	et	4	main
taha	doc_881412446071_item	3584123	et	4	main
loobuda	doc_881412446071_item	3584124	et	3	main
olen	doc_881412446071_item	3584125	et	3	main
veendunud	doc_881412446071_item	3584126	et	4	main
et	doc_881412446071_item	3584127	et	3	main
iga	doc_881412446071_item	3584128	et	4	main
inimene	doc_881412446071_item	3584129	et	3	main
võib	doc_881412446071_item	3584130	et	3	main
loodust	doc_881412446071_item	3584131	et	4	main
kaitsta	doc_881412446071_item	3584132	et	4	main
ja	doc_881412446071_item	3584133	et	3	main
keskkonast	doc_881412446071_item	3584134	et	4	main
igaüks	doc_881412446071_item	3584136	et	3	main
hoolitseda	doc_881412446071_item	3584135	et	3	main
meist	doc_881412446071_item	3584137	et	3	main
peaks	doc_881412446071_item	3584138	et	4	main
oma	doc_881412446071_item	3584139	et	4	main
käitumisest	doc_881412446071_item	3584140	et	4	main
jälgima	doc_881412446071_item	3584141	et	4	main
näiteks	doc_881412446071_item	3584142	et	4	main
looduses	doc_881412446071_item	3584143	et	4	main
puhkamas	doc_881412446071_item	3584144	et	3	main
ei	doc_881412446071_item	3584145	et	4	main
tohi	doc_881412446071_item	3584146	et	4	main
taimeid	doc_881412446071_item	3584147	et	4	main
puruneda	doc_881412446071_item	3584148	et	3	main
oma	doc_881412446071_item	3584158	et	4	main
vähem	doc_881412446071_item	3584167	et	4	main
kõik	doc_881412446071_item	3584180	et	4	main
eesti	doc_767882159207_item	3584523	et	4	main
keele	doc_767882159207_item	3584527	et	4	main
kirjutamine	doc_767882159207_item	3584529	et	4	main
mis	doc_767882159207_item	3584533	et	4	main
teeb	doc_767882159207_item	3584534	et	3	main
eestlastest	doc_767882159207_item	3584535	et	4	main
laulurahva	doc_767882159207_item	3584536	et	3	main
ja	doc_767882159207_item	3584547	et	3	main
üldistav	doc_767882159207_item	3584548	et	4	main
tuginema	doc_767882159207_item	3584549	et	3	main
loengus	doc_767882159207_item	3584550	et	3	main
ja	doc_767882159207_item	3584551	et	3	main
lugemistekstis	doc_767882159207_item	3584552	et	3	main
esitatud	doc_767882159207_item	3584553	et	4	main
faktidele	doc_767882159207_item	3584554	et	3	main
palju	doc_767882159207_item	3584562	et	4	main
eesti	doc_767882159207_item	3584573	et	4	main
laul	doc_767882159207_item	3584576	et	4	main
tunnete	doc_767882159207_item	3584591	et	4	main
eeslaulja	doc_767882159207_item	3584623	et	4	main
mis	doc_767882159207_item	3584630	et	4	main
laulupidu	doc_767882159207_item	3584635	et	4	main
kujunes	doc_767882159207_item	3584640	et	3	main
rahvusliku	doc_767882159207_item	3584642	et	3	main
saartel	doc_767882159207_item	3584645	et	3	main
laulukombed	doc_767882159207_item	3584649	et	3	main
midagi	doc_767882159207_item	3584666	et	4	main
venemaalt	doc_767882159207_item	3584668	et	3	main
nagu	doc_767882159207_item	3584669	et	3	main
öelda	doc_881412446071_item	3584190	et	4	main
et	doc_881412446071_item	3584191	et	3	main
ökoloogilisest	doc_881412446071_item	3584192	et	4	main
keele	doc_767882159207_item	3584524	et	4	main
essee	doc_767882159207_item	3584537	et	4	main
olema	doc_767882159207_item	3584544	et	4	main
väiteid	doc_767882159207_item	3584555	et	4	main
traditsioon	doc_767882159207_item	3584566	et	3	main
mis	doc_767882159207_item	3584584	et	4	main
laul	doc_767882159207_item	3584587	et	4	main
meil	doc_767882159207_item	3584594	et	4	main
on	doc_767882159207_item	3584595	et	4	main
kurb	doc_767882159207_item	3584596	et	3	main
siis	doc_767882159207_item	3584597	et	3	main
essee	doc_767882159207_item	3584522	et	4	main
kirjutage	doc_767882159207_item	3584530	et	3	main
teemal	doc_767882159207_item	3584532	et	3	main
essee	doc_767882159207_item	3584542	et	4	main
peab	doc_767882159207_item	3584543	et	4	main
maailmas	doc_767882159207_item	3584560	et	3	main
on	doc_767882159207_item	3584561	et	4	main
kellel	doc_767882159207_item	3584564	et	4	main
rahvas	doc_767882159207_item	3584574	et	4	main
on	doc_767882159207_item	3584585	et	4	main
see	doc_767882159207_item	3584588	et	3	main
kui	doc_767882159207_item	3584593	et	3	main
esitasid	doc_767882159207_item	3584622	et	4	main
oli	doc_767882159207_item	3584631	et	3	main
laenatud	doc_767882159207_item	3584632	et	4	main
tänapäeval	doc_767882159207_item	3584647	et	3	main
rahvukostüümid	doc_767882159207_item	3584651	et	3	main
rohkem	doc_767882159207_item	3584653	et	4	main
ja	doc_767882159207_item	3584664	et	3	main
tulnud	doc_767882159207_item	3584667	et	4	main
tänapäeval	doc_767882159207_item	3584673	et	3	main
rahvalaulu	doc_767882159207_item	3584674	et	4	main
laulamine	doc_767882159207_item	3584675	et	4	main
sellistes	doc_767882159207_item	3584692	et	4	main
peodes	doc_767882159207_item	3584693	et	3	main
suur	doc_767882159207_item	3584694	et	3	main
pääseda	doc_767882159207_item	3584707	et	3	main
peole	doc_767882159207_item	3584709	et	4	main
ja	doc_767882159207_item	3584710	et	3	main
ka	doc_767882159207_item	3584722	et	3	main
vanad	doc_767882159207_item	3584723	et	3	main
kogu	doc_767882159207_item	3584724	et	4	main
eestist	doc_767882159207_item	3584725	et	3	main
on	doc_767882159207_item	3584726	et	4	main
hingas	doc_767882159207_item	3584763	et	3	main
mis	doc_767882159207_item	3584764	et	4	main
siiski	doc_767882159207_item	3584765	et	4	main
teeb	doc_767882159207_item	3584766	et	3	main
eestlastest	doc_767882159207_item	3584767	et	4	main
laulurahva	doc_767882159207_item	3584768	et	3	main
see	doc_767882159207_item	3584769	et	3	main
on	doc_767882159207_item	3584770	et	4	main
traditsioon	doc_767882159207_item	3584771	et	3	main
mis	doc_767882159207_item	3584772	et	4	main
tekkis	doc_767882159207_item	3584773	et	3	main
rohkem	doc_767882159207_item	3584774	et	4	main
kui	doc_767882159207_item	3584775	et	3	main
tuhad	doc_767882159207_item	3584776	et	3	main
aastad	doc_767882159207_item	3584777	et	3	main
tagasi	doc_767882159207_item	3584778	et	3	main
ja	doc_767882159207_item	3584779	et	3	main
need	doc_767882159207_item	3584780	et	3	main
traditsioonid	doc_767882159207_item	3584781	et	3	main
säilitasid	doc_767882159207_item	3584782	et	4	main
ka	doc_767882159207_item	3584783	et	3	main
tänapäeval	doc_767882159207_item	3584784	et	3	main
kui	doc_767882159207_item	3584525	et	3	main
essee	doc_767882159207_item	3584531	et	4	main
300	doc_767882159207_item	3584539	et	2	main
arutlev	doc_767882159207_item	3584545	et	4	main
on	doc_767882159207_item	3584556	et	4	main
rahvu	doc_767882159207_item	3584563	et	4	main
laulda	doc_767882159207_item	3584567	et	4	main
tantsida	doc_767882159207_item	3584569	et	3	main
kuulub	doc_767882159207_item	3584571	et	3	main
eestlastele	doc_767882159207_item	3584575	et	4	main
oli	doc_767882159207_item	3584577	et	3	main
alati	doc_767882159207_item	3584578	et	4	main
emotsionaalne	doc_767882159207_item	3584579	et	3	main
väljendusvahendi	doc_767882159207_item	3584580	et	3	main
ja	doc_767882159207_item	3584581	et	3	main
sotsiaalne	doc_767882159207_item	3584582	et	3	main
teguvusena	doc_767882159207_item	3584583	et	4	main
laul	doc_767882159207_item	3584586	et	4	main
on	doc_767882159207_item	3584589	et	4	main
oma	doc_767882159207_item	3584590	et	4	main
me	doc_767882159207_item	3584598	et	4	main
laulame	doc_767882159207_item	3584599	et	4	main
kurva	doc_767882159207_item	3584600	et	3	main
laulu	doc_767882159207_item	3584601	et	4	main
kui	doc_767882159207_item	3584602	et	3	main
meil	doc_767882159207_item	3584603	et	4	main
on	doc_767882159207_item	3584604	et	4	main
hea	doc_767882159207_item	3584605	et	4	main
tunne	doc_767882159207_item	3584606	et	4	main
siis	doc_767882159207_item	3584607	et	3	main
me	doc_767882159207_item	3584608	et	4	main
laulame	doc_767882159207_item	3584609	et	4	main
ja	doc_767882159207_item	3584610	et	3	main
tantsime	doc_767882159207_item	3584611	et	3	main
nii	doc_767882159207_item	3584612	et	3	main
ka	doc_767882159207_item	3584613	et	3	main
eestlased	doc_767882159207_item	3584614	et	3	main
kõige	doc_767882159207_item	3584615	et	4	main
vanemat	doc_767882159207_item	3584616	et	4	main
laulutraditsiooni	doc_767882159207_item	3584617	et	4	main
esindab	doc_767882159207_item	3584618	et	3	main
regivärsiline	doc_767882159207_item	3584619	et	4	main
rahvalaul	doc_767882159207_item	3584620	et	4	main
regilaulu	doc_767882159207_item	3584621	et	4	main
riimiline	doc_767882159207_item	3584628	et	4	main
esimene	doc_767882159207_item	3584634	et	3	main
tartus	doc_767882159207_item	3584637	et	3	main
sellest	doc_767882159207_item	3584639	et	4	main
eestlaste	doc_767882159207_item	3584641	et	4	main
olid	doc_767882159207_item	3584657	et	4	main
merel	doc_767882159207_item	3584658	et	3	main
rootsist	doc_767882159207_item	3584672	et	3	main
vähenenud	doc_767882159207_item	3584678	et	4	main
esinevad	doc_767882159207_item	3584682	et	4	main
rahvalaulu	doc_767882159207_item	3584686	et	4	main
hea	doc_767882159207_item	3584688	et	4	main
tallinnas	doc_767882159207_item	3584699	et	4	main
toimub	doc_767882159207_item	3584700	et	3	main
teise	doc_767882159207_item	3584526	et	4	main
test	doc_767882159207_item	3584528	et	3	main
pikkus	doc_767882159207_item	3584538	et	4	main
350	doc_767882159207_item	3584540	et	2	main
sõna	doc_767882159207_item	3584541	et	4	main
analüüsiv	doc_767882159207_item	3584546	et	4	main
soovitatav	doc_767882159207_item	3584557	et	4	main
illustreerida	doc_767882159207_item	3584558	et	3	main
näidetega	doc_767882159207_item	3584559	et	3	main
on	doc_767882159207_item	3584565	et	4	main
ja	doc_767882159207_item	3584568	et	3	main
nendele	doc_767882159207_item	3584570	et	4	main
ka	doc_767882159207_item	3584572	et	3	main
väljendamine	doc_767882159207_item	3584592	et	4	main
rahvalaul	doc_767882159207_item	3584629	et	4	main
oli	doc_767882159207_item	3584636	et	3	main
ja	doc_767882159207_item	3584638	et	3	main
liikumise	doc_767882159207_item	3584643	et	4	main
kõrghetk	doc_767882159207_item	3584644	et	3	main
säilitasid	doc_767882159207_item	3584648	et	4	main
ja	doc_767882159207_item	3584650	et	3	main
laulsid	doc_767882159207_item	3584652	et	4	main
naised	doc_767882159207_item	3584654	et	3	main
sest	doc_767882159207_item	3584655	et	4	main
mehed	doc_767882159207_item	3584656	et	3	main
lauludest	doc_767882159207_item	3584665	et	3	main
tallinnas	doc_767882159207_item	3584676	et	4	main
ikka	doc_767882159207_item	3584680	et	4	main
laulavad	doc_767882159207_item	3584685	et	4	main
tallinna	doc_767882159207_item	3584702	et	4	main
tahavad	doc_767882159207_item	3584706	et	3	main
kõik	doc_767882159207_item	3584715	et	4	main
kõik	doc_767882159207_item	3584729	et	4	main
hea	doc_767882159207_item	3584736	et	4	main
sellele	doc_767882159207_item	3584739	et	4	main
tullakse	doc_767882159207_item	3584746	et	3	main
võib	doc_767882159207_item	3584750	et	3	main
leida	doc_767882159207_item	3584751	et	3	main
endale	doc_767882159207_item	3584752	et	4	main
sõpru	doc_767882159207_item	3584753	et	3	main
see	doc_767882159207_item	3584754	et	3	main
ja	doc_767882159207_item	3584758	et	3	main
alati	doc_767882159207_item	3584762	et	4	main
essee	doc_767882159206_item	3584785	et	4	main
keele	doc_767882159206_item	3584787	et	4	main
teise	doc_767882159206_item	3584789	et	4	main
essee	doc_767882159206_item	3584794	et	4	main
tuginema	doc_767882159206_item	3584812	et	3	main
vanal	doc_767882159206_item	3584854	et	3	main
tuli	doc_767882159206_item	3584857	et	4	main
meie	doc_767882159206_item	3584858	et	4	main
päevani	doc_767882159206_item	3584859	et	3	main
erinevad	doc_767882159206_item	3584866	et	4	main
aga	doc_767882159206_item	3584867	et	3	main
see	doc_767882159206_item	3584868	et	3	main
tähtis	doc_767882159206_item	3584872	et	4	main
on	doc_767882159206_item	3584874	et	4	main
on	doc_767882159206_item	3584878	et	4	main
veel	doc_767882159206_item	3584879	et	4	main
ansamblid	doc_767882159206_item	3584880	et	3	main
et	doc_767882159206_item	3584892	et	3	main
kultuuriidentiteeti	doc_767882159206_item	3584896	et	4	main
aastad	doc_767882159206_item	3584908	et	3	main
nõukogude	doc_767882159206_item	3584913	et	3	main
oleks	doc_767882159206_item	3584916	et	3	main
minu	doc_767882159206_item	3584924	et	3	main
arust	doc_767882159206_item	3584925	et	4	main
huvitavad	doc_767882159206_item	3584929	et	4	main
traditsioonid	doc_767882159206_item	3584934	et	3	main
venemaal	doc_767882159206_item	3584967	et	4	main
nagu	doc_767882159206_item	3584968	et	3	main
tuli	doc_767882159206_item	3584986	et	4	main
regivärsilist	doc_767882159206_item	3584994	et	4	main
sest	doc_767882159206_item	3585000	et	4	main
xviii	doc_767882159206_item	3585004	et	4	main
ja	doc_767882159206_item	3585009	et	3	main
kui	doc_767882159206_item	3585014	et	3	main
oli	doc_767882159206_item	3585017	et	3	main
põhja	doc_767882159206_item	3585018	et	4	main
euroopast	doc_767882159206_item	3585019	et	3	main
ka	doc_767882159206_item	3585024	et	3	main
ja	doc_767882159207_item	3584624	et	3	main
koor	doc_767882159207_item	3584625	et	4	main
pärast	doc_767882159207_item	3584626	et	4	main
tekis	doc_767882159207_item	3584627	et	3	main
euroopast	doc_767882159207_item	3584633	et	3	main
kus	doc_767882159207_item	3584646	et	3	main
eesti	doc_767882159207_item	3584659	et	4	main
folklöör	doc_767882159207_item	3584660	et	4	main
koosneb	doc_767882159207_item	3584661	et	3	main
tantsudest	doc_767882159207_item	3584662	et	3	main
mängudest	doc_767882159207_item	3584663	et	3	main
aga	doc_767882159207_item	3584679	et	3	main
ansamblid	doc_767882159207_item	3584683	et	3	main
osa	doc_767882159207_item	3584695	et	4	main
võttavad	doc_767882159207_item	3584696	et	4	main
noored	doc_767882159207_item	3584697	et	3	main
inimesed	doc_767882159207_item	3584698	et	3	main
lauluväljakul	doc_767882159207_item	3584703	et	3	main
toonud	doc_767882159207_item	3584713	et	4	main
inimesed	doc_767882159207_item	3584716	et	3	main
sellel	doc_767882159207_item	3584717	et	4	main
päeval	doc_767882159207_item	3584718	et	3	main
nii	doc_767882159207_item	3584719	et	3	main
noored	doc_767882159207_item	3584720	et	3	main
kui	doc_767882159207_item	3584721	et	3	main
koos	doc_767882159207_item	3584727	et	4	main
ja	doc_767882159207_item	3584728	et	3	main
see	doc_767882159207_item	3584732	et	3	main
lisaks	doc_767882159207_item	3584738	et	4	main
on	doc_767882159207_item	3584742	et	4	main
rahvapidu	doc_767882159207_item	3584744	et	4	main
koos	doc_767882159207_item	3584747	et	4	main
perega	doc_767882159207_item	3584748	et	3	main
kus	doc_767882159207_item	3584749	et	3	main
elamus	doc_767882159207_item	3584757	et	4	main
jäävad	doc_767882159207_item	3584761	et	4	main
instrumendid	doc_767882159207_item	3584670	et	3	main
midagi	doc_767882159207_item	3584671	et	4	main
on	doc_767882159207_item	3584677	et	4	main
vabaõhumuuseumis	doc_767882159207_item	3584681	et	3	main
kes	doc_767882159207_item	3584684	et	4	main
kõige	doc_767882159207_item	3584687	et	4	main
on	doc_767882159207_item	3584689	et	4	main
see	doc_767882159207_item	3584690	et	3	main
et	doc_767882159207_item	3584691	et	3	main
laulupidu	doc_767882159207_item	3584701	et	4	main
neid	doc_767882159207_item	3584711	et	4	main
on	doc_767882159207_item	3584712	et	4	main
rahvalaulu	doc_767882159207_item	3584731	et	4	main
see	doc_767882159207_item	3584741	et	3	main
keele	doc_767882159206_item	3584790	et	4	main
teemal	doc_767882159206_item	3584795	et	3	main
olema	doc_767882159206_item	3584807	et	4	main
üldistav	doc_767882159206_item	3584811	et	4	main
laul	doc_767882159206_item	3584823	et	4	main
ja	doc_767882159206_item	3584824	et	3	main
ravhas	doc_767882159206_item	3584842	et	4	main
selles	doc_767882159206_item	3584843	et	4	main
stiilid	doc_767882159206_item	3584860	et	4	main
ei	doc_767882159206_item	3584869	et	4	main
kes	doc_767882159206_item	3584881	et	4	main
kõige	doc_767882159206_item	3584885	et	4	main
minu	doc_767882159206_item	3584887	et	3	main
arust	doc_767882159206_item	3584888	et	4	main
on	doc_767882159206_item	3584889	et	4	main
said	doc_767882159206_item	3584894	et	4	main
ja	doc_767882159206_item	3584897	et	3	main
laulutraditsiooni	doc_767882159206_item	3584898	et	4	main
hoida	doc_767882159206_item	3584899	et	3	main
tänapäevaseni	doc_767882159206_item	3584900	et	4	main
aga	doc_767882159206_item	3584901	et	3	main
tsaari	doc_767882159206_item	3584910	et	4	main
laulutraditsioonid	doc_767882159206_item	3584922	et	3	main
jne	doc_767882159206_item	3584923	et	4	main
ka	doc_767882159206_item	3584932	et	3	main
sõnu	doc_767882159206_item	3584965	et	4	main
alguses	doc_767882159206_item	3584980	et	4	main
mis	doc_767882159206_item	3584991	et	4	main
tuli	doc_767882159206_item	3584992	et	4	main
ei	doc_767882159206_item	3584996	et	4	main
olnud	doc_767882159206_item	3584997	et	4	main
nii	doc_767882159206_item	3584998	et	3	main
sajandil	doc_767882159206_item	3585005	et	3	main
ja	doc_767882159206_item	3585012	et	3	main
pool	doc_767882159206_item	3585015	et	4	main
traditsioonid	doc_767882159206_item	3585016	et	3	main
oli	doc_767882159206_item	3585023	et	3	main
kuultuuri	doc_767882159206_item	3585031	et	4	main
sel	doc_767882159206_item	3585032	et	3	main
ajal	doc_767882159206_item	3585033	et	4	main
vene	doc_767882159206_item	3585045	et	4	main
laulis	doc_767882159206_item	3585061	et	4	main
ja	doc_767882159206_item	3585062	et	3	main
on	doc_767882159206_item	3585067	et	4	main
see	doc_767882159206_item	3585068	et	3	main
et	doc_767882159206_item	3585069	et	3	main
tänapäeval	doc_767882159206_item	3585077	et	3	main
setu	doc_767882159206_item	3585095	et	4	main
faktid	doc_767882159206_item	3585100	et	3	main
essee	doc_767882159209_item	3585106	et	4	main
eestlastest	doc_767882159209_item	3585119	et	4	main
laulurahva	doc_767882159209_item	3585120	et	3	main
peab	doc_767882159209_item	3585127	et	4	main
ja	doc_767882159209_item	3585131	et	3	main
loengus	doc_767882159209_item	3585134	et	3	main
esitatud	doc_767882159209_item	3585137	et	4	main
väiteid	doc_767882159209_item	3585139	et	4	main
osa	doc_767882159209_item	3585152	et	4	main
see	doc_767882159209_item	3585160	et	3	main
juba	doc_767882159209_item	3585162	et	3	main
muidugi	doc_767882159209_item	3585175	et	4	main
ajalugu	doc_767882159209_item	3585176	et	4	main
kui	doc_767882159209_item	3585177	et	3	main
vaadata	doc_767882159209_item	3585178	et	4	main
siis	doc_767882159209_item	3585182	et	3	main
saada	doc_767882159209_item	3585186	et	4	main
et	doc_767882159209_item	3585187	et	3	main
laulurahva	doc_767882159209_item	3585188	et	3	main
miljonid	doc_767882159207_item	3584704	et	3	main
inimesed	doc_767882159207_item	3584705	et	3	main
sellele	doc_767882159207_item	3584708	et	4	main
laul	doc_767882159207_item	3584714	et	4	main
tunne	doc_767882159207_item	3584737	et	4	main
on	doc_767882159207_item	3584755	et	4	main
hea	doc_767882159207_item	3584756	et	4	main
tunned	doc_767882159207_item	3584760	et	3	main
test	doc_767882159206_item	3584791	et	3	main
kirjutage	doc_767882159206_item	3584793	et	3	main
eestlastest	doc_767882159206_item	3584798	et	4	main
essee	doc_767882159206_item	3584800	et	4	main
300	doc_767882159206_item	3584802	et	2	main
350	doc_767882159206_item	3584803	et	2	main
arutlev	doc_767882159206_item	3584808	et	4	main
ja	doc_767882159206_item	3584814	et	3	main
esitatud	doc_767882159206_item	3584816	et	4	main
väiteid	doc_767882159206_item	3584818	et	4	main
on	doc_767882159206_item	3584845	et	4	main
sündis	doc_767882159206_item	3584852	et	3	main
ajal	doc_767882159206_item	3584855	et	4	main
ja	doc_767882159206_item	3584856	et	3	main
muidugi	doc_767882159206_item	3584862	et	4	main
igal	doc_767882159206_item	3584863	et	3	main
periiodil	doc_767882159206_item	3584864	et	4	main
oli	doc_767882159206_item	3584865	et	3	main
see	doc_767882159206_item	3584875	et	3	main
et	doc_767882159206_item	3584876	et	3	main
tänapäeval	doc_767882159206_item	3584877	et	3	main
eestlased	doc_767882159206_item	3584893	et	3	main
päevad	doc_767882159206_item	3584906	et	3	main
näiteks	doc_767882159206_item	3584909	et	4	main
oma	doc_767882159206_item	3584921	et	4	main
päris	doc_767882159206_item	3584928	et	4	main
ta	doc_767882159206_item	3584961	et	4	main
korraldas	doc_767882159206_item	3584962	et	3	main
ma	doc_767882159206_item	3584969	et	3	main
tundidest	doc_767882159206_item	3584972	et	3	main
natukene	doc_767882159206_item	3584974	et	4	main
struktuur	doc_767882159206_item	3584977	et	3	main
vanaajal	doc_767882159206_item	3584978	et	3	main
venemaal	doc_767882159206_item	3584979	et	4	main
terve	doc_767882159206_item	3585002	et	4	main
oli	doc_767882159206_item	3585006	et	3	main
kiriku	doc_767882159206_item	3585010	et	3	main
see	doc_767882159206_item	3585025	et	3	main
et	doc_767882159206_item	3585026	et	3	main
oma	doc_767882159206_item	3585030	et	4	main
oli	doc_767882159206_item	3585038	et	3	main
eestimaal	doc_767882159206_item	3585039	et	4	main
ajad	doc_767882159206_item	3585043	et	4	main
tsaari	doc_767882159206_item	3585044	et	4	main
olnud	doc_767882159206_item	3585055	et	4	main
eesti	doc_767882159206_item	3585058	et	4	main
rahvas	doc_767882159206_item	3585059	et	4	main
kogunes	doc_767882159206_item	3585060	et	3	main
veel	doc_767882159206_item	3585079	et	4	main
kes	doc_767882159206_item	3585085	et	4	main
koguneb	doc_767882159206_item	3585086	et	3	main
ja	doc_767882159206_item	3585087	et	3	main
laulab	doc_767882159206_item	3585088	et	3	main
rahvalaulu	doc_767882159206_item	3585089	et	4	main
laulavad	doc_767882159207_item	3584730	et	4	main
on	doc_767882159207_item	3584733	et	4	main
fantastiline	doc_767882159207_item	3584734	et	4	main
ja	doc_767882159207_item	3584735	et	3	main
laulupidu	doc_767882159207_item	3584740	et	4	main
suur	doc_767882159207_item	3584743	et	3	main
kuhu	doc_767882159207_item	3584745	et	3	main
kõik	doc_767882159207_item	3584759	et	4	main
kirjutamine	doc_767882159206_item	3584792	et	4	main
laulurahva	doc_767882159206_item	3584799	et	3	main
pikkus	doc_767882159206_item	3584801	et	4	main
sõna	doc_767882159206_item	3584804	et	4	main
analüüsiv	doc_767882159206_item	3584809	et	4	main
ja	doc_767882159206_item	3584810	et	3	main
lugemistekstis	doc_767882159206_item	3584815	et	3	main
faktidele	doc_767882159206_item	3584817	et	3	main
on	doc_767882159206_item	3584819	et	4	main
soovitatav	doc_767882159206_item	3584820	et	4	main
illustreerida	doc_767882159206_item	3584821	et	3	main
näidetega	doc_767882159206_item	3584822	et	3	main
eesti	doc_767882159206_item	3584841	et	4	main
erinev	doc_767882159206_item	3584846	et	4	main
teistega	doc_767882159206_item	3584847	et	4	main
rahvastega	doc_767882159206_item	3584848	et	4	main
zanrid	doc_767882159206_item	3584861	et	4	main
nii	doc_767882159206_item	3584871	et	3	main
laulavad	doc_767882159206_item	3584882	et	4	main
regivärsiliset	doc_767882159206_item	3584883	et	4	main
rahvalaulut	doc_767882159206_item	3584884	et	4	main
eesti	doc_767882159206_item	3584786	et	4	main
kui	doc_767882159206_item	3584788	et	3	main
mis	doc_767882159206_item	3584796	et	4	main
teeb	doc_767882159206_item	3584797	et	3	main
essee	doc_767882159206_item	3584805	et	4	main
peab	doc_767882159206_item	3584806	et	4	main
loengus	doc_767882159206_item	3584813	et	3	main
tants	doc_767882159206_item	3584825	et	3	main
on	doc_767882159206_item	3584826	et	4	main
saatnud	doc_767882159206_item	3584827	et	4	main
eestlasi	doc_767882159206_item	3584828	et	3	main
nii	doc_767882159206_item	3584829	et	3	main
halval	doc_767882159206_item	3584830	et	3	main
kui	doc_767882159206_item	3584831	et	3	main
ka	doc_767882159206_item	3584832	et	3	main
heal	doc_767882159206_item	3584833	et	3	main
ajal	doc_767882159206_item	3584834	et	4	main
tööd	doc_767882159206_item	3584836	et	4	main
nii	doc_767882159206_item	3584835	et	3	main
tehes	doc_767882159206_item	3584837	et	3	main
kui	doc_767882159206_item	3584838	et	3	main
ka	doc_767882159206_item	3584839	et	3	main
pidutsedes	doc_767882159206_item	3584840	et	3	main
plaanis	doc_767882159206_item	3584844	et	4	main
eestlase	doc_767882159206_item	3584849	et	3	main
laulu	doc_767882159206_item	3584850	et	4	main
kultuur	doc_767882159206_item	3584851	et	3	main
veel	doc_767882159206_item	3584853	et	4	main
ole	doc_767882159206_item	3584870	et	4	main
tähtsam	doc_767882159206_item	3584873	et	4	main
veel	doc_767882159206_item	3584890	et	4	main
see	doc_767882159206_item	3584891	et	3	main
oma	doc_767882159206_item	3584895	et	4	main
kuud	doc_767882159206_item	3584907	et	4	main
venemaa	doc_767882159206_item	3584911	et	4	main
ajad	doc_767882159206_item	3584914	et	4	main
halvem	doc_767882159206_item	3584917	et	4	main
kui	doc_767882159206_item	3584918	et	3	main
eestlastel	doc_767882159206_item	3584919	et	4	main
kadus	doc_767882159206_item	3584920	et	3	main
on	doc_767882159206_item	3584927	et	4	main
ja	doc_767882159206_item	3584931	et	3	main
laulupidu	doc_767882159206_item	3584933	et	4	main
mitte	doc_767882159206_item	3584935	et	3	main
näiteks	doc_767882159206_item	3584966	et	4	main
ajaloo	doc_767882159206_item	3584971	et	4	main
laulis	doc_767882159206_item	3584981	et	4	main
koor	doc_767882159206_item	3584985	et	4	main
natukene	doc_767882159206_item	3584987	et	4	main
hilinem	doc_767882159206_item	3584988	et	4	main
teine	doc_767882159206_item	3584989	et	3	main
laulutüüp	doc_767882159206_item	3584990	et	3	main
laulut	doc_767882159206_item	3584995	et	4	main
põhimõtselt	doc_767882159206_item	3585001	et	4	main
nagu	doc_767882159206_item	3585007	et	3	main
laulmine	doc_767882159206_item	3585011	et	4	main
rohkem	doc_767882159206_item	3585013	et	4	main
tähtis	doc_767882159206_item	3585022	et	4	main
rootsi	doc_767882159206_item	3585040	et	4	main
eestlastel	doc_767882159206_item	3585048	et	4	main
kõrghetk	doc_767882159206_item	3585051	et	3	main
tantsis	doc_767882159206_item	3585063	et	4	main
aga	doc_767882159206_item	3585064	et	3	main
eesti	doc_767882159206_item	3585070	et	4	main
rahvas	doc_767882159206_item	3585071	et	4	main
on	doc_767882159206_item	3585078	et	4	main
lõuna-ida	doc_767882159206_item	3585091	et	4	main
eestlastest	doc_767882159206_item	3585103	et	4	main
torem	doc_767882159206_item	3584886	et	4	main
nendel	doc_767882159206_item	3584902	et	4	main
oli	doc_767882159206_item	3584903	et	3	main
ka	doc_767882159206_item	3584904	et	3	main
rasked	doc_767882159206_item	3584905	et	3	main
ajad	doc_767882159206_item	3584912	et	4	main
muidugi	doc_767882159206_item	3584915	et	4	main
eestlastel	doc_767882159206_item	3584926	et	4	main
traditsioonid	doc_767882159206_item	3584930	et	3	main
aga	doc_767882159206_item	3584936	et	3	main
tänapäevased	doc_767882159206_item	3584937	et	4	main
vaid	doc_767882159206_item	3584938	et	3	main
vanaajalised	doc_767882159206_item	3584939	et	4	main
huvitav	doc_767882159206_item	3584940	et	4	main
ja	doc_767882159206_item	3584941	et	3	main
põnev	doc_767882159206_item	3584942	et	3	main
kuidas	doc_767882159206_item	3584943	et	3	main
vanaajal	doc_767882159206_item	3584944	et	3	main
moodustasid	doc_767882159206_item	3584945	et	4	main
laulukoorid	doc_767882159206_item	3584946	et	3	main
eestlastel	doc_767882159206_item	3584947	et	4	main
tähtsam	doc_767882159206_item	3584948	et	4	main
oli	doc_767882159206_item	3584949	et	3	main
see	doc_767882159206_item	3584950	et	3	main
et	doc_767882159206_item	3584951	et	3	main
kooris	doc_767882159206_item	3584952	et	4	main
oli	doc_767882159206_item	3584953	et	3	main
eeslaulja	doc_767882159206_item	3584954	et	4	main
ta	doc_767882159206_item	3584955	et	4	main
viis	doc_767882159206_item	3584956	et	4	main
laulu	doc_767882159206_item	3584957	et	4	main
edasi	doc_767882159206_item	3584958	et	3	main
ja	doc_767882159206_item	3584959	et	3	main
koor	doc_767882159206_item	3584960	et	4	main
eeslaulja	doc_767882159206_item	3584963	et	4	main
viimase	doc_767882159206_item	3584964	et	3	main
mäletan	doc_767882159206_item	3584970	et	3	main
oli	doc_767882159206_item	3584973	et	3	main
teistsugune	doc_767882159206_item	3584975	et	3	main
laulmise	doc_767882159206_item	3584976	et	4	main
ainult	doc_767882159206_item	3584982	et	4	main
üks	doc_767882159206_item	3584983	et	3	main
mees	doc_767882159206_item	3584984	et	4	main
pärast	doc_767882159206_item	3584993	et	4	main
huvitav	doc_767882159206_item	3584999	et	4	main
laulmine	doc_767882159206_item	3585003	et	4	main
uskliku	doc_767882159206_item	3585008	et	3	main
väljavõetud	doc_767882159206_item	3585020	et	4	main
väga	doc_767882159206_item	3585021	et	3	main
rahvas	doc_767882159206_item	3585028	et	4	main
hoidis	doc_767882159206_item	3585029	et	4	main
16	doc_767882159206_item	3585035	et	2	main
ajad	doc_767882159206_item	3585041	et	4	main
saksa	doc_767882159206_item	3585042	et	4	main
ajad	doc_767882159206_item	3585046	et	4	main
oli	doc_767882159206_item	3585050	et	3	main
kinni	doc_767882159206_item	3585056	et	3	main
kõige	doc_767882159206_item	3585065	et	4	main
tähtsam	doc_767882159206_item	3585066	et	4	main
ärkamist	doc_767882159206_item	3585076	et	4	main
regioonid	doc_767882159206_item	3585080	et	3	main
eestis	doc_767882159206_item	3585081	et	3	main
kus	doc_767882159206_item	3585082	et	3	main
on	doc_767882159206_item	3585083	et	4	main
rahvas	doc_767882159206_item	3585084	et	4	main
rahvas	doc_767882159206_item	3585096	et	4	main
ja	doc_767882159206_item	3585097	et	3	main
keele	doc_767882159209_item	3585108	et	4	main
test	doc_767882159209_item	3585112	et	3	main
kirjutage	doc_767882159209_item	3585114	et	3	main
sõna	doc_767882159209_item	3585125	et	4	main
üldistav	doc_767882159209_item	3585132	et	4	main
lauldi	doc_767882159209_item	3585156	et	3	main
lauldi	doc_767882159209_item	3585158	et	3	main
on	doc_767882159209_item	3585161	et	4	main
eestlaste	doc_767882159209_item	3585168	et	4	main
hinges	doc_767882159209_item	3585169	et	4	main
mis	doc_767882159209_item	3585170	et	4	main
teeb	doc_767882159209_item	3585171	et	3	main
läbi	doc_767882159209_item	3585179	et	4	main
ajal	doc_767882159209_item	3585197	et	4	main
eestlased	doc_767882159209_item	3585198	et	3	main
tunnustamise	doc_767882159209_item	3585201	et	4	main
laulu	doc_767882159209_item	3585206	et	4	main
ole	doc_767882159209_item	3585217	et	4	main
ajalugu	doc_767882159209_item	3585222	et	4	main
ole	doc_767882159209_item	3585231	et	4	main
täiesti	doc_767882159209_item	3585232	et	3	main
on	doc_767882159209_item	3585239	et	4	main
peamõte	doc_767882159209_item	3585241	et	3	main
olen	doc_767882159209_item	3585244	et	3	main
et	doc_767882159209_item	3585246	et	3	main
tantsud	doc_767882159209_item	3585247	et	3	main
ja	doc_767882159209_item	3585248	et	3	main
laulud	doc_767882159209_item	3585249	et	3	main
need	doc_767882159209_item	3585250	et	3	main
on	doc_767882159209_item	3585251	et	4	main
jututatakse	doc_767882159209_item	3585263	et	4	main
traditsioonidest	doc_767882159209_item	3585264	et	3	main
kommetest	doc_767882159209_item	3585265	et	4	main
võin	doc_767882159209_item	3585266	et	3	main
oletada	doc_767882159209_item	3585267	et	3	main
arvamus	doc_767882159209_item	3585329	et	3	main
selle	doc_767882159209_item	3585330	et	4	main
kohta	doc_767882159209_item	3585331	et	4	main
aga	doc_767882159209_item	3585332	et	3	main
omapärane	doc_767882159209_item	3585339	et	4	main
võit	doc_767882159209_item	3585340	et	3	main
ei	doc_767882159209_item	3585341	et	4	main
monopoolist	doc_767882159209_item	3585344	et	4	main
riigid	doc_767882159209_item	3585345	et	3	main
ei	doc_767882159209_item	3585351	et	4	main
säilitada	doc_767882159209_item	3585362	et	3	main
komme	doc_767882159209_item	3585366	et	4	main
rahvapidu	doc_767882159209_item	3585372	et	4	main
kombe	doc_767882159209_item	3585388	et	4	main
ja	doc_767882159209_item	3585389	et	3	main
eesti	doc_767882159210_item	3585396	et	4	main
test	doc_767882159210_item	3585401	et	3	main
essee	doc_767882159210_item	3585404	et	4	main
eesti	doc_767882159206_item	3585027	et	4	main
sest	doc_767882159206_item	3585034	et	4	main
18	doc_767882159206_item	3585036	et	2	main
sajandil	doc_767882159206_item	3585037	et	3	main
nõukoguajal	doc_767882159206_item	3585047	et	3	main
üldse	doc_767882159206_item	3585049	et	3	main
laulupidu	doc_767882159206_item	3585052	et	4	main
traditsioon	doc_767882159206_item	3585053	et	3	main
ei	doc_767882159206_item	3585054	et	4	main
pandud	doc_767882159206_item	3585057	et	4	main
laulupidudel	doc_767882159206_item	3585072	et	4	main
tähistas	doc_767882159206_item	3585073	et	3	main
oma	doc_767882159206_item	3585074	et	4	main
rahvusliku	doc_767882159206_item	3585075	et	3	main
need	doc_767882159206_item	3585098	et	3	main
põhimõtted	doc_767882159206_item	3585101	et	3	main
teise	doc_767882159209_item	3585110	et	4	main
essee	doc_767882159209_item	3585121	et	4	main
pikkus	doc_767882159209_item	3585122	et	4	main
300	doc_767882159209_item	3585123	et	2	main
350	doc_767882159209_item	3585124	et	2	main
arutlev	doc_767882159209_item	3585129	et	4	main
lugemistekstis	doc_767882159209_item	3585136	et	3	main
mis	doc_767882159209_item	3585165	et	4	main
aasta	doc_767882159209_item	3585181	et	4	main
kohe	doc_767882159209_item	3585183	et	4	main
laulipidu	doc_767882159209_item	3585190	et	4	main
tuleb	doc_767882159209_item	3585192	et	3	main
just	doc_767882159209_item	3585193	et	3	main
sellest	doc_767882159209_item	3585194	et	4	main
võitlesid	doc_767882159209_item	3585199	et	4	main
kaudu	doc_767882159209_item	3585207	et	3	main
eesti	doc_767882159209_item	3585211	et	4	main
kombed	doc_767882159209_item	3585212	et	3	main
ja	doc_767882159209_item	3585213	et	3	main
tuleb	doc_767882159209_item	3585223	et	3	main
ära	doc_767882159209_item	3585224	et	4	main
kaugemale	doc_767882159209_item	3585226	et	4	main
võib	doc_767882159209_item	3585227	et	3	main
olla	doc_767882159209_item	3585228	et	3	main
ma	doc_767882159209_item	3585229	et	3	main
ei	doc_767882159209_item	3585230	et	4	main
mõte	doc_767882159209_item	3585236	et	3	main
aga	doc_767882159209_item	3585237	et	3	main
samuti	doc_767882159209_item	3585243	et	3	main
vanemad	doc_767882159209_item	3585255	et	4	main
annavad	doc_767882159209_item	3585256	et	3	main
on	doc_767882159209_item	3585270	et	4	main
tänapäeval	doc_767882159209_item	3585272	et	3	main
ei	doc_767882159209_item	3585274	et	4	main
nii	doc_767882159209_item	3585276	et	3	main
see	doc_767882159209_item	3585278	et	3	main
mina	doc_767882159209_item	3585333	et	4	main
ole	doc_767882159209_item	3585342	et	4	main
kõik	doc_767882159209_item	3585346	et	4	main
on	doc_767882159209_item	3585347	et	4	main
ole	doc_767882159209_item	3585352	et	4	main
nii	doc_767882159209_item	3585353	et	3	main
oma	doc_767882159209_item	3585363	et	4	main
laulupidu	doc_767882159209_item	3585373	et	4	main
ajalugu	doc_767882159209_item	3585381	et	4	main
teeb	doc_767882159209_item	3585391	et	3	main
essee	doc_767882159210_item	3585395	et	4	main
peab	doc_767882159210_item	3585416	et	4	main
on	doc_767882159210_item	3585429	et	4	main
näidetega	doc_767882159210_item	3585432	et	3	main
teeb	doc_767882159210_item	3585434	et	3	main
eestlastest	doc_767882159210_item	3585435	et	4	main
laulurahva	doc_767882159210_item	3585436	et	3	main
igal	doc_767882159210_item	3585437	et	3	main
riigil	doc_767882159210_item	3585438	et	3	main
kui	doc_767882159210_item	3585439	et	3	main
ka	doc_767882159210_item	3585440	et	3	main
eestis	doc_767882159210_item	3585441	et	3	main
see	doc_767882159210_item	3585449	et	3	main
on	doc_767882159210_item	3585450	et	4	main
vanal	doc_767882159210_item	3585453	et	3	main
laulsid	doc_767882159210_item	3585456	et	4	main
väga	doc_767882159210_item	3585457	et	3	main
tihti	doc_767882159210_item	3585458	et	3	main
kui	doc_767882159210_item	3585459	et	3	main
nad	doc_767882159210_item	3585460	et	3	main
näiteks	doc_767882159206_item	3585090	et	4	main
eestis	doc_767882159206_item	3585092	et	3	main
kus	doc_767882159206_item	3585093	et	3	main
on	doc_767882159206_item	3585094	et	4	main
kõig	doc_767882159206_item	3585099	et	4	main
teevad	doc_767882159206_item	3585102	et	3	main
laulurahva	doc_767882159206_item	3585104	et	3	main
kui	doc_767882159209_item	3585109	et	3	main
kirjutamine	doc_767882159209_item	3585113	et	4	main
essee	doc_767882159209_item	3585115	et	4	main
teemal	doc_767882159209_item	3585116	et	3	main
mis	doc_767882159209_item	3585117	et	4	main
teeb	doc_767882159209_item	3585118	et	3	main
essee	doc_767882159209_item	3585126	et	4	main
analüüsiv	doc_767882159209_item	3585130	et	4	main
faktidele	doc_767882159209_item	3585138	et	3	main
on	doc_767882159209_item	3585140	et	4	main
soovitatav	doc_767882159209_item	3585141	et	4	main
vana	doc_767882159209_item	3585163	et	4	main
traditsioon	doc_767882159209_item	3585164	et	3	main
eestlastest	doc_767882159209_item	3585172	et	4	main
laulurahva	doc_767882159209_item	3585173	et	3	main
esiteks	doc_767882159209_item	3585174	et	3	main
1896	doc_767882159209_item	3585180	et	2	main
võib	doc_767882159209_item	3585184	et	3	main
aru	doc_767882159209_item	3585185	et	4	main
algus	doc_767882159209_item	3585191	et	4	main
ei	doc_767882159209_item	3585216	et	4	main
nende	doc_767882159209_item	3585221	et	4	main
sügavalt	doc_767882159209_item	3585225	et	4	main
oma	doc_767882159209_item	3585235	et	4	main
see	doc_767882159209_item	3585238	et	3	main
joon	doc_767882159209_item	3585254	et	4	main
lastele	doc_767882159209_item	3585258	et	4	main
kõik	doc_767882159209_item	3585259	et	4	main
selle	doc_767882159209_item	3585261	et	4	main
kohta	doc_767882159209_item	3585262	et	4	main
vilumus	doc_767882159209_item	3585271	et	4	main
populaarsed	doc_767882159209_item	3585277	et	3	main
oma	doc_767882159209_item	3585326	et	4	main
isiklikult	doc_767882159209_item	3585334	et	4	main
arvan	doc_767882159209_item	3585335	et	3	main
et	doc_767882159209_item	3585336	et	3	main
välismaased	doc_767882159209_item	3585348	et	4	main
suur	doc_767882159209_item	3585354	et	3	main
ja	doc_767882159209_item	3585355	et	3	main
võib	doc_767882159209_item	3585356	et	3	main
olla	doc_767882159209_item	3585357	et	3	main
sellise	doc_767882159209_item	3585358	et	4	main
on	doc_767882159209_item	3585371	et	4	main
rahva	doc_767882159209_item	3585380	et	3	main
armastamine	doc_767882159209_item	3585383	et	4	main
ajalugu	doc_767882159209_item	3585390	et	4	main
eesti	doc_767882159209_item	3585107	et	4	main
keele	doc_767882159209_item	3585111	et	4	main
olema	doc_767882159209_item	3585128	et	4	main
tuginema	doc_767882159209_item	3585133	et	3	main
ja	doc_767882159209_item	3585135	et	3	main
illustreerida	doc_767882159209_item	3585142	et	3	main
näidetega	doc_767882159209_item	3585143	et	3	main
laulmine	doc_767882159209_item	3585144	et	4	main
eestis	doc_767882159209_item	3585145	et	3	main
see	doc_767882159209_item	3585146	et	3	main
on	doc_767882159209_item	3585147	et	4	main
osa	doc_767882159209_item	3585148	et	4	main
kultuurist	doc_767882159209_item	3585149	et	3	main
osa	doc_767882159209_item	3585150	et	4	main
ajaloost	doc_767882159209_item	3585151	et	4	main
elust	doc_767882159209_item	3585153	et	3	main
lauldi	doc_767882159209_item	3585154	et	3	main
töötades	doc_767882159209_item	3585155	et	3	main
jalutades	doc_767882159209_item	3585157	et	3	main
pulmades	doc_767882159209_item	3585159	et	3	main
elab	doc_767882159209_item	3585166	et	3	main
kõige	doc_767882159209_item	3585167	et	4	main
või	doc_767882159209_item	3585189	et	4	main
seal	doc_767882159209_item	3585196	et	4	main
oma	doc_767882159209_item	3585200	et	4	main
eest	doc_767882159209_item	3585202	et	4	main
minu	doc_767882159209_item	3585203	et	3	main
ajast	doc_767882159209_item	3585195	et	4	main
arvates	doc_767882159209_item	3585204	et	4	main
eestlased	doc_767882159209_item	3585205	et	3	main
eesti	doc_767882159209_item	3585214	et	4	main
traditsioonid	doc_767882159209_item	3585215	et	3	main
kohtal	doc_767882159209_item	3585220	et	4	main
õige	doc_767882159209_item	3585233	et	4	main
väljendanud	doc_767882159209_item	3585234	et	4	main
minu	doc_767882159209_item	3585240	et	3	main
mina	doc_767882159209_item	3585242	et	4	main
seisukohal	doc_767882159209_item	3585245	et	4	main
oma	doc_767882159209_item	3585257	et	4	main
teadmised	doc_767882159209_item	3585260	et	4	main
see	doc_767882159209_item	3585269	et	3	main
nad	doc_767882159209_item	3585273	et	3	main
ole	doc_767882159209_item	3585275	et	4	main
ja	doc_767882159209_item	3585306	et	3	main
laulasid	doc_767882159209_item	3585307	et	4	main
ja	doc_767882159209_item	3585308	et	3	main
ma	doc_767882159209_item	3585309	et	3	main
olen	doc_767882159209_item	3585310	et	3	main
kindel	doc_767882159209_item	3585311	et	3	main
et	doc_767882159209_item	3585312	et	3	main
sellel	doc_767882159209_item	3585313	et	4	main
ajal	doc_767882159209_item	3585314	et	4	main
võib	doc_767882159209_item	3585315	et	3	main
vastata	doc_767882159209_item	3585316	et	4	main
küsimustele	doc_767882159209_item	3585317	et	4	main
mis	doc_767882159209_item	3585318	et	4	main
eestlastest	doc_767882159209_item	3585320	et	4	main
teeb	doc_767882159209_item	3585319	et	3	main
laulurahva	doc_767882159209_item	3585321	et	3	main
muidugi	doc_767882159209_item	3585322	et	4	main
tahaksid	doc_767882159209_item	3585208	et	4	main
näidata	doc_767882159209_item	3585209	et	4	main
et	doc_767882159209_item	3585210	et	3	main
sündinud	doc_767882159209_item	3585218	et	4	main
tühjal	doc_767882159209_item	3585219	et	3	main
eesti	doc_767882159209_item	3585252	et	4	main
rahva	doc_767882159209_item	3585253	et	3	main
et	doc_767882159209_item	3585268	et	3	main
on	doc_767882159209_item	3585279	et	4	main
vana	doc_767882159209_item	3585280	et	4	main
põlvkonnade	doc_767882159209_item	3585281	et	3	main
aeg	doc_767882159209_item	3585282	et	3	main
mälu	doc_767882159209_item	3585283	et	4	main
1994	doc_767882159209_item	3585284	et	2	main
aasta	doc_767882159209_item	3585285	et	4	main
see	doc_767882159209_item	3585286	et	3	main
ei	doc_767882159209_item	3585287	et	4	main
ole	doc_767882159209_item	3585288	et	4	main
nii	doc_767882159209_item	3585289	et	3	main
ammu	doc_767882159209_item	3585290	et	4	main
sel	doc_767882159209_item	3585291	et	3	main
ajal	doc_767882159209_item	3585292	et	4	main
tähistati	doc_767882159209_item	3585293	et	4	main
125	doc_767882159209_item	3585294	et	2	main
aastat	doc_767882159209_item	3585295	et	3	main
kestnud	doc_767882159209_item	3585296	et	4	main
laulupidude	doc_767882159209_item	3585297	et	4	main
traditsiooni	doc_767882159209_item	3585298	et	4	main
kogus	doc_767882159209_item	3585299	et	4	main
välja	doc_767882159209_item	3585300	et	4	main
palju	doc_767882159209_item	3585301	et	4	main
eesti	doc_767882159209_item	3585302	et	4	main
kõik	doc_767882159209_item	3585304	et	4	main
rahvu	doc_767882159209_item	3585303	et	4	main
tantsisid	doc_767882159209_item	3585305	et	4	main
igal	doc_767882159209_item	3585323	et	3	main
inimesel	doc_767882159209_item	3585324	et	3	main
on	doc_767882159209_item	3585338	et	4	main
eesti	doc_767882159209_item	3585349	et	4	main
laulupeoga	doc_767882159209_item	3585359	et	4	main
rahva	doc_767882159209_item	3585364	et	3	main
oma	doc_767882159209_item	3585365	et	4	main
oma	doc_767882159209_item	3585367	et	4	main
traditsioone	doc_767882159209_item	3585368	et	3	main
laulupidu	doc_767882159209_item	3585369	et	4	main
see	doc_767882159209_item	3585370	et	3	main
see	doc_767882159209_item	3585374	et	3	main
on	doc_767882159209_item	3585375	et	4	main
rahvuslik	doc_767882159209_item	3585376	et	3	main
sümbol	doc_767882159209_item	3585377	et	3	main
see	doc_767882159209_item	3585378	et	3	main
on	doc_767882159209_item	3585379	et	4	main
ja	doc_767882159209_item	3585382	et	3	main
ning	doc_767882159209_item	3585384	et	3	main
neid	doc_767882159209_item	3585386	et	4	main
on	doc_767882159209_item	3585325	et	4	main
vastus	doc_767882159209_item	3585327	et	3	main
oma	doc_767882159209_item	3585328	et	4	main
see	doc_767882159209_item	3585337	et	3	main
enam	doc_767882159209_item	3585343	et	4	main
rahv	doc_767882159209_item	3585350	et	4	main
ta	doc_767882159209_item	3585360	et	4	main
tahab	doc_767882159209_item	3585361	et	3	main
austamine	doc_767882159209_item	3585385	et	4	main
eestlastest	doc_767882159209_item	3585392	et	4	main
laulurahva	doc_767882159209_item	3585393	et	3	main
keele	doc_767882159210_item	3585397	et	4	main
keele	doc_767882159210_item	3585400	et	4	main
kirjutamine	doc_767882159210_item	3585402	et	4	main
laulurahva	doc_767882159210_item	3585409	et	3	main
analüüsiv	doc_767882159210_item	3585419	et	4	main
üldistav	doc_767882159210_item	3585421	et	4	main
illustreerida	doc_767882159210_item	3585431	et	3	main
oma	doc_767882159210_item	3585443	et	4	main
kombed	doc_767882159210_item	3585444	et	3	main
traditsioonid	doc_767882159210_item	3585445	et	3	main
töötasid	doc_767882159210_item	3585461	et	4	main
olid	doc_767882159210_item	3585462	et	4	main
naised	doc_767882159210_item	3585466	et	3	main
oma	doc_767882159210_item	3585468	et	4	main
rohkem	doc_767882159210_item	3585478	et	4	main
vanal	doc_767882159210_item	3585479	et	3	main
mehed	doc_767882159210_item	3585484	et	3	main
meres	doc_767882159210_item	3585486	et	3	main
või	doc_767882159210_item	3585487	et	4	main
tegid	doc_767882159210_item	3585488	et	4	main
traditsioone	doc_767882159209_item	3585387	et	3	main
kui	doc_767882159210_item	3585398	et	3	main
eestlastest	doc_767882159210_item	3585408	et	4	main
essee	doc_767882159210_item	3585410	et	4	main
300	doc_767882159210_item	3585412	et	2	main
arutlev	doc_767882159210_item	3585418	et	4	main
ja	doc_767882159210_item	3585420	et	3	main
faktidele	doc_767882159210_item	3585427	et	3	main
laulud	doc_767882159210_item	3585447	et	3	main
või	doc_767882159210_item	3585465	et	4	main
lapsed	doc_767882159210_item	3585469	et	3	main
laulud	doc_767882159210_item	3585471	et	3	main
ajal	doc_767882159210_item	3585480	et	4	main
muidugi	doc_767882159210_item	3585490	et	4	main
see	doc_767882159210_item	3585491	et	3	main
mehikoori	doc_767882159210_item	3585496	et	4	main
naiteks	doc_767882159210_item	3585497	et	4	main
levis	doc_767882159210_item	3585505	et	4	main
väga	doc_767882159210_item	3585506	et	3	main
kiiresti	doc_767882159210_item	3585507	et	3	main
18	doc_767882159210_item	3585509	et	2	main
hakkas	doc_767882159210_item	3585511	et	3	main
väljaspool	doc_767882159210_item	3585514	et	3	main
kirikut	doc_767882159210_item	3585515	et	3	main
rahvalaul	doc_767882159210_item	3585531	et	4	main
uus	doc_767882159210_item	3585532	et	3	main
25	doc_767882159210_item	3585569	et	2	main
sellised	doc_767882159210_item	3585575	et	4	main
g	doc_767882159210_item	3585589	et	4	main
isamalaulu	doc_767882159210_item	3585592	et	4	main
mu	doc_767882159210_item	3585593	et	3	main
isamaa	doc_767882159210_item	3585594	et	4	main
sellised	doc_767882159210_item	3585625	et	4	main
üritused	doc_767882159210_item	3585626	et	4	main
niimoodi	doc_767882159210_item	3585631	et	3	main
eesti	doc_767882159211_item	3585794	et	4	main
keele	doc_767882159211_item	3585798	et	4	main
analüüsiv	doc_767882159211_item	3585817	et	4	main
ja	doc_767882159211_item	3585818	et	3	main
soovitatav	doc_767882159211_item	3585828	et	4	main
illustreerida	doc_767882159211_item	3585829	et	3	main
näidetega	doc_767882159211_item	3585830	et	3	main
eestlastest	doc_767882159211_item	3585833	et	4	main
eestlastest	doc_767882159211_item	3585835	et	4	main
tõusu	doc_767882159211_item	3585844	et	4	main
laulupidu	doc_767882159211_item	3585856	et	4	main
lauljad	doc_767882159211_item	3585864	et	4	main
inimesed	doc_767882159211_item	3585865	et	3	main
keele	doc_767882159214_item	3585945	et	4	main
tegelikkult	doc_767882159210_item	3585637	et	4	main
on	doc_767882159210_item	3585638	et	4	main
nende	doc_767882159210_item	3585639	et	4	main
rahvus	doc_767882159210_item	3585640	et	3	main
oma	doc_767882159210_item	3585641	et	4	main
riigi	doc_767882159210_item	3585642	et	3	main
kombed	doc_767882159210_item	3585643	et	3	main
ja	doc_767882159210_item	3585644	et	3	main
tragitsioone	doc_767882159210_item	3585645	et	4	main
teise	doc_767882159210_item	3585399	et	4	main
kirjutage	doc_767882159210_item	3585403	et	3	main
pikkus	doc_767882159210_item	3585411	et	4	main
350	doc_767882159210_item	3585413	et	2	main
sõna	doc_767882159210_item	3585414	et	4	main
essee	doc_767882159210_item	3585415	et	4	main
tuginema	doc_767882159210_item	3585422	et	3	main
loengus	doc_767882159210_item	3585423	et	3	main
ja	doc_767882159210_item	3585424	et	3	main
lugemistekstis	doc_767882159210_item	3585425	et	3	main
esitatud	doc_767882159210_item	3585426	et	4	main
teemal	doc_767882159210_item	3585405	et	3	main
mis	doc_767882159210_item	3585406	et	4	main
teeb	doc_767882159210_item	3585407	et	3	main
olema	doc_767882159210_item	3585417	et	4	main
väiteid	doc_767882159210_item	3585428	et	4	main
soovitatav	doc_767882159210_item	3585430	et	4	main
mis	doc_767882159210_item	3585433	et	4	main
ja	doc_767882159210_item	3585446	et	3	main
kultuurinähtus	doc_767882159210_item	3585452	et	4	main
pulmas	doc_767882159210_item	3585463	et	3	main
vaatasid	doc_767882159210_item	3585467	et	4	main
kodus	doc_767882159210_item	3585470	et	4	main
aitasid	doc_767882159210_item	3585472	et	4	main
laulsid	doc_767882159210_item	3585481	et	4	main
naised	doc_767882159210_item	3585482	et	3	main
olid	doc_767882159210_item	3585485	et	4	main
ei	doc_767882159210_item	3585492	et	4	main
lääne	doc_767882159210_item	3585498	et	4	main
rahva	doc_767882159210_item	3585503	et	3	main
juba	doc_767882159210_item	3585508	et	3	main
sajandil	doc_767882159210_item	3585510	et	3	main
laulumine	doc_767882159210_item	3585512	et	4	main
levima	doc_767882159210_item	3585513	et	3	main
laulud	doc_767882159210_item	3585518	et	3	main
praegu	doc_767882159210_item	3585522	et	3	main
me	doc_767882159210_item	3585523	et	4	main
juba	doc_767882159210_item	3585524	et	3	main
teame	doc_767882159210_item	3585525	et	3	main
et	doc_767882159210_item	3585526	et	3	main
erinevaid	doc_767882159210_item	3585535	et	4	main
ja	doc_767882159210_item	3585571	et	3	main
et	doc_767882159210_item	3585580	et	3	main
professionaalse	doc_767882159210_item	3585621	et	3	main
heliloominguga	doc_767882159210_item	3585622	et	3	main
arvan	doc_767882159210_item	3585623	et	3	main
et	doc_767882159210_item	3585624	et	3	main
sest	doc_767882159210_item	3585630	et	4	main
ei	doc_767882159210_item	3585633	et	4	main
kes	doc_767882159210_item	3585635	et	4	main
nad	doc_767882159210_item	3585636	et	3	main
essee	doc_767882159211_item	3585793	et	4	main
eestlastest	doc_767882159211_item	3585806	et	4	main
laulurahva	doc_767882159211_item	3585807	et	3	main
essee	doc_767882159211_item	3585808	et	4	main
pikkus	doc_767882159211_item	3585809	et	4	main
300	doc_767882159211_item	3585810	et	2	main
350	doc_767882159211_item	3585811	et	2	main
üldistav	doc_767882159211_item	3585819	et	4	main
tuginema	doc_767882159211_item	3585820	et	3	main
lugemistekstis	doc_767882159211_item	3585823	et	3	main
mis	doc_767882159211_item	3585831	et	4	main
vabarigi	doc_767882159211_item	3585843	et	4	main
kõiki	doc_767882159211_item	3585849	et	4	main
iga	doc_767882159211_item	3585851	et	4	main
viie	doc_767882159211_item	3585852	et	3	main
aasta	doc_767882159211_item	3585853	et	4	main
ja	doc_767882159211_item	3585867	et	3	main
pidu	doc_767882159211_item	3585869	et	4	main
eesti	doc_767882159214_item	3585941	et	4	main
essee	doc_767882159214_item	3585949	et	4	main
essee	doc_767882159214_item	3585955	et	4	main
teeb	doc_767882159214_item	3585979	et	3	main
linnas	doc_767882159214_item	3585991	et	4	main
sellel	doc_767882159214_item	3585992	et	4	main
ilusad	doc_767882159214_item	3586003	et	3	main
rahva	doc_767882159214_item	3586004	et	3	main
on	doc_767882159210_item	3585442	et	4	main
sest	doc_767882159210_item	3585448	et	4	main
tähelepanuväärne	doc_767882159210_item	3585451	et	3	main
ajal	doc_767882159210_item	3585454	et	4	main
inimesed	doc_767882159210_item	3585455	et	3	main
laulupeol	doc_767882159210_item	3585464	et	4	main
kõige	doc_767882159210_item	3585477	et	4	main
tööd	doc_767882159210_item	3585489	et	4	main
laulsid	doc_767882159210_item	3585500	et	4	main
alguses	doc_767882159210_item	3585516	et	4	main
kiriku	doc_767882159210_item	3585520	et	3	main
on	doc_767882159210_item	3585527	et	4	main
uus	doc_767882159210_item	3585528	et	3	main
ja	doc_767882159210_item	3585529	et	3	main
vana	doc_767882159210_item	3585530	et	4	main
žaanrid	doc_767882159210_item	3585536	et	2	main
kui	doc_767882159210_item	3585538	et	3	main
kuulame	doc_767882159210_item	3585540	et	4	main
rokk	doc_767882159210_item	3585541	et	3	main
muusikat	doc_767882159210_item	3585542	et	3	main
rohkem	doc_767882159210_item	3585573	et	4	main
nende	doc_767882159210_item	3585581	et	4	main
on	doc_767882159210_item	3585583	et	4	main
suur	doc_767882159210_item	3585584	et	3	main
ja	doc_767882159210_item	3585585	et	3	main
tugev	doc_767882159210_item	3585586	et	4	main
1969	doc_767882159210_item	3585587	et	2	main
aastal	doc_767882159210_item	3585588	et	3	main
on	doc_767882159210_item	3585619	et	4	main
eriti	doc_767882159210_item	3585628	et	3	main
neile	doc_767882159210_item	3585473	et	4	main
elada	doc_767882159210_item	3585474	et	3	main
ja	doc_767882159210_item	3585475	et	3	main
töötada	doc_767882159210_item	3585476	et	3	main
sest	doc_767882159210_item	3585483	et	4	main
tähenda	doc_767882159210_item	3585493	et	4	main
et	doc_767882159210_item	3585494	et	3	main
eesti	doc_767882159210_item	3585499	et	4	main
palju	doc_767882159210_item	3585566	et	4	main
inimest	doc_767882159210_item	3585567	et	3	main
umbes	doc_767882159210_item	3585568	et	4	main
000	doc_767882159210_item	3585570	et	2	main
veel	doc_767882159210_item	3585572	et	4	main
esinejat	doc_767882159210_item	3585574	et	4	main
peod	doc_767882159210_item	3585576	et	4	main
ernesaks	doc_767882159210_item	3585590	et	4	main
on	doc_767882159210_item	3585595	et	4	main
minu	doc_767882159210_item	3585596	et	3	main
arm	doc_767882159210_item	3585597	et	3	main
see	doc_767882159210_item	3585598	et	3	main
tugene	doc_767882159210_item	3585599	et	4	main
eesti	doc_767882159210_item	3585600	et	4	main
traditsioone	doc_767882159210_item	3585601	et	3	main
praeguse	doc_767882159210_item	3585602	et	3	main
aja	doc_767882159210_item	3585603	et	4	main
laulupeod	doc_767882159210_item	3585604	et	4	main
on	doc_767882159210_item	3585605	et	4	main
ka	doc_767882159210_item	3585606	et	3	main
väga	doc_767882159210_item	3585607	et	3	main
tähtsad	doc_767882159210_item	3585608	et	3	main
ja	doc_767882159210_item	3585609	et	3	main
huvitavad	doc_767882159210_item	3585610	et	4	main
ja	doc_767882159210_item	3585611	et	3	main
päris	doc_767882159210_item	3585612	et	4	main
tihti	doc_767882159210_item	3585613	et	3	main
toimuvad	doc_767882159210_item	3585614	et	4	main
eestis	doc_767882159210_item	3585615	et	3	main
muidugi	doc_767882159210_item	3585616	et	4	main
peo	doc_767882159210_item	3585617	et	4	main
repertuaar	doc_767882159210_item	3585618	et	3	main
poolnud	doc_767882159210_item	3585495	et	4	main
mehed	doc_767882159210_item	3585501	et	3	main
pulmadel	doc_767882159210_item	3585502	et	3	main
muusika	doc_767882159210_item	3585504	et	4	main
kõik	doc_767882159210_item	3585517	et	4	main
olid	doc_767882159210_item	3585519	et	4	main
sisuga	doc_767882159210_item	3585521	et	3	main
rahvalaulul	doc_767882159210_item	3585533	et	3	main
on	doc_767882159210_item	3585534	et	4	main
näiteks	doc_767882159210_item	3585537	et	4	main
me	doc_767882159210_item	3585539	et	4	main
võime	doc_767882159210_item	3585543	et	4	main
näha	doc_767882159210_item	3585544	et	3	main
et	doc_767882159210_item	3585545	et	3	main
sõnad	doc_767882159210_item	3585546	et	4	main
võetud	doc_767882159210_item	3585547	et	4	main
rahva	doc_767882159210_item	3585548	et	3	main
laulust	doc_767882159210_item	3585549	et	4	main
sellised	doc_767882159210_item	3585550	et	4	main
suure	doc_767882159210_item	3585551	et	3	main
laulupeod	doc_767882159210_item	3585552	et	4	main
hakkasid	doc_767882159210_item	3585553	et	4	main
toimuma	doc_767882159210_item	3585554	et	3	main
meil	doc_767882159210_item	3585555	et	4	main
eestis	doc_767882159210_item	3585556	et	3	main
allates	doc_767882159210_item	3585557	et	3	main
1994	doc_767882159210_item	3585558	et	2	main
aastalt	doc_767882159210_item	3585559	et	3	main
lauluväljakul	doc_767882159210_item	3585561	et	3	main
tallinna	doc_767882159210_item	3585560	et	4	main
seal	doc_767882159210_item	3585562	et	4	main
osa	doc_767882159210_item	3585563	et	4	main
võtsid	doc_767882159210_item	3585564	et	4	main
väga	doc_767882159210_item	3585565	et	3	main
aitavad	doc_767882159210_item	3585577	et	4	main
inimestele	doc_767882159210_item	3585578	et	3	main
tundma	doc_767882159210_item	3585579	et	3	main
rahv	doc_767882159210_item	3585582	et	4	main
kirjutasid	doc_767882159210_item	3585591	et	4	main
seotud	doc_767882159210_item	3585620	et	4	main
inimesed	doc_767882159210_item	3585632	et	3	main
keele	doc_767882159211_item	3585795	et	4	main
essee	doc_767882159211_item	3585802	et	4	main
teemal	doc_767882159211_item	3585803	et	3	main
mis	doc_767882159211_item	3585804	et	4	main
teeb	doc_767882159211_item	3585805	et	3	main
sõna	doc_767882159211_item	3585812	et	4	main
peab	doc_767882159211_item	3585814	et	4	main
arutlev	doc_767882159211_item	3585816	et	4	main
on	doc_767882159211_item	3585827	et	4	main
eesti	doc_767882159211_item	3585842	et	4	main
jarel	doc_767882159211_item	3585854	et	4	main
toimub	doc_767882159211_item	3585855	et	3	main
erinevaid	doc_767882159211_item	3585861	et	4	main
ansamblid	doc_767882159211_item	3585862	et	3	main
ja	doc_767882159211_item	3585863	et	3	main
tantsivad	doc_767882159211_item	3585868	et	4	main
essee	doc_767882159214_item	3585940	et	4	main
keele	doc_767882159214_item	3585942	et	4	main
kui	doc_767882159214_item	3585943	et	3	main
teise	doc_767882159214_item	3585944	et	4	main
teemal	doc_767882159214_item	3585950	et	3	main
mis	doc_767882159214_item	3585951	et	4	main
teeb	doc_767882159214_item	3585952	et	3	main
300	doc_767882159214_item	3585957	et	2	main
olema	doc_767882159214_item	3585962	et	4	main
on	doc_767882159214_item	3585974	et	4	main
eestlastest	doc_767882159214_item	3585980	et	4	main
et	doc_767882159214_item	3585983	et	3	main
ajal	doc_767882159214_item	3585993	et	4	main
ja	doc_767882159214_item	3585996	et	3	main
seljas	doc_767882159214_item	3586006	et	4	main
läksivad	doc_767882159214_item	3586008	et	4	main
ja	doc_767882159214_item	3586012	et	3	main
oma	doc_767882159214_item	3586018	et	4	main
mulle	doc_767882159214_item	3586037	et	4	main
kui	doc_767882159214_item	3586038	et	3	main
ilusad	doc_767882159214_item	3586039	et	3	main
on	doc_767882159210_item	3585627	et	4	main
tähtsad	doc_767882159210_item	3585629	et	3	main
unusta	doc_767882159210_item	3585634	et	4	main
teise	doc_767882159211_item	3585797	et	4	main
test	doc_767882159211_item	3585799	et	3	main
olema	doc_767882159211_item	3585815	et	4	main
esitatud	doc_767882159211_item	3585824	et	4	main
faktidele	doc_767882159211_item	3585825	et	3	main
väiteid	doc_767882159211_item	3585826	et	4	main
teeb	doc_767882159211_item	3585832	et	3	main
laulurahva	doc_767882159211_item	3585834	et	3	main
laulurahva	doc_767882159211_item	3585836	et	3	main
teeb	doc_767882159211_item	3585837	et	3	main
laulupidu	doc_767882159211_item	3585838	et	4	main
esimene	doc_767882159211_item	3585839	et	3	main
laulupidu	doc_767882159211_item	3585840	et	4	main
oli	doc_767882159211_item	3585841	et	3	main
püha	doc_767882159211_item	3585847	et	4	main
ühendas	doc_767882159211_item	3585848	et	3	main
põlvest	doc_767882159211_item	3585913	et	4	main
põlve	doc_767882159211_item	3585914	et	4	main
suuliselt	doc_767882159211_item	3585915	et	4	main
eesti	doc_767882159211_item	3585916	et	4	main
vanemat	doc_767882159211_item	3585917	et	4	main
laulutraditsiooni	doc_767882159211_item	3585918	et	4	main
esindab	doc_767882159211_item	3585919	et	3	main
läänemeresoome	doc_767882159211_item	3585920	et	3	main
kultuurile	doc_767882159211_item	3585921	et	3	main
iseloomulik	doc_767882159211_item	3585922	et	3	main
regivärsiline	doc_767882159211_item	3585923	et	4	main
rahvalaul	doc_767882159211_item	3585924	et	4	main
estlased	doc_767882159211_item	3585925	et	4	main
kirjutavad	doc_767882159211_item	3585926	et	4	main
väga	doc_767882159211_item	3585927	et	3	main
ilusad	doc_767882159211_item	3585928	et	3	main
laulud	doc_767882159211_item	3585929	et	3	main
kui	doc_767882159211_item	3585930	et	3	main
ma	doc_767882159211_item	3585931	et	3	main
kuulasin	doc_767882159211_item	3585932	et	3	main
eesti	doc_767882159211_item	3585933	et	4	main
laulan	doc_767882159211_item	3585934	et	3	main
ma	doc_767882159211_item	3585935	et	3	main
tunnen	doc_767882159211_item	3585936	et	3	main
ennast	doc_767882159211_item	3585937	et	4	main
hästi	doc_767882159211_item	3585938	et	3	main
kui	doc_767882159211_item	3585796	et	3	main
kirjutamine	doc_767882159211_item	3585800	et	4	main
kirjutage	doc_767882159211_item	3585801	et	3	main
essee	doc_767882159211_item	3585813	et	4	main
loengus	doc_767882159211_item	3585821	et	3	main
ja	doc_767882159211_item	3585822	et	3	main
aja	doc_767882159211_item	3585845	et	4	main
see	doc_767882159211_item	3585846	et	3	main
inimesi	doc_767882159211_item	3585850	et	4	main
seal	doc_767882159211_item	3585857	et	4	main
laulavad	doc_767882159211_item	3585866	et	4	main
toimub	doc_767882159211_item	3585870	et	3	main
tavaliselt	doc_767882159211_item	3585871	et	4	main
juulikuu	doc_767882159211_item	3585872	et	4	main
esimesel	doc_767882159211_item	3585873	et	3	main
nädalavahetusel	doc_767882159211_item	3585874	et	4	main
üks	doc_767882159211_item	3585875	et	3	main
kord	doc_767882159211_item	3585876	et	4	main
ma	doc_767882159211_item	3585877	et	3	main
olin	doc_767882159211_item	3585878	et	3	main
seal	doc_767882159211_item	3585879	et	4	main
mulle	doc_767882159211_item	3585880	et	4	main
väga	doc_767882159211_item	3585881	et	3	main
meeldib	doc_767882159211_item	3585882	et	3	main
see	doc_767882159211_item	3585883	et	3	main
laulupidu	doc_767882159211_item	3585884	et	4	main
rahvariietes	doc_767882159211_item	3585885	et	3	main
esitavad	doc_767882159211_item	3585886	et	4	main
tantsulise	doc_767882159211_item	3585887	et	4	main
vaatemangu	doc_767882159211_item	3585888	et	4	main
spordistadionil	doc_767882159211_item	3585889	et	4	main
eesti	doc_767882159211_item	3585890	et	4	main
rahvale	doc_767882159211_item	3585891	et	3	main
oli	doc_767882159211_item	3585892	et	3	main
tulevad	doc_767882159211_item	3585858	et	4	main
kokku	doc_767882159211_item	3585859	et	3	main
palju	doc_767882159211_item	3585860	et	4	main
nii	doc_767882159211_item	3585893	et	3	main
kultuuriliselt	doc_767882159211_item	3585894	et	4	main
kui	doc_767882159211_item	3585895	et	3	main
poliitiliselt	doc_767882159211_item	3585896	et	4	main
väga	doc_767882159211_item	3585897	et	3	main
suur	doc_767882159211_item	3585898	et	3	main
tähendus	doc_767882159211_item	3585899	et	4	main
eestis	doc_767882159211_item	3585900	et	3	main
on	doc_767882159211_item	3585901	et	4	main
väga	doc_767882159211_item	3585902	et	3	main
ilus	doc_767882159211_item	3585903	et	4	main
loodus	doc_767882159211_item	3585904	et	4	main
ja	doc_767882159211_item	3585905	et	3	main
paljud	doc_767882159211_item	3585906	et	3	main
laulud	doc_767882159211_item	3585907	et	3	main
loodusest	doc_767882159211_item	3585908	et	4	main
loomadest	doc_767882159211_item	3585909	et	3	main
seda	doc_767882159211_item	3585910	et	3	main
laulud	doc_767882159211_item	3585911	et	3	main
levisid	doc_767882159211_item	3585912	et	4	main
test	doc_767882159214_item	3585946	et	3	main
kirjutage	doc_767882159214_item	3585948	et	3	main
pikkus	doc_767882159214_item	3585956	et	4	main
sõna	doc_767882159214_item	3585959	et	4	main
peab	doc_767882159214_item	3585961	et	4	main
soovitatav	doc_767882159214_item	3585975	et	4	main
illustreerida	doc_767882159214_item	3585976	et	3	main
näidetega	doc_767882159214_item	3585977	et	3	main
laulurahva	doc_767882159214_item	3585981	et	3	main
kui	doc_767882159214_item	3585984	et	3	main
last	doc_767882159214_item	3585987	et	4	main
oma	doc_767882159214_item	3585989	et	4	main
vanaemaga	doc_767882159214_item	3585990	et	3	main
nägin	doc_767882159214_item	3585998	et	3	main
naised	doc_767882159214_item	3586000	et	3	main
siis	doc_767882159214_item	3586016	et	3	main
vanaema	doc_767882159214_item	3586020	et	4	main
mina	doc_767882159214_item	3586023	et	4	main
nooreks	doc_767882159214_item	3586024	et	3	main
olin	doc_767882159214_item	3586025	et	3	main
ja	doc_767882159214_item	3586042	et	3	main
tavaliselt	doc_767882159214_item	3586048	et	4	main
on	doc_767882159214_item	3586051	et	4	main
suur	doc_767882159214_item	3586052	et	3	main
tähtis	doc_767882159214_item	3586053	et	4	main
laulupidu	doc_767882159214_item	3586062	et	4	main
kolmest	doc_767882159214_item	3586064	et	4	main
tantsid	doc_767882159214_item	3586066	et	4	main
laulu	doc_767882159214_item	3586068	et	4	main
isamaa	doc_767882159214_item	3586075	et	4	main
on	doc_767882159214_item	3586076	et	4	main
ja	doc_767882159214_item	3586083	et	3	main
ka	doc_767882159214_item	3586087	et	3	main
nii	doc_767882159214_item	3586089	et	3	main
aluseks	doc_767882159214_item	3586090	et	4	main
eesti	doc_767882159214_item	3586101	et	4	main
ajaloo	doc_767882159214_item	3586103	et	4	main
on	doc_767882159214_item	3586104	et	4	main
vanemad	doc_767882159214_item	3586110	et	4	main
laulurahva	doc_767882159214_item	3585954	et	3	main
arutlev	doc_767882159214_item	3585963	et	4	main
analüüsiv	doc_767882159214_item	3585964	et	4	main
ja	doc_767882159214_item	3585965	et	3	main
üldistav	doc_767882159214_item	3585966	et	4	main
kirjutamine	doc_767882159214_item	3585947	et	4	main
eestlastest	doc_767882159214_item	3585953	et	4	main
350	doc_767882159214_item	3585958	et	2	main
essee	doc_767882159214_item	3585960	et	4	main
tuginema	doc_767882159214_item	3585967	et	3	main
loengus	doc_767882159214_item	3585968	et	3	main
ja	doc_767882159214_item	3585969	et	3	main
lugemistekstis	doc_767882159214_item	3585970	et	3	main
mis	doc_767882159214_item	3585978	et	4	main
määletan	doc_767882159214_item	3585982	et	4	main
olin	doc_767882159214_item	3585985	et	3	main
jalutasime	doc_767882159214_item	3585988	et	3	main
ma	doc_767882159214_item	3585997	et	3	main
nad	doc_767882159214_item	3586007	et	3	main
vana	doc_767882159214_item	3586009	et	4	main
tallinna	doc_767882159214_item	3586010	et	4	main
minu	doc_767882159214_item	3586017	et	3	main
kena	doc_767882159214_item	3586019	et	4	main
ütles	doc_767882159214_item	3586021	et	3	main
kui	doc_767882159214_item	3586022	et	3	main
tantsin	doc_767882159214_item	3586028	et	3	main
ja	doc_767882159214_item	3586029	et	3	main
kooriga	doc_767882159214_item	3586031	et	4	main
olid	doc_767882159214_item	3586040	et	4	main
määletused	doc_767882159214_item	3586045	et	4	main
tartus	doc_767882159214_item	3586057	et	3	main
ka	doc_767882159214_item	3586061	et	3	main
tehtsad	doc_767882159214_item	3586065	et	4	main
ja	doc_767882159214_item	3586067	et	3	main
pidul	doc_767882159214_item	3586079	et	3	main
lastekoorid	doc_767882159214_item	3586081	et	3	main
laulsid	doc_767882159214_item	3586088	et	4	main
koor	doc_767882159214_item	3586096	et	4	main
mäletavad	doc_767882159214_item	3586108	et	4	main
meie	doc_767882159214_item	3586109	et	4	main
ja	doc_767882159214_item	3586114	et	3	main
on	doc_767882159214_item	3586127	et	4	main
koos	doc_767882159214_item	3586140	et	4	main
tegid	doc_767882159214_item	3586149	et	4	main
nad	doc_767882159214_item	3586152	et	3	main
elasid	doc_767882159214_item	3586153	et	4	main
tänapäeval	doc_767882159214_item	3586154	et	3	main
rahvalaul	doc_767882159214_item	3586155	et	4	main
muusikat	doc_767882159214_item	3586161	et	3	main
kasutatakse	doc_767882159214_item	3586163	et	3	main
muusika	doc_767882159214_item	3586169	et	4	main
on	doc_767882159214_item	3586189	et	4	main
on	doc_767882159214_item	3586226	et	4	main
linna	doc_767882159214_item	3586234	et	4	main
keele	doc_767882159215_item	3586259	et	4	main
keele	doc_767882159215_item	3586262	et	4	main
eestlastest	doc_767882159215_item	3586270	et	4	main
laulurahva	doc_767882159215_item	3586271	et	3	main
essee	doc_767882159215_item	3586272	et	4	main
essee	doc_767882159215_item	3586277	et	4	main
olema	doc_767882159215_item	3586279	et	4	main
arutlev	doc_767882159215_item	3586280	et	4	main
analüüsiv	doc_767882159215_item	3586281	et	4	main
ja	doc_767882159215_item	3586282	et	3	main
kultuuriosa	doc_767882159215_item	3586301	et	4	main
et	doc_767882159215_item	3586302	et	3	main
elab	doc_767882159215_item	3586303	et	3	main
on	doc_767882159215_item	3586312	et	4	main
ise	doc_767882159215_item	3586336	et	4	main
osavõtlesin	doc_767882159215_item	3586337	et	4	main
laulupeos	doc_767882159215_item	3586338	et	4	main
1994	doc_767882159215_item	3586339	et	2	main
akkordeonis	doc_767882159215_item	3586343	et	4	main
muusikakooli	doc_767882159215_item	3586345	et	4	main
esitles	doc_767882159215_item	3586355	et	3	main
keskkooli	doc_767882159215_item	3586357	et	4	main
ma	doc_767882159215_item	3586359	et	3	main
kuidas	doc_767882159215_item	3586369	et	3	main
populaarne	doc_767882159215_item	3586370	et	3	main
laulavad	doc_767882159215_item	3586389	et	4	main
trükitult	doc_767882159215_item	3586416	et	4	main
see	doc_767882159215_item	3586417	et	3	main
tähendab	doc_767882159215_item	3586418	et	3	main
või	doc_767882159215_item	3586421	et	4	main
traditsioon	doc_767882159215_item	3586433	et	3	main
ernesaks	doc_767882159215_item	3586446	et	4	main
esitatud	doc_767882159214_item	3585971	et	4	main
faktidele	doc_767882159214_item	3585972	et	3	main
väiteid	doc_767882159214_item	3585973	et	4	main
mina	doc_767882159214_item	3585986	et	4	main
oli	doc_767882159214_item	3585994	et	3	main
suvi	doc_767882159214_item	3585995	et	3	main
palju	doc_767882159214_item	3585999	et	4	main
neil	doc_767882159214_item	3586001	et	4	main
olid	doc_767882159214_item	3586002	et	4	main
tänaval	doc_767882159214_item	3586011	et	4	main
laulsid	doc_767882159214_item	3586013	et	4	main
laulut	doc_767882159214_item	3586014	et	4	main
ja	doc_767882159214_item	3586015	et	3	main
mina	doc_767882159214_item	3586027	et	4	main
laulsin	doc_767882159214_item	3586030	et	3	main
laulupidudel	doc_767882159214_item	3586032	et	4	main
igal	doc_767882159214_item	3586033	et	3	main
aastal	doc_767882159214_item	3586034	et	3	main
ta	doc_767882159214_item	3586035	et	4	main
jutustas	doc_767882159214_item	3586036	et	3	main
kui	doc_767882159214_item	3586043	et	3	main
on	doc_767882159214_item	3586047	et	4	main
laulupidud	doc_767882159214_item	3586049	et	3	main
pärast	doc_767882159214_item	3586058	et	4	main
koosneb	doc_767882159214_item	3586063	et	3	main
isamaalaulust	doc_767882159214_item	3586073	et	4	main
mu	doc_767882159214_item	3586074	et	3	main
arv	doc_767882159214_item	3586078	et	3	main
naistekoorid	doc_767882159214_item	3586082	et	3	main
poisikoorid	doc_767882159214_item	3586084	et	3	main
mehed	doc_767882159214_item	3586086	et	3	main
sellises	doc_767882159214_item	3586105	et	4	main
propagandeerivad	doc_767882159214_item	3586112	et	4	main
mõtlen	doc_767882159214_item	3586117	et	3	main
nii	doc_767882159214_item	3586119	et	3	main
näidavad	doc_767882159214_item	3586122	et	4	main
sellest	doc_767882159214_item	3586124	et	4	main
et	doc_767882159214_item	3586125	et	3	main
tantisid	doc_767882159214_item	3586139	et	4	main
kleidid	doc_767882159214_item	3586005	et	3	main
siis	doc_767882159214_item	3586026	et	3	main
head	doc_767882159214_item	3586044	et	4	main
aluseks	doc_767882159214_item	3586054	et	4	main
laulupidud	doc_767882159214_item	3586055	et	3	main
oli	doc_767882159214_item	3586056	et	3	main
on	doc_767882159214_item	3586060	et	4	main
minu	doc_767882159214_item	3586077	et	3	main
pärast	doc_767882159214_item	3586095	et	4	main
regilaule	doc_767882159214_item	3586098	et	4	main
pidudes	doc_767882159214_item	3586106	et	4	main
rahvamuusikat	doc_767882159214_item	3586115	et	3	main
pidud	doc_767882159214_item	3586121	et	3	main
meile	doc_767882159214_item	3586123	et	4	main
eestlased	doc_767882159214_item	3586126	et	3	main
kui	doc_767882159214_item	3586129	et	3	main
ei	doc_767882159214_item	3586130	et	4	main
mida	doc_767882159214_item	3586147	et	4	main
ja	doc_767882159214_item	3586150	et	3	main
kuidas	doc_767882159214_item	3586151	et	3	main
muusika	doc_767882159214_item	3586167	et	4	main
head	doc_767882159214_item	3586173	et	4	main
palju	doc_767882159214_item	3586187	et	4	main
jutustame	doc_767882159214_item	3586193	et	3	main
mõjutab	doc_767882159214_item	3586228	et	3	main
tänavadel	doc_767882159214_item	3586235	et	4	main
tantsivad	doc_767882159214_item	3586237	et	4	main
ja	doc_767882159214_item	3586238	et	3	main
essee	doc_767882159215_item	3586257	et	4	main
350	doc_767882159215_item	3586275	et	2	main
üldistav	doc_767882159215_item	3586283	et	4	main
tuginema	doc_767882159215_item	3586284	et	3	main
loengus	doc_767882159215_item	3586285	et	3	main
on	doc_767882159215_item	3586291	et	4	main
soovitatav	doc_767882159215_item	3586292	et	4	main
illustreerida	doc_767882159215_item	3586293	et	3	main
näidetega	doc_767882159215_item	3586294	et	3	main
praaegu	doc_767882159215_item	3586304	et	4	main
ja	doc_767882159215_item	3586305	et	3	main
ma	doc_767882159215_item	3586341	et	3	main
oma	doc_767882159215_item	3586344	et	4	main
vennatega	doc_767882159215_item	3586347	et	4	main
veel	doc_767882159215_item	3586349	et	4	main
laulupidud	doc_767882159214_item	3586041	et	3	main
see	doc_767882159214_item	3586046	et	3	main
eestirahvale	doc_767882159214_item	3586050	et	3	main
tallinnas	doc_767882159214_item	3586059	et	4	main
iga	doc_767882159214_item	3586069	et	4	main
kord	doc_767882159214_item	3586070	et	4	main
alustakse	doc_767882159214_item	3586071	et	3	main
laulupidud	doc_767882159214_item	3586072	et	3	main
olid	doc_767882159214_item	3586080	et	4	main
laulsid	doc_767882159214_item	3586085	et	4	main
laulas	doc_767882159214_item	3586091	et	4	main
üks	doc_767882159214_item	3586092	et	3	main
inimene	doc_767882159214_item	3586093	et	3	main
ja	doc_767882159214_item	3586094	et	3	main
laulsid	doc_767882159214_item	3586097	et	4	main
noor	doc_767882159214_item	3586099	et	3	main
naised	doc_767882159214_item	3586100	et	3	main
rahva	doc_767882159214_item	3586102	et	3	main
mille	doc_767882159214_item	3586107	et	3	main
rehvatantsu	doc_767882159214_item	3586113	et	4	main
suured	doc_767882159214_item	3586120	et	3	main
laulurahva	doc_767882159214_item	3586128	et	3	main
ja	doc_767882159214_item	3586141	et	3	main
neid	doc_767882159214_item	3586142	et	4	main
laulud	doc_767882159214_item	3586143	et	3	main
jutustavad	doc_767882159214_item	3586144	et	4	main
eestlased	doc_767882159214_item	3586148	et	3	main
on	doc_767882159214_item	3586157	et	4	main
rok	doc_767882159214_item	3586166	et	4	main
palju	doc_767882159214_item	3586172	et	4	main
või	doc_767882159214_item	3586178	et	4	main
hästi	doc_767882159214_item	3586179	et	3	main
populaarne	doc_767882159214_item	3586180	et	3	main
omamoodu	doc_767882159214_item	3586181	et	4	main
rahvalaulud	doc_767882159214_item	3586182	et	3	main
folkloorid	doc_767882159214_item	3586188	et	4	main
rahvalaulust	doc_767882159214_item	3586194	et	4	main
tähtsam	doc_767882159214_item	3586220	et	4	main
alati	doc_767882159214_item	3586227	et	4	main
teise	doc_767882159215_item	3586261	et	4	main
mis	doc_767882159215_item	3586268	et	4	main
teeb	doc_767882159215_item	3586269	et	3	main
300	doc_767882159215_item	3586274	et	2	main
lugemistekstis	doc_767882159215_item	3586287	et	3	main
rahvalaul	doc_767882159215_item	3586295	et	4	main
elab	doc_767882159215_item	3586306	et	3	main
tulevikus	doc_767882159215_item	3586307	et	4	main
kus	doc_767882159215_item	3586340	et	3	main
mul	doc_767882159215_item	3586348	et	3	main
võimalus	doc_767882159215_item	3586351	et	3	main
minu	doc_767882159215_item	3586356	et	3	main
ajal	doc_767882159215_item	3586366	et	4	main
eestlastel	doc_767882159215_item	3586378	et	4	main
ka	doc_767882159215_item	3586379	et	3	main
venelastel	doc_767882159215_item	3586380	et	4	main
kõigem	doc_767882159215_item	3586381	et	4	main
pillisaateta	doc_767882159215_item	3586391	et	3	main
eeslaulja	doc_767882159215_item	3586392	et	4	main
hakkab	doc_767882159215_item	3586393	et	3	main
ja	doc_767882159215_item	3586394	et	3	main
et	doc_767882159215_item	3586414	et	3	main
levisid	doc_767882159215_item	3586415	et	4	main
rahvalaul	doc_767882159215_item	3586420	et	4	main
olla	doc_767882159215_item	3586422	et	3	main
regilaulu	doc_767882159215_item	3586432	et	4	main
20	doc_767882159215_item	3586434	et	2	main
sajandil	doc_767882159215_item	3586435	et	3	main
eesti	doc_767882159215_item	3586436	et	4	main
1969	doc_767882159215_item	3586442	et	2	main
koidulas	doc_767882159215_item	3586449	et	4	main
peab	doc_767882159215_item	3586494	et	4	main
kui	doc_767882159216_item	3586507	et	3	main
peab	doc_767882159216_item	3586525	et	4	main
esitatud	doc_767882159216_item	3586535	et	4	main
faktidele	doc_767882159216_item	3586536	et	3	main
on	doc_767882159216_item	3586538	et	4	main
soovitatav	doc_767882159216_item	3586539	et	4	main
illustreerida	doc_767882159216_item	3586540	et	3	main
näidetega	doc_767882159216_item	3586541	et	3	main
ajalt	doc_767882159216_item	3586549	et	4	main
ja	doc_767882159216_item	3586550	et	3	main
rahvapidud	doc_767882159214_item	3586111	et	3	main
ma	doc_767882159214_item	3586116	et	3	main
et	doc_767882159214_item	3586118	et	3	main
olnud	doc_767882159214_item	3586131	et	4	main
telerit	doc_767882159214_item	3586132	et	3	main
ja	doc_767882159214_item	3586133	et	3	main
telefonit	doc_767882159214_item	3586134	et	4	main
inimesed	doc_767882159214_item	3586135	et	3	main
mängusid	doc_767882159214_item	3586136	et	3	main
laulusid	doc_767882159214_item	3586137	et	3	main
ja	doc_767882159214_item	3586138	et	3	main
ka	doc_767882159214_item	3586158	et	3	main
tänapäeva	doc_767882159214_item	3586160	et	4	main
erinevad	doc_767882159214_item	3586164	et	4	main
stiilid	doc_767882159214_item	3586165	et	4	main
olevikus	doc_767882159214_item	3586170	et	3	main
on	doc_767882159214_item	3586171	et	4	main
nägu	doc_767882159214_item	3586175	et	4	main
ansambel	doc_767882159214_item	3586176	et	3	main
kukkerpillid	doc_767882159214_item	3586177	et	4	main
kasutatud	doc_767882159214_item	3586186	et	4	main
positiivselt	doc_767882159214_item	3586229	et	4	main
kõigile	doc_767882159214_item	3586230	et	4	main
inimestele	doc_767882159214_item	3586231	et	3	main
inimesed	doc_767882159214_item	3586232	et	3	main
meile	doc_767882159214_item	3586145	et	4	main
sellest	doc_767882159214_item	3586146	et	4	main
muidugi	doc_767882159214_item	3586156	et	4	main
rahvaliku	doc_767882159214_item	3586159	et	3	main
on	doc_767882159214_item	3586162	et	4	main
vana	doc_767882159214_item	3586168	et	4	main
ansamleid	doc_767882159214_item	3586174	et	4	main
filmides	doc_767882159214_item	3586183	et	4	main
on	doc_767882159214_item	3586184	et	4	main
ka	doc_767882159214_item	3586185	et	3	main
olnud	doc_767882159214_item	3586190	et	4	main
arhiivides	doc_767882159214_item	3586191	et	3	main
kui	doc_767882159214_item	3586192	et	3	main
rägime	doc_767882159214_item	3586195	et	4	main
et	doc_767882159214_item	3586196	et	3	main
sinad	doc_767882159214_item	3586197	et	4	main
laulus	doc_767882159214_item	3586198	et	3	main
oli	doc_767882159214_item	3586199	et	3	main
lihtne	doc_767882159214_item	3586200	et	3	main
nagu	doc_767882159214_item	3586201	et	3	main
sind	doc_767882159214_item	3586202	et	4	main
mind	doc_767882159214_item	3586203	et	4	main
puu	doc_767882159214_item	3586204	et	4	main
kuu	doc_767882159214_item	3586205	et	4	main
veel	doc_767882159214_item	3586206	et	4	main
rahvalaulmine	doc_767882159214_item	3586207	et	3	main
tekkis	doc_767882159214_item	3586208	et	3	main
kirikus	doc_767882159214_item	3586209	et	3	main
rahvalaul	doc_767882159214_item	3586210	et	4	main
on	doc_767882159214_item	3586211	et	4	main
eestirahva	doc_767882159214_item	3586212	et	3	main
kuultur	doc_767882159214_item	3586213	et	4	main
ja	doc_767882159214_item	3586214	et	3	main
ajaloo	doc_767882159214_item	3586215	et	4	main
ja	doc_767882159214_item	3586216	et	3	main
laulupidu	doc_767882159214_item	3586217	et	4	main
on	doc_767882159214_item	3586218	et	4	main
kõige	doc_767882159214_item	3586219	et	4	main
pidu	doc_767882159214_item	3586221	et	4	main
ma	doc_767882159214_item	3586222	et	3	main
arvan	doc_767882159214_item	3586223	et	3	main
et	doc_767882159214_item	3586224	et	3	main
laulupidud	doc_767882159214_item	3586225	et	3	main
jalutavad	doc_767882159214_item	3586233	et	4	main
laulavad	doc_767882159214_item	3586236	et	4	main
muidugi	doc_767882159214_item	3586239	et	4	main
esitlevad	doc_767882159214_item	3586240	et	4	main
laulupeol	doc_767882159214_item	3586241	et	4	main
rahv	doc_767882159214_item	3586242	et	4	main
määletab	doc_767882159214_item	3586243	et	4	main
oma	doc_767882159214_item	3586244	et	4	main
ajaloo	doc_767882159214_item	3586245	et	4	main
ja	doc_767882159214_item	3586246	et	3	main
see	doc_767882159214_item	3586247	et	3	main
on	doc_767882159214_item	3586248	et	4	main
väga	doc_767882159214_item	3586249	et	3	main
hea	doc_767882159214_item	3586250	et	4	main
ja	doc_767882159214_item	3586251	et	3	main
see	doc_767882159214_item	3586252	et	3	main
on	doc_767882159214_item	3586253	et	4	main
väga	doc_767882159214_item	3586254	et	3	main
tähtis	doc_767882159214_item	3586255	et	4	main
kui	doc_767882159215_item	3586260	et	3	main
kirjutamine	doc_767882159215_item	3586264	et	4	main
kirjutage	doc_767882159215_item	3586265	et	3	main
essee	doc_767882159215_item	3586266	et	4	main
teemal	doc_767882159215_item	3586267	et	3	main
pikkus	doc_767882159215_item	3586273	et	4	main
ja	doc_767882159215_item	3586286	et	3	main
tähtsam	doc_767882159215_item	3586300	et	4	main
klassi	doc_767882159215_item	3586346	et	4	main
oli	doc_767882159215_item	3586350	et	3	main
laulda	doc_767882159215_item	3586352	et	4	main
kooris	doc_767882159215_item	3586353	et	4	main
oskanud	doc_767882159215_item	3586361	et	4	main
see	doc_767882159215_item	3586367	et	3	main
on	doc_767882159215_item	3586371	et	4	main
eesti	doc_767882159215_item	3586374	et	4	main
elanikul	doc_767882159215_item	3586375	et	3	main
ning	doc_767882159215_item	3586376	et	3	main
kui	doc_767882159215_item	3586377	et	3	main
vanem	doc_767882159215_item	3586382	et	4	main
regivärsiline	doc_767882159215_item	3586386	et	4	main
erinevad	doc_767882159215_item	3586412	et	4	main
on	doc_767882159215_item	3586426	et	4	main
on	doc_767882159215_item	3586431	et	4	main
fokuseritis	doc_767882159215_item	3586438	et	4	main
liidias	doc_767882159215_item	3586448	et	4	main
isamalaulana	doc_767882159215_item	3586456	et	4	main
inglise	doc_767882159215_item	3586491	et	4	main
keele	doc_767882159216_item	3586506	et	4	main
keele	doc_767882159216_item	3586509	et	4	main
kirjutamine	doc_767882159216_item	3586511	et	4	main
laulurahva	doc_767882159216_item	3586518	et	3	main
ja	doc_767882159216_item	3586533	et	3	main
rahva	doc_767882159216_item	3586545	et	3	main
kultuuris	doc_767882159216_item	3586546	et	3	main
juba	doc_767882159216_item	3586547	et	3	main
vanalt	doc_767882159216_item	3586548	et	4	main
me	doc_767882159216_item	3586553	et	4	main
seda	doc_767882159216_item	3586554	et	3	main
iga	doc_767882159216_item	3586555	et	4	main
kohal	doc_767882159215_item	3586497	et	4	main
aga	doc_767882159215_item	3586498	et	3	main
mäletasin	doc_767882159215_item	3586499	et	3	main
ainult	doc_767882159215_item	3586500	et	4	main
siin	doc_767882159215_item	3586501	et	4	main
vabandage	doc_767882159215_item	3586502	et	3	main
eesti	doc_767882159215_item	3586258	et	4	main
test	doc_767882159215_item	3586263	et	3	main
sõna	doc_767882159215_item	3586276	et	4	main
peab	doc_767882159215_item	3586278	et	4	main
esitatud	doc_767882159215_item	3586288	et	4	main
faktidele	doc_767882159215_item	3586289	et	3	main
väiteid	doc_767882159215_item	3586290	et	4	main
on	doc_767882159215_item	3586296	et	4	main
kõigem	doc_767882159215_item	3586297	et	4	main
vanem	doc_767882159215_item	3586298	et	4	main
ja	doc_767882159215_item	3586299	et	3	main
koos	doc_767882159215_item	3586308	et	4	main
eesti	doc_767882159215_item	3586309	et	4	main
rahvustega	doc_767882159215_item	3586310	et	3	main
see	doc_767882159215_item	3586311	et	3	main
kõigem	doc_767882159215_item	3586313	et	4	main
kallim	doc_767882159215_item	3586314	et	4	main
asi	doc_767882159215_item	3586315	et	4	main
mis	doc_767882159215_item	3586316	et	4	main
ei	doc_767882159215_item	3586317	et	4	main
surnud	doc_767882159215_item	3586318	et	4	main
tuhat	doc_767882159215_item	3586319	et	4	main
aastat	doc_767882159215_item	3586320	et	3	main
tagasi	doc_767882159215_item	3586321	et	3	main
sõja	doc_767882159215_item	3586322	et	3	main
ja	doc_767882159215_item	3586323	et	3	main
okupatsiooni	doc_767882159215_item	3586324	et	4	main
ajal	doc_767882159215_item	3586325	et	4	main
eesti	doc_767882159215_item	3586326	et	4	main
rahvalaul	doc_767882159215_item	3586327	et	4	main
ühendab	doc_767882159215_item	3586328	et	3	main
ajaloost	doc_767882159215_item	3586329	et	4	main
reaalsustega	doc_767882159215_item	3586330	et	4	main
vanakest	doc_767882159215_item	3586331	et	4	main
lapsedega	doc_767882159215_item	3586332	et	3	main
venelastest	doc_767882159215_item	3586333	et	4	main
eestlastega	doc_767882159215_item	3586334	et	4	main
ma	doc_767882159215_item	3586335	et	3	main
mängisin	doc_767882159215_item	3586342	et	3	main
et	doc_767882159215_item	3586354	et	3	main
aga	doc_767882159215_item	3586358	et	3	main
olema	doc_767882159215_item	3586362	et	4	main
kahe	doc_767882159215_item	3586363	et	3	main
kohas	doc_767882159215_item	3586364	et	4	main
sama	doc_767882159215_item	3586365	et	4	main
rahvalaul	doc_767882159215_item	3586372	et	4	main
kõigel	doc_767882159215_item	3586373	et	4	main
oli	doc_767882159215_item	3586384	et	3	main
iseloomulik	doc_767882159215_item	3586385	et	3	main
rahvalaul	doc_767882159215_item	3586387	et	4	main
regilaulu	doc_767882159215_item	3586388	et	4	main
regilaulust	doc_767882159215_item	3586413	et	4	main
kadunud	doc_767882159215_item	3586427	et	4	main
ainult	doc_767882159215_item	3586428	et	4	main
setumaal	doc_767882159215_item	3586429	et	4	main
teisel	doc_767882159215_item	3586439	et	4	main
asjadel	doc_767882159215_item	3586440	et	3	main
juubelilaulupeos	doc_767882159215_item	3586444	et	4	main
gustav	doc_767882159215_item	3586445	et	4	main
isamaa	doc_767882159215_item	3586452	et	4	main
kes	doc_767882159215_item	3586484	et	4	main
tantsib	doc_767882159215_item	3586487	et	3	main
ta	doc_767882159215_item	3586488	et	4	main
olema	doc_767882159215_item	3586495	et	4	main
ei	doc_767882159215_item	3586360	et	4	main
näitab	doc_767882159215_item	3586368	et	3	main
rahvalaul	doc_767882159215_item	3586383	et	4	main
ilma	doc_767882159215_item	3586390	et	4	main
koor	doc_767882159215_item	3586395	et	4	main
kordab	doc_767882159215_item	3586396	et	3	main
koorilauluajal	doc_767882159215_item	3586397	et	3	main
eeslaulja	doc_767882159215_item	3586398	et	4	main
mõtleb	doc_767882159215_item	3586399	et	3	main
mida	doc_767882159215_item	3586400	et	4	main
edasi	doc_767882159215_item	3586401	et	3	main
laulama	doc_767882159215_item	3586402	et	4	main
regilaul	doc_767882159215_item	3586403	et	4	main
võiks	doc_767882159215_item	3586404	et	4	main
olla	doc_767882159215_item	3586405	et	3	main
väga	doc_767882159215_item	3586406	et	3	main
pikk	doc_767882159215_item	3586407	et	4	main
ja	doc_767882159215_item	3586408	et	3	main
spontaalset	doc_767882159215_item	3586409	et	4	main
riimilised	doc_767882159215_item	3586410	et	4	main
rahvalaulud	doc_767882159215_item	3586411	et	3	main
et	doc_767882159215_item	3586419	et	3	main
programeeritud	doc_767882159215_item	3586423	et	4	main
spontaalse	doc_767882159215_item	3586424	et	4	main
improvisatsioon	doc_767882159215_item	3586425	et	3	main
veel	doc_767882159215_item	3586430	et	4	main
rahvus	doc_767882159215_item	3586437	et	3	main
iseseisvusel	doc_767882159215_item	3586441	et	4	main
aastal	doc_767882159215_item	3586443	et	3	main
sõnad	doc_767882159215_item	3586450	et	4	main
mu	doc_767882159215_item	3586451	et	3	main
et	doc_767882159215_item	3586457	et	3	main
vaheta	doc_767882159215_item	3586458	et	4	main
eestlastele	doc_767882159215_item	3586459	et	4	main
hümni	doc_767882159215_item	3586460	et	4	main
mis	doc_767882159215_item	3586461	et	4	main
oli	doc_767882159215_item	3586462	et	3	main
keelatud	doc_767882159215_item	3586463	et	4	main
okupatsiooni	doc_767882159215_item	3586464	et	4	main
periodil	doc_767882159215_item	3586465	et	4	main
rahvalaul	doc_767882159215_item	3586466	et	4	main
annab	doc_767882159215_item	3586467	et	3	main
võimalust	doc_767882159215_item	3586468	et	3	main
tunneda	doc_767882159215_item	3586469	et	4	main
iseseisvust	doc_767882159215_item	3586470	et	4	main
annab	doc_767882159215_item	3586471	et	3	main
kultuuritraditsiooni	doc_767882159215_item	3586472	et	4	main
vanast	doc_767882159215_item	3586473	et	3	main
noortele	doc_767882159215_item	3586474	et	3	main
rahvalaulas	doc_767882159215_item	3586475	et	4	main
on	doc_767882159215_item	3586476	et	4	main
eesti	doc_767882159215_item	3586477	et	4	main
ajalugu	doc_767882159215_item	3586478	et	4	main
õnne	doc_767882159215_item	3586479	et	4	main
vere	doc_767882159215_item	3586480	et	3	main
vaim	doc_767882159215_item	3586481	et	3	main
ja	doc_767882159215_item	3586482	et	3	main
vabadus	doc_767882159215_item	3586483	et	4	main
laulab	doc_767882159215_item	3586485	et	3	main
ja	doc_767882159215_item	3586486	et	3	main
esitas	doc_767882159215_item	3586447	et	3	main
on	doc_767882159215_item	3586453	et	4	main
minu	doc_767882159215_item	3586454	et	3	main
arm	doc_767882159215_item	3586455	et	3	main
alati	doc_767882159215_item	3586489	et	4	main
võidab	doc_767882159215_item	3586490	et	3	main
epigrafi	doc_767882159215_item	3586496	et	4	main
essee	doc_767882159216_item	3586504	et	4	main
eestlastest	doc_767882159216_item	3586517	et	4	main
essee	doc_767882159216_item	3586519	et	4	main
pikkus	doc_767882159216_item	3586520	et	4	main
300	doc_767882159216_item	3586521	et	2	main
arutlev	doc_767882159216_item	3586527	et	4	main
analüüsiv	doc_767882159216_item	3586528	et	4	main
üldistav	doc_767882159216_item	3586530	et	4	main
on	doc_767882159216_item	3586543	et	4	main
tänapäevaseni	doc_767882159216_item	3586551	et	4	main
välja	doc_767882159216_item	3586590	et	4	main
mõtles	doc_767882159216_item	3586591	et	3	main
aga	doc_767882159216_item	3586592	et	3	main
mõned	doc_767882159216_item	3586593	et	3	main
hulgast	doc_767882159216_item	3586596	et	4	main
praegu	doc_767882159216_item	3586599	et	3	main
ja	doc_767882159216_item	3586618	et	3	main
aga	doc_767882159216_item	3586633	et	3	main
juhul	doc_767882159216_item	3586639	et	3	main
igal	doc_767882159216_item	3586647	et	3	main
valdajadesena	doc_767882159216_item	3586662	et	4	main
olnud	doc_767882159216_item	3586663	et	4	main
laul	doc_767882159216_item	3586672	et	4	main
selle	doc_767882159216_item	3586705	et	4	main
ühineda	doc_767882159216_item	3586709	et	3	main
võita	doc_767882159216_item	3586711	et	4	main
põhjus	doc_767882159216_item	3586713	et	4	main
keel	doc_767882159216_item	3586719	et	4	main
kui	doc_767882159216_item	3586734	et	3	main
esimese	doc_767882159216_item	3586740	et	3	main
tuleb	doc_767882159216_item	3586745	et	3	main
nendele	doc_767882159216_item	3586761	et	4	main
kutsuda	doc_767882159216_item	3586765	et	3	main
eesti	doc_767882159217_item	3586768	et	4	main
kirjutamine	doc_767882159217_item	3586774	et	4	main
kirjutage	doc_767882159217_item	3586775	et	3	main
loengus	doc_767882159217_item	3586795	et	3	main
mis	doc_767882159217_item	3586805	et	4	main
teeb	doc_767882159217_item	3586806	et	3	main
on	doc_767882159217_item	3586815	et	4	main
nii	doc_767882159217_item	3586821	et	3	main
kui	doc_767882159217_item	3586824	et	3	main
eesti	doc_767882159217_item	3586832	et	4	main
rahva	doc_767882159217_item	3586833	et	3	main
jaoks	doc_767882159217_item	3586834	et	4	main
tähtis	doc_767882159217_item	3586838	et	4	main
nende	doc_767882159217_item	3586840	et	4	main
elust	doc_767882159217_item	3586841	et	3	main
ajalugu	doc_767882159217_item	3586871	et	4	main
estlaste	doc_767882159217_item	3586875	et	4	main
mitte	doc_767882159217_item	3586879	et	3	main
pidudes	doc_767882159217_item	3586884	et	4	main
soendab	doc_767882159217_item	3586886	et	3	main
ja	doc_767882159217_item	3586887	et	3	main
annab	doc_767882159217_item	3586888	et	3	main
kindlust	doc_767882159217_item	3586889	et	4	main
ainult	doc_767882159217_item	3586911	et	4	main
pidudes	doc_767882159217_item	3586912	et	4	main
noortel	doc_767882159217_item	3586913	et	3	main
kuulda	doc_767882159217_item	3586916	et	4	main
laulavad	doc_767882159217_item	3586926	et	4	main
laulsid	doc_767882159217_item	3586934	et	4	main
nii	doc_767882159217_item	3586935	et	3	main
ümberelada	doc_767882159217_item	3586945	et	4	main
mina	doc_767882159217_item	3586946	et	4	main
ise	doc_767882159217_item	3586947	et	4	main
ja	doc_767882159217_item	3586950	et	3	main
tähtis	doc_767882159217_item	3586961	et	4	main
asi	doc_767882159217_item	3586967	et	4	main
raskel	doc_767882159217_item	3586971	et	3	main
kui	doc_767882159217_item	3586973	et	3	main
mul	doc_767882159217_item	3586974	et	3	main
on	doc_767882159217_item	3586975	et	4	main
laulupeos	doc_767882159217_item	3587004	et	4	main
see	doc_767882159217_item	3587005	et	3	main
vanasõna	doc_767882159215_item	3586492	et	4	main
see	doc_767882159215_item	3586493	et	3	main
teise	doc_767882159216_item	3586508	et	4	main
test	doc_767882159216_item	3586510	et	3	main
kirjutage	doc_767882159216_item	3586512	et	3	main
350	doc_767882159216_item	3586522	et	2	main
sõna	doc_767882159216_item	3586523	et	4	main
olema	doc_767882159216_item	3586526	et	4	main
ja	doc_767882159216_item	3586529	et	3	main
tuginema	doc_767882159216_item	3586531	et	3	main
loengus	doc_767882159216_item	3586532	et	3	main
lugemistekstis	doc_767882159216_item	3586534	et	3	main
väiteid	doc_767882159216_item	3586537	et	4	main
iga	doc_767882159216_item	3586544	et	4	main
oma	doc_767882159216_item	3586602	et	4	main
naabrid	doc_767882159216_item	3586604	et	3	main
mehed	doc_767882159216_item	3586606	et	3	main
elas	doc_767882159216_item	3586614	et	3	main
rahvalaul	doc_767882159216_item	3586615	et	4	main
inimeste	doc_767882159216_item	3586616	et	3	main
peades	doc_767882159216_item	3586617	et	3	main
laulud	doc_767882159216_item	3586631	et	3	main
end	doc_767882159216_item	3586635	et	4	main
kutsuvad	doc_767882159216_item	3586637	et	4	main
maa	doc_767882159216_item	3586645	et	4	main
oli	doc_767882159216_item	3586646	et	3	main
teistele	doc_767882159216_item	3586649	et	4	main
olid	doc_767882159216_item	3586651	et	4	main
peaaegu	doc_767882159216_item	3586658	et	3	main
ainult	doc_767882159216_item	3586664	et	4	main
said	doc_767882159216_item	3586667	et	4	main
gustav	doc_767882159216_item	3586679	et	4	main
mu	doc_767882159216_item	3586681	et	3	main
abil	doc_767882159216_item	3586706	et	4	main
ja	doc_767882159216_item	3586710	et	3	main
teine	doc_767882159216_item	3586712	et	3	main
et	doc_767882159216_item	3586714	et	3	main
laulda	doc_767882159216_item	3586715	et	4	main
oli	doc_767882159216_item	3586716	et	3	main
eestlastel	doc_767882159216_item	3586717	et	4	main
konkursil	doc_767882159216_item	3586743	et	3	main
et	doc_767882159216_item	3586746	et	3	main
meeldivaid	doc_767882159216_item	3586748	et	4	main
saavad	doc_767882159216_item	3586750	et	4	main
eestlased	doc_767882159216_item	3586751	et	3	main
see	doc_767882159216_item	3586755	et	3	main
teeb	doc_767882159216_item	3586756	et	3	main
õigust	doc_767882159216_item	3586762	et	4	main
laulurahvusega	doc_767882159216_item	3586764	et	3	main
keele	doc_767882159217_item	3586772	et	4	main
test	doc_767882159217_item	3586773	et	3	main
mis	doc_767882159217_item	3586778	et	4	main
eestlastest	doc_767882159217_item	3586780	et	4	main
peab	doc_767882159217_item	3586788	et	4	main
estlased	doc_767882159217_item	3586814	et	4	main
see	doc_767882159217_item	3586818	et	3	main
teistel	doc_767882159217_item	3586826	et	4	main
üks	doc_767882159217_item	3586837	et	3	main
rahvalaul	doc_767882159217_item	3586868	et	4	main
muidugi	doc_767882159217_item	3586877	et	4	main
ainult	doc_767882159217_item	3586880	et	4	main
ma	doc_767882159217_item	3586895	et	3	main
on	doc_767882159217_item	3586918	et	4	main
regilaul	doc_767882159217_item	3586922	et	4	main
mulle	doc_767882159217_item	3586929	et	4	main
meeldib	doc_767882159217_item	3586930	et	3	main
see	doc_767882159217_item	3586931	et	3	main
et	doc_767882159217_item	3586932	et	3	main
estlased	doc_767882159217_item	3586933	et	4	main
ajal	doc_767882159217_item	3586937	et	4	main
ajal	doc_767882159217_item	3586940	et	4	main
aitas	doc_767882159217_item	3586942	et	3	main
on	doc_767882159217_item	3586959	et	4	main
nii	doc_767882159217_item	3586960	et	3	main
ainukene	doc_767882159217_item	3586966	et	4	main
on	doc_767882159216_item	3586728	et	4	main
paljud	doc_767882159216_item	3586729	et	3	main
veel	doc_767882159216_item	3586730	et	4	main
üks	doc_767882159216_item	3586731	et	3	main
kord	doc_767882159216_item	3586732	et	4	main
veendunud	doc_767882159216_item	3586733	et	4	main
eesti	doc_767882159216_item	3586505	et	4	main
essee	doc_767882159216_item	3586513	et	4	main
teemal	doc_767882159216_item	3586514	et	3	main
mis	doc_767882159216_item	3586515	et	4	main
teeb	doc_767882159216_item	3586516	et	3	main
essee	doc_767882159216_item	3586524	et	4	main
laul	doc_767882159216_item	3586542	et	4	main
oma	doc_767882159216_item	3586559	et	4	main
tunneid	doc_767882159216_item	3586560	et	4	main
näidata	doc_767882159216_item	3586561	et	4	main
või	doc_767882159216_item	3586562	et	4	main
meelelahustuseks	doc_767882159216_item	3586563	et	3	main
eestis	doc_767882159216_item	3586564	et	3	main
muidsel	doc_767882159216_item	3586565	et	4	main
ajal	doc_767882159216_item	3586566	et	4	main
polnud	doc_767882159216_item	3586567	et	3	main
palju	doc_767882159216_item	3586568	et	4	main
linnusi	doc_767882159216_item	3586569	et	4	main
inimesed	doc_767882159216_item	3586570	et	3	main
elasid	doc_767882159216_item	3586571	et	4	main
külades	doc_767882159216_item	3586572	et	3	main
kus	doc_767882159216_item	3586573	et	3	main
ilma	doc_767882159216_item	3586574	et	4	main
laulmiseta	doc_767882159216_item	3586575	et	4	main
oleks	doc_767882159216_item	3586576	et	3	main
igav	doc_767882159216_item	3586578	et	3	main
kõigile	doc_767882159216_item	3586577	et	4	main
keegi	doc_767882159216_item	3586579	et	4	main
ei	doc_767882159216_item	3586580	et	4	main
tea	doc_767882159216_item	3586581	et	4	main
kuidas	doc_767882159216_item	3586582	et	3	main
esimene	doc_767882159216_item	3586583	et	3	main
rahvalaus	doc_767882159216_item	3586584	et	3	main
ilmus	doc_767882159216_item	3586585	et	4	main
ja	doc_767882159216_item	3586586	et	3	main
kes	doc_767882159216_item	3586587	et	4	main
seda	doc_767882159216_item	3586588	et	3	main
kuulame	doc_767882159216_item	3586552	et	4	main
teksti	doc_767882159216_item	3586589	et	4	main
lastele	doc_767882159216_item	3586603	et	4	main
päev	doc_767882159216_item	3586556	et	3	main
lauldakse	doc_767882159216_item	3586557	et	3	main
et	doc_767882159216_item	3586558	et	3	main
rahvalaulud	doc_767882159216_item	3586594	et	3	main
teavad	doc_767882159216_item	3586597	et	3	main
vanemad	doc_767882159216_item	3586600	et	4	main
laulsid	doc_767882159216_item	3586601	et	4	main
naabridele	doc_767882159216_item	3586605	et	4	main
laulsid	doc_767882159216_item	3586607	et	4	main
naised	doc_767882159216_item	3586610	et	3	main
kudumises	doc_767882159216_item	3586611	et	4	main
ja	doc_767882159216_item	3586612	et	3	main
nii	doc_767882159216_item	3586613	et	3	main
oli	doc_767882159216_item	3586621	et	3	main
olid	doc_767882159216_item	3586629	et	4	main
laulurahvaseks	doc_767882159216_item	3586636	et	4	main
ka	doc_767882159216_item	3586642	et	3	main
ajal	doc_767882159216_item	3586648	et	4	main
huvitav	doc_767882159216_item	3586650	et	4	main
eestlast	doc_767882159216_item	3586657	et	4	main
oma	doc_767882159216_item	3586660	et	4	main
eelmisel	doc_767882159216_item	3586665	et	3	main
mis	doc_767882159216_item	3586673	et	4	main
äratas	doc_767882159216_item	3586674	et	3	main
nendel	doc_767882159216_item	3586675	et	4	main
just	doc_767882159216_item	3586704	et	3	main
paar	doc_767882159216_item	3586735	et	3	main
tagasi	doc_767882159216_item	3586737	et	3	main
eesti	doc_767882159216_item	3586739	et	4	main
koha	doc_767882159216_item	3586741	et	4	main
paljud	doc_767882159216_item	3586747	et	3	main
tunneid	doc_767882159216_item	3586749	et	4	main
tänu	doc_767882159216_item	3586752	et	4	main
neid	doc_767882159216_item	3586757	et	4	main
kultuurrahvuseks	doc_767882159216_item	3586758	et	4	main
ja	doc_767882159216_item	3586759	et	3	main
annab	doc_767882159216_item	3586760	et	3	main
teeb	doc_767882159217_item	3586779	et	3	main
essee	doc_767882159217_item	3586787	et	4	main
üldistav	doc_767882159217_item	3586793	et	4	main
tuginema	doc_767882159217_item	3586794	et	3	main
ja	doc_767882159217_item	3586796	et	3	main
lugemistekstis	doc_767882159217_item	3586797	et	3	main
esitatud	doc_767882159217_item	3586798	et	4	main
faktidele	doc_767882159217_item	3586799	et	3	main
väiteid	doc_767882159217_item	3586800	et	4	main
eestlastest	doc_767882159217_item	3586807	et	4	main
laulurahva	doc_767882159217_item	3586808	et	3	main
praegu	doc_767882159217_item	3586809	et	3	main
palju	doc_767882159217_item	3586810	et	4	main
räägitakse	doc_767882159217_item	3586811	et	3	main
laulurahvas	doc_767882159217_item	3586816	et	4	main
kas	doc_767882159217_item	3586817	et	3	main
tõesti	doc_767882159217_item	3586820	et	3	main
on	doc_767882159217_item	3586827	et	4	main
oma	doc_767882159217_item	3586828	et	4	main
kombed	doc_767882159217_item	3586829	et	3	main
ja	doc_767882159217_item	3586830	et	3	main
traditsioonid	doc_767882159217_item	3586831	et	3	main
ajal	doc_767882159217_item	3586846	et	4	main
on	doc_767882159217_item	3586869	et	4	main
see	doc_767882159217_item	3586873	et	3	main
eluviisi	doc_767882159217_item	3586876	et	4	main
lauldi	doc_767882159217_item	3586878	et	3	main
korraldati	doc_767882159217_item	3586890	et	3	main
esimese	doc_767882159217_item	3586891	et	3	main
ülemaaline	doc_767882159217_item	3586892	et	4	main
praegu	doc_767882159217_item	3586897	et	3	main
kultuuri	doc_767882159217_item	3586910	et	4	main
võimalus	doc_767882159217_item	3586915	et	3	main
eesti	doc_767882159217_item	3586920	et	4	main
setu	doc_767882159217_item	3586928	et	4	main
halval	doc_767882159217_item	3586936	et	3	main
neile	doc_767882159217_item	3586943	et	4	main
kõik	doc_767882159217_item	3586944	et	4	main
muusikaga	doc_767882159217_item	3586949	et	3	main
kooris	doc_767882159217_item	3586952	et	4	main
arvan	doc_767882159217_item	3586953	et	3	main
aru	doc_767882159217_item	3586956	et	4	main
estlaste	doc_767882159217_item	3586962	et	4	main
jaoks	doc_767882159217_item	3586963	et	4	main
sellest	doc_767882159216_item	3586595	et	4	main
ka	doc_767882159216_item	3586598	et	3	main
hingedes	doc_767882159216_item	3586619	et	3	main
aastat	doc_767882159216_item	3586623	et	3	main
kui	doc_767882159216_item	3586625	et	3	main
iga	doc_767882159216_item	3586627	et	4	main
rahvasel	doc_767882159216_item	3586628	et	4	main
miks	doc_767882159216_item	3586632	et	4	main
sellel	doc_767882159216_item	3586638	et	4	main
on	doc_767882159216_item	3586640	et	4	main
tegemist	doc_767882159216_item	3586641	et	4	main
ajalooga	doc_767882159216_item	3586643	et	4	main
eesti	doc_767882159216_item	3586644	et	4	main
venelased	doc_767882159216_item	3586656	et	3	main
polnud	doc_767882159216_item	3586659	et	3	main
maa	doc_767882159216_item	3586661	et	4	main
eestlased	doc_767882159216_item	3586668	et	3	main
rahvuslikuid	doc_767882159216_item	3586676	et	4	main
tunneid	doc_767882159216_item	3586677	et	4	main
oli	doc_767882159216_item	3586678	et	3	main
isamaa	doc_767882159216_item	3586682	et	4	main
said	doc_767882159216_item	3586707	et	4	main
kerge	doc_767882159216_item	3586720	et	4	main
ja	doc_767882159216_item	3586721	et	3	main
meloodiline	doc_767882159216_item	3586722	et	3	main
see	doc_767882159216_item	3586723	et	3	main
sobis	doc_767882159216_item	3586724	et	4	main
muusikale	doc_767882159216_item	3586725	et	4	main
hästi	doc_767882159216_item	3586726	et	3	main
aastat	doc_767882159216_item	3586736	et	3	main
võttis	doc_767882159216_item	3586738	et	3	main
niimoodi	doc_767882159216_item	3586744	et	3	main
nende	doc_767882159216_item	3586753	et	4	main
end	doc_767882159216_item	3586763	et	4	main
essee	doc_767882159217_item	3586767	et	4	main
essee	doc_767882159217_item	3586776	et	4	main
essee	doc_767882159217_item	3586782	et	4	main
pikkus	doc_767882159217_item	3586783	et	4	main
350	doc_767882159217_item	3586785	et	2	main
olema	doc_767882159217_item	3586789	et	4	main
arutlev	doc_767882159217_item	3586790	et	4	main
analüüsiv	doc_767882159217_item	3586791	et	4	main
ja	doc_767882159217_item	3586792	et	3	main
soovitatav	doc_767882159217_item	3586802	et	4	main
illustreerida	doc_767882159217_item	3586803	et	3	main
näidetega	doc_767882159217_item	3586804	et	3	main
et	doc_767882159217_item	3586813	et	3	main
nii	doc_767882159217_item	3586822	et	3	main
estlastel	doc_767882159217_item	3586823	et	4	main
ka	doc_767882159217_item	3586825	et	3	main
on	doc_767882159217_item	3586836	et	4	main
põllul	doc_767882159216_item	3586608	et	3	main
töötades	doc_767882159216_item	3586609	et	3	main
see	doc_767882159216_item	3586620	et	3	main
palju	doc_767882159216_item	3586622	et	4	main
tagasi	doc_767882159216_item	3586624	et	3	main
praaktiliselt	doc_767882159216_item	3586626	et	4	main
oma	doc_767882159216_item	3586630	et	4	main
eestlased	doc_767882159216_item	3586634	et	3	main
tulnud	doc_767882159216_item	3586652	et	4	main
rootslased	doc_767882159216_item	3586653	et	3	main
taanlased	doc_767882159216_item	3586654	et	3	main
sakslased	doc_767882159216_item	3586655	et	3	main
sajandil	doc_767882159216_item	3586666	et	3	main
oma	doc_767882159216_item	3586669	et	4	main
maa	doc_767882159216_item	3586670	et	4	main
tagasi	doc_767882159216_item	3586671	et	3	main
ernesaksa	doc_767882159216_item	3586680	et	4	main
on	doc_767882159216_item	3586683	et	4	main
minu	doc_767882159216_item	3586684	et	3	main
arm	doc_767882159216_item	3586685	et	3	main
ja	doc_767882159216_item	3586686	et	3	main
nii	doc_767882159216_item	3586687	et	3	main
see	doc_767882159216_item	3586688	et	3	main
sai	doc_767882159216_item	3586689	et	4	main
rahva	doc_767882159216_item	3586690	et	3	main
sümboliks	doc_767882159216_item	3586691	et	4	main
niimodi	doc_767882159216_item	3586692	et	4	main
võib	doc_767882159216_item	3586693	et	3	main
öelda	doc_767882159216_item	3586694	et	4	main
et	doc_767882159216_item	3586695	et	3	main
eestlastele	doc_767882159216_item	3586696	et	4	main
laul	doc_767882159216_item	3586697	et	4	main
on	doc_767882159216_item	3586698	et	4	main
kui	doc_767882159216_item	3586700	et	3	main
olulisem	doc_767882159216_item	3586699	et	4	main
teistele	doc_767882159216_item	3586701	et	4	main
rahvastele	doc_767882159216_item	3586702	et	4	main
sest	doc_767882159216_item	3586703	et	4	main
nad	doc_767882159216_item	3586708	et	3	main
nende	doc_767882159216_item	3586718	et	4	main
selles	doc_767882159216_item	3586727	et	4	main
eurovisiooni	doc_767882159216_item	3586742	et	4	main
lauludele	doc_767882159216_item	3586754	et	3	main
teeksid	doc_767882159217_item	3587092	et	4	main
ja	doc_767882159217_item	3587093	et	3	main
teevad	doc_767882159217_item	3587094	et	3	main
kõike	doc_767882159217_item	3587095	et	4	main
lauldes	doc_767882159217_item	3587096	et	3	main
keele	doc_767882159217_item	3586769	et	4	main
kui	doc_767882159217_item	3586770	et	3	main
teise	doc_767882159217_item	3586771	et	4	main
teemal	doc_767882159217_item	3586777	et	3	main
laulurahva	doc_767882159217_item	3586781	et	3	main
300	doc_767882159217_item	3586784	et	2	main
sõna	doc_767882159217_item	3586786	et	4	main
on	doc_767882159217_item	3586801	et	4	main
sellest	doc_767882159217_item	3586812	et	4	main
on	doc_767882159217_item	3586819	et	4	main
laul	doc_767882159217_item	3586835	et	4	main
osa	doc_767882159217_item	3586839	et	4	main
nad	doc_767882159217_item	3586842	et	3	main
lauluvad	doc_767882159217_item	3586843	et	4	main
kõikjal	doc_767882159217_item	3586844	et	3	main
vanal	doc_767882159217_item	3586845	et	3	main
lauldi	doc_767882159217_item	3586847	et	3	main
töötades	doc_767882159217_item	3586848	et	3	main
ükski	doc_767882159217_item	3586849	et	4	main
olles	doc_767882159217_item	3586850	et	3	main
last	doc_767882159217_item	3586851	et	4	main
kiigutades	doc_767882159217_item	3586852	et	3	main
laulud	doc_767882159217_item	3586853	et	3	main
väljendusid	doc_767882159217_item	3586854	et	4	main
emotsionaalne	doc_767882159217_item	3586855	et	3	main
ja	doc_767882159217_item	3586856	et	3	main
sotsiaalne	doc_767882159217_item	3586857	et	3	main
seisund	doc_767882159217_item	3586858	et	3	main
mulle	doc_767882159217_item	3586859	et	4	main
et	doc_767882159217_item	3586861	et	3	main
kui	doc_767882159217_item	3586862	et	3	main
inimene	doc_767882159217_item	3586863	et	3	main
tundub	doc_767882159217_item	3586860	et	3	main
laulab	doc_767882159217_item	3586864	et	3	main
siis	doc_767882159217_item	3586865	et	3	main
avab	doc_767882159217_item	3586866	et	3	main
hing	doc_767882159217_item	3586867	et	3	main
estlaste	doc_767882159217_item	3586870	et	4	main
töötades	doc_767882159217_item	3586881	et	3	main
laulupidu	doc_767882159217_item	3586893	et	4	main
nagu	doc_767882159217_item	3586894	et	3	main
eesti	doc_767882159217_item	3586909	et	4	main
on	doc_767882159217_item	3586914	et	4	main
mis	doc_767882159217_item	3586917	et	4	main
ainult	doc_767882159217_item	3586927	et	4	main
heal	doc_767882159217_item	3586939	et	3	main
saan	doc_767882159217_item	3586955	et	4	main
miks	doc_767882159217_item	3586957	et	4	main
laul	doc_767882159217_item	3586958	et	4	main
laul	doc_767882159217_item	3586964	et	4	main
oli	doc_767882159217_item	3586965	et	3	main
mis	doc_767882159217_item	3586968	et	4	main
aitas	doc_767882159217_item	3586969	et	3	main
ajal	doc_767882159217_item	3586972	et	4	main
tuju	doc_767882159217_item	3586977	et	4	main
huvitavad	doc_767882159217_item	3586991	et	4	main
nagu	doc_767882159217_item	3586992	et	3	main
kirjutasin	doc_767882159217_item	3586995	et	3	main
olen	doc_767882159217_item	3587000	et	3	main
sest	doc_767882159217_item	3586872	et	4	main
näidab	doc_767882159217_item	3586874	et	4	main
lauldi	doc_767882159217_item	3586882	et	3	main
ka	doc_767882159217_item	3586883	et	3	main
laul	doc_767882159217_item	3586885	et	4	main
tean	doc_767882159217_item	3586896	et	3	main
maailmas	doc_767882159217_item	3586898	et	3	main
laulupidu	doc_767882159217_item	3586899	et	4	main
korraldatakse	doc_767882159217_item	3586900	et	3	main
ka	doc_767882159217_item	3586901	et	3	main
ainult	doc_767882159217_item	3586902	et	4	main
eestis	doc_767882159217_item	3586903	et	3	main
minu	doc_767882159217_item	3586904	et	3	main
arvates	doc_767882159217_item	3586905	et	4	main
laulupidu	doc_767882159217_item	3586906	et	4	main
aitab	doc_767882159217_item	3586907	et	3	main
säilitada	doc_767882159217_item	3586908	et	3	main
tõeline	doc_767882159217_item	3586919	et	4	main
rahvalaul	doc_767882159217_item	3586921	et	4	main
on	doc_767882159217_item	3586923	et	4	main
kadunud	doc_767882159217_item	3586924	et	4	main
seda	doc_767882159217_item	3586925	et	3	main
kui	doc_767882159217_item	3586938	et	3	main
laul	doc_767882159217_item	3586941	et	4	main
tegelen	doc_767882159217_item	3586948	et	3	main
laulan	doc_767882159217_item	3586951	et	3	main
et	doc_767882159217_item	3586954	et	3	main
paha	doc_767882159217_item	3586976	et	4	main
tekivad	doc_767882159217_item	3586979	et	3	main
ma	doc_767882159217_item	3586993	et	3	main
juba	doc_767882159217_item	3586994	et	3	main
unistamatu	doc_767882159217_item	3587007	et	4	main
lauluväljakul	doc_767882159217_item	3587008	et	3	main
selleks	doc_767882159217_item	3587016	et	4	main
mis	doc_767882159217_item	3587027	et	4	main
ei	doc_767882159217_item	3587053	et	4	main
saanud	doc_767882159217_item	3587054	et	4	main
aru	doc_767882159217_item	3587055	et	4	main
rahvale	doc_767882159217_item	3586970	et	3	main
või	doc_767882159217_item	3586978	et	4	main
raskused	doc_767882159217_item	3586980	et	4	main
siis	doc_767882159217_item	3586981	et	3	main
mina	doc_767882159217_item	3586982	et	4	main
ka	doc_767882159217_item	3586983	et	3	main
laulan	doc_767882159217_item	3586984	et	3	main
eesti	doc_767882159217_item	3586985	et	4	main
rahvalaulud	doc_767882159217_item	3586986	et	3	main
mina	doc_767882159217_item	3586996	et	4	main
kooris	doc_767882159217_item	3586998	et	4	main
juba	doc_767882159217_item	3587001	et	3	main
palju	doc_767882159217_item	3587010	et	4	main
inimesi	doc_767882159217_item	3587011	et	4	main
ja	doc_767882159217_item	3587012	et	3	main
need	doc_767882159217_item	3587014	et	3	main
tulid	doc_767882159217_item	3587015	et	4	main
oli	doc_767882159217_item	3587028	et	3	main
kõikide	doc_767882159217_item	3587030	et	4	main
serbiasse	doc_767882159217_item	3587043	et	4	main
laulsin	doc_767882159217_item	3587046	et	3	main
millest	doc_767882159217_item	3587056	et	3	main
see	doc_767882159217_item	3587057	et	3	main
laul	doc_767882159217_item	3587058	et	4	main
on	doc_767882159217_item	3587059	et	4	main
aga	doc_767882159217_item	3587060	et	3	main
see	doc_767882159217_item	3587061	et	3	main
meeldis	doc_767882159217_item	3587062	et	3	main
neile	doc_767882159217_item	3587063	et	4	main
arvan	doc_767882159217_item	3587064	et	3	main
et	doc_767882159217_item	3587065	et	3	main
rahvalaulu	doc_767882159217_item	3587066	et	4	main
keele	doc_767882159218_item	3587100	et	4	main
kirjutamine	doc_767882159218_item	3587105	et	4	main
pikkus	doc_767882159218_item	3587114	et	4	main
300	doc_767882159218_item	3587115	et	2	main
350	doc_767882159218_item	3587116	et	2	main
arutlev	doc_767882159218_item	3587121	et	4	main
väiteid	doc_767882159218_item	3587131	et	4	main
kui	doc_767882159218_item	3587136	et	3	main
teame	doc_767882159218_item	3587139	et	3	main
eestlased	doc_767882159218_item	3587140	et	3	main
mis	doc_767882159218_item	3587152	et	4	main
oskab	doc_767882159218_item	3587153	et	3	main
seal	doc_767882159218_item	3587180	et	4	main
kuulata	doc_767882159218_item	3587183	et	4	main
rahvamuusikat	doc_767882159218_item	3587184	et	3	main
situatsiooni	doc_767882159218_item	3587192	et	4	main
eestimaal	doc_767882159218_item	3587200	et	4	main
eestlased	doc_767882159218_item	3587216	et	3	main
rahvamuusika	doc_767882159218_item	3587235	et	4	main
ka	doc_767882159218_item	3587238	et	3	main
põlve	doc_767882159218_item	3587247	et	4	main
on	doc_767882159218_item	3587271	et	4	main
asi	doc_767882159218_item	3587277	et	4	main
muusika	doc_767882159218_item	3587282	et	4	main
ja	doc_767882159218_item	3587283	et	3	main
laulud	doc_767882159218_item	3587284	et	3	main
teadsid	doc_767882159218_item	3587299	et	4	main
eesti	doc_767882159218_item	3587301	et	4	main
mängis	doc_767882159218_item	3587309	et	3	main
patriootiline	doc_767882159218_item	3587310	et	3	main
laul	doc_767882159218_item	3587311	et	4	main
isamaa	doc_767882159218_item	3587313	et	4	main
on	doc_767882159218_item	3587314	et	4	main
minu	doc_767882159218_item	3587315	et	3	main
arm	doc_767882159218_item	3587316	et	3	main
arvan	doc_767882159218_item	3587317	et	3	main
et	doc_767882159218_item	3587318	et	3	main
see	doc_767882159218_item	3587319	et	3	main
on	doc_767882159218_item	3587330	et	4	main
on	doc_767882159217_item	3586987	et	4	main
väga	doc_767882159217_item	3586988	et	3	main
ilusad	doc_767882159217_item	3586989	et	3	main
ja	doc_767882159217_item	3586990	et	3	main
laulan	doc_767882159217_item	3586997	et	3	main
ja	doc_767882159217_item	3586999	et	3	main
osa	doc_767882159217_item	3587002	et	4	main
võtnud	doc_767882159217_item	3587003	et	4	main
et	doc_767882159217_item	3587017	et	3	main
üks	doc_767882159217_item	3587025	et	3	main
ja	doc_767882159217_item	3587044	et	3	main
essee	doc_767882159218_item	3587098	et	4	main
eestlastest	doc_767882159218_item	3587111	et	4	main
esitatud	doc_767882159218_item	3587129	et	4	main
illustreerida	doc_767882159218_item	3587134	et	3	main
rahv	doc_767882159218_item	3587151	et	4	main
lihtsalt	doc_767882159218_item	3587188	et	4	main
pole	doc_767882159218_item	3587189	et	3	main
niisugune	doc_767882159218_item	3587191	et	3	main
seas	doc_767882159218_item	3587199	et	4	main
on	doc_767882159218_item	3587201	et	4	main
näiteks	doc_767882159218_item	3587202	et	4	main
bänd	doc_767882159218_item	3587203	et	3	main
on	doc_767882159218_item	3587210	et	4	main
ka	doc_767882159218_item	3587211	et	3	main
see	doc_767882159218_item	3587212	et	3	main
et	doc_767882159218_item	3587213	et	3	main
vanadel	doc_767882159218_item	3587214	et	3	main
praktiliselt	doc_767882159218_item	3587218	et	4	main
lihtsalt	doc_767882159218_item	3587227	et	4	main
jalutamas	doc_767882159218_item	3587228	et	3	main
eestis	doc_767882159218_item	3587236	et	3	main
regilaule	doc_767882159218_item	3587239	et	4	main
ilma	doc_767882159218_item	3587241	et	4	main
pillisaateta	doc_767882159218_item	3587242	et	3	main
ning	doc_767882159218_item	3587243	et	3	main
neid	doc_767882159218_item	3587244	et	4	main
19	doc_767882159218_item	3587254	et	2	main
sajandil	doc_767882159218_item	3587255	et	3	main
oli	doc_767882159218_item	3587256	et	3	main
uus	doc_767882159218_item	3587257	et	3	main
riimiline	doc_767882159218_item	3587258	et	4	main
värsimõõdult	doc_767882159218_item	3587264	et	3	main
ja	doc_767882159218_item	3587265	et	3	main
viisilt	doc_767882159218_item	3587266	et	3	main
regilauludest	doc_767882159218_item	3587267	et	3	main
mitmekesisemad	doc_767882159218_item	3587268	et	4	main
ka	doc_767882159218_item	3587273	et	3	main
muidugi	doc_767882159218_item	3587285	et	4	main
inimesed	doc_767882159218_item	3587298	et	3	main
et	doc_767882159218_item	3587300	et	3	main
on	doc_767882159218_item	3587303	et	4	main
tõstis	doc_767882159218_item	3587320	et	4	main
on	doc_767882159218_item	3587324	et	4	main
et	doc_767882159218_item	3587326	et	3	main
meie	doc_767882159218_item	3587328	et	4	main
ajal	doc_767882159218_item	3587329	et	4	main
ainult	doc_767882159218_item	3587336	et	4	main
teavad	doc_767882159218_item	3587337	et	3	main
kes	doc_767882159218_item	3587347	et	4	main
ei	doc_767882159218_item	3587348	et	4	main
aga	doc_767882159218_item	3587372	et	3	main
ikka	doc_767882159218_item	3587373	et	4	main
natuke	doc_767882159218_item	3587375	et	4	main
ja	doc_767882159218_item	3587377	et	3	main
noored	doc_767882159218_item	3587389	et	3	main
vanad	doc_767882159218_item	3587391	et	3	main
naised	doc_767882159218_item	3587392	et	3	main
keele	doc_767882159219_item	3587434	et	4	main
pikkus	doc_767882159219_item	3587448	et	4	main
350	doc_767882159219_item	3587450	et	2	main
olema	doc_767882159219_item	3587454	et	4	main
tuginema	doc_767882159219_item	3587459	et	3	main
ja	doc_767882159219_item	3587461	et	3	main
esitatud	doc_767882159219_item	3587463	et	4	main
teeb	doc_767882159219_item	3587471	et	3	main
ja	doc_767882159219_item	3587478	et	3	main
minu	doc_767882159219_item	3587481	et	3	main
laul	doc_767882159219_item	3587483	et	4	main
elus	doc_767882159219_item	3587487	et	4	main
nägid	doc_767882159219_item	3587504	et	4	main
toimus	doc_767882159219_item	3587507	et	3	main
oli	doc_767882159217_item	3587006	et	3	main
kõik	doc_767882159217_item	3587013	et	4	main
puhata	doc_767882159217_item	3587022	et	4	main
laul	doc_767882159217_item	3587023	et	4	main
oli	doc_767882159217_item	3587024	et	3	main
käinud	doc_767882159217_item	3587042	et	4	main
eesti	doc_767882159217_item	3587047	et	4	main
rahvalaulu	doc_767882159217_item	3587048	et	4	main
on	doc_767882159217_item	3587067	et	4	main
tugev	doc_767882159217_item	3587068	et	4	main
ja	doc_767882159217_item	3587069	et	3	main
omamoodi	doc_767882159217_item	3587070	et	3	main
kaitseb	doc_767882159217_item	3587071	et	4	main
oma	doc_767882159217_item	3587072	et	4	main
rahva	doc_767882159217_item	3587073	et	3	main
võin	doc_767882159217_item	3587074	et	3	main
öelda	doc_767882159217_item	3587075	et	4	main
et	doc_767882159217_item	3587076	et	3	main
estlased	doc_767882159217_item	3587077	et	4	main
on	doc_767882159217_item	3587078	et	4	main
rahvalaul	doc_767882159217_item	3587079	et	4	main
sest	doc_767882159217_item	3587080	et	4	main
nad	doc_767882159217_item	3587081	et	3	main
elavad	doc_767882159217_item	3587082	et	4	main
lauluga	doc_767882159217_item	3587083	et	4	main
laulupidu	doc_767882159217_item	3587084	et	4	main
balti	doc_767882159217_item	3587085	et	3	main
keet	doc_767882159217_item	3587086	et	3	main
ja	doc_767882159217_item	3587087	et	3	main
ne	doc_767882159217_item	3587088	et	4	main
näitab	doc_767882159217_item	3587089	et	3	main
et	doc_767882159217_item	3587090	et	3	main
estlased	doc_767882159217_item	3587091	et	4	main
kui	doc_767882159218_item	3587101	et	3	main
test	doc_767882159218_item	3587104	et	3	main
sõna	doc_767882159218_item	3587117	et	4	main
analüüsiv	doc_767882159218_item	3587122	et	4	main
ja	doc_767882159218_item	3587123	et	3	main
üldistav	doc_767882159218_item	3587124	et	4	main
tuginema	doc_767882159218_item	3587125	et	3	main
loengus	doc_767882159218_item	3587126	et	3	main
ja	doc_767882159218_item	3587127	et	3	main
lugemistekstis	doc_767882159218_item	3587128	et	3	main
on	doc_767882159218_item	3587132	et	4	main
tõeline	doc_767882159218_item	3587142	et	4	main
oma	doc_767882159218_item	3587154	et	4	main
maadel	doc_767882159218_item	3587187	et	4	main
isegi	doc_767882159218_item	3587197	et	4	main
oli	doc_767882159217_item	3587009	et	3	main
laulda	doc_767882159217_item	3587018	et	4	main
tantsida	doc_767882159217_item	3587019	et	3	main
ja	doc_767882159217_item	3587020	et	3	main
lihtsalt	doc_767882159217_item	3587021	et	4	main
asi	doc_767882159217_item	3587026	et	4	main
tähtis	doc_767882159217_item	3587029	et	4	main
jaoks	doc_767882159217_item	3587031	et	4	main
euroopas	doc_767882159217_item	3587032	et	3	main
inimesed	doc_767882159217_item	3587033	et	3	main
teavad	doc_767882159217_item	3587034	et	3	main
et	doc_767882159217_item	3587035	et	3	main
eestis	doc_767882159217_item	3587036	et	3	main
korraldatakse	doc_767882159217_item	3587037	et	3	main
laulupidu	doc_767882159217_item	3587038	et	4	main
sel	doc_767882159217_item	3587039	et	3	main
aastal	doc_767882159217_item	3587040	et	3	main
olin	doc_767882159217_item	3587041	et	3	main
seal	doc_767882159217_item	3587045	et	4	main
lauliku	doc_767882159217_item	3587049	et	3	main
lapsepõlv	doc_767882159217_item	3587050	et	3	main
muidugi	doc_767882159217_item	3587051	et	4	main
serblased	doc_767882159217_item	3587052	et	3	main
eesti	doc_767882159218_item	3587099	et	4	main
laulurahva	doc_767882159218_item	3587112	et	3	main
essee	doc_767882159218_item	3587113	et	4	main
peab	doc_767882159218_item	3587119	et	4	main
olema	doc_767882159218_item	3587120	et	4	main
faktidele	doc_767882159218_item	3587130	et	3	main
kõik	doc_767882159218_item	3587138	et	4	main
on	doc_767882159218_item	3587141	et	4	main
miks	doc_767882159218_item	3587144	et	4	main
te	doc_767882159218_item	3587146	et	4	main
mind	doc_767882159218_item	3587147	et	4	main
ja	doc_767882159218_item	3587148	et	3	main
ma	doc_767882159218_item	3587149	et	3	main
vastan	doc_767882159218_item	3587150	et	3	main
on	doc_767882159218_item	3587181	et	4	main
võimalik	doc_767882159218_item	3587182	et	3	main
paljudel	doc_767882159218_item	3587185	et	3	main
teistel	doc_767882159218_item	3587186	et	4	main
näha	doc_767882159218_item	3587193	et	3	main
rahvamuusika	doc_767882159218_item	3587194	et	4	main
noorte	doc_767882159218_item	3587198	et	3	main
setu	doc_767882159218_item	3587206	et	4	main
aega	doc_767882159218_item	3587220	et	4	main
naised	doc_767882159218_item	3587221	et	3	main
koos	doc_767882159218_item	3587224	et	4	main
või	doc_767882159218_item	3587229	et	4	main
käsitöö	doc_767882159218_item	3587230	et	4	main
tegemas	doc_767882159218_item	3587231	et	3	main
võime	doc_767882159218_item	3587232	et	4	main
näha	doc_767882159218_item	3587233	et	3	main
et	doc_767882159218_item	3587234	et	3	main
lauldi	doc_767882159218_item	3587240	et	3	main
suuliselt	doc_767882159218_item	3587248	et	4	main
tuginedes	doc_767882159218_item	3587249	et	3	main
mälule	doc_767882159218_item	3587250	et	3	main
ja	doc_767882159218_item	3587251	et	3	main
traditsioonidele	doc_767882159218_item	3587252	et	3	main
aga	doc_767882159218_item	3587253	et	3	main
on	doc_767882159218_item	3587263	et	4	main
esitatud	doc_767882159218_item	3587272	et	4	main
tähtis	doc_767882159218_item	3587276	et	4	main
eestlastele	doc_767882159218_item	3587287	et	4	main
iga	doc_767882159218_item	3587305	et	4	main
vapustav	doc_767882159218_item	3587323	et	4	main
võimalik	doc_767882159218_item	3587331	et	3	main
näha	doc_767882159218_item	3587332	et	3	main
kes	doc_767882159218_item	3587334	et	4	main
laule	doc_767882159218_item	3587388	et	4	main
ja	doc_767882159218_item	3587390	et	3	main
õppetajad	doc_767882159218_item	3587395	et	4	main
nii	doc_767882159218_item	3587407	et	3	main
tihti	doc_767882159218_item	3587408	et	3	main
kui	doc_767882159218_item	3587409	et	3	main
on	doc_767882159218_item	3587410	et	4	main
võimalik	doc_767882159218_item	3587411	et	3	main
ja	doc_767882159218_item	3587412	et	3	main
kõik	doc_767882159218_item	3587413	et	4	main
loodavad	doc_767882159218_item	3587414	et	4	main
et	doc_767882159218_item	3587415	et	3	main
järgmine	doc_767882159218_item	3587416	et	3	main
laulupidu	doc_767882159218_item	3587417	et	4	main
tuleb	doc_767882159218_item	3587418	et	3	main
kiiremini	doc_767882159218_item	3587419	et	4	main
kui	doc_767882159218_item	3587420	et	3	main
eelmine	doc_767882159218_item	3587421	et	3	main
ja	doc_767882159218_item	3587422	et	3	main
veel	doc_767882159218_item	3587423	et	4	main
küsite	doc_767882159218_item	3587424	et	3	main
kas	doc_767882159218_item	3587425	et	3	main
on	doc_767882159218_item	3587426	et	4	main
eestirahv	doc_767882159218_item	3587427	et	4	main
laulurahv	doc_767882159218_item	3587428	et	4	main
muidugi	doc_767882159218_item	3587429	et	4	main
on	doc_767882159218_item	3587430	et	4	main
teise	doc_767882159218_item	3587102	et	4	main
keele	doc_767882159218_item	3587103	et	4	main
kirjutage	doc_767882159218_item	3587106	et	3	main
essee	doc_767882159218_item	3587107	et	4	main
teemal	doc_767882159218_item	3587108	et	3	main
mis	doc_767882159218_item	3587109	et	4	main
teeb	doc_767882159218_item	3587110	et	3	main
essee	doc_767882159218_item	3587118	et	4	main
soovitatav	doc_767882159218_item	3587133	et	4	main
näidetega	doc_767882159218_item	3587135	et	3	main
me	doc_767882159218_item	3587137	et	4	main
laulurahv	doc_767882159218_item	3587143	et	4	main
küsite	doc_767882159218_item	3587145	et	3	main
muusikultuuri	doc_767882159218_item	3587155	et	4	main
austada	doc_767882159218_item	3587156	et	3	main
mis	doc_767882159218_item	3587157	et	4	main
ei	doc_767882159218_item	3587158	et	4	main
luba	doc_767882159218_item	3587159	et	4	main
selle	doc_767882159218_item	3587160	et	4	main
surra	doc_767882159218_item	3587161	et	3	main
vot	doc_767882159218_item	3587162	et	3	main
see	doc_767882159218_item	3587163	et	3	main
on	doc_767882159218_item	3587164	et	4	main
täpselt	doc_767882159218_item	3587165	et	4	main
laulurahv	doc_767882159218_item	3587166	et	4	main
eestimaal	doc_767882159218_item	3587167	et	4	main
toimuvad	doc_767882159218_item	3587168	et	4	main
laulupeod	doc_767882159218_item	3587169	et	4	main
neid	doc_767882159218_item	3587170	et	4	main
külastavad	doc_767882159218_item	3587171	et	4	main
inimesed	doc_767882159218_item	3587172	et	3	main
peredega	doc_767882159218_item	3587173	et	3	main
sõbradega	doc_767882159218_item	3587174	et	4	main
ja	doc_767882159218_item	3587175	et	3	main
se	doc_767882159218_item	3587176	et	4	main
pole	doc_767882159218_item	3587177	et	3	main
mingi	doc_767882159218_item	3587178	et	4	main
rokk-kontsert	doc_767882159218_item	3587179	et	3	main
võimalik	doc_767882159218_item	3587190	et	3	main
on	doc_767882159218_item	3587195	et	4	main
populaarne	doc_767882159218_item	3587196	et	3	main
laulab	doc_767882159218_item	3587205	et	3	main
keeles	doc_767882159218_item	3587207	et	4	main
huvitav	doc_767882159218_item	3587208	et	4	main
fakt	doc_767882159218_item	3587209	et	3	main
kogu	doc_767882159218_item	3587219	et	4	main
kui	doc_767882159218_item	3587222	et	3	main
progresseeris	doc_767882159218_item	3587237	et	4	main
põlvest	doc_767882159218_item	3587246	et	4	main
tekkinud	doc_767882159218_item	3587260	et	4	main
riimilised	doc_767882159218_item	3587261	et	4	main
rahvalaulud	doc_767882159218_item	3587262	et	3	main
on	doc_767882159218_item	3587278	et	4	main
ka	doc_767882159218_item	3587279	et	3	main
see	doc_767882159218_item	3587280	et	3	main
et	doc_767882159218_item	3587281	et	3	main
oma	doc_767882159218_item	3587288	et	4	main
laulupidu	doc_767882159218_item	3587306	et	4	main
viimasel	doc_767882159218_item	3587307	et	3	main
osal	doc_767882159218_item	3587308	et	3	main
mu	doc_767882159218_item	3587312	et	3	main
rahvavaimu	doc_767882159218_item	3587321	et	4	main
ja	doc_767882159218_item	3587345	et	3	main
inimesed	doc_767882159218_item	3587371	et	3	main
leiavad	doc_767882159218_item	3587374	et	3	main
aega	doc_767882159218_item	3587376	et	4	main
pühistavad	doc_767882159218_item	3587378	et	4	main
seda	doc_767882159218_item	3587379	et	3	main
ja	doc_767882159218_item	3587387	et	3	main
ja	doc_767882159218_item	3587393	et	3	main
studentid	doc_767882159218_item	3587397	et	4	main
essee	doc_767882159219_item	3587432	et	4	main
keele	doc_767882159219_item	3587437	et	4	main
teemal	doc_767882159219_item	3587442	et	3	main
essee	doc_767882159219_item	3587452	et	4	main
arutlev	doc_767882159219_item	3587455	et	4	main
analüüsiv	doc_767882159219_item	3587456	et	4	main
üldistav	doc_767882159219_item	3587458	et	4	main
lugemistekstis	doc_767882159219_item	3587462	et	3	main
faktidele	doc_767882159219_item	3587464	et	3	main
väiteid	doc_767882159219_item	3587465	et	4	main
on	doc_767882159219_item	3587466	et	4	main
väga	doc_767882159219_item	3587476	et	3	main
eestlaste	doc_767882159219_item	3587486	et	4	main
oma	doc_767882159219_item	3587489	et	4	main
kultuuri	doc_767882159219_item	3587490	et	4	main
säilitada	doc_767882159219_item	3587491	et	3	main
ja	doc_767882159219_item	3587492	et	3	main
pärinema	doc_767882159219_item	3587493	et	3	main
igapäevased	doc_767882159219_item	3587501	et	4	main
midagi	doc_767882159219_item	3587505	et	4	main
suhelda	doc_767882159219_item	3587515	et	4	main
teine	doc_767882159219_item	3587516	et	3	main
laul	doc_767882159219_item	3587540	et	4	main
aitas	doc_767882159219_item	3587541	et	3	main
eestlastele	doc_767882159219_item	3587542	et	4	main
mitte	doc_767882159219_item	3587543	et	3	main
kultuuri	doc_767882159219_item	3587553	et	4	main
mõjusid	doc_767882159219_item	3587557	et	4	main
eluviisi	doc_767882159219_item	3587566	et	4	main
kombete	doc_767882159219_item	3587569	et	3	main
laulupidu	doc_767882159219_item	3587592	et	4	main
selline	doc_767882159219_item	3587606	et	4	main
saamiseks	doc_767882159219_item	3587621	et	4	main
lahingu	doc_767882159219_item	3587622	et	3	main
tänapäeval	doc_767882159219_item	3587623	et	3	main
laul	doc_767882159219_item	3587624	et	4	main
toimuvad	doc_767882159219_item	3587628	et	4	main
igasuguseid	doc_767882159219_item	3587629	et	3	main
uritused	doc_767882159219_item	3587630	et	4	main
festivalid	doc_767882159219_item	3587631	et	3	main
lapsed	doc_767882159219_item	3587634	et	3	main
kes	doc_767882159219_item	3587644	et	4	main
nad	doc_767882159219_item	3587645	et	3	main
unistus	doc_767882159219_item	3587652	et	4	main
ja	doc_767882159219_item	3587655	et	3	main
meid	doc_767882159219_item	3587663	et	4	main
kõik	doc_767882159219_item	3587664	et	4	main
on	doc_767882159219_item	3587669	et	4	main
mis	doc_767882159218_item	3587204	et	4	main
ajadel	doc_767882159218_item	3587215	et	4	main
laulasid	doc_767882159218_item	3587217	et	4	main
kogusid	doc_767882159218_item	3587223	et	4	main
oma	doc_767882159218_item	3587225	et	4	main
lastele	doc_767882159218_item	3587226	et	4	main
pärandati	doc_767882159218_item	3587245	et	4	main
rahvalaul	doc_767882159218_item	3587259	et	4	main
ja	doc_767882159218_item	3587269	et	3	main
neid	doc_767882159218_item	3587270	et	4	main
pillisaatega	doc_767882159218_item	3587274	et	3	main
väga	doc_767882159218_item	3587275	et	3	main
aitasid	doc_767882159218_item	3587286	et	4	main
iseseisvuse	doc_767882159218_item	3587289	et	4	main
vastu	doc_767882159218_item	3587290	et	3	main
liikuda	doc_767882159218_item	3587291	et	3	main
1980	doc_767882159218_item	3587292	et	2	main
ndal	doc_767882159218_item	3587293	et	4	main
aastal	doc_767882159218_item	3587294	et	3	main
hakkas	doc_767882159218_item	3587295	et	3	main
ärkamisaeg	doc_767882159218_item	3587296	et	3	main
ja	doc_767882159218_item	3587297	et	3	main
kultuur	doc_767882159218_item	3587302	et	3	main
elus	doc_767882159218_item	3587304	et	4	main
kõrgem	doc_767882159218_item	3587322	et	4	main
see	doc_767882159218_item	3587325	et	3	main
isegi	doc_767882159218_item	3587327	et	4	main
inimesi	doc_767882159218_item	3587333	et	4	main
mitte	doc_767882159218_item	3587335	et	3	main
oma	doc_767882159218_item	3587338	et	4	main
muusikat	doc_767882159218_item	3587339	et	3	main
vaid	doc_767882159218_item	3587340	et	3	main
ka	doc_767882159218_item	3587341	et	3	main
ole	doc_767882159218_item	3587349	et	4	main
unustanud	doc_767882159218_item	3587350	et	4	main
oma	doc_767882159218_item	3587351	et	4	main
traditsiooni	doc_767882159218_item	3587352	et	4	main
ma	doc_767882159218_item	3587353	et	3	main
räägin	doc_767882159218_item	3587354	et	3	main
setu	doc_767882159218_item	3587355	et	4	main
rahvast	doc_767882159218_item	3587356	et	4	main
tõesti	doc_767882159218_item	3587357	et	3	main
tore	doc_767882159218_item	3587358	et	3	main
on	doc_767882159218_item	3587359	et	4	main
see	doc_767882159218_item	3587360	et	3	main
et	doc_767882159218_item	3587361	et	3	main
nad	doc_767882159218_item	3587362	et	3	main
elavad	doc_767882159218_item	3587363	et	4	main
euroopas	doc_767882159218_item	3587364	et	3	main
käivad	doc_767882159218_item	3587365	et	4	main
koolis	doc_767882159218_item	3587366	et	4	main
töötavad	doc_767882159218_item	3587367	et	4	main
nagu	doc_767882159218_item	3587368	et	3	main
kõik	doc_767882159218_item	3587369	et	4	main
normaalsed	doc_767882159218_item	3587370	et	3	main
oskavad	doc_767882159218_item	3587342	et	4	main
hästi	doc_767882159218_item	3587343	et	3	main
laulda	doc_767882159218_item	3587344	et	4	main
tantsida	doc_767882159218_item	3587346	et	3	main
teise	doc_767882159219_item	3587436	et	4	main
test	doc_767882159219_item	3587438	et	3	main
kirjutage	doc_767882159219_item	3587440	et	3	main
mis	doc_767882159219_item	3587443	et	4	main
teeb	doc_767882159219_item	3587444	et	3	main
eestlastest	doc_767882159219_item	3587445	et	4	main
laulurahva	doc_767882159219_item	3587446	et	3	main
sõna	doc_767882159219_item	3587451	et	4	main
ja	doc_767882159219_item	3587457	et	3	main
loengus	doc_767882159219_item	3587460	et	3	main
keruline	doc_767882159219_item	3587477	et	4	main
küsimus	doc_767882159219_item	3587480	et	4	main
arust	doc_767882159219_item	3587482	et	4	main
oli	doc_767882159219_item	3587484	et	3	main
vanad	doc_767882159219_item	3587495	et	3	main
eestlased	doc_767882159219_item	3587496	et	3	main
laulsid	doc_767882159219_item	3587497	et	4	main
tööd	doc_767882159219_item	3587502	et	4	main
nad	doc_767882159219_item	3587503	et	3	main
mis	doc_767882159219_item	3587506	et	4	main
looduses	doc_767882159219_item	3587508	et	4	main
ja	doc_767882159219_item	3587509	et	3	main
laulsid	doc_767882159219_item	3587510	et	4	main
sellest	doc_767882159219_item	3587511	et	4	main
nii	doc_767882159219_item	3587512	et	3	main
nad	doc_767882159219_item	3587513	et	3	main
ümbritseva	doc_767882159219_item	3587521	et	4	main
pärinesid	doc_767882159219_item	3587537	et	4	main
esimesed	doc_767882159219_item	3587538	et	3	main
laulud	doc_767882159219_item	3587539	et	3	main
olid	doc_767882159219_item	3587549	et	4	main
rahvus	doc_767882159219_item	3587607	et	3	main
on	doc_767882159219_item	3587611	et	4	main
tähtis	doc_767882159219_item	3587626	et	4	main
lauluvõistlused	doc_767882159219_item	3587633	et	3	main
tahtejõud	doc_767882159219_item	3587651	et	4	main
et	doc_767882159219_item	3587671	et	3	main
eestlastest	doc_767882159223_item	3587688	et	4	main
pikkus	doc_767882159223_item	3587691	et	4	main
350	doc_767882159223_item	3587693	et	2	main
sõna	doc_767882159223_item	3587694	et	4	main
arutlev	doc_767882159223_item	3587698	et	4	main
analüüsiv	doc_767882159223_item	3587699	et	4	main
ja	doc_767882159223_item	3587700	et	3	main
miks	doc_767882159223_item	3587742	et	4	main
miks	doc_767882159223_item	3587750	et	4	main
selleta	doc_767882159223_item	3587752	et	3	main
küllaltki	doc_767882159223_item	3587755	et	4	main
raske	doc_767882159223_item	3587756	et	4	main
elada	doc_767882159223_item	3587757	et	3	main
räägites	doc_767882159223_item	3587758	et	4	main
eestimaast	doc_767882159223_item	3587759	et	3	main
kõik	doc_767882159223_item	3587768	et	4	main
tähtsad	doc_767882159223_item	3587769	et	3	main
sündmused	doc_767882159223_item	3587770	et	3	main
nii	doc_767882159223_item	3587771	et	3	main
pärast	doc_767882159223_item	3587786	et	4	main
see	doc_767882159223_item	3587799	et	3	main
tuleviku	doc_767882159223_item	3587815	et	4	main
keskonna	doc_767882159223_item	3587839	et	4	main
väga	doc_767882159223_item	3587840	et	3	main
tähtsa	doc_767882159223_item	3587841	et	3	main
ajalugu	doc_767882159223_item	3587853	et	4	main
ja	doc_767882159223_item	3587854	et	3	main
saame	doc_767882159223_item	3587857	et	4	main
elas	doc_767882159223_item	3587860	et	3	main
palju	doc_767882159223_item	3587862	et	4	main
sajandeid	doc_767882159223_item	3587863	et	3	main
tema	doc_767882159223_item	3587871	et	4	main
elu	doc_767882159223_item	3587872	et	4	main
selline	doc_767882159223_item	3587876	et	4	main
mis	doc_767882159223_item	3587878	et	4	main
avaneb	doc_767882159223_item	3587879	et	3	main
elus	doc_767882159223_item	3587895	et	4	main
nüüd	doc_767882159223_item	3587901	et	4	main
ma	doc_767882159223_item	3587903	et	3	main
näiteks	doc_767882159223_item	3587910	et	4	main
kui	doc_767882159225_item	3587957	et	3	main
oma	doc_767882159218_item	3587380	et	4	main
kultuuri	doc_767882159218_item	3587381	et	4	main
ühesõnaga	doc_767882159218_item	3587382	et	3	main
eestimaal	doc_767882159218_item	3587383	et	4	main
armastavad	doc_767882159218_item	3587384	et	4	main
inimesed	doc_767882159218_item	3587385	et	3	main
muusikat	doc_767882159218_item	3587386	et	3	main
mehed	doc_767882159218_item	3587394	et	3	main
ja	doc_767882159218_item	3587396	et	3	main
kõik	doc_767882159218_item	3587398	et	4	main
teavad	doc_767882159218_item	3587399	et	3	main
mis	doc_767882159218_item	3587400	et	4	main
nende	doc_767882159218_item	3587401	et	4	main
kultuur	doc_767882159218_item	3587402	et	3	main
on	doc_767882159218_item	3587403	et	4	main
väärt	doc_767882159218_item	3587404	et	4	main
kõik	doc_767882159218_item	3587405	et	4	main
laulavad	doc_767882159218_item	3587406	et	4	main
kui	doc_767882159219_item	3587435	et	3	main
kirjutamine	doc_767882159219_item	3587439	et	4	main
essee	doc_767882159219_item	3587441	et	4	main
300	doc_767882159219_item	3587449	et	2	main
mitmekülgne	doc_767882159219_item	3587479	et	3	main
näiteks	doc_767882159219_item	3587494	et	4	main
saaksid	doc_767882159219_item	3587514	et	4	main
kohta	doc_767882159223_item	3587931	et	4	main
siis	doc_767882159223_item	3587932	et	3	main
kõik	doc_767882159223_item	3587933	et	4	main
euroopa	doc_767882159223_item	3587934	et	4	main
riigid	doc_767882159223_item	3587935	et	3	main
said	doc_767882159223_item	3587936	et	4	main
teada	doc_767882159223_item	3587937	et	3	main
et	doc_767882159223_item	3587938	et	3	main
eesti	doc_767882159223_item	3587939	et	4	main
rahvas	doc_767882159223_item	3587940	et	4	main
on	doc_767882159223_item	3587941	et	4	main
tugev	doc_767882159223_item	3587942	et	4	main
ja	doc_767882159223_item	3587943	et	3	main
võib	doc_767882159223_item	3587944	et	3	main
palju	doc_767882159223_item	3587945	et	4	main
teha	doc_767882159223_item	3587946	et	3	main
ekonoomiliselt	doc_767882159223_item	3587947	et	4	main
see	doc_767882159223_item	3587948	et	3	main
oli	doc_767882159223_item	3587949	et	3	main
ka	doc_767882159223_item	3587950	et	3	main
väga	doc_767882159223_item	3587951	et	3	main
kasulik	doc_767882159223_item	3587952	et	3	main
eesti	doc_767882159219_item	3587433	et	4	main
essee	doc_767882159219_item	3587447	et	4	main
peab	doc_767882159219_item	3587453	et	4	main
soovitatav	doc_767882159219_item	3587467	et	4	main
illustreerida	doc_767882159219_item	3587468	et	3	main
näidetega	doc_767882159219_item	3587469	et	3	main
mis	doc_767882159219_item	3587470	et	4	main
eestlastest	doc_767882159219_item	3587472	et	4	main
laulurahva	doc_767882159219_item	3587473	et	3	main
see	doc_767882159219_item	3587474	et	3	main
on	doc_767882159219_item	3587475	et	4	main
tähtis	doc_767882159219_item	3587485	et	4	main
et	doc_767882159219_item	3587488	et	3	main
regilaule	doc_767882159219_item	3587498	et	4	main
kui	doc_767882159219_item	3587499	et	3	main
tegid	doc_767882159219_item	3587500	et	4	main
maaimaga	doc_767882159219_item	3587522	et	3	main
ema	doc_767882159219_item	3587523	et	4	main
laulis	doc_767882159219_item	3587524	et	4	main
oma	doc_767882159219_item	3587525	et	4	main
lastele	doc_767882159219_item	3587526	et	4	main
kiigutades	doc_767882159219_item	3587527	et	3	main
teda	doc_767882159219_item	3587528	et	4	main
laps	doc_767882159219_item	3587529	et	4	main
kuulis	doc_767882159219_item	3587530	et	4	main
laulu	doc_767882159219_item	3587531	et	4	main
ja	doc_767882159219_item	3587532	et	3	main
rebenud	doc_767882159219_item	3587535	et	4	main
unustada	doc_767882159219_item	3587544	et	3	main
nende	doc_767882159219_item	3587550	et	4	main
aastaid	doc_767882159219_item	3587555	et	4	main
mõjutasid	doc_767882159219_item	3587565	et	4	main
kulturi	doc_767882159219_item	3587567	et	4	main
ja	doc_767882159219_item	3587568	et	3	main
peale	doc_767882159219_item	3587570	et	4	main
saada	doc_767882159219_item	3587575	et	4	main
sihtmärki	doc_767882159219_item	3587600	et	4	main
maailm	doc_767882159219_item	3587601	et	3	main
peab	doc_767882159219_item	3587602	et	4	main
teadma	doc_767882159219_item	3587603	et	3	main
et	doc_767882159219_item	3587604	et	3	main
on	doc_767882159219_item	3587605	et	4	main
on	doc_767882159219_item	3587625	et	4	main
koolides	doc_767882159219_item	3587627	et	3	main
kontserdid	doc_767882159219_item	3587632	et	3	main
tõeliselt	doc_767882159219_item	3587646	et	4	main
on	doc_767882159219_item	3587647	et	4	main
ja	doc_767882159219_item	3587653	et	3	main
teeb	doc_767882159219_item	3587658	et	3	main
eestlastest	doc_767882159219_item	3587659	et	4	main
laulurahva	doc_767882159219_item	3587660	et	3	main
ja	doc_767882159219_item	3587666	et	3	main
koos	doc_767882159219_item	3587667	et	4	main
jõud	doc_767882159219_item	3587670	et	4	main
essee	doc_767882159223_item	3587695	et	4	main
üldistav	doc_767882159223_item	3587701	et	4	main
tuginema	doc_767882159223_item	3587702	et	3	main
loengus	doc_767882159223_item	3587703	et	3	main
ja	doc_767882159223_item	3587704	et	3	main
lugemistekstis	doc_767882159223_item	3587705	et	3	main
unelaulu	doc_767882159223_item	3587733	et	4	main
ongi	doc_767882159223_item	3587743	et	4	main
see	doc_767882159223_item	3587744	et	3	main
jaoks	doc_767882159223_item	3587749	et	4	main
lauluga	doc_767882159223_item	3587764	et	4	main
on	doc_767882159223_item	3587765	et	4	main
rahvas	doc_767882159223_item	3587788	et	4	main
tunne	doc_767882159223_item	3587800	et	4	main
ongi	doc_767882159223_item	3587801	et	4	main
ju	doc_767882159223_item	3587802	et	3	main
tähtsam	doc_767882159223_item	3587805	et	4	main
raskedel	doc_767882159223_item	3587809	et	4	main
teisega	doc_767882159219_item	3587517	et	4	main
loomadega	doc_767882159219_item	3587518	et	3	main
loodusega	doc_767882159219_item	3587519	et	4	main
üldse	doc_767882159219_item	3587520	et	3	main
side	doc_767882159219_item	3587533	et	4	main
kes	doc_767882159219_item	3587548	et	4	main
esivanemad	doc_767882159219_item	3587551	et	4	main
palju	doc_767882159219_item	3587554	et	4	main
eestlasi	doc_767882159219_item	3587556	et	3	main
erinevaid	doc_767882159219_item	3587558	et	4	main
rahvusi	doc_767882159219_item	3587559	et	3	main
sakslased	doc_767882159219_item	3587560	et	3	main
taanlased	doc_767882159219_item	3587561	et	3	main
rootslased	doc_767882159219_item	3587562	et	3	main
venelased	doc_767882159219_item	3587563	et	3	main
nad	doc_767882159219_item	3587564	et	3	main
eestlasi	doc_767882159219_item	3587595	et	3	main
koos	doc_767882159219_item	3587596	et	4	main
et	doc_767882159219_item	3587597	et	3	main
saavutada	doc_767882159219_item	3587598	et	3	main
ühe	doc_767882159219_item	3587599	et	4	main
eestlased	doc_767882159219_item	3587609	et	3	main
hakkasid	doc_767882159219_item	3587619	et	4	main
iseseisvuse	doc_767882159219_item	3587620	et	4	main
laulavad	doc_767882159219_item	3587635	et	4	main
rahvusriietes	doc_767882159219_item	3587637	et	3	main
miks	doc_767882159219_item	3587638	et	4	main
nad	doc_767882159219_item	3587639	et	3	main
seda	doc_767882159219_item	3587640	et	3	main
teevad	doc_767882159219_item	3587641	et	3	main
et	doc_767882159219_item	3587642	et	3	main
mäletada	doc_767882159219_item	3587643	et	3	main
et	doc_767882159219_item	3587650	et	3	main
koosolemine	doc_767882159219_item	3587654	et	4	main
muidugi	doc_767882159219_item	3587656	et	4	main
laul	doc_767882159219_item	3587657	et	4	main
koos	doc_767882159219_item	3587665	et	4	main
teise	doc_767882159223_item	3587679	et	4	main
keele	doc_767882159223_item	3587680	et	4	main
test	doc_767882159223_item	3587681	et	3	main
laulurahva	doc_767882159223_item	3587689	et	3	main
olema	doc_767882159223_item	3587697	et	4	main
ei	doc_767882159219_item	3587534	et	4	main
suuliselt	doc_767882159219_item	3587536	et	4	main
kes	doc_767882159219_item	3587545	et	4	main
nad	doc_767882159219_item	3587546	et	3	main
on	doc_767882159219_item	3587547	et	4	main
oma	doc_767882159219_item	3587552	et	4	main
eestlased	doc_767882159219_item	3587571	et	3	main
tahtsid	doc_767882159219_item	3587572	et	4	main
vabaneda	doc_767882159219_item	3587573	et	3	main
iseseisvaks	doc_767882159219_item	3587574	et	3	main
ja	doc_767882159219_item	3587576	et	3	main
laul	doc_767882159219_item	3587577	et	4	main
aitas	doc_767882159219_item	3587578	et	3	main
neid	doc_767882159219_item	3587579	et	4	main
näiteks	doc_767882159219_item	3587580	et	4	main
esimene	doc_767882159219_item	3587581	et	3	main
rahvusärkamine	doc_767882159219_item	3587582	et	3	main
kõrghetk	doc_767882159219_item	3587583	et	3	main
kujunes	doc_767882159219_item	3587584	et	3	main
pärast	doc_767882159219_item	3587585	et	4	main
esimese	doc_767882159219_item	3587586	et	3	main
laulupidu	doc_767882159219_item	3587587	et	4	main
mis	doc_767882159219_item	3587588	et	4	main
toimus	doc_767882159219_item	3587589	et	3	main
1869	doc_767882159219_item	3587590	et	2	main
aastal	doc_767882159219_item	3587591	et	3	main
ühendas	doc_767882159219_item	3587593	et	3	main
palju	doc_767882159219_item	3587594	et	4	main
nagu	doc_767882159219_item	3587608	et	3	main
kellel	doc_767882159219_item	3587610	et	4	main
oma	doc_767882159219_item	3587612	et	4	main
rikkas	doc_767882159219_item	3587613	et	4	main
rahvakultuur	doc_767882159219_item	3587614	et	3	main
traditsioonid	doc_767882159219_item	3587615	et	3	main
ja	doc_767882159219_item	3587616	et	3	main
kombet	doc_767882159219_item	3587617	et	3	main
nad	doc_767882159219_item	3587618	et	3	main
vanalaule	doc_767882159219_item	3587636	et	4	main
mina	doc_767882159219_item	3587648	et	4	main
arvan	doc_767882159219_item	3587649	et	3	main
laul	doc_767882159219_item	3587661	et	4	main
viib	doc_767882159219_item	3587662	et	3	main
meil	doc_767882159219_item	3587668	et	4	main
sihtmärki	doc_767882159219_item	3587672	et	4	main
essee	doc_767882159223_item	3587675	et	4	main
eesti	doc_767882159223_item	3587676	et	4	main
keele	doc_767882159223_item	3587677	et	4	main
kui	doc_767882159223_item	3587678	et	3	main
peab	doc_767882159223_item	3587696	et	4	main
esitatud	doc_767882159223_item	3587706	et	4	main
faktidele	doc_767882159223_item	3587707	et	3	main
väiteid	doc_767882159223_item	3587708	et	4	main
on	doc_767882159223_item	3587709	et	4	main
soovitatav	doc_767882159223_item	3587710	et	4	main
illustreerida	doc_767882159223_item	3587711	et	3	main
näidetega	doc_767882159223_item	3587712	et	3	main
sünniajast	doc_767882159223_item	3587713	et	4	main
surmani	doc_767882159223_item	3587714	et	3	main
elab	doc_767882159223_item	3587715	et	3	main
inimene	doc_767882159223_item	3587716	et	3	main
lauluga	doc_767882159223_item	3587717	et	4	main
koos	doc_767882159223_item	3587718	et	4	main
kui	doc_767882159223_item	3587719	et	3	main
inimene	doc_767882159223_item	3587720	et	3	main
on	doc_767882159223_item	3587721	et	4	main
veel	doc_767882159223_item	3587722	et	4	main
väike	doc_767882159223_item	3587723	et	4	main
laps	doc_767882159223_item	3587724	et	4	main
kes	doc_767882159223_item	3587725	et	4	main
just	doc_767882159223_item	3587726	et	3	main
alustab	doc_767882159223_item	3587727	et	3	main
oma	doc_767882159223_item	3587728	et	4	main
elu	doc_767882159223_item	3587729	et	4	main
laulab	doc_767882159223_item	3587730	et	3	main
talle	doc_767882159223_item	3587731	et	4	main
ema	doc_767882159223_item	3587732	et	4	main
sureb	doc_767882159223_item	3587736	et	3	main
tema	doc_767882159223_item	3587738	et	4	main
mälestuseks	doc_767882159223_item	3587739	et	4	main
matuselaule	doc_767882159223_item	3587740	et	4	main
aga	doc_767882159223_item	3587741	et	3	main
inimeste	doc_767882159223_item	3587748	et	3	main
oleks	doc_767882159223_item	3587753	et	3	main
seotud	doc_767882159223_item	3587766	et	4	main
peaaegu	doc_767882159223_item	3587767	et	3	main
mille	doc_767882159223_item	3587785	et	3	main
jaoks	doc_767882159223_item	3587798	et	4	main
kõige	doc_767882159223_item	3587804	et	4	main
areneda	doc_767882159223_item	3587808	et	3	main
positiivsemaks	doc_767882159223_item	3587816	et	4	main
uskuda	doc_767882159223_item	3587818	et	3	main
korda	doc_767882159223_item	3587823	et	4	main
saavutada	doc_767882159219_item	3587673	et	3	main
kirjutamine	doc_767882159223_item	3587682	et	4	main
kirjutage	doc_767882159223_item	3587683	et	3	main
essee	doc_767882159223_item	3587684	et	4	main
teemal	doc_767882159223_item	3587685	et	3	main
mis	doc_767882159223_item	3587686	et	4	main
teeb	doc_767882159223_item	3587687	et	3	main
essee	doc_767882159223_item	3587690	et	4	main
300	doc_767882159223_item	3587692	et	2	main
nii	doc_767882159223_item	3587746	et	3	main
tähtis	doc_767882159223_item	3587747	et	4	main
meil	doc_767882159223_item	3587754	et	4	main
üldlaulupidu	doc_767882159223_item	3587784	et	4	main
eesti	doc_767882159223_item	3587787	et	4	main
tunnes	doc_767882159223_item	3587789	et	3	main
end	doc_767882159223_item	3587790	et	4	main
ühine	doc_767882159223_item	3587791	et	4	main
ja	doc_767882159223_item	3587792	et	3	main
iseseisvana	doc_767882159223_item	3587793	et	3	main
noore	doc_767882159223_item	3587794	et	3	main
ja	doc_767882159223_item	3587795	et	3	main
peaaegu	doc_767882159223_item	3587803	et	3	main
et	doc_767882159223_item	3587806	et	3	main
edasi	doc_767882159223_item	3587807	et	3	main
ja	doc_767882159223_item	3587817	et	3	main
kõik	doc_767882159223_item	3587820	et	4	main
ikkagi	doc_767882159223_item	3587821	et	4	main
koos	doc_767882159223_item	3587827	et	4	main
tunne	doc_767882159223_item	3587834	et	4	main
et	doc_767882159223_item	3587835	et	3	main
moodustavad	doc_767882159223_item	3587837	et	4	main
tugeva	doc_767882159223_item	3587838	et	4	main
eesti	doc_767882159223_item	3587844	et	4	main
rahvalaulud	doc_767882159223_item	3587847	et	3	main
ta	doc_767882159223_item	3587867	et	4	main
elas	doc_767882159223_item	3587868	et	3	main
väärtused	doc_767882159223_item	3587873	et	3	main
informatsioon	doc_767882159223_item	3587877	et	3	main
lauludest	doc_767882159223_item	3587880	et	3	main
mujal	doc_767882159223_item	3587892	et	3	main
olulist	doc_767882159223_item	3587899	et	4	main
eesti	doc_767882159225_item	3587955	et	4	main
keele	doc_767882159225_item	3587959	et	4	main
essee	doc_767882159225_item	3587969	et	4	main
pikkus	doc_767882159225_item	3587970	et	4	main
350	doc_767882159225_item	3587972	et	2	main
on	doc_767882159225_item	3587988	et	4	main
kultuurinähtus	doc_767882159225_item	3587995	et	4	main
ja	doc_767882159225_item	3587999	et	3	main
väljendusvahend	doc_767882159225_item	3588001	et	3	main
ise	doc_767882159225_item	3588044	et	4	main
last	doc_767882159225_item	3588049	et	4	main
kiigutades	doc_767882159225_item	3588050	et	3	main
minevikust	doc_767882159225_item	3588054	et	3	main
kohalikust	doc_767882159225_item	3588085	et	4	main
on	doc_767882159225_item	3588087	et	4	main
lauldud	doc_767882159225_item	3588088	et	4	main
ja	doc_767882159225_item	3588093	et	3	main
see	doc_767882159225_item	3588095	et	3	main
külakoolid	doc_767882159225_item	3588125	et	3	main
levikuga	doc_767882159225_item	3588136	et	3	main
ka	doc_767882159225_item	3588138	et	3	main
hiljem	doc_767882159225_item	3588145	et	3	main
laulupidu	doc_767882159225_item	3588190	et	4	main
tartus	doc_767882159225_item	3588191	et	3	main
mille	doc_767882159225_item	3588192	et	3	main
johann	doc_767882159225_item	3588201	et	4	main
sellest	doc_767882159225_item	3588206	et	4	main
kui	doc_767882159223_item	3587734	et	3	main
inimene	doc_767882159223_item	3587735	et	3	main
lauldakse	doc_767882159223_item	3587737	et	3	main
laul	doc_767882159223_item	3587745	et	4	main
ilma	doc_767882159223_item	3587751	et	4	main
siin	doc_767882159223_item	3587760	et	4	main
muusikaga	doc_767882159223_item	3587761	et	3	main
ja	doc_767882159223_item	3587762	et	3	main
eriti	doc_767882159223_item	3587763	et	3	main
poliitilised	doc_767882159223_item	3587772	et	3	main
kui	doc_767882159223_item	3587773	et	3	main
ka	doc_767882159223_item	3587774	et	3	main
kuultuursed	doc_767882159223_item	3587775	et	4	main
kõige	doc_767882159223_item	3587776	et	4	main
tähtsam	doc_767882159223_item	3587777	et	4	main
sündmus	doc_767882159223_item	3587778	et	3	main
eestlaste	doc_767882159223_item	3587779	et	4	main
jaoks	doc_767882159223_item	3587780	et	4	main
oli	doc_767882159223_item	3587781	et	3	main
ja	doc_767882159223_item	3587782	et	3	main
on	doc_767882159223_item	3587783	et	4	main
väikse	doc_767882159223_item	3587796	et	4	main
riigi	doc_767882159223_item	3587797	et	3	main
laul	doc_767882159223_item	3587811	et	4	main
abistas	doc_767882159223_item	3587812	et	3	main
inimestel	doc_767882159223_item	3587813	et	3	main
näha	doc_767882159223_item	3587814	et	3	main
saab	doc_767882159223_item	3587822	et	3	main
inimesed	doc_767882159223_item	3587825	et	3	main
uhke	doc_767882159223_item	3587833	et	4	main
mängivad	doc_767882159223_item	3587843	et	4	main
rahvalauluga	doc_767882159223_item	3587848	et	4	main
avaneb	doc_767882159223_item	3587849	et	3	main
meie	doc_767882159223_item	3587850	et	4	main
silmadele	doc_767882159223_item	3587851	et	3	main
me	doc_767882159223_item	3587856	et	4	main
teada	doc_767882159223_item	3587858	et	3	main
kuidas	doc_767882159223_item	3587859	et	3	main
olid	doc_767882159223_item	3587870	et	4	main
ei	doc_767882159223_item	3587886	et	4	main
eesti	doc_767882159223_item	3587893	et	4	main
mängib	doc_767882159223_item	3587897	et	3	main
kuulda	doc_767882159223_item	3587909	et	4	main
keele	doc_767882159225_item	3587956	et	4	main
test	doc_767882159225_item	3587960	et	3	main
kirjutage	doc_767882159225_item	3587962	et	3	main
teemal	doc_767882159225_item	3587964	et	3	main
mis	doc_767882159225_item	3587965	et	4	main
teeb	doc_767882159225_item	3587966	et	3	main
ja	doc_767882159225_item	3587979	et	3	main
üldistav	doc_767882159225_item	3587980	et	4	main
ja	doc_767882159225_item	3587983	et	3	main
esitatud	doc_767882159225_item	3587985	et	4	main
tähelepanuväärne	doc_767882159225_item	3587994	et	3	main
sotsiaalne	doc_767882159225_item	3588004	et	3	main
oli	doc_767882159225_item	3588058	et	3	main
ajadel	doc_767882159223_item	3587810	et	4	main
et	doc_767882159223_item	3587819	et	3	main
kui	doc_767882159223_item	3587824	et	3	main
laulavad	doc_767882159223_item	3587826	et	4	main
nende	doc_767882159223_item	3587828	et	4	main
rolli	doc_767882159223_item	3587842	et	4	main
kultuuris	doc_767882159223_item	3587845	et	3	main
ka	doc_767882159223_item	3587846	et	3	main
traditsioonid	doc_767882159223_item	3587855	et	3	main
eestlane	doc_767882159223_item	3587861	et	3	main
tagasi	doc_767882159223_item	3587864	et	3	main
mille	doc_767882159223_item	3587865	et	3	main
jaoks	doc_767882159223_item	3587866	et	4	main
lootused	doc_767882159223_item	3587875	et	4	main
saa	doc_767882159223_item	3587887	et	4	main
seda	doc_767882159223_item	3587888	et	3	main
üles	doc_767882159223_item	3587889	et	3	main
leada	doc_767882159223_item	3587890	et	4	main
kuskil	doc_767882159223_item	3587891	et	3	main
rolli	doc_767882159223_item	3587900	et	4	main
niisugustest	doc_767882159223_item	3587904	et	3	main
mida	doc_767882159223_item	3587906	et	4	main
me	doc_767882159223_item	3587907	et	4	main
südametel	doc_767882159223_item	3587829	et	4	main
avaneb	doc_767882159223_item	3587830	et	3	main
ühine	doc_767882159223_item	3587831	et	4	main
ja	doc_767882159223_item	3587832	et	3	main
nad	doc_767882159223_item	3587836	et	3	main
eesti	doc_767882159223_item	3587852	et	4	main
mis	doc_767882159223_item	3587869	et	4	main
ja	doc_767882159223_item	3587874	et	3	main
on	doc_767882159223_item	3587881	et	4	main
nii	doc_767882159223_item	3587882	et	3	main
spetsiifiline	doc_767882159223_item	3587883	et	3	main
et	doc_767882159223_item	3587884	et	3	main
keegi	doc_767882159223_item	3587885	et	4	main
tänapäeva	doc_767882159223_item	3587894	et	4	main
laul	doc_767882159223_item	3587896	et	4	main
ka	doc_767882159223_item	3587898	et	3	main
räägin	doc_767882159223_item	3587902	et	3	main
lauludest	doc_767882159223_item	3587905	et	3	main
saame	doc_767882159223_item	3587908	et	4	main
raadiost	doc_767882159223_item	3587911	et	3	main
või	doc_767882159223_item	3587912	et	4	main
kontserdile	doc_767882159223_item	3587913	et	3	main
minna	doc_767882159223_item	3587914	et	3	main
see	doc_767882159223_item	3587915	et	3	main
aitab	doc_767882159223_item	3587916	et	3	main
eestimaale	doc_767882159223_item	3587917	et	4	main
leida	doc_767882159223_item	3587918	et	3	main
oma	doc_767882159223_item	3587919	et	4	main
kohta	doc_767882159223_item	3587920	et	4	main
mailmaks	doc_767882159223_item	3587921	et	4	main
näiteks	doc_767882159223_item	3587922	et	4	main
kui	doc_767882159223_item	3587923	et	3	main
eesti	doc_767882159223_item	3587924	et	4	main
laulja	doc_767882159223_item	3587925	et	4	main
taanel	doc_767882159223_item	3587926	et	4	main
padar	doc_767882159223_item	3587927	et	4	main
sai	doc_767882159223_item	3587928	et	4	main
eurovisioonil	doc_767882159223_item	3587929	et	3	main
esimest	doc_767882159223_item	3587930	et	4	main
essee	doc_767882159225_item	3587954	et	4	main
kirjutamine	doc_767882159225_item	3587961	et	4	main
olema	doc_767882159225_item	3587976	et	4	main
soovitatav	doc_767882159225_item	3587989	et	4	main
illustreerida	doc_767882159225_item	3587990	et	3	main
see	doc_767882159225_item	3587996	et	3	main
esteetiline	doc_767882159225_item	3587998	et	3	main
ka	doc_767882159225_item	3588003	et	3	main
tegevus	doc_767882159225_item	3588005	et	4	main
mis	doc_767882159225_item	3588006	et	4	main
on	doc_767882159225_item	3588007	et	4	main
austatud	doc_767882159225_item	3588008	et	4	main
üldse	doc_767882159225_item	3588011	et	3	main
saatsid	doc_767882159225_item	3588053	et	4	main
laulmine	doc_767882159225_item	3588057	et	4	main
kogusid	doc_767882159225_item	3588064	et	4	main
andes	doc_767882159225_item	3588078	et	4	main
sellega	doc_767882159225_item	3588079	et	3	main
ja	doc_767882159225_item	3588084	et	3	main
seotud	doc_767882159225_item	3588127	et	4	main
lapsed	doc_767882159225_item	3588130	et	3	main
musitseeriti	doc_767882159225_item	3588147	et	3	main
ka	doc_767882159225_item	3588149	et	3	main
saateks	doc_767882159225_item	3588151	et	3	main
pani	doc_767882159225_item	3588210	et	4	main
aluse	doc_767882159225_item	3588211	et	4	main
järgnevate	doc_767882159225_item	3588212	et	4	main
üldlaulupidude	doc_767882159225_item	3588213	et	4	main
korraldamisele	doc_767882159225_item	3588214	et	4	main
ja	doc_767882159225_item	3588215	et	3	main
praegu	doc_767882159225_item	3588216	et	3	main
iga	doc_767882159225_item	3588217	et	4	main
viie	doc_767882159225_item	3588218	et	3	main
aasta	doc_767882159225_item	3588219	et	4	main
järel	doc_767882159225_item	3588220	et	4	main
koguneb	doc_767882159225_item	3588221	et	3	main
tallinnasse	doc_767882159225_item	3588222	et	3	main
teise	doc_767882159225_item	3587958	et	4	main
essee	doc_767882159225_item	3587963	et	4	main
300	doc_767882159225_item	3587971	et	2	main
arutlev	doc_767882159225_item	3587977	et	4	main
loengus	doc_767882159225_item	3587982	et	3	main
näidetega	doc_767882159225_item	3587991	et	3	main
laulmine	doc_767882159225_item	3587992	et	4	main
rahvalaul	doc_767882159225_item	3588012	et	4	main
jaguneb	doc_767882159225_item	3588013	et	3	main
2	doc_767882159225_item	3588014	et	2	main
ajaloo	doc_767882159225_item	3588015	et	4	main
gruppist	doc_767882159225_item	3588016	et	4	main
esimene	doc_767882159225_item	3588017	et	3	main
rahvalaul	doc_767882159225_item	3588018	et	4	main
grupp	doc_767882159225_item	3588019	et	3	main
on	doc_767882159225_item	3588020	et	4	main
nimetatud	doc_767882159225_item	3588021	et	4	main
regivärsiliseks	doc_767882159225_item	3588022	et	4	main
mis	doc_767882159225_item	3588023	et	4	main
näitab	doc_767882159225_item	3588024	et	3	main
meile	doc_767882159225_item	3588025	et	4	main
eesti	doc_767882159225_item	3588026	et	4	main
vanemat	doc_767882159225_item	3588027	et	4	main
laulutraditsiooni	doc_767882159225_item	3588028	et	4	main
oluliselt	doc_767882159225_item	3588029	et	4	main
ka	doc_767882159225_item	3588030	et	3	main
see	doc_767882159225_item	3588031	et	3	main
et	doc_767882159225_item	3588032	et	3	main
regivärsiline	doc_767882159225_item	3588033	et	4	main
rahvalaul	doc_767882159225_item	3588034	et	4	main
tekkis	doc_767882159225_item	3588035	et	3	main
enam	doc_767882159225_item	3588036	et	4	main
kui	doc_767882159225_item	3588037	et	3	main
tuhat	doc_767882159225_item	3588038	et	4	main
aastat	doc_767882159225_item	3588039	et	3	main
tagasi	doc_767882159225_item	3588040	et	3	main
tol	doc_767882159225_item	3588041	et	3	main
ajal	doc_767882159225_item	3588042	et	4	main
lauldi	doc_767882159225_item	3588043	et	3	main
eestlastest	doc_767882159225_item	3587967	et	4	main
laulurahva	doc_767882159225_item	3587968	et	3	main
sõna	doc_767882159225_item	3587973	et	4	main
essee	doc_767882159225_item	3587974	et	4	main
peab	doc_767882159225_item	3587975	et	4	main
analüüsiv	doc_767882159225_item	3587978	et	4	main
tuginema	doc_767882159225_item	3587981	et	3	main
lugemistekstis	doc_767882159225_item	3587984	et	3	main
faktidele	doc_767882159225_item	3587986	et	3	main
väiteid	doc_767882159225_item	3587987	et	4	main
on	doc_767882159225_item	3587993	et	4	main
on	doc_767882159225_item	3587997	et	4	main
emotsionaalne	doc_767882159225_item	3588000	et	3	main
aga	doc_767882159225_item	3588002	et	3	main
igal	doc_767882159225_item	3588009	et	3	main
rahvusel	doc_767882159225_item	3588010	et	3	main
jaoks	doc_767882159225_item	3588045	et	4	main
töötades	doc_767882159225_item	3588048	et	3	main
rahvalauludest	doc_767882159225_item	3588051	et	3	main
inimesed	doc_767882159225_item	3588052	et	3	main
teada	doc_767882159225_item	3588055	et	3	main
ajaloo	doc_767882159225_item	3588060	et	4	main
uurimine	doc_767882159225_item	3588061	et	4	main
pärast	doc_767882159225_item	3588062	et	4	main
inimesed	doc_767882159225_item	3588063	et	3	main
eeslaulja	doc_767882159225_item	3588067	et	4	main
edasi	doc_767882159225_item	3588069	et	3	main
arendab	doc_767882159225_item	3588071	et	3	main
seda	doc_767882159225_item	3588072	et	3	main
kordas	doc_767882159225_item	3588074	et	3	main
eeslaulja	doc_767882159225_item	3588075	et	4	main
talle	doc_767882159225_item	3588080	et	4	main
mõtteaega	doc_767882159225_item	3588081	et	4	main
olenevalt	doc_767882159225_item	3588082	et	4	main
kooriga	doc_767882159225_item	3588091	et	4	main
olnud	doc_767882159225_item	3588097	et	4	main
nii	doc_767882159225_item	3588098	et	3	main
tähtis	doc_767882159225_item	3588099	et	4	main
kõige	doc_767882159225_item	3588100	et	4	main
kõik	doc_767882159225_item	3588124	et	4	main
olid	doc_767882159225_item	3588126	et	4	main
koorilaulu	doc_767882159225_item	3588135	et	4	main
asutamine	doc_767882159225_item	3588140	et	4	main
kui	doc_767882159225_item	3588142	et	3	main
mängimiseks	doc_767882159225_item	3588144	et	4	main
19	doc_767882159225_item	3588152	et	2	main
lõi	doc_767882159225_item	3588154	et	4	main
idee	doc_767882159225_item	3588194	et	4	main
ja	doc_767882159225_item	3588195	et	3	main
voldemar	doc_767882159225_item	3588202	et	4	main
jannseniga	doc_767882159225_item	3588203	et	4	main
ühtlasi	doc_767882159225_item	3588204	et	4	main
mis	doc_767882159225_item	3588209	et	4	main
keele	doc_767882159226_item	3588229	et	4	main
test	doc_767882159226_item	3588230	et	3	main
eestlastest	doc_767882159226_item	3588237	et	4	main
350	doc_767882159226_item	3588242	et	2	main
tuginema	doc_767882159226_item	3588251	et	3	main
esitatud	doc_767882159226_item	3588255	et	4	main
väiteid	doc_767882159226_item	3588257	et	4	main
laulurahva	doc_767882159226_item	3588265	et	3	main
väga	doc_767882159226_item	3588268	et	3	main
inimesed	doc_767882159226_item	3588270	et	3	main
isegi	doc_767882159226_item	3588272	et	4	main
koos	doc_767882159226_item	3588281	et	4	main
kui	doc_767882159226_item	3588285	et	3	main
koosseisus	doc_767882159226_item	3588306	et	4	main
ükskõik	doc_767882159226_item	3588307	et	3	main
nad	doc_767882159226_item	3588308	et	3	main
festvali	doc_767882159226_item	3588313	et	4	main
on	doc_767882159226_item	3588325	et	4	main
mis	doc_767882159226_item	3588332	et	4	main
elavad	doc_767882159226_item	3588341	et	4	main
isegi	doc_767882159226_item	3588345	et	4	main
ajal	doc_767882159226_item	3588347	et	4	main
nad	doc_767882159226_item	3588348	et	3	main
arenevad	doc_767882159226_item	3588349	et	4	main
ja	doc_767882159226_item	3588350	et	3	main
naiteks	doc_767882159226_item	3588358	et	4	main
rahvalaulu	doc_767882159226_item	3588375	et	4	main
aega	doc_767882159226_item	3588401	et	4	main
üksi	doc_767882159225_item	3588046	et	4	main
olles	doc_767882159225_item	3588047	et	3	main
seepärast	doc_767882159225_item	3588056	et	3	main
nagu	doc_767882159225_item	3588059	et	3	main
kooridesse	doc_767882159225_item	3588065	et	3	main
koor	doc_767882159225_item	3588073	et	4	main
esitatud	doc_767882159225_item	3588076	et	4	main
värsse	doc_767882159225_item	3588077	et	3	main
laululiigist	doc_767882159225_item	3588083	et	3	main
tavast	doc_767882159225_item	3588086	et	4	main
eeslauljaga	doc_767882159225_item	3588092	et	3	main
seepärast	doc_767882159225_item	3588129	et	3	main
osa	doc_767882159225_item	3588132	et	4	main
kaasnes	doc_767882159225_item	3588137	et	3	main
puhkpilliorkestrite	doc_767882159225_item	3588139	et	3	main
muusika	doc_767882159225_item	3588143	et	4	main
aga	doc_767882159225_item	3588146	et	3	main
piduõhtutel	doc_767882159225_item	3588148	et	3	main
tantsu	doc_767882159225_item	3588150	et	4	main
sajandil	doc_767882159225_item	3588153	et	3	main
seltsist	doc_767882159225_item	3588199	et	4	main
eesotsas	doc_767882159225_item	3588200	et	4	main
sai	doc_767882159225_item	3588205	et	4	main
eesti	doc_767882159226_item	3588225	et	4	main
keele	doc_767882159226_item	3588226	et	4	main
kui	doc_767882159226_item	3588227	et	3	main
teise	doc_767882159226_item	3588228	et	4	main
essee	doc_767882159226_item	3588239	et	4	main
peab	doc_767882159226_item	3588245	et	4	main
ja	doc_767882159226_item	3588253	et	3	main
olid	doc_767882159226_item	3588279	et	4	main
olid	doc_767882159226_item	3588295	et	4	main
suured	doc_767882159226_item	3588296	et	3	main
probleemid	doc_767882159226_item	3588297	et	3	main
venemaa	doc_767882159226_item	3588305	et	4	main
laul	doc_767882159226_item	3588326	et	4	main
laulupeod	doc_767882159226_item	3588331	et	4	main
laulupeod	doc_767882159226_item	3588340	et	4	main
ja	doc_767882159226_item	3588344	et	3	main
toimuvad	doc_767882159226_item	3588351	et	4	main
viljandis	doc_767882159226_item	3588359	et	4	main
et	doc_767882159226_item	3588368	et	3	main
lapsed	doc_767882159226_item	3588370	et	3	main
on	doc_767882159226_item	3588405	et	4	main
see	doc_767882159226_item	3588406	et	3	main
ainuke	doc_767882159226_item	3588407	et	4	main
mõtted	doc_767882159226_item	3588416	et	3	main
asi	doc_767882159226_item	3588423	et	4	main
oli	doc_767882159226_item	3588435	et	3	main
nii	doc_767882159226_item	3588436	et	3	main
laulmine	doc_767882159226_item	3588440	et	4	main
ja	doc_767882159226_item	3588441	et	3	main
tantsimine	doc_767882159226_item	3588442	et	4	main
situatsioon	doc_767882159226_item	3588453	et	3	main
kergem	doc_767882159226_item	3588466	et	4	main
natuke	doc_767882159226_item	3588468	et	4	main
armsam	doc_767882159226_item	3588469	et	4	main
kaasaegsed	doc_767882159226_item	3588470	et	3	main
eestlased	doc_767882159226_item	3588471	et	3	main
räägitud	doc_767882159226_item	3588488	et	4	main
kus	doc_767882159225_item	3588066	et	3	main
viis	doc_767882159225_item	3588068	et	4	main
ja	doc_767882159225_item	3588070	et	3	main
üksi	doc_767882159225_item	3588089	et	4	main
kahekesi	doc_767882159225_item	3588090	et	3	main
ilma	doc_767882159225_item	3588094	et	4	main
ei	doc_767882159225_item	3588096	et	4	main
oluliseim	doc_767882159225_item	3588101	et	4	main
oli	doc_767882159225_item	3588102	et	3	main
see	doc_767882159225_item	3588103	et	3	main
et	doc_767882159225_item	3588104	et	3	main
üle	doc_767882159225_item	3588105	et	3	main
laulu	doc_767882159225_item	3588106	et	4	main
inimsed	doc_767882159225_item	3588107	et	4	main
kujunesid	doc_767882159225_item	3588108	et	4	main
oma	doc_767882159225_item	3588109	et	4	main
mõtteid	doc_767882159225_item	3588110	et	3	main
pärast	doc_767882159225_item	3588111	et	4	main
18	doc_767882159225_item	3588112	et	2	main
sajandil	doc_767882159225_item	3588113	et	3	main
kirikus	doc_767882159225_item	3588114	et	3	main
hakkas	doc_767882159225_item	3588115	et	3	main
aga	doc_767882159225_item	3588116	et	3	main
vaimulike	doc_767882159225_item	3588117	et	3	main
laulude	doc_767882159225_item	3588118	et	3	main
laulmine	doc_767882159225_item	3588119	et	4	main
levima	doc_767882159225_item	3588120	et	3	main
ka	doc_767882159225_item	3588121	et	3	main
väljaspool	doc_767882159225_item	3588122	et	3	main
kirikut	doc_767882159225_item	3588123	et	3	main
kirikuga	doc_767882159225_item	3588128	et	3	main
lapsepõlveni	doc_767882159225_item	3588131	et	4	main
võtsid	doc_767882159225_item	3588133	et	4	main
koorides	doc_767882159225_item	3588134	et	4	main
esialgul	doc_767882159225_item	3588141	et	3	main
vanema	doc_767882159225_item	3588155	et	4	main
ja	doc_767882159225_item	3588156	et	3	main
korraldamise	doc_767882159225_item	3588193	et	4	main
tuli	doc_767882159225_item	3588197	et	4	main
vanemuise	doc_767882159225_item	3588198	et	4	main
laulurahva	doc_767882159226_item	3588238	et	3	main
arutlev	doc_767882159226_item	3588247	et	4	main
loengus	doc_767882159226_item	3588252	et	3	main
mis	doc_767882159226_item	3588262	et	4	main
teeb	doc_767882159226_item	3588263	et	3	main
eestlastest	doc_767882159226_item	3588264	et	4	main
alati	doc_767882159226_item	3588280	et	4	main
õnnes	doc_767882159226_item	3588284	et	4	main
ka	doc_767882159226_item	3588286	et	3	main
seda	doc_767882159226_item	3588288	et	3	main
näiteks	doc_767882159226_item	3588298	et	4	main
oli	doc_767882159226_item	3588299	et	3	main
väga	doc_767882159226_item	3588300	et	3	main
tegid	doc_767882159226_item	3588309	et	4	main
tantsu	doc_767882159226_item	3588310	et	4	main
ja	doc_767882159226_item	3588311	et	3	main
eestlaste	doc_767882159226_item	3588314	et	4	main
on	doc_767882159226_item	3588316	et	4	main
väga	doc_767882159226_item	3588317	et	3	main
euroopast	doc_767882159225_item	3588157	et	3	main
laenatud	doc_767882159225_item	3588158	et	4	main
laulutraditsiooni	doc_767882159225_item	3588159	et	4	main
koosmõju	doc_767882159225_item	3588160	et	4	main
eeldused	doc_767882159225_item	3588161	et	4	main
uue	doc_767882159225_item	3588162	et	3	main
riimilise	doc_767882159225_item	3588163	et	4	main
rahvalaulu	doc_767882159225_item	3588164	et	4	main
tekkeks	doc_767882159225_item	3588165	et	3	main
19	doc_767882159225_item	3588166	et	2	main
sajandi	doc_767882159225_item	3588167	et	3	main
lõpupool	doc_767882159225_item	3588168	et	4	main
eestlaste	doc_767882159225_item	3588169	et	4	main
jaoks	doc_767882159225_item	3588170	et	4	main
tähendab	doc_767882159225_item	3588171	et	3	main
kõige	doc_767882159225_item	3588172	et	4	main
tähtsam	doc_767882159225_item	3588173	et	4	main
periood	doc_767882159225_item	3588174	et	3	main
eestlaste	doc_767882159225_item	3588175	et	4	main
rahvuslik	doc_767882159225_item	3588176	et	3	main
ärkamine	doc_767882159225_item	3588177	et	4	main
millal	doc_767882159225_item	3588178	et	3	main
haridus	doc_767882159225_item	3588179	et	3	main
mängis	doc_767882159225_item	3588180	et	3	main
rolli	doc_767882159225_item	3588181	et	4	main
nii	doc_767882159225_item	3588182	et	3	main
linnas	doc_767882159225_item	3588183	et	4	main
kui	doc_767882159225_item	3588184	et	3	main
maal	doc_767882159225_item	3588185	et	4	main
1869-l	doc_767882159225_item	3588186	et	3	main
toimus	doc_767882159225_item	3588187	et	3	main
esimene	doc_767882159225_item	3588188	et	3	main
ülemaaline	doc_767882159225_item	3588189	et	4	main
teostus	doc_767882159225_item	3588196	et	4	main
muusikaline	doc_767882159225_item	3588207	et	4	main
suursündmus	doc_767882159225_item	3588208	et	3	main
essee	doc_767882159226_item	3588224	et	4	main
pikkus	doc_767882159226_item	3588240	et	4	main
sõna	doc_767882159226_item	3588243	et	4	main
üldistav	doc_767882159226_item	3588250	et	4	main
faktidele	doc_767882159226_item	3588256	et	3	main
on	doc_767882159226_item	3588258	et	4	main
soovitatav	doc_767882159226_item	3588259	et	4	main
illustreerida	doc_767882159226_item	3588260	et	3	main
näidetega	doc_767882159226_item	3588261	et	3	main
estlased	doc_767882159226_item	3588266	et	4	main
patriootilised	doc_767882159226_item	3588269	et	3	main
ja	doc_767882159226_item	3588271	et	3	main
nende	doc_767882159226_item	3588273	et	4	main
rahva	doc_767882159226_item	3588274	et	3	main
tegelemine	doc_767882159226_item	3588275	et	4	main
näitab	doc_767882159226_item	3588276	et	3	main
seda	doc_767882159226_item	3588277	et	3	main
laulud	doc_767882159226_item	3588278	et	3	main
nii	doc_767882159226_item	3588283	et	3	main
häbis	doc_767882159226_item	3588287	et	3	main
võib	doc_767882159226_item	3588289	et	3	main
selleparast	doc_767882159226_item	3588291	et	3	main
raske	doc_767882159226_item	3588301	et	4	main
saada	doc_767882159226_item	3588302	et	4	main
need	doc_767882159226_item	3588324	et	3	main
pilli	doc_767882159226_item	3588327	et	4	main
muusika	doc_767882159226_item	3588328	et	4	main
ja	doc_767882159226_item	3588329	et	3	main
tants	doc_767882159226_item	3588330	et	3	main
inimesi	doc_767882159226_item	3588337	et	4	main
laulurahva	doc_767882159226_item	3588338	et	3	main
rahva	doc_767882159226_item	3588339	et	3	main
ammu	doc_767882159226_item	3588343	et	4	main
meie	doc_767882159226_item	3588346	et	4	main
nii	doc_767882159226_item	3588356	et	3	main
palju	doc_767882159226_item	3588357	et	4	main
ja	doc_767882159226_item	3588361	et	3	main
on	doc_767882159226_item	3588366	et	4	main
kaasaegsed	doc_767882159226_item	3588369	et	3	main
armastavad	doc_767882159226_item	3588373	et	4	main
oma	doc_767882159226_item	3588374	et	4	main
oma	doc_767882159226_item	3588413	et	4	main
tunned	doc_767882159226_item	3588414	et	3	main
ja	doc_767882159226_item	3588415	et	3	main
sellepäras	doc_767882159226_item	3588424	et	3	main
osaled	doc_767882159226_item	3588426	et	3	main
kõik	doc_767882159226_item	3588427	et	4	main
ja	doc_767882159226_item	3588430	et	3	main
lapsed	doc_767882159226_item	3588431	et	3	main
vanasti	doc_767882159226_item	3588432	et	3	main
nägu	doc_767882159226_item	3588452	et	4	main
isegi	doc_767882159226_item	3588460	et	4	main
laulurahva	doc_767882159226_item	3588475	et	3	main
alati	doc_767882159226_item	3588487	et	4	main
folkloori	doc_767882159226_item	3588491	et	4	main
arhiivi	doc_767882159226_item	3588494	et	4	main
otsivad	doc_767882159226_item	3588495	et	4	main
ja	doc_767882159226_item	3588496	et	3	main
eesti	doc_767882159229_item	3588536	et	4	main
test	doc_767882159229_item	3588541	et	3	main
kirjutage	doc_767882159229_item	3588543	et	3	main
300	doc_767882159229_item	3588552	et	2	main
laulmine	doc_767882159229_item	3588573	et	4	main
on	doc_767882159229_item	3588577	et	4	main
ja	doc_767882159229_item	3588579	et	3	main
aga	doc_767882159229_item	3588582	et	3	main
tegevus	doc_767882159229_item	3588585	et	4	main
jaoks	doc_767882159229_item	3588607	et	4	main
aga	doc_767882159229_item	3588608	et	3	main
lauljad	doc_767882159229_item	3588614	et	4	main
ja	doc_767882159229_item	3588617	et	3	main
laulasid	doc_767882159229_item	3588618	et	4	main
palju	doc_767882159226_item	3588511	et	4	main
aastad	doc_767882159226_item	3588512	et	3	main
ja	doc_767882159226_item	3588513	et	3	main
see	doc_767882159226_item	3588514	et	3	main
on	doc_767882159226_item	3588515	et	4	main
väga	doc_767882159226_item	3588516	et	3	main
oluline	doc_767882159226_item	3588517	et	4	main
asi	doc_767882159226_item	3588518	et	4	main
inimesed	doc_767882159226_item	3588519	et	3	main
sellest	doc_767882159226_item	3588521	et	4	main
kust	doc_767882159226_item	3588522	et	4	main
mäletavad	doc_767882159226_item	3588520	et	4	main
nad	doc_767882159226_item	3588523	et	3	main
on	doc_767882159226_item	3588524	et	4	main
pärit	doc_767882159226_item	3588525	et	3	main
ja	doc_767882159226_item	3588526	et	3	main
see	doc_767882159226_item	3588527	et	3	main
on	doc_767882159226_item	3588528	et	4	main
tähtis	doc_767882159226_item	3588529	et	4	main
nendele	doc_767882159226_item	3588530	et	4	main
eestlased	doc_767882159226_item	3588531	et	3	main
on	doc_767882159226_item	3588532	et	4	main
laulurahva	doc_767882159226_item	3588533	et	3	main
kirjutamine	doc_767882159226_item	3588231	et	4	main
kirjutage	doc_767882159226_item	3588232	et	3	main
essee	doc_767882159226_item	3588233	et	4	main
teemal	doc_767882159226_item	3588234	et	3	main
mis	doc_767882159226_item	3588235	et	4	main
teeb	doc_767882159226_item	3588236	et	3	main
300	doc_767882159226_item	3588241	et	2	main
essee	doc_767882159226_item	3588244	et	4	main
olema	doc_767882159226_item	3588246	et	4	main
analüüsiv	doc_767882159226_item	3588248	et	4	main
ja	doc_767882159226_item	3588249	et	3	main
lugemistekstis	doc_767882159226_item	3588254	et	3	main
on	doc_767882159226_item	3588267	et	4	main
nendega	doc_767882159226_item	3588282	et	4	main
öelda	doc_767882159226_item	3588290	et	4	main
isegi	doc_767882159226_item	3588292	et	4	main
kui	doc_767882159226_item	3588293	et	3	main
nei	doc_767882159226_item	3588294	et	4	main
loa	doc_767882159226_item	3588303	et	4	main
tsaristliku	doc_767882159226_item	3588304	et	3	main
laulu	doc_767882159226_item	3588312	et	4	main
lalurahv	doc_767882159226_item	3588315	et	4	main
eriline	doc_767882159226_item	3588318	et	4	main
ja	doc_767882159226_item	3588319	et	3	main
see	doc_767882159226_item	3588320	et	3	main
koosneb	doc_767882159226_item	3588321	et	3	main
mitmendast	doc_767882159226_item	3588322	et	3	main
osast	doc_767882159226_item	3588323	et	4	main
toimuvad	doc_767882159226_item	3588333	et	4	main
regulaarselt	doc_767882159226_item	3588334	et	4	main
eestis	doc_767882159226_item	3588335	et	3	main
teevad	doc_767882159226_item	3588336	et	3	main
tihti	doc_767882159226_item	3588353	et	3	main
teistes	doc_767882159226_item	3588362	et	4	main
väga	doc_767882159226_item	3588364	et	3	main
asi	doc_767882159226_item	3588408	et	4	main
kus	doc_767882159226_item	3588409	et	3	main
sa	doc_767882159226_item	3588410	et	3	main
võid	doc_767882159226_item	3588411	et	4	main
laul	doc_767882159226_item	3588419	et	4	main
võivad	doc_767882159226_item	3588425	et	4	main
naised	doc_767882159226_item	3588428	et	3	main
rohkem	doc_767882159226_item	3588444	et	4	main
olid	doc_767882159226_item	3588449	et	4	main
näiteks	doc_767882159226_item	3588450	et	4	main
merel	doc_767882159226_item	3588451	et	3	main
laul	doc_767882159226_item	3588455	et	4	main
tants	doc_767882159226_item	3588457	et	3	main
võimalik	doc_767882159226_item	3588459	et	3	main
töö	doc_767882159226_item	3588461	et	4	main
tehes	doc_767882159226_item	3588462	et	3	main
see	doc_767882159226_item	3588463	et	3	main
teeb	doc_767882159226_item	3588464	et	3	main
tööd	doc_767882159226_item	3588465	et	4	main
näitavad	doc_767882159226_item	3588472	et	4	main
elab	doc_767882159226_item	3588476	et	3	main
veel	doc_767882159226_item	3588478	et	4	main
elada	doc_767882159226_item	3588480	et	3	main
televisoris	doc_767882159226_item	3588484	et	4	main
raadios	doc_767882159226_item	3588485	et	3	main
on	doc_767882159226_item	3588486	et	4	main
essee	doc_767882159229_item	3588535	et	4	main
keele	doc_767882159229_item	3588537	et	4	main
väiteid	doc_767882159229_item	3588568	et	4	main
see	doc_767882159229_item	3588576	et	3	main
ajal	doc_767882159229_item	3588587	et	4	main
aega	doc_767882159229_item	3588590	et	4	main
kinkis	doc_767882159229_item	3588591	et	3	main
laulmise	doc_767882159229_item	3588592	et	4	main
ja	doc_767882159229_item	3588593	et	3	main
kultur	doc_767882159229_item	3588598	et	4	main
rohkem	doc_767882159229_item	3588600	et	4	main
laulas	doc_767882159229_item	3588611	et	4	main
istusid	doc_767882159229_item	3588615	et	4	main
laulatakse	doc_767882159229_item	3588624	et	4	main
eestlane	doc_767882159229_item	3588625	et	3	main
juba	doc_767882159226_item	3588342	et	3	main
väga	doc_767882159226_item	3588352	et	3	main
naideid	doc_767882159226_item	3588354	et	4	main
on	doc_767882159226_item	3588355	et	4	main
tallinnas	doc_767882159226_item	3588360	et	4	main
linnades	doc_767882159226_item	3588363	et	3	main
meeldiv	doc_767882159226_item	3588365	et	4	main
see	doc_767882159226_item	3588367	et	3	main
ja	doc_767882159226_item	3588371	et	3	main
noored	doc_767882159226_item	3588372	et	3	main
ja	doc_767882159226_item	3588376	et	3	main
isegi	doc_767882159226_item	3588377	et	4	main
paar	doc_767882159226_item	3588378	et	3	main
astad	doc_767882159226_item	3588379	et	4	main
tagasi	doc_767882159226_item	3588380	et	3	main
üks	doc_767882159226_item	3588381	et	3	main
niisugune	doc_767882159226_item	3588382	et	3	main
laul	doc_767882159226_item	3588383	et	4	main
oli	doc_767882159226_item	3588384	et	3	main
väga	doc_767882159226_item	3588385	et	3	main
populaarne	doc_767882159226_item	3588386	et	3	main
hitt	doc_767882159226_item	3588387	et	3	main
inimeste	doc_767882159226_item	3588388	et	3	main
elurütm	doc_767882159226_item	3588389	et	3	main
teeb	doc_767882159226_item	3588390	et	3	main
neid	doc_767882159226_item	3588391	et	4	main
ka	doc_767882159226_item	3588392	et	3	main
laulurahva	doc_767882159226_item	3588393	et	3	main
nad	doc_767882159226_item	3588394	et	3	main
alati	doc_767882159226_item	3588395	et	4	main
kiirustavad	doc_767882159226_item	3588396	et	4	main
ja	doc_767882159226_item	3588397	et	3	main
neil	doc_767882159226_item	3588398	et	4	main
ei	doc_767882159226_item	3588399	et	4	main
ole	doc_767882159226_item	3588400	et	4	main
rahvalaul	doc_767882159226_item	3588402	et	4	main
ja	doc_767882159226_item	3588403	et	3	main
tants	doc_767882159226_item	3588404	et	3	main
näidata	doc_767882159226_item	3588412	et	4	main
või	doc_767882159226_item	3588418	et	4	main
on	doc_767882159226_item	3588420	et	4	main
hea	doc_767882159226_item	3588422	et	4	main
tants	doc_767882159226_item	3588417	et	3	main
väga	doc_767882159226_item	3588421	et	3	main
ei	doc_767882159226_item	3588434	et	4	main
nagu	doc_767882159226_item	3588438	et	3	main
oli	doc_767882159226_item	3588443	et	3	main
sest	doc_767882159226_item	3588447	et	4	main
ja	doc_767882159226_item	3588456	et	3	main
ja	doc_767882159226_item	3588467	et	3	main
see	doc_767882159226_item	3588474	et	3	main
ja	doc_767882159226_item	3588477	et	3	main
koolides	doc_767882159226_item	3588482	et	3	main
ülikoolides	doc_767882159226_item	3588483	et	3	main
paljud	doc_767882159226_item	3588490	et	3	main
lähevad	doc_767882159226_item	3588493	et	3	main
lugevad	doc_767882159226_item	3588497	et	4	main
teise	doc_767882159229_item	3588539	et	4	main
essee	doc_767882159229_item	3588550	et	4	main
peab	doc_767882159229_item	3588556	et	4	main
analüüsiv	doc_767882159229_item	3588559	et	4	main
ja	doc_767882159229_item	3588560	et	3	main
üldistav	doc_767882159229_item	3588561	et	4	main
tuginema	doc_767882159229_item	3588562	et	3	main
loengus	doc_767882159229_item	3588563	et	3	main
ja	doc_767882159229_item	3588564	et	3	main
lugemistekstis	doc_767882159229_item	3588565	et	3	main
esitatud	doc_767882159229_item	3588566	et	4	main
faktidele	doc_767882159229_item	3588567	et	3	main
ja	doc_767882159229_item	3588574	et	3	main
esteetuline	doc_767882159229_item	3588578	et	4	main
emotsionaalne	doc_767882159229_item	3588580	et	3	main
ka	doc_767882159229_item	3588583	et	3	main
rahvus	doc_767882159229_item	3588588	et	3	main
palju	doc_767882159229_item	3588589	et	4	main
ja	doc_767882159229_item	3588597	et	3	main
saab	doc_767882159229_item	3588599	et	3	main
ja	doc_767882159229_item	3588601	et	3	main
ise	doc_767882159229_item	3588612	et	4	main
jaoks	doc_767882159229_item	3588613	et	4	main
ringi	doc_767882159229_item	3588616	et	4	main
kes	doc_767882159229_item	3588623	et	4	main
mehed	doc_767882159226_item	3588429	et	3	main
see	doc_767882159226_item	3588433	et	3	main
võimalik	doc_767882159226_item	3588437	et	3	main
kohe	doc_767882159226_item	3588439	et	4	main
naistel	doc_767882159226_item	3588445	et	3	main
võimalik	doc_767882159226_item	3588446	et	3	main
mehed	doc_767882159226_item	3588448	et	3	main
kihnul	doc_767882159226_item	3588454	et	3	main
on	doc_767882159226_item	3588458	et	4	main
et	doc_767882159226_item	3588473	et	3	main
hakkab	doc_767882159226_item	3588479	et	3	main
sest	doc_767882159226_item	3588481	et	4	main
sellest	doc_767882159226_item	3588489	et	4	main
rühmad	doc_767882159226_item	3588492	et	4	main
vana	doc_767882159226_item	3588498	et	4	main
ja	doc_767882159226_item	3588499	et	3	main
rahva	doc_767882159226_item	3588500	et	3	main
asju	doc_767882159226_item	3588501	et	3	main
mina	doc_767882159226_item	3588502	et	4	main
olen	doc_767882159226_item	3588503	et	3	main
veendunud	doc_767882159226_item	3588504	et	4	main
et	doc_767882159226_item	3588505	et	3	main
eesti	doc_767882159226_item	3588506	et	4	main
laulurahva	doc_767882159226_item	3588507	et	3	main
hakkab	doc_767882159226_item	3588508	et	3	main
veel	doc_767882159226_item	3588509	et	4	main
elada	doc_767882159226_item	3588510	et	3	main
keele	doc_767882159229_item	3588540	et	4	main
pikkus	doc_767882159229_item	3588551	et	4	main
350	doc_767882159229_item	3588553	et	2	main
sõna	doc_767882159229_item	3588554	et	4	main
essee	doc_767882159229_item	3588555	et	4	main
arutlev	doc_767882159229_item	3588558	et	4	main
soovitatav	doc_767882159229_item	3588570	et	4	main
illustreerida	doc_767882159229_item	3588571	et	3	main
näidetega	doc_767882159229_item	3588572	et	3	main
tantsise	doc_767882159229_item	3588594	et	4	main
aeg	doc_767882159229_item	3588595	et	3	main
pikkem	doc_767882159229_item	3588602	et	4	main
praegu	doc_767882159229_item	3588603	et	3	main
rahvus	doc_767882159229_item	3588604	et	3	main
laulab	doc_767882159229_item	3588605	et	3	main
raha	doc_767882159229_item	3588606	et	4	main
laulurahva	doc_767882159229_item	3588626	et	3	main
tavast	doc_767882159229_item	3588633	et	4	main
üksi	doc_767882159229_item	3588636	et	4	main
keha	doc_767882159229_item	3588646	et	4	main
ning	doc_767882159229_item	3588654	et	3	main
põlvest	doc_767882159229_item	3588657	et	4	main
põlve	doc_767882159229_item	3588658	et	4	main
suuliselt	doc_767882159229_item	3588659	et	4	main
tuginedes	doc_767882159229_item	3588660	et	3	main
mälule	doc_767882159229_item	3588661	et	3	main
ja	doc_767882159229_item	3588662	et	3	main
traditsioonidele	doc_767882159229_item	3588663	et	3	main
ristiusuga	doc_767882159229_item	3588664	et	3	main
kaasnes	doc_767882159229_item	3588665	et	3	main
vaimulike	doc_767882159229_item	3588666	et	3	main
laulude	doc_767882159229_item	3588667	et	3	main
laulude	doc_767882159229_item	3588675	et	3	main
on	doc_767882159229_item	3588695	et	4	main
kuulatud	doc_767882159229_item	3588697	et	4	main
mitmes	doc_767882159229_item	3588703	et	4	main
riigis	doc_767882159229_item	3588704	et	3	main
euroopast	doc_767882159229_item	3588712	et	3	main
tähtsusega	doc_767882159229_item	3588742	et	4	main
sündmuseks	doc_767882159229_item	3588743	et	3	main
kujunes	doc_767882159229_item	3588744	et	3	main
idee	doc_767882159229_item	3588753	et	4	main
kes	doc_767882159229_item	3588791	et	4	main
on	doc_767882159229_item	3588792	et	4	main
üle	doc_767882159229_item	3588793	et	3	main
kogu	doc_767882159229_item	3588794	et	4	main
maailma	doc_767882159229_item	3588795	et	4	main
kokku	doc_767882159229_item	3588796	et	3	main
sõitnud	doc_767882159229_item	3588797	et	4	main
kui	doc_767882159229_item	3588538	et	3	main
kirjutamine	doc_767882159229_item	3588542	et	4	main
essee	doc_767882159229_item	3588544	et	4	main
teemal	doc_767882159229_item	3588545	et	3	main
mis	doc_767882159229_item	3588546	et	4	main
teeb	doc_767882159229_item	3588547	et	3	main
eestlastest	doc_767882159229_item	3588548	et	4	main
laulurahva	doc_767882159229_item	3588549	et	3	main
olema	doc_767882159229_item	3588557	et	4	main
on	doc_767882159229_item	3588569	et	4	main
tantsime	doc_767882159229_item	3588575	et	3	main
väljendusvahed	doc_767882159229_item	3588581	et	3	main
sotsiaalne	doc_767882159229_item	3588584	et	3	main
vanal	doc_767882159229_item	3588586	et	3	main
läheb	doc_767882159229_item	3588596	et	3	main
varem	doc_767882159229_item	3588609	et	4	main
rahvus	doc_767882159229_item	3588610	et	3	main
või	doc_767882159229_item	3588619	et	4	main
tantsid	doc_767882159229_item	3588620	et	4	main
praegu	doc_767882159229_item	3588621	et	3	main
laul	doc_767882159229_item	3588622	et	4	main
rahvalaul	doc_767882159229_item	3588628	et	4	main
rütmi	doc_767882159229_item	3588644	et	4	main
regilaule	doc_767882159229_item	3588650	et	4	main
lauldi	doc_767882159229_item	3588651	et	3	main
ilma	doc_767882159229_item	3588652	et	4	main
pillisaateta	doc_767882159229_item	3588653	et	3	main
pärandati	doc_767882159229_item	3588656	et	4	main
aga	doc_767882159229_item	3588673	et	3	main
on	doc_767882159229_item	3588705	et	4	main
vanema	doc_767882159229_item	3588710	et	4	main
laenatud	doc_767882159229_item	3588713	et	4	main
koosmõju	doc_767882159229_item	3588715	et	4	main
lõi	doc_767882159229_item	3588716	et	4	main
19	doc_767882159229_item	3588717	et	2	main
sajandil	doc_767882159229_item	3588718	et	3	main
need	doc_767882159229_item	3588724	et	3	main
laulud	doc_767882159229_item	3588725	et	3	main
on	doc_767882159229_item	3588726	et	4	main
euroopa	doc_767882159229_item	3588729	et	4	main
saksa	doc_767882159229_item	3588732	et	4	main
aga	doc_767882159229_item	3588733	et	3	main
ka	doc_767882159229_item	3588734	et	3	main
nimetab	doc_767882159229_item	3588627	et	3	main
olenevalt	doc_767882159229_item	3588629	et	4	main
laululiigist	doc_767882159229_item	3588630	et	3	main
ja	doc_767882159229_item	3588631	et	3	main
kohalikust	doc_767882159229_item	3588632	et	4	main
näiteks	doc_767882159229_item	3588645	et	4	main
laulmine	doc_767882159229_item	3588668	et	4	main
kirikus	doc_767882159229_item	3588669	et	3	main
18	doc_767882159229_item	3588670	et	2	main
sajandil	doc_767882159229_item	3588671	et	3	main
teised	doc_767882159229_item	3588698	et	4	main
ja	doc_767882159229_item	3588699	et	3	main
ja	doc_767882159229_item	3588711	et	3	main
laulutraditsiooni	doc_767882159229_item	3588714	et	4	main
riimilise	doc_767882159229_item	3588721	et	4	main
rahvalaulu	doc_767882159229_item	3588722	et	4	main
tekkeks	doc_767882159229_item	3588723	et	3	main
kujunenud	doc_767882159229_item	3588728	et	4	main
muusika	doc_767882159229_item	3588730	et	4	main
eelkõige	doc_767882159229_item	3588731	et	3	main
soome	doc_767882159229_item	3588736	et	3	main
esimene	doc_767882159229_item	3588745	et	3	main
ja	doc_767882159229_item	3588754	et	3	main
laulupeod	doc_767882159229_item	3588767	et	4	main
on	doc_767882159229_item	3588634	et	4	main
lauldud	doc_767882159229_item	3588635	et	4	main
kahekesi	doc_767882159229_item	3588637	et	3	main
kooriga	doc_767882159229_item	3588638	et	4	main
lauldes	doc_767882159229_item	3588641	et	3	main
võidi	doc_767882159229_item	3588642	et	4	main
rõhutada	doc_767882159229_item	3588643	et	3	main
või	doc_767882159229_item	3588648	et	4	main
jalapõrutusega	doc_767882159229_item	3588649	et	3	main
neid	doc_767882159229_item	3588655	et	4	main
vaimulike	doc_767882159229_item	3588674	et	3	main
laulatud	doc_767882159229_item	3588700	et	4	main
koos	doc_767882159229_item	3588701	et	4	main
kõikiga	doc_767882159229_item	3588702	et	4	main
ja	doc_767882159229_item	3588708	et	3	main
ja	doc_767882159229_item	3588737	et	3	main
muusika	doc_767882159229_item	3588739	et	4	main
aastal	doc_767882159229_item	3588749	et	3	main
tartus	doc_767882159229_item	3588750	et	3	main
mille	doc_767882159229_item	3588751	et	3	main
korraldamise	doc_767882159229_item	3588752	et	4	main
ja	doc_767882159229_item	3588763	et	3	main
ajani	doc_767882159229_item	3588765	et	3	main
lauluväljakud	doc_767882159229_item	3588770	et	3	main
teise	doc_767882159234_item	3588803	et	4	main
essee	doc_767882159234_item	3588808	et	4	main
essee	doc_767882159234_item	3588819	et	4	main
peab	doc_767882159234_item	3588820	et	4	main
loengus	doc_767882159234_item	3588827	et	3	main
ja	doc_767882159234_item	3588828	et	3	main
on	doc_767882159234_item	3588838	et	4	main
inimesi	doc_767882159234_item	3588840	et	4	main
tulid	doc_767882159234_item	3588845	et	4	main
inimesed	doc_767882159234_item	3588846	et	3	main
tuju	doc_767882159234_item	3588902	et	4	main
sõpru	doc_767882159234_item	3588908	et	3	main
laulupeod	doc_767882159234_item	3588915	et	4	main
inimesi	doc_767882159234_item	3588917	et	4	main
ja	doc_767882159234_item	3588918	et	3	main
ja	doc_767882159234_item	3588931	et	3	main
praegu	doc_767882159234_item	3588934	et	3	main
lauluõhtud	doc_767882159234_item	3588937	et	3	main
pop-	doc_767882159234_item	3588941	et	4	main
väga	doc_767882159234_item	3588945	et	3	main
et	doc_767882159234_item	3588947	et	3	main
inimesed	doc_767882159234_item	3588949	et	3	main
rahvalauludest	doc_767882159234_item	3588952	et	3	main
ma	doc_767882159234_item	3588960	et	3	main
keeles	doc_767882159234_item	3588965	et	4	main
mängivad	doc_767882159234_item	3588968	et	4	main
rock-muusikat	doc_767882159234_item	3588969	et	3	main
arvan	doc_767882159234_item	3588970	et	3	main
et	doc_767882159234_item	3588971	et	3	main
väga	doc_767882159234_item	3588972	et	3	main
huvitavad	doc_767882159234_item	3588973	et	4	main
olid	doc_767882159234_item	3588974	et	4	main
muinasjutud	doc_767882159234_item	3588975	et	3	main
ja	doc_767882159234_item	3588976	et	3	main
laulud	doc_767882159234_item	3588977	et	3	main
üksi	doc_767882159234_item	3588992	et	4	main
olles	doc_767882159234_item	3588993	et	3	main
töötades	doc_767882159234_item	3588994	et	3	main
minevik	doc_767882159234_item	3589027	et	3	main
mõelnud	doc_767882159234_item	3589044	et	4	main
et	doc_767882159234_item	3589045	et	3	main
see	doc_767882159234_item	3589046	et	3	main
18	doc_767882159234_item	3589051	et	2	main
sajandil	doc_767882159234_item	3589052	et	3	main
kindel	doc_767882159234_item	3589068	et	3	main
mulle	doc_767882159234_item	3589072	et	4	main
ja	doc_767882159229_item	3588639	et	3	main
eeslauljaga	doc_767882159229_item	3588640	et	3	main
õõtsutamise	doc_767882159229_item	3588647	et	4	main
hakkas	doc_767882159229_item	3588672	et	3	main
laulmine	doc_767882159229_item	3588676	et	4	main
levima	doc_767882159229_item	3588677	et	3	main
ka	doc_767882159229_item	3588678	et	3	main
väljaspool	doc_767882159229_item	3588679	et	3	main
kirikut	doc_767882159229_item	3588680	et	3	main
olen	doc_767882159229_item	3588681	et	3	main
ka	doc_767882159229_item	3588682	et	3	main
mitmehäälset	doc_767882159229_item	3588683	et	3	main
koorilaulu	doc_767882159229_item	3588684	et	4	main
ma	doc_767882159229_item	3588685	et	3	main
laulasin	doc_767882159229_item	3588686	et	4	main
mitmehäälset	doc_767882159229_item	3588687	et	3	main
koorilaulu	doc_767882159229_item	3588688	et	4	main
kooriga	doc_767882159229_item	3588689	et	4	main
see	doc_767882159229_item	3588690	et	3	main
on	doc_767882159229_item	3588691	et	4	main
väga	doc_767882159229_item	3588692	et	3	main
raske	doc_767882159229_item	3588693	et	4	main
seepärast	doc_767882159229_item	3588694	et	3	main
vaja	doc_767882159229_item	3588696	et	4	main
oma	doc_767882159229_item	3588706	et	4	main
kultuuriidentiteet	doc_767882159229_item	3588707	et	4	main
laulutraditsioonid	doc_767882159229_item	3588709	et	3	main
eeldused	doc_767882159229_item	3588719	et	4	main
uue	doc_767882159229_item	3588720	et	3	main
välja	doc_767882159229_item	3588727	et	4	main
rootsi	doc_767882159229_item	3588735	et	4	main
slaavi	doc_767882159229_item	3588738	et	3	main
mõjul	doc_767882159229_item	3588740	et	4	main
ajaloolise	doc_767882159229_item	3588741	et	4	main
teostus	doc_767882159229_item	3588755	et	4	main
seltsist	doc_767882159229_item	3588758	et	4	main
on	doc_767882159229_item	3588766	et	4	main
essee	doc_767882159234_item	3588799	et	4	main
test	doc_767882159234_item	3588805	et	3	main
teemal	doc_767882159234_item	3588809	et	3	main
eestlastest	doc_767882159234_item	3588812	et	4	main
faktidele	doc_767882159234_item	3588831	et	3	main
soovitatav	doc_767882159234_item	3588834	et	4	main
näidetega	doc_767882159234_item	3588836	et	3	main
siia	doc_767882159234_item	3588844	et	4	main
kujutan	doc_767882159234_item	3588885	et	3	main
ette	doc_767882159234_item	3588886	et	4	main
et	doc_767882159234_item	3588887	et	3	main
olen	doc_767882159234_item	3588888	et	3	main
ka	doc_767882159234_item	3588889	et	3	main
rahvariietes	doc_767882159234_item	3588890	et	3	main
et	doc_767882159234_item	3588891	et	3	main
tulin	doc_767882159234_item	3588892	et	3	main
sest	doc_767882159234_item	3588903	et	4	main
loodan	doc_767882159234_item	3588905	et	3	main
kohtan	doc_767882159234_item	3588907	et	3	main
et	doc_767882159234_item	3588913	et	3	main
said	doc_767882159234_item	3588920	et	4	main
kahjuks	doc_767882159234_item	3588923	et	4	main
ei	doc_767882159234_item	3588925	et	4	main
juba	doc_767882159234_item	3588927	et	3	main
elada	doc_767882159234_item	3588928	et	3	main
tol	doc_767882159234_item	3588929	et	3	main
nüüd	doc_767882159234_item	3588939	et	4	main
või	doc_767882159234_item	3588942	et	4	main
rock-ansaamblidega	doc_767882159234_item	3588943	et	4	main
olen	doc_767882159234_item	3588944	et	3	main
huvitatud	doc_767882159234_item	3588951	et	4	main
tean	doc_767882159234_item	3588961	et	3	main
setu	doc_767882159234_item	3588964	et	4	main
ja	doc_767882159234_item	3588966	et	3	main
tingimata	doc_767882159234_item	3588982	et	4	main
väljendusvahe	doc_767882159234_item	3588988	et	4	main
vanal	doc_767882159234_item	3588989	et	3	main
ajal	doc_767882159234_item	3588990	et	4	main
lauldi	doc_767882159234_item	3588991	et	3	main
huvitab	doc_767882159234_item	3589024	et	3	main
minu	doc_767882159234_item	3589025	et	3	main
rahva	doc_767882159234_item	3589026	et	3	main
väga	doc_767882159234_item	3589031	et	3	main
sain	doc_767882159234_item	3589036	et	3	main
traditsioon	doc_767882159234_item	3589047	et	3	main
nüüd	doc_767882159234_item	3589053	et	4	main
ülemaaline	doc_767882159229_item	3588746	et	4	main
laulupidu	doc_767882159229_item	3588747	et	4	main
1869	doc_767882159229_item	3588748	et	2	main
tuli	doc_767882159229_item	3588756	et	4	main
vanamuise	doc_767882159229_item	3588757	et	4	main
eesotsas	doc_767882159229_item	3588759	et	4	main
johann	doc_767882159229_item	3588760	et	4	main
nad	doc_767882159229_item	3588768	et	3	main
seal	doc_767882159229_item	3588771	et	4	main
lisaks	doc_767882159229_item	3588775	et	4	main
on	doc_767882159229_item	3588776	et	4	main
laulupidu	doc_767882159229_item	3588777	et	4	main
ka	doc_767882159229_item	3588778	et	3	main
suur	doc_767882159229_item	3588779	et	3	main
rahvapidu	doc_767882159229_item	3588780	et	4	main
kuhu	doc_767882159229_item	3588781	et	3	main
tullakse	doc_767882159229_item	3588782	et	3	main
koos	doc_767882159229_item	3588783	et	4	main
perega	doc_767882159229_item	3588784	et	3	main
lootuses	doc_767882159229_item	3588785	et	4	main
kohata	doc_767882159229_item	3588786	et	4	main
sõpru	doc_767882159229_item	3588787	et	3	main
sugulasi	doc_767882159229_item	3588788	et	3	main
ja	doc_767882159229_item	3588789	et	3	main
tuttavaid	doc_767882159229_item	3588790	et	3	main
kui	doc_767882159234_item	3588802	et	3	main
kirjutamine	doc_767882159234_item	3588806	et	4	main
sõna	doc_767882159234_item	3588818	et	4	main
analüüsiv	doc_767882159234_item	3588823	et	4	main
ja	doc_767882159234_item	3588824	et	3	main
üldistav	doc_767882159234_item	3588825	et	4	main
tuginema	doc_767882159234_item	3588826	et	3	main
lugemistekstis	doc_767882159234_item	3588829	et	3	main
lauluväljakul	doc_767882159234_item	3588837	et	3	main
palju	doc_767882159234_item	3588839	et	4	main
kõik	doc_767882159234_item	3588841	et	4	main
ei	doc_767882159234_item	3588853	et	4	main
ma	doc_767882159234_item	3588854	et	3	main
lihtsalt	doc_767882159234_item	3588855	et	4	main
voldemar	doc_767882159229_item	3588761	et	4	main
jannseniga	doc_767882159229_item	3588762	et	4	main
tänamise	doc_767882159229_item	3588764	et	4	main
lähevad	doc_767882159229_item	3588769	et	3	main
on	doc_767882159229_item	3588772	et	4	main
väga	doc_767882159229_item	3588773	et	3	main
huvitav	doc_767882159229_item	3588774	et	4	main
keele	doc_767882159234_item	3588801	et	4	main
keele	doc_767882159234_item	3588804	et	4	main
teeb	doc_767882159234_item	3588811	et	3	main
laulurahva	doc_767882159234_item	3588813	et	3	main
essee	doc_767882159234_item	3588814	et	4	main
olema	doc_767882159234_item	3588821	et	4	main
väiteid	doc_767882159234_item	3588832	et	4	main
on	doc_767882159234_item	3588842	et	4	main
rahvariietes	doc_767882159234_item	3588843	et	3	main
lätist	doc_767882159234_item	3588847	et	4	main
rootsist	doc_767882159234_item	3588848	et	3	main
soomest	doc_767882159234_item	3588849	et	3	main
algab	doc_767882159234_item	3588850	et	3	main
uus	doc_767882159234_item	3588851	et	3	main
rahvalaulupidu	doc_767882159234_item	3588852	et	4	main
peole	doc_767882159234_item	3588893	et	4	main
oma	doc_767882159234_item	3588894	et	4	main
suure	doc_767882159234_item	3588895	et	3	main
perega	doc_767882159234_item	3588896	et	3	main
et	doc_767882159234_item	3588897	et	3	main
mul	doc_767882159234_item	3588898	et	3	main
väga	doc_767882159234_item	3588900	et	3	main
ma	doc_767882159234_item	3588904	et	3	main
sugulasi	doc_767882159234_item	3588909	et	3	main
tuttavaid	doc_767882159234_item	3588911	et	3	main
naad	doc_767882159234_item	3588919	et	4	main
loodushäältega	doc_767882159234_item	3588981	et	3	main
ja	doc_767882159234_item	3588984	et	3	main
on	doc_767882159234_item	3588986	et	4	main
väga	doc_767882159234_item	3589023	et	3	main
ja	doc_767882159234_item	3589028	et	3	main
lugeda	doc_767882159234_item	3589033	et	3	main
ma	doc_767882159234_item	3589035	et	3	main
teada	doc_767882159234_item	3589037	et	3	main
põnevat	doc_767882159234_item	3589041	et	3	main
sai	doc_767882159234_item	3589048	et	4	main
kui	doc_767882159234_item	3589054	et	3	main
elan	doc_767882159234_item	3589056	et	3	main
mul	doc_767882159234_item	3589058	et	3	main
on	doc_767882159234_item	3589059	et	4	main
võimalus	doc_767882159234_item	3589060	et	3	main
minna	doc_767882159234_item	3589061	et	3	main
lauluväljakule	doc_767882159234_item	3589062	et	3	main
ja	doc_767882159234_item	3589063	et	3	main
osaleda	doc_767882159234_item	3589064	et	3	main
sellel	doc_767882159234_item	3589065	et	4	main
meeldib	doc_767882159234_item	3589071	et	3	main
eesti	doc_767882159234_item	3588800	et	4	main
kirjutage	doc_767882159234_item	3588807	et	3	main
mis	doc_767882159234_item	3588810	et	4	main
pikkus	doc_767882159234_item	3588815	et	4	main
300	doc_767882159234_item	3588816	et	2	main
350	doc_767882159234_item	3588817	et	2	main
arutlev	doc_767882159234_item	3588822	et	4	main
esitatud	doc_767882159234_item	3588830	et	4	main
on	doc_767882159234_item	3588833	et	4	main
illustreerida	doc_767882159234_item	3588835	et	3	main
unistan	doc_767882159234_item	3588856	et	3	main
elan	doc_767882159234_item	3588857	et	3	main
kasaaegses	doc_767882159234_item	3588858	et	4	main
maailmas	doc_767882159234_item	3588859	et	3	main
xix	doc_767882159234_item	3588860	et	4	main
sajandil	doc_767882159234_item	3588861	et	3	main
ikkagi	doc_767882159234_item	3588862	et	4	main
tahatsin	doc_767882159234_item	3588863	et	4	main
1928	doc_767882159234_item	3588865	et	2	main
aastal	doc_767882159234_item	3588866	et	3	main
siin	doc_767882159234_item	3588867	et	4	main
elada	doc_767882159234_item	3588864	et	3	main
tol	doc_767882159234_item	3588869	et	3	main
tallinnas	doc_767882159234_item	3588868	et	4	main
ajal	doc_767882159234_item	3588870	et	4	main
algasid	doc_767882159234_item	3588871	et	4	main
rahvalaulud	doc_767882159234_item	3588872	et	3	main
just	doc_767882159234_item	3588873	et	3	main
tallinnas	doc_767882159234_item	3588874	et	4	main
kadrioru	doc_767882159234_item	3588875	et	3	main
lauluväljakul	doc_767882159234_item	3588876	et	3	main
kui	doc_767882159234_item	3588877	et	3	main
mul	doc_767882159234_item	3588878	et	3	main
oleks	doc_767882159234_item	3588879	et	3	main
võimalus	doc_767882159234_item	3588880	et	3	main
veedaksin	doc_767882159234_item	3588881	et	3	main
terve	doc_767882159234_item	3588882	et	4	main
seal	doc_767882159234_item	3588884	et	4	main
päeva	doc_767882159234_item	3588883	et	4	main
hea	doc_767882159234_item	3588901	et	4	main
ja	doc_767882159234_item	3588910	et	3	main
arvan	doc_767882159234_item	3588912	et	3	main
sellised	doc_767882159234_item	3588914	et	4	main
ühendasid	doc_767882159234_item	3588916	et	4	main
palju	doc_767882159234_item	3588921	et	4	main
ma	doc_767882159234_item	3588924	et	3	main
saa	doc_767882159234_item	3588926	et	4	main
on	doc_767882159234_item	3588899	et	4	main
et	doc_767882159234_item	3588906	et	3	main
lähedamaks	doc_767882159234_item	3588922	et	4	main
ajal	doc_767882159234_item	3588930	et	4	main
on	doc_767882159234_item	3588933	et	4	main
mõned	doc_767882159234_item	3588936	et	3	main
toimuvad	doc_767882159234_item	3588938	et	4	main
poissid	doc_767882159234_item	3588957	et	4	main
värskast	doc_767882159234_item	3588958	et	4	main
nagu	doc_767882159234_item	3588959	et	3	main
laulavad	doc_767882159234_item	3588963	et	4	main
lastele	doc_767882159234_item	3588978	et	4	main
mõned	doc_767882159234_item	3588979	et	3	main
laul	doc_767882159234_item	3588983	et	4	main
tants	doc_767882159234_item	3588985	et	3	main
emotsionaalne	doc_767882159234_item	3588987	et	3	main
oli	doc_767882159234_item	3589030	et	3	main
mina	doc_767882159234_item	3589042	et	4	main
ei	doc_767882159234_item	3589043	et	4	main
alguse	doc_767882159234_item	3589049	et	3	main
ma	doc_767882159234_item	3589055	et	3	main
tallinnas	doc_767882159234_item	3589057	et	4	main
see	doc_767882159234_item	3589070	et	3	main
rahvalaulupeod	doc_767882159234_item	3588932	et	4	main
teistsugused	doc_767882159234_item	3588935	et	3	main
koostöös	doc_767882159234_item	3588940	et	3	main
õnnelik	doc_767882159234_item	3588946	et	3	main
noored	doc_767882159234_item	3588948	et	3	main
on	doc_767882159234_item	3588950	et	4	main
tahaksin	doc_767882159234_item	3588953	et	3	main
kuulata	doc_767882159234_item	3588954	et	4	main
kuidas	doc_767882159234_item	3588955	et	3	main
laulavad	doc_767882159234_item	3588956	et	4	main
nad	doc_767882159234_item	3588962	et	3	main
nad	doc_767882159234_item	3588967	et	3	main
olid	doc_767882159234_item	3588980	et	4	main
last	doc_767882159234_item	3588995	et	4	main
kiigutades	doc_767882159234_item	3588996	et	3	main
loomulikult	doc_767882159234_item	3588997	et	4	main
laul	doc_767882159234_item	3588998	et	4	main
aitas	doc_767882159234_item	3588999	et	3	main
inimesi	doc_767882159234_item	3589000	et	4	main
kui	doc_767882159234_item	3589001	et	3	main
mul	doc_767882159234_item	3589002	et	3	main
on	doc_767882159234_item	3589003	et	4	main
halb	doc_767882159234_item	3589004	et	3	main
tuju	doc_767882159234_item	3589005	et	4	main
ma	doc_767882159234_item	3589006	et	3	main
laulan	doc_767882159234_item	3589007	et	3	main
ka	doc_767882159234_item	3589008	et	3	main
eriti	doc_767882159234_item	3589009	et	3	main
kui	doc_767882159234_item	3589010	et	3	main
olen	doc_767882159234_item	3589011	et	3	main
üksi	doc_767882159234_item	3589012	et	4	main
kodus	doc_767882159234_item	3589013	et	4	main
tants	doc_767882159234_item	3589014	et	3	main
on	doc_767882159234_item	3589015	et	4	main
ka	doc_767882159234_item	3589016	et	3	main
väga	doc_767882159234_item	3589017	et	3	main
hea	doc_767882159234_item	3589018	et	4	main
viis	doc_767882159234_item	3589019	et	4	main
tuju	doc_767882159234_item	3589020	et	4	main
tõstma	doc_767882159234_item	3589021	et	3	main
mind	doc_767882159234_item	3589022	et	4	main
mul	doc_767882159234_item	3589029	et	3	main
huvitav	doc_767882159234_item	3589032	et	4	main
laulutraditsioonist	doc_767882159234_item	3589034	et	3	main
palju	doc_767882159234_item	3589038	et	4	main
uut	doc_767882159234_item	3589039	et	3	main
ja	doc_767882159234_item	3589040	et	3	main
juba	doc_767882159234_item	3589050	et	3	main
üritusel	doc_767882159234_item	3589066	et	4	main
olen	doc_767882159234_item	3589067	et	3	main
et	doc_767882159234_item	3589069	et	3	main
essee	doc_767882159239_item	3589352	et	4	main
keele	doc_767882159239_item	3589354	et	4	main
test	doc_767882159239_item	3589358	et	3	main
kirjutage	doc_767882159239_item	3589360	et	3	main
300	doc_767882159239_item	3589369	et	2	main
arutlev	doc_767882159239_item	3589375	et	4	main
esitatud	doc_767882159239_item	3589383	et	4	main
ööelda	doc_767882159239_item	3589393	et	4	main
miks	doc_767882159239_item	3589404	et	4	main
nad	doc_767882159239_item	3589405	et	3	main
arvavad	doc_767882159239_item	3589406	et	4	main
vale	doc_767882159239_item	3589413	et	4	main
esses	doc_767882159239_item	3589415	et	3	main
tahan	doc_767882159239_item	3589417	et	3	main
kõik	doc_767882159239_item	3589433	et	4	main
teame	doc_767882159239_item	3589434	et	3	main
rahva	doc_767882159239_item	3589435	et	3	main
laulud	doc_767882159239_item	3589436	et	3	main
sellepärast	doc_767882159239_item	3589452	et	3	main
kasutasid	doc_767882159239_item	3589454	et	4	main
rahvalaulu	doc_767882159239_item	3589463	et	4	main
ja	doc_767882159239_item	3589465	et	3	main
selline	doc_767882159239_item	3589469	et	4	main
traditsiooni	doc_767882159239_item	3589471	et	4	main
aastat	doc_767882159239_item	3589478	et	3	main
estlased	doc_767882159239_item	3589479	et	4	main
laulavad	doc_767882159239_item	3589482	et	4	main
ja	doc_767882159239_item	3589484	et	3	main
pidustavad	doc_767882159239_item	3589485	et	4	main
traditsioni	doc_767882159239_item	3589486	et	4	main
eestis	doc_767882159239_item	3589538	et	3	main
tuntud	doc_767882159239_item	3589542	et	4	main
nägu	doc_767882159239_item	3589544	et	4	main
arvo	doc_767882159239_item	3589547	et	4	main
laulda	doc_767882159239_item	3589566	et	4	main
ja	doc_767882159239_item	3589567	et	3	main
nad	doc_767882159239_item	3589574	et	3	main
kohe	doc_767882159239_item	3589627	et	4	main
mäletab	doc_767882159239_item	3589629	et	3	main
eesti	doc_767882159240_item	3589633	et	4	main
teise	doc_767882159240_item	3589636	et	4	main
eestlastest	doc_767882159240_item	3589645	et	4	main
laulurahva	doc_767882159240_item	3589646	et	3	main
teise	doc_767882159239_item	3589356	et	4	main
essee	doc_767882159239_item	3589361	et	4	main
eestlastest	doc_767882159239_item	3589365	et	4	main
laulurahva	doc_767882159239_item	3589366	et	3	main
essee	doc_767882159239_item	3589367	et	4	main
peab	doc_767882159239_item	3589373	et	4	main
üldistav	doc_767882159239_item	3589378	et	4	main
tuginema	doc_767882159239_item	3589379	et	3	main
loengus	doc_767882159239_item	3589380	et	3	main
me	doc_767882159239_item	3589392	et	4	main
et	doc_767882159239_item	3589407	et	3	main
olevad	doc_767882159239_item	3589408	et	4	main
laulurahva	doc_767882159239_item	3589409	et	3	main
muidugi	doc_767882159239_item	3589410	et	4	main
see	doc_767882159239_item	3589411	et	3	main
selles	doc_767882159239_item	3589414	et	4	main
rääkida	doc_767882159239_item	3589418	et	3	main
küsimusest	doc_767882159239_item	3589420	et	4	main
tegur	doc_767882159239_item	3589425	et	3	main
inemisi	doc_767882159239_item	3589438	et	4	main
praegu	doc_767882159239_item	3589457	et	3	main
laulu	doc_767882159239_item	3589459	et	4	main
rohkem	doc_767882159239_item	3589467	et	4	main
iga	doc_767882159239_item	3589476	et	4	main
lauluväljakul	doc_767882159239_item	3589481	et	3	main
üritus	doc_767882159239_item	3589487	et	4	main
praegu	doc_767882159239_item	3589489	et	3	main
kasutavad	doc_767882159239_item	3589519	et	4	main
eestlased	doc_767882159239_item	3589520	et	3	main
oskusi	doc_767882159239_item	3589527	et	3	main
erinevas	doc_767882159239_item	3589528	et	4	main
muusika	doc_767882159239_item	3589529	et	4	main
ja	doc_767882159239_item	3589530	et	3	main
rock	doc_767882159239_item	3589535	et	4	main
oli	doc_767882159239_item	3589539	et	3	main
kapp	doc_767882159239_item	3589546	et	3	main
requem	doc_767882159239_item	3589551	et	4	main
kirjutamine	doc_767882159239_item	3589359	et	4	main
mis	doc_767882159239_item	3589363	et	4	main
sõna	doc_767882159239_item	3589371	et	4	main
essee	doc_767882159239_item	3589372	et	4	main
analüüsiv	doc_767882159239_item	3589376	et	4	main
ja	doc_767882159239_item	3589377	et	3	main
ja	doc_767882159239_item	3589381	et	3	main
et	doc_767882159239_item	3589394	et	3	main
laulurahv	doc_767882159239_item	3589397	et	4	main
ja	doc_767882159239_item	3589403	et	3	main
alati	doc_767882159239_item	3589427	et	4	main
aitavad	doc_767882159239_item	3589437	et	4	main
või	doc_767882159239_item	3589444	et	4	main
nad	doc_767882159239_item	3589453	et	3	main
festival	doc_767882159239_item	3589464	et	3	main
festivaalid	doc_767882159239_item	3589474	et	4	main
on	doc_767882159239_item	3589495	et	4	main
laulurahv	doc_767882159239_item	3589496	et	4	main
aga	doc_767882159239_item	3589497	et	3	main
ja	doc_767882159239_item	3589524	et	3	main
laulu	doc_767882159239_item	3589531	et	4	main
jne	doc_767882159239_item	3589536	et	4	main
sündinud	doc_767882159239_item	3589540	et	4	main
sümfoonia	doc_767882159239_item	3589550	et	4	main
for	doc_767882159239_item	3589552	et	4	main
dream	doc_767882159239_item	3589554	et	4	main
on	doc_767882159239_item	3589555	et	4	main
väga	doc_767882159239_item	3589556	et	3	main
oskasid	doc_767882159239_item	3589565	et	4	main
nisugune	doc_767882159239_item	3589570	et	4	main
peasid	doc_767882159239_item	3589573	et	4	main
loomulik	doc_767882159239_item	3589614	et	3	main
kui	doc_767882159239_item	3589617	et	3	main
tavaline	doc_767882159239_item	3589618	et	4	main
eestlane	doc_767882159239_item	3589619	et	3	main
räägib	doc_767882159239_item	3589620	et	3	main
rahvas	doc_767882159239_item	3589624	et	4	main
ja	doc_767882159239_item	3589625	et	3	main
laul	doc_767882159239_item	3589626	et	4	main
laulupidu	doc_767882159239_item	3589630	et	4	main
test	doc_767882159240_item	3589638	et	3	main
essee	doc_767882159240_item	3589647	et	4	main
arutlev	doc_767882159240_item	3589655	et	4	main
analüüsiv	doc_767882159240_item	3589656	et	4	main
soovitatav	doc_767882159240_item	3589667	et	4	main
illustreerida	doc_767882159240_item	3589668	et	3	main
näidetega	doc_767882159240_item	3589669	et	3	main
kes	doc_767882159240_item	3589677	et	4	main
minuga	doc_767882159240_item	3589679	et	3	main
eestlased	doc_767882159240_item	3589684	et	3	main
miks	doc_767882159240_item	3589689	et	4	main
nimetada	doc_767882159240_item	3589694	et	3	main
eesti	doc_767882159239_item	3589353	et	4	main
kui	doc_767882159239_item	3589355	et	3	main
teemal	doc_767882159239_item	3589362	et	3	main
teeb	doc_767882159239_item	3589364	et	3	main
olema	doc_767882159239_item	3589374	et	4	main
lugemistekstis	doc_767882159239_item	3589382	et	3	main
väiteid	doc_767882159239_item	3589385	et	4	main
soovitatav	doc_767882159239_item	3589387	et	4	main
illustreerida	doc_767882159239_item	3589388	et	3	main
näidetega	doc_767882159239_item	3589389	et	3	main
kas	doc_767882159239_item	3589390	et	3	main
võime	doc_767882159239_item	3589391	et	4	main
estlased	doc_767882159239_item	3589395	et	4	main
miks	doc_767882159239_item	3589398	et	4	main
nendel	doc_767882159239_item	3589399	et	4	main
on	doc_767882159239_item	3589400	et	4	main
niisugune	doc_767882159239_item	3589401	et	3	main
sellest	doc_767882159239_item	3589419	et	4	main
rohkem	doc_767882159239_item	3589421	et	4	main
laul	doc_767882159239_item	3589422	et	4	main
on	doc_767882159239_item	3589423	et	4	main
mis	doc_767882159239_item	3589426	et	4	main
inemisi	doc_767882159239_item	3589429	et	4	main
ja	doc_767882159239_item	3589430	et	3	main
kuidas	doc_767882159239_item	3589431	et	3	main
me	doc_767882159239_item	3589432	et	4	main
laul	doc_767882159239_item	3589441	et	4	main
võib	doc_767882159239_item	3589442	et	3	main
rahuldama	doc_767882159239_item	3589443	et	3	main
laul	doc_767882159239_item	3589598	et	4	main
tants	doc_767882159239_item	3589599	et	3	main
ja	doc_767882159239_item	3589600	et	3	main
muusika	doc_767882159239_item	3589601	et	4	main
praegu	doc_767882159239_item	3589602	et	3	main
mitte	doc_767882159239_item	3589603	et	3	main
ainult	doc_767882159239_item	3589604	et	4	main
traditsioon	doc_767882159239_item	3589605	et	3	main
või	doc_767882159239_item	3589606	et	4	main
ajalo	doc_767882159239_item	3589608	et	4	main
kultuuri	doc_767882159239_item	3589607	et	4	main
aga	doc_767882159239_item	3589609	et	3	main
eluviis	doc_767882159239_item	3589610	et	3	main
praegu	doc_767882159239_item	3589612	et	3	main
ja	doc_767882159239_item	3589611	et	3	main
on	doc_767882159239_item	3589613	et	4	main
keele	doc_767882159239_item	3589357	et	4	main
pikkus	doc_767882159239_item	3589368	et	4	main
350	doc_767882159239_item	3589370	et	2	main
faktidele	doc_767882159239_item	3589384	et	3	main
on	doc_767882159239_item	3589386	et	4	main
on	doc_767882159239_item	3589396	et	4	main
status	doc_767882159239_item	3589402	et	4	main
on	doc_767882159239_item	3589412	et	4	main
ma	doc_767882159239_item	3589416	et	3	main
nisugune	doc_767882159239_item	3589424	et	4	main
kogus	doc_767882159239_item	3589428	et	4	main
koos	doc_767882159239_item	3589439	et	4	main
olla	doc_767882159239_item	3589440	et	3	main
tõusta	doc_767882159239_item	3589445	et	4	main
meie	doc_767882159239_item	3589446	et	4	main
jõudu	doc_767882159239_item	3589447	et	4	main
ja	doc_767882159239_item	3589448	et	3	main
estlased	doc_767882159239_item	3589449	et	4	main
teatsid	doc_767882159239_item	3589450	et	4	main
sellest	doc_767882159239_item	3589451	et	4	main
ja	doc_767882159239_item	3589455	et	3	main
selline	doc_767882159239_item	3589458	et	4	main
maagiat	doc_767882159239_item	3589460	et	3	main
esimene	doc_767882159239_item	3589462	et	3	main
juba	doc_767882159239_item	3589466	et	3	main
kui	doc_767882159239_item	3589468	et	3	main
juba	doc_767882159239_item	3589470	et	3	main
toimuvad	doc_767882159239_item	3589475	et	4	main
tansivad	doc_767882159239_item	3589483	et	4	main
juba	doc_767882159239_item	3589488	et	3	main
võime	doc_767882159239_item	3589491	et	4	main
juba	doc_767882159239_item	3589516	et	3	main
mitte	doc_767882159239_item	3589517	et	3	main
sajandid	doc_767882159239_item	3589518	et	3	main
stiilis	doc_767882159239_item	3589532	et	4	main
teiseks	doc_767882159239_item	3589537	et	4	main
kogumaa	doc_767882159239_item	3589541	et	4	main
inimesed	doc_767882159239_item	3589543	et	3	main
the	doc_767882159239_item	3589553	et	4	main
eile	doc_767882159239_item	3589561	et	3	main
juba	doc_767882159239_item	3589562	et	3	main
lapsepõlves	doc_767882159239_item	3589563	et	4	main
lapsed	doc_767882159239_item	3589564	et	3	main
temal	doc_767882159239_item	3589569	et	3	main
nisugused	doc_767882159239_item	3589621	et	4	main
essee	doc_767882159240_item	3589632	et	4	main
keele	doc_767882159240_item	3589634	et	4	main
kui	doc_767882159240_item	3589635	et	3	main
mis	doc_767882159240_item	3589643	et	4	main
teeb	doc_767882159240_item	3589644	et	3	main
pikkus	doc_767882159240_item	3589648	et	4	main
sõna	doc_767882159240_item	3589651	et	4	main
peab	doc_767882159240_item	3589653	et	4	main
olema	doc_767882159240_item	3589654	et	4	main
ja	doc_767882159240_item	3589657	et	3	main
lugemistekstis	doc_767882159240_item	3589662	et	3	main
ei	doc_767882159240_item	3589673	et	4	main
leia	doc_767882159240_item	3589674	et	4	main
kui	doc_767882159240_item	3589681	et	3	main
on	doc_767882159240_item	3589685	et	4	main
neid	doc_767882159240_item	3589692	et	4	main
aga	doc_767882159240_item	3589736	et	3	main
see	doc_767882159240_item	3589779	et	3	main
algus	doc_767882159240_item	3589783	et	4	main
ainult	doc_767882159240_item	3589787	et	4	main
meesterahvas	doc_767882159240_item	3589788	et	4	main
keele	doc_767882159241_item	3589817	et	4	main
test	doc_767882159241_item	3589818	et	3	main
kirjutamine	doc_767882159241_item	3589819	et	4	main
eestlastest	doc_767882159241_item	3589825	et	4	main
300	doc_767882159241_item	3589829	et	2	main
loengus	doc_767882159241_item	3589840	et	3	main
tähtsam	doc_767882159241_item	3589857	et	4	main
asi	doc_767882159241_item	3589867	et	4	main
laulupidu	doc_767882159241_item	3589880	et	4	main
olid	doc_767882159241_item	3589882	et	4	main
probleemid	doc_767882159241_item	3589883	et	3	main
tsaari	doc_767882159241_item	3589884	et	4	main
kasutavad	doc_767882159239_item	3589456	et	4	main
algas	doc_767882159239_item	3589461	et	3	main
laulupeod	doc_767882159239_item	3589472	et	4	main
ja	doc_767882159239_item	3589473	et	3	main
4	doc_767882159239_item	3589477	et	2	main
kogusevad	doc_767882159239_item	3589480	et	4	main
me	doc_767882159239_item	3589490	et	4	main
ööelda	doc_767882159239_item	3589492	et	4	main
et	doc_767882159239_item	3589493	et	3	main
estlased	doc_767882159239_item	3589494	et	4	main
seal	doc_767882159239_item	3589498	et	4	main
on	doc_767882159239_item	3589499	et	4	main
ka	doc_767882159239_item	3589500	et	3	main
teised	doc_767882159239_item	3589501	et	4	main
tegurid	doc_767882159239_item	3589502	et	3	main
mis	doc_767882159239_item	3589503	et	4	main
räägivad	doc_767882159239_item	3589504	et	3	main
et	doc_767882159239_item	3589505	et	3	main
eesti	doc_767882159239_item	3589506	et	4	main
rahv	doc_767882159239_item	3589507	et	4	main
alati	doc_767882159239_item	3589508	et	4	main
oli	doc_767882159239_item	3589509	et	3	main
laulurahvast	doc_767882159239_item	3589510	et	4	main
esiteks	doc_767882159239_item	3589511	et	3	main
ma	doc_767882159239_item	3589512	et	3	main
võin	doc_767882159239_item	3589513	et	3	main
ööelda	doc_767882159239_item	3589514	et	4	main
et	doc_767882159239_item	3589515	et	3	main
erinevaid	doc_767882159239_item	3589521	et	4	main
muusika	doc_767882159239_item	3589522	et	4	main
instrumente	doc_767882159239_item	3589523	et	3	main
proovivad	doc_767882159239_item	3589525	et	4	main
oma	doc_767882159239_item	3589526	et	4	main
näiteks	doc_767882159239_item	3589533	et	4	main
pop	doc_767882159239_item	3589534	et	4	main
artur	doc_767882159239_item	3589545	et	4	main
part	doc_767882159239_item	3589548	et	4	main
tema	doc_767882159239_item	3589549	et	4	main
ja	doc_767882159239_item	3589558	et	3	main
oli	doc_767882159239_item	3589568	et	3	main
sõnad	doc_767882159239_item	3589622	et	4	main
ka	doc_767882159239_item	3589628	et	3	main
tuntuv	doc_767882159239_item	3589557	et	4	main
teised	doc_767882159239_item	3589559	et	4	main
kolmandaks	doc_767882159239_item	3589560	et	4	main
mäng	doc_767882159239_item	3589571	et	3	main
kus	doc_767882159239_item	3589572	et	3	main
suhtlema	doc_767882159239_item	3589575	et	3	main
ainult	doc_767882159239_item	3589576	et	4	main
laulaga	doc_767882159239_item	3589577	et	4	main
lõpuks	doc_767882159239_item	3589578	et	4	main
ma	doc_767882159239_item	3589579	et	3	main
võin	doc_767882159239_item	3589580	et	3	main
ööelda	doc_767882159239_item	3589581	et	4	main
et	doc_767882159239_item	3589582	et	3	main
estlased	doc_767882159239_item	3589583	et	4	main
on	doc_767882159239_item	3589584	et	4	main
tõesti	doc_767882159239_item	3589585	et	3	main
laulurahv	doc_767882159239_item	3589586	et	4	main
aga	doc_767882159239_item	3589587	et	3	main
need	doc_767882159239_item	3589588	et	3	main
on	doc_767882159239_item	3589590	et	4	main
laulud	doc_767882159239_item	3589589	et	3	main
läbi	doc_767882159239_item	3589591	et	4	main
aja	doc_767882159239_item	3589592	et	4	main
kujunenud	doc_767882159239_item	3589593	et	4	main
rahvuslikeks	doc_767882159239_item	3589594	et	3	main
sümboliteks	doc_767882159239_item	3589595	et	3	main
nende	doc_767882159239_item	3589596	et	4	main
rahva	doc_767882159239_item	3589597	et	3	main
see	doc_767882159239_item	3589615	et	3	main
sest	doc_767882159239_item	3589616	et	4	main
nägu	doc_767882159239_item	3589623	et	4	main
keele	doc_767882159240_item	3589637	et	4	main
300	doc_767882159240_item	3589649	et	2	main
esitatud	doc_767882159240_item	3589663	et	4	main
faktidele	doc_767882159240_item	3589664	et	3	main
väiteid	doc_767882159240_item	3589665	et	4	main
hakkab	doc_767882159240_item	3589678	et	3	main
niimodi	doc_767882159240_item	3589693	et	4	main
vastus	doc_767882159240_item	3589695	et	3	main
laulda	doc_767882159240_item	3589734	et	4	main
toimus	doc_767882159240_item	3589775	et	3	main
tartus	doc_767882159240_item	3589778	et	3	main
rajanes	doc_767882159240_item	3589781	et	3	main
pärast	doc_767882159240_item	3589789	et	4	main
essee	doc_767882159241_item	3589812	et	4	main
keele	doc_767882159241_item	3589814	et	4	main
kui	doc_767882159241_item	3589815	et	3	main
kirjutage	doc_767882159241_item	3589820	et	3	main
mis	doc_767882159241_item	3589823	et	4	main
pikkus	doc_767882159241_item	3589828	et	4	main
tuginema	doc_767882159241_item	3589839	et	3	main
lugemistekstis	doc_767882159241_item	3589842	et	3	main
esitatud	doc_767882159241_item	3589843	et	4	main
faktidele	doc_767882159241_item	3589844	et	3	main
väiteid	doc_767882159241_item	3589845	et	4	main
soovitatav	doc_767882159241_item	3589847	et	4	main
kombel	doc_767882159241_item	3589864	et	4	main
ka	doc_767882159241_item	3589869	et	3	main
tartus	doc_767882159241_item	3589871	et	3	main
ja	doc_767882159240_item	3589793	et	3	main
lapsed	doc_767882159240_item	3589794	et	3	main
laulupeod	doc_767882159240_item	3589795	et	4	main
toimuvad	doc_767882159240_item	3589796	et	4	main
tänapäevani	doc_767882159240_item	3589797	et	3	main
lauluväljakul	doc_767882159240_item	3589798	et	3	main
koguneb	doc_767882159240_item	3589799	et	3	main
suur	doc_767882159240_item	3589800	et	3	main
hulk	doc_767882159240_item	3589801	et	3	main
inimesi	doc_767882159240_item	3589802	et	4	main
mis	doc_767882159240_item	3589803	et	4	main
veel	doc_767882159240_item	3589804	et	4	main
kord	doc_767882159240_item	3589805	et	4	main
näitab	doc_767882159240_item	3589806	et	3	main
et	doc_767882159240_item	3589807	et	3	main
eestlased	doc_767882159240_item	3589808	et	3	main
on	doc_767882159240_item	3589809	et	4	main
laulurahv	doc_767882159240_item	3589810	et	4	main
kirjutamine	doc_767882159240_item	3589639	et	4	main
kirjutage	doc_767882159240_item	3589640	et	3	main
essee	doc_767882159240_item	3589641	et	4	main
teemal	doc_767882159240_item	3589642	et	3	main
350	doc_767882159240_item	3589650	et	2	main
essee	doc_767882159240_item	3589652	et	4	main
üldistav	doc_767882159240_item	3589658	et	4	main
tuginema	doc_767882159240_item	3589659	et	3	main
loengus	doc_767882159240_item	3589660	et	3	main
ja	doc_767882159240_item	3589661	et	3	main
mina	doc_767882159240_item	3589670	et	4	main
usun	doc_767882159240_item	3589671	et	3	main
et	doc_767882159240_item	3589672	et	3	main
vaidlema	doc_767882159240_item	3589680	et	3	main
on	doc_767882159240_item	3589696	et	4	main
mitmepoolne	doc_767882159240_item	3589697	et	3	main
aga	doc_767882159240_item	3589698	et	3	main
püüan	doc_767882159240_item	3589699	et	3	main
vastata	doc_767882159240_item	3589700	et	4	main
iga	doc_767882159240_item	3589701	et	4	main
küsimustele	doc_767882159240_item	3589702	et	4	main
võib	doc_767882159240_item	3589703	et	3	main
leida	doc_767882159240_item	3589704	et	3	main
vastust	doc_767882159240_item	3589705	et	4	main
mitte	doc_767882159240_item	3589706	et	3	main
täpsust	doc_767882159240_item	3589707	et	4	main
aga	doc_767882159240_item	3589708	et	3	main
ikkagi	doc_767882159240_item	3589709	et	4	main
laulmine	doc_767882159240_item	3589710	et	4	main
on	doc_767882159240_item	3589711	et	4	main
vahend	doc_767882159240_item	3589712	et	3	main
mille	doc_767882159240_item	3589713	et	3	main
paljud	doc_767882159240_item	3589714	et	3	main
inimesed	doc_767882159240_item	3589715	et	3	main
kasutavad	doc_767882159240_item	3589716	et	4	main
et	doc_767882159240_item	3589717	et	3	main
välja	doc_767882159240_item	3589718	et	4	main
näidata	doc_767882159240_item	3589719	et	4	main
oma	doc_767882159240_item	3589720	et	4	main
emotsionaalset	doc_767882159240_item	3589721	et	3	main
tuju	doc_767882159240_item	3589722	et	4	main
oma	doc_767882159240_item	3589723	et	4	main
tunned	doc_767882159240_item	3589724	et	3	main
ja	doc_767882159240_item	3589725	et	3	main
mõted	doc_767882159240_item	3589726	et	4	main
mina	doc_767882159240_item	3589727	et	4	main
ei	doc_767882159240_item	3589728	et	4	main
tea	doc_767882159240_item	3589729	et	4	main
inimesi	doc_767882159240_item	3589730	et	4	main
kes	doc_767882159240_item	3589731	et	4	main
on	doc_767882159240_item	3589666	et	4	main
sellist	doc_767882159240_item	3589675	et	4	main
inimest	doc_767882159240_item	3589676	et	3	main
ma	doc_767882159240_item	3589682	et	3	main
vältin	doc_767882159240_item	3589683	et	4	main
laulurahv	doc_767882159240_item	3589686	et	4	main
tekkib	doc_767882159240_item	3589687	et	3	main
küsimus	doc_767882159240_item	3589688	et	4	main
me	doc_767882159240_item	3589690	et	4	main
saame	doc_767882159240_item	3589691	et	4	main
ei	doc_767882159240_item	3589732	et	4	main
laulupidu	doc_767882159240_item	3589774	et	4	main
1869	doc_767882159240_item	3589776	et	2	main
aastal	doc_767882159240_item	3589777	et	3	main
sündmus	doc_767882159240_item	3589780	et	3	main
aga	doc_767882159240_item	3589790	et	3	main
ka	doc_767882159240_item	3589791	et	3	main
essee	doc_767882159241_item	3589827	et	4	main
essee	doc_767882159241_item	3589832	et	4	main
olema	doc_767882159241_item	3589834	et	4	main
illustreerida	doc_767882159241_item	3589848	et	3	main
mis	doc_767882159241_item	3589850	et	4	main
teeb	doc_767882159241_item	3589851	et	3	main
eestlastest	doc_767882159241_item	3589852	et	4	main
laulurahva	doc_767882159241_item	3589853	et	3	main
minu	doc_767882159241_item	3589854	et	3	main
arust	doc_767882159241_item	3589855	et	4	main
kõigepealt	doc_767882159241_item	3589856	et	3	main
on	doc_767882159241_item	3589862	et	4	main
juba	doc_767882159241_item	3589863	et	3	main
laulamine	doc_767882159241_item	3589865	et	4	main
tähtsam	doc_767882159241_item	3589866	et	4	main
laulupid	doc_767882159241_item	3589870	et	4	main
aastal	doc_767882159241_item	3589873	et	3	main
hakkasid	doc_767882159241_item	3589877	et	4	main
tähistama	doc_767882159241_item	3589881	et	3	main
eesti	doc_767882159241_item	3589912	et	4	main
noored	doc_767882159241_item	3589930	et	3	main
ka	doc_767882159241_item	3589932	et	3	main
on	doc_767882159241_item	3589942	et	4	main
ka	doc_767882159241_item	3589943	et	3	main
populaarne	doc_767882159241_item	3589944	et	3	main
oma	doc_767882159241_item	3589953	et	4	main
eesti	doc_767882159241_item	3589966	et	4	main
on	doc_767882159241_item	3589968	et	4	main
parim	doc_767882159241_item	3589969	et	4	main
keel	doc_767882159241_item	3589970	et	4	main
arust	doc_767882159241_item	3589983	et	4	main
kõige	doc_767882159241_item	3589986	et	4	main
essee	doc_767882159243_item	3590006	et	4	main
keele	doc_767882159243_item	3590011	et	4	main
teeb	doc_767882159243_item	3590018	et	3	main
sõna	doc_767882159243_item	3590025	et	4	main
soovitatav	doc_767882159243_item	3590041	et	4	main
on	doc_767882159243_item	3590045	et	4	main
822	doc_767882159243_item	3590058	et	2	main
lauljaga	doc_767882159243_item	3590059	et	4	main
ja	doc_767882159243_item	3590060	et	3	main
5	doc_767882159243_item	3590061	et	2	main
puhkpilliorkestrit	doc_767882159243_item	3590062	et	3	main
56	doc_767882159243_item	3590063	et	2	main
kõik	doc_767882159243_item	3590078	et	4	main
ühendas	doc_767882159243_item	3590079	et	3	main
eestlast	doc_767882159243_item	3590080	et	4	main
naiskoorid	doc_767882159243_item	3590081	et	3	main
meeskoorid	doc_767882159243_item	3590082	et	4	main
poiste-	doc_767882159243_item	3590083	et	3	main
ja	doc_767882159243_item	3590084	et	3	main
tüdrukutekoorid	doc_767882159243_item	3590085	et	4	main
populaarsed	doc_767882159243_item	3590088	et	3	main
tallinna	doc_767882159243_item	3590095	et	4	main
lauluväljakule	doc_767882159243_item	3590096	et	3	main
hulgas	doc_767882159243_item	3590101	et	4	main
varem	doc_767882159240_item	3589735	et	4	main
laulavad	doc_767882159240_item	3589737	et	4	main
see	doc_767882159240_item	3589739	et	3	main
ei	doc_767882159240_item	3589740	et	4	main
sõltnud	doc_767882159240_item	3589741	et	4	main
kus	doc_767882159240_item	3589742	et	3	main
sa	doc_767882159240_item	3589743	et	3	main
oled	doc_767882159240_item	3589744	et	3	main
kellega	doc_767882159240_item	3589745	et	3	main
millega	doc_767882159240_item	3589746	et	3	main
tegeled	doc_767882159240_item	3589747	et	3	main
lauldi	doc_767882159240_item	3589748	et	3	main
alati	doc_767882159240_item	3589749	et	4	main
ja	doc_767882159240_item	3589750	et	3	main
igalpool	doc_767882159240_item	3589751	et	4	main
üksi	doc_767882159240_item	3589752	et	4	main
olles	doc_767882159240_item	3589753	et	3	main
töötades	doc_767882159240_item	3589754	et	3	main
last	doc_767882159240_item	3589755	et	4	main
kiigutades	doc_767882159240_item	3589756	et	3	main
muidugi	doc_767882159240_item	3589757	et	4	main
peodes	doc_767882159240_item	3589758	et	3	main
ja	doc_767882159240_item	3589759	et	3	main
kirikudes	doc_767882159240_item	3589760	et	4	main
ajaga	doc_767882159240_item	3589761	et	3	main
laul	doc_767882159240_item	3589762	et	4	main
muutuks	doc_767882159240_item	3589763	et	4	main
eesti	doc_767882159240_item	3589764	et	4	main
kultuuri	doc_767882159240_item	3589765	et	4	main
suureks	doc_767882159240_item	3589766	et	4	main
armasta	doc_767882159240_item	3589733	et	4	main
kõik	doc_767882159240_item	3589738	et	4	main
osaks	doc_767882159240_item	3589767	et	3	main
räägib	doc_767882159240_item	3589769	et	3	main
ka	doc_767882159240_item	3589770	et	3	main
osalema	doc_767882159240_item	3589786	et	3	main
teemal	doc_767882159241_item	3589822	et	3	main
teeb	doc_767882159241_item	3589824	et	3	main
350	doc_767882159241_item	3589830	et	2	main
peab	doc_767882159241_item	3589833	et	4	main
arutlev	doc_767882159241_item	3589835	et	4	main
analüüsiv	doc_767882159241_item	3589836	et	4	main
ja	doc_767882159241_item	3589837	et	3	main
on	doc_767882159241_item	3589846	et	4	main
estlastel	doc_767882159241_item	3589861	et	4	main
iga	doc_767882159241_item	3589878	et	4	main
venemaal	doc_767882159241_item	3589885	et	4	main
lauludes	doc_767882159241_item	3589913	et	3	main
bajaan	doc_767882159241_item	3589915	et	3	main
vene	doc_767882159241_item	3589917	et	4	main
muusika	doc_767882159241_item	3589918	et	4	main
instrument	doc_767882159241_item	3589919	et	3	main
tallinna	doc_767882159241_item	3589926	et	4	main
et	doc_767882159241_item	3589934	et	3	main
kuulata	doc_767882159241_item	3589936	et	4	main
tänapäevas	doc_767882159241_item	3589937	et	3	main
noorte	doc_767882159241_item	3589938	et	3	main
seas	doc_767882159241_item	3589939	et	4	main
rahva	doc_767882159241_item	3589940	et	3	main
lõuna	doc_767882159241_item	3589946	et	4	main
rockband	doc_767882159241_item	3589950	et	4	main
kes	doc_767882159241_item	3589951	et	4	main
keeles	doc_767882159241_item	3589956	et	4	main
ma	doc_767882159241_item	3589957	et	3	main
et	doc_767882159241_item	3589959	et	3	main
teine	doc_767882159241_item	3589960	et	3	main
tähtsam	doc_767882159241_item	3589961	et	4	main
asi	doc_767882159241_item	3589962	et	4	main
laulamiseks	doc_767882159241_item	3589971	et	4	main
et	doc_767882159241_item	3589972	et	3	main
sellest	doc_767882159240_item	3589768	et	4	main
sündinud	doc_767882159240_item	3589771	et	4	main
laulutraditsioon	doc_767882159240_item	3589772	et	3	main
esimene	doc_767882159240_item	3589773	et	3	main
laulutraditsiooni	doc_767882159240_item	3589782	et	4	main
peodes	doc_767882159240_item	3589784	et	3	main
võid	doc_767882159240_item	3589785	et	4	main
naised	doc_767882159240_item	3589792	et	3	main
kõik	doc_767882159241_item	3590000	et	4	main
see	doc_767882159241_item	3590001	et	3	main
teeb	doc_767882159241_item	3590002	et	3	main
eestlastest	doc_767882159241_item	3590003	et	4	main
laulurahvaks	doc_767882159241_item	3590004	et	3	main
eesti	doc_767882159241_item	3589813	et	4	main
teise	doc_767882159241_item	3589816	et	4	main
essee	doc_767882159241_item	3589821	et	4	main
laulurahva	doc_767882159241_item	3589826	et	3	main
sõna	doc_767882159241_item	3589831	et	4	main
üldistav	doc_767882159241_item	3589838	et	4	main
ja	doc_767882159241_item	3589841	et	3	main
näidetega	doc_767882159241_item	3589849	et	3	main
asi	doc_767882159241_item	3589858	et	4	main
on	doc_767882159241_item	3589859	et	4	main
kombed	doc_767882159241_item	3589860	et	3	main
oli	doc_767882159241_item	3589868	et	3	main
1869	doc_767882159241_item	3589872	et	2	main
selle	doc_767882159241_item	3589874	et	4	main
pärast	doc_767882159241_item	3589875	et	4	main
eestis	doc_767882159241_item	3589876	et	3	main
ja	doc_767882159241_item	3589886	et	3	main
soveti	doc_767882159241_item	3589887	et	4	main
ajal	doc_767882159241_item	3589888	et	4	main
aga	doc_767882159241_item	3589889	et	3	main
ned	doc_767882159241_item	3589890	et	4	main
ei	doc_767882159241_item	3589891	et	4	main
teha	doc_767882159241_item	3589893	et	3	main
seganud	doc_767882159241_item	3589892	et	4	main
eestlastest	doc_767882159241_item	3589894	et	4	main
laulurahvaks	doc_767882159241_item	3589895	et	3	main
muidugi	doc_767882159241_item	3589896	et	4	main
eesti	doc_767882159241_item	3589897	et	4	main
laulud	doc_767882159241_item	3589898	et	3	main
oli	doc_767882159241_item	3589899	et	3	main
muutunud	doc_767882159241_item	3589900	et	4	main
ajast	doc_767882159241_item	3589901	et	4	main
ajani	doc_767882159241_item	3589902	et	3	main
selleks	doc_767882159241_item	3589903	et	4	main
oli	doc_767882159241_item	3589904	et	3	main
mõjunud	doc_767882159241_item	3589905	et	4	main
kui	doc_767882159241_item	3589906	et	3	main
lätlased	doc_767882159241_item	3589907	et	3	main
kui	doc_767882159241_item	3589908	et	3	main
ka	doc_767882159241_item	3589909	et	3	main
venelased	doc_767882159241_item	3589910	et	3	main
näiteks	doc_767882159241_item	3589911	et	4	main
ilmunud	doc_767882159241_item	3589914	et	4	main
rahva	doc_767882159241_item	3589916	et	3	main
aasta	doc_767882159241_item	3589925	et	4	main
kui	doc_767882159241_item	3589929	et	3	main
vanemad	doc_767882159241_item	3589933	et	4	main
näiteks	doc_767882159241_item	3589945	et	4	main
laulavad	doc_767882159241_item	3589952	et	4	main
arvan	doc_767882159241_item	3589958	et	3	main
see	doc_767882159241_item	3589964	et	3	main
keeles	doc_767882159241_item	3589974	et	4	main
on	doc_767882159241_item	3589975	et	4	main
palju	doc_767882159241_item	3589976	et	4	main
täishääliku	doc_767882159241_item	3589977	et	3	main
millised	doc_767882159241_item	3589978	et	3	main
aasta	doc_767882159241_item	3589879	et	4	main
rahvalaulad	doc_767882159241_item	3589920	et	4	main
lauluväljakul	doc_767882159241_item	3589927	et	3	main
muusika	doc_767882159241_item	3589941	et	4	main
eestil	doc_767882159241_item	3589947	et	3	main
üks	doc_767882159241_item	3589949	et	3	main
settu	doc_767882159241_item	3589955	et	4	main
on	doc_767882159241_item	3589963	et	4	main
et	doc_767882159241_item	3589965	et	3	main
palju	doc_767882159241_item	3589994	et	4	main
eesti	doc_767882159243_item	3590007	et	4	main
teemal	doc_767882159243_item	3590016	et	3	main
laulurahva	doc_767882159243_item	3590020	et	3	main
300	doc_767882159243_item	3590023	et	2	main
essee	doc_767882159243_item	3590026	et	4	main
peab	doc_767882159243_item	3590027	et	4	main
olema	doc_767882159243_item	3590028	et	4	main
arutlev	doc_767882159243_item	3590029	et	4	main
näidetega	doc_767882159243_item	3590043	et	3	main
aga	doc_767882159243_item	3590070	et	3	main
see	doc_767882159243_item	3590077	et	3	main
lauljad	doc_767882159243_item	3590094	et	4	main
massiharrastuseks	doc_767882159243_item	3590103	et	3	main
seepärast	doc_767882159243_item	3590104	et	3	main
ja	doc_767882159243_item	3590174	et	3	main
seejärel	doc_767882159243_item	3590175	et	3	main
teeb	doc_767882159243_item	3590176	et	3	main
neist	doc_767882159243_item	3590177	et	4	main
kirjutamine	doc_767882159246_item	3590187	et	4	main
kirjutage	doc_767882159246_item	3590188	et	3	main
essee	doc_767882159246_item	3590189	et	4	main
pikkus	doc_767882159246_item	3590196	et	4	main
350	doc_767882159246_item	3590198	et	2	main
ja	doc_767882159246_item	3590205	et	3	main
üldistav	doc_767882159246_item	3590206	et	4	main
tuginema	doc_767882159246_item	3590207	et	3	main
esitatud	doc_767882159246_item	3590211	et	4	main
on	doc_767882159246_item	3590220	et	4	main
esteetiline	doc_767882159246_item	3590221	et	3	main
luuletusi	doc_767882159246_item	3590241	et	4	main
võib	doc_767882159246_item	3590246	et	3	main
muusikale	doc_767882159246_item	3590248	et	4	main
noorus	doc_767882159246_item	3590250	et	4	main
ilusasti	doc_767882159246_item	3590260	et	3	main
aitab	doc_767882159246_item	3590263	et	3	main
mehed	doc_767882159246_item	3590266	et	3	main
neiule	doc_767882159246_item	3590270	et	4	main
see	doc_767882159246_item	3590271	et	3	main
on	doc_767882159246_item	3590272	et	4	main
kajastub	doc_767882159246_item	3590288	et	3	main
uurimine	doc_767882159246_item	3590299	et	4	main
tuhat	doc_767882159246_item	3590311	et	4	main
aastat	doc_767882159246_item	3590312	et	3	main
tagasi	doc_767882159246_item	3590313	et	3	main
suuliselt	doc_767882159246_item	3590318	et	4	main
tuginedes	doc_767882159246_item	3590319	et	3	main
lõpe	doc_767882159246_item	3590355	et	4	main
mite	doc_767882159246_item	3590356	et	4	main
kunagi	doc_767882159246_item	3590357	et	3	main
eesti	doc_767882159246_item	3590358	et	4	main
kuid	doc_767882159246_item	3590367	et	4	main
hiljem	doc_767882159246_item	3590368	et	3	main
musitseeriti	doc_767882159246_item	3590369	et	3	main
piduõhtutel	doc_767882159246_item	3590370	et	3	main
ka	doc_767882159246_item	3590371	et	3	main
tartus	doc_767882159246_item	3590383	et	3	main
korraldamise	doc_767882159246_item	3590385	et	4	main
teostus	doc_767882159246_item	3590388	et	4	main
vanemuise	doc_767882159246_item	3590390	et	4	main
seltsist	doc_767882159246_item	3590391	et	4	main
koorilaul	doc_767882159246_item	3590396	et	4	main
massiharrastuseks	doc_767882159246_item	3590401	et	3	main
seepärast	doc_767882159246_item	3590402	et	3	main
tavalise	doc_767882159246_item	3590406	et	4	main
sõnadega	doc_767882159246_item	3590410	et	3	main
rahvas	doc_767882159246_item	3590411	et	4	main
ja	doc_767882159246_item	3590412	et	3	main
on	doc_767882159246_item	3590418	et	4	main
lootuses	doc_767882159246_item	3590427	et	4	main
tuttavaid	doc_767882159246_item	3590432	et	3	main
armastavad	doc_767882159246_item	3590447	et	4	main
on	doc_767882159241_item	3589921	et	4	main
siiamaani	doc_767882159241_item	3589922	et	3	main
populaarsed	doc_767882159241_item	3589923	et	3	main
iga	doc_767882159241_item	3589924	et	4	main
koosnevad	doc_767882159241_item	3589928	et	4	main
kui	doc_767882159241_item	3589931	et	3	main
rahvalaulu	doc_767882159241_item	3589935	et	4	main
on	doc_767882159241_item	3589948	et	4	main
emakeeles	doc_767882159241_item	3589954	et	4	main
keel	doc_767882159241_item	3589967	et	4	main
eesti	doc_767882159241_item	3589973	et	4	main
ilusam	doc_767882159241_item	3589980	et	4	main
laulda	doc_767882159241_item	3589981	et	4	main
minu	doc_767882159241_item	3589982	et	3	main
on	doc_767882159241_item	3589985	et	4	main
kaunima	doc_767882159241_item	3589995	et	4	main
kohtu	doc_767882159241_item	3589996	et	4	main
ilusad	doc_767882159241_item	3589997	et	3	main
metsad	doc_767882159241_item	3589998	et	3	main
mere	doc_767882159241_item	3589999	et	3	main
kui	doc_767882159243_item	3590009	et	3	main
kirjutamine	doc_767882159243_item	3590013	et	4	main
essee	doc_767882159243_item	3590015	et	4	main
eestlastest	doc_767882159243_item	3590019	et	4	main
ja	doc_767882159243_item	3590031	et	3	main
loengus	doc_767882159243_item	3590034	et	3	main
illustreerida	doc_767882159243_item	3590042	et	3	main
tähelepanuväärne	doc_767882159243_item	3590046	et	3	main
rahvalaulu	doc_767882159243_item	3590076	et	4	main
olid	doc_767882159243_item	3590086	et	4	main
laulupeole	doc_767882159243_item	3590097	et	4	main
loomulik	doc_767882159243_item	3590106	et	3	main
seostub	doc_767882159243_item	3590111	et	3	main
aitavad	doc_767882159241_item	3589979	et	4	main
eestlastel	doc_767882159241_item	3589984	et	4	main
paremad	doc_767882159241_item	3589987	et	4	main
tingimused	doc_767882159241_item	3589988	et	3	main
et	doc_767882159241_item	3589989	et	3	main
laulurahvaks	doc_767882159241_item	3589990	et	3	main
olla	doc_767882159241_item	3589991	et	3	main
eestis	doc_767882159241_item	3589992	et	3	main
on	doc_767882159241_item	3589993	et	4	main
keele	doc_767882159243_item	3590008	et	4	main
kirjutage	doc_767882159243_item	3590014	et	3	main
350	doc_767882159243_item	3590024	et	2	main
analüüsiv	doc_767882159243_item	3590030	et	4	main
üldistav	doc_767882159243_item	3590032	et	4	main
tuginema	doc_767882159243_item	3590033	et	3	main
lugemistekstis	doc_767882159243_item	3590036	et	3	main
palju	doc_767882159243_item	3590066	et	4	main
rahvast	doc_767882159243_item	3590067	et	4	main
esinenud	doc_767882159243_item	3590068	et	4	main
veel	doc_767882159243_item	3590071	et	4	main
korraldasid	doc_767882159243_item	3590074	et	4	main
seda	doc_767882159243_item	3590075	et	3	main
1944	doc_767882159243_item	3590089	et	2	main
juulis	doc_767882159243_item	3590091	et	3	main
kogunesid	doc_767882159243_item	3590092	et	4	main
tuhanded	doc_767882159243_item	3590093	et	3	main
kujunenud	doc_767882159243_item	3590102	et	4	main
et	doc_767882159243_item	3590107	et	3	main
jaoks	doc_767882159243_item	3590110	et	4	main
sõnadega	doc_767882159243_item	3590112	et	3	main
rahvas	doc_767882159243_item	3590113	et	4	main
test	doc_767882159246_item	3590186	et	3	main
teeb	doc_767882159246_item	3590192	et	3	main
essee	doc_767882159246_item	3590195	et	4	main
300	doc_767882159246_item	3590197	et	2	main
loengus	doc_767882159246_item	3590208	et	3	main
väiteid	doc_767882159246_item	3590213	et	4	main
ja	doc_767882159246_item	3590222	et	3	main
oma	doc_767882159246_item	3590237	et	4	main
emotsioonid	doc_767882159246_item	3590238	et	3	main
paberile	doc_767882159246_item	3590239	et	3	main
kirjutab	doc_767882159246_item	3590240	et	3	main
neid	doc_767882159246_item	3590245	et	4	main
omad	doc_767882159246_item	3590268	et	4	main
üksi	doc_767882159246_item	3590282	et	4	main
last	doc_767882159246_item	3590285	et	4	main
kiigutades	doc_767882159246_item	3590286	et	3	main
tutvumine	doc_767882159246_item	3590295	et	4	main
iseloomulik	doc_767882159246_item	3590303	et	3	main
regivärsiline	doc_767882159246_item	3590304	et	4	main
on	doc_767882159246_item	3590307	et	4	main
kujunenud	doc_767882159246_item	3590308	et	4	main
enam	doc_767882159246_item	3590309	et	4	main
kui	doc_767882159246_item	3590310	et	3	main
põlve	doc_767882159246_item	3590317	et	4	main
raske	doc_767882159246_item	3590345	et	4	main
aga	doc_767882159246_item	3590346	et	3	main
ainult	doc_767882159246_item	3590361	et	4	main
laulis	doc_767882159246_item	3590364	et	4	main
ülemaaline	doc_767882159246_item	3590379	et	4	main
laulupidu	doc_767882159246_item	3590380	et	4	main
eesotsas	doc_767882159246_item	3590392	et	4	main
johann	doc_767882159246_item	3590393	et	4	main
hulgas	doc_767882159246_item	3590399	et	4	main
et	doc_767882159246_item	3590405	et	3	main
laul	doc_767882159246_item	3590413	et	4	main
rahvapidu	doc_767882159246_item	3590422	et	4	main
kuhu	doc_767882159246_item	3590423	et	3	main
kohata	doc_767882159246_item	3590428	et	4	main
meeldivad	doc_767882159246_item	3590434	et	4	main
oma	doc_767882159246_item	3590448	et	4	main
tema	doc_767882159246_item	3590452	et	4	main
nagu	doc_767882159246_item	3590462	et	3	main
essee	doc_767882159247_item	3590485	et	4	main
laulurahva	doc_767882159247_item	3590499	et	3	main
350	doc_767882159247_item	3590503	et	2	main
analüüsiv	doc_767882159247_item	3590509	et	4	main
ja	doc_767882159247_item	3590510	et	3	main
väiteid	doc_767882159247_item	3590518	et	4	main
illustreerida	doc_767882159247_item	3590521	et	3	main
kultuurilt	doc_767882159247_item	3590552	et	3	main
omavahel	doc_767882159243_item	3590150	et	3	main
räägivad	doc_767882159243_item	3590151	et	3	main
tantsivad	doc_767882159243_item	3590152	et	4	main
laulavad	doc_767882159243_item	3590153	et	4	main
ja	doc_767882159243_item	3590154	et	3	main
lihtsalt	doc_767882159243_item	3590155	et	4	main
puhkavad	doc_767882159243_item	3590156	et	4	main
mõned	doc_767882159243_item	3590157	et	3	main
ei	doc_767882159243_item	3590158	et	4	main
saa	doc_767882159243_item	3590159	et	4	main
kokku	doc_767882159243_item	3590160	et	3	main
teine	doc_767882159243_item	3590161	et	3	main
teisega	doc_767882159243_item	3590162	et	4	main
kaua	doc_767882159243_item	3590163	et	3	main
aega	doc_767882159243_item	3590164	et	4	main
aga	doc_767882159243_item	3590165	et	3	main
nad	doc_767882159243_item	3590167	et	3	main
laulupeol	doc_767882159243_item	3590166	et	4	main
saavad	doc_767882159243_item	3590168	et	4	main
kokku	doc_767882159243_item	3590169	et	3	main
sest	doc_767882159243_item	3590170	et	4	main
laulupidu	doc_767882159243_item	3590171	et	4	main
ühendab	doc_767882159243_item	3590172	et	3	main
eestlast	doc_767882159243_item	3590173	et	4	main
teise	doc_767882159243_item	3590010	et	4	main
test	doc_767882159243_item	3590012	et	3	main
mis	doc_767882159243_item	3590017	et	4	main
essee	doc_767882159243_item	3590021	et	4	main
pikkus	doc_767882159243_item	3590022	et	4	main
ja	doc_767882159243_item	3590035	et	3	main
esitatud	doc_767882159243_item	3590037	et	4	main
faktidele	doc_767882159243_item	3590038	et	3	main
väiteid	doc_767882159243_item	3590039	et	4	main
on	doc_767882159243_item	3590040	et	4	main
laulmine	doc_767882159243_item	3590044	et	4	main
kultuurinähtus	doc_767882159243_item	3590047	et	4	main
esimene	doc_767882159243_item	3590048	et	3	main
laulupidu	doc_767882159243_item	3590049	et	4	main
1869	doc_767882159243_item	3590050	et	2	main
aastal	doc_767882159243_item	3590051	et	3	main
tartus	doc_767882159243_item	3590052	et	3	main
sellel	doc_767882159243_item	3590053	et	4	main
peol	doc_767882159243_item	3590054	et	4	main
osales	doc_767882159243_item	3590055	et	3	main
46	doc_767882159243_item	3590056	et	2	main
meeskoori	doc_767882159243_item	3590057	et	4	main
mängijaga	doc_767882159243_item	3590064	et	4	main
nii	doc_767882159243_item	3590065	et	3	main
rahvalaulu	doc_767882159243_item	3590069	et	4	main
rohkem	doc_767882159243_item	3590072	et	4	main
inimesi	doc_767882159243_item	3590073	et	4	main
alati	doc_767882159243_item	3590087	et	4	main
aasta	doc_767882159243_item	3590090	et	4	main
koorilaul	doc_767882159243_item	3590098	et	4	main
on	doc_767882159243_item	3590099	et	4	main
eestlaste	doc_767882159243_item	3590100	et	4	main
on	doc_767882159243_item	3590105	et	4	main
eestlase	doc_767882159243_item	3590109	et	3	main
essee	doc_767882159246_item	3590180	et	4	main
teemal	doc_767882159246_item	3590190	et	3	main
laulurahva	doc_767882159246_item	3590194	et	3	main
sõna	doc_767882159246_item	3590199	et	4	main
peab	doc_767882159246_item	3590201	et	4	main
ja	doc_767882159246_item	3590209	et	3	main
faktidele	doc_767882159246_item	3590212	et	3	main
on	doc_767882159246_item	3590214	et	4	main
soovitatav	doc_767882159246_item	3590215	et	4	main
illustreerida	doc_767882159246_item	3590216	et	3	main
näidetega	doc_767882159246_item	3590217	et	3	main
on	doc_767882159246_item	3590251	et	4	main
aktiivne	doc_767882159246_item	3590252	et	3	main
oma	doc_767882159246_item	3590253	et	4	main
eelistuses	doc_767882159246_item	3590254	et	4	main
rikkas	doc_767882159246_item	3590261	et	4	main
armas	doc_767882159246_item	3590262	et	3	main
võimalus	doc_767882159246_item	3590275	et	3	main
kuidas	doc_767882159246_item	3590276	et	3	main
võiksid	doc_767882159246_item	3590277	et	4	main
ilmuma	doc_767882159246_item	3590278	et	3	main
rahvalaulud	doc_767882159246_item	3590279	et	3	main
tavalise	doc_767882159243_item	3590108	et	4	main
ja	doc_767882159243_item	3590114	et	3	main
laul	doc_767882159243_item	3590115	et	4	main
kohe	doc_767882159243_item	3590116	et	4	main
ka	doc_767882159243_item	3590117	et	3	main
laulupidu	doc_767882159243_item	3590118	et	4	main
manifestatsioon	doc_767882159243_item	3590119	et	3	main
on	doc_767882159243_item	3590120	et	4	main
tähtis	doc_767882159243_item	3590121	et	4	main
ja	doc_767882159243_item	3590122	et	3	main
tõsine	doc_767882159243_item	3590123	et	4	main
sõna	doc_767882159243_item	3590124	et	4	main
üle	doc_767882159243_item	3590125	et	3	main
eestiline	doc_767882159243_item	3590126	et	3	main
laulupidu	doc_767882159243_item	3590127	et	4	main
on	doc_767882159243_item	3590128	et	4	main
ka	doc_767882159243_item	3590129	et	3	main
praegusel	doc_767882159243_item	3590130	et	3	main
ajal	doc_767882159243_item	3590131	et	4	main
kõige	doc_767882159243_item	3590132	et	4	main
tähelepanuväärsem	doc_767882159243_item	3590133	et	4	main
ja	doc_767882159243_item	3590134	et	3	main
massilisem	doc_767882159243_item	3590135	et	4	main
rahvusluse	doc_767882159243_item	3590136	et	4	main
manifestatsioon	doc_767882159243_item	3590137	et	3	main
eestis	doc_767882159243_item	3590138	et	3	main
eakas	doc_767882159243_item	3590139	et	4	main
inimestele	doc_767882159243_item	3590140	et	3	main
laulupidu	doc_767882159243_item	3590141	et	4	main
on	doc_767882159243_item	3590142	et	4	main
igaaastane	doc_767882159243_item	3590143	et	4	main
traditsioon	doc_767882159243_item	3590144	et	3	main
ja	doc_767882159243_item	3590145	et	3	main
aeg	doc_767882159243_item	3590146	et	3	main
koht	doc_767882159243_item	3590147	et	3	main
kus	doc_767882159243_item	3590148	et	3	main
nad	doc_767882159243_item	3590149	et	3	main
laulurahva	doc_767882159243_item	3590178	et	3	main
keele	doc_767882159246_item	3590185	et	4	main
mis	doc_767882159246_item	3590191	et	4	main
analüüsiv	doc_767882159246_item	3590204	et	4	main
eesti	doc_767882159246_item	3590218	et	4	main
oma	doc_767882159246_item	3590242	et	4	main
stiilis	doc_767882159246_item	3590243	et	4	main
aga	doc_767882159246_item	3590244	et	3	main
eesti	doc_767882159246_item	3590181	et	4	main
keele	doc_767882159246_item	3590182	et	4	main
kui	doc_767882159246_item	3590183	et	3	main
teise	doc_767882159246_item	3590184	et	4	main
eestlastest	doc_767882159246_item	3590193	et	4	main
essee	doc_767882159246_item	3590200	et	4	main
olema	doc_767882159246_item	3590202	et	4	main
arutlev	doc_767882159246_item	3590203	et	4	main
lugemistekstis	doc_767882159246_item	3590210	et	3	main
rahvas	doc_767882159246_item	3590219	et	4	main
emotsionaalne	doc_767882159246_item	3590223	et	3	main
kõik	doc_767882159246_item	3590224	et	4	main
emotsioonid	doc_767882159246_item	3590225	et	3	main
sündivad	doc_767882159246_item	3590226	et	4	main
ja	doc_767882159246_item	3590227	et	3	main
surivad	doc_767882159246_item	3590228	et	4	main
kunagi	doc_767882159246_item	3590229	et	3	main
ja	doc_767882159246_item	3590230	et	3	main
rahvas	doc_767882159246_item	3590231	et	4	main
või	doc_767882159246_item	3590232	et	4	main
üksik	doc_767882159246_item	3590233	et	3	main
inimene	doc_767882159246_item	3590234	et	3	main
kirjutab	doc_767882159246_item	3590235	et	3	main
kirjeldab	doc_767882159246_item	3590236	et	3	main
looma	doc_767882159246_item	3590247	et	4	main
alati	doc_767882159246_item	3590249	et	4	main
elada	doc_767882159246_item	3590255	et	3	main
harmoonias	doc_767882159246_item	3590256	et	3	main
ja	doc_767882159246_item	3590257	et	3	main
üldse	doc_767882159246_item	3590258	et	3	main
elada	doc_767882159246_item	3590259	et	3	main
noored	doc_767882159246_item	3590265	et	3	main
lauluvad	doc_767882159246_item	3590267	et	4	main
mõtted	doc_767882159246_item	3590269	et	3	main
ainult	doc_767882159246_item	3590273	et	4	main
üks	doc_767882159246_item	3590274	et	3	main
lauluvad	doc_767882159246_item	3590281	et	4	main
minevik	doc_767882159246_item	3590290	et	3	main
mistõttu	doc_767882159246_item	3590291	et	3	main
mis	doc_767882159246_item	3590306	et	4	main
uuemat	doc_767882159246_item	3590324	et	4	main
iseloomustab	doc_767882159246_item	3590326	et	4	main
kuulas	doc_767882159246_item	3590362	et	3	main
tantsu	doc_767882159246_item	3590372	et	4	main
saateks	doc_767882159246_item	3590373	et	3	main
ajaloolise	doc_767882159246_item	3590374	et	4	main
tähsusega	doc_767882159246_item	3590375	et	4	main
idee	doc_767882159246_item	3590386	et	4	main
on	doc_767882159246_item	3590403	et	4	main
eestase	doc_767882159246_item	3590407	et	4	main
jaoks	doc_767882159246_item	3590408	et	4	main
seostub	doc_767882159246_item	3590409	et	3	main
suur	doc_767882159246_item	3590421	et	3	main
tullakse	doc_767882159246_item	3590424	et	3	main
perega	doc_767882159246_item	3590426	et	3	main
sugulasi	doc_767882159246_item	3590430	et	3	main
tuttvuma	doc_767882159246_item	3590443	et	4	main
ja	doc_767882159246_item	3590444	et	3	main
muud	doc_767882159246_item	3590445	et	4	main
kuulturi	doc_767882159246_item	3590449	et	3	main
rahvalaulud	doc_767882159246_item	3590480	et	3	main
teevad	doc_767882159246_item	3590481	et	3	main
eestlastest	doc_767882159246_item	3590482	et	4	main
laulurahva	doc_767882159246_item	3590483	et	3	main
kirjutamine	doc_767882159247_item	3590492	et	4	main
kirjutage	doc_767882159247_item	3590493	et	3	main
essee	doc_767882159247_item	3590494	et	4	main
teemal	doc_767882159247_item	3590495	et	3	main
mis	doc_767882159247_item	3590496	et	4	main
pikkus	doc_767882159247_item	3590501	et	4	main
arutlev	doc_767882159247_item	3590508	et	4	main
on	doc_767882159247_item	3590519	et	4	main
laulma	doc_767882159247_item	3590525	et	3	main
laulud	doc_767882159247_item	3590554	et	3	main
koor	doc_767882159247_item	3590556	et	4	main
ja	doc_767882159247_item	3590564	et	3	main
ilmusid	doc_767882159247_item	3590568	et	4	main
eest	doc_767882159247_item	3590570	et	4	main
rahva	doc_767882159247_item	3590571	et	3	main
hulga	doc_767882159247_item	3590572	et	4	main
viimased	doc_767882159247_item	3590579	et	3	main
olid	doc_767882159247_item	3590580	et	4	main
alati	doc_767882159247_item	3590581	et	4	main
meid	doc_767882159246_item	3590264	et	4	main
nad	doc_767882159246_item	3590280	et	3	main
olles	doc_767882159246_item	3590283	et	3	main
töötades	doc_767882159246_item	3590284	et	3	main
rahvalauludes	doc_767882159246_item	3590287	et	3	main
ka	doc_767882159246_item	3590293	et	3	main
eesti	doc_767882159246_item	3590300	et	4	main
vanemat	doc_767882159246_item	3590301	et	4	main
laulutraditsioonid	doc_767882159246_item	3590302	et	3	main
neid	doc_767882159246_item	3590314	et	4	main
mälule	doc_767882159246_item	3590320	et	3	main
ja	doc_767882159246_item	3590321	et	3	main
traditsioonidele	doc_767882159246_item	3590322	et	3	main
aga	doc_767882159246_item	3590323	et	3	main
ei	doc_767882159246_item	3590354	et	4	main
muusika	doc_767882159246_item	3590365	et	4	main
mängimises	doc_767882159246_item	3590366	et	4	main
rahva	doc_767882159246_item	3590289	et	3	main
on	doc_767882159246_item	3590292	et	4	main
rahvalauluga	doc_767882159246_item	3590294	et	4	main
pisut	doc_767882159246_item	3590296	et	3	main
nagu	doc_767882159246_item	3590297	et	3	main
ajaloo	doc_767882159246_item	3590298	et	4	main
rahvalaul	doc_767882159246_item	3590305	et	4	main
pärandati	doc_767882159246_item	3590315	et	4	main
põlvest	doc_767882159246_item	3590316	et	4	main
rahvalaulu	doc_767882159246_item	3590325	et	4	main
kirjalik	doc_767882159246_item	3590327	et	3	main
ülestähendus	doc_767882159246_item	3590328	et	3	main
laululehed	doc_767882159246_item	3590329	et	3	main
ja	doc_767882159246_item	3590330	et	3	main
salmialbumid	doc_767882159246_item	3590331	et	3	main
levisid	doc_767882159246_item	3590332	et	4	main
trükitult	doc_767882159246_item	3590333	et	4	main
laulikuid	doc_767882159246_item	3590334	et	3	main
ja	doc_767882159246_item	3590335	et	3	main
salmikuid	doc_767882159246_item	3590336	et	4	main
kirjutati	doc_767882159246_item	3590337	et	3	main
ümber	doc_767882159246_item	3590338	et	3	main
ka	doc_767882159246_item	3590339	et	3	main
käsitsi	doc_767882159246_item	3590340	et	3	main
rahvalaulu	doc_767882159246_item	3590341	et	4	main
ajaloo	doc_767882159246_item	3590342	et	4	main
uurimine	doc_767882159246_item	3590343	et	4	main
on	doc_767882159246_item	3590344	et	4	main
huvitav	doc_767882159246_item	3590347	et	4	main
töö	doc_767882159246_item	3590348	et	4	main
algab	doc_767882159246_item	3590349	et	3	main
tuhandeid	doc_767882159246_item	3590350	et	3	main
aastad	doc_767882159246_item	3590351	et	3	main
tagasi	doc_767882159246_item	3590352	et	3	main
ja	doc_767882159246_item	3590353	et	3	main
rahvas	doc_767882159246_item	3590359	et	4	main
esialgu	doc_767882159246_item	3590360	et	3	main
või	doc_767882159246_item	3590363	et	4	main
sundmuseks	doc_767882159246_item	3590376	et	4	main
kujunes	doc_767882159246_item	3590377	et	3	main
esimene	doc_767882159246_item	3590378	et	3	main
1869	doc_767882159246_item	3590381	et	2	main
mille	doc_767882159246_item	3590384	et	3	main
voldemar	doc_767882159246_item	3590394	et	4	main
jannseniga	doc_767882159246_item	3590395	et	4	main
kujunenud	doc_767882159246_item	3590400	et	4	main
laulupidu	doc_767882159246_item	3590419	et	4	main
ka	doc_767882159246_item	3590420	et	3	main
ja	doc_767882159246_item	3590431	et	3	main
kõikidele	doc_767882159246_item	3590433	et	4	main
erinevad	doc_767882159246_item	3590435	et	4	main
peod	doc_767882159246_item	3590436	et	4	main
kus	doc_767882159246_item	3590437	et	3	main
võib	doc_767882159246_item	3590438	et	3	main
lahutama	doc_767882159246_item	3590439	et	3	main
lõbutsema	doc_767882159246_item	3590440	et	3	main
tantsima	doc_767882159246_item	3590441	et	3	main
laulma	doc_767882159246_item	3590442	et	3	main
ja	doc_767882159246_item	3590450	et	3	main
rahvusluse	doc_767882159246_item	3590457	et	4	main
laulupeod	doc_767882159246_item	3590458	et	4	main
aitavad	doc_767882159246_item	3590459	et	4	main
aastal	doc_767882159246_item	3590382	et	3	main
ja	doc_767882159246_item	3590387	et	3	main
tuli	doc_767882159246_item	3590389	et	4	main
on	doc_767882159246_item	3590397	et	4	main
eestlaste	doc_767882159246_item	3590398	et	4	main
loomulik	doc_767882159246_item	3590404	et	3	main
kohe	doc_767882159246_item	3590414	et	4	main
ka	doc_767882159246_item	3590415	et	3	main
laulupidu	doc_767882159246_item	3590416	et	4	main
lisaks	doc_767882159246_item	3590417	et	4	main
koos	doc_767882159246_item	3590425	et	4	main
sõpru	doc_767882159246_item	3590429	et	3	main
eestlased	doc_767882159246_item	3590446	et	3	main
ja	doc_767882159246_item	3590455	et	3	main
massiline	doc_767882159246_item	3590456	et	4	main
eestlastele	doc_767882159246_item	3590460	et	4	main
üks	doc_767882159246_item	3590463	et	3	main
suur	doc_767882159246_item	3590464	et	3	main
pere	doc_767882159246_item	3590465	et	4	main
kuid	doc_767882159246_item	3590466	et	4	main
eesti	doc_767882159246_item	3590467	et	4	main
on	doc_767882159246_item	3590468	et	4	main
väike	doc_767882159246_item	3590469	et	4	main
riik	doc_767882159246_item	3590470	et	3	main
ja	doc_767882159246_item	3590471	et	3	main
kuulturi	doc_767882159246_item	3590472	et	3	main
säilitamine	doc_767882159246_item	3590473	et	4	main
on	doc_767882159246_item	3590474	et	4	main
tähtis	doc_767882159246_item	3590475	et	4	main
nendle	doc_767882159246_item	3590476	et	4	main
ma	doc_767882159246_item	3590477	et	3	main
arvan	doc_767882159246_item	3590478	et	3	main
et	doc_767882159246_item	3590479	et	3	main
keele	doc_767882159247_item	3590490	et	4	main
test	doc_767882159247_item	3590491	et	3	main
essee	doc_767882159247_item	3590500	et	4	main
ja	doc_767882159247_item	3590514	et	3	main
soovitatav	doc_767882159247_item	3590520	et	4	main
näidetega	doc_767882159247_item	3590522	et	3	main
ammu	doc_767882159247_item	3590527	et	4	main
ajal	doc_767882159247_item	3590530	et	4	main
kui	doc_767882159247_item	3590531	et	3	main
sajandil	doc_767882159247_item	3590567	et	3	main
tööd	doc_767882159247_item	3590585	et	4	main
last	doc_767882159247_item	3590587	et	4	main
kiigutades	doc_767882159247_item	3590588	et	3	main
üksi	doc_767882159247_item	3590589	et	4	main
tuntumaid	doc_767882159247_item	3590596	et	4	main
rahvalaulupidu	doc_767882159247_item	3590640	et	4	main
sajandil	doc_767882159247_item	3590643	et	3	main
näitavad	doc_767882159247_item	3590655	et	4	main
inimestele	doc_767882159247_item	3590656	et	3	main
rahvalaulu	doc_767882159247_item	3590657	et	4	main
ja	doc_767882159247_item	3590658	et	3	main
võime	doc_767882159247_item	3590663	et	4	main
ajal	doc_767882159247_item	3590667	et	4	main
eesti	doc_767882159248_item	3590690	et	4	main
300	doc_767882159248_item	3590706	et	2	main
essee	doc_767882159248_item	3590709	et	4	main
peab	doc_767882159248_item	3590710	et	4	main
on	doc_767882159248_item	3590723	et	4	main
muusikalne	doc_767882159248_item	3590735	et	4	main
kultuur	doc_767882159248_item	3590736	et	3	main
sündis	doc_767882159248_item	3590737	et	3	main
laulavad	doc_767882159248_item	3590749	et	4	main
hoolitsevad	doc_767882159246_item	3590451	et	4	main
säilimase	doc_767882159246_item	3590453	et	4	main
eest	doc_767882159246_item	3590454	et	4	main
olla	doc_767882159246_item	3590461	et	3	main
eesti	doc_767882159247_item	3590486	et	4	main
keele	doc_767882159247_item	3590487	et	4	main
kui	doc_767882159247_item	3590488	et	3	main
teise	doc_767882159247_item	3590489	et	4	main
teeb	doc_767882159247_item	3590497	et	3	main
300	doc_767882159247_item	3590502	et	2	main
essee	doc_767882159247_item	3590505	et	4	main
üldistav	doc_767882159247_item	3590511	et	4	main
lugemistekstis	doc_767882159247_item	3590515	et	3	main
faktidele	doc_767882159247_item	3590517	et	3	main
hakkasid	doc_767882159247_item	3590524	et	4	main
väga	doc_767882159247_item	3590526	et	3	main
isegi	doc_767882159247_item	3590528	et	4	main
tol	doc_767882159247_item	3590529	et	3	main
esitavad	doc_767882159247_item	3590555	et	4	main
ja	doc_767882159247_item	3590557	et	3	main
rütmi	doc_767882159247_item	3590562	et	4	main
18	doc_767882159247_item	3590566	et	2	main
kirikulaulud	doc_767882159247_item	3590569	et	3	main
naised	doc_767882159247_item	3590573	et	3	main
laulsid	doc_767882159247_item	3590574	et	4	main
meres	doc_767882159247_item	3590582	et	3	main
meeste	doc_767882159247_item	3590593	et	4	main
rahvast	doc_767882159247_item	3590594	et	4	main
pulmast	doc_767882159247_item	3590601	et	4	main
pulmale	doc_767882159247_item	3590602	et	3	main
eestis	doc_767882159247_item	3590641	et	3	main
rahvalaulu	doc_767882159247_item	3590648	et	4	main
neid	doc_767882159247_item	3590664	et	4	main
näha	doc_767882159247_item	3590665	et	3	main
vanalinnas	doc_767882159247_item	3590669	et	4	main
saavad	doc_767882159247_item	3590671	et	4	main
nn	doc_767882159247_item	3590673	et	4	main
seal	doc_767882159247_item	3590676	et	4	main
rahvamuusika	doc_767882159247_item	3590684	et	4	main
remixid	doc_767882159247_item	3590685	et	4	main
või	doc_767882159247_item	3590686	et	4	main
ümbertöötlused	doc_767882159247_item	3590687	et	3	main
essee	doc_767882159248_item	3590689	et	4	main
keele	doc_767882159248_item	3590694	et	4	main
essee	doc_767882159248_item	3590698	et	4	main
mis	doc_767882159248_item	3590700	et	4	main
teeb	doc_767882159248_item	3590701	et	3	main
eestlastest	doc_767882159248_item	3590702	et	4	main
laulurahva	doc_767882159248_item	3590703	et	3	main
arutlev	doc_767882159248_item	3590712	et	4	main
soovitatav	doc_767882159248_item	3590724	et	4	main
eestlased	doc_767882159248_item	3590727	et	3	main
olnud	doc_767882159248_item	3590730	et	4	main
tähtis	doc_767882159248_item	3590743	et	4	main
ja	doc_767882159248_item	3590746	et	3	main
praegu	doc_767882159248_item	3590747	et	3	main
heal	doc_767882159248_item	3590754	et	3	main
vanem	doc_767882159248_item	3590757	et	4	main
rahvalaul	doc_767882159248_item	3590758	et	4	main
ka	doc_767882159248_item	3590789	et	3	main
olla	doc_767882159248_item	3590795	et	3	main
sõnad	doc_767882159248_item	3590798	et	4	main
sest	doc_767882159248_item	3590805	et	4	main
armastavad	doc_767882159248_item	3590806	et	4	main
on	doc_767882159248_item	3590809	et	4	main
oli	doc_767882159248_item	3590822	et	3	main
uus	doc_767882159248_item	3590829	et	3	main
enne	doc_767882159248_item	3590843	et	4	main
laulud	doc_767882159248_item	3590847	et	3	main
ja	doc_767882159248_item	3590859	et	3	main
lauldi	doc_767882159248_item	3590862	et	3	main
kooris	doc_767882159248_item	3590865	et	4	main
sees	doc_767882159248_item	3590867	et	4	main
regilaule	doc_767882159248_item	3590868	et	4	main
aga	doc_767882159248_item	3590892	et	3	main
xviii	doc_767882159248_item	3590893	et	4	main
eestirahvuslik	doc_767882159248_item	3590899	et	3	main
laulupeod	doc_767882159248_item	3590909	et	4	main
eestlastest	doc_767882159247_item	3590498	et	4	main
sõna	doc_767882159247_item	3590504	et	4	main
peab	doc_767882159247_item	3590506	et	4	main
olema	doc_767882159247_item	3590507	et	4	main
tuginema	doc_767882159247_item	3590512	et	3	main
loengus	doc_767882159247_item	3590513	et	3	main
esitatud	doc_767882159247_item	3590516	et	4	main
eestlased	doc_767882159247_item	3590523	et	3	main
nad	doc_767882159247_item	3590532	et	3	main
elasid	doc_767882159247_item	3590533	et	4	main
kauas	doc_767882159247_item	3590534	et	4	main
eesti	doc_767882159247_item	3590535	et	4	main
folkloor	doc_767882159247_item	3590536	et	4	main
koosneb	doc_767882159247_item	3590537	et	3	main
kolmast	doc_767882159247_item	3590538	et	3	main
osast	doc_767882159247_item	3590539	et	4	main
laulud	doc_767882159247_item	3590540	et	3	main
tantsud	doc_767882159247_item	3590541	et	3	main
ja	doc_767882159247_item	3590542	et	3	main
muusika	doc_767882159247_item	3590543	et	4	main
esimesed	doc_767882159247_item	3590544	et	3	main
rahvalaulud	doc_767882159247_item	3590545	et	3	main
nimetatakse	doc_767882159247_item	3590546	et	3	main
regivärsiliseks	doc_767882159247_item	3590547	et	4	main
lauluks	doc_767882159247_item	3590548	et	4	main
nad	doc_767882159247_item	3590549	et	3	main
tulid	doc_767882159247_item	3590550	et	4	main
läänemeresoome	doc_767882159247_item	3590551	et	3	main
need	doc_767882159247_item	3590553	et	3	main
ette	doc_767882159247_item	3590563	et	4	main
laulsid	doc_767882159247_item	3590584	et	4	main
tehes	doc_767882159247_item	3590586	et	3	main
olles	doc_767882159247_item	3590590	et	3	main
käsitöö	doc_767882159247_item	3590591	et	4	main
tehes	doc_767882159247_item	3590592	et	3	main
olid	doc_767882159247_item	3590597	et	4	main
pulmalauljad	doc_767882159247_item	3590598	et	3	main
nad	doc_767882159247_item	3590599	et	3	main
teisel	doc_767882159247_item	3590644	et	4	main
on	doc_767882159247_item	3590651	et	4	main
ansambleid	doc_767882159247_item	3590653	et	3	main
kes	doc_767882159247_item	3590654	et	4	main
kõik	doc_767882159247_item	3590662	et	4	main
tuntumaks	doc_767882159247_item	3590672	et	4	main
kuulata	doc_767882159247_item	3590680	et	4	main
laule	doc_767882159247_item	3590681	et	4	main
ja	doc_767882159247_item	3590682	et	3	main
nn	doc_767882159247_item	3590683	et	4	main
teise	doc_767882159248_item	3590693	et	4	main
test	doc_767882159248_item	3590695	et	3	main
essee	doc_767882159248_item	3590704	et	4	main
üldistav	doc_767882159248_item	3590715	et	4	main
tuginema	doc_767882159248_item	3590716	et	3	main
loengus	doc_767882159248_item	3590717	et	3	main
illustreerida	doc_767882159248_item	3590725	et	3	main
näidetega	doc_767882159248_item	3590726	et	3	main
ammu	doc_767882159248_item	3590738	et	4	main
laulmine	doc_767882159248_item	3590739	et	4	main
inimesed	doc_767882159248_item	3590744	et	3	main
laulsid	doc_767882159248_item	3590745	et	4	main
ka	doc_767882159248_item	3590748	et	3	main
eesti	doc_767882159248_item	3590756	et	4	main
huvitav	doc_767882159248_item	3590791	et	4	main
kõik	doc_767882159248_item	3590797	et	4	main
alustavad	doc_767882159248_item	3590799	et	4	main
k	doc_767882159248_item	3590800	et	4	main
tähega	doc_767882159248_item	3590801	et	3	main
eestlased	doc_767882159248_item	3590802	et	3	main
lauda	doc_767882159248_item	3590807	et	4	main
19	doc_767882159248_item	3590826	et	2	main
on	doc_767882159248_item	3590836	et	4	main
väga	doc_767882159248_item	3590837	et	3	main
ilmusid	doc_767882159248_item	3590842	et	4	main
erinevates	doc_767882159248_item	3590850	et	4	main
lauldi	doc_767882159248_item	3590857	et	3	main
bajaanit	doc_767882159248_item	3590889	et	4	main
ja	doc_767882159248_item	3590894	et	3	main
ixx	doc_767882159248_item	3590895	et	4	main
sajandi	doc_767882159248_item	3590896	et	3	main
mis	doc_767882159248_item	3590910	et	4	main
erinevad	doc_767882159248_item	3590916	et	4	main
46	doc_767882159248_item	3590922	et	2	main
on	doc_767882159248_item	3590924	et	4	main
arusaadav	doc_767882159248_item	3590925	et	4	main
sest	doc_767882159248_item	3590931	et	4	main
näiteks	doc_767882159248_item	3590932	et	4	main
1994	doc_767882159248_item	3590933	et	2	main
aastal	doc_767882159248_item	3590934	et	3	main
125	doc_767882159248_item	3590935	et	2	main
000	doc_767882159248_item	3590940	et	2	main
eestis	doc_767882159248_item	3590942	et	3	main
oma	doc_767882159248_item	3590966	et	4	main
rahva	doc_767882159248_item	3590967	et	3	main
laulja	doc_767882159247_item	3590558	et	4	main
lauldes	doc_767882159247_item	3590559	et	3	main
võidi	doc_767882159247_item	3590560	et	4	main
liigutada	doc_767882159247_item	3590561	et	3	main
tagapoole	doc_767882159247_item	3590565	et	4	main
rohkem	doc_767882159247_item	3590575	et	4	main
kui	doc_767882159247_item	3590576	et	3	main
mehed	doc_767882159247_item	3590577	et	3	main
sest	doc_767882159247_item	3590578	et	4	main
naised	doc_767882159247_item	3590583	et	3	main
kõige	doc_767882159247_item	3590595	et	4	main
19ndal	doc_767882159247_item	3590642	et	4	main
töötlusi	doc_767882159247_item	3590649	et	3	main
kultuuri	doc_767882159247_item	3590660	et	4	main
me	doc_767882159247_item	3590661	et	4	main
pidude	doc_767882159247_item	3590666	et	4	main
rahvamuusika	doc_767882159247_item	3590674	et	4	main
üritused	doc_767882159247_item	3590675	et	4	main
keele	doc_767882159248_item	3590691	et	4	main
kirjutamine	doc_767882159248_item	3590696	et	4	main
teemal	doc_767882159248_item	3590699	et	3	main
pikkus	doc_767882159248_item	3590705	et	4	main
sõna	doc_767882159248_item	3590708	et	4	main
analüüsiv	doc_767882159248_item	3590713	et	4	main
ja	doc_767882159248_item	3590714	et	3	main
lugemistekstis	doc_767882159248_item	3590719	et	3	main
esitatud	doc_767882159248_item	3590720	et	4	main
väiteid	doc_767882159248_item	3590722	et	4	main
on	doc_767882159248_item	3590728	et	4	main
muusikaalsed	doc_767882159248_item	3590732	et	4	main
inimesed	doc_767882159248_item	3590733	et	3	main
nende	doc_767882159248_item	3590734	et	4	main
väga	doc_767882159248_item	3590742	et	3	main
halval	doc_767882159248_item	3590751	et	3	main
kihistus	doc_767882159248_item	3590792	et	4	main
võib	doc_767882159248_item	3590794	et	3	main
on	doc_767882159248_item	3590803	et	4	main
folkloor	doc_767882159248_item	3590811	et	4	main
folklooriansamble	doc_767882159248_item	3590813	et	4	main
eesti	doc_767882159248_item	3590819	et	4	main
laulu	doc_767882159248_item	3590820	et	4	main
kultuuris	doc_767882159248_item	3590821	et	3	main
palju	doc_767882159248_item	3590823	et	4	main
mudestisi	doc_767882159248_item	3590824	et	4	main
sündis	doc_767882159248_item	3590828	et	3	main
mida	doc_767882159248_item	3590831	et	4	main
vookalse	doc_767882159248_item	3590839	et	4	main
zanri	doc_767882159248_item	3590840	et	4	main
rahvalaulu	doc_767882159248_item	3590844	et	4	main
loodushäälte	doc_767882159248_item	3590846	et	3	main
sõltus	doc_767882159248_item	3590854	et	4	main
sellest	doc_767882159248_item	3590855	et	4	main
kellega	doc_767882159248_item	3590860	et	3	main
vahel	doc_767882159248_item	3590897	et	4	main
tõuseaeg	doc_767882159248_item	3590900	et	4	main
see	doc_767882159248_item	3590904	et	3	main
et	doc_767882159248_item	3590905	et	3	main
neil	doc_767882159248_item	3590906	et	4	main
laulupeodel	doc_767882159248_item	3590914	et	3	main
koorid	doc_767882159248_item	3590917	et	4	main
aastal	doc_767882159248_item	3590920	et	3	main
meeskoori	doc_767882159248_item	3590923	et	4	main
eestlastele	doc_767882159248_item	3590930	et	4	main
tallinnas	doc_767882159248_item	3590938	et	4	main
on	doc_767882159248_item	3590943	et	4	main
ka	doc_767882159248_item	3590944	et	3	main
heliloja	doc_767882159248_item	3590945	et	4	main
oma	doc_767882159248_item	3590950	et	4	main
töödes	doc_767882159248_item	3590951	et	3	main
tema	doc_767882159248_item	3590952	et	4	main
xx	doc_767882159248_item	3590958	et	4	main
algusel	doc_767882159248_item	3590960	et	4	main
esimesed	doc_767882159248_item	3590962	et	3	main
ansamblid	doc_767882159248_item	3590963	et	3	main
eestlased	doc_767882159248_item	3590964	et	3	main
väga	doc_767882159248_item	3590992	et	3	main
populaarne	doc_767882159248_item	3590993	et	3	main
eesti	doc_767882159250_item	3591038	et	4	main
mis	doc_767882159250_item	3591048	et	4	main
teeb	doc_767882159250_item	3591049	et	3	main
essee	doc_767882159250_item	3591057	et	4	main
käisid	doc_767882159247_item	3590600	et	4	main
ja	doc_767882159247_item	3590603	et	3	main
laulsid	doc_767882159247_item	3590604	et	4	main
külalistele	doc_767882159247_item	3590605	et	4	main
viimastel	doc_767882159247_item	3590606	et	3	main
30	doc_767882159247_item	3590607	et	2	main
aastal	doc_767882159247_item	3590608	et	3	main
kasvas	doc_767882159247_item	3590609	et	3	main
huvi	doc_767882159247_item	3590610	et	4	main
folkloori	doc_767882159247_item	3590611	et	4	main
poole	doc_767882159247_item	3590612	et	4	main
hakkasid	doc_767882159247_item	3590613	et	4	main
levima	doc_767882159247_item	3590614	et	3	main
rahvamuusika	doc_767882159247_item	3590615	et	4	main
ansambleid	doc_767882159247_item	3590616	et	3	main
folkloori	doc_767882159247_item	3590617	et	4	main
peod	doc_767882159247_item	3590618	et	4	main
temaatilised	doc_767882159247_item	3590619	et	4	main
üritused	doc_767882159247_item	3590620	et	4	main
kõige	doc_767882159247_item	3590621	et	4	main
tuntum	doc_767882159247_item	3590622	et	4	main
aga	doc_767882159247_item	3590623	et	3	main
muidugi	doc_767882159247_item	3590624	et	4	main
eesti	doc_767882159247_item	3590625	et	4	main
laulupeod	doc_767882159247_item	3590626	et	4	main
esimene	doc_767882159247_item	3590627	et	3	main
laulupidu	doc_767882159247_item	3590628	et	4	main
toimus	doc_767882159247_item	3590629	et	3	main
tartus	doc_767882159247_item	3590630	et	3	main
aastal	doc_767882159247_item	3590631	et	3	main
1869	doc_767882159247_item	3590632	et	2	main
see	doc_767882159247_item	3590633	et	3	main
on	doc_767882159247_item	3590634	et	4	main
tänapäevani	doc_767882159247_item	3590635	et	3	main
kõige	doc_767882159247_item	3590636	et	4	main
tähelepanuväärsem	doc_767882159247_item	3590637	et	4	main
ja	doc_767882159247_item	3590638	et	3	main
massilisem	doc_767882159247_item	3590639	et	4	main
poolel	doc_767882159247_item	3590645	et	4	main
hakkasid	doc_767882159247_item	3590646	et	4	main
heliloojad	doc_767882159247_item	3590647	et	3	main
täna	doc_767882159247_item	3590650	et	4	main
palju	doc_767882159247_item	3590652	et	4	main
tantsu	doc_767882159247_item	3590659	et	4	main
vabaõhumuuseumis	doc_767882159247_item	3590668	et	3	main
praegu	doc_767882159247_item	3590670	et	3	main
on	doc_767882159247_item	3590677	et	4	main
võimalik	doc_767882159247_item	3590678	et	3	main
muinasjutte	doc_767882159247_item	3590679	et	3	main
et	doc_767882159248_item	3591012	et	3	main
nad	doc_767882159248_item	3591013	et	3	main
alati	doc_767882159248_item	3591014	et	4	main
teevad	doc_767882159248_item	3591015	et	3	main
midagi	doc_767882159248_item	3591016	et	4	main
uut	doc_767882159248_item	3591017	et	3	main
näiteks	doc_767882159248_item	3591018	et	4	main
poistebänd	doc_767882159248_item	3591019	et	3	main
kus	doc_767882159248_item	3591020	et	3	main
poisid	doc_767882159248_item	3591021	et	4	main
laulavad	doc_767882159248_item	3591022	et	4	main
setu	doc_767882159248_item	3591023	et	4	main
keeles	doc_767882159248_item	3591024	et	4	main
rahvalaulu	doc_767882159248_item	3591025	et	4	main
koos	doc_767882159248_item	3591026	et	4	main
rock	doc_767882159248_item	3591027	et	4	main
muusikaga	doc_767882159248_item	3591028	et	3	main
erinevat	doc_767882159248_item	3591029	et	4	main
folkloori	doc_767882159248_item	3591030	et	4	main
festivaalid	doc_767882159248_item	3591031	et	4	main
ja	doc_767882159248_item	3591032	et	3	main
esimene	doc_767882159248_item	3591033	et	3	main
koht	doc_767882159248_item	3591034	et	3	main
eurovisioonil	doc_767882159248_item	3591035	et	3	main
kui	doc_767882159248_item	3590692	et	3	main
kirjutage	doc_767882159248_item	3590697	et	3	main
350	doc_767882159248_item	3590707	et	2	main
olema	doc_767882159248_item	3590711	et	4	main
ja	doc_767882159248_item	3590718	et	3	main
faktidele	doc_767882159248_item	3590721	et	3	main
alati	doc_767882159248_item	3590729	et	4	main
väga	doc_767882159248_item	3590731	et	3	main
on	doc_767882159248_item	3590740	et	4	main
eestlaseks	doc_767882159248_item	3590741	et	3	main
nii	doc_767882159248_item	3590750	et	3	main
kui	doc_767882159248_item	3590752	et	3	main
on	doc_767882159248_item	3590759	et	4	main
regilaul	doc_767882159248_item	3590760	et	4	main
mida	doc_767882159248_item	3590761	et	4	main
lauldi	doc_767882159248_item	3590762	et	3	main
eeslaulja	doc_767882159248_item	3590763	et	4	main
ja	doc_767882159248_item	3590764	et	3	main
koor	doc_767882159248_item	3590765	et	4	main
vaheldumisi	doc_767882159248_item	3590766	et	4	main
eesti	doc_767882159248_item	3590767	et	4	main
folkloor	doc_767882159248_item	3590768	et	4	main
kosneb	doc_767882159248_item	3590769	et	4	main
laulust	doc_767882159248_item	3590770	et	4	main
pillinemisest	doc_767882159248_item	3590771	et	4	main
ja	doc_767882159248_item	3590772	et	3	main
tantsust	doc_767882159248_item	3590773	et	3	main
laulad	doc_767882159248_item	3590774	et	3	main
eesti	doc_767882159248_item	3590775	et	4	main
võivad	doc_767882159248_item	3590777	et	4	main
olla	doc_767882159248_item	3590778	et	3	main
folklooris	doc_767882159248_item	3590776	et	4	main
erinevad	doc_767882159248_item	3590779	et	4	main
näiteks	doc_767882159248_item	3590780	et	4	main
on	doc_767882159248_item	3590781	et	4	main
rahvalaul	doc_767882159248_item	3590782	et	4	main
regilaul	doc_767882159248_item	3590783	et	4	main
rahvamaie	doc_767882159248_item	3590784	et	4	main
male	doc_767882159248_item	3590785	et	4	main
jne	doc_767882159248_item	3590786	et	4	main
lauludes	doc_767882159248_item	3590787	et	3	main
on	doc_767882159248_item	3590788	et	4	main
väga	doc_767882159248_item	3590790	et	3	main
et	doc_767882159248_item	3590796	et	3	main
rikkas	doc_767882159248_item	3590810	et	4	main
laulupeod	doc_767882159248_item	3590818	et	4	main
näiteks	doc_767882159248_item	3590825	et	4	main
palju	doc_767882159248_item	3590838	et	4	main
moodis	doc_767882159248_item	3590851	et	4	main
ja	doc_767882159248_item	3590852	et	3	main
see	doc_767882159248_item	3590853	et	3	main
kus	doc_767882159248_item	3590858	et	3	main
ka	doc_767882159248_item	3590753	et	3	main
ajal	doc_767882159248_item	3590755	et	4	main
et	doc_767882159248_item	3590793	et	3	main
laulurahvas	doc_767882159248_item	3590804	et	4	main
neil	doc_767882159248_item	3590808	et	4	main
palju	doc_767882159248_item	3590812	et	4	main
ja	doc_767882159248_item	3590814	et	3	main
just	doc_767882159248_item	3590815	et	3	main
eestlastel	doc_767882159248_item	3590816	et	4	main
on	doc_767882159248_item	3590817	et	4	main
sajandil	doc_767882159248_item	3590827	et	3	main
rahvalaul	doc_767882159248_item	3590830	et	4	main
lauldi	doc_767882159248_item	3590832	et	3	main
ainult	doc_767882159248_item	3590833	et	4	main
kiirikus	doc_767882159248_item	3590834	et	3	main
arhiivides	doc_767882159248_item	3590835	et	3	main
mis	doc_767882159248_item	3590841	et	4	main
lastelaulud	doc_767882159248_item	3590845	et	3	main
rahvas	doc_767882159248_item	3590848	et	4	main
laulis	doc_767882159248_item	3590849	et	4	main
miks	doc_767882159248_item	3590856	et	4	main
üksi	doc_767882159248_item	3590863	et	4	main
kahekesi	doc_767882159248_item	3590864	et	3	main
laulsid	doc_767882159248_item	3590869	et	4	main
põhiliselt	doc_767882159248_item	3590870	et	4	main
naised	doc_767882159248_item	3590871	et	3	main
saartel	doc_767882159248_item	3590872	et	3	main
mehed	doc_767882159248_item	3590874	et	3	main
riikilaule	doc_767882159248_item	3590875	et	4	main
laulsid	doc_767882159248_item	3590873	et	4	main
lauldi	doc_767882159248_item	3590876	et	3	main
vokaalselt	doc_767882159248_item	3590877	et	4	main
ilma	doc_767882159248_item	3590878	et	4	main
instrumentita	doc_767882159248_item	3590879	et	4	main
xx	doc_767882159248_item	3590880	et	4	main
sajandil	doc_767882159248_item	3590881	et	3	main
ilmus	doc_767882159248_item	3590882	et	4	main
uus	doc_767882159248_item	3590883	et	3	main
rahvalaul	doc_767882159248_item	3590884	et	4	main
juba	doc_767882159248_item	3590885	et	3	main
mängiti	doc_767882159248_item	3590886	et	3	main
ka	doc_767882159248_item	3590887	et	3	main
vene	doc_767882159248_item	3590888	et	4	main
ilmusid	doc_767882159248_item	3590907	et	4	main
rahvuslikud	doc_767882159248_item	3590908	et	3	main
esinevad	doc_767882159248_item	3590915	et	4	main
näiteks	doc_767882159248_item	3590918	et	4	main
1869	doc_767882159248_item	3590919	et	2	main
tähtis	doc_767882159248_item	3590929	et	4	main
kes	doc_767882159248_item	3590946	et	4	main
kasutab	doc_767882159248_item	3590947	et	3	main
nimi	doc_767882159248_item	3590953	et	3	main
on	doc_767882159248_item	3590954	et	4	main
sajandi	doc_767882159248_item	3590959	et	3	main
lauldi	doc_767882159248_item	3590989	et	3	main
peol	doc_767882159248_item	3590991	et	4	main
ja	doc_767882159248_item	3590996	et	3	main
pop	doc_767882159248_item	3591000	et	4	main
ja	doc_767882159248_item	3591001	et	3	main
essee	doc_767882159250_item	3591037	et	4	main
eestlastest	doc_767882159250_item	3591050	et	4	main
peab	doc_767882159250_item	3591058	et	4	main
analüüsiv	doc_767882159250_item	3591061	et	4	main
tuginema	doc_767882159250_item	3591064	et	3	main
lauldi	doc_767882159248_item	3590861	et	3	main
ringide	doc_767882159248_item	3590866	et	3	main
ja	doc_767882159248_item	3590890	et	3	main
kannelit	doc_767882159248_item	3590891	et	4	main
oli	doc_767882159248_item	3590898	et	3	main
eestlastest	doc_767882159248_item	3590901	et	4	main
laulurahva	doc_767882159248_item	3590902	et	3	main
teeb	doc_767882159248_item	3590903	et	3	main
on	doc_767882159248_item	3590911	et	4	main
juba	doc_767882159248_item	3590912	et	3	main
traditsioon	doc_767882159248_item	3590913	et	3	main
esinesid	doc_767882159248_item	3590921	et	4	main
on	doc_767882159248_item	3590928	et	4	main
laulupeol	doc_767882159248_item	3590936	et	4	main
esitas	doc_767882159248_item	3590937	et	3	main
palju	doc_767882159248_item	3590948	et	4	main
v	doc_767882159248_item	3590955	et	4	main
juba	doc_767882159248_item	3590957	et	3	main
ilmusid	doc_767882159248_item	3590961	et	4	main
esitasid	doc_767882159248_item	3590965	et	4	main
ja	doc_767882159248_item	3590969	et	3	main
tantsu	doc_767882159248_item	3590970	et	4	main
ka	doc_767882159248_item	3590971	et	3	main
välismaale	doc_767882159248_item	3590972	et	4	main
laulmine	doc_767882159248_item	3590973	et	4	main
oli	doc_767882159248_item	3590974	et	3	main
alati	doc_767882159248_item	3590975	et	4	main
tähtis	doc_767882159248_item	3590976	et	4	main
emad	doc_767882159248_item	3590978	et	3	main
sest	doc_767882159248_item	3590977	et	4	main
laulsid	doc_767882159248_item	3590979	et	4	main
oma	doc_767882159248_item	3590980	et	4	main
lastele	doc_767882159248_item	3590981	et	4	main
lauldi	doc_767882159248_item	3590982	et	3	main
ka	doc_767882159248_item	3590983	et	3	main
tööl	doc_767882159248_item	3590984	et	3	main
lapsed	doc_767882159248_item	3590985	et	3	main
laulsid	doc_767882159248_item	3590986	et	4	main
alati	doc_767882159248_item	3590987	et	4	main
mängides	doc_767882159248_item	3590988	et	4	main
ka	doc_767882159248_item	3590990	et	3	main
on	doc_767882159248_item	3590994	et	4	main
ka	doc_767882159248_item	3590999	et	3	main
rock	doc_767882159248_item	3591002	et	4	main
muusika	doc_767882159248_item	3591003	et	4	main
ma	doc_767882159248_item	3591004	et	3	main
arvan	doc_767882159248_item	3591005	et	3	main
keele	doc_767882159250_item	3591039	et	4	main
olema	doc_767882159250_item	3591059	et	4	main
faktidele	doc_767882159250_item	3591069	et	3	main
on	doc_767882159250_item	3591071	et	4	main
soovitatav	doc_767882159250_item	3591072	et	4	main
illustreerida	doc_767882159250_item	3591073	et	3	main
näidetega	doc_767882159250_item	3591074	et	3	main
praegu	doc_767882159250_item	3591075	et	3	main
omapärane	doc_767882159250_item	3591082	et	4	main
kultuur	doc_767882159250_item	3591083	et	3	main
ajalugu	doc_767882159250_item	3591090	et	4	main
ammu	doc_767882159250_item	3591099	et	4	main
et	doc_767882159248_item	3590926	et	3	main
laulmine	doc_767882159248_item	3590927	et	4	main
25	doc_767882159248_item	3590939	et	2	main
esinejat	doc_767882159248_item	3590941	et	4	main
rahvalaule	doc_767882159248_item	3590949	et	4	main
tormis	doc_767882159248_item	3590956	et	3	main
laulu	doc_767882159248_item	3590968	et	4	main
noorte	doc_767882159248_item	3590997	et	3	main
kui	doc_767882159250_item	3591040	et	3	main
test	doc_767882159250_item	3591043	et	3	main
laulurahva	doc_767882159250_item	3591051	et	3	main
essee	doc_767882159250_item	3591052	et	4	main
pikkus	doc_767882159250_item	3591053	et	4	main
300	doc_767882159250_item	3591054	et	2	main
350	doc_767882159250_item	3591055	et	2	main
ja	doc_767882159250_item	3591062	et	3	main
lugemistekstis	doc_767882159250_item	3591067	et	3	main
on	doc_767882159250_item	3591077	et	4	main
vaba	doc_767882159250_item	3591078	et	4	main
riik	doc_767882159250_item	3591079	et	3	main
on	doc_767882159250_item	3591087	et	4	main
kujunenud	doc_767882159250_item	3591093	et	4	main
rahvalauludes	doc_767882159250_item	3591094	et	3	main
eesti	doc_767882159250_item	3591095	et	4	main
kultuur	doc_767882159250_item	3591096	et	3	main
ajal	doc_767882159250_item	3591101	et	4	main
eestlased	doc_767882159250_item	3591102	et	3	main
küll	doc_767882159250_item	3591137	et	4	main
eestis	doc_767882159250_item	3591153	et	3	main
kujunes	doc_767882159250_item	3591162	et	3	main
rahvusliku	doc_767882159250_item	3591164	et	3	main
see	doc_767882159250_item	3591166	et	3	main
väga	doc_767882159250_item	3591168	et	3	main
muusikaline	doc_767882159250_item	3591170	et	4	main
korraldamisele	doc_767882159250_item	3591177	et	4	main
sajandil	doc_767882159250_item	3591179	et	3	main
pärast	doc_767882159250_item	3591185	et	4	main
ja	doc_767882159250_item	3591189	et	3	main
vabadussõda	doc_767882159250_item	3591190	et	4	main
mis	doc_767882159250_item	3591195	et	4	main
aastal	doc_767882159250_item	3591202	et	3	main
korra	doc_767882159250_item	3591209	et	4	main
tingimustes	doc_767882159250_item	3591210	et	3	main
partei	doc_767882159250_item	3591212	et	4	main
pealesunnitud	doc_767882159250_item	3591226	et	4	main
propagandistlikke	doc_767882159250_item	3591227	et	3	main
rahvalaul	doc_767882159248_item	3590995	et	4	main
seas	doc_767882159248_item	3590998	et	4	main
et	doc_767882159248_item	3591006	et	3	main
eestlastest	doc_767882159248_item	3591007	et	4	main
teeb	doc_767882159248_item	3591008	et	3	main
laulurahva	doc_767882159248_item	3591009	et	3	main
ka	doc_767882159248_item	3591010	et	3	main
see	doc_767882159248_item	3591011	et	3	main
teise	doc_767882159250_item	3591041	et	4	main
keele	doc_767882159250_item	3591042	et	4	main
kirjutamine	doc_767882159250_item	3591044	et	4	main
kirjutage	doc_767882159250_item	3591045	et	3	main
essee	doc_767882159250_item	3591046	et	4	main
teemal	doc_767882159250_item	3591047	et	3	main
sõna	doc_767882159250_item	3591056	et	4	main
arutlev	doc_767882159250_item	3591060	et	4	main
loengus	doc_767882159250_item	3591065	et	3	main
eestlasel	doc_767882159250_item	3591080	et	3	main
on	doc_767882159250_item	3591081	et	4	main
üsna	doc_767882159250_item	3591088	et	3	main
suur	doc_767882159250_item	3591089	et	3	main
vanal	doc_767882159250_item	3591100	et	3	main
laulusid	doc_767882159250_item	3591104	et	3	main
näiteks	doc_767882159250_item	3591105	et	4	main
üksi	doc_767882159250_item	3591106	et	4	main
olles	doc_767882159250_item	3591107	et	3	main
töötades	doc_767882159250_item	3591108	et	3	main
last	doc_767882159250_item	3591109	et	4	main
kiigutades	doc_767882159250_item	3591110	et	3	main
nad	doc_767882159250_item	3591111	et	3	main
jagunesid	doc_767882159250_item	3591112	et	4	main
oma	doc_767882159250_item	3591113	et	4	main
probleemidega	doc_767882159250_item	3591114	et	3	main
rõõmudega	doc_767882159250_item	3591115	et	3	main
ja	doc_767882159250_item	3591116	et	3	main
avastusega	doc_767882159250_item	3591117	et	4	main
teine	doc_767882159250_item	3591118	et	3	main
teistega	doc_767882159250_item	3591119	et	4	main
lauldes	doc_767882159250_item	3591120	et	3	main
18	doc_767882159250_item	3591121	et	2	main
sajandil	doc_767882159250_item	3591122	et	3	main
muusika	doc_767882159250_item	3591123	et	4	main
mängis	doc_767882159250_item	3591124	et	3	main
suur	doc_767882159250_item	3591125	et	3	main
rolli	doc_767882159250_item	3591126	et	4	main
kirikute	doc_767882159250_item	3591127	et	4	main
jaoks	doc_767882159250_item	3591128	et	4	main
seal	doc_767882159250_item	3591129	et	4	main
koorilaulu	doc_767882159250_item	3591130	et	4	main
levikuga	doc_767882159250_item	3591131	et	3	main
kaasnes	doc_767882159250_item	3591132	et	3	main
ka	doc_767882159250_item	3591133	et	3	main
puhkpilliorkestrite	doc_767882159250_item	3591134	et	3	main
asutamine	doc_767882159250_item	3591135	et	4	main
esialgu	doc_767882159250_item	3591136	et	3	main
ärkamine	doc_767882159250_item	3591152	et	4	main
üldistav	doc_767882159250_item	3591063	et	4	main
eesti	doc_767882159250_item	3591076	et	4	main
oma	doc_767882159250_item	3591084	et	4	main
sündi	doc_767882159250_item	3591097	et	4	main
väga	doc_767882159250_item	3591098	et	3	main
tihti	doc_767882159250_item	3591103	et	3	main
rahvuslik	doc_767882159250_item	3591151	et	3	main
sellest	doc_767882159250_item	3591161	et	4	main
sündmus	doc_767882159250_item	3591171	et	3	main
oli	doc_767882159250_item	3591181	et	3	main
sündmusi	doc_767882159250_item	3591184	et	3	main
lauluväljakul	doc_767882159250_item	3591199	et	3	main
xii	doc_767882159250_item	3591204	et	4	main
kommunistliku	doc_767882159250_item	3591211	et	3	main
valitsuse	doc_767882159250_item	3591214	et	4	main
range	doc_767882159250_item	3591215	et	4	main
osas	doc_767882159250_item	3591218	et	4	main
reeglid	doc_767882159250_item	3591221	et	3	main
laule	doc_767882159250_item	3591228	et	4	main
praegu	doc_767882159250_item	3591229	et	3	main
kujunesid	doc_767882159250_item	3591239	et	4	main
on	doc_767882159250_item	3591246	et	4	main
komposiitorid	doc_767882159250_item	3591248	et	4	main
nagu	doc_767882159250_item	3591249	et	3	main
saar	doc_767882159250_item	3591250	et	3	main
ja	doc_767882159250_item	3591251	et	3	main
kapp	doc_767882159250_item	3591252	et	3	main
musikaks	doc_767882159250_item	3591258	et	4	main
paljud	doc_767882159250_item	3591259	et	3	main
filmides	doc_767882159250_item	3591262	et	4	main
on	doc_767882159250_item	3591266	et	4	main
essee	doc_767882159251_item	3591279	et	4	main
keele	doc_767882159251_item	3591281	et	4	main
test	doc_767882159251_item	3591285	et	3	main
sõna	doc_767882159251_item	3591298	et	4	main
analüüsiv	doc_767882159251_item	3591303	et	4	main
ja	doc_767882159251_item	3591304	et	3	main
lugemistekstis	doc_767882159251_item	3591309	et	3	main
väiteid	doc_767882159251_item	3591312	et	4	main
on	doc_767882159251_item	3591313	et	4	main
tekkinud	doc_767882159251_item	3591325	et	4	main
palju	doc_767882159251_item	3591326	et	4	main
aitavad	doc_767882159251_item	3591331	et	4	main
meile	doc_767882159251_item	3591332	et	4	main
praegu	doc_767882159251_item	3591333	et	3	main
eesti	doc_767882159251_item	3591376	et	4	main
keerulistest	doc_767882159251_item	3591389	et	4	main
veeta	doc_767882159251_item	3591395	et	4	main
palju	doc_767882159251_item	3591407	et	4	main
tähelepanu	doc_767882159251_item	3591408	et	4	main
ja	doc_767882159251_item	3591409	et	3	main
ja	doc_767882159251_item	3591415	et	3	main
teeb	doc_767882159251_item	3591417	et	3	main
neid	doc_767882159251_item	3591426	et	4	main
oma	doc_767882159251_item	3591443	et	4	main
rahvas	doc_767882159251_item	3591451	et	4	main
millega	doc_767882159251_item	3591452	et	3	main
kindlasti	doc_767882159251_item	3591458	et	3	main
eesti	doc_767882159251_item	3591461	et	4	main
kui	doc_767882159251_item	3591463	et	3	main
enam	doc_767882159251_item	3591470	et	4	main
ei	doc_767882159251_item	3591471	et	4	main
või	doc_767882159251_item	3591472	et	4	main
nii	doc_767882159251_item	3591473	et	3	main
tore	doc_767882159251_item	3591474	et	3	main
rääkib	doc_767882159251_item	3591485	et	4	main
eesti	doc_767882159251_item	3591495	et	4	main
keele	doc_767882159253_item	3591506	et	4	main
keele	doc_767882159253_item	3591509	et	4	main
kirjutamine	doc_767882159253_item	3591511	et	4	main
essee	doc_767882159253_item	3591519	et	4	main
300	doc_767882159253_item	3591521	et	2	main
soovitatav	doc_767882159253_item	3591539	et	4	main
mis	doc_767882159253_item	3591542	et	4	main
eestlastest	doc_767882159253_item	3591544	et	4	main
oma	doc_767882159253_item	3591570	et	4	main
eeslaulja	doc_767882159253_item	3591581	et	4	main
laulis	doc_767882159253_item	3591582	et	4	main
esimesena	doc_767882159253_item	3591583	et	3	main
ja	doc_767882159253_item	3591584	et	3	main
tähtis	doc_767882159253_item	3591596	et	4	main
tol	doc_767882159253_item	3591597	et	3	main
ja	doc_767882159250_item	3591066	et	3	main
esitatud	doc_767882159250_item	3591068	et	4	main
väiteid	doc_767882159250_item	3591070	et	4	main
tavad	doc_767882159250_item	3591085	et	3	main
eestimaal	doc_767882159250_item	3591086	et	4	main
mis	doc_767882159250_item	3591091	et	4	main
on	doc_767882159250_item	3591092	et	4	main
vaimuliku	doc_767882159250_item	3591138	et	3	main
mängimiseks	doc_767882159250_item	3591140	et	4	main
niimoodi	doc_767882159250_item	3591154	et	3	main
oli	doc_767882159250_item	3591158	et	3	main
laulupidu	doc_767882159250_item	3591160	et	4	main
suur	doc_767882159250_item	3591169	et	3	main
mis	doc_767882159250_item	3591172	et	4	main
pani	doc_767882159250_item	3591173	et	4	main
väga	doc_767882159250_item	3591182	et	3	main
loomist	doc_767882159250_item	3591188	et	4	main
suuruürituseks	doc_767882159250_item	3591194	et	4	main
1947	doc_767882159250_item	3591201	et	2	main
toimunud	doc_767882159250_item	3591203	et	4	main
üldlaulupeost	doc_767882159250_item	3591205	et	4	main
olid	doc_767882159250_item	3591206	et	4	main
pidustused	doc_767882159250_item	3591207	et	3	main
nõukogude	doc_767882159250_item	3591208	et	3	main
kontrolli	doc_767882159250_item	3591216	et	4	main
ja	doc_767882159250_item	3591222	et	3	main
tuli	doc_767882159250_item	3591224	et	4	main
ajalood	doc_767882159250_item	3591241	et	4	main
oma	doc_767882159250_item	3591242	et	4	main
tegis	doc_767882159250_item	3591254	et	4	main
üsna	doc_767882159250_item	3591255	et	3	main
rahvamuusika	doc_767882159250_item	3591264	et	4	main
ka	doc_767882159250_item	3591267	et	3	main
ja	doc_767882159250_item	3591268	et	3	main
eesti	doc_767882159250_item	3591269	et	4	main
pop	doc_767882159250_item	3591270	et	4	main
muusikas	doc_767882159250_item	3591271	et	3	main
keele	doc_767882159251_item	3591284	et	4	main
kirjutamine	doc_767882159251_item	3591286	et	4	main
pikkus	doc_767882159251_item	3591295	et	4	main
300	doc_767882159251_item	3591296	et	2	main
350	doc_767882159251_item	3591297	et	2	main
arutlev	doc_767882159251_item	3591302	et	4	main
ja	doc_767882159251_item	3591308	et	3	main
faktidele	doc_767882159251_item	3591311	et	3	main
kergemalt	doc_767882159251_item	3591334	et	4	main
uurida	doc_767882159251_item	3591335	et	3	main
rahva	doc_767882159251_item	3591336	et	3	main
vanad	doc_767882159251_item	3591380	et	3	main
laulasid	doc_767882159251_item	3591383	et	4	main
koos	doc_767882159251_item	3591385	et	4	main
on	doc_767882159251_item	3591393	et	4	main
meeleldivalt	doc_767882159251_item	3591396	et	4	main
suuliseid	doc_767882159251_item	3591401	et	4	main
sellepärast	doc_767882159251_item	3591403	et	3	main
kui	doc_767882159251_item	3591412	et	3	main
kooris	doc_767882159251_item	3591420	et	4	main
kirikus	doc_767882159251_item	3591421	et	3	main
on	doc_767882159251_item	3591427	et	4	main
palju	doc_767882159251_item	3591428	et	4	main
poliitiline	doc_767882159251_item	3591429	et	3	main
laulupidu	doc_767882159251_item	3591437	et	4	main
aasta	doc_767882159251_item	3591456	et	4	main
keegi	doc_767882159251_item	3591469	et	4	main
see	doc_767882159251_item	3591480	et	3	main
palju	doc_767882159251_item	3591486	et	4	main
ja	doc_767882159251_item	3591487	et	3	main
see	doc_767882159251_item	3591488	et	3	main
on	doc_767882159251_item	3591489	et	4	main
rahvas	doc_767882159251_item	3591496	et	4	main
kui	doc_767882159253_item	3591507	et	3	main
laulurahva	doc_767882159253_item	3591518	et	3	main
peab	doc_767882159253_item	3591525	et	4	main
esitatud	doc_767882159253_item	3591535	et	4	main
faktidele	doc_767882159253_item	3591536	et	3	main
väiteid	doc_767882159253_item	3591537	et	4	main
ajalugu	doc_767882159253_item	3591548	et	4	main
reegilaulu	doc_767882159253_item	3591575	et	4	main
eeslaulja	doc_767882159253_item	3591578	et	4	main
ja	doc_767882159253_item	3591579	et	3	main
koor	doc_767882159253_item	3591580	et	4	main
muusika	doc_767882159250_item	3591139	et	4	main
ja	doc_767882159250_item	3591141	et	3	main
hiljem	doc_767882159250_item	3591142	et	3	main
musitseeriti	doc_767882159250_item	3591143	et	3	main
piduõhtutel	doc_767882159250_item	3591144	et	3	main
ka	doc_767882159250_item	3591145	et	3	main
tantsu	doc_767882159250_item	3591146	et	4	main
saateks	doc_767882159250_item	3591147	et	3	main
19	doc_767882159250_item	3591148	et	2	main
sajandil	doc_767882159250_item	3591149	et	3	main
oli	doc_767882159250_item	3591150	et	3	main
1869	doc_767882159250_item	3591155	et	2	main
tartus	doc_767882159250_item	3591157	et	3	main
esimene	doc_767882159250_item	3591159	et	3	main
eestlaste	doc_767882159250_item	3591163	et	4	main
kõrghetk	doc_767882159250_item	3591165	et	3	main
oli	doc_767882159250_item	3591167	et	3	main
järgnevate	doc_767882159250_item	3591175	et	4	main
üldlaulupidude	doc_767882159250_item	3591176	et	4	main
20	doc_767882159250_item	3591178	et	2	main
vabariigi	doc_767882159250_item	3591187	et	3	main
laulupeod	doc_767882159250_item	3591192	et	4	main
muusika	doc_767882159250_item	3591193	et	4	main
alates	doc_767882159250_item	3591200	et	3	main
ja	doc_767882159250_item	3591213	et	3	main
palju	doc_767882159250_item	3591225	et	4	main
vaba	doc_767882159250_item	3591232	et	4	main
riik	doc_767882159250_item	3591233	et	3	main
eestlased	doc_767882159250_item	3591234	et	3	main
on	doc_767882159250_item	3591235	et	4	main
tõiesti	doc_767882159250_item	3591236	et	4	main
laulurahv	doc_767882159250_item	3591237	et	4	main
kes	doc_767882159250_item	3591253	et	4	main
töötasid	doc_767882159250_item	3591260	et	4	main
kui	doc_767882159251_item	3591282	et	3	main
essee	doc_767882159251_item	3591294	et	4	main
olema	doc_767882159251_item	3591301	et	4	main
loengus	doc_767882159251_item	3591307	et	3	main
esitatud	doc_767882159251_item	3591310	et	4	main
soovitatav	doc_767882159251_item	3591314	et	4	main
illustreerida	doc_767882159251_item	3591315	et	3	main
näidetega	doc_767882159251_item	3591316	et	3	main
traditsioonid	doc_767882159251_item	3591330	et	3	main
mitmest	doc_767882159251_item	3591339	et	4	main
traditsioonidest	doc_767882159251_item	3591340	et	3	main
naised	doc_767882159251_item	3591377	et	3	main
ja	doc_767882159251_item	3591378	et	3	main
ja	doc_767882159251_item	3591381	et	3	main
laulamine	doc_767882159251_item	3591384	et	4	main
aitab	doc_767882159251_item	3591386	et	3	main
parem	doc_767882159251_item	3591387	et	4	main
teha	doc_767882159251_item	3591388	et	3	main
palju	doc_767882159251_item	3591394	et	4	main
pikade	doc_767882159251_item	3591397	et	4	main
panevad	doc_767882159251_item	3591406	et	4	main
see	doc_767882159251_item	3591413	et	3	main
lastele	doc_767882159251_item	3591436	et	4	main
suurepärane	doc_767882159251_item	3591439	et	4	main
parem	doc_767882159251_item	3591449	et	4	main
eesti	doc_767882159251_item	3591450	et	4	main
tagasi	doc_767882159251_item	3591457	et	3	main
rahvast	doc_767882159251_item	3591462	et	4	main
oma	doc_767882159251_item	3591476	et	4	main
eesti	doc_767882159251_item	3591482	et	4	main
rahvas	doc_767882159251_item	3591483	et	4	main
elustiil	doc_767882159251_item	3591484	et	4	main
mis	doc_767882159251_item	3591492	et	4	main
ütleb	doc_767882159251_item	3591493	et	3	main
et	doc_767882159251_item	3591494	et	3	main
on	doc_767882159251_item	3591497	et	4	main
rahvas	doc_767882159251_item	3591498	et	4	main
oma	doc_767882159251_item	3591499	et	4	main
eesti	doc_767882159253_item	3591505	et	4	main
test	doc_767882159253_item	3591510	et	3	main
kirjutage	doc_767882159253_item	3591512	et	3	main
pikkus	doc_767882159253_item	3591520	et	4	main
aastal	doc_767882159250_item	3591156	et	3	main
aluse	doc_767882159250_item	3591174	et	4	main
eestis	doc_767882159250_item	3591180	et	3	main
palju	doc_767882159250_item	3591183	et	4	main
eesti	doc_767882159250_item	3591186	et	4	main
muutusid	doc_767882159250_item	3591191	et	4	main
toimusid	doc_767882159250_item	3591196	et	4	main
kadriorus	doc_767882159250_item	3591197	et	3	main
praegusel	doc_767882159250_item	3591198	et	3	main
repertuaari	doc_767882159250_item	3591217	et	4	main
kehtestati	doc_767882159250_item	3591219	et	3	main
ranged	doc_767882159250_item	3591220	et	3	main
laulda	doc_767882159250_item	3591223	et	4	main
eesti	doc_767882159250_item	3591230	et	4	main
on	doc_767882159250_item	3591231	et	4	main
nad	doc_767882159250_item	3591238	et	3	main
eestlaste	doc_767882159250_item	3591244	et	4	main
palju	doc_767882159250_item	3591256	et	4	main
eesti	doc_767882159250_item	3591263	et	4	main
mõju	doc_767882159250_item	3591265	et	4	main
eesti	doc_767882159251_item	3591280	et	4	main
kirjutage	doc_767882159251_item	3591287	et	3	main
mis	doc_767882159251_item	3591290	et	4	main
teeb	doc_767882159251_item	3591291	et	3	main
eestlastest	doc_767882159251_item	3591292	et	4	main
laulurahva	doc_767882159251_item	3591293	et	3	main
peab	doc_767882159251_item	3591300	et	4	main
tuginema	doc_767882159251_item	3591306	et	3	main
iga	doc_767882159251_item	3591318	et	4	main
rahvas	doc_767882159251_item	3591319	et	4	main
omab	doc_767882159251_item	3591320	et	3	main
mitmeid	doc_767882159251_item	3591321	et	4	main
traditsioone	doc_767882159251_item	3591322	et	3	main
millised	doc_767882159251_item	3591323	et	3	main
ajalugu	doc_767882159251_item	3591337	et	4	main
üks	doc_767882159251_item	3591338	et	3	main
mehed	doc_767882159251_item	3591379	et	3	main
noored	doc_767882159251_item	3591382	et	3	main
kui	doc_767882159251_item	3591391	et	3	main
teda	doc_767882159251_item	3591392	et	4	main
talveõhtu	doc_767882159251_item	3591398	et	4	main
oma	doc_767882159251_item	3591400	et	4	main
oskuseid	doc_767882159251_item	3591402	et	3	main
laulmisele	doc_767882159251_item	3591411	et	4	main
tegi	doc_767882159251_item	3591414	et	4	main
eesti	doc_767882159251_item	3591418	et	4	main
rahvas	doc_767882159251_item	3591419	et	4	main
laulupeol	doc_767882159251_item	3591422	et	4	main
isamaa	doc_767882159251_item	3591430	et	4	main
teemad	doc_767882159251_item	3591431	et	3	main
täiskasvanutele	doc_767882159251_item	3591432	et	3	main
ja	doc_767882159251_item	3591433	et	3	main
ajalugu	doc_767882159251_item	3591444	et	4	main
teadmisi	doc_767882159251_item	3591445	et	4	main
ja	doc_767882159251_item	3591446	et	3	main
kindlasti	doc_767882159251_item	3591447	et	3	main
teada	doc_767882159251_item	3591448	et	3	main
mitme	doc_767882159251_item	3591455	et	4	main
nimetada	doc_767882159251_item	3591460	et	3	main
oma	doc_767882159250_item	3591240	et	4	main
lauludes	doc_767882159250_item	3591243	et	3	main
keskel	doc_767882159250_item	3591245	et	3	main
niisugused	doc_767882159250_item	3591247	et	3	main
eesti	doc_767882159250_item	3591257	et	4	main
kasutasid	doc_767882159250_item	3591261	et	4	main
eestlased	doc_767882159250_item	3591272	et	3	main
meeldivad	doc_767882159250_item	3591273	et	4	main
oma	doc_767882159250_item	3591274	et	4	main
muusikat	doc_767882159250_item	3591275	et	3	main
oma	doc_767882159250_item	3591276	et	4	main
laulud	doc_767882159250_item	3591277	et	3	main
teise	doc_767882159251_item	3591283	et	4	main
essee	doc_767882159251_item	3591288	et	4	main
teemal	doc_767882159251_item	3591289	et	3	main
essee	doc_767882159251_item	3591299	et	4	main
üldistav	doc_767882159251_item	3591305	et	4	main
praktiliselt	doc_767882159251_item	3591317	et	4	main
on	doc_767882159251_item	3591324	et	4	main
aastat	doc_767882159251_item	3591327	et	3	main
tagasi	doc_767882159251_item	3591328	et	3	main
need	doc_767882159251_item	3591329	et	3	main
eestis	doc_767882159251_item	3591341	et	3	main
on	doc_767882159251_item	3591342	et	4	main
laulmine	doc_767882159251_item	3591343	et	4	main
teine	doc_767882159251_item	3591344	et	3	main
on	doc_767882159251_item	3591345	et	4	main
tantsimine	doc_767882159251_item	3591346	et	4	main
lihtsad	doc_767882159251_item	3591348	et	3	main
sellised	doc_767882159251_item	3591347	et	4	main
tegevused	doc_767882159251_item	3591349	et	4	main
näiteks	doc_767882159251_item	3591350	et	4	main
laulmine	doc_767882159251_item	3591351	et	4	main
või	doc_767882159251_item	3591352	et	4	main
tantsimine	doc_767882159251_item	3591353	et	4	main
annavad	doc_767882159251_item	3591354	et	3	main
teada	doc_767882159251_item	3591355	et	3	main
kuidas	doc_767882159251_item	3591356	et	3	main
toimus	doc_767882159251_item	3591357	et	3	main
eestlaste	doc_767882159251_item	3591358	et	4	main
elu	doc_767882159251_item	3591359	et	4	main
varem	doc_767882159251_item	3591360	et	4	main
ja	doc_767882159251_item	3591361	et	3	main
miks	doc_767882159251_item	3591362	et	4	main
võib	doc_767882159251_item	3591363	et	3	main
eestlastest	doc_767882159251_item	3591364	et	4	main
nimetada	doc_767882159251_item	3591365	et	3	main
laulurahvaks	doc_767882159251_item	3591366	et	3	main
töötades	doc_767882159251_item	3591367	et	3	main
põllul	doc_767882159251_item	3591368	et	3	main
ükski	doc_767882159251_item	3591369	et	4	main
olemas	doc_767882159251_item	3591371	et	4	main
kodus	doc_767882159251_item	3591370	et	4	main
koos	doc_767882159251_item	3591372	et	4	main
sõpradega	doc_767882159251_item	3591373	et	3	main
aega	doc_767882159251_item	3591374	et	4	main
veetmas	doc_767882159251_item	3591375	et	3	main
tööd	doc_767882159251_item	3591390	et	4	main
parendada	doc_767882159251_item	3591399	et	3	main
mõned	doc_767882159251_item	3591404	et	3	main
rahvad	doc_767882159251_item	3591405	et	3	main
aega	doc_767882159251_item	3591410	et	4	main
praegu	doc_767882159251_item	3591416	et	3	main
laulatakse	doc_767882159251_item	3591423	et	4	main
mitmeteemalised	doc_767882159251_item	3591424	et	4	main
laulud	doc_767882159251_item	3591425	et	3	main
muinasjuttu	doc_767882159251_item	3591434	et	4	main
teema	doc_767882159251_item	3591435	et	4	main
on	doc_767882159251_item	3591438	et	4	main
võimalus	doc_767882159251_item	3591440	et	3	main
arendamiseks	doc_767882159251_item	3591441	et	4	main
laiendada	doc_767882159251_item	3591442	et	3	main
elasid	doc_767882159251_item	3591453	et	4	main
eestlased	doc_767882159251_item	3591454	et	3	main
võib	doc_767882159251_item	3591459	et	3	main
laulura	doc_767882159251_item	3591464	et	4	main
mulle	doc_767882159251_item	3591465	et	4	main
paistaks	doc_767882159251_item	3591466	et	3	main
et	doc_767882159251_item	3591467	et	3	main
mitte	doc_767882159251_item	3591468	et	3	main
tuua	doc_767882159251_item	3591475	et	3	main
elule	doc_767882159251_item	3591477	et	3	main
laule	doc_767882159251_item	3591478	et	4	main
nagu	doc_767882159251_item	3591479	et	3	main
tegi	doc_767882159251_item	3591481	et	4	main
ajalooga	doc_767882159251_item	3591500	et	4	main
mitmest	doc_767882159251_item	3591490	et	4	main
aspektidest	doc_767882159251_item	3591491	et	3	main
oma	doc_767882159251_item	3591501	et	4	main
väärtusega	doc_767882159251_item	3591502	et	3	main
essee	doc_767882159253_item	3591504	et	4	main
eestlastest	doc_767882159253_item	3591517	et	4	main
olema	doc_767882159253_item	3591526	et	4	main
illustreerida	doc_767882159253_item	3591540	et	3	main
on	doc_767882159253_item	3591549	et	4	main
väga	doc_767882159253_item	3591550	et	3	main
esialguses	doc_767882159253_item	3591572	et	4	main
see	doc_767882159253_item	3591573	et	3	main
oli	doc_767882159253_item	3591574	et	3	main
lauldi	doc_767882159253_item	3591577	et	3	main
temaga	doc_767882159253_item	3591587	et	3	main
lauldi	doc_767882159253_item	3591590	et	3	main
ma	doc_767882159253_item	3591599	et	3	main
ütelda	doc_767882159253_item	3591602	et	4	main
et	doc_767882159253_item	3591603	et	3	main
elus	doc_767882159253_item	3591610	et	4	main
aga	doc_767882159253_item	3591616	et	3	main
vajavad	doc_767882159253_item	3591627	et	4	main
ka	doc_767882159253_item	3591634	et	3	main
oma	doc_767882159253_item	3591639	et	4	main
elust	doc_767882159253_item	3591640	et	3	main
laulis	doc_767882159253_item	3591646	et	4	main
ja	doc_767882159253_item	3591647	et	3	main
tantsis	doc_767882159253_item	3591648	et	4	main
väga	doc_767882159253_item	3591653	et	3	main
pulmalauljad	doc_767882159253_item	3591655	et	3	main
folkloor	doc_767882159253_item	3591656	et	4	main
on	doc_767882159253_item	3591657	et	4	main
rahva	doc_767882159253_item	3591662	et	3	main
ajaloo	doc_767882159253_item	3591663	et	4	main
kujutatud	doc_767882159253_item	3591668	et	4	main
rahva	doc_767882159253_item	3591669	et	3	main
elu	doc_767882159253_item	3591670	et	4	main
üldlaulupidude	doc_767882159253_item	3591727	et	4	main
20	doc_767882159253_item	3591729	et	2	main
eestil	doc_767882159253_item	3591731	et	3	main
heliloojad	doc_767882159253_item	3591735	et	3	main
ilmus	doc_767882159253_item	3591744	et	4	main
saada	doc_767882159253_item	3591746	et	4	main
muusikaalne	doc_767882159253_item	3591747	et	4	main
haridus	doc_767882159253_item	3591748	et	3	main
eestis	doc_767882159253_item	3591749	et	3	main
praegu	doc_767882159253_item	3591750	et	3	main
ja	doc_767882159253_item	3591759	et	3	main
esitavad	doc_767882159253_item	3591760	et	4	main
eestilaulu	doc_767882159253_item	3591775	et	4	main
on	doc_767882159253_item	3591781	et	4	main
ja	doc_767882159253_item	3591783	et	3	main
teeb	doc_767882159253_item	3591785	et	3	main
armastus	doc_767882159253_item	3591788	et	4	main
laulda	doc_767882159253_item	3591789	et	4	main
ja	doc_767882159253_item	3591790	et	3	main
tantsida	doc_767882159253_item	3591791	et	3	main
essee	doc_767882159255_item	3591793	et	4	main
keele	doc_767882159255_item	3591798	et	4	main
essee	doc_767882159255_item	3591802	et	4	main
essee	doc_767882159255_item	3591813	et	4	main
üldistav	doc_767882159255_item	3591819	et	4	main
tuginema	doc_767882159255_item	3591820	et	3	main
loengus	doc_767882159255_item	3591821	et	3	main
ja	doc_767882159255_item	3591822	et	3	main
lugemistekstis	doc_767882159255_item	3591823	et	3	main
näidetega	doc_767882159255_item	3591830	et	3	main
tavaliselt	doc_767882159255_item	3591852	et	4	main
teise	doc_767882159253_item	3591508	et	4	main
essee	doc_767882159253_item	3591513	et	4	main
teemal	doc_767882159253_item	3591514	et	3	main
mis	doc_767882159253_item	3591515	et	4	main
teeb	doc_767882159253_item	3591516	et	3	main
arutlev	doc_767882159253_item	3591527	et	4	main
analüüsiv	doc_767882159253_item	3591528	et	4	main
ja	doc_767882159253_item	3591529	et	3	main
üldistav	doc_767882159253_item	3591530	et	4	main
tuginema	doc_767882159253_item	3591531	et	3	main
loengus	doc_767882159253_item	3591532	et	3	main
ja	doc_767882159253_item	3591533	et	3	main
lugemistekstis	doc_767882159253_item	3591534	et	3	main
näidetega	doc_767882159253_item	3591541	et	3	main
pikk	doc_767882159253_item	3591551	et	4	main
ja	doc_767882159253_item	3591552	et	3	main
kui	doc_767882159253_item	3591554	et	3	main
te	doc_767882159253_item	3591555	et	4	main
hakkate	doc_767882159253_item	3591556	et	3	main
seda	doc_767882159253_item	3591557	et	3	main
uurima	doc_767882159253_item	3591558	et	3	main
siis	doc_767882159253_item	3591559	et	3	main
saate	doc_767882159253_item	3591560	et	4	main
aru	doc_767882159253_item	3591561	et	4	main
et	doc_767882159253_item	3591562	et	3	main
kindlasti	doc_767882159253_item	3591563	et	3	main
eestlased	doc_767882159253_item	3591564	et	3	main
on	doc_767882159253_item	3591565	et	4	main
laulurahvas	doc_767882159253_item	3591566	et	4	main
eestlased	doc_767882159253_item	3591567	et	3	main
laulavad	doc_767882159253_item	3591568	et	4	main
kõik	doc_767882159253_item	3591569	et	4	main
350	doc_767882159253_item	3591522	et	2	main
sõna	doc_767882159253_item	3591523	et	4	main
essee	doc_767882159253_item	3591524	et	4	main
on	doc_767882159253_item	3591538	et	4	main
teeb	doc_767882159253_item	3591543	et	3	main
laulurahva	doc_767882159253_item	3591545	et	3	main
eesti	doc_767882159253_item	3591546	et	4	main
laulu	doc_767882159253_item	3591547	et	4	main
mitmekülgne	doc_767882159253_item	3591553	et	3	main
aga	doc_767882159253_item	3591588	et	3	main
inimestele	doc_767882159253_item	3591606	et	3	main
praeguste	doc_767882159253_item	3591608	et	3	main
roll	doc_767882159253_item	3591615	et	3	main
ta	doc_767882159253_item	3591622	et	4	main
ilmus	doc_767882159253_item	3591623	et	4	main
sellepärast	doc_767882159253_item	3591624	et	3	main
et	doc_767882159253_item	3591625	et	3	main
inimesed	doc_767882159253_item	3591626	et	3	main
seda	doc_767882159253_item	3591628	et	3	main
ja	doc_767882159253_item	3591633	et	3	main
inimesed	doc_767882159253_item	3591637	et	3	main
puhkades	doc_767882159253_item	3591641	et	4	main
ja	doc_767882159253_item	3591642	et	3	main
pidutsedes	doc_767882159253_item	3591643	et	3	main
mehed	doc_767882159253_item	3591651	et	3	main
hinnatud	doc_767882159253_item	3591654	et	4	main
äärmiselt	doc_767882159253_item	3591658	et	4	main
uurimates	doc_767882159253_item	3591664	et	4	main
1869	doc_767882159253_item	3591720	et	2	main
tartus	doc_767882159253_item	3591722	et	3	main
aluse	doc_767882159253_item	3591725	et	4	main
ja	doc_767882159253_item	3591743	et	3	main
võimalus	doc_767882159253_item	3591745	et	3	main
mis	doc_767882159253_item	3591756	et	4	main
laulavad	doc_767882159253_item	3591757	et	4	main
laule	doc_767882159253_item	3591773	et	4	main
arvestades	doc_767882159253_item	3591774	et	3	main
eestlased	doc_767882159253_item	3591780	et	3	main
laulurahva	doc_767882159253_item	3591786	et	3	main
kui	doc_767882159255_item	3591796	et	3	main
kirjutamine	doc_767882159255_item	3591800	et	4	main
peab	doc_767882159255_item	3591814	et	4	main
olema	doc_767882159255_item	3591815	et	4	main
esitatud	doc_767882159255_item	3591824	et	4	main
rahval	doc_767882159255_item	3591832	et	3	main
oma	doc_767882159255_item	3591834	et	4	main
iseloomustus	doc_767882159255_item	3591836	et	4	main
eestlastest	doc_767882159255_item	3591837	et	4	main
võib	doc_767882159255_item	3591838	et	3	main
laulurahvas	doc_767882159255_item	3591843	et	4	main
kõige	doc_767882159255_item	3591844	et	4	main
vanem	doc_767882159255_item	3591845	et	4	main
regivärsiline	doc_767882159255_item	3591849	et	4	main
koor	doc_767882159255_item	3591856	et	4	main
nukraid	doc_767882159255_item	3591898	et	3	main
laule	doc_767882159255_item	3591899	et	4	main
lauljad	doc_767882159255_item	3591900	et	4	main
laule	doc_767882159255_item	3591914	et	4	main
emad	doc_767882159255_item	3591915	et	3	main
uilikene	doc_767882159255_item	3591925	et	4	main
maga	doc_767882159255_item	3591926	et	4	main
ilmusid	doc_767882159255_item	3591935	et	4	main
pillimehed	doc_767882159255_item	3591936	et	3	main
see	doc_767882159255_item	3591943	et	3	main
aasta	doc_767882159255_item	3591955	et	4	main
jaoks	doc_767882159255_item	3591961	et	4	main
seltsi	doc_767882159255_item	3591973	et	4	main
46	doc_767882159255_item	3591980	et	2	main
meeskoori	doc_767882159255_item	3591981	et	4	main
822	doc_767882159255_item	3591982	et	2	main
sellepärast	doc_767882159255_item	3591994	et	3	main
ilmusid	doc_767882159255_item	3591999	et	4	main
segakoorid	doc_767882159255_item	3592001	et	3	main
rahvastega	doc_767882159255_item	3592008	et	4	main
kahes	doc_767882159255_item	3592015	et	4	main
keeles	doc_767882159255_item	3592016	et	4	main
laulupidu	doc_767882159255_item	3592024	et	4	main
lätlased	doc_767882159255_item	3592036	et	3	main
juba	doc_767882159255_item	3592043	et	3	main
eesti	doc_767882159255_item	3592087	et	4	main
rahvas	doc_767882159255_item	3592088	et	4	main
ajaloo	doc_767882159253_item	3591571	et	4	main
mis	doc_767882159253_item	3591576	et	4	main
koor	doc_767882159253_item	3591585	et	4	main
regilaulu	doc_767882159253_item	3591589	et	4	main
ilma	doc_767882159253_item	3591591	et	4	main
pillisaadeta	doc_767882159253_item	3591592	et	4	main
laul	doc_767882159253_item	3591593	et	4	main
oli	doc_767882159253_item	3591594	et	3	main
väga	doc_767882159253_item	3591595	et	3	main
võin	doc_767882159253_item	3591600	et	3	main
isegi	doc_767882159253_item	3591601	et	4	main
laulis	doc_767882159253_item	3591586	et	4	main
ajal	doc_767882159253_item	3591598	et	4	main
ka	doc_767882159253_item	3591612	et	3	main
mängib	doc_767882159253_item	3591613	et	3	main
ammu	doc_767882159253_item	3591620	et	4	main
ja	doc_767882159253_item	3591621	et	3	main
talurahvale	doc_767882159253_item	3591629	et	3	main
väljendada	doc_767882159253_item	3591635	et	3	main
rahvas	doc_767882159253_item	3591644	et	4	main
kindlasti	doc_767882159253_item	3591645	et	3	main
oli	doc_767882159253_item	3591652	et	3	main
sest	doc_767882159253_item	3591665	et	4	main
näiteks	doc_767882159253_item	3591671	et	4	main
kristlus	doc_767882159253_item	3591673	et	4	main
tuli	doc_767882159253_item	3591674	et	4	main
eestile	doc_767882159253_item	3591675	et	3	main
sajandi	doc_767882159253_item	3591704	et	3	main
lõpus	doc_767882159253_item	3591705	et	4	main
ja	doc_767882159253_item	3591706	et	3	main
sel	doc_767882159253_item	3591707	et	3	main
sajandil	doc_767882159253_item	3591708	et	3	main
ka	doc_767882159253_item	3591709	et	3	main
toimus	doc_767882159253_item	3591710	et	3	main
eesti	doc_767882159253_item	3591711	et	4	main
laulu	doc_767882159253_item	3591712	et	4	main
ja	doc_767882159253_item	3591713	et	3	main
muusika	doc_767882159253_item	3591714	et	4	main
kõige	doc_767882159253_item	3591715	et	4	main
tähtsam	doc_767882159253_item	3591716	et	4	main
sündmus	doc_767882159253_item	3591717	et	3	main
aitas	doc_767882159253_item	3591605	et	3	main
inimeste	doc_767882159253_item	3591609	et	3	main
aitas	doc_767882159253_item	3591631	et	3	main
laulsid	doc_767882159253_item	3591638	et	4	main
näiteks	doc_767882159253_item	3591649	et	4	main
tähtis	doc_767882159253_item	3591659	et	4	main
seal	doc_767882159253_item	3591666	et	4	main
kui	doc_767882159253_item	3591672	et	3	main
ja	doc_767882159253_item	3591676	et	3	main
kirikus	doc_767882159253_item	3591677	et	3	main
toimutati	doc_767882159253_item	3591678	et	4	main
laulde	doc_767882159253_item	3591679	et	4	main
laulmine	doc_767882159253_item	3591680	et	4	main
see	doc_767882159253_item	3591681	et	3	main
mõjus	doc_767882159253_item	3591682	et	4	main
ka	doc_767882159253_item	3591683	et	3	main
rahvaluulet	doc_767882159253_item	3591684	et	3	main
19	doc_767882159253_item	3591685	et	2	main
ja	doc_767882159253_item	3591686	et	3	main
20	doc_767882159253_item	3591687	et	2	main
sajandid	doc_767882159253_item	3591688	et	3	main
võib	doc_767882159253_item	3591689	et	3	main
õiguslikult	doc_767882159253_item	3591690	et	4	main
nimetada	doc_767882159253_item	3591691	et	3	main
kõige	doc_767882159253_item	3591692	et	4	main
tähtsamate	doc_767882159253_item	3591693	et	4	main
sajanditena	doc_767882159253_item	3591694	et	3	main
eesti	doc_767882159253_item	3591695	et	4	main
laulu	doc_767882159253_item	3591696	et	4	main
ajaloos	doc_767882159253_item	3591697	et	4	main
lauluga	doc_767882159253_item	3591698	et	4	main
on	doc_767882159253_item	3591699	et	4	main
tihedalt	doc_767882159253_item	3591700	et	4	main
seotud	doc_767882159253_item	3591701	et	4	main
ärkamisaeg	doc_767882159253_item	3591702	et	3	main
19	doc_767882159253_item	3591703	et	2	main
aastal	doc_767882159253_item	3591721	et	3	main
mis	doc_767882159253_item	3591723	et	4	main
muusikakoolid	doc_767882159253_item	3591742	et	3	main
rahvatantsutega	doc_767882159253_item	3591761	et	4	main
on	doc_767882159253_item	3591763	et	4	main
populaarne	doc_767882159253_item	3591766	et	3	main
ajalooga	doc_767882159253_item	3591776	et	4	main
võib	doc_767882159253_item	3591777	et	3	main
öelda	doc_767882159253_item	3591778	et	4	main
teise	doc_767882159255_item	3591797	et	4	main
eestlastest	doc_767882159255_item	3591806	et	4	main
essee	doc_767882159255_item	3591808	et	4	main
pikkus	doc_767882159255_item	3591809	et	4	main
300	doc_767882159255_item	3591810	et	2	main
350	doc_767882159255_item	3591811	et	2	main
arutlev	doc_767882159255_item	3591816	et	4	main
on	doc_767882159255_item	3591827	et	4	main
laul	doc_767882159253_item	3591604	et	4	main
elada	doc_767882159253_item	3591607	et	3	main
laul	doc_767882159253_item	3591611	et	4	main
mahukas	doc_767882159253_item	3591614	et	4	main
laul	doc_767882159253_item	3591617	et	4	main
ilmus	doc_767882159253_item	3591618	et	4	main
väga	doc_767882159253_item	3591619	et	3	main
ta	doc_767882159253_item	3591630	et	4	main
töötada	doc_767882159253_item	3591632	et	3	main
iseennast	doc_767882159253_item	3591636	et	3	main
saartel	doc_767882159253_item	3591650	et	3	main
allikas	doc_767882159253_item	3591660	et	4	main
eesti	doc_767882159253_item	3591661	et	4	main
on	doc_767882159253_item	3591667	et	4	main
esimene	doc_767882159253_item	3591718	et	3	main
laulupidu	doc_767882159253_item	3591719	et	4	main
pani	doc_767882159253_item	3591724	et	4	main
korraldamisele	doc_767882159253_item	3591728	et	4	main
sajandil	doc_767882159253_item	3591730	et	3	main
ilmusid	doc_767882159253_item	3591732	et	4	main
professionaalsed	doc_767882159253_item	3591734	et	3	main
näiteks	doc_767882159253_item	3591736	et	4	main
rüüdik	doc_767882159253_item	3591737	et	4	main
saar	doc_767882159253_item	3591738	et	3	main
kapp	doc_767882159253_item	3591739	et	3	main
ka	doc_767882159253_item	3591740	et	3	main
avati	doc_767882159253_item	3591741	et	3	main
eestis	doc_767882159253_item	3591751	et	3	main
rahvalaule	doc_767882159253_item	3591758	et	4	main
veel	doc_767882159253_item	3591762	et	4	main
ka	doc_767882159253_item	3591764	et	3	main
võtta	doc_767882159253_item	3591767	et	3	main
keele	doc_767882159255_item	3591795	et	4	main
test	doc_767882159255_item	3591799	et	3	main
kirjutage	doc_767882159255_item	3591801	et	3	main
teemal	doc_767882159255_item	3591803	et	3	main
mis	doc_767882159255_item	3591804	et	4	main
teeb	doc_767882159255_item	3591805	et	3	main
sõna	doc_767882159255_item	3591812	et	4	main
analüüsiv	doc_767882159255_item	3591817	et	4	main
ja	doc_767882159255_item	3591818	et	3	main
soovitatav	doc_767882159255_item	3591828	et	4	main
illustreerida	doc_767882159255_item	3591829	et	3	main
öelda	doc_767882159255_item	3591839	et	4	main
et	doc_767882159255_item	3591840	et	3	main
nad	doc_767882159255_item	3591841	et	3	main
on	doc_767882159255_item	3591842	et	4	main
rahvalaul	doc_767882159255_item	3591847	et	4	main
rahvalaul	doc_767882159255_item	3591850	et	4	main
esitavad	doc_767882159255_item	3591853	et	4	main
ja	doc_767882159255_item	3591855	et	3	main
laulsid	doc_767882159255_item	3591901	et	4	main
pulmades	doc_767882159255_item	3591902	et	3	main
ka	doc_767882159255_item	3591903	et	3	main
laulsid	doc_767882159255_item	3591909	et	4	main
nende	doc_767882159255_item	3591918	et	4	main
uinu	doc_767882159255_item	3591924	et	4	main
jooksis	doc_767882159255_item	3591929	et	4	main
aeg	doc_767882159255_item	3591930	et	3	main
aeg	doc_767882159255_item	3591945	et	3	main
millal	doc_767882159255_item	3591956	et	3	main
aktiivsem	doc_767882159255_item	3591969	et	4	main
korraldaja	doc_767882159255_item	3591970	et	4	main
oli	doc_767882159255_item	3591971	et	3	main
voldemar	doc_767882159255_item	3591976	et	4	main
puhkpilliorkestrit	doc_767882159255_item	3591986	et	3	main
eestlased	doc_767882159255_item	3592005	et	3	main
muutus	doc_767882159255_item	3592018	et	4	main
laulude	doc_767882159255_item	3592019	et	3	main
praegu	doc_767882159255_item	3592022	et	3	main
venelased	doc_767882159255_item	3592032	et	3	main
valgevenelased	doc_767882159255_item	3592033	et	3	main
ukraainlased	doc_767882159255_item	3592034	et	4	main
soomlased	doc_767882159255_item	3592035	et	3	main
ole	doc_767882159255_item	3592042	et	4	main
nagu	doc_767882159255_item	3592045	et	3	main
ammu-ammu	doc_767882159255_item	3592047	et	4	main
organiseeritud	doc_767882159255_item	3592052	et	4	main
rahvas	doc_767882159255_item	3592084	et	4	main
essee	doc_767882159256_item	3592099	et	4	main
keele	doc_767882159256_item	3592104	et	4	main
järgnevate	doc_767882159253_item	3591726	et	4	main
esimesed	doc_767882159253_item	3591733	et	3	main
on	doc_767882159253_item	3591752	et	4	main
väga	doc_767882159253_item	3591753	et	3	main
palju	doc_767882159253_item	3591754	et	4	main
rahvalauluansambleid	doc_767882159253_item	3591755	et	3	main
väga	doc_767882159253_item	3591765	et	3	main
rahvaluulest	doc_767882159253_item	3591768	et	4	main
sõnu	doc_767882159253_item	3591769	et	4	main
ja	doc_767882159253_item	3591770	et	3	main
teha	doc_767882159253_item	3591771	et	3	main
uut	doc_767882159253_item	3591772	et	3	main
et	doc_767882159253_item	3591779	et	3	main
laulurahva	doc_767882159253_item	3591782	et	3	main
nendest	doc_767882159253_item	3591784	et	4	main
suur	doc_767882159253_item	3591787	et	3	main
eesti	doc_767882159255_item	3591794	et	4	main
laulurahva	doc_767882159255_item	3591807	et	3	main
faktidele	doc_767882159255_item	3591825	et	3	main
väiteid	doc_767882159255_item	3591826	et	4	main
igal	doc_767882159255_item	3591831	et	3	main
on	doc_767882159255_item	3591848	et	4	main
vaheldumisi	doc_767882159255_item	3591857	et	4	main
eeslaulja	doc_767882159255_item	3591858	et	4	main
laulab	doc_767882159255_item	3591859	et	3	main
aga	doc_767882159255_item	3591860	et	3	main
koor	doc_767882159255_item	3591861	et	4	main
kordab	doc_767882159255_item	3591862	et	3	main
tema	doc_767882159255_item	3591863	et	4	main
esitatud	doc_767882159255_item	3591864	et	4	main
värsse	doc_767882159255_item	3591865	et	3	main
andes	doc_767882159255_item	3591866	et	4	main
sellega	doc_767882159255_item	3591867	et	3	main
talle	doc_767882159255_item	3591868	et	4	main
mõtteaega	doc_767882159255_item	3591869	et	4	main
ei	doc_767882159255_item	3591870	et	4	main
ole	doc_767882159255_item	3591871	et	4	main
seda	doc_767882159255_item	3591872	et	3	main
aega	doc_767882159255_item	3591873	et	4	main
eestlased	doc_767882159255_item	3591875	et	3	main
millal	doc_767882159255_item	3591874	et	3	main
ei	doc_767882159255_item	3591876	et	4	main
laulnud	doc_767882159255_item	3591877	et	4	main
emad	doc_767882159255_item	3591878	et	3	main
laulsid	doc_767882159255_item	3591879	et	4	main
oma	doc_767882159255_item	3591880	et	4	main
pisikestele	doc_767882159255_item	3591881	et	4	main
lastele	doc_767882159255_item	3591882	et	4	main
lastelaule	doc_767882159255_item	3591883	et	4	main
mehed	doc_767882159255_item	3591884	et	3	main
laulsid	doc_767882159255_item	3591885	et	4	main
sõjalaule	doc_767882159255_item	3591886	et	4	main
kui	doc_767882159255_item	3591887	et	3	main
läksid	doc_767882159255_item	3591888	et	4	main
surma	doc_767882159255_item	3591889	et	4	main
sellest	doc_767882159255_item	3591890	et	4	main
ka	doc_767882159255_item	3591891	et	3	main
laulsid	doc_767882159255_item	3591892	et	4	main
nende	doc_767882159255_item	3591893	et	4	main
laulsid	doc_767882159255_item	3591904	et	4	main
abikaasad	doc_767882159255_item	3591905	et	3	main
aga	doc_767882159255_item	3591906	et	3	main
ka	doc_767882159255_item	3591910	et	3	main
on	doc_767882159255_item	3591833	et	4	main
nn	doc_767882159255_item	3591835	et	4	main
eesti	doc_767882159255_item	3591846	et	4	main
regilaulu	doc_767882159255_item	3591851	et	4	main
eeslaulja	doc_767882159255_item	3591854	et	4	main
sugulased	doc_767882159255_item	3591894	et	3	main
naine	doc_767882159255_item	3591896	et	3	main
oma	doc_767882159255_item	3591897	et	4	main
kirikus	doc_767882159255_item	3591911	et	3	main
vaimu	doc_767882159255_item	3591913	et	4	main
olid	doc_767882159255_item	3591920	et	4	main
armastuse	doc_767882159255_item	3591921	et	4	main
täis	doc_767882159255_item	3591922	et	4	main
tulid	doc_767882159255_item	3591931	et	4	main
uued	doc_767882159255_item	3591932	et	3	main
stiilid	doc_767882159255_item	3591933	et	4	main
mängisid	doc_767882159255_item	3591938	et	4	main
pilli	doc_767882159255_item	3591939	et	4	main
aga	doc_767882159255_item	3591940	et	3	main
naised	doc_767882159255_item	3591941	et	3	main
millal	doc_767882159255_item	3591946	et	3	main
hakkasid	doc_767882159255_item	3591948	et	4	main
rõõmsad	doc_767882159255_item	3591950	et	3	main
see	doc_767882159255_item	3591951	et	3	main
oli	doc_767882159255_item	3591952	et	3	main
aasta	doc_767882159255_item	3591954	et	4	main
väga	doc_767882159255_item	3591958	et	3	main
eesti	doc_767882159255_item	3591960	et	4	main
sündmus	doc_767882159255_item	3591962	et	3	main
esimene	doc_767882159255_item	3591963	et	3	main
laulupidu	doc_767882159255_item	3591964	et	4	main
korraldati	doc_767882159255_item	3591965	et	3	main
seda	doc_767882159255_item	3591966	et	3	main
tartus	doc_767882159255_item	3591967	et	3	main
kõige	doc_767882159255_item	3591968	et	4	main
esindaja	doc_767882159255_item	3591974	et	4	main
peol	doc_767882159255_item	3591978	et	4	main
osales	doc_767882159255_item	3591979	et	3	main
ja	doc_767882159255_item	3591895	et	3	main
palju	doc_767882159255_item	3591907	et	4	main
inimesi	doc_767882159255_item	3591908	et	4	main
laulud	doc_767882159255_item	3591919	et	3	main
kes	doc_767882159255_item	3591937	et	4	main
oli	doc_767882159255_item	3591944	et	3	main
juhtus	doc_767882159255_item	3591957	et	3	main
vanemuise	doc_767882159255_item	3591972	et	4	main
jannsen	doc_767882159255_item	3591977	et	4	main
56	doc_767882159255_item	3591987	et	2	main
mängijaga	doc_767882159255_item	3591988	et	4	main
1896	doc_767882159255_item	3591989	et	2	main
laulupidu	doc_767882159255_item	3591991	et	4	main
toimus	doc_767882159255_item	3591992	et	3	main
aastal	doc_767882159255_item	3591990	et	3	main
ka	doc_767882159255_item	3592000	et	3	main
aega	doc_767882159255_item	3592004	et	4	main
sõbrustasid	doc_767882159255_item	3592006	et	4	main
teiste	doc_767882159255_item	3592007	et	4	main
tulevad	doc_767882159255_item	3592031	et	4	main
kes	doc_767882159255_item	3592054	et	4	main
laulsid	doc_767882159255_item	3592055	et	4	main
on	doc_767882159255_item	3592085	et	4	main
kui	doc_767882159256_item	3592102	et	3	main
kirjutamine	doc_767882159256_item	3592106	et	4	main
arutlev	doc_767882159256_item	3592122	et	4	main
analüüsiv	doc_767882159256_item	3592123	et	4	main
ja	doc_767882159256_item	3592124	et	3	main
üldistav	doc_767882159256_item	3592125	et	4	main
et	doc_767882159256_item	3592139	et	3	main
on	doc_767882159256_item	3592141	et	4	main
olen	doc_767882159256_item	3592145	et	3	main
mingit	doc_767882159256_item	3592155	et	3	main
rahvust	doc_767882159256_item	3592156	et	3	main
on	doc_767882159256_item	3592168	et	4	main
kogu	doc_767882159256_item	3592202	et	4	main
salmeid	doc_767882159255_item	3591912	et	4	main
laulsid	doc_767882159255_item	3591916	et	4	main
tasa	doc_767882159255_item	3591917	et	3	main
uinu	doc_767882159255_item	3591923	et	4	main
maga	doc_767882159255_item	3591927	et	4	main
maarjakene	doc_767882159255_item	3591928	et	4	main
nüüd	doc_767882159255_item	3591934	et	4	main
laulsid	doc_767882159255_item	3591942	et	4	main
laulud	doc_767882159255_item	3591947	et	3	main
olema	doc_767882159255_item	3591949	et	4	main
1869	doc_767882159255_item	3591953	et	2	main
tähtis	doc_767882159255_item	3591959	et	4	main
johann	doc_767882159255_item	3591975	et	4	main
lauljaga	doc_767882159255_item	3591983	et	4	main
ja	doc_767882159255_item	3591984	et	3	main
5	doc_767882159255_item	3591985	et	2	main
tallinnas	doc_767882159255_item	3591993	et	4	main
osavõtjate	doc_767882159255_item	3591996	et	3	main
kasvas	doc_767882159255_item	3591998	et	3	main
läks	doc_767882159255_item	3592002	et	3	main
veel	doc_767882159255_item	3592003	et	4	main
venemaa	doc_767882159255_item	3592009	et	4	main
natuke	doc_767882159255_item	3592017	et	4	main
on	doc_767882159255_item	3592025	et	4	main
iga	doc_767882159255_item	3592027	et	4	main
neli	doc_767882159255_item	3592028	et	3	main
aastat	doc_767882159255_item	3592029	et	3	main
meile	doc_767882159255_item	3592030	et	4	main
n	doc_767882159255_item	3592038	et	4	main
niisugused	doc_767882159255_item	3592044	et	3	main
olid	doc_767882159255_item	3592046	et	4	main
aga	doc_767882159255_item	3592048	et	3	main
setsmendates	doc_767882159255_item	3592049	et	4	main
aastates	doc_767882159255_item	3592050	et	4	main
keele	doc_767882159256_item	3592101	et	4	main
essee	doc_767882159256_item	3592108	et	4	main
teemal	doc_767882159256_item	3592109	et	3	main
essee	doc_767882159256_item	3592119	et	4	main
peab	doc_767882159256_item	3592120	et	4	main
tuginema	doc_767882159256_item	3592126	et	3	main
faktidele	doc_767882159256_item	3592131	et	3	main
ei	doc_767882159256_item	3592152	et	4	main
tea	doc_767882159256_item	3592153	et	4	main
veel	doc_767882159256_item	3592154	et	4	main
mis	doc_767882159256_item	3592157	et	4	main
paneb	doc_767882159256_item	3592158	et	3	main
nii	doc_767882159256_item	3592159	et	3	main
palju	doc_767882159256_item	3592160	et	4	main
tantsu	doc_767882159256_item	3592164	et	4	main
traditsioonidele	doc_767882159256_item	3592165	et	3	main
estlastele	doc_767882159256_item	3592166	et	4	main
kultuurinähtus	doc_767882159256_item	3592170	et	4	main
see	doc_767882159256_item	3592171	et	3	main
on	doc_767882159256_item	3592172	et	4	main
esteetiline	doc_767882159256_item	3592173	et	3	main
ja	doc_767882159256_item	3592174	et	3	main
emotsionaalne	doc_767882159256_item	3592175	et	3	main
väljendusvahed	doc_767882159256_item	3592176	et	3	main
aga	doc_767882159256_item	3592177	et	3	main
ka	doc_767882159256_item	3592178	et	3	main
sotsiaalne	doc_767882159256_item	3592179	et	3	main
estlased	doc_767882159256_item	3592200	et	4	main
olles	doc_767882159256_item	3592205	et	3	main
tegevusi	doc_767882159256_item	3592215	et	4	main
kajastub	doc_767882159256_item	3592222	et	3	main
ka	doc_767882159256_item	3592227	et	3	main
mil	doc_767882159256_item	3592259	et	4	main
rahvuslikke	doc_767882159256_item	3592260	et	3	main
haridus-	doc_767882159256_item	3592261	et	3	main
ja	doc_767882159256_item	3592262	et	3	main
muusikaseltse	doc_767882159256_item	3592263	et	3	main
kui	doc_767882159256_item	3592270	et	3	main
kui	doc_767882159256_item	3592272	et	3	main
ajal	doc_767882159256_item	3592274	et	4	main
siis	doc_767882159256_item	3592275	et	3	main
selle	doc_767882159256_item	3592281	et	4	main
need	doc_767882159256_item	3592289	et	3	main
seal	doc_767882159256_item	3592296	et	4	main
rühmi	doc_767882159256_item	3592306	et	4	main
lootuses	doc_767882159256_item	3592346	et	4	main
üle	doc_767882159256_item	3592354	et	3	main
laulurahv	doc_767882159256_item	3592368	et	4	main
et	doc_767882159255_item	3591995	et	3	main
arv	doc_767882159255_item	3591997	et	3	main
läti	doc_767882159255_item	3592010	et	4	main
mõned	doc_767882159255_item	3592011	et	3	main
huumori	doc_767882159255_item	3592012	et	3	main
laulud	doc_767882159255_item	3592013	et	3	main
olid	doc_767882159255_item	3592014	et	4	main
kirjutamise	doc_767882159255_item	3592020	et	4	main
stiil	doc_767882159255_item	3592021	et	3	main
eesti	doc_767882159255_item	3592023	et	4	main
rahvusvaheline	doc_767882159255_item	3592026	et	4	main
ja	doc_767882159255_item	3592037	et	3	main
e	doc_767882159255_item	3592039	et	4	main
laulud	doc_767882159255_item	3592040	et	3	main
ei	doc_767882159255_item	3592041	et	4	main
olid	doc_767882159255_item	3592051	et	4	main
folk-ansamblid	doc_767882159255_item	3592053	et	3	main
laule	doc_767882159255_item	3592056	et	4	main
nagu	doc_767882159255_item	3592057	et	3	main
palju-palju	doc_767882159255_item	3592058	et	4	main
aastaid	doc_767882159255_item	3592059	et	4	main
tagasi	doc_767882159255_item	3592060	et	3	main
neid	doc_767882159255_item	3592061	et	4	main
laule	doc_767882159255_item	3592062	et	4	main
võtakse	doc_767882159255_item	3592063	et	4	main
arhiivist	doc_767882159255_item	3592064	et	3	main
praegu	doc_767882159255_item	3592065	et	3	main
aga	doc_767882159255_item	3592066	et	3	main
kõige	doc_767882159255_item	3592067	et	4	main
meeldivaim	doc_767882159255_item	3592068	et	4	main
laul	doc_767882159255_item	3592069	et	4	main
on	doc_767882159255_item	3592070	et	4	main
meie	doc_767882159255_item	3592071	et	4	main
hümn	doc_767882159255_item	3592072	et	3	main
mille	doc_767882159255_item	3592073	et	3	main
laulavad	doc_767882159255_item	3592074	et	4	main
laulupeo	doc_767882159255_item	3592075	et	4	main
osalejad	doc_767882159255_item	3592076	et	4	main
ja	doc_767882159255_item	3592077	et	3	main
vaatajad	doc_767882159255_item	3592078	et	4	main
kõik	doc_767882159255_item	3592079	et	4	main
koos	doc_767882159255_item	3592080	et	4	main
see	doc_767882159255_item	3592081	et	3	main
tähendab	doc_767882159255_item	3592082	et	3	main
eesti	doc_767882159255_item	3592083	et	4	main
laulurahvas	doc_767882159255_item	3592086	et	4	main
on	doc_767882159255_item	3592089	et	4	main
tugev	doc_767882159255_item	3592090	et	4	main
rahvas	doc_767882159255_item	3592091	et	4	main
aga	doc_767882159255_item	3592092	et	3	main
igaüks	doc_767882159255_item	3592093	et	3	main
tunneb	doc_767882159255_item	3592094	et	3	main
rõõmu	doc_767882159255_item	3592095	et	4	main
kui	doc_767882159255_item	3592096	et	3	main
laulab	doc_767882159255_item	3592097	et	3	main
teise	doc_767882159256_item	3592103	et	4	main
kirjutage	doc_767882159256_item	3592107	et	3	main
mis	doc_767882159256_item	3592110	et	4	main
teeb	doc_767882159256_item	3592111	et	3	main
eestlastest	doc_767882159256_item	3592112	et	4	main
laulurahva	doc_767882159256_item	3592113	et	3	main
lugemistekstis	doc_767882159256_item	3592129	et	3	main
õige	doc_767882159256_item	3592137	et	4	main
see	doc_767882159256_item	3592138	et	3	main
täesti	doc_767882159256_item	3592147	et	4	main
nõus	doc_767882159256_item	3592148	et	4	main
või	doc_767882159256_item	3592163	et	4	main
aega	doc_767882159256_item	3592203	et	4	main
üksi	doc_767882159256_item	3592204	et	4	main
töötades	doc_767882159256_item	3592206	et	3	main
last	doc_767882159256_item	3592207	et	4	main
kiigutades	doc_767882159256_item	3592208	et	3	main
ma	doc_767882159256_item	3592209	et	3	main
võin	doc_767882159256_item	3592210	et	3	main
öelda	doc_767882159256_item	3592211	et	4	main
et	doc_767882159256_item	3592212	et	3	main
lauldi	doc_767882159256_item	3592213	et	3	main
tegemises	doc_767882159256_item	3592216	et	4	main
seotud	doc_767882159256_item	3592251	et	4	main
estlased	doc_767882159256_item	3592278	et	4	main
palju	doc_767882159256_item	3592285	et	4	main
kontserte	doc_767882159256_item	3592286	et	3	main
laulupeod	doc_767882159256_item	3592290	et	4	main
kõike	doc_767882159256_item	3592292	et	4	main
inimeste	doc_767882159256_item	3592293	et	3	main
kes	doc_767882159256_item	3592294	et	4	main
aru	doc_767882159256_item	3592298	et	4	main
saanud	doc_767882159256_item	3592299	et	4	main
praegu	doc_767882159256_item	3592303	et	3	main
suur	doc_767882159256_item	3592340	et	3	main
rahvapidu	doc_767882159256_item	3592341	et	4	main
kuhu	doc_767882159256_item	3592342	et	3	main
tullakse	doc_767882159256_item	3592343	et	3	main
koos	doc_767882159256_item	3592344	et	4	main
perega	doc_767882159256_item	3592345	et	3	main
kogu	doc_767882159256_item	3592355	et	4	main
ja	doc_767882159256_item	3592369	et	3	main
kõik	doc_767882159256_item	3592370	et	4	main
need	doc_767882159256_item	3592371	et	3	main
traditsioonid	doc_767882159256_item	3592372	et	3	main
eesti	doc_767882159256_item	3592100	et	4	main
pikkus	doc_767882159256_item	3592115	et	4	main
300	doc_767882159256_item	3592116	et	2	main
350	doc_767882159256_item	3592117	et	2	main
sõna	doc_767882159256_item	3592118	et	4	main
ja	doc_767882159256_item	3592128	et	3	main
esitatud	doc_767882159256_item	3592130	et	4	main
väiteid	doc_767882159256_item	3592132	et	4	main
on	doc_767882159256_item	3592133	et	4	main
eestlased	doc_767882159256_item	3592140	et	3	main
laulurahv	doc_767882159256_item	3592142	et	4	main
ja	doc_767882159256_item	3592143	et	3	main
ma	doc_767882159256_item	3592144	et	3	main
tähelepanu	doc_767882159256_item	3592161	et	4	main
laulu	doc_767882159256_item	3592162	et	4	main
laulmine	doc_767882159256_item	3592167	et	4	main
tähelepanuväärne	doc_767882159256_item	3592169	et	3	main
tegevus	doc_767882159256_item	3592180	et	4	main
juba	doc_767882159256_item	3592181	et	3	main
vanast	doc_767882159256_item	3592182	et	3	main
ajast	doc_767882159256_item	3592183	et	4	main
saab	doc_767882159256_item	3592184	et	3	main
öelda	doc_767882159256_item	3592185	et	4	main
et	doc_767882159256_item	3592186	et	3	main
laul	doc_767882159256_item	3592187	et	4	main
oli	doc_767882159256_item	3592188	et	3	main
väga	doc_767882159256_item	3592189	et	3	main
oluline	doc_767882159256_item	3592190	et	4	main
estlaste	doc_767882159256_item	3592191	et	4	main
jaoks	doc_767882159256_item	3592192	et	4	main
sellepärast	doc_767882159256_item	3592193	et	3	main
et	doc_767882159256_item	3592194	et	3	main
nad	doc_767882159256_item	3592195	et	3	main
kasutasid	doc_767882159256_item	3592196	et	4	main
laulu	doc_767882159256_item	3592197	et	4	main
nagu	doc_767882159256_item	3592198	et	3	main
iseväljendusvahendina	doc_767882159256_item	3592199	et	3	main
siis	doc_767882159256_item	3592217	et	3	main
et	doc_767882159256_item	3592220	et	3	main
rahva	doc_767882159256_item	3592223	et	3	main
mistõttu	doc_767882159256_item	3592225	et	3	main
ajaloo	doc_767882159256_item	3592232	et	4	main
tähtis	doc_767882159256_item	3592235	et	4	main
märkmida	doc_767882159256_item	3592236	et	4	main
et	doc_767882159256_item	3592237	et	3	main
laulude	doc_767882159256_item	3592238	et	3	main
lõpupoole	doc_767882159256_item	3592258	et	4	main
nii	doc_767882159256_item	3592268	et	3	main
vanal	doc_767882159256_item	3592273	et	3	main
ka	doc_767882159256_item	3592276	et	3	main
täna	doc_767882159256_item	3592277	et	4	main
põhul	doc_767882159256_item	3592282	et	3	main
korraldakse	doc_767882159256_item	3592283	et	4	main
eestis	doc_767882159256_item	3592284	et	3	main
esitavad	doc_767882159256_item	3592295	et	4	main
test	doc_767882159256_item	3592105	et	3	main
essee	doc_767882159256_item	3592114	et	4	main
olema	doc_767882159256_item	3592121	et	4	main
loengus	doc_767882159256_item	3592127	et	3	main
soovitatav	doc_767882159256_item	3592134	et	4	main
illustreerida	doc_767882159256_item	3592135	et	3	main
näidetega	doc_767882159256_item	3592136	et	3	main
sellega	doc_767882159256_item	3592146	et	3	main
sest	doc_767882159256_item	3592149	et	4	main
et	doc_767882159256_item	3592150	et	3	main
ma	doc_767882159256_item	3592151	et	3	main
laulsid	doc_767882159256_item	3592201	et	4	main
kõike	doc_767882159256_item	3592214	et	4	main
nagu	doc_767882159256_item	3592231	et	3	main
väga	doc_767882159256_item	3592234	et	3	main
tihedalt	doc_767882159256_item	3592252	et	4	main
eestlaste	doc_767882159256_item	3592253	et	4	main
rahvuslik	doc_767882159256_item	3592254	et	3	main
loodi	doc_767882159256_item	3592264	et	4	main
baltisaksa	doc_767882159256_item	3592265	et	4	main
linnas	doc_767882159256_item	3592269	et	4	main
maal	doc_767882159256_item	3592271	et	4	main
ning	doc_767882159256_item	3592287	et	3	main
ühendavad	doc_767882159256_item	3592291	et	4	main
olen	doc_767882159256_item	3592297	et	3	main
eestis	doc_767882159256_item	3592301	et	3	main
palju	doc_767882159256_item	3592304	et	4	main
folklööri	doc_767882159256_item	3592305	et	4	main
kohata	doc_767882159256_item	3592347	et	4	main
sõpru	doc_767882159256_item	3592348	et	3	main
sugulasi	doc_767882159256_item	3592349	et	3	main
ja	doc_767882159256_item	3592350	et	3	main
tuttavaid	doc_767882159256_item	3592351	et	3	main
kes	doc_767882159256_item	3592352	et	4	main
kokku	doc_767882159256_item	3592357	et	3	main
minu	doc_767882159256_item	3592359	et	3	main
eestlased	doc_767882159256_item	3592365	et	3	main
on	doc_767882159256_item	3592366	et	4	main
täesti	doc_767882159256_item	3592367	et	4	main
poole	doc_767882159256_item	3592374	et	4	main
panevad	doc_767882159256_item	3592376	et	4	main
teevad	doc_767882159256_item	3592378	et	3	main
test	doc_767882159259_item	3592388	et	3	main
eestlastest	doc_767882159259_item	3592395	et	4	main
laulurahva	doc_767882159259_item	3592396	et	3	main
juba	doc_767882159259_item	3592423	et	3	main
on	doc_767882159259_item	3592432	et	4	main
erineb	doc_767882159259_item	3592439	et	3	main
oma	doc_767882159259_item	3592440	et	4	main
vaimuga	doc_767882159259_item	3592441	et	3	main
vanemates	doc_767882159259_item	3592456	et	4	main
eesti	doc_767882159259_item	3592458	et	4	main
rahvas	doc_767882159259_item	3592459	et	4	main
kasutanud	doc_767882159259_item	3592462	et	4	main
sest	doc_767882159259_item	3592465	et	4	main
et	doc_767882159259_item	3592466	et	3	main
muusika	doc_767882159259_item	3592467	et	4	main
oli	doc_767882159259_item	3592468	et	3	main
juba	doc_767882159259_item	3592469	et	3	main
lihtsalt	doc_767882159259_item	3592479	et	4	main
ise	doc_767882159259_item	3592482	et	4	main
tantsima	doc_767882159259_item	3592484	et	3	main
eesti	doc_767882159259_item	3592495	et	4	main
kuidas	doc_767882159259_item	3592502	et	3	main
riik	doc_767882159259_item	3592505	et	3	main
võita	doc_767882159259_item	3592507	et	4	main
kui	doc_767882159259_item	3592515	et	3	main
sa	doc_767882159259_item	3592516	et	3	main
laul	doc_767882159259_item	3592519	et	4	main
patriootsust	doc_767882159259_item	3592521	et	4	main
esimest	doc_767882159259_item	3592526	et	4	main
korda	doc_767882159259_item	3592527	et	4	main
suur	doc_767882159259_item	3592532	et	3	main
selle	doc_767882159259_item	3592576	et	4	main
kuulavad	doc_767882159259_item	3592577	et	4	main
eestlased	doc_767882159259_item	3592579	et	3	main
üle	doc_767882159259_item	3592580	et	3	main
televiisorist	doc_767882159259_item	3592584	et	4	main
pere	doc_767882159259_item	3592588	et	4	main
kus	doc_767882159259_item	3592589	et	3	main
inimesed	doc_767882159259_item	3592590	et	3	main
ole	doc_767882159259_item	3592597	et	4	main
võib	doc_767882159256_item	3592218	et	3	main
öelda	doc_767882159256_item	3592219	et	4	main
rahvalauludes	doc_767882159256_item	3592221	et	3	main
minevik	doc_767882159256_item	3592224	et	3	main
on	doc_767882159256_item	3592226	et	4	main
rahvalauluga	doc_767882159256_item	3592228	et	4	main
tutvumine	doc_767882159256_item	3592229	et	4	main
pisut	doc_767882159256_item	3592230	et	3	main
uurimine	doc_767882159256_item	3592233	et	4	main
laulmisega	doc_767882159256_item	3592239	et	4	main
seotud	doc_767882159256_item	3592240	et	4	main
palju	doc_767882159256_item	3592241	et	4	main
erinevd	doc_767882159256_item	3592242	et	4	main
ning	doc_767882159256_item	3592243	et	3	main
olulised	doc_767882159256_item	3592244	et	4	main
tähtajad	doc_767882159256_item	3592245	et	3	main
näiteks	doc_767882159256_item	3592246	et	4	main
muusika-	doc_767882159256_item	3592247	et	4	main
ning	doc_767882159256_item	3592248	et	3	main
lauluharrastusega	doc_767882159256_item	3592249	et	3	main
on	doc_767882159256_item	3592250	et	4	main
ärkamine	doc_767882159256_item	3592255	et	4	main
19	doc_767882159256_item	3592256	et	2	main
sajandi	doc_767882159256_item	3592257	et	3	main
kogukonna	doc_767882159256_item	3592266	et	4	main
eeskujul	doc_767882159256_item	3592267	et	3	main
järgnevad	doc_767882159256_item	3592279	et	4	main
laulda	doc_767882159256_item	3592280	et	4	main
laulupeosid	doc_767882159256_item	3592288	et	3	main
et	doc_767882159256_item	3592300	et	3	main
on	doc_767882159256_item	3592302	et	4	main
on	doc_767882159256_item	3592353	et	4	main
kõik	doc_767882159256_item	3592361	et	4	main
see	doc_767882159256_item	3592362	et	3	main
et	doc_767882159256_item	3592364	et	3	main
keele	doc_767882159259_item	3592387	et	4	main
teemal	doc_767882159259_item	3592392	et	3	main
teeb	doc_767882159259_item	3592394	et	3	main
essee	doc_767882159259_item	3592397	et	4	main
olema	doc_767882159259_item	3592404	et	4	main
üldistav	doc_767882159259_item	3592408	et	4	main
tuginema	doc_767882159259_item	3592409	et	3	main
loengus	doc_767882159259_item	3592410	et	3	main
ja	doc_767882159259_item	3592411	et	3	main
lugemistekstis	doc_767882159259_item	3592412	et	3	main
esitatud	doc_767882159259_item	3592413	et	4	main
faktidele	doc_767882159259_item	3592414	et	3	main
rahvas	doc_767882159259_item	3592426	et	4	main
nähtav	doc_767882159259_item	3592433	et	4	main
iseloomuga	doc_767882159259_item	3592443	et	3	main
ajades	doc_767882159259_item	3592457	et	3	main
kes	doc_767882159256_item	3592307	et	4	main
huvitunud	doc_767882159256_item	3592308	et	4	main
eesti	doc_767882159256_item	3592309	et	4	main
muusika	doc_767882159256_item	3592310	et	4	main
traditsioonides	doc_767882159256_item	3592311	et	3	main
nad	doc_767882159256_item	3592312	et	3	main
käivad	doc_767882159256_item	3592313	et	4	main
arhiivides	doc_767882159256_item	3592314	et	3	main
et	doc_767882159256_item	3592315	et	3	main
leida	doc_767882159256_item	3592316	et	3	main
rohkem	doc_767882159256_item	3592317	et	4	main
informatsiooni	doc_767882159256_item	3592318	et	4	main
sellest	doc_767882159256_item	3592319	et	4	main
see	doc_767882159256_item	3592320	et	3	main
täesti	doc_767882159256_item	3592321	et	4	main
ühendab	doc_767882159256_item	3592322	et	3	main
eesti	doc_767882159256_item	3592323	et	4	main
rahvust	doc_767882159256_item	3592324	et	3	main
laulupidu	doc_767882159256_item	3592325	et	4	main
korraldamine	doc_767882159256_item	3592326	et	4	main
ning	doc_767882159256_item	3592327	et	3	main
laule	doc_767882159256_item	3592328	et	4	main
laulmine	doc_767882159256_item	3592329	et	4	main
teeb	doc_767882159256_item	3592330	et	3	main
inimeste	doc_767882159256_item	3592331	et	3	main
omavaheliseid	doc_767882159256_item	3592332	et	4	main
suhteid	doc_767882159256_item	3592333	et	3	main
parem	doc_767882159256_item	3592334	et	4	main
sest	doc_767882159256_item	3592335	et	4	main
et	doc_767882159256_item	3592336	et	3	main
laulupidu	doc_767882159256_item	3592337	et	4	main
on	doc_767882159256_item	3592338	et	4	main
ka	doc_767882159256_item	3592339	et	3	main
maailma	doc_767882159256_item	3592356	et	4	main
sõitnud	doc_767882159256_item	3592358	et	4	main
arvatest	doc_767882159256_item	3592360	et	3	main
tähendab	doc_767882159256_item	3592363	et	3	main
mille	doc_767882159256_item	3592373	et	3	main
neist	doc_767882159256_item	3592379	et	4	main
laulurahva	doc_767882159256_item	3592380	et	3	main
essee	doc_767882159259_item	3592382	et	4	main
keele	doc_767882159259_item	3592384	et	4	main
kirjutage	doc_767882159259_item	3592390	et	3	main
essee	doc_767882159259_item	3592391	et	4	main
mis	doc_767882159259_item	3592393	et	4	main
arutlev	doc_767882159259_item	3592405	et	4	main
soovitatav	doc_767882159259_item	3592417	et	4	main
nad	doc_767882159256_item	3592375	et	3	main
ettepanekut	doc_767882159256_item	3592377	et	3	main
kirjutamine	doc_767882159259_item	3592389	et	4	main
pikkus	doc_767882159259_item	3592398	et	4	main
300	doc_767882159259_item	3592399	et	2	main
väiteid	doc_767882159259_item	3592415	et	4	main
on	doc_767882159259_item	3592416	et	4	main
teame	doc_767882159259_item	3592424	et	3	main
teistest	doc_767882159259_item	3592430	et	4	main
ajadest	doc_767882159259_item	3592436	et	4	main
ja	doc_767882159259_item	3592445	et	3	main
on	doc_767882159259_item	3592447	et	4	main
eestlase	doc_767882159259_item	3592449	et	3	main
on	doc_767882159259_item	3592452	et	4	main
veres	doc_767882159259_item	3592453	et	3	main
kui	doc_767882159259_item	3592454	et	3	main
soovite	doc_767882159259_item	3592455	et	3	main
isegi	doc_767882159259_item	3592460	et	4	main
instrumente	doc_767882159259_item	3592464	et	3	main
jalad	doc_767882159259_item	3592481	et	3	main
võitustele	doc_767882159259_item	3592491	et	4	main
tekkib	doc_767882159259_item	3592500	et	3	main
väike	doc_767882159259_item	3592504	et	4	main
riiki	doc_767882159259_item	3592512	et	4	main
vastu	doc_767882159259_item	3592513	et	3	main
aga	doc_767882159259_item	3592514	et	3	main
araneb	doc_767882159259_item	3592520	et	4	main
tean	doc_767882159259_item	3592522	et	3	main
huvi	doc_767882159259_item	3592533	et	4	main
laulupeol	doc_767882159259_item	3592574	et	4	main
tekkib	doc_767882159259_item	3592585	et	3	main
kohta	doc_767882159259_item	3592598	et	4	main
vihale	doc_767882159259_item	3592601	et	4	main
palju	doc_767882159259_item	3592607	et	4	main
see	doc_767882159259_item	3592618	et	3	main
andekas	doc_767882159259_item	3592621	et	4	main
keele	doc_767882159260_item	3592648	et	4	main
essee	doc_767882159260_item	3592655	et	4	main
mis	doc_767882159260_item	3592657	et	4	main
eestlastest	doc_767882159260_item	3592659	et	4	main
essee	doc_767882159260_item	3592661	et	4	main
pikkus	doc_767882159260_item	3592662	et	4	main
300	doc_767882159260_item	3592663	et	2	main
350	doc_767882159260_item	3592664	et	2	main
arutlev	doc_767882159260_item	3592669	et	4	main
tuginema	doc_767882159260_item	3592673	et	3	main
ja	doc_767882159260_item	3592675	et	3	main
eestlastest	doc_767882159260_item	3592686	et	4	main
laulmine	doc_767882159260_item	3592688	et	4	main
kultuurinähtus	doc_767882159260_item	3592692	et	4	main
aastast	doc_767882159260_item	3592748	et	4	main
laulupeod	doc_767882159260_item	3592752	et	4	main
aast	doc_767882159260_item	3592767	et	4	main
kujunesid	doc_767882159260_item	3592769	et	4	main
laulupeod	doc_767882159260_item	3592770	et	4	main
ja	doc_767882159260_item	3592771	et	3	main
oli	doc_767882159260_item	3592774	et	3	main
nagu	doc_767882159260_item	3592781	et	3	main
et	doc_767882159260_item	3592786	et	3	main
erinev	doc_767882159260_item	3592789	et	4	main
rahvas	doc_767882159260_item	3592790	et	4	main
ja	doc_767882159260_item	3592791	et	3	main
näe	doc_767882159260_item	3592801	et	4	main
kui	doc_767882159261_item	3592811	et	3	main
kirjutamine	doc_767882159261_item	3592815	et	4	main
mis	doc_767882159261_item	3592819	et	4	main
peab	doc_767882159261_item	3592829	et	4	main
olema	doc_767882159261_item	3592830	et	4	main
loengus	doc_767882159261_item	3592836	et	3	main
väga	doc_767882159261_item	3592848	et	3	main
laul	doc_767882159261_item	3592854	et	4	main
laulasid	doc_767882159261_item	3592859	et	4	main
nii	doc_767882159261_item	3592860	et	3	main
kodus	doc_767882159261_item	3592861	et	4	main
kui	doc_767882159261_item	3592862	et	3	main
ka	doc_767882159261_item	3592863	et	3	main
tööl	doc_767882159261_item	3592864	et	3	main
rahvalaulu	doc_767882159261_item	3592869	et	4	main
nimetatakse	doc_767882159261_item	3592870	et	3	main
enam	doc_767882159261_item	3592875	et	4	main
põlve	doc_767882159261_item	3592883	et	4	main
aastas	doc_767882159261_item	3592918	et	3	main
rahvalaul	doc_767882159259_item	3592624	et	4	main
on	doc_767882159259_item	3592625	et	4	main
sees	doc_767882159259_item	3592626	et	4	main
ja	doc_767882159259_item	3592627	et	3	main
mitte	doc_767882159259_item	3592628	et	3	main
keegi	doc_767882159259_item	3592629	et	4	main
ei	doc_767882159259_item	3592630	et	4	main
saa	doc_767882159259_item	3592631	et	4	main
seda	doc_767882159259_item	3592632	et	3	main
eesti	doc_767882159259_item	3592633	et	4	main
rahva	doc_767882159259_item	3592634	et	3	main
käest	doc_767882159259_item	3592635	et	4	main
võtta	doc_767882159259_item	3592636	et	3	main
ära	doc_767882159259_item	3592637	et	4	main
võitleme	doc_767882159259_item	3592638	et	3	main
lõppuni	doc_767882159259_item	3592639	et	3	main
ja	doc_767882159259_item	3592640	et	3	main
meie	doc_767882159259_item	3592641	et	4	main
laul	doc_767882159259_item	3592642	et	4	main
aitab	doc_767882159259_item	3592643	et	3	main
meile	doc_767882159259_item	3592644	et	4	main
eesti	doc_767882159259_item	3592383	et	4	main
kui	doc_767882159259_item	3592385	et	3	main
teise	doc_767882159259_item	3592386	et	4	main
350	doc_767882159259_item	3592400	et	2	main
sõna	doc_767882159259_item	3592401	et	4	main
essee	doc_767882159259_item	3592402	et	4	main
peab	doc_767882159259_item	3592403	et	4	main
analüüsiv	doc_767882159259_item	3592406	et	4	main
ja	doc_767882159259_item	3592407	et	3	main
rahvastest	doc_767882159259_item	3592431	et	4	main
eesti	doc_767882159259_item	3592437	et	4	main
inimene	doc_767882159259_item	3592438	et	3	main
laul	doc_767882159259_item	3592444	et	4	main
tants	doc_767882159259_item	3592446	et	3	main
vaimust	doc_767882159259_item	3592450	et	4	main
see	doc_767882159259_item	3592451	et	3	main
ei	doc_767882159259_item	3592461	et	4	main
musikaal	doc_767882159259_item	3592463	et	3	main
saa	doc_767882159259_item	3592478	et	4	main
peab	doc_767882159259_item	3592492	et	4	main
nii	doc_767882159259_item	3592503	et	3	main
mingi	doc_767882159259_item	3592508	et	4	main
suurema	doc_767882159259_item	3592509	et	4	main
ja	doc_767882159259_item	3592510	et	3	main
kuidas	doc_767882159259_item	3592518	et	3	main
et	doc_767882159259_item	3592523	et	3	main
kui	doc_767882159259_item	3592524	et	3	main
turistid	doc_767882159259_item	3592525	et	3	main
nendel	doc_767882159259_item	3592531	et	4	main
külmas	doc_767882159259_item	3592562	et	4	main
kliimas	doc_767882159259_item	3592563	et	3	main
üks	doc_767882159259_item	3592586	et	3	main
suur	doc_767882159259_item	3592587	et	3	main
aitavad	doc_767882159259_item	3592591	et	4	main
üks	doc_767882159259_item	3592592	et	3	main
probleemitele	doc_767882159259_item	3592599	et	4	main
ja	doc_767882159259_item	3592602	et	3	main
rahva	doc_767882159259_item	3592609	et	3	main
teevad	doc_767882159259_item	3592611	et	3	main
erinevaid	doc_767882159259_item	3592612	et	4	main
tuleb	doc_767882159259_item	3592617	et	3	main
välja	doc_767882159259_item	3592619	et	4	main
huvitavaks	doc_767882159259_item	3592623	et	4	main
essee	doc_767882159260_item	3592646	et	4	main
kirjutage	doc_767882159260_item	3592654	et	3	main
laulurahva	doc_767882159260_item	3592660	et	3	main
olema	doc_767882159260_item	3592668	et	4	main
üldistav	doc_767882159260_item	3592672	et	4	main
lugemistekstis	doc_767882159260_item	3592676	et	3	main
faktidele	doc_767882159260_item	3592678	et	3	main
palju	doc_767882159260_item	3592690	et	4	main
eestlastele	doc_767882159260_item	3592696	et	4	main
ja	doc_767882159260_item	3592701	et	3	main
mitte	doc_767882159260_item	3592706	et	3	main
1869	doc_767882159260_item	3592749	et	2	main
aastast	doc_767882159260_item	3592766	et	4	main
rahvast	doc_767882159260_item	3592776	et	4	main
hea	doc_767882159260_item	3592782	et	4	main
nad	doc_767882159260_item	3592792	et	3	main
määletavad	doc_767882159260_item	3592795	et	4	main
eesti	doc_767882159261_item	3592809	et	4	main
keele	doc_767882159261_item	3592813	et	4	main
essee	doc_767882159261_item	3592817	et	4	main
laulurahva	doc_767882159261_item	3592822	et	3	main
sõna	doc_767882159261_item	3592827	et	4	main
analüüsiv	doc_767882159261_item	3592832	et	4	main
ja	doc_767882159261_item	3592833	et	3	main
esitatud	doc_767882159261_item	3592839	et	4	main
väiteid	doc_767882159261_item	3592841	et	4	main
soovitatav	doc_767882159261_item	3592843	et	4	main
illustreerida	doc_767882159261_item	3592844	et	3	main
näidetega	doc_767882159261_item	3592845	et	3	main
kultuurinähtus	doc_767882159261_item	3592850	et	4	main
vanal	doc_767882159261_item	3592851	et	3	main
ajal	doc_767882159261_item	3592852	et	4	main
saatis	doc_767882159261_item	3592853	et	3	main
hällist	doc_767882159261_item	3592856	et	4	main
on	doc_767882159261_item	3592873	et	4	main
pärandati	doc_767882159261_item	3592881	et	4	main
tallinnas	doc_767882159261_item	3592915	et	4	main
mis	doc_767882159261_item	3592919	et	4	main
kadriorus	doc_767882159261_item	3592921	et	3	main
eestlastel	doc_767882159261_item	3592924	et	4	main
vaid	doc_767882159261_item	3592930	et	3	main
sõitnud	doc_767882159261_item	3592976	et	4	main
meelest	doc_767882159261_item	3592988	et	4	main
illustreerida	doc_767882159259_item	3592418	et	3	main
näidetega	doc_767882159259_item	3592419	et	3	main
nagu	doc_767882159259_item	3592420	et	3	main
kõik	doc_767882159259_item	3592421	et	4	main
meie	doc_767882159259_item	3592422	et	4	main
eesti	doc_767882159259_item	3592425	et	4	main
hästi	doc_767882159259_item	3592427	et	3	main
tugevalt	doc_767882159259_item	3592428	et	4	main
erineb	doc_767882159259_item	3592429	et	3	main
et	doc_767882159259_item	3592434	et	3	main
vanematest	doc_767882159259_item	3592435	et	4	main
ja	doc_767882159259_item	3592442	et	3	main
aranenud	doc_767882159259_item	3592448	et	4	main
hinges	doc_767882159259_item	3592470	et	4	main
ja	doc_767882159259_item	3592471	et	3	main
kui	doc_767882159259_item	3592472	et	3	main
sa	doc_767882159259_item	3592473	et	3	main
kuulad	doc_767882159259_item	3592474	et	3	main
muusikat	doc_767882159259_item	3592475	et	3	main
sa	doc_767882159259_item	3592476	et	3	main
ei	doc_767882159259_item	3592477	et	4	main
seista	doc_767882159259_item	3592480	et	4	main
mina	doc_767882159259_item	3592485	et	4	main
olen	doc_767882159259_item	3592486	et	3	main
kindel	doc_767882159259_item	3592487	et	3	main
et	doc_767882159259_item	3592488	et	3	main
mõnedele	doc_767882159259_item	3592489	et	3	main
ajaloo	doc_767882159259_item	3592490	et	4	main
rahvalauludele	doc_767882159259_item	3592496	et	3	main
sellepärast	doc_767882159259_item	3592497	et	3	main
mõni	doc_767882159259_item	3592498	et	3	main
kord	doc_767882159259_item	3592499	et	4	main
näed	doc_767882159259_item	3592517	et	3	main
laulupeole	doc_767882159259_item	3592529	et	4	main
tekkima	doc_767882159259_item	3592530	et	3	main
ja	doc_767882159259_item	3592575	et	3	main
kõik	doc_767882159259_item	3592578	et	4	main
eesti	doc_767882159259_item	3592581	et	4	main
või	doc_767882159259_item	3592583	et	4	main
raadiost	doc_767882159259_item	3592582	et	3	main
jooksevad	doc_767882159259_item	3592483	et	4	main
olema	doc_767882159259_item	3592493	et	4	main
tänulik	doc_767882159259_item	3592494	et	3	main
küsimus	doc_767882159259_item	3592501	et	4	main
võib	doc_767882159259_item	3592506	et	3	main
tugeva	doc_767882159259_item	3592511	et	4	main
sattuvad	doc_767882159259_item	3592528	et	4	main
laulude	doc_767882159259_item	3592534	et	3	main
vastu	doc_767882159259_item	3592535	et	3	main
nad	doc_767882159259_item	3592536	et	3	main
tahavad	doc_767882159259_item	3592537	et	3	main
teada	doc_767882159259_item	3592538	et	3	main
millest	doc_767882159259_item	3592539	et	3	main
on	doc_767882159259_item	3592540	et	4	main
see	doc_767882159259_item	3592541	et	3	main
või	doc_767882159259_item	3592542	et	4	main
too	doc_767882159259_item	3592543	et	4	main
laul	doc_767882159259_item	3592544	et	4	main
mõned	doc_767882159259_item	3592545	et	3	main
välismaalased	doc_767882159259_item	3592546	et	3	main
isegi	doc_767882159259_item	3592547	et	4	main
püüavad	doc_767882159259_item	3592548	et	3	main
laule	doc_767882159259_item	3592549	et	4	main
üle	doc_767882159259_item	3592550	et	3	main
kirjutada	doc_767882159259_item	3592551	et	3	main
turistidele	doc_767882159259_item	3592552	et	3	main
on	doc_767882159259_item	3592553	et	4	main
see	doc_767882159259_item	3592554	et	3	main
imeline	doc_767882159259_item	3592555	et	4	main
kuidas	doc_767882159259_item	3592556	et	3	main
võib	doc_767882159259_item	3592557	et	3	main
rahvas	doc_767882159259_item	3592558	et	4	main
mis	doc_767882159259_item	3592559	et	4	main
elab	doc_767882159259_item	3592560	et	3	main
nii	doc_767882159259_item	3592561	et	3	main
olla	doc_767882159259_item	3592564	et	3	main
nii	doc_767882159259_item	3592565	et	3	main
soe	doc_767882159259_item	3592566	et	4	main
ja	doc_767882159259_item	3592567	et	3	main
sõbralik	doc_767882159259_item	3592568	et	3	main
kui	doc_767882159259_item	3592569	et	3	main
25	doc_767882159259_item	3592570	et	2	main
000	doc_767882159259_item	3592571	et	2	main
inimest	doc_767882159259_item	3592572	et	3	main
laulab	doc_767882159259_item	3592573	et	3	main
ja	doc_767882159259_item	3592594	et	3	main
kus	doc_767882159259_item	3592595	et	3	main
ei	doc_767882159259_item	3592596	et	4	main
oma	doc_767882159259_item	3592608	et	4	main
puhul	doc_767882159259_item	3592615	et	4	main
väga	doc_767882159259_item	3592620	et	3	main
ja	doc_767882159259_item	3592622	et	3	main
teisele	doc_767882159259_item	3592593	et	4	main
ja	doc_767882159259_item	3592600	et	3	main
isegi	doc_767882159259_item	3592603	et	4	main
tänapäevased	doc_767882159259_item	3592604	et	4	main
noored	doc_767882159259_item	3592605	et	3	main
teavad	doc_767882159259_item	3592606	et	3	main
mixi	doc_767882159259_item	3592613	et	4	main
rahvalaulude	doc_767882159259_item	3592614	et	3	main
kui	doc_767882159260_item	3592649	et	3	main
kirjutamine	doc_767882159260_item	3592653	et	4	main
sõna	doc_767882159260_item	3592665	et	4	main
analüüsiv	doc_767882159260_item	3592670	et	4	main
soovitatav	doc_767882159260_item	3592681	et	4	main
illustreerida	doc_767882159260_item	3592682	et	3	main
näidetega	doc_767882159260_item	3592683	et	3	main
on	doc_767882159260_item	3592689	et	4	main
mitte	doc_767882159260_item	3592694	et	3	main
on	doc_767882159260_item	3592698	et	4	main
kõik	doc_767882159260_item	3592746	et	4	main
aitasid	doc_767882159260_item	3592753	et	4	main
eestlastele	doc_767882159260_item	3592754	et	4	main
halval	doc_767882159260_item	3592755	et	3	main
eestlased	doc_767882159260_item	3592768	et	3	main
rohkem	doc_767882159260_item	3592775	et	4	main
peod	doc_767882159260_item	3592779	et	4	main
ei	doc_767882159260_item	3592800	et	4	main
hüüakse	doc_767882159260_item	3592805	et	4	main
laulurahvaks	doc_767882159260_item	3592806	et	3	main
essee	doc_767882159261_item	3592808	et	4	main
teeb	doc_767882159261_item	3592820	et	3	main
essee	doc_767882159261_item	3592828	et	4	main
tuginema	doc_767882159261_item	3592835	et	3	main
on	doc_767882159261_item	3592842	et	4	main
laulmine	doc_767882159261_item	3592846	et	4	main
regilaul	doc_767882159261_item	3592871	et	4	main
kui	doc_767882159261_item	3592876	et	3	main
aastat	doc_767882159261_item	3592877	et	3	main
tagasi	doc_767882159261_item	3592878	et	3	main
sellest	doc_767882159261_item	3592908	et	4	main
alguse	doc_767882159261_item	3592910	et	3	main
1928	doc_767882159261_item	3592917	et	2	main
toimus	doc_767882159261_item	3592920	et	3	main
kus	doc_767882159261_item	3592927	et	3	main
laulma	doc_767882159261_item	3592929	et	3	main
maailma	doc_767882159261_item	3592974	et	4	main
kokku	doc_767882159261_item	3592975	et	3	main
peos	doc_767882159261_item	3592986	et	4	main
minu	doc_767882159261_item	3592987	et	3	main
rõõmus	doc_767882159261_item	3592998	et	4	main
on	doc_767882159261_item	3593001	et	4	main
oma	doc_767882159261_item	3593003	et	4	main
keele	doc_767882159262_item	3593024	et	4	main
teemal	doc_767882159262_item	3593029	et	3	main
laulurahva	doc_767882159262_item	3593033	et	3	main
essee	doc_767882159262_item	3593039	et	4	main
peab	doc_767882159262_item	3593040	et	4	main
olema	doc_767882159262_item	3593041	et	4	main
arutlev	doc_767882159262_item	3593042	et	4	main
faktidele	doc_767882159262_item	3593051	et	3	main
soovitatav	doc_767882159262_item	3593054	et	4	main
illustreerida	doc_767882159262_item	3593055	et	3	main
näidetega	doc_767882159262_item	3593056	et	3	main
mis	doc_767882159262_item	3593057	et	4	main
teeb	doc_767882159262_item	3593058	et	3	main
laulurahva	doc_767882159262_item	3593068	et	3	main
üks	doc_767882159262_item	3593073	et	3	main
135	doc_767882159262_item	3593086	et	2	main
aastat	doc_767882159262_item	3593087	et	3	main
voldemar	doc_767882159262_item	3593128	et	4	main
rahvuslik	doc_767882159262_item	3593137	et	3	main
kui	doc_767882159263_item	3593203	et	3	main
keele	doc_767882159263_item	3593205	et	4	main
eestlastest	doc_767882159263_item	3593213	et	4	main
laulurahva	doc_767882159263_item	3593214	et	3	main
350	doc_767882159263_item	3593218	et	2	main
arutlev	doc_767882159263_item	3593223	et	4	main
loengus	doc_767882159263_item	3593228	et	3	main
esitatud	doc_767882159263_item	3593231	et	4	main
on	doc_767882159263_item	3593239	et	4	main
väga	doc_767882159263_item	3593240	et	3	main
parem	doc_767882159263_item	3593268	et	4	main
laulust	doc_767882159259_item	3592610	et	4	main
ja	doc_767882159259_item	3592616	et	3	main
teise	doc_767882159260_item	3592650	et	4	main
keele	doc_767882159260_item	3592651	et	4	main
teeb	doc_767882159260_item	3592658	et	3	main
ja	doc_767882159260_item	3592671	et	3	main
mis	doc_767882159260_item	3592684	et	4	main
teeb	doc_767882159260_item	3592685	et	3	main
rahvaste	doc_767882159260_item	3592691	et	4	main
ainult	doc_767882159260_item	3592695	et	4	main
see	doc_767882159260_item	3592697	et	3	main
emotsionaalne	doc_767882159260_item	3592699	et	3	main
väljendusvahe	doc_767882159260_item	3592700	et	4	main
kindlasti	doc_767882159260_item	3592702	et	3	main
võin	doc_767882159260_item	3592703	et	3	main
et	doc_767882159260_item	3592705	et	3	main
ainult	doc_767882159260_item	3592707	et	4	main
eestis	doc_767882159260_item	3592708	et	3	main
vanal	doc_767882159260_item	3592709	et	3	main
laulupeod	doc_767882159260_item	3592747	et	4	main
tänapäevani	doc_767882159260_item	3592751	et	3	main
ajal	doc_767882159260_item	3592756	et	4	main
eriti	doc_767882159260_item	3592757	et	3	main
kui	doc_767882159260_item	3592758	et	3	main
eesti	doc_767882159260_item	3592759	et	4	main
oli	doc_767882159260_item	3592760	et	3	main
tsaristliku	doc_767882159260_item	3592761	et	3	main
venemaa	doc_767882159260_item	3592762	et	4	main
koosseisus	doc_767882159260_item	3592763	et	4	main
või	doc_767882159260_item	3592764	et	4	main
nsvliidus	doc_767882159260_item	3592765	et	4	main
on	doc_767882159260_item	3592743	et	4	main
laulurahvas	doc_767882159260_item	3592744	et	4	main
näiteks	doc_767882159260_item	3592745	et	4	main
eesti	doc_767882159260_item	3592647	et	4	main
test	doc_767882159260_item	3592652	et	3	main
teemal	doc_767882159260_item	3592656	et	3	main
essee	doc_767882159260_item	3592666	et	4	main
peab	doc_767882159260_item	3592667	et	4	main
loengus	doc_767882159260_item	3592674	et	3	main
esitatud	doc_767882159260_item	3592677	et	4	main
väiteid	doc_767882159260_item	3592679	et	4	main
on	doc_767882159260_item	3592680	et	4	main
laulurahva	doc_767882159260_item	3592687	et	3	main
ja	doc_767882159260_item	3592693	et	3	main
öelda	doc_767882159260_item	3592704	et	4	main
ajal	doc_767882159260_item	3592710	et	4	main
lauldi	doc_767882159260_item	3592711	et	3	main
üksi	doc_767882159260_item	3592712	et	4	main
olles	doc_767882159260_item	3592713	et	3	main
töötades	doc_767882159260_item	3592714	et	3	main
last	doc_767882159260_item	3592715	et	4	main
kiigutades	doc_767882159260_item	3592716	et	3	main
nagu	doc_767882159260_item	3592717	et	3	main
tekstis	doc_767882159260_item	3592718	et	3	main
kirjas	doc_767882159260_item	3592719	et	4	main
on	doc_767882159260_item	3592720	et	4	main
kõikidel	doc_767882159260_item	3592721	et	4	main
rahvastel	doc_767882159260_item	3592722	et	4	main
on	doc_767882159260_item	3592723	et	4	main
olemas	doc_767882159260_item	3592724	et	4	main
vanad	doc_767882159260_item	3592725	et	3	main
laulud	doc_767882159260_item	3592726	et	3	main
tantsud	doc_767882159260_item	3592727	et	3	main
jne	doc_767882159260_item	3592728	et	4	main
mis	doc_767882159260_item	3592729	et	4	main
olid	doc_767882159260_item	3592730	et	4	main
pärandatud	doc_767882159260_item	3592731	et	4	main
põlvest	doc_767882159260_item	3592732	et	4	main
põlve	doc_767882159260_item	3592733	et	4	main
aga	doc_767882159260_item	3592734	et	3	main
ajaloos	doc_767882159260_item	3592735	et	4	main
on	doc_767882159260_item	3592736	et	4	main
näidised	doc_767882159260_item	3592737	et	3	main
mis	doc_767882159260_item	3592738	et	4	main
põhjendavad	doc_767882159260_item	3592739	et	4	main
seda	doc_767882159260_item	3592740	et	3	main
et	doc_767882159260_item	3592741	et	3	main
eestlased	doc_767882159260_item	3592742	et	3	main
ja	doc_767882159260_item	3592750	et	3	main
kui	doc_767882159260_item	3592777	et	3	main
eelmisel	doc_767882159260_item	3592778	et	3	main
võimalus	doc_767882159260_item	3592783	et	3	main
igal	doc_767882159260_item	3592772	et	3	main
järgmisel	doc_767882159260_item	3592773	et	3	main
oli	doc_767882159260_item	3592780	et	3	main
näidata	doc_767882159260_item	3592785	et	4	main
on	doc_767882159260_item	3592788	et	4	main
ja	doc_767882159260_item	3592794	et	3	main
oma	doc_767882159260_item	3592796	et	4	main
traditsioonid	doc_767882159260_item	3592797	et	3	main
rohkem	doc_767882159260_item	3592798	et	4	main
ma	doc_767882159260_item	3592799	et	3	main
eestlaste	doc_767882159260_item	3592804	et	4	main
keele	doc_767882159261_item	3592810	et	4	main
teemal	doc_767882159261_item	3592818	et	3	main
eestlastest	doc_767882159261_item	3592821	et	4	main
essee	doc_767882159261_item	3592823	et	4	main
pikkus	doc_767882159261_item	3592824	et	4	main
300	doc_767882159261_item	3592825	et	2	main
350	doc_767882159261_item	3592826	et	2	main
arutlev	doc_767882159261_item	3592831	et	4	main
ja	doc_767882159261_item	3592837	et	3	main
faktidele	doc_767882159261_item	3592840	et	3	main
on	doc_767882159261_item	3592847	et	4	main
oluline	doc_767882159261_item	3592849	et	4	main
eestlast	doc_767882159261_item	3592855	et	4	main
hauani	doc_767882159261_item	3592857	et	3	main
eestlased	doc_767882159261_item	3592858	et	3	main
eesti	doc_767882159261_item	3592867	et	4	main
vanemat	doc_767882159261_item	3592868	et	4	main
kujunenud	doc_767882159261_item	3592874	et	4	main
põlvest	doc_767882159261_item	3592882	et	4	main
sai	doc_767882159261_item	3592909	et	4	main
laulupidude	doc_767882159261_item	3592911	et	4	main
traditsioon	doc_767882159261_item	3592912	et	3	main
esimene	doc_767882159261_item	3592913	et	3	main
laulupidu	doc_767882159261_item	3592914	et	4	main
suur	doc_767882159261_item	3592963	et	3	main
rahvapidu	doc_767882159261_item	3592964	et	4	main
kuhu	doc_767882159261_item	3592965	et	3	main
tullakse	doc_767882159261_item	3592966	et	3	main
koos	doc_767882159261_item	3592967	et	4	main
perega	doc_767882159261_item	3592968	et	3	main
kes	doc_767882159261_item	3592971	et	4	main
laulupidu	doc_767882159261_item	3592977	et	4	main
pakub	doc_767882159261_item	3592978	et	3	main
mitte	doc_767882159261_item	3592979	et	3	main
rahvas	doc_767882159261_item	3592999	et	4	main
test	doc_767882159262_item	3593025	et	3	main
eestlastest	doc_767882159262_item	3593059	et	4	main
laulurahva	doc_767882159262_item	3593060	et	3	main
kui	doc_767882159262_item	3593061	et	3	main
ma	doc_767882159262_item	3593062	et	3	main
kuulen	doc_767882159262_item	3593063	et	3	main
tuleb	doc_767882159262_item	3593071	et	3	main
137	doc_767882159262_item	3593121	et	2	main
kõikidele	doc_767882159260_item	3592784	et	4	main
eestlased	doc_767882159260_item	3592787	et	3	main
armastavad	doc_767882159260_item	3592793	et	4	main
põhjust	doc_767882159260_item	3592802	et	4	main
miks	doc_767882159260_item	3592803	et	4	main
teise	doc_767882159261_item	3592812	et	4	main
test	doc_767882159261_item	3592814	et	3	main
kirjutage	doc_767882159261_item	3592816	et	3	main
üldistav	doc_767882159261_item	3592834	et	4	main
lugemistekstis	doc_767882159261_item	3592838	et	3	main
õues	doc_767882159261_item	3592865	et	4	main
pidudes	doc_767882159261_item	3592866	et	4	main
mis	doc_767882159261_item	3592872	et	4	main
regivärsiline	doc_767882159261_item	3592879	et	4	main
rahvalaul	doc_767882159261_item	3592880	et	4	main
suuliselt	doc_767882159261_item	3592884	et	4	main
ja	doc_767882159261_item	3592885	et	3	main
neid	doc_767882159261_item	3592886	et	4	main
lauldi	doc_767882159261_item	3592887	et	3	main
ilma	doc_767882159261_item	3592888	et	4	main
pillisaateta	doc_767882159261_item	3592889	et	3	main
1869	doc_767882159261_item	3592890	et	2	main
aastal	doc_767882159261_item	3592891	et	3	main
kujunes	doc_767882159261_item	3592892	et	3	main
esimene	doc_767882159261_item	3592893	et	3	main
ülemaaline	doc_767882159261_item	3592894	et	4	main
laulupidu	doc_767882159261_item	3592895	et	4	main
kus	doc_767882159261_item	3592897	et	3	main
tartus	doc_767882159261_item	3592896	et	3	main
osales	doc_767882159261_item	3592898	et	3	main
46	doc_767882159261_item	3592899	et	2	main
meekoori	doc_767882159261_item	3592900	et	4	main
822	doc_767882159261_item	3592901	et	2	main
lauljaga	doc_767882159261_item	3592902	et	4	main
ja	doc_767882159261_item	3592903	et	3	main
5	doc_767882159261_item	3592904	et	2	main
puhkpilliorkestrit	doc_767882159261_item	3592905	et	3	main
56	doc_767882159261_item	3592906	et	2	main
mängijaga	doc_767882159261_item	3592907	et	4	main
toimus	doc_767882159261_item	3592916	et	3	main
praegusel	doc_767882159261_item	3592922	et	3	main
tähtis	doc_767882159261_item	3592926	et	4	main
kohas	doc_767882159261_item	3592928	et	4	main
kellega	doc_767882159261_item	3592931	et	3	main
ja	doc_767882159261_item	3592932	et	3	main
mis	doc_767882159261_item	3592933	et	4	main
lauldi	doc_767882159261_item	3592934	et	3	main
kahekesi	doc_767882159261_item	3592936	et	3	main
kolmekesi	doc_767882159261_item	3592937	et	3	main
üksi	doc_767882159261_item	3592935	et	4	main
kooris	doc_767882159261_item	3592938	et	4	main
ringis	doc_767882159261_item	3592939	et	4	main
jne	doc_767882159261_item	3592940	et	4	main
regilaule	doc_767882159261_item	3592941	et	4	main
laulsid	doc_767882159261_item	3592942	et	4	main
naised	doc_767882159261_item	3592943	et	3	main
ainult	doc_767882159261_item	3592944	et	4	main
vokaalselt	doc_767882159261_item	3592945	et	4	main
ilma	doc_767882159261_item	3592946	et	4	main
muusika	doc_767882159261_item	3592947	et	4	main
instrumente	doc_767882159261_item	3592948	et	3	main
eestlastel	doc_767882159261_item	3592949	et	4	main
oli	doc_767882159261_item	3592950	et	3	main
ka	doc_767882159261_item	3592951	et	3	main
väga	doc_767882159261_item	3592952	et	3	main
oluline	doc_767882159261_item	3592953	et	4	main
naaber	doc_767882159261_item	3592954	et	3	main
laulu	doc_767882159261_item	3592955	et	4	main
näiteks	doc_767882159261_item	3592956	et	4	main
lätimaa	doc_767882159261_item	3592957	et	4	main
ja	doc_767882159261_item	3592958	et	3	main
venemaa	doc_767882159261_item	3592959	et	4	main
laulupidu	doc_767882159261_item	3592960	et	4	main
on	doc_767882159261_item	3592961	et	4	main
ka	doc_767882159261_item	3592962	et	3	main
lauluväljakul	doc_767882159261_item	3592923	et	3	main
pole	doc_767882159261_item	3592925	et	3	main
sugulastega	doc_767882159261_item	3592969	et	4	main
eestlastest	doc_767882159261_item	3592989	et	4	main
teeb	doc_767882159261_item	3592990	et	3	main
laulurahva	doc_767882159261_item	3592991	et	3	main
see	doc_767882159261_item	3592992	et	3	main
et	doc_767882159261_item	3592993	et	3	main
nad	doc_767882159261_item	3592994	et	3	main
on	doc_767882159261_item	3592995	et	4	main
emotsionaalne	doc_767882159261_item	3592996	et	3	main
esteetiline	doc_767882159261_item	3592997	et	3	main
kellel	doc_767882159261_item	3593000	et	4	main
tegevus	doc_767882159261_item	3593007	et	4	main
essee	doc_767882159262_item	3593019	et	4	main
teise	doc_767882159262_item	3593023	et	4	main
kirjutage	doc_767882159262_item	3593027	et	3	main
sõna	doc_767882159262_item	3593038	et	4	main
ja	doc_767882159262_item	3593044	et	3	main
üldistav	doc_767882159262_item	3593045	et	4	main
tuginema	doc_767882159262_item	3593046	et	3	main
lugemistekstis	doc_767882159262_item	3593049	et	3	main
meelde	doc_767882159262_item	3593072	et	3	main
suurimatest	doc_767882159262_item	3593074	et	4	main
rahvalaulupidu	doc_767882159262_item	3593076	et	4	main
laulupidu	doc_767882159262_item	3593124	et	4	main
mida	doc_767882159262_item	3593125	et	4	main
organiseeris	doc_767882159262_item	3593126	et	3	main
johann	doc_767882159262_item	3593127	et	4	main
ja	doc_767882159262_item	3593134	et	3	main
see	doc_767882159262_item	3593135	et	3	main
tähendab	doc_767882159262_item	3593140	et	3	main
laul	doc_767882159262_item	3593145	et	4	main
sõpradega	doc_767882159261_item	3592970	et	3	main
on	doc_767882159261_item	3592972	et	4	main
kogu	doc_767882159261_item	3592973	et	4	main
ainult	doc_767882159261_item	3592980	et	4	main
võimalust	doc_767882159261_item	3592981	et	3	main
laulu	doc_767882159261_item	3592982	et	4	main
kuulama	doc_767882159261_item	3592983	et	3	main
vaid	doc_767882159261_item	3592984	et	3	main
osaleda	doc_767882159261_item	3592985	et	3	main
kultuuri	doc_767882159261_item	3593004	et	4	main
ja	doc_767882159261_item	3593005	et	3	main
sotsiaalne	doc_767882159261_item	3593006	et	3	main
oluline	doc_767882159261_item	3593002	et	4	main
minu	doc_767882159261_item	3593009	et	3	main
sest	doc_767882159261_item	3593008	et	4	main
meelest	doc_767882159261_item	3593010	et	4	main
rahvalaulad	doc_767882159261_item	3593011	et	4	main
kõige	doc_767882159261_item	3593012	et	4	main
parem	doc_767882159261_item	3593013	et	4	main
iseloomustavad	doc_767882159261_item	3593014	et	4	main
oma	doc_767882159261_item	3593015	et	4	main
tõeline	doc_767882159261_item	3593016	et	4	main
rahvas	doc_767882159261_item	3593017	et	4	main
eesti	doc_767882159262_item	3593020	et	4	main
keele	doc_767882159262_item	3593021	et	4	main
kui	doc_767882159262_item	3593022	et	3	main
kirjutamine	doc_767882159262_item	3593026	et	4	main
teeb	doc_767882159262_item	3593031	et	3	main
analüüsiv	doc_767882159262_item	3593043	et	4	main
loengus	doc_767882159262_item	3593047	et	3	main
esitatud	doc_767882159262_item	3593050	et	4	main
on	doc_767882159262_item	3593053	et	4	main
mis	doc_767882159262_item	3593065	et	4	main
teeb	doc_767882159262_item	3593066	et	3	main
eestlastest	doc_767882159262_item	3593067	et	4	main
pealt	doc_767882159262_item	3593070	et	4	main
iga	doc_767882159262_item	3593081	et	4	main
5	doc_767882159262_item	3593082	et	2	main
aastat	doc_767882159262_item	3593083	et	3	main
juba	doc_767882159262_item	3593084	et	3	main
üle	doc_767882159262_item	3593085	et	3	main
hällist	doc_767882159262_item	3593119	et	4	main
tagasi	doc_767882159262_item	3593123	et	3	main
jannsen	doc_767882159262_item	3593129	et	4	main
ühines	doc_767882159262_item	3593130	et	3	main
ärkamiseaeg	doc_767882159262_item	3593138	et	4	main
muusika	doc_767882159262_item	3593142	et	4	main
essee	doc_767882159263_item	3593200	et	4	main
test	doc_767882159263_item	3593206	et	3	main
essee	doc_767882159263_item	3593209	et	4	main
teemal	doc_767882159263_item	3593210	et	3	main
mis	doc_767882159263_item	3593211	et	4	main
teeb	doc_767882159263_item	3593212	et	3	main
300	doc_767882159263_item	3593217	et	2	main
analüüsiv	doc_767882159263_item	3593224	et	4	main
ja	doc_767882159263_item	3593225	et	3	main
tuginema	doc_767882159263_item	3593227	et	3	main
lugemistekstis	doc_767882159263_item	3593230	et	3	main
on	doc_767882159263_item	3593234	et	4	main
ajaloos	doc_767882159263_item	3593245	et	4	main
kõige	doc_767882159263_item	3593276	et	4	main
aasta	doc_767882159263_item	3593283	et	4	main
millal	doc_767882159263_item	3593284	et	3	main
kujunes	doc_767882159263_item	3593285	et	3	main
laulupidu	doc_767882159263_item	3593288	et	4	main
aastal	doc_767882159263_item	3593290	et	3	main
tuli	doc_767882159263_item	3593300	et	4	main
1988	doc_767882159263_item	3593327	et	2	main
tuhanded	doc_767882159263_item	3593346	et	3	main
ja	doc_767882159263_item	3593348	et	3	main
orkestriid	doc_767882159263_item	3593350	et	3	main
koht	doc_767882159263_item	3593352	et	3	main
tallinna	doc_767882159263_item	3593354	et	4	main
mis	doc_767882159263_item	3593356	et	4	main
eesti	doc_767882159263_item	3593366	et	4	main
rahva	doc_767882159263_item	3593367	et	3	main
eesti	doc_767882159265_item	3593370	et	4	main
keele	doc_767882159265_item	3593371	et	4	main
kui	doc_767882159265_item	3593372	et	3	main
teemal	doc_767882159265_item	3593379	et	3	main
essee	doc_767882159265_item	3593384	et	4	main
350	doc_767882159265_item	3593387	et	2	main
sõna	doc_767882159265_item	3593388	et	4	main
essee	doc_767882159265_item	3593389	et	4	main
need	doc_767882159262_item	3593178	et	3	main
faktid	doc_767882159262_item	3593179	et	3	main
teevad	doc_767882159262_item	3593180	et	3	main
eestlasi	doc_767882159262_item	3593181	et	3	main
laulurahvaks	doc_767882159262_item	3593182	et	3	main
selle	doc_767882159262_item	3593183	et	4	main
pärast	doc_767882159262_item	3593184	et	4	main
et	doc_767882159262_item	3593185	et	3	main
ma	doc_767882159262_item	3593186	et	3	main
ei	doc_767882159262_item	3593187	et	4	main
tea	doc_767882159262_item	3593188	et	4	main
teis	doc_767882159262_item	3593189	et	4	main
riiki	doc_767882159262_item	3593190	et	4	main
kus	doc_767882159262_item	3593191	et	3	main
inimeste	doc_767882159262_item	3593192	et	3	main
ellu	doc_767882159262_item	3593193	et	4	main
mõjub	doc_767882159262_item	3593194	et	3	main
muusika	doc_767882159262_item	3593195	et	4	main
rohkem	doc_767882159262_item	3593196	et	4	main
kui	doc_767882159262_item	3593197	et	3	main
eestlastele	doc_767882159262_item	3593198	et	4	main
essee	doc_767882159262_item	3593028	et	4	main
mis	doc_767882159262_item	3593030	et	4	main
eestlastest	doc_767882159262_item	3593032	et	4	main
essee	doc_767882159262_item	3593034	et	4	main
pikkus	doc_767882159262_item	3593035	et	4	main
300	doc_767882159262_item	3593036	et	2	main
350	doc_767882159262_item	3593037	et	2	main
ja	doc_767882159262_item	3593048	et	3	main
väiteid	doc_767882159262_item	3593052	et	4	main
küsimust	doc_767882159262_item	3593064	et	4	main
kõige	doc_767882159262_item	3593069	et	4	main
maailmas	doc_767882159262_item	3593075	et	3	main
mis	doc_767882159262_item	3593077	et	4	main
toimub	doc_767882159262_item	3593078	et	3	main
tallinna	doc_767882159262_item	3593079	et	4	main
lauluväljakul	doc_767882159262_item	3593080	et	3	main
sellise	doc_767882159262_item	3593088	et	4	main
suure	doc_767882159262_item	3593089	et	3	main
laulupeo	doc_767882159262_item	3593090	et	4	main
üritamine	doc_767882159262_item	3593091	et	4	main
näitab	doc_767882159262_item	3593092	et	3	main
et	doc_767882159262_item	3593093	et	3	main
eestlaste	doc_767882159262_item	3593094	et	4	main
kultuur	doc_767882159262_item	3593095	et	3	main
oli	doc_767882159262_item	3593096	et	3	main
seotud	doc_767882159262_item	3593097	et	4	main
igal	doc_767882159262_item	3593098	et	3	main
ajal	doc_767882159262_item	3593099	et	4	main
muusikaga	doc_767882159262_item	3593100	et	3	main
inimesed	doc_767882159262_item	3593101	et	3	main
lauldi	doc_767882159262_item	3593102	et	3	main
üksi	doc_767882159262_item	3593103	et	4	main
olles	doc_767882159262_item	3593104	et	3	main
töötaded	doc_767882159262_item	3593105	et	4	main
last	doc_767882159262_item	3593106	et	4	main
kiigutades	doc_767882159262_item	3593107	et	3	main
nad	doc_767882159262_item	3593108	et	3	main
laulsid	doc_767882159262_item	3593109	et	4	main
koguaeg	doc_767882159262_item	3593110	et	3	main
selle	doc_767882159262_item	3593111	et	4	main
pärast	doc_767882159262_item	3593112	et	4	main
et	doc_767882159262_item	3593113	et	3	main
vanal	doc_767882159262_item	3593114	et	3	main
ajal	doc_767882159262_item	3593115	et	4	main
saatis	doc_767882159262_item	3593116	et	3	main
laul	doc_767882159262_item	3593117	et	4	main
eestlast	doc_767882159262_item	3593118	et	4	main
hauani	doc_767882159262_item	3593120	et	3	main
aastat	doc_767882159262_item	3593122	et	3	main
see	doc_767882159262_item	3593139	et	3	main
et	doc_767882159262_item	3593141	et	3	main
eesti	doc_767882159262_item	3593131	et	4	main
rahva	doc_767882159262_item	3593132	et	3	main
liikumist	doc_767882159262_item	3593133	et	4	main
oli	doc_767882159262_item	3593136	et	3	main
tants	doc_767882159262_item	3593143	et	3	main
eestlastele	doc_767882159262_item	3593147	et	4	main
saada	doc_767882159262_item	3593148	et	4	main
iseseisvak	doc_767882159262_item	3593149	et	4	main
riigiks	doc_767882159262_item	3593150	et	3	main
tänapäevadel	doc_767882159262_item	3593151	et	3	main
rahvalaulud	doc_767882159262_item	3593152	et	3	main
on	doc_767882159262_item	3593153	et	4	main
väga	doc_767882159262_item	3593154	et	3	main
populaarsed	doc_767882159262_item	3593155	et	3	main
eestis	doc_767882159262_item	3593156	et	3	main
neid	doc_767882159262_item	3593157	et	4	main
lauldakse	doc_767882159262_item	3593158	et	3	main
paljudes	doc_767882159262_item	3593159	et	3	main
koorides	doc_767882159262_item	3593160	et	4	main
mõned	doc_767882159262_item	3593161	et	3	main
laulavad	doc_767882159262_item	3593162	et	4	main
rahvalaulu	doc_767882159262_item	3593163	et	4	main
koos	doc_767882159262_item	3593164	et	4	main
rokk	doc_767882159262_item	3593165	et	3	main
muusika	doc_767882159262_item	3593166	et	4	main
okomponimendiga	doc_767882159262_item	3593167	et	4	main
see	doc_767882159262_item	3593168	et	3	main
teeb	doc_767882159262_item	3593169	et	3	main
huvitavamak	doc_767882159262_item	3593170	et	4	main
noorte	doc_767882159262_item	3593171	et	3	main
jaoks	doc_767882159262_item	3593172	et	4	main
lõppus	doc_767882159262_item	3593173	et	4	main
tahaks	doc_767882159262_item	3593174	et	3	main
ütleda	doc_767882159262_item	3593175	et	4	main
et	doc_767882159262_item	3593176	et	3	main
kõik	doc_767882159262_item	3593177	et	4	main
keele	doc_767882159263_item	3593202	et	4	main
essee	doc_767882159263_item	3593215	et	4	main
olema	doc_767882159263_item	3593222	et	4	main
faktidele	doc_767882159263_item	3593232	et	3	main
eesti	doc_767882159263_item	3593244	et	4	main
ja	doc_767882159263_item	3593270	et	3	main
tähtsem	doc_767882159263_item	3593277	et	4	main
korraldamise	doc_767882159263_item	3593296	et	4	main
vanemuise	doc_767882159263_item	3593301	et	4	main
eesti	doc_767882159263_item	3593320	et	4	main
aastal	doc_767882159263_item	3593328	et	3	main
revolutsioon	doc_767882159263_item	3593332	et	3	main
on	doc_767882159263_item	3593340	et	4	main
olemas	doc_767882159263_item	3593343	et	4	main
ja	doc_767882159262_item	3593144	et	3	main
aitas	doc_767882159262_item	3593146	et	3	main
eesti	doc_767882159263_item	3593201	et	4	main
sõna	doc_767882159263_item	3593219	et	4	main
peab	doc_767882159263_item	3593221	et	4	main
ja	doc_767882159263_item	3593229	et	3	main
laulmine	doc_767882159263_item	3593238	et	4	main
tähtis	doc_767882159263_item	3593241	et	4	main
sotsialne	doc_767882159263_item	3593242	et	4	main
elada	doc_767882159263_item	3593269	et	3	main
vaadata	doc_767882159263_item	3593272	et	4	main
minu	doc_767882159263_item	3593274	et	3	main
melest	doc_767882159263_item	3593275	et	4	main
mis	doc_767882159263_item	3593292	et	4	main
kestis	doc_767882159263_item	3593293	et	4	main
tartus	doc_767882159263_item	3593294	et	3	main
mille	doc_767882159263_item	3593295	et	3	main
eesotsas	doc_767882159263_item	3593303	et	4	main
oli	doc_767882159263_item	3593329	et	3	main
rolli	doc_767882159263_item	3593335	et	4	main
tuleviku	doc_767882159263_item	3593336	et	4	main
üks	doc_767882159263_item	3593341	et	3	main
on	doc_767882159263_item	3593357	et	4	main
meelest	doc_767882159263_item	3593360	et	4	main
essee	doc_767882159265_item	3593369	et	4	main
teise	doc_767882159265_item	3593373	et	4	main
eestlastest	doc_767882159265_item	3593382	et	4	main
olema	doc_767882159265_item	3593391	et	4	main
lugemistekstis	doc_767882159265_item	3593399	et	3	main
ja	doc_767882159265_item	3593418	et	3	main
estlastest	doc_767882159265_item	3593430	et	4	main
kus	doc_767882159265_item	3593437	et	3	main
on	doc_767882159265_item	3593470	et	4	main
kooris	doc_767882159265_item	3593479	et	4	main
jne	doc_767882159265_item	3593480	et	4	main
natukes	doc_767882159265_item	3593484	et	4	main
teised	doc_767882159265_item	3593496	et	4	main
mis	doc_767882159265_item	3593498	et	4	main
nt	doc_767882159265_item	3593502	et	4	main
ja	doc_767882159265_item	3593505	et	3	main
venemaal	doc_767882159265_item	3593506	et	4	main
rahvas	doc_767882159265_item	3593515	et	4	main
hakkas	doc_767882159265_item	3593516	et	3	main
ka	doc_767882159265_item	3593517	et	3	main
läheneda	doc_767882159265_item	3593518	et	3	main
on	doc_767882159265_item	3593536	et	4	main
tõsiselt	doc_767882159265_item	3593541	et	4	main
aitas	doc_767882159265_item	3593552	et	3	main
inimesi	doc_767882159265_item	3593553	et	4	main
elame	doc_767882159265_item	3593562	et	3	main
teises	doc_767882159265_item	3593564	et	4	main
oluline	doc_767882159265_item	3593569	et	4	main
oled	doc_767882159265_item	3593572	et	3	main
kui	doc_767882159265_item	3593573	et	3	main
rahvast	doc_767882159265_item	3593584	et	4	main
ja	doc_767882159265_item	3593585	et	3	main
see	doc_767882159265_item	3593586	et	3	main
on	doc_767882159265_item	3593591	et	4	main
näitusi	doc_767882159265_item	3593593	et	3	main
inimesed	doc_767882159265_item	3593600	et	3	main
folk	doc_767882159265_item	3593607	et	4	main
kirjutage	doc_767882159267_item	3593631	et	3	main
essee	doc_767882159267_item	3593643	et	4	main
tuginema	doc_767882159267_item	3593650	et	3	main
väiteid	doc_767882159267_item	3593656	et	4	main
mis	doc_767882159267_item	3593661	et	4	main
laulurahva	doc_767882159267_item	3593664	et	3	main
huvitav	doc_767882159267_item	3593689	et	4	main
ja	doc_767882159267_item	3593690	et	3	main
kasulik	doc_767882159267_item	3593691	et	3	main
lauldi	doc_767882159267_item	3593696	et	3	main
palju	doc_767882159267_item	3593704	et	4	main
idee	doc_767882159263_item	3593297	et	4	main
ja	doc_767882159263_item	3593298	et	3	main
teostus	doc_767882159263_item	3593299	et	4	main
teise	doc_767882159263_item	3593204	et	4	main
kirjutamine	doc_767882159263_item	3593207	et	4	main
kirjutage	doc_767882159263_item	3593208	et	3	main
pikkus	doc_767882159263_item	3593216	et	4	main
essee	doc_767882159263_item	3593220	et	4	main
üldistav	doc_767882159263_item	3593226	et	4	main
väiteid	doc_767882159263_item	3593233	et	4	main
soovitatav	doc_767882159263_item	3593235	et	4	main
illustreerida	doc_767882159263_item	3593236	et	3	main
näidetega	doc_767882159263_item	3593237	et	3	main
tegevus	doc_767882159263_item	3593243	et	4	main
eesti	doc_767882159263_item	3593246	et	4	main
rahvasel	doc_767882159263_item	3593247	et	4	main
on	doc_767882159263_item	3593248	et	4	main
suur	doc_767882159263_item	3593249	et	3	main
ja	doc_767882159263_item	3593250	et	3	main
huvitav	doc_767882159263_item	3593251	et	4	main
muusikaalne	doc_767882159263_item	3593252	et	4	main
minevik	doc_767882159263_item	3593253	et	3	main
paljud	doc_767882159263_item	3593254	et	3	main
sajad	doc_767882159263_item	3593255	et	4	main
aastat	doc_767882159263_item	3593256	et	3	main
inimesed	doc_767882159263_item	3593257	et	3	main
eestis	doc_767882159263_item	3593258	et	3	main
elavad	doc_767882159263_item	3593259	et	4	main
ja	doc_767882159263_item	3593260	et	3	main
teevad	doc_767882159263_item	3593261	et	3	main
oma	doc_767882159263_item	3593262	et	4	main
tööd	doc_767882159263_item	3593263	et	4	main
muusikaga	doc_767882159263_item	3593264	et	3	main
see	doc_767882159263_item	3593265	et	3	main
aitab	doc_767882159263_item	3593266	et	3	main
nendele	doc_767882159263_item	3593267	et	4	main
maailma	doc_767882159263_item	3593273	et	4	main
aeg	doc_767882159263_item	3593278	et	3	main
eestilaulu	doc_767882159263_item	3593279	et	4	main
ajaloos	doc_767882159263_item	3593280	et	4	main
on	doc_767882159263_item	3593281	et	4	main
1869	doc_767882159263_item	3593282	et	2	main
ülemaaline	doc_767882159263_item	3593287	et	4	main
1869	doc_767882159263_item	3593289	et	2	main
seltsist	doc_767882159263_item	3593302	et	4	main
taasiseisvumisel	doc_767882159263_item	3593321	et	4	main
kui	doc_767882159263_item	3593322	et	3	main
oli	doc_767882159263_item	3593323	et	3	main
teine	doc_767882159263_item	3593324	et	3	main
eesti	doc_767882159263_item	3593330	et	4	main
laulu	doc_767882159263_item	3593331	et	4	main
mis	doc_767882159263_item	3593333	et	4	main
mängis	doc_767882159263_item	3593334	et	3	main
tänapaeval	doc_767882159263_item	3593338	et	4	main
eestis	doc_767882159263_item	3593339	et	3	main
koht	doc_767882159263_item	3593342	et	3	main
lauljad	doc_767882159263_item	3593347	et	4	main
suured	doc_767882159263_item	3593349	et	3	main
see	doc_767882159263_item	3593351	et	3	main
on	doc_767882159263_item	3593353	et	4	main
lauluvaljale	doc_767882159263_item	3593355	et	3	main
minu	doc_767882159263_item	3593359	et	3	main
eesti	doc_767882159263_item	3593361	et	4	main
rahvamuusika	doc_767882159263_item	3593362	et	4	main
süda	doc_767882159263_item	3593363	et	3	main
kirjutamine	doc_767882159265_item	3593376	et	4	main
teeb	doc_767882159265_item	3593381	et	3	main
peab	doc_767882159265_item	3593390	et	4	main
loengus	doc_767882159265_item	3593397	et	3	main
väiteid	doc_767882159265_item	3593402	et	4	main
on	doc_767882159265_item	3593410	et	4	main
eesti	doc_767882159265_item	3593416	et	4	main
esmased	doc_767882159265_item	3593420	et	3	main
eesti	doc_767882159265_item	3593422	et	4	main
kõikjal	doc_767882159265_item	3593436	et	3	main
on	doc_767882159265_item	3593438	et	4	main
rahvas	doc_767882159265_item	3593440	et	4	main
kasutas	doc_767882159265_item	3593441	et	3	main
laule	doc_767882159265_item	3593442	et	4	main
nagu	doc_767882159265_item	3593443	et	3	main
emad	doc_767882159265_item	3593446	et	3	main
oma	doc_767882159265_item	3593447	et	4	main
kodudes	doc_767882159265_item	3593448	et	3	main
mis	doc_767882159265_item	3593469	et	4	main
vokaalne	doc_767882159265_item	3593471	et	3	main
nad	doc_767882159265_item	3593486	et	3	main
on	doc_767882159265_item	3593487	et	4	main
ja	doc_767882159265_item	3593489	et	3	main
seal	doc_767882159265_item	3593490	et	4	main
juuba	doc_767882159265_item	3593491	et	4	main
kasutakse	doc_767882159265_item	3593492	et	3	main
tulid	doc_767882159265_item	3593499	et	4	main
bojan	doc_767882159265_item	3593507	et	4	main
hakkati	doc_767882159265_item	3593508	et	3	main
luua	doc_767882159265_item	3593509	et	4	main
kohale	doc_767882159265_item	3593526	et	4	main
nii	doc_767882159265_item	3593527	et	3	main
aastal	doc_767882159265_item	3593529	et	3	main
tartus	doc_767882159265_item	3593530	et	3	main
see	doc_767882159265_item	3593531	et	3	main
suur	doc_767882159265_item	3593532	et	3	main
asi	doc_767882159265_item	3593533	et	4	main
mille	doc_767882159265_item	3593534	et	3	main
nimeks	doc_767882159265_item	3593535	et	3	main
see	doc_767882159265_item	3593540	et	3	main
oli	doc_767882159265_item	3593542	et	3	main
rahvale	doc_767882159265_item	3593545	et	3	main
see	doc_767882159265_item	3593550	et	3	main
laul	doc_767882159265_item	3593581	et	4	main
päästab	doc_767882159265_item	3593582	et	3	main
eesti	doc_767882159265_item	3593583	et	4	main
pärandama	doc_767882159265_item	3593590	et	3	main
noored	doc_767882159265_item	3593599	et	3	main
on	doc_767882159265_item	3593604	et	4	main
populaarne	doc_767882159265_item	3593605	et	3	main
viljanli	doc_767882159265_item	3593606	et	4	main
positiivseks	doc_767882159263_item	3593271	et	3	main
esimine	doc_767882159263_item	3593286	et	4	main
üritus	doc_767882159263_item	3593291	et	4	main
johann	doc_767882159263_item	3593304	et	4	main
voldemar	doc_767882159263_item	3593305	et	4	main
jannseniga	doc_767882159263_item	3593306	et	4	main
oli	doc_767882159263_item	3593307	et	3	main
väga	doc_767882159263_item	3593308	et	3	main
suur	doc_767882159263_item	3593309	et	3	main
natsionaalne	doc_767882159263_item	3593310	et	3	main
pidu	doc_767882159263_item	3593311	et	4	main
teine	doc_767882159263_item	3593312	et	3	main
tähtis	doc_767882159263_item	3593313	et	4	main
aeg	doc_767882159263_item	3593314	et	3	main
algas	doc_767882159263_item	3593315	et	3	main
1980ndate	doc_767882159263_item	3593316	et	4	main
lõpus	doc_767882159263_item	3593317	et	4	main
ja	doc_767882159263_item	3593318	et	3	main
lõpes	doc_767882159263_item	3593319	et	3	main
ärkamise	doc_767882159263_item	3593325	et	4	main
aeg	doc_767882159263_item	3593326	et	3	main
taasiseivumisel	doc_767882159263_item	3593337	et	4	main
kogunevad	doc_767882159263_item	3593345	et	4	main
mis	doc_767882159263_item	3593364	et	4	main
koguneb	doc_767882159263_item	3593365	et	3	main
keele	doc_767882159265_item	3593374	et	4	main
mis	doc_767882159265_item	3593380	et	4	main
laulurahva	doc_767882159265_item	3593383	et	3	main
300	doc_767882159265_item	3593386	et	2	main
üldistav	doc_767882159265_item	3593395	et	4	main
tuginema	doc_767882159265_item	3593396	et	3	main
esitatud	doc_767882159265_item	3593400	et	4	main
keel	doc_767882159265_item	3593408	et	4	main
mis	doc_767882159265_item	3593409	et	4	main
laulamiseks	doc_767882159265_item	3593415	et	4	main
tema	doc_767882159265_item	3593419	et	4	main
traditsioonid	doc_767882159265_item	3593421	et	3	main
hing	doc_767882159265_item	3593423	et	3	main
laulurarahvat	doc_767882159265_item	3593431	et	4	main
alustada	doc_767882159265_item	3593432	et	3	main
tuleb	doc_767882159265_item	3593433	et	3	main
lauda	doc_767882159265_item	3593476	et	4	main
üksi	doc_767882159265_item	3593477	et	4	main
kahekesi	doc_767882159265_item	3593478	et	3	main
tulid	doc_767882159265_item	3593483	et	4	main
keerulisem	doc_767882159265_item	3593488	et	4	main
teisest	doc_767882159265_item	3593500	et	4	main
koorid	doc_767882159265_item	3593519	et	4	main
erinevatest	doc_767882159265_item	3593522	et	4	main
laulupidu	doc_767882159265_item	3593537	et	4	main
tipphetk	doc_767882159265_item	3593543	et	3	main
niimoodi	doc_767882159265_item	3593546	et	3	main
see	doc_767882159265_item	3593547	et	3	main
ja	doc_767882159265_item	3593549	et	3	main
laulupidu	doc_767882159265_item	3593551	et	4	main
tundma	doc_767882159265_item	3593554	et	3	main
endast	doc_767882159265_item	3593555	et	4	main
juba	doc_767882159265_item	3593563	et	3	main
kus	doc_767882159265_item	3593566	et	3	main
ei	doc_767882159265_item	3593567	et	4	main
ole	doc_767882159265_item	3593568	et	4	main
kus	doc_767882159263_item	3593344	et	3	main
kaa	doc_767882159263_item	3593358	et	4	main
ansaamblid	doc_767882159265_item	3593612	et	4	main
neid	doc_767882159265_item	3593613	et	4	main
väiksed	doc_767882159265_item	3593614	et	4	main
asjad	doc_767882159265_item	3593615	et	3	main
nagu	doc_767882159265_item	3593616	et	3	main
laul	doc_767882159265_item	3593617	et	4	main
võib	doc_767882159265_item	3593618	et	3	main
tõesti	doc_767882159265_item	3593619	et	3	main
aidata	doc_767882159265_item	3593620	et	4	main
elama	doc_767882159265_item	3593621	et	3	main
test	doc_767882159265_item	3593375	et	3	main
kirjutage	doc_767882159265_item	3593377	et	3	main
essee	doc_767882159265_item	3593378	et	4	main
pikkus	doc_767882159265_item	3593385	et	4	main
arutlev	doc_767882159265_item	3593392	et	4	main
analüüsiv	doc_767882159265_item	3593393	et	4	main
ja	doc_767882159265_item	3593394	et	3	main
eesti	doc_767882159265_item	3593407	et	4	main
kõik	doc_767882159265_item	3593427	et	4	main
see	doc_767882159265_item	3593428	et	3	main
teeb	doc_767882159265_item	3593429	et	3	main
et	doc_767882159265_item	3593435	et	3	main
võimalik	doc_767882159265_item	3593439	et	3	main
väljendis	doc_767882159265_item	3593444	et	3	main
vahend	doc_767882159265_item	3593445	et	3	main
töö	doc_767882159265_item	3593449	et	4	main
ajal	doc_767882159265_item	3593450	et	4	main
põlludel	doc_767882159265_item	3593451	et	4	main
ja	doc_767882159265_item	3593452	et	3	main
hauadel	doc_767882159265_item	3593453	et	4	main
vana	doc_767882159265_item	3593454	et	4	main
ajal	doc_767882159265_item	3593455	et	4	main
tuleb	doc_767882159265_item	3593456	et	3	main
meenutada	doc_767882159265_item	3593457	et	3	main
esimest	doc_767882159265_item	3593458	et	4	main
laulu	doc_767882159265_item	3593459	et	4	main
mille	doc_767882159265_item	3593460	et	3	main
nime	doc_767882159265_item	3593461	et	4	main
on	doc_767882159265_item	3593462	et	4	main
regilaul	doc_767882159265_item	3593463	et	4	main
see	doc_767882159265_item	3593464	et	3	main
on	doc_767882159265_item	3593465	et	4	main
hästi	doc_767882159265_item	3593466	et	3	main
lihtne	doc_767882159265_item	3593467	et	3	main
laul	doc_767882159265_item	3593468	et	4	main
ja	doc_767882159265_item	3593398	et	3	main
faktidele	doc_767882159265_item	3593401	et	3	main
on	doc_767882159265_item	3593403	et	4	main
soovitatav	doc_767882159265_item	3593404	et	4	main
illustreerida	doc_767882159265_item	3593405	et	3	main
näidetega	doc_767882159265_item	3593406	et	3	main
ilus	doc_767882159265_item	3593411	et	4	main
ja	doc_767882159265_item	3593412	et	3	main
hästi	doc_767882159265_item	3593413	et	3	main
soobiv	doc_767882159265_item	3593414	et	4	main
ajaloo	doc_767882159265_item	3593417	et	4	main
mis	doc_767882159265_item	3593424	et	4	main
on	doc_767882159265_item	3593425	et	4	main
avar	doc_767882159265_item	3593426	et	3	main
sellest	doc_767882159265_item	3593434	et	4	main
hiljem	doc_767882159265_item	3593485	et	3	main
instrumeendid	doc_767882159265_item	3593497	et	4	main
lätist	doc_767882159265_item	3593503	et	4	main
kaanel	doc_767882159265_item	3593504	et	4	main
kirikust	doc_767882159265_item	3593520	et	4	main
1869	doc_767882159265_item	3593528	et	2	main
ja	doc_767882159265_item	3593539	et	3	main
rahvanna	doc_767882159265_item	3593556	et	4	main
nõukoguajal	doc_767882159265_item	3593557	et	3	main
ka	doc_767882159265_item	3593558	et	3	main
praegu	doc_767882159265_item	3593559	et	3	main
kui	doc_767882159265_item	3593560	et	3	main
jälle	doc_767882159265_item	3593589	et	3	main
elab	doc_767882159265_item	3593597	et	3	main
mis	doc_767882159265_item	3593602	et	4	main
see	doc_767882159265_item	3593603	et	3	main
test	doc_767882159267_item	3593629	et	3	main
kirjutamine	doc_767882159267_item	3593630	et	4	main
mis	doc_767882159267_item	3593634	et	4	main
laulurahva	doc_767882159267_item	3593637	et	3	main
peab	doc_767882159267_item	3593644	et	4	main
olema	doc_767882159267_item	3593645	et	4	main
arutlev	doc_767882159267_item	3593646	et	4	main
ja	doc_767882159267_item	3593652	et	3	main
sügavalt	doc_767882159267_item	3593668	et	4	main
on	doc_767882159267_item	3593673	et	4	main
rahvalauludes	doc_767882159267_item	3593680	et	3	main
rahvalauluga	doc_767882159267_item	3593687	et	4	main
on	doc_767882159267_item	3593688	et	4	main
mitmekesine	doc_767882159267_item	3593695	et	4	main
vaheldumisi	doc_767882159267_item	3593723	et	4	main
saksa	doc_767882159267_item	3593742	et	4	main
mitmehäälset	doc_767882159267_item	3593743	et	3	main
koorilaulu	doc_767882159267_item	3593744	et	4	main
19	doc_767882159267_item	3593745	et	2	main
sajandil	doc_767882159267_item	3593746	et	3	main
laulude	doc_767882159267_item	3593754	et	3	main
naabrid	doc_767882159267_item	3593762	et	3	main
näiteks	doc_767882159267_item	3593763	et	4	main
eestlased	doc_767882159267_item	3593764	et	3	main
19	doc_767882159267_item	3593774	et	2	main
rahvuslik	doc_767882159267_item	3593779	et	3	main
laulupidu	doc_767882159267_item	3593789	et	4	main
eeskujuks	doc_767882159267_item	3593792	et	3	main
rahvusele	doc_767882159267_item	3593794	et	3	main
selline	doc_767882159267_item	3593795	et	4	main
suursündmus	doc_767882159267_item	3593796	et	3	main
korraldamisele	doc_767882159267_item	3593801	et	4	main
partei	doc_767882159267_item	3593829	et	4	main
kontroll	doc_767882159267_item	3593830	et	3	main
oli	doc_767882159267_item	3593831	et	3	main
range	doc_767882159267_item	3593832	et	4	main
ja	doc_767882159267_item	3593833	et	3	main
laulukoorid	doc_767882159267_item	3593838	et	3	main
pealesunnitud	doc_767882159267_item	3593841	et	4	main
stiili	doc_767882159267_item	3593859	et	4	main
hulk	doc_767882159267_item	3593892	et	3	main
pidu	doc_767882159267_item	3593901	et	4	main
kõige	doc_767882159267_item	3593906	et	4	main
eesti	doc_767882159267_item	3593928	et	4	main
eurovision	doc_767882159267_item	3593937	et	4	main
laulurahvas	doc_767882159267_item	3593947	et	4	main
teise	doc_767882159268_item	3593953	et	4	main
test	doc_767882159268_item	3593955	et	3	main
mis	doc_767882159268_item	3593960	et	4	main
essee	doc_767882159268_item	3593964	et	4	main
ilma	doc_767882159265_item	3593472	et	4	main
piilideta	doc_767882159265_item	3593473	et	4	main
seda	doc_767882159265_item	3593474	et	3	main
võib	doc_767882159265_item	3593475	et	3	main
riimilised	doc_767882159265_item	3593481	et	4	main
rahvalaulud	doc_767882159265_item	3593482	et	3	main
pillid	doc_767882159265_item	3593493	et	4	main
ja	doc_767882159265_item	3593494	et	3	main
mõned	doc_767882159265_item	3593495	et	3	main
maast	doc_767882159265_item	3593501	et	3	main
festivali	doc_767882159265_item	3593510	et	4	main
ja	doc_767882159265_item	3593511	et	3	main
tänu	doc_767882159265_item	3593512	et	4	main
neile	doc_767882159265_item	3593513	et	4	main
eesti	doc_767882159265_item	3593514	et	4	main
ning	doc_767882159265_item	3593521	et	3	main
kohtadest	doc_767882159265_item	3593523	et	3	main
tulid	doc_767882159265_item	3593524	et	4	main
ühele	doc_767882159265_item	3593525	et	3	main
toimus	doc_767882159265_item	3593538	et	3	main
eesti	doc_767882159265_item	3593544	et	4	main
läks	doc_767882159265_item	3593548	et	3	main
me	doc_767882159265_item	3593561	et	4	main
maailmas	doc_767882159265_item	3593565	et	3	main
sa	doc_767882159265_item	3593571	et	3	main
on	doc_767882159265_item	3593574	et	4	main
niipalju	doc_767882159265_item	3593575	et	3	main
võimalusi	doc_767882159265_item	3593576	et	3	main
kes	doc_767882159265_item	3593577	et	4	main
teab	doc_767882159265_item	3593578	et	3	main
võib	doc_767882159265_item	3593579	et	3	main
olla	doc_767882159265_item	3593580	et	3	main
hakkab	doc_767882159265_item	3593588	et	3	main
palju	doc_767882159265_item	3593592	et	4	main
et	doc_767882159265_item	3593594	et	3	main
laul	doc_767882159265_item	3593595	et	4	main
veel	doc_767882159265_item	3593596	et	4	main
fest	doc_767882159265_item	3593608	et	4	main
keele	doc_767882159267_item	3593628	et	4	main
teeb	doc_767882159267_item	3593635	et	3	main
sõna	doc_767882159267_item	3593642	et	4	main
analüüsiv	doc_767882159267_item	3593647	et	4	main
ja	doc_767882159267_item	3593648	et	3	main
lugemistekstis	doc_767882159267_item	3593653	et	3	main
faktidele	doc_767882159267_item	3593655	et	3	main
näidetega	doc_767882159267_item	3593660	et	3	main
eestlastest	doc_767882159267_item	3593663	et	4	main
vanem	doc_767882159267_item	3593670	et	4	main
kujunenud	doc_767882159267_item	3593674	et	4	main
enam	doc_767882159267_item	3593675	et	4	main
kui	doc_767882159267_item	3593676	et	3	main
me	doc_767882159267_item	3593681	et	4	main
rahva	doc_767882159267_item	3593683	et	3	main
tutvumine	doc_767882159267_item	3593686	et	4	main
laulmine	doc_767882159267_item	3593693	et	4	main
on	doc_767882159267_item	3593694	et	4	main
olles	doc_767882159267_item	3593698	et	3	main
töötades	doc_767882159267_item	3593699	et	3	main
kiigutades	doc_767882159267_item	3593701	et	3	main
rahvalaulas	doc_767882159267_item	3593702	et	4	main
laulu	doc_767882159267_item	3593726	et	4	main
tema	doc_767882159267_item	3593730	et	4	main
18	doc_767882159267_item	3593732	et	2	main
sajandil	doc_767882159267_item	3593733	et	3	main
lauldi	doc_767882159267_item	3593734	et	3	main
laule	doc_767882159267_item	3593735	et	4	main
kirikus	doc_767882159267_item	3593736	et	3	main
kirik	doc_767882159267_item	3593737	et	3	main
ja	doc_767882159267_item	3593738	et	3	main
külakoolid	doc_767882159267_item	3593739	et	3	main
muutus	doc_767882159267_item	3593747	et	4	main
sellel	doc_767882159267_item	3593757	et	4	main
hakkasid	doc_767882159267_item	3593765	et	4	main
eesmärgi	doc_767882159267_item	3593772	et	4	main
lõppus	doc_767882159267_item	3593776	et	4	main
oli	doc_767882159267_item	3593778	et	3	main
tundmise	doc_767882159267_item	3593785	et	4	main
organiseerimine	doc_767882159267_item	3593790	et	4	main
oli	doc_767882159267_item	3593791	et	3	main
järgnevate	doc_767882159267_item	3593799	et	4	main
rolli	doc_767882159267_item	3593806	et	4	main
rahva	doc_767882159267_item	3593807	et	3	main
oli	doc_767882159267_item	3593825	et	3	main
keerulisem	doc_767882159267_item	3593827	et	4	main
ka	doc_767882159267_item	3593837	et	3	main
palju	doc_767882159267_item	3593840	et	4	main
propagandistlikke	doc_767882159267_item	3593842	et	3	main
laule	doc_767882159267_item	3593843	et	4	main
1960-70	doc_767882159267_item	3593844	et	2	main
ansamblid	doc_767882159267_item	3593850	et	3	main
kes	doc_767882159265_item	3593570	et	4	main
traditsioon	doc_767882159265_item	3593587	et	3	main
ja	doc_767882159265_item	3593598	et	3	main
teaved	doc_767882159265_item	3593601	et	4	main
torupillide	doc_767882159265_item	3593609	et	3	main
päevad	doc_767882159265_item	3593610	et	3	main
noored	doc_767882159265_item	3593611	et	3	main
essee	doc_767882159267_item	3593623	et	4	main
keele	doc_767882159267_item	3593625	et	4	main
kui	doc_767882159267_item	3593626	et	3	main
teise	doc_767882159267_item	3593627	et	4	main
teemal	doc_767882159267_item	3593633	et	3	main
eestlastest	doc_767882159267_item	3593636	et	4	main
essee	doc_767882159267_item	3593638	et	4	main
pikkus	doc_767882159267_item	3593639	et	4	main
300	doc_767882159267_item	3593640	et	2	main
350	doc_767882159267_item	3593641	et	2	main
loengus	doc_767882159267_item	3593651	et	3	main
esitatud	doc_767882159267_item	3593654	et	4	main
on	doc_767882159267_item	3593657	et	4	main
soovitatav	doc_767882159267_item	3593658	et	4	main
illustreerida	doc_767882159267_item	3593659	et	3	main
ajaloost	doc_767882159267_item	3593669	et	4	main
tagasi	doc_767882159267_item	3593679	et	3	main
sellepärast	doc_767882159267_item	3593685	et	3	main
rahvalaule	doc_767882159267_item	3593692	et	4	main
ja	doc_767882159267_item	3593727	et	3	main
kordas	doc_767882159267_item	3593729	et	3	main
laiemale	doc_767882159267_item	3593755	et	4	main
ajal	doc_767882159267_item	3593758	et	4	main
rahvalaulu	doc_767882159267_item	3593760	et	4	main
eestlaste	doc_767882159267_item	3593761	et	4	main
saavutamiseks	doc_767882159267_item	3593773	et	4	main
pani	doc_767882159267_item	3593797	et	4	main
aluse	doc_767882159267_item	3593798	et	4	main
hiljem	doc_767882159267_item	3593809	et	3	main
muutus	doc_767882159267_item	3593810	et	4	main
riik	doc_767882159267_item	3593824	et	3	main
laulsid	doc_767882159267_item	3593839	et	4	main
ndatel	doc_767882159267_item	3593845	et	4	main
laulu	doc_767882159267_item	3593855	et	4	main
ja	doc_767882159267_item	3593856	et	3	main
proovisid	doc_767882159267_item	3593857	et	4	main
muuta	doc_767882159267_item	3593858	et	4	main
tähtis	doc_767882159267_item	3593898	et	4	main
ja	doc_767882159267_item	3593899	et	3	main
populaarne	doc_767882159267_item	3593900	et	3	main
on	doc_767882159267_item	3593905	et	4	main
eestis	doc_767882159267_item	3593911	et	3	main
lauale	doc_767882159267_item	3593927	et	4	main
kogu	doc_767882159267_item	3593930	et	4	main
aeg	doc_767882159267_item	3593931	et	3	main
rahvusvahelistest	doc_767882159267_item	3593934	et	4	main
keele	doc_767882159268_item	3593951	et	4	main
teemal	doc_767882159268_item	3593959	et	3	main
eestlastest	doc_767882159268_item	3593962	et	4	main
analüüsiv	doc_767882159268_item	3593973	et	4	main
ja	doc_767882159268_item	3593974	et	3	main
väiteid	doc_767882159268_item	3593982	et	4	main
on	doc_767882159268_item	3593983	et	4	main
see	doc_767882159268_item	3593991	et	3	main
näiteks	doc_767882159268_item	3594006	et	4	main
eesti	doc_767882159268_item	3594007	et	4	main
rahva	doc_767882159268_item	3594008	et	3	main
nii	doc_767882159268_item	3594016	et	3	main
laulutraditsioon	doc_767882159268_item	3594018	et	3	main
käbi	doc_767882159268_item	3594055	et	4	main
kukkus	doc_767882159268_item	3594056	et	3	main
ema	doc_767882159268_item	3594067	et	4	main
neil	doc_767882159268_item	3594073	et	4	main
käia	doc_767882159268_item	3594086	et	4	main
ning	doc_767882159268_item	3594097	et	3	main
oma	doc_767882159268_item	3594107	et	4	main
hääle	doc_767882159268_item	3594108	et	3	main
suuliselt	doc_767882159268_item	3594115	et	4	main
tähtis	doc_767882159268_item	3594126	et	4	main
toimusid	doc_767882159268_item	3594135	et	4	main
on	doc_767882159267_item	3593914	et	4	main
ka	doc_767882159267_item	3593915	et	3	main
praegusel	doc_767882159267_item	3593916	et	3	main
ajal	doc_767882159267_item	3593917	et	4	main
populaarne	doc_767882159267_item	3593918	et	3	main
ansamblid	doc_767882159267_item	3593919	et	3	main
proovivad	doc_767882159267_item	3593920	et	4	main
uued	doc_767882159267_item	3593921	et	3	main
stiilid	doc_767882159267_item	3593922	et	4	main
annavad	doc_767882159267_item	3593923	et	3	main
uued	doc_767882159267_item	3593924	et	3	main
loomingud	doc_767882159267_item	3593925	et	3	main
vanale	doc_767882159267_item	3593926	et	3	main
eesti	doc_767882159267_item	3593624	et	4	main
essee	doc_767882159267_item	3593632	et	4	main
üldistav	doc_767882159267_item	3593649	et	4	main
teeb	doc_767882159267_item	3593662	et	3	main
eesti	doc_767882159267_item	3593665	et	4	main
laulutraditsioonid	doc_767882159267_item	3593666	et	3	main
lagunevad	doc_767882159267_item	3593667	et	4	main
regivärsiline	doc_767882159267_item	3593671	et	4	main
rahvalaul	doc_767882159267_item	3593672	et	4	main
tuhat	doc_767882159267_item	3593677	et	4	main
aastat	doc_767882159267_item	3593678	et	3	main
näeme	doc_767882159267_item	3593682	et	3	main
mineviku	doc_767882159267_item	3593684	et	3	main
üksi	doc_767882159267_item	3593697	et	4	main
last	doc_767882159267_item	3593700	et	4	main
on	doc_767882159267_item	3593703	et	4	main
loodus	doc_767882159267_item	3593705	et	4	main
häälte	doc_767882159267_item	3593706	et	3	main
lastelaule	doc_767882159267_item	3593707	et	4	main
muinasjutte	doc_767882159267_item	3593708	et	3	main
ning	doc_767882159267_item	3593709	et	3	main
olme	doc_767882159267_item	3593710	et	4	main
tavaliselt	doc_767882159267_item	3593711	et	4	main
naised	doc_767882159267_item	3593712	et	3	main
laulsid	doc_767882159267_item	3593713	et	4	main
igas	doc_767882159267_item	3593714	et	3	main
kohas	doc_767882159267_item	3593715	et	4	main
ilma	doc_767882159267_item	3593716	et	4	main
instrumentideta	doc_767882159267_item	3593717	et	3	main
regilaulu	doc_767882159267_item	3593718	et	4	main
esitati	doc_767882159267_item	3593719	et	4	main
eeslaulja	doc_767882159267_item	3593720	et	4	main
ja	doc_767882159267_item	3593721	et	3	main
koor	doc_767882159267_item	3593722	et	4	main
eeslaulja	doc_767882159267_item	3593724	et	4	main
õpetasid	doc_767882159267_item	3593740	et	4	main
põhiliselt	doc_767882159267_item	3593741	et	4	main
rahvalaul	doc_767882159267_item	3593748	et	4	main
uueks	doc_767882159267_item	3593749	et	3	main
tekkeks	doc_767882159267_item	3593750	et	3	main
laululehte	doc_767882159267_item	3593751	et	4	main
levikule	doc_767882159267_item	3593756	et	3	main
mõjutas	doc_767882159267_item	3593759	et	3	main
bajaani	doc_767882159267_item	3593766	et	4	main
sümbol	doc_767882159267_item	3593780	et	3	main
see	doc_767882159267_item	3593781	et	3	main
oli	doc_767882159267_item	3593782	et	3	main
rahvusliku	doc_767882159267_item	3593784	et	3	main
laul	doc_767882159267_item	3593802	et	4	main
mängis	doc_767882159267_item	3593803	et	3	main
siin	doc_767882159267_item	3593804	et	4	main
suurt	doc_767882159267_item	3593805	et	3	main
nõukogude	doc_767882159267_item	3593823	et	3	main
laulupidu	doc_767882159267_item	3593834	et	4	main
repertuaar	doc_767882159267_item	3593835	et	3	main
aastatel	doc_767882159267_item	3593846	et	4	main
ärkas	doc_767882159267_item	3593847	et	3	main
huvi	doc_767882159267_item	3593848	et	4	main
vana	doc_767882159267_item	3593854	et	4	main
ei	doc_767882159267_item	3593861	et	4	main
korraldati	doc_767882159267_item	3593862	et	3	main
suur	doc_767882159267_item	3593891	et	3	main
sest	doc_767882159267_item	3593895	et	4	main
arendas	doc_767882159267_item	3593725	et	3	main
koor	doc_767882159267_item	3593728	et	4	main
pärast	doc_767882159267_item	3593731	et	4	main
trükimine	doc_767882159267_item	3593752	et	4	main
aitas	doc_767882159267_item	3593753	et	3	main
mängima	doc_767882159267_item	3593767	et	3	main
laul	doc_767882159267_item	3593768	et	4	main
mängib	doc_767882159267_item	3593769	et	3	main
suurt	doc_767882159267_item	3593770	et	3	main
rolli	doc_767882159267_item	3593771	et	4	main
sajandi	doc_767882159267_item	3593775	et	3	main
laul	doc_767882159267_item	3593777	et	4	main
eestlaste	doc_767882159267_item	3593783	et	4	main
ärkamisperiiod	doc_767882159267_item	3593786	et	4	main
esimese	doc_767882159267_item	3593787	et	3	main
ülemaalise	doc_767882159267_item	3593788	et	4	main
kõikidele	doc_767882159267_item	3593793	et	4	main
laulupidude	doc_767882159267_item	3593800	et	4	main
ühendamiseks	doc_767882159267_item	3593808	et	4	main
poliitiline	doc_767882159267_item	3593811	et	3	main
seisukord	doc_767882159267_item	3593812	et	3	main
eestimaal	doc_767882159267_item	3593813	et	4	main
ja	doc_767882159267_item	3593814	et	3	main
korraldata	doc_767882159267_item	3593815	et	3	main
laulupidusid	doc_767882159267_item	3593816	et	4	main
oli	doc_767882159267_item	3593817	et	3	main
keeruline	doc_767882159267_item	3593818	et	4	main
ajal	doc_767882159267_item	3593819	et	4	main
millal	doc_767882159267_item	3593820	et	3	main
eesti	doc_767882159267_item	3593821	et	4	main
oli	doc_767882159267_item	3593822	et	3	main
veel	doc_767882159267_item	3593826	et	4	main
kommunistliku	doc_767882159267_item	3593828	et	3	main
muutus	doc_767882159267_item	3593836	et	4	main
vanalauluks	doc_767882159267_item	3593849	et	4	main
laulupidu	doc_767882159267_item	3593860	et	4	main
1980-ndate	doc_767882159267_item	3593863	et	4	main
lõpus	doc_767882159267_item	3593864	et	4	main
oli	doc_767882159267_item	3593865	et	3	main
eestis	doc_767882159267_item	3593866	et	3	main
teine	doc_767882159267_item	3593867	et	3	main
ärkamisaeg	doc_767882159267_item	3593868	et	3	main
eesti	doc_767882159267_item	3593869	et	4	main
sai	doc_767882159267_item	3593870	et	4	main
iseseisvust	doc_767882159267_item	3593871	et	4	main
ja	doc_767882159267_item	3593872	et	3	main
rahvalaulad	doc_767882159267_item	3593873	et	4	main
said	doc_767882159267_item	3593874	et	4	main
veel	doc_767882159267_item	3593875	et	4	main
populaarseks	doc_767882159267_item	3593876	et	4	main
1994	doc_767882159267_item	3593877	et	2	main
aasta	doc_767882159267_item	3593878	et	4	main
juulis	doc_767882159267_item	3593879	et	3	main
tallinnas	doc_767882159267_item	3593880	et	4	main
ja	doc_767882159267_item	3593881	et	3	main
tartus	doc_767882159267_item	3593882	et	3	main
toimus	doc_767882159267_item	3593883	et	3	main
laulupidu	doc_767882159267_item	3593884	et	4	main
et	doc_767882159267_item	3593885	et	3	main
tähistada	doc_767882159267_item	3593886	et	3	main
125	doc_767882159267_item	3593887	et	2	main
käisid	doc_767882159267_item	3593851	et	4	main
arhiivis	doc_767882159267_item	3593852	et	3	main
otsisid	doc_767882159267_item	3593853	et	4	main
aastat	doc_767882159267_item	3593888	et	3	main
laulupidude	doc_767882159267_item	3593889	et	4	main
tuli	doc_767882159267_item	3593893	et	4	main
lauldest	doc_767882159267_item	3593894	et	4	main
tähelepanuväärsem	doc_767882159267_item	3593907	et	4	main
ja	doc_767882159267_item	3593908	et	3	main
lauljad	doc_767882159267_item	3593929	et	4	main
kõik	doc_767882159267_item	3593938	et	4	main
need	doc_767882159267_item	3593939	et	3	main
faktid	doc_767882159267_item	3593940	et	3	main
räägivad	doc_767882159267_item	3593941	et	3	main
essee	doc_767882159268_item	3593949	et	4	main
kirjutage	doc_767882159268_item	3593957	et	3	main
teeb	doc_767882159268_item	3593961	et	3	main
laulurahva	doc_767882159268_item	3593963	et	3	main
olema	doc_767882159268_item	3593971	et	4	main
tuginema	doc_767882159268_item	3593976	et	3	main
esitatud	doc_767882159268_item	3593980	et	4	main
laul	doc_767882159268_item	3593987	et	4	main
on	doc_767882159268_item	3593988	et	4	main
inimese	doc_767882159268_item	3593989	et	4	main
elukaaslane	doc_767882159268_item	3593990	et	3	main
rahvadega	doc_767882159268_item	3594004	et	4	main
toon	doc_767882159268_item	3594005	et	4	main
peetakse	doc_767882159268_item	3594010	et	3	main
on	doc_767882159268_item	3594014	et	4	main
algasid	doc_767882159268_item	3594050	et	4	main
sest	doc_767882159268_item	3594072	et	4	main
oli	doc_767882159268_item	3594074	et	3	main
tööd	doc_767882159268_item	3594076	et	4	main
teha	doc_767882159268_item	3594077	et	3	main
toimusid	doc_767882159268_item	3594079	et	4	main
mehedel	doc_767882159268_item	3594083	et	4	main
keelatud	doc_767882159268_item	3594085	et	4	main
telefoneid	doc_767882159268_item	3594103	et	4	main
ja	doc_767882159268_item	3594104	et	3	main
inimesed	doc_767882159268_item	3594105	et	3	main
kasutasid	doc_767882159268_item	3594106	et	4	main
alates	doc_767882159268_item	3594117	et	3	main
laul	doc_767882159268_item	3594123	et	4	main
on	doc_767882159268_item	3594124	et	4	main
väga	doc_767882159268_item	3594125	et	3	main
lõpus	doc_767882159268_item	3594134	et	4	main
essee	doc_767882159270_item	3594174	et	4	main
essee	doc_767882159270_item	3594189	et	4	main
pikkus	doc_767882159270_item	3594190	et	4	main
350	doc_767882159270_item	3594192	et	2	main
sõna	doc_767882159270_item	3594193	et	4	main
analüüsiv	doc_767882159270_item	3594198	et	4	main
faktidele	doc_767882159270_item	3594206	et	3	main
näidetega	doc_767882159270_item	3594211	et	3	main
väga	doc_767882159270_item	3594233	et	3	main
ja	doc_767882159270_item	3594235	et	3	main
kujunes	doc_767882159270_item	3594238	et	3	main
ja	doc_767882159270_item	3594248	et	3	main
mängijaga	doc_767882159270_item	3594252	et	4	main
aluse	doc_767882159270_item	3594256	et	4	main
neljandast	doc_767882159270_item	3594267	et	3	main
puhkpilliorkestrile	doc_767882159270_item	3594273	et	3	main
ka	doc_767882159270_item	3594274	et	3	main
pärast	doc_767882159270_item	3594276	et	4	main
1933	doc_767882159270_item	3594278	et	2	main
kokku	doc_767882159270_item	3594282	et	3	main
tallinnas	doc_767882159270_item	3594309	et	4	main
suur	doc_767882159270_item	3594310	et	3	main
hulk	doc_767882159270_item	3594311	et	3	main
laulupidu	doc_767882159270_item	3594317	et	4	main
massilisem	doc_767882159270_item	3594328	et	4	main
ka	doc_767882159270_item	3594337	et	3	main
kuhu	doc_767882159270_item	3594340	et	3	main
pidu	doc_767882159270_item	3594350	et	4	main
kogu	doc_767882159270_item	3594353	et	4	main
sõitnud	doc_767882159270_item	3594357	et	4	main
meeldiv	doc_767882159270_item	3594359	et	4	main
et	doc_767882159270_item	3594360	et	3	main
eestlased	doc_767882159270_item	3594361	et	3	main
mõeldi	doc_767882159270_item	3594362	et	3	main
kõik	doc_767882159270_item	3594406	et	4	main
traditsiooni	doc_767882159267_item	3593890	et	4	main
eestlaste	doc_767882159267_item	3593902	et	4	main
hulgas	doc_767882159267_item	3593903	et	4	main
massilisem	doc_767882159267_item	3593909	et	4	main
osa	doc_767882159267_item	3593933	et	4	main
sellest	doc_767882159267_item	3593942	et	4	main
et	doc_767882159267_item	3593943	et	3	main
eestlased	doc_767882159267_item	3593944	et	3	main
on	doc_767882159267_item	3593945	et	4	main
see	doc_767882159267_item	3593896	et	3	main
on	doc_767882159267_item	3593897	et	4	main
laulupidu	doc_767882159267_item	3593904	et	4	main
manifestatsioon	doc_767882159267_item	3593910	et	3	main
rahvatemaatika	doc_767882159267_item	3593912	et	4	main
lauldes	doc_767882159267_item	3593913	et	3	main
võtavad	doc_767882159267_item	3593932	et	3	main
lauluvõistlustest	doc_767882159267_item	3593935	et	4	main
näiteks	doc_767882159267_item	3593936	et	4	main
tõeline	doc_767882159267_item	3593946	et	4	main
kui	doc_767882159268_item	3593952	et	3	main
keele	doc_767882159268_item	3593954	et	4	main
essee	doc_767882159268_item	3593958	et	4	main
peab	doc_767882159268_item	3593970	et	4	main
üldistav	doc_767882159268_item	3593975	et	4	main
olukordades	doc_767882159268_item	3593994	et	3	main
puhul	doc_767882159268_item	3594000	et	4	main
nii	doc_767882159268_item	3594001	et	3	main
on	doc_767882159268_item	3594002	et	4	main
laulurahvaks	doc_767882159268_item	3594011	et	3	main
see	doc_767882159268_item	3594013	et	3	main
tõesti	doc_767882159268_item	3594015	et	3	main
eestlaste	doc_767882159268_item	3594017	et	4	main
regivärsilise	doc_767882159268_item	3594020	et	4	main
kännu	doc_767882159268_item	3594057	et	3	main
sama	doc_767882159268_item	3594068	et	4	main
naised	doc_767882159268_item	3594069	et	3	main
õhtud	doc_767882159268_item	3594081	et	3	main
kus	doc_767882159268_item	3594082	et	3	main
oli	doc_767882159268_item	3594084	et	3	main
põllul	doc_767882159268_item	3594091	et	3	main
regilaule	doc_767882159268_item	3594113	et	4	main
edastati	doc_767882159268_item	3594114	et	4	main
19	doc_767882159268_item	3594118	et	2	main
salmikuid	doc_767882159268_item	3594121	et	4	main
eestlastele	doc_767882159268_item	3594127	et	4	main
seda	doc_767882159268_item	3594128	et	3	main
faktid	doc_767882159268_item	3594131	et	3	main
sajandi	doc_767882159268_item	3594133	et	3	main
ülemaaline	doc_767882159268_item	3594149	et	4	main
keele	doc_767882159270_item	3594176	et	4	main
300	doc_767882159270_item	3594191	et	2	main
arutlev	doc_767882159270_item	3594197	et	4	main
on	doc_767882159270_item	3594208	et	4	main
mis	doc_767882159270_item	3594212	et	4	main
laulutraditsioonid	doc_767882159270_item	3594231	et	3	main
ülemaaline	doc_767882159270_item	3594240	et	4	main
peol	doc_767882159270_item	3594242	et	4	main
osales	doc_767882159270_item	3594243	et	3	main
puhkpillorkestrit	doc_767882159270_item	3594250	et	4	main
see	doc_767882159270_item	3594253	et	3	main
üldlaulupidude	doc_767882159270_item	3594258	et	4	main
korraldamisele	doc_767882159270_item	3594259	et	4	main
igal	doc_767882159270_item	3594260	et	3	main
aastal	doc_767882159270_item	3594261	et	3	main
osavõtjate	doc_767882159270_item	3594262	et	3	main
meeskooridele	doc_767882159270_item	3594271	et	4	main
eesti	doc_767882159268_item	3593950	et	4	main
kirjutamine	doc_767882159268_item	3593956	et	4	main
sõna	doc_767882159268_item	3593968	et	4	main
essee	doc_767882159268_item	3593969	et	4	main
ja	doc_767882159268_item	3593978	et	3	main
lugemistekstis	doc_767882159268_item	3593979	et	3	main
soovitatav	doc_767882159268_item	3593984	et	4	main
illustreerida	doc_767882159268_item	3593985	et	3	main
näidetega	doc_767882159268_item	3593986	et	3	main
aitab	doc_767882159268_item	3593992	et	3	main
ning	doc_767882159268_item	3593995	et	3	main
kõrval	doc_767882159268_item	3593998	et	4	main
rõõmsuse	doc_767882159268_item	3593999	et	4	main
algas	doc_767882159268_item	3594019	et	3	main
rahvalauluga	doc_767882159268_item	3594021	et	4	main
see	doc_767882159268_item	3594022	et	3	main
on	doc_767882159268_item	3594023	et	4	main
väärt	doc_767882159268_item	3594024	et	4	main
vaatamist	doc_767882159268_item	3594025	et	4	main
sest	doc_767882159268_item	3594026	et	4	main
seda	doc_767882159268_item	3594027	et	3	main
kaasnevad	doc_767882159268_item	3594028	et	4	main
keha	doc_767882159268_item	3594029	et	4	main
õõtsutamine	doc_767882159268_item	3594030	et	4	main
ja	doc_767882159268_item	3594031	et	3	main
jalapõrutus	doc_767882159268_item	3594032	et	4	main
mitte	doc_767882159268_item	3594033	et	3	main
ainult	doc_767882159268_item	3594034	et	4	main
hääl	doc_767882159268_item	3594035	et	3	main
see	doc_767882159268_item	3594036	et	3	main
jaguneb	doc_767882159268_item	3594037	et	3	main
kaheks	doc_767882159268_item	3594038	et	4	main
stiiliks	doc_767882159268_item	3594039	et	4	main
vana-	doc_767882159268_item	3594040	et	4	main
ja	doc_767882159268_item	3594041	et	3	main
uus	doc_767882159268_item	3594042	et	3	main
rahvalaul	doc_767882159268_item	3594043	et	4	main
alguses	doc_767882159268_item	3594044	et	4	main
lauldi	doc_767882159268_item	3594045	et	3	main
nii	doc_767882159268_item	3594046	et	3	main
et	doc_767882159268_item	3594047	et	3	main
kõik	doc_767882159268_item	3594048	et	4	main
sõnad	doc_767882159268_item	3594049	et	4	main
ühe	doc_767882159268_item	3594051	et	4	main
ja	doc_767882159268_item	3594052	et	3	main
sama	doc_767882159268_item	3594053	et	4	main
tähega	doc_767882159268_item	3594054	et	3	main
tema	doc_767882159268_item	3594066	et	4	main
tihti	doc_767882159268_item	3594071	et	3	main
palju	doc_767882159268_item	3594075	et	4	main
naistel	doc_767882159268_item	3594078	et	3	main
tegelikult	doc_767882159268_item	3594087	et	4	main
oli	doc_767882159268_item	3594088	et	3	main
pikkus	doc_767882159268_item	3593965	et	4	main
300	doc_767882159268_item	3593966	et	2	main
350	doc_767882159268_item	3593967	et	2	main
arutlev	doc_767882159268_item	3593972	et	4	main
loengus	doc_767882159268_item	3593977	et	3	main
faktidele	doc_767882159268_item	3593981	et	3	main
rasketes	doc_767882159268_item	3593993	et	3	main
on	doc_767882159268_item	3593996	et	4	main
meie	doc_767882159268_item	3593997	et	4	main
kõikide	doc_767882159268_item	3594003	et	4	main
neid	doc_767882159268_item	3594009	et	4	main
ja	doc_767882159268_item	3594012	et	3	main
kõrvale	doc_767882159268_item	3594058	et	4	main
uues	doc_767882159268_item	3594059	et	3	main
rahvalaulas	doc_767882159268_item	3594060	et	4	main
aga	doc_767882159268_item	3594061	et	3	main
oli	doc_767882159268_item	3594062	et	3	main
sõnade	doc_767882159268_item	3594063	et	3	main
lõpp	doc_767882159268_item	3594064	et	3	main
sarnane	doc_767882159268_item	3594065	et	4	main
laulsid	doc_767882159268_item	3594070	et	4	main
isegi	doc_767882159268_item	3594080	et	4	main
ajal	doc_767882159268_item	3594101	et	4	main
polnud	doc_767882159268_item	3594102	et	3	main
suhelda	doc_767882159268_item	3594112	et	4	main
kuid	doc_767882159268_item	3594116	et	4	main
paljudes	doc_767882159268_item	3594136	et	3	main
eesti	doc_767882159268_item	3594137	et	4	main
ühislaulmised	doc_767882159268_item	3594139	et	3	main
linnades	doc_767882159268_item	3594138	et	3	main
see	doc_767882159268_item	3594140	et	3	main
ühines	doc_767882159268_item	3594141	et	3	main
inimesi	doc_767882159268_item	3594142	et	4	main
ja	doc_767882159268_item	3594143	et	3	main
1869	doc_767882159268_item	3594144	et	2	main
aastal	doc_767882159268_item	3594145	et	3	main
tartus	doc_767882159268_item	3594146	et	3	main
toimus	doc_767882159268_item	3594147	et	3	main
esimene	doc_767882159268_item	3594148	et	3	main
laulu	doc_767882159268_item	3594089	et	4	main
ka	doc_767882159268_item	3594090	et	3	main
vaja	doc_767882159268_item	3594092	et	4	main
see	doc_767882159268_item	3594093	et	3	main
aitas	doc_767882159268_item	3594094	et	3	main
ületada	doc_767882159268_item	3594095	et	3	main
raskusi	doc_767882159268_item	3594096	et	4	main
oli	doc_767882159268_item	3594098	et	3	main
meelelahutuseks	doc_767882159268_item	3594099	et	4	main
tol	doc_767882159268_item	3594100	et	3	main
võimu	doc_767882159268_item	3594109	et	4	main
et	doc_767882159268_item	3594110	et	3	main
teineteisega	doc_767882159268_item	3594111	et	3	main
sajandist	doc_767882159268_item	3594119	et	3	main
hakkasid	doc_767882159268_item	3594120	et	4	main
koostama	doc_767882159268_item	3594122	et	3	main
näitavad	doc_767882159268_item	3594129	et	4	main
paljud	doc_767882159268_item	3594130	et	3	main
19	doc_767882159268_item	3594132	et	2	main
teise	doc_767882159270_item	3594178	et	4	main
test	doc_767882159270_item	3594180	et	3	main
kirjutamine	doc_767882159270_item	3594181	et	4	main
kirjutage	doc_767882159270_item	3594182	et	3	main
essee	doc_767882159270_item	3594183	et	4	main
teemal	doc_767882159270_item	3594184	et	3	main
mis	doc_767882159270_item	3594185	et	4	main
teeb	doc_767882159270_item	3594186	et	3	main
essee	doc_767882159270_item	3594194	et	4	main
ja	doc_767882159270_item	3594199	et	3	main
üldistav	doc_767882159270_item	3594200	et	4	main
tuginema	doc_767882159270_item	3594201	et	3	main
loengus	doc_767882159270_item	3594202	et	3	main
ja	doc_767882159270_item	3594203	et	3	main
lugemistekstis	doc_767882159270_item	3594204	et	3	main
soovitatav	doc_767882159270_item	3594209	et	4	main
olid	doc_767882159270_item	3594232	et	4	main
1869	doc_767882159270_item	3594236	et	2	main
järgnevate	doc_767882159270_item	3594257	et	4	main
peost	doc_767882159270_item	3594268	et	4	main
senistele	doc_767882159270_item	3594270	et	3	main
ning	doc_767882159270_item	3594272	et	3	main
alates	doc_767882159270_item	3594277	et	3	main
lisandusid	doc_767882159270_item	3594279	et	4	main
naiskoorid	doc_767882159270_item	3594281	et	3	main
30	doc_767882159270_item	3594288	et	2	main
tähistati	doc_767882159270_item	3594300	et	4	main
korraldati	doc_767882159270_item	3594303	et	3	main
kahes	doc_767882159270_item	3594305	et	4	main
linnas	doc_767882159270_item	3594306	et	4	main
tartus	doc_767882159270_item	3594307	et	3	main
ja	doc_767882159270_item	3594308	et	3	main
tuli	doc_767882159270_item	3594315	et	4	main
laulupidu	doc_767882159270_item	3594320	et	4	main
praegusel	doc_767882159270_item	3594323	et	3	main
kõige	doc_767882159270_item	3594325	et	4	main
tohi	doc_767882159270_item	3594333	et	4	main
unustada	doc_767882159270_item	3594334	et	3	main
et	doc_767882159270_item	3594335	et	3	main
rahvapidu	doc_767882159270_item	3594339	et	4	main
tullakse	doc_767882159270_item	3594341	et	3	main
kus	doc_767882159270_item	3594351	et	3	main
rahvusmuusika	doc_767882159270_item	3594409	et	4	main
folkloore	doc_767882159270_item	3594413	et	4	main
ja	doc_767882159270_item	3594415	et	3	main
suurt	doc_767882159270_item	3594425	et	3	main
eurovisiooni	doc_767882159270_item	3594432	et	4	main
võistlusele	doc_767882159270_item	3594433	et	3	main
see	doc_767882159270_item	3594434	et	3	main
oli	doc_767882159270_item	3594435	et	3	main
väga	doc_767882159270_item	3594436	et	3	main
surepärane	doc_767882159270_item	3594437	et	4	main
ma	doc_767882159270_item	3594438	et	3	main
arvan	doc_767882159270_item	3594439	et	3	main
et	doc_767882159270_item	3594440	et	3	main
ja	doc_767882159270_item	3594446	et	3	main
tulevikus	doc_767882159270_item	3594450	et	4	main
komposeerima	doc_767882159270_item	3594451	et	4	main
uued	doc_767882159270_item	3594452	et	3	main
essee	doc_767882159271_item	3594459	et	4	main
kirjutage	doc_767882159271_item	3594467	et	3	main
eestlastest	doc_767882159271_item	3594472	et	4	main
laulupidu	doc_767882159268_item	3594150	et	4	main
seal	doc_767882159268_item	3594151	et	4	main
esinesid	doc_767882159268_item	3594152	et	4	main
meestekoorid	doc_767882159268_item	3594153	et	3	main
aga	doc_767882159268_item	3594154	et	3	main
hiljem	doc_767882159268_item	3594155	et	3	main
hakkasid	doc_767882159268_item	3594156	et	4	main
naiste-	doc_767882159268_item	3594157	et	3	main
laste	doc_767882159268_item	3594158	et	4	main
ja	doc_767882159268_item	3594159	et	3	main
segakoorid	doc_767882159268_item	3594160	et	3	main
esinema	doc_767882159268_item	3594161	et	3	main
kuigi	doc_767882159268_item	3594162	et	3	main
oli	doc_767882159268_item	3594163	et	3	main
raske	doc_767882159268_item	3594164	et	4	main
load	doc_767882159268_item	3594165	et	4	main
saama	doc_767882159268_item	3594166	et	4	main
liitusid	doc_767882159268_item	3594167	et	4	main
iga	doc_767882159268_item	3594168	et	4	main
aasta	doc_767882159268_item	3594169	et	4	main
kooridesse	doc_767882159268_item	3594170	et	3	main
rohkem	doc_767882159268_item	3594171	et	4	main
inimesi	doc_767882159268_item	3594172	et	4	main
kui	doc_767882159270_item	3594177	et	3	main
keele	doc_767882159270_item	3594179	et	4	main
laulurahva	doc_767882159270_item	3594188	et	3	main
peab	doc_767882159270_item	3594195	et	4	main
väiteid	doc_767882159270_item	3594207	et	4	main
teeb	doc_767882159270_item	3594213	et	3	main
esimene	doc_767882159270_item	3594239	et	3	main
laulupidu	doc_767882159270_item	3594241	et	4	main
46	doc_767882159270_item	3594244	et	2	main
meeskoori	doc_767882159270_item	3594245	et	4	main
822	doc_767882159270_item	3594246	et	2	main
56	doc_767882159270_item	3594251	et	2	main
pidu	doc_767882159270_item	3594254	et	4	main
pani	doc_767882159270_item	3594255	et	4	main
arv	doc_767882159270_item	3594263	et	3	main
kasvas	doc_767882159270_item	3594264	et	3	main
ja	doc_767882159270_item	3594265	et	3	main
alates	doc_767882159270_item	3594266	et	3	main
liitusid	doc_767882159270_item	3594269	et	4	main
ka	doc_767882159270_item	3594280	et	3	main
osavõtjate	doc_767882159270_item	3594283	et	3	main
umbes	doc_767882159270_item	3594286	et	4	main
125	doc_767882159270_item	3594301	et	2	main
vaatajad	doc_767882159270_item	3594312	et	4	main
ja	doc_767882159270_item	3594313	et	3	main
kuulajad	doc_767882159270_item	3594314	et	4	main
eestiline	doc_767882159270_item	3594319	et	3	main
ka	doc_767882159270_item	3594322	et	3	main
ajal	doc_767882159270_item	3594324	et	4	main
suur	doc_767882159270_item	3594338	et	3	main
perega	doc_767882159270_item	3594343	et	3	main
inimesed	doc_767882159270_item	3594355	et	3	main
väga	doc_767882159270_item	3594358	et	3	main
sükkane	doc_767882159270_item	3594363	et	4	main
peo	doc_767882159270_item	3594364	et	4	main
need	doc_767882159270_item	3594365	et	3	main
eesti	doc_767882159270_item	3594175	et	4	main
eestlastest	doc_767882159270_item	3594187	et	4	main
olema	doc_767882159270_item	3594196	et	4	main
esitatud	doc_767882159270_item	3594205	et	4	main
illustreerida	doc_767882159270_item	3594210	et	3	main
eestlastest	doc_767882159270_item	3594214	et	4	main
laulurahva	doc_767882159270_item	3594215	et	3	main
juba	doc_767882159270_item	3594216	et	3	main
vanal	doc_767882159270_item	3594217	et	3	main
ajal	doc_767882159270_item	3594218	et	4	main
lauldi	doc_767882159270_item	3594219	et	3	main
eestlased	doc_767882159270_item	3594220	et	3	main
laulu	doc_767882159270_item	3594221	et	4	main
töötades	doc_767882159270_item	3594222	et	3	main
last	doc_767882159270_item	3594223	et	4	main
kiigutades	doc_767882159270_item	3594224	et	3	main
laulsid	doc_767882159270_item	3594225	et	4	main
kui	doc_767882159270_item	3594226	et	3	main
mehed	doc_767882159270_item	3594227	et	3	main
ka	doc_767882159270_item	3594228	et	3	main
naised	doc_767882159270_item	3594229	et	3	main
eesti	doc_767882159270_item	3594230	et	4	main
populaarsed	doc_767882159270_item	3594234	et	3	main
aastal	doc_767882159270_item	3594237	et	3	main
lauljaga	doc_767882159270_item	3594247	et	4	main
5	doc_767882159270_item	3594249	et	2	main
arv	doc_767882159270_item	3594284	et	3	main
pillimängijani	doc_767882159270_item	3594292	et	3	main
eestlased	doc_767882159270_item	3594293	et	3	main
väga	doc_767882159270_item	3594294	et	3	main
sünnipäev	doc_767882159270_item	3594302	et	3	main
laulupidu	doc_767882159270_item	3594304	et	4	main
üle	doc_767882159270_item	3594318	et	3	main
on	doc_767882159270_item	3594321	et	4	main
rahvusluse	doc_767882159270_item	3594329	et	4	main
manifestatsioon	doc_767882159270_item	3594330	et	3	main
eestis	doc_767882159270_item	3594331	et	3	main
ei	doc_767882159270_item	3594332	et	4	main
kohata	doc_767882159270_item	3594345	et	4	main
sõpru	doc_767882159270_item	3594346	et	3	main
maailma	doc_767882159270_item	3594354	et	4	main
perega	doc_767882159270_item	3594371	et	3	main
populaarsemaks	doc_767882159270_item	3594411	et	4	main
ei	doc_767882159270_item	3594418	et	4	main
eesti	doc_767882159270_item	3594428	et	4	main
ei	doc_767882159270_item	3594442	et	4	main
unusta	doc_767882159270_item	3594443	et	4	main
laulurahva	doc_767882159270_item	3594448	et	3	main
et	doc_767882159270_item	3594449	et	3	main
laulud	doc_767882159270_item	3594453	et	3	main
ja	doc_767882159270_item	3594454	et	3	main
teha	doc_767882159270_item	3594455	et	3	main
uued	doc_767882159270_item	3594456	et	3	main
laulupeod	doc_767882159270_item	3594457	et	4	main
kui	doc_767882159271_item	3594462	et	3	main
test	doc_767882159271_item	3594465	et	3	main
olema	doc_767882159271_item	3594481	et	4	main
üldistav	doc_767882159271_item	3594485	et	4	main
tuginema	doc_767882159271_item	3594486	et	3	main
lugemistekstis	doc_767882159271_item	3594489	et	3	main
eestlased	doc_767882159271_item	3594502	et	3	main
ja	doc_767882159271_item	3594505	et	3	main
kaheks	doc_767882159271_item	3594517	et	4	main
osaks	doc_767882159271_item	3594518	et	3	main
võtnud	doc_767882159271_item	3594571	et	4	main
näiteks	doc_767882159271_item	3594577	et	4	main
pille	doc_767882159271_item	3594578	et	3	main
eesti	doc_767882159271_item	3594579	et	4	main
laulupeod	doc_767882159271_item	3594584	et	4	main
esimene	doc_767882159271_item	3594585	et	3	main
toimus	doc_767882159271_item	3594587	et	3	main
korraldas	doc_767882159271_item	3594592	et	3	main
kelle	doc_767882159271_item	3594596	et	4	main
abiks	doc_767882159271_item	3594597	et	3	main
pärast	doc_767882159271_item	3594603	et	4	main
aastal	doc_767882159271_item	3594609	et	3	main
üldlaulupidude	doc_767882159271_item	3594611	et	4	main
poisid	doc_767882159271_item	3594636	et	4	main
setumaalt	doc_767882159271_item	3594637	et	3	main
laulsid	doc_767882159271_item	3594638	et	4	main
rahvalaulud	doc_767882159271_item	3594639	et	3	main
parem	doc_767882159271_item	3594657	et	4	main
palju	doc_399014257202_item	3594664	et	4	main
ilusaid	doc_399014257202_item	3594665	et	3	main
naisi	doc_399014257202_item	3594666	et	3	main
ja	doc_399014257202_item	3594667	et	3	main
nägusaid	doc_399014257202_item	3594668	et	3	main
mehi	doc_399014257202_item	3594669	et	3	main
ma	doc_399014257202_item	3594674	et	3	main
raamatuid	doc_399014257202_item	3594677	et	3	main
lugema	doc_399014257202_item	3594680	et	4	main
vene	doc_399014257202_item	3594681	et	4	main
sel	doc_399014257202_item	3594690	et	3	main
eurolaul	doc_399014257202_item	3594693	et	4	main
lemmikuid	doc_399014257202_item	3594699	et	4	main
sõbered	doc_399014257202_item	3594706	et	4	main
ma	doc_399014257202_item	3594707	et	3	main
glasgows	doc_399014257202_item	3594712	et	4	main
on	doc_399014257202_item	3594714	et	4	main
segakoorid	doc_767882159270_item	3594275	et	3	main
oli	doc_767882159270_item	3594285	et	3	main
25	doc_767882159270_item	3594287	et	2	main
000	doc_767882159270_item	3594289	et	2	main
laulja	doc_767882159270_item	3594290	et	4	main
ja	doc_767882159270_item	3594291	et	3	main
meeldisid	doc_767882159270_item	3594295	et	4	main
laulupeod	doc_767882159270_item	3594296	et	4	main
ja	doc_767882159270_item	3594297	et	3	main
1994	doc_767882159270_item	3594298	et	2	main
aastal	doc_767882159270_item	3594299	et	3	main
vaadata	doc_767882159270_item	3594316	et	4	main
tähelepanuväärsem	doc_767882159270_item	3594326	et	4	main
ja	doc_767882159270_item	3594327	et	3	main
laulupidu	doc_767882159270_item	3594336	et	4	main
koos	doc_767882159270_item	3594342	et	4	main
lootuses	doc_767882159270_item	3594344	et	4	main
või	doc_767882159270_item	3594347	et	4	main
sugulasi	doc_767882159270_item	3594348	et	3	main
see	doc_767882159270_item	3594349	et	3	main
üle	doc_767882159270_item	3594352	et	3	main
kokku	doc_767882159270_item	3594356	et	3	main
aias	doc_767882159270_item	3594370	et	4	main
sugulastega	doc_767882159270_item	3594373	et	4	main
aasta	doc_767882159270_item	3594408	et	4	main
estlased	doc_767882159270_item	3594441	et	4	main
ju	doc_767882159270_item	3594366	et	3	main
lauldi	doc_767882159270_item	3594367	et	3	main
juba	doc_767882159270_item	3594368	et	3	main
vanas	doc_767882159270_item	3594369	et	3	main
sõpruga	doc_767882159270_item	3594372	et	4	main
ja	doc_767882159270_item	3594374	et	3	main
keegi	doc_767882159270_item	3594375	et	4	main
ei	doc_767882159270_item	3594376	et	4	main
nõudnud	doc_767882159270_item	3594377	et	4	main
kooslaulda	doc_767882159270_item	3594378	et	4	main
oli	doc_767882159270_item	3594379	et	3	main
lihtsalt	doc_767882159270_item	3594380	et	4	main
nii	doc_767882159270_item	3594381	et	3	main
et	doc_767882159270_item	3594382	et	3	main
üks	doc_767882159270_item	3594383	et	3	main
ütleb	doc_767882159270_item	3594384	et	3	main
või	doc_767882159270_item	3594385	et	4	main
hakkab	doc_767882159270_item	3594386	et	3	main
laulma	doc_767882159270_item	3594387	et	3	main
siis	doc_767882159270_item	3594388	et	3	main
teised	doc_767882159270_item	3594389	et	4	main
hakkavad	doc_767882159270_item	3594390	et	4	main
laulma	doc_767882159270_item	3594392	et	3	main
kaasa	doc_767882159270_item	3594391	et	4	main
eesti	doc_767882159270_item	3594393	et	4	main
rahvus	doc_767882159270_item	3594394	et	3	main
oli	doc_767882159270_item	3594395	et	3	main
väga	doc_767882159270_item	3594396	et	3	main
ühine	doc_767882159270_item	3594397	et	4	main
mõnikord	doc_767882159270_item	3594398	et	3	main
nemad	doc_767882159270_item	3594399	et	3	main
liigutasid	doc_767882159270_item	3594400	et	4	main
ringi	doc_767882159270_item	3594401	et	4	main
või	doc_767882159270_item	3594402	et	4	main
lihtsalt	doc_767882159270_item	3594403	et	4	main
istusid	doc_767882159270_item	3594404	et	4	main
koos	doc_767882159270_item	3594405	et	4	main
iga	doc_767882159270_item	3594407	et	4	main
toimuvad	doc_767882159270_item	3594412	et	4	main
tohi	doc_767882159270_item	3594419	et	4	main
unustada	doc_767882159270_item	3594420	et	3	main
et	doc_767882159270_item	3594421	et	3	main
praegu	doc_767882159270_item	3594422	et	3	main
muusika	doc_767882159270_item	3594423	et	4	main
rolli	doc_767882159270_item	3594426	et	4	main
ka	doc_767882159270_item	3594427	et	3	main
kohta	doc_767882159270_item	3594431	et	4	main
oma	doc_767882159270_item	3594444	et	4	main
laulutraditsioone	doc_767882159270_item	3594445	et	3	main
teise	doc_767882159271_item	3594463	et	4	main
essee	doc_767882159271_item	3594468	et	4	main
mis	doc_767882159271_item	3594470	et	4	main
essee	doc_767882159271_item	3594474	et	4	main
350	doc_767882159271_item	3594477	et	2	main
essee	doc_767882159271_item	3594479	et	4	main
peab	doc_767882159271_item	3594480	et	4	main
analüüsiv	doc_767882159271_item	3594483	et	4	main
ja	doc_767882159271_item	3594484	et	3	main
ja	doc_767882159271_item	3594488	et	3	main
väiteid	doc_767882159271_item	3594492	et	4	main
on	doc_767882159271_item	3594493	et	4	main
on	doc_767882159271_item	3594514	et	4	main
võimalik	doc_767882159271_item	3594515	et	3	main
eraldada	doc_767882159271_item	3594516	et	3	main
siis	doc_767882159271_item	3594552	et	3	main
meie	doc_767882159271_item	3594558	et	4	main
aastal	doc_767882159271_item	3594589	et	3	main
johann	doc_767882159271_item	3594593	et	4	main
laulupeode	doc_767882159271_item	3594605	et	3	main
rahvalaulud	doc_767882159271_item	3594624	et	3	main
on	doc_767882159271_item	3594632	et	4	main
väga	doc_767882159271_item	3594633	et	3	main
populaarsed	doc_767882159271_item	3594634	et	3	main
rahvalaul	doc_767882159271_item	3594643	et	4	main
saab	doc_767882159271_item	3594644	et	3	main
nii	doc_767882159271_item	3594645	et	3	main
popularseks	doc_767882159271_item	3594646	et	4	main
kui	doc_767882159271_item	3594647	et	3	main
see	doc_767882159271_item	3594648	et	3	main
oli	doc_767882159271_item	3594649	et	3	main
on	doc_399014257202_item	3594663	et	4	main
vendasid	doc_399014257202_item	3594673	et	3	main
eesti	doc_399014257202_item	3594688	et	4	main
vanilla	doc_399014257202_item	3594696	et	4	main
ninja	doc_399014257202_item	3594697	et	4	main
on	doc_399014257202_item	3594698	et	4	main
peal	doc_399014257202_item	3594760	et	4	main
paberi	doc_399014257202_item	3594762	et	3	main
hakkab	doc_767882159270_item	3594410	et	3	main
festivaale	doc_767882159270_item	3594414	et	4	main
temaatilised	doc_767882159270_item	3594416	et	4	main
üritused	doc_767882159270_item	3594417	et	4	main
mängib	doc_767882159270_item	3594424	et	3	main
sai	doc_767882159270_item	3594429	et	4	main
esimese	doc_767882159270_item	3594430	et	3	main
jäävad	doc_767882159270_item	3594447	et	4	main
keele	doc_767882159271_item	3594461	et	4	main
keele	doc_767882159271_item	3594464	et	4	main
kirjutamine	doc_767882159271_item	3594466	et	4	main
teeb	doc_767882159271_item	3594471	et	3	main
laulurahva	doc_767882159271_item	3594473	et	3	main
eesti	doc_767882159271_item	3594497	et	4	main
on	doc_767882159271_item	3594499	et	4	main
laulav	doc_767882159271_item	3594500	et	4	main
vana	doc_767882159271_item	3594511	et	4	main
eesti	doc_767882159271_item	3594512	et	4	main
laulu	doc_767882159271_item	3594513	et	4	main
nad	doc_767882159271_item	3594554	et	3	main
seda	doc_767882159271_item	3594556	et	3	main
kihnu	doc_767882159271_item	3594565	et	4	main
saarel	doc_767882159271_item	3594566	et	3	main
eesti	doc_767882159271_item	3594567	et	4	main
naabritest	doc_767882159271_item	3594573	et	4	main
nagu	doc_767882159271_item	3594574	et	3	main
läti	doc_767882159271_item	3594575	et	4	main
ajaloos	doc_767882159271_item	3594580	et	4	main
on	doc_767882159271_item	3594581	et	4	main
üldlaulupidu	doc_767882159271_item	3594586	et	4	main
voldemar	doc_767882159271_item	3594594	et	4	main
oli	doc_767882159271_item	3594598	et	3	main
koht	doc_767882159271_item	3594606	et	3	main
tallinnasse	doc_767882159271_item	3594607	et	3	main
oli	doc_767882159271_item	3594610	et	3	main
aastapäev	doc_767882159271_item	3594613	et	3	main
näiteks	doc_767882159271_item	3594635	et	4	main
ajaloo	doc_767882159271_item	3594655	et	4	main
ka	doc_767882159271_item	3594656	et	3	main
harjutus	doc_399014257202_item	3594659	et	4	main
glasgows	doc_399014257202_item	3594662	et	4	main
ei	doc_399014257202_item	3594671	et	4	main
palju	doc_399014257202_item	3594676	et	4	main
ma	doc_399014257202_item	3594678	et	3	main
raske	doc_399014257202_item	3594685	et	4	main
mulle	doc_399014257202_item	3594686	et	4	main
meeldib	doc_399014257202_item	3594687	et	3	main
ei	doc_399014257202_item	3594708	et	4	main
meeldib	doc_399014257202_item	3594709	et	3	main
käratsevid	doc_399014257202_item	3594710	et	4	main
ülikoolis	doc_399014257202_item	3594713	et	4	main
palju	doc_399014257202_item	3594761	et	4	main
viimasel	doc_767882159271_item	3594619	et	3	main
ajal	doc_767882159271_item	3594620	et	4	main
mõned	doc_767882159271_item	3594621	et	3	main
heliloojad	doc_767882159271_item	3594622	et	3	main
eesti	doc_767882159271_item	3594460	et	4	main
teemal	doc_767882159271_item	3594469	et	3	main
300	doc_767882159271_item	3594476	et	2	main
sõna	doc_767882159271_item	3594478	et	4	main
arutlev	doc_767882159271_item	3594482	et	4	main
soovitatav	doc_767882159271_item	3594494	et	4	main
illustreerida	doc_767882159271_item	3594495	et	3	main
näidetega	doc_767882159271_item	3594496	et	3	main
rahvas	doc_767882159271_item	3594501	et	4	main
alati	doc_767882159271_item	3594504	et	4	main
ja	doc_767882159271_item	3594520	et	3	main
riimilaul	doc_767882159271_item	3594521	et	4	main
reegilaulud	doc_767882159271_item	3594522	et	4	main
laulsid	doc_767882159271_item	3594523	et	4	main
ilma	doc_767882159271_item	3594524	et	4	main
muusika	doc_767882159271_item	3594525	et	4	main
instrumentideta	doc_767882159271_item	3594526	et	3	main
reegilaulades	doc_767882159271_item	3594527	et	4	main
iga	doc_767882159271_item	3594528	et	4	main
võis	doc_767882159271_item	3594529	et	4	main
alustada	doc_767882159271_item	3594530	et	3	main
ühe	doc_767882159271_item	3594531	et	4	main
tähega	doc_767882159271_item	3594532	et	3	main
enamus	doc_767882159271_item	3594533	et	4	main
laule	doc_767882159271_item	3594534	et	4	main
laulsid	doc_767882159271_item	3594535	et	4	main
naised	doc_767882159271_item	3594536	et	3	main
uue	doc_767882159271_item	3594537	et	3	main
rahvalaulu	doc_767882159271_item	3594538	et	4	main
laulsid	doc_767882159271_item	3594539	et	4	main
kirikutes	doc_767882159271_item	3594540	et	4	main
koorides	doc_767882159271_item	3594541	et	4	main
üks	doc_767882159271_item	3594542	et	3	main
laulja	doc_767882159271_item	3594543	et	4	main
laulas	doc_767882159271_item	3594544	et	4	main
ja	doc_767882159271_item	3594545	et	3	main
siis	doc_767882159271_item	3594546	et	3	main
koor	doc_767882159271_item	3594547	et	4	main
kordnes	doc_767882159271_item	3594548	et	4	main
kui	doc_767882159271_item	3594549	et	3	main
rahvas	doc_767882159271_item	3594550	et	4	main
laulas	doc_767882159271_item	3594551	et	4	main
pikkus	doc_767882159271_item	3594475	et	4	main
loengus	doc_767882159271_item	3594487	et	3	main
esitatud	doc_767882159271_item	3594490	et	4	main
faktidele	doc_767882159271_item	3594491	et	3	main
rahvas	doc_767882159271_item	3594498	et	4	main
laulsid	doc_767882159271_item	3594503	et	4	main
erinevates	doc_767882159271_item	3594506	et	4	main
olukordades	doc_767882159271_item	3594507	et	3	main
töötades	doc_767882159271_item	3594508	et	3	main
üksi	doc_767882159271_item	3594509	et	4	main
olles	doc_767882159271_item	3594510	et	3	main
reegilaul	doc_767882159271_item	3594519	et	4	main
mõnikord	doc_767882159271_item	3594553	et	3	main
tegid	doc_767882159271_item	3594555	et	4	main
ringis	doc_767882159271_item	3594557	et	4	main
ajal	doc_767882159271_item	3594559	et	4	main
vanarahvalaul	doc_767882159271_item	3594560	et	4	main
on	doc_767882159271_item	3594561	et	4	main
säilinud	doc_767882159271_item	3594562	et	4	main
setumaal	doc_767882159271_item	3594563	et	4	main
ja	doc_767882159271_item	3594564	et	3	main
laulud	doc_767882159271_item	3594568	et	3	main
on	doc_767882159271_item	3594569	et	4	main
midagi	doc_767882159271_item	3594570	et	4	main
venemaa	doc_767882159271_item	3594576	et	4	main
toimunud	doc_767882159271_item	3594582	et	4	main
1869	doc_767882159271_item	3594588	et	2	main
aja	doc_767882159271_item	3594602	et	4	main
oli	doc_767882159271_item	3594615	et	3	main
suur	doc_767882159271_item	3594616	et	3	main
sündmus	doc_767882159271_item	3594617	et	3	main
varem	doc_767882159271_item	3594650	et	4	main
siis	doc_767882159271_item	3594651	et	3	main
rahvas	doc_767882159271_item	3594652	et	4	main
saab	doc_767882159271_item	3594653	et	3	main
ole	doc_399014257202_item	3594672	et	4	main
lugema	doc_399014257202_item	3594675	et	4	main
ka	doc_399014257202_item	3594679	et	3	main
laule	doc_399014257202_item	3594689	et	4	main
mul	doc_399014257202_item	3594702	et	3	main
palju	doc_399014257202_item	3594704	et	4	main
eestlaneid	doc_399014257202_item	3594705	et	4	main
palju	doc_399014257202_item	3594715	et	4	main
oma	doc_767882159271_item	3594572	et	4	main
mitu	doc_767882159271_item	3594583	et	4	main
tartus	doc_767882159271_item	3594590	et	3	main
seda	doc_767882159271_item	3594591	et	3	main
jaansen	doc_767882159271_item	3594595	et	4	main
lydia	doc_767882159271_item	3594599	et	4	main
koidula	doc_767882159271_item	3594600	et	4	main
mõne	doc_767882159271_item	3594601	et	3	main
koolis	doc_767882159271_item	3594604	et	4	main
1969	doc_767882159271_item	3594608	et	2	main
100	doc_767882159271_item	3594612	et	2	main
mis	doc_767882159271_item	3594614	et	4	main
eestlastele	doc_767882159271_item	3594618	et	4	main
kasutavad	doc_767882159271_item	3594623	et	4	main
oma	doc_767882159271_item	3594625	et	4	main
loomingus	doc_767882159271_item	3594626	et	3	main
näiteks	doc_767882159271_item	3594627	et	4	main
mart	doc_767882159271_item	3594628	et	3	main
saar	doc_767882159271_item	3594629	et	3	main
praegu	doc_767882159271_item	3594630	et	3	main
rahvalaulud	doc_767882159271_item	3594631	et	3	main
oma	doc_767882159271_item	3594640	et	4	main
plaadil	doc_767882159271_item	3594641	et	3	main
kui	doc_767882159271_item	3594642	et	3	main
oma	doc_767882159271_item	3594654	et	4	main
kõige	doc_399014257202_item	3594740	et	4	main
parem	doc_399014257202_item	3594741	et	4	main
lauljaid	doc_399014257202_item	3594742	et	4	main
tema	doc_399014257202_item	3594743	et	4	main
konsertied	doc_399014257202_item	3594744	et	4	main
alati	doc_399014257202_item	3594745	et	4	main
huvitav	doc_399014257202_item	3594746	et	4	main
sügiseid	doc_399014257202_item	3594747	et	3	main
on	doc_399014257202_item	3594748	et	4	main
ilusaid	doc_399014257202_item	3594749	et	3	main
kuu	doc_399014257202_item	3594750	et	4	main
ka	doc_399014257202_item	3594751	et	3	main
armasaid	doc_399014257202_item	3594752	et	4	main
ilm	doc_399014257202_item	3594753	et	3	main
mulle	doc_399014257202_item	3594754	et	4	main
meeldib	doc_399014257202_item	3594755	et	3	main
suvele	doc_399014257202_item	3594756	et	3	main
rohkem	doc_399014257202_item	3594757	et	4	main
veel	doc_399014257202_item	3594758	et	4	main
plural	doc_399014257202_item	3594660	et	4	main
partitative	doc_399014257202_item	3594661	et	4	main
mul	doc_399014257202_item	3594670	et	3	main
keel	doc_399014257202_item	3594682	et	4	main
ajalehteid	doc_399014257202_item	3594683	et	4	main
väga	doc_399014257202_item	3594684	et	3	main
nädalal	doc_399014257202_item	3594691	et	3	main
on	doc_399014257202_item	3594692	et	4	main
eesti	doc_399014257202_item	3594694	et	4	main
televisiooni	doc_399014257202_item	3594695	et	4	main
mängu	doc_399014257202_item	3594700	et	4	main
võitma	doc_399014257202_item	3594701	et	3	main
on	doc_399014257202_item	3594703	et	4	main
lapsi	doc_399014257202_item	3594711	et	4	main
üliõpilasi	doc_399014257202_item	3594716	et	3	main
palju	doc_399014257202_item	3594717	et	4	main
inimesi	doc_399014257202_item	3594718	et	4	main
šotimaal	doc_399014257202_item	3594719	et	2	main
on	doc_399014257202_item	3594720	et	4	main
üks	doc_399014257202_item	3594721	et	3	main
kaunimaid	doc_399014257202_item	3594722	et	4	main
maid	doc_399014257202_item	3594723	et	4	main
minu	doc_399014257202_item	3594724	et	3	main
arvates	doc_399014257202_item	3594725	et	4	main
eestimaa	doc_399014257202_item	3594726	et	4	main
on	doc_399014257202_item	3594727	et	4	main
väga	doc_399014257202_item	3594728	et	3	main
ilusaid	doc_399014257202_item	3594729	et	3	main
ka	doc_399014257202_item	3594730	et	3	main
venelasedi	doc_399014257202_item	3594731	et	4	main
ja	doc_399014257202_item	3594732	et	3	main
eestlaneid	doc_399014257202_item	3594733	et	4	main
oled	doc_399014257202_item	3594734	et	3	main
ärev	doc_399014257202_item	3594735	et	3	main
ajaluguid	doc_399014257202_item	3594736	et	4	main
celine	doc_399014257202_item	3594737	et	4	main
dion	doc_399014257202_item	3594738	et	4	main
on	doc_399014257202_item	3594739	et	4	main
laudu	doc_399014257202_item	3594759	et	3	main
ma	doc_399014257202_item	3594763	et	3	main
olen	doc_399014257202_item	3594764	et	3	main
väga	doc_399014257202_item	3594765	et	3	main
räpaneid	doc_399014257202_item	3594766	et	4	main
vahele	doc_399014257202_item	3594767	et	4	main
täna	doc_399014257202_item	3594768	et	4	main
on	doc_399014257202_item	3594769	et	4	main
minu	doc_399014257202_item	3594770	et	3	main
sõbrannaid	doc_399014257202_item	3594771	et	4	main
sünnipäev	doc_399014257202_item	3594772	et	3	main
kakskummend	doc_399014257202_item	3594773	et	4	main
uks	doc_399014257202_item	3594774	et	3	main
aastat	doc_399014257202_item	3594775	et	3	main
vana	doc_399014257202_item	3594776	et	4	main
mis	doc_399014257202_item	3594777	et	4	main
kell	doc_399014257202_item	3594778	et	3	main
on	doc_399014257202_item	3594779	et	4	main
kell	doc_399014257202_item	3594780	et	3	main
on	doc_399014257202_item	3594781	et	4	main
pidu	doc_399014257202_item	3594782	et	4	main
korraldama	doc_399014257202_item	3594783	et	3	main
kokkuvõte	doc_213943985053_item	3595091	et	3	main
marketing	doc_213943985053_item	3595107	et	4	main
kinnisvara	doc_213943985053_item	3595110	et	4	main
inimesed	doc_213943985053_item	3595123	et	3	main
tahavad	doc_213943985053_item	3595124	et	3	main
teine	doc_213943985053_item	3595131	et	3	main
samuti	doc_213943985053_item	3595137	et	3	main
kui	doc_213943985053_item	3595138	et	3	main
õpilane	doc_213943985053_item	3595144	et	3	main
ma	doc_213943985053_item	3595193	et	3	main
õpin	doc_213943985053_item	3595194	et	3	main
harjutus	doc_213943985054_item	3595259	et	4	main
eriala	doc_213943985054_item	3595269	et	4	main
selle	doc_213943985054_item	3595279	et	4	main
eriala	doc_213943985054_item	3595280	et	4	main
on	doc_213943985054_item	3595284	et	4	main
ajakirjandus	doc_213943985054_item	3595285	et	3	main
sest	doc_213943985054_item	3595299	et	4	main
ma	doc_213943985054_item	3595300	et	3	main
olen	doc_213943985054_item	3595301	et	3	main
väga	doc_213943985054_item	3595302	et	3	main
võin	doc_213943985054_item	3595322	et	3	main
et	doc_213943985054_item	3595328	et	3	main
ajakirjaniku	doc_213943985054_item	3595330	et	3	main
raha	doc_213943985054_item	3595335	et	4	main
ma	doc_213943985054_item	3595336	et	3	main
tahaks	doc_213943985054_item	3595337	et	3	main
saada	doc_213943985054_item	3595338	et	4	main
tahan	doc_213943985054_item	3595342	et	3	main
mulle	doc_213943985054_item	3595345	et	4	main
moodsaim	doc_213943985055_item	3595361	et	4	main
on	doc_213943985055_item	3595368	et	4	main
töötavad	doc_213943985055_item	3595371	et	4	main
tabelit	doc_213943985053_item	3595089	et	3	main
reklaam	doc_213943985053_item	3595108	et	3	main
saada	doc_213943985053_item	3595127	et	4	main
et	doc_213943985053_item	3595128	et	3	main
kõik	doc_213943985053_item	3595133	et	4	main
sõltub	doc_213943985053_item	3595134	et	3	main
riigieksami	doc_213943985053_item	3595135	et	3	main
tulemusest	doc_213943985053_item	3595136	et	4	main
eriala	doc_213943985053_item	3595139	et	4	main
nimetus	doc_213943985053_item	3595140	et	4	main
tundub	doc_213943985053_item	3595141	et	3	main
tore	doc_213943985053_item	3595142	et	3	main
akrediteeritud	doc_213943985053_item	3595152	et	4	main
või	doc_213943985053_item	3595153	et	4	main
selle	doc_213943985053_item	3595197	et	4	main
aasta	doc_213943985053_item	3595200	et	4	main
mulle	doc_213943985053_item	3595220	et	4	main
huvitavad	doc_213943985053_item	3595225	et	4	main
juutustused	doc_213943985053_item	3595226	et	4	main
ka	doc_213943985053_item	3595227	et	3	main
suhtlema	doc_213943985053_item	3595228	et	3	main
inimestega	doc_213943985053_item	3595229	et	3	main
see	doc_213943985053_item	3595230	et	3	main
eriala	doc_213943985053_item	3595231	et	4	main
õppida	doc_213943985053_item	3595234	et	3	main
rakendus	doc_213943985053_item	3595241	et	4	main
ajalehes	doc_213943985053_item	3595242	et	3	main
kokkuvõte	doc_213943985054_item	3595262	et	3	main
valiku	doc_213943985054_item	3595265	et	3	main
ise	doc_213943985054_item	3595276	et	4	main
tean	doc_213943985054_item	3595277	et	3	main
eriala	doc_213943985054_item	3595283	et	4	main
sõprad	doc_213943985054_item	3595287	et	4	main
rääkisid	doc_213943985054_item	3595288	et	4	main
eriala	doc_213943985054_item	3595294	et	4	main
ma	doc_213943985054_item	3595295	et	3	main
mulle	doc_213943985054_item	3595304	et	4	main
suhelda	doc_213943985054_item	3595306	et	4	main
selle	doc_213943985054_item	3595309	et	4	main
mulle	doc_213943985054_item	3595333	et	4	main
töötada	doc_213943985054_item	3595343	et	3	main
seda	doc_213943985054_item	3595347	et	3	main
eriala	doc_213943985054_item	3595355	et	4	main
on	doc_213943985055_item	3595360	et	4	main
nissugune	doc_213943985055_item	3595363	et	4	main
populaarsed	doc_213943985055_item	3595369	et	3	main
hiljem	doc_213943985055_item	3595372	et	3	main
kõrgemat	doc_213943985055_item	3595373	et	4	main
palka	doc_213943985055_item	3595374	et	4	main
aga	doc_213943985055_item	3595375	et	3	main
ma	doc_213943985055_item	3595376	et	3	main
inimene	doc_213943985055_item	3595379	et	3	main
valida	doc_213943985055_item	3595381	et	3	main
kõrgus	doc_213943985055_item	3595387	et	4	main
paljem	doc_213943985055_item	3595390	et	4	main
peab	doc_213943985055_item	3595409	et	4	main
vaata	doc_213943985055_item	3595450	et	4	main
missugused	doc_213943985055_item	3595455	et	3	main
tuttavad	doc_213943985055_item	3595461	et	4	main
ei	doc_213943985055_item	3595466	et	4	main
ole	doc_213943985055_item	3595467	et	4	main
väga	doc_213943985055_item	3595468	et	3	main
on	doc_213943985055_item	3595475	et	4	main
järgmiseid	doc_213943985055_item	3595476	et	3	main
võimalused	doc_213943985055_item	3595477	et	3	main
oma	doc_213943985056_item	3595525	et	4	main
kohta	doc_213943985056_item	3595528	et	4	main
ma	doc_213943985056_item	3595543	et	3	main
ajakirjandus	doc_213943985056_item	3595574	et	3	main
on	doc_213943985056_item	3595575	et	4	main
tee	doc_213943985053_item	3595088	et	4	main
millesed	doc_213943985053_item	3595099	et	4	main
valivad	doc_213943985053_item	3595100	et	4	main
õpilased	doc_213943985053_item	3595101	et	3	main
on	doc_213943985053_item	3595103	et	4	main
ärijuhtimine	doc_213943985053_item	3595104	et	3	main
rahvusvaheline	doc_213943985053_item	3595105	et	4	main
suhted	doc_213943985053_item	3595106	et	3	main
on	doc_213943985053_item	3595120	et	4	main
palk	doc_213943985053_item	3595121	et	3	main
kõik	doc_213943985053_item	3595122	et	4	main
suur	doc_213943985053_item	3595125	et	3	main
on	doc_213943985053_item	3595151	et	4	main
valivad	doc_213943985053_item	3595156	et	4	main
ajakirjandusena	doc_213943985053_item	3595195	et	3	main
infot	doc_213943985053_item	3595202	et	3	main
erialast	doc_213943985053_item	3595204	et	4	main
leidsin	doc_213943985053_item	3595205	et	3	main
internetis	doc_213943985053_item	3595206	et	4	main
kasutades	doc_213943985053_item	3595090	et	3	main
täna	doc_213943985053_item	3595092	et	4	main
on	doc_213943985053_item	3595094	et	4	main
see	doc_213943985053_item	3595102	et	3	main
mittu	doc_213943985053_item	3595115	et	4	main
motivatsioonid	doc_213943985053_item	3595116	et	3	main
erialavalikul	doc_213943985053_item	3595117	et	3	main
esimene	doc_213943985053_item	3595118	et	3	main
see	doc_213943985053_item	3595119	et	3	main
tema	doc_213943985053_item	3595143	et	4	main
veel	doc_213943985053_item	3595146	et	4	main
kui	doc_213943985053_item	3595149	et	3	main
eriala	doc_213943985053_item	3595150	et	4	main
oma	doc_213943985053_item	3595188	et	4	main
kokkuvõte	doc_213943985053_item	3595187	et	3	main
eriala	doc_213943985053_item	3595189	et	4	main
valiku	doc_213943985053_item	3595190	et	3	main
kohta	doc_213943985053_item	3595191	et	4	main
praegu	doc_213943985053_item	3595192	et	3	main
tv	doc_213943985053_item	3595244	et	4	main
s	doc_213943985053_item	3595245	et	4	main
tähtsus	doc_213943985053_item	3595246	et	4	main
on	doc_213943985053_item	3595247	et	4	main
selles	doc_213943985053_item	3595248	et	4	main
et	doc_213943985053_item	3595249	et	3	main
see	doc_213943985053_item	3595250	et	3	main
peab	doc_213943985053_item	3595251	et	4	main
olema	doc_213943985053_item	3595252	et	4	main
vene	doc_213943985053_item	3595253	et	4	main
keelne	doc_213943985053_item	3595254	et	3	main
vene	doc_213943985053_item	3595255	et	4	main
välja	doc_213943985053_item	3595256	et	4	main
andmine	doc_213943985053_item	3595257	et	4	main
harjutus	doc_213943985053_item	3595087	et	4	main
päeval	doc_213943985053_item	3595093	et	3	main
seitse	doc_213943985053_item	3595095	et	3	main
kõige	doc_213943985053_item	3595096	et	4	main
populaarsemad	doc_213943985053_item	3595097	et	4	main
erialad	doc_213943985053_item	3595098	et	3	main
psühholoogia	doc_213943985053_item	3595109	et	4	main
planeerimine	doc_213943985053_item	3595111	et	4	main
ja	doc_213943985053_item	3595112	et	3	main
agronoom	doc_213943985053_item	3595113	et	3	main
on	doc_213943985053_item	3595114	et	4	main
palk	doc_213943985053_item	3595126	et	3	main
rikkalik	doc_213943985053_item	3595129	et	3	main
elada	doc_213943985053_item	3595130	et	3	main
et	doc_213943985053_item	3595132	et	3	main
valib	doc_213943985053_item	3595145	et	3	main
me	doc_213943985053_item	3595147	et	4	main
vaatame	doc_213943985053_item	3595148	et	3	main
ei	doc_213943985053_item	3595154	et	4	main
tihti	doc_213943985053_item	3595155	et	3	main
akrediteeritud	doc_213943985053_item	3595157	et	4	main
erialad	doc_213943985053_item	3595158	et	3	main
et	doc_213943985053_item	3595159	et	3	main
see	doc_213943985053_item	3595160	et	3	main
on	doc_213943985053_item	3595161	et	4	main
parem	doc_213943985053_item	3595162	et	4	main
ja	doc_213943985053_item	3595163	et	3	main
viimane	doc_213943985053_item	3595164	et	3	main
punkt	doc_213943985053_item	3595165	et	4	main
see	doc_213943985053_item	3595166	et	3	main
on	doc_213943985053_item	3595167	et	4	main
materiaalne	doc_213943985053_item	3595168	et	3	main
aspekt	doc_213943985053_item	3595169	et	3	main
sellepärast	doc_213943985053_item	3595170	et	3	main
et	doc_213943985053_item	3595171	et	3	main
peres	doc_213943985053_item	3595172	et	3	main
on	doc_213943985053_item	3595173	et	4	main
vähem	doc_213943985053_item	3595174	et	4	main
raha	doc_213943985053_item	3595175	et	4	main
vanemad	doc_213943985053_item	3595176	et	4	main
tahavad	doc_213943985053_item	3595177	et	3	main
et	doc_213943985053_item	3595178	et	3	main
nende	doc_213943985053_item	3595179	et	4	main
tütar	doc_213943985053_item	3595180	et	3	main
poeg	doc_213943985053_item	3595181	et	3	main
tulevikus	doc_213943985053_item	3595182	et	4	main
õpetati	doc_213943985053_item	3595183	et	3	main
tasuta	doc_213943985053_item	3595184	et	4	main
tee	doc_213943985053_item	3595185	et	4	main
kirjalik	doc_213943985053_item	3595186	et	3	main
eriala	doc_213943985053_item	3595198	et	4	main
valisin	doc_213943985053_item	3595199	et	3	main
ja	doc_213943985053_item	3595196	et	3	main
is	doc_213943985053_item	3595211	et	4	main
selle	doc_213943985053_item	3595212	et	4	main
et	doc_213943985053_item	3595216	et	3	main
ajakirjandus	doc_213943985053_item	3595219	et	3	main
meeldib	doc_213943985053_item	3595221	et	3	main
te	doc_213943985053_item	3595232	et	4	main
tallinna	doc_213943985053_item	3595235	et	4	main
raadios	doc_213943985053_item	3595243	et	3	main
tagasi	doc_213943985053_item	3595201	et	3	main
sellest	doc_213943985053_item	3595203	et	4	main
eriala	doc_213943985053_item	3595213	et	4	main
mulle	doc_213943985053_item	3595217	et	4	main
meeldib	doc_213943985053_item	3595218	et	3	main
kirjutada	doc_213943985053_item	3595222	et	3	main
saate	doc_213943985053_item	3595233	et	4	main
ülikoolis	doc_213943985053_item	3595236	et	4	main
õpimise	doc_213943985053_item	3595237	et	4	main
oma	doc_213943985054_item	3595263	et	4	main
et	doc_213943985054_item	3595289	et	3	main
väga	doc_213943985054_item	3595292	et	3	main
eriala	doc_213943985054_item	3595310	et	4	main
võib	doc_213943985054_item	3595311	et	3	main
õppida	doc_213943985054_item	3595312	et	3	main
ma	doc_213943985054_item	3595321	et	3	main
meelest	doc_213943985054_item	3595327	et	4	main
tulevikus	doc_213943985054_item	3595329	et	4	main
eriala	doc_213943985054_item	3595331	et	4	main
toob	doc_213943985054_item	3595332	et	3	main
selle	doc_213943985054_item	3595339	et	4	main
ajakirjanikuna	doc_213943985054_item	3595344	et	3	main
on	doc_213943985054_item	3595349	et	4	main
et	doc_213943985054_item	3595351	et	3	main
ma	doc_213943985054_item	3595352	et	3	main
valisin	doc_213943985054_item	3595353	et	3	main
selle	doc_213943985054_item	3595354	et	4	main
ja	doc_213943985053_item	3595207	et	3	main
ka	doc_213943985053_item	3595208	et	3	main
olin	doc_213943985053_item	3595209	et	3	main
teeviit	doc_213943985053_item	3595210	et	3	main
valisin	doc_213943985053_item	3595214	et	3	main
sellepärast	doc_213943985053_item	3595215	et	3	main
uudised	doc_213943985053_item	3595223	et	3	main
ja	doc_213943985053_item	3595224	et	3	main
ajal	doc_213943985053_item	3595238	et	4	main
võib	doc_213943985053_item	3595239	et	3	main
leida	doc_213943985053_item	3595240	et	3	main
tee	doc_213943985054_item	3595260	et	4	main
eriala	doc_213943985054_item	3595264	et	4	main
ma	doc_213943985054_item	3595267	et	3	main
palju	doc_213943985054_item	3595278	et	4	main
see	doc_213943985054_item	3595290	et	3	main
sõbralik	doc_213943985054_item	3595303	et	3	main
erinevate	doc_213943985054_item	3595307	et	4	main
inimestega	doc_213943985054_item	3595308	et	3	main
tulevikus	doc_213943985054_item	3595315	et	4	main
ma	doc_213943985054_item	3595316	et	3	main
võin	doc_213943985054_item	3595317	et	3	main
töötada	doc_213943985054_item	3595318	et	3	main
erinevates	doc_213943985054_item	3595319	et	4	main
firmades	doc_213943985054_item	3595320	et	3	main
huvitavaid	doc_213943985054_item	3595324	et	4	main
minu	doc_213943985054_item	3595326	et	3	main
palju	doc_213943985054_item	3595334	et	4	main
eriala	doc_213943985054_item	3595340	et	4	main
meeldib	doc_213943985054_item	3595346	et	3	main
mul	doc_213943985054_item	3595348	et	3	main
erialad	doc_213943985055_item	3595359	et	3	main
sest	doc_213943985055_item	3595362	et	4	main
tänav	doc_213943985055_item	3595364	et	4	main
mood	doc_213943985055_item	3595365	et	3	main
paljud	doc_213943985055_item	3595366	et	3	main
et	doc_213943985055_item	3595378	et	3	main
missuguses	doc_213943985055_item	3595383	et	3	main
võib	doc_213943985055_item	3595385	et	3	main
saavutada	doc_213943985055_item	3595386	et	3	main
ja	doc_213943985055_item	3595388	et	3	main
missugune	doc_213943985055_item	3595389	et	3	main
ma	doc_213943985055_item	3595394	et	3	main
leidsin	doc_213943985055_item	3595395	et	3	main
internetist	doc_213943985055_item	3595397	et	4	main
ja	doc_213943985055_item	3595398	et	3	main
sõpradest	doc_213943985055_item	3595399	et	3	main
miks	doc_213943985055_item	3595400	et	4	main
ma	doc_213943985055_item	3595401	et	3	main
valin	doc_213943985055_item	3595402	et	3	main
elukutse	doc_213943985055_item	3595411	et	4	main
minna	doc_213943985055_item	3595444	et	3	main
tartu	doc_213943985055_item	3595445	et	4	main
kahe	doc_213943985055_item	3595453	et	3	main
kirjalik	doc_213943985054_item	3595261	et	3	main
kohta	doc_213943985054_item	3595266	et	4	main
leidsin	doc_213943985054_item	3595268	et	3	main
kohta	doc_213943985054_item	3595270	et	4	main
infot	doc_213943985054_item	3595271	et	3	main
oma	doc_213943985054_item	3595272	et	4	main
sõpradest	doc_213943985054_item	3595273	et	3	main
ja	doc_213943985054_item	3595274	et	3	main
ma	doc_213943985054_item	3595275	et	3	main
kohta	doc_213943985054_item	3595281	et	4	main
see	doc_213943985054_item	3595282	et	3	main
minu	doc_213943985054_item	3595286	et	3	main
on	doc_213943985054_item	3595291	et	4	main
huvitav	doc_213943985054_item	3595293	et	4	main
võin	doc_213943985054_item	3595296	et	3	main
saada	doc_213943985054_item	3595297	et	4	main
ajakirjanikuna	doc_213943985054_item	3595298	et	3	main
meeldib	doc_213943985054_item	3595305	et	3	main
tallinna	doc_213943985054_item	3595313	et	4	main
ülikoolis	doc_213943985054_item	3595314	et	4	main
kirjutada	doc_213943985054_item	3595323	et	3	main
artikleid	doc_213943985054_item	3595325	et	3	main
ja	doc_213943985054_item	3595341	et	3	main
rõõmus	doc_213943985054_item	3595350	et	4	main
paljud	doc_213943985055_item	3595358	et	3	main
erialad	doc_213943985055_item	3595367	et	3	main
mõtlen	doc_213943985055_item	3595377	et	3	main
peab	doc_213943985055_item	3595380	et	4	main
see	doc_213943985055_item	3595392	et	3	main
see	doc_213943985055_item	3595403	et	3	main
eriala	doc_213943985055_item	3595404	et	4	main
ma	doc_213943985055_item	3595405	et	3	main
tean	doc_213943985055_item	3595406	et	3	main
et	doc_213943985055_item	3595407	et	3	main
ma	doc_213943985055_item	3595408	et	3	main
vahe	doc_213943985055_item	3595451	et	4	main
keskel	doc_213943985055_item	3595452	et	3	main
sarnased	doc_213943985055_item	3595457	et	4	main
seal	doc_213943985055_item	3595463	et	4	main
meil	doc_213943985055_item	3595474	et	4	main
raadios	doc_213943985055_item	3595484	et	3	main
eriala	doc_213943985056_item	3595526	et	4	main
internetist	doc_213943985056_item	3595539	et	4	main
ja	doc_213943985056_item	3595540	et	3	main
küsisin	doc_213943985056_item	3595544	et	3	main
nad	doc_213943985056_item	3595547	et	3	main
suhelda	doc_213943985056_item	3595558	et	4	main
teiseks	doc_213943985056_item	3595560	et	4	main
eriala	doc_213943985056_item	3595570	et	4	main
selle	doc_213943985056_item	3595571	et	4	main
pärast	doc_213943985056_item	3595572	et	4	main
et	doc_213943985056_item	3595573	et	3	main
tartu	doc_213943985056_item	3595582	et	4	main
ja	doc_213943985056_item	3595583	et	3	main
tartus	doc_213943985056_item	3595589	et	3	main
õppida	doc_213943985056_item	3595592	et	3	main
tee	doc_213943985058_item	3595637	et	4	main
tahtsin	doc_213943985058_item	3595650	et	3	main
veel	doc_213943985058_item	3595657	et	4	main
kui	doc_213943985058_item	3595659	et	3	main
eksamid	doc_213943985058_item	3595662	et	3	main
tahan	doc_213943985058_item	3595666	et	3	main
vastus	doc_213943985058_item	3595672	et	3	main
meeldib	doc_213943985058_item	3595676	et	3	main
teada	doc_213943985058_item	3595679	et	3	main
uudiseid	doc_213943985058_item	3595681	et	3	main
on	doc_213943985058_item	3595684	et	4	main
infot	doc_213943985058_item	3595689	et	3	main
saada	doc_213943985058_item	3595701	et	4	main
tööle	doc_213943985058_item	3595737	et	3	main
potile	doc_432051777912_item	3595766	et	4	main
soodsa	doc_432051777912_item	3595772	et	4	main
3	doc_432051777912_item	3595774	et	2	main
käitume	doc_432051777912_item	3595776	et	3	main
korralikult	doc_432051777912_item	3595777	et	4	main
nagu	doc_432051777912_item	3595778	et	3	main
igal	doc_432051777912_item	3595779	et	3	main
kõiki	doc_432051777912_item	3595790	et	4	main
kordaminekuid	doc_432051777912_item	3595791	et	3	main
6	doc_432051777912_item	3595792	et	2	main
isal	doc_432051777912_item	3595793	et	3	main
inspiratsioon	doc_432051777912_item	3595800	et	3	main
harjutus	doc_213943985055_item	3595357	et	4	main
sest	doc_213943985055_item	3595370	et	4	main
eriala	doc_213943985055_item	3595382	et	4	main
ta	doc_213943985055_item	3595384	et	4	main
inimene	doc_213943985055_item	3595393	et	3	main
info	doc_213943985055_item	3595396	et	4	main
kus	doc_213943985055_item	3595412	et	3	main
ma	doc_213943985055_item	3595413	et	3	main
võin	doc_213943985055_item	3595414	et	3	main
palju	doc_213943985055_item	3595415	et	4	main
teha	doc_213943985055_item	3595416	et	3	main
ja	doc_213943985055_item	3595417	et	3	main
saavustada	doc_213943985055_item	3595418	et	4	main
kõrgus	doc_213943985055_item	3595419	et	4	main
on	doc_213943985055_item	3595420	et	4	main
vaja	doc_213943985055_item	3595421	et	4	main
rääkida	doc_213943985055_item	3595422	et	3	main
et	doc_213943985055_item	3595423	et	3	main
minu	doc_213943985055_item	3595424	et	3	main
sündis	doc_213943985055_item	3595425	et	3	main
valis	doc_213943985055_item	3595426	et	3	main
minu	doc_213943985055_item	3595427	et	3	main
jaoks	doc_213943985055_item	3595428	et	4	main
eriala	doc_213943985055_item	3595429	et	4	main
mulle	doc_213943985055_item	3595430	et	4	main
meeldib	doc_213943985055_item	3595431	et	3	main
töötada	doc_213943985055_item	3595432	et	3	main
inimesega	doc_213943985055_item	3595433	et	3	main
ja	doc_213943985055_item	3595434	et	3	main
analüüsida	doc_213943985055_item	3595435	et	3	main
faktid	doc_213943985055_item	3595436	et	3	main
ka	doc_213943985055_item	3595437	et	3	main
mulle	doc_213943985055_item	3595438	et	4	main
meeldib	doc_213943985055_item	3595439	et	3	main
kirjutada	doc_213943985055_item	3595440	et	3	main
miks	doc_213943985055_item	3595441	et	4	main
ei	doc_213943985055_item	3595443	et	4	main
meeldib	doc_213943985055_item	3595391	et	3	main
valida	doc_213943985055_item	3595410	et	3	main
ma	doc_213943985055_item	3595442	et	3	main
ülikoolis	doc_213943985055_item	3595446	et	4	main
esimene	doc_213943985055_item	3595447	et	3	main
ma	doc_213943985055_item	3595448	et	3	main
õppekavad	doc_213943985055_item	3595458	et	3	main
rahuldatud	doc_213943985055_item	3595469	et	4	main
me	doc_213943985055_item	3595471	et	4	main
lõpetame	doc_213943985055_item	3595472	et	3	main
ülikooli	doc_213943985055_item	3595473	et	4	main
on	doc_213943985055_item	3595480	et	4	main
tee	doc_213943985056_item	3595522	et	4	main
õpin	doc_213943985056_item	3595530	et	3	main
ma	doc_213943985056_item	3595535	et	3	main
mis	doc_213943985056_item	3595546	et	4	main
selle	doc_213943985056_item	3595549	et	4	main
eriala	doc_213943985056_item	3595550	et	4	main
meeldib	doc_213943985056_item	3595557	et	3	main
inimestega	doc_213943985056_item	3595559	et	3	main
mulle	doc_213943985056_item	3595561	et	4	main
meeldib	doc_213943985056_item	3595562	et	3	main
olla	doc_213943985056_item	3595563	et	3	main
sündmuse	doc_213943985056_item	3595564	et	3	main
keskel	doc_213943985056_item	3595565	et	3	main
kolmeks	doc_213943985056_item	3595566	et	4	main
ma	doc_213943985056_item	3595567	et	3	main
valisin	doc_213943985056_item	3595568	et	3	main
kõik	doc_213943985056_item	3595586	et	4	main
teavad	doc_213943985056_item	3595587	et	3	main
erialaga	doc_213943985056_item	3595622	et	3	main
võib	doc_213943985056_item	3595623	et	3	main
olla	doc_213943985056_item	3595624	et	3	main
palju	doc_213943985056_item	3595625	et	4	main
tudengid	doc_213943985056_item	3595626	et	3	main
pärast	doc_213943985056_item	3595627	et	4	main
ülikooli	doc_213943985056_item	3595628	et	4	main
lõpetamist	doc_213943985056_item	3595629	et	4	main
sõidavad	doc_213943985056_item	3595630	et	3	main
välismaale	doc_213943985056_item	3595631	et	4	main
parema	doc_213943985056_item	3595632	et	4	main
elu	doc_213943985056_item	3595633	et	4	main
leida	doc_213943985056_item	3595634	et	3	main
kohta	doc_213943985058_item	3595643	et	4	main
olen	doc_213943985058_item	3595644	et	3	main
sest	doc_213943985058_item	3595648	et	4	main
oma	doc_213943985058_item	3595652	et	4	main
sooritasin	doc_213943985058_item	3595660	et	3	main
küsisin	doc_213943985058_item	3595663	et	3	main
kellena	doc_213943985058_item	3595665	et	3	main
oli	doc_213943985058_item	3595669	et	3	main
siis	doc_213943985058_item	3595682	et	3	main
amet	doc_213943985058_item	3595686	et	3	main
sain	doc_213943985058_item	3595688	et	3	main
keeles	doc_213943985058_item	3595696	et	4	main
on	doc_213943985058_item	3595697	et	4	main
võimalus	doc_213943985058_item	3595698	et	3	main
seda	doc_213943985058_item	3595699	et	3	main
ameti	doc_213943985058_item	3595700	et	3	main
ja	doc_213943985058_item	3595707	et	3	main
ei	doc_213943985055_item	3595449	et	4	main
ülikoolist	doc_213943985055_item	3595454	et	4	main
peaaegu	doc_213943985055_item	3595456	et	3	main
teine	doc_213943985055_item	3595459	et	3	main
kui	doc_213943985055_item	3595470	et	3	main
võimalusi	doc_213943985055_item	3595481	et	3	main
töötada	doc_213943985055_item	3595482	et	3	main
ajalehes	doc_213943985055_item	3595483	et	3	main
minu	doc_213943985055_item	3595460	et	3	main
õppisid	doc_213943985055_item	3595462	et	4	main
ja	doc_213943985055_item	3595464	et	3	main
nad	doc_213943985055_item	3595465	et	3	main
töökohti	doc_213943985055_item	3595478	et	4	main
leida	doc_213943985055_item	3595479	et	3	main
või	doc_213943985055_item	3595485	et	4	main
televisioonis	doc_213943985055_item	3595486	et	4	main
mulle	doc_213943985055_item	3595487	et	4	main
meeldib	doc_213943985055_item	3595488	et	3	main
kõik	doc_213943985055_item	3595489	et	4	main
varianteid	doc_213943985055_item	3595490	et	4	main
sest	doc_213943985055_item	3595491	et	4	main
nad	doc_213943985055_item	3595492	et	3	main
on	doc_213943985055_item	3595493	et	4	main
huvitavad	doc_213943985055_item	3595494	et	4	main
ja	doc_213943985055_item	3595495	et	3	main
annavad	doc_213943985055_item	3595496	et	3	main
ajakirjanikule	doc_213943985055_item	3595497	et	3	main
võimalusi	doc_213943985055_item	3595498	et	3	main
areneda	doc_213943985055_item	3595499	et	3	main
elukutselise	doc_213943985055_item	3595500	et	4	main
ma	doc_213943985055_item	3595501	et	3	main
loodan	doc_213943985055_item	3595502	et	3	main
et	doc_213943985055_item	3595503	et	3	main
kõik	doc_213943985055_item	3595504	et	4	main
minu	doc_213943985055_item	3595505	et	3	main
soovid	doc_213943985055_item	3595506	et	4	main
õigesti	doc_213943985055_item	3595507	et	3	main
ja	doc_213943985055_item	3595508	et	3	main
meie	doc_213943985055_item	3595509	et	4	main
töö	doc_213943985055_item	3595510	et	4	main
annab	doc_213943985055_item	3595511	et	3	main
palju	doc_213943985055_item	3595512	et	4	main
häid	doc_213943985055_item	3595513	et	3	main
muljeid	doc_213943985055_item	3595514	et	3	main
ja	doc_213943985055_item	3595515	et	3	main
tutvustab	doc_213943985055_item	3595516	et	3	main
meid	doc_213943985055_item	3595517	et	4	main
hea	doc_213943985055_item	3595518	et	4	main
inimesega	doc_213943985055_item	3595519	et	3	main
kokkuvõte	doc_213943985056_item	3595524	et	3	main
valiku	doc_213943985056_item	3595527	et	3	main
tallinna	doc_213943985056_item	3595541	et	4	main
eest	doc_213943985056_item	3595551	et	4	main
ma	doc_213943985056_item	3595552	et	3	main
valisin	doc_213943985056_item	3595553	et	3	main
umbes	doc_213943985056_item	3595599	et	4	main
44	doc_213943985056_item	3595600	et	2	main
inimest	doc_213943985056_item	3595601	et	3	main
aga	doc_213943985056_item	3595602	et	3	main
riik	doc_213943985056_item	3595603	et	3	main
tellis	doc_213943985056_item	3595604	et	4	main
oma	doc_213943985056_item	3595605	et	4	main
vajandusel	doc_213943985056_item	3595606	et	4	main
ainult	doc_213943985056_item	3595607	et	4	main
4	doc_213943985056_item	3595608	et	2	main
inimest	doc_213943985056_item	3595609	et	3	main
ja	doc_213943985056_item	3595610	et	3	main
kõik	doc_213943985056_item	3595611	et	4	main
üliõpilased	doc_213943985056_item	3595612	et	3	main
pärast	doc_213943985056_item	3595613	et	4	main
ülikooli	doc_213943985056_item	3595614	et	4	main
lõpetamist	doc_213943985056_item	3595615	et	4	main
ei	doc_213943985056_item	3595616	et	4	main
leida	doc_213943985056_item	3595618	et	3	main
saa	doc_213943985056_item	3595617	et	4	main
töökohta	doc_213943985056_item	3595619	et	4	main
seatatud	doc_213943985056_item	3595620	et	4	main
harjutus	doc_213943985056_item	3595521	et	4	main
kirjalik	doc_213943985056_item	3595523	et	3	main
ma	doc_213943985056_item	3595529	et	3	main
tallinna	doc_213943985056_item	3595531	et	4	main
ülikoolis	doc_213943985056_item	3595532	et	4	main
ajakirjanduse	doc_213943985056_item	3595533	et	3	main
erialal	doc_213943985056_item	3595534	et	3	main
leidsin	doc_213943985056_item	3595536	et	3	main
eriala	doc_213943985056_item	3595537	et	4	main
infot	doc_213943985056_item	3595538	et	3	main
ülikoolist	doc_213943985056_item	3595542	et	4	main
sõpadelt	doc_213943985056_item	3595545	et	4	main
teavad	doc_213943985056_item	3595548	et	3	main
mulle	doc_213943985056_item	3595556	et	4	main
vene	doc_213943985056_item	3595576	et	4	main
ülikoolis	doc_213943985056_item	3595585	et	4	main
kõige	doc_213943985056_item	3595590	et	4	main
parem	doc_213943985056_item	3595591	et	4	main
kahjuks	doc_213943985056_item	3595594	et	4	main
praegu	doc_213943985056_item	3595595	et	3	main
esimesel	doc_213943985056_item	3595596	et	3	main
kursusel	doc_213943985056_item	3595597	et	3	main
õppivad	doc_213943985056_item	3595598	et	4	main
harjutus	doc_213943985058_item	3595636	et	4	main
kirjalik	doc_213943985058_item	3595638	et	3	main
oma	doc_213943985058_item	3595640	et	4	main
eriala	doc_213943985058_item	3595641	et	4	main
valiku	doc_213943985058_item	3595642	et	3	main
lapsepõlvest	doc_213943985058_item	3595649	et	4	main
maailmas	doc_213943985058_item	3595658	et	3	main
mu	doc_213943985058_item	3595661	et	3	main
endast	doc_213943985058_item	3595664	et	4	main
üks	doc_213943985058_item	3595671	et	3	main
ajakirjanikuna	doc_213943985058_item	3595673	et	3	main
inimestele	doc_213943985058_item	3595675	et	3	main
kirjutada	doc_213943985058_item	3595677	et	3	main
teda	doc_213943985058_item	3595685	et	4	main
sõbradest	doc_213943985058_item	3595687	et	4	main
palju	doc_213943985058_item	3595692	et	4	main
tartus	doc_213943985058_item	3595706	et	3	main
kuhu	doc_213943985058_item	3595736	et	3	main
raadiole	doc_213943985058_item	3595740	et	3	main
või	doc_213943985058_item	3595742	et	4	main
juba	doc_213943985058_item	3595744	et	3	main
tean	doc_213943985058_item	3595745	et	3	main
harjutus	doc_432051777912_item	3595763	et	4	main
2	doc_432051777912_item	3595769	et	2	main
ostusid	doc_432051777912_item	3595771	et	3	main
hinnaga	doc_432051777912_item	3595773	et	3	main
luuletajal	doc_432051777912_item	3595797	et	4	main
öösel	doc_432051777912_item	3595799	et	4	main
näinud	doc_432051777912_item	3595818	et	4	main
ajakirjandust	doc_213943985056_item	3595554	et	3	main
sest	doc_213943985056_item	3595555	et	4	main
selle	doc_213943985056_item	3595569	et	4	main
keeles	doc_213943985056_item	3595577	et	4	main
saab	doc_213943985056_item	3595578	et	3	main
sellele	doc_213943985056_item	3595579	et	4	main
erialale	doc_213943985056_item	3595580	et	3	main
õppida	doc_213943985056_item	3595581	et	3	main
et	doc_213943985056_item	3595588	et	3	main
ajakirjandusele	doc_213943985056_item	3595593	et	3	main
tallinna	doc_213943985056_item	3595584	et	4	main
oma	doc_213943985056_item	3595621	et	4	main
tudeng	doc_213943985058_item	3595647	et	3	main
teada	doc_213943985058_item	3595651	et	3	main
keel	doc_213943985058_item	3595653	et	4	main
kui	doc_213943985058_item	3595655	et	3	main
ja	doc_213943985058_item	3595668	et	3	main
ainult	doc_213943985058_item	3595670	et	4	main
kui	doc_213943985058_item	3595674	et	3	main
artikleid	doc_213943985058_item	3595678	et	3	main
kõik	doc_213943985058_item	3595680	et	4	main
ajakirjandus	doc_213943985058_item	3595683	et	3	main
internetis	doc_213943985058_item	3595702	et	4	main
täpsustasin	doc_213943985058_item	3595703	et	3	main
et	doc_213943985058_item	3595704	et	3	main
ainult	doc_213943985058_item	3595705	et	4	main
valida	doc_213943985058_item	3595735	et	3	main
kas	doc_213943985058_item	3595739	et	3	main
telesaadele	doc_213943985058_item	3595743	et	4	main
et	doc_213943985058_item	3595717	et	3	main
ülikooli	doc_213943985058_item	3595718	et	4	main
lõpetan	doc_213943985058_item	3595719	et	3	main
hästi	doc_213943985058_item	3595720	et	3	main
ja	doc_213943985058_item	3595721	et	3	main
saan	doc_213943985058_item	3595722	et	4	main
töö	doc_213943985058_item	3595723	et	4	main
oma	doc_213943985058_item	3595724	et	4	main
ametis	doc_213943985058_item	3595725	et	3	main
et	doc_213943985058_item	3595726	et	3	main
oleks	doc_213943985058_item	3595727	et	3	main
võimalus	doc_213943985058_item	3595728	et	3	main
meelsasti	doc_213943985058_item	3595729	et	3	main
töötada	doc_213943985058_item	3595730	et	3	main
tean	doc_213943985058_item	3595731	et	3	main
et	doc_213943985058_item	3595732	et	3	main
ajakirjanikud	doc_213943985058_item	3595733	et	3	main
võivad	doc_213943985058_item	3595734	et	4	main
kokkuvõte	doc_213943985058_item	3595639	et	3	main
filosoofia	doc_213943985058_item	3595645	et	4	main
teaduskonna	doc_213943985058_item	3595646	et	4	main
parem	doc_213943985058_item	3595654	et	4	main
keegi	doc_213943985058_item	3595656	et	4	main
olla	doc_213943985058_item	3595667	et	3	main
kus	doc_213943985058_item	3595690	et	3	main
kui	doc_213943985058_item	3595691	et	3	main
aastad	doc_213943985058_item	3595693	et	3	main
ja	doc_213943985058_item	3595694	et	3	main
mis	doc_213943985058_item	3595695	et	4	main
tallinnas	doc_213943985058_item	3595708	et	4	main
võin	doc_213943985058_item	3595709	et	3	main
seda	doc_213943985058_item	3595710	et	3	main
õppida	doc_213943985058_item	3595711	et	3	main
ja	doc_213943985058_item	3595712	et	3	main
valin	doc_213943985058_item	3595713	et	3	main
tallinna	doc_213943985058_item	3595714	et	4	main
ülikooli	doc_213943985058_item	3595715	et	4	main
loodan	doc_213943985058_item	3595716	et	3	main
minna	doc_213943985058_item	3595738	et	3	main
1	doc_432051777912_item	3595764	et	2	main
4	doc_432051777912_item	3595781	et	2	main
mul	doc_432051777912_item	3595782	et	3	main
on	doc_432051777912_item	3595783	et	4	main
vaja	doc_432051777912_item	3595784	et	4	main
mõõta	doc_432051777912_item	3595785	et	3	main
pudeli	doc_432051777912_item	3595786	et	3	main
mahtu	doc_432051777912_item	3595787	et	4	main
5	doc_432051777912_item	3595788	et	2	main
soovin	doc_432051777912_item	3595789	et	3	main
7	doc_432051777912_item	3595796	et	2	main
klubis	doc_432051777912_item	3595802	et	3	main
palju	doc_432051777912_item	3595804	et	4	main
kohtumisi	doc_432051777912_item	3595806	et	4	main
9	doc_432051777912_item	3595807	et	2	main
veel	doc_432051777912_item	3595817	et	4	main
lehele	doc_213943985058_item	3595741	et	3	main
et	doc_213943985058_item	3595746	et	3	main
ajakirjanikule	doc_213943985058_item	3595747	et	3	main
makstakse	doc_213943985058_item	3595748	et	3	main
mitte	doc_213943985058_item	3595749	et	3	main
palk	doc_213943985058_item	3595751	et	3	main
suur	doc_213943985058_item	3595750	et	3	main
aga	doc_213943985058_item	3595752	et	3	main
kui	doc_213943985058_item	3595753	et	3	main
tööd	doc_213943985058_item	3595754	et	4	main
sind	doc_213943985058_item	3595755	et	4	main
huvitab	doc_213943985058_item	3595756	et	3	main
siis	doc_213943985058_item	3595757	et	3	main
raha	doc_213943985058_item	3595758	et	4	main
midagi	doc_213943985058_item	3595759	et	4	main
ei	doc_213943985058_item	3595760	et	4	main
tähenda	doc_213943985058_item	3595761	et	4	main
kaane	doc_432051777912_item	3595767	et	4	main
peale	doc_432051777912_item	3595768	et	4	main
koolis	doc_432051777912_item	3595775	et	4	main
kahtlus	doc_432051777912_item	3595795	et	4	main
tuli	doc_432051777912_item	3595798	et	4	main
peab	doc_432051777912_item	3595808	et	4	main
püüdma	doc_432051777912_item	3595809	et	3	main
eesmärgi	doc_432051777912_item	3595810	et	4	main
poole	doc_432051777912_item	3595811	et	4	main
nii	doc_432051777912_item	3595813	et	3	main
tagasihoidlikku	doc_432051777912_item	3595814	et	4	main
tüdrukut	doc_432051777912_item	3595815	et	3	main
pole	doc_432051777912_item	3595816	et	3	main
tahan	doc_432051777912_item	3595820	et	3	main
õppeaastat	doc_432051777912_item	3595844	et	3	main
16	doc_432051777912_item	3595845	et	2	main
mõnikord	doc_432051777912_item	3595846	et	3	main
tahaks	doc_432051777912_item	3595847	et	3	main
nutta	doc_432051777912_item	3595848	et	3	main
17	doc_432051777912_item	3595849	et	2	main
kui	doc_432051777912_item	3595850	et	3	main
ma	doc_432051777912_item	3595851	et	3	main
saan	doc_432051777912_item	3595852	et	4	main
siis	doc_432051777912_item	3595853	et	3	main
kirjutan	doc_432051777912_item	3595854	et	3	main
maha	doc_432051777912_item	3595855	et	4	main
18	doc_432051777912_item	3595856	et	2	main
ootame	doc_432051777912_item	3595857	et	3	main
sobivat	doc_432051777912_item	3595858	et	4	main
juhusti	doc_432051777912_item	3595859	et	4	main
19	doc_432051777912_item	3595860	et	2	main
sõnu	doc_432051777912_item	3595861	et	4	main
tuleb	doc_432051777912_item	3595862	et	3	main
õigesti	doc_432051777912_item	3595863	et	3	main
hääldata	doc_432051777912_item	3595864	et	3	main
20	doc_432051777912_item	3595865	et	2	main
aitasin	doc_432051777912_item	3595866	et	3	main
vanaemal	doc_432051777912_item	3595867	et	3	main
tänavat	doc_432051777912_item	3595868	et	4	main
üle	doc_432051777912_item	3595869	et	3	main
minna	doc_432051777912_item	3595870	et	3	main
pane	doc_432051777912_item	3595765	et	4	main
ostsin	doc_432051777912_item	3595770	et	3	main
pool	doc_432051777912_item	3595780	et	4	main
tekis	doc_432051777912_item	3595794	et	3	main
8	doc_432051777912_item	3595801	et	2	main
ei	doc_432051777912_item	3595826	et	4	main
tohi	doc_432051777912_item	3595827	et	4	main
olla	doc_432051777912_item	3595828	et	3	main
puudujääki	doc_432051777912_item	3595829	et	4	main
13	doc_432051777912_item	3595830	et	2	main
hilinejad	doc_432051777912_item	3595831	et	4	main
tuleb	doc_432051777912_item	3595832	et	3	main
kirja	doc_432051777912_item	3595833	et	4	main
panna	doc_432051777912_item	3595834	et	4	main
14	doc_432051777912_item	3595835	et	2	main
õpetaja	doc_432051777912_item	3595836	et	4	main
esitas	doc_432051777912_item	3595837	et	3	main
küsimusi	doc_432051777912_item	3595839	et	4	main
keeruliseid	doc_432051777912_item	3595838	et	4	main
15	doc_432051777912_item	3595840	et	2	main
sooviksin	doc_432051777912_item	3595841	et	3	main
endale	doc_432051777912_item	3595842	et	4	main
edukat	doc_432051777912_item	3595843	et	3	main
on	doc_432051777912_item	3595803	et	4	main
loominguliseid	doc_432051777912_item	3595805	et	4	main
10	doc_432051777912_item	3595812	et	2	main
11	doc_432051777912_item	3595819	et	2	main
natuke	doc_432051777912_item	3595821	et	4	main
ajalehte	doc_432051777912_item	3595822	et	4	main
sirvida	doc_432051777912_item	3595823	et	3	main
12	doc_432051777912_item	3595824	et	2	main
aruannes	doc_432051777912_item	3595825	et	3	main
dialogue	doc_399014257217_item	3596373	et	4	main
müüja	doc_399014257217_item	3596375	et	4	main
mida	doc_399014257217_item	3596376	et	4	main
üks	doc_399014257217_item	3596382	et	3	main
ning	doc_399014257217_item	3596384	et	3	main
mida	doc_399014257217_item	3596391	et	4	main
veel	doc_399014257217_item	3596392	et	4	main
ostja	doc_399014257217_item	3596393	et	4	main
müüja	doc_399014257217_item	3596398	et	4	main
krooni	doc_399014257217_item	3596413	et	4	main
tapselt	doc_399014257217_item	3596414	et	4	main
mahla	doc_399014257217_item	3596423	et	4	main
te	doc_399014257217_item	3596424	et	4	main
soovite	doc_399014257217_item	3596425	et	3	main
nii	doc_399014257217_item	3596430	et	3	main
apelsinimahla	doc_399014257217_item	3596431	et	4	main
kui	doc_399014257217_item	3596432	et	3	main
ka	doc_399014257217_item	3596433	et	3	main
head	doc_399014257217_item	3596445	et	4	main
teile	doc_399014257217_item	3596377	et	4	main
mulle	doc_399014257217_item	3596381	et	4	main
rohkem	doc_399014257217_item	3596397	et	4	main
palju	doc_399014257217_item	3596410	et	4	main
mahla	doc_399014257217_item	3596419	et	4	main
palun	doc_399014257217_item	3596420	et	3	main
või	doc_399014257217_item	3596427	et	4	main
palun	doc_399014257217_item	3596435	et	3	main
ostja	doc_399014257217_item	3596449	et	4	main
ah	doc_399014257217_item	3596450	et	3	main
meeldiv	doc_399014257217_item	3596452	et	4	main
müüja	doc_399014257217_item	3596457	et	4	main
kilo	doc_399014257217_item	3596459	et	4	main
see	doc_399014257217_item	3596460	et	3	main
on	doc_399014257217_item	3596461	et	4	main
väga	doc_399014257217_item	3596462	et	3	main
olen	doc_399014257217_item	3596468	et	3	main
vaga	doc_399014257217_item	3596469	et	4	main
olen	doc_399014257217_item	3596473	et	3	main
naljamees	doc_399014257217_item	3596479	et	4	main
ostja	doc_399014257217_item	3596480	et	4	main
ostja	doc_399014257217_item	3596487	et	4	main
oi	doc_399014257217_item	3596488	et	3	main
kui	doc_399014257217_item	3596489	et	3	main
kilo	doc_399014257217_item	3596500	et	4	main
müüja	doc_399014257217_item	3596506	et	4	main
kana	doc_399014257217_item	3596510	et	4	main
kvaliteet	doc_399014257217_item	3596513	et	3	main
hästi	doc_399014257217_item	3596515	et	3	main
müüja	doc_399014257217_item	3596522	et	4	main
täiesti	doc_399014257217_item	3596523	et	3	main
kolmkummend	doc_399014257217_item	3596524	et	4	main
viis	doc_399014257217_item	3596525	et	4	main
aitah	doc_399014257217_item	3596530	et	4	main
dialoog	doc_399014257217_item	3596372	et	3	main
homework	doc_399014257217_item	3596374	et	4	main
tere	doc_399014257217_item	3596379	et	3	main
leib	doc_399014257217_item	3596383	et	3	main
poole	doc_399014257217_item	3596385	et	4	main
juustu	doc_399014257217_item	3596387	et	4	main
müüja	doc_399014257217_item	3596388	et	4	main
palun	doc_399014257217_item	3596389	et	3	main
ja	doc_399014257217_item	3596390	et	3	main
palju	doc_399014257217_item	3596396	et	4	main
müüja	doc_399014257217_item	3596421	et	4	main
missugune	doc_399014257217_item	3596422	et	3	main
õuna	doc_399014257217_item	3596428	et	4	main
ostja	doc_399014257217_item	3596429	et	4	main
need	doc_399014257217_item	3596437	et	3	main
ka	doc_399014257217_item	3596439	et	3	main
kuus	doc_399014257217_item	3596454	et	4	main
ostja	doc_399014257217_item	3596464	et	4	main
pole	doc_399014257217_item	3596465	et	3	main
ma	doc_399014257217_item	3596472	et	3	main
loomulikult	doc_399014257217_item	3596481	et	4	main
ilusad	doc_399014257217_item	3596490	et	3	main
need	doc_399014257217_item	3596495	et	3	main
kakskummend	doc_399014257217_item	3596498	et	4	main
krooni	doc_399014257217_item	3596499	et	4	main
parim	doc_399014257217_item	3596512	et	4	main
poole	doc_399014257217_item	3596517	et	4	main
kilo	doc_399014257217_item	3596518	et	4	main
palun	doc_399014257217_item	3596519	et	3	main
kui	doc_399014257217_item	3596520	et	3	main
krooni	doc_399014257217_item	3596526	et	4	main
surr	doc_399014257217_item	3596529	et	4	main
nägemist	doc_399014257217_item	3596532	et	4	main
jällen	doc_399014257217_item	3596534	et	4	main
maarja	doc_399014257209_item	3596541	et	3	main
õnne	doc_399014257209_item	3596543	et	4	main
kuidas	doc_399014257209_item	3596550	et	3	main
jaan	doc_399014257209_item	3596556	et	3	main
tonu	doc_399014257209_item	3596562	et	4	main
naer	doc_399014257209_item	3596572	et	3	main
vanaema	doc_399014257209_item	3596574	et	4	main
sina	doc_399014257209_item	3596575	et	4	main
palja	doc_399014257209_item	3596585	et	3	main
ostja	doc_399014257217_item	3596378	et	4	main
kilo	doc_399014257217_item	3596386	et	4	main
ja	doc_399014257217_item	3596406	et	3	main
kala	doc_399014257217_item	3596408	et	4	main
kui	doc_399014257217_item	3596409	et	3	main
ostja	doc_399014257217_item	3596415	et	4	main
hästi	doc_399014257217_item	3596416	et	3	main
uks	doc_399014257217_item	3596417	et	3	main
pakk	doc_399014257217_item	3596418	et	3	main
apelsini	doc_399014257217_item	3596426	et	4	main
õunamahla	doc_399014257217_item	3596434	et	4	main
on	doc_399014257217_item	3596438	et	4	main
müüja	doc_399014257217_item	3596442	et	4	main
vaga	doc_399014257217_item	3596444	et	4	main
kilo	doc_399014257217_item	3596455	et	4	main
suuremeelne	doc_399014257217_item	3596470	et	3	main
müüja	doc_399014257217_item	3596471	et	4	main
palun	doc_399014257217_item	3596380	et	3	main
ei	doc_399014257217_item	3596394	et	4	main
palun	doc_399014257217_item	3596395	et	3	main
pole	doc_399014257217_item	3596399	et	3	main
viga	doc_399014257217_item	3596400	et	4	main
ostja	doc_399014257217_item	3596401	et	4	main
uks	doc_399014257217_item	3596402	et	3	main
pakk	doc_399014257217_item	3596403	et	3	main
tee	doc_399014257217_item	3596404	et	4	main
palun	doc_399014257217_item	3596405	et	3	main
viis	doc_399014257217_item	3596407	et	4	main
müüja	doc_399014257217_item	3596411	et	4	main
kümme	doc_399014257217_item	3596412	et	3	main
kas	doc_399014257217_item	3596436	et	3	main
head	doc_399014257217_item	3596440	et	4	main
kartulid	doc_399014257217_item	3596441	et	3	main
jaa	doc_399014257217_item	3596443	et	3	main
mulle	doc_399014257217_item	3596451	et	4	main
palun	doc_399014257217_item	3596456	et	3	main
kuus	doc_399014257217_item	3596458	et	4	main
viga	doc_399014257217_item	3596466	et	4	main
ma	doc_399014257217_item	3596467	et	3	main
pole	doc_399014257217_item	3596474	et	3	main
müüja	doc_399014257217_item	3596482	et	4	main
palun	doc_399014257217_item	3596483	et	3	main
ja	doc_399014257217_item	3596484	et	3	main
on	doc_399014257217_item	3596493	et	4	main
müüja	doc_399014257217_item	3596497	et	4	main
minu	doc_399014257217_item	3596509	et	3	main
ostja	doc_399014257217_item	3596514	et	4	main
mulle	doc_399014257217_item	3596516	et	4	main
ostja	doc_399014257217_item	3596528	et	4	main
müüja	doc_399014257217_item	3596531	et	4	main
tulen	doc_399014257217_item	3596533	et	3	main
estonian	doc_399014257209_item	3596538	et	4	main
läheb	doc_399014257209_item	3596551	et	3	main
hästi	doc_399014257209_item	3596554	et	3	main
ta	doc_399014257209_item	3596557	et	4	main
on	doc_399014257209_item	3596558	et	4	main
naine	doc_399014257209_item	3596563	et	3	main
maarja	doc_399014257209_item	3596564	et	3	main
jultunud	doc_399014257209_item	3596565	et	4	main
suured	doc_399014257217_item	3596446	et	3	main
ning	doc_399014257217_item	3596447	et	3	main
ilusad	doc_399014257217_item	3596448	et	3	main
sada	doc_399014257217_item	3596453	et	4	main
kallis	doc_399014257217_item	3596463	et	4	main
tänu	doc_399014257217_item	3596475	et	4	main
ma	doc_399014257217_item	3596477	et	3	main
olen	doc_399014257217_item	3596478	et	3	main
mida	doc_399014257217_item	3596485	et	4	main
veel	doc_399014257217_item	3596486	et	4	main
kana	doc_399014257217_item	3596491	et	4	main
mis	doc_399014257217_item	3596494	et	4	main
maksavad	doc_399014257217_item	3596496	et	3	main
ei	doc_399014257217_item	3596507	et	4	main
ole	doc_399014257217_item	3596508	et	4	main
palju	doc_399014257217_item	3596521	et	4	main
palun	doc_399014257217_item	3596527	et	3	main
sünnipäev	doc_399014257209_item	3596540	et	3	main
maarja	doc_399014257209_item	3596549	et	3	main
liiga	doc_399014257209_item	3596559	et	4	main
tonu	doc_399014257209_item	3596573	et	4	main
on	doc_399014257209_item	3596576	et	4	main
väga	doc_399014257209_item	3596577	et	3	main
vaikne	doc_399014257209_item	3596578	et	3	main
valge	doc_399014257209_item	3596586	et	4	main
tüüpiline	doc_399014257209_item	3596589	et	3	main
jaan	doc_399014257209_item	3596591	et	3	main
sunnipaevkook	doc_399014257209_item	3596593	et	4	main
on	doc_399014257209_item	3596607	et	4	main
vanaema	doc_399014257209_item	3596615	et	4	main
see	doc_399014257209_item	3596616	et	3	main
on	doc_399014257209_item	3596617	et	4	main
pärastin	doc_399014257209_item	3596625	et	4	main
kell	doc_399014257209_item	3596628	et	3	main
harjutus	doc_491521501918_item	3596673	et	4	main
perekond	doc_491521501918_item	3596681	et	3	main
üle	doc_491521501918_item	3596691	et	3	main
pereinimesed	doc_491521501918_item	3596693	et	3	main
alati	doc_491521501918_item	3596702	et	4	main
6	doc_491521501918_item	3596705	et	2	main
tänavalt	doc_491521501918_item	3596706	et	4	main
lapsed	doc_491521501918_item	3596712	et	3	main
käsutuses	doc_491521501918_item	3596718	et	4	main
on	doc_491521501918_item	3596719	et	4	main
9	doc_491521501918_item	3596721	et	2	main
10	doc_491521501918_item	3596727	et	2	main
kõige	doc_491521501918_item	3596728	et	4	main
oma	doc_491521501918_item	3596732	et	4	main
lähedaste	doc_491521501918_item	3596733	et	3	main
tervise	doc_491521501918_item	3596734	et	3	main
12	doc_491521501918_item	3596740	et	2	main
sageli	doc_491521501918_item	3596744	et	3	main
elektritööriista	doc_842434202397_item	3596787	et	4	main
võib	doc_842434202397_item	3596790	et	3	main
elektrilöögi	doc_842434202397_item	3596792	et	3	main
olla	doc_842434202397_item	3596796	et	3	main
ja	doc_842434202397_item	3596798	et	3	main
rikkida	doc_842434202397_item	3596800	et	4	main
sellepärast	doc_842434202397_item	3596807	et	3	main
ta	doc_842434202397_item	3596809	et	4	main
töötab	doc_842434202397_item	3596810	et	3	main
nähtud	doc_842434202397_item	3596817	et	4	main
piirides	doc_842434202397_item	3596819	et	3	main
elektritööriista	doc_842434202397_item	3596821	et	4	main
et	doc_842434202397_item	3596858	et	3	main
tagada	doc_842434202397_item	3596859	et	3	main
efektiivsust	doc_842434202397_item	3596860	et	4	main
ja	doc_842434202397_item	3596861	et	3	main
vajalik	doc_842434202397_item	3596880	et	3	main
jälgida	doc_842434202397_item	3596882	et	3	main
millest	doc_542009824771_item	3596918	et	3	main
silmadele	doc_542009824771_item	3596920	et	3	main
kasulik	doc_542009824771_item	3596922	et	3	main
valgust	doc_542009824771_item	3596924	et	4	main
muretseda	doc_542009824771_item	3596943	et	3	main
töölaud	doc_542009824771_item	3596953	et	4	main
peavad	doc_542009824771_item	3596958	et	4	main
mahtuma	doc_542009824771_item	3596961	et	3	main
peab	doc_542009824771_item	3596964	et	4	main
u-kujuline	doc_542009824771_item	3596978	et	4	main
tuleb	doc_542009824771_item	3596979	et	3	main
käsi	doc_542009824771_item	3596985	et	4	main
väärt	doc_399014257217_item	3596476	et	4	main
teil	doc_399014257217_item	3596492	et	4	main
ostja	doc_399014257217_item	3596501	et	4	main
see	doc_399014257217_item	3596502	et	3	main
on	doc_399014257217_item	3596503	et	4	main
natuke	doc_399014257217_item	3596504	et	4	main
kallis	doc_399014257217_item	3596505	et	4	main
on	doc_399014257217_item	3596511	et	4	main
ostja	doc_399014257217_item	3596535	et	4	main
homework	doc_399014257209_item	3596539	et	4	main
palju	doc_399014257209_item	3596542	et	4	main
tõnu	doc_399014257209_item	3596544	et	4	main
sünnipäevaks	doc_399014257209_item	3596545	et	3	main
tonu	doc_399014257209_item	3596546	et	4	main
aitäh	doc_399014257209_item	3596547	et	3	main
maarja	doc_399014257209_item	3596552	et	3	main
vaga	doc_399014257209_item	3596553	et	4	main
tänan	doc_399014257209_item	3596555	et	3	main
täna	doc_399014257209_item	3596561	et	4	main
poiss	doc_399014257209_item	3596566	et	3	main
they	doc_399014257209_item	3596567	et	4	main
all	doc_399014257209_item	3596568	et	3	main
laugh	doc_399014257209_item	3596569	et	4	main
nemad	doc_399014257209_item	3596570	et	3	main
kõik	doc_399014257209_item	3596571	et	4	main
vabandust	doc_399014257209_item	3596580	et	4	main
minu	doc_399014257209_item	3596581	et	3	main
viin	doc_399014257209_item	3596587	et	4	main
tonu	doc_399014257209_item	3596588	et	4	main
vanaisa	doc_399014257209_item	3596590	et	4	main
köökus	doc_399014257209_item	3596595	et	3	main
lähme	doc_399014257209_item	3596598	et	3	main
kukepea	doc_399014257209_item	3596618	et	4	main
nemad	doc_399014257209_item	3596619	et	3	main
jaan	doc_399014257209_item	3596626	et	3	main
on	doc_399014257209_item	3596629	et	4	main
tõnu	doc_399014257209_item	3596630	et	4	main
kell	doc_399014257209_item	3596631	et	3	main
sul	doc_399014257209_item	3596645	et	3	main
1	doc_491521501918_item	3596674	et	2	main
paljuski	doc_491521501918_item	3596677	et	4	main
2	doc_491521501918_item	3596679	et	2	main
majas	doc_491521501918_item	3596684	et	3	main
halvasti	doc_491521501918_item	3596688	et	3	main
ruumide	doc_491521501918_item	3596690	et	3	main
4	doc_491521501918_item	3596692	et	2	main
kostev	doc_491521501918_item	3596707	et	4	main
täiskasvanuks	doc_491521501918_item	3596715	et	4	main
8	doc_491521501918_item	3596716	et	2	main
inimeste	doc_491521501918_item	3596722	et	3	main
tubade	doc_491521501918_item	3596725	et	3	main
11	doc_491521501918_item	3596736	et	2	main
korterisisustus	doc_491521501918_item	3596737	et	3	main
on	doc_491521501918_item	3596738	et	4	main
on	doc_491521501918_item	3596743	et	4	main
raskusi	doc_491521501918_item	3596745	et	4	main
harjutus	doc_842434202397_item	3596779	et	4	main
vihma	doc_842434202397_item	3596783	et	4	main
ja	doc_842434202397_item	3596793	et	3	main
tohi	doc_842434202397_item	3596804	et	4	main
talle	doc_842434202397_item	3596815	et	4	main
3	doc_842434202397_item	3596820	et	2	main
laste	doc_842434202397_item	3596823	et	4	main
eest	doc_842434202397_item	3596824	et	4	main
mitte	doc_842434202397_item	3596864	et	3	main
juhul	doc_842434202397_item	3596866	et	3	main
et	doc_842434202397_item	3596883	et	3	main
tööriist	doc_842434202397_item	3596884	et	3	main
käivituks	doc_842434202397_item	3596886	et	3	main
sellepärast	doc_842434202397_item	3596888	et	3	main
et	doc_842434202397_item	3596889	et	3	main
võib	doc_842434202397_item	3596890	et	3	main
põhjustada	doc_842434202397_item	3596891	et	3	main
optimaalsest	doc_542009824771_item	3596917	et	3	main
on	doc_542009824771_item	3596942	et	4	main
missugune	doc_542009824771_item	3596948	et	3	main
nägemist	doc_399014257217_item	3596536	et	4	main
dialoog	doc_399014257209_item	3596537	et	3	main
tädi	doc_399014257209_item	3596548	et	4	main
jutukas	doc_399014257209_item	3596560	et	4	main
vanaema	doc_399014257209_item	3596579	et	4	main
liiga	doc_399014257209_item	3596584	et	4	main
kus	doc_399014257209_item	3596592	et	3	main
vanaisa	doc_399014257209_item	3596596	et	4	main
on	doc_399014257209_item	3596600	et	4	main
küll	doc_399014257209_item	3596601	et	4	main
mis	doc_399014257209_item	3596602	et	4	main
kell	doc_399014257209_item	3596603	et	3	main
parem	doc_399014257209_item	3596614	et	4	main
jälle	doc_399014257209_item	3596622	et	3	main
täpselt	doc_399014257209_item	3596634	et	4	main
maarja	doc_399014257209_item	3596635	et	3	main
palun	doc_399014257209_item	3596636	et	3	main
varsti	doc_399014257209_item	3596644	et	3	main
minna	doc_399014257209_item	3596648	et	3	main
jah	doc_399014257209_item	3596650	et	3	main
on	doc_399014257209_item	3596652	et	4	main
meie	doc_491521501918_item	3596680	et	4	main
3	doc_491521501918_item	3596685	et	2	main
kurdame	doc_491521501918_item	3596687	et	3	main
köetud	doc_491521501918_item	3596689	et	4	main
on	doc_491521501918_item	3596694	et	4	main
omavaheliste	doc_491521501918_item	3596695	et	4	main
müra	doc_491521501918_item	3596708	et	4	main
segab	doc_491521501918_item	3596709	et	3	main
perekonna	doc_491521501918_item	3596717	et	4	main
arv	doc_491521501918_item	3596723	et	3	main
arvu	doc_491521501918_item	3596726	et	4	main
enam	doc_491521501918_item	3596729	et	4	main
ma	doc_491521501918_item	3596730	et	3	main
muretsen	doc_491521501918_item	3596731	et	3	main
vana	doc_491521501918_item	3596739	et	4	main
peal	doc_399014257209_item	3596582	et	4	main
vigastatud	doc_399014257209_item	3596583	et	4	main
jaan	doc_399014257209_item	3596594	et	3	main
aitäh	doc_399014257209_item	3596597	et	3	main
jaan	doc_399014257209_item	3596599	et	3	main
lõikama	doc_399014257209_item	3596608	et	3	main
tonu	doc_399014257209_item	3596610	et	4	main
mida	doc_399014257209_item	3596611	et	4	main
varem	doc_399014257209_item	3596612	et	4	main
seda	doc_399014257209_item	3596613	et	3	main
kõik	doc_399014257209_item	3596620	et	4	main
naer	doc_399014257209_item	3596621	et	3	main
kaks	doc_399014257209_item	3596623	et	3	main
tundi	doc_399014257209_item	3596624	et	4	main
mis	doc_399014257209_item	3596627	et	4	main
vabandust	doc_399014257209_item	3596637	et	4	main
aeg	doc_399014257209_item	3596638	et	3	main
on	doc_399014257209_item	3596639	et	4	main
minema	doc_399014257209_item	3596640	et	3	main
hakata	doc_399014257209_item	3596641	et	4	main
on	doc_399014257209_item	3596646	et	4	main
aeg	doc_399014257209_item	3596647	et	3	main
jaan	doc_399014257209_item	3596649	et	3	main
kell	doc_399014257209_item	3596651	et	3	main
tõnu	doc_399014257209_item	3596654	et	4	main
tänan	doc_399014257209_item	3596655	et	3	main
millegi	doc_399014257209_item	3596656	et	4	main
tulen	doc_399014257209_item	3596657	et	3	main
maarja	doc_399014257209_item	3596658	et	3	main
pole	doc_399014257209_item	3596659	et	3	main
viga	doc_399014257209_item	3596660	et	4	main
ma	doc_399014257209_item	3596661	et	3	main
armistan	doc_399014257209_item	3596662	et	4	main
sind	doc_399014257209_item	3596663	et	4	main
jaan	doc_399014257209_item	3596664	et	3	main
head	doc_399014257209_item	3596665	et	4	main
ööd	doc_399014257209_item	3596666	et	4	main
tõnu	doc_399014257209_item	3596667	et	4	main
tõnu	doc_399014257209_item	3596668	et	4	main
head	doc_399014257209_item	3596669	et	4	main
nägemist	doc_399014257209_item	3596671	et	4	main
ööd	doc_399014257209_item	3596670	et	4	main
õnn	doc_491521501918_item	3596675	et	3	main
sõltub	doc_491521501918_item	3596676	et	3	main
pisiasjadest	doc_491521501918_item	3596678	et	3	main
suhetega	doc_491521501918_item	3596696	et	3	main
täiesti	doc_491521501918_item	3596697	et	3	main
rahul	doc_491521501918_item	3596698	et	4	main
5	doc_491521501918_item	3596699	et	2	main
elamistingimuste	doc_491521501918_item	3596700	et	3	main
kõrgelt	doc_491521501918_item	3596703	et	4	main
väärtustatud	doc_491521501918_item	3596704	et	4	main
on	doc_491521501918_item	3596713	et	4	main
saanud	doc_491521501918_item	3596714	et	4	main
keskküte	doc_491521501918_item	3596720	et	3	main
peredel	doc_491521501918_item	3596742	et	3	main
kodune	doc_842434202397_item	3596780	et	4	main
ülesanne	doc_842434202397_item	3596781	et	4	main
1	doc_842434202397_item	3596782	et	2	main
tohi	doc_842434202397_item	3596786	et	4	main
saada	doc_842434202397_item	3596791	et	4	main
lühis	doc_842434202397_item	3596797	et	4	main
võib	doc_842434202397_item	3596799	et	3	main
elektritööriista	doc_842434202397_item	3596802	et	4	main
on	doc_399014257209_item	3596604	et	4	main
maarja	doc_399014257209_item	3596605	et	3	main
aeg	doc_399014257209_item	3596606	et	3	main
kooki	doc_399014257209_item	3596609	et	4	main
on	doc_399014257209_item	3596632	et	4	main
kumme	doc_399014257209_item	3596633	et	3	main
tõnu	doc_399014257209_item	3596642	et	4	main
nii	doc_399014257209_item	3596643	et	3	main
hiljutine	doc_399014257209_item	3596653	et	3	main
14	doc_491521501918_item	3596754	et	2	main
noored	doc_491521501918_item	3596755	et	3	main
pered	doc_491521501918_item	3596756	et	3	main
ei	doc_491521501918_item	3596757	et	4	main
ole	doc_491521501918_item	3596758	et	4	main
rahul	doc_491521501918_item	3596759	et	4	main
oma	doc_491521501918_item	3596760	et	4	main
mugavused	doc_491521501918_item	3596761	et	4	main
15	doc_491521501918_item	3596762	et	2	main
me	doc_491521501918_item	3596763	et	4	main
kurdame	doc_491521501918_item	3596764	et	3	main
16	doc_491521501918_item	3596765	et	2	main
noored	doc_491521501918_item	3596766	et	3	main
inimesed	doc_491521501918_item	3596767	et	3	main
elavad	doc_491521501918_item	3596768	et	4	main
eraldi	doc_491521501918_item	3596769	et	4	main
17	doc_491521501918_item	3596770	et	2	main
majapidamiseg	doc_491521501918_item	3596771	et	4	main
segab	doc_491521501918_item	3596772	et	3	main
tolm	doc_491521501918_item	3596773	et	3	main
18	doc_491521501918_item	3596774	et	2	main
heitgaasid	doc_491521501918_item	3596775	et	3	main
on	doc_491521501918_item	3596776	et	4	main
kahjulik	doc_491521501918_item	3596777	et	3	main
elab	doc_491521501918_item	3596682	et	3	main
mitmekorruselises	doc_491521501918_item	3596683	et	4	main
me	doc_491521501918_item	3596686	et	4	main
on	doc_491521501918_item	3596701	et	4	main
kodurahu	doc_491521501918_item	3596710	et	4	main
7	doc_491521501918_item	3596711	et	2	main
ületab	doc_491521501918_item	3596724	et	3	main
pärast	doc_491521501918_item	3596735	et	4	main
noortel	doc_491521501918_item	3596741	et	3	main
omaette	doc_491521501918_item	3596746	et	3	main
elamispinna	doc_491521501918_item	3596747	et	3	main
muretsemisega	doc_491521501918_item	3596748	et	4	main
13	doc_491521501918_item	3596749	et	2	main
kodutehnika	doc_491521501918_item	3596750	et	4	main
on	doc_491521501918_item	3596751	et	4	main
heas	doc_491521501918_item	3596752	et	3	main
korras	doc_491521501918_item	3596753	et	4	main
kätte	doc_842434202397_item	3596784	et	4	main
ei	doc_842434202397_item	3596785	et	4	main
ekt-asse	doc_842434202397_item	3596794	et	3	main
võib	doc_842434202397_item	3596795	et	3	main
2	doc_842434202397_item	3596801	et	2	main
paremini	doc_842434202397_item	3596812	et	4	main
ette	doc_842434202397_item	3596816	et	4	main
tuleb	doc_842434202397_item	3596822	et	3	main
6	doc_842434202397_item	3596863	et	2	main
on	doc_842434202397_item	3596881	et	4	main
8	doc_842434202397_item	3596894	et	2	main
te	doc_842434202397_item	3596895	et	4	main
võite	doc_842434202397_item	3596896	et	4	main
kasutada	doc_842434202397_item	3596897	et	3	main
ainult	doc_842434202397_item	3596898	et	4	main
spetsiaalseid	doc_842434202397_item	3596899	et	3	main
lisaosi	doc_842434202397_item	3596900	et	4	main
sellepärast	doc_842434202397_item	3596901	et	3	main
et	doc_842434202397_item	3596902	et	3	main
muude	doc_842434202397_item	3596903	et	4	main
lisaseadmete	doc_842434202397_item	3596904	et	3	main
kasutamine	doc_842434202397_item	3596905	et	4	main
võib	doc_842434202397_item	3596906	et	3	main
põhjustada	doc_842434202397_item	3596907	et	3	main
töönnetusi	doc_842434202397_item	3596908	et	4	main
ei	doc_842434202397_item	3596867	et	4	main
tohi	doc_842434202397_item	3596868	et	4	main
tööriista	doc_842434202397_item	3596869	et	4	main
kanda	doc_842434202397_item	3596870	et	4	main
juhtmest	doc_842434202397_item	3596871	et	4	main
hoides	doc_842434202397_item	3596872	et	4	main
sellepärast	doc_842434202397_item	3596873	et	3	main
et	doc_842434202397_item	3596874	et	3	main
ta	doc_842434202397_item	3596875	et	4	main
võib	doc_842434202397_item	3596876	et	3	main
tahtmatult	doc_842434202397_item	3596877	et	4	main
käivitada	doc_842434202397_item	3596878	et	3	main
sellepärast	doc_842434202397_item	3596788	et	3	main
et	doc_842434202397_item	3596789	et	3	main
üle	doc_842434202397_item	3596805	et	3	main
koormata	doc_842434202397_item	3596806	et	4	main
et	doc_842434202397_item	3596808	et	3	main
ja	doc_842434202397_item	3596813	et	3	main
eemal	doc_842434202397_item	3596825	et	3	main
hoida	doc_842434202397_item	3596826	et	3	main
sellepärast	doc_842434202397_item	3596827	et	3	main
et	doc_842434202397_item	3596828	et	3	main
võib	doc_842434202397_item	3596829	et	3	main
lastega	doc_842434202397_item	3596830	et	3	main
juhtuda	doc_842434202397_item	3596831	et	3	main
õnnetus	doc_842434202397_item	3596832	et	4	main
4	doc_842434202397_item	3596833	et	2	main
tööriista	doc_842434202397_item	3596834	et	4	main
kasutades	doc_842434202397_item	3596835	et	3	main
peab	doc_842434202397_item	3596836	et	4	main
õigesti	doc_842434202397_item	3596837	et	3	main
riietuma	doc_842434202397_item	3596838	et	3	main
ja	doc_842434202397_item	3596839	et	3	main
tolmukaitset	doc_842434202397_item	3596840	et	4	main
kandma	doc_842434202397_item	3596841	et	3	main
sellepärast	doc_842434202397_item	3596842	et	3	main
et	doc_842434202397_item	3596843	et	3	main
võivad	doc_842434202397_item	3596844	et	4	main
takerduda	doc_842434202397_item	3596845	et	3	main
pöörduvatesse	doc_842434202397_item	3596846	et	4	main
sõlmedesse	doc_842434202397_item	3596847	et	4	main
ja	doc_842434202397_item	3596848	et	3	main
tolmu	doc_842434202397_item	3596849	et	4	main
hingamisteedesse	doc_842434202397_item	3596850	et	3	main
5	doc_842434202397_item	3596851	et	2	main
tööriista	doc_842434202397_item	3596852	et	4	main
peab	doc_842434202397_item	3596853	et	4	main
hoidma	doc_842434202397_item	3596854	et	3	main
alati	doc_842434202397_item	3596855	et	4	main
puhtana	doc_842434202397_item	3596856	et	3	main
sellepärast	doc_842434202397_item	3596857	et	3	main
ei	doc_842434202397_item	3596803	et	4	main
kõige	doc_842434202397_item	3596811	et	4	main
turvasemalt	doc_842434202397_item	3596814	et	4	main
koormuse	doc_842434202397_item	3596818	et	3	main
õnnetusi	doc_842434202397_item	3596893	et	4	main
harjutus	doc_542009824771_item	3596910	et	4	main
ja	doc_542009824771_item	3596916	et	3	main
piisavalt	doc_542009824771_item	3596944	et	4	main
ja	doc_542009824771_item	3596946	et	3	main
mis	doc_542009824771_item	3596954	et	4	main
tööpind	doc_542009824771_item	3596956	et	3	main
püsikinde	doc_542009824771_item	3596966	et	4	main
seljatoe	doc_542009824771_item	3596968	et	3	main
istme	doc_542009824771_item	3596970	et	3	main
missugune	doc_542009824771_item	3596972	et	3	main
3x	doc_542009824771_item	3596973	et	4	main
7	doc_542009824771_item	3596974	et	2	main
kui	doc_542009824771_item	3596975	et	3	main
saab	doc_542009824771_item	3596986	et	3	main
pean	doc_542009824810_item	3597028	et	4	main
pean	doc_542009824810_item	3597044	et	4	main
tutvustama	doc_542009824810_item	3597045	et	3	main
jätan	doc_542009824810_item	3597060	et	3	main
ma	doc_542009824810_item	3597078	et	3	main
sest	doc_542009824810_item	3597089	et	4	main
postkaarti	doc_542009824810_item	3597096	et	4	main
õpilased	doc_542009824810_item	3597112	et	3	main
peate	doc_542009824810_item	3597114	et	4	main
pean	doc_542009824810_item	3597121	et	4	main
esimesel	doc_286998102737_item	3597165	et	3	main
kell	doc_286998102737_item	3597169	et	3	main
pliiats	doc_286998102737_item	3597170	et	4	main
kahvel	doc_286998102737_item	3597180	et	4	main
glaas	doc_286998102737_item	3597181	et	4	main
ja	doc_286998102737_item	3597182	et	3	main
taldrik	doc_286998102737_item	3597183	et	3	main
öö	doc_286998102737_item	3597211	et	4	main
on	doc_286998102737_item	3597229	et	4	main
aken	doc_286998102737_item	3597233	et	3	main
turvalisust	doc_842434202397_item	3596862	et	4	main
mingil	doc_842434202397_item	3596865	et	4	main
7	doc_842434202397_item	3596879	et	2	main
ei	doc_842434202397_item	3596885	et	4	main
tahtmatult	doc_842434202397_item	3596887	et	4	main
kellelegi	doc_842434202397_item	3596892	et	4	main
1	doc_542009824771_item	3596911	et	2	main
mugavast	doc_542009824771_item	3596914	et	3	main
2	doc_542009824771_item	3596919	et	2	main
on	doc_542009824771_item	3596921	et	4	main
kui	doc_542009824771_item	3596923	et	3	main
5	doc_542009824771_item	3596951	et	2	main
töötaja	doc_542009824771_item	3596952	et	4	main
on	doc_542009824771_item	3596977	et	4	main
toetada	doc_542009824771_item	3596987	et	3	main
töötaja	doc_542009824771_item	3597011	et	4	main
ma	doc_542009824810_item	3597027	et	3	main
äratama	doc_542009824810_item	3597029	et	3	main
ma	doc_542009824810_item	3597059	et	3	main
ma	doc_542009824810_item	3597063	et	3	main
harjutama	doc_542009824810_item	3597065	et	4	main
olen	doc_542009824810_item	3597069	et	3	main
ma	doc_542009824810_item	3597072	et	3	main
soovitani	doc_542009824810_item	3597073	et	4	main
kuidas	doc_542009824810_item	3597074	et	3	main
inimesed	doc_542009824810_item	3597075	et	3	main
peavad	doc_542009824810_item	3597076	et	4	main
venda	doc_542009824810_item	3597088	et	4	main
saadan	doc_542009824810_item	3597095	et	4	main
kuus	doc_542009824810_item	3597100	et	4	main
te	doc_542009824810_item	3597113	et	4	main
kirjeldus	doc_286998102737_item	3597164	et	4	main
on	doc_286998102737_item	3597168	et	4	main
teisel	doc_286998102737_item	3597173	et	4	main
pildil	doc_286998102737_item	3597174	et	3	main
ei	doc_286998102737_item	3597175	et	4	main
on	doc_286998102737_item	3597210	et	4	main
kirju	doc_286998102737_item	3597221	et	4	main
laualiina	doc_286998102737_item	3597223	et	3	main
on	doc_286998102737_item	3597224	et	4	main
kirju	doc_286998102737_item	3597230	et	4	main
teisel	doc_286998102737_item	3597231	et	4	main
pildi	doc_286998102739_item	3597262	et	4	main
asemel	doc_286998102739_item	3597276	et	4	main
siin	doc_286998102739_item	3597282	et	4	main
ja	doc_286998102739_item	3597287	et	3	main
on	doc_286998102739_item	3597295	et	4	main
aga	doc_286998102739_item	3597297	et	3	main
kahvel	doc_286998102739_item	3597302	et	4	main
ja	doc_286998102739_item	3597303	et	3	main
glaas	doc_286998102739_item	3597304	et	4	main
juba	doc_286998102739_item	3597328	et	3	main
koer	doc_286998102739_item	3597330	et	3	main
kurb	doc_286998102739_item	3597332	et	3	main
sest	doc_286998102739_item	3597333	et	4	main
tal	doc_286998102739_item	3597334	et	3	main
et	doc_286998102739_item	3597360	et	3	main
peal	doc_286998102739_item	3597390	et	4	main
aga	doc_286998102739_item	3597391	et	3	main
korteris	doc_286998102739_item	3597396	et	3	main
ja	doc_286998102739_item	3597406	et	3	main
on	doc_286998102739_item	3597408	et	4	main
öö	doc_286998102739_item	3597409	et	4	main
pildi	doc_286998102743_item	3597412	et	4	main
nemad	doc_286998102743_item	3597417	et	3	main
puud	doc_286998102743_item	3597422	et	4	main
on	doc_286998102743_item	3597428	et	4	main
poisid	doc_286998102743_item	3597434	et	4	main
on	doc_286998102743_item	3597436	et	4	main
on	doc_286998102743_item	3597440	et	4	main
ajakirjanik	doc_286998102743_item	3597441	et	3	main
jaan	doc_286998102743_item	3597447	et	3	main
üliõpilaned	doc_286998102743_item	3597450	et	4	main
perekond	doc_286998102743_item	3597451	et	3	main
räägivad	doc_286998102743_item	3597452	et	3	main
ja	doc_286998102743_item	3597453	et	3	main
söövad	doc_286998102743_item	3597454	et	4	main
valge	doc_286998102743_item	3597459	et	4	main
suur	doc_286998102743_item	3597460	et	3	main
ja	doc_286998102743_item	3597461	et	3	main
ilus	doc_286998102743_item	3597462	et	4	main
madis	doc_286998102743_item	3597463	et	3	main
8	doc_542009824771_item	3596989	et	2	main
et	doc_542009824771_item	3596990	et	3	main
vähendada	doc_542009824771_item	3596991	et	3	main
mida	doc_542009824771_item	3596992	et	4	main
teha	doc_542009824771_item	3596993	et	3	main
keha	doc_542009824771_item	3596994	et	4	main
väsimust	doc_542009824771_item	3596995	et	4	main
ning	doc_542009824771_item	3596996	et	3	main
ebamugavustunnet	doc_542009824771_item	3596997	et	3	main
paigutage	doc_542009824771_item	3596998	et	3	main
töövahendid	doc_542009824771_item	3596999	et	3	main
käepäraselt	doc_542009824771_item	3597000	et	4	main
9	doc_542009824771_item	3597001	et	2	main
ostke	doc_542009824771_item	3597002	et	3	main
töötaja	doc_542009824771_item	3597003	et	4	main
jaoks	doc_542009824771_item	3597004	et	4	main
kerge	doc_542009824771_item	3597005	et	4	main
kuidas	doc_542009824771_item	3597006	et	3	main
hiir	doc_542009824771_item	3597008	et	4	main
liigutatav	doc_542009824771_item	3597007	et	4	main
mis	doc_542009824771_item	3597009	et	4	main
töökoht	doc_542009824771_item	3596912	et	3	main
koosneb	doc_542009824771_item	3596913	et	3	main
sobivast	doc_542009824771_item	3596915	et	4	main
saab	doc_542009824771_item	3596925	et	3	main
planeerida	doc_542009824771_item	3596926	et	3	main
mida	doc_542009824771_item	3596927	et	4	main
teha	doc_542009824771_item	3596928	et	3	main
3	doc_542009824771_item	3596929	et	2	main
töötajale	doc_542009824771_item	3596930	et	4	main
peab	doc_542009824771_item	3596931	et	4	main
olema	doc_542009824771_item	3596932	et	4	main
võimaldatud	doc_542009824771_item	3596933	et	4	main
ruumis	doc_542009824771_item	3596934	et	4	main
vabalt	doc_542009824771_item	3596935	et	4	main
liikuda	doc_542009824771_item	3596936	et	3	main
mida	doc_542009824771_item	3596937	et	4	main
teha	doc_542009824771_item	3596938	et	3	main
4	doc_542009824771_item	3596939	et	2	main
töötaja	doc_542009824771_item	3596940	et	4	main
kohustus	doc_542009824771_item	3596941	et	4	main
suur	doc_542009824771_item	3596945	et	3	main
reguleerimine	doc_542009824771_item	3596947	et	4	main
2x	doc_542009824771_item	3596949	et	4	main
töölaud	doc_542009824771_item	3596950	et	4	main
ja	doc_542009824771_item	3596955	et	3	main
mis	doc_542009824771_item	3596957	et	4	main
töötool	doc_542009824771_item	3596963	et	3	main
ja	doc_542009824771_item	3596969	et	3	main
kõrsusega	doc_542009824771_item	3596971	et	4	main
käetoed	doc_542009824771_item	3596980	et	3	main
fikseerida	doc_542009824771_item	3596981	et	3	main
mida	doc_542009824771_item	3596982	et	4	main
teha	doc_542009824771_item	3596983	et	3	main
mille	doc_542009824771_item	3597013	et	3	main
kujuga	doc_542009824771_item	3597014	et	3	main
10	doc_542009824771_item	3597015	et	2	main
ka	doc_542009824771_item	3597016	et	3	main
klaviatuuri	doc_542009824771_item	3597017	et	4	main
kasutamisel	doc_542009824771_item	3597018	et	4	main
peavad	doc_542009824771_item	3597019	et	4	main
käed	doc_542009824771_item	3597020	et	3	main
olema	doc_542009824771_item	3597021	et	4	main
loomulikus	doc_542009824771_item	3597022	et	4	main
asendis	doc_542009824771_item	3597023	et	3	main
milles	doc_542009824771_item	3597024	et	3	main
harjutus	doc_542009824810_item	3597026	et	4	main
ema	doc_542009824810_item	3597030	et	4	main
ma	doc_542009824810_item	3597031	et	3	main
pean	doc_542009824810_item	3597032	et	4	main
õppima	doc_542009824810_item	3597033	et	3	main
lõpetama	doc_542009824810_item	3597041	et	4	main
ma	doc_542009824810_item	3597050	et	3	main
helistan	doc_542009824810_item	3597051	et	3	main
sööklasse	doc_542009824810_item	3597052	et	4	main
ma	doc_542009824810_item	3597053	et	3	main
muudan	doc_542009824810_item	3597054	et	3	main
kodutöö	doc_542009824810_item	3597061	et	4	main
töötama	doc_542009824810_item	3597077	et	3	main
to	doc_542009824810_item	3597090	et	4	main
ma	doc_542009824810_item	3597097	et	3	main
meie	doc_542009824810_item	3597118	et	4	main
heliseb	doc_542009824810_item	3597119	et	3	main
minuma	doc_542009824810_item	3597122	et	4	main
ja	doc_542009824810_item	3597155	et	3	main
juua	doc_542009824810_item	3597156	et	3	main
ma	doc_542009824810_item	3597157	et	3	main
pean	doc_542009824810_item	3597158	et	4	main
vabalt	doc_542009824771_item	3596959	et	4	main
ära	doc_542009824771_item	3596960	et	4	main
6	doc_542009824771_item	3596962	et	2	main
olema	doc_542009824771_item	3596965	et	4	main
reguleeritava	doc_542009824771_item	3596967	et	4	main
töölaud	doc_542009824771_item	3596976	et	4	main
sest	doc_542009824771_item	3596984	et	4	main
lauale	doc_542009824771_item	3596988	et	4	main
sobiks	doc_542009824771_item	3597010	et	4	main
käele	doc_542009824771_item	3597012	et	3	main
eesti	doc_542009824810_item	3597034	et	4	main
töö	doc_542009824810_item	3597042	et	4	main
ma	doc_542009824810_item	3597043	et	3	main
telefoni	doc_542009824810_item	3597055	et	4	main
ma	doc_542009824810_item	3597056	et	3	main
peatun	doc_542009824810_item	3597057	et	3	main
metsas	doc_542009824810_item	3597058	et	3	main
selleparast	doc_542009824810_item	3597066	et	3	main
ma	doc_542009824810_item	3597068	et	3	main
sest	doc_542009824810_item	3597081	et	4	main
kell	doc_542009824810_item	3597099	et	3	main
algab	doc_542009824810_item	3597111	et	3	main
ma	doc_542009824810_item	3597120	et	3	main
kell	doc_542009824810_item	3597123	et	3	main
üheksa	doc_542009824810_item	3597124	et	4	main
sest	doc_542009824810_item	3597125	et	4	main
ma	doc_542009824810_item	3597126	et	3	main
pean	doc_542009824810_item	3597127	et	4	main
ärkama	doc_542009824810_item	3597128	et	3	main
kell	doc_542009824810_item	3597129	et	3	main
kuus	doc_542009824810_item	3597130	et	4	main
ma	doc_542009824810_item	3597131	et	3	main
tahan	doc_542009824810_item	3597132	et	3	main
sinuga	doc_542009824810_item	3597133	et	3	main
tutvuda	doc_542009824810_item	3597134	et	3	main
me	doc_542009824810_item	3597135	et	4	main
peame	doc_542009824810_item	3597136	et	4	main
muutuma	doc_542009824810_item	3597137	et	4	main
sest	doc_542009824810_item	3597138	et	4	main
see	doc_542009824810_item	3597139	et	3	main
on	doc_542009824810_item	3597140	et	4	main
ma	doc_542009824810_item	3597141	et	3	main
idee	doc_542009824810_item	3597142	et	4	main
buss	doc_542009824810_item	3597143	et	3	main
peab	doc_542009824810_item	3597144	et	4	main
siin	doc_542009824810_item	3597145	et	4	main
peatuma	doc_542009824810_item	3597146	et	4	main
ma	doc_542009824810_item	3597147	et	3	main
soovin	doc_542009824810_item	3597148	et	3	main
sulle	doc_542009824810_item	3597149	et	3	main
palju	doc_542009824810_item	3597150	et	4	main
õnne	doc_542009824810_item	3597151	et	4	main
mulle	doc_542009824810_item	3597152	et	4	main
meeldib	doc_542009824810_item	3597153	et	3	main
süüa	doc_542009824810_item	3597154	et	3	main
õpimine	doc_542009824810_item	3597105	et	4	main
on	doc_542009824810_item	3597106	et	4	main
meie	doc_542009824810_item	3597107	et	4	main
tulevik	doc_542009824810_item	3597108	et	3	main
film	doc_542009824810_item	3597109	et	3	main
juba	doc_542009824810_item	3597110	et	3	main
sõnad	doc_542009824810_item	3597035	et	4	main
ma	doc_542009824810_item	3597036	et	3	main
alustan	doc_542009824810_item	3597037	et	3	main
elu	doc_542009824810_item	3597038	et	4	main
ma	doc_542009824810_item	3597039	et	3	main
pean	doc_542009824810_item	3597040	et	4	main
õde	doc_542009824810_item	3597046	et	4	main
koos	doc_542009824810_item	3597047	et	4	main
minu	doc_542009824810_item	3597048	et	3	main
sõpradega	doc_542009824810_item	3597049	et	3	main
koju	doc_542009824810_item	3597062	et	3	main
pean	doc_542009824810_item	3597064	et	4	main
et	doc_542009824810_item	3597067	et	3	main
sportlik	doc_542009824810_item	3597070	et	3	main
inimene	doc_542009824810_item	3597071	et	3	main
joodan	doc_542009824810_item	3597079	et	3	main
hobuse	doc_542009824810_item	3597080	et	4	main
ta	doc_542009824810_item	3597082	et	4	main
tahab	doc_542009824810_item	3597083	et	3	main
juua	doc_542009824810_item	3597084	et	3	main
ma	doc_542009824810_item	3597085	et	3	main
pean	doc_542009824810_item	3597086	et	4	main
söötma	doc_542009824810_item	3597087	et	3	main
on	doc_542009824810_item	3597091	et	4	main
liiga	doc_542009824810_item	3597092	et	4	main
pisike	doc_542009824810_item	3597093	et	3	main
ma	doc_542009824810_item	3597094	et	3	main
ärkan	doc_542009824810_item	3597098	et	3	main
ma	doc_542009824810_item	3597101	et	3	main
pean	doc_542009824810_item	3597102	et	4	main
õppima	doc_542009824810_item	3597103	et	3	main
sest	doc_542009824810_item	3597104	et	4	main
lõpetama	doc_542009824810_item	3597115	et	4	main
sellepärast	doc_542009824810_item	3597116	et	3	main
et	doc_542009824810_item	3597117	et	3	main
saama	doc_542009824810_item	3597159	et	4	main
paremaks	doc_542009824810_item	3597160	et	4	main
pildil	doc_286998102737_item	3597166	et	3	main
ja	doc_286998102737_item	3597171	et	3	main
raamat	doc_286998102737_item	3597172	et	3	main
on	doc_286998102737_item	3597179	et	4	main
ole	doc_286998102737_item	3597207	et	4	main
aga	doc_286998102737_item	3597208	et	3	main
seal	doc_286998102737_item	3597209	et	4	main
pildil	doc_286998102737_item	3597213	et	3	main
kardin	doc_286998102737_item	3597214	et	3	main
teppiline	doc_286998102737_item	3597216	et	4	main
teisel	doc_286998102737_item	3597217	et	4	main
pildil	doc_286998102737_item	3597218	et	3	main
see	doc_286998102737_item	3597219	et	3	main
teppiline	doc_286998102737_item	3597225	et	4	main
ja	doc_286998102737_item	3597226	et	3	main
pildil	doc_286998102737_item	3597232	et	3	main
ees	doc_286998102737_item	3597234	et	4	main
on	doc_286998102737_item	3597235	et	4	main
lill	doc_286998102737_item	3597236	et	3	main
kirjeldus	doc_286998102739_item	3597263	et	4	main
parem	doc_286998102739_item	3597267	et	4	main
esimesel	doc_286998102739_item	3597272	et	3	main
teisel	doc_286998102739_item	3597278	et	4	main
pildil	doc_286998102739_item	3597279	et	3	main
jooksev	doc_286998102739_item	3597280	et	4	main
raamatu	doc_286998102739_item	3597284	et	4	main
peal	doc_286998102739_item	3597286	et	4	main
on	doc_286998102739_item	3597290	et	4	main
on	doc_286998102739_item	3597300	et	4	main
taldrik	doc_286998102739_item	3597301	et	3	main
pole	doc_286998102739_item	3597338	et	3	main
et	doc_286998102739_item	3597343	et	3	main
väike	doc_286998102739_item	3597346	et	4	main
koer	doc_286998102739_item	3597347	et	3	main
alati	doc_286998102739_item	3597348	et	4	main
oli	doc_286998102739_item	3597349	et	3	main
tal	doc_286998102739_item	3597350	et	3	main
kõht	doc_286998102739_item	3597351	et	3	main
täis	doc_286998102739_item	3597352	et	4	main
koer	doc_286998102739_item	3597353	et	3	main
näeb	doc_286998102739_item	3597354	et	3	main
keetab	doc_286998102739_item	3597361	et	4	main
korteris	doc_286998102739_item	3597385	et	3	main
ka	doc_286998102737_item	3597244	et	3	main
kass	doc_286998102737_item	3597245	et	3	main
kass	doc_286998102737_item	3597246	et	3	main
on	doc_286998102737_item	3597247	et	4	main
laua	doc_286998102737_item	3597248	et	3	main
pool	doc_286998102737_item	3597249	et	4	main
ja	doc_286998102737_item	3597250	et	3	main
hiir	doc_286998102737_item	3597251	et	4	main
on	doc_286998102737_item	3597252	et	4	main
teisel	doc_286998102737_item	3597253	et	4	main
pool	doc_286998102737_item	3597254	et	4	main
nii	doc_286998102737_item	3597255	et	3	main
kass	doc_286998102737_item	3597256	et	3	main
ei	doc_286998102737_item	3597257	et	4	main
vaada	doc_286998102737_item	3597258	et	4	main
hiiri	doc_286998102737_item	3597259	et	4	main
pildi	doc_286998102737_item	3597163	et	4	main
ole	doc_286998102737_item	3597176	et	4	main
teisel	doc_286998102737_item	3597184	et	4	main
pildil	doc_286998102737_item	3597185	et	3	main
on	doc_286998102737_item	3597186	et	4	main
kaks	doc_286998102737_item	3597187	et	3	main
tooli	doc_286998102737_item	3597188	et	4	main
esimesel	doc_286998102737_item	3597189	et	3	main
pildil	doc_286998102737_item	3597190	et	3	main
laua	doc_286998102737_item	3597191	et	3	main
kõrval	doc_286998102737_item	3597192	et	4	main
istub	doc_286998102737_item	3597193	et	3	main
koer	doc_286998102737_item	3597194	et	3	main
aga	doc_286998102737_item	3597195	et	3	main
teisel	doc_286998102737_item	3597196	et	4	main
pildil	doc_286998102737_item	3597197	et	3	main
on	doc_286998102737_item	3597198	et	4	main
hiir	doc_286998102737_item	3597199	et	4	main
esimesel	doc_286998102737_item	3597200	et	3	main
pildil	doc_286998102737_item	3597201	et	3	main
sajab	doc_286998102737_item	3597202	et	3	main
vihma	doc_286998102737_item	3597203	et	4	main
teisel	doc_286998102737_item	3597204	et	4	main
pildil	doc_286998102737_item	3597205	et	3	main
laual	doc_286998102737_item	3597167	et	3	main
aga	doc_286998102737_item	3597177	et	3	main
siin	doc_286998102737_item	3597178	et	4	main
ei	doc_286998102737_item	3597206	et	4	main
on	doc_286998102737_item	3597220	et	4	main
esimesel	doc_286998102737_item	3597227	et	3	main
see	doc_286998102737_item	3597228	et	3	main
on	doc_286998102737_item	3597239	et	4	main
lamp	doc_286998102737_item	3597240	et	3	main
ja	doc_286998102737_item	3597241	et	3	main
seal	doc_286998102737_item	3597242	et	4	main
on	doc_286998102737_item	3597243	et	4	main
pildil	doc_286998102739_item	3597265	et	3	main
teisel	doc_286998102739_item	3597270	et	4	main
pildil	doc_286998102739_item	3597273	et	3	main
on	doc_286998102739_item	3597283	et	4	main
kõrval	doc_286998102739_item	3597289	et	4	main
vasakul	doc_286998102739_item	3597293	et	4	main
pool	doc_286998102739_item	3597294	et	4	main
laual	doc_286998102739_item	3597299	et	3	main
on	doc_286998102739_item	3597335	et	4	main
kõht	doc_286998102739_item	3597336	et	3	main
tühi	doc_286998102739_item	3597337	et	3	main
ja	doc_286998102739_item	3597340	et	3	main
mäletan	doc_286998102739_item	3597342	et	3	main
oli	doc_286998102739_item	3597345	et	3	main
teises	doc_286998102739_item	3597392	et	4	main
korteris	doc_286998102739_item	3597393	et	3	main
maailma	doc_286998102739_item	3597398	et	4	main
pool	doc_286998102739_item	3597400	et	4	main
valgus	doc_286998102739_item	3597404	et	4	main
päev	doc_286998102739_item	3597405	et	3	main
seal	doc_286998102739_item	3597407	et	4	main
see	doc_286998102743_item	3597414	et	3	main
istuvad	doc_286998102743_item	3597418	et	4	main
maja	doc_286998102743_item	3597420	et	4	main
esimesel	doc_286998102737_item	3597212	et	3	main
on	doc_286998102737_item	3597215	et	4	main
seal	doc_286998102737_item	3597222	et	4	main
telisel	doc_286998102737_item	3597237	et	4	main
pildil	doc_286998102737_item	3597238	et	3	main
on	doc_286998102739_item	3597266	et	4	main
nagu	doc_286998102739_item	3597269	et	3	main
pildil	doc_286998102739_item	3597271	et	3	main
istuv	doc_286998102739_item	3597274	et	4	main
koera	doc_286998102739_item	3597275	et	4	main
hiir	doc_286998102739_item	3597281	et	4	main
raamatu	doc_286998102739_item	3597288	et	4	main
pliiats	doc_286998102739_item	3597291	et	4	main
ja	doc_286998102739_item	3597292	et	3	main
seal	doc_286998102739_item	3597298	et	4	main
kass	doc_286998102739_item	3597326	et	3	main
on	doc_286998102739_item	3597327	et	4	main
naljane	doc_286998102739_item	3597329	et	4	main
on	doc_286998102739_item	3597331	et	4	main
ema	doc_286998102739_item	3597355	et	4	main
sööki	doc_286998102739_item	3597362	et	4	main
esimeses	doc_286998102739_item	3597363	et	3	main
korteris	doc_286998102739_item	3597364	et	3	main
kus	doc_286998102739_item	3597365	et	3	main
istub	doc_286998102739_item	3597366	et	3	main
koer	doc_286998102739_item	3597367	et	3	main
on	doc_286998102739_item	3597368	et	4	main
taldrik	doc_286998102739_item	3597369	et	3	main
akna	doc_286998102739_item	3597370	et	3	main
all	doc_286998102739_item	3597371	et	3	main
see	doc_286998102739_item	3597372	et	3	main
on	doc_286998102739_item	3597373	et	4	main
lae	doc_286998102739_item	3597389	et	4	main
teises	doc_286998102739_item	3597395	et	4	main
perekond	doc_286998102743_item	3597416	et	3	main
ka	doc_286998102743_item	3597423	et	3	main
pere	doc_286998102743_item	3597427	et	4	main
üks	doc_286998102743_item	3597430	et	3	main
poisid	doc_286998102743_item	3597442	et	4	main
nemad	doc_286998102743_item	3597448	et	3	main
on	doc_286998102743_item	3597464	et	4	main
nemad	doc_286998102743_item	3597470	et	3	main
olevad	doc_286998102743_item	3597474	et	4	main
tallinnissa	doc_286998102743_item	3597475	et	4	main
pildil	doc_286998102745_item	3597481	et	3	main
mehed	doc_286998102745_item	3597485	et	3	main
kirjutab	doc_286998102745_item	3597496	et	3	main
ja	doc_286998102745_item	3597497	et	3	main
kõneleb	doc_286998102745_item	3597498	et	3	main
kaks	doc_286998102745_item	3597499	et	3	main
meest	doc_286998102745_item	3597500	et	4	main
vaatab	doc_286998102745_item	3597501	et	3	main
meest	doc_286998102745_item	3597502	et	4	main
vana	doc_286998102746_item	3597541	et	4	main
õnne	doc_286998102746_item	3597543	et	4	main
hea	doc_286998102746_item	3597555	et	4	main
ema	doc_286998102746_item	3597558	et	4	main
kampsu	doc_286998102746_item	3597564	et	4	main
on	doc_286998102746_item	3597565	et	4	main
kollane	doc_286998102746_item	3597570	et	4	main
päike	doc_286998102746_item	3597571	et	3	main
praegu	doc_286998102746_item	3597572	et	3	main
madis	doc_286998102746_item	3597573	et	3	main
on	doc_286998102746_item	3597574	et	4	main
sest	doc_286998102746_item	3597585	et	4	main
tal	doc_286998102746_item	3597586	et	3	main
on	doc_286998102746_item	3597587	et	4	main
ilus	doc_286998102746_item	3597588	et	4	main
sõbratar	doc_286998102746_item	3597589	et	3	main
ema	doc_286998102746_item	3597596	et	4	main
pildil	doc_286998102746_item	3597601	et	3	main
pottilille	doc_286998102739_item	3597374	et	4	main
koht	doc_286998102739_item	3597375	et	3	main
praegu	doc_286998102739_item	3597376	et	3	main
on	doc_286998102739_item	3597377	et	4	main
lill	doc_286998102739_item	3597378	et	3	main
valamus	doc_286998102739_item	3597379	et	3	main
sest	doc_286998102739_item	3597380	et	4	main
ema	doc_286998102739_item	3597381	et	4	main
pesen	doc_286998102739_item	3597382	et	3	main
teda	doc_286998102739_item	3597383	et	4	main
esimeses	doc_286998102739_item	3597384	et	3	main
esimesel	doc_286998102739_item	3597264	et	3	main
ilm	doc_286998102739_item	3597268	et	3	main
on	doc_286998102739_item	3597277	et	4	main
laua	doc_286998102739_item	3597285	et	3	main
kell	doc_286998102739_item	3597296	et	3	main
esimesel	doc_286998102739_item	3597305	et	3	main
korteris	doc_286998102739_item	3597306	et	3	main
pole	doc_286998102739_item	3597307	et	3	main
lõunasöök	doc_286998102739_item	3597308	et	3	main
sest	doc_286998102739_item	3597310	et	4	main
ema	doc_286998102739_item	3597311	et	4	main
valmis	doc_286998102739_item	3597309	et	4	main
kirjutab	doc_286998102739_item	3597312	et	3	main
päevikku	doc_286998102739_item	3597313	et	4	main
teises	doc_286998102739_item	3597314	et	4	main
korteris	doc_286998102739_item	3597315	et	3	main
elab	doc_286998102739_item	3597316	et	3	main
üksi	doc_286998102739_item	3597317	et	4	main
ema	doc_286998102739_item	3597318	et	4	main
sõbranna	doc_286998102739_item	3597319	et	4	main
kes	doc_286998102739_item	3597320	et	4	main
keetas	doc_286998102739_item	3597321	et	4	main
juba	doc_286998102739_item	3597322	et	3	main
sööki	doc_286998102739_item	3597323	et	4	main
sest	doc_286998102739_item	3597324	et	4	main
teda	doc_286998102739_item	3597325	et	4	main
söök	doc_286998102739_item	3597339	et	3	main
ta	doc_286998102739_item	3597341	et	4	main
millal	doc_286998102739_item	3597344	et	3	main
kes	doc_286998102739_item	3597356	et	4	main
tuleb	doc_286998102739_item	3597357	et	3	main
juba	doc_286998102739_item	3597358	et	3	main
kööki	doc_286998102739_item	3597359	et	4	main
ole	doc_286998102739_item	3597387	et	4	main
lamp	doc_286998102739_item	3597388	et	3	main
on	doc_286998102739_item	3597397	et	4	main
teisel	doc_286998102739_item	3597399	et	4	main
sest	doc_286998102739_item	3597401	et	4	main
siin	doc_286998102739_item	3597402	et	4	main
on	doc_286998102743_item	3597415	et	4	main
nende	doc_286998102743_item	3597419	et	4	main
ema	doc_286998102743_item	3597429	et	4	main
ja	doc_286998102743_item	3597432	et	3	main
on	doc_286998102743_item	3597444	et	4	main
madis	doc_286998102743_item	3597445	et	3	main
on	doc_286998102743_item	3597458	et	4	main
on	doc_286998102743_item	3597468	et	4	main
on	doc_286998102743_item	3597471	et	4	main
ja	doc_286998102743_item	3597473	et	3	main
kirjeldus	doc_286998102745_item	3597479	et	4	main
kolm	doc_286998102745_item	3597483	et	3	main
istuvad	doc_286998102745_item	3597486	et	4	main
juures	doc_286998102745_item	3597488	et	4	main
need	doc_286998102745_item	3597489	et	3	main
mehed	doc_286998102745_item	3597490	et	3	main
ole	doc_286998102745_item	3597492	et	4	main
vanad	doc_286998102745_item	3597493	et	3	main
üks	doc_286998102745_item	3597494	et	3	main
pildi	doc_286998102746_item	3597535	et	4	main
on	doc_286998102746_item	3597538	et	4	main
palju	doc_286998102746_item	3597542	et	4	main
on	doc_286998102746_item	3597546	et	4	main
madise	doc_286998102746_item	3597547	et	3	main
pilt	doc_286998102746_item	3597548	et	3	main
kui	doc_286998102746_item	3597549	et	3	main
ta	doc_286998102746_item	3597550	et	4	main
oli	doc_286998102746_item	3597551	et	3	main
ja	doc_286998102746_item	3597556	et	3	main
isa	doc_286998102746_item	3597560	et	4	main
armastasivad	doc_286998102746_item	3597561	et	4	main
lasta	doc_286998102746_item	3597562	et	4	main
madise	doc_286998102746_item	3597563	et	3	main
ta	doc_286998102746_item	3597578	et	4	main
on	doc_286998102748_item	3597634	et	4	main
nende	doc_286998102748_item	3597635	et	4	main
vana	doc_286998102748_item	3597639	et	4	main
noorid	doc_286998102748_item	3597643	et	4	main
perekond	doc_286998102748_item	3597649	et	3	main
tütar	doc_286998102748_item	3597653	et	3	main
on	doc_286998102748_item	3597658	et	4	main
ja	doc_286998102748_item	3597664	et	3	main
tütar	doc_286998102748_item	3597666	et	3	main
on	doc_286998102748_item	3597672	et	4	main
kadri	doc_286998102748_item	3597685	et	4	main
ei	doc_286998102739_item	3597386	et	4	main
on	doc_286998102739_item	3597394	et	4	main
on	doc_286998102739_item	3597403	et	4	main
kirjeldus	doc_286998102743_item	3597413	et	4	main
on	doc_286998102743_item	3597424	et	4	main
maja	doc_286998102743_item	3597425	et	4	main
ema	doc_286998102743_item	3597435	et	4	main
arst	doc_286998102743_item	3597437	et	3	main
ja	doc_286998102743_item	3597438	et	3	main
tüdruk	doc_286998102743_item	3597439	et	3	main
ja	doc_286998102743_item	3597446	et	3	main
on	doc_286998102743_item	3597449	et	4	main
aiasse	doc_286998102743_item	3597455	et	4	main
pildi	doc_286998102745_item	3597478	et	4	main
mees	doc_286998102745_item	3597495	et	4	main
kirjeldus	doc_286998102746_item	3597536	et	4	main
madis	doc_286998102746_item	3597537	et	3	main
oli	doc_286998102746_item	3597554	et	3	main
iso	doc_286998102746_item	3597575	et	4	main
palju	doc_286998102746_item	3597584	et	4	main
kadrile	doc_286998102746_item	3597591	et	3	main
meeldib	doc_286998102746_item	3597592	et	3	main
ka	doc_286998102746_item	3597593	et	3	main
on	doc_286998102746_item	3597597	et	4	main
vanem	doc_286998102746_item	3597599	et	4	main
tal	doc_286998102746_item	3597603	et	3	main
juba	doc_286998102746_item	3597605	et	3	main
ema	doc_286998102748_item	3597637	et	4	main
on	doc_286998102748_item	3597638	et	4	main
poissed	doc_286998102748_item	3597656	et	3	main
poissed	doc_286998102748_item	3597657	et	3	main
pojad	doc_286998102748_item	3597660	et	4	main
maja	doc_286998102748_item	3597661	et	4	main
ja	doc_286998102748_item	3597669	et	3	main
ta	doc_286998102748_item	3597670	et	4	main
kadri	doc_286998102748_item	3597673	et	4	main
on	doc_286998102748_item	3597675	et	4	main
madis	doc_286998102748_item	3597676	et	3	main
ja	doc_286998102748_item	3597677	et	3	main
jaan	doc_286998102748_item	3597678	et	3	main
madis	doc_286998102748_item	3597679	et	3	main
on	doc_286998102748_item	3597680	et	4	main
üliõpilane	doc_286998102748_item	3597681	et	3	main
ole	doc_286998102748_item	3597687	et	4	main
ajakirjanik	doc_286998102748_item	3597688	et	3	main
tartus	doc_286998102748_item	3597692	et	3	main
neli	doc_286998102749_item	3597890	et	3	main
janos	doc_286998102749_item	3597901	et	4	main
ees	doc_286998102743_item	3597421	et	4	main
ees	doc_286998102743_item	3597426	et	4	main
tüdruk	doc_286998102743_item	3597431	et	3	main
kaks	doc_286998102743_item	3597433	et	3	main
nimed	doc_286998102743_item	3597443	et	3	main
nende	doc_286998102743_item	3597456	et	4	main
maja	doc_286998102743_item	3597457	et	4	main
pikk	doc_286998102743_item	3597465	et	4	main
ja	doc_286998102743_item	3597466	et	3	main
jaan	doc_286998102743_item	3597467	et	3	main
sellel	doc_286998102745_item	3597480	et	4	main
ei	doc_286998102745_item	3597491	et	4	main
lühike	doc_286998102743_item	3597469	et	4	main
eestlased	doc_286998102743_item	3597472	et	3	main
on	doc_286998102745_item	3597482	et	4	main
inimest	doc_286998102745_item	3597484	et	3	main
laua	doc_286998102745_item	3597487	et	3	main
kes	doc_286998102745_item	3597503	et	4	main
kõneleb	doc_286998102745_item	3597504	et	3	main
need	doc_286998102745_item	3597505	et	3	main
mehed	doc_286998102745_item	3597506	et	3	main
on	doc_286998102745_item	3597507	et	4	main
ajakirjanikud	doc_286998102745_item	3597508	et	3	main
mehed	doc_286998102745_item	3597509	et	3	main
tahavad	doc_286998102745_item	3597510	et	3	main
süüa	doc_286998102745_item	3597511	et	3	main
need	doc_286998102745_item	3597512	et	3	main
mehed	doc_286998102745_item	3597513	et	3	main
on	doc_286998102745_item	3597514	et	4	main
sööklas	doc_286998102745_item	3597515	et	3	main
sest	doc_286998102745_item	3597516	et	4	main
see	doc_286998102745_item	3597517	et	3	main
on	doc_286998102745_item	3597518	et	4	main
lõunaaeg	doc_286998102745_item	3597519	et	3	main
palju	doc_286998102745_item	3597520	et	4	main
rahvast	doc_286998102745_item	3597521	et	4	main
on	doc_286998102745_item	3597522	et	4	main
sööklas	doc_286998102745_item	3597523	et	3	main
sest	doc_286998102745_item	3597524	et	4	main
inimesel	doc_286998102745_item	3597525	et	3	main
on	doc_286998102745_item	3597526	et	4	main
kõht	doc_286998102745_item	3597527	et	3	main
tühi	doc_286998102745_item	3597528	et	3	main
need	doc_286998102745_item	3597529	et	3	main
mehed	doc_286998102745_item	3597530	et	3	main
on	doc_286998102745_item	3597531	et	4	main
eleganned	doc_286998102745_item	3597532	et	4	main
üks	doc_286998102746_item	3597539	et	3	main
laps	doc_286998102746_item	3597552	et	4	main
ilus	doc_286998102746_item	3597557	et	4	main
ja	doc_286998102746_item	3597559	et	3	main
valge	doc_286998102746_item	3597566	et	4	main
ilusam	doc_286998102746_item	3597581	et	4	main
madis	doc_286998102746_item	3597582	et	3	main
naerab	doc_286998102746_item	3597583	et	3	main
kadri	doc_286998102746_item	3597590	et	4	main
madise	doc_286998102746_item	3597594	et	3	main
praegu	doc_286998102746_item	3597598	et	3	main
kui	doc_286998102746_item	3597600	et	3	main
ja	doc_286998102746_item	3597602	et	3	main
taga	doc_286998102748_item	3597636	et	4	main
ja	doc_286998102748_item	3597640	et	3	main
ema	doc_286998102748_item	3597644	et	4	main
kampus	doc_286998102748_item	3597645	et	4	main
suur	doc_286998102746_item	3597616	et	3	main
ja	doc_286998102746_item	3597617	et	3	main
ilus	doc_286998102746_item	3597618	et	4	main
aasta	doc_286998102746_item	3597540	et	4	main
madisele	doc_286998102746_item	3597544	et	3	main
see	doc_286998102746_item	3597545	et	3	main
ta	doc_286998102746_item	3597553	et	4	main
ja	doc_286998102746_item	3597567	et	3	main
siin	doc_286998102746_item	3597568	et	4	main
on	doc_286998102746_item	3597569	et	4	main
poiss	doc_286998102746_item	3597576	et	3	main
ja	doc_286998102746_item	3597577	et	3	main
on	doc_286998102746_item	3597579	et	4	main
veel	doc_286998102746_item	3597580	et	4	main
pilt	doc_286998102746_item	3597595	et	3	main
kaks	doc_286998102746_item	3597606	et	3	main
poisid	doc_286998102746_item	3597607	et	4	main
aga	doc_286998102746_item	3597608	et	3	main
madis	doc_286998102746_item	3597609	et	3	main
on	doc_286998102746_item	3597610	et	4	main
kõike	doc_286998102746_item	3597611	et	4	main
vanem	doc_286998102746_item	3597612	et	4	main
madise	doc_286998102746_item	3597613	et	3	main
pere	doc_286998102746_item	3597614	et	4	main
on	doc_286998102746_item	3597615	et	4	main
nemad	doc_286998102748_item	3597631	et	3	main
räägivad	doc_286998102748_item	3597632	et	3	main
puud	doc_286998102748_item	3597633	et	4	main
lapsed	doc_286998102748_item	3597641	et	3	main
valge	doc_286998102748_item	3597647	et	4	main
see	doc_286998102748_item	3597648	et	3	main
on	doc_286998102748_item	3597650	et	4	main
üks	doc_286998102748_item	3597652	et	3	main
ema	doc_286998102748_item	3597659	et	4	main
kollane	doc_286998102748_item	3597665	et	4	main
on	doc_286998102748_item	3597667	et	4	main
ilus	doc_286998102748_item	3597668	et	4	main
on	doc_286998102748_item	3597683	et	4	main
arst	doc_286998102748_item	3597684	et	3	main
ta	doc_286998102748_item	3597690	et	4	main
on	doc_286998102746_item	3597604	et	4	main
pildi	doc_286998102748_item	3597621	et	4	main
kirjeldus	doc_286998102748_item	3597622	et	4	main
see	doc_286998102748_item	3597623	et	3	main
on	doc_286998102748_item	3597624	et	4	main
üks	doc_286998102748_item	3597625	et	3	main
perekond	doc_286998102748_item	3597626	et	3	main
nemad	doc_286998102748_item	3597627	et	3	main
istuvad	doc_286998102748_item	3597628	et	4	main
maja	doc_286998102748_item	3597629	et	4	main
ees	doc_286998102748_item	3597630	et	4	main
ülikoolis	doc_286998102748_item	3597693	et	4	main
on	doc_286998102748_item	3597642	et	4	main
kaks	doc_286998102748_item	3597655	et	3	main
suur	doc_286998102748_item	3597663	et	3	main
nimi	doc_286998102748_item	3597671	et	3	main
poissed	doc_286998102748_item	3597674	et	3	main
ei	doc_286998102748_item	3597686	et	4	main
lühen	doc_286998102748_item	3597691	et	4	main
on	doc_286998102749_item	3597889	et	4	main
kaks	doc_286998102749_item	3597892	et	3	main
ja	doc_286998102749_item	3597894	et	3	main
ja	doc_286998102749_item	3597900	et	3	main
on	doc_286998102749_item	3597906	et	4	main
tartu	doc_286998102749_item	3597922	et	4	main
ülikoolis	doc_286998102749_item	3597923	et	4	main
madis	doc_286998102749_item	3597924	et	3	main
tüdruk	doc_286998102749_item	3597937	et	3	main
talinnas	doc_286998102749_item	3597950	et	4	main
ei	doc_286998102749_item	3597957	et	4	main
armasta	doc_286998102749_item	3597958	et	4	main
temad	doc_286998102749_item	3597959	et	4	main
ülikoolisse	doc_286998102749_item	3598001	et	4	main
istuvad	doc_286998102749_item	3598008	et	4	main
nad	doc_286998102749_item	3598010	et	3	main
võileiba	doc_286998102749_item	3598012	et	4	main
ajas	doc_286998102749_item	3598013	et	4	main
kalad	doc_286998102749_item	3598024	et	3	main
musträstas	doc_286998102749_item	3598031	et	4	main
jõe	doc_286998102749_item	3598032	et	3	main
kass	doc_286998102749_item	3598041	et	3	main
magab	doc_286998102749_item	3598042	et	3	main
nad	doc_286998102749_item	3598043	et	3	main
ilus	doc_286998102750_item	3598081	et	4	main
puumaja	doc_286998102750_item	3598082	et	4	main
ees	doc_286998102750_item	3598084	et	4	main
on	doc_286998102750_item	3598085	et	4	main
istuvad	doc_286998102750_item	3598102	et	4	main
on	doc_286998102750_item	3598111	et	4	main
majas	doc_286998102750_item	3598113	et	3	main
ei	doc_286998102750_item	3598124	et	4	main
kõrval	doc_286998102750_item	3598141	et	4	main
pildi	doc_286998102751_item	3598170	et	4	main
see	doc_286998102751_item	3598172	et	3	main
viinamarja	doc_286998102751_item	3598188	et	4	main
nad	doc_286998102751_item	3598190	et	3	main
joovad	doc_286998102751_item	3598191	et	4	main
veini	doc_286998102751_item	3598192	et	4	main
nende	doc_286998102751_item	3598193	et	4	main
ilus	doc_286998102751_item	3598197	et	4	main
aknad	doc_286998102751_item	3598205	et	3	main
on	doc_286998102751_item	3598206	et	4	main
aknet	doc_286998102751_item	3598212	et	3	main
puu	doc_286998102751_item	3598218	et	4	main
on	doc_286998102751_item	3598219	et	4	main
on	doc_286998102748_item	3597646	et	4	main
ema	doc_286998102748_item	3597651	et	4	main
ja	doc_286998102748_item	3597654	et	3	main
on	doc_286998102748_item	3597662	et	4	main
ema	doc_286998102748_item	3597682	et	4	main
aga	doc_286998102748_item	3597689	et	3	main
pildi	doc_286998102749_item	3597886	et	4	main
madis	doc_286998102749_item	3597899	et	3	main
janos	doc_286998102749_item	3597909	et	4	main
on	doc_286998102749_item	3597910	et	4	main
ungarlane	doc_286998102749_item	3597911	et	3	main
janos	doc_286998102749_item	3597912	et	4	main
elab	doc_286998102749_item	3597913	et	3	main
ta	doc_286998102749_item	3597918	et	4	main
janosi	doc_286998102749_item	3597926	et	4	main
kakskümmend	doc_286998102749_item	3597940	et	4	main
ja	doc_286998102749_item	3597943	et	3	main
õpib	doc_286998102749_item	3597945	et	3	main
madist	doc_286998102749_item	3597953	et	3	main
ta	doc_286998102749_item	3597960	et	4	main
armastab	doc_286998102749_item	3597961	et	3	main
reede	doc_286998102749_item	3597994	et	4	main
pea	doc_286998102749_item	3597999	et	4	main
minna	doc_286998102749_item	3598000	et	3	main
pea	doc_286998102749_item	3598005	et	4	main
vana	doc_286998102749_item	3598016	et	4	main
kivimaja	doc_286998102749_item	3598017	et	4	main
kivimaja	doc_286998102749_item	3598018	et	4	main
jões	doc_286998102749_item	3598023	et	3	main
kivimaja	doc_286998102749_item	3598027	et	4	main
väike	doc_286998102749_item	3598030	et	4	main
nad	doc_286998102749_item	3598047	et	3	main
kinosse	doc_286998102749_item	3598050	et	3	main
kirjeldus	doc_286998102750_item	3598078	et	4	main
on	doc_286998102750_item	3598093	et	4	main
neli	doc_286998102750_item	3598094	et	3	main
inimesed	doc_286998102750_item	3598095	et	3	main
kaks	doc_286998102750_item	3598096	et	3	main
tüdrukut	doc_286998102750_item	3598097	et	3	main
ja	doc_286998102750_item	3598098	et	3	main
kaks	doc_286998102750_item	3598099	et	3	main
meest	doc_286998102750_item	3598100	et	4	main
nad	doc_286998102750_item	3598101	et	3	main
inimesed	doc_286998102750_item	3598105	et	3	main
on	doc_286998102750_item	3598107	et	4	main
lastetuba	doc_286998102750_item	3598118	et	4	main
homme	doc_286998102749_item	3598051	et	3	main
aga	doc_286998102749_item	3598052	et	3	main
homme	doc_286998102749_item	3598053	et	3	main
on	doc_286998102749_item	3598054	et	4	main
laupäev	doc_286998102749_item	3598055	et	3	main
ja	doc_286998102749_item	3598056	et	3	main
laupäeval	doc_286998102749_item	3598057	et	3	main
tüdrukud	doc_286998102749_item	3598058	et	3	main
lähevad	doc_286998102749_item	3598059	et	3	main
turule	doc_286998102749_item	3598060	et	3	main
nad	doc_286998102749_item	3598061	et	3	main
ostavad	doc_286998102749_item	3598062	et	3	main
muna	doc_286998102749_item	3598063	et	4	main
ja	doc_286998102749_item	3598064	et	3	main
kapsasta	doc_286998102749_item	3598065	et	4	main
turult	doc_286998102749_item	3598066	et	3	main
ja	doc_286998102749_item	3598067	et	3	main
nad	doc_286998102749_item	3598068	et	3	main
ostavad	doc_286998102749_item	3598069	et	3	main
piima	doc_286998102749_item	3598070	et	4	main
poest	doc_286998102749_item	3598071	et	4	main
õhtul	doc_286998102749_item	3598072	et	3	main
nad	doc_286998102749_item	3598073	et	3	main
keelavad	doc_286998102749_item	3598074	et	4	main
pildis	doc_286998102749_item	3597888	et	3	main
inimest	doc_286998102749_item	3597891	et	3	main
kaks	doc_286998102749_item	3597895	et	3	main
kadri	doc_286998102749_item	3597897	et	4	main
kaks	doc_286998102749_item	3597902	et	3	main
madis	doc_286998102749_item	3597905	et	3	main
eestlased	doc_286998102749_item	3597907	et	3	main
õpib	doc_286998102749_item	3597919	et	3	main
keelt	doc_286998102749_item	3597921	et	4	main
ilus	doc_286998102749_item	3597936	et	4	main
on	doc_286998102749_item	3597939	et	4	main
praantsuse	doc_286998102749_item	3597946	et	4	main
keelt	doc_286998102749_item	3597947	et	4	main
ja	doc_286998102749_item	3597948	et	3	main
kirjandust	doc_286998102749_item	3597949	et	3	main
eevi	doc_286998102749_item	3597962	et	4	main
eevi	doc_286998102749_item	3597963	et	4	main
on	doc_286998102749_item	3597964	et	4	main
kadri	doc_286998102749_item	3597965	et	4	main
sõbrana	doc_286998102749_item	3597966	et	3	main
ja	doc_286998102749_item	3597967	et	3	main
ta	doc_286998102749_item	3597968	et	4	main
on	doc_286998102749_item	3597969	et	4	main
ajakirjanik	doc_286998102749_item	3597970	et	3	main
ta	doc_286998102749_item	3597971	et	4	main
kirjutab	doc_286998102749_item	3597972	et	3	main
teatrist	doc_286998102749_item	3597973	et	3	main
ja	doc_286998102749_item	3597974	et	3	main
kunstist	doc_286998102749_item	3597975	et	4	main
tal	doc_286998102749_item	3597976	et	3	main
on	doc_286998102749_item	3597977	et	4	main
sõber	doc_286998102749_item	3597978	et	3	main
jaan	doc_286998102749_item	3597979	et	3	main
nüüd	doc_286998102749_item	3597980	et	4	main
jaan	doc_286998102749_item	3597981	et	3	main
on	doc_286998102749_item	3597982	et	4	main
kodus	doc_286998102749_item	3597983	et	4	main
noorid	doc_286998102749_item	3597984	et	4	main
on	doc_286998102749_item	3597985	et	4	main
ja	doc_286998102749_item	3597996	et	3	main
kadri	doc_286998102749_item	3597997	et	4	main
ei	doc_286998102749_item	3598004	et	4	main
on	doc_286998102749_item	3598020	et	4	main
elavad	doc_286998102749_item	3598025	et	4	main
ja	doc_286998102749_item	3598026	et	3	main
on	doc_286998102749_item	3598029	et	4	main
taga	doc_286998102749_item	3598033	et	4	main
räägivad	doc_286998102749_item	3598044	et	3	main
on	doc_286998102750_item	3598080	et	4	main
maja	doc_286998102750_item	3598083	et	4	main
ja	doc_286998102750_item	3598087	et	3	main
ja	doc_286998102750_item	3598103	et	3	main
magamistuba	doc_286998102750_item	3598117	et	4	main
ees	doc_286998102750_item	3598123	et	4	main
ja	doc_286998102750_item	3598130	et	3	main
on	doc_286998102750_item	3598142	et	4	main
toolid	doc_286998102750_item	3598145	et	3	main
ilus	doc_286998102751_item	3598175	et	4	main
tüdrukut	doc_286998102751_item	3598182	et	3	main
kirjeldus	doc_286998102749_item	3597887	et	4	main
poissit	doc_286998102749_item	3597893	et	4	main
tüdrukut	doc_286998102749_item	3597896	et	3	main
eevi	doc_286998102749_item	3597898	et	4	main
ja	doc_286998102749_item	3597904	et	3	main
aga	doc_286998102749_item	3597908	et	3	main
budapestis	doc_286998102749_item	3597915	et	4	main
aga	doc_286998102749_item	3597916	et	3	main
praegu	doc_286998102749_item	3597917	et	3	main
eesti	doc_286998102749_item	3597920	et	4	main
sõber	doc_286998102749_item	3597927	et	3	main
ta	doc_286998102749_item	3597928	et	4	main
õpib	doc_286998102749_item	3597929	et	3	main
ajalugu	doc_286998102749_item	3597930	et	4	main
ka	doc_286998102749_item	3597931	et	3	main
tartus	doc_286998102749_item	3597932	et	3	main
kadri	doc_286998102749_item	3597933	et	4	main
kolm	doc_286998102749_item	3597941	et	3	main
ta	doc_286998102749_item	3597951	et	4	main
aga	doc_286998102749_item	3597954	et	3	main
madis	doc_286998102749_item	3597956	et	3	main
poisid	doc_286998102749_item	3597995	et	4	main
ja	doc_286998102749_item	3598002	et	3	main
eevi	doc_286998102749_item	3598003	et	4	main
tööta	doc_286998102749_item	3598006	et	4	main
ilus	doc_286998102749_item	3598015	et	4	main
väike	doc_286998102749_item	3598021	et	4	main
jõgi	doc_286998102749_item	3598022	et	3	main
katusel	doc_286998102749_item	3598028	et	3	main
puu	doc_286998102749_item	3598037	et	4	main
all	doc_286998102749_item	3598038	et	3	main
suur	doc_286998102749_item	3598039	et	3	main
valge	doc_286998102749_item	3598040	et	4	main
uuest	doc_286998102749_item	3598045	et	3	main
tahavad	doc_286998102749_item	3598048	et	3	main
pildi	doc_286998102750_item	3598077	et	4	main
rõhi	doc_286998102750_item	3598086	et	4	main
puud	doc_286998102750_item	3598088	et	4	main
majal	doc_286998102750_item	3598089	et	3	main
on	doc_286998102750_item	3598090	et	4	main
pildil	doc_286998102750_item	3598092	et	3	main
söövad	doc_286998102750_item	3598104	et	4	main
valged	doc_286998102750_item	3598112	et	3	main
on	doc_286998102750_item	3598114	et	4	main
mitu	doc_286998102750_item	3598115	et	4	main
tuba	doc_286998102750_item	3598116	et	4	main
ole	doc_286998102750_item	3598125	et	4	main
magavad	doc_286998102750_item	3598131	et	4	main
tüdrukud	doc_286998102750_item	3598132	et	3	main
nende	doc_286998102750_item	3598135	et	4	main
inimesed	doc_286998102750_item	3598146	et	3	main
kirjeldus	doc_286998102751_item	3598171	et	4	main
pilt	doc_286998102751_item	3598176	et	3	main
on	doc_286998102751_item	3598178	et	4	main
sõbra	doc_286998102751_item	3598180	et	3	main
kaks	doc_286998102751_item	3598181	et	3	main
kaks	doc_286998102751_item	3598184	et	3	main
vana	doc_286998102751_item	3598196	et	4	main
nelle	doc_286998102751_item	3598208	et	4	main
mitu	doc_286998102751_item	3598217	et	4	main
on	doc_286998102751_item	3598224	et	4	main
suomi	doc_286998102751_item	3598231	et	4	main
saksa	doc_286998102751_item	3598232	et	4	main
eesti	doc_286998102751_item	3598233	et	4	main
ja	doc_286998102751_item	3598234	et	3	main
inglise	doc_286998102751_item	3598235	et	4	main
keelt	doc_286998102751_item	3598236	et	4	main
nad	doc_286998102751_item	3598237	et	3	main
on	doc_286998102751_item	3598238	et	4	main
pildil	doc_286998102751_item	3598249	et	3	main
veel	doc_286998102751_item	3598251	et	4	main
järvel	doc_286998102751_item	3598260	et	4	main
tüdrukut	doc_286998102749_item	3597903	et	3	main
ungaris	doc_286998102749_item	3597914	et	4	main
on	doc_286998102749_item	3597925	et	4	main
on	doc_286998102749_item	3597934	et	4	main
väga	doc_286998102749_item	3597935	et	3	main
ta	doc_286998102749_item	3597938	et	4	main
aastlane	doc_286998102749_item	3597942	et	4	main
ta	doc_286998102749_item	3597944	et	4	main
armastab	doc_286998102749_item	3597952	et	3	main
kahjuks	doc_286998102749_item	3597955	et	4	main
ilusas	doc_286998102749_item	3597986	et	3	main
ajas	doc_286998102749_item	3597987	et	4	main
sest	doc_286998102749_item	3597988	et	4	main
täna	doc_286998102749_item	3597989	et	4	main
on	doc_286998102749_item	3597990	et	4	main
madise	doc_286998102749_item	3597991	et	3	main
sünnipäev	doc_286998102749_item	3597992	et	3	main
on	doc_286998102749_item	3597993	et	4	main
ei	doc_286998102749_item	3597998	et	4	main
nad	doc_286998102749_item	3598007	et	3	main
maal	doc_286998102749_item	3598009	et	4	main
söövad	doc_286998102749_item	3598011	et	4	main
on	doc_286998102749_item	3598014	et	4	main
ees	doc_286998102749_item	3598019	et	4	main
puud	doc_286998102749_item	3598034	et	4	main
seisavad	doc_286998102749_item	3598035	et	3	main
ja	doc_286998102749_item	3598036	et	3	main
filmist	doc_286998102749_item	3598046	et	4	main
minna	doc_286998102749_item	3598049	et	3	main
madalad	doc_286998102750_item	3598164	et	3	main
vees	doc_286998102750_item	3598165	et	3	main
on	doc_286998102750_item	3598166	et	4	main
kalad	doc_286998102750_item	3598167	et	3	main
see	doc_286998102750_item	3598079	et	3	main
trepp	doc_286998102750_item	3598091	et	3	main
taga	doc_286998102750_item	3598106	et	4	main
vesi	doc_286998102750_item	3598108	et	4	main
maja	doc_286998102750_item	3598109	et	4	main
aknad	doc_286998102750_item	3598110	et	3	main
maja	doc_286998102750_item	3598122	et	4	main
majas	doc_286998102750_item	3598129	et	3	main
on	doc_286998102750_item	3598133	et	4	main
lilled	doc_286998102750_item	3598143	et	3	main
ja	doc_286998102750_item	3598144	et	3	main
istuvad	doc_286998102750_item	3598147	et	4	main
meesel	doc_286998102750_item	3598149	et	4	main
janu	doc_286998102750_item	3598151	et	4	main
tüdrukul	doc_286998102750_item	3598152	et	3	main
on	doc_286998102750_item	3598150	et	4	main
ei	doc_286998102750_item	3598153	et	4	main
ole	doc_286998102750_item	3598154	et	4	main
tühi	doc_286998102750_item	3598155	et	3	main
kõht	doc_286998102750_item	3598156	et	3	main
vee	doc_286998102750_item	3598157	et	3	main
juures	doc_286998102750_item	3598158	et	4	main
on	doc_286998102750_item	3598159	et	4	main
viis	doc_286998102750_item	3598160	et	4	main
puut	doc_286998102750_item	3598161	et	4	main
need	doc_286998102750_item	3598162	et	3	main
on	doc_286998102750_item	3598163	et	4	main
siin	doc_286998102751_item	3598177	et	4	main
neli	doc_286998102751_item	3598179	et	3	main
poissi	doc_286998102751_item	3598185	et	4	main
maja	doc_286998102751_item	3598198	et	4	main
see	doc_286998102751_item	3598199	et	3	main
valged	doc_286998102751_item	3598207	et	3	main
majale	doc_286998102751_item	3598209	et	3	main
kümme	doc_286998102751_item	3598211	et	3	main
taga	doc_286998102751_item	3598222	et	4	main
nad	doc_286998102751_item	3598223	et	3	main
tartus	doc_286998102751_item	3598228	et	3	main
viis	doc_286998102751_item	3598240	et	4	main
aastat	doc_286998102751_item	3598241	et	3	main
juust	doc_286998102751_item	3598252	et	4	main
liha	doc_286998102751_item	3598253	et	4	main
ja	doc_286998102751_item	3598254	et	3	main
pudel	doc_286998102751_item	3598255	et	3	main
on	doc_286998102751_item	3598261	et	4	main
kalad	doc_286998102751_item	3598262	et	3	main
poisi	doc_286998102751_item	3598272	et	3	main
poissi	doc_286998102751_item	3598277	et	4	main
kadri	doc_286998102753_item	3598327	et	4	main
on	doc_286998102753_item	3598345	et	4	main
on	doc_286998102753_item	3598349	et	4	main
õde	doc_286998102753_item	3598351	et	4	main
viis	doc_286998102753_item	3598355	et	4	main
kodus	doc_286998102753_item	3598361	et	4	main
ja	doc_286998102753_item	3598362	et	3	main
on	doc_286998102753_item	3598365	et	4	main
kõht	doc_286998102753_item	3598366	et	3	main
täis	doc_286998102753_item	3598367	et	4	main
kadril	doc_286998102753_item	3598368	et	3	main
kirjeldus	doc_286998102754_item	3598375	et	4	main
on	doc_286998102754_item	3598377	et	4	main
tartu	doc_286998102754_item	3598385	et	4	main
on	doc_286998102754_item	3598420	et	4	main
see	doc_286998102754_item	3598422	et	3	main
on	doc_286998102754_item	3598430	et	4	main
jaanil	doc_286998102754_item	3598435	et	3	main
kingitust	doc_286998102754_item	3598474	et	4	main
see	doc_286998102754_item	3598476	et	3	main
elutuba	doc_286998102750_item	3598119	et	4	main
ja	doc_286998102750_item	3598120	et	3	main
kööki	doc_286998102750_item	3598121	et	4	main
inimest	doc_286998102750_item	3598126	et	3	main
inimesed	doc_286998102750_item	3598127	et	3	main
on	doc_286998102750_item	3598128	et	4	main
ilusad	doc_286998102750_item	3598134	et	3	main
on	doc_286998102750_item	3598136	et	4	main
kass	doc_286998102750_item	3598137	et	3	main
ja	doc_286998102750_item	3598138	et	3	main
koer	doc_286998102750_item	3598139	et	3	main
vee	doc_286998102750_item	3598140	et	3	main
rõhil	doc_286998102750_item	3598148	et	4	main
on	doc_286998102751_item	3598173	et	4	main
suur	doc_286998102751_item	3598174	et	3	main
ja	doc_286998102751_item	3598183	et	3	main
söövad	doc_286998102751_item	3598187	et	4	main
õunat	doc_286998102751_item	3598189	et	4	main
maja	doc_286998102751_item	3598200	et	4	main
on	doc_286998102751_item	3598215	et	4	main
järv	doc_286998102751_item	3598216	et	3	main
kõrval	doc_286998102751_item	3598221	et	4	main
õpivad	doc_286998102751_item	3598227	et	3	main
rääkivad	doc_286998102751_item	3598230	et	4	main
kakskümmend	doc_286998102751_item	3598239	et	4	main
inetud	doc_286998102751_item	3598246	et	4	main
nad	doc_286998102751_item	3598247	et	3	main
on	doc_286998102751_item	3598250	et	4	main
ilus	doc_286998102751_item	3598263	et	4	main
tüdruk	doc_286998102751_item	3598264	et	3	main
armastab	doc_286998102751_item	3598265	et	3	main
ilusat	doc_286998102751_item	3598266	et	3	main
poissi	doc_286998102751_item	3598267	et	4	main
nad	doc_286998102751_item	3598268	et	3	main
rääkivad	doc_286998102751_item	3598269	et	4	main
teise	doc_286998102751_item	3598276	et	4	main
pildi	doc_286998102753_item	3598301	et	4	main
pildil	doc_286998102753_item	3598303	et	3	main
tütar	doc_286998102753_item	3598309	et	3	main
kassi	doc_286998102753_item	3598330	et	4	main
nende	doc_286998102753_item	3598331	et	4	main
see	doc_286998102753_item	3598335	et	3	main
ei	doc_286998102753_item	3598336	et	4	main
vana	doc_286998102753_item	3598347	et	4	main
on	doc_286998102753_item	3598354	et	4	main
vana	doc_286998102753_item	3598357	et	4	main
ka	doc_286998102753_item	3598360	et	3	main
magab	doc_286998102753_item	3598363	et	3	main
kadril	doc_286998102753_item	3598364	et	3	main
pildi	doc_286998102754_item	3598374	et	4	main
ema	doc_286998102754_item	3598381	et	4	main
ta	doc_286998102754_item	3598393	et	4	main
töötab	doc_286998102754_item	3598394	et	3	main
haiglas	doc_286998102754_item	3598395	et	3	main
leena	doc_286998102754_item	3598396	et	3	main
torti	doc_286998102754_item	3598415	et	4	main
leenale	doc_286998102754_item	3598416	et	4	main
aga	doc_286998102754_item	3598417	et	3	main
leena	doc_286998102754_item	3598429	et	3	main
väike	doc_286998102754_item	3598433	et	4	main
meelest	doc_286998102754_item	3598436	et	4	main
ta	doc_286998102754_item	3598437	et	4	main
parem	doc_286998102754_item	3598443	et	4	main
tüdruk	doc_286998102754_item	3598444	et	3	main
kuin	doc_286998102754_item	3598453	et	4	main
kirjeldus	doc_286998102755_item	3598488	et	4	main
on	doc_286998102755_item	3598507	et	4	main
valge	doc_286998102755_item	3598508	et	4	main
kleit	doc_286998102755_item	3598509	et	3	main
ta	doc_286998102755_item	3598513	et	4	main
vanemad	doc_286998102755_item	3598519	et	4	main
ja	doc_286998102755_item	3598520	et	3	main
vanavanemad	doc_286998102755_item	3598521	et	4	main
ta	doc_286998102755_item	3598532	et	4	main
veel	doc_286998102755_item	3598535	et	4	main
tal	doc_286998102755_item	3598537	et	3	main
ema	doc_286998102755_item	3598548	et	4	main
ei	doc_286998102755_item	3598558	et	4	main
nad	doc_286998102751_item	3598186	et	3	main
taga	doc_286998102751_item	3598194	et	4	main
on	doc_286998102751_item	3598195	et	4	main
on	doc_286998102751_item	3598201	et	4	main
väga	doc_286998102751_item	3598202	et	3	main
suur	doc_286998102751_item	3598203	et	3	main
maja	doc_286998102751_item	3598204	et	4	main
on	doc_286998102751_item	3598210	et	4	main
maja	doc_286998102751_item	3598213	et	4	main
ees	doc_286998102751_item	3598214	et	4	main
järve	doc_286998102751_item	3598220	et	4	main
üliõpilased	doc_286998102751_item	3598225	et	3	main
vana	doc_286998102751_item	3598242	et	4	main
nad	doc_286998102751_item	3598243	et	3	main
ei	doc_286998102751_item	3598244	et	4	main
ole	doc_286998102751_item	3598245	et	4	main
seal	doc_286998102751_item	3598256	et	4	main
majast	doc_286998102751_item	3598270	et	4	main
nimi	doc_286998102751_item	3598273	et	3	main
jaan	doc_286998102751_item	3598280	et	3	main
ta	doc_286998102753_item	3598310	et	4	main
nimi	doc_286998102753_item	3598311	et	3	main
nad	doc_286998102751_item	3598226	et	3	main
nad	doc_286998102751_item	3598229	et	3	main
istuvad	doc_286998102751_item	3598248	et	4	main
ei	doc_286998102751_item	3598257	et	4	main
ole	doc_286998102751_item	3598258	et	4	main
lind	doc_286998102751_item	3598259	et	3	main
on	doc_286998102751_item	3598279	et	4	main
kirjeldus	doc_286998102753_item	3598302	et	4	main
on	doc_286998102753_item	3598304	et	4	main
väike	doc_286998102753_item	3598305	et	4	main
on	doc_286998102753_item	3598312	et	4	main
tal	doc_286998102753_item	3598314	et	3	main
hea	doc_286998102753_item	3598316	et	4	main
ema	doc_286998102753_item	3598317	et	4	main
silmad	doc_286998102753_item	3598324	et	4	main
ema	doc_286998102753_item	3598325	et	4	main
võtab	doc_286998102753_item	3598326	et	3	main
must	doc_286998102753_item	3598333	et	4	main
kass	doc_286998102753_item	3598334	et	3	main
ta	doc_286998102753_item	3598353	et	4	main
ta	doc_286998102753_item	3598358	et	4	main
on	doc_286998102753_item	3598359	et	4	main
hea	doc_286998102753_item	3598370	et	4	main
ta	doc_286998102754_item	3598380	et	4	main
kadri	doc_286998102754_item	3598382	et	4	main
valmis	doc_286998102754_item	3598421	et	4	main
väga	doc_286998102754_item	3598424	et	3	main
ja	doc_286998102754_item	3598426	et	3	main
šokolaaditort	doc_286998102754_item	3598428	et	2	main
ilus	doc_286998102754_item	3598432	et	4	main
tüdruk	doc_286998102754_item	3598434	et	3	main
ilusem	doc_286998102754_item	3598440	et	4	main
ja	doc_286998102754_item	3598441	et	3	main
kõige	doc_286998102754_item	3598442	et	4	main
ema	doc_286998102754_item	3598449	et	4	main
ja	doc_286998102754_item	3598450	et	3	main
isa	doc_286998102754_item	3598451	et	4	main
ja	doc_286998102754_item	3598452	et	3	main
on	doc_286998102754_item	3598477	et	4	main
suur	doc_286998102754_item	3598478	et	3	main
mõmmi	doc_286998102754_item	3598479	et	4	main
laps	doc_286998102755_item	3598490	et	4	main
väga	doc_286998102755_item	3598504	et	3	main
armas	doc_286998102755_item	3598505	et	3	main
tüdruk	doc_286998102755_item	3598512	et	3	main
süüa	doc_286998102755_item	3598525	et	3	main
ta	doc_286998102755_item	3598528	et	4	main
kadri	doc_286998102755_item	3598541	et	4	main
õde	doc_286998102755_item	3598542	et	4	main
on	doc_286998102755_item	3598543	et	4	main
kui	doc_286998102755_item	3598551	et	3	main
kadri	doc_286998102755_item	3598552	et	4	main
kadri	doc_286998102755_item	3598557	et	4	main
on	doc_286998102758_item	3598567	et	4	main
juures	doc_286998102758_item	3598570	et	4	main
raamaturiiul	doc_286998102758_item	3598579	et	4	main
raamaturiiulil	doc_286998102758_item	3598580	et	3	main
on	doc_286998102758_item	3598585	et	4	main
kapil	doc_286998102758_item	3598589	et	3	main
suure	doc_286998102758_item	3598592	et	3	main
kass	doc_286998102758_item	3598597	et	3	main
toas	doc_286998102759_item	3598622	et	3	main
minu	doc_286998102759_item	3598624	et	3	main
toas	doc_286998102759_item	3598625	et	3	main
üks	doc_286998102759_item	3598627	et	3	main
pilti	doc_286998102759_item	3598636	et	4	main
kõrval	doc_286998102759_item	3598646	et	4	main
kaks	doc_286998102759_item	3598653	et	3	main
mitu	doc_286998102759_item	3598662	et	4	main
raamatut	doc_286998102759_item	3598663	et	3	main
mul	doc_286998102759_item	3598664	et	3	main
kaks	doc_286998102759_item	3598726	et	3	main
kaks	doc_286998102759_item	3598730	et	3	main
kaks	doc_464301607713_item	3598737	et	3	main
kella	doc_464301607713_item	3598740	et	4	main
studioos	doc_464301607713_item	3598760	et	4	main
kuuest	doc_464301607713_item	3598762	et	4	main
vaja	doc_464301607713_item	3598770	et	4	main
kirjutada	doc_464301607713_item	3598771	et	3	main
ära	doc_464301607713_item	3598772	et	4	main
minutiks	doc_464301607713_item	3598807	et	4	main
lemmik	doc_464301607713_item	3598820	et	3	main
järgi	doc_464301607713_item	3598824	et	4	main
ühe	doc_286998102751_item	3598271	et	4	main
on	doc_286998102751_item	3598274	et	4	main
tõnu	doc_286998102751_item	3598275	et	4	main
nimi	doc_286998102751_item	3598278	et	3	main
ühe	doc_286998102751_item	3598281	et	4	main
tüdruku	doc_286998102751_item	3598282	et	3	main
nimi	doc_286998102751_item	3598283	et	3	main
on	doc_286998102751_item	3598284	et	4	main
tiina	doc_286998102751_item	3598285	et	4	main
tiinal	doc_286998102751_item	3598286	et	4	main
on	doc_286998102751_item	3598287	et	4	main
ilus	doc_286998102751_item	3598288	et	4	main
kass	doc_286998102751_item	3598289	et	3	main
kassi	doc_286998102751_item	3598290	et	4	main
nimi	doc_286998102751_item	3598291	et	3	main
on	doc_286998102751_item	3598292	et	4	main
cismi	doc_286998102751_item	3598293	et	4	main
neil	doc_286998102751_item	3598294	et	4	main
ei	doc_286998102751_item	3598295	et	4	main
ole	doc_286998102751_item	3598296	et	4	main
juba	doc_286998102751_item	3598297	et	3	main
kahju	doc_286998102751_item	3598298	et	4	main
laps	doc_286998102753_item	3598306	et	4	main
see	doc_286998102753_item	3598307	et	3	main
on	doc_286998102753_item	3598308	et	4	main
isa	doc_286998102753_item	3598318	et	4	main
töötab	doc_286998102753_item	3598319	et	3	main
praegu	doc_286998102753_item	3598320	et	3	main
kadril	doc_286998102753_item	3598321	et	3	main
on	doc_286998102753_item	3598322	et	4	main
mustad	doc_286998102753_item	3598323	et	4	main
kadri	doc_286998102753_item	3598328	et	4	main
ole	doc_286998102753_item	3598337	et	4	main
pildil	doc_286998102753_item	3598338	et	3	main
praegu	doc_286998102753_item	3598339	et	3	main
kadril	doc_286998102753_item	3598340	et	3	main
poolaastat	doc_286998102753_item	3598346	et	3	main
vanem	doc_286998102753_item	3598350	et	4	main
luise	doc_286998102753_item	3598352	et	4	main
aastat	doc_286998102753_item	3598356	et	3	main
on	doc_286998102753_item	3598369	et	4	main
kadri	doc_286998102753_item	3598313	et	4	main
on	doc_286998102753_item	3598315	et	4	main
armastab	doc_286998102753_item	3598329	et	3	main
on	doc_286998102753_item	3598332	et	4	main
käded	doc_286998102753_item	3598341	et	4	main
on	doc_286998102753_item	3598342	et	4	main
vaikesed	doc_286998102753_item	3598343	et	4	main
kadri	doc_286998102753_item	3598344	et	4	main
tal	doc_286998102753_item	3598348	et	3	main
meel	doc_286998102753_item	3598371	et	4	main
on	doc_286998102754_item	3598383	et	4	main
ülikoolis	doc_286998102754_item	3598386	et	4	main
ta	doc_286998102754_item	3598388	et	4	main
on	doc_286998102754_item	3598397	et	4	main
maitsev	doc_286998102754_item	3598427	et	4	main
on	doc_286998102754_item	3598438	et	4	main
ta	doc_286998102754_item	3598445	et	4	main
oskab	doc_286998102754_item	3598446	et	3	main
juba	doc_286998102754_item	3598447	et	3	main
palju	doc_286998102754_item	3598481	et	4	main
õnne	doc_286998102754_item	3598482	et	4	main
leena	doc_286998102754_item	3598484	et	3	main
pildi	doc_286998102755_item	3598487	et	4	main
on	doc_286998102755_item	3598511	et	4	main
ta	doc_286998102755_item	3598522	et	4	main
armastab	doc_286998102755_item	3598523	et	3	main
mängida	doc_286998102755_item	3598524	et	3	main
magada	doc_286998102755_item	3598527	et	3	main
ei	doc_286998102755_item	3598533	et	4	main
kadri	doc_286998102755_item	3598546	et	4	main
kadri	doc_286998102755_item	3598554	et	4	main
elab	doc_286998102755_item	3598555	et	3	main
tartus	doc_286998102755_item	3598556	et	3	main
kirjeldus	doc_286998102758_item	3598565	et	4	main
on	doc_286998102758_item	3598578	et	4	main
kapp	doc_286998102758_item	3598587	et	3	main
on	doc_286998102758_item	3598590	et	4	main
lill	doc_286998102758_item	3598591	et	3	main
ta	doc_286998102754_item	3598454	et	4	main
on	doc_286998102754_item	3598455	et	4	main
suurem	doc_286998102754_item	3598456	et	4	main
ta	doc_286998102754_item	3598457	et	4	main
on	doc_286998102754_item	3598458	et	4	main
väga	doc_286998102754_item	3598459	et	3	main
jutukas	doc_286998102754_item	3598460	et	4	main
vanaema	doc_286998102754_item	3598461	et	4	main
jäi	doc_286998102754_item	3598462	et	3	main
hiljaks	doc_286998102754_item	3598463	et	3	main
aga	doc_286998102754_item	3598464	et	3	main
nüüd	doc_286998102754_item	3598465	et	4	main
ta	doc_286998102754_item	3598466	et	4	main
on	doc_286998102754_item	3598467	et	4	main
leena	doc_286998102754_item	3598468	et	3	main
kõrval	doc_286998102754_item	3598469	et	4	main
ja	doc_286998102754_item	3598470	et	3	main
ta	doc_286998102754_item	3598471	et	4	main
annab	doc_286998102754_item	3598472	et	3	main
väga	doc_286998102754_item	3598473	et	3	main
leenale	doc_286998102754_item	3598475	et	4	main
see	doc_286998102754_item	3598376	et	3	main
väike	doc_286998102754_item	3598378	et	4	main
leena	doc_286998102754_item	3598379	et	3	main
õppejõud	doc_286998102754_item	3598384	et	4	main
ja	doc_286998102754_item	3598387	et	3	main
isa	doc_286998102754_item	3598389	et	4	main
jaan	doc_286998102754_item	3598390	et	3	main
on	doc_286998102754_item	3598391	et	4	main
arst	doc_286998102754_item	3598392	et	3	main
kaks	doc_286998102754_item	3598398	et	3	main
aastat	doc_286998102754_item	3598399	et	3	main
vana	doc_286998102754_item	3598400	et	4	main
täna	doc_286998102754_item	3598401	et	4	main
ta	doc_286998102754_item	3598402	et	4	main
on	doc_286998102754_item	3598403	et	4	main
sünnipäevapidu	doc_286998102754_item	3598404	et	4	main
kogu	doc_286998102754_item	3598405	et	4	main
pärastlõunal	doc_286998102754_item	3598406	et	3	main
oli	doc_286998102754_item	3598408	et	3	main
köögis	doc_286998102754_item	3598409	et	3	main
ja	doc_286998102754_item	3598410	et	3	main
tegi	doc_286998102754_item	3598411	et	4	main
kartulisalatit	doc_286998102754_item	3598412	et	3	main
kadri	doc_286998102754_item	3598407	et	4	main
jaanile	doc_286998102754_item	3598413	et	3	main
ja	doc_286998102754_item	3598414	et	3	main
nüüd	doc_286998102754_item	3598418	et	4	main
tort	doc_286998102754_item	3598419	et	3	main
on	doc_286998102754_item	3598423	et	4	main
ilus	doc_286998102754_item	3598425	et	4	main
väga	doc_286998102754_item	3598431	et	3	main
kõige	doc_286998102754_item	3598439	et	4	main
ütleda	doc_286998102754_item	3598448	et	4	main
karu	doc_286998102754_item	3598480	et	4	main
on	doc_286998102755_item	3598491	et	4	main
ta	doc_286998102755_item	3598510	et	4	main
nimi	doc_286998102755_item	3598514	et	3	main
tal	doc_286998102755_item	3598517	et	3	main
ja	doc_286998102755_item	3598526	et	3	main
ülikoolis	doc_286998102755_item	3598531	et	4	main
lasteaias	doc_286998102755_item	3598536	et	4	main
kadri	doc_286998102755_item	3598547	et	4	main
pikem	doc_286998102755_item	3598550	et	4	main
õde	doc_286998102755_item	3598553	et	4	main
veel	doc_286998102755_item	3598560	et	4	main
rääkida	doc_286998102755_item	3598561	et	3	main
seinal	doc_286998102758_item	3598568	et	3	main
kapi	doc_286998102758_item	3598576	et	4	main
kõrval	doc_286998102758_item	3598577	et	4	main
raamaturiiuli	doc_286998102758_item	3598583	et	3	main
kõrval	doc_286998102758_item	3598584	et	4	main
taga	doc_286998102758_item	3598594	et	4	main
väikse	doc_286998102758_item	3598598	et	4	main
kapi	doc_286998102758_item	3598599	et	4	main
seal	doc_286998102759_item	3598629	et	4	main
kolm	doc_286998102759_item	3598635	et	3	main
on	doc_286998102759_item	3598638	et	4	main
tooli	doc_286998102759_item	3598640	et	4	main
on	doc_286998102759_item	3598647	et	4	main
neli	doc_286998102759_item	3598648	et	3	main
suurt	doc_286998102759_item	3598651	et	3	main
riiulil	doc_286998102759_item	3598728	et	3	main
rong	doc_464301607713_item	3598735	et	3	main
seans	doc_464301607713_item	3598743	et	4	main
kolmverand	doc_464301607713_item	3598745	et	4	main
kaks	doc_464301607713_item	3598747	et	3	main
kaheksateistkümnest	doc_464301607713_item	3598757	et	3	main
4	doc_464301607713_item	3598758	et	2	main
helistasid	doc_464301607713_item	3598761	et	4	main
hommikust	doc_464301607713_item	3598763	et	4	main
kellaks	doc_464301607713_item	3598773	et	4	main
kaheteistkümne	doc_464301607713_item	3598799	et	4	main
kahekümne	doc_464301607713_item	3598800	et	4	main
viie-kümne	doc_464301607713_item	3598806	et	4	main
kooselek	doc_464301607713_item	3598813	et	4	main
kella	doc_464301607713_item	3598815	et	4	main
üheksateistkümneks	doc_464301607713_item	3598816	et	4	main
10	doc_464301607713_item	3598817	et	2	main
minu	doc_464301607713_item	3598818	et	3	main
kava	doc_464301607713_item	3598823	et	4	main
kell	doc_464301607713_item	3598826	et	3	main
tõesti	doc_464301607713_item	3598828	et	3	main
seitse	doc_464301607713_item	3598833	et	3	main
ma	doc_464301607713_item	3598838	et	3	main
olen	doc_464301607713_item	3598839	et	3	main
tuhande	doc_464301607713_item	3598843	et	3	main
kaheksandal	doc_464301607713_item	3598845	et	3	main
unustage	doc_464301607713_item	3598857	et	3	main
poole	doc_464301607713_item	3598860	et	4	main
kaheksa	doc_464301607713_item	3598864	et	4	main
ootan	doc_464301607713_item	3598873	et	3	main
kümne-viieteistkümne	doc_464301607713_item	3598877	et	4	main
üksi	doc_464301607713_item	3598888	et	4	main
viis	doc_464301607713_item	3598893	et	4	main
minutit	doc_464301607713_item	3598894	et	3	main
kolme	doc_464301607713_item	3598906	et	4	main
ja	doc_464301607713_item	3598912	et	3	main
võttis	doc_464301607713_item	3598914	et	3	main
täelikult	doc_464301607713_item	3598924	et	4	main
tööle	doc_464301607713_item	3598925	et	3	main
valmis	doc_464301607713_item	3598926	et	4	main
ei	doc_464301607713_item	3598928	et	4	main
sünnipäevaks	doc_286998102754_item	3598483	et	3	main
see	doc_286998102755_item	3598489	et	3	main
väike	doc_286998102755_item	3598492	et	4	main
ja	doc_286998102755_item	3598493	et	3	main
lõbus	doc_286998102755_item	3598494	et	4	main
lapse	doc_286998102755_item	3598495	et	4	main
käed	doc_286998102755_item	3598496	et	3	main
on	doc_286998102755_item	3598497	et	4	main
ka	doc_286998102755_item	3598498	et	3	main
väikesed	doc_286998102755_item	3598499	et	4	main
ja	doc_286998102755_item	3598500	et	3	main
paksud	doc_286998102755_item	3598501	et	3	main
ta	doc_286998102755_item	3598502	et	4	main
on	doc_286998102755_item	3598503	et	4	main
tal	doc_286998102755_item	3598506	et	3	main
on	doc_286998102755_item	3598515	et	4	main
kadri	doc_286998102755_item	3598516	et	4	main
on	doc_286998102755_item	3598518	et	4	main
ei	doc_286998102755_item	3598529	et	4	main
käi	doc_286998102755_item	3598530	et	4	main
käi	doc_286998102755_item	3598534	et	4	main
on	doc_286998102755_item	3598538	et	4	main
üks	doc_286998102755_item	3598539	et	3	main
õde	doc_286998102755_item	3598540	et	4	main
vanem	doc_286998102755_item	3598544	et	4	main
kui	doc_286998102755_item	3598545	et	3	main
on	doc_286998102755_item	3598549	et	4	main
oska	doc_286998102755_item	3598559	et	4	main
pildi	doc_286998102758_item	3598564	et	4	main
raamatud	doc_286998102758_item	3598582	et	4	main
kapi	doc_286998102758_item	3598593	et	4	main
must	doc_286998102758_item	3598596	et	4	main
minu	doc_286998102759_item	3598621	et	3	main
on	doc_286998102759_item	3598626	et	4	main
voodi	doc_286998102759_item	3598628	et	4	main
on	doc_286998102759_item	3598634	et	4	main
neli	doc_286998102759_item	3598639	et	3	main
toas	doc_286998102759_item	3598641	et	3	main
on	doc_286998102759_item	3598642	et	4	main
kaks	doc_286998102759_item	3598643	et	3	main
lauda	doc_286998102759_item	3598644	et	4	main
riiuli	doc_286998102759_item	3598645	et	3	main
ja	doc_286998102759_item	3598652	et	3	main
kassi	doc_286998102759_item	3598655	et	4	main
on	doc_286998102759_item	3598657	et	4	main
üks	doc_286998102759_item	3598658	et	3	main
koer	doc_286998102759_item	3598659	et	3	main
raamaturiiulil	doc_286998102759_item	3598660	et	3	main
ja	doc_286998102759_item	3598725	et	3	main
pild	doc_286998102758_item	3598566	et	3	main
seina	doc_286998102758_item	3598569	et	4	main
on	doc_286998102758_item	3598571	et	4	main
kapp	doc_286998102758_item	3598572	et	3	main
kapil	doc_286998102758_item	3598573	et	3	main
on	doc_286998102758_item	3598574	et	4	main
televiisor	doc_286998102758_item	3598575	et	3	main
on	doc_286998102758_item	3598581	et	4	main
suur	doc_286998102758_item	3598586	et	3	main
suurel	doc_286998102758_item	3598588	et	3	main
on	doc_286998102758_item	3598595	et	4	main
ees	doc_286998102758_item	3598600	et	4	main
on	doc_286998102758_item	3598601	et	4	main
laud	doc_286998102758_item	3598602	et	4	main
laual	doc_286998102758_item	3598603	et	3	main
on	doc_286998102758_item	3598604	et	4	main
raamat	doc_286998102758_item	3598605	et	3	main
laua	doc_286998102758_item	3598606	et	3	main
all	doc_286998102758_item	3598607	et	3	main
magab	doc_286998102758_item	3598608	et	3	main
valge	doc_286998102758_item	3598609	et	4	main
koer	doc_286998102758_item	3598610	et	3	main
laua	doc_286998102758_item	3598611	et	3	main
juures	doc_286998102758_item	3598612	et	4	main
on	doc_286998102758_item	3598613	et	4	main
tool	doc_286998102758_item	3598614	et	3	main
toolil	doc_286998102758_item	3598615	et	3	main
istub	doc_286998102758_item	3598616	et	3	main
väike	doc_286998102758_item	3598617	et	4	main
tüdruk	doc_286998102758_item	3598618	et	3	main
harjutus	doc_286998102759_item	3598620	et	4	main
on	doc_286998102759_item	3598623	et	4	main
kaks	doc_286998102759_item	3598631	et	3	main
raamaturiiulit	doc_286998102759_item	3598632	et	3	main
on	doc_286998102759_item	3598661	et	4	main
jänest	doc_286998102759_item	3598727	et	3	main
vaasit	doc_286998102759_item	3598731	et	4	main
harjutus	doc_464301607713_item	3598733	et	4	main
algas	doc_464301607713_item	3598744	et	3	main
kakskümmend	doc_464301607713_item	3598746	et	4	main
lõppenud	doc_464301607713_item	3598751	et	4	main
vastuvõtu	doc_464301607713_item	3598752	et	3	main
neli	doc_464301607713_item	3598753	et	3	main
minutit	doc_464301607713_item	3598754	et	3	main
puudub	doc_464301607713_item	3598755	et	3	main
kahekümme	doc_464301607713_item	3598764	et	4	main
kaheni	doc_464301607713_item	3598765	et	3	main
õhtuni	doc_464301607713_item	3598766	et	3	main
verand	doc_464301607713_item	3598774	et	4	main
viisteist	doc_464301607713_item	3598775	et	4	main
6	doc_464301607713_item	3598776	et	2	main
kolm	doc_464301607713_item	3598777	et	3	main
minutit	doc_464301607713_item	3598778	et	3	main
ühe	doc_464301607713_item	3598801	et	4	main
9	doc_464301607713_item	3598808	et	2	main
et	doc_464301607713_item	3598811	et	3	main
algama	doc_464301607713_item	3598825	et	3	main
kaksteist	doc_464301607713_item	3598827	et	4	main
ta	doc_464301607713_item	3598829	et	4	main
algab	doc_464301607713_item	3598830	et	3	main
reklaami	doc_464301607713_item	3598831	et	4	main
läbi	doc_464301607713_item	3598836	et	4	main
järgi	doc_464301607713_item	3598854	et	4	main
pastapliiatsit	doc_286998102759_item	3598702	et	3	main
sahtlil	doc_286998102759_item	3598703	et	3	main
on	doc_286998102759_item	3598704	et	4	main
kaheksa	doc_286998102759_item	3598705	et	4	main
vihikut	doc_286998102759_item	3598706	et	3	main
tooli	doc_286998102759_item	3598707	et	4	main
neben	doc_286998102759_item	3598708	et	4	main
kaks	doc_286998102759_item	3598710	et	3	main
on	doc_286998102759_item	3598709	et	4	main
palli	doc_286998102759_item	3598711	et	4	main
voodil	doc_286998102759_item	3598712	et	3	main
on	doc_286998102759_item	3598713	et	4	main
viis	doc_286998102759_item	3598714	et	4	main
patja	doc_286998102759_item	3598715	et	4	main
seal	doc_286998102759_item	3598716	et	4	main
on	doc_286998102759_item	3598717	et	4	main
ka	doc_286998102759_item	3598718	et	3	main
kaks	doc_286998102759_item	3598719	et	3	main
tekki	doc_286998102759_item	3598720	et	4	main
on	doc_286998102759_item	3598722	et	4	main
mul	doc_286998102759_item	3598721	et	3	main
kolm	doc_286998102759_item	3598723	et	3	main
karu	doc_286998102759_item	3598724	et	4	main
on	doc_286998102759_item	3598630	et	4	main
seinal	doc_286998102759_item	3598633	et	3	main
põrandal	doc_286998102759_item	3598637	et	3	main
kassi	doc_286998102759_item	3598649	et	4	main
kaks	doc_286998102759_item	3598650	et	3	main
väikest	doc_286998102759_item	3598654	et	4	main
meil	doc_286998102759_item	3598656	et	4	main
on	doc_286998102759_item	3598665	et	4	main
üks	doc_286998102759_item	3598666	et	3	main
riidekapp	doc_286998102759_item	3598667	et	3	main
seal	doc_286998102759_item	3598668	et	4	main
on	doc_286998102759_item	3598669	et	4	main
kaks	doc_286998102759_item	3598670	et	3	main
tugitooli	doc_286998102759_item	3598671	et	4	main
toas	doc_286998102759_item	3598672	et	3	main
ei	doc_286998102759_item	3598673	et	4	main
ole	doc_286998102759_item	3598674	et	4	main
üksteist	doc_286998102759_item	3598675	et	4	main
tooli	doc_286998102759_item	3598676	et	4	main
ei	doc_286998102759_item	3598677	et	4	main
ole	doc_286998102759_item	3598678	et	4	main
kümme	doc_286998102759_item	3598679	et	3	main
voodit	doc_286998102759_item	3598680	et	3	main
seal	doc_286998102759_item	3598681	et	4	main
ei	doc_286998102759_item	3598682	et	4	main
ole	doc_286998102759_item	3598683	et	4	main
kolm	doc_286998102759_item	3598684	et	3	main
treppi	doc_286998102759_item	3598685	et	4	main
toal	doc_286998102759_item	3598686	et	3	main
on	doc_286998102759_item	3598687	et	4	main
üks	doc_286998102759_item	3598688	et	3	main
aken	doc_286998102759_item	3598689	et	3	main
ja	doc_286998102759_item	3598690	et	3	main
üks	doc_286998102759_item	3598691	et	3	main
aks	doc_286998102759_item	3598692	et	4	main
on	doc_286998102759_item	3598694	et	4	main
kakskümmend	doc_286998102759_item	3598695	et	4	main
laual	doc_286998102759_item	3598693	et	3	main
neli	doc_286998102759_item	3598696	et	3	main
pliiatsit	doc_286998102759_item	3598697	et	3	main
kirjutuslaual	doc_286998102759_item	3598698	et	3	main
on	doc_286998102759_item	3598699	et	4	main
ka	doc_286998102759_item	3598700	et	3	main
üheksateist	doc_286998102759_item	3598701	et	4	main
on	doc_286998102759_item	3598729	et	4	main
1	doc_464301607713_item	3598734	et	2	main
saabub	doc_464301607713_item	3598736	et	3	main
puudub	doc_464301607713_item	3598739	et	3	main
kaheteistkümnest	doc_464301607713_item	3598741	et	3	main
poole	doc_464301607713_item	3598756	et	4	main
telefonid	doc_464301607713_item	3598759	et	3	main
5	doc_464301607713_item	3598767	et	2	main
tööd	doc_464301607713_item	3598768	et	4	main
on	doc_464301607713_item	3598769	et	4	main
puudub	doc_464301607713_item	3598779	et	3	main
kümnest	doc_464301607713_item	3598780	et	4	main
klienditele	doc_464301607713_item	3598781	et	4	main
sissepääs	doc_464301607713_item	3598782	et	3	main
stocmanisse	doc_464301607713_item	3598783	et	4	main
on	doc_464301607713_item	3598784	et	4	main
keelatud	doc_464301607713_item	3598785	et	4	main
nad	doc_464301607713_item	3598786	et	3	main
peeavad	doc_464301607713_item	3598787	et	4	main
ootada	doc_464301607713_item	3598788	et	4	main
kella	doc_464301607713_item	3598789	et	4	main
kümneni	doc_464301607713_item	3598790	et	4	main
7	doc_464301607713_item	3598791	et	2	main
ülemus	doc_464301607713_item	3598792	et	4	main
tuleb	doc_464301607713_item	3598793	et	3	main
tagasi	doc_464301607713_item	3598794	et	3	main
kuskil	doc_464301607713_item	3598795	et	3	main
kaheteistkümne	doc_464301607713_item	3598796	et	4	main
kolmeteistkümne	doc_464301607713_item	3598797	et	4	main
ja	doc_464301607713_item	3598798	et	3	main
minutit	doc_464301607713_item	3598738	et	3	main
2	doc_464301607713_item	3598742	et	2	main
3	doc_464301607713_item	3598748	et	2	main
arst	doc_464301607713_item	3598749	et	3	main
on	doc_464301607713_item	3598750	et	4	main
läks	doc_464301607713_item	3598805	et	3	main
loodan	doc_464301607713_item	3598810	et	3	main
vanaema	doc_464301607713_item	3598819	et	4	main
tõttu	doc_464301607713_item	3598832	et	4	main
vahel	doc_464301607713_item	3598802	et	4	main
8	doc_464301607713_item	3598803	et	2	main
sekretär	doc_464301607713_item	3598804	et	3	main
ma	doc_464301607713_item	3598809	et	3	main
vanemate	doc_464301607713_item	3598812	et	4	main
lõpetab	doc_464301607713_item	3598814	et	3	main
serial	doc_464301607713_item	3598821	et	4	main
peab	doc_464301607713_item	3598822	et	4	main
minutit	doc_464301607713_item	3598834	et	3	main
neljast	doc_464301607713_item	3598851	et	4	main
ärge	doc_464301607713_item	3598856	et	3	main
mulle	doc_464301607713_item	3598859	et	4	main
verand	doc_464301607713_item	3598863	et	4	main
minutit	doc_464301607713_item	3598869	et	3	main
rohkem	doc_464301607713_item	3598876	et	4	main
minutit	doc_464301607713_item	3598878	et	3	main
kui	doc_464301607713_item	3598879	et	3	main
sa	doc_464301607713_item	3598880	et	3	main
ei	doc_464301607713_item	3598881	et	4	main
14	doc_464301607713_item	3598889	et	2	main
killer	doc_464301607713_item	3598890	et	4	main
saabus	doc_464301607713_item	3598891	et	3	main
neljateistkümne	doc_464301607713_item	3598895	et	4	main
läbi	doc_464301607713_item	3598896	et	4	main
läbi	doc_464301607713_item	3598901	et	4	main
vajalikku	doc_464301607713_item	3598902	et	4	main
akent	doc_464301607713_item	3598903	et	3	main
ta	doc_464301607713_item	3598904	et	4	main
juhtus	doc_464301607713_item	3598910	et	3	main
läbi	doc_464301607713_item	3598921	et	4	main
dialoog	doc_980560860246_item	3598952	et	3	main
lewis	doc_980560860246_item	3598955	et	4	main
ma	doc_980560860246_item	3598962	et	3	main
berliinis	doc_980560860246_item	3598964	et	4	main
saksamaa	doc_980560860246_item	3598965	et	4	main
olen	doc_980560860246_item	3598967	et	3	main
sündinüd	doc_980560860246_item	3598968	et	4	main
kaks	doc_980560860246_item	3598975	et	3	main
keel	doc_980560860246_item	3598990	et	4	main
ma	doc_980560860246_item	3598991	et	3	main
hamilton	doc_980560860246_item	3599003	et	4	main
vana	doc_980560860246_item	3599011	et	4	main
räägin	doc_980560860246_item	3599029	et	3	main
hallo	doc_980560860252_item	3599043	et	3	main
piret	doc_980560860252_item	3599047	et	4	main
see	doc_980560860252_item	3599048	et	3	main
rahu	doc_980560860252_item	3599053	et	4	main
kus	doc_980560860252_item	3599054	et	3	main
sa	doc_980560860252_item	3599055	et	3	main
on	doc_980560860252_item	3599062	et	4	main
intervjuu	doc_980560860252_item	3599064	et	4	main
kell	doc_980560860252_item	3599065	et	3	main
mina	doc_980560860252_item	3599068	et	4	main
tuleks	doc_980560860252_item	3599069	et	4	main
helistasid	doc_980560860252_item	3599077	et	4	main
on	doc_980560860252_item	3599079	et	4	main
juba	doc_980560860252_item	3599080	et	3	main
kolm	doc_980560860252_item	3599081	et	3	main
noh	doc_980560860252_item	3599083	et	3	main
ma	doc_980560860252_item	3599084	et	3	main
tean	doc_980560860252_item	3599085	et	3	main
ma	doc_980560860252_item	3599086	et	3	main
tean	doc_980560860252_item	3599087	et	3	main
issand	doc_980560860252_item	3599088	et	4	main
siia	doc_980560860252_item	3599093	et	4	main
on	doc_980560860252_item	3599102	et	4	main
ja	doc_980560860252_item	3599103	et	3	main
siis	doc_980560860252_item	3599104	et	3	main
tulen	doc_980560860252_item	3599105	et	3	main
paike	doc_980560860252_item	3599141	et	4	main
oli	doc_980560860252_item	3599143	et	3	main
aga	doc_980560860252_item	3599148	et	3	main
põder	doc_980560860256_item	3599191	et	3	main
nad	doc_980560860256_item	3599196	et	3	main
tugevad	doc_980560860256_item	3599200	et	4	main
on	doc_980560860256_item	3599204	et	4	main
ka	doc_980560860256_item	3599205	et	3	main
kartlikud	doc_980560860256_item	3599206	et	3	main
nad	doc_980560860256_item	3599207	et	3	main
on	doc_980560860256_item	3599208	et	4	main
sarvad	doc_980560860256_item	3599213	et	4	main
sest	doc_980560860256_item	3599247	et	4	main
nad	doc_980560860256_item	3599248	et	3	main
kaheteistkümne	doc_464301607713_item	3598835	et	4	main
kaheksandal	doc_464301607713_item	3598841	et	3	main
moskva	doc_464301607713_item	3598852	et	4	main
aja	doc_464301607713_item	3598853	et	4	main
helistada	doc_464301607713_item	3598858	et	3	main
seitsme	doc_464301607713_item	3598861	et	3	main
ja	doc_464301607713_item	3598862	et	3	main
kümme	doc_464301607713_item	3598868	et	3	main
mitte	doc_464301607713_item	3598875	et	3	main
kohale	doc_464301607713_item	3598892	et	4	main
neljateistkümne	doc_464301607713_item	3598900	et	4	main
sekundiga	doc_464301607713_item	3598907	et	3	main
kuid	doc_464301607713_item	3598908	et	4	main
see	doc_464301607713_item	3598913	et	3	main
veel	doc_464301607713_item	3598915	et	4	main
minutit	doc_464301607713_item	3598917	et	3	main
üksteist	doc_464301607713_item	3598918	et	4	main
minutit	doc_464301607713_item	3598919	et	3	main
tulnud	doc_464301607713_item	3598929	et	4	main
dialoog	doc_980560860246_item	3598950	et	3	main
prantslane	doc_980560860246_item	3598972	et	3	main
üks	doc_980560860246_item	3598977	et	3	main
aastat	doc_980560860246_item	3598978	et	3	main
ma	doc_980560860246_item	3598980	et	3	main
üliõpilane	doc_980560860246_item	3598982	et	3	main
õpin	doc_980560860246_item	3598984	et	3	main
eesti	doc_980560860246_item	3598989	et	4	main
hea	doc_980560860246_item	3598995	et	4	main
lewis	doc_980560860246_item	3598996	et	4	main
anna	doc_980560860246_item	3598998	et	4	main
minu	doc_980560860246_item	3598999	et	3	main
ma	doc_980560860246_item	3599004	et	3	main
ka	doc_980560860246_item	3599006	et	3	main
kümmend	doc_980560860246_item	3599008	et	4	main
aastat	doc_980560860246_item	3599010	et	3	main
ma	doc_980560860246_item	3599012	et	3	main
olen	doc_980560860246_item	3599013	et	3	main
sündinud	doc_980560860246_item	3599014	et	4	main
northampronis	doc_980560860246_item	3599015	et	4	main
fi	doc_980560860246_item	3599026	et	4	main
juht	doc_980560860246_item	3599027	et	3	main
ma	doc_980560860246_item	3599028	et	3	main
dialoog	doc_980560860252_item	3599041	et	3	main
on	doc_980560860252_item	3599049	et	4	main
oled	doc_980560860252_item	3599056	et	3	main
mul	doc_980560860252_item	3599061	et	3	main
representiivsegina	doc_980560860252_item	3599071	et	4	main
kõik	doc_980560860252_item	3599089	et	4	main
p	doc_980560860252_item	3599094	et	4	main
tulen	doc_980560860252_item	3599095	et	3	main
ometi	doc_980560860252_item	3599096	et	3	main
aga	doc_980560860252_item	3599097	et	3	main
positiivne	doc_980560860252_item	3599146	et	3	main
läks	doc_980560860252_item	3599150	et	3	main
sajama	doc_980560860252_item	3599155	et	4	main
11	doc_464301607713_item	3598837	et	2	main
sündinud	doc_464301607713_item	3598840	et	4	main
märtsil	doc_464301607713_item	3598842	et	3	main
üheksasaja	doc_464301607713_item	3598844	et	4	main
aastal	doc_464301607713_item	3598846	et	3	main
üheksa	doc_464301607713_item	3598847	et	4	main
minutit	doc_464301607713_item	3598848	et	3	main
puudub	doc_464301607713_item	3598849	et	3	main
kahekümne	doc_464301607713_item	3598850	et	4	main
12	doc_464301607713_item	3598855	et	2	main
vahel	doc_464301607713_item	3598865	et	4	main
13	doc_464301607713_item	3598866	et	2	main
sind	doc_464301607713_item	3598874	et	4	main
tule	doc_464301607713_item	3598882	et	4	main
ma	doc_464301607713_item	3598883	et	3	main
sõidan	doc_464301607713_item	3598884	et	3	main
ta	doc_464301607713_item	3598897	et	4	main
midagi	doc_464301607713_item	3598909	et	4	main
polteist	doc_464301607713_item	3598916	et	4	main
neljateistkümne	doc_464301607713_item	3598920	et	4	main
klient	doc_464301607713_item	3598927	et	3	main
üheksa	doc_464301607713_item	3598932	et	4	main
tee	doc_980560860246_item	3598951	et	4	main
anna	doc_980560860246_item	3598953	et	4	main
ma	doc_980560860246_item	3598970	et	3	main
ma	doc_980560860246_item	3598973	et	3	main
ma	doc_980560860246_item	3598983	et	3	main
keel	doc_980560860246_item	3598994	et	4	main
õpi	doc_980560860246_item	3599023	et	4	main
ma	doc_980560860246_item	3599024	et	3	main
töötan	doc_980560860246_item	3599025	et	3	main
p	doc_980560860252_item	3599042	et	4	main
piret	doc_980560860252_item	3599044	et	4	main
mina	doc_980560860252_item	3599050	et	4	main
kirsi	doc_980560860252_item	3599051	et	4	main
p	doc_980560860252_item	3599052	et	4	main
sa	doc_980560860252_item	3599058	et	3	main
kolm	doc_980560860252_item	3599066	et	3	main
miks	doc_980560860252_item	3599074	et	4	main
sa	doc_980560860252_item	3599075	et	3	main
jutusta	doc_980560860252_item	3599098	et	4	main
mis	doc_980560860252_item	3599099	et	4	main
ometi	doc_980560860252_item	3599100	et	3	main
kõikumatu	doc_980560860252_item	3599144	et	4	main
ja	doc_980560860252_item	3599145	et	3	main
olukord	doc_980560860252_item	3599147	et	3	main
siis	doc_980560860252_item	3599149	et	3	main
pilvesse	doc_980560860252_item	3599152	et	4	main
hakkas	doc_980560860252_item	3599154	et	3	main
on	doc_980560860256_item	3599192	et	4	main
suured	doc_980560860256_item	3599198	et	3	main
neil	doc_980560860256_item	3599211	et	4	main
tapta	doc_980560860256_item	3599251	et	4	main
tapma	doc_980560860256_item	3599252	et	3	main
eestimaal	doc_980560860256_item	3599253	et	4	main
on	doc_980560860256_item	3599260	et	4	main
ja	doc_980560860256_item	3599264	et	3	main
metsikad	doc_980560860256_item	3599265	et	4	main
on	doc_980560860256_item	3599267	et	4	main
kõige	doc_980560860256_item	3599269	et	4	main
on	doc_980560860256_item	3599281	et	4	main
uut	doc_980560860257_item	3599294	et	3	main
poe	doc_980560860257_item	3599299	et	4	main
kas	doc_980560860257_item	3599303	et	3	main
saan	doc_980560860257_item	3599305	et	4	main
aidata	doc_980560860257_item	3599307	et	4	main
mees	doc_980560860257_item	3599308	et	4	main
jah	doc_980560860257_item	3599309	et	3	main
ma	doc_980560860257_item	3599310	et	3	main
tahaksin	doc_980560860257_item	3599311	et	3	main
uut	doc_980560860257_item	3599312	et	3	main
te	doc_980560860257_item	3599318	et	4	main
tahaksite	doc_980560860257_item	3599319	et	3	main
on	doc_980560860257_item	3599331	et	4	main
vaga	doc_980560860257_item	3599332	et	4	main
moodsest	doc_980560860257_item	3599339	et	3	main
müüja	doc_980560860257_item	3599341	et	4	main
meil	doc_980560860257_item	3599342	et	4	main
kostüümi	doc_980560860257_item	3599346	et	4	main
palju	doc_980560860257_item	3599349	et	4	main
te	doc_980560860257_item	3599350	et	4	main
tahaksite	doc_980560860257_item	3599351	et	3	main
maksab	doc_980560860257_item	3599357	et	3	main
tule	doc_464301607713_item	3598867	et	4	main
enne	doc_464301607713_item	3598870	et	4	main
kaheksat	doc_464301607713_item	3598871	et	3	main
ma	doc_464301607713_item	3598872	et	3	main
ära	doc_464301607713_item	3598885	et	4	main
kell	doc_464301607713_item	3598886	et	3	main
kaheksa	doc_464301607713_item	3598887	et	4	main
kaheksa	doc_464301607713_item	3598898	et	4	main
minutit	doc_464301607713_item	3598899	et	3	main
leidis	doc_464301607713_item	3598905	et	4	main
relviga	doc_464301607713_item	3598911	et	3	main
ta	doc_464301607713_item	3598922	et	4	main
oli	doc_464301607713_item	3598923	et	3	main
akna	doc_464301607713_item	3598930	et	3	main
ette	doc_464301607713_item	3598931	et	4	main
minutit	doc_464301607713_item	3598933	et	3	main
kuid	doc_464301607713_item	3598934	et	4	main
killer	doc_464301607713_item	3598935	et	4	main
nägi	doc_464301607713_item	3598936	et	3	main
teda	doc_464301607713_item	3598937	et	4	main
ning	doc_464301607713_item	3598938	et	3	main
üheksa	doc_464301607713_item	3598939	et	4	main
minutit	doc_464301607713_item	3598940	et	3	main
puudub	doc_464301607713_item	3598941	et	3	main
poole	doc_464301607713_item	3598942	et	4	main
viieteistkümnest	doc_464301607713_item	3598943	et	3	main
eestis	doc_464301607713_item	3598944	et	3	main
saanud	doc_464301607713_item	3598945	et	4	main
ühe	doc_464301607713_item	3598946	et	4	main
inimese	doc_464301607713_item	3598947	et	4	main
vähem	doc_464301607713_item	3598948	et	4	main
elan	doc_980560860246_item	3598963	et	3	main
pariisis	doc_980560860246_item	3598969	et	4	main
olen	doc_980560860246_item	3598971	et	3	main
olen	doc_980560860246_item	3598974	et	3	main
vana	doc_980560860246_item	3598979	et	4	main
olen	doc_980560860246_item	3598981	et	3	main
räägin	doc_980560860246_item	3598992	et	3	main
on	doc_980560860246_item	3599001	et	4	main
olen	doc_980560860246_item	3599005	et	3	main
kaks	doc_980560860246_item	3599007	et	3	main
üks	doc_980560860246_item	3599009	et	3	main
hea	doc_980560860246_item	3599030	et	4	main
teab	doc_980560860252_item	3599059	et	3	main
et	doc_980560860252_item	3599060	et	3	main
see	doc_980560860252_item	3599063	et	3	main
ja	doc_980560860252_item	3599067	et	3	main
p	doc_980560860252_item	3599072	et	4	main
aga	doc_980560860252_item	3599073	et	3	main
kell	doc_980560860252_item	3599078	et	3	main
on	doc_980560860252_item	3599090	et	4	main
rikutud	doc_980560860252_item	3599091	et	4	main
keel	doc_980560860246_item	3599032	et	4	main
aga	doc_980560860246_item	3599033	et	3	main
ma	doc_980560860246_item	3599034	et	3	main
ei	doc_980560860246_item	3599035	et	4	main
räägi	doc_980560860246_item	3599036	et	4	main
hea	doc_980560860246_item	3599037	et	4	main
eesti	doc_980560860246_item	3599038	et	4	main
keel	doc_980560860246_item	3599039	et	4	main
tere	doc_980560860246_item	3598954	et	3	main
kuidas	doc_980560860246_item	3598956	et	3	main
sa	doc_980560860246_item	3598957	et	3	main
läheb	doc_980560860246_item	3598958	et	3	main
mina	doc_980560860246_item	3598959	et	4	main
olen	doc_980560860246_item	3598960	et	3	main
anna	doc_980560860246_item	3598961	et	4	main
ma	doc_980560860246_item	3598966	et	3	main
kümmend	doc_980560860246_item	3598976	et	4	main
tartu	doc_980560860246_item	3598985	et	4	main
ülikoolis	doc_980560860246_item	3598986	et	4	main
ma	doc_980560860246_item	3598987	et	3	main
õpin	doc_980560860246_item	3598988	et	3	main
eesti	doc_980560860246_item	3598993	et	4	main
tere	doc_980560860246_item	3598997	et	3	main
nimi	doc_980560860246_item	3599000	et	3	main
lewis	doc_980560860246_item	3599002	et	4	main
inglismaa	doc_980560860246_item	3599016	et	4	main
ja	doc_980560860246_item	3599017	et	3	main
ma	doc_980560860246_item	3599018	et	3	main
olen	doc_980560860246_item	3599019	et	3	main
inglane	doc_980560860246_item	3599020	et	3	main
ma	doc_980560860246_item	3599021	et	3	main
ei	doc_980560860246_item	3599022	et	4	main
inglise	doc_980560860246_item	3599031	et	4	main
väljapoole	doc_980560860252_item	3599181	et	3	main
paikes	doc_980560860252_item	3599182	et	4	main
tule	doc_980560860252_item	3599183	et	4	main
varsti	doc_980560860252_item	3599184	et	3	main
p	doc_980560860252_item	3599185	et	4	main
tulen	doc_980560860252_item	3599186	et	3	main
tulen	doc_980560860252_item	3599187	et	3	main
kohe	doc_980560860252_item	3599188	et	4	main
kuuleb	doc_980560860252_item	3599045	et	3	main
k	doc_980560860252_item	3599046	et	4	main
k	doc_980560860252_item	3599057	et	4	main
näida	doc_980560860252_item	3599070	et	4	main
mulle	doc_980560860252_item	3599076	et	4	main
k	doc_980560860252_item	3599082	et	4	main
tule	doc_980560860252_item	3599092	et	4	main
lahti	doc_980560860252_item	3599101	et	4	main
autoga	doc_980560860252_item	3599106	et	3	main
k	doc_980560860252_item	3599107	et	4	main
noh	doc_980560860252_item	3599108	et	3	main
täna	doc_980560860252_item	3599109	et	4	main
hommikusel	doc_980560860252_item	3599110	et	4	main
minul	doc_980560860252_item	3599111	et	3	main
ei	doc_980560860252_item	3599112	et	4	main
olnud	doc_980560860252_item	3599113	et	4	main
mitte	doc_980560860252_item	3599114	et	3	main
midagi	doc_980560860252_item	3599115	et	4	main
mida	doc_980560860252_item	3599116	et	4	main
andekast	doc_980560860252_item	3599117	et	4	main
riietada	doc_980560860252_item	3599118	et	3	main
ja	doc_980560860252_item	3599119	et	3	main
seetõttu	doc_980560860252_item	3599120	et	3	main
ma	doc_980560860252_item	3599121	et	3	main
läksin	doc_980560860252_item	3599122	et	3	main
varal	doc_980560860252_item	3599123	et	4	main
hommikusel	doc_980560860252_item	3599124	et	4	main
ostma	doc_980560860252_item	3599125	et	3	main
uue	doc_980560860252_item	3599126	et	3	main
kleiti	doc_980560860252_item	3599127	et	4	main
ma	doc_980560860252_item	3599128	et	3	main
sobitin	doc_980560860252_item	3599129	et	4	main
mõned	doc_980560860252_item	3599130	et	3	main
kleitid	doc_980560860252_item	3599131	et	4	main
ja	doc_980560860252_item	3599132	et	3	main
leiutasin	doc_980560860252_item	3599134	et	3	main
lõpuks	doc_980560860252_item	3599133	et	4	main
asjalise	doc_980560860252_item	3599135	et	4	main
kui	doc_980560860252_item	3599136	et	3	main
olin	doc_980560860252_item	3599137	et	3	main
reisimas	doc_980560860252_item	3599138	et	3	main
suunas	doc_980560860252_item	3599139	et	4	main
intervjuu	doc_980560860252_item	3599140	et	4	main
päike	doc_980560860252_item	3599151	et	3	main
ja	doc_980560860252_item	3599153	et	3	main
sest	doc_980560860256_item	3599195	et	4	main
on	doc_980560860256_item	3599197	et	4	main
minul	doc_980560860252_item	3599142	et	3	main
nagu	doc_980560860252_item	3599156	et	3	main
oavarrest	doc_980560860252_item	3599157	et	4	main
ja	doc_980560860252_item	3599158	et	3	main
minu	doc_980560860252_item	3599159	et	3	main
uus	doc_980560860252_item	3599160	et	3	main
kleit	doc_980560860252_item	3599161	et	3	main
sais	doc_980560860252_item	3599162	et	4	main
märjaks	doc_980560860252_item	3599163	et	3	main
ja	doc_980560860252_item	3599164	et	3	main
siis	doc_980560860252_item	3599165	et	3	main
sellest	doc_980560860252_item	3599166	et	4	main
hakkas	doc_980560860252_item	3599167	et	3	main
värv	doc_980560860252_item	3599168	et	3	main
alla	doc_980560860252_item	3599169	et	3	main
vajuda	doc_980560860252_item	3599170	et	3	main
ma	doc_980560860252_item	3599171	et	3	main
olen	doc_980560860252_item	3599172	et	3	main
nagu	doc_980560860252_item	3599173	et	3	main
piret	doc_980560860252_item	3599174	et	4	main
tule	doc_980560860252_item	3599175	et	4	main
siia	doc_980560860252_item	3599176	et	4	main
ma	doc_980560860252_item	3599177	et	3	main
ootan	doc_980560860252_item	3599178	et	3	main
sind	doc_980560860252_item	3599179	et	4	main
teatri	doc_980560860252_item	3599180	et	3	main
harjutus	doc_980560860256_item	3599190	et	4	main
imelik	doc_980560860256_item	3599193	et	3	main
loomad	doc_980560860256_item	3599201	et	3	main
aga	doc_980560860256_item	3599202	et	3	main
nad	doc_980560860256_item	3599203	et	3	main
on	doc_980560860256_item	3599212	et	4	main
me	doc_980560860256_item	3599214	et	4	main
tean	doc_980560860256_item	3599215	et	3	main
et	doc_980560860256_item	3599216	et	3	main
vaga	doc_980560860256_item	3599261	et	4	main
lemmikloomad	doc_980560860256_item	3599283	et	3	main
on	doc_980560860256_item	3599285	et	4	main
loom	doc_980560860256_item	3599194	et	3	main
pruuned	doc_980560860256_item	3599209	et	4	main
ja	doc_980560860256_item	3599210	et	3	main
eestimaal	doc_980560860256_item	3599217	et	4	main
inimestele	doc_980560860256_item	3599218	et	3	main
meeldib	doc_980560860256_item	3599219	et	3	main
põder	doc_980560860256_item	3599220	et	3	main
juhtema	doc_980560860256_item	3599221	et	4	main
jänes	doc_980560860256_item	3599222	et	3	main
on	doc_980560860256_item	3599223	et	4	main
vaga	doc_980560860256_item	3599224	et	4	main
kiire	doc_980560860256_item	3599225	et	4	main
loom	doc_980560860256_item	3599226	et	3	main
nad	doc_980560860256_item	3599227	et	3	main
elavad	doc_980560860256_item	3599228	et	4	main
koobastel	doc_980560860256_item	3599229	et	3	main
ja	doc_980560860256_item	3599230	et	3	main
nad	doc_980560860256_item	3599231	et	3	main
on	doc_980560860256_item	3599232	et	4	main
kartlikud	doc_980560860256_item	3599233	et	3	main
nagu	doc_980560860256_item	3599234	et	3	main
põdri	doc_980560860256_item	3599235	et	4	main
tavaliselt	doc_980560860256_item	3599236	et	4	main
jänsed	doc_980560860256_item	3599237	et	4	main
on	doc_980560860256_item	3599238	et	4	main
väiksed	doc_980560860256_item	3599239	et	4	main
ja	doc_980560860256_item	3599240	et	3	main
pruunsed	doc_980560860256_item	3599241	et	4	main
karu	doc_980560860256_item	3599242	et	4	main
on	doc_980560860256_item	3599243	et	4	main
vaga	doc_980560860256_item	3599244	et	4	main
loomad	doc_980560860256_item	3599246	et	3	main
kardetavad	doc_980560860256_item	3599245	et	4	main
inimesti	doc_980560860256_item	3599250	et	4	main
suurem	doc_980560860256_item	3599256	et	4	main
karurahvastik	doc_980560860256_item	3599257	et	3	main
pikad	doc_980560860256_item	3599262	et	4	main
koerad	doc_980560860256_item	3599280	et	3	main
ja	doc_980560860256_item	3599284	et	3	main
tüüpe	doc_980560860256_item	3599287	et	3	main
koerade	doc_980560860256_item	3599288	et	3	main
ma	doc_980560860257_item	3599292	et	3	main
pean	doc_980560860257_item	3599293	et	4	main
tere	doc_980560860257_item	3599301	et	3	main
kostüümi	doc_980560860257_item	3599313	et	4	main
müüja	doc_980560860257_item	3599315	et	4	main
missugune	doc_980560860257_item	3599316	et	3	main
kostüüm	doc_980560860257_item	3599317	et	3	main
mul	doc_980560860257_item	3599323	et	3	main
seljas	doc_980560860257_item	3599325	et	4	main
ja	doc_980560860256_item	3599199	et	3	main
europas	doc_980560860256_item	3599258	et	4	main
karud	doc_980560860256_item	3599259	et	3	main
suured	doc_980560860256_item	3599263	et	3	main
koerad	doc_980560860256_item	3599266	et	3	main
võib-olla	doc_980560860256_item	3599268	et	3	main
sõbralikud	doc_980560860256_item	3599270	et	3	main
loomad	doc_980560860256_item	3599271	et	3	main
maailmas	doc_980560860256_item	3599272	et	3	main
aga	doc_980560860256_item	3599273	et	3	main
mulle	doc_980560860256_item	3599274	et	4	main
meeldib	doc_980560860256_item	3599275	et	3	main
kassid	doc_980560860256_item	3599276	et	3	main
populaarsed	doc_980560860256_item	3599282	et	3	main
mees	doc_980560860257_item	3599291	et	4	main
kostüümi	doc_980560860257_item	3599295	et	4	main
ostma	doc_980560860257_item	3599296	et	3	main
ma	doc_980560860257_item	3599297	et	3	main
lähen	doc_980560860257_item	3599298	et	3	main
päevast	doc_980560860257_item	3599302	et	4	main
osta	doc_980560860257_item	3599314	et	4	main
et	doc_980560860257_item	3599322	et	3	main
ta	doc_980560860257_item	3599330	et	4	main
peaksin	doc_980560860257_item	3599338	et	4	main
moodsi	doc_980560860257_item	3599345	et	4	main
meie	doc_980560860257_item	3599353	et	4	main
kallisam	doc_980560860257_item	3599363	et	4	main
000	doc_980560860257_item	3599367	et	2	main
mees	doc_980560860257_item	3599369	et	4	main
ma	doc_980560860257_item	3599370	et	3	main
ei	doc_980560860257_item	3599371	et	4	main
müüja	doc_980560860257_item	3599378	et	4	main
kas	doc_980560860257_item	3599389	et	3	main
te	doc_980560860257_item	3599406	et	4	main
arvate	doc_980560860257_item	3599407	et	3	main
jah	doc_980560860257_item	3599410	et	3	main
krooni	doc_980560860257_item	3599425	et	4	main
mees	doc_980560860257_item	3599426	et	4	main
1900	doc_980560860257_item	3599427	et	2	main
head	doc_980560860257_item	3599433	et	4	main
mees	doc_980560860257_item	3599438	et	4	main
moodne	doc_980560860257_item	3599446	et	3	main
on	doc_980560860257_item	3599450	et	4	main
moodne	doc_980560860257_item	3599452	et	3	main
päev	doc_574559240059_item	3599482	et	3	main
saan	doc_574559240059_item	3599485	et	4	main
on	doc_574559240059_item	3599501	et	4	main
hästi	doc_574559240059_item	3599502	et	3	main
võib-olla	doc_574559240059_item	3599517	et	3	main
lause	doc_574559240059_item	3599526	et	4	main
jalutades	doc_574559240059_item	3599557	et	3	main
selliste	doc_574559240059_item	3599563	et	4	main
reklaamide	doc_574559240059_item	3599564	et	3	main
üle	doc_574559240059_item	3599565	et	3	main
ajavad	doc_574559240059_item	3599569	et	4	main
on	doc_574559240059_item	3599572	et	4	main
saavad	doc_980560860256_item	3599249	et	4	main
on	doc_980560860256_item	3599254	et	4	main
kõige	doc_980560860256_item	3599255	et	4	main
parem	doc_980560860256_item	3599277	et	4	main
kui	doc_980560860256_item	3599278	et	3	main
koerad	doc_980560860256_item	3599279	et	3	main
pälju	doc_980560860256_item	3599286	et	4	main
dialoog	doc_980560860257_item	3599290	et	3	main
müüja	doc_980560860257_item	3599300	et	4	main
mees	doc_980560860257_item	3599320	et	4	main
on	doc_980560860257_item	3599343	et	4	main
aga	doc_980560860257_item	3599347	et	3	main
kõige	doc_980560860257_item	3599354	et	4	main
odavam	doc_980560860257_item	3599355	et	4	main
kostüüm	doc_980560860257_item	3599356	et	3	main
ja	doc_980560860257_item	3599360	et	3	main
kõige	doc_980560860257_item	3599362	et	4	main
krooni	doc_980560860257_item	3599368	et	4	main
2000	doc_980560860257_item	3599376	et	2	main
krooni	doc_980560860257_item	3599377	et	4	main
sobiks	doc_980560860257_item	3599382	et	4	main
mida	doc_980560860257_item	3599405	et	4	main
mees	doc_980560860257_item	3599409	et	4	main
et	doc_980560860257_item	3599413	et	3	main
kostüümi	doc_980560860257_item	3599415	et	4	main
mulle	doc_980560860257_item	3599417	et	4	main
ma	doc_980560860257_item	3599418	et	3	main
hea	doc_980560860257_item	3599423	et	4	main
1900	doc_980560860257_item	3599424	et	2	main
aitah	doc_980560860257_item	3599432	et	4	main
aega	doc_980560860257_item	3599437	et	4	main
vaga	doc_980560860257_item	3599445	et	4	main
mehel	doc_980560860257_item	3599449	et	3	main
harjutus	doc_574559240059_item	3599478	et	4	main
tõttu	doc_574559240059_item	3599489	et	4	main
reklaame	doc_574559240059_item	3599499	et	3	main
nende	doc_574559240059_item	3599511	et	4	main
jaoks	doc_574559240059_item	3599512	et	4	main
3	doc_574559240059_item	3599516	et	2	main
mingisugune	doc_574559240059_item	3599520	et	3	main
nali	doc_574559240059_item	3599521	et	3	main
või	doc_574559240059_item	3599529	et	4	main
mis	doc_574559240059_item	3599566	et	4	main
on	doc_574559240059_item	3599588	et	4	main
aega	doc_574559240059_item	3599596	et	4	main
võib-olla	doc_574559240059_item	3599598	et	3	main
nali	doc_574559240059_item	3599602	et	3	main
või	doc_574559240059_item	3599603	et	4	main
olnud	doc_574559240059_item	3599641	et	4	main
reede	doc_35015649953_item	3599647	et	4	main
eesti	doc_35015649953_item	3599653	et	4	main
tund	doc_35015649953_item	3599655	et	3	main
laupäev	doc_35015649953_item	3599657	et	3	main
me	doc_35015649953_item	3599664	et	4	main
observatooriumi	doc_35015649953_item	3599666	et	4	main
vaatasime	doc_35015649953_item	3599667	et	3	main
maastikku	doc_35015649953_item	3599668	et	4	main
ma	doc_35015649953_item	3599669	et	3	main
meili	doc_35015649953_item	3599682	et	4	main
minu	doc_35015649953_item	3599683	et	3	main
sõbrale	doc_35015649953_item	3599684	et	3	main
sõbra	doc_35015649953_item	3599689	et	3	main
pühapäev	doc_35015649953_item	3599692	et	3	main
leiba	doc_35015649953_item	3599746	et	4	main
2304	doc_35015649953_item	3599749	et	2	main
keele	doc_35015649953_item	3599754	et	4	main
päevik	doc_35015649954_item	3599783	et	3	main
16c	doc_35015649954_item	3599795	et	4	main
pühapäev	doc_35015649954_item	3599807	et	3	main
ma	doc_35015649954_item	3599811	et	3	main
ja	doc_35015649954_item	3599840	et	3	main
laulsid	doc_35015649954_item	3599847	et	4	main
paisteline	doc_35015649954_item	3599854	et	4	main
ma	doc_35015649954_item	3599855	et	3	main
ujusin	doc_35015649954_item	3599856	et	3	main
20	doc_35015649954_item	3599883	et	2	main
külastasin	doc_35015649954_item	3599887	et	3	main
tallinna	doc_35015649954_item	3599888	et	4	main
vaatasin	doc_35015649954_item	3599894	et	3	main
ta	doc_786864950072_item	3599922	et	4	main
kadri	doc_786864950072_item	3599925	et	4	main
aastat	doc_786864950072_item	3599928	et	3	main
ükses	doc_786864950072_item	3599958	et	3	main
mees	doc_980560860257_item	3599454	et	4	main
oh	doc_980560860257_item	3599455	et	3	main
issand	doc_980560860257_item	3599456	et	4	main
vihm	doc_980560860257_item	3599457	et	3	main
hakkab	doc_980560860257_item	3599458	et	3	main
sadata	doc_980560860257_item	3599459	et	4	main
ma	doc_980560860257_item	3599460	et	3	main
pean	doc_980560860257_item	3599461	et	4	main
koju	doc_980560860257_item	3599462	et	3	main
joosta	doc_980560860257_item	3599463	et	4	main
mees	doc_980560860257_item	3599464	et	4	main
nüüd	doc_980560860257_item	3599465	et	4	main
minu	doc_980560860257_item	3599466	et	3	main
uus	doc_980560860257_item	3599467	et	3	main
kostüüm	doc_980560860257_item	3599468	et	3	main
on	doc_980560860257_item	3599469	et	4	main
must	doc_980560860257_item	3599470	et	4	main
nagu	doc_980560860257_item	3599471	et	3	main
mu	doc_980560860257_item	3599472	et	3	main
vana	doc_980560860257_item	3599473	et	4	main
kostüüm	doc_980560860257_item	3599474	et	3	main
on	doc_980560860257_item	3599475	et	4	main
varisemine	doc_980560860257_item	3599476	et	4	main
ma	doc_980560860257_item	3599304	et	3	main
teid	doc_980560860257_item	3599306	et	4	main
kostüüm	doc_980560860257_item	3599321	et	3	main
on	doc_980560860257_item	3599324	et	4	main
on	doc_980560860257_item	3599326	et	4	main
mu	doc_980560860257_item	3599327	et	3	main
vana	doc_980560860257_item	3599333	et	4	main
ja	doc_980560860257_item	3599334	et	3	main
palju	doc_980560860257_item	3599344	et	4	main
maksta	doc_980560860257_item	3599352	et	4	main
1725	doc_980560860257_item	3599358	et	2	main
meie	doc_980560860257_item	3599361	et	4	main
20	doc_980560860257_item	3599366	et	2	main
tahtnud	doc_980560860257_item	3599372	et	4	main
okei	doc_980560860257_item	3599379	et	4	main
see	doc_980560860257_item	3599380	et	3	main
teile	doc_980560860257_item	3599383	et	4	main
maksab	doc_980560860257_item	3599385	et	3	main
ma	doc_980560860257_item	3599411	et	3	main
vaga	doc_980560860257_item	3599422	et	4	main
müüja	doc_980560860257_item	3599429	et	4	main
palun	doc_980560860257_item	3599430	et	3	main
müüja	doc_980560860257_item	3599435	et	4	main
kostüüm	doc_980560860257_item	3599443	et	3	main
on	doc_980560860257_item	3599444	et	4	main
vaga	doc_980560860257_item	3599451	et	4	main
kostüüm	doc_980560860257_item	3599453	et	3	main
ainus	doc_980560860257_item	3599328	et	4	main
kostüüm	doc_980560860257_item	3599329	et	3	main
must	doc_980560860257_item	3599335	et	4	main
sellepärast	doc_980560860257_item	3599336	et	3	main
ma	doc_980560860257_item	3599337	et	3	main
kostüümi	doc_980560860257_item	3599340	et	4	main
kui	doc_980560860257_item	3599348	et	3	main
krooni	doc_980560860257_item	3599359	et	4	main
kostüüm	doc_980560860257_item	3599364	et	3	main
osta	doc_980560860257_item	3599373	et	4	main
kostüüm	doc_980560860257_item	3599381	et	3	main
ja	doc_980560860257_item	3599384	et	3	main
ainult	doc_980560860257_item	3599386	et	4	main
1900	doc_980560860257_item	3599387	et	2	main
krooni	doc_980560860257_item	3599388	et	4	main
kostüümist	doc_980560860257_item	3599408	et	4	main
seda	doc_980560860257_item	3599414	et	3	main
sobib	doc_980560860257_item	3599416	et	3	main
teda	doc_980560860257_item	3599420	et	4	main
mees	doc_980560860257_item	3599431	et	4	main
head	doc_980560860257_item	3599436	et	4	main
naine	doc_980560860257_item	3599447	et	3	main
iga	doc_574559240059_item	3599481	et	4	main
jalutades	doc_574559240059_item	3599484	et	3	main
rõõmu	doc_574559240059_item	3599486	et	4	main
selliste	doc_574559240059_item	3599487	et	4	main
reklaamide	doc_574559240059_item	3599488	et	3	main
lõbusaid	doc_574559240059_item	3599498	et	3	main
aega	doc_574559240059_item	3599515	et	4	main
või	doc_574559240059_item	3599522	et	4	main
muu	doc_574559240059_item	3599523	et	4	main
mitmetähenduslik	doc_574559240059_item	3599524	et	3	main
muul	doc_574559240059_item	3599530	et	4	main
taval	doc_574559240059_item	3599531	et	3	main
naerma	doc_574559240059_item	3599568	et	3	main
need	doc_574559240059_item	3599571	et	3	main
ilmneb	doc_574559240059_item	3599590	et	3	main
3	doc_574559240059_item	3599597	et	2	main
käisin	doc_35015649953_item	3599649	et	3	main
oleviste	doc_35015649953_item	3599660	et	4	main
ostasin	doc_35015649953_item	3599670	et	4	main
varssavisse	doc_35015649953_item	3599673	et	4	main
tund	doc_35015649953_item	3599755	et	3	main
magasin	doc_35015649954_item	3599786	et	4	main
ühest	doc_35015649954_item	3599788	et	4	main
ilm	doc_35015649954_item	3599790	et	3	main
ja	doc_35015649954_item	3599797	et	3	main
laine	doc_35015649954_item	3599809	et	4	main
jalutasime	doc_35015649954_item	3599812	et	3	main
õhtust	doc_35015649954_item	3599814	et	4	main
ma	doc_35015649954_item	3599815	et	3	main
üliopilane	doc_35015649954_item	3599846	et	4	main
paikese	doc_35015649954_item	3599853	et	4	main
vana	doc_35015649954_item	3599885	et	4	main
vangla	doc_35015649954_item	3599889	et	4	main
õpetajaga	doc_35015649954_item	3599890	et	4	main
ja	doc_35015649954_item	3599891	et	3	main
tallinna	doc_35015649954_item	3599896	et	4	main
maksab	doc_980560860257_item	3599365	et	3	main
rohkem	doc_980560860257_item	3599374	et	4	main
kui	doc_980560860257_item	3599375	et	3	main
te	doc_980560860257_item	3599390	et	4	main
tahaksite	doc_980560860257_item	3599391	et	3	main
selga	doc_980560860257_item	3599392	et	4	main
proovida	doc_980560860257_item	3599393	et	3	main
jah	doc_980560860257_item	3599395	et	3	main
mees	doc_980560860257_item	3599394	et	4	main
ma	doc_980560860257_item	3599396	et	3	main
proovin	doc_980560860257_item	3599397	et	3	main
selga	doc_980560860257_item	3599398	et	4	main
kostüümi	doc_980560860257_item	3599399	et	4	main
müüja	doc_980560860257_item	3599400	et	4	main
kostüüm	doc_980560860257_item	3599401	et	3	main
tõepoolest	doc_980560860257_item	3599402	et	3	main
sobib	doc_980560860257_item	3599403	et	3	main
teile	doc_980560860257_item	3599404	et	4	main
tean	doc_980560860257_item	3599412	et	3	main
ostan	doc_980560860257_item	3599419	et	3	main
müüja	doc_980560860257_item	3599421	et	4	main
krooni	doc_980560860257_item	3599428	et	4	main
aega	doc_980560860257_item	3599434	et	4	main
mulle	doc_980560860257_item	3599439	et	4	main
meeldib	doc_980560860257_item	3599440	et	3	main
mu	doc_980560860257_item	3599441	et	3	main
uus	doc_980560860257_item	3599442	et	3	main
see	doc_980560860257_item	3599448	et	3	main
1	doc_574559240059_item	3599479	et	2	main
tänavatel	doc_574559240059_item	3599483	et	4	main
2	doc_574559240059_item	3599493	et	2	main
nad	doc_574559240059_item	3599494	et	3	main
on	doc_574559240059_item	3599495	et	4	main
geniaalseid	doc_574559240059_item	3599496	et	3	main
ja	doc_574559240059_item	3599497	et	3	main
pikale	doc_574559240059_item	3599504	et	4	main
on	doc_574559240059_item	3599513	et	4	main
sõna	doc_574559240059_item	3599525	et	4	main
huvitav	doc_574559240059_item	3599532	et	4	main
asi	doc_574559240059_item	3599533	et	4	main
4	doc_574559240059_item	3599534	et	2	main
mind	doc_574559240059_item	3599567	et	4	main
2	doc_574559240059_item	3599570	et	2	main
on	doc_574559240059_item	3599578	et	4	main
on	doc_574559240059_item	3599583	et	4	main
palju	doc_574559240059_item	3599584	et	4	main
näha	doc_574559240059_item	3599589	et	3	main
jaoks	doc_574559240059_item	3599593	et	4	main
on	doc_574559240059_item	3599594	et	4	main
on	doc_574559240059_item	3599599	et	4	main
mingisugune	doc_574559240059_item	3599601	et	3	main
muu	doc_574559240059_item	3599604	et	4	main
on	doc_574559240059_item	3599640	et	4	main
geniaalsed	doc_574559240059_item	3599573	et	3	main
ja	doc_574559240059_item	3599574	et	3	main
lõbusad	doc_574559240059_item	3599575	et	3	main
reklaamid	doc_574559240059_item	3599576	et	4	main
mis	doc_574559240059_item	3599577	et	4	main
peaaegu	doc_574559240059_item	3599480	et	3	main
mis	doc_574559240059_item	3599490	et	4	main
naerma	doc_574559240059_item	3599491	et	3	main
panevad	doc_574559240059_item	3599492	et	4	main
mis	doc_574559240059_item	3599500	et	4	main
tehtud	doc_574559240059_item	3599503	et	4	main
mõeldud	doc_574559240059_item	3599505	et	4	main
ja	doc_574559240059_item	3599506	et	3	main
millest	doc_574559240059_item	3599507	et	3	main
on	doc_574559240059_item	3599508	et	4	main
näha	doc_574559240059_item	3599509	et	3	main
et	doc_574559240059_item	3599510	et	3	main
kulutatud	doc_574559240059_item	3599514	et	4	main
neis	doc_574559240059_item	3599518	et	4	main
on	doc_574559240059_item	3599519	et	4	main
või	doc_574559240059_item	3599527	et	4	main
pilt	doc_574559240059_item	3599528	et	3	main
riidereklaamid	doc_574559240059_item	3599535	et	3	main
võivad	doc_574559240059_item	3599536	et	4	main
selliseid	doc_574559240059_item	3599537	et	4	main
olla	doc_574559240059_item	3599538	et	3	main
aga	doc_574559240059_item	3599539	et	3	main
muud	doc_574559240059_item	3599540	et	4	main
ka	doc_574559240059_item	3599541	et	3	main
5	doc_574559240059_item	3599542	et	2	main
tavaliselt	doc_574559240059_item	3599543	et	4	main
nendest	doc_574559240059_item	3599544	et	4	main
on	doc_574559240059_item	3599545	et	4	main
näha	doc_574559240059_item	3599546	et	3	main
et	doc_574559240059_item	3599547	et	3	main
nende	doc_574559240059_item	3599548	et	4	main
tegemine	doc_574559240059_item	3599549	et	4	main
ja	doc_574559240059_item	3599550	et	3	main
väljaandmine	doc_574559240059_item	3599551	et	3	main
maksab	doc_574559240059_item	3599552	et	3	main
väga	doc_574559240059_item	3599553	et	3	main
palju	doc_574559240059_item	3599554	et	4	main
1	doc_574559240059_item	3599555	et	2	main
tänavatel	doc_574559240059_item	3599556	et	4	main
tunnen	doc_574559240059_item	3599558	et	3	main
peaaegu	doc_574559240059_item	3599559	et	3	main
iga	doc_574559240059_item	3599560	et	4	main
päev	doc_574559240059_item	3599561	et	3	main
rõõmu	doc_574559240059_item	3599562	et	4	main
hästi	doc_574559240059_item	3599579	et	3	main
tehtud	doc_574559240059_item	3599580	et	4	main
üle	doc_574559240059_item	3599582	et	3	main
mõeldud	doc_574559240059_item	3599585	et	4	main
millest	doc_574559240059_item	3599587	et	3	main
nende	doc_574559240059_item	3599592	et	4	main
kulutatud	doc_574559240059_item	3599595	et	4	main
neis	doc_574559240059_item	3599600	et	4	main
mitmetähenduslik	doc_574559240059_item	3599605	et	3	main
sõna	doc_574559240059_item	3599606	et	4	main
lause	doc_574559240059_item	3599607	et	4	main
või	doc_574559240059_item	3599608	et	4	main
pilt	doc_574559240059_item	3599609	et	3	main
või	doc_574559240059_item	3599610	et	4	main
muul	doc_574559240059_item	3599611	et	4	main
moel	doc_574559240059_item	3599612	et	4	main
viisil	doc_574559240059_item	3599613	et	4	main
huvitav	doc_574559240059_item	3599614	et	4	main
asi	doc_574559240059_item	3599615	et	4	main
lähenemine	doc_574559240059_item	3599616	et	4	main
4	doc_574559240059_item	3599617	et	2	main
riide	doc_574559240059_item	3599618	et	4	main
riietereklaamid	doc_574559240059_item	3599619	et	3	main
võivad	doc_574559240059_item	3599620	et	4	main
olla	doc_574559240059_item	3599621	et	3	main
selliseid	doc_574559240059_item	3599622	et	4	main
aga	doc_574559240059_item	3599623	et	3	main
ka	doc_574559240059_item	3599624	et	3	main
muud	doc_574559240059_item	3599625	et	4	main
teised	doc_574559240059_item	3599626	et	4	main
5	doc_574559240059_item	3599627	et	2	main
tavaliselt	doc_574559240059_item	3599628	et	4	main
on	doc_574559240059_item	3599629	et	4	main
nendest	doc_574559240059_item	3599630	et	4	main
näha	doc_574559240059_item	3599631	et	3	main
et	doc_574559240059_item	3599632	et	3	main
nende	doc_574559240059_item	3599633	et	4	main
tegemine	doc_574559240059_item	3599634	et	4	main
ja	doc_574559240059_item	3599635	et	3	main
väljaandmine	doc_574559240059_item	3599636	et	3	main
maksab	doc_574559240059_item	3599637	et	3	main
väga	doc_574559240059_item	3599638	et	3	main
palju	doc_574559240059_item	3599639	et	4	main
mille	doc_574559240059_item	3599581	et	3	main
ja	doc_574559240059_item	3599586	et	3	main
et	doc_574559240059_item	3599591	et	3	main
väga	doc_574559240059_item	3599642	et	3	main
kallis	doc_574559240059_item	3599643	et	4	main
1804	doc_35015649953_item	3599646	et	2	main
mul	doc_35015649953_item	3599651	et	3	main
ma	doc_35015649953_item	3599658	et	3	main
kirikusse	doc_35015649953_item	3599661	et	4	main
sõbraga	doc_35015649953_item	3599663	et	3	main
bussi	doc_35015649953_item	3599671	et	4	main
sest	doc_35015649953_item	3599685	et	4	main
ma	doc_35015649953_item	3599693	et	3	main
kell	doc_35015649953_item	3599747	et	3	main
kolmapäev	doc_35015649953_item	3599750	et	3	main
oli	doc_35015649953_item	3599752	et	3	main
kella	doc_35015649954_item	3599787	et	4	main
viieni	doc_35015649954_item	3599789	et	3	main
sõbrad	doc_35015649954_item	3599798	et	3	main
leidi	doc_35015649954_item	3599808	et	4	main
vanalinnas	doc_35015649954_item	3599813	et	4	main
ma	doc_35015649954_item	3599841	et	3	main
üliopilanen	doc_35015649954_item	3599843	et	4	main
nädale	doc_35015649954_item	3599844	et	4	main
laul	doc_35015649954_item	3599849	et	4	main
teisipäev	doc_35015649954_item	3599850	et	3	main
see	doc_35015649954_item	3599851	et	3	main
hummekusts	doc_35015649954_item	3599858	et	4	main
ma	doc_35015649954_item	3599859	et	3	main
ostsin	doc_35015649954_item	3599860	et	3	main
üks	doc_35015649954_item	3599861	et	3	main
tomatit	doc_35015649954_item	3599862	et	3	main
üks	doc_35015649954_item	3599863	et	3	main
üks	doc_35015649954_item	3599866	et	3	main
üliopilanen	doc_35015649954_item	3599892	et	4	main
ma	doc_35015649954_item	3599893	et	3	main
ülikooli	doc_35015649954_item	3599897	et	4	main
ma	doc_35015649954_item	3599899	et	3	main
olen	doc_35015649954_item	3599900	et	3	main
õppinud	doc_35015649954_item	3599901	et	4	main
eesti	doc_35015649954_item	3599902	et	4	main
keelt	doc_35015649954_item	3599903	et	4	main
kohta	doc_786864950072_item	3599912	et	4	main
see	doc_786864950072_item	3599913	et	3	main
nime	doc_786864950072_item	3599918	et	4	main
on	doc_786864950072_item	3599919	et	4	main
on	doc_786864950072_item	3599926	et	4	main
vana	doc_786864950072_item	3599929	et	4	main
ta	doc_786864950072_item	3599930	et	4	main
ja	doc_786864950072_item	3599954	et	3	main
ta	doc_786864950072_item	3599955	et	4	main
ema	doc_786864950072_item	3599956	et	4	main
on	doc_786864950072_item	3599963	et	4	main
perekond	doc_786864950072_item	3599975	et	3	main
aga	doc_786864950072_item	3599981	et	3	main
ei	doc_786864950072_item	3599983	et	4	main
pea	doc_786864950072_item	3599984	et	4	main
pildi	doc_786864950073_item	3600006	et	4	main
ja	doc_786864950073_item	3600011	et	3	main
laps	doc_786864950073_item	3600013	et	4	main
vahur	doc_786864950073_item	3600023	et	4	main
vahur	doc_786864950073_item	3600024	et	4	main
on	doc_786864950073_item	3600025	et	4	main
käi	doc_786864950073_item	3600029	et	4	main
koolis	doc_786864950073_item	3600030	et	4	main
kaheksa	doc_786864950073_item	3600033	et	4	main
praegu	doc_786864950073_item	3600038	et	3	main
vara	doc_786864950073_item	3600049	et	4	main
vahur	doc_786864950073_item	3600050	et	4	main
armastab	doc_786864950073_item	3600051	et	3	main
mängida	doc_786864950073_item	3600052	et	3	main
ta	doc_786864950073_item	3600053	et	4	main
vahur	doc_786864950073_item	3600066	et	4	main
nad	doc_786864950073_item	3600067	et	3	main
viisteist	doc_786864950073_item	3600072	et	4	main
aastat	doc_786864950073_item	3600073	et	3	main
ilusas	doc_786864950073_item	3600083	et	3	main
vana	doc_786864950073_item	3600093	et	4	main
ülikoolilinn	doc_786864950073_item	3600094	et	3	main
kirjeldus	doc_786864950074_item	3600098	et	4	main
ma	doc_35015649953_item	3599730	et	3	main
läksin	doc_35015649953_item	3599731	et	3	main
poodisse	doc_35015649953_item	3599732	et	4	main
ja	doc_35015649953_item	3599733	et	3	main
ostasin	doc_35015649953_item	3599734	et	4	main
liha	doc_35015649953_item	3599735	et	4	main
leiba	doc_35015649953_item	3599736	et	4	main
mahla	doc_35015649953_item	3599737	et	4	main
piima	doc_35015649953_item	3599738	et	4	main
kartulit	doc_35015649953_item	3599739	et	3	main
ja	doc_35015649953_item	3599740	et	3	main
porgandit	doc_35015649953_item	3599741	et	3	main
ma	doc_35015649953_item	3599742	et	3	main
sõin	doc_35015649953_item	3599743	et	3	main
köögiviljasuppi	doc_35015649953_item	3599744	et	4	main
ma	doc_35015649953_item	3599648	et	3	main
oli	doc_35015649953_item	3599652	et	3	main
keele	doc_35015649953_item	3599654	et	4	main
1904	doc_35015649953_item	3599656	et	2	main
1904	doc_35015649953_item	3599686	et	2	main
oli	doc_35015649953_item	3599687	et	3	main
sünnipäev	doc_35015649953_item	3599690	et	3	main
olin	doc_35015649953_item	3599694	et	3	main
kodus	doc_35015649953_item	3599695	et	4	main
hommikust	doc_35015649953_item	3599696	et	4	main
õhtuni	doc_35015649953_item	3599697	et	3	main
ma	doc_35015649953_item	3599698	et	3	main
vaatasin	doc_35015649953_item	3599699	et	3	main
hiina	doc_35015649953_item	3599700	et	3	main
filmi	doc_35015649953_item	3599701	et	4	main
ma	doc_35015649953_item	3599702	et	3	main
mängisin	doc_35015649953_item	3599703	et	3	main
arvuti	doc_35015649953_item	3599704	et	4	main
2104	doc_35015649953_item	3599705	et	2	main
esmaspäev	doc_35015649953_item	3599706	et	3	main
mul	doc_35015649953_item	3599707	et	3	main
oli	doc_35015649953_item	3599708	et	3	main
inglise	doc_35015649953_item	3599709	et	4	main
ja	doc_35015649953_item	3599710	et	3	main
vene	doc_35015649953_item	3599711	et	4	main
keele	doc_35015649953_item	3599712	et	4	main
tunnid	doc_35015649953_item	3599713	et	3	main
ma	doc_35015649953_item	3599714	et	3	main
aratasin	doc_35015649953_item	3599715	et	4	main
kell	doc_35015649953_item	3599716	et	3	main
7	doc_35015649953_item	3599717	et	2	main
ules	doc_35015649953_item	3599718	et	3	main
ma	doc_35015649953_item	3599719	et	3	main
vaatasin	doc_35015649953_item	3599720	et	3	main
korea	doc_35015649953_item	3599721	et	4	main
filmi	doc_35015649953_item	3599722	et	4	main
2204	doc_35015649953_item	3599723	et	2	main
teisepäev	doc_35015649953_item	3599724	et	3	main
mul	doc_35015649953_item	3599725	et	3	main
oli	doc_35015649953_item	3599726	et	3	main
inglise	doc_35015649953_item	3599727	et	4	main
keele	doc_35015649953_item	3599728	et	4	main
tund	doc_35015649953_item	3599729	et	3	main
päevik	doc_35015649953_item	3599645	et	3	main
ulikoolis	doc_35015649953_item	3599650	et	4	main
käisin	doc_35015649953_item	3599659	et	3	main
minu	doc_35015649953_item	3599662	et	3	main
ronisime	doc_35015649953_item	3599665	et	3	main
piletit	doc_35015649953_item	3599672	et	3	main
vilniust	doc_35015649953_item	3599674	et	4	main
ma	doc_35015649953_item	3599675	et	3	main
saatsin	doc_35015649953_item	3599676	et	3	main
postkaarti	doc_35015649953_item	3599677	et	4	main
minu	doc_35015649953_item	3599678	et	3	main
perekondale	doc_35015649953_item	3599679	et	4	main
ma	doc_35015649953_item	3599680	et	3	main
saatsin	doc_35015649953_item	3599681	et	3	main
minu	doc_35015649953_item	3599688	et	3	main
2004	doc_35015649953_item	3599691	et	2	main
ja	doc_35015649953_item	3599745	et	3	main
8	doc_35015649953_item	3599748	et	2	main
vene	doc_35015649953_item	3599753	et	4	main
ma	doc_35015649954_item	3599785	et	3	main
oli	doc_35015649954_item	3599791	et	3	main
ma	doc_35015649954_item	3599796	et	3	main
randle	doc_35015649954_item	3599800	et	4	main
meie	doc_35015649954_item	3599802	et	4	main
sõbrad	doc_35015649954_item	3599806	et	3	main
eesti	doc_35015649954_item	3599845	et	4	main
on	doc_35015649954_item	3599852	et	4	main
leiva	doc_35015649954_item	3599864	et	3	main
ja	doc_35015649954_item	3599865	et	3	main
kirjeldus	doc_786864950072_item	3599907	et	4	main
10	doc_786864950072_item	3599909	et	2	main
lauset	doc_786864950072_item	3599910	et	3	main
on	doc_786864950072_item	3599923	et	4	main
tüdruk	doc_786864950072_item	3599924	et	3	main
kolm	doc_786864950072_item	3599927	et	3	main
elavad	doc_786864950072_item	3599957	et	4	main
olla	doc_786864950072_item	3599960	et	3	main
teda	doc_786864950072_item	3599972	et	4	main
ema	doc_786864950072_item	3599979	et	4	main
kadri	doc_786864950072_item	3599982	et	4	main
väike	doc_786864950073_item	3600010	et	4	main
ilus	doc_786864950073_item	3600012	et	4	main
ta	doc_786864950073_item	3600014	et	4	main
on	doc_786864950073_item	3600032	et	4	main
vana	doc_786864950073_item	3600035	et	4	main
ta	doc_786864950073_item	3600036	et	4	main
ei	doc_786864950073_item	3600039	et	4	main
ta	doc_786864950073_item	3600041	et	4	main
laps	doc_786864950073_item	3600056	et	4	main
venda	doc_786864950073_item	3600060	et	4	main
aga	doc_786864950073_item	3600061	et	3	main
nad	doc_786864950073_item	3600062	et	3	main
on	doc_786864950073_item	3600063	et	4	main
vanemad	doc_786864950073_item	3600064	et	4	main
kui	doc_786864950073_item	3600065	et	3	main
on	doc_786864950073_item	3600071	et	4	main
jaan	doc_786864950073_item	3600076	et	3	main
on	doc_786864950073_item	3600077	et	4	main
ja	doc_786864950073_item	3600084	et	3	main
maja	doc_786864950073_item	3600088	et	4	main
tartus	doc_786864950073_item	3600090	et	3	main
sest	doc_786864950074_item	3600123	et	4	main
ta	doc_786864950074_item	3600124	et	4	main
magada	doc_786864950074_item	3600130	et	3	main
mängida	doc_786864950074_item	3600132	et	3	main
on	doc_786864950074_item	3600134	et	4	main
sinise	doc_786864950074_item	3600141	et	4	main
nimi	doc_786864950074_item	3600145	et	3	main
kaheksa	doc_786864950074_item	3600151	et	4	main
aastat	doc_786864950074_item	3600152	et	3	main
ta	doc_786864950074_item	3600154	et	4	main
on	doc_786864950074_item	3600155	et	4	main
ja	doc_786864950074_item	3600162	et	3	main
10	doc_786864950075_item	3600170	et	2	main
kohta	doc_786864950075_item	3600173	et	4	main
on	doc_786864950075_item	3600178	et	4	main
sõbrid	doc_786864950075_item	3600179	et	4	main
nemad	doc_786864950075_item	3600180	et	3	main
nende	doc_786864950075_item	3600213	et	4	main
on	doc_786864950075_item	3600224	et	4	main
puud	doc_786864950075_item	3600225	et	4	main
on	doc_786864950075_item	3600227	et	4	main
pere	doc_786864950076_item	3600244	et	4	main
maja	doc_786864950076_item	3600250	et	4	main
mul	doc_35015649953_item	3599751	et	3	main
ma	doc_35015649953_item	3599756	et	3	main
käisin	doc_35015649953_item	3599757	et	3	main
ulikoolis	doc_35015649953_item	3599758	et	4	main
kell	doc_35015649953_item	3599759	et	3	main
6	doc_35015649953_item	3599760	et	2	main
õhtul	doc_35015649953_item	3599761	et	3	main
vene	doc_35015649953_item	3599762	et	4	main
keele	doc_35015649953_item	3599763	et	4	main
tund	doc_35015649953_item	3599764	et	3	main
algas	doc_35015649953_item	3599765	et	3	main
kell	doc_35015649953_item	3599766	et	3	main
6	doc_35015649953_item	3599767	et	2	main
pärast	doc_35015649953_item	3599768	et	4	main
vene	doc_35015649953_item	3599769	et	4	main
keele	doc_35015649953_item	3599770	et	4	main
tund	doc_35015649953_item	3599771	et	3	main
ma	doc_35015649953_item	3599772	et	3	main
läksin	doc_35015649953_item	3599773	et	3	main
majja	doc_35015649953_item	3599774	et	3	main
tagasi	doc_35015649953_item	3599775	et	3	main
sõin	doc_35015649953_item	3599776	et	3	main
õhtusööki	doc_35015649953_item	3599777	et	4	main
ja	doc_35015649953_item	3599778	et	3	main
magasin	doc_35015649953_item	3599779	et	4	main
kell	doc_35015649953_item	3599780	et	3	main
12	doc_35015649953_item	3599781	et	2	main
pudeli	doc_35015649954_item	3599867	et	3	main
vesi	doc_35015649954_item	3599868	et	4	main
õhtust	doc_35015649954_item	3599869	et	4	main
mu	doc_35015649954_item	3599870	et	3	main
sõbrad	doc_35015649954_item	3599871	et	3	main
ja	doc_35015649954_item	3599872	et	3	main
ma	doc_35015649954_item	3599873	et	3	main
käisime	doc_35015649954_item	3599874	et	3	main
kontserte	doc_35015649954_item	3599875	et	3	main
kolmapäev	doc_35015649954_item	3599876	et	3	main
mu	doc_35015649954_item	3599877	et	3	main
õde	doc_35015649954_item	3599878	et	4	main
on	doc_35015649954_item	3599879	et	4	main
sünnipäevaks	doc_35015649954_item	3599880	et	3	main
ta	doc_35015649954_item	3599881	et	4	main
on	doc_35015649954_item	3599882	et	4	main
laupäev	doc_35015649954_item	3599784	et	3	main
ilus	doc_35015649954_item	3599792	et	4	main
sooja	doc_35015649954_item	3599793	et	4	main
on	doc_35015649954_item	3599794	et	4	main
jalutasime	doc_35015649954_item	3599799	et	3	main
kui	doc_35015649954_item	3599801	et	3	main
külastanud	doc_35015649954_item	3599803	et	4	main
olime	doc_35015649954_item	3599804	et	3	main
teine	doc_35015649954_item	3599805	et	3	main
ja	doc_35015649954_item	3599810	et	3	main
vaatasin	doc_35015649954_item	3599816	et	3	main
filmi	doc_35015649954_item	3599817	et	4	main
blow	doc_35015649954_item	3599818	et	4	main
sõbradga	doc_35015649954_item	3599819	et	4	main
päev	doc_35015649954_item	3599820	et	3	main
olin	doc_35015649954_item	3599821	et	3	main
selge	doc_35015649954_item	3599822	et	4	main
ja	doc_35015649954_item	3599823	et	3	main
viihma	doc_35015649954_item	3599824	et	4	main
ei	doc_35015649954_item	3599825	et	4	main
saja	doc_35015649954_item	3599826	et	4	main
ma	doc_35015649954_item	3599827	et	3	main
kirjutasin	doc_35015649954_item	3599828	et	3	main
kodutöö	doc_35015649954_item	3599829	et	4	main
sotsiaaltöö	doc_35015649954_item	3599830	et	4	main
tundile	doc_35015649954_item	3599831	et	4	main
esmaspäev	doc_35015649954_item	3599832	et	3	main
ma	doc_35015649954_item	3599833	et	3	main
õppisin	doc_35015649954_item	3599834	et	3	main
eesti	doc_35015649954_item	3599835	et	4	main
keelt	doc_35015649954_item	3599836	et	4	main
ja	doc_35015649954_item	3599837	et	3	main
sotsiaaltöö	doc_35015649954_item	3599838	et	4	main
sõbrad	doc_35015649954_item	3599839	et	3	main
käisime	doc_35015649954_item	3599842	et	3	main
eesti	doc_35015649954_item	3599848	et	4	main
ujumisbasseins	doc_35015649954_item	3599857	et	4	main
aastat	doc_35015649954_item	3599884	et	3	main
ma	doc_35015649954_item	3599886	et	3	main
film	doc_35015649954_item	3599895	et	3	main
kui	doc_35015649954_item	3599898	et	3	main
pildi	doc_786864950072_item	3599906	et	4	main
kirjuta	doc_786864950072_item	3599908	et	4	main
pildi	doc_786864950072_item	3599911	et	4	main
ta	doc_786864950072_item	3599917	et	4	main
sellepärast	doc_786864950072_item	3599921	et	3	main
kadril	doc_786864950072_item	3599962	et	3	main
isa	doc_786864950072_item	3599964	et	4	main
tõnu	doc_786864950072_item	3599969	et	4	main
naist	doc_786864950072_item	3599970	et	3	main
võtab	doc_786864950072_item	3599971	et	3	main
lasteaias	doc_786864950072_item	3599985	et	4	main
pildi	doc_786864950073_item	3600001	et	4	main
kirjeldus	doc_786864950073_item	3600002	et	4	main
kirjuta	doc_786864950073_item	3600003	et	4	main
10	doc_786864950073_item	3600004	et	2	main
lauset	doc_786864950073_item	3600005	et	3	main
ta	doc_786864950072_item	3599987	et	4	main
vanaema	doc_786864950072_item	3599988	et	4	main
on	doc_786864950072_item	3599989	et	4	main
kodus	doc_786864950072_item	3599990	et	4	main
kui	doc_786864950072_item	3599991	et	3	main
ema	doc_786864950072_item	3599992	et	4	main
on	doc_786864950072_item	3599993	et	4	main
tööl	doc_786864950072_item	3599994	et	3	main
kadri	doc_786864950072_item	3599995	et	4	main
on	doc_786864950072_item	3599996	et	4	main
ilus	doc_786864950072_item	3599997	et	4	main
laps	doc_786864950072_item	3599998	et	4	main
on	doc_786864950072_item	3599914	et	4	main
väike	doc_786864950072_item	3599915	et	4	main
laps	doc_786864950072_item	3599916	et	4	main
kadri	doc_786864950072_item	3599920	et	4	main
on	doc_786864950072_item	3599931	et	4	main
sünndinud	doc_786864950072_item	3599932	et	4	main
2001	doc_786864950072_item	3599933	et	2	main
aastas	doc_786864950072_item	3599934	et	3	main
kadri	doc_786864950072_item	3599935	et	4	main
ema	doc_786864950072_item	3599936	et	4	main
on	doc_786864950072_item	3599937	et	4	main
eestlane	doc_786864950072_item	3599938	et	3	main
ta	doc_786864950072_item	3599939	et	4	main
perekonnanimi	doc_786864950072_item	3599940	et	3	main
on	doc_786864950072_item	3599941	et	4	main
lõpik	doc_786864950072_item	3599942	et	3	main
aga	doc_786864950072_item	3599943	et	3	main
ta	doc_786864950072_item	3599944	et	4	main
ei	doc_786864950072_item	3599946	et	4	main
isa	doc_786864950072_item	3599945	et	4	main
ole	doc_786864950072_item	3599947	et	4	main
eestlane	doc_786864950072_item	3599948	et	3	main
ta	doc_786864950072_item	3599949	et	4	main
on	doc_786864950072_item	3599950	et	4	main
sakslane	doc_786864950072_item	3599951	et	3	main
sellepärast	doc_786864950072_item	3599952	et	3	main
kadri	doc_786864950072_item	3599953	et	4	main
võib	doc_786864950072_item	3599959	et	3	main
see	doc_786864950072_item	3599973	et	3	main
väike	doc_786864950072_item	3599974	et	4	main
elavad	doc_786864950072_item	3599976	et	4	main
tartus	doc_786864950072_item	3599977	et	3	main
kadri	doc_786864950072_item	3599978	et	4	main
käima	doc_786864950072_item	3599986	et	4	main
kohta	doc_786864950073_item	3600007	et	4	main
naerab	doc_786864950073_item	3600015	et	3	main
ole	doc_786864950073_item	3600018	et	4	main
kurb	doc_786864950073_item	3600019	et	3	main
ta	doc_786864950073_item	3600020	et	4	main
nimi	doc_786864950073_item	3600021	et	3	main
on	doc_786864950073_item	3600022	et	4	main
veel	doc_786864950073_item	3600026	et	4	main
väike	doc_786864950073_item	3600027	et	4	main
ema	doc_786864950073_item	3600037	et	4	main
tööta	doc_786864950073_item	3600040	et	4	main
koolis	doc_786864950073_item	3600069	et	4	main
vana	doc_786864950073_item	3600074	et	4	main
vanas	doc_786864950073_item	3600085	et	3	main
see	doc_786864950073_item	3600087	et	3	main
tartu	doc_786864950073_item	3600091	et	4	main
on	doc_786864950073_item	3600092	et	4	main
kohta	doc_786864950074_item	3600103	et	4	main
sellel	doc_786864950074_item	3600104	et	4	main
pildil	doc_786864950074_item	3600105	et	3	main
on	doc_786864950074_item	3600106	et	4	main
ilus	doc_786864950074_item	3600135	et	4	main
silmad	doc_786864950074_item	3600142	et	4	main
kakskümmend	doc_786864950074_item	3600150	et	4	main
arvutiinsener	doc_786864950074_item	3600156	et	3	main
kirjuta	doc_786864950075_item	3600169	et	4	main
on	doc_786864950075_item	3600175	et	4	main
aed	doc_786864950075_item	3600176	et	3	main
istuvad	doc_786864950075_item	3600181	et	4	main
ja	doc_786864950075_item	3600182	et	3	main
ka	doc_786864950075_item	3600203	et	3	main
poisid	doc_786864950075_item	3600206	et	4	main
ja	doc_786864950075_item	3600207	et	3	main
tüdrukud	doc_786864950075_item	3600208	et	3	main
on	doc_786864950075_item	3600209	et	4	main
noored	doc_786864950075_item	3600210	et	3	main
ja	doc_786864950075_item	3600211	et	3	main
ilusad	doc_786864950075_item	3600212	et	3	main
maja	doc_786864950075_item	3600222	et	4	main
pere	doc_786864950076_item	3600248	et	4	main
soome	doc_786864950076_item	3600259	et	3	main
pildi	doc_786864950077_item	3600268	et	4	main
juures	doc_786864950077_item	3600294	et	4	main
on	doc_786864950077_item	3600295	et	4	main
puud	doc_786864950077_item	3600296	et	4	main
juures	doc_786864950077_item	3600301	et	4	main
istub	doc_786864950077_item	3600302	et	3	main
ilus	doc_786864950077_item	3600309	et	4	main
ja	doc_786864950077_item	3600310	et	3	main
on	doc_786864950077_item	3600313	et	4	main
laisad	doc_786864950077_item	3600314	et	3	main
kirjeldus	doc_786864950078_item	3600338	et	4	main
10	doc_786864950078_item	3600340	et	2	main
lauset	doc_786864950078_item	3600341	et	3	main
pildi	doc_786864950078_item	3600342	et	4	main
tema	doc_786864950078_item	3600347	et	4	main
tema	doc_786864950078_item	3600379	et	4	main
nimi	doc_786864950078_item	3600380	et	3	main
on	doc_786864950078_item	3600381	et	4	main
arst	doc_786864950078_item	3600392	et	3	main
sünnipäev	doc_786864950078_item	3600401	et	3	main
et	doc_786864950072_item	3599961	et	3	main
kui	doc_786864950072_item	3599965	et	3	main
ta	doc_786864950072_item	3599966	et	4	main
ema	doc_786864950072_item	3599967	et	4	main
sõber	doc_786864950072_item	3599968	et	3	main
töötab	doc_786864950072_item	3599980	et	3	main
on	doc_786864950073_item	3600009	et	4	main
ta	doc_786864950073_item	3600016	et	4	main
ei	doc_786864950073_item	3600017	et	4	main
ei	doc_786864950073_item	3600028	et	4	main
isa	doc_786864950073_item	3600042	et	4	main
on	doc_786864950073_item	3600054	et	4	main
tark	doc_786864950073_item	3600055	et	3	main
on	doc_786864950073_item	3600058	et	4	main
käivad	doc_786864950073_item	3600068	et	4	main
elavad	doc_786864950073_item	3600082	et	4	main
on	doc_786864950073_item	3600089	et	4	main
laps	doc_786864950074_item	3600108	et	4	main
ja	doc_786864950074_item	3600109	et	3	main
ta	doc_786864950074_item	3600110	et	4	main
ema	doc_786864950074_item	3600111	et	4	main
lapse	doc_786864950074_item	3600112	et	4	main
nimi	doc_786864950074_item	3600113	et	3	main
on	doc_786864950074_item	3600114	et	4	main
tiiu	doc_786864950074_item	3600115	et	4	main
ta	doc_786864950074_item	3600116	et	4	main
on	doc_786864950074_item	3600117	et	4	main
see	doc_786864950073_item	3600008	et	3	main
ta	doc_786864950073_item	3600031	et	4	main
kuud	doc_786864950073_item	3600034	et	4	main
on	doc_786864950073_item	3600043	et	4	main
ajakirjanik	doc_786864950073_item	3600044	et	3	main
aga	doc_786864950073_item	3600045	et	3	main
tuleb	doc_786864950073_item	3600046	et	3	main
töölt	doc_786864950073_item	3600047	et	3	main
koju	doc_786864950073_item	3600048	et	3	main
tal	doc_786864950073_item	3600057	et	3	main
kaks	doc_786864950073_item	3600059	et	3	main
tambet	doc_786864950073_item	3600070	et	4	main
ja	doc_786864950073_item	3600075	et	3	main
üheksa	doc_786864950073_item	3600078	et	4	main
aastat	doc_786864950073_item	3600079	et	3	main
vana	doc_786864950073_item	3600080	et	4	main
nad	doc_786864950073_item	3600081	et	3	main
puumajas	doc_786864950073_item	3600086	et	3	main
pildi	doc_786864950074_item	3600097	et	4	main
kirjuta	doc_786864950074_item	3600099	et	4	main
väike	doc_786864950074_item	3600107	et	4	main
aastat	doc_786864950074_item	3600119	et	3	main
on	doc_786864950074_item	3600125	et	4	main
meeldib	doc_786864950074_item	3600128	et	3	main
tiiul	doc_786864950074_item	3600133	et	4	main
on	doc_786864950074_item	3600140	et	4	main
ema	doc_786864950074_item	3600144	et	4	main
eva	doc_786864950074_item	3600147	et	4	main
talle	doc_786864950074_item	3600157	et	4	main
kuulata	doc_786864950074_item	3600160	et	4	main
mängida	doc_786864950074_item	3600163	et	3	main
kirjeldus	doc_786864950075_item	3600168	et	4	main
maja	doc_786864950075_item	3600216	et	4	main
puud	doc_786864950075_item	3600226	et	4	main
on	doc_786864950076_item	3600249	et	4	main
eestlased	doc_786864950076_item	3600255	et	3	main
ema	doc_786864950077_item	3600303	et	4	main
tüdruk	doc_786864950077_item	3600304	et	3	main
ja	doc_786864950077_item	3600305	et	3	main
poisid	doc_786864950077_item	3600306	et	4	main
üliõpilased	doc_786864950077_item	3600317	et	3	main
ei	doc_786864950077_item	3600319	et	4	main
ole	doc_786864950077_item	3600320	et	4	main
laisk	doc_786864950077_item	3600321	et	3	main
maga	doc_786864950077_item	3600331	et	4	main
nad	doc_786864950077_item	3600332	et	3	main
räägivad	doc_786864950077_item	3600333	et	3	main
on	doc_786864950078_item	3600345	et	4	main
laps	doc_786864950078_item	3600346	et	4	main
ema	doc_786864950078_item	3600390	et	4	main
on	doc_786864950078_item	3600391	et	4	main
on	doc_786864950078_item	3600400	et	4	main
mis	doc_786864950079_item	3600404	et	4	main
veel	doc_786864950079_item	3600418	et	4	main
üks	doc_786864950079_item	3600419	et	3	main
peeter	doc_786864950079_item	3600420	et	3	main
aga	doc_786864950079_item	3600421	et	3	main
ja	doc_786864950079_item	3600427	et	3	main
sa	doc_786864950079_item	3600452	et	3	main
räägin	doc_786864950079_item	3600454	et	3	main
ka	doc_786864950079_item	3600462	et	3	main
rootsi	doc_786864950079_item	3600464	et	4	main
ja	doc_786864950079_item	3600465	et	3	main
loan	doc_786864950079_item	3600469	et	4	main
keelt	doc_786864950079_item	3600471	et	4	main
õpin	doc_786864950079_item	3600472	et	3	main
ei	doc_786864950079_item	3600476	et	4	main
koolis	doc_786864950079_item	3600479	et	4	main
ma	doc_786864950079_item	3600480	et	3	main
inglise	doc_786864950079_item	3600483	et	4	main
keelt	doc_786864950079_item	3600484	et	4	main
milline	doc_786864950079_item	3600485	et	3	main
linn	doc_786864950079_item	3600486	et	3	main
on	doc_786864950079_item	3600487	et	4	main
jõgi	doc_786864950079_item	3600506	et	3	main
palatsi	doc_786864950079_item	3600509	et	4	main
ja	doc_786864950079_item	3600510	et	3	main
ülikool	doc_786864950079_item	3600511	et	4	main
mul	doc_786864950079_item	3600516	et	3	main
meie	doc_786864950079_item	3600528	et	4	main
emaga	doc_786864950079_item	3600529	et	3	main
koos	doc_786864950079_item	3600530	et	4	main
mul	doc_786864950079_item	3600531	et	3	main
10	doc_786864950074_item	3600100	et	2	main
lauset	doc_786864950074_item	3600101	et	3	main
pildi	doc_786864950074_item	3600102	et	4	main
pool	doc_786864950074_item	3600118	et	4	main
vana	doc_786864950074_item	3600120	et	4	main
tiiu	doc_786864950074_item	3600121	et	4	main
naerab	doc_786864950074_item	3600122	et	3	main
emaga	doc_786864950074_item	3600126	et	3	main
helesinine	doc_786864950074_item	3600136	et	4	main
kleit	doc_786864950074_item	3600137	et	3	main
tiiu	doc_786864950074_item	3600143	et	4	main
pildi	doc_786864950075_item	3600167	et	4	main
ees	doc_786864950075_item	3600202	et	4	main
poiss	doc_786864950075_item	3600205	et	3	main
taga	doc_786864950075_item	3600214	et	4	main
seisab	doc_786864950075_item	3600215	et	3	main
maja	doc_786864950075_item	3600217	et	4	main
on	doc_786864950075_item	3600218	et	4	main
ees	doc_786864950075_item	3600223	et	4	main
rohelised	doc_786864950075_item	3600230	et	4	main
ei	doc_786864950076_item	3600245	et	4	main
ole	doc_786864950076_item	3600246	et	4	main
suur	doc_786864950076_item	3600247	et	3	main
aegas	doc_786864950076_item	3600252	et	4	main
nemad	doc_786864950076_item	3600253	et	3	main
on	doc_786864950076_item	3600254	et	4	main
aga	doc_786864950076_item	3600256	et	3	main
on	doc_786864950077_item	3600276	et	4	main
pilt	doc_786864950077_item	3600277	et	3	main
pildil	doc_786864950077_item	3600278	et	3	main
on	doc_786864950077_item	3600279	et	4	main
pere	doc_786864950077_item	3600280	et	4	main
rohelised	doc_786864950077_item	3600299	et	4	main
ema	doc_786864950077_item	3600307	et	4	main
on	doc_786864950077_item	3600308	et	4	main
ta	doc_786864950077_item	3600322	et	4	main
ta	doc_786864950077_item	3600325	et	4	main
majast	doc_786864950077_item	3600334	et	4	main
pildi	doc_786864950078_item	3600337	et	4	main
kirjuta	doc_786864950078_item	3600339	et	4	main
on	doc_786864950078_item	3600349	et	4	main
ta	doc_786864950078_item	3600352	et	4	main
lauri	doc_786864950078_item	3600371	et	4	main
armastab	doc_786864950078_item	3600372	et	3	main
mängida	doc_786864950078_item	3600373	et	3	main
karin	doc_786864950078_item	3600382	et	4	main
lauri	doc_786864950078_item	3600389	et	4	main
lauril	doc_786864950078_item	3600399	et	4	main
on	doc_786864950079_item	3600407	et	4	main
nimi	doc_786864950079_item	3600409	et	3	main
on	doc_786864950079_item	3600424	et	4	main
sa	doc_786864950079_item	3600429	et	3	main
budapestis	doc_786864950079_item	3600432	et	4	main
ungari	doc_786864950079_item	3600433	et	4	main
itaalia	doc_786864950079_item	3600440	et	4	main
ja	doc_786864950079_item	3600442	et	3	main
soome	doc_786864950079_item	3600443	et	3	main
mis	doc_786864950079_item	3600450	et	4	main
keelt	doc_786864950079_item	3600458	et	4	main
ma	doc_786864950079_item	3600468	et	3	main
aga	doc_786864950079_item	3600475	et	3	main
heasti	doc_786864950079_item	3600478	et	4	main
õppinud	doc_786864950079_item	3600482	et	4	main
linn	doc_786864950079_item	3600492	et	3	main
see	doc_786864950079_item	3600493	et	3	main
on	doc_786864950079_item	3600494	et	4	main
ungari	doc_786864950079_item	3600495	et	4	main
pealinn	doc_786864950079_item	3600496	et	3	main
seal	doc_786864950079_item	3600497	et	4	main
elab	doc_786864950079_item	3600498	et	3	main
naist	doc_786864950079_item	3600503	et	3	main
milline	doc_786864950079_item	3600512	et	3	main
pere	doc_786864950079_item	3600515	et	4	main
ainult	doc_786864950079_item	3600518	et	4	main
elab	doc_786864950079_item	3600522	et	3	main
meie	doc_786864950079_item	3600523	et	4	main
isaga	doc_786864950079_item	3600524	et	3	main
vanaisa	doc_786864950079_item	3600533	et	4	main
ja	doc_786864950079_item	3600534	et	3	main
sinu	doc_786864950079_item	3600565	et	3	main
elan	doc_786864950079_item	3600569	et	3	main
koos	doc_786864950079_item	3600571	et	4	main
kõrgemajas	doc_786864950079_item	3600572	et	3	main
tiiule	doc_786864950074_item	3600127	et	4	main
palju	doc_786864950074_item	3600129	et	4	main
ja	doc_786864950074_item	3600131	et	3	main
seljas	doc_786864950074_item	3600138	et	4	main
tal	doc_786864950074_item	3600139	et	3	main
on	doc_786864950074_item	3600146	et	4	main
ta	doc_786864950074_item	3600148	et	4	main
on	doc_786864950074_item	3600149	et	4	main
vana	doc_786864950074_item	3600153	et	4	main
meeldib	doc_786864950074_item	3600158	et	3	main
lugeda	doc_786864950074_item	3600159	et	3	main
muusikat	doc_786864950074_item	3600161	et	3	main
tütrega	doc_786864950074_item	3600164	et	3	main
lauset	doc_786864950075_item	3600171	et	3	main
pildi	doc_786864950075_item	3600172	et	4	main
see	doc_786864950075_item	3600174	et	3	main
siin	doc_786864950075_item	3600177	et	4	main
söövad	doc_786864950075_item	3600183	et	4	main
neil	doc_786864950075_item	3600184	et	4	main
on	doc_786864950075_item	3600185	et	4	main
hea	doc_786864950075_item	3600186	et	4	main
meel	doc_786864950075_item	3600187	et	4	main
nemad	doc_786864950075_item	3600188	et	3	main
räägivad	doc_786864950075_item	3600189	et	3	main
ülikoolist	doc_786864950075_item	3600190	et	4	main
tüdruku	doc_786864950075_item	3600192	et	3	main
ees	doc_786864950075_item	3600193	et	4	main
poiss	doc_786864950075_item	3600191	et	3	main
istub	doc_786864950075_item	3600194	et	3	main
tüdruku	doc_786864950075_item	3600195	et	3	main
kõrval	doc_786864950075_item	3600196	et	4	main
on	doc_786864950075_item	3600197	et	4	main
ka	doc_786864950075_item	3600198	et	3	main
tüdruk	doc_786864950075_item	3600199	et	3	main
selle	doc_786864950075_item	3600200	et	4	main
tüdruku	doc_786864950075_item	3600201	et	3	main
istub	doc_786864950075_item	3600204	et	3	main
valge	doc_786864950075_item	3600219	et	4	main
ja	doc_786864950075_item	3600220	et	3	main
suur	doc_786864950075_item	3600221	et	3	main
väikesed	doc_786864950075_item	3600228	et	4	main
ja	doc_786864950075_item	3600229	et	3	main
ees	doc_786864950076_item	3600251	et	4	main
saavad	doc_786864950076_item	3600257	et	4	main
keelest	doc_786864950076_item	3600260	et	4	main
on	doc_786864950076_item	3600262	et	4	main
ilusad	doc_786864950076_item	3600263	et	3	main
ja	doc_786864950076_item	3600264	et	3	main
kirjeldus	doc_786864950077_item	3600269	et	4	main
kirjuta	doc_786864950077_item	3600270	et	4	main
10	doc_786864950077_item	3600271	et	2	main
lauset	doc_786864950077_item	3600272	et	3	main
pildi	doc_786864950077_item	3600273	et	4	main
pere	doc_786864950077_item	3600281	et	4	main
taga	doc_786864950077_item	3600282	et	4	main
on	doc_786864950077_item	3600283	et	4	main
suur	doc_786864950077_item	3600284	et	3	main
ja	doc_786864950077_item	3600285	et	3	main
uus	doc_786864950077_item	3600286	et	3	main
maja	doc_786864950077_item	3600287	et	4	main
see	doc_786864950077_item	3600288	et	3	main
on	doc_786864950077_item	3600289	et	4	main
valge	doc_786864950077_item	3600290	et	4	main
ja	doc_786864950077_item	3600291	et	3	main
ilus	doc_786864950077_item	3600292	et	4	main
maja	doc_786864950077_item	3600293	et	4	main
pildi	doc_786864950076_item	3600233	et	4	main
kirjeldus	doc_786864950076_item	3600234	et	4	main
kirjuta	doc_786864950076_item	3600235	et	4	main
10	doc_786864950076_item	3600236	et	2	main
lauset	doc_786864950076_item	3600237	et	3	main
pildi	doc_786864950076_item	3600238	et	4	main
kohta	doc_786864950076_item	3600239	et	4	main
see	doc_786864950076_item	3600240	et	3	main
on	doc_786864950076_item	3600241	et	4	main
pere	doc_786864950076_item	3600242	et	4	main
see	doc_786864950076_item	3600243	et	3	main
aru	doc_786864950076_item	3600258	et	4	main
nemad	doc_786864950076_item	3600261	et	3	main
noored	doc_786864950076_item	3600265	et	3	main
kohta	doc_786864950077_item	3600274	et	4	main
see	doc_786864950077_item	3600275	et	3	main
järve	doc_786864950077_item	3600300	et	4	main
poisid	doc_786864950077_item	3600312	et	4	main
tüdruk	doc_786864950077_item	3600318	et	3	main
virk	doc_786864950077_item	3600324	et	3	main
on	doc_786864950077_item	3600326	et	4	main
ilus	doc_786864950077_item	3600327	et	4	main
tüdruk	doc_786864950077_item	3600328	et	3	main
nad	doc_786864950077_item	3600329	et	3	main
ei	doc_786864950077_item	3600330	et	4	main
lauri	doc_786864950078_item	3600350	et	4	main
ja	doc_786864950078_item	3600351	et	3	main
väga	doc_786864950078_item	3600354	et	3	main
ilus	doc_786864950078_item	3600355	et	4	main
on	doc_786864950078_item	3600353	et	4	main
poiss	doc_786864950078_item	3600356	et	3	main
lauri	doc_786864950078_item	3600357	et	4	main
käib	doc_786864950078_item	3600358	et	3	main
lasteaeda	doc_786864950078_item	3600359	et	4	main
sest	doc_786864950078_item	3600360	et	4	main
tema	doc_786864950078_item	3600361	et	4	main
ema	doc_786864950078_item	3600362	et	4	main
ja	doc_786864950078_item	3600363	et	3	main
isa	doc_786864950078_item	3600364	et	4	main
töötavad	doc_786864950078_item	3600365	et	4	main
lauri	doc_786864950078_item	3600366	et	4	main
on	doc_786864950078_item	3600367	et	4	main
kõige	doc_786864950078_item	3600368	et	4	main
noorem	doc_786864950078_item	3600369	et	4	main
ja	doc_786864950078_item	3600374	et	3	main
puud	doc_786864950077_item	3600297	et	4	main
on	doc_786864950077_item	3600298	et	4	main
pikk	doc_786864950077_item	3600311	et	4	main
nemad	doc_786864950077_item	3600315	et	3	main
on	doc_786864950077_item	3600316	et	4	main
on	doc_786864950077_item	3600323	et	4	main
kohta	doc_786864950078_item	3600343	et	4	main
see	doc_786864950078_item	3600344	et	3	main
nimi	doc_786864950078_item	3600348	et	3	main
magada	doc_786864950078_item	3600375	et	3	main
õde	doc_786864950078_item	3600378	et	4	main
viisteist	doc_786864950078_item	3600386	et	4	main
aastad	doc_786864950078_item	3600387	et	3	main
vana	doc_786864950078_item	3600388	et	4	main
ja	doc_786864950078_item	3600393	et	3	main
on	doc_786864950078_item	3600396	et	4	main
juuksur	doc_786864950078_item	3600397	et	3	main
harjutus	doc_786864950079_item	3600403	et	4	main
mu	doc_786864950079_item	3600408	et	3	main
meie	doc_786864950079_item	3600415	et	4	main
klassis	doc_786864950079_item	3600416	et	3	main
on	doc_786864950079_item	3600417	et	4	main
kask	doc_786864950079_item	3600425	et	3	main
mida	doc_786864950079_item	3600428	et	4	main
õpid	doc_786864950079_item	3600430	et	4	main
õpin	doc_786864950079_item	3600431	et	3	main
ülikoolis	doc_786864950079_item	3600436	et	4	main
õpin	doc_786864950079_item	3600437	et	3	main
rootsi	doc_786864950079_item	3600438	et	4	main
keelt	doc_786864950079_item	3600441	et	4	main
eesti	doc_786864950079_item	3600448	et	4	main
keeli	doc_786864950079_item	3600451	et	4	main
eesti	doc_786864950079_item	3600457	et	4	main
leedugi	doc_786864950079_item	3600473	et	4	main
räägi	doc_786864950079_item	3600477	et	4	main
budapest	doc_786864950079_item	3600489	et	4	main
kaks	doc_786864950079_item	3600499	et	3	main
perekonnas	doc_786864950078_item	3600370	et	4	main
lauri	doc_786864950078_item	3600376	et	4	main
on	doc_786864950078_item	3600377	et	4	main
ja	doc_786864950078_item	3600383	et	3	main
karin	doc_786864950078_item	3600384	et	4	main
on	doc_786864950078_item	3600385	et	4	main
lauri	doc_786864950078_item	3600394	et	4	main
isa	doc_786864950078_item	3600395	et	4	main
nädalavahetusel	doc_786864950078_item	3600398	et	4	main
sinu	doc_786864950079_item	3600405	et	3	main
peeter	doc_786864950079_item	3600411	et	3	main
perekonnanimi	doc_786864950079_item	3600412	et	3	main
on	doc_786864950079_item	3600413	et	4	main
tamm	doc_786864950079_item	3600414	et	3	main
ta	doc_786864950079_item	3600422	et	4	main
perekonnanimi	doc_786864950079_item	3600423	et	3	main
kõige	doc_786864950079_item	3600434	et	4	main
vanemas	doc_786864950079_item	3600435	et	4	main
ka	doc_786864950079_item	3600447	et	3	main
ma	doc_786864950079_item	3600460	et	3	main
keelt	doc_786864950079_item	3600467	et	4	main
latinia	doc_786864950079_item	3600470	et	4	main
budapest	doc_786864950079_item	3600488	et	4	main
budapestil	doc_786864950079_item	3600504	et	4	main
on	doc_786864950079_item	3600513	et	4	main
sinu	doc_786864950079_item	3600514	et	3	main
on	doc_786864950079_item	3600517	et	4	main
üks	doc_786864950079_item	3600519	et	3	main
elavad	doc_786864950079_item	3600537	et	4	main
mu	doc_786864950079_item	3600538	et	3	main
põeg	doc_786864950079_item	3600546	et	4	main
korter	doc_786864950079_item	3600566	et	3	main
elab	doc_786864950079_item	3600577	et	3	main
mul	doc_786864950079_item	3600580	et	3	main
tuba	doc_786864950079_item	3600583	et	4	main
nimi	doc_786864950080_item	3600636	et	3	main
tamm	doc_786864950080_item	3600639	et	3	main
ja	doc_786864950080_item	3600643	et	3	main
on	doc_786864950080_item	3600645	et	4	main
perekonnanimi	doc_786864950080_item	3600646	et	3	main
kus	doc_786864950080_item	3600647	et	3	main
ma	doc_786864950080_item	3600652	et	3	main
mis	doc_786864950080_item	3600666	et	4	main
on	doc_786864950080_item	3600679	et	4	main
ta	doc_786864950080_item	3600685	et	4	main
on	doc_786864950080_item	3600690	et	4	main
pere	doc_786864950080_item	3600692	et	4	main
ei	doc_786864950080_item	3600694	et	4	main
ole	doc_786864950080_item	3600695	et	4	main
suur	doc_786864950080_item	3600696	et	3	main
ema	doc_786864950080_item	3600703	et	4	main
elan	doc_786864950080_item	3600729	et	3	main
suuri	doc_786864950081_item	3600768	et	3	main
riipub	doc_786864950081_item	3600778	et	4	main
õpid	doc_786864950081_item	3600787	et	4	main
rootsi	doc_786864950081_item	3600792	et	4	main
keelt	doc_786864950081_item	3600793	et	4	main
budapest	doc_786864950081_item	3600815	et	4	main
on	doc_786864950081_item	3600821	et	4	main
on	doc_786864950081_item	3600833	et	4	main
kaks	doc_786864950081_item	3600834	et	3	main
ja	doc_786864950081_item	3600836	et	3	main
õde	doc_786864950081_item	3600838	et	4	main
minu	doc_786864950081_item	3600866	et	3	main
seinad	doc_786864950081_item	3600870	et	3	main
on	doc_786864950081_item	3600871	et	4	main
kus	doc_786864950082_item	3600890	et	3	main
õpin	doc_786864950082_item	3600896	et	3	main
õpin	doc_786864950082_item	3600900	et	3	main
ka	doc_786864950082_item	3600905	et	3	main
räägid	doc_786864950082_item	3600913	et	4	main
budapest	doc_786864950082_item	3600928	et	4	main
on	doc_786864950082_item	3600933	et	4	main
on	doc_786864950082_item	3600961	et	4	main
suvila	doc_786864950082_item	3600962	et	4	main
kus	doc_786864950082_item	3600963	et	3	main
nimi	doc_786864950079_item	3600406	et	3	main
on	doc_786864950079_item	3600410	et	4	main
kus	doc_786864950079_item	3600426	et	3	main
keelt	doc_786864950079_item	3600439	et	4	main
keelt	doc_786864950079_item	3600444	et	4	main
nüüd	doc_786864950079_item	3600445	et	4	main
õpin	doc_786864950079_item	3600446	et	3	main
keelt	doc_786864950079_item	3600449	et	4	main
räägid	doc_786864950079_item	3600453	et	4	main
muidugi	doc_786864950079_item	3600455	et	4	main
natuke	doc_786864950079_item	3600456	et	4	main
ja	doc_786864950079_item	3600459	et	3	main
räägin	doc_786864950079_item	3600461	et	3	main
itaalia	doc_786864950079_item	3600463	et	4	main
soome	doc_786864950079_item	3600466	et	3	main
keelt	doc_786864950079_item	3600474	et	4	main
on	doc_786864950079_item	3600481	et	4	main
on	doc_786864950079_item	3600490	et	4	main
suur	doc_786864950079_item	3600491	et	3	main
miljoona	doc_786864950079_item	3600500	et	4	main
meest	doc_786864950079_item	3600501	et	4	main
ja	doc_786864950079_item	3600502	et	3	main
on	doc_786864950079_item	3600505	et	4	main
koos	doc_786864950079_item	3600525	et	4	main
ma	doc_786864950079_item	3600526	et	3	main
elan	doc_786864950079_item	3600527	et	3	main
vanaema	doc_786864950079_item	3600535	et	4	main
need	doc_786864950079_item	3600536	et	3	main
isa	doc_786864950079_item	3600541	et	4	main
neel	doc_786864950079_item	3600543	et	3	main
on	doc_786864950079_item	3600544	et	4	main
hundkõer	doc_786864950079_item	3600575	et	4	main
väike	doc_786864950079_item	3600582	et	4	main
mida	doc_786864950080_item	3600649	et	4	main
keelt	doc_786864950080_item	3600655	et	4	main
räägin	doc_786864950080_item	3600671	et	3	main
inglise	doc_786864950080_item	3600673	et	4	main
keelt	doc_786864950080_item	3600676	et	4	main
milline	doc_786864950080_item	3600677	et	3	main
linn	doc_786864950080_item	3600678	et	3	main
pealinn	doc_786864950080_item	3600688	et	3	main
on	doc_786864950080_item	3600699	et	4	main
ainult	doc_786864950080_item	3600700	et	4	main
yks	doc_786864950080_item	3600701	et	4	main
vend	doc_786864950080_item	3600702	et	3	main
ja	doc_786864950080_item	3600706	et	3	main
autojust	doc_786864950080_item	3600709	et	4	main
maja	doc_786864950080_item	3600727	et	4	main
harjutus	doc_786864950081_item	3600760	et	4	main
on	doc_786864950081_item	3600762	et	4	main
veel	doc_786864950081_item	3600781	et	4	main
ja	doc_786864950081_item	3600791	et	3	main
mis	doc_786864950081_item	3600795	et	4	main
räägid	doc_786864950081_item	3600798	et	4	main
rootsi	doc_786864950081_item	3600802	et	4	main
ja	doc_786864950081_item	3600803	et	3	main
natuke	doc_786864950081_item	3600808	et	4	main
eesti	doc_786864950081_item	3600809	et	4	main
budapest	doc_786864950081_item	3600816	et	4	main
suur	doc_786864950081_item	3600822	et	3	main
pere	doc_786864950081_item	3600831	et	4	main
minul	doc_786864950081_item	3600832	et	3	main
oleme	doc_786864950081_item	3600840	et	3	main
on	doc_786864950082_item	3600881	et	4	main
peeter	doc_786864950082_item	3600882	et	3	main
tamm	doc_786864950082_item	3600883	et	3	main
peeter	doc_786864950082_item	3600884	et	3	main
ja	doc_786864950082_item	3600887	et	3	main
mida	doc_786864950082_item	3600892	et	4	main
ülikoolis	doc_786864950082_item	3600898	et	4	main
ma	doc_786864950082_item	3600899	et	3	main
õpisin	doc_786864950082_item	3600904	et	4	main
keelt	doc_786864950082_item	3600907	et	4	main
kirjandust	doc_786864950082_item	3600909	et	3	main
mis	doc_786864950082_item	3600910	et	4	main
keeli	doc_786864950082_item	3600911	et	4	main
sa	doc_786864950082_item	3600912	et	3	main
ja	doc_786864950082_item	3600917	et	3	main
budapest	doc_786864950082_item	3600927	et	4	main
ülikoolilinn	doc_786864950082_item	3600935	et	3	main
vana	doc_786864950079_item	3600507	et	4	main
kuningas	doc_786864950079_item	3600508	et	4	main
vend	doc_786864950079_item	3600520	et	3	main
ta	doc_786864950079_item	3600521	et	4	main
venne	doc_786864950079_item	3600539	et	4	main
koos	doc_786864950079_item	3600542	et	4	main
kaks	doc_786864950079_item	3600545	et	3	main
mu	doc_786864950079_item	3600547	et	3	main
isa	doc_786864950079_item	3600548	et	4	main
ja	doc_786864950079_item	3600549	et	3	main
ta	doc_786864950079_item	3600550	et	4	main
vend	doc_786864950079_item	3600551	et	3	main
vennel	doc_786864950079_item	3600552	et	4	main
ka	doc_786864950079_item	3600553	et	3	main
on	doc_786864950079_item	3600554	et	4	main
juba	doc_786864950079_item	3600555	et	3	main
perekonne	doc_786864950079_item	3600556	et	3	main
tüdruk	doc_786864950079_item	3600557	et	3	main
ja	doc_786864950079_item	3600558	et	3	main
põeg	doc_786864950079_item	3600559	et	4	main
kus	doc_786864950079_item	3600560	et	3	main
sa	doc_786864950079_item	3600561	et	3	main
elad	doc_786864950079_item	3600562	et	3	main
milline	doc_786864950079_item	3600563	et	3	main
on	doc_786864950079_item	3600564	et	4	main
ma	doc_786864950079_item	3600568	et	3	main
emaga	doc_786864950079_item	3600570	et	3	main
on	doc_786864950079_item	3600574	et	4	main
roosal	doc_786864950079_item	3600584	et	4	main
seinal	doc_786864950079_item	3600585	et	3	main
riipub	doc_786864950079_item	3600586	et	4	main
üks	doc_786864950079_item	3600587	et	3	main
sinine	doc_786864950079_item	3600588	et	4	main
pild	doc_786864950079_item	3600589	et	3	main
pildis	doc_786864950079_item	3600590	et	3	main
on	doc_786864950079_item	3600591	et	4	main
valge	doc_786864950079_item	3600592	et	4	main
mõmmi	doc_786864950079_item	3600593	et	4	main
tubal	doc_786864950079_item	3600594	et	4	main
on	doc_786864950079_item	3600595	et	4	main
suur	doc_786864950079_item	3600596	et	3	main
aken	doc_786864950079_item	3600597	et	3	main
aken	doc_786864950079_item	3600598	et	3	main
ees	doc_786864950079_item	3600599	et	4	main
ei	doc_786864950079_item	3600600	et	4	main
ole	doc_786864950079_item	3600601	et	4	main
kardinit	doc_786864950079_item	3600602	et	3	main
on	doc_786864950079_item	3600532	et	4	main
ja	doc_786864950079_item	3600540	et	3	main
maja	doc_786864950079_item	3600567	et	4	main
kõer	doc_786864950079_item	3600576	et	4	main
harjutus	doc_786864950080_item	3600630	et	4	main
on	doc_786864950080_item	3600637	et	4	main
on	doc_786864950080_item	3600641	et	4	main
tamm	doc_786864950080_item	3600644	et	3	main
ja	doc_786864950080_item	3600648	et	3	main
soome	doc_786864950080_item	3600654	et	3	main
kirjandust	doc_786864950080_item	3600658	et	3	main
praegu	doc_786864950080_item	3600660	et	3	main
ka	doc_786864950080_item	3600663	et	3	main
on	doc_786864950080_item	3600686	et	4	main
milline	doc_786864950080_item	3600689	et	3	main
pangas	doc_786864950080_item	3600705	et	4	main
mina	doc_786864950081_item	3600788	et	4	main
õpin	doc_786864950081_item	3600789	et	3	main
soome	doc_786864950081_item	3600790	et	3	main
sa	doc_786864950081_item	3600797	et	3	main
on	doc_786864950081_item	3600817	et	4	main
linn	doc_786864950081_item	3600823	et	3	main
on	doc_786864950081_item	3600825	et	4	main
pere	doc_786864950081_item	3600827	et	4	main
minul	doc_786864950081_item	3600828	et	3	main
on	doc_786864950081_item	3600829	et	4	main
suur	doc_786864950081_item	3600830	et	3	main
me	doc_786864950081_item	3600839	et	4	main
kaksikud	doc_786864950081_item	3600841	et	3	main
suur	doc_786864950081_item	3600865	et	3	main
suur	doc_786864950081_item	3600869	et	3	main
helrohelised	doc_786864950081_item	3600872	et	4	main
harjutus	doc_786864950082_item	3600874	et	4	main
sinu	doc_786864950082_item	3600876	et	3	main
nimi	doc_786864950082_item	3600877	et	3	main
on	doc_786864950082_item	3600878	et	4	main
minu	doc_786864950082_item	3600879	et	3	main
nimi	doc_786864950082_item	3600880	et	3	main
perekonnanimi	doc_786864950082_item	3600889	et	3	main
budapestis	doc_786864950082_item	3600897	et	4	main
ja	doc_786864950082_item	3600903	et	3	main
ungari	doc_786864950082_item	3600906	et	4	main
ja	doc_786864950082_item	3600908	et	3	main
räägin	doc_786864950082_item	3600915	et	3	main
keelt	doc_786864950082_item	3600919	et	4	main
on	doc_786864950082_item	3600929	et	4	main
suur	doc_786864950082_item	3600934	et	3	main
milline	doc_786864950082_item	3600936	et	3	main
sa	doc_786864950082_item	3600964	et	3	main
elad	doc_786864950082_item	3600965	et	3	main
milline	doc_786864950082_item	3600966	et	3	main
on	doc_786864950082_item	3600967	et	4	main
sinu	doc_786864950082_item	3600968	et	3	main
majas	doc_786864950082_item	3600977	et	3	main
seitse	doc_786864950082_item	3600979	et	3	main
minu	doc_786864950083_item	3601028	et	3	main
on	doc_786864950083_item	3601030	et	4	main
tamm	doc_786864950083_item	3601032	et	3	main
ülikoolis	doc_786864950083_item	3601048	et	4	main
eesti	doc_786864950083_item	3601056	et	4	main
natuke-natuke	doc_786864950083_item	3601075	et	4	main
on	doc_786864950083_item	3601083	et	4	main
on	doc_786864950083_item	3601087	et	4	main
ja	doc_786864950083_item	3601089	et	3	main
kus	doc_786864950083_item	3601092	et	3	main
2000000	doc_786864950083_item	3601094	et	2	main
inimet	doc_786864950083_item	3601095	et	4	main
budapestis	doc_786864950083_item	3601096	et	4	main
ja	doc_786864950083_item	3601132	et	3	main
elame	doc_786864950083_item	3601133	et	3	main
museos	doc_786864950083_item	3601147	et	4	main
õde	doc_786864950083_item	3601148	et	4	main
vanem	doc_786864950083_item	3601159	et	4	main
elad	doc_786864950083_item	3601162	et	3	main
korter	doc_786864950083_item	3601166	et	3	main
elan	doc_786864950083_item	3601168	et	3	main
ja	doc_786864950083_item	3601174	et	3	main
majas	doc_786864950083_item	3601180	et	3	main
on	doc_786864950083_item	3601181	et	4	main
aknid	doc_786864950083_item	3601183	et	4	main
ja	doc_786864950083_item	3601184	et	3	main
mu	doc_786864950084_item	3601219	et	3	main
tamm	doc_786864950084_item	3601226	et	3	main
meie	doc_786864950079_item	3600573	et	4	main
laual	doc_786864950079_item	3600578	et	3	main
alas	doc_786864950079_item	3600579	et	3	main
on	doc_786864950079_item	3600581	et	4	main
elame	doc_786864950079_item	3600604	et	3	main
me	doc_786864950079_item	3600603	et	4	main
teisel	doc_786864950079_item	3600605	et	4	main
korrusel	doc_786864950079_item	3600606	et	3	main
majas	doc_786864950079_item	3600607	et	3	main
ei	doc_786864950079_item	3600608	et	4	main
ole	doc_786864950079_item	3600609	et	4	main
lifti	doc_786864950079_item	3600610	et	4	main
aga	doc_786864950079_item	3600611	et	3	main
on	doc_786864950079_item	3600612	et	4	main
trepp	doc_786864950079_item	3600613	et	3	main
maja	doc_786864950079_item	3600614	et	4	main
on	doc_786864950079_item	3600615	et	4	main
sinine	doc_786864950079_item	3600616	et	4	main
ja	doc_786864950079_item	3600617	et	3	main
hall	doc_786864950079_item	3600618	et	4	main
maja	doc_786864950079_item	3600619	et	4	main
asub	doc_786864950079_item	3600620	et	3	main
budas	doc_786864950079_item	3600621	et	4	main
budas	doc_786864950079_item	3600622	et	4	main
on	doc_786864950079_item	3600623	et	4	main
metsad	doc_786864950079_item	3600624	et	3	main
see	doc_786864950079_item	3600625	et	3	main
on	doc_786864950079_item	3600626	et	4	main
hea	doc_786864950079_item	3600627	et	4	main
linn	doc_786864950079_item	3600628	et	3	main
õpid	doc_786864950080_item	3600651	et	4	main
õpin	doc_786864950080_item	3600653	et	3	main
ma	doc_786864950080_item	3600661	et	3	main
eesti	doc_786864950080_item	3600664	et	4	main
keelt	doc_786864950080_item	3600665	et	4	main
räägid	doc_786864950080_item	3600669	et	4	main
ma	doc_786864950080_item	3600670	et	3	main
soome	doc_786864950080_item	3600672	et	3	main
ja	doc_786864950080_item	3600674	et	3	main
prantsuse	doc_786864950080_item	3600675	et	3	main
budapest	doc_786864950080_item	3600681	et	4	main
on	doc_786864950080_item	3600682	et	4	main
suur	doc_786864950080_item	3600683	et	3	main
linn	doc_786864950080_item	3600684	et	3	main
sinu	doc_786864950080_item	3600691	et	3	main
mul	doc_786864950080_item	3600693	et	3	main
töötab	doc_786864950080_item	3600704	et	3	main
sinu	doc_786864950080_item	3600725	et	3	main
vanavanemad	doc_786864950080_item	3600710	et	4	main
jäi	doc_786864950080_item	3600711	et	3	main
mont	doc_786864950080_item	3600712	et	4	main
agast	doc_786864950080_item	3600713	et	4	main
tagasi	doc_786864950080_item	3600714	et	3	main
pensionile	doc_786864950080_item	3600715	et	3	main
nad	doc_786864950080_item	3600716	et	3	main
ka	doc_786864950080_item	3600718	et	3	main
budapestis	doc_786864950080_item	3600719	et	4	main
elavad	doc_786864950080_item	3600717	et	4	main
kus	doc_786864950080_item	3600720	et	3	main
sa	doc_786864950080_item	3600721	et	3	main
elad	doc_786864950080_item	3600722	et	3	main
milline	doc_786864950080_item	3600723	et	3	main
mis	doc_786864950080_item	3600631	et	4	main
sinu	doc_786864950080_item	3600632	et	3	main
nimi	doc_786864950080_item	3600633	et	3	main
on	doc_786864950080_item	3600634	et	4	main
minu	doc_786864950080_item	3600635	et	3	main
peeter	doc_786864950080_item	3600638	et	3	main
peeter	doc_786864950080_item	3600640	et	3	main
eesnimi	doc_786864950080_item	3600642	et	3	main
sa	doc_786864950080_item	3600650	et	3	main
ja	doc_786864950080_item	3600656	et	3	main
ungari	doc_786864950080_item	3600657	et	4	main
ülikoolis	doc_786864950080_item	3600659	et	4	main
õpin	doc_786864950080_item	3600662	et	3	main
keeli	doc_786864950080_item	3600667	et	4	main
sa	doc_786864950080_item	3600668	et	3	main
budapest	doc_786864950080_item	3600680	et	4	main
ungari	doc_786864950080_item	3600687	et	4	main
pere	doc_786864950080_item	3600697	et	4	main
mul	doc_786864950080_item	3600698	et	3	main
isa	doc_786864950080_item	3600707	et	4	main
on	doc_786864950080_item	3600708	et	4	main
on	doc_786864950080_item	3600724	et	4	main
korter	doc_786864950080_item	3600726	et	3	main
ma	doc_786864950080_item	3600728	et	3	main
kivimajas	doc_786864950080_item	3600731	et	4	main
ypestis	doc_786864950080_item	3600730	et	4	main
ta	doc_786864950080_item	3600732	et	4	main
ei	doc_786864950080_item	3600733	et	4	main
ole	doc_786864950080_item	3600734	et	4	main
kõrge	doc_786864950080_item	3600735	et	4	main
maja	doc_786864950080_item	3600736	et	4	main
siin	doc_786864950080_item	3600737	et	4	main
on	doc_786864950080_item	3600738	et	4	main
nelja	doc_786864950080_item	3600739	et	4	main
korrust	doc_786864950080_item	3600740	et	3	main
ma	doc_786864950080_item	3600741	et	3	main
elan	doc_786864950080_item	3600742	et	3	main
esimasel	doc_786864950080_item	3600743	et	4	main
korrusel	doc_786864950080_item	3600744	et	3	main
mul	doc_786864950080_item	3600745	et	3	main
on	doc_786864950080_item	3600746	et	4	main
tuba	doc_786864950080_item	3600748	et	4	main
suur	doc_786864950080_item	3600747	et	3	main
mis	doc_786864950080_item	3600749	et	4	main
on	doc_786864950080_item	3600750	et	4	main
kaks	doc_786864950080_item	3600751	et	3	main
akent	doc_786864950080_item	3600752	et	3	main
ja	doc_786864950080_item	3600753	et	3	main
üks	doc_786864950080_item	3600754	et	3	main
uks	doc_786864950080_item	3600755	et	3	main
seinad	doc_786864950080_item	3600756	et	3	main
on	doc_786864950080_item	3600757	et	4	main
kollased	doc_786864950080_item	3600758	et	4	main
milline	doc_786864950081_item	3600761	et	3	main
meie	doc_786864950081_item	3600763	et	4	main
klassiruum	doc_786864950081_item	3600764	et	3	main
meie	doc_786864950081_item	3600765	et	4	main
klassiruum	doc_786864950081_item	3600766	et	3	main
mina	doc_786864950081_item	3600842	et	4	main
ei	doc_786864950081_item	3600843	et	4	main
ole	doc_786864950081_item	3600844	et	4	main
tädi	doc_786864950081_item	3600845	et	4	main
koska	doc_786864950081_item	3600846	et	4	main
õel	doc_786864950081_item	3600847	et	4	main
ei	doc_786864950081_item	3600848	et	4	main
ole	doc_786864950081_item	3600849	et	4	main
last	doc_786864950081_item	3600850	et	4	main
kus	doc_786864950081_item	3600851	et	3	main
sa	doc_786864950081_item	3600852	et	3	main
elad	doc_786864950081_item	3600853	et	3	main
milline	doc_786864950081_item	3600854	et	3	main
on	doc_786864950081_item	3600855	et	4	main
sinu	doc_786864950081_item	3600856	et	3	main
korter	doc_786864950081_item	3600857	et	3	main
maja	doc_786864950081_item	3600858	et	4	main
mina	doc_786864950081_item	3600859	et	4	main
elan	doc_786864950081_item	3600860	et	3	main
budapestis	doc_786864950081_item	3600861	et	4	main
meie	doc_786864950081_item	3600862	et	4	main
korter	doc_786864950081_item	3600863	et	3	main
on	doc_786864950081_item	3600767	et	4	main
seinad	doc_786864950081_item	3600769	et	3	main
on	doc_786864950081_item	3600770	et	4	main
kollased	doc_786864950081_item	3600771	et	4	main
ruumis	doc_786864950081_item	3600772	et	4	main
on	doc_786864950081_item	3600773	et	4	main
laed	doc_786864950081_item	3600774	et	4	main
ja	doc_786864950081_item	3600775	et	3	main
toolit	doc_786864950081_item	3600776	et	4	main
seinal	doc_786864950081_item	3600777	et	3	main
pild	doc_786864950081_item	3600779	et	3	main
ülikoolis	doc_786864950081_item	3600794	et	4	main
keelest	doc_786864950081_item	3600810	et	4	main
aru	doc_786864950081_item	3600811	et	4	main
milline	doc_786864950081_item	3600812	et	3	main
linn	doc_786864950081_item	3600813	et	3	main
on	doc_786864950081_item	3600814	et	4	main
pealinn	doc_786864950081_item	3600819	et	3	main
see	doc_786864950081_item	3600820	et	3	main
üks	doc_786864950081_item	3600837	et	3	main
tuba	doc_786864950081_item	3600867	et	4	main
on	doc_786864950081_item	3600868	et	4	main
on	doc_786864950082_item	3600885	et	4	main
eesnimi	doc_786864950082_item	3600886	et	3	main
ja	doc_786864950082_item	3600891	et	3	main
õpid	doc_786864950082_item	3600894	et	4	main
soome	doc_786864950082_item	3600901	et	3	main
ma	doc_786864950082_item	3600914	et	3	main
inglise	doc_786864950082_item	3600918	et	4	main
ja	doc_786864950082_item	3600920	et	3	main
räägin	doc_786864950082_item	3600921	et	3	main
veidi	doc_786864950082_item	3600922	et	3	main
linn	doc_786864950082_item	3600925	et	3	main
see	doc_786864950082_item	3600932	et	3	main
minu	doc_786864950082_item	3600954	et	3	main
pere	doc_786864950082_item	3600956	et	4	main
elab	doc_786864950082_item	3600957	et	3	main
külas	doc_786864950082_item	3600958	et	3	main
meil	doc_786864950082_item	3600960	et	4	main
suures	doc_786864950082_item	3600974	et	3	main
majas	doc_786864950082_item	3600976	et	3	main
nimi	doc_786864950083_item	3601026	et	3	main
on	doc_786864950083_item	3601040	et	4	main
tamm	doc_786864950083_item	3601041	et	3	main
kus	doc_786864950083_item	3601042	et	3	main
ja	doc_786864950083_item	3601043	et	3	main
õpin	doc_786864950083_item	3601047	et	3	main
keelt	doc_786864950083_item	3601057	et	4	main
räägid	doc_786864950083_item	3601061	et	4	main
veel	doc_786864950083_item	3601070	et	4	main
natuke	doc_786864950083_item	3601071	et	4	main
inglise	doc_786864950083_item	3601072	et	4	main
budapest	doc_786864950083_item	3601082	et	4	main
see	doc_786864950083_item	3601086	et	3	main
ilus	doc_786864950083_item	3601088	et	4	main
suur	doc_786864950083_item	3601090	et	3	main
linn	doc_786864950083_item	3601091	et	3	main
palju	doc_786864950083_item	3601098	et	4	main
budapest	doc_786864950083_item	3601105	et	4	main
koos	doc_786864950083_item	3601134	et	4	main
ei	doc_786864950083_item	3601137	et	4	main
ungari	doc_786864950083_item	3601139	et	4	main
pealinn	doc_786864950083_item	3601140	et	3	main
minu	doc_786864950083_item	3601141	et	3	main
isa	doc_786864950083_item	3601142	et	4	main
on	doc_786864950083_item	3601143	et	4	main
on	doc_786864950083_item	3601150	et	4	main
kus	doc_786864950083_item	3601160	et	3	main
sinu	doc_786864950083_item	3601165	et	3	main
on	doc_786864950083_item	3601172	et	4	main
suur	doc_786864950083_item	3601173	et	3	main
kollane	doc_786864950083_item	3601175	et	4	main
minul	doc_786864950083_item	3601176	et	3	main
seinä	doc_786864950083_item	3601186	et	4	main
on	doc_786864950083_item	3601187	et	4	main
mis	doc_786864950084_item	3601210	et	4	main
on	doc_786864950084_item	3601221	et	4	main
perekonnanimi	doc_786864950084_item	3601224	et	3	main
mida	doc_786864950084_item	3601229	et	4	main
õpin	doc_786864950084_item	3601233	et	3	main
keelt	doc_786864950084_item	3601243	et	4	main
ma	doc_786864950084_item	3601244	et	3	main
õpin	doc_786864950084_item	3601245	et	3	main
keeli	doc_786864950084_item	3601249	et	4	main
eesti	doc_786864950084_item	3601259	et	4	main
see	doc_786864950084_item	3601269	et	3	main
milline	doc_786864950084_item	3601276	et	3	main
mul	doc_786864950084_item	3601284	et	3	main
pensionär	doc_786864950084_item	3601311	et	3	main
üksi	doc_786864950084_item	3601314	et	4	main
elab	doc_786864950084_item	3601323	et	3	main
kus	doc_786864950084_item	3601325	et	3	main
sa	doc_786864950084_item	3601326	et	3	main
on	doc_786864950081_item	3600780	et	4	main
raamaturiuli	doc_786864950081_item	3600782	et	4	main
kus	doc_786864950081_item	3600783	et	3	main
ja	doc_786864950081_item	3600784	et	3	main
mida	doc_786864950081_item	3600785	et	4	main
sa	doc_786864950081_item	3600786	et	3	main
keeli	doc_786864950081_item	3600796	et	4	main
mina	doc_786864950081_item	3600799	et	4	main
räägin	doc_786864950081_item	3600800	et	3	main
soome	doc_786864950081_item	3600801	et	3	main
saksa	doc_786864950081_item	3600804	et	4	main
keelt	doc_786864950081_item	3600805	et	4	main
mina	doc_786864950081_item	3600806	et	4	main
saan	doc_786864950081_item	3600807	et	4	main
ungari	doc_786864950081_item	3600818	et	4	main
milline	doc_786864950081_item	3600824	et	3	main
sinu	doc_786864950081_item	3600826	et	3	main
vennad	doc_786864950081_item	3600835	et	3	main
on	doc_786864950081_item	3600864	et	4	main
mis	doc_786864950082_item	3600875	et	4	main
tamm	doc_786864950082_item	3600888	et	3	main
sa	doc_786864950082_item	3600893	et	3	main
ma	doc_786864950082_item	3600895	et	3	main
keelt	doc_786864950082_item	3600902	et	4	main
soome	doc_786864950082_item	3600916	et	3	main
saksakeelt	doc_786864950082_item	3600923	et	4	main
milline	doc_786864950082_item	3600924	et	3	main
on	doc_786864950082_item	3600926	et	4	main
ungarin	doc_786864950082_item	3600930	et	4	main
pealinn	doc_786864950082_item	3600931	et	3	main
sinu	doc_786864950082_item	3600938	et	3	main
pere	doc_786864950082_item	3600939	et	4	main
pere	doc_786864950082_item	3600941	et	4	main
minu	doc_786864950082_item	3600940	et	3	main
on	doc_786864950082_item	3600942	et	4	main
suur	doc_786864950082_item	3600943	et	3	main
ma	doc_786864950082_item	3600944	et	3	main
elan	doc_786864950082_item	3600945	et	3	main
koos	doc_786864950082_item	3600946	et	4	main
emage	doc_786864950082_item	3600947	et	4	main
budapestis	doc_786864950082_item	3600948	et	4	main
minu	doc_786864950082_item	3600949	et	3	main
vanaema	doc_786864950082_item	3600950	et	4	main
elab	doc_786864950082_item	3600951	et	3	main
ka	doc_786864950082_item	3600952	et	3	main
budapestis	doc_786864950082_item	3600953	et	4	main
korter	doc_786864950082_item	3600969	et	3	main
maja	doc_786864950082_item	3600970	et	4	main
ma	doc_786864950082_item	3600971	et	3	main
elan	doc_786864950082_item	3600972	et	3	main
budapestis	doc_786864950082_item	3600973	et	4	main
rohelises	doc_786864950082_item	3600975	et	4	main
pastapliiats	doc_786864950082_item	3601021	et	4	main
harjutus	doc_786864950083_item	3601023	et	4	main
sinu	doc_786864950083_item	3601025	et	3	main
anna	doc_786864950083_item	3601031	et	4	main
minu	doc_786864950083_item	3601033	et	3	main
on	doc_786864950083_item	3601035	et	4	main
anna	doc_786864950083_item	3601036	et	4	main
ja	doc_786864950083_item	3601037	et	3	main
minu	doc_786864950083_item	3601038	et	3	main
perekonnanimi	doc_786864950083_item	3601039	et	3	main
õpid	doc_786864950083_item	3601046	et	4	main
ja	doc_786864950083_item	3601050	et	3	main
keelt	doc_786864950083_item	3601052	et	4	main
mis	doc_786864950083_item	3601058	et	4	main
sa	doc_786864950083_item	3601060	et	3	main
keelt	doc_786864950083_item	3601067	et	4	main
ja	doc_786864950083_item	3601068	et	3	main
räägin	doc_786864950083_item	3601069	et	3	main
ja	doc_786864950083_item	3601074	et	3	main
keelt	doc_786864950083_item	3601077	et	4	main
budaösis	doc_786864950083_item	3601135	et	4	main
ole	doc_786864950083_item	3601138	et	4	main
töötab	doc_786864950083_item	3601146	et	3	main
nüüt	doc_786864950083_item	3601154	et	4	main
olen	doc_786864950083_item	3601157	et	3	main
sa	doc_786864950083_item	3601161	et	3	main
maja	doc_786864950083_item	3601171	et	4	main
tuba	doc_786864950083_item	3601179	et	4	main
anna	doc_786864950084_item	3601217	et	4	main
on	doc_786864950082_item	3600937	et	4	main
ema	doc_786864950082_item	3600955	et	4	main
kus	doc_786864950082_item	3600959	et	3	main
on	doc_786864950083_item	3601027	et	4	main
mida	doc_786864950083_item	3601044	et	4	main
budapest	doc_786864950083_item	3601081	et	4	main
pealinn	doc_786864950083_item	3601085	et	3	main
elab	doc_786864950083_item	3601093	et	3	main
duna	doc_786864950083_item	3601104	et	4	main
kaks	doc_786864950083_item	3601124	et	3	main
ja	doc_786864950083_item	3601123	et	3	main
poisi	doc_786864950083_item	3601125	et	3	main
minu	doc_786864950083_item	3601126	et	3	main
ja	doc_786864950083_item	3601128	et	3	main
isa	doc_786864950083_item	3601129	et	4	main
ema	doc_786864950083_item	3601127	et	4	main
elab	doc_786864950083_item	3601130	et	3	main
abidisis	doc_786864950083_item	3601131	et	4	main
on	doc_786864950082_item	3600978	et	4	main
korrust	doc_786864950082_item	3600980	et	3	main
ja	doc_786864950082_item	3600981	et	3	main
me	doc_786864950082_item	3600982	et	4	main
elame	doc_786864950082_item	3600983	et	3	main
viiel	doc_786864950082_item	3600984	et	3	main
korrusel	doc_786864950082_item	3600985	et	3	main
korteris	doc_786864950082_item	3600986	et	3	main
on	doc_786864950082_item	3600987	et	4	main
viis	doc_786864950082_item	3600988	et	4	main
tuba	doc_786864950082_item	3600989	et	4	main
minu	doc_786864950082_item	3600990	et	3	main
tuba	doc_786864950082_item	3600991	et	4	main
on	doc_786864950082_item	3600992	et	4	main
peen	doc_786864950082_item	3600993	et	3	main
ja	doc_786864950082_item	3600994	et	3	main
valge	doc_786864950082_item	3600995	et	4	main
laes	doc_786864950082_item	3600996	et	4	main
on	doc_786864950082_item	3600997	et	4	main
lamp	doc_786864950082_item	3600998	et	3	main
toas	doc_786864950082_item	3600999	et	3	main
on	doc_786864950082_item	3601000	et	4	main
laud	doc_786864950082_item	3601001	et	4	main
raamaturiiul	doc_786864950082_item	3601002	et	4	main
vaip	doc_786864950082_item	3601003	et	3	main
palju	doc_786864950082_item	3601004	et	4	main
taimi	doc_786864950082_item	3601005	et	4	main
ja	doc_786864950082_item	3601006	et	3	main
telekas	doc_786864950082_item	3601007	et	4	main
seinal	doc_786864950082_item	3601008	et	3	main
on	doc_786864950082_item	3601009	et	4	main
pilt	doc_786864950082_item	3601010	et	3	main
pildil	doc_786864950082_item	3601011	et	3	main
on	doc_786864950082_item	3601012	et	4	main
meie	doc_786864950082_item	3601013	et	4	main
suvila	doc_786864950082_item	3601014	et	4	main
laual	doc_786864950082_item	3601015	et	3	main
on	doc_786864950082_item	3601016	et	4	main
mõned	doc_786864950082_item	3601017	et	3	main
paberilehed	doc_786864950082_item	3601018	et	3	main
raamat	doc_786864950082_item	3601019	et	3	main
ja	doc_786864950082_item	3601020	et	3	main
kollane	doc_786864950083_item	3601188	et	4	main
ja	doc_786864950083_item	3601189	et	3	main
valge	doc_786864950083_item	3601190	et	4	main
katus	doc_786864950083_item	3601191	et	4	main
on	doc_786864950083_item	3601192	et	4	main
punane	doc_786864950083_item	3601193	et	4	main
ja	doc_786864950083_item	3601194	et	3	main
meil	doc_786864950083_item	3601195	et	4	main
on	doc_786864950083_item	3601196	et	4	main
suur	doc_786864950083_item	3601197	et	3	main
aid	doc_786864950083_item	3601198	et	4	main
see	doc_786864950083_item	3601199	et	3	main
suvel	doc_786864950083_item	3601200	et	3	main
on	doc_786864950083_item	3601201	et	4	main
rohkane	doc_786864950083_item	3601202	et	4	main
maja	doc_786864950083_item	3601203	et	4	main
ees	doc_786864950083_item	3601204	et	4	main
on	doc_786864950083_item	3601205	et	4	main
puut	doc_786864950083_item	3601207	et	4	main
kolme	doc_786864950083_item	3601206	et	4	main
mis	doc_786864950083_item	3601024	et	4	main
nimi	doc_786864950083_item	3601029	et	3	main
eesnimi	doc_786864950083_item	3601034	et	3	main
sa	doc_786864950083_item	3601045	et	3	main
itaalia	doc_786864950083_item	3601049	et	4	main
soome	doc_786864950083_item	3601051	et	3	main
nüüd	doc_786864950083_item	3601053	et	4	main
õpin	doc_786864950083_item	3601054	et	3	main
veel	doc_786864950083_item	3601055	et	4	main
keeli	doc_786864950083_item	3601059	et	4	main
mina	doc_786864950083_item	3601062	et	4	main
rägin	doc_786864950083_item	3601063	et	3	main
itaalia	doc_786864950083_item	3601064	et	4	main
ja	doc_786864950083_item	3601065	et	3	main
soome	doc_786864950083_item	3601066	et	3	main
keelt	doc_786864950083_item	3601073	et	4	main
eesti	doc_786864950083_item	3601076	et	4	main
milline	doc_786864950083_item	3601078	et	3	main
linn	doc_786864950083_item	3601079	et	3	main
on	doc_786864950083_item	3601080	et	4	main
ungari	doc_786864950083_item	3601084	et	4	main
on	doc_786864950083_item	3601097	et	4	main
kõrget	doc_786864950083_item	3601099	et	4	main
majit	doc_786864950083_item	3601100	et	4	main
ja	doc_786864950083_item	3601101	et	3	main
üks	doc_786864950083_item	3601102	et	3	main
jõki	doc_786864950083_item	3601103	et	4	main
on	doc_786864950083_item	3601106	et	4	main
vana	doc_786864950083_item	3601107	et	4	main
linn	doc_786864950083_item	3601108	et	3	main
milline	doc_786864950083_item	3601109	et	3	main
on	doc_786864950083_item	3601110	et	4	main
sinu	doc_786864950083_item	3601111	et	3	main
pere	doc_786864950083_item	3601112	et	4	main
minu	doc_786864950083_item	3601113	et	3	main
pere	doc_786864950083_item	3601114	et	4	main
on	doc_786864950083_item	3601115	et	4	main
suuri	doc_786864950083_item	3601116	et	3	main
minul	doc_786864950083_item	3601117	et	3	main
on	doc_786864950083_item	3601118	et	4	main
kolm	doc_786864950083_item	3601119	et	3	main
venda	doc_786864950083_item	3601120	et	4	main
üks	doc_786864950083_item	3601121	et	3	main
õde	doc_786864950083_item	3601122	et	4	main
budaös	doc_786864950083_item	3601136	et	4	main
inseneri	doc_786864950083_item	3601144	et	4	main
ema	doc_786864950083_item	3601145	et	4	main
taaskas	doc_786864950083_item	3601151	et	4	main
vennad	doc_786864950083_item	3601152	et	3	main
on	doc_786864950083_item	3601153	et	4	main
mina	doc_786864950083_item	3601156	et	4	main
milline	doc_786864950083_item	3601163	et	3	main
oma	doc_786864950083_item	3601178	et	4	main
palju	doc_786864950083_item	3601182	et	4	main
uksid	doc_786864950083_item	3601185	et	4	main
harjutus	doc_786864950084_item	3601209	et	4	main
anna	doc_786864950084_item	3601222	et	4	main
kus	doc_786864950084_item	3601227	et	3	main
ja	doc_786864950084_item	3601228	et	3	main
keelt	doc_786864950084_item	3601235	et	4	main
keelt	doc_786864950084_item	3601238	et	4	main
ma	doc_786864950084_item	3601239	et	3	main
inglise	doc_786864950084_item	3601254	et	4	main
keelt	doc_786864950084_item	3601260	et	4	main
on	doc_786864950084_item	3601266	et	4	main
ungaris	doc_786864950084_item	3601272	et	4	main
nüüt	doc_786864950083_item	3601149	et	4	main
koolis	doc_786864950083_item	3601155	et	4	main
kõige	doc_786864950083_item	3601158	et	4	main
on	doc_786864950083_item	3601164	et	4	main
maja	doc_786864950083_item	3601167	et	4	main
budaösis	doc_786864950083_item	3601169	et	4	main
meie	doc_786864950083_item	3601170	et	4	main
on	doc_786864950083_item	3601177	et	4	main
sinu	doc_786864950084_item	3601211	et	3	main
nimi	doc_786864950084_item	3601212	et	3	main
on	doc_786864950084_item	3601213	et	4	main
mu	doc_786864950084_item	3601214	et	3	main
nimi	doc_786864950084_item	3601215	et	3	main
on	doc_786864950084_item	3601216	et	4	main
mu	doc_786864950084_item	3601223	et	3	main
on	doc_786864950084_item	3601225	et	4	main
sa	doc_786864950084_item	3601230	et	3	main
soome	doc_786864950084_item	3601234	et	3	main
ja	doc_786864950084_item	3601236	et	3	main
eesti	doc_786864950084_item	3601237	et	4	main
keelt	doc_786864950084_item	3601257	et	4	main
ja	doc_786864950084_item	3601258	et	3	main
budapest	doc_786864950084_item	3601265	et	4	main
on	doc_786864950084_item	3601270	et	4	main
pere	doc_786864950084_item	3601281	et	4	main
on	doc_786864950084_item	3601282	et	4	main
on	doc_786864950084_item	3601285	et	4	main
vaig	doc_786864950084_item	3601286	et	4	main
üks	doc_786864950084_item	3601287	et	3	main
õde	doc_786864950084_item	3601288	et	4	main
ta	doc_786864950084_item	3601289	et	4	main
on	doc_786864950084_item	3601290	et	4	main
abelius	doc_786864950084_item	3601291	et	4	main
ja	doc_786864950084_item	3601292	et	3	main
ta	doc_786864950084_item	3601293	et	4	main
ootab	doc_786864950084_item	3601294	et	3	main
nüüd	doc_786864950084_item	3601295	et	4	main
last	doc_786864950084_item	3601296	et	4	main
ta	doc_786864950084_item	3601297	et	4	main
on	doc_786864950084_item	3601298	et	4	main
arst	doc_786864950084_item	3601299	et	3	main
ja	doc_786864950084_item	3601300	et	3	main
tal	doc_786864950084_item	3601301	et	3	main
mees	doc_786864950084_item	3601302	et	4	main
on	doc_786864950084_item	3601303	et	4	main
õpetaja	doc_786864950084_item	3601304	et	4	main
nad	doc_786864950084_item	3601305	et	3	main
töödavad	doc_786864950084_item	3601306	et	4	main
budapestis	doc_786864950084_item	3601307	et	4	main
mu	doc_786864950084_item	3601308	et	3	main
tamm	doc_786864950084_item	3601218	et	3	main
eesnimi	doc_786864950084_item	3601220	et	3	main
räägin	doc_786864950084_item	3601240	et	3	main
ka	doc_786864950084_item	3601241	et	3	main
inglise	doc_786864950084_item	3601242	et	4	main
mis	doc_786864950084_item	3601248	et	4	main
sa	doc_786864950084_item	3601250	et	3	main
keelt	doc_786864950084_item	3601255	et	4	main
soome	doc_786864950084_item	3601256	et	3	main
budapest	doc_786864950084_item	3601264	et	4	main
linn	doc_786864950084_item	3601268	et	3	main
pealinn	doc_786864950084_item	3601271	et	3	main
ma	doc_786864950084_item	3601273	et	3	main
budapestis	doc_786864950084_item	3601275	et	4	main
väike	doc_786864950084_item	3601283	et	4	main
ema	doc_786864950084_item	3601309	et	4	main
ta	doc_786864950084_item	3601312	et	4	main
elab	doc_786864950084_item	3601313	et	3	main
aastat	doc_786864950084_item	3601320	et	3	main
sinu	doc_786864950084_item	3601330	et	3	main
korter	doc_786864950084_item	3601331	et	3	main
suur	doc_786864950084_item	3601368	et	3	main
riiulid	doc_786864950084_item	3601372	et	3	main
on	doc_786864950084_item	3601384	et	4	main
on	doc_786864950084_item	3601387	et	4	main
minna	doc_786864950085_item	3601395	et	3	main
10	doc_786864950085_item	3601400	et	2	main
4	doc_786864950085_item	3601412	et	2	main
6	doc_786864950085_item	3601414	et	2	main
ei	doc_786864950085_item	3601417	et	4	main
metroga	doc_786864950085_item	3601425	et	4	main
sõita	doc_786864950085_item	3601428	et	3	main
jalakse	doc_786864950085_item	3601436	et	4	main
või	doc_786864950085_item	3601437	et	4	main
bussiga	doc_786864950085_item	3601438	et	3	main
kestab	doc_786864950085_item	3601448	et	4	main
minutid	doc_786864950085_item	3601450	et	3	main
kauem	doc_786864950085_item	3601451	et	4	main
kui	doc_786864950085_item	3601452	et	3	main
teine	doc_786864950085_item	3601453	et	3	main
aga	doc_786864950085_item	3601454	et	3	main
ma	doc_786864950085_item	3601455	et	3	main
ei	doc_786864950085_item	3601456	et	4	main
anni	doc_399014257213_item	3601463	et	3	main
ema	doc_399014257213_item	3601481	et	4	main
varsti	doc_399014257213_item	3601482	et	3	main
tahan	doc_399014257213_item	3601486	et	3	main
mina	doc_399014257213_item	3601492	et	4	main
sooviksid	doc_399014257213_item	3601496	et	4	main
vabandust	doc_399014257213_item	3601500	et	4	main
aitäh	doc_399014257213_item	3601511	et	3	main
inglise	doc_399014257213_item	3601518	et	4	main
teman	doc_399014257213_item	3601526	et	4	main
anni	doc_399014257213_item	3601527	et	3	main
täpselt	doc_399014257213_item	3601528	et	4	main
kala-justusalatt	doc_542009824769_item	3601631	et	4	main
3	doc_542009824769_item	3601634	et	2	main
supp	doc_542009824769_item	3601649	et	3	main
borš	doc_542009824769_item	3601651	et	2	main
uhha	doc_542009824769_item	3601653	et	4	main
praed	doc_542009824769_item	3601654	et	4	main
1	doc_542009824769_item	3601655	et	2	main
viiner	doc_542009824769_item	3601657	et	3	main
friikartul	doc_542009824769_item	3601659	et	3	main
sinepkastmega	doc_542009824769_item	3601664	et	4	main
tunikala	doc_542009824769_item	3601667	et	4	main
tillikastmega	doc_542009824769_item	3601668	et	3	main
3	doc_542009824769_item	3601669	et	2	main
naturalne	doc_542009824769_item	3601678	et	4	main
keedisega	doc_542009824769_item	3601688	et	3	main
kondenspiimaga	doc_542009824769_item	3601691	et	3	main
õpid	doc_786864950084_item	3601231	et	4	main
ma	doc_786864950084_item	3601232	et	3	main
ülikoolis	doc_786864950084_item	3601246	et	4	main
budapestis	doc_786864950084_item	3601247	et	4	main
räägid	doc_786864950084_item	3601251	et	4	main
ma	doc_786864950084_item	3601252	et	3	main
räägin	doc_786864950084_item	3601253	et	3	main
milline	doc_786864950084_item	3601261	et	3	main
linn	doc_786864950084_item	3601262	et	3	main
on	doc_786864950084_item	3601263	et	4	main
suur	doc_786864950084_item	3601267	et	3	main
elan	doc_786864950084_item	3601274	et	3	main
on	doc_786864950084_item	3601277	et	4	main
sinu	doc_786864950084_item	3601278	et	3	main
pere	doc_786864950084_item	3601279	et	4	main
mu	doc_786864950084_item	3601280	et	3	main
on	doc_786864950084_item	3601310	et	4	main
tagasi	doc_786864950084_item	3601321	et	3	main
pealinns	doc_786864950084_item	3601324	et	4	main
on	doc_786864950084_item	3601359	et	4	main
ja	doc_786864950084_item	3601367	et	3	main
on	doc_786864950084_item	3601374	et	4	main
punane	doc_786864950084_item	3601375	et	4	main
pinkid	doc_786864950084_item	3601385	et	4	main
aed	doc_786864950084_item	3601389	et	3	main
harjutus	doc_786864950085_item	3601391	et	4	main
ülikoolist	doc_786864950085_item	3601396	et	4	main
raudteejaama	doc_786864950085_item	3601398	et	4	main
tuleb	doc_786864950085_item	3601402	et	3	main
umbes	doc_786864950085_item	3601420	et	4	main
20	doc_786864950085_item	3601421	et	2	main
minutid	doc_786864950085_item	3601422	et	3	main
minna	doc_786864950085_item	3601424	et	3	main
3	doc_786864950085_item	3601426	et	2	main
tuleb	doc_786864950085_item	3601427	et	3	main
ülikoolist	doc_786864950085_item	3601432	et	4	main
fesenciek-jaama	doc_786864950085_item	3601433	et	4	main
umbes	doc_786864950085_item	3601443	et	4	main
20	doc_786864950085_item	3601444	et	2	main
minuti	doc_786864950085_item	3601445	et	3	main
teine	doc_786864950085_item	3601446	et	3	main
pari	doc_786864950085_item	3601449	et	4	main
dialoog	doc_399014257213_item	3601462	et	3	main
söök	doc_399014257213_item	3601465	et	3	main
maarja	doc_399014257213_item	3601467	et	3	main
koju	doc_399014257213_item	3601483	et	3	main
maarja	doc_399014257213_item	3601484	et	3	main
minna	doc_399014257213_item	3601487	et	3	main
anni	doc_399014257213_item	3601489	et	3	main
kana	doc_399014257213_item	3601503	et	4	main
karri	doc_399014257213_item	3601504	et	4	main
palun	doc_399014257213_item	3601505	et	3	main
helistas	doc_399014257213_item	3601514	et	3	main
ta	doc_399014257213_item	3601516	et	4	main
ma	doc_399014257213_item	3601524	et	3	main
isa	doc_786864950084_item	3601317	et	4	main
suri	doc_786864950084_item	3601318	et	3	main
paar	doc_786864950084_item	3601319	et	3	main
kõig	doc_786864950084_item	3601322	et	4	main
on	doc_786864950084_item	3601329	et	4	main
elan	doc_786864950084_item	3601334	et	3	main
budapestis	doc_786864950084_item	3601335	et	4	main
minu	doc_786864950084_item	3601336	et	3	main
elan	doc_786864950084_item	3601337	et	3	main
korteris	doc_786864950084_item	3601338	et	3	main
see	doc_786864950084_item	3601339	et	3	main
on	doc_786864950084_item	3601340	et	4	main
kõrges	doc_786864950084_item	3601341	et	4	main
majas	doc_786864950084_item	3601342	et	3	main
siin	doc_786864950084_item	3601343	et	4	main
ei	doc_786864950084_item	3601344	et	4	main
ole	doc_786864950084_item	3601345	et	4	main
lifti	doc_786864950084_item	3601346	et	4	main
vaid	doc_786864950084_item	3601347	et	3	main
trepp	doc_786864950084_item	3601348	et	3	main
korteris	doc_786864950084_item	3601349	et	3	main
on	doc_786864950084_item	3601350	et	4	main
palju	doc_786864950084_item	3601351	et	4	main
ruumis	doc_786864950084_item	3601352	et	4	main
tuba	doc_786864950084_item	3601353	et	4	main
on	doc_786864950084_item	3601354	et	4	main
valge	doc_786864950084_item	3601355	et	4	main
budapestis	doc_786864950084_item	3601315	et	4	main
mu	doc_786864950084_item	3601316	et	3	main
milline	doc_786864950084_item	3601328	et	3	main
maja	doc_786864950084_item	3601332	et	4	main
sinise	doc_786864950084_item	3601357	et	4	main
toas	doc_786864950084_item	3601358	et	3	main
ilus	doc_786864950084_item	3601366	et	4	main
on	doc_786864950084_item	3601370	et	4	main
maja	doc_786864950084_item	3601373	et	4	main
kuidas	doc_786864950085_item	3601393	et	3	main
sõita	doc_786864950085_item	3601403	et	3	main
kesta	doc_786864950085_item	3601418	et	4	main
kaua	doc_786864950085_item	3601419	et	3	main
fesenciek-jaamalt	doc_786864950085_item	3601429	et	3	main
raudteejaama	doc_786864950085_item	3601431	et	4	main
7	doc_786864950085_item	3601439	et	2	main
see	doc_786864950085_item	3601440	et	3	main
reisiga	doc_786864950085_item	3601441	et	3	main
kestab	doc_786864950085_item	3601442	et	4	main
palju	doc_786864950085_item	3601458	et	4	main
hasti	doc_399014257213_item	3601464	et	4	main
maarja	doc_399014257213_item	3601466	et	3	main
jah	doc_399014257213_item	3601468	et	3	main
ma	doc_399014257213_item	3601485	et	3	main
edinburghisse	doc_399014257213_item	3601488	et	4	main
ettekandja	doc_399014257213_item	3601501	et	4	main
kaks	doc_399014257213_item	3601502	et	3	main
anni	doc_399014257213_item	3601512	et	3	main
täpselt	doc_399014257213_item	3601523	et	4	main
salatid	doc_542009824769_item	3601629	et	3	main
rosalje	doc_542009824769_item	3601633	et	4	main
4	doc_542009824769_item	3601636	et	2	main
kapsa	doc_542009824769_item	3601648	et	4	main
5	doc_542009824769_item	3601652	et	2	main
liha	doc_542009824769_item	3601670	et	4	main
šnitsell	doc_542009824769_item	3601679	et	2	main
linnapiim	doc_542009824769_item	3601682	et	3	main
3	doc_542009824769_item	3601685	et	2	main
pannkoogid	doc_542009824769_item	3601687	et	3	main
kohupiimamarjakastmega	doc_542009824769_item	3601689	et	3	main
õuna-ananassi	doc_542009824769_item	3601693	et	4	main
5	doc_542009824769_item	3601695	et	2	main
apelsinikastmega	doc_542009824769_item	3601697	et	3	main
kohv	doc_542009824769_item	3601702	et	3	main
tee	doc_542009824769_item	3601704	et	4	main
4	doc_542009824769_item	3601707	et	2	main
5	doc_542009824769_item	3601709	et	2	main
mahl	doc_542009824769_item	3601710	et	3	main
või	doc_542009824769_item	3601711	et	4	main
limonaad	doc_542009824769_item	3601712	et	3	main
lisandid	doc_542009824769_item	3601713	et	3	main
1	doc_542009824769_item	3601714	et	2	main
3	doc_542009824769_item	3601718	et	2	main
5	doc_542009824769_item	3601722	et	2	main
menüü	doc_542009824770_item	3601726	et	4	main
kohupiimaga	doc_542009824770_item	3601763	et	3	main
4	doc_542009824770_item	3601766	et	2	main
1	doc_542009824770_item	3601772	et	2	main
želee	doc_542009824770_item	3601777	et	2	main
pähklid	doc_542009824770_item	3601785	et	3	main
1	doc_542009824770_item	3601788	et	2	main
2	doc_542009824770_item	3601790	et	2	main
3	doc_542009824770_item	3601792	et	2	main
vein	doc_542009824770_item	3601793	et	3	main
harjutus	doc_542009824814_item	3601810	et	4	main
amerikale	doc_542009824814_item	3601822	et	4	main
elust	doc_542009824814_item	3601824	et	3	main
ka	doc_542009824814_item	3601840	et	3	main
ma	doc_542009824814_item	3601842	et	3	main
rikast	doc_542009824814_item	3601854	et	4	main
lugesin	doc_685122975264_item	3601866	et	3	main
solvava	doc_685122975264_item	3601873	et	4	main
on	doc_685122975264_item	3601887	et	4	main
see	doc_685122975264_item	3601888	et	3	main
elad	doc_786864950084_item	3601327	et	3	main
ma	doc_786864950084_item	3601333	et	3	main
ja	doc_786864950084_item	3601356	et	3	main
on	doc_786864950084_item	3601365	et	4	main
maja	doc_786864950084_item	3601376	et	4	main
ala	doc_786864950084_item	3601383	et	4	main
tuleb	doc_786864950085_item	3601394	et	3	main
raudteejaama	doc_786864950085_item	3601415	et	4	main
reis	doc_786864950085_item	3601416	et	4	main
või	doc_786864950085_item	3601423	et	4	main
nyugati	doc_786864950085_item	3601430	et	4	main
tea	doc_786864950085_item	3601457	et	4	main
tee	doc_399014257213_item	3601461	et	4	main
meeldiv	doc_399014257213_item	3601470	et	4	main
anni	doc_399014257213_item	3601471	et	3	main
maarja	doc_399014257213_item	3601472	et	3	main
ma	doc_399014257213_item	3601473	et	3	main
pean	doc_399014257213_item	3601474	et	4	main
homme	doc_399014257213_item	3601475	et	3	main
sõitma	doc_399014257213_item	3601476	et	3	main
edinburghisse	doc_399014257213_item	3601477	et	4	main
aga	doc_399014257213_item	3601478	et	3	main
ma	doc_399014257213_item	3601479	et	3	main
tooli	doc_786864950084_item	3601360	et	4	main
raamaturiiuli	doc_786864950084_item	3601361	et	3	main
ja	doc_786864950084_item	3601362	et	3	main
lead	doc_786864950084_item	3601363	et	4	main
see	doc_786864950084_item	3601364	et	3	main
seinal	doc_786864950084_item	3601369	et	3	main
ka	doc_786864950084_item	3601371	et	3	main
ees	doc_786864950084_item	3601377	et	4	main
on	doc_786864950084_item	3601378	et	4	main
taim	doc_786864950084_item	3601379	et	3	main
ja	doc_786864950084_item	3601380	et	3	main
puud	doc_786864950084_item	3601381	et	4	main
puu	doc_786864950084_item	3601382	et	4	main
majal	doc_786864950084_item	3601386	et	3	main
suur	doc_786864950084_item	3601388	et	3	main
kirjuta	doc_786864950085_item	3601392	et	4	main
nyugati	doc_786864950085_item	3601397	et	4	main
maks	doc_786864950085_item	3601399	et	3	main
lauset	doc_786864950085_item	3601401	et	3	main
metroga	doc_786864950085_item	3601404	et	4	main
2	doc_786864950085_item	3601405	et	2	main
blaha	doc_786864950085_item	3601407	et	4	main
astoriast	doc_786864950085_item	3601406	et	4	main
lujza	doc_786864950085_item	3601408	et	4	main
metroojaama	doc_786864950085_item	3601409	et	4	main
sest	doc_786864950085_item	3601410	et	4	main
tramiga	doc_786864950085_item	3601411	et	4	main
või	doc_786864950085_item	3601413	et	4	main
või	doc_786864950085_item	3601434	et	4	main
minna	doc_786864950085_item	3601435	et	3	main
võib-olla	doc_786864950085_item	3601447	et	3	main
dialoog	doc_399014257213_item	3601460	et	3	main
mulle	doc_399014257213_item	3601469	et	4	main
varsti	doc_399014257213_item	3601490	et	3	main
lubada	doc_399014257213_item	3601493	et	3	main
sa	doc_399014257213_item	3601495	et	3	main
jah	doc_399014257213_item	3601499	et	3	main
üks	doc_399014257213_item	3601508	et	3	main
minutet	doc_399014257213_item	3601509	et	4	main
palun	doc_399014257213_item	3601510	et	3	main
keelt	doc_399014257213_item	3601519	et	4	main
vaga	doc_399014257213_item	3601520	et	4	main
hästi	doc_399014257213_item	3601521	et	3	main
maarja	doc_399014257213_item	3601522	et	3	main
lubasin	doc_399014257213_item	3601480	et	3	main
varsti	doc_399014257213_item	3601491	et	3	main
kas	doc_399014257213_item	3601494	et	3	main
veel	doc_399014257213_item	3601497	et	4	main
maarja	doc_399014257213_item	3601498	et	3	main
waitress	doc_399014257213_item	3601506	et	4	main
jah	doc_399014257213_item	3601507	et	3	main
ema	doc_399014257213_item	3601513	et	4	main
eesti	doc_399014257213_item	3601515	et	4	main
õppis	doc_399014257213_item	3601517	et	3	main
armistan	doc_399014257213_item	3601525	et	4	main
1	doc_542009824769_item	3601630	et	2	main
venegrett	doc_542009824769_item	3601637	et	4	main
ja	doc_542009824769_item	3601658	et	3	main
2	doc_542009824769_item	3601660	et	2	main
singi-šampinjoni	doc_542009824769_item	3601663	et	2	main
hakkliha	doc_542009824769_item	3601665	et	4	main
tomatikastmega	doc_542009824769_item	3601666	et	3	main
ananassiga	doc_542009824769_item	3601674	et	3	main
ja	doc_542009824769_item	3601675	et	3	main
juustuga	doc_542009824769_item	3601676	et	3	main
5	doc_542009824769_item	3601677	et	2	main
1	doc_542009824769_item	3601681	et	2	main
žele	doc_542009824769_item	3601684	et	2	main
puuviljade	doc_542009824769_item	3601690	et	3	main
friikartul	doc_542009824769_item	3601715	et	3	main
1	doc_542009824770_item	3601728	et	2	main
seljanka	doc_542009824770_item	3601731	et	4	main
aedviiljasupp	doc_542009824770_item	3601733	et	4	main
riis	doc_542009824770_item	3601753	et	3	main
1	doc_542009824770_item	3601757	et	2	main
pealinna	doc_542009824770_item	3601758	et	4	main
2	doc_542009824770_item	3601760	et	2	main
meresalat	doc_542009824770_item	3601765	et	3	main
5	doc_542009824770_item	3601769	et	2	main
magustoidud	doc_542009824770_item	3601771	et	3	main
ahjuõunad	doc_542009824770_item	3601773	et	3	main
2	doc_542009824770_item	3601775	et	2	main
3	doc_542009824770_item	3601778	et	2	main
kirss	doc_542009824770_item	3601782	et	3	main
meega	doc_542009824770_item	3601786	et	3	main
menüü	doc_542009824769_item	3601627	et	4	main
2	doc_542009824769_item	3601632	et	2	main
olivje	doc_542009824769_item	3601635	et	4	main
4	doc_542009824769_item	3601650	et	2	main
soolased	doc_542009824769_item	3601661	et	4	main
prantsusmaa	doc_542009824769_item	3601671	et	4	main
4	doc_542009824769_item	3601672	et	2	main
magustoit	doc_542009824769_item	3601680	et	3	main
2	doc_542009824769_item	3601683	et	2	main
magusad	doc_542009824769_item	3601686	et	3	main
4	doc_542009824769_item	3601692	et	2	main
jäätis	doc_542009824769_item	3601696	et	3	main
joogid	doc_542009824769_item	3601700	et	4	main
2	doc_542009824769_item	3601703	et	2	main
2	doc_542009824769_item	3601716	et	2	main
4	doc_542009824769_item	3601720	et	2	main
kartulipüree	doc_542009824769_item	3601721	et	4	main
menüü	doc_542009824769_item	3601628	et	4	main
5	doc_542009824769_item	3601638	et	2	main
kevaduse	doc_542009824769_item	3601639	et	4	main
salatt	doc_542009824769_item	3601640	et	4	main
supid	doc_542009824769_item	3601641	et	3	main
1	doc_542009824769_item	3601642	et	2	main
seljanka	doc_542009824769_item	3601643	et	4	main
2	doc_542009824769_item	3601644	et	2	main
külm	doc_542009824769_item	3601645	et	3	main
borš	doc_542009824769_item	3601646	et	2	main
3	doc_542009824769_item	3601647	et	2	main
lastepraad	doc_542009824769_item	3601656	et	3	main
pannkogit	doc_542009824769_item	3601662	et	4	main
liha	doc_542009824769_item	3601673	et	4	main
kokk	doc_542009824769_item	3601694	et	3	main
puuviljaga	doc_542009824769_item	3601698	et	3	main
1	doc_542009824769_item	3601701	et	2	main
3	doc_542009824769_item	3601705	et	2	main
kakao	doc_542009824769_item	3601706	et	4	main
piim	doc_542009824769_item	3601708	et	3	main
ahjukartul	doc_542009824769_item	3601723	et	3	main
supid	doc_542009824770_item	3601727	et	3	main
3	doc_542009824770_item	3601732	et	2	main
4	doc_542009824770_item	3601734	et	2	main
kalasupp	doc_542009824770_item	3601735	et	3	main
juustuga	doc_542009824770_item	3601736	et	3	main
majoneesiga	doc_542009824770_item	3601751	et	3	main
roheline	doc_542009824770_item	3601761	et	4	main
püree	doc_542009824770_item	3601800	et	4	main
2	doc_542009824770_item	3601801	et	2	main
fri-kartul	doc_542009824770_item	3601802	et	3	main
3	doc_542009824770_item	3601803	et	2	main
olin	doc_542009824814_item	3601813	et	3	main
reisist	doc_542009824814_item	3601821	et	3	main
papagoist	doc_542009824814_item	3601825	et	3	main
mänguasjadest	doc_542009824814_item	3601826	et	3	main
kullast	doc_542009824814_item	3601828	et	4	main
unistasin	doc_542009824814_item	3601837	et	3	main
väikesest	doc_542009824814_item	3601838	et	4	main
nüüd	doc_542009824814_item	3601841	et	4	main
oma	doc_542009824814_item	3601844	et	4	main
majast	doc_542009824814_item	3601845	et	4	main
autost	doc_542009824814_item	3601846	et	3	main
ja	doc_542009824814_item	3601847	et	3	main
elukutsest	doc_542009824814_item	3601848	et	4	main
klaverist	doc_542009824814_item	3601849	et	3	main
ja	doc_542009824814_item	3601850	et	3	main
kiri	doc_685122975264_item	3601862	et	3	main
olen	doc_685122975264_item	3601877	et	3	main
vaielda	doc_685122975264_item	3601882	et	4	main
ma	doc_685122975264_item	3601883	et	3	main
arvan	doc_685122975264_item	3601884	et	3	main
et	doc_685122975264_item	3601885	et	3	main
õige	doc_685122975264_item	3601886	et	4	main
on	doc_685122975264_item	3601906	et	4	main
astumiseni	doc_685122975264_item	3601908	et	4	main
kooli	doc_685122975264_item	3601937	et	4	main
ei	doc_685122975264_item	3601941	et	4	main
teadnud	doc_685122975264_item	3601942	et	4	main
kuhu	doc_685122975264_item	3601943	et	3	main
nad	doc_685122975264_item	3601944	et	3	main
õppima	doc_685122975264_item	3601945	et	3	main
lähevad	doc_685122975264_item	3601946	et	3	main
riigieksamite	doc_685122975264_item	3601951	et	3	main
siis	doc_685122975264_item	3601953	et	3	main
ei	doc_685122975264_item	3601962	et	4	main
töökohast	doc_685122975264_item	3601964	et	4	main
palga	doc_685122975264_item	3601966	et	3	main
kuid	doc_685122975264_item	3601967	et	4	main
ei	doc_685122975264_item	3601970	et	4	main
lõpetajad	doc_685122975264_item	3601978	et	4	main
osales	doc_685122975264_item	3601982	et	3	main
aga	doc_685122975264_item	3601986	et	3	main
palju	doc_685122975264_item	3601989	et	4	main
infotehnoloogiat	doc_685122975264_item	3602001	et	3	main
õppida	doc_685122975264_item	3602002	et	3	main
siia	doc_685122975264_item	3602003	et	4	main
oli	doc_685122975264_item	3602004	et	3	main
väga	doc_685122975264_item	3602005	et	3	main
veel	doc_685122975264_item	3602018	et	4	main
pärast	doc_685122975264_item	3602028	et	4	main
arvan	doc_685122975264_item	3602029	et	3	main
et	doc_685122975264_item	3602030	et	3	main
on	doc_685122975264_item	3602039	et	4	main
nende	doc_685122975264_item	3602040	et	4	main
inimesel	doc_685122975264_item	3602044	et	3	main
kahtlustada	doc_685122975264_item	3602079	et	3	main
perekonnanimi	doc_685122975264_item	3602084	et	3	main
2005	doc_685122975264_item	3602087	et	2	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_685122975264_item	3602088	et	4	main
läbi	doc_491521502045_item	3602091	et	4	main
ja	doc_491521502045_item	3602094	et	3	main
šokolaadikastmega	doc_542009824769_item	3601699	et	2	main
riis	doc_542009824769_item	3601717	et	3	main
kedukartul	doc_542009824769_item	3601719	et	4	main
menüü	doc_542009824770_item	3601725	et	4	main
2	doc_542009824770_item	3601730	et	2	main
5	doc_542009824770_item	3601752	et	2	main
loomaliha	doc_542009824770_item	3601754	et	4	main
fileega	doc_542009824770_item	3601755	et	3	main
salatid	doc_542009824770_item	3601756	et	3	main
salat	doc_542009824770_item	3601762	et	3	main
salat	doc_542009824770_item	3601768	et	3	main
kohupiimaga	doc_542009824770_item	3601774	et	3	main
puuviilja	doc_542009824770_item	3601776	et	4	main
jäätis	doc_542009824770_item	3601779	et	3	main
4	doc_542009824770_item	3601781	et	2	main
5	doc_542009824770_item	3601784	et	2	main
joogid	doc_542009824770_item	3601787	et	4	main
mahl	doc_542009824770_item	3601789	et	3	main
tee	doc_542009824770_item	3601791	et	4	main
4	doc_542009824770_item	3601794	et	2	main
kohf	doc_542009824770_item	3601795	et	4	main
5	doc_542009824770_item	3601796	et	2	main
morss	doc_542009824770_item	3601797	et	3	main
lisandid	doc_542009824770_item	3601798	et	3	main
1	doc_542009824770_item	3601799	et	2	main
väike	doc_542009824814_item	3601814	et	4	main
unistasin	doc_542009824814_item	3601817	et	3	main
mäele	doc_542009824814_item	3601819	et	3	main
rikast	doc_542009824814_item	3601823	et	4	main
ja	doc_542009824814_item	3601827	et	3	main
sepast	doc_542009824814_item	3601829	et	4	main
arvutist	doc_542009824814_item	3601830	et	4	main
ja	doc_542009824814_item	3601831	et	3	main
riis	doc_542009824770_item	3601804	et	3	main
4	doc_542009824770_item	3601805	et	2	main
makaroonid	doc_542009824770_item	3601806	et	4	main
5	doc_542009824770_item	3601807	et	2	main
ahjukartul	doc_542009824770_item	3601808	et	3	main
seenesupp	doc_542009824770_item	3601729	et	3	main
5	doc_542009824770_item	3601737	et	2	main
boršt	doc_542009824770_item	3601738	et	2	main
praed	doc_542009824770_item	3601739	et	4	main
1	doc_542009824770_item	3601740	et	2	main
ahjukartul	doc_542009824770_item	3601741	et	3	main
2	doc_542009824770_item	3601742	et	2	main
kartul	doc_542009824770_item	3601743	et	3	main
hapu	doc_542009824770_item	3601744	et	4	main
kastas	doc_542009824770_item	3601745	et	4	main
3	doc_542009824770_item	3601746	et	2	main
makaroonid	doc_542009824770_item	3601747	et	4	main
kastas	doc_542009824770_item	3601748	et	4	main
4	doc_542009824770_item	3601749	et	2	main
merekala	doc_542009824770_item	3601750	et	4	main
salat	doc_542009824770_item	3601759	et	3	main
3	doc_542009824770_item	3601764	et	2	main
kana-peedi	doc_542009824770_item	3601767	et	3	main
aedviiljasalat	doc_542009824770_item	3601770	et	4	main
marjademahlast	doc_542009824770_item	3601780	et	4	main
šokolaadis	doc_542009824770_item	3601783	et	2	main
ma	doc_542009824814_item	3601812	et	3	main
ma	doc_542009824814_item	3601816	et	3	main
matkast	doc_542009824814_item	3601818	et	4	main
ja	doc_542009824814_item	3601820	et	3	main
huvitavast	doc_542009824814_item	3601834	et	4	main
raamatust	doc_542009824814_item	3601835	et	4	main
ja	doc_542009824814_item	3601836	et	3	main
moest	doc_542009824814_item	3601851	et	4	main
riiest	doc_542009824814_item	3601852	et	3	main
ilusast	doc_542009824814_item	3601853	et	3	main
lugupeetud	doc_685122975264_item	3601863	et	4	main
juhtkirja	doc_685122975264_item	3601868	et	4	main
kiri	doc_685122975264_item	3601870	et	3	main
mulje	doc_685122975264_item	3601874	et	4	main
valmis	doc_685122975264_item	3601881	et	4	main
rühm	doc_685122975264_item	3601894	et	3	main
neid	doc_685122975264_item	3601896	et	4	main
kes	doc_685122975264_item	3601897	et	4	main
neist	doc_685122975264_item	3601901	et	4	main
saab	doc_685122975264_item	3601902	et	3	main
aga	doc_685122975264_item	3601910	et	3	main
minna	doc_685122975264_item	3601933	et	3	main
paljud	doc_685122975264_item	3601939	et	3	main
et	doc_685122975264_item	3601948	et	3	main
tulemus	doc_685122975264_item	3601952	et	3	main
kõik	doc_685122975264_item	3601976	et	4	main
praegu	doc_685122975264_item	3601977	et	3	main
abiturienti	doc_685122975264_item	3601985	et	4	main
raske	doc_685122975264_item	3602006	et	4	main
selleks	doc_685122975264_item	3602022	et	4	main
kõik	doc_685122975264_item	3602033	et	4	main
praeguse	doc_685122975264_item	3602034	et	3	main
solvav	doc_685122975264_item	3602042	et	4	main
on	doc_685122975264_item	3602045	et	4	main
siht	doc_685122975264_item	3602047	et	3	main
ja	doc_685122975264_item	3602062	et	3	main
saada	doc_685122975264_item	3602063	et	4	main
täiesti	doc_685122975264_item	3602064	et	3	main
normaalset	doc_685122975264_item	3602065	et	3	main
palka	doc_685122975264_item	3602066	et	4	main
liisida	doc_685122975264_item	3602067	et	4	main
auto	doc_685122975264_item	3602068	et	4	main
soetada	doc_685122975264_item	3602069	et	3	main
kodu	doc_685122975264_item	3602071	et	4	main
väike	doc_685122975264_item	3602070	et	4	main
siis	doc_685122975264_item	3602072	et	3	main
on	doc_685122975264_item	3602073	et	4	main
see	doc_685122975264_item	3602074	et	3	main
kui	doc_542009824814_item	3601811	et	3	main
siis	doc_542009824814_item	3601815	et	3	main
oma	doc_542009824814_item	3601832	et	4	main
lennukist	doc_542009824814_item	3601833	et	3	main
õest	doc_542009824814_item	3601839	et	4	main
unistan	doc_542009824814_item	3601843	et	3	main
neiust	doc_542009824814_item	3601855	et	4	main
oma	doc_542009824814_item	3601856	et	4	main
tegevust	doc_542009824814_item	3601857	et	4	main
isaga	doc_542009824814_item	3601858	et	3	main
ja	doc_542009824814_item	3601859	et	3	main
seksuaalsest	doc_542009824814_item	3601860	et	3	main
sekretärist	doc_542009824814_item	3601861	et	3	main
tiina	doc_685122975264_item	3601864	et	4	main
teie	doc_685122975264_item	3601867	et	4	main
läbi	doc_685122975264_item	3601869	et	4	main
jättis	doc_685122975264_item	3601871	et	3	main
natuke	doc_685122975264_item	3601872	et	4	main
mõnede	doc_685122975264_item	3601875	et	3	main
mõnedest	doc_685122975264_item	3601879	et	3	main
olen	doc_685122975264_item	3601880	et	3	main
on	doc_685122975264_item	3601895	et	4	main
mis	doc_685122975264_item	3601900	et	4	main
vaid	doc_685122975264_item	3601903	et	3	main
kui	doc_685122975264_item	3601934	et	3	main
lõpetasin	doc_685122975264_item	3601936	et	3	main
veel	doc_685122975264_item	3601940	et	4	main
ei	doc_685122975264_item	3601949	et	4	main
oli	doc_685122975264_item	3601954	et	3	main
tähtis	doc_685122975264_item	3601956	et	4	main
mõtle	doc_685122975264_item	3601963	et	4	main
ja	doc_685122975264_item	3601965	et	3	main
saa	doc_685122975264_item	3601971	et	4	main
kindlalt	doc_685122975264_item	3601973	et	4	main
öelda	doc_685122975264_item	3601974	et	4	main
et	doc_685122975264_item	3601975	et	3	main
on	doc_685122975264_item	3601979	et	4	main
küsitluses	doc_685122975264_item	3601981	et	4	main
lõpetab	doc_685122975264_item	3601988	et	3	main
palju	doc_685122975264_item	3601990	et	4	main
matemaatika	doc_685122975264_item	3602020	et	4	main
riigieksami	doc_685122975264_item	3602021	et	3	main
iga	doc_685122975264_item	3602043	et	4	main
oma	doc_685122975264_item	3602046	et	4	main
ta	doc_685122975264_item	3602049	et	4	main
püstitab	doc_685122975264_item	3602050	et	3	main
seda	doc_685122975264_item	3602051	et	3	main
mida	doc_685122975264_item	3602052	et	4	main
tal	doc_685122975264_item	3602053	et	3	main
meie	doc_685122975264_item	3602080	et	4	main
eesnimi	doc_685122975264_item	3602083	et	3	main
10	doc_685122975264_item	3602085	et	2	main
dets	doc_685122975264_item	3602086	et	4	main
vastus	doc_491521502045_item	3602097	et	3	main
ja	doc_491521502045_item	3602116	et	3	main
tallinnas	doc_491521502045_item	3602119	et	4	main
minna	doc_491521502045_item	3602120	et	3	main
tahad	doc_491521502045_item	3602121	et	3	main
jään	doc_491521502045_item	3602122	et	3	main
vastust	doc_491521502045_item	3602123	et	4	main
loosi	doc_491521502045_item	3602146	et	4	main
veel	doc_491521502045_item	3602150	et	4	main
ma	doc_491521502045_item	3602151	et	3	main
külastada	doc_491521502045_item	3602153	et	3	main
sõpru	doc_491521502045_item	3602155	et	3	main
juhuslik	doc_491521501735_item	3602167	et	3	main
21-63	doc_491521501735_item	3602169	et	2	main
06	doc_491521501735_item	3602174	et	2	main
2002	doc_491521501735_item	3602176	et	2	main
soovin	doc_491521501735_item	3602180	et	3	main
välja	doc_491521501735_item	3602184	et	4	main
informatsiooni	doc_491521501735_item	3602191	et	4	main
eesti	doc_491521501735_item	3602197	et	4	main
on	doc_491521501735_item	3602210	et	4	main
keelt	doc_491521501735_item	3602219	et	4	main
kalep	doc_685122975264_item	3601865	et	4	main
punktidega	doc_685122975264_item	3601876	et	3	main
nõus	doc_685122975264_item	3601878	et	4	main
te	doc_685122975264_item	3601890	et	4	main
ütlete	doc_685122975264_item	3601891	et	3	main
teine	doc_685122975264_item	3601892	et	3	main
suur	doc_685122975264_item	3601893	et	3	main
tea	doc_685122975264_item	3601899	et	4	main
nädal	doc_685122975264_item	3601905	et	3	main
nad	doc_685122975264_item	3601911	et	3	main
ei	doc_685122975264_item	3601912	et	4	main
tea	doc_685122975264_item	3601913	et	4	main
isegi	doc_685122975264_item	3601914	et	4	main
umbkaudu	doc_685122975264_item	3601915	et	3	main
mitte	doc_685122975264_item	3601916	et	3	main
see	doc_685122975264_item	3601917	et	3	main
on	doc_685122975264_item	3601918	et	4	main
uus	doc_685122975264_item	3601919	et	3	main
asi	doc_685122975264_item	3601920	et	4	main
tulnud	doc_685122975264_item	3601921	et	4	main
koos	doc_685122975264_item	3601922	et	4	main
riigieksamite	doc_685122975264_item	3601923	et	3	main
loteriiga	doc_685122975264_item	3601924	et	3	main
see	doc_685122975264_item	3601925	et	3	main
kaine	doc_685122975264_item	3601926	et	4	main
arvestus	doc_685122975264_item	3601927	et	4	main
kuhu	doc_685122975264_item	3601928	et	3	main
nende	doc_685122975264_item	3601929	et	4	main
punktidega	doc_685122975264_item	3601930	et	3	main
üldse	doc_685122975264_item	3601931	et	3	main
saab	doc_685122975264_item	3601932	et	3	main
et	doc_685122975264_item	3601889	et	3	main
ei	doc_685122975264_item	3601898	et	4	main
mõni	doc_685122975264_item	3601904	et	3	main
ülikoolidesse	doc_685122975264_item	3601907	et	3	main
aega	doc_685122975264_item	3601909	et	4	main
väga	doc_685122975264_item	3601938	et	3	main
teadnud	doc_685122975264_item	3601950	et	4	main
teiselt	doc_685122975264_item	3601968	et	4	main
sellised	doc_685122975264_item	3601980	et	4	main
ainult	doc_685122975264_item	3601983	et	4	main
tavaliselt	doc_685122975264_item	3601987	et	4	main
minu	doc_685122975264_item	3602009	et	3	main
tulemused	doc_685122975264_item	3602010	et	3	main
ei	doc_685122975264_item	3602011	et	4	main
olnud	doc_685122975264_item	3602012	et	4	main
väga	doc_685122975264_item	3602013	et	3	main
hea	doc_685122975264_item	3602014	et	4	main
ja	doc_685122975264_item	3602015	et	3	main
ma	doc_685122975264_item	3602016	et	3	main
tegin	doc_685122975264_item	3602017	et	3	main
ei	doc_685122975264_item	3602023	et	4	main
ei	doc_685122975264_item	3602031	et	4	main
tohi	doc_685122975264_item	3602032	et	4	main
suhtes	doc_685122975264_item	3602041	et	4	main
vaja	doc_685122975264_item	3602054	et	4	main
tema	doc_685122975264_item	3602075	et	4	main
valik	doc_685122975264_item	3602076	et	3	main
ja	doc_685122975264_item	3602077	et	3	main
lugege	doc_491521502045_item	3602090	et	3	main
marguse	doc_491521502045_item	3602092	et	4	main
kirjutage	doc_491521502045_item	3602095	et	3	main
kuhu	doc_491521502045_item	3602117	et	3	main
eest	doc_491521502045_item	3602130	et	4	main
tallinnasse	doc_491521502045_item	3602133	et	3	main
järgmisel	doc_491521502045_item	3602134	et	3	main
oota	doc_491521502045_item	3602136	et	4	main
mind	doc_491521502045_item	3602137	et	4	main
esmaspäeval	doc_491521502045_item	3602138	et	3	main
viieks	doc_491521502045_item	3602139	et	3	main
päevaks	doc_491521502045_item	3602140	et	3	main
tallinnasse	doc_491521502045_item	3602141	et	3	main
ma	doc_491521502045_item	3602142	et	3	main
tahan	doc_491521502045_item	3602143	et	3	main
minna	doc_491521502045_item	3602144	et	3	main
toompea	doc_491521502045_item	3602145	et	4	main
eesnimi	doc_491521501735_item	3602165	et	3	main
5555555	doc_491521501735_item	3602173	et	2	main
klienditeenindaja	doc_491521501735_item	3602189	et	4	main
kohta	doc_491521501735_item	3602194	et	4	main
lugesin	doc_491521501735_item	3602195	et	3	main
oskan	doc_491521501735_item	3602202	et	3	main
windows	doc_491521501735_item	3602205	et	4	main
vabalt	doc_491521501735_item	3602216	et	4	main
ka	doc_491521501735_item	3602217	et	3	main
eesti	doc_491521501735_item	3602218	et	4	main
ole	doc_491521501735_item	3602228	et	4	main
kogemust	doc_491521501735_item	3602229	et	3	main
kaubanduses	doc_491521501735_item	3602230	et	3	main
kui	doc_491521501735_item	3602231	et	3	main
soovin	doc_491521501906_item	3602278	et	3	main
poolt	doc_491521501906_item	3602281	et	4	main
kuulutatud	doc_491521501906_item	3602283	et	4	main
konkursil	doc_491521501906_item	3602284	et	3	main
bns	doc_491521501906_item	3602285	et	4	main
teie	doc_491521501906_item	3602290	et	4	main
ekspress	doc_491521501906_item	3602296	et	4	main
firmas	doc_491521501906_item	3602299	et	3	main
ja	doc_491521501906_item	3602315	et	3	main
kontrolib	doc_491521501906_item	3602317	et	4	main
tean	doc_491521501906_item	3602321	et	3	main
kuidas	doc_491521501906_item	3602322	et	3	main
koos	doc_491521501906_item	3602347	et	4	main
töötama	doc_491521501906_item	3602348	et	3	main
mina	doc_685122975264_item	3601935	et	4	main
sest	doc_685122975264_item	3601947	et	4	main
nendel	doc_685122975264_item	3601955	et	4	main
kuhugi	doc_685122975264_item	3601957	et	4	main
õppida	doc_685122975264_item	3601958	et	3	main
saada	doc_685122975264_item	3601959	et	4	main
ja	doc_685122975264_item	3601960	et	3	main
nad	doc_685122975264_item	3601961	et	3	main
poolt	doc_685122975264_item	3601969	et	4	main
teie	doc_685122975264_item	3601972	et	4	main
140	doc_685122975264_item	3601984	et	2	main
rohkem	doc_685122975264_item	3601991	et	4	main
näiteks	doc_685122975264_item	3601992	et	4	main
minul	doc_685122975264_item	3601993	et	3	main
oli	doc_685122975264_item	3601994	et	3	main
juba	doc_685122975264_item	3601995	et	3	main
kindel	doc_685122975264_item	3601996	et	3	main
eesmärk	doc_685122975264_item	3601997	et	3	main
et	doc_685122975264_item	3601998	et	3	main
ma	doc_685122975264_item	3601999	et	3	main
tahan	doc_685122975264_item	3602000	et	3	main
sisse	doc_685122975264_item	3602007	et	4	main
saada	doc_685122975264_item	3602008	et	4	main
kord	doc_685122975264_item	3602019	et	4	main
siia	doc_685122975264_item	3602024	et	4	main
sisse	doc_685122975264_item	3602025	et	4	main
saada	doc_685122975264_item	3602026	et	4	main
selle	doc_685122975264_item	3602027	et	4	main
abituriendid	doc_685122975264_item	3602035	et	3	main
üldistada	doc_685122975264_item	3602036	et	3	main
sest	doc_685122975264_item	3602037	et	4	main
see	doc_685122975264_item	3602038	et	3	main
ja	doc_685122975264_item	3602048	et	3	main
on	doc_685122975264_item	3602055	et	4	main
kui	doc_685122975264_item	3602056	et	3	main
ta	doc_685122975264_item	3602057	et	4	main
tahaks	doc_685122975264_item	3602058	et	3	main
töötada	doc_685122975264_item	3602059	et	3	main
rahulikult	doc_685122975264_item	3602060	et	4	main
rabelemata	doc_685122975264_item	3602061	et	4	main
selles	doc_685122975264_item	3602078	et	4	main
kiri	doc_491521502045_item	3602089	et	3	main
kiri	doc_491521502045_item	3602093	et	3	main
oled	doc_491521502045_item	3602115	et	3	main
sa	doc_491521502045_item	3602118	et	3	main
ma	doc_491521502045_item	3602131	et	3	main
vanalinnas	doc_491521502045_item	3602147	et	4	main
vastust	doc_491521502045_item	3602157	et	4	main
eesnimi	doc_491521502045_item	3602160	et	3	main
ametlik	doc_491521501735_item	3602163	et	3	main
tel	doc_491521501735_item	3602172	et	4	main
oktoober	doc_491521501735_item	3602175	et	3	main
eesnimi	doc_491521501735_item	3602178	et	3	main
kondideerida	doc_491521501735_item	3602181	et	4	main
teie	doc_491521501735_item	3602182	et	4	main
leidmiseks	doc_491521501735_item	3602190	et	4	main
ajalehest	doc_491521501735_item	3602196	et	4	main
töötada	doc_491521501735_item	3602203	et	3	main
vene	doc_491521501735_item	3602211	et	4	main
natukene	doc_491521501735_item	3602220	et	4	main
direktor	doc_491521501906_item	3602277	et	3	main
pearaamatupidaja	doc_491521501906_item	3602287	et	4	main
leidmiseks	doc_491521501906_item	3602288	et	4	main
ma	doc_491521501906_item	3602297	et	3	main
töötan	doc_491521501906_item	3602298	et	3	main
kes	doc_491521501906_item	3602300	et	4	main
töötab	doc_491521501906_item	3602301	et	3	main
kõiges	doc_491521501906_item	3602302	et	4	main
europas	doc_491521501906_item	3602303	et	4	main
ma	doc_491521501906_item	3602304	et	3	main
olen	doc_491521501906_item	3602305	et	3	main
mitu	doc_491521501906_item	3602313	et	4	main
kandidatuur	doc_491521501906_item	3602340	et	3	main
teile	doc_491521501906_item	3602342	et	4	main
me	doc_491521501906_item	3602344	et	4	main
varsti	doc_491521501906_item	3602345	et	3	main
hakkame	doc_491521501906_item	3602346	et	3	main
koopiad	doc_491521501906_item	3602351	et	3	main
lugupidamisega	doc_491521501906_item	3602352	et	3	main
järelpärimine	doc_973441205349_item	3602357	et	3	main
4	doc_973441205349_item	3602362	et	2	main
plink	doc_973441205349_item	3602374	et	3	main
plonk	doc_973441205349_item	3602375	et	4	main
ei	doc_685122975264_item	3602081	et	4	main
tohi	doc_685122975264_item	3602082	et	4	main
talle	doc_491521502045_item	3602096	et	4	main
kus	doc_491521502045_item	3602098	et	3	main
on	doc_491521502045_item	3602099	et	4	main
sõna	doc_491521502045_item	3602101	et	4	main
tere	doc_491521502045_item	3602102	et	3	main
20-25	doc_491521502045_item	3602100	et	2	main
kirjuta	doc_491521502045_item	3602103	et	4	main
palun	doc_491521502045_item	3602104	et	3	main
mulle	doc_491521502045_item	3602105	et	4	main
millal	doc_491521502045_item	3602106	et	3	main
sa	doc_491521502045_item	3602107	et	3	main
tallinnasse	doc_491521502045_item	3602108	et	3	main
tuled	doc_491521502045_item	3602109	et	4	main
mitu	doc_491521502045_item	3602110	et	4	main
päeva	doc_491521502045_item	3602111	et	4	main
sa	doc_491521502045_item	3602112	et	3	main
minu	doc_491521502045_item	3602113	et	3	main
juures	doc_491521502045_item	3602114	et	4	main
ootama	doc_491521502045_item	3602124	et	3	main
tere	doc_491521502045_item	3602125	et	3	main
margus	doc_491521502045_item	3602126	et	3	main
tänan	doc_491521502045_item	3602127	et	3	main
sulle	doc_491521502045_item	3602128	et	3	main
kirja	doc_491521502045_item	3602129	et	4	main
tullen	doc_491521502045_item	3602132	et	4	main
ja	doc_491521502045_item	3602148	et	3	main
oma	doc_491521502045_item	3602154	et	4	main
jään	doc_491521502045_item	3602156	et	3	main
ootama	doc_491521502045_item	3602158	et	3	main
tervitab	doc_491521502045_item	3602159	et	3	main
nädalal	doc_491521502045_item	3602135	et	3	main
muuseumis	doc_491521502045_item	3602149	et	3	main
tahan	doc_491521502045_item	3602152	et	3	main
perekonnanimi	doc_491521501735_item	3602166	et	3	main
kohtla-järv	doc_491521501735_item	3602170	et	3	main
lp	doc_491521501735_item	3602177	et	4	main
poolt	doc_491521501735_item	3602183	et	4	main
tietopuhelin	doc_491521501735_item	3602187	et	4	main
oü	doc_491521501735_item	3602188	et	4	main
pakkumise	doc_491521501735_item	3602193	et	4	main
21	doc_491521501735_item	3602200	et	2	main
aastane	doc_491521501735_item	3602201	et	4	main
keel	doc_491521501735_item	3602212	et	4	main
aga	doc_491521501735_item	3602213	et	3	main
ma	doc_491521501735_item	3602214	et	3	main
räägin	doc_491521501735_item	3602215	et	3	main
oskan	doc_491521501735_item	3602221	et	3	main
juhuslik	doc_491521501906_item	3602265	et	3	main
3-19	doc_491521501906_item	3602266	et	2	main
kohtla	doc_491521501906_item	3602267	et	4	main
jarve	doc_491521501906_item	3602268	et	4	main
41323	doc_491521501906_item	3602269	et	2	main
tel	doc_491521501906_item	3602270	et	4	main
teha	doc_491521501906_item	3602323	et	3	main
aruande	doc_491521501906_item	3602324	et	4	main
vastavalt	doc_491521501906_item	3602325	et	4	main
eesti	doc_491521501906_item	3602326	et	4	main
vabariigi	doc_491521501906_item	3602327	et	3	main
ning	doc_491521501906_item	3602328	et	3	main
rahvusvahelisele	doc_491521501906_item	3602329	et	4	main
seadusandlusele	doc_491521501906_item	3602330	et	3	main
oma	doc_491521501906_item	3602331	et	4	main
tööks	doc_491521501906_item	3602332	et	3	main
kasutan	doc_491521501906_item	3602333	et	3	main
raamatupidamisprogramm	doc_491521501906_item	3602334	et	3	main
saf	doc_491521501906_item	3602335	et	4	main
ma	doc_491521501906_item	3602336	et	3	main
loodan	doc_491521501906_item	3602337	et	3	main
kiri	doc_491521501735_item	3602164	et	3	main
pst	doc_491521501735_item	3602168	et	3	main
31022	doc_491521501735_item	3602171	et	2	main
perekonnanimi	doc_491521501735_item	3602179	et	3	main
kuulutatud	doc_491521501735_item	3602185	et	4	main
konkursil	doc_491521501735_item	3602186	et	3	main
teie	doc_491521501735_item	3602192	et	4	main
ekspress	doc_491521501735_item	3602198	et	4	main
olen	doc_491521501735_item	3602199	et	3	main
kompuutril	doc_491521501735_item	3602204	et	4	main
excel	doc_491521501735_item	3602206	et	4	main
programmidega	doc_491521501735_item	3602207	et	3	main
minu	doc_491521501735_item	3602208	et	3	main
emakeel	doc_491521501735_item	3602209	et	4	main
ka	doc_491521501735_item	3602222	et	3	main
keelt	doc_491521501735_item	3602224	et	4	main
kahjuks	doc_491521501735_item	3602225	et	4	main
mul	doc_491521501735_item	3602226	et	3	main
ei	doc_491521501735_item	3602227	et	4	main
ma	doc_491521501735_item	3602232	et	3	main
võin	doc_491521501735_item	3602233	et	3	main
selle	doc_491521501735_item	3602234	et	4	main
alati	doc_491521501735_item	3602235	et	4	main
kiiresti	doc_491521501735_item	3602236	et	3	main
omandada	doc_491521501735_item	3602237	et	3	main
ma	doc_491521501735_item	3602238	et	3	main
olen	doc_491521501735_item	3602239	et	3	main
aktiivne	doc_491521501735_item	3602240	et	3	main
iseseisev	doc_491521501735_item	3602241	et	3	main
ja	doc_491521501735_item	3602242	et	3	main
mul	doc_491521501735_item	3602243	et	3	main
on	doc_491521501735_item	3602244	et	4	main
hea	doc_491521501735_item	3602245	et	4	main
suhtlemisoskus	doc_491521501735_item	3602246	et	3	main
soovitav	doc_491521501735_item	3602247	et	4	main
5000	doc_491521501735_item	3602249	et	2	main
palk	doc_491521501735_item	3602248	et	3	main
krooni	doc_491521501735_item	3602250	et	4	main
meeldivale	doc_491521501735_item	3602251	et	4	main
koostööle	doc_491521501735_item	3602252	et	3	main
lootes	doc_491521501735_item	3602253	et	4	main
eesnimi	doc_491521501735_item	3602254	et	3	main
perekonnanimi	doc_491521501735_item	3602255	et	3	main
08102002	doc_491521501735_item	3602256	et	2	main
lisa	doc_491521501735_item	3602257	et	4	main
cv	doc_491521501735_item	3602258	et	4	main
diplom	doc_491521501735_item	3602259	et	3	main
koopiad	doc_491521501735_item	3602260	et	3	main
kiri	doc_491521501906_item	3602264	et	3	main
ametlik	doc_491521501906_item	3602263	et	3	main
55	doc_491521501906_item	3602273	et	2	main
inglise	doc_491521501735_item	3602223	et	4	main
härra	doc_491521501906_item	3602276	et	4	main
kontserni	doc_491521501906_item	3602286	et	4	main
pakkumise	doc_491521501906_item	3602291	et	4	main
pearaamatupidaja	doc_491521501906_item	3602306	et	4	main
ja	doc_491521501906_item	3602307	et	3	main
vastan	doc_491521501906_item	3602308	et	3	main
tütarfirmad	doc_491521501906_item	3602314	et	3	main
neid	doc_491521501906_item	3602318	et	4	main
ka	doc_491521501906_item	3602319	et	3	main
ma	doc_491521501906_item	3602320	et	3	main
et	doc_491521501906_item	3602338	et	3	main
minu	doc_491521501906_item	3602339	et	3	main
lisa	doc_491521501906_item	3602349	et	4	main
eesnimi	doc_491521501906_item	3602353	et	3	main
8102002	doc_491521501906_item	3602355	et	2	main
muusika	doc_973441205349_item	3602360	et	4	main
tartu	doc_973441205349_item	3602365	et	4	main
meie	doc_973441205349_item	3602377	et	4	main
klass	doc_973441205349_item	3602378	et	3	main
tahab	doc_973441205349_item	3602379	et	3	main
külastada	doc_973441205349_item	3602380	et	3	main
inimesed	doc_973441205349_item	3602387	et	3	main
me	doc_973441205349_item	3602392	et	4	main
tahame	doc_973441205349_item	3602393	et	3	main
tartusse	doc_973441205349_item	3602395	et	3	main
me	doc_973441205349_item	3602397	et	4	main
aeg	doc_973441205349_item	3602401	et	3	main
te	doc_973441205349_item	3602403	et	4	main
et	doc_973441205349_item	3602405	et	3	main
3	doc_973441205349_item	3602408	et	2	main
maksab	doc_973441205349_item	3602414	et	3	main
teadma	doc_973441205349_item	3602419	et	3	main
et	doc_973441205349_item	3602429	et	3	main
me	doc_973441205349_item	3602430	et	4	main
sõitsime	doc_973441205349_item	3602431	et	3	main
minu	doc_432051777904_item	3602485	et	3	main
on	doc_432051777904_item	3602487	et	4	main
20	doc_432051777904_item	3602490	et	2	main
vana	doc_432051777904_item	3602492	et	4	main
olen	doc_432051777904_item	3602504	et	3	main
aastat	doc_432051777904_item	3602507	et	3	main
vaja	doc_432051777904_item	3602527	et	4	main
et	doc_432051777904_item	3602528	et	3	main
ajakiri	doc_432051777904_item	3602530	et	3	main
ma	doc_432051777904_item	3602539	et	3	main
ma	doc_432051777904_item	3602544	et	3	main
55	doc_491521501906_item	3602271	et	2	main
555	doc_491521501906_item	3602272	et	2	main
lp	doc_491521501906_item	3602275	et	4	main
teie	doc_491521501906_item	3602280	et	4	main
välja	doc_491521501906_item	3602282	et	4	main
informatsiooni	doc_491521501906_item	3602289	et	4	main
eesti	doc_491521501906_item	3602295	et	4	main
ettevõtte	doc_491521501906_item	3602309	et	4	main
raamatupidamise	doc_491521501906_item	3602310	et	3	main
eest	doc_491521501906_item	3602311	et	4	main
soobib	doc_491521501906_item	3602341	et	4	main
ja	doc_491521501906_item	3602343	et	3	main
cv	doc_491521501906_item	3602350	et	4	main
perekonnanimi	doc_491521501906_item	3602354	et	3	main
koila	doc_973441205349_item	3602361	et	4	main
teie	doc_973441205349_item	3602381	et	4	main
rokkmuusika	doc_973441205349_item	3602390	et	4	main
kell	doc_973441205349_item	3602410	et	3	main
150	doc_973441205349_item	3602415	et	2	main
ma	doc_973441205349_item	3602417	et	3	main
tahan	doc_973441205349_item	3602418	et	3	main
ja	doc_973441205349_item	3602421	et	3	main
inimesed	doc_973441205349_item	3602436	et	3	main
kes	doc_973441205349_item	3602458	et	4	main
külastavad	doc_973441205349_item	3602459	et	4	main
selles	doc_973441205349_item	3602460	et	4	main
festivalid	doc_973441205349_item	3602461	et	3	main
me	doc_973441205349_item	3602462	et	4	main
teame	doc_973441205349_item	3602463	et	3	main
tartus	doc_973441205349_item	3602464	et	3	main
väga	doc_973441205349_item	3602465	et	3	main
halbasti	doc_973441205349_item	3602466	et	4	main
ma	doc_973441205349_item	3602467	et	3	main
arvan	doc_973441205349_item	3602468	et	3	main
et	doc_973441205349_item	3602469	et	3	main
te	doc_973441205349_item	3602470	et	4	main
vastate	doc_973441205349_item	3602471	et	3	main
küsimustele	doc_973441205349_item	3602473	et	4	main
minu	doc_973441205349_item	3602474	et	3	main
mail	doc_973441205349_item	3602475	et	4	main
aadress	doc_973441205349_item	3602476	et	3	main
on	doc_973441205349_item	3602477	et	4	main
eesnimimailru	doc_973441205349_item	3602478	et	2	main
eesnimi	doc_973441205349_item	3602479	et	3	main
perekonnanimi	doc_973441205349_item	3602480	et	3	main
minu	doc_973441205349_item	3602472	et	3	main
nimi	doc_432051777904_item	3602486	et	3	main
olen	doc_432051777904_item	3602489	et	3	main
on	doc_432051777904_item	3602497	et	4	main
rõõm	doc_432051777904_item	3602498	et	3	main
armastan	doc_432051777904_item	3602500	et	3	main
keel	doc_432051777904_item	3602503	et	4	main
hea	doc_432051777904_item	3602521	et	4	main
mul	doc_432051777904_item	3602523	et	3	main
eesti	doc_432051777904_item	3602525	et	4	main
keelt	doc_432051777904_item	3602526	et	4	main
on	doc_432051777904_item	3602532	et	4	main
ma	doc_432051777904_item	3602534	et	3	main
tahan	doc_432051777904_item	3602535	et	3	main
8oktoober	doc_491521501906_item	3602274	et	3	main
kandideerida	doc_491521501906_item	3602279	et	3	main
kohta	doc_491521501906_item	3602292	et	4	main
lugesin	doc_491521501906_item	3602293	et	3	main
ajalehest	doc_491521501906_item	3602294	et	4	main
meil	doc_491521501906_item	3602312	et	4	main
pearaamatupidaja	doc_491521501906_item	3602316	et	4	main
eesti	doc_973441205349_item	3602359	et	4	main
209	doc_973441205349_item	3602364	et	2	main
festivali	doc_973441205349_item	3602382	et	4	main
nendel	doc_973441205349_item	3602388	et	4	main
ja	doc_973441205349_item	3602391	et	3	main
ja	doc_973441205349_item	3602396	et	3	main
külastada	doc_973441205349_item	3602399	et	3	main
lisainfot	doc_973441205349_item	3602422	et	3	main
selles	doc_973441205349_item	3602424	et	4	main
on	doc_973441205349_item	3602434	et	4	main
õpetaja	doc_432051777904_item	3602484	et	4	main
elus	doc_432051777904_item	3602496	et	4	main
õppinud	doc_432051777904_item	3602505	et	4	main
varem	doc_432051777904_item	3602508	et	4	main
õppinud	doc_432051777904_item	3602510	et	4	main
põhjus	doc_432051777904_item	3602512	et	4	main
põhjus	doc_432051777904_item	3602520	et	4	main
keel	doc_432051777904_item	3602538	et	4	main
eesti	doc_432051777904_item	3602542	et	4	main
kirju	doc_432051777904_item	3602547	et	4	main
minu	doc_432051777913_item	3602595	et	3	main
olen	doc_432051777913_item	3602600	et	3	main
eesti	doc_432051777913_item	3602614	et	4	main
olen	doc_432051777913_item	3602621	et	3	main
kiviõli	doc_432051777913_item	3602623	et	4	main
vene	doc_432051777913_item	3602624	et	4	main
gümnaasiumis	doc_432051777913_item	3602625	et	3	main
esimene	doc_432051777913_item	3602626	et	3	main
ma	doc_432051777913_item	3602657	et	3	main
sõidan	doc_432051777913_item	3602665	et	3	main
me	doc_432051777913_item	3602681	et	4	main
ei	doc_432051777913_item	3602709	et	4	main
avaldus	doc_40918597558_item	3602879	et	4	main
e-mail	doc_40918597558_item	3602897	et	4	main
12052008	doc_40918597558_item	3602899	et	2	main
avaldus	doc_40918597558_item	3602900	et	4	main
mina	doc_40918597558_item	3602901	et	4	main
lugesin	doc_40918597558_item	3602902	et	3	main
selles	doc_40918597558_item	3602910	et	4	main
mina	doc_40918597558_item	3602912	et	4	main
tahaksin	doc_40918597558_item	3602913	et	3	main
kandideerida	doc_40918597558_item	3602914	et	3	main
müügiesindajale	doc_40918597558_item	3602915	et	3	main
aga	doc_40918597558_item	3602983	et	3	main
tahame	doc_973441205349_item	3602438	et	3	main
broneerida	doc_973441205349_item	3602439	et	3	main
majutus	doc_973441205349_item	3602440	et	4	main
kui	doc_973441205349_item	3602441	et	3	main
palju	doc_973441205349_item	3602442	et	4	main
maksab	doc_973441205349_item	3602443	et	3	main
teie	doc_973441205349_item	3602444	et	4	main
majutus	doc_973441205349_item	3602445	et	4	main
veel	doc_973441205349_item	3602446	et	4	main
ma	doc_973441205349_item	3602447	et	3	main
tahan	doc_973441205349_item	3602448	et	3	main
teadma	doc_973441205349_item	3602449	et	3	main
milliseid	doc_973441205349_item	3602450	et	3	main
gruppid	doc_973441205349_item	3602451	et	4	main
olid	doc_973441205349_item	3602452	et	4	main
esinevad	doc_973441205349_item	3602453	et	4	main
mis	doc_973441205349_item	3602454	et	4	main
toimetab	doc_973441205349_item	3602455	et	3	main
veel	doc_973441205349_item	3602456	et	4	main
as	doc_973441205349_item	3602358	et	4	main
305	doc_973441205349_item	3602363	et	2	main
70406	doc_973441205349_item	3602366	et	2	main
järelepärimine	doc_973441205349_item	3602367	et	3	main
lugesin	doc_973441205349_item	3602368	et	3	main
internetist	doc_973441205349_item	3602369	et	4	main
et	doc_973441205349_item	3602370	et	3	main
3	doc_973441205349_item	3602371	et	2	main
märtsil	doc_973441205349_item	3602372	et	3	main
toimub	doc_973441205349_item	3602373	et	3	main
festival	doc_973441205349_item	3602376	et	3	main
on	doc_973441205349_item	3602385	et	4	main
23	doc_973441205349_item	3602386	et	2	main
sõita	doc_973441205349_item	3602394	et	3	main
tahame	doc_973441205349_item	3602398	et	3	main
tore	doc_973441205349_item	3602400	et	3	main
kirjutasite	doc_973441205349_item	3602404	et	3	main
märtsil	doc_973441205349_item	3602409	et	3	main
ja	doc_973441205349_item	3602412	et	3	main
aga	doc_973441205349_item	3602423	et	3	main
festivalis	doc_973441205349_item	3602425	et	3	main
soodustused	doc_973441205349_item	3602427	et	4	main
sest	doc_973441205349_item	3602428	et	4	main
palju	doc_973441205349_item	3602435	et	4	main
festivalis	doc_973441205349_item	3602457	et	3	main
kiri	doc_432051777904_item	3602482	et	3	main
eesnimi	doc_432051777904_item	3602488	et	3	main
aastat	doc_432051777904_item	3602491	et	3	main
kõige	doc_432051777904_item	3602493	et	4	main
tähtsam	doc_432051777904_item	3602494	et	4	main
minu	doc_432051777904_item	3602495	et	3	main
eesti	doc_432051777904_item	3602502	et	4	main
sellele	doc_432051777904_item	3602515	et	4	main
kursusele	doc_432051777904_item	3602516	et	3	main
on	doc_432051777904_item	3602517	et	4	main
haridus	doc_432051777904_item	3602518	et	3	main
teine	doc_432051777904_item	3602519	et	3	main
on	doc_432051777904_item	3602524	et	4	main
mul	doc_432051777904_item	3602531	et	3	main
vaja	doc_432051777904_item	3602533	et	4	main
kuulata	doc_432051777904_item	3602536	et	4	main
eesti	doc_432051777904_item	3602537	et	4	main
kiri	doc_432051777913_item	3602592	et	3	main
tähtsam	doc_432051777913_item	3602606	et	4	main
minu	doc_432051777913_item	3602607	et	3	main
olen	doc_432051777913_item	3602616	et	3	main
aastat	doc_432051777913_item	3602619	et	3	main
tahan	doc_432051777913_item	3602658	et	3	main
eesti	doc_432051777913_item	3602660	et	4	main
keeles	doc_432051777913_item	3602661	et	4	main
eestlasega	doc_432051777913_item	3602662	et	3	main
tahan	doc_432051777913_item	3602670	et	3	main
erinevaid	doc_432051777913_item	3602672	et	4	main
on	doc_432051777913_item	3602702	et	4	main
rääkida	doc_432051777913_item	3602704	et	3	main
eesti	doc_432051777913_item	3602705	et	4	main
keelt	doc_432051777913_item	3602706	et	4	main
kui	doc_432051777913_item	3602707	et	3	main
mul	doc_432051777913_item	3602708	et	3	main
rääkima	doc_432051777913_item	3602719	et	3	main
keelt	doc_432051777913_item	3602721	et	4	main
meie	doc_973441205349_item	3602383	et	4	main
klassis	doc_973441205349_item	3602384	et	3	main
meeldib	doc_973441205349_item	3602389	et	3	main
internetist	doc_973441205349_item	3602402	et	4	main
festival	doc_973441205349_item	3602406	et	3	main
toimub	doc_973441205349_item	3602407	et	3	main
kaheksa	doc_973441205349_item	3602411	et	4	main
pilet	doc_973441205349_item	3602413	et	3	main
krooni	doc_973441205349_item	3602416	et	4	main
piletiinfot	doc_973441205349_item	3602420	et	3	main
olid	doc_973441205349_item	3602426	et	4	main
gruppiga	doc_973441205349_item	3602432	et	4	main
neil	doc_973441205349_item	3602433	et	4	main
me	doc_973441205349_item	3602437	et	4	main
et	doc_432051777904_item	3602563	et	3	main
eesti	doc_432051777904_item	3602564	et	4	main
keel	doc_432051777904_item	3602565	et	4	main
on	doc_432051777904_item	3602566	et	4	main
raske	doc_432051777904_item	3602567	et	4	main
ja	doc_432051777904_item	3602568	et	3	main
ta	doc_432051777904_item	3602569	et	4	main
võtab	doc_432051777904_item	3602570	et	3	main
palju	doc_432051777904_item	3602571	et	4	main
aega	doc_432051777904_item	3602572	et	4	main
ma	doc_432051777904_item	3602573	et	3	main
tahaksin	doc_432051777904_item	3602574	et	3	main
teada	doc_432051777904_item	3602575	et	3	main
eesti	doc_432051777904_item	3602576	et	4	main
ja	doc_432051777904_item	3602577	et	3	main
inglise	doc_432051777904_item	3602578	et	4	main
keel	doc_432051777904_item	3602579	et	4	main
ja	doc_432051777904_item	3602580	et	3	main
minu	doc_432051777904_item	3602581	et	3	main
riigi	doc_432051777904_item	3602582	et	3	main
ajalugu	doc_432051777904_item	3602583	et	4	main
loodan	doc_432051777904_item	3602584	et	3	main
et	doc_432051777904_item	3602585	et	3	main
teile	doc_432051777904_item	3602586	et	4	main
meeldis	doc_432051777904_item	3602587	et	3	main
lugupidamisega	doc_432051777904_item	3602588	et	3	main
tere	doc_432051777904_item	3602483	et	3	main
ma	doc_432051777904_item	3602499	et	3	main
muusika	doc_432051777904_item	3602501	et	4	main
10	doc_432051777904_item	3602506	et	2	main
olen	doc_432051777904_item	3602509	et	3	main
esimene	doc_432051777904_item	3602511	et	3	main
miks	doc_432051777904_item	3602513	et	4	main
tulin	doc_432051777904_item	3602514	et	3	main
töö	doc_432051777904_item	3602522	et	4	main
lugeda	doc_432051777904_item	3602529	et	3	main
rääkida	doc_432051777904_item	3602541	et	3	main
tahan	doc_432051777904_item	3602545	et	3	main
loodan	doc_432051777904_item	3602550	et	3	main
et	doc_432051777904_item	3602551	et	3	main
me	doc_432051777904_item	3602552	et	4	main
tegeleme	doc_432051777904_item	3602553	et	3	main
põhjalikult	doc_432051777904_item	3602554	et	4	main
keelega	doc_432051777904_item	3602556	et	3	main
ja	doc_432051777904_item	3602557	et	3	main
natukene	doc_432051777904_item	3602558	et	4	main
eesti	doc_432051777904_item	3602555	et	4	main
filosofia	doc_432051777904_item	3602559	et	4	main
ma	doc_432051777904_item	3602560	et	3	main
kardan	doc_432051777904_item	3602561	et	4	main
natuke	doc_432051777904_item	3602562	et	4	main
eesnimi	doc_432051777904_item	3602589	et	3	main
tere	doc_432051777913_item	3602593	et	3	main
kaitse	doc_432051777913_item	3602603	et	4	main
on	doc_432051777913_item	3602609	et	4	main
õppimine	doc_432051777913_item	3602610	et	4	main
ma	doc_432051777913_item	3602611	et	3	main
armastan	doc_432051777913_item	3602612	et	3	main
õpima	doc_432051777913_item	3602613	et	4	main
13	doc_432051777913_item	3602618	et	2	main
kui	doc_432051777913_item	3602663	et	3	main
keeles	doc_432051777913_item	3602677	et	4	main
ma	doc_432051777913_item	3602678	et	3	main
loodan	doc_432051777913_item	3602679	et	3	main
et	doc_432051777913_item	3602680	et	3	main
tahan	doc_432051777904_item	3602540	et	3	main
kellega	doc_432051777904_item	3602543	et	3	main
kirjutada	doc_432051777904_item	3602546	et	3	main
sõbradele	doc_432051777904_item	3602548	et	4	main
ma	doc_432051777904_item	3602549	et	3	main
perekonnanimi	doc_432051777904_item	3602590	et	3	main
õpetajad	doc_432051777913_item	3602594	et	4	main
on	doc_432051777913_item	3602597	et	4	main
perekonnanimi	doc_432051777913_item	3602599	et	3	main
keskkonna	doc_432051777913_item	3602602	et	3	main
elus	doc_432051777913_item	3602608	et	4	main
õppinud	doc_432051777913_item	3602617	et	4	main
varem	doc_432051777913_item	3602620	et	4	main
õppinud	doc_432051777913_item	3602622	et	4	main
ma	doc_432051777913_item	3602664	et	3	main
külalisse	doc_432051777913_item	3602668	et	4	main
põhjalikult	doc_432051777913_item	3602683	et	4	main
keele	doc_432051777913_item	3602685	et	4	main
kardan	doc_432051777913_item	3602688	et	4	main
natuke	doc_432051777913_item	3602689	et	4	main
et	doc_432051777913_item	3602690	et	3	main
ma	doc_432051777913_item	3602691	et	3	main
ei	doc_432051777913_item	3602692	et	4	main
kuidas	doc_432051777913_item	3602701	et	3	main
tekste	doc_432051777913_item	3602673	et	3	main
ja	doc_432051777913_item	3602674	et	3	main
jutustused	doc_432051777913_item	3602675	et	4	main
eesti	doc_432051777913_item	3602676	et	4	main
nimi	doc_432051777913_item	3602596	et	3	main
eesnimi	doc_432051777913_item	3602598	et	3	main
õpilane	doc_432051777913_item	3602601	et	3	main
eriala	doc_432051777913_item	3602604	et	4	main
kõige	doc_432051777913_item	3602605	et	4	main
keelt	doc_432051777913_item	3602615	et	4	main
põhjus	doc_432051777913_item	3602627	et	4	main
miks	doc_432051777913_item	3602628	et	4	main
tulin	doc_432051777913_item	3602629	et	3	main
sellel	doc_432051777913_item	3602630	et	4	main
kursusel	doc_432051777913_item	3602631	et	3	main
hariduse	doc_432051777913_item	3602632	et	3	main
kätte	doc_432051777913_item	3602633	et	4	main
saama	doc_432051777913_item	3602634	et	4	main
teine	doc_432051777913_item	3602635	et	3	main
põhjus	doc_432051777913_item	3602636	et	4	main
on	doc_432051777913_item	3602637	et	4	main
suhtlemine	doc_432051777913_item	3602638	et	4	main
mul	doc_432051777913_item	3602639	et	3	main
on	doc_432051777913_item	3602640	et	4	main
eesti	doc_432051777913_item	3602641	et	4	main
vaja	doc_432051777913_item	3602643	et	4	main
et	doc_432051777913_item	3602644	et	3	main
keelt	doc_432051777913_item	3602642	et	4	main
lugeda	doc_432051777913_item	3602645	et	3	main
eesti	doc_432051777913_item	3602646	et	4	main
ajalehti	doc_432051777913_item	3602647	et	4	main
ja	doc_432051777913_item	3602648	et	3	main
ajakiri	doc_432051777913_item	3602649	et	3	main
mul	doc_432051777913_item	3602650	et	3	main
on	doc_432051777913_item	3602651	et	4	main
vaja	doc_432051777913_item	3602652	et	4	main
et	doc_432051777913_item	3602653	et	3	main
kuulata	doc_432051777913_item	3602654	et	4	main
eesti	doc_432051777913_item	3602655	et	4	main
raadiot	doc_432051777913_item	3602656	et	3	main
rääkida	doc_432051777913_item	3602659	et	3	main
minu	doc_432051777913_item	3602666	et	3	main
sõprades	doc_432051777913_item	3602667	et	3	main
ma	doc_432051777913_item	3602669	et	3	main
kirjutada	doc_432051777913_item	3602671	et	3	main
tegeleme	doc_432051777913_item	3602682	et	3	main
eesti	doc_432051777913_item	3602684	et	4	main
õppusega	doc_432051777913_item	3602686	et	3	main
ma	doc_432051777913_item	3602687	et	3	main
teada	doc_432051777913_item	3602700	et	3	main
parem	doc_432051777913_item	3602703	et	4	main
suhelda	doc_432051777913_item	3602712	et	4	main
eesti	doc_432051777913_item	3602713	et	4	main
keeles	doc_432051777913_item	3602714	et	4	main
loodan	doc_432051777913_item	3602715	et	3	main
et	doc_432051777913_item	3602716	et	3	main
ma	doc_432051777913_item	3602717	et	3	main
eesti	doc_432051777913_item	3602720	et	4	main
saa	doc_432051777913_item	3602693	et	4	main
rääkima	doc_432051777913_item	3602694	et	3	main
eesti	doc_432051777913_item	3602695	et	4	main
keelt	doc_432051777913_item	3602696	et	4	main
hästi	doc_432051777913_item	3602697	et	3	main
ma	doc_432051777913_item	3602698	et	3	main
tahaksin	doc_432051777913_item	3602699	et	3	main
ole	doc_432051777913_item	3602710	et	4	main
võimalusi	doc_432051777913_item	3602711	et	3	main
saan	doc_432051777913_item	3602718	et	4	main
parema	doc_432051777913_item	3602722	et	4	main
lugupidamisega	doc_432051777913_item	3602723	et	3	main
eesnimi	doc_432051777913_item	3602724	et	3	main
perekonnanimi	doc_432051777913_item	3602725	et	3	main
ps	doc_432051777913_item	3602726	et	4	main
vabandage	doc_432051777913_item	3602727	et	3	main
et	doc_432051777913_item	3602728	et	3	main
ma	doc_432051777913_item	3602729	et	3	main
kirjutasin	doc_432051777913_item	3602730	et	3	main
hooltult	doc_432051777913_item	3602731	et	4	main
eesnimi	doc_40918597558_item	3602882	et	3	main
jahu	doc_40918597558_item	3602885	et	4	main
eesnimimailru	doc_40918597558_item	3602898	et	2	main
internetist	doc_40918597558_item	3602905	et	4	main
valdan	doc_40918597558_item	3602956	et	3	main
vene	doc_40918597558_item	3602961	et	4	main
keelt	doc_40918597558_item	3602980	et	4	main
kui	doc_40918597558_item	3602992	et	3	main
lõpuni	doc_384045275269_item	3603037	et	3	main
nimetada	doc_384045275269_item	3603052	et	3	main
reaalseid	doc_384045275269_item	3603053	et	3	main
deiktikutel	doc_384045275269_item	3603060	et	4	main
neid	doc_384045275269_item	3603066	et	4	main
deiktikutel	doc_384045275269_item	3603076	et	4	main
osade	doc_384045275269_item	3603078	et	3	main
teema	doc_384045275269_item	3603120	et	4	main
selle	doc_384045275269_item	3603121	et	4	main
üle	doc_384045275269_item	3603122	et	3	main
vaieldakse	doc_384045275269_item	3603123	et	3	main
kokkuleppele	doc_384045275269_item	3603127	et	3	main
2004	doc_384045275269_item	3603129	et	2	main
aasta	doc_384045275269_item	3603130	et	4	main
toimus	doc_384045275269_item	3603132	et	3	main
ajakirjanuslevi	doc_40918597558_item	3602881	et	4	main
konkurss	doc_40918597558_item	3602884	et	3	main
juhuslik	doc_40918597558_item	3602887	et	3	main
10626	doc_40918597558_item	3602891	et	2	main
tallinn	doc_40918597558_item	3602892	et	4	main
ja	doc_40918597558_item	3602906	et	3	main
sest	doc_40918597558_item	3602916	et	4	main
mulle	doc_40918597558_item	3602917	et	4	main
väga	doc_40918597558_item	3602918	et	3	main
suur	doc_40918597558_item	3602919	et	3	main
eesti	doc_40918597558_item	3602959	et	4	main
keelt	doc_40918597558_item	3602962	et	4	main
tööd	doc_40918597558_item	3602974	et	4	main
arvan	doc_40918597558_item	3602975	et	3	main
et	doc_40918597558_item	3602976	et	3	main
saan	doc_40918597558_item	3602977	et	4	main
leida	doc_40918597558_item	3602978	et	3	main
ühist	doc_40918597558_item	3602979	et	3	main
paljude	doc_40918597558_item	3602981	et	3	main
mul	doc_40918597558_item	3602984	et	3	main
mitu	doc_40918597558_item	3602987	et	4	main
küsimust	doc_40918597558_item	3602988	et	4	main
milline	doc_40918597558_item	3602989	et	3	main
inimesi	doc_40918597558_item	3602994	et	4	main
on	doc_40918597558_item	3602995	et	4	main
referaat	doc_384045275269_item	3603026	et	3	main
ole	doc_384045275269_item	3603035	et	4	main
teadmata	doc_384045275269_item	3603039	et	4	main
ja	doc_384045275269_item	3603055	et	3	main
nimesid	doc_384045275269_item	3603058	et	3	main
vaene	doc_384045275269_item	3603062	et	4	main
leksikaalne	doc_384045275269_item	3603063	et	3	main
tähendus	doc_384045275269_item	3603064	et	4	main
kuid	doc_384045275269_item	3603065	et	4	main
ja	doc_384045275269_item	3603070	et	3	main
teine	doc_384045275269_item	3603072	et	3	main
tähtis	doc_384045275269_item	3603073	et	4	main
roll	doc_384045275269_item	3603074	et	3	main
on	doc_384045275269_item	3603075	et	4	main
sidumisel	doc_384045275269_item	3603079	et	4	main
tekstist	doc_384045275269_item	3603082	et	3	main
valisin	doc_384045275269_item	3603084	et	3	main
et	doc_384045275269_item	3603109	et	3	main
nullist	doc_384045275269_item	3603112	et	4	main
keeleteadlaste	doc_384045275269_item	3603113	et	3	main
olda	doc_384045275269_item	3603126	et	3	main
jõutud	doc_384045275269_item	3603128	et	4	main
selleteemaline	doc_384045275269_item	3603134	et	4	main
konverents	doc_384045275269_item	3603135	et	3	main
võimalikult	doc_384045275269_item	3603140	et	4	main
lihtsalt	doc_384045275269_item	3603141	et	4	main
lahti	doc_384045275269_item	3603142	et	4	main
eesmärk	doc_384045275270_item	3603169	et	3	main
eesti	doc_384045275270_item	3603173	et	4	main
kirjakeele	doc_384045275270_item	3603174	et	4	main
korpustest	doc_384045275270_item	3603175	et	3	main
leidnud	doc_384045275270_item	3603181	et	4	main
töö	doc_384045275270_item	3603190	et	4	main
erinevatest	doc_384045275270_item	3603197	et	4	main
keele	doc_384045275270_item	3603205	et	4	main
kirjutamine	doc_366216787874_item	3603267	et	4	main
teemal	doc_366216787874_item	3603270	et	3	main
teeb	doc_366216787874_item	3603272	et	3	main
essee	doc_366216787874_item	3603275	et	4	main
350	doc_366216787874_item	3603278	et	2	main
üldistav	doc_366216787874_item	3603286	et	4	main
tuginema	doc_366216787874_item	3603287	et	3	main
loengus	doc_366216787874_item	3603288	et	3	main
ja	doc_366216787874_item	3603289	et	3	main
as	doc_40918597558_item	3602880	et	4	main
10988	doc_40918597558_item	3602889	et	2	main
tel	doc_40918597558_item	3602893	et	4	main
55	doc_40918597558_item	3602894	et	2	main
555	doc_40918597558_item	3602895	et	2	main
55	doc_40918597558_item	3602896	et	2	main
teie	doc_40918597558_item	3602903	et	4	main
olen	doc_40918597558_item	3602907	et	3	main
huvitanud	doc_40918597558_item	3602909	et	4	main
konkurssis	doc_40918597558_item	3602911	et	4	main
ka	doc_40918597558_item	3602957	et	3	main
inimestega	doc_40918597558_item	3602982	et	3	main
töökõver	doc_40918597558_item	3602991	et	3	main
ja	doc_40918597558_item	3602964	et	3	main
soome	doc_40918597558_item	3602965	et	3	main
keel	doc_40918597558_item	3602966	et	4	main
on	doc_40918597558_item	3602967	et	4	main
suhtlemisoskuse	doc_40918597558_item	3602968	et	3	main
tasemel	doc_40918597558_item	3602969	et	3	main
mulle	doc_40918597558_item	3602970	et	4	main
meeldib	doc_40918597558_item	3602971	et	3	main
teha	doc_40918597558_item	3602972	et	3	main
perekonnanimi	doc_40918597558_item	3602883	et	3	main
34	doc_40918597558_item	3602886	et	2	main
6	doc_40918597558_item	3602888	et	2	main
narva	doc_40918597558_item	3602890	et	4	main
avalduse	doc_40918597558_item	3602904	et	4	main
väga	doc_40918597558_item	3602908	et	3	main
soov	doc_40918597558_item	3602920	et	3	main
seda	doc_40918597558_item	3602921	et	3	main
tööd	doc_40918597558_item	3602922	et	4	main
teha	doc_40918597558_item	3602923	et	3	main
ja	doc_40918597558_item	3602924	et	3	main
mul	doc_40918597558_item	3602925	et	3	main
on	doc_40918597558_item	3602926	et	4	main
juba	doc_40918597558_item	3602927	et	3	main
hea	doc_40918597558_item	3602928	et	4	main
kogemus	doc_40918597558_item	3602929	et	3	main
selles	doc_40918597558_item	3602930	et	4	main
valdkonnas	doc_40918597558_item	3602931	et	4	main
mina	doc_40918597558_item	3602932	et	4	main
olen	doc_40918597558_item	3602933	et	3	main
juba	doc_40918597558_item	3602934	et	3	main
töötanud	doc_40918597558_item	3602935	et	4	main
müügiesindajana	doc_40918597558_item	3602936	et	3	main
spordikaupluses	doc_40918597558_item	3602937	et	3	main
5	doc_40918597558_item	3602938	et	2	main
aastat	doc_40918597558_item	3602939	et	3	main
oman	doc_40918597558_item	3602940	et	3	main
häid	doc_40918597558_item	3602941	et	3	main
rekomendatsiooni	doc_40918597558_item	3602942	et	4	main
eelmisel	doc_40918597558_item	3602943	et	3	main
suvel	doc_40918597558_item	3602944	et	3	main
sõitsin	doc_40918597558_item	3602945	et	3	main
suhtlemisoskuste	doc_40918597558_item	3602947	et	3	main
tallinnasse	doc_40918597558_item	3602946	et	3	main
kursustele	doc_40918597558_item	3602948	et	3	main
sain	doc_40918597558_item	3602949	et	3	main
väga	doc_40918597558_item	3602950	et	3	main
häid	doc_40918597558_item	3602951	et	3	main
huvitavaid	doc_40918597558_item	3602952	et	4	main
ja	doc_40918597558_item	3602953	et	3	main
kasulikke	doc_40918597558_item	3602954	et	3	main
teadmisi	doc_40918597558_item	3602955	et	4	main
vabalt	doc_40918597558_item	3602958	et	4	main
ja	doc_40918597558_item	3602960	et	3	main
inglise	doc_40918597558_item	3602963	et	4	main
meeskonna	doc_40918597558_item	3602973	et	4	main
on	doc_40918597558_item	3602990	et	4	main
mida	doc_384045275269_item	3603033	et	4	main
ei	doc_384045275269_item	3603034	et	4	main
konteksti	doc_384045275269_item	3603042	et	4	main
on	doc_384045275269_item	3603061	et	4	main
moodustavad	doc_384045275269_item	3603081	et	4	main
terviku	doc_384045275269_item	3603083	et	3	main
deiksise	doc_384045275269_item	3603086	et	4	main
tuleb	doc_384045275269_item	3603111	et	3	main
harutada	doc_384045275269_item	3603143	et	3	main
et	doc_384045275269_item	3603144	et	3	main
kõik	doc_384045275269_item	3603145	et	4	main
käesoleva	doc_384045275270_item	3603167	et	3	main
anda	doc_384045275270_item	3603171	et	3	main
on	doc_384045275270_item	3603179	et	4	main
ülevaate	doc_384045275270_item	3603187	et	4	main
korpuse	doc_384045275270_item	3603188	et	3	main
ülevaade	doc_384045275270_item	3603194	et	3	main
eesti	doc_384045275270_item	3603195	et	4	main
ülikoolis	doc_384045275270_item	3603201	et	4	main
ka	doc_384045275270_item	3603203	et	3	main
on	doc_40918597558_item	3602985	et	4	main
ka	doc_40918597558_item	3602986	et	3	main
palju	doc_40918597558_item	3602993	et	4	main
teie	doc_40918597558_item	3602996	et	4	main
kollektiivis	doc_40918597558_item	3602997	et	3	main
millised	doc_40918597558_item	3602998	et	3	main
on	doc_40918597558_item	3602999	et	4	main
töötingimused	doc_40918597558_item	3603000	et	3	main
kas	doc_40918597558_item	3603001	et	3	main
teil	doc_40918597558_item	3603002	et	4	main
on	doc_40918597558_item	3603003	et	4	main
lõunaaeg	doc_40918597558_item	3603004	et	3	main
kus	doc_40918597558_item	3603005	et	3	main
inimesed	doc_40918597558_item	3603006	et	3	main
söövad	doc_40918597558_item	3603007	et	4	main
kas	doc_40918597558_item	3603008	et	3	main
teil	doc_40918597558_item	3603009	et	4	main
on	doc_40918597558_item	3603010	et	4	main
töövorm	doc_40918597558_item	3603011	et	3	main
mina	doc_40918597558_item	3603012	et	4	main
loodan	doc_40918597558_item	3603013	et	3	main
et	doc_40918597558_item	3603014	et	3	main
teie	doc_40918597558_item	3603015	et	4	main
vaatlete	doc_40918597558_item	3603016	et	3	main
minu	doc_40918597558_item	3603017	et	3	main
kandidatuur	doc_40918597558_item	3603018	et	3	main
ning	doc_40918597558_item	3603019	et	3	main
võtate	doc_40918597558_item	3603020	et	3	main
tööle	doc_40918597558_item	3603021	et	3	main
lugupidamisega	doc_40918597558_item	3603022	et	3	main
eesnimi	doc_40918597558_item	3603023	et	3	main
perekonnanimi	doc_40918597558_item	3603024	et	3	main
deiksis	doc_384045275269_item	3603028	et	4	main
mõista	doc_384045275269_item	3603038	et	4	main
kasutuse	doc_384045275269_item	3603041	et	4	main
sõnu	doc_384045275269_item	3603044	et	4	main
isikuid	doc_384045275269_item	3603056	et	4	main
jms	doc_384045275269_item	3603057	et	4	main
kasutamata	doc_384045275269_item	3603059	et	4	main
kasutatakse	doc_384045275269_item	3603067	et	3	main
palju	doc_384045275269_item	3603069	et	4	main
mitmekülgselt	doc_384045275269_item	3603071	et	4	main
teksti	doc_384045275269_item	3603077	et	4	main
teemaks	doc_384045275269_item	3603085	et	4	main
alustada	doc_384045275269_item	3603110	et	3	main
huvi	doc_384045275269_item	3603118	et	4	main
pakkuv	doc_384045275269_item	3603119	et	4	main
novembris	doc_384045275269_item	3603131	et	3	main
töö	doc_384045275270_item	3603168	et	4	main
on	doc_384045275270_item	3603170	et	4	main
ülevaade	doc_384045275270_item	3603172	et	3	main
selgitust	doc_384045275270_item	3603180	et	4	main
olemusest	doc_384045275270_item	3603189	et	4	main
kirjakeele	doc_384045275270_item	3603196	et	4	main
tartu	doc_384045275270_item	3603200	et	4	main
keele	doc_366216787874_item	3603265	et	4	main
proovile	doc_384045275269_item	3603106	et	3	main
panna	doc_384045275269_item	3603107	et	4	main
teades	doc_384045275269_item	3603108	et	4	main
sissejuhatus	doc_384045275269_item	3603027	et	4	main
haarab	doc_384045275269_item	3603029	et	3	main
enda	doc_384045275269_item	3603030	et	4	main
alla	doc_384045275269_item	3603031	et	3	main
sõnad	doc_384045275269_item	3603032	et	4	main
võimalik	doc_384045275269_item	3603036	et	3	main
nende	doc_384045275269_item	3603040	et	4	main
selliseid	doc_384045275269_item	3603043	et	4	main
nimetatakse	doc_384045275269_item	3603045	et	3	main
deiktikuteks	doc_384045275269_item	3603046	et	4	main
ja	doc_384045275269_item	3603047	et	3	main
need	doc_384045275269_item	3603048	et	3	main
annavad	doc_384045275269_item	3603049	et	3	main
inimestele	doc_384045275269_item	3603050	et	3	main
võimaluse	doc_384045275269_item	3603051	et	3	main
esemeid	doc_384045275269_item	3603054	et	3	main
väga	doc_384045275269_item	3603068	et	3	main
nad	doc_384045275269_item	3603080	et	3	main
sest	doc_384045275269_item	3603087	et	4	main
polnud	doc_384045275269_item	3603088	et	3	main
sellest	doc_384045275269_item	3603089	et	4	main
varem	doc_384045275269_item	3603090	et	4	main
kuulnud	doc_384045275269_item	3603091	et	4	main
ja	doc_384045275269_item	3603092	et	3	main
arvasin	doc_384045275269_item	3603093	et	3	main
et	doc_384045275269_item	3603094	et	3	main
võiks	doc_384045275269_item	3603095	et	4	main
olla	doc_384045275269_item	3603096	et	3	main
huvitav	doc_384045275269_item	3603097	et	4	main
tegeleda	doc_384045275269_item	3603098	et	3	main
minu	doc_384045275269_item	3603099	et	3	main
jaoks	doc_384045275269_item	3603100	et	4	main
täiesti	doc_384045275269_item	3603101	et	3	main
tundmatu	doc_384045275269_item	3603102	et	4	main
teemaga	doc_384045275269_item	3603103	et	3	main
tahtsin	doc_384045275269_item	3603104	et	3	main
ennast	doc_384045275269_item	3603105	et	4	main
seas	doc_384045275269_item	3603114	et	4	main
on	doc_384045275269_item	3603115	et	4	main
deiksis	doc_384045275269_item	3603116	et	4	main
suurt	doc_384045275269_item	3603117	et	3	main
siiani	doc_384045275269_item	3603124	et	4	main
ega	doc_384045275269_item	3603125	et	3	main
deiksise	doc_384045275269_item	3603139	et	4	main
sellest	doc_384045275269_item	3603146	et	4	main
aru	doc_384045275269_item	3603147	et	4	main
saaksid	doc_384045275269_item	3603148	et	4	main
ning	doc_384045275269_item	3603149	et	3	main
välja	doc_384045275269_item	3603150	et	4	main
tuua	doc_384045275269_item	3603151	et	3	main
selle	doc_384045275269_item	3603152	et	4	main
põhikomponendid	doc_384045275269_item	3603153	et	3	main
referaadi	doc_384045275269_item	3603154	et	3	main
koostamisel	doc_384045275269_item	3603155	et	4	main
kasutasin	doc_384045275269_item	3603156	et	3	main
peamiselt	doc_384045275269_item	3603157	et	4	main
renate	doc_384045275269_item	3603158	et	4	main
pajusalu	doc_384045275269_item	3603159	et	4	main
doktoritööd	doc_384045275269_item	3603160	et	4	main
deiktikud	doc_384045275269_item	3603161	et	4	main
eesti	doc_384045275269_item	3603162	et	4	main
keeles	doc_384045275269_item	3603163	et	4	main
tartus	doc_384045275269_item	3603133	et	3	main
oma	doc_384045275269_item	3603136	et	4	main
referaadiga	doc_384045275269_item	3603137	et	3	main
tahaksin	doc_384045275269_item	3603138	et	3	main
referaat	doc_384045275270_item	3603165	et	3	main
osas	doc_384045275270_item	3603178	et	4	main
mõiste	doc_384045275270_item	3603185	et	4	main
andmaks	doc_384045275270_item	3603186	et	3	main
osas	doc_384045275270_item	3603192	et	4	main
antakse	doc_384045275270_item	3603193	et	3	main
nii	doc_384045275270_item	3603199	et	3	main
kui	doc_384045275270_item	3603202	et	3	main
essee	doc_366216787874_item	3603260	et	4	main
test	doc_366216787874_item	3603266	et	3	main
essee	doc_366216787874_item	3603269	et	4	main
mis	doc_366216787874_item	3603271	et	4	main
300	doc_366216787874_item	3603277	et	2	main
essee	doc_366216787874_item	3603280	et	4	main
rahvadel	doc_366216787874_item	3603299	et	4	main
maailma	doc_366216787874_item	3603307	et	4	main
venelastel	doc_366216787874_item	3603310	et	4	main
on	doc_366216787874_item	3603311	et	4	main
oma	doc_366216787874_item	3603313	et	4	main
kui	doc_366216787874_item	3603347	et	3	main
mina	doc_366216787874_item	3603358	et	4	main
mõtlen	doc_366216787874_item	3603359	et	3	main
ära	doc_384045275270_item	3603242	et	4	main
toodud	doc_384045275270_item	3603243	et	4	main
tekstiklassid	doc_384045275270_item	3603244	et	3	main
ning	doc_384045275270_item	3603245	et	3	main
neis	doc_384045275270_item	3603246	et	4	main
sisalduv	doc_384045275270_item	3603247	et	4	main
ning	doc_384045275270_item	3603248	et	3	main
samas	doc_384045275270_item	3603249	et	4	main
on	doc_384045275270_item	3603250	et	4	main
tõmmatud	doc_384045275270_item	3603251	et	4	main
paraleele	doc_384045275270_item	3603252	et	3	main
tartu	doc_384045275270_item	3603253	et	4	main
ülikooli	doc_384045275270_item	3603254	et	4	main
baaskorpuse	doc_384045275270_item	3603255	et	3	main
ja	doc_384045275270_item	3603256	et	3	main
tema	doc_384045275270_item	3603257	et	4	main
läbilõikekorpustega	doc_384045275270_item	3603258	et	3	main
sissejuhatus	doc_384045275270_item	3603166	et	4	main
töö	doc_384045275270_item	3603176	et	4	main
esimeses	doc_384045275270_item	3603177	et	3	main
korpuslingvistika	doc_384045275270_item	3603182	et	4	main
ja	doc_384045275270_item	3603183	et	3	main
korpuse	doc_384045275270_item	3603184	et	3	main
teises	doc_384045275270_item	3603191	et	4	main
korpustest	doc_384045275270_item	3603198	et	3	main
eesti	doc_384045275270_item	3603204	et	4	main
instituudis	doc_384045275270_item	3603206	et	3	main
põhjalikumalt	doc_384045275270_item	3603207	et	4	main
leiab	doc_384045275270_item	3603208	et	3	main
käsitulust	doc_384045275270_item	3603209	et	4	main
tartu	doc_384045275270_item	3603210	et	4	main
ülikooli	doc_384045275270_item	3603211	et	4	main
juures	doc_384045275270_item	3603212	et	4	main
loodud	doc_384045275270_item	3603213	et	4	main
baaskorpus	doc_384045275270_item	3603214	et	3	main
oma	doc_384045275270_item	3603215	et	4	main
läbilõikekorpustega	doc_384045275270_item	3603216	et	3	main
kusjuures	doc_384045275270_item	3603217	et	3	main
selgitatakse	doc_384045275270_item	3603218	et	3	main
korpuse	doc_384045275270_item	3603219	et	3	main
loomise	doc_384045275270_item	3603220	et	4	main
protsessi	doc_384045275270_item	3603221	et	4	main
tekstivaliku	doc_384045275270_item	3603222	et	3	main
kriteeriumite	doc_384045275270_item	3603223	et	3	main
valiku	doc_384045275270_item	3603224	et	3	main
tekstiklasside	doc_384045275270_item	3603225	et	3	main
valiku	doc_384045275270_item	3603226	et	3	main
ja	doc_384045275270_item	3603227	et	3	main
tekstide	doc_384045275270_item	3603228	et	3	main
märgendamise	doc_384045275270_item	3603229	et	4	main
näol	doc_384045275270_item	3603230	et	4	main
tartu	doc_384045275270_item	3603231	et	4	main
ülikooli	doc_384045275270_item	3603232	et	4	main
segakorpuse	doc_384045275270_item	3603233	et	3	main
ja	doc_384045275270_item	3603234	et	3	main
eesti	doc_384045275270_item	3603235	et	4	main
keele	doc_384045275270_item	3603236	et	4	main
instituudi	doc_384045275270_item	3603237	et	3	main
korpuse	doc_384045275270_item	3603238	et	3	main
käsituluse	doc_384045275270_item	3603239	et	4	main
puhul	doc_384045275270_item	3603240	et	4	main
on	doc_384045275270_item	3603241	et	4	main
teise	doc_366216787874_item	3603264	et	4	main
võime	doc_366216787874_item	3603450	et	4	main
näita	doc_366216787874_item	3603451	et	4	main
nende	doc_366216787874_item	3603452	et	4	main
kultuur	doc_366216787874_item	3603453	et	3	main
mina	doc_366216787874_item	3603454	et	4	main
mõtlen	doc_366216787874_item	3603455	et	3	main
et	doc_366216787874_item	3603456	et	3	main
see	doc_366216787874_item	3603457	et	3	main
on	doc_366216787874_item	3603458	et	4	main
väga	doc_366216787874_item	3603459	et	3	main
tähtis	doc_366216787874_item	3603460	et	4	main
faktor	doc_366216787874_item	3603461	et	3	main
sellepärast	doc_366216787874_item	3603462	et	3	main
see	doc_366216787874_item	3603463	et	3	main
näitab	doc_366216787874_item	3603464	et	3	main
et	doc_366216787874_item	3603465	et	3	main
laulad	doc_366216787874_item	3603466	et	3	main
tähistavad	doc_366216787874_item	3603467	et	4	main
eestlastele	doc_366216787874_item	3603468	et	4	main
väga	doc_366216787874_item	3603469	et	3	main
palju	doc_366216787874_item	3603470	et	4	main
ja	doc_366216787874_item	3603471	et	3	main
naad	doc_366216787874_item	3603472	et	4	main
seda	doc_366216787874_item	3603473	et	3	main
traditsioon	doc_366216787874_item	3603474	et	3	main
ei	doc_366216787874_item	3603475	et	4	main
suri	doc_366216787874_item	3603476	et	3	main
eesti	doc_366216787874_item	3603261	et	4	main
keele	doc_366216787874_item	3603262	et	4	main
kui	doc_366216787874_item	3603263	et	3	main
kirjutage	doc_366216787874_item	3603268	et	3	main
eestlastest	doc_366216787874_item	3603273	et	4	main
pikkus	doc_366216787874_item	3603276	et	4	main
sõna	doc_366216787874_item	3603279	et	4	main
peab	doc_366216787874_item	3603281	et	4	main
olema	doc_366216787874_item	3603282	et	4	main
väiteid	doc_366216787874_item	3603293	et	4	main
on	doc_366216787874_item	3603294	et	4	main
traditsioonid	doc_366216787874_item	3603302	et	3	main
kultuur	doc_366216787874_item	3603303	et	3	main
pizzad	doc_366216787874_item	3603309	et	4	main
ka	doc_366216787874_item	3603312	et	3	main
traditsioonid	doc_366216787874_item	3603315	et	3	main
eestlased	doc_366216787874_item	3603316	et	3	main
nimetavad	doc_366216787874_item	3603317	et	4	main
iseendas	doc_366216787874_item	3603318	et	3	main
laulurahvas	doc_366216787874_item	3603319	et	4	main
laulumine	doc_366216787874_item	3603320	et	4	main
traditsioon	doc_366216787874_item	3603321	et	3	main
on	doc_366216787874_item	3603322	et	4	main
väga	doc_366216787874_item	3603323	et	3	main
vane	doc_366216787874_item	3603324	et	4	main
vana	doc_366216787874_item	3603325	et	4	main
laulad	doc_366216787874_item	3603326	et	3	main
oli	doc_366216787874_item	3603327	et	3	main
aeglased	doc_366216787874_item	3603328	et	3	main
vanesti	doc_366216787874_item	3603329	et	4	main
ema	doc_366216787874_item	3603330	et	4	main
laulas	doc_366216787874_item	3603331	et	4	main
lapsele	doc_366216787874_item	3603332	et	4	main
laulu	doc_366216787874_item	3603333	et	4	main
ka	doc_366216787874_item	3603334	et	3	main
lauldi	doc_366216787874_item	3603335	et	3	main
laulurahva	doc_366216787874_item	3603274	et	3	main
analüüsiv	doc_366216787874_item	3603284	et	4	main
ja	doc_366216787874_item	3603285	et	3	main
esitatud	doc_366216787874_item	3603291	et	4	main
soovitatav	doc_366216787874_item	3603295	et	4	main
illustreerida	doc_366216787874_item	3603296	et	3	main
näidetega	doc_366216787874_item	3603297	et	3	main
kõikidel	doc_366216787874_item	3603298	et	4	main
kultuuri	doc_366216787874_item	3603314	et	4	main
et	doc_366216787874_item	3603336	et	3	main
loomi	doc_366216787874_item	3603337	et	4	main
naised	doc_366216787874_item	3603346	et	3	main
meeldib	doc_366216787874_item	3603350	et	3	main
sellepärast	doc_366216787874_item	3603352	et	3	main
et	doc_366216787874_item	3603360	et	3	main
lauldest	doc_366216787874_item	3603362	et	4	main
on	doc_366216787874_item	3603375	et	4	main
selles	doc_366216787874_item	3603378	et	4	main
kus	doc_366216787874_item	3603385	et	3	main
veel	doc_366216787874_item	3603386	et	4	main
on	doc_366216787874_item	3603401	et	4	main
eesti	doc_366216787874_item	3603404	et	4	main
näiteks	doc_366216787874_item	3603411	et	4	main
laulurahva	doc_366216787876_item	3603492	et	3	main
300	doc_366216787876_item	3603495	et	2	main
essee	doc_366216787876_item	3603498	et	4	main
üldistav	doc_366216787876_item	3603504	et	4	main
tuginema	doc_366216787876_item	3603505	et	3	main
loengus	doc_366216787876_item	3603506	et	3	main
ja	doc_366216787876_item	3603507	et	3	main
eestlastest	doc_366216787876_item	3603518	et	4	main
eestlased	doc_366216787876_item	3603521	et	3	main
laulab	doc_366216787876_item	3603524	et	3	main
hästi	doc_366216787876_item	3603534	et	3	main
eestlastele	doc_366216787876_item	3603536	et	4	main
eestlastel	doc_366216787876_item	3603573	et	4	main
tantsu	doc_366216787876_item	3603585	et	4	main
muusika	doc_366216787876_item	3603586	et	4	main
laulud	doc_366216787876_item	3603587	et	3	main
laulupidu	doc_366216787876_item	3603593	et	4	main
esimene	doc_366216787876_item	3603594	et	3	main
kujunes	doc_366216787876_item	3603597	et	3	main
mille	doc_366216787876_item	3603601	et	3	main
jannseniga	doc_366216787876_item	3603612	et	4	main
muusikaline	doc_366216787876_item	3603616	et	4	main
suursündmus	doc_366216787876_item	3603617	et	3	main
mis	doc_366216787876_item	3603618	et	4	main
pani	doc_366216787876_item	3603619	et	4	main
korraldamisele	doc_366216787876_item	3603623	et	4	main
laulupidu	doc_366216787876_item	3603626	et	4	main
tahandeid	doc_366216787876_item	3603642	et	4	main
sest	doc_366216787876_item	3603653	et	4	main
tol	doc_366216787876_item	3603654	et	3	main
keele	doc_366216787877_item	3603705	et	4	main
test	doc_366216787877_item	3603706	et	3	main
kirjutamine	doc_366216787877_item	3603707	et	4	main
300	doc_366216787877_item	3603717	et	2	main
essee	doc_366216787877_item	3603720	et	4	main
tuginema	doc_366216787877_item	3603727	et	3	main
loengus	doc_366216787877_item	3603728	et	3	main
ja	doc_366216787877_item	3603729	et	3	main
lugemistekstis	doc_366216787877_item	3603730	et	3	main
esitatud	doc_366216787877_item	3603731	et	4	main
faktidele	doc_366216787877_item	3603732	et	3	main
väiteid	doc_366216787877_item	3603733	et	4	main
näidetega	doc_366216787877_item	3603737	et	3	main
laulmine	doc_366216787877_item	3603738	et	4	main
esteetiline	doc_366216787877_item	3603740	et	3	main
ja	doc_366216787877_item	3603741	et	3	main
üksi	doc_366216787877_item	3603751	et	4	main
kiigutades	doc_366216787877_item	3603755	et	3	main
rahvalauluga	doc_366216787877_item	3603757	et	4	main
laulu	doc_366216787877_item	3603764	et	4	main
kasutavad	doc_366216787877_item	3603800	et	4	main
laule	doc_366216787877_item	3603804	et	4	main
mitte	doc_366216787877_item	3603806	et	3	main
palju	doc_366216787877_item	3603808	et	4	main
aega	doc_366216787877_item	3603809	et	4	main
h	doc_366216787877_item	3603817	et	4	main
läbi	doc_366216787877_item	3603826	et	4	main
kus	doc_366216787877_item	3603828	et	3	main
arutlev	doc_366216787874_item	3603283	et	4	main
faktidele	doc_366216787874_item	3603292	et	3	main
oma	doc_366216787874_item	3603301	et	4	main
näiteks	doc_366216787874_item	3603304	et	4	main
italiased	doc_366216787874_item	3603305	et	4	main
teevad	doc_366216787874_item	3603306	et	3	main
mehed	doc_366216787874_item	3603348	et	3	main
laulda	doc_366216787874_item	3603351	et	4	main
võid	doc_366216787874_item	3603354	et	4	main
näita	doc_366216787874_item	3603355	et	4	main
võime	doc_366216787874_item	3603364	et	4	main
mis	doc_366216787874_item	3603371	et	4	main
ja	doc_366216787874_item	3603377	et	3	main
me	doc_366216787874_item	3603379	et	4	main
võime	doc_366216787874_item	3603380	et	4	main
teada	doc_366216787874_item	3603381	et	3	main
laulavad	doc_366216787874_item	3603387	et	4	main
eestlased	doc_366216787874_item	3603388	et	3	main
pulmadest	doc_366216787874_item	3603389	et	3	main
mida	doc_366216787874_item	3603392	et	4	main
tuli	doc_366216787874_item	3603407	et	4	main
uue	doc_366216787874_item	3603408	et	3	main
läti	doc_366216787874_item	3603414	et	4	main
muusika	doc_366216787874_item	3603415	et	4	main
kirjutamine	doc_366216787876_item	3603485	et	4	main
kirjutage	doc_366216787876_item	3603486	et	3	main
essee	doc_366216787876_item	3603487	et	4	main
teemal	doc_366216787876_item	3603488	et	3	main
mis	doc_366216787876_item	3603516	et	4	main
vastus	doc_366216787876_item	3603520	et	3	main
rahvas	doc_366216787876_item	3603523	et	4	main
ja	doc_366216787876_item	3603530	et	3	main
seda	doc_366216787876_item	3603532	et	3	main
regivärsiline	doc_366216787876_item	3603563	et	4	main
on	doc_366216787876_item	3603566	et	4	main
näiteks	doc_366216787876_item	3603579	et	4	main
kõige	doc_366216787876_item	3603588	et	4	main
on	doc_366216787876_item	3603591	et	4	main
voldemar	doc_366216787876_item	3603611	et	4	main
aasta	doc_366216787876_item	3603648	et	4	main
oli	doc_366216787876_item	3603650	et	3	main
linnas	doc_366216787876_item	3603660	et	4	main
tartus	doc_366216787876_item	3603661	et	3	main
essee	doc_366216787877_item	3603700	et	4	main
teise	doc_366216787877_item	3603704	et	4	main
essee	doc_366216787877_item	3603709	et	4	main
essee	doc_366216787877_item	3603715	et	4	main
pikkus	doc_366216787877_item	3603716	et	4	main
ja	doc_366216787877_item	3603725	et	3	main
üldistav	doc_366216787877_item	3603726	et	4	main
soovitatav	doc_366216787877_item	3603735	et	4	main
on	doc_366216787877_item	3603739	et	4	main
emotsionaalne	doc_366216787877_item	3603742	et	3	main
väljendusvahend	doc_366216787877_item	3603743	et	3	main
eluaeg	doc_366216787877_item	3603744	et	3	main
olles	doc_366216787877_item	3603752	et	3	main
tänasepäeval	doc_366216787877_item	3603761	et	4	main
taastatakse	doc_366216787877_item	3603762	et	3	main
eesti	doc_366216787877_item	3603801	et	4	main
2008	doc_366216787877_item	3603820	et	2	main
raekoja	doc_366216787877_item	3603821	et	3	main
1600	doc_366216787877_item	3603824	et	2	main
ürituse	doc_366216787877_item	3603827	et	4	main
pisar	doc_366216787877_item	3603847	et	3	main
kontserdi	doc_366216787877_item	3603861	et	3	main
ilmselt	doc_366216787877_item	3603863	et	4	main
närvipingest	doc_366216787877_item	3603864	et	4	main
unustas	doc_366216787877_item	3603865	et	3	main
mis	doc_366216787877_item	3603869	et	4	main
palju	doc_366216787877_item	3603885	et	4	main
ja	doc_366216787877_item	3603907	et	3	main
sama	doc_366216787877_item	3603909	et	4	main
on	doc_366216787877_item	3603918	et	4	main
konstruktsioon	doc_366216787877_item	3603922	et	3	main
ja	doc_366216787877_item	3603926	et	3	main
komsomoli	doc_366216787877_item	3603928	et	4	main
sõpru	doc_366216787877_item	3603938	et	3	main
osalejate	doc_366216787877_item	3603958	et	4	main
paraadile	doc_366216787877_item	3603959	et	3	main
ja	doc_366216787877_item	3603960	et	3	main
võtavad	doc_366216787877_item	3603999	et	3	main
lugemistekstis	doc_366216787874_item	3603290	et	3	main
on	doc_366216787874_item	3603300	et	4	main
parim	doc_366216787874_item	3603308	et	4	main
laulavad	doc_366216787874_item	3603345	et	4	main
eestlastele	doc_366216787874_item	3603349	et	4	main
lauldes	doc_366216787874_item	3603353	et	3	main
me	doc_366216787874_item	3603363	et	4	main
elati	doc_366216787874_item	3603367	et	3	main
kuidas	doc_366216787874_item	3603369	et	3	main
ajaloo	doc_366216787874_item	3603376	et	4	main
ajast	doc_366216787874_item	3603384	et	4	main
kõik	doc_366216787874_item	3603391	et	4	main
surnud	doc_366216787874_item	3603402	et	4	main
sai	doc_366216787874_item	3603405	et	4	main
iseseisvuse	doc_366216787874_item	3603406	et	4	main
vene	doc_366216787874_item	3603412	et	4	main
ja	doc_366216787874_item	3603413	et	3	main
eesti	doc_366216787876_item	3603479	et	4	main
eestlastest	doc_366216787876_item	3603491	et	4	main
pikkus	doc_366216787876_item	3603494	et	4	main
olema	doc_366216787876_item	3603500	et	4	main
arutlev	doc_366216787876_item	3603501	et	4	main
esitatud	doc_366216787876_item	3603509	et	4	main
teeb	doc_366216787876_item	3603517	et	3	main
laulurahva	doc_366216787876_item	3603519	et	3	main
aastat	doc_366216787876_item	3603529	et	3	main
teha	doc_366216787876_item	3603535	et	3	main
rahvalaul	doc_366216787876_item	3603564	et	4	main
kujunenud	doc_366216787876_item	3603567	et	4	main
enam	doc_366216787876_item	3603568	et	4	main
kui	doc_366216787876_item	3603569	et	3	main
erinevaid	doc_366216787876_item	3603577	et	4	main
hirmutama	doc_366216787874_item	3603338	et	4	main
noored	doc_366216787874_item	3603339	et	3	main
tehti	doc_366216787874_item	3603340	et	3	main
loomade	doc_366216787874_item	3603341	et	4	main
hääled	doc_366216787874_item	3603342	et	3	main
aga	doc_366216787874_item	3603343	et	3	main
rohkem	doc_366216787874_item	3603344	et	4	main
oma	doc_366216787874_item	3603356	et	4	main
kultuur	doc_366216787874_item	3603357	et	3	main
vanest	doc_366216787874_item	3603361	et	4	main
teada	doc_366216787874_item	3603365	et	3	main
varem	doc_366216787874_item	3603368	et	4	main
lauldi	doc_366216787874_item	3603370	et	3	main
lauldi	doc_366216787874_item	3603372	et	3	main
kõik	doc_366216787874_item	3603373	et	4	main
see	doc_366216787874_item	3603374	et	3	main
vanest	doc_366216787874_item	3603383	et	4	main
keegi	doc_366216787874_item	3603400	et	4	main
muusika	doc_366216787874_item	3603409	et	4	main
kuidas	doc_366216787874_item	3603366	et	3	main
kõik	doc_366216787874_item	3603382	et	4	main
lauldi	doc_366216787874_item	3603390	et	3	main
tehti	doc_366216787874_item	3603393	et	3	main
näiteks	doc_366216787874_item	3603394	et	4	main
tervitati	doc_366216787874_item	3603395	et	3	main
pulmarongi	doc_366216787874_item	3603396	et	4	main
ka	doc_366216787874_item	3603397	et	3	main
lauldi	doc_366216787874_item	3603398	et	3	main
kui	doc_366216787874_item	3603399	et	3	main
kui	doc_366216787874_item	3603403	et	3	main
stiilid	doc_366216787874_item	3603410	et	4	main
on	doc_366216787874_item	3603416	et	4	main
eesti	doc_366216787874_item	3603417	et	4	main
muusika	doc_366216787874_item	3603418	et	4	main
naaber	doc_366216787874_item	3603419	et	3	main
mis	doc_366216787874_item	3603420	et	4	main
näitab	doc_366216787874_item	3603421	et	3	main
tänapäeval	doc_366216787874_item	3603422	et	3	main
et	doc_366216787874_item	3603423	et	3	main
eestlased	doc_366216787874_item	3603424	et	3	main
on	doc_366216787874_item	3603425	et	4	main
laulurahva	doc_366216787874_item	3603426	et	3	main
laulupeod	doc_366216787874_item	3603427	et	4	main
mis	doc_366216787874_item	3603428	et	4	main
toimuti	doc_366216787874_item	3603429	et	3	main
palju	doc_366216787874_item	3603430	et	4	main
aega	doc_366216787874_item	3603431	et	4	main
varem	doc_366216787874_item	3603432	et	4	main
toimuvad	doc_366216787874_item	3603433	et	4	main
tänapäeval	doc_366216787874_item	3603434	et	3	main
see	doc_366216787874_item	3603435	et	3	main
on	doc_366216787874_item	3603436	et	4	main
kõige	doc_366216787874_item	3603437	et	4	main
tähelepanuväärsem	doc_366216787874_item	3603438	et	4	main
festivaalis	doc_366216787874_item	3603439	et	4	main
esinevad	doc_366216787874_item	3603440	et	4	main
palju	doc_366216787874_item	3603441	et	4	main
teised	doc_366216787874_item	3603442	et	4	main
riigid	doc_366216787874_item	3603443	et	3	main
mis	doc_366216787874_item	3603444	et	4	main
laulavad	doc_366216787874_item	3603445	et	4	main
tantsivad	doc_366216787874_item	3603446	et	4	main
ja	doc_366216787874_item	3603447	et	3	main
sellest	doc_366216787874_item	3603448	et	4	main
me	doc_366216787874_item	3603449	et	4	main
keele	doc_366216787876_item	3603483	et	4	main
essee	doc_366216787876_item	3603478	et	4	main
keele	doc_366216787876_item	3603480	et	4	main
kui	doc_366216787876_item	3603481	et	3	main
teise	doc_366216787876_item	3603482	et	4	main
mis	doc_366216787876_item	3603489	et	4	main
peab	doc_366216787876_item	3603499	et	4	main
lugemistekstis	doc_366216787876_item	3603508	et	3	main
on	doc_366216787876_item	3603512	et	4	main
soovitatav	doc_366216787876_item	3603513	et	4	main
illustreerida	doc_366216787876_item	3603514	et	3	main
näidetega	doc_366216787876_item	3603515	et	3	main
see	doc_366216787876_item	3603522	et	3	main
juba	doc_366216787876_item	3603525	et	3	main
rohkem	doc_366216787876_item	3603526	et	4	main
kui	doc_366216787876_item	3603527	et	3	main
väga	doc_366216787876_item	3603533	et	3	main
kui	doc_366216787876_item	3603538	et	3	main
need	doc_366216787876_item	3603539	et	3	main
nimetakse	doc_366216787876_item	3603540	et	3	main
laulurahvas	doc_366216787876_item	3603541	et	4	main
see	doc_366216787876_item	3603542	et	3	main
nimi	doc_366216787876_item	3603543	et	3	main
sobip	doc_366216787876_item	3603544	et	4	main
nendele	doc_366216787876_item	3603545	et	4	main
kõige	doc_366216787876_item	3603546	et	4	main
rohkem	doc_366216787876_item	3603547	et	4	main
vanasti	doc_366216787876_item	3603548	et	3	main
lauldi	doc_366216787876_item	3603549	et	3	main
koguaeg	doc_366216787876_item	3603550	et	3	main
töö	doc_366216787876_item	3603551	et	4	main
juures	doc_366216787876_item	3603552	et	4	main
lastele	doc_366216787876_item	3603553	et	4	main
vabal	doc_366216787876_item	3603554	et	3	main
ajal	doc_366216787876_item	3603555	et	4	main
eesti	doc_366216787876_item	3603556	et	4	main
vanemat	doc_366216787876_item	3603557	et	4	main
laulutraditsiooni	doc_366216787876_item	3603558	et	4	main
esindab	doc_366216787876_item	3603559	et	3	main
läänemeresoome	doc_366216787876_item	3603560	et	3	main
kultuurile	doc_366216787876_item	3603561	et	3	main
iseloomulik	doc_366216787876_item	3603562	et	3	main
test	doc_366216787876_item	3603484	et	3	main
teeb	doc_366216787876_item	3603490	et	3	main
essee	doc_366216787876_item	3603493	et	4	main
350	doc_366216787876_item	3603496	et	2	main
sõna	doc_366216787876_item	3603497	et	4	main
analüüsiv	doc_366216787876_item	3603502	et	4	main
ja	doc_366216787876_item	3603503	et	3	main
faktidele	doc_366216787876_item	3603510	et	3	main
väiteid	doc_366216787876_item	3603511	et	4	main
tuhad	doc_366216787876_item	3603528	et	3	main
oskab	doc_366216787876_item	3603531	et	3	main
meeldib	doc_366216787876_item	3603537	et	3	main
tuhat	doc_366216787876_item	3603570	et	4	main
aastat	doc_366216787876_item	3603571	et	3	main
tagasi	doc_366216787876_item	3603572	et	3	main
laulu	doc_366216787876_item	3603578	et	4	main
laulud	doc_366216787876_item	3603580	et	3	main
laulud	doc_366216787876_item	3603582	et	3	main
pulmade	doc_366216787876_item	3603583	et	3	main
jaoks	doc_366216787876_item	3603584	et	4	main
kindlasti	doc_366216787876_item	3603592	et	3	main
ülemaaline	doc_366216787876_item	3603595	et	4	main
laulupidu	doc_366216787876_item	3603596	et	4	main
1869	doc_366216787876_item	3603598	et	2	main
tartus	doc_366216787876_item	3603600	et	3	main
korraldamise	doc_366216787876_item	3603602	et	4	main
idee	doc_366216787876_item	3603603	et	4	main
ja	doc_366216787876_item	3603604	et	3	main
eesotsas	doc_366216787876_item	3603609	et	4	main
üldlaulupidude	doc_366216787876_item	3603622	et	4	main
lauljad	doc_366216787876_item	3603643	et	4	main
tallinna	doc_366216787876_item	3603644	et	4	main
lauluväljakule	doc_366216787876_item	3603645	et	3	main
suvel	doc_366216787876_item	3603655	et	3	main
100	doc_366216787876_item	3603679	et	2	main
esinejat	doc_366216787876_item	3603678	et	4	main
000	doc_366216787876_item	3603680	et	2	main
pealtvaatajale	doc_366216787876_item	3603681	et	3	main
siit	doc_366216787876_item	3603682	et	3	main
paistab	doc_366216787876_item	3603683	et	3	main
et	doc_366216787876_item	3603684	et	3	main
rahvas	doc_366216787876_item	3603685	et	4	main
armastab	doc_366216787876_item	3603686	et	3	main
oma	doc_366216787876_item	3603687	et	4	main
kultuuri	doc_366216787876_item	3603688	et	4	main
ja	doc_366216787876_item	3603689	et	3	main
oma	doc_366216787876_item	3603690	et	4	main
laulud	doc_366216787876_item	3603691	et	3	main
ja	doc_366216787876_item	3603692	et	3	main
võib	doc_366216787876_item	3603693	et	3	main
öelda	doc_366216787876_item	3603694	et	4	main
et	doc_366216787876_item	3603695	et	3	main
eestlased	doc_366216787876_item	3603696	et	3	main
on	doc_366216787876_item	3603697	et	4	main
laulurahvas	doc_366216787876_item	3603698	et	4	main
eesti	doc_366216787877_item	3603701	et	4	main
keele	doc_366216787877_item	3603702	et	4	main
kui	doc_366216787877_item	3603703	et	3	main
mis	doc_366216787877_item	3603711	et	4	main
350	doc_366216787877_item	3603718	et	2	main
analüüsiv	doc_366216787877_item	3603724	et	4	main
mis	doc_366216787876_item	3603565	et	4	main
on	doc_366216787876_item	3603574	et	4	main
väga	doc_366216787876_item	3603575	et	3	main
palju	doc_366216787876_item	3603576	et	4	main
asi	doc_366216787876_item	3603590	et	4	main
teostus	doc_366216787876_item	3603605	et	4	main
tuli	doc_366216787876_item	3603606	et	4	main
johann	doc_366216787876_item	3603610	et	4	main
sellest	doc_366216787876_item	3603615	et	4	main
järgnevate	doc_366216787876_item	3603621	et	4	main
laulupeole	doc_366216787876_item	3603646	et	4	main
laulupidu	doc_366216787876_item	3603649	et	4	main
kõige	doc_366216787876_item	3603651	et	4	main
suurem	doc_366216787876_item	3603652	et	4	main
eesti	doc_366216787876_item	3603657	et	4	main
kahes	doc_366216787876_item	3603659	et	4	main
lastele	doc_366216787876_item	3603581	et	4	main
tähtsam	doc_366216787876_item	3603589	et	4	main
aastal	doc_366216787876_item	3603599	et	3	main
vanemuise	doc_366216787876_item	3603607	et	4	main
seltsist	doc_366216787876_item	3603608	et	4	main
ühtlasi	doc_366216787876_item	3603613	et	4	main
sai	doc_366216787876_item	3603614	et	4	main
aluse	doc_366216787876_item	3603620	et	4	main
üle	doc_366216787876_item	3603624	et	3	main
eestiline	doc_366216787876_item	3603625	et	3	main
on	doc_366216787876_item	3603627	et	4	main
ka	doc_366216787876_item	3603628	et	3	main
praegusel	doc_366216787876_item	3603629	et	3	main
ajal	doc_366216787876_item	3603630	et	4	main
kõige	doc_366216787876_item	3603631	et	4	main
tähelepanuväärsem	doc_366216787876_item	3603632	et	4	main
ja	doc_366216787876_item	3603633	et	3	main
massilisem	doc_366216787876_item	3603634	et	4	main
rahvusluse	doc_366216787876_item	3603635	et	4	main
manifestatsioon	doc_366216787876_item	3603636	et	3	main
1994	doc_366216787876_item	3603638	et	2	main
eestis	doc_366216787876_item	3603637	et	3	main
aasta	doc_366216787876_item	3603639	et	4	main
juulis	doc_366216787876_item	3603640	et	3	main
kogunesid	doc_366216787876_item	3603641	et	4	main
see	doc_366216787876_item	3603647	et	3	main
korraldati	doc_366216787876_item	3603656	et	3	main
üldlaulupidu	doc_366216787876_item	3603658	et	4	main
ja	doc_366216787876_item	3603662	et	3	main
tallinnas	doc_366216787876_item	3603663	et	4	main
tartus	doc_366216787876_item	3603664	et	3	main
laulis	doc_366216787876_item	3603665	et	4	main
umbes	doc_366216787876_item	3603666	et	4	main
16	doc_366216787876_item	3603667	et	2	main
000	doc_366216787876_item	3603668	et	2	main
laujat	doc_366216787876_item	3603669	et	4	main
70	doc_366216787876_item	3603670	et	2	main
000	doc_366216787876_item	3603671	et	2	main
kuulajale	doc_366216787876_item	3603672	et	4	main
tallinnas	doc_366216787876_item	3603673	et	4	main
laulis	doc_366216787876_item	3603674	et	4	main
ühtekokku	doc_366216787876_item	3603675	et	3	main
25	doc_366216787876_item	3603676	et	2	main
000	doc_366216787876_item	3603677	et	2	main
kirjutage	doc_366216787877_item	3603708	et	3	main
teeb	doc_366216787877_item	3603712	et	3	main
laulurahva	doc_366216787877_item	3603714	et	3	main
sõna	doc_366216787877_item	3603719	et	4	main
peab	doc_366216787877_item	3603721	et	4	main
olema	doc_366216787877_item	3603722	et	4	main
illustreerida	doc_366216787877_item	3603736	et	3	main
lauldi	doc_366216787877_item	3603750	et	3	main
teemal	doc_366216787877_item	3603710	et	3	main
eestlastest	doc_366216787877_item	3603713	et	4	main
arutlev	doc_366216787877_item	3603723	et	4	main
on	doc_366216787877_item	3603734	et	4	main
hällist	doc_366216787877_item	3603748	et	4	main
hauani	doc_366216787877_item	3603749	et	3	main
vana	doc_366216787877_item	3603763	et	4	main
ehk	doc_366216787877_item	3603765	et	3	main
rägivärsilise	doc_366216787877_item	3603766	et	4	main
laulu	doc_366216787877_item	3603767	et	4	main
mis	doc_366216787877_item	3603768	et	4	main
on	doc_366216787877_item	3603769	et	4	main
kujunenud	doc_366216787877_item	3603770	et	4	main
enam	doc_366216787877_item	3603771	et	4	main
kui	doc_366216787877_item	3603772	et	3	main
tuhat	doc_366216787877_item	3603773	et	4	main
aastat	doc_366216787877_item	3603774	et	3	main
tagasi	doc_366216787877_item	3603775	et	3	main
laulavad	doc_366216787877_item	3603776	et	4	main
laule	doc_366216787877_item	3603777	et	4	main
mis	doc_366216787877_item	3603778	et	4	main
laulsid	doc_366216787877_item	3603779	et	4	main
emad	doc_366216787877_item	3603780	et	3	main
lastele	doc_366216787877_item	3603781	et	4	main
nn	doc_366216787877_item	3603782	et	4	main
emalaulud	doc_366216787877_item	3603783	et	3	main
laulsid	doc_366216787877_item	3603785	et	4	main
mehed	doc_366216787877_item	3603786	et	3	main
peodel	doc_366216787877_item	3603787	et	3	main
mis	doc_366216787877_item	3603784	et	4	main
ja	doc_366216787877_item	3603788	et	3	main
arhiveeritakse	doc_366216787877_item	3603789	et	4	main
lindistatakse	doc_366216787877_item	3603790	et	3	main
tänase	doc_366216787877_item	3603791	et	3	main
päeval	doc_366216787877_item	3603792	et	3	main
on	doc_366216787877_item	3603793	et	4	main
välja	doc_366216787877_item	3603794	et	4	main
kujunenud	doc_366216787877_item	3603795	et	4	main
üritused	doc_366216787877_item	3603796	et	4	main
kus	doc_366216787877_item	3603797	et	3	main
eesti	doc_366216787877_item	3603798	et	4	main
kõrgpoliitikud	doc_366216787877_item	3603799	et	3	main
saatis	doc_366216787877_item	3603745	et	3	main
laul	doc_366216787877_item	3603746	et	4	main
eestlast	doc_366216787877_item	3603747	et	4	main
töötades	doc_366216787877_item	3603753	et	3	main
tutvumine	doc_366216787877_item	3603756	et	4	main
on	doc_366216787877_item	3603758	et	4	main
ajaloo	doc_366216787877_item	3603759	et	4	main
sümboolikad	doc_366216787877_item	3603803	et	3	main
me	doc_366216787877_item	3603813	et	4	main
t	doc_366216787877_item	3603816	et	4	main
kell	doc_366216787877_item	3603823	et	3	main
tehnikaülikooli	doc_366216787877_item	3603833	et	4	main
ansambel	doc_366216787877_item	3603837	et	3	main
käes	doc_366216787877_item	3603845	et	4	main
laulsid	doc_366216787877_item	3603849	et	4	main
kes	doc_366216787877_item	3603859	et	4	main
alustas	doc_366216787877_item	3603860	et	3	main
laulu	doc_366216787877_item	3603875	et	4	main
väga	doc_366216787877_item	3603876	et	3	main
meeldiv	doc_366216787877_item	3603877	et	4	main
ka	doc_366216787877_item	3603878	et	3	main
see	doc_366216787877_item	3603879	et	3	main
et	doc_366216787877_item	3603880	et	3	main
mäletan	doc_366216787877_item	3603900	et	3	main
kollase	doc_366216787877_item	3603902	et	4	main
mis	doc_366216787877_item	3603904	et	4	main
värvi	doc_366216787877_item	3603910	et	4	main
ja	doc_366216787877_item	3603911	et	3	main
rahvuslik	doc_366216787877_item	3603912	et	3	main
instrument	doc_366216787877_item	3603913	et	3	main
metall	doc_366216787877_item	3603921	et	3	main
lauluväljakul	doc_366216787877_item	3603924	et	3	main
tantsupeod	doc_366216787877_item	3603927	et	4	main
inimestega	doc_366216787877_item	3603943	et	3	main
vaatasid	doc_366216787877_item	3603957	et	4	main
keele	doc_366216787878_item	3604009	et	4	main
essee	doc_366216787878_item	3604013	et	4	main
teemal	doc_366216787878_item	3604014	et	3	main
essee	doc_366216787878_item	3604024	et	4	main
ja	doc_366216787878_item	3604029	et	3	main
üldistav	doc_366216787878_item	3604030	et	4	main
tuginema	doc_366216787878_item	3604031	et	3	main
loengus	doc_366216787878_item	3604032	et	3	main
ja	doc_366216787878_item	3604033	et	3	main
lugemistekstis	doc_366216787878_item	3604034	et	3	main
esitatud	doc_366216787878_item	3604035	et	4	main
faktidele	doc_366216787878_item	3604036	et	3	main
ammustest	doc_366216787878_item	3604063	et	4	main
lapsi	doc_366216787878_item	3604072	et	4	main
vanemaid	doc_366216787878_item	3604082	et	4	main
regivärsilisi	doc_366216787878_item	3604084	et	4	main
ja	doc_366216787878_item	3604085	et	3	main
riimilisi	doc_366216787878_item	3604086	et	4	main
laule	doc_366216787878_item	3604087	et	4	main
samuti	doc_366216787878_item	3604088	et	3	main
laulikud	doc_366216787878_item	3604089	et	3	main
austust	doc_366216787878_item	3604098	et	4	main
rahva	doc_366216787878_item	3604100	et	3	main
ärkamisaeg	doc_366216787878_item	3604101	et	3	main
on	doc_366216787878_item	3604102	et	4	main
rahvalaulu	doc_366216787878_item	3604105	et	4	main
laul	doc_366216787878_item	3604116	et	4	main
eestlast	doc_366216787878_item	3604117	et	4	main
hällist	doc_366216787878_item	3604118	et	4	main
hauani	doc_366216787878_item	3604119	et	3	main
kui	doc_366216787878_item	3604120	et	3	main
uuritakse	doc_366216787878_item	3604121	et	3	main
tingimata	doc_366216787878_item	3604124	et	4	main
minevikuga	doc_366216787878_item	3604128	et	3	main
on	doc_366216787878_item	3604130	et	4	main
nagu	doc_366216787878_item	3604131	et	3	main
ajaloo	doc_366216787878_item	3604132	et	4	main
kuulda	doc_366216787878_item	3604140	et	4	main
laulmine	doc_366216787878_item	3604143	et	4	main
üks	doc_366216787878_item	3604145	et	3	main
olulisi	doc_366216787878_item	3604146	et	4	main
kultuurinähtuseid	doc_366216787878_item	3604147	et	3	main
see	doc_366216787878_item	3604148	et	3	main
on	doc_366216787878_item	3604149	et	4	main
esteetiline	doc_366216787878_item	3604150	et	3	main
ja	doc_366216787878_item	3604151	et	3	main
last	doc_366216787877_item	3603754	et	4	main
uurimine	doc_366216787877_item	3603760	et	4	main
on	doc_366216787877_item	3603810	et	4	main
möödas	doc_366216787877_item	3603811	et	3	main
kui	doc_366216787877_item	3603812	et	3	main
ilvest	doc_366216787877_item	3603818	et	3	main
platsil	doc_366216787877_item	3603822	et	3	main
piirivalve	doc_366216787877_item	3603830	et	4	main
orkester	doc_366216787877_item	3603831	et	3	main
tallinna	doc_366216787877_item	3603832	et	4	main
koor	doc_366216787877_item	3603835	et	4	main
käsi	doc_366216787877_item	3603844	et	4	main
eesti	doc_366216787877_item	3603850	et	4	main
vaadata	doc_366216787877_item	3603855	et	4	main
kui	doc_366216787877_item	3603856	et	3	main
väike	doc_366216787877_item	3603857	et	4	main
tütarlaps	doc_366216787877_item	3603858	et	4	main
sõnad	doc_366216787877_item	3603866	et	4	main
siis	doc_366216787877_item	3603867	et	3	main
kogunud	doc_366216787877_item	3603871	et	4	main
väikesel	doc_366216787877_item	3603881	et	4	main
eestil	doc_366216787877_item	3603882	et	3	main
ilusa	doc_366216787877_item	3603901	et	3	main
mütsike	doc_366216787877_item	3603903	et	4	main
kolmnurkne	doc_366216787877_item	3603920	et	3	main
mäletan	doc_366216787877_item	3603923	et	3	main
laulupeod	doc_366216787877_item	3603925	et	4	main
koos	doc_366216787877_item	3603935	et	4	main
perega	doc_366216787877_item	3603936	et	3	main
kohtuvad	doc_366216787877_item	3603937	et	4	main
tantsupidu	doc_366216787877_item	3603949	et	4	main
paduvihma	doc_366216787877_item	3603951	et	4	main
alla	doc_366216787877_item	3603952	et	3	main
sattunud	doc_366216787877_item	3603953	et	4	main
suured	doc_366216787877_item	3603954	et	3	main
saadikud	doc_366216787877_item	3603955	et	3	main
välismaalt	doc_366216787877_item	3603956	et	3	main
salmik	doc_366216787877_item	3603994	et	3	main
inimesed	doc_366216787877_item	3603996	et	3	main
hea	doc_366216787877_item	3603997	et	4	main
rahvusliku	doc_366216787877_item	3603802	et	3	main
rietust	doc_366216787877_item	3603805	et	4	main
nii	doc_366216787877_item	3603807	et	3	main
nägime	doc_366216787877_item	3603814	et	3	main
telekanalitel	doc_366216787877_item	3603815	et	3	main
rahvariietuses	doc_366216787877_item	3603819	et	3	main
viidi	doc_366216787877_item	3603825	et	4	main
seisid	doc_366216787877_item	3603843	et	4	main
silmas	doc_366216787877_item	3603848	et	4	main
rahvalaulud	doc_366216787877_item	3603851	et	3	main
huvitav	doc_366216787877_item	3603853	et	4	main
suurest	doc_366216787877_item	3603862	et	4	main
tõesti	doc_366216787877_item	3603884	et	3	main
rahvalaule	doc_366216787877_item	3603886	et	4	main
kontsert	doc_366216787877_item	3603887	et	3	main
kestis	doc_366216787877_item	3603888	et	4	main
25	doc_366216787877_item	3603889	et	2	main
tundi	doc_366216787877_item	3603890	et	4	main
ja	doc_366216787877_item	3603891	et	3	main
laulud	doc_366216787877_item	3603892	et	3	main
ainult	doc_366216787877_item	3603893	et	4	main
vahetusid	doc_366216787877_item	3603894	et	4	main
üks	doc_366216787877_item	3603895	et	3	main
teise	doc_366216787877_item	3603896	et	4	main
järgi	doc_366216787877_item	3603897	et	4	main
oma	doc_366216787877_item	3603898	et	4	main
lapsepõlvest	doc_366216787877_item	3603899	et	4	main
esinesid	doc_366216787877_item	3603829	et	4	main
meeste	doc_366216787877_item	3603834	et	4	main
ning	doc_366216787877_item	3603836	et	3	main
kurerpillid	doc_366216787877_item	3603838	et	4	main
vanad	doc_366216787877_item	3603839	et	3	main
inimesed	doc_366216787877_item	3603840	et	3	main
koos	doc_366216787877_item	3603841	et	4	main
noortega	doc_366216787877_item	3603842	et	3	main
ja	doc_366216787877_item	3603846	et	3	main
ja	doc_366216787877_item	3603852	et	3	main
oli	doc_366216787877_item	3603854	et	3	main
rahvas	doc_366216787877_item	3603868	et	4	main
oli	doc_366216787877_item	3603870	et	3	main
raekoja	doc_366216787877_item	3603872	et	3	main
platsile	doc_366216787877_item	3603873	et	4	main
jätkas	doc_366216787877_item	3603874	et	3	main
on	doc_366216787877_item	3603883	et	4	main
mul	doc_366216787877_item	3603905	et	3	main
seeliku	doc_366216787877_item	3603908	et	3	main
ei	doc_366216787877_item	3603914	et	4	main
tea	doc_366216787877_item	3603915	et	4	main
kuidas	doc_366216787877_item	3603916	et	3	main
tavaline	doc_366216787877_item	3603919	et	4	main
staadiumil	doc_366216787877_item	3603929	et	3	main
sellistele	doc_366216787877_item	3603930	et	4	main
peodele	doc_366216787877_item	3603931	et	3	main
ja	doc_366216787877_item	3603933	et	3	main
tuttavaid	doc_366216787877_item	3603939	et	3	main
2004	doc_366216787877_item	3603944	et	2	main
laulupeo	doc_366216787877_item	3603946	et	4	main
imestasid	doc_366216787877_item	3603961	et	4	main
on	doc_366216787877_item	3603993	et	4	main
meelega	doc_366216787877_item	3603998	et	4	main
eesti	doc_366216787878_item	3604005	et	4	main
kirjutage	doc_366216787878_item	3604012	et	3	main
mis	doc_366216787878_item	3604015	et	4	main
teeb	doc_366216787878_item	3604016	et	3	main
eestlastest	doc_366216787878_item	3604017	et	4	main
laulurahva	doc_366216787878_item	3604018	et	3	main
peab	doc_366216787878_item	3604025	et	4	main
maailma	doc_366216787878_item	3604043	et	4	main
aegadest	doc_366216787878_item	3604064	et	3	main
laulab	doc_366216787878_item	3604066	et	3	main
kas	doc_366216787878_item	3604068	et	3	main
puhul	doc_366216787878_item	3604079	et	4	main
eriti	doc_366216787878_item	3604080	et	3	main
armastatakse	doc_366216787878_item	3604081	et	3	main
omavad	doc_366216787878_item	3604093	et	4	main
praegugi	doc_366216787878_item	3604094	et	3	main
suurt	doc_366216787878_item	3604095	et	3	main
tähendust	doc_366216787878_item	3604096	et	4	main
ning	doc_366216787878_item	3604097	et	3	main
tihedalt	doc_366216787878_item	3604103	et	4	main
seotud	doc_366216787878_item	3604104	et	4	main
ja	doc_366216787878_item	3604106	et	3	main
laul	doc_366216787878_item	3604108	et	4	main
siis	doc_366216787878_item	3604123	et	3	main
saadakse	doc_366216787878_item	3604125	et	3	main
kokku	doc_366216787878_item	3604126	et	3	main
rahva	doc_366216787878_item	3604127	et	3	main
võiks	doc_366216787878_item	3604154	et	4	main
tegevus	doc_366216787878_item	3604162	et	4	main
iseloomustab	doc_366216787878_item	3604165	et	4	main
kaks	doc_366216787878_item	3604166	et	3	main
laulupidusid	doc_366216787878_item	3604222	et	4	main
korraldatakse	doc_366216787878_item	3604223	et	3	main
on	doc_366216787878_item	3604232	et	4	main
rajatud	doc_366216787878_item	3604233	et	4	main
sümbolitele	doc_366216787878_item	3604234	et	3	main
on	doc_366216787878_item	3604240	et	4	main
nimetatud	doc_366216787878_item	3604256	et	4	main
ärkamisaja	doc_366216787878_item	3604258	et	3	main
käib	doc_366216787878_item	3604265	et	3	main
kultuurielu	doc_366216787878_item	3604267	et	4	main
mis	doc_366216787878_item	3604276	et	4	main
keele	doc_366216787882_item	3604286	et	4	main
essee	doc_366216787882_item	3604296	et	4	main
peab	doc_366216787882_item	3604302	et	4	main
olema	doc_366216787882_item	3604303	et	4	main
analüüsiv	doc_366216787882_item	3604305	et	4	main
ja	doc_366216787882_item	3604306	et	3	main
üldistav	doc_366216787882_item	3604307	et	4	main
oli	doc_366216787877_item	3603906	et	3	main
nimetus	doc_366216787877_item	3603917	et	4	main
käidi	doc_366216787877_item	3603932	et	3	main
käivad	doc_366216787877_item	3603934	et	4	main
laulavad	doc_366216787877_item	3603940	et	4	main
koos	doc_366216787877_item	3603941	et	4	main
võõrastega	doc_366216787877_item	3603942	et	4	main
aastal	doc_366216787877_item	3603945	et	3	main
üritus	doc_366216787877_item	3603947	et	4	main
ja	doc_366216787877_item	3603948	et	3	main
olid	doc_366216787877_item	3603950	et	4	main
inimesed	doc_366216787877_item	3603962	et	3	main
lauluga	doc_366216787877_item	3603963	et	4	main
ja	doc_366216787877_item	3603964	et	3	main
tantsuga	doc_366216787877_item	3603965	et	3	main
läbi	doc_366216787877_item	3603966	et	4	main
linna	doc_366216787877_item	3603967	et	4	main
sammusid	doc_366216787877_item	3603968	et	4	main
lauluväljaku	doc_366216787877_item	3603969	et	3	main
poole	doc_366216787877_item	3603970	et	4	main
aina	doc_366216787877_item	3603971	et	4	main
populaarsemaks	doc_366216787877_item	3603972	et	4	main
muutuvad	doc_366216787877_item	3603973	et	4	main
reet	doc_366216787877_item	3603974	et	4	main
linna	doc_366216787877_item	3603975	et	4	main
üritused	doc_366216787877_item	3603976	et	4	main
koorilaulmisega	doc_366216787877_item	3603977	et	3	main
läbi	doc_366216787877_item	3603978	et	4	main
eesti	doc_366216787877_item	3603979	et	4	main
ja	doc_366216787877_item	3603980	et	3	main
ei	doc_366216787877_item	3603981	et	4	main
ole	doc_366216787877_item	3603982	et	4	main
hullu	doc_366216787877_item	3603983	et	4	main
et	doc_366216787877_item	3603984	et	3	main
mitte	doc_366216787877_item	3603985	et	3	main
kõik	doc_366216787877_item	3603986	et	4	main
inimesed	doc_366216787877_item	3603987	et	3	main
mäletavad	doc_366216787877_item	3603988	et	4	main
laulde	doc_366216787877_item	3603989	et	4	main
sõnu	doc_366216787877_item	3603990	et	4	main
selle	doc_366216787877_item	3603991	et	4	main
jaoks	doc_366216787877_item	3603992	et	4	main
olemas	doc_366216787877_item	3603995	et	4	main
osa	doc_366216787877_item	3604000	et	4	main
rahvalaulu	doc_366216787877_item	3604001	et	4	main
üritustes	doc_366216787877_item	3604002	et	4	main
kui	doc_366216787878_item	3604007	et	3	main
test	doc_366216787878_item	3604010	et	3	main
essee	doc_366216787878_item	3604019	et	4	main
pikkus	doc_366216787878_item	3604020	et	4	main
300	doc_366216787878_item	3604021	et	2	main
350	doc_366216787878_item	3604022	et	2	main
arutlev	doc_366216787878_item	3604027	et	4	main
on	doc_366216787878_item	3604038	et	4	main
kiigutades	doc_366216787878_item	3604073	et	3	main
pulma	doc_366216787878_item	3604074	et	4	main
saavutamiseks	doc_366216787878_item	3604244	et	4	main
rahvalaul	doc_366216787878_item	3604245	et	4	main
sai	doc_366216787878_item	3604246	et	4	main
eesti	doc_366216787878_item	3604247	et	4	main
rahva	doc_366216787878_item	3604248	et	3	main
lootuseks	doc_366216787878_item	3604249	et	4	main
raskel	doc_366216787878_item	3604250	et	3	main
ajal	doc_366216787878_item	3604251	et	4	main
nii	doc_366216787878_item	3604252	et	3	main
teise	doc_366216787878_item	3604008	et	4	main
olema	doc_366216787878_item	3604026	et	4	main
väiteid	doc_366216787878_item	3604037	et	4	main
rahval	doc_366216787878_item	3604044	et	3	main
on	doc_366216787878_item	3604045	et	4	main
oma	doc_366216787878_item	3604046	et	4	main
omapära	doc_366216787878_item	3604047	et	4	main
on	doc_366216787878_item	3604049	et	4	main
eestlastel	doc_366216787878_item	3604048	et	4	main
olemas	doc_366216787878_item	3604050	et	4	main
ka	doc_366216787878_item	3604051	et	3	main
üks	doc_366216787878_item	3604052	et	3	main
erinev	doc_366216787878_item	3604053	et	4	main
joon	doc_366216787878_item	3604054	et	4	main
eesti	doc_366216787878_item	3604055	et	4	main
rahvas	doc_366216787878_item	3604056	et	4	main
on	doc_366216787878_item	3604057	et	4	main
laulurahvas	doc_366216787878_item	3604058	et	4	main
eestlane	doc_366216787878_item	3604059	et	3	main
väga	doc_366216787878_item	3604060	et	3	main
armastab	doc_366216787878_item	3604061	et	3	main
laulda	doc_366216787878_item	3604062	et	4	main
essee	doc_366216787878_item	3604004	et	4	main
keele	doc_366216787878_item	3604006	et	4	main
kirjutamine	doc_366216787878_item	3604011	et	4	main
sõna	doc_366216787878_item	3604023	et	4	main
analüüsiv	doc_366216787878_item	3604028	et	4	main
soovitatav	doc_366216787878_item	3604039	et	4	main
illustreerida	doc_366216787878_item	3604040	et	3	main
näidetega	doc_366216787878_item	3604041	et	3	main
igal	doc_366216787878_item	3604042	et	3	main
peale	doc_366216787878_item	3604065	et	4	main
või	doc_366216787878_item	3604076	et	4	main
rahvalaule	doc_366216787878_item	3604083	et	4	main
vanasti	doc_366216787878_item	3604114	et	3	main
saatis	doc_366216787878_item	3604115	et	3	main
võib	doc_366216787878_item	3604139	et	3	main
öelda	doc_366216787878_item	3604155	et	4	main
et	doc_366216787878_item	3604156	et	3	main
see	doc_366216787878_item	3604157	et	3	main
on	doc_366216787878_item	3604158	et	4	main
ka	doc_366216787878_item	3604159	et	3	main
omakorda	doc_366216787878_item	3604160	et	3	main
eesti	doc_366216787878_item	3604163	et	4	main
sündmuseks	doc_366216787878_item	3604200	et	3	main
said	doc_366216787878_item	3604204	et	4	main
üldlaulupeod	doc_366216787878_item	3604205	et	4	main
neist	doc_366216787878_item	3604206	et	4	main
esimene	doc_366216787878_item	3604207	et	3	main
on	doc_366216787878_item	3604208	et	4	main
toimunud	doc_366216787878_item	3604209	et	4	main
tartus	doc_366216787878_item	3604210	et	3	main
1869	doc_366216787878_item	3604211	et	2	main
aastal	doc_366216787878_item	3604212	et	3	main
johann	doc_366216787878_item	3604213	et	4	main
voldemar	doc_366216787878_item	3604214	et	4	main
jannseni	doc_366216787878_item	3604215	et	4	main
juhtimisel	doc_366216787878_item	3604216	et	4	main
sellest	doc_366216787878_item	3604217	et	4	main
sai	doc_366216787878_item	3604218	et	4	main
üks	doc_366216787878_item	3604219	et	3	main
tore	doc_366216787878_item	3604220	et	3	main
tava	doc_366216787878_item	3604221	et	4	main
maarahvas	doc_366216787878_item	3604067	et	4	main
olles	doc_366216787878_item	3604069	et	3	main
üksi	doc_366216787878_item	3604070	et	4	main
töötades	doc_366216787878_item	3604071	et	3	main
tähistades	doc_366216787878_item	3604075	et	3	main
keegi	doc_366216787878_item	3604077	et	4	main
surma	doc_366216787878_item	3604078	et	4	main
alati	doc_366216787878_item	3604090	et	4	main
omasid	doc_366216787878_item	3604091	et	4	main
ja	doc_366216787878_item	3604092	et	3	main
eesti	doc_366216787878_item	3604099	et	4	main
kohal	doc_366216787878_item	3604113	et	4	main
rahvalaulu	doc_366216787878_item	3604122	et	4	main
see	doc_366216787878_item	3604129	et	3	main
inimsaatuse	doc_366216787878_item	3604141	et	3	main
on	doc_366216787878_item	3604144	et	4	main
sotsiaalne	doc_366216787878_item	3604161	et	3	main
muusikat	doc_366216787878_item	3604164	et	3	main
rahva	doc_366216787878_item	3604202	et	3	main
kultuurinähtus	doc_366216787878_item	3604228	et	4	main
ja	doc_366216787878_item	3604229	et	3	main
sotsiaalne	doc_366216787878_item	3604230	et	3	main
pärinevad	doc_366216787878_item	3604236	et	4	main
eesmärgi	doc_366216787878_item	3604243	et	4	main
ka	doc_366216787878_item	3604254	et	3	main
teise	doc_366216787878_item	3604257	et	4	main
vältel	doc_366216787878_item	3604259	et	4	main
täna	doc_366216787878_item	3604263	et	4	main
eestis	doc_366216787878_item	3604264	et	3	main
vilgas	doc_366216787878_item	3604266	et	3	main
laul	doc_366216787878_item	3604268	et	4	main
aitab	doc_366216787878_item	3604269	et	3	main
elada	doc_366216787878_item	3604270	et	3	main
see	doc_366216787878_item	3604271	et	3	main
on	doc_366216787878_item	3604272	et	4	main
teebki	doc_366216787878_item	3604277	et	3	main
essee	doc_366216787882_item	3604281	et	4	main
keele	doc_366216787882_item	3604283	et	4	main
mis	doc_366216787882_item	3604292	et	4	main
teeb	doc_366216787882_item	3604293	et	3	main
essee	doc_366216787882_item	3604301	et	4	main
esitatud	doc_366216787882_item	3604312	et	4	main
meiega	doc_366216787882_item	3604322	et	4	main
terve	doc_366216787882_item	3604323	et	4	main
juba	doc_366216787882_item	3604331	et	3	main
ta	doc_366216787882_item	3604349	et	4	main
kukkus	doc_366216787882_item	3604350	et	3	main
abiga	doc_366216787882_item	3604353	et	3	main
ema	doc_366216787882_item	3604354	et	4	main
püüaks	doc_366216787882_item	3604355	et	3	main
ja	doc_366216787882_item	3604391	et	3	main
erinevaks	doc_366216787882_item	3604396	et	4	main
muusika	doc_366216787882_item	3604410	et	4	main
seisa	doc_366216787882_item	3604435	et	4	main
kohal	doc_366216787882_item	3604436	et	4	main
ja	doc_366216787882_item	3604437	et	3	main
koorilaulu	doc_366216787882_item	3604438	et	4	main
hakkas	doc_366216787882_item	3604439	et	3	main
kaasnema	doc_366216787882_item	3604440	et	3	main
mängiti	doc_366216787882_item	3604444	et	3	main
juurde	doc_366216787882_item	3604481	et	4	main
laulupidu	doc_366216787882_item	3604488	et	4	main
väga	doc_366216787882_item	3604490	et	3	main
kujunes	doc_366216787882_item	3604500	et	3	main
tartus	doc_366216787882_item	3604503	et	3	main
tuli	doc_366216787882_item	3604509	et	4	main
vanemuise	doc_366216787882_item	3604510	et	4	main
822	doc_366216787882_item	3604522	et	2	main
naiste	doc_366216787882_item	3604533	et	3	main
poissi	doc_366216787882_item	3604536	et	4	main
kooriga	doc_366216787882_item	3604537	et	4	main
peoorganiseerimine	doc_366216787882_item	3604539	et	3	main
on	doc_366216787882_item	3604540	et	4	main
ja	doc_366216787882_item	3604554	et	3	main
jutustada	doc_366216787882_item	3604555	et	3	main
et	doc_366216787882_item	3604562	et	3	main
teaksid	doc_366216787882_item	3604564	et	4	main
arenes	doc_366216787882_item	3604566	et	3	main
essee	doc_366216787884_item	3604619	et	4	main
laulurahva	doc_366216787884_item	3604633	et	3	main
analüüsiv	doc_366216787884_item	3604643	et	4	main
tantsuga	doc_366216787878_item	3604107	et	3	main
siin	doc_366216787878_item	3604109	et	4	main
seisab	doc_366216787878_item	3604110	et	3	main
iseäranis	doc_366216787878_item	3604111	et	3	main
tähtsal	doc_366216787878_item	3604112	et	3	main
uurimine	doc_366216787878_item	3604133	et	4	main
laulus	doc_366216787878_item	3604134	et	3	main
kajastub	doc_366216787878_item	3604135	et	3	main
rahva	doc_366216787878_item	3604136	et	3	main
iseloom	doc_366216787878_item	3604137	et	3	main
mõnikord	doc_366216787878_item	3604138	et	3	main
teemat	doc_366216787878_item	3604142	et	3	main
rahvusliku	doc_366216787878_item	3604167	et	3	main
laulu	doc_366216787878_item	3604168	et	4	main
põhitüüpi	doc_366216787878_item	3604169	et	4	main
1	doc_366216787878_item	3604170	et	2	main
eesti	doc_366216787878_item	3604171	et	4	main
vanema	doc_366216787878_item	3604172	et	4	main
laulutraditsioonid	doc_366216787878_item	3604173	et	3	main
on	doc_366216787878_item	3604174	et	4	main
seotud	doc_366216787878_item	3604175	et	4	main
läänemeresoome	doc_366216787878_item	3604176	et	3	main
kultuurile	doc_366216787878_item	3604177	et	3	main
omane	doc_366216787878_item	3604178	et	3	main
regivärsiline	doc_366216787878_item	3604179	et	4	main
rahvalaul	doc_366216787878_item	3604180	et	4	main
2	doc_366216787878_item	3604181	et	2	main
riimiline	doc_366216787878_item	3604182	et	4	main
rahvalaul	doc_366216787878_item	3604183	et	4	main
mis	doc_366216787878_item	3604184	et	4	main
on	doc_366216787878_item	3604185	et	4	main
rohkem	doc_366216787878_item	3604186	et	4	main
iseloomulik	doc_366216787878_item	3604187	et	3	main
euroopa	doc_366216787878_item	3604188	et	4	main
laulutraditsioonile	doc_366216787878_item	3604189	et	3	main
peamiselt	doc_366216787878_item	3604190	et	4	main
saksa	doc_366216787878_item	3604191	et	4	main
rootsi	doc_366216787878_item	3604192	et	4	main
soome	doc_366216787878_item	3604193	et	3	main
ja	doc_366216787878_item	3604194	et	3	main
slaavi	doc_366216787878_item	3604195	et	3	main
muusika	doc_366216787878_item	3604196	et	4	main
mõju	doc_366216787878_item	3604197	et	4	main
emotsionaalne	doc_366216787878_item	3604152	et	3	main
väljendusvahend	doc_366216787878_item	3604153	et	3	main
silmapaistvaks	doc_366216787878_item	3604199	et	3	main
laul	doc_366216787878_item	3604225	et	4	main
kui	doc_366216787878_item	3604226	et	3	main
tähelepanuväärne	doc_366216787878_item	3604227	et	3	main
mis	doc_366216787878_item	3604235	et	4	main
rakendatud	doc_366216787878_item	3604241	et	4	main
kindla	doc_366216787878_item	3604242	et	3	main
nii	doc_366216787878_item	3604255	et	3	main
eestlaste	doc_366216787878_item	3604273	et	4	main
elu	doc_366216787878_item	3604274	et	4	main
osa	doc_366216787878_item	3604275	et	4	main
laulurahva	doc_366216787878_item	3604279	et	3	main
eesti	doc_366216787882_item	3604282	et	4	main
kui	doc_366216787882_item	3604284	et	3	main
teise	doc_366216787882_item	3604285	et	4	main
eestlastest	doc_366216787882_item	3604294	et	4	main
laulurahva	doc_366216787882_item	3604295	et	3	main
sõna	doc_366216787882_item	3604300	et	4	main
väiteid	doc_366216787882_item	3604314	et	4	main
koos	doc_366216787882_item	3604321	et	4	main
siis	doc_366216787882_item	3604328	et	3	main
lõppuni	doc_366216787882_item	3604330	et	3	main
muusika	doc_366216787882_item	3604334	et	4	main
emal	doc_366216787882_item	3604336	et	3	main
oma	doc_366216787882_item	3604338	et	4	main
last	doc_366216787882_item	3604339	et	4	main
ta	doc_366216787882_item	3604341	et	4	main
tahtnud	doc_366216787882_item	3604343	et	4	main
aga	doc_366216787882_item	3604351	et	3	main
laulu	doc_366216787882_item	3604352	et	4	main
praegu	doc_366216787882_item	3604392	et	3	main
meie	doc_366216787882_item	3604394	et	4	main
paremini	doc_366216787882_item	3604398	et	4	main
muusika	doc_366216787882_item	3604401	et	4	main
rahulikuks	doc_366216787882_item	3604404	et	3	main
selle	doc_366216787882_item	3604415	et	4	main
puhkpilliorkester	doc_366216787882_item	3604442	et	3	main
vaimulikut	doc_366216787882_item	3604445	et	4	main
muusikat	doc_366216787882_item	3604446	et	3	main
kuid	doc_366216787882_item	3604447	et	4	main
vaadata	doc_366216787882_item	3604483	et	4	main
muusikat	doc_366216787882_item	3604486	et	3	main
on	doc_366216787882_item	3604489	et	4	main
ülemaailne	doc_366216787882_item	3604498	et	4	main
laulupidu	doc_366216787882_item	3604499	et	4	main
1868	doc_366216787882_item	3604501	et	2	main
mille	doc_366216787882_item	3604504	et	3	main
sel	doc_366216787882_item	3604514	et	3	main
peol	doc_366216787882_item	3604516	et	4	main
osales	doc_366216787882_item	3604517	et	3	main
palju	doc_366216787882_item	3604518	et	4	main
5	doc_366216787882_item	3604525	et	2	main
56	doc_366216787882_item	3604527	et	2	main
praegu	doc_366216787882_item	3604529	et	3	main
meie	doc_366216787882_item	3604541	et	4	main
kaasaegsel	doc_366216787882_item	3604542	et	3	main
ajal	doc_366216787882_item	3604543	et	4	main
vana	doc_366216787882_item	3604551	et	4	main
traditsiooni	doc_366216787882_item	3604552	et	4	main
oma	doc_366216787882_item	3604556	et	4	main
lapsele	doc_366216787882_item	3604557	et	4	main
eesti	doc_366216787884_item	3604620	et	4	main
test	doc_366216787884_item	3604625	et	3	main
mis	doc_366216787884_item	3604630	et	4	main
teeb	doc_366216787884_item	3604631	et	3	main
300	doc_366216787884_item	3604636	et	2	main
essee	doc_366216787884_item	3604639	et	4	main
olema	doc_366216787884_item	3604641	et	4	main
tuginema	doc_366216787884_item	3604646	et	3	main
on	doc_366216787884_item	3604658	et	4	main
emotsionaalne	doc_366216787884_item	3604661	et	3	main
sotsiaalne	doc_366216787884_item	3604664	et	3	main
tutvume	doc_366216787884_item	3604668	et	3	main
eeslaulja	doc_366216787884_item	3604679	et	4	main
kes	doc_366216787884_item	3604680	et	4	main
viib	doc_366216787884_item	3604681	et	3	main
laulu	doc_366216787884_item	3604682	et	4	main
ja	doc_366216787884_item	3604684	et	3	main
eeslaulja	doc_366216787884_item	3604688	et	4	main
üheks	doc_366216787878_item	3604198	et	3	main
eesti	doc_366216787878_item	3604201	et	4	main
ajaloos	doc_366216787878_item	3604203	et	4	main
regulaarselt	doc_366216787878_item	3604224	et	4	main
rahvalaul	doc_366216787878_item	3604260	et	4	main
ka	doc_366216787878_item	3604262	et	3	main
kirjutamine	doc_366216787882_item	3604288	et	4	main
kirjutage	doc_366216787882_item	3604289	et	3	main
essee	doc_366216787882_item	3604290	et	4	main
teemal	doc_366216787882_item	3604291	et	3	main
350	doc_366216787882_item	3604299	et	2	main
arutlev	doc_366216787882_item	3604304	et	4	main
ja	doc_366216787882_item	3604327	et	3	main
laulis	doc_366216787882_item	3604346	et	4	main
või	doc_366216787882_item	3604381	et	4	main
tegevus	doc_366216787878_item	3604231	et	4	main
folkloorist	doc_366216787878_item	3604237	et	4	main
ning	doc_366216787878_item	3604238	et	3	main
mida	doc_366216787878_item	3604239	et	4	main
oli	doc_366216787878_item	3604253	et	3	main
elab	doc_366216787878_item	3604261	et	3	main
eestlastest	doc_366216787878_item	3604278	et	4	main
tal	doc_366216787882_item	3604608	et	3	main
oli	doc_366216787882_item	3604609	et	3	main
sest	doc_366216787882_item	3604610	et	4	main
kõik	doc_366216787882_item	3604611	et	4	main
uus	doc_366216787882_item	3604612	et	3	main
see	doc_366216787882_item	3604613	et	3	main
on	doc_366216787882_item	3604614	et	4	main
kõik	doc_366216787882_item	3604615	et	4	main
unustatud	doc_366216787882_item	3604616	et	4	main
vana	doc_366216787882_item	3604617	et	4	main
test	doc_366216787882_item	3604287	et	3	main
pikkus	doc_366216787882_item	3604297	et	4	main
300	doc_366216787882_item	3604298	et	2	main
faktidele	doc_366216787882_item	3604313	et	3	main
on	doc_366216787882_item	3604315	et	4	main
soovitatav	doc_366216787882_item	3604316	et	4	main
illustreerida	doc_366216787882_item	3604317	et	3	main
elu	doc_366216787882_item	3604324	et	4	main
alates	doc_366216787882_item	3604325	et	3	main
sündimusest	doc_366216787882_item	3604326	et	4	main
elu	doc_366216787882_item	3604329	et	4	main
vanal	doc_366216787882_item	3604332	et	3	main
aitas	doc_366216787882_item	3604335	et	3	main
kiigutada	doc_366216787882_item	3604337	et	3	main
kui	doc_366216787882_item	3604340	et	3	main
talle	doc_366216787882_item	3604347	et	4	main
kui	doc_366216787882_item	3604348	et	3	main
last	doc_366216787882_item	3604356	et	4	main
rahuneda	doc_366216787882_item	3604357	et	3	main
mõnedele	doc_366216787882_item	3604358	et	3	main
lastele	doc_366216787882_item	3604359	et	4	main
meeldib	doc_366216787882_item	3604360	et	3	main
kui	doc_366216787882_item	3604361	et	3	main
ema	doc_366216787882_item	3604362	et	4	main
laulab	doc_366216787882_item	3604363	et	3	main
ehki	doc_366216787882_item	3604364	et	4	main
ta	doc_366216787882_item	3604365	et	4	main
on	doc_366216787882_item	3604366	et	4	main
juba	doc_366216787882_item	3604367	et	3	main
sai	doc_366216787882_item	3604368	et	4	main
natuke	doc_366216787882_item	3604369	et	4	main
suureks	doc_366216787882_item	3604370	et	4	main
sel	doc_366216787882_item	3604371	et	3	main
ajal	doc_366216787882_item	3604372	et	4	main
laulasid	doc_366216787882_item	3604373	et	4	main
peaaegu	doc_366216787882_item	3604374	et	3	main
kõik	doc_366216787882_item	3604375	et	4	main
ja	doc_366216787882_item	3604376	et	3	main
kõikidel	doc_366216787882_item	3604377	et	4	main
käimas	doc_366216787882_item	3604378	et	4	main
metsa	doc_366216787882_item	3604379	et	4	main
jalutades	doc_366216787882_item	3604380	et	3	main
põllul	doc_366216787882_item	3604383	et	3	main
toimetusel	doc_366216787882_item	3604385	et	4	main
lapse	doc_366216787882_item	3604387	et	4	main
sündmusel	doc_366216787882_item	3604388	et	3	main
elu	doc_366216787882_item	3604395	et	4	main
tundma	doc_366216787882_item	3604399	et	3	main
näiteks	doc_366216787882_item	3604405	et	4	main
kus	doc_366216787882_item	3604406	et	3	main
enne	doc_366216787882_item	3604407	et	4	main
kirikus	doc_366216787882_item	3604413	et	3	main
meeste	doc_366216787882_item	3604416	et	4	main
laulsid	doc_366216787882_item	3604430	et	4	main
ka	doc_366216787882_item	3604441	et	3	main
esialgu	doc_366216787882_item	3604443	et	3	main
ja	doc_366216787882_item	3604484	et	3	main
tuginema	doc_366216787882_item	3604308	et	3	main
loengus	doc_366216787882_item	3604309	et	3	main
ja	doc_366216787882_item	3604310	et	3	main
lugemistekstis	doc_366216787882_item	3604311	et	3	main
näidetega	doc_366216787882_item	3604318	et	3	main
muusika	doc_366216787882_item	3604319	et	4	main
sammub	doc_366216787882_item	3604320	et	3	main
ajal	doc_366216787882_item	3604333	et	4	main
ei	doc_366216787882_item	3604342	et	4	main
magada	doc_366216787882_item	3604344	et	3	main
või	doc_366216787882_item	3604345	et	4	main
töötades	doc_366216787882_item	3604382	et	3	main
muusika	doc_366216787882_item	3604389	et	4	main
veel	doc_366216787882_item	3604408	et	4	main
oli	doc_366216787882_item	3604409	et	3	main
esindas	doc_366216787882_item	3604414	et	3	main
koor	doc_366216787882_item	3604417	et	4	main
pärast	doc_366216787882_item	3604418	et	4	main
ka	doc_366216787882_item	3604419	et	3	main
väljaspool	doc_366216787882_item	3604420	et	3	main
kirikut	doc_366216787882_item	3604421	et	3	main
pärast	doc_366216787882_item	3604422	et	4	main
hakati	doc_366216787882_item	3604423	et	3	main
õpilasi	doc_366216787882_item	3604424	et	3	main
õpetama	doc_366216787882_item	3604425	et	3	main
külakoolides	doc_366216787882_item	3604426	et	3	main
kus	doc_366216787882_item	3604427	et	3	main
noored	doc_366216787882_item	3604428	et	3	main
koorilaulu	doc_366216787882_item	3604431	et	4	main
kuid	doc_366216787882_item	3604432	et	4	main
aeg	doc_366216787882_item	3604433	et	3	main
ei	doc_366216787882_item	3604434	et	4	main
kuulata	doc_366216787882_item	3604485	et	4	main
see	doc_366216787882_item	3604487	et	3	main
tähtis	doc_366216787882_item	3604491	et	4	main
eestimaa	doc_366216787882_item	3604492	et	4	main
aastal	doc_366216787882_item	3604502	et	3	main
korraldamise	doc_366216787882_item	3604505	et	4	main
idee	doc_366216787882_item	3604506	et	4	main
ja	doc_366216787882_item	3604507	et	3	main
seltsist	doc_366216787882_item	3604511	et	4	main
lauljaga	doc_366216787882_item	3604523	et	4	main
ja	doc_366216787882_item	3604524	et	3	main
puhkpilliorkestrit	doc_366216787882_item	3604526	et	3	main
mängijaga	doc_366216787882_item	3604528	et	4	main
nautida	doc_366216787882_item	3604532	et	3	main
laste	doc_366216787882_item	3604534	et	4	main
niisuguste	doc_366216787882_item	3604538	et	3	main
tähtis	doc_366216787882_item	3604545	et	4	main
sest	doc_366216787882_item	3604546	et	4	main
meie	doc_366216787882_item	3604547	et	4	main
edastada	doc_366216787882_item	3604550	et	3	main
kui	doc_366216787884_item	3604622	et	3	main
keele	doc_366216787884_item	3604624	et	4	main
kirjutamine	doc_366216787884_item	3604626	et	4	main
kirjutage	doc_366216787884_item	3604627	et	3	main
essee	doc_366216787884_item	3604628	et	4	main
teemal	doc_366216787884_item	3604629	et	3	main
pikkus	doc_366216787884_item	3604635	et	4	main
arutlev	doc_366216787884_item	3604642	et	4	main
väiteid	doc_366216787884_item	3604652	et	4	main
ka	doc_366216787884_item	3604666	et	3	main
ajalooga	doc_366216787884_item	3604670	et	4	main
koor	doc_366216787884_item	3604685	et	4	main
kordab	doc_366216787884_item	3604687	et	3	main
kirik	doc_366216787884_item	3604695	et	3	main
õpetasid	doc_366216787884_item	3604698	et	4	main
saksa	doc_366216787884_item	3604699	et	4	main
vanema	doc_366216787884_item	3604704	et	4	main
rootsi	doc_366216787884_item	3604709	et	4	main
muusikat	doc_366216787884_item	3604713	et	3	main
salmialbumid	doc_366216787884_item	3604721	et	3	main
trükitult	doc_366216787884_item	3604723	et	4	main
sageli	doc_366216787884_item	3604724	et	3	main
on	doc_366216787884_item	3604725	et	4	main
rahvuslik	doc_366216787884_item	3604726	et	3	main
identiteeditunne	doc_366216787884_item	3604727	et	3	main
ja	doc_366216787884_item	3604728	et	3	main
kultuur	doc_366216787884_item	3604729	et	3	main
rakendatud	doc_366216787884_item	3604739	et	4	main
eesmärgi	doc_366216787884_item	3604741	et	4	main
pulma	doc_366216787882_item	3604384	et	4	main
ja	doc_366216787882_item	3604386	et	3	main
tegi	doc_366216787882_item	3604390	et	4	main
teeb	doc_366216787882_item	3604393	et	3	main
aitab	doc_366216787882_item	3604397	et	3	main
rahva	doc_366216787882_item	3604400	et	3	main
teeb	doc_366216787882_item	3604402	et	3	main
inimest	doc_366216787882_item	3604403	et	3	main
levinud	doc_366216787882_item	3604411	et	4	main
muidugi	doc_366216787882_item	3604412	et	4	main
poisid	doc_366216787882_item	3604429	et	4	main
hiljem	doc_366216787882_item	3604448	et	3	main
hakati	doc_366216787882_item	3604449	et	3	main
muusitseerima	doc_366216787882_item	3604450	et	4	main
piduõhtutel	doc_366216787882_item	3604451	et	3	main
ka	doc_366216787882_item	3604452	et	3	main
tantsu	doc_366216787882_item	3604453	et	4	main
saateks	doc_366216787882_item	3604454	et	3	main
praegu	doc_366216787882_item	3604455	et	3	main
on	doc_366216787882_item	3604456	et	4	main
ka	doc_366216787882_item	3604457	et	3	main
toimuvad	doc_366216787882_item	3604458	et	4	main
rahvamuusika	doc_366216787882_item	3604459	et	4	main
kontserdid	doc_366216787882_item	3604460	et	3	main
estonia	doc_366216787882_item	3604461	et	4	main
teatris	doc_366216787882_item	3604462	et	3	main
ja	doc_366216787882_item	3604463	et	3	main
suvel	doc_366216787882_item	3604464	et	3	main
birgitta	doc_366216787882_item	3604465	et	4	main
brigitta	doc_366216787882_item	3604466	et	4	main
kirikus	doc_366216787882_item	3604467	et	3	main
kuid	doc_366216787882_item	3604468	et	4	main
kõige	doc_366216787882_item	3604469	et	4	main
tähtsam	doc_366216787882_item	3604470	et	4	main
on	doc_366216787882_item	3604471	et	4	main
laulupidu	doc_366216787882_item	3604472	et	4	main
lauluväljakul	doc_366216787882_item	3604473	et	3	main
ajal	doc_366216787882_item	3604475	et	4	main
sellel	doc_366216787882_item	3604474	et	4	main
sõidavad	doc_366216787882_item	3604476	et	3	main
kõikidest	doc_366216787882_item	3604477	et	4	main
riikidest	doc_366216787882_item	3604478	et	3	main
külastajad	doc_366216787882_item	3604479	et	4	main
meie	doc_366216787882_item	3604480	et	4	main
et	doc_366216787882_item	3604482	et	3	main
jaoks	doc_366216787882_item	3604493	et	4	main
teostus	doc_366216787882_item	3604508	et	4	main
johann	doc_366216787882_item	3604512	et	4	main
meeskoori	doc_366216787882_item	3604521	et	4	main
me	doc_366216787882_item	3604530	et	4	main
ja	doc_366216787882_item	3604535	et	3	main
ülesanne	doc_366216787882_item	3604548	et	4	main
eesti	doc_366216787882_item	3604558	et	4	main
kommetest	doc_366216787882_item	3604559	et	4	main
ja	doc_366216787882_item	3604560	et	3	main
traditsioonidest	doc_366216787882_item	3604561	et	3	main
kuidas	doc_366216787882_item	3604565	et	3	main
muusika	doc_366216787882_item	3604567	et	4	main
et	doc_366216787882_item	3604568	et	3	main
nad	doc_366216787882_item	3604569	et	3	main
ei	doc_366216787882_item	3604570	et	4	main
kuulnudki	doc_366216787882_item	3604571	et	4	main
ainult	doc_366216787882_item	3604572	et	4	main
metall	doc_366216787882_item	3604573	et	3	main
pop	doc_366216787882_item	3604574	et	4	main
rock	doc_366216787882_item	3604575	et	4	main
ja	doc_366216787882_item	3604576	et	3	main
hiphopp	doc_366216787882_item	3604577	et	4	main
muusikat	doc_366216787882_item	3604578	et	3	main
on	doc_366216787882_item	3604579	et	4	main
vaga	doc_366216787882_item	3604580	et	4	main
keele	doc_366216787884_item	3604621	et	4	main
eestlastest	doc_366216787884_item	3604632	et	4	main
350	doc_366216787884_item	3604637	et	2	main
peab	doc_366216787884_item	3604640	et	4	main
üldistav	doc_366216787884_item	3604645	et	4	main
loengus	doc_366216787884_item	3604647	et	3	main
ja	doc_366216787884_item	3604648	et	3	main
lugemistekstis	doc_366216787884_item	3604649	et	3	main
esitatud	doc_366216787884_item	3604650	et	4	main
faktidele	doc_366216787884_item	3604651	et	3	main
illustreerida	doc_366216787884_item	3604655	et	3	main
laulmine	doc_366216787884_item	3604657	et	4	main
esteetiline	doc_366216787884_item	3604659	et	3	main
ja	doc_366216787884_item	3604663	et	3	main
rahvalauluga	doc_366216787884_item	3604667	et	4	main
esitavad	doc_366216787884_item	3604678	et	4	main
andes	doc_366216787884_item	3604691	et	4	main
sellega	doc_366216787884_item	3604692	et	3	main
eeskuju	doc_366216787884_item	3604700	et	4	main
euroopast	doc_366216787884_item	3604706	et	3	main
soome	doc_366216787884_item	3604710	et	3	main
slaavi	doc_366216787884_item	3604712	et	3	main
uuemat	doc_366216787884_item	3604714	et	4	main
laululehed	doc_366216787884_item	3604719	et	3	main
mis	doc_366216787884_item	3604732	et	4	main
mida	doc_366216787884_item	3604737	et	4	main
on	doc_366216787884_item	3604738	et	4	main
tartus	doc_366216787884_item	3604745	et	3	main
osales	doc_366216787884_item	3604750	et	3	main
5	doc_366216787884_item	3604754	et	2	main
jätnud	doc_366216787884_item	3604761	et	4	main
valitsenud	doc_366216787884_item	3604762	et	4	main
ja	doc_366216787884_item	3604773	et	3	main
kadriorus	doc_366216787884_item	3604775	et	3	main
koorilaul	doc_366216787884_item	3604777	et	4	main
eestlaste	doc_366216787884_item	3604779	et	4	main
seepärast	doc_366216787884_item	3604783	et	3	main
loomulik	doc_366216787884_item	3604785	et	3	main
aga	doc_366216787882_item	3604494	et	3	main
esimene	doc_366216787882_item	3604495	et	3	main
nii	doc_366216787882_item	3604496	et	3	main
suur	doc_366216787882_item	3604497	et	3	main
jannsen	doc_366216787882_item	3604513	et	4	main
ajal	doc_366216787882_item	3604515	et	4	main
inimesi	doc_366216787882_item	3604519	et	4	main
46	doc_366216787882_item	3604520	et	2	main
saame	doc_366216787882_item	3604531	et	4	main
väga	doc_366216787882_item	3604544	et	3	main
on	doc_366216787882_item	3604549	et	4	main
näidata	doc_366216787882_item	3604553	et	4	main
nad	doc_366216787882_item	3604563	et	3	main
oluline	doc_366216787882_item	3604581	et	4	main
see	doc_366216787882_item	3604582	et	3	main
et	doc_366216787882_item	3604583	et	3	main
nad	doc_366216787882_item	3604584	et	3	main
oskasid	doc_366216787882_item	3604585	et	4	main
head	doc_366216787882_item	3604586	et	4	main
vana	doc_366216787882_item	3604587	et	4	main
ja	doc_366216787882_item	3604588	et	3	main
meeldivat	doc_366216787882_item	3604589	et	4	main
muusikat	doc_366216787882_item	3604590	et	3	main
folkloori	doc_366216787882_item	3604591	et	4	main
ja	doc_366216787882_item	3604592	et	3	main
nje	doc_366216787882_item	3604593	et	4	main
muusika	doc_366216787882_item	3604594	et	4	main
peab	doc_366216787882_item	3604595	et	4	main
aitama	doc_366216787882_item	3604596	et	3	main
neile	doc_366216787882_item	3604597	et	4	main
arusaada	doc_366216787882_item	3604598	et	4	main
kuidas	doc_366216787882_item	3604599	et	3	main
elas	doc_366216787882_item	3604600	et	3	main
eesti	doc_366216787882_item	3604601	et	4	main
rahvas	doc_366216787882_item	3604602	et	4	main
millega	doc_366216787882_item	3604603	et	3	main
tegeles	doc_366216787882_item	3604604	et	3	main
ja	doc_366216787882_item	3604605	et	3	main
milleseid	doc_366216787882_item	3604606	et	4	main
kombeid	doc_366216787882_item	3604607	et	4	main
riikides	doc_366216787884_item	3604829	et	3	main
on	doc_366216787884_item	3604831	et	4	main
väga	doc_366216787884_item	3604832	et	3	main
populaarne	doc_366216787884_item	3604833	et	3	main
ja	doc_366216787884_item	3604830	et	3	main
laulja	doc_366216787884_item	3604834	et	4	main
teise	doc_366216787884_item	3604623	et	4	main
essee	doc_366216787884_item	3604634	et	4	main
sõna	doc_366216787884_item	3604638	et	4	main
ja	doc_366216787884_item	3604644	et	3	main
on	doc_366216787884_item	3604653	et	4	main
näidetega	doc_366216787884_item	3604656	et	3	main
ja	doc_366216787884_item	3604660	et	3	main
väljendusvahend	doc_366216787884_item	3604662	et	3	main
läänemeresoome	doc_366216787884_item	3604674	et	3	main
kultuurile	doc_366216787884_item	3604675	et	3	main
iseloomulik	doc_366216787884_item	3604676	et	3	main
regilaulu	doc_366216787884_item	3604677	et	4	main
edasi	doc_366216787884_item	3604683	et	3	main
kes	doc_366216787884_item	3604686	et	4	main
mõtteaega	doc_366216787884_item	3604694	et	4	main
ja	doc_366216787884_item	3604696	et	3	main
ja	doc_366216787884_item	3604705	et	3	main
laenatud	doc_366216787884_item	3604707	et	4	main
rahvalaulu	doc_366216787884_item	3604715	et	4	main
iseloomustab	doc_366216787884_item	3604716	et	4	main
kirjalik	doc_366216787884_item	3604717	et	3	main
ülestähendus	doc_366216787884_item	3604718	et	3	main
ja	doc_366216787884_item	3604720	et	3	main
sümbolitele	doc_366216787884_item	3604731	et	3	main
peol	doc_366216787884_item	3604749	et	4	main
meeskoori	doc_366216787884_item	3604752	et	4	main
loomist	doc_366216787884_item	3604768	et	4	main
suurüritusteks	doc_366216787884_item	3604772	et	3	main
lauluväljakul	doc_366216787884_item	3604776	et	3	main
on	doc_366216787884_item	3604784	et	4	main
et	doc_366216787884_item	3604786	et	3	main
jaoks	doc_366216787884_item	3604789	et	4	main
seostub	doc_366216787884_item	3604790	et	3	main
sõnadega	doc_366216787884_item	3604791	et	3	main
teise	doc_366216787886_item	3604840	et	4	main
test	doc_366216787886_item	3604842	et	3	main
kirjutage	doc_366216787886_item	3604844	et	3	main
sõna	doc_366216787886_item	3604855	et	4	main
olema	doc_366216787886_item	3604858	et	4	main
üldistav	doc_366216787886_item	3604862	et	4	main
lugemistekstis	doc_366216787886_item	3604866	et	3	main
väiteid	doc_366216787886_item	3604869	et	4	main
et	doc_366216787886_item	3604876	et	3	main
rahvas	doc_366216787886_item	3604886	et	4	main
ajal	doc_366216787886_item	3604913	et	4	main
oli	doc_366216787886_item	3604917	et	3	main
laulmine	doc_366216787886_item	3604937	et	4	main
protest	doc_366216787886_item	3604941	et	3	main
laulsid	doc_366216787886_item	3604945	et	4	main
ajal	doc_366216787886_item	3604951	et	4	main
nad	doc_366216787886_item	3604964	et	3	main
ajaloos	doc_366216787886_item	3604981	et	4	main
sündmus	doc_366216787886_item	3604983	et	3	main
et	doc_366216787886_item	3604997	et	3	main
on	doc_366216787886_item	3605028	et	4	main
veres	doc_366216787886_item	3605033	et	3	main
essee	doc_366216787889_item	3605035	et	4	main
kirjutage	doc_366216787889_item	3605043	et	3	main
teemal	doc_366216787889_item	3605045	et	3	main
essee	doc_366216787889_item	3605055	et	4	main
lugemistekstis	doc_366216787889_item	3605065	et	3	main
emotsionaalne	doc_366216787889_item	3605078	et	3	main
laul	doc_366216787889_item	3605085	et	4	main
eestlast	doc_366216787889_item	3605086	et	4	main
kui	doc_366216787889_item	3605087	et	3	main
olles	doc_366216787889_item	3605088	et	3	main
töödes	doc_366216787889_item	3605089	et	3	main
aga	doc_366216787889_item	3605097	et	3	main
olid	doc_366216787889_item	3605105	et	4	main
mingi	doc_366216787889_item	3605106	et	4	main
pidud	doc_366216787889_item	3605107	et	3	main
teise	doc_366216787892_item	3605127	et	4	main
300	doc_366216787892_item	3605140	et	2	main
olema	doc_366216787892_item	3605145	et	4	main
esitatud	doc_366216787892_item	3605154	et	4	main
ajal	doc_366216787892_item	3605162	et	4	main
1896	doc_366216787892_item	3605172	et	2	main
soovitatav	doc_366216787884_item	3604654	et	4	main
tegevus	doc_366216787884_item	3604665	et	4	main
pisut	doc_366216787884_item	3604669	et	3	main
eesti	doc_366216787884_item	3604671	et	4	main
laulutraditsiooni	doc_366216787884_item	3604672	et	4	main
esindab	doc_366216787884_item	3604673	et	3	main
talle	doc_366216787884_item	3604693	et	4	main
järgivat	doc_366216787884_item	3604701	et	4	main
mitmehäälset	doc_366216787884_item	3604702	et	3	main
saaksa	doc_366216787884_item	3604708	et	4	main
ja	doc_366216787884_item	3604711	et	3	main
levisid	doc_366216787884_item	3604722	et	4	main
algselt	doc_366216787884_item	3604733	et	4	main
folkloorist	doc_366216787884_item	3604735	et	4	main
puhkpilliorkestrit	doc_366216787884_item	3604755	et	3	main
toimumisse	doc_366216787884_item	3604757	et	4	main
on	doc_366216787884_item	3604758	et	4	main
poliitilised	doc_366216787884_item	3604763	et	3	main
olnud	doc_366216787884_item	3604764	et	4	main
muutusid	doc_366216787884_item	3604769	et	4	main
laulupeod	doc_366216787884_item	3604770	et	4	main
kujunenud	doc_366216787884_item	3604781	et	4	main
massiharrastuseks	doc_366216787884_item	3604782	et	3	main
laul	doc_366216787884_item	3604794	et	4	main
kui	doc_366216787886_item	3604839	et	3	main
peab	doc_366216787886_item	3604857	et	4	main
ja	doc_366216787886_item	3604861	et	3	main
tuginema	doc_366216787886_item	3604863	et	3	main
alustame	doc_366216787886_item	3604874	et	3	main
laulurahvas	doc_366216787886_item	3604883	et	4	main
see	doc_366216787886_item	3604884	et	3	main
väga	doc_366216787886_item	3604890	et	3	main
oluline	doc_366216787886_item	3604891	et	4	main
eesti	doc_366216787886_item	3604892	et	4	main
olnud	doc_366216787886_item	3604895	et	4	main
aeg	doc_366216787886_item	3604897	et	3	main
tegevus	doc_366216787886_item	3604901	et	4	main
eestlased	doc_366216787886_item	3604902	et	3	main
lauluvad	doc_366216787886_item	3604903	et	4	main
juba	doc_366216787886_item	3604904	et	3	main
peo	doc_366216787886_item	3604912	et	4	main
millal	doc_366216787886_item	3604915	et	3	main
poliitiline	doc_366216787886_item	3604940	et	3	main
lauludes	doc_366216787886_item	3604943	et	3	main
venemaa	doc_366216787886_item	3604949	et	4	main
kõigile	doc_366216787886_item	3604957	et	4	main
öelda	doc_366216787886_item	3604958	et	4	main
oma	doc_366216787886_item	3604962	et	4	main
linnas	doc_366216787886_item	3604988	et	4	main
tartus	doc_366216787886_item	3604989	et	3	main
ja	doc_366216787886_item	3604990	et	3	main
on	doc_366216787886_item	3604999	et	4	main
euroopas	doc_366216787886_item	3605002	et	3	main
teavad	doc_366216787886_item	3605003	et	3	main
ja	doc_366216787886_item	3605021	et	3	main
keele	doc_366216787889_item	3605037	et	4	main
essee	doc_366216787889_item	3605044	et	4	main
mis	doc_366216787889_item	3605046	et	4	main
sõna	doc_366216787889_item	3605054	et	4	main
ja	doc_366216787889_item	3605060	et	3	main
üldistav	doc_366216787889_item	3605061	et	4	main
ja	doc_366216787889_item	3605064	et	3	main
esitatud	doc_366216787889_item	3605066	et	4	main
faktidele	doc_366216787889_item	3605067	et	3	main
väiteid	doc_366216787889_item	3605068	et	4	main
on	doc_366216787889_item	3605069	et	4	main
on	doc_366216787889_item	3605077	et	4	main
vanal	doc_366216787889_item	3605082	et	3	main
saatis	doc_366216787889_item	3605084	et	3	main
laulsid	doc_366216787889_item	3605094	et	4	main
kodus	doc_366216787889_item	3605096	et	4	main
kasvasid	doc_366216787889_item	3605101	et	4	main
kui	doc_366216787892_item	3605126	et	3	main
essee	doc_366216787892_item	3605132	et	4	main
pikkus	doc_366216787892_item	3605139	et	4	main
350	doc_366216787892_item	3605141	et	2	main
sõna	doc_366216787892_item	3605142	et	4	main
arutlev	doc_366216787892_item	3605146	et	4	main
soovitatav	doc_366216787892_item	3605158	et	4	main
illustreerida	doc_366216787892_item	3605159	et	3	main
tegemist	doc_366216787892_item	3605169	et	4	main
esitatud	doc_366216787884_item	3604689	et	4	main
värsse	doc_366216787884_item	3604690	et	3	main
külakoolid	doc_366216787884_item	3604697	et	3	main
koorilaulu	doc_366216787884_item	3604703	et	4	main
rajatud	doc_366216787884_item	3604730	et	4	main
pärinevad	doc_366216787884_item	3604734	et	4	main
ning	doc_366216787884_item	3604736	et	3	main
kindla	doc_366216787884_item	3604740	et	3	main
saavutamiseks	doc_366216787884_item	3604742	et	4	main
aastal	doc_366216787884_item	3604744	et	3	main
ülemaaline	doc_366216787884_item	3604747	et	4	main
laulupidu	doc_366216787884_item	3604748	et	4	main
pärast	doc_366216787884_item	3604765	et	4	main
toimub	doc_366216787884_item	3604774	et	3	main
on	doc_366216787884_item	3604778	et	4	main
hulgas	doc_366216787884_item	3604780	et	4	main
tavalise	doc_366216787884_item	3604787	et	4	main
kohe	doc_366216787884_item	3604795	et	4	main
ka	doc_366216787884_item	3604796	et	3	main
laulupidu	doc_366216787884_item	3604797	et	4	main
tänäsepäevani	doc_366216787884_item	3604798	et	4	main
vaatame	doc_366216787884_item	3604799	et	3	main
filme	doc_366216787884_item	3604800	et	3	main
ja	doc_366216787884_item	3604801	et	3	main
vanad	doc_366216787884_item	3604802	et	3	main
saateid	doc_366216787884_item	3604803	et	3	main
georg	doc_366216787884_item	3604804	et	4	main
otsaga	doc_366216787884_item	3604805	et	3	main
näiteks	doc_366216787884_item	3604806	et	4	main
mister	doc_366216787884_item	3604807	et	3	main
x	doc_366216787884_item	3604808	et	4	main
60	doc_366216787884_item	3604809	et	2	main
70	doc_366216787884_item	3604810	et	2	main
aastatel	doc_366216787884_item	3604811	et	4	main
ta	doc_366216787884_item	3604812	et	4	main
tegeles	doc_366216787884_item	3604813	et	3	main
lastekooridega	doc_366216787884_item	3604814	et	3	main
kõik	doc_366216787884_item	3604815	et	4	main
uue	doc_366216787884_item	3604816	et	3	main
armastame	doc_366216787884_item	3604817	et	3	main
meie	doc_366216787884_item	3604818	et	4	main
essee	doc_366216787886_item	3604836	et	4	main
eestlastest	doc_366216787886_item	3604849	et	4	main
analüüsiv	doc_366216787886_item	3604860	et	4	main
loengus	doc_366216787886_item	3604864	et	3	main
esitatud	doc_366216787886_item	3604867	et	4	main
sellest	doc_366216787886_item	3604875	et	4	main
kes	doc_366216787886_item	3604880	et	4	main
on	doc_366216787886_item	3604889	et	4	main
on	doc_366216787886_item	3604894	et	4	main
ja	doc_366216787886_item	3604899	et	3	main
töö	doc_366216787886_item	3604910	et	4	main
ja	doc_366216787886_item	3604911	et	3	main
laulsid	doc_366216787886_item	3604914	et	4	main
peres	doc_366216787886_item	3604916	et	3	main
ka	doc_366216787886_item	3604939	et	3	main
mõttedest	doc_366216787886_item	3604948	et	4	main
tahtsid	doc_366216787886_item	3604956	et	4	main
et	doc_366216787886_item	3604961	et	3	main
tallinnas	doc_366216787886_item	3604978	et	4	main
tallinnas	doc_366216787886_item	3604991	et	4	main
1869	doc_366216787884_item	3604743	et	2	main
kujunes	doc_366216787884_item	3604746	et	3	main
46	doc_366216787884_item	3604751	et	2	main
ja	doc_366216787884_item	3604753	et	3	main
laulupidude	doc_366216787884_item	3604756	et	4	main
alati	doc_366216787884_item	3604759	et	4	main
jälje	doc_366216787884_item	3604760	et	3	main
eesti	doc_366216787884_item	3604766	et	4	main
vabariigi	doc_366216787884_item	3604767	et	3	main
muusika	doc_366216787884_item	3604771	et	4	main
eestlase	doc_366216787884_item	3604788	et	3	main
rahvas	doc_366216787884_item	3604792	et	4	main
ja	doc_366216787884_item	3604793	et	3	main
noorused	doc_366216787884_item	3604819	et	4	main
laulud	doc_366216787884_item	3604820	et	3	main
ivo	doc_366216787884_item	3604821	et	4	main
linnaga	doc_366216787884_item	3604822	et	3	main
tänase	doc_366216787884_item	3604823	et	3	main
päevani	doc_366216787884_item	3604824	et	3	main
anne	doc_366216787884_item	3604825	et	4	main
laulab	doc_366216787884_item	3604827	et	3	main
mõlemates	doc_366216787884_item	3604828	et	3	main
veski	doc_366216787884_item	3604826	et	4	main
keele	doc_366216787886_item	3604838	et	4	main
keele	doc_366216787886_item	3604841	et	4	main
kirjutamine	doc_366216787886_item	3604843	et	4	main
laulurahva	doc_366216787886_item	3604850	et	3	main
essee	doc_366216787886_item	3604851	et	4	main
pikkus	doc_366216787886_item	3604852	et	4	main
300	doc_366216787886_item	3604853	et	2	main
350	doc_366216787886_item	3604854	et	2	main
arutlev	doc_366216787886_item	3604859	et	4	main
soovitatav	doc_366216787886_item	3604871	et	4	main
illustreerida	doc_366216787886_item	3604872	et	3	main
näidetega	doc_366216787886_item	3604873	et	3	main
vastus	doc_366216787886_item	3604878	et	3	main
on	doc_366216787886_item	3604885	et	4	main
rohkem	doc_366216787886_item	3604905	et	4	main
1000	doc_366216787886_item	3604906	et	2	main
aastat	doc_366216787886_item	3604907	et	3	main
nad	doc_366216787886_item	3604908	et	3	main
laulsid	doc_366216787886_item	3604909	et	4	main
rõõmus	doc_366216787886_item	3604918	et	4	main
pilli	doc_366216787886_item	3604936	et	4	main
vabadusest	doc_366216787886_item	3604946	et	4	main
oma	doc_366216787886_item	3604947	et	4	main
toimus	doc_366216787886_item	3604952	et	3	main
esimene	doc_366216787886_item	3604953	et	3	main
laulupidu	doc_366216787886_item	3604954	et	4	main
eestlased	doc_366216787886_item	3604955	et	3	main
laulu	doc_366216787886_item	3604959	et	4	main
abil	doc_366216787886_item	3604960	et	4	main
meie	doc_366216787886_item	3604980	et	4	main
millal	doc_366216787886_item	3604984	et	3	main
meie	doc_366216787886_item	3605019	et	4	main
laulurahvas	doc_366216787886_item	3605029	et	4	main
laul	doc_366216787886_item	3605030	et	4	main
eesti	doc_366216787889_item	3605036	et	4	main
keele	doc_366216787889_item	3605040	et	4	main
teeb	doc_366216787889_item	3605047	et	3	main
pikkus	doc_366216787889_item	3605051	et	4	main
300	doc_366216787889_item	3605052	et	2	main
350	doc_366216787889_item	3605053	et	2	main
arutlev	doc_366216787889_item	3605058	et	4	main
kultuur	doc_366216787889_item	3605075	et	3	main
see	doc_366216787889_item	3605076	et	3	main
neid	doc_366216787889_item	3605090	et	4	main
laulsid	doc_366216787889_item	3605091	et	4	main
emad	doc_366216787889_item	3605093	et	3	main
tansid	doc_366216787889_item	3605100	et	4	main
saama	doc_366216787889_item	3605102	et	4	main
moodi	doc_366216787889_item	3605103	et	4	main
eesti	doc_366216787886_item	3604837	et	4	main
essee	doc_366216787886_item	3604845	et	4	main
teemal	doc_366216787886_item	3604846	et	3	main
mis	doc_366216787886_item	3604847	et	4	main
teeb	doc_366216787886_item	3604848	et	3	main
essee	doc_366216787886_item	3604856	et	4	main
ja	doc_366216787886_item	3604865	et	3	main
faktidele	doc_366216787886_item	3604868	et	3	main
on	doc_366216787886_item	3604870	et	4	main
leiame	doc_366216787886_item	3604877	et	3	main
küsimusele	doc_366216787886_item	3604879	et	4	main
on	doc_366216787886_item	3604881	et	4	main
laulurahvas	doc_366216787886_item	3604882	et	4	main
kellel	doc_366216787886_item	3604887	et	4	main
laul	doc_366216787886_item	3604888	et	4	main
rahvalaul	doc_366216787886_item	3604893	et	4	main
kogu	doc_366216787886_item	3604896	et	4	main
esteetiline	doc_366216787886_item	3604898	et	3	main
sotsiaalne	doc_366216787886_item	3604900	et	3	main
ja	doc_366216787886_item	3604919	et	3	main
mure	doc_366216787886_item	3604920	et	4	main
meeldib	doc_366216787886_item	3604922	et	3	main
eestlastele	doc_366216787886_item	3604921	et	4	main
laulda	doc_366216787886_item	3604923	et	4	main
üksi	doc_366216787886_item	3604924	et	4	main
kahekesi	doc_366216787886_item	3604925	et	3	main
kooriga	doc_366216787886_item	3604926	et	4	main
eeslauljaga	doc_366216787886_item	3604927	et	3	main
ja	doc_366216787886_item	3604928	et	3	main
ilma	doc_366216787886_item	3604929	et	4	main
tavaliselt	doc_366216787886_item	3604930	et	4	main
lauluvad	doc_366216787886_item	3604931	et	4	main
naised	doc_366216787886_item	3604932	et	3	main
aga	doc_366216787886_item	3604933	et	3	main
mehed	doc_366216787886_item	3604934	et	3	main
mängivad	doc_366216787886_item	3604935	et	4	main
oli	doc_366216787886_item	3604938	et	3	main
oma	doc_366216787886_item	3604942	et	4	main
eestlased	doc_366216787886_item	3604944	et	3	main
tsari	doc_366216787886_item	3604950	et	4	main
maal	doc_366216787886_item	3604963	et	4	main
tahavad	doc_366216787886_item	3604965	et	3	main
rääkida	doc_366216787886_item	3604966	et	3	main
oma	doc_366216787886_item	3604967	et	4	main
emakeeles	doc_366216787886_item	3604968	et	4	main
algusel	doc_366216787886_item	3604969	et	4	main
kujunes	doc_366216787886_item	3604970	et	3	main
laulupidu	doc_366216787886_item	3604971	et	4	main
tartus	doc_366216787886_item	3604972	et	3	main
praegu	doc_366216787886_item	3604973	et	3	main
igal	doc_366216787886_item	3604974	et	3	main
suvel	doc_366216787886_item	3604975	et	3	main
toimub	doc_366216787886_item	3604976	et	3	main
ta	doc_366216787886_item	3604977	et	4	main
oli	doc_366216787886_item	3604979	et	3	main
tähtsam	doc_366216787886_item	3604982	et	4	main
laulupidu	doc_366216787886_item	3604985	et	4	main
oli	doc_366216787886_item	3604986	et	3	main
kahes	doc_366216787886_item	3604987	et	4	main
räägib	doc_366216787886_item	3604994	et	3	main
sellest	doc_366216787886_item	3604996	et	4	main
laulurahvas	doc_366216787886_item	3605000	et	4	main
kõik	doc_366216787886_item	3605001	et	4	main
meie	doc_366216787886_item	3605004	et	4	main
laulupeost	doc_366216787886_item	3605005	et	4	main
ja	doc_366216787886_item	3605006	et	3	main
teavad	doc_366216787886_item	3605007	et	3	main
et	doc_366216787886_item	3605008	et	3	main
eestlased	doc_366216787886_item	3605009	et	3	main
said	doc_366216787886_item	3605010	et	4	main
laulu	doc_366216787886_item	3605012	et	4	main
vabadust	doc_366216787886_item	3605011	et	4	main
abil	doc_366216787886_item	3605013	et	4	main
ja	doc_366216787886_item	3605014	et	3	main
ilma	doc_366216787886_item	3605015	et	4	main
relvata	doc_366216787886_item	3605016	et	3	main
võistlus	doc_366216787886_item	3604992	et	3	main
eurovisioonis	doc_366216787886_item	3604993	et	3	main
ka	doc_366216787886_item	3604995	et	3	main
eestlased	doc_366216787886_item	3604998	et	3	main
laul	doc_366216787886_item	3605017	et	4	main
ühendab	doc_366216787886_item	3605018	et	3	main
ma	doc_366216787886_item	3605022	et	3	main
saan	doc_366216787886_item	3605023	et	4	main
on	doc_366216787886_item	3605031	et	4	main
rahvas	doc_366216787886_item	3605020	et	4	main
täpselt	doc_366216787886_item	3605024	et	4	main
öelda	doc_366216787886_item	3605025	et	4	main
et	doc_366216787886_item	3605026	et	3	main
eestlased	doc_366216787886_item	3605027	et	3	main
nende	doc_366216787886_item	3605032	et	4	main
teise	doc_366216787889_item	3605039	et	4	main
test	doc_366216787889_item	3605041	et	3	main
eestlastest	doc_366216787889_item	3605048	et	4	main
laulurahva	doc_366216787889_item	3605049	et	3	main
essee	doc_366216787889_item	3605050	et	4	main
peab	doc_366216787889_item	3605056	et	4	main
olema	doc_366216787889_item	3605057	et	4	main
tuginema	doc_366216787889_item	3605062	et	3	main
loengus	doc_366216787889_item	3605063	et	3	main
ja	doc_366216787889_item	3605079	et	3	main
tegevus	doc_366216787889_item	3605081	et	4	main
ajal	doc_366216787889_item	3605083	et	4	main
üksi	doc_366216787889_item	3605092	et	4	main
lapsele	doc_366216787889_item	3605095	et	4	main
tööl	doc_366216787889_item	3605099	et	3	main
eesti	doc_366216787892_item	3605124	et	4	main
test	doc_366216787892_item	3605129	et	3	main
kirjutamine	doc_366216787892_item	3605130	et	4	main
mis	doc_366216787892_item	3605134	et	4	main
essee	doc_366216787892_item	3605143	et	4	main
tuginema	doc_366216787892_item	3605150	et	3	main
loengus	doc_366216787892_item	3605151	et	3	main
näidetega	doc_366216787892_item	3605160	et	3	main
vanal	doc_366216787892_item	3605161	et	3	main
töötamist	doc_366216787892_item	3605165	et	4	main
käsitööd	doc_366216787892_item	3605168	et	4	main
esimene	doc_366216787892_item	3605175	et	3	main
ülemaaline	doc_366216787892_item	3605176	et	4	main
pani	doc_366216787892_item	3605179	et	4	main
räägivad	doc_366216787892_item	3605194	et	3	main
eestlased	doc_366216787892_item	3605197	et	3	main
tulevad	doc_366216787892_item	3605226	et	4	main
kohata	doc_366216787892_item	3605231	et	4	main
laulavad	doc_366216787892_item	3605240	et	4	main
meelelahutuslikke	doc_366216787892_item	3605244	et	3	main
kus	doc_366216787892_item	3605246	et	3	main
ja	doc_366216787892_item	3605249	et	3	main
on	doc_366216787892_item	3605251	et	4	main
väga	doc_366216787892_item	3605252	et	3	main
huvitav	doc_366216787892_item	3605253	et	4	main
et	doc_366216787892_item	3605254	et	3	main
on	doc_366216787892_item	3605268	et	4	main
on	doc_366216787892_item	3605277	et	4	main
eestlaste	doc_366216787892_item	3605279	et	4	main
rahvuslik	doc_366216787892_item	3605280	et	3	main
ärkamine	doc_366216787892_item	3605281	et	4	main
19	doc_366216787892_item	3605282	et	2	main
ma	doc_366216787892_item	3605295	et	3	main
et	doc_366216787892_item	3605298	et	3	main
laul	doc_366216787892_item	3605299	et	4	main
mõjutas	doc_366216787892_item	3605300	et	3	main
nendel	doc_366216787892_item	3605323	et	4	main
laulupidude	doc_366216787892_item	3605325	et	4	main
kui	doc_366216787894_item	3605362	et	3	main
kirjutamine	doc_366216787894_item	3605366	et	4	main
kirjutage	doc_366216787894_item	3605367	et	3	main
teemal	doc_366216787894_item	3605369	et	3	main
mis	doc_366216787894_item	3605370	et	4	main
300	doc_366216787894_item	3605376	et	2	main
peab	doc_366216787894_item	3605380	et	4	main
soovitatav	doc_366216787894_item	3605394	et	4	main
sest	doc_366216787894_item	3605403	et	4	main
see	doc_366216787894_item	3605404	et	3	main
on	doc_366216787894_item	3605405	et	4	main
emotsionaalne	doc_366216787894_item	3605406	et	3	main
valjenusvahed	doc_366216787894_item	3605407	et	4	main
ka	doc_366216787894_item	3605408	et	3	main
saame	doc_366216787894_item	3605409	et	4	main
inimesed	doc_366216787894_item	3605415	et	3	main
lauldes	doc_366216787894_item	3605449	et	3	main
rõhutati	doc_366216787894_item	3605450	et	4	main
laenatud	doc_366216787894_item	3605463	et	4	main
laulud	doc_366216787894_item	3605466	et	3	main
ja	doc_366216787894_item	3605477	et	3	main
see	doc_366216787894_item	3605478	et	3	main
et	doc_366216787889_item	3605116	et	3	main
neid	doc_366216787889_item	3605117	et	4	main
tegevused	doc_366216787889_item	3605118	et	4	main
läksid	doc_366216787889_item	3605119	et	4	main
nendest	doc_366216787889_item	3605120	et	4	main
kultuurist	doc_366216787889_item	3605121	et	3	main
kui	doc_366216787889_item	3605038	et	3	main
kirjutamine	doc_366216787889_item	3605042	et	4	main
analüüsiv	doc_366216787889_item	3605059	et	4	main
soovitatav	doc_366216787889_item	3605070	et	4	main
illustreerida	doc_366216787889_item	3605071	et	3	main
näidetega	doc_366216787889_item	3605072	et	3	main
laulmine	doc_366216787889_item	3605073	et	4	main
ja	doc_366216787889_item	3605074	et	3	main
sotsiaalne	doc_366216787889_item	3605080	et	3	main
mehed	doc_366216787889_item	3605098	et	3	main
kui	doc_366216787889_item	3605104	et	3	main
nad	doc_366216787889_item	3605108	et	3	main
olid	doc_366216787889_item	3605109	et	4	main
rõmsad	doc_366216787889_item	3605110	et	4	main
lõbusad	doc_366216787889_item	3605111	et	3	main
hakkasid	doc_366216787889_item	3605112	et	4	main
liikuma	doc_366216787889_item	3605113	et	3	main
ma	doc_366216787889_item	3605114	et	3	main
arvan	doc_366216787889_item	3605115	et	3	main
keele	doc_366216787892_item	3605128	et	4	main
essee	doc_366216787892_item	3605138	et	4	main
peab	doc_366216787892_item	3605144	et	4	main
üldistav	doc_366216787892_item	3605149	et	4	main
ja	doc_366216787892_item	3605152	et	3	main
on	doc_366216787892_item	3605157	et	4	main
kaasnesid	doc_366216787892_item	3605163	et	4	main
rahvalaulu	doc_366216787892_item	3605170	et	4	main
järgnevate	doc_366216787892_item	3605181	et	4	main
on	doc_366216787892_item	3605185	et	4	main
faktid	doc_366216787892_item	3605193	et	3	main
et	doc_366216787892_item	3605196	et	3	main
laulda	doc_366216787892_item	3605199	et	4	main
ajast	doc_366216787892_item	3605201	et	4	main
tänapäevani	doc_366216787892_item	3605202	et	3	main
et	doc_366216787892_item	3605203	et	3	main
ja	doc_366216787892_item	3605224	et	3	main
laulupeole	doc_366216787892_item	3605227	et	4	main
kus	doc_366216787892_item	3605228	et	3	main
nad	doc_366216787892_item	3605229	et	3	main
loodavad	doc_366216787892_item	3605230	et	4	main
eestlased	doc_366216787892_item	3605241	et	3	main
laulavad	doc_366216787892_item	3605248	et	4	main
heal	doc_366216787892_item	3605274	et	3	main
muusikaharrastusega	doc_366216787892_item	3605276	et	3	main
1980ndate	doc_366216787892_item	3605286	et	4	main
lõpus	doc_366216787892_item	3605287	et	4	main
järgi	doc_366216787892_item	3605294	et	4	main
väga	doc_366216787892_item	3605301	et	3	main
palju	doc_366216787892_item	3605302	et	4	main
on	doc_366216787892_item	3605324	et	4	main
traditsioon	doc_366216787892_item	3605326	et	3	main
nendel	doc_366216787892_item	3605327	et	4	main
essee	doc_366216787894_item	3605359	et	4	main
test	doc_366216787894_item	3605365	et	3	main
teeb	doc_366216787894_item	3605371	et	3	main
eestlastest	doc_366216787894_item	3605372	et	4	main
laulurahva	doc_366216787894_item	3605373	et	3	main
350	doc_366216787894_item	3605377	et	2	main
ja	doc_366216787894_item	3605388	et	3	main
näidetega	doc_366216787894_item	3605396	et	3	main
on	doc_366216787894_item	3605398	et	4	main
tähtis	doc_366216787894_item	3605400	et	4	main
meie	doc_366216787894_item	3605401	et	4	main
laulmine	doc_366216787894_item	3605412	et	4	main
laulude	doc_366216787894_item	3605455	et	3	main
kirikus	doc_366216787894_item	3605458	et	3	main
on	doc_366216787894_item	3605467	et	4	main
euroopa	doc_366216787894_item	3605470	et	4	main
eelkõige	doc_366216787894_item	3605472	et	3	main
on	doc_366216787894_item	3605479	et	4	main
selge	doc_366216787894_item	3605480	et	4	main
mitte	doc_366216787894_item	3605481	et	3	main
sain	doc_366216787894_item	3605485	et	3	main
rahvalaul	doc_366216787892_item	3605345	et	4	main
ja	doc_366216787892_item	3605346	et	3	main
tants	doc_366216787892_item	3605347	et	3	main
on	doc_366216787892_item	3605348	et	4	main
populaarne	doc_366216787892_item	3605349	et	3	main
vanast	doc_366216787892_item	3605350	et	3	main
ajast	doc_366216787892_item	3605351	et	4	main
tänapäevani	doc_366216787892_item	3605352	et	3	main
ja	doc_366216787892_item	3605353	et	3	main
see	doc_366216787892_item	3605354	et	3	main
teeb	doc_366216787892_item	3605355	et	3	main
eestlastest	doc_366216787892_item	3605356	et	4	main
laulurahva	doc_366216787892_item	3605357	et	3	main
essee	doc_366216787892_item	3605123	et	4	main
keele	doc_366216787892_item	3605125	et	4	main
kirjutage	doc_366216787892_item	3605131	et	3	main
teemal	doc_366216787892_item	3605133	et	3	main
teeb	doc_366216787892_item	3605135	et	3	main
eestlastest	doc_366216787892_item	3605136	et	4	main
laulurahva	doc_366216787892_item	3605137	et	3	main
analüüsiv	doc_366216787892_item	3605147	et	4	main
ja	doc_366216787892_item	3605148	et	3	main
lugemistekstis	doc_366216787892_item	3605153	et	3	main
faktidele	doc_366216787892_item	3605155	et	3	main
väiteid	doc_366216787892_item	3605156	et	4	main
eestlased	doc_366216787892_item	3605164	et	3	main
last	doc_366216787892_item	3605166	et	4	main
kiigutamist	doc_366216787892_item	3605167	et	4	main
laulmisega	doc_366216787892_item	3605171	et	4	main
korraldamisele	doc_366216787892_item	3605183	et	4	main
laulupidu	doc_366216787892_item	3605186	et	4	main
tähtis	doc_366216787892_item	3605187	et	4	main
ja	doc_366216787892_item	3605188	et	3	main
massiline	doc_366216787892_item	3605189	et	4	main
manifestatsioon	doc_366216787892_item	3605190	et	3	main
eestis	doc_366216787892_item	3605191	et	3	main
sellest	doc_366216787892_item	3605195	et	4	main
laulud	doc_366216787892_item	3605204	et	3	main
on	doc_366216787892_item	3605205	et	4	main
tähtis	doc_366216787892_item	3605206	et	4	main
osa	doc_366216787892_item	3605207	et	4	main
nende	doc_366216787892_item	3605208	et	4	main
elust	doc_366216787892_item	3605209	et	3	main
tanapäeval	doc_366216787892_item	3605210	et	4	main
on	doc_366216787892_item	3605211	et	4	main
rahvalaulud	doc_366216787892_item	3605212	et	3	main
populaarsed	doc_366216787892_item	3605213	et	3	main
ka	doc_366216787892_item	3605214	et	3	main
noorte	doc_366216787892_item	3605215	et	3	main
seas	doc_366216787892_item	3605216	et	4	main
igal	doc_366216787892_item	3605217	et	3	main
aastal	doc_366216787892_item	3605218	et	3	main
noored	doc_366216787892_item	3605219	et	3	main
koos	doc_366216787892_item	3605220	et	4	main
vanematega	doc_366216787892_item	3605222	et	4	main
oma	doc_366216787892_item	3605221	et	4	main
vanaisadega	doc_366216787892_item	3605223	et	3	main
oma	doc_366216787892_item	3605232	et	4	main
muusikat	doc_366216787892_item	3605238	et	3	main
programme	doc_366216787892_item	3605245	et	3	main
nad	doc_366216787892_item	3605247	et	3	main
mõjub	doc_366216787892_item	3605256	et	3	main
eesti	doc_366216787892_item	3605257	et	4	main
laul	doc_366216787892_item	3605259	et	4	main
ja	doc_366216787892_item	3605260	et	3	main
tants	doc_366216787892_item	3605261	et	3	main
on	doc_366216787892_item	3605262	et	4	main
väga	doc_366216787892_item	3605263	et	3	main
kui	doc_366216787892_item	3605273	et	3	main
aastal	doc_366216787892_item	3605173	et	3	main
oli	doc_366216787892_item	3605174	et	3	main
mis	doc_366216787892_item	3605178	et	4	main
aluse	doc_366216787892_item	3605180	et	4	main
üldlaulupidude	doc_366216787892_item	3605182	et	4	main
sellised	doc_366216787892_item	3605192	et	4	main
armastavad	doc_366216787892_item	3605198	et	4	main
vanast	doc_366216787892_item	3605200	et	3	main
vanaemadega	doc_366216787892_item	3605225	et	3	main
kus	doc_366216787892_item	3605235	et	3	main
kuulavad	doc_366216787892_item	3605237	et	4	main
organiseerivad	doc_366216787892_item	3605242	et	4	main
tantsivad	doc_366216787892_item	3605250	et	4	main
popmuusikale	doc_366216787892_item	3605258	et	4	main
saatnud	doc_366216787892_item	3605269	et	4	main
eestlasi	doc_366216787892_item	3605270	et	3	main
nii	doc_366216787892_item	3605271	et	3	main
halval	doc_366216787892_item	3605272	et	3	main
ajal	doc_366216787892_item	3605275	et	4	main
seotud	doc_366216787892_item	3605278	et	4	main
sajandi	doc_366216787892_item	3605283	et	3	main
lõpupoole	doc_366216787892_item	3605284	et	4	main
ja	doc_366216787892_item	3605285	et	3	main
selle	doc_366216787892_item	3605293	et	4	main
laulupidu	doc_366216787892_item	3605177	et	4	main
tänapäeval	doc_366216787892_item	3605184	et	3	main
sõpru	doc_366216787892_item	3605233	et	3	main
tuttavaid	doc_366216787892_item	3605234	et	3	main
nad	doc_366216787892_item	3605236	et	3	main
ja	doc_366216787892_item	3605239	et	3	main
mitmesuguseid	doc_366216787892_item	3605243	et	3	main
rahvamuusika	doc_366216787892_item	3605255	et	4	main
olulised	doc_366216787892_item	3605264	et	4	main
asjad	doc_366216787892_item	3605265	et	3	main
eestlastele	doc_366216787892_item	3605266	et	4	main
nad	doc_366216787892_item	3605267	et	3	main
väga	doc_366216787892_item	3605288	et	3	main
tähtsad	doc_366216787892_item	3605289	et	3	main
sündmused	doc_366216787892_item	3605290	et	3	main
eesti	doc_366216787892_item	3605291	et	4	main
ajaloos	doc_366216787892_item	3605292	et	4	main
võin	doc_366216787892_item	3605296	et	3	main
ütelda	doc_366216787892_item	3605297	et	4	main
eesti	doc_366216787892_item	3605303	et	4	main
ajalugu	doc_366216787892_item	3605304	et	4	main
kokkuvõttes	doc_366216787892_item	3605305	et	3	main
ma	doc_366216787892_item	3605306	et	3	main
võin	doc_366216787892_item	3605307	et	3	main
vältida	doc_366216787892_item	3605308	et	3	main
et	doc_366216787892_item	3605309	et	3	main
eestlased	doc_366216787892_item	3605310	et	3	main
on	doc_366216787892_item	3605311	et	4	main
laulurahva	doc_366216787892_item	3605312	et	3	main
nad	doc_366216787892_item	3605313	et	3	main
laulsid	doc_366216787892_item	3605314	et	4	main
nii	doc_366216787892_item	3605315	et	3	main
raskel	doc_366216787892_item	3605316	et	3	main
kui	doc_366216787892_item	3605317	et	3	main
heal	doc_366216787892_item	3605318	et	3	main
ajal	doc_366216787892_item	3605319	et	4	main
nendel	doc_366216787892_item	3605320	et	4	main
on	doc_366216787892_item	3605321	et	4	main
laulutraditsioonid	doc_366216787892_item	3605322	et	3	main
teise	doc_366216787894_item	3605363	et	4	main
keele	doc_366216787894_item	3605364	et	4	main
essee	doc_366216787894_item	3605368	et	4	main
pikkus	doc_366216787894_item	3605375	et	4	main
essee	doc_366216787894_item	3605379	et	4	main
olema	doc_366216787894_item	3605381	et	4	main
arutlev	doc_366216787894_item	3605382	et	4	main
loengus	doc_366216787894_item	3605387	et	3	main
lugemistekstis	doc_366216787894_item	3605389	et	3	main
faktidele	doc_366216787894_item	3605391	et	3	main
elus	doc_366216787894_item	3605402	et	4	main
öelda	doc_366216787894_item	3605410	et	4	main
et	doc_366216787894_item	3605411	et	3	main
rütmi	doc_366216787894_item	3605451	et	4	main
veel	doc_366216787894_item	3605452	et	4	main
18	doc_366216787894_item	3605453	et	2	main
laulmine	doc_366216787894_item	3605456	et	4	main
juba	doc_366216787894_item	3605459	et	3	main
välja	doc_366216787894_item	3605468	et	4	main
kujunenud	doc_366216787894_item	3605469	et	4	main
muusika	doc_366216787894_item	3605471	et	4	main
saksa	doc_366216787894_item	3605473	et	4	main
slaavi	doc_366216787894_item	3605474	et	3	main
palju	doc_366216787894_item	3605482	et	4	main
on	doc_366216787892_item	3605328	et	4	main
suur	doc_366216787892_item	3605329	et	3	main
huvi	doc_366216787892_item	3605330	et	4	main
rahvalaulude	doc_366216787892_item	3605331	et	3	main
vastu	doc_366216787892_item	3605332	et	3	main
eestis	doc_366216787892_item	3605333	et	3	main
on	doc_366216787892_item	3605334	et	4	main
palju	doc_366216787892_item	3605335	et	4	main
mis	doc_366216787892_item	3605337	et	4	main
folkloorirühmi	doc_366216787892_item	3605336	et	4	main
käivad	doc_366216787892_item	3605338	et	4	main
arhiivil	doc_366216787892_item	3605339	et	3	main
teevad	doc_366216787892_item	3605340	et	3	main
üürituseid	doc_366216787892_item	3605341	et	4	main
ja	doc_366216787892_item	3605342	et	3	main
nii	doc_366216787892_item	3605343	et	3	main
edasi	doc_366216787892_item	3605344	et	3	main
keele	doc_366216787894_item	3605361	et	4	main
essee	doc_366216787894_item	3605374	et	4	main
analüüsiv	doc_366216787894_item	3605383	et	4	main
ja	doc_366216787894_item	3605384	et	3	main
üldistav	doc_366216787894_item	3605385	et	4	main
esitatud	doc_366216787894_item	3605390	et	4	main
väiteid	doc_366216787894_item	3605392	et	4	main
on	doc_366216787894_item	3605393	et	4	main
laulmine	doc_366216787894_item	3605397	et	4	main
esteetiline	doc_366216787894_item	3605414	et	3	main
sajandil	doc_366216787894_item	3605454	et	3	main
oli	doc_366216787894_item	3605457	et	3	main
19	doc_366216787894_item	3605460	et	2	main
euroopast	doc_366216787894_item	3605462	et	3	main
mõjul	doc_366216787894_item	3605476	et	4	main
tagasi	doc_366216787894_item	3605484	et	3	main
mis	doc_366216787894_item	3605497	et	4	main
toimusse	doc_366216787894_item	3605510	et	4	main
on	doc_366216787894_item	3605511	et	4	main
olud	doc_366216787894_item	3605516	et	3	main
kõik	doc_366216787894_item	3605539	et	4	main
ka	doc_366216787894_item	3605559	et	3	main
on	doc_366216787894_item	3605574	et	4	main
saan	doc_366216787894_item	3605582	et	4	main
on	doc_366216787894_item	3605594	et	4	main
möödas	doc_366216787894_item	3605595	et	3	main
rahvapeost	doc_366216787894_item	3605603	et	4	main
kuhu	doc_366216787894_item	3605607	et	3	main
oma	doc_366216787894_item	3605610	et	4	main
kuulavad	doc_366216787894_item	3605617	et	4	main
saavad	doc_366216787894_item	3605618	et	4	main
ka	doc_366216787894_item	3605619	et	3	main
ilus	doc_366216787894_item	3605626	et	4	main
laulupeod	doc_366216787894_item	3605630	et	4	main
on	doc_366216787894_item	3605632	et	4	main
eesti	doc_366216787894_item	3605360	et	4	main
sõna	doc_366216787894_item	3605378	et	4	main
tuginema	doc_366216787894_item	3605386	et	3	main
illustreerida	doc_366216787894_item	3605395	et	3	main
väga	doc_366216787894_item	3605399	et	3	main
on	doc_366216787894_item	3605413	et	4	main
laulavad	doc_366216787894_item	3605416	et	4	main
kõikjal	doc_366216787894_item	3605417	et	3	main
kodus	doc_366216787894_item	3605418	et	4	main
õues	doc_366216787894_item	3605419	et	4	main
võib	doc_366216787894_item	3605420	et	3	main
olla	doc_366216787894_item	3605421	et	3	main
tööl	doc_366216787894_item	3605422	et	3	main
varem	doc_366216787894_item	3605423	et	4	main
lauldi	doc_366216787894_item	3605424	et	3	main
ainuld	doc_366216787894_item	3605425	et	4	main
üksi	doc_366216787894_item	3605426	et	4	main
olles	doc_366216787894_item	3605427	et	3	main
täpselt	doc_366216787894_item	3605428	et	4	main
tean	doc_366216787894_item	3605429	et	3	main
et	doc_366216787894_item	3605430	et	3	main
laulmine	doc_366216787894_item	3605431	et	4	main
saab	doc_366216787894_item	3605432	et	3	main
stressi	doc_366216787894_item	3605433	et	4	main
maha	doc_366216787894_item	3605434	et	4	main
võtta	doc_366216787894_item	3605435	et	3	main
enam	doc_366216787894_item	3605436	et	4	main
kui	doc_366216787894_item	3605437	et	3	main
tuhat	doc_366216787894_item	3605438	et	4	main
aastat	doc_366216787894_item	3605439	et	3	main
tagasi	doc_366216787894_item	3605440	et	3	main
oli	doc_366216787894_item	3605441	et	3	main
regivärsiline	doc_366216787894_item	3605442	et	4	main
rahvalaul	doc_366216787894_item	3605443	et	4	main
kus	doc_366216787894_item	3605444	et	3	main
esitati	doc_366216787894_item	3605445	et	4	main
eeslaulja	doc_366216787894_item	3605446	et	4	main
ja	doc_366216787894_item	3605447	et	3	main
koor	doc_366216787894_item	3605448	et	4	main
sajandil	doc_366216787894_item	3605461	et	3	main
laulutraditsiooni	doc_366216787894_item	3605464	et	4	main
need	doc_366216787894_item	3605465	et	3	main
muusika	doc_366216787894_item	3605475	et	4	main
teada	doc_366216787894_item	3605486	et	3	main
et	doc_366216787894_item	3605487	et	3	main
tähtsusega	doc_366216787894_item	3605489	et	4	main
sündmuseks	doc_366216787894_item	3605490	et	3	main
kujunes	doc_366216787894_item	3605491	et	3	main
esimene	doc_366216787894_item	3605492	et	3	main
ülemaaline	doc_366216787894_item	3605493	et	4	main
laulupidu	doc_366216787894_item	3605494	et	4	main
1869	doc_366216787894_item	3605495	et	2	main
aastal	doc_366216787894_item	3605496	et	3	main
palju	doc_366216787894_item	3605503	et	4	main
kurb	doc_366216787894_item	3605505	et	3	main
see	doc_366216787894_item	3605507	et	3	main
valitsenud	doc_366216787894_item	3605514	et	4	main
loomist	doc_366216787894_item	3605535	et	4	main
teame	doc_366216787894_item	3605541	et	3	main
mis	doc_366216787894_item	3605542	et	4	main
on	doc_366216787894_item	3605543	et	4	main
lauluväljak	doc_366216787894_item	3605544	et	3	main
see	doc_366216787894_item	3605545	et	3	main
on	doc_366216787894_item	3605546	et	4	main
koht	doc_366216787894_item	3605547	et	3	main
palju	doc_366216787894_item	3605549	et	4	main
aastaid	doc_366216787894_item	3605550	et	4	main
kus	doc_366216787894_item	3605548	et	3	main
tagasi	doc_366216787894_item	3605551	et	3	main
ja	doc_366216787894_item	3605552	et	3	main
ka	doc_366216787894_item	3605553	et	3	main
praegu	doc_366216787894_item	3605554	et	3	main
toimuvad	doc_366216787894_item	3605555	et	4	main
laulupeod	doc_366216787894_item	3605556	et	4	main
laulupidu	doc_366216787894_item	3605557	et	4	main
on	doc_366216787894_item	3605558	et	4	main
on	doc_366216787894_item	3605564	et	4	main
rahvasluse	doc_366216787894_item	3605569	et	4	main
aega	doc_366216787894_item	3605593	et	4	main
midagi	doc_366216787894_item	3605602	et	4	main
koht	doc_366216787894_item	3605606	et	3	main
meil	doc_366216787894_item	3605624	et	4	main
kus	doc_366216787894_item	3605628	et	3	main
kui	doc_366216787896_item	3605640	et	3	main
keele	doc_366216787896_item	3605642	et	4	main
peab	doc_366216787896_item	3605658	et	4	main
olema	doc_366216787896_item	3605659	et	4	main
analüüsiv	doc_366216787896_item	3605661	et	4	main
üldistav	doc_366216787896_item	3605663	et	4	main
väiteid	doc_366216787896_item	3605670	et	4	main
on	doc_366216787896_item	3605671	et	4	main
laulurahva	doc_366216787896_item	3605678	et	3	main
kõigepealt	doc_366216787896_item	3605684	et	3	main
sellest	doc_366216787896_item	3605689	et	4	main
vaatame	doc_366216787896_item	3605691	et	3	main
minu	doc_366216787896_item	3605701	et	3	main
meelest	doc_366216787896_item	3605702	et	4	main
see	doc_366216787896_item	3605703	et	3	main
tähtsam	doc_366216787896_item	3605706	et	4	main
punkt	doc_366216787896_item	3605707	et	4	main
sest	doc_366216787896_item	3605708	et	4	main
tantsivad	doc_366216787896_item	3605716	et	4	main
ja	doc_366216787896_item	3605717	et	3	main
aega	doc_366216787894_item	3605483	et	4	main
ajaloolise	doc_366216787894_item	3605488	et	4	main
nii	doc_366216787894_item	3605502	et	3	main
on	doc_366216787894_item	3605506	et	4	main
et	doc_366216787894_item	3605508	et	3	main
jätnud	doc_366216787894_item	3605513	et	4	main
nii	doc_366216787894_item	3605518	et	3	main
ei	doc_366216787894_item	3605519	et	4	main
teame	doc_366216787894_item	3605522	et	3	main
see	doc_366216787894_item	3605523	et	3	main
et	doc_366216787894_item	3605524	et	3	main
ainult	doc_366216787894_item	3605525	et	4	main
1896	doc_366216787894_item	3605526	et	2	main
traditsioon	doc_366216787894_item	3605527	et	3	main
vabariigi	doc_366216787894_item	3605534	et	3	main
laulupeod	doc_366216787894_item	3605537	et	4	main
toimus	doc_366216787894_item	3605498	et	3	main
tartus	doc_366216787894_item	3605499	et	3	main
meeskoori	doc_366216787894_item	3605504	et	4	main
alati	doc_366216787894_item	3605512	et	4	main
aga	doc_366216787894_item	3605517	et	3	main
tuli	doc_366216787894_item	3605528	et	4	main
meie	doc_366216787894_item	3605529	et	4	main
juurde	doc_366216787894_item	3605530	et	4	main
tallinnasse	doc_366216787894_item	3605531	et	3	main
tänast	doc_366216787894_item	3605532	et	3	main
me	doc_366216787894_item	3605540	et	4	main
tähtis	doc_366216787894_item	3605561	et	4	main
kõige	doc_366216787894_item	3605565	et	4	main
tähelepanuväärsem	doc_366216787894_item	3605566	et	4	main
ja	doc_366216787894_item	3605567	et	3	main
proffessionaalse	doc_366216787894_item	3605576	et	4	main
heliloominguga	doc_366216787894_item	3605577	et	3	main
koorilaulu	doc_366216787894_item	3605578	et	4	main
sest	doc_366216787894_item	3605586	et	4	main
teine	doc_366216787894_item	3605589	et	3	main
muusikatalu	doc_366216787894_item	3605590	et	4	main
ja	doc_366216787894_item	3605591	et	3	main
palju	doc_366216787894_item	3605592	et	4	main
kes	doc_366216787894_item	3605616	et	4	main
on	doc_366216787894_item	3605625	et	4	main
see	doc_366216787894_item	3605631	et	3	main
essee	doc_366216787896_item	3605637	et	4	main
kirjutamine	doc_366216787896_item	3605644	et	4	main
essee	doc_366216787896_item	3605646	et	4	main
pikkus	doc_366216787896_item	3605653	et	4	main
300	doc_366216787896_item	3605654	et	2	main
ja	doc_366216787896_item	3605662	et	3	main
loengus	doc_366216787896_item	3605665	et	3	main
kui	doc_366216787896_item	3605679	et	3	main
mida	doc_366216787896_item	3605686	et	4	main
kõige	doc_366216787896_item	3605705	et	4	main
suhtlevad	doc_366216787896_item	3605712	et	4	main
saavad	doc_366216787896_item	3605713	et	4	main
uued	doc_366216787896_item	3605714	et	3	main
tuttavaid	doc_366216787896_item	3605715	et	3	main
tähtis	doc_366216787896_item	3605723	et	4	main
mis	doc_366216787896_item	3605730	et	4	main
oma	doc_366216787896_item	3605759	et	4	main
maailmas	doc_366216787896_item	3605760	et	3	main
lapsed	doc_366216787896_item	3605761	et	3	main
kuulavad	doc_366216787896_item	3605762	et	4	main
aga	doc_366216787896_item	3605769	et	3	main
linnapäevad	doc_366216787896_item	3605779	et	3	main
mis	doc_366216787896_item	3605780	et	4	main
kannavad	doc_366216787896_item	3605798	et	3	main
rahva	doc_366216787896_item	3605800	et	3	main
varem	doc_366216787896_item	3605809	et	4	main
see	doc_366216787896_item	3605810	et	3	main
toob	doc_366216787896_item	3605811	et	3	main
sõbralik	doc_366216787896_item	3605814	et	3	main
tantsid	doc_366216787896_item	3605818	et	4	main
kui	doc_366216787896_item	3605819	et	3	main
ka	doc_366216787896_item	3605820	et	3	main
laulud	doc_366216787896_item	3605821	et	3	main
see	doc_366216787896_item	3605829	et	3	main
emotsionaalne	doc_366216787896_item	3605832	et	3	main
massilisem	doc_366216787896_item	3605865	et	4	main
manifestatsioon	doc_366216787896_item	3605867	et	3	main
eestis	doc_366216787896_item	3605868	et	3	main
toimub	doc_366216787896_item	3605876	et	3	main
mida	doc_366216787896_item	3605878	et	4	main
teeb	doc_366216787896_item	3605879	et	3	main
test	doc_366216787899_item	3605895	et	3	main
kirjutamine	doc_366216787899_item	3605896	et	4	main
kirjutage	doc_366216787899_item	3605897	et	3	main
essee	doc_366216787899_item	3605909	et	4	main
üldistav	doc_366216787899_item	3605915	et	4	main
tuginema	doc_366216787899_item	3605916	et	3	main
inimesed	doc_366216787899_item	3605929	et	3	main
sa	doc_366216787899_item	3605943	et	3	main
on	doc_366216787899_item	3605946	et	4	main
kõik	doc_366216787899_item	3605957	et	4	main
peod	doc_366216787899_item	3605958	et	4	main
seal	doc_366216787899_item	3605960	et	4	main
aga	doc_366216787899_item	3605989	et	3	main
seal	doc_366216787894_item	3605500	et	4	main
osales	doc_366216787894_item	3605501	et	3	main
laulupidude	doc_366216787894_item	3605509	et	4	main
poliitilised	doc_366216787894_item	3605515	et	3	main
pea	doc_366216787894_item	3605520	et	4	main
olema	doc_366216787894_item	3605521	et	4	main
eesti	doc_366216787894_item	3605533	et	4	main
muutusid	doc_366216787894_item	3605536	et	4	main
muusika	doc_366216787894_item	3605538	et	4	main
massilisem	doc_366216787894_item	3605568	et	4	main
manifistatsioon	doc_366216787894_item	3605570	et	4	main
aga	doc_366216787894_item	3605571	et	3	main
peo	doc_366216787894_item	3605572	et	4	main
repertuaar	doc_366216787894_item	3605573	et	3	main
traditsioon	doc_366216787894_item	3605579	et	3	main
mõjutanud	doc_366216787894_item	3605580	et	4	main
ja	doc_366216787894_item	3605581	et	3	main
praegu	doc_366216787894_item	3605587	et	3	main
meie	doc_366216787894_item	3605598	et	4	main
riigis	doc_366216787894_item	3605599	et	3	main
peab	doc_366216787894_item	3605600	et	4	main
teadma	doc_366216787894_item	3605601	et	3	main
on	doc_366216787894_item	3605605	et	4	main
tulla	doc_366216787894_item	3605609	et	3	main
perega	doc_366216787894_item	3605611	et	3	main
tantsida	doc_366216787894_item	3605623	et	3	main
koht	doc_366216787894_item	3605627	et	3	main
eesti	doc_366216787896_item	3605638	et	4	main
eestlastest	doc_366216787896_item	3605650	et	4	main
laulurahva	doc_366216787896_item	3605651	et	3	main
essee	doc_366216787896_item	3605652	et	4	main
sõna	doc_366216787896_item	3605656	et	4	main
tuginema	doc_366216787896_item	3605664	et	3	main
lugemistekstis	doc_366216787896_item	3605667	et	3	main
faktidele	doc_366216787896_item	3605669	et	3	main
eestlastest	doc_366216787896_item	3605677	et	4	main
tahame	doc_366216787896_item	3605681	et	3	main
laulurahvast	doc_366216787896_item	3605683	et	4	main
me	doc_366216787896_item	3605687	et	4	main
võime	doc_366216787896_item	3605688	et	4	main
rääkida	doc_366216787896_item	3605690	et	3	main
kõik	doc_366216787896_item	3605692	et	4	main
me	doc_366216787896_item	3605693	et	4	main
teame	doc_366216787896_item	3605694	et	3	main
et	doc_366216787896_item	3605695	et	3	main
praegu	doc_366216787896_item	3605696	et	3	main
on	doc_366216787896_item	3605704	et	4	main
on	doc_366216787896_item	3605721	et	4	main
väga	doc_366216787896_item	3605722	et	3	main
pea	doc_366216787896_item	3605727	et	4	main
tööd	doc_366216787896_item	3605749	et	4	main
ka	doc_366216787896_item	3605752	et	3	main
aga	doc_366216787896_item	3605754	et	3	main
me	doc_366216787896_item	3605756	et	4	main
näeme	doc_366216787896_item	3605757	et	3	main
praegu	doc_366216787896_item	3605758	et	3	main
tore	doc_366216787896_item	3605768	et	3	main
tore	doc_366216787896_item	3605775	et	3	main
et	doc_366216787896_item	3605776	et	3	main
mis	doc_366216787896_item	3605807	et	4	main
oli	doc_366216787896_item	3605808	et	3	main
meeleolu	doc_366216787896_item	3605815	et	4	main
olulised	doc_366216787896_item	3605816	et	4	main
et	doc_366216787896_item	3605828	et	3	main
sotsiaalne	doc_366216787896_item	3605835	et	3	main
tegevus	doc_366216787896_item	3605836	et	4	main
siin	doc_366216787896_item	3605874	et	4	main
on	doc_366216787896_item	3605875	et	4	main
essee	doc_366216787899_item	3605889	et	4	main
keele	doc_366216787899_item	3605891	et	4	main
kui	doc_366216787899_item	3605892	et	3	main
essee	doc_366216787899_item	3605898	et	4	main
eestlastest	doc_366216787899_item	3605902	et	4	main
essee	doc_366216787899_item	3605904	et	4	main
300	doc_366216787899_item	3605906	et	2	main
arutlev	doc_366216787899_item	3605912	et	4	main
lugemistekstis	doc_366216787899_item	3605919	et	3	main
faktidele	doc_366216787899_item	3605921	et	3	main
on	doc_366216787899_item	3605923	et	4	main
soovitatav	doc_366216787899_item	3605924	et	4	main
illustreerida	doc_366216787899_item	3605925	et	3	main
väga	doc_366216787894_item	3605560	et	3	main
praegu	doc_366216787894_item	3605562	et	3	main
see	doc_366216787894_item	3605563	et	3	main
seotud	doc_366216787894_item	3605575	et	4	main
öelda	doc_366216787894_item	3605583	et	4	main
et	doc_366216787894_item	3605584	et	3	main
väga	doc_366216787894_item	3605585	et	3	main
on	doc_366216787894_item	3605588	et	4	main
iga	doc_366216787894_item	3605596	et	4	main
inimene	doc_366216787894_item	3605597	et	3	main
laulupidu	doc_366216787894_item	3605604	et	4	main
saad	doc_366216787894_item	3605608	et	4	main
sõbradega	doc_366216787894_item	3605612	et	4	main
see	doc_366216787894_item	3605613	et	3	main
annab	doc_366216787894_item	3605614	et	3	main
rõõmu	doc_366216787894_item	3605615	et	4	main
laulda	doc_366216787894_item	3605620	et	4	main
võib	doc_366216787894_item	3605621	et	3	main
olla	doc_366216787894_item	3605622	et	3	main
toimub	doc_366216787894_item	3605629	et	3	main
ka	doc_366216787894_item	3605633	et	3	main
väga	doc_366216787894_item	3605634	et	3	main
tähtis	doc_366216787894_item	3605635	et	4	main
keele	doc_366216787896_item	3605639	et	4	main
350	doc_366216787896_item	3605655	et	2	main
arutlev	doc_366216787896_item	3605660	et	4	main
ja	doc_366216787896_item	3605666	et	3	main
esitatud	doc_366216787896_item	3605668	et	4	main
arutleme	doc_366216787896_item	3605685	et	3	main
tallinnas	doc_366216787896_item	3605697	et	4	main
seal	doc_366216787896_item	3605709	et	4	main
inimesed	doc_366216787896_item	3605710	et	3	main
laulavad	doc_366216787896_item	3605718	et	4	main
sest	doc_366216787896_item	3605724	et	4	main
seda	doc_366216787896_item	3605729	et	3	main
rahvalaulu	doc_366216787896_item	3605881	et	4	main
see	doc_366216787896_item	3605882	et	3	main
on	doc_366216787896_item	3605883	et	4	main
nende	doc_366216787896_item	3605884	et	4	main
kultuur	doc_366216787896_item	3605885	et	3	main
ja	doc_366216787896_item	3605886	et	3	main
laulutraditsioon	doc_366216787896_item	3605887	et	3	main
teise	doc_366216787896_item	3605641	et	4	main
test	doc_366216787896_item	3605643	et	3	main
kirjutage	doc_366216787896_item	3605645	et	3	main
teemal	doc_366216787896_item	3605647	et	3	main
mis	doc_366216787896_item	3605648	et	4	main
teeb	doc_366216787896_item	3605649	et	3	main
essee	doc_366216787896_item	3605657	et	4	main
soovitatav	doc_366216787896_item	3605672	et	4	main
illustreerida	doc_366216787896_item	3605673	et	3	main
näidetega	doc_366216787896_item	3605674	et	3	main
mis	doc_366216787896_item	3605675	et	4	main
teeb	doc_366216787896_item	3605676	et	3	main
me	doc_366216787896_item	3605680	et	4	main
rääkida	doc_366216787896_item	3605682	et	3	main
toimuvad	doc_366216787896_item	3605698	et	4	main
traditsioonid	doc_366216787896_item	3605699	et	3	main
laulupeod	doc_366216787896_item	3605700	et	4	main
kohtuvad	doc_366216787896_item	3605711	et	4	main
rahavlaulu	doc_366216787896_item	3605719	et	4	main
see	doc_366216787896_item	3605720	et	3	main
inimesed	doc_366216787896_item	3605725	et	3	main
kaotada	doc_366216787896_item	3605728	et	3	main
varem	doc_366216787896_item	3605732	et	4	main
inimesed	doc_366216787896_item	3605733	et	3	main
elasid	doc_366216787896_item	3605734	et	4	main
sellega	doc_366216787896_item	3605735	et	3	main
laul	doc_366216787896_item	3605736	et	4	main
nii	doc_366216787896_item	3605748	et	3	main
pidutsedes	doc_366216787896_item	3605753	et	3	main
mida	doc_366216787896_item	3605755	et	4	main
on	doc_366216787896_item	3605767	et	4	main
austama	doc_366216787896_item	3605772	et	3	main
traditsioonid	doc_366216787896_item	3605774	et	3	main
praegu	doc_366216787896_item	3605777	et	3	main
on	doc_366216787896_item	3605804	et	4	main
see	doc_366216787896_item	3605805	et	3	main
saama	doc_366216787896_item	3605806	et	4	main
kultuuinähtu	doc_366216787896_item	3605825	et	4	main
ja	doc_366216787896_item	3605834	et	3	main
keele	doc_366216787899_item	3605894	et	4	main
teeb	doc_366216787899_item	3605901	et	3	main
peab	doc_366216787899_item	3605910	et	4	main
loengus	doc_366216787899_item	3605917	et	3	main
esitatud	doc_366216787899_item	3605920	et	4	main
ajast	doc_366216787899_item	3605934	et	4	main
kui	doc_366216787899_item	3605942	et	3	main
eestlased	doc_366216787899_item	3605945	et	3	main
laulurahvus	doc_366216787899_item	3605947	et	3	main
mis	doc_366216787899_item	3605952	et	4	main
peod	doc_366216787899_item	3605965	et	4	main
mehed	doc_366216787899_item	3605990	et	3	main
koorid	doc_366216787899_item	3605997	et	4	main
laulsid	doc_366216787899_item	3606000	et	4	main
naiskoorid	doc_366216787899_item	3606011	et	3	main
aga	doc_366216787899_item	3606014	et	3	main
1960	doc_366216787899_item	3606016	et	2	main
laulsid	doc_366216787899_item	3606019	et	4	main
ainult	doc_366216787899_item	3606023	et	4	main
aga	doc_366216787899_item	3606025	et	3	main
pärast	doc_366216787899_item	3606026	et	4	main
koor	doc_366216787899_item	3606027	et	4	main
tihti	doc_366216787899_item	3606028	et	3	main
oli	doc_366216787899_item	3606037	et	3	main
laulupidu	doc_366216787899_item	3606041	et	4	main
on	doc_366216787899_item	3606053	et	4	main
vene	doc_366216787899_item	3606063	et	4	main
pop	doc_366216787899_item	3606079	et	4	main
muusikat	doc_366216787899_item	3606080	et	3	main
keele	doc_366216787901_item	3606105	et	4	main
essee	doc_366216787901_item	3606120	et	4	main
üldistav	doc_366216787901_item	3606126	et	4	main
tuginema	doc_366216787901_item	3606127	et	3	main
loengus	doc_366216787901_item	3606128	et	3	main
soovitatav	doc_366216787901_item	3606135	et	4	main
kuulsin	doc_366216787901_item	3606139	et	3	main
ja	doc_366216787901_item	3606140	et	3	main
on	doc_366216787901_item	3606144	et	4	main
ei	doc_366216787896_item	3605726	et	4	main
oli	doc_366216787896_item	3605731	et	3	main
ja	doc_366216787896_item	3605737	et	3	main
on	doc_366216787896_item	3605739	et	4	main
eestlasi	doc_366216787896_item	3605741	et	3	main
nii	doc_366216787896_item	3605742	et	3	main
ka	doc_366216787896_item	3605745	et	3	main
heal	doc_366216787896_item	3605746	et	3	main
ajal	doc_366216787896_item	3605747	et	4	main
nad	doc_366216787896_item	3605770	et	3	main
peavad	doc_366216787896_item	3605771	et	4	main
vanad	doc_366216787896_item	3605773	et	3	main
toimuvad	doc_366216787896_item	3605778	et	4	main
tantsjad	doc_366216787896_item	3605797	et	4	main
muusika	doc_366216787896_item	3605802	et	4	main
ja	doc_366216787896_item	3605813	et	3	main
mulle	doc_366216787896_item	3605826	et	4	main
tundub	doc_366216787896_item	3605827	et	3	main
on	doc_366216787896_item	3605830	et	4	main
esteetiline	doc_366216787896_item	3605831	et	3	main
on	doc_366216787896_item	3605870	et	4	main
väga	doc_366216787896_item	3605871	et	3	main
oluline	doc_366216787896_item	3605872	et	4	main
et	doc_366216787896_item	3605873	et	3	main
eestlastest	doc_366216787896_item	3605880	et	4	main
mis	doc_366216787899_item	3605900	et	4	main
laulurahva	doc_366216787899_item	3605903	et	3	main
pikkus	doc_366216787899_item	3605905	et	4	main
350	doc_366216787899_item	3605907	et	2	main
sõna	doc_366216787899_item	3605908	et	4	main
analüüsiv	doc_366216787899_item	3605913	et	4	main
ja	doc_366216787899_item	3605914	et	3	main
väiteid	doc_366216787899_item	3605922	et	4	main
loovatud	doc_366216787899_item	3605930	et	3	main
muusikat	doc_366216787899_item	3605932	et	3	main
lauluvad	doc_366216787899_item	3605936	et	4	main
kõik	doc_366216787899_item	3605937	et	4	main
teavad	doc_366216787899_item	3605938	et	3	main
et	doc_366216787899_item	3605939	et	3	main
laud	doc_366216787899_item	3605944	et	4	main
on	doc_366216787899_item	3605953	et	4	main
oli	doc_366216787899_item	3605959	et	3	main
lauluväljakul	doc_366216787899_item	3605961	et	3	main
organiseerisid	doc_366216787899_item	3605963	et	4	main
erinevad	doc_366216787899_item	3605964	et	4	main
muusikat	doc_366216787899_item	3605996	et	3	main
tihti	doc_366216787899_item	3605998	et	3	main
lapsed	doc_366216787899_item	3605999	et	3	main
kaa	doc_366216787899_item	3606001	et	4	main
see	doc_366216787899_item	3606002	et	3	main
oli	doc_366216787899_item	3606003	et	3	main
lapsekoor	doc_366216787899_item	3606004	et	4	main
lastekoorid	doc_366216787899_item	3606005	et	3	main
laulsid	doc_366216787899_item	3606022	et	4	main
laulja	doc_366216787899_item	3606024	et	4	main
tartus	doc_366216787899_item	3606033	et	3	main
ja	doc_366216787899_item	3606034	et	3	main
tallinnas	doc_366216787899_item	3606035	et	4	main
see	doc_366216787899_item	3606036	et	3	main
täna	doc_366216787899_item	3606052	et	4	main
kõige	doc_366216787899_item	3606057	et	4	main
kui	doc_366216787899_item	3606068	et	3	main
kaasaaegne	doc_366216787899_item	3606075	et	3	main
rock	doc_366216787899_item	3606077	et	4	main
või	doc_366216787899_item	3606078	et	4	main
meil	doc_366216787899_item	3606085	et	4	main
eesti	doc_366216787901_item	3606101	et	4	main
teise	doc_366216787901_item	3606104	et	4	main
teeb	doc_366216787901_item	3606112	et	3	main
laulurahva	doc_366216787901_item	3606114	et	3	main
pikkus	doc_366216787901_item	3606116	et	4	main
350	doc_366216787901_item	3606118	et	2	main
sõna	doc_366216787901_item	3606119	et	4	main
analüüsiv	doc_366216787901_item	3606124	et	4	main
ja	doc_366216787901_item	3606125	et	3	main
esitatud	doc_366216787901_item	3606131	et	4	main
faktidele	doc_366216787901_item	3606132	et	3	main
eestlased	doc_366216787901_item	3606143	et	3	main
keel	doc_366216787901_item	3606156	et	4	main
tants	doc_366216787896_item	3605738	et	3	main
saatnud	doc_366216787896_item	3605740	et	4	main
halva	doc_366216787896_item	3605743	et	4	main
kui	doc_366216787896_item	3605744	et	3	main
tehes	doc_366216787896_item	3605750	et	3	main
kui	doc_366216787896_item	3605751	et	3	main
erinevate	doc_366216787896_item	3605763	et	4	main
stiile	doc_366216787896_item	3605764	et	3	main
muusikat	doc_366216787896_item	3605765	et	3	main
see	doc_366216787896_item	3605766	et	3	main
teeb	doc_366216787896_item	3605781	et	3	main
eestlastest	doc_366216787896_item	3605782	et	4	main
laulurahva	doc_366216787896_item	3605783	et	3	main
ka	doc_366216787896_item	3605784	et	3	main
seal	doc_366216787896_item	3605785	et	4	main
inimesed	doc_366216787896_item	3605786	et	3	main
puhkavad	doc_366216787896_item	3605787	et	4	main
oma	doc_366216787896_item	3605788	et	4	main
probleemidest	doc_366216787896_item	3605789	et	3	main
veetavad	doc_366216787896_item	3605790	et	4	main
oma	doc_366216787896_item	3605791	et	4	main
vaba	doc_366216787896_item	3605792	et	4	main
aeg	doc_366216787896_item	3605793	et	3	main
niimoodi	doc_366216787896_item	3605794	et	3	main
hästi	doc_366216787896_item	3605795	et	3	main
et	doc_366216787896_item	3605796	et	3	main
eesti	doc_366216787896_item	3605799	et	4	main
riided	doc_366216787896_item	3605801	et	3	main
stiil	doc_366216787896_item	3605803	et	3	main
pidulik	doc_366216787896_item	3605812	et	3	main
nii	doc_366216787896_item	3605817	et	3	main
laulmine	doc_366216787896_item	3605822	et	4	main
on	doc_366216787896_item	3605823	et	4	main
tähelepanuväärne	doc_366216787896_item	3605824	et	3	main
väljendusvahed	doc_366216787896_item	3605833	et	3	main
ja	doc_366216787896_item	3605837	et	3	main
see	doc_366216787896_item	3605838	et	3	main
teeb	doc_366216787896_item	3605839	et	3	main
eestlastest	doc_366216787896_item	3605840	et	4	main
laulurahva	doc_366216787896_item	3605841	et	3	main
inimesed	doc_366216787896_item	3605842	et	3	main
laulavad	doc_366216787896_item	3605843	et	4	main
ajal	doc_366216787896_item	3605845	et	4	main
kõik	doc_366216787896_item	3605844	et	4	main
oma	doc_366216787896_item	3605846	et	4	main
lastele	doc_366216787896_item	3605847	et	4	main
töötades	doc_366216787896_item	3605848	et	3	main
kui	doc_366216787896_item	3605849	et	3	main
kuulavad	doc_366216787896_item	3605850	et	4	main
muusika	doc_366216787896_item	3605851	et	4	main
ja	doc_366216787896_item	3605852	et	3	main
oma	doc_366216787896_item	3605853	et	4	main
mõttes	doc_366216787896_item	3605854	et	3	main
ka	doc_366216787896_item	3605855	et	3	main
üle-eestiline	doc_366216787896_item	3605856	et	3	main
laulupidu	doc_366216787896_item	3605857	et	4	main
on	doc_366216787896_item	3605858	et	4	main
ka	doc_366216787896_item	3605859	et	3	main
praegusel	doc_366216787896_item	3605860	et	3	main
ajal	doc_366216787896_item	3605861	et	4	main
kõige	doc_366216787896_item	3605862	et	4	main
tähelepanuväärsem	doc_366216787896_item	3605863	et	4	main
ja	doc_366216787896_item	3605864	et	3	main
see	doc_366216787896_item	3605869	et	3	main
rahvusluse	doc_366216787896_item	3605866	et	4	main
see	doc_366216787896_item	3605877	et	3	main
eesti	doc_366216787899_item	3605890	et	4	main
teise	doc_366216787899_item	3605893	et	4	main
teemal	doc_366216787899_item	3605899	et	3	main
olema	doc_366216787899_item	3605911	et	4	main
ja	doc_366216787899_item	3605918	et	3	main
ajast	doc_366216787899_item	3605928	et	4	main
kergemaks	doc_366216787899_item	3605940	et	4	main
töötada	doc_366216787899_item	3605941	et	3	main
me	doc_366216787899_item	3605948	et	4	main
saame	doc_366216787899_item	3605949	et	4	main
eesti	doc_366216787899_item	3605954	et	4	main
pealinnas	doc_366216787899_item	3605955	et	4	main
konserdid	doc_366216787899_item	3605966	et	4	main
ja	doc_366216787899_item	3605967	et	3	main
muidugi	doc_366216787899_item	3605968	et	4	main
nad	doc_366216787899_item	3605969	et	3	main
laulsid	doc_366216787899_item	3605970	et	4	main
kui	doc_366216787899_item	3605971	et	3	main
lauluväljakul	doc_366216787899_item	3605972	et	3	main
oli	doc_366216787899_item	3605973	et	3	main
pidu	doc_366216787899_item	3605974	et	4	main
inimesed	doc_366216787899_item	3605975	et	3	main
laulsid	doc_366216787899_item	3605976	et	4	main
üksi	doc_366216787899_item	3605977	et	4	main
kooris	doc_366216787899_item	3605978	et	4	main
muusika	doc_366216787899_item	3605979	et	4	main
folkloor	doc_366216787899_item	3605980	et	4	main
oli	doc_366216787899_item	3605981	et	3	main
muusika	doc_366216787899_item	3605982	et	4	main
ja	doc_366216787899_item	3605983	et	3	main
tantsu	doc_366216787899_item	3605984	et	4	main
tihti	doc_366216787899_item	3605985	et	3	main
naised	doc_366216787899_item	3605986	et	3	main
laulsid	doc_366216787899_item	3605987	et	4	main
regilaulud	doc_366216787899_item	3605988	et	3	main
kõigele	doc_366216787899_item	3605992	et	4	main
ansamblid	doc_366216787899_item	3605994	et	3	main
laulupidudel	doc_366216787899_item	3606007	et	4	main
osalema	doc_366216787899_item	3606008	et	3	main
aastal	doc_366216787899_item	3606010	et	3	main
1933	doc_366216787899_item	3606012	et	2	main
poistekoorid	doc_366216787899_item	3606015	et	3	main
kui	doc_366216787899_item	3606018	et	3	main
laulupeod	doc_366216787899_item	3606029	et	4	main
kahes	doc_366216787899_item	3606031	et	4	main
linnas	doc_366216787899_item	3606032	et	4	main
raske	doc_366216787899_item	3606039	et	4	main
korraldada	doc_366216787899_item	3606040	et	3	main
sest	doc_366216787899_item	3606042	et	4	main
kui	doc_366216787899_item	3606043	et	3	main
esimene	doc_366216787899_item	3606044	et	3	main
laulupidu	doc_366216787899_item	3606045	et	4	main
oli	doc_366216787899_item	3606046	et	3	main
ka	doc_366216787899_item	3606054	et	3	main
muusikat	doc_366216787899_item	3606055	et	3	main
popularsem	doc_366216787899_item	3606058	et	4	main
muju	doc_366216787899_item	3606064	et	4	main
aga	doc_366216787899_item	3606065	et	3	main
laul	doc_366216787899_item	3606069	et	4	main
on	doc_366216787899_item	3606070	et	4	main
muusika	doc_366216787899_item	3606081	et	4	main
näidetega	doc_366216787899_item	3605926	et	3	main
vanast	doc_366216787899_item	3605927	et	3	main
laulud	doc_366216787899_item	3605931	et	3	main
vanast	doc_366216787899_item	3605933	et	3	main
inimesed	doc_366216787899_item	3605935	et	3	main
vaadata	doc_366216787899_item	3605950	et	4	main
lauluväljakule	doc_366216787899_item	3605951	et	3	main
tallinnas	doc_366216787899_item	3605956	et	4	main
nad	doc_366216787899_item	3605962	et	3	main
puulmalaulikud	doc_366216787899_item	3605991	et	4	main
laulud	doc_366216787899_item	3605995	et	3	main
1933	doc_366216787899_item	3606009	et	2	main
aastal	doc_366216787899_item	3606013	et	3	main
aastal	doc_366216787899_item	3606017	et	3	main
siis	doc_366216787899_item	3606021	et	3	main
korraldatatud	doc_366216787899_item	3606047	et	4	main
see	doc_366216787899_item	3606048	et	3	main
oli	doc_366216787899_item	3606049	et	3	main
rahvusliku	doc_366216787899_item	3606050	et	3	main
popularne	doc_366216787899_item	3606056	et	4	main
on	doc_366216787899_item	3606059	et	4	main
uus	doc_366216787899_item	3606060	et	3	main
rahvalaul	doc_366216787899_item	3606061	et	4	main
noortele	doc_366216787899_item	3606066	et	3	main
meeldib	doc_366216787899_item	3606067	et	3	main
on	doc_366216787899_item	3606074	et	4	main
aitab	doc_366216787899_item	3606084	et	3	main
kirjutamine	doc_366216787901_item	3606107	et	4	main
essee	doc_366216787901_item	3606109	et	4	main
eestlastest	doc_366216787901_item	3606113	et	4	main
olema	doc_366216787901_item	3606122	et	4	main
arutlev	doc_366216787901_item	3606123	et	4	main
illustreerida	doc_366216787901_item	3606136	et	3	main
näidetega	doc_366216787901_item	3606137	et	3	main
ma	doc_366216787901_item	3606138	et	3	main
tean	doc_366216787901_item	3606141	et	3	main
laulurahvas	doc_366216787901_item	3606145	et	4	main
meloodiline	doc_366216787901_item	3606159	et	3	main
lapsele	doc_366216787901_item	3606197	et	4	main
pealine	doc_366216787901_item	3606309	et	4	main
laul	doc_366216787901_item	3606282	et	4	main
ärkamisega	doc_366216787901_item	3606263	et	4	main
seotud	doc_366216787901_item	3606261	et	4	main
oli	doc_366216787901_item	3606260	et	3	main
see	doc_366216787901_item	3606259	et	3	main
ka	doc_366216787901_item	3606258	et	3	main
laulupidu	doc_366216787901_item	3606251	et	4	main
seal	doc_366216787901_item	3606241	et	4	main
sai	doc_366216787901_item	3606224	et	4	main
laul	doc_366216787901_item	3606223	et	4	main
tulid	doc_366216787901_item	3606217	et	4	main
midagi	doc_366216787901_item	3606212	et	4	main
unusta	doc_366216787902_item	3606583	et	4	main
aastaid	doc_366216787902_item	3606578	et	4	main
nad	doc_366216787902_item	3606572	et	3	main
emakeelt	doc_366216787902_item	3606559	et	4	main
mitte	doc_366216787902_item	3606555	et	3	main
laulud	doc_366216787902_item	3606552	et	3	main
mõju	doc_366216787902_item	3606549	et	4	main
riiki	doc_366216787902_item	3606548	et	4	main
rahvas	doc_366216787902_item	3606535	et	4	main
armastab	doc_366216787902_item	3606533	et	3	main
mu	doc_366216787902_item	3606524	et	3	main
koidulale	doc_366216787902_item	3606521	et	3	main
ja	doc_366216787902_item	3606515	et	3	main
võimaldasid	doc_366216787902_item	3606496	et	4	main
trükiti	doc_366216787902_item	3606489	et	3	main
laulud	doc_366216787902_item	3606487	et	3	main
uued	doc_366216787902_item	3606486	et	3	main
nad	doc_366216787902_item	3606480	et	3	main
tekkisid	doc_366216787902_item	3606476	et	4	main
laul	doc_366216787902_item	3606470	et	4	main
levis	doc_366216787902_item	3606469	et	4	main
sajandil	doc_366216787902_item	3606468	et	3	main
ka	doc_366216787902_item	3606464	et	3	main
laulsid	doc_366216787902_item	3606455	et	4	main
juba	doc_366216787902_item	3606446	et	3	main
laulub	doc_366216787902_item	3606436	et	4	main
koorega	doc_366216787902_item	3606434	et	3	main
koos	doc_366216787902_item	3606433	et	4	main
inimene	doc_366216787902_item	3606432	et	3	main
meeldib	doc_366216787899_item	3605993	et	3	main
hakkasid	doc_366216787899_item	3606006	et	4	main
koor	doc_366216787899_item	3606020	et	4	main
korraldati	doc_366216787899_item	3606030	et	3	main
väga	doc_366216787899_item	3606038	et	3	main
liikumine	doc_366216787899_item	3606051	et	4	main
läti	doc_366216787899_item	3606062	et	4	main
vana	doc_366216787899_item	3606071	et	4	main
aga	doc_366216787899_item	3606072	et	3	main
muusikat	doc_366216787899_item	3606073	et	3	main
näiteks	doc_366216787899_item	3606076	et	4	main
elada	doc_366216787899_item	3606086	et	3	main
ja	doc_366216787899_item	3606087	et	3	main
naerata	doc_366216787899_item	3606088	et	4	main
essee	doc_366216787901_item	3606100	et	4	main
keele	doc_366216787901_item	3606102	et	4	main
kui	doc_366216787901_item	3606103	et	3	main
kirjutage	doc_366216787901_item	3606108	et	3	main
mis	doc_366216787901_item	3606111	et	4	main
essee	doc_366216787901_item	3606115	et	4	main
300	doc_366216787901_item	3606117	et	2	main
lugemistekstis	doc_366216787901_item	3606130	et	3	main
väiteid	doc_366216787901_item	3606133	et	4	main
on	doc_366216787901_item	3606134	et	4	main
et	doc_366216787901_item	3606142	et	3	main
eesti	doc_366216787901_item	3606155	et	4	main
rahva	doc_366216787901_item	3606308	et	3	main
nende	doc_366216787901_item	3606307	et	4	main
see	doc_366216787901_item	3606305	et	3	main
lõbusad	doc_366216787901_item	3606300	et	3	main
on	doc_366216787901_item	3606298	et	4	main
eestlased	doc_366216787901_item	3606297	et	3	main
poistekoorid	doc_366216787901_item	3606293	et	3	main
eesti	doc_366216787901_item	3606281	et	4	main
tüüpiline	doc_366216787901_item	3606280	et	3	main
et	doc_366216787901_item	3606279	et	3	main
eestis	doc_366216787901_item	3606264	et	3	main
rahvusliku	doc_366216787901_item	3606262	et	3	main
mis	doc_366216787901_item	3606252	et	4	main
19	doc_366216787901_item	3606247	et	2	main
oli	doc_366216787901_item	3606245	et	3	main
nende	doc_366216787901_item	3606237	et	4	main
tekkisid	doc_366216787901_item	3606226	et	4	main
saksa-	doc_366216787901_item	3606220	et	4	main
tantsivad	doc_366216787901_item	3606210	et	4	main
või	doc_366216787901_item	3606209	et	4	main
koos	doc_366216787901_item	3606208	et	4	main
töötavad	doc_366216787901_item	3606207	et	4	main
inimesi	doc_366216787901_item	3606206	et	4	main
palju	doc_366216787901_item	3606205	et	4	main
kui	doc_366216787901_item	3606204	et	3	main
kohustuslik	doc_366216787901_item	3606203	et	3	main
on	doc_366216787901_item	3606202	et	4	main
mis	doc_366216787901_item	3606201	et	4	main
rüütmi	doc_366216787901_item	3606200	et	4	main
ma	doc_366216787902_item	3606581	et	3	main
lauldi	doc_366216787902_item	3606576	et	3	main
lauludest	doc_366216787902_item	3606574	et	3	main
aastaid	doc_366216787902_item	3606563	et	4	main
möödusid	doc_366216787902_item	3606561	et	4	main
juba	doc_366216787902_item	3606560	et	3	main
unustda	doc_366216787902_item	3606556	et	4	main
aitasid	doc_366216787902_item	3606553	et	4	main
ja	doc_366216787902_item	3606551	et	3	main
laulusega	doc_366216787902_item	3606538	et	4	main
eesti	doc_366216787902_item	3606534	et	4	main
laul	doc_366216787902_item	3606518	et	4	main
kõik	doc_366216787902_item	3606512	et	4	main
aitas	doc_366216787899_item	3606082	et	3	main
ja	doc_366216787899_item	3606083	et	3	main
ta	doc_366216787899_item	3606089	et	4	main
aitab	doc_366216787899_item	3606090	et	3	main
meil	doc_366216787899_item	3606091	et	4	main
suhtuda	doc_366216787899_item	3606092	et	3	main
teine	doc_366216787899_item	3606093	et	3	main
teisega	doc_366216787899_item	3606094	et	4	main
ta	doc_366216787899_item	3606095	et	4	main
aitab	doc_366216787899_item	3606096	et	3	main
meil	doc_366216787899_item	3606097	et	4	main
olla	doc_366216787899_item	3606098	et	3	main
test	doc_366216787901_item	3606106	et	3	main
teemal	doc_366216787901_item	3606110	et	3	main
peab	doc_366216787901_item	3606121	et	4	main
ja	doc_366216787901_item	3606129	et	3	main
eestlastest	doc_366216787901_item	3606151	et	4	main
laulurahva	doc_366216787901_item	3606152	et	3	main
arvan	doc_366216787901_item	3606153	et	3	main
et	doc_366216787901_item	3606154	et	3	main
keel	doc_366216787901_item	3606160	et	4	main
sõnu	doc_366216787901_item	3606161	et	4	main
laulda	doc_366216787901_item	3606162	et	4	main
on	doc_366216787901_item	3606163	et	4	main
üsna	doc_366216787901_item	3606164	et	3	main
lihtsalt	doc_366216787901_item	3606165	et	4	main
võib-olla	doc_366216787901_item	3606166	et	3	main
see	doc_366216787901_item	3606167	et	3	main
on	doc_366216787901_item	3606168	et	4	main
genotüüpiliselt	doc_366216787901_item	3606169	et	4	main
nii	doc_366216787901_item	3606170	et	3	main
et	doc_366216787901_item	3606171	et	3	main
eestlased	doc_366216787901_item	3606172	et	3	main
hästi	doc_366216787901_item	3606173	et	3	main
laulavad	doc_366216787901_item	3606174	et	4	main
laul	doc_366216787901_item	3606175	et	4	main
oli	doc_366216787901_item	3606176	et	3	main
alati	doc_366216787901_item	3606177	et	4	main
informatsioonivahend	doc_366216787901_item	3606178	et	3	main
mingid	doc_366216787901_item	3606179	et	4	main
sündmusid	doc_366216787901_item	3606180	et	4	main
eeposid	doc_366216787901_item	3606181	et	4	main
juttud	doc_366216787901_item	3606182	et	4	main
olid	doc_366216787901_item	3606183	et	4	main
laule	doc_366216787901_item	3606184	et	4	main
alused	doc_366216787901_item	3606185	et	4	main
ka	doc_366216787901_item	3606186	et	3	main
lauldes	doc_366216787901_item	3606187	et	3	main
inimesed	doc_366216787901_item	3606188	et	3	main
võisid	doc_366216787901_item	3606189	et	4	main
oma	doc_366216787901_item	3606190	et	4	main
tunde	doc_366216787901_item	3606191	et	4	main
avastada	doc_366216787901_item	3606192	et	3	main
näiteks	doc_366216787901_item	3606193	et	4	main
miks	doc_366216787901_item	3606146	et	4	main
räägitakse	doc_366216787901_item	3606147	et	3	main
nii	doc_366216787901_item	3606148	et	3	main
mis	doc_366216787901_item	3606149	et	4	main
teeb	doc_366216787901_item	3606150	et	3	main
on	doc_366216787901_item	3606157	et	4	main
väga	doc_366216787901_item	3606158	et	3	main
ema	doc_366216787901_item	3606194	et	4	main
laulis	doc_366216787901_item	3606195	et	4	main
oma	doc_366216787901_item	3606196	et	4	main
et	doc_366216787901_item	3606304	et	3	main
ja	doc_366216787901_item	3606301	et	3	main
nii	doc_366216787901_item	3606299	et	3	main
et	doc_366216787901_item	3606296	et	3	main
siis	doc_366216787901_item	3606294	et	3	main
meeste-	doc_366216787901_item	3606291	et	4	main
on	doc_366216787901_item	3606290	et	4	main
populaarsed	doc_366216787901_item	3606289	et	3	main
eriti	doc_366216787901_item	3606288	et	3	main
ürituseks	doc_366216787901_item	3606257	et	4	main
põnevaks	doc_366216787901_item	3606256	et	3	main
esimene	doc_366216787901_item	3606250	et	3	main
kohustuslik	doc_366216787901_item	3606246	et	3	main
see	doc_366216787901_item	3606244	et	3	main
regulaarselt	doc_366216787901_item	3606240	et	4	main
kirikukoolides	doc_366216787901_item	3606236	et	3	main
lapsed	doc_366216787901_item	3606234	et	3	main
rikkumiseks	doc_366216787901_item	3606225	et	4	main
vene-	doc_366216787901_item	3606219	et	4	main
muud	doc_366216787901_item	3606213	et	4	main
aga	doc_366216787902_item	3606580	et	3	main
mida	doc_366216787902_item	3606575	et	4	main
lauluvad	doc_366216787902_item	3606568	et	4	main
praegu	doc_366216787902_item	3606566	et	3	main
ajaloo	doc_366216787902_item	3606558	et	4	main
eestlastele	doc_366216787902_item	3606554	et	4	main
all	doc_366216787902_item	3606550	et	3	main
palju	doc_366216787902_item	3606532	et	4	main
isamaa	doc_366216787902_item	3606523	et	4	main
kõige	doc_366216787902_item	3606516	et	4	main
venemaalt	doc_366216787902_item	3606484	et	3	main
tulid	doc_366216787902_item	3606481	et	4	main
rahvalaulud	doc_366216787902_item	3606479	et	3	main
uued	doc_366216787902_item	3606477	et	3	main
xix	doc_366216787902_item	3606474	et	4	main
kirikus	doc_366216787902_item	3606465	et	3	main
eestlased	doc_366216787902_item	3606451	et	3	main
näha	doc_366216787902_item	3606444	et	3	main
üks	doc_366216787902_item	3606440	et	3	main
kord	doc_366216787902_item	3606439	et	4	main
ja	doc_366216787902_item	3606438	et	3	main
koor	doc_366216787902_item	3606437	et	4	main
regilaulud	doc_366216787902_item	3606430	et	3	main
koores	doc_366216787902_item	3606427	et	4	main
kahekesi	doc_366216787902_item	3606425	et	3	main
või	doc_366216787902_item	3606418	et	4	main
süüja	doc_366216787902_item	3606417	et	4	main
regilaul	doc_366216787902_item	3606392	et	4	main
ajaloo	doc_366216787902_item	3606388	et	4	main
hommikul	doc_366216787902_item	3606372	et	3	main
õhtul	doc_366216787902_item	3606371	et	3	main
ja	doc_366216787902_item	3606360	et	3	main
teeb	doc_366216787902_item	3606351	et	3	main
soovitatav	doc_366216787902_item	3606347	et	4	main
faktidele	doc_366216787902_item	3606344	et	3	main
peab	doc_366216787902_item	3606333	et	4	main
pikkus	doc_366216787902_item	3606328	et	4	main
teeb	doc_366216787902_item	3606324	et	3	main
kirjutamine	doc_366216787902_item	3606319	et	4	main
lastele	doc_366216787903_item	3606676	et	4	main
miks	doc_366216787903_item	3606663	et	4	main
teevad	doc_366216787903_item	3606662	et	3	main
ei	doc_366216787903_item	3606661	et	4	main
inimesed	doc_366216787903_item	3606660	et	3	main
see	doc_366216787903_item	3606655	et	3	main
mõnikord	doc_366216787903_item	3606649	et	3	main
eestis	doc_366216787903_item	3606637	et	3	main
tuginema	doc_366216787903_item	3606622	et	3	main
essee	doc_366216787903_item	3606615	et	4	main
sõna	doc_366216787903_item	3606614	et	4	main
pikkus	doc_366216787903_item	3606611	et	4	main
mis	doc_366216787903_item	3606606	et	4	main
laulmine	doc_366216787901_item	3606198	et	4	main
annab	doc_366216787901_item	3606199	et	3	main
printsiip	doc_366216787901_item	3606310	et	3	main
on	doc_366216787901_item	3606306	et	4	main
arvan	doc_366216787901_item	3606295	et	3	main
ja	doc_366216787901_item	3606292	et	3	main
ilma	doc_366216787901_item	3606286	et	4	main
huvitav	doc_366216787901_item	3606278	et	4	main
on	doc_366216787901_item	3606277	et	4	main
see	doc_366216787901_item	3606276	et	3	main
traditsiooniliseks	doc_366216787901_item	3606255	et	4	main
korraldati	doc_366216787901_item	3606249	et	3	main
salmikuid	doc_366216787901_item	3606243	et	4	main
kirikus	doc_366216787901_item	3606239	et	3	main
õppisid	doc_366216787901_item	3606235	et	4	main
et	doc_366216787901_item	3606233	et	3	main
vaja	doc_366216787901_item	3606231	et	4	main
rotsi-	doc_366216787901_item	3606218	et	4	main
või	doc_366216787901_item	3606211	et	4	main
ei	doc_366216787902_item	3606582	et	4	main
erinevad	doc_366216787902_item	3606573	et	4	main
rahvalaulud	doc_366216787902_item	3606569	et	3	main
eestlased	doc_366216787902_item	3606567	et	3	main
ka	doc_366216787902_item	3606565	et	3	main
tese	doc_366216787902_item	3606547	et	4	main
eestlased	doc_366216787902_item	3606546	et	3	main
väljendasid	doc_366216787902_item	3606539	et	4	main
oma	doc_366216787902_item	3606536	et	4	main
kui	doc_366216787902_item	3606531	et	3	main
laul	doc_366216787902_item	3606529	et	4	main
rõõm	doc_366216787902_item	3606527	et	3	main
ja	doc_366216787902_item	3606526	et	3	main
õnn	doc_366216787902_item	3606525	et	3	main
tähtsam	doc_366216787902_item	3606517	et	4	main
koos	doc_366216787902_item	3606513	et	4	main
laulsid	doc_366216787902_item	3606511	et	4	main
tulid	doc_366216787902_item	3606509	et	4	main
eestlased	doc_366216787902_item	3606508	et	3	main
laulupidu	doc_366216787902_item	3606507	et	4	main
esimene	doc_366216787902_item	3606506	et	3	main
toimus	doc_366216787902_item	3606505	et	3	main
tartus	doc_366216787902_item	3606504	et	3	main
aastal	doc_366216787902_item	3606503	et	3	main
1869	doc_366216787902_item	3606502	et	2	main
ärkamisaeg	doc_366216787902_item	3606501	et	3	main
algas	doc_366216787902_item	3606500	et	3	main
sajandil	doc_366216787902_item	3606499	et	3	main
elada	doc_366216787902_item	3606494	et	3	main
eesti	doc_366216787902_item	3606492	et	4	main
laulud	doc_366216787902_item	3606490	et	3	main
need	doc_366216787902_item	3606485	et	3	main
riimilised	doc_366216787902_item	3606478	et	4	main
xiix	doc_366216787902_item	3606467	et	4	main
ainult	doc_366216787902_item	3606454	et	4	main
mitte	doc_366216787902_item	3606453	et	3	main
nad	doc_366216787902_item	3606452	et	3	main
et	doc_366216787902_item	3606445	et	3	main
ajaloost	doc_366216787902_item	3606442	et	4	main
tegid	doc_366216787902_item	3606416	et	4	main
on	doc_366216787902_item	3606393	et	4	main
rahvalaul	doc_366216787902_item	3606391	et	4	main
vanem	doc_366216787902_item	3606390	et	4	main
mõjuvad	doc_366216787902_item	3606377	et	4	main
laulud	doc_366216787902_item	3606376	et	3	main
eestis	doc_366216787902_item	3606375	et	3	main
päeval	doc_366216787902_item	3606374	et	3	main
ja	doc_366216787902_item	3606373	et	3	main
kuulame	doc_366216787902_item	3606369	et	4	main
meie	doc_366216787902_item	3606365	et	4	main
ei	doc_366216787902_item	3606363	et	4	main
mis	doc_366216787902_item	3606350	et	4	main
näidetega	doc_366216787902_item	3606349	et	3	main
illustreerida	doc_366216787902_item	3606348	et	3	main
väiteid	doc_366216787902_item	3606345	et	4	main
olema	doc_366216787902_item	3606334	et	4	main
laulurahva	doc_366216787902_item	3606326	et	3	main
essee	doc_366216787902_item	3606321	et	4	main
test	doc_366216787902_item	3606318	et	3	main
laulmises	doc_366216787901_item	3606303	et	4	main
geniaalsed	doc_366216787901_item	3606302	et	3	main
pillesaateta	doc_366216787901_item	3606287	et	4	main
koorilaul	doc_366216787901_item	3606285	et	4	main
on	doc_366216787901_item	3606284	et	4	main
see	doc_366216787901_item	3606283	et	3	main
laulda	doc_366216787901_item	3606275	et	4	main
saavad	doc_366216787901_item	3606274	et	4	main
ja	doc_366216787901_item	3606273	et	3	main
armastavad	doc_366216787901_item	3606272	et	4	main
eestlased	doc_366216787901_item	3606271	et	3	main
laulumeelelahetusi	doc_366216787901_item	3606270	et	4	main
erinevaid	doc_366216787901_item	3606269	et	4	main
ja	doc_366216787901_item	3606268	et	3	main
festivali	doc_366216787901_item	3606267	et	4	main
palju	doc_366216787901_item	3606266	et	4	main
toimuvad	doc_366216787901_item	3606265	et	4	main
hiljemalt	doc_366216787901_item	3606254	et	3	main
sai	doc_366216787901_item	3606253	et	4	main
sajandil	doc_366216787901_item	3606248	et	3	main
lauldi	doc_366216787901_item	3606242	et	3	main
vanemad	doc_366216787901_item	3606238	et	4	main
öelda	doc_366216787901_item	3606232	et	4	main
on	doc_366216787901_item	3606230	et	4	main
rütmid	doc_366216787901_item	3606229	et	3	main
motiivid	doc_366216787901_item	3606228	et	3	main
uued	doc_366216787901_item	3606227	et	3	main
eesti	doc_366216787901_item	3606222	et	4	main
sõdurid	doc_366216787901_item	3606221	et	3	main
eestisse	doc_366216787901_item	3606216	et	4	main
kui	doc_366216787901_item	3606215	et	3	main
hiljemalt	doc_366216787901_item	3606214	et	3	main
on	doc_366216787902_item	3606585	et	4	main
rahvalaulud	doc_366216787902_item	3606584	et	3	main
tagasi	doc_366216787902_item	3606579	et	3	main
tuhat	doc_366216787902_item	3606577	et	4	main
me	doc_366216787902_item	3606592	et	4	main
laulurahva	doc_366216787902_item	3606593	et	3	main
oleme	doc_366216787902_item	3606591	et	3	main
seepärast	doc_366216787902_item	3606590	et	3	main
veres	doc_366216787902_item	3606588	et	3	main
hingas	doc_366216787902_item	3606589	et	3	main
eestlase	doc_366216787902_item	3606587	et	3	main
iga	doc_366216787902_item	3606586	et	4	main
olla	doc_366216787902_item	3606571	et	3	main
võib	doc_366216787902_item	3606570	et	3	main
aga	doc_366216787902_item	3606564	et	3	main
palju	doc_366216787902_item	3606562	et	4	main
nende	doc_366216787902_item	3606557	et	4	main
elasid	doc_366216787902_item	3606545	et	4	main
aeg	doc_366216787902_item	3606544	et	3	main
pikk	doc_366216787902_item	3606543	et	4	main
mõtted	doc_366216787902_item	3606542	et	3	main
oma	doc_366216787902_item	3606541	et	4	main
eestlased	doc_366216787902_item	3606540	et	3	main
maa	doc_366216787902_item	3606537	et	4	main
näitis	doc_366216787902_item	3606530	et	4	main
see	doc_366216787902_item	3606528	et	3	main
mu	doc_366216787902_item	3606522	et	3	main
l	doc_366216787902_item	3606520	et	4	main
kuulus	doc_366216787902_item	3606519	et	4	main
rahvalaulud	doc_366216787902_item	3606514	et	3	main
laulud	doc_366216787902_item	3606495	et	3	main
rahvale	doc_366216787902_item	3606493	et	3	main
aitasid	doc_366216787902_item	3606491	et	4	main
juba	doc_366216787902_item	3606488	et	3	main
ja	doc_366216787902_item	3606466	et	3	main
inimesed	doc_366216787902_item	3606461	et	3	main
keskel	doc_366216787902_item	3606459	et	3	main
laulsid	doc_366216787902_item	3606450	et	4	main
tagasi	doc_366216787902_item	3606449	et	3	main
tuhat	doc_366216787902_item	3606447	et	4	main
on	doc_366216787902_item	3606443	et	4	main
inimene	doc_366216787902_item	3606441	et	3	main
kord	doc_366216787902_item	3606435	et	4	main
tavaliselt	doc_366216787902_item	3606428	et	4	main
ja	doc_366216787902_item	3606386	et	3	main
väga	doc_366216787902_item	3606384	et	3	main
elu	doc_366216787902_item	3606366	et	4	main
mõista	doc_366216787902_item	3606364	et	4	main
maailmas	doc_366216787902_item	3606355	et	3	main
praegu	doc_366216787902_item	3606354	et	3	main
laulurahva	doc_366216787902_item	3606353	et	3	main
eestlastest	doc_366216787902_item	3606352	et	4	main
on	doc_366216787902_item	3606346	et	4	main
esitatud	doc_366216787902_item	3606343	et	4	main
lugemistekstis	doc_366216787902_item	3606342	et	3	main
ja	doc_366216787902_item	3606341	et	3	main
loengus	doc_366216787902_item	3606340	et	3	main
tuginema	doc_366216787902_item	3606339	et	3	main
üldistav	doc_366216787902_item	3606338	et	4	main
ja	doc_366216787902_item	3606337	et	3	main
essee	doc_366216787902_item	3606332	et	4	main
eestlastest	doc_366216787902_item	3606325	et	4	main
teemal	doc_366216787902_item	3606322	et	3	main
juba	doc_366216787903_item	3606671	et	3	main
kui	doc_366216787903_item	3606659	et	3	main
ja	doc_366216787903_item	3606654	et	3	main
hakkavad	doc_366216787903_item	3606651	et	4	main
siin	doc_366216787903_item	3606642	et	4	main
traditsioon	doc_366216787903_item	3606641	et	3	main
huvitav	doc_366216787903_item	3606640	et	4	main
väga	doc_366216787903_item	3606639	et	3	main
eestlastest	doc_366216787903_item	3606635	et	4	main
mis	doc_366216787903_item	3606633	et	4	main
soovitatav	doc_366216787903_item	3606630	et	4	main
väiteid	doc_366216787903_item	3606628	et	4	main
faktidele	doc_366216787903_item	3606627	et	3	main
peab	doc_366216787903_item	3606616	et	4	main
essee	doc_366216787903_item	3606604	et	4	main
eesti	doc_366216787903_item	3606596	et	4	main
ja	doc_366216787903_item	3606746	et	3	main
lõdvestuda	doc_366216787903_item	3606745	et	4	main
aitab	doc_366216787903_item	3606744	et	3	main
see	doc_366216787903_item	3606743	et	3	main
ja	doc_366216787903_item	3606742	et	3	main
kogu	doc_366216787903_item	3606724	et	4	main
kokku	doc_366216787903_item	3606723	et	3	main
sõidavad	doc_366216787903_item	3606722	et	3	main
inimesed	doc_366216787903_item	3606721	et	3	main
ja	doc_366216787903_item	3606720	et	3	main
populaarne	doc_366216787903_item	3606719	et	3	main
väga	doc_366216787903_item	3606718	et	3	main
puhkipilliorkestrit	doc_366216787903_item	3606709	et	4	main
5	doc_366216787903_item	3606708	et	2	main
ja	doc_366216787903_item	3606707	et	3	main
ja	doc_366216787902_item	3606510	et	3	main
xix-xx	doc_366216787902_item	3606498	et	4	main
et	doc_366216787902_item	3606497	et	3	main
ja	doc_366216787902_item	3606483	et	3	main
euroopast	doc_366216787902_item	3606482	et	3	main
sajandil	doc_366216787902_item	3606475	et	3	main
kirikut	doc_366216787902_item	3606473	et	3	main
väljaspool	doc_366216787902_item	3606472	et	3	main
ka	doc_366216787902_item	3606471	et	3	main
laulma	doc_366216787902_item	3606463	et	3	main
hakkasid	doc_366216787902_item	3606462	et	4	main
hiljem	doc_366216787902_item	3606460	et	3	main
laulu	doc_366216787902_item	3606458	et	4	main
elasid	doc_366216787902_item	3606457	et	4	main
nad	doc_366216787902_item	3606456	et	3	main
aastat	doc_366216787902_item	3606448	et	3	main
üksinda	doc_366216787902_item	3606423	et	4	main
laulsid	doc_366216787902_item	3606422	et	4	main
inimesed	doc_366216787902_item	3606421	et	3	main
lastega	doc_366216787902_item	3606420	et	3	main
mängisid	doc_366216787902_item	3606419	et	4	main
töötasid	doc_366216787902_item	3606415	et	4	main
nad	doc_366216787902_item	3606414	et	3	main
kui	doc_366216787902_item	3606413	et	3	main
naised	doc_366216787902_item	3606412	et	3	main
rohkem	doc_366216787902_item	3606411	et	4	main
lauldi	doc_366216787902_item	3606410	et	3	main
varem	doc_366216787902_item	3606409	et	4	main
rütmiga	doc_366216787902_item	3606408	et	3	main
mõnikord	doc_366216787902_item	3606407	et	3	main
lauldi	doc_366216787902_item	3606406	et	3	main
olla	doc_366216787902_item	3606405	et	3	main
võib	doc_366216787902_item	3606404	et	3	main
pillita	doc_366216787902_item	3606403	et	4	main
lauldi	doc_366216787902_item	3606402	et	3	main
regilaulud	doc_366216787902_item	3606401	et	3	main
tagasi	doc_366216787902_item	3606399	et	3	main
muidugi	doc_366216787902_item	3606400	et	4	main
aastat	doc_366216787902_item	3606398	et	3	main
tuhat	doc_366216787902_item	3606397	et	4	main
kui	doc_366216787902_item	3606396	et	3	main
enam	doc_366216787902_item	3606395	et	4	main
kujunand	doc_366216787902_item	3606394	et	4	main
kõige	doc_366216787902_item	3606389	et	4	main
rikkas	doc_366216787902_item	3606385	et	4	main
on	doc_366216787902_item	3606383	et	4	main
lauludel	doc_366216787902_item	3606382	et	3	main
meie	doc_366216787902_item	3606381	et	4	main
tugev	doc_366216787902_item	3606380	et	4	main
eriti	doc_366216787902_item	3606379	et	3	main
inimesele	doc_366216787902_item	3606378	et	3	main
me	doc_366216787902_item	3606368	et	4	main
me	doc_366216787902_item	3606362	et	4	main
gruppe	doc_366216787902_item	3606361	et	3	main
laulu	doc_366216787902_item	3606359	et	4	main
palju	doc_366216787902_item	3606358	et	4	main
nii	doc_366216787902_item	3606357	et	3	main
arutlev	doc_366216787902_item	3606335	et	4	main
300	doc_366216787902_item	3606329	et	2	main
mis	doc_366216787902_item	3606323	et	4	main
neid	doc_366216787903_item	3606677	et	4	main
oma	doc_366216787903_item	3606675	et	4	main
laulsid	doc_366216787903_item	3606674	et	4	main
on	doc_366216787903_item	3606656	et	4	main
üks	doc_366216787902_item	3606431	et	3	main
lauldis	doc_366216787902_item	3606429	et	4	main
või	doc_366216787902_item	3606426	et	4	main
või	doc_366216787902_item	3606424	et	4	main
pikk	doc_366216787902_item	3606387	et	4	main
laulud	doc_366216787902_item	3606370	et	3	main
lauluta	doc_366216787902_item	3606367	et	3	main
on	doc_366216787902_item	3606356	et	4	main
analüüsiv	doc_366216787902_item	3606336	et	4	main
sõna	doc_366216787902_item	3606331	et	4	main
350	doc_366216787902_item	3606330	et	2	main
essee	doc_366216787902_item	3606327	et	4	main
kirjutage	doc_366216787902_item	3606320	et	3	main
keele	doc_366216787902_item	3606317	et	4	main
teise	doc_366216787902_item	3606316	et	4	main
kui	doc_366216787902_item	3606315	et	3	main
keele	doc_366216787902_item	3606314	et	4	main
eesti	doc_366216787902_item	3606313	et	4	main
essee	doc_366216787902_item	3606312	et	4	main
vana	doc_366216787903_item	3606670	et	4	main
väga	doc_366216787903_item	3606669	et	3	main
on	doc_366216787903_item	3606668	et	4	main
rahvalaul	doc_366216787903_item	3606667	et	4	main
nii	doc_366216787903_item	3606666	et	3	main
natuke	doc_366216787903_item	3606657	et	4	main
laulma	doc_366216787903_item	3606653	et	3	main
spontaalselt	doc_366216787903_item	3606652	et	4	main
väga	doc_366216787903_item	3606646	et	3	main
korraldatakse	doc_366216787903_item	3606643	et	3	main
illustreerida	doc_366216787903_item	3606631	et	3	main
loengus	doc_366216787903_item	3606623	et	3	main
analüüsiv	doc_366216787903_item	3606619	et	4	main
arutlev	doc_366216787903_item	3606618	et	4	main
350	doc_366216787903_item	3606613	et	2	main
kirjutage	doc_366216787903_item	3606603	et	3	main
essee	doc_366216787903_item	3606595	et	4	main
laulda	doc_366216787903_item	3606754	et	4	main
sõpradega	doc_366216787903_item	3606739	et	3	main
perega	doc_366216787903_item	3606734	et	3	main
ka	doc_366216787903_item	3606717	et	3	main
ajal	doc_366216787903_item	3606716	et	4	main
praegusel	doc_366216787903_item	3606715	et	3	main
on	doc_366216787903_item	3606714	et	4	main
pidu	doc_366216787903_item	3606713	et	4	main
see	doc_366216787903_item	3606712	et	3	main
peol	doc_366216787903_item	3606701	et	4	main
tavaliselt	doc_366216787903_item	3606700	et	4	main
kui	doc_366216787903_item	3606693	et	3	main
tähendab	doc_366216787903_item	3606689	et	3	main
meestekoor	doc_366216787903_item	3606687	et	4	main
lastekoor	doc_366216787903_item	3606686	et	4	main
ja	doc_366216787903_item	3606685	et	3	main
rahvas	doc_366216787905_item	3607029	et	4	main
ette	doc_366216787905_item	3607024	et	4	main
kujunenud	doc_366216787905_item	3607021	et	4	main
on	doc_366216787905_item	3607020	et	4	main
saadeteks	doc_366216787905_item	3607019	et	3	main
lemmik	doc_366216787905_item	3607018	et	3	main
on	doc_366216787905_item	3607008	et	4	main
rahvas	doc_366216787905_item	3607007	et	4	main
laul	doc_366216787905_item	3606999	et	4	main
just	doc_366216787905_item	3606998	et	3	main
tähtis	doc_366216787905_item	3606997	et	4	main
eestlastele	doc_366216787905_item	3606995	et	4	main
on	doc_366216787905_item	3606994	et	4	main
hoidmise	doc_366216787905_item	3606990	et	4	main
kokku	doc_366216787905_item	3606989	et	3	main
identiteeditunne	doc_366216787905_item	3606988	et	3	main
rahvuslik	doc_366216787905_item	3606987	et	3	main
kujuneb	doc_366216787905_item	3606986	et	3	main
maal	doc_366216787905_item	3606985	et	4	main
omal	doc_366216787905_item	3606984	et	3	main
tegevus	doc_366216787903_item	3606774	et	4	main
sotsiaalne	doc_366216787903_item	3606773	et	3	main
ja	doc_366216787903_item	3606772	et	3	main
emotsionaalne	doc_366216787903_item	3606771	et	3	main
on	doc_366216787903_item	3606770	et	4	main
see	doc_366216787903_item	3606769	et	3	main
kultuurinähtus	doc_366216787903_item	3606768	et	4	main
tähelepanuväärne	doc_366216787903_item	3606767	et	3	main
on	doc_366216787903_item	3606766	et	4	main
laulmine	doc_366216787903_item	3606765	et	4	main
sest	doc_366216787903_item	3606764	et	4	main
laulurahva	doc_366216787903_item	3606763	et	3	main
eestlastest	doc_366216787903_item	3606762	et	4	main
teeb	doc_366216787903_item	3606761	et	3	main
see	doc_366216787903_item	3606760	et	3	main
just	doc_366216787903_item	3606759	et	3	main
et	doc_366216787903_item	3606758	et	3	main
ma	doc_366216787903_item	3606756	et	3	main
arvan	doc_366216787903_item	3606757	et	3	main
koos	doc_366216787903_item	3606755	et	4	main
emad	doc_366216787903_item	3606673	et	3	main
ammu	doc_366216787903_item	3606672	et	4	main
on	doc_366216787903_item	3606665	et	4	main
see	doc_366216787903_item	3606664	et	3	main
mittetavaline	doc_366216787903_item	3606658	et	4	main
nad	doc_366216787903_item	3606650	et	3	main
on	doc_366216787903_item	3606638	et	4	main
näidetega	doc_366216787903_item	3606632	et	3	main
on	doc_366216787903_item	3606629	et	4	main
esitatud	doc_366216787903_item	3606626	et	4	main
lugemistekstis	doc_366216787903_item	3606625	et	3	main
üldistav	doc_366216787903_item	3606621	et	4	main
olema	doc_366216787903_item	3606617	et	4	main
300	doc_366216787903_item	3606612	et	2	main
essee	doc_366216787903_item	3606610	et	4	main
laulurahva	doc_366216787903_item	3606609	et	3	main
eestlastest	doc_366216787903_item	3606608	et	4	main
teeb	doc_366216787903_item	3606607	et	3	main
test	doc_366216787903_item	3606601	et	3	main
keele	doc_366216787903_item	3606600	et	4	main
teise	doc_366216787903_item	3606599	et	4	main
kui	doc_366216787903_item	3606598	et	3	main
võimalus	doc_366216787903_item	3606753	et	3	main
enesetunde	doc_366216787903_item	3606749	et	4	main
koos	doc_366216787903_item	3606738	et	4	main
seal	doc_366216787903_item	3606737	et	4	main
rahvapeos	doc_366216787903_item	3606732	et	4	main
inimesed	doc_366216787903_item	3606730	et	3	main
vaadata	doc_366216787903_item	3606729	et	4	main
see	doc_366216787903_item	3606728	et	3	main
et	doc_366216787903_item	3606727	et	3	main
selleks	doc_366216787903_item	3606726	et	4	main
maailmas	doc_366216787903_item	3606725	et	3	main
mängijaga	doc_366216787903_item	3606711	et	4	main
56	doc_366216787903_item	3606710	et	2	main
lapsed	doc_366216787903_item	3606694	et	3	main
võtavad	doc_366216787903_item	3606692	et	3	main
koorid	doc_366216787903_item	3606682	et	4	main
ja	doc_366216787905_item	3607036	et	3	main
ka	doc_366216787905_item	3607016	et	3	main
meid	doc_366216787905_item	3607014	et	4	main
lapsepõlvest	doc_366216787905_item	3607012	et	4	main
alates	doc_366216787905_item	3607011	et	3	main
rahvas	doc_366216787905_item	3607010	et	4	main
väga	doc_366216787905_item	3606996	et	3	main
oma	doc_366216787905_item	3606982	et	4	main
ja	doc_366216787905_item	3606981	et	3	main
oma	doc_366216787905_item	3606979	et	4	main
tähendab	doc_366216787905_item	3606978	et	3	main
siis	doc_366216787905_item	3606965	et	3	main
alt	doc_366216787905_item	3606953	et	4	main
vastu	doc_366216787905_item	3606951	et	3	main
ilmaga	doc_366216787905_item	3606949	et	3	main
rahvas	doc_366216787905_item	3606946	et	4	main
hull	doc_366216787905_item	3606945	et	3	main
eestlasid	doc_366216787905_item	3606939	et	4	main
läbimärjad	doc_366216787905_item	3606938	et	3	main
2005	doc_366216787905_item	3606934	et	2	main
eestis	doc_366216787905_item	3606929	et	3	main
vanu	doc_366216787905_item	3606912	et	4	main
on	doc_366216787905_item	3606903	et	4	main
ajaks	doc_366216787905_item	3606893	et	4	main
hälli	doc_366216787905_item	3606884	et	4	main
lastele	doc_366216787905_item	3606883	et	4	main
lauldi	doc_366216787905_item	3606882	et	3	main
eestlast	doc_366216787905_item	3606879	et	4	main
ajaloost	doc_366216787905_item	3606864	et	4	main
sai	doc_366216787905_item	3606861	et	4	main
kust	doc_366216787905_item	3606860	et	4	main
laulurahva	doc_366216787905_item	3606859	et	3	main
inimesi	doc_366216787905_item	3606855	et	4	main
sellele	doc_366216787905_item	3606838	et	4	main
juures	doc_366216787905_item	3606834	et	4	main
kus	doc_366216787905_item	3606833	et	3	main
kui	doc_366216787905_item	3606827	et	3	main
sündmused	doc_366216787905_item	3606826	et	3	main
1991	doc_366216787905_item	3606824	et	2	main
tulevad	doc_366216787905_item	3606823	et	4	main
meelde	doc_366216787905_item	3606822	et	3	main
teemal	doc_366216787905_item	3606786	et	3	main
essee	doc_366216787905_item	3606785	et	4	main
kirjutage	doc_366216787905_item	3606784	et	3	main
eesti	doc_366216787905_item	3606777	et	4	main
essee	doc_366216787905_item	3606776	et	4	main
laulda	doc_366216787903_item	3606648	et	4	main
armastavad	doc_366216787903_item	3606647	et	4	main
eestlased	doc_366216787903_item	3606645	et	3	main
laulupidu	doc_366216787903_item	3606644	et	4	main
laulurahva	doc_366216787903_item	3606636	et	3	main
teeb	doc_366216787903_item	3606634	et	3	main
ja	doc_366216787903_item	3606624	et	3	main
ja	doc_366216787903_item	3606620	et	3	main
kirjutamine	doc_366216787903_item	3606602	et	4	main
teemal	doc_366216787903_item	3606605	et	3	main
keele	doc_366216787903_item	3606597	et	4	main
on	doc_366216787903_item	3606752	et	4	main
sest	doc_366216787903_item	3606750	et	4	main
hea	doc_366216787903_item	3606748	et	4	main
annab	doc_366216787903_item	3606747	et	3	main
kohtuvad	doc_366216787903_item	3606736	et	4	main
koos	doc_366216787903_item	3606733	et	4	main
822	doc_366216787903_item	3606705	et	2	main
meeskoori	doc_366216787903_item	3606704	et	4	main
46	doc_366216787903_item	3606703	et	2	main
osales	doc_366216787903_item	3606702	et	3	main
nii	doc_366216787903_item	3606695	et	3	main
naistekoor	doc_366216787903_item	3606684	et	4	main
näiteks	doc_366216787903_item	3606683	et	4	main
maal	doc_366216787905_item	3607038	et	4	main
meelega	doc_366216787905_item	3607034	et	4	main
eurovisioonile	doc_366216787905_item	3607025	et	3	main
kaks	doc_366216787905_item	3607022	et	3	main
laul	doc_366216787905_item	3607015	et	4	main
rahvalaul	doc_366216787905_item	3606993	et	4	main
meel	doc_366216787905_item	3606983	et	4	main
mida	doc_366216787905_item	3606977	et	4	main
iga	doc_366216787905_item	3606966	et	4	main
rahvast	doc_366216787905_item	3606964	et	4	main
ühindavad	doc_366216787905_item	3606963	et	4	main
hetked	doc_366216787905_item	3606962	et	3	main
sellised	doc_366216787905_item	3606961	et	4	main
just	doc_366216787905_item	3606960	et	3	main
arm	doc_366216787905_item	3606959	et	3	main
minu	doc_366216787905_item	3606958	et	3	main
kõlas	doc_366216787905_item	3606954	et	4	main
oma	doc_366216787905_item	3606941	et	4	main
paduvihma	doc_366216787905_item	3606936	et	4	main
kus	doc_366216787905_item	3606932	et	3	main
laulupidude	doc_366216787905_item	3606930	et	4	main
marjakene	doc_366216787905_item	3606916	et	4	main
maga	doc_366216787905_item	3606914	et	4	main
laule	doc_366216787905_item	3606913	et	4	main
rahvalaulud	doc_366216787905_item	3606901	et	3	main
regivärsilised	doc_366216787905_item	3606900	et	4	main
pikaks	doc_366216787905_item	3606892	et	4	main
sõjaväkke	doc_366216787905_item	3606891	et	3	main
lauldi	doc_366216787905_item	3606888	et	3	main
last	doc_366216787905_item	3606886	et	4	main
on	doc_366216787905_item	3606865	et	4	main
alguse	doc_366216787905_item	3606863	et	3	main
mis	doc_366216787905_item	3606856	et	4	main
pärast	doc_366216787905_item	3606852	et	4	main
jõudu	doc_366216787905_item	3606850	et	4	main
palju	doc_366216787905_item	3606849	et	4	main
nii	doc_366216787905_item	3606848	et	3	main
verd	doc_366216787905_item	3606836	et	3	main
rahvusriik	doc_366216787905_item	3606829	et	3	main
eesti	doc_366216787905_item	3606828	et	4	main
aasta	doc_366216787905_item	3606825	et	4	main
tähistame	doc_366216787905_item	3606818	et	3	main
kirjutamine	doc_366216787905_item	3606783	et	4	main
test	doc_366216787905_item	3606782	et	3	main
keele	doc_366216787905_item	3606778	et	4	main
seal	doc_366216787903_item	3606751	et	4	main
sugulastega	doc_366216787903_item	3606741	et	4	main
ning	doc_366216787903_item	3606740	et	3	main
või	doc_366216787903_item	3606735	et	4	main
tulevad	doc_366216787903_item	3606731	et	4	main
osa	doc_366216787903_item	3606699	et	4	main
inimesed	doc_366216787903_item	3606698	et	3	main
vanad	doc_366216787903_item	3606697	et	3	main
et	doc_366216787903_item	3606690	et	3	main
see	doc_366216787903_item	3606688	et	3	main
erinevaid	doc_366216787903_item	3606681	et	4	main
on	doc_366216787903_item	3606680	et	4	main
laulupeos	doc_366216787903_item	3606679	et	4	main
laulud	doc_366216787903_item	3606678	et	3	main
lauljaga	doc_366216787903_item	3606706	et	4	main
ka	doc_366216787903_item	3606696	et	3	main
peos	doc_366216787903_item	3606691	et	4	main
linnas	doc_366216787905_item	3607040	et	4	main
ja	doc_366216787905_item	3607039	et	3	main
hea	doc_366216787905_item	3607033	et	4	main
kuidas	doc_366216787905_item	3607032	et	3	main
näha	doc_366216787905_item	3607031	et	3	main
on	doc_366216787905_item	3607030	et	4	main
tänapäeval	doc_366216787905_item	3607017	et	3	main
saadab	doc_366216787905_item	3607013	et	3	main
eesti	doc_366216787905_item	3607006	et	4	main
toob	doc_366216787905_item	3607005	et	3	main
kokku	doc_366216787905_item	3607004	et	3	main
eestlasi	doc_366216787905_item	3607003	et	3	main
mis	doc_366216787905_item	3607002	et	4	main
see	doc_366216787905_item	3607001	et	3	main
keel	doc_366216787905_item	3606980	et	4	main
on	doc_366216787905_item	3606957	et	4	main
mu	doc_366216787905_item	3606955	et	3	main
laulukaare	doc_366216787905_item	3606952	et	3	main
iga	doc_366216787905_item	3606948	et	4	main
laulsid	doc_366216787905_item	3606940	et	4	main
aastal	doc_366216787905_item	3606935	et	3	main
meelega	doc_366216787905_item	3606921	et	4	main
hea	doc_366216787905_item	3606920	et	4	main
ullikene	doc_366216787905_item	3606919	et	4	main
1994	doc_366216787905_item	3606910	et	2	main
album	doc_366216787905_item	3606908	et	3	main
poolt	doc_366216787905_item	3606906	et	4	main
on	doc_366216787905_item	3606899	et	4	main
pulmades	doc_366216787905_item	3606889	et	3	main
hällist	doc_366216787905_item	3606880	et	4	main
üliuhke	doc_366216787905_item	3607066	et	4	main
kodumaale	doc_366216787905_item	3607065	et	4	main
oma	doc_366216787905_item	3607064	et	4	main
armastusest	doc_366216787905_item	3607063	et	4	main
lauldes	doc_366216787905_item	3607062	et	3	main
kooriga	doc_366216787905_item	3607061	et	4	main
tuhandilise	doc_366216787905_item	3607060	et	4	main
kümne	doc_366216787905_item	3607059	et	4	main
koos	doc_366216787905_item	3607058	et	4	main
all	doc_366216787905_item	3607057	et	3	main
kaare	doc_366216787905_item	3607056	et	3	main
lauluväljaku	doc_366216787905_item	3607055	et	3	main
lapsepõlves	doc_366216787905_item	3607054	et	4	main
tundnud	doc_366216787905_item	3607053	et	4	main
uhkust	doc_366216787905_item	3607052	et	4	main
mina	doc_366216787905_item	3607051	et	4	main
ka	doc_366216787905_item	3607050	et	3	main
olen	doc_366216787905_item	3607049	et	3	main
kaasa	doc_366216787905_item	3607048	et	4	main
laulge	doc_366216787905_item	3607047	et	3	main
tv-saates	doc_366216787905_item	3607046	et	4	main
laulavad	doc_366216787905_item	3607045	et	4	main
eestlased	doc_366216787905_item	3607044	et	3	main
tähtedega	doc_366216787905_item	3607043	et	4	main
estraadi	doc_366216787905_item	3607042	et	4	main
koos	doc_366216787905_item	3607041	et	4	main
tunne	doc_366216787905_item	3607067	et	4	main
vanad	doc_366216787905_item	3607037	et	3	main
noored	doc_366216787905_item	3607035	et	3	main
kogu	doc_366216787905_item	3607028	et	4	main
kaasa	doc_366216787905_item	3607027	et	4	main
elab	doc_366216787905_item	3607026	et	3	main
takti	doc_366216787905_item	3607023	et	4	main
laulev	doc_366216787905_item	3607009	et	4	main
on	doc_366216787905_item	3607000	et	4	main
oma	doc_366216787905_item	3606992	et	4	main
tunne	doc_366216787905_item	3606991	et	4	main
tunneb	doc_366216787905_item	3606976	et	3	main
hää	doc_366216787905_item	3606975	et	4	main
ja	doc_366216787905_item	3606974	et	3	main
uhke	doc_366216787905_item	3606973	et	4	main
on	doc_366216787905_item	3606972	et	4	main
olla	doc_366216787905_item	3606971	et	3	main
eestlane	doc_366216787905_item	3606970	et	3	main
et	doc_366216787905_item	3606969	et	3	main
tunneb	doc_366216787905_item	3606968	et	3	main
eestlane	doc_366216787905_item	3606967	et	3	main
isamaa	doc_366216787905_item	3606956	et	4	main
ja	doc_366216787905_item	3606950	et	3	main
laulab	doc_366216787905_item	3606947	et	3	main
täheldasid	doc_366216787905_item	3606944	et	4	main
välismaalased	doc_366216787905_item	3606943	et	3	main
ajal	doc_366216787905_item	3606937	et	4	main
näiteks	doc_366216787905_item	3606933	et	4	main
traditsioon	doc_366216787905_item	3606931	et	3	main
on	doc_366216787905_item	3606928	et	4	main
tuntud	doc_366216787905_item	3606927	et	4	main
emad	doc_366216787905_item	3606926	et	3	main
noored	doc_366216787905_item	3606925	et	3	main
praegu	doc_366216787905_item	3606924	et	3	main
ka	doc_366216787905_item	3606923	et	3	main
minu	doc_366216787905_item	3606918	et	3	main
maga	doc_366216787905_item	3606915	et	4	main
näiteks	doc_366216787905_item	3606907	et	4	main
teadlaste	doc_366216787905_item	3606905	et	3	main
kogutud	doc_366216787905_item	3606904	et	4	main
rütmi	doc_366216787905_item	3606896	et	4	main
töötades	doc_366216787905_item	3606895	et	3	main
saatmisel	doc_366216787905_item	3606894	et	4	main
mehi	doc_366216787905_item	3606890	et	3	main
hauani	doc_366216787905_item	3606881	et	3	main
laul	doc_366216787905_item	3606878	et	4	main
saatis	doc_366216787905_item	3606877	et	3	main
ajal	doc_366216787905_item	3606876	et	4	main
vanal	doc_366216787905_item	3606875	et	3	main
teada	doc_366216787905_item	3606866	et	3	main
liidab	doc_366216787905_item	3606854	et	3	main
on	doc_366216787905_item	3606847	et	4	main
laulul	doc_366216787905_item	3606846	et	3	main
tõepoolest	doc_366216787905_item	3606845	et	3	main
teise	doc_366216787905_item	3606831	et	4	main
taasiseseisvumispäeva	doc_366216787905_item	3606821	et	4	main
eestis	doc_366216787905_item	3606820	et	3	main
laule	doc_366216787905_item	3606942	et	4	main
laulavad	doc_366216787905_item	3606922	et	4	main
minu	doc_366216787905_item	3606917	et	3	main
neid	doc_366216787905_item	3606911	et	4	main
emalaulud	doc_366216787905_item	3606909	et	3	main
mis	doc_366216787905_item	3606902	et	4	main
tuntud	doc_366216787905_item	3606898	et	4	main
hoidmiseks	doc_366216787905_item	3606897	et	4	main
kiigutades	doc_366216787905_item	3606887	et	3	main
juures	doc_366216787905_item	3606885	et	4	main
aasta	doc_366216787905_item	3606874	et	4	main
tuhande	doc_366216787905_item	3606873	et	3	main
üle	doc_366216787905_item	3606872	et	3	main
maal	doc_366216787905_item	3606871	et	4	main
omal	doc_366216787905_item	3606870	et	3	main
elavad	doc_366216787905_item	3606869	et	4	main
eestlased	doc_366216787905_item	3606868	et	3	main
et	doc_366216787905_item	3606867	et	3	main
eestlastest	doc_366216787905_item	3606858	et	4	main
teeb	doc_366216787905_item	3606857	et	3	main
küsimus	doc_366216787905_item	3606843	et	4	main
tekib	doc_366216787905_item	3606842	et	3	main
revolutsioon	doc_366216787905_item	3606841	et	3	main
laulev	doc_366216787905_item	3606840	et	4	main
eelnes	doc_366216787905_item	3606839	et	3	main
sai	doc_366216787905_item	3606830	et	4	main
kui	doc_366216787905_item	3606779	et	3	main
laulutraditsioon	doc_366216787905_item	3606862	et	3	main
laul	doc_366216787905_item	3606853	et	4	main
mis	doc_366216787905_item	3606851	et	4	main
kas	doc_366216787905_item	3606844	et	3	main
valamata	doc_366216787905_item	3606837	et	4	main
tilkagi	doc_366216787905_item	3606835	et	4	main
sünni	doc_366216787905_item	3606832	et	4	main
me	doc_366216787905_item	3606819	et	4	main
iga	doc_366216787905_item	3606816	et	4	main
aasta	doc_366216787905_item	3606817	et	4	main
augustil	doc_366216787905_item	3606815	et	3	main
20-ndal	doc_366216787905_item	3606814	et	4	main
näidetega	doc_366216787905_item	3606813	et	3	main
illustreerida	doc_366216787905_item	3606812	et	3	main
soovitatav	doc_366216787905_item	3606811	et	4	main
on	doc_366216787905_item	3606810	et	4	main
väiteid	doc_366216787905_item	3606809	et	4	main
faktidele	doc_366216787905_item	3606808	et	3	main
esitatud	doc_366216787905_item	3606807	et	4	main
lugemistekstis	doc_366216787905_item	3606806	et	3	main
ja	doc_366216787905_item	3606805	et	3	main
loengus	doc_366216787905_item	3606804	et	3	main
tuginema	doc_366216787905_item	3606803	et	3	main
üldistav	doc_366216787905_item	3606802	et	4	main
ja	doc_366216787905_item	3606801	et	3	main
analüüsiv	doc_366216787905_item	3606800	et	4	main
arutlev	doc_366216787905_item	3606799	et	4	main
olema	doc_366216787905_item	3606798	et	4	main
peab	doc_366216787905_item	3606797	et	4	main
essee	doc_366216787905_item	3606796	et	4	main
sõna	doc_366216787905_item	3606795	et	4	main
350	doc_366216787905_item	3606794	et	2	main
300	doc_366216787905_item	3606793	et	2	main
pikkus	doc_366216787905_item	3606792	et	4	main
essee	doc_366216787905_item	3606791	et	4	main
laulurahva	doc_366216787905_item	3606790	et	3	main
eestlastest	doc_366216787905_item	3606789	et	4	main
teeb	doc_366216787905_item	3606788	et	3	main
mis	doc_366216787905_item	3606787	et	4	main
keele	doc_366216787905_item	3606781	et	4	main
teise	doc_366216787905_item	3606780	et	4	main
palju	doc_366216787907_item	3607701	et	4	main
väga	doc_366216787907_item	3607700	et	3	main
on	doc_366216787907_item	3607699	et	4	main
virumaal	doc_366216787907_item	3607698	et	4	main
kudum	doc_366216787907_item	3607690	et	3	main
muster	doc_366216787907_item	3607688	et	3	main
valladest	doc_366216787907_item	3607680	et	4	main
eesti	doc_366216787907_item	3607679	et	4	main
tegelen	doc_366216787907_item	3607666	et	3	main
aega	doc_366216787907_item	3607659	et	4	main
valitsuse	doc_366216787907_item	3607594	et	4	main
pool	doc_366216787907_item	3607711	et	4	main
nimetada	doc_366216787907_item	3607705	et	3	main
võiks	doc_366216787907_item	3607704	et	4	main
samuti	doc_366216787907_item	3607692	et	3	main
külas	doc_366216787907_item	3607684	et	3	main
eesti	doc_366216787907_item	3607683	et	4	main
riietust	doc_366216787907_item	3607677	et	4	main
õmbleme	doc_366216787907_item	3607676	et	3	main
viimane	doc_366216787907_item	3607669	et	3	main
mina	doc_366216787907_item	3607665	et	4	main
muusikataju	doc_366216787907_item	3607661	et	4	main
repertuaari	doc_366216787907_item	3607600	et	4	main
partei	doc_366216787907_item	3607592	et	4	main
kommunistliku	doc_366216787907_item	3607591	et	3	main
tingimustes	doc_366216787907_item	3607590	et	3	main
keeles	doc_366216787907_item	3607710	et	4	main
miks	doc_366216787907_item	3607703	et	4	main
ida	doc_366216787907_item	3607697	et	4	main
tantsuga	doc_366216787907_item	3607696	et	3	main
ja	doc_366216787907_item	3607695	et	3	main
lauluga	doc_366216787907_item	3607694	et	4	main
on	doc_366216787907_item	3607685	et	4	main
erinevate	doc_366216787907_item	3607678	et	4	main
on	doc_366216787907_item	3607671	et	4	main
töö	doc_366216787907_item	3607670	et	4	main
pikka	doc_366216787907_item	3607658	et	4	main
mõjutanud	doc_366216787907_item	3607657	et	4	main
laulda	doc_366216787907_item	3607606	et	4	main
ja	doc_366216787907_item	3607605	et	3	main
reeglid	doc_366216787907_item	3607604	et	3	main
ranged	doc_366216787907_item	3607603	et	3	main
kehtestati	doc_366216787907_item	3607602	et	3	main
suunamise	doc_366216787907_item	3607598	et	4	main
toimunud	doc_366216787907_item	3607583	et	4	main
üldlaulupidude	doc_366216787907_item	3607572	et	4	main
ühtlasi	doc_366216787907_item	3607563	et	4	main
rahvusliku	doc_366216787907_item	3607560	et	3	main
kujunes	doc_366216787907_item	3607558	et	3	main
sellest	doc_366216787907_item	3607557	et	4	main
lauljaga	doc_366216787907_item	3607551	et	4	main
peol	doc_366216787907_item	3607546	et	4	main
kujunes	doc_366216787907_item	3607527	et	3	main
tähtsusega	doc_366216787907_item	3607525	et	4	main
ka	doc_366216787907_item	3607509	et	3	main
kirikut	doc_366216787907_item	3607504	et	3	main
kaasnes	doc_366216787907_item	3607489	et	3	main
neid	doc_366216787907_item	3607479	et	4	main
ilma	doc_366216787907_item	3607476	et	4	main
see	doc_366216787907_item	3607464	et	3	main
on	doc_366216787907_item	3607461	et	4	main
laulmine	doc_366216787907_item	3607460	et	4	main
seda	doc_366216787907_item	3607459	et	3	main
arendab	doc_366216787907_item	3607458	et	3	main
ja	doc_366216787907_item	3607457	et	3	main
edasi	doc_366216787907_item	3607456	et	3	main
viib	doc_366216787907_item	3607454	et	3	main
tavaliselt	doc_366216787907_item	3607448	et	4	main
mis	doc_366216787907_item	3607438	et	4	main
rahvalaul	doc_366216787907_item	3607437	et	4	main
350	doc_366216787907_item	3607409	et	2	main
eestlastest	doc_366216787907_item	3607404	et	4	main
teise	doc_366216787907_item	3607395	et	4	main
traditsioon	doc_366216787907_item	3607656	et	3	main
pool	doc_366216787907_item	3607708	et	4	main
lauluteks	doc_366216787907_item	3607707	et	3	main
segamini	doc_366216787907_item	3607706	et	4	main
ka	doc_366216787907_item	3607693	et	3	main
oma	doc_366216787907_item	3607687	et	4	main
olemas	doc_366216787907_item	3607686	et	4	main
iga	doc_366216787907_item	3607682	et	4	main
küladest	doc_366216787907_item	3607681	et	3	main
me	doc_366216787907_item	3607675	et	4	main
tantsupeodele	doc_366216787907_item	3607674	et	3	main
vaim	doc_366216787907_item	3607673	et	3	main
minu	doc_366216787907_item	3607668	et	3	main
laulupärimust	doc_366216787907_item	3607664	et	4	main
suulist	doc_366216787907_item	3607663	et	4	main
ja	doc_366216787907_item	3607662	et	3	main
osas	doc_366216787907_item	3607601	et	4	main
all	doc_366216787907_item	3607599	et	3	main
ja	doc_366216787907_item	3607597	et	3	main
kontrolli	doc_366216787907_item	3607596	et	4	main
korra	doc_366216787907_item	3607589	et	4	main
nõukogude	doc_366216787907_item	3607588	et	3	main
pidustused	doc_366216787907_item	3607587	et	3	main
olid	doc_366216787907_item	3607586	et	4	main
aastal	doc_366216787907_item	3607582	et	3	main
mis	doc_366216787907_item	3607568	et	4	main
mängijaga	doc_366216787907_item	3607556	et	4	main
56	doc_366216787907_item	3607555	et	2	main
puhkpilliorkestrit	doc_366216787907_item	3607554	et	3	main
5	doc_366216787907_item	3607553	et	2	main
46	doc_366216787907_item	3607548	et	2	main
küll	doc_366216787907_item	3607513	et	4	main
levikuga	doc_366216787907_item	3607507	et	3	main
ka	doc_366216787907_item	3607505	et	3	main
väljaspool	doc_366216787907_item	3607503	et	3	main
laulmine	doc_366216787907_item	3607500	et	4	main
vaimulike	doc_366216787907_item	3607498	et	3	main
hakkas	doc_366216787907_item	3607496	et	3	main
laulude	doc_366216787907_item	3607491	et	3	main
regilaule	doc_366216787907_item	3607474	et	4	main
väljendusvahed	doc_366216787907_item	3607469	et	3	main
ja	doc_366216787907_item	3607467	et	3	main
kultuurinähtus	doc_366216787907_item	3607463	et	4	main
regilaulu	doc_366216787907_item	3607446	et	4	main
tagasi	doc_366216787907_item	3607445	et	3	main
aastat	doc_366216787907_item	3607444	et	3	main
tuhat	doc_366216787907_item	3607443	et	4	main
kujunenud	doc_366216787907_item	3607440	et	4	main
kultuurile	doc_366216787907_item	3607434	et	3	main
sõna	doc_366216787907_item	3607410	et	4	main
kirjutamine	doc_366216787907_item	3607398	et	4	main
on	doc_366216787907_item	3607650	et	4	main
repertuaar	doc_366216787907_item	3607649	et	3	main
rahvusluse	doc_366216787907_item	3607643	et	4	main
tähelepanuväärsem	doc_366216787907_item	3607640	et	4	main
bajaan	doc_366216787907_item	3607722	et	3	main
ehk	doc_366216787907_item	3607721	et	3	main
akkordeon	doc_366216787907_item	3607720	et	4	main
venemoodne	doc_366216787907_item	3607719	et	3	main
kannel	doc_366216787907_item	3607718	et	4	main
pill	doc_366216787907_item	3607717	et	3	main
instrumentidega	doc_366216787907_item	3607716	et	3	main
muusika	doc_366216787907_item	3607715	et	4	main
samuti	doc_366216787907_item	3607714	et	3	main
keeles	doc_366216787907_item	3607713	et	4	main
vene	doc_366216787907_item	3607712	et	4	main
eesti	doc_366216787907_item	3607709	et	4	main
laule	doc_366216787907_item	3607702	et	4	main
riietus	doc_366216787907_item	3607691	et	4	main
oma	doc_366216787907_item	3607689	et	4	main
eesti	doc_366216787907_item	3607672	et	4	main
käsitööga	doc_366216787907_item	3607667	et	3	main
eestlaste	doc_366216787907_item	3607660	et	4	main
range	doc_366216787907_item	3607595	et	4	main
üldlaulupeost	doc_366216787907_item	3607585	et	4	main
1947	doc_366216787907_item	3607581	et	2	main
alates	doc_366216787907_item	3607580	et	3	main
naiskoorid	doc_366216787907_item	3607579	et	3	main
ka	doc_366216787907_item	3607578	et	3	main
osavõtjatena	doc_366216787907_item	3607577	et	3	main
lisandusid	doc_366216787907_item	3607576	et	4	main
aastal	doc_366216787907_item	3607575	et	3	main
1933	doc_366216787907_item	3607574	et	2	main
korraldamisele	doc_366216787907_item	3607573	et	4	main
suursündmus	doc_366216787907_item	3607567	et	3	main
muusikaline	doc_366216787907_item	3607566	et	4	main
sellest	doc_366216787907_item	3607565	et	4	main
meeskoori	doc_366216787907_item	3607549	et	4	main
eesotsas	doc_366216787907_item	3607542	et	4	main
seltsist	doc_366216787907_item	3607541	et	4	main
ülemaaline	doc_366216787907_item	3607529	et	4	main
mängimiseks	doc_366216787907_item	3607516	et	4	main
muusika	doc_366216787907_item	3607515	et	4	main
vaimuliku	doc_366216787907_item	3607514	et	3	main
puhkpilliorkestrite	doc_366216787907_item	3607510	et	3	main
ka	doc_366216787907_item	3607502	et	3	main
18	doc_366216787907_item	3607494	et	2	main
laulmine	doc_366216787907_item	3607492	et	4	main
ja	doc_366216787907_item	3607593	et	3	main
xii	doc_366216787907_item	3607584	et	4	main
jargnevate	doc_366216787907_item	3607571	et	4	main
aluse	doc_366216787907_item	3607570	et	4	main
pani	doc_366216787907_item	3607569	et	4	main
sai	doc_366216787907_item	3607564	et	4	main
liikumise	doc_366216787907_item	3607561	et	4	main
eestlaste	doc_366216787907_item	3607559	et	4	main
822	doc_366216787907_item	3607550	et	2	main
osales	doc_366216787907_item	3607547	et	3	main
jannseniga	doc_366216787907_item	3607545	et	4	main
voldemar	doc_366216787907_item	3607544	et	4	main
saateks	doc_366216787907_item	3607523	et	3	main
asutamine	doc_366216787907_item	3607511	et	4	main
kaasnes	doc_366216787907_item	3607508	et	3	main
levima	doc_366216787907_item	3607501	et	3	main
aga	doc_366216787907_item	3607497	et	3	main
sajandil	doc_366216787907_item	3607495	et	3	main
ristiusuga	doc_366216787907_item	3607488	et	3	main
ja	doc_366216787907_item	3607486	et	3	main
tuginedes	doc_366216787907_item	3607484	et	3	main
põlve	doc_366216787907_item	3607482	et	4	main
põlvest	doc_366216787907_item	3607481	et	4	main
pärandati	doc_366216787907_item	3607480	et	4	main
tegevus	doc_366216787907_item	3607473	et	4	main
ka	doc_366216787907_item	3607471	et	3	main
esteetiline	doc_366216787907_item	3607466	et	3	main
vaheldumisi	doc_366216787907_item	3607452	et	4	main
koor	doc_366216787907_item	3607451	et	4	main
ja	doc_366216787907_item	3607450	et	3	main
eeslaulja	doc_366216787907_item	3607449	et	4	main
kui	doc_366216787907_item	3607442	et	3	main
üldistav	doc_366216787907_item	3607417	et	4	main
ja	doc_366216787907_item	3607416	et	3	main
essee	doc_366216787907_item	3607411	et	4	main
pikkus	doc_366216787907_item	3607407	et	4	main
essee	doc_366216787907_item	3607406	et	4	main
test	doc_366216787907_item	3607397	et	3	main
keele	doc_366216787907_item	3607396	et	4	main
essee	doc_366216787907_item	3607391	et	4	main
manifestatsioon	doc_366216787907_item	3607644	et	3	main
ja	doc_366216787907_item	3607641	et	3	main
rootsi	doc_366216787908_item	3607925	et	4	main
näiteks	doc_366216787908_item	3607921	et	4	main
on	doc_366216787908_item	3607910	et	4	main
laulurahva	doc_366216787908_item	3607909	et	3	main
eestlaste	doc_366216787908_item	3607908	et	4	main
4	doc_366216787908_item	3607893	et	2	main
konkursid	doc_366216787908_item	3607886	et	3	main
laste	doc_366216787908_item	3607884	et	4	main
folkloori	doc_366216787908_item	3607882	et	4	main
palju	doc_366216787908_item	3607881	et	4	main
pidus	doc_366216787908_item	3607875	et	3	main
et	doc_366216787908_item	3607872	et	3	main
lauljad	doc_366216787908_item	3607871	et	4	main
maailmast	doc_366216787908_item	3607865	et	4	main
kultuuri	doc_366216787908_item	3607818	et	4	main
ärkamisaeg	doc_366216787908_item	3607812	et	3	main
tegevus	doc_366216787908_item	3607807	et	4	main
kajastas	doc_366216787908_item	3607803	et	3	main
nii	doc_366216787908_item	3607779	et	3	main
on	doc_366216787908_item	3607772	et	4	main
ja	doc_366216787908_item	3607770	et	3	main
tänapäeva	doc_366216787908_item	3607762	et	4	main
näidetega	doc_366216787908_item	3607761	et	3	main
tuginema	doc_366216787908_item	3607751	et	3	main
sõna	doc_366216787908_item	3607743	et	4	main
300	doc_366216787908_item	3607741	et	2	main
pikkus	doc_366216787908_item	3607740	et	4	main
essee	doc_366216787908_item	3607739	et	4	main
laulurahva	doc_366216787908_item	3607738	et	3	main
ja	doc_366216787909_item	3608231	et	3	main
kujunenud	doc_366216787909_item	3608223	et	4	main
need	doc_366216787909_item	3608218	et	3	main
kogedes	doc_366216787909_item	3608203	et	4	main
laulda	doc_366216787909_item	3608202	et	4	main
kaasa	doc_366216787909_item	3608201	et	4	main
võimalust	doc_366216787909_item	3608200	et	3	main
elamust	doc_366216787909_item	3608196	et	4	main
publikule	doc_366216787909_item	3608193	et	3	main
on	doc_366216787909_item	3608167	et	4	main
kõrghetk	doc_366216787907_item	3607562	et	3	main
ja	doc_366216787907_item	3607552	et	3	main
johann	doc_366216787907_item	3607543	et	4	main
vanemuise	doc_366216787907_item	3607540	et	4	main
tuli	doc_366216787907_item	3607539	et	4	main
teostus	doc_366216787907_item	3607538	et	4	main
ja	doc_366216787907_item	3607537	et	3	main
idee	doc_366216787907_item	3607536	et	4	main
korraldamise	doc_366216787907_item	3607535	et	4	main
mille	doc_366216787907_item	3607534	et	3	main
tartus	doc_366216787907_item	3607533	et	3	main
aastal	doc_366216787907_item	3607532	et	3	main
1869	doc_366216787907_item	3607531	et	2	main
laulupidu	doc_366216787907_item	3607530	et	4	main
esimene	doc_366216787907_item	3607528	et	3	main
sündmuseks	doc_366216787907_item	3607526	et	3	main
ajaloolise	doc_366216787907_item	3607524	et	4	main
tantsu	doc_366216787907_item	3607522	et	4	main
ka	doc_366216787907_item	3607521	et	3	main
piduõhtutel	doc_366216787907_item	3607520	et	3	main
musitseeriti	doc_366216787907_item	3607519	et	3	main
hiljem	doc_366216787907_item	3607518	et	3	main
kuid	doc_366216787907_item	3607517	et	4	main
esialgu	doc_366216787907_item	3607512	et	3	main
koorilaulu	doc_366216787907_item	3607506	et	4	main
laulude	doc_366216787907_item	3607499	et	3	main
kirikus	doc_366216787907_item	3607493	et	3	main
vaimulike	doc_366216787907_item	3607490	et	3	main
traditsioonidele	doc_366216787907_item	3607487	et	3	main
mälule	doc_366216787907_item	3607485	et	3	main
suuliselt	doc_366216787907_item	3607483	et	4	main
ning	doc_366216787907_item	3607478	et	3	main
pillisaateta	doc_366216787907_item	3607477	et	3	main
lauldi	doc_366216787907_item	3607475	et	3	main
sotsiaalne	doc_366216787907_item	3607472	et	3	main
aga	doc_366216787907_item	3607470	et	3	main
on	doc_366216787907_item	3607465	et	4	main
tähelepanuväärne	doc_366216787907_item	3607462	et	3	main
regivärsiline	doc_366216787907_item	3607436	et	4	main
iseloomulik	doc_366216787907_item	3607435	et	3	main
ja	doc_366216787907_item	3607420	et	3	main
loengus	doc_366216787907_item	3607419	et	3	main
tuginema	doc_366216787907_item	3607418	et	3	main
peab	doc_366216787907_item	3607412	et	4	main
mis	doc_366216787907_item	3607402	et	4	main
teemal	doc_366216787907_item	3607401	et	3	main
kui	doc_366216787907_item	3607394	et	3	main
keele	doc_366216787907_item	3607393	et	4	main
peo	doc_366216787907_item	3607648	et	4	main
ajal	doc_366216787907_item	3607638	et	4	main
ka	doc_366216787907_item	3607636	et	3	main
on	doc_366216787907_item	3607635	et	4	main
laulupidu	doc_366216787907_item	3607634	et	4	main
eestiline	doc_366216787907_item	3607633	et	3	main
üle	doc_366216787907_item	3607632	et	3	main
pillimängijani	doc_366216787907_item	3607631	et	3	main
ja	doc_366216787907_item	3607630	et	3	main
laulja	doc_366216787907_item	3607629	et	4	main
000	doc_366216787907_item	3607628	et	2	main
30	doc_366216787907_item	3607627	et	2	main
000	doc_366216787907_item	3607626	et	2	main
25	doc_366216787907_item	3607625	et	2	main
arv	doc_366216787907_item	3607624	et	3	main
osavõtjate	doc_366216787907_item	3607623	et	3	main
ja	doc_366216787908_item	3607926	et	3	main
rahvakuulturi	doc_366216787908_item	3607920	et	3	main
ta	doc_366216787908_item	3607917	et	4	main
tegelikult	doc_366216787908_item	3607907	et	4	main
koha	doc_366216787908_item	3607899	et	4	main
laulu	doc_366216787908_item	3607888	et	4	main
iga	doc_366216787908_item	3607879	et	4	main
tantsujad	doc_366216787908_item	3607870	et	4	main
koorid	doc_366216787908_item	3607869	et	4	main
pole	doc_366216787908_item	3607868	et	3	main
traditsiooni	doc_366216787908_item	3607863	et	4	main
kuultur	doc_366216787908_item	3607828	et	4	main
emotsionaalne	doc_366216787907_item	3607468	et	3	main
laulu	doc_366216787907_item	3607455	et	4	main
eeslaulja	doc_366216787907_item	3607453	et	4	main
esitavad	doc_366216787907_item	3607447	et	4	main
enam	doc_366216787907_item	3607441	et	4	main
on	doc_366216787907_item	3607439	et	4	main
läänemeresoome	doc_366216787907_item	3607433	et	3	main
esindab	doc_366216787907_item	3607432	et	3	main
laulutraditsiooni	doc_366216787907_item	3607431	et	4	main
vanemat	doc_366216787907_item	3607430	et	4	main
eesti	doc_366216787907_item	3607429	et	4	main
näidetega	doc_366216787907_item	3607428	et	3	main
illustreerida	doc_366216787907_item	3607427	et	3	main
soovitatav	doc_366216787907_item	3607426	et	4	main
on	doc_366216787907_item	3607425	et	4	main
väiteid	doc_366216787907_item	3607424	et	4	main
faktidele	doc_366216787907_item	3607423	et	3	main
esitatud	doc_366216787907_item	3607422	et	4	main
lugemistekstis	doc_366216787907_item	3607421	et	3	main
analüüsiv	doc_366216787907_item	3607415	et	4	main
arutlev	doc_366216787907_item	3607414	et	4	main
olema	doc_366216787907_item	3607413	et	4	main
300	doc_366216787907_item	3607408	et	2	main
laulurahva	doc_366216787907_item	3607405	et	3	main
teeb	doc_366216787907_item	3607403	et	3	main
essee	doc_366216787907_item	3607400	et	4	main
kirjutage	doc_366216787907_item	3607399	et	3	main
eesti	doc_366216787907_item	3607392	et	4	main
koorilaulu	doc_366216787907_item	3607655	et	4	main
heliloominguga	doc_366216787907_item	3607653	et	3	main
selle	doc_366216787907_item	3607647	et	4	main
kuigi	doc_366216787907_item	3607646	et	3	main
eestis	doc_366216787907_item	3607645	et	3	main
massilisem	doc_366216787907_item	3607642	et	4	main
kõge	doc_366216787907_item	3607639	et	4	main
suurenes	doc_366216787907_item	3607622	et	4	main
on	doc_366216787907_item	3607654	et	4	main
professionaalse	doc_366216787907_item	3607652	et	3	main
seotud	doc_366216787907_item	3607651	et	4	main
esinemised	doc_366216787907_item	3607621	et	4	main
saksa	doc_366216787908_item	3607923	et	4	main
selle	doc_366216787908_item	3607915	et	4	main
teine	doc_366216787908_item	3607906	et	3	main
olime	doc_366216787908_item	3607905	et	3	main
me	doc_366216787908_item	3607904	et	4	main
aastat	doc_366216787908_item	3607903	et	3	main
ja	doc_366216787908_item	3607901	et	3	main
tagasi	doc_366216787908_item	3607895	et	3	main
aastat	doc_366216787908_item	3607894	et	3	main
umbes	doc_366216787908_item	3607892	et	4	main
ne	doc_366216787908_item	3607891	et	4	main
ja	doc_366216787908_item	3607890	et	3	main
aasta	doc_366216787908_item	3607880	et	4	main
meie	doc_366216787908_item	3607867	et	4	main
kogu	doc_366216787908_item	3607864	et	4	main
arenesid	doc_366216787908_item	3607826	et	4	main
ärkamisaega	doc_366216787908_item	3607819	et	4	main
oli	doc_366216787908_item	3607814	et	3	main
19	doc_366216787908_item	3607808	et	2	main
rohkem	doc_366216787908_item	3607794	et	4	main
laulsid	doc_366216787908_item	3607793	et	4	main
aastat	doc_366216787908_item	3607778	et	3	main
rohkem	doc_366216787908_item	3607775	et	4	main
eestlasi	doc_366216787908_item	3607774	et	3	main
on	doc_366216787908_item	3607758	et	4	main
loengus	doc_366216787908_item	3607752	et	3	main
ja	doc_366216787908_item	3607749	et	3	main
essee	doc_366216787908_item	3607744	et	4	main
teise	doc_366216787908_item	3607728	et	4	main
kui	doc_366216787908_item	3607727	et	3	main
keele	doc_366216787908_item	3607726	et	4	main
eesti	doc_366216787908_item	3607725	et	4	main
essee	doc_366216787908_item	3607724	et	4	main
endale	doc_366216787908_item	3607934	et	4	main
oma	doc_366216787908_item	3607933	et	4	main
huvitav	doc_366216787908_item	3607932	et	4	main
midagi	doc_366216787908_item	3607931	et	4	main
leida	doc_366216787908_item	3607930	et	3	main
saab	doc_366216787908_item	3607929	et	3	main
inimesi	doc_366216787908_item	3607928	et	4	main
palju	doc_366216787908_item	3607927	et	4	main
praegusel	doc_366216787907_item	3607637	et	3	main
1960	doc_366216787907_item	3607620	et	2	main
poistekooride	doc_366216787907_item	3607619	et	3	main
ja	doc_366216787907_item	3607618	et	3	main
1947	doc_366216787907_item	3607617	et	2	main
lastekooride	doc_366216787907_item	3607616	et	3	main
ka	doc_366216787907_item	3607615	et	3	main
lülitati	doc_366216787907_item	3607614	et	4	main
kavva	doc_366216787907_item	3607613	et	3	main
et	doc_366216787907_item	3607612	et	3	main
laule	doc_366216787907_item	3607611	et	4	main
propagandistlikke	doc_366216787907_item	3607610	et	3	main
pealesunnitud	doc_366216787907_item	3607609	et	4	main
palju	doc_366216787907_item	3607608	et	4	main
tuli	doc_366216787907_item	3607607	et	4	main
soome	doc_366216787908_item	3607922	et	3	main
palju	doc_366216787908_item	3607919	et	4	main
eurovisioonil	doc_366216787908_item	3607900	et	3	main
esimene	doc_366216787908_item	3607898	et	3	main
pidu	doc_366216787908_item	3607889	et	4	main
laulu	doc_366216787908_item	3607885	et	4	main
festivalid	doc_366216787908_item	3607883	et	3	main
sama	doc_366216787908_item	3607876	et	4	main
osaleda	doc_366216787908_item	3607873	et	3	main
eesti	doc_366216787908_item	3607827	et	4	main
nad	doc_366216787908_item	3607825	et	3	main
eesti	doc_366216787908_item	3607817	et	4	main
see	doc_366216787908_item	3607813	et	3	main
sajandil	doc_366216787908_item	3607809	et	3	main
ja	doc_366216787908_item	3607806	et	3	main
kultur	doc_366216787908_item	3607805	et	4	main
rahva	doc_366216787908_item	3607804	et	3	main
lausid	doc_366216787908_item	3607802	et	4	main
neid	doc_366216787908_item	3607801	et	4	main
sõjast	doc_366216787908_item	3607800	et	3	main
mehi	doc_366216787908_item	3607799	et	3	main
ajal	doc_366216787908_item	3607792	et	4	main
vanal	doc_366216787908_item	3607791	et	3	main
teadki	doc_366216787908_item	3607764	et	4	main
väiteid	doc_366216787908_item	3607757	et	4	main
faktidele	doc_366216787908_item	3607756	et	3	main
350	doc_366216787908_item	3607742	et	2	main
kristin	doc_366216787909_item	3608227	et	4	main
allikad	doc_366216787909_item	3608226	et	3	main
sümboliteks	doc_366216787909_item	3608225	et	3	main
rahvuslikeks	doc_366216787909_item	3608224	et	3	main
ülendavat	doc_366216787909_item	3608205	et	4	main
seda	doc_366216787909_item	3608204	et	3	main
kuulajaskond	doc_366216787909_item	3608198	et	3	main
pealtvaataja	doc_366216787909_item	3608195	et	4	main
pakub	doc_366216787909_item	3608192	et	3	main
laulupidu	doc_366216787909_item	3608191	et	4	main
lootuses	doc_366216787909_item	3608176	et	4	main
lisaks	doc_366216787909_item	3608166	et	4	main
eestis	doc_366216787909_item	3608165	et	3	main
manifestatsioon	doc_366216787909_item	3608164	et	3	main
mis	doc_366216787909_item	3608147	et	4	main
suurüritusteks	doc_366216787909_item	3608146	et	3	main
vabadussõda	doc_366216787909_item	3608142	et	4	main
voldemar	doc_366216787909_item	3608133	et	4	main
tuli	doc_366216787909_item	3608128	et	4	main
kulturil	doc_366216787908_item	3607939	et	4	main
temal	doc_366216787908_item	3607938	et	3	main
ja	doc_366216787908_item	3607937	et	3	main
rahvas	doc_366216787908_item	3607936	et	4	main
selles	doc_366216787908_item	3607935	et	4	main
vene	doc_366216787908_item	3607924	et	4	main
kajastab	doc_366216787908_item	3607918	et	3	main
pärast	doc_366216787908_item	3607916	et	4	main
huivitavad	doc_366216787908_item	3607914	et	4	main
ja	doc_366216787908_item	3607913	et	3	main
erinevad	doc_366216787908_item	3607912	et	4	main
väga	doc_366216787908_item	3607911	et	3	main
7	doc_366216787908_item	3607902	et	2	main
sai	doc_366216787908_item	3607897	et	4	main
eesti	doc_366216787908_item	3607896	et	4	main
rahva	doc_366216787908_item	3607887	et	3	main
toimub	doc_366216787908_item	3607878	et	3	main
eestis	doc_366216787908_item	3607877	et	3	main
selles	doc_366216787908_item	3607874	et	4	main
soidab	doc_366216787908_item	3607866	et	4	main
laulupidude	doc_366216787908_item	3607862	et	4	main
kestnud	doc_366216787908_item	3607861	et	4	main
aasta	doc_366216787908_item	3607860	et	4	main
137	doc_366216787908_item	3607859	et	2	main
tähistame	doc_366216787908_item	3607858	et	3	main
me	doc_366216787908_item	3607857	et	4	main
täna	doc_366216787908_item	3607856	et	4	main
koidula	doc_366216787908_item	3607855	et	4	main
l	doc_366216787908_item	3607854	et	4	main
tütar	doc_366216787908_item	3607853	et	3	main
janseni	doc_366216787908_item	3607852	et	4	main
kirjutas	doc_366216787908_item	3607851	et	3	main
sõnad	doc_366216787908_item	3607850	et	4	main
aga	doc_366216787908_item	3607849	et	3	main
ernesaks	doc_366216787908_item	3607848	et	4	main
g	doc_366216787908_item	3607847	et	4	main
kirjutas	doc_366216787908_item	3607846	et	3	main
muusika	doc_366216787908_item	3607845	et	4	main
gumni	doc_366216787908_item	3607844	et	4	main
luulupidu	doc_366216787908_item	3607843	et	4	main
eesti	doc_366216787908_item	3607842	et	4	main
aastal	doc_366216787908_item	3607841	et	3	main
1869	doc_366216787908_item	3607840	et	2	main
tartus	doc_366216787908_item	3607839	et	3	main
toimus	doc_366216787908_item	3607838	et	3	main
laulupidu	doc_366216787908_item	3607837	et	4	main
esimene	doc_366216787908_item	3607836	et	3	main
laulmine	doc_366216787908_item	3607835	et	4	main
osa	doc_366216787908_item	3607834	et	4	main
oluline	doc_366216787908_item	3607833	et	4	main
tema	doc_366216787908_item	3607832	et	4	main
ajal	doc_366216787908_item	3607831	et	4	main
samal	doc_366216787908_item	3607830	et	3	main
ja	doc_366216787908_item	3607829	et	3	main
juhid	doc_366216787908_item	3607820	et	4	main
tähtis	doc_366216787908_item	3607815	et	4	main
eestis	doc_366216787908_item	3607810	et	3	main
omad	doc_366216787908_item	3607798	et	4	main
ootavad	doc_366216787908_item	3607797	et	4	main
nad	doc_366216787908_item	3607796	et	3	main
naisi	doc_366216787908_item	3607795	et	3	main
ajal	doc_366216787908_item	3607786	et	4	main
sõja	doc_366216787908_item	3607785	et	3	main
nii	doc_366216787908_item	3607784	et	3	main
pidul	doc_366216787908_item	3607783	et	3	main
ka	doc_366216787908_item	3607782	et	3	main
kui	doc_366216787908_item	3607781	et	3	main
tool	doc_366216787908_item	3607780	et	3	main
tuhat	doc_366216787908_item	3607777	et	4	main
kui	doc_366216787908_item	3607776	et	3	main
tants	doc_366216787908_item	3607771	et	3	main
laul	doc_366216787908_item	3607769	et	4	main
maailma	doc_366216787908_item	3607768	et	4	main
kogu	doc_366216787908_item	3607767	et	4	main
laulurahva	doc_366216787908_item	3607766	et	3	main
nagu	doc_366216787908_item	3607765	et	3	main
illustreerida	doc_366216787908_item	3607760	et	3	main
soovitatav	doc_366216787908_item	3607759	et	4	main
ja	doc_366216787908_item	3607753	et	3	main
üldistav	doc_366216787908_item	3607750	et	4	main
analüüsiv	doc_366216787908_item	3607748	et	4	main
arutlev	doc_366216787908_item	3607747	et	4	main
olema	doc_366216787908_item	3607746	et	4	main
teemal	doc_366216787908_item	3607734	et	3	main
muutused	doc_366216787909_item	3608232	et	4	main
kultuuriidentiteet	doc_366216787909_item	3608229	et	4	main
läbi	doc_366216787909_item	3608221	et	4	main
laulud	doc_366216787909_item	3608219	et	3	main
ootab	doc_366216787909_item	3608197	et	3	main
kõigepealt	doc_366216787909_item	3608194	et	3	main
kuigi	doc_366216787909_item	3608190	et	3	main
kohata	doc_366216787909_item	3608177	et	4	main
perega	doc_366216787909_item	3608175	et	3	main
tullakse	doc_366216787909_item	3608173	et	3	main
kuhu	doc_366216787909_item	3608172	et	3	main
rahvusluse	doc_366216787909_item	3608163	et	4	main
praegusel	doc_366216787909_item	3608158	et	3	main
ka	doc_366216787909_item	3608157	et	3	main
muusika	doc_366216787909_item	3608145	et	4	main
ja	doc_366216787909_item	3608141	et	3	main
1918	doc_366216787909_item	3608139	et	2	main
eesotsas	doc_366216787909_item	3608131	et	4	main
seltsist	doc_366216787909_item	3608130	et	4	main
ja	doc_366216787909_item	3608126	et	3	main
tähtsusega	doc_366216787909_item	3608114	et	4	main
eeskujul	doc_366216787909_item	3608108	et	3	main
baltisaksa	doc_366216787909_item	3608106	et	4	main
eestlaste	doc_366216787909_item	3608094	et	4	main
on	doc_366216787909_item	3608090	et	4	main
muusika-	doc_366216787909_item	3608087	et	4	main
mõjul	doc_366216787909_item	3608086	et	4	main
saksa	doc_366216787909_item	3608078	et	4	main
on	doc_366216787909_item	3608071	et	4	main
laulud	doc_366216787909_item	3608070	et	3	main
riimilise	doc_366216787909_item	3608066	et	4	main
sajandil	doc_366216787909_item	3608063	et	3	main
lõi	doc_366216787909_item	3608061	et	4	main
setu	doc_366216787909_item	3608053	et	4	main
on	doc_366216787909_item	3608046	et	4	main
või	doc_366216787909_item	3608042	et	4	main
tuhat	doc_366216787909_item	3608025	et	4	main
kultuurile	doc_366216787909_item	3608016	et	3	main
ajaloo	doc_366216787909_item	3608009	et	4	main
nagu	doc_366216787909_item	3608008	et	3	main
tutvumine	doc_366216787909_item	3608006	et	4	main
aga	doc_366216787909_item	3607995	et	3	main
soovitatav	doc_366216787909_item	3607976	et	4	main
analüüsiv	doc_366216787909_item	3607965	et	4	main
arutlev	doc_366216787909_item	3607964	et	4	main
350	doc_366216787909_item	3607959	et	2	main
eestlastest	doc_366216787909_item	3607954	et	4	main
mis	doc_366216787909_item	3607952	et	4	main
kirjutamine	doc_366216787909_item	3607948	et	4	main
test	doc_366216787909_item	3607947	et	3	main
jakobson	doc_366216787908_item	3607824	et	4	main
ja	doc_366216787908_item	3607823	et	3	main
jannsen	doc_366216787908_item	3607822	et	4	main
oli	doc_366216787908_item	3607821	et	3	main
aja	doc_366216787908_item	3607816	et	4	main
algas	doc_366216787908_item	3607811	et	3	main
ajal	doc_366216787908_item	3607790	et	4	main
heal	doc_366216787908_item	3607789	et	3	main
ka	doc_366216787908_item	3607788	et	3	main
kui	doc_366216787908_item	3607787	et	3	main
saatnud	doc_366216787908_item	3607773	et	4	main
eestlastest	doc_366216787908_item	3607763	et	4	main
esitatud	doc_366216787908_item	3607755	et	4	main
lugemistekstis	doc_366216787908_item	3607754	et	3	main
peab	doc_366216787908_item	3607745	et	4	main
eestlastest	doc_366216787908_item	3607737	et	4	main
teeb	doc_366216787908_item	3607736	et	3	main
mis	doc_366216787908_item	3607735	et	4	main
essee	doc_366216787908_item	3607733	et	4	main
kirjutage	doc_366216787908_item	3607732	et	3	main
kirjutamine	doc_366216787908_item	3607731	et	4	main
test	doc_366216787908_item	3607730	et	3	main
keele	doc_366216787908_item	3607729	et	4	main
laulutraditsioonis	doc_366216787909_item	3608233	et	3	main
mis	doc_366216787909_item	3608207	et	4	main
tunnet	doc_366216787909_item	3608206	et	3	main
tegelikult	doc_366216787909_item	3608199	et	4	main
sõpru	doc_366216787909_item	3608178	et	3	main
koos	doc_366216787909_item	3608174	et	4	main
rahvapidu	doc_366216787909_item	3608171	et	4	main
suur	doc_366216787909_item	3608170	et	3	main
ka	doc_366216787909_item	3608169	et	3	main
massilisem	doc_366216787909_item	3608162	et	4	main
ja	doc_366216787909_item	3608161	et	3	main
ajal	doc_366216787909_item	3608159	et	4	main
on	doc_366216787909_item	3608156	et	4	main
laulupidu	doc_366216787909_item	3608155	et	4	main
eestiline	doc_366216787909_item	3608154	et	3	main
1928	doc_366216787909_item	3608152	et	2	main
lauluväljakul	doc_366216787909_item	3608151	et	3	main
praegusel	doc_366216787909_item	3608150	et	3	main
kadriorus	doc_366216787909_item	3608149	et	3	main
toimusid	doc_366216787909_item	3608148	et	4	main
eesti	doc_366216787909_item	3608136	et	4	main
ülemaaline	doc_366216787909_item	3608118	et	4	main
esimene	doc_366216787909_item	3608117	et	3	main
kujunes	doc_366216787909_item	3608116	et	3	main
sündmuseks	doc_366216787909_item	3608115	et	3	main
maal	doc_366216787909_item	3608112	et	4	main
sajandi	doc_366216787909_item	3608098	et	3	main
ärkamine	doc_366216787909_item	3608096	et	4	main
rahvuslik	doc_366216787909_item	3608095	et	3	main
seotud	doc_366216787909_item	3608091	et	4	main
lauluharrastusega	doc_366216787909_item	3608089	et	3	main
väl	doc_366216787909_item	3608072	et	4	main
uue	doc_366216787909_item	3608065	et	3	main
19	doc_366216787909_item	3608062	et	2	main
esitatud	doc_366216787909_item	3608047	et	4	main
lüroeepilisi	doc_366216787909_item	3608044	et	4	main
aastat	doc_366216787909_item	3608026	et	3	main
kui	doc_366216787909_item	3608024	et	3	main
kujunenud	doc_366216787909_item	3608022	et	4	main
on	doc_366216787909_item	3608021	et	4	main
iseloomulik	doc_366216787909_item	3608017	et	3	main
esindab	doc_366216787909_item	3608014	et	3	main
vanemat	doc_366216787909_item	3608012	et	4	main
eesti	doc_366216787909_item	3608011	et	4	main
pisut	doc_366216787909_item	3608007	et	3	main
on	doc_366216787909_item	3608003	et	4	main
minevik	doc_366216787909_item	3608001	et	3	main
kajastub	doc_366216787909_item	3607999	et	3	main
lastele	doc_366216787909_item	3607997	et	4	main
tööl	doc_366216787909_item	3607994	et	3	main
essee	doc_366216787909_item	3607961	et	4	main
sõna	doc_366216787909_item	3607960	et	4	main
300	doc_366216787909_item	3607958	et	2	main
pikkus	doc_366216787909_item	3607957	et	4	main
teeb	doc_366216787909_item	3607953	et	3	main
teemal	doc_366216787909_item	3607951	et	3	main
essee	doc_366216787909_item	3607950	et	4	main
kirjutage	doc_366216787909_item	3607949	et	3	main
rahvuslus	doc_366216787909_item	3608230	et	4	main
kuutma	doc_366216787909_item	3608228	et	4	main
aja	doc_366216787909_item	3608222	et	4	main
on	doc_366216787909_item	3608220	et	4	main
lauldes	doc_366216787909_item	3608217	et	3	main
viisi	doc_366216787909_item	3608216	et	4	main
sama	doc_366216787909_item	3608215	et	4	main
tekib	doc_366216787909_item	3608208	et	3	main
ja	doc_366216787909_item	3608189	et	3	main
kokku	doc_366216787909_item	3608187	et	3	main
maailma	doc_366216787909_item	3608186	et	4	main
sõitnud	doc_366216787909_item	3608188	et	4	main
kogu	doc_366216787909_item	3608185	et	4	main
üle	doc_366216787909_item	3608184	et	3	main
on	doc_366216787909_item	3608183	et	4	main
kes	doc_366216787909_item	3608182	et	4	main
tuttavaid	doc_366216787909_item	3608181	et	3	main
ja	doc_366216787909_item	3608180	et	3	main
sugulasi	doc_366216787909_item	3608179	et	3	main
laulupidu	doc_366216787909_item	3608168	et	4	main
üle	doc_366216787909_item	3608153	et	3	main
muutusid	doc_366216787909_item	3608143	et	4	main
aastal	doc_366216787909_item	3608140	et	3	main
loomist	doc_366216787909_item	3608138	et	4	main
vabariigi	doc_366216787909_item	3608137	et	3	main
pärast	doc_366216787909_item	3608135	et	4	main
jannseniga	doc_366216787909_item	3608134	et	4	main
vanemuise	doc_366216787909_item	3608129	et	4	main
idee	doc_366216787909_item	3608125	et	4	main
1869	doc_366216787909_item	3608120	et	2	main
laulupidu	doc_366216787909_item	3608119	et	4	main
ajaloolise	doc_366216787909_item	3608113	et	4	main
linnas	doc_366216787909_item	3608110	et	4	main
muusika	doc_366216787909_item	3608085	et	4	main
slaavi	doc_366216787909_item	3608084	et	3	main
ja	doc_366216787909_item	3608083	et	3	main
soome	doc_366216787909_item	3608082	et	3	main
kujunenud	doc_366216787909_item	3608074	et	4	main
ja	doc_366216787909_item	3608073	et	3	main
rahvalaulu	doc_366216787909_item	3608067	et	4	main
eeldused	doc_366216787909_item	3608064	et	4	main
pöörajooks	doc_366216787909_item	3608054	et	4	main
saatel	doc_366216787909_item	3608051	et	4	main
liikumise	doc_366216787909_item	3608050	et	4	main
laule	doc_366216787909_item	3608045	et	4	main
enam	doc_366216787909_item	3608023	et	4	main
regivärsiline	doc_366216787909_item	3608018	et	4	main
väiteid	doc_366216787909_item	3607974	et	4	main
peab	doc_366216787909_item	3607962	et	4	main
laulurahva	doc_366216787909_item	3607955	et	3	main
keele	doc_366216787909_item	3607946	et	4	main
me	doc_366216787910_item	3608478	et	4	main
mille	doc_366216787910_item	3608476	et	3	main
asjad	doc_366216787910_item	3608475	et	3	main
hiljem	doc_366216787910_item	3608452	et	3	main
tuli	doc_366216787910_item	3608451	et	4	main
mis	doc_366216787910_item	3608449	et	4	main
tagasi	doc_366216787910_item	3608446	et	3	main
aastad	doc_366216787910_item	3608445	et	3	main
sada	doc_366216787910_item	3608444	et	4	main
me	doc_366216787910_item	3608438	et	4	main
kui	doc_366216787910_item	3608437	et	3	main
arendab	doc_366216787910_item	3608436	et	3	main
on	doc_366216787910_item	3608429	et	4	main
rahvuse	doc_366216787910_item	3608423	et	3	main
inimesed	doc_366216787910_item	3608420	et	3	main
eestis	doc_366216787910_item	3608418	et	3	main
koos	doc_366216787910_item	3608410	et	4	main
on	doc_366216787910_item	3608405	et	4	main
muidugi	doc_366216787910_item	3608402	et	4	main
rahvusluse	doc_366216787910_item	3608382	et	4	main
tähelepanuväärsem	doc_366216787910_item	3608379	et	4	main
ajal	doc_366216787910_item	3608377	et	4	main
praegusel	doc_366216787910_item	3608376	et	3	main
ka	doc_366216787910_item	3608375	et	3	main
on	doc_366216787910_item	3608374	et	4	main
võttis	doc_366216787910_item	3608361	et	3	main
kultuuri	doc_366216787910_item	3608358	et	4	main
säilitada	doc_366216787910_item	3608356	et	3	main
olid	doc_366216787910_item	3608351	et	4	main
on	doc_366216787910_item	3608320	et	4	main
laul	doc_366216787910_item	3608319	et	4	main
kuulatada	doc_366216787910_item	3608318	et	3	main
keel	doc_366216787910_item	3608313	et	4	main
ilus	doc_366216787910_item	3608310	et	4	main
meloodiline	doc_366216787910_item	3608309	et	3	main
väga	doc_366216787910_item	3608308	et	3	main
on	doc_366216787910_item	3608307	et	4	main
eesti	doc_366216787910_item	3608305	et	4	main
350	doc_366216787910_item	3608253	et	2	main
kirjutage	doc_366216787910_item	3608243	et	3	main
kirjutamine	doc_366216787910_item	3608242	et	4	main
test	doc_366216787910_item	3608241	et	3	main
essee	doc_366216787910_item	3608235	et	4	main
oma	doc_366216787910_item	3608518	et	4	main
väljendada	doc_366216787910_item	3608517	et	3	main
hinda	doc_366216787910_item	3608508	et	4	main
ja	doc_366216787910_item	3608507	et	3	main
tähtis	doc_366216787910_item	3608506	et	4	main
oli	doc_366216787910_item	3608505	et	3	main
meie	doc_366216787910_item	3608499	et	4	main
tähelepanuväärsem	doc_366216787909_item	3608160	et	4	main
laulupeod	doc_366216787909_item	3608144	et	4	main
johann	doc_366216787909_item	3608132	et	4	main
teostus	doc_366216787909_item	3608127	et	4	main
korraldamise	doc_366216787909_item	3608124	et	4	main
mille	doc_366216787909_item	3608123	et	3	main
tartus	doc_366216787909_item	3608122	et	3	main
aastal	doc_366216787909_item	3608121	et	3	main
kui	doc_366216787909_item	3608111	et	3	main
lõpupoole	doc_366216787909_item	3608099	et	4	main
19	doc_366216787909_item	3608097	et	2	main
tihedalt	doc_366216787909_item	3608092	et	4	main
rootsi	doc_366216787909_item	3608081	et	4	main
ka	doc_366216787909_item	3608080	et	3	main
aga	doc_366216787909_item	3608079	et	3	main
eelkõige	doc_366216787909_item	3608077	et	3	main
tekkeks	doc_366216787909_item	3608068	et	3	main
koosmõju	doc_366216787909_item	3608060	et	4	main
laulutraditsiooni	doc_366216787909_item	3608059	et	4	main
tantsulise	doc_366216787909_item	3608049	et	4	main
ka	doc_366216787909_item	3608048	et	3	main
tagasi	doc_366216787909_item	3608027	et	3	main
uurimine	doc_366216787909_item	3608010	et	4	main
rahvalauluga	doc_366216787909_item	3608005	et	4	main
rahva	doc_366216787909_item	3608000	et	3	main
rahvalauludes	doc_366216787909_item	3607998	et	3	main
ka	doc_366216787909_item	3607996	et	3	main
laulsid	doc_366216787909_item	3607993	et	4	main
on	doc_366216787909_item	3607975	et	4	main
olema	doc_366216787909_item	3607963	et	4	main
essee	doc_366216787909_item	3607956	et	4	main
keele	doc_366216787909_item	3607943	et	4	main
arendavad	doc_366216787910_item	3608463	et	4	main
nad	doc_366216787910_item	3608462	et	3	main
laulades	doc_366216787910_item	3608461	et	3	main
nad	doc_366216787910_item	3608455	et	3	main
oli	doc_366216787910_item	3608450	et	3	main
laulu	doc_366216787910_item	3608448	et	4	main
ja	doc_366216787910_item	3608447	et	3	main
mis	doc_366216787910_item	3608441	et	4	main
eesti	doc_366216787910_item	3608432	et	4	main
osa	doc_366216787910_item	3608427	et	4	main
ja	doc_366216787910_item	3608425	et	3	main
nii	doc_366216787909_item	3608109	et	3	main
kogukonna	doc_366216787909_item	3608107	et	4	main
loodi	doc_366216787909_item	3608105	et	4	main
muusikaseltse	doc_366216787909_item	3608104	et	3	main
ja	doc_366216787909_item	3608103	et	3	main
haridus-	doc_366216787909_item	3608102	et	3	main
rahvuslikke	doc_366216787909_item	3608101	et	3	main
mil	doc_366216787909_item	3608100	et	4	main
ka	doc_366216787909_item	3608093	et	3	main
ning	doc_366216787909_item	3608088	et	3	main
muusika	doc_366216787909_item	3608076	et	4	main
euroopa	doc_366216787909_item	3608075	et	4	main
need	doc_366216787909_item	3608069	et	3	main
laenatud	doc_366216787909_item	3608058	et	4	main
euroopast	doc_366216787909_item	3608057	et	3	main
ja	doc_366216787909_item	3608056	et	3	main
vanema	doc_366216787909_item	3608055	et	4	main
näiteks	doc_366216787909_item	3608052	et	4	main
jalapõrutusega	doc_366216787909_item	3608043	et	3	main
õõtsutamise	doc_366216787909_item	3608041	et	4	main
keha	doc_366216787909_item	3608040	et	4	main
näiteks	doc_366216787909_item	3608039	et	4	main
rütmi	doc_366216787909_item	3608038	et	4	main
rõhutada	doc_366216787909_item	3608037	et	3	main
võidi	doc_366216787909_item	3608036	et	4	main
lauldes	doc_366216787909_item	3608035	et	3	main
vaheldumisi	doc_366216787909_item	3608034	et	4	main
koor	doc_366216787909_item	3608033	et	4	main
ja	doc_366216787909_item	3608032	et	3	main
eeslaulja	doc_366216787909_item	3608031	et	4	main
tavaliselt	doc_366216787909_item	3608030	et	4	main
esitavad	doc_366216787909_item	3608029	et	4	main
regilaulu	doc_366216787909_item	3608028	et	4	main
mis	doc_366216787909_item	3608020	et	4	main
rahvalaul	doc_366216787909_item	3608019	et	4	main
länemeresoome	doc_366216787909_item	3608015	et	4	main
laulutraditsiooni	doc_366216787909_item	3608013	et	4	main
ka	doc_366216787909_item	3608004	et	3	main
mistõttu	doc_366216787909_item	3608002	et	3	main
tegevus	doc_366216787909_item	3607992	et	4	main
sotsiaalne	doc_366216787909_item	3607991	et	3	main
ka	doc_366216787909_item	3607990	et	3	main
aga	doc_366216787909_item	3607989	et	3	main
väljendusvahend	doc_366216787909_item	3607988	et	3	main
emotsionaalne	doc_366216787909_item	3607987	et	3	main
ja	doc_366216787909_item	3607986	et	3	main
esteetiline	doc_366216787909_item	3607985	et	3	main
on	doc_366216787909_item	3607984	et	4	main
see	doc_366216787909_item	3607983	et	3	main
kultuurinähtus	doc_366216787909_item	3607982	et	4	main
tähelepanuväärne	doc_366216787909_item	3607981	et	3	main
on	doc_366216787909_item	3607980	et	4	main
laulmine	doc_366216787909_item	3607979	et	4	main
näidetega	doc_366216787909_item	3607978	et	3	main
illustreerida	doc_366216787909_item	3607977	et	3	main
faktidele	doc_366216787909_item	3607973	et	3	main
esitatud	doc_366216787909_item	3607972	et	4	main
lugemistekstis	doc_366216787909_item	3607971	et	3	main
ja	doc_366216787909_item	3607970	et	3	main
loengus	doc_366216787909_item	3607969	et	3	main
tuginema	doc_366216787909_item	3607968	et	3	main
üldistav	doc_366216787909_item	3607967	et	4	main
ja	doc_366216787909_item	3607966	et	3	main
kui	doc_366216787909_item	3607944	et	3	main
essee	doc_366216787909_item	3607941	et	4	main
ja	doc_366216787909_item	3608214	et	3	main
teistega	doc_366216787909_item	3608210	et	4	main
tuhandete	doc_366216787909_item	3608209	et	3	main
eest	doc_366216787910_item	3608477	et	4	main
on	doc_366216787910_item	3608474	et	4	main
need	doc_366216787910_item	3608473	et	3	main
traditsioonid	doc_366216787910_item	3608472	et	3	main
oma	doc_366216787910_item	3608471	et	4	main
muidugi	doc_366216787910_item	3608454	et	4	main
popularne	doc_366216787910_item	3608443	et	4	main
oli	doc_366216787910_item	3608442	et	3	main
ja	doc_366216787910_item	3608435	et	3	main
muutub	doc_366216787910_item	3608434	et	3	main
laul	doc_366216787910_item	3608433	et	4	main
säilimises	doc_366216787910_item	3608428	et	4	main
kaasa	doc_366216787910_item	3608413	et	4	main
et	doc_366216787910_item	3608412	et	3	main
perega	doc_366216787910_item	3608411	et	3	main
peo	doc_366216787910_item	3608404	et	4	main
eestis	doc_366216787910_item	3608384	et	3	main
1869	doc_366216787910_item	3608370	et	2	main
voldemar	doc_366216787910_item	3608363	et	4	main
ja	doc_366216787910_item	3608350	et	3	main
et	doc_366216787910_item	3608348	et	3	main
pärast	doc_366216787910_item	3608347	et	4	main
me	doc_366216787910_item	3608326	et	4	main
inimesed	doc_366216787910_item	3608325	et	3	main
on	doc_366216787910_item	3608315	et	4	main
seda	doc_366216787910_item	3608314	et	3	main
keel	doc_366216787910_item	3608306	et	4	main
teised	doc_366216787910_item	3608304	et	4	main
kui	doc_366216787910_item	3608303	et	3	main
rohkem	doc_366216787910_item	3608302	et	4	main
on	doc_366216787910_item	3608294	et	4	main
eestlased	doc_366216787910_item	3608293	et	3	main
muidugi	doc_366216787910_item	3608292	et	4	main
muusikaga	doc_366216787910_item	3608291	et	3	main
peab	doc_366216787910_item	3608256	et	4	main
laulurahva	doc_366216787910_item	3608249	et	3	main
eestlastest	doc_366216787910_item	3608248	et	4	main
teeb	doc_366216787910_item	3608247	et	3	main
mis	doc_366216787910_item	3608246	et	4	main
teemal	doc_366216787910_item	3608245	et	3	main
tunne	doc_366216787910_item	3608519	et	4	main
laulu	doc_366216787910_item	3608510	et	4	main
seda	doc_366216787910_item	3608509	et	3	main
ei	doc_366216787910_item	3608492	et	4	main
niisugune	doc_213943984965_item	3608685	et	3	main
vot	doc_213943984965_item	3608684	et	3	main
gaas	doc_213943984965_item	3608681	et	3	main
kiirem	doc_213943984965_item	3608679	et	4	main
kui	doc_213943984965_item	3608675	et	3	main
arvatest	doc_213943984965_item	3608671	et	3	main
majas	doc_213943984965_item	3608667	et	3	main
minu	doc_213943984965_item	3608666	et	3	main
et	doc_213943984965_item	3608665	et	3	main
see	doc_213943984965_item	3608664	et	3	main
ka	doc_213943984965_item	3608663	et	3	main
meeldib	doc_213943984965_item	3608662	et	3	main
need	doc_213943984965_item	3608631	et	3	main
ei	doc_213943984965_item	3608622	et	4	main
ei	doc_213943984965_item	3608619	et	4	main
teise	doc_366216787909_item	3607945	et	4	main
eesti	doc_366216787909_item	3607942	et	4	main
oma	doc_366216787910_item	3608467	et	4	main
mäletavad	doc_366216787910_item	3608466	et	4	main
oskused	doc_366216787910_item	3608465	et	3	main
oma	doc_366216787910_item	3608464	et	4	main
siis	doc_366216787910_item	3608453	et	3	main
laulu	doc_366216787910_item	3608440	et	4	main
kättes	doc_366216787910_item	3608431	et	4	main
suur	doc_366216787910_item	3608426	et	3	main
hoolitsevad	doc_366216787910_item	3608422	et	4	main
kes	doc_366216787910_item	3608421	et	4	main
on	doc_366216787910_item	3608419	et	4	main
oluline	doc_366216787910_item	3608416	et	4	main
väga	doc_366216787910_item	3608415	et	3	main
lauldaon	doc_366216787910_item	3608414	et	4	main
koht	doc_366216787910_item	3608407	et	3	main
see	doc_366216787910_item	3608403	et	3	main
laulupärimust	doc_366216787910_item	3608401	et	4	main
suulist	doc_366216787910_item	3608400	et	4	main
ja	doc_366216787910_item	3608380	et	3	main
kõige	doc_366216787910_item	3608378	et	4	main
laulupidu	doc_366216787910_item	3608369	et	4	main
ülemaline	doc_366216787910_item	3608368	et	4	main
esimest	doc_366216787910_item	3608367	et	4	main
korraldas	doc_366216787910_item	3608366	et	3	main
osa	doc_366216787910_item	3608360	et	4	main
rahvusliku	doc_366216787910_item	3608357	et	3	main
tahtsid	doc_366216787910_item	3608355	et	4	main
laulame	doc_366216787910_item	3608329	et	4	main
pulmades	doc_366216787910_item	3608328	et	3	main
laulame	doc_366216787910_item	3608327	et	4	main
meeldiv	doc_366216787910_item	3608317	et	4	main
väga	doc_366216787910_item	3608316	et	3	main
natuke	doc_366216787910_item	3608301	et	4	main
olla	doc_366216787910_item	3608300	et	3	main
võib	doc_366216787910_item	3608299	et	3	main
ja	doc_366216787910_item	3608298	et	3	main
selles	doc_366216787910_item	3608297	et	4	main
lugemistekstis	doc_366216787910_item	3608265	et	3	main
ja	doc_366216787910_item	3608264	et	3	main
loengus	doc_366216787910_item	3608263	et	3	main
tuginema	doc_366216787910_item	3608262	et	3	main
üldistav	doc_366216787910_item	3608261	et	4	main
ja	doc_366216787910_item	3608260	et	3	main
analüüsiv	doc_366216787910_item	3608259	et	4	main
sõna	doc_366216787910_item	3608254	et	4	main
essee	doc_366216787910_item	3608244	et	4	main
eesti	doc_366216787910_item	3608236	et	4	main
saame	doc_366216787910_item	3608516	et	4	main
ja	doc_366216787910_item	3608515	et	3	main
üheteist	doc_366216787910_item	3608514	et	4	main
tunneme	doc_366216787910_item	3608513	et	3	main
sugulastlele	doc_366216787910_item	3608501	et	4	main
pane	doc_366216787910_item	3608496	et	4	main
ja	doc_366216787910_item	3608491	et	3	main
tuleviku	doc_366216787910_item	3608489	et	4	main
hoolitseda	doc_366216787910_item	3608487	et	3	main
sõnu	doc_366216787909_item	3608213	et	4	main
samu	doc_366216787909_item	3608212	et	3	main
üheskoos	doc_366216787909_item	3608211	et	3	main
kõige	doc_366216787910_item	3608484	et	4	main
sest	doc_366216787910_item	3608483	et	4	main
laulurahvaga	doc_366216787910_item	3608482	et	3	main
eestlasi	doc_366216787910_item	3608481	et	3	main
nimetada	doc_366216787910_item	3608480	et	3	main
saame	doc_366216787910_item	3608479	et	4	main
armastavad	doc_366216787910_item	3608470	et	4	main
laulad	doc_366216787910_item	3608469	et	3	main
rahvuse	doc_366216787910_item	3608468	et	3	main
huvitatud	doc_366216787910_item	3608460	et	4	main
on	doc_366216787910_item	3608459	et	4	main
eestlased	doc_366216787910_item	3608458	et	3	main
erinevad	doc_366216787910_item	3608457	et	4	main
on	doc_366216787910_item	3608456	et	4	main
kuulame	doc_366216787910_item	3608439	et	4	main
nende	doc_366216787910_item	3608430	et	4	main
muusikaga	doc_366216787910_item	3608424	et	3	main
et	doc_366216787910_item	3608417	et	3	main
tullakse	doc_366216787910_item	3608409	et	3	main
kuhu	doc_366216787910_item	3608408	et	3	main
ka	doc_366216787910_item	3608406	et	3	main
ja	doc_366216787910_item	3608399	et	3	main
muusikataju	doc_366216787910_item	3608398	et	4	main
eestlaste	doc_366216787910_item	3608397	et	4	main
aega	doc_366216787910_item	3608396	et	4	main
pikka	doc_366216787910_item	3608395	et	4	main
mõjutanud	doc_366216787910_item	3608394	et	4	main
traditsioon	doc_366216787910_item	3608393	et	3	main
koorilaulu	doc_366216787910_item	3608392	et	4	main
on	doc_366216787910_item	3608391	et	4	main
heliloominguga	doc_366216787910_item	3608390	et	3	main
professionaalse	doc_366216787910_item	3608389	et	3	main
seotud	doc_366216787910_item	3608388	et	4	main
on	doc_366216787910_item	3608387	et	4	main
repertuaar	doc_366216787910_item	3608386	et	3	main
peo	doc_366216787910_item	3608385	et	4	main
massilisem	doc_366216787910_item	3608381	et	4	main
laulupidu	doc_366216787910_item	3608373	et	4	main
tartus	doc_366216787910_item	3608372	et	3	main
aastal	doc_366216787910_item	3608371	et	3	main
jannsen	doc_366216787910_item	3608364	et	4	main
suur	doc_366216787910_item	3608359	et	3	main
kes	doc_366216787910_item	3608354	et	4	main
inimesed	doc_366216787910_item	3608353	et	3	main
huvitatud	doc_366216787910_item	3608352	et	4	main
mida	doc_366216787910_item	3608323	et	4	main
väljendusvahe	doc_366216787910_item	3608322	et	4	main
emotsionaalne	doc_366216787910_item	3608321	et	3	main
tegutsid	doc_366216787910_item	3608290	et	4	main
ja	doc_366216787910_item	3608289	et	3	main
tantsisid	doc_366216787910_item	3608288	et	4	main
alati	doc_366216787910_item	3608286	et	4	main
inimesed	doc_366216787910_item	3608285	et	3	main
essee	doc_366216787910_item	3608255	et	4	main
keele	doc_366216787910_item	3608240	et	4	main
teise	doc_366216787910_item	3608239	et	4	main
kui	doc_366216787910_item	3608238	et	3	main
keele	doc_366216787910_item	3608237	et	4	main
abil	doc_366216787910_item	3608511	et	4	main
laulad	doc_366216787910_item	3608502	et	3	main
vana	doc_366216787910_item	3608500	et	4	main
et	doc_366216787910_item	3608498	et	3	main
unusta	doc_366216787910_item	3608493	et	4	main
oma	doc_366216787910_item	3608488	et	4	main
palju	doc_213943984965_item	3608678	et	4	main
aga	doc_213943984965_item	3608630	et	3	main
meil	doc_213943984965_item	3608621	et	4	main
aga	doc_213943984965_item	3608606	et	3	main
kottid	doc_213943984965_item	3608604	et	4	main
peab	doc_213943984965_item	3608592	et	4	main
ja	doc_213943984965_item	3608587	et	3	main
maja	doc_213943984965_item	3608584	et	4	main
manifestatsion	doc_366216787910_item	3608383	et	4	main
kes	doc_366216787910_item	3608365	et	4	main
selles	doc_366216787910_item	3608362	et	4	main
on	doc_366216787910_item	3608349	et	4	main
selle	doc_366216787910_item	3608346	et	4	main
arhiiv	doc_366216787910_item	3608345	et	3	main
folklooride	doc_366216787910_item	3608344	et	4	main
suur	doc_366216787910_item	3608343	et	3	main
on	doc_366216787910_item	3608342	et	4	main
kurb	doc_366216787910_item	3608340	et	3	main
eestlastel	doc_366216787910_item	3608341	et	4	main
on	doc_366216787910_item	3608339	et	4	main
meile	doc_366216787910_item	3608338	et	4	main
kui	doc_366216787910_item	3608337	et	3	main
laulame	doc_366216787910_item	3608336	et	4	main
ja	doc_366216787910_item	3608335	et	3	main
rahustada	doc_366216787910_item	3608334	et	3	main
lapse	doc_366216787910_item	3608333	et	4	main
et	doc_366216787910_item	3608332	et	3	main
tahame	doc_366216787910_item	3608331	et	3	main
kui	doc_366216787910_item	3608330	et	3	main
kasutavad	doc_366216787910_item	3608324	et	4	main
õrn	doc_366216787910_item	3608312	et	3	main
ja	doc_366216787910_item	3608311	et	3	main
huvitanud	doc_366216787910_item	3608296	et	4	main
ka	doc_366216787910_item	3608295	et	3	main
laulsid	doc_366216787910_item	3608287	et	4	main
tantsu	doc_366216787910_item	3608284	et	4	main
ning	doc_366216787910_item	3608283	et	3	main
muusikat	doc_366216787910_item	3608282	et	3	main
laulu	doc_366216787910_item	3608281	et	4	main
oma	doc_366216787910_item	3608280	et	4	main
ole	doc_366216787910_item	3608279	et	4	main
ei	doc_366216787910_item	3608278	et	4	main
kellel	doc_366216787910_item	3608277	et	4	main
rahvast	doc_366216787910_item	3608276	et	4	main
mäleta	doc_366216787910_item	3608275	et	4	main
ei	doc_366216787910_item	3608274	et	4	main
ajalugu	doc_366216787910_item	3608273	et	4	main
näidetega	doc_366216787910_item	3608272	et	3	main
illustreerida	doc_366216787910_item	3608271	et	3	main
soovitatav	doc_366216787910_item	3608270	et	4	main
on	doc_366216787910_item	3608269	et	4	main
faktidele	doc_366216787910_item	3608267	et	3	main
väiteid	doc_366216787910_item	3608268	et	4	main
esitatud	doc_366216787910_item	3608266	et	4	main
arutlev	doc_366216787910_item	3608258	et	4	main
olema	doc_366216787910_item	3608257	et	4	main
300	doc_366216787910_item	3608252	et	2	main
pikkus	doc_366216787910_item	3608251	et	4	main
essee	doc_366216787910_item	3608250	et	4	main
me	doc_366216787910_item	3608512	et	4	main
muusika	doc_366216787910_item	3608504	et	4	main
ja	doc_366216787910_item	3608503	et	3	main
mineviku	doc_366216787910_item	3608495	et	3	main
eest	doc_366216787910_item	3608490	et	4	main
on	doc_366216787910_item	3608486	et	4	main
pealt	doc_366216787910_item	3608485	et	4	main
elektripliit	doc_213943984965_item	3608676	et	3	main
mugavam	doc_213943984965_item	3608674	et	4	main
see	doc_213943984965_item	3608672	et	3	main
ei	doc_213943984965_item	3608627	et	4	main
see	doc_213943984965_item	3608626	et	3	main
ja	doc_213943984965_item	3608625	et	3	main
tee	doc_213943984965_item	3608620	et	4	main
midagi	doc_213943984965_item	3608615	et	4	main
heaks	doc_213943984965_item	3608610	et	4	main
võib	doc_213943984965_item	3608608	et	3	main
ei	doc_213943984965_item	3608589	et	4	main
seal	doc_213943984965_item	3608588	et	4	main
on	doc_213943984965_item	3608585	et	4	main
rahul	doc_213943984965_item	3608568	et	4	main
alati	doc_213943984965_item	3608556	et	4	main
et	doc_213943984965_item	3608555	et	3	main
sellepärast	doc_213943984965_item	3608554	et	3	main
tore	doc_213943984965_item	3608553	et	3	main
väga	doc_213943984965_item	3608552	et	3	main
ühetoaline	doc_213943984965_item	3608532	et	4	main
suur	doc_213943984978_item	3608839	et	3	main
minna	doc_213943984978_item	3608823	et	3	main
kividel	doc_213943984978_item	3608817	et	3	main
on	doc_213943984978_item	3608815	et	4	main
et	doc_213943984978_item	3608813	et	3	main
ja	doc_213943984978_item	3608811	et	3	main
kallase	doc_213943984978_item	3608808	et	4	main
selle	doc_213943984978_item	3608807	et	4	main
vaatasime	doc_213943984978_item	3608806	et	3	main
mina	doc_213943984978_item	3608795	et	4	main
ei	doc_213943984978_item	3608789	et	4	main
et	doc_213943984978_item	3608788	et	3	main
asjad	doc_213943984978_item	3608783	et	3	main
ei	doc_213943984978_item	3608772	et	4	main
koer	doc_213943984978_item	3608771	et	3	main
koos	doc_213943984978_item	3608770	et	4	main
jalutasime	doc_213943984978_item	3608769	et	3	main
siis	doc_213943984978_item	3608768	et	3	main
kohtusin	doc_213943984978_item	3608765	et	4	main
võtmed	doc_213943984978_item	3608740	et	3	main
mul	doc_213943984978_item	3608738	et	3	main
jalutada	doc_213943984978_item	3608729	et	3	main
on	doc_213943984978_item	3608721	et	4	main
sõnakulmatuse	doc_213943984980_item	3608977	et	4	main
lõi	doc_213943984980_item	3608965	et	4	main
seda	doc_213943984980_item	3608964	et	3	main
mind	doc_213943984980_item	3608959	et	4	main
juurde	doc_213943984980_item	3608956	et	4	main
kitsapoeg	doc_213943984980_item	3608938	et	3	main
kutsus	doc_213943984980_item	3608936	et	4	main
ja	doc_213943984980_item	3608934	et	3	main
inimesega	doc_213943984980_item	3608932	et	3	main
ema	doc_213943984980_item	3608925	et	4	main
kitsapoeg	doc_213943984980_item	3608915	et	3	main
väike	doc_213943984980_item	3608911	et	4	main
tuli	doc_213943984980_item	3608909	et	4	main
siis	doc_213943984980_item	3608908	et	3	main
mängis	doc_213943984980_item	3608907	et	3	main
seisis	doc_213943984980_item	3608900	et	4	main
õues	doc_213943984980_item	3608892	et	4	main
meie	doc_213943984980_item	3608891	et	4	main
ja	doc_213943984980_item	3608886	et	3	main
meie	doc_213943984980_item	3608879	et	4	main
krõmmis	doc_213943984980_item	3608866	et	4	main
ma	doc_213943984980_item	3608863	et	3	main
elasin	doc_213943984980_item	3608862	et	3	main
tähtsalt	doc_366216787910_item	3608497	et	4	main
oma	doc_366216787910_item	3608494	et	4	main
vähem	doc_213943984965_item	3608683	et	4	main
maksab	doc_213943984965_item	3608682	et	3	main
ja	doc_213943984965_item	3608677	et	3	main
prügikastid	doc_213943984965_item	3608632	et	3	main
elu	doc_213943984965_item	3608629	et	4	main
kergenga	doc_213943984965_item	3608628	et	4	main
tee	doc_213943984965_item	3608617	et	4	main
tegema	doc_213943984965_item	3608611	et	3	main
ka	doc_213943984965_item	3608609	et	3	main
kaasas	doc_213943984965_item	3608605	et	4	main
rasked	doc_213943984965_item	3608603	et	3	main
mul	doc_213943984965_item	3608601	et	3	main
kui	doc_213943984965_item	3608600	et	3	main
ebamugav	doc_213943984965_item	3608599	et	3	main
on	doc_213943984965_item	3608598	et	4	main
see	doc_213943984965_item	3608597	et	3	main
minna	doc_213943984965_item	3608596	et	3	main
koju	doc_213943984965_item	3608595	et	3	main
jalgsi	doc_213943984965_item	3608594	et	3	main
ole	doc_213943984965_item	3608590	et	4	main
viiekorruseline	doc_213943984965_item	3608586	et	4	main
vaikuses	doc_213943984965_item	3608575	et	4	main
magada	doc_213943984965_item	3608574	et	3	main
linnaosa	doc_213943984965_item	3608569	et	4	main
väga	doc_213943984965_item	3608567	et	3	main
palju	doc_213943984965_item	3608559	et	4	main
negatiivne	doc_213943984965_item	3608540	et	3	main
küljed	doc_213943984965_item	3608539	et	3	main
kodu	doc_213943984965_item	3608523	et	4	main
minu	doc_213943984965_item	3608522	et	3	main
väielda	doc_213943984965_item	3608712	et	4	main
mulle	doc_213943984965_item	3608711	et	4	main
proovige	doc_213943984965_item	3608710	et	3	main
noh	doc_213943984965_item	3608709	et	3	main
seal	doc_213943984965_item	3608708	et	4	main
elan	doc_213943984965_item	3608707	et	3	main
et	doc_213943984965_item	3608706	et	3	main
rahul	doc_213943984965_item	3608705	et	4	main
olen	doc_213943984965_item	3608704	et	3	main
mina	doc_213943984965_item	3608703	et	4	main
ja	doc_213943984965_item	3608702	et	3	main
soobib	doc_213943984965_item	3608701	et	4	main
saa	doc_213943984965_item	3608700	et	4	main
mulle	doc_213943984965_item	3608699	et	4	main
aga	doc_213943984965_item	3608698	et	3	main
küljed	doc_213943984965_item	3608697	et	3	main
head	doc_213943984965_item	3608696	et	4	main
ja	doc_213943984965_item	3608695	et	3	main
halvad	doc_213943984965_item	3608694	et	4	main
on	doc_213943984965_item	3608693	et	4	main
seal	doc_213943984965_item	3608692	et	4	main
et	doc_213943984965_item	3608691	et	3	main
on	doc_213943984965_item	3608690	et	4	main
nähtav	doc_213943984965_item	3608689	et	4	main
maja	doc_213943984965_item	3608688	et	4	main
minu	doc_213943984965_item	3608687	et	3	main
on	doc_213943984965_item	3608686	et	4	main
lisaks	doc_213943984965_item	3608680	et	4	main
on	doc_213943984965_item	3608673	et	4	main
minu	doc_213943984965_item	3608670	et	3	main
gaasipliit	doc_213943984965_item	3608669	et	3	main
on	doc_213943984965_item	3608668	et	4	main
mulle	doc_213943984965_item	3608661	et	4	main
lõhna	doc_213943984965_item	3608660	et	4	main
halva	doc_213943984965_item	3608659	et	4	main
ole	doc_213943984965_item	3608658	et	4	main
ei	doc_213943984965_item	3608657	et	4	main
kunagi	doc_213943984965_item	3608656	et	3	main
meil	doc_213943984965_item	3608655	et	4	main
et	doc_213943984965_item	3608654	et	3	main
sellepärast	doc_213943984965_item	3608653	et	3	main
muutuda	doc_213943984965_item	3608652	et	3	main
heaks	doc_213943984965_item	3608651	et	4	main
ka	doc_213943984965_item	3608650	et	3	main
võib	doc_213943984965_item	3608649	et	3	main
sees	doc_213943984965_item	3608648	et	4	main
maja	doc_213943984965_item	3608647	et	4	main
ole	doc_213943984965_item	3608646	et	4	main
ei	doc_213943984965_item	3608645	et	4	main
prügišaht	doc_213943984965_item	3608644	et	2	main
et	doc_213943984965_item	3608643	et	3	main
olukord	doc_213943984965_item	3608642	et	3	main
see	doc_213943984965_item	3608641	et	3	main
raudtaraga	doc_213943984965_item	3608640	et	3	main
kaitstud	doc_213943984965_item	3608639	et	4	main
on	doc_213943984965_item	3608638	et	4	main
maja	doc_213943984965_item	3608636	et	4	main
ees	doc_213943984965_item	3608637	et	4	main
õues	doc_213943984965_item	3608635	et	4	main
asuvad	doc_213943984965_item	3608634	et	4	main
mis	doc_213943984965_item	3608633	et	4	main
prügišahtit	doc_213943984965_item	3608624	et	2	main
ole	doc_213943984965_item	3608623	et	4	main
lärmi	doc_213943984965_item	3608618	et	4	main
ei	doc_213943984965_item	3608616	et	4	main
mitte	doc_213943984965_item	3608614	et	3	main
et	doc_213943984965_item	3608613	et	3	main
sellepärast	doc_213943984965_item	3608612	et	3	main
see	doc_213943984965_item	3608607	et	3	main
lifti	doc_213943984965_item	3608591	et	4	main
on	doc_213943984965_item	3608580	et	4	main
külg	doc_213943984965_item	3608579	et	3	main
negatiivne	doc_213943984965_item	3608578	et	3	main
üks	doc_213943984965_item	3608577	et	3	main
jõuda	doc_213943984965_item	3608563	et	3	main
kesklinna	doc_213943984965_item	3608562	et	4	main
et	doc_213943984965_item	3608561	et	3	main
on	doc_213943984965_item	3608557	et	4	main
see	doc_213943984965_item	3608549	et	3	main
maja	doc_213943984965_item	3608546	et	4	main
et	doc_213943984965_item	3608545	et	3	main
see	doc_213943984965_item	3608544	et	3	main
minu	doc_213943984965_item	3608541	et	3	main
seal	doc_213943984965_item	3608534	et	4	main
korter	doc_213943984965_item	3608533	et	3	main
korrussel	doc_213943984965_item	3608529	et	4	main
kolmandal	doc_213943984965_item	3608528	et	3	main
majas	doc_213943984965_item	3608527	et	3	main
viiekorruselises	doc_213943984965_item	3608526	et	4	main
elan	doc_213943984965_item	3608525	et	3	main
aga	doc_213943984978_item	3608836	et	3	main
võttis	doc_213943984978_item	3608834	et	3	main
sõber	doc_213943984978_item	3608830	et	3	main
minu	doc_213943984978_item	3608829	et	3	main
pikk	doc_213943984978_item	3608828	et	4	main
ja	doc_213943984978_item	3608827	et	3	main
ta	doc_213943984978_item	3608818	et	4	main
poole	doc_213943984978_item	3608810	et	4	main
kivikallas	doc_213943984978_item	3608804	et	4	main
aga	doc_213943984978_item	3608801	et	3	main
tema	doc_213943984978_item	3608793	et	4	main
kus	doc_213943984978_item	3608792	et	3	main
koera	doc_213943984978_item	3608791	et	4	main
me	doc_213943984978_item	3608785	et	4	main
oma	doc_213943984978_item	3608781	et	4	main
tegi	doc_213943984978_item	3608780	et	4	main
jooksis	doc_213943984978_item	3608778	et	4	main
aga	doc_213943984978_item	3608777	et	3	main
tuttavat	doc_213943984978_item	3608767	et	3	main
sõber	doc_213943984978_item	3608727	et	3	main
tagasi	doc_213943984978_item	3608725	et	3	main
suur	doc_213943984978_item	3608722	et	3	main
ta	doc_213943984978_item	3608720	et	4	main
ta	doc_213943984980_item	3608957	et	4	main
ja	doc_213943984980_item	3608953	et	3	main
tahtnud	doc_213943984980_item	3608940	et	4	main
ei	doc_213943984980_item	3608927	et	4	main
ta	doc_213943984980_item	3608926	et	4	main
rõõmus	doc_213943984980_item	3608913	et	4	main
kuidas	doc_213943984980_item	3608904	et	3	main
ja	doc_213943984980_item	3608902	et	3	main
poega	doc_213943984980_item	3608898	et	4	main
oma	doc_213943984980_item	3608897	et	4	main
kits	doc_213943984980_item	3608896	et	3	main
jalutasid	doc_213943984980_item	3608890	et	4	main
loomad	doc_213943984980_item	3608889	et	3	main
kes	doc_213943984980_item	3608881	et	4	main
naabrid	doc_213943984980_item	3608880	et	3	main
mille	doc_213943984980_item	3608874	et	3	main
majas	doc_213943984980_item	3608873	et	3	main
me	doc_213943984980_item	3608870	et	4	main
lähedal	doc_213943984980_item	3608869	et	4	main
perega	doc_213943984980_item	3608865	et	3	main
viieastane	doc_213943984980_item	3608861	et	4	main
olin	doc_213943984980_item	3608860	et	3	main
mina	doc_213943984980_item	3608859	et	4	main
kui	doc_213943984980_item	3608858	et	3	main
sa	doc_213943984986_item	3609124	et	3	main
aga	doc_213943984986_item	3609115	et	3	main
mis	doc_213943984986_item	3609112	et	4	main
kõik	doc_213943984986_item	3609111	et	4	main
teha	doc_213943984986_item	3609110	et	3	main
ole	doc_213943984986_item	3609103	et	4	main
et	doc_213943984986_item	3609086	et	3	main
on	doc_213943984965_item	3608602	et	4	main
alati	doc_213943984965_item	3608593	et	4	main
veel	doc_213943984965_item	3608576	et	4	main
aega	doc_213943984965_item	3608560	et	4	main
ole	doc_213943984965_item	3608551	et	4	main
mina	doc_213943984965_item	3608524	et	4	main
koeraga	doc_213943984978_item	3608855	et	3	main
koer	doc_213943984978_item	3608837	et	3	main
koera	doc_213943984978_item	3608835	et	4	main
oli	doc_213943984978_item	3608825	et	3	main
ei	doc_213943984978_item	3608819	et	4	main
me	doc_213943984978_item	3608805	et	4	main
kõrval	doc_213943984978_item	3608802	et	4	main
on	doc_213943984978_item	3608794	et	4	main
aru	doc_213943984978_item	3608787	et	4	main
saime	doc_213943984978_item	3608786	et	3	main
koera	doc_213943984978_item	3608782	et	4	main
ja	doc_213943984978_item	3608779	et	3	main
oli	doc_213943984978_item	3608739	et	3	main
ei	doc_213943984978_item	3608733	et	4	main
tal	doc_213943984978_item	3608732	et	3	main
koeraga	doc_213943984978_item	3608730	et	3	main
kaks	doc_213943984978_item	3608723	et	3	main
lõi	doc_213943984980_item	3608958	et	4	main
minu	doc_213943984965_item	3608583	et	3	main
et	doc_213943984965_item	3608582	et	3	main
selline	doc_213943984965_item	3608581	et	4	main
alati	doc_213943984965_item	3608573	et	4	main
võin	doc_213943984965_item	3608572	et	3	main
mina	doc_213943984965_item	3608571	et	4	main
ja	doc_213943984965_item	3608570	et	3	main
on	doc_213943984965_item	3608566	et	4	main
see	doc_213943984965_item	3608565	et	3	main
see-eest	doc_213943984965_item	3608564	et	4	main
vaja	doc_213943984965_item	3608558	et	4	main
ei	doc_213943984965_item	3608550	et	4	main
mustamäes	doc_213943984965_item	3608548	et	3	main
asub	doc_213943984965_item	3608547	et	3	main
on	doc_213943984965_item	3608543	et	4	main
majas	doc_213943984965_item	3608542	et	3	main
positiivsed	doc_213943984965_item	3608538	et	3	main
ja	doc_213943984965_item	3608537	et	3	main
negatiivsed	doc_213943984965_item	3608536	et	3	main
on	doc_213943984965_item	3608535	et	4	main
on	doc_213943984965_item	3608531	et	4	main
mul	doc_213943984965_item	3608530	et	3	main
essee	doc_213943984965_item	3608521	et	4	main
allpoole	doc_213943984978_item	3608833	et	4	main
seal	doc_213943984978_item	3608832	et	4	main
läks	doc_213943984978_item	3608831	et	3	main
kallas	doc_213943984978_item	3608824	et	4	main
sealt	doc_213943984978_item	3608821	et	4	main
mere	doc_213943984978_item	3608809	et	3	main
oli	doc_213943984978_item	3608803	et	3	main
koera	doc_213943984978_item	3608800	et	4	main
ole	doc_213943984978_item	3608799	et	4	main
juures	doc_213943984978_item	3608776	et	4	main
minu	doc_213943984978_item	3608775	et	3	main
juba	doc_213943984978_item	3608774	et	3	main
päeva	doc_213943984978_item	3608736	et	4	main
olnud	doc_213943984978_item	3608734	et	4	main
mind	doc_213943984978_item	3608728	et	4	main
eest	doc_213943984980_item	3608978	et	4	main
meid	doc_213943984980_item	3608976	et	4	main
karistas	doc_213943984980_item	3608975	et	3	main
emakits	doc_213943984980_item	3608974	et	3	main
range	doc_213943984980_item	3608973	et	4	main
nii	doc_213943984980_item	3608972	et	3	main
pärast	doc_213943984980_item	3608963	et	4	main
ja	doc_213943984980_item	3608962	et	3	main
sarvega	doc_213943984980_item	3608961	et	3	main
koju	doc_213943984980_item	3608941	et	3	main
poeg	doc_213943984980_item	3608931	et	3	main
tahtnud	doc_213943984980_item	3608928	et	4	main
koos	doc_213943984980_item	3608919	et	4	main
hakkasime	doc_213943984980_item	3608918	et	3	main
ja	doc_213943984980_item	3608912	et	3	main
mina	doc_213943984980_item	3608910	et	4	main
kitsapoeg	doc_213943984980_item	3608906	et	3	main
lähedal	doc_213943984980_item	3608901	et	4	main
emakits	doc_213943984980_item	3608899	et	3	main
jalutasid	doc_213943984980_item	3608888	et	4	main
pidasid	doc_213943984980_item	3608884	et	4	main
eramajdes	doc_213943984980_item	3608883	et	4	main
oli	doc_213943984978_item	3608838	et	3	main
suur	doc_213943984978_item	3608826	et	3	main
välja	doc_213943984978_item	3608822	et	4	main
saanud	doc_213943984978_item	3608820	et	4	main
meres	doc_213943984978_item	3608816	et	3	main
koer	doc_213943984978_item	3608814	et	3	main
nägime	doc_213943984978_item	3608812	et	3	main
ei	doc_213943984978_item	3608798	et	4	main
ümber	doc_213943984978_item	3608797	et	3	main
vaatasin	doc_213943984978_item	3608796	et	3	main
näe	doc_213943984978_item	3608790	et	4	main
varsti	doc_213943984978_item	3608784	et	3	main
olnud	doc_213943984978_item	3608773	et	4	main
oma	doc_213943984978_item	3608766	et	4	main
mina	doc_213943984978_item	3608764	et	4	main
jalutades	doc_213943984978_item	3608763	et	3	main
poole	doc_213943984978_item	3608762	et	4	main
pirita	doc_213943984978_item	3608761	et	4	main
juures	doc_213943984978_item	3608760	et	4	main
minu	doc_213943984978_item	3608759	et	3	main
oli	doc_213943984978_item	3608758	et	3	main
alati	doc_213943984978_item	3608757	et	4	main
koer	doc_213943984978_item	3608756	et	3	main
ja	doc_213943984978_item	3608755	et	3	main
inimesed	doc_213943984978_item	3608754	et	3	main
mitmed	doc_213943984978_item	3608753	et	4	main
oli	doc_213943984978_item	3608752	et	3	main
seal	doc_213943984978_item	3608751	et	4	main
kõrvale	doc_213943984978_item	3608750	et	4	main
russalka	doc_213943984978_item	3608749	et	4	main
äärde	doc_213943984978_item	3608748	et	4	main
mere	doc_213943984978_item	3608747	et	3	main
sõidsin	doc_213943984978_item	3608746	et	4	main
ja	doc_213943984978_item	3608745	et	3	main
koera	doc_213943984978_item	3608744	et	4	main
võtsin	doc_213943984978_item	3608743	et	3	main
tulin	doc_213943984978_item	3608742	et	3	main
mina	doc_213943984978_item	3608741	et	4	main
kodus	doc_213943984978_item	3608737	et	4	main
kogu	doc_213943984978_item	3608735	et	4	main
sest	doc_213943984978_item	3608731	et	4	main
küsis	doc_213943984978_item	3608726	et	3	main
aastat	doc_213943984978_item	3608724	et	3	main
eesnimi	doc_213943984978_item	3608719	et	3	main
koer	doc_213943984978_item	3608718	et	3	main
on	doc_213943984978_item	3608717	et	4	main
sõbral	doc_213943984978_item	3608716	et	3	main
minu	doc_213943984978_item	3608715	et	3	main
essee	doc_213943984978_item	3608714	et	4	main
jalutasin	doc_213943984978_item	3608854	et	3	main
nii	doc_213943984978_item	3608853	et	3	main
puhas	doc_213943984978_item	3608852	et	3	main
väga	doc_213943984978_item	3608851	et	3	main
mitte	doc_213943984978_item	3608850	et	3	main
oli	doc_213943984978_item	3608849	et	3	main
vesi	doc_213943984978_item	3608848	et	4	main
oli	doc_213943984978_item	3608846	et	3	main
must	doc_213943984978_item	3608847	et	4	main
koer	doc_213943984978_item	3608845	et	3	main
juurde	doc_213943984978_item	3608844	et	4	main
minu	doc_213943984978_item	3608843	et	3	main
teda	doc_213943984978_item	3608842	et	4	main
pani	doc_213943984978_item	3608841	et	4	main
ja	doc_213943984978_item	3608840	et	3	main
valus	doc_213943984980_item	3608971	et	4	main
eriti	doc_213943984980_item	3608970	et	3	main
polnud	doc_213943984980_item	3608969	et	3	main
see	doc_213943984980_item	3608968	et	3	main
poega	doc_213943984980_item	3608967	et	4	main
oma	doc_213943984980_item	3608966	et	4	main
oma	doc_213943984980_item	3608960	et	4	main
minu	doc_213943984980_item	3608955	et	3	main
süüdi	doc_213943984980_item	3608952	et	4	main
olen	doc_213943984980_item	3608951	et	3	main
mina	doc_213943984980_item	3608950	et	4	main
et	doc_213943984980_item	3608949	et	3	main
arvas	doc_213943984980_item	3608948	et	3	main
emakits	doc_213943984980_item	3608947	et	3	main
rõõmustada	doc_213943984980_item	3608946	et	3	main
minuga	doc_213943984980_item	3608945	et	3	main
jätkas	doc_213943984980_item	3608944	et	3	main
ja	doc_213943984980_item	3608943	et	3	main
tulla	doc_213943984980_item	3608942	et	3	main
teda	doc_213943984980_item	3608937	et	4	main
ta	doc_213943984980_item	3608935	et	4	main
mängis	doc_213943984980_item	3608933	et	3	main
tema	doc_213943984980_item	3608930	et	4	main
et	doc_213943984980_item	3608929	et	3	main
range	doc_213943984980_item	3608924	et	4	main
väga	doc_213943984980_item	3608923	et	3	main
oli	doc_213943984980_item	3608922	et	3	main
kits	doc_213943984980_item	3608921	et	3	main
mängima	doc_213943984980_item	3608920	et	3	main
nagu	doc_213943984980_item	3608914	et	3	main
tema	doc_213943984980_item	3608905	et	4	main
meile	doc_213943984980_item	3608895	et	4	main
elasid	doc_213943984980_item	3608882	et	4	main
eramajad	doc_213943984980_item	3608878	et	3	main
seisisid	doc_213943984980_item	3608876	et	3	main
essee	doc_213943984980_item	3608857	et	4	main
tuli	doc_213943984980_item	3608954	et	4	main
ei	doc_213943984980_item	3608939	et	4	main
me	doc_213943984980_item	3608917	et	4	main
ise	doc_213943984980_item	3608916	et	4	main
vaatas	doc_213943984980_item	3608903	et	3	main
tuli	doc_213943984980_item	3608894	et	4	main
ükskord	doc_213943984980_item	3608893	et	3	main
nad	doc_213943984980_item	3608887	et	3	main
loomi	doc_213943984980_item	3608885	et	4	main
väikesed	doc_213943984980_item	3608877	et	4	main
elasime	doc_213943984980_item	3608871	et	3	main
võimalus	doc_213943984986_item	3609120	et	3	main
saa	doc_213943984986_item	3609109	et	4	main
elama	doc_213943984986_item	3609101	et	3	main
on	doc_213943984986_item	3609091	et	4	main
kus	doc_213943984986_item	3609090	et	3	main
toad	doc_213943984986_item	3609089	et	3	main
on	doc_213943984986_item	3609088	et	4	main
kuna	doc_213943984986_item	3609083	et	3	main
tüdrukud	doc_213943984986_item	3609066	et	3	main
mulle	doc_213943984986_item	3609053	et	4	main
aga	doc_213943984986_item	3609052	et	3	main
lamp	doc_213943984986_item	3609051	et	3	main
on	doc_213943984986_item	3609046	et	4	main
minu	doc_213943984986_item	3609044	et	3	main
ma	doc_213943984986_item	3609041	et	3	main
et	doc_213943984986_item	3609027	et	3	main
ma	doc_213943984986_item	3609025	et	3	main
positiivsed	doc_213943984986_item	3609003	et	3	main
korrusel	doc_213943984986_item	3608999	et	3	main
asub	doc_213943984986_item	3608997	et	3	main
mina	doc_213943984986_item	3608992	et	4	main
praegu	doc_213943984986_item	3608991	et	3	main
kolisin	doc_213943984986_item	3608989	et	3	main
sügisel	doc_213943984986_item	3608987	et	3	main
olen	doc_213943984986_item	3608982	et	3	main
ma	doc_213943984986_item	3608981	et	3	main
ümbruses	doc_213943984980_item	3608875	et	3	main
suures	doc_213943984980_item	3608872	et	3	main
mäede	doc_213943984980_item	3608868	et	4	main
karu	doc_213943984980_item	3608867	et	4	main
oma	doc_213943984980_item	3608864	et	4	main
elada	doc_213943984986_item	3609121	et	3	main
ole	doc_213943984986_item	3609119	et	4	main
sul	doc_213943984986_item	3609117	et	3	main
kui	doc_213943984986_item	3609116	et	3	main
sulle	doc_213943984986_item	3609113	et	3	main
ei	doc_213943984986_item	3609102	et	4	main
seal	doc_213943984986_item	3609100	et	4	main
et	doc_213943984986_item	3609098	et	3	main
öelda	doc_213943984986_item	3609097	et	4	main
tahaksin	doc_213943984986_item	3609096	et	3	main
ma	doc_213943984986_item	3609095	et	3	main
lõpetuseks	doc_213943984986_item	3609094	et	4	main
külm	doc_213943984986_item	3609093	et	3	main
väga	doc_213943984986_item	3609092	et	3	main
ühiselamus	doc_213943984986_item	3609087	et	4	main
vaba	doc_213943984986_item	3609073	et	4	main
on	doc_213943984986_item	3609072	et	4	main
kui	doc_213943984986_item	3609071	et	3	main
puhtaks	doc_213943984986_item	3609070	et	3	main
koristavad	doc_213943984986_item	3609069	et	4	main
ja	doc_213943984986_item	3609068	et	3	main
seal	doc_213943984986_item	3609065	et	4	main
avar	doc_213943984986_item	3609061	et	3	main
ebahea	doc_213943984986_item	3609050	et	4	main
voodid	doc_213943984986_item	3609048	et	3	main
arvan	doc_213943984986_item	3609042	et	3	main
on	doc_213943984986_item	3609034	et	4	main
mõnikord	doc_213943984986_item	3609033	et	3	main
kuna	doc_213943984986_item	3609032	et	3	main
õhkkonnale	doc_213943984986_item	3609031	et	4	main
minu	doc_213943984986_item	3608995	et	3	main
ma	doc_213943984986_item	3608988	et	3	main
sel	doc_213943984986_item	3608986	et	3	main
on	doc_213943985001_item	3609260	et	4	main
lõbus	doc_213943985001_item	3609248	et	4	main
et	doc_213943985001_item	3609243	et	3	main
arvamus	doc_213943985001_item	3609242	et	3	main
saada	doc_213943985001_item	3609238	et	4	main
võimalus	doc_213943985001_item	3609236	et	3	main
kus	doc_213943985001_item	3609233	et	3	main
koht	doc_213943985001_item	3609231	et	3	main
parim	doc_213943985001_item	3609230	et	4	main
et	doc_213943985001_item	3609226	et	3	main
eriala	doc_213943985001_item	3609223	et	4	main
huvitava	doc_213943985001_item	3609222	et	4	main
kõrgharidusi	doc_213943985001_item	3609218	et	3	main
valisin	doc_213943985001_item	3609209	et	3	main
ise	doc_213943985001_item	3609208	et	4	main
ja	doc_213943985001_item	3609194	et	3	main
mul	doc_213943985001_item	3609190	et	3	main
jaoks	doc_213943985001_item	3609188	et	4	main
tallinna	doc_213943985008_item	3609343	et	4	main
ja	doc_213943985008_item	3609342	et	3	main
õppimisest	doc_213943985008_item	3609339	et	4	main
teada	doc_213943985008_item	3609335	et	3	main
ma	doc_213943985008_item	3609333	et	3	main
kooli	doc_213943985008_item	3609331	et	4	main
on	doc_213943985008_item	3609328	et	4	main
see	doc_213943985008_item	3609327	et	3	main
meeldib	doc_213943985008_item	3609309	et	3	main
palju	doc_213943985008_item	3609306	et	4	main
sain	doc_213943985008_item	3609305	et	3	main
ma	doc_213943985008_item	3609304	et	3	main
on	doc_213943985008_item	3609296	et	4	main
huvitav	doc_213943985008_item	3609293	et	4	main
erialla	doc_213943985008_item	3609283	et	4	main
selle	doc_213943985008_item	3609274	et	4	main
erialla	doc_213943985008_item	3609269	et	4	main
selle	doc_213943985008_item	3609268	et	4	main
minu	doc_213943985010_item	3609423	et	3	main
tulen	doc_213943985010_item	3609409	et	3	main
avauksepäeva	doc_213943985010_item	3609405	et	4	main
väga	doc_213943985010_item	3609390	et	3	main
tallinna	doc_213943985010_item	3609368	et	4	main
selle	doc_213943985010_item	3609359	et	4	main
valisin	doc_213943985010_item	3609358	et	3	main
ma	doc_213943985010_item	3609357	et	3	main
veel	doc_213943984986_item	3609123	et	4	main
ei	doc_213943984986_item	3609108	et	4	main
sa	doc_213943984986_item	3609107	et	3	main
kuskil	doc_213943984986_item	3609122	et	3	main
ei	doc_213943984986_item	3609118	et	4	main
meeldib	doc_213943984986_item	3609114	et	3	main
mugav	doc_213943984986_item	3609104	et	3	main
muidugi	doc_213943984986_item	3609099	et	4	main
ma	doc_213943984986_item	3609084	et	3	main
on	doc_213943984986_item	3609056	et	4	main
et	doc_213943984986_item	3609055	et	3	main
tundub	doc_213943984986_item	3609054	et	3	main
veel	doc_213943984986_item	3609036	et	4	main
konfliktid	doc_213943984986_item	3609035	et	3	main
see	doc_213943984986_item	3609028	et	3	main
harjumused	doc_213943984986_item	3609024	et	4	main
ja	doc_213943984986_item	3609023	et	3	main
iseloomad	doc_213943984986_item	3609022	et	3	main
on	doc_213943984986_item	3609020	et	4	main
erinevad	doc_213943984986_item	3609021	et	4	main
inimestel	doc_213943984986_item	3609019	et	3	main
sest	doc_213943984986_item	3609018	et	4	main
meeldi	doc_213943984986_item	3609017	et	4	main
ei	doc_213943984986_item	3609016	et	4	main
mulle	doc_213943984986_item	3609015	et	4	main
see	doc_213943984986_item	3609014	et	3	main
ja	doc_213943984986_item	3609013	et	3	main
toas	doc_213943984986_item	3609012	et	3	main
ühes	doc_213943984986_item	3609011	et	4	main
kolmekesi	doc_213943984986_item	3609010	et	3	main
elame	doc_213943984986_item	3609009	et	3	main
me	doc_213943984986_item	3609008	et	4	main
küljed	doc_213943984986_item	3609007	et	3	main
negatiivsed	doc_213943984986_item	3609006	et	3	main
ka	doc_213943984986_item	3609005	et	3	main
kui	doc_213943984986_item	3609004	et	3	main
et	doc_213943984986_item	3609106	et	3	main
sellepärast	doc_213943984986_item	3609105	et	3	main
tean	doc_213943984986_item	3609085	et	3	main
on	doc_213943984986_item	3609081	et	4	main
ta	doc_213943984986_item	3609080	et	4	main
et	doc_213943984986_item	3609079	et	3	main
mõtlema	doc_213943984986_item	3609078	et	3	main
kaldun	doc_213943984986_item	3609077	et	3	main
ma	doc_213943984986_item	3609076	et	3	main
veel	doc_213943984986_item	3609075	et	4	main
aeg	doc_213943984986_item	3609074	et	3	main
elavad	doc_213943984986_item	3609067	et	4	main
sest	doc_213943984986_item	3609064	et	4	main
korralik	doc_213943984986_item	3609063	et	3	main
ja	doc_213943984986_item	3609049	et	3	main
seal	doc_213943984986_item	3609037	et	4	main
mõjutab	doc_213943984986_item	3609029	et	3	main
on	doc_213943984986_item	3609002	et	4	main
pead	doc_213943984986_item	3609125	et	4	main
kõik	doc_213943985001_item	3609261	et	4	main
ootan	doc_213943985001_item	3609253	et	3	main
õppimisest	doc_213943985001_item	3609249	et	4	main
on	doc_213943985001_item	3609246	et	4	main
üliõpilane	doc_213943985001_item	3609244	et	3	main
ülikool	doc_213943985001_item	3609228	et	4	main
mis	doc_213943985001_item	3609213	et	4	main
eriala	doc_213943985001_item	3609211	et	4	main
sõber	doc_213943985001_item	3609192	et	3	main
on	doc_213943985001_item	3609191	et	4	main
eriala	doc_213943985001_item	3609136	et	4	main
selles	doc_213943985008_item	3609340	et	4	main
kõig	doc_213943985008_item	3609336	et	4	main
tahan	doc_213943985008_item	3609334	et	3	main
mulle	doc_213943985008_item	3609308	et	4	main
kirjutama	doc_213943985008_item	3609307	et	3	main
eest	doc_213943985008_item	3609303	et	4	main
mille	doc_213943985008_item	3609302	et	3	main
vaatamisvärsuseid	doc_213943985008_item	3609301	et	4	main
ilusad	doc_213943985008_item	3609300	et	3	main
ja	doc_213943985008_item	3609299	et	3	main
tallinnas	doc_213943985008_item	3609295	et	4	main
väga	doc_213943985008_item	3609292	et	3	main
mulle	doc_213943985008_item	3609287	et	4	main
et	doc_213943985008_item	3609286	et	3	main
pärast	doc_213943985008_item	3609285	et	4	main
tallinna	doc_213943985008_item	3609277	et	4	main
ja	doc_213943985008_item	3609276	et	3	main
2	doc_213943985008_item	3609270	et	2	main
valisin	doc_213943985008_item	3609267	et	3	main
ma	doc_213943985008_item	3609266	et	3	main
miks	doc_213943985008_item	3609265	et	4	main
essee	doc_213943985008_item	3609263	et	4	main
soe	doc_213943984986_item	3609082	et	4	main
ja	doc_213943984986_item	3609062	et	3	main
on	doc_213943984986_item	3609060	et	4	main
tuba	doc_213943984986_item	3609059	et	4	main
pluusid	doc_213943984986_item	3609058	et	3	main
ka	doc_213943984986_item	3609057	et	3	main
vanad	doc_213943984986_item	3609047	et	3	main
toas	doc_213943984986_item	3609045	et	3	main
et	doc_213943984986_item	3609043	et	3	main
tegemata	doc_213943984986_item	3609040	et	4	main
on	doc_213943984986_item	3609039	et	4	main
remont	doc_213943984986_item	3609038	et	3	main
sõbralikule	doc_213943984986_item	3609030	et	3	main
mõtlen	doc_213943984986_item	3609026	et	3	main
igal	doc_213943984986_item	3609000	et	3	main
elan	doc_213943984986_item	3608993	et	3	main
aga	doc_213943984986_item	3608985	et	3	main
pärit	doc_213943984986_item	3608983	et	3	main
saada	doc_213943985001_item	3609257	et	4	main
töökoht	doc_213943985001_item	3609256	et	3	main
sellel	doc_213943985001_item	3609250	et	4	main
ja	doc_213943985001_item	3609239	et	3	main
mul	doc_213943985001_item	3609234	et	3	main
on	doc_213943985001_item	3609229	et	4	main
arvan	doc_213943985001_item	3609225	et	3	main
hea	doc_213943985001_item	3609217	et	4	main
siis	doc_213943985001_item	3609207	et	3	main
ja	doc_213943985001_item	3609206	et	3	main
positiivne	doc_213943985001_item	3609205	et	3	main
väga	doc_213943985001_item	3609204	et	3	main
ja	doc_213943985001_item	3609203	et	3	main
huvitav	doc_213943985001_item	3609202	et	4	main
et	doc_213943985001_item	3609198	et	3	main
ka	doc_213943985001_item	3609189	et	3	main
ühiskonna	doc_213943985001_item	3609187	et	4	main
selle	doc_213943985001_item	3609135	et	4	main
valisin	doc_213943985001_item	3609134	et	3	main
miks	doc_213943985001_item	3609132	et	4	main
oma	doc_213943985008_item	3609337	et	4	main
õppima	doc_213943985008_item	3609332	et	3	main
kui	doc_213943985008_item	3609330	et	3	main
raske	doc_213943985008_item	3609329	et	4	main
selle	doc_213943985008_item	3609284	et	4	main
eriallal	doc_213943985008_item	3609275	et	4	main
1	doc_213943985008_item	3609264	et	2	main
ma	doc_213943985010_item	3609420	et	3	main
siin	doc_213943985010_item	3609411	et	4	main
õppida	doc_213943985010_item	3609410	et	3	main
et	doc_213943985010_item	3609408	et	3	main
tallinna	doc_213943985010_item	3609403	et	4	main
missugune	doc_213943985010_item	3609398	et	3	main
edasi	doc_213943985010_item	3609395	et	3	main
küsimus	doc_213943985010_item	3609392	et	4	main
tähtis	doc_213943985010_item	3609391	et	4	main
kooli	doc_213943985010_item	3609387	et	4	main
mina	doc_213943985010_item	3609385	et	4	main
erialal	doc_213943985010_item	3609366	et	3	main
annaks	doc_213943985010_item	3609463	et	4	main
ajakirjandus	doc_213943985010_item	3609462	et	3	main
et	doc_213943985010_item	3609461	et	3	main
loodan	doc_213943985010_item	3609460	et	3	main
erinevaid	doc_213943985010_item	3609452	et	4	main
ülatatud	doc_213943985015_item	3609600	et	4	main
juba	doc_213943985015_item	3609599	et	3	main
on	doc_213943985015_item	3609598	et	4	main
keele	doc_213943985015_item	3609588	et	4	main
probleemid	doc_213943985015_item	3609583	et	3	main
jne	doc_213943985015_item	3609582	et	4	main
venelased	doc_213943985015_item	3609581	et	3	main
on	doc_213943985015_item	3609562	et	4	main
probleem	doc_213943985015_item	3609561	et	3	main
suur	doc_213943985015_item	3609560	et	3	main
oma	doc_213943985015_item	3609556	et	4	main
suuremaks	doc_213943985015_item	3609542	et	4	main
seda	doc_213943985015_item	3609541	et	3	main
mida	doc_213943985015_item	3609537	et	4	main
õppimesel	doc_213943985015_item	3609533	et	4	main
keele	doc_213943985015_item	3609532	et	4	main
on	doc_213943985015_item	3609531	et	4	main
aga	doc_213943985015_item	3609530	et	3	main
suheldama	doc_213943985015_item	3609529	et	3	main
aktiivselt	doc_213943985015_item	3609528	et	4	main
asjal	doc_213943984986_item	3609001	et	3	main
kolmandal	doc_213943984986_item	3608998	et	3	main
tuba	doc_213943984986_item	3608996	et	4	main
ühiselamus	doc_213943984986_item	3608994	et	4	main
tallinnasse	doc_213943984986_item	3608990	et	3	main
narvast	doc_213943984986_item	3608984	et	4	main
essee	doc_213943984986_item	3608980	et	4	main
arvamustega	doc_213943984986_item	3609128	et	3	main
inimeste	doc_213943984986_item	3609127	et	3	main
arvestama	doc_213943984986_item	3609126	et	3	main
ja	doc_213943985001_item	3609258	et	3	main
võimalusi	doc_213943985001_item	3609254	et	3	main
erialal	doc_213943985001_item	3609251	et	3	main
mul	doc_213943985001_item	3609240	et	3	main
kõrgharidus	doc_213943985001_item	3609237	et	3	main
on	doc_213943985001_item	3609235	et	4	main
eestis	doc_213943985001_item	3609232	et	3	main
tallinna	doc_213943985001_item	3609227	et	4	main
ka	doc_213943985001_item	3609224	et	3	main
saada	doc_213943985001_item	3609216	et	4	main
tahan	doc_213943985001_item	3609215	et	3	main
ootan	doc_213943985001_item	3609214	et	3	main
2	doc_213943985001_item	3609212	et	2	main
on	doc_213943985001_item	3609201	et	4	main
ajakirjanik	doc_213943985001_item	3609193	et	3	main
ajakirjandus	doc_213943985001_item	3609161	et	3	main
meeldib	doc_213943985001_item	3609160	et	3	main
mulle	doc_213943985001_item	3609159	et	4	main
asi	doc_213943985001_item	3609158	et	4	main
huvitav	doc_213943985001_item	3609157	et	4	main
väga	doc_213943985001_item	3609156	et	3	main
on	doc_213943985001_item	3609155	et	4	main
ajakirjandus	doc_213943985001_item	3609154	et	3	main
et	doc_213943985001_item	3609153	et	3	main
arvan	doc_213943985001_item	3609152	et	3	main
et	doc_213943985001_item	3609151	et	3	main
sest	doc_213943985001_item	3609150	et	4	main
eriala	doc_213943985001_item	3609149	et	4	main
selle	doc_213943985001_item	3609148	et	4	main
valisin	doc_213943985001_item	3609147	et	3	main
1	doc_213943985001_item	3609146	et	2	main
ülikoolis	doc_213943985001_item	3609145	et	4	main
tallinna	doc_213943985001_item	3609144	et	4	main
ja	doc_213943985001_item	3609143	et	3	main
sellel	doc_213943985001_item	3609141	et	4	main
erialal	doc_213943985001_item	3609142	et	3	main
õppimisest	doc_213943985001_item	3609140	et	4	main
ootan	doc_213943985001_item	3609139	et	3	main
mida	doc_213943985001_item	3609138	et	4	main
2	doc_213943985001_item	3609137	et	2	main
siis	doc_213943985001_item	3609259	et	3	main
hea	doc_213943985001_item	3609255	et	4	main
aga	doc_213943985001_item	3609252	et	3	main
väga	doc_213943985001_item	3609247	et	3	main
elu	doc_213943985001_item	3609245	et	4	main
on	doc_213943985001_item	3609241	et	4	main
jaoks	doc_213943985001_item	3609221	et	4	main
minu	doc_213943985001_item	3609220	et	3	main
ja	doc_213943985001_item	3609219	et	3	main
selle	doc_213943985001_item	3609210	et	4	main
elu	doc_213943985001_item	3609200	et	4	main
tema	doc_213943985001_item	3609199	et	4	main
arvamus	doc_213943985001_item	3609197	et	3	main
on	doc_213943985001_item	3609196	et	4	main
mul	doc_213943985001_item	3609195	et	3	main
tähtis	doc_213943985001_item	3609186	et	4	main
väga	doc_213943985001_item	3609185	et	3	main
on	doc_213943985001_item	3609184	et	4	main
tv	doc_213943985001_item	3609183	et	4	main
ja	doc_213943985001_item	3609182	et	3	main
raadio	doc_213943985001_item	3609181	et	4	main
ajalehed	doc_213943985001_item	3609180	et	3	main
siis	doc_213943985001_item	3609179	et	3	main
ja	doc_213943985001_item	3609178	et	3	main
asi	doc_213943985001_item	3609177	et	4	main
palju	doc_213943985001_item	3609176	et	4	main
teada	doc_213943985001_item	3609175	et	3	main
peavad	doc_213943985001_item	3609174	et	4	main
inimesed	doc_213943985001_item	3609173	et	3	main
tänapäeval	doc_213943985001_item	3609172	et	3	main
elus	doc_213943985001_item	3609171	et	4	main
meie	doc_213943985001_item	3609170	et	4	main
tähtis	doc_213943985001_item	3609169	et	4	main
väga	doc_213943985001_item	3609168	et	3	main
on	doc_213943985001_item	3609167	et	4	main
media	doc_213943985001_item	3609166	et	4	main
et	doc_213943985001_item	3609165	et	3	main
ka	doc_213943985001_item	3609164	et	3	main
arvan	doc_213943985001_item	3609163	et	3	main
ja	doc_213943985001_item	3609162	et	3	main
ma	doc_213943985001_item	3609133	et	3	main
1	doc_213943985001_item	3609131	et	2	main
essee	doc_213943985001_item	3609130	et	4	main
eriala	doc_213943985008_item	3609338	et	4	main
huvitavaid	doc_213943985008_item	3609298	et	4	main
meeldima	doc_213943985008_item	3609288	et	3	main
ma	doc_213943985008_item	3609280	et	3	main
õppimisest	doc_213943985008_item	3609273	et	4	main
ootan	doc_213943985008_item	3609272	et	3	main
ajakirjandus	doc_213943985010_item	3609422	et	3	main
filoloogia	doc_213943985010_item	3609418	et	4	main
ajakirjandus	doc_213943985010_item	3609415	et	3	main
ja	doc_213943985010_item	3609406	et	3	main
külastasin	doc_213943985010_item	3609402	et	3	main
tekkis	doc_213943985010_item	3609389	et	3	main
lõpetasin	doc_213943985010_item	3609386	et	3	main
1	doc_213943985010_item	3609355	et	2	main
essee	doc_213943985010_item	3609354	et	4	main
suhelda	doc_213943985010_item	3609471	et	4	main
töötada	doc_213943985010_item	3609469	et	3	main
huvitav	doc_213943985010_item	3609467	et	4	main
veel	doc_213943985010_item	3609465	et	4	main
mulle	doc_213943985010_item	3609464	et	4	main
välismaal	doc_213943985010_item	3609456	et	4	main
me	doc_213943985015_item	3609602	et	4	main
siis	doc_213943985015_item	3609601	et	3	main
kaduvad	doc_213943985015_item	3609592	et	4	main
probleemid	doc_213943985015_item	3609591	et	3	main
vahel	doc_213943985015_item	3609585	et	4	main
ja	doc_213943985015_item	3609566	et	3	main
vead	doc_213943985015_item	3609558	et	4	main
suheldab	doc_213943985015_item	3609551	et	4	main
kui	doc_213943985015_item	3609549	et	3	main
vääriti	doc_213943985015_item	3609547	et	4	main
paremine	doc_213943985015_item	3609538	et	4	main
teadmisi	doc_213943985015_item	3609524	et	4	main
teoretilisi	doc_213943985015_item	3609523	et	4	main
koguma	doc_213943985015_item	3609522	et	3	main
teise	doc_213943985015_item	3609488	et	4	main
ja	doc_213943985015_item	3609483	et	3	main
keel	doc_213943985017_item	3609660	et	4	main
tegemist	doc_213943985017_item	3609647	et	4	main
üksteist	doc_213943985017_item	3609644	et	4	main
suuremaks	doc_213943985017_item	3609640	et	4	main
mida	doc_213943985017_item	3609635	et	4	main
kultuuri	doc_213943985017_item	3609634	et	4	main
maa	doc_213943985017_item	3609633	et	4	main
õppima	doc_213943985017_item	3609632	et	3	main
tundma	doc_213943985017_item	3609631	et	3	main
võimaluse	doc_213943985017_item	3609630	et	3	main
on	doc_213943985017_item	3609623	et	4	main
kultuur	doc_213943985017_item	3609622	et	3	main
ja	doc_213943985017_item	3609621	et	3	main
kultuur	doc_213943985017_item	3609617	et	3	main
ja	doc_213943985017_item	3609616	et	3	main
ja	doc_213943985017_item	3609690	et	3	main
b	doc_213943985021_item	3609807	et	4	main
siis	doc_213943985021_item	3609805	et	3	main
a	doc_213943985021_item	3609803	et	4	main
tõde	doc_213943985021_item	3609798	et	4	main
ei	doc_213943985021_item	3609796	et	4	main
tähendab	doc_213943985021_item	3609795	et	3	main
b	doc_213943985021_item	3609794	et	4	main
vastandid	doc_213943985021_item	3609779	et	3	main
enesearendamisvõimalusi	doc_213943985021_item	3609765	et	4	main
araldab	doc_213943985021_item	3609755	et	4	main
sügav	doc_213943985021_item	3609752	et	4	main
viis	doc_213943985021_item	3609749	et	4	main
leida	doc_213943985021_item	3609748	et	3	main
kuidas	doc_213943985021_item	3609747	et	3	main
on	doc_213943985021_item	3609746	et	4	main
vabalt	doc_213943985027_item	3609885	et	4	main
kultuuriparadoksiga	doc_213943985027_item	3609858	et	4	main
võimalused	doc_213943985027_item	3609854	et	3	main
annab	doc_213943985027_item	3609839	et	3	main
see	doc_213943985027_item	3609838	et	3	main
kultuuri	doc_213943985027_item	3609837	et	4	main
keele	doc_213943985027_item	3609834	et	4	main
kultuuri	doc_213943985027_item	3609833	et	4	main
leida	doc_213943985028_item	3610081	et	3	main
väga	doc_213943985028_item	3610078	et	3	main
ma	doc_213943985028_item	3610073	et	3	main
sõbrad	doc_213943985008_item	3609352	et	3	main
huvitavad	doc_213943985008_item	3609351	et	4	main
palju	doc_213943985008_item	3609350	et	4	main
ja	doc_213943985008_item	3609349	et	3	main
asju	doc_213943985008_item	3609348	et	3	main
palju	doc_213943985008_item	3609347	et	4	main
ootan	doc_213943985008_item	3609346	et	3	main
ma	doc_213943985008_item	3609345	et	3	main
ülikoolik	doc_213943985008_item	3609344	et	3	main
eriallal	doc_213943985008_item	3609341	et	4	main
uudised	doc_213943985008_item	3609326	et	3	main
vaatasin	doc_213943985008_item	3609325	et	3	main
ja	doc_213943985008_item	3609324	et	3	main
ajalehed	doc_213943985008_item	3609323	et	3	main
lugema	doc_213943985008_item	3609322	et	4	main
palju	doc_213943985008_item	3609321	et	4	main
õppisin	doc_213943985008_item	3609320	et	3	main
palju	doc_213943985008_item	3609319	et	4	main
pean	doc_213943985008_item	3609318	et	4	main
mulle	doc_213943985008_item	3609317	et	4	main
et	doc_213943985008_item	3609316	et	3	main
tean	doc_213943985008_item	3609315	et	3	main
ma	doc_213943985008_item	3609314	et	3	main
muidugi	doc_213943985008_item	3609313	et	4	main
inimised	doc_213943985008_item	3609312	et	4	main
koos	doc_213943985008_item	3609311	et	4	main
töötama	doc_213943985008_item	3609310	et	3	main
palju	doc_213943985008_item	3609297	et	4	main
erialla	doc_213943985008_item	3609294	et	4	main
on	doc_213943985008_item	3609291	et	4	main
see	doc_213943985008_item	3609290	et	3	main
ajakirjandus	doc_213943985008_item	3609289	et	3	main
selle	doc_213943985008_item	3609282	et	4	main
valisin	doc_213943985008_item	3609281	et	3	main
1	doc_213943985008_item	3609279	et	2	main
ülikoolis	doc_213943985008_item	3609278	et	4	main
mida	doc_213943985008_item	3609271	et	4	main
arvamus	doc_213943985010_item	3609424	et	3	main
lõpuks	doc_213943985010_item	3609419	et	4	main
vene	doc_213943985010_item	3609417	et	4	main
või	doc_213943985010_item	3609416	et	4	main
valik	doc_213943985010_item	3609414	et	3	main
on	doc_213943985010_item	3609413	et	4	main
mul	doc_213943985010_item	3609412	et	3	main
ülikooli	doc_213943985010_item	3609404	et	4	main
mina	doc_213943985010_item	3609401	et	4	main
ja	doc_213943985010_item	3609397	et	3	main
läks	doc_213943985010_item	3609394	et	3	main
kuhu	doc_213943985010_item	3609393	et	3	main
siis	doc_213943985010_item	3609388	et	3	main
eriala	doc_213943985010_item	3609360	et	4	main
inimestele	doc_213943985010_item	3609473	et	3	main
ja	doc_213943985010_item	3609470	et	3	main
võimalus	doc_213943985010_item	3609468	et	3	main
üks	doc_213943985010_item	3609466	et	3	main
huvitavaid	doc_213943985010_item	3609458	et	4	main
palju	doc_213943985010_item	3609457	et	4	main
näiteks	doc_213943985010_item	3609454	et	4	main
studentile	doc_213943985010_item	3609450	et	4	main
ülikool	doc_213943985010_item	3609447	et	4	main
tallinna	doc_213943985010_item	3609446	et	4	main
laiendada	doc_213943985010_item	3609445	et	3	main
maailmavaade	doc_213943985010_item	3609444	et	3	main
oma	doc_213943985010_item	3609443	et	4	main
mulle	doc_213943985010_item	3609442	et	4	main
aitaks	doc_213943985010_item	3609441	et	3	main
õppimine	doc_213943985010_item	3609440	et	4	main
ülikooli	doc_213943985010_item	3609439	et	4	main
tallina	doc_213943985010_item	3609438	et	3	main
et	doc_213943985010_item	3609437	et	3	main
loodan	doc_213943985010_item	3609436	et	3	main
töökoht	doc_213943985010_item	3609435	et	3	main
hea	doc_213943985010_item	3609434	et	4	main
saan	doc_213943985010_item	3609433	et	4	main
ülikooli	doc_213943985010_item	3609432	et	4	main
lõpetan	doc_213943985010_item	3609431	et	3	main
ma	doc_213943985010_item	3609430	et	3	main
kui	doc_213943985010_item	3609429	et	3	main
ja	doc_213943985010_item	3609428	et	3	main
perspektiivsem	doc_213943985010_item	3609427	et	4	main
on	doc_213943985010_item	3609426	et	4	main
see	doc_213943985010_item	3609425	et	3	main
valisin	doc_213943985010_item	3609421	et	3	main
otsusin	doc_213943985010_item	3609407	et	3	main
valida	doc_213943985010_item	3609400	et	3	main
eriala	doc_213943985010_item	3609399	et	4	main
õppida	doc_213943985010_item	3609396	et	3	main
kui	doc_213943985010_item	3609384	et	3	main
realiseerida	doc_213943985010_item	3609383	et	3	main
plaani	doc_213943985010_item	3609382	et	4	main
oma	doc_213943985010_item	3609381	et	4	main
võimalus	doc_213943985010_item	3609380	et	3	main
hea	doc_213943985010_item	3609379	et	4	main
on	doc_213943985010_item	3609378	et	4	main
see	doc_213943985010_item	3609377	et	3	main
eriala	doc_213943985010_item	3609376	et	4	main
huvitav	doc_213943985010_item	3609375	et	4	main
väga	doc_213943985010_item	3609374	et	3	main
on	doc_213943985010_item	3609373	et	4	main
ajakirjandus	doc_213943985010_item	3609372	et	3	main
et	doc_213943985010_item	3609371	et	3	main
arvan	doc_213943985010_item	3609370	et	3	main
ülikoolis	doc_213943985010_item	3609369	et	4	main
ja	doc_213943985010_item	3609367	et	3	main
sellel	doc_213943985010_item	3609365	et	4	main
õppimisest	doc_213943985010_item	3609364	et	4	main
ootan	doc_213943985010_item	3609363	et	3	main
mida	doc_213943985010_item	3609362	et	4	main
2	doc_213943985010_item	3609361	et	2	main
välismaal	doc_213943985010_item	3609476	et	4	main
ja	doc_213943985010_item	3609475	et	3	main
eestis	doc_213943985010_item	3609474	et	3	main
võimalusi	doc_213943985010_item	3609453	et	3	main
arusaamisest	doc_213943985015_item	3609611	et	4	main
kultuuri	doc_213943985015_item	3609608	et	4	main
on	doc_213943985015_item	3609606	et	4	main
keelebarjäär	doc_213943985015_item	3609597	et	3	main
kui	doc_213943985015_item	3609596	et	3	main
seda	doc_213943985015_item	3609595	et	3	main
pärast	doc_213943985015_item	3609594	et	4	main
halba	doc_213943985015_item	3609587	et	4	main
hulg	doc_213943985015_item	3609580	et	4	main
suur	doc_213943985015_item	3609579	et	3	main
teine	doc_213943985015_item	3609559	et	3	main
andestab	doc_213943985015_item	3609555	et	3	main
keelt	doc_213943985015_item	3609540	et	4	main
suur	doc_213943985015_item	3609535	et	3	main
keele	doc_213943985015_item	3609518	et	4	main
peab	doc_213943985015_item	3609515	et	4	main
oskus	doc_213943985015_item	3609490	et	3	main
keele	doc_213943985015_item	3609489	et	4	main
keel	doc_213943985015_item	3609484	et	4	main
miks	doc_213943985010_item	3609356	et	4	main
paljudele	doc_213943985010_item	3609472	et	3	main
üristusi	doc_213943985010_item	3609459	et	4	main
õppimine	doc_213943985010_item	3609455	et	4	main
palju	doc_213943985010_item	3609451	et	4	main
oma	doc_213943985010_item	3609449	et	4	main
annab	doc_213943985010_item	3609448	et	3	main
rahva	doc_213943985015_item	3609610	et	3	main
ja	doc_213943985015_item	3609609	et	3	main
võtmed	doc_213943985015_item	3609607	et	3	main
keel	doc_213943985015_item	3609605	et	4	main
et	doc_213943985015_item	3609604	et	3	main
näeme	doc_213943985015_item	3609603	et	3	main
ainult	doc_213943985015_item	3609593	et	4	main
tekkistavad	doc_213943985015_item	3609586	et	4	main
keele-	doc_213943985015_item	3609565	et	4	main
et	doc_213943985015_item	3609564	et	3	main
sellest	doc_213943985015_item	3609563	et	4	main
ta	doc_213943985015_item	3609554	et	4	main
võõraga	doc_213943985015_item	3609552	et	3	main
mõista	doc_213943985015_item	3609548	et	4	main
üksteist	doc_213943985015_item	3609546	et	4	main
vestluses	doc_213943985015_item	3609545	et	3	main
oht	doc_213943985015_item	3609544	et	3	main
muutub	doc_213943985015_item	3609543	et	3	main
laiendama	doc_213943985015_item	3609520	et	3	main
ka	doc_213943985015_item	3609517	et	3	main
inimene	doc_213943985015_item	3609514	et	3	main
keelt	doc_213943985015_item	3609511	et	4	main
et	doc_213943985015_item	3609510	et	3	main
oskusi	doc_213943985015_item	3609509	et	3	main
keele	doc_213943985015_item	3609508	et	4	main
kohe	doc_213943985015_item	3609507	et	4	main
veel	doc_213943985015_item	3609506	et	4	main
loomulikult	doc_213943985015_item	3609505	et	4	main
anda	doc_213943985015_item	3609504	et	3	main
ei	doc_213943985015_item	3609503	et	4	main
kuulturist	doc_213943985015_item	3609502	et	3	main
maa	doc_213943985015_item	3609501	et	4	main
teise	doc_213943985015_item	3609500	et	4	main
teadmised	doc_213943985015_item	3609499	et	4	main
head	doc_213943985015_item	3609498	et	4	main
aga	doc_213943985015_item	3609497	et	3	main
kultuur	doc_213943985015_item	3609496	et	3	main
rahva	doc_213943985015_item	3609495	et	3	main
teise	doc_213943985015_item	3609494	et	4	main
saada	doc_213943985015_item	3609493	et	4	main
aru	doc_213943985015_item	3609492	et	4	main
tõttu	doc_213943985015_item	3609590	et	4	main
oskuse	doc_213943985015_item	3609589	et	3	main
rahvade	doc_213943985015_item	3609584	et	4	main
ka	doc_213943985015_item	3609578	et	3	main
kui	doc_213943985015_item	3609577	et	3	main
estlased	doc_213943985015_item	3609576	et	4	main
elavad	doc_213943985015_item	3609575	et	4	main
eestis	doc_213943985015_item	3609574	et	3	main
näiteks	doc_213943985015_item	3609573	et	4	main
kokku	doc_213943985015_item	3609572	et	3	main
lange	doc_213943985015_item	3609571	et	4	main
ei	doc_213943985015_item	3609570	et	4	main
tihti	doc_213943985015_item	3609569	et	3	main
teretorium	doc_213943985015_item	3609568	et	4	main
kultuuri	doc_213943985015_item	3609567	et	4	main
vestlusepartneri	doc_213943985015_item	3609557	et	4	main
siis	doc_213943985015_item	3609553	et	3	main
inimene	doc_213943985015_item	3609550	et	3	main
osatakse	doc_213943985015_item	3609539	et	4	main
probleem	doc_213943985015_item	3609536	et	3	main
üks	doc_213943985015_item	3609534	et	3	main
sõnavara	doc_213943985015_item	3609521	et	4	main
aitab	doc_213943985015_item	3609491	et	3	main
on	doc_213943985015_item	3609485	et	4	main
ja	doc_213943985015_item	3609480	et	3	main
essee	doc_213943985015_item	3609478	et	4	main
keeleteritooriumi	doc_213943985017_item	3609662	et	4	main
on	doc_213943985017_item	3609648	et	4	main
osatakse	doc_213943985017_item	3609637	et	4	main
paremini	doc_213943985017_item	3609636	et	4	main
avab	doc_213943985017_item	3609628	et	3	main
keeleoskus	doc_213943985017_item	3609627	et	3	main
hea	doc_213943985017_item	3609626	et	4	main
seotud	doc_213943985017_item	3609619	et	4	main
keel	doc_213943985017_item	3609615	et	4	main
kas	doc_213943985017_item	3609614	et	3	main
essee	doc_213943985017_item	3609613	et	4	main
võib	doc_213943985021_item	3609806	et	3	main
ja	doc_213943985021_item	3609799	et	3	main
lääne	doc_213943985021_item	3609782	et	4	main
iseennes	doc_213943985021_item	3609777	et	4	main
lääne	doc_213943985021_item	3609774	et	4	main
elutavades	doc_213943985021_item	3609773	et	3	main
rituaalidest	doc_213943985021_item	3609772	et	3	main
vaid	doc_213943985021_item	3609771	et	3	main
ida	doc_213943985021_item	3609760	et	4	main
usundeist	doc_213943985021_item	3609759	et	3	main
ida	doc_213943985021_item	3609758	et	4	main
usundeid	doc_213943985021_item	3609757	et	3	main
lääne	doc_213943985021_item	3609756	et	4	main
arendamiseks	doc_213943985021_item	3609751	et	4	main
enda	doc_213943985021_item	3609750	et	4	main
mitte	doc_213943985027_item	3609886	et	3	main
grammatika	doc_213943985027_item	3609881	et	4	main
võrkeele	doc_213943985027_item	3609880	et	3	main
valdab	doc_213943985027_item	3609879	et	3	main
kui	doc_213943985027_item	3609861	et	3	main
vestluspartner	doc_213943985027_item	3609859	et	3	main
on	doc_213943985027_item	3609852	et	4	main
teised	doc_213943985027_item	3609844	et	4	main
inimesed	doc_213943985027_item	3609836	et	3	main
kultuuriga	doc_213943985027_item	3609821	et	4	main
seotud	doc_213943985027_item	3609820	et	4	main
keel	doc_213943985027_item	3609817	et	4	main
seotud	doc_213943985027_item	3609816	et	4	main
on	doc_213943985027_item	3609815	et	4	main
kultuur	doc_213943985027_item	3609814	et	3	main
ja	doc_213943985027_item	3609813	et	3	main
ka	doc_213943985015_item	3609527	et	3	main
kui	doc_213943985015_item	3609526	et	3	main
kultuurist	doc_213943985015_item	3609525	et	3	main
gramaatikat	doc_213943985015_item	3609519	et	4	main
õppima	doc_213943985015_item	3609516	et	3	main
teada	doc_213943985015_item	3609513	et	3	main
hästi	doc_213943985015_item	3609512	et	3	main
seotud	doc_213943985015_item	3609487	et	4	main
kultuur	doc_213943985015_item	3609482	et	3	main
keel	doc_213943985015_item	3609479	et	4	main
hästi	doc_213943985017_item	3609658	et	3	main
saad	doc_213943985017_item	3609656	et	4	main
vestluses	doc_213943985017_item	3609643	et	3	main
muutub	doc_213943985017_item	3609641	et	3	main
keelt	doc_213943985017_item	3609638	et	4	main
parema	doc_213943985017_item	3609629	et	4	main
keel	doc_213943985017_item	3609620	et	4	main
venelased	doc_213943985017_item	3609689	et	3	main
eestimaa	doc_213943985017_item	3609688	et	4	main
olla	doc_213943985021_item	3609808	et	3	main
puudub	doc_213943985021_item	3609804	et	3	main
vastand	doc_213943985021_item	3609802	et	4	main
kui	doc_213943985021_item	3609801	et	3	main
tõde	doc_213943985021_item	3609791	et	4	main
tähendab	doc_213943985021_item	3609790	et	3	main
see	doc_213943985021_item	3609789	et	3	main
a	doc_213943985021_item	3609788	et	4	main
vastand	doc_213943985021_item	3609787	et	4	main
teineteise	doc_213943985021_item	3609781	et	4	main
uskumistest	doc_213943985021_item	3609770	et	4	main
ei	doc_213943985021_item	3609768	et	4	main
võimalus	doc_213943985021_item	3609767	et	3	main
on	doc_213943985021_item	3609766	et	4	main
filosoofiline	doc_213943985021_item	3609753	et	4	main
sellest	doc_213943985021_item	3609743	et	4	main
räägib	doc_213943985021_item	3609742	et	3	main
see	doc_213943985021_item	3609741	et	3	main
keeleveaks	doc_213943985027_item	3609887	et	3	main
tegemist	doc_213943985027_item	3609856	et	4	main
inimesed	doc_213943985027_item	3609845	et	3	main
teada	doc_213943985027_item	3609841	et	3	main
meile	doc_213943985027_item	3609840	et	4	main
meile	doc_213943985027_item	3609825	et	4	main
annab	doc_213943985027_item	3609824	et	3	main
oskus	doc_213943985027_item	3609823	et	3	main
keel	doc_213943985027_item	3609812	et	4	main
kas	doc_213943985027_item	3609811	et	3	main
essee	doc_213943985027_item	3609810	et	4	main
uus	doc_213943985028_item	3610082	et	3	main
mõtlen	doc_213943985028_item	3610074	et	3	main
on	doc_213943985028_item	3610069	et	4	main
on	doc_213943985028_item	3610065	et	4	main
tallinna	doc_213943985028_item	3610063	et	4	main
keel	doc_213943985028_item	3610062	et	4	main
soome	doc_213943985028_item	3610061	et	3	main
või	doc_213943985028_item	3610057	et	4	main
valisin	doc_213943985028_item	3609961	et	3	main
ma	doc_213943985028_item	3609960	et	3	main
edasi	doc_213943985028_item	3609959	et	3	main
nii	doc_213943985028_item	3609958	et	3	main
ja	doc_213943985028_item	3609957	et	3	main
kirjanikud	doc_213943985028_item	3609956	et	3	main
ma	doc_213943985028_item	3609940	et	3	main
töötada	doc_213943985028_item	3609936	et	3	main
tahan	doc_213943985028_item	3609935	et	3	main
sest	doc_213943985028_item	3609933	et	4	main
eriala	doc_213943985028_item	3609932	et	4	main
ja	doc_213943985028_item	3609926	et	3	main
sellel	doc_213943985028_item	3609924	et	4	main
ma	doc_213943985028_item	3609916	et	3	main
1	doc_213943985028_item	3609914	et	2	main
essee	doc_213943985028_item	3609913	et	4	main
ajalugu	doc_213943985028_item	3610044	et	4	main
meeldib	doc_213943985028_item	3610043	et	3	main
ka	doc_213943985028_item	3610042	et	3	main
tihedalt	doc_213943985015_item	3609486	et	4	main
kultuur	doc_213943985015_item	3609481	et	3	main
ja	doc_213943985017_item	3609661	et	3	main
tema	doc_213943985017_item	3609657	et	4	main
sina	doc_213943985017_item	3609655	et	4	main
aga	doc_213943985017_item	3609654	et	3	main
grammatikaga	doc_213943985017_item	3609653	et	3	main
eksib	doc_213943985017_item	3609652	et	3	main
võõrmaainimene	doc_213943985017_item	3609651	et	3	main
keeleparadoksiga	doc_213943985017_item	3609650	et	4	main
ka	doc_213943985017_item	3609649	et	3	main
vääriti	doc_213943985017_item	3609645	et	4	main
oht	doc_213943985017_item	3609642	et	3	main
seda	doc_213943985017_item	3609639	et	3	main
seotud	doc_213943985017_item	3609625	et	4	main
kahtlemata	doc_213943985017_item	3609624	et	4	main
on	doc_213943985017_item	3609618	et	4	main
kultuurile	doc_213943985017_item	3609709	et	3	main
tema	doc_213943985017_item	3609708	et	4	main
huvi	doc_213943985017_item	3609707	et	4	main
tekib	doc_213943985017_item	3609706	et	3	main
sul	doc_213943985017_item	3609705	et	3	main
keel	doc_213943985017_item	3609704	et	4	main
õpid	doc_213943985017_item	3609703	et	4	main
sa	doc_213943985017_item	3609702	et	3	main
kui	doc_213943985017_item	3609701	et	3	main
erinevusi	doc_213943985017_item	3609700	et	4	main
olulisi	doc_213943985017_item	3609699	et	4	main
väärtushinnangutes	doc_213943985017_item	3609698	et	3	main
nende	doc_213943985017_item	3609697	et	4	main
kui	doc_213943985017_item	3609696	et	3	main
keelt	doc_213943985017_item	3609695	et	4	main
ühest	doc_213943985017_item	3609694	et	4	main
räägivad	doc_213943985017_item	3609693	et	3	main
venelased	doc_213943985017_item	3609692	et	3	main
venemaa	doc_213943985017_item	3609691	et	4	main
aru	doc_213943985017_item	3609659	et	4	main
mõista	doc_213943985017_item	3609646	et	4	main
samad	doc_213943985017_item	3609687	et	3	main
on	doc_213943985017_item	3609686	et	4	main
väärtushinnangud	doc_213943985017_item	3609685	et	3	main
põhilised	doc_213943985017_item	3609684	et	3	main
eestlaste	doc_213943985017_item	3609683	et	4	main
ja	doc_213943985017_item	3609682	et	3	main
erinevust	doc_213943985017_item	3609680	et	4	main
tšehhide	doc_213943985017_item	3609681	et	2	main
või	doc_213943985017_item	3609679	et	4	main
sarnasust	doc_213943985017_item	3609678	et	4	main
nende	doc_213943985017_item	3609677	et	4	main
prognoosida	doc_213943985017_item	3609676	et	4	main
hästi	doc_213943985017_item	3609675	et	3	main
võime	doc_213943985017_item	3609674	et	4	main
ajalugu	doc_213943985017_item	3609673	et	4	main
kultuuride	doc_213943985017_item	3609672	et	3	main
võrreldes	doc_213943985017_item	3609671	et	3	main
ajalugu	doc_213943985017_item	3609670	et	4	main
ka	doc_213943985017_item	3609669	et	3	main
küsimustele	doc_213943985017_item	3609668	et	4	main
vastada	doc_213943985017_item	3609667	et	4	main
aitab	doc_213943985017_item	3609666	et	3	main
kokku	doc_213943985017_item	3609665	et	3	main
lange	doc_213943985017_item	3609664	et	4	main
ei	doc_213943985017_item	3609663	et	4	main
veel	doc_213943985021_item	3609800	et	4	main
ole	doc_213943985021_item	3609797	et	4	main
teooria	doc_213943985021_item	3609786	et	4	main
niisugune	doc_213943985021_item	3609785	et	3	main
erinevaid	doc_213943985021_item	3609764	et	4	main
inimestele	doc_213943985021_item	3609763	et	3	main
pakuvad	doc_213943985021_item	3609762	et	3	main
usundid	doc_213943985021_item	3609761	et	3	main
veelahe	doc_213943985021_item	3609754	et	4	main
keelt	doc_213943985027_item	3609884	et	4	main
sõnavara	doc_213943985027_item	3609883	et	4	main
ja	doc_213943985027_item	3609882	et	3	main
eksib	doc_213943985027_item	3609863	et	3	main
kõneleja	doc_213943985027_item	3609862	et	4	main
mõistab	doc_213943985027_item	3609860	et	3	main
elus	doc_213943985027_item	3609855	et	4	main
rohkem	doc_213943985027_item	3609853	et	4	main
keele	doc_213943985027_item	3609851	et	4	main
teise	doc_213943985027_item	3609850	et	4	main
paljud	doc_213943985027_item	3609849	et	3	main
teavad	doc_213943985027_item	3609848	et	3	main
maa	doc_213943985027_item	3609832	et	4	main
õppida	doc_213943985027_item	3609831	et	3	main
tundma	doc_213943985027_item	3609830	et	3	main
võimaluse	doc_213943985027_item	3609829	et	3	main
parema	doc_213943985027_item	3609828	et	4	main
avab	doc_213943985027_item	3609827	et	3	main
ja	doc_213943985027_item	3609826	et	3	main
kahtletama	doc_213943985027_item	3609819	et	4	main
vastand	doc_213943985021_item	3609793	et	4	main
aga	doc_213943985021_item	3609792	et	3	main
on	doc_213943985021_item	3609784	et	4	main
loogikas	doc_213943985021_item	3609783	et	3	main
välistavad	doc_213943985021_item	3609780	et	4	main
mõistetavas	doc_213943985021_item	3609778	et	4	main
sisalduv	doc_213943985021_item	3609776	et	4	main
loogikas	doc_213943985021_item	3609775	et	3	main
koosne	doc_213943985021_item	3609769	et	4	main
oluline	doc_213943985021_item	3609745	et	4	main
et	doc_213943985021_item	3609744	et	3	main
lahtiseks	doc_213943985021_item	3609740	et	4	main
tõest	doc_213943985021_item	3609739	et	4	main
küsimuste	doc_213943985021_item	3609738	et	4	main
jätab	doc_213943985021_item	3609737	et	3	main
dünaamika	doc_213943985021_item	3609736	et	4	main
konfutsiaanlik	doc_213943985021_item	3609735	et	4	main
otsimisele	doc_213943985021_item	3609734	et	4	main
tõe	doc_213943985021_item	3609733	et	4	main
pühenduda	doc_213943985021_item	3609732	et	3	main
võivad	doc_213943985021_item	3609731	et	4	main
halvasti	doc_213943985021_item	3609730	et	3	main
väga	doc_213943985021_item	3609729	et	3	main
ebakindlust	doc_213943985021_item	3609728	et	4	main
taluvad	doc_213943985021_item	3609727	et	4	main
mis	doc_213943985021_item	3609726	et	4	main
kultuurid	doc_213943985021_item	3609725	et	3	main
teooriaid	doc_213943985021_item	3609724	et	3	main
mõjuta	doc_213943985021_item	3609723	et	4	main
aga	doc_213943985021_item	3609722	et	3	main
igapäevatoiminguid	doc_213943985021_item	3609721	et	3	main
mõjuta	doc_213943985021_item	3609720	et	4	main
ei	doc_213943985021_item	3609719	et	4	main
kultuur	doc_213943985021_item	3609718	et	3	main
kommunikatsioon	doc_213943985021_item	3609717	et	3	main
ning	doc_213943985021_item	3609716	et	3	main
mõtteviis	doc_213943985021_item	3609715	et	3	main
ida	doc_213943985021_item	3609714	et	4	main
ja	doc_213943985021_item	3609713	et	3	main
lääne	doc_213943985021_item	3609712	et	4	main
essee	doc_213943985021_item	3609711	et	4	main
suheldavad	doc_213943985027_item	3609911	et	4	main
millal	doc_213943985027_item	3609909	et	3	main
nad	doc_213943985027_item	3609910	et	3	main
õppida	doc_213943985027_item	3609908	et	3	main
keel	doc_213943985027_item	3609907	et	4	main
paremeni	doc_213943985027_item	3609906	et	4	main
saavad	doc_213943985027_item	3609905	et	4	main
inimesed	doc_213943985027_item	3609904	et	3	main
veel	doc_213943985027_item	3609903	et	4	main
ja	doc_213943985027_item	3609902	et	3	main
inimestega	doc_213943985027_item	3609901	et	3	main
erinevamate	doc_213943985027_item	3609900	et	4	main
suheldakse	doc_213943985027_item	3609899	et	3	main
millal	doc_213943985027_item	3609898	et	3	main
märgatakse	doc_213943985027_item	3609897	et	3	main
kergemini	doc_213943985027_item	3609896	et	4	main
jooni	doc_213943985027_item	3609895	et	4	main
tingitud	doc_213943985027_item	3609894	et	4	main
kultuuri	doc_213943985027_item	3609893	et	4	main
eraldamatud	doc_213943985027_item	3609892	et	4	main
on	doc_213943985027_item	3609891	et	4	main
kultuur	doc_213943985027_item	3609890	et	3	main
ja	doc_213943985027_item	3609889	et	3	main
suhtlus	doc_213943985027_item	3609888	et	3	main
kõneleja	doc_213943985027_item	3609878	et	4	main
kui	doc_213943985027_item	3609877	et	3	main
mõista	doc_213943985027_item	3609876	et	4	main
ja	doc_213943985027_item	3609875	et	3	main
rääkida	doc_213943985027_item	3609874	et	3	main
rohkem	doc_213943985027_item	3609873	et	4	main
pea	doc_213943985027_item	3609872	et	4	main
ei	doc_213943985027_item	3609871	et	4	main
vestluspartner	doc_213943985027_item	3609870	et	3	main
teistmoodi	doc_213943985027_item	3609869	et	3	main
ja	doc_213943985027_item	3609868	et	3	main
sõnavara	doc_213943985027_item	3609867	et	4	main
ja	doc_213943985027_item	3609866	et	3	main
grammatikas	doc_213943985027_item	3609865	et	3	main
võõrkeele	doc_213943985027_item	3609864	et	4	main
on	doc_213943985027_item	3609857	et	4	main
kes	doc_213943985027_item	3609847	et	4	main
inimesed	doc_213943985027_item	3609846	et	3	main
elavad	doc_213943985027_item	3609843	et	4	main
kuidas	doc_213943985027_item	3609842	et	3	main
kultuuri	doc_213943985027_item	3609835	et	4	main
keele	doc_213943985027_item	3609822	et	4	main
on	doc_213943985027_item	3609818	et	4	main
hea	doc_213943985028_item	3610079	et	4	main
ja	doc_213943985028_item	3610072	et	3	main
väga	doc_213943985028_item	3610070	et	3	main
või	doc_213943985028_item	3610060	et	4	main
keel	doc_213943985028_item	3610059	et	4	main
oppima	doc_213943985028_item	3610055	et	4	main
huvitavad	doc_213943985028_item	3609953	et	4	main
tööl	doc_213943985028_item	3609949	et	3	main
ajalehes	doc_213943985028_item	3609939	et	3	main
mida	doc_213943985028_item	3609921	et	4	main
2	doc_213943985028_item	3609920	et	2	main
meeldib	doc_213943985028_item	3610038	et	3	main
ootan	doc_213943985028_item	3610016	et	3	main
ka	doc_213943985028_item	3610014	et	3	main
narvas	doc_213943985028_item	3610001	et	4	main
otan	doc_213943985028_item	3609991	et	4	main
sellel	doc_213943985028_item	3609988	et	4	main
leida	doc_213943985028_item	3609984	et	3	main
sõbrad	doc_213943985028_item	3610083	et	3	main
võimalusi	doc_213943985028_item	3610080	et	3	main
on	doc_213943985028_item	3610077	et	4	main
et	doc_213943985028_item	3610075	et	3	main
see	doc_213943985028_item	3610068	et	3	main
ülikoolis	doc_213943985028_item	3610064	et	4	main
saksa	doc_213943985028_item	3610058	et	4	main
inglise	doc_213943985028_item	3610056	et	4	main
ma	doc_213943985028_item	3610053	et	3	main
aastal	doc_213943985028_item	3610052	et	3	main
järgmisel	doc_213943985028_item	3610051	et	3	main
muidugi	doc_213943985028_item	3610050	et	4	main
ja	doc_213943985028_item	3610049	et	3	main
see	doc_213943985028_item	3610076	et	3	main
üliõpilased	doc_213943985028_item	3610067	et	3	main
saksa	doc_213943985028_item	3610047	et	4	main
ja	doc_213943985028_item	3610046	et	3	main
inglise	doc_213943985028_item	3610045	et	4	main
mõtlen	doc_213943985028_item	3609966	et	3	main
ma	doc_213943985028_item	3609965	et	3	main
palju	doc_213943985028_item	3609952	et	4	main
selle	doc_213943985028_item	3609931	et	4	main
valisin	doc_213943985028_item	3609930	et	3	main
ma	doc_213943985028_item	3609929	et	3	main
selle	doc_213943985028_item	3609918	et	4	main
valisin	doc_213943985028_item	3609917	et	3	main
aga	doc_213943985028_item	3610040	et	3	main
eriala	doc_213943985028_item	3610036	et	4	main
veel	doc_213943985028_item	3610034	et	4	main
üks	doc_213943985028_item	3610033	et	3	main
ma	doc_213943985028_item	3610015	et	3	main
hea	doc_213943985028_item	3610011	et	4	main
ülikoolis	doc_213943985028_item	3610004	et	4	main
tallinnas	doc_213943985028_item	3609999	et	4	main
ja	doc_213943985028_item	3609996	et	3	main
uus	doc_213943985028_item	3609994	et	3	main
tundid	doc_213943985028_item	3609993	et	4	main
hea	doc_213943985028_item	3609982	et	4	main
hea	doc_213943985028_item	3609972	et	4	main
sellel	doc_213943985028_item	3609968	et	4	main
palju	doc_213943985028_item	3610071	et	4	main
7000	doc_213943985028_item	3610066	et	2	main
valin	doc_213943985028_item	3610054	et	3	main
ülikool	doc_213943985028_item	3609963	et	4	main
tallinna	doc_213943985028_item	3609962	et	4	main
artistid	doc_213943985028_item	3609955	et	3	main
tutvun	doc_213943985028_item	3609951	et	3	main
eriala	doc_213943985028_item	3609947	et	4	main
on	doc_213943985028_item	3609944	et	4	main
see	doc_213943985028_item	3609943	et	3	main
et	doc_213943985028_item	3609942	et	3	main
mõtlen	doc_213943985028_item	3609941	et	3	main
ülikoolis	doc_213943985028_item	3609928	et	4	main
erialal	doc_213943985028_item	3609925	et	3	main
opimisest	doc_213943985028_item	3609923	et	4	main
otan	doc_213943985028_item	3609922	et	4	main
miks	doc_213943985028_item	3609915	et	4	main
ajakirjandus	doc_213943985028_item	3610039	et	3	main
töö	doc_213943985028_item	3610013	et	4	main
semenarid	doc_213943985028_item	3610009	et	4	main
tundid	doc_213943985028_item	3610008	et	4	main
töökoht	doc_213943985028_item	3609998	et	3	main
sõbrad	doc_213943985028_item	3609995	et	3	main
erialal	doc_213943985028_item	3609989	et	3	main
õpetajad	doc_213943985028_item	3609975	et	4	main
huvitav	doc_213943985028_item	3609974	et	4	main
ja	doc_213943985028_item	3609973	et	3	main
ülikoolis	doc_213943985030_item	3610210	et	4	main
uued	doc_213943985030_item	3610208	et	3	main
õpisid	doc_213943985030_item	3610201	et	4	main
ülikoolist	doc_213943985030_item	3610193	et	4	main
ma	doc_213943985030_item	3610190	et	3	main
aga	doc_213943985030_item	3610188	et	3	main
ootan	doc_213943985030_item	3610185	et	3	main
elus	doc_213943985030_item	3610182	et	4	main
osa	doc_213943985030_item	3610181	et	4	main
tähtis	doc_213943985030_item	3610177	et	4	main
ülikoolis	doc_213943985030_item	3610174	et	4	main
anan	doc_213943985030_item	3610169	et	4	main
kui	doc_213943985030_item	3610167	et	3	main
inimesele	doc_213943985030_item	3610166	et	3	main
aita	doc_213943985030_item	3610165	et	4	main
arvamuse	doc_213943985030_item	3610163	et	3	main
oma	doc_213943985030_item	3610162	et	4	main
huvitav	doc_213943985030_item	3610142	et	4	main
on	doc_213943985030_item	3610141	et	4	main
ajakirjanikuks	doc_213943985030_item	3610135	et	3	main
4	doc_213943985030_item	3610126	et	2	main
töötab	doc_213943985030_item	3610124	et	3	main
ta	doc_213943985030_item	3610120	et	4	main
praegu	doc_213943985030_item	3610119	et	3	main
tallinna	doc_213943985030_item	3610116	et	4	main
ka	doc_213943985030_item	3610114	et	3	main
tädipoeg	doc_213943985030_item	3610113	et	3	main
minu	doc_213943985030_item	3610112	et	3	main
klassis	doc_213943985030_item	3610111	et	3	main
veel	doc_213943985030_item	3610109	et	4	main
õpin	doc_213943985030_item	3610108	et	3	main
ma	doc_213943985030_item	3610107	et	3	main
kui	doc_213943985030_item	3610106	et	3	main
ülikoolist	doc_213943985030_item	3610100	et	4	main
mida	doc_213943985030_item	3610093	et	4	main
2	doc_213943985030_item	3610092	et	2	main
erinevad	doc_213943985033_item	3610296	et	4	main
ma	doc_213943985033_item	3610293	et	3	main
arvan	doc_213943985033_item	3610288	et	3	main
hea	doc_213943985033_item	3610282	et	4	main
keel	doc_213943985028_item	3610048	et	4	main
sest	doc_213943985028_item	3609964	et	4	main
inimesed	doc_213943985028_item	3609954	et	3	main
ma	doc_213943985028_item	3609950	et	3	main
sellel	doc_213943985028_item	3609948	et	4	main
huvitav	doc_213943985028_item	3609946	et	4	main
väga	doc_213943985028_item	3609945	et	3	main
või	doc_213943985028_item	3609938	et	4	main
radios	doc_213943985028_item	3609937	et	4	main
ma	doc_213943985028_item	3609934	et	3	main
tallinna	doc_213943985028_item	3609927	et	4	main
eriala	doc_213943985028_item	3609919	et	4	main
mulle	doc_213943985028_item	3610041	et	4	main
mulle	doc_213943985028_item	3610037	et	4	main
uus	doc_213943985028_item	3610035	et	3	main
huvitavad	doc_213943985028_item	3610007	et	4	main
otan	doc_213943985028_item	3610006	et	4	main
või	doc_213943985028_item	3610000	et	4	main
huvitavad	doc_213943985028_item	3609992	et	4	main
õpimisest	doc_213943985028_item	3609987	et	4	main
hea	doc_213943985028_item	3609985	et	4	main
väga	doc_213943985028_item	3609981	et	3	main
on	doc_213943985028_item	3609970	et	4	main
ülikoolil	doc_213943985028_item	3609969	et	4	main
et	doc_213943985028_item	3609967	et	3	main
õpetajad	doc_213943985030_item	3610209	et	4	main
sõbrad	doc_213943985030_item	3610207	et	3	main
varem	doc_213943985030_item	3610203	et	4	main
ülikoolis	doc_213943985030_item	3610202	et	4	main
üliõpilase	doc_213943985030_item	3610195	et	3	main
ootan	doc_213943985030_item	3610191	et	3	main
ajakirjaniku	doc_213943985030_item	3610186	et	3	main
diploom	doc_213943985030_item	3610187	et	4	main
ma	doc_213943985030_item	3610184	et	3	main
esimeseks	doc_213943985030_item	3610183	et	3	main
huvitav	doc_213943985030_item	3610178	et	4	main
ma	doc_213943985030_item	3610168	et	3	main
ja	doc_213943985030_item	3610164	et	3	main
räärida	doc_213943985030_item	3610161	et	4	main
ajakirjanikuks	doc_213943985030_item	3610158	et	3	main
hea	doc_213943985030_item	3610157	et	4	main
jaoks	doc_213943985030_item	3610153	et	4	main
ja	doc_213943985030_item	3610150	et	3	main
on	doc_213943985030_item	3610148	et	4	main
tööl	doc_213943985030_item	3610147	et	3	main
aga	doc_213943985030_item	3610146	et	3	main
targad	doc_213943985030_item	3610145	et	3	main
sõbrad	doc_213943985030_item	3610143	et	3	main
ma	doc_213943985030_item	3610136	et	3	main
selle	doc_213943985030_item	3610104	et	4	main
valisin	doc_213943985030_item	3610103	et	3	main
ma	doc_213943985030_item	3610102	et	3	main
1	doc_213943985030_item	3610101	et	2	main
tallinna	doc_213943985030_item	3610099	et	4	main
ja	doc_213943985030_item	3610098	et	3	main
eriaial	doc_213943985030_item	3610097	et	4	main
eriala	doc_213943985030_item	3610091	et	4	main
tallinna	doc_213943985033_item	3610303	et	4	main
kõrghariduse	doc_213943985033_item	3610302	et	3	main
ootan	doc_213943985033_item	3610299	et	3	main
võin	doc_213943985033_item	3610294	et	3	main
eriala	doc_213943985033_item	3610292	et	4	main
see	doc_213943985033_item	3610291	et	3	main
abiga	doc_213943985033_item	3610290	et	3	main
et	doc_213943985033_item	3610289	et	3	main
tegema	doc_213943985033_item	3610285	et	3	main
sellel	doc_213943985033_item	3610280	et	4	main
ootan	doc_213943985033_item	3610278	et	3	main
ma	doc_213943985033_item	3610277	et	3	main
muidugi	doc_213943985028_item	3610032	et	4	main
ja	doc_213943985028_item	3610031	et	3	main
võõrkeeled	doc_213943985028_item	3610030	et	3	main
uus	doc_213943985028_item	3610029	et	3	main
õppimine	doc_213943985028_item	3610028	et	4	main
otan	doc_213943985028_item	3610027	et	4	main
ma	doc_213943985028_item	3610026	et	3	main
ülikoolis	doc_213943985028_item	3610025	et	4	main
tallinna	doc_213943985028_item	3610024	et	4	main
õpimisest	doc_213943985028_item	3610023	et	4	main
ka	doc_213943985028_item	3610022	et	3	main
eriala	doc_213943985028_item	3610021	et	4	main
huvitav	doc_213943985028_item	3610020	et	4	main
ja	doc_213943985028_item	3610019	et	3	main
võõrkeeled	doc_213943985028_item	3610018	et	3	main
uus	doc_213943985028_item	3610017	et	3	main
praktilise	doc_213943985028_item	3610012	et	3	main
ja	doc_213943985028_item	3610010	et	3	main
ma	doc_213943985028_item	3610005	et	3	main
tallinna	doc_213943985028_item	3610003	et	4	main
õpimisest	doc_213943985028_item	3610002	et	4	main
uus	doc_213943985028_item	3609997	et	3	main
ma	doc_213943985028_item	3609990	et	3	main
töö	doc_213943985028_item	3609986	et	4	main
võimalusi	doc_213943985028_item	3609983	et	3	main
on	doc_213943985028_item	3609980	et	4	main
tallinnas	doc_213943985028_item	3609979	et	4	main
ka	doc_213943985028_item	3609978	et	3	main
üliõpilased	doc_213943985028_item	3609977	et	3	main
ja	doc_213943985028_item	3609976	et	3	main
väga	doc_213943985028_item	3609971	et	3	main
elama	doc_213943985030_item	3610212	et	3	main
see	doc_213943985030_item	3610204	et	3	main
selle	doc_213943985030_item	3610194	et	4	main
eriti	doc_213943985030_item	3610176	et	3	main
õppimine	doc_213943985030_item	3610173	et	4	main
muidugi	doc_213943985030_item	3610172	et	4	main
2	doc_213943985030_item	3610171	et	2	main
saada	doc_213943985030_item	3610156	et	4	main
ühiskonna	doc_213943985030_item	3610152	et	4	main
on	doc_213943985030_item	3610144	et	4	main
eriala	doc_213943985030_item	3610105	et	4	main
õppimisest	doc_213943985030_item	3610095	et	4	main
ootan	doc_213943985030_item	3610094	et	3	main
miks	doc_213943985030_item	3610087	et	4	main
keeled	doc_213943985033_item	3610297	et	3	main
õppida	doc_213943985033_item	3610295	et	3	main
karjeeri	doc_213943985033_item	3610286	et	4	main
on	doc_213943985033_item	3610255	et	4	main
see	doc_213943985033_item	3610254	et	3	main
ajakirjaniku	doc_213943985033_item	3610253	et	3	main
hea	doc_213943985033_item	3610330	et	4	main
ma	doc_213943985033_item	3610328	et	3	main
on	doc_213943985033_item	3610326	et	4	main
ma	doc_213943985033_item	3610315	et	3	main
õppevad	doc_213943985030_item	3610211	et	4	main
kes	doc_213943985030_item	3610200	et	4	main
inimesed	doc_213943985030_item	3610199	et	3	main
rääkivad	doc_213943985030_item	3610198	et	4	main
missugusel	doc_213943985030_item	3610197	et	3	main
elu	doc_213943985030_item	3610196	et	4	main
uued	doc_213943985030_item	3610206	et	3	main
on	doc_213943985030_item	3610205	et	4	main
tallinna	doc_213943985030_item	3610192	et	4	main
lõbus	doc_213943985030_item	3610180	et	4	main
ja	doc_213943985030_item	3610179	et	3	main
on	doc_213943985030_item	3610175	et	4	main
nõus	doc_213943985030_item	3610170	et	4	main
ühiskonna	doc_213943985030_item	3610160	et	4	main
informeerida	doc_213943985030_item	3610159	et	3	main
teiseks	doc_213943985030_item	3610189	et	4	main
tahaksin	doc_213943985030_item	3610155	et	3	main
elu	doc_213943985030_item	3610140	et	4	main
mõtlen	doc_213943985030_item	3610137	et	3	main
tahan	doc_213943985030_item	3610133	et	3	main
ja	doc_213943985030_item	3610131	et	3	main
vaatasin	doc_213943985030_item	3610129	et	3	main
ma	doc_213943985030_item	3610127	et	3	main
raadiol	doc_213943985030_item	3610125	et	3	main
eesnimi	doc_213943985030_item	3610123	et	3	main
on	doc_213943985030_item	3610121	et	4	main
ja	doc_213943985030_item	3610118	et	3	main
õpis	doc_213943985030_item	3610115	et	3	main
üheksandal	doc_213943985030_item	3610110	et	3	main
selle	doc_213943985030_item	3610096	et	4	main
selle	doc_213943985030_item	3610090	et	4	main
valisin	doc_213943985030_item	3610089	et	3	main
ma	doc_213943985030_item	3610088	et	3	main
1	doc_213943985030_item	3610086	et	2	main
essee	doc_213943985030_item	3610085	et	4	main
ma	doc_213943985030_item	3610154	et	3	main
kasulik	doc_213943985030_item	3610151	et	3	main
positiivne	doc_213943985030_item	3610149	et	3	main
ajakirjaniku	doc_213943985030_item	3610139	et	3	main
et	doc_213943985030_item	3610138	et	3	main
saada	doc_213943985030_item	3610134	et	4	main
ka	doc_213943985030_item	3610132	et	3	main
temale	doc_213943985030_item	3610130	et	3	main
alati	doc_213943985030_item	3610128	et	4	main
ajakirjanik	doc_213943985030_item	3610122	et	3	main
ülikoolis	doc_213943985030_item	3610117	et	4	main
ülikoolist	doc_213943985033_item	3610304	et	4	main
erialal	doc_213943985033_item	3610301	et	3	main
sellel	doc_213943985033_item	3610300	et	4	main
ma	doc_213943985033_item	3610298	et	3	main
olevikus	doc_213943985033_item	3610284	et	3	main
võimaluse	doc_213943985033_item	3610283	et	3	main
õige	doc_213943985033_item	3610271	et	4	main
õppida	doc_213943985033_item	3610270	et	3	main
võib	doc_213943985033_item	3610269	et	3	main
jaoks	doc_213943985033_item	3610265	et	4	main
teda	doc_213943985033_item	3610263	et	4	main
võimalus	doc_213943985033_item	3610258	et	3	main
hea	doc_213943985033_item	3610257	et	4	main
väga	doc_213943985033_item	3610256	et	3	main
on	doc_213943985033_item	3610249	et	4	main
ja	doc_213943985033_item	3610244	et	3	main
teada	doc_213943985033_item	3610242	et	3	main
inimesega	doc_213943985033_item	3610239	et	3	main
essee	doc_213943985033_item	3610214	et	4	main
olevikusse	doc_213943985033_item	3610347	et	4	main
teega	doc_213943985033_item	3610346	et	3	main
ja	doc_213943985033_item	3610345	et	3	main
kõrgharidusega	doc_213943985033_item	3610344	et	3	main
inimeseks	doc_213943985033_item	3610343	et	3	main
teiseks	doc_213943985033_item	3610342	et	4	main
oleksin	doc_213943985033_item	3610341	et	3	main
ma	doc_213943985033_item	3610340	et	3	main
ülikooli	doc_213943985033_item	3610339	et	4	main
tallinna	doc_213943985033_item	3610338	et	4	main
lõpetaksin	doc_213943985033_item	3610337	et	3	main
ma	doc_213943985033_item	3610336	et	3	main
millal	doc_213943985033_item	3610335	et	3	main
et	doc_213943985033_item	3610334	et	3	main
arvan	doc_213943985033_item	3610333	et	3	main
ma	doc_213943985033_item	3610332	et	3	main
õppima	doc_213943985033_item	3610331	et	3	main
õppida	doc_213943985033_item	3610314	et	3	main
võimaluse	doc_213943985033_item	3610313	et	3	main
ja	doc_213943985033_item	3610312	et	3	main
vaja	doc_213943985033_item	3610311	et	4	main
on	doc_213943985033_item	3610310	et	4	main
ta	doc_213943985033_item	3610309	et	4	main
kui	doc_213943985033_item	3610308	et	3	main
abi	doc_213943985033_item	3610307	et	4	main
ootan	doc_213943985033_item	3610306	et	3	main
ma	doc_213943985033_item	3610305	et	3	main
ma	doc_213943985033_item	3610287	et	3	main
erialal	doc_213943985033_item	3610281	et	3	main
eriala	doc_213943985033_item	3610268	et	4	main
eriala	doc_213943985033_item	3610252	et	4	main
jaoks	doc_213943985033_item	3610248	et	4	main
minu	doc_213943985033_item	3610247	et	3	main
sest	doc_213943985033_item	3610234	et	4	main
eriala	doc_213943985033_item	3610233	et	4	main
selle	doc_213943985033_item	3610232	et	4	main
valisin	doc_213943985033_item	3610231	et	3	main
ma	doc_213943985033_item	3610230	et	3	main
ülikoolist	doc_213943985033_item	3610229	et	4	main
tallinna	doc_213943985033_item	3610228	et	4	main
ja	doc_213943985033_item	3610227	et	3	main
erialal	doc_213943985033_item	3610226	et	3	main
sellel	doc_213943985033_item	3610225	et	4	main
õppimisest	doc_213943985033_item	3610224	et	4	main
ootan	doc_213943985033_item	3610223	et	3	main
mida	doc_213943985033_item	3610222	et	4	main
2	doc_213943985033_item	3610221	et	2	main
eriala	doc_213943985033_item	3610220	et	4	main
valisin	doc_213943985033_item	3610218	et	3	main
selle	doc_213943985033_item	3610219	et	4	main
ma	doc_213943985033_item	3610217	et	3	main
miks	doc_213943985033_item	3610216	et	4	main
1	doc_213943985033_item	3610215	et	2	main
ka	doc_213943985033_item	3610317	et	3	main
minu	doc_213943985035_item	3610477	et	3	main
raadios	doc_213943985035_item	3610473	et	3	main
tv-s	doc_213943985035_item	3610471	et	3	main
erialaga	doc_213943985035_item	3610466	et	3	main
huvidega	doc_213943985035_item	3610460	et	3	main
seda	doc_213943985035_item	3610449	et	3	main
ja	doc_213943985035_item	3610446	et	3	main
palju	doc_213943985035_item	3610444	et	4	main
minu	doc_213943985035_item	3610442	et	3	main
ja	doc_213943985035_item	3610433	et	3	main
oskus	doc_213943985035_item	3610428	et	3	main
tahaksin	doc_213943985035_item	3610425	et	3	main
ja	doc_213943985035_item	3610423	et	3	main
et	doc_213943985035_item	3610418	et	3	main
loodan	doc_213943985036_item	3610616	et	3	main
ja	doc_213943985036_item	3610614	et	3	main
tahan	doc_213943985036_item	3610611	et	3	main
väga	doc_213943985036_item	3610607	et	3	main
see	doc_213943985036_item	3610605	et	3	main
ülikoolist	doc_213943985036_item	3610590	et	4	main
palka	doc_213943985036_item	3610589	et	4	main
õppimisest	doc_213943985036_item	3610576	et	4	main
ootan	doc_213943985036_item	3610575	et	3	main
eriala	doc_213943985036_item	3610551	et	4	main
mulle	doc_213943985036_item	3610549	et	4	main
soovitas	doc_213943985036_item	3610548	et	3	main
ta	doc_213943985036_item	3610547	et	4	main
emale	doc_213943985036_item	3610546	et	3	main
minu	doc_213943985036_item	3610545	et	3	main
õppimisest	doc_213943985036_item	3610490	et	4	main
ootan	doc_213943985036_item	3610489	et	3	main
ma	doc_213943985039_item	3610781	et	3	main
veel	doc_213943985039_item	3610777	et	4	main
õppida	doc_213943985039_item	3610776	et	3	main
õppimisest	doc_213943985033_item	3610279	et	4	main
see	doc_213943985033_item	3610267	et	3	main
oluline	doc_213943985033_item	3610251	et	4	main
väga	doc_213943985033_item	3610250	et	3	main
tahan	doc_213943985033_item	3610241	et	3	main
ma	doc_213943985033_item	3610240	et	3	main
olen	doc_213943985033_item	3610329	et	3	main
tallinna	doc_213943985033_item	3610318	et	4	main
ootan	doc_213943985033_item	3610316	et	3	main
jaoks	doc_213943985035_item	3610478	et	4	main
huvitav	doc_213943985035_item	3610476	et	4	main
on	doc_213943985035_item	3610475	et	4	main
see	doc_213943985035_item	3610474	et	3	main
ja	doc_213943985035_item	3610472	et	3	main
ajakirjas	doc_213943985035_item	3610470	et	3	main
ajakirjaniku	doc_213943985035_item	3610465	et	3	main
ja	doc_213943985035_item	3610462	et	3	main
õppima	doc_213943985035_item	3610457	et	3	main
näiteks	doc_213943985035_item	3610451	et	4	main
ees	doc_213943985035_item	3610443	et	4	main
tlü	doc_213943985035_item	3610440	et	4	main
tähendab	doc_213943985035_item	3610438	et	3	main
see	doc_213943985035_item	3610437	et	3	main
palju	doc_213943985035_item	3610436	et	4	main
õppimisest	doc_213943985035_item	3610430	et	4	main
ma	doc_213943985035_item	3610424	et	3	main
hästi	doc_213943985035_item	3610420	et	3	main
veel	doc_213943985035_item	3610411	et	4	main
inimeste	doc_213943985033_item	3610276	et	3	main
teisega	doc_213943985033_item	3610275	et	4	main
suhtlema	doc_213943985033_item	3610274	et	3	main
ja	doc_213943985033_item	3610273	et	3	main
rääkima	doc_213943985033_item	3610272	et	3	main
abiga	doc_213943985033_item	3610266	et	3	main
oma	doc_213943985033_item	3610264	et	4	main
avab	doc_213943985033_item	3610262	et	3	main
ja	doc_213943985033_item	3610261	et	3	main
maailm	doc_213943985033_item	3610260	et	3	main
näitab	doc_213943985033_item	3610259	et	3	main
asjad	doc_213943985033_item	3610246	et	3	main
huvitavad	doc_213943985033_item	3610245	et	4	main
uued	doc_213943985033_item	3610243	et	3	main
suhelda	doc_213943985033_item	3610238	et	4	main
meeldib	doc_213943985033_item	3610237	et	3	main
mulle	doc_213943985033_item	3610236	et	4	main
et	doc_213943985033_item	3610235	et	3	main
ülikoolist	doc_213943985033_item	3610319	et	4	main
töötaga	doc_213943985035_item	3610468	et	4	main
nii	doc_213943985035_item	3610463	et	3	main
inimestega	doc_213943985035_item	3610461	et	3	main
tutvuma	doc_213943985035_item	3610459	et	3	main
sõita	doc_213943985035_item	3610456	et	3	main
kasutada	doc_213943985035_item	3610450	et	3	main
võimalusi	doc_213943985035_item	3610445	et	3	main
ülikoolis	doc_213943985035_item	3610435	et	4	main
sellel	doc_213943985035_item	3610431	et	4	main
arendada	doc_213943985035_item	3610426	et	3	main
seda	doc_213943985035_item	3610422	et	3	main
mulle	doc_213943985035_item	3610416	et	4	main
küsida	doc_213943985035_item	3610415	et	3	main
peab	doc_213943985035_item	3610413	et	4	main
et	doc_213943985036_item	3610617	et	3	main
hästi	doc_213943985036_item	3610613	et	3	main
hea	doc_213943985036_item	3610608	et	4	main
on	doc_213943985036_item	3610606	et	4	main
sellel	doc_213943985036_item	3610602	et	4	main
õppida	doc_213943985036_item	3610601	et	3	main
tahan	doc_213943985036_item	3610600	et	3	main
ma	doc_213943985036_item	3610599	et	3	main
õppida	doc_213943985036_item	3610598	et	3	main
võiks	doc_213943985036_item	3610584	et	4	main
ma	doc_213943985036_item	3610583	et	3	main
tulevases	doc_213943985036_item	3610582	et	4	main
et	doc_213943985036_item	3610581	et	3	main
seda	doc_213943985036_item	3610580	et	3	main
vist	doc_213943985036_item	3610579	et	4	main
erialal	doc_213943985036_item	3610578	et	3	main
meelest	doc_213943985036_item	3610553	et	4	main
minu	doc_213943985036_item	3610552	et	3	main
mida	doc_213943985036_item	3610488	et	4	main
ma	doc_213943985036_item	3610483	et	3	main
miks	doc_213943985036_item	3610482	et	4	main
kui	doc_213943985033_item	3610327	et	3	main
küll	doc_213943985033_item	3610325	et	4	main
aga	doc_213943985033_item	3610324	et	3	main
haridusele	doc_213943985033_item	3610323	et	3	main
tasuta	doc_213943985033_item	3610322	et	4	main
tulla	doc_213943985033_item	3610321	et	3	main
võimaluse	doc_213943985033_item	3610320	et	3	main
saan	doc_213943985035_item	3610467	et	4	main
saama	doc_213943985035_item	3610452	et	4	main
avab	doc_213943985035_item	3610441	et	3	main
et	doc_213943985035_item	3610439	et	3	main
erialal	doc_213943985035_item	3610432	et	3	main
ootan	doc_213943985035_item	3610429	et	3	main
seda	doc_213943985035_item	3610427	et	3	main
paistab	doc_213943985035_item	3610417	et	3	main
oskama	doc_213943985035_item	3610414	et	3	main
ajakirjanik	doc_213943985035_item	3610412	et	3	main
mulle	doc_213943985035_item	3610410	et	4	main
saada	doc_213943985035_item	3610378	et	4	main
otsustasin	doc_213943985035_item	3610377	et	3	main
ma	doc_213943985035_item	3610376	et	3	main
koolis	doc_213943985035_item	3610375	et	4	main
juba	doc_213943985035_item	3610374	et	3	main
huvitav	doc_213943985035_item	3610373	et	4	main
väga	doc_213943985035_item	3610372	et	3	main
on	doc_213943985035_item	3610371	et	4	main
ajakirjandus	doc_213943985035_item	3610370	et	3	main
sest	doc_213943985035_item	3610369	et	4	main
eriala	doc_213943985035_item	3610368	et	4	main
selle	doc_213943985035_item	3610367	et	4	main
valisin	doc_213943985035_item	3610366	et	3	main
ma	doc_213943985035_item	3610365	et	3	main
ülikoolist	doc_213943985035_item	3610364	et	4	main
tallinna	doc_213943985035_item	3610363	et	4	main
ja	doc_213943985035_item	3610362	et	3	main
erialal	doc_213943985035_item	3610361	et	3	main
sellel	doc_213943985035_item	3610360	et	4	main
õppimisest	doc_213943985035_item	3610359	et	4	main
ootan	doc_213943985035_item	3610358	et	3	main
mida	doc_213943985035_item	3610357	et	4	main
2	doc_213943985035_item	3610356	et	2	main
eriala	doc_213943985035_item	3610355	et	4	main
selle	doc_213943985035_item	3610354	et	4	main
valisin	doc_213943985035_item	3610353	et	3	main
ma	doc_213943985035_item	3610352	et	3	main
1	doc_213943985035_item	3610350	et	2	main
miks	doc_213943985035_item	3610351	et	4	main
essee	doc_213943985035_item	3610349	et	4	main
võin	doc_213943985036_item	3610618	et	3	main
ülikool	doc_213943985036_item	3610609	et	4	main
sest	doc_213943985036_item	3610604	et	4	main
ülikoolil	doc_213943985036_item	3610603	et	4	main
ajalehes	doc_213943985035_item	3610469	et	3	main
edasi	doc_213943985035_item	3610464	et	3	main
välismaale	doc_213943985035_item	3610458	et	4	main
või	doc_213943985035_item	3610455	et	4	main
kõrgharidus	doc_213943985035_item	3610454	et	3	main
kvaliteetne	doc_213943985035_item	3610453	et	3	main
soovin	doc_213943985035_item	3610448	et	3	main
ma	doc_213943985035_item	3610447	et	3	main
tallinna	doc_213943985035_item	3610434	et	4	main
oskan	doc_213943985035_item	3610421	et	3	main
ma	doc_213943985035_item	3610419	et	3	main
meeldib	doc_213943985035_item	3610409	et	3	main
väga	doc_213943985035_item	3610408	et	3	main
vajadus	doc_213943985035_item	3610407	et	3	main
seda	doc_213943985035_item	3610406	et	3	main
silmaring	doc_213943985035_item	3610405	et	3	main
lai	doc_213943985035_item	3610404	et	3	main
olema	doc_213943985035_item	3610403	et	4	main
peab	doc_213943985035_item	3610402	et	4	main
ajakirjanikuks	doc_213943985035_item	3610401	et	3	main
et	doc_213943985035_item	3610400	et	3	main
teavad	doc_213943985035_item	3610399	et	3	main
kõik	doc_213943985035_item	3610398	et	4	main
samuti	doc_213943985035_item	3610397	et	3	main
kirjandusega	doc_213943985035_item	3610396	et	3	main
seotud	doc_213943985035_item	3610395	et	4	main
on	doc_213943985035_item	3610394	et	4	main
mis	doc_213943985035_item	3610393	et	4	main
eriala	doc_213943985035_item	3610392	et	4	main
valin	doc_213943985035_item	3610391	et	3	main
ma	doc_213943985035_item	3610390	et	3	main
sellepärast	doc_213943985035_item	3610389	et	3	main
raamatuid	doc_213943985035_item	3610388	et	3	main
loeda	doc_213943985035_item	3610387	et	4	main
armastan	doc_213943985035_item	3610386	et	3	main
väga	doc_213943985035_item	3610385	et	3	main
ma	doc_213943985035_item	3610384	et	3	main
eesmärk	doc_213943985035_item	3610383	et	3	main
minu	doc_213943985035_item	3610382	et	3	main
oli	doc_213943985035_item	3610381	et	3	main
see	doc_213943985035_item	3610380	et	3	main
ajakirjanikuks	doc_213943985035_item	3610379	et	3	main
teha	doc_213943985036_item	3610620	et	3	main
õppida	doc_213943985036_item	3610612	et	3	main
mind	doc_213943985036_item	3610597	et	4	main
aitab	doc_213943985036_item	3610596	et	3	main
ülikool	doc_213943985036_item	3610595	et	4	main
et	doc_213943985036_item	3610594	et	3	main
seda	doc_213943985036_item	3610593	et	3	main
sellel	doc_213943985036_item	3610577	et	4	main
tahaksid	doc_213943985036_item	3610570	et	4	main
seda	doc_213943985036_item	3610619	et	3	main
ma	doc_213943985036_item	3610615	et	3	main
ma	doc_213943985036_item	3610610	et	3	main
ma	doc_213943985036_item	3610591	et	3	main
saada	doc_213943985036_item	3610585	et	4	main
mida	doc_213943985036_item	3610574	et	4	main
2	doc_213943985036_item	3610573	et	2	main
inimesi	doc_213943985036_item	3610569	et	4	main
huvitava	doc_213943985036_item	3610565	et	4	main
võin	doc_213943985036_item	3610562	et	3	main
siis	doc_213943985036_item	3610560	et	3	main
selle	doc_213943985036_item	3610550	et	4	main
meeldib	doc_213943985036_item	3610543	et	3	main
eriala	doc_213943985036_item	3610542	et	4	main
selline	doc_213943985036_item	3610541	et	4	main
sest	doc_213943985036_item	3610540	et	4	main
eriala	doc_213943985036_item	3610539	et	4	main
selle	doc_213943985036_item	3610538	et	4	main
valisin	doc_213943985036_item	3610537	et	3	main
ma	doc_213943985036_item	3610536	et	3	main
miks	doc_213943985036_item	3610535	et	4	main
veel	doc_213943985036_item	3610534	et	4	main
eriala	doc_213943985036_item	3610533	et	4	main
hea	doc_213943985036_item	3610532	et	4	main
väga	doc_213943985036_item	3610531	et	3	main
on	doc_213943985036_item	3610530	et	4	main
see	doc_213943985036_item	3610529	et	3	main
et	doc_213943985036_item	3610528	et	3	main
tundub	doc_213943985036_item	3610527	et	3	main
mulle	doc_213943985036_item	3610526	et	4	main
inimestega	doc_213943985036_item	3610525	et	3	main
armastan	doc_213943985036_item	3610523	et	3	main
tutvuda	doc_213943985036_item	3610524	et	3	main
ma	doc_213943985036_item	3610522	et	3	main
sõbralik	doc_213943985036_item	3610521	et	3	main
2	doc_213943985036_item	3610487	et	2	main
valisin	doc_213943985036_item	3610484	et	3	main
1	doc_213943985036_item	3610481	et	2	main
nad	doc_213943985039_item	3610784	et	3	main
õpetajatega	doc_213943985039_item	3610783	et	4	main
tutvusin	doc_213943985039_item	3610782	et	3	main
õpin	doc_213943985039_item	3610770	et	3	main
ootan	doc_213943985039_item	3610766	et	3	main
õppida	doc_213943985039_item	3610763	et	3	main
õppida	doc_213943985039_item	3610761	et	3	main
tahan	doc_213943985039_item	3610760	et	3	main
lõpetan	doc_213943985039_item	3610687	et	3	main
inimestega	doc_213943985039_item	3610684	et	3	main
ja	doc_213943985039_item	3610665	et	3	main
jaoks	doc_213943985039_item	3610651	et	4	main
minu	doc_213943985039_item	3610650	et	3	main
õpetajaks	doc_213943985039_item	3610649	et	4	main
ootan	doc_213943985036_item	3610592	et	3	main
hea	doc_213943985036_item	3610588	et	4	main
tööd	doc_213943985036_item	3610587	et	4	main
hea	doc_213943985036_item	3610586	et	4	main
suhelda	doc_213943985036_item	3610572	et	4	main
minuga	doc_213943985036_item	3610571	et	3	main
palju	doc_213943985036_item	3610568	et	4	main
inimesena	doc_213943985036_item	3610566	et	3	main
väga	doc_213943985036_item	3610564	et	3	main
olla	doc_213943985036_item	3610563	et	3	main
ma	doc_213943985036_item	3610561	et	3	main
erialal	doc_213943985036_item	3610559	et	3	main
sellel	doc_213943985036_item	3610558	et	4	main
õppin	doc_213943985036_item	3610557	et	4	main
ma	doc_213943985036_item	3610556	et	3	main
kui	doc_213943985036_item	3610555	et	3	main
et	doc_213943985036_item	3610554	et	3	main
väga	doc_213943985036_item	3610520	et	3	main
olen	doc_213943985036_item	3610519	et	3	main
ma	doc_213943985036_item	3610518	et	3	main
inimestega	doc_213943985036_item	3610517	et	3	main
suhelda	doc_213943985036_item	3610516	et	4	main
meeldib	doc_213943985036_item	3610515	et	3	main
mulle	doc_213943985036_item	3610514	et	4	main
eriala	doc_213943985036_item	3610513	et	4	main
huvitav	doc_213943985036_item	3610512	et	4	main
väga	doc_213943985036_item	3610511	et	3	main
on	doc_213943985036_item	3610510	et	4	main
see	doc_213943985036_item	3610509	et	3	main
et	doc_213943985036_item	3610508	et	3	main
arvan	doc_213943985036_item	3610507	et	3	main
ma	doc_213943985036_item	3610506	et	3	main
väga	doc_213943985036_item	3610505	et	3	main
see	doc_213943985036_item	3610504	et	3	main
meeldib	doc_213943985036_item	3610503	et	3	main
mulle	doc_213943985036_item	3610502	et	4	main
sest	doc_213943985036_item	3610501	et	4	main
eriala	doc_213943985036_item	3610500	et	4	main
selle	doc_213943985036_item	3610499	et	4	main
valisin	doc_213943985036_item	3610498	et	3	main
ma	doc_213943985036_item	3610497	et	3	main
ja	doc_213943985036_item	3610567	et	3	main
väga	doc_213943985036_item	3610544	et	3	main
ülikoolist	doc_213943985036_item	3610495	et	4	main
tallinna	doc_213943985036_item	3610494	et	4	main
ja	doc_213943985036_item	3610493	et	3	main
erialal	doc_213943985036_item	3610492	et	3	main
sellel	doc_213943985036_item	3610491	et	4	main
essee	doc_213943985036_item	3610480	et	4	main
kolm	doc_213943985039_item	3610771	et	3	main
kõrgharidust	doc_213943985039_item	3610767	et	4	main
ma	doc_213943985039_item	3610765	et	3	main
ja	doc_213943985039_item	3610762	et	3	main
ma	doc_213943985039_item	3610759	et	3	main
ülikoolis	doc_213943985039_item	3610758	et	4	main
ja	doc_213943985039_item	3610757	et	3	main
ma	doc_213943985039_item	3610693	et	3	main
koolisse	doc_213943985039_item	3610692	et	4	main
töötamas	doc_213943985039_item	3610691	et	3	main
tulen	doc_213943985039_item	3610690	et	3	main
ja	doc_213943985039_item	3610689	et	3	main
ülikooli	doc_213943985039_item	3610688	et	4	main
teha	doc_213943985039_item	3610682	et	3	main
praegu	doc_213943985039_item	3610677	et	3	main
tõlgen	doc_213943985039_item	3610666	et	4	main
aeg	doc_213943985039_item	3610661	et	3	main
on	doc_213943985039_item	3610659	et	4	main
tõlkida	doc_213943985039_item	3610645	et	3	main
selle	doc_213943985039_item	3610638	et	4	main
mulle	doc_213943985039_item	3610749	et	4	main
ootan	doc_213943985039_item	3610746	et	3	main
küsimus	doc_213943985039_item	3610744	et	4	main
on	doc_213943985039_item	3610741	et	4	main
see	doc_213943985039_item	3610740	et	3	main
ülikoolis	doc_213943985039_item	3610739	et	4	main
teised	doc_213943985039_item	3610731	et	4	main
ja	doc_213943985039_item	3610728	et	3	main
iga	doc_213943985039_item	3610720	et	4	main
igasuguseid	doc_213943985039_item	3610719	et	3	main
eesti	doc_213943985039_item	3610712	et	4	main
meeldib	doc_213943985039_item	3610711	et	3	main
palju	doc_213943985040_item	3610958	et	4	main
kellel	doc_213943985040_item	3610950	et	4	main
teavad	doc_213943985040_item	3610940	et	3	main
et	doc_213943985040_item	3610933	et	3	main
ülikooli	doc_213943985040_item	3610904	et	4	main
pärast	doc_213943985040_item	3610898	et	4	main
vene	doc_213943985040_item	3610892	et	4	main
mängus	doc_213943985040_item	3610886	et	3	main
inimesi	doc_213943985040_item	3610884	et	4	main
1	doc_213943985036_item	3610496	et	2	main
eriala	doc_213943985036_item	3610486	et	4	main
selle	doc_213943985036_item	3610485	et	4	main
ülikoolis	doc_213943985039_item	3610780	et	4	main
aastat	doc_213943985039_item	3610779	et	3	main
kaks	doc_213943985039_item	3610778	et	3	main
ma	doc_213943985039_item	3610769	et	3	main
energiline	doc_213943985039_item	3610695	et	3	main
kui	doc_213943985039_item	3610685	et	3	main
lapsepõlves	doc_213943985039_item	3610669	et	4	main
luuletused	doc_213943985039_item	3610664	et	4	main
kirjutan	doc_213943985039_item	3610663	et	3	main
vaba	doc_213943985039_item	3610660	et	4	main
mul	doc_213943985039_item	3610658	et	3	main
eriala	doc_213943985039_item	3610656	et	4	main
saada	doc_213943985039_item	3610648	et	4	main
koolis	doc_213943985039_item	3610753	et	4	main
üldse	doc_213943985039_item	3610752	et	3	main
mida	doc_213943985039_item	3610735	et	4	main
2	doc_213943985039_item	3610734	et	2	main
on	doc_213943985039_item	3610718	et	4	main
on	doc_213943985040_item	3610961	et	4	main
tõelised	doc_213943985040_item	3610954	et	4	main
inimesed	doc_213943985040_item	3610949	et	3	main
ülikoolis	doc_213943985040_item	3610947	et	4	main
on	doc_213943985040_item	3610935	et	4	main
ma	doc_213943985040_item	3610928	et	3	main
ootan	doc_213943985040_item	3610925	et	3	main
tallinna	doc_213943985040_item	3610903	et	4	main
astusin	doc_213943985040_item	3610902	et	3	main
ma	doc_213943985040_item	3610901	et	3	main
lõpetamist	doc_213943985040_item	3610900	et	4	main
vaid	doc_213943985040_item	3610887	et	3	main
õppetada	doc_213943985040_item	3610883	et	4	main
istuda	doc_213943985040_item	3610862	et	3	main
aeg	doc_213943985040_item	3610859	et	3	main
vaba	doc_213943985040_item	3610858	et	4	main
oli	doc_213943985040_item	3610857	et	3	main
mul	doc_213943985040_item	3610856	et	3	main
kui	doc_213943985040_item	3610855	et	3	main
õpetajaks	doc_213943985040_item	3610854	et	4	main
õppimisest	doc_213943985040_item	3610804	et	4	main
ootan	doc_213943985040_item	3610803	et	3	main
ma	doc_213943985040_item	3610802	et	3	main
miks	doc_213943985040_item	3610795	et	4	main
õpivad	doc_724355862921_item	3611021	et	3	main
et	doc_724355862921_item	3611017	et	3	main
minu	doc_724355862921_item	3611006	et	3	main
vaid	doc_724355862921_item	3611003	et	3	main
ainult	doc_724355862921_item	3611001	et	4	main
mitte	doc_724355862921_item	3611000	et	3	main
toimub	doc_724355862921_item	3610999	et	3	main
ülikoolis	doc_724355862921_item	3610998	et	4	main
asuvad	doc_724355862921_item	3610995	et	4	main
on	doc_724355862921_item	3611096	et	4	main
ja	doc_724355862921_item	3611094	et	3	main
magistraturis	doc_724355862921_item	3611091	et	4	main
aga	doc_724355862921_item	3611086	et	3	main
veel	doc_724355862921_item	3611085	et	4	main
teha	doc_724355862921_item	3611084	et	3	main
huvitavama	doc_724355862921_item	3611079	et	4	main
võimalus	doc_724355862921_item	3611075	et	3	main
õppe	doc_724355862921_item	3611072	et	4	main
vatamata	doc_724355862921_item	3611056	et	4	main
töötavad	doc_187964557896_item	3611181	et	4	main
on	doc_187964557896_item	3611168	et	4	main
mul	doc_187964557896_item	3611167	et	3	main
süsteem	doc_187964557896_item	3611166	et	3	main
operatsioon	doc_187964557896_item	3611165	et	3	main
on	doc_187964557896_item	3611163	et	4	main
milline	doc_187964557896_item	3611162	et	3	main
ja	doc_187964557896_item	3611161	et	3	main
ja	doc_187964557896_item	3611153	et	3	main
palju	doc_187964557896_item	3611149	et	4	main
ma	doc_187964557896_item	3611147	et	3	main
minu	doc_187964557896_item	3611109	et	3	main
ja	doc_187964557896_item	3611107	et	3	main
essee	doc_187964557896_item	3611105	et	4	main
keele	doc_187964557907_item	3611315	et	4	main
inimesed	doc_187964557907_item	3611313	et	3	main
tark	doc_187964557907_item	3611312	et	3	main
väga	doc_187964557907_item	3611306	et	3	main
tulevikus	doc_213943985039_item	3610791	et	4	main
tee	doc_213943985039_item	3610790	et	4	main
on	doc_213943985039_item	3610789	et	4	main
see	doc_213943985039_item	3610788	et	3	main
ülikool	doc_213943985039_item	3610787	et	4	main
sõbralikud	doc_213943985039_item	3610786	et	3	main
on	doc_213943985039_item	3610785	et	4	main
tulevikus	doc_213943985039_item	3610774	et	4	main
aga	doc_213943985039_item	3610773	et	3	main
aastat	doc_213943985039_item	3610772	et	3	main
hästi	doc_213943985039_item	3610756	et	3	main
õpisin	doc_213943985039_item	3610755	et	4	main
ma	doc_213943985039_item	3610754	et	3	main
inglise	doc_213943985039_item	3610706	et	4	main
ja	doc_213943985039_item	3610705	et	3	main
keelt	doc_213943985039_item	3610704	et	4	main
vene	doc_213943985039_item	3610703	et	4	main
keelt	doc_213943985039_item	3610702	et	4	main
eesti	doc_213943985039_item	3610701	et	4	main
õpisin	doc_213943985039_item	3610700	et	4	main
ma	doc_213943985039_item	3610699	et	3	main
koolis	doc_213943985039_item	3610698	et	4	main
korralik	doc_213943985039_item	3610697	et	3	main
töökas	doc_213943985039_item	3610696	et	4	main
tahan	doc_213943985039_item	3610775	et	3	main
praegu	doc_213943985039_item	3610768	et	3	main
veel	doc_213943985039_item	3610764	et	4	main
olen	doc_213943985039_item	3610694	et	3	main
seda	doc_213943985039_item	3610683	et	3	main
võimalus	doc_213943985039_item	3610681	et	3	main
mul	doc_213943985039_item	3610678	et	3	main
kirjutama	doc_213943985039_item	3610676	et	3	main
lugema	doc_213943985039_item	3610675	et	4	main
õpisin	doc_213943985039_item	3610674	et	4	main
ja	doc_213943985039_item	3610673	et	3	main
nukuga	doc_213943985039_item	3610672	et	3	main
mängisin	doc_213943985039_item	3610671	et	3	main
ma	doc_213943985039_item	3610670	et	3	main
eesti	doc_213943985039_item	3610667	et	4	main
ma	doc_213943985039_item	3610662	et	3	main
ma	doc_213943985039_item	3610646	et	3	main
õppida	doc_213943985039_item	3610751	et	3	main
meeldib	doc_213943985039_item	3610750	et	3	main
teadmused	doc_213943985039_item	3610748	et	3	main
uued	doc_213943985039_item	3610747	et	3	main
ma	doc_213943985039_item	3610745	et	3	main
huvitab	doc_213943985039_item	3610743	et	3	main
ka	doc_213943985039_item	3610733	et	3	main
keeled	doc_213943985039_item	3610732	et	3	main
õppida	doc_213943985039_item	3610730	et	3	main
tahan	doc_213943985039_item	3610729	et	3	main
on	doc_213943985039_item	3610726	et	4	main
neid	doc_213943985039_item	3610716	et	4	main
kõige	doc_213943985039_item	3610708	et	4	main
ma	doc_213943985039_item	3610686	et	3	main
hea	doc_213943985039_item	3610680	et	4	main
on	doc_213943985039_item	3610679	et	4	main
keelt	doc_213943985039_item	3610668	et	4	main
kui	doc_213943985039_item	3610657	et	3	main
huvitab	doc_213943985039_item	3610655	et	3	main
väga	doc_213943985039_item	3610654	et	3	main
on	doc_213943985039_item	3610653	et	4	main
see	doc_213943985039_item	3610652	et	3	main
tahan	doc_213943985039_item	3610647	et	3	main
inimestega	doc_213943985039_item	3610644	et	3	main
mulle	doc_213943985039_item	3610641	et	4	main
eriala	doc_213943985039_item	3610639	et	4	main
õppimisest	doc_213943985039_item	3610738	et	4	main
ootan	doc_213943985039_item	3610737	et	3	main
ma	doc_213943985039_item	3610736	et	3	main
kui	doc_213943985039_item	3610724	et	3	main
ilus	doc_213943985039_item	3610723	et	4	main
on	doc_213943985039_item	3610722	et	4	main
keel	doc_213943985039_item	3610721	et	4	main
mulle	doc_213943985039_item	3610710	et	4	main
rohkem	doc_213943985039_item	3610709	et	4	main
ja	doc_213943985040_item	3610965	et	3	main
töö	doc_213943985040_item	3610964	et	4	main
lemmik	doc_213943985040_item	3610963	et	3	main
hea	doc_213943985040_item	3610962	et	4	main
kõrgharidus	doc_213943985040_item	3610952	et	3	main
kõrgharidust	doc_213943985040_item	3610948	et	4	main
õppimisest	doc_213943985040_item	3610946	et	4	main
ootan	doc_213943985040_item	3610945	et	3	main
ma	doc_213943985040_item	3610944	et	3	main
oskavad	doc_213943985040_item	3610943	et	4	main
tean	doc_213943985040_item	3610932	et	3	main
koolis	doc_213943985040_item	3610921	et	4	main
mingi	doc_213943985040_item	3610920	et	4	main
töötada	doc_213943985040_item	3610919	et	3	main
ja	doc_213943985040_item	3610918	et	3	main
kõrghariduse	doc_213943985040_item	3610917	et	3	main
endale	doc_213943985040_item	3610916	et	4	main
saada	doc_213943985040_item	3610915	et	4	main
kooli	doc_213943985040_item	3610899	et	4	main
kirjanduse	doc_213943985040_item	3610895	et	3	main
elus	doc_213943985040_item	3610888	et	4	main
panin	doc_213943985040_item	3610871	et	3	main
meeldis	doc_213943985040_item	3610861	et	3	main
lapsepõlvest	doc_213943985040_item	3610850	et	4	main
mina	doc_213943985040_item	3610841	et	4	main
oskama	doc_213943985040_item	3610840	et	3	main
ülikoolis	doc_213943985040_item	3610805	et	4	main
eriala	doc_213943985040_item	3610799	et	4	main
ma	doc_213943985040_item	3610796	et	3	main
suhelda	doc_213943985039_item	3610643	et	4	main
meeldib	doc_213943985039_item	3610642	et	3	main
sest	doc_213943985039_item	3610640	et	4	main
valin	doc_213943985039_item	3610637	et	3	main
ma	doc_213943985039_item	3610636	et	3	main
1	doc_213943985039_item	3610635	et	2	main
ülikoolis	doc_213943985039_item	3610634	et	4	main
õppimisest	doc_213943985039_item	3610633	et	4	main
ootan	doc_213943985039_item	3610632	et	3	main
ma	doc_213943985039_item	3610631	et	3	main
mida	doc_213943985039_item	3610630	et	4	main
2	doc_213943985039_item	3610629	et	2	main
eriala	doc_213943985039_item	3610628	et	4	main
selle	doc_213943985039_item	3610627	et	4	main
valin	doc_213943985039_item	3610626	et	3	main
ma	doc_213943985039_item	3610625	et	3	main
miks	doc_213943985039_item	3610624	et	4	main
1	doc_213943985039_item	3610623	et	2	main
essee	doc_213943985039_item	3610622	et	4	main
väga	doc_213943985039_item	3610742	et	3	main
võimalus	doc_213943985039_item	3610727	et	3	main
mul	doc_213943985039_item	3610725	et	3	main
keeled	doc_213943985039_item	3610717	et	3	main
keelt	doc_213943985039_item	3610715	et	4	main
vene	doc_213943985039_item	3610714	et	4	main
ja	doc_213943985039_item	3610713	et	3	main
keelt	doc_213943985039_item	3610707	et	4	main
neil	doc_213943985040_item	3610960	et	4	main
sõpru	doc_213943985040_item	3610959	et	3	main
on	doc_213943985040_item	3610953	et	4	main
palju	doc_213943985040_item	3610942	et	4	main
ja	doc_213943985040_item	3610941	et	3	main
huvitavad	doc_213943985040_item	3610934	et	4	main
teadmusi	doc_213943985040_item	3610930	et	3	main
ülikoolis	doc_213943985040_item	3610927	et	4	main
ma	doc_213943985040_item	3610924	et	3	main
mida	doc_213943985040_item	3610923	et	4	main
õpetajana	doc_213943985040_item	3610922	et	4	main
õpetajaks	doc_213943985040_item	3610896	et	4	main
keele	doc_213943985040_item	3610893	et	4	main
saada	doc_213943985040_item	3610891	et	4	main
tahan	doc_213943985040_item	3610890	et	3	main
ma	doc_213943985040_item	3610889	et	3	main
neile	doc_213943985040_item	3610872	et	4	main
neid	doc_213943985040_item	3610870	et	4	main
ja	doc_213943985040_item	3610864	et	3	main
kodus	doc_213943985040_item	3610863	et	4	main
mulle	doc_213943985040_item	3610860	et	4	main
vene	doc_213943985040_item	3610848	et	4	main
on	doc_213943985040_item	3610847	et	4	main
2	doc_213943985040_item	3610800	et	2	main
inimesi	doc_724355862921_item	3611019	et	4	main
ma	doc_724355862921_item	3611015	et	3	main
testerimine	doc_724355862921_item	3611013	et	4	main
digitaalsüsteemide	doc_724355862921_item	3611012	et	3	main
tarkvara	doc_724355862921_item	3611011	et	4	main
uus	doc_724355862921_item	3611010	et	3	main
teaduskonnad	doc_724355862921_item	3610997	et	4	main
ainus	doc_724355862921_item	3611097	et	4	main
palju	doc_724355862921_item	3611083	et	4	main
magistraturis	doc_724355862921_item	3611078	et	4	main
sellele	doc_724355862921_item	3611057	et	4	main
huvitav	doc_724355862921_item	3611055	et	4	main
minule	doc_724355862921_item	3611054	et	3	main
targad	doc_213943985040_item	3610972	et	3	main
on	doc_213943985040_item	3610971	et	4	main
nad	doc_213943985040_item	3610970	et	3	main
tähtis	doc_213943985040_item	3610969	et	4	main
kõige	doc_213943985040_item	3610968	et	4	main
on	doc_213943985040_item	3610967	et	4	main
mis	doc_213943985040_item	3610966	et	4	main
on	doc_213943985040_item	3610957	et	4	main
neil	doc_213943985040_item	3610956	et	4	main
inimesed	doc_213943985040_item	3610955	et	3	main
on	doc_213943985040_item	3610951	et	4	main
palju	doc_213943985040_item	3610939	et	4	main
kes	doc_213943985040_item	3610938	et	4	main
inimesed	doc_213943985040_item	3610937	et	3	main
need	doc_213943985040_item	3610936	et	3	main
ma	doc_213943985040_item	3610931	et	3	main
ootan	doc_213943985040_item	3610929	et	3	main
õppimisest	doc_213943985040_item	3610926	et	4	main
et	doc_213943985040_item	3610914	et	3	main
ülikooli	doc_213943985040_item	3610913	et	4	main
astuda	doc_213943985040_item	3610912	et	3	main
tahan	doc_213943985040_item	3610911	et	3	main
et	doc_213943985040_item	3610910	et	3	main
teadsin	doc_213943985040_item	3610909	et	3	main
ma	doc_213943985040_item	3610908	et	3	main
klassist	doc_213943985040_item	3610907	et	3	main
üheksandast	doc_213943985040_item	3610906	et	3	main
juba	doc_213943985040_item	3610905	et	3	main
2	doc_213943985040_item	3610897	et	2	main
ja	doc_213943985040_item	3610894	et	3	main
mitte	doc_213943985040_item	3610885	et	3	main
tahan	doc_213943985040_item	3610882	et	3	main
ma	doc_213943985040_item	3610881	et	3	main
inimene	doc_213943985040_item	3610880	et	3	main
täiskasvanud	doc_213943985040_item	3610879	et	4	main
juba	doc_213943985040_item	3610878	et	3	main
olen	doc_213943985040_item	3610877	et	3	main
ma	doc_213943985040_item	3610876	et	3	main
kui	doc_213943985040_item	3610875	et	3	main
praegu	doc_213943985040_item	3610874	et	3	main
hindeid	doc_213943985040_item	3610873	et	3	main
õppetasin	doc_213943985040_item	3610869	et	4	main
mänguasjadega	doc_213943985040_item	3610868	et	3	main
mängisin	doc_213943985040_item	3610867	et	3	main
ma	doc_213943985040_item	3610866	et	3	main
mängida	doc_213943985040_item	3610865	et	3	main
saada	doc_213943985040_item	3610853	et	4	main
tahaksin	doc_213943985040_item	3610852	et	3	main
ma	doc_213943985040_item	3610851	et	3	main
emakeel	doc_213943985040_item	3610846	et	4	main
minu	doc_213943985040_item	3610845	et	3	main
aga	doc_213943985040_item	3610844	et	3	main
eestlane	doc_213943985040_item	3610843	et	3	main
olen	doc_213943985040_item	3610842	et	3	main
mida	doc_213943985040_item	3610801	et	4	main
valisin	doc_213943985040_item	3610797	et	3	main
1	doc_213943985040_item	3610794	et	2	main
tehnika	doc_724355862921_item	3611023	et	4	main
teduskonnas	doc_724355862921_item	3611007	et	4	main
erinevad	doc_724355862921_item	3610996	et	4	main
insperatsioon	doc_724355862921_item	3611099	et	4	main
eriala	doc_724355862921_item	3611090	et	4	main
uus	doc_724355862921_item	3611089	et	3	main
et	doc_724355862921_item	3611088	et	3	main
loodan	doc_724355862921_item	3611087	et	3	main
eriala	doc_724355862921_item	3611080	et	4	main
jatkama	doc_724355862921_item	3611076	et	4	main
mulle	doc_724355862921_item	3611058	et	4	main
lektorid	doc_187964557896_item	3611179	et	3	main
see	doc_187964557896_item	3611175	et	3	main
nende	doc_187964557896_item	3611164	et	4	main
töötavad	doc_187964557896_item	3611160	et	4	main
arvutid	doc_187964557896_item	3611159	et	4	main
kuidas	doc_187964557896_item	3611158	et	3	main
eest	doc_187964557896_item	3611152	et	4	main
veedan	doc_187964557896_item	3611148	et	3	main
ootan	doc_187964557907_item	3611318	et	3	main
eesti	doc_187964557907_item	3611314	et	4	main
keel	doc_213943985040_item	3610849	et	4	main
keelt	doc_213943985040_item	3610839	et	4	main
kaks	doc_213943985040_item	3610838	et	3	main
minimaalselt	doc_213943985040_item	3610837	et	4	main
peab	doc_213943985040_item	3610836	et	4	main
inimene	doc_213943985040_item	3610835	et	3	main
iga	doc_213943985040_item	3610834	et	4	main
arvates	doc_213943985040_item	3610833	et	4	main
minu	doc_213943985040_item	3610832	et	3	main
keelt	doc_213943985040_item	3610831	et	4	main
saksa	doc_213943985040_item	3610830	et	4	main
natukene	doc_213943985040_item	3610829	et	4	main
ja	doc_213943985040_item	3610828	et	3	main
keelt	doc_213943985040_item	3610827	et	4	main
inglise	doc_213943985040_item	3610826	et	4	main
keelt	doc_213943985040_item	3610825	et	4	main
vene	doc_213943985040_item	3610824	et	4	main
õppisin	doc_213943985040_item	3610823	et	3	main
ma	doc_213943985040_item	3610822	et	3	main
koolis	doc_213943985040_item	3610821	et	4	main
keeled	doc_213943985040_item	3610820	et	3	main
igasuguseid	doc_213943985040_item	3610819	et	3	main
õppida	doc_213943985040_item	3610818	et	3	main
meeldib	doc_213943985040_item	3610817	et	3	main
väga	doc_213943985040_item	3610816	et	3	main
mulle	doc_213943985040_item	3610815	et	4	main
sest	doc_213943985040_item	3610814	et	4	main
võõrkeelena	doc_213943985040_item	3610813	et	3	main
keel	doc_213943985040_item	3610812	et	4	main
vene	doc_213943985040_item	3610811	et	4	main
eriala	doc_213943985040_item	3610810	et	4	main
selle	doc_213943985040_item	3610809	et	4	main
valisin	doc_213943985040_item	3610808	et	3	main
ma	doc_213943985040_item	3610807	et	3	main
1	doc_213943985040_item	3610806	et	2	main
selle	doc_213943985040_item	3610798	et	4	main
essee	doc_213943985040_item	3610793	et	4	main
kes	doc_724355862921_item	3611020	et	4	main
palju	doc_724355862921_item	3611018	et	4	main
mõtlen	doc_724355862921_item	3611016	et	3	main
jaoks	doc_724355862921_item	3611014	et	4	main
oli	doc_724355862921_item	3611008	et	3	main
ka	doc_724355862921_item	3611004	et	3	main
õppetööt	doc_724355862921_item	3611002	et	4	main
kus	doc_724355862921_item	3610994	et	3	main
tugev	doc_724355862921_item	3611098	et	4	main
huvitavam	doc_724355862921_item	3611093	et	4	main
on	doc_724355862921_item	3611082	et	4	main
õppemist	doc_724355862921_item	3611077	et	4	main
kes	doc_187964557896_item	3611180	et	4	main
mulle	doc_187964557896_item	3611173	et	4	main
teada	doc_187964557896_item	3611156	et	3	main
parem	doc_187964557896_item	3611155	et	4	main
tahan	doc_187964557896_item	3611154	et	3	main
mina	doc_187964557896_item	3611106	et	4	main
tallinna	doc_724355862921_item	3611022	et	4	main
realiseeritud	doc_724355862921_item	3611009	et	4	main
teadustöö	doc_724355862921_item	3611005	et	4	main
korpustest	doc_724355862921_item	3610993	et	3	main
seitsmest	doc_724355862921_item	3610992	et	4	main
koosneb	doc_724355862921_item	3610991	et	3	main
ta	doc_724355862921_item	3610990	et	4	main
ülikool	doc_724355862921_item	3610988	et	4	main
tallinnas	doc_724355862921_item	3610989	et	4	main
suurem	doc_724355862921_item	3610987	et	4	main
kõige	doc_724355862921_item	3610986	et	4	main
on	doc_724355862921_item	3610985	et	4	main
see	doc_724355862921_item	3610984	et	3	main
ülikoolis	doc_724355862921_item	3610983	et	4	main
tehnika	doc_724355862921_item	3610982	et	4	main
tallinna	doc_724355862921_item	3610981	et	4	main
õpin	doc_724355862921_item	3610980	et	3	main
ma	doc_724355862921_item	3610979	et	3	main
tänaseks	doc_724355862921_item	3610978	et	4	main
ülikool	doc_724355862921_item	3610977	et	4	main
ja	doc_724355862921_item	3610976	et	3	main
mina	doc_724355862921_item	3610975	et	4	main
essee	doc_724355862921_item	3610974	et	4	main
oppida	doc_724355862921_item	3611103	et	4	main
mind	doc_724355862921_item	3611102	et	4	main
aitab	doc_724355862921_item	3611101	et	3	main
mis	doc_724355862921_item	3611100	et	4	main
see	doc_724355862921_item	3611095	et	3	main
on	doc_724355862921_item	3611092	et	4	main
omandates	doc_724355862921_item	3611081	et	4	main
on	doc_724355862921_item	3611074	et	4	main
mul	doc_724355862921_item	3611073	et	3	main
bakalaurusse	doc_724355862921_item	3611071	et	4	main
lõppetan	doc_724355862921_item	3611070	et	4	main
edukalt	doc_724355862921_item	3611069	et	4	main
ma	doc_724355862921_item	3611068	et	3	main
kui	doc_724355862921_item	3611067	et	3	main
ja	doc_724355862921_item	3611066	et	3	main
ülikoolis	doc_724355862921_item	3611065	et	4	main
õpin	doc_724355862921_item	3611064	et	3	main
ma	doc_724355862921_item	3611063	et	3	main
fakt	doc_724355862921_item	3611061	et	3	main
et	doc_724355862921_item	3611062	et	3	main
see	doc_724355862921_item	3611060	et	3	main
meeldib	doc_724355862921_item	3611059	et	3	main
pole	doc_724355862921_item	3611053	et	3	main
eriala	doc_724355862921_item	3611052	et	4	main
see	doc_724355862921_item	3611051	et	3	main
et	doc_724355862921_item	3611050	et	3	main
näitab	doc_724355862921_item	3611049	et	3	main
aeg	doc_724355862921_item	3611048	et	3	main
aga	doc_724355862921_item	3611047	et	3	main
hästi	doc_724355862921_item	3611046	et	3	main
õppima	doc_724355862921_item	3611045	et	3	main
üritan	doc_724355862921_item	3611044	et	3	main
ma	doc_724355862921_item	3611043	et	3	main
aastat	doc_724355862921_item	3611042	et	3	main
kaks	doc_724355862921_item	3611041	et	3	main
juba	doc_724355862921_item	3611040	et	3	main
eriala	doc_724355862921_item	3611039	et	4	main
minu	doc_724355862921_item	3611038	et	3	main
meeldib	doc_724355862921_item	3611037	et	3	main
mulle	doc_724355862921_item	3611036	et	4	main
et	doc_724355862921_item	3611035	et	3	main
ütle	doc_724355862921_item	3611034	et	4	main
ei	doc_724355862921_item	3611033	et	4	main
ma	doc_724355862921_item	3611032	et	3	main
aga	doc_724355862921_item	3611031	et	3	main
armastan	doc_724355862921_item	3611030	et	3	main
ka	doc_724355862921_item	3611029	et	3	main
mina	doc_724355862921_item	3611028	et	4	main
ülikool	doc_724355862921_item	3611027	et	4	main
oma	doc_724355862921_item	3611026	et	4	main
armastavad	doc_724355862921_item	3611025	et	4	main
ülikoolis	doc_724355862921_item	3611024	et	4	main
meeldivad	doc_187964557896_item	3611178	et	4	main
meeldib	doc_187964557896_item	3611174	et	3	main
ttüst	doc_187964557896_item	3611172	et	4	main
muljed	doc_187964557896_item	3611171	et	3	main
hea	doc_187964557896_item	3611170	et	4	main
väga	doc_187964557896_item	3611169	et	3	main
arvuti	doc_187964557896_item	3611151	et	4	main
on	doc_187964557896_item	3611111	et	4	main
parem	doc_187964557907_item	3611323	et	4	main
et	doc_187964557907_item	3611319	et	3	main
loengud	doc_187964557907_item	3611316	et	3	main
õppivad	doc_187964557907_item	3611311	et	4	main
seal	doc_187964557907_item	3611310	et	4	main
katki	doc_187964557907_item	3611303	et	4	main
läks	doc_187964557907_item	3611302	et	3	main
ja	doc_187964557907_item	3611291	et	3	main
kond	doc_187964557907_item	3611284	et	4	main
kergem	doc_187964557907_item	3611277	et	4	main
haridus	doc_187964557907_item	3611275	et	3	main
ja	doc_187964557907_item	3611270	et	3	main
ja	doc_187964557907_item	3611267	et	3	main
kõrk	doc_187964557907_item	3611265	et	3	main
ma	doc_187964557907_item	3611263	et	3	main
ära	doc_187964557896_item	3611195	et	4	main
keelt	doc_187964557896_item	3611194	et	4	main
seda	doc_187964557896_item	3611193	et	3	main
õppida	doc_187964557896_item	3611192	et	3	main
varsti	doc_187964557896_item	3611191	et	3	main
mulle	doc_187964557896_item	3611190	et	4	main
aitavad	doc_187964557896_item	3611189	et	4	main
loengud	doc_187964557896_item	3611188	et	3	main
keele	doc_187964557896_item	3611187	et	4	main
eesti	doc_187964557896_item	3611186	et	4	main
et	doc_187964557896_item	3611185	et	3	main
arvan	doc_187964557896_item	3611184	et	3	main
ma	doc_187964557896_item	3611183	et	3	main
siin	doc_187964557896_item	3611182	et	4	main
ja	doc_187964557896_item	3611177	et	3	main
hoone	doc_187964557896_item	3611176	et	4	main
saada	doc_187964557896_item	3611157	et	4	main
aega	doc_187964557896_item	3611150	et	4	main
et	doc_187964557896_item	3611146	et	3	main
sest	doc_187964557896_item	3611145	et	4	main
õppima	doc_187964557896_item	3611144	et	3	main
eriala	doc_187964557896_item	3611143	et	4	main
seda	doc_187964557896_item	3611142	et	3	main
tulin	doc_187964557896_item	3611141	et	3	main
ma	doc_187964557896_item	3611140	et	3	main
klaveri	doc_187964557896_item	3611139	et	3	main
ja	doc_187964557896_item	3611138	et	3	main
viiuli	doc_187964557896_item	3611137	et	3	main
mängisin	doc_187964557896_item	3611136	et	3	main
ma	doc_187964557896_item	3611135	et	3	main
kus	doc_187964557896_item	3611134	et	3	main
ka	doc_187964557896_item	3611133	et	3	main
kool	doc_187964557896_item	3611132	et	4	main
kunstide	doc_187964557896_item	3611131	et	3	main
maardu	doc_187964557896_item	3611130	et	4	main
ja	doc_187964557896_item	3611129	et	3	main
aastal	doc_187964557896_item	3611128	et	3	main
kuuendal	doc_187964557896_item	3611127	et	3	main
tuhande	doc_187964557896_item	3611126	et	3	main
kahe	doc_187964557896_item	3611125	et	3	main
gümnaasium	doc_187964557896_item	3611124	et	3	main
paekaare	doc_187964557896_item	3611123	et	3	main
tallinna	doc_187964557896_item	3611122	et	4	main
lõpetasin	doc_187964557896_item	3611121	et	3	main
ma	doc_187964557896_item	3611120	et	3	main
vana	doc_187964557896_item	3611119	et	4	main
aastat	doc_187964557896_item	3611118	et	3	main
kaheksateist	doc_187964557896_item	3611117	et	4	main
olen	doc_187964557896_item	3611116	et	3	main
mina	doc_187964557896_item	3611115	et	4	main
ja	doc_187964557896_item	3611114	et	3	main
perekonnanimi	doc_187964557896_item	3611113	et	3	main
eesnimi	doc_187964557896_item	3611112	et	3	main
nimi	doc_187964557896_item	3611110	et	3	main
ülikool	doc_187964557896_item	3611108	et	4	main
eestikeel	doc_187964557907_item	3611321	et	4	main
minu	doc_187964557907_item	3611320	et	3	main
ma	doc_187964557907_item	3611317	et	3	main
hea	doc_187964557907_item	3611307	et	4	main
meldib	doc_187964557907_item	3611287	et	4	main
mehaanika	doc_187964557907_item	3611282	et	4	main
valin	doc_187964557907_item	3611281	et	3	main
ma	doc_187964557907_item	3611280	et	3	main
mul	doc_187964557907_item	3611272	et	3	main
huvitav	doc_187964557907_item	3611268	et	4	main
tahan	doc_187964557907_item	3611264	et	3	main
ap	doc_187964557907_item	3611326	et	4	main
kaks	doc_187964557907_item	3611325	et	3	main
ja	doc_187964557907_item	3611324	et	3	main
on	doc_187964557907_item	3611322	et	4	main
ttüst	doc_187964557907_item	3611309	et	4	main
muljed	doc_187964557907_item	3611308	et	3	main
auto	doc_187964557907_item	3611301	et	4	main
aastat	doc_187964557907_item	3611300	et	3	main
mulle	doc_187964557907_item	3611286	et	4	main
töökohas	doc_187964557907_item	3611279	et	4	main
leida	doc_187964557907_item	3611278	et	3	main
on	doc_187964557907_item	3611273	et	4	main
ttü-sse	doc_187964557907_item	3611261	et	3	main
tulin	doc_187964557907_item	3611260	et	3	main
ma	doc_187964557907_item	3611259	et	3	main
miks	doc_187964557907_item	3611258	et	4	main
haridus	doc_187964557907_item	3611257	et	3	main
kõrk	doc_187964557907_item	3611256	et	3	main
on	doc_187964557907_item	3611255	et	4	main
inimesel	doc_187964557907_item	3611254	et	3	main
kui	doc_187964557907_item	3611253	et	3	main
oluline	doc_187964557907_item	3611252	et	4	main
väga	doc_187964557907_item	3611251	et	3	main
mailmas	doc_187964557907_item	3611250	et	4	main
praegu	doc_187964557907_item	3611249	et	3	main
konna	doc_187964557907_item	3611248	et	4	main
teandus	doc_187964557907_item	3611247	et	4	main
mehaanika	doc_187964557907_item	3611246	et	4	main
ttü-st	doc_187964557907_item	3611245	et	3	main
avaldust	doc_187964557907_item	3611244	et	4	main
andsin	doc_187964557907_item	3611243	et	3	main
ja	doc_187964557907_item	3611242	et	3	main
keskkool	doc_187964557907_item	3611241	et	4	main
lõpuksin	doc_187964557907_item	3611240	et	4	main
ma	doc_187964557907_item	3611239	et	3	main
aastal	doc_187964557907_item	3611238	et	3	main
seal	doc_187964557907_item	3611237	et	4	main
eriala	doc_187964557907_item	3611236	et	4	main
tansi	doc_187964557907_item	3611235	et	4	main
hivitav	doc_187964557907_item	3611234	et	4	main
väga	doc_187964557907_item	3611233	et	3	main
on	doc_187964557907_item	3611232	et	4	main
see	doc_187964557907_item	3611231	et	3	main
breakdance	doc_187964557907_item	3611230	et	4	main
tantsin	doc_187964557907_item	3611229	et	3	main
ma	doc_187964557907_item	3611228	et	3	main
ja	doc_187964557907_item	3611227	et	3	main
õpisin	doc_670731433411_item	3611467	et	4	main
eesti	doc_670731433411_item	3611461	et	4	main
tean	doc_670731433411_item	3611460	et	3	main
on	doc_187964557907_item	3611305	et	4	main
mulle	doc_187964557907_item	3611304	et	4	main
ostsin	doc_187964557907_item	3611296	et	3	main
ma	doc_187964557907_item	3611295	et	3	main
tagasi	doc_187964557907_item	3611294	et	3	main
aastat	doc_187964557907_item	3611293	et	3	main
auto	doc_187964557907_item	3611290	et	4	main
ja	doc_187964557907_item	3611289	et	3	main
motorid	doc_187964557907_item	3611288	et	4	main
teandus	doc_187964557907_item	3611283	et	4	main
kõrk	doc_187964557907_item	3611274	et	3	main
kui	doc_187964557907_item	3611271	et	3	main
töö	doc_187964557907_item	3611269	et	4	main
haridus	doc_187964557907_item	3611266	et	3	main
sest	doc_187964557907_item	3611262	et	4	main
klassis	doc_670731433411_item	3611466	et	3	main
väga	doc_670731433411_item	3611463	et	3	main
seal	doc_670731433411_item	3611447	et	4	main
olen	doc_670731433411_item	3611437	et	3	main
keele	doc_670731433409_item	3611422	et	4	main
siin	doc_670731433409_item	3611410	et	4	main
õpida	doc_670731433409_item	3611409	et	4	main
ja	doc_670731433409_item	3611408	et	3	main
ttü	doc_670731433409_item	3611403	et	4	main
hea	doc_670731433409_item	3611401	et	4	main
ttüs	doc_670731433409_item	3611355	et	4	main
koolilt	doc_670731433409_item	3611353	et	4	main
minu	doc_670731433409_item	3611352	et	3	main
nüüd	doc_670731433409_item	3611348	et	4	main
ja	doc_670731433409_item	3611347	et	3	main
noor	doc_670731433409_item	3611341	et	3	main
olen	doc_670731433409_item	3611338	et	3	main
perekonnanimi	doc_670731433409_item	3611336	et	3	main
on	doc_670731433409_item	3611334	et	4	main
mina	doc_670731433409_item	3611329	et	4	main
essee	doc_670731433409_item	3611328	et	4	main
et	doc_670731433411_item	3611521	et	3	main
ttüst	doc_670731433411_item	3611518	et	4	main
tuttavad	doc_670731433411_item	3611513	et	4	main
ma	doc_670731433411_item	3611484	et	3	main
astusin	doc_670731433411_item	3611481	et	3	main
aastal	doc_670731433411_item	3611479	et	3	main
oli	doc_670731433411_item	3611474	et	3	main
mul	doc_670731433411_item	3611473	et	3	main
kirjaliku	doc_670731433413_item	3611676	et	3	main
ja	doc_670731433413_item	3611675	et	3	main
loengutega	doc_670731433413_item	3611669	et	4	main
eesti	doc_670731433413_item	3611667	et	4	main
on	doc_670731433413_item	3611665	et	4	main
paljud	doc_670731433413_item	3611664	et	3	main
tea	doc_670731433413_item	3611663	et	4	main
natukene	doc_670731433413_item	3611645	et	4	main
praegu	doc_670731433413_item	3611644	et	3	main
siis	doc_670731433413_item	3611637	et	3	main
aastat	doc_670731433413_item	3611635	et	3	main
ma	doc_670731433413_item	3611631	et	3	main
kui	doc_670731433413_item	3611630	et	3	main
asjad	doc_670731433413_item	3611629	et	3	main
saan	doc_670731433413_item	3611621	et	4	main
midagi	doc_670731433413_item	3611611	et	4	main
õppimine	doc_670731433413_item	3611605	et	4	main
tahan	doc_670731433413_item	3611590	et	3	main
pärast	doc_187964557907_item	3611299	et	4	main
ja	doc_187964557907_item	3611298	et	3	main
auto	doc_187964557907_item	3611297	et	4	main
kaks	doc_187964557907_item	3611292	et	3	main
sest	doc_187964557907_item	3611285	et	4	main
ma	doc_187964557907_item	3611276	et	3	main
ja	doc_670731433411_item	3611469	et	3	main
halvasti	doc_670731433411_item	3611464	et	3	main
keel	doc_670731433411_item	3611462	et	4	main
mind	doc_670731433411_item	3611456	et	4	main
huvitanud	doc_670731433411_item	3611455	et	4	main
oli	doc_670731433411_item	3611449	et	3	main
keskkool	doc_670731433411_item	3611446	et	4	main
tallinna	doc_670731433411_item	3611444	et	4	main
lõpetasin	doc_670731433411_item	3611443	et	3	main
parem	doc_670731433409_item	3611430	et	4	main
ilus	doc_670731433409_item	3611406	et	4	main
väga	doc_670731433409_item	3611405	et	3	main
töö	doc_670731433409_item	3611402	et	4	main
selle	doc_670731433409_item	3611368	et	4	main
lõpetasid	doc_670731433409_item	3611367	et	4	main
vanemad	doc_670731433409_item	3611366	et	4	main
minu	doc_670731433409_item	3611365	et	3	main
tugevam	doc_187964557907_item	3611226	et	4	main
terve	doc_187964557907_item	3611225	et	4	main
minu	doc_187964557907_item	3611224	et	3	main
teeb	doc_187964557907_item	3611223	et	3	main
sport	doc_187964557907_item	3611222	et	3	main
see	doc_187964557907_item	3611221	et	3	main
sest	doc_187964557907_item	3611220	et	4	main
eriala	doc_187964557907_item	3611219	et	4	main
spordi	doc_187964557907_item	3611218	et	4	main
see	doc_187964557907_item	3611217	et	3	main
meeldib	doc_187964557907_item	3611216	et	3	main
mulle	doc_187964557907_item	3611215	et	4	main
raskejõustik	doc_187964557907_item	3611214	et	3	main
hobbi	doc_187964557907_item	3611213	et	4	main
esimene	doc_187964557907_item	3611212	et	3	main
hobbid	doc_187964557907_item	3611211	et	4	main
palju	doc_187964557907_item	3611210	et	4	main
on	doc_187964557907_item	3611209	et	4	main
minu	doc_187964557907_item	3611208	et	3	main
narvas	doc_187964557907_item	3611207	et	4	main
elan	doc_187964557907_item	3611206	et	3	main
ma	doc_187964557907_item	3611205	et	3	main
eesnimi	doc_187964557907_item	3611204	et	3	main
nimi	doc_187964557907_item	3611202	et	3	main
minu	doc_187964557907_item	3611201	et	3	main
ülikool	doc_187964557907_item	3611200	et	4	main
ja	doc_187964557907_item	3611199	et	3	main
on	doc_187964557907_item	3611203	et	4	main
mina	doc_187964557907_item	3611198	et	4	main
essee	doc_187964557907_item	3611197	et	4	main
ukrainas	doc_670731433411_item	3611468	et	4	main
ei	doc_670731433411_item	3611454	et	4	main
missugused	doc_670731433411_item	3611453	et	3	main
tundi	doc_670731433411_item	3611452	et	4	main
mul	doc_670731433411_item	3611448	et	3	main
53	doc_670731433411_item	3611445	et	2	main
ma	doc_670731433411_item	3611442	et	3	main
sellel	doc_670731433411_item	3611440	et	4	main
perekonnanimi	doc_670731433411_item	3611439	et	3	main
eesnimi	doc_670731433411_item	3611438	et	3	main
essee	doc_670731433411_item	3611432	et	4	main
siin	doc_670731433409_item	3611416	et	4	main
et	doc_670731433409_item	3611415	et	3	main
loodan	doc_670731433409_item	3611414	et	3	main
ma	doc_670731433409_item	3611413	et	3	main
meeldiv	doc_670731433409_item	3611412	et	4	main
ma	doc_670731433409_item	3611360	et	3	main
sillamäe	doc_670731433409_item	3611344	et	3	main
parem	doc_670731433411_item	3611525	et	4	main
ootan	doc_670731433411_item	3611520	et	3	main
meldiv	doc_670731433411_item	3611516	et	4	main
on	doc_670731433411_item	3611515	et	4	main
esimeses	doc_670731433411_item	3611465	et	3	main
aastal	doc_670731433411_item	3611441	et	3	main
oleksid	doc_670731433409_item	3611429	et	4	main
eesti	doc_670731433409_item	3611421	et	4	main
sõpru	doc_670731433409_item	3611420	et	3	main
väga	doc_670731433409_item	3611411	et	3	main
on	doc_670731433409_item	3611404	et	4	main
leida	doc_670731433409_item	3611400	et	3	main
võimalusi	doc_670731433409_item	3611399	et	3	main
palju	doc_670731433409_item	3611398	et	4	main
mulle	doc_670731433409_item	3611397	et	4	main
annab	doc_670731433409_item	3611396	et	3	main
ttü	doc_670731433409_item	3611395	et	4	main
et	doc_670731433409_item	3611394	et	3	main
loodan	doc_670731433409_item	3611393	et	3	main
ma	doc_670731433409_item	3611392	et	3	main
teaduskondades	doc_670731433409_item	3611391	et	3	main
ärinduses	doc_670731433409_item	3611390	et	3	main
õpib	doc_670731433409_item	3611389	et	3	main
praegu	doc_670731433409_item	3611388	et	3	main
õde	doc_670731433409_item	3611387	et	4	main
minu	doc_670731433409_item	3611386	et	3	main
firmades	doc_670731433409_item	3611385	et	3	main
töötada	doc_670731433409_item	3611384	et	3	main
tahaksin	doc_670731433409_item	3611383	et	3	main
ka	doc_670731433409_item	3611382	et	3	main
ma	doc_670731433409_item	3611381	et	3	main
ja	doc_670731433409_item	3611380	et	3	main
furmas	doc_670731433409_item	3611379	et	4	main
töötab	doc_670731433409_item	3611377	et	3	main
suures	doc_670731433409_item	3611378	et	3	main
nüüd	doc_670731433409_item	3611376	et	4	main
ja	doc_670731433409_item	3611375	et	3	main
majandus	doc_670731433409_item	3611374	et	4	main
lõpetanud	doc_670731433409_item	3611373	et	4	main
on	doc_670731433409_item	3611372	et	4	main
ema	doc_670731433409_item	3611371	et	4	main
minu	doc_670731433409_item	3611370	et	3	main
ülikool	doc_670731433409_item	3611369	et	4	main
üliõpilane	doc_670731433409_item	3611351	et	3	main
ma	doc_670731433409_item	3611349	et	3	main
4	doc_670731433409_item	3611346	et	2	main
kool	doc_670731433409_item	3611345	et	4	main
aastat	doc_670731433409_item	3611340	et	3	main
teadmisi	doc_670731433411_item	3611523	et	4	main
lejan	doc_670731433411_item	3611511	et	4	main
on	doc_670731433411_item	3611497	et	4	main
mulle	doc_670731433411_item	3611489	et	4	main
et	doc_670731433411_item	3611488	et	3	main
sellepärast	doc_670731433411_item	3611487	et	3	main
ma	doc_670731433411_item	3611459	et	3	main
praegu	doc_670731433411_item	3611458	et	3	main
ja	doc_670731433411_item	3611457	et	3	main
keele	doc_670731433411_item	3611451	et	4	main
eesti	doc_670731433411_item	3611450	et	4	main
mina	doc_670731433411_item	3611436	et	4	main
ülikool	doc_670731433411_item	3611435	et	4	main
ja	doc_670731433411_item	3611434	et	3	main
mina	doc_670731433411_item	3611433	et	4	main
teadmised	doc_670731433409_item	3611428	et	4	main
minu	doc_670731433409_item	3611427	et	3	main
et	doc_670731433409_item	3611426	et	3	main
ootan	doc_670731433409_item	3611425	et	3	main
ma	doc_670731433409_item	3611424	et	3	main
loengutelt	doc_670731433409_item	3611423	et	4	main
palju	doc_670731433409_item	3611419	et	4	main
olevad	doc_670731433409_item	3611418	et	4	main
minul	doc_670731433409_item	3611417	et	3	main
hoone	doc_670731433409_item	3611407	et	4	main
veel	doc_670731433409_item	3611364	et	4	main
ja	doc_670731433409_item	3611363	et	3	main
valin	doc_670731433409_item	3611361	et	3	main
sellepärast	doc_670731433409_item	3611359	et	3	main
sõprad	doc_670731433409_item	3611358	et	4	main
minu	doc_670731433409_item	3611357	et	3	main
palju	doc_670731433409_item	3611356	et	4	main
lõpetasin	doc_670731433409_item	3611343	et	3	main
18	doc_670731433409_item	3611339	et	2	main
ülikool	doc_670731433409_item	3611331	et	4	main
oleksid	doc_670731433411_item	3611524	et	4	main
minu	doc_670731433411_item	3611522	et	3	main
muljed	doc_670731433411_item	3611517	et	3	main
ma	doc_670731433411_item	3611510	et	3	main
siin	doc_670731433411_item	3611509	et	4	main
mulle	doc_670731433411_item	3611502	et	4	main
inimesi	doc_670731433411_item	3611501	et	4	main
huvitavad	doc_670731433411_item	3611500	et	4	main
palju	doc_670731433411_item	3611499	et	4	main
väga	doc_670731433411_item	3611498	et	3	main
majandusteaduskond	doc_670731433411_item	3611483	et	3	main
ma	doc_670731433411_item	3611480	et	3	main
sellel	doc_670731433411_item	3611478	et	4	main
aastat	doc_670731433411_item	3611476	et	3	main
keele	doc_670731433413_item	3611668	et	4	main
kõik	doc_670731433413_item	3611652	et	4	main
ja	doc_670731433413_item	3611643	et	3	main
ained	doc_670731433413_item	3611642	et	3	main
mõlemad	doc_670731433413_item	3611641	et	3	main
kooli	doc_670731433413_item	3611633	et	4	main
lõpetasin	doc_670731433413_item	3611632	et	3	main
inimestele	doc_670731433413_item	3611623	et	3	main
ma	doc_670731433413_item	3611620	et	3	main
ma	doc_670731433413_item	3611617	et	3	main
lihtne	doc_670731433413_item	3611615	et	3	main
ei	doc_670731433413_item	3611613	et	4	main
elus	doc_670731433413_item	3611612	et	4	main
võib	doc_670731433413_item	3611606	et	3	main
mõtlen	doc_670731433413_item	3611602	et	3	main
inseneri	doc_670731433413_item	3611592	et	4	main
olla	doc_670731433413_item	3611591	et	3	main
sellega	doc_670731433413_item	3611588	et	3	main
ma	doc_670731433413_item	3611575	et	3	main
paem	doc_670731433413_item	3611572	et	4	main
et	doc_670731433413_item	3611569	et	3	main
ma	doc_670731433414_item	3611780	et	3	main
ttü	doc_670731433414_item	3611779	et	4	main
meeldib	doc_670731433414_item	3611778	et	3	main
mulle	doc_670731433414_item	3611777	et	4	main
majandust	doc_670731433414_item	3611761	et	4	main
tulin	doc_670731433414_item	3611758	et	3	main
ja	doc_670731433414_item	3611754	et	3	main
ma	doc_670731433414_item	3611748	et	3	main
käin	doc_670731433414_item	3611736	et	3	main
korda	doc_670731433414_item	3611733	et	4	main
kolm	doc_670731433414_item	3611732	et	3	main
ma	doc_670731433414_item	3611729	et	3	main
mulle	doc_670731433414_item	3611724	et	4	main
eriti	doc_670731433414_item	3611723	et	3	main
tähted	doc_670731433414_item	3611715	et	4	main
sel	doc_670731433414_item	3611693	et	3	main
minu	doc_670731433415_item	3611874	et	3	main
on	doc_670731433415_item	3611870	et	4	main
ttü	doc_670731433409_item	3611362	et	4	main
astusid	doc_670731433409_item	3611354	et	4	main
olen	doc_670731433409_item	3611350	et	3	main
ma	doc_670731433409_item	3611342	et	3	main
ma	doc_670731433409_item	3611337	et	3	main
eesnimi	doc_670731433409_item	3611335	et	3	main
nimi	doc_670731433409_item	3611333	et	3	main
minu	doc_670731433409_item	3611332	et	3	main
ja	doc_670731433409_item	3611330	et	3	main
ma	doc_670731433411_item	3611519	et	3	main
palju	doc_670731433411_item	3611512	et	4	main
meldib	doc_670731433411_item	3611503	et	4	main
siin	doc_670731433411_item	3611496	et	4	main
valisin	doc_670731433411_item	3611485	et	3	main
kaheksa	doc_670731433411_item	3611475	et	4	main
kui	doc_670731433411_item	3611472	et	3	main
sinna	doc_670731433411_item	3611471	et	3	main
ma	doc_670731433413_item	3611670	et	3	main
aitavad	doc_670731433413_item	3611658	et	4	main
ja	doc_670731433413_item	3611657	et	3	main
naeratavad	doc_670731433413_item	3611656	et	4	main
inimesed	doc_670731433413_item	3611655	et	3	main
kõik	doc_670731433413_item	3611654	et	4	main
meeldib	doc_670731433413_item	3611653	et	3	main
pudub	doc_670731433413_item	3611648	et	4	main
unustasin	doc_670731433413_item	3611640	et	3	main
muidugi	doc_670731433413_item	3611638	et	4	main
tagasi	doc_670731433413_item	3611636	et	3	main
üks	doc_670731433413_item	3611634	et	3	main
teised	doc_670731433413_item	3611628	et	4	main
või	doc_670731433413_item	3611627	et	4	main
proekteerida	doc_670731433413_item	3611624	et	4	main
ole	doc_670731433413_item	3611614	et	4	main
see	doc_670731433413_item	3611604	et	3	main
elus	doc_670731433413_item	3611601	et	4	main
meie	doc_670731433413_item	3611600	et	4	main
osakond	doc_670731433413_item	3611589	et	3	main
valisin	doc_670731433413_item	3611576	et	3	main
on	doc_670731433413_item	3611573	et	4	main
ülikool	doc_670731433413_item	3611571	et	4	main
arvan	doc_670731433413_item	3611568	et	3	main
ma	doc_670731433413_item	3611567	et	3	main
et	doc_670731433413_item	3611566	et	3	main
ttü	doc_670731433413_item	3611565	et	4	main
on	doc_670731433413_item	3611564	et	4	main
valik	doc_670731433413_item	3611563	et	3	main
minu	doc_670731433413_item	3611562	et	3	main
päevast	doc_670731433414_item	3611776	et	4	main
esmast	doc_670731433414_item	3611775	et	3	main
et	doc_670731433414_item	3611763	et	3	main
puhkan	doc_670731433414_item	3611753	et	3	main
kus	doc_670731433414_item	3611751	et	3	main
käin	doc_670731433414_item	3611749	et	3	main
vaba	doc_670731433414_item	3611745	et	4	main
taipoksiga	doc_670731433414_item	3611741	et	3	main
kus	doc_670731433414_item	3611738	et	3	main
ma	doc_670731433414_item	3611735	et	3	main
spordiga	doc_670731433414_item	3611731	et	3	main
veel	doc_670731433414_item	3611728	et	4	main
raamatud	doc_670731433414_item	3611727	et	4	main
meeldib	doc_670731433414_item	3611721	et	3	main
vaba	doc_670731433414_item	3611718	et	4	main
elus	doc_670731433414_item	3611717	et	4	main
aastat	doc_670731433414_item	3611691	et	3	main
ma	doc_670731433414_item	3611688	et	3	main
mul	doc_670731433411_item	3611514	et	3	main
et	doc_670731433411_item	3611508	et	3	main
mõtlen	doc_670731433411_item	3611507	et	3	main
ma	doc_670731433411_item	3611506	et	3	main
ja	doc_670731433411_item	3611505	et	3	main
suheltada	doc_670731433411_item	3611504	et	4	main
ttüst	doc_670731433411_item	3611495	et	4	main
muljed	doc_670731433411_item	3611494	et	3	main
minu	doc_670731433411_item	3611493	et	3	main
eriala	doc_670731433411_item	3611492	et	4	main
see	doc_670731433411_item	3611491	et	3	main
meldib	doc_670731433411_item	3611490	et	4	main
tulen	doc_670731433411_item	3611470	et	3	main
suhtle	doc_670731433413_item	3611674	et	4	main
oma	doc_670731433413_item	3611673	et	4	main
parandada	doc_670731433413_item	3611672	et	3	main
midagi	doc_670731433413_item	3611661	et	4	main
ma	doc_670731433413_item	3611660	et	3	main
kui	doc_670731433413_item	3611659	et	3	main
et	doc_670731433413_item	3611651	et	3	main
minu	doc_670731433413_item	3611649	et	3	main
mis	doc_670731433413_item	3611647	et	4	main
raske	doc_670731433413_item	3611646	et	4	main
ma	doc_670731433413_item	3611639	et	3	main
nende	doc_670731433413_item	3611625	et	4	main
kui	doc_670731433413_item	3611616	et	3	main
mitte	doc_670731433413_item	3611610	et	3	main
raske	doc_670731433413_item	3611608	et	4	main
väga	doc_670731433413_item	3611597	et	3	main
seotud	doc_670731433413_item	3611587	et	4	main
ehitusteadusosakond	doc_670731433413_item	3611577	et	3	main
rohkem	doc_670731433414_item	3611771	et	4	main
on	doc_670731433414_item	3611770	et	4	main
haridusega	doc_670731433414_item	3611769	et	3	main
majandus	doc_670731433414_item	3611768	et	4	main
et	doc_670731433414_item	3611767	et	3	main
kindel	doc_670731433414_item	3611766	et	3	main
olen	doc_670731433414_item	3611765	et	3	main
ma	doc_670731433414_item	3611764	et	3	main
töötan	doc_670731433414_item	3611755	et	3	main
siis	doc_670731433414_item	3611747	et	3	main
tegelen	doc_670731433414_item	3611740	et	3	main
kiber-punk	doc_670731433414_item	3611726	et	4	main
meie	doc_670731433414_item	3611716	et	4	main
vana	doc_670731433414_item	3611692	et	4	main
kaheksateist	doc_670731433414_item	3611690	et	4	main
perekonnanimi	doc_670731433414_item	3611687	et	3	main
6	doc_670731433415_item	3611803	et	2	main
töö	doc_670731433415_item	3611873	et	4	main
päevane	doc_670731433415_item	3611872	et	4	main
kõrg	doc_670731433415_item	3611848	et	4	main
töötada	doc_670731433415_item	3611832	et	3	main
ma	doc_670731433415_item	3611821	et	3	main
kooli	doc_670731433415_item	3611812	et	4	main
rääkida	doc_670731433417_item	3611998	et	3	main
vaja	doc_670731433417_item	3611992	et	4	main
juba	doc_670731433417_item	3611990	et	3	main
vaja	doc_670731433417_item	3611984	et	4	main
on	doc_670731433417_item	3611963	et	4	main
ja	doc_670731433417_item	3611962	et	3	main
oli	doc_670731433417_item	3611961	et	3	main
polnud	doc_670731433417_item	3611955	et	3	main
majanduse	doc_670731433417_item	3611952	et	4	main
edukalt	doc_670731433417_item	3611950	et	4	main
veel	doc_670731433417_item	3611949	et	4	main
nagu	doc_670731433417_item	3611937	et	3	main
veel	doc_670731433417_item	3611932	et	4	main
võimalusi	doc_670731433417_item	3611930	et	3	main
ttü-sse	doc_670731433417_item	3611928	et	3	main
tehtnud	doc_670731433417_item	3611920	et	4	main
kõik	doc_670731433421_item	3612100	et	4	main
on	doc_670731433421_item	3612077	et	4	main
vaja	doc_670731433421_item	3612065	et	4	main
töö	doc_670731433421_item	3612060	et	4	main
tallinnas	doc_670731433421_item	3612042	et	4	main
firmas	doc_670731433421_item	3612040	et	3	main
ja	doc_670731433421_item	3612035	et	3	main
majandusteaduskond	doc_670731433411_item	3611486	et	3	main
ttüs	doc_670731433411_item	3611482	et	4	main
vana	doc_670731433411_item	3611477	et	4	main
teadmised	doc_670731433413_item	3611677	et	4	main
tahan	doc_670731433413_item	3611671	et	3	main
sõbralik	doc_670731433413_item	3611666	et	3	main
ei	doc_670731433413_item	3611662	et	4	main
mulje	doc_670731433413_item	3611650	et	4	main
maja	doc_670731433413_item	3611626	et	4	main
aita	doc_670731433413_item	3611622	et	4	main
ülikool	doc_670731433413_item	3611619	et	4	main
lõpetan	doc_670731433413_item	3611618	et	3	main
aga	doc_670731433413_item	3611609	et	3	main
olla	doc_670731433413_item	3611607	et	3	main
et	doc_670731433413_item	3611603	et	3	main
osa	doc_670731433413_item	3611599	et	4	main
vajalik	doc_670731433413_item	3611598	et	3	main
praegu	doc_670731433413_item	3611596	et	3	main
tsiviilehitus	doc_670731433413_item	3611595	et	4	main
ja	doc_670731433413_item	3611594	et	3	main
tööstus	doc_670731433413_item	3611593	et	3	main
on	doc_670731433413_item	3611586	et	4	main
kõik	doc_670731433413_item	3611584	et	4	main
õppida	doc_670731433413_item	3611583	et	3	main
mis	doc_670731433413_item	3611585	et	4	main
huvitav	doc_670731433413_item	3611582	et	4	main
väga	doc_670731433413_item	3611581	et	3	main
on	doc_670731433413_item	3611580	et	4	main
mul	doc_670731433413_item	3611579	et	3	main
et	doc_670731433413_item	3611578	et	3	main
see	doc_670731433413_item	3611570	et	3	main
siis	doc_670731433413_item	3611557	et	3	main
ma	doc_670731433414_item	3611757	et	3	main
eestis	doc_670731433413_item	3611574	et	3	main
ülikoolis	doc_670731433413_item	3611561	et	4	main
minna	doc_670731433413_item	3611560	et	3	main
pean	doc_670731433413_item	3611559	et	4	main
ma	doc_670731433413_item	3611558	et	3	main
kõrgharidus	doc_670731433413_item	3611556	et	3	main
saada	doc_670731433413_item	3611555	et	4	main
tahan	doc_670731433413_item	3611554	et	3	main
ma	doc_670731433413_item	3611553	et	3	main
kui	doc_670731433413_item	3611552	et	3	main
tehnikaülikooliga	doc_670731433413_item	3611551	et	4	main
tallinna	doc_670731433413_item	3611550	et	4	main
kõrval	doc_670731433413_item	3611549	et	4	main
tallinnas	doc_670731433413_item	3611548	et	4	main
praegu	doc_670731433413_item	3611547	et	3	main
elan	doc_670731433413_item	3611546	et	3	main
ja	doc_670731433413_item	3611545	et	3	main
eestis	doc_670731433413_item	3611544	et	3	main
sündinud	doc_670731433413_item	3611543	et	4	main
olen	doc_670731433413_item	3611542	et	3	main
ma	doc_670731433413_item	3611541	et	3	main
aastal	doc_670731433413_item	3611540	et	3	main
viiendal	doc_670731433413_item	3611539	et	3	main
kahetuhande	doc_670731433413_item	3611538	et	4	main
kooli	doc_670731433413_item	3611537	et	4	main
lõpetasin	doc_670731433413_item	3611536	et	3	main
ma	doc_670731433413_item	3611535	et	3	main
eesnimi	doc_670731433413_item	3611534	et	3	main
on	doc_670731433413_item	3611533	et	4	main
nimi	doc_670731433413_item	3611532	et	3	main
minu	doc_670731433413_item	3611531	et	3	main
ülikool	doc_670731433413_item	3611530	et	4	main
ja	doc_670731433413_item	3611529	et	3	main
mina	doc_670731433413_item	3611528	et	4	main
essee	doc_670731433413_item	3611527	et	4	main
ise	doc_670731433414_item	3611774	et	4	main
realiseerida	doc_670731433414_item	3611773	et	3	main
võimalusi	doc_670731433414_item	3611772	et	3	main
just	doc_670731433414_item	3611760	et	3	main
õppima	doc_670731433414_item	3611759	et	3	main
ma	doc_670731433414_item	3611739	et	3	main
trenni	doc_670731433414_item	3611737	et	4	main
nädalas	doc_670731433414_item	3611734	et	3	main
tegelen	doc_670731433414_item	3611730	et	3	main
lugeda	doc_670731433414_item	3611722	et	3	main
arvestus	doc_670731433414_item	3611793	et	4	main
loengutelt	doc_670731433414_item	3611792	et	4	main
keele	doc_670731433414_item	3611791	et	4	main
eesti	doc_670731433414_item	3611790	et	4	main
ootan	doc_670731433414_item	3611789	et	3	main
ma	doc_670731433414_item	3611788	et	3	main
koht	doc_670731433414_item	3611787	et	3	main
huvitav	doc_670731433414_item	3611786	et	4	main
väga	doc_670731433414_item	3611785	et	3	main
see	doc_670731433414_item	3611783	et	3	main
on	doc_670731433414_item	3611784	et	4	main
et	doc_670731433414_item	3611782	et	3	main
arvan	doc_670731433414_item	3611781	et	3	main
sellepärast	doc_670731433414_item	3611762	et	3	main
samaegselt	doc_670731433414_item	3611756	et	4	main
ma	doc_670731433414_item	3611752	et	3	main
jõusaalis	doc_670731433414_item	3611750	et	3	main
aeg	doc_670731433414_item	3611746	et	3	main
on	doc_670731433414_item	3611744	et	4	main
mul	doc_670731433414_item	3611743	et	3	main
kui	doc_670731433414_item	3611742	et	3	main
meeldivad	doc_670731433414_item	3611725	et	4	main
mulle	doc_670731433414_item	3611720	et	4	main
ajal	doc_670731433414_item	3611719	et	4	main
väga	doc_670731433414_item	3611714	et	3	main
on	doc_670731433414_item	3611713	et	4	main
aastad	doc_670731433414_item	3611712	et	3	main
kooli	doc_670731433414_item	3611711	et	4	main
et	doc_670731433414_item	3611710	et	3	main
arvan	doc_670731433414_item	3611709	et	3	main
ma	doc_670731433414_item	3611708	et	3	main
kodu	doc_670731433414_item	3611707	et	4	main
nagu	doc_670731433414_item	3611706	et	3	main
jaoks	doc_670731433414_item	3611705	et	4	main
minu	doc_670731433414_item	3611704	et	3	main
oli	doc_670731433414_item	3611703	et	3	main
ta	doc_670731433414_item	3611702	et	4	main
kool	doc_670731433414_item	3611701	et	4	main
armastan	doc_670731433414_item	3611699	et	3	main
ma	doc_670731433414_item	3611698	et	3	main
minu	doc_670731433414_item	3611700	et	3	main
kooli	doc_670731433414_item	3611697	et	4	main
lõpetasin	doc_670731433414_item	3611696	et	3	main
ma	doc_670731433414_item	3611695	et	3	main
aastal	doc_670731433414_item	3611694	et	3	main
kool	doc_670731433415_item	3611802	et	4	main
narva	doc_670731433415_item	3611801	et	4	main
lõpetasin	doc_670731433415_item	3611800	et	3	main
ma	doc_670731433415_item	3611799	et	3	main
ülikool	doc_670731433415_item	3611798	et	4	main
ja	doc_670731433415_item	3611797	et	3	main
mina	doc_670731433415_item	3611796	et	4	main
majandus	doc_670731433415_item	3611868	et	4	main
majanduse	doc_670731433415_item	3611849	et	4	main
majandust	doc_670731433415_item	3611840	et	4	main
oskama	doc_670731433415_item	3611839	et	3	main
tahan	doc_670731433415_item	3611831	et	3	main
õppima	doc_670731433415_item	3611823	et	3	main
õpida	doc_670731433415_item	3611813	et	4	main
õpida	doc_670731433415_item	3611806	et	4	main
ma	doc_670731433415_item	3611805	et	3	main
keelt	doc_670731433417_item	3611986	et	4	main
ei	doc_670731433417_item	3611982	et	4	main
ausalt	doc_670731433417_item	3611974	et	4	main
üldse	doc_670731433417_item	3611954	et	3	main
igale	doc_670731433417_item	3611938	et	3	main
kardsin	doc_670731433417_item	3611922	et	4	main
sellepärast	doc_670731433421_item	3612097	et	3	main
väga	doc_670731433421_item	3612094	et	3	main
õppida	doc_670731433421_item	3612083	et	3	main
ma	doc_670731433421_item	3612081	et	3	main
erineva	doc_670731433421_item	3612079	et	4	main
palju	doc_670731433421_item	3612078	et	4	main
olen	doc_670731433414_item	3611689	et	3	main
eesnimi	doc_670731433414_item	3611686	et	3	main
on	doc_670731433414_item	3611685	et	4	main
nimi	doc_670731433414_item	3611684	et	3	main
minu	doc_670731433414_item	3611683	et	3	main
ülikool	doc_670731433414_item	3611682	et	4	main
ja	doc_670731433414_item	3611681	et	3	main
mina	doc_670731433414_item	3611680	et	4	main
essee	doc_670731433414_item	3611679	et	4	main
kui	doc_670731433415_item	3611804	et	3	main
vend	doc_670731433415_item	3611875	et	3	main
see	doc_670731433415_item	3611869	et	3	main
ema	doc_670731433415_item	3611842	et	4	main
minu	doc_670731433415_item	3611841	et	3	main
eri	doc_670731433415_item	3611833	et	4	main
majandust	doc_670731433415_item	3611828	et	4	main
majandust	doc_670731433415_item	3611824	et	4	main
tulin	doc_670731433415_item	3611822	et	3	main
ülikoolis	doc_670731433415_item	3611820	et	4	main
koolis	doc_670731433417_item	3611988	et	4	main
õppida	doc_670731433417_item	3611987	et	3	main
juba	doc_670731433417_item	3611981	et	3	main
vanuses	doc_670731433417_item	3611980	et	4	main
kui	doc_670731433417_item	3611973	et	3	main
igas	doc_670731433417_item	3611971	et	3	main
kui	doc_670731433417_item	3611970	et	3	main
kõik	doc_670731433417_item	3611960	et	4	main
kursusi	doc_670731433417_item	3611953	et	3	main
lõpetasi	doc_670731433417_item	3611951	et	4	main
õppida	doc_670731433417_item	3611946	et	3	main
see	doc_670731433417_item	3611942	et	3	main
miks	doc_670731433417_item	3611934	et	4	main
tulemusi	doc_670731433417_item	3611926	et	4	main
halvasi	doc_670731433417_item	3611925	et	4	main
sain	doc_670731433417_item	3611924	et	3	main
et	doc_670731433417_item	3611923	et	3	main
aktualne	doc_670731433415_item	3611888	et	4	main
väga	doc_670731433415_item	3611887	et	3	main
on	doc_670731433415_item	3611886	et	4	main
see	doc_670731433415_item	3611885	et	3	main
majandus	doc_670731433415_item	3611884	et	4	main
tänapäeval	doc_670731433415_item	3611883	et	3	main
et	doc_670731433415_item	3611882	et	3	main
mõtlen	doc_670731433415_item	3611881	et	3	main
ma	doc_670731433415_item	3611880	et	3	main
teaduskond	doc_670731433415_item	3611879	et	3	main
majanduse	doc_670731433415_item	3611878	et	4	main
ka	doc_670731433415_item	3611877	et	3	main
õppida	doc_670731433415_item	3611876	et	3	main
essee	doc_670731433415_item	3611795	et	4	main
iga	doc_670731433415_item	3611871	et	4	main
et	doc_670731433415_item	3611867	et	3	main
arvan	doc_670731433415_item	3611866	et	3	main
ma	doc_670731433415_item	3611865	et	3	main
on	doc_670731433415_item	3611864	et	4	main
see	doc_670731433415_item	3611863	et	3	main
raske	doc_670731433415_item	3611862	et	4	main
kui	doc_670731433415_item	3611861	et	3	main
tean	doc_670731433415_item	3611860	et	3	main
ma	doc_670731433415_item	3611859	et	3	main
ja	doc_670731433415_item	3611858	et	3	main
majandus	doc_670731433415_item	3611857	et	4	main
on	doc_670731433415_item	3611856	et	4	main
mis	doc_670731433415_item	3611855	et	4	main
näen	doc_670731433415_item	3611854	et	3	main
päev	doc_670731433415_item	3611853	et	3	main
iga	doc_670731433415_item	3611852	et	4	main
ma	doc_670731433415_item	3611851	et	3	main
tase	doc_670731433415_item	3611850	et	3	main
on	doc_670731433415_item	3611847	et	4	main
tal	doc_670731433415_item	3611846	et	3	main
ja	doc_670731433415_item	3611845	et	3	main
ülikoolis	doc_670731433415_item	3611844	et	4	main
lõpetasin	doc_670731433415_item	3611843	et	3	main
ma	doc_670731433415_item	3611830	et	3	main
ja	doc_670731433415_item	3611829	et	3	main
mulle	doc_670731433415_item	3611826	et	4	main
ülikoolis	doc_670731433415_item	3611814	et	4	main
sest	doc_670731433417_item	3611995	et	4	main
suhelda	doc_670731433417_item	3611994	et	4	main
on	doc_670731433417_item	3611991	et	4	main
sest	doc_670731433417_item	3611989	et	4	main
ole	doc_670731433417_item	3611983	et	4	main
kõik	doc_670731433417_item	3611967	et	4	main
ootasin	doc_670731433417_item	3611966	et	3	main
ma	doc_670731433417_item	3611965	et	3	main
nagu	doc_670731433417_item	3611964	et	3	main
mingeid	doc_670731433417_item	3611956	et	3	main
alati	doc_670731433417_item	3611944	et	4	main
ja	doc_670731433417_item	3611943	et	3	main
polnud	doc_670731433417_item	3611933	et	3	main
kuskil	doc_670731433417_item	3611931	et	3	main
sest	doc_670731433417_item	3611929	et	4	main
tulen	doc_670731433417_item	3611927	et	3	main
ei	doc_670731433417_item	3611919	et	4	main
ja	doc_670731433417_item	3611898	et	3	main
elasin	doc_670731433417_item	3611897	et	3	main
eesnimi	doc_670731433417_item	3611896	et	3	main
olen	doc_670731433417_item	3611895	et	3	main
ma	doc_670731433417_item	3611894	et	3	main
ülikool	doc_670731433417_item	3611893	et	4	main
ja	doc_670731433417_item	3611892	et	3	main
mina	doc_670731433417_item	3611891	et	4	main
essee	doc_670731433417_item	3611890	et	4	main
et	doc_670731433421_item	3612098	et	3	main
tore	doc_670731433421_item	3612095	et	3	main
on	doc_670731433421_item	3612093	et	4	main
ttü	doc_670731433421_item	3612092	et	4	main
et	doc_670731433421_item	3612091	et	3	main
arvan	doc_670731433421_item	3612090	et	3	main
ma	doc_670731433421_item	3612089	et	3	main
ja	doc_670731433421_item	3612088	et	3	main
hästi	doc_670731433421_item	3612087	et	3	main
väga	doc_670731433421_item	3612086	et	3	main
keel	doc_670731433421_item	3612085	et	4	main
ttüs	doc_670731433421_item	3612073	et	4	main
meeldib	doc_670731433421_item	3612071	et	3	main
mulle	doc_670731433421_item	3612069	et	4	main
mul	doc_670731433421_item	3612064	et	3	main
ja	doc_670731433421_item	3612062	et	3	main
ta	doc_670731433421_item	3612036	et	4	main
on	doc_670731433421_item	3612033	et	4	main
ma	doc_670731433424_item	3612223	et	3	main
pealinnas	doc_670731433424_item	3612211	et	4	main
meeldib	doc_670731433424_item	3612209	et	3	main
kui	doc_670731433424_item	3612205	et	3	main
kaupluses	doc_670731433424_item	3612199	et	3	main
ilmusid	doc_670731433424_item	3612195	et	4	main
kõik	doc_670731433424_item	3612188	et	4	main
on	doc_670731433424_item	3612185	et	4	main
ülikoolist	doc_670731433424_item	3612183	et	4	main
tehnika	doc_670731433424_item	3612182	et	4	main
töötab	doc_670731433424_item	3612159	et	3	main
sellest	doc_670731433424_item	3612143	et	4	main
inimene	doc_670731433424_item	3612142	et	3	main
sõbralik	doc_670731433424_item	3612141	et	3	main
ja	doc_670731433424_item	3612140	et	3	main
rahulik	doc_670731433424_item	3612139	et	3	main
olen	doc_670731433424_item	3612138	et	3	main
miks	doc_532115409103_item	3612379	et	4	main
keeles	doc_532115409103_item	3612362	et	4	main
lätis	doc_532115409103_item	3612359	et	4	main
pidan	doc_670731433415_item	3611838	et	4	main
ma	doc_670731433415_item	3611837	et	3	main
seal	doc_670731433415_item	3611836	et	4	main
aga	doc_670731433415_item	3611835	et	3	main
firmas	doc_670731433415_item	3611834	et	3	main
meeldib	doc_670731433415_item	3611827	et	3	main
sellepärast	doc_670731433415_item	3611825	et	3	main
tehnika	doc_670731433415_item	3611819	et	4	main
tallinna	doc_670731433415_item	3611818	et	4	main
õpin	doc_670731433415_item	3611817	et	3	main
ma	doc_670731433415_item	3611816	et	3	main
tänapäeval	doc_670731433415_item	3611815	et	3	main
lõpetamine	doc_670731433415_item	3611811	et	4	main
pärast	doc_670731433415_item	3611810	et	4	main
tahaksin	doc_670731433415_item	3611809	et	3	main
ma	doc_670731433415_item	3611808	et	3	main
koolis	doc_670731433415_item	3611807	et	4	main
kardavad	doc_670731433417_item	3611997	et	4	main
paljud	doc_670731433417_item	3611996	et	3	main
lihtsalt	doc_670731433417_item	3611993	et	4	main
eesti	doc_670731433417_item	3611985	et	4	main
selles	doc_670731433417_item	3611979	et	4	main
et	doc_670731433417_item	3611978	et	3	main
arvan	doc_670731433417_item	3611977	et	3	main
siis	doc_670731433417_item	3611976	et	3	main
öelda	doc_670731433417_item	3611975	et	4	main
ülikoolis	doc_670731433417_item	3611972	et	4	main
tavaliselt	doc_670731433417_item	3611969	et	4	main
on	doc_670731433417_item	3611968	et	4	main
sest	doc_670731433417_item	3611959	et	4	main
ttüst	doc_670731433417_item	3611958	et	4	main
muljeid	doc_670731433417_item	3611957	et	3	main
teaduskonnas	doc_670731433417_item	3611948	et	4	main
selles	doc_670731433417_item	3611947	et	4	main
tahtsin	doc_670731433417_item	3611945	et	3	main
meeldib	doc_670731433417_item	3611941	et	3	main
mulle	doc_670731433417_item	3611940	et	4	main
rühmas	doc_670731433417_item	3611939	et	4	main
majandus	doc_670731433417_item	3611936	et	4	main
just	doc_670731433417_item	3611935	et	3	main
sest	doc_670731433417_item	3611921	et	4	main
ma	doc_670731433417_item	3611918	et	3	main
mida	doc_670731433417_item	3611917	et	4	main
keelt	doc_670731433417_item	3611916	et	4	main
inglise	doc_670731433417_item	3611915	et	4	main
sooritada	doc_670731433417_item	3611914	et	3	main
vaja	doc_670731433417_item	3611913	et	4	main
oli	doc_670731433417_item	3611912	et	3	main
jaoks	doc_670731433417_item	3611911	et	4	main
selle	doc_670731433417_item	3611910	et	4	main
aga	doc_670731433417_item	3611909	et	3	main
tartus	doc_670731433417_item	3611908	et	3	main
õppida	doc_670731433417_item	3611907	et	3	main
tahtsin	doc_670731433417_item	3611906	et	3	main
üldse	doc_670731433417_item	3611905	et	3	main
gümnaasiumi	doc_670731433417_item	3611904	et	4	main
narva	doc_670731433417_item	3611903	et	4	main
lõpetanud	doc_670731433417_item	3611902	et	4	main
olen	doc_670731433417_item	3611901	et	3	main
narvas	doc_670731433417_item	3611900	et	4	main
õppisin	doc_670731433417_item	3611899	et	3	main
siin	doc_670731433421_item	3612099	et	4	main
võimalik	doc_670731433421_item	3612096	et	3	main
eesti	doc_670731433421_item	3612084	et	4	main
siin	doc_670731433421_item	3612076	et	4	main
et	doc_670731433421_item	3612075	et	3	main
sellepärast	doc_670731433421_item	3612074	et	3	main
õppida	doc_670731433421_item	3612072	et	3	main
selleks	doc_670731433421_item	3612063	et	4	main
kasvab	doc_670731433424_item	3612221	et	3	main
oskused	doc_670731433424_item	3612220	et	3	main
koolis	doc_670731433424_item	3612206	et	4	main
erinevat	doc_670731433424_item	3612196	et	4	main
uus	doc_670731433424_item	3612193	et	3	main
muljed	doc_670731433424_item	3612187	et	3	main
energeetikas	doc_670731433424_item	3612160	et	3	main
isa	doc_670731433424_item	3612158	et	4	main
sest	doc_670731433424_item	3612156	et	4	main
õppima	doc_670731433424_item	3612155	et	3	main
keel	doc_670731433421_item	3612114	et	4	main
eesti	doc_670731433421_item	3612113	et	4	main
õppida	doc_670731433421_item	3612112	et	3	main
võimalused	doc_670731433421_item	3612111	et	3	main
ootan	doc_670731433421_item	3612109	et	3	main
head	doc_670731433421_item	3612110	et	4	main
ma	doc_670731433421_item	3612108	et	3	main
loengutelt	doc_670731433421_item	3612107	et	4	main
keele	doc_670731433421_item	3612106	et	4	main
eesti	doc_670731433421_item	3612105	et	4	main
keeles	doc_670731433421_item	3612104	et	4	main
eesti	doc_670731433421_item	3612103	et	4	main
suhtlevad	doc_670731433421_item	3612102	et	4	main
inimesed	doc_670731433421_item	3612101	et	3	main
tahan	doc_670731433421_item	3612082	et	3	main
inemisi	doc_670731433421_item	3612080	et	4	main
väga	doc_670731433421_item	3612070	et	3	main
ülikool	doc_670731433421_item	3612068	et	4	main
majandus	doc_670731433421_item	3612067	et	4	main
minuga	doc_670731433421_item	3612061	et	3	main
vana	doc_670731433421_item	3612041	et	4	main
kinnisvara	doc_670731433421_item	3612039	et	4	main
ma	doc_670731433421_item	3612025	et	3	main
aastat	doc_670731433421_item	3612024	et	3	main
kaksteist	doc_670731433421_item	3612023	et	4	main
õppisin	doc_670731433421_item	3612022	et	3	main
seal	doc_670731433421_item	3612020	et	4	main
ma	doc_670731433421_item	3612021	et	3	main
gümnaasium	doc_670731433421_item	3612019	et	3	main
paekaare	doc_670731433421_item	3612018	et	3	main
lõpetasin	doc_670731433421_item	3612017	et	3	main
ma	doc_670731433421_item	3612016	et	3	main
aastal	doc_670731433421_item	3612015	et	3	main
sellel	doc_670731433421_item	3612014	et	4	main
vana	doc_670731433421_item	3612013	et	4	main
aastat	doc_670731433421_item	3612012	et	3	main
18	doc_670731433421_item	3612011	et	2	main
olen	doc_670731433421_item	3612010	et	3	main
ma	doc_670731433421_item	3612009	et	3	main
perekonnanimi	doc_670731433421_item	3612008	et	3	main
eesnimi	doc_670731433421_item	3612007	et	3	main
on	doc_670731433421_item	3612006	et	4	main
nimi	doc_670731433421_item	3612005	et	3	main
minu	doc_670731433421_item	3612004	et	3	main
ülikool	doc_670731433421_item	3612003	et	4	main
ja	doc_670731433421_item	3612002	et	3	main
mina	doc_670731433421_item	3612001	et	4	main
essee	doc_670731433421_item	3612000	et	4	main
tahab	doc_670731433421_item	3612059	et	3	main
ta	doc_670731433421_item	3612058	et	4	main
ja	doc_670731433421_item	3612057	et	3	main
finantsi	doc_670731433421_item	3612055	et	4	main
on	doc_670731433421_item	3612054	et	4	main
mees	doc_670731433421_item	3612053	et	4	main
on	doc_670731433421_item	3612066	et	4	main
väikses	doc_670731433421_item	3612038	et	4	main
töötab	doc_670731433421_item	3612037	et	3	main
raamatupidaja	doc_670731433421_item	3612034	et	4	main
ema	doc_670731433421_item	3612032	et	4	main
minu	doc_670731433421_item	3612031	et	3	main
et	doc_670731433421_item	3612030	et	3	main
sellepärast	doc_670731433421_item	3612029	et	3	main
majandust	doc_670731433421_item	3612028	et	4	main
õppima	doc_670731433421_item	3612027	et	3	main
tulen	doc_670731433421_item	3612026	et	3	main
analütik	doc_670731433421_item	3612056	et	4	main
eesti	doc_670731433424_item	3612212	et	4	main
aga	doc_670731433424_item	3612207	et	3	main
toitu	doc_670731433424_item	3612201	et	4	main
problemid	doc_670731433424_item	3612197	et	4	main
uued	doc_670731433424_item	3612191	et	3	main
tallinna	doc_670731433424_item	3612181	et	4	main
eriala	doc_670731433424_item	3612154	et	4	main
aastast	doc_670731433424_item	3612144	et	4	main
ma	doc_670731433424_item	3612134	et	3	main
lõpetasin	doc_670731433424_item	3612130	et	3	main
seal	doc_670731433424_item	3612129	et	4	main
ja	doc_670731433424_item	3612128	et	3	main
narvas	doc_670731433424_item	3612127	et	4	main
selles	doc_670731433424_item	3612131	et	4	main
sündinud	doc_670731433424_item	3612126	et	4	main
olin	doc_670731433424_item	3612125	et	3	main
ma	doc_670731433424_item	3612124	et	3	main
et	doc_670731433424_item	3612123	et	3	main
sellest	doc_670731433424_item	3612122	et	4	main
algan	doc_670731433424_item	3612121	et	3	main
ma	doc_670731433424_item	3612120	et	3	main
ülikool	doc_670731433424_item	3612119	et	4	main
ja	doc_670731433424_item	3612118	et	3	main
mina	doc_670731433424_item	3612117	et	4	main
essee	doc_670731433424_item	3612116	et	4	main
arvates	doc_532115409103_item	3612390	et	4	main
minu	doc_532115409103_item	3612389	et	3	main
diskrimineerimine	doc_532115409103_item	3612388	et	4	main
rahvuse	doc_532115409103_item	3612387	et	3	main
on	doc_532115409103_item	3612386	et	4	main
see	doc_532115409103_item	3612385	et	3	main
suhtus	doc_532115409103_item	3612384	et	3	main
rangelt	doc_532115409103_item	3612383	et	4	main
nii	doc_532115409103_item	3612382	et	3	main
sellisse	doc_532115409103_item	3612381	et	3	main
valitsus	doc_532115409103_item	3612380	et	4	main
tunne	doc_532115409103_item	3612378	et	4	main
ei	doc_532115409103_item	3612377	et	4	main
kui	doc_532115409103_item	3612360	et	3	main
juhtus	doc_532115409103_item	3612358	et	3	main
läbi	doc_532115409103_item	3612356	et	4	main
vaatame	doc_532115409103_item	3612355	et	3	main
töökohta	doc_532115409103_item	3612354	et	4	main
kui	doc_532115409103_item	3612350	et	3	main
keelt	doc_532115409103_item	3612348	et	4	main
ja	doc_532115409103_item	3612346	et	3	main
kodanikud	doc_532115409103_item	3612345	et	3	main
maa	doc_532115409103_item	3612344	et	4	main
siis	doc_532115409103_item	3612340	et	3	main
on	doc_532115409103_item	3612338	et	4	main
vene	doc_532115409103_item	3612332	et	4	main
suuev	doc_532115409103_item	3612320	et	4	main
kl	doc_532115409103_item	3612307	et	4	main
õpilased	doc_532115409103_item	3612305	et	3	main
minu	doc_670731433421_item	3612052	et	3	main
seal	doc_670731433421_item	3612051	et	4	main
meeldib	doc_670731433421_item	3612050	et	3	main
mulle	doc_670731433421_item	3612049	et	4	main
ja	doc_670731433421_item	3612048	et	3	main
tööle	doc_670731433421_item	3612047	et	3	main
emale	doc_670731433421_item	3612046	et	3	main
tulnud	doc_670731433421_item	3612045	et	4	main
olen	doc_670731433421_item	3612044	et	3	main
ma	doc_670731433421_item	3612043	et	3	main
elada	doc_670731433424_item	3612210	et	3	main
õppimine	doc_670731433424_item	3612203	et	4	main
käimine	doc_670731433424_item	3612200	et	4	main
nagu	doc_670731433424_item	3612198	et	3	main
on	doc_670731433424_item	3612189	et	4	main
erinevat	doc_670731433424_item	3612186	et	4	main
mul	doc_670731433424_item	3612184	et	3	main
oma	doc_670731433424_item	3612153	et	4	main
just	doc_670731433424_item	3612152	et	3	main
tulin	doc_670731433424_item	3612151	et	3	main
ma	doc_670731433424_item	3612150	et	3	main
ülikoolis	doc_670731433424_item	3612149	et	4	main
ma	doc_670731433424_item	3612137	et	3	main
keeles	doc_532115409103_item	3612397	et	4	main
mis	doc_532115409103_item	3612396	et	4	main
tõsine	doc_532115409103_item	3612368	et	4	main
oli	doc_532115409103_item	3612367	et	3	main
see	doc_532115409103_item	3612366	et	3	main
õpetada	doc_532115409103_item	3612365	et	3	main
koolis	doc_532115409103_item	3612364	et	4	main
hakkati	doc_532115409103_item	3612363	et	3	main
head	doc_532115409103_item	3612353	et	4	main
oma	doc_532115409103_item	3612343	et	4	main
teadmine	doc_532115409103_item	3612337	et	4	main
või	doc_532115409103_item	3612331	et	4	main
saavad	doc_532115409103_item	3612324	et	4	main
eesti	doc_670731433424_item	3612230	et	4	main
räägib	doc_670731433424_item	3612229	et	3	main
keet	doc_670731433424_item	3612231	et	3	main
kes	doc_670731433424_item	3612228	et	4	main
inimestedega	doc_670731433424_item	3612227	et	4	main
suhelda	doc_670731433424_item	3612226	et	4	main
vaba	doc_670731433424_item	3612225	et	4	main
võin	doc_670731433424_item	3612224	et	3	main
ja	doc_670731433424_item	3612222	et	3	main
keeli	doc_670731433424_item	3612219	et	4	main
minu	doc_670731433424_item	3612218	et	3	main
et	doc_670731433424_item	3612217	et	3	main
ootan	doc_670731433424_item	3612216	et	3	main
ma	doc_670731433424_item	3612215	et	3	main
tundidelt	doc_670731433424_item	3612214	et	3	main
keele	doc_670731433424_item	3612213	et	4	main
mulle	doc_670731433424_item	3612208	et	4	main
raskem	doc_670731433424_item	3612204	et	4	main
valmistamine	doc_670731433424_item	3612202	et	4	main
õppekoht	doc_670731433424_item	3612194	et	3	main
tuttavad	doc_670731433424_item	3612192	et	4	main
uus	doc_670731433424_item	3612190	et	3	main
töötan	doc_670731433424_item	3612180	et	3	main
ja	doc_670731433424_item	3612179	et	3	main
õppin	doc_670731433424_item	3612178	et	4	main
elan	doc_670731433424_item	3612177	et	3	main
ma	doc_670731433424_item	3612176	et	3	main
praegu	doc_670731433424_item	3612175	et	3	main
kus	doc_670731433424_item	3612174	et	3	main
tallinnasse	doc_670731433424_item	3612173	et	3	main
sõitsin	doc_670731433424_item	3612172	et	3	main
ma	doc_670731433424_item	3612171	et	3	main
sellepärast	doc_670731433424_item	3612170	et	3	main
palk	doc_670731433424_item	3612169	et	3	main
tema	doc_670731433424_item	3612168	et	4	main
muidugi	doc_670731433424_item	3612167	et	4	main
ja	doc_670731433424_item	3612166	et	3	main
töö	doc_670731433424_item	3612165	et	4	main
tema	doc_670731433424_item	3612164	et	4	main
meeldib	doc_670731433424_item	3612163	et	3	main
ja	doc_670731433424_item	3612161	et	3	main
mulle	doc_670731433424_item	3612162	et	4	main
minu	doc_670731433424_item	3612157	et	3	main
tehnika	doc_670731433424_item	3612148	et	4	main
et	doc_670731433424_item	3612136	et	3	main
kool	doc_670731433424_item	3612133	et	4	main
keelt	doc_532115409103_item	3612376	et	4	main
nad	doc_532115409103_item	3612375	et	3	main
kui	doc_532115409103_item	3612374	et	3	main
hakkama	doc_532115409103_item	3612373	et	3	main
keele	doc_532115409103_item	3612336	et	4	main
eesti	doc_532115409103_item	3612335	et	4	main
eesti	doc_532115409103_item	3612330	et	4	main
teised	doc_532115409103_item	3612313	et	4	main
ja	doc_532115409103_item	3612312	et	3	main
õpima	doc_532115409103_item	3612309	et	4	main
ainult	doc_532115409103_item	3612304	et	4	main
teha	doc_532115409103_item	3612301	et	3	main
on	doc_532115409103_item	3612299	et	4	main
arvates	doc_532115409103_item	3612298	et	4	main
minu	doc_532115409103_item	3612297	et	3	main
järsk	doc_532115409103_item	3612296	et	3	main
eesti	doc_532115409103_item	3612289	et	4	main
koolis	doc_532115409103_item	3612269	et	4	main
haridus	doc_532115409103_item	3612267	et	3	main
viimane	doc_532115409103_item	3612260	et	3	main
kooli	doc_532115409103_item	3612259	et	4	main
õpilased	doc_532115409103_item	3612257	et	3	main
läbi	doc_532115409103_item	3612256	et	4	main
vaatame	doc_532115409103_item	3612255	et	3	main
küljed	doc_532115409103_item	3612254	et	3	main
negatiivsed	doc_532115409103_item	3612253	et	3	main
kui	doc_532115409103_item	3612252	et	3	main
positiivsed	doc_532115409103_item	3612251	et	3	main
nii	doc_532115409103_item	3612250	et	3	main
olemas	doc_532115409103_item	3612249	et	4	main
eesti	doc_532115409103_item	3612241	et	4	main
lubati	doc_532115409103_item	3612240	et	3	main
vene	doc_532115409103_item	3612234	et	4	main
et	doc_802069853793_item	3612501	et	3	main
ei	doc_802069853793_item	3612496	et	4	main
tegeleda	doc_802069853793_item	3612494	et	3	main
järgmisel	doc_802069853793_item	3612492	et	3	main
praegu	doc_802069853793_item	3612490	et	3	main
asjaga	doc_802069853793_item	3612489	et	3	main
ma	doc_802069853793_item	3612487	et	3	main
teise	doc_802069853793_item	3612479	et	4	main
olla	doc_802069853793_item	3612475	et	3	main
teha	doc_802069853793_item	3612460	et	3	main
kui	doc_802069853793_item	3612456	et	3	main
seda	doc_802069853793_item	3612451	et	3	main
see	doc_802069853793_item	3612443	et	3	main
erialat	doc_802069853793_item	3612441	et	4	main
pärast	doc_802069853793_item	3612440	et	4	main
aastat	doc_802069853793_item	3612439	et	3	main
aega	doc_802069853793_item	3612505	et	4	main
kõik	doc_120968879150_item	3612632	et	4	main
näis	doc_120968879150_item	3612631	et	3	main
seina	doc_120968879150_item	3612623	et	4	main
istusin	doc_120968879150_item	3612622	et	3	main
peal	doc_120968879150_item	3612619	et	4	main
mäe	doc_120968879150_item	3612618	et	3	main
asub	doc_120968879150_item	3612617	et	3	main
ja	doc_120968879150_item	3612616	et	3	main
oli	doc_120968879150_item	3612611	et	3	main
hiiglane	doc_120968879150_item	3612609	et	3	main
uue	doc_120968879150_item	3612553	et	3	main
õhtul	doc_120968879152_item	3612767	et	3	main
väga	doc_120968879152_item	3612763	et	3	main
avatakse	doc_120968879152_item	3612755	et	4	main
õhtul	doc_120968879152_item	3612752	et	3	main
käisin	doc_120968879152_item	3612750	et	3	main
õhtul	doc_120968879152_item	3612748	et	3	main
linn	doc_120968879152_item	3612746	et	3	main
on	doc_120968879152_item	3612742	et	4	main
pealinn	doc_120968879152_item	3612740	et	3	main
ukraina	doc_120968879152_item	3612739	et	4	main
kasvatal	doc_120968879152_item	3612727	et	4	main
sõin	doc_120968879152_item	3612715	et	3	main
päev	doc_120968879152_item	3612713	et	3	main
kui	doc_120968879152_item	3612710	et	3	main
käisin	doc_120968879152_item	3612666	et	3	main
ma	doc_120968879152_item	3612665	et	3	main
tallinna	doc_670731433424_item	3612147	et	4	main
õpin	doc_670731433424_item	3612146	et	3	main
ma	doc_670731433424_item	3612145	et	3	main
arvan	doc_670731433424_item	3612135	et	3	main
aastas	doc_670731433424_item	3612132	et	3	main
valima	doc_532115409103_item	3612395	et	3	main
ise	doc_532115409103_item	3612394	et	4	main
peab	doc_532115409103_item	3612393	et	4	main
inimene	doc_532115409103_item	3612392	et	3	main
iga	doc_532115409103_item	3612391	et	4	main
ootama	doc_532115409103_item	3612423	et	3	main
jaame	doc_532115409103_item	3612422	et	3	main
mõistlik	doc_532115409103_item	3612421	et	3	main
on	doc_532115409103_item	3612420	et	4	main
haridus	doc_532115409103_item	3612419	et	3	main
keele	doc_532115409103_item	3612418	et	4	main
eesti	doc_532115409103_item	3612417	et	4	main
üleminek	doc_532115409103_item	3612416	et	3	main
et	doc_532115409103_item	3612415	et	3	main
loodan	doc_532115409103_item	3612414	et	3	main
lõpuks	doc_532115409103_item	3612413	et	4	main
olema	doc_532115409103_item	3612412	et	4	main
hingelt	doc_532115409103_item	3612411	et	4	main
peab	doc_532115409103_item	3612410	et	4	main
õpimine	doc_532115409103_item	3612409	et	4	main
keele	doc_532115409103_item	3612408	et	4	main
võtma	doc_532115409103_item	3612407	et	3	main
vastu	doc_532115409103_item	3612406	et	3	main
keelt	doc_532115409103_item	3612405	et	4	main
võimalust	doc_532115409103_item	3612404	et	3	main
ole	doc_532115409103_item	3612403	et	4	main
ei	doc_532115409103_item	3612402	et	4	main
üldsegi	doc_532115409103_item	3612401	et	3	main
mõnedel	doc_532115409103_item	3612400	et	3	main
sest	doc_532115409103_item	3612399	et	4	main
õpima	doc_532115409103_item	3612398	et	4	main
saavad	doc_532115409103_item	3612372	et	4	main
inimesed	doc_532115409103_item	3612371	et	3	main
kuidas	doc_532115409103_item	3612370	et	3	main
probleem	doc_532115409103_item	3612369	et	3	main
läti	doc_532115409103_item	3612361	et	4	main
mis	doc_532115409103_item	3612357	et	4	main
sada	doc_532115409103_item	3612352	et	4	main
tahame	doc_532115409103_item	3612351	et	3	main
oleme	doc_532115409103_item	3612342	et	3	main
vajalik	doc_532115409103_item	3612339	et	3	main
saada	doc_532115409103_item	3612334	et	4	main
keeles	doc_532115409103_item	3612333	et	4	main
ja	doc_532115409103_item	3612328	et	3	main
lõpetada	doc_532115409103_item	3612327	et	3	main
kõik	doc_532115409103_item	3612323	et	4	main
üleminek	doc_532115409103_item	3612321	et	3	main
siis	doc_532115409103_item	3612318	et	3	main
haridus	doc_532115409103_item	3612317	et	3	main
keeles	doc_532115409103_item	3612311	et	4	main
liiga	doc_532115409103_item	3612295	et	4	main
eksamid	doc_532115409103_item	3612262	et	3	main
seaduses	doc_532115409103_item	3612247	et	3	main
a	doc_532115409103_item	3612239	et	4	main
essee	doc_532115409103_item	3612233	et	4	main
ka	doc_802069853793_item	3612499	et	3	main
astal	doc_802069853793_item	3612493	et	4	main
või	doc_802069853793_item	3612491	et	4	main
astuda	doc_802069853793_item	3612477	et	3	main
sõjaväesse	doc_802069853793_item	3612473	et	3	main
minna	doc_802069853793_item	3612471	et	3	main
mul	doc_802069853793_item	3612468	et	3	main
seda	doc_802069853793_item	3612458	et	3	main
on	doc_802069853793_item	3612447	et	4	main
soov	doc_802069853793_item	3612446	et	3	main
minu	doc_802069853793_item	3612445	et	3	main
tõttu	doc_802069853793_item	3612444	et	4	main
õpingut	doc_802069853793_item	3612435	et	3	main
jatkada	doc_802069853793_item	3612434	et	4	main
plaanis	doc_802069853793_item	3612433	et	4	main
teadma	doc_532115409103_item	3612349	et	3	main
peame	doc_532115409103_item	3612347	et	4	main
me	doc_532115409103_item	3612341	et	4	main
tunnistuse	doc_532115409103_item	3612329	et	4	main
kooli	doc_532115409103_item	3612326	et	4	main
normaalselt	doc_532115409103_item	3612325	et	4	main
ja	doc_532115409103_item	3612322	et	3	main
jätkavad	doc_532115409103_item	3612314	et	4	main
1-4	doc_532115409103_item	3612306	et	2	main
niimoodi	doc_532115409103_item	3612302	et	3	main
õige	doc_532115409103_item	3612300	et	4	main
on	doc_532115409103_item	3612294	et	4	main
üleminek	doc_532115409103_item	3612293	et	3	main
vene	doc_532115409103_item	3612268	et	4	main
et	doc_532115409103_item	3612266	et	3	main
seadus	doc_532115409103_item	3612265	et	4	main
jõustub	doc_532115409103_item	3612264	et	3	main
on	doc_532115409103_item	3612248	et	4	main
keeleks	doc_532115409103_item	3612245	et	4	main
2007	doc_532115409103_item	3612238	et	2	main
keeles	doc_532115409103_item	3612237	et	4	main
eesti	doc_532115409103_item	3612236	et	4	main
lisada	doc_802069853793_item	3612500	et	3	main
mina	doc_802069853793_item	3612482	et	4	main
mingi	doc_802069853793_item	3612478	et	4	main
võib	doc_802069853793_item	3612474	et	3	main
või	doc_802069853793_item	3612472	et	4	main
tööle	doc_802069853793_item	3612470	et	3	main
tuleb	doc_802069853793_item	3612459	et	3	main
muutuda	doc_802069853793_item	3612454	et	3	main
plaani	doc_802069853793_item	3612452	et	4	main
jooksul	doc_802069853793_item	3612450	et	4	main
aasta	doc_802069853793_item	3612449	et	4	main
uue	doc_802069853793_item	3612448	et	3	main
saada	doc_802069853793_item	3612442	et	4	main
on	doc_802069853793_item	3612432	et	4	main
mul	doc_802069853793_item	3612431	et	3	main
aastak	doc_802069853793_item	3612430	et	3	main
järgmiseks	doc_802069853793_item	3612429	et	3	main
astasoovid	doc_802069853793_item	3612428	et	4	main
uus	doc_802069853793_item	3612427	et	3	main
minu	doc_802069853793_item	3612426	et	3	main
raha	doc_802069853793_item	3612506	et	4	main
hiid	doc_120968879150_item	3612630	et	4	main
nagu	doc_120968879150_item	3612629	et	3	main
kui	doc_120968879150_item	3612620	et	3	main
padsed	doc_120968879150_item	3612614	et	4	main
välja	doc_120968879150_item	3612607	et	4	main
oli	doc_120968879150_item	3612605	et	3	main
keskajaline	doc_120968879150_item	3612602	et	4	main
suur	doc_120968879150_item	3612601	et	3	main
väga	doc_120968879150_item	3612600	et	3	main
suures	doc_120968879150_item	3612599	et	3	main
ümbretsesid	doc_120968879150_item	3612595	et	4	main
tutvustamine	doc_120968879150_item	3612552	et	4	main
see	doc_120968879150_item	3612550	et	3	main
maitsev	doc_120968879152_item	3612764	et	4	main
melelahutusikohti	doc_120968879152_item	3612760	et	4	main
on	doc_120968879152_item	3612738	et	4	main
see	doc_120968879152_item	3612737	et	3	main
harkovis	doc_120968879152_item	3612736	et	4	main
käisin	doc_120968879152_item	3612735	et	3	main
ma	doc_120968879152_item	3612734	et	3	main
ukrainas	doc_120968879152_item	3612733	et	4	main
ja	doc_120968879152_item	3612731	et	3	main
lilleid	doc_120968879152_item	3612730	et	4	main
juurvilju	doc_120968879152_item	3612729	et	3	main
igasuguseid	doc_120968879152_item	3612728	et	3	main
kus	doc_120968879152_item	3612725	et	3	main
suur	doc_120968879152_item	3612723	et	3	main
on	doc_120968879152_item	3612722	et	4	main
juurvilju	doc_120968879152_item	3612719	et	3	main
ma	doc_120968879152_item	3612714	et	3	main
iga	doc_120968879152_item	3612712	et	4	main
kus	doc_120968879152_item	3612664	et	3	main
ma	doc_120968879152_item	3612661	et	3	main
olen	doc_120968879152_item	3612657	et	3	main
kuske	doc_873901597533_item	3612880	et	3	main
ringis	doc_873901597533_item	3612865	et	4	main
pidudes	doc_873901597533_item	3612857	et	4	main
kaupluses	doc_873901597533_item	3612850	et	3	main
tahab	doc_873901597533_item	3612841	et	3	main
tekib	doc_532115409103_item	3612319	et	3	main
keele	doc_532115409103_item	3612316	et	4	main
oma	doc_532115409103_item	3612315	et	4	main
eesti	doc_532115409103_item	3612310	et	4	main
hakkavad	doc_532115409103_item	3612308	et	4	main
et	doc_532115409103_item	3612303	et	3	main
selline	doc_532115409103_item	3612292	et	4	main
teadma	doc_532115409103_item	3612291	et	3	main
keeles	doc_532115409103_item	3612290	et	4	main
materjalid	doc_532115409103_item	3612287	et	3	main
kõik	doc_532115409103_item	3612286	et	4	main
peavad	doc_532115409103_item	3612285	et	4	main
nad	doc_532115409103_item	3612284	et	3	main
praegu	doc_532115409103_item	3612283	et	3	main
ja	doc_532115409103_item	3612282	et	3	main
emakeeles	doc_532115409103_item	3612281	et	4	main
õpisid	doc_532115409103_item	3612280	et	4	main
aastat	doc_532115409103_item	3612279	et	3	main
11	doc_532115409103_item	3612278	et	2	main
sest	doc_532115409103_item	3612277	et	4	main
paanika	doc_532115409103_item	3612276	et	4	main
on	doc_532115409103_item	3612275	et	4	main
õpilastel	doc_532115409103_item	3612274	et	4	main
keeles	doc_532115409103_item	3612273	et	4	main
eesti	doc_532115409103_item	3612272	et	4	main
olema	doc_532115409103_item	3612271	et	4	main
peab	doc_532115409103_item	3612270	et	4	main
harjumatu	doc_532115409103_item	3612288	et	4	main
klass	doc_532115409103_item	3612261	et	3	main
selles	doc_532115409103_item	3612246	et	4	main
õppe	doc_532115409103_item	3612244	et	4	main
muuda	doc_532115409103_item	3612243	et	4	main
võib	doc_802069853793_item	3612498	et	3	main
üldse	doc_802069853793_item	3612495	et	3	main
ja	doc_802069853793_item	3612481	et	3	main
õppeasutusesse	doc_802069853793_item	3612480	et	4	main
saa	doc_802069853793_item	3612466	et	4	main
mul	doc_802069853793_item	3612457	et	3	main
sest	doc_802069853793_item	3612455	et	4	main
mitte	doc_802069853793_item	3612453	et	3	main
ja	doc_120968879150_item	3612634	et	3	main
ma	doc_120968879150_item	3612621	et	3	main
kõrged	doc_120968879150_item	3612612	et	3	main
tal	doc_120968879150_item	3612610	et	3	main
nagu	doc_120968879150_item	3612608	et	3	main
ta	doc_120968879150_item	3612604	et	4	main
loss	doc_120968879150_item	3612603	et	3	main
mind	doc_120968879150_item	3612594	et	4	main
keskajase	doc_120968879150_item	3612592	et	4	main
rohkem	doc_120968879150_item	3612556	et	4	main
siis	doc_532115409103_item	3612263	et	3	main
lõpetavad	doc_532115409103_item	3612258	et	4	main
keelt	doc_532115409103_item	3612242	et	4	main
kool	doc_532115409103_item	3612235	et	4	main
taha	doc_802069853793_item	3612523	et	4	main
ei	doc_802069853793_item	3612522	et	4	main
kirjutada	doc_802069853793_item	3612521	et	3	main
sellest	doc_802069853793_item	3612520	et	4	main
ma	doc_802069853793_item	3612519	et	3	main
pärast	doc_802069853793_item	3612518	et	4	main
selle	doc_802069853793_item	3612517	et	4	main
tudendit	doc_802069853793_item	3612516	et	4	main
osa	doc_802069853793_item	3612515	et	4	main
suurem	doc_802069853793_item	3612514	et	4	main
tahab	doc_802069853793_item	3612513	et	3	main
seda	doc_802069853793_item	3612512	et	3	main
aga	doc_802069853793_item	3612511	et	3	main
ülesandeid	doc_802069853793_item	3612510	et	3	main
kodune	doc_802069853793_item	3612509	et	4	main
vähem	doc_802069853793_item	3612508	et	4	main
ja	doc_802069853793_item	3612507	et	3	main
taha	doc_802069853793_item	3612497	et	4	main
sele	doc_802069853793_item	3612488	et	4	main
et	doc_802069853793_item	3612486	et	3	main
kinde	doc_802069853793_item	3612485	et	4	main
tõesti	doc_802069853793_item	3612484	et	3	main
olen	doc_802069853793_item	3612483	et	3	main
tuleb	doc_802069853793_item	3612476	et	3	main
tuleb	doc_802069853793_item	3612469	et	3	main
siis	doc_802069853793_item	3612467	et	3	main
ei	doc_802069853793_item	3612465	et	4	main
hakkama	doc_802069853793_item	3612464	et	3	main
millega	doc_802069853793_item	3612463	et	3	main
ma	doc_802069853793_item	3612462	et	3	main
kui	doc_802069853793_item	3612461	et	3	main
mitu	doc_802069853793_item	3612438	et	4	main
ja	doc_802069853793_item	3612437	et	3	main
ülikolis	doc_802069853793_item	3612436	et	3	main
essee	doc_802069853793_item	3612425	et	4	main
vaba	doc_802069853793_item	3612504	et	4	main
rohkem	doc_802069853793_item	3612503	et	4	main
tahaks	doc_802069853793_item	3612502	et	3	main
eest	doc_120968879150_item	3612628	et	4	main
oma	doc_120968879150_item	3612627	et	4	main
tundsin	doc_120968879150_item	3612626	et	3	main
ma	doc_120968879150_item	3612625	et	3	main
seinad	doc_120968879150_item	3612615	et	3	main
hooned	doc_120968879150_item	3612597	et	4	main
väikesed	doc_120968879150_item	3612596	et	4	main
riietusi	doc_120968879150_item	3612593	et	4	main
kõige	doc_120968879150_item	3612555	et	4	main
kojust	doc_120968879150_item	3612549	et	4	main
kaugelt	doc_120968879150_item	3612548	et	4	main
nii	doc_120968879150_item	3612547	et	3	main
sõidan	doc_120968879150_item	3612546	et	3	main
ma	doc_120968879150_item	3612545	et	3	main
kui	doc_120968879150_item	3612544	et	3	main
kord	doc_120968879150_item	3612543	et	4	main
esimene	doc_120968879150_item	3612542	et	3	main
oli	doc_120968879150_item	3612541	et	3	main
see	doc_120968879150_item	3612540	et	3	main
inglismaal	doc_120968879150_item	3612539	et	4	main
käinud	doc_120968879150_item	3612538	et	4	main
olin	doc_120968879150_item	3612537	et	3	main
ma	doc_120968879150_item	3612536	et	3	main
tagasi	doc_120968879150_item	3612535	et	3	main
aastat	doc_120968879150_item	3612534	et	3	main
paar	doc_120968879150_item	3612533	et	3	main
näinud	doc_120968879150_item	3612532	et	4	main
olen	doc_120968879150_item	3612531	et	3	main
mida	doc_120968879150_item	3612530	et	4	main
ja	doc_120968879150_item	3612529	et	3	main
käinud	doc_120968879150_item	3612528	et	4	main
olen	doc_120968879150_item	3612527	et	3	main
kus	doc_120968879150_item	3612526	et	3	main
essee	doc_120968879150_item	3612525	et	4	main
unustamutu	doc_120968879150_item	3612649	et	4	main
oli	doc_120968879150_item	3612648	et	3	main
see	doc_120968879150_item	3612647	et	3	main
vaade	doc_120968879150_item	3612646	et	3	main
suurepärane	doc_120968879150_item	3612645	et	4	main
oli	doc_120968879150_item	3612644	et	3	main
seal	doc_120968879150_item	3612643	et	4	main
sipelgad	doc_120968879150_item	3612642	et	3	main
nagu	doc_120968879150_item	3612641	et	3	main
inimesed	doc_120968879150_item	3612640	et	3	main
aga	doc_120968879150_item	3612639	et	3	main
väikesed	doc_120968879150_item	3612638	et	4	main
oli	doc_120968879150_item	3612637	et	3	main
hooned	doc_120968879150_item	3612636	et	4	main
piisike	doc_120968879150_item	3612635	et	4	main
väike	doc_120968879150_item	3612633	et	4	main
peal	doc_120968879150_item	3612624	et	4	main
ja	doc_120968879150_item	3612613	et	3	main
nähtud	doc_120968879150_item	3612606	et	4	main
kesklinnas	doc_120968879150_item	3612598	et	4	main
inemesi	doc_120968879150_item	3612591	et	4	main
palju	doc_120968879150_item	3612590	et	4	main
käisid	doc_120968879150_item	3612589	et	4	main
õues	doc_120968879150_item	3612588	et	4	main
inimene	doc_120968879150_item	3612587	et	3	main
keskajane	doc_120968879150_item	3612586	et	4	main
nagu	doc_120968879150_item	3612585	et	3	main
eest	doc_120968879150_item	3612584	et	4	main
oma	doc_120968879150_item	3612583	et	4	main
tuntsin	doc_120968879150_item	3612582	et	4	main
ja	doc_120968879150_item	3612581	et	3	main
tänavatel	doc_120968879150_item	3612580	et	4	main
nõrkal	doc_120968879150_item	3612579	et	4	main
käinud	doc_120968879150_item	3612578	et	4	main
olin	doc_120968879150_item	3612577	et	3	main
ma	doc_120968879150_item	3612576	et	3	main
linnas	doc_120968879150_item	3612575	et	4	main
vana	doc_120968879150_item	3612574	et	4	main
meeldis	doc_120968879150_item	3612573	et	3	main
mulle	doc_120968879150_item	3612572	et	4	main
pealt	doc_120968879150_item	3612571	et	4	main
kõige	doc_120968879150_item	3612570	et	4	main
kõik	doc_120968879150_item	3612569	et	4	main
oska	doc_120968879150_item	3612568	et	4	main
ma	doc_120968879150_item	3612566	et	3	main
muidugi	doc_120968879150_item	3612565	et	4	main
ei	doc_120968879150_item	3612567	et	4	main
aga	doc_120968879150_item	3612564	et	3	main
vaatamisvärsusi	doc_120968879150_item	3612563	et	4	main
palju	doc_120968879150_item	3612562	et	4	main
oli	doc_120968879150_item	3612561	et	3	main
seal	doc_120968879150_item	3612560	et	4	main
edinburgis	doc_120968879150_item	3612559	et	4	main
meeldis	doc_120968879150_item	3612558	et	3	main
mulle	doc_120968879150_item	3612557	et	4	main
kultuuriga	doc_120968879150_item	3612554	et	4	main
oli	doc_120968879150_item	3612551	et	3	main
köök	doc_120968879152_item	3612765	et	3	main
seal	doc_120968879152_item	3612761	et	4	main
ärkab	doc_120968879152_item	3612754	et	3	main
igal	doc_120968879152_item	3612747	et	3	main
ilus	doc_120968879152_item	3612745	et	4	main
marju	doc_120968879152_item	3612732	et	3	main
ta	doc_120968879152_item	3612726	et	4	main
ja	doc_120968879152_item	3612718	et	3	main
meie	doc_120968879152_item	3612711	et	4	main
ilmad	doc_120968879152_item	3612694	et	3	main
head	doc_120968879152_item	3612693	et	4	main
oli	doc_120968879152_item	3612691	et	3	main
väga	doc_120968879152_item	3612692	et	3	main
seal	doc_120968879152_item	3612690	et	4	main
sugulasi	doc_120968879152_item	3612689	et	3	main
oma	doc_120968879152_item	3612688	et	4	main
külastada	doc_120968879152_item	3612687	et	3	main
sõitsin	doc_120968879152_item	3612686	et	3	main
ma	doc_120968879152_item	3612685	et	3	main
mälestussammaid	doc_120968879152_item	3612684	et	4	main
ja	doc_120968879152_item	3612683	et	3	main
kohti	doc_120968879152_item	3612682	et	4	main
huvitavaid	doc_120968879152_item	3612681	et	4	main
palju	doc_120968879152_item	3612680	et	4	main
väga	doc_120968879152_item	3612679	et	3	main
oli	doc_120968879152_item	3612678	et	3	main
seal	doc_120968879152_item	3612677	et	4	main
ukrainas	doc_120968879152_item	3612676	et	4	main
olin	doc_120968879152_item	3612675	et	3	main
ma	doc_120968879152_item	3612674	et	3	main
seal	doc_120968879152_item	3612673	et	4	main
näinud	doc_120968879152_item	3612672	et	4	main
olen	doc_120968879152_item	3612671	et	3	main
mida	doc_120968879152_item	3612670	et	4	main
ja	doc_120968879152_item	3612669	et	3	main
suvel	doc_120968879152_item	3612668	et	3	main
elmisel	doc_120968879152_item	3612667	et	4	main
minna	doc_120968879152_item	3612794	et	3	main
sinna	doc_120968879152_item	3612793	et	3	main
kord	doc_120968879152_item	3612792	et	4	main
veel	doc_120968879152_item	3612791	et	4	main
tahaksin	doc_120968879152_item	3612790	et	3	main
ma	doc_120968879152_item	3612789	et	3	main
seal	doc_120968879152_item	3612788	et	4	main
väga	doc_120968879152_item	3612786	et	3	main
meldis	doc_120968879152_item	3612787	et	3	main
mulle	doc_120968879152_item	3612785	et	4	main
rahvast	doc_120968879152_item	3612784	et	4	main
palju	doc_120968879152_item	3612783	et	4	main
väga	doc_120968879152_item	3612782	et	3	main
oli	doc_120968879152_item	3612781	et	3	main
raekoeplatsil	doc_120968879152_item	3612780	et	3	main
kontsert	doc_120968879152_item	3612779	et	3	main
ja	doc_120968879152_item	3612778	et	3	main
ilutulestik	doc_120968879152_item	3612777	et	3	main
ilus	doc_120968879152_item	3612776	et	4	main
väga	doc_120968879152_item	3612775	et	3	main
oli	doc_120968879152_item	3612774	et	3	main
seal	doc_120968879152_item	3612773	et	4	main
peol	doc_120968879152_item	3612772	et	4	main
sünnipäeva	doc_120968879152_item	3612771	et	4	main
harkovi	doc_120968879152_item	3612770	et	4	main
olin	doc_120968879152_item	3612769	et	3	main
ühel	doc_120968879152_item	3612766	et	3	main
linn	doc_120968879152_item	3612753	et	3	main
klubides	doc_120968879152_item	3612751	et	3	main
ma	doc_120968879152_item	3612749	et	3	main
ja	doc_120968879152_item	3612744	et	3	main
aed	doc_120968879152_item	3612724	et	3	main
vanaemal	doc_120968879152_item	3612721	et	3	main
minu	doc_120968879152_item	3612720	et	3	main
puuvilju	doc_120968879152_item	3612717	et	3	main
samad	doc_120968879152_item	3612709	et	3	main
on	doc_120968879152_item	3612708	et	4	main
ilmad	doc_120968879152_item	3612707	et	3	main
omast	doc_120968879152_item	3612706	et	4	main
meie	doc_120968879152_item	3612705	et	4	main
erinev	doc_120968879152_item	3612704	et	4	main
ja	doc_120968879152_item	3612703	et	3	main
ilus	doc_120968879152_item	3612702	et	4	main
väga	doc_120968879152_item	3612701	et	3	main
on	doc_120968879152_item	3612700	et	4	main
seal	doc_120968879152_item	3612699	et	4	main
loodus	doc_120968879152_item	3612698	et	4	main
ekskursionil	doc_120968879152_item	3612697	et	4	main
käisin	doc_120968879152_item	3612696	et	3	main
ma	doc_120968879152_item	3612695	et	3	main
selles	doc_120968879152_item	3612659	et	4	main
mida	doc_120968879152_item	3612656	et	4	main
käinud	doc_120968879152_item	3612654	et	4	main
me	doc_873901597533_item	3612882	et	4	main
püstitab	doc_873901597533_item	3612879	et	3	main
sõidan	doc_873901597533_item	3612859	et	3	main
jõulu	doc_873901597533_item	3612856	et	4	main
kiireneb	doc_873901597533_item	3612848	et	3	main
osta	doc_873901597533_item	3612843	et	4	main
on	doc_873901597533_item	3612837	et	4	main
mitte	doc_873901597533_item	3612827	et	3	main
kusked	doc_873901597533_item	3612823	et	4	main
tuju	doc_873901597533_item	3612811	et	4	main
session	doc_873901597534_item	3612972	et	4	main
sest	doc_873901597534_item	3612964	et	4	main
olevad	doc_873901597534_item	3612961	et	4	main
minu	doc_873901597534_item	3612959	et	3	main
aastas	doc_873901597534_item	3612958	et	3	main
on	doc_873901597534_item	3612949	et	4	main
aga	doc_873901597534_item	3612947	et	3	main
riietatud	doc_873901597534_item	3612939	et	4	main
rõmsad	doc_873901597534_item	3612929	et	4	main
on	doc_873901597534_item	3612926	et	4	main
kingitused	doc_873901597534_item	3612990	et	4	main
jõulus	doc_873901597534_item	3612989	et	3	main
selles	doc_873901597534_item	3612988	et	4	main
tulemused	doc_873901597534_item	3612987	et	3	main
head	doc_873901597534_item	3612986	et	4	main
võtta	doc_873901597534_item	3612985	et	3	main
õppida	doc_873901597534_item	3612983	et	3	main
ma	doc_120968879152_item	3612768	et	3	main
on	doc_120968879152_item	3612762	et	4	main
teisi	doc_120968879152_item	3612759	et	4	main
ja	doc_120968879152_item	3612758	et	3	main
klubid	doc_120968879152_item	3612757	et	3	main
baarid	doc_120968879152_item	3612756	et	3	main
suur	doc_120968879152_item	3612743	et	3	main
harkov	doc_120968879152_item	3612741	et	4	main
värskeid	doc_120968879152_item	3612716	et	4	main
jutustada	doc_120968879152_item	3612663	et	3	main
esses	doc_120968879152_item	3612660	et	3	main
essee	doc_120968879152_item	3612651	et	4	main
ja	doc_873901597533_item	3612881	et	3	main
on	doc_873901597533_item	3612870	et	4	main
jõulu	doc_873901597533_item	3612869	et	4	main
et	doc_873901597533_item	3612868	et	3	main
arvan	doc_873901597533_item	3612867	et	3	main
ma	doc_873901597533_item	3612866	et	3	main
jõulu	doc_873901597533_item	3612863	et	4	main
ma	doc_873901597533_item	3612853	et	3	main
suured	doc_873901597533_item	3612851	et	3	main
kuhugi	doc_873901597533_item	3612849	et	4	main
minu	doc_873901597533_item	3612824	et	3	main
kaunistavad	doc_873901597533_item	3612819	et	4	main
teised	doc_873901597533_item	3612815	et	4	main
mõned	doc_873901597533_item	3612814	et	3	main
ja	doc_873901597533_item	3612813	et	3	main
tahan	doc_120968879152_item	3612662	et	3	main
ja	doc_120968879152_item	3612655	et	3	main
olen	doc_120968879152_item	3612653	et	3	main
kus	doc_120968879152_item	3612652	et	3	main
toitu	doc_873901597533_item	3612877	et	4	main
maitsva	doc_873901597533_item	3612876	et	4	main
isa	doc_873901597533_item	3612878	et	4	main
palju	doc_873901597533_item	3612875	et	4	main
valmistab	doc_873901597533_item	3612874	et	3	main
ema	doc_873901597533_item	3612873	et	4	main
pidu	doc_873901597533_item	3612872	et	4	main
näinud	doc_120968879152_item	3612658	et	4	main
kaunistame	doc_873901597533_item	3612883	et	3	main
ma	doc_873901597533_item	3612858	et	3	main
et	doc_873901597533_item	3612855	et	3	main
kõik	doc_873901597533_item	3612847	et	4	main
ja	doc_873901597533_item	3612846	et	3	main
võtta	doc_873901597533_item	3612845	et	3	main
anna	doc_873901597533_item	3612844	et	4	main
erinevat	doc_873901597533_item	3612834	et	4	main
ka	doc_873901597533_item	3612833	et	3	main
annab	doc_873901597533_item	3612832	et	3	main
aga	doc_873901597533_item	3612831	et	3	main
tunned	doc_873901597533_item	3612830	et	3	main
püstitatud	doc_873901597533_item	3612822	et	4	main
tänavad	doc_873901597533_item	3612820	et	4	main
linnas	doc_873901597533_item	3612818	et	4	main
tunned	doc_873901597533_item	3612817	et	3	main
positiivsed	doc_873901597533_item	3612816	et	3	main
pidu	doc_873901597533_item	3612807	et	4	main
pidudeks	doc_873901597533_item	3612806	et	4	main
valmistada	doc_873901597533_item	3612805	et	3	main
algavad	doc_873901597533_item	3612804	et	4	main
inimesed	doc_873901597533_item	3612803	et	3	main
mõned	doc_873901597533_item	3612802	et	3	main
jõulupühad	doc_873901597533_item	3612801	et	3	main
on	doc_873901597533_item	3612800	et	4	main
varsti	doc_873901597533_item	3612799	et	3	main
jõulumõtted	doc_873901597533_item	3612798	et	3	main
minu	doc_873901597533_item	3612797	et	3	main
essee	doc_873901597533_item	3612796	et	4	main
eksami	doc_873901597534_item	3612971	et	3	main
jaanuari	doc_873901597534_item	3612968	et	4	main
kuni	doc_873901597534_item	3612966	et	3	main
perepidu	doc_873901597534_item	3612950	et	4	main
peod	doc_873901597534_item	3612944	et	4	main
tulevikus	doc_873901597534_item	3612942	et	4	main
kõikidel	doc_873901597534_item	3612941	et	4	main
puud	doc_873901597534_item	3612937	et	4	main
et	doc_873901597534_item	3612936	et	3	main
jatama	doc_873901597534_item	3612998	et	4	main
sest	doc_873901597534_item	3612984	et	4	main
vaja	doc_873901597534_item	3612982	et	4	main
eksameid	doc_873901597534_item	3612977	et	3	main
ilutulestikku	doc_873901597535_item	3613092	et	4	main
ja	doc_873901597535_item	3613091	et	3	main
väike	doc_873901597535_item	3613089	et	4	main
ilutulestikku	doc_873901597535_item	3613086	et	4	main
talvepidu	doc_873901597535_item	3613075	et	4	main
sõnadega	doc_873901597535_item	3613059	et	3	main
ühe	doc_873901597535_item	3613058	et	4	main
edasi	doc_873901597535_item	3613057	et	3	main
nii	doc_873901597535_item	3613056	et	3	main
ja	doc_873901597535_item	3613055	et	3	main
õppida	doc_873901597535_item	3613054	et	3	main
valmistada	doc_873901597535_item	3613053	et	3	main
ja	doc_873901597535_item	3613046	et	3	main
aga	doc_873901597535_item	3613044	et	3	main
7	doc_873901597535_item	3613042	et	2	main
ja	doc_873901597535_item	3613037	et	3	main
pidu	doc_873901597535_item	3613033	et	4	main
palju	doc_873901597533_item	3612906	et	4	main
õnne	doc_873901597533_item	3612907	et	4	main
ja	doc_873901597533_item	3612905	et	3	main
jõulu	doc_873901597533_item	3612904	et	4	main
hea	doc_873901597533_item	3612903	et	4	main
soovitame	doc_873901597533_item	3612902	et	3	main
ja	doc_873901597533_item	3612901	et	3	main
kingitused	doc_873901597533_item	3612900	et	4	main
teisele	doc_873901597533_item	3612899	et	4	main
teine	doc_873901597533_item	3612898	et	3	main
kingitame	doc_873901597533_item	3612897	et	4	main
künlad	doc_873901597533_item	3612896	et	4	main
põlestame	doc_873901597533_item	3612895	et	4	main
taga	doc_873901597533_item	3612894	et	4	main
laua	doc_873901597533_item	3612893	et	3	main
istume	doc_873901597533_item	3612892	et	3	main
koos	doc_873901597533_item	3612891	et	4	main
kõik	doc_873901597533_item	3612890	et	4	main
me	doc_873901597533_item	3612889	et	4	main
korter	doc_873901597533_item	3612888	et	3	main
meie	doc_873901597533_item	3612887	et	4	main
ja	doc_873901597533_item	3612886	et	3	main
puu	doc_873901597533_item	3612885	et	4	main
see	doc_873901597533_item	3612884	et	3	main
pere	doc_873901597533_item	3612871	et	4	main
pere	doc_873901597533_item	3612864	et	4	main
pidan	doc_873901597533_item	3612862	et	4	main
ja	doc_873901597533_item	3612861	et	3	main
kodus	doc_873901597533_item	3612860	et	4	main
arvan	doc_873901597533_item	3612854	et	3	main
järjekorrad	doc_873901597533_item	3612852	et	3	main
midagi	doc_873901597533_item	3612842	et	4	main
kes	doc_873901597533_item	3612840	et	4	main
inemesi	doc_873901597533_item	3612839	et	4	main
palju	doc_873901597533_item	3612838	et	4	main
positiivne	doc_873901597533_item	3612829	et	3	main
ja	doc_873901597533_item	3612821	et	3	main
hea	doc_873901597533_item	3612810	et	4	main
inimestele	doc_873901597533_item	3612809	et	3	main
annab	doc_873901597533_item	3612808	et	3	main
on	doc_873901597534_item	3612970	et	4	main
rasked	doc_873901597534_item	3612963	et	3	main
jõuluvaheaed	doc_873901597534_item	3612960	et	3	main
selles	doc_873901597534_item	3612957	et	4	main
minu	doc_873901597534_item	3612955	et	3	main
aga	doc_873901597534_item	3612954	et	3	main
vaikne	doc_873901597534_item	3612953	et	3	main
ja	doc_873901597534_item	3612952	et	3	main
ja	doc_873901597534_item	3612945	et	3	main
on	doc_873901597534_item	3612943	et	4	main
olid	doc_873901597534_item	3612938	et	4	main
ja	doc_873901597534_item	3612928	et	3	main
kõikidel	doc_873901597534_item	3612924	et	4	main
istuma	doc_873901597534_item	3613000	et	3	main
ja	doc_873901597534_item	3612999	et	3	main
palju	doc_873901597534_item	3612995	et	4	main
ja	doc_873901597534_item	3612994	et	3	main
õlu	doc_873901597534_item	3612993	et	3	main
salat	doc_873901597534_item	3612992	et	3	main
olevje	doc_873901597534_item	3612991	et	4	main
soritama	doc_873901597534_item	3612978	et	3	main
kõik	doc_873901597535_item	3613108	et	4	main
me	doc_873901597535_item	3613107	et	4	main
pärast	doc_873901597535_item	3613106	et	4	main
lumesõda	doc_873901597535_item	3613090	et	4	main
teen	doc_873901597535_item	3613088	et	3	main
ja	doc_873901597535_item	3613087	et	3	main
kaasas	doc_873901597535_item	3613084	et	4	main
tänavale	doc_873901597535_item	3613082	et	4	main
0000	doc_873901597535_item	3613081	et	2	main
kell	doc_873901597535_item	3613080	et	3	main
lähen	doc_873901597535_item	3613079	et	3	main
ma	doc_873901597535_item	3613078	et	3	main
uus	doc_873901597535_item	3613071	et	3	main
see	doc_873901597535_item	3613068	et	3	main
aasta	doc_873901597535_item	3613066	et	4	main
kauaoodatud	doc_873901597535_item	3613030	et	3	main
jõulupidu	doc_873901597535_item	3613026	et	4	main
minu	doc_873901597535_item	3613024	et	3	main
kreeka-katolik	doc_873901597536_item	3613199	et	4	main
järgi	doc_873901597536_item	3613194	et	4	main
kalendri	doc_873901597536_item	3613193	et	3	main
õigeusu	doc_873901597536_item	3613192	et	3	main
pidutsen	doc_873901597536_item	3613191	et	3	main
millel	doc_873901597536_item	3613169	et	3	main
koos	doc_873901597536_item	3613153	et	4	main
on	doc_873901597536_item	3613145	et	4	main
perega	doc_873901597536_item	3613143	et	3	main
mõtlen	doc_873901597540_item	3613303	et	3	main
seda	doc_873901597540_item	3613300	et	3	main
on	doc_873901597540_item	3613291	et	4	main
kõige	doc_873901597540_item	3613287	et	4	main
võibolla	doc_873901597540_item	3613286	et	4	main
eksamid	doc_873901597540_item	3613285	et	3	main
teisest	doc_873901597540_item	3613281	et	4	main
mängib	doc_873901597540_item	3613277	et	3	main
muidugi	doc_873901597540_item	3613263	et	4	main
inimesed	doc_873901597540_item	3613253	et	3	main
kõik	doc_873901597540_item	3613252	et	4	main
aasta	doc_873901597540_item	3613251	et	4	main
on	doc_873901597540_item	3613360	et	4	main
raske	doc_873901597540_item	3613355	et	4	main
meeldib	doc_873901597540_item	3613340	et	3	main
ei	doc_873901597541_item	3613455	et	4	main
kingitused	doc_873901597541_item	3613450	et	4	main
lähedale	doc_873901597541_item	3613447	et	4	main
tänavadel	doc_873901597533_item	3612836	et	4	main
probleemid	doc_873901597533_item	3612835	et	3	main
ainult	doc_873901597533_item	3612828	et	4	main
jõulu	doc_873901597533_item	3612826	et	4	main
jaoks	doc_873901597533_item	3612825	et	4	main
rõõmu	doc_873901597533_item	3612812	et	4	main
palju	doc_873901597534_item	3612976	et	4	main
kus	doc_873901597534_item	3612973	et	3	main
kahest	doc_873901597534_item	3612965	et	4	main
jõulud	doc_873901597534_item	3612948	et	3	main
jõuluvaheaed	doc_873901597534_item	3612946	et	3	main
sellepärast	doc_873901597534_item	3612935	et	3	main
ilus	doc_873901597534_item	3612934	et	4	main
väga	doc_873901597534_item	3612933	et	3	main
peolised	doc_873901597534_item	3612927	et	4	main
inimestel	doc_873901597534_item	3612925	et	3	main
nii	doc_873901597534_item	3612922	et	3	main
munu	doc_873901597534_item	3613003	et	4	main
pean	doc_873901597534_item	3612997	et	4	main
muud	doc_873901597534_item	3612996	et	4	main
on	doc_873901597534_item	3612981	et	4	main
peolaud	doc_873901597535_item	3613105	et	4	main
teha	doc_873901597535_item	3613104	et	3	main
palju	doc_873901597535_item	3613085	et	4	main
võttan	doc_873901597535_item	3613083	et	4	main
lemmik	doc_873901597535_item	3613074	et	3	main
minu	doc_873901597535_item	3613073	et	3	main
aasta	doc_873901597535_item	3613072	et	4	main
on	doc_873901597535_item	3613069	et	4	main
ja	doc_873901597535_item	3613067	et	3	main
vaja	doc_873901597535_item	3613052	et	4	main
eksamid	doc_873901597535_item	3613051	et	3	main
mul	doc_873901597535_item	3613049	et	3	main
jaanuaris	doc_873901597535_item	3613048	et	3	main
kuendal	doc_873901597535_item	3613045	et	4	main
jaanuaris	doc_873901597535_item	3613043	et	3	main
algavad	doc_873901597535_item	3613040	et	4	main
õigeusu	doc_873901597535_item	3613038	et	3	main
õigeusklik	doc_873901597535_item	3613036	et	3	main
ma	doc_873901597535_item	3613034	et	3	main
on	doc_873901597535_item	3613027	et	4	main
kuhu	doc_873901597536_item	3613202	et	3	main
tallinnas	doc_873901597536_item	3613201	et	4	main
kirik	doc_873901597536_item	3613200	et	3	main
meil	doc_873901597536_item	3613195	et	4	main
kuid	doc_873901597536_item	3613180	et	4	main
kristlased	doc_873901597536_item	3613179	et	3	main
ainult	doc_873901597536_item	3613178	et	4	main
pidutsevad	doc_873901597536_item	3613177	et	4	main
et	doc_873901597536_item	3613176	et	3	main
seda	doc_873901597536_item	3613175	et	3	main
tähendab	doc_873901597536_item	3613174	et	3	main
see	doc_873901597536_item	3613173	et	3	main
ellu	doc_873901597536_item	3613172	et	4	main
lumememme	doc_873901597536_item	3613159	et	4	main
inimestega	doc_873901597536_item	3613150	et	3	main
lähema	doc_873901597536_item	3613149	et	4	main
mõtelda	doc_873901597536_item	3613147	et	4	main
kodus	doc_873901597536_item	3613141	et	4	main
pidutsetakse	doc_873901597536_item	3613140	et	3	main
jõulud	doc_873901597536_item	3613139	et	3	main
maailma	doc_873901597536_item	3613138	et	4	main
üle	doc_873901597536_item	3613137	et	3	main
jõuludest	doc_873901597536_item	3613136	et	3	main
mõted	doc_873901597536_item	3613135	et	4	main
minu	doc_873901597536_item	3613134	et	3	main
essee	doc_873901597536_item	3613133	et	4	main
palju	doc_873901597540_item	3613308	et	4	main
tuleb	doc_873901597540_item	3613306	et	3	main
meie	doc_873901597540_item	3613292	et	4	main
minul	doc_873901597540_item	3613283	et	3	main
juba	doc_873901597540_item	3613280	et	3	main
meeldiv	doc_873901597540_item	3613269	et	4	main
jõulud	doc_873901597534_item	3613021	et	3	main
noraalne	doc_873901597534_item	3613020	et	4	main
rohkem	doc_873901597534_item	3613019	et	4	main
või	doc_873901597534_item	3613018	et	4	main
vähem	doc_873901597534_item	3613017	et	4	main
tulevikus	doc_873901597534_item	3613016	et	4	main
on	doc_873901597534_item	3613015	et	4	main
mul	doc_873901597534_item	3613014	et	3	main
et	doc_873901597534_item	3613013	et	3	main
arvasin	doc_873901597534_item	3613012	et	3	main
ikkagi	doc_873901597534_item	3613011	et	4	main
aga	doc_873901597534_item	3613010	et	3	main
viied	doc_873901597534_item	3613009	et	3	main
ja	doc_873901597534_item	3613008	et	3	main
neljad	doc_873901597534_item	3613007	et	4	main
olaks	doc_873901597534_item	3613006	et	4	main
kingitusek	doc_873901597534_item	3613005	et	4	main
suureks	doc_873901597534_item	3613004	et	4	main
pean	doc_873901597534_item	3612975	et	4	main
ma	doc_873901597534_item	3612974	et	3	main
mul	doc_873901597534_item	3612969	et	3	main
kahekümneni	doc_873901597534_item	3612967	et	4	main
väga	doc_873901597534_item	3612962	et	3	main
arvates	doc_873901597534_item	3612956	et	4	main
kodune	doc_873901597534_item	3612951	et	4	main
valgustusse	doc_873901597534_item	3612940	et	4	main
on	doc_873901597534_item	3612932	et	4	main
linnades	doc_873901597534_item	3612931	et	3	main
tunned	doc_873901597534_item	3612930	et	3	main
sest	doc_873901597534_item	3612923	et	4	main
on	doc_873901597534_item	3612921	et	4	main
see	doc_873901597534_item	3612920	et	3	main
jõulud	doc_873901597534_item	3612919	et	3	main
on	doc_873901597534_item	3612918	et	4	main
aastas	doc_873901597534_item	3612917	et	3	main
aeg	doc_873901597534_item	3612916	et	3	main
parem	doc_873901597534_item	3612915	et	4	main
et	doc_873901597534_item	3612914	et	3	main
arvan	doc_873901597534_item	3612913	et	3	main
ma	doc_873901597534_item	3612912	et	3	main
jõulumõtted	doc_873901597534_item	3612911	et	3	main
minu	doc_873901597534_item	3612910	et	3	main
essee	doc_873901597534_item	3612909	et	4	main
peale	doc_873901597534_item	3613002	et	4	main
õpikute	doc_873901597534_item	3613001	et	3	main
arvatavasti	doc_873901597534_item	3612979	et	3	main
sellel	doc_873901597535_item	3613076	et	4	main
sureparane	doc_873901597535_item	3613070	et	4	main
on	doc_873901597535_item	3613064	et	4	main
enne	doc_873901597535_item	3613062	et	4	main
igavus	doc_873901597535_item	3613060	et	4	main
seitsmendal	doc_873901597535_item	3613047	et	3	main
religioosne	doc_873901597535_item	3613032	et	3	main
väga	doc_873901597535_item	3613028	et	3	main
pühistame	doc_873901597536_item	3613207	et	4	main
ja	doc_873901597536_item	3613206	et	3	main
me	doc_873901597536_item	3613203	et	4	main
on	doc_873901597536_item	3613196	et	4	main
kreeka-katolik	doc_873901597536_item	3613189	et	4	main
mina	doc_873901597536_item	3613187	et	4	main
kristus	doc_873901597536_item	3613170	et	3	main
läheb	doc_873901597536_item	3613164	et	3	main
jõulude	doc_873901597536_item	3613162	et	3	main
tegelik	doc_873901597536_item	3613161	et	3	main
pidulik	doc_873901597536_item	3613155	et	3	main
jõulu	doc_873901597536_item	3613154	et	4	main
aga	doc_873901597540_item	3613304	et	3	main
sellest	doc_873901597540_item	3613302	et	4	main
sooritada	doc_873901597540_item	3613299	et	3	main
sest	doc_873901597540_item	3613289	et	4	main
raskemad	doc_873901597540_item	3613288	et	4	main
jaanuaris	doc_873901597540_item	3613282	et	3	main
jõulumuusika	doc_873901597540_item	3613278	et	4	main
jõulusöök	doc_873901597540_item	3613276	et	3	main
ilus	doc_873901597540_item	3613267	et	4	main
väga	doc_873901597540_item	3613266	et	3	main
on	doc_873901597540_item	3613265	et	4	main
on	doc_873901597540_item	3613368	et	4	main
nädal	doc_873901597540_item	3613362	et	3	main
on	doc_873901597540_item	3613354	et	4	main
vaheajal	doc_873901597534_item	3612980	et	3	main
ja	doc_873901597535_item	3613103	et	3	main
kaunistama	doc_873901597535_item	3613102	et	3	main
kuuske	doc_873901597535_item	3613101	et	4	main
sõpradega	doc_873901597535_item	3613100	et	3	main
koos	doc_873901597535_item	3613099	et	4	main
hakkan	doc_873901597535_item	3613098	et	3	main
ma	doc_873901597535_item	3613097	et	3	main
0000	doc_873901597535_item	3613096	et	2	main
enne	doc_873901597535_item	3613095	et	4	main
aga	doc_873901597535_item	3613094	et	3	main
aastat	doc_873901597535_item	3613131	et	3	main
uut	doc_873901597535_item	3613130	et	3	main
ja	doc_873901597535_item	3613129	et	3	main
jõulu	doc_873901597535_item	3613128	et	4	main
head	doc_873901597535_item	3613127	et	4	main
hästi	doc_873901597535_item	3613126	et	3	main
möödus	doc_873901597535_item	3613125	et	3	main
pidu	doc_873901597535_item	3613124	et	4	main
siis	doc_873901597535_item	3613123	et	3	main
peavalu	doc_873901597535_item	3613122	et	4	main
tuleb	doc_873901597535_item	3613121	et	3	main
hommikul	doc_873901597535_item	3613120	et	3	main
aga	doc_873901597535_item	3613119	et	3	main
ja	doc_873901597535_item	3613118	et	3	main
kanaal	doc_873901597535_item	3613117	et	4	main
baalti	doc_873901597535_item	3613116	et	4	main
esimene	doc_873901597535_item	3613115	et	3	main
telerit	doc_873901597535_item	3613114	et	3	main
sisse	doc_873901597535_item	3613113	et	4	main
lületame	doc_873901597535_item	3613112	et	4	main
ja	doc_873901597535_item	3613111	et	3	main
peolautaga	doc_873901597535_item	3613110	et	4	main
istume	doc_873901597535_item	3613109	et	3	main
sõda	doc_873901597535_item	3613093	et	4	main
peol	doc_873901597535_item	3613077	et	4	main
uus	doc_873901597535_item	3613065	et	3	main
jõulu	doc_873901597535_item	3613063	et	4	main
aga	doc_873901597535_item	3613061	et	3	main
on	doc_873901597535_item	3613050	et	4	main
6	doc_873901597535_item	3613041	et	2	main
jõulupühad	doc_873901597535_item	3613039	et	3	main
olen	doc_873901597535_item	3613035	et	3	main
ja	doc_873901597535_item	3613031	et	3	main
mis	doc_873901597536_item	3613209	et	4	main
korvidega	doc_873901597536_item	3613205	et	3	main
käime	doc_873901597536_item	3613204	et	4	main
oma	doc_873901597536_item	3613197	et	4	main
erinevad	doc_873901597536_item	3613181	et	4	main
ärkas	doc_873901597536_item	3613171	et	3	main
on	doc_873901597536_item	3613167	et	4	main
reliigasse	doc_873901597536_item	3613165	et	4	main
tähendus	doc_873901597536_item	3613163	et	4	main
ehitamine	doc_873901597536_item	3613160	et	4	main
teha	doc_873901597536_item	3613151	et	3	main
aeg	doc_873901597536_item	3613146	et	3	main
see	doc_873901597536_item	3613144	et	3	main
oma	doc_873901597536_item	3613142	et	4	main
huvitav	doc_873901597535_item	3613029	et	4	main
jõulumõtted	doc_873901597535_item	3613025	et	3	main
essee	doc_873901597535_item	3613023	et	4	main
tehtud	doc_873901597536_item	3613214	et	4	main
kättega	doc_873901597536_item	3613213	et	4	main
oma	doc_873901597536_item	3613212	et	4	main
kodus	doc_873901597536_item	3613211	et	4	main
on	doc_873901597536_item	3613210	et	4	main
läheda	doc_873901597536_item	3613240	et	3	main
inimestega	doc_873901597536_item	3613241	et	3	main
ja	doc_873901597536_item	3613239	et	3	main
huvitava	doc_873901597536_item	3613238	et	4	main
koosolemist	doc_873901597536_item	3613237	et	4	main
mõnitlen	doc_873901597536_item	3613236	et	4	main
ainult	doc_873901597536_item	3613235	et	4	main
ma	doc_873901597536_item	3613234	et	3	main
ajal	doc_873901597536_item	3613233	et	4	main
jõulude	doc_873901597536_item	3613232	et	3	main
eesmärke	doc_873901597536_item	3613231	et	4	main
pane	doc_873901597536_item	3613230	et	4	main
ei	doc_873901597536_item	3613229	et	4	main
mina	doc_873901597536_item	3613228	et	4	main
tegelikult	doc_873901597536_item	3613227	et	4	main
energeetika	doc_873901597536_item	3613226	et	4	main
positivne	doc_873901597536_item	3613225	et	4	main
ja	doc_873901597536_item	3613224	et	3	main
tuju	doc_873901597536_item	3613223	et	4	main
hea	doc_873901597536_item	3613222	et	4	main
on	doc_873901597536_item	3613221	et	4	main
kõigil	doc_873901597536_item	3613220	et	4	main
jumalast	doc_873901597536_item	3613219	et	4	main
räägime	doc_873901597536_item	3613218	et	3	main
laulud	doc_873901597536_item	3613217	et	3	main
jõulu	doc_873901597536_item	3613216	et	4	main
laulame	doc_873901597536_item	3613215	et	4	main
toitu	doc_873901597536_item	3613208	et	4	main
ukraina	doc_873901597536_item	3613198	et	4	main
ja	doc_873901597536_item	3613190	et	3	main
olen	doc_873901597536_item	3613188	et	3	main
ajal	doc_873901597536_item	3613186	et	4	main
erineval	doc_873901597536_item	3613185	et	4	main
seda	doc_873901597536_item	3613184	et	3	main
teevad	doc_873901597536_item	3613183	et	3	main
kristlased	doc_873901597536_item	3613182	et	3	main
aeg	doc_873901597536_item	3613168	et	3	main
see	doc_873901597536_item	3613166	et	3	main
metsas	doc_873901597536_item	3613158	et	3	main
suusatamine	doc_873901597536_item	3613157	et	4	main
õhtusöök	doc_873901597536_item	3613156	et	3	main
midagi	doc_873901597536_item	3613152	et	4	main
suhtedest	doc_873901597536_item	3613148	et	4	main
väga	doc_873901597540_item	3613307	et	3	main
ootan	doc_873901597540_item	3613301	et	3	main
edukalt	doc_873901597540_item	3613298	et	4	main
need	doc_873901597540_item	3613290	et	3	main
pidu	doc_873901597540_item	3613270	et	4	main
jõulu	doc_873901597540_item	3613264	et	4	main
väsinud	doc_873901597540_item	3613255	et	4	main
ja	doc_873901597540_item	3613378	et	3	main
väga	doc_873901597540_item	3613376	et	3	main
seda	doc_873901597540_item	3613373	et	3	main
kavatsen	doc_873901597540_item	3613372	et	3	main
ja	doc_873901597540_item	3613371	et	3	main
kallis	doc_873901597540_item	3613370	et	4	main
väga	doc_873901597540_item	3613369	et	3	main
aga	doc_873901597540_item	3613363	et	3	main
peost	doc_873901597540_item	3613357	et	4	main
pidu	doc_873901597541_item	3613459	et	4	main
arvates	doc_873901597541_item	3613453	et	4	main
inimestele	doc_873901597541_item	3613448	et	3	main
oma	doc_873901597541_item	3613446	et	4	main
mina	doc_873901597541_item	3613443	et	4	main
muidugi	doc_873901597541_item	3613442	et	4	main
külla	doc_873901597541_item	3613410	et	4	main
juurde	doc_873901597541_item	3613409	et	4	main
vanaemale	doc_873901597541_item	3613408	et	3	main
sõita	doc_873901597541_item	3613407	et	3	main
võib-olla	doc_873901597541_item	3613406	et	3	main
ja	doc_873901597541_item	3613405	et	3	main
elamutest	doc_873901597541_item	3613404	et	4	main
mina	doc_873901597541_item	3613397	et	4	main
seda	doc_873901597541_item	3613395	et	3	main
toredad	doc_873901597545_item	3613628	et	3	main
et	doc_873901597545_item	3613623	et	3	main
mis	doc_873901597545_item	3613608	et	4	main
saunasse	doc_873901597545_item	3613607	et	3	main
millal	doc_873901597545_item	3613592	et	3	main
ootavad	doc_873901597545_item	3613584	et	4	main
lapsed	doc_873901597545_item	3613583	et	3	main
otsivad	doc_873901597545_item	3613581	et	4	main
on	doc_873901597545_item	3613575	et	4	main
igaühel	doc_873901597545_item	3613574	et	3	main
pidu	doc_873901597545_item	3613554	et	4	main
minu	doc_873901597545_item	3613550	et	3	main
kõik	doc_873901597545_item	3613545	et	4	main
järgmisel	doc_873901597545_item	3613543	et	3	main
loodan	doc_873901597545_item	3613541	et	3	main
koostada	doc_873901597545_item	3613538	et	3	main
mulle	doc_873901597545_item	3613535	et	4	main
lemmik	doc_873901597545_item	3613501	et	3	main
öelda	doc_873901597545_item	3613496	et	4	main
essee	doc_873901597545_item	3613490	et	4	main
töötades	doc_286998102732_item	3613775	et	3	main
koduses	doc_286998102732_item	3613773	et	4	main
et	doc_286998102732_item	3613767	et	3	main
on	doc_286998102732_item	3613762	et	4	main
asju	doc_286998102732_item	3613755	et	3	main
alati	doc_286998102732_item	3613753	et	4	main
tahab	doc_286998102732_item	3613752	et	3	main
moodi	doc_286998102732_item	3613743	et	4	main
ma	doc_286998102732_item	3613729	et	3	main
ja	doc_286998102732_item	3613728	et	3	main
mulle	doc_286998102732_item	3613727	et	4	main
sobib	doc_286998102732_item	3613726	et	3	main
on	doc_286998102732_item	3613716	et	4	main
kui	doc_286998102732_item	3613715	et	3	main
hea	doc_286998102732_item	3613714	et	4	main
mul	doc_873901597540_item	3613305	et	3	main
neid	doc_873901597540_item	3613297	et	4	main
kavatsen	doc_873901597540_item	3613296	et	3	main
muidugi	doc_873901597540_item	3613295	et	4	main
ülikoolieksamid	doc_873901597540_item	3613294	et	3	main
esimesed	doc_873901597540_item	3613293	et	3	main
on	doc_873901597540_item	3613284	et	4	main
aga	doc_873901597540_item	3613279	et	3	main
on	doc_873901597540_item	3613275	et	4	main
peal	doc_873901597540_item	3613274	et	4	main
laua	doc_873901597540_item	3613273	et	3	main
pereringil	doc_873901597540_item	3613272	et	3	main
istutakse	doc_873901597540_item	3613271	et	3	main
kui	doc_873901597540_item	3613261	et	3	main
väsinud	doc_873901597540_item	3613260	et	4	main
mina	doc_873901597540_item	3613257	et	4	main
aga	doc_873901597540_item	3613256	et	3	main
uus	doc_873901597540_item	3613250	et	3	main
ja	doc_873901597540_item	3613249	et	3	main
joulu	doc_873901597540_item	3613248	et	4	main
on	doc_873901597540_item	3613247	et	4	main
varsti	doc_873901597540_item	3613246	et	3	main
jõulumõtted	doc_873901597540_item	3613245	et	3	main
minu	doc_873901597540_item	3613244	et	3	main
essee	doc_873901597540_item	3613243	et	4	main
kasulikult	doc_873901597540_item	3613379	et	4	main
lõbusalt	doc_873901597540_item	3613377	et	4	main
läbi	doc_873901597540_item	3613375	et	4	main
viia	doc_873901597540_item	3613374	et	3	main
muidugi	doc_873901597540_item	3613364	et	4	main
raske	doc_873901597540_item	3613361	et	4	main
praegu	doc_873901597540_item	3613359	et	3	main
sest	doc_873901597540_item	3613358	et	4	main
praegu	doc_873901597540_item	3613353	et	3	main
jõulumõtted	doc_873901597540_item	3613352	et	3	main
minu	doc_873901597540_item	3613351	et	3	main
on	doc_873901597540_item	3613350	et	4	main
need	doc_873901597540_item	3613349	et	3	main
piduöö	doc_873901597540_item	3613348	et	4	main
lumi	doc_873901597540_item	3613347	et	3	main
pidulaud	doc_873901597540_item	3613346	et	4	main
muusika	doc_873901597540_item	3613345	et	4	main
laulud	doc_873901597540_item	3613343	et	3	main
ja	doc_873901597540_item	3613268	et	3	main
teised	doc_873901597540_item	3613262	et	4	main
rohkem	doc_873901597540_item	3613259	et	4	main
muidugi	doc_873901597540_item	3613258	et	4	main
on	doc_873901597540_item	3613254	et	4	main
jaoks	doc_873901597540_item	3613367	et	4	main
minu	doc_873901597540_item	3613366	et	3	main
jõulupuhkus	doc_873901597540_item	3613365	et	3	main
mõttelda	doc_873901597540_item	3613356	et	4	main
naeratused	doc_873901597540_item	3613344	et	4	main
mulle	doc_873901597540_item	3613341	et	4	main
pidu	doc_873901597540_item	3613339	et	4	main
uus	doc_873901597541_item	3613461	et	3	main
nagu	doc_873901597541_item	3613460	et	3	main
jõulu	doc_873901597541_item	3613454	et	4	main
väikesed	doc_873901597541_item	3613449	et	4	main
teine-teisele	doc_873901597541_item	3613440	et	4	main
kahjuks	doc_873901597541_item	3613411	et	4	main
ka	doc_873901597541_item	3613398	et	3	main
kui	doc_873901597545_item	3613629	et	3	main
tüdrukuid	doc_873901597545_item	3613614	et	4	main
tavaliselt	doc_873901597545_item	3613598	et	4	main
unustad	doc_873901597545_item	3613593	et	3	main
on	doc_873901597545_item	3613589	et	4	main
kingitus	doc_873901597545_item	3613587	et	4	main
tuju	doc_873901597545_item	3613577	et	4	main
on	doc_873901597545_item	3613565	et	4	main
jõulud	doc_873901597545_item	3613564	et	3	main
just	doc_873901597545_item	3613563	et	3	main
detsember	doc_873901597545_item	3613562	et	3	main
24	doc_873901597545_item	3613561	et	2	main
ja	doc_873901597545_item	3613560	et	3	main
tahan	doc_873901597545_item	3613555	et	3	main
jaoks	doc_873901597545_item	3613551	et	4	main
saab	doc_873901597545_item	3613546	et	3	main
tulevikuplaane	doc_873901597545_item	3613539	et	3	main
meeldib	doc_873901597545_item	3613536	et	3	main
ei	doc_286998102732_item	3613764	et	4	main
et	doc_286998102732_item	3613759	et	3	main
kes	doc_286998102732_item	3613751	et	4	main
ole	doc_286998102732_item	3613748	et	4	main
sobib	doc_286998102732_item	3613741	et	3	main
nii	doc_286998102732_item	3613739	et	3	main
ka	doc_286998102732_item	3613725	et	3	main
külalised	doc_286998102732_item	3613721	et	4	main
kui	doc_286998102732_item	3613720	et	3	main
näiteks	doc_286998102732_item	3613719	et	4	main
korrusel	doc_286998102732_item	3613698	et	3	main
vastu	doc_286998102732_item	3613696	et	3	main
ja	doc_286998102732_item	3613693	et	3	main
kodus	doc_286998102732_item	3613643	et	4	main
ei	doc_286998102732_item	3613636	et	4	main
tulevikukodu	doc_286998102732_item	3613633	et	4	main
essee	doc_286998102732_item	3613632	et	4	main
rohkem	doc_873901597540_item	3613342	et	4	main
see	doc_873901597540_item	3613338	et	3	main
sest	doc_873901597540_item	3613337	et	4	main
aastast	doc_873901597540_item	3613336	et	4	main
uuest	doc_873901597540_item	3613335	et	3	main
on	doc_873901597540_item	3613334	et	4	main
minul	doc_873901597540_item	3613333	et	3	main
jõulumõtted	doc_873901597540_item	3613332	et	3	main
kuu	doc_873901597540_item	3613331	et	4	main
raske	doc_873901597540_item	3613330	et	4	main
tuleb	doc_873901597540_item	3613329	et	3	main
pärast	doc_873901597540_item	3613328	et	4	main
mille	doc_873901597540_item	3613327	et	3	main
puhkus	doc_873901597540_item	3613326	et	3	main
väike	doc_873901597540_item	3613325	et	4	main
nagu	doc_873901597540_item	3613324	et	3	main
jaoks	doc_873901597540_item	3613323	et	4	main
minu	doc_873901597540_item	3613322	et	3	main
on	doc_873901597540_item	3613321	et	4	main
jõulunädal	doc_873901597540_item	3613320	et	3	main
kiiresti	doc_873901597540_item	3613319	et	3	main
väga	doc_873901597540_item	3613318	et	3	main
tuleb	doc_873901597540_item	3613317	et	3	main
aeg	doc_873901597540_item	3613316	et	3	main
see	doc_873901597540_item	3613315	et	3	main
et	doc_873901597540_item	3613314	et	3	main
arvan	doc_873901597540_item	3613313	et	3	main
mina	doc_873901597540_item	3613312	et	4	main
sellepärast	doc_873901597540_item	3613311	et	3	main
teha	doc_873901597540_item	3613310	et	3	main
veel	doc_873901597540_item	3613309	et	4	main
kuna	doc_873901597541_item	3613451	et	3	main
kingitusele	doc_873901597541_item	3613441	et	4	main
kodus	doc_873901597541_item	3613403	et	4	main
inimesed	doc_873901597541_item	3613393	et	3	main
paljud	doc_873901597541_item	3613392	et	3	main
tean	doc_873901597541_item	3613390	et	3	main
on	doc_873901597545_item	3613626	et	4	main
loodan	doc_873901597545_item	3613622	et	3	main
on	doc_873901597545_item	3613619	et	4	main
hakkame	doc_873901597545_item	3613616	et	3	main
ja	doc_873901597545_item	3613615	et	3	main
kutsume	doc_873901597545_item	3613613	et	3	main
majas	doc_873901597545_item	3613612	et	3	main
sõbra	doc_873901597545_item	3613611	et	3	main
mu	doc_873901597545_item	3613610	et	3	main
on	doc_873901597545_item	3613609	et	4	main
istumist	doc_873901597545_item	3613597	et	4	main
perega	doc_873901597545_item	3613596	et	3	main
aeg	doc_873901597545_item	3613591	et	3	main
sellel	doc_873901597545_item	3613578	et	4	main
rõmsad	doc_873901597545_item	3613573	et	4	main
täituksid	doc_873901597541_item	3613488	et	4	main
soovid	doc_873901597541_item	3613487	et	4	main
minu	doc_873901597541_item	3613486	et	3	main
et	doc_873901597541_item	3613485	et	3	main
loodan	doc_873901597541_item	3613484	et	3	main
ma	doc_873901597541_item	3613483	et	3	main
haiged	doc_873901597541_item	3613482	et	3	main
ole	doc_873901597541_item	3613481	et	4	main
ei	doc_873901597541_item	3613480	et	4	main
sugulased	doc_873901597541_item	3613479	et	3	main
minu	doc_873901597541_item	3613478	et	3	main
et	doc_873901597541_item	3613477	et	3	main
või	doc_873901597541_item	3613476	et	4	main
maailmas	doc_873901597541_item	3613475	et	3	main
kogu	doc_873901597541_item	3613474	et	4	main
rahu	doc_873901597541_item	3613473	et	4	main
näiteks	doc_873901597541_item	3613472	et	4	main
võimatu	doc_873901597541_item	3613471	et	4	main
on	doc_873901597541_item	3613470	et	4	main
nad	doc_873901597541_item	3613469	et	3	main
aga	doc_873901597541_item	3613468	et	3	main
soovid	doc_873901597541_item	3613467	et	4	main
teised	doc_873901597541_item	3613466	et	4	main
ka	doc_873901597541_item	3613465	et	3	main
on	doc_873901597541_item	3613464	et	4	main
mul	doc_873901597541_item	3613463	et	3	main
aasta	doc_873901597541_item	3613462	et	4	main
tähtis	doc_873901597541_item	3613458	et	4	main
nii	doc_873901597541_item	3613457	et	3	main
ole	doc_873901597541_item	3613456	et	4	main
minu	doc_873901597541_item	3613452	et	3	main
ka	doc_873901597541_item	3613444	et	3	main
inimesed	doc_873901597541_item	3613438	et	3	main
kuidas	doc_873901597541_item	3613437	et	3	main
ka	doc_873901597541_item	3613436	et	3	main
tore	doc_873901597541_item	3613435	et	3	main
on	doc_873901597541_item	3613434	et	4	main
inimesed	doc_873901597541_item	3613432	et	3	main
rõõmustavad	doc_873901597541_item	3613433	et	4	main
teised	doc_873901597541_item	3613431	et	4	main
kuidas	doc_873901597541_item	3613430	et	3	main
meeldib	doc_873901597541_item	3613429	et	3	main
mulle	doc_873901597541_item	3613428	et	4	main
aga	doc_873901597541_item	3613427	et	3	main
päevast	doc_873901597541_item	3613426	et	4	main
sellest	doc_873901597541_item	3613425	et	4	main
midagi	doc_873901597541_item	3613424	et	4	main
mitte	doc_873901597541_item	3613423	et	3	main
oota	doc_873901597541_item	3613422	et	4	main
ei	doc_873901597541_item	3613421	et	4	main
ja	doc_873901597541_item	3613420	et	3	main
jõulu	doc_873901597541_item	3613419	et	4	main
veel	doc_873901597541_item	3613418	et	4	main
tunne	doc_873901597541_item	3613417	et	4	main
ei	doc_873901597541_item	3613416	et	4	main
ma	doc_873901597541_item	3613415	et	3	main
õnneks	doc_873901597541_item	3613414	et	4	main
võib-olla	doc_873901597541_item	3613413	et	3	main
aga	doc_873901597541_item	3613412	et	3	main
teen	doc_873901597541_item	3613445	et	3	main
teevad	doc_873901597541_item	3613439	et	3	main
ootavad	doc_873901597541_item	3613394	et	4	main
et	doc_873901597541_item	3613391	et	3	main
ja	doc_873901597541_item	3613388	et	3	main
aega	doc_873901597541_item	3613387	et	4	main
vähe	doc_873901597541_item	3613386	et	3	main
jääd	doc_873901597541_item	3613385	et	4	main
jõuluni	doc_873901597541_item	3613384	et	3	main
jõulumõted	doc_873901597541_item	3613383	et	4	main
minu	doc_873901597541_item	3613382	et	3	main
essee	doc_873901597541_item	3613381	et	4	main
eelmised	doc_873901597545_item	3613630	et	3	main
jõulud	doc_873901597545_item	3613625	et	3	main
lähme	doc_873901597545_item	3613606	et	3	main
ja	doc_873901597545_item	3613605	et	3	main
õllesid	doc_873901597545_item	3613604	et	3	main
palju-palju	doc_873901597545_item	3613603	et	4	main
ostame	doc_873901597545_item	3613602	et	3	main
sõpradega	doc_873901597545_item	3613601	et	3	main
probleemidest	doc_873901597545_item	3613594	et	3	main
see	doc_873901597545_item	3613590	et	3	main
jõulud	doc_873901597545_item	3613588	et	3	main
ja	doc_873901597545_item	3613586	et	3	main
hea	doc_873901597545_item	3613576	et	4	main
on	doc_873901597545_item	3613572	et	4	main
saaks	doc_873901597545_item	3613558	et	3	main
et	doc_873901597545_item	3613556	et	3	main
on	doc_873901597545_item	3613552	et	4	main
veel	doc_873901597545_item	3613547	et	4	main
et	doc_873901597545_item	3613542	et	3	main
jõuluööl	doc_873901597545_item	3613540	et	3	main
jõuludest	doc_873901597545_item	3613508	et	3	main
kirjutan	doc_873901597545_item	3613506	et	3	main
küll	doc_873901597545_item	3613505	et	4	main
meeldib	doc_873901597545_item	3613504	et	3	main
aga	doc_873901597545_item	3613503	et	3	main
on	doc_873901597545_item	3613499	et	4	main
kui	doc_286998102732_item	3613768	et	3	main
missugune	doc_286998102732_item	3613760	et	3	main
erilisi	doc_286998102732_item	3613754	et	4	main
inimest	doc_286998102732_item	3613750	et	3	main
niisugust	doc_286998102732_item	3613749	et	3	main
tavaline	doc_286998102732_item	3613742	et	4	main
lülitada	doc_286998102732_item	3613738	et	3	main
lambi	doc_286998102732_item	3613736	et	4	main
vessu	doc_286998102732_item	3613724	et	4	main
aga	doc_286998102732_item	3613699	et	3	main
teisel	doc_286998102732_item	3613697	et	4	main
puhata	doc_873901597541_item	3613402	et	4	main
tahan	doc_873901597541_item	3613401	et	3	main
kuna	doc_873901597541_item	3613400	et	3	main
ootan	doc_873901597541_item	3613399	et	3	main
pidu	doc_873901597541_item	3613396	et	4	main
ma	doc_873901597541_item	3613389	et	3	main
sama	doc_873901597545_item	3613627	et	4	main
järgmised	doc_873901597545_item	3613624	et	3	main
jõulud	doc_873901597545_item	3613621	et	3	main
tõelised	doc_873901597545_item	3613620	et	4	main
need	doc_873901597545_item	3613618	et	3	main
pidutsema	doc_873901597545_item	3613617	et	3	main
kohtume	doc_873901597545_item	3613600	et	3	main
me	doc_873901597545_item	3613599	et	4	main
pärast	doc_873901597545_item	3613595	et	4	main
jõuluvana	doc_873901597545_item	3613585	et	4	main
jõulupuud	doc_873901597545_item	3613582	et	4	main
vanemad	doc_873901597545_item	3613580	et	4	main
päeval	doc_873901597545_item	3613579	et	3	main
inimesed	doc_873901597545_item	3613571	et	3	main
kõik	doc_873901597545_item	3613570	et	4	main
23	doc_873901597545_item	3613559	et	2	main
kiiresti	doc_873901597545_item	3613557	et	3	main
optimistlik	doc_873901597545_item	3613553	et	3	main
jõulud	doc_873901597545_item	3613549	et	3	main
ütlen	doc_873901597545_item	3613530	et	3	main
lõpuks	doc_873901597545_item	3613529	et	4	main
ja	doc_873901597545_item	3613528	et	3	main
aastal	doc_873901597545_item	3613527	et	3	main
sellel	doc_873901597545_item	3613526	et	4	main
teinud	doc_873901597545_item	3613525	et	4	main
olen	doc_873901597545_item	3613524	et	3	main
halba	doc_873901597545_item	3613523	et	4	main
ja	doc_873901597545_item	3613522	et	3	main
head	doc_873901597545_item	3613521	et	4	main
mida	doc_873901597545_item	3613520	et	4	main
sellest	doc_873901597545_item	3613519	et	4	main
mõtlema	doc_873901597545_item	3613518	et	3	main
ma	doc_873901597545_item	3613517	et	3	main
hakkan	doc_873901597545_item	3613516	et	3	main
tavaliselt	doc_873901597545_item	3613515	et	4	main
jõuluõhtul	doc_873901597545_item	3613514	et	3	main
eestis	doc_873901597545_item	3613513	et	3	main
populaarsem	doc_873901597545_item	3613512	et	4	main
on	doc_873901597545_item	3613511	et	4	main
see	doc_873901597545_item	3613510	et	3	main
sest	doc_873901597545_item	3613509	et	4	main
talvel	doc_873901597545_item	3613569	et	4	main
pidu	doc_873901597545_item	3613568	et	4	main
suur	doc_873901597545_item	3613567	et	3	main
esimene	doc_873901597545_item	3613566	et	3	main
paremaks	doc_873901597545_item	3613548	et	4	main
aastal	doc_873901597545_item	3613544	et	3	main
ka	doc_873901597545_item	3613537	et	3	main
paremaks	doc_873901597545_item	3613534	et	4	main
muutun	doc_873901597545_item	3613533	et	3	main
et	doc_873901597545_item	3613532	et	3	main
endale	doc_873901597545_item	3613531	et	4	main
pidu	doc_873901597545_item	3613502	et	4	main
et	doc_873901597545_item	3613497	et	3	main
oska	doc_873901597545_item	3613495	et	4	main
ei	doc_873901597545_item	3613494	et	4	main
ma	doc_873901597545_item	3613493	et	3	main
jõulumõtted	doc_873901597545_item	3613492	et	3	main
minu	doc_873901597545_item	3613491	et	3	main
katoliiklikust	doc_873901597545_item	3613507	et	4	main
minu	doc_873901597545_item	3613500	et	3	main
jõulud	doc_873901597545_item	3613498	et	3	main
tööd	doc_286998102732_item	3613774	et	4	main
mind	doc_286998102732_item	3613772	et	4	main
aitas	doc_286998102732_item	3613771	et	3	main
masina	doc_286998102732_item	3613770	et	3	main
palju	doc_286998102732_item	3613769	et	4	main
sellest	doc_286998102732_item	3613766	et	4	main
sõltu	doc_286998102732_item	3613765	et	4	main
see	doc_286998102732_item	3613763	et	3	main
see	doc_286998102732_item	3613758	et	3	main
arvan	doc_286998102732_item	3613756	et	3	main
seegi	doc_286998102732_item	3613740	et	4	main
välja	doc_286998102732_item	3613737	et	4	main
tahan	doc_286998102732_item	3613735	et	3	main
kui	doc_286998102732_item	3613734	et	3	main
minna	doc_286998102732_item	3613733	et	3	main
juurde	doc_286998102732_item	3613732	et	4	main
tavaline	doc_286998102732_item	3613723	et	4	main
tulevad	doc_286998102732_item	3613722	et	4	main
ei	doc_286998102732_item	3613708	et	4	main
masinasid	doc_286998102732_item	3613707	et	4	main
ma	doc_286998102732_item	3613703	et	3	main
magamistoad	doc_286998102732_item	3613700	et	3	main
külalisi	doc_286998102732_item	3613695	et	4	main
võtame	doc_286998102732_item	3613694	et	3	main
mulle	doc_286998102732_item	3613674	et	4	main
et	doc_286998102732_item	3613649	et	3	main
tahan	doc_286998102732_item	3613640	et	3	main
oma	doc_286998102733_item	3613899	et	4	main
võimalust	doc_286998102733_item	3613898	et	3	main
sai	doc_286998102733_item	3613896	et	4	main
norra	doc_286998102733_item	3613891	et	4	main
ja	doc_286998102733_item	3613886	et	3	main
oslos	doc_286998102733_item	3613884	et	4	main
näitust	doc_286998102733_item	3613882	et	4	main
korraldas	doc_286998102733_item	3613881	et	3	main
ta	doc_286998102733_item	3613880	et	4	main
kõvasti	doc_286998102733_item	3613879	et	3	main
ja	doc_286998102733_item	3613874	et	3	main
teda	doc_286998102733_item	3613873	et	4	main
pariisis	doc_286998102733_item	3613869	et	4	main
ta	doc_286998102733_item	3613859	et	4	main
minna	doc_286998102733_item	3613858	et	3	main
pariisi	doc_286998102733_item	3613857	et	4	main
stipendiumiga	doc_286998102733_item	3613856	et	3	main
temale	doc_286998102733_item	3613855	et	3	main
ta	doc_286998102733_item	3613844	et	4	main
aga	doc_286998102733_item	3613843	et	3	main
seda	doc_286998102733_item	3613842	et	3	main
pärast	doc_286998102733_item	3613841	et	4	main
ta	doc_286998102734_item	3613940	et	4	main
technikaga	doc_286998102734_item	3613932	et	4	main
teoseid	doc_286998102734_item	3613930	et	3	main
surnud	doc_286998102734_item	3613987	et	4	main
huvitus	doc_286998102734_item	3613986	et	4	main
ta	doc_286998102734_item	3613985	et	4	main
tuntud	doc_286998102734_item	3613965	et	4	main
et	doc_286998102734_item	3613962	et	3	main
võimaldas	doc_286998102734_item	3613961	et	3	main
stipendiumi	doc_286998102734_item	3613959	et	4	main
hästi	doc_286998102735_item	3614090	et	3	main
räägib	doc_286998102735_item	3614089	et	3	main
õppisib	doc_286998102735_item	3614084	et	4	main
aastani	doc_286998102735_item	3614080	et	3	main
kahetuhande	doc_286998102735_item	3614078	et	4	main
üheksakümnenda	doc_286998102735_item	3614076	et	4	main
üheksasaja	doc_286998102735_item	3614075	et	4	main
tuhande	doc_286998102735_item	3614074	et	3	main
ta	doc_286998102735_item	3614069	et	4	main
kus	doc_286998102735_item	3614068	et	3	main
ülikool	doc_286998102735_item	3614067	et	4	main
käisi	doc_286998102735_item	3614056	et	4	main
aastast	doc_286998102735_item	3614045	et	4	main
üheksasaja	doc_286998102735_item	3614042	et	4	main
kuuekümne	doc_286998102735_item	3614035	et	4	main
üheksasaja	doc_286998102735_item	3614034	et	4	main
juunil	doc_286998102735_item	3614032	et	3	main
salu	doc_286998102735_item	3614028	et	4	main
salu	doc_286998102735_item	3614019	et	4	main
elu	doc_286998102732_item	3613761	et	4	main
et	doc_286998102732_item	3613757	et	3	main
ei	doc_286998102732_item	3613747	et	4	main
ma	doc_286998102732_item	3613746	et	3	main
et	doc_286998102732_item	3613745	et	3	main
arvan	doc_286998102732_item	3613744	et	3	main
seina	doc_286998102732_item	3613731	et	4	main
suudan	doc_286998102732_item	3613730	et	3	main
olemas	doc_286998102732_item	3613718	et	4	main
nõupesumasina	doc_286998102732_item	3613717	et	3	main
ole	doc_286998102732_item	3613709	et	4	main
väga	doc_286998102732_item	3613705	et	3	main
rõdu	doc_286998102732_item	3613702	et	4	main
ja	doc_286998102732_item	3613701	et	3	main
elame	doc_286998102732_item	3613692	et	3	main
kus	doc_286998102732_item	3613691	et	3	main
tuba	doc_286998102732_item	3613690	et	4	main
suur	doc_286998102732_item	3613689	et	3	main
ja	doc_286998102732_item	3613688	et	3	main
kööki	doc_286998102732_item	3613687	et	4	main
alalpool	doc_286998102732_item	3613686	et	4	main
maja	doc_286998102732_item	3613685	et	4	main
kahekorruseline	doc_286998102732_item	3613684	et	4	main
oleks	doc_286998102732_item	3613683	et	3	main
parem	doc_286998102732_item	3613682	et	4	main
kõige	doc_286998102732_item	3613681	et	4	main
on	doc_286998102732_item	3613679	et	4	main
aed	doc_286998102732_item	3613680	et	3	main
millel	doc_286998102732_item	3613678	et	3	main
elada	doc_286998102732_item	3613677	et	3	main
eramajas	doc_286998102732_item	3613676	et	3	main
olen	doc_286998102732_item	3613673	et	3	main
vaja	doc_286998102732_item	3613648	et	4	main
ole	doc_286998102732_item	3613647	et	4	main
ei	doc_286998102732_item	3613646	et	4	main
aga	doc_286998102732_item	3613645	et	3	main
elada	doc_286998102732_item	3613644	et	3	main
erilist	doc_286998102732_item	3613638	et	4	main
tulevikukodu	doc_286998102732_item	3613635	et	4	main
ta	doc_286998102733_item	3613895	et	4	main
ta	doc_286998102733_item	3613888	et	4	main
mõjustatud	doc_286998102733_item	3613877	et	4	main
oli	doc_286998102733_item	3613876	et	3	main
ta	doc_286998102733_item	3613875	et	4	main
3	doc_286998102733_item	3613862	et	2	main
siia	doc_286998102733_item	3613861	et	4	main
jäi	doc_286998102733_item	3613860	et	3	main
sest	doc_286998102733_item	3613851	et	4	main
lemmikala	doc_286998102733_item	3613848	et	4	main
oma	doc_286998102733_item	3613847	et	4	main
võimalust	doc_286998102733_item	3613846	et	3	main
pariisi	doc_286998102734_item	3613942	et	4	main
tunnus	doc_286998102734_item	3613934	et	3	main
seal	doc_286998102734_item	3613923	et	4	main
kunsttööstuskoolis	doc_286998102734_item	3613922	et	4	main
sai	doc_286998102734_item	3613995	et	4	main
oleks	doc_286998102734_item	3613964	et	3	main
ta	doc_286998102735_item	3614088	et	4	main
siis	doc_286998102735_item	3614087	et	3	main
koolis	doc_286998102735_item	3614086	et	4	main
palju	doc_286998102735_item	3614085	et	4	main
tartu	doc_286998102735_item	3614066	et	4	main
ta	doc_286998102735_item	3614055	et	4	main
sellepärast	doc_286998102735_item	3614054	et	3	main
üheksasaja	doc_286998102735_item	3614047	et	4	main
on	doc_286998102732_item	3613713	et	4	main
mõnikord	doc_286998102732_item	3613712	et	3	main
kuigi	doc_286998102732_item	3613711	et	3	main
vaja	doc_286998102732_item	3613710	et	4	main
erilisi	doc_286998102732_item	3613706	et	4	main
tahan	doc_286998102732_item	3613704	et	3	main
meeldiks	doc_286998102732_item	3613675	et	3	main
mugavas	doc_286998102732_item	3613642	et	3	main
ma	doc_286998102732_item	3613639	et	3	main
mu	doc_286998102732_item	3613634	et	3	main
mina	doc_286998102732_item	3613672	et	4	main
missugune	doc_286998102732_item	3613671	et	3	main
näitab	doc_286998102732_item	3613670	et	3	main
see	doc_286998102732_item	3613669	et	3	main
elukutse	doc_286998102733_item	3613900	et	4	main
sest	doc_286998102733_item	3613893	et	4	main
elama	doc_286998102733_item	3613892	et	3	main
tallinnas	doc_286998102733_item	3613887	et	4	main
expressionismist	doc_286998102733_item	3613878	et	4	main
ta	doc_286998102733_item	3613865	et	4	main
ja	doc_286998102733_item	3613864	et	3	main
aastat	doc_286998102733_item	3613863	et	3	main
sai	doc_286998102733_item	3613845	et	4	main
vastu	doc_286998102733_item	3613801	et	3	main
puulõige	doc_286998102733_item	3613800	et	4	main
huvi	doc_286998102733_item	3613799	et	4	main
tundis	doc_286998102733_item	3613798	et	3	main
ta	doc_286998102733_item	3613797	et	4	main
kunsttöötuskoolis	doc_286998102733_item	3613796	et	4	main
tallinna	doc_286998102733_item	3613795	et	4	main
ka	doc_286998102733_item	3613793	et	3	main
õppima	doc_286998102733_item	3613794	et	3	main
hakkas	doc_286998102733_item	3613792	et	3	main
ta	doc_286998102733_item	3613791	et	4	main
aga	doc_286998102733_item	3613790	et	3	main
hiiumaalt	doc_286998102733_item	3613789	et	3	main
pärines	doc_286998102733_item	3613788	et	3	main
ta	doc_286998102733_item	3613787	et	4	main
1885	doc_286998102733_item	3613786	et	2	main
a	doc_286998102733_item	3613785	et	4	main
sündinud	doc_286998102733_item	3613784	et	4	main
on	doc_286998102733_item	3613783	et	4	main
viiralt	doc_286998102733_item	3613782	et	3	main
eduart	doc_286998102733_item	3613781	et	4	main
elu	doc_286998102733_item	3613780	et	4	main
viiralti	doc_286998102733_item	3613779	et	4	main
eduard	doc_286998102733_item	3613778	et	4	main
essee	doc_286998102733_item	3613777	et	4	main
viiralt	doc_286998102734_item	3613933	et	3	main
ta	doc_286998102734_item	3613924	et	4	main
keskkooli	doc_286998102734_item	3613918	et	4	main
ta	doc_286998102734_item	3613994	et	4	main
ja	doc_286998102734_item	3613992	et	3	main
joonistas	doc_286998102734_item	3613990	et	3	main
ta	doc_286998102734_item	3613989	et	4	main
inimestedest	doc_286998102734_item	3613988	et	4	main
ta	doc_286998102734_item	3613956	et	4	main
lihtsalt	doc_286998102732_item	3613641	et	4	main
ole	doc_286998102732_item	3613637	et	4	main
ja	doc_286998102732_item	3613668	et	3	main
meeldib	doc_286998102732_item	3613667	et	3	main
mulle	doc_286998102732_item	3613666	et	4	main
kuidas	doc_286998102732_item	3613665	et	3	main
minumoodi	doc_286998102732_item	3613664	et	4	main
täiesti	doc_286998102732_item	3613663	et	3	main
ilus	doc_286998102732_item	3613662	et	4	main
on	doc_286998102732_item	3613661	et	4	main
see	doc_286998102732_item	3613660	et	3	main
ruumi	doc_286998102732_item	3613659	et	4	main
piisavaid	doc_286998102732_item	3613658	et	4	main
on	doc_286998102732_item	3613657	et	4	main
tulevikukodu	doc_286998102732_item	3613656	et	4	main
mu	doc_286998102732_item	3613655	et	3	main
asemel	doc_286998102732_item	3613654	et	4	main
minu	doc_286998102732_item	3613653	et	3	main
tööks	doc_286998102732_item	3613652	et	3	main
masina	doc_286998102732_item	3613651	et	3	main
mingi	doc_286998102732_item	3613650	et	4	main
harjutada	doc_286998102733_item	3613901	et	3	main
rohkem	doc_286998102733_item	3613897	et	4	main
kaua	doc_286998102733_item	3613890	et	3	main
jäi	doc_286998102733_item	3613889	et	3	main
tuntus	doc_286998102733_item	3613872	et	4	main
kunstnikke	doc_286998102733_item	3613871	et	3	main
tunnustust	doc_286998102733_item	3613868	et	4	main
kohe	doc_286998102733_item	3613867	et	4	main
saavutas	doc_286998102733_item	3613866	et	3	main
võimaldas	doc_286998102733_item	3613854	et	3	main
kultuurkapital	doc_286998102733_item	3613853	et	3	main
eesti	doc_286998102733_item	3613852	et	4	main
paremini	doc_286998102733_item	3613849	et	4	main
peterburis	doc_286998102733_item	3613840	et	4	main
aastat	doc_286998102733_item	3613839	et	3	main
üks	doc_286998102733_item	3613838	et	3	main
seal	doc_286998102733_item	3613894	et	4	main
peterburis	doc_286998102733_item	3613885	et	4	main
pariisis	doc_286998102733_item	3613883	et	4	main
prantsusmaa	doc_286998102733_item	3613870	et	4	main
tutvuda	doc_286998102733_item	3613850	et	3	main
viibis	doc_286998102733_item	3613837	et	3	main
ta	doc_286998102733_item	3613836	et	4	main
jääma	doc_286998102733_item	3613835	et	4	main
võõrsile	doc_286998102733_item	3613834	et	4	main
otsustas	doc_286998102733_item	3613833	et	3	main
ta	doc_286998102733_item	3613832	et	4	main
vastu	doc_286998102733_item	3613831	et	3	main
maalimine	doc_286998102733_item	3613830	et	4	main
vaimustust	doc_286998102733_item	3613829	et	4	main
tundis	doc_286998102733_item	3613828	et	3	main
ta	doc_286998102733_item	3613827	et	4	main
kuid	doc_286998102733_item	3613826	et	4	main
ja	doc_286998102733_item	3613825	et	3	main
plaanima	doc_286998102733_item	3613824	et	3	main
elu	doc_286998102733_item	3613823	et	4	main
oma	doc_286998102733_item	3613822	et	4	main
aega	doc_286998102733_item	3613821	et	4	main
oli	doc_286998102733_item	3613820	et	3	main
tal	doc_286998102733_item	3613819	et	3	main
siis	doc_286998102733_item	3613818	et	3	main
sest	doc_286998102733_item	3613817	et	4	main
temale	doc_286998102733_item	3613815	et	3	main
tuli	doc_286998102733_item	3613814	et	4	main
kasuks	doc_286998102733_item	3613816	et	4	main
aga	doc_286998102733_item	3613813	et	3	main
see	doc_286998102733_item	3613812	et	3	main
havata	doc_286998102733_item	3613811	et	4	main
ruttu	doc_286998102733_item	3613810	et	4	main
sai	doc_286998102733_item	3613809	et	4	main
ta	doc_286998102733_item	3613808	et	4	main
aga	doc_286998102733_item	3613807	et	3	main
vababadussõjas	doc_286998102733_item	3613806	et	4	main
eesti	doc_286998102733_item	3613805	et	4	main
osa	doc_286998102733_item	3613804	et	4	main
võtis	doc_286998102733_item	3613803	et	3	main
ta	doc_286998102733_item	3613802	et	4	main
läks	doc_286998102734_item	3613941	et	3	main
sellepärast	doc_286998102734_item	3613939	et	3	main
vastu	doc_286998102734_item	3613938	et	3	main
kunstniku	doc_286998102734_item	3613937	et	3	main
kaasaegse	doc_286998102734_item	3613936	et	3	main
ekspressionismust	doc_286998102734_item	3614014	et	4	main
hiljem	doc_286998102734_item	3614013	et	3	main
ja	doc_286998102734_item	3614012	et	3	main
impressionismust	doc_286998102734_item	3614011	et	4	main
mõjustatud	doc_286998102734_item	3614010	et	4	main
on	doc_286998102734_item	3614009	et	4	main
teosed	doc_286998102734_item	3614008	et	3	main
tema	doc_286998102734_item	3614007	et	4	main
tunnustust	doc_286998102734_item	3614006	et	4	main
suurem	doc_286998102734_item	3614005	et	4	main
saavutas	doc_286998102734_item	3614004	et	3	main
ja	doc_286998102734_item	3614003	et	3	main
popularne	doc_286998102734_item	3614002	et	4	main
väga	doc_286998102734_item	3614001	et	3	main
oli	doc_286998102734_item	3614000	et	3	main
ta	doc_286998102734_item	3613999	et	4	main
maailmasõda	doc_286998102734_item	3613998	et	4	main
pärast	doc_286998102734_item	3613997	et	4	main
haavata	doc_286998102734_item	3613996	et	4	main
selle	doc_286998102734_item	3613931	et	4	main
lõi	doc_286998102734_item	3613929	et	4	main
ära	doc_286998102734_item	3613927	et	4	main
puulõige	doc_286998102734_item	3613926	et	4	main
õppis	doc_286998102734_item	3613925	et	3	main
pärast	doc_286998102734_item	3613917	et	4	main
tartust	doc_286998102734_item	3613916	et	3	main
pärit	doc_286998102734_item	3613915	et	3	main
on	doc_286998102734_item	3613914	et	4	main
ta	doc_286998102734_item	3613913	et	4	main
kunstnik	doc_286998102734_item	3613912	et	3	main
eesti	doc_286998102734_item	3613911	et	4	main
suur	doc_286998102734_item	3613910	et	3	main
on	doc_286998102734_item	3613909	et	4	main
viiralt	doc_286998102734_item	3613908	et	3	main
eduard	doc_286998102734_item	3613907	et	4	main
elu	doc_286998102734_item	3613906	et	4	main
viiralti	doc_286998102734_item	3613905	et	4	main
eduard	doc_286998102734_item	3613904	et	4	main
essee	doc_286998102734_item	3613903	et	4	main
sõjal	doc_286998102734_item	3613993	et	3	main
ja	doc_286998102734_item	3613984	et	3	main
sõdur	doc_286998102734_item	3613983	et	3	main
ka	doc_286998102734_item	3613982	et	3	main
oli	doc_286998102734_item	3613981	et	3	main
ta	doc_286998102734_item	3613980	et	4	main
ajal	doc_286998102734_item	3613979	et	4	main
maailmasõja	doc_286998102734_item	3613978	et	3	main
teisel	doc_286998102734_item	3613977	et	4	main
elus	doc_286998102734_item	3613976	et	4	main
tema	doc_286998102734_item	3613975	et	4	main
tähtis	doc_286998102734_item	3613974	et	4	main
väga	doc_286998102734_item	3613973	et	3	main
oli	doc_286998102734_item	3613972	et	3	main
mis	doc_286998102734_item	3613971	et	4	main
näitust	doc_286998102734_item	3613970	et	4	main
viiralti	doc_286998102734_item	3613969	et	4	main
korraldati	doc_286998102734_item	3613968	et	3	main
vaimustus	doc_286998102734_item	3613935	et	4	main
ja	doc_286998102734_item	3613928	et	3	main
tallinnas	doc_286998102734_item	3613921	et	4	main
õppis	doc_286998102734_item	3613920	et	3	main
ta	doc_286998102734_item	3613919	et	4	main
nende	doc_286998102734_item	3613991	et	4	main
sai	doc_286998102734_item	3613955	et	4	main
jõudmist	doc_286998102734_item	3613954	et	4	main
kodumaale	doc_286998102734_item	3613953	et	4	main
pärast	doc_286998102734_item	3613952	et	4	main
loodusemaaline	doc_286998102734_item	3613951	et	4	main
oli	doc_286998102734_item	3613950	et	3	main
lemmikala	doc_286998102734_item	3613949	et	4	main
tema	doc_286998102734_item	3613948	et	4	main
aastat	doc_286998102734_item	3613947	et	3	main
paar	doc_286998102734_item	3613946	et	3	main
võõrsile	doc_286998102734_item	3613945	et	4	main
jäi	doc_286998102734_item	3613944	et	3	main
ta	doc_286998102734_item	3613943	et	4	main
ajalooarhiiv	doc_286998102735_item	3614082	et	3	main
töötasib	doc_286998102735_item	3614073	et	4	main
meelis	doc_286998102735_item	3614072	et	3	main
ajalugu	doc_286998102735_item	3614071	et	4	main
õppisib	doc_286998102735_item	3614070	et	4	main
aastast	doc_286998102735_item	3614065	et	4	main
üheksakümnenda	doc_286998102735_item	3614064	et	4	main
üheksasaja	doc_286998102735_item	3614063	et	4	main
tuhande	doc_286998102735_item	3614062	et	3	main
aastani	doc_286998102735_item	3614061	et	3	main
viienda	doc_286998102735_item	3614060	et	3	main
keskkool	doc_286998102735_item	3614053	et	4	main
kolmanda	doc_286998102735_item	3614052	et	3	main
tuhande	doc_286998102735_item	3614046	et	3	main
tallinnas	doc_286998102735_item	3614038	et	4	main
aastal	doc_286998102735_item	3614037	et	3	main
seitsmendal	doc_286998102735_item	3614036	et	3	main
on	doc_286998102735_item	3614029	et	4	main
meelis	doc_286998102735_item	3614027	et	3	main
kuueteistkümneseitme	doc_286998102736_item	3614126	et	4	main
sõnadega	doc_286998102736_item	3614114	et	3	main
arvud	doc_286998102736_item	3614113	et	3	main
kirjuta	doc_286998102736_item	3614112	et	4	main
tegeleb	doc_286998102738_item	3614244	et	3	main
talle	doc_286998102738_item	3614239	et	4	main
nelja	doc_286998102738_item	3614229	et	4	main
õppis	doc_286998102738_item	3614216	et	3	main
aastani	doc_286998102738_item	3614215	et	3	main
üheksasaja	doc_286998102738_item	3614213	et	4	main
tuhande	doc_286998102738_item	3614212	et	3	main
kaheksakümne	doc_286998102738_item	3614210	et	4	main
üheksasaja	doc_286998102738_item	3614209	et	4	main
tuhande	doc_286998102738_item	3614208	et	3	main
tuhande	doc_286998102738_item	3614197	et	3	main
sõnadega	doc_286998102738_item	3614182	et	3	main
salu	doc_286998102738_item	3614178	et	4	main
aastast	doc_286998102740_item	3614293	et	4	main
ajalugu	doc_286998102740_item	3614284	et	4	main
ja	doc_286998102740_item	3614282	et	3	main
tuhatüheksasadakaheksakümmend	doc_286998102740_item	3614280	et	4	main
aastal	doc_286998102740_item	3614279	et	3	main
hiljem	doc_286998102734_item	3613967	et	3	main
eestis	doc_286998102734_item	3613966	et	3	main
ta	doc_286998102734_item	3613963	et	4	main
see	doc_286998102734_item	3613960	et	3	main
kultuurkapitali	doc_286998102734_item	3613958	et	4	main
eesti	doc_286998102734_item	3613957	et	4	main
tallinna	doc_286998102735_item	3614081	et	4	main
aastast	doc_286998102735_item	3614077	et	4	main
üheksasaja	doc_286998102735_item	3614058	et	4	main
tuhande	doc_286998102735_item	3614057	et	3	main
kaheksakümne	doc_286998102735_item	3614048	et	4	main
neljateistkümnendal	doc_286998102735_item	3614031	et	4	main
sündinud	doc_286998102735_item	3614030	et	4	main
elulugu	doc_286998102735_item	3614026	et	4	main
salu	doc_286998102735_item	3614025	et	4	main
meelis	doc_286998102735_item	3614024	et	3	main
kaheksakümmendviis	doc_286998102736_item	3614149	et	4	main
üheksasada	doc_286998102736_item	3614148	et	4	main
tuhat	doc_286998102736_item	3614147	et	4	main
ülikoolis	doc_286998102736_item	3614146	et	4	main
tartu	doc_286998102736_item	3614145	et	4	main
ajalugu	doc_286998102736_item	3614144	et	4	main
õppis	doc_286998102736_item	3614143	et	3	main
ta	doc_286998102736_item	3614142	et	4	main
aastani	doc_286998102736_item	3614141	et	3	main
kaheksakümneviie	doc_286998102736_item	3614140	et	4	main
üheksasaja	doc_286998102736_item	3614139	et	4	main
tuhande	doc_286998102736_item	3614138	et	3	main
kuni	doc_286998102736_item	3614137	et	3	main
neli	doc_286998102736_item	3614136	et	3	main
seitsmekümmend	doc_286998102736_item	3614135	et	4	main
üheksasada	doc_286998102736_item	3614134	et	4	main
tuhat	doc_286998102736_item	3614133	et	4	main
keskkoolis	doc_286998102736_item	3614132	et	4	main
kolmandas	doc_286998102736_item	3614131	et	3	main
tallinna	doc_286998102736_item	3614130	et	4	main
käis	doc_286998102736_item	3614129	et	4	main
mängida	doc_286998102735_item	3614105	et	3	main
võrkpalli	doc_286998102735_item	3614104	et	4	main
armastab	doc_286998102735_item	3614103	et	3	main
ta	doc_286998102735_item	3614102	et	4	main
ja	doc_286998102735_item	3614101	et	3	main
ajas	doc_286998102735_item	3614100	et	4	main
vaba	doc_286998102735_item	3614099	et	4	main
lugemine	doc_286998102735_item	3614098	et	4	main
paremini	doc_286998102735_item	3614097	et	4	main
armastab	doc_286998102735_item	3614096	et	3	main
ta	doc_286998102735_item	3614095	et	4	main
keel	doc_286998102735_item	3614094	et	4	main
inglise	doc_286998102735_item	3614093	et	4	main
ja	doc_286998102735_item	3614092	et	3	main
saksa	doc_286998102735_item	3614091	et	4	main
meelis	doc_286998102735_item	3614083	et	3	main
neljanda	doc_286998102735_item	3614079	et	3	main
kaheksakümne	doc_286998102735_item	3614059	et	4	main
tallinna	doc_286998102735_item	3614051	et	4	main
aastani	doc_286998102735_item	3614050	et	3	main
viienda	doc_286998102735_item	3614049	et	3	main
neljanda	doc_286998102735_item	3614044	et	3	main
käisid	doc_286998102735_item	3614040	et	4	main
ta	doc_286998102735_item	3614039	et	4	main
tuhande	doc_286998102735_item	3614033	et	3	main
elulugu	doc_286998102735_item	3614020	et	4	main
elulugu	doc_286998102736_item	3614117	et	4	main
kirjuta	doc_286998102736_item	3614108	et	4	main
ta	doc_286998102738_item	3614243	et	4	main
lugemine	doc_286998102738_item	3614241	et	4	main
meeldib	doc_286998102738_item	3614240	et	3	main
ja	doc_286998102738_item	3614236	et	3	main
tartu	doc_286998102738_item	3614217	et	4	main
üheksakümne	doc_286998102738_item	3614214	et	4	main
viiendast	doc_286998102738_item	3614211	et	3	main
kaheksakümne	doc_286998102738_item	3614203	et	4	main
üheksasaja	doc_286998102738_item	3614202	et	4	main
tuhande	doc_286998102738_item	3614201	et	3	main
neljandast	doc_286998102738_item	3614200	et	3	main
seitsmendal	doc_286998102738_item	3614195	et	3	main
üheksasaja	doc_286998102738_item	3614193	et	4	main
neljateistkümnendal	doc_286998102738_item	3614190	et	4	main
sündinud	doc_286998102738_item	3614189	et	4	main
meelis	doc_286998102738_item	3614186	et	3	main
elulugu	doc_286998102738_item	3614185	et	4	main
salu	doc_286998102738_item	3614184	et	4	main
tuhandeüheksasajaüheksakümnest	doc_286998102740_item	3614292	et	3	main
õppis	doc_286998102740_item	3614283	et	3	main
ta	doc_286998102740_item	3614276	et	4	main
romantilline	doc_286998102741_item	3614367	et	4	main
suvi	doc_286998102741_item	3614361	et	3	main
köögis	doc_286998102741_item	3614319	et	3	main
palju	doc_286998102741_item	3614317	et	4	main
vihma	doc_286998102741_item	3614309	et	4	main
ja	doc_286998102741_item	3614426	et	3	main
on	doc_286998102741_item	3614417	et	4	main
tal	doc_286998102741_item	3614416	et	3	main
ees	doc_286998102741_item	3614406	et	4	main
ja	doc_286998102741_item	3614402	et	3	main
vain	doc_286998102742_item	3614692	et	3	main
ajab	doc_286998102742_item	3614691	et	3	main
keda	doc_286998102742_item	3614690	et	4	main
juristid	doc_286998102742_item	3614689	et	3	main
ja	doc_286998102742_item	3614688	et	3	main
majandusteadlased	doc_286998102742_item	3614687	et	3	main
ja	doc_286998102742_item	3614686	et	3	main
tegeleb	doc_286998102742_item	3614682	et	3	main
tulemuseks	doc_286998102742_item	3614674	et	3	main
kõrgkooli	doc_286998102742_item	3614673	et	4	main
viimati	doc_286998102742_item	3614671	et	3	main
pedagoogilise	doc_286998102742_item	3614666	et	4	main
hiljem	doc_286998102742_item	3614665	et	3	main
eriala	doc_286998102742_item	3614664	et	4	main
teaduskonna	doc_286998102742_item	3614663	et	4	main
ülokooli	doc_286998102742_item	3614660	et	4	main
keelest	doc_286998102742_item	3614648	et	4	main
näiteks	doc_286998102742_item	3614641	et	4	main
vastavalt	doc_286998102742_item	3614640	et	4	main
aga	doc_286998102742_item	3614634	et	3	main
naine	doc_286998102742_item	3614627	et	3	main
peab	doc_286998102742_item	3614615	et	4	main
miks	doc_286998102742_item	3614608	et	4	main
seitsmekümne	doc_286998102735_item	3614043	et	4	main
tuhande	doc_286998102735_item	3614041	et	3	main
sõnadega	doc_286998102735_item	3614023	et	3	main
arvud	doc_286998102735_item	3614022	et	3	main
kirjuta	doc_286998102735_item	3614021	et	4	main
essee	doc_286998102735_item	3614016	et	4	main
julil	doc_286998102736_item	3614123	et	4	main
neliteistkümnendal	doc_286998102736_item	3614122	et	4	main
salu	doc_286998102736_item	3614116	et	4	main
meelis	doc_286998102736_item	3614115	et	3	main
essee	doc_286998102736_item	3614107	et	4	main
võrkpalliga	doc_286998102738_item	3614245	et	3	main
ja	doc_286998102738_item	3614242	et	3	main
hästi	doc_286998102738_item	3614234	et	3	main
aasta	doc_286998102738_item	3614230	et	4	main
käis	doc_286998102738_item	3614206	et	4	main
aastani	doc_286998102738_item	3614205	et	3	main
viie	doc_286998102738_item	3614204	et	3	main
üheksasaja	doc_286998102738_item	3614198	et	4	main
on	doc_286998102738_item	3614188	et	4	main
arvud	doc_286998102738_item	3614181	et	3	main
kirjuta	doc_286998102738_item	3614176	et	4	main
essee	doc_286998102738_item	3614175	et	4	main
ajalooarhiivis	doc_286998102740_item	3614298	et	3	main
ta	doc_286998102740_item	3614294	et	4	main
tuhandeüheksasajaüheksakümne	doc_286998102740_item	3614290	et	4	main
ilus	doc_286998102741_item	3614365	et	4	main
on	doc_286998102741_item	3614360	et	4	main
on	doc_286998102741_item	3614334	et	4	main
koer	doc_286998102741_item	3614332	et	3	main
suur	doc_286998102741_item	3614330	et	3	main
puus	doc_286998102741_item	3614314	et	4	main
ja	doc_286998102741_item	3614313	et	3	main
puhub	doc_286998102741_item	3614312	et	3	main
tuul	doc_286998102741_item	3614311	et	3	main
sajab	doc_286998102741_item	3614310	et	3	main
pildil	doc_286998102741_item	3614303	et	3	main
pildi	doc_286998102741_item	3614301	et	4	main
joosta	doc_286998102741_item	3614425	et	4	main
meeldi	doc_286998102741_item	3614424	et	4	main
lasteaga	doc_286998102742_item	3614683	et	4	main
õpetajad	doc_286998102742_item	3614679	et	4	main
lasteaiakasvatajad	doc_286998102742_item	3614677	et	3	main
lasteaiakasvatajate	doc_286998102742_item	3614672	et	3	main
kõrgkooli	doc_286998102742_item	3614669	et	4	main
paneb	doc_286998102742_item	3614654	et	3	main
ungari	doc_286998102742_item	3614647	et	4	main
vanemate	doc_286998102742_item	3614638	et	4	main
prestiiži	doc_286998102742_item	3614636	et	2	main
huvi	doc_286998102742_item	3614633	et	4	main
oma	doc_286998102742_item	3614632	et	4	main
mitte	doc_286998102742_item	3614631	et	3	main
sageli	doc_286998102742_item	3614630	et	3	main
ülikooli	doc_286998102742_item	3614619	et	4	main
sest	doc_286998102742_item	3614613	et	4	main
ja	doc_286998102742_item	3614607	et	3	main
siis	doc_286998102742_item	3614605	et	3	main
nõrgemaks	doc_286998102742_item	3614590	et	4	main
keha	doc_286998102742_item	3614586	et	4	main
siis	doc_286998102742_item	3614584	et	3	main
mitte	doc_286998102742_item	3614573	et	3	main
vahel	doc_286998102742_item	3614566	et	4	main
toodangu	doc_286998102742_item	3614565	et	3	main
unustada	doc_286998102742_item	3614557	et	3	main
ei	doc_286998102742_item	3614555	et	4	main
lapsevanem	doc_286998102742_item	3614554	et	4	main
aga	doc_286998102742_item	3614553	et	3	main
hästi	doc_286998102742_item	3614552	et	3	main
nii	doc_286998102742_item	3614551	et	3	main
sooritab	doc_286998102742_item	3614550	et	3	main
õpivad	doc_286998102742_item	3614523	et	3	main
et	doc_286998102742_item	3614519	et	3	main
sest	doc_286998102742_item	3614515	et	4	main
nõutuseni	doc_286998102742_item	3614514	et	4	main
prooviti	doc_286998102742_item	3614504	et	3	main
siis	doc_286998102742_item	3614499	et	3	main
viib	doc_286998102742_item	3614497	et	3	main
paha	doc_286998102742_item	3614493	et	4	main
ole	doc_286998102742_item	3614492	et	4	main
lastele	doc_286998102742_item	3614482	et	4	main
oma	doc_286998102742_item	3614473	et	4	main
meelis	doc_286998102735_item	3614018	et	3	main
kirjuta	doc_286998102735_item	3614017	et	4	main
aastal	doc_286998102736_item	3614127	et	3	main
üheksasaja	doc_286998102736_item	3614125	et	4	main
tuhande	doc_286998102736_item	3614124	et	3	main
salu	doc_286998102736_item	3614119	et	4	main
meelis	doc_286998102736_item	3614118	et	3	main
elulugu	doc_286998102736_item	3614111	et	4	main
salu	doc_286998102736_item	3614110	et	4	main
meelis	doc_286998102736_item	3614109	et	3	main
inglise	doc_286998102738_item	3614237	et	4	main
saksa	doc_286998102738_item	3614235	et	4	main
räägib	doc_286998102738_item	3614233	et	3	main
ta	doc_286998102738_item	3614232	et	4	main
vahel	doc_286998102738_item	3614231	et	4	main
kahetuhande	doc_286998102738_item	3614228	et	4	main
üheksakümne	doc_286998102738_item	3614227	et	4	main
üheksasaja	doc_286998102738_item	3614226	et	4	main
tuhande	doc_286998102738_item	3614225	et	3	main
ajalooarhiivis	doc_286998102738_item	3614224	et	3	main
meelis	doc_286998102738_item	3614223	et	3	main
töötas	doc_286998102738_item	3614222	et	3	main
seda	doc_286998102738_item	3614221	et	3	main
pärast	doc_286998102738_item	3614220	et	4	main
ajalugu	doc_286998102738_item	3614219	et	4	main
ülikoolis	doc_286998102738_item	3614218	et	4	main
ja	doc_286998102736_item	3614172	et	3	main
võrkpalli	doc_286998102736_item	3614173	et	4	main
lugemist	doc_286998102736_item	3614171	et	4	main
armastab	doc_286998102736_item	3614170	et	3	main
ta	doc_286998102736_item	3614169	et	4	main
keelt	doc_286998102736_item	3614168	et	4	main
inglise	doc_286998102736_item	3614167	et	4	main
ja	doc_286998102736_item	3614166	et	3	main
saksa	doc_286998102736_item	3614165	et	4	main
räägib	doc_286998102736_item	3614164	et	3	main
ta	doc_286998102736_item	3614163	et	4	main
ajalooarhiivil	doc_286998102736_item	3614162	et	3	main
tallinna	doc_286998102736_item	3614161	et	4	main
töötas	doc_286998102736_item	3614160	et	3	main
ta	doc_286998102736_item	3614159	et	4	main
aastani	doc_286998102736_item	3614158	et	3	main
nelja	doc_286998102736_item	3614157	et	4	main
kahetuhande	doc_286998102736_item	3614156	et	4	main
üheksakümnest	doc_286998102736_item	3614155	et	3	main
üheksasaja	doc_286998102736_item	3614154	et	4	main
tuhande	doc_286998102736_item	3614153	et	3	main
aastani	doc_286998102736_item	3614152	et	3	main
tuhandeüheksasajaüheksakümne	doc_286998102736_item	3614151	et	4	main
kuni	doc_286998102736_item	3614150	et	3	main
ta	doc_286998102736_item	3614128	et	4	main
sündinud	doc_286998102736_item	3614121	et	4	main
on	doc_286998102736_item	3614120	et	4	main
keel	doc_286998102738_item	3614238	et	4	main
koolis	doc_286998102738_item	3614207	et	4	main
seitsmekümne	doc_286998102738_item	3614199	et	4	main
kuuekümne	doc_286998102738_item	3614194	et	4	main
tuhande	doc_286998102738_item	3614192	et	3	main
juulil	doc_286998102738_item	3614191	et	3	main
salu	doc_286998102738_item	3614187	et	4	main
kirjuta	doc_286998102738_item	3614180	et	4	main
tallinna	doc_286998102740_item	3614297	et	4	main
aastani	doc_286998102740_item	3614291	et	3	main
kaheksakümneviiendast	doc_286998102740_item	3614288	et	4	main
tartu	doc_286998102740_item	3614285	et	4	main
lõpetas	doc_286998102740_item	3614277	et	3	main
keskkoolis	doc_286998102740_item	3614274	et	4	main
kolmandas	doc_286998102740_item	3614273	et	3	main
tallinna	doc_286998102740_item	3614272	et	4	main
aastal	doc_286998102740_item	3614271	et	3	main
tuhandeüheksasajaseitsmekümnenelja	doc_286998102740_item	3614270	et	4	main
keskkooli	doc_286998102740_item	3614269	et	4	main
algas	doc_286998102740_item	3614268	et	3	main
ja	doc_286998102740_item	3614267	et	3	main
tallinnas	doc_286998102740_item	3614266	et	4	main
aastal	doc_286998102740_item	3614265	et	3	main
tuhandeüheksasajakuuekümneseitsme	doc_286998102740_item	3614264	et	4	main
juulil	doc_286998102740_item	3614263	et	3	main
sündinud	doc_286998102740_item	3614261	et	4	main
neljateistkümnes	doc_286998102740_item	3614262	et	4	main
on	doc_286998102740_item	3614260	et	4	main
salu	doc_286998102740_item	3614259	et	4	main
meelis	doc_286998102740_item	3614258	et	3	main
elulugu	doc_286998102740_item	3614257	et	4	main
salu	doc_286998102740_item	3614256	et	4	main
meelis	doc_286998102740_item	3614255	et	3	main
sõnadega	doc_286998102740_item	3614254	et	3	main
arvud	doc_286998102740_item	3614253	et	3	main
kirjuta	doc_286998102740_item	3614252	et	4	main
elulugu	doc_286998102740_item	3614251	et	4	main
salu	doc_286998102740_item	3614250	et	4	main
meelis	doc_286998102740_item	3614249	et	3	main
kirjuta	doc_286998102740_item	3614248	et	4	main
essee	doc_286998102740_item	3614247	et	4	main
on	doc_286998102741_item	3614364	et	4	main
sest	doc_286998102741_item	3614362	et	4	main
kurb	doc_286998102741_item	3614331	et	3	main
paremale	doc_286998102741_item	3614328	et	4	main
pastakas	doc_286998102741_item	3614326	et	4	main
ja	doc_286998102741_item	3614325	et	3	main
kell	doc_286998102741_item	3614324	et	3	main
raamat	doc_286998102741_item	3614323	et	3	main
lehte	doc_286998102741_item	3614318	et	4	main
ole	doc_286998102741_item	3614316	et	4	main
aastal	doc_286998102738_item	3614196	et	3	main
meelis	doc_286998102738_item	3614183	et	3	main
elulugu	doc_286998102738_item	3614179	et	4	main
meelis	doc_286998102738_item	3614177	et	3	main
töötanud	doc_286998102740_item	3614296	et	4	main
on	doc_286998102740_item	3614295	et	4	main
aastast	doc_286998102740_item	3614289	et	4	main
tuhandeüheksasaja	doc_286998102740_item	3614287	et	4	main
ülikoolis	doc_286998102740_item	3614286	et	4	main
viis	doc_286998102740_item	3614281	et	4	main
seda	doc_286998102740_item	3614278	et	3	main
ja	doc_286998102740_item	3614275	et	3	main
öö	doc_286998102741_item	3614368	et	4	main
see	doc_286998102741_item	3614363	et	3	main
ta	doc_286998102741_item	3614333	et	4	main
istub	doc_286998102741_item	3614329	et	3	main
laua	doc_286998102741_item	3614320	et	3	main
number	doc_286998102741_item	3614304	et	3	main
ei	doc_286998102741_item	3614423	et	4	main
uuni	doc_286998102741_item	3614405	et	4	main
hea	doc_286998102742_item	3614684	et	4	main
ühiskonnale	doc_286998102742_item	3614676	et	4	main
filosoofia	doc_286998102742_item	3614662	et	4	main
pärast	doc_286998102742_item	3614661	et	4	main
majandusteaduse	doc_286998102742_item	3614657	et	3	main
esimese	doc_286998102742_item	3614655	et	3	main
siis	doc_286998102742_item	3614653	et	3	main
teha	doc_286998102742_item	3614646	et	3	main
või	doc_286998102742_item	3614637	et	4	main
ühiskondliku	doc_286998102742_item	3614635	et	3	main
sisse	doc_286998102742_item	3614620	et	4	main
pärast	doc_286998102742_item	3614617	et	4	main
kohe	doc_286998102742_item	3614616	et	4	main
see	doc_286998102742_item	3614610	et	3	main
on	doc_286998102742_item	3614609	et	4	main
täiskasvanuteks	doc_286998102742_item	3614606	et	3	main
vastavalt	doc_286998102742_item	3614601	et	4	main
arendab	doc_286998102742_item	3614600	et	3	main
ei	doc_286998102742_item	3614599	et	4	main
laps	doc_286998102742_item	3614592	et	4	main
kui	doc_286998102742_item	3614591	et	3	main
jääb	doc_286998102742_item	3614587	et	3	main
lapse	doc_286998102742_item	3614585	et	4	main
hetkelist	doc_286998102742_item	3614575	et	4	main
tekitab	doc_286998102742_item	3614572	et	3	main
osutanud	doc_286998102742_item	3614564	et	4	main
elus	doc_286998102742_item	3614563	et	4	main
hiljem	doc_286998102742_item	3614562	et	3	main
ja	doc_286998102742_item	3614561	et	3	main
toodangu	doc_286998102742_item	3614560	et	3	main
ei	doc_286998102742_item	3614549	et	4	main
sest	doc_286998102742_item	3614542	et	4	main
õige	doc_286998102742_item	3614541	et	4	main
nende	doc_286998102742_item	3614534	et	4	main
et	doc_286998102742_item	3614533	et	3	main
palju	doc_286998102742_item	3614524	et	4	main
kõik	doc_286998102742_item	3614520	et	4	main
veel	doc_286998102742_item	3614512	et	4	main
vain	doc_286998102742_item	3614511	et	3	main
lapsi	doc_286998102742_item	3614502	et	4	main
ülekormuseni	doc_286998102742_item	3614498	et	4	main
kui	doc_286998102742_item	3614495	et	3	main
aga	doc_286998102742_item	3614494	et	3	main
populaarsem	doc_286998102742_item	3614488	et	4	main
kõige	doc_286998102742_item	3614487	et	4	main
ja	doc_286998102742_item	3614486	et	3	main
haridust	doc_286998102742_item	3614477	et	4	main
lapsevanematele	doc_286998102742_item	3614464	et	4	main
haarab	doc_286998102742_item	3614461	et	3	main
see	doc_286998102742_item	3614459	et	3	main
olisi	doc_286998102742_item	3614450	et	4	main
nagu	doc_286998102742_item	3614449	et	3	main
ta	doc_286998102744_item	3614834	et	4	main
parem	doc_286998102744_item	3614806	et	4	main
ole	doc_286998102744_item	3614800	et	4	main
tunnistama	doc_286998102744_item	3614796	et	3	main
maha	doc_286998102744_item	3614781	et	4	main
munad	doc_286998102744_item	3614779	et	3	main
jooksis	doc_286998102744_item	3614777	et	4	main
tahtis	doc_286998102744_item	3614776	et	3	main
valmistada	doc_286998102744_item	3614775	et	3	main
ta	doc_286998102744_item	3614774	et	4	main
hiiri	doc_286998102741_item	3614429	et	4	main
kardab	doc_286998102741_item	3614428	et	4	main
ta	doc_286998102741_item	3614427	et	4	main
ja	doc_286998102741_item	3614366	et	3	main
meelest	doc_286998102741_item	3614359	et	4	main
minu	doc_286998102741_item	3614358	et	3	main
ja	doc_286998102741_item	3614357	et	3	main
öö	doc_286998102741_item	3614356	et	4	main
on	doc_286998102741_item	3614355	et	4	main
pildil	doc_286998102741_item	3614354	et	3	main
teisel	doc_286998102741_item	3614353	et	4	main
liha	doc_286998102741_item	3614352	et	4	main
ole	doc_286998102741_item	3614351	et	4	main
ei	doc_286998102741_item	3614350	et	4	main
taldrikus	doc_286998102741_item	3614349	et	3	main
kahjuks	doc_286998102741_item	3614348	et	4	main
ja	doc_286998102741_item	3614347	et	3	main
ees	doc_286998102741_item	3614346	et	4	main
akna	doc_286998102741_item	3614345	et	3	main
on	doc_286998102741_item	3614344	et	4	main
taldrik	doc_286998102741_item	3614343	et	3	main
ta	doc_286998102741_item	3614342	et	4	main
ja	doc_286998102741_item	3614341	et	3	main
tühi	doc_286998102741_item	3614340	et	3	main
kõht	doc_286998102741_item	3614339	et	3	main
on	doc_286998102741_item	3614338	et	4	main
tal	doc_286998102741_item	3614337	et	3	main
sest	doc_286998102741_item	3614336	et	4	main
kurb	doc_286998102741_item	3614335	et	3	main
lauast	doc_286998102741_item	3614327	et	4	main
on	doc_286998102741_item	3614322	et	4	main
peal	doc_286998102741_item	3614321	et	4	main
sest	doc_286998102741_item	3614308	et	4	main
kirjeldus	doc_286998102741_item	3614302	et	4	main
talle	doc_286998102741_item	3614422	et	4	main
aga	doc_286998102741_item	3614421	et	3	main
tühi	doc_286998102741_item	3614420	et	3	main
kõht	doc_286998102741_item	3614419	et	3	main
ka	doc_286998102741_item	3614418	et	3	main
on	doc_286998102741_item	3614407	et	4	main
vasakule	doc_286998102741_item	3614404	et	4	main
temast	doc_286998102741_item	3614403	et	3	main
hiir	doc_286998102741_item	3614401	et	4	main
paks	doc_286998102741_item	3614400	et	3	main
suur	doc_286998102741_item	3614399	et	3	main
on	doc_286998102741_item	3614398	et	4	main
paremale	doc_286998102741_item	3614397	et	4	main
lauast	doc_286998102741_item	3614396	et	4	main
pool	doc_286998102741_item	3614395	et	4	main
vasakul	doc_286998102741_item	3614394	et	4	main
laud	doc_286998102741_item	3614393	et	4	main
ka	doc_286998102741_item	3614392	et	3	main
on	doc_286998102741_item	3614391	et	4	main
ja	doc_286998102741_item	3614390	et	3	main
tool	doc_286998102741_item	3614389	et	3	main
on	doc_286998102741_item	3614388	et	4	main
taga	doc_286998102741_item	3614387	et	4	main
laua	doc_286998102741_item	3614386	et	3	main
klahvel	doc_286998102741_item	3614385	et	3	main
ja	doc_286998102741_item	3614384	et	3	main
taldrik	doc_286998102741_item	3614383	et	3	main
klaas	doc_286998102741_item	3614382	et	3	main
on	doc_286998102741_item	3614381	et	4	main
peal	doc_286998102741_item	3614380	et	4	main
laua	doc_286998102741_item	3614379	et	3	main
ilusti	doc_286998102741_item	3614378	et	3	main
paistab	doc_286998102741_item	3614377	et	3	main
kuu	doc_286998102741_item	3614376	et	4	main
ja	doc_286998102741_item	3614375	et	3	main
puhu	doc_286998102741_item	3614374	et	4	main
ei	doc_286998102741_item	3614373	et	4	main
tuul	doc_286998102741_item	3614372	et	3	main
saja	doc_286998102741_item	3614371	et	4	main
ei	doc_286998102741_item	3614370	et	4	main
vihma	doc_286998102741_item	3614369	et	4	main
meelega	doc_286998102742_item	3614685	et	4	main
saame	doc_286998102742_item	3614675	et	4	main
ja	doc_286998102742_item	3614670	et	3	main
või	doc_286998102742_item	3614668	et	4	main
ülikooli	doc_286998102742_item	3614667	et	4	main
või	doc_286998102742_item	3614658	et	4	main
ei	doc_286998102741_item	3614315	et	4	main
sügis	doc_286998102741_item	3614307	et	3	main
on	doc_286998102741_item	3614306	et	4	main
1	doc_286998102741_item	3614305	et	2	main
sest	doc_286998102741_item	3614415	et	4	main
hiiri	doc_286998102741_item	3614414	et	4	main
süüa	doc_286998102741_item	3614413	et	3	main
tahaks	doc_286998102741_item	3614412	et	3	main
kass	doc_286998102741_item	3614411	et	3	main
kass	doc_286998102741_item	3614410	et	3	main
laisk	doc_286998102741_item	3614409	et	3	main
väike	doc_286998102741_item	3614408	et	4	main
ei	doc_286998102742_item	3614681	et	4	main
kes	doc_286998102742_item	3614680	et	4	main
ungaris	doc_286998102742_item	3614707	et	4	main
probleeme	doc_286998102742_item	3614706	et	3	main
ühiskondliku	doc_286998102742_item	3614705	et	3	main
ka	doc_286998102742_item	3614704	et	3	main
on	doc_286998102742_item	3614703	et	4	main
kooliprobleeme	doc_286998102742_item	3614702	et	3	main
et	doc_286998102742_item	3614701	et	3	main
kirjutan	doc_286998102742_item	3614700	et	3	main
seetõttu	doc_286998102742_item	3614699	et	3	main
ring	doc_286998102742_item	3614698	et	3	main
kurade	doc_286998102742_item	3614697	et	3	main
on	doc_286998102742_item	3614695	et	4	main
tõsine	doc_286998102742_item	3614696	et	4	main
see	doc_286998102742_item	3614694	et	3	main
raha	doc_286998102742_item	3614693	et	4	main
ja	doc_286998102742_item	3614678	et	3	main
õigusteaduse	doc_286998102742_item	3614659	et	3	main
vastuvõtmise	doc_286998102742_item	3614644	et	3	main
keegi	doc_286998102742_item	3614642	et	4	main
nõude	doc_286998102742_item	3614639	et	4	main
ülikool	doc_286998102742_item	3614629	et	4	main
või	doc_286998102742_item	3614626	et	4	main
noor	doc_286998102742_item	3614624	et	3	main
ja	doc_286998102742_item	3614622	et	3	main
laps	doc_286998102742_item	3614614	et	4	main
tagajärgjed	doc_286998102742_item	3614603	et	4	main
vain	doc_286998102742_item	3614595	et	3	main
koormatud	doc_286998102742_item	3614594	et	4	main
ära	doc_286998102742_item	3614588	et	4	main
vain	doc_286998102742_item	3614574	et	3	main
lastel	doc_286998102742_item	3614571	et	4	main
kooli	doc_286998102742_item	3614559	et	4	main
et	doc_286998102742_item	3614558	et	3	main
nende	doc_286998102742_item	3614547	et	4	main
et	doc_286998102742_item	3614546	et	3	main
olla	doc_286998102742_item	3614545	et	3	main
tõesti	doc_286998102742_item	3614544	et	3	main
võb	doc_286998102742_item	3614543	et	4	main
olla	doc_286998102742_item	3614531	et	3	main
nendel	doc_286998102742_item	3614529	et	4	main
rohkem	doc_286998102742_item	3614525	et	4	main
teised	doc_286998102742_item	3614521	et	4	main
lapsevanemad	doc_286998102742_item	3614517	et	4	main
ungaris	doc_286998102742_item	3614507	et	4	main
kannavad	doc_286998102742_item	3614501	et	3	main
kõrvatunde	doc_286998102742_item	3614489	et	4	main
parema	doc_286998102742_item	3614484	et	4	main
kõige	doc_286998102742_item	3614475	et	4	main
ka	doc_286998102742_item	3614463	et	3	main
võistlus	doc_286998102742_item	3614460	et	3	main
ja	doc_286998102742_item	3614458	et	3	main
asukkaid	doc_286998102742_item	3614457	et	4	main
on	doc_286998102742_item	3614448	et	4	main
kohale	doc_286998102742_item	3614656	et	4	main
ajalugust	doc_286998102742_item	3614652	et	4	main
ning	doc_286998102742_item	3614651	et	3	main
kirjandusest	doc_286998102742_item	3614650	et	4	main
ja	doc_286998102742_item	3614649	et	3	main
eksam	doc_286998102742_item	3614645	et	3	main
tahab	doc_286998102742_item	3614643	et	3	main
valib	doc_286998102742_item	3614628	et	3	main
mees	doc_286998102742_item	3614625	et	4	main
ungari	doc_286998102742_item	3614623	et	4	main
astuma	doc_286998102742_item	3614621	et	3	main
keskkooli	doc_286998102742_item	3614618	et	4	main
võistlus	doc_286998102742_item	3614612	et	3	main
kogu	doc_286998102742_item	3614611	et	4	main
keha	doc_286998102742_item	3614598	et	4	main
siis	doc_286998102742_item	3614597	et	3	main
intellektuaalselt	doc_286998102742_item	3614596	et	4	main
jääb	doc_286998102742_item	3614589	et	3	main
pidevalt	doc_286998102742_item	3614583	et	4	main
jääb	doc_286998102742_item	3614582	et	3	main
see	doc_286998102742_item	3614581	et	3	main
kui	doc_286998102742_item	3614580	et	3	main
vaid	doc_286998102742_item	3614579	et	3	main
väsimust	doc_286998102742_item	3614578	et	4	main
vaimset	doc_286998102742_item	3614577	et	3	main
ja	doc_286998102742_item	3614576	et	3	main
ülekoormus	doc_286998102742_item	3614570	et	3	main
laps	doc_286998102742_item	3614548	et	4	main
on	doc_286998102742_item	3614540	et	4	main
see	doc_286998102742_item	3614539	et	3	main
ja	doc_286998102742_item	3614538	et	3	main
tunne	doc_286998102742_item	3614532	et	4	main
laps	doc_286998102742_item	3614528	et	4	main
nende	doc_286998102742_item	3614527	et	4	main
kui	doc_286998102742_item	3614526	et	3	main
laiem	doc_286998102742_item	3614513	et	4	main
reformima	doc_286998102742_item	3614505	et	4	main
siin	doc_286998102742_item	3614500	et	4	main
see	doc_286998102742_item	3614496	et	3	main
kõige	doc_286998102742_item	3614483	et	4	main
oma	doc_286998102742_item	3614481	et	4	main
nad	doc_286998102742_item	3614479	et	3	main
järelikult	doc_286998102742_item	3614478	et	3	main
parem	doc_286998102742_item	3614476	et	4	main
lastele	doc_286998102742_item	3614474	et	4	main
anda	doc_286998102742_item	3614472	et	3	main
mingi	doc_286998102742_item	3614451	et	4	main
söögu	doc_286998102744_item	3614832	et	3	main
tellis	doc_286998102744_item	3614824	et	4	main
kus	doc_286998102744_item	3614823	et	3	main
naisele	doc_286998102744_item	3614812	et	3	main
oma	doc_286998102744_item	3614811	et	4	main
laseb	doc_286998102744_item	3614810	et	3	main
nii	doc_286998102744_item	3614801	et	3	main
pidi	doc_286998102744_item	3614795	et	4	main
nagu	doc_286998102744_item	3614791	et	3	main
välja	doc_286998102744_item	3614790	et	4	main
nii	doc_286998102744_item	3614789	et	3	main
näeb	doc_286998102744_item	3614788	et	3	main
köök	doc_286998102744_item	3614787	et	3	main
ja	doc_286998102744_item	3614782	et	3	main
välja	doc_286998102744_item	3614778	et	4	main
toit	doc_286998102744_item	3614772	et	3	main
ja	doc_286998102744_item	3614721	et	3	main
toolile	doc_286998102744_item	3614746	et	3	main
naisele	doc_286998102744_item	3614729	et	3	main
teeb	doc_286998102744_item	3614726	et	3	main
otsustab	doc_286998102744_item	3614723	et	3	main
mis	doc_286998102747_item	3614902	et	4	main
küüslauk	doc_286998102747_item	3614901	et	3	main
nagu	doc_286998102747_item	3614900	et	3	main
mentsuatsionieelset	doc_286998102747_item	3614877	et	4	main
piparmünt	doc_286998102747_item	3614869	et	3	main
kasulik	doc_286998102747_item	3614866	et	3	main
ravimtaime	doc_286998102747_item	3614858	et	4	main
maitsev	doc_286998102747_item	3614857	et	4	main
see	doc_286998102747_item	3614853	et	3	main
ravimtaime	doc_286998102747_item	3614843	et	4	main
populaarne	doc_286998102747_item	3614842	et	3	main
väga	doc_286998102747_item	3614841	et	3	main
essee	doc_286998102747_item	3614837	et	4	main
alles	doc_286998102752_item	3615035	et	3	main
kannab	doc_286998102742_item	3614604	et	3	main
selle	doc_286998102742_item	3614602	et	4	main
on	doc_286998102742_item	3614593	et	4	main
vastavust	doc_286998102742_item	3614569	et	4	main
otse	doc_286998102742_item	3614568	et	4	main
pole	doc_286998102742_item	3614567	et	3	main
saa	doc_286998102742_item	3614556	et	4	main
ära	doc_286998102742_item	3614537	et	4	main
jääb	doc_286998102742_item	3614536	et	3	main
laps	doc_286998102742_item	3614535	et	4	main
võib	doc_286998102742_item	3614530	et	3	main
lapsed	doc_286998102742_item	3614522	et	3	main
näevad	doc_286998102742_item	3614518	et	3	main
kui	doc_286998102742_item	3614516	et	3	main
viis	doc_286998102742_item	3614510	et	4	main
see	doc_286998102742_item	3614509	et	3	main
aga	doc_286998102742_item	3614508	et	3	main
haridussüsteeme	doc_286998102742_item	3614506	et	3	main
aastaid	doc_286998102742_item	3614503	et	4	main
ei	doc_286998102742_item	3614491	et	4	main
võistlus	doc_286998102742_item	3614490	et	3	main
kooli	doc_286998102742_item	3614485	et	4	main
otsivad	doc_286998102742_item	3614480	et	4	main
tahavad	doc_286998102742_item	3614471	et	3	main
üles	doc_286998102742_item	3614462	et	3	main
pealinna	doc_286998102742_item	3614456	et	4	main
kiirustavad	doc_286998102742_item	3614454	et	4	main
kõik	doc_286998102742_item	3614453	et	4	main
võistluses	doc_286998102742_item	3614452	et	3	main
ka	doc_286998102742_item	3614444	et	3	main
seehulgas	doc_286998102742_item	3614443	et	3	main
ungaris	doc_286998102742_item	3614442	et	4	main
kogu	doc_286998102742_item	3614441	et	4	main
aga	doc_286998102742_item	3614440	et	3	main
koolisüsteemis	doc_286998102742_item	3614439	et	3	main
vain	doc_286998102742_item	3614438	et	3	main
ole	doc_286998102742_item	3614437	et	4	main
puudused	doc_286998102742_item	3614435	et	3	main
puudused	doc_286998102742_item	3614434	et	3	main
koolisüsteeme	doc_286998102742_item	3614433	et	3	main
ei	doc_286998102742_item	3614436	et	4	main
ungari	doc_286998102742_item	3614432	et	4	main
essee	doc_286998102742_item	3614431	et	4	main
naine	doc_286998102744_item	3614831	et	3	main
tema	doc_286998102744_item	3614830	et	4	main
õhtusööki	doc_286998102744_item	3614828	et	4	main
restorandisse	doc_286998102744_item	3614822	et	4	main
ühesse	doc_286998102744_item	3614821	et	3	main
istus	doc_286998102744_item	3614820	et	4	main
ja	doc_286998102744_item	3614819	et	3	main
kiirustades	doc_286998102744_item	3614818	et	3	main
korterist	doc_286998102744_item	3614817	et	3	main
pääses	doc_286998102744_item	3614816	et	4	main
hea	doc_286998102744_item	3614802	et	4	main
ta	doc_286998102744_item	3614798	et	4	main
kogu	doc_286998102744_item	3614786	et	4	main
on	doc_286998102744_item	3614719	et	4	main
üksi	doc_286998102744_item	3614716	et	4	main
on	doc_286998102744_item	3614715	et	4	main
toivo	doc_286998102744_item	3614710	et	4	main
väikesele	doc_286998102744_item	3614745	et	4	main
ta	doc_286998102744_item	3614743	et	4	main
hakkab	doc_286998102744_item	3614740	et	3	main
lapsevanemad	doc_286998102742_item	3614470	et	4	main
sest	doc_286998102742_item	3614469	et	4	main
koolidele	doc_286998102742_item	3614468	et	3	main
ka	doc_286998102742_item	3614467	et	3	main
niisiis	doc_286998102742_item	3614466	et	3	main
ja	doc_286998102742_item	3614465	et	3	main
eriti	doc_286998102742_item	3614455	et	3	main
ungari	doc_286998102742_item	3614447	et	4	main
kogu	doc_286998102742_item	3614446	et	4	main
koolides	doc_286998102742_item	3614445	et	3	main
tahab	doc_286998102744_item	3614835	et	3	main
oma	doc_286998102744_item	3614825	et	4	main
ta	doc_286998102744_item	3614815	et	4	main
ala	doc_286998102744_item	3614814	et	4	main
köögi	doc_286998102744_item	3614813	et	3	main
kõige	doc_286998102744_item	3614805	et	4	main
ja	doc_286998102744_item	3614804	et	3	main
kokk	doc_286998102744_item	3614803	et	3	main
et	doc_286998102744_item	3614797	et	3	main
ebaõnnestunud	doc_286998102744_item	3614785	et	4	main
on	doc_286998102744_item	3614784	et	4	main
kukuvad	doc_286998102744_item	3614780	et	3	main
mida	doc_286998102744_item	3614773	et	4	main
igav	doc_286998102744_item	3614720	et	3	main
kodus	doc_286998102744_item	3614717	et	4	main
paksu	doc_286998102744_item	3614713	et	4	main
suitsetava	doc_286998102744_item	3614712	et	4	main
ja	doc_286998102744_item	3614747	et	3	main
istub	doc_286998102744_item	3614744	et	3	main
keetma	doc_286998102744_item	3614742	et	3	main
nõud	doc_286998102744_item	3614738	et	3	main
võtab	doc_286998102744_item	3614737	et	3	main
teeb	doc_286998102744_item	3614735	et	3	main
teatris	doc_286998102744_item	3614733	et	3	main
oma	doc_286998102744_item	3614728	et	4	main
ta	doc_286998102744_item	3614725	et	4	main
et	doc_286998102744_item	3614724	et	3	main
piparmünt	doc_286998102747_item	3614914	et	3	main
mõju	doc_286998102747_item	3614912	et	4	main
on	doc_286998102747_item	3614910	et	4	main
mõlemal	doc_286998102747_item	3614909	et	3	main
et	doc_286998102747_item	3614908	et	3	main
see	doc_286998102747_item	3614898	et	3	main
piparmünt	doc_286998102747_item	3614894	et	3	main
sest	doc_286998102747_item	3614874	et	4	main
on	doc_286998102747_item	3614870	et	4	main
tema	doc_286998102747_item	3614851	et	4	main
a	doc_286998102752_item	3615037	et	4	main
tulevast	doc_286998102752_item	3615022	et	4	main
lapse	doc_286998102752_item	3615021	et	4	main
eas	doc_286998102752_item	3615020	et	3	main
veel	doc_286998102752_item	3615005	et	4	main
ühiskondliku	doc_286998102752_item	3614997	et	3	main
toimu	doc_286998102752_item	3614992	et	4	main
euroopas	doc_286998102752_item	3614988	et	3	main
selektiivsem	doc_286998102752_item	3614987	et	4	main
suunas	doc_286998102752_item	3614967	et	4	main
pidevalt	doc_286998102752_item	3614960	et	4	main
rohkem	doc_286998102752_item	3614952	et	4	main
enam	doc_286998102752_item	3614946	et	4	main
kehti	doc_286998102752_item	3614945	et	4	main
õpitud	doc_286998102752_item	3614938	et	4	main
rõhutatakse	doc_286998102752_item	3614937	et	3	main
koolis	doc_286998102752_item	3614936	et	4	main
ees	doc_286998102752_item	3614935	et	4	main
kus	doc_286998102744_item	3614833	et	3	main
ja	doc_286998102744_item	3614829	et	3	main
maitsvat	doc_286998102744_item	3614827	et	4	main
endale	doc_286998102744_item	3614826	et	4	main
ta	doc_286998102744_item	3614809	et	4	main
et	doc_286998102744_item	3614808	et	3	main
on	doc_286998102744_item	3614807	et	4	main
ei	doc_286998102744_item	3614799	et	4	main
ta	doc_286998102744_item	3614794	et	4	main
sõjaplats	doc_286998102744_item	3614793	et	3	main
mingi	doc_286998102744_item	3614792	et	4	main
kõik	doc_286998102744_item	3614783	et	4	main
tal	doc_286998102744_item	3614718	et	3	main
meestele	doc_286998102744_item	3614770	et	4	main
lähe	doc_286998102744_item	3614769	et	4	main
ei	doc_286998102744_item	3614768	et	4	main
üldiselt	doc_286998102744_item	3614767	et	4	main
korraga	doc_286998102744_item	3614766	et	4	main
ühe	doc_286998102744_item	3614765	et	4	main
asja	doc_286998102744_item	3614764	et	4	main
kaks	doc_286998102744_item	3614763	et	3	main
aga	doc_286998102744_item	3614762	et	3	main
mune	doc_286998102744_item	3614761	et	4	main
toob	doc_286998102744_item	3614760	et	3	main
ja	doc_286998102744_item	3614759	et	3	main
raamatut	doc_286998102744_item	3614758	et	3	main
tähelepanelikult	doc_286998102744_item	3614757	et	4	main
loeb	doc_286998102744_item	3614756	et	3	main
ta	doc_286998102744_item	3614755	et	4	main
keeda	doc_286998102744_item	3614754	et	4	main
tainast	doc_286998102744_item	3614753	et	4	main
mingit	doc_286998102744_item	3614752	et	3	main
tahab	doc_286998102744_item	3614751	et	3	main
ta	doc_286998102744_item	3614750	et	4	main
kokaraamatut	doc_286998102744_item	3614749	et	3	main
ta	doc_286998102744_item	3614722	et	4	main
mees	doc_286998102744_item	3614714	et	4	main
see	doc_286998102744_item	3614711	et	3	main
essee	doc_286998102744_item	3614709	et	4	main
see	doc_286998102744_item	3614771	et	3	main
vaatab	doc_286998102744_item	3614748	et	3	main
vett	doc_286998102744_item	3614741	et	3	main
ja	doc_286998102744_item	3614739	et	3	main
ettevalmistusi	doc_286998102744_item	3614736	et	3	main
ta	doc_286998102744_item	3614734	et	4	main
on	doc_286998102744_item	3614731	et	4	main
kes	doc_286998102744_item	3614730	et	4	main
üllatus	doc_286998102744_item	3614727	et	4	main
siis	doc_286998102747_item	3614913	et	3	main
värskendav	doc_286998102747_item	3614897	et	4	main
naiste	doc_286998102747_item	3614872	et	3	main
tuntud	doc_286998102747_item	3614871	et	4	main
on	doc_286998102747_item	3614860	et	4	main
temal	doc_286998102747_item	3614859	et	3	main
võib-olla	doc_286998102747_item	3614855	et	3	main
maitse	doc_286998102747_item	3614852	et	4	main
tema	doc_286998102747_item	3614847	et	4	main
põhjus	doc_286998102747_item	3614845	et	4	main
võiks	doc_286998102752_item	3615034	et	4	main
ja	doc_286998102752_item	3615032	et	3	main
rohkem	doc_286998102752_item	3615006	et	4	main
vahelised	doc_286998102752_item	3615001	et	4	main
ei	doc_286998102752_item	3614991	et	4	main
ungari	doc_286998102752_item	3614983	et	4	main
et	doc_286998102752_item	3614982	et	3	main
on	doc_286998102752_item	3614980	et	4	main
probleem	doc_286998102752_item	3614979	et	3	main
et	doc_286998102752_item	3614968	et	3	main
muuta	doc_286998102752_item	3614965	et	4	main
tuleks	doc_286998102752_item	3614964	et	4	main
vaja	doc_286998102752_item	3614958	et	4	main
ka	doc_286998102752_item	3614957	et	3	main
toodetakse	doc_286998102752_item	3614950	et	3	main
ühiskonna	doc_286998102752_item	3614948	et	4	main
tänapäeva	doc_286998102752_item	3614947	et	4	main
mis	doc_286998102752_item	3614943	et	4	main
muutuste	doc_286998102752_item	3614934	et	4	main
suurte	doc_286998102752_item	3614933	et	3	main
ja	doc_286998102752_item	3614926	et	3	main
lõpuks	doc_286998102760_item	3615253	et	4	main
nädalavahetusel	doc_286998102760_item	3615248	et	4	main
prantsuse	doc_286998102760_item	3615246	et	3	main
armasta	doc_286998102760_item	3615245	et	4	main
ei	doc_286998102760_item	3615244	et	4	main
ma	doc_286998102760_item	3615243	et	3	main
aga	doc_286998102760_item	3615242	et	3	main
keeli	doc_286998102760_item	3615236	et	4	main
armastan	doc_286998102760_item	3615234	et	3	main
ja	doc_286998102760_item	3615230	et	3	main
ja	doc_286998102760_item	3615220	et	3	main
on	doc_286998102760_item	3615206	et	4	main
mul	doc_286998102760_item	3615205	et	3	main
reedel	doc_286998102760_item	3615204	et	3	main
õhtul	doc_286998102760_item	3615203	et	3	main
seitse	doc_286998102760_item	3615202	et	3	main
keele	doc_286998102760_item	3615198	et	4	main
teine	doc_286998102760_item	3615196	et	3	main
kinosse	doc_286998102760_item	3615160	et	3	main
puhkan	doc_286998102760_item	3615152	et	3	main
kolm	doc_286998102760_item	3615150	et	3	main
minna	doc_286998102760_item	3615147	et	3	main
seepärast	doc_286998102760_item	3615145	et	3	main
ei	doc_286998102760_item	3615142	et	4	main
aga	doc_286998102760_item	3615139	et	3	main
kirjandus	doc_286998102760_item	3615130	et	3	main
prantsuse	doc_286998102760_item	3615125	et	3	main
kolm	doc_286998102760_item	3615088	et	3	main
just	doc_286998102744_item	3614732	et	3	main
on	doc_286998102747_item	3614899	et	4	main
mõju	doc_286998102747_item	3614862	et	4	main
põletikuvastane	doc_286998102747_item	3614861	et	3	main
ainuke	doc_286998102747_item	3614856	et	4	main
mõju	doc_286998102747_item	3614849	et	4	main
hea	doc_286998102747_item	3614848	et	4	main
on	doc_286998102747_item	3614846	et	4	main
hommikul	doc_286998102747_item	3614920	et	3	main
kui	doc_286998102747_item	3614919	et	3	main
õhtul	doc_286998102747_item	3614918	et	3	main
nii	doc_286998102747_item	3614917	et	3	main
abikätt	doc_286998102747_item	3614916	et	3	main
annab	doc_286998102747_item	3614915	et	3	main
vastukaalune	doc_286998102747_item	3614911	et	4	main
mõttes	doc_286998102747_item	3614907	et	3	main
selles	doc_286998102747_item	3614906	et	4	main
lahendada	doc_286998102747_item	3614905	et	3	main
vererõhuprobleemide	doc_286998102747_item	3614904	et	3	main
aitab	doc_286998102747_item	3614903	et	3	main
ja	doc_286998102747_item	3614896	et	3	main
rahustab	doc_286998102747_item	3614895	et	3	main
küljed	doc_286998102747_item	3614893	et	3	main
head	doc_286998102747_item	3614892	et	4	main
veel	doc_286998102747_item	3614891	et	4	main
on	doc_286998102747_item	3614890	et	4	main
piparmündil	doc_286998102747_item	3614889	et	3	main
ajal	doc_286998102747_item	3614888	et	4	main
külmustamise	doc_286998102747_item	3614887	et	4	main
aitab	doc_286998102747_item	3614886	et	3	main
piparmünt	doc_286998102747_item	3614885	et	3	main
pingulisust	doc_286998102747_item	3614884	et	4	main
närvilisust	doc_286998102747_item	3614883	et	4	main
seotud	doc_286998102747_item	3614882	et	4	main
üleminekuajaga	doc_286998102747_item	3614881	et	3	main
leevendab	doc_286998102747_item	3614880	et	3	main
ja	doc_286998102747_item	3614879	et	3	main
valu	doc_286998102747_item	3614878	et	4	main
vähendab	doc_286998102747_item	3614876	et	3	main
see	doc_286998102747_item	3614875	et	3	main
vahel	doc_286998102747_item	3614873	et	4	main
alandamisele	doc_286998102747_item	3614868	et	4	main
palavikku	doc_286998102747_item	3614867	et	4	main
on	doc_286998102747_item	3614865	et	4	main
tee	doc_286998102747_item	3614864	et	4	main
piparmündi	doc_286998102747_item	3614863	et	3	main
on	doc_286998102747_item	3614854	et	4	main
ja	doc_286998102747_item	3614850	et	3	main
selle	doc_286998102747_item	3614844	et	4	main
on	doc_286998102747_item	3614840	et	4	main
piparmünt	doc_286998102747_item	3614839	et	3	main
piparmünt	doc_286998102747_item	3614838	et	3	main
vanuses	doc_286998102752_item	3615038	et	4	main
pakkuda	doc_286998102752_item	3615027	et	3	main
lahendus	doc_286998102752_item	3615025	et	4	main
juba	doc_286998102752_item	3615018	et	3	main
peresid	doc_286998102752_item	3615016	et	3	main
aastane	doc_286998102752_item	3615013	et	4	main
46	doc_286998102752_item	3615010	et	2	main
liigitus	doc_286998102752_item	3615009	et	4	main
koolide	doc_286998102752_item	3615008	et	3	main
praegune	doc_286998102752_item	3615007	et	3	main
erinevused	doc_286998102752_item	3615002	et	4	main
põhjal	doc_286998102752_item	3614999	et	4	main
kõige	doc_286998102752_item	3614986	et	4	main
otsida	doc_286998102752_item	3614971	et	4	main
suudavad	doc_286998102752_item	3614970	et	3	main
õpilased	doc_286998102752_item	3614969	et	3	main
selles	doc_286998102752_item	3614966	et	4	main
ennast	doc_286998102752_item	3614959	et	4	main
järjest	doc_286998102752_item	3614951	et	4	main
rohkust	doc_286998102752_item	3614942	et	4	main
koolisüsteem	doc_286998102752_item	3614930	et	3	main
ungari	doc_286998102752_item	3614929	et	4	main
halvad	doc_286998102752_item	3614927	et	4	main
essee	doc_286998102752_item	3614922	et	4	main
palju	doc_286998102760_item	3615260	et	4	main
pean	doc_286998102760_item	3615258	et	4	main
aga	doc_286998102760_item	3615256	et	3	main
kaua	doc_286998102760_item	3615252	et	3	main
ja	doc_286998102760_item	3615250	et	3	main
mule	doc_286998102760_item	3615241	et	4	main
meeldib	doc_286998102760_item	3615240	et	3	main
õppetool	doc_286998102760_item	3615239	et	3	main
aga	doc_286998102760_item	3615233	et	3	main
kodune	doc_286998102760_item	3615231	et	4	main
tundi	doc_286998102760_item	3615229	et	4	main
kell	doc_286998102760_item	3615218	et	3	main
hariduslugu	doc_286998102760_item	3615214	et	4	main
pool	doc_286998102760_item	3615201	et	4	main
eesti	doc_286998102760_item	3615197	et	4	main
kaks	doc_286998102760_item	3615192	et	3	main
ja	doc_286998102760_item	3615158	et	3	main
kohtan	doc_286998102760_item	3615156	et	3	main
enam	doc_286998102760_item	3615144	et	4	main
praegu	doc_286998102760_item	3615140	et	3	main
etnograafia	doc_286998102760_item	3615137	et	4	main
eesti	doc_286998102760_item	3615136	et	4	main
oli	doc_286998102760_item	3615135	et	3	main
seminar	doc_286998102760_item	3615127	et	3	main
loeng	doc_286998102760_item	3615098	et	3	main
esimene	doc_286998102760_item	3615097	et	3	main
ja	doc_286998102760_item	3615087	et	3	main
soome	doc_286998102760_item	3615084	et	3	main
ajalugu	doc_286998102760_item	3615082	et	4	main
loengut	doc_286998102760_item	3615079	et	3	main
on	doc_286998102760_item	3615077	et	4	main
mul	doc_286998102760_item	3615076	et	3	main
kolm	doc_286998102760_item	3615068	et	3	main
ja	doc_286998102760_item	3615060	et	3	main
on	doc_286998102760_item	3615055	et	4	main
mul	doc_286998102760_item	3615054	et	3	main
seal	doc_286998102761_item	3615364	et	4	main
ja	doc_286998102761_item	3615356	et	3	main
me	doc_286998102761_item	3615335	et	4	main
neljapäeval	doc_286998102761_item	3615334	et	3	main
said	doc_286998102761_item	3615303	et	4	main
on	doc_286998102761_item	3615298	et	4	main
kallimad	doc_286998102761_item	3615296	et	4	main
puuvili	doc_286998102761_item	3615295	et	3	main
18	doc_286998102752_item	3615036	et	2	main
eneseteostamiseks	doc_286998102752_item	3615031	et	3	main
laiu	doc_286998102752_item	3615029	et	4	main
varases	doc_286998102752_item	3615019	et	4	main
gümnaasium	doc_286998102752_item	3615014	et	3	main
8	doc_286998102752_item	3615012	et	2	main
ja	doc_286998102752_item	3615011	et	3	main
kasvavad	doc_286998102752_item	3615003	et	4	main
positsiooni	doc_286998102752_item	3614998	et	4	main
vaid	doc_286998102752_item	3614995	et	3	main
aga	doc_286998102752_item	3614993	et	3	main
eraldamine	doc_286998102752_item	3614990	et	4	main
õpilaste	doc_286998102752_item	3614989	et	4	main
selles	doc_286998102752_item	3614981	et	4	main
teine	doc_286998102752_item	3614978	et	3	main
ja	doc_286998102752_item	3614974	et	3	main
informatsiooni	doc_286998102752_item	3614973	et	4	main
iseseisvalt	doc_286998102752_item	3614972	et	4	main
õpetuse	doc_286998102752_item	3614962	et	4	main
täiendada	doc_286998102752_item	3614961	et	3	main
informatsiooni	doc_286998102752_item	3614953	et	4	main
informatsiooni	doc_286998102752_item	3614941	et	4	main
faktide	doc_286998102752_item	3614939	et	3	main
ungari	doc_286998102752_item	3614923	et	4	main
õppima	doc_286998102760_item	3615259	et	3	main
kahjuks	doc_286998102760_item	3615257	et	4	main
mitu	doc_286998102760_item	3615228	et	4	main
väga	doc_286998102760_item	3615227	et	3	main
on	doc_286998102760_item	3615226	et	4	main
mul	doc_286998102760_item	3615225	et	3	main
koju	doc_286998102760_item	3615224	et	3	main
lähen	doc_286998102760_item	3615223	et	3	main
ainult	doc_286998102760_item	3615207	et	4	main
lõpeb	doc_286998102760_item	3615200	et	4	main
seminarit	doc_286998102760_item	3615195	et	4	main
keele	doc_286998102760_item	3615194	et	4	main
otsustada	doc_286998102752_item	3615033	et	3	main
võimalusi	doc_286998102752_item	3615030	et	3	main
õpilastele	doc_286998102752_item	3615028	et	4	main
oleks	doc_286998102752_item	3615026	et	3	main
ideaalne	doc_286998102752_item	3615024	et	3	main
tegevusala	doc_286998102752_item	3615023	et	4	main
otsustama	doc_286998102752_item	3615017	et	3	main
sunnib	doc_286998102752_item	3615015	et	3	main
koolis	doc_286998102752_item	3615004	et	4	main
tasete	doc_286998102752_item	3615000	et	4	main
rohkem	doc_286998102752_item	3614996	et	4	main
teadustase	doc_286998102752_item	3614994	et	3	main
on	doc_286998102752_item	3614985	et	4	main
koolisüsteem	doc_286998102752_item	3614984	et	3	main
praktiliselt	doc_286998102752_item	3614977	et	4	main
seda	doc_286998102752_item	3614976	et	3	main
rakendada	doc_286998102752_item	3614975	et	3	main
sisu	doc_286998102752_item	3614963	et	4	main
on	doc_286998102752_item	3614956	et	4	main
täiskasvanutel	doc_286998102752_item	3614955	et	3	main
ja	doc_286998102752_item	3614954	et	3	main
kus	doc_286998102752_item	3614949	et	3	main
ei	doc_286998102752_item	3614944	et	4	main
ja	doc_286998102752_item	3614940	et	3	main
seisab	doc_286998102752_item	3614931	et	3	main
küljed	doc_286998102752_item	3614928	et	3	main
head	doc_286998102752_item	3614925	et	4	main
koolisüsteemi	doc_286998102752_item	3614924	et	4	main
praegu	doc_286998102752_item	3614932	et	3	main
kohtan	doc_286998102760_item	3615254	et	3	main
keelt	doc_286998102760_item	3615247	et	4	main
soome-ugri	doc_286998102760_item	3615238	et	3	main
lõpuks	doc_286998102760_item	3615222	et	4	main
lõpeb	doc_286998102760_item	3615217	et	4	main
loeng	doc_286998102760_item	3615216	et	3	main
tund	doc_286998102760_item	3615199	et	3	main
eesti	doc_286998102760_item	3615193	et	4	main
ja	doc_286998102760_item	3615191	et	3	main
fagotit	doc_286998102760_item	3615190	et	4	main
mängin	doc_286998102760_item	3615189	et	3	main
muusika	doc_286998102760_item	3615188	et	4	main
loeng	doc_286998102760_item	3615187	et	3	main
kirjandus	doc_286998102760_item	3615186	et	3	main
prantsuse	doc_286998102760_item	3615185	et	3	main
sõpra	doc_286998102760_item	3615157	et	4	main
õhtul	doc_286998102760_item	3615155	et	3	main
kodus	doc_286998102760_item	3615151	et	4	main
kell	doc_286998102760_item	3615149	et	3	main
ole	doc_286998102760_item	3615143	et	4	main
see	doc_286998102760_item	3615141	et	3	main
seminar	doc_286998102760_item	3615138	et	3	main
prantsuse	doc_286998102760_item	3615129	et	3	main
prantsuse	doc_286998102760_item	3615122	et	3	main
mul	doc_286998102760_item	3615120	et	3	main
seminarit	doc_286998102760_item	3615089	et	4	main
soome	doc_286998102760_item	3615081	et	3	main
kolm	doc_286998102760_item	3615078	et	3	main
väsinud	doc_286998102760_item	3615074	et	4	main
alati	doc_286998102760_item	3615073	et	4	main
olen	doc_286998102760_item	3615072	et	3	main
ma	doc_286998102760_item	3615071	et	3	main
seepärast	doc_286998102760_item	3615070	et	3	main
budapestis	doc_286998102760_item	3615053	et	4	main
ja	doc_286998102761_item	3615376	et	3	main
linnad	doc_286998102761_item	3615374	et	3	main
kana	doc_286998102761_item	3615372	et	4	main
harva	doc_286998102761_item	3615363	et	4	main
on	doc_286998102761_item	3615362	et	4	main
see	doc_286998102761_item	3615361	et	3	main
minu	doc_286998102761_item	3615354	et	3	main
riie	doc_286998102761_item	3615353	et	3	main
töötab	doc_286998102761_item	3615344	et	3	main
õde	doc_286998102761_item	3615341	et	4	main
siis	doc_286998102761_item	3615338	et	3	main
ole	doc_286998102761_item	3615337	et	4	main
minu	doc_286998102761_item	3615328	et	3	main
ma	doc_286998102761_item	3615325	et	3	main
kapsast	doc_286998102761_item	3615323	et	4	main
sibulat	doc_286998102761_item	3615322	et	3	main
õuna	doc_286998102761_item	3615321	et	4	main
koogisse	doc_286998102761_item	3615320	et	3	main
sidrunit	doc_286998102761_item	3615319	et	3	main
viinamarja	doc_286998102761_item	3615318	et	4	main
ostan	doc_286998102761_item	3615317	et	3	main
sealt	doc_286998102761_item	3615316	et	4	main
marjad	doc_286998102761_item	3615315	et	3	main
ja	doc_286998102761_item	3615314	et	3	main
puuviljad	doc_286998102761_item	3615313	et	3	main
aedviljad	doc_286998102761_item	3615312	et	3	main
ja	doc_286998102761_item	3615302	et	3	main
suuremas	doc_286998102761_item	3615290	et	4	main
sõpra	doc_286998102760_item	3615255	et	4	main
magan	doc_286998102760_item	3615251	et	3	main
puhkan	doc_286998102760_item	3615249	et	3	main
ja	doc_286998102760_item	3615237	et	3	main
õppida	doc_286998102760_item	3615235	et	3	main
ülesast	doc_286998102760_item	3615232	et	3	main
pärast	doc_286998102760_item	3615221	et	4	main
üks	doc_286998102760_item	3615219	et	3	main
see	doc_286998102760_item	3615215	et	3	main
soome	doc_286998102760_item	3615213	et	3	main
ja	doc_286998102760_item	3615212	et	3	main
keel	doc_286998102760_item	3615211	et	4	main
soome	doc_286998102760_item	3615210	et	3	main
seminarit	doc_286998102760_item	3615209	et	4	main
kaks	doc_286998102760_item	3615208	et	3	main
keel	doc_286998102760_item	3615184	et	4	main
soome	doc_286998102760_item	3615183	et	3	main
tundi	doc_286998102760_item	3615182	et	4	main
mitu	doc_286998102760_item	3615181	et	4	main
on	doc_286998102760_item	3615180	et	4	main
mul	doc_286998102760_item	3615179	et	3	main
ka	doc_286998102760_item	3615178	et	3	main
neljapäeval	doc_286998102760_item	3615177	et	3	main
keeleteadust	doc_286998102760_item	3615176	et	4	main
armasta	doc_286998102760_item	3615175	et	4	main
ei	doc_286998102760_item	3615174	et	4	main
ma	doc_286998102760_item	3615173	et	3	main
prantsuse	doc_286998102760_item	3615171	et	3	main
on	doc_286998102760_item	3615170	et	4	main
keeleteadus	doc_286998102760_item	3615172	et	4	main
mul	doc_286998102760_item	3615169	et	3	main
lõunal	doc_286998102760_item	3615168	et	3	main
ja	doc_286998102760_item	3615167	et	3	main
keeletundi	doc_286998102760_item	3615166	et	4	main
eesti	doc_286998102760_item	3615165	et	4	main
kaks	doc_286998102760_item	3615164	et	3	main
on	doc_286998102760_item	3615163	et	4	main
mul	doc_286998102760_item	3615162	et	3	main
kolmapäeval	doc_286998102760_item	3615161	et	3	main
läheme	doc_286998102760_item	3615159	et	3	main
natuke	doc_286998102760_item	3615153	et	4	main
viis	doc_286998102760_item	3615134	et	4	main
kell	doc_286998102760_item	3615133	et	3	main
õhtul	doc_286998102760_item	3615132	et	3	main
seminar	doc_286998102760_item	3615131	et	3	main
minu	doc_286998102760_item	3615041	et	3	main
keele	doc_286998102760_item	3615126	et	4	main
luuletusõpetus	doc_286998102760_item	3615123	et	3	main
teisipäeval	doc_286998102760_item	3615119	et	3	main
eesti	doc_286998102760_item	3615095	et	4	main
ja	doc_286998102760_item	3615094	et	3	main
loeng	doc_286998102760_item	3615086	et	3	main
eriala	doc_286998102760_item	3615069	et	4	main
on	doc_286998102760_item	3615065	et	4	main
eksamit	doc_286998102760_item	3615064	et	3	main
mitu	doc_286998102760_item	3615063	et	4	main
tundi	doc_286998102760_item	3615059	et	4	main
on	doc_286998102761_item	3615365	et	4	main
laata	doc_286998102761_item	3615359	et	4	main
ma	doc_286998102761_item	3615357	et	3	main
ja	doc_286998102760_item	3615154	et	3	main
koju	doc_286998102760_item	3615148	et	3	main
saan	doc_286998102760_item	3615146	et	4	main
essee	doc_286998102760_item	3615040	et	4	main
ja	doc_286998102760_item	3615128	et	3	main
loeng	doc_286998102760_item	3615124	et	3	main
on	doc_286998102760_item	3615121	et	4	main
mule	doc_286998102760_item	3615118	et	4	main
fagotti	doc_286998102760_item	3615117	et	4	main
õpetab	doc_286998102760_item	3615116	et	3	main
kes	doc_286998102760_item	3615115	et	4	main
tüdrukule	doc_286998102760_item	3615114	et	3	main
keelt	doc_286998102760_item	3615113	et	4	main
prantsuse	doc_286998102760_item	3615112	et	3	main
õpetan	doc_286998102760_item	3615111	et	3	main
seitse	doc_286998102760_item	3615110	et	3	main
veerand	doc_286998102760_item	3615109	et	4	main
aga	doc_286998102760_item	3615108	et	3	main
õhtul	doc_286998102760_item	3615107	et	3	main
kuus	doc_286998102760_item	3615106	et	4	main
kell	doc_286998102760_item	3615105	et	3	main
lõpeb	doc_286998102760_item	3615104	et	4	main
viimane	doc_286998102760_item	3615103	et	3	main
ja	doc_286998102760_item	3615102	et	3	main
pool	doc_286998102760_item	3615100	et	4	main
algab	doc_286998102760_item	3615099	et	3	main
üheksa	doc_286998102760_item	3615101	et	4	main
maatundmine	doc_286998102760_item	3615096	et	3	main
keel	doc_286998102760_item	3615093	et	4	main
soome	doc_286998102760_item	3615092	et	3	main
ja	doc_286998102760_item	3615091	et	3	main
laplane	doc_286998102760_item	3615090	et	3	main
kirjanduse	doc_286998102760_item	3615085	et	3	main
ja	doc_286998102760_item	3615083	et	3	main
soome-ugri	doc_286998102760_item	3615080	et	3	main
esmaspäeval	doc_286998102760_item	3615075	et	3	main
tegema	doc_286998102760_item	3615067	et	3	main
raske	doc_286998102760_item	3615066	et	4	main
otsas	doc_286998102760_item	3615062	et	4	main
on	doc_286998102761_item	3615371	et	4	main
seal	doc_286998102761_item	3615370	et	4	main
loomad	doc_286998102761_item	3615369	et	3	main
ja	doc_286998102761_item	3615368	et	3	main
asjad	doc_286998102761_item	3615367	et	3	main
magustoidud	doc_286998102761_item	3615366	et	3	main
kahjuks	doc_286998102761_item	3615360	et	4	main
õde	doc_286998102761_item	3615355	et	4	main
ja	doc_286998102761_item	3615352	et	3	main
ei	doc_286998102761_item	3615336	et	4	main
ei	doc_286998102761_item	3615330	et	4	main
ja	doc_286998102761_item	3615326	et	3	main
on	doc_286998102761_item	3615309	et	4	main
poes	doc_286998102761_item	3615308	et	3	main
joogid	doc_286998102761_item	3615306	et	4	main
ja	doc_286998102761_item	3615305	et	3	main
eriti	doc_286998102761_item	3615300	et	3	main
toit	doc_286998102761_item	3615299	et	3	main
poodi	doc_286998102761_item	3615289	et	4	main
saia	doc_286998102761_item	3615275	et	4	main
poes	doc_286998102761_item	3615270	et	3	main
ma	doc_286998102761_item	3615268	et	3	main
laupäeva	doc_286998102761_item	3615266	et	4	main
pool	doc_286998102762_item	3615545	et	4	main
ja	doc_286998102762_item	3615540	et	3	main
on	doc_286998102762_item	3615523	et	4	main
ma	doc_286998102762_item	3615518	et	3	main
tavaliselt	doc_286998102762_item	3615506	et	4	main
raamatukogus	doc_286998102762_item	3615504	et	4	main
vaba	doc_286998102762_item	3615500	et	4	main
ometi	doc_286998102762_item	3615499	et	3	main
lõpuks	doc_286998102762_item	3615498	et	4	main
olen	doc_286998102762_item	3615497	et	3	main
ma	doc_286998102762_item	3615496	et	3	main
hea	doc_286998102762_item	3615490	et	4	main
sellepärast	doc_286998102762_item	3615489	et	3	main
tundi	doc_286998102762_item	3615485	et	4	main
eesti	doc_286998102762_item	3615483	et	4	main
kaks	doc_286998102762_item	3615482	et	3	main
pool	doc_286998102762_item	3615471	et	4	main
nädal	doc_286998102762_item	3615385	et	3	main
kirjanduse	doc_286998102762_item	3615449	et	3	main
kolm	doc_286998102762_item	3615447	et	3	main
lähen	doc_286998102762_item	3615443	et	3	main
ma	doc_286998102762_item	3615442	et	3	main
päeval	doc_286998102762_item	3615441	et	3	main
sellel	doc_286998102762_item	3615440	et	4	main
aga	doc_286998102762_item	3615439	et	3	main
õppima	doc_286998102762_item	3615438	et	3	main
ja	doc_286998102762_item	3615437	et	3	main
kaheksa	doc_286998102762_item	3615414	et	4	main
lõpeb	doc_286998102762_item	3615412	et	4	main
üheksa	doc_286998102762_item	3615407	et	4	main
tund	doc_286998102762_item	3615404	et	3	main
sõnad	doc_286998102763_item	3615689	et	4	main
pean	doc_286998102763_item	3615681	et	4	main
ma	doc_286998102763_item	3615680	et	3	main
olen	doc_286998102763_item	3615671	et	3	main
nädalavahetusel	doc_286998102763_item	3615669	et	4	main
või	doc_286998102763_item	3615657	et	4	main
ja	doc_286998102763_item	3615650	et	3	main
eesti	doc_286998102763_item	3615642	et	4	main
soome	doc_286998102763_item	3615638	et	3	main
koju	doc_286998102763_item	3615608	et	3	main
ma	doc_286998102763_item	3615606	et	3	main
see	doc_286998102763_item	3615604	et	3	main
kümme	doc_286998102763_item	3615567	et	3	main
minu	doc_286998102763_item	3615551	et	3	main
hommikusööki	doc_286998102764_item	3615713	et	4	main
semestri	doc_286998102760_item	3615061	et	3	main
ja	doc_286998102760_item	3615058	et	3	main
loengut	doc_286998102760_item	3615057	et	3	main
mitu	doc_286998102760_item	3615056	et	4	main
ülikoolis	doc_286998102760_item	3615052	et	4	main
lorandi	doc_286998102760_item	3615051	et	4	main
eötvös	doc_286998102760_item	3615050	et	4	main
keelt	doc_286998102760_item	3615049	et	4	main
eesti	doc_286998102760_item	3615048	et	4	main
ja	doc_286998102760_item	3615047	et	3	main
soome	doc_286998102760_item	3615046	et	3	main
prantsuse	doc_286998102760_item	3615045	et	3	main
õpin	doc_286998102760_item	3615044	et	3	main
ma	doc_286998102760_item	3615043	et	3	main
nädal	doc_286998102760_item	3615042	et	3	main
inimeest	doc_286998102761_item	3615381	et	4	main
mitu	doc_286998102761_item	3615380	et	4	main
on	doc_286998102761_item	3615379	et	4	main
seal	doc_286998102761_item	3615378	et	4	main
koerad	doc_286998102761_item	3615377	et	3	main
kassid	doc_286998102761_item	3615375	et	3	main
siga	doc_286998102761_item	3615373	et	4	main
armastame	doc_286998102761_item	3615358	et	3	main
toit	doc_286998102761_item	3615351	et	3	main
on	doc_286998102761_item	3615349	et	4	main
aga	doc_286998102761_item	3615347	et	3	main
ma	doc_286998102761_item	3615345	et	3	main
ja	doc_286998102761_item	3615342	et	3	main
minu	doc_286998102761_item	3615340	et	3	main
vabad	doc_286998102761_item	3615339	et	3	main
osta	doc_286998102761_item	3615331	et	4	main
ja	doc_286998102761_item	3615311	et	3	main
piimasaadused	doc_286998102761_item	3615301	et	3	main
mitu	doc_286998102761_item	3615288	et	4	main
külas	doc_286998102761_item	3615286	et	3	main
minu	doc_286998102761_item	3615285	et	3	main
juustu	doc_286998102761_item	3615284	et	4	main
ja	doc_286998102761_item	3615283	et	3	main
hapukoort	doc_286998102761_item	3615282	et	3	main
šokolaadi	doc_286998102761_item	3615281	et	2	main
ma	doc_286998102761_item	3615271	et	3	main
ja	doc_286998102761_item	3615264	et	3	main
ma	doc_286998102762_item	3615542	et	3	main
esmaspäev	doc_286998102762_item	3615538	et	3	main
teha	doc_286998102762_item	3615532	et	3	main
koristada	doc_286998102762_item	3615530	et	3	main
kodus	doc_286998102762_item	3615525	et	4	main
nädalavahetusel	doc_286998102762_item	3615521	et	4	main
loen	doc_286998102762_item	3615519	et	3	main
ja	doc_286998102762_item	3615517	et	3	main
väga	doc_286998102762_item	3615512	et	3	main
kodus	doc_286998102762_item	3615509	et	4	main
olen	doc_286998102762_item	3615508	et	3	main
ole	doc_286998102762_item	3615494	et	4	main
on	doc_286998102762_item	3615481	et	4	main
mul	doc_286998102762_item	3615480	et	3	main
neljapäev	doc_286998102762_item	3615479	et	3	main
seitse	doc_286998102762_item	3615478	et	3	main
kell	doc_286998102762_item	3615477	et	3	main
essee	doc_286998102762_item	3615383	et	4	main
ei	doc_286998102762_item	3615452	et	4	main
koju	doc_286998102762_item	3615445	et	3	main
vara	doc_286998102762_item	3615444	et	4	main
pean	doc_286998102762_item	3615434	et	4	main
kümme	doc_286998102762_item	3615428	et	3	main
algab	doc_286998102762_item	3615426	et	3	main
tundi	doc_286998102762_item	3615424	et	4	main
mul	doc_286998102762_item	3615421	et	3	main
teisipäeval	doc_286998102762_item	3615420	et	3	main
õhtul	doc_286998102762_item	3615415	et	3	main
rahvatantsud	doc_286998102762_item	3615411	et	3	main
viimane	doc_286998102762_item	3615408	et	3	main
pool	doc_286998102762_item	3615406	et	4	main
algab	doc_286998102762_item	3615405	et	3	main
praktikumi	doc_286998102762_item	3615402	et	4	main
kolm	doc_286998102762_item	3615401	et	3	main
lähen	doc_286998102763_item	3615693	et	3	main
koristana	doc_286998102763_item	3615682	et	4	main
jos	doc_286998102763_item	3615662	et	4	main
loengud	doc_286998102763_item	3615661	et	3	main
kaks	doc_286998102763_item	3615660	et	3	main
on	doc_286998102763_item	3615655	et	4	main
mul	doc_286998102763_item	3615654	et	3	main
reedel	doc_286998102763_item	3615653	et	3	main
olen	doc_286998102763_item	3615647	et	3	main
neli	doc_286998102763_item	3615641	et	3	main
ja	doc_286998102763_item	3615609	et	3	main
lõpeb	doc_286998102763_item	3615605	et	4	main
jos	doc_286998102763_item	3615603	et	4	main
tunnile	doc_286998102763_item	3615602	et	3	main
kell	doc_286998102763_item	3615578	et	3	main
algab	doc_286998102763_item	3615577	et	3	main
maaoskus	doc_286998102763_item	3615576	et	3	main
eesti	doc_286998102763_item	3615575	et	4	main
siis	doc_286998102763_item	3615568	et	3	main
lõpeb	doc_286998102763_item	3615565	et	4	main
loeng	doc_286998102763_item	3615564	et	3	main
asjad	doc_286998102761_item	3615350	et	3	main
turul	doc_286998102761_item	3615348	et	3	main
õpin	doc_286998102761_item	3615346	et	3	main
ema	doc_286998102761_item	3615343	et	4	main
on	doc_286998102761_item	3615333	et	4	main
turg	doc_286998102761_item	3615332	et	3	main
pere	doc_286998102761_item	3615329	et	4	main
ka	doc_286998102761_item	3615327	et	3	main
turult	doc_286998102761_item	3615324	et	3	main
juur-	doc_286998102761_item	3615310	et	3	main
vaiksemas	doc_286998102761_item	3615307	et	4	main
leivad	doc_286998102761_item	3615304	et	3	main
seal	doc_286998102761_item	3615297	et	4	main
kartul	doc_286998102761_item	3615293	et	3	main
muna	doc_286998102761_item	3615279	et	4	main
kümme	doc_286998102761_item	3615278	et	3	main
vorsti	doc_286998102761_item	3615277	et	4	main
margariini	doc_286998102761_item	3615276	et	4	main
ostan	doc_286998102761_item	3615272	et	3	main
poes	doc_286998102761_item	3615265	et	3	main
pean	doc_286998102762_item	3615543	et	4	main
ka	doc_286998102762_item	3615524	et	3	main
ma	doc_286998102762_item	3615515	et	3	main
väga	doc_286998102762_item	3615513	et	3	main
magab	doc_286998102762_item	3615511	et	3	main
ma	doc_286998102762_item	3615510	et	3	main
ma	doc_286998102762_item	3615507	et	3	main
lähen	doc_286998102762_item	3615503	et	3	main
ei	doc_286998102762_item	3615493	et	4	main
mul	doc_286998102762_item	3615492	et	3	main
reeda	doc_286998102762_item	3615491	et	4	main
keelt	doc_286998102762_item	3615484	et	4	main
esmaspäev	doc_286998102762_item	3615386	et	3	main
ma	doc_286998102762_item	3615451	et	3	main
ma	doc_286998102762_item	3615433	et	3	main
ma	doc_286998102762_item	3615430	et	3	main
praktikum	doc_286998102762_item	3615425	et	3	main
neli	doc_286998102762_item	3615423	et	3	main
kell	doc_286998102762_item	3615413	et	3	main
tund	doc_286998102762_item	3615409	et	3	main
ja	doc_286998102761_item	3615294	et	3	main
on	doc_286998102761_item	3615292	et	4	main
poes	doc_286998102761_item	3615291	et	3	main
on	doc_286998102761_item	3615287	et	4	main
mitu	doc_286998102761_item	3615280	et	4	main
tavaliselt	doc_286998102761_item	3615273	et	4	main
lähen	doc_286998102761_item	3615269	et	3	main
kartulit	doc_286998102761_item	3615274	et	3	main
hommikul	doc_286998102761_item	3615267	et	3	main
turul	doc_286998102761_item	3615263	et	3	main
essee	doc_286998102761_item	3615262	et	4	main
teisipäev	doc_286998102762_item	3615539	et	3	main
nädalavahetust	doc_286998102762_item	3615537	et	4	main
ma	doc_286998102762_item	3615535	et	3	main
minul	doc_286998102762_item	3615528	et	3	main
ma	doc_286998102762_item	3615526	et	3	main
tundi	doc_286998102762_item	3615495	et	4	main
pärastlõunal	doc_286998102762_item	3615488	et	3	main
need	doc_286998102762_item	3615486	et	3	main
tundi	doc_286998102762_item	3615475	et	4	main
viimane	doc_286998102762_item	3615474	et	3	main
minu	doc_286998102762_item	3615473	et	3	main
üheksa	doc_286998102762_item	3615472	et	4	main
tõusen	doc_286998102762_item	3615388	et	3	main
viis	doc_286998102762_item	3615546	et	4	main
tõusma	doc_286998102762_item	3615544	et	3	main
kolmapäev	doc_286998102762_item	3615541	et	3	main
armastan	doc_286998102762_item	3615536	et	3	main
tegema	doc_286998102762_item	3615534	et	3	main
sisseoste	doc_286998102762_item	3615533	et	3	main
süüa	doc_286998102762_item	3615531	et	3	main
emal	doc_286998102762_item	3615529	et	3	main
aita	doc_286998102762_item	3615527	et	4	main
ma	doc_286998102762_item	3615522	et	3	main
raamatut	doc_286998102762_item	3615520	et	3	main
puhkan	doc_286998102762_item	3615516	et	3	main
palju	doc_286998102762_item	3615514	et	4	main
aga	doc_286998102762_item	3615505	et	3	main
ma	doc_286998102762_item	3615502	et	3	main
mõnikord	doc_286998102762_item	3615501	et	3	main
on	doc_286998102762_item	3615487	et	4	main
lõpeb	doc_286998102762_item	3615476	et	4	main
algab	doc_286998102762_item	3615470	et	3	main
tund	doc_286998102762_item	3615469	et	3	main
esimene	doc_286998102762_item	3615468	et	3	main
minu	doc_286998102762_item	3615467	et	3	main
vara	doc_286998102762_item	3615466	et	4	main
tõusen	doc_286998102762_item	3615465	et	3	main
ma	doc_286998102762_item	3615464	et	3	main
kolm	doc_286998102762_item	3615462	et	3	main
ja	doc_286998102762_item	3615461	et	3	main
loengut	doc_286998102762_item	3615460	et	3	main
kaks	doc_286998102762_item	3615459	et	3	main
ja	doc_286998102762_item	3615400	et	3	main
loeng	doc_286998102762_item	3615399	et	3	main
praktikumi	doc_286998102762_item	3615463	et	4	main
üks	doc_286998102762_item	3615398	et	3	main
on	doc_286998102762_item	3615397	et	4	main
mul	doc_286998102762_item	3615396	et	3	main
päeval	doc_286998102762_item	3615395	et	3	main
sellel	doc_286998102762_item	3615394	et	4	main
minema	doc_286998102762_item	3615393	et	3	main
ülikoolisse	doc_286998102762_item	3615392	et	4	main
pean	doc_286998102762_item	3615391	et	4	main
ma	doc_286998102762_item	3615390	et	3	main
vara	doc_286998102762_item	3615389	et	4	main
ma	doc_286998102762_item	3615387	et	3	main
tundi	doc_286998102762_item	3615458	et	4	main
viis	doc_286998102762_item	3615457	et	4	main
on	doc_286998102762_item	3615456	et	4	main
mul	doc_286998102762_item	3615455	et	3	main
kolmapäev	doc_286998102762_item	3615454	et	3	main
loengul	doc_286998102762_item	3615450	et	3	main
ungari	doc_286998102762_item	3615448	et	4	main
pool	doc_286998102762_item	3615446	et	4	main
palju	doc_286998102762_item	3615435	et	4	main
olen	doc_286998102762_item	3615431	et	3	main
hommikul	doc_286998102762_item	3615429	et	3	main
kell	doc_286998102762_item	3615427	et	3	main
on	doc_286998102762_item	3615422	et	4	main
väsinud	doc_286998102762_item	3615419	et	4	main
väga	doc_286998102762_item	3615418	et	3	main
olen	doc_286998102762_item	3615417	et	3	main
ma	doc_286998102762_item	3615416	et	3	main
minu	doc_286998102762_item	3615384	et	3	main
käi	doc_286998102762_item	3615453	et	4	main
lugema	doc_286998102762_item	3615436	et	4	main
raamatukogus	doc_286998102762_item	3615432	et	4	main
esimene	doc_286998102762_item	3615403	et	3	main
õhtul	doc_286998102763_item	3615691	et	3	main
oma	doc_286998102763_item	3615683	et	4	main
magan	doc_286998102763_item	3615674	et	3	main
või	doc_286998102763_item	3615667	et	4	main
loen	doc_286998102763_item	3615666	et	3	main
magan	doc_286998102763_item	3615665	et	3	main
kodus	doc_286998102763_item	3615664	et	4	main
olen	doc_286998102763_item	3615663	et	3	main
olen	doc_286998102763_item	3615651	et	3	main
kaua	doc_286998102763_item	3615649	et	3	main
õhtul	doc_286998102763_item	3615645	et	3	main
keele	doc_286998102763_item	3615643	et	4	main
soome	doc_286998102763_item	3615600	et	3	main
siis	doc_286998102763_item	3615598	et	3	main
keele	doc_286998102763_item	3615596	et	4	main
on	doc_286998102763_item	3615594	et	4	main
mul	doc_286998102763_item	3615593	et	3	main
hommikul	doc_286998102763_item	3615592	et	3	main
teisipäeval	doc_286998102763_item	3615591	et	3	main
õpin	doc_286998102763_item	3615590	et	3	main
ja	doc_286998102763_item	3615589	et	3	main
kodus	doc_286998102763_item	3615588	et	4	main
olen	doc_286998102763_item	3615587	et	3	main
ma	doc_286998102763_item	3615586	et	3	main
õhtul	doc_286998102763_item	3615585	et	3	main
keel	doc_286998102763_item	3615584	et	4	main
soome	doc_286998102763_item	3615583	et	3	main
on	doc_286998102763_item	3615582	et	4	main
tundi	doc_286998102763_item	3615581	et	4	main
kolmas	doc_286998102763_item	3615580	et	3	main
kolm	doc_286998102763_item	3615579	et	3	main
eesti	doc_286998102762_item	3615410	et	4	main
tantsimajase	doc_286998102763_item	3615694	et	4	main
vahest	doc_286998102763_item	3615692	et	4	main
õppima	doc_286998102763_item	3615687	et	3	main
hea	doc_286998102763_item	3615678	et	4	main
on	doc_286998102763_item	3615677	et	4	main
see	doc_286998102763_item	3615676	et	3	main
kaua	doc_286998102763_item	3615675	et	3	main
laupäeval	doc_286998102763_item	3615673	et	3	main
on	doc_286998102763_item	3615659	et	4	main
mul	doc_286998102763_item	3615658	et	3	main
väsinud	doc_286998102763_item	3615652	et	4	main
ülikoolis	doc_286998102763_item	3615648	et	4	main
ma	doc_286998102763_item	3615646	et	3	main
tunnid	doc_286998102763_item	3615644	et	3	main
keelele	doc_286998102763_item	3615601	et	4	main
tund	doc_286998102763_item	3615597	et	3	main
on	doc_286998102763_item	3615570	et	4	main
mul	doc_286998102763_item	3615569	et	3	main
kell	doc_286998102763_item	3615566	et	3	main
üheksa	doc_286998102763_item	3615558	et	4	main
esmaspäeval	doc_286998102763_item	3615554	et	3	main
esimene	doc_286998102763_item	3615552	et	3	main
minu	doc_286998102763_item	3615549	et	3	main
kell	doc_286998102764_item	3615708	et	3	main
kuldne	doc_286998102764_item	3615798	et	3	main
ta	doc_286998102764_item	3615780	et	4	main
läheb	doc_286998102764_item	3615779	et	3	main
sööki	doc_286998102764_item	3615778	et	4	main
enamikul	doc_286998102764_item	3615771	et	3	main
puhkab	doc_286998102764_item	3615766	et	3	main
ja	doc_286998102764_item	3615764	et	3	main
kohtab	doc_286998102764_item	3615755	et	3	main
tal	doc_286998102764_item	3615744	et	3	main
siduma	doc_286998102764_item	3615743	et	3	main
kellegagi	doc_286998102764_item	3615742	et	4	main
ennast	doc_286998102764_item	3615741	et	4	main
taha	doc_286998102764_item	3615740	et	4	main
ei	doc_286998102764_item	3615739	et	4	main
ta	doc_286998102764_item	3615738	et	4	main
aga	doc_286998102764_item	3615737	et	3	main
naist	doc_286998102764_item	3615736	et	3	main
ole	doc_286998102764_item	3615735	et	4	main
ei	doc_286998102764_item	3615734	et	4	main
tal	doc_286998102764_item	3615733	et	3	main
kaarte	doc_286998102764_item	3615732	et	4	main
mängib	doc_286998102764_item	3615731	et	3	main
ja	doc_286998102764_item	3615730	et	3	main
kõrtsisse	doc_286998102764_item	3615729	et	3	main
pühapäeval	doc_286998102763_item	3615690	et	3	main
mitu	doc_286998102763_item	3615688	et	4	main
pean	doc_286998102763_item	3615686	et	4	main
ma	doc_286998102763_item	3615685	et	3	main
tuba	doc_286998102763_item	3615684	et	4	main
pühapäeval	doc_286998102763_item	3615679	et	3	main
kodus	doc_286998102763_item	3615672	et	4	main
ma	doc_286998102763_item	3615670	et	3	main
õpin	doc_286998102763_item	3615668	et	3	main
vaba	doc_286998102763_item	3615656	et	4	main
ja	doc_286998102763_item	3615640	et	3	main
keele	doc_286998102763_item	3615639	et	4	main
kolm	doc_286998102763_item	3615637	et	3	main
on	doc_286998102763_item	3615636	et	4	main
siis	doc_286998102763_item	3615635	et	3	main
tunnid	doc_286998102763_item	3615634	et	3	main
kolme	doc_286998102763_item	3615633	et	4	main
pidab	doc_286998102763_item	3615632	et	4	main
see	doc_286998102763_item	3615631	et	3	main
loeng	doc_286998102763_item	3615630	et	3	main
taani	doc_286998102763_item	3615629	et	4	main
teine	doc_286998102763_item	3615628	et	3	main
minu	doc_286998102763_item	3615627	et	3	main
on	doc_286998102763_item	3615626	et	4	main
hommikul	doc_286998102763_item	3615625	et	3	main
neljapäeval	doc_286998102763_item	3615624	et	3	main
tööma	doc_286998102763_item	3615623	et	4	main
harjutused	doc_286998102763_item	3615622	et	4	main
mitu	doc_286998102763_item	3615621	et	4	main
on	doc_286998102763_item	3615620	et	4	main
mul	doc_286998102763_item	3615619	et	3	main
mut	doc_286998102763_item	3615618	et	4	main
tunnid	doc_286998102763_item	3615617	et	3	main
keele	doc_286998102763_item	3615616	et	4	main
eesti	doc_286998102763_item	3615615	et	4	main
ainult	doc_286998102763_item	3615614	et	4	main
on	doc_286998102763_item	3615613	et	4	main
mul	doc_286998102763_item	3615612	et	3	main
kolmapäeval	doc_286998102763_item	3615611	et	3	main
õpin	doc_286998102763_item	3615610	et	3	main
lähen	doc_286998102763_item	3615607	et	3	main
lähen	doc_286998102763_item	3615599	et	3	main
taani	doc_286998102763_item	3615595	et	4	main
on	doc_286998102763_item	3615574	et	4	main
loeng	doc_286998102763_item	3615573	et	3	main
teine	doc_286998102763_item	3615572	et	3	main
on	doc_286998102763_item	3615560	et	4	main
see	doc_286998102763_item	3615559	et	3	main
kell	doc_286998102763_item	3615556	et	3	main
tundi	doc_286998102763_item	3615553	et	4	main
nädal	doc_286998102763_item	3615550	et	3	main
essee	doc_286998102763_item	3615548	et	4	main
sööb	doc_286998102764_item	3615711	et	3	main
liblikal	doc_286998102764_item	3615699	et	3	main
päev	doc_286998102764_item	3615698	et	3	main
liblika	doc_286998102764_item	3615697	et	3	main
essee	doc_286998102764_item	3615696	et	4	main
kinno	doc_286998102764_item	3615788	et	3	main
või	doc_286998102764_item	3615785	et	4	main
või	doc_286998102764_item	3615783	et	4	main
sõpradega	doc_286998102764_item	3615781	et	3	main
aga	doc_286998102764_item	3615770	et	3	main
loeb	doc_286998102764_item	3615765	et	3	main
koju	doc_286998102764_item	3615763	et	3	main
tavaliselt	doc_286998102764_item	3615753	et	4	main
on	doc_286998102764_item	3615745	et	4	main
on	doc_286998102765_item	3615943	et	4	main
õnnelik	doc_286998102765_item	3615941	et	3	main
aga	doc_286998102765_item	3615940	et	3	main
väsinud	doc_286998102765_item	3615939	et	4	main
on	doc_286998102765_item	3615938	et	4	main
ja	doc_286998102765_item	3615933	et	3	main
huvitavates	doc_286998102765_item	3615928	et	4	main
ta	doc_286998102765_item	3615918	et	4	main
töö	doc_286998102765_item	3615905	et	4	main
tule	doc_286998102765_item	3615876	et	4	main
tere	doc_286998102765_item	3615875	et	3	main
saa	doc_286998102765_item	3615861	et	4	main
tere	doc_286998102765_item	3615849	et	3	main
lilled	doc_286998102765_item	3615837	et	3	main
päike	doc_286998102765_item	3615835	et	3	main
ta	doc_286998102765_item	3615821	et	4	main
ärkas	doc_286998102765_item	3615820	et	3	main
kohta	doc_536541856856_item	3616109	et	4	main
eesti	doc_536541856856_item	3616104	et	4	main
rohkem	doc_536541856856_item	3616102	et	4	main
üldlaulupeod	doc_536541856856_item	3616090	et	4	main
tunnustamise	doc_536541856856_item	3616086	et	4	main
oma	doc_536541856856_item	3616085	et	4	main
kaudu	doc_536541856856_item	3616081	et	3	main
rahvuslik	doc_536541856856_item	3616078	et	3	main
oli	doc_536541856856_item	3616076	et	3	main
saanud	doc_536541856856_item	3616068	et	4	main
erinevate	doc_536541856856_item	3616049	et	4	main
ka	doc_536541856856_item	3616048	et	3	main
laulu	doc_536541856856_item	3616045	et	4	main
tegevusi	doc_536541856856_item	3616036	et	4	main
neid	doc_536541856856_item	3616035	et	4	main
kergendas	doc_536541856856_item	3616034	et	3	main
laul	doc_536541856856_item	3616033	et	4	main
et	doc_536541856856_item	3616032	et	3	main
olla	doc_536541856856_item	3616031	et	3	main
võib	doc_536541856856_item	3616030	et	3	main
suheldes	doc_536541856856_item	3616029	et	3	main
eestis	doc_536541856856_item	3616016	et	3	main
laulmise	doc_536541856856_item	3616013	et	4	main
laulurahvaks	doc_536541856856_item	3616012	et	3	main
nimetatakse	doc_536541856856_item	3616011	et	3	main
laulude	doc_536541856856_item	3616006	et	3	main
olnud	doc_536541856856_item	3615994	et	4	main
on	doc_536541856856_item	3615991	et	4	main
loengus	doc_536541856856_item	3615976	et	3	main
laulurahvaks	doc_536541856856_item	3616234	et	3	main
eestlasi	doc_536541856856_item	3616231	et	3	main
sellepärast	doc_536541856856_item	3616230	et	3	main
pakub	doc_536541856856_item	3616228	et	3	main
muusika	doc_536541856856_item	3616219	et	4	main
see	doc_536541856856_item	3616217	et	3	main
rahva	doc_536541856856_item	3616213	et	3	main
eesti	doc_536541856856_item	3616212	et	4	main
ajalooline	doc_536541856856_item	3616210	et	4	main
laulude	doc_536541856856_item	3616209	et	3	main
vaba	doc_286998102763_item	3615571	et	4	main
algab	doc_286998102763_item	3615555	et	3	main
läheb	doc_286998102764_item	3615728	et	3	main
või	doc_286998102764_item	3615727	et	4	main
sõpradega	doc_286998102764_item	3615726	et	3	main
oma	doc_286998102764_item	3615725	et	4	main
kohtub	doc_286998102764_item	3615724	et	3	main
või	doc_286998102764_item	3615723	et	4	main
ta	doc_286998102764_item	3615721	et	4	main
sööki	doc_286998102764_item	3615720	et	4	main
loeb	doc_286998102764_item	3615722	et	3	main
pärast	doc_286998102764_item	3615719	et	4	main
teda	doc_286998102764_item	3615718	et	4	main
kiirustab	doc_286998102764_item	3615717	et	3	main
ei	doc_286998102764_item	3615716	et	4	main
keegi	doc_286998102764_item	3615715	et	4	main
mitte	doc_286998102764_item	3615714	et	3	main
see	doc_286998102763_item	3615563	et	3	main
ajalugu	doc_286998102763_item	3615562	et	4	main
soome-ugri	doc_286998102763_item	3615561	et	3	main
pool	doc_286998102763_item	3615557	et	4	main
ta	doc_286998102764_item	3615710	et	4	main
ainult	doc_286998102764_item	3615706	et	4	main
ei	doc_286998102764_item	3615700	et	4	main
ainult	doc_286998102764_item	3615794	et	4	main
koju	doc_286998102764_item	3615793	et	3	main
läheb	doc_286998102764_item	3615792	et	3	main
ja	doc_286998102764_item	3615791	et	3	main
kontserdile	doc_286998102764_item	3615790	et	3	main
teatrisse	doc_286998102764_item	3615786	et	3	main
õhtul	doc_286998102764_item	3615776	et	3	main
sest	doc_286998102764_item	3615775	et	4	main
magab	doc_286998102764_item	3615774	et	3	main
kuulab	doc_286998102764_item	3615768	et	3	main
ta	doc_286998102764_item	3615761	et	4	main
pärast	doc_286998102764_item	3615758	et	4	main
õhtul	doc_286998102764_item	3615757	et	3	main
päev	doc_286998102765_item	3615946	et	3	main
väga	doc_286998102765_item	3615944	et	3	main
õhtul	doc_286998102765_item	3615936	et	3	main
ilma	doc_286998102765_item	3615935	et	4	main
nautis	doc_286998102765_item	3615931	et	3	main
asjadest	doc_286998102765_item	3615929	et	3	main
mõtiskles	doc_286998102765_item	3615927	et	3	main
lillelt	doc_286998102765_item	3615925	et	4	main
lendas	doc_286998102765_item	3615924	et	3	main
ja	doc_286998102765_item	3615917	et	3	main
kohal	doc_286998102765_item	3615916	et	4	main
põllu	doc_286998102765_item	3615915	et	3	main
oma	doc_286998102765_item	3615904	et	4	main
oli	doc_286998102765_item	3615903	et	3	main
pani	doc_286998102765_item	3615872	et	4	main
liblikas	doc_286998102765_item	3615871	et	4	main
lendas	doc_286998102765_item	3615869	et	3	main
ja	doc_286998102765_item	3615868	et	3	main
ei	doc_286998102765_item	3615860	et	4	main
mängima	doc_286998102765_item	3615856	et	3	main
pani	doc_286998102765_item	3615846	et	4	main
ta	doc_286998102765_item	3615845	et	4	main
heal	doc_286998102765_item	3615843	et	3	main
nii	doc_286998102765_item	3615842	et	3	main
päeval	doc_286998102765_item	3615844	et	3	main
teeksin	doc_286998102765_item	3615841	et	3	main
ma	doc_286998102765_item	3615840	et	3	main
mida	doc_286998102765_item	3615839	et	4	main
parim	doc_286998102764_item	3615811	et	4	main
on	doc_286998102764_item	3615810	et	4	main
see	doc_286998102764_item	3615809	et	3	main
raha	doc_286998102764_item	3615808	et	4	main
vaja	doc_286998102764_item	3615807	et	4	main
ei	doc_286998102764_item	3615806	et	4	main
tal	doc_286998102764_item	3615805	et	3	main
liblikas	doc_286998102764_item	3615804	et	4	main
on	doc_286998102764_item	3615803	et	4	main
ta	doc_286998102764_item	3615802	et	4	main
kuna	doc_286998102764_item	3615801	et	3	main
ja	doc_286998102764_item	3615800	et	3	main
elu	doc_286998102764_item	3615799	et	4	main
rahulikult	doc_286998102764_item	3615712	et	4	main
ta	doc_286998102764_item	3615704	et	4	main
on	doc_286998102764_item	3615797	et	4	main
tal	doc_286998102764_item	3615796	et	3	main
varahommikul	doc_286998102764_item	3615795	et	3	main
või	doc_286998102764_item	3615787	et	4	main
tantsida	doc_286998102764_item	3615784	et	3	main
kõrtsisse	doc_286998102764_item	3615782	et	3	main
ta	doc_286998102764_item	3615773	et	4	main
juhtudel	doc_286998102764_item	3615772	et	3	main
neid	doc_286998102764_item	3615756	et	4	main
ole	doc_286998102764_item	3615751	et	4	main
ei	doc_286998102764_item	3615750	et	4	main
nad	doc_286998102764_item	3615749	et	3	main
aga	doc_286998102764_item	3615748	et	3	main
sõbrannasid	doc_286998102764_item	3615747	et	3	main
palju	doc_286998102764_item	3615746	et	4	main
ta	doc_286998102765_item	3615937	et	4	main
päikest	doc_286998102765_item	3615932	et	4	main
üksi	doc_286998102765_item	3615914	et	4	main
et	doc_286998102765_item	3615912	et	3	main
mõtles	doc_286998102765_item	3615911	et	3	main
ja	doc_286998102765_item	3615910	et	3	main
ootamiseks	doc_286998102765_item	3615909	et	4	main
tüdines	doc_286998102765_item	3615908	et	3	main
aga	doc_286998102765_item	3615901	et	3	main
tähele	doc_286998102765_item	3615873	et	3	main
mesilane	doc_286998102765_item	3615867	et	4	main
vastas	doc_286998102765_item	3615866	et	4	main
töötas	doc_286998102765_item	3615865	et	3	main
ma	doc_286998102765_item	3615859	et	3	main
ja	doc_286998102765_item	3615855	et	3	main
tähele	doc_286998102765_item	3615847	et	3	main
õitsevad	doc_286998102765_item	3615838	et	4	main
hommik	doc_286998102765_item	3615833	et	3	main
nii	doc_286998102765_item	3615831	et	3	main
tiiba	doc_286998102765_item	3615826	et	4	main
läikima	doc_286998102765_item	3615825	et	4	main
11-12	doc_286998102764_item	3615709	et	2	main
umbes	doc_286998102764_item	3615707	et	4	main
tõuseb	doc_286998102764_item	3615705	et	3	main
sellepärast	doc_286998102764_item	3615703	et	3	main
töötada	doc_286998102764_item	3615702	et	3	main
vaja	doc_286998102764_item	3615701	et	4	main
või	doc_286998102764_item	3615789	et	4	main
pärast	doc_286998102764_item	3615777	et	4	main
muusikat	doc_286998102764_item	3615769	et	3	main
või	doc_286998102764_item	3615767	et	4	main
läheb	doc_286998102764_item	3615762	et	3	main
tavaliselt	doc_286998102764_item	3615760	et	4	main
lõunat	doc_286998102764_item	3615759	et	3	main
ta	doc_286998102764_item	3615754	et	4	main
tõsised	doc_286998102764_item	3615752	et	4	main
hea	doc_286998102765_item	3615945	et	4	main
ja	doc_286998102765_item	3615930	et	3	main
ta	doc_286998102765_item	3615923	et	4	main
päeval	doc_286998102765_item	3615922	et	3	main
kogu	doc_286998102765_item	3615921	et	4	main
seda	doc_286998102765_item	3615920	et	3	main
lendab	doc_286998102765_item	3615913	et	3	main
kõigile	doc_286998102765_item	3615902	et	4	main
pean	doc_286998102765_item	3615864	et	4	main
ma	doc_286998102765_item	3615863	et	3	main
minna	doc_286998102765_item	3615862	et	3	main
küsis	doc_286998102765_item	3615857	et	3	main
lendama	doc_286998102765_item	3615854	et	3	main
tuled	doc_286998102765_item	3615852	et	4	main
kas	doc_286998102765_item	3615850	et	3	main
paistab	doc_286998102765_item	3615836	et	3	main
on	doc_286998102765_item	3615834	et	4	main
ilus	doc_286998102765_item	3615832	et	4	main
vaatas	doc_286998102765_item	3615828	et	3	main
päeval	doc_286998102765_item	3615817	et	3	main
päev	doc_286998102765_item	3615815	et	3	main
essee	doc_286998102765_item	3615813	et	4	main
ajaloo	doc_536541856856_item	3616106	et	4	main
informatsiooni	doc_536541856856_item	3616103	et	4	main
inimestele	doc_536541856856_item	3616101	et	3	main
anda	doc_536541856856_item	3616100	et	3	main
ja	doc_536541856856_item	3616099	et	3	main
folkloori	doc_536541856856_item	3616098	et	4	main
ühendasid	doc_536541856856_item	3616091	et	4	main
eestlased	doc_536541856856_item	3616082	et	3	main
kasutada	doc_536541856856_item	3616047	et	3	main
ning	doc_536541856856_item	3616044	et	3	main
funktsioon	doc_536541856856_item	3616043	et	3	main
esteetiline	doc_536541856856_item	3616042	et	3	main
ajal	doc_536541856856_item	3616020	et	4	main
vanal	doc_536541856856_item	3616019	et	3	main
ning	doc_536541856856_item	3616008	et	3	main
huvi	doc_536541856856_item	3616005	et	4	main
eestis	doc_536541856856_item	3616003	et	3	main
tänapäeval	doc_536541856856_item	3616001	et	3	main
ka	doc_536541856856_item	3616000	et	3	main
elus	doc_536541856856_item	3615999	et	4	main
eestlaste	doc_536541856856_item	3615998	et	4	main
on	doc_536541856856_item	3615982	et	4	main
tuginema	doc_536541856856_item	3615975	et	3	main
essee	doc_536541856856_item	3615968	et	4	main
sõna	doc_536541856856_item	3615967	et	4	main
300	doc_536541856856_item	3615965	et	2	main
pikkus	doc_536541856856_item	3615964	et	4	main
inimesi	doc_536541856856_item	3616226	et	4	main
vahel	doc_536541856856_item	3616224	et	4	main
kui	doc_536541856856_item	3616215	et	3	main
tähtsus	doc_536541856856_item	3616211	et	4	main
huvi	doc_536541856856_item	3616203	et	4	main
tal	doc_286998102765_item	3615942	et	3	main
sooja	doc_286998102765_item	3615934	et	4	main
lillele	doc_286998102765_item	3615926	et	4	main
tegi	doc_286998102765_item	3615919	et	4	main
liblikas	doc_286998102765_item	3615907	et	4	main
nii	doc_286998102765_item	3615906	et	3	main
temaga	doc_286998102765_item	3615900	et	3	main
mängima	doc_286998102765_item	3615899	et	3	main
tuleks	doc_286998102765_item	3615898	et	4	main
keegi	doc_286998102765_item	3615897	et	4	main
et	doc_286998102765_item	3615896	et	3	main
ootas	doc_286998102765_item	3615895	et	3	main
ja	doc_286998102765_item	3615894	et	3	main
peal	doc_286998102765_item	3615893	et	4	main
lille	doc_286998102765_item	3615892	et	4	main
istus	doc_286998102765_item	3615891	et	4	main
liblikas	doc_286998102765_item	3615890	et	4	main
edasi	doc_286998102765_item	3615889	et	3	main
ronis	doc_286998102765_item	3615888	et	4	main
ja	doc_286998102765_item	3615887	et	3	main
uss	doc_286998102765_item	3615886	et	3	main
ütles	doc_286998102765_item	3615885	et	3	main
lennata	doc_286998102765_item	3615884	et	4	main
oska	doc_286998102765_item	3615883	et	4	main
ei	doc_286998102765_item	3615882	et	4	main
ma	doc_286998102765_item	3615881	et	3	main
mängima	doc_286998102765_item	3615880	et	3	main
ja	doc_286998102765_item	3615879	et	3	main
lendama	doc_286998102765_item	3615878	et	3	main
minuga	doc_286998102765_item	3615877	et	3	main
vihmaussi	doc_286998102765_item	3615874	et	4	main
edasi	doc_286998102765_item	3615870	et	3	main
liblikas	doc_286998102765_item	3615858	et	4	main
minuga	doc_286998102765_item	3615853	et	3	main
sa	doc_286998102765_item	3615851	et	3	main
mesilat	doc_286998102765_item	3615848	et	3	main
oi	doc_286998102765_item	3615830	et	3	main
ringi	doc_286998102765_item	3615829	et	4	main
liblikas	doc_286998102765_item	3615819	et	4	main
kui	doc_286998102765_item	3615818	et	3	main
ning	doc_536541856856_item	3616107	et	3	main
eesti	doc_536541856856_item	3616097	et	4	main
sellele	doc_536541856856_item	3616089	et	4	main
lisaks	doc_536541856856_item	3616088	et	4	main
üldlaulupidude	doc_536541856856_item	3616080	et	4	main
identiteeditunne	doc_536541856856_item	3616079	et	3	main
ajal	doc_536541856856_item	3616075	et	4	main
rahvusliku	doc_536541856856_item	3616073	et	3	main
millele	doc_536541856856_item	3616072	et	3	main
sümbol	doc_536541856856_item	3616071	et	3	main
tähtis	doc_536541856856_item	3616070	et	4	main
ka	doc_536541856856_item	3616069	et	3	main
sai	doc_536541856856_item	3616046	et	4	main
olnud	doc_536541856856_item	3616041	et	4	main
on	doc_536541856856_item	3616040	et	4	main
rahvalaulul	doc_536541856856_item	3616039	et	3	main
pidude	doc_536541856856_item	3616026	et	4	main
saatnud	doc_536541856856_item	3616023	et	4	main
laul	doc_536541856856_item	3616022	et	4	main
väga	doc_536541856856_item	3616017	et	3	main
on	doc_536541856856_item	3616015	et	4	main
traditsioon	doc_536541856856_item	3616014	et	3	main
ja	doc_286998102765_item	3615827	et	3	main
löömalõi	doc_286998102765_item	3615824	et	4	main
läikis	doc_286998102765_item	3615823	et	3	main
tõusis	doc_286998102765_item	3615822	et	4	main
ühel	doc_286998102765_item	3615816	et	3	main
liblika	doc_286998102765_item	3615814	et	3	main
ka	doc_536541856856_item	3616110	et	3	main
rahva	doc_536541856856_item	3616105	et	3	main
säilitada	doc_536541856856_item	3616096	et	3	main
aitasid	doc_536541856856_item	3616095	et	4	main
võidelda	doc_536541856856_item	3616084	et	4	main
rajatud	doc_536541856856_item	3616077	et	4	main
ärkamise	doc_536541856856_item	3616074	et	4	main
lisaks	doc_536541856856_item	3616037	et	4	main
tähistades	doc_536541856856_item	3616027	et	3	main
töötades	doc_536541856856_item	3616025	et	3	main
on	doc_536541856856_item	3616021	et	4	main
sellepärast	doc_536541856856_item	3616009	et	3	main
vastu	doc_536541856856_item	3616007	et	3	main
tegevuseks	doc_536541856856_item	3615997	et	4	main
aegade	doc_536541856856_item	3615993	et	3	main
läbi	doc_536541856856_item	3615992	et	4	main
laulmine	doc_536541856856_item	3615990	et	4	main
laulurahva	doc_536541856856_item	3615989	et	3	main
eestlastest	doc_536541856856_item	3615988	et	4	main
teeb	doc_536541856856_item	3615987	et	3	main
faktidele	doc_536541856856_item	3615980	et	3	main
esitatud	doc_536541856856_item	3615979	et	4	main
lugemistekstis	doc_536541856856_item	3615978	et	3	main
peab	doc_536541856856_item	3615969	et	4	main
ning	doc_536541856856_item	3616227	et	3	main
erinevate	doc_536541856856_item	3616222	et	4	main
jaoks	doc_536541856856_item	3616214	et	4	main
laulmise	doc_536541856856_item	3616204	et	4	main
võistlust	doc_536541856856_item	3616201	et	3	main
aastal	doc_536541856856_item	3616197	et	3	main
on	doc_536541856856_item	3616191	et	4	main
riigis	doc_536541856856_item	3616174	et	3	main
iseseisvaks	doc_536541856856_item	3616173	et	3	main
võib	doc_536541856856_item	3616163	et	3	main
niisiis	doc_536541856856_item	3616162	et	3	main
ndate	doc_536541856856_item	3616152	et	4	main
1980	doc_536541856856_item	3616151	et	2	main
vastu	doc_536541856856_item	3616145	et	3	main
tol	doc_536541856856_item	3616132	et	3	main
ilmumist	doc_536541856856_item	3616131	et	4	main
oli	doc_536541856856_item	3616114	et	3	main
liidu	doc_536541856856_item	3616112	et	3	main
näiteks	doc_536541856857_item	3616557	et	4	main
või	doc_536541856857_item	3616553	et	4	main
on	doc_536541856857_item	3616547	et	4	main
ning	doc_536541856857_item	3616538	et	3	main
eesti	doc_536541856857_item	3616535	et	4	main
kes	doc_536541856857_item	3616533	et	4	main
oma	doc_536541856857_item	3616529	et	4	main
aga	doc_536541856857_item	3616528	et	3	main
otsivad	doc_536541856857_item	3616527	et	4	main
kollektiivid	doc_536541856857_item	3616526	et	3	main
kaasaegsed	doc_536541856857_item	3616525	et	3	main
paljud	doc_536541856857_item	3616524	et	3	main
teatris	doc_536541856857_item	3616517	et	3	main
nõukogude	doc_536541856857_item	3616470	et	3	main
raskemas	doc_536541856857_item	3616466	et	4	main
olid	doc_536541856857_item	3616459	et	4	main
laulu	doc_536541856857_item	3616449	et	4	main
räägime	doc_536541856857_item	3616447	et	3	main
kaanel	doc_536541856857_item	3616443	et	4	main
uusi	doc_536541856857_item	3616438	et	3	main
hakkasid	doc_536541856857_item	3616436	et	4	main
saada	doc_536541856857_item	3616412	et	4	main
raamatutest	doc_536541856857_item	3616403	et	4	main
lähedamini	doc_536541856857_item	3616394	et	4	main
ja	doc_536541856857_item	3616393	et	3	main
me	doc_536541856857_item	3616387	et	4	main
tänapäeval	doc_536541856857_item	3616386	et	3	main
ajal	doc_536541856857_item	3616385	et	4	main
oma	doc_536541856857_item	3616379	et	4	main
seda	doc_536541856857_item	3616374	et	3	main
mainima	doc_536541856857_item	3616372	et	3	main
nii	doc_536541856857_item	3616365	et	3	main
üksi	doc_536541856857_item	3616359	et	4	main
traditsioonide	doc_536541856856_item	3616108	et	3	main
ning	doc_536541856856_item	3616094	et	3	main
rahva	doc_536541856856_item	3616093	et	3	main
eesti	doc_536541856856_item	3616092	et	4	main
eest	doc_536541856856_item	3616087	et	4	main
üritasid	doc_536541856856_item	3616083	et	4	main
pooles	doc_536541856856_item	3616067	et	4	main
teises	doc_536541856856_item	3616066	et	4	main
sajandi	doc_536541856856_item	3616065	et	3	main
19	doc_536541856856_item	3616064	et	2	main
rahvalaulust	doc_536541856856_item	3616063	et	4	main
on	doc_536541856856_item	3616062	et	4	main
selle	doc_536541856856_item	3616061	et	4	main
peale	doc_536541856856_item	3616060	et	4	main
tähtsaks	doc_536541856856_item	3616059	et	4	main
väga	doc_536541856856_item	3616058	et	3	main
rahvalaulu	doc_536541856856_item	3616057	et	4	main
tegid	doc_536541856856_item	3616056	et	4	main
funktsioonid	doc_536541856856_item	3616055	et	3	main
need	doc_536541856856_item	3616054	et	3	main
väljendamiseks	doc_536541856856_item	3616053	et	4	main
emotsioonide	doc_536541856856_item	3616052	et	3	main
ja	doc_536541856856_item	3616051	et	3	main
tunnete	doc_536541856856_item	3616050	et	4	main
sellele	doc_536541856856_item	3616038	et	4	main
lastega	doc_536541856856_item	3616028	et	3	main
inimest	doc_536541856856_item	3616024	et	3	main
vana	doc_536541856856_item	3616018	et	4	main
eestlasi	doc_536541856856_item	3616010	et	3	main
säilitub	doc_536541856856_item	3616002	et	4	main
väga	doc_536541856856_item	3615995	et	3	main
väiteid	doc_536541856856_item	3615981	et	4	main
ja	doc_536541856856_item	3615973	et	3	main
arutlev	doc_536541856856_item	3615971	et	4	main
olema	doc_536541856856_item	3615970	et	4	main
essee	doc_536541856856_item	3615963	et	4	main
laulurahva	doc_536541856856_item	3615962	et	3	main
nimetada	doc_536541856856_item	3616233	et	3	main
ühendab	doc_536541856856_item	3616225	et	3	main
et	doc_536541856856_item	3616218	et	3	main
selle	doc_536541856856_item	3616200	et	4	main
mitmekordselt	doc_536541856856_item	3616192	et	4	main
viljandis	doc_536541856856_item	3616189	et	4	main
või	doc_536541856856_item	3616187	et	4	main
laulupidu	doc_536541856856_item	3616186	et	4	main
eestiline	doc_536541856856_item	3616185	et	3	main
laulmisega	doc_536541856856_item	3616166	et	4	main
huvi	doc_536541856856_item	3616156	et	4	main
ka	doc_536541856856_item	3616146	et	3	main
rahvakultuuri	doc_536541856856_item	3616143	et	4	main
levimist	doc_536541856856_item	3616136	et	4	main
kasutati	doc_536541856856_item	3616134	et	4	main
ajal	doc_536541856856_item	3616133	et	4	main
ernesaksa	doc_536541856856_item	3616126	et	4	main
g	doc_536541856856_item	3616125	et	4	main
näiteks	doc_536541856856_item	3616120	et	4	main
hoidja	doc_536541856856_item	3616118	et	4	main
kõik	doc_536541856857_item	3616558	et	4	main
pop	doc_536541856857_item	3616552	et	4	main
meil	doc_536541856857_item	3616546	et	4	main
niiviisi	doc_536541856857_item	3616545	et	3	main
mängida	doc_536541856857_item	3616537	et	3	main
etendustel	doc_536541856857_item	3616523	et	4	main
igasugustel	doc_536541856857_item	3616522	et	3	main
ning	doc_536541856857_item	3616521	et	3	main
kontsertidel	doc_536541856857_item	3616520	et	3	main
linnas	doc_536541856857_item	3616507	et	4	main
suur	doc_536541856856_item	3616004	et	3	main
tähtsaks	doc_536541856856_item	3615996	et	4	main
mis	doc_536541856856_item	3615986	et	4	main
näidetega	doc_536541856856_item	3615985	et	3	main
illustreerida	doc_536541856856_item	3615984	et	3	main
soovitatav	doc_536541856856_item	3615983	et	4	main
ja	doc_536541856856_item	3615977	et	3	main
üldistav	doc_536541856856_item	3615974	et	4	main
analüüsiv	doc_536541856856_item	3615972	et	4	main
350	doc_536541856856_item	3615966	et	2	main
eestlastest	doc_536541856856_item	3615961	et	4	main
teeb	doc_536541856856_item	3615960	et	3	main
mis	doc_536541856856_item	3615959	et	4	main
teemal	doc_536541856856_item	3615958	et	3	main
essee	doc_536541856856_item	3615957	et	4	main
kirjutage	doc_536541856856_item	3615956	et	3	main
kirjutamine	doc_536541856856_item	3615955	et	4	main
test	doc_536541856856_item	3615954	et	3	main
keele	doc_536541856856_item	3615953	et	4	main
kui	doc_536541856856_item	3615951	et	3	main
teise	doc_536541856856_item	3615952	et	4	main
keele	doc_536541856856_item	3615950	et	4	main
eesti	doc_536541856856_item	3615949	et	4	main
essee	doc_536541856856_item	3615948	et	4	main
võibki	doc_536541856856_item	3616232	et	3	main
meelelahutust	doc_536541856856_item	3616229	et	4	main
põlvkondade	doc_536541856856_item	3616223	et	3	main
sidet	doc_536541856856_item	3616221	et	4	main
moodustab	doc_536541856856_item	3616220	et	3	main
ka	doc_536541856856_item	3616216	et	3	main
võitnud	doc_536541856856_item	3616199	et	4	main
isegi	doc_536541856856_item	3616198	et	4	main
2001	doc_536541856856_item	3616196	et	2	main
eurovisioonis	doc_536541856856_item	3616194	et	3	main
eestis	doc_536541856856_item	3616178	et	3	main
toimub	doc_536541856856_item	3616177	et	3	main
tänapäeval	doc_536541856856_item	3616176	et	3	main
ka	doc_536541856856_item	3616175	et	3	main
sai	doc_536541856856_item	3616172	et	4	main
et	doc_536541856856_item	3616165	et	3	main
laulude	doc_536541856856_item	3616160	et	3	main
ning	doc_536541856856_item	3616158	et	3	main
algas	doc_536541856856_item	3616150	et	3	main
mis	doc_536541856856_item	3616149	et	4	main
ärkamisajaga	doc_536541856856_item	3616148	et	3	main
stiliseerimise	doc_536541856856_item	3616144	et	4	main
ametliku	doc_536541856856_item	3616142	et	3	main
tunnete	doc_536541856856_item	3616130	et	4	main
rahvuslikke	doc_536541856856_item	3616129	et	3	main
kõlas	doc_536541856856_item	3616124	et	4	main
kui	doc_536541856856_item	3616123	et	3	main
funktsioon	doc_536541856856_item	3616119	et	3	main
rock	doc_536541856857_item	3616554	et	4	main
kuulata	doc_536541856857_item	3616549	et	4	main
võimalus	doc_536541856857_item	3616548	et	3	main
rahvalaule	doc_536541856857_item	3616539	et	4	main
vanu	doc_536541856857_item	3616531	et	4	main
ansamblidesse	doc_536541856857_item	3616530	et	4	main
tallinnas	doc_536541856857_item	3616518	et	4	main
ja	doc_536541856857_item	3616515	et	3	main
tartus	doc_536541856857_item	3616514	et	3	main
teatris	doc_536541856857_item	3616513	et	3	main
vanemuine	doc_536541856857_item	3616512	et	4	main
nendes	doc_536541856857_item	3616505	et	4	main
valitsesid	doc_536541856857_item	3616469	et	4	main
ajas	doc_536541856857_item	3616467	et	4	main
nii	doc_536541856856_item	3616208	et	3	main
on	doc_536541856856_item	3616207	et	4	main
põhjusteks	doc_536541856856_item	3616206	et	3	main
vastu	doc_536541856856_item	3616205	et	3	main
eestlaste	doc_536541856856_item	3616202	et	4	main
ning	doc_536541856856_item	3616195	et	3	main
eesti	doc_536541856856_item	3616190	et	4	main
folkloorifestival	doc_536541856856_item	3616188	et	3	main
eesti	doc_536541856856_item	3616171	et	4	main
et	doc_536541856856_item	3616170	et	3	main
seda	doc_536541856856_item	3616169	et	3	main
soodustas	doc_536541856856_item	3616168	et	3	main
järeldada	doc_536541856856_item	3616164	et	3	main
vastu	doc_536541856856_item	3616161	et	3	main
rahvalaulude	doc_536541856856_item	3616157	et	3	main
kasvav	doc_536541856856_item	3616155	et	4	main
kaasnes	doc_536541856856_item	3616154	et	3	main
lõpus	doc_536541856856_item	3616153	et	4	main
teise	doc_536541856856_item	3616147	et	4	main
protesti	doc_536541856856_item	3616141	et	4	main
avaldada	doc_536541856856_item	3616140	et	3	main
et	doc_536541856856_item	3616139	et	3	main
selleks	doc_536541856856_item	3616138	et	4	main
rahvalaulu	doc_536541856856_item	3616135	et	4	main
isamaalaul	doc_536541856856_item	3616127	et	4	main
laulupidude	doc_536541856856_item	3616121	et	4	main
ajal	doc_536541856856_item	3616113	et	4	main
osalenud	doc_536541856856_item	3616193	et	4	main
üle	doc_536541856856_item	3616184	et	3	main
näiteks	doc_536541856856_item	3616183	et	4	main
seotud	doc_536541856856_item	3616181	et	4	main
üritusi	doc_536541856856_item	3616182	et	4	main
laulmisega	doc_536541856856_item	3616180	et	4	main
palju	doc_536541856856_item	3616179	et	4	main
tegelemine	doc_536541856856_item	3616167	et	4	main
isamaaliste	doc_536541856856_item	3616159	et	4	main
ka	doc_536541856856_item	3616137	et	3	main
soodustasid	doc_536541856856_item	3616128	et	4	main
lõpetamise	doc_536541856856_item	3616122	et	4	main
identiteedi	doc_536541856856_item	3616117	et	4	main
rahvusliku	doc_536541856856_item	3616116	et	3	main
rahvalaulul	doc_536541856856_item	3616115	et	3	main
nsv	doc_536541856856_item	3616111	et	4	main
saatel	doc_536541856857_item	3616556	et	4	main
muusika	doc_536541856857_item	3616555	et	4	main
vanu	doc_536541856857_item	3616550	et	4	main
rahvapille	doc_536541856857_item	3616536	et	3	main
oskavad	doc_536541856857_item	3616534	et	4	main
teatrides	doc_536541856857_item	3616511	et	4	main
käiakse	doc_536541856857_item	3616510	et	3	main
rahvamassiliset	doc_536541856857_item	3616509	et	4	main
tänapäevani	doc_536541856857_item	3616508	et	3	main
kui	doc_536541856857_item	3616468	et	3	main
viidud	doc_536541856857_item	3616463	et	4	main
läbi	doc_536541856857_item	3616462	et	4	main
saa	doc_536541856857_item	3616454	et	4	main
traditsioonidest	doc_536541856857_item	3616450	et	3	main
eesti	doc_536541856857_item	3616448	et	4	main
oskasid	doc_536541856857_item	3616415	et	4	main
inimesed	doc_536541856857_item	3616414	et	3	main
kuidas	doc_536541856857_item	3616413	et	3	main
palju	doc_536541856857_item	3616409	et	4	main
on	doc_536541856857_item	3616407	et	4	main
meil	doc_536541856857_item	3616406	et	4	main
kihnu	doc_536541856857_item	3616399	et	4	main
traditsioonidega	doc_536541856857_item	3616398	et	3	main
rahvalaulu	doc_536541856857_item	3616397	et	4	main
leida	doc_536541856857_item	3616391	et	3	main
seni	doc_536541856857_item	3616389	et	3	main
erinevatel	doc_536541856857_item	3616381	et	4	main
vahel	doc_536541856857_item	3616380	et	4	main
naised	doc_536541856857_item	3616376	et	3	main
et	doc_536541856857_item	3616375	et	3	main
toimusid	doc_536541856857_item	3616364	et	4	main
või	doc_536541856857_item	3616362	et	4	main
kooriga	doc_536541856857_item	3616361	et	4	main
kahekesi	doc_536541856857_item	3616360	et	3	main
vanal	doc_536541856857_item	3616355	et	3	main
laule	doc_536541856857_item	3616346	et	4	main
nendele	doc_536541856857_item	3616344	et	4	main
lauldes	doc_536541856857_item	3616343	et	3	main
lastega	doc_536541856857_item	3616342	et	3	main
oma	doc_536541856857_item	3616341	et	4	main
pärandamises	doc_536541856857_item	3616336	et	4	main
suulises	doc_536541856857_item	3616335	et	4	main
traditsioonide	doc_536541856857_item	3616334	et	3	main
suuliselt	doc_536541856857_item	3616325	et	4	main
kombeid	doc_536541856857_item	3616323	et	4	main
seotud	doc_536541856857_item	3616322	et	4	main
seotud	doc_536541856857_item	3616307	et	4	main
laulutraditsioonid	doc_536541856857_item	3616305	et	3	main
eesti	doc_536541856857_item	3616304	et	4	main
vanasti	doc_536541856857_item	3616303	et	3	main
juba	doc_536541856857_item	3616302	et	3	main
nimelt	doc_536541856857_item	3616296	et	4	main
pärines	doc_536541856857_item	3616295	et	3	main
eesti	doc_536541856857_item	3616350	et	4	main
muinasjutte	doc_536541856857_item	3616349	et	3	main
ikkagi	doc_536541856866_item	3616863	et	4	main
nagu	doc_536541856866_item	3616849	et	3	main
on	doc_536541856866_item	3616845	et	4	main
ainult	doc_536541856866_item	3616840	et	4	main
elab	doc_536541856866_item	3616835	et	3	main
nüüd	doc_536541856866_item	3616826	et	4	main
kus	doc_536541856866_item	3616825	et	3	main
folkloorifestival	doc_536541856866_item	3616824	et	3	main
vanu	doc_536541856866_item	3616817	et	4	main
kuues	doc_536541856866_item	3616805	et	4	main
1896	doc_536541856866_item	3616796	et	2	main
ja	doc_536541856866_item	3616769	et	3	main
lõuna	doc_536541856866_item	3616758	et	4	main
lauldakse	doc_536541856866_item	3616757	et	3	main
praegu	doc_536541856866_item	3616756	et	3	main
regilaulud	doc_536541856866_item	3616755	et	3	main
ka	doc_536541856866_item	3616754	et	3	main
laulurahvast	doc_536541856857_item	3616567	et	4	main
nagu	doc_536541856857_item	3616566	et	3	main
eestlastest	doc_536541856857_item	3616565	et	4	main
rääkida	doc_536541856857_item	3616564	et	3	main
õigust	doc_536541856857_item	3616563	et	4	main
meile	doc_536541856857_item	3616562	et	4	main
annavad	doc_536541856857_item	3616561	et	3	main
teadmised	doc_536541856857_item	3616560	et	4	main
need	doc_536541856857_item	3616559	et	3	main
laulu	doc_536541856857_item	3616551	et	4	main
töötlusi	doc_536541856857_item	3616544	et	3	main
modernseid	doc_536541856857_item	3616543	et	3	main
teha	doc_536541856857_item	3616542	et	3	main
et	doc_536541856857_item	3616541	et	3	main
selleks	doc_536541856857_item	3616540	et	4	main
mehi	doc_536541856857_item	3616532	et	3	main
muusikafestivalidel	doc_536541856857_item	3616519	et	3	main
estonia	doc_536541856857_item	3616516	et	4	main
kahes	doc_536541856857_item	3616506	et	4	main
tallinnas	doc_536541856857_item	3616504	et	4	main
ka	doc_536541856857_item	3616503	et	3	main
kui	doc_536541856857_item	3616502	et	3	main
tartus	doc_536541856857_item	3616501	et	3	main
nii	doc_536541856857_item	3616500	et	3	main
muusikaseltsidel	doc_536541856857_item	3616499	et	3	main
oli	doc_536541856857_item	3616498	et	3	main
tähendus	doc_536541856857_item	3616497	et	4	main
suur	doc_536541856857_item	3616496	et	3	main
laulukombeid	doc_536541856857_item	3616495	et	4	main
rahvuslikke	doc_536541856857_item	3616494	et	3	main
oma	doc_536541856857_item	3616493	et	4	main
säilitada	doc_536541856857_item	3616492	et	3	main
ning	doc_536541856857_item	3616491	et	3	main
laulda	doc_536541856857_item	3616490	et	4	main
kaasa	doc_536541856857_item	3616489	et	4	main
takistusi	doc_536541856857_item	3616488	et	4	main
igasuguseid	doc_536541856857_item	3616487	et	3	main
elada	doc_536541856857_item	3616486	et	3	main
üle	doc_536541856857_item	3616485	et	3	main
võimaluse	doc_536541856857_item	3616483	et	3	main
koos	doc_536541856857_item	3616484	et	4	main
inimestele	doc_536541856857_item	3616482	et	3	main
andis	doc_536541856857_item	3616481	et	3	main
rahvapeol	doc_536541856857_item	3616480	et	4	main
alati	doc_536541856857_item	3616479	et	4	main
valitses	doc_536541856857_item	3616478	et	3	main
mis	doc_536541856857_item	3616477	et	4	main
õhkkond	doc_536541856857_item	3616476	et	3	main
andev	doc_536541856857_item	3616475	et	4	main
tunnet	doc_536541856857_item	3616474	et	3	main
ülendavat	doc_536541856857_item	3616473	et	4	main
selline	doc_536541856857_item	3616472	et	4	main
reeglid	doc_536541856857_item	3616471	et	3	main
ning	doc_536541856857_item	3616461	et	3	main
korraldatud	doc_536541856857_item	3616460	et	4	main
ei	doc_536541856857_item	3616453	et	4	main
kunagi	doc_536541856857_item	3616452	et	3	main
bajaan	doc_536541856857_item	3616441	et	3	main
muusikapille	doc_536541856857_item	3616439	et	3	main
kasutama	doc_536541856857_item	3616437	et	3	main
mõjule	doc_536541856857_item	3616434	et	3	main
venemaa	doc_536541856857_item	3616429	et	4	main
ja	doc_536541856857_item	3616428	et	3	main
läti	doc_536541856857_item	3616427	et	4	main
näiteks	doc_536541856857_item	3616426	et	4	main
arengule	doc_536541856857_item	3616425	et	3	main
rahvalaulu	doc_536541856857_item	3616424	et	4	main
eesti	doc_536541856857_item	3616423	et	4	main
mõjusid	doc_536541856857_item	3616422	et	4	main
naaberriigid	doc_536541856857_item	3616421	et	3	main
eesti	doc_536541856857_item	3616420	et	4	main
kuidas	doc_536541856857_item	3616419	et	3	main
sellises	doc_536541856857_item	3616465	et	4	main
isegi	doc_536541856857_item	3616464	et	4	main
mis	doc_536541856857_item	3616458	et	4	main
laulupeodest	doc_536541856857_item	3616457	et	3	main
me	doc_536541856857_item	3616451	et	4	main
me	doc_536541856857_item	3616446	et	4	main
kindlasti	doc_536541856857_item	3616444	et	3	main
ja	doc_536541856857_item	3616442	et	3	main
nagu	doc_536541856857_item	3616440	et	3	main
eestlased	doc_536541856857_item	3616435	et	3	main
välismaalaste	doc_536541856857_item	3616433	et	4	main
tänu	doc_536541856857_item	3616432	et	4	main
just	doc_536541856857_item	3616431	et	3	main
aga	doc_536541856857_item	3616430	et	3	main
teada	doc_536541856857_item	3616411	et	3	main
setumaal	doc_536541856857_item	3616402	et	4	main
ja	doc_536541856857_item	3616401	et	3	main
käsitöö	doc_536541856857_item	3616384	et	4	main
ning	doc_536541856857_item	3616383	et	3	main
kokkutulekutel	doc_536541856857_item	3616382	et	3	main
põhiliselt	doc_536541856857_item	3616377	et	4	main
peab	doc_536541856857_item	3616371	et	4	main
ka	doc_536541856857_item	3616368	et	3	main
vokaalsed	doc_536541856857_item	3616366	et	3	main
ringis	doc_536541856857_item	3616363	et	4	main
ajal	doc_536541856857_item	3616356	et	4	main
aega	doc_536541856857_item	3616340	et	4	main
rohkem	doc_536541856857_item	3616339	et	4	main
laule	doc_536541856857_item	3616319	et	4	main
edastada	doc_536541856857_item	3616318	et	3	main
mitte	doc_536541856857_item	3616308	et	3	main
regiväärsilisest	doc_536541856857_item	3616297	et	4	main
on	doc_536541856866_item	3616858	et	4	main
ei	doc_536541856866_item	3616852	et	4	main
mõnikord	doc_536541856866_item	3616851	et	3	main
rahvalaul	doc_536541856866_item	3616844	et	4	main
võin	doc_536541856866_item	3616839	et	3	main
geenides	doc_536541856866_item	3616837	et	3	main
on	doc_536541856866_item	3616827	et	4	main
eestis	doc_536541856866_item	3616821	et	3	main
tallinnas	doc_536541856866_item	3616809	et	4	main
esimene	doc_536541856866_item	3616808	et	3	main
aga	doc_536541856866_item	3616807	et	3	main
pidu	doc_536541856866_item	3616806	et	4	main
pillimehi	doc_536541856866_item	3616770	et	3	main
lauljaid	doc_536541856866_item	3616768	et	4	main
peab	doc_536541856866_item	3616766	et	4	main
arusaadav	doc_536541856866_item	3616764	et	4	main
oli	doc_536541856866_item	3616763	et	3	main
sajandil	doc_536541856866_item	3616762	et	3	main
19	doc_536541856866_item	3616761	et	2	main
riimilaulud	doc_536541856866_item	3616752	et	4	main
19	doc_536541856866_item	3616747	et	2	main
on	doc_536541856866_item	3616745	et	4	main
regilaul	doc_536541856866_item	3616737	et	4	main
kuni	doc_536541856866_item	3616727	et	3	main
lauljatest	doc_536541856866_item	3616722	et	4	main
hetkeolukorrast	doc_536541856866_item	3616719	et	4	main
sõltuvalt	doc_536541856866_item	3616718	et	4	main
jagatakse	doc_536541856866_item	3616717	et	3	main
laulukogumiku	doc_536541856866_item	3616703	et	4	main
ega	doc_536541856866_item	3616702	et	3	main
autorit	doc_536541856866_item	3616701	et	3	main
hakkan	doc_536541856866_item	3616670	et	3	main
unusta	doc_536541856866_item	3616657	et	4	main
tantsid	doc_536541856866_item	3616649	et	4	main
olid	doc_536541856866_item	3616646	et	4	main
õhtul	doc_536541856866_item	3616645	et	3	main
oli	doc_536541856866_item	3616639	et	3	main
üüritustel	doc_536541856866_item	3616624	et	4	main
algusel	doc_536541856866_item	3616615	et	4	main
eestlastest	doc_536541856866_item	3616609	et	4	main
esitatud	doc_536541856866_item	3616600	et	4	main
lugemistekstis	doc_536541856866_item	3616599	et	3	main
loengus	doc_536541856866_item	3616597	et	3	main
arutlev	doc_536541856866_item	3616592	et	4	main
essee	doc_536541856866_item	3616589	et	4	main
teemal	doc_536541856866_item	3616579	et	3	main
eestlastest	doc_536541856867_item	3617057	et	4	main
võistlustedel	doc_536541856867_item	3617050	et	4	main
palju	doc_536541856867_item	3617042	et	4	main
nendest	doc_536541856857_item	3616456	et	4	main
unustada	doc_536541856857_item	3616455	et	3	main
kui	doc_536541856857_item	3616445	et	3	main
lauluga	doc_536541856857_item	3616417	et	4	main
ennast	doc_536541856857_item	3616416	et	4	main
kirjandusest	doc_536541856857_item	3616405	et	4	main
ja	doc_536541856857_item	3616404	et	3	main
eestu	doc_536541856857_item	3616396	et	4	main
tutvuda	doc_536541856857_item	3616395	et	3	main
ajani	doc_536541856857_item	3616390	et	3	main
laulsid	doc_536541856857_item	3616378	et	4	main
veel	doc_536541856857_item	3616373	et	4	main
instrumentaalsed	doc_536541856857_item	3616369	et	3	main
väljendada	doc_536541856857_item	3616418	et	3	main
võimalusi	doc_536541856857_item	3616410	et	3	main
alati	doc_536541856857_item	3616408	et	4	main
saarel	doc_536541856857_item	3616400	et	3	main
informatsiooni	doc_536541856857_item	3616392	et	4	main
võime	doc_536541856857_item	3616388	et	4	main
etendused	doc_536541856857_item	3616370	et	4	main
kui	doc_536541856857_item	3616367	et	3	main
funktsioonid	doc_536541856857_item	3616354	et	3	main
vanu	doc_536541856857_item	3616345	et	4	main
viibisid	doc_536541856857_item	3616338	et	4	main
nemad	doc_536541856857_item	3616337	et	3	main
ka	doc_536541856857_item	3616327	et	3	main
nii	doc_536541856857_item	3616324	et	3	main
nendega	doc_536541856857_item	3616321	et	4	main
ja	doc_536541856857_item	3616320	et	3	main
ainult	doc_536541856857_item	3616309	et	4	main
olid	doc_536541856857_item	3616306	et	4	main
rahvalaulust	doc_536541856857_item	3616301	et	4	main
üldistav	doc_536541856857_item	3616262	et	4	main
ja	doc_536541856857_item	3616261	et	3	main
analüüsiv	doc_536541856857_item	3616260	et	4	main
arutlev	doc_536541856857_item	3616259	et	4	main
olema	doc_536541856857_item	3616258	et	4	main
peab	doc_536541856857_item	3616257	et	4	main
essee	doc_536541856857_item	3616256	et	4	main
sõna	doc_536541856857_item	3616255	et	4	main
350	doc_536541856857_item	3616254	et	2	main
300	doc_536541856857_item	3616253	et	2	main
pikkus	doc_536541856857_item	3616252	et	4	main
essee	doc_536541856857_item	3616251	et	4	main
laulurahva	doc_536541856857_item	3616250	et	3	main
eestlastest	doc_536541856857_item	3616249	et	4	main
teeb	doc_536541856857_item	3616248	et	3	main
mis	doc_536541856857_item	3616247	et	4	main
teemal	doc_536541856857_item	3616246	et	3	main
essee	doc_536541856857_item	3616245	et	4	main
kirjutage	doc_536541856857_item	3616244	et	3	main
kirjutamine	doc_536541856857_item	3616243	et	4	main
test	doc_536541856857_item	3616242	et	3	main
keele	doc_536541856857_item	3616241	et	4	main
teise	doc_536541856857_item	3616240	et	4	main
kui	doc_536541856857_item	3616239	et	3	main
keele	doc_536541856857_item	3616238	et	4	main
eesti	doc_536541856857_item	3616237	et	4	main
essee	doc_536541856857_item	3616236	et	4	main
erinevad	doc_536541856857_item	3616353	et	4	main
on	doc_536541856857_item	3616352	et	4	main
lauludel	doc_536541856857_item	3616351	et	3	main
lauljad	doc_536541856857_item	3616357	et	4	main
ning	doc_536541856857_item	3616347	et	3	main
kui	doc_536541856857_item	3616326	et	3	main
püüdsid	doc_536541856857_item	3616317	et	4	main
pillimänguga	doc_536541856857_item	3616313	et	3	main
ka	doc_536541856857_item	3616312	et	3	main
vaid	doc_536541856857_item	3616311	et	3	main
laulmisega	doc_536541856857_item	3616310	et	4	main
rahvalaulust	doc_536541856857_item	3616298	et	4	main
kõik	doc_536541856857_item	3616294	et	4	main
millest	doc_536541856857_item	3616293	et	3	main
sellest	doc_536541856857_item	3616292	et	4	main
alustada	doc_536541856857_item	3616291	et	3	main
tasub	doc_536541856857_item	3616290	et	3	main
aga	doc_536541856857_item	3616289	et	3	main
kõigpealt	doc_536541856857_item	3616288	et	4	main
näideid	doc_536541856857_item	3616287	et	4	main
ja	doc_536541856857_item	3616286	et	3	main
vastuseid	doc_536541856857_item	3616285	et	3	main
küllalt	doc_536541856857_item	3616284	et	4	main
tuua	doc_536541856857_item	3616283	et	3	main
arust	doc_536541856857_item	3616282	et	4	main
minu	doc_536541856857_item	3616281	et	3	main
võib	doc_536541856857_item	3616280	et	3	main
laulurahva	doc_536541856857_item	3616279	et	3	main
eestlastest	doc_536541856857_item	3616278	et	4	main
teeb	doc_536541856857_item	3616277	et	3	main
mis	doc_536541856857_item	3616276	et	4	main
küsimusele	doc_536541856857_item	3616275	et	4	main
sellele	doc_536541856857_item	3616274	et	4	main
näidetega	doc_536541856857_item	3616273	et	3	main
illustreerida	doc_536541856857_item	3616272	et	3	main
soovitatav	doc_536541856857_item	3616271	et	4	main
on	doc_536541856857_item	3616270	et	4	main
väiteid	doc_536541856857_item	3616269	et	4	main
faktidele	doc_536541856857_item	3616268	et	3	main
esitatud	doc_536541856857_item	3616267	et	4	main
lugemistekstis	doc_536541856857_item	3616266	et	3	main
ja	doc_536541856857_item	3616265	et	3	main
loengus	doc_536541856857_item	3616264	et	3	main
tuginema	doc_536541856857_item	3616263	et	3	main
mis	doc_536541856866_item	3616857	et	4	main
mina	doc_536541856866_item	3616850	et	4	main
inimesed	doc_536541856866_item	3616848	et	3	main
noored	doc_536541856866_item	3616847	et	3	main
populaarne	doc_536541856866_item	3616846	et	3	main
sellega	doc_536541856866_item	3616841	et	3	main
hoida	doc_536541856866_item	3616820	et	3	main
ning	doc_536541856866_item	3616816	et	3	main
esinesid	doc_536541856857_item	3616358	et	4	main
lugedes	doc_536541856857_item	3616348	et	3	main
just	doc_536541856857_item	3616333	et	3	main
rolli	doc_536541856857_item	3616332	et	4	main
suurt	doc_536541856857_item	3616331	et	3	main
mängisid	doc_536541856857_item	3616330	et	4	main
naised	doc_536541856857_item	3616329	et	3	main
kirjalikult	doc_536541856857_item	3616328	et	4	main
inimesed	doc_536541856857_item	3616316	et	3	main
tantsuga	doc_536541856857_item	3616315	et	3	main
ja	doc_536541856857_item	3616314	et	3	main
riimilisest	doc_536541856857_item	3616300	et	4	main
ja	doc_536541856857_item	3616299	et	3	main
sellisteks	doc_536541856866_item	3616870	et	4	main
neid	doc_536541856866_item	3616869	et	4	main
teeb	doc_536541856866_item	3616868	et	3	main
hing	doc_536541856866_item	3616867	et	3	main
nende	doc_536541856866_item	3616866	et	4	main
laulurahvas	doc_536541856866_item	3616865	et	4	main
on	doc_536541856866_item	3616864	et	4	main
eestlased	doc_536541856866_item	3616862	et	3	main
peale	doc_536541856866_item	3616861	et	4	main
rokkmuusika	doc_536541856866_item	3616860	et	4	main
rahvalaule	doc_536541856866_item	3616856	et	4	main
kuulata	doc_536541856866_item	3616855	et	4	main
vastu	doc_536541856866_item	3616854	et	3	main
et	doc_536541856866_item	3616843	et	3	main
taastunud	doc_536541856866_item	3616828	et	4	main
toimub	doc_536541856866_item	3616822	et	3	main
tagasi	doc_536541856866_item	3616819	et	3	main
laul	doc_536541856866_item	3616812	et	4	main
rahvale	doc_536541856866_item	3616811	et	3	main
eesti	doc_536541856866_item	3616810	et	4	main
juba	doc_536541856866_item	3616804	et	3	main
ja	doc_536541856866_item	3616795	et	3	main
tekste	doc_536541856866_item	3616794	et	3	main
vanu	doc_536541856866_item	3616793	et	4	main
leidi	doc_536541856866_item	3616792	et	4	main
arhiividest	doc_536541856866_item	3616791	et	3	main
laulupidu	doc_536541856866_item	3616790	et	4	main
koostada	doc_536541856866_item	3616789	et	3	main
vaja	doc_536541856866_item	3616788	et	4	main
oli	doc_536541856866_item	3616787	et	3	main
et	doc_536541856866_item	3616786	et	3	main
oleneb	doc_536541856866_item	3616785	et	3	main
sellest	doc_536541856866_item	3616784	et	4	main
pillidega	doc_536541856866_item	3616783	et	3	main
lauldakse	doc_536541856866_item	3616782	et	3	main
ja	doc_536541856866_item	3616781	et	3	main
autor	doc_536541856866_item	3616780	et	3	main
on	doc_536541856866_item	3616779	et	4	main
nüüd	doc_536541856866_item	3616778	et	4	main
rahvalaulu	doc_536541856866_item	3616777	et	4	main
muutused	doc_536541856866_item	3616776	et	4	main
tulid	doc_536541856866_item	3616775	et	4	main
ka	doc_536541856866_item	3616774	et	3	main
sajandil	doc_536541856866_item	3616773	et	3	main
sel	doc_536541856866_item	3616772	et	3	main
koguda	doc_536541856866_item	3616771	et	3	main
kõiki	doc_536541856866_item	3616767	et	4	main
et	doc_536541856866_item	3616765	et	3	main
on	doc_536541856866_item	3616736	et	4	main
rahvalauludest	doc_536541856866_item	3616735	et	3	main
koor	doc_536541856866_item	3616726	et	4	main
naised	doc_536541856866_item	3616724	et	3	main
ja	doc_536541856866_item	3616721	et	3	main
tea	doc_536541856866_item	3616667	et	4	main
nad	doc_536541856866_item	3616665	et	3	main
mõtlen	doc_536541856866_item	3616661	et	3	main
rahvalaule	doc_536541856866_item	3616659	et	4	main
ei	doc_536541856866_item	3616656	et	4	main
palju	doc_536541856866_item	3616640	et	4	main
mare	doc_536541856866_item	3616633	et	4	main
mitmetel	doc_536541856866_item	3616623	et	4	main
käisime	doc_536541856866_item	3616622	et	3	main
meie	doc_536541856866_item	3616621	et	4	main
aastal	doc_536541856866_item	3616612	et	3	main
kantud	doc_536541856866_item	3616859	et	4	main
ole	doc_536541856866_item	3616853	et	4	main
tõestada	doc_536541856866_item	3616842	et	3	main
ma	doc_536541856866_item	3616838	et	3	main
inimeste	doc_536541856866_item	3616836	et	3	main
rahvalaul	doc_536541856866_item	3616834	et	4	main
eesti	doc_536541856866_item	3616833	et	4	main
rahvariided	doc_536541856866_item	3616832	et	3	main
ja	doc_536541856866_item	3616831	et	3	main
traditsioonid	doc_536541856866_item	3616830	et	3	main
rahvalaulu	doc_536541856866_item	3616829	et	4	main
viljandi	doc_536541856866_item	3616823	et	4	main
traditsioone	doc_536541856866_item	3616818	et	3	main
see	doc_536541856866_item	3616802	et	3	main
toimus	doc_536541856866_item	3616800	et	3	main
aastal	doc_536541856866_item	3616797	et	3	main
nii	doc_536541856866_item	3616751	et	3	main
kuluv	doc_536541856866_item	3616749	et	4	main
uuem	doc_536541856866_item	3616746	et	4	main
see	doc_536541856866_item	3616744	et	3	main
riimiline	doc_536541856866_item	3616742	et	4	main
populaarsemaks	doc_536541856866_item	3616734	et	4	main
regilaule	doc_536541856866_item	3616716	et	4	main
pillideta	doc_536541856866_item	3616715	et	3	main
suuliselt	doc_536541856866_item	3616706	et	4	main
edastatakse	doc_536541856866_item	3616705	et	3	main
neid	doc_536541856866_item	3616704	et	4	main
tunne	doc_536541856866_item	3616669	et	4	main
sõnu	doc_536541856866_item	3616664	et	4	main
mitte	doc_536541856866_item	3616662	et	3	main
ma	doc_536541856866_item	3616660	et	3	main
neid	doc_536541856866_item	3616658	et	4	main
ütlesid	doc_536541856866_item	3616653	et	4	main
mu	doc_536541856866_item	3616651	et	3	main
laulud	doc_536541856866_item	3616647	et	3	main
rahvariide	doc_536541856866_item	3616644	et	4	main
kes	doc_536541856866_item	3616642	et	4	main
muuseumi	doc_536541856866_item	3616634	et	4	main
rohkem	doc_536541856866_item	3616628	et	4	main
kõige	doc_536541856866_item	3616627	et	4	main
valgevenemaalt	doc_536541856866_item	3616620	et	3	main
sugulased	doc_536541856866_item	3616619	et	3	main
tulid	doc_536541856866_item	3616618	et	4	main
sel	doc_536541856866_item	3616611	et	3	main
olema	doc_536541856866_item	3616591	et	4	main
kõik	doc_536541856867_item	3617054	et	4	main
toimuvad	doc_536541856867_item	3617041	et	4	main
tänapäevad	doc_536541856867_item	3617040	et	3	main
käivad	doc_536541856867_item	3617035	et	4	main
tanapaevase	doc_536541856867_item	3617027	et	4	main
laulude	doc_536541856867_item	3617026	et	3	main
vana	doc_536541856867_item	3617025	et	4	main
mitmesugust	doc_536541856867_item	3617023	et	3	main
laulatakse	doc_536541856867_item	3617022	et	4	main
ansambleid	doc_536541856867_item	3617021	et	3	main
on	doc_536541856867_item	3617015	et	4	main
see	doc_536541856867_item	3617014	et	3	main
ja	doc_536541856867_item	3617013	et	3	main
teise	doc_536541856867_item	3617003	et	4	main
nende	doc_536541856867_item	3616997	et	4	main
sündmus	doc_536541856867_item	3616993	et	3	main
eestis	doc_536541856867_item	3616986	et	3	main
kõige	doc_536541856867_item	3616954	et	4	main
sündmustedel	doc_536541856867_item	3616952	et	4	main
pulmadel	doc_536541856867_item	3616950	et	3	main
laulti	doc_536541856867_item	3616948	et	4	main
naised	doc_536541856867_item	3616940	et	3	main
juba	doc_536541856867_item	3616928	et	3	main
teeb	doc_536541856867_item	3616884	et	3	main
mis	doc_536541856867_item	3616883	et	4	main
teemal	doc_536541856867_item	3616882	et	3	main
essee	doc_536541856867_item	3616881	et	4	main
kirjutage	doc_536541856867_item	3616880	et	3	main
näidetega	doc_536541856867_item	3616909	et	3	main
on	doc_536541856867_item	3616906	et	4	main
liikumise	doc_536541856871_item	3617180	et	4	main
rahvusliku	doc_536541856871_item	3617179	et	3	main
eestlaste	doc_536541856871_item	3617178	et	4	main
ja	doc_536541856871_item	3617175	et	3	main
väga	doc_536541856871_item	3617173	et	3	main
puhkpilliorkestrit	doc_536541856871_item	3617170	et	3	main
väljendada	doc_536541856866_item	3616815	et	3	main
ennast	doc_536541856866_item	3616814	et	4	main
aitas	doc_536541856866_item	3616813	et	3	main
oli	doc_536541856866_item	3616803	et	3	main
tallinnas	doc_536541856866_item	3616801	et	4	main
laulupidu	doc_536541856866_item	3616799	et	4	main
riiklik	doc_536541856866_item	3616798	et	3	main
setumaal	doc_536541856866_item	3616760	et	4	main
eestis	doc_536541856866_item	3616759	et	3	main
kui	doc_536541856866_item	3616753	et	3	main
laul	doc_536541856866_item	3616743	et	4	main
ka	doc_536541856866_item	3616741	et	3	main
veel	doc_536541856866_item	3616739	et	4	main
esimene	doc_536541856866_item	3616738	et	3	main
regilaul	doc_536541856866_item	3616730	et	4	main
elab	doc_536541856866_item	3616729	et	3	main
tänapäevani	doc_536541856866_item	3616728	et	3	main
lauldi	doc_536541856866_item	3616714	et	3	main
regilaulud	doc_536541856866_item	3616713	et	3	main
lapselapsele	doc_536541856866_item	3616712	et	4	main
nemad	doc_536541856866_item	3616711	et	3	main
ja	doc_536541856866_item	3616710	et	3	main
oma	doc_536541856866_item	3616708	et	4	main
vanemad	doc_536541856866_item	3616707	et	4	main
ei	doc_536541856866_item	3616699	et	4	main
regilauludel	doc_536541856866_item	3616698	et	3	main
iseendale	doc_536541856866_item	3616697	et	3	main
heinaajal	doc_536541856866_item	3616696	et	3	main
ja	doc_536541856866_item	3616695	et	3	main
lastele	doc_536541856866_item	3616694	et	4	main
oma	doc_536541856866_item	3616693	et	4	main
laulsid	doc_536541856866_item	3616692	et	4	main
tehes	doc_536541856866_item	3616691	et	3	main
käsitöö	doc_536541856866_item	3616690	et	4	main
naised	doc_536541856866_item	3616689	et	3	main
laulsid	doc_536541856866_item	3616688	et	4	main
mis	doc_536541856866_item	3616687	et	4	main
laulud	doc_536541856866_item	3616686	et	3	main
olid	doc_536541856866_item	3616685	et	4	main
need	doc_536541856866_item	3616684	et	3	main
regilauludeks	doc_536541856866_item	3616683	et	3	main
arenema	doc_536541856866_item	3616682	et	3	main
hakkas	doc_536541856866_item	3616681	et	3	main
laulukuns	doc_536541856866_item	3616680	et	4	main
eestlaste	doc_536541856866_item	3616679	et	4	main
õhtu	doc_536541856866_item	3616678	et	4	main
rahvalaulu	doc_536541856866_item	3616677	et	4	main
jätis	doc_536541856866_item	3616676	et	4	main
mulje	doc_536541856866_item	3616675	et	4	main
sellise	doc_536541856866_item	3616674	et	4	main
miks	doc_536541856866_item	3616673	et	4	main
mõtlema	doc_536541856866_item	3616672	et	3	main
ma	doc_536541856866_item	3616671	et	3	main
vaid	doc_536541856866_item	3616668	et	3	main
laul	doc_536541856866_item	3616750	et	4	main
sajandile	doc_536541856866_item	3616748	et	3	main
on	doc_536541856866_item	3616740	et	4	main
aastatega	doc_536541856866_item	3616733	et	3	main
muutub	doc_536541856866_item	3616732	et	3	main
ja	doc_536541856866_item	3616731	et	3	main
solo	doc_536541856866_item	3616725	et	4	main
mehed	doc_536541856866_item	3616723	et	3	main
laulufunktsioonist	doc_536541856866_item	3616720	et	3	main
lastele	doc_536541856866_item	3616709	et	4	main
ole	doc_536541856866_item	3616700	et	4	main
kunagi	doc_536541856866_item	3616655	et	3	main
ja	doc_536541856866_item	3616650	et	3	main
ja	doc_536541856866_item	3616648	et	3	main
kandsid	doc_536541856866_item	3616643	et	4	main
seal	doc_536541856866_item	3616638	et	4	main
päeval	doc_536541856866_item	3616637	et	3	main
sel	doc_536541856866_item	3616636	et	3	main
külastamine	doc_536541856866_item	3616635	et	4	main
al	doc_536541856866_item	3616632	et	4	main
jäi	doc_536541856866_item	3616629	et	3	main
kuu	doc_536541856866_item	3616614	et	4	main
augusti	doc_536541856866_item	3616613	et	3	main
teeb	doc_536541856866_item	3616608	et	3	main
soovitatav	doc_536541856866_item	3616604	et	4	main
väiteid	doc_536541856866_item	3616602	et	4	main
faktidele	doc_536541856866_item	3616601	et	3	main
analüüsiv	doc_536541856866_item	3616593	et	4	main
350	doc_536541856866_item	3616587	et	2	main
pikkus	doc_536541856866_item	3616585	et	4	main
laulurahva	doc_536541856866_item	3616583	et	3	main
eestlastest	doc_536541856866_item	3616582	et	4	main
teeb	doc_536541856866_item	3616581	et	3	main
laulurahva	doc_536541856867_item	3617058	et	3	main
et	doc_536541856867_item	3617053	et	3	main
laulu	doc_536541856867_item	3617049	et	4	main
sõbrad	doc_536541856867_item	3617037	et	3	main
sinna	doc_536541856867_item	3617034	et	3	main
laule	doc_536541856867_item	3617024	et	4	main
laulavad	doc_536541856867_item	3617018	et	4	main
pidu	doc_536541856867_item	3617017	et	4	main
suur	doc_536541856867_item	3617016	et	3	main
1	doc_536541856867_item	3617009	et	2	main
laul	doc_536541856867_item	3617002	et	4	main
oli	doc_536541856867_item	3616996	et	3	main
tartus	doc_536541856867_item	3616989	et	3	main
ei	doc_536541856866_item	3616666	et	4	main
sõnu	doc_536541856866_item	3616663	et	4	main
et	doc_536541856866_item	3616654	et	3	main
sugulased	doc_536541856866_item	3616652	et	3	main
inimesi	doc_536541856866_item	3616641	et	4	main
nendele	doc_536541856866_item	3616626	et	4	main
vaid	doc_536541856866_item	3616625	et	3	main
juurde	doc_536541856866_item	3616617	et	4	main
minu	doc_536541856866_item	3616616	et	3	main
laulurahva	doc_536541856866_item	3616610	et	3	main
näidetega	doc_536541856866_item	3616606	et	3	main
illustreerida	doc_536541856866_item	3616605	et	3	main
on	doc_536541856866_item	3616603	et	4	main
ja	doc_536541856866_item	3616598	et	3	main
tuginema	doc_536541856866_item	3616596	et	3	main
ja	doc_536541856866_item	3616594	et	3	main
sõna	doc_536541856866_item	3616588	et	4	main
essee	doc_536541856866_item	3616584	et	4	main
essee	doc_536541856866_item	3616578	et	4	main
kirjutage	doc_536541856866_item	3616577	et	3	main
kirjutamine	doc_536541856866_item	3616576	et	4	main
test	doc_536541856866_item	3616575	et	3	main
keele	doc_536541856866_item	3616574	et	4	main
teise	doc_536541856866_item	3616573	et	4	main
kui	doc_536541856866_item	3616572	et	3	main
keele	doc_536541856866_item	3616571	et	4	main
eesti	doc_536541856866_item	3616570	et	4	main
essee	doc_536541856866_item	3616569	et	4	main
rocca	doc_536541856866_item	3616631	et	4	main
mällu	doc_536541856866_item	3616630	et	3	main
mis	doc_536541856866_item	3616607	et	4	main
üldistav	doc_536541856866_item	3616595	et	4	main
peab	doc_536541856866_item	3616590	et	4	main
300	doc_536541856866_item	3616586	et	2	main
mis	doc_536541856866_item	3616580	et	4	main
teeb	doc_536541856867_item	3617056	et	3	main
ma	doc_536541856867_item	3617051	et	3	main
maailma	doc_536541856867_item	3617048	et	4	main
osaleb	doc_536541856867_item	3617047	et	3	main
eesti	doc_536541856867_item	3617046	et	4	main
saatega	doc_536541856867_item	3617045	et	3	main
laulude	doc_536541856867_item	3617044	et	3	main
inimesi	doc_536541856867_item	3617039	et	4	main
kord	doc_536541856867_item	3617010	et	4	main
tallinnas	doc_536541856867_item	3617007	et	4	main
toimub	doc_536541856867_item	3617006	et	3	main
siiamani	doc_536541856867_item	3617005	et	4	main
päevast	doc_536541856867_item	3617000	et	4	main
ajal	doc_536541856867_item	3616958	et	4	main
laulti	doc_536541856867_item	3616956	et	4	main
mitmesuguste	doc_536541856867_item	3616951	et	3	main
käsitöö	doc_536541856867_item	3616942	et	4	main
ei	doc_536541856867_item	3616933	et	4	main
varem	doc_536541856867_item	3616932	et	4	main
essee	doc_536541856867_item	3616887	et	4	main
laulurahva	doc_536541856867_item	3616886	et	3	main
eestlastest	doc_536541856867_item	3616885	et	4	main
eesti	doc_536541856867_item	3616873	et	4	main
essee	doc_536541856867_item	3616872	et	4	main
vanast	doc_536541856867_item	3616911	et	3	main
juba	doc_536541856867_item	3616910	et	3	main
illustreerida	doc_536541856867_item	3616908	et	3	main
väiteid	doc_536541856867_item	3616905	et	4	main
faktidele	doc_536541856867_item	3616904	et	3	main
esitatud	doc_536541856867_item	3616903	et	4	main
lugemistekstis	doc_536541856867_item	3616902	et	3	main
anse	doc_536541856871_item	3617160	et	4	main
siis	doc_536541856871_item	3617153	et	3	main
sajandil	doc_536541856871_item	3617144	et	3	main
tuli	doc_536541856871_item	3617142	et	4	main
rahvalaul	doc_536541856871_item	3617141	et	4	main
enam	doc_536541856871_item	3617124	et	4	main
vanal	doc_536541856871_item	3617118	et	3	main
eestlastest	doc_536541856871_item	3617107	et	4	main
lugemistekstis	doc_536541856871_item	3617090	et	3	main
ja	doc_536541856871_item	3617089	et	3	main
loengus	doc_536541856871_item	3617088	et	3	main
tuginema	doc_536541856871_item	3617087	et	3	main
üldistav	doc_536541856871_item	3617086	et	4	main
ja	doc_536541856871_item	3617085	et	3	main
analüüsiv	doc_536541856871_item	3617084	et	4	main
sõna	doc_536541856871_item	3617079	et	4	main
essee	doc_536541856871_item	3617069	et	4	main
eesti	doc_536541856871_item	3617061	et	4	main
essee	doc_536541856871_item	3617060	et	4	main
andekad	doc_536541856871_item	3617302	et	3	main
eestis	doc_536541856871_item	3617299	et	3	main
noorte	doc_536541856871_item	3617296	et	3	main
mina	doc_536541856871_item	3617285	et	4	main
aga	doc_536541856871_item	3617284	et	3	main
laulda	doc_536541856871_item	3617283	et	4	main
rõõmu	doc_536541856871_item	3617277	et	4	main
on	doc_536541856871_item	3617248	et	4	main
kooris	doc_536541856871_item	3617237	et	4	main
aastal	doc_536541856871_item	3617194	et	3	main
laulupeod	doc_536541856871_item	3617187	et	4	main
veel	doc_536541856871_item	3617185	et	4	main
olid	doc_536541856871_item	3617184	et	4	main
jooksuga	doc_536541856871_item	3617183	et	3	main
kõik	doc_536541856872_item	3617524	et	4	main
laulda	doc_536541856872_item	3617523	et	4	main
perega	doc_536541856872_item	3617516	et	3	main
sinna	doc_536541856872_item	3617513	et	3	main
eesti	doc_536541856872_item	3617508	et	4	main
arm	doc_536541856872_item	3617507	et	3	main
minu	doc_536541856872_item	3617506	et	3	main
peost	doc_536541856872_item	3617490	et	4	main
arv	doc_536541856872_item	3617485	et	3	main
pärast	doc_536541856872_item	3617482	et	4	main
eestlaste	doc_536541856872_item	3617480	et	4	main
sündmus	doc_536541856872_item	3617479	et	3	main
see	doc_536541856867_item	3617055	et	3	main
arvan	doc_536541856867_item	3617052	et	3	main
üritusi	doc_536541856867_item	3617043	et	4	main
on	doc_536541856867_item	3617030	et	4	main
see	doc_536541856867_item	3617029	et	3	main
lauludeni	doc_536541856867_item	3617028	et	3	main
koore	doc_536541856867_item	3617020	et	4	main
aastades	doc_536541856867_item	3617012	et	4	main
4	doc_536541856867_item	3617011	et	2	main
laulupidu	doc_536541856867_item	3617008	et	4	main
sai	doc_536541856867_item	3617001	et	4	main
see	doc_536541856867_item	3616995	et	3	main
suur	doc_536541856867_item	3616992	et	3	main
esimene	doc_536541856867_item	3616987	et	3	main
toimus	doc_536541856867_item	3616985	et	3	main
juba	doc_536541856867_item	3616982	et	3	main
19	doc_536541856867_item	3616983	et	2	main
ja	doc_536541856867_item	3616981	et	3	main
saateks	doc_536541856867_item	3616980	et	3	main
tantsu	doc_536541856867_item	3616979	et	4	main
ka	doc_536541856867_item	3616978	et	3	main
laule	doc_536541856867_item	3616977	et	4	main
kasutama	doc_536541856867_item	3616976	et	3	main
hakkati	doc_536541856867_item	3616975	et	3	main
ka	doc_536541856867_item	3616974	et	3	main
kiruku	doc_536541856867_item	3616973	et	4	main
aga	doc_536541856867_item	3616972	et	3	main
laule	doc_536541856867_item	3616971	et	4	main
muinasjuttu	doc_536541856867_item	3616970	et	4	main
laulti	doc_536541856867_item	3616969	et	4	main
salme	doc_536541856867_item	3616968	et	4	main
laule	doc_536541856867_item	3616967	et	4	main
kirjutama	doc_536541856867_item	3616966	et	3	main
hakkati	doc_536541856867_item	3616964	et	3	main
ümber	doc_536541856867_item	3616965	et	3	main
levima	doc_536541856867_item	3616963	et	3	main
laul	doc_536541856867_item	3616962	et	4	main
hakkas	doc_536541856867_item	3616961	et	3	main
pärast	doc_536541856867_item	3616960	et	4	main
kirukus	doc_536541856867_item	3616959	et	4	main
aga	doc_536541856867_item	3616953	et	3	main
ka	doc_536541856867_item	3616949	et	3	main
ajal	doc_536541856867_item	3616947	et	4	main
mängu	doc_536541856867_item	3616946	et	4	main
lapsega	doc_536541856867_item	3616945	et	3	main
olnud	doc_536541856867_item	3616934	et	4	main
ammu	doc_536541856867_item	3616929	et	4	main
levinud	doc_536541856867_item	3616926	et	4	main
test	doc_536541856867_item	3616878	et	3	main
kui	doc_536541856867_item	3616875	et	3	main
kõrghetk	doc_536541856871_item	3617181	et	3	main
sellest	doc_536541856871_item	3617176	et	4	main
palju	doc_536541856871_item	3617174	et	4	main
see	doc_536541856871_item	3617171	et	3	main
5	doc_536541856871_item	3617169	et	2	main
ühislaulmised	doc_536541856871_item	3617157	et	3	main
toimusid	doc_536541856871_item	3617154	et	4	main
palju	doc_536541856867_item	3617038	et	4	main
pered	doc_536541856867_item	3617036	et	3	main
pidu	doc_536541856867_item	3617033	et	4	main
suur	doc_536541856867_item	3617032	et	3	main
tõeliselt	doc_536541856867_item	3617031	et	4	main
palju	doc_536541856867_item	3617019	et	4	main
tähtsust	doc_536541856867_item	3617004	et	4	main
sellest	doc_536541856867_item	3616999	et	4	main
ärkamisaeg	doc_536541856867_item	3616998	et	3	main
eestlastele	doc_536541856867_item	3616994	et	4	main
oli	doc_536541856867_item	3616991	et	3	main
see	doc_536541856867_item	3616990	et	3	main
laulupidu	doc_536541856867_item	3616988	et	4	main
s-dil	doc_536541856867_item	3616984	et	4	main
rohkem	doc_536541856867_item	3616955	et	4	main
laulsid	doc_536541856867_item	3616944	et	4	main
ajal	doc_536541856867_item	3616943	et	4	main
näiteks	doc_536541856867_item	3616939	et	4	main
laulti	doc_536541856867_item	3616937	et	4	main
peod	doc_536541856867_item	3616936	et	4	main
mitmesuguseid	doc_536541856867_item	3616935	et	3	main
ajast	doc_536541856867_item	3616931	et	4	main
vanast	doc_536541856867_item	3616930	et	3	main
keele	doc_536541856867_item	3616877	et	4	main
keele	doc_536541856867_item	3616874	et	4	main
kujunes	doc_536541856871_item	3617177	et	3	main
oli	doc_536541856871_item	3617172	et	3	main
meeskoori	doc_536541856871_item	3617167	et	4	main
46	doc_536541856871_item	3617166	et	2	main
osales	doc_536541856871_item	3617165	et	3	main
põlvas	doc_536541856871_item	3617159	et	4	main
muusika	doc_536541856871_item	3617151	et	4	main
laulutraditsiooni	doc_536541856871_item	3617134	et	4	main
vanemat	doc_536541856871_item	3617133	et	4	main
aga	doc_536541856871_item	3617129	et	3	main
kui	doc_536541856871_item	3617125	et	3	main
ajal	doc_536541856871_item	3617119	et	4	main
veel	doc_536541856871_item	3617115	et	4	main
ja	doc_536541856871_item	3617113	et	3	main
mõeldud	doc_536541856871_item	3617112	et	4	main
olid	doc_536541856871_item	3617111	et	4	main
millised	doc_536541856871_item	3617110	et	3	main
laulurahva	doc_536541856871_item	3617106	et	3	main
eestlastest	doc_536541856871_item	3617100	et	4	main
teeb	doc_536541856871_item	3617099	et	3	main
illustreerida	doc_536541856871_item	3617096	et	3	main
väiteid	doc_536541856871_item	3617093	et	4	main
350	doc_536541856871_item	3617078	et	2	main
essee	doc_536541856871_item	3617075	et	4	main
laulurahva	doc_536541856871_item	3617074	et	3	main
eestlastest	doc_536541856871_item	3617073	et	4	main
teeb	doc_536541856871_item	3617072	et	3	main
mis	doc_536541856871_item	3617071	et	4	main
teemal	doc_536541856871_item	3617070	et	3	main
teise	doc_536541856871_item	3617064	et	4	main
on	doc_536541856871_item	3617300	et	4	main
kuulaksin	doc_536541856871_item	3617294	et	3	main
sportlane	doc_536541856871_item	3617292	et	3	main
inimestele	doc_536541856871_item	3617276	et	3	main
annavad	doc_536541856871_item	3617275	et	3	main
laul	doc_536541856871_item	3617274	et	4	main
ja	doc_536541856871_item	3617273	et	3	main
vanal	doc_536541856867_item	3616957	et	3	main
laulsid	doc_536541856867_item	3616941	et	4	main
kodus	doc_536541856867_item	3616938	et	4	main
laul	doc_536541856867_item	3616927	et	4	main
on	doc_536541856867_item	3616925	et	4	main
eestis	doc_536541856867_item	3616924	et	3	main
peod	doc_536541856867_item	3616923	et	4	main
ja	doc_536541856867_item	3616922	et	3	main
muusika	doc_536541856867_item	3616921	et	4	main
traditsioonid	doc_536541856867_item	3616920	et	3	main
laulud	doc_536541856867_item	3616919	et	3	main
oma	doc_536541856867_item	3616918	et	4	main
on	doc_536541856867_item	3616917	et	4	main
ajal	doc_536541856867_item	3616916	et	4	main
igal	doc_536541856867_item	3616915	et	3	main
inimesed	doc_536541856867_item	3616914	et	3	main
laulavad	doc_536541856867_item	3616913	et	4	main
ajast	doc_536541856867_item	3616912	et	4	main
ja	doc_536541856867_item	3616901	et	3	main
loengus	doc_536541856867_item	3616900	et	3	main
tuginema	doc_536541856867_item	3616899	et	3	main
üldistav	doc_536541856867_item	3616898	et	4	main
ja	doc_536541856867_item	3616897	et	3	main
analüüsiv	doc_536541856867_item	3616896	et	4	main
arutlev	doc_536541856867_item	3616895	et	4	main
olema	doc_536541856867_item	3616894	et	4	main
peab	doc_536541856867_item	3616893	et	4	main
essee	doc_536541856867_item	3616892	et	4	main
sõna	doc_536541856867_item	3616891	et	4	main
350	doc_536541856867_item	3616890	et	2	main
300	doc_536541856867_item	3616889	et	2	main
pikkus	doc_536541856867_item	3616888	et	4	main
kirjutamine	doc_536541856867_item	3616879	et	4	main
teise	doc_536541856867_item	3616876	et	4	main
soovitatav	doc_536541856867_item	3616907	et	4	main
ju	doc_536541856871_item	3617328	et	3	main
laularahv	doc_536541856871_item	3617329	et	4	main
on	doc_536541856871_item	3617327	et	4	main
eestlased	doc_536541856871_item	3617326	et	3	main
laulukooris	doc_536541856871_item	3617325	et	4	main
võimalusi	doc_536541856871_item	3617324	et	3	main
oma	doc_536541856871_item	3617323	et	4	main
proovida	doc_536541856871_item	3617322	et	3	main
võivad	doc_536541856871_item	3617321	et	4	main
kõik	doc_536541856871_item	3617320	et	4	main
tore	doc_536541856871_item	3617319	et	3	main
väga	doc_536541856871_item	3617318	et	3	main
see	doc_536541856871_item	3617316	et	3	main
on	doc_536541856871_item	3617317	et	4	main
ja	doc_536541856871_item	3617315	et	3	main
eestis	doc_536541856871_item	3617314	et	3	main
laulupeost	doc_536541856871_item	3617313	et	4	main
tähtsamaid	doc_536541856871_item	3617312	et	4	main
kõige	doc_536541856871_item	3617311	et	4	main
üks	doc_536541856871_item	3617310	et	3	main
on	doc_536541856871_item	3617309	et	4	main
arvates	doc_536541856871_item	3617308	et	4	main
minu	doc_536541856871_item	3617307	et	3	main
laulupidu	doc_536541856871_item	3617306	et	4	main
muusikasfääris	doc_536541856871_item	3617305	et	3	main
ja	doc_536541856871_item	3617304	et	3	main
laulu-	doc_536541856871_item	3617303	et	4	main
ülemaalisel	doc_536541856871_item	3617163	et	4	main
esimesel	doc_536541856871_item	3617162	et	3	main
külas	doc_536541856871_item	3617161	et	3	main
naiteks	doc_536541856871_item	3617158	et	4	main
kujunenud	doc_536541856871_item	3617149	et	4	main
on	doc_536541856871_item	3617147	et	4	main
nimetus	doc_536541856871_item	3617138	et	4	main
mille	doc_536541856871_item	3617137	et	3	main
rahvalaul	doc_536541856871_item	3617136	et	4	main
eesti	doc_536541856871_item	3617132	et	4	main
tuhat	doc_536541856871_item	3617126	et	4	main
kujunenud	doc_536541856871_item	3617123	et	4	main
ammu	doc_536541856871_item	3617117	et	4	main
teevad	doc_536541856871_item	3617108	et	3	main
esiteks	doc_536541856871_item	3617105	et	3	main
et	doc_536541856871_item	3617104	et	3	main
mis	doc_536541856871_item	3617098	et	4	main
näidetega	doc_536541856871_item	3617097	et	3	main
on	doc_536541856871_item	3617094	et	4	main
faktidele	doc_536541856871_item	3617092	et	3	main
esitatud	doc_536541856871_item	3617091	et	4	main
peab	doc_536541856871_item	3617081	et	4	main
kirjutage	doc_536541856871_item	3617068	et	3	main
väga	doc_536541856871_item	3617301	et	3	main
noored	doc_536541856871_item	3617298	et	3	main
vaid	doc_536541856871_item	3617293	et	3	main
olen	doc_536541856871_item	3617291	et	3	main
sfääri	doc_536541856871_item	3617289	et	4	main
muud	doc_536541856871_item	3617288	et	4	main
kooris	doc_536541856871_item	3617282	et	4	main
väga	doc_536541856871_item	3617249	et	3	main
või	doc_536541856871_item	3617238	et	4	main
ta	doc_536541856871_item	3617196	et	4	main
aja	doc_536541856871_item	3617182	et	4	main
teisega	doc_536541856872_item	3617530	et	4	main
teine	doc_536541856872_item	3617529	et	3	main
tansida	doc_536541856872_item	3617528	et	4	main
rahvajõudu	doc_536541856872_item	3617527	et	4	main
võimalus	doc_536541856872_item	3617522	et	3	main
laulupidu	doc_536541856872_item	3617509	et	4	main
kandus	doc_536541856872_item	3617491	et	3	main
osavõtjate	doc_536541856872_item	3617484	et	3	main
see	doc_536541856872_item	3617474	et	3	main
esimene	doc_536541856872_item	3617457	et	3	main
väga	doc_536541856872_item	3617447	et	3	main
rahvakostüümides	doc_536541856872_item	3617444	et	3	main
kingitasid	doc_536541856872_item	3617431	et	4	main
kadripäev	doc_536541856872_item	3617419	et	3	main
väga	doc_536541856872_item	3617416	et	3	main
pillisaateta	doc_536541856872_item	3617403	et	3	main
laulsid	doc_536541856872_item	3617400	et	4	main
või	doc_536541856872_item	3617397	et	4	main
kooriga	doc_536541856872_item	3617396	et	4	main
olla	doc_536541856872_item	3617388	et	3	main
neiusid	doc_536541856872_item	3617385	et	3	main
iseloomu	doc_536541856872_item	3617382	et	4	main
näitab	doc_536541856872_item	3617380	et	3	main
illustreerida	doc_536541856872_item	3617367	et	3	main
ja	doc_536541856871_item	3617168	et	3	main
laulupeol	doc_536541856871_item	3617164	et	4	main
eestlaste	doc_536541856871_item	3617156	et	4	main
igasugused	doc_536541856871_item	3617155	et	3	main
euroopa	doc_536541856871_item	3617150	et	4	main
välja	doc_536541856871_item	3617148	et	4	main
laulud	doc_536541856871_item	3617146	et	3	main
need	doc_536541856871_item	3617145	et	3	main
19	doc_536541856871_item	3617143	et	2	main
uuem	doc_536541856871_item	3617135	et	4	main
esindab	doc_536541856871_item	3617131	et	3	main
aastat	doc_536541856871_item	3617127	et	3	main
rahvalaul	doc_536541856871_item	3617121	et	4	main
regivärsiline	doc_536541856871_item	3617120	et	4	main
väga	doc_536541856871_item	3617116	et	3	main
organiseeritud	doc_536541856871_item	3617114	et	4	main
arvan	doc_536541856871_item	3617103	et	3	main
soovitatav	doc_536541856871_item	3617095	et	4	main
arutlev	doc_536541856871_item	3617083	et	4	main
olema	doc_536541856871_item	3617082	et	4	main
300	doc_536541856871_item	3617077	et	2	main
pikkus	doc_536541856871_item	3617076	et	4	main
kui	doc_536541856871_item	3617063	et	3	main
keele	doc_536541856871_item	3617062	et	4	main
koori	doc_536541856871_item	3617297	et	4	main
rõõmusega	doc_536541856871_item	3617295	et	3	main
mina	doc_536541856871_item	3617290	et	4	main
ka	doc_536541856871_item	3617281	et	3	main
tahaksin	doc_536541856871_item	3617280	et	3	main
mina	doc_536541856871_item	3617279	et	4	main
ilus	doc_536541856871_item	3617250	et	4	main
hulgas	doc_536541856871_item	3617246	et	4	main
laulda	doc_536541856871_item	3617236	et	4	main
suured	doc_536541856871_item	3617204	et	3	main
väga	doc_536541856871_item	3617203	et	3	main
on	doc_536541856871_item	3617202	et	4	main
inimestel	doc_536541856871_item	3617201	et	3	main
ka	doc_536541856871_item	3617200	et	3	main
päeval	doc_536541856871_item	3617199	et	3	main
tänasel	doc_536541856871_item	3617198	et	3	main
toimub	doc_536541856871_item	3617197	et	3	main
oli	doc_536541856871_item	3617192	et	3	main
laulupidu	doc_536541856871_item	3617191	et	4	main
lauluväljakul	doc_536541856871_item	3617189	et	3	main
traditsioon	doc_536541856872_item	3617537	et	3	main
see	doc_536541856872_item	3617534	et	3	main
teisega	doc_536541856872_item	3617533	et	4	main
teine	doc_536541856872_item	3617532	et	3	main
suhelda	doc_536541856872_item	3617531	et	4	main
koos	doc_536541856872_item	3617525	et	4	main
on	doc_536541856872_item	3617521	et	4	main
sugulastega	doc_536541856872_item	3617517	et	4	main
koos	doc_536541856872_item	3617515	et	4	main
rahvapidu	doc_536541856872_item	3617512	et	4	main
suur	doc_536541856872_item	3617511	et	3	main
on	doc_536541856872_item	3617510	et	4	main
on	doc_536541856872_item	3617505	et	4	main
isamaa	doc_536541856872_item	3617504	et	4	main
100	doc_536541856872_item	3617499	et	2	main
ja	doc_536541856872_item	3617487	et	3	main
muusikaline	doc_536541856872_item	3617478	et	4	main
suur	doc_536541856872_item	3617477	et	3	main
väga	doc_536541856872_item	3617476	et	3	main
palju	doc_536541856872_item	3617466	et	4	main
tartus	doc_536541856872_item	3617462	et	3	main
ülemaaline	doc_536541856872_item	3617458	et	4	main
ma	doc_536541856872_item	3617449	et	3	main
tansivad	doc_536541856872_item	3617443	et	4	main
laulsid	doc_536541856872_item	3617440	et	4	main
ja	doc_536541856872_item	3617438	et	3	main
teist	doc_536541856872_item	3617437	et	4	main
õnnetlesid	doc_536541856872_item	3617435	et	4	main
teine	doc_536541856872_item	3617433	et	3	main
teisega	doc_536541856872_item	3617430	et	4	main
teine	doc_536541856872_item	3617429	et	3	main
vaslapäev	doc_536541856872_item	3617422	et	4	main
jõulud	doc_536541856872_item	3617421	et	3	main
tööl	doc_536541856872_item	3617409	et	3	main
põllul	doc_536541856872_item	3617408	et	3	main
pulmadel	doc_536541856872_item	3617406	et	3	main
regilaulud	doc_536541856872_item	3617404	et	3	main
mõjul	doc_536541856871_item	3617152	et	4	main
riimilise	doc_536541856871_item	3617140	et	4	main
on	doc_536541856871_item	3617139	et	4	main
ta	doc_536541856871_item	3617130	et	4	main
tagasi	doc_536541856871_item	3617128	et	3	main
on	doc_536541856871_item	3617122	et	4	main
laulupeod	doc_536541856871_item	3617109	et	4	main
mina	doc_536541856871_item	3617102	et	4	main
laulurahva	doc_536541856871_item	3617101	et	3	main
essee	doc_536541856871_item	3617080	et	4	main
kirjutamine	doc_536541856871_item	3617067	et	4	main
test	doc_536541856871_item	3617066	et	3	main
keele	doc_536541856871_item	3617065	et	4	main
natuke	doc_536541856871_item	3617287	et	4	main
valisin	doc_536541856871_item	3617286	et	3	main
armastust	doc_536541856871_item	3617278	et	4	main
muusika	doc_536541856871_item	3617272	et	4	main
seda	doc_536541856871_item	3617271	et	3	main
kordab	doc_536541856871_item	3617270	et	3	main
koor	doc_536541856871_item	3617269	et	4	main
aga	doc_536541856871_item	3617268	et	3	main
laulab	doc_536541856871_item	3617267	et	3	main
eeslaulja	doc_536541856871_item	3617266	et	4	main
seal	doc_536541856871_item	3617265	et	4	main
aga	doc_536541856871_item	3617264	et	3	main
noored	doc_536541856871_item	3617263	et	3	main
laulavad	doc_536541856871_item	3617262	et	4	main
kus	doc_536541856871_item	3617261	et	3	main
koorid	doc_536541856871_item	3617260	et	4	main
igasugused	doc_536541856871_item	3617259	et	3	main
ka	doc_536541856871_item	3617258	et	3	main
on	doc_536541856871_item	3617256	et	4	main
praegu	doc_536541856871_item	3617257	et	3	main
kirikus	doc_536541856871_item	3617255	et	3	main
võimalused	doc_536541856871_item	3617254	et	3	main
suured	doc_536541856871_item	3617253	et	3	main
ja	doc_536541856871_item	3617252	et	3	main
hääl	doc_536541856871_item	3617251	et	3	main
neil	doc_536541856871_item	3617247	et	4	main
noorte	doc_536541856871_item	3617245	et	3	main
populaarne	doc_536541856871_item	3617244	et	3	main
väga	doc_536541856871_item	3617243	et	3	main
on	doc_536541856871_item	3617242	et	4	main
festivalis	doc_536541856871_item	3617241	et	3	main
folkloori	doc_536541856871_item	3617240	et	4	main
muud	doc_536541856871_item	3617235	et	4	main
ja	doc_536541856871_item	3617234	et	3	main
kus	doc_536541856871_item	3617195	et	3	main
igasugused	doc_536541856871_item	3617186	et	3	main
on	doc_536541856872_item	3617535	et	4	main
sõpradega	doc_536541856872_item	3617519	et	3	main
ja	doc_536541856872_item	3617518	et	3	main
mu	doc_536541856872_item	3617503	et	3	main
alates	doc_536541856872_item	3617488	et	3	main
jannseniga	doc_536541856872_item	3617473	et	4	main
voldemar	doc_536541856872_item	3617472	et	4	main
vanemuise	doc_536541856872_item	3617470	et	4	main
esitas	doc_536541856872_item	3617469	et	3	main
vägi	doc_536541856872_item	3617465	et	3	main
kus	doc_536541856872_item	3617463	et	3	main
1869	doc_536541856872_item	3617460	et	2	main
sündmüs	doc_536541856872_item	3617453	et	4	main
tähtsam	doc_536541856872_item	3617452	et	4	main
mõtlen	doc_536541856872_item	3617450	et	3	main
olid	doc_536541856872_item	3617446	et	4	main
ja	doc_536541856872_item	3617441	et	3	main
palju	doc_536541856872_item	3617427	et	4	main
päevades	doc_536541856872_item	3617426	et	3	main
võistelda	doc_536541856871_item	3617239	et	4	main
lõtspiil	doc_536541856871_item	3617233	et	4	main
kannel	doc_536541856871_item	3617232	et	4	main
näiteks	doc_536541856871_item	3617231	et	4	main
muusika-instrumente	doc_536541856871_item	3617230	et	3	main
palju	doc_536541856871_item	3617229	et	4	main
väga	doc_536541856871_item	3617228	et	3	main
on	doc_536541856871_item	3617227	et	4	main
eestis	doc_536541856871_item	3617226	et	3	main
ka	doc_536541856871_item	3617225	et	3	main
tahavad	doc_536541856871_item	3617224	et	3	main
kes	doc_536541856871_item	3617223	et	4	main
inimesed	doc_536541856871_item	3617222	et	3	main
kõik	doc_536541856871_item	3617221	et	4	main
astuda	doc_536541856871_item	3617220	et	3	main
võivad	doc_536541856871_item	3617219	et	4	main
kuhu	doc_536541856871_item	3617218	et	3	main
gruppe	doc_536541856871_item	3617217	et	3	main
ja	doc_536541856871_item	3617216	et	3	main
festivali	doc_536541856871_item	3617215	et	4	main
folkloore	doc_536541856871_item	3617214	et	4	main
palju	doc_536541856871_item	3617213	et	4	main
väga	doc_536541856871_item	3617212	et	3	main
on	doc_536541856871_item	3617211	et	4	main
eestis	doc_536541856871_item	3617210	et	3	main
laulda	doc_536541856871_item	3617209	et	4	main
kooris	doc_536541856871_item	3617208	et	4	main
muusikaga	doc_536541856871_item	3617207	et	3	main
tegeleda	doc_536541856871_item	3617206	et	3	main
võimalused	doc_536541856871_item	3617205	et	3	main
1928	doc_536541856871_item	3617193	et	2	main
esimene	doc_536541856871_item	3617190	et	3	main
aga	doc_536541856871_item	3617188	et	3	main
ajaloo	doc_536541856872_item	3617536	et	4	main
tunneta	doc_536541856872_item	3617526	et	4	main
seal	doc_536541856872_item	3617520	et	4	main
tullakse	doc_536541856872_item	3617514	et	3	main
isamalaul	doc_536541856872_item	3617502	et	4	main
kõlas	doc_536541856872_item	3617501	et	4	main
aastapäeval	doc_536541856872_item	3617500	et	3	main
üldlaulupidude	doc_536541856872_item	3617498	et	4	main
poistekoorid	doc_536541856872_item	3617497	et	3	main
ja	doc_536541856872_item	3617496	et	3	main
lastekoorid	doc_536541856872_item	3617495	et	3	main
esinema	doc_536541856872_item	3617494	et	3	main
alustasid	doc_536541856872_item	3617493	et	4	main
tallinnasse	doc_536541856872_item	3617492	et	3	main
kuuendast	doc_536541856872_item	3617489	et	3	main
kasvas	doc_536541856872_item	3617486	et	3	main
laulupeost	doc_536541856872_item	3617483	et	4	main
jaoks	doc_536541856872_item	3617481	et	4	main
seal	doc_536541856872_item	3617468	et	4	main
oli	doc_536541856872_item	3617464	et	3	main
aastal	doc_536541856872_item	3617461	et	3	main
laulupidu	doc_536541856872_item	3617459	et	4	main
on	doc_536541856872_item	3617456	et	4	main
ajaloos	doc_536541856872_item	3617455	et	4	main
et	doc_536541856872_item	3617451	et	3	main
tansisid	doc_536541856872_item	3617442	et	4	main
teisel	doc_536541856872_item	3617411	et	4	main
laulsid	doc_536541856872_item	3617395	et	4	main
nad	doc_536541856872_item	3617394	et	3	main
mõnikord	doc_536541856872_item	3617393	et	3	main
ta	doc_536541856872_item	3617379	et	4	main
ajalugu	doc_536541856872_item	3617378	et	4	main
kultuur	doc_536541856872_item	3617377	et	3	main
rahvatraditsioonid	doc_536541856872_item	3617376	et	3	main
väiteid	doc_536541856872_item	3617364	et	4	main
oli	doc_536541856872_item	3617475	et	3	main
johann	doc_536541856872_item	3617471	et	4	main
inimesi	doc_536541856872_item	3617467	et	4	main
eesti	doc_536541856872_item	3617454	et	4	main
pidulikud	doc_536541856872_item	3617448	et	3	main
milliseid	doc_536541856872_item	3617445	et	3	main
muidugi	doc_536541856872_item	3617439	et	4	main
teine	doc_536541856872_item	3617436	et	3	main
teisele	doc_536541856872_item	3617434	et	4	main
kingitusi	doc_536541856872_item	3617432	et	4	main
suhtlesid	doc_536541856872_item	3617428	et	4	main
mardipäev	doc_536541856872_item	3617420	et	3	main
palju	doc_536541856872_item	3617417	et	4	main
oli	doc_536541856872_item	3617415	et	3	main
või	doc_536541856872_item	3617410	et	4	main
sünnipäevadel	doc_536541856872_item	3617407	et	3	main
laulsid	doc_536541856872_item	3617405	et	4	main
ilma	doc_536541856872_item	3617402	et	4	main
nad	doc_536541856872_item	3617399	et	3	main
tavaliselt	doc_536541856872_item	3617383	et	4	main
väga	doc_536541856872_item	3617374	et	3	main
on	doc_536541856872_item	3617373	et	4	main
rahvalaulus	doc_536541856872_item	3617372	et	3	main
et	doc_536541856872_item	3617371	et	3	main
arvan	doc_536541856872_item	3617370	et	3	main
ma	doc_536541856872_item	3617369	et	3	main
on	doc_536541856872_item	3617365	et	4	main
faktidele	doc_536541856872_item	3617363	et	3	main
esitatud	doc_536541856872_item	3617362	et	4	main
lugemistekstis	doc_536541856872_item	3617361	et	3	main
ja	doc_536541856872_item	3617360	et	3	main
loengus	doc_536541856872_item	3617359	et	3	main
tuginema	doc_536541856872_item	3617358	et	3	main
üldistav	doc_536541856872_item	3617357	et	4	main
ja	doc_536541856872_item	3617356	et	3	main
analüüsiv	doc_536541856872_item	3617355	et	4	main
arutlev	doc_536541856872_item	3617354	et	4	main
olema	doc_536541856872_item	3617353	et	4	main
peab	doc_536541856872_item	3617352	et	4	main
essee	doc_536541856872_item	3617351	et	4	main
sõna	doc_536541856872_item	3617350	et	4	main
350	doc_536541856872_item	3617349	et	2	main
300	doc_536541856872_item	3617348	et	2	main
pikkus	doc_536541856872_item	3617347	et	4	main
essee	doc_536541856872_item	3617346	et	4	main
laulurahva	doc_536541856872_item	3617345	et	3	main
eestlastest	doc_536541856872_item	3617344	et	4	main
teeb	doc_536541856872_item	3617343	et	3	main
mis	doc_536541856872_item	3617342	et	4	main
teemal	doc_536541856872_item	3617341	et	3	main
essee	doc_536541856872_item	3617340	et	4	main
kirjutage	doc_536541856872_item	3617339	et	3	main
kirjutamine	doc_536541856872_item	3617338	et	4	main
selledes	doc_536541856872_item	3617425	et	4	main
inimesed	doc_536541856872_item	3617424	et	3	main
jaanipäev	doc_536541856872_item	3617423	et	3	main
näiteks	doc_536541856872_item	3617418	et	4	main
aastas	doc_536541856872_item	3617414	et	3	main
peod	doc_536541856872_item	3617413	et	4	main
pidudel	doc_536541856872_item	3617412	et	4	main
regilaule	doc_536541856872_item	3617401	et	4	main
eeslauljaga	doc_536541856872_item	3617398	et	3	main
võib	doc_536541856872_item	3617387	et	3	main
laulsid	doc_536541856872_item	3617384	et	4	main
eesti	doc_536541856872_item	3617381	et	4	main
näidetega	doc_536541856872_item	3617368	et	3	main
soovitatav	doc_536541856872_item	3617366	et	4	main
test	doc_536541856872_item	3617337	et	3	main
keele	doc_536541856872_item	3617336	et	4	main
teise	doc_536541856872_item	3617335	et	4	main
kui	doc_536541856872_item	3617334	et	3	main
keele	doc_536541856872_item	3617333	et	4	main
eesti	doc_536541856872_item	3617332	et	4	main
essee	doc_536541856872_item	3617331	et	4	main
neiud	doc_536541856872_item	3617392	et	4	main
kaks	doc_536541856872_item	3617391	et	3	main
või	doc_536541856872_item	3617390	et	4	main
üks	doc_536541856872_item	3617389	et	3	main
see	doc_536541856872_item	3617386	et	3	main
palju	doc_536541856872_item	3617375	et	4	main
see	doc_536541856873_item	3618149	et	3	main
elu	doc_536541856873_item	3617900	et	4	main
loengus	doc_536541856873_item	3617874	et	3	main
analüüsiv	doc_536541856873_item	3617870	et	4	main
arutlev	doc_536541856873_item	3617869	et	4	main
essee	doc_536541856873_item	3617866	et	4	main
sõna	doc_536541856873_item	3617865	et	4	main
350	doc_536541856873_item	3617864	et	2	main
laulurahva	doc_536541856873_item	3617860	et	3	main
oma	doc_536541856873_item	3618140	et	4	main
ei	doc_536541856873_item	3618138	et	4	main
rahvamuusikat	doc_536541856873_item	3618115	et	3	main
palju	doc_536541856873_item	3618103	et	4	main
setumaal	doc_536541856873_item	3618102	et	4	main
rahvamuusika	doc_536541856873_item	3618089	et	4	main
palju	doc_536541856873_item	3618081	et	4	main
kohtutakse	doc_536541856873_item	3618054	et	4	main
tullakse	doc_536541856873_item	3618050	et	3	main
mida	doc_536541856873_item	3618044	et	4	main
sündmus	doc_536541856873_item	3618043	et	3	main
põnev	doc_536541856873_item	3618042	et	3	main
ja	doc_536541856873_item	3618041	et	3	main
laulupeod	doc_536541856873_item	3618038	et	4	main
ühine	doc_536541856873_item	3618024	et	4	main
aastal	doc_536541856873_item	3618010	et	3	main
esimese	doc_536541856873_item	3618005	et	3	main
veel	doc_536541856873_item	3617998	et	4	main
ka	doc_536541856873_item	3617997	et	3	main
algab	doc_536541856873_item	3617996	et	3	main
vaba	doc_536541856873_item	3617991	et	4	main
erilist	doc_536541856873_item	3617974	et	4	main
mängisid	doc_536541856873_item	3617973	et	4	main
laulud	doc_536541856873_item	3617972	et	3	main
millal	doc_536541856873_item	3617967	et	3	main
arvates	doc_536541856873_item	3617959	et	4	main
minu	doc_536541856873_item	3617958	et	3	main
teeb	doc_536541856873_item	3618150	et	3	main
ja	doc_536541856873_item	3618148	et	3	main
on	doc_536541856873_item	3617901	et	4	main
sest	doc_536541856873_item	3617898	et	4	main
tõesti	doc_536541856873_item	3617896	et	3	main
on	doc_536541856873_item	3617895	et	4	main
see	doc_536541856873_item	3617894	et	3	main
ja	doc_536541856873_item	3617893	et	3	main
laulurahva	doc_536541856873_item	3617892	et	3	main
on	doc_536541856873_item	3617891	et	4	main
eestlased	doc_536541856873_item	3617890	et	3	main
et	doc_536541856873_item	3617889	et	3	main
arvatakse	doc_536541856873_item	3617888	et	3	main
et	doc_536541856873_item	3617887	et	3	main
teame	doc_536541856873_item	3617886	et	3	main
lugemistekstis	doc_536541856873_item	3617876	et	3	main
kirjutamine	doc_536541856873_item	3617853	et	4	main
test	doc_536541856873_item	3617852	et	3	main
essee	doc_536541856873_item	3617846	et	4	main
need	doc_536541856873_item	3618142	et	3	main
unusta	doc_536541856873_item	3618139	et	4	main
nad	doc_536541856873_item	3618137	et	3	main
olid	doc_536541856873_item	3617906	et	4	main
laulud	doc_536541856873_item	3617905	et	3	main
laulmisega	doc_536541856873_item	3617904	et	4	main
kõik	doc_536541856873_item	3617885	et	4	main
näidetega	doc_536541856873_item	3617883	et	3	main
illustreerida	doc_536541856873_item	3617882	et	3	main
on	doc_536541856873_item	3617880	et	4	main
väiteid	doc_536541856873_item	3617879	et	4	main
faktidele	doc_536541856873_item	3617878	et	3	main
esitatud	doc_536541856873_item	3617877	et	4	main
peab	doc_536541856873_item	3617867	et	4	main
300	doc_536541856873_item	3617863	et	2	main
mis	doc_536541856873_item	3617857	et	4	main
essee	doc_536541856873_item	3617855	et	4	main
kirjutage	doc_536541856873_item	3617854	et	3	main
eesti	doc_536541856873_item	3617847	et	4	main
heliloojad	doc_536541856873_item	3618113	et	3	main
osa	doc_536541856873_item	3618110	et	4	main
ja	doc_536541856873_item	3618108	et	3	main
traditsiooni	doc_536541856873_item	3618107	et	4	main
seda	doc_536541856873_item	3618106	et	3	main
või	doc_536541856873_item	3618101	et	4	main
et	doc_536541856873_item	3618085	et	3	main
sõidavad	doc_536541856873_item	3618083	et	3	main
ja	doc_536541856873_item	3618068	et	3	main
tihti	doc_536541856873_item	3618065	et	3	main
laulupidu	doc_536541856873_item	3618063	et	4	main
perega	doc_536541856873_item	3618052	et	3	main
koos	doc_536541856873_item	3618051	et	4	main
kuhu	doc_536541856873_item	3618049	et	3	main
rõõmsaga	doc_536541856873_item	3618047	et	3	main
inimesed	doc_536541856873_item	3618045	et	3	main
tähelepanuväärne	doc_536541856873_item	3618040	et	3	main
näitas	doc_536541856873_item	3618020	et	3	main
palju	doc_536541856873_item	3618016	et	4	main
võtsid	doc_536541856873_item	3618014	et	4	main
korraldas	doc_536541856873_item	3618007	et	3	main
laulupeo	doc_536541856873_item	3618006	et	4	main
sellest	doc_536541856873_item	3617994	et	4	main
tunnustamise	doc_536541856873_item	3617981	et	4	main
1860-tes	doc_536541856873_item	3617966	et	3	main
kultuuris	doc_536541856873_item	3617964	et	3	main
aastad	doc_536541856873_item	3617962	et	3	main
olles	doc_536541856873_item	3617950	et	3	main
aitas	doc_536541856873_item	3617946	et	3	main
vanu	doc_536541856874_item	3618395	et	4	main
kasutatakse	doc_536541856874_item	3618394	et	3	main
alati	doc_536541856874_item	3618386	et	4	main
mäletama	doc_536541856874_item	3618385	et	3	main
läbi	doc_536541856874_item	3618375	et	4	main
kaasatundlus	doc_536541856874_item	3618369	et	4	main
situatsioon	doc_536541856874_item	3618361	et	3	main
on	doc_536541856874_item	3618351	et	4	main
olid	doc_536541856874_item	3618344	et	4	main
20-sajandid	doc_536541856874_item	3618343	et	3	main
vormis	doc_536541856874_item	3618311	et	4	main
selles	doc_536541856874_item	3618310	et	4	main
laulurahva	doc_536541856873_item	3618152	et	3	main
südames	doc_536541856873_item	3618147	et	3	main
igavesti	doc_536541856873_item	3618145	et	4	main
seotud	doc_536541856873_item	3617903	et	4	main
me	doc_536541856873_item	3617884	et	4	main
soovitatav	doc_536541856873_item	3617881	et	4	main
ja	doc_536541856873_item	3617875	et	3	main
ja	doc_536541856873_item	3617871	et	3	main
pikkus	doc_536541856873_item	3617862	et	4	main
keele	doc_536541856873_item	3617851	et	4	main
ajalugu	doc_536541856873_item	3618141	et	4	main
pidudel	doc_536541856873_item	3618136	et	4	main
rahvalaulu	doc_536541856873_item	3618135	et	4	main
tähtsamaid	doc_536541856873_item	3618134	et	4	main
mäletades	doc_536541856873_item	3618133	et	3	main
seda	doc_536541856873_item	3618132	et	3	main
teavad	doc_536541856873_item	3618131	et	3	main
eestlased	doc_536541856873_item	3618130	et	3	main
aga	doc_536541856873_item	3618129	et	3	main
huvitavad	doc_536541856873_item	3618105	et	4	main
noore	doc_536541856873_item	3618104	et	3	main
rahvalaule	doc_536541856873_item	3618098	et	4	main
kuulata	doc_536541856873_item	3618097	et	4	main
rahvapeol	doc_536541856873_item	3618094	et	4	main
igal	doc_536541856873_item	3618093	et	3	main
elama	doc_536541856873_item	3618092	et	3	main
jätkab	doc_536541856873_item	3618091	et	3	main
ka	doc_536541856873_item	3618090	et	3	main
nad	doc_536541856873_item	3618069	et	3	main
külastavad	doc_536541856873_item	3618066	et	4	main
veetakse	doc_536541856873_item	3618060	et	4	main
hästi	doc_536541856873_item	3618059	et	3	main
kus	doc_536541856873_item	3618053	et	3	main
ja	doc_536541856873_item	3618048	et	3	main
otavad	doc_536541856873_item	3618046	et	4	main
praegu	doc_536541856873_item	3618037	et	3	main
on	doc_536541856873_item	3618023	et	4	main
eestlased	doc_536541856873_item	3618022	et	3	main
et	doc_536541856873_item	3618021	et	3	main
sündmusel	doc_536541856873_item	3618013	et	3	main
sellel	doc_536541856873_item	3618012	et	4	main
tartus	doc_536541856873_item	3618011	et	3	main
1869	doc_536541856873_item	3618009	et	2	main
ajast	doc_536541856873_item	3617995	et	4	main
sümbol	doc_536541856873_item	3617990	et	3	main
oma	doc_536541856873_item	3617980	et	4	main
võitlesid	doc_536541856873_item	3617979	et	4	main
eestlased	doc_536541856873_item	3617978	et	3	main
sellel	doc_536541856873_item	3617970	et	4	main
ärkamisaeg	doc_536541856873_item	3617969	et	3	main
olid	doc_536541856873_item	3617965	et	4	main
eesti	doc_536541856873_item	3617963	et	4	main
laulsid	doc_536541856873_item	3617949	et	4	main
vanad	doc_536541856874_item	3618382	et	3	main
sõnad	doc_536541856874_item	3618377	et	4	main
laula	doc_536541856874_item	3618376	et	4	main
kes	doc_536541856874_item	3618371	et	4	main
mingi	doc_536541856874_item	3618365	et	4	main
kultuuri	doc_536541856874_item	3618355	et	4	main
väärtlised	doc_536541856874_item	3618348	et	4	main
ja	doc_536541856874_item	3618347	et	3	main
rasked	doc_536541856874_item	3618346	et	3	main
nendest	doc_536541856873_item	3618151	et	4	main
nende	doc_536541856873_item	3618146	et	4	main
on	doc_536541856873_item	3618144	et	4	main
laulud	doc_536541856873_item	3618143	et	3	main
raskel	doc_536541856873_item	3617908	et	3	main
nii	doc_536541856873_item	3617907	et	3	main
väga	doc_536541856873_item	3617902	et	3	main
eestlaste	doc_536541856873_item	3617899	et	4	main
nii	doc_536541856873_item	3617897	et	3	main
tuginema	doc_536541856873_item	3617873	et	3	main
üldistav	doc_536541856873_item	3617872	et	4	main
olema	doc_536541856873_item	3617868	et	4	main
essee	doc_536541856873_item	3617861	et	4	main
eestlastest	doc_536541856873_item	3617859	et	4	main
teeb	doc_536541856873_item	3617858	et	3	main
teemal	doc_536541856873_item	3617856	et	3	main
teise	doc_536541856873_item	3617850	et	4	main
kui	doc_536541856873_item	3617849	et	3	main
keele	doc_536541856873_item	3617848	et	4	main
ajalugu	doc_536541856873_item	3618128	et	4	main
tema	doc_536541856873_item	3618127	et	4	main
minevik	doc_536541856873_item	3618126	et	3	main
riigi	doc_536541856873_item	3618125	et	3	main
meie	doc_536541856873_item	3618124	et	4	main
on	doc_536541856873_item	3618123	et	4	main
muusikas	doc_536541856873_item	3618122	et	3	main
et	doc_536541856873_item	3618121	et	3	main
mäletada	doc_536541856873_item	3618120	et	3	main
tähtsam	doc_536541856873_item	3618119	et	4	main
on	doc_536541856873_item	3618118	et	4	main
töös	doc_536541856873_item	3618117	et	3	main
oma	doc_536541856873_item	3618116	et	4	main
ka	doc_536541856873_item	3618112	et	3	main
rahvapidudest	doc_536541856873_item	3618111	et	4	main
võtavad	doc_536541856873_item	3618109	et	3	main
eriti	doc_536541856873_item	3618099	et	3	main
võime	doc_536541856873_item	3618096	et	4	main
me	doc_536541856873_item	3618095	et	4	main
tallinnasse	doc_536541856873_item	3618084	et	3	main
lihtsalt	doc_536541856873_item	3618058	et	4	main
ja	doc_536541856873_item	3618057	et	3	main
sõpru	doc_536541856873_item	3618056	et	3	main
eest	doc_536541856873_item	3618036	et	4	main
oma	doc_536541856873_item	3618034	et	4	main
ja	doc_536541856873_item	3618031	et	3	main
tahavad	doc_536541856873_item	3618030	et	3	main
nad	doc_536541856873_item	3618029	et	3	main
ja	doc_536541856873_item	3618028	et	3	main
rahva	doc_536541856873_item	3618027	et	3	main
tugev	doc_536541856873_item	3618026	et	4	main
ja	doc_536541856873_item	3618025	et	3	main
ja	doc_536541856873_item	3618018	et	3	main
laulupeod	doc_536541856873_item	3618004	et	4	main
traditsioon	doc_536541856873_item	3618003	et	3	main
põnev	doc_536541856873_item	3618002	et	3	main
ja	doc_536541856873_item	3618001	et	3	main
huvitav	doc_536541856873_item	3618000	et	4	main
üks	doc_536541856873_item	3617999	et	3	main
eestimaa	doc_536541856873_item	3617992	et	4	main
olid	doc_536541856873_item	3617988	et	4	main
neid	doc_536541856873_item	3617986	et	4	main
laulud	doc_536541856873_item	3617984	et	3	main
ja	doc_536541856873_item	3617983	et	3	main
ajal	doc_536541856873_item	3617971	et	4	main
tähtsamad	doc_536541856873_item	3617961	et	4	main
kõige	doc_536541856873_item	3617960	et	4	main
ja	doc_536541856873_item	3617955	et	3	main
kodutöid	doc_536541856873_item	3617954	et	3	main
tehes	doc_536541856873_item	3617953	et	3	main
inimesed	doc_536541856873_item	3617948	et	3	main
kasutavad	doc_536541856873_item	3618114	et	4	main
kiihnul	doc_536541856873_item	3618100	et	4	main
praegu	doc_536541856873_item	3618088	et	3	main
laulupeol	doc_536541856873_item	3618087	et	4	main
olla	doc_536541856873_item	3618086	et	3	main
külastajad	doc_536541856873_item	3618082	et	4	main
ja	doc_536541856873_item	3618080	et	3	main
maailmas	doc_536541856873_item	3618079	et	3	main
kogu	doc_536541856873_item	3618078	et	4	main
populaarsed	doc_536541856873_item	3618077	et	3	main
on	doc_536541856873_item	3618076	et	4	main
laulupeod	doc_536541856873_item	3618075	et	4	main
seetõttu	doc_536541856873_item	3618074	et	3	main
huvi	doc_536541856873_item	3618073	et	4	main
traditsiooni	doc_536541856873_item	3618072	et	4	main
selle	doc_536541856873_item	3618071	et	4	main
tunnevad	doc_536541856873_item	3618070	et	3	main
välismaalased	doc_536541856873_item	3618067	et	3	main
ka	doc_536541856873_item	3618064	et	3	main
meie	doc_536541856873_item	3618062	et	4	main
aega	doc_536541856873_item	3618061	et	4	main
oma	doc_536541856873_item	3618055	et	4	main
on	doc_536541856873_item	3618039	et	4	main
vabaduse	doc_536541856873_item	3618035	et	4	main
võitelda	doc_536541856873_item	3618033	et	4	main
hakkab	doc_536541856873_item	3618032	et	3	main
see	doc_536541856873_item	3618019	et	3	main
inimesi	doc_536541856873_item	3618017	et	4	main
osa	doc_536541856873_item	3618015	et	4	main
janseen	doc_536541856873_item	3618008	et	4	main
jaoks	doc_536541856873_item	3617993	et	4	main
nagu	doc_536541856873_item	3617989	et	3	main
ja	doc_536541856873_item	3617987	et	3	main
ühendavad	doc_536541856873_item	3617985	et	4	main
eest	doc_536541856873_item	3617982	et	4	main
rooli	doc_536541856873_item	3617977	et	4	main
tähtsam	doc_536541856873_item	3617976	et	4	main
aga	doc_536541856873_item	3617975	et	3	main
algab	doc_536541856873_item	3617968	et	3	main
rahvapidudel	doc_536541856873_item	3617957	et	4	main
muidugi	doc_536541856873_item	3617956	et	4	main
töötades	doc_536541856873_item	3617952	et	3	main
üksi	doc_536541856873_item	3617951	et	4	main
kirjaoskus	doc_536541856873_item	3617945	et	3	main
sest	doc_536541856873_item	3617944	et	4	main
kiiresti	doc_536541856873_item	3617943	et	3	main
levitasid	doc_536541856873_item	3617942	et	4	main
mis	doc_536541856873_item	3617941	et	4	main
kirikulaulud	doc_536541856873_item	3617940	et	3	main
ilmusid	doc_536541856873_item	3617939	et	4	main
varem	doc_536541856873_item	3617938	et	4	main
lauab	doc_536541856873_item	3617937	et	4	main
kellega	doc_536541856873_item	3617936	et	3	main
ja	doc_536541856873_item	3617935	et	3	main
kus	doc_536541856873_item	3617934	et	3	main
sõltus	doc_536541856873_item	3617933	et	4	main
see	doc_536541856873_item	3617932	et	3	main
erinevad	doc_536541856873_item	3617931	et	4	main
olid	doc_536541856873_item	3617930	et	4	main
mis	doc_536541856873_item	3617929	et	4	main
regilaulud	doc_536541856873_item	3617928	et	3	main
olid	doc_536541856873_item	3617927	et	4	main
tagasi	doc_536541856873_item	3617926	et	3	main
aasta	doc_536541856873_item	3617925	et	4	main
1000	doc_536541856873_item	3617924	et	2	main
aastatel	doc_536541856873_item	3617923	et	4	main
vanadel	doc_536541856873_item	3617922	et	3	main
juba	doc_536541856873_item	3617921	et	3	main
et	doc_536541856873_item	3617920	et	3	main
räägib	doc_536541856873_item	3617919	et	3	main
ajalugu	doc_536541856873_item	3617918	et	4	main
rahvapeol	doc_536541856873_item	3617917	et	4	main
igal	doc_536541856873_item	3617916	et	3	main
kus	doc_536541856874_item	3618393	et	3	main
pop-muusika	doc_536541856874_item	3618392	et	4	main
tänapaeva	doc_536541856874_item	3618391	et	4	main
olla	doc_536541856874_item	3618390	et	3	main
peame	doc_536541856874_item	3618384	et	4	main
mingid	doc_536541856874_item	3618380	et	4	main
on	doc_536541856874_item	3618379	et	4	main
ajad	doc_536541856874_item	3618374	et	4	main
selles	doc_536541856873_item	3617947	et	4	main
laulu	doc_536541856874_item	3618396	et	4	main
me	doc_536541856874_item	3618383	et	4	main
nendele	doc_536541856874_item	3618370	et	4	main
on	doc_536541856874_item	3618364	et	4	main
veel	doc_536541856874_item	3618358	et	4	main
ainult	doc_536541856874_item	3618353	et	4	main
mitte	doc_536541856874_item	3618352	et	3	main
eestlasteks	doc_536541856874_item	3618345	et	4	main
19-	doc_536541856874_item	3618341	et	4	main
olid	doc_536541856874_item	3618312	et	4	main
mida	doc_536541856874_item	3618304	et	4	main
regilaulu	doc_536541856874_item	3618303	et	4	main
väljust	doc_536541856874_item	3618299	et	3	main
erinev	doc_536541856874_item	3618297	et	4	main
palju	doc_536541856874_item	3618270	et	4	main
aastade	doc_536541856874_item	3618257	et	4	main
paljud	doc_536541856874_item	3618256	et	3	main
võib	doc_536541856874_item	3618251	et	3	main
nad	doc_536541856874_item	3618244	et	3	main
sest	doc_536541856874_item	3618243	et	4	main
tähtsamad	doc_536541856874_item	3618242	et	4	main
on	doc_536541856874_item	3618241	et	4	main
põhusi	doc_536541856874_item	3618237	et	4	main
me	doc_536541856874_item	3618206	et	4	main
väikesed	doc_536541856874_item	3618202	et	4	main
oleme	doc_536541856874_item	3618201	et	3	main
inimese	doc_536541856874_item	3618197	et	4	main
iga	doc_536541856874_item	3618196	et	4	main
osa	doc_536541856874_item	3618195	et	4	main
esitatud	doc_536541856874_item	3618185	et	4	main
peab	doc_536541856874_item	3618175	et	4	main
essee	doc_536541856874_item	3618169	et	4	main
mis	doc_536541856874_item	3618165	et	4	main
nende	doc_536541856874_item	3618414	et	4	main
laulupeole	doc_536541856878_item	3618720	et	4	main
oma	doc_536541856878_item	3618707	et	4	main
rahvapeole	doc_536541856878_item	3618699	et	4	main
osa	doc_536541856878_item	3618693	et	4	main
ja	doc_536541856878_item	3618692	et	3	main
neil	doc_536541856878_item	3618684	et	4	main
vist	doc_536541856878_item	3618681	et	4	main
praegu	doc_536541856878_item	3618680	et	3	main
kodus	doc_536541856878_item	3618679	et	4	main
on	doc_536541856878_item	3618672	et	4	main
missugune	doc_536541856878_item	3618666	et	3	main
selline	doc_536541856878_item	3618640	et	4	main
muusikat	doc_536541856878_item	3618632	et	3	main
lihtsalt	doc_536541856878_item	3618631	et	4	main
nagu	doc_536541856878_item	3618630	et	3	main
on	doc_536541856878_item	3618626	et	4	main
populaarsem	doc_536541856878_item	3618619	et	4	main
on	doc_536541856878_item	3618617	et	4	main
tänapäeval	doc_536541856878_item	3618616	et	3	main
eesti	doc_536541856878_item	3618608	et	4	main
lõpus	doc_536541856878_item	3618607	et	4	main
siiski	doc_536541856878_item	3618587	et	4	main
arv	doc_536541856878_item	3618586	et	3	main
osavõitjate	doc_536541856878_item	3618585	et	3	main
aasta	doc_536541856878_item	3618584	et	4	main
meeskoorid	doc_536541856878_item	3618579	et	4	main
seal	doc_536541856878_item	3618576	et	4	main
laulupidu	doc_536541856878_item	3618575	et	4	main
aastal	doc_536541856878_item	3618570	et	3	main
kooriga	doc_536541856878_item	3618528	et	4	main
pärast	doc_536541856878_item	3618523	et	4	main
koor	doc_536541856878_item	3618517	et	4	main
laulu	doc_536541856878_item	3618502	et	4	main
lauluvad	doc_536541856878_item	3618495	et	4	main
nad	doc_536541856878_item	3618494	et	3	main
kui	doc_536541856878_item	3618489	et	3	main
töö	doc_536541856878_item	3618479	et	4	main
traditsioon	doc_536541856878_item	3618472	et	3	main
üks	doc_536541856878_item	3618470	et	3	main
väiteid	doc_536541856878_item	3618461	et	4	main
lugemistekstis	doc_536541856878_item	3618458	et	3	main
peab	doc_536541856878_item	3618449	et	4	main
essee	doc_536541856878_item	3618437	et	4	main
kirjutage	doc_536541856878_item	3618436	et	3	main
laularahvaseks	doc_536541856879_item	3619037	et	4	main
ja	doc_536541856879_item	3619035	et	3	main
on	doc_536541856879_item	3619034	et	4	main
praegu	doc_536541856873_item	3617914	et	3	main
ja	doc_536541856873_item	3617913	et	3	main
hetkel	doc_536541856873_item	3617912	et	4	main
rõõmsal	doc_536541856873_item	3617911	et	3	main
ka	doc_536541856873_item	3617910	et	3	main
kui	doc_536541856873_item	3617909	et	3	main
lauakse	doc_536541856873_item	3617915	et	4	main
traditsioonist	doc_536541856874_item	3618412	et	3	main
rahva	doc_536541856874_item	3618411	et	3	main
eesti	doc_536541856874_item	3618410	et	4	main
mateljaalid	doc_536541856874_item	3618409	et	4	main
võtta	doc_536541856874_item	3618407	et	3	main
et	doc_536541856874_item	3618406	et	3	main
arhiivis	doc_536541856874_item	3618405	et	3	main
sealt	doc_536541856874_item	3618408	et	4	main
käivad	doc_536541856874_item	3618404	et	4	main
kontserdil	doc_536541856874_item	3618403	et	3	main
lauluväljaku	doc_536541856874_item	3618402	et	3	main
osa	doc_536541856874_item	3618401	et	4	main
võtavad	doc_536541856874_item	3618400	et	3	main
kes	doc_536541856874_item	3618399	et	4	main
inimesed	doc_536541856874_item	3618398	et	3	main
mõned	doc_536541856874_item	3618397	et	3	main
päev	doc_536541856874_item	3618426	et	3	main
iga	doc_536541856874_item	3618425	et	4	main
vajavad	doc_536541856874_item	3618424	et	4	main
nad	doc_536541856874_item	3618423	et	3	main
mida	doc_536541856874_item	3618422	et	4	main
võiks	doc_536541856874_item	3618389	et	4	main
näitus	doc_536541856874_item	3618388	et	3	main
kujutav	doc_536541856874_item	3618387	et	4	main
sajandid	doc_536541856874_item	3618381	et	3	main
millised	doc_536541856874_item	3618378	et	3	main
rasked	doc_536541856874_item	3618373	et	3	main
elasid	doc_536541856874_item	3618372	et	4	main
laul	doc_536541856874_item	3618363	et	4	main
sissetunne	doc_536541856874_item	3618360	et	3	main
tema	doc_536541856874_item	3618354	et	4	main
vajalikuks	doc_536541856874_item	3618328	et	3	main
hakkas	doc_536541856874_item	3618327	et	3	main
laulmine	doc_536541856874_item	3618326	et	4	main
kaasnes	doc_536541856874_item	3618325	et	3	main
ristiusuga	doc_536541856874_item	3618324	et	3	main
meres	doc_536541856874_item	3618323	et	3	main
mehed	doc_536541856874_item	3618321	et	3	main
nende	doc_536541856874_item	3618320	et	4	main
olid	doc_536541856874_item	3618322	et	4	main
kuna	doc_536541856874_item	3618319	et	3	main
meelelahetus	doc_536541856874_item	3618318	et	4	main
nagu	doc_536541856874_item	3618317	et	3	main
laulsid	doc_536541856874_item	3618316	et	4	main
naised	doc_536541856874_item	3618315	et	3	main
tavaliselt	doc_536541856874_item	3618314	et	4	main
variantid	doc_536541856874_item	3618313	et	4	main
eeslaulja	doc_536541856874_item	3618306	et	4	main
eesti	doc_536541856874_item	3618294	et	4	main
mõjutasid	doc_536541856874_item	3618289	et	4	main
elasid	doc_536541856874_item	3618281	et	4	main
mõni	doc_536541856874_item	3618277	et	3	main
100	doc_536541856874_item	3618263	et	2	main
kaupa	doc_536541856874_item	3618255	et	4	main
eesti	doc_536541856874_item	3618246	et	4	main
nendest	doc_536541856874_item	3618240	et	4	main
laulame	doc_536541856874_item	3618207	et	4	main
et	doc_536541856874_item	3618205	et	3	main
tahavad	doc_536541856874_item	3618204	et	3	main
õpetajad	doc_536541856874_item	3618203	et	4	main
väiteid	doc_536541856874_item	3618187	et	4	main
lugemistekstis	doc_536541856874_item	3618184	et	3	main
tuginema	doc_536541856874_item	3618181	et	3	main
ja	doc_536541856874_item	3618179	et	3	main
essee	doc_536541856874_item	3618174	et	4	main
sõna	doc_536541856874_item	3618173	et	4	main
350	doc_536541856874_item	3618172	et	2	main
300	doc_536541856874_item	3618171	et	2	main
keele	doc_536541856874_item	3618159	et	4	main
rahvaks	doc_536541856874_item	3618421	et	3	main
harrimustest	doc_536541856874_item	3618415	et	4	main
ja	doc_536541856878_item	3618716	et	3	main
lapsed	doc_536541856878_item	3618712	et	3	main
palju	doc_536541856878_item	3618711	et	4	main
tuttavaid	doc_536541856878_item	3618710	et	3	main
ja	doc_536541856878_item	3618709	et	3	main
sugulasi	doc_536541856878_item	3618708	et	3	main
laulupeole	doc_536541856878_item	3618700	et	4	main
laulupeol	doc_536541856878_item	3618695	et	4	main
võtta	doc_536541856878_item	3618694	et	3	main
lauluda	doc_536541856878_item	3618688	et	4	main
võimalus	doc_536541856878_item	3618687	et	3	main
praegu	doc_536541856878_item	3618685	et	3	main
põllus	doc_536541856878_item	3618677	et	3	main
huvitaval	doc_536541856878_item	3618664	et	4	main
eesti	doc_536541856878_item	3618657	et	4	main
või	doc_536541856874_item	3618368	et	4	main
uni	doc_536541856874_item	3618367	et	3	main
kellegi	doc_536541856874_item	3618366	et	4	main
ilus	doc_536541856874_item	3618362	et	4	main
tema	doc_536541856874_item	3618359	et	4	main
aga	doc_536541856874_item	3618357	et	3	main
kuju	doc_536541856874_item	3618356	et	4	main
eestlaseks	doc_536541856874_item	3618350	et	3	main
laul	doc_536541856874_item	3618349	et	4	main
laule	doc_536541856874_item	3618336	et	4	main
kiriku	doc_536541856874_item	3618335	et	3	main
ja	doc_536541856874_item	3618334	et	3	main
arenes	doc_536541856874_item	3618333	et	3	main
variant	doc_536541856874_item	3618332	et	3	main
see	doc_536541856874_item	3618331	et	3	main
siis	doc_536541856874_item	3618330	et	3	main
kirikus	doc_536541856874_item	3618329	et	3	main
esitasid	doc_536541856874_item	3618305	et	4	main
rahvalaul	doc_536541856874_item	3618301	et	4	main
esimese	doc_536541856874_item	3618298	et	3	main
on	doc_536541856874_item	3618296	et	4	main
folklör	doc_536541856874_item	3618295	et	4	main
kultuuri	doc_536541856874_item	3618292	et	4	main
ka	doc_536541856874_item	3618290	et	3	main
sakslased	doc_536541856874_item	3618283	et	3	main
eestis	doc_536541856874_item	3618280	et	3	main
hiljem	doc_536541856874_item	3618279	et	3	main
uusi	doc_536541856874_item	3618271	et	3	main
see	doc_536541856874_item	3618268	et	3	main
kontrollisid	doc_536541856874_item	3618266	et	4	main
ümbes	doc_536541856874_item	3618262	et	4	main
uurida	doc_536541856874_item	3618252	et	3	main
eesti	doc_536541856874_item	3618249	et	4	main
aga	doc_536541856874_item	3618238	et	3	main
me	doc_536541856874_item	3618200	et	4	main
kui	doc_536541856874_item	3618199	et	3	main
soovitatav	doc_536541856874_item	3618189	et	4	main
olema	doc_536541856874_item	3618176	et	4	main
eestlastest	doc_536541856874_item	3618167	et	4	main
teise	doc_536541856874_item	3618158	et	4	main
kui	doc_536541856874_item	3618157	et	3	main
keele	doc_536541856874_item	3618156	et	4	main
on	doc_536541856874_item	3618418	et	4	main
kokkuvõttes	doc_536541856874_item	3618416	et	3	main
ja	doc_536541856874_item	3618413	et	3	main
koos	doc_536541856878_item	3618717	et	4	main
käivad	doc_536541856878_item	3618714	et	4	main
koolis	doc_536541856878_item	3618713	et	4	main
laval	doc_536541856878_item	3618691	et	3	main
aga	doc_536541856878_item	3618683	et	3	main
ka	doc_536541856878_item	3618682	et	3	main
varem	doc_536541856878_item	3618674	et	4	main
laulurahv	doc_536541856878_item	3618673	et	4	main
näitab	doc_536541856878_item	3618667	et	3	main
pikk	doc_536541856878_item	3618662	et	4	main
ajal	doc_536541856878_item	3618652	et	4	main
saavad	doc_536541856878_item	3618645	et	4	main
laulud	doc_536541856878_item	3618644	et	3	main
ja	doc_536541856878_item	3618643	et	3	main
reisija	doc_536541856878_item	3618637	et	4	main
nautida	doc_536541856878_item	3618628	et	3	main
kus	doc_536541856878_item	3618625	et	3	main
on	doc_536541856878_item	3618623	et	4	main
pidu	doc_536541856878_item	3618622	et	4	main
arkamisaja	doc_536541856878_item	3618613	et	4	main
kolmendal	doc_536541856878_item	3618599	et	4	main
kolmekümnend	doc_536541856878_item	3618598	et	3	main
osa	doc_536541856878_item	3618578	et	4	main
toimus	doc_536541856878_item	3618571	et	3	main
linnades	doc_536541856878_item	3618565	et	3	main
regilaulud	doc_536541856878_item	3618532	et	3	main
kooriga	doc_536541856878_item	3618530	et	4	main
või	doc_536541856878_item	3618529	et	4	main
ja	doc_536541856874_item	3618342	et	3	main
väljaspool	doc_536541856874_item	3618340	et	3	main
kirikut	doc_536541856874_item	3618339	et	3	main
laulda	doc_536541856874_item	3618338	et	4	main
võis	doc_536541856874_item	3618337	et	4	main
esimene	doc_536541856874_item	3618300	et	3	main
tänapäeva	doc_536541856874_item	3618293	et	4	main
kultuurid	doc_536541856874_item	3618288	et	3	main
need	doc_536541856874_item	3618286	et	3	main
eesti	doc_536541856874_item	3618272	et	4	main
tõi	doc_536541856874_item	3618269	et	3	main
eestis	doc_536541856874_item	3618267	et	3	main
rootslased	doc_536541856874_item	3618265	et	3	main
iseseisvust	doc_536541856874_item	3618261	et	4	main
polnud	doc_536541856874_item	3618260	et	3	main
eestimaal	doc_536541856874_item	3618259	et	4	main
jooksul	doc_536541856874_item	3618258	et	4	main
laulmise	doc_536541856874_item	3618253	et	4	main
koosnevad	doc_536541856874_item	3618245	et	4	main
paar	doc_536541856874_item	3618239	et	3	main
palju	doc_536541856874_item	3618236	et	4	main
on	doc_536541856874_item	3618235	et	4	main
sellest	doc_536541856874_item	3618234	et	4	main
jooksul	doc_536541856874_item	3618233	et	4	main
sajandi	doc_536541856874_item	3618232	et	3	main
mõni	doc_536541856874_item	3618231	et	3	main
laularahva	doc_536541856874_item	3618230	et	4	main
nimetatakse	doc_536541856874_item	3618229	et	3	main
eestlased	doc_536541856874_item	3618228	et	3	main
asukohtades	doc_536541856874_item	3618227	et	3	main
eesti	doc_536541856874_item	3618226	et	4	main
eriti	doc_536541856874_item	3618225	et	3	main
tähelepanu	doc_536541856874_item	3618224	et	4	main
palju	doc_536541856874_item	3618223	et	4	main
pannatakse	doc_536541856874_item	3618222	et	4	main
laulmisele	doc_536541856874_item	3618221	et	4	main
rõõmu	doc_536541856874_item	3618220	et	4	main
meile	doc_536541856874_item	3618219	et	4	main
toob	doc_536541856874_item	3618218	et	3	main
see	doc_536541856874_item	3618217	et	3	main
sest	doc_536541856874_item	3618216	et	4	main
laulame	doc_536541856874_item	3618215	et	4	main
me	doc_536541856874_item	3618214	et	4	main
hiljem	doc_536541856874_item	3618213	et	3	main
sest	doc_536541856874_item	3618208	et	4	main
elus	doc_536541856874_item	3618198	et	4	main
on	doc_536541856874_item	3618188	et	4	main
loengus	doc_536541856874_item	3618182	et	3	main
analüüsiv	doc_536541856874_item	3618178	et	4	main
arutlev	doc_536541856874_item	3618177	et	4	main
pikkus	doc_536541856874_item	3618170	et	4	main
kirjutage	doc_536541856874_item	3618162	et	3	main
kirjutamine	doc_536541856874_item	3618161	et	4	main
test	doc_536541856874_item	3618160	et	3	main
essee	doc_536541856874_item	3618154	et	4	main
oluline	doc_536541856874_item	3618419	et	4	main
laulmine	doc_536541856874_item	3618417	et	4	main
teisega	doc_536541856878_item	3618718	et	4	main
kohtuvad	doc_536541856878_item	3618706	et	4	main
tuled	doc_536541856878_item	3618698	et	4	main
inimesi	doc_536541856878_item	3618697	et	4	main
kõikidele	doc_536541856878_item	3618689	et	4	main
aga	doc_536541856874_item	3618309	et	3	main
koor	doc_536541856874_item	3618308	et	4	main
ja	doc_536541856874_item	3618307	et	3	main
on	doc_536541856874_item	3618302	et	4	main
eesti	doc_536541856874_item	3618291	et	4	main
mitmekesised	doc_536541856874_item	3618287	et	4	main
venelased	doc_536541856874_item	3618285	et	3	main
ja	doc_536541856874_item	3618284	et	3	main
soomlased	doc_536541856874_item	3618282	et	3	main
aastat	doc_536541856874_item	3618278	et	3	main
arenemisesse	doc_536541856874_item	3618276	et	4	main
nende	doc_536541856874_item	3618275	et	4	main
ja	doc_536541856874_item	3618274	et	3	main
kultuurisse	doc_536541856874_item	3618273	et	3	main
aastat	doc_536541856874_item	3618264	et	3	main
stiili	doc_536541856874_item	3618254	et	4	main
ajalugu	doc_536541856874_item	3618250	et	4	main
osaliselt	doc_536541856874_item	3618248	et	4	main
ajalugu	doc_536541856874_item	3618247	et	4	main
oskusi	doc_536541856874_item	3618212	et	3	main
meie	doc_536541856874_item	3618211	et	4	main
arendab	doc_536541856874_item	3618210	et	3	main
see	doc_536541856874_item	3618209	et	3	main
vajalik	doc_536541856874_item	3618194	et	3	main
on	doc_536541856874_item	3618193	et	4	main
laulmine	doc_536541856874_item	3618192	et	4	main
näidetega	doc_536541856874_item	3618191	et	3	main
illustreerida	doc_536541856874_item	3618190	et	3	main
faktidele	doc_536541856874_item	3618186	et	3	main
ja	doc_536541856874_item	3618183	et	3	main
üldistav	doc_536541856874_item	3618180	et	4	main
laulurahva	doc_536541856874_item	3618168	et	3	main
teeb	doc_536541856874_item	3618166	et	3	main
teemal	doc_536541856874_item	3618164	et	3	main
essee	doc_536541856874_item	3618163	et	4	main
eesti	doc_536541856874_item	3618155	et	4	main
eesti	doc_536541856874_item	3618420	et	4	main
sõidavad	doc_536541856878_item	3618719	et	3	main
koorisse	doc_536541856878_item	3618715	et	4	main
nad	doc_536541856878_item	3618705	et	3	main
kus	doc_536541856878_item	3618704	et	3	main
perega	doc_536541856878_item	3618703	et	3	main
oma	doc_536541856878_item	3618702	et	4	main
koos	doc_536541856878_item	3618701	et	4	main
palju	doc_536541856878_item	3618696	et	4	main
jaoks	doc_536541856878_item	3618690	et	4	main
veel	doc_536541856878_item	3618686	et	4	main
rahv	doc_536541856878_item	3618671	et	4	main
eesti	doc_536541856878_item	3618670	et	4	main
ajalugu	doc_536541856878_item	3618665	et	4	main
aga	doc_536541856878_item	3618663	et	3	main
nii	doc_536541856878_item	3618653	et	3	main
tuju	doc_536541856878_item	3618649	et	4	main
meile	doc_536541856878_item	3618647	et	4	main
abitseda	doc_536541856878_item	3618646	et	4	main
või	doc_536541856878_item	3618636	et	4	main
elanik	doc_536541856878_item	3618635	et	3	main
eesti	doc_536541856878_item	3618634	et	4	main
lihtne	doc_536541856878_item	3618633	et	3	main
massilisem	doc_536541856878_item	3618621	et	4	main
või	doc_536541856878_item	3618678	et	4	main
lauluvad	doc_536541856878_item	3618676	et	4	main
inimesed	doc_536541856878_item	3618675	et	3	main
et	doc_536541856878_item	3618669	et	3	main
meile	doc_536541856878_item	3618668	et	4	main
on	doc_536541856878_item	3618661	et	4	main
laulupeol	doc_536541856878_item	3618660	et	4	main
ja	doc_536541856878_item	3618659	et	3	main
rahvamuusikal	doc_536541856878_item	3618658	et	4	main
halval	doc_536541856878_item	3618651	et	3	main
tõusteda	doc_536541856878_item	3618648	et	4	main
viisitad	doc_536541856878_item	3618639	et	4	main
saab	doc_536541856878_item	3618638	et	3	main
koorilaulu	doc_536541856878_item	3618629	et	4	main
repertuaar	doc_536541856878_item	3618614	et	3	main
nn	doc_536541856878_item	3618611	et	4	main
viinud	doc_536541856878_item	3618610	et	4	main
tuhande	doc_536541856878_item	3618596	et	3	main
segakoorid	doc_536541856878_item	3618594	et	3	main
juba	doc_536541856878_item	3618593	et	3	main
iga	doc_536541856878_item	3618583	et	4	main
puhkpilliorkestrid	doc_536541856878_item	3618582	et	3	main
ja	doc_536541856878_item	3618581	et	3	main
lauljad	doc_536541856878_item	3618580	et	4	main
võttas	doc_536541856878_item	3618577	et	4	main
tartus	doc_536541856878_item	3618572	et	3	main
laulupeod	doc_536541856878_item	3618568	et	4	main
toimusid	doc_536541856878_item	3618566	et	4	main
esitavad	doc_536541856878_item	3618533	et	4	main
kordab	doc_536541856878_item	3618522	et	3	main
koor	doc_536541856878_item	3618521	et	4	main
ja	doc_536541856878_item	3618516	et	3	main
laulja	doc_536541856878_item	3618515	et	4	main
regilaul	doc_536541856878_item	3618513	et	4	main
tavaliselt	doc_536541856878_item	3618512	et	4	main
tansu	doc_536541856878_item	3618505	et	4	main
ja	doc_536541856878_item	3618504	et	3	main
muusikat	doc_536541856878_item	3618503	et	3	main
kõige	doc_536541856878_item	3618497	et	4	main
ka	doc_536541856878_item	3618496	et	3	main
naised	doc_536541856878_item	3618490	et	3	main
et	doc_536541856878_item	3618485	et	3	main
tegema	doc_536541856878_item	3618480	et	3	main
inimesed	doc_536541856878_item	3618476	et	3	main
illustreerida	doc_536541856878_item	3618464	et	3	main
faktidele	doc_536541856878_item	3618460	et	3	main
ja	doc_536541856878_item	3618457	et	3	main
essee	doc_536541856878_item	3618448	et	4	main
sõna	doc_536541856878_item	3618447	et	4	main
kirjutamine	doc_536541856878_item	3618435	et	4	main
ole	doc_536541856879_item	3619031	et	4	main
otsivad	doc_536541856879_item	3619020	et	4	main
palju	doc_536541856879_item	3619015	et	4	main
präegu	doc_536541856879_item	3619010	et	4	main
mureid	doc_536541856879_item	3619008	et	4	main
teistega	doc_536541856879_item	3619006	et	4	main
kooselavad	doc_536541856879_item	3619005	et	3	main
aeg	doc_536541856879_item	3619004	et	3	main
sõpru	doc_536541856879_item	3618978	et	3	main
oma	doc_536541856879_item	3618977	et	4	main
peole	doc_536541856879_item	3618968	et	4	main
palju	doc_536541856879_item	3618958	et	4	main
aasta	doc_536541856879_item	3618953	et	4	main
viie	doc_536541856879_item	3618952	et	3	main
iga	doc_536541856879_item	3618951	et	4	main
toimub	doc_536541856879_item	3618950	et	3	main
on	doc_536541856879_item	3618944	et	4	main
pille	doc_536541856879_item	3618933	et	3	main
läti	doc_536541856879_item	3618923	et	4	main
kui	doc_536541856879_item	3618919	et	3	main
meiepäevadel	doc_536541856879_item	3618914	et	3	main
sest	doc_536541856879_item	3618912	et	4	main
settumaal	doc_536541856879_item	3618911	et	4	main
ja	doc_536541856879_item	3618910	et	3	main
kihnus	doc_536541856879_item	3618909	et	3	main
jaoks	doc_536541856879_item	3618903	et	4	main
pereelamise	doc_536541856879_item	3618902	et	3	main
lastele	doc_536541856879_item	3618865	et	4	main
oma	doc_536541856879_item	3618864	et	4	main
kõikasid	doc_536541856879_item	3618860	et	4	main
ajaloose	doc_536541856879_item	3618852	et	3	main
ka	doc_536541856878_item	3618656	et	3	main
ajal	doc_536541856878_item	3618655	et	4	main
heal	doc_536541856878_item	3618654	et	3	main
kui	doc_536541856878_item	3618650	et	3	main
tansud	doc_536541856878_item	3618642	et	4	main
pidu	doc_536541856878_item	3618641	et	4	main
võimalus	doc_536541856878_item	3618627	et	3	main
laulupidu	doc_536541856878_item	3618624	et	4	main
ja	doc_536541856878_item	3618620	et	3	main
kõige	doc_536541856878_item	3618618	et	4	main
muusikat	doc_536541856878_item	3618615	et	3	main
teise	doc_536541856878_item	3618612	et	4	main
lastekoorid	doc_536541856878_item	3618606	et	3	main
lisandusid	doc_536541856878_item	3618605	et	4	main
hiljem	doc_536541856878_item	3618604	et	3	main
ka	doc_536541856878_item	3618603	et	3	main
naistkoorid	doc_536541856878_item	3618602	et	4	main
üheksasaja	doc_536541856878_item	3618597	et	4	main
ka	doc_536541856878_item	3618595	et	3	main
olid	doc_536541856878_item	3618592	et	4	main
ja	doc_536541856878_item	3618589	et	3	main
1869	doc_536541856878_item	3618569	et	2	main
kohalikud	doc_536541856878_item	3618567	et	3	main
ja	doc_536541856878_item	3618564	et	3	main
ilma	doc_536541856878_item	3618527	et	4	main
laulja	doc_536541856878_item	3618518	et	4	main
esitavad	doc_536541856878_item	3618514	et	4	main
erinevad	doc_536541856878_item	3618508	et	4	main
on	doc_536541856878_item	3618507	et	4	main
rahvalaulul	doc_536541856878_item	3618506	et	3	main
populaarsem	doc_536541856878_item	3618498	et	4	main
loomide	doc_536541856878_item	3618492	et	4	main
hoolitsevad	doc_536541856878_item	3618491	et	4	main
seal	doc_536541856878_item	3618481	et	4	main
käisid	doc_536541856878_item	3618477	et	4	main
minevikkus	doc_536541856878_item	3618475	et	4	main
laulutraditsioon	doc_536541856878_item	3618474	et	3	main
on	doc_536541856878_item	3618473	et	4	main
vanemait	doc_536541856878_item	3618471	et	3	main
traditsioonid	doc_536541856878_item	3618469	et	3	main
palju	doc_536541856878_item	3618468	et	4	main
on	doc_536541856878_item	3618462	et	4	main
esitatud	doc_536541856878_item	3618459	et	4	main
üldistav	doc_536541856878_item	3618454	et	4	main
analüüsiv	doc_536541856878_item	3618452	et	4	main
olema	doc_536541856878_item	3618450	et	4	main
300	doc_536541856878_item	3618445	et	2	main
essee	doc_536541856878_item	3618443	et	4	main
test	doc_536541856878_item	3618434	et	3	main
keele	doc_536541856878_item	3618433	et	4	main
teise	doc_536541856878_item	3618432	et	4	main
taasiseisvuseni	doc_536541856878_item	3618609	et	4	main
lisandusid	doc_536541856878_item	3618601	et	4	main
aastal	doc_536541856878_item	3618600	et	3	main
peost	doc_536541856878_item	3618591	et	4	main
neljandast	doc_536541856878_item	3618590	et	3	main
kasvas	doc_536541856878_item	3618588	et	3	main
ülemaaline	doc_536541856878_item	3618574	et	4	main
esimene	doc_536541856878_item	3618573	et	3	main
koorid	doc_536541856878_item	3618563	et	4	main
kohalikud	doc_536541856878_item	3618562	et	3	main
olid	doc_536541856878_item	3618561	et	4	main
algusel	doc_536541856878_item	3618560	et	4	main
heliloojad	doc_536541856878_item	3618559	et	3	main
kasutatakse	doc_536541856878_item	3618558	et	3	main
sajandil	doc_536541856878_item	3618557	et	3	main
19	doc_536541856878_item	3618556	et	2	main
umbes	doc_536541856878_item	3618555	et	4	main
kannel	doc_536541856878_item	3618554	et	4	main
näiteks	doc_536541856878_item	3618553	et	4	main
muusikainstrumendide	doc_536541856878_item	3618552	et	4	main
kasutamist	doc_536541856878_item	3618551	et	4	main
pärast	doc_536541856878_item	3618550	et	4	main
ka	doc_536541856878_item	3618549	et	3	main
väljaspool	doc_536541856878_item	3618548	et	3	main
hiljem	doc_536541856878_item	3618547	et	3	main
ja	doc_536541856878_item	3618546	et	3	main
kirikus	doc_536541856878_item	3618545	et	3	main
laulda	doc_536541856878_item	3618544	et	4	main
võimalus	doc_536541856878_item	3618543	et	3	main
oli	doc_536541856878_item	3618542	et	3	main
sajandil	doc_536541856878_item	3618541	et	3	main
18	doc_536541856878_item	3618540	et	2	main
kirik	doc_536541856878_item	3618539	et	3	main
mängis	doc_536541856878_item	3618538	et	3	main
rahvalaulu	doc_536541856878_item	3618537	et	4	main
roll	doc_536541856878_item	3618536	et	3	main
suur	doc_536541856878_item	3618535	et	3	main
naised	doc_536541856878_item	3618534	et	3	main
tavaliselt	doc_536541856878_item	3618531	et	4	main
lauluvad	doc_536541856878_item	3618526	et	4	main
lauljad	doc_536541856878_item	3618525	et	4	main
pärast	doc_536541856878_item	3618524	et	4	main
aga	doc_536541856878_item	3618520	et	3	main
eest	doc_536541856878_item	3618493	et	4	main
tuju	doc_536541856878_item	3618488	et	4	main
võid	doc_536541856878_item	3618483	et	4	main
nad	doc_536541856878_item	3618482	et	3	main
soovitatav	doc_536541856878_item	3618463	et	4	main
loengus	doc_536541856878_item	3618456	et	3	main
arutlev	doc_536541856878_item	3618451	et	4	main
350	doc_536541856878_item	3618446	et	2	main
eestlastest	doc_536541856878_item	3618441	et	4	main
teeb	doc_536541856878_item	3618440	et	3	main
mis	doc_536541856878_item	3618439	et	4	main
teemal	doc_536541856878_item	3618438	et	3	main
kui	doc_536541856878_item	3618431	et	3	main
eesti	doc_536541856879_item	3619028	et	4	main
et	doc_536541856879_item	3619025	et	3	main
informatsiooni	doc_536541856879_item	3619022	et	4	main
eestikultuuriajaloost	doc_536541856879_item	3619021	et	4	main
folklööransamble	doc_536541856879_item	3619016	et	4	main
meie	doc_536541856879_item	3619011	et	4	main
probleemi	doc_536541856879_item	3619009	et	4	main
jagunes	doc_536541856879_item	3619007	et	3	main
kohtuda	doc_536541856879_item	3618975	et	3	main
tulevad	doc_536541856879_item	3618957	et	4	main
öeldud	doc_536541856879_item	3618942	et	4	main
nägu	doc_536541856879_item	3618939	et	4	main
eestirahvas	doc_536541856879_item	3618926	et	4	main
all	doc_536541856879_item	3618925	et	3	main
mõju	doc_536541856879_item	3618924	et	4	main
traditsioon	doc_536541856879_item	3618918	et	3	main
kuulata	doc_536541856879_item	3618908	et	4	main
võiks	doc_536541856879_item	3618907	et	4	main
laulu	doc_536541856879_item	3618906	et	4	main
ümberlausid	doc_536541856879_item	3618880	et	4	main
kokkusaades	doc_536541856879_item	3618879	et	4	main
lauluga	doc_536541856879_item	3618873	et	4	main
panid	doc_536541856879_item	3618867	et	4	main
kui	doc_536541856879_item	3618866	et	3	main
kogu	doc_536541856879_item	3618845	et	4	main
seda	doc_536541856879_item	3618837	et	3	main
riimiline	doc_536541856879_item	3618835	et	4	main
ilma	doc_536541856879_item	3618807	et	4	main
mida	doc_536541856879_item	3618803	et	4	main
vanem	doc_536541856879_item	3618799	et	4	main
laulmine	doc_536541856879_item	3618776	et	4	main
eriti	doc_536541856879_item	3618772	et	3	main
eestlased	doc_536541856879_item	3618771	et	3	main
hulka	doc_536541856879_item	3618768	et	4	main
üldistav	doc_536541856879_item	3618748	et	4	main
300	doc_536541856879_item	3618739	et	2	main
pikkus	doc_536541856879_item	3618738	et	4	main
teeb	doc_536541856879_item	3618734	et	3	main
mis	doc_536541856879_item	3618733	et	4	main
asendas	doc_536541856879_item	3618831	et	3	main
pilita	doc_536541856879_item	3618808	et	4	main
laulavad	doc_536541856880_item	3619342	et	4	main
lauljad	doc_536541856880_item	3619330	et	4	main
laulda	doc_536541856880_item	3619329	et	4	main
ja	doc_536541856880_item	3619328	et	3	main
saavad	doc_536541856880_item	3619320	et	4	main
toimuvad	doc_536541856880_item	3619316	et	4	main
eestlastega	doc_536541856880_item	3619312	et	4	main
peavad	doc_536541856880_item	3619304	et	4	main
toimuvad	doc_536541856880_item	3619290	et	4	main
muusikakoolides	doc_536541856880_item	3619289	et	3	main
kuulus	doc_536541856880_item	3619286	et	4	main
ja	doc_536541856880_item	3619278	et	3	main
alustab	doc_536541856878_item	3618519	et	3	main
regilaul	doc_536541856878_item	3618511	et	4	main
näiteks	doc_536541856878_item	3618510	et	4	main
žanrid	doc_536541856878_item	3618509	et	2	main
folkloori	doc_536541856878_item	3618501	et	4	main
kolm	doc_536541856878_item	3618500	et	3	main
on	doc_536541856878_item	3618499	et	4	main
oma	doc_536541856878_item	3618487	et	4	main
tõustada	doc_536541856878_item	3618486	et	4	main
laulda	doc_536541856878_item	3618484	et	4	main
põllus	doc_536541856878_item	3618478	et	3	main
on	doc_536541856878_item	3618467	et	4	main
eestis	doc_536541856878_item	3618466	et	3	main
näidetega	doc_536541856878_item	3618465	et	3	main
tuginema	doc_536541856878_item	3618455	et	3	main
ja	doc_536541856878_item	3618453	et	3	main
pikkus	doc_536541856878_item	3618444	et	4	main
laulurahva	doc_536541856878_item	3618442	et	3	main
keele	doc_536541856878_item	3618430	et	4	main
eesti	doc_536541856878_item	3618429	et	4	main
essee	doc_536541856878_item	3618428	et	4	main
jaavad	doc_536541856879_item	3619036	et	4	main
kultuur	doc_536541856879_item	3619029	et	3	main
vana	doc_536541856879_item	3619023	et	4	main
käivad	doc_536541856879_item	3619018	et	4	main
kes	doc_536541856879_item	3619017	et	4	main
päevadel	doc_536541856879_item	3619012	et	3	main
koos	doc_536541856879_item	3618981	et	4	main
et	doc_536541856879_item	3618980	et	3	main
tuttavaid	doc_536541856879_item	3618979	et	3	main
lootus	doc_536541856879_item	3618974	et	4	main
kõikidel	doc_536541856879_item	3618972	et	4	main
perega	doc_536541856879_item	3618971	et	3	main
koos	doc_536541856879_item	3618970	et	4	main
eestimaal	doc_536541856879_item	3618962	et	4	main
ainult	doc_536541856879_item	3618961	et	4	main
mitte	doc_536541856879_item	3618960	et	3	main
külasid	doc_536541856879_item	3618959	et	3	main
meil	doc_536541856879_item	3618949	et	4	main
tänapäevadel	doc_536541856879_item	3618948	et	3	main
eestlased	doc_536541856879_item	3618943	et	3	main
oli	doc_536541856879_item	3618940	et	3	main
ei	doc_536541856879_item	3619030	et	4	main
naidata	doc_536541856879_item	3619026	et	4	main
kogu	doc_536541856879_item	3619003	et	4	main
ongi	doc_536541856879_item	3619000	et	4	main
need	doc_536541856879_item	3618999	et	3	main
emotsioonid	doc_536541856879_item	3618998	et	3	main
oma	doc_536541856879_item	3618997	et	4	main
hing	doc_536541856879_item	3618996	et	3	main
oma	doc_536541856879_item	3618995	et	4	main
tuju	doc_536541856879_item	3618994	et	4	main
oma	doc_536541856879_item	3618993	et	4	main
naitavad	doc_536541856879_item	3618992	et	4	main
inimesed	doc_536541856879_item	3618991	et	3	main
kaudu	doc_536541856879_item	3618990	et	3	main
laulu	doc_536541856879_item	3618989	et	4	main
sest	doc_536541856879_item	3618988	et	4	main
laulda	doc_536541856879_item	3618987	et	4	main
koos	doc_536541856879_item	3618986	et	4	main
aegu	doc_536541856879_item	3618985	et	4	main
eestlased	doc_536541856879_item	3619033	et	3	main
surnud	doc_536541856879_item	3619032	et	4	main
et	doc_536541856879_item	3619027	et	3	main
rahvalaulud	doc_536541856879_item	3619024	et	3	main
arhivides	doc_536541856879_item	3619019	et	4	main
ka	doc_536541856879_item	3619014	et	3	main
on	doc_536541856879_item	3619013	et	4	main
kes	doc_536541856879_item	3619002	et	4	main
eestlased	doc_536541856879_item	3619001	et	3	main
vana	doc_536541856879_item	3618984	et	4	main
seal	doc_536541856879_item	3618976	et	4	main
on	doc_536541856879_item	3618973	et	4	main
selle	doc_536541856879_item	3618967	et	4	main
maalt	doc_536541856879_item	3618966	et	3	main
teisest	doc_536541856879_item	3618965	et	4	main
ka	doc_536541856879_item	3618964	et	3	main
vaid	doc_536541856879_item	3618963	et	3	main
laulupidu	doc_536541856879_item	3618955	et	4	main
jooksul	doc_536541856879_item	3618954	et	4	main
sest	doc_536541856879_item	3618946	et	4	main
laulurahva	doc_536541856879_item	3618945	et	3	main
bojan	doc_536541856879_item	3618938	et	4	main
näiteks	doc_536541856879_item	3618934	et	4	main
venemaa	doc_536541856879_item	3618922	et	4	main
oli	doc_536541856879_item	3618921	et	3	main
jäi	doc_536541856879_item	3618915	et	3	main
isegi	doc_536541856879_item	3618913	et	4	main
neid	doc_536541856879_item	3618905	et	4	main
eriti	doc_536541856879_item	3618904	et	3	main
ie	doc_536541856879_item	3618885	et	4	main
loo	doc_536541856879_item	3618882	et	4	main
oma	doc_536541856879_item	3618877	et	4	main
laulsid	doc_536541856879_item	3618876	et	4	main
naised	doc_536541856879_item	3618875	et	3	main
juttustasid	doc_536541856879_item	3618870	et	4	main
magama	doc_536541856879_item	3618869	et	3	main
laule	doc_536541856879_item	3618863	et	4	main
laulsid	doc_536541856879_item	3618862	et	4	main
karjapoisid	doc_536541856879_item	3618855	et	4	main
isegi	doc_536541856879_item	3618854	et	4	main
vaadata	doc_536541856879_item	3618851	et	4	main
kui	doc_536541856879_item	3618850	et	3	main
laulurahvas	doc_536541856879_item	3618849	et	4	main
iganes	doc_536541856879_item	3618844	et	4	main
oma	doc_536541856879_item	3618763	et	4	main
ja	doc_536541856879_item	3618751	et	3	main
väiteid	doc_536541856879_item	3618755	et	4	main
peab	doc_536541856879_item	3618743	et	4	main
laulurahva	doc_536541856879_item	3618736	et	3	main
essee	doc_536541856879_item	3618731	et	4	main
kirjutage	doc_536541856879_item	3618730	et	3	main
kirjutamine	doc_536541856879_item	3618729	et	4	main
essee	doc_536541856879_item	3618722	et	4	main
see	doc_536541856879_item	3618823	et	3	main
tähega	doc_536541856879_item	3618822	et	3	main
k	doc_536541856879_item	3618821	et	4	main
algasid	doc_536541856879_item	3618820	et	4	main
ajalugu	doc_536541856879_item	3618983	et	4	main
meenutad	doc_536541856879_item	3618982	et	3	main
tulevad	doc_536541856879_item	3618969	et	4	main
kuhu	doc_536541856879_item	3618956	et	3	main
isegi	doc_536541856879_item	3618947	et	4	main
juba	doc_536541856879_item	3618941	et	3	main
toodud	doc_536541856879_item	3618937	et	4	main
venemaalt	doc_536541856879_item	3618935	et	3	main
maast	doc_536541856879_item	3618932	et	3	main
teisest	doc_536541856879_item	3618931	et	4	main
kasutada	doc_536541856879_item	3618930	et	3	main
muusikas	doc_536541856879_item	3618929	et	3	main
oma	doc_536541856879_item	3618928	et	4	main
hakkas	doc_536541856879_item	3618927	et	3	main
see	doc_536541856879_item	3618917	et	3	main
seal	doc_536541856879_item	3618916	et	4	main
mingi	doc_536541856879_item	3618881	et	4	main
abil	doc_536541856879_item	3618874	et	4	main
neid	doc_536541856879_item	3618868	et	4	main
suhelda	doc_536541856879_item	3618857	et	4	main
et	doc_536541856879_item	3618856	et	3	main
olid	doc_536541856879_item	3618848	et	4	main
eestlased	doc_536541856879_item	3618847	et	3	main
aeg	doc_536541856879_item	3618846	et	3	main
oli	doc_536541856879_item	3618936	et	3	main
eesti	doc_536541856879_item	3618920	et	4	main
raha	doc_536541856879_item	3618901	et	4	main
tennima	doc_536541856879_item	3618900	et	4	main
et	doc_536541856879_item	3618899	et	3	main
tööd	doc_536541856879_item	3618898	et	4	main
tegema	doc_536541856879_item	3618897	et	3	main
nad	doc_536541856879_item	3618895	et	3	main
pidid	doc_536541856879_item	3618896	et	4	main
sest	doc_536541856879_item	3618894	et	4	main
harva	doc_536541856879_item	3618893	et	4	main
aga	doc_536541856879_item	3618892	et	3	main
laulsid	doc_536541856879_item	3618891	et	4	main
ka	doc_536541856879_item	3618890	et	3	main
mehed	doc_536541856879_item	3618889	et	3	main
naisi	doc_536541856879_item	3618888	et	3	main
ainult	doc_536541856879_item	3618887	et	4	main
puttu	doc_536541856879_item	3618886	et	4	main
see	doc_536541856879_item	3618884	et	3	main
aga	doc_536541856879_item	3618883	et	3	main
vahel	doc_536541856879_item	3618878	et	4	main
muinasjuttu	doc_536541856879_item	3618872	et	4	main
mingi	doc_536541856879_item	3618871	et	4	main
perenaised	doc_536541856879_item	3618861	et	3	main
teistega	doc_536541856879_item	3618859	et	4	main
ühe	doc_536541856879_item	3618858	et	4	main
siis	doc_536541856879_item	3618853	et	3	main
õues	doc_536541856879_item	3618842	et	4	main
kirikus	doc_536541856879_item	3618841	et	3	main
võik	doc_536541856879_item	3618839	et	3	main
laulu	doc_536541856879_item	3618838	et	4	main
rahvalaul	doc_536541856879_item	3618836	et	4	main
tavaliselt	doc_536541856879_item	3618805	et	4	main
on	doc_536541856879_item	3618801	et	4	main
edasi	doc_536541856879_item	3618797	et	3	main
omapärane	doc_536541856879_item	3618785	et	4	main
vanakultuuriga	doc_536541856879_item	3618775	et	4	main
oma	doc_536541856879_item	3618774	et	4	main
ka	doc_536541856879_item	3618770	et	3	main
on	doc_536541856879_item	3618762	et	4	main
faktidele	doc_536541856879_item	3618754	et	3	main
lugemistekstis	doc_536541856879_item	3618752	et	3	main
loengus	doc_536541856879_item	3618750	et	3	main
essee	doc_536541856879_item	3618742	et	4	main
sõna	doc_536541856879_item	3618741	et	4	main
350	doc_536541856879_item	3618740	et	2	main
eestlastest	doc_536541856879_item	3618735	et	4	main
teemal	doc_536541856879_item	3618732	et	3	main
teise	doc_536541856879_item	3618726	et	4	main
kui	doc_536541856879_item	3618725	et	3	main
keele	doc_536541856879_item	3618724	et	4	main
algusel	doc_536541856879_item	3618834	et	4	main
regilaulu	doc_536541856879_item	3618830	et	4	main
eesti	doc_536541856879_item	3618828	et	4	main
alguse	doc_536541856879_item	3618827	et	3	main
rahvalaulu	doc_536541856880_item	3619343	et	4	main
seal	doc_536541856880_item	3619340	et	4	main
vanalinna	doc_536541856880_item	3619338	et	4	main
toimuvad	doc_536541856880_item	3619337	et	4	main
aastal	doc_536541856880_item	3619336	et	3	main
igal	doc_536541856880_item	3619335	et	3	main
kostüümides	doc_536541856880_item	3619334	et	3	main
rahva	doc_536541856880_item	3619333	et	3	main
tantsuda	doc_536541856880_item	3619327	et	4	main
inimesed	doc_536541856880_item	3619319	et	3	main
aastat	doc_536541856880_item	3619315	et	3	main
kirjutatud	doc_536541856880_item	3619311	et	4	main
on	doc_536541856880_item	3619310	et	4	main
vilistlasid	doc_536541856880_item	3619303	et	4	main
muusikakoolis	doc_536541856880_item	3619302	et	4	main
näiteks	doc_536541856880_item	3619299	et	4	main
teosed	doc_536541856880_item	3619298	et	3	main
festival	doc_536541856880_item	3619288	et	3	main
esinevad	doc_536541856880_item	3619282	et	4	main
ja	doc_536541856880_item	3619280	et	3	main
palju	doc_536541856880_item	3619271	et	4	main
kes	doc_536541856880_item	3619265	et	4	main
rühm	doc_536541856880_item	3619264	et	3	main
folkloori	doc_536541856880_item	3619258	et	4	main
kus	doc_536541856879_item	3618843	et	3	main
kuulata	doc_536541856879_item	3618840	et	4	main
vokaalselt	doc_536541856879_item	3618806	et	4	main
regilaul	doc_536541856879_item	3618802	et	4	main
eesti	doc_536541856879_item	3618798	et	4	main
nii	doc_536541856879_item	3618796	et	3	main
tuju	doc_536541856879_item	3618794	et	4	main
tunned	doc_536541856879_item	3618793	et	3	main
emotsioonid	doc_536541856879_item	3618791	et	3	main
väljendada	doc_536541856879_item	3618790	et	3	main
tänu	doc_536541856879_item	3618787	et	4	main
nähtus	doc_536541856879_item	3618786	et	4	main
eestikultuuri	doc_536541856879_item	3618784	et	4	main
laulmine	doc_536541856879_item	3618782	et	4	main
traditsioon	doc_536541856879_item	3618781	et	3	main
vanematest	doc_536541856879_item	3618780	et	4	main
üks	doc_536541856879_item	3618779	et	3	main
rahval	doc_536541856879_item	3618761	et	3	main
igal	doc_536541856879_item	3618760	et	3	main
näidetega	doc_536541856879_item	3618759	et	3	main
illustreerida	doc_536541856879_item	3618758	et	3	main
soovitatav	doc_536541856879_item	3618757	et	4	main
on	doc_536541856879_item	3618756	et	4	main
esitatud	doc_536541856879_item	3618753	et	4	main
tuginema	doc_536541856879_item	3618749	et	3	main
ja	doc_536541856879_item	3618747	et	3	main
analüüsiv	doc_536541856879_item	3618746	et	4	main
arutlev	doc_536541856879_item	3618745	et	4	main
test	doc_536541856879_item	3618728	et	3	main
keele	doc_536541856879_item	3618727	et	4	main
19	doc_536541856879_item	3618832	et	2	main
regilaul	doc_536541856879_item	3618824	et	4	main
koor	doc_536541856879_item	3618812	et	4	main
aitas	doc_536541856879_item	3618810	et	3	main
muidugi	doc_536541856879_item	3618809	et	4	main
kostüümides	doc_536541856880_item	3619345	et	3	main
päevad	doc_536541856880_item	3619339	et	3	main
esinevad	doc_536541856880_item	3619332	et	4	main
meelelahutada	doc_536541856880_item	3619326	et	4	main
sõpradega	doc_536541856880_item	3619325	et	3	main
ja	doc_536541856880_item	3619324	et	3	main
perega	doc_536541856880_item	3619323	et	3	main
kus	doc_536541856880_item	3619318	et	3	main
4	doc_536541856880_item	3619314	et	2	main
georg	doc_536541856880_item	3619300	et	4	main
eesti	doc_536541856880_item	3619296	et	4	main
esitama	doc_536541856880_item	3619295	et	3	main
peavad	doc_536541856880_item	3619294	et	4	main
lapsed	doc_536541856880_item	3619293	et	3	main
kus	doc_536541856880_item	3619292	et	3	main
folklori	doc_536541856880_item	3619287	et	4	main
viljandis	doc_536541856880_item	3619283	et	4	main
tihti	doc_536541856880_item	3619281	et	3	main
on	doc_536541856880_item	3619270	et	4	main
arhiividest	doc_536541856880_item	3619269	et	3	main
laulu	doc_536541856880_item	3619268	et	4	main
üks	doc_536541856880_item	3619263	et	3	main
on	doc_536541856880_item	3619256	et	4	main
esitasid	doc_536541856879_item	3618804	et	4	main
rahvalaul	doc_536541856879_item	3618800	et	4	main
ja	doc_536541856879_item	3618795	et	3	main
tegevus	doc_536541856879_item	3618792	et	4	main
võib	doc_536541856879_item	3618789	et	3	main
seda	doc_536541856879_item	3618788	et	3	main
on	doc_536541856879_item	3618783	et	4	main
ongi	doc_536541856879_item	3618778	et	4	main
see	doc_536541856879_item	3618777	et	3	main
tundav	doc_536541856879_item	3618773	et	4	main
kuulub	doc_536541856879_item	3618769	et	3	main
selle	doc_536541856879_item	3618767	et	4	main
kultuur	doc_536541856879_item	3618766	et	3	main
oma	doc_536541856879_item	3618765	et	4	main
tradatsioonid	doc_536541856879_item	3618764	et	4	main
olema	doc_536541856879_item	3618744	et	4	main
essee	doc_536541856879_item	3618737	et	4	main
eesti	doc_536541856879_item	3618723	et	4	main
saja	doc_536541856879_item	3618833	et	4	main
kulturise	doc_536541856879_item	3618829	et	4	main
suure	doc_536541856879_item	3618826	et	3	main
pani	doc_536541856879_item	3618825	et	4	main
laulud	doc_536541856879_item	3618819	et	3	main
ja	doc_536541856879_item	3618818	et	3	main
rütmi	doc_536541856879_item	3618817	et	4	main
rõhutades	doc_536541856879_item	3618816	et	3	main
kahekesi	doc_536541856879_item	3618815	et	3	main
üksikuna	doc_536541856879_item	3618814	et	3	main
lauldi	doc_536541856879_item	3618813	et	3	main
rahva	doc_536541856880_item	3619344	et	3	main
oma	doc_536541856880_item	3619322	et	4	main
tulla	doc_536541856880_item	3619321	et	3	main
iga	doc_536541856880_item	3619313	et	4	main
mis	doc_536541856880_item	3619309	et	4	main
otsa	doc_536541856880_item	3619301	et	4	main
heliloojate	doc_536541856880_item	3619297	et	3	main
väga	doc_536541856880_item	3619285	et	3	main
laste	doc_536541856880_item	3619272	et	4	main
otsivad	doc_536541856880_item	3619266	et	4	main
palju	doc_536541856880_item	3619257	et	4	main
folkloori	doc_536541856880_item	3619252	et	4	main
eeslauljat	doc_536541856879_item	3618811	et	3	main
ka	doc_536541856880_item	3619341	et	3	main
alati	doc_536541856880_item	3619331	et	4	main
laulupeod	doc_536541856880_item	3619317	et	4	main
teos	doc_536541856880_item	3619308	et	4	main
üks	doc_536541856880_item	3619307	et	3	main
riigieksamil	doc_536541856880_item	3619306	et	3	main
mängima	doc_536541856880_item	3619305	et	3	main
konkurssid	doc_536541856880_item	3619291	et	4	main
toimub	doc_536541856880_item	3619284	et	3	main
tantsu	doc_536541856880_item	3619279	et	4	main
laulu	doc_536541856880_item	3619277	et	4	main
on	doc_536541856880_item	3619262	et	4	main
eestis	doc_536541856880_item	3619261	et	3	main
näiteks	doc_536541856880_item	3619260	et	4	main
on	doc_536541856880_item	3619248	et	4	main
praegu	doc_536541856880_item	3619247	et	3	main
filmides	doc_536541856880_item	3619246	et	4	main
helilooja	doc_536541856880_item	3619241	et	4	main
tuntuim	doc_536541856880_item	3619240	et	4	main
kuulsaim	doc_536541856880_item	3619233	et	4	main
üks	doc_536541856880_item	3619232	et	3	main
saari	doc_536541856880_item	3619231	et	3	main
vahel	doc_536541856880_item	3619227	et	4	main
tormis	doc_536541856880_item	3619220	et	3	main
näiteks	doc_536541856880_item	3619216	et	4	main
ja	doc_536541856880_item	3619208	et	3	main
kannel	doc_536541856880_item	3619204	et	4	main
populaarsem	doc_536541856880_item	3619202	et	4	main
mõju	doc_536541856880_item	3619189	et	4	main
näiteks	doc_536541856880_item	3619166	et	4	main
kasutatud	doc_536541856880_item	3619164	et	4	main
last	doc_536541856880_item	3619104	et	4	main
laulsid	doc_536541856880_item	3619100	et	4	main
alati	doc_536541856880_item	3619099	et	4	main
ja	doc_536541856880_item	3619084	et	3	main
kus	doc_536541856880_item	3619082	et	3	main
tuginema	doc_536541856880_item	3619066	et	3	main
üldistav	doc_536541856880_item	3619065	et	4	main
analüüsiv	doc_536541856880_item	3619063	et	4	main
essee	doc_536541856880_item	3619059	et	4	main
sõna	doc_536541856880_item	3619058	et	4	main
350	doc_536541856880_item	3619057	et	2	main
300	doc_536541856880_item	3619056	et	2	main
pikkus	doc_536541856880_item	3619055	et	4	main
mis	doc_536541856880_item	3619050	et	4	main
eesti	doc_536541856880_item	3619040	et	4	main
pärast	doc_536541856880_item	3619160	et	4	main
olid	doc_536541856880_item	3619122	et	4	main
kihnus	doc_536541856880_item	3619119	et	3	main
laulsid	doc_536541856880_item	3619115	et	4	main
laule	doc_536541856880_item	3619113	et	4	main
naiste	doc_536541856880_item	3619112	et	3	main
teised	doc_536541856881_item	3619430	et	4	main
ukrainlased	doc_536541856881_item	3619426	et	3	main
aga	doc_536541856881_item	3619417	et	3	main
muusikat	doc_536541856881_item	3619415	et	3	main
tähistades	doc_536541856881_item	3619406	et	3	main
peaaegu	doc_536541856881_item	3619396	et	3	main
laul	doc_536541856881_item	3619394	et	4	main
essee	doc_536541856881_item	3619362	et	4	main
laulurahva	doc_536541856881_item	3619361	et	3	main
eestlastest	doc_536541856881_item	3619360	et	4	main
teeb	doc_536541856881_item	3619359	et	3	main
klassika-	doc_536541856881_item	3619613	et	4	main
leida	doc_536541856881_item	3619612	et	3	main
saab	doc_536541856881_item	3619611	et	3	main
eestis	doc_536541856881_item	3619610	et	3	main
stiilides	doc_536541856881_item	3619609	et	4	main
brigitta	doc_536541856881_item	3619604	et	4	main
sellele	doc_536541856881_item	3619579	et	4	main
eesti	doc_536541856881_item	3619571	et	4	main
et	doc_536541856881_item	3619570	et	3	main
lisada	doc_536541856881_item	3619569	et	3	main
head	doc_536541856881_item	3619565	et	4	main
eestlased	doc_536541856881_item	3619563	et	3	main
2004	doc_536541856881_item	3619553	et	2	main
lauljad	doc_536541856881_item	3619552	et	4	main
eesti	doc_536541856881_item	3619551	et	4	main
vana	doc_536541856880_item	3619276	et	4	main
õppevad	doc_536541856880_item	3619275	et	4	main
nad	doc_536541856880_item	3619274	et	3	main
ansambli	doc_536541856880_item	3619273	et	3	main
vana	doc_536541856880_item	3619267	et	4	main
rühmade	doc_536541856880_item	3619259	et	3	main
tervis	doc_536541856880_item	3619254	et	3	main
ülemaailma	doc_536541856880_item	3619239	et	4	main
on	doc_536541856880_item	3619238	et	4	main
tormis	doc_536541856880_item	3619237	et	3	main
paljud	doc_536541856880_item	3619229	et	3	main
ja	doc_536541856880_item	3619219	et	3	main
oma	doc_536541856880_item	3619214	et	4	main
kasutasid	doc_536541856880_item	3619212	et	4	main
loojad	doc_536541856880_item	3619211	et	4	main
lauldi	doc_536541856880_item	3619205	et	3	main
oli	doc_536541856880_item	3619203	et	3	main
tuntuim	doc_536541856880_item	3619200	et	4	main
kasutada	doc_536541856880_item	3619197	et	3	main
hakati	doc_536541856880_item	3619196	et	3	main
läti	doc_536541856880_item	3619186	et	4	main
eeskujutud	doc_536541856880_item	3619182	et	4	main
kiigutasid	doc_536541856880_item	3619103	et	4	main
soovitatav	doc_536541856880_item	3619074	et	4	main
ja	doc_536541856880_item	3619068	et	3	main
ja	doc_536541856880_item	3619064	et	3	main
arutlev	doc_536541856880_item	3619062	et	4	main
olema	doc_536541856880_item	3619061	et	4	main
essee	doc_536541856880_item	3619054	et	4	main
laulurahva	doc_536541856880_item	3619053	et	3	main
teemal	doc_536541856880_item	3619049	et	3	main
essee	doc_536541856880_item	3619048	et	4	main
kirjutamine	doc_536541856880_item	3619046	et	4	main
keele	doc_536541856880_item	3619044	et	4	main
teise	doc_536541856880_item	3619043	et	4	main
kui	doc_536541856880_item	3619042	et	3	main
essee	doc_536541856880_item	3619039	et	4	main
lõppus	doc_536541856880_item	3619157	et	4	main
meres	doc_536541856880_item	3619123	et	3	main
teistpidi	doc_536541856880_item	3619120	et	3	main
maailmas	doc_536541856880_item	3619255	et	3	main
kasutamine	doc_536541856880_item	3619253	et	4	main
aktiivne	doc_536541856880_item	3619251	et	3	main
moodne	doc_536541856880_item	3619250	et	3	main
väga	doc_536541856880_item	3619249	et	3	main
töötlusi	doc_536541856880_item	3619245	et	3	main
mängisid	doc_536541856880_item	3619230	et	4	main
tagasi	doc_536541856880_item	3619223	et	3	main
kapp	doc_536541856880_item	3619218	et	3	main
heli	doc_536541856880_item	3619210	et	4	main
saatega	doc_536541856880_item	3619207	et	3	main
instrumendi	doc_536541856880_item	3619198	et	3	main
vene	doc_536541856880_item	3619188	et	4	main
ja	doc_536541856880_item	3619187	et	3	main
alati	doc_536541856880_item	3619183	et	4	main
kirjalikult	doc_536541856880_item	3619181	et	4	main
erinev	doc_536541856880_item	3619180	et	4	main
täiesti	doc_536541856880_item	3619179	et	3	main
oli	doc_536541856880_item	3619178	et	3	main
see	doc_536541856880_item	3619177	et	3	main
laul	doc_536541856880_item	3619176	et	4	main
uus	doc_536541856880_item	3619175	et	3	main
oli	doc_536541856880_item	3619174	et	3	main
kui	doc_536541856880_item	3619101	et	3	main
naised	doc_536541856880_item	3619098	et	3	main
sest	doc_536541856880_item	3619088	et	4	main
olid	doc_536541856880_item	3619080	et	4	main
väiteid	doc_536541856880_item	3619072	et	4	main
faktidele	doc_536541856880_item	3619071	et	3	main
esitatud	doc_536541856880_item	3619070	et	4	main
peab	doc_536541856880_item	3619060	et	4	main
eestlastest	doc_536541856880_item	3619052	et	4	main
kirjutage	doc_536541856880_item	3619047	et	3	main
test	doc_536541856880_item	3619045	et	3	main
oli	doc_536541856880_item	3619163	et	3	main
maie	doc_536541856880_item	3619159	et	4	main
mehed	doc_536541856880_item	3619117	et	3	main
setumaal	doc_536541856880_item	3619114	et	4	main
palju	doc_536541856880_item	3619111	et	4	main
väga	doc_536541856880_item	3619110	et	3	main
oli	doc_536541856880_item	3619109	et	3	main
saarel	doc_536541856880_item	3619108	et	3	main
kihnu	doc_536541856880_item	3619107	et	4	main
ja	doc_536541856880_item	3619106	et	3	main
setumaal	doc_536541856880_item	3619105	et	4	main
ja	doc_536541856881_item	3619428	et	3	main
rohkem	doc_536541856881_item	3619411	et	4	main
lauldi	doc_536541856881_item	3619410	et	3	main
vanasti	doc_536541856881_item	3619409	et	3	main
rahvas	doc_536541856881_item	3619399	et	4	main
essee	doc_536541856881_item	3619356	et	4	main
kirjutamine	doc_536541856881_item	3619354	et	4	main
eesti	doc_536541856881_item	3619348	et	4	main
rahvalauljad	doc_536541856881_item	3619618	et	3	main
ja	doc_536541856881_item	3619617	et	3	main
popp-	doc_536541856881_item	3619616	et	3	main
erinevate	doc_536541856881_item	3619608	et	4	main
jazzkarr	doc_536541856881_item	3619600	et	4	main
palju	doc_536541856881_item	3619596	et	4	main
ka	doc_536541856881_item	3619595	et	3	main
tekkis	doc_536541856881_item	3619594	et	3	main
eestis	doc_536541856881_item	3619593	et	3	main
laulmiseks	doc_536541856881_item	3619592	et	4	main
sobib	doc_536541856881_item	3619591	et	3	main
keeles	doc_536541856881_item	3619587	et	4	main
hakkasid	doc_536541856881_item	3619584	et	4	main
keeltest	doc_536541856881_item	3619576	et	4	main
ilusamadest	doc_536541856881_item	3619575	et	4	main
üks	doc_536541856881_item	3619574	et	3	main
peetakse	doc_536541856881_item	3619573	et	3	main
keelt	doc_536541856881_item	3619572	et	4	main
tulemused	doc_536541856881_item	3619566	et	3	main
näitavad	doc_536541856881_item	3619564	et	4	main
sellel	doc_536541856881_item	3619561	et	4	main
rahvav	doc_536541856880_item	3619244	et	4	main
kadakad	doc_536541856880_item	3619236	et	3	main
pianistide	doc_536541856880_item	3619226	et	3	main
konkurss	doc_536541856880_item	3619225	et	3	main
kasutab	doc_536541856880_item	3619243	et	3	main
ta	doc_536541856880_item	3619242	et	4	main
kassari	doc_536541856880_item	3619235	et	4	main
teos	doc_536541856880_item	3619234	et	4	main
kus	doc_536541856880_item	3619228	et	3	main
oli	doc_536541856880_item	3619224	et	3	main
kaks	doc_536541856880_item	3619221	et	3	main
teostes	doc_536541856880_item	3619215	et	3	main
paljud	doc_536541856880_item	3619209	et	3	main
laul	doc_536541856880_item	3619191	et	4	main
see	doc_536541856880_item	3619190	et	3	main
on	doc_536541856880_item	3619184	et	4	main
kadunud	doc_536541856880_item	3619172	et	4	main
on	doc_536541856880_item	3619171	et	4	main
regilaulud	doc_536541856880_item	3619170	et	3	main
praegu	doc_536541856880_item	3619169	et	3	main
mind	doc_536541856880_item	3619168	et	4	main
riimid	doc_536541856880_item	3619165	et	4	main
puhkasid	doc_536541856880_item	3619096	et	4	main
ja	doc_536541856880_item	3619095	et	3	main
töötasid	doc_536541856880_item	3619094	et	4	main
nad	doc_536541856880_item	3619093	et	3	main
tihti	doc_536541856880_item	3619092	et	3	main
väga	doc_536541856880_item	3619091	et	3	main
koguti	doc_536541856880_item	3619090	et	3	main
inimesed	doc_536541856880_item	3619089	et	3	main
aastat	doc_536541856880_item	3619222	et	3	main
saar	doc_536541856880_item	3619217	et	3	main
rahvaviisi	doc_536541856880_item	3619213	et	4	main
alati	doc_536541856880_item	3619206	et	4	main
ja	doc_536541856880_item	3619201	et	3	main
kõige	doc_536541856880_item	3619199	et	4	main
sest	doc_536541856880_item	3619195	et	4	main
levitud	doc_536541856880_item	3619194	et	4	main
väga	doc_536541856880_item	3619193	et	3	main
oli	doc_536541856880_item	3619192	et	3	main
tuntud	doc_536541856880_item	3619185	et	4	main
teiseks	doc_536541856880_item	3619173	et	4	main
sind	doc_536541856880_item	3619167	et	4	main
nad	doc_536541856880_item	3619102	et	3	main
koos	doc_536541856880_item	3619097	et	4	main
toimis	doc_536541856880_item	3619087	et	4	main
see	doc_536541856880_item	3619086	et	3	main
kogemused	doc_536541856880_item	3619081	et	3	main
eestlastel	doc_536541856880_item	3619079	et	4	main
ajast	doc_536541856880_item	3619078	et	4	main
vanast	doc_536541856880_item	3619077	et	3	main
näidetega	doc_536541856880_item	3619076	et	3	main
illustreerida	doc_536541856880_item	3619075	et	3	main
lugemistekstis	doc_536541856880_item	3619069	et	3	main
teeb	doc_536541856880_item	3619051	et	3	main
ilmusid	doc_536541856880_item	3619162	et	4	main
oli	doc_536541856880_item	3619158	et	3	main
mehed	doc_536541856880_item	3619121	et	3	main
aga	doc_536541856880_item	3619118	et	3	main
vanasti	doc_536541856881_item	3619432	et	3	main
venelased	doc_536541856881_item	3619425	et	3	main
eestis	doc_536541856881_item	3619423	et	3	main
mitte	doc_536541856881_item	3619421	et	3	main
niisugune	doc_536541856881_item	3619418	et	3	main
kuulata	doc_536541856881_item	3619416	et	4	main
eelistavad	doc_536541856881_item	3619414	et	4	main
inimesed	doc_536541856881_item	3619413	et	3	main
tänapäeva	doc_536541856881_item	3619412	et	4	main
saatis	doc_536541856881_item	3619395	et	3	main
jazzi-	doc_536541856881_item	3619614	et	4	main
festival	doc_536541856881_item	3619605	et	3	main
või	doc_536541856881_item	3619603	et	4	main
summer	doc_536541856881_item	3619602	et	3	main
rock	doc_536541856881_item	3619601	et	4	main
laulma	doc_536541856881_item	3619585	et	3	main
lauljad	doc_536541856881_item	3619583	et	4	main
eesti	doc_536541856881_item	3619582	et	4	main
paljud	doc_536541856881_item	3619581	et	3	main
et	doc_536541856881_item	3619580	et	3	main
tahan	doc_536541856881_item	3619567	et	3	main
eesti	doc_536541856881_item	3619556	et	4	main
võtavad	doc_536541856881_item	3619548	et	3	main
muusikalistes	doc_536541856881_item	3619547	et	4	main
tantsuti	doc_536541856880_item	3619085	et	4	main
lauldi	doc_536541856880_item	3619083	et	3	main
on	doc_536541856880_item	3619073	et	4	main
loengus	doc_536541856880_item	3619067	et	3	main
keele	doc_536541856880_item	3619041	et	4	main
kirikulaulud	doc_536541856880_item	3619161	et	3	main
sõna	doc_536541856880_item	3619156	et	4	main
et	doc_536541856880_item	3619155	et	3	main
tähendab	doc_536541856880_item	3619154	et	3	main
see	doc_536541856880_item	3619153	et	3	main
regilaulud	doc_536541856880_item	3619152	et	3	main
olid	doc_536541856880_item	3619151	et	4	main
esiteks	doc_536541856880_item	3619150	et	3	main
erilised	doc_536541856880_item	3619149	et	4	main
olid	doc_536541856880_item	3619148	et	4	main
laulud	doc_536541856880_item	3619147	et	3	main
vanad	doc_536541856880_item	3619146	et	3	main
pulmalaulud	doc_536541856880_item	3619145	et	3	main
populaarsed	doc_536541856880_item	3619144	et	3	main
väga	doc_536541856880_item	3619143	et	3	main
olid	doc_536541856880_item	3619142	et	4	main
näiteks	doc_536541856880_item	3619141	et	4	main
saatega	doc_536541856880_item	3619140	et	3	main
piili	doc_536541856880_item	3619139	et	4	main
laulda	doc_536541856880_item	3619138	et	4	main
hakkasid	doc_536541856880_item	3619137	et	4	main
inimesed	doc_536541856880_item	3619136	et	3	main
pärast	doc_536541856880_item	3619135	et	4	main
kordas	doc_536541856880_item	3619134	et	3	main
koor	doc_536541856880_item	3619133	et	4	main
ja	doc_536541856880_item	3619132	et	3	main
motiivi	doc_536541856880_item	3619131	et	4	main
laulis	doc_536541856880_item	3619130	et	4	main
ta	doc_536541856880_item	3619129	et	4	main
eeslaulja	doc_536541856880_item	3619128	et	4	main
ja	doc_536541856880_item	3619127	et	3	main
koor	doc_536541856880_item	3619126	et	4	main
oli	doc_536541856880_item	3619125	et	3	main
vanasti	doc_536541856880_item	3619124	et	3	main
ka	doc_536541856880_item	3619116	et	3	main
rahvad	doc_536541856881_item	3619431	et	3	main
hispaanlased	doc_536541856881_item	3619427	et	3	main
ka	doc_536541856881_item	3619424	et	3	main
oli	doc_536541856881_item	3619420	et	3	main
eriliste	doc_536541856881_item	3619404	et	4	main
ning	doc_536541856881_item	3619403	et	3	main
puhkades	doc_536541856881_item	3619402	et	4	main
töötades	doc_536541856881_item	3619401	et	3	main
laulis	doc_536541856881_item	3619400	et	4	main
iga	doc_536541856881_item	3619397	et	4	main
pikkus	doc_536541856881_item	3619363	et	4	main
mis	doc_536541856881_item	3619358	et	4	main
keele	doc_536541856881_item	3619349	et	4	main
essee	doc_536541856881_item	3619347	et	4	main
rocki-	doc_536541856881_item	3619615	et	4	main
laulavad	doc_536541856881_item	3619607	et	4	main
eestlased	doc_536541856881_item	3619606	et	3	main
muusikafestivaale	doc_536541856881_item	3619598	et	4	main
teisi	doc_536541856881_item	3619597	et	4	main
eesti	doc_536541856881_item	3619588	et	4	main
vaatamata	doc_536541856881_item	3619578	et	4	main
ja	doc_536541856881_item	3619577	et	3	main
ka	doc_536541856881_item	3619568	et	3	main
konkursil	doc_536541856881_item	3619562	et	3	main
sai	doc_536541856881_item	3619555	et	4	main
aastal	doc_536541856881_item	3619554	et	3	main
eestis	doc_536541856881_item	3619546	et	3	main
positiivselt	doc_536541856881_item	3619518	et	4	main
muusika	doc_536541856881_item	3619516	et	4	main
mõjus	doc_536541856881_item	3619514	et	4	main
ajaloofaktor	doc_536541856881_item	3619513	et	3	main
see	doc_536541856881_item	3619512	et	3	main
traditsioon	doc_536541856881_item	3619511	et	3	main
kultuuri-	doc_536541856881_item	3619507	et	4	main
mitte	doc_536541856881_item	3619505	et	3	main
riigi	doc_536541856881_item	3619500	et	3	main
lauluga	doc_536541856881_item	3619496	et	4	main
oma	doc_536541856881_item	3619494	et	4	main
nende	doc_536541856881_item	3619473	et	4	main
rahvas	doc_536541856881_item	3619467	et	4	main
koosseisus	doc_536541856881_item	3619465	et	4	main
väärt	doc_536541856881_item	3619456	et	4	main
on	doc_536541856881_item	3619452	et	4	main
eesti	doc_536541856881_item	3619450	et	4	main
et	doc_536541856881_item	3619449	et	3	main
nendel	doc_536541856881_item	3619436	et	4	main
palju	doc_536541856881_item	3619434	et	4	main
maailmas	doc_536541856882_item	3619873	et	3	main
teistega	doc_536541856882_item	3619863	et	4	main
mis	doc_536541856882_item	3619860	et	4	main
tunnet	doc_536541856882_item	3619859	et	3	main
rahvapidu	doc_536541856882_item	3619850	et	4	main
suur	doc_536541856882_item	3619849	et	3	main
on	doc_536541856882_item	3619848	et	4	main
laulupeo	doc_536541856882_item	3619824	et	4	main
selle	doc_536541856882_item	3619808	et	4	main
identiteedi	doc_536541856882_item	3619802	et	4	main
rahvusliku	doc_536541856882_item	3619801	et	3	main
mehed	doc_536541856882_item	3619796	et	3	main
pärandati	doc_536541856882_item	3619782	et	4	main
lihtsam	doc_536541856882_item	3619780	et	4	main
ja	doc_536541856882_item	3619759	et	3	main
tekkeks	doc_536541856882_item	3619755	et	3	main
tugines	doc_536541856882_item	3619751	et	3	main
levimine	doc_536541856882_item	3619750	et	4	main
laulude	doc_536541856882_item	3619749	et	3	main
rahvalaulu	doc_536541856882_item	3619742	et	4	main
regivärsiline	doc_536541856882_item	3619726	et	4	main
esindab	doc_536541856882_item	3619725	et	3	main
sellele	doc_536541856882_item	3619680	et	4	main
illustreerida	doc_536541856882_item	3619672	et	3	main
analüüsiv	doc_536541856882_item	3619660	et	4	main
pikkus	doc_536541856882_item	3619652	et	4	main
laulurahva	doc_536541856882_item	3619650	et	3	main
kujunenud	doc_536541856882_item	3619933	et	4	main
aja	doc_536541856882_item	3619932	et	4	main
on	doc_536541856882_item	3619930	et	4	main
laulud	doc_536541856882_item	3619929	et	3	main
ümbertöötlused	doc_536541856882_item	3619918	et	3	main
laulmisest	doc_536541856881_item	3619634	et	4	main
loobu	doc_536541856881_item	3619633	et	4	main
ei	doc_536541856881_item	3619632	et	4	main
kunagi	doc_536541856881_item	3619631	et	3	main
et	doc_536541856881_item	3619630	et	3	main
loodan	doc_536541856881_item	3619629	et	3	main
ja	doc_536541856881_item	3619628	et	3	main
laulurahvas	doc_536541856881_item	3619627	et	4	main
on	doc_536541856881_item	3619626	et	4	main
rahvas	doc_536541856881_item	3619625	et	4	main
eesti	doc_536541856881_item	3619624	et	4	main
ka	doc_536541856881_item	3619623	et	3	main
klubimuusikat	doc_536541856881_item	3619622	et	3	main
erinevat	doc_536541856881_item	3619621	et	4	main
väga	doc_536541856881_item	3619620	et	3	main
ning	doc_536541856881_item	3619619	et	3	main
laulsid	doc_536541856881_item	3619433	et	4	main
paljud	doc_536541856881_item	3619429	et	3	main
ainult	doc_536541856881_item	3619422	et	4	main
olukord	doc_536541856881_item	3619419	et	3	main
arust	doc_536541856881_item	3619408	et	4	main
minu	doc_536541856881_item	3619407	et	3	main
sündmuste	doc_536541856881_item	3619405	et	3	main
tegevust	doc_536541856881_item	3619398	et	4	main
traditsiooniliselt	doc_536541856881_item	3619393	et	4	main
saadik	doc_536541856881_item	3619392	et	4	main
aegadest	doc_536541856881_item	3619391	et	3	main
vanadest	doc_536541856881_item	3619390	et	3	main
laulmisega	doc_536541856881_item	3619389	et	4	main
seotud	doc_536541856881_item	3619388	et	4	main
on	doc_536541856881_item	3619387	et	4	main
elu	doc_536541856881_item	3619386	et	4	main
eestlaste	doc_536541856881_item	3619385	et	4	main
näidetega	doc_536541856881_item	3619384	et	3	main
illustreerida	doc_536541856881_item	3619383	et	3	main
soovitatav	doc_536541856881_item	3619382	et	4	main
on	doc_536541856881_item	3619381	et	4	main
väiteid	doc_536541856881_item	3619380	et	4	main
faktidele	doc_536541856881_item	3619379	et	3	main
esitatud	doc_536541856881_item	3619378	et	4	main
lugemistekstis	doc_536541856881_item	3619377	et	3	main
ja	doc_536541856881_item	3619376	et	3	main
loengus	doc_536541856881_item	3619375	et	3	main
tuginema	doc_536541856881_item	3619374	et	3	main
üldistav	doc_536541856881_item	3619373	et	4	main
ja	doc_536541856881_item	3619372	et	3	main
analüüsiv	doc_536541856881_item	3619371	et	4	main
arutlev	doc_536541856881_item	3619370	et	4	main
olema	doc_536541856881_item	3619369	et	4	main
peab	doc_536541856881_item	3619368	et	4	main
essee	doc_536541856881_item	3619367	et	4	main
sõna	doc_536541856881_item	3619366	et	4	main
350	doc_536541856881_item	3619365	et	2	main
300	doc_536541856881_item	3619364	et	2	main
teemal	doc_536541856881_item	3619357	et	3	main
kirjutage	doc_536541856881_item	3619355	et	3	main
test	doc_536541856881_item	3619353	et	3	main
keele	doc_536541856881_item	3619352	et	4	main
teise	doc_536541856881_item	3619351	et	4	main
kui	doc_536541856881_item	3619350	et	3	main
näiteks	doc_536541856881_item	3619599	et	4	main
suurepäraselt	doc_536541856881_item	3619590	et	4	main
keel	doc_536541856881_item	3619589	et	4	main
inglise	doc_536541856881_item	3619586	et	4	main
koha	doc_536541856881_item	3619558	et	4	main
esimese	doc_536541856881_item	3619557	et	3	main
paljud	doc_536541856881_item	3619550	et	3	main
osa	doc_536541856881_item	3619549	et	4	main
edukalt	doc_536541856881_item	3619544	et	4	main
ning	doc_536541856881_item	3619543	et	3	main
keelde	doc_536541856881_item	3619542	et	4	main
eesti	doc_536541856881_item	3619541	et	4	main
tõlgitud	doc_536541856881_item	3619540	et	4	main
on	doc_536541856881_item	3619539	et	4	main
julia	doc_536541856881_item	3619538	et	4	main
ja	doc_536541856881_item	3619537	et	3	main
romeo	doc_536541856881_item	3619536	et	4	main
fame	doc_536541856881_item	3619535	et	4	main
cats	doc_536541856881_item	3619534	et	4	main
näiteks	doc_536541856881_item	3619533	et	4	main
muusikalid	doc_536541856881_item	3619532	et	3	main
maailmatuntud	doc_536541856881_item	3619531	et	3	main
paljud	doc_536541856881_item	3619530	et	3	main
muusikalid	doc_536541856881_item	3619529	et	3	main
traditsioon	doc_536541856881_item	3619528	et	3	main
ütleks	doc_536541856881_item	3619527	et	3	main
ma	doc_536541856881_item	3619526	et	3	main
uus	doc_536541856881_item	3619525	et	3	main
tekkis	doc_536541856881_item	3619524	et	3	main
eestis	doc_536541856881_item	3619523	et	3	main
muusikaga	doc_536541856881_item	3619522	et	3	main
eestlased	doc_536541856881_item	3619520	et	3	main
laulupidude	doc_536541856881_item	3619502	et	4	main
vedaski	doc_536541856881_item	3619498	et	4	main
vaba	doc_536541856881_item	3619471	et	4	main
ajal	doc_536541856881_item	3619469	et	4	main
laulupidu	doc_536541856881_item	3619459	et	4	main
esimene	doc_536541856881_item	3619457	et	3	main
tõesti	doc_536541856881_item	3619455	et	3	main
rahvas	doc_536541856881_item	3619444	et	4	main
iga	doc_536541856881_item	3619443	et	4	main
traditsiooniliselt	doc_536541856881_item	3619560	et	4	main
eurovisioonil	doc_536541856881_item	3619559	et	3	main
lavastatud	doc_536541856881_item	3619545	et	4	main
paljud	doc_536541856881_item	3619519	et	3	main
eesti	doc_536541856881_item	3619515	et	4	main
poliitiline	doc_536541856881_item	3619510	et	3	main
on	doc_536541856881_item	3619504	et	4	main
tähistamine	doc_536541856881_item	3619503	et	4	main
pärast	doc_536541856881_item	3619499	et	4	main
kuid	doc_536541856881_item	3619472	et	4	main
tol	doc_536541856881_item	3619468	et	3	main
eest	doc_536541856881_item	3619466	et	4	main
ülemaaline	doc_536541856881_item	3619458	et	4	main
seda	doc_536541856881_item	3619453	et	3	main
tohutu	doc_536541856881_item	3619438	et	4	main
helilooja	doc_536541856882_item	3619880	et	4	main
ka	doc_536541856882_item	3619871	et	3	main
sõnu	doc_536541856882_item	3619866	et	4	main
sama	doc_536541856882_item	3619865	et	4	main
koos	doc_536541856882_item	3619853	et	4	main
sai	doc_536541856882_item	3619836	et	4	main
rahvusliku	doc_536541856882_item	3619832	et	3	main
selles	doc_536541856882_item	3619827	et	4	main
seisneb	doc_536541856882_item	3619826	et	3	main
tartus	doc_536541856882_item	3619820	et	3	main
rahva	doc_536541856882_item	3619815	et	3	main
laulupeod	doc_536541856882_item	3619807	et	4	main
pidudel	doc_536541856882_item	3619800	et	4	main
pulmades	doc_536541856882_item	3619798	et	3	main
tehes	doc_536541856882_item	3619793	et	3	main
kirjalikult	doc_536541856882_item	3619783	et	4	main
oli	doc_536541856882_item	3619778	et	3	main
rahvalaulu	doc_536541856882_item	3619776	et	4	main
riimi	doc_536541856882_item	3619768	et	4	main
erineb	doc_536541856882_item	3619766	et	3	main
eeldused	doc_536541856882_item	3619757	et	4	main
rahvalaul	doc_536541856882_item	3619727	et	4	main
ajalooga	doc_536541856882_item	3619721	et	4	main
rahva	doc_536541856882_item	3619720	et	3	main
ka	doc_536541856882_item	3619719	et	3	main
tutvud	doc_536541856882_item	3619718	et	3	main
arengut	doc_536541856881_item	3619517	et	3	main
ka	doc_536541856881_item	3619509	et	3	main
ainult	doc_536541856881_item	3619506	et	4	main
laulmine	doc_536541856881_item	3619497	et	4	main
hinge	doc_536541856881_item	3619495	et	4	main
väljendada	doc_536541856881_item	3619493	et	3	main
said	doc_536541856881_item	3619492	et	4	main
aga	doc_536541856881_item	3619491	et	3	main
valitseda	doc_536541856881_item	3619490	et	3	main
saanud	doc_536541856881_item	3619489	et	4	main
ei	doc_536541856881_item	3619488	et	4	main
eestlased	doc_536541856881_item	3619487	et	3	main
vabadus	doc_536541856881_item	3619486	et	4	main
riigi	doc_536541856881_item	3619485	et	3	main
isegi	doc_536541856881_item	3619484	et	4	main
kui	doc_536541856881_item	3619483	et	3	main
tähtsam	doc_536541856881_item	3619482	et	4	main
palju	doc_536541856881_item	3619481	et	4	main
meelest	doc_536541856881_item	3619480	et	4	main
minu	doc_536541856881_item	3619479	et	3	main
on	doc_536541856881_item	3619478	et	4	main
vaimuvabadus	doc_536541856881_item	3619477	et	4	main
tegelevad	doc_536541856881_item	3619521	et	4	main
vaid	doc_536541856881_item	3619508	et	3	main
vabaduseni	doc_536541856881_item	3619501	et	4	main
polnud	doc_536541856881_item	3619470	et	3	main
aastal	doc_536541856881_item	3619462	et	3	main
toimus	doc_536541856881_item	3619460	et	3	main
veendunud	doc_536541856881_item	3619448	et	4	main
olen	doc_536541856881_item	3619447	et	3	main
laulurahvaks	doc_536541856881_item	3619446	et	3	main
nimetatakse	doc_536541856881_item	3619445	et	3	main
on	doc_536541856881_item	3619437	et	4	main
tuntumaid	doc_536541856882_item	3619875	et	4	main
üks	doc_536541856882_item	3619874	et	3	main
kaasaegses	doc_536541856882_item	3619872	et	3	main
see	doc_536541856882_item	3619847	et	3	main
kaotanud	doc_536541856882_item	3619844	et	4	main
ning	doc_536541856882_item	3619835	et	3	main
liikumise	doc_536541856882_item	3619833	et	4	main
eestlaste	doc_536541856882_item	3619831	et	4	main
kujunes	doc_536541856882_item	3619830	et	3	main
sellest	doc_536541856882_item	3619829	et	4	main
et	doc_536541856882_item	3619828	et	3	main
1869	doc_536541856882_item	3619821	et	2	main
suurt	doc_536541856882_item	3619812	et	3	main
olid	doc_536541856882_item	3619806	et	4	main
ajal	doc_536541856882_item	3619805	et	4	main
nõukogude	doc_536541856882_item	3619804	et	3	main
laulsid	doc_536541856882_item	3619797	et	4	main
laulsid	doc_536541856882_item	3619791	et	4	main
naised	doc_536541856882_item	3619789	et	3	main
tavaliselt	doc_536541856882_item	3619787	et	4	main
trükitult	doc_536541856882_item	3619786	et	4	main
neid	doc_536541856882_item	3619781	et	4	main
levimine	doc_536541856882_item	3619777	et	4	main
olekuga	doc_536541856882_item	3619769	et	3	main
laulutraditsiooni	doc_536541856882_item	3619762	et	4	main
vanema	doc_536541856882_item	3619758	et	4	main
rütmi	doc_536541856882_item	3619747	et	4	main
ka	doc_536541856882_item	3619746	et	3	main
kaasneda	doc_536541856882_item	3619745	et	3	main
võis	doc_536541856882_item	3619744	et	4	main
ainult	doc_536541856882_item	3619739	et	4	main
sõna	doc_536541856882_item	3619736	et	4	main
vanemat	doc_536541856882_item	3619723	et	4	main
laulmise	doc_536541856882_item	3619687	et	4	main
üldistav	doc_536541856882_item	3619662	et	4	main
ja	doc_536541856882_item	3619661	et	3	main
essee	doc_536541856882_item	3619656	et	4	main
hulgas	doc_536541856882_item	3619907	et	4	main
noorte	doc_536541856882_item	3619906	et	3	main
alustatakse	doc_536541856882_item	3619905	et	3	main
seda	doc_536541856882_item	3619904	et	3	main
kui	doc_536541856882_item	3619903	et	3	main
tagasi	doc_536541856884_item	3620229	et	3	main
ka	doc_536541856884_item	3620226	et	3	main
nagu	doc_536541856884_item	3620223	et	3	main
mõjut	doc_536541856884_item	3620219	et	4	main
palju	doc_536541856884_item	3620217	et	4	main
nii	doc_536541856884_item	3620216	et	3	main
setumaal	doc_536541856884_item	3620212	et	4	main
et	doc_536541856884_item	3620208	et	3	main
rahvus	doc_536541856884_item	3620202	et	3	main
sõnadega	doc_536541856884_item	3620200	et	3	main
kasutamist	doc_536541856884_item	3620188	et	4	main
laulda	doc_536541856884_item	3620183	et	4	main
kohata	doc_536541856884_item	3620178	et	4	main
viitma	doc_536541856884_item	3620177	et	3	main
inimesed	doc_536541856884_item	3620171	et	3	main
tehes	doc_536541856884_item	3620165	et	3	main
nii	doc_536541856884_item	3620163	et	3	main
ajal	doc_536541856884_item	3620162	et	4	main
heal	doc_536541856884_item	3620161	et	3	main
kui	doc_536541856884_item	3620160	et	3	main
halval	doc_536541856884_item	3620159	et	3	main
nii	doc_536541856884_item	3620158	et	3	main
eestlasi	doc_536541856884_item	3620157	et	3	main
saatnud	doc_536541856884_item	3620156	et	4	main
aitab	doc_536541856884_item	3620148	et	3	main
ühendab	doc_536541856884_item	3620146	et	3	main
see	doc_536541856884_item	3620144	et	3	main
ja	doc_536541856884_item	3620135	et	3	main
sajandil	doc_536541856884_item	3620127	et	3	main
olema	doc_536541856881_item	3619476	et	4	main
hakkas	doc_536541856881_item	3619475	et	3	main
vaim	doc_536541856881_item	3619474	et	3	main
venemaa	doc_536541856881_item	3619464	et	4	main
tsaristliku	doc_536541856881_item	3619463	et	3	main
1869	doc_536541856881_item	3619461	et	2	main
nimetust	doc_536541856881_item	3619454	et	4	main
rahvas	doc_536541856881_item	3619451	et	4	main
mitte	doc_536541856881_item	3619442	et	3	main
aga	doc_536541856881_item	3619441	et	3	main
kuid	doc_536541856881_item	3619440	et	4	main
rahvalaule	doc_536541856881_item	3619439	et	4	main
ja	doc_536541856881_item	3619435	et	3	main
tormis	doc_536541856882_item	3619882	et	3	main
eesti	doc_536541856882_item	3619879	et	4	main
on	doc_536541856882_item	3619878	et	4	main
maailmas	doc_536541856882_item	3619877	et	3	main
heliloojaid	doc_536541856882_item	3619876	et	3	main
saadavad	doc_536541856882_item	3619869	et	4	main
laulud	doc_536541856882_item	3619868	et	3	main
kuhu	doc_536541856882_item	3619851	et	3	main
armastust	doc_536541856882_item	3619846	et	4	main
inimeste	doc_536541856882_item	3619845	et	3	main
ei	doc_536541856882_item	3619843	et	4	main
laulupidu	doc_536541856882_item	3619842	et	4	main
tänapäeval	doc_536541856882_item	3619841	et	3	main
ka	doc_536541856882_item	3619840	et	3	main
traditsioon	doc_536541856882_item	3619839	et	3	main
kõrghetk	doc_536541856882_item	3619834	et	3	main
tähtsus	doc_536541856882_item	3619825	et	4	main
toimus	doc_536541856882_item	3619819	et	3	main
esimene	doc_536541856882_item	3619817	et	3	main
eesti	doc_536541856882_item	3619814	et	4	main
omavad	doc_536541856882_item	3619811	et	4	main
nad	doc_536541856882_item	3619810	et	3	main
pärast	doc_536541856882_item	3619809	et	4	main
hoidjaks	doc_536541856882_item	3619803	et	4	main
tegeledes	doc_536541856882_item	3619795	et	3	main
lastega	doc_536541856882_item	3619794	et	3	main
isegi	doc_536541856882_item	3619785	et	4	main
ja	doc_536541856882_item	3619784	et	3	main
ka	doc_536541856882_item	3619779	et	3	main
uuema	doc_536541856882_item	3619775	et	4	main
pillisaatega	doc_536541856882_item	3619774	et	3	main
esitatud	doc_536541856882_item	3619773	et	4	main
rahvalaul	doc_536541856882_item	3619765	et	4	main
koosmõju	doc_536541856882_item	3619763	et	4	main
laenatud	doc_536541856882_item	3619761	et	4	main
euroopast	doc_536541856882_item	3619760	et	3	main
uema	doc_536541856882_item	3619753	et	4	main
laulmisega	doc_536541856882_item	3619743	et	4	main
ja	doc_536541856882_item	3619738	et	3	main
on	doc_536541856882_item	3619730	et	4	main
laulule	doc_536541856882_item	3619729	et	3	main
sellele	doc_536541856882_item	3619728	et	4	main
eesti	doc_536541856882_item	3619722	et	4	main
tähtsusega	doc_536541856882_item	3619688	et	4	main
ja	doc_536541856882_item	3619686	et	3	main
laulutraditsioonide	doc_536541856882_item	3619685	et	3	main
mis	doc_536541856882_item	3619674	et	4	main
soovitatav	doc_536541856882_item	3619671	et	4	main
väiteid	doc_536541856882_item	3619669	et	4	main
faktidele	doc_536541856882_item	3619668	et	3	main
esitatud	doc_536541856882_item	3619667	et	4	main
lugemistekstis	doc_536541856882_item	3619666	et	3	main
ja	doc_536541856882_item	3619665	et	3	main
loengus	doc_536541856882_item	3619664	et	3	main
tuginema	doc_536541856882_item	3619663	et	3	main
peab	doc_536541856882_item	3619657	et	4	main
300	doc_536541856882_item	3619653	et	2	main
eestlastest	doc_536541856882_item	3619649	et	4	main
rahvuslikeks	doc_536541856882_item	3619934	et	3	main
alati	doc_536541856882_item	3619924	et	4	main
minevik	doc_536541856882_item	3619923	et	3	main
tema	doc_536541856882_item	3619922	et	4	main
laulurahva	doc_536541856882_item	3619921	et	3	main
teeb	doc_536541856882_item	3619920	et	3	main
eestlastest	doc_536541856882_item	3619919	et	4	main
näiteks	doc_536541856882_item	3619915	et	4	main
teha	doc_536541856882_item	3619911	et	3	main
jätkavad	doc_536541856882_item	3619900	et	4	main
tuttavad	doc_536541856882_item	3619888	et	4	main
paljudele	doc_536541856882_item	3619887	et	3	main
on	doc_536541856882_item	3619886	et	4	main
ümbertöötlused	doc_536541856882_item	3619885	et	3	main
rahvalaulude	doc_536541856882_item	3619884	et	3	main
kelle	doc_536541856882_item	3619883	et	4	main
veljo	doc_536541856882_item	3619881	et	4	main
eestlasi	doc_536541856882_item	3619870	et	3	main
lauldes	doc_536541856882_item	3619867	et	3	main
üheskoos	doc_536541856882_item	3619864	et	3	main
paljude	doc_536541856882_item	3619862	et	3	main
tekib	doc_536541856882_item	3619861	et	3	main
ülendavat	doc_536541856882_item	3619858	et	4	main
seda	doc_536541856882_item	3619857	et	3	main
kogeda	doc_536541856882_item	3619856	et	3	main
et	doc_536541856882_item	3619855	et	3	main
perega	doc_536541856882_item	3619854	et	3	main
tullakse	doc_536541856882_item	3619852	et	3	main
laulupidude	doc_536541856882_item	3619838	et	4	main
alguse	doc_536541856882_item	3619837	et	3	main
selle	doc_536541856882_item	3619823	et	4	main
aastal	doc_536541856882_item	3619822	et	3	main
laulupidu	doc_536541856882_item	3619818	et	4	main
jaoks	doc_536541856882_item	3619816	et	4	main
tähtsust	doc_536541856882_item	3619813	et	4	main
ja	doc_536541856882_item	3619799	et	3	main
töid	doc_536541856882_item	3619792	et	3	main
nad	doc_536541856882_item	3619790	et	3	main
laulsid	doc_536541856882_item	3619788	et	4	main
on	doc_536541856882_item	3619772	et	4	main
seda	doc_536541856882_item	3619771	et	3	main
ning	doc_536541856882_item	3619770	et	3	main
vanemast	doc_536541856882_item	3619767	et	4	main
uuem	doc_536541856882_item	3619764	et	4	main
lõi	doc_536541856882_item	3619756	et	4	main
rahvalaulu	doc_536541856882_item	3619754	et	4	main
mälule	doc_536541856882_item	3619752	et	3	main
rõhutamine	doc_536541856882_item	3619748	et	4	main
vanema	doc_536541856882_item	3619741	et	4	main
vokaalesitus	doc_536541856882_item	3619740	et	3	main
lõpus	doc_536541856882_item	3619737	et	4	main
laulu	doc_536541856882_item	3619735	et	4	main
iga	doc_536541856882_item	3619734	et	4	main
silp	doc_536541856882_item	3619733	et	3	main
maie	doc_536541856882_item	3619732	et	4	main
iseloomulik	doc_536541856882_item	3619731	et	3	main
laulutraditsiooni	doc_536541856882_item	3619724	et	4	main
rahvalaulutraditsioonidega	doc_536541856882_item	3619717	et	3	main
tutvudes	doc_536541856882_item	3619716	et	3	main
et	doc_536541856882_item	3619715	et	3	main
väita	doc_536541856882_item	3619714	et	4	main
kindlalt	doc_536541856882_item	3619713	et	4	main
võib	doc_536541856882_item	3619712	et	3	main
põhjusel	doc_536541856882_item	3619711	et	3	main
sellel	doc_536541856882_item	3619710	et	4	main
ja	doc_536541856882_item	3619709	et	3	main
elu	doc_536541856882_item	3619708	et	4	main
rahva	doc_536541856882_item	3619707	et	3	main
peegeldub	doc_536541856882_item	3619706	et	3	main
rahvalauludes	doc_536541856882_item	3619705	et	3	main
pidutsedes	doc_536541856882_item	3619704	et	3	main
ka	doc_536541856882_item	3619703	et	3	main
kui	doc_536541856882_item	3619702	et	3	main
tehes	doc_536541856882_item	3619701	et	3	main
nii	doc_536541856882_item	3619699	et	3	main
lauldi	doc_536541856882_item	3619698	et	3	main
hauani	doc_536541856882_item	3619697	et	3	main
hällist	doc_536541856882_item	3619696	et	4	main
tööd	doc_536541856882_item	3619700	et	4	main
eestlast	doc_536541856882_item	3619695	et	4	main
laul	doc_536541856882_item	3619694	et	4	main
saatis	doc_536541856882_item	3619693	et	3	main
ajal	doc_536541856882_item	3619692	et	4	main
vanal	doc_536541856882_item	3619691	et	3	main
jaoks	doc_536541856882_item	3619690	et	4	main
rahva	doc_536541856882_item	3619689	et	3	main
vastata	doc_536541856882_item	3619679	et	4	main
et	doc_536541856882_item	3619678	et	3	main
laulurahva	doc_536541856882_item	3619677	et	3	main
eestlastest	doc_536541856882_item	3619676	et	4	main
eesti	doc_536541856882_item	3619684	et	4	main
tutvuda	doc_536541856882_item	3619683	et	3	main
tuleb	doc_536541856882_item	3619682	et	3	main
küsimusele	doc_536541856882_item	3619681	et	4	main
näidetega	doc_536541856882_item	3619673	et	3	main
on	doc_536541856882_item	3619670	et	4	main
olema	doc_536541856882_item	3619658	et	4	main
350	doc_536541856882_item	3619654	et	2	main
teeb	doc_536541856882_item	3619648	et	3	main
mis	doc_536541856882_item	3619647	et	4	main
teemal	doc_536541856882_item	3619646	et	3	main
essee	doc_536541856882_item	3619645	et	4	main
kirjutage	doc_536541856882_item	3619644	et	3	main
kirjutamine	doc_536541856882_item	3619643	et	4	main
test	doc_536541856882_item	3619642	et	3	main
keele	doc_536541856882_item	3619641	et	4	main
teise	doc_536541856882_item	3619640	et	4	main
kui	doc_536541856882_item	3619639	et	3	main
keele	doc_536541856882_item	3619638	et	4	main
eesti	doc_536541856882_item	3619637	et	4	main
essee	doc_536541856882_item	3619636	et	4	main
teeb	doc_536541856882_item	3619675	et	3	main
arutlev	doc_536541856882_item	3619659	et	4	main
sõna	doc_536541856882_item	3619655	et	4	main
essee	doc_536541856882_item	3619651	et	4	main
sümboliteks	doc_536541856882_item	3619935	et	3	main
läbi	doc_536541856882_item	3619931	et	4	main
laulutraditsioonid	doc_536541856882_item	3619928	et	3	main
ja	doc_536541856882_item	3619927	et	3	main
lauludega	doc_536541856882_item	3619926	et	3	main
seotud	doc_536541856882_item	3619925	et	4	main
laulu	doc_536541856882_item	3619902	et	4	main
alati	doc_536541856882_item	3619901	et	4	main
säilinud	doc_536541856882_item	3619896	et	4	main
eriti	doc_536541856882_item	3619894	et	3	main
setumaal	doc_536541856882_item	3619892	et	4	main
ja	doc_536541856882_item	3619891	et	3	main
saarel	doc_536541856882_item	3619890	et	3	main
dagö	doc_536541856882_item	3619917	et	4	main
mulle	doc_536541856882_item	3619914	et	4	main
rahvalaulude	doc_536541856882_item	3619912	et	3	main
vanad	doc_536541856882_item	3619897	et	3	main
hästi	doc_536541856882_item	3619895	et	3	main
säilinud	doc_536541856884_item	3620221	et	4	main
rahvalaulude	doc_536541856884_item	3620199	et	3	main
kuid	doc_536541856884_item	3620197	et	4	main
olemas	doc_536541856884_item	3620191	et	4	main
muidugi	doc_536541856884_item	3620181	et	4	main
ja	doc_536541856884_item	3620180	et	3	main
sõpru	doc_536541856884_item	3620179	et	3	main
laulupeole	doc_536541856884_item	3620172	et	4	main
end	doc_536541856884_item	3620151	et	4	main
rahvusele	doc_536541856884_item	3620149	et	3	main
mis	doc_536541856884_item	3620147	et	4	main
mis	doc_536541856884_item	3620145	et	4	main
on	doc_536541856884_item	3620143	et	4	main
sümboliteks	doc_536541856884_item	3620141	et	3	main
on	doc_536541856884_item	3620129	et	4	main
ärkimisele	doc_536541856884_item	3620120	et	4	main
laulupeod	doc_536541856884_item	3620109	et	4	main
laulupidu	doc_536541856884_item	3620108	et	4	main
sajandil	doc_536541856884_item	3620083	et	3	main
ka	doc_536541856884_item	3620079	et	3	main
lihtsalt	doc_536541856884_item	3620030	et	4	main
meeldivad	doc_536541856882_item	3619916	et	4	main
ümbertöötlusi	doc_536541856882_item	3619913	et	3	main
kombe	doc_536541856882_item	3619910	et	4	main
populaarne	doc_536541856882_item	3619909	et	3	main
on	doc_536541856882_item	3619908	et	4	main
laulutraditsioonid	doc_536541856882_item	3619898	et	3	main
on	doc_536541856882_item	3619893	et	4	main
kihnu	doc_536541856882_item	3619889	et	4	main
need	doc_536541856884_item	3620224	et	3	main
on	doc_536541856884_item	3620220	et	4	main
linnamuusika	doc_536541856884_item	3620218	et	4	main
näiteks	doc_536541856884_item	3620211	et	4	main
kohtadel	doc_536541856884_item	3620210	et	3	main
iseloomustab	doc_536541856884_item	3620205	et	4	main
laulurahvus	doc_536541856884_item	3620204	et	3	main
kaasaegse	doc_536541856884_item	3620195	et	3	main
mis	doc_536541856884_item	3620193	et	4	main
aja	doc_536541856884_item	3620176	et	4	main
perega	doc_536541856884_item	3620175	et	3	main
oma	doc_536541856884_item	3620174	et	4	main
lootuses	doc_536541856884_item	3620173	et	4	main
samuti	doc_536541856884_item	3620169	et	3	main
pidutsedes	doc_536541856884_item	3620168	et	3	main
kui	doc_536541856884_item	3620166	et	3	main
tervikuna	doc_536541856884_item	3620152	et	3	main
on	doc_536541856884_item	3620138	et	4	main
üldse	doc_536541856884_item	3620137	et	3	main
laulud	doc_536541856884_item	3620136	et	3	main
taasiseseisvumiseni	doc_536541856884_item	3620125	et	3	main
ja	doc_536541856884_item	3620123	et	3	main
tõuke	doc_536541856884_item	3620118	et	4	main
andsid	doc_536541856884_item	3620117	et	4	main
need	doc_536541856884_item	3620116	et	3	main
just	doc_536541856884_item	3620115	et	3	main
ajaloos	doc_536541856884_item	3620114	et	4	main
on	doc_536541856884_item	3620107	et	4	main
sündmus	doc_536541856884_item	3620106	et	3	main
kõige	doc_536541856884_item	3620101	et	4	main
isegi	doc_536541856884_item	3620098	et	4	main
üks	doc_536541856884_item	3620096	et	3	main
muidugi	doc_536541856884_item	3620095	et	4	main
hakati	doc_536541856884_item	3620087	et	3	main
laulude	doc_536541856884_item	3620085	et	3	main
19	doc_536541856884_item	3620082	et	2	main
kaasnes	doc_536541856884_item	3620078	et	3	main
koorilaul	doc_536541856884_item	3620076	et	4	main
kirikulaul	doc_536541856884_item	3620074	et	4	main
ka	doc_536541856884_item	3620073	et	3	main
levima	doc_536541856884_item	3620072	et	3	main
hakkas	doc_536541856884_item	3620071	et	3	main
18	doc_536541856884_item	3620069	et	2	main
armastust	doc_536541856884_item	3620018	et	4	main
peegeldavad	doc_536541856884_item	3620007	et	4	main
tegevus	doc_536541856884_item	3620004	et	4	main
sotsiaalne	doc_536541856884_item	3620003	et	3	main
ka	doc_536541856884_item	3620002	et	3	main
kui	doc_536541856884_item	3620001	et	3	main
on	doc_536541856884_item	3619997	et	4	main
laulmine	doc_536541856884_item	3619988	et	4	main
oluline	doc_536541856884_item	3619978	et	4	main
üsna	doc_536541856884_item	3619977	et	3	main
teisest	doc_536541856885_item	3620455	et	4	main
erastab	doc_536541856885_item	3620454	et	3	main
ning	doc_536541856885_item	3620453	et	3	main
ühtlastab	doc_536541856885_item	3620447	et	4	main
laul	doc_536541856885_item	3620446	et	4	main
olud	doc_536541856885_item	3620440	et	3	main
poliitilised	doc_536541856885_item	3620439	et	3	main
revolutsioon	doc_536541856885_item	3620326	et	3	main
kuid	doc_536541856885_item	3620316	et	4	main
oma	doc_536541856885_item	3620313	et	4	main
tulevad	doc_536541856885_item	3620300	et	4	main
inimesi	doc_536541856885_item	3620299	et	4	main
tuhandeid	doc_536541856885_item	3620298	et	3	main
sümbol	doc_536541856885_item	3620297	et	3	main
tantsis	doc_536541856885_item	3620291	et	4	main
ja	doc_536541856885_item	3620290	et	3	main
laulus	doc_536541856885_item	3620289	et	3	main
pöördusid	doc_536541856885_item	3620279	et	4	main
tuginema	doc_536541856885_item	3620258	et	3	main
essee	doc_536541856885_item	3620251	et	4	main
inimesed	doc_536541856882_item	3619899	et	3	main
laulutraditsioonid	doc_536541856884_item	3620222	et	3	main
ei	doc_536541856884_item	3620214	et	4	main
ka	doc_536541856884_item	3620206	et	3	main
kui	doc_536541856884_item	3620203	et	3	main
eesti	doc_536541856884_item	3620201	et	4	main
vanade	doc_536541856884_item	3620198	et	3	main
esitavad	doc_536541856884_item	3620194	et	4	main
on	doc_536541856884_item	3620190	et	4	main
ka	doc_536541856884_item	3620186	et	3	main
tänapäeval	doc_536541856884_item	3620184	et	3	main
kaasa	doc_536541856884_item	3620182	et	4	main
on	doc_536541856884_item	3620155	et	4	main
ju	doc_536541856884_item	3620154	et	3	main
laulud	doc_536541856884_item	3620142	et	3	main
rahvuslikeks	doc_536541856884_item	3620140	et	3	main
kujunenud	doc_536541856884_item	3620139	et	4	main
aastat	doc_536541856884_item	3620228	et	3	main
palju	doc_536541856884_item	3620227	et	4	main
olid	doc_536541856884_item	3620225	et	4	main
ole	doc_536541856884_item	3620215	et	4	main
kus	doc_536541856884_item	3620213	et	3	main
mõnedel	doc_536541856884_item	3620209	et	3	main
see	doc_536541856884_item	3620207	et	3	main
muusikaga	doc_536541856884_item	3620196	et	3	main
ansamblid	doc_536541856884_item	3620192	et	3	main
näiteks	doc_536541856884_item	3620189	et	4	main
leiavad	doc_536541856884_item	3620187	et	3	main
rahvalaulutraditsioonid	doc_536541856884_item	3620185	et	3	main
tulevad	doc_536541856884_item	3620170	et	4	main
ka	doc_536541856884_item	3620167	et	3	main
tööd	doc_536541856884_item	3620164	et	4	main
laul	doc_536541856884_item	3620153	et	4	main
tunna	doc_536541856884_item	3620150	et	4	main
laulupeod	doc_536541856884_item	3620134	et	4	main
et	doc_536541856884_item	3620133	et	3	main
sellepärast	doc_536541856884_item	3620132	et	3	main
kõigepealt	doc_536541856884_item	3620131	et	3	main
laulurahvas	doc_536541856884_item	3620130	et	4	main
eestlased	doc_536541856884_item	3620128	et	3	main
sajandil	doc_536541856884_item	3620122	et	3	main
rahva	doc_536541856884_item	3620119	et	3	main
laulu	doc_536541856884_item	3620093	et	4	main
ilmusid	doc_536541856884_item	3620092	et	4	main
ja	doc_536541856884_item	3620091	et	3	main
pillisaateid	doc_536541856884_item	3620090	et	3	main
sellega	doc_536541856884_item	3620077	et	3	main
ja	doc_536541856884_item	3620075	et	3	main
suuliselt	doc_536541856884_item	3620067	et	4	main
põlve	doc_536541856884_item	3620066	et	4	main
armastus	doc_536541856884_item	3620031	et	4	main
eestlastest	doc_536541856884_item	3620022	et	4	main
aga	doc_536541856884_item	3620019	et	3	main
just	doc_536541856884_item	3620005	et	3	main
väljendusvahend	doc_536541856884_item	3620000	et	3	main
on	doc_536541856884_item	3619987	et	4	main
jaoks	doc_536541856884_item	3619986	et	4	main
on	doc_536541856884_item	3619976	et	4	main
test	doc_536541856884_item	3619943	et	3	main
teise	doc_536541856884_item	3619941	et	4	main
eesti	doc_536541856884_item	3619938	et	4	main
tugevaks	doc_536541856885_item	3620452	et	4	main
neid	doc_536541856885_item	3620451	et	4	main
teeb	doc_536541856885_item	3620450	et	3	main
fakti	doc_536541856885_item	3620445	et	4	main
valitsenud	doc_536541856885_item	3620438	et	4	main
eest	doc_536541856885_item	3620315	et	4	main
võitlesid	doc_536541856885_item	3620312	et	4	main
eestlased	doc_536541856885_item	3620311	et	3	main
ajal	doc_536541856885_item	3620310	et	4	main
nõukogude	doc_536541856885_item	3620309	et	3	main
tunnet	doc_536541856885_item	3620308	et	3	main
rahvalaulu	doc_536541856885_item	3620305	et	4	main
kaasa	doc_536541856885_item	3620304	et	4	main
on	doc_536541856885_item	3620293	et	4	main
laulupidu	doc_536541856885_item	3620292	et	4	main
päästmist	doc_536541856885_item	3620287	et	4	main
rahvas	doc_536541856885_item	3620284	et	4	main
vastu	doc_536541856885_item	3620282	et	3	main
saamiseks	doc_536541856885_item	3620275	et	4	main
ajal	doc_536541856885_item	3620273	et	4	main
ja	doc_536541856885_item	3620256	et	3	main
pikkus	doc_536541856885_item	3620247	et	4	main
essee	doc_536541856885_item	3620231	et	4	main
eestlasi	doc_536541856885_item	3620433	et	3	main
suudis	doc_536541856885_item	3620424	et	4	main
imelik	doc_536541856885_item	3620419	et	3	main
on	doc_536541856885_item	3620411	et	4	main
eestlased	doc_536541856885_item	3620410	et	3	main
et	doc_536541856885_item	3620409	et	3	main
öelda	doc_536541856885_item	3620408	et	4	main
võin	doc_536541856885_item	3620407	et	3	main
kindlasti	doc_536541856885_item	3620406	et	3	main
20	doc_536541856884_item	3620126	et	2	main
viidid	doc_536541856884_item	3620124	et	3	main
19	doc_536541856884_item	3620121	et	2	main
muusikaline	doc_536541856884_item	3620105	et	4	main
lemmikum	doc_536541856884_item	3620104	et	4	main
ja	doc_536541856884_item	3620103	et	3	main
kuulsam	doc_536541856884_item	3620102	et	4	main
võib	doc_536541856884_item	3620099	et	3	main
ja	doc_536541856884_item	3620097	et	3	main
autorid	doc_536541856884_item	3620094	et	3	main
mõjuga	doc_536541856884_item	3620086	et	3	main
euroopa	doc_536541856884_item	3620084	et	4	main
sajandil	doc_536541856884_item	3620070	et	3	main
hiljem	doc_536541856884_item	3620068	et	3	main
põlvest	doc_536541856884_item	3620065	et	4	main
pärandati	doc_536541856884_item	3620064	et	4	main
ja	doc_536541856884_item	3620063	et	3	main
kasutati	doc_536541856884_item	3620062	et	4	main
ei	doc_536541856884_item	3620061	et	4	main
pillisaateid	doc_536541856884_item	3620060	et	3	main
esitamises	doc_536541856884_item	3620059	et	4	main
regilaule	doc_536541856884_item	3620058	et	4	main
koor	doc_536541856884_item	3620057	et	4	main
ja	doc_536541856884_item	3620056	et	3	main
eeslaulja	doc_536541856884_item	3620055	et	4	main
osast	doc_536541856884_item	3620054	et	4	main
kahest	doc_536541856884_item	3620053	et	4	main
koosnesid	doc_536541856884_item	3620052	et	4	main
nad	doc_536541856884_item	3620051	et	3	main
tavaliselt	doc_536541856884_item	3620050	et	4	main
tagasi	doc_536541856884_item	3620049	et	3	main
aastat	doc_536541856884_item	3620048	et	3	main
tuhat	doc_536541856884_item	3620047	et	4	main
kui	doc_536541856884_item	3620046	et	3	main
enam	doc_536541856884_item	3620045	et	4	main
kujunenud	doc_536541856884_item	3620044	et	4	main
on	doc_536541856884_item	3620043	et	4	main
regivärsilised	doc_536541856884_item	3620041	et	4	main
esimesed	doc_536541856884_item	3620040	et	3	main
õiged	doc_536541856884_item	3620039	et	3	main
on	doc_536541856884_item	3620038	et	4	main
rahvalaulud	doc_536541856884_item	3620042	et	3	main
variantid	doc_536541856884_item	3620037	et	4	main
need	doc_536541856884_item	3620036	et	3	main
kõik	doc_536541856884_item	3620035	et	4	main
eesti	doc_536541856884_item	3620113	et	4	main
roll	doc_536541856884_item	3620112	et	3	main
suur	doc_536541856884_item	3620111	et	3	main
mängisid	doc_536541856884_item	3620110	et	4	main
olla	doc_536541856884_item	3620100	et	3	main
erinevaid	doc_536541856884_item	3620089	et	4	main
kasutama	doc_536541856884_item	3620088	et	3	main
asutamine	doc_536541856884_item	3620081	et	4	main
puhkpilliorkestrite	doc_536541856884_item	3620080	et	3	main
lauluajalugu	doc_536541856884_item	3620026	et	4	main
rikkas	doc_536541856884_item	3620025	et	4	main
kas	doc_536541856884_item	3620024	et	3	main
laulurahva	doc_536541856884_item	3620023	et	3	main
mis	doc_536541856884_item	3620020	et	4	main
isamaa	doc_536541856884_item	3620017	et	4	main
tulevikule	doc_536541856884_item	3620016	et	4	main
laulad	doc_536541856884_item	3620006	et	3	main
kultuuri	doc_536541856884_item	3619991	et	4	main
põhilistest	doc_536541856884_item	3619990	et	3	main
üks	doc_536541856884_item	3619989	et	3	main
loomulikult	doc_536541856884_item	3619983	et	4	main
laulmine	doc_536541856884_item	3619975	et	4	main
keele	doc_536541856884_item	3619942	et	4	main
keele	doc_536541856884_item	3619939	et	4	main
essee	doc_536541856884_item	3619937	et	4	main
ei	doc_536541856885_item	3620441	et	4	main
enne	doc_536541856885_item	3620435	et	4	main
eesti	doc_536541856885_item	3620324	et	4	main
tähelepanu	doc_536541856885_item	3620321	et	4	main
lauluga	doc_536541856885_item	3620320	et	4	main
sõjaga	doc_536541856885_item	3620318	et	3	main
tunnustamise	doc_536541856885_item	3620314	et	4	main
kogedes	doc_536541856885_item	3620306	et	4	main
rahvavaimu	doc_536541856885_item	3620295	et	4	main
oma	doc_536541856885_item	3620286	et	4	main
eesti	doc_536541856885_item	3620283	et	4	main
arutlev	doc_536541856885_item	3620254	et	4	main
sõna	doc_536541856885_item	3620250	et	4	main
350	doc_536541856885_item	3620249	et	2	main
300	doc_536541856885_item	3620248	et	2	main
eestlastest	doc_536541856885_item	3620244	et	4	main
teeb	doc_536541856885_item	3620243	et	3	main
essee	doc_536541856885_item	3620240	et	4	main
kirjutage	doc_536541856885_item	3620239	et	3	main
laul	doc_536541856885_item	3620432	et	4	main
väike	doc_536541856885_item	3620422	et	4	main
et	doc_536541856885_item	3620420	et	3	main
kõikide	doc_536541856885_item	3620413	et	4	main
laulurahvas	doc_536541856885_item	3620412	et	4	main
lauluidee	doc_536541856885_item	3620394	et	4	main
jannsen	doc_536541856885_item	3620389	et	4	main
lydia	doc_536541856885_item	3620385	et	4	main
sellele	doc_536541856885_item	3620366	et	4	main
kujundamises	doc_536541856885_item	3620364	et	4	main
olles	doc_536541856886_item	3620703	et	3	main
laulsid	doc_536541856886_item	3620699	et	4	main
hällilaule	doc_536541856886_item	3620698	et	4	main
tehed	doc_536541856886_item	3620694	et	4	main
käsitööd	doc_536541856886_item	3620693	et	4	main
vanasti	doc_536541856886_item	3620687	et	3	main
aasta	doc_536541856886_item	3620663	et	4	main
1994	doc_536541856886_item	3620662	et	2	main
tallinnasse	doc_536541856886_item	3620661	et	3	main
arv	doc_536541856886_item	3620648	et	3	main
jannsen	doc_536541856886_item	3620645	et	4	main
autor	doc_536541856886_item	3620638	et	3	main
idee	doc_536541856886_item	3620637	et	4	main
ühisrahvas	doc_536541856886_item	3620607	et	4	main
et	doc_536541856886_item	3620604	et	3	main
ja	doc_536541856886_item	3620593	et	3	main
rahvas	doc_536541856886_item	3620589	et	4	main
eesti	doc_536541856886_item	3620588	et	4	main
tahtis	doc_536541856886_item	3620587	et	3	main
saatel	doc_536541856886_item	3620578	et	4	main
õõtsutamise	doc_536541856886_item	3620568	et	4	main
riimilised	doc_536541856886_item	3620546	et	4	main
põlve	doc_536541856886_item	3620537	et	4	main
lauldi	doc_536541856886_item	3620529	et	3	main
tööd	doc_536541856886_item	3620519	et	4	main
laule	doc_536541856886_item	3620518	et	4	main
eestlased	doc_536541856886_item	3620517	et	3	main
et	doc_536541856884_item	3620034	et	3	main
arvan	doc_536541856884_item	3620033	et	3	main
laulda	doc_536541856884_item	3620032	et	4	main
või	doc_536541856884_item	3620029	et	4	main
ja	doc_536541856884_item	3620027	et	3	main
teeb	doc_536541856884_item	3620021	et	3	main
lootused	doc_536541856884_item	3620015	et	4	main
ja	doc_536541856884_item	3620014	et	3	main
südmusi	doc_536541856884_item	3620013	et	4	main
mineviku	doc_536541856884_item	3620012	et	3	main
rõõmusi	doc_536541856884_item	3620011	et	3	main
ja	doc_536541856884_item	3620010	et	3	main
emotsionaalne	doc_536541856884_item	3619999	et	3	main
sest	doc_536541856884_item	3619995	et	4	main
rahvadele	doc_536541856884_item	3619982	et	4	main
laulurahva	doc_536541856885_item	3620463	et	3	main
teevadki	doc_536541856885_item	3620461	et	3	main
just	doc_536541856885_item	3620457	et	3	main
rahvast	doc_536541856885_item	3620449	et	4	main
eesti	doc_536541856885_item	3620448	et	4	main
suutnud	doc_536541856885_item	3620442	et	4	main
kui	doc_536541856885_item	3620436	et	3	main
noored	doc_536541856885_item	3620328	et	3	main
ülendavat	doc_536541856885_item	3620307	et	4	main
taastamise	doc_536541856885_item	3620296	et	4	main
just	doc_536541856885_item	3620288	et	3	main
tegemiste	doc_536541856885_item	3620281	et	4	main
erinevate	doc_536541856885_item	3620280	et	4	main
rahuolu	doc_536541856885_item	3620274	et	4	main
üldistav	doc_536541856885_item	3620257	et	4	main
analüüsiv	doc_536541856885_item	3620255	et	4	main
olema	doc_536541856885_item	3620253	et	4	main
essee	doc_536541856885_item	3620246	et	4	main
teemal	doc_536541856885_item	3620241	et	3	main
keele	doc_536541856885_item	3620236	et	4	main
eesti	doc_536541856885_item	3620232	et	4	main
olla	doc_536541856885_item	3620425	et	3	main
nii	doc_536541856885_item	3620421	et	3	main
on	doc_536541856885_item	3620418	et	4	main
laulutega	doc_536541856885_item	3620417	et	4	main
oli	doc_536541856885_item	3620403	et	3	main
tuginedes	doc_536541856885_item	3620400	et	3	main
traditsioonile	doc_536541856885_item	3620399	et	3	main
laulupidude	doc_536541856885_item	3620398	et	4	main
alguse	doc_536541856885_item	3620397	et	3	main
oma	doc_536541856885_item	3620391	et	4	main
j	doc_536541856885_item	3620387	et	4	main
koidula	doc_536541856885_item	3620386	et	4	main
praaktiliselt	doc_536541856885_item	3620374	et	4	main
on	doc_536541856885_item	3620373	et	4	main
regilaulud	doc_536541856885_item	3620372	et	3	main
ehk	doc_536541856885_item	3620371	et	3	main
eesti	doc_536541856885_item	3620369	et	4	main
vaatamata	doc_536541856885_item	3620365	et	4	main
lastele	doc_536541856886_item	3620697	et	4	main
oma	doc_536541856886_item	3620696	et	4	main
tuttavaid	doc_536541856886_item	3620685	et	3	main
ja	doc_536541856886_item	3620684	et	3	main
suur	doc_536541856886_item	3620675	et	3	main
tallinnas	doc_536541856886_item	3620669	et	4	main
iga	doc_536541856886_item	3620650	et	4	main
laulupeost	doc_536541856886_item	3620646	et	4	main
voldemar	doc_536541856886_item	3620644	et	4	main
johann	doc_536541856886_item	3620643	et	4	main
on	doc_536541856886_item	3620639	et	4	main
laulutraditsiooni	doc_536541856884_item	3620028	et	4	main
muretseid	doc_536541856884_item	3620009	et	4	main
rahvuse	doc_536541856884_item	3620008	et	3	main
nii	doc_536541856884_item	3619998	et	3	main
see	doc_536541856884_item	3619996	et	3	main
osast	doc_536541856884_item	3619994	et	4	main
ajaloo	doc_536541856884_item	3619993	et	4	main
ja	doc_536541856884_item	3619992	et	3	main
eestlaste	doc_536541856884_item	3619985	et	4	main
ka	doc_536541856884_item	3619984	et	3	main
maailma	doc_536541856884_item	3619981	et	4	main
kõikidele	doc_536541856884_item	3619980	et	4	main
kultuurinähtus	doc_536541856884_item	3619979	et	4	main
näidetega	doc_536541856884_item	3619974	et	3	main
illustreerida	doc_536541856884_item	3619973	et	3	main
soovitatav	doc_536541856884_item	3619972	et	4	main
on	doc_536541856884_item	3619971	et	4	main
väiteid	doc_536541856884_item	3619970	et	4	main
faktidele	doc_536541856884_item	3619969	et	3	main
esitatud	doc_536541856884_item	3619968	et	4	main
lugemistekstis	doc_536541856884_item	3619967	et	3	main
ja	doc_536541856884_item	3619966	et	3	main
loengus	doc_536541856884_item	3619965	et	3	main
tuginema	doc_536541856884_item	3619964	et	3	main
üldistav	doc_536541856884_item	3619963	et	4	main
ja	doc_536541856884_item	3619962	et	3	main
analüüsiv	doc_536541856884_item	3619961	et	4	main
arutlev	doc_536541856884_item	3619960	et	4	main
olema	doc_536541856884_item	3619959	et	4	main
peab	doc_536541856884_item	3619958	et	4	main
essee	doc_536541856884_item	3619957	et	4	main
sõna	doc_536541856884_item	3619956	et	4	main
350	doc_536541856884_item	3619955	et	2	main
300	doc_536541856884_item	3619954	et	2	main
pikkus	doc_536541856884_item	3619953	et	4	main
essee	doc_536541856884_item	3619952	et	4	main
laulurahva	doc_536541856884_item	3619951	et	3	main
eestlastest	doc_536541856884_item	3619950	et	4	main
teeb	doc_536541856884_item	3619949	et	3	main
mis	doc_536541856884_item	3619948	et	4	main
teemal	doc_536541856884_item	3619947	et	3	main
essee	doc_536541856884_item	3619946	et	4	main
kirjutage	doc_536541856884_item	3619945	et	3	main
kirjutamine	doc_536541856884_item	3619944	et	4	main
kui	doc_536541856884_item	3619940	et	3	main
eestlastest	doc_536541856885_item	3620462	et	4	main
ajalugu	doc_536541856885_item	3620460	et	4	main
traditsioonid	doc_536541856885_item	3620459	et	3	main
laulupeod	doc_536541856885_item	3620458	et	4	main
rahvustest	doc_536541856885_item	3620456	et	4	main
selle	doc_536541856885_item	3620444	et	4	main
parandada	doc_536541856885_item	3620443	et	3	main
praegu	doc_536541856885_item	3620437	et	3	main
nii	doc_536541856885_item	3620434	et	3	main
kui	doc_536541856885_item	3620327	et	3	main
laulav	doc_536541856885_item	3620325	et	4	main
on	doc_536541856885_item	3620323	et	4	main
väärt	doc_536541856885_item	3620322	et	4	main
vaid	doc_536541856885_item	3620319	et	3	main
mitte	doc_536541856885_item	3620317	et	3	main
laulda	doc_536541856885_item	3620303	et	4	main
et	doc_536541856885_item	3620302	et	3	main
kokku	doc_536541856885_item	3620301	et	3	main
senini	doc_536541856885_item	3620294	et	3	main
leidis	doc_536541856885_item	3620285	et	4	main
hoidmiseks	doc_536541856885_item	3620278	et	4	main
identiteeditunne	doc_536541856885_item	3620277	et	3	main
ning	doc_536541856885_item	3620276	et	3	main
raske	doc_536541856885_item	3620272	et	4	main
oma	doc_536541856885_item	3620271	et	4	main
rahvused	doc_536541856885_item	3620270	et	3	main
kõik	doc_536541856885_item	3620269	et	4	main
näidetega	doc_536541856885_item	3620268	et	3	main
illustreerida	doc_536541856885_item	3620267	et	3	main
soovitatav	doc_536541856885_item	3620266	et	4	main
on	doc_536541856885_item	3620265	et	4	main
väiteid	doc_536541856885_item	3620264	et	4	main
faktidele	doc_536541856885_item	3620263	et	3	main
esitatud	doc_536541856885_item	3620262	et	4	main
lugemistekstis	doc_536541856885_item	3620261	et	3	main
ja	doc_536541856885_item	3620260	et	3	main
loengus	doc_536541856885_item	3620259	et	3	main
peab	doc_536541856885_item	3620252	et	4	main
laulurahva	doc_536541856885_item	3620245	et	3	main
mis	doc_536541856885_item	3620242	et	4	main
test	doc_536541856885_item	3620237	et	3	main
teise	doc_536541856885_item	3620235	et	4	main
saatab	doc_536541856885_item	3620431	et	4	main
hauani	doc_536541856885_item	3620430	et	3	main
hällist	doc_536541856885_item	3620429	et	4	main
vaimuga	doc_536541856885_item	3620428	et	3	main
tugev	doc_536541856885_item	3620427	et	4	main
nii	doc_536541856885_item	3620426	et	3	main
kirjutamine	doc_536541856885_item	3620238	et	4	main
kui	doc_536541856885_item	3620234	et	3	main
keele	doc_536541856885_item	3620233	et	4	main
raskustega	doc_536541856885_item	3620414	et	4	main
ülaltoodud	doc_536541856885_item	3620404	et	3	main
panid	doc_536541856885_item	3620396	et	4	main
nad	doc_536541856885_item	3620395	et	3	main
kogu	doc_536541856885_item	3620390	et	4	main
nüüdisaja	doc_536541856885_item	3620378	et	3	main
need	doc_536541856885_item	3620377	et	3	main
just	doc_536541856885_item	3620376	et	3	main
kadunud	doc_536541856885_item	3620375	et	4	main
et	doc_536541856885_item	3620367	et	3	main
kultuuri	doc_536541856885_item	3620363	et	4	main
eesti	doc_536541856885_item	3620362	et	4	main
rolli	doc_536541856885_item	3620361	et	4	main
suurt	doc_536541856885_item	3620360	et	3	main
mängisid	doc_536541856885_item	3620359	et	4	main
laulud	doc_536541856885_item	3620358	et	3	main
uuemad	doc_536541856885_item	3620357	et	4	main
ning	doc_536541856885_item	3620356	et	3	main
folkloor	doc_536541856885_item	3620355	et	4	main
lauluharrastusega	doc_536541856885_item	3620354	et	3	main
seotud	doc_536541856885_item	3620353	et	4	main
tihedalt	doc_536541856885_item	3620352	et	4	main
ka	doc_536541856885_item	3620351	et	3	main
oli	doc_536541856885_item	3620350	et	3	main
ärkamine	doc_536541856885_item	3620349	et	4	main
rahvuslik	doc_536541856885_item	3620348	et	3	main
esimene	doc_536541856885_item	3620347	et	3	main
eesti	doc_536541856885_item	3620346	et	4	main
ning	doc_536541856885_item	3620345	et	3	main
olla	doc_536541856885_item	3620344	et	3	main
koos	doc_536541856885_item	3620343	et	4	main
lihtsalt	doc_536541856885_item	3620342	et	4	main
et	doc_536541856885_item	3620341	et	3	main
keeles	doc_536541856885_item	3620340	et	4	main
oma	doc_536541856885_item	3620339	et	4	main
teineteisega	doc_536541856885_item	3620338	et	3	main
suhelda	doc_536541856885_item	3620337	et	4	main
et	doc_536541856885_item	3620336	et	3	main
rahvalaulu	doc_536541856885_item	3620335	et	4	main
oma	doc_536541856885_item	3620334	et	4	main
et	doc_536541856885_item	3620332	et	3	main
laulda	doc_536541856885_item	3620333	et	4	main
kogusid	doc_536541856885_item	3620331	et	4	main
vanad	doc_536541856885_item	3620330	et	3	main
ja	doc_536541856885_item	3620329	et	3	main
lihtsalt	doc_536541856886_item	3620701	et	4	main
rahvas	doc_536541856885_item	3620423	et	4	main
võitlevad	doc_536541856885_item	3620416	et	4	main
nad	doc_536541856885_item	3620415	et	3	main
mis	doc_536541856885_item	3620402	et	4	main
kõikili	doc_536541856885_item	3620401	et	4	main
v	doc_536541856885_item	3620388	et	4	main
nagu	doc_536541856885_item	3620384	et	3	main
valgustustuaja	doc_536541856885_item	3620382	et	4	main
rahvalaulud	doc_536541856885_item	3620370	et	3	main
ma	doc_536541856885_item	3620405	et	3	main
teostasid	doc_536541856885_item	3620393	et	4	main
elu	doc_536541856885_item	3620392	et	4	main
inimesed	doc_536541856885_item	3620383	et	3	main
eesti	doc_536541856885_item	3620381	et	4	main
baas	doc_536541856885_item	3620380	et	3	main
kultuuri	doc_536541856885_item	3620379	et	4	main
praegu	doc_536541856885_item	3620368	et	3	main
koos	doc_536541856886_item	3620702	et	4	main
laulsid	doc_536541856886_item	3620688	et	4	main
sõpru	doc_536541856886_item	3620683	et	3	main
koos	doc_536541856886_item	3620679	et	4	main
tullakse	doc_536541856886_item	3620678	et	3	main
peost	doc_536541856886_item	3620660	et	4	main
kuuendast	doc_536541856886_item	3620659	et	3	main
alates	doc_536541856886_item	3620658	et	3	main
kandus	doc_536541856886_item	3620657	et	3	main
traditsioon	doc_536541856886_item	3620656	et	3	main
osavõtjate	doc_536541856886_item	3620647	et	3	main
vanemuise	doc_536541856886_item	3620640	et	4	main
aastal	doc_536541856886_item	3620634	et	3	main
tekkisid	doc_536541856886_item	3620596	et	4	main
seetõttu	doc_536541856886_item	3620595	et	3	main
või	doc_536541856886_item	3620569	et	4	main
siis	doc_536541856886_item	3620555	et	3	main
hakkasid	doc_536541856886_item	3620543	et	4	main
seejärel	doc_536541856886_item	3620542	et	3	main
olnud	doc_536541856886_item	3620541	et	4	main
suuliselt	doc_536541856886_item	3620535	et	4	main
ainult	doc_536541856886_item	3620534	et	4	main
nad	doc_536541856886_item	3620532	et	3	main
regilauludeks	doc_536541856886_item	3620531	et	3	main
ajal	doc_536541856886_item	3620528	et	4	main
tol	doc_536541856886_item	3620527	et	3	main
mida	doc_536541856886_item	3620526	et	4	main
muistsel	doc_536541856886_item	3620514	et	3	main
eesti	doc_536541856886_item	3620507	et	4	main
laulurahva	doc_536541856886_item	3620506	et	3	main
teeb	doc_536541856886_item	3620504	et	3	main
faktidele	doc_536541856886_item	3620497	et	3	main
peab	doc_536541856886_item	3620486	et	4	main
neist	doc_536541856886_item	3620774	et	4	main
festivale	doc_536541856886_item	3620771	et	3	main
palju	doc_536541856886_item	3620769	et	4	main
ka	doc_536541856886_item	3620768	et	3	main
toimub	doc_536541856886_item	3620767	et	3	main
tänapäeval	doc_536541856886_item	3620766	et	3	main
esituses	doc_536541856886_item	3620765	et	4	main
kooride	doc_536541856886_item	3620764	et	3	main
noorte	doc_536541856886_item	3620763	et	3	main
eestlased	doc_536541856886_item	3620755	et	3	main
näha	doc_536541856886_item	3620751	et	3	main
eesti	doc_536541856886_item	3620748	et	4	main
mõned	doc_536541856886_item	3620745	et	3	main
ka	doc_536541856886_item	3620744	et	3	main
säilinud	doc_536541856886_item	3620743	et	4	main
alati	doc_536541856892_item	3621064	et	4	main
sest	doc_536541856892_item	3621061	et	4	main
on	doc_536541856892_item	3621056	et	4	main
ürituses	doc_536541856892_item	3621051	et	4	main
kui	doc_536541856892_item	3621044	et	3	main
on	doc_536541856892_item	3621034	et	4	main
ning	doc_536541856892_item	3621028	et	3	main
unusta	doc_536541856892_item	3621016	et	4	main
et	doc_536541856892_item	3621013	et	3	main
laulurahvas	doc_536541856892_item	3621008	et	4	main
laulmisega	doc_536541856886_item	3620801	et	4	main
tegutsevad	doc_536541856886_item	3620800	et	4	main
nad	doc_536541856886_item	3620799	et	3	main
tänapäevani	doc_536541856886_item	3620798	et	3	main
aegadest	doc_536541856886_item	3620797	et	3	main
muistatest	doc_536541856886_item	3620796	et	4	main
alates	doc_536541856886_item	3620795	et	3	main
kuna	doc_536541856886_item	3620794	et	3	main
laulurahvaks	doc_536541856886_item	3620793	et	3	main
nimetada	doc_536541856886_item	3620792	et	3	main
võib	doc_536541856886_item	3620791	et	3	main
eestlasi	doc_536541856886_item	3620790	et	3	main
et	doc_536541856886_item	3620789	et	3	main
öelda	doc_536541856886_item	3620788	et	4	main
laulsid	doc_536541856886_item	3620692	et	4	main
nad	doc_536541856886_item	3620691	et	3	main
naised	doc_536541856886_item	3620690	et	3	main
peamiselt	doc_536541856886_item	3620689	et	4	main
seal	doc_536541856886_item	3620682	et	4	main
perega	doc_536541856886_item	3620680	et	3	main
sinna	doc_536541856886_item	3620677	et	3	main
ka	doc_536541856886_item	3620674	et	3	main
linnas	doc_536541856886_item	3620668	et	4	main
lauljad	doc_536541856886_item	3620666	et	4	main
kogunesid	doc_536541856886_item	3620665	et	4	main
juulis	doc_536541856886_item	3620664	et	3	main
aastaga	doc_536541856886_item	3620651	et	3	main
kasvas	doc_536541856886_item	3620649	et	3	main
seltsi	doc_536541856886_item	3620641	et	4	main
selle	doc_536541856886_item	3620635	et	4	main
1869	doc_536541856886_item	3620633	et	2	main
tartus	doc_536541856886_item	3620632	et	3	main
toimus	doc_536541856886_item	3620631	et	3	main
laulupidu	doc_536541856886_item	3620630	et	4	main
ülemaaline	doc_536541856886_item	3620629	et	4	main
esimene	doc_536541856886_item	3620628	et	3	main
traditsioon	doc_536541856886_item	3620627	et	3	main
laulupidude	doc_536541856886_item	3620626	et	4	main
alguse	doc_536541856886_item	3620625	et	3	main
sai	doc_536541856886_item	3620624	et	4	main
millest	doc_536541856886_item	3620623	et	3	main
laulupidu	doc_536541856886_item	3620622	et	4	main
esimene	doc_536541856886_item	3620621	et	3	main
toimus	doc_536541856886_item	3620620	et	3	main
ajal	doc_536541856886_item	3620619	et	4	main
ärkamise	doc_536541856886_item	3620618	et	4	main
rahvusliku	doc_536541856886_item	3620617	et	3	main
rahvast	doc_536541856886_item	3620616	et	4	main
eesti	doc_536541856886_item	3620615	et	4	main
ühines	doc_536541856886_item	3620614	et	3	main
lausa	doc_536541856886_item	3620613	et	4	main
mis	doc_536541856886_item	3620612	et	4	main
rahvuslik	doc_536541856886_item	3620610	et	3	main
algas	doc_536541856886_item	3620609	et	3	main
ärkamine	doc_536541856886_item	3620611	et	4	main
ühinenuna	doc_536541856886_item	3620594	et	4	main
end	doc_536541856886_item	3620591	et	4	main
peamiselt	doc_536541856886_item	3620583	et	4	main
esitati	doc_536541856886_item	3620582	et	4	main
aga	doc_536541856886_item	3620581	et	3	main
laule	doc_536541856886_item	3620580	et	4	main
uusi	doc_536541856886_item	3620579	et	3	main
ka	doc_536541856886_item	3620575	et	3	main
keha	doc_536541856886_item	3620567	et	4	main
rahvalaule	doc_536541856886_item	3620560	et	4	main
kirjutatud	doc_536541856886_item	3620558	et	4	main
ümber	doc_536541856886_item	3620557	et	3	main
või	doc_536541856886_item	3620554	et	4	main
levima	doc_536541856886_item	3620545	et	3	main
eestis	doc_536541856886_item	3620544	et	3	main
põlvest	doc_536541856886_item	3620536	et	4	main
lihtsalt	doc_536541856886_item	3620522	et	4	main
ka	doc_536541856886_item	3620700	et	3	main
laulsid	doc_536541856886_item	3620695	et	4	main
kohata	doc_536541856886_item	3620686	et	4	main
lootuses	doc_536541856886_item	3620681	et	4	main
rahvapidu	doc_536541856886_item	3620676	et	4	main
on	doc_536541856886_item	3620673	et	4	main
laulupidu	doc_536541856886_item	3620672	et	4	main
tartus	doc_536541856886_item	3620671	et	3	main
ja	doc_536541856886_item	3620670	et	3	main
kahes	doc_536541856886_item	3620667	et	4	main
saanud	doc_536541856886_item	3620655	et	4	main
alguse	doc_536541856886_item	3620654	et	3	main
tartust	doc_536541856886_item	3620653	et	3	main
ja	doc_536541856886_item	3620652	et	3	main
liige	doc_536541856886_item	3620642	et	4	main
korralduse	doc_536541856886_item	3620636	et	4	main
siis	doc_536541856886_item	3620608	et	3	main
on	doc_536541856886_item	3620606	et	4	main
nad	doc_536541856886_item	3620605	et	3	main
eestlased	doc_536541856886_item	3620603	et	3	main
näitasid	doc_536541856886_item	3620602	et	4	main
nõnda	doc_536541856886_item	3620601	et	3	main
tantsuseltsid	doc_536541856886_item	3620600	et	3	main
ja	doc_536541856886_item	3620599	et	3	main
laulu-	doc_536541856886_item	3620598	et	4	main
igasugused	doc_536541856886_item	3620597	et	3	main
ajal	doc_536541856886_item	3620586	et	4	main
nõukogude	doc_536541856886_item	3620585	et	3	main
muusikaga	doc_536541856886_item	3620584	et	3	main
liikumiste	doc_536541856886_item	3620577	et	4	main
esitatud	doc_536541856886_item	3620574	et	4	main
rütmi	doc_536541856886_item	3620566	et	4	main
rõhutades	doc_536541856886_item	3620565	et	3	main
muusikata	doc_536541856886_item	3620564	et	3	main
vanemaid	doc_536541856886_item	3620559	et	4	main
käsitsi	doc_536541856886_item	3620556	et	3	main
trükitud	doc_536541856886_item	3620553	et	4	main
olid	doc_536541856886_item	3620552	et	4	main
salmikud	doc_536541856886_item	3620551	et	3	main
ja	doc_536541856886_item	3620550	et	3	main
ei	doc_536541856886_item	3620540	et	4	main
tekste	doc_536541856886_item	3620539	et	3	main
laule	doc_536541856886_item	3620525	et	4	main
olles	doc_536541856886_item	3620524	et	3	main
omaette	doc_536541856886_item	3620523	et	3	main
vaba	doc_536541856886_item	3620592	et	4	main
tunda	doc_536541856886_item	3620590	et	3	main
tantsuliste	doc_536541856886_item	3620576	et	4	main
on	doc_536541856886_item	3620573	et	4	main
laule	doc_536541856886_item	3620572	et	4	main
mõningaid	doc_536541856886_item	3620571	et	3	main
jalapõrutusega	doc_536541856886_item	3620570	et	3	main
ilma	doc_536541856886_item	3620563	et	4	main
ka	doc_536541856886_item	3620562	et	3	main
lauldi	doc_536541856886_item	3620561	et	3	main
laulmikud	doc_536541856886_item	3620549	et	4	main
mille	doc_536541856886_item	3620548	et	3	main
rahvalaulud	doc_536541856886_item	3620547	et	3	main
kirjalikke	doc_536541856886_item	3620538	et	3	main
levisid	doc_536541856886_item	3620533	et	4	main
nimetatakse	doc_536541856886_item	3620530	et	3	main
või	doc_536541856886_item	3620521	et	4	main
tehes	doc_536541856886_item	3620520	et	3	main
nimetada	doc_536541856886_item	3620511	et	3	main
julgelt	doc_536541856886_item	3620510	et	4	main
võib	doc_536541856886_item	3620509	et	3	main
rahvast	doc_536541856886_item	3620508	et	4	main
on	doc_536541856886_item	3620499	et	4	main
lugemistekstis	doc_536541856886_item	3620495	et	3	main
loengus	doc_536541856886_item	3620493	et	3	main
üldistav	doc_536541856886_item	3620491	et	4	main
olema	doc_536541856886_item	3620487	et	4	main
essee	doc_536541856886_item	3620480	et	4	main
laulurahva	doc_536541856886_item	3620479	et	3	main
folk	doc_536541856886_item	3620777	et	4	main
tuntum	doc_536541856886_item	3620773	et	4	main
mida	doc_536541856886_item	3620760	et	4	main
on	doc_536541856886_item	3620742	et	4	main
ja	doc_536541856892_item	3621066	et	3	main
eestlaste	doc_536541856892_item	3621059	et	4	main
üritustel	doc_536541856892_item	3621046	et	4	main
ka	doc_536541856892_item	3621045	et	3	main
nii	doc_536541856892_item	3621035	et	3	main
aga	doc_536541856892_item	3621020	et	3	main
oma	doc_536541856892_item	3621017	et	4	main
tahenda	doc_536541856892_item	3621010	et	4	main
vanu	doc_536541856892_item	3621003	et	4	main
vanu	doc_536541856892_item	3620994	et	4	main
tänapäeval	doc_536541856892_item	3620993	et	3	main
ka	doc_536541856892_item	3620992	et	3	main
ümber	doc_536541856892_item	3620991	et	3	main
töölesid	doc_536541856892_item	3620990	et	4	main
tänu	doc_536541856892_item	3620964	et	4	main
laule	doc_536541856892_item	3620961	et	4	main
arendama	doc_536541856892_item	3620959	et	3	main
tasapisi	doc_536541856892_item	3620957	et	3	main
kui	doc_536541856892_item	3620955	et	3	main
edaspidi	doc_536541856892_item	3620951	et	3	main
mis	doc_536541856892_item	3620950	et	4	main
bojan	doc_536541856892_item	3620949	et	4	main
nagu	doc_536541856892_item	3620948	et	3	main
see	doc_536541856892_item	3620932	et	3	main
eestirahva	doc_536541856892_item	3620930	et	3	main
ja	doc_536541856892_item	3620926	et	3	main
naabrid	doc_536541856892_item	3620923	et	3	main
aga	doc_536541856892_item	3620915	et	3	main
rõõmu	doc_536541856892_item	3620909	et	4	main
üle	doc_536541856892_item	3620906	et	3	main
see	doc_536541856892_item	3620903	et	3	main
kõik	doc_536541856892_item	3620894	et	4	main
mehed	doc_536541856892_item	3620893	et	3	main
ka	doc_536541856892_item	3620892	et	3	main
ilma	doc_536541856892_item	3620886	et	4	main
pidada	doc_536541856892_item	3620877	et	4	main
võiks	doc_536541856892_item	3620876	et	4	main
üksi	doc_536541856892_item	3620864	et	4	main
lauldi	doc_536541856892_item	3620863	et	3	main
ajal	doc_536541856892_item	3620862	et	4	main
vabalt	doc_536541856892_item	3620858	et	4	main
eestlasi	doc_536541856892_item	3620856	et	3	main
eestis	doc_536541856892_item	3620855	et	3	main
ka	doc_536541856892_item	3620854	et	3	main
ja	doc_536541856892_item	3620851	et	3	main
lauldakse	doc_536541856892_item	3620850	et	3	main
laulsid	doc_536541856886_item	3620516	et	4	main
juba	doc_536541856886_item	3620513	et	3	main
soovitatav	doc_536541856886_item	3620500	et	4	main
esitatud	doc_536541856886_item	3620496	et	4	main
ja	doc_536541856886_item	3620494	et	3	main
tuginema	doc_536541856886_item	3620492	et	3	main
ja	doc_536541856886_item	3620490	et	3	main
analüüsiv	doc_536541856886_item	3620489	et	4	main
essee	doc_536541856886_item	3620485	et	4	main
eestlastest	doc_536541856886_item	3620478	et	4	main
laulsid	doc_536541856886_item	3620762	et	4	main
nad	doc_536541856886_item	3620761	et	3	main
muistsed	doc_536541856886_item	3620754	et	3	main
kuidas	doc_536541856886_item	3620752	et	3	main
võib	doc_536541856886_item	3620750	et	3	main
palju	doc_536541856886_item	3620741	et	4	main
osalenud	doc_536541856892_item	3621065	et	4	main
tähtis	doc_536541856892_item	3621058	et	4	main
lauluvõistlus	doc_536541856892_item	3621055	et	3	main
eurovisioon	doc_536541856892_item	3621053	et	3	main
kontserditel	doc_536541856892_item	3621043	et	4	main
baarides	doc_536541856892_item	3621042	et	3	main
pool	doc_536541856892_item	3621041	et	4	main
lauljaid	doc_536541856892_item	3621037	et	4	main
tänapäeval	doc_536541856892_item	3621033	et	3	main
ei	doc_536541856892_item	3621015	et	4	main
eestlased	doc_536541856892_item	3621014	et	3	main
seda	doc_536541856892_item	3621012	et	3	main
kasutades	doc_536541856892_item	3621006	et	3	main
aga	doc_536541856892_item	3621005	et	3	main
näiteks	doc_536541856892_item	3620997	et	4	main
töödeldakse	doc_536541856892_item	3620996	et	3	main
rahvalaule	doc_536541856892_item	3620995	et	4	main
sellele	doc_536541856892_item	3620965	et	4	main
hakkati	doc_536541856892_item	3620960	et	3	main
eesti	doc_536541856892_item	3620956	et	4	main
loomingut	doc_536541856892_item	3620953	et	3	main
selline	doc_536541856892_item	3620946	et	4	main
tuli	doc_536541856892_item	3620945	et	4	main
venemaalt	doc_536541856892_item	3620944	et	3	main
et	doc_536541856892_item	3620943	et	3	main
osalesid	doc_536541856892_item	3620929	et	4	main
jäävad	doc_536541856892_item	3620918	et	4	main
ikks	doc_536541856892_item	3620917	et	4	main
mööduvad	doc_536541856892_item	3620914	et	4	main
aastad	doc_536541856892_item	3620913	et	3	main
mure	doc_536541856892_item	3620912	et	4	main
ka	doc_536541856892_item	3620911	et	3	main
kõik	doc_536541856892_item	3620897	et	4	main
ning	doc_536541856892_item	3620896	et	3	main
nii	doc_536541856892_item	3620889	et	3	main
eeslaulja	doc_536541856892_item	3620884	et	4	main
või	doc_536541856892_item	3620870	et	4	main
laulurahvaks	doc_536541856892_item	3620860	et	3	main
kaasarvatud	doc_536541856892_item	3620853	et	4	main
tantsitakse	doc_536541856892_item	3620852	et	3	main
jooksul	doc_536541856892_item	3620846	et	4	main
laulurahva	doc_536541856892_item	3620844	et	3	main
teeb	doc_536541856892_item	3620842	et	3	main
essee	doc_536541856892_item	3620803	et	4	main
pärast	doc_536541856892_item	3621123	et	4	main
unusta	doc_536541856892_item	3621114	et	4	main
tantsu	doc_536541856892_item	3621106	et	4	main
nautida	doc_536541856892_item	3621103	et	3	main
kuhu	doc_536541856892_item	3621098	et	3	main
ka	doc_536541856892_item	3621073	et	3	main
esimese	doc_536541856892_item	3621069	et	3	main
isegi	doc_536541856892_item	3621067	et	4	main
ajal	doc_536541856886_item	3620515	et	4	main
laulurahvaks	doc_536541856886_item	3620512	et	3	main
väiteid	doc_536541856886_item	3620498	et	4	main
sõna	doc_536541856886_item	3620484	et	4	main
350	doc_536541856886_item	3620483	et	2	main
300	doc_536541856886_item	3620482	et	2	main
pikkus	doc_536541856886_item	3620481	et	4	main
essee	doc_536541856886_item	3620474	et	4	main
laule	doc_536541856886_item	3620759	et	4	main
elasid	doc_536541856886_item	3620753	et	4	main
vabaõhumuuseumis	doc_536541856886_item	3620749	et	3	main
lindistused	doc_536541856886_item	3620747	et	4	main
vanad	doc_536541856886_item	3620746	et	3	main
on	doc_536541856892_item	3621063	et	4	main
väga	doc_536541856892_item	3621057	et	3	main
palju	doc_536541856892_item	3621036	et	4	main
huvi	doc_536541856892_item	3621032	et	4	main
selle	doc_536541856892_item	3621030	et	4	main
tantsivad	doc_536541856892_item	3621027	et	4	main
laulavad	doc_536541856892_item	3621026	et	4	main
eestlased	doc_536541856892_item	3621025	et	3	main
tänapäevani	doc_536541856892_item	3621024	et	3	main
et	doc_536541856892_item	3621023	et	3	main
seda	doc_536541856892_item	3621022	et	3	main
tähendab	doc_536541856892_item	3621021	et	3	main
vanu	doc_536541856892_item	3621018	et	4	main
ainult	doc_536541856892_item	3621011	et	4	main
rock-muusikat	doc_536541856892_item	3621007	et	3	main
laule	doc_536541856892_item	3621004	et	4	main
laulavad	doc_536541856892_item	3621002	et	4	main
kandist	doc_536541856892_item	3621001	et	3	main
setumaa	doc_536541856892_item	3621000	et	4	main
poistebänd	doc_536541856892_item	3620999	et	3	main
üks	doc_536541856892_item	3620998	et	3	main
laule	doc_536541856892_item	3620989	et	4	main
olemasolevat	doc_536541856892_item	3620988	et	3	main
siis	doc_536541856892_item	3620987	et	3	main
ja	doc_536541856892_item	3620963	et	3	main
hakkas	doc_536541856892_item	3620958	et	3	main
pilli	doc_536541856892_item	3620938	et	4	main
kasutada	doc_536541856892_item	3620937	et	3	main
hakkati	doc_536541856892_item	3620936	et	3	main
et	doc_536541856892_item	3620935	et	3	main
seda	doc_536541856892_item	3620934	et	3	main
tähendab	doc_536541856892_item	3620933	et	3	main
loomingus	doc_536541856892_item	3620931	et	3	main
venemaa	doc_536541856892_item	3620927	et	4	main
alati	doc_536541856892_item	3620898	et	4	main
naised	doc_536541856892_item	3620890	et	3	main
pillisaateta	doc_536541856892_item	3620887	et	3	main
koor	doc_536541856892_item	3620882	et	4	main
mida	doc_536541856892_item	3620879	et	4	main
regilaulu	doc_536541856892_item	3620878	et	4	main
olles	doc_536541856892_item	3620873	et	3	main
koos	doc_536541856892_item	3620872	et	4	main
kõik	doc_536541856892_item	3620871	et	4	main
eestlastest	doc_536541856886_item	3620505	et	4	main
mis	doc_536541856886_item	3620503	et	4	main
näidetega	doc_536541856886_item	3620502	et	3	main
illustreerida	doc_536541856886_item	3620501	et	3	main
arutlev	doc_536541856886_item	3620488	et	4	main
teeb	doc_536541856886_item	3620477	et	3	main
mis	doc_536541856886_item	3620476	et	4	main
teemal	doc_536541856886_item	3620475	et	3	main
kirjutage	doc_536541856886_item	3620473	et	3	main
kirjutamine	doc_536541856886_item	3620472	et	4	main
test	doc_536541856886_item	3620471	et	3	main
keele	doc_536541856886_item	3620470	et	4	main
teise	doc_536541856886_item	3620469	et	4	main
kui	doc_536541856886_item	3620468	et	3	main
keele	doc_536541856886_item	3620467	et	4	main
eesti	doc_536541856886_item	3620466	et	4	main
essee	doc_536541856886_item	3620465	et	4	main
kord	doc_536541856886_item	3620787	et	4	main
veel	doc_536541856886_item	3620786	et	4	main
tahaksin	doc_536541856886_item	3620785	et	3	main
lõpuks	doc_536541856886_item	3620784	et	4	main
keskel	doc_536541856886_item	3620783	et	3	main
juuli	doc_536541856886_item	3620782	et	4	main
aasta	doc_536541856886_item	3620781	et	4	main
iga	doc_536541856886_item	3620780	et	4	main
toimub	doc_536541856886_item	3620779	et	3	main
mis	doc_536541856886_item	3620778	et	4	main
viljandi	doc_536541856886_item	3620776	et	4	main
on	doc_536541856886_item	3620775	et	4	main
kõige	doc_536541856886_item	3620772	et	4	main
folklöör	doc_536541856886_item	3620770	et	4	main
kuulda	doc_536541856886_item	3620758	et	4	main
ka	doc_536541856886_item	3620757	et	3	main
ja	doc_536541856886_item	3620756	et	3	main
hästi	doc_536541856886_item	3620740	et	3	main
on	doc_536541856886_item	3620739	et	4	main
töötlusi	doc_536541856886_item	3620738	et	3	main
rahvalaulude	doc_536541856886_item	3620737	et	3	main
ka	doc_536541856886_item	3620736	et	3	main
stiili	doc_536541856886_item	3620735	et	4	main
rahvalaulude	doc_536541856886_item	3620734	et	3	main
kasutasid	doc_536541856886_item	3620733	et	4	main
heliloojad	doc_536541856886_item	3620732	et	3	main
paljud	doc_536541856886_item	3620731	et	3	main
vahel	doc_536541856886_item	3620730	et	4	main
sajandi	doc_536541856886_item	3620729	et	3	main
20nda	doc_536541856886_item	3620728	et	4	main
ja	doc_536541856886_item	3620727	et	3	main
19nda	doc_536541856886_item	3620726	et	4	main
populaarsed	doc_536541856886_item	3620725	et	3	main
väga	doc_536541856886_item	3620724	et	3	main
rahvalaulud	doc_536541856886_item	3620723	et	3	main
on	doc_536541856886_item	3620722	et	4	main
tänapäeval	doc_536541856886_item	3620721	et	3	main
ka	doc_536541856886_item	3620720	et	3	main
pulmadel	doc_536541856886_item	3620719	et	3	main
eelkõige	doc_536541856886_item	3620718	et	3	main
nad	doc_536541856886_item	3620717	et	3	main
laulsid	doc_536541856886_item	3620716	et	4	main
ja	doc_536541856886_item	3620715	et	3	main
saartel	doc_536541856886_item	3620714	et	3	main
populaarsed	doc_536541856886_item	3620713	et	3	main
väga	doc_536541856886_item	3620712	et	3	main
olid	doc_536541856886_item	3620711	et	4	main
koorid	doc_536541856886_item	3620710	et	4	main
meeste	doc_536541856886_item	3620709	et	4	main
mehed	doc_536541856886_item	3620708	et	3	main
ka	doc_536541856886_item	3620707	et	3	main
laulma	doc_536541856886_item	3620706	et	3	main
hakkasid	doc_536541856886_item	3620705	et	4	main
pärast	doc_536541856886_item	3620704	et	4	main
eesti	doc_536541856892_item	3621062	et	4	main
jaoks	doc_536541856892_item	3621060	et	4	main
see	doc_536541856892_item	3621054	et	3	main
näiteks	doc_536541856892_item	3621052	et	4	main
riigivahelistes	doc_536541856892_item	3621050	et	4	main
osalevad	doc_536541856892_item	3621049	et	4	main
ka	doc_536541856892_item	3621048	et	3	main
samuti	doc_536541856892_item	3621047	et	3	main
igal	doc_536541856892_item	3621040	et	3	main
esinevad	doc_536541856892_item	3621039	et	4	main
kes	doc_536541856892_item	3621038	et	4	main
vastu	doc_536541856892_item	3621031	et	3	main
tunnevad	doc_536541856892_item	3621029	et	3	main
rahvalaule	doc_536541856892_item	3621019	et	4	main
ei	doc_536541856892_item	3621009	et	4	main
või	doc_536541856892_item	3620986	et	4	main
vanarahvalauludega	doc_536541856892_item	3620985	et	3	main
sarnaneks	doc_536541856892_item	3620984	et	3	main
mis	doc_536541856892_item	3620983	et	4	main
stiili	doc_536541856892_item	3620982	et	4	main
leida	doc_536541856892_item	3620981	et	3	main
püüdsid	doc_536541856892_item	3620980	et	4	main
heliloojad	doc_536541856892_item	3620979	et	3	main
kultuur	doc_536541856892_item	3620978	et	3	main
eesti	doc_536541856892_item	3620977	et	4	main
arenes	doc_536541856892_item	3620976	et	3	main
sajandiga	doc_536541856892_item	3620975	et	3	main
iga	doc_536541856892_item	3620974	et	4	main
ning	doc_536541856892_item	3620973	et	3	main
möödusid	doc_536541856892_item	3620972	et	4	main
aastad	doc_536541856892_item	3620971	et	3	main
laule	doc_536541856892_item	3620970	et	4	main
vanu	doc_536541856892_item	3620969	et	4	main
nautida	doc_536541856892_item	3620968	et	3	main
saamegi	doc_536541856892_item	3620967	et	4	main
me	doc_536541856892_item	3620966	et	4	main
instrument	doc_536541856892_item	3620947	et	3	main
teada	doc_536541856892_item	3620942	et	3	main
osaliselt	doc_536541856892_item	3620928	et	4	main
rootsi	doc_536541856892_item	3620924	et	4	main
eesti	doc_536541856892_item	3620922	et	4	main
huvi	doc_536541856892_item	3620921	et	4	main
pakkuvad	doc_536541856892_item	3620920	et	4	main
ning	doc_536541856892_item	3620919	et	3	main
kui	doc_536541856892_item	3620910	et	3	main
elada	doc_536541856892_item	3620907	et	3	main
aitab	doc_536541856892_item	3620904	et	3	main
hetkel	doc_536541856892_item	3620902	et	4	main
igal	doc_536541856892_item	3620901	et	3	main
et	doc_536541856892_item	3620900	et	3	main
teadsid	doc_536541856892_item	3620899	et	4	main
kui	doc_536541856892_item	3620891	et	3	main
laulsid	doc_536541856892_item	3620888	et	4	main
abiga	doc_536541856892_item	3620885	et	3	main
ja	doc_536541856892_item	3620883	et	3	main
tavaliselt	doc_536541856892_item	3620880	et	4	main
rahvalauluks	doc_536541856892_item	3620875	et	4	main
esimeseks	doc_536541856892_item	3620874	et	3	main
või	doc_536541856892_item	3620866	et	4	main
pool	doc_536541856892_item	3620848	et	4	main
laulurahva	doc_536541856892_item	3621133	et	3	main
eestlastest	doc_536541856892_item	3621132	et	4	main
salvestama	doc_536541856892_item	3620962	et	3	main
hiljem	doc_536541856892_item	3620954	et	3	main
laiendas	doc_536541856892_item	3620952	et	3	main
on	doc_536541856892_item	3620941	et	4	main
näiteks	doc_536541856892_item	3620940	et	4	main
lauldes	doc_536541856892_item	3620939	et	3	main
soome	doc_536541856892_item	3620925	et	3	main
rahvalaulud	doc_536541856892_item	3620916	et	3	main
nii	doc_536541856892_item	3620908	et	3	main
neil	doc_536541856892_item	3620905	et	4	main
oskasid	doc_536541856892_item	3620895	et	4	main
lauldi	doc_536541856892_item	3620881	et	3	main
kiigutades	doc_536541856892_item	3620869	et	3	main
last	doc_536541856892_item	3620868	et	4	main
töötades	doc_536541856892_item	3620867	et	3	main
kutsuda	doc_536541856892_item	3620859	et	3	main
igal	doc_536541856892_item	3620847	et	3	main
aastate	doc_536541856892_item	3620845	et	3	main
eestlastest	doc_536541856892_item	3620843	et	4	main
eesti	doc_536541856892_item	3620804	et	4	main
on	doc_536541856892_item	3621117	et	4	main
laulud	doc_536541856892_item	3621116	et	3	main
laulsid	doc_536541856892_item	3621109	et	4	main
rahvalaule	doc_536541856892_item	3621104	et	4	main
kõik	doc_536541856892_item	3621100	et	4	main
laulupidu	doc_536541856892_item	3621097	et	4	main
kadriorus	doc_536541856892_item	3621096	et	3	main
lauluväljakul	doc_536541856892_item	3621095	et	3	main
toimub	doc_536541856892_item	3621094	et	3	main
tagant	doc_536541856892_item	3621093	et	3	main
aasta	doc_536541856892_item	3621092	et	4	main
nelja	doc_536541856892_item	3621091	et	4	main
iga	doc_536541856892_item	3621090	et	4	main
kujutab	doc_536541856892_item	3621089	et	3	main
endast	doc_536541856892_item	3621088	et	4	main
ta	doc_536541856892_item	3621087	et	4	main
mida	doc_536541856892_item	3621086	et	4	main
näidata	doc_536541856892_item	3621085	et	4	main
alati	doc_536541856892_item	3621083	et	4	main
rahvas	doc_536541856892_item	3621082	et	4	main
võiks	doc_536541856892_item	3621084	et	4	main
eesti	doc_536541856892_item	3621081	et	4	main
sellele	doc_536541856892_item	3621080	et	4	main
tänu	doc_536541856892_item	3621079	et	4	main
rahvalaulupidu	doc_536541856892_item	3621078	et	4	main
peo-	doc_536541856892_item	3621077	et	4	main
tähtsama	doc_536541856892_item	3621076	et	4	main
olles	doc_536541856892_item	3620865	et	3	main
vanal	doc_536541856892_item	3620861	et	3	main
võiks	doc_536541856892_item	3620857	et	4	main
mis	doc_536541856892_item	3620841	et	4	main
näidetega	doc_536541856892_item	3620840	et	3	main
illustreerida	doc_536541856892_item	3620839	et	3	main
soovitatav	doc_536541856892_item	3620838	et	4	main
on	doc_536541856892_item	3620837	et	4	main
väiteid	doc_536541856892_item	3620836	et	4	main
faktidele	doc_536541856892_item	3620835	et	3	main
esitatud	doc_536541856892_item	3620834	et	4	main
lugemistekstis	doc_536541856892_item	3620833	et	3	main
ja	doc_536541856892_item	3620832	et	3	main
loengus	doc_536541856892_item	3620831	et	3	main
tuginema	doc_536541856892_item	3620830	et	3	main
üldistav	doc_536541856892_item	3620829	et	4	main
ja	doc_536541856892_item	3620828	et	3	main
analüüsiv	doc_536541856892_item	3620827	et	4	main
arutlev	doc_536541856892_item	3620826	et	4	main
olema	doc_536541856892_item	3620825	et	4	main
peab	doc_536541856892_item	3620824	et	4	main
essee	doc_536541856892_item	3620823	et	4	main
sõna	doc_536541856892_item	3620822	et	4	main
350	doc_536541856892_item	3620821	et	2	main
300	doc_536541856892_item	3620820	et	2	main
pikkus	doc_536541856892_item	3620819	et	4	main
essee	doc_536541856892_item	3620818	et	4	main
laulurahva	doc_536541856892_item	3620817	et	3	main
eestlastest	doc_536541856892_item	3620816	et	4	main
teeb	doc_536541856892_item	3620815	et	3	main
mis	doc_536541856892_item	3620814	et	4	main
teemal	doc_536541856892_item	3620813	et	3	main
essee	doc_536541856892_item	3620812	et	4	main
kirjutage	doc_536541856892_item	3620811	et	3	main
kirjutamine	doc_536541856892_item	3620810	et	4	main
test	doc_536541856892_item	3620809	et	3	main
keele	doc_536541856892_item	3620808	et	4	main
maailmas	doc_536541856892_item	3620849	et	3	main
kui	doc_536541856892_item	3620806	et	3	main
keele	doc_536541856892_item	3620805	et	4	main
võib	doc_536541856892_item	3621124	et	3	main
ainult	doc_536541856892_item	3621121	et	4	main
ning	doc_536541856892_item	3621120	et	3	main
südames	doc_536541856892_item	3621119	et	3	main
eestlaste	doc_536541856892_item	3621118	et	4	main
ja	doc_536541856892_item	3621105	et	3	main
kõige	doc_536541856892_item	3621075	et	4	main
ei	doc_536541856892_item	3621071	et	4	main
kohta	doc_536541856894_item	3621439	et	4	main
eurovisiooni	doc_536541856894_item	3621430	et	4	main
korraldati	doc_536541856894_item	3621429	et	3	main
lapsi	doc_536541856894_item	3621422	et	4	main
õpetatakse	doc_536541856894_item	3621421	et	3	main
kus	doc_536541856894_item	3621420	et	3	main
on	doc_536541856894_item	3621410	et	4	main
kuulda	doc_536541856894_item	3621402	et	4	main
sest	doc_536541856894_item	3621381	et	4	main
tundma	doc_536541856894_item	3621378	et	3	main
kodanikud	doc_536541856894_item	3621375	et	3	main
kõik	doc_536541856894_item	3621373	et	4	main
peavad	doc_536541856894_item	3621371	et	4	main
laulu	doc_536541856894_item	3621370	et	4	main
on	doc_536541856894_item	3621354	et	4	main
isamaa	doc_536541856894_item	3621353	et	4	main
ja	doc_536541856894_item	3621347	et	3	main
laulupidu	doc_536541856894_item	3621334	et	4	main
ka	doc_536541856894_item	3621328	et	3	main
läti	doc_536541856894_item	3621292	et	4	main
jõuda	doc_536541856894_item	3621283	et	3	main
rohkem	doc_536541856894_item	3621275	et	4	main
jumalasse	doc_536541856894_item	3621235	et	4	main
uskus	doc_536541856894_item	3621234	et	3	main
põlvest	doc_536541856894_item	3621229	et	4	main
vana	doc_536541856894_item	3621225	et	4	main
laulutraditsiooni	doc_536541856894_item	3621218	et	4	main
vanemat	doc_536541856894_item	3621217	et	4	main
laulud	doc_536541856894_item	3621216	et	3	main
lapsi	doc_536541856894_item	3621203	et	4	main
elu	doc_536541856894_item	3621197	et	4	main
essee	doc_536541856894_item	3621150	et	4	main
laulurahva	doc_536541856894_item	3621149	et	3	main
keele	doc_536541856894_item	3621140	et	4	main
eesti	doc_536541856894_item	3621136	et	4	main
rasked	doc_536541856895_item	3621681	et	3	main
küll	doc_536541856895_item	3621679	et	4	main
olid	doc_536541856895_item	3621678	et	4	main
ka	doc_536541856895_item	3621677	et	3	main
vabadusega	doc_536541856895_item	3621667	et	4	main
oma	doc_536541856895_item	3621666	et	4	main
ka	doc_536541856895_item	3621665	et	3	main
oma	doc_536541856895_item	3621662	et	4	main
seob	doc_536541856895_item	3621661	et	3	main
ei	doc_536541856895_item	3621647	et	4	main
muusika	doc_536541856895_item	3621640	et	4	main
võtavad	doc_536541856895_item	3621634	et	3	main
kes	doc_536541856895_item	3621628	et	4	main
noori	doc_536541856895_item	3621627	et	3	main
vabaõhumuuseumis	doc_536541856895_item	3621626	et	3	main
laulud	doc_536541856895_item	3621619	et	3	main
muidugi	doc_536541856895_item	3621613	et	4	main
oskused	doc_536541856895_item	3621611	et	3	main
oma	doc_536541856895_item	3621610	et	4	main
teise	doc_536541856892_item	3620807	et	4	main
teeb	doc_536541856892_item	3621131	et	3	main
see	doc_536541856892_item	3621130	et	3	main
ainult	doc_536541856892_item	3621129	et	4	main
laulurahvana	doc_536541856892_item	3621128	et	3	main
eestlasi	doc_536541856892_item	3621127	et	3	main
nimetada	doc_536541856892_item	3621126	et	3	main
juba	doc_536541856892_item	3621125	et	3	main
selle	doc_536541856892_item	3621122	et	4	main
ei	doc_536541856892_item	3621113	et	4	main
kunagi	doc_536541856892_item	3621112	et	3	main
ning	doc_536541856892_item	3621111	et	3	main
laulavad	doc_536541856892_item	3621110	et	4	main
eestlased	doc_536541856892_item	3621101	et	3	main
tulevad	doc_536541856892_item	3621099	et	4	main
uhked	doc_536541856894_item	3621453	et	4	main
meil	doc_536541856894_item	3621444	et	4	main
korraldati	doc_536541856894_item	3621443	et	3	main
võistlus	doc_536541856894_item	3621442	et	3	main
see	doc_536541856894_item	3621441	et	3	main
ja	doc_536541856894_item	3621440	et	3	main
laulu	doc_536541856894_item	3621431	et	4	main
on	doc_536541856894_item	3621423	et	4	main
erinevad	doc_536541856894_item	3621418	et	4	main
festivaali	doc_536541856894_item	3621415	et	4	main
laulupidu	doc_536541856894_item	3621413	et	4	main
korraldatakse	doc_536541856894_item	3621412	et	3	main
elus	doc_536541856894_item	3621411	et	4	main
laule	doc_536541856894_item	3621403	et	4	main
ja	doc_536541856894_item	3621398	et	3	main
raadio	doc_536541856894_item	3621397	et	4	main
eestis	doc_536541856894_item	3621395	et	3	main
umbes	doc_536541856894_item	3621394	et	4	main
et	doc_536541856894_item	3621393	et	3	main
laul	doc_536541856894_item	3621383	et	4	main
teadma	doc_536541856894_item	3621372	et	3	main
on	doc_536541856894_item	3621364	et	4	main
laulmist	doc_536541856892_item	3621115	et	4	main
alati	doc_536541856892_item	3621108	et	4	main
eestlased	doc_536541856892_item	3621107	et	3	main
et	doc_536541856892_item	3621102	et	3	main
unustada	doc_536541856892_item	3621074	et	3	main
koha	doc_536541856892_item	3621070	et	4	main
võitnud	doc_536541856892_item	3621068	et	4	main
et	doc_536541856894_item	3621455	et	3	main
ja	doc_536541856894_item	3621451	et	3	main
seda	doc_536541856894_item	3621449	et	3	main
peame	doc_536541856894_item	3621448	et	4	main
me	doc_536541856894_item	3621447	et	4	main
et	doc_536541856894_item	3621446	et	3	main
arvan	doc_536541856894_item	3621445	et	3	main
näiteks	doc_536541856894_item	3621427	et	4	main
ansamblid	doc_536541856894_item	3621426	et	3	main
populaarsed	doc_536541856894_item	3621425	et	3	main
olemas	doc_536541856894_item	3621417	et	4	main
nad	doc_536541856894_item	3621409	et	3	main
surnud	doc_536541856894_item	3621408	et	4	main
võimalust	doc_536541856894_item	3621401	et	3	main
uhkust	doc_536541856894_item	3621389	et	4	main
tundma	doc_536541856894_item	3621388	et	3	main
aitab	doc_536541856894_item	3621387	et	3	main
ja	doc_536541856894_item	3621386	et	3	main
inimesi	doc_536541856894_item	3621385	et	4	main
ühendab	doc_536541856894_item	3621384	et	3	main
vastu	doc_536541856894_item	3621380	et	3	main
tänaseni	doc_536541856894_item	3621361	et	4	main
lidia	doc_536541856894_item	3621359	et	4	main
sõnade	doc_536541856894_item	3621358	et	3	main
ühendamist	doc_536541856894_item	3621348	et	4	main
aitas	doc_536541856894_item	3621344	et	3	main
esimene	doc_536541856894_item	3621333	et	3	main
toimus	doc_536541856894_item	3621332	et	3	main
1869	doc_536541856894_item	3621330	et	2	main
rahvariided	doc_536541856894_item	3621326	et	3	main
pulmalaulud	doc_536541856894_item	3621317	et	3	main
mõjusid	doc_536541856894_item	3621291	et	4	main
öelda	doc_536541856894_item	3621268	et	4	main
algas	doc_536541856894_item	3621261	et	3	main
ringis	doc_536541856894_item	3621259	et	4	main
õpetati	doc_536541856894_item	3621252	et	3	main
koos	doc_536541856894_item	3621250	et	4	main
olla	doc_536541856894_item	3621249	et	3	main
ja	doc_536541856894_item	3621248	et	3	main
ühendada	doc_536541856894_item	3621247	et	3	main
koorilaulu	doc_536541856894_item	3621243	et	4	main
kus	doc_536541856894_item	3621241	et	3	main
eesti	doc_536541856894_item	3621232	et	4	main
pärandati	doc_536541856894_item	3621228	et	4	main
iseloomustab	doc_536541856894_item	3621219	et	4	main
ka	doc_536541856894_item	3621210	et	3	main
tõsta	doc_536541856894_item	3621207	et	4	main
erinevad	doc_536541856894_item	3621201	et	4	main
tohi	doc_536541856892_item	3621072	et	4	main
rahvalaulud	doc_536541856894_item	3621456	et	3	main
mäletama	doc_536541856894_item	3621450	et	3	main
me	doc_536541856894_item	3621436	et	4	main
kord	doc_536541856894_item	3621435	et	4	main
üks	doc_536541856894_item	3621434	et	3	main
kus	doc_536541856894_item	3621433	et	3	main
võistluse	doc_536541856894_item	3621432	et	3	main
jäänud	doc_536541856894_item	3621424	et	4	main
on	doc_536541856894_item	3621416	et	4	main
suurt	doc_536541856894_item	3621400	et	3	main
ilmus	doc_536541856894_item	3621396	et	4	main
huvi	doc_536541856894_item	3621377	et	4	main
meie	doc_536541856894_item	3621374	et	4	main
meie	doc_536541856894_item	3621365	et	4	main
mu	doc_536541856894_item	3621352	et	3	main
isamaalaul	doc_536541856894_item	3621351	et	4	main
ilmus	doc_536541856894_item	3621350	et	4	main
tunda	doc_536541856894_item	3621345	et	3	main
eestist	doc_536541856894_item	3621341	et	3	main
aastal	doc_536541856894_item	3621331	et	3	main
esitatud	doc_536541856894_item	3621324	et	4	main
muuseum	doc_536541856894_item	3621321	et	3	main
säilis	doc_536541856894_item	3621320	et	4	main
saaremal	doc_536541856894_item	3621319	et	3	main
rahvalaule	doc_536541856894_item	3621290	et	4	main
talle	doc_536541856894_item	3621276	et	4	main
parem	doc_536541856894_item	3621270	et	4	main
on	doc_536541856894_item	3621266	et	4	main
laulsid	doc_536541856894_item	3621258	et	4	main
laule	doc_536541856894_item	3621257	et	4	main
tihti	doc_536541856894_item	3621256	et	3	main
aitas	doc_536541856894_item	3621245	et	3	main
laulsid	doc_536541856894_item	3621242	et	4	main
käisid	doc_536541856894_item	3621239	et	4	main
nad	doc_536541856894_item	3621238	et	3	main
suuliselt	doc_536541856894_item	3621231	et	4	main
seda	doc_536541856894_item	3621227	et	3	main
on	doc_536541856894_item	3621223	et	4	main
mis	doc_536541856894_item	3621222	et	4	main
rahvalaul	doc_536541856894_item	3621221	et	4	main
aitasid	doc_536541856894_item	3621215	et	4	main
rahvale	doc_536541856894_item	3621214	et	3	main
voib	doc_536541856894_item	3621208	et	4	main
olnud	doc_536541856894_item	3621199	et	4	main
ei	doc_536541856894_item	3621198	et	4	main
essee	doc_536541856894_item	3621155	et	4	main
sõna	doc_536541856894_item	3621154	et	4	main
ajad	doc_536541856895_item	3621682	et	4	main
näiteks	doc_536541856895_item	3621663	et	4	main
vabaduse	doc_536541856895_item	3621656	et	4	main
ka	doc_536541856895_item	3621655	et	3	main
rahvas	doc_536541856895_item	3621639	et	4	main
kontserdidest	doc_536541856895_item	3621637	et	4	main
rahvatantsud	doc_536541856895_item	3621618	et	3	main
traditsioonile	doc_536541856895_item	3621603	et	3	main
ringis	doc_536541856895_item	3621586	et	4	main
tihti	doc_536541856895_item	3621585	et	3	main
alati	doc_536541856895_item	3621581	et	4	main
liiguv	doc_536541856895_item	3621579	et	4	main
olnud	doc_536541856895_item	3621577	et	4	main
rahvamuusika	doc_536541856895_item	3621574	et	4	main
tekkib	doc_536541856895_item	3621561	et	3	main
kooriga	doc_536541856895_item	3621549	et	4	main
koos	doc_536541856895_item	3621548	et	4	main
esines	doc_536541856895_item	3621547	et	3	main
eeslaulja	doc_536541856895_item	3621546	et	4	main
rahvamuusika	doc_536541856895_item	3621534	et	4	main
see	doc_536541856895_item	3621526	et	3	main
ajaga	doc_536541856894_item	3621461	et	3	main
surnuks	doc_536541856894_item	3621460	et	4	main
ei	doc_536541856894_item	3621459	et	4	main
traditsioonid	doc_536541856894_item	3621458	et	3	main
ja	doc_536541856894_item	3621457	et	3	main
loodan	doc_536541856894_item	3621454	et	3	main
olema	doc_536541856894_item	3621452	et	4	main
esimest	doc_536541856894_item	3621438	et	4	main
saime	doc_536541856894_item	3621437	et	3	main
kullerkuppud	doc_536541856894_item	3621428	et	4	main
muusikakoolid	doc_536541856894_item	3621419	et	3	main
folkloori	doc_536541856894_item	3621414	et	4	main
ole	doc_536541856894_item	3621407	et	4	main
ei	doc_536541856894_item	3621406	et	4	main
laulutraditsioonid	doc_536541856894_item	3621405	et	3	main
tänapäeval	doc_536541856894_item	3621404	et	3	main
andis	doc_536541856894_item	3621399	et	3	main
mäletan	doc_536541856894_item	3621392	et	3	main
jaoks	doc_536541856894_item	3621391	et	4	main
riigi	doc_536541856894_item	3621390	et	3	main
niisugune	doc_536541856894_item	3621382	et	3	main
selle	doc_536541856894_item	3621379	et	4	main
ja	doc_536541856894_item	3621376	et	3	main
seda	doc_536541856894_item	3621369	et	3	main
ja	doc_536541856894_item	3621368	et	3	main
hümn	doc_536541856894_item	3621367	et	3	main
riigi	doc_536541856894_item	3621366	et	3	main
see	doc_536541856894_item	3621362	et	3	main
laul	doc_536541856894_item	3621363	et	4	main
koidula	doc_536541856894_item	3621360	et	4	main
laulu	doc_536541856894_item	3621357	et	4	main
arm	doc_536541856894_item	3621356	et	3	main
minu	doc_536541856894_item	3621355	et	3	main
1969	doc_536541856894_item	3621349	et	2	main
see	doc_536541856894_item	3621343	et	3	main
kogu	doc_536541856894_item	3621340	et	4	main
palju	doc_536541856894_item	3621338	et	4	main
osales	doc_536541856894_item	3621337	et	3	main
peol	doc_536541856894_item	3621336	et	4	main
tartus	doc_536541856894_item	3621335	et	3	main
ning	doc_536541856894_item	3621327	et	3	main
näiteks	doc_536541856894_item	3621318	et	4	main
uuemat	doc_536541856894_item	3621297	et	4	main
kultuur	doc_536541856894_item	3621296	et	3	main
soome	doc_536541856894_item	3621295	et	3	main
ning	doc_536541856894_item	3621294	et	3	main
vene	doc_536541856894_item	3621293	et	4	main
ja	doc_536541856894_item	3621287	et	3	main
karjuda	doc_536541856894_item	3621286	et	3	main
mitte	doc_536541856894_item	3621285	et	3	main
magama	doc_536541856894_item	3621282	et	3	main
emad	doc_536541856894_item	3621274	et	3	main
laulsid	doc_536541856894_item	3621273	et	4	main
et	doc_536541856894_item	3621269	et	3	main
võimalik	doc_536541856894_item	3621267	et	3	main
koolis	doc_536541856894_item	3621255	et	4	main
vaimulikke	doc_536541856894_item	3621253	et	3	main
koorilaule	doc_536541856894_item	3621251	et	4	main
inimestele	doc_536541856894_item	3621246	et	3	main
rahvas	doc_536541856894_item	3621233	et	4	main
regivärsiline	doc_536541856894_item	3621220	et	4	main
eesti	doc_536541856894_item	3621213	et	4	main
sõpru	doc_536541856894_item	3621212	et	3	main
leida	doc_536541856894_item	3621211	et	3	main
põllutööd	doc_536541856894_item	3621202	et	4	main
nende	doc_536541856894_item	3621196	et	4	main
eestlastest	doc_536541856894_item	3621148	et	4	main
teeb	doc_536541856894_item	3621147	et	3	main
teise	doc_536541856894_item	3621139	et	4	main
kui	doc_536541856894_item	3621138	et	3	main
iseseistvust	doc_536541856894_item	3621346	et	4	main
ja	doc_536541856894_item	3621342	et	3	main
rahvast	doc_536541856894_item	3621339	et	4	main
pulmariided	doc_536541856894_item	3621329	et	3	main
villased	doc_536541856894_item	3621325	et	4	main
on	doc_536541856894_item	3621323	et	4	main
kus	doc_536541856894_item	3621322	et	3	main
populaarsed	doc_536541856894_item	3621316	et	3	main
on	doc_536541856894_item	3621315	et	4	main
saartel	doc_536541856894_item	3621314	et	3	main
teistel	doc_536541856894_item	3621313	et	4	main
ja	doc_536541856894_item	3621312	et	3	main
hiiumal	doc_536541856894_item	3621311	et	4	main
saaremaal	doc_536541856894_item	3621310	et	4	main
käsitsi	doc_536541856894_item	3621309	et	3	main
ka	doc_536541856894_item	3621308	et	3	main
kirjutati	doc_536541856894_item	3621307	et	3	main
aga	doc_536541856894_item	3621306	et	3	main
salmikud	doc_536541856894_item	3621305	et	3	main
trükitud	doc_536541856894_item	3621304	et	4	main
laululehed	doc_536541856894_item	3621302	et	3	main
ülestähendus	doc_536541856894_item	3621301	et	3	main
kirjalik	doc_536541856894_item	3621300	et	3	main
on	doc_536541856894_item	3621303	et	4	main
iseloomustab	doc_536541856894_item	3621299	et	4	main
rahvalaulu	doc_536541856894_item	3621298	et	4	main
eesti	doc_536541856894_item	3621289	et	4	main
nutta	doc_536541856894_item	3621288	et	3	main
ja	doc_536541856894_item	3621284	et	3	main
parem	doc_536541856894_item	3621281	et	4	main
võiks	doc_536541856894_item	3621280	et	4	main
need	doc_536541856894_item	3621279	et	3	main
et	doc_536541856894_item	3621278	et	3	main
laulu	doc_536541856894_item	3621277	et	4	main
lapsi	doc_536541856894_item	3621272	et	4	main
kasvatada	doc_536541856894_item	3621271	et	3	main
veel	doc_536541856894_item	3621265	et	4	main
korraldas	doc_536541856894_item	3621264	et	3	main
koor	doc_536541856894_item	3621263	et	4	main
ja	doc_536541856894_item	3621262	et	3	main
ka	doc_536541856894_item	3621254	et	3	main
eeslaulja	doc_536541856894_item	3621260	et	4	main
see	doc_536541856894_item	3621244	et	3	main
kirikus	doc_536541856894_item	3621240	et	3	main
loomulikult	doc_536541856894_item	3621237	et	4	main
ja	doc_536541856894_item	3621236	et	3	main
põlve	doc_536541856894_item	3621230	et	4	main
ja	doc_536541856894_item	3621226	et	3	main
väga	doc_536541856894_item	3621224	et	3	main
olla	doc_536541856894_item	3621209	et	3	main
tuju	doc_536541856894_item	3621206	et	4	main
et	doc_536541856894_item	3621205	et	3	main
kasvatamine	doc_536541856894_item	3621204	et	4	main
lihtne	doc_536541856894_item	3621200	et	3	main
sest	doc_536541856894_item	3621195	et	4	main
alati	doc_536541856894_item	3621194	et	4	main
laulsid	doc_536541856894_item	3621193	et	4	main
eestlased	doc_536541856894_item	3621192	et	3	main
tööga	doc_536541856894_item	3621191	et	3	main
raske	doc_536541856894_item	3621190	et	4	main
tulla	doc_536541856894_item	3621189	et	3	main
toime	doc_536541856894_item	3621188	et	4	main
et	doc_536541856894_item	3621187	et	3	main
ne	doc_536541856894_item	3621186	et	4	main
ja	doc_536541856894_item	3621185	et	3	main
lauludest	doc_536541856894_item	3621184	et	3	main
tantsudest	doc_536541856894_item	3621183	et	3	main
laulumängudest	doc_536541856894_item	3621182	et	3	main
koosneb	doc_536541856894_item	3621181	et	3	main
muusikafolkloor	doc_536541856894_item	3621180	et	4	main
eesti	doc_536541856894_item	3621179	et	4	main
laulurahvas	doc_536541856894_item	3621178	et	4	main
jäävad	doc_536541856894_item	3621177	et	4	main
ja	doc_536541856894_item	3621176	et	3	main
on	doc_536541856894_item	3621175	et	4	main
olid	doc_536541856894_item	3621174	et	4	main
eestlased	doc_536541856894_item	3621173	et	3	main
näidetega	doc_536541856894_item	3621172	et	3	main
illustreerida	doc_536541856894_item	3621171	et	3	main
soovitatav	doc_536541856894_item	3621170	et	4	main
on	doc_536541856894_item	3621169	et	4	main
väiteid	doc_536541856894_item	3621168	et	4	main
faktidele	doc_536541856894_item	3621167	et	3	main
esitatud	doc_536541856894_item	3621166	et	4	main
lugemistekstis	doc_536541856894_item	3621165	et	3	main
ja	doc_536541856894_item	3621164	et	3	main
loengus	doc_536541856894_item	3621163	et	3	main
tuginema	doc_536541856894_item	3621162	et	3	main
üldistav	doc_536541856894_item	3621161	et	4	main
ja	doc_536541856894_item	3621160	et	3	main
peab	doc_536541856894_item	3621156	et	4	main
350	doc_536541856894_item	3621153	et	2	main
300	doc_536541856894_item	3621152	et	2	main
pikkus	doc_536541856894_item	3621151	et	4	main
essee	doc_536541856894_item	3621135	et	4	main
ka	doc_536541856895_item	3621680	et	3	main
täthsus	doc_536541856895_item	3621657	et	4	main
erinevalest	doc_536541856895_item	3621636	et	4	main
ansambleid	doc_536541856895_item	3621633	et	3	main
näiteks	doc_536541856895_item	3621625	et	4	main
näha	doc_536541856895_item	3621624	et	3	main
on	doc_536541856895_item	3621617	et	4	main
rahvamuusikaga	doc_536541856895_item	3621615	et	3	main
näitavad	doc_536541856895_item	3621609	et	4	main
korraldatakse	doc_536541856895_item	3621604	et	3	main
tähelepanu	doc_536541856895_item	3621600	et	4	main
tänased	doc_536541856895_item	3621595	et	3	main
pulmalauljad	doc_536541856895_item	3621594	et	3	main
eesti	doc_536541856895_item	3621573	et	4	main
olid	doc_536541856895_item	3621551	et	4	main
need	doc_536541856895_item	3621550	et	3	main
ühel	doc_536541856895_item	3621537	et	3	main
seisa	doc_536541856895_item	3621536	et	4	main
aeg	doc_536541856895_item	3621531	et	3	main
algusel	doc_536541856895_item	3621525	et	4	main
inimestega	doc_536541856895_item	3621524	et	3	main
hingades	doc_536541856895_item	3621517	et	4	main
ole	doc_536541856895_item	3621504	et	4	main
mis	doc_536541856895_item	3621474	et	4	main
teeb	doc_536541856897_item	3621980	et	3	main
suurt	doc_536541856897_item	3621976	et	3	main
kultuuris	doc_536541856897_item	3621973	et	3	main
öelda	doc_536541856897_item	3621959	et	4	main
osa	doc_536541856897_item	3621946	et	4	main
võtavad	doc_536541856897_item	3621945	et	3	main
kujunes	doc_536541856897_item	3621926	et	3	main
ülemaalise	doc_536541856897_item	3621923	et	4	main
tartus	doc_536541856897_item	3621920	et	3	main
1869	doc_536541856897_item	3621918	et	2	main
ei	doc_536541856897_item	3621915	et	4	main
see	doc_536541856897_item	3621903	et	3	main
ja	doc_536541856897_item	3621901	et	3	main
kõlas	doc_536541856897_item	3621895	et	4	main
gustav	doc_536541856897_item	3621893	et	4	main
soovide	doc_536541856897_item	3621887	et	3	main
kui	doc_536541856897_item	3621764	et	3	main
väljendusvahend	doc_536541856897_item	3621759	et	3	main
tundud	doc_536541856897_item	3621746	et	3	main
illustreerida	doc_536541856897_item	3621743	et	3	main
ja	doc_536541856897_item	3621732	et	3	main
mis	doc_536541856897_item	3621718	et	4	main
kui	doc_536541856897_item	3621710	et	3	main
19	doc_536541856897_item	3621870	et	2	main
kui	doc_536541856897_item	3621869	et	3	main
või	doc_536541856897_item	3621838	et	4	main
sõjamees	doc_536541856897_item	3621837	et	4	main
mingisugune	doc_536541856897_item	3621836	et	3	main
parem	doc_536541856897_item	3621810	et	4	main
laulsid	doc_536541856897_item	3621792	et	4	main
olulised	doc_536541856897_item	3621785	et	4	main
et	doc_536541856897_item	3621773	et	3	main
ajalugu	doc_536541856897_item	3621769	et	4	main
analüüsiv	doc_536541856894_item	3621159	et	4	main
arutlev	doc_536541856894_item	3621158	et	4	main
olema	doc_536541856894_item	3621157	et	4	main
mis	doc_536541856894_item	3621146	et	4	main
teemal	doc_536541856894_item	3621145	et	3	main
essee	doc_536541856894_item	3621144	et	4	main
kirjutage	doc_536541856894_item	3621143	et	3	main
kirjutamine	doc_536541856894_item	3621142	et	4	main
test	doc_536541856894_item	3621141	et	3	main
keele	doc_536541856894_item	3621137	et	4	main
teistele	doc_536541856895_item	3621676	et	4	main
seda	doc_536541856895_item	3621675	et	3	main
selgitada	doc_536541856895_item	3621674	et	3	main
rahvas	doc_536541856895_item	3621660	et	4	main
eesti	doc_536541856895_item	3621659	et	4	main
endaga	doc_536541856895_item	3621654	et	4	main
toob	doc_536541856895_item	3621653	et	3	main
see	doc_536541856895_item	3621652	et	3	main
aga	doc_536541856895_item	3621651	et	3	main
rõõmust	doc_536541856895_item	3621650	et	3	main
ainult	doc_536541856895_item	3621649	et	4	main
eestlaste	doc_536541856895_item	3621645	et	4	main
muusika	doc_536541856895_item	3621644	et	4	main
päevani	doc_536541856895_item	3621643	et	3	main
tänase	doc_536541856895_item	3621642	et	3	main
elab	doc_536541856895_item	3621641	et	3	main
rahvusprogrammiga	doc_536541856895_item	3621638	et	4	main
nädalavahetusel	doc_536541856895_item	3621631	et	4	main
võib	doc_536541856895_item	3621623	et	3	main
isegi	doc_536541856895_item	3621621	et	4	main
seotud	doc_536541856895_item	3621614	et	4	main
mis	doc_536541856895_item	3621612	et	4	main
erinevaid	doc_536541856895_item	3621605	et	4	main
laulsid	doc_536541856895_item	3621588	et	4	main
rahvaulud	doc_536541856895_item	3621587	et	3	main
lauldi	doc_536541856895_item	3621582	et	3	main
väga	doc_536541856895_item	3621578	et	3	main
alati	doc_536541856895_item	3621576	et	4	main
populaarse	doc_536541856895_item	3621571	et	3	main
tänase	doc_536541856895_item	3621570	et	3	main
ka	doc_536541856895_item	3621569	et	3	main
elu	doc_536541856895_item	3621568	et	4	main
tulevikus	doc_536541856895_item	3621566	et	4	main
mis	doc_536541856895_item	3621565	et	4	main
ilmub	doc_536541856895_item	3621556	et	3	main
oli	doc_536541856895_item	3621543	et	3	main
ei	doc_536541856895_item	3621535	et	4	main
jookseb	doc_536541856895_item	3621532	et	3	main
laul	doc_536541856895_item	3621529	et	4	main
oli	doc_536541856895_item	3621527	et	3	main
koos	doc_536541856895_item	3621523	et	4	main
muusika	doc_536541856895_item	3621521	et	4	main
sellest	doc_536541856895_item	3621512	et	4	main
eesti	doc_536541856895_item	3621509	et	4	main
näidetega	doc_536541856895_item	3621500	et	3	main
mängis	doc_536541856897_item	3621975	et	3	main
elus	doc_536541856897_item	3621971	et	4	main
nende	doc_536541856897_item	3621970	et	4	main
et	doc_536541856897_item	3621968	et	3	main
võrreldes	doc_536541856897_item	3621961	et	3	main
koorid	doc_536541856897_item	3621944	et	4	main
paljud	doc_536541856897_item	3621943	et	3	main
aastal	doc_536541856897_item	3621942	et	3	main
millest	doc_536541856897_item	3621925	et	3	main
esimese	doc_536541856897_item	3621922	et	3	main
korraldati	doc_536541856897_item	3621921	et	3	main
taha	doc_536541856897_item	3621916	et	4	main
nemad	doc_536541856897_item	3621914	et	3	main
ja	doc_536541856897_item	3621913	et	3	main
tõsine	doc_536541856897_item	3621912	et	4	main
on	doc_536541856897_item	3621911	et	4	main
eestlaste	doc_536541856897_item	3621908	et	4	main
märk	doc_536541856897_item	3621906	et	3	main
esimene	doc_536541856897_item	3621905	et	3	main
oli	doc_536541856897_item	3621904	et	3	main
rõõm	doc_536541856897_item	3621902	et	3	main
kui	doc_536541856897_item	3621892	et	3	main
nii	doc_536541856897_item	3621889	et	3	main
sai	doc_536541856897_item	3621884	et	4	main
laul	doc_536541856897_item	3621883	et	4	main
on	doc_536541856897_item	3621881	et	4	main
et	doc_536541856897_item	3621879	et	3	main
püsti	doc_536541856895_item	3621705	et	3	main
tõuseb	doc_536541856895_item	3621704	et	3	main
rahvalaul	doc_536541856895_item	3621703	et	4	main
nüüd	doc_536541856895_item	3621702	et	4	main
ja	doc_536541856895_item	3621701	et	3	main
läbi	doc_536541856895_item	3621700	et	4	main
sai	doc_536541856895_item	3621699	et	4	main
rahvas	doc_536541856895_item	3621698	et	4	main
ikkagi	doc_536541856895_item	3621696	et	4	main
aga	doc_536541856895_item	3621695	et	3	main
eesti	doc_536541856895_item	3621697	et	4	main
korraldamisele	doc_536541856895_item	3621694	et	4	main
rahvaspidudele	doc_536541856895_item	3621693	et	4	main
õigust	doc_536541856895_item	3621692	et	4	main
oma	doc_536541856895_item	3621691	et	4	main
tõestada	doc_536541856895_item	3621690	et	3	main
raske	doc_536541856895_item	3621689	et	4	main
väga	doc_536541856895_item	3621688	et	3	main
oli	doc_536541856895_item	3621687	et	3	main
kui	doc_536541856895_item	3621686	et	3	main
aeg	doc_536541856895_item	3621685	et	3	main
nõukogude	doc_536541856895_item	3621684	et	3	main
näiteks	doc_536541856895_item	3621683	et	4	main
üritasid	doc_536541856895_item	3621673	et	4	main
nad	doc_536541856895_item	3621672	et	3	main
kaudu	doc_536541856895_item	3621671	et	3	main
muusika	doc_536541856895_item	3621670	et	4	main
ja	doc_536541856895_item	3621669	et	3	main
laulude	doc_536541856895_item	3621668	et	3	main
rahvalaulupeod	doc_536541856895_item	3621664	et	4	main
sest	doc_536541856895_item	3621658	et	4	main
tähenda	doc_536541856895_item	3621648	et	4	main
jaoks	doc_536541856895_item	3621646	et	4	main
osa	doc_536541856895_item	3621635	et	4	main
populaarsed	doc_536541856895_item	3621632	et	3	main
seal	doc_536541856895_item	3621630	et	4	main
esinevad	doc_536541856895_item	3621629	et	4	main
praegu	doc_536541856895_item	3621622	et	3	main
esindused	doc_536541856895_item	3621620	et	4	main
see	doc_536541856895_item	3621616	et	3	main
esinejad	doc_536541856895_item	3621608	et	4	main
kus	doc_536541856895_item	3621607	et	3	main
pidusid	doc_536541856895_item	3621606	et	4	main
oma	doc_536541856895_item	3621601	et	4	main
noored	doc_536541856895_item	3621596	et	3	main
eriti	doc_536541856895_item	3621584	et	3	main
vanasti	doc_536541856895_item	3621580	et	3	main
muusikale	doc_536541856895_item	3621572	et	4	main
muusika	doc_536541856895_item	3621564	et	4	main
juba	doc_536541856895_item	3621562	et	3	main
sajandil	doc_536541856895_item	3621560	et	3	main
kirikumuusika	doc_536541856895_item	3621558	et	4	main
regilaul	doc_536541856895_item	3621544	et	4	main
algusel	doc_536541856895_item	3621541	et	4	main
aastaid	doc_536541856895_item	3621520	et	4	main
tuhandeid	doc_536541856895_item	3621519	et	3	main
juba	doc_536541856895_item	3621518	et	3	main
koosneb	doc_536541856895_item	3621511	et	3	main
muusika	doc_536541856895_item	3621508	et	4	main
rahvamuusika	doc_536541856895_item	3621502	et	4	main
see	doc_536541856897_item	3621979	et	3	main
mängib	doc_536541856897_item	3621974	et	3	main
vanate	doc_536541856897_item	3621964	et	4	main
eestlasi	doc_536541856897_item	3621963	et	3	main
tänapäevaseid	doc_536541856897_item	3621962	et	4	main
kokkuvõtteks	doc_536541856897_item	3621957	et	3	main
nagu	doc_536541856897_item	3621955	et	3	main
pidu	doc_536541856897_item	3621954	et	4	main
oodata	doc_536541856897_item	3621917	et	4	main
ühineda	doc_536541856897_item	3621910	et	3	main
mu	doc_536541856897_item	3621899	et	3	main
mu	doc_536541856897_item	3621897	et	3	main
laulurevolutsioon	doc_536541856897_item	3621891	et	3	main
said	doc_536541856897_item	3621877	et	4	main
nad	doc_536541856897_item	3621876	et	3	main
ja	doc_536541856897_item	3621875	et	3	main
identiteeditunne	doc_536541856897_item	3621874	et	3	main
tekkis	doc_536541856897_item	3621873	et	3	main
eestlastel	doc_536541856897_item	3621872	et	4	main
kultuuri	doc_536541856897_item	3621768	et	4	main
kui	doc_536541856897_item	3621760	et	3	main
emotsionaalne	doc_536541856897_item	3621758	et	3	main
nii	doc_536541856897_item	3621755	et	3	main
laulmisel	doc_536541856897_item	3621748	et	4	main
on	doc_536541856897_item	3621741	et	4	main
arutlev	doc_536541856897_item	3621730	et	4	main
olema	doc_536541856897_item	3621729	et	4	main
peab	doc_536541856897_item	3621728	et	4	main
eestlastest	doc_536541856897_item	3621720	et	4	main
teeb	doc_536541856897_item	3621719	et	3	main
teise	doc_536541856897_item	3621711	et	4	main
kuritegija	doc_536541856897_item	3621839	et	4	main
nende	doc_536541856897_item	3621805	et	4	main
tehes	doc_536541856897_item	3621804	et	3	main
teiste	doc_536541856897_item	3621797	et	4	main
ja	doc_536541856897_item	3621796	et	3	main
kiigutades	doc_536541856897_item	3621795	et	3	main
last	doc_536541856897_item	3621794	et	4	main
töötades	doc_536541856897_item	3621793	et	3	main
poliitilised	doc_536541856897_item	3621788	et	3	main
laulmisega	doc_536541856897_item	3621781	et	4	main
eesti	doc_536541856897_item	3621774	et	4	main
eestile	doc_536541856899_item	3622349	et	3	main
tulevik	doc_536541856899_item	3622347	et	3	main
läheks	doc_536541856899_item	3622343	et	3	main
kõik	doc_536541856899_item	3622339	et	4	main
liiga	doc_536541856899_item	3622333	et	4	main
neid	doc_536541856899_item	3622331	et	4	main
kahjuks	doc_536541856899_item	3622330	et	4	main
rahvaansamblid	doc_536541856899_item	3622329	et	3	main
vana	doc_536541856895_item	3621602	et	4	main
pöördusid	doc_536541856895_item	3621599	et	4	main
jälle	doc_536541856895_item	3621598	et	3	main
inimesed	doc_536541856895_item	3621597	et	3	main
rohkem	doc_536541856895_item	3621593	et	4	main
olid	doc_536541856895_item	3621592	et	4	main
mehed	doc_536541856895_item	3621591	et	3	main
aga	doc_536541856895_item	3621590	et	3	main
naised	doc_536541856895_item	3621589	et	3	main
liikumisega	doc_536541856895_item	3621583	et	4	main
on	doc_536541856895_item	3621575	et	4	main
annab	doc_536541856895_item	3621567	et	3	main
uus	doc_536541856895_item	3621563	et	3	main
19	doc_536541856895_item	3621559	et	2	main
kirikulaulmine	doc_536541856895_item	3621557	et	3	main
pärast	doc_536541856895_item	3621555	et	4	main
juba	doc_536541856895_item	3621554	et	3	main
esindused	doc_536541856895_item	3621553	et	4	main
suured	doc_536541856895_item	3621552	et	3	main
kus	doc_536541856895_item	3621545	et	3	main
see	doc_536541856895_item	3621542	et	3	main
kõige	doc_536541856895_item	3621540	et	4	main
ka	doc_536541856895_item	3621539	et	3	main
paigal	doc_536541856895_item	3621538	et	4	main
ja	doc_536541856895_item	3621533	et	3	main
aga	doc_536541856895_item	3621530	et	3	main
lihtne	doc_536541856895_item	3621528	et	3	main
aruneb	doc_536541856895_item	3621522	et	4	main
nende	doc_536541856895_item	3621516	et	4	main
elab	doc_536541856895_item	3621515	et	3	main
see	doc_536541856895_item	3621514	et	3	main
muusikast	doc_536541856895_item	3621513	et	4	main
rahvas	doc_536541856895_item	3621510	et	4	main
elav	doc_536541856895_item	3621507	et	4	main
eraldi	doc_536541856895_item	3621506	et	4	main
lihtsalt	doc_536541856895_item	3621505	et	4	main
ei	doc_536541856895_item	3621503	et	4	main
eesti	doc_536541856895_item	3621501	et	4	main
illustreerida	doc_536541856895_item	3621499	et	3	main
essee	doc_536541856895_item	3621478	et	4	main
laulurahva	doc_536541856895_item	3621477	et	3	main
eestlastest	doc_536541856895_item	3621476	et	4	main
teeb	doc_536541856895_item	3621475	et	3	main
teemal	doc_536541856895_item	3621473	et	3	main
essee	doc_536541856895_item	3621472	et	4	main
kirjutage	doc_536541856895_item	3621471	et	3	main
kirjutamine	doc_536541856895_item	3621470	et	4	main
test	doc_536541856895_item	3621469	et	3	main
keele	doc_536541856895_item	3621468	et	4	main
teise	doc_536541856895_item	3621467	et	4	main
kui	doc_536541856895_item	3621466	et	3	main
keele	doc_536541856895_item	3621465	et	4	main
eesti	doc_536541856895_item	3621464	et	4	main
essee	doc_536541856895_item	3621463	et	4	main
soovitatav	doc_536541856895_item	3621498	et	4	main
on	doc_536541856895_item	3621497	et	4	main
väiteid	doc_536541856895_item	3621496	et	4	main
faktidele	doc_536541856895_item	3621495	et	3	main
esitatud	doc_536541856895_item	3621494	et	4	main
lugemistekstis	doc_536541856895_item	3621493	et	3	main
ja	doc_536541856895_item	3621492	et	3	main
loengus	doc_536541856895_item	3621491	et	3	main
tuginema	doc_536541856895_item	3621490	et	3	main
üldistav	doc_536541856895_item	3621489	et	4	main
ja	doc_536541856895_item	3621488	et	3	main
analüüsiv	doc_536541856895_item	3621487	et	4	main
arutlev	doc_536541856895_item	3621486	et	4	main
olema	doc_536541856895_item	3621485	et	4	main
peab	doc_536541856895_item	3621484	et	4	main
essee	doc_536541856895_item	3621483	et	4	main
sõna	doc_536541856895_item	3621482	et	4	main
350	doc_536541856895_item	3621481	et	2	main
300	doc_536541856895_item	3621480	et	2	main
pikkus	doc_536541856895_item	3621479	et	4	main
rolli	doc_536541856897_item	3621977	et	4	main
ja	doc_536541856897_item	3621972	et	3	main
laul	doc_536541856897_item	3621969	et	4	main
võime	doc_536541856897_item	3621966	et	4	main
eestlastega	doc_536541856897_item	3621965	et	4	main
tahan	doc_536541856897_item	3621958	et	3	main
seda	doc_536541856897_item	3621953	et	3	main
külastavad	doc_536541856897_item	3621952	et	4	main
palju	doc_536541856897_item	3621950	et	4	main
üritusest	doc_536541856897_item	3621948	et	4	main
sellest	doc_536541856897_item	3621947	et	4	main
laulupeo	doc_536541856897_item	3621924	et	4	main
aastal	doc_536541856897_item	3621919	et	3	main
soov	doc_536541856897_item	3621909	et	3	main
et	doc_536541856897_item	3621907	et	3	main
laulurahva	doc_536541856897_item	3621982	et	3	main
eestlastest	doc_536541856897_item	3621981	et	4	main
ilmselt	doc_536541856897_item	3621978	et	4	main
näha	doc_536541856897_item	3621967	et	3	main
et	doc_536541856897_item	3621960	et	3	main
vaatajad	doc_536541856897_item	3621956	et	4	main
inimesi	doc_536541856897_item	3621951	et	4	main
ning	doc_536541856897_item	3621949	et	3	main
neljandal	doc_536541856897_item	3621941	et	3	main
igal	doc_536541856897_item	3621940	et	3	main
korraldatakse	doc_536541856897_item	3621939	et	3	main
eestis	doc_536541856897_item	3621937	et	3	main
see	doc_536541856897_item	3621938	et	3	main
traditsiooniks	doc_536541856897_item	3621936	et	3	main
regulaarseks	doc_536541856897_item	3621935	et	4	main
sai	doc_536541856897_item	3621934	et	4	main
laulupidu	doc_536541856897_item	3621933	et	4	main
seda	doc_536541856897_item	3621932	et	3	main
pärast	doc_536541856897_item	3621931	et	4	main
kõrghetk	doc_536541856897_item	3621930	et	3	main
liikumise	doc_536541856897_item	3621929	et	4	main
rahvusliku	doc_536541856897_item	3621928	et	3	main
eestlaste	doc_536541856897_item	3621927	et	4	main
õnn	doc_536541856897_item	3621900	et	3	main
isamaa	doc_536541856897_item	3621898	et	4	main
sündis	doc_536541856897_item	3621890	et	3	main
peaks	doc_536541856897_item	3621885	et	4	main
tähelepanelikult	doc_536541856897_item	3621765	et	4	main
ka	doc_536541856897_item	3621761	et	3	main
esteetiline	doc_536541856897_item	3621756	et	3	main
on	doc_536541856897_item	3621754	et	4	main
on	doc_536541856897_item	3621749	et	4	main
on	doc_536541856897_item	3621745	et	4	main
essee	doc_536541856897_item	3621727	et	4	main
350	doc_536541856897_item	3621725	et	2	main
kirjutage	doc_536541856897_item	3621715	et	3	main
kirjutamine	doc_536541856897_item	3621714	et	4	main
test	doc_536541856897_item	3621713	et	3	main
seetõttu	doc_536541856897_item	3621844	et	3	main
saa	doc_536541856897_item	3621841	et	4	main
ei	doc_536541856897_item	3621840	et	4	main
on	doc_536541856897_item	3621833	et	4	main
need	doc_536541856897_item	3621832	et	3	main
kultuur	doc_536541856897_item	3621831	et	3	main
ja	doc_536541856897_item	3621830	et	3	main
kõike	doc_536541856897_item	3621809	et	4	main
rahvalaul	doc_536541856897_item	3621808	et	4	main
oli	doc_536541856897_item	3621807	et	3	main
jaoks	doc_536541856897_item	3621806	et	4	main
vanad	doc_536541856897_item	3621790	et	3	main
ajaloolised	doc_536541856897_item	3621786	et	4	main
laulu	doc_536541856897_item	3621780	et	4	main
märkame	doc_536541856897_item	3621772	et	3	main
poole	doc_536541856897_item	3621770	et	4	main
meil	doc_536541856899_item	3622341	et	4	main
küll	doc_536541856899_item	3622337	et	4	main
tööd	doc_536541856899_item	3622326	et	4	main
tohi	doc_536541856899_item	3622321	et	4	main
sellist	doc_536541856899_item	3622317	et	4	main
kahju	doc_536541856899_item	3622300	et	4	main
väga	doc_536541856899_item	3622299	et	3	main
inimesed	doc_536541856899_item	3622298	et	3	main
häid	doc_536541856899_item	3622293	et	3	main
georg	doc_536541856899_item	3622271	et	4	main
ernesaks	doc_536541856899_item	3622270	et	4	main
muusikuid	doc_536541856899_item	3622264	et	3	main
palju	doc_536541856899_item	3622262	et	4	main
võitis	doc_536541856899_item	3622249	et	3	main
vähem	doc_536541856899_item	3622244	et	4	main
on	doc_536541856899_item	3622232	et	4	main
ajal	doc_536541856899_item	3622222	et	4	main
1989	doc_536541856899_item	3622216	et	2	main
küll	doc_536541856899_item	3622198	et	4	main
ajal	doc_536541856899_item	3622194	et	4	main
saatnud	doc_536541856899_item	3622191	et	4	main
on	doc_536541856899_item	3622190	et	4	main
tants	doc_536541856899_item	3622189	et	3	main
ja	doc_536541856899_item	3622188	et	3	main
isamaalaul	doc_536541856897_item	3621896	et	4	main
ernesaksa	doc_536541856897_item	3621894	et	4	main
väljendusvahendiks	doc_536541856897_item	3621888	et	3	main
nende	doc_536541856897_item	3621886	et	4	main
rahvas	doc_536541856897_item	3621882	et	4	main
nemad	doc_536541856897_item	3621880	et	3	main
eesti	doc_536541856897_item	3621767	et	4	main
vaatame	doc_536541856897_item	3621766	et	3	main
ja	doc_536541856897_item	3621757	et	3	main
et	doc_536541856897_item	3621747	et	3	main
soovitatav	doc_536541856897_item	3621742	et	4	main
väiteid	doc_536541856897_item	3621740	et	4	main
faktidele	doc_536541856897_item	3621739	et	3	main
esitatud	doc_536541856897_item	3621738	et	4	main
lugemistekstis	doc_536541856897_item	3621737	et	3	main
ja	doc_536541856897_item	3621736	et	3	main
loengus	doc_536541856897_item	3621735	et	3	main
tuginema	doc_536541856897_item	3621734	et	3	main
essee	doc_536541856897_item	3621722	et	4	main
laulurahva	doc_536541856897_item	3621721	et	3	main
keele	doc_536541856897_item	3621712	et	4	main
keele	doc_536541856897_item	3621709	et	4	main
kaudu	doc_536541856897_item	3621868	et	3	main
laulu	doc_536541856897_item	3621867	et	4	main
essee	doc_536541856897_item	3621707	et	4	main
kujutlust	doc_536541856897_item	3621866	et	4	main
maailma	doc_536541856897_item	3621865	et	4	main
oma	doc_536541856897_item	3621864	et	4	main
väljendavad	doc_536541856897_item	3621863	et	4	main
nad	doc_536541856897_item	3621862	et	3	main
rock-bändid	doc_536541856897_item	3621861	et	4	main
tänapäevased	doc_536541856897_item	3621860	et	4	main
teevad	doc_536541856897_item	3621859	et	3	main
sama	doc_536541856897_item	3621858	et	4	main
seda	doc_536541856897_item	3621857	et	3	main
kujutlusi	doc_536541856897_item	3621856	et	4	main
maailma	doc_536541856897_item	3621855	et	4	main
ja	doc_536541856897_item	3621854	et	3	main
mõtteid	doc_536541856897_item	3621853	et	3	main
emotsioone	doc_536541856897_item	3621852	et	3	main
tundeid	doc_536541856897_item	3621851	et	3	main
oma	doc_536541856897_item	3621850	et	4	main
kaudu	doc_536541856897_item	3621849	et	3	main
laulu	doc_536541856897_item	3621848	et	4	main
eestlased	doc_536541856897_item	3621847	et	3	main
vanad	doc_536541856897_item	3621846	et	3	main
aru	doc_536541856897_item	3621878	et	4	main
tegevus	doc_536541856897_item	3621763	et	4	main
sotsiaalne	doc_536541856897_item	3621762	et	3	main
see	doc_536541856897_item	3621753	et	3	main
tähtsus	doc_536541856897_item	3621752	et	4	main
oluline	doc_536541856897_item	3621751	et	4	main
väga	doc_536541856897_item	3621750	et	3	main
näidetega	doc_536541856897_item	3621744	et	3	main
üldistav	doc_536541856897_item	3621733	et	4	main
analüüsiv	doc_536541856897_item	3621731	et	4	main
sõna	doc_536541856897_item	3621726	et	4	main
300	doc_536541856897_item	3621724	et	2	main
pikkus	doc_536541856897_item	3621723	et	4	main
teemal	doc_536541856897_item	3621717	et	3	main
essee	doc_536541856897_item	3621716	et	4	main
eesti	doc_536541856897_item	3621708	et	4	main
sajandil	doc_536541856897_item	3621871	et	3	main
väljendasid	doc_536541856897_item	3621845	et	4	main
võtta	doc_536541856897_item	3621843	et	3	main
käsitöö	doc_536541856897_item	3621803	et	4	main
sündmused	doc_536541856897_item	3621789	et	3	main
kaasnesid	doc_536541856897_item	3621782	et	4	main
rahvas	doc_536541856897_item	3621775	et	4	main
kogu	doc_536541856899_item	3622348	et	4	main
hästi	doc_536541856899_item	3622344	et	3	main
aga	doc_536541856899_item	3622336	et	3	main
on	doc_536541856899_item	3622332	et	4	main
looda	doc_536541856899_item	3622322	et	4	main
kõik	doc_536541856899_item	3622310	et	4	main
eestlaste	doc_536541856899_item	3622301	et	4	main
lauljaid	doc_536541856899_item	3622296	et	4	main
lauljaid	doc_536541856899_item	3622268	et	4	main
et	doc_536541856899_item	3622258	et	3	main
ka	doc_536541856899_item	3622256	et	3	main
räägiti	doc_536541856899_item	3622255	et	3	main
koos	doc_536541856899_item	3622252	et	4	main
padar	doc_536541856899_item	3622251	et	4	main
2002	doc_536541856899_item	3622247	et	2	main
kui	doc_536541856899_item	3622245	et	3	main
vähem	doc_536541856899_item	3622242	et	4	main
sellest	doc_536541856899_item	3622241	et	4	main
räägitakse	doc_536541856899_item	3622240	et	3	main
tõeline	doc_536541856899_item	3622233	et	4	main
eestlased	doc_536541856899_item	3622231	et	3	main
tuhat	doc_536541856899_item	3622229	et	4	main
kolmsada	doc_536541856899_item	3622228	et	4	main
kui	doc_536541856899_item	3622227	et	3	main
liikumise	doc_536541856899_item	3622221	et	4	main
vastu	doc_536541856899_item	3622220	et	3	main
üldlaulupidude	doc_536541856899_item	3622201	et	4	main
praegu	doc_536541856899_item	3622200	et	3	main
ka	doc_536541856899_item	3622199	et	3	main
laul	doc_536541856899_item	3622187	et	4	main
tahate	doc_536541856899_item	3622186	et	3	main
kui	doc_536541856899_item	3622185	et	3	main
ära	doc_536541856897_item	3621842	et	4	main
mida	doc_536541856897_item	3621835	et	4	main
asjad	doc_536541856897_item	3621834	et	3	main
laul	doc_536541856897_item	3621829	et	4	main
veeta	doc_536541856897_item	3621828	et	4	main
aja	doc_536541856897_item	3621827	et	4	main
vaba	doc_536541856897_item	3621826	et	4	main
meelsasti	doc_536541856897_item	3621825	et	3	main
neid	doc_536541856897_item	3621824	et	4	main
aitas	doc_536541856897_item	3621823	et	3	main
ajal	doc_536541856897_item	3621822	et	4	main
halval	doc_536541856897_item	3621821	et	3	main
neid	doc_536541856897_item	3621820	et	4	main
päästas	doc_536541856897_item	3621819	et	4	main
mis	doc_536541856897_item	3621818	et	4	main
aeg	doc_536541856897_item	3621817	et	3	main
kogu	doc_536541856897_item	3621816	et	4	main
lähedal	doc_536541856897_item	3621815	et	4	main
nendega	doc_536541856897_item	3621814	et	4	main
oli	doc_536541856897_item	3621813	et	3	main
mis	doc_536541856897_item	3621812	et	4	main
sõber	doc_536541856897_item	3621811	et	3	main
laulsid	doc_536541856897_item	3621802	et	4	main
naised	doc_536541856897_item	3621801	et	3	main
näiteks	doc_536541856897_item	3621800	et	4	main
tehes	doc_536541856897_item	3621799	et	3	main
tegevuste	doc_536541856897_item	3621798	et	4	main
eestlased	doc_536541856897_item	3621791	et	3	main
ja	doc_536541856897_item	3621787	et	3	main
eesti	doc_536541856897_item	3621784	et	4	main
kõik	doc_536541856897_item	3621783	et	4	main
tänapäevaseni	doc_536541856897_item	3621779	et	4	main
ajast	doc_536541856897_item	3621778	et	4	main
vanast	doc_536541856897_item	3621777	et	3	main
laulab	doc_536541856897_item	3621776	et	3	main
siis	doc_536541856897_item	3621771	et	3	main
tulevikus	doc_536541856899_item	3622340	et	4	main
et	doc_536541856899_item	3622338	et	3	main
vähe	doc_536541856899_item	3622334	et	3	main
ei	doc_536541856899_item	3622320	et	4	main
rahvamuusikat	doc_536541856899_item	3622318	et	3	main
peame	doc_536541856899_item	3622312	et	4	main
eestimaalased	doc_536541856899_item	3622311	et	3	main
pea	doc_536541856899_item	3622306	et	4	main
häid	doc_536541856899_item	3622295	et	3	main
muidugi	doc_536541856899_item	3622267	et	4	main
bentoniga	doc_536541856899_item	3622253	et	4	main
eurovisioonil	doc_536541856899_item	3622246	et	3	main
laulurahvas	doc_536541856899_item	3622234	et	4	main
inimesi	doc_536541856899_item	3622230	et	4	main
aastal	doc_536541856899_item	3622217	et	3	main
ja	doc_536541856899_item	3622214	et	3	main
keele	doc_536541856899_item	3622212	et	4	main
oma	doc_536541856899_item	3622211	et	4	main
areneb	doc_536541856899_item	3622210	et	3	main
säilitab	doc_536541856899_item	3622208	et	3	main
saadab	doc_536541856899_item	3622197	et	3	main
tehes	doc_536541856899_item	3622196	et	3	main
elustiil	doc_536541856899_item	3622184	et	4	main
eesti	doc_536541856899_item	3622132	et	4	main
rahvaga	doc_536541856899_item	3622126	et	3	main
eesti	doc_536541856899_item	3622125	et	4	main
juhtuda	doc_536541856899_item	3622124	et	3	main
ela	doc_536541856899_item	3622116	et	4	main
siis	doc_536541856899_item	3622110	et	3	main
kolime	doc_536541856899_item	3622109	et	3	main
lõuna-eestil	doc_536541856899_item	3622105	et	3	main
muutub	doc_536541856899_item	3622096	et	3	main
maa	doc_536541856899_item	3622095	et	4	main
see	doc_536541856899_item	3622091	et	3	main
raskelt	doc_536541856899_item	3622088	et	4	main
tuleb	doc_536541856899_item	3622086	et	3	main
ole	doc_536541856899_item	3622080	et	4	main
olulisem	doc_536541856899_item	3622076	et	4	main
on	doc_536541856899_item	3622075	et	4	main
omapärasus	doc_536541856899_item	3622074	et	4	main
ja	doc_536541856899_item	3622073	et	3	main
et	doc_536541856899_item	3622070	et	3	main
olen	doc_536541856899_item	3622068	et	3	main
arvanud	doc_536541856899_item	3622069	et	4	main
bensiini	doc_536541856899_item	3622063	et	4	main
kõike	doc_536541856899_item	3622059	et	4	main
kõikidele	doc_536541856899_item	3622346	et	4	main
tulevik	doc_536541856899_item	3622345	et	3	main
teiega	doc_536541856899_item	3622342	et	3	main
loodan	doc_536541856899_item	3622335	et	3	main
saavad	doc_536541856899_item	3622327	et	4	main
sellist	doc_536541856899_item	3622325	et	4	main
kõike	doc_536541856899_item	3622324	et	4	main
et	doc_536541856899_item	3622323	et	3	main
veel	doc_536541856899_item	3622316	et	4	main
arenema	doc_536541856899_item	3622315	et	3	main
ja	doc_536541856899_item	3622314	et	3	main
säilitama	doc_536541856899_item	3622313	et	4	main
meie	doc_536541856899_item	3622308	et	4	main
vähestama	doc_536541856899_item	3622307	et	4	main
kohta	doc_536541856899_item	3622304	et	4	main
laulmistraditsiooni	doc_536541856899_item	3622303	et	4	main
uhkus	doc_536541856899_item	3622302	et	4	main
hääle	doc_536541856899_item	3622294	et	3	main
enam	doc_536541856899_item	3622292	et	4	main
ole	doc_536541856899_item	3622291	et	4	main
ei	doc_536541856899_item	3622290	et	4	main
eestis	doc_536541856899_item	3622289	et	3	main
kas	doc_536541856899_item	3622288	et	3	main
juhtub	doc_536541856899_item	3622287	et	3	main
mis	doc_536541856899_item	3622286	et	4	main
näiteks	doc_536541856899_item	3622285	et	4	main
rootslaseid	doc_536541856899_item	3622284	et	3	main
eesti	doc_536541856899_item	3622283	et	4	main
saadab	doc_536541856899_item	3622282	et	3	main
osalemiseks	doc_536541856899_item	3622281	et	4	main
festivali	doc_536541856899_item	3622280	et	4	main
pop-muusika	doc_536541856899_item	3622279	et	4	main
odava	doc_536541856899_item	3622278	et	3	main
sellise	doc_536541856899_item	3622277	et	4	main
ka	doc_536541856899_item	3622276	et	3	main
tihti	doc_536541856899_item	3622275	et	3	main
et	doc_536541856899_item	3622274	et	3	main
häbi	doc_536541856899_item	3622273	et	4	main
ots	doc_536541856899_item	3622272	et	3	main
teha	doc_536541856899_item	3622328	et	3	main
rahvatantsu	doc_536541856899_item	3622319	et	4	main
ise	doc_536541856899_item	3622309	et	4	main
ei	doc_536541856899_item	3622305	et	4	main
küsivad	doc_536541856899_item	3622297	et	4	main
ka	doc_536541856899_item	3622266	et	3	main
kuid	doc_536541856899_item	3622265	et	4	main
maailmale	doc_536541856899_item	3622261	et	4	main
eestimaa	doc_536541856899_item	3622259	et	4	main
tanel	doc_536541856899_item	3622250	et	4	main
gustav	doc_536541856899_item	3622269	et	4	main
paremaid	doc_536541856899_item	3622263	et	4	main
andis	doc_536541856899_item	3622260	et	3	main
sellest	doc_536541856899_item	3622257	et	4	main
palju	doc_536541856899_item	3622254	et	4	main
ja	doc_536541856899_item	3622243	et	3	main
eestis	doc_536541856899_item	3622239	et	3	main
kaasaegses	doc_536541856899_item	3622238	et	3	main
kahjuks	doc_536541856899_item	3622237	et	4	main
mõtlen	doc_536541856899_item	3622236	et	3	main
ma	doc_536541856899_item	3622235	et	3	main
käinud	doc_536541856899_item	3622224	et	4	main
oli	doc_536541856899_item	3622223	et	3	main
nõukogude	doc_536541856899_item	3622218	et	3	main
tantsukultuuri	doc_536541856899_item	3622215	et	4	main
laulu-	doc_536541856899_item	3622213	et	4	main
igas	doc_536541856899_item	3622195	et	3	main
eestlasi	doc_536541856899_item	3622192	et	3	main
eluviis	doc_536541856899_item	3622182	et	3	main
niisugune	doc_536541856899_item	3622181	et	3	main
kõva	doc_536541856899_item	3622129	et	4	main
me	doc_536541856899_item	3622114	et	4	main
rumal	doc_536541856899_item	3622113	et	3	main
tallinnasse	doc_536541856899_item	3622112	et	3	main
tuleviku	doc_536541856899_item	3622108	et	4	main
aastal	doc_536541856899_item	3622248	et	3	main
rohkem	doc_536541856899_item	3622226	et	4	main
lauluväljakule	doc_536541856899_item	3622225	et	3	main
liitu	doc_536541856899_item	3622219	et	4	main
ja	doc_536541856899_item	3622209	et	3	main
rahvas	doc_536541856899_item	3622207	et	4	main
kuidas	doc_536541856899_item	3622206	et	3	main
näide	doc_536541856899_item	3622205	et	3	main
õige	doc_536541856899_item	3622204	et	4	main
on	doc_536541856899_item	3622203	et	4	main
traditsioon	doc_536541856899_item	3622202	et	3	main
igal	doc_536541856899_item	3622193	et	3	main
oli	doc_536541856899_item	3622183	et	3	main
vale	doc_536541856899_item	3622180	et	4	main
variante	doc_536541856899_item	3622179	et	3	main
laulu	doc_536541856899_item	3622178	et	4	main
ühte	doc_536541856899_item	3622177	et	4	main
palju	doc_536541856899_item	3622176	et	4	main
lihtsalt	doc_536541856899_item	3622175	et	4	main
on	doc_536541856899_item	3622174	et	4	main
eestlastel	doc_536541856899_item	3622173	et	4	main
sest	doc_536541856899_item	3622172	et	4	main
vähe	doc_536541856899_item	3622171	et	3	main
liiga	doc_536541856899_item	3622170	et	4	main
oli	doc_536541856899_item	3622169	et	3	main
tihendus	doc_536541856899_item	3622168	et	4	main
rahvastiku	doc_536541856899_item	3622167	et	3	main
taludel	doc_536541856899_item	3622166	et	3	main
elasid	doc_536541856899_item	3622165	et	4	main
ajal	doc_536541856899_item	3622164	et	4	main
tol	doc_536541856899_item	3622163	et	3	main
kõik	doc_536541856899_item	3622162	et	4	main
et	doc_536541856899_item	3622161	et	3	main
sellega	doc_536541856899_item	3622160	et	3	main
seda	doc_536541856899_item	3622159	et	3	main
rahvalaul	doc_536541856899_item	3622141	et	4	main
eestlasteks	doc_536541856899_item	3622140	et	4	main
eestlaseid	doc_536541856899_item	3622139	et	3	main
tegi	doc_536541856899_item	3622138	et	4	main
rahandus	doc_536541856899_item	3622137	et	3	main
mitte	doc_536541856899_item	3622136	et	3	main
muinasajadelt	doc_536541856899_item	3622135	et	4	main
tuli	doc_536541856899_item	3622134	et	4	main
keel	doc_536541856899_item	3622133	et	4	main
kogu	doc_536541856899_item	3622131	et	4	main
võis	doc_536541856899_item	3622123	et	4	main
eest	doc_536541856899_item	3622119	et	4	main
raha	doc_536541856899_item	3622118	et	4	main
ainult	doc_536541856899_item	3622117	et	4	main
ei	doc_536541856899_item	3622115	et	4	main
ole	doc_536541856899_item	3622107	et	4	main
et	doc_536541856899_item	3622104	et	3	main
juri	doc_536541856899_item	3622100	et	4	main
ka	doc_536541856899_item	3622099	et	3	main
meie	doc_536541856899_item	3622094	et	4	main
et	doc_536541856899_item	3622093	et	3	main
tähendab	doc_536541856899_item	3622092	et	3	main
elada	doc_536541856899_item	3622085	et	3	main
palju	doc_536541856899_item	3622081	et	4	main
eestis	doc_536541856899_item	3622078	et	3	main
mina	doc_536541856899_item	3622065	et	4	main
osta	doc_536541856899_item	3622060	et	4	main
ei	doc_536541856899_item	3622057	et	4	main
küll	doc_536541856899_item	3622056	et	4	main
mitte	doc_536541856899_item	3622050	et	3	main
oma	doc_536541856899_item	3622046	et	4	main
lihtinimene	doc_536541856899_item	3622043	et	3	main
kuningas	doc_536541856899_item	3622037	et	4	main
või	doc_536541856899_item	3622036	et	4	main
pärsia	doc_536541856899_item	3622029	et	4	main
väiteid	doc_536541856899_item	3622017	et	4	main
faktidele	doc_536541856899_item	3622016	et	3	main
tuginema	doc_536541856899_item	3622011	et	3	main
essee	doc_536541856899_item	3622004	et	4	main
ei	doc_536541856902_item	3622652	et	4	main
selline	doc_536541856902_item	3622645	et	4	main
mulle	doc_536541856902_item	3622642	et	4	main
elavad	doc_536541856902_item	3622638	et	4	main
kaasa	doc_536541856902_item	3622636	et	4	main
kooridega	doc_536541856902_item	3622635	et	3	main
kõik	doc_536541856902_item	3622628	et	4	main
et	doc_536541856902_item	3622627	et	3	main
tunnevad	doc_536541856902_item	3622626	et	3	main
nad	doc_536541856902_item	3622625	et	3	main
siin	doc_536541856902_item	3622624	et	4	main
ja	doc_536541856902_item	3622623	et	3	main
laulupeod	doc_536541856902_item	3622610	et	4	main
rahvamuusikast	doc_536541856902_item	3622595	et	4	main
vahel	doc_536541856902_item	3622586	et	4	main
noorte	doc_536541856902_item	3622585	et	3	main
on	doc_536541856902_item	3622557	et	4	main
tänapäeval	doc_536541856902_item	3622550	et	3	main
et	doc_536541856902_item	3622544	et	3	main
võib	doc_536541856902_item	3622542	et	3	main
ajal	doc_536541856902_item	3622541	et	4	main
taasiseseisvimise	doc_536541856902_item	3622540	et	4	main
mängis	doc_536541856902_item	3622539	et	3	main
traditsioon	doc_536541856902_item	3622538	et	3	main
rahvalaulu	doc_536541856902_item	3622537	et	4	main
oma	doc_536541856902_item	3622423	et	4	main
loodustingimused	doc_536541856902_item	3622411	et	3	main
kus	doc_536541856902_item	3622410	et	3	main
maal	doc_536541856902_item	3622409	et	4	main
tööga	doc_536541856902_item	3622408	et	3	main
füüsilise	doc_536541856902_item	3622407	et	3	main
põlveni	doc_536541856902_item	3622395	et	4	main
vanaaegne	doc_536541856902_item	3622391	et	3	main
eestlased	doc_536541856902_item	3622389	et	3	main
illustreerida	doc_536541856902_item	3622387	et	3	main
on	doc_536541856902_item	3622385	et	4	main
väiteid	doc_536541856902_item	3622384	et	4	main
faktidele	doc_536541856902_item	3622383	et	3	main
arutlev	doc_536541856902_item	3622374	et	4	main
keele	doc_536541856902_item	3622353	et	4	main
laulutraditsioonita	doc_536541856899_item	3622130	et	3	main
mis	doc_536541856899_item	3622122	et	4	main
mõtlema	doc_536541856899_item	3622121	et	3	main
tuleb	doc_536541856899_item	3622120	et	3	main
kõik	doc_536541856899_item	3622111	et	4	main
juba	doc_536541856899_item	3622103	et	3	main
mõis	doc_536541856899_item	3622101	et	3	main
halvemaks	doc_536541856899_item	3622098	et	4	main
sellepärast	doc_536541856899_item	3622097	et	3	main
kas	doc_536541856899_item	3622090	et	3	main
aga	doc_536541856899_item	3622089	et	3	main
gaasi	doc_536541856899_item	3622084	et	4	main
või	doc_536541856899_item	3622083	et	4	main
nafta	doc_536541856899_item	3622082	et	4	main
tean	doc_536541856899_item	3622077	et	3	main
kultuur	doc_536541856899_item	3622072	et	3	main
rahva	doc_536541856899_item	3622071	et	3	main
alati	doc_536541856899_item	3622067	et	4	main
ise	doc_536541856899_item	3622066	et	4	main
raha	doc_536541856899_item	3622061	et	4	main
aga	doc_536541856899_item	3622055	et	3	main
tänapäeval	doc_536541856899_item	3622054	et	3	main
olulised	doc_536541856899_item	3622053	et	4	main
on	doc_536541856899_item	3622052	et	4	main
elust	doc_536541856899_item	3622047	et	3	main
kulla	doc_536541856899_item	3622039	et	4	main
ujub	doc_536541856899_item	3622038	et	3	main
peab	doc_536541856899_item	3622005	et	4	main
laulava	doc_536541856902_item	3622659	et	4	main
olla	doc_536541856902_item	3622657	et	3	main
ja	doc_536541856902_item	3622654	et	3	main
traditsioon	doc_536541856902_item	3622649	et	3	main
ja	doc_536541856902_item	3622647	et	3	main
tuntub	doc_536541856902_item	3622643	et	4	main
kaasa	doc_536541856902_item	3622641	et	4	main
laulavad	doc_536541856902_item	3622634	et	4	main
inimesed	doc_536541856902_item	3622633	et	3	main
siin	doc_536541856902_item	3622632	et	4	main
perega	doc_536541856902_item	3622620	et	3	main
laulupeole	doc_536541856902_item	3622617	et	4	main
tugevamaks	doc_536541856902_item	3622616	et	4	main
rahvasümboliks	doc_536541856902_item	3622609	et	4	main
uhkendada	doc_536541856902_item	3622601	et	4	main
teadlikust	doc_536541856902_item	3622594	et	4	main
öelda	doc_536541856902_item	3622593	et	4	main
võib	doc_536541856902_item	3622592	et	3	main
ka	doc_536541856902_item	3622584	et	3	main
suurt	doc_536541856899_item	3622128	et	3	main
ilma	doc_536541856899_item	3622127	et	4	main
ei	doc_536541856899_item	3622106	et	4	main
eest	doc_536541856899_item	3622064	et	4	main
vaidlen	doc_536541856899_item	3622051	et	3	main
üldse	doc_536541856899_item	3622048	et	3	main
nuta	doc_536541856899_item	3622045	et	4	main
ei	doc_536541856899_item	3622044	et	4	main
ka	doc_536541856899_item	3622042	et	3	main
kuid	doc_536541856899_item	3622041	et	4	main
emir	doc_536541856899_item	3622035	et	4	main
üsna	doc_536541856899_item	3622033	et	3	main
on	doc_536541856899_item	3622032	et	4	main
riikidest	doc_536541856899_item	3622023	et	3	main
näidetega	doc_536541856899_item	3622021	et	3	main
esitatud	doc_536541856899_item	3622015	et	4	main
lugemistekstis	doc_536541856899_item	3622014	et	3	main
üldistav	doc_536541856899_item	3622010	et	4	main
jätkavad	doc_536541856902_item	3622656	et	4	main
eestlase	doc_536541856902_item	3622655	et	3	main
surene	doc_536541856902_item	3622653	et	4	main
vana	doc_536541856902_item	3622648	et	4	main
teisega	doc_536541856902_item	3622640	et	4	main
on	doc_536541856902_item	3622630	et	4	main
rahvas	doc_536541856902_item	3622629	et	4	main
või	doc_536541856902_item	3622621	et	4	main
kogu	doc_536541856902_item	3622619	et	4	main
tuuakse	doc_536541856902_item	3622618	et	3	main
kujunenud	doc_536541856902_item	3622608	et	4	main
nad	doc_536541856902_item	3622607	et	3	main
traditsioonidega	doc_536541856902_item	3622606	et	3	main
oma	doc_536541856902_item	3622602	et	4	main
julgelt	doc_536541856902_item	3622600	et	4	main
arvates	doc_536541856902_item	3622597	et	4	main
minu	doc_536541856902_item	3622596	et	3	main
loovad	doc_536541856902_item	3622588	et	4	main
noored	doc_536541856902_item	3622587	et	3	main
on	doc_536541856902_item	3622582	et	4	main
rahvamuusika	doc_536541856902_item	3622556	et	4	main
ja	doc_536541856902_item	3622555	et	3	main
inimesi	doc_536541856902_item	3622554	et	4	main
palju	doc_536541856902_item	3622553	et	4	main
ka	doc_536541856902_item	3622549	et	3	main
teine	doc_536541856902_item	3622547	et	3	main
öelda	doc_536541856902_item	3622543	et	4	main
raske	doc_536541856902_item	3622533	et	4	main
veel	doc_536541856902_item	3622529	et	4	main
on	doc_536541856902_item	3622528	et	4	main
siin	doc_536541856902_item	3622523	et	4	main
vanaajal	doc_536541856902_item	3622428	et	3	main
juba	doc_536541856902_item	3622427	et	3	main
teha	doc_536541856902_item	3622426	et	3	main
tööd	doc_536541856902_item	3622425	et	4	main
rasket	doc_536541856902_item	3622424	et	3	main
laul	doc_536541856902_item	3622420	et	4	main
sellepärast	doc_536541856902_item	3622419	et	3	main
taime	doc_536541856902_item	3622418	et	4	main
vajaliku	doc_536541856902_item	3622417	et	3	main
kasvada	doc_536541856902_item	3622416	et	4	main
et	doc_536541856902_item	3622415	et	3	main
meeldis	doc_536541856902_item	3622402	et	3	main
et	doc_536541856902_item	3622400	et	3	main
oli	doc_536541856902_item	3622398	et	3	main
esitatud	doc_536541856902_item	3622382	et	4	main
lugemistekstis	doc_536541856902_item	3622381	et	3	main
ja	doc_536541856902_item	3622380	et	3	main
loengus	doc_536541856902_item	3622379	et	3	main
tuginema	doc_536541856902_item	3622378	et	3	main
pikkus	doc_536541856902_item	3622367	et	4	main
tsaristliku	doc_536541856902_item	3622520	et	3	main
lapsed	doc_536541856902_item	3622519	et	3	main
mehed	doc_536541856902_item	3622514	et	3	main
laulutraditsiooniks	doc_536541856902_item	3622504	et	3	main
korraldama	doc_536541856902_item	3622497	et	3	main
laulud	doc_536541856902_item	3622492	et	3	main
enamasti	doc_536541856902_item	3622490	et	4	main
laulud	doc_536541856902_item	3622479	et	3	main
laulutüüpiga	doc_536541856902_item	3622468	et	4	main
paigani	doc_536541856902_item	3622462	et	3	main
lõbusa	doc_536541856902_item	3622443	et	3	main
laulmise	doc_536541856905_item	3622948	et	4	main
rääkib	doc_536541856899_item	3622102	et	4	main
tihti	doc_536541856899_item	3622087	et	3	main
ei	doc_536541856899_item	3622079	et	4	main
või	doc_536541856899_item	3622062	et	4	main
saa	doc_536541856899_item	3622058	et	4	main
materiaalväärtused	doc_536541856899_item	3622049	et	3	main
sees	doc_536541856899_item	3622040	et	4	main
riigid	doc_536541856899_item	3622031	et	3	main
lahe	doc_536541856899_item	3622030	et	4	main
tihti	doc_536541856899_item	3622024	et	3	main
loengus	doc_536541856899_item	3622012	et	3	main
ja	doc_536541856899_item	3622009	et	3	main
arutlev	doc_536541856899_item	3622007	et	4	main
olema	doc_536541856899_item	3622006	et	4	main
pikkus	doc_536541856899_item	3622000	et	4	main
essee	doc_536541856899_item	3621999	et	4	main
laulurahva	doc_536541856899_item	3621998	et	3	main
eestlastest	doc_536541856899_item	3621997	et	4	main
teeb	doc_536541856899_item	3621996	et	3	main
mis	doc_536541856899_item	3621995	et	4	main
teemal	doc_536541856899_item	3621994	et	3	main
essee	doc_536541856899_item	3621993	et	4	main
kirjutage	doc_536541856899_item	3621992	et	3	main
test	doc_536541856899_item	3621990	et	3	main
keele	doc_536541856899_item	3621989	et	4	main
teise	doc_536541856899_item	3621988	et	4	main
kirjutamine	doc_536541856899_item	3621991	et	4	main
kui	doc_536541856899_item	3621987	et	3	main
keele	doc_536541856899_item	3621986	et	4	main
eesti	doc_536541856899_item	3621985	et	4	main
essee	doc_536541856899_item	3621984	et	4	main
defineerida	doc_536541856899_item	3622158	et	3	main
küll	doc_536541856899_item	3622157	et	4	main
võib	doc_536541856899_item	3622156	et	3	main
maailmas	doc_536541856899_item	3622155	et	3	main
rahvalaulu	doc_536541856899_item	3622154	et	4	main
rohkem	doc_536541856899_item	3622153	et	4	main
on	doc_536541856899_item	3622152	et	4	main
eestlastel	doc_536541856899_item	3622151	et	4	main
miks	doc_536541856899_item	3622150	et	4	main
huvitas	doc_536541856899_item	3622149	et	3	main
alati	doc_536541856899_item	3622148	et	4	main
mind	doc_536541856899_item	3622147	et	4	main
seda	doc_536541856899_item	3622146	et	3	main
tegi	doc_536541856899_item	3622145	et	4	main
arvates	doc_536541856899_item	3622144	et	4	main
minu	doc_536541856899_item	3622143	et	3	main
rahvatants	doc_536541856899_item	3622142	et	3	main
rahvaga	doc_536541856902_item	3622660	et	3	main
kõige	doc_536541856902_item	3622658	et	4	main
kunagi	doc_536541856902_item	3622651	et	3	main
rikad	doc_536541856899_item	3622034	et	4	main
kõigepealt	doc_536541856899_item	3622028	et	3	main
sellised	doc_536541856899_item	3622027	et	4	main
et	doc_536541856899_item	3622026	et	3	main
kirjutatakse	doc_536541856899_item	3622025	et	3	main
lähim-ida	doc_536541856899_item	3622022	et	4	main
illustreerida	doc_536541856899_item	3622020	et	3	main
soovitatav	doc_536541856899_item	3622019	et	4	main
on	doc_536541856899_item	3622018	et	4	main
ja	doc_536541856899_item	3622013	et	3	main
analüüsiv	doc_536541856899_item	3622008	et	4	main
sõna	doc_536541856899_item	3622003	et	4	main
350	doc_536541856899_item	3622002	et	2	main
300	doc_536541856899_item	3622001	et	2	main
mitte	doc_536541856902_item	3622650	et	3	main
tugev	doc_536541856902_item	3622646	et	4	main
teine	doc_536541856902_item	3622639	et	3	main
ja	doc_536541856902_item	3622637	et	3	main
tema	doc_536541856902_item	3622615	et	4	main
teevad	doc_536541856902_item	3622614	et	3	main
ja	doc_536541856902_item	3622613	et	3	main
rahva	doc_536541856902_item	3622612	et	3	main
rahvamuusika	doc_536541856902_item	3622605	et	4	main
ja	doc_536541856902_item	3622604	et	3	main
populaarsed	doc_536541856902_item	3622583	et	3	main
tants	doc_536541856902_item	3622581	et	3	main
rahva	doc_536541856902_item	3622580	et	3	main
ja	doc_536541856902_item	3622579	et	3	main
rahvamuusika	doc_536541856902_item	3622578	et	4	main
stiili	doc_536541856902_item	3622577	et	4	main
tema	doc_536541856902_item	3622576	et	4	main
või	doc_536541856902_item	3622575	et	4	main
rahvamuusikat	doc_536541856902_item	3622574	et	3	main
loominguses	doc_536541856902_item	3622573	et	4	main
oma	doc_536541856902_item	3622572	et	4	main
kasutavad	doc_536541856902_item	3622571	et	4	main
heliloojad	doc_536541856902_item	3622570	et	3	main
eesti	doc_536541856902_item	3622569	et	4	main
paljud	doc_536541856902_item	3622568	et	3	main
ka	doc_536541856902_item	3622567	et	3	main
rahvalaule	doc_536541856902_item	3622566	et	4	main
laulavad	doc_536541856902_item	3622565	et	4	main
mis	doc_536541856902_item	3622564	et	4	main
vokaalansamble	doc_536541856902_item	3622563	et	4	main
palju	doc_536541856902_item	3622562	et	4	main
on	doc_536541856902_item	3622561	et	4	main
eestis	doc_536541856902_item	3622560	et	3	main
väga	doc_536541856902_item	3622558	et	3	main
laulupidudes	doc_536541856902_item	3622551	et	4	main
oli	doc_536541856902_item	3622546	et	3	main
oli	doc_536541856902_item	3622532	et	3	main
loa	doc_536541856902_item	3622530	et	4	main
mis	doc_536541856902_item	3622527	et	4	main
ole	doc_536541856902_item	3622413	et	4	main
eestlased	doc_536541856902_item	3622404	et	3	main
nendele	doc_536541856902_item	3622401	et	4	main
ja	doc_536541856902_item	3622393	et	3	main
et	doc_536541856902_item	3622644	et	3	main
koos	doc_536541856902_item	3622631	et	4	main
sõbradega	doc_536541856902_item	3622622	et	4	main
ühenevad	doc_536541856902_item	3622611	et	4	main
rahvalaulu-	doc_536541856902_item	3622603	et	4	main
võivad	doc_536541856902_item	3622599	et	4	main
eestlased	doc_536541856902_item	3622598	et	3	main
siin	doc_536541856902_item	3622591	et	4	main
ja	doc_536541856902_item	3622590	et	3	main
ansambleid	doc_536541856902_item	3622589	et	3	main
populaarne	doc_536541856902_item	3622559	et	3	main
osalevad	doc_536541856902_item	3622552	et	4	main
see	doc_536541856902_item	3622545	et	3	main
rolli	doc_536541856902_item	3622536	et	4	main
suur	doc_536541856902_item	3622535	et	3	main
eriti	doc_536541856902_item	3622534	et	3	main
nendele	doc_536541856902_item	3622422	et	4	main
head	doc_536541856902_item	3622414	et	4	main
raske	doc_536541856902_item	3622406	et	4	main
tegelesid	doc_536541856902_item	3622405	et	4	main
põlvest	doc_536541856902_item	3622394	et	4	main
on	doc_536541856902_item	3622390	et	4	main
näidetega	doc_536541856902_item	3622388	et	3	main
üldistav	doc_536541856902_item	3622377	et	4	main
ja	doc_536541856902_item	3622376	et	3	main
olema	doc_536541856902_item	3622373	et	4	main
essee	doc_536541856902_item	3622371	et	4	main
sõna	doc_536541856902_item	3622370	et	4	main
350	doc_536541856902_item	3622369	et	2	main
300	doc_536541856902_item	3622368	et	2	main
essee	doc_536541856902_item	3622366	et	4	main
eestlastest	doc_536541856902_item	3622364	et	4	main
teeb	doc_536541856902_item	3622363	et	3	main
mis	doc_536541856902_item	3622362	et	4	main
teemal	doc_536541856902_item	3622361	et	3	main
essee	doc_536541856902_item	3622360	et	4	main
kirjutage	doc_536541856902_item	3622359	et	3	main
eesti	doc_536541856902_item	3622352	et	4	main
venemaa	doc_536541856902_item	3622521	et	4	main
ja	doc_536541856902_item	3622518	et	3	main
ka	doc_536541856902_item	3622516	et	3	main
võtavad	doc_536541856902_item	3622511	et	3	main
eestilt	doc_536541856902_item	3622509	et	3	main
üle	doc_536541856902_item	3622508	et	3	main
koorid	doc_536541856902_item	3622507	et	4	main
eesti	doc_536541856902_item	3622502	et	4	main
muutusid	doc_536541856902_item	3622501	et	4	main
laulupeod	doc_536541856902_item	3622500	et	4	main
algati	doc_536541856902_item	3622496	et	3	main
kirikutega	doc_536541856902_item	3622483	et	4	main
sõnad	doc_536541856902_item	3622472	et	4	main
regilaulus	doc_536541856902_item	3622471	et	3	main
oli	doc_536541856902_item	3622469	et	3	main
pea	doc_536541856902_item	3622467	et	4	main
ajal	doc_536541856902_item	3622466	et	4	main
sel	doc_536541856902_item	3622465	et	3	main
näiteks	doc_536541856902_item	3622454	et	4	main
traditsiooniks	doc_536541856902_item	3622453	et	3	main
eeslaulja	doc_536541856902_item	3622438	et	4	main
oli	doc_536541856902_item	3622436	et	3	main
tihti	doc_536541856902_item	3622435	et	3	main
ka	doc_536541856902_item	3622437	et	3	main
kus	doc_536541856902_item	3622434	et	3	main
naiskoorid	doc_536541856902_item	3622433	et	3	main
ja	doc_536541856902_item	3622432	et	3	main
mees-	doc_536541856902_item	3622431	et	4	main
olid	doc_536541856902_item	3622430	et	4	main
eestlastel	doc_536541856902_item	3622429	et	4	main
ärkamisaeg	doc_536541856902_item	3622548	et	3	main
saamine	doc_536541856902_item	3622531	et	4	main
meeskoorid	doc_536541856902_item	3622526	et	4	main
ainult	doc_536541856902_item	3622525	et	4	main
osalesid	doc_536541856902_item	3622524	et	4	main
abistas	doc_536541856902_item	3622421	et	3	main
ei	doc_536541856902_item	3622412	et	4	main
laulda	doc_536541856902_item	3622403	et	4	main
selline	doc_536541856902_item	3622399	et	4	main
rahvaerilisus	doc_536541856902_item	3622397	et	4	main
eestlaste	doc_536541856902_item	3622396	et	4	main
maarahvas	doc_536541856902_item	3622392	et	4	main
soovitatav	doc_536541856902_item	3622386	et	4	main
analüüsiv	doc_536541856902_item	3622375	et	4	main
peab	doc_536541856902_item	3622372	et	4	main
kirjutamine	doc_536541856902_item	3622358	et	4	main
test	doc_536541856902_item	3622357	et	3	main
essee	doc_536541856902_item	3622351	et	4	main
naised	doc_536541856902_item	3622517	et	3	main
kui	doc_536541856902_item	3622515	et	3	main
osa	doc_536541856902_item	3622512	et	4	main
sõidavad	doc_536541856902_item	3622506	et	3	main
laulupeole	doc_536541856902_item	3622505	et	4	main
pea	doc_536541856902_item	3622503	et	4	main
laulupidusid	doc_536541856902_item	3622498	et	4	main
riimilised	doc_536541856902_item	3622491	et	4	main
arenevad	doc_536541856902_item	3622489	et	4	main
tänapäeval	doc_536541856902_item	3622488	et	3	main
poistekoorid	doc_536541856902_item	3622487	et	3	main
lauldi	doc_536541856902_item	3622486	et	3	main
neid	doc_536541856902_item	3622485	et	4	main
kus	doc_536541856902_item	3622484	et	3	main
on	doc_536541856902_item	3622481	et	4	main
riimilised	doc_536541856902_item	3622478	et	4	main
eestisse	doc_536541856902_item	3622476	et	4	main
hiljem	doc_536541856902_item	3622475	et	3	main
samatähega	doc_536541856902_item	3622474	et	3	main
algavad	doc_536541856902_item	3622473	et	4	main
pulmast	doc_536541856902_item	3622463	et	4	main
käisid	doc_536541856902_item	3622460	et	4	main
pulmalauljad	doc_536541856902_item	3622458	et	3	main
olid	doc_536541856902_item	3622457	et	4	main
populaarsed	doc_536541856902_item	3622456	et	3	main
eriti	doc_536541856902_item	3622455	et	3	main
teised	doc_536541856902_item	3622446	et	4	main
ja	doc_536541856902_item	3622442	et	3	main
laulurahvaks	doc_536541856905_item	3622962	et	3	main
võiks	doc_536541856905_item	3622960	et	4	main
on	doc_536541856905_item	3622942	et	4	main
hulgas	doc_536541856905_item	3622941	et	4	main
korraldajad	doc_536541856905_item	3622939	et	4	main
ja	doc_536541856905_item	3622937	et	3	main
folkloorifestivaalide	doc_536541856905_item	3622936	et	4	main
ka	doc_536541856905_item	3622935	et	3	main
rahvamuusikat	doc_536541856905_item	3622927	et	3	main
lindistusi	doc_536541856905_item	3622905	et	4	main
leida	doc_536541856905_item	3622902	et	3	main
ja	doc_536541856905_item	3622899	et	3	main
inimesed	doc_536541856905_item	3622896	et	3	main
paljud	doc_536541856905_item	3622895	et	3	main
traditsioon	doc_536541856905_item	3622890	et	3	main
laulda	doc_536541856905_item	3622882	et	4	main
armastavad	doc_536541856905_item	3622881	et	4	main
ja	doc_536541856905_item	3622880	et	3	main
palju	doc_536541856905_item	3622870	et	4	main
eesti	doc_536541856905_item	3622866	et	4	main
rahvapidu	doc_536541856905_item	3622861	et	4	main
suur	doc_536541856905_item	3622860	et	3	main
sai	doc_536541856905_item	3622854	et	4	main
ka	doc_536541856905_item	3622849	et	3	main
kui	doc_536541856905_item	3622832	et	3	main
näiteks	doc_536541856905_item	3622831	et	4	main
ärkamisajal	doc_536541856905_item	3622814	et	3	main
palju	doc_536541856905_item	3622792	et	4	main
nende	doc_536541856905_item	3622789	et	4	main
seepärast	doc_536541856905_item	3622788	et	3	main
palju	doc_536541856905_item	3622785	et	4	main
ka	doc_536541856905_item	3622759	et	3	main
hakkati	doc_536541856905_item	3622758	et	3	main
pärast	doc_536541856905_item	3622757	et	4	main
aga	doc_536541856905_item	3622756	et	3	main
laulurahva	doc_536541856902_item	3622365	et	3	main
keele	doc_536541856902_item	3622356	et	4	main
teise	doc_536541856902_item	3622355	et	4	main
kui	doc_536541856902_item	3622354	et	3	main
ajal	doc_536541856902_item	3622522	et	4	main
nii	doc_536541856902_item	3622513	et	3	main
ülemaalised	doc_536541856902_item	3622499	et	4	main
1869	doc_536541856902_item	3622494	et	2	main
alates	doc_536541856902_item	3622493	et	3	main
nad	doc_536541856902_item	3622480	et	3	main
tulid	doc_536541856902_item	3622477	et	4	main
pulmani	doc_536541856902_item	3622464	et	4	main
ja	doc_536541856902_item	3622450	et	3	main
kaasa	doc_536541856902_item	3622449	et	4	main
laulsid	doc_536541856902_item	3622448	et	4	main
inimesed	doc_536541856902_item	3622447	et	3	main
sündmuste	doc_536541856902_item	3622444	et	3	main
kurba	doc_536541856902_item	3622441	et	4	main
laulsid	doc_536541856902_item	3622440	et	4	main
koorid	doc_536541856902_item	3622439	et	4	main
nimetada	doc_536541856905_item	3622963	et	3	main
tõeliselt	doc_536541856905_item	3622961	et	4	main
laulavad	doc_536541856905_item	3622957	et	4	main
surra	doc_536541856905_item	3622951	et	3	main
ei	doc_536541856905_item	3622950	et	4	main
traditsioon	doc_536541856905_item	3622949	et	3	main
ei	doc_536541856905_item	3622929	et	4	main
ja	doc_536541856905_item	3622928	et	3	main
või	doc_536541856905_item	3622907	et	4	main
et	doc_536541856905_item	3622901	et	3	main
raamatukogudes	doc_536541856905_item	3622898	et	3	main
laulupidudega	doc_536541856905_item	3622894	et	4	main
ainult	doc_536541856905_item	3622893	et	4	main
et	doc_536541856905_item	3622888	et	3	main
on	doc_536541856905_item	3622885	et	4	main
kogu	doc_536541856905_item	3622872	et	4	main
rahvast	doc_536541856905_item	3622871	et	4	main
eesti	doc_536541856905_item	3622856	et	4	main
ja	doc_536541856905_item	3622851	et	3	main
isamalaul	doc_536541856905_item	3622841	et	4	main
vallandasid	doc_536541856905_item	3622833	et	4	main
on	doc_536541856905_item	3622826	et	4	main
see	doc_536541856905_item	3622825	et	3	main
neid	doc_536541856905_item	3622817	et	4	main
meres	doc_536541856905_item	3622787	et	3	main
veedasid	doc_536541856905_item	3622784	et	4	main
mehed	doc_536541856905_item	3622783	et	3	main
ja	doc_536541856905_item	3622749	et	3	main
see	doc_536541856905_item	3622746	et	3	main
lõbus	doc_536541856905_item	3622741	et	4	main
oli	doc_536541856905_item	3622738	et	3	main
kui	doc_536541856905_item	3622736	et	3	main
ja	doc_536541856905_item	3622734	et	3	main
tööl	doc_536541856905_item	3622733	et	3	main
laulsid	doc_536541856905_item	3622732	et	4	main
väljenduda	doc_536541856905_item	3622730	et	3	main
laulmine	doc_536541856905_item	3622718	et	4	main
rahvalauludel	doc_536541856905_item	3622717	et	3	main
nimetati	doc_536541856905_item	3622705	et	4	main
eestlasi	doc_536541856905_item	3622704	et	3	main
laulurahva	doc_536541856905_item	3622703	et	3	main
väiteid	doc_536541856905_item	3622695	et	4	main
faktidele	doc_536541856905_item	3622694	et	3	main
olema	doc_536541856905_item	3622684	et	4	main
pikkus	doc_536541856905_item	3622678	et	4	main
eestlastest	doc_536541856905_item	3622675	et	4	main
neile	doc_536541856906_item	3623286	et	4	main
ja	doc_536541856906_item	3623280	et	3	main
ainuke	doc_536541856906_item	3623247	et	4	main
ja	doc_536541856906_item	3623244	et	3	main
rahvalaulu	doc_536541856906_item	3623240	et	4	main
laulupeol	doc_536541856906_item	3623238	et	4	main
eestis	doc_536541856906_item	3623237	et	3	main
manifestatsioon	doc_536541856906_item	3623236	et	3	main
rahvulise	doc_536541856906_item	3623235	et	4	main
nad	doc_536541856906_item	3623229	et	3	main
sai	doc_536541856906_item	3623221	et	4	main
end	doc_536541856906_item	3623217	et	4	main
tundis	doc_536541856906_item	3623216	et	3	main
pidudes	doc_536541856902_item	3622510	et	4	main
aastalt	doc_536541856902_item	3622495	et	3	main
seotud	doc_536541856902_item	3622482	et	4	main
regilaul	doc_536541856902_item	3622470	et	4	main
paigast	doc_536541856902_item	3622461	et	4	main
kes	doc_536541856902_item	3622459	et	4	main
muutus	doc_536541856902_item	3622452	et	4	main
see	doc_536541856902_item	3622451	et	3	main
puhul	doc_536541856902_item	3622445	et	4	main
neid	doc_536541856905_item	3622959	et	4	main
ja	doc_536541856905_item	3622956	et	3	main
palju	doc_536541856905_item	3622944	et	4	main
tegelevad	doc_536541856905_item	3622934	et	4	main
sellega	doc_536541856905_item	3622933	et	3	main
surra	doc_536541856905_item	3622932	et	3	main
seda	doc_536541856905_item	3622931	et	3	main
anda	doc_536541856905_item	3622930	et	3	main
et	doc_536541856905_item	3622924	et	3	main
aru	doc_536541856905_item	3622923	et	4	main
saavad	doc_536541856905_item	3622921	et	4	main
mõju	doc_536541856905_item	3622912	et	4	main
rahvamuusika	doc_536541856905_item	3622911	et	4	main
vanasid	doc_536541856905_item	3622904	et	3	main
mingeid	doc_536541856905_item	3622903	et	3	main
arhiivides	doc_536541856905_item	3622900	et	3	main
käivad	doc_536541856905_item	3622897	et	4	main
ei	doc_536541856905_item	3622891	et	4	main
oskavad	doc_536541856905_item	3622879	et	4	main
eestlased	doc_536541856905_item	3622878	et	3	main
kui	doc_536541856905_item	3622877	et	3	main
näitab	doc_536541856905_item	3622876	et	3	main
ka	doc_536541856905_item	3622869	et	3	main
mitte	doc_536541856905_item	3622864	et	3	main
kuhu	doc_536541856905_item	3622862	et	3	main
tantsupeod	doc_536541856905_item	3622852	et	4	main
toimuvad	doc_536541856905_item	3622848	et	4	main
tänapäeval	doc_536541856905_item	3622847	et	3	main
arm	doc_536541856905_item	3622846	et	3	main
minu	doc_536541856905_item	3622845	et	3	main
ernesaksa	doc_536541856905_item	3622839	et	4	main
ajaloost	doc_536541856905_item	3622830	et	4	main
kõik	doc_536541856905_item	3622824	et	4	main
tulevikule	doc_536541856905_item	3622823	et	4	main
iseseisvale	doc_536541856905_item	3622822	et	3	main
aitas	doc_536541856905_item	3622816	et	3	main
laulsid	doc_536541856905_item	3622812	et	4	main
laulsid	doc_536541856905_item	3622791	et	4	main
naised	doc_536541856905_item	3622790	et	3	main
ajal	doc_536541856905_item	3622744	et	4	main
lauldi	doc_536541856905_item	3622742	et	3	main
tegevus	doc_536541856905_item	3622723	et	4	main
emotsionaalne	doc_536541856905_item	3622722	et	3	main
ja	doc_536541856905_item	3622721	et	3	main
on	doc_536541856905_item	3622715	et	4	main
arvame	doc_536541856905_item	3622711	et	3	main
miks	doc_536541856905_item	3622709	et	4	main
ja	doc_536541856905_item	3622691	et	3	main
üldistav	doc_536541856905_item	3622688	et	4	main
ja	doc_536541856905_item	3622687	et	3	main
essee	doc_536541856905_item	3622677	et	4	main
teeb	doc_536541856905_item	3622674	et	3	main
ja	doc_536541856905_item	3622958	et	3	main
laulsid	doc_536541856905_item	3622955	et	4	main
alati	doc_536541856905_item	3622954	et	4	main
eestlased	doc_536541856905_item	3622953	et	3	main
kunagi	doc_536541856905_item	3622952	et	3	main
väga	doc_536541856905_item	3622943	et	3	main
kelle	doc_536541856905_item	3622940	et	4	main
kokkutulekute	doc_536541856905_item	3622938	et	3	main
kasutavad	doc_536541856905_item	3622926	et	4	main
tunduv	doc_536541856905_item	3622914	et	4	main
on	doc_536541856905_item	3622913	et	4	main
peale	doc_536541856905_item	3622909	et	4	main
muud	doc_536541856905_item	3622908	et	4	main
piirandatud	doc_536541856905_item	3622892	et	4	main
see	doc_536541856905_item	3622887	et	3	main
veel	doc_536541856905_item	3622886	et	4	main
tähtsam	doc_536541856905_item	3622884	et	4	main
kõige	doc_536541856905_item	3622883	et	4	main
pidu	doc_536541856905_item	3622875	et	4	main
see	doc_536541856905_item	3622874	et	3	main
maailmast	doc_536541856905_item	3622873	et	4	main
aga	doc_536541856905_item	3622868	et	3	main
ainult	doc_536541856905_item	3622865	et	4	main
et	doc_536541856905_item	3622947	et	3	main
arvan	doc_536541856905_item	3622946	et	3	main
noori	doc_536541856905_item	3622945	et	3	main
nad	doc_536541856905_item	3622925	et	3	main
isegi	doc_536541856905_item	3622922	et	4	main
ei	doc_536541856905_item	3622920	et	4	main
heliloojad	doc_536541856905_item	3622919	et	3	main
kaasaegsed	doc_536541856905_item	3622918	et	3	main
tihti	doc_536541856905_item	3622917	et	3	main
pop-muusikas	doc_536541856905_item	3622916	et	3	main
ka	doc_536541856905_item	3622915	et	3	main
selle	doc_536541856905_item	3622910	et	4	main
pilte	doc_536541856905_item	3622906	et	3	main
rahvalaulu	doc_536541856905_item	3622889	et	4	main
elanikud	doc_536541856905_item	3622867	et	3	main
suuremaks	doc_536541856905_item	3622855	et	4	main
kõlas	doc_536541856905_item	3622840	et	4	main
lootust	doc_536541856905_item	3622820	et	4	main
kaotada	doc_536541856905_item	3622819	et	3	main
mitte	doc_536541856905_item	3622818	et	3	main
mis	doc_536541856905_item	3622815	et	4	main
algus	doc_536541856905_item	3622752	et	4	main
elada	doc_536541856905_item	3622751	et	3	main
parem	doc_536541856905_item	3622748	et	4	main
ja	doc_536541856905_item	3622745	et	3	main
ja	doc_536541856905_item	3622740	et	3	main
esteetiline	doc_536541856905_item	3622720	et	3	main
on	doc_536541856905_item	3622719	et	4	main
minevik	doc_536541856905_item	3622714	et	3	main
niimoodi	doc_536541856905_item	3622712	et	3	main
eestlastest	doc_536541856905_item	3622702	et	4	main
teeb	doc_536541856905_item	3622701	et	3	main
mis	doc_536541856905_item	3622700	et	4	main
näidetega	doc_536541856905_item	3622699	et	3	main
illustreerida	doc_536541856905_item	3622698	et	3	main
soovitatav	doc_536541856905_item	3622697	et	4	main
on	doc_536541856905_item	3622696	et	4	main
analüüsiv	doc_536541856905_item	3622686	et	4	main
arutlev	doc_536541856905_item	3622685	et	4	main
laulurahva	doc_536541856905_item	3622676	et	3	main
mis	doc_536541856905_item	3622673	et	4	main
teemal	doc_536541856905_item	3622672	et	3	main
essee	doc_536541856905_item	3622671	et	4	main
kirjutage	doc_536541856905_item	3622670	et	3	main
ja	doc_536541856906_item	3623289	et	3	main
andsid	doc_536541856906_item	3623285	et	4	main
laul	doc_536541856906_item	3623279	et	4	main
end	doc_536541856906_item	3623277	et	4	main
aitas	doc_536541856906_item	3623275	et	3	main
laulu	doc_536541856906_item	3623243	et	4	main
oli	doc_536541856906_item	3623233	et	3	main
jõud	doc_536541856906_item	3623231	et	4	main
on	doc_536541856906_item	3623230	et	4	main
koos	doc_536541856906_item	3623227	et	4	main
kui	doc_536541856906_item	3623224	et	3	main
ainuke	doc_536541856906_item	3623212	et	4	main
oli	doc_536541856906_item	3623211	et	3	main
see	doc_536541856906_item	3623210	et	3	main
ajal	doc_536541856906_item	3623207	et	4	main
see	doc_536541856906_item	3623197	et	3	main
kuulajad	doc_536541856906_item	3623193	et	4	main
muidugi	doc_536541856906_item	3623192	et	4	main
ja	doc_536541856906_item	3623191	et	3	main
eeslauljad	doc_536541856906_item	3623190	et	3	main
laulsid	doc_536541856906_item	3623189	et	4	main
võtsid	doc_536541856906_item	3623183	et	4	main
elu	doc_536541856906_item	3623071	et	4	main
magas	doc_536541856906_item	3623064	et	4	main
oli	doc_536541856906_item	3623056	et	3	main
kui	doc_536541856906_item	3623054	et	3	main
laul	doc_536541856906_item	3623053	et	4	main
teadis	doc_536541856906_item	3623050	et	4	main
lapsepõlvest	doc_536541856906_item	3623049	et	4	main
inimene	doc_536541856906_item	3623048	et	3	main
iga	doc_536541856906_item	3623047	et	4	main
rahvaga	doc_536541856906_item	3623046	et	3	main
seotud	doc_536541856906_item	3623045	et	4	main
tulevad	doc_536541856905_item	3622863	et	4	main
on	doc_536541856905_item	3622859	et	4	main
laulupidu	doc_536541856905_item	3622858	et	4	main
traditsiooniks	doc_536541856905_item	3622857	et	3	main
see	doc_536541856905_item	3622853	et	3	main
laulu-	doc_536541856905_item	3622850	et	4	main
on	doc_536541856905_item	3622844	et	4	main
isamaa	doc_536541856905_item	3622843	et	4	main
mu	doc_536541856905_item	3622842	et	3	main
gustav	doc_536541856905_item	3622838	et	4	main
kui	doc_536541856905_item	3622837	et	3	main
tunded	doc_536541856905_item	3622836	et	3	main
rahvuslikud	doc_536541856905_item	3622835	et	3	main
eestlaste	doc_536541856905_item	3622834	et	4	main
laulupidude	doc_536541856905_item	3622829	et	4	main
nähtav	doc_536541856905_item	3622828	et	4	main
hästi	doc_536541856905_item	3622827	et	3	main
paremale	doc_536541856905_item	3622821	et	4	main
rahvusliku	doc_536541856905_item	3622813	et	3	main
aega	doc_536541856905_item	3622786	et	4	main
levitatud	doc_536541856905_item	3622782	et	4	main
laiemalt	doc_536541856905_item	3622781	et	4	main
kõige	doc_536541856905_item	3622780	et	4	main
on	doc_536541856905_item	3622779	et	4	main
rahvalaul	doc_536541856905_item	3622778	et	4	main
kus	doc_536541856905_item	3622777	et	3	main
saarel	doc_536541856905_item	3622776	et	3	main
kihnu	doc_536541856905_item	3622775	et	4	main
naiteks	doc_536541856905_item	3622774	et	4	main
tegevusi	doc_536541856905_item	3622773	et	4	main
olulisemaid	doc_536541856905_item	3622772	et	4	main
erinevaid	doc_536541856905_item	3622771	et	4	main
palju	doc_536541856905_item	3622770	et	4	main
oli	doc_536541856905_item	3622769	et	3	main
meestel	doc_536541856905_item	3622768	et	4	main
nende	doc_536541856905_item	3622767	et	4	main
sest	doc_536541856905_item	3622766	et	4	main
naised	doc_536541856905_item	3622765	et	3	main
laulsid	doc_536541856905_item	3622764	et	4	main
põhiliselt	doc_536541856905_item	3622763	et	4	main
õpetama	doc_536541856905_item	3622762	et	3	main
laulu	doc_536541856905_item	3622761	et	4	main
väljaspool	doc_536541856905_item	3622760	et	3	main
kirikutes	doc_536541856905_item	3622755	et	4	main
ainult	doc_536541856905_item	3622754	et	4	main
lauldi	doc_536541856905_item	3622753	et	3	main
igal	doc_536541856905_item	3622743	et	3	main
hinge	doc_536541856905_item	3622729	et	4	main
võivad	doc_536541856905_item	3622727	et	4	main
eesti	doc_536541856905_item	3622716	et	4	main
esitatud	doc_536541856905_item	3622693	et	4	main
lugemistekstis	doc_536541856905_item	3622692	et	3	main
tuginema	doc_536541856905_item	3622689	et	3	main
essee	doc_536541856905_item	3622682	et	4	main
sõna	doc_536541856905_item	3622681	et	4	main
350	doc_536541856905_item	3622680	et	2	main
300	doc_536541856905_item	3622679	et	2	main
keele	doc_536541856905_item	3622667	et	4	main
teise	doc_536541856905_item	3622666	et	4	main
ja	doc_536541856906_item	3623284	et	3	main
ühendasid	doc_536541856906_item	3623282	et	4	main
laul	doc_536541856906_item	3623269	et	4	main
kus	doc_536541856906_item	3623249	et	3	main
koht	doc_536541856906_item	3623248	et	3	main
ja	doc_536541856906_item	3623241	et	3	main
laulsid	doc_536541856906_item	3623239	et	4	main
siis	doc_536541856906_item	3623228	et	3	main
kõik	doc_536541856906_item	3623225	et	4	main
et	doc_536541856906_item	3623223	et	3	main
kus	doc_536541856906_item	3623219	et	3	main
vaba	doc_536541856906_item	3623218	et	4	main
asi	doc_536541856906_item	3623209	et	4	main
ühendas	doc_536541856906_item	3623195	et	3	main
laul	doc_536541856906_item	3623194	et	4	main
see	doc_536541856906_item	3623079	et	3	main
on	doc_536541856906_item	3623052	et	4	main
pärast	doc_536541856906_item	3623042	et	4	main
igapäevane	doc_536541856906_item	3623038	et	4	main
pühendatud	doc_536541856906_item	3623037	et	4	main
on	doc_536541856906_item	3623036	et	4	main
rahvalaulud	doc_536541856906_item	3623035	et	3	main
laulurahva	doc_536541856906_item	3623034	et	3	main
mis	doc_536541856906_item	3623031	et	4	main
mis	doc_536541856906_item	3623003	et	4	main
olema	doc_536541856906_item	3622987	et	4	main
pikkus	doc_536541856906_item	3622981	et	4	main
keele	doc_536541856906_item	3622970	et	4	main
teise	doc_536541856906_item	3622969	et	4	main
kui	doc_536541856906_item	3622968	et	3	main
laulupeod	doc_536541856906_item	3623180	et	4	main
olid	doc_536541856906_item	3623178	et	4	main
see	doc_536541856906_item	3623177	et	3	main
on	doc_536541856906_item	3623169	et	4	main
lastele	doc_536541856906_item	3623132	et	4	main
laulama	doc_536541856906_item	3623091	et	4	main
sümboliteks	doc_536541856910_item	3623587	et	3	main
rahvuslikeks	doc_536541856910_item	3623586	et	3	main
kujunenud	doc_536541856910_item	3623585	et	4	main
et	doc_536541856910_item	3623578	et	3	main
massilisem	doc_536541856910_item	3623539	et	4	main
laulupidu	doc_536541856910_item	3623535	et	4	main
praegu	doc_536541856910_item	3623534	et	3	main
näitas	doc_536541856910_item	3623521	et	3	main
sada	doc_536541856910_item	3623517	et	4	main
populaarseks	doc_536541856910_item	3623515	et	4	main
rahvast	doc_536541856910_item	3623451	et	4	main
koos	doc_536541856910_item	3623449	et	4	main
laulupeod	doc_536541856910_item	3623447	et	4	main
teised	doc_536541856910_item	3623446	et	4	main
esinejaid	doc_536541856910_item	3623428	et	4	main
meeldib	doc_536541856910_item	3623404	et	3	main
eestlastele	doc_536541856910_item	3623403	et	4	main
ajalugu	doc_536541856910_item	3623399	et	4	main
magama	doc_536541856910_item	3623396	et	3	main
näiteks	doc_536541856910_item	3623391	et	4	main
suuliselt	doc_536541856910_item	3623390	et	4	main
koosneb	doc_536541856910_item	3623360	et	3	main
kultuur	doc_536541856910_item	3623359	et	3	main
tagasi	doc_536541856910_item	3623358	et	3	main
tuhat	doc_536541856910_item	3623356	et	4	main
mis	doc_536541856910_item	3623352	et	4	main
tähelepanuväärne	doc_536541856910_item	3623350	et	3	main
on	doc_536541856910_item	3623343	et	4	main
esitatud	doc_536541856910_item	3623340	et	4	main
kergem	doc_536541856905_item	3622750	et	4	main
aitas	doc_536541856905_item	3622747	et	3	main
nurk	doc_536541856905_item	3622739	et	3	main
nendel	doc_536541856905_item	3622737	et	4	main
kodus	doc_536541856905_item	3622735	et	4	main
eestlased	doc_536541856905_item	3622731	et	3	main
oma	doc_536541856905_item	3622728	et	4	main
inimesed	doc_536541856905_item	3622726	et	3	main
abil	doc_536541856905_item	3622725	et	4	main
mille	doc_536541856905_item	3622724	et	3	main
mis	doc_536541856905_item	3622713	et	4	main
me	doc_536541856905_item	3622710	et	4	main
aga	doc_536541856905_item	3622708	et	3	main
laulurahvaks	doc_536541856905_item	3622707	et	3	main
alati	doc_536541856905_item	3622706	et	4	main
loengus	doc_536541856905_item	3622690	et	3	main
peab	doc_536541856905_item	3622683	et	4	main
kirjutamine	doc_536541856905_item	3622669	et	4	main
test	doc_536541856905_item	3622668	et	3	main
kui	doc_536541856905_item	3622665	et	3	main
keele	doc_536541856905_item	3622664	et	4	main
eesti	doc_536541856905_item	3622663	et	4	main
essee	doc_536541856905_item	3622662	et	4	main
eestlased	doc_536541856905_item	3622811	et	3	main
sümbolid	doc_536541856905_item	3622810	et	3	main
kultuuri	doc_536541856905_item	3622809	et	4	main
ja	doc_536541856905_item	3622808	et	3	main
identiteeditunnete	doc_536541856905_item	3622807	et	3	main
rahvusliku	doc_536541856905_item	3622806	et	3	main
paljud	doc_536541856905_item	3622805	et	3	main
pärinesid	doc_536541856905_item	3622804	et	4	main
folkloorist	doc_536541856905_item	3622803	et	4	main
näiteks	doc_536541856905_item	3622802	et	4	main
sündmustega	doc_536541856905_item	3622801	et	3	main
mineviku	doc_536541856905_item	3622800	et	3	main
seotud	doc_536541856905_item	3622799	et	4	main
alati	doc_536541856905_item	3622798	et	4	main
olid	doc_536541856905_item	3622797	et	4	main
laulud	doc_536541856905_item	3622796	et	3	main
ootamises	doc_536541856905_item	3622795	et	4	main
oma	doc_536541856905_item	3622793	et	4	main
abikaasade	doc_536541856905_item	3622794	et	3	main
enesesse	doc_536541856906_item	3623288	et	4	main
usk	doc_536541856906_item	3623287	et	3	main
eestlastena	doc_536541856906_item	3623278	et	4	main
tunda	doc_536541856906_item	3623276	et	3	main
asi	doc_536541856906_item	3623273	et	4	main
ainuke	doc_536541856906_item	3623272	et	4	main
oli	doc_536541856906_item	3623271	et	3	main
jälle	doc_536541856906_item	3623270	et	3	main
oli	doc_536541856906_item	3623246	et	3	main
see	doc_536541856906_item	3623245	et	3	main
suurem	doc_536541856906_item	3623234	et	4	main
see	doc_536541856906_item	3623232	et	3	main
on	doc_536541856906_item	3623226	et	4	main
aru	doc_536541856906_item	3623222	et	4	main
rahvas	doc_536541856906_item	3623220	et	4	main
ärkamise	doc_536541856906_item	3623206	et	4	main
said	doc_536541856906_item	3623205	et	4	main
laulupeod	doc_536541856906_item	3623204	et	4	main
laulurahvaks	doc_536541856906_item	3623307	et	3	main
eestlased	doc_536541856906_item	3623306	et	3	main
nimetada	doc_536541856906_item	3623305	et	3	main
normaalne	doc_536541856906_item	3623304	et	3	main
absolütselt	doc_536541856906_item	3623303	et	4	main
pärast	doc_536541856906_item	3623301	et	4	main
see	doc_536541856906_item	3623300	et	3	main
on	doc_536541856906_item	3623302	et	4	main
lauluga	doc_536541856906_item	3623299	et	4	main
läbi	doc_536541856906_item	3623298	et	4	main
elas	doc_536541856906_item	3623297	et	3	main
rahvas	doc_536541856906_item	3623296	et	4	main
eesti	doc_536541856906_item	3623295	et	4	main
mured	doc_536541856906_item	3623294	et	3	main
oma	doc_536541856906_item	3623293	et	4	main
kõik	doc_536541856906_item	3623292	et	4	main
tulevikusse	doc_536541856906_item	3623291	et	4	main
parema	doc_536541856906_item	3623290	et	4	main
inimesed	doc_536541856906_item	3623283	et	3	main
laulupeod	doc_536541856906_item	3623281	et	4	main
mis	doc_536541856906_item	3623274	et	4	main
pärast	doc_536541856906_item	3623268	et	4	main
see	doc_536541856906_item	3623267	et	3	main
pikk	doc_536541856906_item	3623266	et	4	main
oli	doc_536541856906_item	3623265	et	3	main
periood	doc_536541856906_item	3623264	et	3	main
see	doc_536541856906_item	3623263	et	3	main
aga	doc_536541856906_item	3623262	et	3	main
iseseisvust	doc_536541856906_item	3623261	et	4	main
olnud	doc_536541856906_item	3623260	et	4	main
ei	doc_536541856906_item	3623259	et	4	main
tal	doc_536541856906_item	3623258	et	3	main
kui	doc_536541856906_item	3623257	et	3	main
seda	doc_536541856906_item	3623256	et	3	main
vajas	doc_536541856906_item	3623255	et	4	main
rahvas	doc_536541856906_item	3623254	et	4	main
teha	doc_536541856906_item	3623253	et	3	main
seda	doc_536541856906_item	3623252	et	3	main
võiksid	doc_536541856906_item	3623251	et	4	main
nad	doc_536541856906_item	3623250	et	3	main
isamaalisi	doc_536541856906_item	3623242	et	4	main
tähtsam	doc_536541856906_item	3623208	et	4	main
rahvas	doc_536541856906_item	3623215	et	4	main
kus	doc_536541856906_item	3623214	et	3	main
koht	doc_536541856906_item	3623213	et	3	main
ole	doc_536541856906_item	3623200	et	4	main
rahvas	doc_536541856906_item	3623196	et	4	main
osa	doc_536541856906_item	3623182	et	4	main
imelik	doc_536541856906_item	3623081	et	3	main
pole	doc_536541856906_item	3623080	et	3	main
kõik	doc_536541856906_item	3623076	et	4	main
kala	doc_536541856906_item	3623074	et	4	main
tehes	doc_536541856906_item	3623073	et	3	main
tööd	doc_536541856906_item	3623072	et	4	main
laulu	doc_536541856906_item	3623061	et	4	main
ema	doc_536541856906_item	3623058	et	4	main
mis	doc_536541856906_item	3623051	et	4	main
see	doc_536541856906_item	3623041	et	3	main
ja	doc_536541856906_item	3623040	et	3	main
teevad	doc_536541856906_item	3623032	et	3	main
laulupeod	doc_536541856906_item	3623030	et	4	main
nende	doc_536541856906_item	3623029	et	4	main
laulud	doc_536541856906_item	3623028	et	3	main
ei	doc_536541856906_item	3623199	et	4	main
pärast	doc_536541856906_item	3623198	et	4	main
koorid	doc_536541856906_item	3623188	et	4	main
laulsid	doc_536541856906_item	3623187	et	4	main
seal	doc_536541856906_item	3623186	et	4	main
külad	doc_536541856906_item	3623185	et	3	main
ja	doc_536541856906_item	3623078	et	3	main
püüjas	doc_536541856906_item	3623075	et	4	main
nende	doc_536541856906_item	3623070	et	4	main
oli	doc_536541856906_item	3623069	et	3	main
mängimas	doc_536541856906_item	3623067	et	3	main
laulasid	doc_536541856906_item	3623066	et	4	main
lapsed	doc_536541856906_item	3623065	et	3	main
talle	doc_536541856906_item	3623060	et	4	main
väike	doc_536541856906_item	3623057	et	4	main
ta	doc_536541856906_item	3623055	et	4	main
on	doc_536541856906_item	3623044	et	4	main
nad	doc_536541856906_item	3623043	et	3	main
nende	doc_536541856906_item	3623027	et	4	main
on	doc_536541856906_item	3623026	et	4	main
see	doc_536541856906_item	3623025	et	3	main
niimoodi	doc_536541856906_item	3623024	et	3	main
on	doc_536541856906_item	3623023	et	4	main
see	doc_536541856906_item	3623022	et	3	main
miks	doc_536541856906_item	3623021	et	4	main
arusaadav	doc_536541856906_item	3623020	et	4	main
on	doc_536541856906_item	3623019	et	4	main
siis	doc_536541856906_item	3623018	et	3	main
ajaloosse	doc_536541856906_item	3623017	et	4	main
vaadata	doc_536541856906_item	3623016	et	4	main
kui	doc_536541856906_item	3623015	et	3	main
kindlasti	doc_536541856906_item	3623014	et	3	main
on	doc_536541856906_item	3623013	et	4	main
see	doc_536541856906_item	3623012	et	3	main
laulurahvas	doc_536541856906_item	3623011	et	4	main
on	doc_536541856906_item	3623010	et	4	main
rahvas	doc_536541856906_item	3623009	et	4	main
eesti	doc_536541856906_item	3623008	et	4	main
laulurahva	doc_536541856906_item	3623006	et	3	main
teeb	doc_536541856906_item	3623004	et	3	main
näidetega	doc_536541856906_item	3623002	et	3	main
lugemistekstis	doc_536541856906_item	3622995	et	3	main
peab	doc_536541856906_item	3622986	et	4	main
kirjutamine	doc_536541856906_item	3622972	et	4	main
test	doc_536541856906_item	3622971	et	3	main
essee	doc_536541856906_item	3622965	et	4	main
kus	doc_536541856906_item	3623181	et	3	main
arusaadav	doc_536541856906_item	3623170	et	4	main
praktika	doc_536541856906_item	3623131	et	4	main
lihtsam	doc_536541856906_item	3623124	et	4	main
võiksid	doc_536541856906_item	3623090	et	4	main
inimesed	doc_536541856906_item	3623089	et	3	main
eesti	doc_536541856906_item	3623083	et	4	main
just	doc_536541856906_item	3623203	et	3	main
et	doc_536541856906_item	3623202	et	3	main
imelik	doc_536541856906_item	3623201	et	3	main
kogu	doc_536541856906_item	3623184	et	4	main
laulsid	doc_536541856906_item	3623077	et	4	main
laul	doc_536541856906_item	3623068	et	4	main
ta	doc_536541856906_item	3623063	et	4	main
kui	doc_536541856906_item	3623062	et	3	main
laulas	doc_536541856906_item	3623059	et	4	main
elule	doc_536541856906_item	3623039	et	3	main
eestlastest	doc_536541856906_item	3623033	et	4	main
illustreerida	doc_536541856906_item	3623001	et	3	main
arutlev	doc_536541856906_item	3622988	et	4	main
teemal	doc_536541856906_item	3622975	et	3	main
essee	doc_536541856906_item	3622974	et	4	main
kirjutage	doc_536541856906_item	3622973	et	3	main
keele	doc_536541856906_item	3622967	et	4	main
eesti	doc_536541856906_item	3622966	et	4	main
miks	doc_536541856906_item	3623171	et	4	main
on	doc_536541856906_item	3623138	et	4	main
laul	doc_536541856906_item	3623137	et	4	main
õppima	doc_536541856906_item	3623136	et	3	main
hea	doc_536541856906_item	3623130	et	4	main
ka	doc_536541856906_item	3623129	et	3	main
on	doc_536541856906_item	3623123	et	4	main
laulmas	doc_536541856906_item	3623122	et	3	main
esiteks	doc_536541856906_item	3623082	et	3	main
see	doc_536541856910_item	3623599	et	3	main
andekad	doc_536541856910_item	3623598	et	3	main
väga	doc_536541856910_item	3623597	et	3	main
aja	doc_536541856910_item	3623584	et	4	main
ootavad	doc_536541856910_item	3623575	et	4	main
laulupeod	doc_536541856910_item	3623574	et	4	main
suur	doc_536541856910_item	3623546	et	3	main
on	doc_536541856910_item	3623544	et	4	main
laulupidu	doc_536541856910_item	3623543	et	4	main
eestis	doc_536541856910_item	3623542	et	3	main
manifestatsioon	doc_536541856910_item	3623541	et	3	main
ajal	doc_536541856910_item	3623533	et	4	main
tol	doc_536541856910_item	3623532	et	3	main
lauldi	doc_536541856910_item	3623531	et	3	main
mis	doc_536541856910_item	3623530	et	4	main
see	doc_536541856910_item	3623520	et	3	main
peaaegu	doc_536541856910_item	3623516	et	3	main
said	doc_536541856910_item	3623514	et	4	main
järgnevate	doc_536541856910_item	3623443	et	4	main
aluse	doc_536541856910_item	3623442	et	4	main
laulupidu	doc_536541856910_item	3623427	et	4	main
eestlaste	doc_536541856910_item	3623417	et	4	main
sajandil	doc_536541856910_item	3623415	et	3	main
sest	doc_536541856910_item	3623402	et	4	main
lauludest	doc_536541856910_item	3623401	et	3	main
eesti	doc_536541856910_item	3623398	et	4	main
loengus	doc_536541856910_item	3623337	et	3	main
üldistav	doc_536541856910_item	3623335	et	4	main
eestlastest	doc_536541856910_item	3623322	et	4	main
teeb	doc_536541856910_item	3623321	et	3	main
teise	doc_536541856910_item	3623313	et	4	main
kui	doc_536541856910_item	3623312	et	3	main
170	doc_536541856910_item	3623506	et	2	main
ühe	doc_536541856910_item	3623492	et	4	main
käsitlesid	doc_536541856910_item	3623491	et	4	main
korda	doc_536541856910_item	3623480	et	4	main
üldlaulupidu	doc_536541856910_item	3623474	et	4	main
said	doc_536541856910_item	3623461	et	4	main
ka	doc_536541856910_item	3623454	et	3	main
käisid	doc_536541856910_item	3623453	et	4	main
külalised	doc_536541856910_item	3623452	et	4	main
eestlastest	doc_536541856911_item	3623911	et	4	main
soov	doc_536541856911_item	3623905	et	3	main
et	doc_536541856911_item	3623904	et	3	main
öelda	doc_536541856911_item	3623903	et	4	main
valust	doc_536541856911_item	3623887	et	3	main
niimoodi	doc_536541856911_item	3623885	et	3	main
sellest	doc_536541856911_item	3623879	et	4	main
kas	doc_536541856911_item	3623877	et	3	main
laulad	doc_536541856911_item	3623875	et	3	main
asi	doc_536541856911_item	3623871	et	4	main
sama	doc_536541856911_item	3623870	et	4	main
et	doc_536541856906_item	3623007	et	3	main
eestlastest	doc_536541856906_item	3623005	et	4	main
soovitatav	doc_536541856906_item	3623000	et	4	main
on	doc_536541856906_item	3622999	et	4	main
faktidele	doc_536541856906_item	3622997	et	3	main
ja	doc_536541856906_item	3622994	et	3	main
üldistav	doc_536541856906_item	3622991	et	4	main
ja	doc_536541856906_item	3622990	et	3	main
analüüsiv	doc_536541856906_item	3622989	et	4	main
essee	doc_536541856906_item	3622985	et	4	main
essee	doc_536541856906_item	3622980	et	4	main
laulurahva	doc_536541856906_item	3622979	et	3	main
peosid	doc_536541856906_item	3623176	et	3	main
palju	doc_536541856906_item	3623175	et	4	main
nii	doc_536541856906_item	3623174	et	3	main
pärast	doc_536541856906_item	3623168	et	4	main
see	doc_536541856906_item	3623167	et	3	main
suhtlema	doc_536541856906_item	3623166	et	3	main
ja	doc_536541856906_item	3623163	et	3	main
gruppile	doc_536541856906_item	3623162	et	4	main
inimesed	doc_536541856906_item	3623161	et	3	main
ühinesid	doc_536541856906_item	3623160	et	4	main
ja	doc_536541856906_item	3623159	et	3	main
peoses	doc_536541856906_item	3623158	et	4	main
asi	doc_536541856906_item	3623157	et	4	main
tähtsam	doc_536541856906_item	3623156	et	4	main
kõige	doc_536541856906_item	3623155	et	4	main
olid	doc_536541856906_item	3623154	et	4	main
nad	doc_536541856906_item	3623153	et	3	main
pärast	doc_536541856906_item	3623152	et	4	main
see	doc_536541856906_item	3623151	et	3	main
tantsiga	doc_536541856906_item	3623150	et	3	main
ka	doc_536541856906_item	3623149	et	3	main
seotud	doc_536541856906_item	3623148	et	4	main
olid	doc_536541856906_item	3623147	et	4	main
rahvalaulud	doc_536541856906_item	3623146	et	3	main
eesti	doc_536541856906_item	3623145	et	4	main
viis	doc_536541856906_item	3623144	et	4	main
suhtemis	doc_536541856906_item	3623143	et	4	main
omapärane	doc_536541856906_item	3623142	et	4	main
ka	doc_536541856906_item	3623141	et	3	main
ja	doc_536541856906_item	3623140	et	3	main
ajaviide	doc_536541856906_item	3623139	et	3	main
väiteid	doc_536541856906_item	3622998	et	4	main
esitatud	doc_536541856906_item	3622996	et	4	main
loengus	doc_536541856906_item	3622993	et	3	main
tuginema	doc_536541856906_item	3622992	et	3	main
sõna	doc_536541856906_item	3622984	et	4	main
350	doc_536541856906_item	3622983	et	2	main
300	doc_536541856906_item	3622982	et	2	main
eestlastest	doc_536541856906_item	3622978	et	4	main
teeb	doc_536541856906_item	3622977	et	3	main
mis	doc_536541856906_item	3622976	et	4	main
väiksed	doc_536541856906_item	3623179	et	4	main
tegid	doc_536541856906_item	3623173	et	4	main
eestlased	doc_536541856906_item	3623172	et	3	main
hakkasid	doc_536541856906_item	3623165	et	4	main
nad	doc_536541856906_item	3623164	et	3	main
midagi	doc_536541856906_item	3623134	et	4	main
et	doc_536541856906_item	3623133	et	3	main
tööd	doc_536541856906_item	3623125	et	4	main
emotsionaalne	doc_536541856906_item	3623120	et	3	main
on	doc_536541856906_item	3623119	et	4	main
see	doc_536541856906_item	3623118	et	3	main
laul	doc_536541856906_item	3623117	et	4	main
on	doc_536541856906_item	3623116	et	4	main
mis	doc_536541856906_item	3623115	et	4	main
rutiinis	doc_536541856906_item	3623114	et	3	main
igapäevane	doc_536541856906_item	3623113	et	4	main
keerulises	doc_536541856906_item	3623112	et	4	main
selles	doc_536541856906_item	3623111	et	4	main
eksisteerima	doc_536541856906_item	3623110	et	4	main
ja	doc_536541856906_item	3623109	et	3	main
elama	doc_536541856906_item	3623108	et	3	main
teile	doc_536541856906_item	3623107	et	4	main
aitas	doc_536541856906_item	3623106	et	3	main
laul	doc_536541856906_item	3623105	et	4	main
viimaseks	doc_536541856906_item	3623104	et	3	main
ja	doc_536541856906_item	3623103	et	3	main
kolmaks	doc_536541856906_item	3623102	et	4	main
instrumente	doc_536541856906_item	3623101	et	3	main
vaja	doc_536541856906_item	3623100	et	4	main
olnud	doc_536541856906_item	3623099	et	4	main
ei	doc_536541856906_item	3623098	et	4	main
et	doc_536541856906_item	3623097	et	3	main
sest	doc_536541856906_item	3623096	et	4	main
millal	doc_536541856906_item	3623095	et	3	main
pähe	doc_536541856906_item	3623135	et	4	main
on	doc_536541856906_item	3623128	et	4	main
see	doc_536541856906_item	3623127	et	3	main
teha	doc_536541856906_item	3623126	et	3	main
abi	doc_536541856906_item	3623121	et	4	main
teiseks	doc_536541856906_item	3623088	et	4	main
meloodiline	doc_536541856906_item	3623087	et	3	main
väga	doc_536541856906_item	3623086	et	3	main
on	doc_536541856906_item	3623085	et	4	main
kokkuleppe	doc_536541856910_item	3623589	et	4	main
kui	doc_536541856910_item	3623588	et	3	main
laulaksid	doc_536541856910_item	3623580	et	4	main
nad	doc_536541856910_item	3623579	et	3	main
tähelepanuväärsem	doc_536541856910_item	3623537	et	4	main
on	doc_536541856910_item	3623536	et	4	main
mineviku	doc_536541856910_item	3623526	et	3	main
oma	doc_536541856910_item	3623525	et	4	main
austavad	doc_536541856910_item	3623524	et	4	main
eestlased	doc_536541856910_item	3623523	et	3	main
et	doc_536541856910_item	3623522	et	3	main
palju	doc_536541856910_item	3623450	et	4	main
korraldamisele	doc_536541856910_item	3623445	et	4	main
üldlaulupidude	doc_536541856910_item	3623444	et	4	main
esimene	doc_536541856910_item	3623439	et	3	main
piisas	doc_536541856910_item	3623438	et	4	main
ikka	doc_536541856910_item	3623437	et	4	main
aga	doc_536541856910_item	3623436	et	3	main
peodel	doc_536541856910_item	3623435	et	3	main
järgmistel	doc_536541856910_item	3623434	et	3	main
nagu	doc_536541856910_item	3623433	et	3	main
palju	doc_536541856910_item	3623432	et	4	main
nii	doc_536541856910_item	3623431	et	3	main
olnud	doc_536541856910_item	3623430	et	4	main
ülemaaline	doc_536541856910_item	3623426	et	4	main
esimene	doc_536541856910_item	3623425	et	3	main
korraldati	doc_536541856910_item	3623424	et	3	main
tartus	doc_536541856910_item	3623423	et	3	main
aastal	doc_536541856910_item	3623422	et	3	main
19	doc_536541856910_item	3623414	et	2	main
põlve	doc_536541856910_item	3623389	et	4	main
aastat	doc_536541856910_item	3623357	et	3	main
kultuurinähtus	doc_536541856910_item	3623351	et	4	main
ja	doc_536541856906_item	3623094	et	3	main
kus	doc_536541856906_item	3623093	et	3	main
ükskõik	doc_536541856906_item	3623092	et	3	main
keel	doc_536541856906_item	3623084	et	4	main
et	doc_536541856910_item	3623594	et	3	main
välja	doc_536541856910_item	3623593	et	4	main
tuleb	doc_536541856910_item	3623592	et	3	main
siis	doc_536541856910_item	3623591	et	3	main
teha	doc_536541856910_item	3623590	et	3	main
on	doc_536541856910_item	3623582	et	4	main
rahvalaulud	doc_536541856910_item	3623581	et	3	main
kõigepealt	doc_536541856910_item	3623576	et	3	main
aga	doc_536541856910_item	3623573	et	3	main
olla	doc_536541856910_item	3623572	et	3	main
nautida	doc_536541856910_item	3623569	et	3	main
hästi	doc_536541856910_item	3623568	et	3	main
rahvusluse	doc_536541856910_item	3623540	et	4	main
laule	doc_536541856910_item	3623529	et	4	main
teavad	doc_536541856910_item	3623528	et	3	main
tagasi	doc_536541856910_item	3623519	et	3	main
laulurahvana	doc_536541856910_item	3623611	et	3	main
ennast	doc_536541856910_item	3623610	et	4	main
nimetada	doc_536541856910_item	3623609	et	3	main
võivad	doc_536541856910_item	3623608	et	4	main
nad	doc_536541856910_item	3623607	et	3	main
et	doc_536541856910_item	3623606	et	3	main
näitab	doc_536541856910_item	3623605	et	3	main
traditsioone	doc_536541856910_item	3623604	et	3	main
oma	doc_536541856910_item	3623603	et	4	main
hoolivad	doc_536541856910_item	3623602	et	4	main
nad	doc_536541856910_item	3623601	et	3	main
kuidas	doc_536541856910_item	3623600	et	3	main
on	doc_536541856910_item	3623596	et	4	main
eestlased	doc_536541856910_item	3623595	et	3	main
läbi	doc_536541856910_item	3623583	et	4	main
inimesi	doc_536541856910_item	3623577	et	4	main
koos	doc_536541856910_item	3623571	et	4	main
et	doc_536541856910_item	3623570	et	3	main
aega	doc_536541856910_item	3623567	et	4	main
et	doc_536541856910_item	3623566	et	3	main
lihtsalt	doc_536541856910_item	3623565	et	4	main
peole	doc_536541856910_item	3623564	et	4	main
tulevad	doc_536541856910_item	3623563	et	4	main
inimesed	doc_536541856910_item	3623562	et	3	main
maailma	doc_536541856910_item	3623561	et	4	main
kogu	doc_536541856910_item	3623560	et	4	main
üle	doc_536541856910_item	3623559	et	3	main
spetsaalselt	doc_536541856910_item	3623558	et	4	main
peole	doc_536541856910_item	3623557	et	4	main
tulevad	doc_536541856910_item	3623556	et	4	main
paljud	doc_536541856910_item	3623555	et	3	main
tuttavatega	doc_536541856910_item	3623554	et	3	main
ja	doc_536541856910_item	3623553	et	3	main
sõpradega	doc_536541856910_item	3623552	et	3	main
perega	doc_536541856910_item	3623551	et	3	main
koos	doc_536541856910_item	3623550	et	4	main
kuhu	doc_536541856910_item	3623548	et	3	main
käiakse	doc_536541856910_item	3623549	et	3	main
rahvapidu	doc_536541856910_item	3623547	et	4	main
ka	doc_536541856910_item	3623545	et	3	main
ja	doc_536541856910_item	3623538	et	3	main
ja	doc_536541856910_item	3623527	et	3	main
aastat	doc_536541856910_item	3623518	et	3	main
laulupidu	doc_536541856910_item	3623440	et	4	main
ei	doc_536541856910_item	3623429	et	4	main
rahvuslik	doc_536541856910_item	3623418	et	3	main
lauludele	doc_536541856910_item	3623413	et	3	main
kirikus	doc_536541856910_item	3623411	et	3	main
tekkis	doc_536541856910_item	3623410	et	3	main
koosneb	doc_536541856910_item	3623400	et	3	main
minekut	doc_536541856910_item	3623397	et	3	main
enna	doc_536541856910_item	3623395	et	4	main
lapsele	doc_536541856910_item	3623394	et	4	main
sündinud	doc_536541856910_item	3623354	et	4	main
on	doc_536541856910_item	3623349	et	4	main
laulmine	doc_536541856910_item	3623348	et	4	main
väiteid	doc_536541856910_item	3623342	et	4	main
lugemistekstis	doc_536541856910_item	3623339	et	3	main
peab	doc_536541856910_item	3623330	et	4	main
essee	doc_536541856910_item	3623329	et	4	main
sõna	doc_536541856910_item	3623328	et	4	main
350	doc_536541856910_item	3623327	et	2	main
pikkus	doc_536541856910_item	3623325	et	4	main
lauljat	doc_536541856910_item	3623503	et	4	main
41	doc_536541856910_item	3623501	et	2	main
peo	doc_536541856910_item	3623493	et	4	main
oli	doc_536541856910_item	3623487	et	3	main
peo	doc_536541856910_item	3623486	et	4	main
ja	doc_536541856910_item	3623478	et	3	main
korda	doc_536541856910_item	3623477	et	4	main
korraldati	doc_536541856910_item	3623472	et	3	main
aastal	doc_536541856910_item	3623471	et	3	main
sellepärast	doc_536541856910_item	3623460	et	3	main
kogunesid	doc_536541856910_item	3623448	et	4	main
pani	doc_536541856910_item	3623441	et	4	main
1869	doc_536541856910_item	3623421	et	2	main
ja	doc_536541856910_item	3623420	et	3	main
ärkamine	doc_536541856910_item	3623419	et	4	main
algas	doc_536541856910_item	3623416	et	3	main
tänu	doc_536541856910_item	3623412	et	4	main
rahvalaul	doc_536541856910_item	3623409	et	4	main
uus	doc_536541856910_item	3623408	et	3	main
tantsida	doc_536541856910_item	3623407	et	3	main
ja	doc_536541856910_item	3623406	et	3	main
laulda	doc_536541856910_item	3623405	et	4	main
laulas	doc_536541856910_item	3623393	et	4	main
ema	doc_536541856910_item	3623392	et	4	main
põlvest	doc_536541856910_item	3623388	et	4	main
laule	doc_536541856910_item	3623387	et	4	main
pärandasid	doc_536541856910_item	3623386	et	4	main
eestlased	doc_536541856910_item	3623385	et	3	main
saatel	doc_536541856910_item	3623384	et	4	main
liikumise	doc_536541856910_item	3623383	et	4	main
tantsulise	doc_536541856910_item	3623382	et	4	main
ka	doc_536541856910_item	3623381	et	3	main
esitasid	doc_536541856910_item	3623380	et	4	main
laulud	doc_536541856910_item	3623379	et	3	main
mõned	doc_536541856910_item	3623378	et	3	main
jalapõrutusega	doc_536541856910_item	3623377	et	3	main
või	doc_536541856910_item	3623376	et	4	main
õõtsutamise	doc_536541856910_item	3623375	et	4	main
keha	doc_536541856910_item	3623374	et	4	main
näiteks	doc_536541856910_item	3623373	et	4	main
rütmi	doc_536541856910_item	3623372	et	4	main
rõhutada	doc_536541856910_item	3623371	et	3	main
võidi	doc_536541856910_item	3623370	et	4	main
lauldes	doc_536541856910_item	3623369	et	3	main
ajal	doc_536541856910_item	3623368	et	4	main
pillimäng	doc_536541856910_item	3623366	et	3	main
ja	doc_536541856910_item	3623365	et	3	main
vana	doc_536541856910_item	3623367	et	4	main
tants	doc_536541856910_item	3623364	et	3	main
laul	doc_536541856910_item	3623363	et	4	main
osast	doc_536541856910_item	3623362	et	4	main
kolmest	doc_536541856910_item	3623361	et	4	main
umbes	doc_536541856910_item	3623355	et	4	main
on	doc_536541856910_item	3623353	et	4	main
eestlastele	doc_536541856910_item	3623347	et	4	main
olema	doc_536541856910_item	3623331	et	4	main
essee	doc_536541856910_item	3623324	et	4	main
laulurahva	doc_536541856910_item	3623323	et	3	main
keele	doc_536541856910_item	3623314	et	4	main
ja	doc_536541856910_item	3623504	et	3	main
000	doc_536541856910_item	3623502	et	2	main
nii	doc_536541856910_item	3623488	et	3	main
tallinnas	doc_536541856910_item	3623485	et	4	main
ja	doc_536541856910_item	3623484	et	3	main
tartus	doc_536541856910_item	3623483	et	3	main
linnas	doc_536541856910_item	3623482	et	4	main
kui	doc_536541856910_item	3623465	et	3	main
need	doc_536541856910_item	3623458	et	3	main
kõikidele	doc_536541856910_item	3623456	et	4	main
teeb	doc_536541856911_item	3623910	et	3	main
emotsioone	doc_536541856911_item	3623909	et	3	main
su	doc_536541856911_item	3623899	et	3	main
osakese	doc_536541856911_item	3623898	et	4	main
teised	doc_536541856911_item	3623896	et	4	main
ka	doc_536541856911_item	3623895	et	3	main
et	doc_536541856911_item	3623894	et	3	main
armunud	doc_536541856911_item	3623893	et	4	main
oled	doc_536541856911_item	3623892	et	3	main
kui	doc_536541856911_item	3623891	et	3	main
siis	doc_536541856911_item	3623890	et	3	main
paha	doc_536541856911_item	3623883	et	4	main
kui	doc_536541856911_item	3623874	et	3	main
oma	doc_536541856911_item	3623866	et	4	main
valu	doc_536541856911_item	3623852	et	4	main
karjudes	doc_536541856911_item	3623848	et	3	main
ta	doc_536541856911_item	3623845	et	4	main
haiget	doc_536541856911_item	3623844	et	3	main
väga	doc_536541856911_item	3623843	et	3	main
kui	doc_536541856911_item	3623811	et	3	main
minu	doc_536541856911_item	3623774	et	3	main
mitte	doc_536541856911_item	3623769	et	3	main
miks	doc_536541856911_item	3623765	et	4	main
kõlasid	doc_536541856911_item	3623758	et	4	main
keerulisel	doc_536541856911_item	3623741	et	4	main
sellisel	doc_536541856911_item	3623740	et	4	main
kultuuritegelased	doc_536541856911_item	3623736	et	3	main
eestlaste	doc_536541856911_item	3623732	et	4	main
raske	doc_536541856911_item	3623731	et	4	main
oli	doc_536541856911_item	3623730	et	3	main
sajand	doc_536541856911_item	3623729	et	3	main
19	doc_536541856911_item	3623728	et	2	main
palju	doc_536541856911_item	3623718	et	4	main
tartusse	doc_536541856911_item	3623717	et	3	main
oli	doc_536541856911_item	3623689	et	3	main
armastust	doc_536541856911_item	3623687	et	4	main
rajuma	doc_536541856911_item	3623684	et	4	main
puid	doc_536541856911_item	3623683	et	3	main
siis	doc_536541856911_item	3623677	et	3	main
tehti	doc_536541856911_item	3623675	et	3	main
naised	doc_536541856911_item	3623673	et	3	main
mehed	doc_536541856911_item	3623671	et	3	main
kõik	doc_536541856911_item	3623664	et	4	main
kuuluvad	doc_536541856911_item	3623660	et	4	main
hulka	doc_536541856911_item	3623659	et	4	main
mängis	doc_536541856911_item	3623652	et	3	main
näidetega	doc_536541856911_item	3623650	et	3	main
lugemistekstis	doc_536541856911_item	3623643	et	3	main
loengus	doc_536541856911_item	3623641	et	3	main
analüüsiv	doc_536541856911_item	3623637	et	4	main
peab	doc_536541856911_item	3623634	et	4	main
teineteisele	doc_852214925993_item	3624072	et	3	main
õhtul	doc_852214925993_item	3624070	et	3	main
mängida	doc_852214925993_item	3624069	et	3	main
nad	doc_852214925993_item	3624060	et	3	main
kui	doc_852214925993_item	3624059	et	3	main
päev	doc_852214925993_item	3624058	et	3	main
ilus	doc_852214925993_item	3624057	et	4	main
oli	doc_852214925993_item	3624056	et	3	main
see	doc_852214925993_item	3624055	et	3	main
mõte	doc_852214925993_item	3624054	et	3	main
hea	doc_852214925993_item	3624053	et	4	main
on	doc_852214925993_item	3624040	et	4	main
on	doc_852214925993_item	3624039	et	4	main
meelest	doc_852214925993_item	3624038	et	4	main
näidetega	doc_536541856910_item	3623346	et	3	main
illustreerida	doc_536541856910_item	3623345	et	3	main
soovitatav	doc_536541856910_item	3623344	et	4	main
faktidele	doc_536541856910_item	3623341	et	3	main
ja	doc_536541856910_item	3623338	et	3	main
analüüsiv	doc_536541856910_item	3623333	et	4	main
arutlev	doc_536541856910_item	3623332	et	4	main
300	doc_536541856910_item	3623326	et	2	main
teemal	doc_536541856910_item	3623319	et	3	main
essee	doc_536541856910_item	3623318	et	4	main
kirjutage	doc_536541856910_item	3623317	et	3	main
kirjutamine	doc_536541856910_item	3623316	et	4	main
test	doc_536541856910_item	3623315	et	3	main
eesti	doc_536541856910_item	3623310	et	4	main
essee	doc_536541856910_item	3623309	et	4	main
kavas	doc_536541856910_item	3623513	et	3	main
olid	doc_536541856910_item	3623512	et	4	main
mis	doc_536541856910_item	3623511	et	4	main
laulud	doc_536541856910_item	3623510	et	3	main
paljud	doc_536541856910_item	3623509	et	3	main
000	doc_536541856910_item	3623507	et	2	main
tuginema	doc_536541856910_item	3623336	et	3	main
ja	doc_536541856910_item	3623334	et	3	main
mis	doc_536541856910_item	3623320	et	4	main
keele	doc_536541856910_item	3623311	et	4	main
umbes	doc_536541856910_item	3623505	et	4	main
umbes	doc_536541856910_item	3623500	et	4	main
pidu	doc_536541856910_item	3623498	et	4	main
et	doc_536541856910_item	3623490	et	3	main
esimest	doc_536541856910_item	3623479	et	4	main
eesti	doc_536541856910_item	3623473	et	4	main
1994	doc_536541856910_item	3623470	et	2	main
laulupeod	doc_536541856910_item	3623469	et	4	main
125	doc_536541856910_item	3623466	et	2	main
meeldisid	doc_536541856910_item	3623457	et	4	main
laulurahva	doc_536541856911_item	3623912	et	3	main
tõelisi	doc_536541856911_item	3623908	et	4	main
oma	doc_536541856911_item	3623907	et	4	main
väljendada	doc_536541856911_item	3623906	et	3	main
armastusest	doc_536541856911_item	3623900	et	4	main
üle	doc_536541856911_item	3623888	et	3	main
teistega	doc_536541856911_item	3623869	et	4	main
ta	doc_536541856911_item	3623864	et	4	main
naeramise	doc_536541856911_item	3623862	et	4	main
äkki	doc_536541856911_item	3623841	et	3	main
sa	doc_536541856911_item	3623812	et	3	main
koos	doc_536541856911_item	3623809	et	4	main
kaudu	doc_536541856911_item	3623780	et	3	main
selline	doc_536541856911_item	3623777	et	4	main
või	doc_536541856911_item	3623772	et	4	main
selline	doc_536541856911_item	3623763	et	4	main
tekib	doc_536541856911_item	3623762	et	3	main
kohe	doc_536541856911_item	3623761	et	4	main
kelle	doc_536541856911_item	3623756	et	4	main
on	doc_536541856911_item	3623753	et	4	main
kes	doc_536541856911_item	3623745	et	4	main
need	doc_536541856911_item	3623744	et	3	main
aga	doc_536541856911_item	3623743	et	3	main
ajal	doc_536541856911_item	3623742	et	4	main
ja	doc_536541856911_item	3623734	et	3	main
on	doc_536541856911_item	3623724	et	4	main
tunneti	doc_536541856911_item	3623686	et	4	main
töödati	doc_536541856911_item	3623679	et	4	main
nii	doc_536541856911_item	3623670	et	3	main
kui	doc_536541856911_item	3623667	et	3	main
kelle	doc_536541856911_item	3623658	et	4	main
elus	doc_536541856911_item	3623657	et	4	main
tähtsa	doc_536541856911_item	3623653	et	3	main
soovitatav	doc_536541856911_item	3623648	et	4	main
tuginema	doc_536541856911_item	3623640	et	3	main
ja	doc_536541856911_item	3623638	et	3	main
essee	doc_536541856911_item	3623622	et	4	main
kirjutage	doc_536541856911_item	3623621	et	3	main
kirjutamine	doc_536541856911_item	3623620	et	4	main
test	doc_536541856911_item	3623619	et	3	main
pealtvaatajaid	doc_536541856910_item	3623508	et	3	main
kogunes	doc_536541856910_item	3623499	et	3	main
linnas	doc_536541856910_item	3623497	et	4	main
kahes	doc_536541856910_item	3623496	et	4	main
osana	doc_536541856910_item	3623495	et	3	main
kahe	doc_536541856910_item	3623494	et	3	main
suur	doc_536541856910_item	3623489	et	3	main
kahes	doc_536541856910_item	3623481	et	4	main
teist	doc_536541856910_item	3623476	et	4	main
kahekümne	doc_536541856910_item	3623475	et	4	main
korraldatakse	doc_536541856910_item	3623468	et	3	main
aastat	doc_536541856910_item	3623467	et	3	main
rohkem	doc_536541856910_item	3623464	et	4	main
populaarseks	doc_536541856910_item	3623463	et	4	main
nad	doc_536541856910_item	3623462	et	3	main
peod	doc_536541856910_item	3623459	et	4	main
välismaalt	doc_536541856910_item	3623455	et	3	main
tahaksin	doc_536541856911_item	3623902	et	3	main
või	doc_536541856911_item	3623889	et	4	main
saad	doc_536541856911_item	3623886	et	4	main
ja	doc_536541856911_item	3623884	et	3	main
sul	doc_536541856911_item	3623881	et	3	main
tunneid	doc_536541856911_item	3623868	et	4	main
häid	doc_536541856911_item	3623867	et	3	main
kaudu	doc_536541856911_item	3623863	et	3	main
ja	doc_536541856911_item	3623861	et	3	main
või	doc_536541856911_item	3623807	et	4	main
oma	doc_536541856911_item	3623782	et	4	main
tants	doc_536541856911_item	3623773	et	3	main
küsimus	doc_536541856911_item	3623764	et	4	main
jäid	doc_536541856911_item	3623746	et	4	main
isamaa	doc_536541856911_item	3623739	et	4	main
mõned	doc_536541856911_item	3623735	et	3	main
seotud	doc_536541856911_item	3623725	et	4	main
kogus	doc_536541856911_item	3623716	et	4	main
kui	doc_536541856911_item	3623688	et	3	main
kui	doc_536541856911_item	3623685	et	3	main
metsas	doc_536541856911_item	3623682	et	3	main
käiti	doc_536541856911_item	3623681	et	4	main
põllul	doc_536541856911_item	3623680	et	3	main
noored	doc_536541856911_item	3623669	et	3	main
laulsid	doc_536541856911_item	3623663	et	4	main
eestlased	doc_536541856911_item	3623662	et	3	main
ka	doc_536541856911_item	3623661	et	3	main
erinevate	doc_536541856911_item	3623655	et	4	main
on	doc_536541856911_item	3623647	et	4	main
väiteid	doc_536541856911_item	3623646	et	4	main
faktidele	doc_536541856911_item	3623645	et	3	main
olema	doc_536541856911_item	3623635	et	4	main
essee	doc_536541856911_item	3623633	et	4	main
sõna	doc_536541856911_item	3623632	et	4	main
350	doc_536541856911_item	3623631	et	2	main
essee	doc_536541856911_item	3623628	et	4	main
eestlastest	doc_536541856911_item	3623626	et	4	main
teeb	doc_536541856911_item	3623625	et	3	main
mis	doc_536541856911_item	3623624	et	4	main
teemal	doc_536541856911_item	3623623	et	3	main
et	doc_852214925993_item	3624076	et	3	main
väsinud	doc_852214925993_item	3624062	et	4	main
leian	doc_852214925993_item	3624051	et	3	main
küll	doc_852214925993_item	3624041	et	4	main
sinu	doc_852214925993_item	3624037	et	3	main
on	doc_852214925993_item	3624029	et	4	main
see	doc_852214925993_item	3624028	et	3	main
ka	doc_852214925993_item	3624024	et	3	main
aga	doc_852214925993_item	3624006	et	3	main
kahju	doc_852214925993_item	3624005	et	4	main
on	doc_852214925993_item	3624004	et	4	main
mul	doc_852214925993_item	3624003	et	3	main
päev	doc_852214925993_item	3624002	et	3	main
ja	doc_852214925993_item	3623995	et	3	main
olen	doc_852214925993_item	3623993	et	3	main
punakas	doc_852214925993_item	3623978	et	4	main
tiivad	doc_852214925993_item	3623977	et	3	main
on	doc_852214925993_item	3623973	et	4	main
oh	doc_852214925993_item	3623969	et	3	main
oskad	doc_852214925993_item	3623967	et	3	main
lennata	doc_852214925993_item	3623964	et	4	main
lilled	doc_852214925993_item	3623960	et	3	main
meeldivad	doc_852214925993_item	3623959	et	4	main
olen	doc_852214925993_item	3623952	et	3	main
oled	doc_852214925993_item	3623950	et	3	main
kokkuvõteks	doc_536541856911_item	3623901	et	3	main
saaksid	doc_536541856911_item	3623897	et	4	main
on	doc_536541856911_item	3623882	et	4	main
et	doc_536541856911_item	3623880	et	3	main
laulad	doc_536541856911_item	3623878	et	3	main
sa	doc_536541856911_item	3623876	et	3	main
siis	doc_536541856911_item	3623873	et	3	main
toimub	doc_536541856911_item	3623872	et	3	main
jagab	doc_536541856911_item	3623865	et	3	main
naerab	doc_536541856911_item	3623860	et	3	main
ta	doc_536541856911_item	3623859	et	4	main
tuju	doc_536541856911_item	3623858	et	4	main
ta	doc_536541856911_item	3623851	et	4	main
et	doc_536541856911_item	3623850	et	3	main
ja	doc_536541856911_item	3623847	et	3	main
inimene	doc_536541856911_item	3623840	et	3	main
kui	doc_536541856911_item	3623839	et	3	main
seletada	doc_536541856911_item	3623838	et	3	main
proovin	doc_536541856911_item	3623837	et	3	main
võimu	doc_536541856911_item	3623836	et	4	main
hääle	doc_536541856911_item	3623835	et	3	main
oma	doc_536541856911_item	3623834	et	4	main
kasutab	doc_536541856911_item	3623833	et	3	main
inimene	doc_536541856911_item	3623832	et	3	main
lauldes	doc_536541856911_item	3623831	et	3	main
et	doc_536541856911_item	3623830	et	3	main
selline	doc_536541856911_item	3623829	et	4	main
on	doc_536541856911_item	3623828	et	4	main
põhjus	doc_536541856911_item	3623827	et	4	main
kolmas	doc_536541856911_item	3623826	et	3	main
tuju	doc_536541856911_item	3623825	et	4	main
see	doc_536541856911_item	3623824	et	3	main
jagatatakse	doc_536541856911_item	3623823	et	4	main
emotsioone	doc_536541856911_item	3623822	et	3	main
see	doc_536541856911_item	3623821	et	3	main
et	doc_536541856911_item	3623820	et	3	main
ja	doc_536541856911_item	3623819	et	3	main
tunned	doc_536541856911_item	3623816	et	3	main
end	doc_536541856911_item	3623817	et	4	main
mitteüksikuna	doc_536541856911_item	3623818	et	3	main
koos	doc_536541856911_item	3623814	et	4	main
laulad	doc_536541856911_item	3623813	et	3	main
teistega	doc_536541856911_item	3623815	et	4	main
teistega	doc_536541856911_item	3623808	et	4	main
tõelisi	doc_536541856911_item	3623783	et	4	main
väljendati	doc_536541856911_item	3623781	et	3	main
laulu	doc_536541856911_item	3623779	et	4	main
et	doc_536541856911_item	3623778	et	3	main
pillimäng	doc_536541856911_item	3623771	et	3	main
näiteks	doc_536541856911_item	3623770	et	4	main
miks	doc_536541856911_item	3623768	et	4	main
laul	doc_536541856911_item	3623767	et	4	main
just	doc_536541856911_item	3623766	et	3	main
üldlaulupeol	doc_536541856911_item	3623760	et	4	main
hea	doc_536541856911_item	3623857	et	4	main
väga	doc_536541856911_item	3623856	et	3	main
inimesel	doc_536541856911_item	3623855	et	3	main
kui	doc_536541856911_item	3623854	et	3	main
kaob	doc_536541856911_item	3623853	et	3	main
tunneb	doc_536541856911_item	3623849	et	3	main
karjub	doc_536541856911_item	3623846	et	3	main
saab	doc_536541856911_item	3623842	et	3	main
ja	doc_536541856911_item	3623810	et	3	main
on	doc_536541856911_item	3623776	et	4	main
arvamus	doc_536541856911_item	3623775	et	3	main
luuletused	doc_536541856911_item	3623757	et	4	main
lydia	doc_536541856911_item	3623754	et	4	main
südametes	doc_536541856911_item	3623750	et	4	main
meie	doc_536541856911_item	3623749	et	4	main
siiamaani	doc_536541856911_item	3623748	et	3	main
on	doc_536541856911_item	3623747	et	4	main
jätsid	doc_536541856911_item	3623737	et	4	main
jaoks	doc_536541856911_item	3623733	et	4	main
algus	doc_536541856911_item	3623727	et	4	main
ärkamisaja	doc_536541856911_item	3623726	et	3	main
inimesi	doc_536541856911_item	3623719	et	4	main
üldlaulupidu	doc_536541856911_item	3623715	et	4	main
esimest	doc_536541856911_item	3623714	et	4	main
korraldati	doc_536541856911_item	3623713	et	3	main
kui	doc_536541856911_item	3623712	et	3	main
aastal	doc_536541856911_item	3623711	et	3	main
1869	doc_536541856911_item	3623710	et	2	main
pildi	doc_536541856911_item	3623709	et	4	main
huvitava	doc_536541856911_item	3623708	et	4	main
näeme	doc_536541856911_item	3623707	et	3	main
siis	doc_536541856911_item	3623706	et	3	main
ühiskond	doc_536541856911_item	3623705	et	3	main
eesti	doc_536541856911_item	3623704	et	4	main
arenes	doc_536541856911_item	3623703	et	3	main
kuidas	doc_536541856911_item	3623702	et	3	main
seda	doc_536541856911_item	3623701	et	3	main
vaadata	doc_536541856911_item	3623700	et	4	main
kui	doc_536541856911_item	3623699	et	3	main
ajal	doc_536541856911_item	3623698	et	4	main
halval	doc_536541856911_item	3623697	et	3	main
ja	doc_536541856911_item	3623696	et	3	main
heal	doc_536541856911_item	3623695	et	3	main
inimestega	doc_536541856911_item	3623694	et	3	main
olnud	doc_536541856911_item	3623693	et	4	main
on	doc_536541856911_item	3623692	et	4	main
laul	doc_536541856911_item	3623691	et	4	main
sõda	doc_536541856911_item	3623690	et	4	main
seda	doc_536541856911_item	3623676	et	3	main
kui	doc_536541856911_item	3623672	et	3	main
ka	doc_536541856911_item	3623668	et	3	main
nii	doc_536541856911_item	3623665	et	3	main
inimeste	doc_536541856911_item	3623656	et	3	main
esitatud	doc_536541856911_item	3623644	et	4	main
ja	doc_536541856911_item	3623642	et	3	main
arutlev	doc_536541856911_item	3623636	et	4	main
pikkus	doc_536541856911_item	3623629	et	4	main
laulurahva	doc_536541856911_item	3623627	et	3	main
teise	doc_536541856911_item	3623617	et	4	main
liblikas	doc_852214925993_item	3624073	et	4	main
läksid	doc_852214925993_item	3624068	et	4	main
tugevaks	doc_852214925993_item	3624067	et	4	main
jälle	doc_852214925993_item	3624066	et	3	main
kui	doc_852214925993_item	3624065	et	3	main
esimesel	doc_536541856911_item	3623759	et	3	main
koidula	doc_536541856911_item	3623755	et	4	main
see	doc_536541856911_item	3623752	et	3	main
ja	doc_536541856911_item	3623751	et	3	main
oma	doc_536541856911_item	3623738	et	4	main
sündmusega	doc_536541856911_item	3623723	et	3	main
selle	doc_536541856911_item	3623722	et	4	main
just	doc_536541856911_item	3623721	et	3	main
ning	doc_536541856911_item	3623720	et	3	main
kui	doc_536541856911_item	3623678	et	3	main
ja	doc_536541856911_item	3623674	et	3	main
vanad	doc_536541856911_item	3623666	et	3	main
rolli	doc_536541856911_item	3623654	et	4	main
laul	doc_536541856911_item	3623651	et	4	main
illustreerida	doc_536541856911_item	3623649	et	3	main
üldistav	doc_536541856911_item	3623639	et	4	main
300	doc_536541856911_item	3623630	et	2	main
keele	doc_536541856911_item	3623618	et	4	main
kui	doc_536541856911_item	3623616	et	3	main
keele	doc_536541856911_item	3623615	et	4	main
eesti	doc_536541856911_item	3623614	et	4	main
essee	doc_536541856911_item	3623613	et	4	main
omaette	doc_536541856911_item	3623806	et	3	main
üksinda	doc_536541856911_item	3623805	et	4	main
võib	doc_536541856911_item	3623804	et	3	main
laulda	doc_536541856911_item	3623803	et	4	main
et	doc_536541856911_item	3623802	et	3	main
see	doc_536541856911_item	3623801	et	3	main
ka	doc_536541856911_item	3623800	et	3	main
on	doc_536541856911_item	3623799	et	4	main
põhjus	doc_536541856911_item	3623798	et	4	main
tähtis	doc_536541856911_item	3623797	et	4	main
armastust	doc_536541856911_item	3623796	et	4	main
valu	doc_536541856911_item	3623795	et	4	main
hirmu	doc_536541856911_item	3623794	et	4	main
peideti	doc_536541856911_item	3623793	et	3	main
tavaliselt	doc_536541856911_item	3623792	et	4	main
mida	doc_536541856911_item	3623791	et	4	main
seda	doc_536541856911_item	3623790	et	3	main
näitasid	doc_536541856911_item	3623789	et	4	main
inimesed	doc_536541856911_item	3623788	et	3	main
lauldes	doc_536541856911_item	3623787	et	3	main
mõtteid	doc_536541856911_item	3623786	et	3	main
ehk	doc_536541856911_item	3623785	et	3	main
emotsioone	doc_536541856911_item	3623784	et	3	main
jutustas	doc_852214925993_item	3624074	et	3	main
puhkasid	doc_852214925993_item	3624063	et	4	main
sind	doc_852214925993_item	3624052	et	4	main
kas	doc_852214925993_item	3624036	et	3	main
roheline	doc_852214925993_item	3624034	et	4	main
ilus	doc_852214925993_item	3624033	et	4	main
olen	doc_852214925993_item	3624026	et	3	main
rõmustas	doc_852214925993_item	3624021	et	4	main
hüpleda	doc_852214925993_item	3624019	et	4	main
päev	doc_852214925993_item	3624018	et	3	main
ei	doc_852214925993_item	3624010	et	4	main
sa	doc_852214925993_item	3624009	et	3	main
lennata	doc_852214925993_item	3623998	et	4	main
roheline	doc_852214925993_item	3623994	et	4	main
aga	doc_852214925993_item	3623985	et	3	main
ilus	doc_852214925993_item	3623984	et	4	main
väga	doc_852214925993_item	3623983	et	3	main
väga	doc_852214925993_item	3623982	et	3	main
sinikas	doc_852214925993_item	3623981	et	4	main
lõpp	doc_852214925993_item	3624090	et	3	main
hästi	doc_852214925993_item	3624089	et	3	main
magasid	doc_852214925993_item	3624088	et	4	main
nad	doc_852214925993_item	3624087	et	3	main
sõber	doc_852214925993_item	3624086	et	3	main
hea	doc_852214925993_item	3624085	et	4	main
juba	doc_852214925993_item	3624084	et	3	main
on	doc_852214925993_item	3624083	et	4	main
liblikal	doc_852214925993_item	3624082	et	3	main
et	doc_852214925993_item	3624081	et	3	main
rõõmustas	doc_852214925993_item	3624080	et	3	main
ema	doc_852214925993_item	3624079	et	4	main
liblikaemale	doc_852214925993_item	3624075	et	3	main
lehvitasid	doc_852214925993_item	3624071	et	4	main
läksid	doc_852214925993_item	3624061	et	4	main
ma	doc_852214925993_item	3624050	et	3	main
peitad	doc_852214925993_item	3624048	et	4	main
sa	doc_852214925993_item	3624047	et	3	main
mängigu	doc_852214925993_item	3624046	et	3	main
teegu	doc_852214925993_item	3624045	et	4	main
me	doc_852214925993_item	3624044	et	4	main
mida	doc_852214925993_item	3624043	et	4	main
aga	doc_852214925993_item	3624042	et	3	main
ja	doc_852214925993_item	3624064	et	3	main
ja	doc_852214925993_item	3624049	et	3	main
sa	doc_852214925993_item	3624031	et	3	main
terve	doc_852214925993_item	3624017	et	4	main
meelest	doc_852214925993_item	3624008	et	4	main
minu	doc_852214925993_item	3624007	et	3	main
millised	doc_852214925993_item	3623975	et	3	main
sol	doc_852214925993_item	3623972	et	3	main
sa	doc_852214925993_item	3623966	et	3	main
järve	doc_852214925993_item	3623945	et	4	main
olen	doc_852214925993_item	3623939	et	3	main
oled	doc_852214925993_item	3623936	et	3	main
mis	doc_852214925993_item	3623934	et	4	main
tere	doc_852214925993_item	3623930	et	3	main
ta	doc_852214925993_item	3623928	et	4	main
konna	doc_852214925993_item	3623927	et	4	main
konnaga	doc_852214925993_item	3623921	et	3	main
kohtumis	doc_852214925993_item	3623920	et	3	main
liblikas	doc_852214925993_item	3623919	et	4	main
päev	doc_852214925993_item	3623918	et	3	main
ühel	doc_852214925993_item	3623917	et	3	main
päevast	doc_852214925993_item	3623916	et	4	main
liblika	doc_852214925993_item	3623915	et	3	main
olnud	doc_464301607714_item	3624224	et	4	main
vähe	doc_464301607714_item	3624208	et	3	main
ilu	doc_464301607714_item	3624200	et	4	main
vaid	doc_464301607714_item	3624198	et	3	main
mõelnud	doc_464301607714_item	3624193	et	4	main
ta	doc_464301607714_item	3624191	et	4	main
ainult	doc_464301607714_item	3624185	et	4	main
väärtuslikke	doc_464301607714_item	3624181	et	3	main
tõmbuma	doc_464301607714_item	3624168	et	3	main
enam	doc_464301607714_item	3624161	et	4	main
juurde	doc_464301607714_item	3624160	et	4	main
tütarde	doc_464301607714_item	3624159	et	3	main
teda	doc_464301607714_item	3624158	et	4	main
ja	doc_464301607714_item	3624157	et	3	main
raha	doc_464301607714_item	3624154	et	4	main
saamine	doc_464301607714_item	3624146	et	4	main
väljendada	doc_464301607714_item	3624133	et	3	main
ei	doc_464301607714_item	3624129	et	4	main
ta	doc_464301607714_item	3624128	et	4	main
pulgale	doc_464301607714_item	3624123	et	3	main
tütred	doc_464301607714_item	3624120	et	3	main
raha	doc_464301607714_item	3624116	et	4	main
ta	doc_464301607714_item	3624111	et	4	main
tahtis	doc_464301607714_item	3624109	et	3	main
isa	doc_464301607719_item	3624330	et	4	main
minu	doc_464301607719_item	3624329	et	3	main
raamatupidamises	doc_464301607719_item	3624328	et	3	main
abielus	doc_464301607719_item	3624316	et	4	main
on	doc_464301607719_item	3624315	et	4	main
õed	doc_464301607719_item	3624314	et	3	main
vanem	doc_464301607719_item	3624308	et	4	main
lapsi	doc_464301607719_item	3624305	et	4	main
ole	doc_464301607719_item	3624304	et	4	main
ühiskondlik	doc_464301607719_item	3624290	et	3	main
tööta	doc_464301607719_item	3624286	et	4	main
kass	doc_464301607719_item	3624282	et	3	main
meie	doc_464301607719_item	3624281	et	4	main
ja	doc_464301607719_item	3624280	et	3	main
abikaasa	doc_464301607719_item	3624279	et	4	main
mu	doc_464301607719_item	3624278	et	3	main
kell	doc_464301607739_item	3624440	et	3	main
keelt	doc_464301607739_item	3624435	et	4	main
õppisin	doc_464301607739_item	3624433	et	3	main
ma	doc_464301607739_item	3624432	et	3	main
õhtul	doc_464301607739_item	3624431	et	3	main
isaga	doc_464301607739_item	3624429	et	3	main
ja	doc_464301607739_item	3624428	et	3	main
ema	doc_464301607739_item	3624427	et	4	main
minu	doc_464301607739_item	3624426	et	3	main
kõnelesin	doc_464301607739_item	3624425	et	3	main
ma	doc_464301607739_item	3624424	et	3	main
pühapäeval	doc_464301607739_item	3624412	et	3	main
seitse	doc_464301607739_item	3624411	et	3	main
pool	doc_464301607739_item	3624410	et	4	main
me	doc_464301607739_item	3624404	et	4	main
mõtlenud	doc_464301607739_item	3624400	et	4	main
kui	doc_464301607739_item	3624397	et	3	main
muusium	doc_464301607739_item	3624394	et	4	main
linnud	doc_464301607739_item	3624393	et	3	main
ja	doc_464301607739_item	3624392	et	3	main
konn	doc_852214925993_item	3624035	et	3	main
vale	doc_852214925993_item	3624030	et	4	main
inetu	doc_852214925993_item	3624027	et	4	main
aga	doc_852214925993_item	3624025	et	3	main
olla	doc_852214925993_item	3624016	et	3	main
hea	doc_852214925993_item	3624015	et	4	main
võib	doc_852214925993_item	3624014	et	3	main
ja	doc_852214925993_item	3624013	et	3	main
inetu	doc_852214925993_item	3624012	et	4	main
oska	doc_852214925993_item	3623997	et	4	main
ei	doc_852214925993_item	3623996	et	4	main
ma	doc_852214925993_item	3623992	et	3	main
inetu	doc_852214925993_item	3623991	et	4	main
olen	doc_852214925993_item	3623990	et	3	main
et	doc_852214925993_item	3623989	et	3	main
tean	doc_852214925993_item	3623988	et	3	main
ma	doc_852214925993_item	3623987	et	3	main
juba	doc_852214925993_item	3623986	et	3	main
oled	doc_852214925993_item	3624032	et	3	main
meelest	doc_852214925993_item	3624023	et	4	main
minu	doc_852214925993_item	3624022	et	3	main
konn	doc_852214925993_item	3624020	et	3	main
ole	doc_852214925993_item	3624011	et	4	main
terve	doc_852214925993_item	3624001	et	4	main
hüplen	doc_852214925993_item	3624000	et	3	main
ma	doc_852214925993_item	3623999	et	3	main
rohekas	doc_852214925993_item	3623979	et	4	main
tiivad	doc_852214925993_item	3623974	et	3	main
kas	doc_852214925993_item	3623965	et	3	main
oskan	doc_852214925993_item	3623963	et	3	main
mulle	doc_852214925993_item	3623958	et	4	main
maailmas	doc_852214925993_item	3623957	et	3	main
elan	doc_852214925993_item	3623956	et	3	main
ma	doc_852214925993_item	3623955	et	3	main
juures	doc_852214925993_item	3623946	et	4	main
ma	doc_852214925993_item	3623941	et	3	main
ma	doc_852214925993_item	3623938	et	3	main
ei	doc_464301607714_item	3624223	et	4	main
tütarde	doc_464301607714_item	3624214	et	3	main
et	doc_464301607714_item	3624213	et	3	main
pärast	doc_464301607714_item	3624212	et	4	main
põhjus	doc_464301607714_item	3624202	et	4	main
tegelik	doc_464301607714_item	3624201	et	3	main
et	doc_464301607714_item	3624195	et	3	main
võimaldada	doc_464301607714_item	3624189	et	3	main
oma	doc_464301607714_item	3624180	et	4	main
oli	doc_464301607714_item	3624176	et	3	main
tütarde	doc_464301607714_item	3624174	et	3	main
oodatud	doc_464301607714_item	3624163	et	4	main
sai	doc_464301607714_item	3624156	et	4	main
ja	doc_852214925993_item	3623980	et	3	main
ilusad	doc_852214925993_item	3623976	et	3	main
näen	doc_852214925993_item	3623971	et	3	main
liblikatüdruk	doc_852214925993_item	3623954	et	3	main
kes	doc_852214925993_item	3623948	et	4	main
aga	doc_852214925993_item	3623947	et	3	main
või	doc_852214925993_item	3623944	et	4	main
elan	doc_852214925993_item	3623942	et	3	main
konn	doc_852214925993_item	3623940	et	3	main
sa	doc_852214925993_item	3623935	et	3	main
oled	doc_852214925993_item	3623933	et	3	main
sa	doc_852214925993_item	3623932	et	3	main
küsis	doc_852214925993_item	3623929	et	3	main
ei	doc_852214925993_item	3623924	et	4	main
ta	doc_852214925993_item	3623923	et	4	main
aga	doc_852214925993_item	3623922	et	3	main
ma	doc_852214925993_item	3623970	et	3	main
lennata	doc_852214925993_item	3623968	et	4	main
ma	doc_852214925993_item	3623962	et	3	main
ja	doc_852214925993_item	3623961	et	3	main
ilus	doc_852214925993_item	3623953	et	4	main
ma	doc_852214925993_item	3623951	et	3	main
sa	doc_852214925993_item	3623949	et	3	main
jõe	doc_852214925993_item	3623943	et	3	main
tere	doc_852214925993_item	3623937	et	3	main
veel	doc_852214925993_item	3623926	et	4	main
näinud	doc_852214925993_item	3623925	et	4	main
essee	doc_852214925993_item	3623914	et	4	main
mis	doc_852214925993_item	3624077	et	4	main
kättesaid	doc_464301607714_item	3624222	et	4	main
gorioti	doc_464301607714_item	3624217	et	4	main
häbenesid	doc_464301607714_item	3624216	et	4	main
mehed	doc_464301607714_item	3624215	et	3	main
miks	doc_464301607714_item	3624203	et	4	main
on	doc_464301607714_item	3624197	et	4	main
sellele	doc_464301607714_item	3624194	et	4	main
ei	doc_464301607714_item	3624192	et	4	main
neile	doc_464301607714_item	3624186	et	4	main
asju	doc_464301607714_item	3624182	et	3	main
ta	doc_464301607714_item	3624177	et	4	main
ei	doc_464301607714_item	3624162	et	4	main
kui	doc_464301607714_item	3624152	et	3	main
neile	doc_464301607714_item	3624148	et	4	main
kõrgseldskonda	doc_464301607714_item	3624145	et	4	main
nende	doc_464301607714_item	3624144	et	4	main
et	doc_464301607714_item	3624143	et	3	main
arvas	doc_464301607714_item	3624142	et	3	main
neile	doc_464301607714_item	3624137	et	4	main
andis	doc_464301607714_item	3624136	et	3	main
oma	doc_464301607714_item	3624131	et	4	main
inglitega	doc_464301607714_item	3624121	et	3	main
nendele	doc_464301607714_item	3624113	et	4	main
vaeses	doc_464301607714_item	3624101	et	4	main
oli	doc_464301607714_item	3624100	et	3	main
goriot	doc_464301607714_item	3624099	et	4	main
elab	doc_464301607719_item	3624331	et	3	main
õde	doc_464301607719_item	3624319	et	4	main
keskmine	doc_464301607719_item	3624318	et	3	main
minu	doc_464301607719_item	3624317	et	3	main
õde	doc_464301607719_item	3624309	et	4	main
on	doc_464301607719_item	3624307	et	4	main
on	doc_464301607719_item	3624300	et	4	main
ta	doc_464301607719_item	3624299	et	4	main
kontoris	doc_464301607719_item	3624298	et	3	main
töötab	doc_464301607719_item	3624297	et	3	main
on	doc_464301607719_item	3624289	et	4	main
mina	doc_464301607719_item	3624277	et	4	main
inimest	doc_464301607719_item	3624276	et	3	main
kaks	doc_464301607719_item	3624275	et	3	main
magada	doc_464301607739_item	3624438	et	3	main
umbes	doc_464301607739_item	3624409	et	4	main
selle	doc_464301607739_item	3624403	et	4	main
väikem	doc_464301607739_item	3624396	et	4	main
nädalavahetusel	doc_464301607739_item	3624352	et	4	main
tegin	doc_464301607739_item	3624351	et	3	main
ma	doc_464301607739_item	3624350	et	3	main
mis	doc_464301607739_item	3624349	et	4	main
nädalavahetus	doc_464301607740_item	3624595	et	4	main
siis	doc_464301607740_item	3624583	et	3	main
me	doc_464301607740_item	3624577	et	4	main
õhtul	doc_464301607740_item	3624576	et	3	main
väga	doc_464301607740_item	3624574	et	3	main
reede	doc_464301607740_item	3624455	et	4	main
tegin	doc_464301607740_item	3624447	et	3	main
villased	doc_464301607740_item	3624558	et	4	main
nii	doc_464301607740_item	3624554	et	3	main
olnud	doc_464301607740_item	3624552	et	4	main
jõuluturule	doc_464301607740_item	3624550	et	3	main
kodus	doc_464301607740_item	3624545	et	4	main
hommikusöök	doc_464301607740_item	3624544	et	3	main
suur	doc_464301607740_item	3624543	et	3	main
oli	doc_464301607740_item	3624542	et	3	main
meil	doc_464301607740_item	3624541	et	4	main
pühapäeval	doc_464301607740_item	3624540	et	3	main
koju	doc_464301607740_item	3624539	et	3	main
jalutasime	doc_464301607740_item	3624538	et	3	main
seal	doc_464301607740_item	3624502	et	4	main
film	doc_464301607740_item	3624491	et	3	main
kes	doc_852214925993_item	3623931	et	4	main
oli	doc_852214925993_item	3624078	et	3	main
selle	doc_464301607714_item	3624211	et	4	main
oli	doc_464301607714_item	3624210	et	3	main
nii	doc_464301607714_item	3624207	et	3	main
oma	doc_464301607714_item	3624205	et	4	main
goriot	doc_464301607714_item	3624204	et	4	main
rikkus	doc_464301607714_item	3624196	et	4	main
elu	doc_464301607714_item	3624188	et	4	main
paremat	doc_464301607714_item	3624187	et	4	main
pantima	doc_464301607714_item	3624183	et	4	main
nõus	doc_464301607714_item	3624178	et	4	main
jaoks	doc_464301607714_item	3624175	et	4	main
valmistada	doc_464301607714_item	3624173	et	3	main
eemal	doc_464301607714_item	3624167	et	3	main
otsa	doc_464301607714_item	3624155	et	4	main
ta	doc_464301607714_item	3624141	et	4	main
ta	doc_464301607714_item	3624135	et	4	main
tundeid	doc_464301607714_item	3624132	et	3	main
kindlasti	doc_464301607714_item	3624124	et	3	main
seadis	doc_464301607714_item	3624118	et	4	main
kogu	doc_464301607714_item	3624114	et	4	main
aidata	doc_464301607714_item	3624110	et	4	main
ilma	doc_464301607714_item	3624248	et	4	main
kõigest	doc_464301607714_item	3624247	et	4	main
ise	doc_464301607714_item	3624246	et	4	main
ta	doc_464301607714_item	3624245	et	4	main
jäi	doc_464301607714_item	3624244	et	3	main
head	doc_464301607714_item	3624243	et	4	main
lastele	doc_464301607714_item	3624242	et	4	main
oma	doc_464301607714_item	3624241	et	4	main
soovides	doc_464301607714_item	3624240	et	4	main
riided	doc_464301607714_item	3624239	et	3	main
ilusad	doc_464301607714_item	3624238	et	3	main
ja	doc_464301607714_item	3624237	et	3	main
raha	doc_464301607714_item	3624236	et	4	main
põhiline	doc_464301607714_item	3624235	et	3	main
oligi	doc_464301607714_item	3624234	et	3	main
pariisis	doc_464301607714_item	3624233	et	4	main
aegses	doc_464301607714_item	3624232	et	3	main
selle	doc_464301607714_item	3624231	et	4	main
külma	doc_464301607714_item	3624230	et	4	main
ega	doc_464301607714_item	3624229	et	3	main
sooja	doc_464301607714_item	3624228	et	4	main
ei	doc_464301607714_item	3624227	et	4	main
isast	doc_464301607714_item	3624226	et	4	main
neil	doc_464301607714_item	3624225	et	4	main
kaasavara	doc_464301607714_item	3624221	et	4	main
tütarde	doc_464301607714_item	3624220	et	3	main
mehed	doc_464301607714_item	3624219	et	3	main
kui	doc_464301607714_item	3624218	et	3	main
nägi	doc_464301607714_item	3624209	et	3	main
tütreid	doc_464301607714_item	3624206	et	3	main
näilik	doc_464301607714_item	3624199	et	3	main
samas	doc_464301607714_item	3624190	et	4	main
et	doc_464301607714_item	3624184	et	3	main
isegi	doc_464301607714_item	3624179	et	4	main
piilikus	doc_464301607714_item	3624172	et	4	main
tütardele	doc_464301607714_item	3624171	et	3	main
mitte	doc_464301607714_item	3624170	et	3	main
et	doc_464301607714_item	3624169	et	3	main
nõus	doc_464301607714_item	3624166	et	4	main
ta	doc_464301607714_item	3624165	et	4	main
oli	doc_464301607714_item	3624164	et	3	main
goriotil	doc_464301607714_item	3624153	et	4	main
vaated	doc_464301607714_item	3624151	et	3	main
elu	doc_464301607714_item	3624150	et	4	main
paremat	doc_464301607714_item	3624149	et	4	main
avab	doc_464301607714_item	3624147	et	3	main
ning	doc_464301607714_item	3624134	et	3	main
osanud	doc_464301607714_item	3624130	et	4	main
kõrgemale	doc_464301607714_item	3624127	et	4	main
goriot	doc_464301607714_item	3624117	et	4	main
perekonnas	doc_464301607714_item	3624102	et	4	main
ta	doc_464301607719_item	3624326	et	4	main
õde	doc_464301607719_item	3624313	et	4	main
kaks	doc_464301607719_item	3624312	et	3	main
on	doc_464301607719_item	3624311	et	4	main
mul	doc_464301607719_item	3624310	et	3	main
mul	doc_464301607719_item	3624306	et	3	main
juhataja	doc_464301607719_item	3624301	et	4	main
veel	doc_464301607719_item	3624284	et	4	main
mina	doc_464301607719_item	3624283	et	4	main
meie	doc_464301607719_item	3624272	et	4	main
kaks	doc_464301607739_item	3624441	et	3	main
ja	doc_464301607739_item	3624436	et	3	main
skypega	doc_464301607739_item	3624430	et	4	main
ühiselamusse	doc_464301607739_item	3624408	et	4	main
meeldib	doc_464301607739_item	3624402	et	3	main
ma	doc_464301607739_item	3624398	et	3	main
läupäeval	doc_464301607739_item	3624353	et	4	main
essee	doc_464301607739_item	3624348	et	4	main
kallis	doc_464301607740_item	3624594	et	4	main
ka	doc_464301607740_item	3624592	et	3	main
aga	doc_464301607740_item	3624591	et	3	main
lõbus	doc_464301607740_item	3624590	et	4	main
väga	doc_464301607740_item	3624589	et	3	main
oli	doc_464301607740_item	3624588	et	3	main
kinno	doc_464301607740_item	3624587	et	3	main
sõime	doc_464301607740_item	3624578	et	4	main
hea	doc_464301607740_item	3624575	et	4	main
ka	doc_464301607740_item	3624573	et	3	main
ja	doc_464301607740_item	3624572	et	3	main
film	doc_464301607740_item	3624571	et	3	main
iiri	doc_464301607740_item	3624570	et	4	main
oli	doc_464301607740_item	3624569	et	3	main
see	doc_464301607740_item	3624568	et	3	main
kinno	doc_464301607740_item	3624567	et	3	main
jälle	doc_464301607740_item	3624566	et	3	main
läksime	doc_464301607740_item	3624565	et	3	main
kolisime	doc_464301607740_item	3624470	et	3	main
me	doc_464301607740_item	3624469	et	4	main
laupäeval	doc_464301607740_item	3624468	et	3	main
juurde	doc_464301607740_item	3624454	et	4	main
minu	doc_464301607740_item	3624453	et	3	main
kangast	doc_464301607740_item	3624562	et	4	main
põdra	doc_464301607740_item	3624561	et	3	main
ja	doc_464301607740_item	3624560	et	3	main
kindad	doc_464301607740_item	3624559	et	3	main
enam	doc_464301607740_item	3624553	et	4	main
ei	doc_464301607740_item	3624551	et	4	main
tahtnud	doc_464301607740_item	3624505	et	4	main
me	doc_464301607740_item	3624503	et	4	main
pärast	doc_464301607740_item	3624495	et	4	main
raha	doc_464301607714_item	3624140	et	4	main
asemel	doc_464301607714_item	3624139	et	4	main
selle	doc_464301607714_item	3624138	et	4	main
enesest	doc_464301607714_item	3624126	et	4	main
aga	doc_464301607714_item	3624125	et	3	main
ühele	doc_464301607714_item	3624122	et	3	main
oma	doc_464301607714_item	3624119	et	4	main
aeg	doc_464301607714_item	3624115	et	3	main
andis	doc_464301607714_item	3624112	et	3	main
ta	doc_464301607714_item	3624108	et	4	main
kellele	doc_464301607714_item	3624107	et	4	main
tütart	doc_464301607714_item	3624106	et	3	main
kaks	doc_464301607714_item	3624105	et	3	main
oli	doc_464301607714_item	3624104	et	3	main
tal	doc_464301607714_item	3624103	et	3	main
isa	doc_464301607714_item	3624098	et	4	main
voorused	doc_464301607714_item	3624097	et	3	main
ja	doc_464301607714_item	3624096	et	3	main
puudused	doc_464301607714_item	3624095	et	3	main
goriot	doc_464301607714_item	3624094	et	4	main
isa	doc_464301607714_item	3624093	et	4	main
essee	doc_464301607714_item	3624092	et	4	main
töötab	doc_464301607719_item	3624327	et	3	main
õde	doc_464301607719_item	3624323	et	4	main
noorem	doc_464301607719_item	3624322	et	4	main
minu	doc_464301607719_item	3624321	et	3	main
töötab	doc_464301607719_item	3624320	et	3	main
meil	doc_464301607719_item	3624302	et	4	main
töö	doc_464301607719_item	3624291	et	4	main
mul	doc_464301607719_item	3624288	et	3	main
ei	doc_464301607719_item	3624285	et	4	main
perekonnas	doc_464301607719_item	3624273	et	4	main
umbes	doc_464301607739_item	3624439	et	4	main
interneti	doc_464301607739_item	3624423	et	4	main
kasutan	doc_464301607739_item	3624422	et	3	main
ülikoolis	doc_464301607739_item	3624421	et	4	main
käisin	doc_464301607739_item	3624420	et	3	main
ma	doc_464301607739_item	3624419	et	3	main
aga	doc_464301607739_item	3624418	et	3	main
spetsiaalse	doc_464301607739_item	3624416	et	3	main
meie	doc_464301607739_item	3624407	et	4	main
koju	doc_464301607739_item	3624406	et	3	main
tulime	doc_464301607739_item	3624405	et	3	main
ka	doc_464301607739_item	3624389	et	3	main
käisin	doc_464301607739_item	3624355	et	3	main
jälle	doc_464301607740_item	3624586	et	3	main
jõime	doc_464301607740_item	3624581	et	3	main
pannkogid	doc_464301607740_item	3624579	et	4	main
meeldinud	doc_464301607740_item	3624467	et	4	main
ei	doc_464301607740_item	3624466	et	4	main
meile	doc_464301607740_item	3624465	et	4	main
nädalavahetusel	doc_464301607740_item	3624452	et	4	main
nädalavahetusel	doc_464301607740_item	3624446	et	4	main
ma	doc_464301607740_item	3624445	et	3	main
essee	doc_464301607740_item	3624443	et	4	main
me	doc_464301607740_item	3624564	et	4	main
siis	doc_464301607740_item	3624563	et	3	main
ma	doc_464301607740_item	3624556	et	3	main
me	doc_464301607740_item	3624537	et	4	main
2	doc_464301607740_item	3624536	et	2	main
kell	doc_464301607740_item	3624535	et	3	main
välja	doc_464301607740_item	3624506	et	4	main
oli	doc_464301607740_item	3624492	et	3	main
jälle	doc_464301607740_item	3624489	et	3	main
külm	doc_464301607740_item	3624486	et	3	main
oli	doc_464301607740_item	3624484	et	3	main
aga	doc_464301607740_item	3624482	et	3	main
valiv	doc_980560860247_item	3624718	et	4	main
maitset	doc_980560860247_item	3624710	et	3	main
on	doc_980560860247_item	3624707	et	4	main
sõbratar	doc_980560860247_item	3624706	et	3	main
minu	doc_980560860247_item	3624705	et	3	main
proovima	doc_980560860247_item	3624704	et	3	main
on	doc_980560860247_item	3624694	et	4	main
keskalinasse	doc_980560860247_item	3624688	et	4	main
pensionärid	doc_464301607719_item	3624346	et	3	main
juba	doc_464301607719_item	3624345	et	3	main
on	doc_464301607719_item	3624344	et	4	main
nad	doc_464301607719_item	3624343	et	3	main
tallinnas	doc_464301607719_item	3624342	et	4	main
elavad	doc_464301607719_item	3624341	et	4	main
äi	doc_464301607719_item	3624340	et	3	main
ja	doc_464301607719_item	3624339	et	3	main
minu	doc_464301607719_item	3624337	et	3	main
ämm	doc_464301607719_item	3624338	et	3	main
pensionär	doc_464301607719_item	3624336	et	3	main
juba	doc_464301607719_item	3624335	et	3	main
isa	doc_464301607719_item	3624333	et	4	main
on	doc_464301607719_item	3624334	et	4	main
ukrainas	doc_464301607719_item	3624332	et	4	main
raamatupidaja	doc_464301607719_item	3624325	et	4	main
on	doc_464301607719_item	3624324	et	4	main
ei	doc_464301607719_item	3624303	et	4	main
abikaasa	doc_464301607719_item	3624296	et	4	main
minu	doc_464301607719_item	3624295	et	3	main
arst	doc_464301607719_item	3624294	et	3	main
olen	doc_464301607719_item	3624293	et	3	main
ma	doc_464301607719_item	3624292	et	3	main
aga	doc_464301607719_item	3624287	et	3	main
on	doc_464301607719_item	3624274	et	4	main
perekond	doc_464301607719_item	3624271	et	3	main
väike	doc_464301607719_item	3624270	et	4	main
on	doc_464301607719_item	3624269	et	4	main
meil	doc_464301607719_item	3624268	et	4	main
narval	doc_464301607719_item	3624267	et	2	main
elame	doc_464301607719_item	3624266	et	3	main
me	doc_464301607719_item	3624265	et	4	main
abielus	doc_464301607719_item	3624264	et	4	main
olen	doc_464301607719_item	3624263	et	3	main
ma	doc_464301607719_item	3624262	et	3	main
perekonnanimi	doc_464301607719_item	3624261	et	3	main
on	doc_464301607719_item	3624260	et	4	main
perekonnanimi	doc_464301607719_item	3624259	et	3	main
minu	doc_464301607719_item	3624258	et	3	main
ja	doc_464301607719_item	3624257	et	3	main
eesnimi	doc_464301607719_item	3624256	et	3	main
on	doc_464301607719_item	3624255	et	4	main
eesnimi	doc_464301607719_item	3624254	et	3	main
minu	doc_464301607719_item	3624253	et	3	main
perekond	doc_464301607719_item	3624252	et	3	main
meie	doc_464301607719_item	3624251	et	4	main
essee	doc_464301607719_item	3624250	et	4	main
tulin	doc_464301607739_item	3624437	et	3	main
inglise	doc_464301607739_item	3624434	et	4	main
asjad	doc_464301607739_item	3624417	et	3	main
tee	doc_464301607739_item	3624415	et	4	main
ei	doc_464301607739_item	3624414	et	4	main
ma	doc_464301607739_item	3624413	et	3	main
aga	doc_464301607739_item	3624401	et	3	main
olen	doc_464301607739_item	3624399	et	3	main
oli	doc_464301607739_item	3624395	et	3	main
oli	doc_464301607739_item	3624388	et	3	main
seal	doc_464301607739_item	3624387	et	4	main
sest	doc_464301607739_item	3624386	et	4	main
ilus	doc_464301607739_item	3624385	et	4	main
väga	doc_464301607739_item	3624384	et	3	main
oli	doc_464301607739_item	3624383	et	3	main
see	doc_464301607739_item	3624382	et	3	main
ja	doc_464301607739_item	3624381	et	3	main
läbi	doc_464301607739_item	3624380	et	4	main
park	doc_464301607739_item	3624379	et	3	main
kadriorg	doc_464301607739_item	3624378	et	3	main
muusium	doc_464301607739_item	3624377	et	4	main
käisime	doc_464301607739_item	3624376	et	3	main
me	doc_464301607739_item	3624375	et	4	main
tänavas	doc_464301607739_item	3624374	et	4	main
lund	doc_464301607739_item	3624373	et	3	main
palju	doc_464301607739_item	3624372	et	4	main
oli	doc_464301607739_item	3624371	et	3	main
seal	doc_464301607739_item	3624370	et	4	main
külma	doc_464301607739_item	3624369	et	4	main
kraadi	doc_464301607739_item	3624368	et	4	main
viis	doc_464301607739_item	3624367	et	4	main
oli	doc_464301607739_item	3624366	et	3	main
see	doc_464301607739_item	3624365	et	3	main
sest	doc_464301607739_item	3624364	et	4	main
külm	doc_464301607739_item	3624363	et	3	main
oli	doc_464301607739_item	3624361	et	3	main
väga	doc_464301607739_item	3624362	et	3	main
ilm	doc_464301607739_item	3624360	et	3	main
sõbraga	doc_464301607739_item	3624359	et	3	main
minu	doc_464301607739_item	3624358	et	3	main
muusiumus	doc_464301607739_item	3624357	et	4	main
kumu	doc_464301607739_item	3624356	et	4	main
lund	doc_464301607739_item	3624391	et	3	main
palju	doc_464301607739_item	3624390	et	4	main
laksime	doc_464301607740_item	3624585	et	3	main
ja	doc_464301607740_item	3624580	et	3	main
aga	doc_464301607740_item	3624464	et	3	main
film	doc_464301607740_item	3624463	et	3	main
taani	doc_464301607740_item	3624462	et	4	main
oli	doc_464301607740_item	3624461	et	3	main
tuli	doc_464301607740_item	3624451	et	4	main
sõber	doc_464301607740_item	3624449	et	3	main
mis	doc_464301607740_item	3624444	et	4	main
ostsin	doc_464301607740_item	3624557	et	3	main
külm	doc_464301607740_item	3624555	et	3	main
läksime	doc_464301607740_item	3624549	et	3	main
siis	doc_464301607740_item	3624546	et	3	main
klubisse	doc_464301607740_item	3624523	et	3	main
läksime	doc_464301607740_item	3624522	et	3	main
me	doc_464301607740_item	3624521	et	4	main
siis	doc_464301607740_item	3624520	et	3	main
juttu	doc_464301607740_item	3624519	et	4	main
ajasime	doc_464301607740_item	3624518	et	3	main
ja	doc_464301607740_item	3624517	et	3	main
seal	doc_464301607740_item	3624516	et	4	main
ka	doc_464301607740_item	3624515	et	3	main
sõime	doc_464301607740_item	3624514	et	4	main
me	doc_464301607740_item	3624513	et	4	main
sellepärast	doc_464301607740_item	3624512	et	3	main
külm	doc_464301607740_item	3624511	et	3	main
nii	doc_464301607740_item	3624510	et	3	main
oli	doc_464301607740_item	3624509	et	3	main
ma	doc_464301607739_item	3624354	et	3	main
natuke	doc_464301607740_item	3624593	et	4	main
me	doc_464301607740_item	3624584	et	4	main
hõõgveini	doc_464301607740_item	3624582	et	4	main
see	doc_464301607740_item	3624460	et	3	main
kinno	doc_464301607740_item	3624459	et	3	main
läksime	doc_464301607740_item	3624458	et	3	main
me	doc_464301607740_item	3624457	et	4	main
õhtul	doc_464301607740_item	3624456	et	3	main
viinist	doc_464301607740_item	3624450	et	3	main
üks	doc_464301607740_item	3624448	et	3	main
lõpuks	doc_464301607740_item	3624548	et	4	main
me	doc_464301607740_item	3624547	et	4	main
natuke	doc_464301607740_item	3624534	et	4	main
tantsisime	doc_464301607740_item	3624533	et	3	main
me	doc_464301607740_item	3624532	et	4	main
siis	doc_464301607740_item	3624531	et	3	main
sõnu	doc_464301607740_item	3624530	et	4	main
eesti	doc_464301607740_item	3624529	et	4	main
uid	doc_464301607740_item	3624528	et	4	main
mulle	doc_464301607740_item	3624527	et	4	main
õpetas	doc_464301607740_item	3624526	et	3	main
tüdruk	doc_464301607740_item	3624525	et	3	main
üks	doc_464301607740_item	3624524	et	3	main
me	doc_464301607740_item	3624496	et	4	main
hea	doc_464301607740_item	3624494	et	4	main
me	doc_464301607740_item	3624475	et	4	main
ta	doc_980560860247_item	3624716	et	4	main
pean	doc_980560860247_item	3624701	et	4	main
ma	doc_980560860247_item	3624700	et	3	main
meeldi	doc_980560860247_item	3624692	et	4	main
pean	doc_980560860247_item	3624687	et	4	main
juhuslikult	doc_980560860247_item	3624685	et	4	main
väga	doc_980560860247_item	3624683	et	3	main
meeldib	doc_980560860247_item	3624667	et	3	main
terve	doc_980560860247_item	3624665	et	4	main
väga	doc_980560860247_item	3624664	et	3	main
valin	doc_980560860247_item	3624653	et	3	main
ja	doc_980560860247_item	3624638	et	3	main
tööt	doc_980560860247_item	3624631	et	4	main
minu	doc_980560860247_item	3624630	et	3	main
ning	doc_980560860247_item	3624629	et	3	main
lemmik	doc_980560860253_item	3624794	et	3	main
on	doc_980560860253_item	3624792	et	4	main
york	doc_980560860253_item	3624791	et	4	main
new	doc_980560860253_item	3624790	et	4	main
lõpuks	doc_980560860253_item	3624785	et	4	main
tahan	doc_980560860253_item	3624776	et	3	main
augustil	doc_980560860253_item	3624765	et	3	main
inimesed	doc_980560860253_item	3624764	et	3	main
kohtusin	doc_980560860253_item	3624762	et	4	main
nõus	doc_980560860253_item	3624760	et	4	main
john	doc_980560860253_item	3624746	et	4	main
sõber	doc_980560860253_item	3624745	et	3	main
minu	doc_980560860253_item	3624744	et	3	main
maailmas	doc_980560860254_item	3625001	et	3	main
ainult	doc_980560860254_item	3624996	et	4	main
aga	doc_980560860254_item	3624993	et	3	main
tunen	doc_980560860254_item	3624988	et	4	main
võistlust	doc_980560860254_item	3624985	et	3	main
ragbi	doc_980560860254_item	3624974	et	4	main
mängivad	doc_980560860254_item	3624962	et	4	main
sõbrad	doc_980560860254_item	3624961	et	3	main
ma	doc_980560860254_item	3624943	et	3	main
ragbi	doc_980560860254_item	3624936	et	4	main
inimest	doc_980560860254_item	3624916	et	3	main
ragbi	doc_980560860254_item	3624909	et	4	main
teineteist	doc_980560860254_item	3624896	et	4	main
pead	doc_980560860254_item	3624895	et	4	main
väga	doc_980560860254_item	3624890	et	3	main
peaksite	doc_980560860254_item	3624884	et	4	main
meest	doc_980560860254_item	3624873	et	4	main
on	doc_980560860254_item	3624867	et	4	main
šotimeeskond	doc_980560860254_item	3624866	et	2	main
sest	doc_464301607740_item	3624508	et	4	main
minna	doc_464301607740_item	3624507	et	3	main
ei	doc_464301607740_item	3624504	et	4	main
hõõgveini	doc_464301607740_item	3624501	et	4	main
jõime	doc_464301607740_item	3624500	et	3	main
ja	doc_464301607740_item	3624499	et	3	main
kohvikus	doc_464301607740_item	3624498	et	3	main
istusime	doc_464301607740_item	3624497	et	3	main
väga	doc_464301607740_item	3624493	et	3	main
kohvikus	doc_464301607740_item	3624474	et	3	main
lõunastasime	doc_464301607740_item	3624473	et	3	main
ja	doc_464301607740_item	3624472	et	3	main
sõpradega	doc_464301607740_item	3624471	et	3	main
ma	doc_980560860247_item	3624714	et	3	main
head	doc_980560860247_item	3624709	et	4	main
ja	doc_980560860247_item	3624699	et	3	main
kiire	doc_980560860247_item	3624698	et	4	main
ei	doc_980560860247_item	3624691	et	4	main
ma	doc_980560860247_item	3624686	et	3	main
nädalavahetus	doc_980560860247_item	3624679	et	4	main
armasta	doc_980560860247_item	3624678	et	4	main
jooma	doc_980560860247_item	3624661	et	4	main
teravili	doc_980560860247_item	3624651	et	3	main
lähen	doc_980560860247_item	3624645	et	3	main
ma	doc_980560860247_item	3624644	et	3	main
oleks	doc_980560860247_item	3624639	et	3	main
töötast	doc_980560860247_item	3624636	et	4	main
ma	doc_980560860247_item	3624634	et	3	main
töötan	doc_980560860247_item	3624627	et	3	main
äärelinna	doc_980560860247_item	3624625	et	4	main
ma	doc_980560860247_item	3624622	et	3	main
york	doc_980560860253_item	3624800	et	4	main
yorkisse	doc_980560860253_item	3624789	et	4	main
las	doc_980560860253_item	3624782	et	4	main
läksin	doc_980560860253_item	3624781	et	3	main
ma	doc_980560860253_item	3624780	et	3	main
fransiscosse	doc_980560860253_item	3624772	et	4	main
san	doc_980560860253_item	3624771	et	4	main
ameerikasse	doc_980560860253_item	3624768	et	4	main
ma	doc_980560860253_item	3624766	et	3	main
palju	doc_980560860253_item	3624763	et	4	main
ma	doc_980560860253_item	3624761	et	3	main
on	doc_980560860253_item	3624753	et	4	main
töö	doc_980560860253_item	3624741	et	4	main
kinno	doc_464301607740_item	3624490	et	3	main
läksime	doc_464301607740_item	3624488	et	3	main
liiga	doc_464301607740_item	3624485	et	4	main
mõtlen	doc_980560860247_item	3624715	et	3	main
aga	doc_980560860247_item	3624712	et	3	main
väga	doc_980560860247_item	3624697	et	3	main
siin	doc_980560860247_item	3624696	et	4	main
ka	doc_980560860247_item	3624695	et	3	main
minema	doc_980560860247_item	3624689	et	3	main
kiire	doc_980560860247_item	3624684	et	4	main
on	doc_980560860247_item	3624682	et	4	main
sest	doc_980560860247_item	3624681	et	4	main
minema	doc_980560860247_item	3624680	et	3	main
ei	doc_980560860247_item	3624677	et	4	main
ma	doc_980560860247_item	3624676	et	3	main
vaiksem	doc_980560860247_item	3624675	et	4	main
kõige	doc_980560860247_item	3624674	et	4	main
segakauplus	doc_980560860247_item	3624673	et	3	main
on	doc_980560860247_item	3624672	et	4	main
hommikul	doc_980560860247_item	3624671	et	3	main
sest	doc_980560860247_item	3624670	et	4	main
minema	doc_980560860247_item	3624669	et	3	main
hommikul	doc_980560860247_item	3624668	et	3	main
me	doc_464301607740_item	3624487	et	4	main
väljas	doc_464301607740_item	3624483	et	4	main
juua	doc_464301607740_item	3624481	et	3	main
hõõgveini	doc_464301607740_item	3624480	et	4	main
ja	doc_464301607740_item	3624479	et	3	main
minna	doc_464301607740_item	3624478	et	3	main
jõuluturule	doc_464301607740_item	3624477	et	3	main
tahtsime	doc_464301607740_item	3624476	et	3	main
on	doc_980560860247_item	3624717	et	4	main
sageli	doc_980560860247_item	3624713	et	3	main
omama	doc_980560860247_item	3624711	et	4	main
riided	doc_980560860247_item	3624708	et	3	main
selga	doc_980560860247_item	3624703	et	4	main
riided	doc_980560860247_item	3624702	et	3	main
sest	doc_980560860247_item	3624693	et	4	main
mulle	doc_980560860247_item	3624690	et	4	main
mulle	doc_980560860247_item	3624666	et	4	main
võimatu	doc_980560860247_item	3624640	et	4	main
paisleys	doc_980560860247_item	3624628	et	4	main
segakauplus	doc_980560860247_item	3624624	et	3	main
asemel	doc_980560860247_item	3624621	et	4	main
selle	doc_980560860247_item	3624620	et	4	main
on	doc_980560860247_item	3624663	et	4	main
sest	doc_980560860247_item	3624662	et	4	main
lõunasöök	doc_980560860247_item	3624657	et	3	main
ja	doc_980560860247_item	3624656	et	3	main
ma	doc_980560860247_item	3624652	et	3	main
leib	doc_980560860247_item	3624649	et	3	main
ostan	doc_980560860247_item	3624648	et	3	main
ma	doc_980560860247_item	3624647	et	3	main
tavaliselt	doc_980560860247_item	3624643	et	4	main
tassima	doc_980560860247_item	3624642	et	3	main
palju	doc_980560860247_item	3624641	et	4	main
bussiga	doc_980560860247_item	3624637	et	3	main
sõidan	doc_980560860247_item	3624635	et	3	main
jüüres	doc_980560860247_item	3624633	et	4	main
asda	doc_980560860247_item	3624632	et	4	main
ma	doc_980560860247_item	3624626	et	3	main
lähen	doc_980560860247_item	3624623	et	3	main
minu	doc_980560860253_item	3624793	et	3	main
new	doc_980560860253_item	3624788	et	4	main
ma	doc_980560860253_item	3624786	et	3	main
ärritav	doc_980560860253_item	3624784	et	4	main
vegasse	doc_980560860253_item	3624783	et	4	main
hiilgav	doc_980560860253_item	3624773	et	4	main
läksin	doc_980560860253_item	3624770	et	3	main
ilus	doc_980560860253_item	3624755	et	4	main
mõtlesin	doc_980560860253_item	3624750	et	3	main
raske	doc_980560860253_item	3624743	et	4	main
oli	doc_980560860253_item	3624742	et	3	main
parem	doc_980560860254_item	3624999	et	4	main
saaks	doc_980560860254_item	3624991	et	3	main
sest	doc_980560860254_item	3624977	et	4	main
ma	doc_980560860254_item	3624972	et	3	main
oma	doc_980560860254_item	3624960	et	4	main
kuni	doc_980560860254_item	3624937	et	3	main
ka	doc_980560860254_item	3624926	et	3	main
oli	doc_980560860254_item	3624925	et	3	main
minu	doc_980560860254_item	3624918	et	3	main
ma	doc_980560860254_item	3624912	et	3	main
on	doc_980560860254_item	3624901	et	4	main
mõnikord	doc_980560860254_item	3624899	et	3	main
ja	doc_980560860254_item	3624898	et	3	main
sport	doc_980560860254_item	3624892	et	3	main
siis	doc_980560860254_item	3624882	et	3	main
pälju	doc_980560860254_item	3624863	et	4	main
on	doc_980560860254_item	3624862	et	4	main
eestimaal	doc_980560860254_item	3624860	et	4	main
õige	doc_980560860254_item	3624859	et	4	main
mänginud	doc_980560860254_item	3624846	et	4	main
mängima	doc_980560860254_item	3624832	et	3	main
algasin	doc_980560860254_item	3624830	et	3	main
oma	doc_980560860254_item	3624841	et	4	main
siiski	doc_980560860255_item	3625099	et	4	main
eestlasi	doc_980560860255_item	3625081	et	3	main
palju	doc_980560860255_item	3625080	et	4	main
varem	doc_980560860255_item	3625077	et	4	main
pronkssõdurit	doc_980560860255_item	3625075	et	3	main
siiski	doc_980560860255_item	3625067	et	4	main
mati	doc_980560860255_item	3625064	et	4	main
12	doc_980560860255_item	3625062	et	2	main
ja	doc_980560860255_item	3625061	et	3	main
liidu	doc_980560860255_item	3625060	et	3	main
nõukogude	doc_980560860255_item	3625059	et	3	main
sõdure	doc_980560860255_item	3625058	et	4	main
kesklinnas	doc_980560860255_item	3625055	et	4	main
1947	doc_980560860255_item	3625052	et	2	main
septembril	doc_980560860255_item	3625051	et	3	main
pronkssõdur	doc_980560860255_item	3625044	et	3	main
vesi	doc_980560860247_item	3624660	et	4	main
meeldib	doc_980560860247_item	3624659	et	3	main
mulle	doc_980560860247_item	3624658	et	4	main
lantš	doc_980560860247_item	3624655	et	2	main
ka	doc_980560860247_item	3624654	et	3	main
või	doc_980560860247_item	3624650	et	4	main
hommikul	doc_980560860247_item	3624646	et	3	main
kallim	doc_980560860247_item	3624619	et	4	main
on	doc_980560860247_item	3624617	et	4	main
kõik	doc_980560860247_item	3624618	et	4	main
keskalinnas	doc_980560860247_item	3624616	et	4	main
ja	doc_980560860247_item	3624615	et	3	main
keskalinna	doc_980560860247_item	3624614	et	4	main
elan	doc_980560860247_item	3624613	et	3	main
ma	doc_980560860247_item	3624612	et	3	main
lähen	doc_980560860247_item	3624611	et	3	main
päev	doc_980560860247_item	3624610	et	3	main
iga	doc_980560860247_item	3624609	et	4	main
miks	doc_980560860247_item	3624608	et	4	main
minema	doc_980560860247_item	3624607	et	3	main
poes	doc_980560860247_item	3624606	et	3	main
tärvis	doc_980560860247_item	3624605	et	4	main
on	doc_980560860247_item	3624604	et	4	main
mul	doc_980560860247_item	3624603	et	3	main
päev	doc_980560860247_item	3624602	et	3	main
poes	doc_980560860247_item	3624600	et	3	main
iga	doc_980560860247_item	3624601	et	4	main
ja	doc_980560860247_item	3624599	et	3	main
turul	doc_980560860247_item	3624598	et	3	main
essee	doc_980560860247_item	3624597	et	4	main
new	doc_980560860253_item	3624799	et	4	main
elan	doc_980560860253_item	3624798	et	3	main
tahan	doc_980560860253_item	3624797	et	3	main
ma	doc_980560860253_item	3624796	et	3	main
linn	doc_980560860253_item	3624795	et	3	main
lähen	doc_980560860253_item	3624787	et	3	main
jälle	doc_980560860253_item	3624778	et	3	main
ma	doc_980560860253_item	3624775	et	3	main
olen	doc_980560860253_item	3624759	et	3	main
ma	doc_980560860253_item	3624758	et	3	main
huvitav	doc_980560860253_item	3624757	et	4	main
ja	doc_980560860253_item	3624756	et	3	main
tallinn	doc_980560860253_item	3624752	et	4	main
tema	doc_980560860253_item	3624749	et	4	main
tulid	doc_980560860253_item	3624747	et	4	main
kaheksas	doc_980560860254_item	3624997	et	4	main
šotimaa	doc_980560860254_item	3624994	et	2	main
šotimaal	doc_980560860254_item	3624990	et	2	main
aga	doc_980560860254_item	3624986	et	3	main
aafrika	doc_980560860254_item	3624983	et	4	main
lõuna	doc_980560860254_item	3624982	et	4	main
ikka	doc_980560860254_item	3624963	et	4	main
vana	doc_980560860254_item	3624942	et	4	main
aastat	doc_980560860254_item	3624941	et	3	main
kuusteist	doc_980560860254_item	3624940	et	4	main
olin	doc_980560860254_item	3624939	et	3	main
mängisin	doc_980560860254_item	3624935	et	3	main
trofeed	doc_980560860254_item	3624933	et	4	main
meeskond	doc_980560860254_item	3624924	et	3	main
on	doc_980560860254_item	3624921	et	4	main
ragbi	doc_980560860254_item	3624920	et	4	main
ka	doc_980560860253_item	3624820	et	3	main
ameerika	doc_980560860253_item	3624819	et	3	main
ja	doc_980560860253_item	3624818	et	3	main
head	doc_980560860253_item	3624817	et	4	main
oli	doc_980560860253_item	3624816	et	3	main
eesti	doc_980560860253_item	3624815	et	4	main
lõpule	doc_980560860253_item	3624813	et	3	main
suvel	doc_980560860253_item	3624812	et	3	main
et	doc_980560860253_item	3624811	et	3	main
jõudma	doc_980560860253_item	3624814	et	3	main
kurb	doc_980560860253_item	3624810	et	3	main
väga	doc_980560860253_item	3624809	et	3	main
olen	doc_980560860253_item	3624808	et	3	main
ma	doc_980560860253_item	3624807	et	3	main
parem	doc_980560860253_item	3624806	et	4	main
kõige	doc_980560860253_item	3624805	et	4	main
oli	doc_980560860253_item	3624804	et	3	main
2007	doc_980560860253_item	3624803	et	2	main
suvel	doc_980560860253_item	3624802	et	3	main
tulevikus	doc_980560860253_item	3624801	et	4	main
järel	doc_980560860253_item	3624779	et	4	main
külastan	doc_980560860253_item	3624777	et	3	main
plats	doc_980560860253_item	3624774	et	4	main
ma	doc_980560860253_item	3624769	et	3	main
reisisin	doc_980560860253_item	3624767	et	3	main
vaga	doc_980560860253_item	3624754	et	4	main
et	doc_980560860253_item	3624751	et	3	main
londonist	doc_980560860253_item	3624748	et	4	main
tavaliselt	doc_980560860253_item	3624740	et	4	main
aga	doc_980560860253_item	3624739	et	3	main
meeldib	doc_980560860253_item	3624738	et	3	main
mulle	doc_980560860253_item	3624737	et	4	main
ülikoolis	doc_980560860253_item	3624736	et	4	main
tallinna	doc_980560860253_item	3624735	et	4	main
keelt	doc_980560860253_item	3624734	et	4	main
eesti	doc_980560860253_item	3624733	et	4	main
õpisin	doc_980560860253_item	3624732	et	4	main
ma	doc_980560860253_item	3624731	et	3	main
nädala	doc_980560860253_item	3624730	et	3	main
kolm	doc_980560860253_item	3624729	et	3	main
eesti	doc_980560860253_item	3624728	et	4	main
laksin	doc_980560860253_item	3624727	et	3	main
ma	doc_980560860253_item	3624726	et	3	main
tegev	doc_980560860253_item	3624725	et	4	main
väga	doc_980560860253_item	3624724	et	3	main
oli	doc_980560860253_item	3624723	et	3	main
suvel	doc_980560860253_item	3624722	et	3	main
suvel	doc_980560860253_item	3624721	et	3	main
essee	doc_980560860253_item	3624720	et	4	main
meeskond	doc_980560860254_item	3625000	et	3	main
parem	doc_980560860254_item	3624992	et	4	main
maailmameistrivõistlused	doc_980560860254_item	3624981	et	3	main
ragbi	doc_980560860254_item	3624980	et	4	main
oli	doc_980560860254_item	3624979	et	3	main
hiljuti	doc_980560860254_item	3624978	et	4	main
tahaksin	doc_980560860254_item	3624973	et	3	main
liiga	doc_980560860254_item	3624970	et	4	main
olen	doc_980560860254_item	3624969	et	3	main
mina	doc_980560860254_item	3624968	et	4	main
sest	doc_980560860254_item	3624959	et	4	main
jälle	doc_980560860254_item	3624958	et	3	main
mina	doc_980560860254_item	3624938	et	4	main
menukas	doc_980560860254_item	3624927	et	4	main
minu	doc_980560860254_item	3624923	et	3	main
nali	doc_980560860254_item	3624922	et	3	main
ja	doc_980560860254_item	3624917	et	3	main
sõbraks	doc_980560860254_item	3624914	et	3	main
sest	doc_980560860254_item	3624911	et	4	main
tülitsevad	doc_980560860254_item	3624906	et	4	main
mängijad	doc_980560860254_item	3624904	et	4	main
sellepärast	doc_980560860254_item	3624903	et	3	main
valulik	doc_980560860254_item	3624902	et	3	main
näiteks	doc_980560860254_item	3624893	et	4	main
on	doc_980560860254_item	3624889	et	4	main
sest	doc_980560860254_item	3624887	et	4	main
olema	doc_980560860254_item	3624886	et	4	main
te	doc_980560860254_item	3624883	et	4	main
ragbi	doc_980560860254_item	3624880	et	4	main
viisteist	doc_980560860254_item	3624872	et	4	main
on	doc_980560860254_item	3624871	et	4	main
ja	doc_980560860254_item	3624865	et	3	main
kõige	doc_980560860254_item	3624998	et	4	main
on	doc_980560860254_item	3624995	et	4	main
et	doc_980560860254_item	3624989	et	3	main
ma	doc_980560860254_item	3624987	et	3	main
võitis	doc_980560860254_item	3624984	et	3	main
jalle	doc_980560860254_item	3624976	et	4	main
mängida	doc_980560860254_item	3624975	et	3	main
väike	doc_980560860254_item	3624971	et	4	main
et	doc_980560860254_item	3624967	et	3	main
tunnen	doc_980560860254_item	3624966	et	3	main
ma	doc_980560860254_item	3624965	et	3	main
siiski	doc_980560860254_item	3624964	et	4	main
mängida	doc_980560860254_item	3624957	et	3	main
ragbi	doc_980560860254_item	3624956	et	4	main
tahaksin	doc_980560860254_item	3624955	et	3	main
ma	doc_980560860254_item	3624954	et	3	main
praegu	doc_980560860254_item	3624953	et	3	main
aga	doc_980560860254_item	3624952	et	3	main
enda	doc_980560860254_item	3624951	et	4	main
vigastasin	doc_980560860254_item	3624950	et	3	main
ma	doc_980560860254_item	3624949	et	3	main
kui	doc_980560860254_item	3624948	et	3	main
mängima	doc_980560860254_item	3624947	et	3	main
ragbi	doc_980560860254_item	3624946	et	4	main
peatama	doc_980560860254_item	3624945	et	3	main
pidin	doc_980560860254_item	3624944	et	3	main
ma	doc_980560860254_item	3624934	et	3	main
kakskümmend	doc_980560860254_item	3624932	et	4	main
umbes	doc_980560860254_item	3624931	et	4	main
võitsime	doc_980560860254_item	3624930	et	3	main
me	doc_980560860254_item	3624929	et	4	main
ja	doc_980560860254_item	3624928	et	3	main
meelest	doc_980560860254_item	3624919	et	4	main
pälju	doc_980560860254_item	3624915	et	4	main
sain	doc_980560860254_item	3624913	et	3	main
meeldis	doc_980560860254_item	3624908	et	3	main
see	doc_980560860254_item	3624900	et	3	main
takistama	doc_980560860254_item	3624897	et	3	main
mängijad	doc_980560860254_item	3624894	et	4	main
tugev	doc_980560860254_item	3624885	et	4	main
mängida	doc_980560860254_item	3624881	et	3	main
te	doc_980560860254_item	3624879	et	4	main
kui	doc_980560860254_item	3624878	et	3	main
siiski	doc_980560860254_item	3624877	et	4	main
naist	doc_980560860254_item	3624876	et	3	main
tahaksite	doc_980560860254_item	3624875	et	3	main
või	doc_980560860254_item	3624874	et	4	main
hea	doc_980560860254_item	3624869	et	4	main
üsna	doc_980560860254_item	3624868	et	3	main
see	doc_980560860254_item	3624856	et	3	main
tean	doc_980560860254_item	3624854	et	3	main
aga	doc_980560860254_item	3624852	et	3	main
ragbi	doc_980560860254_item	3624848	et	4	main
ragbi	doc_980560860254_item	3624831	et	4	main
meeskonnas	doc_980560860254_item	3624828	et	4	main
ragbi	doc_980560860254_item	3624827	et	4	main
mängisin	doc_980560860254_item	3624826	et	3	main
ma	doc_980560860254_item	3624825	et	3	main
noorena	doc_980560860254_item	3624824	et	3	main
klubid	doc_980560860254_item	3624823	et	3	main
umbes	doc_980560860254_item	3624836	et	4	main
aastal	doc_980560860255_item	3625112	et	3	main
27	doc_980560860255_item	3625109	et	2	main
vaga	doc_980560860255_item	3625107	et	4	main
on	doc_980560860255_item	3625106	et	4	main
pronkssõdur	doc_980560860255_item	3625105	et	3	main
õige	doc_980560860255_item	3625098	et	4	main
kui	doc_980560860255_item	3625095	et	3	main
sellest	doc_980560860255_item	3625093	et	4	main
mudelina	doc_980560860255_item	3625088	et	3	main
maadleja	doc_980560860255_item	3625085	et	4	main
uskub	doc_980560860255_item	3625082	et	4	main
monument	doc_980560860255_item	3625078	et	3	main
kui	doc_980560860255_item	3625076	et	3	main
arnold	doc_980560860255_item	3625072	et	4	main
ja	doc_980560860255_item	3625071	et	3	main
roos	doc_980560860255_item	3625070	et	4	main
all	doc_980560860255_item	3625066	et	3	main
monumenti	doc_980560860255_item	3625065	et	4	main
sõdurit	doc_980560860255_item	3625063	et	3	main
monument	doc_980560860255_item	3625056	et	3	main
pronksöö	doc_980560860255_item	3625046	et	4	main
ja	doc_980560860255_item	3625045	et	3	main
lõpuks	doc_980560860255_item	3625038	et	4	main
nimi	doc_980560860255_item	3625011	et	3	main
pronkssõdur	doc_980560860255_item	3625004	et	3	main
aru	doc_980560860255_item	3625260	et	4	main
saan	doc_980560860255_item	3625259	et	4	main
ma	doc_980560860255_item	3625258	et	3	main
paluksin	doc_980560860255_item	3625243	et	3	main
asukoha	doc_980560860255_item	3625221	et	4	main
pronkssõduri	doc_980560860255_item	3625219	et	3	main
asus	doc_980560860255_item	3625218	et	4	main
hotell	doc_980560860255_item	3625217	et	3	main
sellest	doc_980560860255_item	3625210	et	4	main
kohta	doc_980560860255_item	3625193	et	4	main
pronkssõduri	doc_980560860255_item	3625192	et	3	main
ja	doc_980560860255_item	3625191	et	3	main
mida	doc_980560860255_item	3625188	et	4	main
teda	doc_980560860255_item	3625170	et	4	main
tapas	doc_980560860255_item	3625169	et	3	main
dmitri	doc_980560860255_item	3625163	et	4	main
oli	doc_980560860255_item	3625162	et	3	main
jõudiga	doc_980560860255_item	3625149	et	4	main
märatsejaid	doc_980560860255_item	3625148	et	4	main
pälju	doc_980560860255_item	3625142	et	4	main
liigutada	doc_980560860255_item	3625131	et	3	main
tahtis	doc_980560860255_item	3625129	et	3	main
mängida	doc_980560860254_item	3624910	et	3	main
mulle	doc_980560860254_item	3624907	et	4	main
sageli	doc_980560860254_item	3624905	et	3	main
füüsiline	doc_980560860254_item	3624891	et	3	main
ragbi	doc_980560860254_item	3624888	et	4	main
ragbimeeskonnas	doc_980560860254_item	3624870	et	4	main
ragbiklube	doc_980560860254_item	3624864	et	4	main
väga	doc_980560860254_item	3624850	et	3	main
essee	doc_980560860254_item	3624822	et	4	main
sest	doc_980560860254_item	3624840	et	4	main
aastat	doc_980560860254_item	3624838	et	3	main
üheksa	doc_980560860254_item	3624837	et	4	main
olin	doc_980560860254_item	3624835	et	3	main
miks	doc_980560860255_item	3625104	et	4	main
põhjus	doc_980560860255_item	3625103	et	4	main
on	doc_980560860255_item	3625097	et	4	main
kasatati	doc_980560860255_item	3625086	et	4	main
eesti	doc_980560860255_item	3625084	et	4	main
et	doc_980560860255_item	3625083	et	3	main
eestlased	doc_980560860255_item	3625068	et	3	main
tunnen	doc_980560860255_item	3625043	et	3	main
kirjutan	doc_980560860255_item	3625040	et	3	main
sõjamonumenti	doc_980560860255_item	3625007	et	4	main
siis	doc_980560860255_item	3625249	et	3	main
teab	doc_980560860255_item	3625247	et	3	main
nad	doc_980560860255_item	3625246	et	3	main
lähedal	doc_980560860255_item	3625222	et	4	main
varem	doc_980560860255_item	3625220	et	4	main
arvamus	doc_980560860255_item	3625209	et	3	main
tugev	doc_980560860255_item	3625208	et	4	main
oleks	doc_980560860255_item	3625207	et	3	main
või	doc_980560860255_item	3625203	et	4	main
ma	doc_980560860255_item	3625200	et	3	main
õelda	doc_980560860255_item	3625189	et	4	main
tea	doc_980560860255_item	3625187	et	4	main
ei	doc_980560860255_item	3625186	et	4	main
ma	doc_980560860255_item	3625185	et	3	main
teda	doc_980560860255_item	3625174	et	4	main
tapas	doc_980560860255_item	3625173	et	3	main
eestlane	doc_980560860255_item	3625172	et	3	main
võib-olla	doc_980560860255_item	3625171	et	3	main
ganin	doc_980560860255_item	3625164	et	4	main
ja	doc_980560860255_item	3625159	et	3	main
venelane	doc_980560860255_item	3625158	et	3	main
ta	doc_980560860255_item	3625156	et	4	main
pidis	doc_980560860255_item	3625147	et	4	main
tallinna	doc_980560860255_item	3625140	et	4	main
sõduritega	doc_980560860255_item	3625139	et	3	main
lähedal	doc_980560860255_item	3625137	et	4	main
tallina	doc_980560860255_item	3625136	et	3	main
sõjakalmistus	doc_980560860255_item	3625135	et	3	main
asub	doc_980560860255_item	3625134	et	3	main
pronkssõdur	doc_980560860255_item	3625133	et	3	main
praegu	doc_980560860255_item	3625132	et	3	main
nad	doc_980560860255_item	3625123	et	3	main
vastu	doc_980560860258_item	3625437	et	3	main
loosunge	doc_980560860258_item	3625433	et	4	main
hüüdavad	doc_980560860258_item	3625432	et	3	main
nad	doc_980560860258_item	3625431	et	3	main
aga	doc_980560860258_item	3625424	et	3	main
eestimaal	doc_980560860258_item	3625413	et	4	main
meest	doc_980560860258_item	3625396	et	4	main
et	doc_980560860258_item	3625343	et	3	main
šotimaal	doc_980560860254_item	3624861	et	2	main
ole	doc_980560860254_item	3624858	et	4	main
juba	doc_980560860254_item	3624845	et	3	main
vend	doc_980560860254_item	3624843	et	3	main
kui	doc_980560860254_item	3624833	et	3	main
vanem	doc_980560860254_item	3624842	et	4	main
vana	doc_980560860254_item	3624839	et	4	main
ei	doc_980560860254_item	3624857	et	4	main
et	doc_980560860254_item	3624855	et	3	main
ma	doc_980560860254_item	3624853	et	3	main
tähtis	doc_980560860254_item	3624851	et	4	main
on	doc_980560860254_item	3624849	et	4	main
šotimaal	doc_980560860254_item	3624847	et	2	main
on	doc_980560860254_item	3624844	et	4	main
ma	doc_980560860254_item	3624834	et	3	main
ma	doc_980560860254_item	3624829	et	3	main
2007	doc_980560860255_item	3625111	et	2	main
vaieldav	doc_980560860255_item	3625108	et	4	main
üks	doc_980560860255_item	3625102	et	3	main
see	doc_980560860255_item	3625100	et	3	main
või	doc_980560860255_item	3625094	et	4	main
mida	doc_980560860255_item	3625092	et	4	main
tea	doc_980560860255_item	3625091	et	4	main
pronkssõdur	doc_980560860255_item	3625087	et	3	main
ründati	doc_980560860255_item	3625079	et	4	main
kujundati	doc_980560860255_item	3625074	et	3	main
alas	doc_980560860255_item	3625073	et	3	main
kohta	doc_980560860255_item	3625047	et	4	main
mida	doc_980560860255_item	3625041	et	4	main
on	doc_980560860255_item	3625012	et	4	main
kohta	doc_980560860255_item	3625008	et	4	main
see	doc_980560860255_item	3625254	et	3	main
lepingus	doc_980560860255_item	3625253	et	3	main
ei	doc_980560860255_item	3625251	et	4	main
mul	doc_980560860255_item	3625206	et	3	main
kui	doc_980560860255_item	3625199	et	3	main
ole	doc_980560860255_item	3625197	et	4	main
ei	doc_980560860255_item	3625166	et	4	main
ma	doc_980560860255_item	3625165	et	3	main
tema	doc_980560860255_item	3625160	et	4	main
oli	doc_980560860255_item	3625157	et	3	main
eesti	doc_980560860255_item	3625127	et	4	main
et	doc_980560860255_item	3625126	et	3	main
teada	doc_980560860255_item	3625125	et	3	main
tallinna	doc_980560860255_item	3625115	et	4	main
liigutati	doc_980560860255_item	3625114	et	3	main
pronkssõdur	doc_980560860255_item	3625113	et	3	main
nalja	doc_980560860258_item	3625440	et	4	main
nad	doc_980560860258_item	3625438	et	3	main
vaiduslikad	doc_980560860258_item	3625429	et	4	main
naljaksad	doc_980560860258_item	3625423	et	4	main
ole	doc_980560860258_item	3625422	et	4	main
protestivad	doc_980560860258_item	3625412	et	4	main
nad	doc_980560860258_item	3625411	et	3	main
ja	doc_980560860258_item	3625410	et	3	main
alla	doc_980560860258_item	3625409	et	3	main
teekslesid	doc_980560860258_item	3625405	et	4	main
teekslevad	doc_980560860258_item	3625398	et	4	main
käivad	doc_980560860258_item	3625345	et	4	main
oma	doc_980560860258_item	3625321	et	4	main
filmis	doc_980560860258_item	3625316	et	4	main
eesti	doc_980560860258_item	3625308	et	4	main
oli	doc_980560860258_item	3625307	et	3	main
film	doc_980560860258_item	3625306	et	3	main
teine	doc_980560860258_item	3625305	et	3	main
tähistada	doc_980560860258_item	3625304	et	3	main
filmidest	doc_980560860258_item	3625294	et	3	main
need	doc_980560860258_item	3625293	et	3	main
kirjutan	doc_980560860258_item	3625292	et	3	main
ma	doc_980560860258_item	3625291	et	3	main
filme	doc_980560860258_item	3625290	et	3	main
eesti	doc_980560860258_item	3625282	et	4	main
ei	doc_980560860258_item	3625383	et	4	main
pidusid	doc_980560860258_item	3625378	et	4	main
kelles	doc_980560860258_item	3625370	et	4	main
filmis	doc_980560860258_item	3625367	et	4	main
nendeks	doc_980560860258_item	3625360	et	4	main
sättiks	doc_980560860258_item	3625356	et	4	main
firma	doc_980560860258_item	3625352	et	4	main
tahtis	doc_980560860258_item	3625351	et	3	main
valged	doc_980560860259_item	3625547	et	3	main
seinad	doc_980560860259_item	3625543	et	3	main
voodi	doc_980560860259_item	3625534	et	4	main
minu	doc_980560860259_item	3625533	et	3	main
toa	doc_980560860259_item	3625530	et	3	main
hiinast	doc_980560860259_item	3625523	et	4	main
vaip	doc_980560860259_item	3625522	et	3	main
minu	doc_980560860259_item	3625492	et	3	main
aias	doc_980560860259_item	3625488	et	4	main
tulevasel	doc_980560860255_item	3625279	et	4	main
lahendatakse	doc_980560860255_item	3625278	et	3	main
küsimust	doc_980560860255_item	3625277	et	4	main
seda	doc_980560860255_item	3625276	et	3	main
et	doc_980560860255_item	3625275	et	3	main
loodan	doc_980560860255_item	3625274	et	3	main
ma	doc_980560860255_item	3625273	et	3	main
ajaloo-küsimus	doc_980560860255_item	3625272	et	4	main
tähtis	doc_980560860255_item	3625271	et	4	main
on	doc_980560860255_item	3625270	et	4	main
see	doc_980560860255_item	3625269	et	3	main
sest	doc_980560860255_item	3625268	et	4	main
kohta	doc_980560860255_item	3625267	et	4	main
pronkssõduri	doc_980560860255_item	3625266	et	3	main
lepingus	doc_980560860255_item	3625265	et	3	main
ole	doc_980560860255_item	3625264	et	4	main
ei	doc_980560860255_item	3625263	et	4	main
nad	doc_980560860255_item	3625262	et	3	main
aprilil	doc_980560860255_item	3625110	et	4	main
on	doc_980560860255_item	3625101	et	4	main
see	doc_980560860255_item	3625096	et	3	main
ei	doc_980560860255_item	3625090	et	4	main
ma	doc_980560860255_item	3625089	et	3	main
enn	doc_980560860255_item	3625069	et	4	main
erigeeruti	doc_980560860255_item	3625057	et	4	main
tallinna	doc_980560860255_item	3625054	et	4	main
aastal	doc_980560860255_item	3625053	et	3	main
22	doc_980560860255_item	3625050	et	2	main
erigeeruti	doc_980560860255_item	3625049	et	4	main
monument	doc_980560860255_item	3625048	et	3	main
ma	doc_980560860255_item	3625042	et	3	main
ma	doc_980560860255_item	3625039	et	3	main
ja	doc_980560860255_item	3625037	et	3	main
tallinnas	doc_980560860255_item	3625036	et	4	main
kohta	doc_980560860255_item	3625035	et	4	main
pronksöö	doc_980560860255_item	3625034	et	4	main
kirjutan	doc_980560860255_item	3625033	et	3	main
ma	doc_980560860255_item	3625032	et	3	main
teiseks	doc_980560860255_item	3625031	et	4	main
ajaloost	doc_980560860255_item	3625030	et	4	main
pronkssõduri	doc_980560860255_item	3625029	et	3	main
kirjutan	doc_980560860255_item	3625028	et	3	main
ma	doc_980560860255_item	3625027	et	3	main
esiteks	doc_980560860255_item	3625026	et	3	main
eestis	doc_980560860255_item	3625025	et	3	main
vaieldav	doc_980560860255_item	3625024	et	4	main
vaga	doc_980560860255_item	3625023	et	4	main
ka	doc_980560860255_item	3625022	et	3	main
on	doc_980560860255_item	3625021	et	4	main
monument	doc_980560860255_item	3625020	et	3	main
aga	doc_980560860255_item	3625019	et	3	main
ajalugu	doc_980560860255_item	3625018	et	4	main
huvitav	doc_980560860255_item	3625017	et	4	main
on	doc_980560860255_item	3625016	et	4	main
monumentil	doc_980560860255_item	3625015	et	4	main
ja	doc_980560860255_item	3625014	et	3	main
pronkssõdur	doc_980560860255_item	3625013	et	3	main
monumenti	doc_980560860255_item	3625010	et	4	main
kirjutan	doc_980560860255_item	3625006	et	3	main
õnnetu	doc_980560860255_item	3625256	et	4	main
on	doc_980560860255_item	3625255	et	4	main
oma	doc_980560860255_item	3625216	et	4	main
ja	doc_980560860255_item	3625215	et	3	main
olin	doc_980560860255_item	3625213	et	3	main
ma	doc_980560860255_item	3625212	et	3	main
hiljuti	doc_980560860255_item	3625211	et	4	main
venelane	doc_980560860255_item	3625204	et	3	main
eestlane	doc_980560860255_item	3625202	et	3	main
oleks	doc_980560860255_item	3625201	et	3	main
pronksöö	doc_980560860255_item	3625190	et	4	main
tavaliselt	doc_980560860255_item	3625009	et	4	main
mina	doc_980560860255_item	3625005	et	4	main
essee	doc_980560860255_item	3625003	et	4	main
miks	doc_980560860255_item	3625261	et	4	main
aga	doc_980560860255_item	3625257	et	3	main
oleks	doc_980560860255_item	3625252	et	3	main
nad	doc_980560860255_item	3625250	et	3	main
sellest	doc_980560860255_item	3625248	et	4	main
mida	doc_980560860255_item	3625245	et	4	main
venelasi	doc_980560860255_item	3625244	et	3	main
ma	doc_980560860255_item	3625242	et	3	main
kui	doc_980560860255_item	3625241	et	3	main
ja	doc_980560860255_item	3625240	et	3	main
kohta	doc_980560860255_item	3625239	et	4	main
pronkssõduri	doc_980560860255_item	3625238	et	3	main
teab	doc_980560860255_item	3625237	et	3	main
nad	doc_980560860255_item	3625236	et	3	main
mida	doc_980560860255_item	3625235	et	4	main
eestlasi	doc_980560860255_item	3625234	et	3	main
paluksin	doc_980560860255_item	3625233	et	3	main
ma	doc_980560860255_item	3625232	et	3	main
kui	doc_980560860255_item	3625231	et	3	main
ka	doc_980560860255_item	3625230	et	3	main
tean	doc_980560860255_item	3625229	et	3	main
ma	doc_980560860255_item	3625228	et	3	main
seda	doc_980560860255_item	3625227	et	3	main
teadnud	doc_980560860255_item	3625226	et	4	main
ei	doc_980560860255_item	3625225	et	4	main
ma	doc_980560860255_item	3625224	et	3	main
aga	doc_980560860255_item	3625223	et	3	main
tallinnas	doc_980560860255_item	3625214	et	4	main
siis	doc_980560860255_item	3625205	et	3	main
eestlane	doc_980560860255_item	3625198	et	3	main
ei	doc_980560860255_item	3625196	et	4	main
ma	doc_980560860255_item	3625195	et	3	main
sest	doc_980560860255_item	3625194	et	4	main
tea	doc_980560860255_item	3625167	et	4	main
mees	doc_980560860255_item	3625154	et	4	main
üks	doc_980560860255_item	3625153	et	3	main
ainult	doc_980560860255_item	3625152	et	4	main
pronksööl	doc_980560860255_item	3625151	et	3	main
takistada	doc_980560860255_item	3625150	et	3	main
poode	doc_980560860255_item	3625143	et	3	main
sais	doc_980560860255_item	3625124	et	4	main
inimesi	doc_980560860255_item	3625120	et	4	main
sest	doc_980560860255_item	3625118	et	4	main
sõjakalmistusse	doc_980560860255_item	3625117	et	3	main
teda	doc_980560860255_item	3625184	et	4	main
torkas	doc_980560860255_item	3625183	et	3	main
keegi	doc_980560860255_item	3625182	et	4	main
pärast	doc_980560860255_item	3625181	et	4	main
haiglas	doc_980560860255_item	3625180	et	3	main
suris	doc_980560860255_item	3625179	et	4	main
ganin	doc_980560860255_item	3625178	et	4	main
venelane	doc_980560860255_item	3625177	et	3	main
veel	doc_980560860255_item	3625176	et	4	main
või	doc_980560860255_item	3625175	et	4	main
keda	doc_980560860255_item	3625168	et	4	main
nimi	doc_980560860255_item	3625161	et	3	main
tapati	doc_980560860255_item	3625155	et	4	main
politsei	doc_980560860255_item	3625146	et	4	main
ja	doc_980560860255_item	3625145	et	3	main
rüüstati	doc_980560860255_item	3625144	et	3	main
kesklinas	doc_980560860255_item	3625141	et	4	main
vaiksed	doc_980560860255_item	3625138	et	3	main
monumenti	doc_980560860255_item	3625130	et	4	main
valitsus	doc_980560860255_item	3625128	et	4	main
märatses	doc_980560860255_item	3625121	et	3	main
palju	doc_980560860255_item	3625119	et	4	main
kesklinnast	doc_980560860255_item	3625116	et	4	main
ka	doc_980560860258_item	3625441	et	3	main
teevad	doc_980560860258_item	3625439	et	3	main
neegre	doc_980560860258_item	3625436	et	4	main
ja	doc_980560860258_item	3625435	et	3	main
homoseksuaalte	doc_980560860258_item	3625434	et	4	main
ka	doc_980560860258_item	3625427	et	3	main
nad	doc_980560860258_item	3625425	et	3	main
meesti	doc_980560860258_item	3625421	et	4	main
neid	doc_980560860258_item	3625420	et	4	main
et	doc_980560860258_item	3625419	et	3	main
tunnen	doc_980560860258_item	3625418	et	3	main
ma	doc_980560860258_item	3625417	et	3	main
rassisti	doc_980560860258_item	3625408	et	4	main
nad	doc_980560860258_item	3625404	et	3	main
kaks	doc_980560860258_item	3625395	et	3	main
ja	doc_980560860258_item	3625349	et	3	main
brite	doc_980560860258_item	3625347	et	4	main
palju	doc_980560860258_item	3625346	et	4	main
rahat	doc_980560860258_item	3625334	et	4	main
naine	doc_980560860258_item	3625318	et	3	main
eesti	doc_980560860258_item	3625289	et	4	main
mõne	doc_980560860258_item	3625288	et	3	main
filmis	doc_980560860258_item	3625393	et	4	main
teine	doc_980560860258_item	3625387	et	3	main
briti	doc_980560860258_item	3625385	et	4	main
meeldi	doc_980560860258_item	3625384	et	4	main
tallinna	doc_980560860258_item	3625379	et	4	main
naine	doc_980560860258_item	3625375	et	3	main
näiteks	doc_980560860258_item	3625366	et	4	main
pidusid	doc_980560860258_item	3625359	et	4	main
ta	doc_980560860258_item	3625355	et	4	main
tekitada	doc_980560860258_item	3625353	et	3	main
kõrval	doc_980560860259_item	3625536	et	4	main
pärast	doc_980560860259_item	3625524	et	4	main
on	doc_980560860259_item	3625505	et	4	main
tugitooli	doc_980560860259_item	3625499	et	4	main
puhkan	doc_980560860259_item	3625498	et	3	main
ja	doc_980560860259_item	3625497	et	3	main
loen	doc_980560860259_item	3625496	et	3	main
ma	doc_980560860259_item	3625495	et	3	main
kus	doc_980560860259_item	3625494	et	3	main
on	doc_980560860259_item	3625481	et	4	main
ostma	doc_980560860262_item	3625663	et	3	main
ma	doc_980560860262_item	3625661	et	3	main
riias	doc_980560860262_item	3625660	et	4	main
olnud	doc_980560860262_item	3625655	et	4	main
on	doc_980560860262_item	3625654	et	4	main
ilm	doc_980560860262_item	3625653	et	3	main
äsja	doc_980560860262_item	3625652	et	3	main
aga	doc_980560860262_item	3625651	et	3	main
talv	doc_980560860262_item	3625650	et	3	main
lund	doc_980560860262_item	3625645	et	3	main
hakka	doc_980560860262_item	3625643	et	4	main
sügise	doc_980560860262_item	3625641	et	3	main
lätis	doc_980560860262_item	3625640	et	4	main
suvi	doc_980560860262_item	3625639	et	3	main
šoti	doc_980560860262_item	3625638	et	2	main
ka	doc_980560860262_item	3625637	et	3	main
jahe	doc_980560860262_item	3625629	et	3	main
lätis	doc_980560860262_item	3625623	et	4	main
ma	doc_980560860262_item	3625574	et	3	main
mulle	doc_980560860262_item	3625679	et	4	main
lõpuni	doc_980560860262_item	3625678	et	3	main
jaanuari	doc_980560860262_item	3625677	et	4	main
suuski	doc_980560860262_item	3625665	et	4	main
eestimaal	doc_980560860264_item	3625954	et	4	main
lumel	doc_980560860264_item	3625941	et	3	main
jahe	doc_980560860264_item	3625933	et	3	main
enamasti	doc_980560860264_item	3625930	et	4	main
kui	doc_980560860255_item	3625122	et	3	main
näiteks	doc_980560860258_item	3625430	et	4	main
soomes	doc_980560860258_item	3625416	et	4	main
ja	doc_980560860258_item	3625415	et	3	main
ja	doc_980560860258_item	3625407	et	3	main
publica	doc_980560860258_item	3625403	et	4	main
partei	doc_980560860258_item	3625401	et	4	main
alla	doc_980560860258_item	3625400	et	3	main
liigi	doc_980560860258_item	3625399	et	4	main
tallinnas	doc_980560860258_item	3625344	et	4	main
ta	doc_980560860258_item	3625341	et	4	main
rohkem	doc_980560860258_item	3625333	et	4	main
oli	doc_980560860258_item	3625317	et	3	main
vaatanud	doc_980560860258_item	3625287	et	4	main
essee	doc_980560860258_item	3625281	et	4	main
ta	doc_980560860258_item	3625382	et	4	main
ka	doc_980560860258_item	3625377	et	3	main
londonis	doc_980560860258_item	3625365	et	4	main
seda	doc_980560860258_item	3625364	et	3	main
kuulutaks	doc_980560860258_item	3625363	et	4	main
ta	doc_980560860258_item	3625362	et	4	main
ja	doc_980560860258_item	3625361	et	3	main
aga	doc_980560860259_item	3625551	et	3	main
punased	doc_980560860259_item	3625545	et	4	main
toas	doc_980560860259_item	3625542	et	3	main
minu	doc_980560860259_item	3625541	et	3	main
raamatud	doc_980560860259_item	3625540	et	4	main
ja	doc_980560860259_item	3625539	et	3	main
äratuskell	doc_980560860259_item	3625538	et	3	main
on	doc_980560860259_item	3625537	et	4	main
minu	doc_980560860259_item	3625526	et	3	main
keda	doc_980560860259_item	3625525	et	4	main
on	doc_980560860259_item	3625521	et	4	main
põrandal	doc_980560860259_item	3625520	et	3	main
kapp	doc_980560860259_item	3625519	et	3	main
suur	doc_980560860259_item	3625518	et	3	main
ja	doc_980560860259_item	3625517	et	3	main
diivan	doc_980560860259_item	3625516	et	3	main
on	doc_980560860259_item	3625515	et	4	main
toa	doc_980560860259_item	3625514	et	3	main
kirjutuslaual	doc_980560860259_item	3625509	et	3	main
kirjutuslaud	doc_980560860259_item	3625508	et	4	main
ja	doc_980560860259_item	3625507	et	3	main
kapp	doc_980560860259_item	3625506	et	3	main
kõrval	doc_980560860259_item	3625500	et	4	main
on	doc_980560860259_item	3625491	et	4	main
ees	doc_980560860259_item	3625490	et	4	main
maas	doc_980560860262_item	3625648	et	4	main
maadel	doc_980560860262_item	3625633	et	4	main
mõlemadel	doc_980560860262_item	3625632	et	4	main
tuuline	doc_980560860262_item	3625631	et	3	main
ja	doc_980560860262_item	3625630	et	3	main
riias	doc_980560860262_item	3625579	et	4	main
töötasin	doc_980560860262_item	3625578	et	3	main
ma	doc_980560860262_item	3625577	et	3	main
õnnelik	doc_980560860262_item	3625576	et	3	main
olin	doc_980560860262_item	3625575	et	3	main
lätis	doc_980560860262_item	3625572	et	4	main
ja	doc_980560860262_item	3625571	et	3	main
lund	doc_980560860262_item	3625674	et	3	main
randas	doc_980560860262_item	3625672	et	4	main
isegi	doc_980560860262_item	3625671	et	4	main
ja	doc_980560860262_item	3625670	et	3	main
metsis	doc_980560860262_item	3625669	et	4	main
sageli	doc_980560860262_item	3625668	et	3	main
suusatama	doc_980560860262_item	3625667	et	3	main
ja	doc_980560860262_item	3625666	et	3	main
venemaal	doc_980560860264_item	3625956	et	4	main
talve	doc_980560860264_item	3625950	et	4	main
millal	doc_980560860264_item	3625946	et	3	main
korral	doc_980560860264_item	3625945	et	4	main
eelmisel	doc_980560860264_item	3625944	et	3	main
kuid	doc_980560860264_item	3625943	et	4	main
lumes	doc_980560860264_item	3625942	et	3	main
kui	doc_980560860264_item	3625934	et	3	main
on	doc_980560860264_item	3625932	et	4	main
aga	doc_980560860264_item	3625925	et	3	main
külma	doc_980560860264_item	3625924	et	4	main
kraad	doc_980560860264_item	3625923	et	3	main
üks	doc_980560860264_item	3625922	et	3	main
on	doc_980560860264_item	3625921	et	4	main
päeval	doc_980560860264_item	3625920	et	3	main
on	doc_980560860264_item	3625915	et	4	main
filmis	doc_980560860258_item	3625468	et	4	main
mehed	doc_980560860258_item	3625467	et	3	main
nagu	doc_980560860258_item	3625466	et	3	main
huumorimeel	doc_980560860258_item	3625465	et	4	main
on	doc_980560860258_item	3625464	et	4	main
mul	doc_980560860258_item	3625463	et	3	main
ja	doc_980560860258_item	3625462	et	3	main
naljakas	doc_980560860258_item	3625461	et	4	main
vaga	doc_980560860258_item	3625460	et	4	main
meeled	doc_980560860258_item	3625459	et	3	main
mu	doc_980560860258_item	3625458	et	3	main
oli	doc_980560860258_item	3625457	et	3	main
teine	doc_980560860258_item	3625455	et	3	main
film	doc_980560860258_item	3625456	et	3	main
sest	doc_980560860258_item	3625454	et	4	main
film	doc_980560860258_item	3625453	et	3	main
esimene	doc_980560860258_item	3625452	et	3	main
kui	doc_980560860258_item	3625451	et	3	main
parem	doc_980560860258_item	3625450	et	4	main
film	doc_980560860258_item	3625449	et	3	main
teine	doc_980560860258_item	3625448	et	3	main
meeldib	doc_980560860258_item	3625447	et	3	main
mulle	doc_980560860258_item	3625446	et	4	main
sortsist	doc_980560860258_item	3625445	et	2	main
peeter	doc_980560860258_item	3625444	et	3	main
peaminister	doc_980560860258_item	3625443	et	3	main
eesti	doc_980560860258_item	3625442	et	4	main
vaga	doc_980560860258_item	3625428	et	4	main
oli	doc_980560860258_item	3625426	et	3	main
itaalias	doc_980560860258_item	3625414	et	4	main
fašiste	doc_980560860258_item	3625406	et	2	main
res	doc_980560860258_item	3625402	et	3	main
kes	doc_980560860258_item	3625397	et	4	main
ta	doc_980560860258_item	3625350	et	4	main
poissimeesteid	doc_980560860258_item	3625348	et	4	main
tunnis	doc_980560860258_item	3625342	et	3	main
firma	doc_980560860258_item	3625340	et	4	main
oma	doc_980560860258_item	3625339	et	4	main
oleks	doc_980560860258_item	3625338	et	3	main
tal	doc_980560860258_item	3625337	et	3	main
kui	doc_980560860258_item	3625336	et	3	main
teenida	doc_980560860258_item	3625335	et	3	main
saab	doc_980560860258_item	3625332	et	3	main
ta	doc_980560860258_item	3625331	et	4	main
et	doc_980560860258_item	3625330	et	3	main
uskus	doc_980560860258_item	3625329	et	3	main
aga	doc_980560860258_item	3625328	et	3	main
müüjanana	doc_980560860258_item	3625327	et	4	main
töötanud	doc_980560860258_item	3625326	et	4	main
on	doc_980560860258_item	3625325	et	4	main
ta	doc_980560860258_item	3625324	et	4	main
firma	doc_980560860258_item	3625322	et	4	main
tahtis	doc_980560860258_item	3625320	et	3	main
kes	doc_980560860258_item	3625319	et	4	main
dokumentaalfilm	doc_980560860258_item	3625314	et	3	main
ka	doc_980560860258_item	3625312	et	3	main
aga	doc_980560860258_item	3625310	et	3	main
olen	doc_980560860258_item	3625286	et	3	main
ma	doc_980560860258_item	3625285	et	3	main
hiljuti	doc_980560860258_item	3625284	et	4	main
oli	doc_980560860258_item	3625394	et	3	main
eesti	doc_980560860258_item	3625391	et	4	main
film	doc_980560860258_item	3625388	et	3	main
poissimehed	doc_980560860258_item	3625386	et	4	main
sõitma	doc_980560860258_item	3625374	et	3	main
autosid	doc_980560860258_item	3625373	et	3	main
oli	doc_980560860258_item	3625371	et	3	main
mees	doc_980560860258_item	3625369	et	4	main
oli	doc_980560860258_item	3625368	et	3	main
sündmusi	doc_980560860258_item	3625357	et	3	main
väike	doc_980560860259_item	3625550	et	4	main
on	doc_980560860259_item	3625549	et	4	main
voodi	doc_980560860259_item	3625535	et	4	main
seal	doc_980560860259_item	3625529	et	4	main
ostis	doc_980560860259_item	3625528	et	4	main
ema	doc_980560860259_item	3625527	et	4	main
teisel	doc_980560860259_item	3625512	et	4	main
juures	doc_980560860259_item	3625504	et	4	main
raamaturiiu	doc_980560860259_item	3625503	et	3	main
raamaturiul	doc_980560860259_item	3625502	et	4	main
tugitool	doc_980560860259_item	3625493	et	3	main
akna	doc_980560860259_item	3625489	et	3	main
ma	doc_980560860259_item	3625485	et	3	main
kedas	doc_980560860259_item	3625484	et	4	main
aken	doc_980560860259_item	3625483	et	3	main
suur	doc_980560860259_item	3625482	et	3	main
elasin	doc_980560860262_item	3625659	et	3	main
ma	doc_980560860262_item	3625658	et	3	main
kui	doc_980560860262_item	3625657	et	3	main
soojem	doc_980560860262_item	3625656	et	3	main
lumi	doc_980560860262_item	3625647	et	3	main
sadama	doc_980560860262_item	3625644	et	4	main
lõppus	doc_980560860262_item	3625642	et	4	main
natukune	doc_980560860262_item	3625628	et	4	main
võis	doc_980560860262_item	3625626	et	4	main
lätis	doc_980560860262_item	3625617	et	4	main
päev	doc_980560860262_item	3625616	et	3	main
on	doc_980560860262_item	3625614	et	4	main
üks	doc_980560860262_item	3625581	et	3	main
õppetajaks	doc_980560860262_item	3625580	et	4	main
tekitada	doc_980560860258_item	3625323	et	3	main
esimesel	doc_980560860258_item	3625315	et	3	main
naljakas	doc_980560860258_item	3625313	et	4	main
oli	doc_980560860258_item	3625311	et	3	main
politikast	doc_980560860258_item	3625309	et	4	main
poissimeesteõhtul	doc_980560860258_item	3625303	et	4	main
tallinnas	doc_980560860258_item	3625302	et	4	main
käivad	doc_980560860258_item	3625301	et	4	main
kes	doc_980560860258_item	3625300	et	4	main
poissimeestest	doc_980560860258_item	3625299	et	4	main
briti	doc_980560860258_item	3625298	et	4	main
oli	doc_980560860258_item	3625297	et	3	main
film	doc_980560860258_item	3625296	et	3	main
esimene	doc_980560860258_item	3625295	et	3	main
filmid	doc_980560860258_item	3625283	et	4	main
politikast	doc_980560860258_item	3625392	et	4	main
dokumentaalfilm	doc_980560860258_item	3625390	et	3	main
oli	doc_980560860258_item	3625389	et	3	main
siiski	doc_980560860258_item	3625381	et	4	main
kesklinnas	doc_980560860258_item	3625380	et	4	main
kuulutaks	doc_980560860258_item	3625376	et	4	main
palju	doc_980560860258_item	3625372	et	4	main
ja	doc_980560860258_item	3625358	et	3	main
nendeks	doc_980560860258_item	3625354	et	4	main
meeldis	doc_980560860259_item	3625559	et	3	main
väga	doc_980560860259_item	3625558	et	3	main
mulle	doc_980560860259_item	3625557	et	4	main
see	doc_980560860259_item	3625556	et	3	main
ja	doc_980560860259_item	3625555	et	3	main
vaikne	doc_980560860259_item	3625554	et	3	main
ja	doc_980560860259_item	3625553	et	3	main
soe	doc_980560860259_item	3625552	et	4	main
see	doc_980560860259_item	3625548	et	3	main
ja	doc_980560860259_item	3625546	et	3	main
on	doc_980560860259_item	3625544	et	4	main
on	doc_980560860259_item	3625532	et	4	main
nurgas	doc_980560860259_item	3625531	et	3	main
külgal	doc_980560860259_item	3625513	et	4	main
sülearvuti	doc_980560860259_item	3625511	et	4	main
on	doc_980560860259_item	3625510	et	4	main
on	doc_980560860259_item	3625501	et	4	main
mugav	doc_980560860259_item	3625480	et	3	main
ja	doc_980560860259_item	3625479	et	3	main
ilus	doc_980560860259_item	3625478	et	4	main
aga	doc_980560860259_item	3625477	et	3	main
väike	doc_980560860259_item	3625476	et	4	main
on	doc_980560860259_item	3625475	et	4	main
tuba	doc_980560860259_item	3625474	et	4	main
minu	doc_980560860259_item	3625473	et	3	main
tuba	doc_980560860259_item	3625472	et	4	main
minu	doc_980560860259_item	3625471	et	3	main
essee	doc_980560860259_item	3625470	et	4	main
oravad	doc_980560860259_item	3625487	et	3	main
vaatan	doc_980560860259_item	3625486	et	3	main
kõik	doc_980560860262_item	3625649	et	4	main
sama	doc_980560860262_item	3625636	et	4	main
ka	doc_980560860262_item	3625624	et	3	main
suvil	doc_980560860262_item	3625622	et	4	main
aga	doc_980560860262_item	3625621	et	3	main
soojem	doc_980560860262_item	3625620	et	3	main
on	doc_980560860262_item	3625619	et	4	main
suvi	doc_980560860262_item	3625618	et	3	main
sest	doc_980560860262_item	3625573	et	4	main
oli	doc_980560860264_item	3625953	et	3	main
lumega	doc_980560860264_item	3625951	et	3	main
tõelist	doc_980560860264_item	3625949	et	4	main
näin	doc_980560860264_item	3625948	et	3	main
ma	doc_980560860264_item	3625947	et	3	main
korduvalt	doc_980560860264_item	3625940	et	4	main
jää	doc_980560860264_item	3625928	et	4	main
viieteist	doc_980560860264_item	3625916	et	4	main
talvel	doc_980560860264_item	3625903	et	4	main
mõtlen	doc_980560860264_item	3625902	et	3	main
ma	doc_980560860264_item	3625901	et	3	main
ema	doc_980560860264_item	3625894	et	4	main
minu	doc_980560860264_item	3625893	et	3	main
neljaks	doc_980560860264_item	3625890	et	4	main
väga	doc_980560860264_item	3625888	et	3	main
oli	doc_980560860264_item	3625887	et	3	main
ilm	doc_980560860264_item	3625886	et	3	main
eelmisel	doc_980560860264_item	3625883	et	3	main
ka	doc_980560860264_item	3625871	et	3	main
šotimaal	doc_980560860264_item	3625866	et	2	main
ka	doc_980560860264_item	3625864	et	3	main
šotimaal	doc_980560860264_item	3625862	et	2	main
kolmekümne	doc_980560860264_item	3625848	et	4	main
ilm	doc_980560860264_item	3625845	et	3	main
soojem	doc_980560860264_item	3625841	et	3	main
nii	doc_980560860264_item	3625832	et	3	main
suvi	doc_980560860264_item	3625829	et	3	main
sellele	doc_980560860264_item	3625822	et	4	main
inimesed	doc_980560860264_item	3625821	et	3	main
teisiti	doc_980560860264_item	3625815	et	3	main
eelmistel	doc_980560860264_item	3625799	et	3	main
märg	doc_980560860264_item	3625798	et	3	main
seal	doc_980560860264_item	3625795	et	4	main
välja	doc_980560860264_item	3625793	et	4	main
minna	doc_980560860264_item	3625792	et	3	main
kus	doc_980560860264_item	3625756	et	3	main
sellest	doc_980560860264_item	3625755	et	4	main
sõltub	doc_980560860264_item	3625754	et	3	main
see	doc_980560860264_item	3625753	et	3	main
ilm	doc_980560860264_item	3625752	et	3	main
on	doc_980560860264_item	3625751	et	4	main
milline	doc_980560860264_item	3625750	et	3	main
talvel	doc_980560860264_item	3625749	et	4	main
ja	doc_980560860264_item	3625748	et	3	main
sügisel	doc_980560860264_item	3625747	et	3	main
suvel	doc_980560860264_item	3625746	et	3	main
aastal	doc_980560860262_item	3625730	et	3	main
tervel	doc_980560860262_item	3625729	et	4	main
muutan	doc_980560860262_item	3625728	et	4	main
parem	doc_980560860262_item	3625727	et	4	main
ja	doc_980560860262_item	3625726	et	3	main
päevas	doc_980560860262_item	3625725	et	3	main
ühes	doc_980560860262_item	3625724	et	4	main
muutan	doc_980560860262_item	3625723	et	4	main
vähem	doc_980560860262_item	3625722	et	4	main
see	doc_980560860262_item	3625721	et	3	main
sest	doc_980560860262_item	3625720	et	4	main
lätis	doc_980560860262_item	3625719	et	4	main
ilma	doc_980560860262_item	3625718	et	4	main
eelistan	doc_980560860262_item	3625717	et	3	main
ma	doc_980560860262_item	3625716	et	3	main
et	doc_980560860262_item	3625715	et	3	main
mõtlen	doc_980560860262_item	3625714	et	3	main
ma	doc_980560860262_item	3625713	et	3	main
päivi	doc_980560860262_item	3625712	et	4	main
suvelisi	doc_980560860262_item	3625711	et	4	main
ja	doc_980560860262_item	3625710	et	3	main
kevadelisi	doc_980560860262_item	3625709	et	4	main
sooje	doc_980560860262_item	3625708	et	3	main
ootama	doc_980560860262_item	3625707	et	3	main
hakkan	doc_980560860262_item	3625706	et	3	main
ja	doc_980560860262_item	3625705	et	3	main
hästi	doc_980560860262_item	3625704	et	3	main
endale	doc_980560860262_item	3625664	et	4	main
tahasin	doc_980560860262_item	3625662	et	4	main
on	doc_980560860262_item	3625646	et	4	main
on	doc_980560860262_item	3625635	et	4	main
sügis	doc_980560860262_item	3625634	et	3	main
olla	doc_980560860262_item	3625627	et	3	main
ilm	doc_980560860262_item	3625625	et	3	main
sügis	doc_980560860262_item	3625615	et	3	main
suvipäev	doc_980560860262_item	3625613	et	3	main
šoti	doc_980560860262_item	3625612	et	2	main
tuupiline	doc_980560860262_item	3625611	et	4	main
meres	doc_980560860262_item	3625610	et	3	main
ujuvad	doc_980560860262_item	3625609	et	4	main
esimest	doc_980560860262_item	3625607	et	4	main
isegi	doc_980560860262_item	3625608	et	4	main
hullut	doc_980560860262_item	3625606	et	4	main
mõni	doc_980560860262_item	3625605	et	3	main
ja	doc_980560860262_item	3625604	et	3	main
sinine	doc_980560860262_item	3625603	et	4	main
on	doc_980560860262_item	3625602	et	4	main
taevas	doc_980560860262_item	3625601	et	4	main
halid	doc_980560860262_item	3625600	et	4	main
ei	doc_980560860262_item	3625599	et	4	main
valged	doc_980560860262_item	3625598	et	3	main
on	doc_980560860262_item	3625597	et	4	main
pilved	doc_980560860262_item	3625596	et	3	main
paistas	doc_980560860262_item	3625595	et	4	main
päike	doc_980560860262_item	3625594	et	3	main
mõnikord	doc_980560860262_item	3625593	et	3	main
siiski	doc_980560860262_item	3625592	et	4	main
palav	doc_980560860262_item	3625591	et	4	main
mitte	doc_980560860262_item	3625590	et	3	main
hoopiski	doc_980560860262_item	3625589	et	3	main
ole	doc_980560860262_item	3625587	et	4	main
soe	doc_980560860262_item	3625588	et	4	main
ei	doc_980560860262_item	3625586	et	4	main
tavaliselt	doc_980560860262_item	3625585	et	4	main
suvis	doc_980560860262_item	3625584	et	4	main
glasgows	doc_980560860262_item	3625583	et	4	main
aasta	doc_980560860262_item	3625582	et	4	main
šotimaal	doc_980560860262_item	3625570	et	2	main
ilm	doc_980560860262_item	3625569	et	3	main
võrdlema	doc_980560860262_item	3625568	et	3	main
võin	doc_980560860262_item	3625567	et	3	main
ma	doc_980560860262_item	3625566	et	3	main
lätis	doc_980560860262_item	3625565	et	4	main
ja	doc_980560860262_item	3625564	et	3	main
šotimaal	doc_980560860262_item	3625563	et	2	main
ilm	doc_980560860262_item	3625562	et	3	main
essee	doc_980560860262_item	3625561	et	4	main
väga	doc_980560860262_item	3625703	et	3	main
end	doc_980560860262_item	3625702	et	4	main
tunnen	doc_980560860262_item	3625701	et	3	main
ma	doc_980560860262_item	3625700	et	3	main
kauadaks	doc_980560860262_item	3625699	et	4	main
päevad	doc_980560860262_item	3625697	et	3	main
kui	doc_980560860262_item	3625696	et	3	main
et	doc_980560860262_item	3625695	et	3	main
tume	doc_980560860262_item	3625694	et	3	main
ja	doc_980560860262_item	3625693	et	3	main
hall	doc_980560860262_item	3625692	et	4	main
külm	doc_980560860262_item	3625691	et	3	main
kaua	doc_980560860262_item	3625690	et	3	main
saavad	doc_980560860262_item	3625698	et	4	main
nii	doc_980560860262_item	3625689	et	3	main
on	doc_980560860262_item	3625688	et	4	main
talv	doc_980560860262_item	3625687	et	3	main
sest	doc_980560860262_item	3625686	et	4	main
ka	doc_980560860262_item	3625685	et	3	main
lätis	doc_980560860262_item	3625684	et	4	main
ja	doc_980560860262_item	3625683	et	3	main
šotimaal	doc_980560860262_item	3625682	et	2	main
kevad	doc_980560860262_item	3625681	et	3	main
meeldis	doc_980560860262_item	3625680	et	3	main
oli	doc_980560860262_item	3625676	et	3	main
ei	doc_980560860262_item	3625675	et	4	main
ja	doc_980560860264_item	3625955	et	3	main
ma	doc_980560860264_item	3625938	et	3	main
aga	doc_980560860262_item	3625673	et	3	main
see	doc_980560860264_item	3625952	et	3	main
mängisin	doc_980560860264_item	3625939	et	3	main
noor	doc_980560860264_item	3625937	et	3	main
ma	doc_980560860264_item	3625935	et	3	main
ilm	doc_980560860264_item	3625931	et	3	main
maas	doc_980560860264_item	3625929	et	4	main
ei	doc_980560860264_item	3625927	et	4	main
lund	doc_980560860264_item	3625926	et	3	main
peaaegu	doc_980560860264_item	3625909	et	3	main
siin	doc_980560860264_item	3625907	et	4	main
ilusam	doc_980560860264_item	3625900	et	4	main
kus	doc_980560860264_item	3625892	et	3	main
alati	doc_980560860264_item	3625873	et	4	main
inimesed	doc_980560860264_item	3625867	et	3	main
suvel	doc_980560860264_item	3625863	et	3	main
et	doc_980560860264_item	3625861	et	3	main
kraadi	doc_980560860264_item	3625849	et	4	main
šotimaal	doc_980560860264_item	3625843	et	2	main
on	doc_980560860264_item	3625839	et	4	main
saksamaal	doc_980560860264_item	3625837	et	4	main
vaatamata	doc_980560860264_item	3625823	et	4	main
siin	doc_980560860264_item	3625816	et	4	main
ilm	doc_980560860264_item	3625813	et	3	main
aias	doc_980560860264_item	3625811	et	4	main
aastatel	doc_980560860264_item	3625800	et	4	main
on	doc_980560860264_item	3625734	et	4	main
tule	doc_128876189872_item	3625993	et	4	main
pole	doc_128876189872_item	3625969	et	3	main
poolel	doc_128876189872_item	3625967	et	4	main
tema	doc_128876189872_item	3626036	et	4	main
ei	doc_128876189872_item	3626026	et	4	main
liialt	doc_128876189872_item	3626017	et	4	main
leida	doc_128876189872_item	3626015	et	3	main
ajamiseks	doc_128876189872_item	3626014	et	4	main
olin	doc_980560860264_item	3625936	et	3	main
teisel	doc_980560860264_item	3625919	et	4	main
mitte	doc_980560860264_item	3625910	et	3	main
kui	doc_980560860264_item	3625906	et	3	main
ei	doc_980560860264_item	3625898	et	4	main
ilm	doc_980560860264_item	3625897	et	3	main
saksamaal	doc_980560860264_item	3625896	et	4	main
elab	doc_980560860264_item	3625895	et	3	main
vihm	doc_980560860264_item	3625856	et	3	main
aastatel	doc_980560860264_item	3625853	et	4	main
on	doc_980560860264_item	3625846	et	4	main
kui	doc_980560860264_item	3625842	et	3	main
suvel	doc_980560860264_item	3625838	et	3	main
ole	doc_980560860264_item	3625831	et	4	main
kahjuks	doc_980560860264_item	3625827	et	4	main
välja	doc_980560860264_item	3625826	et	4	main
minna	doc_980560860264_item	3625825	et	3	main
oli	doc_980560860264_item	3625804	et	3	main
jõudnud	doc_980560860264_item	3625803	et	4	main
oli	doc_980560860264_item	3625802	et	3	main
suvi	doc_980560860264_item	3625801	et	3	main
on	doc_980560860264_item	3625796	et	4	main
kuna	doc_980560860264_item	3625794	et	3	main
saab	doc_980560860264_item	3625791	et	3	main
kevadel	doc_980560860264_item	3625745	et	4	main
aastal	doc_980560860264_item	3625733	et	3	main
essee	doc_980560860264_item	3625732	et	4	main
enam-vähem	doc_128876189872_item	3625989	et	3	main
on	doc_128876189872_item	3625987	et	4	main
kuulab	doc_128876189872_item	3625985	et	3	main
vaatab	doc_128876189872_item	3625983	et	3	main
neid	doc_128876189872_item	3625982	et	4	main
kui	doc_128876189872_item	3625981	et	3	main
reklaame	doc_128876189872_item	3625980	et	3	main
või	doc_128876189872_item	3625973	et	4	main
näen	doc_128876189872_item	3625963	et	3	main
ole	doc_128876189872_item	3626027	et	4	main
enam	doc_128876189872_item	3626007	et	4	main
mis	doc_534729444708_item	3626297	et	4	main
kogedes	doc_534729444708_item	3626294	et	4	main
on	doc_534729444708_item	3626282	et	4	main
tulevad	doc_534729444708_item	3626272	et	4	main
nad	doc_534729444708_item	3626271	et	3	main
muidugi	doc_534729444708_item	3626270	et	4	main
laulupidu	doc_534729444708_item	3626261	et	4	main
on	doc_534729444708_item	3626203	et	4	main
lihtsalt	doc_534729444708_item	3626200	et	4	main
tähendab	doc_534729444708_item	3626192	et	3	main
meil	doc_534729444708_item	3626182	et	4	main
kui	doc_534729444708_item	3626181	et	3	main
näiteks	doc_534729444708_item	3626180	et	4	main
tantsida	doc_534729444708_item	3626179	et	3	main
hea	doc_534729444708_item	3626175	et	4	main
ilma	doc_534729444708_item	3626155	et	4	main
ja	doc_534729444708_item	3626154	et	3	main
muidugi	doc_534729444708_item	3626143	et	4	main
laulutraditsiooni	doc_534729444708_item	3626142	et	4	main
ka	doc_534729444708_item	3626141	et	3	main
kui	doc_534729444708_item	3626140	et	3	main
siis	doc_534729444708_item	3626133	et	3	main
kasulik	doc_534729444708_item	3626130	et	3	main
on	doc_534729444708_item	3626128	et	4	main
lapsed	doc_534729444708_item	3626121	et	3	main
kui	doc_534729444708_item	3626120	et	3	main
et	doc_534729444708_item	3626117	et	3	main
tegevus	doc_534729444708_item	3626113	et	4	main
sotsiaalne	doc_534729444708_item	3626112	et	3	main
ka	doc_534729444708_item	3626111	et	3	main
väljendusvahed	doc_534729444708_item	3626109	et	3	main
emotsionaalne	doc_534729444708_item	3626108	et	3	main
esteetiline	doc_534729444708_item	3626106	et	3	main
väiteid	doc_534729444708_item	3626085	et	4	main
esitatud	doc_534729444708_item	3626083	et	4	main
loengus	doc_534729444708_item	3626080	et	3	main
sooja	doc_980560860264_item	3625918	et	4	main
kraadi	doc_980560860264_item	3625917	et	4	main
glasgows	doc_980560860264_item	3625908	et	4	main
ilusam	doc_980560860264_item	3625905	et	4	main
saksamaal	doc_980560860264_item	3625904	et	4	main
olnud	doc_980560860264_item	3625899	et	4	main
kuudeks	doc_980560860264_item	3625891	et	4	main
ilus	doc_980560860264_item	3625889	et	4	main
ning	doc_980560860264_item	3625885	et	3	main
glasgows	doc_980560860264_item	3625882	et	4	main
elanud	doc_980560860264_item	3625881	et	4	main
olen	doc_980560860264_item	3625880	et	3	main
ma	doc_980560860264_item	3625879	et	3	main
seda	doc_980560860264_item	3625878	et	3	main
kahtlen	doc_980560860264_item	3625877	et	3	main
ma	doc_980560860264_item	3625876	et	3	main
vihm	doc_980560860264_item	3625875	et	3	main
sajab	doc_980560860264_item	3625874	et	3	main
siin	doc_980560860264_item	3625870	et	4	main
räägivad	doc_980560860264_item	3625868	et	3	main
sajasib	doc_980560860264_item	3625855	et	4	main
varasem	doc_980560860264_item	3625836	et	4	main
oli	doc_980560860264_item	3625835	et	3	main
kui	doc_980560860264_item	3625834	et	3	main
ilus	doc_980560860264_item	3625833	et	4	main
ei	doc_980560860264_item	3625830	et	4	main
tänane	doc_980560860264_item	3625828	et	3	main
vihm	doc_980560860264_item	3625820	et	3	main
sajab	doc_980560860264_item	3625819	et	3	main
alati	doc_980560860264_item	3625818	et	4	main
kevadel	doc_980560860264_item	3625817	et	4	main
päevitasime	doc_980560860264_item	3625810	et	3	main
aprillis	doc_980560860264_item	3625807	et	3	main
juba	doc_980560860264_item	3625806	et	3	main
tulenud	doc_980560860264_item	3625805	et	4	main
keegi	doc_980560860264_item	3625790	et	4	main
mitte	doc_980560860264_item	3625789	et	3	main
siis	doc_980560860264_item	3625788	et	3	main
vihm	doc_980560860264_item	3625787	et	3	main
on	doc_980560860264_item	3625743	et	4	main
ja	doc_980560860264_item	3625740	et	3	main
kevad	doc_980560860264_item	3625737	et	3	main
neli	doc_980560860264_item	3625735	et	3	main
kõik	doc_128876189872_item	3625991	et	4	main
saatatakse	doc_128876189872_item	3625979	et	4	main
televiisorist	doc_128876189872_item	3625972	et	4	main
on	doc_128876189872_item	3625965	et	4	main
linnas	doc_128876189872_item	3625961	et	4	main
leitud	doc_128876189872_item	3626028	et	4	main
uhket	doc_128876189872_item	3626024	et	3	main
alasti	doc_128876189872_item	3626019	et	3	main
mulle	doc_128876189872_item	3626000	et	4	main
ja	doc_128876189872_item	3625999	et	3	main
viisi	doc_534729444708_item	3626306	et	4	main
sama	doc_534729444708_item	3626305	et	4	main
ja	doc_534729444708_item	3626304	et	3	main
ülendavat	doc_534729444708_item	3626295	et	4	main
laulurahv	doc_534729444708_item	3626293	et	4	main
et	doc_534729444708_item	3626292	et	3	main
tahan	doc_534729444708_item	3626290	et	3	main
ma	doc_534729444708_item	3626289	et	3	main
kokkuvõtteks	doc_534729444708_item	3626288	et	3	main
sõitnud	doc_534729444708_item	3626287	et	4	main
kokku	doc_534729444708_item	3626286	et	3	main
jaoks	doc_534729444708_item	3626250	et	4	main
päeval	doc_980560860264_item	3625914	et	3	main
ühel	doc_980560860264_item	3625913	et	3	main
lund	doc_980560860264_item	3625912	et	3	main
sajab	doc_980560860264_item	3625911	et	3	main
sügisel	doc_980560860264_item	3625884	et	3	main
sügisel	doc_980560860264_item	3625872	et	3	main
et	doc_980560860264_item	3625869	et	3	main
vihmane	doc_980560860264_item	3625865	et	4	main
kuulsin	doc_980560860264_item	3625860	et	3	main
ma	doc_980560860264_item	3625859	et	3	main
suvel	doc_980560860264_item	3625858	et	3	main
ka	doc_980560860264_item	3625857	et	3	main
sageli	doc_980560860264_item	3625854	et	3	main
eelmistel	doc_980560860264_item	3625852	et	3	main
kuid	doc_980560860264_item	3625851	et	4	main
sooja	doc_980560860264_item	3625850	et	4	main
rohkem	doc_980560860264_item	3625847	et	4	main
mõnikord	doc_980560860264_item	3625844	et	3	main
korralikult	doc_980560860264_item	3625840	et	4	main
peavad	doc_980560860264_item	3625824	et	4	main
on	doc_980560860264_item	3625814	et	4	main
šotimaal	doc_980560860264_item	3625812	et	2	main
me	doc_980560860264_item	3625809	et	4	main
ja	doc_980560860264_item	3625808	et	3	main
liiga	doc_980560860264_item	3625797	et	4	main
tugev	doc_980560860264_item	3625786	et	4	main
sajab	doc_980560860264_item	3625785	et	3	main
mõnikord	doc_980560860264_item	3625784	et	3	main
kuid	doc_980560860264_item	3625783	et	4	main
soe	doc_980560860264_item	3625782	et	4	main
aga	doc_980560860264_item	3625781	et	3	main
tugev	doc_980560860264_item	3625780	et	4	main
ole	doc_980560860264_item	3625779	et	4	main
ei	doc_980560860264_item	3625778	et	4	main
tuul	doc_980560860264_item	3625777	et	3	main
sinine	doc_980560860264_item	3625776	et	4	main
taevas	doc_980560860264_item	3625774	et	4	main
on	doc_980560860264_item	3625775	et	4	main
paistab	doc_980560860264_item	3625773	et	3	main
sageli	doc_980560860264_item	3625772	et	3	main
päike	doc_980560860264_item	3625771	et	3	main
lõpuks	doc_980560860264_item	3625770	et	4	main
talve	doc_980560860264_item	3625769	et	4	main
kaua	doc_980560860264_item	3625768	et	3	main
pärast	doc_980560860264_item	3625767	et	4	main
ilus	doc_980560860264_item	3625766	et	4	main
on	doc_980560860264_item	3625765	et	4	main
ilm	doc_980560860264_item	3625764	et	3	main
tavaliselt	doc_980560860264_item	3625763	et	4	main
kevadel	doc_980560860264_item	3625762	et	4	main
saksamaal	doc_980560860264_item	3625761	et	4	main
näiteks	doc_980560860264_item	3625760	et	4	main
asute	doc_980560860264_item	3625759	et	3	main
olete	doc_980560860264_item	3625758	et	3	main
te	doc_980560860264_item	3625757	et	4	main
ükskõigne	doc_128876189872_item	3625992	et	4	main
nad	doc_128876189872_item	3625988	et	3	main
lähemalt	doc_128876189872_item	3625986	et	4	main
hetkel	doc_128876189872_item	3625978	et	4	main
sel	doc_128876189872_item	3625977	et	3	main
leida	doc_128876189872_item	3625971	et	3	main
ega	doc_128876189872_item	3625968	et	3	main
igal	doc_128876189872_item	3625966	et	3	main
ette	doc_128876189872_item	3626038	et	4	main
ilm	doc_980560860264_item	3625744	et	3	main
missugune	doc_980560860264_item	3625742	et	3	main
talv	doc_980560860264_item	3625741	et	3	main
sügis	doc_980560860264_item	3625739	et	3	main
suvi	doc_980560860264_item	3625738	et	3	main
aastaajad	doc_980560860264_item	3625736	et	3	main
reklaami	doc_128876189872_item	3626050	et	4	main
mõteta	doc_128876189872_item	3626049	et	4	main
tegijate	doc_128876189872_item	3626048	et	4	main
vaesekeste	doc_128876189872_item	3626047	et	4	main
vaataks	doc_128876189872_item	3626046	et	3	main
keegi	doc_128876189872_item	3626045	et	4	main
et	doc_128876189872_item	3626044	et	3	main
loodetakse	doc_128876189872_item	3626043	et	4	main
ja	doc_128876189872_item	3626042	et	3	main
inimene	doc_128876189872_item	3626041	et	3	main
alasti	doc_128876189872_item	3626040	et	3	main
lüüakse	doc_128876189872_item	3626039	et	3	main
ligikaudu	doc_128876189872_item	3625990	et	3	main
või	doc_128876189872_item	3625984	et	4	main
mis	doc_128876189872_item	3625976	et	4	main
kanalid	doc_128876189872_item	3625975	et	3	main
raadiost	doc_128876189872_item	3625974	et	3	main
rasket	doc_128876189872_item	3625970	et	3	main
reklaame	doc_128876189872_item	3625964	et	3	main
elan	doc_128876189872_item	3625962	et	3	main
kui	doc_128876189872_item	3625960	et	3	main
nüüd	doc_128876189872_item	3625959	et	4	main
arvamus	doc_128876189872_item	3625958	et	3	main
silmade	doc_128876189872_item	3626037	et	3	main
siis	doc_128876189872_item	3626035	et	3	main
ja	doc_128876189872_item	3626034	et	3	main
vastuvõtjat	doc_128876189872_item	3626033	et	3	main
läheneda	doc_128876189872_item	3626032	et	3	main
või	doc_128876189872_item	3626023	et	4	main
ilusat	doc_128876189872_item	3626021	et	3	main
kasutatakse	doc_128876189872_item	3626018	et	3	main
edasi	doc_128876189872_item	3626013	et	3	main
sõnumit	doc_128876189872_item	3626012	et	3	main
kerget	doc_128876189872_item	3626011	et	4	main
seda	doc_128876189872_item	3626010	et	3	main
viise	doc_128876189872_item	3626009	et	3	main
uusi	doc_128876189872_item	3626008	et	3	main
on	doc_128876189872_item	3626005	et	4	main
sõnum	doc_128876189872_item	3625998	et	3	main
nende	doc_128876189872_item	3625997	et	4	main
on	doc_128876189872_item	3625996	et	4	main
kasutama	doc_128876189872_item	3625995	et	3	main
raha	doc_128876189872_item	3625994	et	4	main
rahvuslikeks	doc_534729444708_item	3626313	et	3	main
aja	doc_534729444708_item	3626311	et	4	main
sõnu	doc_534729444708_item	3626303	et	4	main
sama	doc_534729444708_item	3626302	et	4	main
üheskoos	doc_534729444708_item	3626301	et	3	main
tunnet	doc_534729444708_item	3626296	et	3	main
lootuses	doc_534729444708_item	3626275	et	4	main
perega	doc_534729444708_item	3626274	et	3	main
tulevad	doc_534729444708_item	3626267	et	4	main
inimesed	doc_534729444708_item	3626266	et	3	main
kus	doc_534729444708_item	3626265	et	3	main
rahvapidu	doc_534729444708_item	3626264	et	4	main
suur	doc_534729444708_item	3626263	et	3	main
ka	doc_534729444708_item	3626262	et	3	main
laulupidu	doc_534729444708_item	3626258	et	4	main
kohe	doc_534729444708_item	3626256	et	4	main
tavalise	doc_534729444708_item	3626248	et	4	main
muusikalist	doc_534729444708_item	3626213	et	4	main
nad	doc_534729444708_item	3626211	et	3	main
kus	doc_534729444708_item	3626210	et	3	main
käivad	doc_534729444708_item	3626208	et	4	main
võivad	doc_534729444708_item	3626195	et	4	main
laulupidu	doc_534729444708_item	3626184	et	4	main
ühendab	doc_534729444708_item	3626166	et	3	main
laul	doc_534729444708_item	3626163	et	4	main
ja	doc_534729444708_item	3626159	et	3	main
kooriga	doc_534729444708_item	3626158	et	4	main
kahe	doc_534729444708_item	3626157	et	3	main
ka	doc_534729444708_item	3626156	et	3	main
kahekesi	doc_534729444708_item	3626151	et	3	main
kõik	doc_534729444708_item	3626144	et	4	main
lapsepõlvest	doc_534729444708_item	3626135	et	4	main
nende	doc_534729444708_item	3626131	et	4	main
väga	doc_534729444708_item	3626129	et	3	main
see	doc_534729444708_item	3626127	et	3	main
lapsepõlvest	doc_534729444708_item	3626119	et	4	main
nii	doc_534729444708_item	3626116	et	3	main
arvan	doc_534729444708_item	3626114	et	3	main
ja	doc_534729444708_item	3626107	et	3	main
kultuuriidentiteet	doc_534729444708_item	3626099	et	4	main
esiteks	doc_534729444708_item	3626098	et	3	main
mis	doc_534729444708_item	3626090	et	4	main
näidetega	doc_534729444708_item	3626089	et	3	main
illustreerida	doc_534729444708_item	3626088	et	3	main
soovitatav	doc_534729444708_item	3626087	et	4	main
tegelikult	doc_534729444709_item	3626626	et	4	main
nõksu	doc_128876189872_item	3626031	et	4	main
muud	doc_128876189872_item	3626030	et	4	main
mitagi	doc_128876189872_item	3626029	et	3	main
meest	doc_128876189872_item	3626025	et	4	main
naist	doc_128876189872_item	3626022	et	3	main
noort	doc_128876189872_item	3626020	et	3	main
aga	doc_128876189872_item	3626016	et	3	main
raske	doc_128876189872_item	3626006	et	4	main
tegijatel	doc_128876189872_item	3626004	et	4	main
reklaamide	doc_128876189872_item	3626003	et	3	main
et	doc_128876189872_item	3626002	et	3	main
tuntub	doc_128876189872_item	3626001	et	4	main
sümboliteks	doc_534729444708_item	3626314	et	3	main
kujunenud	doc_534729444708_item	3626312	et	4	main
läbi	doc_534729444708_item	3626310	et	4	main
on	doc_534729444708_item	3626309	et	4	main
laulurahvad	doc_534729444708_item	3626308	et	3	main
lauldes	doc_534729444708_item	3626307	et	3	main
teistega	doc_534729444708_item	3626300	et	4	main
tuhandete	doc_534729444708_item	3626299	et	3	main
maailma	doc_534729444708_item	3626285	et	4	main
kogu	doc_534729444708_item	3626284	et	4	main
üle	doc_534729444708_item	3626283	et	3	main
koos	doc_534729444708_item	3626273	et	4	main
tundub	doc_534729444708_item	3626259	et	3	main
ka	doc_534729444708_item	3626257	et	3	main
laul	doc_534729444708_item	3626255	et	4	main
ja	doc_534729444708_item	3626254	et	3	main
rahvas	doc_534729444708_item	3626253	et	4	main
sõnadega	doc_534729444708_item	3626252	et	3	main
seostub	doc_534729444708_item	3626251	et	3	main
et	doc_534729444708_item	3626247	et	3	main
suursündmust	doc_534729444708_item	3626214	et	3	main
see	doc_534729444708_item	3626202	et	3	main
inimesed	doc_534729444708_item	3626194	et	3	main
laulda	doc_534729444708_item	3626190	et	4	main
ka	doc_534729444708_item	3626188	et	3	main
võivad	doc_534729444708_item	3626187	et	4	main
mis	doc_534729444708_item	3626168	et	4	main
laulurahv	doc_534729444708_item	3626165	et	4	main
juba	doc_534729444708_item	3626134	et	3	main
laulavad	doc_534729444708_item	3626124	et	4	main
ja	doc_534729444708_item	3626123	et	3	main
kuulavad	doc_534729444708_item	3626122	et	4	main
tekib	doc_534729444708_item	3626298	et	3	main
öelda	doc_534729444708_item	3626291	et	4	main
kes	doc_534729444708_item	3626281	et	4	main
tuttavaid	doc_534729444708_item	3626280	et	3	main
ja	doc_534729444708_item	3626279	et	3	main
sugulasi	doc_534729444708_item	3626278	et	3	main
sõpru	doc_534729444708_item	3626277	et	3	main
kohata	doc_534729444708_item	3626276	et	4	main
kuulata	doc_534729444708_item	3626269	et	4	main
muusikat	doc_534729444708_item	3626268	et	3	main
et	doc_534729444708_item	3626260	et	3	main
eestlase	doc_534729444708_item	3626249	et	3	main
loomulik	doc_534729444708_item	3626246	et	3	main
on	doc_534729444708_item	3626245	et	4	main
seepärast	doc_534729444708_item	3626244	et	3	main
massiharrastuseks	doc_534729444708_item	3626243	et	3	main
kujunenud	doc_534729444708_item	3626242	et	4	main
hulgas	doc_534729444708_item	3626241	et	4	main
eestlaste	doc_534729444708_item	3626240	et	4	main
on	doc_534729444708_item	3626239	et	4	main
koorilaul	doc_534729444708_item	3626238	et	4	main
aastat	doc_534729444708_item	3626237	et	3	main
sada	doc_534729444708_item	3626236	et	4	main
peaaegu	doc_534729444708_item	3626235	et	3	main
juba	doc_534729444708_item	3626234	et	3	main
olnud	doc_534729444708_item	3626233	et	4	main
populaarsed	doc_534729444708_item	3626232	et	3	main
hulgas	doc_534729444708_item	3626231	et	4	main
eestlaste	doc_534729444708_item	3626230	et	4	main
on	doc_534729444708_item	3626229	et	4	main
lauludest	doc_534729444708_item	3626228	et	3	main
tulnud	doc_534729444708_item	3626227	et	4	main
ettekandele	doc_534729444708_item	3626226	et	4	main
hulk	doc_534729444708_item	3626225	et	3	main
suur	doc_534729444708_item	3626224	et	3	main
et	doc_534729444708_item	3626223	et	3	main
tean	doc_534729444708_item	3626222	et	3	main
mina	doc_534729444708_item	3626221	et	4	main
laulmine	doc_534729444708_item	3626220	et	4	main
meile	doc_534729444708_item	3626219	et	4	main
annab	doc_534729444708_item	3626218	et	3	main
mis	doc_534729444708_item	3626217	et	4	main
kuulata	doc_534729444708_item	3626216	et	4	main
puhkepilliorkestrit	doc_534729444708_item	3626215	et	3	main
võivad	doc_534729444708_item	3626212	et	4	main
vanemuises	doc_534729444708_item	3626209	et	3	main
nad	doc_534729444708_item	3626207	et	3	main
kui	doc_534729444708_item	3626206	et	3	main
inimestele	doc_534729444708_item	3626205	et	3	main
ja	doc_534729444708_item	3626198	et	3	main
lastekoore	doc_534729444708_item	3626197	et	4	main
naiskoore	doc_534729444708_item	3626196	et	4	main
see	doc_534729444708_item	3626191	et	3	main
laulurahvasid	doc_534729444708_item	3626189	et	4	main
on	doc_534729444708_item	3626183	et	4	main
tuju	doc_534729444708_item	3626176	et	4	main
teeb	doc_534729444708_item	3626174	et	3	main
ta	doc_534729444708_item	3626173	et	4	main
laulurahva	doc_534729444708_item	3626172	et	3	main
eestlastest	doc_534729444708_item	3626171	et	4	main
teeb	doc_534729444708_item	3626170	et	3	main
veel	doc_534729444708_item	3626169	et	4	main
eeslauljaga	doc_534729444708_item	3626153	et	3	main
üksi	doc_534729444708_item	3626150	et	4	main
on	doc_534729444708_item	3626148	et	4	main
tavalist	doc_534729444708_item	3626147	et	4	main
et	doc_534729444708_item	3626146	et	3	main
teavad	doc_534729444708_item	3626145	et	3	main
teavad	doc_534729444708_item	3626137	et	3	main
lapsed	doc_534729444708_item	3626136	et	3	main
ka	doc_534729444708_item	3626115	et	3	main
eestlastest	doc_534729444708_item	3626092	et	4	main
teeb	doc_534729444708_item	3626091	et	3	main
tuginema	doc_534729444708_item	3626079	et	3	main
kaasa	doc_534729444709_item	3626628	et	4	main
täna	doc_534729444709_item	3626615	et	4	main
tantsu	doc_534729444709_item	3626608	et	4	main
ning	doc_534729444709_item	3626607	et	3	main
traditsioonid	doc_534729444709_item	3626606	et	3	main
laulu	doc_534729444709_item	3626605	et	4	main
meie	doc_534729444709_item	3626600	et	4	main
ajal	doc_534729444709_item	3626580	et	4	main
tuli	doc_534729444709_item	3626574	et	4	main
naiskoorid	doc_534729444709_item	3626564	et	3	main
osavõtjatena	doc_534729444709_item	3626562	et	3	main
aastal	doc_534729444709_item	3626560	et	3	main
kadriorus	doc_534729444709_item	3626556	et	3	main
osavõtjate	doc_534729444709_item	3626522	et	3	main
tunnustamine	doc_534729444709_item	3626519	et	4	main
võitlesid	doc_534729444709_item	3626517	et	4	main
venemaa	doc_534729444709_item	3626506	et	4	main
5	doc_534729444709_item	3626496	et	2	main
ajaloolise	doc_534729444709_item	3626481	et	4	main
on	doc_534729444709_item	3626480	et	4	main
see	doc_534729444709_item	3626479	et	3	main
saksa	doc_534729444709_item	3626447	et	4	main
eelkõige	doc_534729444709_item	3626446	et	3	main
on	doc_534729444709_item	3626441	et	4	main
need	doc_534729444709_item	3626440	et	3	main
tekkeks	doc_534729444709_item	3626439	et	3	main
laulude	doc_534729444709_item	3626427	et	3	main
vaimulike	doc_534729444709_item	3626426	et	3	main
sajandil	doc_534729444709_item	3626417	et	3	main
pillisaateta	doc_534729444709_item	3626415	et	3	main
pöörajooks	doc_534729444709_item	3626411	et	4	main
ammu	doc_534729444709_item	3626364	et	4	main
ajaloost	doc_534729444709_item	3626363	et	4	main
alustan	doc_534729444709_item	3626362	et	3	main
loengus	doc_534729444709_item	3626344	et	3	main
analüüsiv	doc_534729444709_item	3626340	et	4	main
essee	doc_534729444709_item	3626336	et	4	main
edasi	doc_534729444709_item	3626391	et	3	main
ja	doc_534729444709_item	3626388	et	3	main
eeslaulja	doc_534729444709_item	3626386	et	4	main
näeb	doc_534729444709_item	3626384	et	3	main
eestimaa	doc_534729444710_item	3626677	et	4	main
rahvalauludes	doc_534729444710_item	3626675	et	3	main
esitatud	doc_534729444710_item	3626662	et	4	main
lugemistekstis	doc_534729444710_item	3626661	et	3	main
ja	doc_534729444710_item	3626660	et	3	main
loengus	doc_534729444710_item	3626659	et	3	main
tuginema	doc_534729444710_item	3626658	et	3	main
üldistav	doc_534729444710_item	3626657	et	4	main
essee	doc_534729444710_item	3626651	et	4	main
mis	doc_534729444710_item	3626642	et	4	main
eesti	doc_534729444710_item	3626632	et	4	main
essee	doc_534729444710_item	3626631	et	4	main
laulda	doc_534729444710_item	3626786	et	4	main
rahvalaulude	doc_534729444710_item	3626775	et	3	main
kasulik	doc_534729444708_item	3626204	et	3	main
nautida	doc_534729444708_item	3626201	et	3	main
poistekoore	doc_534729444708_item	3626199	et	4	main
et	doc_534729444708_item	3626193	et	3	main
seal	doc_534729444708_item	3626186	et	4	main
siis	doc_534729444708_item	3626185	et	3	main
võivad	doc_534729444708_item	3626178	et	4	main
inimesed	doc_534729444708_item	3626177	et	3	main
inimesi	doc_534729444708_item	3626167	et	4	main
ja	doc_534729444708_item	3626164	et	3	main
et	doc_534729444708_item	3626162	et	3	main
tähendab	doc_534729444708_item	3626161	et	3	main
see	doc_534729444708_item	3626160	et	3	main
kooriga	doc_534729444708_item	3626152	et	4	main
lauldud	doc_534729444708_item	3626149	et	4	main
eestlaste	doc_534729444708_item	3626139	et	4	main
nii	doc_534729444708_item	3626138	et	3	main
jaoks	doc_534729444708_item	3626132	et	4	main
sest	doc_534729444708_item	3626126	et	4	main
laulurahvasid	doc_534729444708_item	3626125	et	4	main
juba	doc_534729444708_item	3626118	et	3	main
on	doc_534729444708_item	3626105	et	4	main
ja	doc_534729444708_item	3626100	et	3	main
on	doc_534729444708_item	3626086	et	4	main
ja	doc_534729444708_item	3626081	et	3	main
üldistav	doc_534729444708_item	3626078	et	4	main
lauld	doc_534729444709_item	3626629	et	4	main
lisaks	doc_534729444709_item	3626613	et	4	main
ja	doc_534729444709_item	3626612	et	3	main
eestlased	doc_534729444709_item	3626602	et	3	main
laulupeod	doc_534729444709_item	3626598	et	4	main
raske	doc_534729444709_item	3626595	et	4	main
muidugi	doc_534729444709_item	3626593	et	4	main
suurenes	doc_534729444709_item	3626590	et	4	main
ning	doc_534729444709_item	3626589	et	3	main
esinemised	doc_534729444709_item	3626588	et	4	main
1960	doc_534729444709_item	3626587	et	2	main
poistekooride	doc_534729444709_item	3626586	et	3	main
ja	doc_534729444709_item	3626585	et	3	main
1947	doc_534729444709_item	3626584	et	2	main
sellel	doc_534729444709_item	3626579	et	4	main
laulda	doc_534729444709_item	3626573	et	4	main
ja	doc_534729444709_item	3626572	et	3	main
reeglid	doc_534729444709_item	3626571	et	3	main
ranged	doc_534729444709_item	3626570	et	3	main
kehtestati	doc_534729444709_item	3626569	et	3	main
ajal	doc_534729444709_item	3626566	et	4	main
alates	doc_534729444709_item	3626542	et	3	main
saanud	doc_534729444709_item	3626539	et	4	main
alguse	doc_534729444709_item	3626538	et	3	main
tartust	doc_534729444709_item	3626537	et	3	main
aastal	doc_534729444709_item	3626536	et	3	main
segakoorid	doc_534729444709_item	3626534	et	3	main
liitusid	doc_534729444709_item	3626528	et	4	main
juba	doc_534729444709_item	3626524	et	3	main
esimest	doc_534729444709_item	3626510	et	4	main
seitse	doc_534729444709_item	3626509	et	3	main
ja	doc_534729444709_item	3626508	et	3	main
mängijag	doc_534729444709_item	3626499	et	4	main
56	doc_534729444709_item	3626498	et	2	main
puhkpilliorkestrit	doc_534729444709_item	3626497	et	3	main
lauljaga	doc_534729444709_item	3626494	et	4	main
vanemuise	doc_534729444709_item	3626487	et	4	main
laulupidu	doc_534729444709_item	3626484	et	4	main
on	doc_534729444709_item	3626455	et	4	main
muusika	doc_534729444709_item	3626445	et	4	main
euroopa	doc_534729444709_item	3626444	et	4	main
19	doc_534729444709_item	3626431	et	2	main
kirikus	doc_534729444709_item	3626430	et	3	main
oli	doc_534729444709_item	3626429	et	3	main
kirikut	doc_534729444709_item	3626424	et	3	main
laulumine	doc_534729444709_item	3626421	et	4	main
18	doc_534729444709_item	3626416	et	2	main
palju	doc_534729444709_item	3626361	et	4	main
ja	doc_534729444709_item	3626345	et	3	main
mis	doc_534729444709_item	3626327	et	4	main
laulu	doc_534729444709_item	3626390	et	4	main
viib	doc_534729444709_item	3626389	et	3	main
alustab	doc_534729444709_item	3626387	et	3	main
nuga	doc_534729444709_item	3626385	et	4	main
välja	doc_534729444709_item	3626383	et	4	main
koor	doc_534729444709_item	3626382	et	4	main
aga	doc_534729444708_item	3626110	et	3	main
see	doc_534729444708_item	3626104	et	3	main
laulmine	doc_534729444708_item	3626103	et	4	main
ning	doc_534729444708_item	3626102	et	3	main
laulutraditsioon	doc_534729444708_item	3626101	et	3	main
vastusi	doc_534729444708_item	3626097	et	4	main
palju	doc_534729444708_item	3626096	et	4	main
on	doc_534729444708_item	3626095	et	4	main
mul	doc_534729444708_item	3626094	et	3	main
laulurahva	doc_534729444708_item	3626093	et	3	main
faktidele	doc_534729444708_item	3626084	et	3	main
lugemistekstis	doc_534729444708_item	3626082	et	3	main
ja	doc_534729444708_item	3626077	et	3	main
analüüsiv	doc_534729444708_item	3626076	et	4	main
arutlev	doc_534729444708_item	3626075	et	4	main
olema	doc_534729444708_item	3626074	et	4	main
peab	doc_534729444708_item	3626073	et	4	main
essee	doc_534729444708_item	3626072	et	4	main
sõna	doc_534729444708_item	3626071	et	4	main
350	doc_534729444708_item	3626070	et	2	main
300	doc_534729444708_item	3626069	et	2	main
pikkus	doc_534729444708_item	3626068	et	4	main
laulurahva	doc_534729444708_item	3626066	et	3	main
eestlastest	doc_534729444708_item	3626065	et	4	main
essee	doc_534729444708_item	3626067	et	4	main
teeb	doc_534729444708_item	3626064	et	3	main
mis	doc_534729444708_item	3626063	et	4	main
teemal	doc_534729444708_item	3626062	et	3	main
essee	doc_534729444708_item	3626061	et	4	main
kirjutage	doc_534729444708_item	3626060	et	3	main
kirjutamine	doc_534729444708_item	3626059	et	4	main
test	doc_534729444708_item	3626058	et	3	main
keele	doc_534729444708_item	3626057	et	4	main
teise	doc_534729444708_item	3626056	et	4	main
kui	doc_534729444708_item	3626055	et	3	main
keele	doc_534729444708_item	3626054	et	4	main
eesti	doc_534729444708_item	3626053	et	4	main
essee	doc_534729444708_item	3626052	et	4	main
võimalust	doc_534729444709_item	3626627	et	3	main
laulupeole	doc_534729444709_item	3626614	et	4	main
hoijanud	doc_534729444709_item	3626603	et	4	main
aga	doc_534729444709_item	3626597	et	3	main
oli	doc_534729444709_item	3626594	et	3	main
arv	doc_534729444709_item	3626592	et	3	main
osavõtjate	doc_534729444709_item	3626591	et	3	main
kavvale	doc_534729444709_item	3626582	et	4	main
pealesunnitud	doc_534729444709_item	3626576	et	4	main
nõukogude	doc_534729444709_item	3626565	et	3	main
1928	doc_534729444709_item	3626558	et	2	main
toimusid	doc_534729444709_item	3626555	et	4	main
ja	doc_534729444709_item	3626554	et	3	main
vabadusesõja	doc_534729444709_item	3626553	et	3	main
pärast	doc_534729444709_item	3626552	et	4	main
suurüritusteks	doc_534729444709_item	3626551	et	3	main
muutusid	doc_534729444709_item	3626548	et	4	main
osakond	doc_534729444709_item	3626625	et	3	main
kuulaja	doc_534729444709_item	3626624	et	4	main
perega	doc_534729444709_item	3626622	et	3	main
koos	doc_534729444709_item	3626621	et	4	main
tullakse	doc_534729444709_item	3626620	et	3	main
kuhu	doc_534729444709_item	3626619	et	3	main
rahvapidu	doc_534729444709_item	3626618	et	4	main
suur	doc_534729444709_item	3626617	et	3	main
täna	doc_534729444709_item	3626610	et	4	main
traditsioonid	doc_534729444709_item	3626609	et	3	main
ajal	doc_534729444709_item	3626601	et	4	main
toimuvad	doc_534729444709_item	3626599	et	4	main
tuli	doc_534729444709_item	3626581	et	4	main
palju	doc_534729444709_item	3626575	et	4	main
repertuaari	doc_534729444709_item	3626567	et	4	main
ka	doc_534729444709_item	3626563	et	3	main
lisandusid	doc_534729444709_item	3626561	et	4	main
1933	doc_534729444709_item	3626559	et	2	main
lauluväljakul	doc_534729444709_item	3626557	et	3	main
laulupeod	doc_534729444709_item	3626549	et	4	main
aastal	doc_534729444709_item	3626547	et	3	main
ka	doc_534729444709_item	3626533	et	3	main
puhkpilliorkestritele	doc_534729444709_item	3626532	et	3	main
ning	doc_534729444709_item	3626531	et	3	main
meeskoridele	doc_534729444709_item	3626530	et	4	main
kus	doc_534729444709_item	3626623	et	3	main
on	doc_534729444709_item	3626616	et	4	main
päevaseni	doc_534729444709_item	3626611	et	4	main
oma	doc_534729444709_item	3626604	et	4	main
aeg	doc_534729444709_item	3626596	et	3	main
lastekoride	doc_534729444709_item	3626583	et	4	main
laule	doc_534729444709_item	3626578	et	4	main
propagandistlikke	doc_534729444709_item	3626577	et	3	main
osas	doc_534729444709_item	3626568	et	4	main
muusika	doc_534729444709_item	3626550	et	4	main
ka	doc_534729444709_item	3626521	et	3	main
oli	doc_534729444709_item	3626504	et	3	main
ja	doc_534729444709_item	3626495	et	3	main
822	doc_534729444709_item	3626493	et	2	main
meeskoori	doc_534729444709_item	3626492	et	4	main
46	doc_534729444709_item	3626491	et	2	main
osales	doc_534729444709_item	3626490	et	3	main
ta	doc_534729444709_item	3626454	et	4	main
muusika	doc_534729444709_item	3626452	et	4	main
kujunenud	doc_534729444709_item	3626443	et	4	main
riimilise	doc_534729444709_item	3626437	et	4	main
pooles	doc_534729444709_item	3626434	et	4	main
laulmine	doc_534729444709_item	3626428	et	4	main
levima	doc_534729444709_item	3626422	et	3	main
hakkas	doc_534729444709_item	3626418	et	3	main
saatel	doc_534729444709_item	3626409	et	4	main
eestlastest	doc_534729444709_item	3626356	et	4	main
teeb	doc_534729444709_item	3626355	et	3	main
esitatud	doc_534729444709_item	3626347	et	4	main
lugemistekstis	doc_534729444709_item	3626346	et	3	main
üldistav	doc_534729444709_item	3626342	et	4	main
eestlastest	doc_534729444709_item	3626329	et	4	main
teeb	doc_534729444709_item	3626328	et	3	main
minevik	doc_534729444710_item	3626678	et	3	main
kajastub	doc_534729444710_item	3626676	et	3	main
mõjutanud	doc_534729444710_item	3626673	et	4	main
eestlast	doc_534729444710_item	3626672	et	4	main
väiteid	doc_534729444710_item	3626664	et	4	main
faktidele	doc_534729444710_item	3626663	et	3	main
300	doc_534729444710_item	3626648	et	2	main
pikkus	doc_534729444710_item	3626647	et	4	main
eestlastest	doc_534729444710_item	3626644	et	4	main
keele	doc_534729444710_item	3626633	et	4	main
sõpradega	doc_534729444710_item	3626789	et	3	main
perega	doc_534729444710_item	3626788	et	3	main
kus	doc_534729444710_item	3626784	et	3	main
suurteks	doc_534729444710_item	3626782	et	3	main
töödeldut	doc_534729444710_item	3626777	et	4	main
uut	doc_534729444710_item	3626776	et	3	main
1918	doc_534729444709_item	3626546	et	2	main
tallinnasse	doc_534729444709_item	3626545	et	3	main
peost	doc_534729444709_item	3626544	et	4	main
kuuendast	doc_534729444709_item	3626543	et	3	main
kandus	doc_534729444709_item	3626541	et	3	main
traditsioon	doc_534729444709_item	3626540	et	3	main
1896	doc_534729444709_item	3626535	et	2	main
senistele	doc_534729444709_item	3626529	et	3	main
peoses	doc_534729444709_item	3626526	et	4	main
arv	doc_534729444709_item	3626523	et	3	main
kasvas	doc_534729444709_item	3626520	et	3	main
koosseisus	doc_534729444709_item	3626507	et	4	main
eestimaa	doc_534729444709_item	3626503	et	4	main
sellel	doc_534729444709_item	3626501	et	4	main
muidugi	doc_534729444709_item	3626500	et	4	main
teoses	doc_534729444709_item	3626488	et	3	main
oli	doc_534729444709_item	3626485	et	3	main
et	doc_534729444709_item	3626478	et	3	main
rahvalaulu	doc_534729444709_item	3626438	et	4	main
eeldused	doc_534729444709_item	3626435	et	4	main
ii	doc_534729444709_item	3626433	et	4	main
sajandil	doc_534729444709_item	3626432	et	3	main
1891	doc_534729444709_item	3626527	et	2	main
neljandas	doc_534729444709_item	3626525	et	3	main
oma	doc_534729444709_item	3626518	et	4	main
nad	doc_534729444709_item	3626516	et	3	main
aga	doc_534729444709_item	3626515	et	3	main
eestlasele	doc_534729444709_item	3626514	et	3	main
rasked	doc_534729444709_item	3626513	et	3	main
oli	doc_534729444709_item	3626512	et	3	main
üldlaulupeod	doc_534729444709_item	3626511	et	4	main
tsaristliku	doc_534729444709_item	3626505	et	3	main
ajal	doc_534729444709_item	3626502	et	4	main
peol	doc_534729444709_item	3626489	et	4	main
baseritud	doc_534729444709_item	3626486	et	4	main
sündmus	doc_534729444709_item	3626483	et	3	main
tähtsusega	doc_534729444709_item	3626482	et	4	main
ööelda	doc_534729444709_item	3626477	et	4	main
saab	doc_534729444709_item	3626476	et	3	main
ja	doc_534729444709_item	3626475	et	3	main
laulupidu	doc_534729444709_item	3626474	et	4	main
ülemaaline	doc_534729444709_item	3626473	et	4	main
esimene	doc_534729444709_item	3626472	et	3	main
kujunes	doc_534729444709_item	3626471	et	3	main
tartus	doc_534729444709_item	3626470	et	3	main
aastal	doc_534729444709_item	3626469	et	3	main
1869	doc_534729444709_item	3626468	et	2	main
haridus	doc_534729444709_item	3626466	et	3	main
ning	doc_534729444709_item	3626465	et	3	main
muusika	doc_534729444709_item	3626464	et	4	main
on	doc_534729444709_item	3626463	et	4	main
ärkamine	doc_534729444709_item	3626467	et	4	main
ajal	doc_534729444709_item	3626462	et	4	main
selles	doc_534729444709_item	3626461	et	4	main
umbes	doc_534729444709_item	3626460	et	4	main
pillisaatega	doc_534729444709_item	3626459	et	3	main
esitatud	doc_534729444709_item	3626458	et	4	main
ja	doc_534729444709_item	3626457	et	3	main
värsimõõdult	doc_534729444709_item	3626456	et	3	main
mõjul	doc_534729444709_item	3626453	et	4	main
slaavi	doc_534729444709_item	3626451	et	3	main
ja	doc_534729444709_item	3626450	et	3	main
soome	doc_534729444709_item	3626449	et	3	main
rootsi	doc_534729444709_item	3626448	et	4	main
välja	doc_534729444709_item	3626442	et	4	main
uue	doc_534729444709_item	3626436	et	3	main
väljaspool	doc_534729444709_item	3626423	et	3	main
vaimulike	doc_534729444709_item	3626419	et	3	main
neid	doc_534729444709_item	3626413	et	4	main
mis	doc_534729444709_item	3626354	et	4	main
näidetega	doc_534729444709_item	3626353	et	3	main
illustreerida	doc_534729444709_item	3626352	et	3	main
soovitatav	doc_534729444709_item	3626351	et	4	main
on	doc_534729444709_item	3626350	et	4	main
tuginema	doc_534729444709_item	3626343	et	3	main
ja	doc_534729444709_item	3626341	et	3	main
arutlev	doc_534729444709_item	3626339	et	4	main
olema	doc_534729444709_item	3626338	et	4	main
peab	doc_534729444709_item	3626337	et	4	main
350	doc_534729444709_item	3626334	et	2	main
pikkus	doc_534729444709_item	3626332	et	4	main
essee	doc_534729444709_item	3626331	et	4	main
laulurahva	doc_534729444709_item	3626330	et	3	main
on	doc_534729444710_item	3626671	et	4	main
aegade	doc_534729444710_item	3626670	et	3	main
läbi	doc_534729444710_item	3626669	et	4	main
soovitatav	doc_534729444710_item	3626666	et	4	main
on	doc_534729444710_item	3626665	et	4	main
analüüsiv	doc_534729444710_item	3626655	et	4	main
sõna	doc_534729444710_item	3626650	et	4	main
350	doc_534729444710_item	3626649	et	2	main
teeb	doc_534729444710_item	3626643	et	3	main
teemal	doc_534729444710_item	3626641	et	3	main
ning	doc_534729444710_item	3626791	et	3	main
saab	doc_534729444710_item	3626785	et	3	main
kujunenud	doc_534729444710_item	3626781	et	4	main
kuulda	doc_534729444710_item	3626774	et	4	main
võimalik	doc_534729444710_item	3626773	et	3	main
on	doc_534729444710_item	3626772	et	4	main
festivalidel	doc_534729444710_item	3626771	et	3	main
folkloori	doc_534729444710_item	3626770	et	4	main
ja	doc_534729444710_item	3626767	et	3	main
regivärsiline	doc_534729444710_item	3626742	et	4	main
kohta	doc_534729444710_item	3626726	et	4	main
sest	doc_534729444710_item	3626690	et	4	main
võtnud	doc_534729444710_item	3626687	et	4	main
arvan	doc_534729444712_item	3627080	et	3	main
iseseisvust	doc_534729444712_item	3627076	et	4	main
rahvas	doc_534729444712_item	3627073	et	4	main
et	doc_534729444712_item	3627071	et	3	main
see	doc_534729444712_item	3627060	et	3	main
nnad	doc_534729444712_item	3627037	et	4	main
rahvas	doc_534729444712_item	3627027	et	4	main
suuliselt	doc_534729444712_item	3627025	et	4	main
laulud	doc_534729444712_item	3627020	et	3	main
ainult	doc_534729444712_item	3627017	et	4	main
olid	doc_534729444712_item	3627016	et	4	main
kirjandust	doc_534729444712_item	3627015	et	3	main
ja	doc_534729444712_item	3627014	et	3	main
tähestiku	doc_534729444712_item	3627013	et	3	main
oma	doc_534729444712_item	3627012	et	4	main
polnud	doc_534729444712_item	3627011	et	3	main
ajaloo	doc_534729444712_item	3626985	et	4	main
eesti	doc_534729444712_item	3626978	et	4	main
on	doc_534729444712_item	3626965	et	4	main
tuhat	doc_534729444712_item	3626954	et	4	main
samasugusi	doc_534729444712_item	3626951	et	4	main
laulu	doc_534729444712_item	3626942	et	4	main
elu	doc_534729444712_item	3626905	et	4	main
on	doc_534729444712_item	3626897	et	4	main
tema	doc_534729444712_item	3626888	et	4	main
teeb	doc_534729444712_item	3626876	et	3	main
ja	doc_534729444712_item	3626874	et	3	main
seotud	doc_534729444712_item	3626862	et	4	main
kes	doc_534729444713_item	3627353	et	4	main
olemas	doc_534729444713_item	3627350	et	4	main
bändi	doc_534729444713_item	3627345	et	4	main
noori	doc_534729444713_item	3627344	et	3	main
enem	doc_534729444709_item	3626425	et	4	main
laulude	doc_534729444709_item	3626420	et	3	main
ilma	doc_534729444709_item	3626414	et	4	main
lauldi	doc_534729444709_item	3626412	et	3	main
näteks	doc_534729444709_item	3626410	et	4	main
rääkida	doc_534729444709_item	3626360	et	3	main
saab	doc_534729444709_item	3626359	et	3	main
sellest	doc_534729444709_item	3626358	et	4	main
laulurahva	doc_534729444709_item	3626357	et	3	main
väiteid	doc_534729444709_item	3626349	et	4	main
faktidele	doc_534729444709_item	3626348	et	3	main
sõna	doc_534729444709_item	3626335	et	4	main
300	doc_534729444709_item	3626333	et	2	main
teemal	doc_534729444709_item	3626326	et	3	main
essee	doc_534729444709_item	3626325	et	4	main
kirjutage	doc_534729444709_item	3626324	et	3	main
kirjutamine	doc_534729444709_item	3626323	et	4	main
test	doc_534729444709_item	3626322	et	3	main
keele	doc_534729444709_item	3626321	et	4	main
teise	doc_534729444709_item	3626320	et	4	main
kui	doc_534729444709_item	3626319	et	3	main
keele	doc_534729444709_item	3626318	et	4	main
eesti	doc_534729444709_item	3626317	et	4	main
essee	doc_534729444709_item	3626316	et	4	main
liikumise	doc_534729444709_item	3626408	et	4	main
tansulise	doc_534729444709_item	3626407	et	4	main
ka	doc_534729444709_item	3626406	et	3	main
esitatud	doc_534729444709_item	3626405	et	4	main
jalapõrutusega	doc_534729444709_item	3626404	et	3	main
või	doc_534729444709_item	3626403	et	4	main
õõtsutamise	doc_534729444709_item	3626402	et	4	main
keha	doc_534729444709_item	3626401	et	4	main
näiteks	doc_534729444709_item	3626400	et	4	main
rütmi	doc_534729444709_item	3626399	et	4	main
rõhutad	doc_534729444709_item	3626398	et	3	main
võid	doc_534729444709_item	3626397	et	4	main
lauldes	doc_534729444709_item	3626396	et	3	main
eeslaulja	doc_534729444709_item	3626395	et	4	main
kordab	doc_534729444709_item	3626394	et	3	main
koor	doc_534729444709_item	3626393	et	4	main
ja	doc_534729444709_item	3626392	et	3	main
eeslaulja	doc_534729444709_item	3626380	et	4	main
esitasid	doc_534729444709_item	3626379	et	4	main
regilaul	doc_534729444709_item	3626378	et	4	main
regilaul	doc_534729444709_item	3626377	et	4	main
alustas	doc_534729444709_item	3626376	et	3	main
sellest	doc_534729444709_item	3626375	et	4	main
ja	doc_534729444709_item	3626374	et	3	main
rahvalaul	doc_534729444709_item	3626373	et	4	main
regivärsiline	doc_534729444709_item	3626372	et	4	main
kulturist	doc_534729444709_item	3626371	et	4	main
läänemeresoomest	doc_534729444709_item	3626370	et	4	main
eestimaale	doc_534729444709_item	3626369	et	4	main
tuli	doc_534729444709_item	3626368	et	4	main
tagasi	doc_534729444709_item	3626367	et	3	main
aastat	doc_534729444709_item	3626366	et	3	main
tuhat	doc_534729444709_item	3626365	et	4	main
rahvalaul	doc_534729444710_item	3626674	et	4	main
näidetega	doc_534729444710_item	3626668	et	3	main
ja	doc_534729444710_item	3626656	et	3	main
arutlev	doc_534729444710_item	3626654	et	4	main
olema	doc_534729444710_item	3626653	et	4	main
essee	doc_534729444710_item	3626646	et	4	main
kirjutage	doc_534729444710_item	3626639	et	3	main
test	doc_534729444710_item	3626637	et	3	main
teise	doc_534729444710_item	3626635	et	4	main
kui	doc_534729444710_item	3626634	et	3	main
versiooni	doc_534729444710_item	3626778	et	4	main
tänapäeva	doc_534729444710_item	3626769	et	4	main
kihnu	doc_534729444710_item	3626765	et	4	main
praegu	doc_534729444710_item	3626763	et	3	main
koos	doc_534729444710_item	3626754	et	4	main
naised	doc_534729444710_item	3626749	et	3	main
laulsid	doc_534729444710_item	3626748	et	4	main
põhiliselt	doc_534729444710_item	3626747	et	4	main
põlvest	doc_534729444710_item	3626744	et	4	main
riimiline	doc_534729444710_item	3626731	et	4	main
aluse	doc_534729444710_item	3626688	et	4	main
on	doc_534729444710_item	3626686	et	4	main
praegu	doc_534729444710_item	3626685	et	3	main
toimub	doc_534729444710_item	3626684	et	3	main
ning	doc_534729444710_item	3626683	et	3	main
enne	doc_534729444710_item	3626682	et	4	main
toimus	doc_534729444710_item	3626681	et	3	main
ja	doc_534729444709_item	3626381	et	3	main
kultuuri	doc_534729444710_item	3626808	et	4	main
ja	doc_534729444710_item	3626807	et	3	main
traditsioone	doc_534729444710_item	3626806	et	3	main
säilitada	doc_534729444710_item	3626805	et	3	main
aitab	doc_534729444710_item	3626804	et	3	main
see	doc_534729444710_item	3626803	et	3	main
tunnet	doc_534729444710_item	3626802	et	3	main
ühendavat	doc_534729444710_item	3626801	et	4	main
inimestes	doc_534729444710_item	3626800	et	3	main
tekitab	doc_534729444710_item	3626799	et	3	main
mis	doc_534729444710_item	3626798	et	4	main
viisi	doc_534729444710_item	3626797	et	4	main
sama	doc_534729444710_item	3626796	et	4	main
ja	doc_534729444710_item	3626795	et	3	main
sõnu	doc_534729444710_item	3626794	et	4	main
samu	doc_534729444710_item	3626793	et	3	main
tuttavatega	doc_534729444710_item	3626792	et	3	main
illustreerida	doc_534729444710_item	3626667	et	3	main
peab	doc_534729444710_item	3626652	et	4	main
laulurahva	doc_534729444710_item	3626645	et	3	main
essee	doc_534729444710_item	3626640	et	4	main
kirjutamine	doc_534729444710_item	3626638	et	4	main
keele	doc_534729444710_item	3626636	et	4	main
sugulastega	doc_534729444710_item	3626790	et	4	main
koos	doc_534729444710_item	3626787	et	4	main
rahvuspidudeks	doc_534729444710_item	3626783	et	4	main
on	doc_534729444710_item	3626780	et	4	main
laulmine	doc_534729444710_item	3626779	et	4	main
saarel	doc_534729444710_item	3626766	et	3	main
on	doc_534729444710_item	3626762	et	4	main
rahvalaulud	doc_534729444710_item	3626761	et	3	main
päris	doc_534729444710_item	3626759	et	4	main
pulmalaulud	doc_534729444710_item	3626758	et	3	main
laulsid	doc_534729444710_item	3626757	et	4	main
mehed	doc_534729444710_item	3626756	et	3	main
tehes	doc_534729444710_item	3626751	et	3	main
põlve	doc_534729444710_item	3626745	et	4	main
aga	doc_534729444710_item	3626743	et	3	main
trükitult	doc_534729444710_item	3626741	et	4	main
levis	doc_534729444710_item	3626740	et	4	main
alguse	doc_534729444710_item	3626735	et	3	main
sai	doc_534729444710_item	3626734	et	4	main
rahvalaul	doc_534729444710_item	3626728	et	4	main
jaoks	doc_534729444710_item	3626696	et	4	main
rahva	doc_534729444710_item	3626695	et	3	main
eesti	doc_534729444710_item	3626694	et	4	main
kogu	doc_534729444710_item	3626693	et	4	main
mis	doc_534729444710_item	3626680	et	4	main
oma	doc_534729444712_item	3627075	et	4	main
hoidis	doc_534729444712_item	3627028	et	4	main
pärandati	doc_534729444712_item	3627022	et	4	main
eestlastel	doc_534729444712_item	3627010	et	4	main
esimesed	doc_534729444712_item	3627006	et	3	main
kultuurid	doc_534729444712_item	3627004	et	3	main
ja	doc_534729444712_item	3627002	et	3	main
juhid	doc_534729444712_item	3627001	et	4	main
iseseisva	doc_534729444712_item	3626993	et	3	main
polnud	doc_534729444712_item	3626991	et	3	main
aastat	doc_534729444712_item	3626989	et	3	main
nime	doc_534729444712_item	3626982	et	4	main
laulurahva	doc_534729444712_item	3626981	et	3	main
sai	doc_534729444712_item	3626980	et	4	main
rahvas	doc_534729444712_item	3626979	et	4	main
eesti	doc_534729444712_item	3626961	et	4	main
et	doc_534729444712_item	3626960	et	3	main
ka	doc_534729444712_item	3626959	et	3	main
fakt	doc_534729444712_item	3626958	et	3	main
on	doc_534729444712_item	3626957	et	4	main
tagasi	doc_534729444712_item	3626956	et	3	main
täna	doc_534729444712_item	3626944	et	4	main
fakt	doc_534729444712_item	3626898	et	3	main
siis	doc_534729444712_item	3626893	et	3	main
kultuuri	doc_534729444712_item	3626889	et	4	main
kujutama	doc_534729444712_item	3626884	et	3	main
me	doc_534729444712_item	3626882	et	4	main
kõigepealt	doc_534729444712_item	3626881	et	3	main
et	doc_534729444712_item	3626880	et	3	main
arvan	doc_534729444712_item	3626879	et	3	main
iseloomade	doc_534729444712_item	3626866	et	4	main
identiteet	doc_534729444712_item	3626860	et	4	main
rahva	doc_534729444712_item	3626857	et	3	main
näitab	doc_534729444712_item	3626856	et	3	main
oma	doc_534729444712_item	3626851	et	4	main
rahval	doc_534729444712_item	3626849	et	3	main
näidetega	doc_534729444712_item	3626847	et	3	main
igapäevase	doc_534729444712_item	3627089	et	4	main
eesti	doc_534729444712_item	3626811	et	4	main
essee	doc_534729444712_item	3626810	et	4	main
regivärsilist	doc_534729444713_item	3627355	et	4	main
on	doc_534729444713_item	3627342	et	4	main
eestlastel	doc_534729444713_item	3627336	et	4	main
karjased	doc_534729444713_item	3627318	et	4	main
laule	doc_534729444713_item	3627309	et	4	main
setumaal	doc_534729444710_item	3626768	et	4	main
säilinud	doc_534729444710_item	3626764	et	4	main
ehtsad	doc_534729444710_item	3626760	et	3	main
tegeledes	doc_534729444710_item	3626753	et	3	main
suuliselt	doc_534729444710_item	3626746	et	4	main
sajandil	doc_534729444710_item	3626737	et	3	main
uuem	doc_534729444710_item	3626730	et	4	main
ja	doc_534729444710_item	3626729	et	3	main
rahvalaulude	doc_534729444710_item	3626725	et	3	main
väljendusvahend	doc_534729444710_item	3626698	et	3	main
on	doc_534729444710_item	3626692	et	4	main
rahvalaulust	doc_534729444710_item	3626689	et	4	main
eestlastel	doc_534729444712_item	3627082	et	4	main
et	doc_534729444712_item	3627081	et	3	main
jõudu	doc_534729444712_item	3627078	et	4	main
ja	doc_534729444712_item	3627035	et	3	main
ärkamisaeg	doc_534729444712_item	3627032	et	3	main
olid	doc_534729444712_item	3627000	et	4	main
need	doc_534729444712_item	3626999	et	3	main
jne	doc_534729444712_item	3626998	et	4	main
venelased	doc_534729444712_item	3626997	et	3	main
sakslased	doc_534729444712_item	3626996	et	3	main
oma	doc_534729444712_item	3626992	et	4	main
eestlastel	doc_534729444712_item	3626990	et	4	main
umbes	doc_534729444712_item	3626987	et	4	main
tänu	doc_534729444712_item	3626986	et	4	main
aeglaselt	doc_534729444712_item	3626976	et	4	main
nagu	doc_534729444712_item	3626966	et	3	main
eesti	doc_534729444712_item	3626963	et	4	main
aktsent	doc_534729444712_item	3626962	et	3	main
laulavad	doc_534729444712_item	3626948	et	4	main
emad	doc_534729444712_item	3626947	et	3	main
tänapäev	doc_534729444712_item	3626946	et	3	main
ja	doc_534729444712_item	3626945	et	3	main
igapäevase	doc_534729444712_item	3626904	et	4	main
eestlaste	doc_534729444712_item	3626903	et	4	main
tuhat	doc_534729444712_item	3626900	et	4	main
et	doc_534729444712_item	3626899	et	3	main
rahva	doc_534729444712_item	3626886	et	3	main
ette	doc_534729444712_item	3626885	et	4	main
peame	doc_534729444712_item	3626883	et	4	main
laulurahva	doc_534729444712_item	3626878	et	3	main
mis	doc_534729444712_item	3626875	et	4	main
inimeste	doc_534729444712_item	3626865	et	3	main
ajalooga	doc_534729444712_item	3626864	et	4	main
kombetega	doc_534729444712_item	3626863	et	3	main
see	doc_534729444712_item	3626859	et	3	main
mis	doc_534729444712_item	3626855	et	4	main
nimetus	doc_534729444712_item	3626854	et	4	main
ja	doc_534729444712_item	3626853	et	3	main
kultuuriidentiteet	doc_534729444712_item	3626852	et	4	main
igal	doc_534729444712_item	3626848	et	3	main
viibides	doc_534729444710_item	3626755	et	3	main
lastega	doc_534729444710_item	3626752	et	3	main
tööd	doc_534729444710_item	3626750	et	4	main
rahvalaul	doc_534729444710_item	3626739	et	4	main
riimiline	doc_534729444710_item	3626738	et	4	main
19	doc_534729444710_item	3626736	et	2	main
mis	doc_534729444710_item	3626733	et	4	main
rahvalaul	doc_534729444710_item	3626732	et	4	main
regivärsiline	doc_534729444710_item	3626727	et	4	main
kihistust	doc_534729444710_item	3626724	et	4	main
kaks	doc_534729444710_item	3626722	et	3	main
ajaloolist	doc_534729444710_item	3626723	et	4	main
olemas	doc_534729444710_item	3626721	et	4	main
on	doc_534729444710_item	3626720	et	4	main
traditsioone	doc_534729444710_item	3626719	et	3	main
vanu	doc_534729444710_item	3626718	et	4	main
ja	doc_534729444710_item	3626717	et	3	main
kultuuriidentiteedi	doc_534729444710_item	3626716	et	4	main
eestlaste	doc_534729444710_item	3626715	et	4	main
illustreerib	doc_534729444710_item	3626714	et	3	main
laulmine	doc_534729444710_item	3626713	et	4	main
sest	doc_534729444710_item	3626712	et	4	main
sümboliks	doc_534729444710_item	3626711	et	4	main
rahvuslikuks	doc_534729444710_item	3626710	et	3	main
kujunenud	doc_534729444710_item	3626709	et	4	main
on	doc_534729444710_item	3626708	et	4	main
rahvalaul	doc_534729444710_item	3626707	et	4	main
hauani	doc_534729444710_item	3626706	et	3	main
hällist	doc_534729444710_item	3626705	et	4	main
eestlast	doc_534729444710_item	3626704	et	4	main
saadab	doc_534729444710_item	3626703	et	3	main
mis	doc_534729444710_item	3626702	et	4	main
tegevus	doc_534729444710_item	3626701	et	4	main
sotsiaalne	doc_534729444710_item	3626700	et	3	main
ning	doc_534729444710_item	3626699	et	3	main
emotsioonaalne	doc_534729444710_item	3626697	et	4	main
laulmine	doc_534729444710_item	3626691	et	4	main
kõik	doc_534729444710_item	3626679	et	4	main
ja	doc_534729444712_item	3627077	et	3	main
laulu	doc_534729444712_item	3627066	et	4	main
ainuke	doc_534729444712_item	3627065	et	4	main
ja	doc_534729444712_item	3627064	et	3	main
protest	doc_534729444712_item	3627063	et	3	main
rahva	doc_534729444712_item	3627062	et	3	main
oli	doc_534729444712_item	3627061	et	3	main
xix	doc_534729444712_item	3627033	et	4	main
kultuuri	doc_534729444712_item	3627030	et	4	main
oma	doc_534729444712_item	3627029	et	4	main
mida	doc_534729444712_item	3627021	et	4	main
aega	doc_534729444712_item	3627009	et	4	main
palju	doc_534729444712_item	3627008	et	4	main
riigis	doc_534729444712_item	3627007	et	3	main
lauluga	doc_534729444712_item	3627111	et	4	main
seotud	doc_534729444712_item	3627110	et	4	main
on	doc_534729444712_item	3627109	et	4	main
elus	doc_534729444712_item	3627108	et	4	main
rahva	doc_534729444712_item	3627107	et	3	main
sündmused	doc_534729444712_item	3627106	et	3	main
ja	doc_534729444712_item	3627105	et	3	main
olukorrad	doc_534729444712_item	3627104	et	3	main
tähtsad	doc_534729444712_item	3627103	et	3	main
paljud	doc_534729444712_item	3627102	et	3	main
sest	doc_534729444712_item	3627101	et	4	main
laulurahva	doc_534729444712_item	3627100	et	3	main
eestlastest	doc_534729444712_item	3627099	et	4	main
teevad	doc_534729444712_item	3627098	et	3	main
ajalugu	doc_534729444712_item	3627097	et	4	main
eestlaste	doc_534729444712_item	3627096	et	4	main
ja	doc_534729444712_item	3627095	et	3	main
see	doc_534729444712_item	3627094	et	3	main
laul	doc_534729444712_item	3627093	et	4	main
juba	doc_534729444712_item	3627092	et	3	main
on	doc_534729444712_item	3627091	et	4	main
suhtlemine	doc_534729444712_item	3627090	et	4	main
ole	doc_534729444712_item	3627084	et	4	main
ei	doc_534729444712_item	3627083	et	4	main
laulus	doc_534729444712_item	3627079	et	3	main
näidis	doc_534729444712_item	3627074	et	4	main
eesti	doc_534729444712_item	3627072	et	4	main
öelda	doc_534729444712_item	3627070	et	4	main
võib	doc_534729444712_item	3627069	et	3	main
maailmas	doc_534729444712_item	3627068	et	3	main
revolutsioon	doc_534729444712_item	3627067	et	3	main
laulupidudes	doc_534729444712_item	3627059	et	4	main
kultuuri	doc_534729444712_item	3627058	et	4	main
oma	doc_534729444712_item	3627057	et	4	main
areneda	doc_534729444712_item	3627056	et	3	main
ja	doc_534729444712_item	3627055	et	3	main
keeli	doc_534729444712_item	3627054	et	4	main
oma	doc_534729444712_item	3627053	et	4	main
rääkida	doc_534729444712_item	3627052	et	3	main
ning	doc_534729444712_item	3627051	et	3	main
riigis	doc_534729444712_item	3627050	et	3	main
iseseisvas	doc_534729444712_item	3627049	et	3	main
elada	doc_534729444712_item	3627048	et	3	main
soovi	doc_534729444712_item	3627047	et	4	main
oma	doc_534729444712_item	3627046	et	4	main
näitasid	doc_534729444712_item	3627045	et	4	main
inimesed	doc_534729444712_item	3627044	et	3	main
sest	doc_534729444712_item	3627043	et	4	main
laulmisega	doc_534729444712_item	3627042	et	4	main
kõigepealt	doc_534729444712_item	3627041	et	3	main
seotud	doc_534729444712_item	3627040	et	4	main
ka	doc_534729444712_item	3627039	et	3	main
on	doc_534729444712_item	3627038	et	4	main
1980	doc_534729444712_item	3627036	et	2	main
sajand	doc_534729444712_item	3627034	et	3	main
rahva	doc_534729444712_item	3627031	et	3	main
nii	doc_534729444712_item	3627026	et	3	main
põlve	doc_534729444712_item	3627024	et	4	main
põlvest	doc_534729444712_item	3627023	et	4	main
ja	doc_534729444712_item	3627019	et	3	main
muinasjuttud	doc_534729444712_item	3627018	et	4	main
olid	doc_534729444712_item	3627005	et	4	main
rootslased	doc_534729444712_item	3626995	et	3	main
700	doc_534729444712_item	3626988	et	2	main
laulda	doc_534729444712_item	3626975	et	4	main
on	doc_534729444712_item	3626973	et	4	main
keeles	doc_534729444712_item	3626972	et	4	main
eesti	doc_534729444712_item	3626971	et	4	main
ilusasti	doc_534729444712_item	3626970	et	3	main
rääkida	doc_534729444712_item	3626969	et	3	main
et	doc_534729444712_item	3626968	et	3	main
aastat	doc_534729444712_item	3626955	et	3	main
laulu	doc_534729444712_item	3626952	et	4	main
lastele	doc_534729444712_item	3626950	et	4	main
omade	doc_534729444712_item	3626949	et	3	main
nende	doc_534729444712_item	3627003	et	4	main
riigi	doc_534729444712_item	3626994	et	3	main
oma	doc_534729444712_item	3626984	et	4	main
ka	doc_534729444712_item	3626983	et	3	main
hingega	doc_534729444712_item	3626977	et	3	main
vaja	doc_534729444712_item	3626974	et	4	main
laul	doc_534729444712_item	3626967	et	4	main
hääldus	doc_534729444712_item	3626964	et	4	main
nagu	doc_534729444712_item	3626953	et	3	main
veel	doc_534729444712_item	3626943	et	4	main
neid	doc_534729444712_item	3626941	et	4	main
mäletab	doc_534729444712_item	3626940	et	3	main
rahvas	doc_534729444712_item	3626939	et	4	main
eesti	doc_534729444712_item	3626938	et	4	main
tähtsam	doc_534729444712_item	3626937	et	4	main
kõige	doc_534729444712_item	3626936	et	4	main
on	doc_534729444712_item	3626935	et	4	main
mis	doc_534729444712_item	3626934	et	4	main
ja	doc_534729444712_item	3626933	et	3	main
sellega	doc_534729444712_item	3626932	et	3	main
sarnaneb	doc_534729444712_item	3626931	et	3	main
või	doc_534729444712_item	3626930	et	4	main
lauluvormis	doc_534729444712_item	3626929	et	3	main
tihti	doc_534729444712_item	3626928	et	3	main
on	doc_534729444712_item	3626927	et	4	main
eepos	doc_534729444712_item	3626926	et	3	main
eesti	doc_534729444712_item	3626925	et	4	main
nutta	doc_534729444712_item	3626924	et	3	main
rõõmustada	doc_534729444712_item	3626923	et	3	main
last	doc_534729444712_item	3626922	et	4	main
õpetada	doc_534729444712_item	3626921	et	3	main
et	doc_534729444712_item	3626920	et	3	main
koos	doc_534729444712_item	3626919	et	4	main
olla	doc_534729444712_item	3626918	et	3	main
et	doc_534729444712_item	3626917	et	3	main
rütmi	doc_534729444712_item	3626916	et	4	main
hoida	doc_534729444712_item	3626914	et	3	main
et	doc_534729444712_item	3626913	et	3	main
laulsid	doc_534729444712_item	3626912	et	4	main
töö	doc_534729444712_item	3626915	et	4	main
inimesed	doc_534729444712_item	3626911	et	3	main
laulmine	doc_534729444712_item	3626910	et	4	main
oli	doc_534729444712_item	3626909	et	3	main
sõber	doc_534729444712_item	3626908	et	3	main
ja	doc_534729444712_item	3626907	et	3	main
naaber	doc_534729444712_item	3626906	et	3	main
tagasi	doc_534729444712_item	3626902	et	3	main
laulu	doc_534729444712_item	3626896	et	4	main
alguset	doc_534729444712_item	3626890	et	4	main
harjumustega	doc_534729444712_item	3626868	et	4	main
ja	doc_534729444712_item	3626867	et	3	main
on	doc_534729444712_item	3626850	et	4	main
illustreerida	doc_534729444712_item	3626846	et	3	main
soovitatav	doc_534729444712_item	3626845	et	4	main
on	doc_534729444712_item	3626844	et	4	main
väiteid	doc_534729444712_item	3626843	et	4	main
faktidele	doc_534729444712_item	3626842	et	3	main
esitatud	doc_534729444712_item	3626841	et	4	main
lugemistekstis	doc_534729444712_item	3626840	et	3	main
ja	doc_534729444712_item	3626839	et	3	main
loengus	doc_534729444712_item	3626838	et	3	main
tuginema	doc_534729444712_item	3626837	et	3	main
üldistav	doc_534729444712_item	3626836	et	4	main
ja	doc_534729444712_item	3626835	et	3	main
arutlev	doc_534729444712_item	3626833	et	4	main
analüüsiv	doc_534729444712_item	3626834	et	4	main
olema	doc_534729444712_item	3626832	et	4	main
peab	doc_534729444712_item	3626831	et	4	main
essee	doc_534729444712_item	3626830	et	4	main
sõna	doc_534729444712_item	3626829	et	4	main
350	doc_534729444712_item	3626828	et	2	main
300	doc_534729444712_item	3626827	et	2	main
pikkus	doc_534729444712_item	3626826	et	4	main
essee	doc_534729444712_item	3626825	et	4	main
laulurahva	doc_534729444712_item	3626824	et	3	main
eestlastest	doc_534729444712_item	3626823	et	4	main
teeb	doc_534729444712_item	3626822	et	3	main
mis	doc_534729444712_item	3626821	et	4	main
teemal	doc_534729444712_item	3626820	et	3	main
kirjutage	doc_534729444712_item	3626818	et	3	main
essee	doc_534729444712_item	3626819	et	4	main
kirjutamine	doc_534729444712_item	3626817	et	4	main
test	doc_534729444712_item	3626816	et	3	main
keele	doc_534729444712_item	3626815	et	4	main
vaja	doc_534729444712_item	3627085	et	4	main
teise	doc_534729444712_item	3626814	et	4	main
kui	doc_534729444712_item	3626813	et	3	main
keele	doc_534729444712_item	3626812	et	4	main
on	doc_534729444713_item	3627349	et	4	main
olemas	doc_534729444713_item	3627343	et	4	main
täna	doc_534729444713_item	3627334	et	4	main
arust	doc_534729444713_item	3627330	et	4	main
lapsepõlvest	doc_534729444713_item	3627311	et	4	main
aastat	doc_534729444712_item	3626901	et	3	main
teame	doc_534729444712_item	3626895	et	3	main
sellest	doc_534729444712_item	3626894	et	4	main
me	doc_534729444712_item	3626892	et	4	main
mida	doc_534729444712_item	3626891	et	4	main
sünnitust	doc_534729444712_item	3626887	et	4	main
eestlastest	doc_534729444712_item	3626877	et	4	main
miks	doc_534729444712_item	3626873	et	4	main
laulurahvana	doc_534729444712_item	3626872	et	3	main
iseenda	doc_534729444712_item	3626871	et	3	main
nimetavad	doc_534729444712_item	3626870	et	4	main
eestlased	doc_534729444712_item	3626869	et	3	main
on	doc_534729444712_item	3626861	et	4	main
hinget	doc_534729444712_item	3626858	et	4	main
nende	doc_534729444712_item	3627088	et	4	main
laulma	doc_534729444712_item	3627087	et	3	main
õppida	doc_534729444712_item	3627086	et	3	main
folkloori	doc_534729444713_item	3627348	et	4	main
propagandeerivad	doc_534729444713_item	3627347	et	4	main
lauljaid	doc_534729444713_item	3627341	et	4	main
muusikuid	doc_534729444713_item	3627340	et	3	main
häid	doc_534729444713_item	3627339	et	3	main
palju	doc_534729444713_item	3627338	et	4	main
just	doc_534729444713_item	3627333	et	3	main
saab	doc_534729444713_item	3627331	et	3	main
minu	doc_534729444713_item	3627329	et	3	main
näiteks	doc_534729444713_item	3627317	et	4	main
nii	doc_534729444713_item	3627316	et	3	main
lastele	doc_534729444713_item	3627308	et	4	main
oma	doc_534729444713_item	3627307	et	4	main
kaasa	doc_534729444713_item	3627299	et	4	main
või	doc_534729444713_item	3627287	et	4	main
osa	doc_534729444713_item	3627278	et	4	main
võtavad	doc_534729444713_item	3627277	et	3	main
laulupeol	doc_534729444713_item	3627276	et	4	main
näide	doc_534729444713_item	3627271	et	3	main
ja	doc_534729444713_item	3627268	et	3	main
uhke	doc_534729444713_item	3627265	et	4	main
oli	doc_534729444713_item	3627258	et	3	main
sellisena	doc_534729444713_item	3627254	et	4	main
folkloori	doc_534729444713_item	3627253	et	4	main
teiste	doc_534729444713_item	3627242	et	4	main
tihti	doc_534729444713_item	3627241	et	3	main
teiseks	doc_534729444713_item	3627232	et	4	main
pulmalauljad	doc_534729444713_item	3627231	et	3	main
oma	doc_534729444713_item	3627220	et	4	main
edasi	doc_534729444713_item	3627219	et	3	main
aastast	doc_534729444713_item	3627212	et	4	main
oma	doc_534729444713_item	3627208	et	4	main
või	doc_534729444713_item	3627206	et	4	main
regilaule	doc_534729444713_item	3627195	et	4	main
regivärsiliseks	doc_534729444713_item	3627194	et	4	main
esitatud	doc_534729444713_item	3627144	et	4	main
lugemistekstis	doc_534729444713_item	3627143	et	3	main
essee	doc_534729444713_item	3627133	et	4	main
sõna	doc_534729444713_item	3627132	et	4	main
keele	doc_534729444713_item	3627115	et	4	main
eurovisioon	doc_534729444713_item	3627362	et	3	main
kord	doc_534729444713_item	3627359	et	4	main
iga	doc_534729444713_item	3627358	et	4	main
eesti	doc_534729444713_item	3627357	et	4	main
elukaaslaseks	doc_534729444713_item	3627389	et	3	main
neile	doc_534729444713_item	3627388	et	4	main
alati	doc_534729444713_item	3627387	et	4	main
on	doc_534729444713_item	3627386	et	4	main
ja	doc_534729444713_item	3627385	et	3	main
südames	doc_534729444713_item	3627384	et	3	main
eestlaste	doc_534729444713_item	3627383	et	4	main
elab	doc_534729444713_item	3627382	et	3	main
laul	doc_534729444713_item	3627381	et	4	main
et	doc_534729444713_item	3627380	et	3	main
see	doc_534729444713_item	3627379	et	3	main
on	doc_534729444713_item	3627378	et	4	main
laulurahva	doc_534729444713_item	3627377	et	3	main
laulu	doc_534729444713_item	3627356	et	4	main
säilitasid	doc_534729444713_item	3627354	et	4	main
setu	doc_534729444713_item	3627352	et	4	main
rahvus	doc_534729444713_item	3627351	et	3	main
kes	doc_534729444713_item	3627346	et	4	main
päeval	doc_534729444713_item	3627335	et	3	main
näha	doc_534729444713_item	3627332	et	3	main
laulurahva	doc_534729444713_item	3627328	et	3	main
eestlast	doc_534729444713_item	3627327	et	4	main
teeb	doc_534729444713_item	3627326	et	3	main
mis	doc_534729444713_item	3627325	et	4	main
asi	doc_534729444713_item	3627324	et	4	main
tähtsam	doc_534729444713_item	3627323	et	4	main
kõige	doc_534729444713_item	3627322	et	4	main
on	doc_534729444713_item	3627337	et	4	main
olid	doc_534729444713_item	3627313	et	4	main
lapsed	doc_534729444713_item	3627312	et	3	main
elada	doc_534729444713_item	3627297	et	3	main
nautida	doc_534729444713_item	3627295	et	3	main
üritustele	doc_534729444713_item	3627293	et	4	main
sellistele	doc_534729444713_item	3627292	et	4	main
laulja	doc_534729444713_item	3627286	et	4	main
sellele	doc_534729444713_item	3627283	et	4	main
laulupeod	doc_534729444713_item	3627275	et	4	main
ja	doc_534729444713_item	3627274	et	3	main
tantsu-	doc_534729444713_item	3627273	et	4	main
iga	doc_534729444713_item	3627266	et	4	main
olema	doc_534729444713_item	3627264	et	4	main
rootsi	doc_534729444713_item	3627246	et	4	main
nt	doc_534729444713_item	3627245	et	4	main
all	doc_534729444713_item	3627244	et	3	main
riikide	doc_534729444713_item	3627243	et	3	main
märkida	doc_534729444713_item	3627234	et	4	main
tahaks	doc_534729444713_item	3627233	et	3	main
mehed	doc_534729444713_item	3627228	et	3	main
suuliselt	doc_534729444713_item	3627217	et	4	main
eestlased	doc_534729444713_item	3627216	et	3	main
kokku	doc_534729444713_item	3627210	et	3	main
said	doc_534729444713_item	3627207	et	4	main
tuginema	doc_534729444713_item	3627140	et	3	main
300	doc_534729444713_item	3627130	et	2	main
teemal	doc_534729444713_item	3627123	et	3	main
kirjutamine	doc_534729444713_item	3627120	et	4	main
kõige	doc_534729444713_item	3627371	et	4	main
arust	doc_534729444713_item	3627370	et	4	main
minu	doc_534729444713_item	3627369	et	3	main
võitnud	doc_534729444713_item	3627366	et	4	main
on	doc_534729444713_item	3627364	et	4	main
ja	doc_534729444713_item	3627363	et	3	main
sama	doc_534729444714_item	3627545	et	4	main
kuuskilt	doc_534729444714_item	3627543	et	4	main
et	doc_534729444714_item	3627542	et	3	main
aastal	doc_534729444714_item	3627533	et	3	main
umbes	doc_534729444714_item	3627528	et	4	main
rahvuse	doc_534729444714_item	3627505	et	3	main
oli	doc_534729444714_item	3627495	et	3	main
magada	doc_534729444714_item	3627488	et	3	main
oli	doc_534729444714_item	3627476	et	3	main
ikka	doc_534729444714_item	3627464	et	4	main
kuid	doc_534729444713_item	3627321	et	4	main
üksteisele	doc_534729444713_item	3627320	et	3	main
hõikusid	doc_534729444713_item	3627319	et	4	main
lauluga	doc_534729444713_item	3627315	et	4	main
seotud	doc_534729444713_item	3627314	et	4	main
tänapäeval	doc_534729444713_item	3627304	et	3	main
seltskonda	doc_534729444713_item	3627296	et	4	main
et	doc_534729444713_item	3627294	et	3	main
on	doc_534729444713_item	3627284	et	4	main
vaatamata	doc_534729444713_item	3627282	et	4	main
rahvast	doc_534729444713_item	3627281	et	4	main
suur	doc_534729444713_item	3627270	et	3	main
selle	doc_534729444713_item	3627261	et	4	main
ja	doc_534729444713_item	3627260	et	3	main
juba	doc_534729444713_item	3627310	et	3	main
laulavad	doc_534729444713_item	3627306	et	4	main
kui	doc_534729444713_item	3627302	et	3	main
nii	doc_534729444713_item	3627300	et	3	main
üritusele	doc_534729444713_item	3627298	et	4	main
tulevad	doc_534729444713_item	3627291	et	4	main
inimesed	doc_534729444713_item	3627290	et	3	main
siiamaani	doc_534729444713_item	3627289	et	3	main
see	doc_534729444713_item	3627285	et	3	main
on	doc_534729444713_item	3627272	et	4	main
väga	doc_534729444713_item	3627269	et	3	main
eestlane	doc_534729444713_item	3627267	et	3	main
alati	doc_534729444713_item	3627257	et	4	main
milline	doc_534729444713_item	3627255	et	3	main
säilisid	doc_534729444713_item	3627251	et	4	main
olid	doc_534729444713_item	3627240	et	4	main
eestlased	doc_534729444713_item	3627239	et	3	main
head	doc_534729444713_item	3627230	et	4	main
andsid	doc_534729444713_item	3627218	et	4	main
ja	doc_534729444713_item	3627211	et	3	main
laulsid	doc_534729444713_item	3627197	et	4	main
tavaliselt	doc_534729444713_item	3627196	et	4	main
mis	doc_534729444713_item	3627192	et	4	main
mis	doc_534729444713_item	3627162	et	4	main
oma	doc_534729444713_item	3627160	et	4	main
faktidele	doc_534729444713_item	3627145	et	3	main
üldistav	doc_534729444713_item	3627139	et	4	main
arutlev	doc_534729444713_item	3627136	et	4	main
350	doc_534729444713_item	3627131	et	2	main
pikkus	doc_534729444713_item	3627129	et	4	main
essee	doc_534729444713_item	3627128	et	4	main
essee	doc_534729444713_item	3627122	et	4	main
keele	doc_534729444713_item	3627118	et	4	main
teise	doc_534729444713_item	3627117	et	4	main
kui	doc_534729444713_item	3627116	et	3	main
näide	doc_534729444713_item	3627373	et	3	main
suurem	doc_534729444713_item	3627372	et	4	main
osaleb	doc_534729444713_item	3627360	et	3	main
kus	doc_534729444714_item	3627549	et	3	main
toimub	doc_534729444714_item	3627544	et	3	main
osajated	doc_534729444714_item	3627534	et	4	main
inimesi	doc_534729444714_item	3627530	et	4	main
osales	doc_534729444714_item	3627527	et	3	main
laulmine	doc_534729444714_item	3627509	et	4	main
iseloomustada	doc_534729444714_item	3627504	et	4	main
keele	doc_534729444714_item	3627503	et	4	main
arenema	doc_534729444714_item	3627502	et	3	main
lubas	doc_534729444714_item	3627501	et	3	main
laulmine	doc_534729444714_item	3627500	et	4	main
aitas	doc_534729444714_item	3627499	et	3	main
tööisel	doc_534729444714_item	3627498	et	4	main
tööd	doc_534729444714_item	3627492	et	4	main
lihtendati	doc_534729444714_item	3627490	et	4	main
tahtnud	doc_534729444714_item	3627487	et	4	main
ei	doc_534729444714_item	3627486	et	4	main
nad	doc_534729444714_item	3627485	et	3	main
kui	doc_534729444714_item	3627484	et	3	main
laulud	doc_534729444714_item	3627475	et	3	main
poole	doc_534729444714_item	3627460	et	4	main
ajaloos	doc_534729444714_item	3627457	et	4	main
igapäevane	doc_534729444714_item	3627448	et	4	main
teisedes	doc_534729444714_item	3627439	et	3	main
essee	doc_534729444714_item	3627391	et	4	main
emad	doc_534729444713_item	3627305	et	3	main
ka	doc_534729444713_item	3627303	et	3	main
vanasti	doc_534729444713_item	3627301	et	3	main
vaataja	doc_534729444713_item	3627288	et	4	main
palju	doc_534729444713_item	3627280	et	4	main
väga	doc_534729444713_item	3627279	et	3	main
peaks	doc_534729444713_item	3627263	et	4	main
üle	doc_534729444713_item	3627262	et	3	main
oma	doc_534729444713_item	3627252	et	4	main
ikka	doc_534729444713_item	3627250	et	4	main
nad	doc_534729444713_item	3627249	et	3	main
venemaa	doc_534729444713_item	3627248	et	4	main
et	doc_534729444713_item	3627238	et	3	main
sellele	doc_534729444713_item	3627237	et	4	main
tavaliselt	doc_534729444713_item	3627227	et	4	main
laulukultuurist	doc_534729444713_item	3627226	et	3	main
võtsid	doc_534729444713_item	3627224	et	4	main
põlvele	doc_534729444713_item	3627215	et	4	main
sõbrannadega	doc_534729444713_item	3627209	et	3	main
folkloor	doc_534729444713_item	3627161	et	4	main
ning	doc_534729444713_item	3627159	et	3	main
kultuur	doc_534729444713_item	3627158	et	3	main
oma	doc_534729444713_item	3627157	et	4	main
ajalugu	doc_534729444713_item	3627156	et	4	main
oma	doc_534729444713_item	3627155	et	4	main
olemas	doc_534729444713_item	3627154	et	4	main
on	doc_534729444713_item	3627153	et	4	main
rahvusel	doc_534729444713_item	3627152	et	3	main
igal	doc_534729444713_item	3627151	et	3	main
näidetega	doc_534729444713_item	3627150	et	3	main
illustreerida	doc_534729444713_item	3627149	et	3	main
soovitatav	doc_534729444713_item	3627148	et	4	main
on	doc_534729444713_item	3627147	et	4	main
väiteid	doc_534729444713_item	3627146	et	4	main
ja	doc_534729444713_item	3627142	et	3	main
vanasti	doc_534729444713_item	3627259	et	3	main
ta	doc_534729444713_item	3627256	et	4	main
ja	doc_534729444713_item	3627247	et	3	main
vaatamata	doc_534729444713_item	3627236	et	4	main
et	doc_534729444713_item	3627235	et	3	main
olid	doc_534729444713_item	3627229	et	4	main
osa	doc_534729444713_item	3627225	et	4	main
mehed	doc_534729444713_item	3627223	et	3	main
ka	doc_534729444713_item	3627222	et	3	main
laule	doc_534729444713_item	3627221	et	4	main
põlvest	doc_534729444713_item	3627214	et	4	main
aastale	doc_534729444713_item	3627213	et	3	main
tööd	doc_534729444713_item	3627205	et	4	main
tegid	doc_534729444713_item	3627204	et	4	main
nad	doc_534729444713_item	3627203	et	3	main
kui	doc_534729444713_item	3627202	et	3	main
siis	doc_534729444713_item	3627201	et	3	main
toimus	doc_534729444713_item	3627200	et	3	main
see	doc_534729444713_item	3627199	et	3	main
naised	doc_534729444713_item	3627198	et	3	main
nimetati	doc_534729444713_item	3627193	et	4	main
laulud	doc_534729444713_item	3627191	et	3	main
omad	doc_534729444713_item	3627190	et	4	main
olnud	doc_534729444713_item	3627189	et	4	main
on	doc_534729444713_item	3627188	et	4	main
eestlastel	doc_534729444713_item	3627187	et	4	main
ajast	doc_534729444713_item	3627186	et	4	main
vanast	doc_534729444713_item	3627185	et	3	main
juba	doc_534729444713_item	3627184	et	3	main
et	doc_534729444713_item	3627183	et	3	main
öelda	doc_534729444713_item	3627182	et	4	main
tahaks	doc_534729444713_item	3627181	et	3	main
esiteks	doc_534729444713_item	3627180	et	3	main
laulurahva	doc_534729444713_item	3627179	et	3	main
neist	doc_534729444713_item	3627178	et	4	main
teeb	doc_534729444713_item	3627177	et	3	main
mis	doc_534729444713_item	3627176	et	4	main
aga	doc_534729444713_item	3627175	et	3	main
laulurahvaks	doc_534729444713_item	3627174	et	3	main
nimetatakse	doc_534729444713_item	3627173	et	3	main
tihti	doc_534729444713_item	3627172	et	3	main
väga	doc_534729444713_item	3627171	et	3	main
eestlasi	doc_534729444713_item	3627170	et	3	main
just	doc_534729444713_item	3627169	et	3	main
kuid	doc_534729444713_item	3627168	et	4	main
muusikast	doc_534729444713_item	3627167	et	4	main
ja	doc_534729444713_item	3627166	et	3	main
laulust	doc_534729444713_item	3627165	et	4	main
tantsust	doc_534729444713_item	3627164	et	3	main
koosneb	doc_534729444713_item	3627163	et	3	main
loengus	doc_534729444713_item	3627141	et	3	main
analüüsiv	doc_534729444713_item	3627137	et	4	main
olema	doc_534729444713_item	3627135	et	4	main
peab	doc_534729444713_item	3627134	et	4	main
laulurahva	doc_534729444713_item	3627127	et	3	main
eestlastest	doc_534729444713_item	3627126	et	4	main
teeb	doc_534729444713_item	3627125	et	3	main
kirjutage	doc_534729444713_item	3627121	et	3	main
test	doc_534729444713_item	3627119	et	3	main
essee	doc_534729444713_item	3627113	et	4	main
eestlastest	doc_534729444713_item	3627376	et	4	main
teeb	doc_534729444713_item	3627375	et	3	main
mis	doc_534729444713_item	3627374	et	4	main
seda	doc_534729444713_item	3627367	et	3	main
kogurahvuslik	doc_534729444714_item	3627547	et	3	main
määleta	doc_534729444714_item	3627541	et	4	main
ei	doc_534729444714_item	3627540	et	4	main
ma	doc_534729444714_item	3627539	et	3	main
siis	doc_534729444714_item	3627531	et	3	main
tuhande	doc_534729444714_item	3627529	et	3	main
võimalus	doc_534729444714_item	3627511	et	3	main
antis	doc_534729444714_item	3627510	et	4	main
ajaloos	doc_534729444714_item	3627508	et	4	main
põhjus	doc_534729444714_item	3627494	et	4	main
tähtsus	doc_534729444714_item	3627468	et	4	main
väga	doc_534729444714_item	3627467	et	3	main
oli	doc_534729444714_item	3627466	et	3	main
aga	doc_534729444714_item	3627463	et	3	main
oluline	doc_534729444714_item	3627461	et	4	main
vanalajal	doc_534729444714_item	3627450	et	4	main
ja	doc_534729444714_item	3627442	et	3	main
eestlastest	doc_534729444714_item	3627431	et	4	main
minu	doc_534729444714_item	3627429	et	3	main
ja	doc_534729444715_item	3627840	et	3	main
eestlased	doc_534729444715_item	3627827	et	3	main
pillisaatega	doc_534729444715_item	3627820	et	3	main
tulnud	doc_534729444715_item	3627814	et	4	main
põlve	doc_534729444715_item	3627811	et	4	main
põlvest	doc_534729444715_item	3627810	et	4	main
eeslaulja	doc_534729444715_item	3627789	et	4	main
rahvalaulu	doc_534729444715_item	3627784	et	4	main
käsitöö	doc_534729444715_item	3627713	et	4	main
või	doc_534729444715_item	3627712	et	4	main
lastele	doc_534729444715_item	3627704	et	4	main
enamasti	doc_534729444715_item	3627699	et	4	main
laulsid	doc_534729444715_item	3627698	et	4	main
emad	doc_534729444715_item	3627697	et	3	main
pidutsedes	doc_534729444715_item	3627696	et	3	main
ka	doc_534729444715_item	3627695	et	3	main
kui	doc_534729444715_item	3627694	et	3	main
ja	doc_534729444713_item	3627138	et	3	main
mis	doc_534729444713_item	3627124	et	4	main
eesti	doc_534729444713_item	3627114	et	4	main
aga	doc_534729444713_item	3627368	et	3	main
ka	doc_534729444713_item	3627365	et	3	main
lauluvõistlusel	doc_534729444713_item	3627361	et	3	main
kaksadatuhad	doc_534729444714_item	3627538	et	4	main
1994	doc_534729444714_item	3627532	et	2	main
mooderni	doc_534729444714_item	3627507	et	4	main
põlludes	doc_534729444714_item	3627493	et	4	main
rasket	doc_534729444714_item	3627491	et	3	main
lauludega	doc_534729444714_item	3627489	et	3	main
oskused	doc_534729444714_item	3627474	et	3	main
veel	doc_534729444714_item	3627472	et	4	main
poolnud	doc_534729444714_item	3627471	et	4	main
kui	doc_534729444714_item	3627470	et	3	main
vanalajal	doc_534729444714_item	3627469	et	4	main
osa	doc_534729444714_item	3627452	et	4	main
see	doc_534729444714_item	3627451	et	3	main
rahvades	doc_534729444714_item	3627440	et	4	main
nagu	doc_534729444714_item	3627437	et	3	main
rahva	doc_534729444714_item	3627435	et	3	main
laularahva	doc_534729444714_item	3627433	et	4	main
meelest	doc_534729444714_item	3627430	et	4	main
näidetega	doc_534729444714_item	3627428	et	3	main
kultuuri	doc_534729444715_item	3627832	et	4	main
juba	doc_534729444715_item	3627819	et	3	main
on	doc_534729444715_item	3627817	et	4	main
hiljem	doc_534729444715_item	3627813	et	3	main
üksi	doc_534729444715_item	3627798	et	4	main
esitavad	doc_534729444715_item	3627788	et	4	main
tehes	doc_534729444715_item	3627714	et	3	main
said	doc_534729444715_item	3627711	et	4	main
omavahel	doc_534729444715_item	3627710	et	3	main
kui	doc_534729444715_item	3627709	et	3	main
oma	doc_534729444715_item	3627703	et	4	main
muinasjutte	doc_534729444715_item	3627702	et	3	main
tehes	doc_534729444715_item	3627693	et	3	main
lauldi	doc_534729444715_item	3627689	et	3	main
huvi	doc_534729444715_item	3627683	et	4	main
tundsid	doc_534729444715_item	3627682	et	4	main
lapsed	doc_534729444715_item	3627681	et	3	main
vanemad	doc_534729444715_item	3627674	et	4	main
huvitatud	doc_534729444715_item	3627664	et	4	main
olid	doc_534729444715_item	3627663	et	4	main
pereliikmed	doc_534729444715_item	3627662	et	3	main
pere	doc_534729444715_item	3627661	et	4	main
aga	doc_534729444715_item	3627650	et	3	main
ja	doc_534729444715_item	3627644	et	3	main
jooksul	doc_534729444715_item	3627641	et	4	main
praegu	doc_534729444715_item	3627616	et	3	main
olnud	doc_534729444715_item	3627615	et	4	main
laulurahvast	doc_534729444714_item	3627563	et	4	main
nendest	doc_534729444714_item	3627562	et	4	main
teeb	doc_534729444714_item	3627561	et	3	main
rahvusmuusikale	doc_534729444714_item	3627560	et	4	main
muusikale	doc_534729444714_item	3627559	et	4	main
arm	doc_534729444714_item	3627558	et	3	main
eestlaste	doc_534729444714_item	3627557	et	4	main
pidu	doc_534729444714_item	3627556	et	4	main
rahvuslik	doc_534729444714_item	3627555	et	3	main
on	doc_534729444714_item	3627554	et	4	main
see	doc_534729444714_item	3627553	et	3	main
inimesed	doc_534729444714_item	3627552	et	3	main
tuhanded	doc_534729444714_item	3627551	et	3	main
osalevad	doc_534729444714_item	3627550	et	4	main
laulupidu	doc_534729444714_item	3627548	et	4	main
regulaarne	doc_534729444714_item	3627546	et	3	main
umbes	doc_534729444714_item	3627537	et	4	main
juba	doc_534729444714_item	3627536	et	3	main
oli	doc_534729444714_item	3627535	et	3	main
esimesel	doc_534729444714_item	3627525	et	3	main
kui	doc_534729444714_item	3627524	et	3	main
et	doc_534729444714_item	3627523	et	3	main
fakt	doc_534729444714_item	3627522	et	3	main
see	doc_534729444714_item	3627521	et	3	main
naitab	doc_534729444714_item	3627520	et	4	main
hästi	doc_534729444714_item	3627519	et	3	main
laulupeol	doc_534729444714_item	3627526	et	4	main
seda	doc_534729444714_item	3627518	et	3	main
rahvus	doc_534729444714_item	3627517	et	3	main
ühindas	doc_534729444714_item	3627516	et	4	main
muusika	doc_534729444714_item	3627515	et	4	main
mõõted	doc_534729444714_item	3627514	et	3	main
oma	doc_534729444714_item	3627513	et	4	main
rääkida	doc_534729444714_item	3627512	et	3	main
erinevus	doc_534729444714_item	3627506	et	4	main
laulmine	doc_534729444714_item	3627497	et	4	main
üks	doc_534729444714_item	3627496	et	3	main
lapsi	doc_534729444714_item	3627483	et	4	main
rahuldati	doc_534729444714_item	3627482	et	3	main
lauludega	doc_534729444714_item	3627481	et	3	main
allikat	doc_534729444714_item	3627480	et	3	main
urimise	doc_534729444714_item	3627479	et	4	main
ajaloo	doc_534729444714_item	3627478	et	4	main
mineviku	doc_534729444714_item	3627477	et	3	main
kirjutamise	doc_534729444714_item	3627473	et	4	main
ta	doc_534729444714_item	3627465	et	4	main
millal	doc_534729444714_item	3627462	et	3	main
eelus	doc_534729444714_item	3627449	et	4	main
laulud	doc_534729444714_item	3627441	et	3	main
palju	doc_534729444714_item	3627438	et	4	main
minevik	doc_534729444714_item	3627436	et	3	main
nende	doc_534729444714_item	3627434	et	4	main
teeb	doc_534729444714_item	3627432	et	3	main
illustreerida	doc_534729444714_item	3627427	et	3	main
käitakse	doc_534729444715_item	3627844	et	4	main
kuhu	doc_534729444715_item	3627843	et	3	main
üritused	doc_534729444715_item	3627842	et	4	main
ja	doc_534729444715_item	3627821	et	3	main
pärandati	doc_534729444715_item	3627809	et	4	main
ning	doc_534729444715_item	3627808	et	3	main
pillisaateta	doc_534729444715_item	3627807	et	3	main
lauldi	doc_534729444715_item	3627797	et	3	main
regilauluks	doc_534729444715_item	3627786	et	4	main
vanemat	doc_534729444715_item	3627783	et	4	main
laulsid	doc_534729444715_item	3627706	et	4	main
lastelaulu	doc_534729444715_item	3627700	et	4	main
tööd	doc_534729444715_item	3627692	et	4	main
ja	doc_534729444715_item	3627686	et	3	main
muud	doc_534729444715_item	3627673	et	4	main
või	doc_534729444715_item	3627671	et	4	main
pilli	doc_534729444715_item	3627670	et	4	main
klaverit	doc_534729444715_item	3627669	et	3	main
ära	doc_534729444715_item	3627649	et	4	main
esteetiline	doc_534729444715_item	3627643	et	3	main
sajande	doc_534729444715_item	3627640	et	4	main
et	doc_534729444715_item	3627638	et	3	main
uhke	doc_534729444715_item	3627637	et	4	main
peab	doc_534729444715_item	3627635	et	4	main
eestimaa	doc_534729444715_item	3627634	et	4	main
nagu	doc_534729444715_item	3627633	et	3	main
riik	doc_534729444715_item	3627632	et	3	main
on	doc_534729444715_item	3627626	et	4	main
laulmine	doc_534729444715_item	3627625	et	4	main
ajaks	doc_534729444715_item	3627624	et	4	main
veel	doc_534729444715_item	3627622	et	4	main
nii	doc_534729444715_item	3627614	et	3	main
tõesti	doc_534729444715_item	3627613	et	3	main
on	doc_534729444715_item	3627612	et	4	main
see	doc_534729444715_item	3627611	et	3	main
ja	doc_534729444715_item	3627610	et	3	main
kellegile	doc_534729444715_item	3627603	et	4	main
üldistav	doc_534729444715_item	3627591	et	4	main
ja	doc_534729444715_item	3627590	et	3	main
essee	doc_534729444715_item	3627585	et	4	main
essee	doc_534729444715_item	3627580	et	4	main
teeb	doc_534729444715_item	3627577	et	3	main
mis	doc_534729444715_item	3627576	et	4	main
kandus	doc_534729444715_item	3627779	et	3	main
pani	doc_534729444715_item	3627764	et	4	main
sündmus	doc_534729444715_item	3627763	et	3	main
sest	doc_534729444715_item	3627753	et	4	main
tähtsus	doc_534729444715_item	3627749	et	4	main
laulupeo	doc_534729444715_item	3627748	et	4	main
ja	doc_534729444715_item	3627736	et	3	main
ei	doc_534729444715_item	3627731	et	4	main
sellega	doc_534729444718_item	3628141	et	3	main
midagi	doc_534729444718_item	3628140	et	4	main
mitte	doc_534729444718_item	3628139	et	3	main
laulata	doc_534729444718_item	3628128	et	4	main
täiesti	doc_534729444718_item	3628125	et	3	main
aeg	doc_534729444718_item	3628102	et	3	main
aastad	doc_534729444718_item	3628101	et	3	main
ajaloole	doc_534729444718_item	3628090	et	4	main
selle	doc_534729444718_item	3628089	et	4	main
jooksul	doc_534729444718_item	3628081	et	4	main
suur	doc_534729444718_item	3628075	et	3	main
teisega	doc_534729444714_item	3627459	et	4	main
juba	doc_534729444714_item	3627458	et	3	main
mooderni	doc_534729444714_item	3627456	et	4	main
mõõtega	doc_534729444714_item	3627455	et	3	main
ühe	doc_534729444714_item	3627454	et	4	main
oli	doc_534729444714_item	3627453	et	3	main
osa	doc_534729444714_item	3627447	et	4	main
suur	doc_534729444714_item	3627446	et	3	main
võttis	doc_534729444714_item	3627445	et	3	main
üldse	doc_534729444714_item	3627444	et	3	main
muusika	doc_534729444714_item	3627443	et	4	main
soovitatav	doc_534729444714_item	3627426	et	4	main
on	doc_534729444714_item	3627425	et	4	main
väiteid	doc_534729444714_item	3627424	et	4	main
faktidele	doc_534729444714_item	3627423	et	3	main
esitatud	doc_534729444714_item	3627422	et	4	main
lugemistekstis	doc_534729444714_item	3627421	et	3	main
ja	doc_534729444714_item	3627420	et	3	main
loengus	doc_534729444714_item	3627419	et	3	main
tuginema	doc_534729444714_item	3627418	et	3	main
üldistav	doc_534729444714_item	3627417	et	4	main
ja	doc_534729444714_item	3627416	et	3	main
analüüsiv	doc_534729444714_item	3627415	et	4	main
arutlev	doc_534729444714_item	3627414	et	4	main
olema	doc_534729444714_item	3627413	et	4	main
peab	doc_534729444714_item	3627412	et	4	main
essee	doc_534729444714_item	3627411	et	4	main
sõna	doc_534729444714_item	3627410	et	4	main
350	doc_534729444714_item	3627409	et	2	main
300	doc_534729444714_item	3627408	et	2	main
pikkus	doc_534729444714_item	3627407	et	4	main
essee	doc_534729444714_item	3627406	et	4	main
laulurahva	doc_534729444714_item	3627405	et	3	main
eestlastest	doc_534729444714_item	3627404	et	4	main
teeb	doc_534729444714_item	3627403	et	3	main
mis	doc_534729444714_item	3627402	et	4	main
teemal	doc_534729444714_item	3627401	et	3	main
essee	doc_534729444714_item	3627400	et	4	main
kirjutage	doc_534729444714_item	3627399	et	3	main
kirjutamine	doc_534729444714_item	3627398	et	4	main
test	doc_534729444714_item	3627397	et	3	main
keele	doc_534729444714_item	3627396	et	4	main
teise	doc_534729444714_item	3627395	et	4	main
kui	doc_534729444714_item	3627394	et	3	main
keele	doc_534729444714_item	3627393	et	4	main
eesti	doc_534729444714_item	3627392	et	4	main
massilisemad	doc_534729444715_item	3627841	et	4	main
tähelepanuväärsemad	doc_534729444715_item	3627839	et	4	main
kõige	doc_534729444715_item	3627838	et	4	main
oma	doc_534729444715_item	3627831	et	4	main
salmikuid	doc_534729444715_item	3627826	et	4	main
esitatud	doc_534729444715_item	3627818	et	4	main
rahvalaulud	doc_534729444715_item	3627816	et	3	main
lauldi	doc_534729444715_item	3627805	et	3	main
vaheldumisi	doc_534729444715_item	3627796	et	4	main
järgi	doc_534729444715_item	3627795	et	4	main
kordab	doc_534729444715_item	3627794	et	3	main
nimetatakse	doc_534729444715_item	3627785	et	3	main
põhiliselt	doc_534729444715_item	3627705	et	4	main
nii	doc_534729444715_item	3627691	et	3	main
vastu	doc_534729444715_item	3627685	et	3	main
muusika	doc_534729444715_item	3627684	et	4	main
tegid	doc_534729444715_item	3627675	et	4	main
midagi	doc_534729444715_item	3627672	et	4	main
eesti	doc_534729444715_item	3627660	et	4	main
ja	doc_534729444715_item	3627652	et	3	main
elab	doc_534729444715_item	3627651	et	3	main
see	doc_534729444715_item	3627642	et	3	main
paljude	doc_534729444715_item	3627639	et	3	main
kultuurinähtus	doc_534729444715_item	3627628	et	4	main
minu	doc_534729444715_item	3627619	et	3	main
on	doc_534729444715_item	3627608	et	4	main
eestlased	doc_534729444715_item	3627607	et	3	main
et	doc_534729444715_item	3627606	et	3	main
saladus	doc_534729444715_item	3627605	et	3	main
sõna	doc_534729444715_item	3627584	et	4	main
300	doc_534729444715_item	3627582	et	2	main
eestlastest	doc_534729444715_item	3627578	et	4	main
essee	doc_534729444715_item	3627574	et	4	main
kirjutage	doc_534729444715_item	3627573	et	3	main
kirjutamine	doc_534729444715_item	3627572	et	4	main
test	doc_534729444715_item	3627571	et	3	main
essee	doc_534729444715_item	3627565	et	4	main
eestlaste	doc_534729444715_item	3627745	et	4	main
ürituses	doc_534729444715_item	3627735	et	4	main
osa	doc_534729444715_item	3627733	et	4	main
peol	doc_534729444718_item	3628129	et	4	main
õnnelikkutena	doc_534729444718_item	3628126	et	4	main
olla	doc_534729444718_item	3628124	et	3	main
ei	doc_534729444718_item	3628122	et	4	main
mehed	doc_534729444718_item	3628121	et	3	main
muusikat	doc_534729444718_item	3628120	et	3	main
möödasid	doc_534729444718_item	3628100	et	4	main
pidudest	doc_534729444718_item	3628099	et	4	main
võttavad	doc_534729444718_item	3628095	et	4	main
ja	doc_534729444718_item	3628094	et	3	main
on	doc_534729444718_item	3628086	et	4	main
laula	doc_534729444718_item	3628046	et	4	main
praegus	doc_534729444718_item	3628041	et	4	main
stiile	doc_534729444718_item	3628040	et	3	main
jaoks	doc_534729444718_item	3628034	et	4	main
juhtude	doc_534729444718_item	3628033	et	4	main
kasutasid	doc_534729444718_item	3628030	et	4	main
sellele	doc_534729444718_item	3628027	et	4	main
unustanud	doc_534729444718_item	3628017	et	4	main
aja	doc_534729444718_item	3628013	et	4	main
ka	doc_534729444718_item	3628011	et	3	main
tulid	doc_534729444718_item	3628001	et	4	main
peole	doc_534729444718_item	3628000	et	4	main
et	doc_534729444718_item	3627999	et	3	main
hästi	doc_534729444718_item	3627987	et	3	main
võiks	doc_534729444718_item	3627986	et	4	main
et	doc_534729444718_item	3627984	et	3	main
hoolisid	doc_534729444718_item	3627983	et	4	main
nälja	doc_534729444718_item	3627972	et	3	main
ilma	doc_534729444718_item	3627971	et	4	main
on	doc_534729444718_item	3627969	et	4	main
väikestele	doc_534729444718_item	3627968	et	4	main
aga	doc_534729444718_item	3627967	et	3	main
igav	doc_534729444718_item	3627966	et	3	main
väga	doc_534729444718_item	3627965	et	3	main
jaoks	doc_534729444718_item	3627961	et	4	main
koduloomade	doc_534729444718_item	3627958	et	4	main
sellele	doc_534729444718_item	3627903	et	4	main
eestlastest	doc_534729444718_item	3627899	et	4	main
teeb	doc_534729444718_item	3627898	et	3	main
pidu	doc_534729444715_item	3627857	et	4	main
suurepärast	doc_534729444715_item	3627856	et	4	main
seda	doc_534729444715_item	3627855	et	3	main
nautida	doc_534729444715_item	3627854	et	3	main
et	doc_534729444715_item	3627853	et	3	main
selleks	doc_534729444715_item	3627852	et	4	main
spetsiaalselt	doc_534729444715_item	3627851	et	4	main
eestimaal	doc_534729444715_item	3627850	et	4	main
suvel	doc_534729444715_item	3627849	et	3	main
tulevad	doc_534729444715_item	3627848	et	4	main
paljud	doc_534729444715_item	3627847	et	3	main
perega	doc_534729444715_item	3627846	et	3	main
kogu	doc_534729444715_item	3627845	et	4	main
on	doc_534729444715_item	3627837	et	4	main
laulupeod	doc_534729444715_item	3627836	et	4	main
tänapäeval	doc_534729444715_item	3627835	et	3	main
ka	doc_534729444715_item	3627834	et	3	main
ja	doc_534729444715_item	3627833	et	3	main
unusta	doc_534729444715_item	3627830	et	4	main
ei	doc_534729444715_item	3627829	et	4	main
kunagi	doc_534729444715_item	3627828	et	3	main
ja	doc_534729444715_item	3627825	et	3	main
laulikuid	doc_534729444715_item	3627824	et	3	main
kirjutama	doc_534729444715_item	3627823	et	3	main
hakkati	doc_534729444715_item	3627822	et	3	main
riimilised	doc_534729444715_item	3627815	et	4	main
suuliselt	doc_534729444715_item	3627812	et	4	main
ilma	doc_534729444715_item	3627806	et	4	main
regilaule	doc_534729444715_item	3627804	et	4	main
kooriga	doc_534729444715_item	3627803	et	4	main
kahe	doc_534729444715_item	3627802	et	3	main
ka	doc_534729444715_item	3627801	et	3	main
mõnikord	doc_534729444715_item	3627800	et	3	main
kahekesi	doc_534729444715_item	3627799	et	3	main
koor	doc_534729444715_item	3627793	et	4	main
ja	doc_534729444715_item	3627792	et	3	main
ees	doc_534729444715_item	3627791	et	4	main
ütleb	doc_534729444715_item	3627790	et	3	main
regilaulu	doc_534729444715_item	3627787	et	4	main
näiteks	doc_534729444715_item	3627708	et	4	main
naised	doc_534729444715_item	3627707	et	3	main
juttustasid	doc_534729444715_item	3627701	et	4	main
koguaeg	doc_534729444715_item	3627690	et	3	main
tantsuga	doc_534729444715_item	3627688	et	3	main
tegeleksid	doc_534729444715_item	3627687	et	4	main
selleks	doc_534729444715_item	3627678	et	4	main
võimaliku	doc_534729444715_item	3627677	et	3	main
kõike	doc_534729444715_item	3627676	et	4	main
kõik	doc_534729444715_item	3627659	et	4	main
kao	doc_534729444715_item	3627648	et	4	main
ei	doc_534729444715_item	3627647	et	4	main
väljendusvahed	doc_534729444715_item	3627646	et	3	main
olema	doc_534729444715_item	3627636	et	4	main
ja	doc_534729444715_item	3627629	et	3	main
tähelepanuväärne	doc_534729444715_item	3627627	et	3	main
laulurahvas	doc_534729444715_item	3627609	et	4	main
näidetega	doc_534729444715_item	3627602	et	3	main
soovitatav	doc_534729444715_item	3627600	et	4	main
arutlev	doc_534729444715_item	3627588	et	4	main
laulurahva	doc_534729444715_item	3627579	et	3	main
teemal	doc_534729444715_item	3627575	et	3	main
keele	doc_534729444715_item	3627567	et	4	main
eesti	doc_534729444715_item	3627566	et	4	main
traditsioon	doc_534729444715_item	3627778	et	3	main
eestlaste	doc_534729444715_item	3627757	et	4	main
kujunes	doc_534729444715_item	3627756	et	3	main
sellest	doc_534729444715_item	3627755	et	4	main
just	doc_534729444715_item	3627754	et	3	main
on	doc_534729444715_item	3627750	et	4	main
esimese	doc_534729444715_item	3627747	et	3	main
jaoks	doc_534729444715_item	3627746	et	4	main
naist	doc_534729444715_item	3627730	et	3	main
meeskoorid	doc_534729444715_item	3627728	et	4	main
ainult	doc_534729444715_item	3627727	et	4	main
laulupidu	doc_534729444715_item	3627722	et	4	main
nende	doc_534729444715_item	3627680	et	4	main
et	doc_534729444715_item	3627679	et	3	main
mängisid	doc_534729444715_item	3627668	et	4	main
paljud	doc_534729444715_item	3627667	et	3	main
muusikas	doc_534729444715_item	3627666	et	3	main
laulus	doc_534729444715_item	3627665	et	3	main
peaaegu	doc_534729444715_item	3627658	et	3	main
vanasti	doc_534729444715_item	3627657	et	3	main
südametes	doc_534729444715_item	3627656	et	4	main
eestlaste	doc_534729444715_item	3627655	et	4	main
paljude	doc_534729444715_item	3627654	et	3	main
õitseb	doc_534729444715_item	3627653	et	4	main
emotsionaalne	doc_534729444715_item	3627645	et	3	main
väike	doc_534729444715_item	3627631	et	4	main
niisugune	doc_534729444715_item	3627630	et	3	main
kauaks	doc_534729444715_item	3627623	et	3	main
jääbki	doc_534729444715_item	3627621	et	3	main
arvates	doc_534729444715_item	3627620	et	4	main
ja	doc_534729444715_item	3627618	et	3	main
on	doc_534729444715_item	3627617	et	4	main
pole	doc_534729444715_item	3627604	et	3	main
illustreerida	doc_534729444715_item	3627601	et	3	main
on	doc_534729444715_item	3627599	et	4	main
väiteid	doc_534729444715_item	3627598	et	4	main
faktidele	doc_534729444715_item	3627597	et	3	main
esitatud	doc_534729444715_item	3627596	et	4	main
lugemistekstis	doc_534729444715_item	3627595	et	3	main
ja	doc_534729444715_item	3627594	et	3	main
loengus	doc_534729444715_item	3627593	et	3	main
tuginema	doc_534729444715_item	3627592	et	3	main
350	doc_534729444715_item	3627583	et	2	main
keele	doc_534729444715_item	3627570	et	4	main
teise	doc_534729444715_item	3627569	et	4	main
kui	doc_534729444715_item	3627568	et	3	main
tallinnase	doc_534729444715_item	3627780	et	3	main
see	doc_534729444715_item	3627762	et	3	main
ja	doc_534729444715_item	3627761	et	3	main
kõrghetk	doc_534729444715_item	3627760	et	3	main
liikumise	doc_534729444715_item	3627759	et	4	main
rahvusliku	doc_534729444715_item	3627758	et	3	main
suur	doc_534729444715_item	3627752	et	3	main
kõikide	doc_534729444715_item	3627744	et	4	main
naiskoorid	doc_534729444715_item	3627743	et	3	main
ka	doc_534729444715_item	3627742	et	3	main
osavõtjatena	doc_534729444715_item	3627741	et	3	main
lisandusid	doc_534729444715_item	3627740	et	4	main
aastal	doc_534729444715_item	3627739	et	3	main
1933	doc_534729444715_item	3627738	et	2	main
alles	doc_534729444715_item	3627737	et	3	main
selles	doc_534729444715_item	3627734	et	4	main
peol	doc_534729444715_item	3627725	et	4	main
ja	doc_534729444715_item	3627724	et	3	main
tartus	doc_534729444715_item	3627723	et	3	main
ülemaaline	doc_534729444715_item	3627721	et	4	main
esimene	doc_534729444715_item	3627720	et	3	main
korraldatud	doc_534729444715_item	3627719	et	4	main
oli	doc_534729444715_item	3627718	et	3	main
aastal	doc_534729444715_item	3627717	et	3	main
ilma	doc_534729444718_item	3628127	et	4	main
oma	doc_534729444718_item	3628116	et	4	main
laulavad	doc_534729444718_item	3628115	et	4	main
emad	doc_534729444718_item	3628114	et	3	main
okupatsioonidele	doc_534729444718_item	3628113	et	3	main
ise	doc_534729444718_item	3628096	et	4	main
kuuluvad	doc_534729444718_item	3628092	et	4	main
noored	doc_534729444718_item	3628091	et	3	main
kuu	doc_534729444718_item	3628080	et	4	main
iga	doc_534729444718_item	3628079	et	4	main
kultuuris	doc_534729444718_item	3628078	et	3	main
on	doc_534729444718_item	3628069	et	4	main
tänapäeval	doc_534729444718_item	3628052	et	3	main
põllumajandus	doc_534729444718_item	3628051	et	3	main
töö	doc_534729444718_item	3628050	et	4	main
sellele	doc_534729444718_item	3628048	et	4	main
vaatamata	doc_534729444718_item	3628047	et	4	main
palju	doc_534729444718_item	3628037	et	4	main
levinud	doc_534729444718_item	3628036	et	4	main
oli	doc_534729444718_item	3628035	et	3	main
laula	doc_534729444718_item	3628031	et	4	main
eestlased	doc_534729444718_item	3628029	et	3	main
et	doc_534729444718_item	3628028	et	3	main
jooksul	doc_534729444718_item	3628014	et	4	main
ja	doc_534729444718_item	3628009	et	3	main
laulude	doc_534729444718_item	3628008	et	3	main
pidu	doc_534729444718_item	3628006	et	4	main
iga	doc_534729444718_item	3628005	et	4	main
toimus	doc_534729444718_item	3628004	et	3	main
traditsiooniks	doc_534729444718_item	3627998	et	3	main
oli	doc_534729444718_item	3627997	et	3	main
pulmadel	doc_534729444718_item	3627996	et	3	main
tegid	doc_534729444718_item	3627977	et	4	main
tihti	doc_534729444718_item	3627976	et	3	main
selline	doc_534729444718_item	3627963	et	4	main
analüüsiv	doc_534729444715_item	3627589	et	4	main
olema	doc_534729444715_item	3627587	et	4	main
peab	doc_534729444715_item	3627586	et	4	main
pikkus	doc_534729444715_item	3627581	et	4	main
eesti	doc_534729444715_item	3627782	et	4	main
alates	doc_534729444715_item	3627781	et	3	main
saanud	doc_534729444715_item	3627777	et	4	main
alguse	doc_534729444715_item	3627776	et	3	main
tartust	doc_534729444715_item	3627775	et	3	main
jannsen	doc_534729444715_item	3627774	et	4	main
voldemar	doc_534729444715_item	3627773	et	4	main
johann	doc_534729444715_item	3627772	et	4	main
korraldas	doc_534729444715_item	3627771	et	3	main
laulupidu	doc_534729444715_item	3627770	et	4	main
esimese	doc_534729444715_item	3627769	et	3	main
korraldamisele	doc_534729444715_item	3627768	et	4	main
üldlaulupidude	doc_534729444715_item	3627767	et	4	main
järgnevate	doc_534729444715_item	3627766	et	4	main
aluse	doc_534729444715_item	3627765	et	4	main
väga	doc_534729444715_item	3627751	et	3	main
võttnud	doc_534729444715_item	3627732	et	4	main
ühtegi	doc_534729444715_item	3627729	et	4	main
osalesid	doc_534729444715_item	3627726	et	4	main
1869	doc_534729444715_item	3627716	et	2	main
kuid	doc_534729444715_item	3627715	et	4	main
teha	doc_534729444718_item	3628142	et	3	main
nii	doc_534729444718_item	3628130	et	3	main
saa	doc_534729444718_item	3628123	et	4	main
armastavad	doc_534729444718_item	3628119	et	4	main
noored	doc_534729444718_item	3628118	et	3	main
sõjadele	doc_534729444718_item	3628112	et	4	main
osa	doc_534729444718_item	3628097	et	4	main
muusikat	doc_534729444718_item	3628093	et	3	main
missugused	doc_534729444718_item	3628085	et	3	main
üüritused	doc_534729444718_item	3628084	et	4	main
erinevad	doc_534729444718_item	3628083	et	4	main
nende	doc_534729444718_item	3628077	et	4	main
et	doc_534729444718_item	3628049	et	3	main
ei	doc_534729444718_item	3628043	et	4	main
ajal	doc_534729444718_item	3628042	et	4	main
praktiliselt	doc_534729444718_item	3628003	et	4	main
magamise	doc_534729444718_item	3627995	et	4	main
laula	doc_534729444718_item	3627993	et	4	main
jaoks	doc_534729444718_item	3627992	et	4	main
tema	doc_534729444718_item	3627991	et	4	main
magada	doc_534729444718_item	3627988	et	3	main
laps	doc_534729444718_item	3627985	et	4	main
eest	doc_534729444718_item	3627982	et	4	main
elada	doc_534729444718_item	3627975	et	3	main
töö	doc_534729444718_item	3627964	et	4	main
töötasid	doc_534729444718_item	3627923	et	4	main
taludel	doc_534729444718_item	3627922	et	3	main
enamasti	doc_534729444718_item	3627921	et	4	main
vaatame	doc_534729444718_item	3627908	et	3	main
ajaloole	doc_534729444718_item	3627907	et	4	main
vastada	doc_534729444718_item	3627902	et	4	main
soovitatav	doc_534729444718_item	3627894	et	4	main
väiteid	doc_534729444718_item	3627892	et	4	main
faktidele	doc_534729444718_item	3627891	et	3	main
esitatud	doc_534729444718_item	3627890	et	4	main
lugemistekstis	doc_534729444718_item	3627889	et	3	main
pikkus	doc_534729444718_item	3627875	et	4	main
kirjutamine	doc_534729444718_item	3627866	et	4	main
test	doc_534729444718_item	3627865	et	3	main
tänapäeva	doc_534729444720_item	3628337	et	4	main
ja	doc_534729444720_item	3628335	et	3	main
on	doc_534729444720_item	3628325	et	4	main
tänases	doc_534729444720_item	3628318	et	3	main
muusikamaailma	doc_534729444720_item	3628314	et	4	main
isepoolest	doc_534729444720_item	3628312	et	4	main
on	doc_534729444720_item	3628311	et	4	main
inglise	doc_534729444720_item	3628308	et	4	main
on	doc_534729444720_item	3628307	et	4	main
sellele	doc_534729444720_item	3628306	et	4	main
erand	doc_534729444720_item	3628305	et	3	main
on	doc_534729444720_item	3628301	et	4	main
eesti	doc_534729444720_item	3628298	et	4	main
teised	doc_534729444720_item	3628272	et	4	main
palju	doc_534729444720_item	3628271	et	4	main
ja	doc_534729444720_item	3628270	et	3	main
keeled	doc_534729444720_item	3628269	et	3	main
täitsa	doc_534729444720_item	3628264	et	3	main
mis	doc_534729444720_item	3628262	et	4	main
kergesti	doc_534729444720_item	3628256	et	3	main
levinud	doc_534729444720_item	3628251	et	4	main
nii	doc_534729444720_item	3628250	et	3	main
kaldal	doc_534729444720_item	3628235	et	3	main
elasid	doc_534729444720_item	3628232	et	4	main
inimestest	doc_534729444720_item	3628230	et	3	main
vanasti	doc_534729444720_item	3628215	et	3	main
tööl	doc_534729444720_item	3628213	et	3	main
tähtis	doc_534729444720_item	3628199	et	4	main
sõnad	doc_534729444720_item	3628192	et	4	main
illustreerida	doc_534729444720_item	3628185	et	3	main
on	doc_534729444720_item	3628183	et	4	main
väiteid	doc_534729444720_item	3628182	et	4	main
faktidele	doc_534729444720_item	3628181	et	3	main
esitatud	doc_534729444720_item	3628180	et	4	main
lugemistekstis	doc_534729444720_item	3628179	et	3	main
olukorra	doc_534729444718_item	3628147	et	3	main
sellist	doc_534729444718_item	3628146	et	4	main
muuta	doc_534729444718_item	3628145	et	4	main
kuidagi	doc_534729444718_item	3628144	et	3	main
või	doc_534729444718_item	3628143	et	4	main
saa	doc_534729444718_item	3628138	et	4	main
ei	doc_534729444718_item	3628137	et	4	main
aeg	doc_534729444718_item	3628136	et	3	main
ja	doc_534729444718_item	3628135	et	3	main
praegu	doc_534729444718_item	3628134	et	3	main
on	doc_534729444718_item	3628133	et	4	main
nii	doc_534729444718_item	3628132	et	3	main
oli	doc_534729444718_item	3628131	et	3	main
lastele	doc_534729444718_item	3628117	et	4	main
vaatamata	doc_534729444718_item	3628111	et	4	main
folklööri	doc_534729444718_item	3628110	et	4	main
ja	doc_534729444718_item	3628109	et	3	main
oma	doc_534729444718_item	3628107	et	4	main
säilitasid	doc_534729444718_item	3628106	et	4	main
kultuuri	doc_534729444718_item	3628108	et	4	main
eestlased	doc_534729444718_item	3628105	et	3	main
aga	doc_534729444718_item	3628104	et	3	main
muutus	doc_534729444718_item	3628103	et	4	main
muusika	doc_534729444718_item	3628098	et	4	main
laulale	doc_534729444718_item	3628088	et	3	main
pühendatud	doc_534729444718_item	3628087	et	4	main
toimuvad	doc_534729444718_item	3628082	et	4	main
osa	doc_534729444718_item	3628076	et	4	main
ole	doc_534729444718_item	3628044	et	4	main
erinevaid	doc_534729444718_item	3628038	et	4	main
erinevate	doc_534729444718_item	3628032	et	4	main
on	doc_534729444718_item	3628074	et	4	main
see	doc_534729444718_item	3628073	et	3	main
ja	doc_534729444718_item	3628072	et	3	main
veres	doc_534729444718_item	3628071	et	3	main
juba	doc_534729444718_item	3628070	et	3	main
usunud	doc_534729444718_item	3628045	et	4	main
muusika	doc_534729444718_item	3628039	et	4	main
alati	doc_534729444718_item	3628022	et	4	main
oli	doc_534729444718_item	3628021	et	3	main
laulaga	doc_534729444718_item	3628020	et	4	main
kultuurist	doc_534729444718_item	3628019	et	3	main
oma	doc_534729444718_item	3628018	et	4	main
sõjade	doc_534729444718_item	3628012	et	4	main
tantsudega	doc_534729444718_item	3628010	et	3	main
laulajad	doc_534729444718_item	3628002	et	4	main
laulas	doc_534729444718_item	3627990	et	4	main
laste	doc_534729444718_item	3627981	et	4	main
naised	doc_534729444718_item	3627978	et	3	main
räägimiseta	doc_534729444718_item	3627974	et	4	main
laste	doc_534729444718_item	3627960	et	4	main
läks	doc_534729444718_item	3627931	et	3	main
et	doc_534729444718_item	3627929	et	3	main
jooksul	doc_534729444718_item	3627927	et	4	main
elasid	doc_534729444718_item	3627920	et	4	main
tööga	doc_534729444718_item	3627918	et	3	main
põllumajunduse	doc_534729444718_item	3627917	et	4	main
sajandidel	doc_534729444718_item	3627916	et	4	main
eelmistel	doc_534729444718_item	3627915	et	3	main
eestlaste	doc_534729444718_item	3627906	et	4	main
pöörame	doc_534729444718_item	3627905	et	3	main
et	doc_534729444718_item	3627901	et	3	main
laulurahva	doc_534729444718_item	3627900	et	3	main
analüüsiv	doc_534729444718_item	3627883	et	4	main
essee	doc_534729444718_item	3627874	et	4	main
laulurahva	doc_534729444718_item	3627873	et	3	main
eestlastest	doc_534729444718_item	3627872	et	4	main
teeb	doc_534729444718_item	3627871	et	3	main
mis	doc_534729444718_item	3627870	et	4	main
teemal	doc_534729444718_item	3627869	et	3	main
keele	doc_534729444718_item	3627861	et	4	main
mõjuvad	doc_534729444720_item	3628336	et	4	main
maailmas	doc_534729444720_item	3628319	et	3	main
imperialism	doc_534729444720_item	3628315	et	3	main
nn	doc_534729444720_item	3628313	et	4	main
keel	doc_534729444720_item	3628309	et	4	main
rahvalaulud	doc_534729444720_item	3628300	et	3	main
teeb	doc_534729444720_item	3628275	et	3	main
keel	doc_534729444720_item	3628274	et	4	main
näiteks	doc_534729444720_item	3628267	et	4	main
on	doc_534729444720_item	3628259	et	4	main
eesti	doc_534729444720_item	3628254	et	4	main
ja	doc_534729444720_item	3628243	et	3	main
tuginedes	doc_534729444720_item	3628241	et	3	main
põlvele	doc_534729444720_item	3628239	et	4	main
põlvest	doc_534729444720_item	3628238	et	4	main
pärandati	doc_534729444720_item	3628237	et	4	main
arvates	doc_534729444720_item	3628228	et	4	main
algas	doc_534729444720_item	3628226	et	3	main
laulutraditsioon	doc_534729444720_item	3628224	et	3	main
vana	doc_534729444720_item	3628221	et	4	main
on	doc_534729444720_item	3628220	et	4	main
näiteks	doc_534729444720_item	3628212	et	4	main
kes	doc_534729444720_item	3628211	et	4	main
osa	doc_534729444720_item	3628203	et	4	main
rütmiliselt	doc_534729444720_item	3628190	et	4	main
laul	doc_534729444720_item	3628187	et	4	main
soovitatav	doc_534729444720_item	3628184	et	4	main
essee	doc_534729444720_item	3628169	et	4	main
laulurahva	doc_534729444720_item	3628417	et	3	main
vanade	doc_534729444720_item	3628405	et	3	main
et	doc_534729444720_item	3628404	et	3	main
sellest	doc_534729444720_item	3628398	et	4	main
ta	doc_534729444720_item	3628397	et	4	main
eesti	doc_534729444720_item	3628395	et	4	main
kuid	doc_534729444720_item	3628388	et	4	main
riikides	doc_534729444720_item	3628387	et	3	main
balti	doc_534729444720_item	3628386	et	3	main
sündmus	doc_534729444720_item	3628385	et	3	main
laulupidu	doc_534729444720_item	3628373	et	4	main
katsed	doc_534729444720_item	3628367	et	3	main
pole	doc_534729444720_item	3628362	et	3	main
tänu	doc_534729444718_item	3628026	et	4	main
kõrgtasemel	doc_534729444718_item	3628025	et	3	main
moraal	doc_534729444718_item	3628024	et	3	main
sõdurite	doc_534729444718_item	3628023	et	3	main
ei	doc_534729444718_item	3628016	et	4	main
eestlased	doc_534729444718_item	3628015	et	3	main
koos	doc_534729444718_item	3628007	et	4	main
enne	doc_534729444718_item	3627994	et	4	main
ema	doc_534729444718_item	3627989	et	4	main
ja	doc_534729444718_item	3627980	et	3	main
käsitöid	doc_534729444718_item	3627979	et	3	main
ja	doc_534729444718_item	3627973	et	3	main
raske	doc_534729444718_item	3627970	et	4	main
näiteks	doc_534729444718_item	3627957	et	4	main
vaatasid	doc_534729444718_item	3627956	et	4	main
nad	doc_534729444718_item	3627955	et	3	main
lapsepõlvast	doc_534729444718_item	3627954	et	3	main
juba	doc_534729444718_item	3627953	et	3	main
vanemaid	doc_534729444718_item	3627952	et	4	main
oma	doc_534729444718_item	3627951	et	4	main
lapsed	doc_534729444718_item	3627950	et	3	main
aitasid	doc_534729444718_item	3627949	et	4	main
perekonnas	doc_534729444718_item	3627948	et	4	main
eesti	doc_534729444718_item	3627947	et	4	main
lõbusam	doc_534729444718_item	3627946	et	4	main
möödas	doc_534729444718_item	3627945	et	3	main
aeg	doc_534729444718_item	3627944	et	3	main
ja	doc_534729444718_item	3627943	et	3	main
vähem	doc_534729444718_item	3627942	et	4	main
väsitati	doc_534729444718_item	3627941	et	3	main
laulaga	doc_534729444718_item	3627940	et	4	main
laulaga	doc_534729444718_item	3627939	et	4	main
tööda	doc_534729444718_item	3627938	et	4	main
eestlased	doc_534729444718_item	3627937	et	3	main
hakkasid	doc_534729444718_item	3627936	et	4	main
lihtsam	doc_534729444718_item	3627935	et	4	main
ja	doc_534729444718_item	3627934	et	3	main
kiirem	doc_534729444718_item	3627933	et	4	main
natuke	doc_534729444718_item	3627932	et	4	main
ja	doc_534729444718_item	3627928	et	3	main
päeva	doc_534729444718_item	3627926	et	4	main
terve	doc_534729444718_item	3627925	et	4	main
põllul	doc_534729444718_item	3627924	et	3	main
inimesed	doc_534729444718_item	3627919	et	3	main
läbi	doc_534729444718_item	3627909	et	4	main
ja	doc_534729444718_item	3627888	et	3	main
loengus	doc_534729444718_item	3627887	et	3	main
tuginema	doc_534729444718_item	3627886	et	3	main
üldistav	doc_534729444718_item	3627885	et	4	main
ja	doc_534729444718_item	3627884	et	3	main
olema	doc_534729444718_item	3627881	et	4	main
peab	doc_534729444718_item	3627880	et	4	main
essee	doc_534729444718_item	3627879	et	4	main
kui	doc_534729444718_item	3627862	et	3	main
jne	doc_534729444718_item	3628063	et	4	main
muusikasse	doc_534729444720_item	3628338	et	4	main
on	doc_534729444718_item	3627962	et	4	main
järgi	doc_534729444718_item	3627959	et	4	main
töö	doc_534729444718_item	3627930	et	4	main
rahvas	doc_534729444718_item	3627914	et	4	main
tegeles	doc_534729444718_item	3627913	et	3	main
kõigepealt	doc_534729444718_item	3627912	et	3	main
eluviit	doc_534729444718_item	3627911	et	3	main
eestlaste	doc_534729444718_item	3627910	et	4	main
küsimusele	doc_534729444718_item	3627904	et	4	main
illustreerida	doc_534729444718_item	3627895	et	3	main
sõna	doc_534729444718_item	3627878	et	4	main
350	doc_534729444718_item	3627877	et	2	main
300	doc_534729444718_item	3627876	et	2	main
essee	doc_534729444718_item	3627868	et	4	main
kirjutage	doc_534729444718_item	3627867	et	3	main
teise	doc_534729444718_item	3627863	et	4	main
eesti	doc_534729444718_item	3627860	et	4	main
eestlastel	doc_534729444718_item	3628067	et	4	main
et	doc_534729444718_item	3628066	et	3	main
näitab	doc_534729444718_item	3628065	et	3	main
see	doc_534729444718_item	3628064	et	3	main
arvutid	doc_534729444718_item	3628062	et	4	main
telerid	doc_534729444718_item	3628061	et	3	main
kasutamisel	doc_534729444718_item	3628060	et	4	main
inimestel	doc_534729444718_item	3628059	et	3	main
olemas	doc_534729444718_item	3628058	et	4	main
on	doc_534729444718_item	3628057	et	4	main
ja	doc_534729444718_item	3628056	et	3	main
eile	doc_534729444718_item	3628055	et	3	main
kui	doc_534729444718_item	3628054	et	3	main
vähem	doc_534729444718_item	3628053	et	4	main
mis	doc_534729444718_item	3627897	et	4	main
näidetega	doc_534729444718_item	3627896	et	3	main
on	doc_534729444718_item	3627893	et	4	main
arutlev	doc_534729444718_item	3627882	et	4	main
keele	doc_534729444718_item	3627864	et	4	main
essee	doc_534729444718_item	3627859	et	4	main
laulamine	doc_534729444718_item	3628068	et	4	main
kindlasti	doc_534729444720_item	3628326	et	3	main
nad	doc_534729444720_item	3628324	et	3	main
et	doc_534729444720_item	3628317	et	3	main
mis	doc_534729444720_item	3628310	et	4	main
ebasobivad	doc_534729444720_item	3628265	et	3	main
selliseid	doc_534729444720_item	3628260	et	4	main
langeb	doc_534729444720_item	3628257	et	3	main
keel	doc_534729444720_item	3628255	et	4	main
et	doc_534729444720_item	3628253	et	3	main
sellepärast	doc_534729444720_item	3628252	et	3	main
oli	doc_534729444720_item	3628249	et	3	main
rahvalaul	doc_534729444720_item	3628248	et	4	main
et	doc_534729444720_item	3628247	et	3	main
arvan	doc_534729444720_item	3628246	et	3	main
ma	doc_534729444720_item	3628245	et	3	main
suuliselt	doc_534729444720_item	3628240	et	4	main
mere	doc_534729444720_item	3628234	et	3	main
balti	doc_534729444720_item	3628233	et	3	main
kes	doc_534729444720_item	3628231	et	4	main
minu	doc_534729444720_item	3628227	et	3	main
levinud	doc_534729444720_item	3628218	et	4	main
laiali	doc_534729444720_item	3628217	et	3	main
oli	doc_534729444720_item	3628216	et	3	main
harva	doc_534729444720_item	3628208	et	4	main
saab	doc_534729444720_item	3628207	et	3	main
täna	doc_534729444720_item	3628206	et	4	main
kuigi	doc_534729444720_item	3628205	et	3	main
ajaloost	doc_534729444720_item	3628204	et	4	main
on	doc_534729444720_item	3628198	et	4	main
see	doc_534729444720_item	3628197	et	3	main
pole	doc_534729444720_item	3628188	et	3	main
üldistav	doc_534729444720_item	3628175	et	4	main
arutlev	doc_534729444720_item	3628172	et	4	main
300	doc_534729444720_item	3628166	et	2	main
öeldes	doc_534729444720_item	3628401	et	3	main
või	doc_534729444720_item	3628378	et	4	main
kolm	doc_534729444720_item	3628377	et	3	main
iga	doc_534729444720_item	3628376	et	4	main
peetakse	doc_534729444720_item	3628375	et	3	main
tänapäeva	doc_534729444720_item	3628370	et	4	main
unustatud	doc_534729444720_item	3628364	et	4	main
et	doc_534729444720_item	3628360	et	3	main
rahvulaulud	doc_534729444720_item	3628344	et	3	main
leituma	doc_534729444720_item	3628342	et	4	main
naiteks	doc_534729444720_item	3628339	et	4	main
on	doc_534729444721_item	3628588	et	4	main
see	doc_534729444721_item	3628587	et	3	main
inimesi	doc_534729444721_item	3628581	et	4	main
linnas	doc_534729444721_item	3628575	et	4	main
igas	doc_534729444721_item	3628574	et	3	main
eestlased	doc_534729444721_item	3628570	et	3	main
kõik	doc_534729444721_item	3628569	et	4	main
võtta	doc_534729444721_item	3628567	et	3	main
ei	doc_534729444721_item	3628564	et	4	main
ja	doc_534729444721_item	3628562	et	3	main
festivallid	doc_534729444721_item	3628556	et	4	main
kes	doc_534729444721_item	3628532	et	4	main
inimesed	doc_534729444721_item	3628531	et	3	main
need	doc_534729444721_item	3628530	et	3	main
traditsioonid	doc_534729444721_item	3628527	et	3	main
vähe	doc_534729444721_item	3628511	et	3	main
et	doc_534729444721_item	3628501	et	3	main
väga	doc_534729444721_item	3628490	et	3	main
mis	doc_534729444721_item	3628486	et	4	main
laulurahva	doc_534729444721_item	3628470	et	3	main
teeb	doc_534729444721_item	3628468	et	3	main
tuginema	doc_534729444721_item	3628456	et	3	main
andis	doc_534729444723_item	3628692	et	3	main
eesti	doc_534729444723_item	3628679	et	4	main
aitavad	doc_534729444723_item	3628673	et	4	main
väga	doc_534729444723_item	3628665	et	3	main
tants	doc_534729444723_item	3628657	et	3	main
laul	doc_534729444723_item	3628654	et	4	main
soovitatav	doc_534729444723_item	3628651	et	4	main
näited	doc_534729444720_item	3628427	et	3	main
mõned	doc_534729444720_item	3628426	et	3	main
on	doc_534729444720_item	3628425	et	4	main
ninja	doc_534729444720_item	3628424	et	4	main
vanilla	doc_534729444720_item	3628423	et	4	main
eurovisioonil	doc_534729444720_item	3628422	et	3	main
esindus	doc_534729444720_item	3628421	et	4	main
padari	doc_534729444720_item	3628420	et	4	main
tanel	doc_534729444720_item	3628419	et	4	main
eeskujulik	doc_534729444720_item	3628418	et	3	main
keestavad	doc_534729444720_item	3628334	et	4	main
ikkagi	doc_534729444720_item	3628333	et	4	main
nad	doc_534729444720_item	3628332	et	3	main
vanasti	doc_534729444720_item	3628331	et	3	main
nagu	doc_534729444720_item	3628330	et	3	main
on	doc_534729444720_item	3628320	et	4	main
arvatakse	doc_534729444720_item	3628316	et	3	main
enamasti	doc_534729444720_item	3628302	et	4	main
ja	doc_534729444720_item	3628296	et	3	main
kerge	doc_534729444720_item	3628295	et	4	main
keel	doc_534729444720_item	3628294	et	4	main
spaani	doc_534729444720_item	3628293	et	4	main
või	doc_534729444720_item	3628292	et	4	main
itaalia	doc_534729444720_item	3628291	et	4	main
tähe	doc_534729444720_item	3628290	et	3	main
r	doc_534729444720_item	3628289	et	4	main
kasutatakse	doc_534729444720_item	3628288	et	3	main
tihti	doc_534729444720_item	3628287	et	3	main
raske	doc_534729444720_item	3628286	et	4	main
ja	doc_534729444720_item	3628285	et	3	main
range	doc_534729444720_item	3628284	et	4	main
keel	doc_534729444720_item	3628283	et	4	main
saksa	doc_534729444720_item	3628282	et	4	main
tunned	doc_534729444720_item	3628281	et	3	main
kaasnevad	doc_534729444720_item	3628280	et	4	main
keelele	doc_534729444720_item	3628279	et	4	main
sellele	doc_534729444720_item	3628278	et	4	main
ainult	doc_534729444720_item	3628277	et	4	main
oma	doc_534729444720_item	3628276	et	4	main
levinud	doc_534729444720_item	3628329	et	4	main
nii	doc_534729444720_item	3628328	et	3	main
pole	doc_534729444720_item	3628327	et	3	main
kuid	doc_534729444720_item	3628323	et	4	main
ebapopulaarsed	doc_534729444720_item	3628322	et	3	main
rahvalaulud	doc_534729444720_item	3628321	et	3	main
ainus	doc_534729444720_item	3628304	et	4	main
rahulikud	doc_534729444720_item	3628303	et	3	main
keeles	doc_534729444720_item	3628299	et	4	main
kiire	doc_534729444720_item	3628297	et	4	main
iga	doc_534729444720_item	3628273	et	4	main
muusikale	doc_534729444720_item	3628266	et	4	main
keele	doc_534729444720_item	3628261	et	4	main
muusikaga	doc_534729444720_item	3628258	et	3	main
kombele	doc_534729444720_item	3628244	et	4	main
esimestest	doc_534729444720_item	3628229	et	4	main
mis	doc_534729444720_item	3628225	et	4	main
mitmekülgne	doc_534729444720_item	3628223	et	3	main
ja	doc_534729444720_item	3628222	et	3	main
laulvad	doc_534729444720_item	3628214	et	4	main
kultuurinähtus	doc_534729444720_item	3628200	et	4	main
ainult	doc_534729444720_item	3628189	et	4	main
peab	doc_534729444720_item	3628170	et	4	main
võib	doc_534729444720_item	3628402	et	3	main
ainult	doc_534729444720_item	3628394	et	4	main
neid	doc_534729444720_item	3628393	et	4	main
peetakse	doc_534729444720_item	3628392	et	3	main
maades	doc_534729444720_item	3628391	et	4	main
muusikamaailmasse	doc_534729444720_item	3628371	et	4	main
rahvalaulud	doc_534729444720_item	3628363	et	3	main
rahvalaulu	doc_534729444720_item	3628357	et	4	main
loengus	doc_534729444720_item	3628353	et	3	main
motiivid	doc_534729444720_item	3628352	et	3	main
kasutavad	doc_534729444720_item	3628350	et	4	main
tuntud	doc_534729444720_item	3628345	et	4	main
grupp	doc_534729444720_item	3628341	et	3	main
tegelevad	doc_534729444721_item	3628582	et	4	main
on	doc_534729444721_item	3628576	et	4	main
oskavad	doc_534729444721_item	3628571	et	4	main
on	doc_534729444721_item	3628559	et	4	main
laulmise	doc_534729444721_item	3628557	et	4	main
ajadest	doc_534729444721_item	3628551	et	4	main
vanadest	doc_534729444721_item	3628550	et	3	main
laulurahva	doc_534729444721_item	3628549	et	3	main
teeb	doc_534729444721_item	3628547	et	3	main
saavad	doc_534729444721_item	3628533	et	4	main
laulurahv	doc_534729444721_item	3628528	et	4	main
olema	doc_534729444721_item	3628513	et	4	main
armastamist	doc_534729444721_item	3628509	et	4	main
kõike	doc_534729444721_item	3628503	et	4	main
laulurahv	doc_534729444721_item	3628489	et	4	main
vaja	doc_534729444721_item	3628484	et	4	main
sellest	doc_534729444721_item	3628477	et	4	main
rääkida	doc_534729444721_item	3628476	et	3	main
kui	doc_534729444721_item	3628475	et	3	main
seda	doc_534729444721_item	3628474	et	3	main
enne	doc_534729444721_item	3628473	et	4	main
üldistav	doc_534729444721_item	3628455	et	4	main
ja	doc_534729444721_item	3628454	et	3	main
vabadus	doc_534729444723_item	3628688	et	4	main
võtsid	doc_534729444723_item	3628683	et	4	main
mis	doc_534729444723_item	3628682	et	4	main
vaimus	doc_534729444723_item	3628663	et	4	main
näidetega	doc_534729444723_item	3628653	et	3	main
faktidele	doc_534729444723_item	3628648	et	3	main
kesk-aafrika	doc_534729444720_item	3628268	et	4	main
on	doc_534729444720_item	3628263	et	4	main
mälule	doc_534729444720_item	3628242	et	3	main
laule	doc_534729444720_item	3628236	et	4	main
eestlastel	doc_534729444720_item	3628219	et	4	main
inimesi	doc_534729444720_item	3628210	et	4	main
näha	doc_534729444720_item	3628209	et	3	main
ning	doc_534729444720_item	3628202	et	3	main
meelelahutus	doc_534729444720_item	3628201	et	4	main
muusika	doc_534729444720_item	3628196	et	4	main
kaasnev	doc_534729444720_item	3628195	et	4	main
mõnikord	doc_534729444720_item	3628194	et	3	main
ning	doc_534729444720_item	3628193	et	3	main
järjestatud	doc_534729444720_item	3628191	et	4	main
näidetega	doc_534729444720_item	3628186	et	3	main
ja	doc_534729444720_item	3628174	et	3	main
sõna	doc_534729444720_item	3628168	et	4	main
350	doc_534729444720_item	3628167	et	2	main
pikkus	doc_534729444720_item	3628165	et	4	main
essee	doc_534729444720_item	3628164	et	4	main
laulurahva	doc_534729444720_item	3628163	et	3	main
eestlastest	doc_534729444720_item	3628162	et	4	main
teeb	doc_534729444720_item	3628161	et	3	main
mis	doc_534729444720_item	3628160	et	4	main
teemal	doc_534729444720_item	3628159	et	3	main
essee	doc_534729444720_item	3628158	et	4	main
kirjutage	doc_534729444720_item	3628157	et	3	main
kirjutamine	doc_534729444720_item	3628156	et	4	main
test	doc_534729444720_item	3628155	et	3	main
teise	doc_534729444720_item	3628153	et	4	main
kui	doc_534729444720_item	3628152	et	3	main
keele	doc_534729444720_item	3628154	et	4	main
keele	doc_534729444720_item	3628151	et	4	main
eesti	doc_534729444720_item	3628150	et	4	main
essee	doc_534729444720_item	3628149	et	4	main
eestlastest	doc_534729444720_item	3628416	et	4	main
mis	doc_534729444720_item	3628414	et	4	main
kõik	doc_534729444720_item	3628413	et	4	main
pole	doc_534729444720_item	3628412	et	3	main
maailmale	doc_534729444720_item	3628411	et	4	main
tänase	doc_534729444720_item	3628410	et	3	main
öelda	doc_534729444720_item	3628403	et	4	main
lõpp	doc_534729444720_item	3628400	et	3	main
sordi	doc_534729444720_item	3628384	et	4	main
ainus	doc_534729444720_item	3628382	et	4	main
on	doc_534729444720_item	3628381	et	4	main
aastat	doc_534729444720_item	3628380	et	3	main
neli	doc_534729444720_item	3628379	et	3	main
ülemaaline	doc_534729444720_item	3628372	et	4	main
ning	doc_534729444720_item	3628365	et	3	main
kindlasti	doc_534729444720_item	3628361	et	3	main
see	doc_534729444720_item	3628358	et	3	main
rock-versiooni	doc_534729444720_item	3628356	et	4	main
ka	doc_534729444720_item	3628355	et	3	main
mille	doc_534729444720_item	3628343	et	3	main
jne	doc_534729444721_item	3628585	et	4	main
tantsidega	doc_534729444721_item	3628584	et	3	main
laulmisega	doc_534729444721_item	3628583	et	4	main
koore	doc_534729444721_item	3628578	et	4	main
palju	doc_534729444721_item	3628577	et	4	main
ära	doc_534729444721_item	3628566	et	4	main
veres	doc_534729444721_item	3628561	et	3	main
erinevad	doc_534729444721_item	3628555	et	4	main
on	doc_534729444721_item	3628554	et	4	main
laulupeod	doc_534729444721_item	3628553	et	4	main
kõige	doc_534729444721_item	3628543	et	4	main
on	doc_534729444721_item	3628542	et	4	main
ja	doc_534729444720_item	3628178	et	3	main
loengus	doc_534729444720_item	3628177	et	3	main
tuginema	doc_534729444720_item	3628176	et	3	main
analüüsiv	doc_534729444720_item	3628173	et	4	main
olema	doc_534729444720_item	3628171	et	4	main
teeb	doc_534729444720_item	3628415	et	3	main
viibimine	doc_534729444720_item	3628409	et	4	main
nende	doc_534729444720_item	3628408	et	4	main
säilitamine	doc_534729444720_item	3628407	et	4	main
rahvalaulude	doc_534729444720_item	3628406	et	3	main
tähtsust	doc_534729444720_item	3628399	et	4	main
omab	doc_534729444720_item	3628396	et	3	main
teistes	doc_534729444720_item	3628390	et	4	main
ka	doc_534729444720_item	3628389	et	3	main
selle	doc_534729444720_item	3628383	et	4	main
mis	doc_534729444720_item	3628374	et	4	main
neid	doc_534729444720_item	3628369	et	4	main
viia	doc_534729444720_item	3628368	et	3	main
tehakse	doc_534729444720_item	3628366	et	3	main
näitab	doc_534729444720_item	3628359	et	3	main
välismaal	doc_534729444720_item	3628346	et	4	main
soome	doc_534729444720_item	3628340	et	3	main
räägiti	doc_534729444720_item	3628354	et	3	main
vanad	doc_534729444720_item	3628351	et	3	main
heliloojad	doc_534729444720_item	3628349	et	3	main
tänapäevased	doc_534729444720_item	3628348	et	4	main
paljud	doc_534729444720_item	3628347	et	3	main
hästi	doc_534729444721_item	3628572	et	3	main
praktilised	doc_534729444721_item	3628568	et	3	main
eestlaste	doc_534729444721_item	3628560	et	4	main
armastamine	doc_534729444721_item	3628558	et	4	main
eestlastest	doc_534729444721_item	3628548	et	4	main
mis	doc_534729444721_item	3628546	et	4	main
arvates	doc_534729444721_item	3628540	et	4	main
minu	doc_534729444721_item	3628539	et	3	main
aru	doc_534729444721_item	3628536	et	4	main
tähtsus	doc_534729444721_item	3628535	et	4	main
traditsioonide	doc_534729444721_item	3628534	et	3	main
on	doc_534729444721_item	3628524	et	4	main
kui	doc_534729444721_item	3628523	et	3	main
siis	doc_534729444721_item	3628522	et	3	main
veel	doc_534729444721_item	3628514	et	4	main
tähenda	doc_534729444721_item	3628500	et	4	main
ei	doc_534729444721_item	3628499	et	4	main
see	doc_534729444721_item	3628498	et	3	main
aga	doc_534729444721_item	3628497	et	3	main
laulda	doc_534729444721_item	3628496	et	4	main
ja	doc_534729444721_item	3628495	et	3	main
tantsida	doc_534729444721_item	3628494	et	3	main
armastavad	doc_534729444721_item	3628493	et	4	main
meist	doc_534729444721_item	3628492	et	3	main
tähendab	doc_534729444721_item	3628487	et	3	main
mis	doc_534729444721_item	3628478	et	4	main
soovitatav	doc_534729444721_item	3628464	et	4	main
on	doc_534729444721_item	3628463	et	4	main
analüüsiv	doc_534729444721_item	3628453	et	4	main
veres	doc_534729444721_item	3628614	et	3	main
laulmine	doc_534729444721_item	3628612	et	4	main
on	doc_534729444721_item	3628613	et	4	main
et	doc_534729444721_item	3628611	et	3	main
nähtud	doc_534729444721_item	3628610	et	4	main
on	doc_534729444721_item	3628609	et	4	main
et	doc_534729444721_item	3628608	et	3	main
nii	doc_534729444721_item	3628606	et	3	main
hästi	doc_534729444721_item	3628607	et	3	main
seda	doc_534729444721_item	3628605	et	3	main
teevad	doc_534729444721_item	3628604	et	3	main
ja	doc_534729444721_item	3628603	et	3	main
naised	doc_534729444721_item	3628602	et	3	main
mehed	doc_534729444721_item	3628601	et	3	main
lapsed	doc_534729444721_item	3628600	et	3	main
kõik	doc_534729444721_item	3628599	et	4	main
absoluutselt	doc_534729444721_item	3628598	et	4	main
laulavad	doc_534729444721_item	3628597	et	4	main
laulutraditsioonid	doc_534729444721_item	3628596	et	3	main
on	doc_534729444721_item	3628594	et	4	main
eestlastel	doc_534729444721_item	3628593	et	4	main
et	doc_534729444721_item	3628592	et	3	main
head	doc_534729444721_item	3628595	et	4	main
näidis	doc_534729444721_item	3628591	et	4	main
hea	doc_534729444721_item	3628590	et	4	main
päris	doc_534729444721_item	3628589	et	4	main
laulupeod	doc_534729444721_item	3628586	et	4	main
palju	doc_534729444721_item	3628580	et	4	main
ja	doc_534729444721_item	3628579	et	3	main
laulda	doc_534729444721_item	3628573	et	4	main
saa	doc_534729444721_item	3628565	et	4	main
seda	doc_534729444721_item	3628563	et	3	main
on	doc_534729444721_item	3628552	et	4	main
põhjus	doc_534729444721_item	3628545	et	4	main
tähtsam	doc_534729444721_item	3628544	et	4	main
laulutraditsioonide	doc_534729444721_item	3628538	et	3	main
olemas	doc_534729444721_item	3628525	et	4	main
mis	doc_534729444721_item	3628518	et	4	main
austus	doc_534729444721_item	3628517	et	4	main
ja	doc_534729444721_item	3628516	et	3	main
arusaamine	doc_534729444721_item	3628515	et	4	main
see	doc_534729444721_item	3628541	et	3	main
eriti	doc_534729444721_item	3628537	et	3	main
on	doc_534729444721_item	3628529	et	4	main
kultuuri	doc_534729444721_item	3628526	et	4	main
alles	doc_534729444721_item	3628521	et	3	main
olla	doc_534729444721_item	3628520	et	3	main
võib	doc_534729444721_item	3628519	et	3	main
peab	doc_534729444721_item	3628512	et	4	main
absoluutselt	doc_534729444721_item	3628502	et	4	main
palju	doc_534729444721_item	3628491	et	4	main
tegelikult	doc_534729444721_item	3628479	et	4	main
pealt	doc_534729444721_item	3628472	et	4	main
eestlastest	doc_534729444721_item	3628469	et	4	main
mis	doc_534729444721_item	3628467	et	4	main
näidetega	doc_534729444721_item	3628466	et	3	main
illustreerida	doc_534729444721_item	3628465	et	3	main
esitatud	doc_534729444721_item	3628460	et	4	main
lugemistekstis	doc_534729444721_item	3628459	et	3	main
ja	doc_534729444721_item	3628458	et	3	main
loengus	doc_534729444721_item	3628457	et	3	main
raha	doc_534729444723_item	3628689	et	4	main
kõike	doc_534729444723_item	3628686	et	4	main
teised	doc_534729444723_item	3628677	et	4	main
kui	doc_534729444723_item	3628676	et	3	main
seista	doc_534729444723_item	3628675	et	4	main
talle	doc_534729444723_item	3628674	et	4	main
jõudu	doc_534729444723_item	3628670	et	4	main
inimesele	doc_534729444723_item	3628669	et	3	main
annavad	doc_534729444723_item	3628668	et	3	main
nad	doc_534729444723_item	3628667	et	3	main
tähtsad	doc_534729444723_item	3628666	et	3	main
on	doc_534729444723_item	3628650	et	4	main
ja	doc_534729444723_item	3628696	et	3	main
koorilaulu	doc_534729444727_item	3628959	et	4	main
selle	doc_534729444727_item	3628951	et	4	main
kuigi	doc_534729444727_item	3628950	et	3	main
eestis	doc_534729444727_item	3628949	et	3	main
manifestatsioon	doc_534729444727_item	3628948	et	3	main
tähelepanuväärsem	doc_534729444727_item	3628944	et	4	main
kõige	doc_534729444727_item	3628943	et	4	main
jannsen	doc_534729444727_item	3628930	et	4	main
peaks	doc_534729444727_item	3628917	et	4	main
rahvus	doc_534729444727_item	3628916	et	3	main
eesti	doc_534729444727_item	3628915	et	4	main
rahvalaulad	doc_534729444727_item	3628908	et	4	main
rolli	doc_534729444727_item	3628903	et	4	main
oma	doc_534729444727_item	3628902	et	4	main
eesti	doc_534729444727_item	3628882	et	4	main
et	doc_534729444727_item	3628881	et	3	main
seda	doc_534729444727_item	3628880	et	3	main
ka	doc_534729444727_item	3628879	et	3	main
unustada	doc_534729444727_item	3628878	et	3	main
lihtsalt	doc_534729444727_item	3628872	et	4	main
ning	doc_534729444727_item	3628871	et	3	main
laulad	doc_534729444727_item	3628870	et	3	main
rahvusliku	doc_534729444727_item	3628868	et	3	main
annab	doc_534729444727_item	3628861	et	3	main
kuhu	doc_534729444727_item	3628853	et	3	main
seda	doc_534729444727_item	3628845	et	3	main
laulupidu	doc_534729444727_item	3628842	et	4	main
koorilaulu	doc_534729444727_item	3628833	et	4	main
on	doc_534729444727_item	3628818	et	4	main
et	doc_534729444727_item	3628817	et	3	main
see	doc_534729444727_item	3628816	et	3	main
vaid	doc_534729444727_item	3628809	et	3	main
üksnes	doc_534729444727_item	3628806	et	3	main
ei	doc_534729444727_item	3628767	et	4	main
teemal	doc_534729444727_item	3628731	et	3	main
test	doc_534729444727_item	3628727	et	3	main
essee	doc_534729444727_item	3628721	et	4	main
lugemistekstis	doc_534729444728_item	3629000	et	3	main
arutlev	doc_534729444728_item	3628993	et	4	main
olema	doc_534729444728_item	3628992	et	4	main
300	doc_534729444728_item	3628987	et	2	main
pikkus	doc_534729444728_item	3628986	et	4	main
essee	doc_534729444728_item	3628985	et	4	main
laulurahva	doc_534729444728_item	3628984	et	3	main
teemal	doc_534729444728_item	3628980	et	3	main
keele	doc_534729444728_item	3628975	et	4	main
teise	doc_534729444728_item	3628974	et	4	main
kui	doc_534729444728_item	3628973	et	3	main
on	doc_534729444721_item	3628510	et	4	main
muusika	doc_534729444721_item	3628508	et	4	main
ainult	doc_534729444721_item	3628507	et	4	main
laulurahvaks	doc_534729444721_item	3628506	et	3	main
nimetada	doc_534729444721_item	3628505	et	3	main
võib	doc_534729444721_item	3628504	et	3	main
sõna	doc_534729444721_item	3628488	et	4	main
selgitada	doc_534729444721_item	3628485	et	3	main
on	doc_534729444721_item	3628483	et	4	main
laulurahva	doc_534729444721_item	3628482	et	3	main
eestlastest	doc_534729444721_item	3628481	et	4	main
teeb	doc_534729444721_item	3628480	et	3	main
kõige	doc_534729444721_item	3628471	et	4	main
väiteid	doc_534729444721_item	3628462	et	4	main
faktidele	doc_534729444721_item	3628461	et	3	main
arutlev	doc_534729444721_item	3628452	et	4	main
olema	doc_534729444721_item	3628451	et	4	main
peab	doc_534729444721_item	3628450	et	4	main
essee	doc_534729444721_item	3628449	et	4	main
sõna	doc_534729444721_item	3628448	et	4	main
350	doc_534729444721_item	3628447	et	2	main
300	doc_534729444721_item	3628446	et	2	main
pikkus	doc_534729444721_item	3628445	et	4	main
essee	doc_534729444721_item	3628444	et	4	main
laulurahva	doc_534729444721_item	3628443	et	3	main
eestlastest	doc_534729444721_item	3628442	et	4	main
teeb	doc_534729444721_item	3628441	et	3	main
mis	doc_534729444721_item	3628440	et	4	main
teemal	doc_534729444721_item	3628439	et	3	main
essee	doc_534729444721_item	3628438	et	4	main
kirjutage	doc_534729444721_item	3628437	et	3	main
kirjutamine	doc_534729444721_item	3628436	et	4	main
test	doc_534729444721_item	3628435	et	3	main
keele	doc_534729444721_item	3628434	et	4	main
kui	doc_534729444721_item	3628432	et	3	main
teise	doc_534729444721_item	3628433	et	4	main
keele	doc_534729444721_item	3628431	et	4	main
eesti	doc_534729444721_item	3628430	et	4	main
essee	doc_534729444721_item	3628429	et	4	main
taiu	doc_534729444723_item	3628690	et	3	main
ära	doc_534729444723_item	3628687	et	4	main
lasteslt	doc_534729444723_item	3628685	et	4	main
oma	doc_534729444723_item	3628684	et	4	main
laulumaa	doc_534729444723_item	3628681	et	4	main
on	doc_534729444723_item	3628680	et	4	main
probleemi	doc_534729444723_item	3628671	et	4	main
eesti	doc_534729444723_item	3628662	et	4	main
oskused	doc_534729444723_item	3628660	et	3	main
kolm	doc_534729444723_item	3628658	et	3	main
ja	doc_534729444723_item	3628656	et	3	main
väiteid	doc_534729444723_item	3628649	et	4	main
esitatud	doc_534729444723_item	3628647	et	4	main
suulist	doc_534729444727_item	3628967	et	4	main
ja	doc_534729444727_item	3628966	et	3	main
muusikataju	doc_534729444727_item	3628965	et	4	main
pikka	doc_534729444727_item	3628962	et	4	main
seotud	doc_534729444727_item	3628955	et	4	main
on	doc_534729444727_item	3628954	et	4	main
jõudu	doc_534729444723_item	3628719	et	4	main
nendele	doc_534729444723_item	3628718	et	4	main
andsid	doc_534729444723_item	3628717	et	4	main
see	doc_534729444723_item	3628716	et	3	main
ja	doc_534729444723_item	3628715	et	3	main
al	doc_534729444723_item	3628714	et	4	main
loa	doc_534729444723_item	3628713	et	4	main
saksa	doc_534729444723_item	3628712	et	4	main
oli	doc_534729444723_item	3628711	et	3	main
maa	doc_534729444723_item	3628710	et	4	main
nende	doc_534729444723_item	3628709	et	4	main
kui	doc_534729444723_item	3628708	et	3	main
laulda	doc_534729444723_item	3628707	et	4	main
regilaulu	doc_534729444723_item	3628706	et	4	main
alustasid	doc_534729444723_item	3628705	et	4	main
nad	doc_534729444723_item	3628704	et	3	main
ajaloos	doc_534729444723_item	3628703	et	4	main
eesti	doc_534729444723_item	3628702	et	4	main
ümbervaadata	doc_534729444723_item	3628701	et	4	main
võiks	doc_534729444723_item	3628700	et	4	main
kõik	doc_534729444723_item	3628699	et	4	main
ja	doc_534729444723_item	3628691	et	3	main
kukkuvad	doc_534729444723_item	3628678	et	4	main
lahkumisel	doc_534729444723_item	3628672	et	4	main
on	doc_534729444723_item	3628664	et	4	main
mis	doc_534729444723_item	3628661	et	4	main
permanentsets	doc_534729444723_item	3628659	et	4	main
muusika	doc_534729444723_item	3628655	et	4	main
illustreerida	doc_534729444723_item	3628652	et	3	main
lugemistekstis	doc_534729444723_item	3628646	et	3	main
ja	doc_534729444723_item	3628645	et	3	main
loengus	doc_534729444723_item	3628644	et	3	main
tuginema	doc_534729444723_item	3628643	et	3	main
ja	doc_534729444723_item	3628641	et	3	main
üldistav	doc_534729444723_item	3628642	et	4	main
analüüsiv	doc_534729444723_item	3628640	et	4	main
arutlev	doc_534729444723_item	3628639	et	4	main
olema	doc_534729444723_item	3628638	et	4	main
peab	doc_534729444723_item	3628637	et	4	main
essee	doc_534729444723_item	3628636	et	4	main
sõna	doc_534729444723_item	3628635	et	4	main
350	doc_534729444723_item	3628634	et	2	main
300	doc_534729444723_item	3628633	et	2	main
pikkus	doc_534729444723_item	3628632	et	4	main
essee	doc_534729444723_item	3628631	et	4	main
laulurahva	doc_534729444723_item	3628630	et	3	main
eestlastest	doc_534729444723_item	3628629	et	4	main
teeb	doc_534729444723_item	3628628	et	3	main
mis	doc_534729444723_item	3628627	et	4	main
teemal	doc_534729444723_item	3628626	et	3	main
essee	doc_534729444723_item	3628625	et	4	main
kirjutage	doc_534729444723_item	3628624	et	3	main
kirjutamine	doc_534729444723_item	3628623	et	4	main
test	doc_534729444723_item	3628622	et	3	main
keele	doc_534729444723_item	3628621	et	4	main
teise	doc_534729444723_item	3628620	et	4	main
kui	doc_534729444723_item	3628619	et	3	main
keele	doc_534729444723_item	3628618	et	4	main
eesti	doc_534729444723_item	3628617	et	4	main
essee	doc_534729444723_item	3628616	et	4	main
see	doc_534729444723_item	3628698	et	3	main
muusikas	doc_534729444723_item	3628697	et	3	main
laulupärimust	doc_534729444727_item	3628968	et	4	main
aega	doc_534729444727_item	3628963	et	4	main
mõjutanud	doc_534729444727_item	3628961	et	4	main
traditsioon	doc_534729444727_item	3628960	et	3	main
peo	doc_534729444727_item	3628952	et	4	main
massilisem	doc_534729444727_item	3628946	et	4	main
ja	doc_534729444727_item	3628945	et	3	main
näiteks	doc_534729444727_item	3628927	et	4	main
tantsis	doc_534729444723_item	3628695	et	4	main
laulus	doc_534729444723_item	3628694	et	3	main
kõiki	doc_534729444723_item	3628693	et	4	main
on	doc_534729444727_item	3628958	et	4	main
heliloominguga	doc_534729444727_item	3628957	et	3	main
professionaalse	doc_534729444727_item	3628956	et	3	main
rahvusluse	doc_534729444727_item	3628947	et	4	main
voldemar	doc_534729444727_item	3628929	et	4	main
eesti	doc_534729444727_item	3628925	et	4	main
tänu	doc_534729444727_item	3628921	et	4	main
suur	doc_534729444727_item	3628920	et	3	main
öelda	doc_534729444727_item	3628919	et	4	main
mäletama	doc_534729444727_item	3628918	et	3	main
säilitavad	doc_534729444727_item	3628912	et	4	main
ja	doc_534729444727_item	3628911	et	3	main
minevikus	doc_534729444727_item	3628910	et	3	main
kes	doc_534729444727_item	3628905	et	4	main
on	doc_534729444727_item	3628893	et	4	main
keel	doc_534729444727_item	3628889	et	4	main
meloodiline	doc_534729444727_item	3628888	et	3	main
ja	doc_534729444727_item	3628887	et	3	main
õrn	doc_534729444727_item	3628886	et	3	main
väga	doc_534729444727_item	3628885	et	3	main
laulud	doc_534729444727_item	3628875	et	3	main
kõlavad	doc_534729444727_item	3628866	et	4	main
laulda	doc_534729444727_item	3628864	et	4	main
kaasa	doc_534729444727_item	3628863	et	4	main
pidudes	doc_534729444727_item	3628849	et	4	main
arv	doc_534729444727_item	3628848	et	3	main
kogu	doc_534729444727_item	3628843	et	4	main
on	doc_534729444727_item	3628841	et	4	main
tähtis	doc_534729444727_item	3628840	et	4	main
kui	doc_534729444727_item	3628839	et	3	main
arendamises	doc_534729444727_item	3628832	et	4	main
on	doc_534729444727_item	3628828	et	4	main
tähendab	doc_534729444727_item	3628825	et	3	main
ja	doc_534729444727_item	3628823	et	3	main
noorid	doc_534729444727_item	3628821	et	4	main
palju	doc_534729444727_item	3628820	et	4	main
nii	doc_534729444727_item	3628819	et	3	main
kõige	doc_534729444727_item	3628810	et	4	main
kirjutage	doc_534729444727_item	3628729	et	3	main
soovitatav	doc_534729444728_item	3629005	et	4	main
väiteid	doc_534729444728_item	3629003	et	4	main
faktidele	doc_534729444728_item	3629002	et	3	main
esitatud	doc_534729444728_item	3629001	et	4	main
peab	doc_534729444728_item	3628991	et	4	main
essee	doc_534729444728_item	3628990	et	4	main
sõna	doc_534729444728_item	3628989	et	4	main
350	doc_534729444728_item	3628988	et	2	main
mis	doc_534729444728_item	3628981	et	4	main
kirjutamine	doc_534729444728_item	3628977	et	4	main
kultuurinähtus	doc_534729444728_item	3629213	et	4	main
see	doc_534729444728_item	3629211	et	3	main
laulurahvaks	doc_534729444728_item	3629202	et	3	main
arvan	doc_534729444728_item	3629198	et	3	main
miks	doc_534729444728_item	3629196	et	4	main
huvi	doc_534729444728_item	3629191	et	4	main
lihtsalt	doc_534729444728_item	3629190	et	4	main
armastatakse	doc_534729444728_item	3629154	et	3	main
nii	doc_534729444728_item	3629142	et	3	main
kes	doc_534729444728_item	3629134	et	4	main
nad	doc_534729444728_item	3629128	et	3	main
muusikaga	doc_534729444728_item	3629126	et	3	main
kõik	doc_534729444728_item	3629118	et	4	main
ja	doc_534729444728_item	3629117	et	3	main
tuttavaid	doc_534729444728_item	3629116	et	3	main
ja	doc_534729444728_item	3629115	et	3	main
sõpru	doc_534729444728_item	3629114	et	3	main
on	doc_534729444728_item	3629111	et	4	main
protsess	doc_534729444728_item	3629109	et	3	main
pikk	doc_534729444728_item	3629107	et	4	main
siin	doc_534729444728_item	3629096	et	4	main
laul	doc_534729444728_item	3629085	et	4	main
et	doc_534729444728_item	3629084	et	3	main
palju	doc_534729444728_item	3629070	et	4	main
suurt	doc_534729444728_item	3629054	et	3	main
kiigutades	doc_534729444728_item	3629040	et	3	main
või	doc_534729444728_item	3629038	et	4	main
eestlaste	doc_534729444727_item	3628964	et	4	main
ajal	doc_534729444727_item	3628942	et	4	main
praegusel	doc_534729444727_item	3628941	et	3	main
on	doc_534729444727_item	3628939	et	4	main
laulupidu	doc_534729444727_item	3628938	et	4	main
üle-eestiline	doc_534729444727_item	3628937	et	3	main
ernesaks	doc_534729444727_item	3628936	et	4	main
gustav	doc_534729444727_item	3628935	et	4	main
nagu	doc_534729444727_item	3628934	et	3	main
luuletajad	doc_534729444727_item	3628933	et	4	main
muidugi	doc_534729444727_item	3628932	et	4	main
ja	doc_534729444727_item	3628931	et	3	main
repertuaar	doc_534729444727_item	3628953	et	3	main
ka	doc_534729444727_item	3628940	et	3	main
johann	doc_534729444727_item	3628928	et	4	main
arendab	doc_534729444727_item	3628924	et	3	main
inimestele	doc_534729444727_item	3628922	et	3	main
meie	doc_534729444727_item	3628913	et	4	main
said	doc_534729444727_item	3628906	et	4	main
mängis	doc_534729444727_item	3628901	et	3	main
seda	doc_534729444727_item	3628900	et	3	main
et	doc_534729444727_item	3628899	et	3	main
arvan	doc_534729444727_item	3628898	et	3	main
meeldiv	doc_534729444727_item	3628897	et	4	main
ja	doc_534729444727_item	3628896	et	3	main
mugav	doc_534729444727_item	3628895	et	3	main
väga	doc_534729444727_item	3628894	et	3	main
eesti	doc_534729444727_item	3628891	et	4	main
tohi	doc_534729444727_item	3628877	et	4	main
tunnega	doc_534729444727_item	3628869	et	4	main
laulu	doc_534729444727_item	3628926	et	4	main
tulid	doc_534729444727_item	3628909	et	4	main
eestlastest	doc_534729444727_item	3628904	et	4	main
on	doc_534729444727_item	3628884	et	4	main
keel	doc_534729444727_item	3628883	et	4	main
natsioonaalsed	doc_534729444727_item	3628874	et	4	main
eesti	doc_534729444727_item	3628873	et	4	main
võimalust	doc_534729444727_item	3628862	et	3	main
on	doc_534729444727_item	3628851	et	4	main
rahvale	doc_534729444727_item	3628844	et	3	main
vastavalt	doc_534729444727_item	3628837	et	4	main
väärtustada	doc_534729444727_item	3628836	et	3	main
tuleks	doc_534729444727_item	3628835	et	4	main
ülevalpidamist	doc_534729444727_item	3628834	et	3	main
ka	doc_534729444727_item	3628829	et	3	main
et	doc_534729444727_item	3628826	et	3	main
rohkem	doc_534729444727_item	3628815	et	4	main
ettevõtmine	doc_534729444727_item	3628808	et	3	main
ole	doc_534729444727_item	3628768	et	4	main
eesti	doc_534729444727_item	3628722	et	4	main
kes	doc_534729444727_item	3628923	et	4	main
ühikonnal	doc_534729444727_item	3628914	et	4	main
laulurahvast	doc_534729444727_item	3628907	et	4	main
keeles	doc_534729444727_item	3628892	et	4	main
laulma	doc_534729444727_item	3628890	et	3	main
ei	doc_534729444727_item	3628876	et	4	main
nii	doc_534729444727_item	3628867	et	3	main
laupupidudel	doc_534729444727_item	3628865	et	4	main
sõpru	doc_534729444727_item	3628859	et	3	main
kohata	doc_534729444727_item	3628858	et	4	main
perega	doc_534729444727_item	3628856	et	3	main
koos	doc_534729444727_item	3628855	et	4	main
rahvapidu	doc_534729444727_item	3628852	et	4	main
see	doc_534729444727_item	3628850	et	3	main
inimeste	doc_534729444727_item	3628847	et	3	main
sellele	doc_534729444727_item	3628838	et	4	main
laulu	doc_534729444727_item	3628831	et	4	main
see	doc_534729444727_item	3628824	et	3	main
lauljad	doc_534729444727_item	3628822	et	4	main
kõige	doc_534729444727_item	3628814	et	4	main
rõõmustab	doc_534729444727_item	3628813	et	3	main
muusikasündmus	doc_534729444727_item	3628812	et	3	main
kvaliteediga	doc_534729444727_item	3628811	et	3	main
keele	doc_534729444727_item	3628723	et	4	main
tuginema	doc_534729444728_item	3628997	et	3	main
ja	doc_534729444728_item	3628995	et	3	main
eestlastest	doc_534729444728_item	3628983	et	4	main
essee	doc_534729444728_item	3628979	et	4	main
kirjutage	doc_534729444728_item	3628978	et	3	main
eesti	doc_534729444728_item	3628971	et	4	main
essee	doc_534729444728_item	3628970	et	4	main
osa	doc_534729444728_item	3629206	et	4	main
suur	doc_534729444728_item	3629205	et	3	main
siin	doc_534729444728_item	3629153	et	4	main
inimestele	doc_534729444728_item	3629151	et	3	main
eesti	doc_534729444728_item	3629150	et	4	main
läheb	doc_534729444728_item	3629149	et	3	main
et	doc_534729444728_item	3629130	et	3	main
eesti	doc_534729444728_item	3629113	et	4	main
ajalooline	doc_534729444728_item	3629108	et	4	main
ei	doc_534729444728_item	3629101	et	4	main
seotud	doc_534729444728_item	3629095	et	4	main
üldse	doc_534729444728_item	3629087	et	3	main
on	doc_534729444728_item	3629086	et	4	main
arvan	doc_534729444728_item	3629083	et	3	main
tuttavaid	doc_534729444728_item	3629081	et	3	main
leida	doc_534729444728_item	3629079	et	3	main
sinna	doc_534729444728_item	3629073	et	3	main
ei	doc_534729444728_item	3629046	et	4	main
enam	doc_534729444728_item	3629045	et	4	main
lapsi	doc_534729444728_item	3629039	et	4	main
lauldi	doc_534729444728_item	3629027	et	3	main
eestis	doc_534729444728_item	3629026	et	3	main
nii	doc_534729444728_item	3629025	et	3	main
on	doc_534729444728_item	3629018	et	4	main
et	doc_534729444728_item	3629016	et	3	main
loodus	doc_534729444731_item	3629448	et	4	main
inimesed	doc_534729444731_item	3629446	et	3	main
mis	doc_534729444731_item	3629435	et	4	main
proovida	doc_534729444731_item	3629431	et	3	main
eesti	doc_534729444731_item	3629419	et	4	main
jne	doc_534729444731_item	3629417	et	4	main
eestis	doc_534729444731_item	3629412	et	3	main
olulist	doc_534729444731_item	3629410	et	4	main
öelda	doc_534729444731_item	3629399	et	4	main
võib	doc_534729444731_item	3629398	et	3	main
kujunemises	doc_534729444731_item	3629387	et	4	main
kogunesid	doc_534729444731_item	3629374	et	4	main
eesti	doc_534729444731_item	3629372	et	4	main
tantsust	doc_534729444731_item	3629345	et	3	main
pillimängust	doc_534729444731_item	3629343	et	3	main
koosnes	doc_534729444731_item	3629341	et	3	main
rahvafolkloor	doc_534729444731_item	3629339	et	4	main
ja	doc_534729444731_item	3629338	et	3	main
rahvalaulud	doc_534729444731_item	3629337	et	3	main
eestlastel	doc_534729444731_item	3629336	et	4	main
sellele	doc_534729444731_item	3629334	et	4	main
loodusest	doc_534729444731_item	3629330	et	4	main
ja	doc_534729444731_item	3629328	et	3	main
sellepärast	doc_534729444731_item	3629323	et	3	main
eestlased	doc_534729444731_item	3629320	et	3	main
ja	doc_534729444727_item	3628860	et	3	main
lootuses	doc_534729444727_item	3628857	et	4	main
tullakse	doc_534729444727_item	3628854	et	3	main
tõestavad	doc_534729444727_item	3628846	et	4	main
huvitanud	doc_534729444727_item	3628830	et	4	main
noored	doc_534729444727_item	3628827	et	3	main
rahvuslik	doc_534729444727_item	3628807	et	3	main
mitte	doc_534729444727_item	3628805	et	3	main
on	doc_534729444727_item	3628804	et	4	main
laulupeo	doc_534729444727_item	3628803	et	4	main
ja	doc_534729444727_item	3628802	et	3	main
laulurahvas	doc_534729444727_item	3628801	et	4	main
on	doc_534729444727_item	3628800	et	4	main
eestlased	doc_534729444727_item	3628799	et	3	main
ajal	doc_534729444727_item	3628798	et	4	main
heal	doc_534729444727_item	3628797	et	3	main
kui	doc_534729444727_item	3628796	et	3	main
halval	doc_534729444727_item	3628795	et	3	main
nii	doc_534729444727_item	3628794	et	3	main
laulavad	doc_534729444727_item	3628793	et	4	main
ja	doc_534729444727_item	3628792	et	3	main
laulsid	doc_534729444727_item	3628791	et	4	main
nad	doc_534729444727_item	3628790	et	3	main
sama	doc_534729444727_item	3628789	et	4	main
nii	doc_534729444727_item	3628788	et	3	main
kurb	doc_534729444727_item	3628787	et	3	main
on	doc_534729444727_item	3628786	et	4	main
kui	doc_534729444727_item	3628785	et	3	main
ning	doc_534729444727_item	3628784	et	3	main
lõbus	doc_534729444727_item	3628783	et	4	main
on	doc_534729444727_item	3628782	et	4	main
nendele	doc_534729444727_item	3628781	et	4	main
kui	doc_534729444727_item	3628780	et	3	main
muusikat	doc_534729444727_item	3628779	et	3	main
kasutavad	doc_534729444727_item	3628778	et	4	main
ja	doc_534729444727_item	3628777	et	3	main
kasutasid	doc_534729444727_item	3628776	et	4	main
alati	doc_534729444727_item	3628775	et	4	main
inimesed	doc_534729444727_item	3628774	et	3	main
muusikat	doc_534729444727_item	3628773	et	3	main
ja	doc_534729444727_item	3628772	et	3	main
laulu	doc_534729444727_item	3628771	et	4	main
rahva	doc_534729444727_item	3628770	et	3	main
oma	doc_534729444727_item	3628769	et	4	main
ja	doc_534729444727_item	3628766	et	3	main
olnud	doc_534729444727_item	3628765	et	4	main
ei	doc_534729444727_item	3628764	et	4	main
kellel	doc_534729444727_item	3628763	et	4	main
rahvast	doc_534729444727_item	3628762	et	4	main
mäleta	doc_534729444727_item	3628761	et	4	main
ei	doc_534729444727_item	3628760	et	4	main
ajalugu	doc_534729444727_item	3628759	et	4	main
näidetega	doc_534729444727_item	3628758	et	3	main
illustreerida	doc_534729444727_item	3628757	et	3	main
soovitatav	doc_534729444727_item	3628756	et	4	main
on	doc_534729444727_item	3628755	et	4	main
väiteid	doc_534729444727_item	3628754	et	4	main
faktidele	doc_534729444727_item	3628753	et	3	main
esitatud	doc_534729444727_item	3628752	et	4	main
lugemistekstis	doc_534729444727_item	3628751	et	3	main
ja	doc_534729444727_item	3628750	et	3	main
loengus	doc_534729444727_item	3628749	et	3	main
tuginema	doc_534729444727_item	3628748	et	3	main
üldistav	doc_534729444727_item	3628747	et	4	main
ja	doc_534729444727_item	3628746	et	3	main
analüüsiv	doc_534729444727_item	3628745	et	4	main
arutlev	doc_534729444727_item	3628744	et	4	main
olema	doc_534729444727_item	3628743	et	4	main
peab	doc_534729444727_item	3628742	et	4	main
essee	doc_534729444727_item	3628741	et	4	main
sõna	doc_534729444727_item	3628740	et	4	main
350	doc_534729444727_item	3628739	et	2	main
300	doc_534729444727_item	3628738	et	2	main
pikkus	doc_534729444727_item	3628737	et	4	main
essee	doc_534729444727_item	3628736	et	4	main
laulurahva	doc_534729444727_item	3628735	et	3	main
eestlastest	doc_534729444727_item	3628734	et	4	main
teeb	doc_534729444727_item	3628733	et	3	main
mis	doc_534729444727_item	3628732	et	4	main
essee	doc_534729444727_item	3628730	et	4	main
kirjutamine	doc_534729444727_item	3628728	et	4	main
keele	doc_534729444727_item	3628726	et	4	main
teise	doc_534729444727_item	3628725	et	4	main
kui	doc_534729444727_item	3628724	et	3	main
ja	doc_534729444728_item	3628999	et	3	main
üldistav	doc_534729444728_item	3628996	et	4	main
analüüsiv	doc_534729444728_item	3628994	et	4	main
teeb	doc_534729444728_item	3628982	et	3	main
test	doc_534729444728_item	3628976	et	3	main
on	doc_534729444728_item	3629212	et	4	main
sest	doc_534729444728_item	3629204	et	4	main
nimetada	doc_534729444728_item	3629203	et	3	main
elustiil	doc_534729444728_item	3629195	et	4	main
aga	doc_534729444728_item	3629192	et	3	main
nii	doc_534729444728_item	3629155	et	3	main
korda	doc_534729444728_item	3629152	et	4	main
muusika	doc_534729444728_item	3629148	et	4	main
pilli	doc_534729444728_item	3629141	et	4	main
kooris	doc_534729444728_item	3629138	et	4	main
lauldi	doc_534729444728_item	3629137	et	3	main
kas	doc_534729444728_item	3629136	et	3	main
lapsepõlves	doc_534729444728_item	3629135	et	4	main
pärines	doc_534729444728_item	3629132	et	3	main
kudagi	doc_534729444728_item	3629123	et	4	main
või	doc_534729444728_item	3629122	et	4	main
kas	doc_534729444728_item	3629121	et	3	main
on	doc_534729444728_item	3629106	et	4	main
see	doc_534729444728_item	3629105	et	3	main
laulda	doc_534729444728_item	3629100	et	4	main
armastus	doc_534729444728_item	3629099	et	4	main
selline	doc_534729444728_item	3629098	et	4	main
palju	doc_534729444728_item	3629097	et	4	main
sümbol	doc_534729444728_item	3629091	et	3	main
ma	doc_534729444728_item	3629082	et	3	main
uusi	doc_534729444728_item	3629080	et	3	main
lootuses	doc_534729444728_item	3629078	et	4	main
sõpradega	doc_534729444728_item	3629076	et	3	main
tullakse	doc_534729444728_item	3629074	et	3	main
ühendab	doc_534729444728_item	3629068	et	3	main
koos	doc_534729444728_item	3629219	et	4	main
rahva	doc_534729444728_item	3629218	et	3	main
eesti	doc_534729444728_item	3629217	et	4	main
ühendab	doc_534729444728_item	3629216	et	3	main
on	doc_534729444728_item	3629004	et	4	main
loengus	doc_534729444728_item	3628998	et	3	main
keele	doc_534729444728_item	3628972	et	4	main
laul	doc_534729444728_item	3629210	et	4	main
elust	doc_534729444728_item	3629208	et	3	main
nende	doc_534729444728_item	3629207	et	4	main
eestlasi	doc_534729444728_item	3629200	et	3	main
on	doc_534729444728_item	3629194	et	4	main
see	doc_534729444728_item	3629193	et	3	main
vaid	doc_534729444728_item	3629189	et	3	main
ole	doc_534729444728_item	3629188	et	4	main
ei	doc_534729444728_item	3629187	et	4	main
laulupidu	doc_534729444728_item	3629186	et	4	main
arvatud	doc_534729444728_item	3629185	et	4	main
kaasa	doc_534729444728_item	3629184	et	4	main
ja	doc_534729444728_item	3629183	et	3	main
muusika	doc_534729444728_item	3629182	et	4	main
laul	doc_534729444728_item	3629181	et	4	main
jaoks	doc_534729444728_item	3629180	et	4	main
eestlaste	doc_534729444728_item	3629179	et	4	main
et	doc_534729444728_item	3629178	et	3	main
tundub	doc_534729444728_item	3629177	et	3	main
jõudu	doc_534729444728_item	3629176	et	4	main
annab	doc_534729444728_item	3629175	et	3	main
ja	doc_534729444728_item	3629174	et	3	main
heaks	doc_534729444728_item	3629173	et	4	main
tuju	doc_534729444728_item	3629172	et	4	main
teeb	doc_534729444728_item	3629171	et	3	main
laul	doc_534729444728_item	3629170	et	4	main
masenduses	doc_534729444728_item	3629169	et	4	main
või	doc_534729444728_item	3629168	et	4	main
kurb	doc_534729444728_item	3629167	et	3	main
oled	doc_534729444728_item	3629166	et	3	main
sa	doc_534729444728_item	3629165	et	3	main
kui	doc_534729444728_item	3629164	et	3	main
siis	doc_534729444728_item	3629163	et	3	main
aitab	doc_534729444728_item	3629162	et	3	main
laul	doc_534729444728_item	3629161	et	4	main
rokk-muusikat	doc_534729444728_item	3629160	et	3	main
ka	doc_534729444728_item	3629159	et	3	main
kui	doc_534729444728_item	3629158	et	3	main
laule	doc_534729444728_item	3629157	et	4	main
vana	doc_534729444728_item	3629156	et	4	main
see	doc_534729444728_item	3629215	et	3	main
ja	doc_534729444728_item	3629214	et	3	main
ongi	doc_534729444728_item	3629209	et	4	main
saab	doc_534729444728_item	3629201	et	3	main
et	doc_534729444728_item	3629199	et	3	main
ma	doc_534729444728_item	3629197	et	3	main
päeva	doc_534729444728_item	3629147	et	4	main
tänase	doc_534729444728_item	3629146	et	3	main
mängiti	doc_534729444728_item	3629140	et	3	main
see	doc_534729444728_item	3629131	et	3	main
seotud	doc_534729444728_item	3629125	et	4	main
olnud	doc_534729444728_item	3629124	et	4	main
on	doc_534729444728_item	3629120	et	4	main
palju	doc_534729444728_item	3629112	et	4	main
mul	doc_534729444728_item	3629110	et	3	main
tekkinud	doc_534729444728_item	3629102	et	4	main
lauluga	doc_534729444728_item	3629093	et	4	main
kuna	doc_534729444728_item	3629092	et	3	main
eesti	doc_534729444728_item	3629090	et	4	main
mitteametlik	doc_534729444728_item	3629089	et	3	main
nn	doc_534729444728_item	3629088	et	4	main
nii	doc_534729444728_item	3629069	et	3	main
rolli	doc_534729444728_item	3629055	et	4	main
elus	doc_534729444728_item	3629053	et	4	main
eestlaste	doc_534729444728_item	3629052	et	4	main
mängib	doc_534729444728_item	3629051	et	3	main
laul	doc_534729444728_item	3629050	et	4	main
see	doc_534729444728_item	3629044	et	3	main
ajal	doc_534729444728_item	3629043	et	4	main
suheldes	doc_534729444728_item	3629037	et	3	main
ongi	doc_534729444728_item	3629024	et	4	main
see	doc_534729444728_item	3629023	et	3	main
arust	doc_534729444728_item	3629022	et	4	main
laulurahvas	doc_534729444728_item	3629019	et	4	main
räägitakse	doc_534729444728_item	3629015	et	3	main
eestlastest	doc_534729444731_item	3629437	et	4	main
teeb	doc_534729444731_item	3629436	et	3	main
lühikeselt	doc_534729444731_item	3629432	et	4	main
noorus	doc_534729444731_item	3629420	et	4	main
erinevaid	doc_534729444731_item	3629414	et	4	main
sellepärast	doc_534729444731_item	3629397	et	3	main
venemaa	doc_534729444731_item	3629396	et	4	main
laulu	doc_534729444731_item	3629386	et	4	main
kes	doc_534729444731_item	3629377	et	4	main
laulupeod	doc_534729444731_item	3629373	et	4	main
kõrghetk	doc_534729444731_item	3629371	et	3	main
väga	doc_534729444731_item	3629354	et	3	main
see	doc_534729444731_item	3629352	et	3	main
toimus	doc_534729444731_item	3629348	et	3	main
looduse	doc_534729444731_item	3629331	et	4	main
kirjutasid	doc_534729444731_item	3629324	et	4	main
omad	doc_534729444731_item	3629286	et	4	main
nimetada	doc_534729444731_item	3629281	et	3	main
oma	doc_534729444731_item	3629275	et	4	main
inimesi	doc_534729444731_item	3629274	et	4	main
aitama	doc_534729444731_item	3629273	et	3	main
hakkab	doc_534729444731_item	3629272	et	3	main
mis	doc_534729444731_item	3629268	et	4	main
on	doc_534729444731_item	3629265	et	4	main
laul	doc_534729444731_item	3629263	et	4	main
laulurahva	doc_534729444731_item	3629262	et	3	main
näidetega	doc_534729444731_item	3629258	et	3	main
laul	doc_534729444735_item	3629741	et	4	main
ja	doc_534729444735_item	3629740	et	3	main
kombeid	doc_534729444735_item	3629647	et	4	main
rahvamuusika	doc_534729444735_item	3629638	et	4	main
folklooriga	doc_534729444735_item	3629626	et	4	main
eesti	doc_534729444735_item	3629616	et	4	main
kahjuks	doc_534729444735_item	3629606	et	4	main
vanad	doc_534729444735_item	3629605	et	3	main
naised	doc_534729444735_item	3629601	et	3	main
rikas	doc_534729444735_item	3629591	et	4	main
olen	doc_534729444735_item	3629573	et	3	main
armsaim	doc_534729444735_item	3629570	et	4	main
minu	doc_534729444735_item	3629569	et	3	main
ilusamad	doc_534729444735_item	3629563	et	4	main
kõige	doc_534729444735_item	3629562	et	4	main
täiskasvanutele	doc_534729444735_item	3629556	et	3	main
eesti	doc_534729444735_item	3629544	et	4	main
erinevad	doc_534729444735_item	3629530	et	4	main
raske	doc_534729444735_item	3629511	et	4	main
väga	doc_534729444735_item	3629510	et	3	main
ka	doc_534729444728_item	3629145	et	3	main
kui	doc_534729444728_item	3629144	et	3	main
rahvalaul	doc_534729444728_item	3629143	et	4	main
või	doc_534729444728_item	3629139	et	4	main
vanematest	doc_534729444728_item	3629133	et	4	main
tunnistasid	doc_534729444728_item	3629129	et	4	main
ise	doc_534729444728_item	3629127	et	4	main
nad	doc_534729444728_item	3629119	et	3	main
äkiliselt	doc_534729444728_item	3629104	et	4	main
eestis	doc_534729444728_item	3629103	et	3	main
on	doc_534729444728_item	3629094	et	4	main
perega	doc_534729444728_item	3629077	et	3	main
oma	doc_534729444728_item	3629075	et	4	main
koos	doc_534729444728_item	3629072	et	4	main
inimesi	doc_534729444728_item	3629071	et	4	main
mis	doc_534729444728_item	3629067	et	4	main
laulupeost	doc_534729444728_item	3629066	et	4	main
räägimata	doc_534729444728_item	3629065	et	4	main
seotud	doc_534729444728_item	3629064	et	4	main
muusikaga	doc_534729444728_item	3629063	et	3	main
on	doc_534729444728_item	3629062	et	4	main
mis	doc_534729444728_item	3629061	et	4	main
üritusi	doc_534729444728_item	3629060	et	4	main
palju	doc_534729444728_item	3629059	et	4	main
siin	doc_534729444728_item	3629058	et	4	main
toimub	doc_534729444728_item	3629057	et	3	main
siiamaani	doc_534729444728_item	3629056	et	3	main
ikkagi	doc_534729444728_item	3629049	et	4	main
nii	doc_534729444728_item	3629048	et	3	main
ole	doc_534729444728_item	3629047	et	4	main
kuigi	doc_534729444728_item	3629041	et	3	main
vana	doc_534729444728_item	3629029	et	4	main
ka	doc_534729444728_item	3629028	et	3	main
ümbritseb	doc_534729444731_item	3629445	et	3	main
mis	doc_534729444731_item	3629443	et	4	main
vastata	doc_534729444731_item	3629433	et	4	main
nad	doc_534729444731_item	3629426	et	3	main
muusikaürituseid	doc_534729444731_item	3629416	et	4	main
laulufestivale	doc_534729444731_item	3629415	et	3	main
rolli	doc_534729444731_item	3629411	et	4	main
mängib	doc_534729444731_item	3629409	et	3	main
ka	doc_534729444731_item	3629408	et	3	main
laul	doc_534729444731_item	3629407	et	4	main
tänapäeval	doc_534729444731_item	3629406	et	3	main
rahvaid	doc_534729444731_item	3629405	et	3	main
teisi	doc_534729444731_item	3629404	et	4	main
ühendas	doc_534729444731_item	3629403	et	3	main
ja	doc_534729444731_item	3629395	et	3	main
läti	doc_534729444731_item	3629394	et	4	main
ka	doc_534729444731_item	3629393	et	3	main
naabrid	doc_534729444731_item	3629392	et	3	main
ja	doc_534729444731_item	3629391	et	3	main
mängisid	doc_534729444731_item	3629390	et	4	main
leida	doc_534729444731_item	3629384	et	3	main
sõpru	doc_534729444731_item	3629383	et	3	main
uusi	doc_534729444731_item	3629382	et	3	main
ja	doc_534729444731_item	3629381	et	3	main
väljendada	doc_534729444731_item	3629380	et	3	main
ennast	doc_534729444731_item	3629379	et	4	main
inimesi	doc_534729444731_item	3629376	et	4	main
eesti	doc_534729444731_item	3629357	et	4	main
oluline	doc_534729444731_item	3629355	et	4	main
sajandil	doc_534729444731_item	3629351	et	3	main
xviii	doc_534729444731_item	3629350	et	4	main
eestis	doc_534729444731_item	3629349	et	3	main
tekkisid	doc_534729444731_item	3629335	et	4	main
looduslikult	doc_534729444731_item	3629315	et	4	main
rikkas	doc_534729444731_item	3629314	et	4	main
väga	doc_534729444731_item	3629313	et	3	main
on	doc_534729444731_item	3629285	et	4	main
meie	doc_534729444728_item	3629042	et	4	main
vahel	doc_534729444728_item	3629036	et	4	main
oma	doc_534729444728_item	3629035	et	4	main
olles	doc_534729444728_item	3629033	et	3	main
kas	doc_534729444728_item	3629031	et	3	main
ajal	doc_534729444728_item	3629030	et	4	main
minu	doc_534729444728_item	3629021	et	3	main
eestlased	doc_534729444728_item	3629017	et	3	main
poolt	doc_534729444728_item	3629014	et	4	main
armastuse	doc_534729444728_item	3629013	et	4	main
muusika	doc_534729444728_item	3629012	et	4	main
oma	doc_534729444728_item	3629011	et	4	main
tuntud	doc_534729444728_item	3629010	et	4	main
on	doc_534729444728_item	3629009	et	4	main
eestlased	doc_534729444728_item	3629008	et	3	main
näidetega	doc_534729444728_item	3629007	et	3	main
illustreerida	doc_534729444728_item	3629006	et	3	main
loomad	doc_534729444731_item	3629447	et	3	main
neid	doc_534729444731_item	3629444	et	4	main
kõik	doc_534729444731_item	3629442	et	4	main
et	doc_534729444731_item	3629441	et	3	main
öelda	doc_534729444731_item	3629440	et	4	main
võib	doc_534729444731_item	3629439	et	3	main
laulurahva	doc_534729444731_item	3629438	et	3	main
lõppus	doc_534729444731_item	3629430	et	4	main
armastavad	doc_534729444731_item	3629427	et	4	main
et	doc_534729444731_item	3629425	et	3	main
laulurahvas	doc_534729444731_item	3629423	et	4	main
ka	doc_534729444731_item	3629422	et	3	main
on	doc_534729444731_item	3629421	et	4	main
korraldatakse	doc_534729444731_item	3629413	et	3	main
eesti	doc_534729444731_item	3629401	et	4	main
et	doc_534729444731_item	3629400	et	3	main
rolli	doc_534729444731_item	3629389	et	4	main
suurt	doc_534729444731_item	3629388	et	3	main
tahtsid	doc_534729444731_item	3629378	et	4	main
laulupidu	doc_534729444731_item	3629347	et	4	main
ja	doc_534729444731_item	3629344	et	3	main
laulust	doc_534729444731_item	3629342	et	4	main
mis	doc_534729444731_item	3629340	et	4	main
kaunisest	doc_534729444731_item	3629332	et	4	main
laule	doc_534729444731_item	3629329	et	4	main
ja	doc_534729444731_item	3629322	et	3	main
nägid	doc_534729444731_item	3629318	et	4	main
on	doc_534729444731_item	3629312	et	4	main
eestimaa	doc_534729444731_item	3629311	et	4	main
sajandist	doc_534729444731_item	3629290	et	3	main
xix	doc_534729444731_item	3629289	et	4	main
juba	doc_534729444731_item	3629288	et	3	main
põhjused	doc_534729444731_item	3629287	et	3	main
laulurahvaks	doc_534729444731_item	3629282	et	3	main
tingimata	doc_534729444731_item	3629278	et	4	main
aitas	doc_534729444731_item	3629269	et	3	main
vahend	doc_534729444731_item	3629267	et	3	main
imeline	doc_534729444731_item	3629266	et	4	main
see	doc_534729444731_item	3629264	et	3	main
mis	doc_534729444731_item	3629259	et	4	main
eestlaste	doc_534729444735_item	3629744	et	4	main
laulavad	doc_534729444735_item	3629739	et	4	main
kõike	doc_534729444735_item	3629724	et	4	main
oma	doc_534729444735_item	3629723	et	4	main
eestis	doc_534729444735_item	3629651	et	3	main
sailitada	doc_534729444735_item	3629645	et	4	main
tõesti	doc_534729444735_item	3629636	et	3	main
palju	doc_534729444735_item	3629633	et	4	main
tänapäeval	doc_534729444735_item	3629631	et	3	main
et	doc_534729444735_item	3629630	et	3	main
see	doc_534729444735_item	3629629	et	3	main
vahva	doc_534729444735_item	3629628	et	4	main
on	doc_534729444735_item	3629627	et	4	main
leedu	doc_534729444735_item	3629623	et	4	main
läti	doc_534729444735_item	3629622	et	4	main
folkloor	doc_534729444735_item	3629617	et	4	main
töötades	doc_534729444728_item	3629034	et	3	main
üksi	doc_534729444728_item	3629032	et	4	main
ja	doc_534729444728_item	3629020	et	3	main
tundeid	doc_534729444731_item	3629457	et	3	main
hingeliseid	doc_534729444731_item	3629456	et	4	main
oma	doc_534729444731_item	3629455	et	4	main
väljendades	doc_534729444731_item	3629454	et	3	main
niimodi	doc_534729444731_item	3629453	et	4	main
kõigest	doc_534729444731_item	3629452	et	4	main
sellest	doc_534729444731_item	3629451	et	4	main
laulavad	doc_534729444731_item	3629450	et	4	main
nad	doc_534729444731_item	3629449	et	3	main
küsimusele	doc_534729444731_item	3629434	et	4	main
kui	doc_534729444731_item	3629429	et	3	main
muusikat	doc_534729444731_item	3629428	et	3	main
sest	doc_534729444731_item	3629424	et	4	main
kaasaegne	doc_534729444731_item	3629418	et	3	main
laul	doc_534729444731_item	3629402	et	4	main
eesti	doc_534729444731_item	3629385	et	4	main
palju	doc_534729444731_item	3629375	et	4	main
liikumise	doc_534729444731_item	3629370	et	4	main
rahvusliku	doc_534729444731_item	3629369	et	3	main
eestlaste	doc_534729444731_item	3629368	et	4	main
kujunes	doc_534729444731_item	3629367	et	3	main
sellest	doc_534729444731_item	3629366	et	4	main
et	doc_534729444731_item	3629365	et	3	main
selles	doc_534729444731_item	3629364	et	4	main
oli	doc_534729444731_item	3629363	et	3	main
tähtsus	doc_534729444731_item	3629362	et	4	main
laulupeo	doc_534729444731_item	3629361	et	4	main
esimese	doc_534729444731_item	3629360	et	3	main
selle	doc_534729444731_item	3629359	et	4	main
elus	doc_534729444731_item	3629358	et	4	main
sündmus	doc_534729444731_item	3629356	et	3	main
oli	doc_534729444731_item	3629353	et	3	main
esimene	doc_534729444731_item	3629346	et	3	main
tänu	doc_534729444731_item	3629333	et	4	main
jutustusi	doc_534729444731_item	3629327	et	4	main
erinevaid	doc_534729444731_item	3629326	et	4	main
nad	doc_534729444731_item	3629325	et	3	main
ise	doc_534729444731_item	3629321	et	4	main
ka	doc_534729444731_item	3629319	et	3	main
seda	doc_534729444731_item	3629317	et	3	main
elada	doc_534729444731_item	3629310	et	3	main
aitas	doc_534729444731_item	3629309	et	3	main
jõudu	doc_534729444731_item	3629308	et	4	main
moraalseid	doc_534729444731_item	3629307	et	3	main
naistele	doc_534729444731_item	3629306	et	3	main
andis	doc_534729444731_item	3629305	et	3	main
laul	doc_534729444731_item	3629304	et	4	main
töötades	doc_534729444731_item	3629303	et	3	main
kiigutades	doc_534729444731_item	3629302	et	3	main
lapsi	doc_534729444731_item	3629301	et	4	main
olles	doc_534729444731_item	3629300	et	3	main
kirikus	doc_534729444731_item	3629299	et	3	main
alati	doc_534729444731_item	3629298	et	4	main
peaaegu	doc_534729444731_item	3629297	et	3	main
laulsid	doc_534729444731_item	3629296	et	4	main
naised	doc_534729444731_item	3629295	et	3	main
eesti	doc_534729444731_item	3629294	et	4	main
rahvalaulust	doc_534729444731_item	3629293	et	4	main
maa	doc_534729444731_item	3629316	et	4	main
eestis	doc_534729444731_item	3629292	et	3	main
räägiti	doc_534729444731_item	3629291	et	3	main
selle	doc_534729444731_item	3629283	et	4	main
aitab	doc_534729444731_item	3629270	et	3	main
teeb	doc_534729444731_item	3629260	et	3	main
praktiliselt	doc_534729444735_item	3629743	et	4	main
koos	doc_534729444735_item	3629726	et	4	main
pereliikmetega	doc_534729444735_item	3629725	et	3	main
meie	doc_534729444735_item	3629646	et	4	main
meeldib	doc_534729444735_item	3629637	et	3	main
soome	doc_534729444735_item	3629625	et	3	main
on	doc_534729444735_item	3629618	et	4	main
või	doc_534729444735_item	3629614	et	4	main
lapsed	doc_534729444735_item	3629603	et	3	main
mehed	doc_534729444735_item	3629602	et	3	main
laulis	doc_534729444735_item	3629598	et	4	main
tantsis	doc_534729444735_item	3629596	et	4	main
vanasti	doc_534729444735_item	3629595	et	3	main
tantsud	doc_534729444735_item	3629593	et	3	main
laulud	doc_534729444735_item	3629592	et	3	main
ka	doc_534729444735_item	3629589	et	3	main
on	doc_534729444735_item	3629566	et	4	main
lastele	doc_534729444735_item	3629559	et	4	main
ka	doc_534729444735_item	3629558	et	3	main
head	doc_534729444735_item	3629551	et	4	main
päev	doc_534729444735_item	3629543	et	3	main
kogu	doc_534729444735_item	3629542	et	4	main
eestlased	doc_534729444735_item	3629541	et	3	main
ja	doc_534729444735_item	3629529	et	3	main
muusika	doc_534729444735_item	3629528	et	4	main
oli	doc_534729444735_item	3629519	et	3	main
töötada	doc_534729444735_item	3629516	et	3	main
palju	doc_534729444735_item	3629515	et	4	main
vanasti	doc_534729444735_item	3629506	et	3	main
eesti	doc_534729444735_item	3629501	et	4	main
eestlastest	doc_534729444735_item	3629499	et	4	main
teeb	doc_534729444735_item	3629498	et	3	main
mis	doc_534729444735_item	3629470	et	4	main
teemal	doc_534729444735_item	3629469	et	3	main
essee	doc_534729444735_item	3629468	et	4	main
kirjutage	doc_534729444735_item	3629467	et	3	main
keele	doc_534729444735_item	3629461	et	4	main
vallandavad	doc_534729444735_item	3629702	et	4	main
muidugi	doc_534729444735_item	3629700	et	4	main
ja	doc_534729444735_item	3629699	et	3	main
ja	doc_534729444735_item	3629691	et	3	main
rahvaks	doc_534729444735_item	3629690	et	3	main
üritus	doc_534729444735_item	3629677	et	4	main
tuntum	doc_534729444735_item	3629675	et	4	main
ja	doc_534729444735_item	3629674	et	3	main
ilusam	doc_534729444735_item	3629673	et	4	main
palju	doc_534729444735_item	3629669	et	4	main
rahvamuusika	doc_534729444735_item	3629664	et	4	main
ka	doc_534729444735_item	3629662	et	3	main
erinevad	doc_534729444735_item	3629653	et	4	main
on	doc_534729444735_item	3629652	et	4	main
jaoks	doc_534729444731_item	3629284	et	4	main
eestlaseid	doc_534729444731_item	3629279	et	3	main
ja	doc_534729444731_item	3629271	et	3	main
võib	doc_534729444731_item	3629280	et	3	main
väljendada	doc_534729444731_item	3629277	et	3	main
tundeid	doc_534729444731_item	3629276	et	3	main
eestlastest	doc_534729444731_item	3629261	et	4	main
illustreerida	doc_534729444731_item	3629257	et	3	main
soovitatav	doc_534729444731_item	3629256	et	4	main
on	doc_534729444731_item	3629255	et	4	main
väiteid	doc_534729444731_item	3629254	et	4	main
faktidele	doc_534729444731_item	3629253	et	3	main
esitatud	doc_534729444731_item	3629252	et	4	main
lugemistekstis	doc_534729444731_item	3629251	et	3	main
ja	doc_534729444731_item	3629250	et	3	main
olema	doc_534729444731_item	3629243	et	4	main
peab	doc_534729444731_item	3629242	et	4	main
essee	doc_534729444731_item	3629241	et	4	main
sõna	doc_534729444731_item	3629240	et	4	main
350	doc_534729444731_item	3629239	et	2	main
300	doc_534729444731_item	3629238	et	2	main
pikkus	doc_534729444731_item	3629237	et	4	main
essee	doc_534729444731_item	3629236	et	4	main
laulurahva	doc_534729444731_item	3629235	et	3	main
teeb	doc_534729444731_item	3629233	et	3	main
mis	doc_534729444731_item	3629232	et	4	main
teemal	doc_534729444731_item	3629231	et	3	main
eestlastest	doc_534729444731_item	3629234	et	4	main
essee	doc_534729444731_item	3629230	et	4	main
kirjutage	doc_534729444731_item	3629229	et	3	main
kirjutamine	doc_534729444731_item	3629228	et	4	main
test	doc_534729444731_item	3629227	et	3	main
keele	doc_534729444731_item	3629226	et	4	main
teise	doc_534729444731_item	3629225	et	4	main
kui	doc_534729444731_item	3629224	et	3	main
keele	doc_534729444731_item	3629223	et	4	main
eesti	doc_534729444731_item	3629222	et	4	main
essee	doc_534729444731_item	3629221	et	4	main
loengus	doc_534729444731_item	3629249	et	3	main
tuginema	doc_534729444731_item	3629248	et	3	main
üldistav	doc_534729444731_item	3629247	et	4	main
ja	doc_534729444731_item	3629246	et	3	main
analüüsiv	doc_534729444731_item	3629245	et	4	main
arutlev	doc_534729444731_item	3629244	et	4	main
sümbol	doc_534729444735_item	3629745	et	3	main
meelsasti	doc_534729444735_item	3629738	et	3	main
inimesed	doc_534729444735_item	3629737	et	3	main
on	doc_534729444735_item	3629742	et	4	main
kohas	doc_534729444735_item	3629734	et	4	main
ajalugu	doc_534729444735_item	3629649	et	4	main
ja	doc_534729444735_item	3629648	et	3	main
eesti	doc_534729444735_item	3629640	et	4	main
ja	doc_534729444735_item	3629639	et	3	main
kellele	doc_534729444735_item	3629635	et	4	main
folkloori	doc_534729444735_item	3629611	et	4	main
tõelist	doc_534729444735_item	3629610	et	4	main
leida	doc_534729444735_item	3629609	et	3	main
saab	doc_534729444735_item	3629608	et	3	main
praegu	doc_534729444735_item	3629607	et	3	main
väga	doc_534729444735_item	3629590	et	3	main
on	doc_534729444735_item	3629588	et	4	main
ajalugu	doc_534729444735_item	3629587	et	4	main
folkloori	doc_534729444735_item	3629586	et	4	main
eesti	doc_534729444735_item	3629585	et	4	main
aasta	doc_534729444735_item	3629584	et	4	main
uus	doc_534729444735_item	3629583	et	3	main
iga	doc_534729444735_item	3629582	et	4	main
meelde	doc_534729444735_item	3629581	et	3	main
see	doc_534729444735_item	3629580	et	3	main
tuleb	doc_534729444735_item	3629579	et	3	main
ja	doc_534729444735_item	3629578	et	3	main
koolis	doc_534729444735_item	3629577	et	4	main
seda	doc_534729444735_item	3629575	et	3	main
veel	doc_534729444735_item	3629576	et	4	main
nii	doc_534729444735_item	3629555	et	3	main
juhtusid	doc_534729444735_item	3629537	et	4	main
lõbusad	doc_534729444735_item	3629535	et	3	main
neid	doc_534729444735_item	3629533	et	4	main
aitasid	doc_534729444735_item	3629532	et	4	main
laulud	doc_534729444735_item	3629531	et	3	main
väga	doc_534729444735_item	3629520	et	3	main
vaja	doc_534729444735_item	3629514	et	4	main
oli	doc_534729444735_item	3629513	et	3	main
ja	doc_534729444735_item	3629512	et	3	main
on	doc_534729444735_item	3629503	et	4	main
essee	doc_534729444735_item	3629474	et	4	main
eestlastest	doc_534729444735_item	3629472	et	4	main
teise	doc_534729444735_item	3629463	et	4	main
laulupeod	doc_534729444735_item	3629701	et	4	main
nendele	doc_534729444735_item	3629693	et	4	main
annavad	doc_534729444735_item	3629692	et	3	main
üheks	doc_534729444735_item	3629689	et	3	main
ja	doc_534729444735_item	3629685	et	3	main
erinevad	doc_534729444735_item	3629683	et	4	main
näitavad	doc_534729444735_item	3629681	et	4	main
lauljaid	doc_534729444735_item	3629671	et	4	main
meeldib	doc_534729444735_item	3629663	et	3	main
tänapäevastele	doc_534729444735_item	3629660	et	4	main
teematilisi	doc_534729444735_item	3629658	et	4	main
teevad	doc_534729444735_item	3629657	et	3	main
on	doc_534729444738_item	3630067	et	4	main
ja	doc_534729444738_item	3630064	et	3	main
see	doc_534729444738_item	3630062	et	3	main
kuidas	doc_534729444738_item	3630060	et	3	main
asi	doc_534729444738_item	3630058	et	4	main
tore	doc_534729444738_item	3630057	et	3	main
sellele	doc_534729444738_item	3629967	et	4	main
inimestega	doc_534729444738_item	3629966	et	3	main
sümbol	doc_534729444738_item	3629949	et	3	main
aeg	doc_534729444738_item	3629942	et	3	main
on	doc_534729444738_item	3629936	et	4	main
asi	doc_534729444738_item	3629934	et	4	main
see	doc_534729444738_item	3629933	et	3	main
säilitavad	doc_534729444738_item	3629924	et	4	main
ja	doc_534729444738_item	3629923	et	3	main
laulud	doc_534729444738_item	3629922	et	3	main
vanad	doc_534729444738_item	3629921	et	3	main
kõik	doc_534729444735_item	3629736	et	4	main
kus	doc_534729444735_item	3629735	et	3	main
niisuguses	doc_534729444735_item	3629733	et	3	main
elan	doc_534729444735_item	3629732	et	3	main
et	doc_534729444735_item	3629731	et	3	main
see	doc_534729444735_item	3629730	et	3	main
meeldib	doc_534729444735_item	3629729	et	3	main
väga	doc_534729444735_item	3629728	et	3	main
mulle	doc_534729444735_item	3629727	et	4	main
veel	doc_534729444735_item	3629650	et	4	main
aitavad	doc_534729444735_item	3629644	et	4	main
inimesed	doc_534729444735_item	3629643	et	3	main
need	doc_534729444735_item	3629642	et	3	main
kunst	doc_534729444735_item	3629641	et	3	main
folkloorrühmi	doc_534729444735_item	3629634	et	4	main
on	doc_534729444735_item	3629632	et	4	main
ja	doc_534729444735_item	3629624	et	3	main
vene	doc_534729444735_item	3629621	et	4	main
seotud	doc_534729444735_item	3629620	et	4	main
ka	doc_534729444735_item	3629619	et	3	main
setumaal	doc_534729444735_item	3629615	et	4	main
kihnus	doc_534729444735_item	3629613	et	3	main
noored	doc_534729444735_item	3629604	et	3	main
inimene	doc_534729444735_item	3629600	et	3	main
õppinud	doc_534729444735_item	3629574	et	4	main
aisakell	doc_534729444735_item	3629572	et	3	main
on	doc_534729444735_item	3629571	et	4	main
näiteks	doc_534729444735_item	3629568	et	4	main
jõululaulud	doc_534729444735_item	3629567	et	3	main
arvates	doc_534729444735_item	3629561	et	4	main
minu	doc_534729444735_item	3629560	et	3	main
meeldivad	doc_534729444735_item	3629554	et	4	main
meeleolut	doc_534729444735_item	3629552	et	4	main
annavad	doc_534729444735_item	3629550	et	3	main
tantsisid	doc_534729444735_item	3629540	et	4	main
ja	doc_534729444735_item	3629539	et	3	main
peod	doc_534729444735_item	3629536	et	4	main
mitmekesiseks	doc_534729444735_item	3629527	et	4	main
seda	doc_534729444735_item	3629526	et	3	main
teha	doc_534729444735_item	3629525	et	3	main
tahtsid	doc_534729444735_item	3629524	et	4	main
nad	doc_534729444735_item	3629523	et	3	main
ja	doc_534729444735_item	3629522	et	3	main
igav	doc_534729444735_item	3629521	et	3	main
elu	doc_534729444735_item	3629508	et	4	main
ajalugu	doc_534729444735_item	3629505	et	4	main
vana	doc_534729444735_item	3629504	et	4	main
laulurahva	doc_534729444735_item	3629500	et	3	main
mis	doc_534729444735_item	3629497	et	4	main
kirjutamine	doc_534729444735_item	3629466	et	4	main
test	doc_534729444735_item	3629465	et	3	main
keele	doc_534729444735_item	3629464	et	4	main
eesti	doc_534729444735_item	3629460	et	4	main
seda	doc_534729444735_item	3629722	et	3	main
inimesed	doc_534729444735_item	3629720	et	3	main
eestis	doc_534729444735_item	3629719	et	3	main
populaarne	doc_534729444735_item	3629718	et	3	main
rahvuslikke	doc_534729444735_item	3629703	et	3	main
teevad	doc_534729444735_item	3629687	et	3	main
et	doc_534729444735_item	3629682	et	3	main
laulupeod	doc_534729444735_item	3629680	et	4	main
laulupidu	doc_534729444735_item	3629679	et	4	main
eesti	doc_534729444735_item	3629676	et	4	main
praegu	doc_534729444735_item	3629667	et	3	main
on	doc_534729444735_item	3629666	et	4	main
üritusi	doc_534729444735_item	3629659	et	4	main
loodan	doc_534729444738_item	3630070	et	3	main
kui	doc_534729444738_item	3630065	et	3	main
alganud	doc_534729444738_item	3630063	et	4	main
aastast	doc_534729444738_item	3629975	et	4	main
niimoodi	doc_534729444738_item	3629961	et	3	main
armastab	doc_534729444738_item	3629958	et	3	main
koos	doc_534729444738_item	3629955	et	4	main
olla	doc_534729444738_item	3629954	et	3	main
inimestele	doc_534729444738_item	3629953	et	3	main
aitab	doc_534729444738_item	3629952	et	3	main
mis	doc_534729444738_item	3629951	et	4	main
tähtis	doc_534729444738_item	3629937	et	4	main
ainult	doc_534729444735_item	3629612	et	4	main
iga	doc_534729444735_item	3629599	et	4	main
ja	doc_534729444735_item	3629597	et	3	main
muinasjutud	doc_534729444735_item	3629594	et	3	main
lõbusamad	doc_534729444735_item	3629565	et	4	main
ja	doc_534729444735_item	3629564	et	3	main
kui	doc_534729444735_item	3629557	et	3	main
nad	doc_534729444735_item	3629553	et	3	main
alati	doc_534729444735_item	3629549	et	4	main
ja	doc_534729444735_item	3629548	et	3	main
rõõmsameelsed	doc_534729444735_item	3629547	et	3	main
on	doc_534729444735_item	3629546	et	4	main
laulud	doc_534729444735_item	3629545	et	3	main
laulsid	doc_534729444735_item	3629538	et	4	main
kui	doc_534729444735_item	3629534	et	3	main
elu	doc_534729444735_item	3629518	et	4	main
eestlaste	doc_534729444735_item	3629517	et	4	main
kui	doc_534729444735_item	3629507	et	3	main
näidetega	doc_534729444735_item	3629496	et	3	main
illustreerida	doc_534729444735_item	3629495	et	3	main
soovitatav	doc_534729444735_item	3629494	et	4	main
on	doc_534729444735_item	3629493	et	4	main
väiteid	doc_534729444735_item	3629492	et	4	main
faktidele	doc_534729444735_item	3629491	et	3	main
esitatud	doc_534729444735_item	3629490	et	4	main
lugemistekstis	doc_534729444735_item	3629489	et	3	main
ja	doc_534729444735_item	3629488	et	3	main
loengus	doc_534729444735_item	3629487	et	3	main
tuginema	doc_534729444735_item	3629486	et	3	main
üldistav	doc_534729444735_item	3629485	et	4	main
ja	doc_534729444735_item	3629484	et	3	main
analüüsiv	doc_534729444735_item	3629483	et	4	main
arutlev	doc_534729444735_item	3629482	et	4	main
olema	doc_534729444735_item	3629481	et	4	main
peab	doc_534729444735_item	3629480	et	4	main
essee	doc_534729444735_item	3629479	et	4	main
sõna	doc_534729444735_item	3629478	et	4	main
350	doc_534729444735_item	3629477	et	2	main
300	doc_534729444735_item	3629476	et	2	main
pikkus	doc_534729444735_item	3629475	et	4	main
oli	doc_534729444735_item	3629509	et	3	main
muusikal	doc_534729444735_item	3629502	et	4	main
niisugune	doc_534729444735_item	3629705	et	3	main
tundeid	doc_534729444735_item	3629704	et	3	main
rahulikult	doc_534729444735_item	3629696	et	4	main
elada	doc_534729444735_item	3629695	et	3	main
jõusid	doc_534729444735_item	3629694	et	4	main
tantsud	doc_534729444735_item	3629686	et	3	main
laulud	doc_534729444735_item	3629684	et	3	main
kõige	doc_534729444735_item	3629672	et	4	main
väga	doc_534729444735_item	3629668	et	3	main
eestis	doc_534729444735_item	3629665	et	3	main
noortele	doc_534729444735_item	3629661	et	3	main
me	doc_534729444738_item	3630072	et	4	main
et	doc_534729444738_item	3630071	et	3	main
ma	doc_534729444738_item	3630069	et	3	main
laulma	doc_534729444738_item	3630048	et	3	main
on	doc_534729444738_item	3629969	et	4	main
eestis	doc_534729444738_item	3629968	et	3	main
teiste	doc_534729444738_item	3629965	et	4	main
laulda	doc_534729444738_item	3629964	et	4	main
ühiks	doc_534729444738_item	3629960	et	4	main
eestlane	doc_534729444738_item	3629957	et	3	main
eesti	doc_534729444738_item	3629948	et	4	main
see	doc_534729444738_item	3629945	et	3	main
peol	doc_534729444738_item	3629944	et	4	main
igal	doc_534729444738_item	3629943	et	3	main
laul	doc_534729444738_item	3629930	et	4	main
nende	doc_534729444738_item	3629927	et	4	main
et	doc_534729444738_item	3629926	et	3	main
neid	doc_534729444738_item	3629925	et	4	main
taha	doc_534729444738_item	3629914	et	4	main
ei	doc_534729444738_item	3629913	et	4	main
laulu	doc_534729444738_item	3629905	et	4	main
tõuseb	doc_534729444738_item	3629889	et	3	main
on	doc_534729444738_item	3629881	et	4	main
koos	doc_534729444738_item	3629874	et	4	main
mis	doc_534729444738_item	3629871	et	4	main
see	doc_534729444738_item	3629870	et	3	main
on	doc_534729444738_item	3629860	et	4	main
see	doc_534729444738_item	3629859	et	3	main
teine	doc_534729444738_item	3629835	et	3	main
jah	doc_534729444738_item	3629832	et	3	main
see	doc_534729444738_item	3629830	et	3	main
on	doc_534729444738_item	3629829	et	4	main
kõigepealt	doc_534729444738_item	3629828	et	3	main
et	doc_534729444738_item	3629827	et	3	main
ja	doc_534729444738_item	3629821	et	3	main
eestlastest	doc_534729444738_item	3629819	et	4	main
laulmiseta	doc_534729444738_item	3629810	et	4	main
elada	doc_534729444738_item	3629809	et	3	main
mõtelda	doc_534729444738_item	3629805	et	4	main
ole	doc_534729444738_item	3629802	et	4	main
et	doc_534729444738_item	3629800	et	3	main
tuginema	doc_534729444738_item	3629774	et	3	main
analüüsiv	doc_534729444738_item	3629771	et	4	main
arutlev	doc_534729444738_item	3629770	et	4	main
essee	doc_534729444738_item	3629767	et	4	main
pikkus	doc_534729444738_item	3629763	et	4	main
kui	doc_534729444738_item	3629750	et	3	main
eesti	doc_534729444738_item	3629748	et	4	main
proovivad	doc_534729444738_item	3630043	et	4	main
aga	doc_534729444738_item	3630041	et	3	main
vanal	doc_534729444738_item	3630039	et	3	main
on	doc_534729444738_item	3630030	et	4	main
lapsele	doc_534729444738_item	3630021	et	4	main
oma	doc_534729444738_item	3630020	et	4	main
on	doc_534729444738_item	3630014	et	4	main
ainult	doc_534729444738_item	3630006	et	4	main
tehtud	doc_534729444738_item	3630002	et	4	main
hästi	doc_534729444738_item	3629994	et	3	main
väga	doc_534729444738_item	3629993	et	3	main
laulurahva	doc_534729444735_item	3629473	et	3	main
teeb	doc_534729444735_item	3629471	et	3	main
kui	doc_534729444735_item	3629462	et	3	main
essee	doc_534729444735_item	3629459	et	4	main
külastavad	doc_534729444735_item	3629721	et	4	main
väga	doc_534729444735_item	3629717	et	3	main
on	doc_534729444735_item	3629716	et	4	main
praegu	doc_534729444735_item	3629715	et	3	main
ja	doc_534729444735_item	3629714	et	3	main
oli	doc_534729444735_item	3629713	et	3	main
alati	doc_534729444735_item	3629712	et	4	main
tegevus	doc_534729444735_item	3629711	et	4	main
sotsiaalne	doc_534729444735_item	3629710	et	3	main
ilus	doc_534729444735_item	3629709	et	4	main
väga	doc_534729444735_item	3629708	et	3	main
ja	doc_534729444735_item	3629707	et	3	main
meeldiv	doc_534729444735_item	3629706	et	4	main
õnnelikult	doc_534729444735_item	3629698	et	4	main
ja	doc_534729444735_item	3629697	et	3	main
eestlasi	doc_534729444735_item	3629688	et	3	main
on	doc_534729444735_item	3629678	et	4	main
noori	doc_534729444735_item	3629670	et	3	main
mis	doc_534729444735_item	3629656	et	4	main
ansamblid	doc_534729444735_item	3629655	et	3	main
muusikaalised	doc_534729444735_item	3629654	et	3	main
rahvamuusika	doc_534729444738_item	3630068	et	4	main
kõik	doc_534729444738_item	3630061	et	4	main
mäletada	doc_534729444738_item	3630059	et	3	main
on	doc_534729444738_item	3630056	et	4	main
see	doc_534729444738_item	3630055	et	3	main
et	doc_534729444738_item	3630054	et	3	main
arvan	doc_534729444738_item	3630053	et	3	main
ma	doc_534729444738_item	3630052	et	3	main
ja	doc_534729444738_item	3630051	et	3	main
laulad	doc_534729444738_item	3630050	et	3	main
1869	doc_534729444738_item	3629974	et	2	main
toimub	doc_534729444738_item	3629973	et	3	main
mis	doc_534729444738_item	3629972	et	4	main
asi	doc_534729444738_item	3629950	et	4	main
on	doc_534729444738_item	3629946	et	4	main
tutvustada	doc_534729444738_item	3629929	et	3	main
mäletavad	doc_534729444738_item	3629920	et	4	main
läbi	doc_534729444738_item	3629917	et	4	main
traditsiooni	doc_534729444738_item	3629916	et	4	main
nende	doc_534729444738_item	3629915	et	4	main
selle	doc_534729444738_item	3629910	et	4	main
teisel	doc_534729444738_item	3629899	et	4	main
ja	doc_534729444738_item	3629897	et	3	main
peol	doc_534729444738_item	3629896	et	4	main
sõbradega	doc_534729444738_item	3629895	et	4	main
rõõmustab	doc_534729444738_item	3629894	et	3	main
laulmine	doc_534729444738_item	3629887	et	4	main
lapsed	doc_534729444738_item	3629883	et	3	main
koos	doc_534729444738_item	3629878	et	4	main
elab	doc_534729444738_item	3629876	et	3	main
on	doc_534729444738_item	3629869	et	4	main
asi	doc_534729444738_item	3629862	et	4	main
ja	doc_534729444738_item	3629858	et	3	main
inimese	doc_534729444738_item	3629854	et	4	main
iga	doc_534729444738_item	3629853	et	4	main
ajal	doc_534729444738_item	3630087	et	4	main
meie	doc_534729444738_item	3630086	et	4	main
vaja	doc_534729444738_item	3630085	et	4	main
nii	doc_534729444738_item	3630084	et	3	main
on	doc_534729444738_item	3630083	et	4	main
mis	doc_534729444738_item	3630082	et	4	main
armastust	doc_534729444738_item	3630081	et	4	main
toovad	doc_534729444738_item	3630080	et	4	main
laulud	doc_534729444738_item	3630079	et	3	main
need	doc_534729444738_item	3630078	et	3	main
sest	doc_534729444738_item	3630077	et	4	main
tulevikul	doc_534729444738_item	3630076	et	4	main
seda	doc_534729444738_item	3630075	et	3	main
mäletada	doc_534729444738_item	3630074	et	3	main
hakkame	doc_534729444738_item	3630073	et	3	main
ilus	doc_534729444738_item	3630066	et	4	main
vanad	doc_534729444738_item	3630049	et	3	main
ajalugu	doc_534729444738_item	3630047	et	4	main
laulu	doc_534729444738_item	3630046	et	4	main
oma	doc_534729444738_item	3630045	et	4	main
mäletada	doc_534729444738_item	3630044	et	3	main
teab	doc_534729444738_item	3629992	et	3	main
igaüks	doc_534729444738_item	3629991	et	3	main
mis	doc_534729444738_item	3629990	et	4	main
laulu	doc_534729444738_item	3629989	et	4	main
laulavad	doc_534729444738_item	3629988	et	4	main
ja	doc_534729444738_item	3629987	et	3	main
perega	doc_534729444738_item	3629986	et	3	main
oma	doc_534729444738_item	3629985	et	4	main
tulevad	doc_534729444738_item	3629984	et	4	main
inimesed	doc_534729444738_item	3629983	et	3	main
kus	doc_534729444738_item	3629982	et	3	main
pidu	doc_534729444738_item	3629981	et	4	main
tore	doc_534729444738_item	3629980	et	3	main
väga	doc_534729444738_item	3629979	et	3	main
on	doc_534729444738_item	3629978	et	4	main
see	doc_534729444738_item	3629977	et	3	main
praeguni	doc_534729444738_item	3629976	et	4	main
laulupidu	doc_534729444738_item	3629971	et	4	main
suur	doc_534729444738_item	3629970	et	3	main
ta	doc_534729444738_item	3629963	et	4	main
armastab	doc_534729444738_item	3629962	et	3	main
laulda	doc_534729444738_item	3629959	et	4	main
kui	doc_534729444738_item	3629956	et	3	main
suur	doc_534729444738_item	3629947	et	3	main
alati	doc_534729444738_item	3629941	et	4	main
on	doc_534729444738_item	3629940	et	4	main
millele	doc_534729444738_item	3629939	et	3	main
igaühele	doc_534729444738_item	3629938	et	3	main
lapsed	doc_534729444738_item	3629928	et	3	main
nad	doc_534729444738_item	3629919	et	3	main
pärast	doc_534729444738_item	3629911	et	4	main
ajal	doc_534729444738_item	3629900	et	4	main
hommikul	doc_534729444738_item	3629890	et	3	main
vanadele	doc_534729444738_item	3629885	et	3	main
kuni	doc_534729444738_item	3629884	et	3	main
nende	doc_534729444738_item	3629877	et	4	main
ja	doc_534729444738_item	3629875	et	3	main
laulmine	doc_534729444738_item	3629867	et	4	main
laulurahva	doc_534729444738_item	3629866	et	3	main
nende	doc_534729444738_item	3629865	et	4	main
teeb	doc_534729444738_item	3629864	et	3	main
mis	doc_534729444738_item	3629863	et	4	main
ja	doc_534729444738_item	3629856	et	3	main
küll	doc_534729444738_item	3629826	et	4	main
proovin	doc_534729444738_item	3629823	et	3	main
laulurahva	doc_534729444738_item	3629820	et	3	main
teeb	doc_534729444738_item	3629818	et	3	main
kuidas	doc_534729444738_item	3629806	et	3	main
esitatud	doc_534729444738_item	3629778	et	4	main
lugemistekstis	doc_534729444738_item	3629777	et	3	main
ja	doc_534729444738_item	3629776	et	3	main
üldistav	doc_534729444738_item	3629773	et	4	main
essee	doc_534729444738_item	3629762	et	4	main
laulurahva	doc_534729444738_item	3629761	et	3	main
keele	doc_534729444738_item	3629752	et	4	main
keele	doc_534729444738_item	3629749	et	4	main
kelle	doc_534729444738_item	3630034	et	4	main
ansambli	doc_534729444738_item	3630033	et	3	main
mis	doc_534729444738_item	3629935	et	4	main
on	doc_534729444738_item	3629932	et	4	main
eestis	doc_534729444738_item	3629931	et	3	main
muretsevad	doc_534729444738_item	3629909	et	4	main
ja	doc_534729444738_item	3629907	et	3	main
igal	doc_534729444738_item	3629898	et	3	main
kui	doc_534729444738_item	3629888	et	3	main
ajadele	doc_534729444738_item	3629886	et	4	main
ainult	doc_534729444738_item	3629882	et	4	main
need	doc_534729444738_item	3629880	et	3	main
nende	doc_534729444738_item	3629873	et	4	main
sündib	doc_534729444738_item	3629872	et	4	main
eestlasele	doc_534729444738_item	3629868	et	3	main
üks	doc_534729444738_item	3629861	et	3	main
hingades	doc_534729444738_item	3629857	et	4	main
südames	doc_534729444738_item	3629855	et	3	main
aeg	doc_534729444738_item	3629850	et	3	main
kogu	doc_534729444738_item	3629849	et	4	main
laulavad	doc_534729444738_item	3629848	et	4	main
eestlased	doc_534729444738_item	3629847	et	3	main
et	doc_534729444738_item	3629846	et	3	main
ütlema	doc_534729444738_item	3629845	et	3	main
hakkan	doc_534729444738_item	3629844	et	3	main
ja	doc_534729444738_item	3629843	et	3	main
sõna	doc_534729444738_item	3629842	et	4	main
selle	doc_534729444738_item	3629841	et	4	main
hirmu	doc_534729444738_item	3629840	et	4	main
ei	doc_534729444738_item	3629839	et	4	main
laulmisele	doc_534729444738_item	3629838	et	4	main
ja	doc_534729444738_item	3629837	et	3	main
ei	doc_534729444738_item	3629812	et	4	main
see	doc_534729444738_item	3629811	et	3	main
võimalusi	doc_534729444738_item	3629804	et	3	main
loengus	doc_534729444738_item	3629775	et	3	main
olema	doc_534729444738_item	3629769	et	4	main
mis	doc_534729444738_item	3629758	et	4	main
teise	doc_534729444738_item	3629751	et	4	main
eestlased	doc_534729444738_item	3630042	et	3	main
ajal	doc_534729444738_item	3630040	et	4	main
nagu	doc_534729444738_item	3630038	et	3	main
ei	doc_534729444738_item	3630036	et	4	main
eestis	doc_534729444738_item	3630031	et	3	main
tulevikul	doc_534729444738_item	3630028	et	4	main
hakkavad	doc_534729444738_item	3630026	et	4	main
aastaid	doc_534729444738_item	3630023	et	4	main
palju	doc_534729444738_item	3630022	et	4	main
emalauldes	doc_534729444738_item	3630016	et	4	main
see	doc_534729444738_item	3630015	et	3	main
mitte	doc_534729444738_item	3630005	et	3	main
iga	doc_534729444738_item	3629995	et	4	main
tallinnas	doc_534729444743_item	3630313	et	4	main
pärast	doc_534729444743_item	3630305	et	4	main
eestist	doc_534729444743_item	3630299	et	3	main
eestlased	doc_534729444743_item	3630297	et	3	main
kõrghetk	doc_534729444743_item	3630296	et	3	main
liikumise	doc_534729444743_item	3630295	et	4	main
rahvusliku	doc_534729444743_item	3630294	et	3	main
oli	doc_534729444743_item	3630293	et	3	main
tartus	doc_534729444743_item	3630292	et	3	main
1869	doc_534729444743_item	3630290	et	2	main
laulupidu	doc_534729444743_item	3630287	et	4	main
kõige	doc_534729444743_item	3630270	et	4	main
aga	doc_534729444743_item	3630269	et	3	main
trükiti	doc_534729444743_item	3630268	et	3	main
salmialbumid	doc_534729444743_item	3630267	et	3	main
ja	doc_534729444743_item	3630266	et	3	main
laululehed	doc_534729444743_item	3630265	et	3	main
ka	doc_534729444743_item	3630264	et	3	main
ära	doc_534729444738_item	3629918	et	4	main
sest	doc_534729444738_item	3629912	et	4	main
eestlased	doc_534729444738_item	3629908	et	3	main
ajalugu	doc_534729444738_item	3629906	et	4	main
vana	doc_534729444738_item	3629904	et	4	main
väga	doc_534729444738_item	3629903	et	3	main
on	doc_534729444738_item	3629902	et	4	main
eestis	doc_534729444738_item	3629901	et	3	main
töötab	doc_534729444738_item	3629893	et	3	main
kui	doc_534729444738_item	3629892	et	3	main
laulmine	doc_534729444738_item	3629891	et	4	main
kui	doc_534729444738_item	3629879	et	3	main
on	doc_534729444738_item	3629852	et	4	main
laulad	doc_534729444738_item	3629851	et	3	main
teisele	doc_534729444738_item	3629836	et	4	main
elule	doc_534729444738_item	3629834	et	3	main
vastama	doc_534729444738_item	3629824	et	3	main
ma	doc_534729444738_item	3629822	et	3	main
mis	doc_534729444738_item	3629817	et	4	main
küsimus	doc_534729444738_item	3629816	et	4	main
raske	doc_534729444738_item	3629815	et	4	main
väga	doc_534729444738_item	3629814	et	3	main
oskavad	doc_534729444738_item	3629808	et	4	main
juba	doc_534729444738_item	3629803	et	3	main
palju	doc_534729444738_item	3629799	et	4	main
nii	doc_534729444738_item	3629798	et	3	main
väiteid	doc_534729444738_item	3629780	et	4	main
faktidele	doc_534729444738_item	3629779	et	3	main
eestlastest	doc_534729444738_item	3629760	et	4	main
teeb	doc_534729444738_item	3629759	et	3	main
essee	doc_534729444738_item	3629747	et	4	main
ole	doc_534729444738_item	3630037	et	4	main
näidata	doc_534729444738_item	3630012	et	4	main
saavad	doc_534729444738_item	3630008	et	4	main
peol	doc_534729444738_item	3630007	et	4	main
armastust	doc_534729444738_item	3630003	et	4	main
on	doc_534729444738_item	3630001	et	4	main
ja	doc_534729444738_item	3630000	et	3	main
kaasa	doc_534729444738_item	3629999	et	4	main
neid	doc_534729444743_item	3630310	et	4	main
ka	doc_534729444743_item	3630307	et	3	main
rahvamuusikaga	doc_534729444743_item	3630304	et	3	main
tulid	doc_534729444743_item	3630300	et	4	main
kogu	doc_534729444743_item	3630298	et	4	main
ärkamise	doc_534729444743_item	3630279	et	4	main
on	doc_534729444743_item	3630276	et	4	main
erinevad	doc_534729444743_item	3630259	et	4	main
uued	doc_534729444743_item	3630255	et	3	main
euroopast	doc_534729444743_item	3630253	et	3	main
kirikudes	doc_534729444743_item	3630241	et	4	main
mitte	doc_534729444743_item	3630239	et	3	main
lauldi	doc_534729444743_item	3630238	et	3	main
orkestriga	doc_534729444743_item	3630237	et	3	main
esines	doc_534729444743_item	3630233	et	3	main
kirikudes	doc_534729444743_item	3630231	et	4	main
sajandil	doc_534729444743_item	3630225	et	3	main
armastus	doc_534729444738_item	3629833	et	4	main
armastus	doc_534729444738_item	3629831	et	4	main
arvan	doc_534729444738_item	3629825	et	3	main
ole	doc_534729444738_item	3629813	et	4	main
nad	doc_534729444738_item	3629807	et	3	main
ei	doc_534729444738_item	3629801	et	4	main
laulab	doc_534729444738_item	3629797	et	3	main
kes	doc_534729444738_item	3629796	et	4	main
rahvas	doc_534729444738_item	3629795	et	4	main
on	doc_534729444738_item	3629794	et	4	main
eestlased	doc_534729444738_item	3629793	et	3	main
et	doc_534729444738_item	3629792	et	3	main
teab	doc_534729444738_item	3629791	et	3	main
riigis	doc_534729444738_item	3629790	et	3	main
meie	doc_534729444738_item	3629789	et	4	main
elab	doc_534729444738_item	3629788	et	3	main
kes	doc_534729444738_item	3629787	et	4	main
inimene	doc_534729444738_item	3629786	et	3	main
näidetega	doc_534729444738_item	3629784	et	3	main
illustreerida	doc_534729444738_item	3629783	et	3	main
iga	doc_534729444738_item	3629785	et	4	main
soovitatav	doc_534729444738_item	3629782	et	4	main
on	doc_534729444738_item	3629781	et	4	main
ja	doc_534729444738_item	3629772	et	3	main
peab	doc_534729444738_item	3629768	et	4	main
sõna	doc_534729444738_item	3629766	et	4	main
350	doc_534729444738_item	3629765	et	2	main
300	doc_534729444738_item	3629764	et	2	main
teemal	doc_534729444738_item	3629757	et	3	main
essee	doc_534729444738_item	3629756	et	4	main
kirjutage	doc_534729444738_item	3629755	et	3	main
kirjutamine	doc_534729444738_item	3629754	et	4	main
test	doc_534729444738_item	3629753	et	3	main
muusika	doc_534729444738_item	3630035	et	4	main
palju	doc_534729444738_item	3630032	et	4	main
laulma	doc_534729444738_item	3630027	et	3	main
tagasi	doc_534729444738_item	3630024	et	3	main
ka	doc_534729444738_item	3630013	et	3	main
oma	doc_534729444738_item	3630010	et	4	main
armastust	doc_534729444738_item	3629998	et	4	main
toob	doc_534729444738_item	3629997	et	3	main
ja	doc_534729444743_item	3630309	et	3	main
nautida	doc_534729444743_item	3630303	et	3	main
ajal	doc_534729444743_item	3630280	et	4	main
oli	doc_534729444743_item	3630262	et	3	main
nendel	doc_534729444743_item	3630261	et	4	main
ja	doc_534729444743_item	3630260	et	3	main
olid	doc_534729444743_item	3630257	et	4	main
näiteks	doc_534729444743_item	3630254	et	4	main
ka	doc_534729444743_item	3630252	et	3	main
ka	doc_534729444743_item	3630228	et	3	main
18	doc_534729444743_item	3630224	et	2	main
eriti	doc_534729444743_item	3630222	et	3	main
naised	doc_534729444743_item	3630213	et	3	main
või	doc_534729444743_item	3630190	et	4	main
ema	doc_534729444743_item	3630184	et	4	main
viga	doc_534729444743_item	3630174	et	4	main
ja	doc_534729444743_item	3630164	et	3	main
kodus	doc_534729444743_item	3630161	et	4	main
eestlased	doc_534729444743_item	3630159	et	3	main
juba	doc_534729444743_item	3630151	et	3	main
tuleb	doc_534729444743_item	3630150	et	3	main
rahvalaul	doc_534729444743_item	3630149	et	4	main
on	doc_534729444743_item	3630135	et	4	main
näidetega	doc_534729444743_item	3630126	et	3	main
illustreerida	doc_534729444743_item	3630125	et	3	main
loengus	doc_534729444743_item	3630117	et	3	main
essee	doc_534729444743_item	3630109	et	4	main
pikkus	doc_534729444743_item	3630105	et	4	main
laulurahva	doc_534729444743_item	3630103	et	3	main
eestlastest	doc_534729444743_item	3630102	et	4	main
teeb	doc_534729444743_item	3630101	et	3	main
teise	doc_534729444743_item	3630093	et	4	main
kui	doc_534729444743_item	3630092	et	3	main
on	doc_534729444743_item	3630395	et	4	main
et	doc_534729444743_item	3630393	et	3	main
saada	doc_534729444743_item	3630391	et	4	main
võivad	doc_534729444743_item	3630390	et	4	main
turistid	doc_534729444743_item	3630389	et	3	main
ka	doc_534729444743_item	3630388	et	3	main
kui	doc_534729444743_item	3630387	et	3	main
eestlased	doc_534729444743_item	3630386	et	3	main
nii	doc_534729444743_item	3630385	et	3	main
kus	doc_534729444743_item	3630384	et	3	main
iga	doc_534729444743_item	3630379	et	4	main
oma	doc_534729444743_item	3630377	et	4	main
tantsida	doc_534729444743_item	3630376	et	3	main
ja	doc_534729444743_item	3630375	et	3	main
laulud	doc_534729444743_item	3630374	et	3	main
respublika	doc_534729444743_item	3630367	et	4	main
nüüd	doc_534729444738_item	3630029	et	4	main
ja	doc_534729444738_item	3630025	et	3	main
laulsid	doc_534729444738_item	3630019	et	4	main
naised	doc_534729444738_item	3630018	et	3	main
mis	doc_534729444738_item	3630017	et	4	main
armastust	doc_534729444738_item	3630011	et	4	main
inimesed	doc_534729444738_item	3630009	et	3	main
aga	doc_534729444738_item	3630004	et	3	main
laulupidu	doc_534729444738_item	3629996	et	4	main
korraldati	doc_534729444743_item	3630311	et	3	main
laulupeod	doc_534729444743_item	3630308	et	4	main
olid	doc_534729444743_item	3630306	et	4	main
mis	doc_534729444743_item	3630288	et	4	main
esimene	doc_534729444743_item	3630286	et	3	main
sajandi	doc_534729444743_item	3630284	et	3	main
rahvusliku	doc_534729444743_item	3630278	et	3	main
et	doc_534729444743_item	3630274	et	3	main
öelda	doc_534729444743_item	3630273	et	4	main
saab	doc_534729444743_item	3630272	et	3	main
täpsem	doc_534729444743_item	3630271	et	4	main
väga	doc_534729444743_item	3630258	et	3	main
rahvalaulud	doc_534729444743_item	3630256	et	3	main
vaimuliku	doc_534729444743_item	3630229	et	3	main
eestlased	doc_534729444743_item	3630226	et	3	main
elu	doc_534729444743_item	3630211	et	4	main
et	doc_534729444743_item	3630205	et	3	main
on	doc_534729444743_item	3630203	et	4	main
regilauludes	doc_534729444743_item	3630196	et	3	main
lastele	doc_534729444743_item	3630188	et	4	main
juba	doc_534729444743_item	3630182	et	3	main
eesti	doc_534729444743_item	3630180	et	4	main
rahvalaul	doc_534729444743_item	3630178	et	4	main
öelda	doc_534729444743_item	3630176	et	4	main
kui	doc_534729444743_item	3630175	et	3	main
igal	doc_534729444743_item	3630166	et	3	main
praktiliselt	doc_534729444743_item	3630165	et	4	main
töötades	doc_534729444743_item	3630162	et	3	main
laulsid	doc_534729444743_item	3630160	et	4	main
raske	doc_534729444743_item	3630158	et	4	main
oli	doc_534729444743_item	3630157	et	3	main
eesti	doc_534729444743_item	3630148	et	4	main
elada	doc_534729444743_item	3630147	et	3	main
teistele	doc_534729444743_item	3630144	et	4	main
kui	doc_534729444743_item	3630143	et	3	main
rahval	doc_534729444743_item	3630134	et	3	main
muusika	doc_534729444743_item	3630127	et	4	main
ja	doc_534729444743_item	3630118	et	3	main
ja	doc_534729444743_item	3630114	et	3	main
analüüsiv	doc_534729444743_item	3630113	et	4	main
olema	doc_534729444743_item	3630111	et	4	main
peab	doc_534729444743_item	3630110	et	4	main
300	doc_534729444743_item	3630106	et	2	main
essee	doc_534729444743_item	3630104	et	4	main
eesti	doc_534729444743_item	3630090	et	4	main
laulupidu	doc_534729444743_item	3630383	et	4	main
toimub	doc_534729444743_item	3630382	et	3	main
rahvas	doc_534729444743_item	3630370	et	4	main
eesti	doc_534729444743_item	3630364	et	4	main
rahvas	doc_534729444743_item	3630322	et	4	main
randa	doc_35015649955_item	3630563	et	4	main
ka	doc_35015649955_item	3630560	et	3	main
helsinkist	doc_35015649955_item	3630558	et	4	main
reisima	doc_35015649955_item	3630555	et	3	main
eesti	doc_35015649955_item	3630548	et	4	main
et	doc_35015649955_item	3630547	et	3	main
ka	doc_35015649955_item	3630546	et	3	main
mulle	doc_35015649955_item	3630544	et	4	main
samaks	doc_35015649955_item	3630543	et	3	main
et	doc_35015649955_item	3630536	et	3	main
tallinna	doc_35015649955_item	3630527	et	4	main
ilus	doc_35015649955_item	3630526	et	4	main
väga	doc_35015649955_item	3630525	et	3	main
linn	doc_35015649955_item	3630519	et	3	main
mulle	doc_35015649955_item	3630515	et	4	main
rahvad	doc_35015649955_item	3630514	et	3	main
värske	doc_35015649955_item	3630513	et	4	main
selle	doc_35015649955_item	3630508	et	4	main
keelis	doc_35015649955_item	3630507	et	3	main
õppima	doc_35015649955_item	3630506	et	3	main
laulda	doc_534729444743_item	3630405	et	4	main
eestlastele	doc_534729444743_item	3630404	et	4	main
keelata	doc_534729444743_item	3630403	et	4	main
saa	doc_534729444743_item	3630402	et	4	main
ei	doc_534729444743_item	3630401	et	4	main
midagi	doc_534729444743_item	3630400	et	4	main
ka	doc_534729444743_item	3630312	et	3	main
et	doc_534729444743_item	3630302	et	3	main
tartusse	doc_534729444743_item	3630301	et	3	main
aastal	doc_534729444743_item	3630291	et	3	main
toimus	doc_534729444743_item	3630289	et	3	main
lõpus	doc_534729444743_item	3630285	et	4	main
19	doc_534729444743_item	3630283	et	2	main
oli	doc_534729444743_item	3630282	et	3	main
mis	doc_534729444743_item	3630281	et	4	main
laulurahvas	doc_534729444743_item	3630277	et	4	main
eestlased	doc_534729444743_item	3630275	et	3	main
palju	doc_534729444743_item	3630251	et	4	main
võttis	doc_534729444743_item	3630250	et	3	main
rahvalaul	doc_534729444743_item	3630249	et	4	main
uus	doc_534729444743_item	3630248	et	3	main
saateks	doc_534729444743_item	3630247	et	3	main
ainult	doc_534729444743_item	3630240	et	4	main
ka	doc_534729444743_item	3630234	et	3	main
laulu	doc_534729444743_item	3630230	et	4	main
laulsid	doc_534729444743_item	3630227	et	4	main
võimalus	doc_534729444743_item	3630220	et	3	main
ka	doc_534729444743_item	3630219	et	3	main
laulda	doc_534729444743_item	3630221	et	4	main
oli	doc_534729444743_item	3630218	et	3	main
meestel	doc_534729444743_item	3630217	et	4	main
aga	doc_534729444743_item	3630216	et	3	main
rohkem	doc_534729444743_item	3630215	et	4	main
laulsid	doc_534729444743_item	3630214	et	4	main
vaheldumisi	doc_534729444743_item	3630202	et	4	main
eeslaulja	doc_534729444743_item	3630199	et	4	main
laulsid	doc_534729444743_item	3630198	et	4	main
osa	doc_534729444743_item	3630195	et	4	main
võtsid	doc_534729444743_item	3630194	et	4	main
juba	doc_534729444743_item	3630193	et	3	main
noored	doc_534729444743_item	3630192	et	3	main
hakkas	doc_534729444743_item	3630185	et	3	main
veres	doc_534729444743_item	3630181	et	3	main
on	doc_534729444743_item	3630179	et	4	main
et	doc_534729444743_item	3630177	et	3	main
pidudes	doc_534729444743_item	3630163	et	4	main
stiil	doc_534729444743_item	3630139	et	3	main
laulukombed	doc_534729444743_item	3630137	et	3	main
soovitatav	doc_534729444743_item	3630124	et	4	main
on	doc_534729444743_item	3630123	et	4	main
tuginema	doc_534729444743_item	3630116	et	3	main
autor	doc_534729444743_item	3630263	et	3	main
tantsu	doc_534729444743_item	3630246	et	4	main
ka	doc_534729444743_item	3630245	et	3	main
piduõhtutel	doc_534729444743_item	3630244	et	3	main
musitseeriti	doc_534729444743_item	3630243	et	3	main
hiljem	doc_534729444743_item	3630242	et	3	main
aga	doc_534729444743_item	3630236	et	3	main
puhkpilliorkester	doc_534729444743_item	3630235	et	3	main
koorilauluga	doc_534729444743_item	3630232	et	4	main
pulmades	doc_534729444743_item	3630223	et	3	main
laulsid	doc_534729444743_item	3630208	et	4	main
eestlased	doc_534729444743_item	3630207	et	3	main
vanasti	doc_534729444743_item	3630206	et	3	main
nii	doc_534729444743_item	3630204	et	3	main
kus	doc_534729444743_item	3630197	et	3	main
lastelaulu	doc_534729444743_item	3630189	et	4	main
lapsepõlvest	doc_534729444743_item	3630183	et	4	main
ole	doc_534729444743_item	3630173	et	4	main
ei	doc_534729444743_item	3630172	et	4	main
see	doc_534729444743_item	3630171	et	3	main
et	doc_534729444743_item	3630170	et	3	main
arvan	doc_534729444743_item	3630169	et	3	main
ma	doc_534729444743_item	3630168	et	3	main
hetkel	doc_534729444743_item	3630167	et	4	main
aitas	doc_534729444743_item	3630146	et	3	main
oma	doc_534729444743_item	3630136	et	4	main
osa	doc_534729444743_item	3630132	et	4	main
inimese	doc_534729444743_item	3630130	et	4	main
oli	doc_534729444743_item	3630129	et	3	main
alati	doc_534729444743_item	3630128	et	4	main
arutlev	doc_534729444743_item	3630112	et	4	main
350	doc_534729444743_item	3630107	et	2	main
mis	doc_534729444743_item	3630100	et	4	main
teemal	doc_534729444743_item	3630099	et	3	main
keele	doc_534729444743_item	3630091	et	4	main
essee	doc_534729444743_item	3630089	et	4	main
mitte	doc_534729444743_item	3630399	et	3	main
ja	doc_534729444743_item	3630398	et	3	main
meil	doc_534729444743_item	3630381	et	4	main
tantsid	doc_534729444743_item	3630378	et	4	main
vaba	doc_534729444743_item	3630366	et	4	main
olema	doc_534729444743_item	3630329	et	4	main
tundsid	doc_534729444743_item	3630318	et	4	main
olevad	doc_35015649955_item	3630575	et	4	main
meeldib	doc_35015649955_item	3630572	et	3	main
ka	doc_35015649955_item	3630570	et	3	main
piki	doc_35015649955_item	3630562	et	4	main
ja	doc_35015649955_item	3630557	et	3	main
mulle	doc_35015649955_item	3630553	et	4	main
muutub	doc_35015649955_item	3630537	et	3	main
mulle	doc_35015649955_item	3630533	et	4	main
vana	doc_35015649955_item	3630520	et	4	main
ka	doc_35015649955_item	3630517	et	3	main
pärast	doc_35015649955_item	3630509	et	4	main
laisk	doc_35015649955_item	3630503	et	3	main
olen	doc_35015649955_item	3630502	et	3	main
ainult	doc_35015649955_item	3630476	et	4	main
eestis	doc_35015649955_item	3630445	et	3	main
vihma	doc_35015649955_item	3630436	et	4	main
talv	doc_35015649955_item	3630433	et	3	main
ole	doc_35015649955_item	3630432	et	4	main
talv	doc_35015649955_item	3630430	et	3	main
austrias	doc_35015649955_item	3630429	et	4	main
talv	doc_35015649955_item	3630428	et	3	main
mulle	doc_35015649955_item	3630415	et	4	main
eesti	doc_35015649955_item	3630410	et	4	main
essee	doc_35015649955_item	3630407	et	4	main
tallinnas	doc_35015649956_item	3630676	et	4	main
meelest	doc_35015649956_item	3630667	et	4	main
minu	doc_35015649956_item	3630666	et	3	main
sajanud	doc_35015649956_item	3630654	et	4	main
ja	doc_35015649956_item	3630644	et	3	main
ja	doc_35015649956_item	3630632	et	3	main
kreeka	doc_35015649956_item	3630620	et	4	main
soome	doc_35015649956_item	3630618	et	3	main
nätiks	doc_35015649956_item	3630614	et	4	main
inimehed	doc_35015649956_item	3630611	et	4	main
see	doc_35015649956_item	3630747	et	3	main
ma	doc_35015649956_item	3630735	et	3	main
raskem	doc_35015649956_item	3630728	et	4	main
minu	doc_35015649956_item	3630727	et	3	main
meile	doc_35015649956_item	3630723	et	4	main
sõna	doc_35015649956_item	3630711	et	4	main
minu	doc_35015649956_item	3630709	et	3	main
muidugi	doc_534729444743_item	3630212	et	4	main
oma	doc_534729444743_item	3630210	et	4	main
kogu	doc_534729444743_item	3630209	et	4	main
koor	doc_534729444743_item	3630201	et	4	main
ja	doc_534729444743_item	3630200	et	3	main
muinasjutulaulu	doc_534729444743_item	3630191	et	4	main
oma	doc_534729444743_item	3630187	et	4	main
laulma	doc_534729444743_item	3630186	et	3	main
elu	doc_534729444743_item	3630156	et	4	main
et	doc_534729444743_item	3630155	et	3	main
sellest	doc_534729444743_item	3630154	et	4	main
vaatamata	doc_534729444743_item	3630153	et	4	main
minevikust	doc_534729444743_item	3630152	et	3	main
laul	doc_534729444743_item	3630145	et	4	main
rohkem	doc_534729444743_item	3630142	et	4	main
võib-olla	doc_534729444743_item	3630141	et	3	main
eestlastele	doc_534729444743_item	3630140	et	4	main
ja	doc_534729444743_item	3630138	et	3	main
igal	doc_534729444743_item	3630133	et	3	main
elu	doc_534729444743_item	3630131	et	4	main
väiteid	doc_534729444743_item	3630122	et	4	main
faktidele	doc_534729444743_item	3630121	et	3	main
esitatud	doc_534729444743_item	3630120	et	4	main
lugemistekstis	doc_534729444743_item	3630119	et	3	main
üldistav	doc_534729444743_item	3630115	et	4	main
essee	doc_534729444743_item	3630098	et	4	main
kirjutage	doc_534729444743_item	3630097	et	3	main
laulurahvas	doc_534729444743_item	3630397	et	4	main
oma	doc_534729444743_item	3630373	et	4	main
laulda	doc_534729444743_item	3630372	et	4	main
võib	doc_534729444743_item	3630371	et	3	main
on	doc_534729444743_item	3630365	et	4	main
nendel	doc_534729444743_item	3630327	et	4	main
on	doc_534729444743_item	3630324	et	4	main
nendel	doc_534729444743_item	3630323	et	4	main
sellepärast	doc_35015649955_item	3630574	et	3	main
mulle	doc_35015649955_item	3630571	et	4	main
tihti	doc_35015649955_item	3630564	et	3	main
kõik	doc_35015649955_item	3630541	et	4	main
maailma	doc_35015649955_item	3630531	et	4	main
oleb	doc_35015649955_item	3630524	et	4	main
vana	doc_35015649955_item	3630523	et	4	main
linn	doc_35015649955_item	3630522	et	3	main
tallinnas	doc_35015649955_item	3630521	et	4	main
tallinnas	doc_35015649955_item	3630518	et	4	main
meeldib	doc_35015649955_item	3630516	et	3	main
meeldib	doc_35015649955_item	3630505	et	3	main
pärast	doc_35015649955_item	3630473	et	4	main
kevad	doc_35015649955_item	3630443	et	3	main
mulle	doc_35015649955_item	3630441	et	4	main
pärast	doc_35015649955_item	3630435	et	4	main
talv	doc_35015649955_item	3630425	et	3	main
pärast	doc_35015649955_item	3630424	et	4	main
mulle	doc_35015649955_item	3630420	et	4	main
egi	doc_35015649955_item	3630418	et	4	main
eesti	doc_35015649955_item	3630413	et	4	main
ja	doc_35015649956_item	3630678	et	3	main
venemaale	doc_35015649956_item	3630663	et	4	main
maad	doc_35015649956_item	3630661	et	4	main
talv	doc_35015649956_item	3630645	et	3	main
150oc	doc_35015649956_item	3630642	et	2	main
sooja	doc_35015649956_item	3630640	et	4	main
ja	doc_35015649956_item	3630639	et	3	main
paistab	doc_35015649956_item	3630638	et	3	main
päike	doc_35015649956_item	3630637	et	3	main
ja	doc_35015649956_item	3630636	et	3	main
ilm	doc_35015649956_item	3630629	et	3	main
hispaania	doc_35015649956_item	3630616	et	4	main
maad	doc_35015649956_item	3630613	et	4	main
erinev	doc_35015649956_item	3630612	et	4	main
ülipilaselamus	doc_35015649956_item	3630604	et	4	main
elan	doc_35015649956_item	3630603	et	3	main
räägin	doc_35015649956_item	3630737	et	3	main
nädalavahetust	doc_35015649956_item	3630732	et	4	main
on	doc_35015649956_item	3630730	et	4	main
sõna	doc_35015649956_item	3630729	et	4	main
oleme	doc_35015649956_item	3630720	et	3	main
rand	doc_35015649956_item	3630708	et	3	main
saksamaal	doc_35015649956_item	3630704	et	4	main
sõna	doc_534729444743_item	3630108	et	4	main
kirjutamine	doc_534729444743_item	3630096	et	4	main
test	doc_534729444743_item	3630095	et	3	main
keele	doc_534729444743_item	3630094	et	4	main
tõesti	doc_534729444743_item	3630396	et	3	main
eestlased	doc_534729444743_item	3630394	et	3	main
aru	doc_534729444743_item	3630392	et	4	main
aastal	doc_534729444743_item	3630380	et	3	main
meie	doc_534729444743_item	3630369	et	4	main
ja	doc_534729444743_item	3630368	et	3	main
praegu	doc_534729444743_item	3630363	et	3	main
arm	doc_534729444743_item	3630362	et	3	main
minu	doc_534729444743_item	3630361	et	3	main
on	doc_534729444743_item	3630360	et	4	main
isamaa	doc_534729444743_item	3630359	et	4	main
mu	doc_534729444743_item	3630358	et	3	main
isamaalaulu	doc_534729444743_item	3630357	et	4	main
laulda	doc_534729444743_item	3630356	et	4	main
said	doc_534729444743_item	3630355	et	4	main
eestlased	doc_534729444743_item	3630354	et	3	main
ajal	doc_534729444743_item	3630353	et	4	main
sel	doc_534729444743_item	3630352	et	3	main
isegi	doc_534729444743_item	3630351	et	4	main
aga	doc_534729444743_item	3630350	et	3	main
kontroll	doc_534729444743_item	3630349	et	3	main
ja	doc_534729444743_item	3630348	et	3	main
reeglid	doc_534729444743_item	3630347	et	3	main
ranged	doc_534729444743_item	3630346	et	3	main
olid	doc_534729444743_item	3630345	et	4	main
pidudel	doc_534729444743_item	3630344	et	4	main
ja	doc_534729444743_item	3630343	et	3	main
laulu	doc_534729444743_item	3630342	et	4	main
propagandistlikku	doc_534729444743_item	3630341	et	4	main
palju	doc_534729444743_item	3630340	et	4	main
oli	doc_534729444743_item	3630339	et	3	main
repertuaaris	doc_534729444743_item	3630338	et	3	main
millal	doc_534729444743_item	3630337	et	3	main
aegades	doc_534729444743_item	3630336	et	3	main
nõukogu	doc_534729444743_item	3630335	et	4	main
oli	doc_534729444743_item	3630334	et	3	main
eestlastele	doc_534729444743_item	3630333	et	4	main
raske	doc_534729444743_item	3630332	et	4	main
eriti	doc_534729444743_item	3630331	et	3	main
iseseisvus	doc_534729444743_item	3630330	et	4	main
peab	doc_534729444743_item	3630328	et	4	main
on	doc_534729444743_item	3630321	et	4	main
nad	doc_534729444743_item	3630320	et	3	main
et	doc_534729444743_item	3630319	et	3	main
sõbralikud	doc_35015649955_item	3630576	et	3	main
ja	doc_534729444743_item	3630326	et	3	main
ajalugu	doc_534729444743_item	3630325	et	4	main
eestlased	doc_534729444743_item	3630317	et	3	main
sellele	doc_534729444743_item	3630316	et	4	main
aitades	doc_534729444743_item	3630315	et	3	main
ja	doc_534729444743_item	3630314	et	3	main
lõplikult	doc_35015649955_item	3630569	et	4	main
tallinnas	doc_35015649955_item	3630568	et	4	main
sport	doc_35015649955_item	3630567	et	3	main
meeldib	doc_35015649955_item	3630566	et	3	main
meeldib	doc_35015649955_item	3630545	et	3	main
jääb	doc_35015649955_item	3630542	et	3	main
muutu	doc_35015649955_item	3630539	et	4	main
ei	doc_35015649955_item	3630538	et	4	main
meeldib	doc_35015649955_item	3630534	et	3	main
koos	doc_35015649955_item	3630512	et	4	main
pärast	doc_35015649955_item	3630501	et	4	main
selle	doc_35015649955_item	3630500	et	4	main
töötada	doc_35015649955_item	3630499	et	3	main
meeldi	doc_35015649955_item	3630498	et	4	main
ei	doc_35015649955_item	3630497	et	4	main
õppida	doc_35015649955_item	3630496	et	3	main
meeldib	doc_35015649955_item	3630495	et	3	main
mulle	doc_35015649955_item	3630494	et	4	main
päev	doc_35015649955_item	3630493	et	3	main
iga	doc_35015649955_item	3630492	et	4	main
ülikoolist	doc_35015649955_item	3630491	et	4	main
minen	doc_35015649955_item	3630490	et	4	main
ma	doc_35015649955_item	3630489	et	3	main
tänavas	doc_35015649955_item	3630488	et	4	main
lina	doc_35015649955_item	3630487	et	4	main
tallinnas	doc_35015649955_item	3630486	et	4	main
elan	doc_35015649955_item	3630485	et	3	main
ma	doc_35015649955_item	3630484	et	3	main
sügis	doc_35015649955_item	3630483	et	3	main
ka	doc_35015649955_item	3630482	et	3	main
meeldib	doc_35015649955_item	3630481	et	3	main
mõtlen	doc_35015649955_item	3630480	et	3	main
aga	doc_35015649955_item	3630479	et	3	main
kuud	doc_35015649955_item	3630478	et	4	main
viis	doc_35015649955_item	3630477	et	4	main
ei	doc_35015649955_item	3630454	et	4	main
sellepärast	doc_35015649955_item	3630453	et	3	main
suvi	doc_35015649955_item	3630452	et	3	main
eestis	doc_35015649955_item	3630451	et	3	main
meeldib	doc_35015649955_item	3630450	et	3	main
ka	doc_35015649955_item	3630449	et	3	main
aeglaselt	doc_35015649955_item	3630448	et	4	main
saabub	doc_35015649955_item	3630447	et	3	main
ei	doc_35015649955_item	3630431	et	4	main
tegelikult	doc_35015649955_item	3630427	et	4	main
on	doc_35015649955_item	3630426	et	4	main
meeldib	doc_35015649955_item	3630421	et	3	main
eestis	doc_35015649955_item	3630419	et	3	main
aastaa	doc_35015649955_item	3630417	et	4	main
meeldib	doc_35015649955_item	3630416	et	3	main
vanalinn	doc_35015649956_item	3630677	et	3	main
talvel	doc_35015649956_item	3630673	et	4	main
kui	doc_35015649956_item	3630672	et	3	main
sõbralikum	doc_35015649956_item	3630670	et	4	main
on	doc_35015649956_item	3630669	et	4	main
soomesse	doc_35015649956_item	3630664	et	3	main
oli	doc_35015649956_item	3630653	et	3	main
on	doc_35015649956_item	3630634	et	4	main
läheb	doc_35015649956_item	3630630	et	3	main
peale	doc_35015649956_item	3630627	et	4	main
eestlased	doc_35015649955_item	3630573	et	3	main
mulle	doc_35015649955_item	3630565	et	4	main
sörkin	doc_35015649955_item	3630561	et	4	main
tallinnasse	doc_35015649955_item	3630559	et	3	main
venemaast	doc_35015649955_item	3630556	et	3	main
meeldib	doc_35015649955_item	3630554	et	3	main
huvitavaid	doc_35015649955_item	3630552	et	4	main
linnad	doc_35015649955_item	3630551	et	3	main
lähedal	doc_35015649955_item	3630550	et	4	main
on	doc_35015649955_item	3630549	et	4	main
ja	doc_35015649955_item	3630540	et	3	main
eriti	doc_35015649955_item	3630535	et	3	main
kultuuripärand	doc_35015649955_item	3630532	et	3	main
on	doc_35015649955_item	3630530	et	4	main
vana	doc_35015649955_item	3630529	et	4	main
linn	doc_35015649955_item	3630528	et	3	main
räägima	doc_35015649955_item	3630511	et	4	main
võimaldab	doc_35015649955_item	3630510	et	3	main
mulle	doc_35015649955_item	3630504	et	4	main
kevad	doc_35015649955_item	3630446	et	3	main
sajab	doc_35015649955_item	3630439	et	3	main
selle	doc_35015649955_item	3630434	et	4	main
talv	doc_35015649955_item	3630422	et	3	main
meeldib	doc_35015649955_item	3630412	et	3	main
meeldib	doc_35015649956_item	3630675	et	3	main
suvel	doc_35015649956_item	3630671	et	3	main
leedusse	doc_35015649956_item	3630665	et	4	main
see	doc_35015649956_item	3630652	et	3	main
sest	doc_35015649956_item	3630651	et	4	main
halb	doc_35015649956_item	3630650	et	3	main
ja	doc_35015649956_item	3630649	et	3	main
siin	doc_35015649956_item	3630648	et	4	main
kaua	doc_35015649956_item	3630647	et	3	main
kraadi	doc_35015649956_item	3630643	et	4	main
taevas	doc_35015649956_item	3630633	et	4	main
kõrval	doc_35015649956_item	3630621	et	4	main
jaapan	doc_35015649956_item	3630615	et	4	main
eestis	doc_35015649955_item	3630475	et	3	main
elan	doc_35015649955_item	3630474	et	3	main
selle	doc_35015649955_item	3630472	et	4	main
sügist	doc_35015649955_item	3630471	et	3	main
tea	doc_35015649955_item	3630470	et	4	main
ei	doc_35015649955_item	3630469	et	4	main
hea	doc_35015649955_item	3630468	et	4	main
kuigi	doc_35015649955_item	3630467	et	3	main
mitte	doc_35015649955_item	3630466	et	3	main
oleb	doc_35015649955_item	3630465	et	4	main
suvi	doc_35015649955_item	3630464	et	3	main
austrias	doc_35015649955_item	3630463	et	4	main
soe	doc_35015649955_item	3630462	et	4	main
vähem	doc_35015649955_item	3630461	et	4	main
suvi	doc_35015649955_item	3630460	et	3	main
eelistan	doc_35015649955_item	3630459	et	3	main
hea	doc_35015649955_item	3630458	et	4	main
kuigi	doc_35015649955_item	3630457	et	3	main
mitte	doc_35015649955_item	3630456	et	3	main
ole	doc_35015649955_item	3630455	et	4	main
sellepärast	doc_35015649955_item	3630444	et	3	main
meeldib	doc_35015649955_item	3630442	et	3	main
lund	doc_35015649955_item	3630440	et	3	main
asemel	doc_35015649955_item	3630438	et	4	main
sajab	doc_35015649955_item	3630437	et	3	main
selle	doc_35015649955_item	3630423	et	4	main
paljud	doc_35015649955_item	3630414	et	3	main
mulle	doc_35015649955_item	3630411	et	4	main
ja	doc_35015649955_item	3630409	et	3	main
mina	doc_35015649955_item	3630408	et	4	main
sõbrad	doc_35015649956_item	3630757	et	3	main
uues	doc_35015649956_item	3630756	et	3	main
palju	doc_35015649956_item	3630755	et	4	main
nüüd	doc_35015649956_item	3630754	et	4	main
on	doc_35015649956_item	3630753	et	4	main
eestis	doc_35015649956_item	3630751	et	3	main
mulle	doc_35015649956_item	3630752	et	4	main
aega	doc_35015649956_item	3630750	et	4	main
ilus	doc_35015649956_item	3630749	et	4	main
mulle	doc_35015649956_item	3630674	et	4	main
inimehed	doc_35015649956_item	3630668	et	4	main
nätiks	doc_35015649956_item	3630662	et	4	main
palju	doc_35015649956_item	3630660	et	4	main
sõitanud	doc_35015649956_item	3630659	et	4	main
olen	doc_35015649956_item	3630658	et	3	main
ma	doc_35015649956_item	3630657	et	3	main
natuke	doc_35015649956_item	3630656	et	4	main
lund	doc_35015649956_item	3630655	et	3	main
oli	doc_35015649956_item	3630646	et	3	main
on	doc_35015649956_item	3630641	et	4	main
selge	doc_35015649956_item	3630635	et	4	main
soojaks	doc_35015649956_item	3630631	et	4	main
selle	doc_35015649956_item	3630628	et	4	main
tegema	doc_35015649956_item	3630626	et	3	main
ja	doc_35015649956_item	3630619	et	3	main
ma	doc_35015649956_item	3630602	et	3	main
pärnusse	doc_35015649956_item	3630601	et	4	main
narvasse	doc_35015649956_item	3630600	et	4	main
tartusse	doc_35015649956_item	3630599	et	3	main
olin	doc_35015649956_item	3630598	et	3	main
ma	doc_35015649956_item	3630597	et	3	main
elanik	doc_35015649956_item	3630596	et	3	main
ja	doc_35015649956_item	3630595	et	3	main
ajalugu	doc_35015649956_item	3630594	et	4	main
linnad	doc_35015649956_item	3630593	et	3	main
lodus	doc_35015649956_item	3630592	et	4	main
millegi	doc_35015649956_item	3630591	et	4	main
palju	doc_35015649956_item	3630590	et	4	main
tean	doc_35015649956_item	3630589	et	3	main
praegu	doc_35015649956_item	3630588	et	3	main
aga	doc_35015649956_item	3630587	et	3	main
maa	doc_35015649956_item	3630586	et	4	main
võõras	doc_35015649956_item	3630585	et	4	main
oli	doc_35015649956_item	3630584	et	3	main
eesti	doc_35015649956_item	3630583	et	4	main
alguses	doc_35015649956_item	3630582	et	4	main
eesti	doc_35015649956_item	3630581	et	4	main
ja	doc_35015649956_item	3630580	et	3	main
mina	doc_35015649956_item	3630579	et	4	main
essee	doc_35015649956_item	3630578	et	4	main
väike	doc_35015649956_item	3630744	et	4	main
ja	doc_35015649956_item	3630743	et	3	main
ilus	doc_35015649956_item	3630742	et	4	main
oskan	doc_35015649956_item	3630736	et	3	main
alkoholi	doc_35015649956_item	3630726	et	4	main
ja	doc_35015649956_item	3630722	et	3	main
üliõpilased	doc_35015649956_item	3630721	et	3	main
meie	doc_35015649956_item	3630719	et	4	main
tähtis	doc_35015649956_item	3630717	et	4	main
on	doc_35015649956_item	3630716	et	4	main
see	doc_35015649956_item	3630715	et	3	main
ja	doc_35015649956_item	3630714	et	3	main
terviseks	doc_35015649956_item	3630713	et	3	main
oli	doc_35015649956_item	3630712	et	3	main
parem	doc_35015649956_item	3630707	et	4	main
aga	doc_35015649956_item	3630705	et	3	main
kodulinn	doc_35015649956_item	3630703	et	3	main
minu	doc_35015649956_item	3630702	et	3	main
kogemus	doc_35015649958_item	3630957	et	3	main
riias	doc_35015649958_item	3630932	et	4	main
lähen	doc_35015649958_item	3630931	et	3	main
sushi	doc_35015649956_item	3630625	et	4	main
õppinud	doc_35015649956_item	3630624	et	4	main
olen	doc_35015649956_item	3630623	et	3	main
ma	doc_35015649956_item	3630622	et	3	main
holland	doc_35015649956_item	3630617	et	4	main
palju	doc_35015649956_item	3630610	et	4	main
tundanud	doc_35015649956_item	3630609	et	4	main
õppinud	doc_35015649956_item	3630608	et	4	main
olen	doc_35015649956_item	3630607	et	3	main
ma	doc_35015649956_item	3630606	et	3	main
ja	doc_35015649956_item	3630605	et	3	main
oli	doc_35015649956_item	3630748	et	3	main
on	doc_35015649956_item	3630741	et	4	main
eesti	doc_35015649956_item	3630740	et	4	main
aga	doc_35015649956_item	3630733	et	3	main
head	doc_35015649956_item	3630731	et	4	main
juuada	doc_35015649956_item	3630725	et	4	main
meeldivad	doc_35015649956_item	3630724	et	4	main
esimene	doc_35015649956_item	3630710	et	3	main
minu	doc_35015649958_item	3630955	et	3	main
inimesed	doc_35015649958_item	3630948	et	3	main
palju	doc_35015649958_item	3630946	et	4	main
ja	doc_35015649958_item	3630945	et	3	main
arengut	doc_35015649958_item	3630944	et	3	main
õnne	doc_35015649958_item	3630943	et	4	main
eestile	doc_35015649958_item	3630942	et	3	main
soovin	doc_35015649958_item	3630941	et	3	main
ma	doc_35015649958_item	3630940	et	3	main
üks	doc_35015649958_item	3630939	et	3	main
juunil	doc_35015649958_item	3630938	et	3	main
päikesepaisteline	doc_35015649958_item	3630923	et	4	main
tallinas	doc_35015649958_item	3630917	et	4	main
keele	doc_35015649958_item	3630891	et	4	main
läti	doc_35015649958_item	3630885	et	4	main
õppida	doc_35015649958_item	3630880	et	3	main
leedu	doc_35015649958_item	3630878	et	4	main
tahan	doc_35015649958_item	3630877	et	3	main
ma	doc_35015649958_item	3630876	et	3	main
ka	doc_35015649958_item	3630874	et	3	main
keelt	doc_35015649958_item	3630872	et	4	main
on	doc_35015649958_item	3630866	et	4	main
tegeda	doc_35015649958_item	3630861	et	4	main
tahan	doc_35015649958_item	3630860	et	3	main
ma	doc_35015649958_item	3630859	et	3	main
tulevikus	doc_35015649958_item	3630858	et	4	main
lõpuks	doc_35015649956_item	3630746	et	4	main
maa	doc_35015649956_item	3630745	et	4	main
sõna	doc_35015649956_item	3630739	et	4	main
see	doc_35015649956_item	3630738	et	3	main
nüüd	doc_35015649956_item	3630734	et	4	main
sest	doc_35015649956_item	3630718	et	4	main
kielil	doc_35015649956_item	3630706	et	4	main
kui	doc_35015649956_item	3630700	et	3	main
ilusam	doc_35015649956_item	3630699	et	4	main
on	doc_35015649956_item	3630698	et	4	main
tallinna	doc_35015649956_item	3630697	et	4	main
meelest	doc_35015649956_item	3630696	et	4	main
minu	doc_35015649956_item	3630695	et	3	main
suhkraga	doc_35015649956_item	3630694	et	4	main
ja	doc_35015649956_item	3630693	et	3	main
kefiiriga	doc_35015649956_item	3630692	et	3	main
kama	doc_35015649956_item	3630691	et	4	main
joon	doc_35015649956_item	3630690	et	4	main
ja	doc_35015649956_item	3630689	et	3	main
kana	doc_35015649956_item	3630688	et	4	main
palju	doc_35015649956_item	3630687	et	4	main
siin	doc_35015649956_item	3630686	et	4	main
söön	doc_35015649956_item	3630685	et	3	main
ma	doc_35015649956_item	3630684	et	3	main
trammiga	doc_35015649956_item	3630683	et	3	main
sõita	doc_35015649956_item	3630682	et	3	main
ja	doc_35015649956_item	3630681	et	3	main
piritas	doc_35015649956_item	3630680	et	4	main
rand	doc_35015649956_item	3630679	et	3	main
eestis	doc_35015649958_item	3630953	et	3	main
minu	doc_35015649958_item	3630951	et	3	main
ma	doc_35015649958_item	3630930	et	3	main
tallinas	doc_35015649958_item	3630927	et	4	main
elada	doc_35015649958_item	3630926	et	3	main
tahan	doc_35015649958_item	3630925	et	3	main
ma	doc_35015649958_item	3630924	et	3	main
väga	doc_35015649958_item	3630919	et	3	main
hea	doc_35015649958_item	3630901	et	4	main
leedu	doc_35015649958_item	3630888	et	4	main
rääkida	doc_35015649958_item	3630882	et	3	main
keelt	doc_35015649958_item	3630879	et	4	main
mulle	doc_35015649958_item	3630867	et	4	main
uued	doc_35015649958_item	3630853	et	3	main
õhtud	doc_35015649958_item	3630851	et	3	main
peod	doc_35015649958_item	3630849	et	4	main
hullud	doc_35015649958_item	3630848	et	4	main
inimesega	doc_35015649958_item	3630847	et	3	main
huvidav	doc_35015649958_item	3630843	et	4	main
see	doc_35015649958_item	3630829	et	3	main
rakvere	doc_35015649958_item	3630828	et	4	main
meeldib	doc_35015649958_item	3630827	et	3	main
nendega	doc_35015649958_item	3630818	et	4	main
mägi	doc_35015649958_item	3630796	et	3	main
tallinn	doc_35015649958_item	3630790	et	4	main
eriti	doc_35015649958_item	3630789	et	3	main
olin	doc_35015649958_item	3630771	et	3	main
mina	doc_35015649958_item	3630760	et	4	main
essee	doc_35015649958_item	3630759	et	4	main
ilus	doc_35015649959_item	3631115	et	4	main
olin	doc_35015649959_item	3631114	et	3	main
mul	doc_35015649959_item	3631113	et	3	main
väsinud	doc_35015649959_item	3631112	et	4	main
olen	doc_35015649959_item	3631111	et	3	main
ma	doc_35015649959_item	3631110	et	3	main
kiel	doc_35015649956_item	3630701	et	4	main
erasmuse	doc_35015649958_item	3630956	et	4	main
mulle	doc_35015649958_item	3630949	et	4	main
positiivsed	doc_35015649958_item	3630947	et	3	main
aga	doc_35015649958_item	3630929	et	3	main
ilus	doc_35015649958_item	3630920	et	4	main
keelt	doc_35015649958_item	3630889	et	4	main
eesti	doc_35015649958_item	3630883	et	4	main
eesti	doc_35015649958_item	3630871	et	4	main
tahan	doc_35015649958_item	3630870	et	3	main
ma	doc_35015649958_item	3630869	et	3	main
tähtis	doc_35015649958_item	3630868	et	4	main
keelt	doc_35015649958_item	3630865	et	4	main
eesti	doc_35015649958_item	3630864	et	4	main
sellepärast	doc_35015649958_item	3630863	et	3	main
hämmastav	doc_35015649958_item	3630857	et	4	main
see	doc_35015649958_item	3630855	et	3	main
ja	doc_35015649958_item	3630852	et	3	main
filmi	doc_35015649958_item	3630850	et	4	main
oli	doc_35015649958_item	3630845	et	3	main
rakvere	doc_35015649958_item	3630841	et	4	main
hubane	doc_35015649958_item	3630836	et	3	main
ja	doc_35015649958_item	3630835	et	3	main
aga	doc_35015649958_item	3630832	et	3	main
väike	doc_35015649958_item	3630831	et	4	main
mulle	doc_35015649958_item	3630826	et	4	main
ida-eestis	doc_35015649958_item	3630823	et	3	main
kaks	doc_35015649958_item	3630821	et	3	main
tallinas	doc_35015649958_item	3630793	et	4	main
meeldib	doc_35015649958_item	3630787	et	3	main
keelega	doc_35015649958_item	3630785	et	3	main
semestri	doc_35015649958_item	3630783	et	3	main
lõppetan	doc_35015649958_item	3630782	et	4	main
ka	doc_35015649958_item	3630781	et	3	main
ma	doc_35015649958_item	3630780	et	3	main
praegu	doc_35015649958_item	3630779	et	3	main
see	doc_35015649958_item	3630766	et	3	main
maini	doc_35015649958_item	3630765	et	4	main
kuni	doc_35015649958_item	3630764	et	3	main
jaanuarist	doc_35015649958_item	3630763	et	3	main
meel	doc_35015649959_item	3631121	et	4	main
hea	doc_35015649959_item	3631120	et	4	main
on	doc_35015649959_item	3631119	et	4	main
mul	doc_35015649959_item	3631118	et	3	main
eestis	doc_35015649959_item	3631117	et	3	main
päev	doc_35015649959_item	3631116	et	3	main
kasutan	doc_35015649959_item	3631107	et	3	main
televisorit	doc_35015649959_item	3631105	et	4	main
söön	doc_35015649959_item	3631103	et	3	main
lähen	doc_35015649959_item	3631100	et	3	main
ma	doc_35015649959_item	3631099	et	3	main
ja	doc_35015649959_item	3631097	et	3	main
pastat	doc_35015649959_item	3631096	et	3	main
kõht	doc_35015649959_item	3631088	et	3	main
uuesti	doc_35015649959_item	3631086	et	3	main
ilus	doc_35015649959_item	3631084	et	4	main
finlandisse	doc_35015649959_item	3631063	et	4	main
sõidavad	doc_35015649959_item	3631062	et	3	main
on	doc_35015649959_item	3631058	et	4	main
külm	doc_35015649959_item	3631054	et	3	main
oleks	doc_35015649959_item	3631044	et	3	main
lieba	doc_35015649959_item	3631023	et	4	main
lähen	doc_35015649959_item	3631017	et	3	main
kingad	doc_35015649959_item	3631008	et	3	main
ma	doc_35015649959_item	3631004	et	3	main
new	doc_35015649959_item	3630988	et	4	main
siis	doc_35015649959_item	3630984	et	3	main
espresso	doc_35015649959_item	3630982	et	4	main
üles	doc_35015649959_item	3630975	et	3	main
ma	doc_35015649959_item	3630973	et	3	main
ja	doc_35015649958_item	3630954	et	3	main
aeg	doc_35015649958_item	3630952	et	3	main
meeldib	doc_35015649958_item	3630950	et	3	main
1	doc_35015649958_item	3630937	et	2	main
pühapäeval	doc_35015649958_item	3630936	et	3	main
see	doc_35015649958_item	3630935	et	3	main
kodus	doc_35015649958_item	3630934	et	4	main
minu	doc_35015649958_item	3630933	et	3	main
ja	doc_35015649958_item	3630922	et	3	main
tuuline	doc_35015649958_item	3630914	et	3	main
ja	doc_35015649958_item	3630913	et	3	main
külm	doc_35015649958_item	3630912	et	3	main
väga	doc_35015649958_item	3630911	et	3	main
oli	doc_35015649958_item	3630910	et	3	main
tallinas	doc_35015649958_item	3630909	et	4	main
talvel	doc_35015649958_item	3630908	et	4	main
tallinna	doc_35015649958_item	3630907	et	4	main
hea	doc_35015649958_item	3630906	et	4	main
ainust	doc_35015649958_item	3630905	et	4	main
mäletan	doc_35015649958_item	3630904	et	3	main
ma	doc_35015649958_item	3630903	et	3	main
õpetaja	doc_35015649958_item	3630902	et	4	main
väga	doc_35015649958_item	3630900	et	3	main
olid	doc_35015649958_item	3630899	et	4	main
sa	doc_35015649958_item	3630898	et	3	main
kasulik	doc_35015649958_item	3630897	et	3	main
ja	doc_35015649958_item	3630896	et	3	main
huvitav	doc_35015649958_item	3630895	et	4	main
väga	doc_35015649958_item	3630894	et	3	main
oli	doc_35015649958_item	3630893	et	3	main
sügisel	doc_35015649958_item	3630928	et	3	main
soe	doc_35015649958_item	3630921	et	4	main
on	doc_35015649958_item	3630918	et	4	main
kevad	doc_35015649958_item	3630916	et	3	main
aga	doc_35015649958_item	3630915	et	3	main
eesti	doc_35015649958_item	3630890	et	4	main
keelt	doc_35015649958_item	3630884	et	4	main
õppida	doc_35015649958_item	3630875	et	3	main
kodus	doc_35015649958_item	3630873	et	4	main
baltimaadega	doc_35015649958_item	3630862	et	3	main
oli	doc_35015649958_item	3630856	et	3	main
sõbrad	doc_35015649958_item	3630854	et	3	main
aeg	doc_35015649958_item	3630844	et	3	main
on	doc_35015649958_item	3630830	et	4	main
ja	doc_35015649958_item	3630824	et	3	main
ma	doc_35015649958_item	3630819	et	3	main
suhtud	doc_35015649958_item	3630817	et	3	main
ja	doc_35015649958_item	3630797	et	3	main
mulle	doc_35015649958_item	3630786	et	4	main
ma	doc_35015649958_item	3630773	et	3	main
ma	doc_35015649958_item	3630770	et	3	main
magan	doc_35015649959_item	3631124	et	3	main
ja	doc_35015649959_item	3631106	et	3	main
koju	doc_35015649959_item	3631101	et	3	main
on	doc_35015649959_item	3631089	et	4	main
mu	doc_35015649959_item	3631087	et	3	main
ilus	doc_35015649959_item	3631076	et	4	main
siis	doc_35015649959_item	3631075	et	3	main
punast	doc_35015649959_item	3631074	et	4	main
ole	doc_35015649959_item	3631071	et	4	main
ma	doc_35015649959_item	3631069	et	3	main
aga	doc_35015649959_item	3631068	et	3	main
täevas	doc_35015649959_item	3631057	et	4	main
puhkan	doc_35015649959_item	3631043	et	3	main
tundid	doc_35015649958_item	3630892	et	4	main
ja	doc_35015649958_item	3630887	et	3	main
keelt	doc_35015649958_item	3630886	et	4	main
ja	doc_35015649958_item	3630881	et	3	main
erasmuse	doc_35015649958_item	3630846	et	4	main
loss	doc_35015649958_item	3630842	et	3	main
lemmikkohad	doc_35015649958_item	3630792	et	4	main
minu	doc_35015649958_item	3630791	et	3	main
eesti	doc_35015649958_item	3630776	et	4	main
õppima	doc_35015649958_item	3630775	et	3	main
hakkasin	doc_35015649958_item	3630774	et	3	main
eestis	doc_35015649958_item	3630772	et	3	main
mis	doc_35015649958_item	3630769	et	4	main
aeg	doc_35015649958_item	3630768	et	3	main
on	doc_35015649958_item	3630767	et	4	main
ma	doc_35015649959_item	3631122	et	3	main
arvutit	doc_35015649959_item	3631108	et	3	main
kaheksast	doc_35015649959_item	3631079	et	4	main
õhtul	doc_35015649959_item	3631078	et	3	main
päikeseloojang	doc_35015649959_item	3631077	et	3	main
pruunet	doc_35015649959_item	3631072	et	4	main
pilves	doc_35015649959_item	3631060	et	4	main
natuke	doc_35015649959_item	3631059	et	4	main
on	doc_35015649959_item	3631052	et	4	main
ilus	doc_35015649959_item	3631051	et	4	main
oleks	doc_35015649959_item	3631050	et	3	main
ka	doc_35015649959_item	3631049	et	3	main
ilm	doc_35015649959_item	3631048	et	3	main
kui	doc_35015649959_item	3631047	et	3	main
päev	doc_35015649959_item	3631046	et	3	main
ilus	doc_35015649959_item	3631045	et	4	main
kapsas	doc_35015649959_item	3631024	et	4	main
sööki	doc_35015649959_item	3631022	et	4	main
lõunake	doc_35015649959_item	3631021	et	4	main
ostan	doc_35015649959_item	3631020	et	3	main
ja	doc_35015649959_item	3631019	et	3	main
selga	doc_35015649959_item	3631015	et	4	main
roosa	doc_35015649959_item	3631013	et	4	main
ja	doc_35015649959_item	3630996	et	3	main
ajalehte	doc_35015649959_item	3630987	et	4	main
üheksa	doc_35015649959_item	3630977	et	4	main
meeldib	doc_35015649960_item	3631150	et	3	main
ilusa	doc_35015649960_item	3631258	et	3	main
vanalinna	doc_35015649960_item	3631253	et	4	main
minna	doc_35015649960_item	3631252	et	3	main
tahan	doc_35015649960_item	3631251	et	3	main
ma	doc_35015649960_item	3631250	et	3	main
augustus	doc_35015649960_item	3631249	et	4	main
on	doc_35015649960_item	3631242	et	4	main
tallinna	doc_35015649960_item	3631239	et	4	main
ei	doc_35015649960_item	3631206	et	4	main
sõbrad	doc_35015649960_item	3631205	et	3	main
ja	doc_35015649960_item	3631204	et	3	main
jalgpalli	doc_786864950086_item	3631338	et	4	main
vaatan	doc_786864950086_item	3631336	et	3	main
mängin	doc_786864950086_item	3631333	et	3	main
õde	doc_786864950086_item	3631310	et	4	main
pensionil	doc_786864950086_item	3631309	et	3	main
mina	doc_786864950086_item	3631297	et	4	main
ülikoolis	doc_786864950086_item	3631296	et	4	main
on	doc_786864950086_item	3631280	et	4	main
minul	doc_786864950086_item	3631279	et	3	main
mina	doc_786864950086_item	3631271	et	4	main
perekkonnanimi	doc_786864950086_item	3631268	et	4	main
anna	doc_786864950086_item	3631266	et	4	main
olen	doc_786864950086_item	3631265	et	3	main
mina	doc_786864950086_item	3631264	et	4	main
essee	doc_786864950086_item	3631261	et	4	main
pidu	doc_278690626900_item	3631537	et	4	main
eestis	doc_278690626900_item	3631532	et	3	main
nagu	doc_278690626900_item	3631520	et	3	main
võtsid	doc_278690626900_item	3631516	et	4	main
eestlased	doc_278690626900_item	3631512	et	3	main
koorega	doc_278690626900_item	3631511	et	3	main
lastele	doc_278690626900_item	3631508	et	4	main
lauldati	doc_278690626900_item	3631501	et	4	main
ja	doc_278690626900_item	3631469	et	3	main
üldistav	doc_278690626900_item	3631466	et	4	main
arutlev	doc_278690626900_item	3631463	et	4	main
olema	doc_278690626900_item	3631462	et	4	main
essee	doc_278690626900_item	3631449	et	4	main
test	doc_278690626900_item	3631446	et	3	main
teise	doc_278690626900_item	3631444	et	4	main
kui	doc_278690626900_item	3631443	et	3	main
on	doc_35015649958_item	3630840	et	4	main
lemmikkoht	doc_35015649958_item	3630839	et	3	main
minu	doc_35015649958_item	3630838	et	3	main
linn	doc_35015649958_item	3630837	et	3	main
ilus	doc_35015649958_item	3630834	et	4	main
väga	doc_35015649958_item	3630833	et	3	main
lõuna-eestis	doc_35015649958_item	3630825	et	3	main
ekskursioonid	doc_35015649958_item	3630822	et	3	main
olin	doc_35015649958_item	3630820	et	3	main
hea	doc_35015649958_item	3630816	et	4	main
oli	doc_35015649958_item	3630815	et	3	main
mul	doc_35015649958_item	3630814	et	3	main
aga	doc_35015649958_item	3630813	et	3	main
avatud	doc_35015649958_item	3630812	et	4	main
ole	doc_35015649958_item	3630811	et	4	main
ei	doc_35015649958_item	3630810	et	4	main
nad	doc_35015649958_item	3630809	et	3	main
inimesed	doc_35015649958_item	3630808	et	3	main
eestis	doc_35015649958_item	3630807	et	3	main
meeldib	doc_35015649958_item	3630806	et	3	main
ka	doc_35015649958_item	3630805	et	3	main
mulle	doc_35015649958_item	3630804	et	4	main
plads	doc_35015649958_item	3630803	et	4	main
ja	doc_35015649958_item	3630801	et	3	main
rakegoja	doc_35015649958_item	3630802	et	4	main
margareeta	doc_35015649958_item	3630800	et	3	main
paks	doc_35015649958_item	3630799	et	3	main
park	doc_35015649958_item	3630798	et	3	main
toompea	doc_35015649958_item	3630795	et	4	main
on	doc_35015649958_item	3630794	et	4	main
eesti	doc_35015649958_item	3630788	et	4	main
eesti	doc_35015649958_item	3630784	et	4	main
ja	doc_35015649958_item	3630778	et	3	main
keelt	doc_35015649958_item	3630777	et	4	main
eesti	doc_35015649958_item	3630762	et	4	main
ja	doc_35015649958_item	3630761	et	3	main
raskelt	doc_35015649959_item	3631123	et	4	main
siis	doc_35015649959_item	3631109	et	3	main
ostan	doc_35015649959_item	3631095	et	3	main
poodi	doc_35015649959_item	3631093	et	4	main
tühi	doc_35015649959_item	3631090	et	3	main
siis	doc_35015649959_item	3631085	et	3	main
väga	doc_35015649959_item	3631083	et	3	main
on	doc_35015649959_item	3631081	et	4	main
üheteistkümneni	doc_35015649959_item	3631080	et	4	main
laevad	doc_35015649959_item	3631061	et	4	main
äärres	doc_35015649959_item	3631056	et	4	main
natuke	doc_35015649959_item	3631053	et	4	main
äärre	doc_35015649959_item	3631041	et	4	main
mere	doc_35015649959_item	3631040	et	3	main
istan	doc_35015649959_item	3631039	et	4	main
ma	doc_35015649959_item	3631038	et	3	main
juures	doc_35015649959_item	3631037	et	4	main
kadrioru	doc_35015649959_item	3631036	et	3	main
randasse	doc_35015649959_item	3631035	et	3	main
jalatan	doc_35015649959_item	3631034	et	4	main
soid	doc_35015649959_item	3631033	et	3	main
ma	doc_35015649959_item	3631032	et	3	main
siis	doc_35015649959_item	3631031	et	3	main
sibulat	doc_35015649959_item	3631030	et	3	main
punast	doc_35015649959_item	3631029	et	4	main
ja	doc_35015649959_item	3631028	et	3	main
hapukoore	doc_35015649959_item	3631027	et	4	main
heeringad	doc_35015649959_item	3631026	et	3	main
pirukad	doc_35015649959_item	3631025	et	3	main
jalga	doc_35015649959_item	3631009	et	4	main
ennast	doc_35015649959_item	3631001	et	4	main
pesan	doc_35015649959_item	3631000	et	4	main
ma	doc_35015649959_item	3630999	et	3	main
siis	doc_35015649959_item	3630998	et	3	main
kulturist	doc_35015649959_item	3630997	et	4	main
piimaga	doc_35015649959_item	3630983	et	3	main
must	doc_35015649959_item	3630981	et	4	main
tõusan	doc_35015649959_item	3630974	et	4	main
mulle	doc_35015649960_item	3631163	et	4	main
väga	doc_35015649960_item	3631161	et	3	main
eestis	doc_35015649960_item	3631154	et	3	main
näidata	doc_35015649960_item	3631257	et	4	main
ja	doc_35015649960_item	3631256	et	3	main
perega	doc_35015649960_item	3631255	et	3	main
minu	doc_35015649960_item	3631254	et	3	main
ilus	doc_35015649960_item	3631243	et	4	main
kirjandust	doc_35015649960_item	3631236	et	3	main
kuidas	doc_35015649960_item	3631231	et	3	main
huvitatud	doc_35015649960_item	3631230	et	4	main
ja	doc_35015649960_item	3631227	et	3	main
keelt	doc_35015649960_item	3631224	et	4	main
jaapani	doc_35015649960_item	3631201	et	4	main
vaatan	doc_35015649959_item	3631104	et	3	main
ma	doc_35015649959_item	3631102	et	3	main
tomatikastmet	doc_35015649959_item	3631098	et	4	main
ma	doc_35015649959_item	3631094	et	3	main
lähen	doc_35015649959_item	3631092	et	3	main
ma	doc_35015649959_item	3631091	et	3	main
väga	doc_35015649959_item	3631082	et	3	main
või	doc_35015649959_item	3631073	et	4	main
ei	doc_35015649959_item	3631070	et	4	main
päistab	doc_35015649959_item	3631067	et	4	main
päike	doc_35015649959_item	3631066	et	3	main
eestisse	doc_35015649959_item	3631065	et	4	main
ja	doc_35015649959_item	3631064	et	3	main
mere	doc_35015649959_item	3631055	et	3	main
ja	doc_35015649959_item	3631042	et	3	main
poodi	doc_35015649959_item	3631018	et	4	main
musta	doc_35015649959_item	3631010	et	4	main
teksad	doc_35015649959_item	3631006	et	4	main
panen	doc_35015649959_item	3631005	et	3	main
duši	doc_35015649959_item	3631002	et	2	main
reisist	doc_35015649959_item	3630994	et	3	main
meeldib	doc_35015649959_item	3630992	et	3	main
times	doc_35015649959_item	3630990	et	4	main
lugeksin	doc_35015649959_item	3630986	et	4	main
raske	doc_35015649959_item	3630980	et	4	main
joon	doc_35015649959_item	3630979	et	4	main
ja	doc_35015649959_item	3630978	et	3	main
suvil	doc_35015649960_item	3631155	et	4	main
eesti	doc_35015649960_item	3631151	et	4	main
vanalinna	doc_35015649960_item	3631259	et	4	main
pere	doc_35015649960_item	3631247	et	4	main
minu	doc_35015649960_item	3631246	et	3	main
vanalinn	doc_35015649960_item	3631240	et	3	main
meeldib	doc_35015649960_item	3631238	et	3	main
jaapani	doc_35015649960_item	3631235	et	4	main
õpinud	doc_35015649960_item	3631234	et	4	main
eesti	doc_35015649960_item	3631216	et	4	main
pere	doc_35015649960_item	3631203	et	4	main
minu	doc_35015649960_item	3631202	et	3	main
on	doc_35015649960_item	3631198	et	4	main
suusahüppet	doc_786864950086_item	3631340	et	4	main
jalgpalli	doc_786864950086_item	3631334	et	4	main
mina	doc_786864950086_item	3631332	et	4	main
pallimängud	doc_786864950086_item	3631331	et	3	main
meeldivad	doc_786864950086_item	3631330	et	4	main
ema	doc_786864950086_item	3631307	et	4	main
mina	doc_786864950086_item	3631290	et	4	main
ja	doc_786864950086_item	3631287	et	3	main
on	doc_786864950086_item	3631284	et	4	main
minul	doc_786864950086_item	3631283	et	3	main
pere	doc_786864950086_item	3631282	et	4	main
suur	doc_786864950086_item	3631281	et	3	main
vana	doc_786864950086_item	3631275	et	4	main
aastat	doc_786864950086_item	3631274	et	3	main
on	doc_786864950086_item	3631269	et	4	main
minu	doc_786864950086_item	3631267	et	3	main
ma	doc_35015649959_item	3631016	et	3	main
kampsuni	doc_35015649959_item	3631014	et	4	main
ja	doc_35015649959_item	3631012	et	3	main
t-särgi	doc_35015649959_item	3631011	et	4	main
ja	doc_35015649959_item	3631007	et	3	main
all	doc_35015649959_item	3631003	et	3	main
toitist	doc_35015649959_item	3630995	et	4	main
lugeda	doc_35015649959_item	3630993	et	3	main
mulle	doc_35015649959_item	3630991	et	4	main
york	doc_35015649959_item	3630989	et	4	main
ma	doc_35015649959_item	3630985	et	3	main
kell	doc_35015649959_item	3630976	et	3	main
pühapäevaks	doc_35015649959_item	3630972	et	3	main
on	doc_35015649959_item	3630971	et	4	main
nii	doc_35015649959_item	3630970	et	3	main
oleks	doc_35015649959_item	3630969	et	3	main
eestis	doc_35015649959_item	3630968	et	3	main
päev	doc_35015649959_item	3630967	et	3	main
ilus	doc_35015649959_item	3630966	et	4	main
oleks	doc_35015649959_item	3630965	et	3	main
kui	doc_35015649959_item	3630964	et	3	main
eestis	doc_35015649959_item	3630963	et	3	main
on	doc_35015649959_item	3630962	et	4	main
päev	doc_35015649959_item	3630961	et	3	main
ilus	doc_35015649959_item	3630960	et	4	main
essee	doc_35015649959_item	3630959	et	4	main
ilus	doc_35015649960_item	3631162	et	4	main
särav	doc_35015649960_item	3631157	et	4	main
on	doc_35015649960_item	3631156	et	4	main
suvi	doc_35015649960_item	3631152	et	3	main
ja	doc_35015649960_item	3631148	et	3	main
värrikas	doc_35015649960_item	3631245	et	4	main
ja	doc_35015649960_item	3631244	et	3	main
üliõpilased	doc_35015649960_item	3631233	et	3	main
olen	doc_35015649960_item	3631229	et	3	main
ma	doc_35015649960_item	3631228	et	3	main
ja	doc_35015649960_item	3631225	et	3	main
mõned	doc_35015649960_item	3631215	et	3	main
et	doc_35015649960_item	3631214	et	3	main
ma	doc_35015649960_item	3631212	et	3	main
aga	doc_35015649960_item	3631211	et	3	main
oli	doc_35015649960_item	3631210	et	3	main
eesti	doc_35015649960_item	3631209	et	4	main
kus	doc_35015649960_item	3631208	et	3	main
teanud	doc_35015649960_item	3631207	et	4	main
maa	doc_35015649960_item	3631200	et	4	main
väiksem	doc_35015649960_item	3631199	et	4	main
ja	doc_786864950086_item	3631341	et	3	main
aga	doc_786864950086_item	3631335	et	3	main
spordist	doc_786864950086_item	3631327	et	3	main
on	doc_786864950086_item	3631308	et	4	main
soome	doc_786864950086_item	3631292	et	3	main
õpin	doc_786864950086_item	3631291	et	3	main
kaks	doc_786864950086_item	3631285	et	3	main
22	doc_786864950086_item	3631273	et	2	main
olen	doc_786864950086_item	3631272	et	3	main
1869	doc_278690626900_item	3631533	et	2	main
laulupidu	doc_278690626900_item	3631530	et	4	main
asi	doc_278690626900_item	3631523	et	4	main
üks	doc_278690626900_item	3631522	et	3	main
ema	doc_278690626900_item	3631506	et	4	main
või	doc_278690626900_item	3631505	et	4	main
moned	doc_278690626900_item	3631497	et	4	main
lugemistekstis	doc_278690626900_item	3631470	et	3	main
loengus	doc_278690626900_item	3631468	et	3	main
ja	doc_278690626900_item	3631465	et	3	main
eestlastest	doc_278690626900_item	3631453	et	4	main
teeb	doc_278690626900_item	3631452	et	3	main
mis	doc_278690626900_item	3631451	et	4	main
teemal	doc_278690626900_item	3631450	et	3	main
sõnastikud	doc_786864950087_item	3631438	et	3	main
on	doc_35015649960_item	3631160	et	4	main
see	doc_35015649960_item	3631159	et	3	main
ööd	doc_35015649960_item	3631158	et	4	main
sest	doc_35015649960_item	3631153	et	4	main
mulle	doc_35015649960_item	3631149	et	4	main
lahke	doc_35015649960_item	3631147	et	4	main
ja	doc_35015649960_item	3631146	et	3	main
sõbralik	doc_35015649960_item	3631145	et	3	main
on	doc_35015649960_item	3631144	et	4	main
eestilane	doc_35015649960_item	3631143	et	4	main
eesti	doc_35015649960_item	3631142	et	4	main
meeldib	doc_35015649960_item	3631141	et	3	main
mulle	doc_35015649960_item	3631140	et	4	main
jaaniaris	doc_35015649960_item	3631139	et	4	main
eestisse	doc_35015649960_item	3631138	et	4	main
tulesin	doc_35015649960_item	3631137	et	4	main
ma	doc_35015649960_item	3631136	et	3	main
kuuks	doc_35015649960_item	3631135	et	3	main
neljaks	doc_35015649960_item	3631134	et	4	main
eestis	doc_35015649960_item	3631133	et	3	main
elanud	doc_35015649960_item	3631132	et	4	main
olen	doc_35015649960_item	3631131	et	3	main
ma	doc_35015649960_item	3631130	et	3	main
eesti	doc_35015649960_item	3631129	et	4	main
ja	doc_35015649960_item	3631128	et	3	main
mina	doc_35015649960_item	3631127	et	4	main
essee	doc_35015649960_item	3631126	et	4	main
tulenud	doc_35015649960_item	3631248	et	4	main
vanalinn	doc_35015649960_item	3631241	et	3	main
mulle	doc_35015649960_item	3631237	et	4	main
eesti	doc_35015649960_item	3631232	et	4	main
kirjandust	doc_35015649960_item	3631226	et	3	main
jaapani	doc_35015649960_item	3631223	et	4	main
õpisid	doc_35015649960_item	3631222	et	4	main
ja	doc_35015649960_item	3631221	et	3	main
jaapani	doc_35015649960_item	3631220	et	4	main
huvitatud	doc_35015649960_item	3631219	et	4	main
olid	doc_35015649960_item	3631218	et	4	main
üliõpilasi	doc_35015649960_item	3631217	et	3	main
teasin	doc_35015649960_item	3631213	et	4	main
eesti	doc_35015649960_item	3631197	et	4	main
eesti	doc_35015649960_item	3631196	et	4	main
valisin	doc_35015649960_item	3631195	et	3	main
ma	doc_35015649960_item	3631194	et	3	main
miks	doc_35015649960_item	3631193	et	4	main
küsisid	doc_35015649960_item	3631192	et	4	main
kõik	doc_35015649960_item	3631191	et	4	main
üliõpilanena	doc_35015649960_item	3631190	et	4	main
vahemine	doc_35015649960_item	3631189	et	4	main
eestisse	doc_35015649960_item	3631188	et	4	main
minna	doc_35015649960_item	3631187	et	3	main
tahasin	doc_35015649960_item	3631186	et	4	main
ma	doc_35015649960_item	3631185	et	3	main
et	doc_35015649960_item	3631184	et	3	main
sõpra	doc_35015649960_item	3631183	et	4	main
ja	doc_35015649960_item	3631182	et	3	main
pere	doc_35015649960_item	3631181	et	4	main
minu	doc_35015649960_item	3631180	et	3	main
ütlesin	doc_35015649960_item	3631179	et	3	main
ma	doc_35015649960_item	3631178	et	3	main
kui	doc_35015649960_item	3631177	et	3	main
suve	doc_35015649960_item	3631176	et	4	main
eesti	doc_35015649960_item	3631175	et	4	main
kogeda	doc_35015649960_item	3631174	et	3	main
saan	doc_35015649960_item	3631173	et	4	main
ma	doc_35015649960_item	3631172	et	3	main
sest	doc_35015649960_item	3631171	et	4	main
õnnelik	doc_35015649960_item	3631170	et	3	main
olen	doc_35015649960_item	3631169	et	3	main
ma	doc_35015649960_item	3631168	et	3	main
suvi	doc_35015649960_item	3631167	et	3	main
jaapani	doc_35015649960_item	3631166	et	4	main
meeldi	doc_35015649960_item	3631165	et	4	main
ei	doc_35015649960_item	3631164	et	4	main
tennis	doc_786864950086_item	3631339	et	3	main
televiisoris	doc_786864950086_item	3631337	et	3	main
huvitatud	doc_786864950086_item	3631328	et	4	main
isa	doc_786864950086_item	3631305	et	4	main
keelt	doc_786864950086_item	3631304	et	4	main
ja	doc_786864950086_item	3631302	et	3	main
saksa	doc_786864950086_item	3631301	et	4	main
rootsi	doc_786864950086_item	3631300	et	4	main
soome	doc_786864950086_item	3631299	et	3	main
räägin	doc_786864950086_item	3631298	et	3	main
rootsi	doc_786864950086_item	3631294	et	4	main
ja	doc_786864950086_item	3631293	et	3	main
üks	doc_786864950086_item	3631288	et	3	main
venda	doc_786864950086_item	3631286	et	4	main
budapestis	doc_786864950086_item	3631278	et	4	main
käsipalli	doc_786864950086_item	3631342	et	4	main
mulle	doc_786864950086_item	3631329	et	4	main
olen	doc_786864950086_item	3631326	et	3	main
mina	doc_786864950086_item	3631325	et	4	main
budapestis	doc_786864950086_item	3631324	et	4	main
asu	doc_786864950086_item	3631323	et	4	main
ei	doc_786864950086_item	3631322	et	4	main
ta	doc_786864950086_item	3631321	et	4	main
seest	doc_786864950086_item	3631320	et	3	main
järele	doc_786864950086_item	3631319	et	4	main
tema	doc_786864950086_item	3631318	et	4	main
igatseva	doc_786864950086_item	3631317	et	4	main
ema	doc_786864950086_item	3631316	et	4	main
ja	doc_786864950086_item	3631315	et	3	main
isa	doc_786864950086_item	3631314	et	4	main
keelt	doc_786864950086_item	3631313	et	4	main
saksa	doc_786864950086_item	3631312	et	4	main
õpib	doc_786864950086_item	3631311	et	3	main
ja	doc_786864950086_item	3631306	et	3	main
inglise	doc_786864950086_item	3631303	et	4	main
keelt	doc_786864950086_item	3631295	et	4	main
õde	doc_786864950086_item	3631289	et	4	main
pere	doc_786864950086_item	3631263	et	4	main
see	doc_278690626900_item	3631536	et	3	main
ülemaaline	doc_278690626900_item	3631529	et	4	main
esimene	doc_278690626900_item	3631528	et	3	main
et	doc_278690626900_item	3631527	et	3	main
see	doc_278690626900_item	3631526	et	3	main
veel	doc_278690626900_item	3631525	et	4	main
bajaan	doc_278690626900_item	3631521	et	3	main
tihti	doc_278690626900_item	3631509	et	3	main
oma	doc_278690626900_item	3631507	et	4	main
laulu	doc_278690626900_item	3631500	et	4	main
piibliast	doc_278690626900_item	3631499	et	3	main
olid	doc_278690626900_item	3631498	et	4	main
esitatud	doc_278690626900_item	3631471	et	4	main
tuginema	doc_278690626900_item	3631467	et	3	main
pikkus	doc_278690626900_item	3631456	et	4	main
essee	doc_278690626900_item	3631455	et	4	main
laulurahva	doc_278690626900_item	3631454	et	3	main
kirjutage	doc_278690626900_item	3631448	et	3	main
essee	doc_278690626900_item	3631440	et	4	main
asun	doc_786864950086_item	3631277	et	3	main
mina	doc_786864950086_item	3631276	et	4	main
tamm	doc_786864950086_item	3631270	et	3	main
minu	doc_786864950086_item	3631262	et	3	main
tartus	doc_278690626900_item	3631535	et	3	main
vene	doc_278690626900_item	3631518	et	4	main
instrumentid	doc_278690626900_item	3631517	et	4	main
nad	doc_278690626900_item	3631515	et	3	main
instrumentaariumit	doc_278690626900_item	3631514	et	3	main
kasutasid	doc_278690626900_item	3631513	et	4	main
lauldati	doc_278690626900_item	3631510	et	4	main
peol	doc_278690626900_item	3631504	et	4	main
olid	doc_278690626900_item	3631495	et	4	main
suzeetid	doc_278690626900_item	3631494	et	4	main
traditsioon	doc_278690626900_item	3631493	et	3	main
oli	doc_278690626900_item	3631492	et	3	main
analüüsiv	doc_278690626900_item	3631464	et	4	main
sõna	doc_278690626900_item	3631459	et	4	main
350	doc_278690626900_item	3631458	et	2	main
300	doc_278690626900_item	3631457	et	2	main
kirjutamine	doc_278690626900_item	3631447	et	4	main
keele	doc_278690626900_item	3631445	et	4	main
vaibad	doc_786864950087_item	3631425	et	3	main
on	doc_786864950087_item	3631424	et	4	main
on	doc_786864950087_item	3631421	et	4	main
põrand	doc_786864950087_item	3631420	et	3	main
õe	doc_786864950087_item	3631411	et	4	main
arvuti	doc_786864950087_item	3631410	et	4	main
ja	doc_786864950087_item	3631409	et	3	main
lamp	doc_786864950087_item	3631408	et	3	main
seinal	doc_786864950087_item	3631402	et	3	main
valge	doc_786864950087_item	3631400	et	4	main
kaks	doc_786864950087_item	3631395	et	3	main
kolm	doc_786864950087_item	3631390	et	3	main
seinad	doc_786864950087_item	3631381	et	3	main
toasse	doc_786864950087_item	3631380	et	3	main
tuba	doc_786864950087_item	3631346	et	4	main
lastega	doc_278690626900_item	3631566	et	3	main
ja	doc_278690626900_item	3631565	et	3	main
sõpradega	doc_278690626900_item	3631564	et	3	main
perega	doc_278690626900_item	3631563	et	3	main
koos	doc_278690626900_item	3631562	et	4	main
lauluga	doc_278690626901_item	3631643	et	4	main
hea	doc_278690626901_item	3631637	et	4	main
väga	doc_278690626901_item	3631636	et	3	main
on	doc_278690626901_item	3631635	et	4	main
see	doc_278690626901_item	3631634	et	3	main
et	doc_278690626901_item	3631633	et	3	main
arvamus	doc_278690626901_item	3631632	et	3	main
see	doc_278690626901_item	3631631	et	3	main
rahvalaul	doc_278690626901_item	3631623	et	4	main
last	doc_278690626901_item	3631621	et	4	main
lauladki	doc_278690626902_item	3631790	et	3	main
tema	doc_278690626902_item	3631789	et	4	main
nendest	doc_278690626902_item	3631788	et	4	main
üks	doc_278690626902_item	3631787	et	3	main
on	doc_278690626902_item	3631786	et	4	main
kahes	doc_278690626902_item	3631783	et	4	main
esimine	doc_278690626902_item	3631769	et	4	main
regilaulu	doc_278690626902_item	3631767	et	4	main
tarapita	doc_278690626902_item	3631766	et	4	main
need	doc_278690626902_item	3631760	et	3	main
teame	doc_278690626902_item	3631759	et	3	main
eestimaal	doc_278690626902_item	3631748	et	4	main
mis	doc_278690626902_item	3631744	et	4	main
välja	doc_278690626902_item	3631742	et	4	main
veel	doc_278690626902_item	3631741	et	4	main
ajast	doc_278690626902_item	3631731	et	4	main
on	doc_278690626902_item	3631727	et	4	main
on	doc_278690626902_item	3631722	et	4	main
on	doc_278690626902_item	3631720	et	4	main
rahvas	doc_278690626902_item	3631719	et	4	main
näidetega	doc_278690626902_item	3631711	et	3	main
on	doc_278690626902_item	3631708	et	4	main
test	doc_278690626902_item	3631680	et	3	main
keele	doc_278690626902_item	3631679	et	4	main
eesti	doc_278690626902_item	3631675	et	4	main
eesmärk	doc_278690626903_item	3631930	et	3	main
tööl	doc_278690626903_item	3631925	et	3	main
n	doc_278690626903_item	3631916	et	4	main
kahekesi	doc_278690626903_item	3631914	et	3	main
laulsid	doc_278690626903_item	3631903	et	4	main
aastal	doc_278690626900_item	3631534	et	3	main
toimus	doc_278690626900_item	3631531	et	3	main
on	doc_278690626900_item	3631524	et	4	main
rahvast	doc_278690626900_item	3631519	et	4	main
näiteks	doc_278690626900_item	3631503	et	4	main
tööl	doc_278690626900_item	3631502	et	3	main
eralised	doc_278690626900_item	3631496	et	4	main
laulma	doc_278690626900_item	3631491	et	3	main
laulu	doc_278690626900_item	3631490	et	4	main
rõõmustada	doc_278690626900_item	3631489	et	3	main
elust	doc_278690626900_item	3631488	et	3	main
neid	doc_278690626900_item	3631487	et	4	main
aitas	doc_278690626900_item	3631486	et	3	main
laul	doc_278690626900_item	3631485	et	4	main
hauani	doc_278690626900_item	3631484	et	3	main
hällist	doc_278690626900_item	3631483	et	4	main
eestlast	doc_278690626900_item	3631482	et	4	main
laul	doc_278690626900_item	3631481	et	4	main
saatis	doc_278690626900_item	3631480	et	3	main
ajal	doc_278690626900_item	3631479	et	4	main
vanal	doc_278690626900_item	3631478	et	3	main
näidetega	doc_278690626900_item	3631477	et	3	main
illustreerida	doc_278690626900_item	3631476	et	3	main
soovitatav	doc_278690626900_item	3631475	et	4	main
on	doc_278690626900_item	3631474	et	4	main
väiteid	doc_278690626900_item	3631473	et	4	main
faktidele	doc_278690626900_item	3631472	et	3	main
peab	doc_278690626900_item	3631461	et	4	main
essee	doc_278690626900_item	3631460	et	4	main
eesti	doc_278690626900_item	3631441	et	4	main
on	doc_786864950087_item	3631435	et	4	main
raamaturiiul	doc_786864950087_item	3631433	et	4	main
on	doc_786864950087_item	3631432	et	4	main
helepruun	doc_786864950087_item	3631422	et	3	main
laudal	doc_786864950087_item	3631412	et	3	main
pildid	doc_786864950087_item	3631404	et	3	main
kaks	doc_786864950087_item	3631392	et	3	main
kappi	doc_786864950087_item	3631391	et	4	main
on	doc_786864950087_item	3631389	et	4	main
toas	doc_786864950087_item	3631388	et	3	main
helerohelinen	doc_786864950087_item	3631387	et	4	main
ka	doc_786864950087_item	3631386	et	3	main
on	doc_786864950087_item	3631385	et	4	main
õde	doc_786864950087_item	3631378	et	4	main
minu	doc_786864950087_item	3631345	et	3	main
essee	doc_786864950087_item	3631344	et	4	main
minna	doc_278690626901_item	3631644	et	3	main
töötades	doc_278690626901_item	3631620	et	3	main
essee	doc_278690626901_item	3631588	et	4	main
sõna	doc_278690626901_item	3631587	et	4	main
300	doc_278690626901_item	3631585	et	2	main
laulurahva	doc_278690626901_item	3631582	et	3	main
eestlastest	doc_278690626901_item	3631581	et	4	main
teeb	doc_278690626901_item	3631580	et	3	main
raske	doc_278690626902_item	3631803	et	4	main
me	doc_278690626902_item	3631758	et	4	main
usuldasid	doc_278690626902_item	3631754	et	4	main
missugustel	doc_278690626902_item	3631752	et	3	main
ja	doc_278690626902_item	3631751	et	3	main
ole	doc_278690626902_item	3631740	et	4	main
niimoodi	doc_278690626902_item	3631729	et	3	main
nimetatud	doc_278690626902_item	3631728	et	4	main
eestlasi	doc_278690626902_item	3631726	et	3	main
miks	doc_278690626902_item	3631725	et	4	main
põhjusi	doc_278690626902_item	3631724	et	3	main
laulurahvas	doc_278690626902_item	3631721	et	4	main
on	doc_278690626902_item	3631714	et	4	main
päris	doc_278690626902_item	3631712	et	4	main
essee	doc_278690626902_item	3631683	et	4	main
kirjutage	doc_278690626902_item	3631682	et	3	main
keele	doc_278690626902_item	3631676	et	4	main
keele	doc_278690626900_item	3631442	et	4	main
raamaturiiulil	doc_786864950087_item	3631434	et	3	main
triibulised	doc_786864950087_item	3631428	et	4	main
puust	doc_786864950087_item	3631419	et	4	main
on	doc_786864950087_item	3631418	et	4	main
on	doc_786864950087_item	3631407	et	4	main
laudal	doc_786864950087_item	3631406	et	3	main
ja	doc_786864950087_item	3631394	et	3	main
helerohelised	doc_786864950087_item	3631383	et	4	main
on	doc_786864950087_item	3631382	et	4	main
asume	doc_786864950087_item	3631379	et	3	main
vanas	doc_786864950087_item	3631349	et	3	main
rahvapidu	doc_278690626900_item	3631559	et	4	main
suur	doc_278690626900_item	3631558	et	3	main
on	doc_278690626900_item	3631557	et	4	main
praegu	doc_278690626900_item	3631555	et	3	main
laulupidu	doc_278690626900_item	3631556	et	4	main
õigused	doc_278690626900_item	3631554	et	4	main
on	doc_278690626900_item	3631553	et	4	main
neel	doc_278690626900_item	3631552	et	3	main
et	doc_278690626900_item	3631551	et	3	main
tõestavad	doc_278690626900_item	3631550	et	4	main
ja	doc_278690626900_item	3631549	et	3	main
rahvas	doc_278690626900_item	3631548	et	4	main
iseseisev	doc_278690626900_item	3631547	et	3	main
on	doc_278690626900_item	3631546	et	4	main
nad	doc_278690626900_item	3631545	et	3	main
arvamust	doc_278690626900_item	3631544	et	3	main
oma	doc_278690626900_item	3631543	et	4	main
omandavad	doc_278690626900_item	3631542	et	4	main
eestlased	doc_278690626900_item	3631541	et	3	main
et	doc_278690626900_item	3631540	et	3	main
näitama	doc_278690626900_item	3631539	et	3	main
pidi	doc_278690626900_item	3631538	et	4	main
ja	doc_786864950087_item	3631437	et	3	main
märkmikud	doc_786864950087_item	3631436	et	4	main
põrandal	doc_786864950087_item	3631423	et	3	main
on	doc_786864950087_item	3631413	et	4	main
ripub	doc_786864950087_item	3631403	et	3	main
kirjutuslaudda	doc_786864950087_item	3631396	et	4	main
lagi	doc_786864950087_item	3631384	et	4	main
tullakse	doc_278690626900_item	3631561	et	3	main
laul	doc_278690626901_item	3631645	et	4	main
saaks	doc_278690626901_item	3631641	et	3	main
asu	doc_278690626901_item	3631638	et	4	main
on	doc_278690626901_item	3631630	et	4	main
mul	doc_278690626901_item	3631629	et	3	main
traditsioonid	doc_278690626901_item	3631628	et	3	main
rahva	doc_278690626901_item	3631627	et	3	main
minevik	doc_278690626901_item	3631626	et	3	main
rahva	doc_278690626901_item	3631625	et	3	main
pikkus	doc_278690626901_item	3631584	et	4	main
essee	doc_278690626901_item	3631583	et	4	main
test	doc_278690626901_item	3631574	et	3	main
keele	doc_278690626901_item	3631573	et	4	main
teise	doc_278690626901_item	3631572	et	4	main
kui	doc_278690626901_item	3631571	et	3	main
keele	doc_278690626901_item	3631570	et	4	main
eesti	doc_278690626901_item	3631569	et	4	main
essee	doc_278690626901_item	3631568	et	4	main
minevik	doc_278690626902_item	3631804	et	3	main
ennamik	doc_278690626902_item	3631791	et	4	main
maalev	doc_278690626902_item	3631785	et	4	main
jaganeb	doc_278690626902_item	3631782	et	4	main
regilaulul	doc_278690626902_item	3631781	et	3	main
suheldes	doc_278690626902_item	3631780	et	3	main
tegeldes	doc_278690626902_item	3631779	et	3	main
lastega	doc_278690626902_item	3631778	et	3	main
töödes	doc_278690626902_item	3631777	et	3	main
laulsid	doc_278690626902_item	3631776	et	4	main
lauludetüüp	doc_278690626902_item	3631770	et	4	main
vanemuine	doc_278690626902_item	3631763	et	4	main
laulujumal	doc_278690626902_item	3631762	et	3	main
on	doc_278690626902_item	3631761	et	4	main
kaks	doc_278690626902_item	3631756	et	3	main
olnud	doc_278690626902_item	3631747	et	4	main
ei	doc_278690626902_item	3631739	et	4	main
praegu	doc_278690626902_item	3631738	et	3	main
kuigi	doc_278690626902_item	3631737	et	3	main
palju	doc_278690626902_item	3631723	et	4	main
kaua	doc_278690626902_item	3631713	et	3	main
soovitatav	doc_278690626902_item	3631709	et	4	main
kirjutamine	doc_278690626902_item	3631681	et	4	main
essee	doc_278690626902_item	3631674	et	4	main
rahvalaul	doc_278690626903_item	3631929	et	4	main
mehed	doc_278690626903_item	3631923	et	3	main
e	doc_278690626903_item	3631917	et	4	main
ja	doc_278690626903_item	3631911	et	3	main
kirikus	doc_278690626903_item	3631909	et	3	main
laulsid	doc_278690626903_item	3631907	et	4	main
inimesed	doc_278690626903_item	3631906	et	3	main
ja	doc_278690626903_item	3631902	et	3	main
mängisi	doc_278690626903_item	3631901	et	4	main
siis	doc_278690626903_item	3631894	et	3	main
uuem	doc_278690626903_item	3631878	et	4	main
ja	doc_278690626903_item	3631877	et	3	main
näeme	doc_278690626903_item	3631859	et	3	main
hakkasid	doc_278690626903_item	3631847	et	4	main
väiteid	doc_278690626903_item	3631839	et	4	main
lugemistekstis	doc_278690626903_item	3631836	et	3	main
loengus	doc_278690626903_item	3631834	et	3	main
keele	doc_278690626903_item	3631811	et	4	main
teise	doc_278690626903_item	3631810	et	4	main
eesti	doc_278690626903_item	3631807	et	4	main
sümboliteks	doc_278690626903_item	3632016	et	3	main
uuemad	doc_278690626903_item	3632010	et	4	main
ka	doc_278690626903_item	3632009	et	3	main
mailmast	doc_278690626903_item	3631987	et	4	main
kokku	doc_278690626903_item	3631986	et	3	main
sõidavad	doc_278690626903_item	3631985	et	3	main
kohal	doc_786864950087_item	3631431	et	4	main
lauda	doc_786864950087_item	3631430	et	4	main
minu	doc_786864950087_item	3631429	et	3	main
on	doc_786864950087_item	3631427	et	4	main
molemad	doc_786864950087_item	3631426	et	4	main
uks	doc_786864950087_item	3631417	et	3	main
raadio	doc_786864950087_item	3631416	et	4	main
ja	doc_786864950087_item	3631415	et	3	main
lamp	doc_786864950087_item	3631414	et	3	main
minu	doc_786864950087_item	3631405	et	3	main
kaardin	doc_786864950087_item	3631401	et	4	main
on	doc_786864950087_item	3631399	et	4	main
ees	doc_786864950087_item	3631398	et	4	main
akna	doc_786864950087_item	3631397	et	3	main
voodi	doc_786864950087_item	3631393	et	4	main
ja	doc_786864950087_item	3631377	et	3	main
mina	doc_786864950087_item	3631376	et	4	main
tuba	doc_786864950087_item	3631375	et	4	main
suur	doc_786864950087_item	3631374	et	3	main
on	doc_786864950087_item	3631373	et	4	main
minul	doc_786864950087_item	3631372	et	3	main
korrusel	doc_786864950087_item	3631371	et	3	main
esimel	doc_786864950087_item	3631370	et	4	main
asume	doc_786864950087_item	3631369	et	3	main
me	doc_786864950087_item	3631368	et	4	main
elutuba	doc_786864950087_item	3631367	et	4	main
ja	doc_786864950087_item	3631366	et	3	main
vannituba	doc_786864950087_item	3631365	et	4	main
köök	doc_786864950087_item	3631364	et	3	main
tobe	doc_786864950087_item	3631363	et	3	main
kolm	doc_786864950087_item	3631362	et	3	main
on	doc_786864950087_item	3631361	et	4	main
sael	doc_786864950087_item	3631360	et	3	main
suuri	doc_786864950087_item	3631359	et	3	main
on	doc_786864950087_item	3631358	et	4	main
korteri	doc_786864950087_item	3631357	et	3	main
taimed	doc_786864950087_item	3631356	et	3	main
rohelised	doc_786864950087_item	3631355	et	4	main
on	doc_786864950087_item	3631354	et	4	main
ees	doc_786864950087_item	3631353	et	4	main
korteri	doc_786864950087_item	3631352	et	3	main
budapestis	doc_786864950087_item	3631351	et	4	main
majassa	doc_786864950087_item	3631350	et	4	main
elan	doc_786864950087_item	3631348	et	3	main
mina	doc_786864950087_item	3631347	et	4	main
kuhu	doc_278690626900_item	3631560	et	3	main
inimene	doc_278690626901_item	3631640	et	3	main
on	doc_278690626901_item	3631624	et	4	main
kiigutades	doc_278690626901_item	3631622	et	3	main
350	doc_278690626901_item	3631586	et	2	main
kirjutamine	doc_278690626901_item	3631575	et	4	main
olnud	doc_278690626902_item	3631802	et	4	main
on	doc_278690626902_item	3631801	et	4	main
eestlastel	doc_278690626902_item	3631800	et	4	main
kuigi	doc_278690626902_item	3631799	et	3	main
ajal	doc_278690626902_item	3631798	et	4	main
tool	doc_278690626902_item	3631797	et	3	main
tähtsad	doc_278690626902_item	3631796	et	3	main
väga	doc_278690626902_item	3631795	et	3	main
olid	doc_278690626902_item	3631794	et	4	main
rahvalaulud	doc_278690626902_item	3631793	et	3	main
naisi	doc_278690626902_item	3631792	et	3	main
sõdujumal	doc_278690626902_item	3631765	et	4	main
ja	doc_278690626902_item	3631764	et	3	main
kirikuajast	doc_278690626902_item	3631750	et	4	main
enne	doc_278690626902_item	3631749	et	4	main
religioon	doc_278690626902_item	3631745	et	3	main
muinastest	doc_278690626902_item	3631730	et	3	main
eesti	doc_278690626902_item	3631718	et	4	main
et	doc_278690626902_item	3631717	et	3	main
illustreerida	doc_278690626902_item	3631710	et	3	main
väiteid	doc_278690626902_item	3631707	et	4	main
faktidele	doc_278690626902_item	3631706	et	3	main
esitatud	doc_278690626902_item	3631705	et	4	main
lugemistekstis	doc_278690626902_item	3631704	et	3	main
ja	doc_278690626902_item	3631703	et	3	main
loengus	doc_278690626902_item	3631702	et	3	main
tuginema	doc_278690626902_item	3631701	et	3	main
üldistav	doc_278690626902_item	3631700	et	4	main
ja	doc_278690626902_item	3631699	et	3	main
analüüsiv	doc_278690626902_item	3631698	et	4	main
arutlev	doc_278690626902_item	3631697	et	4	main
olema	doc_278690626902_item	3631696	et	4	main
peab	doc_278690626902_item	3631695	et	4	main
essee	doc_278690626902_item	3631694	et	4	main
sõna	doc_278690626902_item	3631693	et	4	main
350	doc_278690626902_item	3631692	et	2	main
300	doc_278690626902_item	3631691	et	2	main
pikkus	doc_278690626902_item	3631690	et	4	main
essee	doc_278690626902_item	3631689	et	4	main
laulurahva	doc_278690626902_item	3631688	et	3	main
eestlastest	doc_278690626902_item	3631687	et	4	main
koor	doc_278690626901_item	3631671	et	4	main
vaheldumisi	doc_278690626901_item	3631672	et	4	main
ja	doc_278690626901_item	3631670	et	3	main
eeslaulja	doc_278690626901_item	3631669	et	4	main
tavaliselt	doc_278690626901_item	3631668	et	4	main
esitavad	doc_278690626901_item	3631667	et	4	main
tagasi	doc_278690626901_item	3631665	et	3	main
aastat	doc_278690626901_item	3631664	et	3	main
regilaulu	doc_278690626901_item	3631666	et	4	main
tuhat	doc_278690626901_item	3631663	et	4	main
kui	doc_278690626901_item	3631662	et	3	main
enam	doc_278690626901_item	3631661	et	4	main
kujundenud	doc_278690626901_item	3631660	et	4	main
on	doc_278690626901_item	3631659	et	4	main
mis	doc_278690626901_item	3631658	et	4	main
rahvalaul	doc_278690626901_item	3631657	et	4	main
regivärsiline	doc_278690626901_item	3631656	et	4	main
iseloomulik	doc_278690626901_item	3631655	et	3	main
kultuurile	doc_278690626901_item	3631654	et	3	main
läänemeresoome	doc_278690626901_item	3631653	et	3	main
esindab	doc_278690626901_item	3631652	et	3	main
laulutraditsiooni	doc_278690626901_item	3631651	et	4	main
vanemat	doc_278690626901_item	3631650	et	4	main
eesti	doc_278690626901_item	3631649	et	4	main
rõõmsam	doc_278690626901_item	3631648	et	4	main
inimene	doc_278690626901_item	3631647	et	3	main
teeb	doc_278690626901_item	3631646	et	3	main
elaks	doc_278690626901_item	3631642	et	3	main
kui	doc_278690626901_item	3631639	et	3	main
olles	doc_278690626901_item	3631619	et	3	main
üksi	doc_278690626901_item	3631618	et	4	main
laudi	doc_278690626901_item	3631617	et	4	main
hauani	doc_278690626901_item	3631616	et	3	main
hällist	doc_278690626901_item	3631615	et	4	main
eestlast	doc_278690626901_item	3631614	et	4	main
laul	doc_278690626901_item	3631613	et	4	main
saatis	doc_278690626901_item	3631612	et	3	main
ajal	doc_278690626901_item	3631611	et	4	main
vanal	doc_278690626901_item	3631610	et	3	main
kultuurinähtus	doc_278690626901_item	3631609	et	4	main
tahelepanuvärane	doc_278690626901_item	3631608	et	4	main
on	doc_278690626901_item	3631607	et	4	main
laulmine	doc_278690626901_item	3631606	et	4	main
näidetega	doc_278690626901_item	3631605	et	3	main
illustreerida	doc_278690626901_item	3631604	et	3	main
soovitatav	doc_278690626901_item	3631603	et	4	main
on	doc_278690626901_item	3631602	et	4	main
väiteid	doc_278690626901_item	3631601	et	4	main
faktidele	doc_278690626901_item	3631600	et	3	main
esitatud	doc_278690626901_item	3631599	et	4	main
lugemistekstis	doc_278690626901_item	3631598	et	3	main
ja	doc_278690626901_item	3631597	et	3	main
loengus	doc_278690626901_item	3631596	et	3	main
tuginema	doc_278690626901_item	3631595	et	3	main
üldistav	doc_278690626901_item	3631594	et	4	main
ja	doc_278690626901_item	3631593	et	3	main
arutlev	doc_278690626901_item	3631591	et	4	main
analüüsiv	doc_278690626901_item	3631592	et	4	main
olema	doc_278690626901_item	3631590	et	4	main
peab	doc_278690626901_item	3631589	et	4	main
mis	doc_278690626901_item	3631579	et	4	main
teemal	doc_278690626901_item	3631578	et	3	main
essee	doc_278690626901_item	3631577	et	4	main
kirjutage	doc_278690626901_item	3631576	et	3	main
tüüpis	doc_278690626902_item	3631784	et	4	main
laulud	doc_278690626902_item	3631775	et	3	main
need	doc_278690626902_item	3631774	et	3	main
eestimaal	doc_278690626902_item	3631773	et	4	main
sündis	doc_278690626902_item	3631772	et	3	main
mis	doc_278690626902_item	3631771	et	4	main
on	doc_278690626902_item	3631768	et	4	main
nendest	doc_278690626902_item	3631757	et	4	main
aga	doc_278690626902_item	3631755	et	3	main
jumalasid	doc_278690626902_item	3631753	et	4	main
on	doc_278690626902_item	3631746	et	4	main
uuritud	doc_278690626902_item	3631743	et	4	main
laulumisega	doc_278690626902_item	3631736	et	4	main
tööd	doc_278690626902_item	3631735	et	4	main
kõik	doc_278690626902_item	3631734	et	4	main
tegid	doc_278690626902_item	3631733	et	4	main
eestlased	doc_278690626902_item	3631732	et	3	main
tuntud	doc_278690626902_item	3631716	et	4	main
juba	doc_278690626902_item	3631715	et	3	main
teeb	doc_278690626902_item	3631686	et	3	main
mis	doc_278690626902_item	3631685	et	4	main
teemal	doc_278690626902_item	3631684	et	3	main
uuema	doc_278690626903_item	3631928	et	4	main
köögis	doc_278690626903_item	3631921	et	3	main
kodus	doc_278690626903_item	3631920	et	4	main
koolis	doc_278690626903_item	3631910	et	4	main
kooris	doc_278690626903_item	3631908	et	4	main
näitek	doc_278690626903_item	3631899	et	4	main
või	doc_278690626903_item	3631898	et	4	main
vanem	doc_278690626903_item	3631876	et	4	main
ajaloo	doc_278690626903_item	3631864	et	4	main
ja	doc_278690626903_item	3631862	et	3	main
nende	doc_278690626903_item	3631860	et	4	main
me	doc_278690626903_item	3631858	et	4	main
eestlaste	doc_278690626903_item	3631856	et	4	main
kiigutades	doc_278690626903_item	3631855	et	3	main
last	doc_278690626903_item	3631854	et	4	main
töötades	doc_278690626903_item	3631853	et	3	main
olles	doc_278690626903_item	3631852	et	3	main
juba	doc_278690626903_item	3631846	et	3	main
vanal	doc_278690626903_item	3631844	et	3	main
näidetega	doc_278690626903_item	3631843	et	3	main
illustreerida	doc_278690626903_item	3631842	et	3	main
essee	doc_278690626903_item	3631826	et	4	main
300	doc_278690626903_item	3631823	et	2	main
laulurahva	doc_278690626903_item	3632022	et	3	main
vanemad	doc_278690626903_item	3632007	et	4	main
väga	doc_278690626903_item	3631999	et	3	main
peole	doc_278690626903_item	3631983	et	4	main
neiuga	doc_278690626903_item	3631977	et	4	main
laulupidu	doc_278690626903_item	3631967	et	4	main
olen	doc_278690626903_item	3631964	et	3	main
mõtlen	doc_278690626903_item	3631961	et	3	main
arv	doc_278690626903_item	3631956	et	3	main
teise	doc_278690626902_item	3631678	et	4	main
kui	doc_278690626902_item	3631677	et	3	main
metsas	doc_278690626903_item	3631927	et	3	main
aias	doc_278690626903_item	3631922	et	4	main
naised	doc_278690626903_item	3631918	et	3	main
j	doc_278690626903_item	3631915	et	4	main
uhekesi	doc_278690626903_item	3631913	et	4	main
ajal	doc_278690626903_item	3631905	et	4	main
vanal	doc_278690626903_item	3631904	et	3	main
tegid	doc_278690626903_item	3631896	et	4	main
ja	doc_278690626903_item	3631893	et	3	main
võistlesid	doc_278690626903_item	3631871	et	4	main
kui	doc_278690626903_item	3631870	et	3	main
aitas	doc_278690626903_item	3631869	et	3	main
laul	doc_278690626903_item	3631868	et	4	main
et	doc_278690626903_item	3631867	et	3	main
arvan	doc_278690626903_item	3631866	et	3	main
ma	doc_278690626903_item	3631865	et	3	main
minevik	doc_278690626903_item	3631861	et	3	main
laudi	doc_278690626903_item	3631850	et	4	main
laulma	doc_278690626903_item	3631849	et	3	main
eestlased	doc_278690626903_item	3631848	et	3	main
ajal	doc_278690626903_item	3631845	et	4	main
soovitatav	doc_278690626903_item	3631841	et	4	main
on	doc_278690626903_item	3631840	et	4	main
tuginema	doc_278690626903_item	3631833	et	3	main
ja	doc_278690626903_item	3631831	et	3	main
peab	doc_278690626903_item	3631827	et	4	main
350	doc_278690626903_item	3631824	et	2	main
pikkus	doc_278690626903_item	3631822	et	4	main
essee	doc_278690626903_item	3631821	et	4	main
laulurahva	doc_278690626903_item	3631820	et	3	main
eestlastest	doc_278690626903_item	3631819	et	4	main
teeb	doc_278690626903_item	3631818	et	3	main
mis	doc_278690626903_item	3631817	et	4	main
teemal	doc_278690626903_item	3631816	et	3	main
kui	doc_278690626903_item	3631809	et	3	main
essee	doc_278690626903_item	3631806	et	4	main
tee	doc_278690626903_item	3632020	et	4	main
aja	doc_278690626903_item	3632013	et	4	main
rahvalaulud	doc_278690626903_item	3632005	et	3	main
georg	doc_278690626903_item	3632003	et	4	main
lastega	doc_278690626903_item	3631975	et	3	main
oma	doc_278690626903_item	3631974	et	4	main
kus	doc_278690626903_item	3631971	et	3	main
et	doc_278690626903_item	3631966	et	3	main
ja	doc_278690626903_item	3631958	et	3	main
võtjate	doc_278690626903_item	3631955	et	4	main
niimodi	doc_278690626906_item	3632260	et	4	main
on	doc_278690626906_item	3632259	et	4	main
see	doc_278690626906_item	3632258	et	3	main
et	doc_278690626906_item	3632257	et	3	main
kindel	doc_278690626906_item	3632256	et	3	main
olen	doc_278690626906_item	3632255	et	3	main
ma	doc_278690626906_item	3632254	et	3	main
aga	doc_278690626906_item	3632253	et	3	main
inimesed	doc_278690626906_item	3632252	et	3	main
laulurahva	doc_278690626906_item	3632251	et	3	main
see	doc_278690626906_item	3632244	et	3	main
eraldi	doc_278690626906_item	3632243	et	4	main
ja	doc_278690626906_item	3632238	et	3	main
eestis	doc_278690626906_item	3632189	et	3	main
laulsid	doc_278690626906_item	3632176	et	4	main
naised	doc_278690626906_item	3632175	et	3	main
laulugruppid	doc_278690626906_item	3632173	et	4	main
oli	doc_278690626906_item	3632170	et	3	main
kiiresti	doc_278690626906_item	3632167	et	3	main
laulsid	doc_278690626906_item	3632147	et	4	main
emad	doc_278690626906_item	3632146	et	3	main
ja	doc_278690626906_item	3632135	et	3	main
sündisin	doc_278690626906_item	3632094	et	3	main
meres	doc_278690626903_item	3631926	et	3	main
aga	doc_278690626903_item	3631924	et	3	main
laulsid	doc_278690626903_item	3631919	et	4	main
ka	doc_278690626903_item	3631912	et	3	main
laulu	doc_278690626903_item	3631897	et	4	main
uudiseid	doc_278690626903_item	3631892	et	3	main
või	doc_278690626903_item	3631891	et	4	main
televisioon	doc_278690626903_item	3631890	et	4	main
ju	doc_278690626903_item	3631889	et	3	main
olnud	doc_278690626903_item	3631888	et	4	main
ei	doc_278690626903_item	3631887	et	4	main
ajal	doc_278690626903_item	3631886	et	4	main
tol	doc_278690626903_item	3631885	et	3	main
näitek	doc_278690626903_item	3631884	et	4	main
informatsiion	doc_278690626903_item	3631883	et	4	main
on	doc_278690626903_item	3631882	et	4	main
eesmärk	doc_278690626903_item	3631881	et	3	main
rahvalaul	doc_278690626903_item	3631880	et	4	main
vanema	doc_278690626903_item	3631879	et	4	main
lapsed	doc_278690626903_item	3631900	et	3	main
inimesed	doc_278690626903_item	3631895	et	3	main
eestlaste	doc_278690626903_item	3631863	et	4	main
üksi	doc_278690626903_item	3631851	et	4	main
faktidele	doc_278690626903_item	3631838	et	3	main
arutlev	doc_278690626903_item	3631829	et	4	main
olema	doc_278690626903_item	3631828	et	4	main
sõna	doc_278690626903_item	3631825	et	4	main
essee	doc_278690626903_item	3631815	et	4	main
kirjutage	doc_278690626903_item	3631814	et	3	main
kirjutamine	doc_278690626903_item	3631813	et	4	main
test	doc_278690626903_item	3631812	et	3	main
see	doc_278690626903_item	3632018	et	3	main
kas	doc_278690626903_item	3632017	et	3	main
rahvuslikeks	doc_278690626903_item	3632015	et	3	main
läbi	doc_278690626903_item	3632012	et	4	main
on	doc_278690626903_item	3632011	et	4	main
ots	doc_278690626903_item	3632004	et	3	main
tuntud	doc_278690626903_item	3632000	et	4	main
elas	doc_278690626903_item	3631997	et	3	main
laulurahvas	doc_278690626903_item	3631995	et	4	main
on	doc_278690626903_item	3631993	et	4	main
eestlased	doc_278690626903_item	3631992	et	3	main
et	doc_278690626903_item	3631991	et	3	main
arvavad	doc_278690626903_item	3631990	et	4	main
nad	doc_278690626903_item	3631989	et	3	main
ja	doc_278690626903_item	3631988	et	3	main
sõpradega	doc_278690626903_item	3631981	et	3	main
oma	doc_278690626903_item	3631976	et	4	main
saad	doc_278690626903_item	3631972	et	4	main
on	doc_278690626903_item	3631968	et	4	main
ma	doc_278690626903_item	3631963	et	3	main
kasvas	doc_278690626903_item	3631959	et	3	main
jannsen	doc_278690626903_item	3631949	et	4	main
voldemar	doc_278690626903_item	3631948	et	4	main
aga	doc_278690626903_item	3631946	et	3	main
johann	doc_278690626903_item	3631947	et	4	main
oli	doc_278690626903_item	3631945	et	3	main
organisaat	doc_278690626903_item	3631944	et	4	main
laulupidu	doc_278690626903_item	3631943	et	4	main
esimene	doc_278690626903_item	3631942	et	3	main
toimus	doc_278690626903_item	3631941	et	3	main
tartus	doc_278690626903_item	3631940	et	3	main
aastal	doc_278690626903_item	3631939	et	3	main
1896	doc_278690626903_item	3631938	et	2	main
loomust	doc_278690626903_item	3631937	et	4	main
ja	doc_278690626903_item	3631936	et	3	main
eestlaste	doc_278690626903_item	3631934	et	4	main
uhkust	doc_278690626903_item	3631935	et	4	main
näitama	doc_278690626903_item	3631933	et	3	main
ja	doc_278690626903_item	3631932	et	3	main
iseloomustama	doc_278690626903_item	3631931	et	4	main
eestis	doc_278690626906_item	3632266	et	3	main
sest	doc_278690626906_item	3632265	et	4	main
on	doc_278690626906_item	3632250	et	4	main
eestlased	doc_278690626906_item	3632249	et	3	main
miks	doc_278690626906_item	3632248	et	4	main
tantsivad	doc_278690626906_item	3632239	et	4	main
ja	doc_278690626906_item	3632200	et	3	main
ei	doc_278690626906_item	3632197	et	4	main
laulsid	doc_278690626906_item	3632180	et	4	main
kahekesi	doc_278690626906_item	3632179	et	3	main
naise	doc_278690626906_item	3632172	et	3	main
sajandil	doc_278690626906_item	3632169	et	3	main
rahuldada	doc_278690626906_item	3632165	et	3	main
osast	doc_278690626903_item	3631875	et	4	main
kahest	doc_278690626903_item	3631874	et	4	main
koosneb	doc_278690626903_item	3631873	et	3	main
rahvalaul	doc_278690626903_item	3631872	et	4	main
laudes	doc_278690626903_item	3631857	et	3	main
esitatud	doc_278690626903_item	3631837	et	4	main
ja	doc_278690626903_item	3631835	et	3	main
üldistav	doc_278690626903_item	3631832	et	4	main
analüüsiv	doc_278690626903_item	3631830	et	4	main
keele	doc_278690626903_item	3631808	et	4	main
eestlastest	doc_278690626903_item	3632021	et	4	main
ei	doc_278690626903_item	3632019	et	4	main
kujunenud	doc_278690626903_item	3632014	et	4	main
kui	doc_278690626903_item	3632008	et	3	main
nii	doc_278690626903_item	3632006	et	3	main
laulja	doc_278690626903_item	3632002	et	4	main
mailmas	doc_278690626903_item	3632001	et	4	main
ka	doc_278690626903_item	3631998	et	3	main
eestis	doc_278690626903_item	3631996	et	3	main
väga	doc_278690626903_item	3631994	et	3	main
laulu	doc_278690626903_item	3631982	et	4	main
perega	doc_278690626903_item	3631979	et	3	main
puhkata	doc_278690626903_item	3631973	et	4	main
rahvapidu	doc_278690626903_item	3631970	et	4	main
ja	doc_278690626903_item	3631962	et	3	main
kasvas	doc_278690626903_item	3631957	et	3	main
on	doc_278690626906_item	3632245	et	4	main
ringis	doc_278690626906_item	3632241	et	4	main
peole	doc_278690626906_item	3632237	et	4	main
telefonid	doc_278690626906_item	3632199	et	3	main
tagasi	doc_278690626906_item	3632196	et	3	main
mõned	doc_278690626906_item	3632194	et	3	main
inimesed	doc_278690626903_item	3631984	et	3	main
ja	doc_278690626903_item	3631980	et	3	main
ühesõnaga	doc_278690626903_item	3631978	et	3	main
tõeline	doc_278690626903_item	3631969	et	4	main
kindel	doc_278690626903_item	3631965	et	3	main
ma	doc_278690626903_item	3631960	et	3	main
osa	doc_278690626903_item	3631954	et	4	main
pidu	doc_278690626903_item	3631953	et	4	main
seda	doc_278690626903_item	3631952	et	3	main
pärast	doc_278690626903_item	3631951	et	4	main
ja	doc_278690626903_item	3631950	et	3	main
minu	doc_278690626906_item	3632261	et	3	main
raske	doc_278690626906_item	3632246	et	4	main
rahvatatsid	doc_278690626906_item	3632240	et	4	main
hobby	doc_278690626906_item	3632192	et	4	main
laulmine	doc_278690626906_item	3632188	et	4	main
väga	doc_278690626906_item	3632186	et	3	main
nad	doc_278690626906_item	3632184	et	3	main
ontsamblis	doc_278690626906_item	3632183	et	4	main
ja	doc_278690626906_item	3632182	et	3	main
üksi	doc_278690626906_item	3632177	et	4	main
väga	doc_278690626906_item	3632166	et	3	main
nuttab	doc_278690626906_item	3632155	et	4	main
laps	doc_278690626906_item	3632154	et	4	main
näiteks	doc_278690626906_item	3632145	et	4	main
loodushääled	doc_278690626906_item	3632144	et	3	main
palju	doc_278690626906_item	3632143	et	4	main
oli	doc_278690626906_item	3632142	et	3	main
teavad	doc_278690626906_item	3632102	et	3	main
inimesed	doc_278690626906_item	3632101	et	3	main
palju	doc_278690626906_item	3632100	et	4	main
kus	doc_278690626906_item	3632099	et	3	main
linn	doc_278690626906_item	3632098	et	3	main
mina	doc_278690626906_item	3632093	et	4	main
väiksem	doc_278690626906_item	3632085	et	4	main
soovitatav	doc_278690626906_item	3632059	et	4	main
on	doc_278690626906_item	3632058	et	4	main
väiteid	doc_278690626906_item	3632057	et	4	main
faktidele	doc_278690626906_item	3632056	et	3	main
peab	doc_278690626906_item	3632045	et	4	main
keele	doc_278690626906_item	3632029	et	4	main
vana	doc_278690626911_item	3632579	et	4	main
muusika	doc_278690626911_item	3632563	et	4	main
on	doc_278690626911_item	3632559	et	4	main
kaasaegses	doc_278690626911_item	3632555	et	3	main
koosnes	doc_278690626911_item	3632548	et	3	main
oli	doc_278690626911_item	3632542	et	3	main
üks	doc_278690626911_item	3632539	et	3	main
eestimaa	doc_278690626911_item	3632527	et	4	main
aastal	doc_278690626911_item	3632526	et	3	main
19	doc_278690626911_item	3632523	et	2	main
laulas	doc_278690626911_item	3632475	et	4	main
igal	doc_278690626911_item	3632471	et	3	main
iga	doc_278690626911_item	3632468	et	4	main
mis	doc_278690626911_item	3632462	et	4	main
hääl	doc_278690626911_item	3632458	et	3	main
töötades	doc_278690626911_item	3632422	et	3	main
kirikulaulud	doc_278690626911_item	3632417	et	3	main
olid	doc_278690626911_item	3632414	et	4	main
jumalad	doc_278690626911_item	3632413	et	3	main
vanad	doc_278690626911_item	3632412	et	3	main
kui	doc_278690626911_item	3632411	et	3	main
hiljem	doc_278690626911_item	3632410	et	3	main
tantsida	doc_278690626911_item	3632404	et	3	main
ja	doc_278690626911_item	3632399	et	3	main
austasid	doc_278690626911_item	3632388	et	4	main
või	doc_278690626911_item	3632382	et	4	main
ajal	doc_278690626911_item	3632380	et	4	main
oli	doc_278690626911_item	3632371	et	3	main
rahvas	doc_278690626911_item	3632367	et	4	main
kultuuris	doc_278690626911_item	3632362	et	3	main
rahvas	doc_278690626911_item	3632332	et	4	main
soovitatav	doc_278690626911_item	3632328	et	4	main
ja	doc_278690626911_item	3632318	et	3	main
igal	doc_278690626911_item	3632623	et	3	main
gustav	doc_278690626911_item	3632617	et	4	main
on	doc_278690626911_item	3632611	et	4	main
essee	doc_278690626911_item	3632308	et	4	main
eestlastest	doc_278690626911_item	3632306	et	4	main
essee	doc_278690626911_item	3632302	et	4	main
test	doc_278690626911_item	3632299	et	3	main
kui	doc_278690626911_item	3632296	et	3	main
laulurahvus	doc_278690626906_item	3632291	et	3	main
on	doc_278690626906_item	3632290	et	4	main
eestirahvus	doc_278690626906_item	3632289	et	3	main
arm	doc_278690626906_item	3632288	et	3	main
minu	doc_278690626906_item	3632287	et	3	main
on	doc_278690626906_item	3632286	et	4	main
isamaa	doc_278690626906_item	3632285	et	4	main
mu	doc_278690626906_item	3632284	et	3	main
isamaalaul	doc_278690626906_item	3632283	et	4	main
tegi	doc_278690626906_item	3632282	et	4	main
kes	doc_278690626906_item	3632281	et	4	main
ernesaksa	doc_278690626906_item	3632280	et	4	main
gustav	doc_278690626906_item	3632279	et	4	main
või	doc_278690626906_item	3632278	et	4	main
kapp	doc_278690626906_item	3632277	et	3	main
a	doc_278690626906_item	3632276	et	4	main
naiteks	doc_278690626906_item	3632275	et	4	main
autorid	doc_278690626906_item	3632274	et	3	main
ja	doc_278690626906_item	3632273	et	3	main
komposiitorid	doc_278690626906_item	3632272	et	4	main
head	doc_278690626906_item	3632271	et	4	main
hääled	doc_278690626906_item	3632270	et	3	main
looduslikult	doc_278690626906_item	3632269	et	4	main
palju	doc_278690626906_item	3632268	et	4	main
on	doc_278690626906_item	3632267	et	4	main
on	doc_278690626906_item	3632264	et	4	main
see	doc_278690626906_item	3632263	et	3	main
meeles	doc_278690626906_item	3632262	et	3	main
öelda	doc_278690626906_item	3632247	et	4	main
või	doc_278690626906_item	3632242	et	4	main
tulevad	doc_278690626906_item	3632236	et	4	main
nad	doc_278690626906_item	3632235	et	3	main
rahvariided	doc_278690626906_item	3632234	et	3	main
selga	doc_278690626906_item	3632233	et	4	main
panevad	doc_278690626906_item	3632232	et	4	main
nad	doc_278690626906_item	3632231	et	3	main
rahvapidu	doc_278690626906_item	3632230	et	4	main
kui	doc_278690626906_item	3632229	et	3	main
traditsioon	doc_278690626906_item	3632228	et	3	main
on	doc_278690626906_item	3632227	et	4	main
inimesel	doc_278690626906_item	3632226	et	3	main
vanadel	doc_278690626906_item	3632225	et	3	main
rahvariided	doc_278690626906_item	3632224	et	3	main
pidulikut	doc_278690626906_item	3632223	et	4	main
nii	doc_278690626906_item	3632222	et	3	main
on	doc_278690626906_item	3632221	et	4	main
eestis	doc_278690626906_item	3632220	et	3	main
ainult	doc_278690626906_item	3632219	et	4	main
meeles	doc_278690626906_item	3632218	et	3	main
minu	doc_278690626906_item	3632217	et	3	main
rahvalaulmist	doc_278690626906_item	3632216	et	3	main
peod	doc_278690626906_item	3632215	et	4	main
palju	doc_278690626906_item	3632214	et	4	main
oli	doc_278690626906_item	3632213	et	3	main
eestis	doc_278690626906_item	3632212	et	3	main
pärast	doc_278690626906_item	3632211	et	4	main
selle	doc_278690626906_item	3632210	et	4	main
peod	doc_278690626906_item	3632209	et	4	main
mingi	doc_278690626906_item	3632208	et	4	main
tahavad	doc_278690626906_item	3632207	et	3	main
ja	doc_278690626906_item	3632206	et	3	main
rõõmsaid	doc_278690626906_item	3632205	et	3	main
on	doc_278690626906_item	3632204	et	4	main
inimesed	doc_278690626906_item	3632203	et	3	main
aga	doc_278690626906_item	3632202	et	3	main
televiisorid	doc_278690626906_item	3632201	et	3	main
olnud	doc_278690626906_item	3632198	et	4	main
aastat	doc_278690626906_item	3632195	et	3	main
ja	doc_278690626906_item	3632193	et	3	main
nägu	doc_278690626906_item	3632191	et	4	main
või	doc_278690626906_item	3632178	et	4	main
populaarne	doc_278690626906_item	3632171	et	3	main
18	doc_278690626906_item	3632168	et	2	main
läheb	doc_278690626906_item	3632164	et	3	main
laul	doc_278690626906_item	3632161	et	4	main
laulma	doc_278690626906_item	3632158	et	3	main
saab	doc_278690626906_item	3632157	et	3	main
räägivad	doc_278690626906_item	3632151	et	3	main
psühoologid	doc_278690626906_item	3632150	et	4	main
ja	doc_278690626906_item	3632141	et	3	main
toimuvad	doc_278690626906_item	3632133	et	4	main
on	doc_278690626906_item	3632097	et	4	main
mitte	doc_278690626906_item	3632083	et	3	main
maa	doc_278690626906_item	3632081	et	4	main
üldistav	doc_278690626906_item	3632050	et	4	main
ja	doc_278690626906_item	3632049	et	3	main
sõna	doc_278690626906_item	3632043	et	4	main
pikkus	doc_278690626906_item	3632040	et	4	main
essee	doc_278690626906_item	3632039	et	4	main
laulurahva	doc_278690626906_item	3632038	et	3	main
mis	doc_278690626906_item	3632035	et	4	main
kirjutage	doc_278690626906_item	3632032	et	3	main
kirjutamine	doc_278690626906_item	3632031	et	4	main
test	doc_278690626906_item	3632030	et	3	main
essee	doc_278690626906_item	3632024	et	4	main
laulu	doc_278690626911_item	3632582	et	4	main
ka	doc_278690626911_item	3632567	et	3	main
külastavad	doc_278690626911_item	3632566	et	4	main
ikka	doc_278690626911_item	3632558	et	4	main
maailmas	doc_278690626911_item	3632556	et	3	main
noor	doc_278690626911_item	3632554	et	3	main
inimeste	doc_278690626911_item	3632550	et	3	main
rahvas	doc_278690626911_item	3632547	et	4	main
selline	doc_278690626911_item	3632541	et	4	main
seal	doc_278690626911_item	3632530	et	4	main
laulupeol	doc_278690626911_item	3632529	et	4	main
saada	doc_278690626911_item	3632522	et	4	main
oli	doc_278690626906_item	3632190	et	3	main
palju	doc_278690626906_item	3632187	et	4	main
laulsid	doc_278690626906_item	3632185	et	4	main
gruppis	doc_278690626906_item	3632181	et	4	main
vaheajal	doc_278690626906_item	3632174	et	3	main
ja	doc_278690626906_item	3632162	et	3	main
rahulik	doc_278690626906_item	3632160	et	3	main
mingi	doc_278690626906_item	3632159	et	4	main
ema	doc_278690626906_item	3632156	et	4	main
et	doc_278690626906_item	3632152	et	3	main
rahvatantsidega	doc_278690626906_item	3632134	et	3	main
kontserdid	doc_278690626906_item	3632132	et	3	main
palju	doc_278690626906_item	3632131	et	4	main
tantsida	doc_278690626906_item	3632130	et	3	main
ja	doc_278690626906_item	3632129	et	3	main
laulda	doc_278690626906_item	3632128	et	4	main
meeldivad	doc_278690626906_item	3632127	et	4	main
väga	doc_278690626906_item	3632126	et	3	main
eestlased	doc_278690626906_item	3632125	et	3	main
teha	doc_278690626906_item	3632124	et	3	main
huvitav	doc_278690626906_item	3632123	et	4	main
midagi	doc_278690626906_item	3632122	et	4	main
võimalusi	doc_278690626906_item	3632121	et	3	main
palju	doc_278690626906_item	3632120	et	4	main
nii	doc_278690626906_item	3632119	et	3	main
olnud	doc_278690626906_item	3632118	et	4	main
ei	doc_278690626906_item	3632117	et	4	main
sajandil	doc_278690626906_item	3632116	et	3	main
19	doc_278690626906_item	3632115	et	2	main
18	doc_278690626906_item	3632114	et	2	main
näiteks	doc_278690626906_item	3632113	et	4	main
aga	doc_278690626906_item	3632112	et	3	main
linn	doc_278690626906_item	3632111	et	3	main
huvitav	doc_278690626906_item	3632110	et	4	main
ja	doc_278690626906_item	3632109	et	3	main
populaarne	doc_278690626906_item	3632108	et	3	main
on	doc_278690626906_item	3632107	et	4	main
see	doc_278690626906_item	3632106	et	3	main
praegu	doc_278690626906_item	3632105	et	3	main
teist	doc_278690626906_item	3632104	et	4	main
üks	doc_278690626906_item	3632103	et	3	main
laps	doc_278690626906_item	3632163	et	4	main
kui	doc_278690626906_item	3632153	et	3	main
lapsele	doc_278690626906_item	3632149	et	4	main
oma	doc_278690626906_item	3632148	et	4	main
on	doc_278690626906_item	3632140	et	4	main
aeg	doc_278690626906_item	3632139	et	3	main
kogu	doc_278690626906_item	3632138	et	4	main
eestis	doc_278690626906_item	3632137	et	3	main
rahvalauludega	doc_278690626906_item	3632136	et	3	main
see	doc_278690626906_item	3632096	et	3	main
väiksed	doc_278690626906_item	3632091	et	4	main
kõige	doc_278690626906_item	3632084	et	4	main
aga	doc_278690626906_item	3632082	et	3	main
lugemistekstis	doc_278690626906_item	3632054	et	3	main
analüüsiv	doc_278690626906_item	3632048	et	4	main
arutlev	doc_278690626906_item	3632047	et	4	main
eestlastest	doc_278690626906_item	3632037	et	4	main
teemal	doc_278690626906_item	3632034	et	3	main
essee	doc_278690626906_item	3632033	et	4	main
eesti	doc_278690626906_item	3632025	et	4	main
tartust	doc_278690626906_item	3632095	et	3	main
näiteks	doc_278690626906_item	3632092	et	4	main
on	doc_278690626906_item	3632090	et	4	main
linnad	doc_278690626906_item	3632089	et	3	main
esitatud	doc_278690626906_item	3632055	et	4	main
tuginema	doc_278690626906_item	3632051	et	3	main
essee	doc_278690626906_item	3632044	et	4	main
350	doc_278690626906_item	3632042	et	2	main
teise	doc_278690626906_item	3632028	et	4	main
kui	doc_278690626906_item	3632027	et	3	main
laulavad	doc_278690626911_item	3632581	et	4	main
mängivad	doc_278690626911_item	3632578	et	4	main
ansamble	doc_278690626911_item	3632576	et	4	main
noorte	doc_278690626911_item	3632575	et	3	main
lauljad	doc_278690626911_item	3632571	et	4	main
ja	doc_278690626911_item	3632570	et	3	main
heliloojad	doc_278690626911_item	3632569	et	3	main
väljaspoolsed	doc_278690626911_item	3632568	et	3	main
laulupeod	doc_278690626911_item	3632557	et	4	main
oli	doc_278690626911_item	3632552	et	3	main
laulas	doc_278690626911_item	3632540	et	4	main
iga	doc_278690626911_item	3632538	et	4	main
ja	doc_278690626911_item	3632537	et	3	main
maal	doc_278690626911_item	3632536	et	4	main
kogus	doc_278690626911_item	3632528	et	4	main
ei	doc_278690626911_item	3632484	et	4	main
eestlased	doc_278690626911_item	3632483	et	3	main
jüüri	doc_278690626911_item	3632479	et	4	main
tuius	doc_278690626911_item	3632467	et	4	main
instrumentid	doc_278690626911_item	3632461	et	4	main
oli	doc_278690626911_item	3632456	et	3	main
erinevaid	doc_278690626911_item	3632452	et	4	main
palju	doc_278690626911_item	3632451	et	4	main
väga	doc_278690626911_item	3632450	et	3	main
oli	doc_278690626911_item	3632449	et	3	main
eestis	doc_278690626911_item	3632448	et	3	main
emalaulud	doc_278690626911_item	3632447	et	3	main
ja	doc_278690626911_item	3632446	et	3	main
laulud	doc_278690626911_item	3632445	et	3	main
pulma	doc_278690626911_item	3632444	et	4	main
oli	doc_278690626911_item	3632443	et	3	main
laulasid	doc_278690626911_item	3632419	et	4	main
inimesed	doc_278690626911_item	3632418	et	3	main
ilmusid	doc_278690626911_item	3632416	et	4	main
ebamääletanud	doc_278690626911_item	3632415	et	4	main
on	doc_278690626911_item	3632405	et	4	main
traditsioon	doc_278690626911_item	3632398	et	3	main
see	doc_278690626911_item	3632396	et	3	main
nad	doc_278690626911_item	3632387	et	3	main
hing	doc_278690626911_item	3632386	et	3	main
oma	doc_278690626911_item	3632385	et	4	main
meie	doc_278690626906_item	3632088	et	4	main
palju	doc_278690626906_item	3632087	et	4	main
ja	doc_278690626906_item	3632086	et	3	main
suur	doc_278690626906_item	3632080	et	3	main
väga	doc_278690626906_item	3632079	et	3	main
ole	doc_278690626906_item	3632078	et	4	main
ei	doc_278690626906_item	3632077	et	4	main
eestimaa	doc_278690626906_item	3632076	et	4	main
televiisorid	doc_278690626906_item	3632075	et	3	main
telefonid	doc_278690626906_item	3632074	et	3	main
olnud	doc_278690626906_item	3632073	et	4	main
ei	doc_278690626906_item	3632072	et	4	main
kuna	doc_278690626906_item	3632071	et	3	main
tagasi	doc_278690626906_item	3632070	et	3	main
aastaid	doc_278690626906_item	3632069	et	4	main
palju	doc_278690626906_item	3632068	et	4	main
sündis	doc_278690626906_item	3632067	et	3	main
laulmine	doc_278690626906_item	3632066	et	4	main
laulurahva	doc_278690626906_item	3632065	et	3	main
eestlastest	doc_278690626906_item	3632064	et	4	main
teeb	doc_278690626906_item	3632063	et	3	main
mis	doc_278690626906_item	3632062	et	4	main
näidetega	doc_278690626906_item	3632061	et	3	main
illustreerida	doc_278690626906_item	3632060	et	3	main
ja	doc_278690626906_item	3632053	et	3	main
loengus	doc_278690626906_item	3632052	et	3	main
olema	doc_278690626906_item	3632046	et	4	main
300	doc_278690626906_item	3632041	et	2	main
teeb	doc_278690626906_item	3632036	et	3	main
keele	doc_278690626906_item	3632026	et	4	main
mis	doc_278690626911_item	3632583	et	4	main
on	doc_278690626911_item	3632572	et	4	main
mis	doc_278690626911_item	3632565	et	4	main
festivaale	doc_278690626911_item	3632564	et	4	main
ka	doc_278690626911_item	3632560	et	3	main
jalle	doc_278690626911_item	3632553	et	4	main
vaim	doc_278690626911_item	3632551	et	3	main
ja	doc_278690626911_item	3632549	et	3	main
eesti	doc_278690626911_item	3632546	et	4	main
ärkamine	doc_278690626911_item	3632545	et	4	main
rahvuslik	doc_278690626911_item	3632544	et	3	main
kui	doc_278690626911_item	3632535	et	3	main
linnas	doc_278690626911_item	3632534	et	4	main
nii	doc_278690626911_item	3632533	et	3	main
rahvas	doc_278690626911_item	3632532	et	4	main
oli	doc_278690626911_item	3632531	et	3	main
1869	doc_278690626911_item	3632525	et	2	main
sajandil	doc_278690626911_item	3632524	et	3	main
öö	doc_278690626911_item	3632480	et	4	main
1343	doc_278690626911_item	3632476	et	2	main
iga	doc_278690626911_item	3632466	et	4	main
hääled	doc_278690626911_item	3632465	et	3	main
olid	doc_278690626911_item	3632460	et	4	main
igaühel	doc_278690626911_item	3632455	et	3	main
last	doc_278690626911_item	3632423	et	4	main
olles	doc_278690626911_item	3632421	et	3	main
oli	doc_278690626911_item	3632397	et	3	main
tantsisid	doc_278690626911_item	3632395	et	4	main
ja	doc_278690626911_item	3632392	et	3	main
kogunesid	doc_278690626911_item	3632391	et	4	main
kivil	doc_278690626911_item	3632381	et	3	main
kõigil	doc_278690626911_item	3632379	et	4	main
metsas	doc_278690626911_item	3632378	et	3	main
kõiges	doc_278690626911_item	3632377	et	4	main
et	doc_278690626911_item	3632376	et	3	main
palju	doc_278690626911_item	3632372	et	4	main
rahval	doc_278690626911_item	3632370	et	3	main
oli	doc_278690626911_item	3632368	et	3	main
eesti	doc_278690626911_item	3632366	et	4	main
kui	doc_278690626911_item	3632365	et	3	main
selles	doc_278690626911_item	3632361	et	4	main
mis	doc_278690626911_item	3632359	et	4	main
osad	doc_278690626911_item	3632358	et	3	main
peamised	doc_278690626911_item	3632357	et	3	main
on	doc_278690626911_item	3632356	et	4	main
tants	doc_278690626911_item	3632355	et	3	main
ja	doc_278690626911_item	3632354	et	3	main
näidetega	doc_278690626911_item	3632330	et	3	main
illustreerida	doc_278690626911_item	3632329	et	3	main
on	doc_278690626911_item	3632327	et	4	main
ja	doc_278690626911_item	3632322	et	3	main
üldistav	doc_278690626911_item	3632319	et	4	main
arutlev	doc_278690626911_item	3632316	et	4	main
peab	doc_278690626911_item	3632314	et	4	main
on	doc_278690626911_item	3632620	et	4	main
nad	doc_278690626911_item	3632619	et	3	main
maailma	doc_278690626911_item	3632613	et	4	main
kõige	doc_278690626911_item	3632612	et	4	main
lauldi	doc_278690626911_item	3632584	et	3	main
essee	doc_278690626911_item	3632313	et	4	main
laulurahva	doc_278690626911_item	3632307	et	3	main
teeb	doc_278690626911_item	3632305	et	3	main
kirjutamine	doc_278690626911_item	3632300	et	4	main
keele	doc_278690626911_item	3632298	et	4	main
tants	doc_278690626911_item	3632633	et	3	main
ja	doc_278690626911_item	3632632	et	3	main
laul	doc_278690626911_item	3632631	et	4	main
on	doc_278690626911_item	3632630	et	4	main
kultuur	doc_278690626911_item	3632629	et	3	main
eesti	doc_278690626911_item	3632628	et	4	main
kultuur	doc_278690626911_item	3632627	et	3	main
oma	doc_278690626911_item	3632626	et	4	main
on	doc_278690626911_item	3632625	et	4	main
muusikat	doc_278690626911_item	3632580	et	3	main
mis	doc_278690626911_item	3632577	et	4	main
palju	doc_278690626911_item	3632574	et	4	main
ka	doc_278690626911_item	3632573	et	3	main
palju	doc_278690626911_item	3632562	et	4	main
on	doc_278690626911_item	3632561	et	4	main
eestlaste	doc_278690626911_item	3632543	et	4	main
aru	doc_278690626911_item	3632521	et	4	main
laulu	doc_278690626911_item	3632520	et	4	main
seda	doc_278690626911_item	3632519	et	3	main
saanud	doc_278690626911_item	3632518	et	4	main
ei	doc_278690626911_item	3632517	et	4	main
ja	doc_278690626911_item	3632516	et	3	main
keelt	doc_278690626911_item	3632515	et	4	main
eesti	doc_278690626911_item	3632514	et	4	main
teadnud	doc_278690626911_item	3632513	et	4	main
ei	doc_278690626911_item	3632512	et	4	main
härrad	doc_278690626911_item	3632511	et	3	main
taani	doc_278690626911_item	3632510	et	4	main
eestisse	doc_278690626911_item	3632509	et	4	main
kogu	doc_278690626911_item	3632508	et	4	main
levis	doc_278690626911_item	3632507	et	4	main
abimisel	doc_278690626911_item	3632506	et	4	main
laulu	doc_278690626911_item	3632505	et	4	main
ja	doc_278690626911_item	3632504	et	3	main
harjumaal	doc_278690626911_item	3632503	et	4	main
sündis	doc_278690626911_item	3632502	et	3	main
idee	doc_278690626911_item	3632501	et	4	main
selline	doc_278690626911_item	3632500	et	4	main
teha	doc_278690626911_item	3632499	et	3	main
vabaks	doc_278690626911_item	3632498	et	3	main
maa	doc_278690626911_item	3632497	et	4	main
oma	doc_278690626911_item	3632496	et	4	main
otsustas	doc_278690626911_item	3632495	et	3	main
rahvas	doc_278690626911_item	3632494	et	4	main
ja	doc_278690626911_item	3632493	et	3	main
raske	doc_278690626911_item	3632492	et	4	main
väga	doc_278690626911_item	3632491	et	3	main
olid	doc_278690626911_item	3632490	et	4	main
elamistingimused	doc_278690626911_item	3632489	et	3	main
juhtimisega	doc_278690626911_item	3632488	et	4	main
taani	doc_278690626911_item	3632487	et	4	main
rahuldav	doc_278690626911_item	3632486	et	4	main
olnud	doc_278690626911_item	3632485	et	4	main
sõda	doc_278690626911_item	3632482	et	4	main
aastal	doc_278690626911_item	3632477	et	3	main
eesti	doc_278690626911_item	3632473	et	4	main
oma	doc_278690626911_item	3632457	et	4	main
muusika	doc_278690626911_item	3632453	et	4	main
populaarsed	doc_278690626911_item	3632442	et	3	main
väga	doc_278690626911_item	3632441	et	3	main
laulud	doc_278690626911_item	3632440	et	3	main
rõõmsad	doc_278690626911_item	3632439	et	3	main
ka	doc_278690626911_item	3632438	et	3	main
lauldi	doc_278690626911_item	3632437	et	3	main
sündis	doc_278690626911_item	3632436	et	3	main
inimene	doc_278690626911_item	3632435	et	3	main
kui	doc_278690626911_item	3632434	et	3	main
kurb	doc_278690626911_item	3632433	et	3	main
oli	doc_278690626911_item	3632432	et	3	main
laulud	doc_278690626911_item	3632431	et	3	main
need	doc_278690626911_item	3632430	et	3	main
lauldi	doc_278690626911_item	3632429	et	3	main
siis	doc_278690626911_item	3632428	et	3	main
suri	doc_278690626911_item	3632427	et	3	main
inimene	doc_278690626911_item	3632426	et	3	main
kui	doc_278690626911_item	3632425	et	3	main
algas	doc_278690626911_item	3632481	et	3	main
oli	doc_278690626911_item	3632478	et	3	main
rahvas	doc_278690626911_item	3632474	et	4	main
juhul	doc_278690626911_item	3632472	et	3	main
ja	doc_278690626911_item	3632470	et	3	main
ilmas	doc_278690626911_item	3632469	et	4	main
looma	doc_278690626911_item	3632464	et	4	main
imiteerisid	doc_278690626911_item	3632463	et	4	main
vaate	doc_278690626911_item	3632459	et	4	main
instrumente	doc_278690626911_item	3632454	et	3	main
kiigutades	doc_278690626911_item	3632424	et	3	main
üksi	doc_278690626911_item	3632420	et	4	main
tänapäevases	doc_278690626911_item	3632407	et	4	main
ka	doc_278690626911_item	3632406	et	3	main
laulda	doc_278690626911_item	3632402	et	4	main
see	doc_278690626911_item	3632400	et	3	main
laulsid	doc_278690626911_item	3632393	et	4	main
jumalaid	doc_278690626911_item	3632390	et	3	main
oma	doc_278690626911_item	3632389	et	4	main
inimesed	doc_278690626911_item	3632374	et	3	main
koor	doc_278690626911_item	3632369	et	4	main
ammu	doc_278690626911_item	3632364	et	4	main
on	doc_278690626911_item	3632360	et	4	main
eesti	doc_278690626911_item	3632331	et	4	main
lugemistekstis	doc_278690626911_item	3632323	et	3	main
essee	doc_278690626911_item	3632293	et	4	main
uhkus	doc_278690626911_item	3632622	et	4	main
eesti	doc_278690626911_item	3632621	et	4	main
ots	doc_278690626911_item	3632616	et	3	main
sõna	doc_278690626911_item	3632312	et	4	main
350	doc_278690626911_item	3632311	et	2	main
300	doc_278690626911_item	3632310	et	2	main
mis	doc_278690626911_item	3632304	et	4	main
laulda	doc_278690626913_item	3632839	et	4	main
kaasa	doc_278690626913_item	3632838	et	4	main
rahvalauluga	doc_278690626913_item	3632820	et	4	main
on	doc_278690626913_item	3632818	et	4	main
mistõttu	doc_278690626913_item	3632817	et	3	main
minevik	doc_278690626913_item	3632816	et	3	main
rahva	doc_278690626913_item	3632815	et	3	main
kajastub	doc_278690626913_item	3632814	et	3	main
rahvalauludes	doc_278690626913_item	3632813	et	3	main
laulu	doc_278690626913_item	3632812	et	4	main
nad	doc_278690626913_item	3632806	et	3	main
töötavad	doc_278690626913_item	3632805	et	4	main
inimesed	doc_278690626913_item	3632804	et	3	main
üldse	doc_278690626913_item	3632803	et	3	main
eestlased	doc_278690626913_item	3632802	et	3	main
kui	doc_278690626913_item	3632801	et	3	main
on	doc_278690626913_item	3632790	et	4	main
kultuurile	doc_278690626913_item	3632785	et	3	main
armastavad	doc_278690626913_item	3632778	et	4	main
inimesed	doc_278690626913_item	3632777	et	3	main
natuke	doc_278690626911_item	3632409	et	4	main
maailmas	doc_278690626911_item	3632408	et	3	main
ning	doc_278690626911_item	3632403	et	3	main
traditsioon	doc_278690626911_item	3632401	et	3	main
ning	doc_278690626911_item	3632394	et	3	main
oli	doc_278690626911_item	3632384	et	3	main
puul	doc_278690626911_item	3632383	et	3	main
jumalaid	doc_278690626911_item	3632373	et	3	main
laul	doc_278690626911_item	3632353	et	4	main
loengus	doc_278690626911_item	3632321	et	3	main
analüüsiv	doc_278690626911_item	3632317	et	4	main
olema	doc_278690626911_item	3632315	et	4	main
rahval	doc_278690626911_item	3632624	et	3	main
georg	doc_278690626911_item	3632615	et	4	main
tuntus	doc_278690626911_item	3632614	et	4	main
kellel	doc_278690626911_item	3632610	et	4	main
lauljate	doc_278690626911_item	3632609	et	4	main
ja	doc_278690626911_item	3632608	et	3	main
heliloojate	doc_278690626911_item	3632607	et	3	main
palju	doc_278690626911_item	3632606	et	4	main
on	doc_278690626911_item	3632605	et	4	main
eestis	doc_278690626911_item	3632604	et	3	main
areneb	doc_278690626911_item	3632603	et	3	main
kultuur	doc_278690626911_item	3632602	et	3	main
et	doc_278690626911_item	3632601	et	3	main
tähendab	doc_278690626911_item	3632600	et	3	main
see	doc_278690626911_item	3632599	et	3	main
ja	doc_278690626911_item	3632598	et	3	main
muusika	doc_278690626911_item	3632597	et	4	main
kaasaegne	doc_278690626911_item	3632596	et	3	main
eelistavad	doc_278690626911_item	3632595	et	4	main
mis	doc_278690626911_item	3632594	et	4	main
bändid	doc_278690626911_item	3632593	et	4	main
või	doc_278690626911_item	3632592	et	4	main
ansamblid	doc_278690626911_item	3632591	et	3	main
noored	doc_278690626911_item	3632590	et	3	main
ka	doc_278690626911_item	3632589	et	3	main
on	doc_278690626911_item	3632588	et	4	main
tagasi	doc_278690626911_item	3632587	et	3	main
aastat	doc_278690626911_item	3632586	et	3	main
tuhat	doc_278690626911_item	3632585	et	4	main
uskusid	doc_278690626911_item	3632375	et	4	main
ammu	doc_278690626911_item	3632363	et	4	main
kultuur	doc_278690626911_item	3632352	et	3	main
vana	doc_278690626911_item	3632351	et	4	main
ja	doc_278690626911_item	3632350	et	3	main
suur	doc_278690626911_item	3632349	et	3	main
on	doc_278690626911_item	3632348	et	4	main
milles	doc_278690626911_item	3632347	et	3	main
ja	doc_278690626911_item	3632346	et	3	main
maal	doc_278690626911_item	3632345	et	4	main
oma	doc_278690626911_item	3632344	et	4	main
elab	doc_278690626911_item	3632343	et	3	main
kus	doc_278690626911_item	3632342	et	3	main
rahvas	doc_278690626911_item	3632341	et	4	main
väike	doc_278690626911_item	3632340	et	4	main
päris	doc_278690626911_item	3632339	et	4	main
on	doc_278690626911_item	3632338	et	4	main
see	doc_278690626911_item	3632337	et	3	main
suur	doc_278690626911_item	3632336	et	3	main
väga	doc_278690626911_item	3632335	et	3	main
ole	doc_278690626911_item	3632334	et	4	main
ei	doc_278690626911_item	3632333	et	4	main
väiteid	doc_278690626911_item	3632326	et	4	main
faktidele	doc_278690626911_item	3632325	et	3	main
esitatud	doc_278690626911_item	3632324	et	4	main
tuginema	doc_278690626911_item	3632320	et	3	main
ernesaks	doc_278690626911_item	3632618	et	4	main
pikkus	doc_278690626911_item	3632309	et	4	main
teemal	doc_278690626911_item	3632303	et	3	main
samu	doc_278690626913_item	3632848	et	3	main
tekib	doc_278690626913_item	3632845	et	3	main
tunnet	doc_278690626913_item	3632843	et	3	main
ülendavat	doc_278690626913_item	3632842	et	4	main
seda	doc_278690626913_item	3632841	et	3	main
palju	doc_278690626913_item	3632810	et	4	main
väga	doc_278690626913_item	3632809	et	3	main
nendel	doc_278690626913_item	3632808	et	4	main
tuhat	doc_278690626913_item	3632794	et	4	main
kui	doc_278690626913_item	3632793	et	3	main
rahvalaul	doc_278690626913_item	3632788	et	4	main
iseloomulik	doc_278690626913_item	3632786	et	3	main
läänemeresoome	doc_278690626913_item	3632784	et	3	main
laulutraditsiooni	doc_278690626913_item	3632782	et	4	main
tore	doc_278690626913_item	3632772	et	3	main
on	doc_278690626913_item	3632770	et	4	main
arm	doc_278690626913_item	3632768	et	3	main
minu	doc_278690626913_item	3632767	et	3	main
on	doc_278690626913_item	3632766	et	4	main
hümm	doc_278690626913_item	3632761	et	4	main
kes	doc_278690626913_item	3632758	et	4	main
ja	doc_278690626913_item	3632727	et	3	main
ja	doc_278690626913_item	3632724	et	3	main
september	doc_278690626913_item	3632721	et	3	main
on	doc_278690626913_item	3632712	et	4	main
eestis	doc_278690626913_item	3632711	et	3	main
pidusid	doc_278690626913_item	3632702	et	4	main
eesti	doc_278690626913_item	3632701	et	4	main
meeldib	doc_278690626913_item	3632700	et	3	main
inimesed	doc_278690626913_item	3632694	et	3	main
rõõmsamelne	doc_278690626913_item	3632693	et	4	main
ja	doc_278690626913_item	3632692	et	3	main
arvan	doc_278690626913_item	3632686	et	3	main
aga	doc_278690626913_item	3632681	et	3	main
üldistav	doc_278690626913_item	3632661	et	4	main
eestlastest	doc_278690626913_item	3632648	et	4	main
eesti	doc_278690626913_item	3632636	et	4	main
ole	doc_278690626914_item	3633012	et	4	main
regatil	doc_278690626914_item	3632990	et	3	main
näiteks	doc_278690626914_item	3632987	et	4	main
vaid	doc_278690626914_item	3632979	et	3	main
võib	doc_278690626914_item	3632970	et	3	main
tegi	doc_278690626914_item	3632967	et	4	main
kirjutage	doc_278690626911_item	3632301	et	3	main
teise	doc_278690626911_item	3632297	et	4	main
keele	doc_278690626911_item	3632295	et	4	main
eesti	doc_278690626911_item	3632294	et	4	main
tuhandete	doc_278690626913_item	3632846	et	3	main
kogedes	doc_278690626913_item	3632840	et	4	main
maa	doc_278690626913_item	3632780	et	4	main
oma	doc_278690626913_item	3632779	et	4	main
ja	doc_278690626913_item	3632775	et	3	main
eestlased	doc_278690626913_item	3632774	et	3	main
ernesaks	doc_278690626913_item	3632757	et	4	main
gustav	doc_278690626913_item	3632756	et	4	main
head	doc_278690626913_item	3632750	et	4	main
laulupüha	doc_278690626913_item	3632729	et	4	main
kindlasti	doc_278690626913_item	3632728	et	3	main
uus	doc_278690626913_item	3632725	et	3	main
1	doc_278690626913_item	3632720	et	2	main
näiteks	doc_278690626913_item	3632717	et	4	main
ja	doc_278690626913_item	3632715	et	3	main
traditsioonid	doc_278690626913_item	3632714	et	3	main
erinevad	doc_278690626913_item	3632713	et	4	main
rikkas	doc_278690626913_item	3632697	et	4	main
väga	doc_278690626913_item	3632690	et	3	main
ma	doc_278690626913_item	3632685	et	3	main
raske	doc_278690626913_item	3632679	et	4	main
on	doc_278690626913_item	3632678	et	4	main
see	doc_278690626913_item	3632677	et	3	main
laulurahva	doc_278690626913_item	3632676	et	3	main
eestlastest	doc_278690626913_item	3632675	et	4	main
teeb	doc_278690626913_item	3632674	et	3	main
mis	doc_278690626913_item	3632673	et	4	main
näidetega	doc_278690626913_item	3632672	et	3	main
illustreerida	doc_278690626913_item	3632671	et	3	main
soovitatav	doc_278690626913_item	3632670	et	4	main
on	doc_278690626913_item	3632669	et	4	main
väiteid	doc_278690626913_item	3632668	et	4	main
faktidele	doc_278690626913_item	3632667	et	3	main
esitatud	doc_278690626913_item	3632666	et	4	main
lugemistekstis	doc_278690626913_item	3632665	et	3	main
terve	doc_278690626913_item	3632876	et	4	main
ole	doc_278690626913_item	3632875	et	4	main
s	doc_278690626913_item	3632874	et	4	main
p	doc_278690626913_item	3632873	et	4	main
laulurahvas	doc_278690626913_item	3632872	et	4	main
on	doc_278690626913_item	3632871	et	4	main
eestlased	doc_278690626913_item	3632870	et	3	main
et	doc_278690626913_item	3632869	et	3	main
aus	doc_278690626913_item	3632868	et	4	main
ma	doc_278690626913_item	3632867	et	3	main
et	doc_278690626913_item	3632866	et	3	main
nii	doc_278690626913_item	3632865	et	3	main
tahan	doc_278690626913_item	3632864	et	3	main
ma	doc_278690626913_item	3632863	et	3	main
lõpetaks	doc_278690626913_item	3632862	et	4	main
sümboliteks	doc_278690626913_item	3632861	et	3	main
rahvuslikeks	doc_278690626913_item	3632860	et	3	main
kujunenud	doc_278690626913_item	3632859	et	4	main
aja	doc_278690626913_item	3632858	et	4	main
läbi	doc_278690626913_item	3632857	et	4	main
on	doc_278690626913_item	3632856	et	4	main
laulud	doc_278690626913_item	3632855	et	3	main
need	doc_278690626913_item	3632854	et	3	main
lauldes	doc_278690626913_item	3632853	et	3	main
viisi	doc_278690626913_item	3632852	et	4	main
sama	doc_278690626913_item	3632851	et	4	main
ja	doc_278690626913_item	3632850	et	3	main
sõnu	doc_278690626913_item	3632849	et	4	main
mis	doc_278690626913_item	3632844	et	4	main
võimalust	doc_278690626913_item	3632837	et	3	main
tegelikult	doc_278690626913_item	3632836	et	4	main
kuulajaskond	doc_278690626913_item	3632835	et	3	main
ootab	doc_278690626913_item	3632834	et	3	main
elamust	doc_278690626913_item	3632833	et	4	main
pealtvaataja	doc_278690626913_item	3632832	et	4	main
kõigepealt	doc_278690626913_item	3632831	et	3	main
publikule	doc_278690626913_item	3632830	et	3	main
pakub	doc_278690626913_item	3632829	et	3	main
laulupidu	doc_278690626913_item	3632828	et	4	main
tänapäeval	doc_278690626913_item	3632827	et	3	main
lisaks	doc_278690626913_item	3632826	et	4	main
uurimine	doc_278690626913_item	3632825	et	4	main
ajaloo	doc_278690626913_item	3632824	et	4	main
nagu	doc_278690626913_item	3632823	et	3	main
pisut	doc_278690626913_item	3632822	et	3	main
tutvumine	doc_278690626913_item	3632821	et	4	main
teistega	doc_278690626913_item	3632847	et	4	main
erinevaid	doc_278690626913_item	3632811	et	4	main
varem	doc_278690626913_item	3632800	et	4	main
et	doc_278690626913_item	3632799	et	3	main
tean	doc_278690626913_item	3632798	et	3	main
ma	doc_278690626913_item	3632797	et	3	main
tagasi	doc_278690626913_item	3632796	et	3	main
aastat	doc_278690626913_item	3632795	et	3	main
enam	doc_278690626913_item	3632792	et	4	main
kujunenud	doc_278690626913_item	3632791	et	4	main
regivärsiline	doc_278690626913_item	3632787	et	4	main
esindab	doc_278690626913_item	3632783	et	3	main
isamaalaul	doc_278690626913_item	3632763	et	4	main
eesti	doc_278690626913_item	3632760	et	4	main
kompositoreid	doc_278690626913_item	3632754	et	4	main
huvitavat	doc_278690626913_item	3632753	et	4	main
ja	doc_278690626913_item	3632752	et	3	main
targat	doc_278690626913_item	3632751	et	4	main
koos	doc_278690626913_item	3632739	et	4	main
rahvapidu	doc_278690626913_item	3632736	et	4	main
on	doc_278690626913_item	3632734	et	4	main
jõulupühad	doc_278690626913_item	3632723	et	3	main
kadripäev	doc_278690626913_item	3632719	et	3	main
pidusid	doc_278690626913_item	3632716	et	4	main
iga	doc_278690626913_item	3632704	et	4	main
sest	doc_278690626913_item	3632703	et	4	main
nendel	doc_278690626913_item	3632695	et	4	main
et	doc_278690626913_item	3632687	et	3	main
vastada	doc_278690626913_item	3632684	et	4	main
ja	doc_278690626913_item	3632660	et	3	main
arutlev	doc_278690626913_item	3632658	et	4	main
essee	doc_278690626913_item	3632650	et	4	main
laulurahva	doc_278690626913_item	3632649	et	3	main
keele	doc_278690626913_item	3632637	et	4	main
ka	doc_278690626913_item	3632819	et	3	main
laulavad	doc_278690626913_item	3632807	et	4	main
mis	doc_278690626913_item	3632789	et	4	main
eesti	doc_278690626913_item	3632781	et	4	main
ülde	doc_278690626913_item	3632776	et	4	main
väga	doc_278690626913_item	3632771	et	3	main
see	doc_278690626913_item	3632769	et	3	main
isamaa	doc_278690626913_item	3632765	et	4	main
mu	doc_278690626913_item	3632764	et	3	main
näiteks	doc_278690626913_item	3632755	et	4	main
palju	doc_278690626913_item	3632749	et	4	main
perega	doc_278690626913_item	3632740	et	3	main
tullakse	doc_278690626913_item	3632738	et	3	main
kuhu	doc_278690626913_item	3632737	et	3	main
suur	doc_278690626913_item	3632735	et	3	main
aastat	doc_278690626913_item	3632726	et	3	main
valentinipäev	doc_278690626913_item	3632722	et	4	main
jaanipäev	doc_278690626913_item	3632718	et	3	main
mulle	doc_278690626913_item	3632699	et	4	main
ajalugu	doc_278690626913_item	3632698	et	4	main
sõbralikud	doc_278690626913_item	3632691	et	3	main
on	doc_278690626913_item	3632689	et	4	main
ma	doc_278690626913_item	3632682	et	3	main
loengus	doc_278690626913_item	3632663	et	3	main
mis	doc_278690626913_item	3632646	et	4	main
kirjutamine	doc_278690626913_item	3632642	et	4	main
test	doc_278690626913_item	3632641	et	3	main
essee	doc_278690626913_item	3632635	et	4	main
rahvas	doc_278690626914_item	3633009	et	4	main
on	doc_278690626914_item	3633002	et	4	main
või	doc_278690626914_item	3632991	et	4	main
eestlastega	doc_278690626914_item	3632981	et	4	main
suhtlen	doc_278690626914_item	3632980	et	3	main
olla	doc_278690626914_item	3632971	et	3	main
eesti	doc_278690626914_item	3632960	et	4	main
kui	doc_278690626914_item	3632959	et	3	main
ja	doc_278690626914_item	3632922	et	3	main
esteetiline	doc_278690626914_item	3632921	et	3	main
ole	doc_278690626914_item	3632919	et	4	main
laulmine	doc_278690626914_item	3632916	et	4	main
näidetega	doc_278690626914_item	3632915	et	3	main
lugemistekstis	doc_278690626914_item	3632908	et	3	main
ja	doc_278690626914_item	3632903	et	3	main
300	doc_278690626914_item	3632895	et	2	main
pikkus	doc_278690626914_item	3632894	et	4	main
ja	doc_278690626915_item	3633250	et	3	main
see	doc_278690626915_item	3633236	et	3	main
rahvalaulud	doc_278690626915_item	3633232	et	3	main
ja	doc_278690626915_item	3633230	et	3	main
meeldib	doc_278690626915_item	3633226	et	3	main
paljudele	doc_278690626915_item	3633225	et	3	main
muusika	doc_278690626915_item	3633223	et	4	main
vana	doc_278690626915_item	3633216	et	4	main
on	doc_278690626915_item	3633206	et	4	main
seal	doc_278690626915_item	3633205	et	4	main
kultuurid	doc_278690626915_item	3633165	et	3	main
jaata	doc_278690626915_item	3633156	et	4	main
et	doc_278690626913_item	3632773	et	3	main
või	doc_278690626913_item	3632762	et	4	main
сочинил	doc_278690626913_item	3632759	et	2	main
on	doc_278690626913_item	3632748	et	4	main
eestimaal	doc_278690626913_item	3632747	et	4	main
tuttavaid	doc_278690626913_item	3632746	et	3	main
ja	doc_278690626913_item	3632745	et	3	main
sugulasi	doc_278690626913_item	3632744	et	3	main
sõpru	doc_278690626913_item	3632743	et	3	main
kohata	doc_278690626913_item	3632742	et	4	main
lootuses	doc_278690626913_item	3632741	et	4	main
laulupidu	doc_278690626913_item	3632733	et	4	main
et	doc_278690626913_item	3632732	et	3	main
arvan	doc_278690626913_item	3632731	et	3	main
ma	doc_278690626913_item	3632730	et	3	main
meil	doc_278690626913_item	3632710	et	4	main
mängib	doc_278690626913_item	3632709	et	3	main
ja	doc_278690626913_item	3632708	et	3	main
tantsib	doc_278690626913_item	3632707	et	3	main
laulab	doc_278690626913_item	3632706	et	3	main
üks	doc_278690626913_item	3632705	et	3	main
on	doc_278690626913_item	3632696	et	4	main
eestlased	doc_278690626913_item	3632688	et	3	main
provin	doc_278690626913_item	3632683	et	4	main
küsimus	doc_278690626913_item	3632680	et	4	main
ja	doc_278690626913_item	3632664	et	3	main
olema	doc_278690626913_item	3632657	et	4	main
essee	doc_278690626913_item	3632655	et	4	main
350	doc_278690626913_item	3632653	et	2	main
teemal	doc_278690626913_item	3632645	et	3	main
essee	doc_278690626913_item	3632644	et	4	main
teise	doc_278690626913_item	3632639	et	4	main
kui	doc_278690626913_item	3632638	et	3	main
ka	doc_278690626914_item	3633020	et	3	main
sõnad	doc_278690626914_item	3633018	et	4	main
nende	doc_278690626914_item	3633017	et	4	main
teab	doc_278690626914_item	3633016	et	3	main
inimene	doc_278690626914_item	3633015	et	3	main
ei	doc_278690626914_item	3633011	et	4	main
teises	doc_278690626914_item	3633008	et	4	main
palju	doc_278690626914_item	3633006	et	4	main
rahvas	doc_278690626914_item	3633001	et	4	main
eesti	doc_278690626914_item	3633000	et	4	main
et	doc_278690626914_item	3632999	et	3	main
näha	doc_278690626914_item	3632998	et	3	main
päris	doc_278690626914_item	3632982	et	4	main
rahvas	doc_278690626914_item	3632966	et	4	main
vabaks	doc_278690626914_item	3632964	et	3	main
liidu	doc_278690626914_item	3632963	et	3	main
nõukogude	doc_278690626914_item	3632962	et	3	main
sai	doc_278690626914_item	3632961	et	4	main
väiteid	doc_278690626914_item	3632911	et	4	main
ja	doc_278690626914_item	3632907	et	3	main
tuginema	doc_278690626914_item	3632905	et	3	main
peab	doc_278690626914_item	3632899	et	4	main
eestlastest	doc_278690626914_item	3632891	et	4	main
aeg	doc_278690626915_item	3633251	et	3	main
elas	doc_278690626915_item	3633242	et	3	main
et	doc_278690626915_item	3633240	et	3	main
ainult	doc_278690626915_item	3633238	et	4	main
tähendab	doc_278690626915_item	3633237	et	3	main
muutub	doc_278690626915_item	3633228	et	3	main
on	doc_278690626915_item	3633199	et	4	main
näiteks	doc_278690626915_item	3633196	et	4	main
populaarne	doc_278690626915_item	3633195	et	3	main
eesti	doc_278690626915_item	3633167	et	4	main
muud	doc_278690626915_item	3633164	et	4	main
paljud	doc_278690626915_item	3633163	et	3	main
et	doc_278690626915_item	3633162	et	3	main
ei	doc_278690626915_item	3633155	et	4	main
nii	doc_278690626915_item	3633150	et	3	main
kahjuks	doc_278690626915_item	3633142	et	4	main
tähtsusega	doc_278690626915_item	3633136	et	4	main
üksi	doc_278690626915_item	3633118	et	4	main
peamiselt	doc_278690626915_item	3633110	et	4	main
algavad	doc_278690626915_item	3633107	et	4	main
kõik	doc_278690626915_item	3633105	et	4	main
kus	doc_278690626915_item	3633104	et	3	main
rahvalaul	doc_278690626915_item	3633103	et	4	main
osast	doc_278690626915_item	3633095	et	4	main
olema	doc_278690626915_item	3633045	et	4	main
essee	doc_278690626915_item	3633038	et	4	main
keele	doc_278690626915_item	3633028	et	4	main
saatis	doc_278690626915_item	3633076	et	3	main
tants	doc_278690626915_item	3633073	et	3	main
laul	doc_278690626915_item	3633070	et	4	main
tähtsat	doc_278690626915_item	3633066	et	3	main
kolmest	doc_278690626915_item	3633064	et	4	main
käsitsi	doc_278690626917_item	3633354	et	3	main
kirjutati	doc_278690626917_item	3633352	et	3	main
eestis	doc_278690626917_item	3633333	et	3	main
eesti	doc_278690626917_item	3633324	et	4	main
last	doc_278690626917_item	3633317	et	4	main
tuginema	doc_278690626913_item	3632662	et	3	main
analüüsiv	doc_278690626913_item	3632659	et	4	main
peab	doc_278690626913_item	3632656	et	4	main
sõna	doc_278690626913_item	3632654	et	4	main
300	doc_278690626913_item	3632652	et	2	main
pikkus	doc_278690626913_item	3632651	et	4	main
teeb	doc_278690626913_item	3632647	et	3	main
kirjutage	doc_278690626913_item	3632643	et	3	main
keele	doc_278690626913_item	3632640	et	4	main
mina	doc_278690626914_item	3633021	et	4	main
küll	doc_278690626914_item	3633010	et	4	main
merelaulu	doc_278690626914_item	3633007	et	4	main
nii	doc_278690626914_item	3633005	et	3	main
laulurahvas	doc_278690626914_item	3633004	et	4	main
kohe	doc_278690626914_item	3632997	et	4	main
saad	doc_278690626914_item	3632996	et	4	main
siis	doc_278690626914_item	3632995	et	3	main
surfilaagrisse	doc_278690626914_item	3632994	et	3	main
suvel	doc_278690626914_item	3632993	et	3	main
sõidad	doc_278690626914_item	3632992	et	3	main
muhu	doc_278690626914_item	3632988	et	3	main
ajaloo	doc_278690626914_item	3632978	et	4	main
eesti	doc_278690626914_item	3632977	et	4	main
hästi	doc_278690626914_item	3632976	et	3	main
eriti	doc_278690626914_item	3632975	et	3	main
tea	doc_278690626914_item	3632974	et	4	main
ei	doc_278690626914_item	3632973	et	4	main
ma	doc_278690626914_item	3632972	et	3	main
ka	doc_278690626914_item	3632968	et	3	main
meie	doc_278690626914_item	3632965	et	4	main
ei	doc_278690626914_item	3632918	et	4	main
see	doc_278690626914_item	3632917	et	3	main
soovitatav	doc_278690626914_item	3632913	et	4	main
loengus	doc_278690626914_item	3632906	et	3	main
essee	doc_278690626914_item	3632898	et	4	main
sõna	doc_278690626914_item	3632897	et	4	main
mängivad	doc_278690626915_item	3633233	et	4	main
vanad	doc_278690626915_item	3633231	et	3	main
keeles	doc_278690626915_item	3633219	et	4	main
laulu	doc_278690626915_item	3633217	et	4	main
ühe	doc_278690626915_item	3633215	et	4	main
need	doc_278690626915_item	3633211	et	3	main
on	doc_278690626915_item	3633203	et	4	main
nimi	doc_278690626915_item	3633202	et	3	main
kõik	doc_278690626915_item	3633158	et	4	main
midagi	doc_278690626915_item	3633157	et	4	main
neilt	doc_278690626915_item	3633152	et	4	main
kadunud	doc_278690626915_item	3633146	et	4	main
laulupidu	doc_278690626915_item	3633140	et	4	main
folkloori	doc_278690626915_item	3633128	et	4	main
aga	doc_278690626915_item	3633124	et	3	main
kasvatasid	doc_278690626915_item	3633123	et	4	main
nad	doc_278690626915_item	3633122	et	3	main
ka	doc_278690626915_item	3633121	et	3	main
sest	doc_278690626915_item	3633114	et	4	main
naised	doc_278690626915_item	3633113	et	3	main
triiprida	doc_278690626915_item	3633098	et	4	main
rahvalaul	doc_278690626915_item	3633091	et	4	main
peab	doc_278690626915_item	3633044	et	4	main
essee	doc_278690626915_item	3633043	et	4	main
keele	doc_278690626915_item	3633025	et	4	main
essee	doc_278690626915_item	3633023	et	4	main
või	doc_278690626915_item	3633087	et	4	main
hällist	doc_278690626915_item	3633079	et	4	main
samuti	doc_278690626914_item	3633019	et	3	main
iga	doc_278690626914_item	3633014	et	4	main
ja	doc_278690626914_item	3633013	et	3	main
tõsiselt	doc_278690626914_item	3633003	et	4	main
väina	doc_278690626914_item	3632989	et	4	main
osa	doc_278690626914_item	3632986	et	4	main
võtad	doc_278690626914_item	3632985	et	3	main
kui	doc_278690626914_item	3632984	et	3	main
palju	doc_278690626914_item	3632983	et	4	main
laulurevolutsioon	doc_278690626914_item	3632969	et	3	main
kõrgemale	doc_278690626914_item	3632958	et	4	main
veel	doc_278690626914_item	3632957	et	4	main
laulukultuur	doc_278690626914_item	3632956	et	3	main
ja	doc_278690626914_item	3632955	et	3	main
tantsu	doc_278690626914_item	3632954	et	4	main
tõstsid	doc_278690626914_item	3632953	et	4	main
laulupeod	doc_278690626914_item	3632952	et	4	main
need	doc_278690626914_item	3632951	et	3	main
korraldama	doc_278690626914_item	3632950	et	3	main
laulupeod	doc_278690626914_item	3632949	et	4	main
need	doc_278690626914_item	3632948	et	3	main
hakkati	doc_278690626914_item	3632947	et	3	main
sajandil	doc_278690626914_item	3632946	et	3	main
üleeelmisel	doc_278690626914_item	3632945	et	4	main
ajal	doc_278690626914_item	3632944	et	4	main
igal	doc_278690626914_item	3632943	et	3	main
elada	doc_278690626914_item	3632942	et	3	main
eestlastele	doc_278690626914_item	3632941	et	4	main
aitas	doc_278690626914_item	3632940	et	3	main
laulmine	doc_278690626914_item	3632939	et	4	main
kiigutades	doc_278690626914_item	3632938	et	3	main
last	doc_278690626914_item	3632937	et	4	main
peol	doc_278690626914_item	3632936	et	4	main
merel	doc_278690626914_item	3632935	et	3	main
peal	doc_278690626914_item	3632934	et	4	main
põllu	doc_278690626914_item	3632933	et	3	main
igalpool	doc_278690626914_item	3632932	et	4	main
lauldi	doc_278690626914_item	3632931	et	3	main
ajal	doc_278690626914_item	3632930	et	4	main
vanal	doc_278690626914_item	3632929	et	3	main
tegevus	doc_278690626914_item	3632928	et	4	main
sotsiaalne	doc_278690626914_item	3632927	et	3	main
ka	doc_278690626914_item	3632926	et	3	main
vaid	doc_278690626914_item	3632925	et	3	main
väljendusvahed	doc_278690626914_item	3632924	et	3	main
emotsionaalne	doc_278690626914_item	3632923	et	3	main
ainult	doc_278690626914_item	3632920	et	4	main
on	doc_278690626914_item	3632912	et	4	main
esitatud	doc_278690626914_item	3632909	et	4	main
üldistav	doc_278690626914_item	3632904	et	4	main
analüüsiv	doc_278690626914_item	3632902	et	4	main
arutlev	doc_278690626914_item	3632901	et	4	main
olema	doc_278690626914_item	3632900	et	4	main
350	doc_278690626914_item	3632896	et	2	main
laulurahva	doc_278690626914_item	3632892	et	3	main
teeb	doc_278690626914_item	3632890	et	3	main
mis	doc_278690626914_item	3632889	et	4	main
teemal	doc_278690626914_item	3632888	et	3	main
essee	doc_278690626914_item	3632887	et	4	main
kirjutage	doc_278690626914_item	3632886	et	3	main
kirjutamine	doc_278690626914_item	3632885	et	4	main
test	doc_278690626914_item	3632884	et	3	main
keele	doc_278690626914_item	3632883	et	4	main
teise	doc_278690626914_item	3632882	et	4	main
kui	doc_278690626914_item	3632881	et	3	main
keele	doc_278690626914_item	3632880	et	4	main
eesti	doc_278690626914_item	3632879	et	4	main
essee	doc_278690626914_item	3632878	et	4	main
illustreerida	doc_278690626914_item	3632914	et	3	main
faktidele	doc_278690626914_item	3632910	et	3	main
essee	doc_278690626914_item	3632893	et	4	main
muutuvad	doc_278690626915_item	3633248	et	4	main
ainult	doc_278690626915_item	3633247	et	4	main
elada	doc_278690626915_item	3633246	et	3	main
elab	doc_278690626915_item	3633243	et	3	main
stiilis	doc_278690626915_item	3633235	et	4	main
setu	doc_278690626915_item	3633218	et	4	main
laulavad	doc_278690626915_item	3633214	et	4	main
poissid	doc_278690626915_item	3633210	et	4	main
mängivad	doc_278690626915_item	3633209	et	4	main
kus	doc_278690626915_item	3633208	et	3	main
bänd	doc_278690626915_item	3633207	et	3	main
mis	doc_278690626915_item	3633201	et	4	main
koht	doc_278690626915_item	3633200	et	3	main
lõuna	doc_278690626915_item	3633197	et	4	main
väga	doc_278690626915_item	3633194	et	3	main
ka	doc_278690626915_item	3633193	et	3	main
praegu	doc_278690626915_item	3633192	et	3	main
sellest	doc_278690626915_item	3633161	et	4	main
juhtub	doc_278690626915_item	3633160	et	3	main
see	doc_278690626915_item	3633159	et	3	main
rahvalaulust	doc_278690626915_item	3633154	et	4	main
esmaalguse	doc_278690626915_item	3633153	et	3	main
või	doc_278690626915_item	3633147	et	4	main
on	doc_278690626915_item	3633145	et	4	main
pärast	doc_278690626915_item	3633129	et	4	main
olnud	doc_278690626915_item	3633117	et	4	main
rohkem	doc_278690626915_item	3633116	et	4	main
nad	doc_278690626915_item	3633115	et	3	main
tähest	doc_278690626915_item	3633109	et	4	main
sõnad	doc_278690626915_item	3633106	et	4	main
esimene	doc_278690626915_item	3633096	et	3	main
koosneb	doc_278690626915_item	3633093	et	3	main
kiigutades	doc_278690626915_item	3633090	et	3	main
analüüsiv	doc_278690626915_item	3633047	et	4	main
sõna	doc_278690626915_item	3633042	et	4	main
350	doc_278690626915_item	3633041	et	2	main
300	doc_278690626915_item	3633040	et	2	main
teemal	doc_278690626915_item	3633033	et	3	main
essee	doc_278690626915_item	3633032	et	4	main
kirjutage	doc_278690626915_item	3633031	et	3	main
kui	doc_278690626915_item	3633026	et	3	main
eestlast	doc_278690626915_item	3633078	et	4	main
see	doc_278690626915_item	3633068	et	3	main
väga	doc_278690626915_item	3633065	et	3	main
koostab	doc_278690626915_item	3633063	et	3	main
on	doc_278690626917_item	3633358	et	4	main
suuliselt	doc_278690626917_item	3633350	et	4	main
põlve	doc_278690626917_item	3633349	et	4	main
ja	doc_278690626917_item	3633344	et	3	main
sajandil	doc_278690626917_item	3633339	et	3	main
arenesid	doc_278690626917_item	3633336	et	4	main
ja	doc_278690626917_item	3633335	et	3	main
levisid	doc_278690626917_item	3633334	et	4	main
kõige	doc_278690626917_item	3633321	et	4	main
on	doc_278690626917_item	3633320	et	4	main
laulud	doc_278690626917_item	3633319	et	3	main
kiigutades	doc_278690626917_item	3633318	et	3	main
olid	doc_278690626917_item	3633313	et	4	main
laulsid	doc_278690626917_item	3633308	et	4	main
analüüsiv	doc_278690626917_item	3633277	et	4	main
eestlastest	doc_278690626917_item	3633266	et	4	main
teeb	doc_278690626917_item	3633265	et	3	main
inimesed	doc_278690626915_item	3633249	et	3	main
tuleb	doc_278690626915_item	3633245	et	3	main
ja	doc_278690626915_item	3633244	et	3	main
rahvalaul	doc_278690626915_item	3633241	et	4	main
seda	doc_278690626915_item	3633239	et	3	main
uues	doc_278690626915_item	3633234	et	3	main
muusika	doc_278690626915_item	3633229	et	4	main
kui	doc_278690626915_item	3633227	et	3	main
ka	doc_278690626915_item	3633224	et	3	main
uuendanud	doc_278690626915_item	3633222	et	4	main
selline	doc_278690626915_item	3633221	et	4	main
ja	doc_278690626915_item	3633220	et	3	main
mehed	doc_278690626915_item	3633213	et	3	main
noored	doc_278690626915_item	3633212	et	3	main
värska	doc_278690626915_item	3633204	et	4	main
eestis	doc_278690626915_item	3633198	et	3	main
rahvalaul	doc_278690626915_item	3633191	et	4	main
uuendanud	doc_278690626915_item	3633190	et	4	main
aga	doc_278690626915_item	3633189	et	3	main
kihnus	doc_278690626915_item	3633188	et	3	main
ja	doc_278690626915_item	3633187	et	3	main
setumaal	doc_278690626915_item	3633186	et	4	main
ainult	doc_278690626915_item	3633185	et	4	main
säilitanud	doc_278690626915_item	3633184	et	4	main
rahvalaulud	doc_278690626915_item	3633183	et	3	main
esmakordsed	doc_278690626915_item	3633182	et	3	main
venemaast	doc_278690626915_item	3633181	et	3	main
tuli	doc_278690626915_item	3633180	et	4	main
mis	doc_278690626915_item	3633179	et	4	main
bojaani	doc_278690626915_item	3633178	et	4	main
ka	doc_278690626915_item	3633177	et	3	main
kuulda	doc_278690626915_item	3633176	et	4	main
võib	doc_278690626915_item	3633175	et	3	main
praegu	doc_278690626915_item	3633174	et	3	main
pillid	doc_278690626915_item	3633173	et	4	main
ainult	doc_278690626915_item	3633172	et	4	main
olid	doc_278690626915_item	3633171	et	4	main
varem	doc_278690626915_item	3633170	et	4	main
kui	doc_278690626915_item	3633169	et	3	main
folklooridele	doc_278690626915_item	3633168	et	4	main
mõjutavad	doc_278690626915_item	3633166	et	4	main
nad	doc_278690626915_item	3633148	et	3	main
rahvalaule	doc_278690626915_item	3633144	et	4	main
sellist	doc_278690626915_item	3633143	et	4	main
ülemaailmne	doc_278690626915_item	3633139	et	3	main
esimene	doc_278690626915_item	3633138	et	3	main
rahvalaulu	doc_278690626915_item	3633126	et	4	main
need	doc_278690626915_item	3633125	et	3	main
et	doc_278690626915_item	3633151	et	3	main
muutusid	doc_278690626915_item	3633149	et	4	main
praegu	doc_278690626915_item	3633141	et	3	main
sündmus	doc_278690626915_item	3633137	et	3	main
ajaloolise	doc_278690626915_item	3633135	et	4	main
toimub	doc_278690626915_item	3633134	et	3	main
aastal	doc_278690626915_item	3633133	et	3	main
sellel	doc_278690626915_item	3633132	et	4	main
aastat	doc_278690626915_item	3633131	et	3	main
1869	doc_278690626915_item	3633130	et	2	main
tulevad	doc_278690626915_item	3633127	et	4	main
on	doc_278690626915_item	3633102	et	4	main
teine	doc_278690626915_item	3633101	et	3	main
ja	doc_278690626915_item	3633100	et	3	main
on	doc_278690626915_item	3633097	et	4	main
kahest	doc_278690626915_item	3633094	et	4	main
ka	doc_278690626915_item	3633092	et	3	main
puhkasid	doc_278690626915_item	3633089	et	4	main
ja	doc_278690626915_item	3633048	et	3	main
laulurahva	doc_278690626915_item	3633037	et	3	main
eestlastest	doc_278690626915_item	3633036	et	4	main
teeb	doc_278690626915_item	3633035	et	3	main
mis	doc_278690626915_item	3633034	et	4	main
teise	doc_278690626915_item	3633027	et	4	main
ajal	doc_278690626915_item	3633075	et	4	main
vanal	doc_278690626915_item	3633074	et	3	main
asjast	doc_278690626915_item	3633067	et	4	main
ja	doc_278690626917_item	3633355	et	3	main
pärandati	doc_278690626917_item	3633347	et	4	main
laulud	doc_278690626917_item	3633346	et	3	main
koorilaul	doc_278690626917_item	3633345	et	4	main
kirikulaul	doc_278690626917_item	3633343	et	4	main
populaarne	doc_278690626917_item	3633342	et	3	main
väga	doc_278690626917_item	3633341	et	3	main
18	doc_278690626917_item	3633338	et	2	main
tähelepanuväärne	doc_278690626917_item	3633331	et	3	main
küll	doc_278690626917_item	3633326	et	4	main
folkloorist	doc_278690626917_item	3633325	et	4	main
üksi	doc_278690626917_item	3633314	et	4	main
olid	doc_278690626917_item	3633310	et	4	main
essee	doc_278690626917_item	3633273	et	4	main
mis	doc_278690626917_item	3633264	et	4	main
teemal	doc_278690626917_item	3633263	et	3	main
essee	doc_278690626917_item	3633253	et	4	main
üksi	doc_278690626917_item	3633414	et	4	main
perega	doc_278690626917_item	3633413	et	3	main
koos	doc_278690626917_item	3633412	et	4	main
tõeline	doc_278690626917_item	3633404	et	4	main
teise	doc_278690626917_item	3633363	et	4	main
ja	doc_278690626917_item	3633362	et	3	main
seotud	doc_278690626917_item	3633360	et	4	main
lapsi	doc_278690626915_item	3633120	et	4	main
ja	doc_278690626915_item	3633119	et	3	main
laulsid	doc_278690626915_item	3633112	et	4	main
aga	doc_278690626915_item	3633111	et	3	main
ühest	doc_278690626915_item	3633108	et	4	main
rahvalaul	doc_278690626915_item	3633099	et	4	main
arutlev	doc_278690626915_item	3633046	et	4	main
pikkus	doc_278690626915_item	3633039	et	4	main
kirjutamine	doc_278690626915_item	3633030	et	4	main
test	doc_278690626915_item	3633029	et	3	main
eesti	doc_278690626915_item	3633024	et	4	main
lihtsalt	doc_278690626915_item	3633088	et	4	main
töötasid	doc_278690626915_item	3633086	et	4	main
üksi	doc_278690626915_item	3633085	et	4	main
olid	doc_278690626915_item	3633084	et	4	main
kui	doc_278690626915_item	3633083	et	3	main
laulasid	doc_278690626915_item	3633082	et	4	main
eestlased	doc_278690626915_item	3633081	et	3	main
hauani	doc_278690626915_item	3633080	et	3	main
laul	doc_278690626915_item	3633077	et	4	main
ja	doc_278690626915_item	3633072	et	3	main
pillimäng	doc_278690626915_item	3633071	et	3	main
on	doc_278690626915_item	3633069	et	4	main
folkloor	doc_278690626915_item	3633062	et	4	main
eesti	doc_278690626915_item	3633061	et	4	main
näidetega	doc_278690626915_item	3633060	et	3	main
illustreerida	doc_278690626915_item	3633059	et	3	main
soovitatav	doc_278690626915_item	3633058	et	4	main
on	doc_278690626915_item	3633057	et	4	main
väiteid	doc_278690626915_item	3633056	et	4	main
faktidele	doc_278690626915_item	3633055	et	3	main
esitatud	doc_278690626915_item	3633054	et	4	main
lugemistekstis	doc_278690626915_item	3633053	et	3	main
ja	doc_278690626915_item	3633052	et	3	main
loengus	doc_278690626915_item	3633051	et	3	main
tuginema	doc_278690626915_item	3633050	et	3	main
üldistav	doc_278690626915_item	3633049	et	4	main
laulud	doc_278690626917_item	3633357	et	3	main
ümber	doc_278690626917_item	3633353	et	3	main
pärast	doc_278690626917_item	3633351	et	4	main
põlvest	doc_278690626917_item	3633348	et	4	main
oli	doc_278690626917_item	3633340	et	3	main
ajaga	doc_278690626917_item	3633337	et	3	main
väga	doc_278690626917_item	3633330	et	3	main
osa	doc_278690626917_item	3633328	et	4	main
suurem	doc_278690626917_item	3633322	et	4	main
ja	doc_278690626917_item	3633278	et	3	main
olema	doc_278690626917_item	3633275	et	4	main
peab	doc_278690626917_item	3633274	et	4	main
essee	doc_278690626917_item	3633268	et	4	main
laulurahva	doc_278690626917_item	3633267	et	3	main
test	doc_278690626917_item	3633259	et	3	main
massilisem	doc_278690626917_item	3633407	et	4	main
kõige	doc_278690626917_item	3633406	et	4	main
traditsioon	doc_278690626917_item	3633405	et	3	main
tähendab	doc_278690626917_item	3633367	et	3	main
see	doc_278690626917_item	3633366	et	3	main
pidu	doc_278690626919_item	3633676	et	4	main
vanaemaga	doc_278690626919_item	3633668	et	3	main
koos	doc_278690626919_item	3633665	et	4	main
tulevad	doc_278690626919_item	3633664	et	4	main
kuhu	doc_278690626919_item	3633663	et	3	main
praegu	doc_278690626919_item	3633658	et	3	main
laulaga	doc_278690626919_item	3633657	et	4	main
peab	doc_278690626919_item	3633644	et	4	main
ta	doc_278690626919_item	3633643	et	4	main
sellepärast	doc_278690626919_item	3633642	et	3	main
on	doc_278690626919_item	3633624	et	4	main
väga	doc_278690626919_item	3633623	et	3	main
muusika	doc_278690626919_item	3633622	et	4	main
et	doc_278690626919_item	3633621	et	3	main
mõtlen	doc_278690626919_item	3633620	et	3	main
ma	doc_278690626919_item	3633619	et	3	main
kaudna	doc_278690626919_item	3633615	et	4	main
võsa	doc_278690626919_item	3633613	et	4	main
lastekoor	doc_278690626919_item	3633609	et	4	main
muusika	doc_278690626919_item	3633599	et	4	main
jaoks	doc_278690626919_item	3633593	et	4	main
ajal	doc_278690626919_item	3633590	et	4	main
saar	doc_278690626919_item	3633587	et	3	main
populäärne	doc_278690626919_item	3633584	et	4	main
muusika	doc_278690626919_item	3633583	et	4	main
rahvaliku	doc_278690626919_item	3633582	et	3	main
ja	doc_278690626919_item	3633581	et	3	main
ii	doc_278690626919_item	3633575	et	4	main
rahva	doc_278690626919_item	3633571	et	3	main
vene	doc_278690626919_item	3633570	et	4	main
kalluste	doc_278690626919_item	3633559	et	3	main
erinevad	doc_278690626919_item	3633551	et	4	main
palju	doc_278690626919_item	3633535	et	4	main
erinev	doc_278690626919_item	3633532	et	4	main
täesti	doc_278690626919_item	3633531	et	4	main
sajandil	doc_278690626919_item	3633530	et	3	main
19	doc_278690626919_item	3633529	et	2	main
sünnipäev	doc_278690626919_item	3633528	et	3	main
meeldivad	doc_278690626919_item	3633520	et	4	main
laulurahva	doc_278690626917_item	3633440	et	3	main
eestlastest	doc_278690626917_item	3633439	et	4	main
teeb	doc_278690626917_item	3633438	et	3	main
see	doc_278690626917_item	3633437	et	3	main
kõik	doc_278690626917_item	3633436	et	4	main
panatseeja	doc_278690626917_item	3633435	et	4	main
omapärane	doc_278690626917_item	3633434	et	4	main
ravi	doc_278690626917_item	3633433	et	4	main
nagu	doc_278690626917_item	3633432	et	3	main
on	doc_278690626917_item	3633431	et	4	main
laul	doc_278690626917_item	3633430	et	4	main
hea	doc_278690626917_item	3633429	et	4	main
et	doc_278690626917_item	3633428	et	3	main
tagasi	doc_278690626917_item	3633427	et	3	main
aastat	doc_278690626917_item	3633426	et	3	main
palju	doc_278690626917_item	3633425	et	4	main
usuvad	doc_278690626917_item	3633423	et	3	main
nagu	doc_278690626917_item	3633424	et	3	main
eestlased	doc_278690626917_item	3633422	et	3	main
et	doc_278690626917_item	3633421	et	3	main
seepärast	doc_278690626917_item	3633420	et	3	main
just	doc_278690626917_item	3633419	et	3	main
toimub	doc_278690626917_item	3633418	et	3	main
see	doc_278690626917_item	3633417	et	3	main
jne	doc_278690626917_item	3633416	et	4	main
sõpradega	doc_278690626917_item	3633415	et	3	main
trükitati	doc_278690626917_item	3633356	et	3	main
laulutraditsioonid	doc_278690626917_item	3633332	et	3	main
on	doc_278690626917_item	3633329	et	4	main
see	doc_278690626917_item	3633327	et	3	main
osa	doc_278690626917_item	3633323	et	4	main
peol	doc_278690626917_item	3633315	et	4	main
tööl	doc_278690626917_item	3633311	et	3	main
kui	doc_278690626917_item	3633309	et	3	main
nad	doc_278690626917_item	3633307	et	3	main
juhtus	doc_278690626917_item	3633306	et	3	main
mure	doc_278690626917_item	3633305	et	4	main
mingisugune	doc_278690626917_item	3633304	et	3	main
on	doc_278690626917_item	3633303	et	4	main
sul	doc_278690626917_item	3633302	et	3	main
kui	doc_278690626917_item	3633301	et	3	main
aidata	doc_278690626917_item	3633300	et	4	main
võib	doc_278690626917_item	3633299	et	3	main
tants	doc_278690626917_item	3633298	et	3	main
ja	doc_278690626917_item	3633297	et	3	main
et	doc_278690626917_item	3633295	et	3	main
laul	doc_278690626917_item	3633296	et	4	main
räägisid	doc_278690626917_item	3633294	et	4	main
muistlased	doc_278690626917_item	3633293	et	4	main
ammu	doc_278690626917_item	3633292	et	4	main
juba	doc_278690626917_item	3633291	et	3	main
näidetega	doc_278690626917_item	3633290	et	3	main
illustreerida	doc_278690626917_item	3633289	et	3	main
soovitatav	doc_278690626917_item	3633288	et	4	main
on	doc_278690626917_item	3633287	et	4	main
väiteid	doc_278690626917_item	3633286	et	4	main
faktidele	doc_278690626917_item	3633285	et	3	main
esitatud	doc_278690626917_item	3633284	et	4	main
lugemistekstis	doc_278690626917_item	3633283	et	3	main
ja	doc_278690626917_item	3633282	et	3	main
loengus	doc_278690626917_item	3633281	et	3	main
tuginema	doc_278690626917_item	3633280	et	3	main
üldistav	doc_278690626917_item	3633279	et	4	main
ja	doc_278690626917_item	3633316	et	3	main
kui	doc_278690626917_item	3633312	et	3	main
sõna	doc_278690626917_item	3633272	et	4	main
350	doc_278690626917_item	3633271	et	2	main
300	doc_278690626917_item	3633270	et	2	main
essee	doc_278690626917_item	3633262	et	4	main
kirjutage	doc_278690626917_item	3633261	et	3	main
teise	doc_278690626917_item	3633257	et	4	main
keele	doc_278690626917_item	3633255	et	4	main
eesti	doc_278690626917_item	3633254	et	4	main
rahvapidu	doc_278690626917_item	3633408	et	4	main
ärkamisajaga	doc_278690626917_item	3633364	et	3	main
esimese	doc_278690626917_item	3633361	et	3	main
tans	doc_278690626919_item	3633673	et	4	main
vanaisaga	doc_278690626919_item	3633669	et	3	main
või	doc_278690626919_item	3633661	et	4	main
koos	doc_278690626919_item	3633656	et	4	main
või	doc_278690626919_item	3633651	et	4	main
või	doc_278690626919_item	3633640	et	4	main
flöötit	doc_278690626919_item	3633639	et	4	main
edasi	doc_278690626919_item	3633618	et	3	main
populäärne	doc_278690626919_item	3633610	et	4	main
segakoor	doc_278690626919_item	3633608	et	4	main
meeskoor	doc_278690626919_item	3633607	et	4	main
palju	doc_278690626919_item	3633603	et	4	main
praegu	doc_278690626919_item	3633602	et	3	main
onsamblid	doc_278690626919_item	3633597	et	4	main
ja	doc_278690626919_item	3633596	et	3	main
folklor	doc_278690626919_item	3633595	et	4	main
eesti	doc_278690626919_item	3633594	et	4	main
muusika	doc_278690626919_item	3633580	et	4	main
instrumendi	doc_278690626919_item	3633579	et	3	main
oli	doc_278690626919_item	3633578	et	3	main
sajandil	doc_278690626919_item	3633577	et	3	main
ka	doc_278690626919_item	3633567	et	3	main
edasi	doc_278690626919_item	3633563	et	3	main
ja	doc_278690626919_item	3633561	et	3	main
t	doc_278690626919_item	3633558	et	4	main
bajanit	doc_278690626919_item	3633547	et	4	main
edasi	doc_278690626919_item	3633546	et	3	main
nii	doc_278690626919_item	3633545	et	3	main
ja	doc_278690626919_item	3633544	et	3	main
flööt	doc_278690626919_item	3633543	et	3	main
akordion	doc_278690626919_item	3633542	et	3	main
bajan	doc_278690626919_item	3633540	et	4	main
kui	doc_278690626919_item	3633539	et	3	main
instrumenti	doc_278690626919_item	3633538	et	4	main
või	doc_278690626919_item	3633527	et	4	main
pulm	doc_278690626919_item	3633526	et	3	main
kui	doc_278690626919_item	3633525	et	3	main
pidudel	doc_278690626919_item	3633524	et	4	main
laulasid	doc_278690626919_item	3633523	et	4	main
hiljem	doc_278690626919_item	3633522	et	3	main
lastele	doc_278690626919_item	3633521	et	4	main
sellised	doc_278690626919_item	3633518	et	4	main
kui	doc_278690626919_item	3633516	et	3	main
lastele	doc_278690626919_item	3633514	et	4	main
nendes	doc_278690626919_item	3633508	et	4	main
laulud	doc_278690626919_item	3633507	et	3	main
faktidele	doc_278690626919_item	3633474	et	3	main
ja	doc_278690626919_item	3633467	et	3	main
sõitnud	doc_278690626923_item	3633830	et	4	main
koos	doc_278690626923_item	3633819	et	4	main
laulupidu	doc_278690626923_item	3633810	et	4	main
kümne	doc_278690626923_item	3633804	et	4	main
kahe	doc_278690626923_item	3633803	et	3	main
sada	doc_278690626923_item	3633802	et	4	main
tähistada	doc_278690626923_item	3633801	et	3	main
tallinna	doc_278690626923_item	3633797	et	4	main
aastal	doc_278690626923_item	3633792	et	3	main
üheksakümnenda	doc_278690626923_item	3633790	et	4	main
tean	doc_278690626923_item	3633786	et	3	main
laulutraditsiooniseks	doc_278690626923_item	3633778	et	3	main
teksti	doc_278690626923_item	3633777	et	4	main
ma	doc_278690626923_item	3633775	et	3	main
laulupeod	doc_278690626923_item	3633768	et	4	main
õpisin	doc_278690626923_item	3633755	et	4	main
ma	doc_278690626923_item	3633754	et	3	main
on	doc_278690626923_item	3633712	et	4	main
arutlev	doc_278690626917_item	3633276	et	4	main
pikkus	doc_278690626917_item	3633269	et	4	main
kirjutamine	doc_278690626917_item	3633260	et	4	main
keele	doc_278690626917_item	3633258	et	4	main
kui	doc_278690626917_item	3633256	et	3	main
see	doc_278690626917_item	3633402	et	3	main
ja	doc_278690626919_item	3633672	et	3	main
laul	doc_278690626919_item	3633671	et	4	main
perega	doc_278690626919_item	3633666	et	3	main
on	doc_278690626919_item	3633659	et	4	main
elavad	doc_278690626919_item	3633655	et	4	main
nii	doc_278690626919_item	3633617	et	3	main
tullakse	doc_278690626917_item	3633411	et	3	main
seal	doc_278690626917_item	3633410	et	4	main
eestis	doc_278690626917_item	3633409	et	3	main
on	doc_278690626917_item	3633403	et	4	main
nüüd	doc_278690626917_item	3633401	et	4	main
laulupidu	doc_278690626917_item	3633400	et	4	main
ülemaaline	doc_278690626917_item	3633399	et	4	main
esimene	doc_278690626917_item	3633398	et	3	main
toimus	doc_278690626917_item	3633397	et	3	main
tartus	doc_278690626917_item	3633396	et	3	main
aastal	doc_278690626917_item	3633395	et	3	main
1869	doc_278690626917_item	3633394	et	2	main
taasiseseisvumisele	doc_278690626917_item	3633393	et	3	main
sammudest	doc_278690626917_item	3633392	et	3	main
üks	doc_278690626917_item	3633391	et	3	main
oli	doc_278690626917_item	3633390	et	3	main
ajal	doc_278690626917_item	3633389	et	4	main
nõukogude	doc_278690626917_item	3633388	et	3	main
toimus	doc_278690626917_item	3633387	et	3	main
mis	doc_278690626917_item	3633386	et	4	main
revolutsioon	doc_278690626917_item	3633385	et	3	main
lauldav	doc_278690626917_item	3633384	et	4	main
ja	doc_278690626917_item	3633383	et	3	main
iseseisvu	doc_278690626917_item	3633382	et	4	main
oma	doc_278690626917_item	3633381	et	4	main
taastada	doc_278690626917_item	3633380	et	3	main
tahaksid	doc_278690626917_item	3633379	et	4	main
nad	doc_278690626917_item	3633378	et	3	main
laulmisega	doc_278690626917_item	3633377	et	4	main
unikaalsust	doc_278690626917_item	3633376	et	4	main
ja	doc_278690626917_item	3633375	et	3	main
isikpärasust	doc_278690626917_item	3633374	et	4	main
oma	doc_278690626917_item	3633373	et	4	main
teistele	doc_278690626917_item	3633372	et	4	main
näidata	doc_278690626917_item	3633371	et	4	main
tahaksid	doc_278690626917_item	3633370	et	4	main
eestlased	doc_278690626917_item	3633369	et	3	main
et	doc_278690626917_item	3633368	et	3	main
eestis	doc_278690626917_item	3633365	et	3	main
ka	doc_278690626917_item	3633359	et	3	main
on	doc_278690626919_item	3633675	et	4	main
rahvapidu	doc_278690626919_item	3633662	et	4	main
inimesed	doc_278690626919_item	3633654	et	3	main
vesi	doc_278690626919_item	3633652	et	4	main
leib	doc_278690626919_item	3633650	et	3	main
kui	doc_278690626919_item	3633649	et	3	main
jaoks	doc_278690626919_item	3633648	et	4	main
inimene	doc_278690626919_item	3633647	et	3	main
kitarrit	doc_278690626919_item	3633641	et	4	main
derigendid	doc_278690626919_item	3633611	et	4	main
naiskoor	doc_278690626919_item	3633606	et	4	main
koorid	doc_278690626919_item	3633605	et	4	main
muusika	doc_278690626919_item	3633601	et	4	main
torupilli	doc_278690626919_item	3633600	et	4	main
on	doc_278690626919_item	3633591	et	4	main
saamal	doc_278690626919_item	3633589	et	3	main
kui	doc_278690626919_item	3633586	et	3	main
oli	doc_278690626919_item	3633566	et	3	main
nii	doc_278690626919_item	3633562	et	3	main
heliloojad	doc_278690626919_item	3633555	et	3	main
praegu	doc_278690626919_item	3633553	et	3	main
palad	doc_278690626919_item	3633552	et	4	main
palju	doc_278690626919_item	3633550	et	4	main
või	doc_278690626919_item	3633541	et	4	main
väga	doc_278690626919_item	3633534	et	3	main
olid	doc_278690626919_item	3633509	et	4	main
väiteid	doc_278690626919_item	3633475	et	4	main
olla	doc_278690626923_item	3633834	et	3	main
inimesed	doc_278690626923_item	3633817	et	3	main
eestimaa	doc_278690626923_item	3633816	et	4	main
kus	doc_278690626923_item	3633815	et	3	main
laulupidude	doc_278690626923_item	3633808	et	4	main
laupeole	doc_278690626923_item	3633799	et	4	main
kogunesid	doc_278690626923_item	3633794	et	4	main
ma	doc_278690626923_item	3633780	et	3	main
neid	doc_278690626923_item	3633773	et	4	main
vaatasin	doc_278690626923_item	3633772	et	3	main
ei	doc_278690626923_item	3633771	et	4	main
arm	doc_278690626923_item	3633763	et	3	main
isamaa	doc_278690626923_item	3633760	et	4	main
muidugi	doc_278690626923_item	3633753	et	4	main
ja	doc_278690626923_item	3633703	et	3	main
analüüsiv	doc_278690626923_item	3633702	et	4	main
arutlev	doc_278690626923_item	3633701	et	4	main
olema	doc_278690626923_item	3633700	et	4	main
selle	doc_278690626923_item	3633734	et	4	main
kujunenud	doc_278690626924_item	3633968	et	4	main
sõnu	doc_278690626924_item	3633958	et	4	main
tunnet	doc_278690626924_item	3633951	et	3	main
ka	doc_278690626924_item	3633907	et	3	main
minevik	doc_278690626924_item	3633904	et	3	main
kajastub	doc_278690626924_item	3633902	et	3	main
olles	doc_278690626924_item	3633897	et	3	main
tähelepanuväärne	doc_278690626924_item	3633876	et	3	main
soovitatav	doc_278690626924_item	3633871	et	4	main
pikkus	doc_278690626924_item	3633852	et	4	main
essee	doc_278690626924_item	3633851	et	4	main
laulurahva	doc_278690626924_item	3633850	et	3	main
test	doc_278690626924_item	3633842	et	3	main
teama	doc_278690626925_item	3634117	et	4	main
on	doc_278690626925_item	3634105	et	4	main
parem	doc_278690626925_item	3634095	et	4	main
iga	doc_278690626925_item	3634077	et	4	main
lauljaid	doc_278690626925_item	3634070	et	4	main
häid	doc_278690626925_item	3634069	et	3	main
päris	doc_278690626925_item	3634054	et	4	main
meeldivad	doc_278690626925_item	3634037	et	4	main
hästi	doc_278690626925_item	3634034	et	3	main
väiteid	doc_278690626925_item	3634005	et	4	main
faktidele	doc_278690626925_item	3634004	et	3	main
esitatud	doc_278690626925_item	3634003	et	4	main
lugemistekstis	doc_278690626925_item	3634002	et	3	main
peab	doc_278690626925_item	3633993	et	4	main
pikkus	doc_278690626925_item	3633988	et	4	main
eestlastest	doc_278690626925_item	3633985	et	4	main
essee	doc_278690626925_item	3633981	et	4	main
kirjutage	doc_278690626925_item	3633980	et	3	main
keele	doc_278690626925_item	3633977	et	4	main
teise	doc_278690626925_item	3633976	et	4	main
see	doc_278690626919_item	3633674	et	3	main
lapsega	doc_278690626919_item	3633670	et	3	main
sõpraga	doc_278690626919_item	3633667	et	4	main
laulupidu	doc_278690626919_item	3633660	et	4	main
kõik	doc_278690626919_item	3633653	et	4	main
laul	doc_278690626919_item	3633646	et	4	main
развиваться	doc_278690626919_item	3633645	et	2	main
klaverit	doc_278690626919_item	3633638	et	3	main
akordionit	doc_278690626919_item	3633637	et	3	main
mängida	doc_278690626919_item	3633636	et	3	main
peab	doc_278690626919_item	3633635	et	4	main
laps	doc_278690626919_item	3633634	et	4	main
jaoks	doc_278690626919_item	3633633	et	4	main
lastele	doc_278690626919_item	3633632	et	4	main
muusika	doc_278690626919_item	3633631	et	4	main
mängib	doc_278690626919_item	3633630	et	3	main
rool	doc_278690626919_item	3633629	et	4	main
suur	doc_278690626919_item	3633628	et	3	main
jaoks	doc_278690626919_item	3633627	et	4	main
inimene	doc_278690626919_item	3633626	et	3	main
vaja	doc_278690626919_item	3633625	et	4	main
ja	doc_278690626919_item	3633616	et	3	main
l	doc_278690626919_item	3633614	et	4	main
sellised	doc_278690626919_item	3633612	et	4	main
erinevad	doc_278690626919_item	3633604	et	4	main
rook	doc_278690626919_item	3633598	et	4	main
filmimuusika	doc_278690626919_item	3633592	et	4	main
kapp	doc_278690626919_item	3633588	et	3	main
heliloojad	doc_278690626919_item	3633585	et	3	main
pool	doc_278690626919_item	3633576	et	4	main
juba	doc_278690626919_item	3633573	et	3	main
laulud	doc_278690626919_item	3633572	et	3	main
sajandil	doc_278690626919_item	3633565	et	3	main
väga	doc_278690626919_item	3633549	et	3	main
mängisid	doc_278690626919_item	3633548	et	4	main
mutte	doc_278690626919_item	3633537	et	3	main
oli	doc_278690626919_item	3633536	et	3	main
muinasjutt	doc_278690626919_item	3633517	et	3	main
ja	doc_278690626919_item	3633471	et	3	main
loengus	doc_278690626919_item	3633470	et	3	main
tuginema	doc_278690626919_item	3633469	et	3	main
üldistav	doc_278690626919_item	3633468	et	4	main
analüüsiv	doc_278690626919_item	3633466	et	4	main
selle	doc_278690626923_item	3633832	et	4	main
puhkavad	doc_278690626923_item	3633818	et	4	main
traditsiooni	doc_278690626923_item	3633809	et	4	main
et	doc_278690626923_item	3633800	et	3	main
tuhanded	doc_278690626923_item	3633795	et	3	main
juulis	doc_278690626923_item	3633793	et	3	main
neljandal	doc_278690626923_item	3633791	et	3	main
üheksa	doc_278690626923_item	3633789	et	4	main
tuhande	doc_278690626923_item	3633788	et	3	main
et	doc_278690626923_item	3633787	et	3	main
ma	doc_278690626923_item	3633785	et	3	main
nüüd	doc_278690626923_item	3633784	et	4	main
uut	doc_278690626923_item	3633783	et	3	main
seal	doc_278690626923_item	3633779	et	4	main
lugesin	doc_278690626923_item	3633776	et	3	main
täna	doc_278690626923_item	3633774	et	4	main
minu	doc_278690626923_item	3633762	et	3	main
isamaalaul	doc_278690626923_item	3633758	et	4	main
meie	doc_278690626923_item	3633757	et	4	main
koolis	doc_278690626923_item	3633756	et	4	main
tuginema	doc_278690626923_item	3633705	et	3	main
ja	doc_278690626923_item	3633733	et	3	main
venelased	doc_278690626923_item	3633732	et	3	main
ainult	doc_278690626923_item	3633731	et	4	main
rahvuslikeks	doc_278690626924_item	3633969	et	3	main
ülendavat	doc_278690626924_item	3633950	et	4	main
kogedes	doc_278690626924_item	3633948	et	4	main
pealtvaataja	doc_278690626924_item	3633940	et	4	main
kõigepealt	doc_278690626924_item	3633939	et	3	main
maailma	doc_278690626924_item	3633932	et	4	main
üle	doc_278690626924_item	3633930	et	3	main
on	doc_278690626924_item	3633929	et	4	main
kes	doc_278690626924_item	3633928	et	4	main
tuttavaid	doc_278690626924_item	3633927	et	3	main
ja	doc_278690626924_item	3633926	et	3	main
sugulasi	doc_278690626924_item	3633925	et	3	main
sõpru	doc_278690626924_item	3633924	et	3	main
kohata	doc_278690626924_item	3633923	et	4	main
rahvalauluga	doc_278690626924_item	3633908	et	4	main
kiigutades	doc_278690626924_item	3633900	et	3	main
töötades	doc_278690626924_item	3633898	et	3	main
tegevus	doc_278690626924_item	3633887	et	4	main
sotsiaalne	doc_278690626924_item	3633886	et	3	main
ka	doc_278690626924_item	3633885	et	3	main
väljendusvähed	doc_278690626924_item	3633883	et	4	main
esteetiline	doc_278690626924_item	3633880	et	3	main
on	doc_278690626924_item	3633875	et	4	main
näidetega	doc_278690626924_item	3633873	et	3	main
eestlastest	doc_278690626924_item	3633849	et	4	main
teeb	doc_278690626924_item	3633848	et	3	main
teise	doc_278690626924_item	3633840	et	4	main
essee	doc_278690626924_item	3633836	et	4	main
kultuurist	doc_278690626925_item	3634119	et	3	main
teab	doc_278690626925_item	3634113	et	3	main
kui	doc_278690626925_item	3634111	et	3	main
kultuuris	doc_278690626925_item	3634109	et	3	main
muusika	doc_278690626925_item	3634104	et	4	main
kasulik	doc_278690626925_item	3634102	et	3	main
19	doc_278690626919_item	3633574	et	2	main
ja	doc_278690626919_item	3633569	et	3	main
läti	doc_278690626919_item	3633568	et	4	main
19	doc_278690626919_item	3633564	et	2	main
piazolo	doc_278690626919_item	3633560	et	4	main
sommer	doc_278690626919_item	3633557	et	4	main
j	doc_278690626919_item	3633556	et	4	main
populäärne	doc_278690626919_item	3633554	et	4	main
laul	doc_278690626919_item	3633533	et	4	main
palju	doc_278690626919_item	3633512	et	4	main
hääled	doc_278690626919_item	3633511	et	3	main
palju	doc_278690626919_item	3633510	et	4	main
grigooriuse	doc_278690626919_item	3633506	et	4	main
oli	doc_278690626919_item	3633505	et	3	main
see	doc_278690626919_item	3633504	et	3	main
kirikus	doc_278690626919_item	3633503	et	3	main
laulusid	doc_278690626919_item	3633502	et	3	main
ja	doc_278690626919_item	3633501	et	3	main
olid	doc_278690626919_item	3633500	et	4	main
laulud	doc_278690626919_item	3633499	et	3	main
esimesed	doc_278690626919_item	3633498	et	3	main
inimesed	doc_278690626919_item	3633497	et	3	main
tansivad	doc_278690626919_item	3633496	et	4	main
ja	doc_278690626919_item	3633495	et	3	main
laulavad	doc_278690626919_item	3633494	et	4	main
aastat	doc_278690626919_item	3633493	et	3	main
palju	doc_278690626919_item	3633492	et	4	main
juba	doc_278690626919_item	3633491	et	3	main
jaoks	doc_278690626919_item	3633490	et	4	main
inimene	doc_278690626919_item	3633489	et	3	main
vaja	doc_278690626919_item	3633488	et	4	main
väga	doc_278690626919_item	3633487	et	3	main
laul	doc_278690626919_item	3633486	et	4	main
inimene	doc_278690626919_item	3633485	et	3	main
tark	doc_278690626919_item	3633484	et	3	main
väga	doc_278690626919_item	3633483	et	3	main
eestlastest	doc_278690626919_item	3633482	et	4	main
teeb	doc_278690626919_item	3633481	et	3	main
rahvalaulu	doc_278690626919_item	3633480	et	4	main
näidetega	doc_278690626919_item	3633479	et	3	main
illustreerida	doc_278690626919_item	3633478	et	3	main
soovitatav	doc_278690626919_item	3633477	et	4	main
laulud	doc_278690626919_item	3633519	et	3	main
laulud	doc_278690626919_item	3633515	et	3	main
oli	doc_278690626919_item	3633513	et	3	main
on	doc_278690626919_item	3633476	et	4	main
esitatud	doc_278690626919_item	3633473	et	4	main
lugemistekstis	doc_278690626919_item	3633472	et	3	main
arutlev	doc_278690626919_item	3633465	et	4	main
olema	doc_278690626919_item	3633464	et	4	main
peab	doc_278690626919_item	3633463	et	4	main
essee	doc_278690626919_item	3633462	et	4	main
sõna	doc_278690626919_item	3633461	et	4	main
350	doc_278690626919_item	3633460	et	2	main
300	doc_278690626919_item	3633459	et	2	main
pikkus	doc_278690626919_item	3633458	et	4	main
essee	doc_278690626919_item	3633457	et	4	main
laulurahva	doc_278690626919_item	3633456	et	3	main
eestlastest	doc_278690626919_item	3633455	et	4	main
teeb	doc_278690626919_item	3633454	et	3	main
mis	doc_278690626919_item	3633453	et	4	main
teemal	doc_278690626919_item	3633452	et	3	main
essee	doc_278690626919_item	3633451	et	4	main
kirjutage	doc_278690626919_item	3633450	et	3	main
kirjutamine	doc_278690626919_item	3633449	et	4	main
test	doc_278690626919_item	3633448	et	3	main
keele	doc_278690626919_item	3633447	et	4	main
teise	doc_278690626919_item	3633446	et	4	main
kui	doc_278690626919_item	3633445	et	3	main
keele	doc_278690626919_item	3633444	et	4	main
eesti	doc_278690626919_item	3633443	et	4	main
essee	doc_278690626919_item	3633442	et	4	main
et	doc_278690626923_item	3633831	et	3	main
maailma	doc_278690626923_item	3633828	et	4	main
üle	doc_278690626923_item	3633826	et	3	main
on	doc_278690626923_item	3633825	et	4	main
perega	doc_278690626923_item	3633821	et	3	main
oma	doc_278690626923_item	3633820	et	4	main
rahvapidu	doc_278690626923_item	3633814	et	4	main
suur	doc_278690626923_item	3633813	et	3	main
väga	doc_278690626923_item	3633812	et	3	main
kestnud	doc_278690626923_item	3633807	et	4	main
aastat	doc_278690626923_item	3633806	et	3	main
viiendat	doc_278690626923_item	3633805	et	3	main
lauluväljakule	doc_278690626923_item	3633798	et	3	main
palju	doc_278690626923_item	3633782	et	4	main
mina	doc_278690626923_item	3633770	et	4	main
aga	doc_278690626923_item	3633769	et	3	main
on	doc_278690626923_item	3633761	et	4	main
mu	doc_278690626923_item	3633759	et	3	main
peos	doc_278690626923_item	3633833	et	4	main
kokku	doc_278690626923_item	3633829	et	3	main
kogu	doc_278690626923_item	3633827	et	4	main
kus	doc_278690626923_item	3633824	et	3	main
sõpradega	doc_278690626923_item	3633823	et	3	main
ja	doc_278690626923_item	3633822	et	3	main
on	doc_278690626923_item	3633811	et	4	main
lauljad	doc_278690626923_item	3633796	et	4	main
teadsin	doc_278690626923_item	3633781	et	3	main
toimuvad	doc_278690626923_item	3633767	et	4	main
kus	doc_278690626923_item	3633766	et	3	main
tean	doc_278690626923_item	3633765	et	3	main
ja	doc_278690626923_item	3633764	et	3	main
elavad	doc_278690626923_item	3633730	et	4	main
kus	doc_278690626923_item	3633729	et	3	main
narvas	doc_278690626923_item	3633728	et	4	main
elasin	doc_278690626923_item	3633727	et	3	main
ma	doc_278690626923_item	3633726	et	3	main
varem	doc_278690626923_item	3633725	et	4	main
valgevenemaal	doc_278690626923_item	3633724	et	4	main
sündisid	doc_278690626923_item	3633723	et	4	main
vanemad	doc_278690626923_item	3633722	et	4	main
minu	doc_278690626923_item	3633721	et	3	main
aga	doc_278690626923_item	3633720	et	3	main
isamaa	doc_278690626923_item	3633719	et	4	main
minu	doc_278690626923_item	3633718	et	3	main
on	doc_278690626923_item	3633717	et	4	main
eesti	doc_278690626923_item	3633716	et	4	main
näidetega	doc_278690626923_item	3633715	et	3	main
illustreerida	doc_278690626923_item	3633714	et	3	main
soovitatav	doc_278690626923_item	3633713	et	4	main
esitatud	doc_278690626923_item	3633709	et	4	main
lugemistekstis	doc_278690626923_item	3633708	et	3	main
üldistav	doc_278690626923_item	3633704	et	4	main
tean	doc_278690626923_item	3633737	et	3	main
ma	doc_278690626923_item	3633736	et	3	main
eest	doc_278690626923_item	3633735	et	4	main
viisi	doc_278690626924_item	3633961	et	4	main
sama	doc_278690626924_item	3633960	et	4	main
ja	doc_278690626924_item	3633959	et	3	main
samu	doc_278690626924_item	3633957	et	3	main
üheskoos	doc_278690626924_item	3633956	et	3	main
teistega	doc_278690626924_item	3633955	et	4	main
tuhandete	doc_278690626924_item	3633954	et	3	main
sõitnud	doc_278690626924_item	3633933	et	4	main
pidu	doc_278690626924_item	3633917	et	4	main
suur	doc_278690626924_item	3633916	et	3	main
on	doc_278690626924_item	3633915	et	4	main
see	doc_278690626924_item	3633914	et	3	main
uurimine	doc_278690626924_item	3633913	et	4	main
lauldi	doc_278690626924_item	3633895	et	3	main
hällist	doc_278690626924_item	3633893	et	4	main
ja	doc_278690626924_item	3633881	et	3	main
mis	doc_278690626924_item	3633847	et	4	main
essee	doc_278690626924_item	3633845	et	4	main
kirjutage	doc_278690626924_item	3633844	et	3	main
kirjutamine	doc_278690626924_item	3633843	et	4	main
peab	doc_278690626925_item	3634116	et	4	main
väga	doc_278690626925_item	3634106	et	3	main
teada	doc_278690626925_item	3634103	et	3	main
on	doc_278690626925_item	3634100	et	4	main
minu	doc_278690626925_item	3634097	et	3	main
on	doc_278690626925_item	3634089	et	4	main
kuhu	doc_278690626925_item	3634081	et	3	main
väiteid	doc_278690626923_item	3633711	et	4	main
faktidele	doc_278690626923_item	3633710	et	3	main
ja	doc_278690626923_item	3633707	et	3	main
loengus	doc_278690626923_item	3633706	et	3	main
peab	doc_278690626923_item	3633699	et	4	main
essee	doc_278690626923_item	3633698	et	4	main
sõna	doc_278690626923_item	3633697	et	4	main
350	doc_278690626923_item	3633696	et	2	main
300	doc_278690626923_item	3633695	et	2	main
pikkus	doc_278690626923_item	3633694	et	4	main
essee	doc_278690626923_item	3633693	et	4	main
laulurahva	doc_278690626923_item	3633692	et	3	main
eestlastest	doc_278690626923_item	3633691	et	4	main
teeb	doc_278690626923_item	3633690	et	3	main
mis	doc_278690626923_item	3633689	et	4	main
teemal	doc_278690626923_item	3633688	et	3	main
essee	doc_278690626923_item	3633687	et	4	main
kirjutage	doc_278690626923_item	3633686	et	3	main
kirjutamine	doc_278690626923_item	3633685	et	4	main
test	doc_278690626923_item	3633684	et	3	main
keele	doc_278690626923_item	3633683	et	4	main
teise	doc_278690626923_item	3633682	et	4	main
kui	doc_278690626923_item	3633681	et	3	main
keele	doc_278690626923_item	3633680	et	4	main
eesti	doc_278690626923_item	3633679	et	4	main
essee	doc_278690626923_item	3633678	et	4	main
laulutraditsioonid	doc_278690626923_item	3633752	et	3	main
ja	doc_278690626923_item	3633751	et	3	main
kultuuri-	doc_278690626923_item	3633750	et	4	main
vanad	doc_278690626923_item	3633749	et	3	main
väga	doc_278690626923_item	3633748	et	3	main
on	doc_278690626923_item	3633747	et	4	main
eestlasel	doc_278690626923_item	3633746	et	3	main
et	doc_278690626923_item	3633745	et	3	main
rääkisid	doc_278690626923_item	3633744	et	4	main
mulle	doc_278690626923_item	3633743	et	4	main
koolis	doc_278690626923_item	3633742	et	4	main
isaalt	doc_278690626923_item	3633741	et	3	main
oma	doc_278690626923_item	3633740	et	4	main
vähe	doc_278690626923_item	3633739	et	3	main
väga	doc_278690626923_item	3633738	et	3	main
ajal	doc_278690626924_item	3633967	et	4	main
mis	doc_278690626924_item	3633952	et	4	main
elamust	doc_278690626924_item	3633941	et	4	main
publikule	doc_278690626924_item	3633938	et	3	main
pakub	doc_278690626924_item	3633937	et	3	main
laulupidu	doc_278690626924_item	3633936	et	4	main
kuigi	doc_278690626924_item	3633935	et	3	main
ja	doc_278690626924_item	3633934	et	3	main
kogu	doc_278690626924_item	3633931	et	4	main
koos	doc_278690626924_item	3633920	et	4	main
tullakse	doc_278690626924_item	3633919	et	3	main
kuhu	doc_278690626924_item	3633918	et	3	main
on	doc_278690626924_item	3633906	et	4	main
rahvalauludes	doc_278690626924_item	3633901	et	3	main
üksi	doc_278690626924_item	3633896	et	4	main
hauani	doc_278690626924_item	3633894	et	3	main
eestlast	doc_278690626924_item	3633892	et	4	main
laul	doc_278690626924_item	3633891	et	4	main
saatis	doc_278690626924_item	3633890	et	3	main
ajal	doc_278690626924_item	3633889	et	4	main
vanal	doc_278690626924_item	3633888	et	3	main
kultuurinähtus	doc_278690626924_item	3633877	et	4	main
laulmine	doc_278690626924_item	3633874	et	4	main
illustreerida	doc_278690626924_item	3633872	et	3	main
on	doc_278690626924_item	3633870	et	4	main
faktidele	doc_278690626924_item	3633868	et	3	main
väiteid	doc_278690626924_item	3633869	et	4	main
esitatud	doc_278690626924_item	3633867	et	4	main
lugemistekstis	doc_278690626924_item	3633866	et	3	main
ja	doc_278690626924_item	3633865	et	3	main
loengus	doc_278690626924_item	3633864	et	3	main
tuginema	doc_278690626924_item	3633863	et	3	main
üldistav	doc_278690626924_item	3633862	et	4	main
ja	doc_278690626924_item	3633861	et	3	main
analüüsiv	doc_278690626924_item	3633860	et	4	main
arutlev	doc_278690626924_item	3633859	et	4	main
olema	doc_278690626924_item	3633858	et	4	main
peab	doc_278690626924_item	3633857	et	4	main
essee	doc_278690626924_item	3633856	et	4	main
sõna	doc_278690626924_item	3633855	et	4	main
350	doc_278690626924_item	3633854	et	2	main
300	doc_278690626924_item	3633853	et	2	main
sümboliteks	doc_278690626924_item	3633970	et	3	main
läbi	doc_278690626924_item	3633966	et	4	main
on	doc_278690626924_item	3633965	et	4	main
laulud	doc_278690626924_item	3633964	et	3	main
need	doc_278690626924_item	3633963	et	3	main
lauldes	doc_278690626924_item	3633962	et	3	main
tekib	doc_278690626924_item	3633953	et	3	main
seda	doc_278690626924_item	3633949	et	3	main
laulda	doc_278690626924_item	3633947	et	4	main
kaasa	doc_278690626924_item	3633946	et	4	main
võimalust	doc_278690626924_item	3633945	et	3	main
tegelikult	doc_278690626924_item	3633944	et	4	main
kuulajaskond	doc_278690626924_item	3633943	et	3	main
ootab	doc_278690626924_item	3633942	et	3	main
lootuses	doc_278690626924_item	3633922	et	4	main
perega	doc_278690626924_item	3633921	et	3	main
ajaloo	doc_278690626924_item	3633912	et	4	main
nagu	doc_278690626924_item	3633911	et	3	main
pisut	doc_278690626924_item	3633910	et	3	main
tutvumine	doc_278690626924_item	3633909	et	4	main
mistõttu	doc_278690626924_item	3633905	et	3	main
rahva	doc_278690626924_item	3633903	et	3	main
last	doc_278690626924_item	3633899	et	4	main
aga	doc_278690626924_item	3633884	et	3	main
emotsionaalne	doc_278690626924_item	3633882	et	3	main
on	doc_278690626924_item	3633879	et	4	main
see	doc_278690626924_item	3633878	et	3	main
keele	doc_278690626924_item	3633841	et	4	main
keele	doc_278690626924_item	3633838	et	4	main
inimene	doc_278690626925_item	3634115	et	3	main
iga	doc_278690626925_item	3634114	et	4	main
osa	doc_278690626925_item	3634108	et	4	main
väga	doc_278690626925_item	3634101	et	3	main
see	doc_278690626925_item	3634099	et	3	main
sellepärast	doc_278690626925_item	3634096	et	3	main
muusikaga	doc_278690626925_item	3634094	et	3	main
eesti	doc_278690626925_item	3634093	et	4	main
võimalus	doc_278690626925_item	3634090	et	3	main
mul	doc_278690626925_item	3634088	et	3	main
tulevikus	doc_278690626925_item	3634087	et	4	main
kui	doc_278690626925_item	3634086	et	3	main
sõpradega	doc_278690626925_item	3634085	et	3	main
laulupidu	doc_278690626925_item	3634076	et	4	main
palju	doc_278690626925_item	3634068	et	4	main
heliloojad	doc_278690626925_item	3634067	et	3	main
on	doc_278690626925_item	3634064	et	4	main
oli	doc_278690626925_item	3634062	et	3	main
kultuuris	doc_278690626925_item	3634060	et	3	main
on	doc_278690626925_item	3634058	et	4	main
inimene	doc_278690626925_item	3634057	et	3	main
kui	doc_278690626925_item	3634056	et	3	main
huvitav	doc_278690626925_item	3634055	et	4	main
eesti	doc_278690626925_item	3634046	et	4	main
ja	doc_278690626925_item	3634044	et	3	main
nantsida	doc_278690626925_item	3634040	et	4	main
kõik	doc_278690626925_item	3634030	et	4	main
on	doc_278690626925_item	3634011	et	4	main
see	doc_278690626925_item	3634010	et	3	main
näidetega	doc_278690626925_item	3634009	et	3	main
illustreerida	doc_278690626925_item	3634008	et	3	main
ja	doc_278690626925_item	3634001	et	3	main
essee	doc_278690626925_item	3633992	et	4	main
mis	doc_278690626925_item	3633983	et	4	main
keele	doc_278690626925_item	3633974	et	4	main
teemal	doc_278690626924_item	3633846	et	3	main
kui	doc_278690626924_item	3633839	et	3	main
eesti	doc_278690626924_item	3633837	et	4	main
palju	doc_278690626925_item	3634118	et	4	main
igaüks	doc_278690626925_item	3634112	et	3	main
ja	doc_278690626925_item	3634110	et	3	main
suur	doc_278690626925_item	3634107	et	3	main
tutvun	doc_278690626925_item	3634092	et	3	main
ma	doc_278690626925_item	3634091	et	3	main
koos	doc_278690626925_item	3634083	et	4	main
on	doc_278690626925_item	3634079	et	4	main
laulupidu	doc_278690626925_item	3634078	et	4	main
teema	doc_278690626925_item	3634074	et	4	main
palju	doc_278690626925_item	3634065	et	4	main
on	doc_278690626925_item	3634053	et	4	main
see	doc_278690626925_item	3634052	et	3	main
et	doc_278690626925_item	3634051	et	3	main
arvan	doc_278690626925_item	3634050	et	3	main
ma	doc_278690626925_item	3634049	et	3	main
laulupeodest	doc_278690626925_item	3634047	et	3	main
palju	doc_278690626925_item	3634041	et	4	main
laulada	doc_278690626925_item	3634038	et	4	main
ma	doc_278690626925_item	3634032	et	3	main
laulupeodel	doc_278690626925_item	3634029	et	3	main
kuula	doc_278690626925_item	3634022	et	4	main
ei	doc_278690626925_item	3634021	et	4	main
ma	doc_278690626925_item	3634020	et	3	main
laulutraditsioonidest	doc_278690626925_item	3634019	et	3	main
eestist	doc_278690626925_item	3634018	et	3	main
palju	doc_278690626925_item	3634017	et	4	main
tea	doc_278690626925_item	3634016	et	4	main
ei	doc_278690626925_item	3634015	et	4	main
me	doc_278690626925_item	3634014	et	4	main
arvates	doc_278690626925_item	3634098	et	4	main
perega	doc_278690626925_item	3634084	et	3	main
tullakse	doc_278690626925_item	3634082	et	3	main
rahvapidu	doc_278690626925_item	3634080	et	4	main
on	doc_278690626925_item	3634075	et	4	main
suur	doc_278690626925_item	3634073	et	3	main
väga	doc_278690626925_item	3634072	et	3	main
veel	doc_278690626925_item	3634071	et	4	main
selles	doc_278690626925_item	3634059	et	4	main
vaatisin	doc_278690626925_item	3634045	et	4	main
kulasin	doc_278690626925_item	3634043	et	4	main
et	doc_278690626925_item	3634035	et	3	main
tean	doc_278690626925_item	3634033	et	3	main
kahju	doc_278690626925_item	3634012	et	4	main
loengus	doc_278690626925_item	3634000	et	3	main
ja	doc_278690626925_item	3633997	et	3	main
analüüsiv	doc_278690626925_item	3633996	et	4	main
sõna	doc_278690626925_item	3633991	et	4	main
350	doc_278690626925_item	3633990	et	2	main
teeb	doc_278690626925_item	3633984	et	3	main
teemal	doc_278690626925_item	3633982	et	3	main
eesti	doc_278690626925_item	3633973	et	4	main
traditsioon	doc_278690626926_item	3634260	et	3	main
on	doc_278690626926_item	3634256	et	4	main
isegi	doc_278690626926_item	3634246	et	4	main
laulajad	doc_278690626926_item	3634245	et	4	main
jäävad	doc_278690626926_item	3634242	et	4	main
eestlastes	doc_278690626926_item	3634239	et	4	main
kanel	doc_278690626926_item	3634206	et	4	main
muusika	doc_278690626926_item	3634203	et	4	main
oma	doc_278690626926_item	3634198	et	4	main
laulma	doc_278690626926_item	3634192	et	3	main
armasid	doc_278690626926_item	3634191	et	4	main
eestlased	doc_278690626926_item	3634190	et	3	main
laulutraditsioon	doc_278690626926_item	3634189	et	3	main
kõik	doc_278690626926_item	3634176	et	4	main
asi	doc_278690626926_item	3634173	et	4	main
laulurahva	doc_278690626926_item	3634170	et	3	main
on	doc_278690626926_item	3634164	et	4	main
see	doc_278690626926_item	3634163	et	3	main
näidetega	doc_278690626926_item	3634158	et	3	main
esitatud	doc_278690626926_item	3634152	et	4	main
lugemistekstis	doc_278690626926_item	3634151	et	3	main
ja	doc_278690626926_item	3634150	et	3	main
loengus	doc_278690626926_item	3634149	et	3	main
tuginema	doc_278690626926_item	3634148	et	3	main
üldistav	doc_278690626926_item	3634147	et	4	main
ja	doc_278690626926_item	3634146	et	3	main
essee	doc_278690626926_item	3634141	et	4	main
laulurahva	doc_278690626926_item	3634135	et	3	main
eestlastest	doc_278690626926_item	3634134	et	4	main
teeb	doc_278690626926_item	3634133	et	3	main
teise	doc_278690626926_item	3634125	et	4	main
kui	doc_278690626926_item	3634124	et	3	main
olid	doc_278690626927_item	3634413	et	4	main
laulupeod	doc_278690626927_item	3634412	et	4	main
tunnevad	doc_278690626927_item	3634406	et	3	main
tahtis	doc_278690626927_item	3634401	et	3	main
põlvest	doc_278690626927_item	3634391	et	4	main
tagasi	doc_278690626927_item	3634390	et	3	main
aega	doc_278690626927_item	3634389	et	4	main
palju	doc_278690626927_item	3634388	et	4	main
seda	doc_278690626927_item	3634384	et	3	main
alati	doc_278690626927_item	3634371	et	4	main
polnud	doc_278690626927_item	3634365	et	3	main
neid	doc_278690626927_item	3634360	et	4	main
aitas	doc_278690626927_item	3634359	et	3	main
laul	doc_278690626927_item	3634358	et	4	main
et	doc_278690626927_item	3634357	et	3	main
olla	doc_278690626927_item	3634356	et	3	main
võib	doc_278690626927_item	3634355	et	3	main
häid	doc_278690626925_item	3634066	et	3	main
ja	doc_278690626925_item	3634063	et	3	main
eestis	doc_278690626925_item	3634061	et	3	main
aga	doc_278690626925_item	3634048	et	3	main
ma	doc_278690626925_item	3634042	et	3	main
ja	doc_278690626925_item	3634039	et	3	main
eestlased	doc_278690626925_item	3634036	et	3	main
mis	doc_278690626925_item	3634031	et	4	main
aga	doc_278690626925_item	3634013	et	3	main
soovitatav	doc_278690626925_item	3634007	et	4	main
on	doc_278690626925_item	3634006	et	4	main
tuginema	doc_278690626925_item	3633999	et	3	main
üldistav	doc_278690626925_item	3633998	et	4	main
arutlev	doc_278690626925_item	3633995	et	4	main
essee	doc_278690626925_item	3633987	et	4	main
test	doc_278690626925_item	3633978	et	3	main
oli	doc_278690626925_item	3634028	et	3	main
meie	doc_278690626926_item	3634264	et	4	main
elab	doc_278690626926_item	3634262	et	3	main
mitu	doc_278690626926_item	3634249	et	4	main
eurovisioonil	doc_278690626926_item	3634248	et	3	main
laulurahvaks	doc_278690626926_item	3634243	et	3	main
sümboliks	doc_278690626926_item	3634232	et	4	main
identiteeditunnete	doc_278690626926_item	3634231	et	3	main
laulupidu	doc_278690626926_item	3634227	et	4	main
eesti	doc_278690626926_item	3634216	et	4	main
eestisse	doc_278690626926_item	3634211	et	4	main
see	doc_278690626926_item	3634187	et	3	main
eestlastel	doc_278690626926_item	3634186	et	4	main
rahvatraditsioonid	doc_278690626926_item	3634185	et	3	main
oma	doc_278690626926_item	3634184	et	4	main
mis	doc_278690626926_item	3634174	et	4	main
teeb	doc_278690626926_item	3634171	et	3	main
mis	doc_278690626926_item	3634159	et	4	main
illustreerida	doc_278690626926_item	3634157	et	3	main
arutlev	doc_278690626926_item	3634144	et	4	main
olema	doc_278690626926_item	3634143	et	4	main
essee	doc_278690626926_item	3634130	et	4	main
kirjutage	doc_278690626926_item	3634129	et	3	main
kirjutamine	doc_278690626926_item	3634128	et	4	main
väga	doc_278690626927_item	3634414	et	3	main
palju	doc_278690626927_item	3634405	et	4	main
on	doc_278690626927_item	3634404	et	4	main
kes	doc_278690626927_item	3634400	et	4	main
tulid	doc_278690626927_item	3634398	et	4	main
üldlaulupeod	doc_278690626927_item	3634396	et	4	main
organiseeritakse	doc_278690626927_item	3634395	et	3	main
hiljem	doc_278690626927_item	3634394	et	3	main
suuliselt	doc_278690626927_item	3634393	et	4	main
neid	doc_278690626927_item	3634387	et	4	main
nii	doc_278690626927_item	3634382	et	3	main
rahva	doc_278690626927_item	3634380	et	3	main
on	doc_278690626927_item	3634370	et	4	main
lootust	doc_278690626927_item	3634364	et	4	main
raskel	doc_278690626927_item	3634361	et	3	main
meie	doc_278690626927_item	3634320	et	4	main
tulevad	doc_278690626927_item	3634318	et	4	main
lauludega	doc_278690626927_item	3634317	et	3	main
on	doc_278690626927_item	3634316	et	4	main
inimesel	doc_278690626927_item	3634315	et	3	main
väiteid	doc_278690626927_item	3634300	et	4	main
faktidele	doc_278690626927_item	3634299	et	3	main
pidu	doc_278690626928_item	3634557	et	4	main
päev	doc_278690626928_item	3634544	et	3	main
oli	doc_278690626928_item	3634542	et	3	main
traditsiooni	doc_278690626928_item	3634540	et	4	main
laulupeole	doc_278690626928_item	3634531	et	4	main
iga	doc_278690626928_item	3634520	et	4	main
laul	doc_278690626928_item	3634519	et	4	main
isamaalaul	doc_278690626928_item	3634508	et	4	main
ernesaksi	doc_278690626928_item	3634507	et	4	main
situatsioon	doc_278690626928_item	3634501	et	3	main
on	doc_278690626928_item	3634499	et	4	main
millal	doc_278690626928_item	3634497	et	3	main
ja	doc_278690626928_item	3634496	et	3	main
olles	doc_278690626928_item	3634492	et	3	main
laulma	doc_278690626928_item	3634490	et	3	main
laulurahvata	doc_278690626928_item	3634489	et	3	main
ilma	doc_278690626928_item	3634488	et	4	main
elada	doc_278690626928_item	3634487	et	3	main
essee	doc_278690626928_item	3634437	et	4	main
olema	doc_278690626925_item	3633994	et	4	main
300	doc_278690626925_item	3633989	et	2	main
laulurahva	doc_278690626925_item	3633986	et	3	main
kirjutamine	doc_278690626925_item	3633979	et	4	main
essee	doc_278690626925_item	3633972	et	4	main
ma	doc_278690626925_item	3634026	et	3	main
ja	doc_278690626925_item	3634025	et	3	main
muusikat	doc_278690626925_item	3634024	et	3	main
eesti	doc_278690626925_item	3634023	et	4	main
ajal	doc_278690626926_item	3634265	et	4	main
mis	doc_278690626926_item	3634261	et	4	main
eestlased	doc_278690626926_item	3634241	et	3	main
tänapäeval	doc_278690626926_item	3634240	et	3	main
väga	doc_278690626926_item	3634237	et	3	main
rahvalaul	doc_278690626926_item	3634235	et	4	main
ajal	doc_278690626926_item	3634234	et	4	main
sai	doc_278690626926_item	3634229	et	4	main
sajandil	doc_278690626926_item	3634226	et	3	main
traditsioonid	doc_278690626926_item	3634215	et	3	main
euroopa	doc_278690626926_item	3634214	et	4	main
laulmine	doc_278690626926_item	3634209	et	4	main
keskajal	doc_278690626926_item	3634207	et	3	main
näiteks	doc_278690626926_item	3634205	et	4	main
instrumentid	doc_278690626926_item	3634204	et	4	main
nendel	doc_278690626926_item	3634196	et	4	main
ajal	doc_278690626926_item	3634195	et	4	main
veel	doc_278690626926_item	3634193	et	4	main
on	doc_278690626926_item	3634183	et	4	main
rahvadel	doc_278690626926_item	3634182	et	4	main
mõjutab	doc_278690626926_item	3634175	et	3	main
seesama	doc_278690626926_item	3634172	et	3	main
eestlastest	doc_278690626926_item	3634169	et	4	main
olla	doc_278690626926_item	3634168	et	3	main
võib	doc_278690626926_item	3634167	et	3	main
küsimus	doc_278690626926_item	3634166	et	4	main
kui	doc_278690626925_item	3633975	et	3	main
ei	doc_278690626925_item	3634027	et	4	main
vana	doc_278690626926_item	3634258	et	4	main
võtsid	doc_278690626926_item	3634247	et	4	main
sellel	doc_278690626926_item	3634233	et	4	main
eestis	doc_278690626926_item	3634228	et	3	main
tuli	doc_278690626926_item	3634210	et	4	main
oma	doc_278690626926_item	3634202	et	4	main
olid	doc_278690626926_item	3634197	et	4	main
on	doc_278690626926_item	3634188	et	4	main
kõikidel	doc_278690626926_item	3634181	et	4	main
rahvatraditsioon	doc_278690626926_item	3634180	et	3	main
pooled	doc_278690626926_item	3634179	et	3	main
ellu	doc_278690626926_item	3634178	et	4	main
meie	doc_278690626926_item	3634177	et	4	main
raske	doc_278690626926_item	3634165	et	4	main
laulurahva	doc_278690626926_item	3634162	et	3	main
teeb	doc_278690626926_item	3634160	et	3	main
soovitatav	doc_278690626926_item	3634156	et	4	main
väiteid	doc_278690626926_item	3634154	et	4	main
300	doc_278690626926_item	3634138	et	2	main
mis	doc_278690626926_item	3634132	et	4	main
teemal	doc_278690626926_item	3634131	et	3	main
ka	doc_278690626926_item	3634263	et	3	main
eesti	doc_278690626926_item	3634259	et	4	main
väga	doc_278690626926_item	3634257	et	3	main
laulamine	doc_278690626926_item	3634255	et	4	main
näeme	doc_278690626926_item	3634254	et	3	main
me	doc_278690626926_item	3634253	et	4	main
nagu	doc_278690626926_item	3634252	et	3	main
tagasi	doc_278690626926_item	3634251	et	3	main
aastat	doc_278690626926_item	3634250	et	3	main
eesti	doc_278690626926_item	3634244	et	4	main
populaarne	doc_278690626926_item	3634238	et	3	main
oli	doc_278690626926_item	3634236	et	3	main
rahvusliku	doc_278690626926_item	3634230	et	3	main
xix	doc_278690626926_item	3634225	et	4	main
rahvas	doc_278690626926_item	3634224	et	4	main
eesti	doc_278690626926_item	3634223	et	4	main
populaarseks	doc_278690626926_item	3634222	et	4	main
ka	doc_278690626926_item	3634221	et	3	main
sai	doc_278690626926_item	3634220	et	4	main
traditsioonid	doc_278690626926_item	3634219	et	3	main
need	doc_278690626926_item	3634218	et	3	main
pani	doc_278690626926_item	3634213	et	4	main
laulmisele	doc_278690626926_item	3634217	et	4	main
see	doc_278690626926_item	3634212	et	3	main
kiriku	doc_278690626926_item	3634208	et	3	main
tantsid	doc_278690626926_item	3634201	et	4	main
oma	doc_278690626926_item	3634200	et	4	main
koorid	doc_278690626926_item	3634199	et	4	main
vanal	doc_278690626926_item	3634194	et	3	main
on	doc_278690626926_item	3634155	et	4	main
analüüsiv	doc_278690626926_item	3634145	et	4	main
sõna	doc_278690626926_item	3634140	et	4	main
350	doc_278690626926_item	3634139	et	2	main
olulised	doc_278690626927_item	3634415	et	4	main
end	doc_278690626927_item	3634408	et	4	main
nad	doc_278690626927_item	3634407	et	3	main
kõik	doc_278690626927_item	3634399	et	4	main
millele	doc_278690626927_item	3634397	et	3	main
et	doc_278690626927_item	3634383	et	3	main
osa	doc_278690626927_item	3634379	et	4	main
on	doc_278690626927_item	3634377	et	4	main
laul	doc_278690626927_item	3634376	et	4	main
üksi	doc_278690626927_item	3634375	et	4	main
kui	doc_278690626927_item	3634374	et	3	main
olla	doc_278690626927_item	3634373	et	3	main
inimesi	doc_278690626927_item	3634368	et	4	main
ühendab	doc_278690626927_item	3634367	et	3	main
kui	doc_278690626927_item	3634363	et	3	main
ajal	doc_278690626927_item	3634362	et	4	main
tähistasid	doc_278690626928_item	3634555	et	4	main
ja	doc_278690626928_item	3634554	et	3	main
olid	doc_278690626928_item	3634553	et	4	main
kõik	doc_278690626928_item	3634552	et	4	main
vanaisad	doc_278690626928_item	3634551	et	3	main
ja	doc_278690626928_item	3634550	et	3	main
vanaemad	doc_278690626928_item	3634549	et	3	main
mehed	doc_278690626928_item	3634548	et	3	main
lapsed	doc_278690626928_item	3634547	et	3	main
laulupidude	doc_278690626928_item	3634539	et	4	main
tähistati	doc_278690626928_item	3634535	et	4	main
aastal	doc_278690626928_item	3634534	et	3	main
tol	doc_278690626928_item	3634533	et	3	main
1994	doc_278690626928_item	3634523	et	2	main
kõige	doc_278690626928_item	3634517	et	4	main
gustavi	doc_278690626928_item	3634506	et	4	main
väga	doc_278690626928_item	3634504	et	3	main
saab	doc_278690626928_item	3634486	et	3	main
eestlaste	doc_278690626928_item	3634475	et	4	main
osa	doc_278690626928_item	3634474	et	4	main
eesti	doc_278690626928_item	3634423	et	4	main
teeb	doc_278690626929_item	3634704	et	3	main
koguneb	doc_278690626929_item	3634701	et	3	main
laulda	doc_278690626929_item	3634695	et	4	main
on	doc_278690626929_item	3634684	et	4	main
üks	doc_278690626929_item	3634674	et	3	main
ise	doc_278690626929_item	3634660	et	4	main
võimalus	doc_278690626929_item	3634659	et	3	main
on	doc_278690626929_item	3634658	et	4	main
aastat	doc_278690626929_item	3634646	et	3	main
üle	doc_278690626929_item	3634644	et	3	main
toimub	doc_278690626929_item	3634642	et	3	main
aastal	doc_278690626929_item	3634640	et	3	main
suurim	doc_278690626929_item	3634635	et	3	main
ja	doc_278690626929_item	3634627	et	3	main
enam	doc_278690626929_item	3634619	et	4	main
tekkis	doc_278690626929_item	3634618	et	3	main
laulurahva	doc_278690626929_item	3634573	et	3	main
teeb	doc_278690626929_item	3634571	et	3	main
keele	doc_278690626929_item	3634564	et	4	main
kõik	doc_278690626929_item	3634604	et	4	main
mis	doc_278690626929_item	3634597	et	4	main
soovitatav	doc_278690626929_item	3634594	et	4	main
tuginema	doc_278690626929_item	3634586	et	3	main
eestlastest	doc_278690626926_item	3634161	et	4	main
faktidele	doc_278690626926_item	3634153	et	3	main
peab	doc_278690626926_item	3634142	et	4	main
pikkus	doc_278690626926_item	3634137	et	4	main
essee	doc_278690626926_item	3634136	et	4	main
test	doc_278690626926_item	3634127	et	3	main
keele	doc_278690626926_item	3634126	et	4	main
keele	doc_278690626926_item	3634123	et	4	main
eesti	doc_278690626926_item	3634122	et	4	main
essee	doc_278690626926_item	3634121	et	4	main
sai	doc_278690626927_item	3634420	et	4	main
arvates	doc_278690626927_item	3634411	et	4	main
minu	doc_278690626927_item	3634410	et	3	main
inimesi	doc_278690626927_item	3634403	et	4	main
solvutada	doc_278690626927_item	3634385	et	4	main
suur	doc_278690626927_item	3634378	et	3	main
koos	doc_278690626927_item	3634369	et	4	main
näidetega	doc_278690626927_item	3634304	et	3	main
illustreerida	doc_278690626927_item	3634303	et	3	main
soovitatav	doc_278690626927_item	3634302	et	4	main
iseseisvust	doc_278690626927_item	3634419	et	4	main
pärast	doc_278690626927_item	3634418	et	4	main
eesti	doc_278690626927_item	3634417	et	4	main
et	doc_278690626927_item	3634416	et	3	main
tugevam	doc_278690626927_item	3634409	et	4	main
kui	doc_278690626927_item	3634402	et	3	main
põlve	doc_278690626927_item	3634392	et	4	main
pärandati	doc_278690626927_item	3634386	et	4	main
kultuurist	doc_278690626927_item	3634381	et	3	main
parem	doc_278690626927_item	3634372	et	4	main
laul	doc_278690626927_item	3634366	et	4	main
teha	doc_278690626927_item	3634354	et	3	main
palju	doc_278690626927_item	3634353	et	4	main
nad	doc_278690626927_item	3634352	et	3	main
peaksid	doc_278690626927_item	3634351	et	4	main
oleks	doc_278690626927_item	3634350	et	3	main
niimodi	doc_278690626927_item	3634349	et	4	main
see	doc_278690626927_item	3634348	et	3	main
et	doc_278690626927_item	3634347	et	3	main
nii	doc_278690626927_item	3634346	et	3	main
iseseisuv	doc_278690626927_item	3634345	et	4	main
alati	doc_278690626927_item	3634344	et	4	main
polnud	doc_278690626927_item	3634343	et	3	main
eestimaa	doc_278690626927_item	3634342	et	4	main
teha	doc_278690626927_item	3634341	et	3	main
paremaks	doc_278690626927_item	3634340	et	4	main
seda	doc_278690626927_item	3634339	et	3	main
lauluga	doc_278690626927_item	3634338	et	4	main
võiks	doc_278690626927_item	3634337	et	4	main
paha	doc_278690626927_item	3634336	et	4	main
on	doc_278690626927_item	3634335	et	4	main
tuju	doc_278690626927_item	3634334	et	4	main
ja	doc_278690626927_item	3634333	et	3	main
probleemid	doc_278690626927_item	3634332	et	3	main
on	doc_278690626927_item	3634331	et	4	main
kui	doc_278690626927_item	3634330	et	3	main
laulda	doc_278690626927_item	3634329	et	4	main
tahame	doc_278690626927_item	3634328	et	3	main
hästi	doc_278690626927_item	3634327	et	3	main
on	doc_278690626927_item	3634326	et	4	main
kõik	doc_278690626927_item	3634325	et	4	main
kui	doc_278690626927_item	3634324	et	3	main
tujud	doc_278690626927_item	3634323	et	3	main
ja	doc_278690626927_item	3634322	et	3	main
tunned	doc_278690626927_item	3634321	et	3	main
mida	doc_278690626927_item	3634314	et	4	main
oskusest	doc_278690626927_item	3634313	et	4	main
olulisemaist	doc_278690626927_item	3634312	et	4	main
välja	doc_278690626927_item	3634319	et	4	main
lugemistekstis	doc_278690626927_item	3634297	et	3	main
ja	doc_278690626927_item	3634296	et	3	main
loengus	doc_278690626927_item	3634295	et	3	main
tuginema	doc_278690626927_item	3634294	et	3	main
üldistav	doc_278690626927_item	3634293	et	4	main
ja	doc_278690626927_item	3634292	et	3	main
analüüsiv	doc_278690626927_item	3634291	et	4	main
arutlev	doc_278690626927_item	3634290	et	4	main
olema	doc_278690626927_item	3634289	et	4	main
peab	doc_278690626927_item	3634288	et	4	main
essee	doc_278690626927_item	3634287	et	4	main
sõna	doc_278690626927_item	3634286	et	4	main
350	doc_278690626927_item	3634285	et	2	main
300	doc_278690626927_item	3634284	et	2	main
pikkus	doc_278690626927_item	3634283	et	4	main
essee	doc_278690626927_item	3634282	et	4	main
laulurahva	doc_278690626927_item	3634281	et	3	main
teeb	doc_278690626927_item	3634279	et	3	main
eestlastest	doc_278690626927_item	3634280	et	4	main
mis	doc_278690626927_item	3634278	et	4	main
teemal	doc_278690626927_item	3634277	et	3	main
essee	doc_278690626927_item	3634276	et	4	main
kirjutage	doc_278690626927_item	3634275	et	3	main
kirjutamine	doc_278690626927_item	3634274	et	4	main
test	doc_278690626927_item	3634273	et	3	main
keele	doc_278690626927_item	3634272	et	4	main
teise	doc_278690626927_item	3634271	et	4	main
kui	doc_278690626927_item	3634270	et	3	main
keele	doc_278690626927_item	3634269	et	4	main
eesti	doc_278690626927_item	3634268	et	4	main
essee	doc_278690626927_item	3634267	et	4	main
on	doc_278690626927_item	3634310	et	4	main
laul	doc_278690626927_item	3634309	et	4	main
laulurahva	doc_278690626927_item	3634308	et	3	main
eestlastest	doc_278690626927_item	3634307	et	4	main
teeb	doc_278690626927_item	3634306	et	3	main
mis	doc_278690626927_item	3634305	et	4	main
üks	doc_278690626927_item	3634311	et	3	main
esitatud	doc_278690626927_item	3634298	et	4	main
naised	doc_278690626928_item	3634546	et	3	main
see	doc_278690626928_item	3634541	et	3	main
tallinna	doc_278690626928_item	3634529	et	4	main
lauljad	doc_278690626928_item	3634527	et	4	main
tuhanded	doc_278690626928_item	3634526	et	3	main
juulis	doc_278690626928_item	3634525	et	3	main
aasta	doc_278690626928_item	3634524	et	4	main
lemmikuim	doc_278690626928_item	3634518	et	3	main
on	doc_278690626928_item	3634516	et	4	main
olla	doc_278690626928_item	3634515	et	3	main
võib	doc_278690626928_item	3634514	et	3	main
arm	doc_278690626928_item	3634513	et	3	main
minu	doc_278690626928_item	3634512	et	3	main
on	doc_278690626928_item	3634511	et	4	main
populaarne	doc_278690626928_item	3634505	et	3	main
praegu	doc_278690626928_item	3634498	et	3	main
ükskõik	doc_278690626928_item	3634494	et	3	main
üksi	doc_278690626928_item	3634491	et	4	main
ette	doc_278690626928_item	3634484	et	4	main
kujuta	doc_278690626928_item	3634483	et	4	main
eestlased	doc_278690626928_item	3634481	et	3	main
praegu	doc_278690626928_item	3634480	et	3	main
nii	doc_278690626928_item	3634479	et	3	main
on	doc_278690626928_item	3634456	et	4	main
soovitatav	doc_278690626928_item	3634457	et	4	main
faktidele	doc_278690626928_item	3634454	et	3	main
väiteid	doc_278690626928_item	3634455	et	4	main
esitatud	doc_278690626928_item	3634453	et	4	main
lugemistekstis	doc_278690626928_item	3634452	et	3	main
ja	doc_278690626928_item	3634451	et	3	main
loengus	doc_278690626928_item	3634450	et	3	main
tuginema	doc_278690626928_item	3634449	et	3	main
üldistav	doc_278690626928_item	3634448	et	4	main
ja	doc_278690626928_item	3634447	et	3	main
analüüsiv	doc_278690626928_item	3634446	et	4	main
arutlev	doc_278690626928_item	3634445	et	4	main
olema	doc_278690626928_item	3634444	et	4	main
peab	doc_278690626928_item	3634443	et	4	main
essee	doc_278690626928_item	3634442	et	4	main
sõna	doc_278690626928_item	3634441	et	4	main
350	doc_278690626928_item	3634440	et	2	main
300	doc_278690626928_item	3634439	et	2	main
pikkus	doc_278690626928_item	3634438	et	4	main
on	doc_278690626927_item	3634301	et	4	main
tähtis	doc_278690626928_item	3634543	et	4	main
kestnud	doc_278690626928_item	3634538	et	4	main
aastat	doc_278690626928_item	3634537	et	3	main
125	doc_278690626928_item	3634536	et	2	main
lauluväljakule	doc_278690626928_item	3634530	et	3	main
jaoks	doc_278690626928_item	3634522	et	4	main
mu	doc_278690626928_item	3634509	et	3	main
on	doc_278690626928_item	3634503	et	4	main
samasugune	doc_278690626928_item	3634500	et	3	main
kus	doc_278690626928_item	3634495	et	3	main
töötades	doc_278690626928_item	3634493	et	3	main
keele	doc_278690626928_item	3634427	et	4	main
kui	doc_278690626928_item	3634425	et	3	main
essee	doc_278690626928_item	3634422	et	4	main
see	doc_278690626929_item	3634703	et	3	main
ajal	doc_278690626929_item	3634693	et	4	main
eesti	doc_278690626929_item	3634690	et	4	main
rahvuslikeks	doc_278690626929_item	3634688	et	3	main
laulud	doc_278690626929_item	3634683	et	3	main
on	doc_278690626929_item	3634672	et	4	main
et	doc_278690626929_item	3634670	et	3	main
inimene	doc_278690626929_item	3634667	et	3	main
seal	doc_278690626929_item	3634657	et	4	main
sõpradega	doc_278690626929_item	3634656	et	3	main
on	doc_278690626929_item	3634648	et	4	main
laulupidu	doc_278690626929_item	3634636	et	4	main
on	doc_278690626929_item	3634630	et	4	main
laul	doc_278690626929_item	3634624	et	4	main
laulupeod	doc_278690626929_item	3634615	et	4	main
toimuvad	doc_278690626929_item	3634614	et	4	main
essee	doc_278690626929_item	3634579	et	4	main
sõna	doc_278690626929_item	3634578	et	4	main
test	doc_278690626929_item	3634565	et	3	main
kui	doc_278690626929_item	3634562	et	3	main
on	doc_278690626929_item	3634603	et	4	main
laul	doc_278690626929_item	3634602	et	4	main
eestlastel	doc_278690626929_item	3634601	et	4	main
laulurahva	doc_278690626929_item	3634600	et	3	main
on	doc_278690626929_item	3634593	et	4	main
ja	doc_278690626929_item	3634588	et	3	main
on	doc_278690626932_item	3634826	et	4	main
laulupeol	doc_278690626932_item	3634821	et	4	main
laulmine	doc_278690626932_item	3634809	et	4	main
lõpupoole	doc_278690626932_item	3634807	et	4	main
muusika	doc_278690626932_item	3634801	et	4	main
slaavi	doc_278690626932_item	3634800	et	3	main
ja	doc_278690626932_item	3634799	et	3	main
soome	doc_278690626932_item	3634798	et	3	main
euroopa	doc_278690626932_item	3634793	et	4	main
kiriku	doc_278690626932_item	3634773	et	3	main
olid	doc_278690626932_item	3634767	et	4	main
tähtsaim	doc_278690626932_item	3634757	et	4	main
on	doc_278690626932_item	3634751	et	4	main
esitatud	doc_278690626932_item	3634739	et	4	main
loengus	doc_278690626932_item	3634736	et	3	main
armastama	doc_278690626933_item	3635198	et	3	main
kes	doc_278690626933_item	3635189	et	4	main
eesti	doc_278690626933_item	3635180	et	4	main
on	doc_278690626933_item	3635169	et	4	main
kui	doc_278690626933_item	3635167	et	3	main
muusika	doc_278690626933_item	3635136	et	4	main
iga	doc_278690626933_item	3635126	et	4	main
aru	doc_278690626933_item	3635117	et	4	main
töötavad	doc_278690626933_item	3635108	et	4	main
on	doc_278690626933_item	3635081	et	4	main
kirik	doc_278690626933_item	3635080	et	3	main
laulute	doc_278690626933_item	3635068	et	4	main
et	doc_278690626933_item	3635066	et	3	main
ole	doc_278690626933_item	3635063	et	4	main
ei	doc_278690626933_item	3635062	et	4	main
stiili	doc_278690626933_item	3635061	et	4	main
seda	doc_278690626933_item	3635060	et	3	main
me	doc_278690626933_item	3635045	et	4	main
regioonides	doc_278690626933_item	3635044	et	3	main
pulmalaul	doc_278690626933_item	3635038	et	4	main
olla	doc_278690626933_item	3635037	et	3	main
võib	doc_278690626933_item	3635036	et	3	main
on	doc_278690626933_item	3635004	et	4	main
kapp	doc_278690626933_item	3635000	et	3	main
rahvalauluga	doc_278690626933_item	3634993	et	4	main
autorid	doc_278690626933_item	3634991	et	3	main
see	doc_278690626928_item	3634556	et	3	main
nendele	doc_278690626928_item	3634545	et	4	main
sest	doc_278690626928_item	3634532	et	4	main
kogunesid	doc_278690626928_item	3634528	et	4	main
eestlase	doc_278690626928_item	3634521	et	3	main
isamaa	doc_278690626928_item	3634510	et	4	main
rahvalaul	doc_278690626928_item	3634502	et	4	main
kuidas	doc_278690626928_item	3634485	et	3	main
ei	doc_278690626928_item	3634482	et	4	main
varem	doc_278690626928_item	3634478	et	4	main
kui	doc_278690626928_item	3634477	et	3	main
elu	doc_278690626928_item	3634476	et	4	main
tähtis	doc_278690626928_item	3634473	et	4	main
kultuur	doc_278690626928_item	3634472	et	3	main
on	doc_278690626928_item	3634471	et	4	main
laulmine	doc_278690626928_item	3634470	et	4	main
vastus	doc_278690626928_item	3634469	et	3	main
anda	doc_278690626928_item	3634468	et	3	main
püüan	doc_278690626928_item	3634467	et	3	main
ma	doc_278690626928_item	3634466	et	3	main
küsimus	doc_278690626928_item	3634465	et	4	main
huvitav	doc_278690626928_item	3634464	et	4	main
laulurahva	doc_278690626928_item	3634463	et	3	main
eestlastest	doc_278690626928_item	3634462	et	4	main
teeb	doc_278690626928_item	3634461	et	3	main
mis	doc_278690626928_item	3634460	et	4	main
näidetega	doc_278690626928_item	3634459	et	3	main
illustreerida	doc_278690626928_item	3634458	et	3	main
essee	doc_278690626928_item	3634431	et	4	main
kirjutage	doc_278690626928_item	3634430	et	3	main
teise	doc_278690626928_item	3634426	et	4	main
laulurahva	doc_278690626929_item	3634706	et	3	main
et	doc_278690626929_item	3634699	et	3	main
meeldis	doc_278690626929_item	3634694	et	3	main
selle	doc_278690626929_item	3634681	et	4	main
kõik	doc_278690626929_item	3634678	et	4	main
vaid	doc_278690626929_item	3634675	et	3	main
saab	doc_278690626929_item	3634668	et	3	main
ühendavat	doc_278690626929_item	3634665	et	4	main
tekib	doc_278690626929_item	3634664	et	3	main
see	doc_278690626929_item	3634663	et	3	main
ja	doc_278690626929_item	3634662	et	3	main
laulda	doc_278690626929_item	3634661	et	4	main
sugulastega	doc_278690626929_item	3634655	et	4	main
tartus	doc_278690626929_item	3634638	et	3	main
kujunenud	doc_278690626929_item	3634631	et	4	main
rahvalaul	doc_278690626929_item	3634617	et	4	main
kirjutamine	doc_278690626929_item	3634566	et	4	main
teise	doc_278690626929_item	3634563	et	4	main
keele	doc_278690626929_item	3634561	et	4	main
eesti	doc_278690626929_item	3634560	et	4	main
essee	doc_278690626929_item	3634559	et	4	main
illustreerida	doc_278690626929_item	3634595	et	3	main
lugemistekstis	doc_278690626929_item	3634589	et	3	main
ja	doc_278690626929_item	3634584	et	3	main
olema	doc_278690626929_item	3634581	et	4	main
festivale	doc_278690626932_item	3634835	et	3	main
ajalugu	doc_278690626932_item	3634825	et	4	main
praegu	doc_278690626932_item	3634820	et	3	main
olid	doc_278690626932_item	3634816	et	4	main
selles	doc_278690626932_item	3634814	et	4	main
osa	doc_278690626932_item	3634813	et	4	main
19	doc_278690626932_item	3634805	et	2	main
pere	doc_278690626932_item	3634782	et	4	main
ajal	doc_278690626932_item	3634779	et	4	main
laulurahva	doc_278690626928_item	3634436	et	3	main
eestlastest	doc_278690626928_item	3634435	et	4	main
teeb	doc_278690626928_item	3634434	et	3	main
mis	doc_278690626928_item	3634433	et	4	main
teemal	doc_278690626928_item	3634432	et	3	main
ja	doc_278690626929_item	3634702	et	3	main
laul	doc_278690626929_item	3634700	et	4	main
arusaadav	doc_278690626929_item	3634698	et	4	main
kõigel	doc_278690626929_item	3634692	et	4	main
rahvale	doc_278690626929_item	3634691	et	3	main
kujunenud	doc_278690626929_item	3634687	et	4	main
aja	doc_278690626929_item	3634686	et	4	main
peo	doc_278690626929_item	3634682	et	4	main
mitte	doc_278690626929_item	3634673	et	3	main
ta	doc_278690626929_item	3634671	et	4	main
aru	doc_278690626929_item	3634669	et	4	main
tunnet	doc_278690626929_item	3634666	et	3	main
perega	doc_278690626929_item	3634654	et	3	main
koos	doc_278690626929_item	3634653	et	4	main
tullakse	doc_278690626929_item	3634652	et	3	main
kuhu	doc_278690626929_item	3634651	et	3	main
laulupidu	doc_278690626929_item	3634647	et	4	main
saja	doc_278690626929_item	3634645	et	4	main
juba	doc_278690626929_item	3634643	et	3	main
ja	doc_278690626929_item	3634641	et	3	main
1869	doc_278690626929_item	3634639	et	2	main
sündis	doc_278690626929_item	3634637	et	3	main
eesti	doc_278690626929_item	3634634	et	4	main
identitee	doc_278690626929_item	3634633	et	4	main
rahvuslik	doc_278690626929_item	3634632	et	3	main
eestlastel	doc_278690626929_item	3634629	et	4	main
inimesi	doc_278690626929_item	3634626	et	4	main
eestimaal	doc_278690626929_item	3634616	et	4	main
kirjutamine	doc_278690626928_item	3634429	et	4	main
test	doc_278690626928_item	3634428	et	3	main
keele	doc_278690626928_item	3634424	et	4	main
eestlasest	doc_278690626929_item	3634705	et	3	main
on	doc_278690626929_item	3634697	et	4	main
sest	doc_278690626929_item	3634696	et	4	main
sümboliteks	doc_278690626929_item	3634689	et	3	main
läbi	doc_278690626929_item	3634685	et	4	main
rahv	doc_278690626929_item	3634680	et	4	main
tema	doc_278690626929_item	3634679	et	4	main
on	doc_278690626929_item	3634677	et	4	main
temaga	doc_278690626929_item	3634676	et	3	main
rahvapidu	doc_278690626929_item	3634650	et	4	main
suur	doc_278690626929_item	3634649	et	3	main
seepärast	doc_278690626929_item	3634628	et	3	main
koguneb	doc_278690626929_item	3634625	et	3	main
tagasi	doc_278690626929_item	3634623	et	3	main
aastat	doc_278690626929_item	3634622	et	3	main
tuhat	doc_278690626929_item	3634621	et	4	main
kui	doc_278690626929_item	3634620	et	3	main
praegu	doc_278690626929_item	3634613	et	3	main
kiigutates	doc_278690626929_item	3634612	et	4	main
last	doc_278690626929_item	3634611	et	4	main
töötades	doc_278690626929_item	3634610	et	3	main
olles	doc_278690626929_item	3634609	et	3	main
laulsid	doc_278690626929_item	3634608	et	4	main
nad	doc_278690626929_item	3634607	et	3	main
peab	doc_278690626929_item	3634580	et	4	main
350	doc_278690626929_item	3634577	et	2	main
300	doc_278690626929_item	3634576	et	2	main
pikkus	doc_278690626929_item	3634575	et	4	main
eestlastest	doc_278690626929_item	3634572	et	4	main
näidetega	doc_278690626929_item	3634596	et	3	main
faktidele	doc_278690626929_item	3634591	et	3	main
pop-	doc_278690626932_item	3634832	et	4	main
palju	doc_278690626932_item	3634829	et	4	main
praegu	doc_278690626932_item	3634828	et	3	main
ka	doc_278690626932_item	3634827	et	3	main
on	doc_278690626932_item	3634822	et	4	main
pärinud	doc_278690626932_item	3634817	et	4	main
tähtis	doc_278690626932_item	3634812	et	4	main
rootsi	doc_278690626932_item	3634797	et	4	main
laulsid	doc_278690626932_item	3634776	et	4	main
eestlased	doc_278690626932_item	3634775	et	3	main
seotatud	doc_278690626932_item	3634768	et	4	main
pillimäng	doc_278690626932_item	3634763	et	3	main
ajal	doc_278690626932_item	3634756	et	4	main
vana	doc_278690626932_item	3634755	et	4	main
erinev	doc_278690626932_item	3634754	et	4	main
ja	doc_278690626932_item	3634753	et	3	main
rahva	doc_278690626932_item	3634747	et	3	main
soovitatav	doc_278690626932_item	3634743	et	4	main
on	doc_278690626932_item	3634742	et	4	main
meie	doc_278690626933_item	3635199	et	4	main
hoolima	doc_278690626933_item	3635196	et	4	main
venelane	doc_278690626933_item	3635194	et	3	main
või	doc_278690626933_item	3635193	et	4	main
eestlane	doc_278690626933_item	3635192	et	3	main
eestis	doc_278690626933_item	3635191	et	3	main
elab	doc_278690626933_item	3635190	et	3	main
on	doc_278690626933_item	3635186	et	4	main
see	doc_278690626933_item	3635185	et	3	main
ja	doc_278690626933_item	3635184	et	3	main
eestlastel	doc_278690626933_item	3635183	et	4	main
aitab	doc_278690626933_item	3635182	et	3	main
kultuur	doc_278690626933_item	3635181	et	3	main
aga	doc_278690626933_item	3635171	et	3	main
eestimaal	doc_278690626933_item	3635164	et	4	main
kui	doc_278690626933_item	3635163	et	3	main
alati	doc_278690626933_item	3635162	et	4	main
laulavad	doc_278690626933_item	3635161	et	4	main
rahvalaulu	doc_278690626933_item	3635149	et	4	main
pea	doc_278690626933_item	3635147	et	4	main
ei	doc_278690626933_item	3635146	et	4	main
me	doc_278690626933_item	3635145	et	4	main
et	doc_278690626933_item	3635144	et	3	main
rock	doc_278690626933_item	3635135	et	4	main
ja	doc_278690626933_item	3635134	et	3	main
essee	doc_278690626929_item	3634574	et	4	main
mis	doc_278690626929_item	3634570	et	4	main
teemal	doc_278690626929_item	3634569	et	3	main
essee	doc_278690626929_item	3634568	et	4	main
kirjutage	doc_278690626929_item	3634567	et	3	main
ajal	doc_278690626929_item	3634606	et	4	main
vanal	doc_278690626929_item	3634605	et	3	main
eestlastest	doc_278690626929_item	3634599	et	4	main
teeb	doc_278690626929_item	3634598	et	3	main
väiteid	doc_278690626929_item	3634592	et	4	main
esitatud	doc_278690626929_item	3634590	et	4	main
loengus	doc_278690626929_item	3634587	et	3	main
üldistav	doc_278690626929_item	3634585	et	4	main
analüüsiv	doc_278690626929_item	3634583	et	4	main
arutlev	doc_278690626929_item	3634582	et	4	main
festivale	doc_278690626932_item	3634831	et	3	main
folkloori	doc_278690626932_item	3634830	et	4	main
idee	doc_278690626932_item	3634819	et	4	main
väga	doc_278690626932_item	3634811	et	3	main
saksa	doc_278690626932_item	3634796	et	4	main
venemaa	doc_278690626932_item	3634795	et	4	main
laulmisega	doc_278690626932_item	3634774	et	4	main
rahvapidustega	doc_278690626932_item	3634771	et	4	main
rohkem	doc_278690626932_item	3634770	et	4	main
tants	doc_278690626932_item	3634765	et	3	main
laulurahva	doc_278690626932_item	3634750	et	3	main
me	doc_278690626933_item	3635188	et	4	main
paha	doc_278690626933_item	3635170	et	4	main
tuntub	doc_278690626933_item	3635143	et	4	main
mulle	doc_278690626933_item	3635142	et	4	main
öelda	doc_278690626933_item	3635131	et	4	main
ei	doc_278690626933_item	3635129	et	4	main
mina	doc_278690626933_item	3635128	et	4	main
päev	doc_278690626933_item	3635127	et	3	main
minevik	doc_278690626933_item	3635120	et	3	main
meie	doc_278690626933_item	3635119	et	4	main
et	doc_278690626933_item	3635118	et	3	main
väga	doc_278690626933_item	3635103	et	3	main
sajandis	doc_278690626933_item	3635102	et	3	main
alati	doc_278690626933_item	3635091	et	4	main
keskuste	doc_278690626933_item	3635078	et	4	main
kultuur	doc_278690626933_item	3635077	et	3	main
tähtsame	doc_278690626933_item	3635076	et	4	main
lõuna	doc_278690626933_item	3635051	et	4	main
erinevat	doc_278690626933_item	3635048	et	4	main
eestlased	doc_278690626933_item	3635005	et	3	main
need	doc_278690626933_item	3635003	et	3	main
teised	doc_278690626933_item	3635002	et	4	main
saar	doc_278690626933_item	3634999	et	3	main
autorilaulu	doc_278690626933_item	3634997	et	4	main
nad	doc_278690626933_item	3634995	et	3	main
rahva	doc_278690626933_item	3634981	et	3	main
mis	doc_278690626933_item	3634875	et	4	main
illustreerida	doc_278690626933_item	3634873	et	3	main
ja	doc_278690626933_item	3634866	et	3	main
teeb	doc_278690626933_item	3634849	et	3	main
kirjutage	doc_278690626933_item	3634845	et	3	main
test	doc_278690626933_item	3634843	et	3	main
regilaulu	doc_278690626933_item	3634924	et	4	main
laulud	doc_278690626933_item	3634918	et	3	main
lauluga	doc_278690626933_item	3634916	et	4	main
elavad	doc_278690626933_item	3634906	et	4	main
rahva	doc_278690626933_item	3634898	et	3	main
rahvakultuuri	doc_278690626933_item	3634886	et	4	main
on	doc_278690626933_item	3634885	et	4	main
see	doc_278690626933_item	3634884	et	3	main
ja	doc_278690626934_item	3635404	et	3	main
teeb	doc_278690626934_item	3635395	et	3	main
mis	doc_278690626934_item	3635394	et	4	main
folkloorfestivalid	doc_278690626934_item	3635392	et	4	main
ka	doc_278690626934_item	3635391	et	3	main
folkloori	doc_278690626934_item	3635388	et	4	main
meie	doc_278690626934_item	3635370	et	4	main
lauluks	doc_278690626934_item	3635361	et	4	main
laulapeol	doc_278690626934_item	3635355	et	4	main
oli	doc_278690626934_item	3635349	et	3	main
1896	doc_278690626934_item	3635346	et	2	main
ülemane	doc_278690626934_item	3635344	et	4	main
tähtsusega	doc_278690626934_item	3635340	et	4	main
tähtis	doc_278690626934_item	3635338	et	4	main
väga	doc_278690626934_item	3635337	et	3	main
rokmuusika	doc_278690626932_item	3634834	et	4	main
ja	doc_278690626932_item	3634833	et	3	main
huvitav	doc_278690626932_item	3634824	et	4	main
oma	doc_278690626932_item	3634823	et	4	main
laulupeo	doc_278690626932_item	3634818	et	4	main
ajas	doc_278690626932_item	3634815	et	4	main
ka	doc_278690626932_item	3634810	et	3	main
oli	doc_278690626932_item	3634808	et	3	main
sajandi	doc_278690626932_item	3634806	et	3	main
ajal	doc_278690626932_item	3634804	et	4	main
ärkamise	doc_278690626932_item	3634803	et	4	main
rahvusliku	doc_278690626932_item	3634802	et	3	main
ning	doc_278690626932_item	3634794	et	3	main
kui	doc_278690626932_item	3634792	et	3	main
mõjutasid	doc_278690626932_item	3634791	et	4	main
laulutraditsioonile	doc_278690626932_item	3634790	et	3	main
jaoks	doc_278690626932_item	3634789	et	4	main
naiste	doc_278690626932_item	3634788	et	3	main
koosneb	doc_278690626932_item	3634787	et	3	main
laulmine	doc_278690626932_item	3634786	et	4	main
tähtsus	doc_278690626932_item	3634785	et	4	main
suur	doc_278690626932_item	3634784	et	3	main
ringis	doc_278690626932_item	3634783	et	4	main
ka	doc_278690626932_item	3634781	et	3	main
kui	doc_278690626932_item	3634780	et	3	main
ja	doc_278690626932_item	3634772	et	3	main
rahvalaulud	doc_278690626932_item	3634766	et	3	main
olid	doc_278690626932_item	3634761	et	4	main
kultuurist	doc_278690626932_item	3634760	et	3	main
eesti	doc_278690626932_item	3634759	et	4	main
kui	doc_278690626932_item	3634749	et	3	main
näidetega	doc_278690626932_item	3634745	et	3	main
väiteid	doc_278690626932_item	3634741	et	4	main
faktidele	doc_278690626932_item	3634740	et	3	main
maa	doc_278690626933_item	3635200	et	4	main
ma	doc_278690626933_item	3635172	et	3	main
probleemid	doc_278690626933_item	3635165	et	3	main
said	doc_278690626933_item	3635160	et	4	main
eestlased	doc_278690626933_item	3635159	et	3	main
kuidas	doc_278690626933_item	3635158	et	3	main
tea	doc_278690626933_item	3635157	et	4	main
ei	doc_278690626933_item	3635156	et	4	main
ma	doc_278690626933_item	3635155	et	3	main
et	doc_278690626933_item	3635154	et	3	main
lisada	doc_278690626933_item	3635153	et	3	main
tahaksin	doc_278690626933_item	3635152	et	3	main
ma	doc_278690626933_item	3635151	et	3	main
töötamise	doc_278690626932_item	3634778	et	4	main
ka	doc_278690626932_item	3634777	et	3	main
kõige	doc_278690626932_item	3634769	et	4	main
ja	doc_278690626932_item	3634764	et	3	main
laul	doc_278690626932_item	3634762	et	4	main
osa	doc_278690626932_item	3634758	et	4	main
pikk	doc_278690626932_item	3634752	et	4	main
ajalugu	doc_278690626932_item	3634748	et	4	main
eesti	doc_278690626932_item	3634746	et	4	main
illustreerida	doc_278690626932_item	3634744	et	3	main
lugemistekstis	doc_278690626932_item	3634738	et	3	main
ja	doc_278690626932_item	3634737	et	3	main
tuginema	doc_278690626932_item	3634735	et	3	main
üldistav	doc_278690626932_item	3634734	et	4	main
ja	doc_278690626932_item	3634733	et	3	main
analüüsiv	doc_278690626932_item	3634732	et	4	main
arutlev	doc_278690626932_item	3634731	et	4	main
olema	doc_278690626932_item	3634730	et	4	main
peab	doc_278690626932_item	3634729	et	4	main
essee	doc_278690626932_item	3634728	et	4	main
sõna	doc_278690626932_item	3634727	et	4	main
350	doc_278690626932_item	3634726	et	2	main
300	doc_278690626932_item	3634725	et	2	main
pikkus	doc_278690626932_item	3634724	et	4	main
essee	doc_278690626932_item	3634723	et	4	main
laulurahva	doc_278690626932_item	3634722	et	3	main
eestlastest	doc_278690626932_item	3634721	et	4	main
teeb	doc_278690626932_item	3634720	et	3	main
mis	doc_278690626932_item	3634719	et	4	main
teemal	doc_278690626932_item	3634718	et	3	main
essee	doc_278690626932_item	3634717	et	4	main
kirjutage	doc_278690626932_item	3634716	et	3	main
kirjutamine	doc_278690626932_item	3634715	et	4	main
test	doc_278690626932_item	3634714	et	3	main
keele	doc_278690626932_item	3634713	et	4	main
teise	doc_278690626932_item	3634712	et	4	main
kui	doc_278690626932_item	3634711	et	3	main
keele	doc_278690626932_item	3634710	et	4	main
eesti	doc_278690626932_item	3634709	et	4	main
essee	doc_278690626932_item	3634708	et	4	main
ja	doc_278690626933_item	3635197	et	3	main
peavad	doc_278690626933_item	3635195	et	4	main
suurepärane	doc_278690626933_item	3635187	et	4	main
tugev	doc_278690626933_item	3635179	et	4	main
väga	doc_278690626933_item	3635178	et	3	main
ja	doc_278690626933_item	3635177	et	3	main
ilus	doc_278690626933_item	3635176	et	4	main
väga	doc_278690626933_item	3635175	et	3	main
et	doc_278690626933_item	3635174	et	3	main
arvan	doc_278690626933_item	3635173	et	3	main
ilm	doc_278690626933_item	3635168	et	3	main
on	doc_278690626933_item	3635166	et	4	main
lõpuks	doc_278690626933_item	3635150	et	4	main
on	doc_278690626933_item	3635137	et	4	main
kultuur	doc_278690626933_item	3635201	et	3	main
unistama	doc_278690626933_item	3635148	et	3	main
paha	doc_278690626933_item	3635141	et	4	main
mõjvad	doc_278690626933_item	3635140	et	4	main
ja	doc_278690626933_item	3635139	et	3	main
negatiivne	doc_278690626933_item	3635138	et	3	main
pop-	doc_278690626933_item	3635133	et	4	main
saa	doc_278690626933_item	3635130	et	4	main
rolli	doc_278690626933_item	3635123	et	4	main
suur	doc_278690626933_item	3635122	et	3	main
mängib	doc_278690626933_item	3635121	et	3	main
valivad	doc_278690626933_item	3635113	et	4	main
nad	doc_278690626933_item	3635112	et	3	main
olla	doc_278690626933_item	3635111	et	3	main
võib	doc_278690626933_item	3635110	et	3	main
rahvalauluga	doc_278690626933_item	3635109	et	4	main
palju	doc_278690626933_item	3635104	et	4	main
et	doc_278690626933_item	3635132	et	3	main
tänapäevase	doc_278690626933_item	3635124	et	4	main
sest	doc_278690626933_item	3635115	et	4	main
seda	doc_278690626933_item	3635114	et	3	main
muusika-	doc_278690626933_item	3635105	et	4	main
tänapäeval	doc_278690626933_item	3635092	et	3	main
kultuur	doc_278690626933_item	3635088	et	3	main
alati	doc_278690626933_item	3635084	et	4	main
kus	doc_278690626933_item	3635083	et	3	main
maja	doc_278690626933_item	3635082	et	4	main
alati	doc_278690626933_item	3635075	et	4	main
kirikuste	doc_278690626933_item	3635071	et	3	main
eesti	doc_278690626933_item	3635058	et	4	main
põhja	doc_278690626933_item	3635057	et	4	main
aga	doc_278690626933_item	3635056	et	3	main
on	doc_278690626933_item	3635055	et	4	main
stiil	doc_278690626933_item	3635054	et	3	main
ühe	doc_278690626933_item	3635053	et	4	main
näiteks	doc_278690626933_item	3635050	et	4	main
erinevaides	doc_278690626933_item	3635043	et	4	main
et	doc_278690626933_item	3635042	et	3	main
huvitav	doc_278690626933_item	3635041	et	4	main
algab	doc_278690626933_item	3634996	et	3	main
samal	doc_278690626933_item	3634988	et	3	main
aga	doc_278690626933_item	3634987	et	3	main
koorikultuuris	doc_278690626933_item	3634986	et	3	main
suur	doc_278690626933_item	3634984	et	3	main
laulavad	doc_278690626933_item	3634977	et	4	main
koorid	doc_278690626933_item	3634973	et	4	main
teeb	doc_278690626933_item	3634876	et	3	main
faktidele	doc_278690626933_item	3634869	et	3	main
olema	doc_278690626933_item	3634859	et	4	main
mis	doc_278690626933_item	3634848	et	4	main
kirjutamine	doc_278690626933_item	3634844	et	4	main
ja	doc_278690626933_item	3634922	et	3	main
olid	doc_278690626933_item	3634919	et	4	main
esimesed	doc_278690626933_item	3634917	et	3	main
algab	doc_278690626933_item	3634915	et	3	main
ebamuusikaline	doc_278690626933_item	3634911	et	4	main
balti	doc_278690626933_item	3634897	et	3	main
eestlased	doc_278690626933_item	3634894	et	3	main
teeme	doc_278690626933_item	3634891	et	3	main
kuidas	doc_278690626933_item	3634889	et	3	main
ja	doc_278690626933_item	3634888	et	3	main
teeb	doc_278690626933_item	3634880	et	3	main
laulurahv	doc_278690626934_item	3635413	et	4	main
tema	doc_278690626934_item	3635405	et	4	main
laulupeod	doc_278690626934_item	3635382	et	4	main
veedab	doc_278690626934_item	3635381	et	3	main
on	doc_278690626934_item	3635373	et	4	main
ka	doc_278690626934_item	3635369	et	3	main
palju	doc_278690626934_item	3635367	et	4	main
olid	doc_278690626934_item	3635365	et	4	main
peole	doc_278690626934_item	3635364	et	4	main
esimese	doc_278690626934_item	3635363	et	3	main
pärast	doc_278690626934_item	3635362	et	4	main
nende	doc_278690626934_item	3635357	et	4	main
sest	doc_278690626934_item	3635356	et	4	main
väga	doc_278690626934_item	3635350	et	3	main
aastal	doc_278690626934_item	3635347	et	3	main
maatused	doc_278690626934_item	3635324	et	4	main
käisid	doc_278690626934_item	3635316	et	4	main
eestlased	doc_278690626934_item	3635312	et	3	main
andis	doc_278690626934_item	3635310	et	3	main
huvitavam	doc_278690626934_item	3635308	et	4	main
sest	doc_278690626934_item	3635296	et	4	main
säilitasid	doc_278690626934_item	3635287	et	4	main
hauani	doc_278690626934_item	3635285	et	3	main
rasked	doc_278690626934_item	3635278	et	3	main
ta	doc_278690626934_item	3635268	et	4	main
sest	doc_278690626934_item	3635267	et	4	main
traditsioonidega	doc_278690626934_item	3635266	et	3	main
essee	doc_278690626934_item	3635223	et	4	main
sõna	doc_278690626934_item	3635222	et	4	main
300	doc_278690626934_item	3635220	et	2	main
pikkus	doc_278690626934_item	3635219	et	4	main
teemal	doc_278690626934_item	3635213	et	3	main
laulurahv	doc_278690626934_item	3635261	et	4	main
suur	doc_278690626935_item	3635532	et	3	main
ühiskonnaelus	doc_278690626933_item	3635125	et	4	main
said	doc_278690626933_item	3635116	et	4	main
vokaalnekollektiivid	doc_278690626933_item	3635107	et	4	main
ja	doc_278690626933_item	3635106	et	3	main
xix	doc_278690626933_item	3635101	et	4	main
xviii	doc_278690626933_item	3635099	et	4	main
kui	doc_278690626933_item	3635098	et	3	main
populaarne	doc_278690626933_item	3635097	et	3	main
rahva	doc_278690626933_item	3635090	et	3	main
sest	doc_278690626933_item	3635079	et	4	main
on	doc_278690626933_item	3635074	et	4	main
kultuur	doc_278690626933_item	3635072	et	3	main
osa	doc_278690626933_item	3635069	et	4	main
suur	doc_278690626933_item	3635067	et	3	main
osa	doc_278690626933_item	3635059	et	4	main
töölaul	doc_278690626933_item	3635040	et	4	main
või	doc_278690626933_item	3635100	et	4	main
väga	doc_278690626933_item	3635096	et	3	main
on	doc_278690626933_item	3635095	et	4	main
stiil	doc_278690626933_item	3635094	et	3	main
rahva	doc_278690626933_item	3635093	et	3	main
on	doc_278690626933_item	3635089	et	4	main
aga	doc_278690626933_item	3635087	et	3	main
rahva	doc_278690626933_item	3635086	et	3	main
palju	doc_278690626933_item	3635085	et	4	main
kirikud	doc_278690626933_item	3635073	et	3	main
omab	doc_278690626933_item	3635070	et	3	main
öelda	doc_278690626933_item	3635065	et	4	main
tahaksin	doc_278690626933_item	3635064	et	3	main
eestis	doc_278690626933_item	3635052	et	3	main
laulutes	doc_278690626933_item	3635049	et	3	main
kuula	doc_278690626933_item	3635047	et	4	main
saame	doc_278690626933_item	3635046	et	4	main
või	doc_278690626933_item	3635039	et	4	main
see	doc_278690626933_item	3635035	et	3	main
žaanrid	doc_278690626933_item	3635034	et	2	main
erinevaid	doc_278690626933_item	3635033	et	4	main
omab	doc_278690626933_item	3635032	et	3	main
laul	doc_278690626933_item	3635031	et	4	main
eesti	doc_278690626933_item	3635030	et	4	main
horisonti	doc_278690626933_item	3635029	et	4	main
kultuuri	doc_278690626933_item	3635028	et	4	main
eesti	doc_278690626933_item	3635027	et	4	main
avardavad	doc_278690626933_item	3635026	et	4	main
ja	doc_278690626933_item	3635025	et	3	main
teemaid	doc_278690626933_item	3635024	et	4	main
avasid	doc_278690626933_item	3635022	et	4	main
nad	doc_278690626933_item	3635021	et	3	main
uuete	doc_278690626933_item	3635023	et	4	main
solistidele	doc_278690626933_item	3635020	et	3	main
laulud	doc_278690626933_item	3635019	et	3	main
ja	doc_278690626933_item	3635018	et	3	main
koorilaulud	doc_278690626933_item	3635017	et	3	main
väärsused	doc_278690626933_item	3635016	et	4	main
on	doc_278690626933_item	3635015	et	4	main
töö	doc_278690626933_item	3635014	et	4	main
nende	doc_278690626933_item	3635013	et	4	main
ja	doc_278690626933_item	3635012	et	3	main
laulu	doc_278690626933_item	3635011	et	4	main
rahva	doc_278690626933_item	3635010	et	3	main
eesti	doc_278690626933_item	3635009	et	4	main
armastasid	doc_278690626933_item	3635008	et	4	main
väga	doc_278690626933_item	3635007	et	3	main
kes	doc_278690626933_item	3635006	et	4	main
periood	doc_278690626933_item	3634998	et	3	main
ja	doc_278690626933_item	3634994	et	3	main
töötavad	doc_278690626933_item	3634992	et	4	main
mängib	doc_278690626933_item	3634983	et	3	main
folklooride	doc_278690626933_item	3634979	et	4	main
soovitatav	doc_278690626933_item	3634872	et	4	main
on	doc_278690626933_item	3634871	et	4	main
loengus	doc_278690626933_item	3634865	et	3	main
üldistav	doc_278690626933_item	3634863	et	4	main
peab	doc_278690626933_item	3634858	et	4	main
eestlastest	doc_278690626933_item	3634850	et	4	main
essee	doc_278690626933_item	3634846	et	4	main
keele	doc_278690626933_item	3634842	et	4	main
teise	doc_278690626933_item	3634841	et	4	main
kui	doc_278690626933_item	3634840	et	3	main
keele	doc_278690626933_item	3634839	et	4	main
eesti	doc_278690626933_item	3634838	et	4	main
essee	doc_278690626933_item	3634837	et	4	main
tihti	doc_278690626933_item	3634972	et	3	main
väga	doc_278690626933_item	3634971	et	3	main
linnas	doc_278690626933_item	3634970	et	4	main
läheb	doc_278690626933_item	3634969	et	3	main
laul	doc_278690626933_item	3634968	et	4	main
maalest	doc_278690626933_item	3634967	et	4	main
laul	doc_278690626933_item	3634966	et	4	main
eesti	doc_278690626933_item	3634965	et	4	main
uus	doc_278690626933_item	3634964	et	3	main
ongi	doc_278690626933_item	3634963	et	4	main
see	doc_278690626933_item	3634962	et	3	main
eeslaulja	doc_278690626933_item	3634961	et	4	main
koorid	doc_278690626933_item	3634960	et	4	main
eestis	doc_278690626933_item	3634959	et	3	main
laulab	doc_278690626933_item	3634958	et	3	main
rahv	doc_278690626933_item	3634957	et	4	main
laulad	doc_278690626933_item	3634956	et	3	main
uued	doc_278690626933_item	3634955	et	3	main
ja	doc_278690626933_item	3634954	et	3	main
minevikus	doc_278690626933_item	3634953	et	3	main
regilaul	doc_278690626933_item	3634952	et	4	main
samm	doc_278690626933_item	3634951	et	3	main
suur	doc_278690626933_item	3634950	et	3	main
on	doc_278690626933_item	3634949	et	4	main
kultuuris	doc_278690626933_item	3634948	et	3	main
eesti	doc_278690626933_item	3634947	et	4	main
sajandis	doc_278690626933_item	3634946	et	3	main
xviii	doc_278690626933_item	3634945	et	4	main
lauluga	doc_278690626933_item	3634944	et	4	main
ja	doc_278690626933_item	3635001	et	3	main
ajal	doc_278690626933_item	3634989	et	4	main
rolli	doc_278690626933_item	3634985	et	4	main
laulate	doc_278690626933_item	3634980	et	3	main
eesti	doc_278690626933_item	3634978	et	4	main
eestlased	doc_278690626933_item	3634976	et	3	main
ja	doc_278690626933_item	3634975	et	3	main
koosnevad	doc_278690626933_item	3634974	et	4	main
väiteid	doc_278690626933_item	3634870	et	4	main
esitatud	doc_278690626933_item	3634868	et	4	main
ja	doc_278690626933_item	3634862	et	3	main
essee	doc_278690626933_item	3634857	et	4	main
sõna	doc_278690626933_item	3634856	et	4	main
300	doc_278690626933_item	3634854	et	2	main
pikkus	doc_278690626933_item	3634853	et	4	main
essee	doc_278690626933_item	3634852	et	4	main
laulurahva	doc_278690626933_item	3634851	et	3	main
teemal	doc_278690626933_item	3634847	et	3	main
tantsiga	doc_278690626933_item	3634926	et	3	main
koos	doc_278690626933_item	3634925	et	4	main
väga	doc_278690626933_item	3634920	et	3	main
kultuur	doc_278690626933_item	3634914	et	3	main
olla	doc_278690626933_item	3634910	et	3	main
ei	doc_278690626933_item	3634908	et	4	main
siin	doc_278690626933_item	3634907	et	4	main
on	doc_278690626933_item	3634900	et	4	main
eesti	doc_278690626933_item	3634899	et	4	main
on	doc_278690626933_item	3634895	et	4	main
inimest	doc_278690626933_item	3634881	et	3	main
mis	doc_278690626933_item	3634879	et	4	main
laulurahva	doc_278690626933_item	3634878	et	3	main
eestlastest	doc_278690626933_item	3634877	et	4	main
minevik	doc_278690626934_item	3635406	et	3	main
ajaloo	doc_278690626934_item	3635403	et	4	main
aulurahva	doc_278690626934_item	3635397	et	4	main
eestlastest	doc_278690626934_item	3635396	et	4	main
esitajaid	doc_278690626934_item	3635389	et	4	main
on	doc_278690626934_item	3635386	et	4	main
laulu	doc_278690626934_item	3635380	et	4	main
oma	doc_278690626934_item	3635379	et	4	main
austab	doc_278690626934_item	3635378	et	3	main
ta	doc_278690626934_item	3635377	et	4	main
praegu	doc_278690626934_item	3635376	et	3	main
ka	doc_278690626934_item	3635375	et	3	main
laulurahv	doc_278690626934_item	3635374	et	4	main
laulupidu	doc_278690626934_item	3635368	et	4	main
veel	doc_278690626934_item	3635366	et	4	main
armastus	doc_278690626934_item	3635359	et	4	main
ühines	doc_278690626934_item	3635358	et	3	main
kõik	doc_278690626934_item	3635353	et	4	main
eestlastele	doc_278690626934_item	3635348	et	4	main
oli	doc_278690626934_item	3635335	et	3	main
muidugi	doc_278690626934_item	3635325	et	4	main
aitas	doc_278690626934_item	3635304	et	3	main
emotsionaalne	doc_278690626934_item	3635301	et	3	main
oluline	doc_278690626934_item	3635300	et	4	main
väga	doc_278690626934_item	3635299	et	3	main
raske	doc_278690626934_item	3635295	et	4	main
ma	doc_278690626934_item	3635289	et	3	main
hällist	doc_278690626934_item	3635284	et	4	main
laul	doc_278690626934_item	3635283	et	4	main
saatsid	doc_278690626934_item	3635282	et	4	main
vana	doc_278690626934_item	3635271	et	4	main
niisama	doc_278690626934_item	3635270	et	3	main
suurega	doc_278690626934_item	3635265	et	4	main
omandab	doc_278690626934_item	3635264	et	3	main
eestis	doc_278690626934_item	3635263	et	3	main
eestlastest	doc_278690626934_item	3635216	et	4	main
teeb	doc_278690626934_item	3635215	et	3	main
mis	doc_278690626934_item	3635214	et	4	main
keele	doc_278690626934_item	3635208	et	4	main
teise	doc_278690626934_item	3635207	et	4	main
eesti	doc_278690626934_item	3635204	et	4	main
miks	doc_278690626934_item	3635257	et	4	main
absoluutselt	doc_278690626935_item	3635529	et	4	main
ma	doc_278690626935_item	3635527	et	3	main
teada	doc_278690626935_item	3635525	et	3	main
meil	doc_278690626935_item	3635518	et	4	main
nii	doc_278690626935_item	3635517	et	3	main
vanasti	doc_278690626935_item	3635515	et	3	main
missugused	doc_278690626935_item	3635514	et	3	main
sündmusi	doc_278690626935_item	3635513	et	3	main
palju	doc_278690626933_item	3634990	et	4	main
folkloor	doc_278690626933_item	3634982	et	4	main
näidetega	doc_278690626933_item	3634874	et	3	main
lugemistekstis	doc_278690626933_item	3634867	et	3	main
tuginema	doc_278690626933_item	3634864	et	3	main
analüüsiv	doc_278690626933_item	3634861	et	4	main
arutlev	doc_278690626933_item	3634860	et	4	main
350	doc_278690626933_item	3634855	et	2	main
nimesid	doc_278690626933_item	3634923	et	3	main
eesti	doc_278690626933_item	3634913	et	4	main
inimesed	doc_278690626933_item	3634904	et	3	main
laulumaa	doc_278690626933_item	3634902	et	4	main
väga	doc_278690626933_item	3634901	et	3	main
tänapäevase	doc_278690626933_item	3634892	et	4	main
muidugi	doc_278690626933_item	3634883	et	4	main
jagavad	doc_278690626933_item	3634943	et	4	main
eestlased	doc_278690626933_item	3634942	et	3	main
eluaspektid	doc_278690626933_item	3634941	et	3	main
kõige	doc_278690626933_item	3634940	et	4	main
et	doc_278690626933_item	3634939	et	3	main
näeme	doc_278690626933_item	3634938	et	3	main
me	doc_278690626933_item	3634937	et	4	main
pulma	doc_278690626933_item	3634936	et	4	main
mängib	doc_278690626933_item	3634935	et	3	main
maal	doc_278690626933_item	3634934	et	4	main
või	doc_278690626933_item	3634933	et	4	main
mängivad	doc_278690626933_item	3634932	et	4	main
töötavad	doc_278690626933_item	3634931	et	4	main
kui	doc_278690626933_item	3634930	et	3	main
laulavad	doc_278690626933_item	3634928	et	4	main
maales	doc_278690626933_item	3634929	et	3	main
regilaul	doc_278690626933_item	3634927	et	4	main
lihtne	doc_278690626933_item	3634921	et	3	main
arvan	doc_278690626933_item	3634912	et	3	main
saa	doc_278690626933_item	3634909	et	4	main
kes	doc_278690626933_item	3634905	et	4	main
ja	doc_278690626933_item	3634903	et	3	main
põhi	doc_278690626933_item	3634896	et	3	main
kultuuril	doc_278690626933_item	3634893	et	3	main
me	doc_278690626933_item	3634890	et	4	main
ajalugu	doc_278690626933_item	3634887	et	4	main
inimese	doc_278690626933_item	3634882	et	4	main
arvan	doc_278690626934_item	3635407	et	3	main
tema	doc_278690626934_item	3635402	et	4	main
muusikale	doc_278690626934_item	3635401	et	4	main
armastus	doc_278690626934_item	3635400	et	4	main
aga	doc_278690626934_item	3635393	et	3	main
palju	doc_278690626934_item	3635387	et	4	main
eestis	doc_278690626934_item	3635385	et	3	main
üritused	doc_278690626934_item	3635384	et	4	main
rahvamuusika	doc_278690626934_item	3635383	et	4	main
ajal	doc_278690626934_item	3635371	et	4	main
kogunema	doc_278690626934_item	3635352	et	3	main
meeldiv	doc_278690626934_item	3635351	et	4	main
laulpidu	doc_278690626934_item	3635345	et	4	main
sündmuseks	doc_278690626934_item	3635341	et	3	main
peole	doc_278690626934_item	3635334	et	4	main
või	doc_278690626934_item	3635323	et	4	main
pulm	doc_278690626934_item	3635322	et	3	main
sündis	doc_278690626934_item	3635321	et	3	main
see	doc_278690626934_item	3635320	et	3	main
olid	doc_278690626934_item	3635319	et	4	main
kas	doc_278690626934_item	3635318	et	3	main
on	doc_278690626934_item	3635412	et	4	main
eestirahvas	doc_278690626934_item	3635411	et	4	main
tulevikus	doc_278690626934_item	3635410	et	4	main
ka	doc_278690626934_item	3635409	et	3	main
et	doc_278690626934_item	3635408	et	3	main
tema	doc_278690626934_item	3635399	et	4	main
teeb	doc_278690626934_item	3635398	et	3	main
vedakse	doc_278690626934_item	3635390	et	4	main
eestirahv	doc_278690626934_item	3635372	et	4	main
oma	doc_278690626934_item	3635360	et	4	main
koos	doc_278690626934_item	3635354	et	4	main
esimene	doc_278690626934_item	3635343	et	3	main
kujunes	doc_278690626934_item	3635342	et	3	main
ajaloolise	doc_278690626934_item	3635339	et	4	main
rohkem	doc_278690626934_item	3635326	et	4	main
lauluga	doc_278690626934_item	3635317	et	4	main
ajalugu	doc_278690626934_item	3635315	et	4	main
oma	doc_278690626934_item	3635314	et	4	main
kogu	doc_278690626934_item	3635313	et	4	main
töötada	doc_278690626934_item	3635305	et	3	main
rahvale	doc_278690626934_item	3635293	et	3	main
et	doc_278690626934_item	3635291	et	3	main
eestirahv	doc_278690626934_item	3635273	et	4	main
kui	doc_278690626934_item	3635272	et	3	main
olema	doc_278690626934_item	3635225	et	4	main
essee	doc_278690626934_item	3635218	et	4	main
laulurahva	doc_278690626934_item	3635217	et	3	main
essee	doc_278690626934_item	3635212	et	4	main
kirjutage	doc_278690626934_item	3635211	et	3	main
kirjutamine	doc_278690626934_item	3635210	et	4	main
keele	doc_278690626934_item	3635205	et	4	main
essee	doc_278690626934_item	3635203	et	4	main
rahvalaul	doc_278690626934_item	3635262	et	4	main
rahvalaulude	doc_278690626934_item	3635256	et	3	main
poolnud	doc_278690626934_item	3635255	et	4	main
kultuuril	doc_278690626934_item	3635254	et	3	main
veendunud	doc_278690626935_item	3635530	et	4	main
saada	doc_278690626935_item	3635526	et	4	main
põlvest	doc_278690626935_item	3635505	et	4	main
pulmast	doc_278690626935_item	3635499	et	4	main
nad	doc_278690626935_item	3635498	et	3	main
laulsid	doc_278690626935_item	3635492	et	4	main
koor	doc_278690626935_item	3635486	et	4	main
eeslaulja	doc_278690626935_item	3635484	et	4	main
elada	doc_278690626935_item	3635483	et	3	main
lauluta	doc_278690626935_item	3635482	et	3	main
ilma	doc_278690626935_item	3635481	et	4	main
estlased	doc_278690626935_item	3635480	et	4	main
saa	doc_278690626935_item	3635479	et	4	main
ka	doc_278690626935_item	3635475	et	3	main
on	doc_278690626935_item	3635472	et	4	main
mängivad	doc_278690626935_item	3635457	et	4	main
elus	doc_278690626935_item	3635454	et	4	main
praeguses	doc_278690626935_item	3635453	et	3	main
näidetega	doc_278690626935_item	3635452	et	3	main
laul	doc_278690626934_item	3635336	et	4	main
kõigile	doc_278690626934_item	3635333	et	4	main
mehed	doc_278690626934_item	3635332	et	3	main
kui	doc_278690626934_item	3635331	et	3	main
lapsed	doc_278690626934_item	3635330	et	3	main
ja	doc_278690626934_item	3635329	et	3	main
naised	doc_278690626934_item	3635328	et	3	main
laulsid	doc_278690626934_item	3635327	et	4	main
tegis	doc_278690626934_item	3635306	et	4	main
laul	doc_278690626934_item	3635303	et	4	main
on	doc_278690626934_item	3635298	et	4	main
see	doc_278690626934_item	3635297	et	3	main
oleks	doc_278690626934_item	3635294	et	3	main
ajad	doc_278690626934_item	3635279	et	4	main
peab	doc_278690626934_item	3635224	et	4	main
kui	doc_278690626934_item	3635206	et	3	main
kelle	doc_278690626934_item	3635253	et	4	main
rahvu	doc_278690626934_item	3635252	et	4	main
ühtegi	doc_278690626934_item	3635251	et	4	main
öelda	doc_278690626934_item	3635250	et	4	main
saa	doc_278690626934_item	3635249	et	4	main
ei	doc_278690626934_item	3635248	et	4	main
ma	doc_278690626934_item	3635247	et	3	main
miks	doc_278690626934_item	3635246	et	4	main
aga	doc_278690626934_item	3635245	et	3	main
laulurahvaks	doc_278690626934_item	3635244	et	3	main
nimetatavad	doc_278690626934_item	3635243	et	4	main
enam	doc_278690626935_item	3635522	et	4	main
areneda	doc_278690626935_item	3635521	et	3	main
võimalus	doc_278690626935_item	3635520	et	3	main
põlva	doc_278690626935_item	3635506	et	4	main
pulma	doc_278690626935_item	3635500	et	4	main
et	doc_278690626935_item	3635494	et	3	main
liikumisega	doc_278690626935_item	3635490	et	4	main
laulu	doc_278690626935_item	3635488	et	4	main
esitasid	doc_278690626935_item	3635487	et	4	main
suurepäraselt	doc_278690626935_item	3635466	et	4	main
ka	doc_278690626935_item	3635465	et	3	main
on	doc_278690626935_item	3635464	et	4	main
eestlastest	doc_278690626935_item	3635428	et	4	main
eesti	doc_278690626935_item	3635416	et	4	main
paljud	doc_278690626936_item	3635711	et	3	main
tuli	doc_278690626936_item	3635706	et	4	main
laulsid	doc_278690626936_item	3635697	et	4	main
ilma	doc_278690626936_item	3635688	et	4	main
midagi	doc_278690626936_item	3635675	et	4	main
rahvalaulad	doc_278690626936_item	3635662	et	4	main
mis	doc_278690626936_item	3635624	et	4	main
üldistav	doc_278690626936_item	3635612	et	4	main
ja	doc_278690626936_item	3635611	et	3	main
erinevad	doc_278690626937_item	3635838	et	4	main
toimuvad	doc_278690626937_item	3635837	et	4	main
tänapäeval	doc_278690626937_item	3635836	et	3	main
oli	doc_278690626937_item	3635827	et	3	main
объеденить	doc_278690626937_item	3635823	et	2	main
toimusid	doc_278690626937_item	3635817	et	4	main
põlvides	doc_278690626937_item	3635813	et	3	main
inimesed	doc_278690626937_item	3635811	et	3	main
elada	doc_278690626937_item	3635810	et	3	main
tähtis	doc_278690626937_item	3635781	et	4	main
mina	doc_278690626937_item	3635773	et	4	main
teeb	doc_278690626937_item	3635743	et	3	main
keele	doc_278690626937_item	3635733	et	4	main
arm	doc_278690626938_item	3636054	et	3	main
isamaalaul	doc_278690626938_item	3636049	et	4	main
aastat	doc_278690626938_item	3636046	et	3	main
see	doc_278690626938_item	3636042	et	3	main
kõik	doc_278690626938_item	3636037	et	4	main
arvan	doc_278690626938_item	3636034	et	3	main
folkloore	doc_278690626938_item	3636001	et	4	main
kasutavad	doc_278690626938_item	3635989	et	4	main
jõudu	doc_278690626934_item	3635311	et	4	main
ja	doc_278690626934_item	3635309	et	3	main
puhkus	doc_278690626934_item	3635307	et	3	main
valjendusvahend	doc_278690626934_item	3635302	et	4	main
lauladeta	doc_278690626934_item	3635292	et	3	main
arvan	doc_278690626934_item	3635290	et	3	main
teda	doc_278690626934_item	3635288	et	4	main
ja	doc_278690626934_item	3635286	et	3	main
nad	doc_278690626934_item	3635281	et	3	main
aga	doc_278690626934_item	3635280	et	3	main
olid	doc_278690626934_item	3635277	et	4	main
vanaajas	doc_278690626934_item	3635276	et	3	main
juba	doc_278690626934_item	3635275	et	3	main
eestlastel	doc_278690626934_item	3635274	et	4	main
on	doc_278690626934_item	3635269	et	4	main
tihti	doc_278690626934_item	3635242	et	3	main
eestirahvu	doc_278690626934_item	3635241	et	4	main
näidetega	doc_278690626934_item	3635240	et	3	main
illustreerida	doc_278690626934_item	3635239	et	3	main
soovitatav	doc_278690626934_item	3635238	et	4	main
on	doc_278690626934_item	3635237	et	4	main
väiteid	doc_278690626934_item	3635236	et	4	main
faktidele	doc_278690626934_item	3635235	et	3	main
esitatud	doc_278690626934_item	3635234	et	4	main
lugemistekstis	doc_278690626934_item	3635233	et	3	main
ja	doc_278690626934_item	3635232	et	3	main
loengus	doc_278690626934_item	3635231	et	3	main
tuginema	doc_278690626934_item	3635230	et	3	main
üldistav	doc_278690626934_item	3635229	et	4	main
ja	doc_278690626934_item	3635228	et	3	main
analüüsiv	doc_278690626934_item	3635227	et	4	main
arutlev	doc_278690626934_item	3635226	et	4	main
350	doc_278690626934_item	3635221	et	2	main
test	doc_278690626934_item	3635209	et	3	main
on	doc_278690626934_item	3635260	et	4	main
eestlased	doc_278690626934_item	3635259	et	3	main
just	doc_278690626934_item	3635258	et	3	main
et	doc_278690626935_item	3635531	et	3	main
on	doc_278690626935_item	3635519	et	4	main
toimusid	doc_278690626935_item	3635516	et	4	main
laule	doc_278690626935_item	3635503	et	4	main
laulu	doc_278690626935_item	3635496	et	4	main
koos	doc_278690626935_item	3635489	et	4	main
tantsimisega	doc_278690626935_item	3635476	et	4	main
tänapäevases	doc_278690626935_item	3635462	et	4	main
kultuur	doc_278690626935_item	3635461	et	3	main
kombed	doc_278690626935_item	3635460	et	3	main
vanad	doc_278690626935_item	3635459	et	3	main
suurt	doc_278690626935_item	3635455	et	3	main
illustreerida	doc_278690626935_item	3635451	et	3	main
soovitatav	doc_278690626935_item	3635450	et	4	main
laulurahva	doc_278690626935_item	3635429	et	3	main
keele	doc_278690626935_item	3635417	et	4	main
rahvamuusikast	doc_278690626935_item	3635571	et	4	main
lihtsalt	doc_278690626935_item	3635570	et	4	main
ja	doc_278690626935_item	3635569	et	3	main
kombeid	doc_278690626935_item	3635584	et	4	main
ja	doc_278690626935_item	3635583	et	3	main
kultuuri	doc_278690626935_item	3635582	et	4	main
eesti	doc_278690626935_item	3635581	et	4	main
arendavad	doc_278690626935_item	3635580	et	4	main
praegu	doc_278690626935_item	3635579	et	3	main
ja	doc_278690626935_item	3635578	et	3	main
säilitasid	doc_278690626935_item	3635577	et	4	main
kes	doc_278690626935_item	3635576	et	4	main
estlasi	doc_278690626935_item	3635575	et	4	main
austada	doc_278690626935_item	3635574	et	3	main
olen	doc_278690626935_item	3635528	et	3	main
rahvast	doc_278690626935_item	3635524	et	4	main
oma	doc_278690626935_item	3635523	et	4	main
suuliselt	doc_278690626935_item	3635504	et	4	main
käisisid	doc_278690626935_item	3635497	et	4	main
tantsides	doc_278690626935_item	3635493	et	4	main
ja	doc_278690626935_item	3635485	et	3	main
seotud	doc_278690626935_item	3635477	et	4	main
laulmise	doc_278690626935_item	3635473	et	4	main
mis	doc_278690626935_item	3635471	et	4	main
traditsioonid	doc_278690626935_item	3635470	et	3	main
estlaste	doc_278690626935_item	3635469	et	4	main
vanad	doc_278690626935_item	3635468	et	3	main
eestis	doc_278690626935_item	3635463	et	3	main
traditsioonid	doc_278690626935_item	3635458	et	3	main
rolli	doc_278690626935_item	3635456	et	4	main
väiteid	doc_278690626935_item	3635448	et	4	main
faktidele	doc_278690626935_item	3635447	et	3	main
esitatud	doc_278690626935_item	3635446	et	4	main
lugemistekstis	doc_278690626935_item	3635445	et	3	main
ja	doc_278690626935_item	3635444	et	3	main
loengus	doc_278690626935_item	3635443	et	3	main
tuginema	doc_278690626935_item	3635442	et	3	main
üldistav	doc_278690626935_item	3635441	et	4	main
ja	doc_278690626935_item	3635440	et	3	main
analüüsiv	doc_278690626935_item	3635439	et	4	main
olema	doc_278690626935_item	3635437	et	4	main
arutlev	doc_278690626935_item	3635438	et	4	main
peab	doc_278690626935_item	3635436	et	4	main
essee	doc_278690626935_item	3635435	et	4	main
sõna	doc_278690626935_item	3635434	et	4	main
350	doc_278690626935_item	3635433	et	2	main
300	doc_278690626935_item	3635432	et	2	main
teeb	doc_278690626935_item	3635427	et	3	main
essee	doc_278690626935_item	3635424	et	4	main
kirjutamine	doc_278690626935_item	3635422	et	4	main
test	doc_278690626935_item	3635421	et	3	main
keele	doc_278690626935_item	3635420	et	4	main
teise	doc_278690626935_item	3635419	et	4	main
kui	doc_278690626935_item	3635418	et	3	main
ainult	doc_278690626935_item	3635573	et	4	main
võin	doc_278690626935_item	3635572	et	3	main
teha	doc_278690626936_item	3635708	et	3	main
idee	doc_278690626936_item	3635707	et	4	main
pärast	doc_278690626936_item	3635705	et	4	main
ja	doc_278690626936_item	3635704	et	3	main
laulda	doc_278690626936_item	3635703	et	4	main
kes	doc_278690626936_item	3635696	et	4	main
inimesed	doc_278690626936_item	3635695	et	3	main
laulu	doc_278690626936_item	3635689	et	4	main
mis	doc_278690626936_item	3635686	et	4	main
lauluvad	doc_278690626936_item	3635684	et	4	main
süüa	doc_278690626936_item	3635678	et	3	main
istuvad	doc_278690626936_item	3635671	et	4	main
laulsid	doc_278690626936_item	3635661	et	4	main
mehed	doc_278690626936_item	3635660	et	3	main
kui	doc_278690626936_item	3635657	et	3	main
paremini	doc_278690626936_item	3635655	et	4	main
ma	doc_278690626936_item	3635628	et	3	main
illustreerida	doc_278690626936_item	3635622	et	3	main
soovitatav	doc_278690626936_item	3635621	et	4	main
väiteid	doc_278690626936_item	3635619	et	4	main
faktidele	doc_278690626936_item	3635618	et	3	main
esitatud	doc_278690626936_item	3635617	et	4	main
lugemistekstis	doc_278690626936_item	3635616	et	3	main
ja	doc_278690626935_item	3635512	et	3	main
traditsioone	doc_278690626935_item	3635511	et	3	main
mäletama	doc_278690626935_item	3635510	et	3	main
peame	doc_278690626935_item	3635509	et	4	main
et	doc_278690626935_item	3635508	et	3	main
arvan	doc_278690626935_item	3635507	et	3	main
edastati	doc_278690626935_item	3635502	et	4	main
nii	doc_278690626935_item	3635501	et	3	main
edastada	doc_278690626935_item	3635495	et	3	main
inimesed	doc_278690626935_item	3635491	et	3	main
ei	doc_278690626935_item	3635478	et	4	main
ja	doc_278690626935_item	3635474	et	3	main
levinud	doc_278690626935_item	3635467	et	4	main
on	doc_278690626935_item	3635449	et	4	main
pikkus	doc_278690626935_item	3635431	et	4	main
mis	doc_278690626935_item	3635426	et	4	main
kirjutage	doc_278690626935_item	3635423	et	3	main
tänapäeval	doc_278690626936_item	3635710	et	3	main
inimesid	doc_278690626936_item	3635698	et	4	main
pidu	doc_278690626936_item	3635687	et	4	main
aga	doc_278690626936_item	3635685	et	3	main
nad	doc_278690626936_item	3635683	et	3	main
või	doc_278690626936_item	3635681	et	4	main
perele	doc_278690626936_item	3635680	et	3	main
kui	doc_278690626936_item	3635669	et	3	main
sõrm	doc_278690626936_item	3635659	et	3	main
teeb	doc_278690626936_item	3635625	et	3	main
on	doc_278690626936_item	3635620	et	4	main
folklööri	doc_278690626937_item	3635839	et	4	main
see	doc_278690626937_item	3635826	et	3	main
erinevad	doc_278690626937_item	3635818	et	4	main
kodus	doc_278690626937_item	3635815	et	4	main
laulasid	doc_278690626937_item	3635812	et	4	main
aitas	doc_278690626937_item	3635809	et	3	main
laulmine	doc_278690626937_item	3635808	et	4	main
tähtis	doc_278690626937_item	3635803	et	4	main
ja	doc_278690626937_item	3635802	et	3	main
suur	doc_278690626937_item	3635801	et	3	main
väga	doc_278690626937_item	3635800	et	3	main
olemas	doc_278690626937_item	3635799	et	4	main
muusika	doc_278690626937_item	3635796	et	4	main
ja	doc_278690626937_item	3635777	et	3	main
laulurahva	doc_278690626937_item	3635772	et	3	main
teise	doc_278690626937_item	3635735	et	4	main
kui	doc_278690626937_item	3635734	et	3	main
ma	doc_278690626938_item	3636062	et	3	main
sest	doc_278690626938_item	3636058	et	4	main
isamaa	doc_278690626938_item	3636051	et	4	main
rahvahingu	doc_278690626938_item	3636044	et	4	main
ja	doc_278690626938_item	3636041	et	3	main
sellepärast	doc_278690626938_item	3636035	et	3	main
jaok	doc_278690626938_item	3636032	et	4	main
tähtis	doc_278690626938_item	3636028	et	4	main
on	doc_278690626938_item	3636026	et	4	main
ja	doc_278690626938_item	3636024	et	3	main
toimuvad	doc_278690626938_item	3636000	et	4	main
on	doc_278690626938_item	3635995	et	4	main
linnades	doc_278690626938_item	3635994	et	3	main
kõikides	doc_278690626938_item	3635993	et	4	main
omas	doc_278690626938_item	3635991	et	4	main
elavad	doc_278690626938_item	3635975	et	4	main
on	doc_278690626938_item	3635971	et	4	main
laulda	doc_278690626938_item	3635969	et	4	main
aitas	doc_278690626938_item	3635967	et	3	main
see	doc_278690626938_item	3635961	et	3	main
oleks	doc_278690626938_item	3635960	et	3	main
ka	doc_278690626938_item	3635957	et	3	main
laulu	doc_278690626938_item	3635948	et	4	main
mere	doc_278690626938_item	3635928	et	3	main
oma	doc_278690626938_item	3635924	et	4	main
seletada	doc_278690626938_item	3635923	et	3	main
proovin	doc_278690626938_item	3635922	et	3	main
laulurahva	doc_278690626938_item	3635921	et	3	main
neid	doc_278690626938_item	3635920	et	4	main
teeb	doc_278690626938_item	3635919	et	3	main
alati	doc_278690626938_item	3635911	et	4	main
ajal	doc_278690626938_item	3635910	et	4	main
kui	doc_278690626938_item	3635906	et	3	main
olema	doc_278690626939_item	3636095	et	4	main
300	doc_278690626939_item	3636090	et	2	main
teeb	doc_278690626939_item	3636085	et	3	main
teemal	doc_278690626939_item	3636083	et	3	main
essee	doc_278690626935_item	3635430	et	4	main
teemal	doc_278690626935_item	3635425	et	3	main
essee	doc_278690626935_item	3635415	et	4	main
rahvalaulust	doc_278690626935_item	3635568	et	4	main
eesti	doc_278690626935_item	3635567	et	4	main
naudingut	doc_278690626935_item	3635566	et	3	main
tunnevad	doc_278690626935_item	3635565	et	3	main
sakslased	doc_278690626935_item	3635564	et	3	main
rootslased	doc_278690626935_item	3635563	et	3	main
soomlased	doc_278690626935_item	3635562	et	3	main
välismaalased	doc_278690626935_item	3635561	et	3	main
külastavad	doc_278690626935_item	3635560	et	4	main
tihti	doc_278690626935_item	3635559	et	3	main
lauluväljakul	doc_278690626935_item	3635558	et	3	main
tallinna	doc_278690626935_item	3635557	et	4	main
toimuvad	doc_278690626935_item	3635556	et	4	main
mis	doc_278690626935_item	3635555	et	4	main
festifale	doc_278690626935_item	3635554	et	4	main
nissuguseid	doc_278690626935_item	3635553	et	4	main
tantsides	doc_278690626935_item	3635552	et	4	main
ja	doc_278690626935_item	3635551	et	3	main
lauldes	doc_278690626935_item	3635550	et	3	main
rahvalaulu	doc_278690626935_item	3635549	et	4	main
veeda	doc_278690626935_item	3635548	et	4	main
aega	doc_278690626935_item	3635547	et	4	main
hästi	doc_278690626935_item	3635546	et	3	main
võivad	doc_278690626935_item	3635545	et	4	main
inimesed	doc_278690626935_item	3635544	et	3	main
kus	doc_278690626935_item	3635543	et	3	main
folkloorefestivaale	doc_278690626935_item	3635542	et	4	main
korraldatakse	doc_278690626935_item	3635541	et	3	main
tihti	doc_278690626935_item	3635540	et	3	main
poole	doc_278690626935_item	3635539	et	4	main
ja	doc_278690626935_item	3635537	et	3	main
rahvamuusika	doc_278690626935_item	3635538	et	4	main
rahvalaulu	doc_278690626935_item	3635536	et	4	main
pöördakse	doc_278690626935_item	3635535	et	4	main
praegu	doc_278690626935_item	3635534	et	3	main
tähelepanu	doc_278690626935_item	3635533	et	4	main
helilojad	doc_278690626936_item	3635712	et	4	main
koos	doc_278690626936_item	3635702	et	4	main
et	doc_278690626936_item	3635701	et	3	main
kogunema	doc_278690626936_item	3635700	et	3	main
hakkasid	doc_278690626936_item	3635699	et	4	main
ajal	doc_278690626936_item	3635691	et	4	main
rahvalaulud	doc_278690626936_item	3635729	et	3	main
oma	doc_278690626936_item	3635728	et	4	main
on	doc_278690626936_item	3635727	et	4	main
meil	doc_278690626936_item	3635726	et	4	main
et	doc_278690626936_item	3635725	et	3	main
tähtis	doc_278690626936_item	3635724	et	4	main
väga	doc_278690626936_item	3635723	et	3	main
on	doc_278690626936_item	3635722	et	4	main
see	doc_278690626936_item	3635721	et	3	main
et	doc_278690626936_item	3635720	et	3	main
mõtlen	doc_278690626936_item	3635719	et	3	main
ma	doc_278690626936_item	3635718	et	3	main
teostes	doc_278690626936_item	3635717	et	3	main
oma	doc_278690626936_item	3635716	et	4	main
meloodiad	doc_278690626936_item	3635715	et	3	main
rahvalaulud	doc_278690626936_item	3635714	et	3	main
kasutavad	doc_278690626936_item	3635713	et	4	main
laulupidu	doc_278690626936_item	3635709	et	4	main
tuleksisid	doc_278690626936_item	3635694	et	4	main
pulmas	doc_278690626936_item	3635693	et	3	main
igal	doc_278690626936_item	3635692	et	3	main
vanal	doc_278690626936_item	3635690	et	3	main
õmblevad	doc_278690626936_item	3635682	et	4	main
teevad	doc_278690626936_item	3635677	et	3	main
naised	doc_278690626936_item	3635670	et	3	main
ja	doc_278690626936_item	3635667	et	3	main
oma	doc_278690626936_item	3635665	et	4	main
mõtlesid	doc_278690626936_item	3635664	et	4	main
ja	doc_278690626936_item	3635663	et	3	main
natukest	doc_278690626936_item	3635654	et	4	main
saaks	doc_278690626936_item	3635653	et	3	main
ta	doc_278690626936_item	3635652	et	4	main
ja	doc_278690626936_item	3635651	et	3	main
laulab	doc_278690626936_item	3635650	et	3	main
ta	doc_278690626936_item	3635649	et	4	main
raske	doc_278690626936_item	3635648	et	4	main
on	doc_278690626936_item	3635647	et	4	main
kellegi	doc_278690626936_item	3635646	et	4	main
naiteks	doc_278690626936_item	3635645	et	4	main
kui	doc_278690626936_item	3635644	et	3	main
elada	doc_278690626936_item	3635643	et	3	main
aitab	doc_278690626936_item	3635642	et	3	main
laul	doc_278690626936_item	3635641	et	4	main
rahvalaulud	doc_278690626936_item	3635640	et	3	main
oma	doc_278690626936_item	3635639	et	4	main
on	doc_278690626936_item	3635638	et	4	main
rahval	doc_278690626936_item	3635637	et	3	main
iga	doc_278690626936_item	3635636	et	4	main
et	doc_278690626936_item	3635635	et	3	main
tähtis	doc_278690626936_item	3635634	et	4	main
väga	doc_278690626936_item	3635633	et	3	main
see	doc_278690626936_item	3635631	et	3	main
et	doc_278690626936_item	3635630	et	3	main
on	doc_278690626936_item	3635632	et	4	main
oma	doc_278690626936_item	3635679	et	4	main
naitesk	doc_278690626936_item	3635676	et	4	main
teevad	doc_278690626936_item	3635674	et	3	main
ja	doc_278690626936_item	3635673	et	3	main
kodus	doc_278690626936_item	3635672	et	4	main
perest	doc_278690626936_item	3635668	et	4	main
kodust	doc_278690626936_item	3635666	et	4	main
oli	doc_278690626936_item	3635658	et	3	main
või	doc_278690626936_item	3635656	et	4	main
arvan	doc_278690626936_item	3635629	et	3	main
laulurahva	doc_278690626936_item	3635627	et	3	main
näidetega	doc_278690626936_item	3635623	et	3	main
analüüsiv	doc_278690626936_item	3635610	et	4	main
eestlastest	doc_278690626936_item	3635626	et	4	main
arutlev	doc_278690626936_item	3635609	et	4	main
olema	doc_278690626936_item	3635608	et	4	main
peab	doc_278690626936_item	3635607	et	4	main
essee	doc_278690626936_item	3635606	et	4	main
sõna	doc_278690626936_item	3635605	et	4	main
350	doc_278690626936_item	3635604	et	2	main
300	doc_278690626936_item	3635603	et	2	main
pikkus	doc_278690626936_item	3635602	et	4	main
essee	doc_278690626936_item	3635601	et	4	main
laulurahva	doc_278690626936_item	3635600	et	3	main
eestlastest	doc_278690626936_item	3635599	et	4	main
teeb	doc_278690626936_item	3635598	et	3	main
mis	doc_278690626936_item	3635597	et	4	main
teemal	doc_278690626936_item	3635596	et	3	main
essee	doc_278690626936_item	3635595	et	4	main
kirjutage	doc_278690626936_item	3635594	et	3	main
kirjutamine	doc_278690626936_item	3635593	et	4	main
test	doc_278690626936_item	3635592	et	3	main
keele	doc_278690626936_item	3635591	et	4	main
teise	doc_278690626936_item	3635590	et	4	main
kui	doc_278690626936_item	3635589	et	3	main
keele	doc_278690626936_item	3635588	et	4	main
eesti	doc_278690626936_item	3635587	et	4	main
essee	doc_278690626936_item	3635586	et	4	main
tavalises	doc_278690626937_item	3635835	et	4	main
nii	doc_278690626937_item	3635834	et	3	main
inimestele	doc_278690626937_item	3635830	et	3	main
ka	doc_278690626937_item	3635821	et	3	main
mis	doc_278690626937_item	3635820	et	4	main
muusika	doc_278690626937_item	3635807	et	4	main
varem	doc_278690626937_item	3635806	et	4	main
iga	doc_278690626937_item	3635794	et	4	main
et	doc_278690626937_item	3635793	et	3	main
ka	doc_278690626937_item	3635789	et	3	main
väljendusvahendid	doc_278690626937_item	3635788	et	3	main
emotsionaalsed	doc_278690626937_item	3635787	et	3	main
ja	doc_278690626937_item	3635786	et	3	main
esteetilised	doc_278690626937_item	3635785	et	3	main
näitab	doc_278690626937_item	3635784	et	3	main
ta	doc_278690626937_item	3635783	et	4	main
kultuuris	doc_278690626937_item	3635782	et	3	main
laulurahva	doc_278690626937_item	3635778	et	3	main
arvan	doc_278690626937_item	3635774	et	3	main
keele	doc_278690626937_item	3635736	et	4	main
ja	doc_278690626936_item	3635615	et	3	main
loengus	doc_278690626936_item	3635614	et	3	main
tuginema	doc_278690626936_item	3635613	et	3	main
väga	doc_278690626937_item	3635828	et	3	main
erinevad	doc_278690626937_item	3635824	et	4	main
laulupeod	doc_278690626937_item	3635819	et	4	main
on	doc_278690626937_item	3635798	et	4	main
väga	doc_278690626937_item	3635780	et	3	main
et	doc_278690626937_item	3635775	et	3	main
eestlastest	doc_278690626937_item	3635744	et	4	main
teemal	doc_278690626937_item	3635741	et	3	main
eesti	doc_278690626937_item	3635732	et	4	main
essee	doc_278690626937_item	3635731	et	4	main
laulab	doc_278690626938_item	3636056	et	3	main
eestirahvas	doc_278690626938_item	3636055	et	4	main
minu	doc_278690626938_item	3636053	et	3	main
on	doc_278690626938_item	3636052	et	4	main
pärast	doc_278690626938_item	3636047	et	4	main
väga	doc_278690626938_item	3636027	et	3	main
see	doc_278690626938_item	3636025	et	3	main
näiteks	doc_278690626938_item	3636003	et	4	main
festivaalid	doc_278690626938_item	3636002	et	4	main
ansambel	doc_278690626938_item	3635997	et	3	main
oma	doc_278690626938_item	3635996	et	4	main
hääli	doc_278690626938_item	3635982	et	4	main
looduse	doc_278690626938_item	3635981	et	4	main
inimesed	doc_278690626938_item	3635974	et	3	main
kuna	doc_278690626938_item	3635965	et	3	main
ajal	doc_278690626938_item	3635964	et	4	main
et	doc_278690626938_item	3635958	et	3	main
ta	doc_278690626938_item	3635955	et	4	main
ja	doc_278690626938_item	3635954	et	3	main
kalapüüdmisel	doc_278690626938_item	3635953	et	3	main
meres	doc_278690626938_item	3635952	et	3	main
mees	doc_278690626938_item	3635951	et	4	main
lapsele	doc_278690626938_item	3635947	et	4	main
oma	doc_278690626938_item	3635946	et	4	main
laulab	doc_278690626938_item	3635944	et	3	main
kaldale	doc_278690626938_item	3635932	et	4	main
jooksevad	doc_278690626938_item	3635931	et	4	main
lained	doc_278690626938_item	3635930	et	3	main
eestimaa	doc_278690626938_item	3635926	et	4	main
töö	doc_278690626938_item	3635914	et	4	main
meie	doc_278690626938_item	3635909	et	4	main
alati	doc_278690626938_item	3635905	et	4	main
test	doc_278690626938_item	3635870	et	3	main
keele	doc_278690626938_item	3635869	et	4	main
sõna	doc_278690626939_item	3636092	et	4	main
essee	doc_278690626939_item	3636088	et	4	main
laulurahva	doc_278690626939_item	3636087	et	3	main
mis	doc_278690626939_item	3636084	et	4	main
essee	doc_278690626939_item	3636082	et	4	main
eesti	doc_278690626939_item	3636074	et	4	main
kõige	doc_278690626939_item	3636217	et	4	main
eestiline	doc_278690626939_item	3636211	et	3	main
kestnud	doc_278690626939_item	3636198	et	4	main
aastat	doc_278690626939_item	3636197	et	3	main
laulupidu	doc_278690626939_item	3636193	et	4	main
1994	doc_278690626939_item	3636187	et	2	main
pillimängijani	doc_278690626939_item	3636186	et	3	main
ja	doc_278690626939_item	3636185	et	3	main
000	doc_278690626939_item	3636183	et	2	main
000	doc_278690626939_item	3636181	et	2	main
ja	doc_278690626939_item	3636150	et	3	main
tingimustest	doc_278690626939_item	3636147	et	3	main
korra	doc_278690626939_item	3636146	et	4	main
nõukogude	doc_278690626939_item	3636145	et	3	main
pidustused	doc_278690626939_item	3636144	et	3	main
olid	doc_278690626939_item	3636143	et	4	main
mehed	doc_278690626939_item	3636136	et	3	main
ka	doc_278690626939_item	3636126	et	3	main
meldib	doc_278690626939_item	3636125	et	4	main
aega	doc_278690626939_item	3636117	et	4	main
palju	doc_278690626939_item	3636116	et	4	main
eestlased	doc_278690626939_item	3636115	et	3	main
laulutraditsioonid	doc_278690626939_item	3636114	et	3	main
palju	doc_278690626939_item	3636113	et	4	main
või	doc_278690626937_item	3635857	et	4	main
festivallil	doc_278690626937_item	3635856	et	4	main
kontserdil	doc_278690626937_item	3635855	et	3	main
käib	doc_278690626937_item	3635854	et	3	main
inimene	doc_278690626937_item	3635853	et	3	main
kui	doc_278690626937_item	3635852	et	3	main
inimestele	doc_278690626937_item	3635851	et	3	main
kasulik	doc_278690626937_item	3635850	et	3	main
väga	doc_278690626937_item	3635849	et	3	main
mõjub	doc_278690626937_item	3635848	et	3	main
et	doc_278690626937_item	3635846	et	3	main
see	doc_278690626937_item	3635847	et	3	main
kindel	doc_278690626937_item	3635845	et	3	main
olen	doc_278690626937_item	3635844	et	3	main
eestis	doc_278690626937_item	3635843	et	3	main
konkursid	doc_278690626937_item	3635842	et	3	main
ja	doc_278690626937_item	3635841	et	3	main
festivallid	doc_278690626937_item	3635840	et	4	main
ennas	doc_278690626937_item	3635862	et	4	main
areneb	doc_278690626937_item	3635861	et	3	main
kindlasti	doc_278690626937_item	3635860	et	3	main
siis	doc_278690626937_item	3635859	et	3	main
konkursil	doc_278690626937_item	3635858	et	3	main
plaanis	doc_278690626937_item	3635833	et	4	main
poliitilises	doc_278690626937_item	3635832	et	3	main
kui	doc_278690626937_item	3635831	et	3	main
kasulik	doc_278690626937_item	3635829	et	3	main
rahvad	doc_278690626937_item	3635825	et	3	main
aitab	doc_278690626937_item	3635822	et	3	main
varem	doc_278690626937_item	3635816	et	4	main
tööl	doc_278690626937_item	3635814	et	3	main
näiteks	doc_278690626937_item	3635805	et	4	main
roll	doc_278690626937_item	3635804	et	3	main
üldse	doc_278690626937_item	3635797	et	3	main
elus	doc_278690626937_item	3635795	et	4	main
arvan	doc_278690626937_item	3635792	et	3	main
traditsioonid	doc_278690626937_item	3635791	et	3	main
iseloomulik	doc_278690626937_item	3635790	et	3	main
on	doc_278690626937_item	3635779	et	4	main
laulmine	doc_278690626937_item	3635776	et	4	main
eestlastest	doc_278690626937_item	3635771	et	4	main
mis	doc_278690626937_item	3635769	et	4	main
näidetega	doc_278690626937_item	3635768	et	3	main
teeb	doc_278690626937_item	3635770	et	3	main
illustreerida	doc_278690626937_item	3635767	et	3	main
soovitatav	doc_278690626937_item	3635766	et	4	main
on	doc_278690626937_item	3635765	et	4	main
väiteid	doc_278690626937_item	3635764	et	4	main
faktidele	doc_278690626937_item	3635763	et	3	main
esitatud	doc_278690626937_item	3635762	et	4	main
lugemistekstis	doc_278690626937_item	3635761	et	3	main
ja	doc_278690626937_item	3635760	et	3	main
loengus	doc_278690626937_item	3635759	et	3	main
tuginema	doc_278690626937_item	3635758	et	3	main
üldistav	doc_278690626937_item	3635757	et	4	main
analüüsiv	doc_278690626937_item	3635755	et	4	main
ja	doc_278690626937_item	3635756	et	3	main
arutlev	doc_278690626937_item	3635754	et	4	main
olema	doc_278690626937_item	3635753	et	4	main
peab	doc_278690626937_item	3635752	et	4	main
essee	doc_278690626937_item	3635751	et	4	main
sõna	doc_278690626937_item	3635750	et	4	main
350	doc_278690626937_item	3635749	et	2	main
300	doc_278690626937_item	3635748	et	2	main
pikkus	doc_278690626937_item	3635747	et	4	main
essee	doc_278690626937_item	3635746	et	4	main
laulurahva	doc_278690626937_item	3635745	et	3	main
mis	doc_278690626937_item	3635742	et	4	main
essee	doc_278690626937_item	3635740	et	4	main
kirjutage	doc_278690626937_item	3635739	et	3	main
kirjutamine	doc_278690626937_item	3635738	et	4	main
test	doc_278690626937_item	3635737	et	3	main
kõlas	doc_278690626938_item	3636048	et	4	main
kogunesid	doc_278690626938_item	3636038	et	4	main
sündmus	doc_278690626938_item	3636029	et	3	main
folkloor	doc_278690626938_item	3635984	et	4	main
aga	doc_278690626938_item	3635983	et	3	main
suuredes	doc_278690626938_item	3635976	et	4	main
laulavana	doc_278690626938_item	3636071	et	3	main
tema	doc_278690626938_item	3636070	et	4	main
teeb	doc_278690626938_item	3636069	et	3	main
inimest	doc_278690626938_item	3636068	et	3	main
ümbertseb	doc_278690626938_item	3636067	et	4	main
mis	doc_278690626938_item	3636066	et	4	main
kõik	doc_278690626938_item	3636065	et	4	main
et	doc_278690626938_item	3636064	et	3	main
arvan	doc_278690626938_item	3636063	et	3	main
südas	doc_278690626938_item	3636061	et	4	main
tema	doc_278690626938_item	3636060	et	4	main
laul	doc_278690626938_item	3636059	et	4	main
alati	doc_278690626938_item	3636057	et	4	main
mu	doc_278690626938_item	3636050	et	3	main
sada	doc_278690626938_item	3636045	et	4	main
tugines	doc_278690626938_item	3636043	et	3	main
peol	doc_278690626938_item	3636040	et	4	main
sellel	doc_278690626938_item	3636039	et	4	main
et	doc_278690626938_item	3636036	et	3	main
ma	doc_278690626938_item	3636033	et	3	main
eestlaste	doc_278690626938_item	3636031	et	4	main
kõigi	doc_278690626938_item	3636030	et	4	main
tartus	doc_278690626938_item	3636023	et	3	main
oli	doc_278690626938_item	3636022	et	3	main
esimene	doc_278690626938_item	3636021	et	3	main
laulupeod	doc_278690626938_item	3636020	et	4	main
toimuvad	doc_278690626938_item	3636019	et	4	main
aastast	doc_278690626938_item	3636018	et	4	main
1869	doc_278690626938_item	3636017	et	2	main
alates	doc_278690626938_item	3636016	et	3	main
eestist	doc_278690626938_item	3636015	et	3	main
kogu	doc_278690626938_item	3636014	et	4	main
koored	doc_278690626938_item	3636013	et	3	main
ja	doc_278690626938_item	3636012	et	3	main
lauljad	doc_278690626938_item	3636011	et	4	main
osalevad	doc_278690626938_item	3636010	et	4	main
kus	doc_278690626938_item	3636009	et	3	main
viljandis	doc_278690626938_item	3636008	et	4	main
festivaal	doc_278690626938_item	3636007	et	4	main
folkloore	doc_278690626938_item	3636006	et	4	main
kuulsam	doc_278690626938_item	3636005	et	4	main
kõige	doc_278690626938_item	3636004	et	4	main
aasta	doc_278690626938_item	3635999	et	4	main
iga	doc_278690626938_item	3635998	et	4	main
loominguses	doc_278690626938_item	3635992	et	4	main
seda	doc_278690626938_item	3635990	et	3	main
helilooja	doc_278690626938_item	3635988	et	4	main
paljud	doc_278690626938_item	3635987	et	3	main
moes	doc_278690626938_item	3635986	et	3	main
jälle	doc_278690626938_item	3635985	et	3	main
ei	doc_278690626938_item	3635979	et	4	main
ja	doc_278690626938_item	3635978	et	3	main
linnades	doc_278690626938_item	3635977	et	3	main
teistmoodi	doc_278690626938_item	3635972	et	3	main
nüüd	doc_278690626938_item	3635970	et	4	main
inimestel	doc_278690626938_item	3635968	et	3	main
tasakeselt	doc_278690626938_item	3635945	et	4	main
ja	doc_278690626938_item	3635943	et	3	main
ees	doc_278690626938_item	3635942	et	4	main
asub	doc_278690626938_item	3635927	et	3	main
moodi	doc_278690626938_item	3635925	et	4	main
laulavad	doc_278690626938_item	3635913	et	4	main
nad	doc_278690626938_item	3635912	et	3	main
nii	doc_278690626938_item	3635908	et	3	main
vanasti	doc_278690626938_item	3635907	et	3	main
essee	doc_278690626939_item	3636093	et	4	main
pikkus	doc_278690626939_item	3636089	et	4	main
keele	doc_278690626939_item	3636075	et	4	main
tähendavad	doc_278690626939_item	3636225	et	4	main
praegusel	doc_278690626939_item	3636215	et	3	main
ka	doc_278690626939_item	3636214	et	3	main
on	doc_278690626939_item	3636213	et	4	main
000	doc_278690626939_item	3636208	et	2	main
000	doc_278690626939_item	3636205	et	2	main
laulis	doc_278690626939_item	3636202	et	4	main
laulupidude	doc_278690626939_item	3636199	et	4	main
laulja	doc_278690626939_item	3636184	et	4	main
30	doc_278690626939_item	3636182	et	2	main
25	doc_278690626939_item	3636180	et	2	main
arv	doc_278690626939_item	3636179	et	3	main
kuula	doc_278690626938_item	3635980	et	4	main
paljud	doc_278690626938_item	3635973	et	3	main
loodus	doc_278690626938_item	3635966	et	4	main
vanal	doc_278690626938_item	3635963	et	3	main
oli	doc_278690626938_item	3635962	et	3	main
rõõmsaks	doc_278690626938_item	3635959	et	3	main
laulab	doc_278690626938_item	3635956	et	3	main
lapsevoodi	doc_278690626938_item	3635941	et	4	main
naine	doc_278690626938_item	3635940	et	3	main
istub	doc_278690626938_item	3635939	et	3	main
ääres	doc_278690626938_item	3635929	et	4	main
tema	doc_278690626938_item	3635950	et	4	main
aga	doc_278690626938_item	3635949	et	3	main
õht	doc_278690626938_item	3635938	et	4	main
puuoksadega	doc_278690626938_item	3635937	et	3	main
mängib	doc_278690626938_item	3635936	et	3	main
uul	doc_278690626938_item	3635935	et	4	main
loks	doc_278690626938_item	3635934	et	3	main
loks	doc_278690626938_item	3635933	et	3	main
mis	doc_278690626938_item	3635918	et	4	main
pidutsedes	doc_278690626938_item	3635917	et	3	main
nii	doc_278690626938_item	3635916	et	3	main
tehes	doc_278690626938_item	3635915	et	3	main
laulurahvas	doc_278690626938_item	3635904	et	4	main
on	doc_278690626938_item	3635903	et	4	main
eestlased	doc_278690626938_item	3635902	et	3	main
näidetega	doc_278690626938_item	3635901	et	3	main
illustreerida	doc_278690626938_item	3635900	et	3	main
soovitatav	doc_278690626938_item	3635899	et	4	main
on	doc_278690626938_item	3635898	et	4	main
väiteid	doc_278690626938_item	3635897	et	4	main
faktidele	doc_278690626938_item	3635896	et	3	main
esitatud	doc_278690626938_item	3635895	et	4	main
lugemistekstis	doc_278690626938_item	3635894	et	3	main
ja	doc_278690626938_item	3635893	et	3	main
loengus	doc_278690626938_item	3635892	et	3	main
tuginema	doc_278690626938_item	3635891	et	3	main
üldistav	doc_278690626938_item	3635890	et	4	main
ja	doc_278690626938_item	3635889	et	3	main
analüüsiv	doc_278690626938_item	3635888	et	4	main
arutlev	doc_278690626938_item	3635887	et	4	main
olema	doc_278690626938_item	3635886	et	4	main
peab	doc_278690626938_item	3635885	et	4	main
essee	doc_278690626938_item	3635884	et	4	main
sõna	doc_278690626938_item	3635883	et	4	main
350	doc_278690626938_item	3635882	et	2	main
300	doc_278690626938_item	3635881	et	2	main
pikkus	doc_278690626938_item	3635880	et	4	main
essee	doc_278690626938_item	3635879	et	4	main
laulurahva	doc_278690626938_item	3635878	et	3	main
eestlastest	doc_278690626938_item	3635877	et	4	main
teeb	doc_278690626938_item	3635876	et	3	main
mis	doc_278690626938_item	3635875	et	4	main
teemal	doc_278690626938_item	3635874	et	3	main
essee	doc_278690626938_item	3635873	et	4	main
kirjutage	doc_278690626938_item	3635872	et	3	main
kirjutamine	doc_278690626938_item	3635871	et	4	main
teise	doc_278690626938_item	3635868	et	4	main
kui	doc_278690626938_item	3635867	et	3	main
keele	doc_278690626938_item	3635866	et	4	main
eesti	doc_278690626938_item	3635865	et	4	main
essee	doc_278690626938_item	3635864	et	4	main
350	doc_278690626939_item	3636091	et	2	main
eestlastest	doc_278690626939_item	3636086	et	4	main
kirjutamine	doc_278690626939_item	3636080	et	4	main
test	doc_278690626939_item	3636079	et	3	main
keele	doc_278690626939_item	3636078	et	4	main
laulupeod	doc_278690626939_item	3636224	et	4	main
ajal	doc_278690626939_item	3636216	et	4	main
pealtvaatajale	doc_278690626939_item	3636209	et	3	main
25	doc_278690626939_item	3636204	et	2	main
125	doc_278690626939_item	3636196	et	2	main
valitsuse	doc_278690626939_item	3636151	et	4	main
alates	doc_278690626939_item	3636137	et	3	main
laulavad	doc_278690626939_item	3636133	et	4	main
neile	doc_278690626939_item	3636124	et	4	main
koored	doc_278690626939_item	3636123	et	3	main
suured	doc_278690626939_item	3636122	et	3	main
teevad	doc_278690626939_item	3636121	et	3	main
nad	doc_278690626939_item	3636120	et	3	main
laulal	doc_278690626939_item	3636119	et	4	main
tuhanded	doc_278690626942_item	3636613	et	3	main
eesti	doc_278690626942_item	3636606	et	4	main
mille	doc_278690626942_item	3636604	et	3	main
märksõna	doc_278690626942_item	3636603	et	4	main
üks	doc_278690626942_item	3636602	et	3	main
on	doc_278690626942_item	3636580	et	4	main
aastal	doc_278690626942_item	3636534	et	3	main
toimunud	doc_278690626942_item	3636532	et	4	main
üldlaulupidu	doc_278690626942_item	3636531	et	4	main
mis	doc_278690626942_item	3636521	et	4	main
on	doc_278690626942_item	3636517	et	4	main
faktidele	doc_278690626942_item	3636515	et	3	main
peab	doc_278690626939_item	3636094	et	4	main
teise	doc_278690626939_item	3636077	et	4	main
kui	doc_278690626939_item	3636076	et	3	main
neile	doc_278690626939_item	3636226	et	4	main
üle	doc_278690626939_item	3636210	et	3	main
esinejat	doc_278690626939_item	3636206	et	4	main
seal	doc_278690626939_item	3636201	et	4	main
traditsiooni	doc_278690626939_item	3636200	et	4	main
et	doc_278690626939_item	3636194	et	3	main
osavõtjate	doc_278690626939_item	3636178	et	3	main
suurenes	doc_278690626939_item	3636177	et	4	main
esinemised	doc_278690626939_item	3636176	et	4	main
poistekooride	doc_278690626939_item	3636175	et	3	main
ja	doc_278690626939_item	3636174	et	3	main
lastekooride	doc_278690626939_item	3636173	et	3	main
ka	doc_278690626939_item	3636172	et	3	main
lülitati	doc_278690626939_item	3636171	et	4	main
kavva	doc_278690626939_item	3636170	et	3	main
et	doc_278690626939_item	3636169	et	3	main
laule	doc_278690626939_item	3636168	et	4	main
propagandistlikke	doc_278690626939_item	3636167	et	3	main
pealesunnitud	doc_278690626939_item	3636166	et	4	main
palju	doc_278690626939_item	3636165	et	4	main
tuli	doc_278690626939_item	3636164	et	4	main
laulda	doc_278690626939_item	3636163	et	4	main
ja	doc_278690626939_item	3636162	et	3	main
reeglid	doc_278690626939_item	3636161	et	3	main
ranged	doc_278690626939_item	3636160	et	3	main
kehtestati	doc_278690626939_item	3636159	et	3	main
osas	doc_278690626939_item	3636158	et	4	main
repertuari	doc_278690626939_item	3636157	et	4	main
all	doc_278690626939_item	3636156	et	3	main
suunamise	doc_278690626939_item	3636155	et	4	main
ja	doc_278690626939_item	3636154	et	3	main
kontrolli	doc_278690626939_item	3636153	et	4	main
range	doc_278690626939_item	3636152	et	4	main
partei	doc_278690626939_item	3636149	et	4	main
kommunistliku	doc_278690626939_item	3636148	et	3	main
toimunud	doc_278690626939_item	3636140	et	4	main
aastal	doc_278690626939_item	3636139	et	3	main
1947	doc_278690626939_item	3636138	et	2	main
rohkem	doc_278690626939_item	3636134	et	4	main
naised	doc_278690626939_item	3636132	et	3	main
põhiliselt	doc_278690626939_item	3636131	et	4	main
tantsuga	doc_278690626939_item	3636130	et	3	main
koos	doc_278690626939_item	3636129	et	4	main
kirjutage	doc_278690626939_item	3636081	et	3	main
essee	doc_278690626939_item	3636073	et	4	main
palju	doc_278690626939_item	3636228	et	4	main
väga	doc_278690626939_item	3636227	et	3	main
eestis	doc_278690626939_item	3636223	et	3	main
manifestatsioon	doc_278690626939_item	3636222	et	3	main
rahvusluse	doc_278690626939_item	3636221	et	4	main
massilisem	doc_278690626939_item	3636220	et	4	main
ja	doc_278690626939_item	3636219	et	3	main
tähelepanuväärsem	doc_278690626939_item	3636218	et	4	main
laulupidu	doc_278690626939_item	3636212	et	4	main
100	doc_278690626939_item	3636207	et	2	main
ühtekokku	doc_278690626939_item	3636203	et	3	main
tähistada	doc_278690626939_item	3636195	et	3	main
kulsaim	doc_278690626939_item	3636192	et	4	main
kõige	doc_278690626939_item	3636191	et	4	main
oli	doc_278690626939_item	3636190	et	3	main
juulis	doc_278690626939_item	3636189	et	3	main
aastas	doc_278690626939_item	3636188	et	3	main
üldlaulupeost	doc_278690626939_item	3636142	et	4	main
xii	doc_278690626939_item	3636141	et	4	main
koor	doc_278690626939_item	3636128	et	4	main
annavad	doc_278690626939_item	3636118	et	3	main
on	doc_278690626939_item	3636112	et	4	main
eestis	doc_278690626939_item	3636111	et	3	main
näidetega	doc_278690626939_item	3636110	et	3	main
illustreerida	doc_278690626939_item	3636109	et	3	main
kui	doc_278690626939_item	3636135	et	3	main
ringi	doc_278690626939_item	3636127	et	4	main
soovitatav	doc_278690626939_item	3636108	et	4	main
on	doc_278690626939_item	3636107	et	4	main
väiteid	doc_278690626939_item	3636106	et	4	main
faktidele	doc_278690626939_item	3636105	et	3	main
esitatud	doc_278690626939_item	3636104	et	4	main
lugemistekstis	doc_278690626939_item	3636103	et	3	main
ja	doc_278690626939_item	3636102	et	3	main
loengus	doc_278690626939_item	3636101	et	3	main
tuginema	doc_278690626939_item	3636100	et	3	main
üldistav	doc_278690626939_item	3636099	et	4	main
ja	doc_278690626939_item	3636098	et	3	main
analüüsiv	doc_278690626939_item	3636097	et	4	main
arutlev	doc_278690626939_item	3636096	et	4	main
kogunesid	doc_278690626942_item	3636612	et	4	main
aasta	doc_278690626942_item	3636610	et	4	main
tuntakse	doc_278690626942_item	3636608	et	3	main
maailmas	doc_278690626942_item	3636607	et	3	main
eestlaste	doc_278690626942_item	3636581	et	4	main
kus	doc_278690626942_item	3636575	et	3	main
osales	doc_278690626942_item	3636537	et	3	main
tartus	doc_278690626942_item	3636535	et	3	main
1869	doc_278690626942_item	3636533	et	2	main
ja	doc_278690626942_item	3636508	et	3	main
andis	doc_278690626942_item	3636568	et	3	main
heale	doc_278690626942_item	3636553	et	3	main
kooliharidus	doc_278690626942_item	3636548	et	3	main
traditsiooni	doc_278690626943_item	3636777	et	4	main
aastat	doc_278690626943_item	3636775	et	3	main
tähistada	doc_278690626943_item	3636773	et	3	main
kestavad	doc_278690626943_item	3636760	et	4	main
naised	doc_278690626943_item	3636754	et	3	main
liitusid	doc_278690626943_item	3636752	et	4	main
väga	doc_278690626943_item	3636748	et	3	main
meestekoorid	doc_278690626943_item	3636744	et	3	main
iga	doc_278690626943_item	3636729	et	4	main
laulupeo	doc_278690626943_item	3636724	et	4	main
juulis	doc_278690626942_item	3636611	et	3	main
1944	doc_278690626942_item	3636609	et	2	main
koorilaul	doc_278690626942_item	3636579	et	4	main
meeles	doc_278690626942_item	3636526	et	3	main
minu	doc_278690626942_item	3636525	et	3	main
illustreerida	doc_278690626942_item	3636519	et	3	main
üldistav	doc_278690626942_item	3636509	et	4	main
analüüsiv	doc_278690626942_item	3636507	et	4	main
arutlev	doc_278690626942_item	3636506	et	4	main
sõna	doc_278690626942_item	3636502	et	4	main
aastal	doc_278690626942_item	3636572	et	3	main
päris	doc_278690626942_item	3636565	et	4	main
tean	doc_278690626942_item	3636563	et	3	main
ja	doc_278690626942_item	3636561	et	3	main
tekkima	doc_278690626942_item	3636559	et	3	main
päris	doc_278690626942_item	3636552	et	4	main
oli	doc_278690626942_item	3636550	et	3	main
mängija	doc_278690626942_item	3636546	et	4	main
5	doc_278690626942_item	3636543	et	2	main
ongi	doc_278690626942_item	3636601	et	4	main
hulgas	doc_278690626942_item	3636582	et	4	main
oli	doc_278690626942_item	3636576	et	3	main
on	doc_278690626942_item	3636528	et	4	main
see	doc_278690626942_item	3636527	et	3	main
laulurahva	doc_278690626942_item	3636524	et	3	main
eestlastest	doc_278690626942_item	3636523	et	4	main
teeb	doc_278690626942_item	3636522	et	3	main
soovitatav	doc_278690626942_item	3636518	et	4	main
väiteid	doc_278690626942_item	3636516	et	4	main
essee	doc_278690626942_item	3636503	et	4	main
ülikooli	doc_278690626942_item	3636574	et	4	main
tartu	doc_278690626942_item	3636573	et	4	main
suur	doc_278690626942_item	3636566	et	3	main
et	doc_278690626942_item	3636564	et	3	main
laulukoore	doc_278690626942_item	3636560	et	4	main
eestimaa	doc_278690626942_item	3636557	et	4	main
kogunesid	doc_278690626943_item	3636767	et	4	main
juulis	doc_278690626943_item	3636766	et	3	main
aastal	doc_278690626943_item	3636765	et	3	main
1994	doc_278690626943_item	3636764	et	2	main
137	doc_278690626943_item	3636762	et	2	main
juba	doc_278690626943_item	3636761	et	3	main
tuli	doc_278690626943_item	3636726	et	4	main
ja	doc_278690626943_item	3636722	et	3	main
oli	doc_278690626943_item	3636719	et	3	main
esimene	doc_278690626943_item	3636717	et	3	main
tähtsad	doc_278690626943_item	3636716	et	3	main
näidetega	doc_278690626943_item	3636677	et	3	main
elust	doc_278690626944_item	3637144	et	3	main
saime	doc_278690626944_item	3637142	et	3	main
rahvas	doc_278690626944_item	3637129	et	4	main
eestlastest	doc_278690626944_item	3637128	et	4	main
seotud	doc_278690626944_item	3637120	et	4	main
sest	doc_278690626944_item	3637115	et	4	main
kui	doc_278690626944_item	3637107	et	3	main
sündis	doc_278690626944_item	3637104	et	3	main
rahva	doc_278690626944_item	3637094	et	3	main
vaba	doc_278690626944_item	3637092	et	4	main
üldlaulupidu	doc_278690626944_item	3637055	et	4	main
manifestatsioon	doc_278690626942_item	3636637	et	3	main
eestis	doc_278690626942_item	3636638	et	3	main
rahvusluse	doc_278690626942_item	3636636	et	4	main
massilisem	doc_278690626942_item	3636635	et	4	main
ja	doc_278690626942_item	3636634	et	3	main
tähelepanuväärsem	doc_278690626942_item	3636633	et	4	main
kõige	doc_278690626942_item	3636632	et	4	main
ajal	doc_278690626942_item	3636631	et	4	main
praegusel	doc_278690626942_item	3636630	et	3	main
ka	doc_278690626942_item	3636629	et	3	main
on	doc_278690626942_item	3636628	et	4	main
laulupidu	doc_278690626942_item	3636627	et	4	main
eestiline	doc_278690626942_item	3636626	et	3	main
üle	doc_278690626942_item	3636625	et	3	main
traditsioon	doc_278690626942_item	3636624	et	3	main
laulupidude	doc_278690626942_item	3636623	et	4	main
kestnud	doc_278690626942_item	3636622	et	4	main
aastat	doc_278690626942_item	3636621	et	3	main
125	doc_278690626942_item	3636620	et	2	main
et	doc_278690626942_item	3636618	et	3	main
tähistada	doc_278690626942_item	3636619	et	3	main
laulupeole	doc_278690626942_item	3636617	et	4	main
lauluväljakule	doc_278690626942_item	3636616	et	3	main
tallinna	doc_278690626942_item	3636615	et	4	main
lauljad	doc_278690626942_item	3636614	et	4	main
järgi	doc_278690626942_item	3636605	et	4	main
laulupidu	doc_278690626942_item	3636600	et	4	main
laulupidu	doc_278690626942_item	3636599	et	4	main
ka	doc_278690626942_item	3636598	et	3	main
kohe	doc_278690626942_item	3636597	et	4	main
laul	doc_278690626942_item	3636596	et	4	main
ja	doc_278690626942_item	3636595	et	3	main
rahvas	doc_278690626942_item	3636594	et	4	main
sõnadega	doc_278690626942_item	3636593	et	3	main
seostub	doc_278690626942_item	3636592	et	3	main
jaoks	doc_278690626942_item	3636591	et	4	main
eestlase	doc_278690626942_item	3636590	et	3	main
tavalise	doc_278690626942_item	3636589	et	4	main
et	doc_278690626942_item	3636588	et	3	main
loomulik	doc_278690626942_item	3636587	et	3	main
on	doc_278690626942_item	3636586	et	4	main
seepärast	doc_278690626942_item	3636585	et	3	main
massiharrastuseks	doc_278690626942_item	3636584	et	3	main
kujunenud	doc_278690626942_item	3636583	et	4	main
õppetool	doc_278690626942_item	3636578	et	3	main
muusika	doc_278690626942_item	3636577	et	4	main
peol	doc_278690626942_item	3636536	et	4	main
esimene	doc_278690626942_item	3636530	et	3	main
laulupidu	doc_278690626942_item	3636529	et	4	main
näidetega	doc_278690626942_item	3636520	et	3	main
olema	doc_278690626942_item	3636505	et	4	main
asutanud	doc_278690626942_item	3636570	et	4	main
nurkades	doc_278690626942_item	3636558	et	3	main
kõigis	doc_278690626942_item	3636556	et	4	main
hakkas	doc_278690626942_item	3636555	et	3	main
tasemele	doc_278690626942_item	3636554	et	3	main
jõudnud	doc_278690626942_item	3636551	et	4	main
muusikaõpetus	doc_278690626942_item	3636549	et	3	main
kuna	doc_278690626942_item	3636547	et	3	main
56	doc_278690626942_item	3636545	et	2	main
puhkpilliorkestrit	doc_278690626942_item	3636544	et	3	main
ja	doc_278690626942_item	3636542	et	3	main
822	doc_278690626942_item	3636540	et	2	main
meeskoori	doc_278690626942_item	3636539	et	4	main
46	doc_278690626942_item	3636538	et	2	main
aastat	doc_278690626943_item	3636763	et	3	main
ja	doc_278690626943_item	3636757	et	3	main
poisid	doc_278690626943_item	3636756	et	4	main
ka	doc_278690626943_item	3636753	et	3	main
hiljem	doc_278690626943_item	3636751	et	3	main
populaarne	doc_278690626943_item	3636749	et	3	main
see	doc_278690626943_item	3636746	et	3	main
siis	doc_278690626943_item	3636740	et	3	main
alles	doc_278690626943_item	3636738	et	3	main
laulupeod	doc_278690626943_item	3636737	et	4	main
kui	doc_278690626943_item	3636736	et	3	main
johan	doc_278690626943_item	3636727	et	4	main
idee	doc_278690626943_item	3636723	et	4	main
väga	doc_278690626943_item	3636715	et	3	main
jaoks	doc_278690626943_item	3636712	et	4	main
analüseerimine	doc_278690626944_item	3637135	et	4	main
kes	doc_278690626944_item	3637130	et	4	main
ja	doc_278690626944_item	3637125	et	3	main
väga	doc_278690626944_item	3637123	et	3	main
teisega	doc_278690626944_item	3637122	et	4	main
üks	doc_278690626944_item	3637121	et	3	main
nüüd	doc_278690626944_item	3637116	et	4	main
nüüd	doc_278690626944_item	3637106	et	4	main
ärkamine	doc_278690626944_item	3637099	et	4	main
tegi	doc_278690626944_item	3637093	et	4	main
ja	doc_278690626944_item	3637091	et	3	main
iseseisvus	doc_278690626944_item	3637090	et	4	main
oleks	doc_278690626944_item	3637089	et	3	main
linnas	doc_278690626944_item	3637083	et	4	main
pidu	doc_278690626944_item	3637079	et	4	main
üks	doc_278690626944_item	3637078	et	3	main
oli	doc_278690626944_item	3637077	et	3	main
see	doc_278690626944_item	3637076	et	3	main
et	doc_278690626944_item	3637075	et	3	main
öelda	doc_278690626944_item	3637074	et	4	main
võib	doc_278690626944_item	3637073	et	3	main
sellepärast	doc_278690626944_item	3637072	et	3	main
ja	doc_278690626944_item	3637071	et	3	main
tartus	doc_278690626944_item	3637062	et	3	main
korraldati	doc_278690626944_item	3637054	et	3	main
kogunesid	doc_278690626944_item	3637051	et	4	main
aastal	doc_278690626944_item	3637050	et	3	main
tol	doc_278690626944_item	3637049	et	3	main
aastad	doc_278690626944_item	3637048	et	3	main
oli	doc_278690626944_item	3637044	et	3	main
kõlas	doc_278690626944_item	3637028	et	4	main
100	doc_278690626944_item	3637020	et	2	main
suur	doc_278690626944_item	3637005	et	3	main
mitu	doc_278690626944_item	3636989	et	4	main
nad	doc_278690626944_item	3636976	et	3	main
kus	doc_278690626944_item	3636975	et	3	main
kõrghetk	doc_278690626944_item	3636974	et	3	main
liikumise	doc_278690626944_item	3636973	et	4	main
imelik	doc_278690626944_item	3636844	et	3	main
nii	doc_278690626944_item	3636837	et	3	main
inimene	doc_278690626944_item	3636828	et	3	main
üldistav	doc_278690626944_item	3636805	et	4	main
kirjutamine	doc_278690626944_item	3636786	et	4	main
pidu	doc_278690626944_item	3636953	et	4	main
asi	doc_278690626944_item	3636945	et	4	main
meloodia	doc_278690626944_item	3636931	et	4	main
esitatud	doc_278690626942_item	3636514	et	4	main
lugemistekstis	doc_278690626942_item	3636513	et	3	main
ja	doc_278690626942_item	3636512	et	3	main
loengus	doc_278690626942_item	3636511	et	3	main
tuginema	doc_278690626942_item	3636510	et	3	main
peab	doc_278690626942_item	3636504	et	4	main
350	doc_278690626942_item	3636501	et	2	main
pikkus	doc_278690626942_item	3636499	et	4	main
300	doc_278690626942_item	3636500	et	2	main
essee	doc_278690626942_item	3636498	et	4	main
laulurahva	doc_278690626942_item	3636497	et	3	main
eestlastest	doc_278690626942_item	3636496	et	4	main
teeb	doc_278690626942_item	3636495	et	3	main
mis	doc_278690626942_item	3636494	et	4	main
teemal	doc_278690626942_item	3636493	et	3	main
essee	doc_278690626942_item	3636492	et	4	main
kirjutage	doc_278690626942_item	3636491	et	3	main
kirjutamine	doc_278690626942_item	3636490	et	4	main
test	doc_278690626942_item	3636489	et	3	main
keele	doc_278690626942_item	3636488	et	4	main
teise	doc_278690626942_item	3636487	et	4	main
kui	doc_278690626942_item	3636486	et	3	main
keele	doc_278690626942_item	3636485	et	4	main
eesti	doc_278690626942_item	3636484	et	4	main
essee	doc_278690626942_item	3636483	et	4	main
1632	doc_278690626942_item	3636571	et	2	main
ka	doc_278690626942_item	3636569	et	3	main
roll	doc_278690626942_item	3636567	et	3	main
puhkpilliorkesteri	doc_278690626942_item	3636562	et	3	main
lauljaga	doc_278690626942_item	3636541	et	4	main
tudrukud	doc_278690626943_item	3636758	et	4	main
esinesid	doc_278690626943_item	3636741	et	4	main
alguses	doc_278690626943_item	3636735	et	4	main
kasvab	doc_278690626943_item	3636734	et	3	main
laulupeodel	doc_278690626943_item	3636733	et	3	main
arv	doc_278690626943_item	3636732	et	3	main
inimeste	doc_278690626943_item	3636731	et	3	main
aasta	doc_278690626943_item	3636730	et	4	main
korraldamises	doc_278690626943_item	3636725	et	4	main
aastal	doc_278690626943_item	3636721	et	3	main
eestlaste	doc_278690626943_item	3636711	et	4	main
vaheldumisi	doc_278690626943_item	3636710	et	4	main
teada	doc_278690626944_item	3637143	et	3	main
tutvume	doc_278690626944_item	3637138	et	3	main
mures	doc_278690626944_item	3637132	et	3	main
teeb	doc_278690626944_item	3637127	et	3	main
tigedalt	doc_278690626944_item	3637124	et	4	main
neid	doc_278690626944_item	3637117	et	4	main
mis	doc_278690626944_item	3637103	et	4	main
kestnud	doc_278690626943_item	3636776	et	4	main
125	doc_278690626943_item	3636774	et	2	main
et	doc_278690626943_item	3636772	et	3	main
lauluväljakul	doc_278690626943_item	3636771	et	3	main
tallinna	doc_278690626943_item	3636770	et	4	main
lauljad	doc_278690626943_item	3636769	et	4	main
tuhandet	doc_278690626943_item	3636768	et	3	main
laulupeod	doc_278690626943_item	3636759	et	4	main
siis	doc_278690626943_item	3636755	et	3	main
siis	doc_278690626943_item	3636750	et	3	main
oli	doc_278690626943_item	3636747	et	3	main
kuna	doc_278690626943_item	3636745	et	3	main
ainult	doc_278690626943_item	3636743	et	4	main
seal	doc_278690626943_item	3636742	et	4	main
algasid	doc_278690626943_item	3636739	et	4	main
voldemarilt	doc_278690626943_item	3636728	et	4	main
koor	doc_278690626943_item	3636709	et	4	main
ja	doc_278690626943_item	3636708	et	3	main
eeslaulja	doc_278690626943_item	3636707	et	4	main
esitavad	doc_278690626943_item	3636706	et	4	main
tavaliselt	doc_278690626943_item	3636705	et	4	main
rahvalaulu	doc_278690626943_item	3636704	et	4	main
vana	doc_278690626943_item	3636703	et	4	main
aastat	doc_278690626943_item	3636702	et	3	main
tuhat	doc_278690626943_item	3636701	et	4	main
kui	doc_278690626943_item	3636700	et	3	main
rohkem	doc_278690626943_item	3636699	et	4	main
juba	doc_278690626943_item	3636698	et	3	main
on	doc_278690626943_item	3636697	et	4	main
rahvalaul	doc_278690626943_item	3636696	et	4	main
eesti	doc_278690626943_item	3636695	et	4	main
mineviku	doc_278690626943_item	3636694	et	3	main
rahva	doc_278690626943_item	3636693	et	3	main
kuulda	doc_278690626943_item	3636692	et	4	main
võid	doc_278690626943_item	3636691	et	4	main
sa	doc_278690626943_item	3636690	et	3	main
laulus	doc_278690626943_item	3636689	et	3	main
regilaul	doc_278690626943_item	3636688	et	4	main
nimetatakse	doc_278690626943_item	3636687	et	3	main
rahvalaul	doc_278690626943_item	3636686	et	4	main
eesti	doc_278690626943_item	3636685	et	4	main
laulurahvas	doc_278690626943_item	3636684	et	4	main
on	doc_278690626943_item	3636683	et	4	main
eestlased	doc_278690626943_item	3636682	et	3	main
kultuurinähtus	doc_278690626943_item	3636681	et	4	main
tähelepanuväärne	doc_278690626943_item	3636680	et	3	main
on	doc_278690626943_item	3636679	et	4	main
laulmine	doc_278690626943_item	3636678	et	4	main
1869	doc_278690626943_item	3636720	et	2	main
laulupeo	doc_278690626943_item	3636718	et	4	main
on	doc_278690626943_item	3636714	et	4	main
laulupeod	doc_278690626943_item	3636713	et	4	main
me	doc_278690626944_item	3637141	et	4	main
ajalooga	doc_278690626944_item	3637139	et	4	main
õnnelikus	doc_278690626944_item	3637134	et	4	main
ja	doc_278690626944_item	3637133	et	3	main
on	doc_278690626944_item	3637119	et	4	main
me	doc_278690626944_item	3637108	et	4	main
laulupidu	doc_278690626944_item	3637105	et	4	main
lõpupoole	doc_278690626944_item	3637102	et	4	main
19	doc_278690626944_item	3637100	et	2	main
rahvana	doc_278690626944_item	3637096	et	3	main
maa	doc_278690626944_item	3637088	et	4	main
nende	doc_278690626944_item	3637087	et	4	main
kahes	doc_278690626944_item	3637082	et	4	main
ajal	doc_278690626944_item	3637057	et	4	main
samal	doc_278690626944_item	3637056	et	3	main
sünnipäev	doc_278690626944_item	3637045	et	3	main
aastal	doc_278690626944_item	3637043	et	3	main
on	doc_278690626944_item	3637035	et	4	main
gustav	doc_278690626944_item	3637029	et	4	main
tähtis	doc_278690626944_item	3637025	et	4	main
väga	doc_278690626944_item	3637024	et	3	main
aastal	doc_278690626944_item	3637016	et	3	main
liigus	doc_278690626944_item	3637009	et	3	main
armastus	doc_278690626944_item	3637008	et	4	main
see	doc_278690626944_item	3637007	et	3	main
juurde	doc_278690626944_item	3637003	et	4	main
armastus	doc_278690626944_item	3637001	et	4	main
tallinasse	doc_278690626944_item	3636988	et	4	main
kolis	doc_278690626944_item	3636986	et	4	main
laulupidu	doc_278690626944_item	3636985	et	4	main
1896	doc_278690626944_item	3636983	et	2	main
juba	doc_278690626944_item	3636982	et	3	main
vabu	doc_278690626944_item	3636981	et	3	main
ja	doc_278690626944_item	3636980	et	3	main
rahvusliku	doc_278690626944_item	3636972	et	3	main
see	doc_278690626944_item	3636969	et	3	main
ole	doc_278690626944_item	3636843	et	4	main
vanematest	doc_278690626944_item	3636835	et	4	main
teha	doc_278690626944_item	3636824	et	3	main
on	doc_278690626944_item	3636818	et	4	main
esitatud	doc_278690626944_item	3636810	et	4	main
lugemistekstis	doc_278690626944_item	3636809	et	3	main
ja	doc_278690626944_item	3636808	et	3	main
loengus	doc_278690626944_item	3636807	et	3	main
tuginema	doc_278690626944_item	3636806	et	3	main
sõna	doc_278690626944_item	3636798	et	4	main
350	doc_278690626944_item	3636797	et	2	main
300	doc_278690626944_item	3636796	et	2	main
essee	doc_278690626944_item	3636788	et	4	main
kirjutage	doc_278690626944_item	3636787	et	3	main
ülemaaline	doc_278690626944_item	3636952	et	4	main
normaalne	doc_278690626944_item	3636944	et	3	main
oli	doc_278690626944_item	3636943	et	3	main
see	doc_278690626944_item	3636942	et	3	main
laulas	doc_278690626944_item	3636941	et	4	main
peale	doc_278690626944_item	3636932	et	4	main
lastele	doc_278690626944_item	3636925	et	4	main
teine	doc_278690626944_item	3636918	et	3	main
ja	doc_278690626944_item	3636914	et	3	main
illustreerida	doc_278690626943_item	3636676	et	3	main
soovitatav	doc_278690626943_item	3636675	et	4	main
on	doc_278690626943_item	3636674	et	4	main
väiteid	doc_278690626943_item	3636673	et	4	main
faktidele	doc_278690626943_item	3636672	et	3	main
esitatud	doc_278690626943_item	3636671	et	4	main
lugemistekstis	doc_278690626943_item	3636670	et	3	main
ja	doc_278690626943_item	3636669	et	3	main
loengus	doc_278690626943_item	3636668	et	3	main
tuginema	doc_278690626943_item	3636667	et	3	main
üldistav	doc_278690626943_item	3636666	et	4	main
ja	doc_278690626943_item	3636665	et	3	main
analüüsiv	doc_278690626943_item	3636664	et	4	main
arutlev	doc_278690626943_item	3636663	et	4	main
olema	doc_278690626943_item	3636662	et	4	main
peab	doc_278690626943_item	3636661	et	4	main
essee	doc_278690626943_item	3636660	et	4	main
sõna	doc_278690626943_item	3636659	et	4	main
350	doc_278690626943_item	3636658	et	2	main
300	doc_278690626943_item	3636657	et	2	main
pikkus	doc_278690626943_item	3636656	et	4	main
essee	doc_278690626943_item	3636655	et	4	main
laulurahva	doc_278690626943_item	3636654	et	3	main
eestlastest	doc_278690626943_item	3636653	et	4	main
teeb	doc_278690626943_item	3636652	et	3	main
mis	doc_278690626943_item	3636651	et	4	main
teemal	doc_278690626943_item	3636650	et	3	main
essee	doc_278690626943_item	3636649	et	4	main
kirjutage	doc_278690626943_item	3636648	et	3	main
kirjutamine	doc_278690626943_item	3636647	et	4	main
test	doc_278690626943_item	3636646	et	3	main
keele	doc_278690626943_item	3636645	et	4	main
teise	doc_278690626943_item	3636644	et	4	main
kui	doc_278690626943_item	3636643	et	3	main
keele	doc_278690626943_item	3636642	et	4	main
eesti	doc_278690626943_item	3636641	et	4	main
essee	doc_278690626943_item	3636640	et	4	main
milles	doc_278690626944_item	3637140	et	3	main
me	doc_278690626944_item	3637137	et	4	main
rahvalaule	doc_278690626944_item	3637136	et	4	main
laulab	doc_278690626944_item	3637131	et	3	main
see	doc_278690626944_item	3637126	et	3	main
sõnu	doc_278690626944_item	3637118	et	4	main
laulupidu	doc_278690626944_item	3637114	et	4	main
mõistame	doc_278690626944_item	3637113	et	3	main
rahvas	doc_278690626944_item	3637112	et	4	main
ja	doc_278690626944_item	3637111	et	3	main
laul	doc_278690626944_item	3637110	et	4	main
kuulame	doc_278690626944_item	3637109	et	4	main
rahvuslik	doc_278690626944_item	3637098	et	3	main
toimus	doc_278690626944_item	3637097	et	3	main
ühe	doc_278690626944_item	3637095	et	4	main
et	doc_278690626944_item	3637086	et	3	main
tahtmine	doc_278690626944_item	3637085	et	4	main
eestlaste	doc_278690626944_item	3637084	et	4	main
ainult	doc_278690626944_item	3637081	et	4	main
aga	doc_278690626944_item	3637080	et	3	main
ehitus	doc_278690626944_item	3637063	et	4	main
tallinnas	doc_278690626944_item	3637060	et	4	main
lauljad	doc_278690626944_item	3637053	et	4	main
ülerahva	doc_278690626944_item	3637040	et	3	main
mu	doc_278690626944_item	3637033	et	3	main
see	doc_278690626944_item	3637022	et	3	main
juubel	doc_278690626944_item	3637019	et	3	main
oli	doc_278690626944_item	3637017	et	3	main
1869	doc_278690626944_item	3637015	et	2	main
oli	doc_278690626944_item	3637004	et	3	main
rahvalaulmise	doc_278690626944_item	3637002	et	3	main
et	doc_278690626944_item	3637000	et	3	main
näitab	doc_278690626944_item	3636999	et	3	main
see	doc_278690626944_item	3636998	et	3	main
poisid	doc_278690626944_item	3636997	et	4	main
naised	doc_278690626944_item	3636996	et	3	main
lapsed	doc_278690626944_item	3636995	et	3	main
osa	doc_278690626944_item	3636994	et	4	main
võttis	doc_278690626944_item	3636993	et	3	main
tartust	doc_278690626944_item	3636987	et	3	main
tunnasid	doc_278690626944_item	3636977	et	4	main
tartus	doc_278690626944_item	3636967	et	3	main
muusika	doc_278690626944_item	3636841	et	4	main
oma	doc_278690626944_item	3636830	et	4	main
mõtleb	doc_278690626944_item	3636829	et	3	main
kuulamises	doc_278690626944_item	3636827	et	4	main
ta	doc_278690626944_item	3636822	et	4	main
sajandi	doc_278690626944_item	3637101	et	3	main
seotud	doc_278690626944_item	3637070	et	4	main
ja	doc_278690626944_item	3637069	et	3	main
samad	doc_278690626944_item	3637068	et	3	main
omavahel	doc_278690626944_item	3637067	et	3	main
oli	doc_278690626944_item	3637066	et	3	main
sisu	doc_278690626944_item	3637065	et	4	main
ja	doc_278690626944_item	3637064	et	3	main
ja	doc_278690626944_item	3637061	et	3	main
linnas	doc_278690626944_item	3637059	et	4	main
kahes	doc_278690626944_item	3637058	et	4	main
tuhandeid	doc_278690626944_item	3637052	et	3	main
125	doc_278690626944_item	3637047	et	2	main
laulupeol	doc_278690626944_item	3637046	et	4	main
1994	doc_278690626944_item	3637042	et	2	main
isamaa	doc_278690626944_item	3637034	et	4	main
isamaalaul	doc_278690626944_item	3637032	et	4	main
hingestatud	doc_278690626944_item	3637031	et	4	main
aastad	doc_278690626944_item	3637021	et	3	main
laulupeol	doc_278690626944_item	3637018	et	4	main
ja	doc_278690626944_item	3637011	et	3	main
edasi	doc_278690626944_item	3637010	et	3	main
laulupeos	doc_278690626944_item	3636992	et	4	main
hiljem	doc_278690626944_item	3636991	et	3	main
aastad	doc_278690626944_item	3636990	et	3	main
aastal	doc_278690626944_item	3636984	et	3	main
jõudu	doc_278690626944_item	3636979	et	4	main
oma	doc_278690626944_item	3636978	et	4	main
oli	doc_278690626944_item	3636970	et	3	main
mõjub	doc_278690626944_item	3636840	et	3	main
ja	doc_278690626944_item	3636839	et	3	main
armukest	doc_278690626944_item	3636834	et	4	main
maailmast	doc_278690626944_item	3636833	et	4	main
erinevaid	doc_278690626944_item	3636825	et	4	main
võib	doc_278690626944_item	3636823	et	3	main
asi	doc_278690626944_item	3636820	et	4	main
imelene	doc_278690626944_item	3636819	et	4	main
ja	doc_278690626944_item	3636804	et	3	main
olema	doc_278690626944_item	3636801	et	4	main
pikkus	doc_278690626944_item	3636795	et	4	main
essee	doc_278690626944_item	3636794	et	4	main
laulurahva	doc_278690626944_item	3636793	et	3	main
eestlastest	doc_278690626944_item	3636792	et	4	main
teeb	doc_278690626944_item	3636791	et	3	main
mis	doc_278690626944_item	3636790	et	4	main
teemal	doc_278690626944_item	3636789	et	3	main
keele	doc_278690626944_item	3636784	et	4	main
keele	doc_278690626944_item	3636781	et	4	main
kujuda	doc_278690626944_item	3636950	et	4	main
otsustas	doc_278690626944_item	3636949	et	3	main
vanemuisega	doc_278690626944_item	3636948	et	4	main
koos	doc_278690626944_item	3636947	et	4	main
põllul	doc_278690626944_item	3636939	et	3	main
töötas	doc_278690626944_item	3636938	et	3	main
isa	doc_278690626944_item	3636937	et	4	main
pani	doc_278690626944_item	3636928	et	4	main
seotud	doc_278690626944_item	3636917	et	4	main
maaelu	doc_278690626944_item	3636915	et	4	main
liiguda	doc_278690626944_item	3636906	et	4	main
keha	doc_278690626944_item	3636904	et	4	main
koos	doc_278690626944_item	3636895	et	4	main
oli	doc_278690626944_item	3636894	et	3	main
kui	doc_278690626944_item	3636893	et	3	main
rahuneb	doc_278690626944_item	3636855	et	3	main
nüüd	doc_278690626946_item	3637455	et	4	main
ja	doc_278690626946_item	3637454	et	3	main
nende	doc_278690626946_item	3637445	et	4	main
siis	doc_278690626946_item	3637438	et	3	main
tihti	doc_278690626946_item	3637436	et	3	main
tihti	doc_278690626946_item	3637434	et	3	main
seda	doc_278690626946_item	3637432	et	3	main
midagi	doc_278690626946_item	3637429	et	4	main
meeldib	doc_278690626946_item	3637428	et	3	main
inimestele	doc_278690626946_item	3637427	et	3	main
kui	doc_278690626946_item	3637426	et	3	main
on	doc_278690626946_item	3637423	et	4	main
tea	doc_278690626946_item	3637413	et	4	main
avalikud	doc_278690626946_item	3637404	et	3	main
eestlastel	doc_278690626946_item	3637393	et	4	main
arvates	doc_278690626946_item	3637392	et	4	main
minu	doc_278690626946_item	3637391	et	3	main
õpetada	doc_278690626946_item	3637390	et	3	main
tuju	doc_278690626944_item	3637041	et	4	main
tõusis	doc_278690626944_item	3637039	et	4	main
mis	doc_278690626944_item	3637038	et	4	main
arm	doc_278690626944_item	3637037	et	3	main
minu	doc_278690626944_item	3637036	et	3	main
ernesaksa	doc_278690626944_item	3637030	et	4	main
seal	doc_278690626944_item	3637027	et	4	main
päev	doc_278690626944_item	3637026	et	3	main
oli	doc_278690626944_item	3637023	et	3	main
rõõmustab	doc_278690626944_item	3637014	et	3	main
mis	doc_278690626944_item	3637013	et	4	main
edasi	doc_278690626944_item	3637012	et	3	main
ja	doc_278690626944_item	3637006	et	3	main
eesti	doc_278690626944_item	3636971	et	4	main
ja	doc_278690626944_item	3636968	et	3	main
ei	doc_278690626944_item	3636842	et	4	main
edasi	doc_278690626944_item	3636838	et	3	main
ja	doc_278690626944_item	3636836	et	3	main
loodust	doc_278690626944_item	3636832	et	4	main
elust	doc_278690626944_item	3636831	et	3	main
tuju	doc_278690626944_item	3636826	et	4	main
seest	doc_278690626944_item	3636821	et	3	main
on	doc_278690626944_item	3636813	et	4	main
väiteid	doc_278690626944_item	3636812	et	4	main
faktidele	doc_278690626944_item	3636811	et	3	main
analüüsiv	doc_278690626944_item	3636803	et	4	main
test	doc_278690626944_item	3636785	et	3	main
esimene	doc_278690626944_item	3636951	et	3	main
ta	doc_278690626944_item	3636940	et	4	main
oma	doc_278690626944_item	3636929	et	4	main
muinasjuttu	doc_278690626944_item	3636923	et	4	main
jutustas	doc_278690626944_item	3636922	et	3	main
ema	doc_278690626944_item	3636921	et	4	main
kui	doc_278690626944_item	3636920	et	3	main
teisega	doc_278690626944_item	3636919	et	4	main
rütmi	doc_278690626944_item	3636909	et	4	main
ja	doc_278690626944_item	3636907	et	3	main
tahab	doc_278690626944_item	3636905	et	3	main
siis	doc_278690626944_item	3636903	et	3	main
meloodia	doc_278690626944_item	3636900	et	4	main
oma	doc_278690626944_item	3636896	et	4	main
mõjub	doc_278690626944_item	3636857	et	3	main
jooksul	doc_278690626944_item	3636848	et	4	main
ka	doc_278690626946_item	3637459	et	3	main
samad	doc_278690626946_item	3637442	et	3	main
armastus	doc_278690626946_item	3637425	et	4	main
see	doc_278690626946_item	3637422	et	3	main
ei	doc_278690626946_item	3637412	et	4	main
laulmine	doc_278690626946_item	3637407	et	4	main
ja	doc_278690626946_item	3637403	et	3	main
on	doc_278690626946_item	3637394	et	4	main
ka	doc_278690626946_item	3637388	et	3	main
tulevikus	doc_278690626946_item	3637385	et	4	main
muusika	doc_278690626944_item	3636817	et	4	main
näidetega	doc_278690626944_item	3636816	et	3	main
illustreerida	doc_278690626944_item	3636815	et	3	main
soovitatav	doc_278690626944_item	3636814	et	4	main
arutlev	doc_278690626944_item	3636802	et	4	main
peab	doc_278690626944_item	3636800	et	4	main
essee	doc_278690626944_item	3636799	et	4	main
teise	doc_278690626944_item	3636783	et	4	main
kui	doc_278690626944_item	3636782	et	3	main
eesti	doc_278690626944_item	3636780	et	4	main
essee	doc_278690626944_item	3636779	et	4	main
juhtus	doc_278690626944_item	3636966	et	3	main
see	doc_278690626944_item	3636965	et	3	main
laulupidu	doc_278690626944_item	3636964	et	4	main
esimene	doc_278690626944_item	3636963	et	3	main
korraldadi	doc_278690626944_item	3636962	et	4	main
aastal	doc_278690626944_item	3636961	et	3	main
1869	doc_278690626944_item	3636960	et	2	main
juba	doc_278690626944_item	3636959	et	3	main
ja	doc_278690626944_item	3636958	et	3	main
saaksid	doc_278690626944_item	3636956	et	4	main
laulma	doc_278690626944_item	3636957	et	3	main
inimesed	doc_278690626944_item	3636955	et	3	main
kus	doc_278690626944_item	3636954	et	3	main
jannsen	doc_278690626944_item	3636946	et	4	main
kui	doc_278690626944_item	3636936	et	3	main
unelaul	doc_278690626944_item	3636935	et	4	main
tekkis	doc_278690626944_item	3636934	et	3	main
ja	doc_278690626944_item	3636933	et	3	main
ta	doc_278690626944_item	3636927	et	4	main
siis	doc_278690626944_item	3636926	et	3	main
oli	doc_278690626944_item	3636916	et	3	main
laulmine	doc_278690626944_item	3636913	et	4	main
tagasi	doc_278690626944_item	3636912	et	3	main
aastad	doc_278690626944_item	3636911	et	3	main
100	doc_278690626944_item	3636910	et	2	main
rütmikas	doc_278690626944_item	3636902	et	4	main
laulu	doc_278690626944_item	3636899	et	4	main
kui	doc_278690626944_item	3636898	et	3	main
perega	doc_278690626944_item	3636897	et	3	main
ja	doc_278690626944_item	3636856	et	3	main
aitab	doc_278690626944_item	3636853	et	3	main
laulavad	doc_278690626944_item	3636851	et	4	main
ajalugu	doc_278690626944_item	3636850	et	4	main
kõik	doc_278690626944_item	3636846	et	4	main
laulavad	doc_278690626946_item	3637458	et	4	main
lapselapsed	doc_278690626946_item	3637446	et	3	main
ja	doc_278690626946_item	3637444	et	3	main
hakkavad	doc_278690626946_item	3637431	et	4	main
nende	doc_278690626946_item	3637424	et	4	main
arvates	doc_278690626946_item	3637421	et	4	main
minu	doc_278690626946_item	3637420	et	3	main
aga	doc_278690626946_item	3637419	et	3	main
laulurahva	doc_278690626946_item	3637418	et	3	main
eestlastest	doc_278690626946_item	3637417	et	4	main
teeb	doc_278690626946_item	3637416	et	3	main
keegi	doc_278690626946_item	3637411	et	4	main
olla	doc_278690626946_item	3637406	et	3	main
väga	doc_278690626946_item	3637400	et	3	main
nad	doc_278690626946_item	3637398	et	3	main
lapsele	doc_278690626946_item	3637387	et	4	main
tahab	doc_278690626946_item	3637384	et	3	main
laulda	doc_278690626946_item	3637358	et	4	main
ja	doc_278690626946_item	3637355	et	3	main
laulmiseks	doc_278690626946_item	3637354	et	4	main
kui	doc_278690626946_item	3637346	et	3	main
arvan	doc_278690626946_item	3637335	et	3	main
miks	doc_278690626946_item	3637331	et	4	main
aga	doc_278690626946_item	3637330	et	3	main
eestlased	doc_278690626946_item	3637231	et	3	main
teab	doc_278690626946_item	3637229	et	3	main
tavaliselt	doc_278690626946_item	3637226	et	4	main
on	doc_278690626946_item	3637225	et	4	main
aga	doc_278690626946_item	3637213	et	3	main
on	doc_278690626946_item	3637202	et	4	main
see	doc_278690626946_item	3637201	et	3	main
riigil	doc_278690626946_item	3637200	et	3	main
analüüsiv	doc_278690626946_item	3637170	et	4	main
sõna	doc_278690626946_item	3637165	et	4	main
350	doc_278690626946_item	3637164	et	2	main
300	doc_278690626946_item	3637163	et	2	main
teeb	doc_278690626946_item	3637158	et	3	main
teemal	doc_278690626946_item	3637156	et	3	main
essee	doc_278690626946_item	3637155	et	4	main
kirjutage	doc_278690626946_item	3637154	et	3	main
oma	doc_278690626946_item	3637305	et	4	main
olid	doc_278690626946_item	3637301	et	4	main
abistas	doc_278690626946_item	3637287	et	3	main
tehes	doc_278690626946_item	3637286	et	3	main
töö	doc_278690626946_item	3637285	et	4	main
tegevus	doc_278690626946_item	3637280	et	4	main
teksti	doc_278690626946_item	3637249	et	4	main
ma	doc_278690626946_item	3637246	et	3	main
otsustada	doc_278690626946_item	3637245	et	3	main
seda	doc_278690626946_item	3637244	et	3	main
aga	doc_278690626946_item	3637242	et	3	main
seotud	doc_278690626949_item	3637577	et	4	main
ja	doc_278690626949_item	3637574	et	3	main
folkloorist	doc_278690626949_item	3637573	et	4	main
pärineb	doc_278690626949_item	3637572	et	3	main
moderniseeritakse	doc_278690626949_item	3637565	et	4	main
muusika	doc_278690626949_item	3637557	et	4	main
tõsta	doc_278690626949_item	3637550	et	4	main
ja	doc_278690626949_item	3637549	et	3	main
eestlaste	doc_278690626949_item	3637539	et	4	main
kujunes	doc_278690626949_item	3637538	et	3	main
jutus	doc_278690626944_item	3636930	et	3	main
oma	doc_278690626944_item	3636924	et	4	main
töötas	doc_278690626944_item	3636892	et	3	main
maailma	doc_278690626944_item	3636849	et	4	main
et	doc_278690626944_item	3636845	et	3	main
lapselapsed	doc_278690626946_item	3637457	et	3	main
nende	doc_278690626946_item	3637456	et	4	main
laulda	doc_278690626946_item	3637453	et	4	main
asju	doc_278690626946_item	3637443	et	3	main
nende	doc_278690626946_item	3637439	et	4	main
ja	doc_278690626946_item	3637437	et	3	main
teha	doc_278690626946_item	3637433	et	3	main
nad	doc_278690626946_item	3637430	et	3	main
täpselt	doc_278690626946_item	3637414	et	4	main
neid	doc_278690626946_item	3637409	et	4	main
aitab	doc_278690626946_item	3637408	et	3	main
rahulikud	doc_278690626946_item	3637401	et	3	main
iseloom	doc_278690626946_item	3637397	et	3	main
laulmise	doc_278690626946_item	3637389	et	4	main
täiskasvanud	doc_278690626946_item	3637371	et	4	main
siis	doc_278690626946_item	3637359	et	3	main
armastab	doc_278690626946_item	3637357	et	3	main
vanavanaema	doc_278690626946_item	3637347	et	4	main
laulda	doc_278690626946_item	3637345	et	4	main
nad	doc_278690626946_item	3637343	et	3	main
eestlased	doc_278690626946_item	3637327	et	3	main
ka	doc_278690626946_item	3637324	et	3	main
see	doc_278690626946_item	3637322	et	3	main
et	doc_278690626946_item	3637321	et	3	main
arvan	doc_278690626946_item	3637320	et	3	main
et	doc_278690626946_item	3637230	et	3	main
sõitnud	doc_278690626946_item	3637227	et	4	main
kes	doc_278690626946_item	3637224	et	4	main
inimene	doc_278690626946_item	3637223	et	3	main
on	doc_278690626946_item	3637217	et	4	main
lugemine	doc_278690626946_item	3637205	et	4	main
teisel	doc_278690626946_item	3637199	et	4	main
mis	doc_278690626946_item	3637184	et	4	main
illustreerida	doc_278690626946_item	3637182	et	3	main
loengus	doc_278690626946_item	3637174	et	3	main
tuginema	doc_278690626946_item	3637173	et	3	main
üldistav	doc_278690626946_item	3637172	et	4	main
ja	doc_278690626946_item	3637171	et	3	main
essee	doc_278690626946_item	3637166	et	4	main
essee	doc_278690626946_item	3637161	et	4	main
teise	doc_278690626946_item	3637150	et	4	main
kui	doc_278690626946_item	3637149	et	3	main
essee	doc_278690626946_item	3637146	et	4	main
eestlastel	doc_278690626946_item	3637308	et	4	main
hoolitseda	doc_278690626946_item	3637307	et	3	main
tuju	doc_278690626946_item	3637299	et	4	main
oma	doc_278690626946_item	3637289	et	4	main
mäletada	doc_278690626946_item	3637288	et	3	main
eestlaste	doc_278690626949_item	3637578	et	4	main
on	doc_278690626949_item	3637576	et	4	main
muusikaga	doc_278690626949_item	3637575	et	3	main
laul	doc_278690626949_item	3637566	et	4	main
stiilid	doc_278690626949_item	3637558	et	4	main
vaimu	doc_278690626949_item	3637552	et	4	main
rahva	doc_278690626949_item	3637551	et	3	main
elada	doc_278690626949_item	3637546	et	3	main
aitas	doc_278690626949_item	3637544	et	3	main
laul	doc_278690626949_item	3637543	et	4	main
laulupidu	doc_278690626949_item	3637536	et	4	main
mõju	doc_278690626949_item	3637532	et	4	main
tähtsam	doc_278690626949_item	3637531	et	4	main
ja	doc_278690626949_item	3637530	et	3	main
laulsid	doc_278690626949_item	3637507	et	4	main
eestlastest	doc_278690626949_item	3637474	et	4	main
teeb	doc_278690626949_item	3637473	et	3	main
teemal	doc_278690626949_item	3637471	et	3	main
eesti	doc_278690626949_item	3637462	et	4	main
rahvuslik	doc_278690626949_item	3637579	et	3	main
ka	doc_278690626950_item	3637908	et	3	main
ära	doc_278690626950_item	3637903	et	4	main
elus	doc_278690626950_item	3637899	et	4	main
olnudki	doc_278690626950_item	3637895	et	4	main
selleta	doc_278690626950_item	3637893	et	3	main
arm	doc_278690626950_item	3637892	et	3	main
minu	doc_278690626950_item	3637891	et	3	main
on	doc_278690626950_item	3637890	et	4	main
gustav	doc_278690626950_item	3637884	et	4	main
tunda	doc_278690626944_item	3636908	et	3	main
on	doc_278690626944_item	3636901	et	4	main
kui	doc_278690626944_item	3636891	et	3	main
üksi	doc_278690626944_item	3636890	et	4	main
oli	doc_278690626944_item	3636889	et	3	main
inimene	doc_278690626944_item	3636888	et	3	main
kui	doc_278690626944_item	3636887	et	3	main
alati	doc_278690626944_item	3636886	et	4	main
aitas	doc_278690626944_item	3636885	et	3	main
laulmine	doc_278690626944_item	3636884	et	4	main
võistlema	doc_278690626944_item	3636883	et	3	main
hakkama	doc_278690626944_item	3636882	et	3	main
saanud	doc_278690626944_item	3636881	et	4	main
ei	doc_278690626944_item	3636880	et	4	main
inimesed	doc_278690626944_item	3636879	et	3	main
laulmiseta	doc_278690626944_item	3636878	et	4	main
ilma	doc_278690626944_item	3636877	et	4	main
vabad	doc_278690626944_item	3636876	et	3	main
on	doc_278690626944_item	3636875	et	4	main
nad	doc_278690626944_item	3636874	et	3	main
sest	doc_278690626944_item	3636873	et	4	main
õnnelikud	doc_278690626944_item	3636872	et	3	main
on	doc_278690626944_item	3636871	et	4	main
eestlased	doc_278690626944_item	3636870	et	3	main
ja	doc_278690626944_item	3636869	et	3	main
eestimaa	doc_278690626944_item	3636868	et	4	main
nüüdne	doc_278690626944_item	3636867	et	3	main
aga	doc_278690626944_item	3636866	et	3	main
ajad	doc_278690626944_item	3636865	et	4	main
rasked	doc_278690626944_item	3636864	et	3	main
olid	doc_278690626944_item	3636863	et	4	main
ajaloos	doc_278690626944_item	3636862	et	4	main
eesti	doc_278690626944_item	3636861	et	4	main
peal	doc_278690626944_item	3636860	et	4	main
kuulatajate	doc_278690626944_item	3636859	et	4	main
positiivselt	doc_278690626944_item	3636858	et	4	main
ta	doc_278690626944_item	3636854	et	4	main
laul	doc_278690626944_item	3636852	et	4	main
inimesed	doc_278690626944_item	3636847	et	3	main
armastasid	doc_278690626946_item	3637452	et	4	main
eestlased	doc_278690626946_item	3637451	et	3	main
ajal	doc_278690626946_item	3637450	et	4	main
vanal	doc_278690626946_item	3637449	et	3	main
ka	doc_278690626946_item	3637448	et	3	main
teevad	doc_278690626946_item	3637447	et	3	main
teevad	doc_278690626946_item	3637441	et	3	main
lapsed	doc_278690626946_item	3637440	et	3	main
ja	doc_278690626946_item	3637435	et	3	main
mis	doc_278690626946_item	3637415	et	4	main
selles	doc_278690626946_item	3637410	et	4	main
võib	doc_278690626946_item	3637405	et	3	main
rõõmsameelsed	doc_278690626946_item	3637402	et	3	main
on	doc_278690626946_item	3637399	et	4	main
hea	doc_278690626946_item	3637396	et	4	main
tavaliselt	doc_278690626946_item	3637395	et	4	main
ka	doc_278690626946_item	3637374	et	3	main
laulab	doc_278690626946_item	3637373	et	3	main
ta	doc_278690626946_item	3637372	et	4	main
juba	doc_278690626946_item	3637370	et	3	main
on	doc_278690626946_item	3637369	et	4	main
ta	doc_278690626946_item	3637368	et	4	main
kui	doc_278690626946_item	3637367	et	3	main
ja	doc_278690626946_item	3637366	et	3	main
lapsepõlves	doc_278690626946_item	3637365	et	4	main
oma	doc_278690626946_item	3637364	et	4	main
laulmise	doc_278690626946_item	3637363	et	4	main
kuuleb	doc_278690626946_item	3637362	et	3	main
tihti	doc_278690626946_item	3637361	et	3	main
laps	doc_278690626946_item	3637360	et	4	main
et	doc_278690626946_item	3637342	et	3	main
sellepärast	doc_278690626946_item	3637341	et	3	main
väga	doc_278690626946_item	3637339	et	3	main
on	doc_278690626946_item	3637338	et	4	main
vastus	doc_278690626946_item	3637337	et	3	main
et	doc_278690626946_item	3637336	et	3	main
seda	doc_278690626946_item	3637333	et	3	main
armastavad	doc_278690626946_item	3637232	et	4	main
või	doc_278690626946_item	3637222	et	4	main
kultuurinähtus	doc_278690626946_item	3637216	et	4	main
või	doc_278690626946_item	3637204	et	4	main
on	doc_278690626946_item	3637197	et	4	main
ühel	doc_278690626946_item	3637194	et	3	main
laulurahva	doc_278690626946_item	3637187	et	3	main
on	doc_278690626946_item	3637180	et	4	main
faktidele	doc_278690626946_item	3637178	et	3	main
esitatud	doc_278690626946_item	3637177	et	4	main
lugemistekstis	doc_278690626946_item	3637176	et	3	main
ja	doc_278690626946_item	3637175	et	3	main
peab	doc_278690626946_item	3637167	et	4	main
kirjutamine	doc_278690626946_item	3637153	et	4	main
test	doc_278690626946_item	3637152	et	3	main
eesti	doc_278690626946_item	3637147	et	4	main
traditsioone	doc_278690626946_item	3637306	et	3	main
mingeid	doc_278690626946_item	3637302	et	3	main
kui	doc_278690626946_item	3637300	et	3	main
andis	doc_278690626946_item	3637296	et	3	main
alati	doc_278690626946_item	3637295	et	4	main
laulmine	doc_278690626946_item	3637294	et	4	main
miks	doc_278690626946_item	3637237	et	4	main
sündinud	doc_278690626949_item	3637556	et	4	main
ajad	doc_278690626949_item	3637548	et	4	main
läbi	doc_278690626949_item	3637545	et	4	main
kõrghetk	doc_278690626949_item	3637542	et	3	main
liikumise	doc_278690626949_item	3637541	et	4	main
kõige	doc_278690626949_item	3637528	et	4	main
ning	doc_278690626949_item	3637527	et	3	main
põllus	doc_278690626949_item	3637526	et	3	main
kirikus	doc_278690626949_item	3637525	et	3	main
minna	doc_278690626949_item	3637524	et	3	main
magama	doc_278690626949_item	3637523	et	3	main
oma	doc_278690626946_item	3637386	et	4	main
ta	doc_278690626946_item	3637383	et	4	main
et	doc_278690626946_item	3637382	et	3	main
mõtlen	doc_278690626946_item	3637381	et	3	main
ma	doc_278690626946_item	3637380	et	3	main
ja	doc_278690626946_item	3637379	et	3	main
meeldib	doc_278690626946_item	3637378	et	3	main
talle	doc_278690626946_item	3637377	et	4	main
see	doc_278690626946_item	3637376	et	3	main
ja	doc_278690626946_item	3637375	et	3	main
laulab	doc_278690626946_item	3637348	et	3	main
armastavad	doc_278690626946_item	3637344	et	4	main
kerge	doc_278690626946_item	3637340	et	4	main
laulavad	doc_278690626946_item	3637328	et	4	main
natsionaalne	doc_278690626946_item	3637325	et	3	main
teab	doc_278690626946_item	3637236	et	3	main
laulda	doc_278690626946_item	3637233	et	4	main
natsionaalne	doc_278690626946_item	3637215	et	3	main
eestlaste	doc_278690626946_item	3637214	et	4	main
mängimine	doc_278690626946_item	3637212	et	4	main
jälgpalli	doc_278690626946_item	3637211	et	4	main
olla	doc_278690626946_item	3637210	et	3	main
võib	doc_278690626946_item	3637209	et	3	main
see	doc_278690626946_item	3637208	et	3	main
riigil	doc_278690626946_item	3637207	et	3	main
järgmisel	doc_278690626946_item	3637206	et	3	main
see	doc_278690626946_item	3637196	et	3	main
natsionaalne	doc_278690626946_item	3637192	et	3	main
on	doc_278690626946_item	3637190	et	4	main
riigil	doc_278690626946_item	3637189	et	3	main
igal	doc_278690626946_item	3637188	et	3	main
teeb	doc_278690626946_item	3637185	et	3	main
näidetega	doc_278690626946_item	3637183	et	3	main
soovitatav	doc_278690626946_item	3637181	et	4	main
väiteid	doc_278690626946_item	3637179	et	4	main
olema	doc_278690626946_item	3637168	et	4	main
pikkus	doc_278690626946_item	3637162	et	4	main
laulurahva	doc_278690626946_item	3637160	et	3	main
eestlastest	doc_278690626946_item	3637159	et	4	main
keele	doc_278690626946_item	3637151	et	4	main
abistas	doc_278690626946_item	3637304	et	3	main
probleeme	doc_278690626946_item	3637303	et	3	main
head	doc_278690626946_item	3637298	et	4	main
eestlastele	doc_278690626946_item	3637297	et	4	main
armastusest	doc_278690626946_item	3637292	et	4	main
abistas	doc_278690626946_item	3637291	et	3	main
vanemaid	doc_278690626946_item	3637290	et	4	main
abistas	doc_278690626946_item	3637283	et	3	main
täna	doc_278690626946_item	3637248	et	4	main
lugesin	doc_278690626946_item	3637247	et	3	main
proovin	doc_278690626946_item	3637243	et	3	main
ei	doc_278690626946_item	3637240	et	4	main
midagi	doc_278690626949_item	3637564	et	4	main
aeg	doc_278690626949_item	3637563	et	3	main
kogu	doc_278690626949_item	3637562	et	4	main
ansamblid	doc_278690626949_item	3637561	et	3	main
on	doc_278690626949_item	3637555	et	4	main
rahvuslikku	doc_278690626949_item	3637540	et	4	main
suurem	doc_278690626949_item	3637529	et	4	main
kui	doc_278690626949_item	3637519	et	3	main
tulles	doc_278690626949_item	3637518	et	4	main
ajal	doc_278690626949_item	3637506	et	4	main
vanadelt	doc_278690626949_item	3637505	et	3	main
juba	doc_278690626949_item	3637504	et	3	main
300	doc_278690626949_item	3637478	et	2	main
ema	doc_278690626946_item	3637356	et	4	main
tegutseb	doc_278690626946_item	3637353	et	3	main
ka	doc_278690626946_item	3637352	et	3	main
vanaema	doc_278690626946_item	3637351	et	4	main
ja	doc_278690626946_item	3637350	et	3	main
tihti	doc_278690626946_item	3637349	et	3	main
teevad	doc_278690626946_item	3637334	et	3	main
nad	doc_278690626946_item	3637332	et	3	main
hästi	doc_278690626946_item	3637329	et	3	main
kultuurinähtus	doc_278690626946_item	3637326	et	4	main
on	doc_278690626946_item	3637323	et	4	main
ilusti	doc_278690626946_item	3637319	et	3	main
laulda	doc_278690626946_item	3637318	et	4	main
saavad	doc_278690626946_item	3637317	et	4	main
eestlased	doc_278690626946_item	3637316	et	3	main
kindlasti	doc_278690626946_item	3637315	et	3	main
arvates	doc_278690626946_item	3637314	et	4	main
minu	doc_278690626946_item	3637313	et	3	main
kaasa	doc_278690626946_item	3637312	et	4	main
laulu	doc_278690626946_item	3637311	et	4	main
alati	doc_278690626946_item	3637310	et	4	main
on	doc_278690626946_item	3637309	et	4	main
kes	doc_278690626946_item	3637235	et	4	main
aga	doc_278690626946_item	3637234	et	3	main
eestis	doc_278690626946_item	3637228	et	3	main
elanik	doc_278690626946_item	3637221	et	3	main
eesti	doc_278690626946_item	3637220	et	4	main
iga	doc_278690626946_item	3637219	et	4	main
laulmine	doc_278690626946_item	3637218	et	4	main
kirjutamine	doc_278690626946_item	3637203	et	4	main
tantsimine	doc_278690626946_item	3637198	et	4	main
riigil	doc_278690626946_item	3637195	et	3	main
kultuurinähtus	doc_278690626946_item	3637193	et	4	main
oma	doc_278690626946_item	3637191	et	4	main
eestlastest	doc_278690626946_item	3637186	et	4	main
arutlev	doc_278690626946_item	3637169	et	4	main
mis	doc_278690626946_item	3637157	et	4	main
keele	doc_278690626946_item	3637148	et	4	main
ütelda	doc_278690626946_item	3637293	et	4	main
eestlastele	doc_278690626946_item	3637284	et	4	main
alati	doc_278690626946_item	3637282	et	4	main
laulmine	doc_278690626946_item	3637281	et	4	main
sotsiaalne	doc_278690626946_item	3637279	et	3	main
ka	doc_278690626946_item	3637278	et	3	main
on	doc_278690626946_item	3637277	et	4	main
see	doc_278690626946_item	3637276	et	3	main
aga	doc_278690626946_item	3637275	et	3	main
väljendusvaheg	doc_278690626946_item	3637274	et	4	main
emotsionaalne	doc_278690626946_item	3637273	et	3	main
ja	doc_278690626946_item	3637272	et	3	main
esteetiline	doc_278690626946_item	3637271	et	3	main
ainult	doc_278690626946_item	3637270	et	4	main
pole	doc_278690626946_item	3637269	et	3	main
see	doc_278690626946_item	3637268	et	3	main
jaoks	doc_278690626946_item	3637267	et	4	main
eestlaste	doc_278690626946_item	3637266	et	4	main
hauani	doc_278690626946_item	3637265	et	3	main
hällist	doc_278690626946_item	3637264	et	4	main
laul	doc_278690626946_item	3637262	et	4	main
eestlast	doc_278690626946_item	3637263	et	4	main
saatis	doc_278690626946_item	3637261	et	3	main
ajal	doc_278690626946_item	3637260	et	4	main
vanal	doc_278690626946_item	3637259	et	3	main
et	doc_278690626946_item	3637258	et	3	main
tean	doc_278690626946_item	3637257	et	3	main
ma	doc_278690626946_item	3637256	et	3	main
nüüd	doc_278690626946_item	3637255	et	4	main
ja	doc_278690626946_item	3637254	et	3	main
laulutraditsioonist	doc_278690626946_item	3637253	et	3	main
ja	doc_278690626946_item	3637252	et	3	main
kultuuriidentiteedist	doc_278690626946_item	3637251	et	4	main
eestlaste	doc_278690626946_item	3637250	et	4	main
tea	doc_278690626946_item	3637241	et	4	main
täpselt	doc_278690626946_item	3637239	et	4	main
mina	doc_278690626946_item	3637238	et	4	main
lauldes	doc_278690626949_item	3637636	et	3	main
teistega	doc_278690626949_item	3637635	et	4	main
tekib	doc_278690626949_item	3637634	et	3	main
mis	doc_278690626949_item	3637633	et	4	main
tunnet	doc_278690626949_item	3637632	et	3	main
seda	doc_278690626949_item	3637631	et	3	main
kogedes	doc_278690626949_item	3637630	et	4	main
kaasa	doc_278690626949_item	3637628	et	4	main
saab	doc_278690626949_item	3637627	et	3	main
laulda	doc_278690626949_item	3637629	et	4	main
kus	doc_278690626949_item	3637626	et	3	main
sõitnud	doc_278690626949_item	3637625	et	4	main
kokku	doc_278690626949_item	3637624	et	3	main
maailma	doc_278690626949_item	3637623	et	4	main
kogu	doc_278690626949_item	3637622	et	4	main
üle	doc_278690626949_item	3637621	et	3	main
laul	doc_278690626949_item	3637571	et	4	main
liikumine	doc_278690626949_item	3637570	et	4	main
protestiline	doc_278690626949_item	3637569	et	4	main
nagu	doc_278690626949_item	3637568	et	3	main
oli	doc_278690626949_item	3637567	et	3	main
tantsus	doc_278690626949_item	3637560	et	3	main
liigutused	doc_278690626949_item	3637559	et	4	main
aegade	doc_278690626949_item	3637554	et	3	main
läbi	doc_278690626949_item	3637553	et	4	main
halvaid	doc_278690626949_item	3637547	et	4	main
tartus	doc_278690626949_item	3637537	et	3	main
esimene	doc_278690626949_item	3637534	et	3	main
laulupeodel	doc_278690626949_item	3637533	et	3	main
kui	doc_278690626949_item	3637513	et	3	main
eestlastega	doc_278690626949_item	3637503	et	4	main
on	doc_278690626949_item	3637500	et	4	main
laul	doc_278690626949_item	3637499	et	4	main
näidetega	doc_278690626949_item	3637498	et	3	main
illustreerida	doc_278690626949_item	3637497	et	3	main
soovitatav	doc_278690626949_item	3637496	et	4	main
on	doc_278690626949_item	3637495	et	4	main
väiteid	doc_278690626949_item	3637494	et	4	main
faktidele	doc_278690626949_item	3637493	et	3	main
esitatud	doc_278690626949_item	3637492	et	4	main
lugemistekstis	doc_278690626949_item	3637491	et	3	main
ja	doc_278690626949_item	3637490	et	3	main
loengus	doc_278690626949_item	3637489	et	3	main
üldistav	doc_278690626949_item	3637487	et	4	main
tuginema	doc_278690626949_item	3637488	et	3	main
ja	doc_278690626949_item	3637486	et	3	main
analüüsiv	doc_278690626949_item	3637485	et	4	main
arutlev	doc_278690626949_item	3637484	et	4	main
olema	doc_278690626949_item	3637483	et	4	main
peab	doc_278690626949_item	3637482	et	4	main
essee	doc_278690626949_item	3637481	et	4	main
sõna	doc_278690626949_item	3637480	et	4	main
350	doc_278690626949_item	3637479	et	2	main
essee	doc_278690626949_item	3637476	et	4	main
mis	doc_278690626949_item	3637472	et	4	main
ja	doc_278690626949_item	3637584	et	3	main
19	doc_278690626949_item	3637581	et	2	main
toimuvad	doc_278690626950_item	3637916	et	4	main
muusikas	doc_278690626950_item	3637910	et	3	main
on	doc_278690626950_item	3637906	et	4	main
ei	doc_278690626950_item	3637901	et	4	main
laul	doc_278690626950_item	3637900	et	4	main
isamaa	doc_278690626950_item	3637889	et	4	main
pidu	doc_278690626950_item	3637871	et	4	main
ilus	doc_278690626950_item	3637870	et	4	main
väga	doc_278690626950_item	3637868	et	3	main
kolm	doc_278690626950_item	3637854	et	3	main
ma	doc_278690626950_item	3637850	et	3	main
kadunud	doc_278690626950_item	3637842	et	4	main
olid	doc_278690626950_item	3637826	et	4	main
kombed	doc_278690626950_item	3637820	et	3	main
uhke	doc_278690626950_item	3637817	et	4	main
ühendamine	doc_278690626950_item	3637808	et	4	main
mõtlen	doc_278690626950_item	3637805	et	3	main
see	doc_278690626950_item	3637801	et	3	main
ülemaaline	doc_278690626949_item	3637535	et	4	main
lastele	doc_278690626949_item	3637520	et	4	main
mehi	doc_278690626949_item	3637516	et	3	main
ootasid	doc_278690626949_item	3637515	et	4	main
naised	doc_278690626949_item	3637514	et	3	main
rahvas	doc_278690626949_item	3637512	et	4	main
kõik	doc_278690626949_item	3637511	et	4	main
lapsed	doc_278690626949_item	3637510	et	3	main
mehed	doc_278690626949_item	3637509	et	3	main
naised	doc_278690626949_item	3637508	et	3	main
koos	doc_278690626949_item	3637502	et	4	main
keele	doc_278690626949_item	3637466	et	4	main
on	doc_278690626949_item	3637586	et	4	main
laulmine	doc_278690626949_item	3637585	et	4	main
haridus	doc_278690626949_item	3637583	et	3	main
näiteks	doc_278690626950_item	3637914	et	4	main
teemad	doc_278690626950_item	3637913	et	3	main
populaarne	doc_278690626950_item	3637909	et	3	main
ja	doc_278690626950_item	3637904	et	3	main
lauluajalood	doc_278690626950_item	3637896	et	4	main
kõlas	doc_278690626950_item	3637883	et	4	main
ajal	doc_278690626950_item	3637882	et	4	main
kõige	doc_278690626950_item	3637874	et	4	main
ja	doc_278690626950_item	3637867	et	3	main
tore	doc_278690626950_item	3637865	et	3	main
laulupeol	doc_278690626950_item	3637862	et	4	main
tantsime	doc_278690626950_item	3637861	et	3	main
ja	doc_278690626950_item	3637860	et	3	main
tallinnasse	doc_278690626950_item	3637859	et	3	main
sõitsime	doc_278690626950_item	3637858	et	3	main
me	doc_278690626950_item	3637857	et	4	main
tagasi	doc_278690626950_item	3637856	et	3	main
siis	doc_278690626950_item	3637849	et	3	main
ei	doc_278690626950_item	3637840	et	4	main
aeg	doc_278690626949_item	3637522	et	3	main
oli	doc_278690626949_item	3637521	et	3	main
töölt	doc_278690626949_item	3637517	et	3	main
olnud	doc_278690626949_item	3637501	et	4	main
laulurahva	doc_278690626949_item	3637475	et	3	main
essee	doc_278690626949_item	3637470	et	4	main
kirjutage	doc_278690626949_item	3637469	et	3	main
kirjutamine	doc_278690626949_item	3637468	et	4	main
test	doc_278690626949_item	3637467	et	3	main
erilised	doc_278690626950_item	3637912	et	4	main
praegu	doc_278690626950_item	3637907	et	3	main
ei	doc_278690626950_item	3637894	et	4	main
ernesaksa	doc_278690626950_item	3637885	et	4	main
aasta	doc_278690626950_item	3637876	et	4	main
tähtsam	doc_278690626950_item	3637875	et	4	main
aastat	doc_278690626950_item	3637855	et	3	main
käisin	doc_278690626950_item	3637851	et	3	main
ole	doc_278690626950_item	3637841	et	4	main
vabadussõda	doc_278690626950_item	3637827	et	4	main
ja	doc_278690626950_item	3637824	et	3	main
hästi	doc_278690626950_item	3637822	et	3	main
eestlaste	doc_278690626950_item	3637819	et	4	main
inimeste	doc_278690626950_item	3637807	et	3	main
ühendamine	doc_278690626950_item	3637804	et	4	main
oli	doc_278690626950_item	3637802	et	3	main
arvan	doc_278690626950_item	3637799	et	3	main
vanemuise	doc_278690626950_item	3637793	et	4	main
tuli	doc_278690626950_item	3637792	et	4	main
aastal	doc_278690626950_item	3637782	et	3	main
on	doc_278690626950_item	3637750	et	4	main
on	doc_278690626950_item	3637744	et	4	main
eestlased	doc_278690626950_item	3637743	et	3	main
aeg	doc_278690626950_item	3637738	et	3	main
oli	doc_278690626950_item	3637731	et	3	main
tähtsad	doc_278690626950_item	3637724	et	3	main
on	doc_278690626950_item	3637723	et	4	main
riigis	doc_278690626950_item	3637719	et	3	main
tore	doc_278690626950_item	3637716	et	3	main
on	doc_278690626950_item	3637703	et	4	main
rahval	doc_278690626950_item	3637702	et	3	main
et	doc_278690626950_item	3637692	et	3	main
elus	doc_278690626950_item	3637681	et	4	main
inimeste	doc_278690626950_item	3637680	et	3	main
asi	doc_278690626950_item	3637679	et	4	main
soovitatav	doc_278690626950_item	3637673	et	4	main
arutlev	doc_278690626950_item	3637661	et	4	main
ei	doc_278690626950_item	3637970	et	4	main
ja	doc_278690626950_item	3637967	et	3	main
sõber	doc_278690626950_item	3637965	et	3	main
veel	doc_278690626950_item	3637958	et	4	main
eesti	doc_278690626950_item	3637955	et	4	main
on	doc_278690626950_item	3637954	et	4	main
sõpradega	doc_278690626950_item	3637950	et	3	main
kuhu	doc_278690626950_item	3637946	et	3	main
see	doc_278690626950_item	3637944	et	3	main
keele	doc_278690626950_item	3637643	et	4	main
inimesed	doc_278690626951_item	3638130	et	3	main
manifestatsioon	doc_278690626951_item	3638121	et	3	main
ja	doc_278690626951_item	3638118	et	3	main
jõud	doc_278690626951_item	3638105	et	4	main
tunnevad	doc_278690626951_item	3638103	et	3	main
võitsid	doc_278690626951_item	3638094	et	4	main
seal	doc_278690626951_item	3638093	et	4	main
tartus	doc_278690626951_item	3638092	et	3	main
korraldati	doc_278690626951_item	3638091	et	3	main
ka	doc_278690626951_item	3638085	et	3	main
asi	doc_278690626951_item	3638065	et	4	main
pikkus	doc_278690626949_item	3637477	et	4	main
teise	doc_278690626949_item	3637465	et	4	main
kui	doc_278690626949_item	3637464	et	3	main
keele	doc_278690626949_item	3637463	et	4	main
essee	doc_278690626949_item	3637461	et	4	main
on	doc_278690626949_item	3637620	et	4	main
kes	doc_278690626949_item	3637619	et	4	main
tuttavaid	doc_278690626949_item	3637618	et	3	main
ja	doc_278690626949_item	3637617	et	3	main
sugulasi	doc_278690626949_item	3637616	et	3	main
sõpru	doc_278690626949_item	3637615	et	3	main
kohata	doc_278690626949_item	3637614	et	4	main
lootuses	doc_278690626949_item	3637613	et	4	main
perega	doc_278690626949_item	3637612	et	3	main
koos	doc_278690626949_item	3637611	et	4	main
tullakse	doc_278690626949_item	3637610	et	3	main
kuhu	doc_278690626949_item	3637609	et	3	main
pidudel	doc_278690626949_item	3637608	et	4	main
eestlasi	doc_278690626949_item	3637607	et	3	main
ühendab	doc_278690626949_item	3637606	et	3	main
laul	doc_278690626949_item	3637605	et	4	main
elu	doc_278690626949_item	3637604	et	4	main
on	doc_278690626949_item	3637603	et	4	main
ja	doc_278690626949_item	3637602	et	3	main
oli	doc_278690626949_item	3637601	et	3	main
laul	doc_278690626949_item	3637600	et	4	main
jaoks	doc_278690626949_item	3637599	et	4	main
eestlastele	doc_278690626949_item	3637598	et	4	main
olukord	doc_278690626949_item	3637597	et	3	main
praegune	doc_278690626949_item	3637596	et	3	main
oli	doc_278690626949_item	3637595	et	3	main
milline	doc_278690626949_item	3637594	et	3	main
sellest	doc_278690626949_item	3637593	et	4	main
olid	doc_278690626949_item	3637592	et	4	main
lastelaulud	doc_278690626949_item	3637591	et	3	main
muinasjutud	doc_278690626949_item	3637590	et	3	main
rahvaluuled	doc_278690626949_item	3637589	et	3	main
seotud	doc_278690626949_item	3637588	et	4	main
koos	doc_278690626949_item	3637587	et	4	main
sajandil	doc_278690626949_item	3637582	et	3	main
ärkamine	doc_278690626949_item	3637580	et	4	main
nende	doc_278690626950_item	3637928	et	4	main
on	doc_278690626950_item	3637927	et	4	main
pillimäng	doc_278690626950_item	3637926	et	3	main
tants	doc_278690626950_item	3637925	et	3	main
laul	doc_278690626950_item	3637924	et	4	main
et	doc_278690626950_item	3637923	et	3	main
sest	doc_278690626950_item	3637922	et	4	main
laulurahv	doc_278690626950_item	3637921	et	4	main
on	doc_278690626950_item	3637920	et	4	main
eestlased	doc_278690626950_item	3637919	et	3	main
muidugi	doc_278690626950_item	3637918	et	4	main
kontserdid	doc_278690626950_item	3637917	et	3	main
värskas	doc_278690626950_item	3637915	et	4	main
on	doc_278690626950_item	3637911	et	4	main
rahvalaul	doc_278690626950_item	3637905	et	4	main
kadunud	doc_278690626950_item	3637902	et	4	main
kaasaegsases	doc_278690626950_item	3637898	et	4	main
hästi	doc_278690626950_item	3637897	et	3	main
mu	doc_278690626950_item	3637888	et	3	main
isamaalaul	doc_278690626950_item	3637887	et	4	main
hingestatud	doc_278690626950_item	3637886	et	4	main
tol	doc_278690626950_item	3637881	et	3	main
et	doc_278690626950_item	3637880	et	3	main
sest	doc_278690626950_item	3637879	et	4	main
1969	doc_278690626950_item	3637878	et	2	main
oli	doc_278690626950_item	3637877	et	3	main
et	doc_278690626950_item	3637873	et	3	main
väga	doc_278690626950_item	3637869	et	3	main
huvitav	doc_278690626950_item	3637866	et	4	main
see	doc_278690626950_item	3637863	et	3	main
tantsuringis	doc_278690626950_item	3637852	et	3	main
koolis	doc_278690626950_item	3637848	et	4	main
veel	doc_278690626950_item	3637846	et	4	main
ma	doc_278690626950_item	3637845	et	3	main
kui	doc_278690626950_item	3637844	et	3	main
ära	doc_278690626950_item	3637843	et	4	main
elus	doc_278690626950_item	3637836	et	4	main
meie	doc_278690626950_item	3637835	et	4	main
on	doc_278690626950_item	3637834	et	4	main
laulupeod	doc_278690626950_item	3637833	et	4	main
siis	doc_278690626950_item	3637832	et	3	main
sõda	doc_278690626950_item	3637831	et	4	main
maailma	doc_278690626950_item	3637830	et	4	main
teine	doc_278690626950_item	3637829	et	3	main
ja	doc_278690626950_item	3637828	et	3	main
kui	doc_278690626950_item	3637825	et	3	main
säilinud	doc_278690626950_item	3637823	et	4	main
johann	doc_278690626950_item	3637796	et	4	main
teostus	doc_278690626950_item	3637791	et	4	main
ja	doc_278690626950_item	3637790	et	3	main
laulupidu	doc_278690626950_item	3637786	et	4	main
toimus	doc_278690626950_item	3637784	et	3	main
1869	doc_278690626950_item	3637781	et	2	main
nad	doc_278690626950_item	3637740	et	3	main
hea	doc_278690626950_item	3637737	et	4	main
halb	doc_278690626950_item	3637732	et	3	main
arvan	doc_278690626950_item	3637872	et	3	main
oli	doc_278690626950_item	3637864	et	3	main
ja	doc_278690626950_item	3637853	et	3	main
õpisin	doc_278690626950_item	3637847	et	4	main
komme	doc_278690626950_item	3637839	et	4	main
see	doc_278690626950_item	3637838	et	3	main
ja	doc_278690626950_item	3637837	et	3	main
on	doc_278690626950_item	3637821	et	4	main
et	doc_278690626950_item	3637818	et	3	main
silmaringi	doc_278690626950_item	3637815	et	4	main
suurendab	doc_278690626950_item	3637814	et	3	main
ja	doc_278690626950_item	3637813	et	3	main
fantaasiat	doc_278690626950_item	3637812	et	3	main
arendab	doc_278690626950_item	3637811	et	3	main
kultuuri	doc_278690626950_item	3637810	et	4	main
tõstab	doc_278690626950_item	3637809	et	3	main
inimeste	doc_278690626950_item	3637803	et	3	main
et	doc_278690626950_item	3637800	et	3	main
seltsist	doc_278690626950_item	3637794	et	4	main
korraldamise	doc_278690626950_item	3637788	et	4	main
laulav	doc_278690626950_item	3637752	et	4	main
väga	doc_278690626950_item	3637751	et	3	main
laulurahv	doc_278690626950_item	3637745	et	4	main
tõstsid	doc_278690626950_item	3637741	et	4	main
oli	doc_278690626950_item	3637736	et	3	main
kui	doc_278690626950_item	3637730	et	3	main
nad	doc_278690626950_item	3637728	et	3	main
meie	doc_278690626950_item	3637718	et	4	main
on	doc_278690626950_item	3637714	et	4	main
ja	doc_278690626950_item	3637709	et	3	main
igav	doc_278690626950_item	3637698	et	3	main
arvan	doc_278690626950_item	3637691	et	3	main
ja	doc_278690626950_item	3637689	et	3	main
tõsta	doc_278690626950_item	3637687	et	4	main
võib	doc_278690626950_item	3637685	et	3	main
sest	doc_278690626950_item	3637682	et	4	main
muusika	doc_278690626950_item	3637676	et	4	main
näidetega	doc_278690626950_item	3637675	et	3	main
on	doc_278690626950_item	3637672	et	4	main
olema	doc_278690626950_item	3637660	et	4	main
selleta	doc_278690626950_item	3637969	et	3	main
arst	doc_278690626950_item	3637966	et	3	main
hea	doc_278690626950_item	3637964	et	4	main
ja	doc_278690626950_item	3637957	et	3	main
sugulastega	doc_278690626950_item	3637951	et	4	main
on	doc_278690626950_item	3637943	et	4	main
teemal	doc_278690626950_item	3637648	et	3	main
essee	doc_278690626950_item	3637647	et	4	main
kirjutage	doc_278690626950_item	3637646	et	3	main
praegu	doc_278690626951_item	3638131	et	3	main
seotud	doc_278690626951_item	3638128	et	4	main
repertuar	doc_278690626951_item	3638126	et	4	main
vanem	doc_278690626951_item	3638125	et	4	main
nii	doc_278690626951_item	3638124	et	3	main
aga	doc_278690626951_item	3638123	et	3	main
ka	doc_278690626951_item	3638116	et	3	main
laulupeod	doc_278690626951_item	3638114	et	4	main
praegu	doc_278690626951_item	3638113	et	3	main
tugevam	doc_278690626951_item	3638112	et	4	main
eestlased	doc_278690626951_item	3638111	et	3	main
teeb	doc_278690626951_item	3638110	et	3	main
laulurahva	doc_278690626951_item	3638109	et	3	main
et	doc_278690626951_item	3638108	et	3	main
arvan	doc_278690626951_item	3638107	et	3	main
ma	doc_278690626951_item	3638106	et	3	main
iseseisvus	doc_278690626951_item	3638101	et	4	main
oma	doc_278690626951_item	3638100	et	4	main
nad	doc_278690626951_item	3638098	et	3	main
rahva	doc_278690626951_item	3638097	et	3	main
ajaloost	doc_278690626951_item	3638076	et	4	main
sümbolitele	doc_278690626951_item	3638075	et	3	main
kuultur	doc_278690626951_item	3638073	et	4	main
näidab	doc_278690626951_item	3638069	et	4	main
see	doc_278690626951_item	3638068	et	3	main
jaoks	doc_278690626951_item	3638067	et	4	main
rahva	doc_278690626951_item	3638066	et	3	main
on	doc_278690626951_item	3638062	et	4	main
laulavad	doc_278690626951_item	3638035	et	4	main
vanal	doc_278690626951_item	3638033	et	3	main
eesti	doc_278690626951_item	3638025	et	4	main
ajal	doc_278690626951_item	3638024	et	4	main
keele	doc_278690626951_item	3637979	et	4	main
olen	doc_278690626950_item	3637816	et	3	main
et	doc_278690626950_item	3637806	et	3	main
eesotsas	doc_278690626950_item	3637795	et	4	main
idee	doc_278690626950_item	3637789	et	4	main
esimene	doc_278690626950_item	3637785	et	3	main
iseväljendamine	doc_278690626950_item	3637780	et	3	main
on	doc_278690626950_item	3637779	et	4	main
laul	doc_278690626950_item	3637778	et	4	main
kooris	doc_278690626950_item	3637777	et	4	main
kahekesi	doc_278690626950_item	3637776	et	3	main
üksi	doc_278690626950_item	3637775	et	4	main
lauldi	doc_278690626950_item	3637774	et	3	main
mängisid	doc_278690626950_item	3637773	et	4	main
kui	doc_278690626950_item	3637772	et	3	main
laulsid	doc_278690626950_item	3637771	et	4	main
lapsed	doc_278690626950_item	3637770	et	3	main
lastele	doc_278690626950_item	3637769	et	4	main
laulsid	doc_278690626950_item	3637768	et	4	main
naised	doc_278690626950_item	3637767	et	3	main
töötasid	doc_278690626950_item	3637766	et	4	main
kui	doc_278690626950_item	3637765	et	3	main
laulsid	doc_278690626950_item	3637764	et	4	main
inimesed	doc_278690626950_item	3637763	et	3	main
varem	doc_278690626950_item	3637762	et	4	main
traditsioonlaulmine	doc_278690626950_item	3637761	et	4	main
on	doc_278690626950_item	3637760	et	4	main
see	doc_278690626950_item	3637759	et	3	main
kultuuris	doc_278690626950_item	3637758	et	3	main
juba	doc_278690626950_item	3637757	et	3	main
on	doc_278690626950_item	3637756	et	4	main
jannseniga	doc_278690626950_item	3637798	et	4	main
voldemar	doc_278690626950_item	3637797	et	4	main
mille	doc_278690626950_item	3637787	et	3	main
tartus	doc_278690626950_item	3637783	et	3	main
laul	doc_278690626950_item	3637755	et	4	main
muidugi	doc_278690626950_item	3637754	et	4	main
ja	doc_278690626950_item	3637753	et	3	main
meeleolu	doc_278690626950_item	3637742	et	4	main
ja	doc_278690626950_item	3637734	et	3	main
aeg	doc_278690626950_item	3637733	et	3	main
aitasid	doc_278690626950_item	3637729	et	4	main
laulupeod	doc_278690626950_item	3637721	et	4	main
igal	doc_278690626950_item	3637701	et	3	main
muusikata	doc_278690626950_item	3637694	et	3	main
ma	doc_278690626950_item	3637690	et	3	main
tähtis	doc_278690626950_item	3637678	et	4	main
loengus	doc_278690626950_item	3637666	et	3	main
tuginema	doc_278690626950_item	3637665	et	3	main
üldistav	doc_278690626950_item	3637664	et	4	main
ja	doc_278690626950_item	3637663	et	3	main
analüüsiv	doc_278690626950_item	3637662	et	4	main
saa	doc_278690626950_item	3637971	et	4	main
on	doc_278690626950_item	3637963	et	4	main
muusika	doc_278690626950_item	3637962	et	4	main
et	doc_278690626950_item	3637961	et	3	main
laul	doc_278690626950_item	3637953	et	4	main
tuttavatega	doc_278690626950_item	3637952	et	3	main
koos	doc_278690626950_item	3637949	et	4	main
laulupidu	doc_278690626950_item	3637942	et	4	main
eesti	doc_278690626950_item	3637941	et	4	main
kujuneda	doc_278690626950_item	3637940	et	3	main
saa	doc_278690626950_item	3637939	et	4	main
ei	doc_278690626950_item	3637938	et	4	main
seda	doc_278690626950_item	3637937	et	3	main
ilma	doc_278690626950_item	3637936	et	4	main
ja	doc_278690626950_item	3637935	et	3	main
rahvapidu	doc_278690626950_item	3637934	et	4	main
suur	doc_278690626950_item	3637933	et	3	main
on	doc_278690626950_item	3637932	et	4	main
laulupidu	doc_278690626950_item	3637931	et	4	main
ajaloos	doc_278690626950_item	3637930	et	4	main
essee	doc_278690626950_item	3637658	et	4	main
elus	doc_278690626950_item	3637929	et	4	main
sõna	doc_278690626950_item	3637657	et	4	main
350	doc_278690626950_item	3637656	et	2	main
300	doc_278690626950_item	3637655	et	2	main
pikkus	doc_278690626950_item	3637654	et	4	main
keel	doc_278690626950_item	3637749	et	4	main
nende	doc_278690626950_item	3637748	et	4	main
et	doc_278690626950_item	3637747	et	3	main
sest	doc_278690626950_item	3637746	et	4	main
siis	doc_278690626950_item	3637739	et	3	main
kui	doc_278690626950_item	3637735	et	3	main
sest	doc_278690626950_item	3637726	et	4	main
toimuvad	doc_278690626950_item	3637720	et	4	main
see	doc_278690626950_item	3637713	et	3	main
mina	doc_278690626950_item	3637710	et	4	main
oma	doc_278690626950_item	3637704	et	4	main
ja	doc_278690626950_item	3637699	et	3	main
meeleolu	doc_278690626950_item	3637688	et	4	main
rahuldada	doc_278690626950_item	3637686	et	3	main
ta	doc_278690626950_item	3637684	et	4	main
et	doc_278690626950_item	3637683	et	3	main
on	doc_278690626950_item	3637677	et	4	main
abi	doc_278690626950_item	3637968	et	4	main
sümbol	doc_278690626950_item	3637956	et	3	main
võib	doc_278690626950_item	3637947	et	3	main
pidu	doc_278690626950_item	3637945	et	4	main
eestlastest	doc_278690626950_item	3637651	et	4	main
mis	doc_278690626950_item	3637649	et	4	main
keele	doc_278690626950_item	3637640	et	4	main
vaiksed	doc_278690626951_item	3638129	et	3	main
on	doc_278690626951_item	3638127	et	4	main
rahvusele	doc_278690626951_item	3638120	et	3	main
laulupidu	doc_278690626951_item	3638090	et	4	main
on	doc_278690626951_item	3638083	et	4	main
lauluharrastusega	doc_278690626951_item	3638082	et	3	main
muusika	doc_278690626951_item	3638080	et	4	main
teame	doc_278690626951_item	3638078	et	3	main
tähtis	doc_278690626951_item	3638064	et	4	main
rahvalaul	doc_278690626951_item	3638061	et	4	main
rahvalaulad	doc_278690626951_item	3638032	et	4	main
regivärsilised	doc_278690626951_item	3638031	et	4	main
vanemad	doc_278690626951_item	3638026	et	4	main
eestlastest	doc_278690626951_item	3637987	et	4	main
essee	doc_278690626951_item	3637983	et	4	main
kirjutage	doc_278690626951_item	3637982	et	3	main
kirjutamine	doc_278690626951_item	3637981	et	4	main
test	doc_278690626951_item	3637980	et	3	main
regilaulu	doc_278690626952_item	3638246	et	4	main
aastat	doc_278690626952_item	3638244	et	3	main
muusika	doc_278690626952_item	3638236	et	4	main
ilma	doc_278690626952_item	3638235	et	4	main
neid	doc_278690626952_item	3638233	et	4	main
et	doc_278690626952_item	3638232	et	3	main
erinevus	doc_278690626952_item	3638229	et	4	main
eesti	doc_278690626952_item	3638219	et	4	main
ajad	doc_278690626952_item	3638212	et	4	main
olles	doc_278690626952_item	3638203	et	3	main
hauani	doc_278690626952_item	3638200	et	3	main
eestlasest	doc_278690626952_item	3638198	et	3	main
laul	doc_278690626952_item	3638197	et	4	main
saatis	doc_278690626952_item	3638196	et	3	main
sümbool	doc_278690626952_item	3638185	et	4	main
rahvas	doc_278690626952_item	3638176	et	4	main
igas	doc_278690626952_item	3638175	et	3	main
näidetega	doc_278690626952_item	3638174	et	3	main
on	doc_278690626952_item	3638171	et	4	main
teise	doc_278690626952_item	3638141	et	4	main
kui	doc_278690626952_item	3638140	et	3	main
keele	doc_278690626952_item	3638139	et	4	main
väga	doc_278690626952_item	3638342	et	3	main
muusika	doc_278690626952_item	3638340	et	4	main
aluse	doc_278690626952_item	3638335	et	4	main
sai	doc_278690626952_item	3638329	et	4	main
asutamine	doc_278690626952_item	3638298	et	4	main
puhkpilliorkestrite	doc_278690626952_item	3638297	et	3	main
ka	doc_278690626952_item	3638296	et	3	main
kaasnes	doc_278690626952_item	3638295	et	3	main
levikuga	doc_278690626952_item	3638294	et	3	main
õpetasid	doc_278690626952_item	3638289	et	4	main
ka	doc_278690626952_item	3638283	et	3	main
vaimulike	doc_278690626952_item	3638279	et	3	main
laulmine	doc_278690626952_item	3638273	et	4	main
kaasnes	doc_278690626952_item	3638270	et	3	main
kahe	doc_278690626952_item	3638267	et	3	main
et	doc_278690626950_item	3637727	et	3	main
peod	doc_278690626950_item	3637725	et	4	main
laulupeod	doc_278690626950_item	3637722	et	4	main
et	doc_278690626950_item	3637717	et	3	main
väga	doc_278690626950_item	3637715	et	3	main
et	doc_278690626950_item	3637712	et	3	main
arvan	doc_278690626950_item	3637711	et	3	main
kombed	doc_278690626950_item	3637708	et	3	main
ja	doc_278690626950_item	3637707	et	3	main
tantsud	doc_278690626950_item	3637706	et	3	main
muusika	doc_278690626950_item	3637705	et	4	main
hall	doc_278690626950_item	3637700	et	4	main
väga	doc_278690626950_item	3637697	et	3	main
oleks	doc_278690626950_item	3637696	et	3	main
elu	doc_278690626950_item	3637695	et	4	main
ilma	doc_278690626950_item	3637693	et	4	main
illustreerida	doc_278690626950_item	3637674	et	3	main
väiteid	doc_278690626950_item	3637671	et	4	main
faktidele	doc_278690626950_item	3637670	et	3	main
esitatud	doc_278690626950_item	3637669	et	4	main
lugemistekstis	doc_278690626950_item	3637668	et	3	main
ja	doc_278690626950_item	3637667	et	3	main
peab	doc_278690626950_item	3637659	et	4	main
elada	doc_278690626950_item	3637972	et	3	main
öelda	doc_278690626950_item	3637960	et	4	main
tahan	doc_278690626950_item	3637959	et	3	main
minna	doc_278690626950_item	3637948	et	3	main
laulurahva	doc_278690626950_item	3637652	et	3	main
teeb	doc_278690626950_item	3637650	et	3	main
kirjutamine	doc_278690626950_item	3637645	et	4	main
test	doc_278690626950_item	3637644	et	3	main
eesti	doc_278690626950_item	3637639	et	4	main
massilisem	doc_278690626951_item	3638119	et	4	main
eestlaste	doc_278690626951_item	3638086	et	4	main
me	doc_278690626951_item	3638077	et	4	main
ja	doc_278690626951_item	3638072	et	3	main
rahvuslik	doc_278690626951_item	3638070	et	3	main
väga	doc_278690626951_item	3638063	et	3	main
et	doc_278690626951_item	3638060	et	3	main
selline	doc_278690626951_item	3638059	et	4	main
on	doc_278690626951_item	3638058	et	4	main
seisukoht	doc_278690626951_item	3638057	et	3	main
minu	doc_278690626951_item	3638056	et	3	main
kuulturile	doc_278690626951_item	3638030	et	4	main
läänemeresoome	doc_278690626951_item	3638029	et	3	main
esindavad	doc_278690626951_item	3638028	et	4	main
300	doc_278690626951_item	3637991	et	2	main
essee	doc_278690626951_item	3637989	et	4	main
laulurahva	doc_278690626951_item	3637988	et	3	main
eesti	doc_278690626951_item	3637975	et	4	main
essee	doc_278690626951_item	3637974	et	4	main
eeslaulja	doc_278690626952_item	3638249	et	4	main
instrumenti	doc_278690626952_item	3638237	et	4	main
regilaul	doc_278690626952_item	3638223	et	4	main
nimetatakse	doc_278690626952_item	3638222	et	3	main
alati	doc_278690626952_item	3638215	et	4	main
töötades	doc_278690626952_item	3638204	et	3	main
hällist	doc_278690626952_item	3638199	et	4	main
ei	doc_278690626952_item	3638192	et	4	main
veel	doc_278690626952_item	3638191	et	4	main
ajal	doc_278690626952_item	3638189	et	4	main
et	doc_278690626952_item	3638182	et	3	main
ma	doc_278690626952_item	3638180	et	3	main
oma	doc_278690626952_item	3638178	et	4	main
on	doc_278690626952_item	3638177	et	4	main
pikkus	doc_278690626952_item	3638153	et	4	main
mis	doc_278690626952_item	3638148	et	4	main
essee	doc_278690626952_item	3638137	et	4	main
torupillipäevad	doc_278690626952_item	3638347	et	3	main
folklooriüritused	doc_278690626952_item	3638346	et	3	main
organiseeritakse	doc_278690626952_item	3638345	et	3	main
on	doc_278690626952_item	3638341	et	4	main
tänapäevadel	doc_278690626952_item	3638339	et	3	main
üldlaulupidude	doc_278690626952_item	3638337	et	4	main
mis	doc_278690626952_item	3638309	et	4	main
tartus	doc_278690626952_item	3638308	et	3	main
koorilaulu	doc_278690626952_item	3638293	et	4	main
külakoolid	doc_278690626952_item	3638288	et	3	main
levima	doc_278690626952_item	3638282	et	3	main
aga	doc_278690626952_item	3638278	et	3	main
sajandil	doc_278690626952_item	3638276	et	3	main
kooriga	doc_278690626952_item	3638268	et	4	main
jaoks	doc_278690626953_item	3638494	et	4	main
pere	doc_278690626953_item	3638493	et	4	main
see	doc_278690626953_item	3638489	et	3	main
ja	doc_278690626953_item	3638487	et	3	main
maad	doc_278690626953_item	3638484	et	4	main
lootuses	doc_278690626953_item	3638467	et	4	main
rahvapidu	doc_278690626953_item	3638462	et	4	main
on	doc_278690626953_item	3638461	et	4	main
laulupidu	doc_278690626953_item	3638460	et	4	main
esinevad	doc_278690626953_item	3638455	et	4	main
ajalugu	doc_278690626953_item	3638445	et	4	main
essee	doc_278690626950_item	3637653	et	4	main
teise	doc_278690626950_item	3637642	et	4	main
kui	doc_278690626950_item	3637641	et	3	main
essee	doc_278690626950_item	3637638	et	4	main
heliloominguga	doc_278690626951_item	3638135	et	3	main
profesionaalse	doc_278690626951_item	3638134	et	4	main
seotud	doc_278690626951_item	3638133	et	4	main
see	doc_278690626951_item	3638132	et	3	main
eestis	doc_278690626951_item	3638122	et	3	main
tähelepanuvad	doc_278690626951_item	3638117	et	4	main
on	doc_278690626951_item	3638115	et	4	main
oma	doc_278690626951_item	3638104	et	4	main
ja	doc_278690626951_item	3638102	et	3	main
tunnevad	doc_278690626951_item	3638099	et	3	main
palju	doc_278690626951_item	3638096	et	4	main
osa	doc_278690626951_item	3638095	et	4	main
esimene	doc_278690626951_item	3638089	et	3	main
ärkamine	doc_278690626951_item	3638088	et	4	main
rahvuslik	doc_278690626951_item	3638087	et	3	main
seotud	doc_278690626951_item	3638084	et	4	main
ja	doc_278690626951_item	3638081	et	3	main
et	doc_278690626951_item	3638079	et	3	main
rajatud	doc_278690626951_item	3638074	et	4	main
identiteeditunne	doc_278690626951_item	3638071	et	3	main
koorilaulu	doc_278690626951_item	3638055	et	4	main
regilaulu	doc_278690626951_item	3638054	et	4	main
laulad	doc_278690626951_item	3638053	et	3	main
erilised	doc_278690626951_item	3638052	et	4	main
olid	doc_278690626951_item	3638051	et	4	main
kiirikuses	doc_278690626951_item	3638050	et	4	main
laulsid	doc_278690626951_item	3638049	et	4	main
mis	doc_278690626951_item	3638048	et	4	main
laulad	doc_278690626951_item	3638047	et	3	main
on	doc_278690626951_item	3638046	et	4	main
see	doc_278690626951_item	3638045	et	3	main
salmid	doc_278690626951_item	3638044	et	4	main
laulsid	doc_278690626951_item	3638043	et	4	main
ka	doc_278690626951_item	3638042	et	3	main
mehed	doc_278690626951_item	3638041	et	3	main
hiljem	doc_278690626951_item	3638039	et	3	main
aga	doc_278690626951_item	3638038	et	3	main
naised	doc_278690626951_item	3638037	et	3	main
laulavad	doc_278690626951_item	3638040	et	4	main
põhiliselt	doc_278690626951_item	3638036	et	4	main
teeb	doc_278690626951_item	3637986	et	3	main
teemal	doc_278690626951_item	3637984	et	3	main
keele	doc_278690626951_item	3637976	et	4	main
ja	doc_278690626952_item	3638250	et	3	main
enam	doc_278690626952_item	3638241	et	4	main
on	doc_278690626952_item	3638230	et	4	main
regilaulu	doc_278690626952_item	3638228	et	4	main
naised	doc_278690626952_item	3638227	et	3	main
lauldi	doc_278690626952_item	3638226	et	3	main
need	doc_278690626952_item	3638225	et	3	main
tavaliselt	doc_278690626952_item	3638224	et	4	main
üleelada	doc_278690626952_item	3638218	et	4	main
need	doc_278690626952_item	3638217	et	3	main
aitas	doc_278690626952_item	3638216	et	3	main
rasked	doc_278690626952_item	3638211	et	3	main
ajaloos	doc_278690626952_item	3638209	et	4	main
rahva	doc_278690626952_item	3638208	et	3	main
eestlaste	doc_278690626952_item	3638207	et	4	main
kiigutades	doc_278690626952_item	3638206	et	3	main
üksi	doc_278690626952_item	3638202	et	4	main
lauldi	doc_278690626952_item	3638201	et	3	main
eestlastest	doc_278690626952_item	3638183	et	4	main
300	doc_278690626952_item	3638154	et	2	main
laulurahva	doc_278690626952_item	3638151	et	3	main
ajal	doc_278690626951_item	3638034	et	4	main
laulutraditsioonid	doc_278690626951_item	3638027	et	3	main
vana	doc_278690626951_item	3638023	et	4	main
laulsid	doc_278690626951_item	3638022	et	4	main
ja	doc_278690626951_item	3638021	et	3	main
praegu	doc_278690626951_item	3638020	et	3	main
laulavad	doc_278690626951_item	3638019	et	4	main
kultuuris	doc_278690626951_item	3638018	et	3	main
osa	doc_278690626951_item	3638017	et	4	main
tähtis	doc_278690626951_item	3638016	et	4	main
väga	doc_278690626951_item	3638015	et	3	main
on	doc_278690626951_item	3638014	et	4	main
see	doc_278690626951_item	3638013	et	3	main
laulmine	doc_278690626951_item	3638012	et	4	main
näidetega	doc_278690626951_item	3638011	et	3	main
illustreerida	doc_278690626951_item	3638010	et	3	main
soovitatav	doc_278690626951_item	3638009	et	4	main
on	doc_278690626951_item	3638008	et	4	main
väiteid	doc_278690626951_item	3638007	et	4	main
faktidele	doc_278690626951_item	3638006	et	3	main
esitatud	doc_278690626951_item	3638005	et	4	main
lugemistekstis	doc_278690626951_item	3638004	et	3	main
ja	doc_278690626951_item	3638003	et	3	main
loengus	doc_278690626951_item	3638002	et	3	main
tuginema	doc_278690626951_item	3638001	et	3	main
üldistav	doc_278690626951_item	3638000	et	4	main
ja	doc_278690626951_item	3637999	et	3	main
analüüsiv	doc_278690626951_item	3637998	et	4	main
arutlev	doc_278690626951_item	3637997	et	4	main
olema	doc_278690626951_item	3637996	et	4	main
peab	doc_278690626951_item	3637995	et	4	main
essee	doc_278690626951_item	3637994	et	4	main
sõna	doc_278690626951_item	3637993	et	4	main
350	doc_278690626951_item	3637992	et	2	main
pikkus	doc_278690626951_item	3637990	et	4	main
mis	doc_278690626951_item	3637985	et	4	main
teise	doc_278690626951_item	3637978	et	4	main
kui	doc_278690626951_item	3637977	et	3	main
tavaliselt	doc_278690626952_item	3638248	et	4	main
kui	doc_278690626952_item	3638242	et	3	main
kujunenud	doc_278690626952_item	3638240	et	4	main
on	doc_278690626952_item	3638239	et	4	main
lauldi	doc_278690626952_item	3638234	et	3	main
rahvalaulu	doc_278690626952_item	3638221	et	4	main
laul	doc_278690626952_item	3638214	et	4	main
aga	doc_278690626952_item	3638213	et	3	main
olid	doc_278690626952_item	3638210	et	4	main
teadnud	doc_278690626952_item	3638193	et	4	main
on	doc_278690626952_item	3638186	et	4	main
sümbool	doc_278690626952_item	3638179	et	4	main
soovitatav	doc_278690626952_item	3638172	et	4	main
350	doc_278690626952_item	3638155	et	2	main
essee	doc_278690626952_item	3638152	et	4	main
essee	doc_278690626952_item	3638146	et	4	main
kirjutage	doc_278690626952_item	3638145	et	3	main
kirjutamine	doc_278690626952_item	3638144	et	4	main
test	doc_278690626952_item	3638143	et	3	main
keele	doc_278690626952_item	3638142	et	4	main
noortel	doc_278690626952_item	3638344	et	3	main
ühtlasi	doc_278690626952_item	3638328	et	4	main
kõrgehetk	doc_278690626952_item	3638327	et	3	main
johann	doc_278690626952_item	3638311	et	4	main
laulupidu	doc_278690626952_item	3638305	et	4	main
ülemaaline	doc_278690626952_item	3638304	et	4	main
koorilaulu	doc_278690626952_item	3638292	et	4	main
mitmehäälset	doc_278690626952_item	3638291	et	3	main
põhiliselt	doc_278690626952_item	3638290	et	4	main
kirik	doc_278690626952_item	3638286	et	3	main
laulude	doc_278690626952_item	3638280	et	3	main
vaimulike	doc_278690626952_item	3638271	et	3	main
vanemuine	doc_278690626953_item	3638514	et	4	main
vajalik	doc_278690626953_item	3638498	et	3	main
kogu	doc_278690626953_item	3638492	et	4	main
sõitnud	doc_278690626953_item	3638479	et	4	main
kokku	doc_278690626953_item	3638478	et	3	main
on	doc_278690626953_item	3638474	et	4	main
ja	doc_278690626953_item	3638471	et	3	main
sugulasi	doc_278690626953_item	3638470	et	3	main
sõpru	doc_278690626953_item	3638469	et	3	main
kohata	doc_278690626953_item	3638468	et	4	main
lastekoor	doc_278690626953_item	3638458	et	4	main
kõik	doc_278690626953_item	3638452	et	4	main
teadma	doc_278690626953_item	3638451	et	3	main
laulus	doc_278690626953_item	3638443	et	3	main
tulevikku	doc_278690626953_item	3638440	et	4	main
ole	doc_278690626953_item	3638439	et	4	main
ei	doc_278690626953_item	3638438	et	4	main
minevikust	doc_278690626953_item	3638437	et	3	main
aga	doc_278690626953_item	3638436	et	3	main
riigi	doc_278690626953_item	3638434	et	3	main
on	doc_278690626953_item	3638433	et	4	main
see	doc_278690626953_item	3638432	et	3	main
aitavad	doc_278690626953_item	3638411	et	4	main
laulud	doc_278690626953_item	3638407	et	3	main
tegevus	doc_278690626953_item	3638405	et	4	main
emotsionaalne	doc_278690626953_item	3638400	et	3	main
esteetiline	doc_278690626953_item	3638398	et	3	main
see	doc_278690626953_item	3638396	et	3	main
väiteid	doc_278690626953_item	3638387	et	4	main
olema	doc_278690626953_item	3638376	et	4	main
300	doc_278690626953_item	3638371	et	2	main
need	doc_278690626955_item	3638606	et	3	main
sellepärast	doc_278690626955_item	3638589	et	3	main
nende	doc_278690626955_item	3638586	et	4	main
laulurahva	doc_278690626955_item	3638584	et	3	main
mis	doc_278690626955_item	3638581	et	4	main
näidetega	doc_278690626955_item	3638580	et	3	main
peab	doc_278690626955_item	3638564	et	4	main
eestlastest	doc_278690626955_item	3638556	et	4	main
teeb	doc_278690626955_item	3638555	et	3	main
teise	doc_278690626955_item	3638547	et	4	main
kui	doc_278690626955_item	3638546	et	3	main
kirjutamine	doc_278690626955_item	3638779	et	4	main
oma	doc_278690626955_item	3638774	et	4	main
maleta	doc_278690626955_item	3638773	et	4	main
ideesse	doc_278690626955_item	3638770	et	4	main
oma	doc_278690626955_item	3638769	et	4	main
festivalid	doc_278690626952_item	3638352	et	3	main
muusika	doc_278690626952_item	3638351	et	4	main
pop	doc_278690626952_item	3638350	et	4	main
ja	doc_278690626952_item	3638349	et	3	main
rock	doc_278690626952_item	3638348	et	4	main
esitavad	doc_278690626952_item	3638247	et	4	main
tagasi	doc_278690626952_item	3638245	et	3	main
tuhat	doc_278690626952_item	3638243	et	4	main
regilaul	doc_278690626952_item	3638238	et	4	main
see	doc_278690626952_item	3638231	et	3	main
vanemat	doc_278690626952_item	3638220	et	4	main
last	doc_278690626952_item	3638205	et	4	main
kiri	doc_278690626952_item	3638195	et	3	main
muusika	doc_278690626952_item	3638194	et	4	main
millal	doc_278690626952_item	3638190	et	3	main
vanal	doc_278690626952_item	3638188	et	3	main
laul	doc_278690626952_item	3638187	et	4	main
see	doc_278690626952_item	3638184	et	3	main
mõtlen	doc_278690626952_item	3638181	et	3	main
illustreerida	doc_278690626952_item	3638173	et	3	main
väiteid	doc_278690626952_item	3638170	et	4	main
faktidele	doc_278690626952_item	3638169	et	3	main
lugemistekstis	doc_278690626952_item	3638167	et	3	main
ja	doc_278690626952_item	3638166	et	3	main
loengus	doc_278690626952_item	3638165	et	3	main
tuginema	doc_278690626952_item	3638164	et	3	main
üldistav	doc_278690626952_item	3638163	et	4	main
esitatud	doc_278690626952_item	3638168	et	4	main
ja	doc_278690626952_item	3638162	et	3	main
analüüsiv	doc_278690626952_item	3638161	et	4	main
arutlev	doc_278690626952_item	3638160	et	4	main
olema	doc_278690626952_item	3638159	et	4	main
peab	doc_278690626952_item	3638158	et	4	main
essee	doc_278690626952_item	3638157	et	4	main
sõna	doc_278690626952_item	3638156	et	4	main
eestlastest	doc_278690626952_item	3638150	et	4	main
teeb	doc_278690626952_item	3638149	et	3	main
teemal	doc_278690626952_item	3638147	et	3	main
eesti	doc_278690626952_item	3638138	et	4	main
järgnevate	doc_278690626952_item	3638336	et	4	main
sellest	doc_278690626952_item	3638330	et	4	main
liikumise	doc_278690626952_item	3638326	et	4	main
rahvusliku	doc_278690626952_item	3638325	et	3	main
eestlaste	doc_278690626952_item	3638324	et	4	main
kujunes	doc_278690626952_item	3638323	et	3	main
sellest	doc_278690626952_item	3638322	et	4	main
puhkpilliorkestrit	doc_278690626952_item	3638321	et	3	main
5	doc_278690626952_item	3638320	et	2	main
ja	doc_278690626952_item	3638319	et	3	main
meeskoori	doc_278690626952_item	3638318	et	4	main
46	doc_278690626952_item	3638317	et	2	main
osales	doc_278690626952_item	3638316	et	3	main
peol	doc_278690626952_item	3638315	et	4	main
esimesel	doc_278690626952_item	3638314	et	3	main
jannsen	doc_278690626952_item	3638313	et	4	main
voldemar	doc_278690626952_item	3638312	et	4	main
populaarne	doc_278690626952_item	3638343	et	3	main
korraldamisele	doc_278690626952_item	3638338	et	4	main
pani	doc_278690626952_item	3638334	et	4	main
mis	doc_278690626952_item	3638333	et	4	main
suursündmus	doc_278690626952_item	3638332	et	3	main
muusikaline	doc_278690626952_item	3638331	et	4	main
1869	doc_278690626952_item	3638306	et	2	main
kujunes	doc_278690626952_item	3638302	et	3	main
sündmus	doc_278690626952_item	3638301	et	3	main
tähtsem	doc_278690626952_item	3638300	et	4	main
ja	doc_278690626952_item	3638287	et	3	main
kirikut	doc_278690626952_item	3638285	et	3	main
laulmine	doc_278690626952_item	3638281	et	4	main
hakkas	doc_278690626952_item	3638277	et	3	main
18	doc_278690626952_item	3638275	et	2	main
kirikus	doc_278690626952_item	3638274	et	3	main
laulide	doc_278690626952_item	3638272	et	3	main
ristiusuga	doc_278690626952_item	3638269	et	3	main
ka	doc_278690626952_item	3638266	et	3	main
ilma	doc_278690626952_item	3638265	et	4	main
ja	doc_278690626952_item	3638264	et	3	main
eeslauljaga	doc_278690626952_item	3638263	et	3	main
kooriga	doc_278690626952_item	3638262	et	4	main
kahekesi	doc_278690626952_item	3638261	et	3	main
üksi	doc_278690626952_item	3638260	et	4	main
lauldud	doc_278690626952_item	3638259	et	4	main
on	doc_278690626952_item	3638258	et	4	main
tavast	doc_278690626952_item	3638257	et	4	main
kohalikust	doc_278690626952_item	3638256	et	4	main
ja	doc_278690626952_item	3638255	et	3	main
laululiigist	doc_278690626952_item	3638254	et	3	main
olenevalt	doc_278690626952_item	3638253	et	4	main
vaheldumisi	doc_278690626952_item	3638252	et	4	main
koor	doc_278690626952_item	3638251	et	4	main
tuli	doc_278690626953_item	3638513	et	4	main
ei	doc_278690626953_item	3638496	et	4	main
ja	doc_278690626953_item	3638495	et	3	main
nii	doc_278690626953_item	3638483	et	3	main
ka	doc_278690626953_item	3638482	et	3	main
võtavad	doc_278690626953_item	3638481	et	3	main
osa	doc_278690626953_item	3638480	et	4	main
kogu	doc_278690626953_item	3638476	et	4	main
peerega	doc_278690626953_item	3638466	et	4	main
koos	doc_278690626953_item	3638465	et	4	main
tullakse	doc_278690626953_item	3638464	et	3	main
naiskoor	doc_278690626953_item	3638457	et	4	main
peavad	doc_278690626953_item	3638450	et	4	main
riik	doc_278690626953_item	3638421	et	3	main
eesti	doc_278690626953_item	3638418	et	4	main
et	doc_278690626953_item	3638417	et	3	main
arvan	doc_278690626953_item	3638416	et	3	main
ma	doc_278690626953_item	3638415	et	3	main
probleeme	doc_278690626953_item	3638414	et	3	main
oma	doc_278690626953_item	3638413	et	4	main
unustada	doc_278690626953_item	3638412	et	3	main
tantsud	doc_278690626953_item	3638408	et	3	main
sotsiaalne	doc_278690626953_item	3638404	et	3	main
kultuurinähtus	doc_278690626953_item	3638395	et	4	main
tähelepanuväärne	doc_278690626953_item	3638394	et	3	main
on	doc_278690626953_item	3638393	et	4	main
faktidele	doc_278690626953_item	3638386	et	3	main
esitatud	doc_278690626953_item	3638385	et	4	main
lugemistekstis	doc_278690626953_item	3638384	et	3	main
ja	doc_278690626953_item	3638383	et	3	main
loengus	doc_278690626953_item	3638382	et	3	main
korraldas	doc_278690626952_item	3638310	et	3	main
aastal	doc_278690626952_item	3638307	et	3	main
esimene	doc_278690626952_item	3638303	et	3	main
kõige	doc_278690626952_item	3638299	et	4	main
väljaspool	doc_278690626952_item	3638284	et	3	main
seltsist	doc_278690626953_item	3638515	et	4	main
keelt	doc_278690626953_item	3638500	et	4	main
ole	doc_278690626953_item	3638497	et	4	main
on	doc_278690626953_item	3638491	et	4	main
vene	doc_278690626953_item	3638488	et	4	main
kes	doc_278690626953_item	3638473	et	4	main
tuttavaid	doc_278690626953_item	3638472	et	3	main
kuhu	doc_278690626953_item	3638463	et	3	main
koorid	doc_278690626953_item	3638456	et	4	main
inimesed	doc_278690626953_item	3638449	et	3	main
folkloor	doc_278690626953_item	3638448	et	4	main
kombed	doc_278690626953_item	3638447	et	3	main
rahva	doc_278690626953_item	3638446	et	3	main
ajaloo	doc_278690626953_item	3638442	et	4	main
ja	doc_278690626953_item	3638441	et	3	main
rahvalaul	doc_278690626953_item	3638431	et	4	main
aga	doc_278690626953_item	3638422	et	3	main
on	doc_278690626953_item	3638419	et	4	main
ühendavad	doc_278690626953_item	3638409	et	4	main
aga	doc_278690626953_item	3638402	et	3	main
on	doc_278690626953_item	3638397	et	4	main
on	doc_278690626953_item	3638388	et	4	main
arutlev	doc_278690626953_item	3638377	et	4	main
350	doc_278690626953_item	3638372	et	2	main
eestlastest	doc_278690626953_item	3638367	et	4	main
kirjutamine	doc_278690626953_item	3638361	et	4	main
test	doc_278690626953_item	3638360	et	3	main
laulab	doc_278690626955_item	3638617	et	3	main
ja	doc_278690626955_item	3638616	et	3	main
laulis	doc_278690626955_item	3638613	et	4	main
tantsida	doc_278690626955_item	3638605	et	3	main
olnud	doc_278690626955_item	3638594	et	4	main
ei	doc_278690626955_item	3638593	et	4	main
ajaloos	doc_278690626955_item	3638592	et	4	main
kultuur	doc_278690626955_item	3638587	et	3	main
soovitatav	doc_278690626955_item	3638578	et	4	main
tuginema	doc_278690626955_item	3638570	et	3	main
essee	doc_278690626955_item	3638563	et	4	main
350	doc_278690626955_item	3638561	et	2	main
teemal	doc_278690626955_item	3638553	et	3	main
essee	doc_278690626955_item	3638552	et	4	main
kirjutage	doc_278690626955_item	3638551	et	3	main
kirjutamine	doc_278690626955_item	3638550	et	4	main
test	doc_278690626955_item	3638549	et	3	main
ära	doc_278690626955_item	3638772	et	4	main
uskuda	doc_278690626955_item	3638768	et	3	main
rahvale	doc_278690626955_item	3638767	et	3	main
eesti	doc_278690626955_item	3638766	et	4	main
aitab	doc_278690626955_item	3638765	et	3	main
mis	doc_278690626955_item	3638764	et	4	main
kannab	doc_278690626955_item	3638757	et	3	main
hingale	doc_278690626955_item	3638754	et	4	main
on	doc_278690626955_item	3638751	et	4	main
pidutsevad	doc_278690626955_item	3638749	et	4	main
ja	doc_278690626955_item	3638747	et	3	main
pidutsesid	doc_278690626955_item	3638746	et	4	main
oma	doc_278690626955_item	3638738	et	4	main
hirmus	doc_278690626955_item	3638723	et	4	main
oma	doc_278690626955_item	3638693	et	4	main
proovi	doc_278690626955_item	3638690	et	4	main
sellega	doc_278690626955_item	3638683	et	3	main
värsse	doc_278690626955_item	3638681	et	3	main
ja	doc_278690626955_item	3638673	et	3	main
ta	doc_278690626955_item	3638660	et	4	main
regilaul	doc_278690626955_item	3638659	et	4	main
läänemeresoome	doc_278690626955_item	3638658	et	3	main
esindab	doc_278690626955_item	3638657	et	3	main
veel	doc_278690626955_item	3638650	et	4	main
ja	doc_278690626955_item	3638649	et	3	main
laulurahva	doc_278690626953_item	3638541	et	3	main
eestlastest	doc_278690626953_item	3638540	et	4	main
teeb	doc_278690626953_item	3638539	et	3	main
ajalugu	doc_278690626953_item	3638538	et	4	main
oma	doc_278690626953_item	3638537	et	4	main
kombed	doc_278690626953_item	3638536	et	3	main
oma	doc_278690626953_item	3638535	et	4	main
maa	doc_278690626953_item	3638534	et	4	main
oma	doc_278690626953_item	3638533	et	4	main
areng	doc_278690626953_item	3638532	et	3	main
juurde	doc_278690626953_item	3638531	et	4	main
laulu	doc_278690626953_item	3638530	et	4	main
armastus	doc_278690626953_item	3638529	et	4	main
jaoks	doc_278690626953_item	3638528	et	4	main
eesti	doc_278690626953_item	3638527	et	4	main
periood	doc_278690626953_item	3638526	et	3	main
tähtis	doc_278690626953_item	3638525	et	4	main
väga	doc_278690626953_item	3638524	et	3	main
on	doc_278690626953_item	3638523	et	4	main
see	doc_278690626953_item	3638522	et	3	main
et	doc_278690626953_item	3638521	et	3	main
arvan	doc_278690626953_item	3638520	et	3	main
jannseniga	doc_278690626953_item	3638519	et	4	main
voldemar	doc_278690626953_item	3638518	et	4	main
johann	doc_278690626953_item	3638517	et	4	main
eesotsas	doc_278690626953_item	3638516	et	4	main
teostus	doc_278690626953_item	3638512	et	4	main
ja	doc_278690626953_item	3638511	et	3	main
idee	doc_278690626953_item	3638510	et	4	main
korraldamise	doc_278690626953_item	3638509	et	4	main
mille	doc_278690626953_item	3638508	et	3	main
laulupidu	doc_278690626953_item	3638507	et	4	main
esimene	doc_278690626953_item	3638506	et	3	main
inimest	doc_278690626953_item	3638505	et	3	main
ühendab	doc_278690626953_item	3638504	et	3	main
rahvalaulpidu	doc_278690626953_item	3638503	et	4	main
räägid	doc_278690626953_item	3638502	et	4	main
sa	doc_278690626953_item	3638501	et	3	main
missuguste	doc_278690626953_item	3638499	et	3	main
pidu	doc_278690626953_item	3638490	et	4	main
läti	doc_278690626953_item	3638486	et	4	main
nagu	doc_278690626953_item	3638485	et	3	main
maailma	doc_278690626953_item	3638477	et	4	main
üle	doc_278690626953_item	3638475	et	3	main
poistekoor	doc_278690626953_item	3638459	et	4	main
rahvalaulupeol	doc_278690626953_item	3638454	et	4	main
see	doc_278690626953_item	3638453	et	3	main
näidatakse	doc_278690626953_item	3638444	et	3	main
minevik	doc_278690626953_item	3638435	et	3	main
jõudu	doc_278690626953_item	3638430	et	4	main
oma	doc_278690626953_item	3638429	et	4	main
tunna	doc_278690626953_item	3638428	et	4	main
inimestele	doc_278690626953_item	3638427	et	3	main
aitavad	doc_278690626953_item	3638426	et	4	main
laulud	doc_278690626953_item	3638425	et	3	main
rahvaga	doc_278690626953_item	3638424	et	3	main
väike	doc_278690626953_item	3638420	et	4	main
rahvas	doc_278690626953_item	3638410	et	4	main
ka	doc_278690626953_item	3638403	et	3	main
väljendusvahed	doc_278690626953_item	3638401	et	3	main
ja	doc_278690626953_item	3638399	et	3	main
soovitatav	doc_278690626953_item	3638389	et	4	main
analüüsiv	doc_278690626953_item	3638378	et	4	main
sõna	doc_278690626953_item	3638373	et	4	main
mis	doc_278690626953_item	3638365	et	4	main
teemal	doc_278690626953_item	3638364	et	3	main
essee	doc_278690626953_item	3638363	et	4	main
kirjutage	doc_278690626953_item	3638362	et	3	main
teise	doc_278690626953_item	3638358	et	4	main
ajast	doc_278690626955_item	3638615	et	4	main
vanast	doc_278690626955_item	3638614	et	3	main
kõige	doc_278690626955_item	3638608	et	4	main
ja	doc_278690626955_item	3638604	et	3	main
eestlaste	doc_278690626955_item	3638591	et	4	main
esitatud	doc_278690626955_item	3638574	et	4	main
lugemistekstis	doc_278690626955_item	3638573	et	3	main
ja	doc_278690626955_item	3638572	et	3	main
loengus	doc_278690626955_item	3638571	et	3	main
sõna	doc_278690626955_item	3638562	et	4	main
300	doc_278690626955_item	3638560	et	2	main
pikkus	doc_278690626955_item	3638559	et	4	main
eesti	doc_278690626955_item	3638544	et	4	main
peod	doc_278690626955_item	3638780	et	4	main
laulu	doc_278690626955_item	3638778	et	4	main
laulmine	doc_278690626955_item	3638777	et	4	main
õppime	doc_278690626955_item	3638763	et	4	main
ja	doc_278690626955_item	3638762	et	3	main
rahvalaul	doc_278690626955_item	3638756	et	4	main
eestlaste	doc_278690626955_item	3638753	et	4	main
kõik	doc_278690626955_item	3638750	et	4	main
praegu	doc_278690626955_item	3638748	et	3	main
lastele	doc_278690626955_item	3638739	et	4	main
pole	doc_278690626955_item	3638733	et	3	main
laulutraditsioon	doc_278690626955_item	3638728	et	3	main
tegevus	doc_278690626955_item	3638691	et	4	main
eestlaste	doc_278690626955_item	3638688	et	4	main
oli	doc_278690626955_item	3638687	et	3	main
see	doc_278690626955_item	3638686	et	3	main
eeslaulja	doc_278690626955_item	3638679	et	4	main
edasi	doc_278690626955_item	3638672	et	3	main
idee	doc_278690626955_item	3638666	et	4	main
jaoks	doc_278690626955_item	3638665	et	4	main
vanemat	doc_278690626955_item	3638655	et	4	main
nii	doc_278690626956_item	3639067	et	3	main
hakkasid	doc_278690626956_item	3639065	et	4	main
miks	doc_278690626956_item	3639063	et	4	main
laulupeost	doc_278690626956_item	3639062	et	4	main
64	doc_278690626956_item	3639058	et	2	main
ainult	doc_278690626956_item	3639054	et	4	main
osast	doc_278690626956_item	3639052	et	4	main
see	doc_278690626956_item	3639041	et	3	main
laulud	doc_278690626956_item	3639038	et	3	main
oli	doc_278690626956_item	3639036	et	3	main
neid	doc_278690626956_item	3639028	et	4	main
rohkem	doc_278690626956_item	3639022	et	4	main
vanal	doc_278690626956_item	3639020	et	3	main
ideet	doc_278690626956_item	3639019	et	4	main
midagi	doc_278690626956_item	3639011	et	4	main
ei	doc_278690626956_item	3639006	et	4	main
veemine	doc_278690626956_item	3638997	et	4	main
tugeva	doc_278690626953_item	3638423	et	4	main
muusika	doc_278690626953_item	3638406	et	4	main
laulmine	doc_278690626953_item	3638392	et	4	main
näidetega	doc_278690626953_item	3638391	et	3	main
illustreerida	doc_278690626953_item	3638390	et	3	main
peab	doc_278690626953_item	3638375	et	4	main
essee	doc_278690626953_item	3638369	et	4	main
laulurahva	doc_278690626953_item	3638368	et	3	main
kui	doc_278690626953_item	3638357	et	3	main
eesti	doc_278690626953_item	3638355	et	4	main
keele	doc_278690626953_item	3638356	et	4	main
essee	doc_278690626953_item	3638354	et	4	main
eesti	doc_278690626955_item	3638611	et	4	main
kultuurinähtused	doc_278690626955_item	3638610	et	3	main
tähelepanuväärsed	doc_278690626955_item	3638609	et	3	main
armastavad	doc_278690626955_item	3638602	et	4	main
nad	doc_278690626955_item	3638601	et	3	main
laulnud	doc_278690626955_item	3638600	et	4	main
ei	doc_278690626955_item	3638599	et	4	main
nad	doc_278690626955_item	3638598	et	3	main
millal	doc_278690626955_item	3638597	et	3	main
momentide	doc_278690626955_item	3638596	et	3	main
niisuguste	doc_278690626955_item	3638595	et	3	main
et	doc_278690626955_item	3638590	et	3	main
eestlastest	doc_278690626955_item	3638583	et	4	main
teeb	doc_278690626955_item	3638582	et	3	main
üldistav	doc_278690626955_item	3638569	et	4	main
arutlev	doc_278690626955_item	3638566	et	4	main
olema	doc_278690626955_item	3638565	et	4	main
essee	doc_278690626955_item	3638558	et	4	main
laulurahva	doc_278690626955_item	3638557	et	3	main
keele	doc_278690626955_item	3638548	et	4	main
ajalools	doc_278690626955_item	3638775	et	4	main
ja	doc_278690626955_item	3638771	et	3	main
tähtis	doc_278690626955_item	3638752	et	4	main
laulis	doc_278690626955_item	3638740	et	4	main
sõna	doc_278690626955_item	3638735	et	4	main
tähtsus	doc_278690626955_item	3638734	et	4	main
folkloor	doc_278690626955_item	3638732	et	4	main
et	doc_278690626955_item	3638731	et	3	main
näitab	doc_278690626955_item	3638730	et	3	main
ka	doc_278690626955_item	3638729	et	3	main
liiga	doc_278690626955_item	3638722	et	4	main
talle	doc_278690626955_item	3638684	et	4	main
andes	doc_278690626955_item	3638682	et	4	main
tuginema	doc_278690626953_item	3638381	et	3	main
üldistav	doc_278690626953_item	3638380	et	4	main
ja	doc_278690626953_item	3638379	et	3	main
essee	doc_278690626953_item	3638374	et	4	main
pikkus	doc_278690626953_item	3638370	et	4	main
teeb	doc_278690626953_item	3638366	et	3	main
keele	doc_278690626953_item	3638359	et	4	main
eestlaste	doc_278690626955_item	3638804	et	4	main
süda	doc_278690626955_item	3638805	et	3	main
on	doc_278690626955_item	3638803	et	4	main
laulud	doc_278690626955_item	3638802	et	3	main
rahvast	doc_278690626955_item	3638801	et	4	main
nendest	doc_278690626955_item	3638800	et	4	main
neid	doc_278690626955_item	3638799	et	4	main
erineb	doc_278690626955_item	3638798	et	3	main
see	doc_278690626955_item	3638797	et	3	main
ja	doc_278690626955_item	3638796	et	3	main
laulurahv	doc_278690626955_item	3638795	et	4	main
on	doc_278690626955_item	3638794	et	4	main
eestlased	doc_278690626955_item	3638793	et	3	main
et	doc_278690626955_item	3638792	et	3	main
ütlema	doc_278690626955_item	3638791	et	3	main
võime	doc_278690626955_item	3638790	et	4	main
me	doc_278690626955_item	3638789	et	4	main
nii	doc_278690626955_item	3638788	et	3	main
elus	doc_278690626955_item	3638787	et	4	main
eestlaste	doc_278690626955_item	3638786	et	4	main
osa	doc_278690626955_item	3638785	et	4	main
rahv	doc_278690626955_item	3638612	et	4	main
on	doc_278690626955_item	3638607	et	4	main
laulda	doc_278690626955_item	3638603	et	4	main
teeb	doc_278690626955_item	3638588	et	3	main
küll	doc_278690626955_item	3638585	et	4	main
illustreerida	doc_278690626955_item	3638579	et	3	main
on	doc_278690626955_item	3638577	et	4	main
väiteid	doc_278690626955_item	3638576	et	4	main
faktidele	doc_278690626955_item	3638575	et	3	main
ja	doc_278690626955_item	3638568	et	3	main
analüüsiv	doc_278690626955_item	3638567	et	4	main
mis	doc_278690626955_item	3638554	et	4	main
keele	doc_278690626955_item	3638545	et	4	main
essee	doc_278690626955_item	3638543	et	4	main
suur	doc_278690626955_item	3638784	et	3	main
koostavad	doc_278690626955_item	3638783	et	4	main
need	doc_278690626955_item	3638782	et	3	main
kõik	doc_278690626955_item	3638781	et	4	main
tantsimine	doc_278690626955_item	3638776	et	4	main
mõted	doc_278690626955_item	3638761	et	4	main
tunned	doc_278690626955_item	3638760	et	3	main
inimeste	doc_278690626955_item	3638759	et	3	main
jaoks	doc_278690626955_item	3638755	et	4	main
inimesed	doc_278690626955_item	3638744	et	3	main
kuidas	doc_278690626955_item	3638743	et	3	main
laulub	doc_278690626955_item	3638742	et	4	main
ja	doc_278690626955_item	3638741	et	3	main
ema	doc_278690626955_item	3638737	et	4	main
kuidas	doc_278690626955_item	3638736	et	3	main
ja	doc_278690626955_item	3638727	et	3	main
kultuuridentiteet	doc_278690626955_item	3638726	et	4	main
olnud	doc_278690626955_item	3638721	et	4	main
ei	doc_278690626955_item	3638720	et	4	main
see	doc_278690626955_item	3638719	et	3	main
aga	doc_278690626955_item	3638718	et	3	main
venemaal	doc_278690626955_item	3638717	et	4	main
tsaari-	doc_278690626955_item	3638716	et	4	main
korraldamisega	doc_278690626955_item	3638715	et	4	main
pidude	doc_278690626955_item	3638714	et	4	main
raskused	doc_278690626955_item	3638713	et	4	main
olid	doc_278690626955_item	3638712	et	4	main
laulupeod	doc_278690626955_item	3638711	et	4	main
toimusid	doc_278690626955_item	3638710	et	4	main
eestis	doc_278690626955_item	3638709	et	3	main
kui	doc_278690626955_item	3638708	et	3	main
hiljem	doc_278690626955_item	3638707	et	3	main
juba	doc_278690626955_item	3638706	et	3	main
näiteks	doc_278690626955_item	3638705	et	4	main
probleemid	doc_278690626955_item	3638704	et	3	main
olid	doc_278690626955_item	3638703	et	4	main
teel	doc_278690626955_item	3638702	et	4	main
tema	doc_278690626955_item	3638701	et	4	main
kaua	doc_278690626955_item	3638700	et	3	main
väga	doc_278690626955_item	3638699	et	3	main
oli	doc_278690626955_item	3638698	et	3	main
sündimine	doc_278690626955_item	3638697	et	4	main
folkloori	doc_278690626955_item	3638696	et	4	main
teha	doc_278690626955_item	3638695	et	3	main
folkloori	doc_278690626955_item	3638694	et	4	main
kaasas	doc_278690626955_item	3638758	et	4	main
pulmaid	doc_278690626955_item	3638745	et	4	main
estlaste	doc_278690626955_item	3638725	et	4	main
probleem	doc_278690626955_item	3638724	et	3	main
esimene	doc_278690626955_item	3638689	et	3	main
mõtteaega	doc_278690626955_item	3638685	et	4	main
esitatud	doc_278690626955_item	3638680	et	4	main
kordas	doc_278690626955_item	3638678	et	3	main
koor	doc_278690626955_item	3638677	et	4	main
aga	doc_278690626955_item	3638676	et	3	main
laulutraditsiooni	doc_278690626955_item	3638656	et	4	main
töötada	doc_278690626955_item	3638653	et	3	main
üks	doc_278690626955_item	3638651	et	3	main
laulma	doc_278690626956_item	3639066	et	3	main
pärast	doc_278690626956_item	3639060	et	4	main
aastat	doc_278690626956_item	3639059	et	3	main
naistekoorid	doc_278690626956_item	3639050	et	3	main
ja	doc_278690626956_item	3639049	et	3	main
laulmisega	doc_278690626956_item	3639048	et	4	main
ka	doc_278690626956_item	3639040	et	3	main
laule	doc_278690626956_item	3639029	et	4	main
ümbritsev	doc_278690626956_item	3639015	et	4	main
rahva	doc_278690626956_item	3639014	et	3	main
laul	doc_278690626956_item	3639009	et	4	main
kes	doc_278690626956_item	3639005	et	4	main
aja	doc_278690626956_item	3638996	et	4	main
tõendatud	doc_278690626956_item	3638987	et	4	main
küla	doc_278690626956_item	3638971	et	4	main
mida	doc_278690626956_item	3638954	et	4	main
nendega	doc_278690626956_item	3638943	et	4	main
rääkida	doc_278690626956_item	3638942	et	3	main
oma	doc_278690626956_item	3638934	et	4	main
rääkis	doc_278690626956_item	3638933	et	3	main
erinevad	doc_278690626956_item	3638928	et	4	main
olid	doc_278690626956_item	3638926	et	4	main
ja	doc_278690626956_item	3638925	et	3	main
päev	doc_278690626956_item	3638924	et	3	main
iga	doc_278690626956_item	3638923	et	4	main
meelde	doc_278690626956_item	3638922	et	3	main
tulid	doc_278690626956_item	3638921	et	4	main
laulud	doc_278690626956_item	3638920	et	3	main
rõõmu	doc_278690626956_item	3638919	et	4	main
või	doc_278690626956_item	3638893	et	4	main
põlull	doc_278690626956_item	3638885	et	4	main
tegelesid	doc_278690626956_item	3638881	et	4	main
kui	doc_278690626956_item	3638871	et	3	main
inimene	doc_278690626956_item	3638867	et	3	main
elab	doc_278690626956_item	3638866	et	3	main
kuidas	doc_278690626956_item	3638865	et	3	main
kultuure	doc_278690626956_item	3638852	et	3	main
niisugused	doc_278690626956_item	3638847	et	3	main
tuginema	doc_278690626956_item	3638834	et	3	main
essee	doc_278690626956_item	3638827	et	4	main
keele	doc_278690626956_item	3638812	et	4	main
teise	doc_278690626956_item	3638811	et	4	main
kui	doc_278690626956_item	3638810	et	3	main
keele	doc_278690626956_item	3638809	et	4	main
eestlased	doc_278690626956_item	3639121	et	3	main
need	doc_278690626956_item	3639112	et	3	main
hakkavad	doc_278690626956_item	3639092	et	4	main
nad	doc_278690626956_item	3639091	et	3	main
et	doc_278690626955_item	3638692	et	3	main
arendas	doc_278690626955_item	3638674	et	3	main
viis	doc_278690626955_item	3638670	et	4	main
eeslaulja	doc_278690626955_item	3638669	et	4	main
muusika	doc_278690626955_item	3638664	et	4	main
eesti	doc_278690626955_item	3638663	et	4	main
niimoodi	doc_278690626955_item	3638654	et	3	main
kord	doc_278690626955_item	3638652	et	4	main
hiljem	doc_278690626956_item	3639068	et	3	main
naised	doc_278690626956_item	3639064	et	3	main
ainult	doc_278690626956_item	3639057	et	4	main
võtta	doc_278690626956_item	3639053	et	3	main
hakkasid	doc_278690626956_item	3639051	et	4	main
huvitav	doc_278690626956_item	3639039	et	4	main
meeste	doc_278690626956_item	3639037	et	4	main
soovinud	doc_278690626956_item	3639034	et	4	main
ka	doc_278690626956_item	3639027	et	3	main
olid	doc_278690626956_item	3639026	et	4	main
aga	doc_278690626956_item	3639025	et	3	main
naised	doc_278690626956_item	3639024	et	3	main
ajal	doc_278690626956_item	3639021	et	4	main
rahva	doc_278690626956_item	3639018	et	3	main
toob	doc_278690626956_item	3639017	et	3	main
mis	doc_278690626956_item	3639016	et	4	main
on	doc_278690626956_item	3639010	et	4	main
ainult	doc_278690626956_item	3638994	et	4	main
pole	doc_278690626956_item	3638993	et	3	main
oli	doc_278690626956_item	3638986	et	3	main
see	doc_278690626956_item	3638985	et	3	main
seda	doc_278690626955_item	3638675	et	3	main
laulu	doc_278690626955_item	3638671	et	4	main
lahke	doc_278690626955_item	3638668	et	4	main
oli	doc_278690626955_item	3638667	et	3	main
algust	doc_278690626955_item	3638662	et	4	main
andis	doc_278690626955_item	3638661	et	3	main
töötada	doc_278690626955_item	3638648	et	3	main
töötada	doc_278690626955_item	3638647	et	3	main
võib	doc_278690626955_item	3638646	et	3	main
see	doc_278690626955_item	3638645	et	3	main
et	doc_278690626955_item	3638644	et	3	main
jõudu	doc_278690626955_item	3638643	et	4	main
kehale	doc_278690626955_item	3638642	et	3	main
annab	doc_278690626955_item	3638641	et	3	main
muusika	doc_278690626955_item	3638640	et	4	main
tähtsamad	doc_278690626955_item	3638639	et	4	main
kallimad	doc_278690626955_item	3638637	et	4	main
ja	doc_278690626955_item	3638638	et	3	main
kõige	doc_278690626955_item	3638636	et	4	main
on	doc_278690626955_item	3638635	et	4	main
rahvalaulud	doc_278690626955_item	3638634	et	3	main
joomine	doc_278690626955_item	3638633	et	4	main
ja	doc_278690626955_item	3638632	et	3	main
söömine	doc_278690626955_item	3638631	et	4	main
kui	doc_278690626955_item	3638630	et	3	main
vaja	doc_278690626955_item	3638629	et	4	main
eestlastele	doc_278690626955_item	3638628	et	4	main
on	doc_278690626955_item	3638627	et	4	main
laulud	doc_278690626955_item	3638626	et	3	main
ja	doc_278690626955_item	3638625	et	3	main
tantsud	doc_278690626955_item	3638624	et	3	main
et	doc_278690626955_item	3638623	et	3	main
sellest	doc_278690626955_item	3638622	et	4	main
meile	doc_278690626955_item	3638621	et	4	main
ütleb	doc_278690626955_item	3638620	et	3	main
see	doc_278690626955_item	3638619	et	3	main
praeguni	doc_278690626955_item	3638618	et	4	main
nad	doc_278690626956_item	3639070	et	3	main
aastal	doc_278690626956_item	3639056	et	3	main
meestekooride	doc_278690626956_item	3639047	et	3	main
ainult	doc_278690626956_item	3639046	et	4	main
toimusid	doc_278690626956_item	3639045	et	4	main
laulupeod	doc_278690626956_item	3639044	et	4	main
esimesed	doc_278690626956_item	3639043	et	3	main
et	doc_278690626956_item	3639042	et	3	main
see	doc_278690626956_item	3639035	et	3	main
ei	doc_278690626956_item	3639033	et	4	main
lauldakse	doc_278690626956_item	3639032	et	3	main
naisele	doc_278690626956_item	3639031	et	3	main
kõike	doc_278690626956_item	3639013	et	4	main
igasuguks	doc_278690626956_item	3639008	et	4	main
laulsid	doc_278690626956_item	3639071	et	4	main
kui	doc_278690626956_item	3639069	et	3	main
esimest	doc_278690626956_item	3639061	et	4	main
1933	doc_278690626956_item	3639055	et	2	main
mida	doc_278690626956_item	3639030	et	4	main
laulsid	doc_278690626956_item	3639023	et	4	main
ühine	doc_278690626956_item	3639012	et	4	main
tea	doc_278690626956_item	3639007	et	4	main
inimesi	doc_278690626956_item	3639004	et	4	main
neid	doc_278690626956_item	3639003	et	4	main
ka	doc_278690626956_item	3639002	et	3	main
ühindab	doc_278690626956_item	3639001	et	4	main
mis	doc_278690626956_item	3639000	et	4	main
rõõmus	doc_278690626956_item	3638995	et	4	main
on	doc_278690626956_item	3638982	et	4	main
eestlased	doc_278690626956_item	3638981	et	3	main
emotsioone	doc_278690626956_item	3638980	et	3	main
huvitavaid	doc_278690626956_item	3638979	et	4	main
saada	doc_278690626956_item	3638978	et	4	main
mentalitee	doc_278690626956_item	3638977	et	4	main
nende	doc_278690626956_item	3638976	et	4	main
tunda	doc_278690626956_item	3638975	et	3	main
inimesi	doc_278690626956_item	3638974	et	4	main
neid	doc_278690626956_item	3638973	et	4	main
näha	doc_278690626956_item	3638972	et	3	main
kujundada	doc_278690626956_item	3638969	et	3	main
niisuguste	doc_278690626956_item	3638963	et	3	main
me	doc_278690626956_item	3638959	et	4	main
vanal	doc_278690626956_item	3638957	et	3	main
eestlased	doc_278690626956_item	3638956	et	3	main
tegelesid	doc_278690626956_item	3638955	et	4	main
proovisid	doc_278690626956_item	3638941	et	4	main
koduloomadega	doc_278690626956_item	3638940	et	3	main
tegelesid	doc_278690626956_item	3638939	et	4	main
töötasid	doc_278690626956_item	3638884	et	4	main
millal	doc_278690626956_item	3638883	et	3	main
sellest	doc_278690626956_item	3638878	et	4	main
ma	doc_278690626956_item	3638875	et	3	main
teised	doc_278690626956_item	3638873	et	4	main
ka	doc_278690626956_item	3638872	et	3	main
eestlasid	doc_278690626956_item	3638870	et	4	main
vanal	doc_278690626956_item	3638868	et	3	main
tunneb	doc_278690626956_item	3638863	et	3	main
võib	doc_278690626956_item	3638860	et	3	main
rahva	doc_278690626956_item	3638851	et	3	main
on	doc_278690626956_item	3638841	et	4	main
arutlev	doc_278690626956_item	3638830	et	4	main
sõna	doc_278690626956_item	3638826	et	4	main
laulurahva	doc_278690626956_item	3638821	et	3	main
mis	doc_278690626956_item	3638818	et	4	main
teemal	doc_278690626956_item	3638817	et	3	main
essee	doc_278690626956_item	3638816	et	4	main
kirjutage	doc_278690626956_item	3638815	et	3	main
mäletab	doc_278690626956_item	3639127	et	3	main
oma	doc_278690626956_item	3639115	et	4	main
inimeste	doc_278690626956_item	3639089	et	3	main
et	doc_278690626956_item	3639086	et	3	main
see	doc_278690626956_item	3639078	et	3	main
aga	doc_278690626956_item	3639077	et	3	main
vanal	doc_278690626956_item	3639075	et	3	main
mehed	doc_278690626956_item	3639074	et	3	main
kui	doc_278690626956_item	3639073	et	3	main
seda	doc_278690626957_item	3639321	et	3	main
huvitab	doc_278690626957_item	3639320	et	3	main
laulupidu	doc_278690626957_item	3639311	et	4	main
praegu	doc_278690626957_item	3639310	et	3	main
lastega	doc_278690626957_item	3639298	et	3	main
ajal	doc_278690626957_item	3639279	et	4	main
vanal	doc_278690626957_item	3639278	et	3	main
kus	doc_278690626957_item	3639272	et	3	main
palju	doc_278690626957_item	3639269	et	4	main
on	doc_278690626957_item	3639267	et	4	main
naabrid	doc_278690626957_item	3639259	et	3	main
midagi	doc_278690626956_item	3638999	et	4	main
aga	doc_278690626956_item	3638998	et	3	main
laulamine	doc_278690626956_item	3638992	et	4	main
tõesti	doc_278690626956_item	3638991	et	3	main
faktidega	doc_278690626956_item	3638990	et	3	main
laulurahv	doc_278690626956_item	3638984	et	4	main
täiesti	doc_278690626956_item	3638983	et	3	main
teada	doc_278690626956_item	3638961	et	3	main
kõik	doc_278690626956_item	3638953	et	4	main
laulde	doc_278690626956_item	3638944	et	4	main
juttu	doc_278690626956_item	3638935	et	4	main
kodus	doc_278690626956_item	3638887	et	4	main
näiteks	doc_278690626956_item	3638882	et	4	main
nad	doc_278690626956_item	3638880	et	3	main
rahvad	doc_278690626956_item	3638874	et	3	main
ajaloo	doc_278690626956_item	3638989	et	4	main
mitme	doc_278690626956_item	3638988	et	4	main
me	doc_278690626956_item	3638966	et	4	main
kaudu	doc_278690626956_item	3638965	et	3	main
rahvalaulu	doc_278690626956_item	3638964	et	4	main
võime	doc_278690626956_item	3638960	et	4	main
ajal	doc_278690626956_item	3638958	et	4	main
millal	doc_278690626956_item	3638949	et	3	main
laulda	doc_278690626956_item	3638948	et	4	main
näiteks	doc_278690626956_item	3638947	et	4	main
ka	doc_278690626956_item	3638946	et	3	main
kaudu	doc_278690626956_item	3638945	et	3	main
kes	doc_278690626956_item	3638938	et	4	main
eestlased	doc_278690626956_item	3638937	et	3	main
külas	doc_278690626956_item	3638936	et	3	main
iga	doc_278690626956_item	3638930	et	4	main
ja	doc_278690626956_item	3638929	et	3	main
lapsele	doc_278690626956_item	3638892	et	4	main
või	doc_278690626956_item	3638886	et	4	main
mida	doc_278690626956_item	3638862	et	4	main
laul	doc_278690626956_item	3638859	et	4	main
ainult	doc_278690626956_item	3638858	et	4	main
sees	doc_278690626956_item	3638857	et	4	main
ajaloost	doc_278690626956_item	3638853	et	4	main
koosnevad	doc_278690626956_item	3638850	et	4	main
laulud	doc_278690626956_item	3638848	et	3	main
väiteid	doc_278690626956_item	3638840	et	4	main
faktidele	doc_278690626956_item	3638839	et	3	main
esitatud	doc_278690626956_item	3638838	et	4	main
lugemistekstis	doc_278690626956_item	3638837	et	3	main
ja	doc_278690626956_item	3638836	et	3	main
üldistav	doc_278690626956_item	3638833	et	4	main
ja	doc_278690626956_item	3638832	et	3	main
analüüsiv	doc_278690626956_item	3638831	et	4	main
pikkus	doc_278690626956_item	3638823	et	4	main
essee	doc_278690626956_item	3638822	et	4	main
eestlastest	doc_278690626956_item	3638820	et	4	main
teeb	doc_278690626956_item	3638819	et	3	main
essee	doc_278690626956_item	3638807	et	4	main
on	doc_278690626956_item	3639122	et	4	main
ja	doc_278690626956_item	3639120	et	3	main
oma	doc_278690626956_item	3639118	et	4	main
ja	doc_278690626956_item	3639117	et	3	main
kultuuri	doc_278690626956_item	3639116	et	4	main
on	doc_278690626956_item	3639111	et	4	main
tugevad	doc_278690626956_item	3639110	et	4	main
tugevad	doc_278690626956_item	3639107	et	4	main
jäätnud	doc_278690626956_item	3639104	et	4	main
idee	doc_278690626956_item	3639083	et	4	main
põhiline	doc_278690626956_item	3639082	et	3	main
on	doc_278690626956_item	3639079	et	4	main
ajal	doc_278690626956_item	3639076	et	4	main
eestlastel	doc_278690626957_item	3639324	et	4	main
ja	doc_278690626957_item	3639323	et	3	main
kõige	doc_278690626957_item	3639313	et	4	main
või	doc_278690626957_item	3639308	et	4	main
koos	doc_278690626957_item	3639297	et	4	main
nendel	doc_278690626957_item	3639290	et	4	main
miks	doc_278690626957_item	3639287	et	4	main
naised	doc_278690626957_item	3639284	et	3	main
meil	doc_278690626957_item	3639266	et	4	main
on	doc_278690626957_item	3639257	et	4	main
milline	doc_278690626957_item	3639252	et	3	main
lauldi	doc_278690626957_item	3639224	et	3	main
mida	doc_278690626957_item	3639204	et	4	main
lapsele	doc_278690626957_item	3639193	et	4	main
või	doc_278690626957_item	3639181	et	4	main
probleemid	doc_278690626957_item	3639180	et	3	main
milline	doc_278690626957_item	3639179	et	3	main
teada	doc_278690626957_item	3639178	et	3	main
saame	doc_278690626957_item	3639177	et	4	main
et	doc_278690626957_item	3639176	et	3	main
nii	doc_278690626957_item	3639175	et	3	main
teha	doc_278690626957_item	3639174	et	3	main
võimalus	doc_278690626957_item	3639173	et	3	main
on	doc_278690626957_item	3639172	et	4	main
see	doc_278690626957_item	3639171	et	3	main
väiteid	doc_278690626957_item	3639162	et	4	main
faktidele	doc_278690626957_item	3639161	et	3	main
esitatud	doc_278690626957_item	3639160	et	4	main
tuginema	doc_278690626957_item	3639156	et	3	main
üldistav	doc_278690626957_item	3639155	et	4	main
eesti	doc_278690626956_item	3638970	et	4	main
ise	doc_278690626956_item	3638968	et	4	main
võime	doc_278690626956_item	3638967	et	4	main
ainult	doc_278690626956_item	3638962	et	4	main
piima	doc_278690626956_item	3638952	et	4	main
annab	doc_278690626956_item	3638951	et	3	main
lehm	doc_278690626956_item	3638950	et	3	main
nägu	doc_278690626956_item	3638932	et	4	main
laul	doc_278690626956_item	3638931	et	4	main
kõik	doc_278690626956_item	3638927	et	4	main
tõi	doc_278690626956_item	3638918	et	3	main
ja	doc_278690626956_item	3638917	et	3	main
kergem	doc_278690626956_item	3638916	et	4	main
oli	doc_278690626956_item	3638915	et	3	main
töö	doc_278690626956_item	3638914	et	4	main
lauldi	doc_278690626956_item	3638913	et	3	main
millal	doc_278690626956_item	3638912	et	3	main
ja	doc_278690626956_item	3638911	et	3	main
töörütm	doc_278690626956_item	3638910	et	3	main
oma	doc_278690626956_item	3638909	et	4	main
oli	doc_278690626956_item	3638908	et	3	main
tööl	doc_278690626956_item	3638907	et	3	main
igal	doc_278690626956_item	3638906	et	3	main
jooksul	doc_278690626956_item	3638905	et	4	main
peole	doc_278690626956_item	3638904	et	4	main
teiste	doc_278690626956_item	3638903	et	4	main
ja	doc_278690626956_item	3638902	et	3	main
ajal	doc_278690626956_item	3638901	et	4	main
pulma	doc_278690626956_item	3638900	et	4	main
rõõmu	doc_278690626956_item	3638899	et	4	main
ema	doc_278690626956_item	3638898	et	4	main
näitasid	doc_278690626956_item	3638897	et	4	main
ja	doc_278690626956_item	3638896	et	3	main
laulsid	doc_278690626956_item	3638895	et	4	main
kõik	doc_278690626956_item	3638894	et	4	main
oma	doc_278690626956_item	3638891	et	4	main
lauldi	doc_278690626956_item	3638890	et	3	main
emad	doc_278690626956_item	3638889	et	3	main
või	doc_278690626956_item	3638888	et	4	main
millega	doc_278690626956_item	3638879	et	3	main
lauldi	doc_278690626956_item	3638877	et	3	main
mõtlen	doc_278690626956_item	3638876	et	3	main
oma	doc_278690626956_item	3638856	et	4	main
traditsioone	doc_278690626956_item	3638855	et	3	main
olema	doc_278690626956_item	3638829	et	4	main
350	doc_278690626956_item	3638825	et	2	main
kirjutamine	doc_278690626956_item	3638814	et	4	main
test	doc_278690626956_item	3638813	et	3	main
kes	doc_278690626956_item	3639126	et	4	main
inimesed	doc_278690626956_item	3639124	et	3	main
mäletavad	doc_278690626956_item	3639114	et	4	main
kes	doc_278690626956_item	3639113	et	4	main
inimesed	doc_278690626956_item	3639108	et	3	main
küsimus	doc_278690626956_item	3639081	et	4	main
rohkem	doc_278690626956_item	3639072	et	4	main
on	doc_278690626957_item	3639312	et	4	main
ja	doc_278690626957_item	3639299	et	3	main
istusid	doc_278690626957_item	3639296	et	4	main
vabaaega	doc_278690626957_item	3639294	et	4	main
et	doc_278690626957_item	3639289	et	3	main
sellepärast	doc_278690626957_item	3639288	et	3	main
mehed	doc_278690626957_item	3639286	et	3	main
eesti	doc_278690626957_item	3639276	et	4	main
ja	doc_278690626957_item	3639275	et	3	main
vened	doc_278690626957_item	3639274	et	3	main
kes	doc_278690626957_item	3639256	et	4	main
sõltub	doc_278690626957_item	3639255	et	3	main
edasi	doc_278690626957_item	3639227	et	3	main
laulu	doc_278690626957_item	3639226	et	4	main
aga	doc_278690626957_item	3639218	et	3	main
oma	doc_278690626957_item	3639216	et	4	main
lauldi	doc_278690626957_item	3639215	et	3	main
kirjutasid	doc_278690626957_item	3639214	et	4	main
kirjutasid	doc_278690626957_item	3639208	et	4	main
eestlased	doc_278690626957_item	3639207	et	3	main
kuidas	doc_278690626957_item	3639206	et	3	main
näen	doc_278690626957_item	3639205	et	3	main
veel	doc_278690626957_item	3639195	et	4	main
töötades	doc_278690626957_item	3639194	et	3	main
olid	doc_278690626957_item	3639183	et	4	main
rõõmused	doc_278690626957_item	3639182	et	3	main
kultuurinähtus	doc_278690626957_item	3639170	et	4	main
illustreerida	doc_278690626957_item	3639165	et	3	main
on	doc_278690626957_item	3639163	et	4	main
olema	doc_278690626957_item	3639151	et	4	main
ajalt	doc_278690626958_item	3639641	et	4	main
rahva	doc_278690626958_item	3639638	et	3	main
sina	doc_278690626958_item	3639636	et	4	main
eesti	doc_278690626958_item	3639634	et	4	main
kuuled	doc_278690626958_item	3639633	et	3	main
sa	doc_278690626958_item	3639632	et	3	main
kui	doc_278690626958_item	3639631	et	3	main
et	doc_278690626958_item	3639630	et	3	main
nii	doc_278690626958_item	3639629	et	3	main
liit	doc_278690626958_item	3639620	et	3	main
laul	doc_278690626958_item	3639450	et	4	main
esimene	doc_278690626958_item	3639449	et	3	main
rikkad	doc_278690626958_item	3639445	et	4	main
midagi	doc_278690626958_item	3639441	et	4	main
laul	doc_278690626958_item	3639420	et	4	main
et	doc_278690626958_item	3639419	et	3	main
arvan	doc_278690626958_item	3639418	et	3	main
eestis	doc_278690626958_item	3639417	et	3	main
laulust	doc_278690626958_item	3639411	et	4	main
olnud	doc_278690626958_item	3639401	et	4	main
olulised	doc_278690626958_item	3639387	et	4	main
nii	doc_278690626958_item	3639386	et	3	main
lugemistekstis	doc_278690626958_item	3639360	et	3	main
olema	doc_278690626958_item	3639352	et	4	main
eestlastest	doc_278690626958_item	3639343	et	4	main
mis	doc_278690626958_item	3639341	et	4	main
eestlasi	doc_278690626958_item	3639615	et	3	main
elu	doc_278690626958_item	3639597	et	4	main
laulurahva	doc_278690626958_item	3639596	et	3	main
me	doc_278690626958_item	3639591	et	4	main
ja	doc_278690626958_item	3639589	et	3	main
eesti	doc_278690626958_item	3639588	et	4	main
ajal	doc_278690626956_item	3638869	et	4	main
ja	doc_278690626956_item	3638864	et	3	main
näidata	doc_278690626956_item	3638861	et	4	main
ja	doc_278690626956_item	3638854	et	3	main
mis	doc_278690626956_item	3638849	et	4	main
on	doc_278690626956_item	3638846	et	4	main
rahvalaulud	doc_278690626956_item	3638845	et	3	main
näidetega	doc_278690626956_item	3638844	et	3	main
illustreerida	doc_278690626956_item	3638843	et	3	main
soovitatav	doc_278690626956_item	3638842	et	4	main
loengus	doc_278690626956_item	3638835	et	3	main
peab	doc_278690626956_item	3638828	et	4	main
300	doc_278690626956_item	3638824	et	2	main
eesti	doc_278690626956_item	3638808	et	4	main
need	doc_278690626956_item	3639125	et	3	main
need	doc_278690626956_item	3639123	et	3	main
minevikut	doc_278690626956_item	3639119	et	4	main
hingaliselt	doc_278690626956_item	3639109	et	4	main
kõige	doc_278690626956_item	3639106	et	4	main
minevikus	doc_278690626956_item	3639105	et	3	main
ei	doc_278690626956_item	3639103	et	4	main
midagi	doc_278690626956_item	3639102	et	4	main
mitte	doc_278690626956_item	3639101	et	3	main
et	doc_278690626956_item	3639100	et	3	main
mäletada	doc_278690626956_item	3639099	et	3	main
et	doc_278690626956_item	3639098	et	3	main
koosnetakse	doc_278690626956_item	3639097	et	3	main
laulde	doc_278690626956_item	3639096	et	4	main
minevikut	doc_278690626956_item	3639095	et	4	main
neid	doc_278690626956_item	3639094	et	4	main
tunna	doc_278690626956_item	3639093	et	4	main
südameid	doc_278690626956_item	3639090	et	3	main
ühendab	doc_278690626956_item	3639088	et	3	main
ritooriline	doc_278690626956_item	3639080	et	4	main
laul	doc_278690626956_item	3639087	et	4	main
selles	doc_278690626956_item	3639085	et	4	main
on	doc_278690626956_item	3639084	et	4	main
see	doc_278690626957_item	3639325	et	3	main
teema	doc_278690626957_item	3639322	et	4	main
aga	doc_278690626957_item	3639302	et	3	main
emalaulaulud	doc_278690626957_item	3639301	et	3	main
oli	doc_278690626957_item	3639291	et	3	main
sõnad	doc_278690626957_item	3639277	et	4	main
laulu	doc_278690626957_item	3639271	et	4	main
sega	doc_278690626957_item	3639270	et	4	main
väga	doc_278690626957_item	3639268	et	3	main
meie	doc_278690626957_item	3639262	et	4	main
et	doc_278690626957_item	3639261	et	3	main
sellepärast	doc_278690626957_item	3639260	et	3	main
oli	doc_278690626957_item	3639253	et	3	main
seda	doc_278690626957_item	3639225	et	3	main
motiive	doc_278690626957_item	3639221	et	3	main
nad	doc_278690626957_item	3639219	et	3	main
laulu	doc_278690626957_item	3639210	et	4	main
oma	doc_278690626957_item	3639209	et	4	main
levitud	doc_278690626957_item	3639199	et	4	main
väga	doc_278690626957_item	3639198	et	3	main
oli	doc_278690626957_item	3639197	et	3	main
eestlastel	doc_278690626957_item	3639196	et	4	main
vanal	doc_278690626957_item	3639188	et	3	main
vanaisal	doc_278690626957_item	3639187	et	3	main
ja	doc_278690626957_item	3639186	et	3	main
vanaemal	doc_278690626957_item	3639185	et	3	main
meie	doc_278690626957_item	3639184	et	4	main
lugemistekstis	doc_278690626957_item	3639159	et	3	main
ja	doc_278690626957_item	3639158	et	3	main
loengus	doc_278690626957_item	3639157	et	3	main
peab	doc_278690626957_item	3639150	et	4	main
elu	doc_278690626958_item	3639639	et	4	main
tunned	doc_278690626958_item	3639637	et	3	main
salvestatud	doc_278690626958_item	3639472	et	4	main
vähe	doc_278690626958_item	3639471	et	3	main
nii	doc_278690626958_item	3639470	et	3	main
kui	doc_278690626958_item	3639453	et	3	main
ja	doc_278690626958_item	3639447	et	3	main
olevad	doc_278690626958_item	3639444	et	4	main
tahab	doc_278690626958_item	3639437	et	3	main
laps	doc_278690626958_item	3639435	et	4	main
pisikene	doc_278690626958_item	3639434	et	3	main
nägu	doc_278690626958_item	3639433	et	4	main
tuli	doc_278690626958_item	3639428	et	4	main
esimene	doc_278690626958_item	3639426	et	3	main
ja	doc_278690626958_item	3639425	et	3	main
ajal	doc_278690626958_item	3639424	et	4	main
vanal	doc_278690626958_item	3639423	et	3	main
raagimist	doc_278690626958_item	3639413	et	4	main
ja	doc_278690626958_item	3639412	et	3	main
vabadus	doc_278690626957_item	3639328	et	4	main
kõigepeaks	doc_278690626957_item	3639327	et	3	main
annab	doc_278690626957_item	3639326	et	3	main
meid	doc_278690626957_item	3639319	et	4	main
et	doc_278690626957_item	3639318	et	3	main
tundub	doc_278690626957_item	3639317	et	3	main
see	doc_278690626957_item	3639316	et	3	main
eestis	doc_278690626957_item	3639315	et	3	main
tähelepanuväärsem	doc_278690626957_item	3639314	et	4	main
sõjal	doc_278690626957_item	3639309	et	3	main
metsas	doc_278690626957_item	3639307	et	3	main
oli	doc_278690626957_item	3639306	et	3	main
ajal	doc_278690626957_item	3639305	et	4	main
samal	doc_278690626957_item	3639304	et	3	main
mehed	doc_278690626957_item	3639303	et	3	main
lauldi	doc_278690626957_item	3639300	et	3	main
nad	doc_278690626957_item	3639295	et	3	main
rohkem	doc_278690626957_item	3639293	et	4	main
natuke	doc_278690626957_item	3639292	et	4	main
kui	doc_278690626957_item	3639285	et	3	main
rohkem	doc_278690626957_item	3639283	et	4	main
lauldi	doc_278690626957_item	3639282	et	3	main
muidugi	doc_278690626957_item	3639281	et	4	main
laulurahva	doc_278690626957_item	3639280	et	3	main
on	doc_278690626957_item	3639273	et	4	main
venemaa	doc_278690626957_item	3639265	et	4	main
on	doc_278690626957_item	3639264	et	4	main
naaber	doc_278690626957_item	3639263	et	3	main
see	doc_278690626957_item	3639251	et	3	main
et	doc_278690626957_item	3639250	et	3	main
tundub	doc_278690626957_item	3639249	et	3	main
mulle	doc_278690626957_item	3639248	et	4	main
emaarmus	doc_278690626957_item	3639246	et	3	main
veel	doc_278690626957_item	3639247	et	4	main
laulurahva	doc_278690626957_item	3639245	et	3	main
eestlastest	doc_278690626957_item	3639244	et	4	main
teeb	doc_278690626957_item	3639243	et	3	main
mida	doc_278690626957_item	3639242	et	4	main
näidis	doc_278690626957_item	3639241	et	4	main
on	doc_278690626957_item	3639240	et	4	main
see	doc_278690626957_item	3639239	et	3	main
lapsele	doc_278690626957_item	3639238	et	4	main
oma	doc_278690626957_item	3639237	et	4	main
lauldi	doc_278690626957_item	3639236	et	3	main
ema	doc_278690626957_item	3639235	et	4	main
milline	doc_278690626957_item	3639234	et	3	main
emalaulud	doc_278690626957_item	3639233	et	3	main
arhiivis	doc_278690626957_item	3639232	et	3	main
leida	doc_278690626957_item	3639231	et	3	main
saame	doc_278690626957_item	3639230	et	4	main
me	doc_278690626957_item	3639229	et	4	main
praegu	doc_278690626957_item	3639228	et	3	main
ja	doc_278690626957_item	3639223	et	3	main
mälestusid	doc_278690626957_item	3639220	et	4	main
ei	doc_278690626957_item	3639213	et	4	main
laulu	doc_278690626957_item	3639212	et	4	main
nad	doc_278690626957_item	3639211	et	3	main
oma	doc_278690626957_item	3639192	et	4	main
inimesed	doc_278690626957_item	3639191	et	3	main
lauldi	doc_278690626957_item	3639190	et	3	main
ajal	doc_278690626957_item	3639189	et	4	main
meie	doc_278690626957_item	3639258	et	4	main
laulurahv	doc_278690626957_item	3639254	et	4	main
laulu	doc_278690626957_item	3639222	et	4	main
lapsele	doc_278690626957_item	3639217	et	4	main
kõik	doc_278690626957_item	3639203	et	4	main
lauldi	doc_278690626957_item	3639202	et	3	main
laulud	doc_278690626957_item	3639201	et	3	main
pulmade	doc_278690626957_item	3639200	et	3	main
on	doc_278690626957_item	3639168	et	4	main
näidetega	doc_278690626957_item	3639166	et	3	main
analüüsiv	doc_278690626957_item	3639153	et	4	main
essee	doc_278690626957_item	3639149	et	4	main
sõna	doc_278690626957_item	3639148	et	4	main
350	doc_278690626957_item	3639147	et	2	main
300	doc_278690626957_item	3639146	et	2	main
pikkus	doc_278690626957_item	3639145	et	4	main
laulurahva	doc_278690626957_item	3639143	et	3	main
essee	doc_278690626957_item	3639144	et	4	main
eestlastest	doc_278690626957_item	3639142	et	4	main
teeb	doc_278690626957_item	3639141	et	3	main
mis	doc_278690626957_item	3639140	et	4	main
teemal	doc_278690626957_item	3639139	et	3	main
essee	doc_278690626957_item	3639138	et	4	main
kirjutage	doc_278690626957_item	3639137	et	3	main
kirjutamine	doc_278690626957_item	3639136	et	4	main
test	doc_278690626957_item	3639135	et	3	main
keele	doc_278690626957_item	3639134	et	4	main
teise	doc_278690626957_item	3639133	et	4	main
kui	doc_278690626957_item	3639132	et	3	main
keele	doc_278690626957_item	3639131	et	4	main
eesti	doc_278690626957_item	3639130	et	4	main
essee	doc_278690626957_item	3639129	et	4	main
tähelepanuväärnu	doc_278690626957_item	3639169	et	4	main
laulurahv	doc_278690626957_item	3639167	et	4	main
soovitatav	doc_278690626957_item	3639164	et	4	main
arutlev	doc_278690626957_item	3639152	et	4	main
vanalt	doc_278690626958_item	3639640	et	4	main
laulu	doc_278690626958_item	3639635	et	4	main
minu	doc_278690626958_item	3639626	et	3	main
ja	doc_278690626958_item	3639625	et	3	main
nii	doc_278690626958_item	3639623	et	3	main
nad	doc_278690626958_item	3639621	et	3	main
olevad	doc_278690626958_item	3639619	et	4	main
laulud	doc_278690626958_item	3639618	et	3	main
ja	doc_278690626958_item	3639617	et	3	main
eestlased	doc_278690626958_item	3639616	et	3	main
muidugi	doc_278690626958_item	3639476	et	4	main
laulu	doc_278690626958_item	3639474	et	4	main
vana	doc_278690626958_item	3639473	et	4	main
enam	doc_278690626958_item	3639452	et	4	main
sündis	doc_278690626958_item	3639451	et	3	main
laulurahva	doc_278690626958_item	3639446	et	3	main
eestlased	doc_278690626958_item	3639443	et	3	main
öelda	doc_278690626958_item	3639442	et	4	main
aga	doc_278690626958_item	3639438	et	3	main
see	doc_278690626958_item	3639431	et	3	main
hüüdmine	doc_278690626958_item	3639430	et	4	main
laulu	doc_278690626958_item	3639416	et	4	main
tähendab	doc_278690626958_item	3639415	et	3	main
aru	doc_278690626958_item	3639408	et	4	main
mina	doc_278690626958_item	3639406	et	4	main
aastat	doc_278690626958_item	3639403	et	3	main
mind	doc_278690626958_item	3639399	et	4	main
ja	doc_278690626958_item	3639396	et	3	main
väga	doc_278690626958_item	3639394	et	3	main
ajal	doc_278690626958_item	3639391	et	4	main
vana-vana	doc_278690626958_item	3639390	et	4	main
ka	doc_278690626958_item	3639389	et	3	main
kui	doc_278690626958_item	3639388	et	3	main
mina	doc_278690626958_item	3639372	et	4	main
soovitatav	doc_278690626958_item	3639365	et	4	main
on	doc_278690626958_item	3639364	et	4	main
väiteid	doc_278690626958_item	3639363	et	4	main
üldistav	doc_278690626958_item	3639356	et	4	main
keele	doc_278690626958_item	3639335	et	4	main
keele	doc_278690626958_item	3639332	et	4	main
aga	doc_278690626958_item	3639607	et	3	main
eestlastest	doc_278690626958_item	3639595	et	4	main
ja	doc_278690626957_item	3639154	et	3	main
koos	doc_278690626958_item	3639645	et	4	main
kõik	doc_278690626958_item	3639643	et	4	main
on	doc_278690626958_item	3639628	et	4	main
lähedal	doc_278690626958_item	3639624	et	4	main
olevad	doc_278690626958_item	3639622	et	4	main
fragmentid	doc_278690626958_item	3639477	et	4	main
nende	doc_278690626958_item	3639448	et	4	main
on	doc_278690626958_item	3639432	et	4	main
veel	doc_278690626958_item	3639422	et	4	main
sündis	doc_278690626958_item	3639421	et	3	main
ka	doc_278690626958_item	3639409	et	3	main
aga	doc_278690626958_item	3639405	et	3	main
kahjuks	doc_278690626958_item	3639398	et	4	main
huvitav	doc_278690626958_item	3639395	et	4	main
ütles	doc_278690626958_item	3639393	et	3	main
lugesin	doc_278690626958_item	3639373	et	3	main
olevad	doc_278690626958_item	3639370	et	4	main
eestlased	doc_278690626958_item	3639369	et	3	main
faktidele	doc_278690626958_item	3639362	et	3	main
peab	doc_278690626958_item	3639351	et	4	main
laulurahva	doc_278690626958_item	3639344	et	3	main
essee	doc_278690626958_item	3639339	et	4	main
kirjutage	doc_278690626958_item	3639338	et	3	main
kirjutamine	doc_278690626958_item	3639337	et	4	main
test	doc_278690626958_item	3639336	et	3	main
eesti	doc_278690626958_item	3639331	et	4	main
täname	doc_278690626958_item	3639613	et	3	main
olevad	doc_278690626958_item	3639611	et	4	main
maas	doc_278690626958_item	3639604	et	4	main
muutub	doc_278690626958_item	3639603	et	3	main
on	doc_278690626958_item	3639601	et	4	main
teeb	doc_278690626958_item	3639594	et	3	main
terve	doc_278690626958_item	3639587	et	4	main
ja	doc_278690626958_item	3639586	et	3	main
rahvad	doc_278690626958_item	3639585	et	3	main
kõik	doc_278690626958_item	3639584	et	4	main
kokku	doc_278690626958_item	3639583	et	3	main
on	doc_278690626958_item	3639577	et	4	main
ja	doc_278690626958_item	3639573	et	3	main
kõik	doc_278690626958_item	3639561	et	4	main
laulust	doc_278690626958_item	3639560	et	4	main
muusika	doc_278690626958_item	3639519	et	4	main
uued	doc_278690626958_item	3639518	et	3	main
ja	doc_278690626958_item	3639517	et	3	main
ka	doc_278690626958_item	3639501	et	3	main
muidugi	doc_278690626958_item	3639500	et	4	main
see	doc_278690626958_item	3639498	et	3	main
laulu	doc_278690626958_item	3639497	et	4	main
last	doc_278690626958_item	3639494	et	4	main
oma	doc_278690626958_item	3639493	et	4	main
kiigutab	doc_278690626958_item	3639492	et	3	main
ema	doc_278690626958_item	3639491	et	4	main
noor	doc_278690626958_item	3639490	et	3	main
kui	doc_278690626958_item	3639489	et	3	main
aljal	doc_278690626958_item	3639488	et	4	main
sel	doc_278690626958_item	3639487	et	3	main
on	doc_278690626958_item	3639486	et	4	main
meeles	doc_278690626958_item	3639485	et	3	main
minu	doc_278690626958_item	3639484	et	3	main
laulumine	doc_278690626958_item	3639483	et	4	main
ausam	doc_278690626958_item	3639482	et	4	main
kõige	doc_278690626958_item	3639481	et	4	main
meeles	doc_278690626958_item	3639480	et	3	main
mu	doc_278690626958_item	3639479	et	3	main
sümbol	doc_278690626960_item	3639955	et	3	main
toimib	doc_278690626958_item	3639644	et	3	main
tanapaeviti	doc_278690626958_item	3639642	et	4	main
meeles	doc_278690626958_item	3639627	et	3	main
olevad	doc_278690626958_item	3639478	et	4	main
aga	doc_278690626958_item	3639475	et	3	main
on	doc_278690626958_item	3639469	et	4	main
meil	doc_278690626958_item	3639468	et	4	main
kahjuks	doc_278690626958_item	3639467	et	4	main
maast	doc_278690626958_item	3639466	et	3	main
teisest	doc_278690626958_item	3639465	et	4	main
ja	doc_278690626958_item	3639464	et	3	main
kirikust	doc_278690626958_item	3639463	et	4	main
häälest	doc_278690626958_item	3639462	et	4	main
looma	doc_278690626958_item	3639461	et	4	main
ja	doc_278690626958_item	3639460	et	3	main
loodust	doc_278690626958_item	3639459	et	4	main
tuli	doc_278690626958_item	3639458	et	4	main
see	doc_278690626958_item	3639457	et	3	main
tagasi	doc_278690626958_item	3639456	et	3	main
aastat	doc_278690626958_item	3639455	et	3	main
tuhat	doc_278690626958_item	3639454	et	4	main
oska	doc_278690626958_item	3639440	et	4	main
ei	doc_278690626958_item	3639439	et	4	main
kes	doc_278690626958_item	3639436	et	4	main
oli	doc_278690626958_item	3639429	et	3	main
mis	doc_278690626958_item	3639427	et	4	main
mis	doc_278690626958_item	3639414	et	4	main
arvuti	doc_278690626958_item	3639410	et	4	main
sada	doc_278690626958_item	3639402	et	4	main
täis	doc_278690626958_item	3639397	et	4	main
olevad	doc_278690626958_item	3639385	et	4	main
laulud	doc_278690626958_item	3639384	et	3	main
tänapäeval	doc_278690626958_item	3639383	et	3	main
ainult	doc_278690626958_item	3639382	et	4	main
mitte	doc_278690626958_item	3639381	et	3	main
palju	doc_278690626958_item	3639374	et	4	main
esitatud	doc_278690626958_item	3639361	et	4	main
loengus	doc_278690626958_item	3639358	et	3	main
analüüsiv	doc_278690626958_item	3639354	et	4	main
arutlev	doc_278690626958_item	3639353	et	4	main
essee	doc_278690626958_item	3639350	et	4	main
350	doc_278690626958_item	3639348	et	2	main
teeb	doc_278690626958_item	3639342	et	3	main
teemal	doc_278690626958_item	3639340	et	3	main
kui	doc_278690626958_item	3639333	et	3	main
essee	doc_278690626958_item	3639330	et	4	main
nad	doc_278690626958_item	3639610	et	3	main
laulud	doc_278690626958_item	3639608	et	3	main
ja	doc_278690626958_item	3639605	et	3	main
näeme	doc_278690626958_item	3639592	et	3	main
mida	doc_278690626958_item	3639590	et	4	main
saavad	doc_278690626958_item	3639582	et	4	main
kus	doc_278690626958_item	3639581	et	3	main
lauluvaljakul	doc_278690626958_item	3639580	et	4	main
laulupidu	doc_278690626958_item	3639579	et	4	main
kõige	doc_278690626958_item	3639575	et	4	main
pidu	doc_278690626958_item	3639574	et	4	main
muusikafestivaalid	doc_278690626958_item	3639572	et	4	main
erinevaid	doc_278690626958_item	3639571	et	4	main
oli	doc_278690626958_item	3639562	et	3	main
nad	doc_278690626958_item	3639541	et	3	main
rohkem	doc_278690626958_item	3639531	et	4	main
mulle	doc_278690626958_item	3639528	et	4	main
laulukultuur	doc_278690626958_item	3639525	et	3	main
eesti	doc_278690626958_item	3639511	et	4	main
aeg	doc_278690626958_item	3639505	et	3	main
vaga	doc_278690626958_item	3639503	et	4	main
on	doc_278690626958_item	3639499	et	4	main
tuleb	doc_278690626958_item	3639496	et	3	main
ja	doc_278690626958_item	3639495	et	3	main
on	doc_278690626960_item	3639958	et	4	main
rahvalaul	doc_278690626960_item	3639952	et	4	main
sõitnud	doc_278690626960_item	3639950	et	4	main
kokku	doc_278690626960_item	3639949	et	3	main
tuttavaid	doc_278690626960_item	3639943	et	3	main
ja	doc_278690626960_item	3639942	et	3	main
sugulasi	doc_278690626960_item	3639941	et	3	main
sõpru	doc_278690626960_item	3639940	et	3	main
kohata	doc_278690626960_item	3639939	et	4	main
rahvapidu	doc_278690626960_item	3639932	et	4	main
suur	doc_278690626960_item	3639931	et	3	main
on	doc_278690626960_item	3639924	et	4	main
ja	doc_278690626960_item	3639919	et	3	main
mina	doc_278690626960_item	3639916	et	4	main
on	doc_278690626960_item	3639904	et	4	main
see	doc_278690626960_item	3639903	et	3	main
lauluvad	doc_278690626960_item	3639902	et	4	main
programm	doc_278690626960_item	3639885	et	3	main
hea	doc_278690626960_item	3639884	et	4	main
paremaid	doc_278690626960_item	3639873	et	4	main
padar	doc_278690626960_item	3639868	et	4	main
näiteks	doc_278690626960_item	3639866	et	4	main
laulda	doc_278690626960_item	3639865	et	4	main
võimalus	doc_278690626960_item	3639864	et	3	main
eestis	doc_278690626960_item	3639839	et	3	main
on	doc_278690626960_item	3639836	et	4	main
on	doc_278690626960_item	3639828	et	4	main
kui	doc_278690626960_item	3639827	et	3	main
mõtlevad	doc_278690626960_item	3639826	et	4	main
eestlased	doc_278690626960_item	3639825	et	3	main
siis	doc_278690626960_item	3639824	et	3	main
laulupidu	doc_278690626960_item	3639823	et	4	main
oli	doc_278690626960_item	3639822	et	3	main
sain	doc_278690626958_item	3639407	et	3	main
tagasi	doc_278690626958_item	3639404	et	3	main
ei	doc_278690626958_item	3639400	et	4	main
dekaan	doc_278690626958_item	3639392	et	3	main
et	doc_278690626958_item	3639380	et	3	main
teada	doc_278690626958_item	3639379	et	3	main
sain	doc_278690626958_item	3639378	et	3	main
ja	doc_278690626958_item	3639377	et	3	main
eestist	doc_278690626958_item	3639376	et	3	main
kultuuriraamatuid	doc_278690626958_item	3639375	et	3	main
laulurahva	doc_278690626958_item	3639371	et	3	main
muidugi	doc_278690626958_item	3639368	et	4	main
näidetega	doc_278690626958_item	3639367	et	3	main
illustreerida	doc_278690626958_item	3639366	et	3	main
ja	doc_278690626958_item	3639359	et	3	main
tuginema	doc_278690626958_item	3639357	et	3	main
ja	doc_278690626958_item	3639355	et	3	main
sõna	doc_278690626958_item	3639349	et	4	main
300	doc_278690626958_item	3639347	et	2	main
pikkus	doc_278690626958_item	3639346	et	4	main
essee	doc_278690626958_item	3639345	et	4	main
teise	doc_278690626958_item	3639334	et	4	main
siis	doc_278690626958_item	3639614	et	3	main
olemal	doc_278690626958_item	3639612	et	3	main
elavad	doc_278690626958_item	3639609	et	4	main
eestis	doc_278690626958_item	3639606	et	3	main
kõik	doc_278690626958_item	3639602	et	4	main
eläma	doc_278690626958_item	3639600	et	4	main
räägitakse	doc_278690626958_item	3639599	et	3	main
kuidas	doc_278690626958_item	3639598	et	3	main
muidugi	doc_278690626958_item	3639578	et	4	main
väga	doc_278690626958_item	3639569	et	3	main
toimub	doc_278690626958_item	3639568	et	3	main
eestis	doc_278690626958_item	3639567	et	3	main
nüüd	doc_278690626958_item	3639566	et	4	main
poliitiline	doc_278690626958_item	3639564	et	3	main
nii	doc_278690626958_item	3639537	et	3	main
eestlased	doc_278690626958_item	3639535	et	3	main
mis	doc_278690626958_item	3639527	et	4	main
seganud	doc_278690626958_item	3639524	et	4	main
uus	doc_278690626958_item	3639522	et	3	main
sundis	doc_278690626958_item	3639521	et	3	main
iseseisvust	doc_278690626958_item	3639513	et	4	main
aastal	doc_278690626958_item	3639509	et	3	main
eestis	doc_278690626958_item	3639506	et	3	main
eesti	doc_278690626960_item	3639957	et	4	main
kogu	doc_278690626960_item	3639947	et	4	main
üle	doc_278690626960_item	3639946	et	3	main
on	doc_278690626960_item	3639945	et	4	main
perega	doc_278690626960_item	3639936	et	3	main
koos	doc_278690626960_item	3639935	et	4	main
tullakse	doc_278690626960_item	3639934	et	3	main
kuhu	doc_278690626960_item	3639933	et	3	main
fotod	doc_278690626960_item	3639925	et	3	main
internetis	doc_278690626960_item	3639918	et	4	main
surfan	doc_278690626960_item	3639917	et	4	main
silmaringi	doc_278690626960_item	3639915	et	4	main
oma	doc_278690626960_item	3639914	et	4	main
huvitav	doc_278690626960_item	3639909	et	4	main
oli	doc_278690626960_item	3639908	et	3	main
koolis	doc_278690626960_item	3639907	et	4	main
on	doc_278690626960_item	3639883	et	4	main
oli	doc_278690626960_item	3639872	et	3	main
heliloojad	doc_278690626960_item	3639842	et	3	main
tema	doc_278690626960_item	3639815	et	4	main
ja	doc_278690626960_item	3639814	et	3	main
etvs	doc_278690626960_item	3639808	et	4	main
on	doc_278690626960_item	3639803	et	4	main
ajas	doc_278690626960_item	3639799	et	4	main
kui	doc_278690626960_item	3639790	et	3	main
ja	doc_278690626960_item	3639788	et	3	main
vana	doc_278690626960_item	3639787	et	4	main
väga	doc_278690626960_item	3639786	et	3	main
magab	doc_278690626960_item	3639782	et	3	main
väike	doc_278690626960_item	3639780	et	4	main
ja	doc_278690626960_item	3639779	et	3	main
laulu	doc_278690626960_item	3639778	et	4	main
oma	doc_278690626960_item	3639771	et	4	main
mis	doc_278690626958_item	3639593	et	4	main
palju	doc_278690626958_item	3639570	et	4	main
pikka	doc_278690626958_item	3639558	et	4	main
ka	doc_278690626958_item	3639557	et	3	main
mõjus	doc_278690626958_item	3639556	et	4	main
see	doc_278690626958_item	3639555	et	3	main
vabadusi	doc_278690626958_item	3639554	et	4	main
olnud	doc_278690626958_item	3639553	et	4	main
ei	doc_278690626958_item	3639552	et	4	main
eestis	doc_278690626958_item	3639551	et	3	main
ja	doc_278690626958_item	3639550	et	3	main
venemaa	doc_278690626958_item	3639549	et	4	main
tuli	doc_278690626958_item	3639548	et	4	main
kui	doc_278690626958_item	3639547	et	3	main
muusika	doc_278690626958_item	3639546	et	4	main
oma	doc_278690626958_item	3639545	et	4	main
laulud	doc_278690626958_item	3639544	et	3	main
oma	doc_278690626958_item	3639543	et	4	main
tegid	doc_278690626958_item	3639542	et	4	main
tähtsam	doc_278690626958_item	3639576	et	4	main
protestiga	doc_278690626958_item	3639565	et	3	main
natukene	doc_278690626958_item	3639563	et	4	main
aega	doc_278690626958_item	3639559	et	4	main
ajal	doc_278690626958_item	3639540	et	4	main
igal	doc_278690626958_item	3639539	et	3	main
et	doc_278690626958_item	3639534	et	3	main
kõige	doc_278690626958_item	3639530	et	4	main
aga	doc_278690626958_item	3639526	et	3	main
natukene	doc_278690626958_item	3639523	et	4	main
mootivid	doc_278690626958_item	3639520	et	4	main
sai	doc_278690626958_item	3639512	et	4	main
1991	doc_278690626958_item	3639508	et	2	main
tänapäeval	doc_278690626958_item	3639502	et	3	main
rõõmsad	doc_278690626958_item	3639538	et	3	main
olid	doc_278690626958_item	3639536	et	4	main
selline	doc_278690626958_item	3639533	et	4	main
on	doc_278690626958_item	3639532	et	4	main
meeldib	doc_278690626958_item	3639529	et	3	main
suhtlemised	doc_278690626958_item	3639516	et	4	main
uued	doc_278690626958_item	3639515	et	3	main
tulid	doc_278690626958_item	3639514	et	4	main
millal	doc_278690626958_item	3639510	et	3	main
alustab	doc_278690626958_item	3639507	et	3	main
huvitav	doc_278690626958_item	3639504	et	4	main
lauluriik	doc_278690626960_item	3639959	et	3	main
eesti	doc_278690626960_item	3639954	et	4	main
maailma	doc_278690626960_item	3639948	et	4	main
lootuses	doc_278690626960_item	3639938	et	4	main
laulupidu	doc_278690626960_item	3639929	et	4	main
edasi	doc_278690626960_item	3639928	et	3	main
nii	doc_278690626960_item	3639927	et	3	main
internetis	doc_278690626960_item	3639920	et	4	main
arendavad	doc_278690626960_item	3639913	et	4	main
noored	doc_278690626960_item	3639912	et	3	main
tallinnas	doc_278690626960_item	3639876	et	4	main
kui	doc_278690626960_item	3639875	et	3	main
euroopas	doc_278690626960_item	3639874	et	3	main
tanel	doc_278690626960_item	3639867	et	4	main
head	doc_278690626960_item	3639841	et	4	main
laul	doc_278690626960_item	3639838	et	4	main
noormees	doc_278690626960_item	3639813	et	4	main
hea	doc_278690626960_item	3639806	et	4	main
on	doc_278690626960_item	3639805	et	4	main
rahvalaul	doc_278690626960_item	3639802	et	4	main
ja	doc_278690626960_item	3639800	et	3	main
on	doc_278690626960_item	3639798	et	4	main
on	doc_278690626960_item	3639793	et	4	main
laul	doc_278690626960_item	3639784	et	4	main
laps	doc_278690626960_item	3639781	et	4	main
ja	doc_278690626960_item	3639773	et	3	main
silmaringi	doc_278690626960_item	3639772	et	4	main
hea	doc_278690626960_item	3639742	et	4	main
kõik	doc_278690626960_item	3639741	et	4	main
on	doc_278690626960_item	3639734	et	4	main
ja	doc_278690626960_item	3639730	et	3	main
kevad	doc_278690626960_item	3639729	et	3	main
on	doc_278690626960_item	3639728	et	4	main
kui	doc_278690626960_item	3639727	et	3	main
kujutlege	doc_278690626960_item	3639726	et	3	main
kui	doc_278690626960_item	3639719	et	3	main
head	doc_278690626960_item	3639717	et	4	main
eestis	doc_278690626960_item	3639715	et	3	main
eesti	doc_278690626960_item	3639708	et	4	main
see	doc_278690626960_item	3639703	et	3	main
eestlased	doc_278690626960_item	3639699	et	3	main
aga	doc_278690626960_item	3639698	et	3	main
ole	doc_278690626960_item	3639697	et	4	main
soovitatav	doc_278690626960_item	3639682	et	4	main
arutlev	doc_278690626960_item	3639670	et	4	main
olema	doc_278690626960_item	3639669	et	4	main
sõna	doc_278690626960_item	3639666	et	4	main
noored	doc_278690626962_item	3640167	et	3	main
aja	doc_278690626962_item	3640162	et	4	main
läbi	doc_278690626962_item	3640161	et	4	main
kohata	doc_278690626962_item	3640146	et	4	main
ka	doc_278690626962_item	3640139	et	3	main
kahes	doc_278690626962_item	3640126	et	4	main
toimus	doc_278690626962_item	3640125	et	3	main
pidu	doc_278690626962_item	3640124	et	4	main
tähistati	doc_278690626962_item	3640118	et	4	main
aastal	doc_278690626962_item	3640117	et	3	main
umbes	doc_278690626962_item	3640101	et	4	main
oli	doc_278690626962_item	3640100	et	3	main
eelkõige	doc_278690626962_item	3640071	et	3	main
euroopast	doc_278690626962_item	3640068	et	3	main
traditsioonid	doc_278690626962_item	3640066	et	3	main
laulutraditsiooni	doc_278690626962_item	3640050	et	4	main
kust	doc_278690626962_item	3640044	et	4	main
ja	doc_278690626962_item	3640035	et	3	main
on	doc_278690626962_item	3640028	et	4	main
elu	doc_278690626962_item	3640026	et	4	main
esteetiline	doc_278690626962_item	3640002	et	3	main
laulmine	doc_278690626962_item	3639999	et	4	main
näidetega	doc_278690626962_item	3639998	et	3	main
sõna	doc_278690626962_item	3639980	et	4	main
lõpuks	doc_278690626960_item	3639956	et	4	main
on	doc_278690626960_item	3639953	et	4	main
eesti	doc_278690626960_item	3639951	et	4	main
kes	doc_278690626960_item	3639944	et	4	main
on	doc_278690626960_item	3639930	et	4	main
rahvalaulud	doc_278690626960_item	3639923	et	3	main
on	doc_278690626960_item	3639921	et	4	main
meie	doc_278690626960_item	3639906	et	4	main
lauluriik	doc_278690626960_item	3639905	et	3	main
etvs	doc_278690626960_item	3639882	et	4	main
jalustrabav	doc_278690626960_item	3639881	et	3	main
oli	doc_278690626960_item	3639880	et	3	main
see	doc_278690626960_item	3639879	et	3	main
eurovisioon	doc_278690626960_item	3639878	et	3	main
oli	doc_278690626960_item	3639877	et	3	main
dave	doc_278690626960_item	3639870	et	4	main
hea	doc_278690626960_item	3639863	et	4	main
väga	doc_278690626960_item	3639862	et	3	main
on	doc_278690626960_item	3639861	et	4	main
eestis	doc_278690626960_item	3639860	et	3	main
süda	doc_278690626960_item	3639859	et	3	main
rahvalaulu	doc_278690626960_item	3639858	et	4	main
on	doc_278690626960_item	3639857	et	4	main
see	doc_278690626960_item	3639856	et	3	main
lauluväljak	doc_278690626960_item	3639855	et	3	main
ilus	doc_278690626960_item	3639854	et	4	main
väga	doc_278690626960_item	3639853	et	3	main
eestis	doc_278690626960_item	3639851	et	3	main
uurimine	doc_278690626960_item	3639850	et	4	main
on	doc_278690626960_item	3639852	et	4	main
ajuloo	doc_278690626960_item	3639849	et	4	main
nagu	doc_278690626960_item	3639848	et	3	main
pisut	doc_278690626960_item	3639847	et	3	main
tutvumine	doc_278690626960_item	3639846	et	4	main
rahvalauluga	doc_278690626960_item	3639845	et	4	main
et	doc_278690626960_item	3639844	et	3	main
arvan	doc_278690626960_item	3639843	et	3	main
hea	doc_278690626960_item	3639829	et	4	main
suhtlemine	doc_278690626960_item	3639820	et	4	main
lauluvad	doc_278690626960_item	3639817	et	4	main
vanaema	doc_278690626960_item	3639816	et	4	main
siin	doc_278690626960_item	3639809	et	4	main
laul	doc_278690626960_item	3639797	et	4	main
eesti	doc_278690626960_item	3639796	et	4	main
suhtlemine	doc_278690626960_item	3639795	et	4	main
ilus	doc_278690626960_item	3639789	et	4	main
eesti	doc_278690626960_item	3639783	et	4	main
lauluringi	doc_278690626960_item	3639774	et	4	main
muusika	doc_278690626960_item	3639736	et	4	main
kõik	doc_278690626960_item	3639724	et	4	main
tööl	doc_278690626960_item	3639723	et	3	main
siis	doc_278690626960_item	3639722	et	3	main
on	doc_278690626960_item	3639709	et	4	main
ei	doc_278690626960_item	3639696	et	4	main
päikest	doc_278690626960_item	3639695	et	4	main
ja	doc_278690626960_item	3639694	et	3	main
illustreerida	doc_278690626960_item	3639683	et	3	main
väiteid	doc_278690626960_item	3639680	et	4	main
ja	doc_278690626960_item	3639676	et	3	main
üldistav	doc_278690626960_item	3639673	et	4	main
essee	doc_278690626960_item	3639667	et	4	main
pikkus	doc_278690626960_item	3639663	et	4	main
kirjutamine	doc_278690626960_item	3639654	et	4	main
siin	doc_278690626960_item	3639937	et	4	main
ja	doc_278690626960_item	3639926	et	3	main
eesti	doc_278690626960_item	3639922	et	4	main
siin	doc_278690626960_item	3639911	et	4	main
rahvalauluring	doc_278690626960_item	3639910	et	3	main
benton	doc_278690626960_item	3639871	et	4	main
ja	doc_278690626960_item	3639869	et	3	main
on	doc_278690626960_item	3639840	et	4	main
iseseisvus	doc_278690626960_item	3639837	et	4	main
laul	doc_278690626960_item	3639835	et	4	main
eesti	doc_278690626960_item	3639834	et	4	main
et	doc_278690626960_item	3639833	et	3	main
arvan	doc_278690626960_item	3639832	et	3	main
vabariigis	doc_278690626960_item	3639831	et	3	main
elada	doc_278690626960_item	3639830	et	3	main
kui	doc_278690626960_item	3639821	et	3	main
see	doc_278690626960_item	3639818	et	3	main
näiteks	doc_278690626960_item	3639812	et	4	main
laulavad	doc_278690626960_item	3639811	et	4	main
inimesed	doc_278690626960_item	3639810	et	3	main
internetis	doc_278690626960_item	3639804	et	4	main
alus	doc_278690626960_item	3639801	et	4	main
lauluvad	doc_278690626960_item	3639792	et	4	main
inimesed	doc_278690626960_item	3639791	et	3	main
vana	doc_278690626960_item	3639777	et	4	main
laulab	doc_278690626960_item	3639776	et	3	main
arendada	doc_278690626960_item	3639770	et	3	main
võimalus	doc_278690626960_item	3639769	et	3	main
on	doc_278690626960_item	3639768	et	4	main
rahvalaulu	doc_278690626960_item	3639767	et	4	main
eesti	doc_278690626960_item	3639766	et	4	main
kuulad	doc_278690626960_item	3639765	et	3	main
sa	doc_278690626960_item	3639764	et	3	main
kui	doc_278690626960_item	3639763	et	3	main
ajal	doc_278690626960_item	3639762	et	4	main
igal	doc_278690626960_item	3639761	et	3	main
lauldi	doc_278690626960_item	3639760	et	3	main
eestlane	doc_278690626960_item	3639759	et	3	main
naistekoorid	doc_278690626960_item	3639758	et	3	main
ja	doc_278690626960_item	3639757	et	3	main
meeskoorid	doc_278690626960_item	3639755	et	4	main
lastekoorid	doc_278690626960_item	3639756	et	3	main
on	doc_278690626960_item	3639754	et	4	main
sotsiaalne	doc_278690626960_item	3639752	et	3	main
tegevus	doc_278690626960_item	3639753	et	4	main
ka	doc_278690626960_item	3639751	et	3	main
on	doc_278690626960_item	3639750	et	4	main
laul	doc_278690626960_item	3639749	et	4	main
eestis	doc_278690626960_item	3639748	et	3	main
eesti	doc_278690626960_item	3639747	et	4	main
lauluriik	doc_278690626960_item	3639746	et	3	main
on	doc_278690626960_item	3639745	et	4	main
see	doc_278690626960_item	3639744	et	3	main
hea	doc_278690626960_item	3639735	et	4	main
laulab	doc_278690626960_item	3639721	et	3	main
lauluriik	doc_278690626960_item	3639705	et	3	main
näidetega	doc_278690626960_item	3639684	et	3	main
faktidele	doc_278690626960_item	3639679	et	3	main
lugemistekstis	doc_278690626960_item	3639677	et	3	main
loengus	doc_278690626960_item	3639675	et	3	main
peab	doc_278690626960_item	3639668	et	4	main
300	doc_278690626960_item	3639664	et	2	main
essee	doc_278690626960_item	3639662	et	4	main
mis	doc_278690626960_item	3639658	et	4	main
on	doc_278690626960_item	3639819	et	4	main
programm	doc_278690626960_item	3639807	et	3	main
muusikalne	doc_278690626960_item	3639794	et	4	main
on	doc_278690626960_item	3639785	et	4	main
ema	doc_278690626960_item	3639775	et	4	main
siis	doc_278690626960_item	3639743	et	3	main
hiirekõrvul	doc_278690626960_item	3639732	et	4	main
hea	doc_278690626960_item	3639725	et	4	main
laulutraditsioonid	doc_278690626960_item	3639718	et	3	main
et	doc_278690626960_item	3639714	et	3	main
et	doc_278690626960_item	3639707	et	3	main
on	doc_278690626960_item	3639704	et	4	main
vihma	doc_278690626960_item	3639693	et	4	main
on	doc_278690626960_item	3639681	et	4	main
esitatud	doc_278690626960_item	3639678	et	4	main
tuginema	doc_278690626960_item	3639674	et	3	main
ja	doc_278690626960_item	3639672	et	3	main
analüüsiv	doc_278690626960_item	3639671	et	4	main
essee	doc_278690626960_item	3639656	et	4	main
kirjutage	doc_278690626960_item	3639655	et	3	main
eesti	doc_278690626960_item	3639648	et	4	main
oma	doc_278690626962_item	3640171	et	4	main
praegu	doc_278690626962_item	3640166	et	3	main
kujunenud	doc_278690626962_item	3640163	et	4	main
sõpru	doc_278690626962_item	3640148	et	3	main
rahvapidu	doc_278690626962_item	3640141	et	4	main
ja	doc_278690626962_item	3640136	et	3	main
pidu	doc_278690626962_item	3640134	et	4	main
see	doc_278690626962_item	3640131	et	3	main
tartus	doc_278690626962_item	3640130	et	3	main
traditsiooni	doc_278690626962_item	3640123	et	4	main
laulupidu	doc_278690626962_item	3640112	et	4	main
ükskõik	doc_278690626962_item	3640111	et	3	main
on	doc_278690626960_item	3639740	et	4	main
siis	doc_278690626960_item	3639739	et	3	main
laul	doc_278690626960_item	3639738	et	4	main
ja	doc_278690626960_item	3639737	et	3	main
kui	doc_278690626960_item	3639733	et	3	main
puud	doc_278690626960_item	3639731	et	4	main
inimene	doc_278690626960_item	3639720	et	3	main
on	doc_278690626960_item	3639716	et	4	main
vendunud	doc_278690626960_item	3639713	et	4	main
absoluutselt	doc_278690626960_item	3639712	et	4	main
olen	doc_278690626960_item	3639711	et	3	main
lauluriik	doc_278690626960_item	3639710	et	3	main
arvan	doc_278690626960_item	3639706	et	3	main
tantsivad	doc_278690626960_item	3639702	et	4	main
ja	doc_278690626960_item	3639701	et	3	main
laulvad	doc_278690626960_item	3639700	et	4	main
sajas	doc_278690626960_item	3639692	et	4	main
laulupidu	doc_278690626960_item	3639691	et	4	main
oli	doc_278690626960_item	3639690	et	3	main
kui	doc_278690626960_item	3639689	et	3	main
et	doc_278690626960_item	3639688	et	3	main
ajalehes	doc_278690626960_item	3639687	et	3	main
lugesin	doc_278690626960_item	3639686	et	3	main
ma	doc_278690626960_item	3639685	et	3	main
350	doc_278690626960_item	3639665	et	2	main
laulurahva	doc_278690626960_item	3639661	et	3	main
eestlastest	doc_278690626960_item	3639660	et	4	main
teeb	doc_278690626960_item	3639659	et	3	main
teise	doc_278690626960_item	3639651	et	4	main
kui	doc_278690626960_item	3639650	et	3	main
essee	doc_278690626960_item	3639647	et	4	main
eestlased	doc_278690626960_item	3639901	et	3	main
kontroll	doc_278690626960_item	3639900	et	3	main
range	doc_278690626960_item	3639899	et	4	main
tihti	doc_278690626962_item	3640168	et	3	main
sümboliteks	doc_278690626962_item	3640165	et	3	main
sugulasi	doc_278690626962_item	3640147	et	3	main
tullakse	doc_278690626962_item	3640143	et	3	main
tänapäevani	doc_278690626962_item	3640137	et	3	main
1994	doc_278690626962_item	3640116	et	2	main
traditsiooniks	doc_278690626962_item	3640115	et	3	main
natsionaalne	doc_278690626962_item	3640114	et	3	main
jäi	doc_278690626962_item	3640113	et	3	main
raske	doc_278690626962_item	3640109	et	4	main
päris	doc_278690626962_item	3640108	et	4	main
oli	doc_278690626962_item	3640107	et	3	main
aeg	doc_278690626962_item	3640106	et	3	main
nõukogude	doc_278690626962_item	3640105	et	3	main
laenatud	doc_278690626962_item	3640067	et	4	main
tagasi	doc_278690626962_item	3640064	et	3	main
tuhat	doc_278690626962_item	3640062	et	4	main
praegu	doc_278690626962_item	3640041	et	3	main
nii	doc_278690626962_item	3640038	et	3	main
elada	doc_278690626962_item	3640034	et	3	main
iseloomus	doc_278690626962_item	3640030	et	4	main
ja	doc_278690626962_item	3640003	et	3	main
väiteid	doc_278690626962_item	3639994	et	4	main
loengus	doc_278690626962_item	3639989	et	3	main
tuginema	doc_278690626962_item	3639988	et	3	main
olema	doc_278690626962_item	3639983	et	4	main
peab	doc_278690626962_item	3639982	et	4	main
essee	doc_278690626962_item	3639981	et	4	main
teemal	doc_278690626960_item	3639657	et	3	main
keele	doc_278690626960_item	3639649	et	4	main
oli	doc_278690626960_item	3639898	et	3	main
kui	doc_278690626960_item	3639897	et	3	main
programm	doc_278690626960_item	3639896	et	3	main
lõbus	doc_278690626960_item	3639895	et	4	main
ja	doc_278690626960_item	3639894	et	3	main
huvitav	doc_278690626960_item	3639893	et	4	main
näidis	doc_278690626960_item	3639892	et	4	main
laulu	doc_278690626960_item	3639891	et	4	main
eesti	doc_278690626960_item	3639890	et	4	main
on	doc_278690626960_item	3639889	et	4	main
see	doc_278690626960_item	3639888	et	3	main
kaasa	doc_278690626960_item	3639887	et	4	main
laulge	doc_278690626960_item	3639886	et	3	main
test	doc_278690626960_item	3639653	et	3	main
keele	doc_278690626960_item	3639652	et	4	main
kasutavad	doc_278690626962_item	3640169	et	4	main
sõitnud	doc_278690626962_item	3640157	et	4	main
kokku	doc_278690626962_item	3640156	et	3	main
maailma	doc_278690626962_item	3640155	et	4	main
kogu	doc_278690626962_item	3640154	et	4	main
üle	doc_278690626962_item	3640153	et	3	main
on	doc_278690626962_item	3640152	et	4	main
perega	doc_278690626962_item	3640145	et	3	main
koos	doc_278690626962_item	3640144	et	4	main
kuhu	doc_278690626962_item	3640142	et	3	main
suur	doc_278690626962_item	3640140	et	3	main
suurem	doc_278690626962_item	3640133	et	4	main
oli	doc_278690626962_item	3640132	et	3	main
ja	doc_278690626962_item	3640129	et	3	main
tallinnas	doc_278690626962_item	3640128	et	4	main
linnas	doc_278690626962_item	3640127	et	4	main
laulupidude	doc_278690626962_item	3640122	et	4	main
aga	doc_278690626962_item	3640110	et	3	main
ja	doc_278690626962_item	3640069	et	3	main
kujunenud	doc_278690626962_item	3640059	et	4	main
vanemat	doc_278690626962_item	3640049	et	4	main
öelda	doc_278690626962_item	3640043	et	4	main
vana	doc_278690626962_item	3640039	et	4	main
on	doc_278690626962_item	3640037	et	4	main
ei	doc_278690626962_item	3640032	et	4	main
juba	doc_278690626962_item	3640029	et	3	main
see	doc_278690626962_item	3640027	et	3	main
terve	doc_278690626962_item	3640025	et	4	main
laulab	doc_278690626962_item	3640024	et	3	main
arutlev	doc_278690626962_item	3639984	et	4	main
essee	doc_278690626962_item	3639976	et	4	main
laulurahva	doc_278690626962_item	3639975	et	3	main
eestlastest	doc_278690626962_item	3639974	et	4	main
teeb	doc_278690626962_item	3639973	et	3	main
minusse	doc_278690626963_item	3640420	et	3	main
ja	doc_278690626963_item	3640418	et	3	main
toimuvad	doc_278690626963_item	3640413	et	4	main
meie	doc_278690626963_item	3640410	et	4	main
praegu	doc_278690626963_item	3640409	et	3	main
kogunesid	doc_278690626963_item	3640397	et	4	main
aasta	doc_278690626963_item	3640395	et	4	main
on	doc_278690626963_item	3640391	et	4	main
tähistati	doc_278690626963_item	3640383	et	4	main
eestis	doc_278690626963_item	3640382	et	3	main
laulu	doc_278690626963_item	3640367	et	4	main
mis	doc_278690626963_item	3640349	et	4	main
eesti	doc_278690626963_item	3640340	et	4	main
pani	doc_278690626963_item	3640338	et	4	main
mis	doc_278690626963_item	3640337	et	4	main
suursündmus	doc_278690626963_item	3640336	et	3	main
rahvusliku	doc_278690626963_item	3640330	et	3	main
johann	doc_278690626963_item	3640318	et	4	main
eesotsas	doc_278690626963_item	3640317	et	4	main
seltsist	doc_278690626963_item	3640316	et	4	main
ja	doc_278690626963_item	3640312	et	3	main
aastal	doc_278690626963_item	3640308	et	3	main
tantsu	doc_278690626963_item	3640293	et	4	main
õpetasid	doc_278690626963_item	3640282	et	4	main
kirikut	doc_278690626963_item	3640278	et	3	main
eesti	doc_278690626963_item	3640240	et	4	main
on	doc_278690626963_item	3640232	et	4	main
kirjutamine	doc_278690626963_item	3640192	et	4	main
essee	doc_278690626963_item	3640185	et	4	main
saadakse	doc_740091150996_item	3640627	et	3	main
järgimine	doc_740091150996_item	3640622	et	4	main
mõeldes	doc_740091150996_item	3640614	et	3	main
ja	doc_740091150996_item	3640609	et	3	main
järelikult	doc_740091150996_item	3640601	et	3	main
kindlustundel	doc_740091150996_item	3640599	et	4	main
ja	doc_740091150996_item	3640584	et	3	main
kindlaksmääratud	doc_740091150996_item	3640582	et	4	main
olemuslik	doc_740091150996_item	3640580	et	3	main
inimese	doc_740091150996_item	3640579	et	4	main
läbi	doc_740091150996_item	3640578	et	4	main
kumab	doc_740091150996_item	3640577	et	3	main
milles	doc_740091150996_item	3640567	et	3	main
taluvuspiir	doc_740091150996_item	3640558	et	3	main
käigus	doc_740091150996_item	3640556	et	4	main
tabudeks	doc_740091150996_item	3640554	et	3	main
folkloor	doc_278690626962_item	3640170	et	4	main
rahvuslikeks	doc_278690626962_item	3640164	et	3	main
on	doc_278690626962_item	3640160	et	4	main
laulud	doc_278690626962_item	3640159	et	3	main
need	doc_278690626962_item	3640158	et	3	main
kes	doc_278690626962_item	3640151	et	4	main
tuttavaid	doc_278690626962_item	3640150	et	3	main
ja	doc_278690626962_item	3640149	et	3	main
laulupidu	doc_278690626962_item	3640138	et	4	main
ajaloos	doc_278690626962_item	3640135	et	4	main
kestnud	doc_278690626962_item	3640121	et	4	main
aastat	doc_278690626962_item	3640120	et	3	main
125	doc_278690626962_item	3640119	et	2	main
inimesi	doc_278690626962_item	3640104	et	4	main
000	doc_278690626962_item	3640103	et	2	main
30	doc_278690626962_item	3640102	et	2	main
arv	doc_278690626962_item	3640099	et	3	main
osavõtjate	doc_278690626962_item	3640098	et	3	main
ja	doc_278690626962_item	3640097	et	3	main
poistekoorid	doc_278690626962_item	3640096	et	3	main
ja	doc_278690626962_item	3640095	et	3	main
lastekoorid	doc_278690626962_item	3640094	et	3	main
naiskoorid	doc_278690626962_item	3640093	et	3	main
osavõtjatena	doc_278690626962_item	3640092	et	3	main
lisandusid	doc_278690626962_item	3640091	et	4	main
hiljem	doc_278690626962_item	3640090	et	3	main
puhkpilliorkestrit	doc_278690626962_item	3640089	et	3	main
ja	doc_278690626962_item	3640088	et	3	main
meeskoori	doc_278690626962_item	3640087	et	4	main
osales	doc_278690626962_item	3640086	et	3	main
peol	doc_278690626962_item	3640085	et	4	main
tartus	doc_278690626962_item	3640084	et	3	main
laulupidu	doc_278690626962_item	3640083	et	4	main
esimene	doc_278690626962_item	3640082	et	3	main
sündis	doc_278690626962_item	3640081	et	3	main
sajandil	doc_278690626962_item	3640080	et	3	main
19	doc_278690626962_item	3640079	et	2	main
muusika	doc_278690626962_item	3640078	et	4	main
slaavi	doc_278690626962_item	3640077	et	3	main
ja	doc_278690626962_item	3640076	et	3	main
läti	doc_278690626962_item	3640075	et	4	main
soome	doc_278690626962_item	3640074	et	3	main
rootsi	doc_278690626962_item	3640073	et	4	main
saaksa	doc_278690626962_item	3640072	et	4	main
aastat	doc_278690626962_item	3640063	et	3	main
enam	doc_278690626962_item	3640060	et	4	main
on	doc_278690626962_item	3640058	et	4	main
mis	doc_278690626962_item	3640057	et	4	main
rahvalaul	doc_278690626962_item	3640056	et	4	main
regivärsiline	doc_278690626962_item	3640055	et	4	main
iseloomulik	doc_278690626962_item	3640054	et	3	main
kultuurile	doc_278690626962_item	3640053	et	3	main
läänemeresoome	doc_278690626962_item	3640052	et	3	main
venemaalt	doc_278690626962_item	3640070	et	3	main
mõned	doc_278690626962_item	3640065	et	3	main
kui	doc_278690626962_item	3640061	et	3	main
eesti	doc_278690626962_item	3640048	et	4	main
algus	doc_278690626962_item	3640047	et	4	main
võtab	doc_278690626962_item	3640046	et	3	main
raske	doc_278690626962_item	3640042	et	4	main
laulutraditsioon	doc_278690626962_item	3640036	et	3	main
tohi	doc_278690626962_item	3640033	et	4	main
ja	doc_278690626962_item	3640023	et	3	main
tantsib	doc_278690626962_item	3640022	et	3	main
tema	doc_278690626962_item	3640021	et	4	main
muusikaga	doc_278690626962_item	3640020	et	3	main
elab	doc_278690626962_item	3640019	et	3	main
rahvas	doc_278690626962_item	3640018	et	4	main
eesti	doc_278690626962_item	3640017	et	4	main
kiigutades	doc_278690626962_item	3640016	et	3	main
last	doc_278690626962_item	3640015	et	4	main
töötades	doc_278690626962_item	3640014	et	3	main
olles	doc_278690626962_item	3640013	et	3	main
üksi	doc_278690626962_item	3640012	et	4	main
lauldi	doc_278690626962_item	3640011	et	3	main
elu	doc_278690626962_item	3640010	et	4	main
ongi	doc_278690626962_item	3640009	et	4	main
see	doc_278690626962_item	3640008	et	3	main
tegevus	doc_278690626962_item	3640007	et	4	main
sotsiaalne	doc_278690626962_item	3640006	et	3	main
väljendusvahend	doc_278690626962_item	3640005	et	3	main
emotsionaalne	doc_278690626962_item	3640004	et	3	main
esindab	doc_278690626962_item	3640051	et	3	main
ta	doc_278690626962_item	3640045	et	4	main
et	doc_278690626962_item	3640040	et	3	main
selleta	doc_278690626962_item	3640031	et	3	main
eestlastele	doc_278690626962_item	3640000	et	4	main
soovitatav	doc_278690626962_item	3639996	et	4	main
on	doc_278690626962_item	3639995	et	4	main
esitatud	doc_278690626962_item	3639992	et	4	main
ja	doc_278690626962_item	3639990	et	3	main
pikkus	doc_278690626962_item	3639977	et	4	main
teemal	doc_278690626962_item	3639971	et	3	main
essee	doc_278690626962_item	3639970	et	4	main
kirjutage	doc_278690626962_item	3639969	et	3	main
kirjutamine	doc_278690626962_item	3639968	et	4	main
test	doc_278690626962_item	3639967	et	3	main
keele	doc_278690626962_item	3639966	et	4	main
teise	doc_278690626962_item	3639965	et	4	main
kui	doc_278690626962_item	3639964	et	3	main
keele	doc_278690626962_item	3639963	et	4	main
eesti	doc_278690626962_item	3639962	et	4	main
essee	doc_278690626962_item	3639961	et	4	main
hauani	doc_278690626962_item	3640183	et	3	main
häilist	doc_278690626962_item	3640182	et	4	main
muusikaga	doc_278690626962_item	3640181	et	3	main
elavad	doc_278690626962_item	3640180	et	4	main
eestlased	doc_278690626962_item	3640179	et	3	main
sest	doc_278690626962_item	3640178	et	4	main
populaarne	doc_278690626962_item	3640177	et	3	main
väga	doc_278690626962_item	3640176	et	3	main
on	doc_278690626962_item	3640175	et	4	main
see	doc_278690626962_item	3640174	et	3	main
ja	doc_278690626962_item	3640173	et	3	main
muusikas	doc_278690626962_item	3640172	et	3	main
et	doc_278690626963_item	3640424	et	3	main
mis	doc_278690626963_item	3640419	et	4	main
juulis	doc_278690626963_item	3640396	et	3	main
1994	doc_278690626963_item	3640394	et	2	main
arm	doc_278690626963_item	3640393	et	3	main
minu	doc_278690626963_item	3640392	et	3	main
juubelilaulupeo	doc_278690626963_item	3640384	et	4	main
lastekoorid	doc_278690626963_item	3640378	et	3	main
ka	doc_278690626963_item	3640376	et	3	main
alates	doc_278690626963_item	3640371	et	3	main
kadriorus	doc_278690626963_item	3640370	et	3	main
seda	doc_278690626963_item	3640362	et	3	main
üldlaulupidu	doc_278690626963_item	3640348	et	4	main
veel	doc_278690626963_item	3640343	et	4	main
oli	doc_278690626963_item	3640334	et	3	main
eestlaste	doc_278690626963_item	3640329	et	4	main
sellest	doc_278690626963_item	3640327	et	4	main
laulavad	doc_278690626963_item	3640326	et	4	main
kes	doc_278690626963_item	3640325	et	4	main
voldemar	doc_278690626963_item	3640319	et	4	main
tuli	doc_278690626963_item	3640314	et	4	main
mille	doc_278690626963_item	3640309	et	3	main
tartus	doc_278690626963_item	3640306	et	3	main
ka	doc_278690626963_item	3640288	et	3	main
koorilaulu	doc_278690626963_item	3640285	et	4	main
ja	doc_278690626963_item	3640280	et	3	main
on	doc_278690626962_item	3640001	et	4	main
illustreerida	doc_278690626962_item	3639997	et	3	main
faktidele	doc_278690626962_item	3639993	et	3	main
lugemistekstis	doc_278690626962_item	3639991	et	3	main
üldistav	doc_278690626962_item	3639987	et	4	main
ja	doc_278690626962_item	3639986	et	3	main
analüüsiv	doc_278690626962_item	3639985	et	4	main
arvan	doc_278690626963_item	3640423	et	3	main
ma	doc_278690626963_item	3640422	et	3	main
näiteks	doc_278690626963_item	3640416	et	4	main
erinevad	doc_278690626963_item	3640414	et	4	main
ka	doc_278690626963_item	3640412	et	3	main
elus	doc_278690626963_item	3640411	et	4	main
meie	doc_278690626963_item	3640387	et	4	main
sündis	doc_278690626963_item	3640386	et	3	main
kus	doc_278690626963_item	3640385	et	3	main
ja	doc_278690626963_item	3640379	et	3	main
lisandusid	doc_278690626963_item	3640374	et	4	main
pärast	doc_278690626963_item	3640361	et	4	main
tallinnasse	doc_278690626963_item	3640360	et	3	main
kuuendast	doc_278690626963_item	3640358	et	3	main
kandus	doc_278690626963_item	3640356	et	3	main
esimest	doc_278690626963_item	3640347	et	4	main
seitse	doc_278690626963_item	3640346	et	3	main
muusikaline	doc_278690626963_item	3640335	et	4	main
liikumise	doc_278690626963_item	3640331	et	4	main
toestus	doc_278690626963_item	3640313	et	4	main
ülemaaline	doc_278690626963_item	3640303	et	4	main
ka	doc_278690626963_item	3640292	et	3	main
asutamine	doc_278690626963_item	3640290	et	4	main
kaasnes	doc_278690626963_item	3640287	et	3	main
laulma	doc_278690626963_item	3640283	et	3	main
kirik	doc_278690626963_item	3640279	et	3	main
väljaspool	doc_278690626963_item	3640277	et	3	main
laulmine	doc_278690626963_item	3640274	et	4	main
vaimulike	doc_278690626963_item	3640272	et	3	main
osa	doc_278690626963_item	3640239	et	4	main
oluline	doc_278690626963_item	3640238	et	4	main
väga	doc_278690626963_item	3640237	et	3	main
on	doc_278690626963_item	3640236	et	4	main
see	doc_278690626963_item	3640235	et	3	main
test	doc_278690626963_item	3640191	et	3	main
oma	doc_740091150996_item	3640629	et	4	main
kinnitust	doc_740091150996_item	3640628	et	4	main
on	doc_740091150996_item	3640618	et	4	main
on	doc_740091150996_item	3640615	et	4	main
olen	doc_740091150996_item	3640602	et	3	main
mõtlen	doc_740091150996_item	3640600	et	3	main
järele	doc_740091150996_item	3640586	et	4	main
vajadus	doc_740091150996_item	3640581	et	3	main
teemal	doc_740091150996_item	3640573	et	3	main
diskussioonis	doc_740091150996_item	3640572	et	3	main
norm	doc_740091150996_item	3640571	et	3	main
on	doc_740091150996_item	3640570	et	4	main
poole	doc_740091150996_item	3640565	et	4	main
teisele	doc_740091150996_item	3640564	et	4	main
formuleerub	doc_740091150996_item	3640557	et	4	main
normideks	doc_740091150996_item	3640552	et	3	main
areneb	doc_740091150996_item	3640549	et	3	main
inimene	doc_740091150996_item	3640548	et	3	main
kontekstis	doc_740091150996_item	3640546	et	3	main
ja	doc_740091150996_item	3640544	et	3	main
ja	doc_740091150996_item	3640537	et	3	main
uus	doc_740091150996_item	3640525	et	3	main
siin	doc_740091150996_item	3640517	et	4	main
kehtestanud	doc_740091150996_item	3640510	et	4	main
milles	doc_740091150996_item	3640503	et	3	main
kogukondatesse	doc_740091150996_item	3640502	et	4	main
mind	doc_740091150996_item	3640496	et	4	main
liikmed	doc_740091150996_item	3640495	et	3	main
selle	doc_740091150996_item	3640494	et	4	main
komponentidele	doc_740091150996_item	3640488	et	3	main
mitmetele	doc_740091150996_item	3640486	et	4	main
alusbaasiks	doc_740091150996_item	3640485	et	4	main
ja	doc_740091150996_item	3640479	et	3	main
võttes	doc_740091150996_item	3640672	et	4	main
saa	doc_740091150996_item	3640635	et	4	main
normaalne	doc_740091150998_item	3641169	et	3	main
vastuvõetav	doc_740091150998_item	3641167	et	4	main
koos	doc_740091150998_item	3641151	et	4	main
see	doc_740091150998_item	3641133	et	3	main
350	doc_278690626962_item	3639979	et	2	main
300	doc_278690626962_item	3639978	et	2	main
mis	doc_278690626962_item	3639972	et	4	main
laulupidusid	doc_278690626963_item	3640417	et	4	main
isamaalaul	doc_278690626963_item	3640388	et	4	main
poistekoorid	doc_278690626963_item	3640380	et	3	main
osavõtjatena	doc_278690626963_item	3640375	et	3	main
eestis	doc_278690626963_item	3640373	et	3	main
1933	doc_278690626963_item	3640372	et	2	main
näiteks	doc_278690626963_item	3640369	et	4	main
üüritused	doc_278690626963_item	3640368	et	4	main
eestis	doc_278690626963_item	3640363	et	3	main
peost	doc_278690626963_item	3640359	et	4	main
saanud	doc_278690626963_item	3640354	et	4	main
alguse	doc_278690626963_item	3640353	et	3	main
tartust	doc_278690626963_item	3640352	et	3	main
venemaal	doc_278690626963_item	3640351	et	4	main
korraldati	doc_278690626963_item	3640350	et	3	main
eestlased	doc_278690626963_item	3640344	et	3	main
rahvapidude	doc_278690626963_item	3640341	et	4	main
aluse	doc_278690626963_item	3640339	et	4	main
kõrghetk	doc_278690626963_item	3640332	et	3	main
kujunes	doc_278690626963_item	3640328	et	3	main
peol	doc_278690626963_item	3640321	et	4	main
jannseniga	doc_278690626963_item	3640320	et	4	main
vanemuise	doc_278690626963_item	3640315	et	4	main
korraldamise	doc_278690626963_item	3640310	et	4	main
1869	doc_278690626963_item	3640307	et	2	main
toimus	doc_278690626963_item	3640305	et	3	main
esimene	doc_278690626963_item	3640302	et	3	main
silmaringi	doc_278690626963_item	3640301	et	4	main
laiendab	doc_278690626963_item	3640300	et	3	main
ja	doc_278690626963_item	3640299	et	3	main
inimest	doc_278690626963_item	3640298	et	3	main
arendab	doc_278690626963_item	3640297	et	3	main
oskused	doc_278690626963_item	3640296	et	3	main
need	doc_278690626963_item	3640295	et	3	main
puhkpilliorkestrite	doc_278690626963_item	3640289	et	3	main
levikuga	doc_278690626963_item	3640286	et	3	main
koorilaulu	doc_278690626963_item	3640284	et	4	main
levima	doc_278690626963_item	3640275	et	3	main
laulude	doc_278690626963_item	3640273	et	3	main
õigus	doc_278690626963_item	3640233	et	4	main
teise	doc_278690626963_item	3640189	et	4	main
keele	doc_278690626963_item	3640187	et	4	main
eesti	doc_278690626963_item	3640186	et	4	main
kultuuris	doc_278690626963_item	3640440	et	3	main
eesti	doc_278690626963_item	3640439	et	4	main
asi	doc_278690626963_item	3640438	et	4	main
tähtis	doc_278690626963_item	3640437	et	4	main
väga	doc_278690626963_item	3640436	et	3	main
on	doc_278690626963_item	3640435	et	4	main
see	doc_278690626963_item	3640434	et	3	main
laul	doc_278690626963_item	3640433	et	4	main
ja	doc_278690626963_item	3640432	et	3	main
laulda	doc_278690626963_item	3640431	et	4	main
armastavad	doc_278690626963_item	3640430	et	4	main
nad	doc_278690626963_item	3640429	et	3	main
sest	doc_278690626963_item	3640428	et	4	main
laulurahva	doc_278690626963_item	3640427	et	3	main
on	doc_278690626963_item	3640426	et	4	main
eestlased	doc_278690626963_item	3640425	et	3	main
puudub	doc_278690626963_item	3640421	et	3	main
laulupeod	doc_278690626963_item	3640415	et	4	main
tansud	doc_278690626963_item	3640408	et	4	main
ja	doc_278690626963_item	3640407	et	3	main
koorilaulud	doc_278690626963_item	3640406	et	3	main
erinevad	doc_278690626963_item	3640405	et	4	main
oli	doc_278690626963_item	3640404	et	3	main
seal	doc_278690626963_item	3640403	et	4	main
laulupeole	doc_278690626963_item	3640402	et	4	main
lauluväljakule	doc_278690626963_item	3640401	et	3	main
tallinna	doc_278690626963_item	3640400	et	4	main
lauljad	doc_278690626963_item	3640399	et	4	main
tuhanded	doc_278690626963_item	3640398	et	3	main
isamaa	doc_278690626963_item	3640390	et	4	main
mu	doc_278690626963_item	3640389	et	3	main
ka	doc_278690626963_item	3640381	et	3	main
naikoorid	doc_278690626963_item	3640377	et	4	main
erinevad	doc_278690626963_item	3640366	et	4	main
toimuma	doc_278690626963_item	3640365	et	3	main
hakkavad	doc_278690626963_item	3640364	et	4	main
alates	doc_278690626963_item	3640357	et	3	main
traditsioon	doc_278690626963_item	3640355	et	3	main
võitlesid	doc_278690626963_item	3640345	et	4	main
korraldamisele	doc_278690626963_item	3640342	et	4	main
see	doc_278690626963_item	3640333	et	3	main
inimesi	doc_278690626963_item	3640324	et	4	main
palju	doc_278690626963_item	3640323	et	4	main
osales	doc_278690626963_item	3640322	et	3	main
idee	doc_278690626963_item	3640311	et	4	main
laulupidu	doc_278690626963_item	3640304	et	4	main
saateks	doc_278690626963_item	3640294	et	3	main
ja	doc_278690626963_item	3640291	et	3	main
külakoolid	doc_278690626963_item	3640281	et	3	main
hakkas	doc_278690626963_item	3640270	et	3	main
sajandil	doc_278690626963_item	3640269	et	3	main
18	doc_278690626963_item	3640268	et	2	main
kirikus	doc_278690626963_item	3640267	et	3	main
laulmine	doc_278690626963_item	3640266	et	4	main
laulude	doc_278690626963_item	3640265	et	3	main
vaimulike	doc_278690626963_item	3640264	et	3	main
kaasnes	doc_278690626963_item	3640263	et	3	main
ristiusuga	doc_278690626963_item	3640262	et	3	main
tagasi	doc_278690626963_item	3640261	et	3	main
aastat	doc_278690626963_item	3640260	et	3	main
tuhat	doc_278690626963_item	3640259	et	4	main
kui	doc_278690626963_item	3640258	et	3	main
enam	doc_278690626963_item	3640257	et	4	main
kujunenud	doc_278690626963_item	3640256	et	4	main
see	doc_278690626963_item	3640255	et	3	main
kultuurile	doc_278690626963_item	3640254	et	3	main
läänemeresoome	doc_278690626963_item	3640253	et	3	main
esindab	doc_278690626963_item	3640252	et	3	main
laulutraditsiooni	doc_278690626963_item	3640251	et	4	main
vanemat	doc_278690626963_item	3640250	et	4	main
eesti	doc_278690626963_item	3640249	et	4	main
hauani	doc_278690626963_item	3640248	et	3	main
hällist	doc_278690626963_item	3640247	et	4	main
eestlast	doc_278690626963_item	3640246	et	4	main
laul	doc_278690626963_item	3640245	et	4	main
saatis	doc_278690626963_item	3640244	et	3	main
ajal	doc_278690626963_item	3640243	et	4	main
vanal	doc_278690626963_item	3640242	et	3	main
kultuuris	doc_278690626963_item	3640241	et	3	main
ka	doc_278690626963_item	3640276	et	3	main
aga	doc_278690626963_item	3640271	et	3	main
laulmine	doc_278690626963_item	3640234	et	4	main
nendel	doc_278690626963_item	3640231	et	4	main
juures	doc_740091150996_item	3640633	et	4	main
nii	doc_740091150996_item	3640626	et	3	main
end	doc_740091150996_item	3640623	et	4	main
traditsiooni	doc_740091150996_item	3640621	et	4	main
vaimse	doc_740091150996_item	3640620	et	3	main
oluline	doc_740091150996_item	3640619	et	4	main
ja	doc_740091150996_item	3640613	et	3	main
teadvustades	doc_740091150996_item	3640612	et	3	main
olemas	doc_740091150996_item	3640603	et	4	main
justkui	doc_740091150996_item	3640588	et	3	main
need	doc_740091150996_item	3640587	et	3	main
normist	doc_740091150996_item	3640574	et	4	main
mis	doc_740091150996_item	3640559	et	4	main
sotsialiseerumisprotsessi	doc_740091150996_item	3640555	et	4	main
kujunevad	doc_740091150996_item	3640551	et	4	main
need	doc_740091150996_item	3640550	et	3	main
õpitatavad	doc_740091150996_item	3640538	et	4	main
komponent	doc_740091150996_item	3640526	et	3	main
mõistetavasse	doc_740091150996_item	3640523	et	4	main
sotsialiseeruma	doc_740091150996_item	3640516	et	4	main
on	doc_740091150996_item	3640509	et	4	main
harjumuspäraselt	doc_740091150996_item	3640500	et	4	main
olles	doc_740091150996_item	3640499	et	3	main
aktsepteerivad	doc_740091150996_item	3640498	et	4	main
inimesena	doc_740091150996_item	3640497	et	3	main
alusel	doc_740091150996_item	3640490	et	4	main
aluseks	doc_740091150996_item	3640671	et	4	main
minapildi	doc_740091150996_item	3640669	et	4	main
inimene	doc_740091150996_item	3640664	et	3	main
hinnata	doc_740091150996_item	3640636	et	4	main
ja	doc_278690626963_item	3640230	et	3	main
laulurahva	doc_278690626963_item	3640229	et	3	main
eestlased	doc_278690626963_item	3640227	et	3	main
on	doc_278690626963_item	3640228	et	4	main
et	doc_278690626963_item	3640226	et	3	main
arvavad	doc_278690626963_item	3640225	et	4	main
inimesi	doc_278690626963_item	3640224	et	4	main
palju	doc_278690626963_item	3640223	et	4	main
näidetega	doc_278690626963_item	3640222	et	3	main
illustreerida	doc_278690626963_item	3640221	et	3	main
soovitatav	doc_278690626963_item	3640220	et	4	main
on	doc_278690626963_item	3640219	et	4	main
väiteid	doc_278690626963_item	3640218	et	4	main
faktidele	doc_278690626963_item	3640217	et	3	main
esitatud	doc_278690626963_item	3640216	et	4	main
lugemistekstis	doc_278690626963_item	3640215	et	3	main
ja	doc_278690626963_item	3640214	et	3	main
loengus	doc_278690626963_item	3640213	et	3	main
tuginema	doc_278690626963_item	3640212	et	3	main
üldistav	doc_278690626963_item	3640211	et	4	main
ja	doc_278690626963_item	3640210	et	3	main
analüüsiv	doc_278690626963_item	3640209	et	4	main
arutlev	doc_278690626963_item	3640208	et	4	main
olema	doc_278690626963_item	3640207	et	4	main
peab	doc_278690626963_item	3640206	et	4	main
essee	doc_278690626963_item	3640205	et	4	main
sõna	doc_278690626963_item	3640204	et	4	main
350	doc_278690626963_item	3640203	et	2	main
300	doc_278690626963_item	3640202	et	2	main
pikkus	doc_278690626963_item	3640201	et	4	main
essee	doc_278690626963_item	3640200	et	4	main
laulurahva	doc_278690626963_item	3640199	et	3	main
eestlastest	doc_278690626963_item	3640198	et	4	main
teeb	doc_278690626963_item	3640197	et	3	main
mis	doc_278690626963_item	3640196	et	4	main
teemal	doc_278690626963_item	3640195	et	3	main
essee	doc_278690626963_item	3640194	et	4	main
kirjutage	doc_278690626963_item	3640193	et	3	main
keele	doc_278690626963_item	3640190	et	4	main
kui	doc_278690626963_item	3640188	et	3	main
inimese	doc_740091150996_item	3640632	et	4	main
normaalsust	doc_740091150996_item	3640631	et	4	main
minapildile	doc_740091150996_item	3640630	et	3	main
samastades	doc_740091150996_item	3640625	et	3	main
inimesi	doc_740091150996_item	3640616	et	4	main
ennast	doc_740091150996_item	3640611	et	4	main
inimesest	doc_740091150996_item	3640607	et	3	main
vaimne	doc_740091150996_item	3640604	et	3	main
raamide	doc_740091150996_item	3640583	et	3	main
normaalsusest	doc_740091150996_item	3640576	et	4	main
ja	doc_740091150996_item	3640575	et	3	main
normaalsust	doc_740091150996_item	3640566	et	4	main
või	doc_740091150996_item	3640563	et	4	main
ühele	doc_740091150996_item	3640562	et	3	main
kas	doc_740091150996_item	3640561	et	3	main
jääb	doc_740091150996_item	3640560	et	3	main
normid	doc_740091150996_item	3640540	et	4	main
sotsiaalsed	doc_740091150996_item	3640539	et	3	main
ei	doc_740091150996_item	3640634	et	4	main
kuulub	doc_740091150996_item	3640684	et	3	main
ta	doc_740091150996_item	3640683	et	4	main
millesse	doc_740091150996_item	3640682	et	3	main
rühmast	doc_740091150996_item	3640681	et	4	main
tagasi	doc_740091150996_item	3640680	et	3	main
peegeldab	doc_740091150996_item	3640679	et	3	main
see	doc_740091150996_item	3640678	et	3	main
teistega	doc_740091150996_item	3640624	et	4	main
kellele	doc_740091150996_item	3640617	et	4	main
areneb	doc_740091150996_item	3640610	et	3	main
kujuneb	doc_740091150996_item	3640608	et	3	main
külg	doc_740091150996_item	3640606	et	3	main
emotsionaalne	doc_740091150996_item	3640605	et	3	main
traditsioonilisusel	doc_740091150996_item	3640597	et	4	main
ja	doc_740091150996_item	3640598	et	3	main
määral	doc_740091150996_item	3640596	et	3	main
suuremal	doc_740091150996_item	3640595	et	4	main
sõltub	doc_740091150996_item	3640594	et	3	main
tasakaal	doc_740091150996_item	3640593	et	3	main
vaimne	doc_740091150996_item	3640592	et	3	main
kindluse	doc_740091150996_item	3640591	et	4	main
eksistentsi	doc_740091150996_item	3640590	et	4	main
tagaksid	doc_740091150996_item	3640589	et	4	main
reeglite	doc_740091150996_item	3640585	et	3	main
see	doc_740091150996_item	3640569	et	3	main
kujunetakse	doc_740091150996_item	3640568	et	3	main
või	doc_740091150996_item	3640553	et	4	main
milles	doc_740091150996_item	3640547	et	3	main
vastavas	doc_740091150996_item	3640545	et	4	main
teatud	doc_740091150996_item	3640542	et	4	main
kujunevad	doc_740091150996_item	3640541	et	4	main
maailmaga	doc_740091150996_item	3640535	et	3	main
kommunikeerub	doc_740091150996_item	3640534	et	4	main
puutub	doc_740091150996_item	3640532	et	3	main
mil	doc_740091150996_item	3640530	et	4	main
visuaalselt	doc_740091150996_item	3640522	et	4	main
kergemalt	doc_740091150996_item	3640521	et	4	main
inimene	doc_740091150996_item	3640515	et	3	main
peab	doc_740091150996_item	3640514	et	4	main
reeglid	doc_740091150996_item	3640513	et	3	main
kujundanud	doc_740091150996_item	3640512	et	4	main
sõpruskonnad	doc_740091150996_item	3640508	et	4	main
grupid	doc_740091150996_item	3640507	et	3	main
kultuurilised	doc_740091150996_item	3640506	et	4	main
etnilised	doc_740091150996_item	3640505	et	3	main
erinevad	doc_740091150996_item	3640504	et	4	main
mille	doc_740091150996_item	3640489	et	3	main
erinevatele	doc_740091150996_item	3640487	et	4	main
normaalseks	doc_740091150996_item	3640482	et	4	main
tunnistada	doc_740091150996_item	3640480	et	3	main
tunnetada	doc_740091150996_item	3640478	et	3	main
selleks	doc_740091150996_item	3640476	et	4	main
ise	doc_740091150996_item	3640667	et	4	main
iga	doc_740091150996_item	3640663	et	4	main
mitmetähenduslikkusele	doc_740091150996_item	3640662	et	4	main
ja	doc_740091150996_item	3640661	et	3	main
normidele	doc_740091150996_item	3640660	et	3	main
erinevate	doc_740091150996_item	3640659	et	4	main
tänu	doc_740091150996_item	3640658	et	4	main
võimalik	doc_740091150996_item	3640657	et	3	main
areng	doc_740091150996_item	3640656	et	3	main
on	doc_740091150996_item	3640655	et	4	main
maailmas	doc_740091150996_item	3640654	et	3	main
mitmekeelses	doc_740091150996_item	3640653	et	3	main
ja	doc_740091150996_item	3640652	et	3	main
multikultuurilises	doc_740091150996_item	3640651	et	4	main
tänapäeva	doc_740091150996_item	3640650	et	4	main
inimesest	doc_740091150996_item	3640649	et	3	main
pool	doc_740091150996_item	3640648	et	4	main
sotsiaalne	doc_740091150996_item	3640647	et	3	main
ja	doc_740091150996_item	3640646	et	3	main
vaimne	doc_740091150996_item	3640645	et	3	main
füüsiline	doc_740091150996_item	3640644	et	3	main
kuuluvad	doc_740091150996_item	3640643	et	4	main
aegruumis	doc_740091150996_item	3640543	et	3	main
iseõpitud	doc_740091150996_item	3640536	et	4	main
kokku	doc_740091150996_item	3640533	et	3	main
kõige	doc_740091150996_item	3640520	et	4	main
füüsilisele	doc_740091150996_item	3640519	et	3	main
lisandub	doc_740091150996_item	3640518	et	3	main
või	doc_740091150996_item	3640511	et	4	main
on	doc_740091150996_item	3640484	et	4	main
see	doc_740091150996_item	3640483	et	3	main
inimeseks	doc_740091150996_item	3640676	et	3	main
endast	doc_740091150996_item	3640666	et	4	main
loob	doc_740091150996_item	3640665	et	3	main
mis	doc_740091150998_item	3641171	et	4	main
tema	doc_740091150998_item	3641164	et	4	main
mis	doc_740091150998_item	3641163	et	4	main
kõigi	doc_740091150998_item	3641152	et	4	main
inimene	doc_740091150998_item	3641150	et	3	main
siis	doc_740091150998_item	3641145	et	3	main
räägitud	doc_740091150998_item	3641135	et	4	main
palju	doc_740091150998_item	3641134	et	4	main
normaalsus	doc_740091150998_item	3641131	et	4	main
on	doc_740091150998_item	3641130	et	4	main
võib-olla	doc_740091150998_item	3641129	et	3	main
tuli	doc_740091150998_item	3641128	et	4	main
ja	doc_740091150998_item	3641127	et	3	main
inimesi	doc_740091150998_item	3641093	et	4	main
kastisüsteemi	doc_740091150998_item	3641091	et	4	main
sõnadekombinatsiooni	doc_740091150998_item	3641080	et	4	main
pigem	doc_740091150998_item	3641077	et	3	main
noridel	doc_740091150998_item	3641071	et	4	main
tänaval	doc_740091150998_item	3641064	et	4	main
jääma	doc_740091150998_item	3641054	et	4	main
inimestele	doc_740091150998_item	3641052	et	3	main
on	doc_740091150998_item	3641038	et	4	main
kus	doc_740091150998_item	3641037	et	3	main
tea	doc_740091150998_item	3641036	et	4	main
ei	doc_740091150998_item	3641035	et	4	main
tegelikult	doc_740091150998_item	3641034	et	4	main
keegi	doc_740091150998_item	3641033	et	4	main
ning	doc_740091150998_item	3641032	et	3	main
maja	doc_740091150998_item	3641031	et	4	main
suur	doc_740091150998_item	3641030	et	3	main
on	doc_740091150998_item	3641029	et	4	main
tal	doc_740091150998_item	3641028	et	3	main
autosid	doc_740091150998_item	3641027	et	3	main
uusi	doc_740091150998_item	3641026	et	3	main
koguaeg	doc_740091150998_item	3641025	et	3	main
on	doc_740091150998_item	3641018	et	4	main
kahtlusi	doc_740091150998_item	3641014	et	4	main
teatud	doc_740091150998_item	3641013	et	4	main
narkojoobes	doc_740091150998_item	3641009	et	3	main
normaalseks	doc_740091150998_item	3641004	et	4	main
identiteedi	doc_740091150998_item	3640996	et	4	main
tunded	doc_740091150998_item	3640994	et	3	main
omaenda	doc_740091150998_item	3640992	et	3	main
kaotaks	doc_740091150998_item	3640990	et	4	main
viimane	doc_740091150998_item	3640973	et	3	main
inimest	doc_740091150998_item	3640969	et	3	main
on	doc_740091150998_item	3640958	et	4	main
sellistel	doc_740091150998_item	3640956	et	4	main
inimesehakatis	doc_740091150996_item	3640531	et	3	main
hetkest	doc_740091150996_item	3640529	et	4	main
algab	doc_740091150996_item	3640528	et	3	main
sotsialiseerumine	doc_740091150996_item	3640527	et	4	main
vormi	doc_740091150996_item	3640524	et	4	main
kuuluv	doc_740091150996_item	3640501	et	4	main
teised	doc_740091150996_item	3640493	et	4	main
ja	doc_740091150996_item	3640492	et	3	main
ühiskond	doc_740091150996_item	3640491	et	3	main
end	doc_740091150996_item	3640481	et	4	main
et	doc_740091150996_item	3640477	et	3	main
rahulolu	doc_740091150996_item	3640475	et	4	main
ja	doc_740091150996_item	3640474	et	3	main
kindlustunde	doc_740091150996_item	3640473	et	4	main
annab	doc_740091150996_item	3640472	et	3	main
normaalsus	doc_740091150996_item	3640471	et	4	main
visuaalne	doc_740091150996_item	3640470	et	3	main
normaalne	doc_740091150996_item	3640469	et	3	main
olla	doc_740091150996_item	3640468	et	3	main
et	doc_740091150996_item	3640467	et	3	main
piisab	doc_740091150996_item	3640466	et	3	main
sellest	doc_740091150996_item	3640465	et	4	main
kas	doc_740091150996_item	3640464	et	3	main
suu	doc_740091150996_item	3640463	et	4	main
nina	doc_740091150996_item	3640462	et	4	main
kõrva	doc_740091150996_item	3640461	et	4	main
kaks	doc_740091150996_item	3640460	et	3	main
silma	doc_740091150996_item	3640459	et	4	main
kaks	doc_740091150996_item	3640458	et	3	main
jalga	doc_740091150996_item	3640457	et	4	main
kaks	doc_740091150996_item	3640456	et	3	main
kätt	doc_740091150996_item	3640455	et	3	main
kaks	doc_740091150996_item	3640454	et	3	main
on	doc_740091150996_item	3640453	et	4	main
mul	doc_740091150996_item	3640452	et	3	main
eesnimi	doc_740091150996_item	3640451	et	3	main
on	doc_740091150996_item	3640450	et	4	main
nimi	doc_740091150996_item	3640449	et	3	main
minu	doc_740091150996_item	3640448	et	3	main
inimene	doc_740091150996_item	3640446	et	3	main
tere	doc_740091150996_item	3640447	et	3	main
normaalne	doc_740091150996_item	3640445	et	3	main
tuttavaks	doc_740091150996_item	3640444	et	4	main
saage	doc_740091150996_item	3640443	et	4	main
essee	doc_740091150996_item	3640442	et	4	main
sest	doc_740091150996_item	3640677	et	4	main
normaalseks	doc_740091150996_item	3640675	et	4	main
end	doc_740091150996_item	3640674	et	4	main
identifitseerib	doc_740091150996_item	3640673	et	3	main
mida	doc_740091150996_item	3640670	et	4	main
oma	doc_740091150996_item	3640668	et	4	main
kuhu	doc_740091150996_item	3640642	et	3	main
tahkudena	doc_740091150996_item	3640641	et	3	main
erinevate	doc_740091150996_item	3640640	et	4	main
tunnetada	doc_740091150996_item	3640639	et	3	main
saab	doc_740091150996_item	3640638	et	3	main
seda	doc_740091150996_item	3640637	et	3	main
vooruste	doc_740091150998_item	3641154	et	3	main
lihtsalt	doc_740091150998_item	3641149	et	4	main
seisukohti	doc_740091150998_item	3641144	et	4	main
toodud	doc_740091150998_item	3641143	et	4	main
psühholoogias	doc_740091150998_item	3641142	et	3	main
kliinilises	doc_740091150998_item	3641141	et	3	main
järgida	doc_740091150998_item	3641140	et	3	main
mitte	doc_740091150998_item	3641139	et	3	main
kui	doc_740091150998_item	3641138	et	3	main
mass	doc_740091150998_item	3641137	et	3	main
vesi	doc_740091150998_item	3641126	et	4	main
õhk	doc_740091150998_item	3641125	et	3	main
kastidesse	doc_740091150998_item	3641095	et	3	main
väheke	doc_740091150998_item	3641086	et	3	main
muuseas	doc_740091150998_item	3641083	et	3	main
pidada	doc_740091150998_item	3641081	et	4	main
inimene	doc_740091150998_item	3641076	et	3	main
vahel	doc_740091150998_item	3641070	et	4	main
jõud	doc_740091150998_item	3641063	et	4	main
edasieksisteerimise	doc_740091150998_item	3641062	et	4	main
peab	doc_740091150998_item	3641053	et	4	main
ja	doc_740091150998_item	3641049	et	3	main
ei	doc_740091150998_item	3641047	et	4	main
paratamatud	doc_740091150998_item	3641044	et	3	main
töökoht	doc_740091150998_item	3641040	et	3	main
ta	doc_740091150998_item	3641022	et	4	main
palju	doc_740091150998_item	3641020	et	4	main
kui	doc_740091150998_item	3641016	et	3	main
isikuid	doc_740091150998_item	3641010	et	4	main
juuatäis	doc_740091150998_item	3641007	et	4	main
kaklevaid	doc_740091150998_item	3641006	et	4	main
peeta	doc_740091150998_item	3641001	et	4	main
eesti	doc_740091150998_item	3640998	et	4	main
mõtted	doc_740091150998_item	3640993	et	3	main
inimene	doc_740091150998_item	3640991	et	3	main
siis	doc_740091150998_item	3640989	et	3	main
sellises	doc_740091150998_item	3640975	et	4	main
hakata	doc_740091150998_item	3640971	et	4	main
muuta	doc_740091150998_item	3640968	et	4	main
kas	doc_740091150998_item	3640966	et	3	main
kas	doc_740091150998_item	3640963	et	3	main
kuidas	doc_740091150998_item	3640961	et	3	main
mõista	doc_740091150998_item	3640946	et	4	main
normaalsuse	doc_740091150998_item	3640939	et	4	main
asjadele	doc_740091150998_item	3640933	et	3	main
tihtipeale	doc_740091150998_item	3640903	et	3	main
perekond	doc_740091150998_item	3640899	et	3	main
tore	doc_740091150998_item	3640898	et	3	main
ning	doc_740091150998_item	3640897	et	3	main
töökoht	doc_740091150998_item	3640896	et	3	main
tasuv	doc_740091150998_item	3640895	et	4	main
oluliselt	doc_740091150998_item	3640871	et	4	main
aastaste	doc_740091150998_item	3640868	et	4	main
kuuekümne	doc_740091150998_item	3640867	et	4	main
vastuvõetav	doc_740091150998_item	3641175	et	4	main
on	doc_740091150998_item	3641174	et	4	main
normaalne	doc_740091150998_item	3641173	et	3	main
on	doc_740091150998_item	3641172	et	4	main
ja	doc_740091150998_item	3641170	et	3	main
endast	doc_740091150998_item	3641162	et	4	main
temast	doc_740091150998_item	3641161	et	3	main
lähtub	doc_740091150998_item	3641160	et	3	main
oma	doc_740091150998_item	3641153	et	4	main
hall	doc_740091150998_item	3641136	et	4	main
justnimelt	doc_740091150998_item	3641132	et	3	main
on	doc_740091150998_item	3641124	et	4	main
seda	doc_740091150998_item	3641123	et	3	main
kui	doc_740091150998_item	3641122	et	3	main
loomulik	doc_740091150998_item	3641121	et	3	main
niivõrd	doc_740091150998_item	3641120	et	3	main
normaalsus	doc_740091150998_item	3641119	et	4	main
on	doc_740091150998_item	3641118	et	4	main
seega	doc_740091150998_item	3641117	et	4	main
sõnakõlksud	doc_740091150998_item	3641116	et	3	main
lihtsalt	doc_740091150998_item	3641115	et	4	main
tänapäeval	doc_740091150998_item	3641114	et	3	main
on	doc_740091150998_item	3641113	et	4	main
ning	doc_740091150998_item	3641111	et	3	main
normaalne	doc_740091150998_item	3641110	et	3	main
oluliseks	doc_740091150998_item	3641109	et	4	main
nii	doc_740091150998_item	3641108	et	3	main
normaalsus	doc_740091150998_item	3641112	et	4	main
peeta	doc_740091150998_item	3641107	et	4	main
ei	doc_740091150998_item	3641106	et	4	main
seda	doc_740091150998_item	3641105	et	3	main
nii	doc_740091150998_item	3641104	et	3	main
seda	doc_740091150998_item	3641103	et	3	main
käsitle	doc_740091150998_item	3641102	et	4	main
ei	doc_740091150998_item	3641101	et	4	main
ise	doc_740091150998_item	3641100	et	4	main
inimesed	doc_740091150998_item	3641099	et	3	main
on	doc_740091150998_item	3641168	et	4	main
on	doc_740091150998_item	3641166	et	4	main
jaoks	doc_740091150998_item	3641165	et	4	main
normaalsus	doc_740091150998_item	3641159	et	4	main
inimese	doc_740091150998_item	3641158	et	4	main
normaalse	doc_740091150998_item	3641157	et	3	main
vigadega	doc_740091150998_item	3641156	et	3	main
ning	doc_740091150998_item	3641155	et	3	main
on	doc_740091150998_item	3641148	et	4	main
inimene	doc_740091150998_item	3641147	et	3	main
normaalne	doc_740091150998_item	3641146	et	3	main
ja	doc_740091150998_item	3641097	et	3	main
meil	doc_740091150998_item	3641088	et	4	main
tögavaks	doc_740091150998_item	3641087	et	4	main
ja	doc_740091150998_item	3641085	et	3	main
nii	doc_740091150998_item	3641082	et	3	main
mittenormaalsed	doc_740091150998_item	3641098	et	3	main
kus	doc_740091150998_item	3641092	et	3	main
ole	doc_740091150998_item	3641090	et	4	main
ei	doc_740091150998_item	3641089	et	4	main
õelduks	doc_740091150998_item	3641084	et	4	main
taolist	doc_740091150998_item	3641079	et	3	main
võibki	doc_740091150998_item	3641078	et	3	main
normaalne	doc_740091150998_item	3641075	et	3	main
võivad	doc_740091150998_item	3641067	et	4	main
tööl	doc_740091150998_item	3641066	et	3	main
sest	doc_740091150998_item	3641059	et	4	main
pingeseisund	doc_740091150998_item	3641058	et	3	main
teatav	doc_740091150998_item	3641057	et	4	main
ning	doc_740091150998_item	3641056	et	3	main
põnevus	doc_740091150998_item	3641055	et	4	main
vajagi	doc_740091150998_item	3641051	et	4	main
pole	doc_740091150998_item	3641050	et	3	main
saa	doc_740091150998_item	3641048	et	4	main
neid	doc_740091150998_item	3641045	et	4	main
arvamused	doc_740091150998_item	3641042	et	3	main
taolised	doc_740091150998_item	3641041	et	3	main
endale	doc_740091150998_item	3641024	et	4	main
soetab	doc_740091150998_item	3641023	et	3	main
kellegil	doc_740091150998_item	3641017	et	4	main
tänavatel	doc_740091150998_item	3641005	et	4	main
ei	doc_740091150998_item	3641000	et	4	main
normaalsuse	doc_740091150998_item	3640983	et	4	main
oma	doc_740091150998_item	3640982	et	4	main
strateegiline	doc_740091150998_item	3640978	et	4	main
paratamatuses	doc_740091150998_item	3640976	et	3	main
või	doc_740091150998_item	3640970	et	4	main
sellega	doc_740091150998_item	3640965	et	3	main
mitu	doc_740091150998_item	3640959	et	4	main
puhkudel	doc_740091150998_item	3640957	et	3	main
tunne	doc_740091150998_item	3640952	et	4	main
mõtle	doc_740091150998_item	3640950	et	4	main
kõrgharidus	doc_740091150998_item	3640894	et	3	main
arvamus	doc_740091150998_item	3640869	et	3	main
suhteline	doc_740091150998_item	3640852	et	4	main
selline	doc_740091150998_item	3640849	et	4	main
normaalsus	doc_740091150998_item	3640847	et	4	main
räägitakse	doc_740091150998_item	3640846	et	3	main
isegi	doc_740091150998_item	3640845	et	4	main
võib-olla	doc_740091150998_item	3640844	et	3	main
juhtuda	doc_740091150998_item	3640840	et	3	main
ei	doc_740091150998_item	3640830	et	4	main
hukka	doc_740091150998_item	3640829	et	4	main
ühiskond	doc_740091150998_item	3640821	et	3	main
tänapäeva	doc_740091150998_item	3640820	et	4	main
antus	doc_740091150998_item	3640811	et	4	main
korda	doc_740091150998_item	3640806	et	4	main
oma	doc_740091150998_item	3640790	et	4	main
kultuuris	doc_740091150998_item	3640785	et	3	main
normaalsed	doc_740091150998_item	3641096	et	3	main
lahterdatakse	doc_740091150998_item	3641094	et	3	main
on	doc_740091150998_item	3641074	et	4	main
no	doc_740091150998_item	3641073	et	3	main
öelda	doc_740091150998_item	3641072	et	4	main
koolis	doc_740091150998_item	3641065	et	4	main
on	doc_740091150998_item	3641061	et	4	main
need	doc_740091150998_item	3641060	et	3	main
muuta	doc_740091150998_item	3641046	et	4	main
on	doc_740091150998_item	3641043	et	4	main
ta	doc_740091150998_item	3641039	et	4	main
ülemäära	doc_740091150998_item	3641019	et	3	main
see	doc_740091150998_item	3641015	et	3	main
tekitab	doc_740091150998_item	3641012	et	3	main
samuti	doc_740091150998_item	3641011	et	3	main
rääkides	doc_740091150998_item	3640997	et	4	main
ning	doc_740091150998_item	3640995	et	3	main
vale	doc_740091150998_item	3640987	et	4	main
siinkohal	doc_740091150998_item	3640986	et	3	main
tundub	doc_740091150998_item	3640985	et	3	main
järgi	doc_740091150998_item	3640984	et	4	main
ning	doc_740091150998_item	3640979	et	3	main
ikka	doc_740091150998_item	3641069	et	4	main
inimesed	doc_740091150998_item	3641068	et	3	main
raha	doc_740091150998_item	3641021	et	4	main
või	doc_740091150998_item	3641008	et	4	main
kindlasti	doc_740091150998_item	3641003	et	3	main
kohe	doc_740091150998_item	3641002	et	4	main
ühiskonnast	doc_740091150998_item	3640999	et	4	main
sest	doc_740091150998_item	3640988	et	4	main
muutumine	doc_740091150998_item	3640981	et	4	main
inimese	doc_740091150998_item	3640980	et	4	main
liiga	doc_740091150998_item	3640977	et	4	main
tundub	doc_740091150998_item	3640974	et	3	main
püüda	doc_740091150998_item	3640967	et	3	main
leppida	doc_740091150998_item	3640964	et	3	main
käituda	doc_740091150998_item	3640962	et	3	main
võimalust	doc_740091150998_item	3640960	et	3	main
samamoodi	doc_740091150998_item	3640953	et	3	main
kedagi	doc_740091150998_item	3640944	et	4	main
sa	doc_740091150998_item	3640943	et	3	main
ei	doc_740091150998_item	3640942	et	4	main
on	doc_740091150998_item	3640937	et	4	main
see	doc_740091150998_item	3640936	et	3	main
vanemad	doc_740091150998_item	3640935	et	4	main
vastuvõtvamad	doc_740091150998_item	3640931	et	4	main
paindlikud	doc_740091150998_item	3640929	et	3	main
plaanid	doc_740091150998_item	3640905	et	4	main
on	doc_740091150998_item	3640902	et	4	main
noortel	doc_740091150998_item	3640901	et	3	main
siis	doc_740091150998_item	3640900	et	3	main
sündinud	doc_740091150998_item	3640863	et	4	main
eriajastutel	doc_740091150998_item	3640862	et	3	main
olla	doc_740091150998_item	3640861	et	3	main
osaliselt	doc_740091150998_item	3640855	et	4	main
on	doc_740091150998_item	3640854	et	4	main
on	doc_740091150998_item	3640850	et	4	main
et	doc_740091150998_item	3640841	et	3	main
vähemalt	doc_740091150998_item	3640836	et	4	main
erinev	doc_740091150998_item	3640835	et	4	main
tundub	doc_740091150998_item	3640834	et	3	main
kohe	doc_740091150998_item	3640828	et	4	main
inimest	doc_740091150998_item	3640827	et	3	main
et	doc_740091150998_item	3640826	et	3	main
tulnud	doc_740091150998_item	3640814	et	4	main
olles	doc_740091150998_item	3640813	et	3	main
kultuuris	doc_740091150998_item	3640812	et	3	main
ei	doc_740091150998_item	3640802	et	4	main
pesta	doc_740091150998_item	3640803	et	4	main
nõeltega	doc_740091150998_item	3640793	et	3	main
ihu	doc_740091150998_item	3640791	et	4	main
elad	doc_740091150998_item	3640783	et	3	main
sa	doc_740091150998_item	3640782	et	3	main
see	doc_740091150998_item	3640779	et	3	main
käituda	doc_740091150998_item	3640773	et	3	main
normaalsus	doc_740091150998_item	3640767	et	4	main
tuli	doc_740091150998_item	3640763	et	4	main
tegelikult	doc_740091150998_item	3640756	et	4	main
mis	doc_740091150998_item	3640754	et	4	main
kultuurinormidele	doc_740091150998_item	3640752	et	3	main
antud	doc_740091150998_item	3640751	et	4	main
selgelt	doc_740091150998_item	3640746	et	4	main
suudab	doc_740091150998_item	3640745	et	3	main
inimene	doc_740091150998_item	3640744	et	3	main
kui	doc_740091150998_item	3640743	et	3	main
see	doc_740091150998_item	3640742	et	3	main
on	doc_740091150998_item	3640741	et	4	main
vältima	doc_740091150998_item	3640972	et	3	main
sina	doc_740091150998_item	3640955	et	4	main
kui	doc_740091150998_item	3640954	et	3	main
hukka	doc_740091150998_item	3640945	et	4	main
nende	doc_740091150998_item	3640938	et	4	main
uutele	doc_740091150998_item	3640932	et	3	main
väga	doc_740091150998_item	3640928	et	3	main
noored	doc_740091150998_item	3640927	et	3	main
on	doc_740091150998_item	3640926	et	4	main
asjades	doc_740091150998_item	3640925	et	3	main
sellistes	doc_740091150998_item	3640924	et	4	main
inimesed	doc_740091150998_item	3640923	et	3	main
pärit	doc_740091150998_item	3640922	et	3	main
kultuurist	doc_740091150998_item	3640921	et	3	main
teistsugusest	doc_740091150998_item	3640920	et	3	main
pakkuda	doc_740091150998_item	3640919	et	3	main
neile	doc_740091150998_item	3640918	et	4	main
võivad	doc_740091150998_item	3640917	et	4	main
mida	doc_740091150998_item	3640916	et	4	main
tunda	doc_740091150998_item	3640915	et	3	main
ning	doc_740091150998_item	3640914	et	3	main
eripaikasid	doc_740091150998_item	3640913	et	3	main
maailma	doc_740091150998_item	3640912	et	4	main
avastada	doc_740091150998_item	3640911	et	3	main
rännata	doc_740091150998_item	3640910	et	4	main
tahab	doc_740091150998_item	3640909	et	3	main
noori	doc_740091150998_item	3640908	et	3	main
enam	doc_740091150998_item	3640907	et	4	main
ega	doc_740091150998_item	3640951	et	3	main
ei	doc_740091150998_item	3640949	et	4	main
ta	doc_740091150998_item	3640948	et	4	main
kui	doc_740091150998_item	3640947	et	3	main
loomulikult	doc_740091150998_item	3640941	et	4	main
piir	doc_740091150998_item	3640940	et	3	main
kui	doc_740091150998_item	3640934	et	3	main
ning	doc_740091150998_item	3640930	et	3	main
üha	doc_740091150998_item	3640906	et	3	main
teistsugused	doc_740091150998_item	3640904	et	3	main
viiekümne	doc_740091150998_item	3640866	et	4	main
praegu	doc_740091150998_item	3640865	et	3	main
inimestel	doc_740091150998_item	3640864	et	3	main
vaieldav	doc_740091150998_item	3640856	et	4	main
see	doc_740091150998_item	3640853	et	3	main
tegelikult	doc_740091150998_item	3640851	et	4	main
kui	doc_740091150998_item	3640848	et	3	main
vaadatakse	doc_740091150998_item	3640842	et	3	main
mõisteta	doc_740091150998_item	3640831	et	4	main
on	doc_740091150998_item	3640822	et	4	main
kirjeldatud	doc_740091150998_item	3640819	et	4	main
eelpool	doc_740091150998_item	3640818	et	4	main
nagu	doc_740091150998_item	3640817	et	3	main
samamoodi	doc_740091150998_item	3640816	et	3	main
teistsugusest	doc_740091150998_item	3640815	et	3	main
normaalne	doc_740091150998_item	3640809	et	3	main
on	doc_740091150998_item	3640808	et	4	main
päevas	doc_740091150998_item	3640807	et	3	main
just	doc_740091150998_item	3640804	et	3	main
käsi	doc_740091150998_item	3640801	et	4	main
ning	doc_740091150998_item	3640800	et	3	main
kanta	doc_740091150998_item	3640799	et	3	main
ei	doc_740091150998_item	3640798	et	4	main
riideid	doc_740091150998_item	3640797	et	3	main
auke	doc_740091150998_item	3640796	et	4	main
sinna	doc_740091150998_item	3640795	et	3	main
erinevate	doc_740091150998_item	3640792	et	4	main
läbistavad	doc_740091150998_item	3640789	et	4	main
vastavalt	doc_740091150998_item	3640774	et	4	main
kui	doc_740091150998_item	3640770	et	3	main
sissejuhatuses	doc_740091150998_item	3640762	et	4	main
inimene	doc_740091150998_item	3640761	et	3	main
normaalne	doc_740091150998_item	3640760	et	3	main
on	doc_740091150998_item	3640759	et	4	main
kes	doc_740091150998_item	3640758	et	4	main
mõelda	doc_740091150998_item	3640747	et	4	main
ikka	doc_740091150998_item	3640738	et	4	main
raha	doc_740091150998_item	3640727	et	4	main
palju	doc_740091150998_item	3640714	et	4	main
kokku	doc_740091150998_item	3640713	et	3	main
palju	doc_740091150998_item	3640703	et	4	main
ning	doc_740091150998_item	3640702	et	3	main
koer	doc_740091150998_item	3640701	et	3	main
tuttavaks	doc_740091150998_item	3640688	et	4	main
ei	doc_740091151000_item	3641869	et	4	main
virtuaalsed	doc_740091151000_item	3641858	et	3	main
mõtekam	doc_740091151000_item	3641851	et	4	main
jõudmisel	doc_740091151000_item	3641832	et	4	main
parim	doc_740091151000_item	3641829	et	4	main
kahekümne	doc_740091150998_item	3640872	et	4	main
erineb	doc_740091150998_item	3640870	et	3	main
võivad	doc_740091150998_item	3640860	et	4	main
sellest	doc_740091150998_item	3640859	et	4	main
eriarvamused	doc_740091150998_item	3640858	et	3	main
omadus	doc_740091150998_item	3640857	et	4	main
järgi	doc_740091150998_item	3640843	et	4	main
võib	doc_740091150998_item	3640839	et	3	main
riietumise	doc_740091150998_item	3640837	et	4	main
ta	doc_740091150998_item	3640833	et	4	main
kui	doc_740091150998_item	3640832	et	3	main
arenenud	doc_740091150998_item	3640825	et	4	main
edasi	doc_740091150998_item	3640824	et	3	main
niipalju	doc_740091150998_item	3640823	et	3	main
kolm	doc_740091150998_item	3640805	et	3	main
kõik	doc_740091150998_item	3640788	et	4	main
näiteks	doc_740091150998_item	3640787	et	4	main
kus	doc_740091150998_item	3640786	et	3	main
inimene	doc_740091150998_item	3640771	et	3	main
on	doc_740091150998_item	3640768	et	4	main
et	doc_740091150998_item	3640766	et	3	main
väide	doc_740091150998_item	3640765	et	4	main
on	doc_740091150998_item	3640755	et	4	main
kuid	doc_740091150998_item	3640753	et	4	main
endale	doc_740091150998_item	3640730	et	4	main
soetada	doc_740091150998_item	3640729	et	3	main
et	doc_740091150998_item	3640728	et	3	main
kinnisvara	doc_740091150998_item	3640715	et	4	main
vara	doc_740091150998_item	3640705	et	4	main
materiaalset	doc_740091150998_item	3640704	et	3	main
pere	doc_740091150998_item	3640699	et	4	main
essee	doc_740091150998_item	3640686	et	4	main
kohapealt	doc_740091150998_item	3640838	et	3	main
käituda	doc_740091150998_item	3640810	et	3	main
teevad	doc_740091150998_item	3640794	et	3	main
ühes	doc_740091150998_item	3640784	et	4	main
loomulik	doc_740091150998_item	3640781	et	3	main
täiesti	doc_740091150998_item	3640780	et	3	main
on	doc_740091150998_item	3640778	et	4	main
tegelikult	doc_740091150998_item	3640777	et	4	main
suudab	doc_740091150998_item	3640772	et	3	main
poolt	doc_740091150998_item	3640712	et	4	main
inimeste	doc_740091150998_item	3640711	et	3	main
osteti	doc_740091150998_item	3640710	et	3	main
tagasi	doc_740091150998_item	3640709	et	3	main
aastat	doc_740091150998_item	3640708	et	3	main
kakskümmend	doc_740091150998_item	3640707	et	4	main
normaalseks	doc_740091150998_item	3640693	et	4	main
peetakse	doc_740091150998_item	3640692	et	3	main
tihtipeale	doc_740091150998_item	3640691	et	3	main
inimene	doc_740091150998_item	3640690	et	3	main
normaalne	doc_740091150998_item	3640689	et	3	main
kellel	doc_740091150998_item	3640892	et	4	main
inimesteks	doc_740091150998_item	3640891	et	3	main
töökateks	doc_740091150998_item	3640890	et	4	main
tublideks	doc_740091150998_item	3640889	et	3	main
sirguksid	doc_740091150998_item	3640888	et	4	main
võsukesed	doc_740091150998_item	3640887	et	4	main
et	doc_740091150998_item	3640886	et	3	main
ootab	doc_740091150998_item	3640885	et	3	main
generatsioon	doc_740091150998_item	3640884	et	3	main
vanem	doc_740091150998_item	3640883	et	4	main
kui	doc_740091150998_item	3640882	et	3	main
olnud	doc_740091150998_item	3640881	et	4	main
nii	doc_740091150998_item	3640880	et	3	main
see	doc_740091150998_item	3640878	et	3	main
alati	doc_740091150998_item	3640879	et	4	main
on	doc_740091150998_item	3640877	et	4	main
tegelikult	doc_740091150998_item	3640876	et	4	main
kuid	doc_740091150998_item	3640875	et	4	main
omast	doc_740091150998_item	3640874	et	4	main
aastaste	doc_740091150998_item	3640873	et	4	main
tõelised	doc_740091151000_item	3641867	et	4	main
et	doc_740091151000_item	3641866	et	3	main
loodan	doc_740091151000_item	3641864	et	3	main
kuhugi	doc_740091151000_item	3641862	et	4	main
on	doc_740091151000_item	3641849	et	4	main
identiteeti	doc_740091151000_item	3641838	et	4	main
virtuaalset	doc_740091151000_item	3641837	et	3	main
kasutada	doc_740091151000_item	3641836	et	3	main
on	doc_740091151000_item	3641835	et	4	main
viis	doc_740091151000_item	3641830	et	4	main
on	doc_740091151000_item	3641828	et	4	main
mõelda	doc_740091151000_item	3641824	et	4	main
kuid	doc_740091151000_item	3641819	et	4	main
proovida	doc_740091151000_item	3641818	et	3	main
järele	doc_740091151000_item	3641817	et	4	main
loomulikult	doc_740091151000_item	3641809	et	4	main
ning	doc_740091151000_item	3641808	et	3	main
hoida	doc_740091151000_item	3641807	et	3	main
eemale	doc_740091151000_item	3641806	et	3	main
rasvavolti	doc_740091151000_item	3641763	et	4	main
pusa	doc_740091151000_item	3641758	et	4	main
laenatud	doc_740091151000_item	3641756	et	4	main
peal	doc_740091151000_item	3641755	et	4	main
kultuurinormidele	doc_740091150998_item	3640776	et	3	main
antud	doc_740091150998_item	3640775	et	4	main
see	doc_740091150998_item	3640769	et	3	main
välja	doc_740091150998_item	3640764	et	4	main
normaalsus	doc_740091150998_item	3640757	et	4	main
vastavalt	doc_740091150998_item	3640750	et	4	main
käitub	doc_740091150998_item	3640749	et	3	main
ning	doc_740091150998_item	3640748	et	3	main
normaalsus	doc_740091150998_item	3640740	et	4	main
et	doc_740091150998_item	3640739	et	3	main
loengutes	doc_740091150998_item	3640736	et	4	main
psühholoogia	doc_740091150998_item	3640735	et	4	main
ihaldab	doc_740091150998_item	3640734	et	3	main
hing	doc_740091150998_item	3640733	et	3	main
mida	doc_740091150998_item	3640732	et	4	main
asju	doc_740091150998_item	3640731	et	3	main
on	doc_740091150998_item	3640696	et	4	main
kui	doc_740091150998_item	3640695	et	3	main
seda	doc_740091150998_item	3640694	et	3	main
on	doc_740091150998_item	3640893	et	4	main
hääbu	doc_740091151000_item	3641870	et	4	main
südamest	doc_740091151000_item	3641865	et	4	main
trenni	doc_740091151000_item	3641857	et	4	main
pärast	doc_740091151000_item	3641856	et	4	main
võib-olla	doc_740091151000_item	3641850	et	3	main
kirjutama	doc_740091151000_item	3641845	et	3	main
hakata	doc_740091151000_item	3641843	et	4	main
kui	doc_740091151000_item	3641842	et	3	main
enne	doc_740091151000_item	3641841	et	4	main
mitte	doc_740091151000_item	3641840	et	3	main
otstarbekam	doc_740091151000_item	3641834	et	4	main
kas	doc_740091151000_item	3641833	et	3	main
tuleb	doc_740091151000_item	3641822	et	3	main
sellest	doc_740091151000_item	3641804	et	4	main
orkuti	doc_740091151000_item	3641792	et	4	main
kord	doc_740091151000_item	3641767	et	4	main
võetud	doc_740091151000_item	3641765	et	4	main
ning	doc_740091151000_item	3641759	et	3	main
nikei	doc_740091151000_item	3641757	et	4	main
oli	doc_740091151000_item	3641750	et	3	main
tulla	doc_740091151000_item	3641748	et	3	main
ta	doc_740091151000_item	3641732	et	4	main
virtuaalmaailmas	doc_740091151000_item	3641708	et	4	main
et	doc_740091151000_item	3641707	et	3	main
isikutega	doc_740091151000_item	3641696	et	4	main
nö	doc_740091151000_item	3641685	et	4	main
jõuab	doc_740091151000_item	3641682	et	3	main
räägitakse	doc_740091150998_item	3640737	et	3	main
on	doc_740091150998_item	3640726	et	4	main
inimesel	doc_740091150998_item	3640725	et	3	main
kui	doc_740091150998_item	3640724	et	3	main
normaalne	doc_740091150998_item	3640723	et	3	main
on	doc_740091150998_item	3640722	et	4	main
odavad	doc_740091150998_item	3640721	et	3	main
praegusega	doc_740091150998_item	3640720	et	3	main
võrreldes	doc_740091150998_item	3640719	et	3	main
olid	doc_740091150998_item	3640718	et	4	main
hinnad	doc_740091150998_item	3640717	et	3	main
kuna	doc_740091150998_item	3640716	et	3	main
veel	doc_740091150998_item	3640706	et	4	main
auto	doc_740091150998_item	3640700	et	4	main
kodu	doc_740091150998_item	3640698	et	4	main
olemas	doc_740091150998_item	3640697	et	4	main
saage	doc_740091150998_item	3640687	et	4	main
kuid	doc_740091151000_item	3641863	et	4	main
kao	doc_740091151000_item	3641861	et	4	main
näiteks	doc_740091151000_item	3641855	et	4	main
rääkida	doc_740091151000_item	3641854	et	3	main
sõpradele	doc_740091151000_item	3641853	et	3	main
sellest	doc_740091151000_item	3641852	et	4	main
suurest	doc_740091151000_item	3641847	et	4	main
oma	doc_740091151000_item	3641846	et	4	main
blogi	doc_740091151000_item	3641844	et	4	main
selleni	doc_740091151000_item	3641831	et	3	main
soovi	doc_740091151000_item	3641816	et	4	main
ning	doc_740091151000_item	3641815	et	3	main
kõigest	doc_740091151000_item	3641805	et	4	main
on	doc_740091151000_item	3641802	et	4	main
pidada	doc_740091151000_item	3641799	et	4	main
vestlust	doc_740091151000_item	3641798	et	3	main
tore	doc_740091151000_item	3641797	et	3	main
on	doc_740091151000_item	3641796	et	4	main
mõnikord	doc_740091151000_item	3641795	et	3	main
ning	doc_740091151000_item	3641794	et	3	main
konto	doc_740091151000_item	3641793	et	4	main
minad	doc_740091151000_item	3641868	et	3	main
ei	doc_740091151000_item	3641860	et	4	main
minad	doc_740091151000_item	3641859	et	3	main
õnnestumisest	doc_740091151000_item	3641848	et	4	main
või	doc_740091151000_item	3641839	et	4	main
läbi	doc_740091151000_item	3641823	et	4	main
huvi	doc_740091151000_item	3641814	et	4	main
tekitab	doc_740091151000_item	3641813	et	3	main
asi	doc_740091151000_item	3641812	et	4	main
uus	doc_740091151000_item	3641811	et	3	main
iga	doc_740091151000_item	3641810	et	4	main
paratamatu	doc_740091151000_item	3641803	et	4	main
msnis	doc_740091151000_item	3641800	et	4	main
samuti	doc_740091151000_item	3641791	et	3	main
täiendan	doc_740091151000_item	3641790	et	3	main
aegajalt	doc_740091151000_item	3641789	et	3	main
mida	doc_740091151000_item	3641788	et	4	main
blog	doc_740091151000_item	3641787	et	4	main
olemas	doc_740091151000_item	3641786	et	4	main
on	doc_740091151000_item	3641785	et	4	main
mul	doc_740091151000_item	3641784	et	3	main
ka	doc_740091151000_item	3641783	et	3	main
et	doc_740091151000_item	3641782	et	3	main
salga	doc_740091151000_item	3641781	et	4	main
ma	doc_740091151000_item	3641779	et	3	main
isiklikult	doc_740091151000_item	3641778	et	4	main
ei	doc_740091151000_item	3641780	et	4	main
ellu	doc_740091151000_item	3641777	et	4	main
päris	doc_740091151000_item	3641776	et	4	main
lapsed	doc_740091151000_item	3641775	et	3	main
oma	doc_740091151000_item	3641774	et	4	main
suunata	doc_740091151000_item	3641773	et	4	main
oskuseni	doc_740091151000_item	3641772	et	3	main
ning	doc_740091151000_item	3641771	et	3	main
kasvatuseni	doc_740091151000_item	3641770	et	4	main
jõuame	doc_740091151000_item	3641768	et	3	main
taas	doc_740091151000_item	3641766	et	3	main
photoshopis	doc_740091151000_item	3641760	et	4	main
päris	doc_740091151000_item	3641745	et	4	main
niisama	doc_740091151000_item	3641744	et	3	main
ka	doc_740091151000_item	3641743	et	3	main
veel	doc_740091151000_item	3641736	et	4	main
hing	doc_740091151000_item	3641735	et	3	main
see	doc_740091151000_item	3641730	et	3	main
saab	doc_740091151000_item	3641728	et	3	main
kuid	doc_740091151000_item	3641698	et	4	main
suheldes	doc_740091151000_item	3641697	et	3	main
luues	doc_740091151000_item	3641690	et	4	main
tõepoolest	doc_740091151000_item	3641680	et	3	main
aruteludel	doc_740091151000_item	3641672	et	3	main
infot	doc_740091151000_item	3641669	et	3	main
kaudu	doc_740091151000_item	3641667	et	3	main
aasta	doc_740091151000_item	3641610	et	4	main
ka	doc_740091151000_item	3641606	et	3	main
esinejaid	doc_740091151000_item	3641603	et	4	main
välja	doc_740091151000_item	3641592	et	4	main
registreerinud	doc_740091151000_item	3641583	et	4	main
loomulikult	doc_740091151000_item	3641561	et	4	main
luulekonkurssi	doc_740091151000_item	3641550	et	4	main
istumine	doc_740091151000_item	3641533	et	4	main
jututubades	doc_740091151000_item	3641532	et	3	main
milline	doc_740091151000_item	3641827	et	3	main
ning	doc_740091151000_item	3641826	et	3	main
eesmärk	doc_740091151000_item	3641825	et	3	main
tegutsemist	doc_740091151000_item	3641821	et	4	main
enne	doc_740091151000_item	3641820	et	4	main
tehnoloogiamaailmas	doc_740091151000_item	3641801	et	3	main
ära	doc_740091151000_item	3641764	et	4	main
pildi	doc_740091151000_item	3641754	et	4	main
tegelikult	doc_740091151000_item	3641749	et	4	main
ei	doc_740091151000_item	3641741	et	4	main
suhtlusprobleemidele	doc_740091151000_item	3641740	et	3	main
lisaks	doc_740091151000_item	3641739	et	4	main
tegelikult	doc_740091151000_item	3641738	et	4	main
ihkab	doc_740091151000_item	3641737	et	3	main
kes	doc_740091151000_item	3641731	et	4	main
mina	doc_740091151000_item	3641689	et	4	main
virtuaalne	doc_740091151000_item	3641688	et	3	main
eesmärgil	doc_740091151000_item	3641687	et	3	main
töö	doc_740091151000_item	3641686	et	4	main
noorteni	doc_740091151000_item	3641681	et	3	main
selleni	doc_740091151000_item	3641678	et	3	main
inimestega	doc_740091151000_item	3641675	et	3	main
omavahelisel	doc_740091151000_item	3641671	et	4	main
koduse	doc_740091151000_item	3641769	et	4	main
paar	doc_740091151000_item	3641762	et	3	main
oli	doc_740091151000_item	3641761	et	3	main
orkuti	doc_740091151000_item	3641753	et	4	main
noorel	doc_740091151000_item	3641752	et	3	main
sellel	doc_740091151000_item	3641751	et	4	main
toime	doc_740091151000_item	3641747	et	4	main
elus	doc_740091151000_item	3641746	et	4	main
tulema	doc_740091151000_item	3641726	et	4	main
välja	doc_740091151000_item	3641725	et	4	main
enam	doc_740091151000_item	3641724	et	4	main
ju	doc_740091151000_item	3641723	et	3	main
peagi	doc_740091151000_item	3641722	et	4	main
ei	doc_740091151000_item	3641721	et	4	main
tema	doc_740091151000_item	3641720	et	4	main
ka	doc_740091151000_item	3641719	et	3	main
ju	doc_740091151000_item	3641718	et	3	main
sinna	doc_740091151000_item	3641717	et	3	main
tuuakse	doc_740091151000_item	3641716	et	3	main
uuele	doc_740091151000_item	3641715	et	3	main
kõigele	doc_740091151000_item	3641714	et	4	main
lisaks	doc_740091151000_item	3641713	et	4	main
sest	doc_740091151000_item	3641712	et	4	main
hea	doc_740091151000_item	3641711	et	4	main
olla	doc_740091151000_item	3641710	et	3	main
on	doc_740091151000_item	3641709	et	4	main
suudeta	doc_740091151000_item	3641742	et	4	main
mida	doc_740091151000_item	3641734	et	4	main
tahab	doc_740091151000_item	3641733	et	3	main
olla	doc_740091151000_item	3641729	et	3	main
noor	doc_740091151000_item	3641727	et	3	main
sellega	doc_740091151000_item	3641706	et	3	main
virtuaalsete	doc_740091151000_item	3641695	et	3	main
vastavates	doc_740091151000_item	3641692	et	4	main
hästi	doc_740091151000_item	3641684	et	3	main
oleme	doc_740091151000_item	3641676	et	3	main
valdkonna	doc_740091151000_item	3641674	et	4	main
sama	doc_740091151000_item	3641673	et	4	main
areneda	doc_740091151000_item	3641608	et	3	main
ning	doc_740091151000_item	3641604	et	3	main
samu	doc_740091151000_item	3641601	et	3	main
võimaldab	doc_740091151000_item	3641598	et	3	main
nende	doc_740091151000_item	3641595	et	4	main
ning	doc_740091151000_item	3641594	et	3	main
identiteedi	doc_740091151000_item	3641587	et	4	main
virtuaalse	doc_740091151000_item	3641586	et	3	main
oma	doc_740091151000_item	3641585	et	4	main
ja	doc_740091151000_item	3641584	et	3	main
erinevates	doc_740091151000_item	3641574	et	4	main
levis	doc_740091151000_item	3641573	et	4	main
põhiinfo	doc_740091151000_item	3641572	et	4	main
eesti	doc_740091151000_item	3641560	et	4	main
üle	doc_740091151000_item	3641559	et	3	main
sobiva	doc_740091151000_item	3641557	et	4	main
oli	doc_740091151000_item	3641554	et	3	main
hästi	doc_740091151000_item	3641552	et	3	main
noortele	doc_740091151000_item	3641551	et	3	main
suurt	doc_740091151000_item	3641549	et	3	main
tõsta	doc_740091151000_item	3641539	et	4	main
saatmise	doc_740091151000_item	3641536	et	4	main
ning	doc_740091151000_item	3641525	et	3	main
arusaama	doc_740091151000_item	3641519	et	4	main
mõistust	doc_740091151000_item	3641517	et	4	main
tervet	doc_740091151000_item	3641516	et	4	main
eelkõige	doc_740091151000_item	3641511	et	3	main
tundides	doc_740091151000_item	3641510	et	3	main
suuline	doc_740091151000_item	3641506	et	4	main
et	doc_740091151000_item	3641504	et	3	main
samuti	doc_740091151000_item	3641501	et	3	main
msni	doc_740091151000_item	3641491	et	4	main
et	doc_740091151000_item	3641487	et	3	main
sellest	doc_740091151000_item	3641486	et	4	main
või	doc_740091151000_item	3641485	et	4	main
et	doc_740091151000_item	3641480	et	3	main
sellest	doc_740091151000_item	3641479	et	4	main
oskagi	doc_740091151000_item	3641472	et	4	main
enam	doc_740091151000_item	3641469	et	4	main
või	doc_740091151000_item	3641430	et	4	main
hetkemeeleolu	doc_740091151000_item	3641429	et	4	main
oma	doc_740091151000_item	3641417	et	4	main
kasutades	doc_740091151000_item	3641416	et	3	main
vajalik	doc_740091151000_item	3641411	et	3	main
on	doc_740091151000_item	3641408	et	4	main
tekitada	doc_740091151000_item	3641406	et	3	main
ning	doc_740091151000_item	3641403	et	3	main
suhelda	doc_740091151000_item	3641387	et	4	main
enam	doc_740091151000_item	3641386	et	4	main
ta	doc_740091151000_item	3641383	et	4	main
avastas	doc_740091151000_item	3641381	et	3	main
suhtlemist	doc_740091151000_item	3641379	et	4	main
hakkab	doc_740091151000_item	3641361	et	3	main
üks	doc_740091151000_item	3641347	et	3	main
saada	doc_740091151000_item	3641287	et	4	main
võinud	doc_740091151000_item	3641286	et	4	main
ma	doc_740091151000_item	3641285	et	3	main
midagi	doc_740091151000_item	3641275	et	4	main
juhtunud	doc_740091151000_item	3641274	et	4	main
ilma	doc_740091151000_item	3641269	et	4	main
pean	doc_740091151000_item	3641265	et	4	main
seetõttu	doc_740091151000_item	3641264	et	3	main
kas	doc_740091151000_item	3641263	et	3	main
lugenud	doc_740091151000_item	3641260	et	4	main
midagi	doc_740091151000_item	3641240	et	4	main
on	doc_740091151000_item	3641237	et	4	main
jne	doc_740091151000_item	3641236	et	4	main
jne	doc_740091151000_item	3641235	et	4	main
foorume	doc_740091151000_item	3641229	et	4	main
35	doc_740091151000_item	3641214	et	2	main
harjuvad	doc_740091151000_item	3641705	et	4	main
noored	doc_740091151000_item	3641704	et	3	main
eetiline	doc_740091151000_item	3641703	et	3	main
ka	doc_740091151000_item	3641702	et	3	main
on	doc_740091151000_item	3641701	et	4	main
see	doc_740091151000_item	3641700	et	3	main
kas	doc_740091151000_item	3641699	et	3	main
noorte	doc_740091151000_item	3641694	et	3	main
kanalites	doc_740091151000_item	3641693	et	3	main
ja	doc_740091151000_item	3641691	et	3	main
väga	doc_740091151000_item	3641683	et	3	main
et	doc_740091151000_item	3641679	et	3	main
jõudnud	doc_740091151000_item	3641677	et	4	main
edastama	doc_740091151000_item	3641670	et	3	main
siis	doc_740091151000_item	3641668	et	3	main
käesoleva	doc_740091151000_item	3641609	et	3	main
üheskoos	doc_740091151000_item	3641605	et	3	main
leida	doc_740091151000_item	3641600	et	3	main
neil	doc_740091151000_item	3641599	et	4	main
identiteet	doc_740091151000_item	3641597	et	4	main
virtuaalne	doc_740091151000_item	3641596	et	3	main
kujunenud	doc_740091151000_item	3641593	et	4	main
pressiteated	doc_740091151000_item	3641567	et	3	main
koduleht	doc_740091151000_item	3641566	et	3	main
teavitamiskanaleid	doc_740091151000_item	3641565	et	4	main
igapäevaseid	doc_740091151000_item	3641564	et	4	main
ka	doc_740091151000_item	3641563	et	3	main
kasutasime	doc_740091151000_item	3641562	et	3	main
sihtgrupini	doc_740091151000_item	3641558	et	3	main
jõuda	doc_740091151000_item	3641555	et	3	main
ühte	doc_740091151000_item	3641548	et	4	main
tõttu	doc_740091151000_item	3641547	et	4	main
tööülesannete	doc_740091151000_item	3641546	et	3	main
asemel	doc_740091151000_item	3641537	et	4	main
enam	doc_740091151000_item	3641530	et	4	main
et	doc_740091151000_item	3641520	et	3	main
ning	doc_740091151000_item	3641518	et	3	main
nende	doc_740091151000_item	3641666	et	4	main
edasi	doc_740091151000_item	3641607	et	3	main
huvide	doc_740091151000_item	3641602	et	3	main
juba	doc_740091151000_item	3641591	et	3	main
nö	doc_740091151000_item	3641590	et	4	main
inimesed	doc_740091151000_item	3641589	et	3	main
kasutajaks	doc_740091151000_item	3641582	et	4	main
kohtades	doc_740091151000_item	3641581	et	3	main
eelpoolnimetatud	doc_740091151000_item	3641580	et	3	main
on	doc_740091151000_item	3641579	et	4	main
tavaliselt	doc_740091151000_item	3641578	et	4	main
kodulehtedel	doc_740091151000_item	3641577	et	4	main
ning	doc_740091151000_item	3641576	et	3	main
kirjandusfoorumites	doc_740091151000_item	3641575	et	3	main
loonud	doc_740091151000_item	3641588	et	4	main
kuid	doc_740091151000_item	3641571	et	4	main
just	doc_740091151000_item	3641556	et	3	main
oluline	doc_740091151000_item	3641553	et	4	main
aastat	doc_740091151000_item	3641542	et	3	main
paar	doc_740091151000_item	3641541	et	3	main
telefonitoru	doc_740091151000_item	3641540	et	4	main
märksa	doc_740091151000_item	3641529	et	3	main
arendab	doc_740091151000_item	3641528	et	3	main
suhtlemine	doc_740091151000_item	3641527	et	4	main
tegelemine	doc_740091151000_item	3641524	et	4	main
hobiga	doc_740091151000_item	3641523	et	3	main
mingisuguse	doc_740091151000_item	3641522	et	3	main
inimese	doc_740091151000_item	3641514	et	4	main
lapsevanematel	doc_740091151000_item	3641497	et	4	main
roll	doc_740091151000_item	3641496	et	3	main
suur	doc_740091151000_item	3641495	et	3	main
on	doc_740091151000_item	3641484	et	4	main
ikka	doc_740091151000_item	3641478	et	4	main
räägivad	doc_740091151000_item	3641477	et	3	main
siis	doc_740091151000_item	3641476	et	3	main
kasutajanime	doc_740091151000_item	3641457	et	4	main
oma	doc_740091151000_item	3641456	et	4	main
kasutades	doc_740091151000_item	3641455	et	3	main
vajaminev	doc_740091151000_item	3641454	et	4	main
soetada	doc_740091151000_item	3641453	et	3	main
e-poodides	doc_740091151000_item	3641452	et	3	main
isegi	doc_740091151000_item	3641451	et	4	main
ning	doc_740091151000_item	3641450	et	3	main
kiri	doc_740091151000_item	3641449	et	3	main
asjalikum	doc_740091151000_item	3641448	et	4	main
mõni	doc_740091151000_item	3641447	et	3	main
saata	doc_740091151000_item	3641446	et	3	main
e-postiga	doc_740091151000_item	3641445	et	4	main
kaustades	doc_740091151000_item	3641444	et	3	main
orkuti	doc_740091151000_item	3641443	et	4	main
ja	doc_740091151000_item	3641442	et	3	main
ratei	doc_740091151000_item	3641441	et	4	main
foorumites	doc_740091151000_item	3641440	et	3	main
või	doc_740091151000_item	3641439	et	4	main
jms	doc_740091151000_item	3641570	et	4	main
plakatid	doc_740091151000_item	3641569	et	3	main
mailinglistid	doc_740091151000_item	3641568	et	4	main
oma	doc_740091151000_item	3641545	et	4	main
organiseerisin	doc_740091151000_item	3641544	et	3	main
tagasi	doc_740091151000_item	3641543	et	3	main
lihtsalt	doc_740091151000_item	3641538	et	4	main
e-kirja	doc_740091151000_item	3641535	et	4	main
või	doc_740091151000_item	3641534	et	4	main
seeläbi	doc_740091151000_item	3641526	et	3	main
enda	doc_740091151000_item	3641515	et	4	main
on	doc_740091151000_item	3641512	et	4	main
ning	doc_740091151000_item	3641508	et	3	main
koolil	doc_740091151000_item	3641503	et	4	main
ka	doc_740091151000_item	3641502	et	3	main
must	doc_740091151000_item	3641489	et	4	main
ei	doc_740091151000_item	3641471	et	4	main
eriti	doc_740091151000_item	3641464	et	3	main
panna	doc_740091151000_item	3641428	et	4	main
suhelda	doc_740091151000_item	3641414	et	4	main
võimalik	doc_740091151000_item	3641409	et	3	main
usaldust	doc_740091151000_item	3641405	et	4	main
kliendis	doc_740091151000_item	3641404	et	3	main
suhelda	doc_740091151000_item	3641388	et	4	main
ei	doc_740091151000_item	3641384	et	4	main
ta	doc_740091151000_item	3641380	et	4	main
konstruktiivset	doc_740091151000_item	3641378	et	3	main
ta	doc_740091151000_item	3641366	et	4	main
vaid	doc_740091151000_item	3641360	et	3	main
oma	doc_740091151000_item	3641358	et	4	main
kirjuta	doc_740091151000_item	3641357	et	4	main
blogis	doc_740091151000_item	3641351	et	4	main
oma	doc_740091151000_item	3641350	et	4	main
sõber	doc_740091151000_item	3641349	et	3	main
tähendab	doc_740091151000_item	3641295	et	3	main
virtuaalne	doc_740091151000_item	3641293	et	3	main
oleks	doc_740091151000_item	3641284	et	3	main
meenutusi	doc_740091151000_item	3641280	et	4	main
nädalavahetuse	doc_740091151000_item	3641279	et	4	main
ei	doc_740091151000_item	3641273	et	4	main
juhul	doc_740091151000_item	3641272	et	3	main
infost	doc_740091151000_item	3641268	et	3	main
ma	doc_740091151000_item	3641266	et	3	main
ei	doc_740091151000_item	3641255	et	4	main
hoopis	doc_740091151000_item	3641243	et	3	main
halba	doc_740091151000_item	3641241	et	4	main
blogisid	doc_740091151000_item	3641234	et	4	main
võimalusi	doc_740091151000_item	3641232	et	3	main
kes	doc_740091151000_item	3641221	et	4	main
internetimaailma	doc_740091151000_item	3641220	et	4	main
kolinud	doc_740091151000_item	3641219	et	4	main
inimeste	doc_740091151000_item	3641216	et	3	main
kohta	doc_740091151000_item	3641204	et	4	main
koosviibimise	doc_740091151000_item	3641203	et	3	main
vastuse	doc_740091151000_item	3641195	et	3	main
nad	doc_740091151000_item	3641662	et	3	main
noortega	doc_740091151000_item	3641655	et	3	main
parem	doc_740091151000_item	3641646	et	4	main
olla	doc_740091151000_item	3641645	et	3	main
või	doc_740091151000_item	3641644	et	4	main
teine	doc_740091151000_item	3641643	et	3	main
et	doc_740091151000_item	3641640	et	3	main
seda	doc_740091151000_item	3641638	et	3	main
inimesed	doc_740091151000_item	3641635	et	3	main
oma	doc_740091151000_item	3641632	et	4	main
huvigruppi	doc_740091151000_item	3641630	et	4	main
mingit	doc_740091151000_item	3641629	et	3	main
ilma	doc_740091151000_item	3641628	et	4	main
niisama	doc_740091151000_item	3641627	et	3	main
näitel	doc_740091151000_item	3641626	et	3	main
räägitigi	doc_740091151000_item	3641621	et	3	main
uurimistööst	doc_740091151000_item	3641619	et	3	main
paratamatult	doc_740091151000_item	3641324	et	4	main
tuleb	doc_740091151000_item	3641323	et	3	main
infost	doc_740091151000_item	3641322	et	3	main
selle	doc_740091151000_item	3641313	et	4	main
tagab	doc_740091151000_item	3641312	et	3	main
tänapäeva	doc_740091151000_item	3641309	et	4	main
infot	doc_740091151000_item	3641301	et	3	main
partner	doc_740091151001_item	3642343	et	3	main
ei	doc_740091151001_item	3642333	et	4	main
kui	doc_740091151000_item	3641531	et	3	main
näiteks	doc_740091151000_item	3641521	et	4	main
vaja	doc_740091151000_item	3641513	et	4	main
vastamine	doc_740091151000_item	3641507	et	4	main
on	doc_740091151000_item	3641494	et	4	main
kindlasti	doc_740091151000_item	3641493	et	3	main
tarbeks	doc_740091151000_item	3641492	et	3	main
orkutis	doc_740091151000_item	3641483	et	4	main
suhtlevadki	doc_740091151000_item	3641475	et	4	main
kui	doc_740091151000_item	3641474	et	3	main
või	doc_740091151000_item	3641473	et	4	main
suhelda	doc_740091151000_item	3641470	et	4	main
omavahel	doc_740091151000_item	3641468	et	3	main
seas	doc_740091151000_item	3641466	et	4	main
teismeliste	doc_740091151000_item	3641465	et	3	main
tõsine	doc_740091151000_item	3641462	et	4	main
on	doc_740091151000_item	3641461	et	4	main
see	doc_740091151000_item	3641460	et	3	main
et	doc_740091151000_item	3641459	et	3	main
arvan	doc_740091151000_item	3641458	et	3	main
lemmiklaulu	doc_740091151000_item	3641438	et	4	main
nimeks	doc_740091151000_item	3641427	et	3	main
oma	doc_740091151000_item	3641426	et	4	main
saan	doc_740091151000_item	3641425	et	4	main
näiteks	doc_740091151000_item	3641420	et	4	main
identiteeti	doc_740091151000_item	3641419	et	4	main
virtuaalset	doc_740091151000_item	3641418	et	3	main
ära	doc_740091151000_item	3641413	et	4	main
kogu	doc_740091151000_item	3641410	et	4	main
oska	doc_740091151000_item	3641385	et	4	main
vahetanud	doc_740091151000_item	3641370	et	4	main
kui	doc_740091151000_item	3641368	et	3	main
siis	doc_740091151000_item	3641367	et	3	main
tegemistest	doc_740091151000_item	3641359	et	4	main
ei	doc_740091151000_item	3641356	et	4	main
kirjutas	doc_740091151000_item	3641345	et	3	main
olulisema	doc_740091151000_item	3641290	et	4	main
märksa	doc_740091151000_item	3641289	et	3	main
kuulnud	doc_740091151000_item	3641278	et	4	main
antud	doc_740091151000_item	3641271	et	4	main
arutelud	doc_740091151000_item	3641509	et	3	main
säiliks	doc_740091151000_item	3641505	et	3	main
kasvatusel	doc_740091151000_item	3641500	et	4	main
kodusel	doc_740091151000_item	3641499	et	4	main
ning	doc_740091151000_item	3641498	et	3	main
pilt	doc_740091151000_item	3641490	et	3	main
tee	doc_740091151000_item	3641488	et	4	main
scrappi	doc_740091151000_item	3641482	et	4	main
mitu	doc_740091151000_item	3641481	et	4	main
kes	doc_740091151000_item	3641467	et	4	main
oht	doc_740091151000_item	3641463	et	3	main
nädalavahetuse	doc_740091151000_item	3641434	et	4	main
möödunud	doc_740091151000_item	3641433	et	4	main
pildiks	doc_740091151000_item	3641432	et	3	main
tegevuse	doc_740091151000_item	3641431	et	4	main
eelpool	doc_740091151000_item	3641422	et	4	main
juba	doc_740091151000_item	3641421	et	3	main
internetis	doc_740091151000_item	3641415	et	4	main
suhtlus	doc_740091151000_item	3641412	et	3	main
tegelikult	doc_740091151000_item	3641407	et	4	main
mulje	doc_740091151000_item	3641401	et	4	main
hea	doc_740091151000_item	3641400	et	4	main
vahetada	doc_740091151000_item	3641398	et	3	main
infot	doc_740091151000_item	3641397	et	3	main
palju	doc_740091151000_item	3641377	et	4	main
oli	doc_740091151000_item	3641369	et	3	main
oma	doc_740091151000_item	3641437	et	4	main
muusikaks	doc_740091151000_item	3641436	et	3	main
poseeringu	doc_740091151000_item	3641435	et	4	main
msnis	doc_740091151000_item	3641424	et	4	main
mainitud	doc_740091151000_item	3641423	et	4	main
jätta	doc_740091151000_item	3641402	et	3	main
endast	doc_740091151000_item	3641399	et	4	main
kiirelt	doc_740091151000_item	3641396	et	4	main
tuleb	doc_740091151000_item	3641395	et	3	main
kus	doc_740091151000_item	3641394	et	3	main
olukordades	doc_740091151000_item	3641393	et	3	main
ning	doc_740091151000_item	3641392	et	3	main
inimestega	doc_740091151000_item	3641391	et	3	main
võõraste	doc_740091151000_item	3641390	et	4	main
just	doc_740091151000_item	3641389	et	3	main
et	doc_740091151000_item	3641382	et	3	main
töökohta	doc_740091151000_item	3641371	et	4	main
põhjuse	doc_740091151000_item	3641364	et	3	main
inimestega	doc_740091151000_item	3641362	et	3	main
siia	doc_740091151000_item	3641355	et	4	main
hea	doc_740091151000_item	3641348	et	4	main
hiljuti	doc_740091151000_item	3641344	et	4	main
kommunikatsiooni	doc_740091151000_item	3641342	et	4	main
identiteet	doc_740091151000_item	3641294	et	4	main
puhul	doc_740091151000_item	3641292	et	4	main
teabe	doc_740091151000_item	3641291	et	3	main
vastuse	doc_740091151000_item	3641283	et	3	main
kui	doc_740091151000_item	3641276	et	3	main
tõsi	doc_740091151000_item	3641270	et	4	main
jääma	doc_740091151000_item	3641267	et	4	main
seda	doc_740091151000_item	3641261	et	3	main
olnud	doc_740091151000_item	3641259	et	4	main
ei	doc_740091151000_item	3641258	et	4	main
tõepoolest	doc_740091151000_item	3641257	et	3	main
ma	doc_740091151000_item	3641256	et	3	main
esineb	doc_740091151000_item	3641249	et	3	main
moesuunal	doc_740091151000_item	3641248	et	3	main
uuel	doc_740091151000_item	3641247	et	3	main
igal	doc_740091151000_item	3641246	et	3	main
eks	doc_740091151000_item	3641245	et	3	main
head	doc_740091151000_item	3641244	et	4	main
siis	doc_740091151000_item	3641239	et	3	main
piltide	doc_740091151000_item	3641230	et	3	main
erinevaid	doc_740091151000_item	3641228	et	4	main
orkutit	doc_740091151000_item	3641226	et	4	main
ratei	doc_740091151000_item	3641225	et	4	main
teaks	doc_740091151000_item	3641224	et	3	main
on	doc_740091151000_item	3641218	et	4	main
13	doc_740091151000_item	3641213	et	2	main
osa	doc_740091151000_item	3641211	et	4	main
ei	doc_740091151000_item	3641208	et	4	main
viibida	doc_740091151000_item	3641207	et	3	main
ise	doc_740091151000_item	3641206	et	4	main
kus	doc_740091151000_item	3641205	et	3	main
olin	doc_740091151000_item	3641199	et	3	main
kui	doc_740091151000_item	3641198	et	3	main
sõbralt	doc_740091151000_item	3641197	et	3	main
oma	doc_740091151000_item	3641196	et	4	main
tagasi	doc_740091151000_item	3641193	et	3	main
aeg	doc_740091151000_item	3641192	et	3	main
mõni	doc_740091151000_item	3641191	et	3	main
sain	doc_740091151000_item	3641190	et	3	main
või	doc_740091151000_item	3641189	et	4	main
ole	doc_740091151000_item	3641187	et	4	main
hästi	doc_740091151000_item	3641376	et	3	main
nõudis	doc_740091151000_item	3641375	et	3	main
töö	doc_740091151000_item	3641374	et	4	main
uus	doc_740091151000_item	3641373	et	3	main
ning	doc_740091151000_item	3641372	et	3	main
avastas	doc_740091151000_item	3641365	et	3	main
suhtlema	doc_740091151000_item	3641363	et	3	main
ta	doc_740091151000_item	3641354	et	4	main
rohkem	doc_740091151000_item	3641353	et	4	main
et	doc_740091151000_item	3641352	et	3	main
mu	doc_740091151000_item	3641346	et	3	main
alles	doc_740091151000_item	3641343	et	3	main
persoonivahelist	doc_740091151000_item	3641341	et	4	main
mingisuguse	doc_740091151000_item	3641288	et	3	main
sama	doc_740091151000_item	3641282	et	4	main
kuid	doc_740091151000_item	3641281	et	4	main
ei	doc_740091151000_item	3641277	et	4	main
blogi	doc_740091151000_item	3641262	et	4	main
tegureid	doc_740091151000_item	3641254	et	4	main
negatiivseid	doc_740091151000_item	3641253	et	3	main
ja	doc_740091151000_item	3641252	et	3	main
positiivseid	doc_740091151000_item	3641251	et	3	main
oma	doc_740091151000_item	3641250	et	4	main
või	doc_740091151000_item	3641242	et	4	main
jututubasid	doc_740091151000_item	3641233	et	3	main
ei	doc_740091151000_item	3641223	et	4	main
identiteedist	doc_740091151000_item	3641217	et	4	main
aastaste	doc_740091151000_item	3641215	et	4	main
saanud	doc_740091151000_item	3641209	et	4	main
möödunud	doc_740091151000_item	3641201	et	4	main
küsinud	doc_740091151000_item	3641200	et	4	main
blogist	doc_740091151000_item	3641185	et	4	main
siis	doc_740091151000_item	3641183	et	3	main
kas	doc_740091151000_item	3641181	et	3	main
virtuaalne	doc_740091151000_item	3641179	et	3	main
selgitama	doc_740091151000_item	3641658	et	4	main
ja	doc_740091151000_item	3641657	et	3	main
suhtlema	doc_740091151000_item	3641654	et	3	main
pean	doc_740091151000_item	3641651	et	4	main
rateee	doc_740091151000_item	3641625	et	4	main
kus	doc_740091151000_item	3641620	et	3	main
jääda	doc_740091151000_item	3641332	et	4	main
olla	doc_740091151000_item	3641330	et	3	main
sõltuv	doc_740091151000_item	3641318	et	4	main
oleme	doc_740091151000_item	3641316	et	3	main
me	doc_740091151000_item	3641315	et	4	main
et	doc_740091151000_item	3641314	et	3	main
virtuaalsete	doc_740091151000_item	3641304	et	3	main
et	doc_740091151001_item	3642355	et	3	main
selleks	doc_740091151001_item	3642354	et	4	main
elada	doc_740091151001_item	3642353	et	3	main
ei	doc_740091151001_item	3642347	et	4	main
oma	doc_740091151001_item	3642340	et	4	main
mees	doc_740091151001_item	3642332	et	4	main
lapsevanem	doc_740091151001_item	3642322	et	4	main
ei	doc_740091151001_item	3642317	et	4	main
on	doc_740091151001_item	3642308	et	4	main
aastaga	doc_740091151001_item	3642307	et	3	main
kindlameelsemad	doc_740091151001_item	3642304	et	4	main
tagasi	doc_740091151001_item	3642293	et	3	main
ka	doc_740091151001_item	3642290	et	3	main
kui	doc_740091151001_item	3642289	et	3	main
on	doc_740091151001_item	3642285	et	4	main
domineerivaks	doc_740091151001_item	3642272	et	4	main
tagasi	doc_740091151001_item	3642269	et	3	main
sellel	doc_740091151001_item	3642251	et	4	main
kui	doc_740091151001_item	3642243	et	3	main
isad	doc_740091151001_item	3642238	et	3	main
saavad	doc_740091151001_item	3642235	et	4	main
on	doc_740091151001_item	3642201	et	4	main
enam	doc_740091151001_item	3642193	et	4	main
sugugi	doc_740091151001_item	3642192	et	4	main
see	doc_740091151001_item	3642190	et	3	main
pole	doc_740091151001_item	3642189	et	3	main
lapsi	doc_740091151001_item	3642186	et	4	main
ja	doc_740091151001_item	3642185	et	3	main
eest	doc_740091151001_item	3642183	et	4	main
majapidamise	doc_740091151001_item	3642182	et	3	main
et	doc_740091151001_item	3642181	et	3	main
võrdset	doc_740091151001_item	3642142	et	3	main
meeste	doc_740091151001_item	3642139	et	4	main
feministid	doc_740091151001_item	3642137	et	3	main
selles	doc_740091151000_item	3641238	et	4	main
üleslaadimise	doc_740091151000_item	3641231	et	3	main
msni	doc_740091151000_item	3641227	et	4	main
meist	doc_740091151000_item	3641222	et	3	main
eelkõige	doc_740091151000_item	3641212	et	3	main
nädalavahetuse	doc_740091151000_item	3641202	et	4	main
lugenud	doc_740091151000_item	3641188	et	4	main
minu	doc_740091151000_item	3641178	et	3	main
kanaleid	doc_740091151000_item	3641660	et	4	main
olla	doc_740091151000_item	3641641	et	3	main
eelkõige	doc_740091151000_item	3641637	et	3	main
üleslaadivad	doc_740091151000_item	3641634	et	3	main
virtuaalsest	doc_740091151000_item	3641623	et	3	main
ettekannet	doc_740091151000_item	3641618	et	4	main
esindaja	doc_740091151000_item	3641617	et	4	main
ülikooli	doc_740091151000_item	3641616	et	4	main
tartu	doc_740091151000_item	3641615	et	4	main
seminaril	doc_740091151000_item	3641614	et	3	main
ühel	doc_740091151000_item	3641613	et	3	main
kuulsin	doc_740091151000_item	3641612	et	3	main
märtsikuus	doc_740091151000_item	3641611	et	3	main
kahe	doc_740091151000_item	3641340	et	3	main
puudutab	doc_740091151000_item	3641339	et	3	main
mis	doc_740091151000_item	3641338	et	4	main
eriti	doc_740091151000_item	3641337	et	3	main
võimaluseks	doc_740091151000_item	3641336	et	3	main
ja	doc_740091151000_item	3641335	et	3	main
vahendiks	doc_740091151000_item	3641334	et	3	main
ainukeseks	doc_740091151000_item	3641333	et	4	main
suur	doc_740091151000_item	3641210	et	3	main
sellise	doc_740091151000_item	3641194	et	4	main
mu	doc_740091151000_item	3641184	et	3	main
kus	doc_740091151000_item	3641661	et	3	main
neid	doc_740091151000_item	3641659	et	4	main
uurima	doc_740091151000_item	3641656	et	3	main
palju	doc_740091151000_item	3641653	et	4	main
ma	doc_740091151000_item	3641652	et	3	main
töös	doc_740091151000_item	3641650	et	3	main
oma	doc_740091151000_item	3641649	et	4	main
praegu	doc_740091151000_item	3641648	et	3	main
kui	doc_740091151000_item	3641647	et	3	main
keegi	doc_740091151000_item	3641642	et	4	main
selleks	doc_740091151000_item	3641639	et	4	main
teevad	doc_740091151000_item	3641636	et	3	main
pilte	doc_740091151000_item	3641633	et	3	main
esindamata	doc_740091151000_item	3641631	et	4	main
noorte	doc_740091151000_item	3641622	et	3	main
tohiks	doc_740091151000_item	3641329	et	3	main
identiteediga	doc_740091151000_item	3641305	et	4	main
üldiselt	doc_740091151001_item	3642350	et	4	main
ning	doc_740091151001_item	3642349	et	3	main
kolmandaks	doc_740091151001_item	3642344	et	4	main
on	doc_740091151001_item	3642339	et	4	main
abikaasana	doc_740091151001_item	3642331	et	3	main
teiseks	doc_740091151001_item	3642330	et	4	main
range	doc_740091151001_item	3642321	et	4	main
mees	doc_740091151001_item	3642316	et	4	main
mitmes	doc_740091151001_item	3642312	et	4	main
muutunud	doc_740091151001_item	3642311	et	4	main
roll	doc_740091151001_item	3642310	et	3	main
viimase	doc_740091151001_item	3642305	et	3	main
tagasihoidlikumad	doc_740091151001_item	3642302	et	4	main
olnud	doc_740091151001_item	3642301	et	4	main
kaitsmisel	doc_740091151001_item	3642300	et	4	main
oma	doc_740091151001_item	3642296	et	4	main
naised	doc_740091151001_item	3642295	et	3	main
oleksid	doc_740091151001_item	3642294	et	4	main
ei	doc_740091151000_item	3641186	et	4	main
sa	doc_740091151000_item	3641182	et	3	main
identiteet	doc_740091151000_item	3641180	et	4	main
essee	doc_740091151000_item	3641177	et	4	main
ning	doc_740091151000_item	3641665	et	3	main
kommunikeeruvad	doc_740091151000_item	3641664	et	4	main
omavahel	doc_740091151000_item	3641663	et	3	main
identiteedist	doc_740091151000_item	3641624	et	4	main
kuid	doc_740091151000_item	3641326	et	4	main
internetist	doc_740091151000_item	3641317	et	4	main
arenev	doc_740091151000_item	3641310	et	4	main
tõepoolest	doc_740091151000_item	3641308	et	3	main
teiseteiste	doc_740091151000_item	3641303	et	3	main
internetis	doc_740091151000_item	3641300	et	4	main
et	doc_740091151000_item	3641298	et	3	main
seda	doc_740091151000_item	3641297	et	3	main
ka	doc_740091151000_item	3641296	et	3	main
soovigi	doc_740091151001_item	3642352	et	4	main
ei	doc_740091151001_item	3642351	et	4	main
mees	doc_740091151001_item	3642346	et	4	main
naisele	doc_740091151001_item	3642341	et	3	main
vaid	doc_740091151001_item	3642338	et	3	main
domineeriv	doc_740091151001_item	3642336	et	4	main
kodus	doc_740091151001_item	3642335	et	4	main
ole	doc_740091151001_item	3642334	et	4	main
lastega	doc_740091151001_item	3642328	et	3	main
oma	doc_740091151001_item	3642327	et	4	main
isana	doc_740091151001_item	3642315	et	3	main
esiteks	doc_740091151001_item	3642314	et	3	main
aspektis	doc_740091151001_item	3642313	et	3	main
nii	doc_740091151001_item	3642287	et	3	main
teenib	doc_740091151001_item	3642259	et	3	main
lootuses	doc_740091151001_item	3642255	et	4	main
rohkem	doc_740091151001_item	3642254	et	4	main
teenib	doc_740091151001_item	3642253	et	3	main
kasulikum	doc_740091151001_item	3642247	et	4	main
tagasi	doc_740091151001_item	3642246	et	3	main
aastad	doc_740091151001_item	3642245	et	3	main
teistsugune	doc_740091151001_item	3642242	et	3	main
hoopis	doc_740091151001_item	3642207	et	3	main
perele	doc_740091151001_item	3642200	et	3	main
et	doc_740091151001_item	3642199	et	3	main
jääma	doc_740091151001_item	3642180	et	4	main
mehed	doc_740091151001_item	3642175	et	3	main
paarkümmend	doc_740091151001_item	3642169	et	4	main
pere	doc_740091151001_item	3642167	et	4	main
hiljem	doc_740091151001_item	3642166	et	3	main
esmalt	doc_740091151001_item	3642159	et	3	main
naised	doc_740091151001_item	3642157	et	3	main
paljud	doc_740091151001_item	3642156	et	3	main
ning	doc_740091151001_item	3642155	et	3	main
iseseisvus	doc_740091151001_item	3642154	et	4	main
naiste	doc_740091151001_item	3642153	et	3	main
suurenenud	doc_740091151001_item	3642152	et	4	main
tänu	doc_740091151001_item	3642147	et	4	main
naiste	doc_740091151001_item	3642141	et	3	main
palju	doc_740091151001_item	3642132	et	4	main
kindlasti	doc_740091151001_item	3642131	et	3	main
muutumine	doc_740091151001_item	3642128	et	4	main
naiste	doc_740091151001_item	3642126	et	3	main
ka	doc_740091151001_item	3642125	et	3	main
poolt	doc_740091151001_item	3642121	et	4	main
olulisemaks	doc_740091151001_item	3642109	et	4	main
julgelt	doc_740091151001_item	3641918	et	4	main
kannavad	doc_740091151001_item	3641917	et	3	main
mehed	doc_740091151001_item	3641916	et	3	main
ja	doc_740091151001_item	3641911	et	3	main
paigas	doc_740091151001_item	3641890	et	4	main
oma	doc_740091151001_item	3642095	et	4	main
mängukaaslane	doc_740091151001_item	3642082	et	3	main
autoriteet	doc_740091151001_item	3642079	et	3	main
olema	doc_740091151001_item	3642077	et	4	main
ühel	doc_740091151001_item	3642075	et	3	main
ja	doc_740091151000_item	3641331	et	3	main
ei	doc_740091151000_item	3641328	et	4	main
see	doc_740091151000_item	3641327	et	3	main
sealt	doc_740091151000_item	3641325	et	4	main
osa	doc_740091151000_item	3641321	et	4	main
suur	doc_740091151000_item	3641320	et	3	main
ning	doc_740091151000_item	3641319	et	3	main
tehnoloogiamaailm	doc_740091151000_item	3641311	et	3	main
intentiteetidega	doc_740091151000_item	3641307	et	4	main
või	doc_740091151000_item	3641306	et	4	main
ka	doc_740091151000_item	3641302	et	3	main
vahetatakse	doc_740091151000_item	3641299	et	3	main
nüüd	doc_740091151001_item	3642372	et	4	main
on	doc_740091151001_item	3642371	et	4	main
meestel	doc_740091151001_item	3642370	et	4	main
indiviidina	doc_740091151001_item	3642369	et	3	main
least	doc_740091151001_item	3642368	et	4	main
not	doc_740091151001_item	3642367	et	4	main
but	doc_740091151001_item	3642366	et	4	main
last	doc_740091151001_item	3642365	et	4	main
veeta	doc_740091151001_item	3642364	et	4	main
lähedastega	doc_740091151001_item	3642363	et	3	main
oma	doc_740091151001_item	3642362	et	4	main
aega	doc_740091151001_item	3642361	et	4	main
oma	doc_740091151001_item	3642360	et	4	main
hakanud	doc_740091151001_item	3642359	et	4	main
on	doc_740091151001_item	3642358	et	4	main
mehed	doc_740091151001_item	3642357	et	3	main
töötada	doc_740091151001_item	3642356	et	3	main
väljendamisel	doc_740091151001_item	3642384	et	4	main
mõtete	doc_740091151001_item	3642383	et	3	main
ja	doc_740091151001_item	3642382	et	3	main
tunnete	doc_740091151001_item	3642381	et	4	main
oma	doc_740091151001_item	3642380	et	4	main
julgemad	doc_740091151001_item	3642379	et	4	main
ja	doc_740091151001_item	3642378	et	3	main
pea	doc_740091151001_item	3642348	et	4	main
töötajana	doc_740091151001_item	3642345	et	4	main
võrdne	doc_740091151001_item	3642342	et	3	main
peremees	doc_740091151001_item	3642337	et	4	main
tegelemiseks	doc_740091151001_item	3642329	et	4	main
ainult	doc_740091151001_item	3642320	et	4	main
olema	doc_740091151001_item	3642319	et	4	main
kahekümne	doc_740091151001_item	3642306	et	4	main
ja	doc_740091151001_item	3642303	et	3	main
valikute	doc_740091151001_item	3642297	et	4	main
mis	doc_740091151001_item	3642284	et	4	main
kompromisse	doc_740091151001_item	3642283	et	3	main
leida	doc_740091151001_item	3642282	et	3	main
eelistatakse	doc_740091151001_item	3642281	et	3	main
tänapäeval	doc_740091151001_item	3642280	et	3	main
peremehena	doc_740091151001_item	3642279	et	3	main
ka	doc_740091151001_item	3642278	et	3	main
kui	doc_740091151001_item	3642277	et	3	main
isana	doc_740091151001_item	3642276	et	3	main
nii	doc_740091151001_item	3642275	et	3	main
mees	doc_740091151001_item	3642274	et	4	main
pooleks	doc_740091151001_item	3642273	et	4	main
kodus	doc_740091151001_item	3642271	et	4	main
oli	doc_740091151001_item	3642270	et	3	main
paarkümmend	doc_740091151001_item	3642267	et	4	main
palgatõusu	doc_740091151001_item	3642266	et	4	main
ka	doc_740091151001_item	3642265	et	3	main
ja	doc_740091151001_item	3642264	et	3	main
ametikõrgenduse	doc_740091151001_item	3642263	et	3	main
hiljem	doc_740091151001_item	3642262	et	3	main
saab	doc_740091151001_item	3642261	et	3	main
see	doc_740091151001_item	3642257	et	3	main
jääda	doc_740091151001_item	3642250	et	4	main
koju	doc_740091151001_item	3642249	et	3	main
on	doc_740091151001_item	3642248	et	4	main
situatsioon	doc_740091151001_item	3642241	et	3	main
nüüd	doc_740091151001_item	3642239	et	4	main
vanematele	doc_740091151001_item	3642230	et	4	main
jääb	doc_740091151001_item	3642206	et	3	main
kui	doc_740091151001_item	3642204	et	3	main
leidnud	doc_740091151001_item	3642198	et	4	main
aga	doc_740091151001_item	3642191	et	3	main
kasvatada	doc_740091151001_item	3642187	et	3	main
hoolitseda	doc_740091151001_item	3642184	et	3	main
vabatahtlikult	doc_740091151001_item	3642178	et	4	main
olnud	doc_740091151001_item	3642176	et	4	main
üksikud	doc_740091151001_item	3642174	et	3	main
initsiatiivi	doc_740091151001_item	3642326	et	4	main
oodatakse	doc_740091151001_item	3642325	et	3	main
temalt	doc_740091151001_item	3642324	et	3	main
vaid	doc_740091151001_item	3642323	et	3	main
pea	doc_740091151001_item	3642318	et	4	main
meeste	doc_740091151001_item	3642309	et	4	main
eelistuste	doc_740091151001_item	3642299	et	4	main
ja	doc_740091151001_item	3642298	et	3	main
aastaid	doc_740091151001_item	3642292	et	4	main
naisele	doc_740091151001_item	3642291	et	3	main
mehele	doc_740091151001_item	3642288	et	3	main
vastuvõetavad	doc_740091151001_item	3642286	et	3	main
vähem	doc_740091151001_item	3642260	et	4	main
kes	doc_740091151001_item	3642252	et	4	main
mõned	doc_740091151001_item	3642244	et	3	main
on	doc_740091151001_item	3642240	et	4	main
mitmed	doc_740091151001_item	3642237	et	4	main
hoopiski	doc_740091151001_item	3642236	et	3	main
tegelikkuses	doc_740091151001_item	3642234	et	4	main
mida	doc_740091151001_item	3642233	et	4	main
emapalk	doc_740091151001_item	3642232	et	3	main
lapsepuhkusele	doc_740091151001_item	3642205	et	4	main
kasulikum	doc_740091151001_item	3642203	et	4	main
majanduslikult	doc_740091151001_item	3642202	et	4	main
lapsevanemad	doc_740091151001_item	3642196	et	4	main
tänapäeval	doc_740091151001_item	3642188	et	3	main
koju	doc_740091151001_item	3642179	et	3	main
väga	doc_740091151001_item	3642173	et	3	main
oma	doc_740091151001_item	3642161	et	4	main
on	doc_740091151001_item	3642151	et	4	main
õiguseid	doc_740091151001_item	3642146	et	4	main
võrdseid	doc_740091151001_item	3642145	et	3	main
ning	doc_740091151001_item	3642144	et	3	main
feministlik	doc_740091151001_item	3642135	et	3	main
on	doc_740091151001_item	3642130	et	4	main
rolli	doc_740091151001_item	3642127	et	4	main
on	doc_740091151001_item	3642111	et	4	main
seda	doc_740091151001_item	3642110	et	3	main
mehed	doc_740091151001_item	3641930	et	3	main
varem	doc_740091151001_item	3641928	et	4	main
ja	doc_740091151001_item	3641921	et	3	main
pluusesid	doc_740091151001_item	3641920	et	4	main
mehed	doc_740091151001_item	3641912	et	3	main
hobisid	doc_740091151001_item	3641910	et	3	main
naised	doc_740091151001_item	3641907	et	3	main
muutunud	doc_740091151001_item	3641905	et	4	main
on	doc_740091151001_item	3641903	et	4	main
teistele	doc_740091151001_item	3641900	et	4	main
ning	doc_740091151001_item	3641899	et	3	main
loomulik	doc_740091151001_item	3641898	et	3	main
ja	doc_740091151001_item	3641897	et	3	main
lubatud	doc_740091151001_item	3641896	et	4	main
ja	doc_740091151001_item	3641886	et	3	main
roll	doc_740091151001_item	3641876	et	3	main
rohkem	doc_740091151001_item	3642373	et	4	main
nüüdisajal	doc_740091151001_item	3642102	et	3	main
nendega	doc_740091151001_item	3642094	et	4	main
ja	doc_740091151001_item	3642093	et	3	main
mängimine	doc_740091151001_item	3642092	et	4	main
lastega	doc_740091151001_item	3642091	et	3	main
osal	doc_740091151001_item	3642090	et	3	main
autoriteedi	doc_740091151001_item	3642089	et	3	main
just	doc_740091151001_item	3642088	et	3	main
tagasi	doc_740091151001_item	3642085	et	3	main
kui	doc_740091151001_item	3642080	et	3	main
mees	doc_740091151001_item	3642044	et	4	main
romantiline	doc_740091151001_item	3642043	et	3	main
kuid	doc_740091151001_item	3642039	et	4	main
abikaasa	doc_740091151001_item	3642036	et	4	main
ideaalne	doc_740091151001_item	3642035	et	3	main
tegema	doc_740091151001_item	3642026	et	3	main
kes	doc_740091151001_item	3642024	et	4	main
varem	doc_740091151001_item	3642015	et	4	main
suhtumisega	doc_740091151001_item	3641996	et	4	main
skandaaliga	doc_740091151001_item	3641990	et	3	main
seegi	doc_740091151001_item	3641973	et	4	main
näitab	doc_740091151001_item	3641972	et	3	main
avalikustamine	doc_740091151001_item	3641964	et	4	main
eelistusi	doc_740091151001_item	3641961	et	4	main
unustatakse	doc_740091151005_item	3642762	et	3	main
kui	doc_740091151005_item	3642756	et	3	main
aastat	doc_740091151001_item	3642268	et	3	main
kes	doc_740091151001_item	3642258	et	4	main
et	doc_740091151001_item	3642256	et	3	main
mõeldud	doc_740091151001_item	3642231	et	4	main
vastsele	doc_740091151001_item	3642229	et	3	main
on	doc_740091151001_item	3642228	et	4	main
tänapäeval	doc_740091151001_item	3642227	et	3	main
töötamist	doc_740091151001_item	3642226	et	4	main
jätkas	doc_740091151001_item	3642225	et	3	main
naine	doc_740091151001_item	3642224	et	3	main
kui	doc_740091151001_item	3642223	et	3	main
kasulikum	doc_740091151001_item	3642222	et	4	main
perele	doc_740091151001_item	3642221	et	3	main
oli	doc_740091151001_item	3642220	et	3	main
seega	doc_740091151001_item	3642219	et	4	main
ning	doc_740091151001_item	3642218	et	3	main
suurem	doc_740091151001_item	3642217	et	4	main
oli	doc_740091151001_item	3642216	et	3	main
palk	doc_740091151001_item	3642215	et	3	main
naise	doc_740091151001_item	3642214	et	3	main
et	doc_740091151001_item	3642213	et	3	main
seetõttu	doc_740091151001_item	3642212	et	3	main
tagasi	doc_740091151001_item	3642211	et	3	main
mõned	doc_740091151001_item	3642209	et	3	main
aastad	doc_740091151001_item	3642210	et	3	main
mees	doc_740091151001_item	3642208	et	4	main
on	doc_740091151001_item	3642197	et	4	main
mitmed	doc_740091151001_item	3642195	et	4	main
haruldane	doc_740091151001_item	3642194	et	3	main
nõus	doc_740091151001_item	3642177	et	4	main
oleks	doc_740091151001_item	3642172	et	3	main
aastat	doc_740091151001_item	3642170	et	3	main
keskenduda	doc_740091151001_item	3642160	et	3	main
eelistavad	doc_740091151001_item	3642158	et	4	main
õiguste	doc_740091151001_item	3642149	et	4	main
oma	doc_740091151001_item	3642148	et	4	main
ja	doc_740091151001_item	3642140	et	3	main
nõuavad	doc_740091151001_item	3642138	et	4	main
soodustanud	doc_740091151001_item	3642124	et	4	main
seda	doc_740091151001_item	3642123	et	3	main
ühiskonnas	doc_740091151001_item	3642119	et	4	main
palju	doc_740091151001_item	3642108	et	4	main
muutunud	doc_740091151001_item	3642107	et	4	main
harrastada	doc_740091151001_item	3641934	et	3	main
niivõrd	doc_740091151001_item	3641931	et	3	main
käivad	doc_740091151001_item	3641926	et	4	main
naiselikke	doc_740091151001_item	3641913	et	3	main
mehelikke	doc_740091151001_item	3641909	et	3	main
piirid	doc_740091151001_item	3641904	et	3	main
kindlamalt	doc_740091151001_item	3641889	et	4	main
rollid	doc_740091151001_item	3641888	et	3	main
naiste	doc_740091151001_item	3641887	et	3	main
muutunud	doc_740091151001_item	3641877	et	4	main
on	doc_740091151001_item	3641874	et	4	main
essee	doc_740091151001_item	3641872	et	4	main
avatumad	doc_740091151001_item	3642377	et	4	main
on	doc_740091151001_item	3642376	et	4	main
nad	doc_740091151001_item	3642375	et	3	main
vabadust	doc_740091151001_item	3642374	et	4	main
muutunud	doc_740091151001_item	3642100	et	4	main
veetmine	doc_740091151001_item	3642098	et	4	main
vaba	doc_740091151001_item	3642096	et	4	main
rõhk	doc_740091151001_item	3642087	et	3	main
aastat	doc_740091151001_item	3642084	et	3	main
eeldatakse	doc_740091151001_item	3642048	et	3	main
armastav	doc_740091151001_item	3642046	et	4	main
ning	doc_740091151001_item	3642045	et	3	main
ja	doc_740091151001_item	3642042	et	3	main
pere	doc_740091151001_item	3642030	et	4	main
palju	doc_740091151001_item	3642027	et	4	main
kui	doc_740091151001_item	3642014	et	3	main
kiiremini	doc_740091151001_item	3642005	et	4	main
tunduvalt	doc_740091151001_item	3642004	et	4	main
lepitakse	doc_740091151001_item	3642003	et	3	main
sellega	doc_740091151001_item	3642002	et	3	main
kaotamisega	doc_740091151001_item	3641992	et	4	main
tunnistamine	doc_740091151001_item	3641988	et	4	main
homoseksuaalsuse	doc_740091151001_item	3641987	et	4	main
muutunud	doc_740091151001_item	3641981	et	4	main
ühiskonnas	doc_740091151001_item	3641977	et	4	main
roll	doc_740091151001_item	3641976	et	3	main
meeste	doc_740091151001_item	3641975	et	4	main
et	doc_740091151001_item	3641974	et	3	main
rõhutamine	doc_740091151001_item	3641966	et	4	main
ja	doc_740091151001_item	3641965	et	3	main
oma	doc_740091151001_item	3641962	et	4	main
ilmudes	doc_740091151005_item	3642761	et	3	main
esimeste	doc_740091151005_item	3642759	et	4	main
kurb	doc_740091151005_item	3642755	et	3	main
vahel	doc_740091151005_item	3642747	et	4	main
huvide	doc_740091151005_item	3642746	et	3	main
ühiskondlike	doc_740091151005_item	3642745	et	3	main
tajutav	doc_740091151005_item	3642741	et	4	main
et	doc_740091151005_item	3642739	et	3	main
ideaalis	doc_740091151005_item	3642732	et	3	main
see	doc_740091151005_item	3642730	et	3	main
oluline	doc_740091151005_item	3642726	et	4	main
kuid	doc_740091151005_item	3642719	et	4	main
juba	doc_740091151005_item	3642717	et	3	main
nad	doc_740091151005_item	3642716	et	3	main
on	doc_740091151005_item	3642715	et	4	main
motiive	doc_740091151005_item	3642710	et	3	main
erinev	doc_740091151005_item	3642698	et	4	main
kelle	doc_740091151005_item	3642690	et	4	main
põlvkond	doc_740091151005_item	3642689	et	3	main
oluline	doc_740091151005_item	3642681	et	4	main
tagasi	doc_740091151001_item	3642171	et	3	main
luua	doc_740091151001_item	3642168	et	4	main
alles	doc_740091151001_item	3642165	et	3	main
soovivad	doc_740091151001_item	3642164	et	4	main
ning	doc_740091151001_item	3642163	et	3	main
karjäärile	doc_740091151001_item	3642162	et	3	main
teadmisele	doc_740091151001_item	3642150	et	4	main
kohtumist	doc_740091151001_item	3642143	et	4	main
aidanud	doc_740091151001_item	3642134	et	4	main
kaasa	doc_740091151001_item	3642133	et	4	main
on	doc_740091151001_item	3642122	et	4	main
kui	doc_740091151001_item	3642117	et	3	main
nii	doc_740091151001_item	3642115	et	3	main
söandanud	doc_740091151001_item	3641935	et	4	main
naiselikke	doc_740091151001_item	3641932	et	3	main
roosasid	doc_740091151001_item	3641919	et	4	main
tänapäeva	doc_740091151001_item	3641914	et	4	main
harrastavad	doc_740091151001_item	3641908	et	4	main
hägusamaks	doc_740091151001_item	3641906	et	4	main
praeguseks	doc_740091151001_item	3641902	et	3	main
mitte	doc_740091151001_item	3641901	et	3	main
selge	doc_740091151001_item	3641892	et	4	main
oli	doc_740091151001_item	3641891	et	3	main
paarkümmend	doc_740091151001_item	3641881	et	4	main
aastaga	doc_740091151001_item	3641880	et	3	main
20	doc_740091151001_item	3641879	et	2	main
viimase	doc_740091151001_item	3641878	et	3	main
olulisemkas	doc_740091151001_item	3642101	et	4	main
ka	doc_740091151001_item	3642081	et	3	main
lapsevanem	doc_740091151001_item	3642047	et	4	main
tänapäeval	doc_740091151001_item	3642033	et	3	main
siis	doc_740091151001_item	3642032	et	3	main
elatamiseks	doc_740091151001_item	3642031	et	4	main
pereisa	doc_740091151001_item	3642023	et	4	main
suhtes	doc_740091151001_item	3642013	et	4	main
muutunud	doc_740091151001_item	3642006	et	4	main
halvustava	doc_740091151001_item	3641995	et	4	main
sõprade	doc_740091151001_item	3641994	et	3	main
ning	doc_740091151001_item	3641993	et	3	main
võinud	doc_740091151001_item	3641986	et	4	main
oleks	doc_740091151001_item	3641985	et	3	main
tagasi	doc_740091151001_item	3641984	et	3	main
aastat	doc_740091151001_item	3641983	et	3	main
on	doc_740091151001_item	3641980	et	4	main
ja	doc_740091151001_item	3641978	et	3	main
küll	doc_740091151001_item	3641969	et	4	main
omane	doc_740091151001_item	3641968	et	3	main
pole	doc_740091151001_item	3641967	et	3	main
esialgsed	doc_740091151005_item	3642757	et	3	main
äri-	doc_740091151005_item	3642743	et	4	main
kujundada	doc_740091151005_item	3642737	et	3	main
ning	doc_740091151005_item	3642734	et	3	main
see	doc_740091151005_item	3642728	et	3	main
kõrval	doc_740091151005_item	3642724	et	4	main
korporatiivse	doc_740091151005_item	3642721	et	4	main
hetkel	doc_740091151005_item	3642714	et	4	main
ning	doc_740091151005_item	3642699	et	3	main
senisest	doc_740091151005_item	3642697	et	3	main
kohanenud	doc_740091151005_item	3642688	et	4	main
infoühiskonnaga	doc_740091151005_item	3642687	et	4	main
uus	doc_740091151005_item	3642686	et	3	main
kasvamas	doc_740091151005_item	3642685	et	3	main
katsetada	doc_740091151005_item	3642610	et	3	main
tõestada	doc_740091151005_item	3642608	et	3	main
identiteet	doc_740091151005_item	3642588	et	4	main
toetab	doc_740091151005_item	3642584	et	3	main
kuhugi	doc_740091151005_item	3642581	et	4	main
heast	doc_740091151005_item	3642579	et	3	main
teeniksid	doc_740091151005_item	3642567	et	4	main
laiem	doc_740091151005_item	3642555	et	4	main
ka	doc_740091151005_item	3642554	et	3	main
olema	doc_740091151005_item	3642553	et	4	main
kuvandit	doc_740091151005_item	3642547	et	3	main
on	doc_740091151005_item	3642544	et	4	main
kui	doc_740091151005_item	3642532	et	3	main
võimalike	doc_740091151005_item	3642530	et	4	main
võitlevad	doc_740091151005_item	3642526	et	4	main
aina	doc_740091151005_item	3642523	et	4	main
on	doc_740091151005_item	3642522	et	4	main
palju	doc_740091151005_item	3642517	et	4	main
tekib	doc_740091151005_item	3642516	et	3	main
suhtlus-situatsioonis	doc_740091151005_item	3642515	et	3	main
oluline	doc_740091151005_item	3642491	et	4	main
see	doc_740091151005_item	3642489	et	3	main
liikumine	doc_740091151001_item	3642136	et	4	main
millele	doc_740091151001_item	3642129	et	3	main
ühelt	doc_740091151001_item	3642120	et	3	main
ka	doc_740091151001_item	3642118	et	3	main
peresiseselt	doc_740091151001_item	3642116	et	4	main
rohkem	doc_740091151001_item	3642114	et	4	main
väärtustama	doc_740091151001_item	3642113	et	3	main
hakatud	doc_740091151001_item	3642112	et	4	main
on	doc_740091151001_item	3642106	et	4	main
isana	doc_740091151001_item	3642105	et	3	main
roll	doc_740091151001_item	3642104	et	3	main
mehe	doc_740091151001_item	3642103	et	3	main
tegevusi	doc_740091151001_item	3641933	et	4	main
poleks	doc_740091151001_item	3641929	et	3	main
solaariumis	doc_740091151001_item	3641927	et	3	main
ning	doc_740091151001_item	3641925	et	3	main
juukseid	doc_740091151001_item	3641924	et	3	main
värvivad	doc_740091151001_item	3641923	et	4	main
lipse	doc_740091151001_item	3641922	et	3	main
trendikad	doc_740091151001_item	3641915	et	4	main
ühtedele	doc_740091151001_item	3641895	et	4	main
on	doc_740091151001_item	3641894	et	4	main
mis	doc_740091151001_item	3641893	et	4	main
meeste	doc_740091151001_item	3641885	et	4	main
olid	doc_740091151001_item	3641884	et	4	main
tagasi	doc_740091151001_item	3641883	et	3	main
aastat	doc_740091151001_item	3641882	et	3	main
mehe	doc_740091151001_item	3641875	et	3	main
kuidas	doc_740091151001_item	3641873	et	3	main
on	doc_740091151001_item	3642099	et	4	main
aja	doc_740091151001_item	3642097	et	4	main
oli	doc_740091151001_item	3642086	et	3	main
paarkümmend	doc_740091151001_item	3642083	et	4	main
nii	doc_740091151001_item	3642078	et	3	main
ajal	doc_740091151001_item	3642076	et	4	main
mees	doc_740091151001_item	3642074	et	4	main
peab	doc_740091151001_item	3642073	et	4	main
seega	doc_740091151001_item	3642072	et	4	main
isa	doc_740091151001_item	3642071	et	4	main
tore	doc_740091151001_item	3642070	et	3	main
ning	doc_740091151001_item	3642069	et	3	main
hoolitsev	doc_740091151001_item	3642068	et	4	main
jälle	doc_740091151001_item	3642067	et	3	main
samas	doc_740091151001_item	3642066	et	4	main
otsustav	doc_740091151001_item	3642065	et	4	main
ja	doc_740091151001_item	3642064	et	3	main
range	doc_740091151001_item	3642063	et	4	main
lastega	doc_740091151001_item	3642062	et	3	main
olema	doc_740091151001_item	3642061	et	4	main
peab	doc_740091151001_item	3642060	et	4	main
vajadusel	doc_740091151001_item	3642059	et	3	main
reageerida	doc_740091151001_item	3642058	et	3	main
ja	doc_740091151001_item	3642057	et	3	main
käituda	doc_740091151001_item	3642056	et	3	main
õigesti	doc_740091151001_item	3642055	et	3	main
situatsioonis	doc_740091151001_item	3642054	et	3	main
igas	doc_740091151001_item	3642053	et	3	main
oskab	doc_740091151001_item	3642051	et	3	main
alati	doc_740091151001_item	3642052	et	4	main
mees	doc_740091151001_item	3642050	et	4	main
et	doc_740091151001_item	3642049	et	3	main
tundeline	doc_740091151001_item	3642041	et	4	main
töökas	doc_740091151001_item	3642038	et	4	main
oma	doc_740091151001_item	3642029	et	4	main
lapsevanem	doc_740091151001_item	3642020	et	4	main
range	doc_740091151001_item	3642019	et	4	main
olema	doc_740091151001_item	3642018	et	4	main
mees	doc_740091151001_item	3642017	et	4	main
abikaasa	doc_740091151001_item	3642012	et	4	main
tulevase	doc_740091151001_item	3642011	et	4	main
ootused	doc_740091151001_item	3642010	et	3	main
naiste	doc_740091151001_item	3642009	et	3	main
ka	doc_740091151001_item	3642008	et	3	main
tavalisem	doc_740091151001_item	3642000	et	4	main
see	doc_740091151001_item	3641999	et	3	main
on	doc_740091151001_item	3641998	et	4	main
ka	doc_740091151001_item	3642040	et	3	main
kindlasti	doc_740091151001_item	3642037	et	3	main
on	doc_740091151001_item	3642034	et	4	main
ületunde	doc_740091151001_item	3642028	et	4	main
pidi	doc_740091151001_item	3642025	et	4	main
töökas	doc_740091151001_item	3642022	et	4	main
ja	doc_740091151001_item	3642021	et	3	main
pidi	doc_740091151001_item	3642016	et	4	main
on	doc_740091151001_item	3642007	et	4	main
ning	doc_740091151001_item	3642001	et	3	main
kuid	doc_740091151001_item	3641971	et	4	main
oma	doc_740091151001_item	3641959	et	4	main
tunnistada	doc_740091151001_item	3641958	et	3	main
julgus	doc_740091151001_item	3641957	et	4	main
vähemusgrupi	doc_740091151001_item	3641956	et	3	main
meeste	doc_740091151001_item	3641955	et	4	main
homoseksuaalsete	doc_740091151001_item	3641954	et	3	main
ka	doc_740091151001_item	3641953	et	3	main
näitab	doc_740091151001_item	3641952	et	3	main
suundumust	doc_740091151001_item	3641951	et	4	main
seda	doc_740091151001_item	3641950	et	3	main
julgemaks	doc_740091151001_item	3641949	et	4	main
tunduvalt	doc_740091151001_item	3641948	et	4	main
ning	doc_740091151001_item	3641947	et	3	main
vabamaks	doc_740091151001_item	3641946	et	4	main
mõttemaailm	doc_740091151001_item	3641944	et	3	main
ja	doc_740091151001_item	3641943	et	3	main
muutunud	doc_740091151001_item	3641945	et	4	main
käitumine	doc_740091151001_item	3641942	et	4	main
meeste	doc_740091151001_item	3641941	et	4	main
on	doc_740091151001_item	3641940	et	4	main
seega	doc_740091151001_item	3641939	et	4	main
tunnistanud	doc_740091151001_item	3641938	et	4	main
vähem	doc_740091151001_item	3641937	et	4	main
veel	doc_740091151001_item	3641936	et	4	main
kasuminumbrite	doc_740091151005_item	3642760	et	3	main
eetevõtte	doc_740091151005_item	3642753	et	4	main
ideest	doc_740091151005_item	3642752	et	4	main
algsest	doc_740091151005_item	3642751	et	3	main
ja	doc_740091151005_item	3642744	et	3	main
seda	doc_740091151005_item	3642736	et	3	main
on	doc_740091151005_item	3642725	et	4	main
vajalikkusest	doc_740091151005_item	3642723	et	4	main
identiteedi	doc_740091151005_item	3642722	et	4	main
otsustanud	doc_740091151005_item	3642718	et	4	main
hetkega	doc_740091151005_item	3642711	et	3	main
nemad	doc_740091151005_item	3642703	et	3	main
lähenemisnurki	doc_740091151005_item	3642702	et	4	main
uusi	doc_740091151005_item	3642701	et	3	main
vajab	doc_740091151005_item	3642700	et	3	main
teaba	doc_740091151005_item	3642691	et	4	main
taibata	doc_740091151005_item	3642682	et	4	main
aitab	doc_740091151005_item	3642589	et	3	main
samasid	doc_740091151005_item	3642585	et	3	main
sooviksime	doc_740091151005_item	3642575	et	4	main
ju	doc_740091151005_item	3642574	et	3	main
mis	doc_740091151005_item	3642566	et	4	main
tänapäeval	doc_740091151001_item	3641997	et	3	main
töökoha	doc_740091151001_item	3641991	et	4	main
lõppeda	doc_740091151001_item	3641989	et	3	main
paarkümmend	doc_740091151001_item	3641982	et	4	main
peremudelis	doc_740091151001_item	3641979	et	3	main
kõikidele	doc_740091151001_item	3641970	et	4	main
orientatsiooni	doc_740091151001_item	3641963	et	4	main
seksuaalseid	doc_740091151001_item	3641960	et	3	main
visioonid	doc_740091151005_item	3642758	et	3	main
kõik	doc_740091151005_item	3642748	et	4	main
piir	doc_740091151005_item	3642742	et	3	main
oleks	doc_740091151005_item	3642740	et	3	main
nii	doc_740091151005_item	3642738	et	3	main
olla	doc_740091151005_item	3642733	et	3	main
milline	doc_740091151005_item	3642729	et	3	main
küsimuse	doc_740091151005_item	3642720	et	4	main
järgmisel	doc_740091151005_item	3642713	et	3	main
peituvaid	doc_740091151005_item	3642709	et	4	main
selle	doc_740091151005_item	3642707	et	4	main
ja	doc_740091151005_item	3642706	et	3	main
sõnumit	doc_740091151005_item	3642705	et	3	main
tajuvad	doc_740091151005_item	3642704	et	4	main
selekteerimise	doc_740091151005_item	3642692	et	4	main
on	doc_740091151005_item	3642684	et	4	main
et	doc_740091151005_item	3642683	et	3	main
oma	doc_740091151005_item	3642599	et	4	main
enamiku	doc_740091151005_item	3642598	et	3	main
iseend	doc_740091151005_item	3642597	et	3	main
ka	doc_740091151005_item	3642596	et	3	main
defineerida	doc_740091151005_item	3642595	et	3	main
kes	doc_740091151005_item	3642591	et	4	main
väärtuseid	doc_740091151005_item	3642586	et	3	main
kuuluda	doc_740091151005_item	3642580	et	4	main
millestki	doc_740091151005_item	3642578	et	4	main
osa	doc_740091151005_item	3642577	et	4	main
olla	doc_740091151005_item	3642576	et	3	main
ühiskonna	doc_740091151005_item	3642570	et	4	main
üldist	doc_740091151005_item	3642569	et	3	main
ka	doc_740091151005_item	3642568	et	3	main
raha	doc_740091151005_item	3642558	et	4	main
kui	doc_740091151005_item	3642557	et	3	main
eesmärk	doc_740091151005_item	3642556	et	3	main
ettevõtte	doc_740091151005_item	3642550	et	4	main
et	doc_740091151005_item	3642549	et	3	main
ning	doc_740091151005_item	3642548	et	3	main
vaja	doc_740091151005_item	3642545	et	4	main
pääsemiseks	doc_740091151005_item	3642543	et	4	main
pildile	doc_740091151005_item	3642542	et	3	main
et	doc_740091151005_item	3642541	et	3	main
teavad	doc_740091151005_item	3642540	et	3	main
nad	doc_740091151005_item	3642539	et	3	main
pärast	doc_740091151005_item	3642538	et	4	main
nii	doc_740091151005_item	3642527	et	3	main
välja	doc_740091151005_item	3642520	et	4	main
kust	doc_740091151005_item	3642519	et	4	main
aidata	doc_740091151005_item	3642476	et	4	main
eesmärgiga	doc_740091151005_item	3642475	et	3	main
luuakse	doc_740091151005_item	3642474	et	3	main
ja	doc_740091151005_item	3642473	et	3	main
identiteedil	doc_740091151005_item	3642465	et	4	main
korporatiivsel	doc_740091151005_item	3642462	et	4	main
tajuvad	doc_740091151005_item	3642461	et	4	main
ja	doc_740091151005_item	3642460	et	3	main
või	doc_740091151005_item	3642447	et	4	main
mis	doc_740091151005_item	3642443	et	4	main
suurkorporatsioon	doc_740091151005_item	3642436	et	3	main
riigiasutus	doc_740091151005_item	3642434	et	4	main
korporatiivne	doc_740091151005_item	3642388	et	4	main
essee	doc_740091151005_item	3642386	et	4	main
seisukohast	doc_740091151005_item	3642680	et	4	main
enda	doc_740091151005_item	3642666	et	4	main
defineerivad	doc_740091151005_item	3642657	et	4	main
inimese	doc_740091151005_item	3642647	et	4	main
kokkupuutuva	doc_740091151005_item	3642646	et	3	main
korporatsiooniga	doc_740091151005_item	3642645	et	3	main
teise	doc_740091151005_item	3642644	et	4	main
mõne	doc_740091151005_item	3642643	et	3	main
on	doc_740091151005_item	3642638	et	4	main
end	doc_740091151005_item	3642628	et	4	main
tunneme	doc_740091151005_item	3642627	et	3	main
keskkonnas	doc_740091151005_item	3642626	et	3	main
innustavas	doc_740091151005_item	3642625	et	4	main
ja	doc_740091151005_item	3642624	et	3	main
hoolivas	doc_740091151005_item	3642623	et	4	main
inimestest	doc_740091151005_item	3642622	et	3	main
kliimaga	doc_740091151005_item	3642621	et	3	main
kõik	doc_740091151005_item	3642614	et	4	main
ettevõtte	doc_740091151007_item	3643204	et	4	main
aluseks	doc_740091151007_item	3643195	et	4	main
loomisel	doc_740091151005_item	3642754	et	4	main
tahtest	doc_740091151005_item	3642750	et	4	main
algab	doc_740091151005_item	3642749	et	3	main
kuidas	doc_740091151005_item	3642735	et	3	main
võiks	doc_740091151005_item	3642731	et	4	main
ka	doc_740091151005_item	3642727	et	3	main
ning	doc_740091151005_item	3642712	et	3	main
taga	doc_740091151005_item	3642708	et	4	main
on	doc_740091151005_item	3642696	et	4	main
meetod	doc_740091151005_item	3642695	et	3	main
ja	doc_740091151005_item	3642694	et	3	main
võime	doc_740091151005_item	3642693	et	4	main
end	doc_740091151005_item	3642607	et	4	main
saame	doc_740091151005_item	3642606	et	4	main
kaudu	doc_740091151005_item	3642605	et	3	main
töö	doc_740091151005_item	3642604	et	4	main
tööl	doc_740091151005_item	3642603	et	3	main
veedame	doc_740091151005_item	3642602	et	3	main
ajast	doc_740091151005_item	3642601	et	4	main
ärkveloleku	doc_740091151005_item	3642600	et	3	main
selles	doc_740091151005_item	3642592	et	4	main
korporatiivne	doc_740091151005_item	3642587	et	4	main
mis	doc_740091151005_item	3642583	et	4	main
kõik	doc_740091151005_item	3642573	et	4	main
me	doc_740091151005_item	3642572	et	4	main
hindavad	doc_740091151005_item	3642564	et	4	main
meedia	doc_740091151005_item	3642563	et	4	main
ja	doc_740091151005_item	3642561	et	3	main
tarbijad	doc_740091151005_item	3642560	et	4	main
positiivset	doc_740091151005_item	3642546	et	3	main
tarbijate	doc_740091151005_item	3642528	et	4	main
organisatsioonid	doc_740091151005_item	3642525	et	3	main
ettevõttete	doc_740091151005_item	3642478	et	4	main
teenida	doc_740091151005_item	3642477	et	3	main
on	doc_740091151005_item	3642466	et	4	main
organisatsioonist	doc_740091151005_item	3642448	et	3	main
teeb	doc_740091151005_item	3642444	et	3	main
see	doc_740091151005_item	3642442	et	3	main
ongi	doc_740091151005_item	3642441	et	4	main
ta	doc_740091151005_item	3642431	et	4	main
olemust	doc_740091151005_item	3642392	et	3	main
teenuste	doc_740091151005_item	3642662	et	3	main
kaubamärkide	doc_740091151005_item	3642660	et	3	main
end	doc_740091151005_item	3642658	et	4	main
neid	doc_740091151005_item	3642655	et	4	main
nn	doc_740091151005_item	3642634	et	4	main
leida	doc_740091151005_item	3642633	et	3	main
positiivse	doc_740091151005_item	3642620	et	3	main
üldist	doc_740091151005_item	3642617	et	3	main
mõjutab	doc_740091151005_item	3642615	et	3	main
see	doc_740091151005_item	3642613	et	3	main
pandiks	doc_740091151007_item	3643206	et	4	main
arengule	doc_740091151007_item	3643198	et	3	main
ettevõtte	doc_740091151007_item	3643196	et	4	main
valdkonnaga	doc_740091151007_item	3643184	et	4	main
eelneva	doc_740091151007_item	3643174	et	4	main
suurima	doc_740091151007_item	3643166	et	4	main
vajalikke	doc_740091151007_item	3643144	et	3	main
tema	doc_740091151007_item	3643142	et	4	main
millised	doc_740091151007_item	3643141	et	3	main
kui	doc_740091151007_item	3643135	et	3	main
rahul	doc_740091151007_item	3643122	et	4	main
allika	doc_740091151007_item	3643108	et	3	main
suhelda	doc_740091151005_item	3642609	et	4	main
töötavad	doc_740091151005_item	3642594	et	4	main
korporatsioonis	doc_740091151005_item	3642593	et	3	main
inimestel	doc_740091151005_item	3642590	et	3	main
gruppi	doc_740091151005_item	3642582	et	4	main
huvi	doc_740091151005_item	3642571	et	4	main
ideid	doc_740091151005_item	3642565	et	3	main
peab	doc_740091151005_item	3642552	et	4	main
tegevusel	doc_740091151005_item	3642551	et	4	main
paista	doc_740091151005_item	3642521	et	4	main
pidevas	doc_740091151005_item	3642514	et	3	main
töödelda	doc_740091151005_item	3642513	et	4	main
ja	doc_740091151005_item	3642512	et	3	main
võtta	doc_740091151005_item	3642511	et	3	main
vastu	doc_740091151005_item	3642510	et	3	main
seda	doc_740091151005_item	3642509	et	3	main
võime	doc_740091151005_item	3642508	et	4	main
oluliselt	doc_740091151005_item	3642507	et	4	main
ületab	doc_740091151005_item	3642506	et	3	main
hulk	doc_740091151005_item	3642505	et	3	main
teabe	doc_740091151005_item	3642504	et	3	main
kus	doc_740091151005_item	3642503	et	3	main
infoühiskond	doc_740091151005_item	3642502	et	3	main
on	doc_740091151005_item	3642501	et	4	main
meil	doc_740091151005_item	3642500	et	4	main
alustala	doc_740091151005_item	3642499	et	4	main
ettevõttemajanduse	doc_740091151005_item	3642498	et	3	main
aga	doc_740091151005_item	3642497	et	3	main
on	doc_740091151005_item	3642496	et	4	main
viimane	doc_740091151005_item	3642495	et	3	main
teenimiseks	doc_740091151005_item	3642494	et	4	main
raha	doc_740091151005_item	3642493	et	4	main
vahend	doc_740091151005_item	3642492	et	3	main
on	doc_740091151005_item	3642490	et	4	main
vaja	doc_740091151005_item	3642486	et	4	main
milleks	doc_740091151005_item	3642484	et	4	main
põhjus	doc_740091151005_item	3642483	et	4	main
peamine	doc_740091151005_item	3642482	et	3	main
tulenebki	doc_740091151005_item	3642481	et	3	main
siit	doc_740091151005_item	3642480	et	3	main
kasumit	doc_740091151005_item	3642479	et	3	main
erinevus	doc_740091151005_item	3642469	et	4	main
suur	doc_740091151005_item	3642468	et	3	main
üks	doc_740091151005_item	3642467	et	3	main
näevad	doc_740091151005_item	3642459	et	3	main
ka	doc_740091151005_item	3642456	et	3	main
ning	doc_740091151005_item	3642454	et	3	main
sellise	doc_740091151005_item	3642450	et	4	main
just	doc_740091151005_item	3642449	et	3	main
olgu	doc_740091151005_item	3642430	et	3	main
ja	doc_740091151005_item	3642427	et	3	main
ning	doc_740091151005_item	3642425	et	3	main
on	doc_740091151005_item	3642678	et	4	main
ka	doc_740091151005_item	3642562	et	3	main
teenimine	doc_740091151005_item	3642559	et	4	main
tähelepanu	doc_740091151005_item	3642537	et	4	main
võimuorganite	doc_740091151005_item	3642536	et	3	main
ja	doc_740091151005_item	3642535	et	3	main
meedia	doc_740091151005_item	3642534	et	4	main
ka	doc_740091151005_item	3642533	et	3	main
partnerite	doc_740091151005_item	3642531	et	3	main
ja	doc_740091151005_item	3642529	et	3	main
keerulisem	doc_740091151005_item	3642524	et	4	main
infomüra	doc_740091151005_item	3642518	et	4	main
korporatiivset	doc_740091151005_item	3642487	et	4	main
kujundatakse	doc_740091151005_item	3642472	et	3	main
isiku	doc_740091151005_item	3642464	et	3	main
ja	doc_740091151005_item	3642463	et	3	main
kõrvaltvaatajad	doc_740091151005_item	3642457	et	3	main
identiteet	doc_740091151005_item	3642440	et	4	main
samuti	doc_740091151005_item	3642439	et	3	main
mtü	doc_740091151005_item	3642433	et	4	main
väikeettevõte	doc_740091151005_item	3642432	et	3	main
teadmised	doc_740091151005_item	3642428	et	4	main
oskused	doc_740091151005_item	3642426	et	3	main
välimus	doc_740091151005_item	3642422	et	3	main
ka	doc_740091151005_item	3642421	et	3	main
harjumused	doc_740091151005_item	3642420	et	4	main
väärtushinnangud	doc_740091151005_item	3642419	et	3	main
põhimõtted	doc_740091151005_item	3642418	et	3	main
kahtlemata	doc_740091151005_item	3642417	et	4	main
hulgas	doc_740091151005_item	3642416	et	4	main
muu	doc_740091151005_item	3642415	et	4	main
on	doc_740091151005_item	3642414	et	4	main
komponentideks	doc_740091151005_item	3642413	et	3	main
olemuse	doc_740091151005_item	3642412	et	3	main
meist	doc_740091151005_item	3642411	et	3	main
kuvandist	doc_740091151005_item	3642410	et	3	main
teiste	doc_740091151005_item	3642409	et	4	main
ning	doc_740091151005_item	3642408	et	3	main
näha	doc_740091151005_item	3642407	et	3	main
end	doc_740091151005_item	3642406	et	4	main
tahaksime	doc_740091151005_item	3642405	et	3	main
millisena	doc_740091151005_item	3642404	et	3	main
soovist	doc_740091151005_item	3642403	et	4	main
iseendast	doc_740091151005_item	3642402	et	3	main
nägemusest	doc_740091151005_item	3642401	et	4	main
meie	doc_740091151005_item	3642400	et	4	main
segu	doc_740091151005_item	3642399	et	4	main
on	doc_740091151005_item	3642398	et	4	main
see	doc_740091151005_item	3642397	et	3	main
defineerime	doc_740091151005_item	3642396	et	3	main
end	doc_740091151005_item	3642395	et	4	main
kuidas	doc_740091151005_item	3642394	et	3	main
seda	doc_740091151005_item	3642393	et	3	main
identiteet	doc_740091151005_item	3642389	et	4	main
ettevõttest	doc_740091151005_item	3642650	et	4	main
tarbija	doc_740091151005_item	3642640	et	4	main
oluline	doc_740091151005_item	3642637	et	4	main
oma	doc_740091151005_item	3642635	et	4	main
mina-pilti	doc_740091151005_item	3642618	et	4	main
identiteeti	doc_740091151005_item	3642488	et	4	main
on	doc_740091151005_item	3642485	et	4	main
identiteeti	doc_740091151005_item	3642471	et	4	main
organisatsiooni	doc_740091151005_item	3642470	et	4	main
teda	doc_740091151005_item	3642458	et	4	main
millisena	doc_740091151005_item	3642455	et	3	main
on	doc_740091151005_item	3642453	et	4	main
ta	doc_740091151005_item	3642452	et	4	main
nagu	doc_740091151005_item	3642451	et	3	main
inimesest	doc_740091151005_item	3642446	et	3	main
ühest	doc_740091151005_item	3642445	et	4	main
on	doc_740091151005_item	3642438	et	4	main
puhul	doc_740091151005_item	3642437	et	4	main
või	doc_740091151005_item	3642435	et	4	main
organisatsioonide	doc_740091151005_item	3642429	et	3	main
käitumismallid	doc_740091151005_item	3642424	et	3	main
iseloomuomadused	doc_740091151005_item	3642423	et	4	main
identiteet	doc_740091151005_item	3642390	et	4	main
selline	doc_740091151005_item	3642665	et	4	main
toodete	doc_740091151005_item	3642664	et	3	main
ja	doc_740091151005_item	3642663	et	3	main
ettevõtete	doc_740091151005_item	3642661	et	3	main
kes	doc_740091151005_item	3642656	et	4	main
palju	doc_740091151005_item	3642654	et	4	main
on	doc_740091151005_item	3642653	et	4	main
iseendast	doc_740091151005_item	3642652	et	3	main
ja	doc_740091151005_item	3642651	et	3	main
ka	doc_740091151005_item	3642642	et	3	main
või	doc_740091151005_item	3642641	et	4	main
meil	doc_740091151005_item	3642632	et	4	main
aitab	doc_740091151005_item	3642631	et	3	main
see	doc_740091151005_item	3642630	et	3	main
hästi	doc_740091151005_item	3642629	et	3	main
töötades	doc_740091151005_item	3642619	et	3	main
enesehinnangut	doc_740091151005_item	3642616	et	3	main
piire	doc_740091151005_item	3642612	et	4	main
võimete	doc_740091151005_item	3642611	et	4	main
identiteeti	doc_740091151007_item	3643202	et	4	main
korporatiivset	doc_740091151007_item	3643201	et	4	main
seega	doc_740091151007_item	3643199	et	4	main
põhjal	doc_740091151007_item	3643176	et	4	main
samas	doc_740091151007_item	3643173	et	4	main
tegevus	doc_740091151007_item	3643168	et	4	main
muudatusi	doc_740091151007_item	3643145	et	3	main
jaoks	doc_740091151007_item	3643143	et	4	main
kohta	doc_740091151007_item	3643140	et	4	main
mugavas	doc_740091151007_item	3643132	et	3	main
teed	doc_740091151007_item	3643131	et	4	main
ja	doc_740091151007_item	3643121	et	3	main
nad	doc_740091151007_item	3643118	et	3	main
on	doc_740091151007_item	3643117	et	4	main
teemal	doc_740091151007_item	3643112	et	3	main
rahakulutuse	doc_740091151007_item	3643111	et	4	main
ühe	doc_740091151007_item	3643103	et	4	main
süüvudes	doc_740091151007_item	3643086	et	4	main
hinnata	doc_740091151007_item	3643011	et	4	main
nüüd	doc_740091151007_item	3643010	et	4	main
kui	doc_740091151007_item	3643009	et	3	main
tegeleb	doc_740091151007_item	3643008	et	3	main
millega	doc_740091151007_item	3643007	et	3	main
organisatsiooni	doc_740091151007_item	3642995	et	4	main
on	doc_740091151007_item	3642992	et	4	main
väljaspool	doc_740091151007_item	3642989	et	3	main
või	doc_740091151007_item	3642983	et	4	main
osa	doc_740091151007_item	3642969	et	4	main
näo	doc_740091151007_item	3642966	et	3	main
tugevad	doc_740091151007_item	3642964	et	4	main
osas	doc_740091151007_item	3642963	et	4	main
suures	doc_740091151007_item	3642962	et	3	main
ei	doc_740091151007_item	3642951	et	4	main
ära	doc_740091151007_item	3642950	et	4	main
kliendile	doc_740091151007_item	3642943	et	3	main
visuaalse	doc_740091151007_item	3642939	et	3	main
tähendab	doc_740091151005_item	3642391	et	3	main
milleks	doc_740091151005_item	3642387	et	4	main
ettevõtluse	doc_740091151005_item	3642679	et	3	main
siinkohal	doc_740091151005_item	3642677	et	3	main
puhul	doc_740091151005_item	3642676	et	4	main
teismeliste	doc_740091151005_item	3642675	et	3	main
nt	doc_740091151005_item	3642674	et	4	main
silma	doc_740091151005_item	3642673	et	4	main
hästi	doc_740091151005_item	3642672	et	3	main
torkab	doc_740091151005_item	3642671	et	3	main
maailma	doc_740091151005_item	3642670	et	4	main
ümbritseva	doc_740091151005_item	3642669	et	4	main
läbi	doc_740091151005_item	3642668	et	4	main
otsimine	doc_740091151005_item	3642667	et	4	main
läbi	doc_740091151005_item	3642659	et	4	main
sellest	doc_740091151005_item	3642649	et	4	main
nägemus	doc_740091151005_item	3642648	et	3	main
ka	doc_740091151005_item	3642639	et	3	main
kohta	doc_740091151005_item	3642636	et	4	main
edu	doc_740091151007_item	3643205	et	4	main
omakorda	doc_740091151007_item	3643194	et	3	main
on	doc_740091151007_item	3643193	et	4	main
eesmärgid	doc_740091151007_item	3643191	et	3	main
ühised	doc_740091151007_item	3643190	et	3	main
defineerib	doc_740091151007_item	3643189	et	3	main
ja	doc_740091151007_item	3643188	et	3	main
ühtekuuluvuse	doc_740091151007_item	3643187	et	4	main
tagab	doc_740091151007_item	3643186	et	3	main
see	doc_740091151007_item	3643185	et	3	main
tegemist	doc_740091151007_item	3643180	et	4	main
et	doc_740091151007_item	3643179	et	3	main
järeldusele	doc_740091151007_item	3643178	et	4	main
jõuame	doc_740091151007_item	3643177	et	3	main
arendamisel	doc_740091151007_item	3643172	et	4	main
ettevõtte	doc_740091151007_item	3643169	et	4	main
kui	doc_740091151007_item	3643165	et	3	main
selle	doc_740091151007_item	3643139	et	4	main
kiri	doc_740091151007_item	3643138	et	3	main
saabub	doc_740091151007_item	3643137	et	3	main
koju	doc_740091151007_item	3643136	et	3	main
istet	doc_740091151007_item	3643125	et	4	main
pakutakse	doc_740091151007_item	3643124	et	3	main
kui	doc_740091151007_item	3643123	et	3	main
ilu	doc_740091151007_item	3643107	et	4	main
osad	doc_740091151007_item	3643093	et	3	main
tunduvad	doc_740091151007_item	3643091	et	4	main
ettevõtte	doc_740091151007_item	3643012	et	4	main
iganes	doc_740091151007_item	3643004	et	4	main
kus	doc_740091151007_item	3643002	et	3	main
töötaja	doc_740091151007_item	3642994	et	4	main
ei	doc_740091151007_item	3642987	et	4	main
täpsemalt	doc_740091151007_item	3642985	et	4	main
siis	doc_740091151007_item	3642984	et	3	main
käitumist	doc_740091151007_item	3642980	et	4	main
kliendidega	doc_740091151007_item	3642979	et	4	main
ja	doc_740091151007_item	3642978	et	3	main
kandmisega	doc_740091151007_item	3642974	et	4	main
algab	doc_740091151007_item	3642972	et	3	main
kandmisel	doc_740091151007_item	3642971	et	4	main
identiteedi	doc_740091151007_item	3642970	et	4	main
kujundamisel	doc_740091151007_item	3642967	et	4	main
ettevõtte	doc_740091151007_item	3642965	et	4	main
reklaamistendid	doc_740091151007_item	3642942	et	3	main
neid	doc_740091151007_item	3642934	et	4	main
ja	doc_740091151007_item	3642932	et	3	main
mis	doc_740091151007_item	3642916	et	4	main
visioon	doc_740091151007_item	3642915	et	3	main
ühendus	doc_740091151007_item	3642908	et	4	main
missioon	doc_740091151007_item	3642903	et	3	main
on	doc_740091151007_item	3642897	et	4	main
annab	doc_740091151007_item	3642888	et	3	main
see	doc_740091151007_item	3642887	et	3	main
lahti	doc_740091151007_item	3642871	et	4	main
osadeks	doc_740091151007_item	3642870	et	3	main
üksimateks	doc_740091151007_item	3642869	et	4	main
vastamiseks	doc_740091151007_item	3642862	et	4	main
identiteeti	doc_740091151007_item	3642859	et	4	main
korporatiivset	doc_740091151007_item	3642858	et	4	main
on	doc_740091151007_item	3642854	et	4	main
tekib	doc_740091151007_item	3642848	et	3	main
suurimate	doc_740091151007_item	3642828	et	4	main
ettevõtte	doc_740091151007_item	3642812	et	4	main
taskust	doc_740091151007_item	3642809	et	3	main
ning	doc_740091151007_item	3642805	et	3	main
ning	doc_740091151007_item	3642786	et	3	main
töötunde	doc_740091151007_item	3642785	et	4	main
kulutatud	doc_740091151007_item	3642783	et	4	main
on	doc_740091151007_item	3642782	et	4	main
identiteedi	doc_740091151007_item	3642779	et	4	main
oma	doc_740091151007_item	3642777	et	4	main
jooksul	doc_740091151007_item	3642771	et	4	main
identiteet	doc_740091151007_item	3642767	et	4	main
klientide	doc_740091151007_item	3643084	et	3	main
ühtekuuluvustunne	doc_740091151007_item	3643083	et	3	main
vajalik	doc_740091151007_item	3643082	et	3	main
lugeda	doc_740091151007_item	3643203	et	3	main
võibki	doc_740091151007_item	3643200	et	3	main
järjepidevale	doc_740091151007_item	3643197	et	4	main
mis	doc_740091151007_item	3643192	et	4	main
on	doc_740091151007_item	3643181	et	4	main
identiteedi	doc_740091151007_item	3643171	et	4	main
tuluüksuse	doc_740091151007_item	3643167	et	3	main
turundusosakonna	doc_740091151007_item	3643164	et	4	main
kohati	doc_740091151007_item	3643162	et	4	main
kuigi	doc_740091151007_item	3643161	et	3	main
seega	doc_740091151007_item	3643160	et	4	main
omadega	doc_740091151007_item	3643159	et	3	main
juhtkonna	doc_740091151007_item	3643158	et	4	main
järeldustele	doc_740091151007_item	3643157	et	4	main
sarnastele	doc_740091151007_item	3643156	et	4	main
suhteliselt	doc_740091151007_item	3643155	et	4	main
jõuame	doc_740091151007_item	3643154	et	3	main
analüüsides	doc_740091151007_item	3643153	et	4	main
huvigruppi	doc_740091151007_item	3643152	et	4	main
töötajate	doc_740091151007_item	3643151	et	4	main
viimasena	doc_740091151007_item	3643150	et	3	main
võetud	doc_740091151007_item	3643149	et	4	main
ette	doc_740091151007_item	3643148	et	4	main
organisatsioonis	doc_740091151007_item	3643147	et	3	main
on	doc_740091151007_item	3643146	et	4	main
vajava	doc_740091151007_item	3643183	et	4	main
panustamist	doc_740091151007_item	3643182	et	4	main
analüüsi	doc_740091151007_item	3643175	et	4	main
korporatiivse	doc_740091151007_item	3643170	et	4	main
tekitab	doc_740091151007_item	3643163	et	3	main
kontoris	doc_740091151007_item	3643133	et	3	main
lõpuks	doc_740091151007_item	3643116	et	4	main
siis	doc_740091151007_item	3643115	et	3	main
avaldada	doc_740091151007_item	3643114	et	3	main
arvamust	doc_740091151007_item	3643113	et	3	main
välise	doc_740091151007_item	3643106	et	4	main
kuuluvatest	doc_740091151007_item	3643102	et	4	main
sellesse	doc_740091151007_item	3643100	et	4	main
osa	doc_740091151007_item	3643099	et	4	main
võib	doc_740091151007_item	3643098	et	3	main
kuigi	doc_740091151007_item	3643097	et	3	main
ning	doc_740091151007_item	3643096	et	3	main
vajalikud	doc_740091151007_item	3643095	et	3	main
identiteedi	doc_740091151007_item	3643014	et	4	main
korporatiivse	doc_740091151007_item	3643013	et	4	main
asub	doc_740091151007_item	3643005	et	3	main
ükskõik	doc_740091151007_item	3643001	et	3	main
suhtlemist	doc_740091151007_item	3642977	et	4	main
ka	doc_740091151007_item	3642954	et	3	main
unustada	doc_740091151007_item	3642953	et	3	main
tohi	doc_740091151007_item	3642952	et	4	main
ettevõtte	doc_740091151007_item	3642926	et	4	main
luuakse	doc_740091151007_item	3642925	et	3	main
lähtuvalt	doc_740091151007_item	3642924	et	4	main
neist	doc_740091151007_item	3642923	et	4	main
viia	doc_740091151007_item	3642922	et	3	main
ellu	doc_740091151007_item	3642921	et	4	main
missioon	doc_740091151007_item	3642920	et	3	main
selline	doc_740091151007_item	3642907	et	4	main
hinnangul	doc_740091151007_item	3642896	et	3	main
küsimusele	doc_740091151007_item	3642894	et	4	main
alguses	doc_740091151007_item	3642892	et	4	main
kliendid	doc_740091151007_item	3642884	et	3	main
huvigruppidest	doc_740091151007_item	3642881	et	3	main
mõiste	doc_740091151007_item	3642866	et	4	main
ühele	doc_740091151007_item	3642856	et	3	main
vaja	doc_740091151007_item	3642855	et	4	main
ikka	doc_740091151007_item	3642853	et	4	main
siis	doc_740091151007_item	3642852	et	3	main
kommertspankade	doc_740091151007_item	3642829	et	3	main
eesti	doc_740091151007_item	3642827	et	4	main
pankasse	doc_740091151007_item	3642813	et	4	main
või	doc_740091151007_item	3642810	et	4	main
klientide	doc_740091151007_item	3642808	et	3	main
müüginuppe	doc_740091151007_item	3642804	et	3	main
kannapöörde	doc_740091151007_item	3642776	et	4	main
milleks	doc_740091151007_item	3642765	et	4	main
organisatsiooni	doc_740091151007_item	3643078	et	4	main
puudub	doc_740091151007_item	3643077	et	3	main
aadetest	doc_740091151007_item	3643076	et	3	main
ja	doc_740091151007_item	3643075	et	3	main
eesnõrkudest	doc_740091151007_item	3643074	et	4	main
sloganit	doc_740091151007_item	3643048	et	4	main
tarbeks	doc_740091151007_item	3643040	et	3	main
kui	doc_740091151007_item	3643038	et	3	main
olemasolevat	doc_740091151008_item	3643670	et	3	main
või	doc_740091151008_item	3643668	et	4	main
identiteediga	doc_740091151008_item	3643660	et	4	main
saavutada	doc_740091151008_item	3643647	et	3	main
potentsiaalne	doc_740091151008_item	3643642	et	3	main
suuremal	doc_740091151008_item	3643638	et	4	main
väiksemal	doc_740091151008_item	3643636	et	4	main
mõnel	doc_740091151008_item	3643635	et	3	main
rõhutamisega	doc_740091151008_item	3643630	et	4	main
meediakajastusele	doc_740091151008_item	3643615	et	3	main
jätkuvalt	doc_740091151008_item	3643606	et	4	main
usaldusväärseimaks	doc_740091151008_item	3643590	et	4	main
rolli	doc_740091151008_item	3643584	et	4	main
ettevõtte	doc_740091151008_item	3643561	et	4	main
korporatiivse	doc_740091151008_item	3643558	et	4	main
on	doc_740091151008_item	3643556	et	4	main
lähenemisega	doc_740091151008_item	3643543	et	4	main
loova	doc_740091151008_item	3643530	et	4	main
potentsiaalne	doc_740091151008_item	3643499	et	3	main
nende	doc_740091151008_item	3643497	et	4	main
või	doc_740091151007_item	3643134	et	4	main
või	doc_740091151007_item	3643130	et	4	main
kohvi	doc_740091151007_item	3643129	et	4	main
olla	doc_740091151007_item	3643128	et	3	main
võib	doc_740091151007_item	3643127	et	3	main
ja	doc_740091151007_item	3643126	et	3	main
õnnelikud	doc_740091151007_item	3643120	et	3	main
siiski	doc_740091151007_item	3643119	et	4	main
mõtetu	doc_740091151007_item	3643110	et	4	main
kui	doc_740091151007_item	3643109	et	3	main
teise	doc_740091151007_item	3643105	et	4	main
või	doc_740091151007_item	3643104	et	4	main
huvigruppi	doc_740091151007_item	3643101	et	4	main
identiteedi	doc_740091151007_item	3643092	et	4	main
siingi	doc_740091151007_item	3643090	et	4	main
et	doc_740091151007_item	3643089	et	3	main
öelda	doc_740091151007_item	3643088	et	4	main
võib	doc_740091151007_item	3643087	et	3	main
identiteedi	doc_740091151007_item	3642996	et	4	main
tegelikult	doc_740091151007_item	3642991	et	4	main
kontorit	doc_740091151007_item	3642990	et	3	main
omavahelist	doc_740091151007_item	3642976	et	4	main
igapäevase	doc_740091151007_item	3642973	et	4	main
väga	doc_740091151007_item	3642961	et	3	main
on	doc_740091151007_item	3642960	et	4	main
kes	doc_740091151007_item	3642959	et	4	main
töötajaid	doc_740091151007_item	3642958	et	4	main
kapitali	doc_740091151007_item	3642957	et	4	main
sotsiaalset	doc_740091151007_item	3642956	et	3	main
kujundamisel	doc_740091151007_item	3642949	et	4	main
infomaterjalid	doc_740091151007_item	3642941	et	3	main
logo	doc_740091151007_item	3642931	et	4	main
sisaldab	doc_740091151007_item	3642930	et	3	main
mis	doc_740091151007_item	3642929	et	4	main
külg	doc_740091151007_item	3642928	et	3	main
visuaalne	doc_740091151007_item	3642927	et	3	main
viisil	doc_740091151007_item	3642919	et	4	main
kutsutud	doc_740091151007_item	3642911	et	4	main
milleks	doc_740091151007_item	3642906	et	4	main
kirjutuse	doc_740091151007_item	3642891	et	4	main
lähtuvalt	doc_740091151007_item	3642878	et	4	main
analüüsida	doc_740091151007_item	3642877	et	3	main
osasid	doc_740091151007_item	3642876	et	3	main
ta	doc_740091151007_item	3642868	et	4	main
ning	doc_740091151007_item	3642867	et	3	main
küsimusele	doc_740091151007_item	3642861	et	4	main
lugedes	doc_740091151007_item	3642847	et	3	main
näevad	doc_740091151007_item	3642834	et	3	main
tehtud	doc_740091151007_item	3642832	et	4	main
korporatiivsel	doc_740091151007_item	3642830	et	4	main
kõrvalt	doc_740091151007_item	3642826	et	4	main
näiteks	doc_740091151007_item	3642825	et	4	main
vaadeldes	doc_740091151007_item	3642824	et	3	main
proovivad	doc_740091151007_item	3642815	et	4	main
kontolt	doc_740091151007_item	3642811	et	3	main
harutades	doc_740091151007_item	3642807	et	3	main
kogemusi	doc_740091151007_item	3642806	et	3	main
erinevaid	doc_740091151007_item	3642803	et	4	main
vaeva	doc_740091151007_item	3642801	et	4	main
suure	doc_740091151007_item	3642800	et	3	main
hulk	doc_740091151007_item	3642784	et	3	main
muutmisel	doc_740091151007_item	3642780	et	4	main
mitmed	doc_740091151007_item	3642773	et	4	main
on	doc_740091151007_item	3642772	et	4	main
paari	doc_740091151007_item	3642769	et	4	main
viimase	doc_740091151007_item	3642768	et	3	main
korporatiivne	doc_740091151007_item	3642766	et	4	main
kaupa	doc_740091151007_item	3643064	et	4	main
või	doc_740091151007_item	3643063	et	4	main
teenust	doc_740091151007_item	3643062	et	3	main
reklaam	doc_740091151007_item	3643050	et	3	main
nägemus	doc_740091151007_item	3643044	et	3	main
ühtmoodi	doc_740091151007_item	3643094	et	3	main
või	doc_740091151007_item	3643006	et	4	main
ta	doc_740091151007_item	3643003	et	4	main
tööaega	doc_740091151007_item	3643000	et	4	main
väljaspool	doc_740091151007_item	3642999	et	3	main
ka	doc_740091151007_item	3642998	et	3	main
kandjaks	doc_740091151007_item	3642997	et	4	main
ettevõtte	doc_740091151007_item	3642993	et	4	main
lõpegi	doc_740091151007_item	3642988	et	4	main
väljendudes	doc_740091151007_item	3642986	et	3	main
lõpeb	doc_740091151007_item	3642982	et	4	main
ning	doc_740091151007_item	3642981	et	3	main
sisaldab	doc_740091151007_item	3642975	et	3	main
töötajate	doc_740091151007_item	3642968	et	4	main
ettevõtte	doc_740091151007_item	3642955	et	4	main
jne	doc_740091151007_item	3642948	et	4	main
kontorites	doc_740091151007_item	3642947	et	3	main
kliendipiirkond	doc_740091151007_item	3642946	et	3	main
infokirjad	doc_740091151007_item	3642945	et	3	main
suunatud	doc_740091151007_item	3642944	et	4	main
poole	doc_740091151007_item	3642940	et	4	main
ettevõtte	doc_740091151007_item	3642938	et	4	main
aluseks	doc_740091151007_item	3642937	et	4	main
on	doc_740091151007_item	3642936	et	4	main
omakorda	doc_740091151007_item	3642935	et	3	main
sloganit	doc_740091151007_item	3642933	et	4	main
mil	doc_740091151007_item	3642918	et	4	main
selgitab	doc_740091151007_item	3642917	et	3	main
ellu	doc_740091151007_item	3642910	et	4	main
üldse	doc_740091151007_item	3642909	et	3	main
teadvustab	doc_740091151007_item	3642905	et	3	main
alustahedeks	doc_740091151007_item	3642901	et	4	main
autori	doc_740091151007_item	3642895	et	3	main
püstitatud	doc_740091151007_item	3642893	et	4	main
ning	doc_740091151007_item	3642885	et	3	main
töötajad	doc_740091151007_item	3642883	et	4	main
erinevatest	doc_740091151007_item	3642880	et	4	main
ettevõtte	doc_740091151007_item	3642879	et	4	main
selle	doc_740091151007_item	3642865	et	4	main
võtma	doc_740091151007_item	3642864	et	3	main
peaksime	doc_740091151007_item	3642863	et	4	main
kas	doc_740091151007_item	3642851	et	3	main
et	doc_740091151007_item	3642850	et	3	main
teiseks	doc_740091151007_item	3642914	et	4	main
ning	doc_740091151007_item	3642913	et	3	main
on	doc_740091151007_item	3642912	et	4	main
mis	doc_740091151007_item	3642904	et	4	main
esmalt	doc_740091151007_item	3642902	et	3	main
identiteedi	doc_740091151007_item	3642900	et	4	main
korporatiivse	doc_740091151007_item	3642899	et	4	main
ettevõtte	doc_740091151007_item	3642898	et	4	main
antud	doc_740091151007_item	3642890	et	4	main
vastuse	doc_740091151007_item	3642889	et	3	main
alles	doc_740091151007_item	3642886	et	3	main
omanikud	doc_740091151007_item	3642882	et	3	main
saadud	doc_740091151007_item	3642875	et	4	main
tuleks	doc_740091151007_item	3642874	et	4	main
seejärel	doc_740091151007_item	3642873	et	3	main
lammutada	doc_740091151007_item	3642872	et	3	main
sellele	doc_740091151007_item	3642860	et	4	main
ettevõttele	doc_740091151007_item	3642857	et	3	main
mõte	doc_740091151007_item	3642849	et	3	main
vastuargumente	doc_740091151007_item	3642846	et	3	main
erinevaid	doc_740091151007_item	3642845	et	4	main
vahel	doc_740091151007_item	3642844	et	4	main
tunustarude	doc_740091151007_item	3642843	et	4	main
suurte	doc_740091151007_item	3642842	et	3	main
pankade	doc_740091151007_item	3642841	et	3	main
ja	doc_740091151007_item	3642840	et	3	main
koha	doc_740091151007_item	3642839	et	4	main
oma	doc_740091151007_item	3642838	et	4	main
seost	doc_740091151007_item	3642837	et	3	main
otsest	doc_740091151007_item	3642836	et	4	main
vaid	doc_740091151007_item	3642835	et	3	main
muudatusi	doc_740091151007_item	3642833	et	3	main
identiteedil	doc_740091151007_item	3642831	et	4	main
teatud	doc_740091151007_item	3642820	et	4	main
ka	doc_740091151007_item	3642819	et	3	main
on	doc_740091151007_item	3642818	et	4	main
arvamusel	doc_740091151007_item	3642817	et	3	main
sarnasel	doc_740091151007_item	3642816	et	4	main
ja	doc_740091151007_item	3642802	et	3	main
teinud	doc_740091151007_item	3642775	et	4	main
suurettevõtted	doc_740091151007_item	3642774	et	3	main
aasta	doc_740091151007_item	3642770	et	4	main
lähenemisse	doc_740091151007_item	3643085	et	4	main
ettevõtte	doc_740091151007_item	3643073	et	4	main
teadlikud	doc_740091151007_item	3643072	et	3	main
ole	doc_740091151007_item	3643071	et	4	main
kes	doc_740091151007_item	3642823	et	4	main
kliente	doc_740091151007_item	3642822	et	3	main
hulk	doc_740091151007_item	3642821	et	3	main
tõsta	doc_740091151007_item	3642814	et	4	main
seda	doc_740091151007_item	3642799	et	3	main
kes	doc_740091151007_item	3642798	et	4	main
müügimuskonnale	doc_740091151007_item	3642797	et	4	main
pähe	doc_740091151007_item	3642796	et	4	main
mahu	doc_740091151007_item	3642795	et	4	main
ei	doc_740091151007_item	3642794	et	4	main
mis	doc_740091151007_item	3642793	et	4	main
raha	doc_740091151007_item	3642792	et	4	main
tunitud	doc_740091151007_item	3642791	et	4	main
raskelt	doc_740091151007_item	3642790	et	4	main
ettevõtte	doc_740091151007_item	3642789	et	4	main
koguses	doc_740091151007_item	3642788	et	4	main
suures	doc_740091151007_item	3642787	et	3	main
ära	doc_740091151007_item	3642781	et	4	main
korporatiivse	doc_740091151007_item	3642778	et	4	main
essee	doc_740091151007_item	3642764	et	4	main
töötajad	doc_740091151007_item	3643069	et	4	main
kui	doc_740091151007_item	3643068	et	3	main
samuti	doc_740091151007_item	3643067	et	3	main
vajada	doc_740091151007_item	3643066	et	3	main
võiksid	doc_740091151007_item	3643065	et	4	main
kes	doc_740091151007_item	3643060	et	4	main
tarbijaid	doc_740091151007_item	3643059	et	4	main
ja	doc_740091151007_item	3643058	et	3	main
kliente	doc_740091151007_item	3643057	et	3	main
siis	doc_740091151007_item	3643053	et	3	main
ega	doc_740091151007_item	3643051	et	3	main
kui	doc_740091151007_item	3643046	et	3	main
puuduks	doc_740091151007_item	3643041	et	3	main
selle	doc_740091151007_item	3643039	et	4	main
ei	doc_740091151007_item	3643035	et	4	main
tähtsusega	doc_740091151007_item	3643034	et	4	main
väärtusi	doc_740091151008_item	3643672	et	3	main
turul	doc_740091151008_item	3643667	et	3	main
mõjuteguritega	doc_740091151008_item	3643666	et	3	main
kohanduda	doc_740091151008_item	3643664	et	3	main
järjepidevalt	doc_740091151008_item	3643662	et	4	main
seetõttu	doc_740091151008_item	3643657	et	3	main
piiratud	doc_740091151008_item	3643656	et	4	main
sageli	doc_740091151008_item	3643655	et	3	main
väga	doc_740091151008_item	3643649	et	3	main
loodetakse	doc_740091151008_item	3643646	et	4	main
õnnestunud	doc_740091151008_item	3643640	et	4	main
teisel	doc_740091151008_item	3643637	et	4	main
on	doc_740091151008_item	3643631	et	4	main
mille	doc_740091151008_item	3643620	et	3	main
korporatiivne	doc_740091151008_item	3643618	et	4	main
grupiettevõtetest	doc_740091151008_item	3643617	et	3	main
selle	doc_740091151008_item	3643616	et	4	main
negatiivsele	doc_740091151008_item	3643614	et	3	main
ja	doc_740091151008_item	3643613	et	3	main
konfliktidele	doc_740091151008_item	3643612	et	3	main
vaatamata	doc_740091151008_item	3643611	et	4	main
kalev	doc_740091151008_item	3643610	et	3	main
või	doc_740091151008_item	3643601	et	4	main
tehakse	doc_740091151008_item	3643598	et	3	main
et	doc_740091151008_item	3643597	et	3	main
tungitud	doc_740091151008_item	3643595	et	4	main
et	doc_740091151008_item	3643588	et	3	main
inimeste	doc_740091151008_item	3643582	et	3	main
läbi	doc_740091151008_item	3643580	et	4	main
peegeldada	doc_740091151008_item	3643579	et	3	main
identiteeti	doc_740091151008_item	3643578	et	4	main
peamiselt	doc_740091151008_item	3643564	et	4	main
tele2	doc_740091151008_item	3643546	et	4	main
nagu	doc_740091151008_item	3643545	et	3	main
teenuspakkujaid	doc_740091151008_item	3643544	et	3	main
nooremaid	doc_740091151008_item	3643538	et	4	main
turule	doc_740091151008_item	3643536	et	3	main
eelise	doc_740091151008_item	3643529	et	4	main
on	doc_740091151008_item	3643501	et	4	main
erinevad	doc_740091151008_item	3643491	et	4	main
loomulikult	doc_740091151008_item	3643490	et	4	main
on	doc_740091151008_item	3643485	et	4	main
erinevad	doc_740091151008_item	3643484	et	4	main
täna	doc_740091151008_item	3643477	et	4	main
tuues	doc_740091151008_item	3643474	et	3	main
suuna	doc_740091151008_item	3643463	et	4	main
valitud	doc_740091151008_item	3643462	et	4	main
hinnata	doc_740091151008_item	3643461	et	4	main
et	doc_740091151008_item	3643460	et	3	main
eelistusi	doc_740091151008_item	3643459	et	4	main
hindamiseks	doc_740091151008_item	3643452	et	4	main
aastapikkuse	doc_740091151008_item	3643450	et	4	main
saada	doc_740091151008_item	3643448	et	4	main
ostjaid	doc_740091151008_item	3643443	et	4	main
potentsiaalseid	doc_740091151008_item	3643442	et	3	main
poole	doc_740091151008_item	3643441	et	4	main
millega	doc_740091151008_item	3643438	et	3	main
endasarnaste	doc_740091151008_item	3643435	et	4	main
et	doc_740091151008_item	3643349	et	3	main
on	doc_740091151008_item	3643345	et	4	main
täna	doc_740091151008_item	3643343	et	4	main
on	doc_740091151008_item	3643342	et	4	main
ekisteerimiseks	doc_740091151007_item	3643081	et	4	main
edukaks	doc_740091151007_item	3643080	et	3	main
sees	doc_740091151007_item	3643079	et	4	main
ei	doc_740091151007_item	3643070	et	4	main
ettevõtte	doc_740091151007_item	3643061	et	4	main
ka	doc_740091151007_item	3643056	et	3	main
ei	doc_740091151007_item	3643054	et	4	main
pole	doc_740091151007_item	3643047	et	3	main
ehk	doc_740091151007_item	3643043	et	3	main
edasiminekut	doc_740091151007_item	3643037	et	3	main
ole	doc_740091151007_item	3643036	et	4	main
brändi	doc_740091151008_item	3643674	et	4	main
kinnistada	doc_740091151008_item	3643669	et	3	main
uute	doc_740091151008_item	3643665	et	3	main
et	doc_740091151008_item	3643663	et	3	main
tegelda	doc_740091151008_item	3643661	et	4	main
määral	doc_740091151008_item	3643639	et	3	main
eesti	doc_740091151008_item	3643632	et	4	main
oma	doc_740091151008_item	3643624	et	4	main
eristumine	doc_740091151008_item	3643623	et	4	main
kaubamärk	doc_740091151008_item	3643609	et	3	main
niisamuti	doc_740091151008_item	3643604	et	3	main
piiririkkumised	doc_740091151008_item	3643603	et	3	main
sellest	doc_740091151008_item	3643596	et	4	main
on	doc_740091151008_item	3643594	et	4	main
piirivalvet	doc_740091151008_item	3643593	et	3	main
peetakse	doc_740091151008_item	3643592	et	3	main
institutsiooniks	doc_740091151008_item	3643591	et	3	main
oma	doc_740091151008_item	3643577	et	4	main
suudetakse	doc_740091151008_item	3643576	et	3	main
kuidas	doc_740091151008_item	3643575	et	3	main
teki	doc_740091151007_item	3643055	et	4	main
infomaterjale	doc_740091151007_item	3643052	et	3	main
ja	doc_740091151007_item	3643049	et	3	main
ning	doc_740091151007_item	3643045	et	3	main
visioon	doc_740091151007_item	3643042	et	3	main
ja	doc_740091151007_item	3643033	et	3	main
kaalu	doc_740091151007_item	3643032	et	4	main
võrdse	doc_740091151007_item	3643031	et	3	main
suhteliselt	doc_740091151007_item	3643030	et	4	main
kõik	doc_740091151007_item	3643029	et	4	main
need	doc_740091151007_item	3643028	et	3	main
on	doc_740091151007_item	3643027	et	4	main
omanikule	doc_740091151007_item	3643026	et	3	main
ettevõtte	doc_740091151007_item	3643025	et	4	main
et	doc_740091151007_item	3643024	et	3	main
öelda	doc_740091151007_item	3643023	et	4	main
võib	doc_740091151007_item	3643022	et	3	main
siis	doc_740091151007_item	3643021	et	3	main
vaatenurgalt	doc_740091151007_item	3643020	et	3	main
huvigrupi	doc_740091151007_item	3643019	et	3	main
kolme	doc_740091151007_item	3643018	et	4	main
eespoolnimetatud	doc_740091151007_item	3643017	et	3	main
osuseid	doc_740091151007_item	3643016	et	4	main
erinevaid	doc_740091151007_item	3643015	et	4	main
ja	doc_740091151008_item	3643673	et	3	main
korporatiivse	doc_740091151008_item	3643659	et	4	main
väike	doc_740091151008_item	3643650	et	4	main
poolehoidu	doc_740091151008_item	3643645	et	4	main
kelle	doc_740091151008_item	3643644	et	4	main
sihtrühm	doc_740091151008_item	3643643	et	3	main
kuna	doc_740091151008_item	3643641	et	3	main
väiksusest	doc_740091151008_item	3643633	et	4	main
parimate	doc_740091151008_item	3643625	et	4	main
eesmärgiks	doc_740091151008_item	3643621	et	3	main
identiteet	doc_740091151008_item	3643619	et	4	main
eesti	doc_740091151008_item	3643607	et	4	main
tööd	doc_740091151008_item	3643600	et	4	main
eesti	doc_740091151008_item	3643589	et	4	main
ja	doc_740091151008_item	3643583	et	3	main
tema	doc_740091151008_item	3643581	et	4	main
ka	doc_740091151008_item	3643573	et	3	main
olulist	doc_740091151008_item	3643571	et	4	main
mängib	doc_740091151008_item	3643569	et	3	main
visuaalne	doc_740091151008_item	3643567	et	3	main
imidž	doc_740091151008_item	3643562	et	2	main
ehkki	doc_740091151008_item	3643553	et	3	main
lepingutega	doc_740091151008_item	3643552	et	3	main
agresiivsema	doc_740091151008_item	3643542	et	4	main
veelgi	doc_740091151008_item	3643541	et	4	main
ehk	doc_740091151008_item	3643540	et	3	main
ja	doc_740091151008_item	3643539	et	3	main
on	doc_740091151008_item	3643535	et	4	main
järjest	doc_740091151008_item	3643534	et	4	main
sihtrühm	doc_740091151008_item	3643500	et	3	main
identiteedilt	doc_740091151008_item	3643489	et	4	main
või	doc_740091151008_item	3643483	et	4	main
kuvandit	doc_740091151008_item	3643671	et	3	main
tuleb	doc_740091151008_item	3643658	et	3	main
jaoks	doc_740091151008_item	3643654	et	4	main
selle	doc_740091151008_item	3643653	et	4	main
vahendid	doc_740091151008_item	3643652	et	3	main
ning	doc_740091151008_item	3643651	et	3	main
on	doc_740091151008_item	3643648	et	4	main
tulenevalt	doc_740091151008_item	3643634	et	4	main
väärtuste	doc_740091151008_item	3643629	et	4	main
esiletoodavamate	doc_740091151008_item	3643628	et	3	main
konkurentidest	doc_740091151008_item	3643627	et	3	main
ja	doc_740091151008_item	3643626	et	3	main
on	doc_740091151008_item	3643622	et	4	main
tugevaim	doc_740091151008_item	3643608	et	4	main
on	doc_740091151008_item	3643605	et	4	main
puuduvad	doc_740091151008_item	3643602	et	4	main
kvaliteetset	doc_740091151008_item	3643599	et	3	main
asjaolu	doc_740091151008_item	3643587	et	4	main
kas	doc_740091151008_item	3643586	et	3	main
ühiskonnas	doc_740091151008_item	3643585	et	4	main
see	doc_740091151008_item	3643574	et	3	main
rolli	doc_740091151008_item	3643572	et	4	main
välimus	doc_740091151008_item	3643568	et	3	main
mis	doc_740091151008_item	3643563	et	4	main
identiteedi	doc_740091151008_item	3643559	et	4	main
peamiseks	doc_740091151008_item	3643557	et	3	main
jaoks	doc_740091151008_item	3643555	et	4	main
tavainimese	doc_740091151008_item	3643554	et	4	main
mittesiduvate	doc_740091151008_item	3643551	et	3	main
teleyks	doc_740091151008_item	3643550	et	4	main
või	doc_740091151008_item	3643549	et	4	main
hinnaga	doc_740091151008_item	3643548	et	3	main
odava	doc_740091151008_item	3643547	et	3	main
kui	doc_740091151008_item	3643533	et	3	main
juhtpositsiooni	doc_740091151008_item	3643532	et	4	main
argumendiga	doc_740091151008_item	3643531	et	3	main
välja	doc_740091151008_item	3643476	et	4	main
näitena	doc_740091151008_item	3643475	et	3	main
muutmiseks	doc_740091151008_item	3643473	et	4	main
või	doc_740091151008_item	3643472	et	4	main
võita	doc_740091151008_item	3643439	et	4	main
oma	doc_740091151008_item	3643355	et	4	main
asjaolust	doc_740091151008_item	3643348	et	3	main
tegevus	doc_740091151008_item	3643330	et	4	main
sihipärane	doc_740091151008_item	3643329	et	4	main
see	doc_740091151008_item	3643325	et	3	main
olnud	doc_740091151008_item	3643324	et	4	main
ajal	doc_740091151008_item	3643320	et	4	main
tegemist	doc_740091151008_item	3643303	et	4	main
on	doc_740091151008_item	3643293	et	4	main
seega	doc_740091151008_item	3643287	et	4	main
tema	doc_740091151008_item	3643282	et	4	main
loovad	doc_740091151008_item	3643281	et	4	main
ja	doc_740091151008_item	3643280	et	3	main
tavainimesele	doc_740091151008_item	3643279	et	3	main
eelpool	doc_740091151008_item	3643272	et	4	main
inimesi	doc_740091151008_item	3643270	et	4	main
töötavaid	doc_740091151008_item	3643269	et	4	main
selle	doc_740091151008_item	3643259	et	4	main
võib	doc_740091151008_item	3643258	et	3	main
korporatiivne	doc_740091151008_item	3643210	et	4	main
tehakse	doc_740091151008_item	3643418	et	3	main
loomis	doc_740091151008_item	3643414	et	4	main
oma	doc_740091151008_item	3643411	et	4	main
eristuv	doc_740091151008_item	3643399	et	4	main
samavõrra	doc_740091151008_item	3643570	et	3	main
tema	doc_740091151008_item	3643566	et	4	main
on	doc_740091151008_item	3643565	et	4	main
peegeldajaks	doc_740091151008_item	3643560	et	4	main
tulnud	doc_740091151008_item	3643537	et	4	main
suure	doc_740091151008_item	3643528	et	3	main
talle	doc_740091151008_item	3643527	et	4	main
nautida	doc_740091151008_item	3643526	et	3	main
saa	doc_740091151008_item	3643525	et	4	main
ei	doc_740091151008_item	3643524	et	4	main
teenusepakkuja	doc_740091151008_item	3643523	et	4	main
valdkonna	doc_740091151008_item	3643522	et	4	main
selle	doc_740091151008_item	3643521	et	4	main
vanim	doc_740091151008_item	3643520	et	3	main
kui	doc_740091151008_item	3643519	et	3	main
emt	doc_740091151008_item	3643518	et	4	main
ka	doc_740091151008_item	3643517	et	3	main
jõudmiseks	doc_740091151008_item	3643516	et	4	main
kliendini	doc_740091151008_item	3643515	et	3	main
lähemistee	doc_740091151008_item	3643514	et	4	main
erineva	doc_740091151008_item	3643513	et	4	main
vähem	doc_740091151008_item	3643512	et	4	main
või	doc_740091151008_item	3643511	et	4	main
rohkem	doc_740091151008_item	3643510	et	4	main
valinud	doc_740091151008_item	3643509	et	4	main
neist	doc_740091151008_item	3643508	et	4	main
igaüks	doc_740091151008_item	3643507	et	3	main
on	doc_740091151008_item	3643506	et	4	main
elanikkond	doc_740091151008_item	3643505	et	3	main
tööealine	doc_740091151008_item	3643504	et	4	main
eesti	doc_740091151008_item	3643503	et	4	main
sarnane	doc_740091151008_item	3643502	et	4	main
kõigi	doc_740091151008_item	3643498	et	4	main
oma	doc_740091151008_item	3643487	et	4	main
nad	doc_740091151008_item	3643486	et	3	main
tegutsevad	doc_740091151008_item	3643479	et	4	main
eestis	doc_740091151008_item	3643478	et	3	main
kinnistamiseks	doc_740091151008_item	3643471	et	4	main
identiteedi	doc_740091151008_item	3643470	et	4	main
olemasoleva	doc_740091151008_item	3643469	et	3	main
samme	doc_740091151008_item	3643468	et	3	main
edasisi	doc_740091151008_item	3643467	et	3	main
teha	doc_740091151008_item	3643466	et	3	main
ja	doc_740091151008_item	3643465	et	3	main
õigsust	doc_740091151008_item	3643464	et	3	main
ja	doc_740091151008_item	3643458	et	3	main
tarbijauuringuid	doc_740091151008_item	3643454	et	3	main
eesmärk	doc_740091151008_item	3643447	et	3	main
oleks	doc_740091151008_item	3643431	et	3	main
imidžit	doc_740091151008_item	3643428	et	2	main
head	doc_740091151008_item	3643427	et	4	main
ja	doc_740091151008_item	3643426	et	3	main
so	doc_740091151008_item	3643351	et	4	main
riik	doc_740091151008_item	3643350	et	3	main
kui	doc_740091151008_item	3643340	et	3	main
jaoks	doc_740091151008_item	3643339	et	4	main
oli	doc_740091151008_item	3643337	et	3	main
tol	doc_740091151008_item	3643335	et	3	main
nagu	doc_740091151008_item	3643334	et	3	main
vormis	doc_740091151008_item	3643333	et	4	main
sellises	doc_740091151008_item	3643332	et	4	main
ent	doc_740091151008_item	3643321	et	3	main
nõukogude	doc_740091151008_item	3643318	et	3	main
aja	doc_740091151008_item	3643297	et	4	main
uue	doc_740091151008_item	3643296	et	3	main
korporatiivne	doc_740091151008_item	3643291	et	4	main
ettevõtte	doc_740091151008_item	3643288	et	4	main
ja	doc_740091151008_item	3643286	et	3	main
nimetatud	doc_740091151008_item	3643273	et	4	main
puhul	doc_740091151008_item	3643257	et	4	main
ettevõtte	doc_740091151008_item	3643254	et	4	main
pigem	doc_740091151008_item	3643251	et	3	main
mõistest	doc_740091151008_item	3643215	et	4	main
inimesele	doc_740091151008_item	3643214	et	3	main
rääkida	doc_740091151008_item	3643213	et	3	main
kui	doc_740091151008_item	3643212	et	3	main
identiteet	doc_740091151008_item	3643211	et	4	main
oma	doc_740091151008_item	3643423	et	4	main
kuigi	doc_740091151008_item	3643496	et	3	main
et	doc_740091151008_item	3643495	et	3	main
arvesse	doc_740091151008_item	3643494	et	4	main
võttes	doc_740091151008_item	3643493	et	4	main
aga	doc_740091151008_item	3643492	et	3	main
korporatiivselt	doc_740091151008_item	3643488	et	4	main
sarnased	doc_740091151008_item	3643482	et	4	main
kuivõrd	doc_740091151008_item	3643481	et	3	main
telefonioperaatorid	doc_740091151008_item	3643480	et	3	main
välja	doc_740091151008_item	3643456	et	4	main
selgitamaks	doc_740091151008_item	3643455	et	3	main
korraldatakse	doc_740091151008_item	3643453	et	3	main
turuliidriks	doc_740091151008_item	3643449	et	3	main
sellega	doc_740091151008_item	3643446	et	3	main
saavutada	doc_740091151008_item	3643445	et	3	main
ja	doc_740091151008_item	3643444	et	3	main
konkurentsieelis	doc_740091151008_item	3643437	et	3	main
pidanud	doc_740091151008_item	3643354	et	4	main
ei	doc_740091151008_item	3643353	et	4	main
see	doc_740091151008_item	3643346	et	3	main
peamiselt	doc_740091151008_item	3643344	et	4	main
ajal	doc_740091151008_item	3643336	et	4	main
kindlasti	doc_740091151008_item	3643322	et	3	main
võimu	doc_740091151008_item	3643319	et	4	main
tarbijakäitumist	doc_740091151008_item	3643457	et	3	main
töö	doc_740091151008_item	3643451	et	4	main
enda	doc_740091151008_item	3643440	et	4	main
ees	doc_740091151008_item	3643436	et	4	main
teiste	doc_740091151008_item	3643434	et	4	main
luua	doc_740091151008_item	3643433	et	4	main
võimalik	doc_740091151008_item	3643432	et	3	main
kaudu	doc_740091151008_item	3643430	et	3	main
mille	doc_740091151008_item	3643429	et	3	main
nsvl	doc_740091151008_item	3643352	et	4	main
tingitud	doc_740091151008_item	3643347	et	4	main
ta	doc_740091151008_item	3643341	et	4	main
ei	doc_740091151008_item	3643323	et	4	main
juba	doc_740091151008_item	3643317	et	3	main
see	doc_740091151008_item	3643316	et	3	main
eksisteeris	doc_740091151008_item	3643315	et	4	main
vormis	doc_740091151008_item	3643314	et	4	main
teistsuguses	doc_740091151008_item	3643313	et	3	main
ja	doc_740091151008_item	3643312	et	3	main
kujul	doc_740091151008_item	3643311	et	4	main
varjatumal	doc_740091151008_item	3643310	et	4	main
mõnevõrra	doc_740091151008_item	3643309	et	3	main
vaid	doc_740091151008_item	3643308	et	3	main
nähtusega	doc_740091151008_item	3643307	et	4	main
uue	doc_740091151008_item	3643306	et	3	main
ole	doc_740091151008_item	3643305	et	4	main
ei	doc_740091151008_item	3643304	et	4	main
et	doc_740091151008_item	3643302	et	3	main
jaoks	doc_740091151008_item	3643295	et	4	main
identiteet	doc_740091151008_item	3643292	et	4	main
väärtuse	doc_740091151008_item	3643289	et	3	main
identiteedi	doc_740091151008_item	3643285	et	4	main
korporatiivse	doc_740091151008_item	3643284	et	4	main
osad	doc_740091151008_item	3643274	et	3	main
kõik	doc_740091151008_item	3643271	et	4	main
enamasti	doc_740091151008_item	3643223	et	4	main
esmalt	doc_740091151008_item	3643222	et	3	main
talle	doc_740091151008_item	3643221	et	4	main
see	doc_740091151008_item	3643220	et	3	main
identiteet	doc_740091151008_item	3643217	et	4	main
milleks	doc_740091151008_item	3643209	et	4	main
välja	doc_740091151008_item	3643422	et	4	main
eesmärgil	doc_740091151008_item	3643420	et	3	main
seda	doc_740091151008_item	3643419	et	3	main
eelkõige	doc_740091151008_item	3643417	et	3	main
ja	doc_740091151008_item	3643415	et	3	main
tänaseks	doc_740091151008_item	3643405	et	4	main
kuna	doc_740091151008_item	3643395	et	3	main
võimalik	doc_740091151008_item	3643338	et	3	main
ettevõtte	doc_740091151008_item	3643331	et	4	main
ja	doc_740091151008_item	3643328	et	3	main
teadlik	doc_740091151008_item	3643327	et	3	main
nii	doc_740091151008_item	3643326	et	3	main
mõiste	doc_740091151008_item	3643298	et	4	main
kas	doc_740091151008_item	3643290	et	3	main
jaoks	doc_740091151008_item	3643283	et	4	main
on	doc_740091151008_item	3643275	et	4	main
brändi	doc_740091151008_item	3643263	et	4	main
imidžit	doc_740091151008_item	3643262	et	2	main
pidada	doc_740091151008_item	3643261	et	4	main
põhiosadeks	doc_740091151008_item	3643260	et	3	main
korporatiivse	doc_740091151008_item	3643255	et	4	main
tunnetatakse	doc_740091151008_item	3643253	et	3	main
öelda	doc_740091151008_item	3643249	et	4	main
võib	doc_740091151008_item	3643248	et	3	main
ütle	doc_740091151008_item	3643219	et	4	main
essee	doc_740091151008_item	3643208	et	4	main
väärtusi	doc_740091151008_item	3643425	et	3	main
identiteedi	doc_740091151008_item	3643413	et	4	main
tegeldud	doc_740091151008_item	3643410	et	4	main
riigisektoris	doc_740091151008_item	3643409	et	3	main
kui	doc_740091151008_item	3643408	et	3	main
era-	doc_740091151008_item	3643407	et	4	main
nii	doc_740091151008_item	3643406	et	3	main
teistest	doc_740091151008_item	3643398	et	4	main
oli	doc_740091151008_item	3643397	et	3	main
see	doc_740091151008_item	3643396	et	3	main
eelistati	doc_740091151008_item	3643393	et	4	main
eelistatud	doc_740091151008_item	3643390	et	4	main
ja	doc_740091151009_item	3644157	et	3	main
olulisemate	doc_740091151009_item	3644154	et	4	main
märgatavamatele	doc_740091151009_item	3644158	et	4	main
on	doc_740091151009_item	3644150	et	4	main
lõikes	doc_740091151009_item	3644143	et	3	main
pelga	doc_740091151009_item	3644140	et	4	main
staatuse	doc_740091151009_item	3644129	et	3	main
ja	doc_740091151009_item	3644124	et	3	main
vice	doc_740091151009_item	3644118	et	4	main
ei	doc_740091151009_item	3644109	et	4	main
rolli	doc_740091151009_item	3644107	et	4	main
tundub	doc_740091151009_item	3644104	et	3	main
käitumisstandardeid	doc_740091151009_item	3644102	et	3	main
tähtsust	doc_740091151009_item	3644095	et	4	main
oma	doc_740091151009_item	3644094	et	4	main
üha	doc_740091151009_item	3644093	et	3	main
mehed	doc_740091151009_item	3644092	et	3	main
taguse	doc_740091151009_item	3644089	et	3	main
võrreldes	doc_740091151009_item	3644086	et	3	main
väita	doc_740091151009_item	3644084	et	4	main
kokkuvõttes	doc_740091151009_item	3644081	et	3	main
järelikult	doc_740091151009_item	3644080	et	3	main
varem	doc_740091151009_item	3644074	et	4	main
mis	doc_740091151009_item	3644073	et	4	main
naudivad	doc_740091151009_item	3644069	et	3	main
isapuhkust	doc_740091151009_item	3644067	et	4	main
väita	doc_740091151008_item	3643301	et	4	main
kindlalt	doc_740091151008_item	3643300	et	4	main
võib	doc_740091151008_item	3643299	et	3	main
meie	doc_740091151008_item	3643294	et	4	main
peegelduvad	doc_740091151008_item	3643278	et	4	main
mis	doc_740091151008_item	3643277	et	4	main
need	doc_740091151008_item	3643276	et	3	main
selles	doc_740091151008_item	3643268	et	4	main
ka	doc_740091151008_item	3643267	et	3	main
kindlasti	doc_740091151008_item	3643266	et	3	main
aga	doc_740091151008_item	3643265	et	3	main
põhiväärtusi	doc_740091151008_item	3643264	et	3	main
identiteedi	doc_740091151008_item	3643256	et	4	main
seda	doc_740091151008_item	3643252	et	3	main
et	doc_740091151008_item	3643250	et	3	main
aga	doc_740091151008_item	3643247	et	3	main
möelda	doc_740091151008_item	3643246	et	4	main
ei	doc_740091151008_item	3643245	et	4	main
küll	doc_740091151008_item	3643244	et	4	main
asjadele	doc_740091151008_item	3643243	et	3	main
sellistele	doc_740091151008_item	3643242	et	4	main
igapäevaselt	doc_740091151008_item	3643241	et	4	main
räägitakse	doc_740091151008_item	3643240	et	3	main
millest	doc_740091151008_item	3643239	et	3	main
aru	doc_740091151008_item	3643238	et	4	main
ta	doc_740091151008_item	3643237	et	4	main
saab	doc_740091151008_item	3643236	et	3	main
k-poliitika	doc_740091151008_item	3643235	et	4	main
või	doc_740091151008_item	3643234	et	4	main
oravapartei	doc_740091151008_item	3643233	et	4	main
nagu	doc_740091151008_item	3643232	et	3	main
väljendid	doc_740091151008_item	3643231	et	3	main
ja	doc_740091151008_item	3643230	et	3	main
näited	doc_740091151008_item	3643229	et	3	main
konkreetsed	doc_740091151008_item	3643228	et	3	main
aga	doc_740091151008_item	3643227	et	3	main
välja	doc_740091151008_item	3643226	et	4	main
tuues	doc_740091151008_item	3643225	et	3	main
midagi	doc_740091151008_item	3643224	et	4	main
ei	doc_740091151008_item	3643218	et	4	main
korporatiivne	doc_740091151008_item	3643216	et	4	main
olulisemaid	doc_740091151008_item	3643424	et	4	main
tuua	doc_740091151008_item	3643421	et	3	main
kujundamisega	doc_740091151008_item	3643416	et	4	main
korporatiivse	doc_740091151008_item	3643412	et	4	main
sümboliseeris	doc_740091151008_item	3643401	et	4	main
ja	doc_740091151008_item	3643400	et	3	main
välismaist	doc_740091151008_item	3643394	et	4	main
alguseks	doc_740091151009_item	3644153	et	4	main
ehk	doc_740091151009_item	3644149	et	3	main
muutusi	doc_740091151009_item	3644147	et	4	main
vaid	doc_740091151009_item	3644145	et	3	main
muutused	doc_740091151009_item	3644137	et	4	main
peab	doc_740091151009_item	3644131	et	4	main
vaid	doc_740091151009_item	3644117	et	3	main
muutuda	doc_740091151009_item	3644116	et	3	main
tühiseks	doc_740091151009_item	3644115	et	4	main
kohanedes	doc_740091151009_item	3644106	et	3	main
ometi	doc_740091151009_item	3644103	et	3	main
aasta	doc_740091151009_item	3644088	et	4	main
et	doc_740091151009_item	3644085	et	3	main
võib	doc_740091151009_item	3644082	et	3	main
sobitunud	doc_740091151009_item	3644079	et	4	main
ei	doc_740091151009_item	3644078	et	4	main
täiel	doc_740091151009_item	3644070	et	3	main
hulk	doc_740091151009_item	3644062	et	3	main
on	doc_740091151009_item	3644060	et	4	main
mehi	doc_740091151009_item	3644051	et	3	main
suhetes	doc_740091151009_item	3644047	et	3	main
üllataval	doc_740091151009_item	3644038	et	4	main
pole	doc_740091151009_item	3644037	et	3	main
rollis	doc_740091151009_item	3644035	et	3	main
muutus	doc_740091151009_item	3644033	et	4	main
loomulikult	doc_740091151009_item	3644017	et	4	main
oma	doc_740091151009_item	3644014	et	4	main
hulga	doc_740091151009_item	3644013	et	4	main
suure	doc_740091151009_item	3644012	et	3	main
aastaga	doc_740091151009_item	3644007	et	3	main
viimase	doc_740091151009_item	3644005	et	3	main
väita	doc_740091151009_item	3644003	et	4	main
ja	doc_740091151009_item	3643995	et	3	main
leiab	doc_740091151009_item	3643992	et	3	main
teha	doc_740091151009_item	3643986	et	3	main
mehi	doc_740091151009_item	3643980	et	3	main
suur	doc_740091151009_item	3643978	et	3	main
sellisel	doc_740091151009_item	3643972	et	4	main
langenud	doc_740091151009_item	3643968	et	4	main
on	doc_740091151008_item	3643404	et	4	main
eestis	doc_740091151008_item	3643403	et	3	main
staatust	doc_740091151008_item	3643402	et	3	main
vaid	doc_740091151008_item	3643392	et	3	main
ühte	doc_740091151008_item	3643391	et	4	main
ei	doc_740091151008_item	3643389	et	4	main
pärast	doc_740091151008_item	3643388	et	4	main
identiteedi	doc_740091151008_item	3643387	et	4	main
ettevõtete	doc_740091151008_item	3643386	et	3	main
nende	doc_740091151008_item	3643385	et	4	main
teadlikult	doc_740091151008_item	3643384	et	4	main
et	doc_740091151008_item	3643383	et	3	main
arvata	doc_740091151008_item	3643382	et	4	main
võib	doc_740091151008_item	3643381	et	3	main
aga	doc_740091151008_item	3643380	et	3	main
adidas	doc_740091151008_item	3643379	et	4	main
või	doc_740091151008_item	3643378	et	4	main
kommunaar	doc_740091151008_item	3643377	et	3	main
nagu	doc_740091151008_item	3643376	et	3	main
brände	doc_740091151008_item	3643375	et	4	main
välismaiseid	doc_740091151008_item	3643374	et	4	main
kui	doc_740091151008_item	3643373	et	3	main
kodu-	doc_740091151008_item	3643372	et	4	main
nii	doc_740091151008_item	3643371	et	3	main
tunti	doc_740091151008_item	3643370	et	3	main
loomulikult	doc_740091151008_item	3643369	et	4	main
tuntud	doc_740091151008_item	3643368	et	4	main
ei	doc_740091151008_item	3643367	et	4	main
peaaegu	doc_740091151008_item	3643366	et	3	main
eestis	doc_740091151008_item	3643365	et	3	main
nõukogude	doc_740091151008_item	3643364	et	3	main
konkurentsi	doc_740091151008_item	3643363	et	4	main
selle	doc_740091151008_item	3643362	et	4	main
või	doc_740091151008_item	3643361	et	4	main
ettevõtlust	doc_740091151008_item	3643360	et	3	main
ning	doc_740091151008_item	3643359	et	3	main
tõestama	doc_740091151008_item	3643358	et	3	main
enam	doc_740091151008_item	3643357	et	4	main
identiteeti	doc_740091151008_item	3643356	et	4	main
ühiskonnas	doc_740091151009_item	3644163	et	4	main
roll	doc_740091151009_item	3644162	et	3	main
mehe	doc_740091151009_item	3644161	et	3	main
teljel	doc_740091151009_item	3644160	et	3	main
pööretele	doc_740091151009_item	3644159	et	3	main
põnevaks	doc_740091151009_item	3644152	et	3	main
mis	doc_740091151009_item	3644148	et	4	main
näha	doc_740091151009_item	3644146	et	3	main
võib	doc_740091151009_item	3644144	et	3	main
aasta	doc_740091151009_item	3644142	et	4	main
20	doc_740091151009_item	3644141	et	2	main
toimuvad	doc_740091151009_item	3644136	et	4	main
ühiskonnas	doc_740091151009_item	3644135	et	4	main
et	doc_740091151009_item	3644134	et	3	main
kriteeriumidel	doc_740091151009_item	3644127	et	3	main
alustel	doc_740091151009_item	3644123	et	4	main
teistel	doc_740091151009_item	3644122	et	4	main
küll	doc_740091151009_item	3644121	et	4	main
saavutada	doc_740091151009_item	3644120	et	3	main
versa	doc_740091151009_item	3644119	et	4	main
sugugi	doc_740091151009_item	3644114	et	4	main
ühiskonnas	doc_740091151009_item	3644113	et	4	main
roll	doc_740091151009_item	3644112	et	3	main
mehe	doc_740091151009_item	3644111	et	3	main
pruugi	doc_740091151009_item	3644110	et	4	main
tuntud	doc_740091151009_item	3644101	et	4	main
ka	doc_740091151009_item	3644099	et	3	main
muudavad	doc_740091151009_item	3644098	et	4	main
ning	doc_740091151009_item	3644097	et	3	main
kaotavad	doc_740091151009_item	3644091	et	4	main
20	doc_740091151009_item	3644087	et	2	main
rolliga	doc_740091151009_item	3644076	et	4	main
rinnal	doc_740091151009_item	3644071	et	3	main
ning	doc_740091151009_item	3644068	et	3	main
tekkele	doc_740091151009_item	3644156	et	3	main
fenomenide	doc_740091151009_item	3644155	et	3	main
aega	doc_740091151009_item	3644139	et	4	main
rõhutama	doc_740091151009_item	3644133	et	4	main
taaskord	doc_740091151009_item	3644132	et	3	main
põhineva	doc_740091151009_item	3644128	et	4	main
erinevatel	doc_740091151009_item	3644126	et	4	main
varasemast	doc_740091151009_item	3644125	et	4	main
teisenemisega	doc_740091151009_item	3644108	et	4	main
et	doc_740091151009_item	3644105	et	3	main
igipõlistena	doc_740091151009_item	3644100	et	4	main
ühiskonnas	doc_740091151009_item	3644096	et	4	main
ajaga	doc_740091151009_item	3644090	et	3	main
justkui	doc_740091151009_item	3644083	et	3	main
nende	doc_740091151009_item	3644075	et	4	main
võtavad	doc_740091151009_item	3644066	et	3	main
häbenemata	doc_740091151009_item	3644065	et	4	main
sellest	doc_740091151009_item	3644058	et	4	main
ilmselgelt	doc_740091151009_item	3644055	et	4	main
naistevahelistes	doc_740091151009_item	3644046	et	4	main
ja	doc_740091151009_item	3644045	et	3	main
meeste-	doc_740091151009_item	3644044	et	4	main
kombel	doc_740091151009_item	3644039	et	4	main
aga	doc_740091151009_item	3644036	et	3	main
selline	doc_740091151009_item	3644032	et	4	main
kehtestajat	doc_740091151009_item	3644031	et	4	main
elukorralduse	doc_740091151009_item	3644030	et	3	main
ning	doc_740091151009_item	3644029	et	3	main
mis	doc_740091151009_item	3644023	et	4	main
väärtusest	doc_740091151009_item	3644016	et	4	main
on	doc_740091151009_item	3644008	et	4	main
seega	doc_740091151009_item	3644001	et	4	main
kõrghariduseni	doc_740091151009_item	3643994	et	3	main
hulk	doc_740091151009_item	3643979	et	3	main
šokeerivat	doc_740091151009_item	3643974	et	2	main
kui	doc_740091151009_item	3643963	et	3	main
erarindel	doc_740091151009_item	3643953	et	3	main
ja	doc_740091151009_item	3643947	et	3	main
tugevaid	doc_740091151009_item	3643938	et	4	main
siiski	doc_740091151009_item	3643931	et	4	main
poliitikud	doc_740091151009_item	3643930	et	3	main
20	doc_740091151009_item	3643921	et	2	main
osatähtsus	doc_740091151009_item	3643916	et	4	main
ühiskonnas	doc_740091151009_item	3643905	et	4	main
on	doc_740091151009_item	3643894	et	4	main
määratumalt	doc_740091151009_item	3643886	et	4	main
aega	doc_740091151009_item	3643885	et	4	main
läheb	doc_740091151009_item	3643884	et	3	main
kahtlemata	doc_740091151009_item	3643873	et	4	main
rollile	doc_740091151009_item	3643863	et	3	main
essee	doc_740091151009_item	3643859	et	4	main
kontekstis	doc_740091151009_item	3643857	et	3	main
roll	doc_740091151009_item	3643855	et	3	main
naise	doc_740091151009_item	3643854	et	3	main
vaid	doc_740091151009_item	3643851	et	3	main
ühiskonnas	doc_740091151009_item	3643850	et	4	main
rolli	doc_740091151009_item	3643849	et	4	main
küsimust	doc_740091151009_item	3643844	et	4	main
olnud	doc_740091151009_item	3643832	et	4	main
paigas	doc_740091151009_item	3643831	et	4	main
on	doc_740091151009_item	3643830	et	4	main
standardid	doc_740091151009_item	3643808	et	4	main
juba	doc_740091151009_item	3643803	et	3	main
on	doc_740091151009_item	3643795	et	4	main
naine	doc_740091151009_item	3643794	et	3	main
soole	doc_740091151009_item	3643790	et	4	main
ilmsemaid	doc_740091151009_item	3643784	et	4	main
üks	doc_740091151009_item	3643783	et	3	main
muudel	doc_740091151009_item	3643775	et	4	main
teha	doc_740091151009_item	3643773	et	3	main
ei	doc_740091151009_item	3643763	et	4	main
või	doc_740091151009_item	3643758	et	4	main
moraalsete	doc_740091151009_item	3643750	et	3	main
alles	doc_740091151009_item	3644151	et	3	main
nõuavad	doc_740091151009_item	3644138	et	4	main
seega	doc_740091151009_item	3644130	et	4	main
sugugi	doc_740091151009_item	3644077	et	4	main
ülesandeid	doc_740091151009_item	3644072	et	3	main
kes	doc_740091151009_item	3644064	et	4	main
aspektist	doc_740091151009_item	3644059	et	3	main
positiivne	doc_740091151009_item	3644056	et	3	main
maailmavaatele	doc_740091151009_item	3644054	et	4	main
olukordi	doc_740091151009_item	3644043	et	4	main
plahvatuslikke	doc_740091151009_item	3644042	et	3	main
kui	doc_740091151009_item	3644026	et	3	main
meest	doc_740091151009_item	3644025	et	4	main
määratlevad	doc_740091151009_item	3644024	et	4	main
roll	doc_740091151009_item	3644010	et	3	main
ühiskonnas	doc_740091151009_item	3644000	et	4	main
positsioonideni	doc_740091151009_item	3643999	et	3	main
paremate	doc_740091151009_item	3643998	et	4	main
ka	doc_740091151009_item	3643997	et	3	main
rohkem	doc_740091151009_item	3643990	et	4	main
kui	doc_740091151009_item	3643988	et	3	main
kuna	doc_740091151009_item	3643977	et	3	main
pole	doc_740091151009_item	3643971	et	3	main
mitte	doc_740091151009_item	3643964	et	3	main
sissetuleku	doc_740091151009_item	3643959	et	3	main
sarnane	doc_740091151009_item	3643950	et	4	main
seega	doc_740091151009_item	3643940	et	4	main
ka	doc_740091151009_item	3643937	et	3	main
viimase	doc_740091151009_item	3643920	et	3	main
mõistmine	doc_740091151009_item	3643913	et	4	main
suhtes	doc_740091151009_item	3643911	et	4	main
muutumise	doc_740091151009_item	3643910	et	4	main
mis	doc_740091151009_item	3643901	et	4	main
seega	doc_740091151009_item	3643893	et	4	main
läbiviimiseks	doc_740091151009_item	3643892	et	3	main
reformi	doc_740091151009_item	3643891	et	4	main
mõne	doc_740091151009_item	3643889	et	3	main
juurdunud	doc_740091151009_item	3643874	et	4	main
ning	doc_740091151009_item	3643864	et	3	main
feminiinsemale	doc_740091151009_item	3644053	et	4	main
lähemale	doc_740091151009_item	3644052	et	4	main
mitte	doc_740091151009_item	3644041	et	3	main
mehi	doc_740091151009_item	3644063	et	3	main
kasvav	doc_740091151009_item	3644061	et	4	main
näide	doc_740091151009_item	3644057	et	3	main
toonud	doc_740091151009_item	3644050	et	4	main
hoopis	doc_740091151009_item	3644049	et	3	main
vaid	doc_740091151009_item	3644048	et	3	main
põhjustanud	doc_740091151009_item	3644040	et	4	main
mehe	doc_740091151009_item	3644034	et	3	main
pere	doc_740091151009_item	3644027	et	4	main
kaotanud	doc_740091151009_item	3644011	et	4	main
mehe	doc_740091151009_item	3644009	et	3	main
tee	doc_740091151009_item	3643993	et	4	main
tammsaarelikus	doc_740091151009_item	3643983	et	4	main
senini	doc_740091151009_item	3643982	et	3	main
rühmab	doc_740091151009_item	3643981	et	3	main
maikugi	doc_740091151009_item	3643975	et	4	main
kätte	doc_740091151009_item	3643967	et	4	main
naise	doc_740091151009_item	3643966	et	3	main
juba	doc_740091151009_item	3643965	et	3	main
jagamisel	doc_740091151009_item	3643962	et	4	main
roll	doc_740091151009_item	3643957	et	3	main
mehe	doc_740091151009_item	3643955	et	3	main
on	doc_740091151009_item	3643951	et	4	main
on	doc_740091151009_item	3643941	et	4	main
vaikimisi	doc_740091151009_item	3643929	et	4	main
nii-öelda	doc_740091151009_item	3643928	et	3	main
kuigi	doc_740091151009_item	3643925	et	3	main
on	doc_740091151009_item	3643919	et	4	main
rolli	doc_740091151009_item	3643909	et	4	main
mehe	doc_740091151009_item	3643908	et	3	main
tähelepanek	doc_740091151009_item	3643907	et	3	main
esmane	doc_740091151009_item	3643906	et	3	main
teljel	doc_740091151009_item	3643900	et	3	main
pöördeid	doc_740091151009_item	3643899	et	3	main
kui	doc_740091151009_item	3643888	et	3	main
et	doc_740091151009_item	3643881	et	3	main
on	doc_740091151009_item	3643872	et	4	main
soorollid	doc_740091151009_item	3643871	et	3	main
igivanad	doc_740091151009_item	3643870	et	3	main
aastaga	doc_740091151009_item	3643869	et	3	main
viimase	doc_740091151009_item	3643867	et	3	main
muutumisele	doc_740091151009_item	3643866	et	4	main
selle	doc_740091151009_item	3643865	et	4	main
sugu	doc_740091151009_item	3643846	et	4	main
enne	doc_740091151009_item	3643835	et	4	main
tublisti	doc_740091151009_item	3643834	et	3	main
juba	doc_740091151009_item	3643833	et	3	main
nõnda	doc_740091151009_item	3643825	et	3	main
sünnitada	doc_740091151009_item	3643821	et	3	main
erinevad	doc_740091151009_item	3643807	et	4	main
koopaelanikud	doc_740091151009_item	3643805	et	3	main
maa	doc_740091151009_item	3643802	et	4	main
planeedil	doc_740091151009_item	3643801	et	3	main
elu	doc_740091151009_item	3643800	et	4	main
kui	doc_740091151009_item	3643799	et	3	main
iidne	doc_740091151009_item	3643798	et	3	main
mees	doc_740091151009_item	3643792	et	4	main
on	doc_740091151009_item	3643788	et	4	main
ainult	doc_740091151009_item	3643779	et	4	main
mitte	doc_740091151009_item	3643778	et	3	main
ühiskonnas	doc_740091151009_item	3643777	et	4	main
eksisteeri	doc_740091151009_item	3643764	et	4	main
kus	doc_740091151009_item	3643753	et	3	main
ühiskonnas	doc_740091151009_item	3643752	et	4	main
tõekspidamistega	doc_740091151009_item	3643751	et	3	main
et	doc_740091151009_item	3643686	et	3	main
aluseks	doc_740091151009_item	3644020	et	4	main
võtta	doc_740091151009_item	3644019	et	3	main
nõnda	doc_740091151009_item	3643747	et	3	main
binaarsetel	doc_740091151009_item	3643743	et	4	main
puhul	doc_740091151009_item	3643741	et	4	main
detailini	doc_740091151009_item	3643735	et	4	main
viimse	doc_740091151009_item	3643734	et	3	main
aparatuuri	doc_740091151009_item	3643733	et	4	main
kui	doc_740091151009_item	3643724	et	3	main
lihtsam	doc_740091151009_item	3643723	et	4	main
isegi	doc_740091151009_item	3643721	et	4	main
lahkamisel	doc_740091151009_item	3643716	et	4	main
toimuvate	doc_740091151009_item	3643714	et	4	main
kommunikatsioonitehnoloogia	doc_740091151010_item	3644458	et	4	main
võib	doc_740091151010_item	3644454	et	3	main
toitjat	doc_740091151009_item	3644028	et	4	main
kui	doc_740091151009_item	3644018	et	3	main
maskuliinses	doc_740091151009_item	3644015	et	3	main
20	doc_740091151009_item	3644006	et	2	main
et	doc_740091151009_item	3644004	et	3	main
võib	doc_740091151009_item	3644002	et	3	main
seega	doc_740091151009_item	3643996	et	4	main
naisi	doc_740091151009_item	3643991	et	3	main
üha	doc_740091151009_item	3643989	et	3	main
samas	doc_740091151009_item	3643987	et	4	main
tööd	doc_740091151009_item	3643985	et	4	main
õndsuses	doc_740091151009_item	3643984	et	4	main
juures	doc_740091151009_item	3643976	et	4	main
dünaamikal	doc_740091151009_item	3643973	et	3	main
öelda	doc_740091151009_item	3643970	et	4	main
tõtt	doc_740091151009_item	3643969	et	4	main
on	doc_740091151009_item	3643961	et	4	main
hankijana	doc_740091151009_item	3643960	et	4	main
pere	doc_740091151009_item	3643958	et	4	main
kus	doc_740091151009_item	3643954	et	3	main
seis	doc_740091151009_item	3643952	et	4	main
ebaolulisemaks	doc_740091151009_item	3643949	et	4	main
naispoliitikuid	doc_740091151009_item	3643939	et	3	main
tõusnud	doc_740091151009_item	3643936	et	4	main
meeste	doc_740091151009_item	3643934	et	4	main
on	doc_740091151009_item	3643933	et	4	main
mehed	doc_740091151009_item	3643932	et	3	main
areenil	doc_740091151009_item	3643918	et	3	main
poliitilisel	doc_740091151009_item	3643917	et	3	main
meeste	doc_740091151009_item	3643915	et	4	main
ka	doc_740091151009_item	3643897	et	3	main
märgata	doc_740091151009_item	3643896	et	4	main
õige	doc_740091151009_item	3643895	et	4	main
hariliku	doc_740091151009_item	3643890	et	3	main
rohkem	doc_740091151009_item	3643887	et	4	main
nende	doc_740091151009_item	3643882	et	4	main
niivõrd	doc_740091151009_item	3643879	et	3	main
lävimisse	doc_740091151009_item	3643878	et	4	main
ja	doc_740091151009_item	3643877	et	3	main
elukorraldusse	doc_740091151009_item	3643876	et	3	main
ühiskondlikku	doc_740091151009_item	3643875	et	4	main
20	doc_740091151009_item	3643868	et	2	main
mehe	doc_740091151009_item	3643862	et	3	main
indiviidi	doc_740091151009_item	3643848	et	4	main
määrab	doc_740091151009_item	3643847	et	3	main
tekkida	doc_740091151009_item	3643843	et	3	main
kehtestamist	doc_740091151009_item	3643839	et	4	main
väita	doc_740091151009_item	3643827	et	4	main
sama	doc_740091151009_item	3643797	et	4	main
vastandus	doc_740091151009_item	3643791	et	4	main
võib	doc_740091151009_item	3643771	et	3	main
vastandlikku	doc_740091151009_item	3643769	et	4	main
jaotusi	doc_740091151009_item	3643765	et	4	main
väär	doc_740091151009_item	3643759	et	4	main
õige	doc_740091151009_item	3643757	et	4	main
ainult	doc_740091151009_item	3643756	et	4	main
lahterdatakse	doc_740091151009_item	3643755	et	3	main
tuleb	doc_740091151009_item	3643691	et	3	main
töötab	doc_740091151009_item	3643690	et	3	main
televiisor	doc_740091151009_item	3643689	et	3	main
kuidas	doc_740091151009_item	3643688	et	3	main
20	doc_740091151009_item	3643683	et	2	main
roll	doc_740091151009_item	3643680	et	3	main
essee	doc_740091151009_item	3643676	et	4	main
soorollid	doc_740091151009_item	3644022	et	3	main
põlised	doc_740091151009_item	3644021	et	4	main
jaotusega	doc_740091151009_item	3643746	et	4	main
samas	doc_740091151009_item	3643737	et	4	main
sest	doc_740091151009_item	3643729	et	4	main
ehk	doc_740091151009_item	3643720	et	3	main
areng	doc_740091151010_item	3644459	et	3	main
ei	doc_740091151010_item	3644449	et	4	main
olukord	doc_740091151010_item	3644448	et	3	main
arvamusliidritest	doc_740091151010_item	3644432	et	4	main
meedias	doc_740091151010_item	3644429	et	4	main
ka	doc_740091151010_item	3644428	et	3	main
seda	doc_740091151010_item	3644424	et	3	main
kommentaatorit	doc_740091151010_item	3644423	et	3	main
selliseid	doc_740091151010_item	3644409	et	4	main
satub	doc_740091151010_item	3644405	et	3	main
positiivses	doc_740091151010_item	3644401	et	3	main
domineeriv	doc_740091151009_item	3643956	et	4	main
muutunud	doc_740091151009_item	3643948	et	4	main
vähenenud	doc_740091151009_item	3643946	et	4	main
reguleerijana	doc_740091151009_item	3643945	et	4	main
ühiskonna	doc_740091151009_item	3643944	et	4	main
roll	doc_740091151009_item	3643943	et	3	main
mehe	doc_740091151009_item	3643942	et	3	main
kõrvale	doc_740091151009_item	3643935	et	4	main
on	doc_740091151009_item	3643927	et	4	main
tänini	doc_740091151009_item	3643926	et	3	main
vähenenud	doc_740091151009_item	3643924	et	4	main
märgatavalt	doc_740091151009_item	3643923	et	4	main
aastaga	doc_740091151009_item	3643922	et	3	main
et	doc_740091151009_item	3643914	et	3	main
on	doc_740091151009_item	3643912	et	4	main
rolli	doc_740091151009_item	3643904	et	4	main
mehe	doc_740091151009_item	3643903	et	3	main
kujutab	doc_740091151009_item	3643902	et	3	main
väiksemaidki	doc_740091151009_item	3643898	et	4	main
kangutamiseks	doc_740091151009_item	3643883	et	4	main
tugevalt	doc_740091151009_item	3643880	et	4	main
just	doc_740091151009_item	3643861	et	3	main
keskendub	doc_740091151009_item	3643860	et	3	main
käesolev	doc_740091151009_item	3643858	et	3	main
tänapäevases	doc_740091151009_item	3643856	et	4	main
kas	doc_740091151009_item	3643845	et	3	main
ei	doc_740091151009_item	3643841	et	4	main
normide	doc_740091151009_item	3643838	et	3	main
võib	doc_740091151009_item	3643826	et	3	main
neid	doc_740091151009_item	3643823	et	4	main
lapsi	doc_740091151009_item	3643820	et	4	main
tõenäoliselt	doc_740091151009_item	3643796	et	4	main
vaatepunkte	doc_740091151009_item	3643787	et	3	main
ning	doc_740091151009_item	3643785	et	3	main
tasanditel	doc_740091151009_item	3643776	et	3	main
ka	doc_740091151009_item	3643774	et	3	main
poolt	doc_740091151009_item	3643770	et	4	main
kaks	doc_740091151009_item	3643768	et	3	main
on	doc_740091151009_item	3643767	et	4	main
millel	doc_740091151009_item	3643766	et	3	main
vahepealset	doc_740091151009_item	3643761	et	3	main
alla	doc_740091151009_item	3643760	et	3	main
tegu	doc_740091151009_item	3643754	et	4	main
mõista	doc_740091151009_item	3643687	et	4	main
viimase	doc_740091151009_item	3643682	et	3	main
on	doc_740091151009_item	3643678	et	4	main
on	doc_740091151009_item	3643748	et	4	main
lammutama	doc_740091151009_item	3643736	et	4	main
oma	doc_740091151009_item	3643728	et	4	main
eelpool	doc_740091151009_item	3643725	et	4	main
mõnevõrra	doc_740091151009_item	3643722	et	3	main
ühiskondlik	doc_740091151009_item	3643717	et	3	main
oskusest	doc_740091151010_item	3644471	et	4	main
toimub	doc_740091151010_item	3644468	et	3	main
muutmisele	doc_740091151010_item	3644464	et	4	main
demokraatlikumaks	doc_740091151010_item	3644463	et	4	main
loob	doc_740091151010_item	3644460	et	3	main
et	doc_740091151010_item	3644457	et	3	main
kokkuvõtteks	doc_740091151010_item	3644455	et	3	main
arvamust	doc_740091151010_item	3644444	et	3	main
või	doc_740091151010_item	3644419	et	4	main
mis	doc_740091151010_item	3644411	et	4	main
arvamusavaldusi	doc_740091151010_item	3644410	et	3	main
lahendamisele	doc_740091151010_item	3644391	et	4	main
probleemide	doc_740091151010_item	3644390	et	3	main
ühiskondlike	doc_740091151010_item	3644389	et	3	main
teravate	doc_740091151010_item	3644388	et	3	main
nö	doc_740091151010_item	3644376	et	4	main
seast	doc_740091151010_item	3644375	et	4	main
esiuudiste	doc_740091151010_item	3644374	et	3	main
leiab	doc_740091151010_item	3644373	et	3	main
eelistustega	doc_740091151010_item	3644344	et	4	main
ühiskonna	doc_740091151010_item	3644336	et	4	main
muudab	doc_740091151010_item	3644335	et	3	main
areng	doc_740091151010_item	3644334	et	3	main
kommunikatsioonitehnoloogia	doc_740091151010_item	3644333	et	4	main
nende	doc_740091151010_item	3644324	et	4	main
ning	doc_740091151010_item	3644248	et	3	main
ja	doc_740091151009_item	3643853	et	3	main
mehe	doc_740091151009_item	3643852	et	3	main
saa	doc_740091151009_item	3643842	et	4	main
järelikult	doc_740091151009_item	3643840	et	3	main
aktsepteeritavate	doc_740091151009_item	3643837	et	4	main
ühiskonnas	doc_740091151009_item	3643836	et	4	main
soorollid	doc_740091151009_item	3643829	et	3	main
et	doc_740091151009_item	3643828	et	3	main
toita	doc_740091151009_item	3643824	et	4	main
ja	doc_740091151009_item	3643822	et	3	main
lõputult	doc_740091151009_item	3643819	et	4	main
osalus	doc_740091151009_item	3643818	et	4	main
naise	doc_740091151009_item	3643817	et	3	main
ning	doc_740091151009_item	3643816	et	3	main
jahtida	doc_740091151009_item	3643815	et	4	main
mammuteid	doc_740091151009_item	3643814	et	3	main
oli	doc_740091151009_item	3643813	et	3	main
ülesanne	doc_740091151009_item	3643812	et	4	main
mehe	doc_740091151009_item	3643811	et	3	main
soole	doc_740091151009_item	3643810	et	4	main
põhinedes	doc_740091151009_item	3643809	et	3	main
kehtestasid	doc_740091151009_item	3643806	et	4	main
kiviaegsed	doc_740091151009_item	3643804	et	3	main
versus	doc_740091151009_item	3643793	et	4	main
keskendumine	doc_740091151009_item	3643789	et	4	main
tavalisemaid	doc_740091151009_item	3643786	et	4	main
seisukohalt	doc_740091151009_item	3643782	et	4	main
väärtuste	doc_740091151009_item	3643781	et	4	main
moraalsete	doc_740091151009_item	3643780	et	3	main
loomulikult	doc_740091151009_item	3643772	et	4	main
varianti	doc_740091151009_item	3643762	et	4	main
näiteks	doc_740091151009_item	3643749	et	4	main
lahti	doc_740091151009_item	3643695	et	4	main
võtta	doc_740091151009_item	3643694	et	3	main
tükkideks	doc_740091151009_item	3643693	et	3	main
see	doc_740091151009_item	3643692	et	3	main
selleks	doc_740091151009_item	3643685	et	4	main
vastandustel	doc_740091151009_item	3643744	et	4	main
nähtuste	doc_740091151009_item	3643740	et	4	main
ühikondlike	doc_740091151009_item	3643739	et	4	main
kui	doc_740091151009_item	3643738	et	3	main
keerulist	doc_740091151009_item	3643732	et	4	main
kiputakse	doc_740091151009_item	3643731	et	3	main
reeglina	doc_740091151009_item	3643730	et	3	main
nimetatud	doc_740091151009_item	3643726	et	4	main
on	doc_740091151009_item	3643719	et	4	main
muutuste	doc_740091151009_item	3643715	et	4	main
selles	doc_740091151009_item	3643713	et	4	main
ning	doc_740091151009_item	3643712	et	3	main
ühiskonna	doc_740091151009_item	3643711	et	4	main
ka	doc_740091151009_item	3643710	et	3	main
kehtib	doc_740091151009_item	3643709	et	3	main
tegutsemisstrateegia	doc_740091151009_item	3643708	et	4	main
sama	doc_740091151009_item	3643707	et	4	main
täidab	doc_740091151009_item	3643706	et	3	main
detail	doc_740091151009_item	3643705	et	3	main
üksik	doc_740091151009_item	3643704	et	3	main
iga	doc_740091151009_item	3643703	et	4	main
ülesannet	doc_740091151009_item	3643702	et	4	main
millist	doc_740091151009_item	3643701	et	3	main
selge	doc_740091151009_item	3643700	et	4	main
oleks	doc_740091151009_item	3643699	et	3	main
et	doc_740091151009_item	3643698	et	3	main
nõnda	doc_740091151009_item	3643697	et	3	main
harutada	doc_740091151009_item	3643696	et	3	main
aastaga	doc_740091151009_item	3643684	et	3	main
muutunud	doc_740091151009_item	3643681	et	4	main
mehe	doc_740091151009_item	3643679	et	3	main
kuidas	doc_740091151009_item	3643677	et	3	main
põhineva	doc_740091151009_item	3643745	et	4	main
lepitakse	doc_740091151009_item	3643742	et	3	main
televiisori	doc_740091151009_item	3643727	et	4	main
jaotussüsteem	doc_740091151009_item	3643718	et	3	main
ühiskonna	doc_740091151010_item	3644462	et	4	main
selline	doc_740091151010_item	3644447	et	4	main
oma	doc_740091151010_item	3644443	et	4	main
osa	doc_740091151010_item	3644431	et	4	main
ja	doc_740091151010_item	3644430	et	3	main
on	doc_740091151010_item	3644426	et	4	main
teist	doc_740091151010_item	3644422	et	4	main
mõnda	doc_740091151010_item	3644421	et	4	main
siis	doc_740091151010_item	3644420	et	3	main
sekka	doc_740091151010_item	3644407	et	3	main
tihti	doc_740091151010_item	3644404	et	3	main
varem	doc_740091151010_item	3644400	et	4	main
avardamisele	doc_740091151010_item	3644386	et	4	main
kollasid	doc_740091151010_item	3644377	et	4	main
valik	doc_740091151010_item	3644369	et	3	main
teemade	doc_740091151010_item	3644368	et	4	main
üha	doc_740091151010_item	3644353	et	3	main
ka	doc_740091151010_item	3644352	et	3	main
lugejaid	doc_740091151010_item	3644351	et	4	main
lugejad	doc_740091151010_item	3644342	et	4	main
et	doc_740091151010_item	3644332	et	3	main
samas	doc_740091151010_item	3644329	et	4	main
ja	doc_740091151010_item	3644323	et	3	main
osaleda	doc_740091151010_item	3644267	et	3	main
aruteludes	doc_740091151010_item	3644266	et	3	main
laiendanud	doc_740091151010_item	3644262	et	4	main
tehnoliigia	doc_740091151010_item	3644260	et	4	main
on	doc_740091151010_item	3644259	et	4	main
vaatamist	doc_740091151010_item	3644250	et	4	main
internetis	doc_740091151010_item	3644246	et	4	main
internetis	doc_740091151010_item	3644225	et	4	main
jaatavalt	doc_740091151010_item	3644224	et	4	main
demokraatlikumaks	doc_740091151010_item	3644218	et	4	main
ja	doc_740091151010_item	3644212	et	3	main
igapäevaselt	doc_740091151010_item	3644201	et	4	main
tehnoloogia	doc_740091151010_item	3644172	et	4	main
demokraatlikumaks	doc_740091151010_item	3644171	et	4	main
vaid	doc_740091151010_item	3644310	et	3	main
teemast	doc_740091151010_item	3644307	et	4	main
ja	doc_740091151011_item	3644725	et	3	main
eestis	doc_740091151011_item	3644720	et	3	main
rohkem	doc_740091151011_item	3644719	et	4	main
näited	doc_740091151011_item	3644715	et	3	main
suunatud	doc_740091151011_item	3644712	et	4	main
rahvusele	doc_740091151011_item	3644709	et	3	main
mis	doc_740091151011_item	3644708	et	4	main
rääkida	doc_740091151011_item	3644707	et	3	main
pigem	doc_740091151011_item	3644706	et	3	main
ja	doc_740091151011_item	3644585	et	3	main
eestlased	doc_740091151011_item	3644584	et	3	main
on	doc_740091151011_item	3644575	et	4	main
küsimuse	doc_740091151011_item	3644573	et	4	main
antud	doc_740091151011_item	3644572	et	4	main
tegureid	doc_740091151011_item	3644567	et	4	main
palju	doc_740091151011_item	3644566	et	4	main
mis	doc_740091151011_item	3644559	et	4	main
organisatsiooni	doc_740091151011_item	3644556	et	4	main
erinev	doc_740091151011_item	3644554	et	4	main
absolüütselt	doc_740091151011_item	3644553	et	4	main
ka	doc_740091151011_item	3644552	et	3	main
tuleneb	doc_740091151011_item	3644551	et	3	main
eesti	doc_740091151011_item	3644545	et	4	main
pigem	doc_740091151011_item	3644544	et	3	main
olemas	doc_740091151011_item	3644539	et	4	main
rahvuse	doc_740091151011_item	3644537	et	3	main
on	doc_740091151011_item	3644515	et	4	main
siin	doc_740091151011_item	3644505	et	4	main
aastaid	doc_740091151011_item	3644502	et	4	main
ühtsus	doc_740091151011_item	3644492	et	4	main
siin	doc_740091151011_item	3644704	et	4	main
või	doc_740091151011_item	3644703	et	4	main
inimesed	doc_740091151011_item	3644702	et	3	main
kohe	doc_740091151011_item	3644691	et	4	main
kasutada	doc_740091151010_item	3644478	et	3	main
eesmärgil	doc_740091151010_item	3644477	et	3	main
õigel	doc_740091151010_item	3644476	et	3	main
ja	doc_740091151010_item	3644475	et	3	main
mõistlikult	doc_740091151010_item	3644474	et	4	main
võimalusi	doc_740091151010_item	3644473	et	3	main
neid	doc_740091151010_item	3644472	et	4	main
inimeste	doc_740091151010_item	3644470	et	3	main
sõltub	doc_740091151010_item	3644469	et	3	main
ka	doc_740091151010_item	3644467	et	3	main
see	doc_740091151010_item	3644466	et	3	main
kas	doc_740091151010_item	3644465	et	3	main
eeldused	doc_740091151010_item	3644461	et	4	main
öelda	doc_740091151010_item	3644456	et	4	main
seega	doc_740091151010_item	3644453	et	4	main
avaldada	doc_740091151010_item	3644445	et	3	main
internetis	doc_740091151010_item	3644442	et	4	main
enam	doc_740091151010_item	3644441	et	4	main
tõttu	doc_740091151010_item	3644440	et	4	main
kommentaaride	doc_740091151010_item	3644439	et	3	main
rumalate	doc_740091151010_item	3644438	et	3	main
soovi	doc_740091151010_item	3644437	et	4	main
ei	doc_740091151010_item	3644436	et	4	main
et	doc_740091151010_item	3644435	et	3	main
arengut	doc_740091151010_item	3644452	et	3	main
demokraatia	doc_740091151010_item	3644451	et	4	main
soodusta	doc_740091151010_item	3644450	et	4	main
ka	doc_740091151010_item	3644446	et	3	main
öelnud	doc_740091151010_item	3644434	et	4	main
on	doc_740091151010_item	3644433	et	4	main
käsitletud	doc_740091151010_item	3644427	et	4	main
teemat	doc_740091151010_item	3644425	et	3	main
võtnud	doc_740091151010_item	3644417	et	4	main
sõna	doc_740091151010_item	3644416	et	4	main
artiklis	doc_740091151010_item	3644415	et	3	main
autorit	doc_740091151010_item	3644414	et	3	main
artikli	doc_740091151010_item	3644413	et	3	main
solvavad	doc_740091151010_item	3644412	et	4	main
ka	doc_740091151010_item	3644408	et	3	main
nende	doc_740091151010_item	3644406	et	4	main
käsitlesin	doc_740091151010_item	3644403	et	3	main
mida	doc_740091151010_item	3644398	et	4	main
avaldada	doc_740091151010_item	3644395	et	3	main
võivad	doc_740091151010_item	3644394	et	4	main
mõju	doc_740091151010_item	3644393	et	4	main
negatiivset	doc_740091151010_item	3644392	et	3	main
inimeste	doc_740091151010_item	3644384	et	3	main
kuidagi	doc_740091151010_item	3644382	et	3	main
mis	doc_740091151010_item	3644379	et	4	main
prominenti	doc_740091151010_item	3644418	et	4	main
valguses	doc_740091151010_item	3644402	et	4	main
ega	doc_740091151010_item	3644387	et	3	main
üha	doc_740091151010_item	3644371	et	3	main
online-lehtede	doc_740091151010_item	3644367	et	2	main
kitseneb	doc_740091151010_item	3644365	et	3	main
sissetulek	doc_740091151010_item	3644363	et	3	main
müük	doc_740091151010_item	3644361	et	3	main
sõltub	doc_740091151010_item	3644359	et	3	main
rohkem	doc_740091151010_item	3644350	et	4	main
mis	doc_740091151010_item	3644348	et	4	main
teemadel	doc_740091151010_item	3644347	et	3	main
nendel	doc_740091151010_item	3644346	et	4	main
teemadevalikut	doc_740091151010_item	3644345	et	3	main
sellele	doc_740091151010_item	3644331	et	4	main
konkreetse	doc_740091151010_item	3644273	et	3	main
vastuseid	doc_740091151010_item	3644272	et	3	main
nõuda	doc_740091151010_item	3644271	et	3	main
ja	doc_740091151010_item	3644270	et	3	main
lisaks	doc_740091151010_item	3644258	et	4	main
suurem	doc_740091151010_item	3644255	et	4	main
siis	doc_740091151010_item	3644253	et	3	main
surfamist	doc_740091151010_item	3644247	et	4	main
keegi	doc_740091151010_item	3644244	et	4	main
ja	doc_740091151010_item	3644236	et	3	main
kõikjalt	doc_740091151010_item	3644234	et	3	main
uudiseid	doc_740091151010_item	3644233	et	3	main
kajastatakse	doc_740091151010_item	3644232	et	3	main
telekanalites	doc_740091151010_item	3644231	et	3	main
arvukamalt	doc_740091151010_item	3644228	et	4	main
küsimusele	doc_740091151010_item	3644223	et	4	main
ühiskonna	doc_740091151010_item	3644217	et	4	main
kuid	doc_740091151010_item	3644206	et	4	main
blogides	doc_740091151010_item	3644205	et	4	main
ja	doc_740091151010_item	3644204	et	3	main
interneti	doc_740091151010_item	3644176	et	4	main
paberlehtedes	doc_740091151010_item	3644311	et	4	main
on	doc_740091151011_item	3644713	et	4	main
üritus	doc_740091151011_item	3644711	et	4	main
see	doc_740091151011_item	3644710	et	3	main
kuid	doc_740091151011_item	3644571	et	4	main
on	doc_740091151011_item	3644565	et	4	main
loomulikult	doc_740091151011_item	3644558	et	4	main
kultuur	doc_740091151011_item	3644555	et	3	main
või	doc_740091151011_item	3644546	et	4	main
kaks	doc_740091151011_item	3644517	et	3	main
perekonnas	doc_740091151011_item	3644514	et	4	main
eestis	doc_740091151011_item	3644510	et	3	main
venelastest	doc_740091151011_item	3644507	et	4	main
elavates	doc_740091151011_item	3644506	et	4	main
riigi	doc_740091151011_item	3644486	et	3	main
kultuuriruum	doc_740091151011_item	3644485	et	3	main
ühine	doc_740091151011_item	3644484	et	4	main
venelased	doc_740091151011_item	3644483	et	3	main
ja	doc_740091151011_item	3644482	et	3	main
eestlased	doc_740091151011_item	3644481	et	3	main
või	doc_740091151011_item	3644700	et	4	main
öelda	doc_740091151011_item	3644693	et	4	main
täpselt	doc_740091151011_item	3644692	et	4	main
ta	doc_740091151011_item	3644658	et	4	main
telekanaleid	doc_740091151011_item	3644657	et	4	main
mis	doc_740091151011_item	3644656	et	4	main
indiviidi	doc_740091151011_item	3644653	et	4	main
iga	doc_740091151011_item	3644652	et	4	main
sõltub	doc_740091151011_item	3644651	et	3	main
kõik	doc_740091151011_item	3644650	et	4	main
siis	doc_740091151011_item	3644639	et	3	main
eristuvad	doc_740091151011_item	3644631	et	4	main
kelle	doc_740091151011_item	3644627	et	4	main
kooli	doc_740091151011_item	3644616	et	4	main
õppekeelega	doc_740091151011_item	3644615	et	3	main
olen	doc_740091151013_item	3644964	et	3	main
vahel	doc_740091151013_item	3644963	et	4	main
rahvuste	doc_740091151013_item	3644962	et	3	main
meelde	doc_740091151013_item	3644955	et	3	main
pidevalt	doc_740091151013_item	3644954	et	4	main
ning	doc_740091151013_item	3644953	et	3	main
eestimeelselt	doc_740091151013_item	3644952	et	4	main
kõik	doc_740091151013_item	3644944	et	4	main
sõbralikumalt	doc_740091151013_item	3644939	et	4	main
aeg	doc_740091151013_item	3644936	et	3	main
ma	doc_740091151010_item	3644399	et	3	main
kommentaarid	doc_740091151010_item	3644397	et	3	main
ka	doc_740091151010_item	3644396	et	3	main
maailmapildi	doc_740091151010_item	3644385	et	4	main
kaasa	doc_740091151010_item	3644383	et	4	main
aita	doc_740091151010_item	3644381	et	4	main
ei	doc_740091151010_item	3644380	et	4	main
lugusid	doc_740091151010_item	3644378	et	3	main
ja	doc_740091151010_item	3644370	et	3	main
seetõttu	doc_740091151010_item	3644364	et	3	main
ehk	doc_740091151010_item	3644362	et	3	main
reklaami	doc_740091151010_item	3644360	et	4	main
arvust	doc_740091151010_item	3644358	et	4	main
lugejate	doc_740091151010_item	3644357	et	4	main
sest	doc_740091151010_item	3644356	et	4	main
kirjutatakse	doc_740091151010_item	3644355	et	3	main
oma	doc_740091151010_item	3644343	et	4	main
leidub	doc_740091151010_item	3644330	et	3	main
väiksemaks	doc_740091151010_item	3644328	et	4	main
jäänud	doc_740091151010_item	3644327	et	4	main
oleks	doc_740091151010_item	3644326	et	3	main
võimalusi	doc_740091151010_item	3644264	et	3	main
valikuvabadus	doc_740091151010_item	3644257	et	4	main
ka	doc_740091151010_item	3644256	et	3	main
sagedamini	doc_740091151010_item	3644372	et	4	main
ka	doc_740091151010_item	3644366	et	3	main
rohkem	doc_740091151010_item	3644354	et	4	main
koguvad	doc_740091151010_item	3644349	et	4	main
mõjutavad	doc_740091151010_item	3644341	et	4	main
online-lehtedes	doc_740091151010_item	3644340	et	2	main
vastuargumente	doc_740091151010_item	3644339	et	3	main
ka	doc_740091151010_item	3644338	et	3	main
demokraatlikumaks	doc_740091151010_item	3644337	et	4	main
mõju	doc_740091151010_item	3644325	et	4	main
tulnud	doc_740091151010_item	3644322	et	4	main
välja	doc_740091151010_item	3644321	et	4	main
selgelt	doc_740091151010_item	3644320	et	4	main
nii	doc_740091151010_item	3644319	et	3	main
arvamused	doc_740091151010_item	3644318	et	3	main
inimeste	doc_740091151010_item	3644317	et	3	main
poleks	doc_740091151010_item	3644316	et	3	main
oma	doc_740091151010_item	3644292	et	4	main
internetikommentaariumites	doc_740091151010_item	3644291	et	4	main
said	doc_740091151010_item	3644290	et	4	main
inimesed	doc_740091151010_item	3644289	et	3	main
eest	doc_740091151010_item	3644288	et	4	main
kõneminuti	doc_740091151010_item	3644287	et	3	main
alustatud	doc_740091151010_item	3644286	et	4	main
iga	doc_740091151010_item	3644285	et	4	main
tasu	doc_740091151010_item	3644284	et	4	main
küsida	doc_740091151010_item	3644283	et	3	main
plaanile	doc_740091151010_item	3644282	et	3	main
emt	doc_740091151010_item	3644281	et	4	main
mobiilioperaatori	doc_740091151010_item	3644280	et	4	main
vastuseisu	doc_740091151010_item	3644279	et	4	main
inimeste	doc_740091151010_item	3644278	et	3	main
tuua	doc_740091151010_item	3644277	et	3	main
siin	doc_740091151010_item	3644276	et	4	main
võib	doc_740091151010_item	3644275	et	3	main
näitena	doc_740091151010_item	3644274	et	3	main
tagasisidet	doc_740091151010_item	3644269	et	4	main
anda	doc_740091151010_item	3644268	et	3	main
ühiskondlikes	doc_740091151010_item	3644265	et	3	main
inimeste	doc_740091151010_item	3644263	et	3	main
areng	doc_740091151010_item	3644261	et	3	main
piira	doc_740091151010_item	3644252	et	4	main
ei	doc_740091151010_item	3644251	et	4	main
jõudvates	doc_740091151010_item	3644230	et	4	main
ja	doc_740091151010_item	3644226	et	3	main
avaldamiseks	doc_740091151010_item	3644215	et	4	main
kommentaariumites	doc_740091151010_item	3644203	et	4	main
uudisteportaalides	doc_740091151010_item	3644202	et	3	main
näiteks	doc_740091151010_item	3644175	et	4	main
ühiskonna	doc_740091151010_item	3644170	et	4	main
kas	doc_740091151010_item	3644166	et	3	main
siis	doc_740091151010_item	3644315	et	3	main
televisioonis	doc_740091151010_item	3644314	et	4	main
või	doc_740091151010_item	3644313	et	4	main
raadios	doc_740091151010_item	3644312	et	3	main
oma	doc_740091151011_item	3644723	et	4	main
tuua	doc_740091151011_item	3644717	et	3	main
võib	doc_740091151011_item	3644716	et	3	main
selliseid	doc_740091151011_item	3644714	et	4	main
see	doc_740091151011_item	3644576	et	3	main
mõjutavad	doc_740091151011_item	3644570	et	4	main
siin	doc_740091151011_item	3644564	et	4	main
siis	doc_740091151011_item	3644563	et	3	main
kultuuri	doc_740091151011_item	3644562	et	4	main
org-ni	doc_740091151011_item	3644561	et	3	main
sees	doc_740091151011_item	3644557	et	4	main
vene	doc_740091151011_item	3644547	et	4	main
näiteks	doc_740091151011_item	3644540	et	4	main
järge	doc_740091151011_item	3644538	et	4	main
kus	doc_740091151011_item	3644513	et	3	main
on	doc_740091151011_item	3644493	et	4	main
essee	doc_740091151011_item	3644480	et	4	main
saab	doc_740091151011_item	3644705	et	3	main
vanemad	doc_740091151011_item	3644699	et	4	main
küll	doc_740091151011_item	3644644	et	4	main
on	doc_740091151010_item	3644254	et	4	main
teleri	doc_740091151010_item	3644249	et	3	main
enamasti	doc_740091151010_item	3644245	et	4	main
kuna	doc_740091151010_item	3644243	et	3	main
ja	doc_740091151010_item	3644242	et	3	main
suurendab	doc_740091151010_item	3644240	et	3	main
teemadel	doc_740091151010_item	3644238	et	3	main
maailmat	doc_740091151010_item	3644235	et	4	main
sellele	doc_740091151010_item	3644222	et	4	main
vastaksin	doc_740091151010_item	3644221	et	3	main
muudavad	doc_740091151010_item	3644216	et	4	main
hankimiseks	doc_740091151010_item	3644211	et	4	main
võimalused	doc_740091151010_item	3644209	et	3	main
avaramad	doc_740091151010_item	3644208	et	4	main
kas	doc_740091151010_item	3644207	et	3	main
kõik	doc_740091151010_item	3644198	et	4	main
arvamust	doc_740091151010_item	3644197	et	3	main
oma	doc_740091151010_item	3644196	et	4	main
kohta	doc_740091151010_item	3644195	et	4	main
probleemide	doc_740091151010_item	3644194	et	3	main
tõstatatud	doc_740091151010_item	3644193	et	4	main
meedial	doc_740091151010_item	3644192	et	4	main
avaldada	doc_740091151010_item	3644191	et	3	main
toimuvast	doc_740091151010_item	3644189	et	4	main
ning	doc_740091151010_item	3644190	et	3	main
kaugel	doc_740091151010_item	3644188	et	4	main
infot	doc_740091151010_item	3644187	et	3	main
saada	doc_740091151010_item	3644186	et	4	main
nägemata	doc_740091151010_item	3644185	et	4	main
teineteist	doc_740091151010_item	3644184	et	4	main
ja	doc_740091151010_item	3644183	et	3	main
kiirelt	doc_740091151010_item	3644182	et	4	main
suhelda	doc_740091151010_item	3644181	et	4	main
võimaluse	doc_740091151010_item	3644180	et	3	main
inimestele	doc_740091151010_item	3644179	et	3	main
näol	doc_740091151010_item	3644177	et	4	main
andnud	doc_740091151010_item	3644178	et	4	main
on	doc_740091151010_item	3644174	et	4	main
valikuvõimalusi	doc_740091151010_item	3644241	et	3	main
see	doc_740091151010_item	3644239	et	3	main
igasugustel	doc_740091151010_item	3644237	et	3	main
meieni	doc_740091151010_item	3644229	et	4	main
üha	doc_740091151010_item	3644227	et	3	main
mõtlemata	doc_740091151010_item	3644220	et	4	main
pikemalt	doc_740091151010_item	3644219	et	4	main
mõtete	doc_740091151010_item	3644214	et	3	main
oma	doc_740091151010_item	3644213	et	4	main
info	doc_740091151010_item	3644210	et	4	main
toimub	doc_740091151010_item	3644200	et	3	main
see	doc_740091151010_item	3644199	et	3	main
muudab	doc_740091151010_item	3644169	et	3	main
kommunikatsioonitehnoloogia	doc_740091151010_item	3644167	et	4	main
venelased	doc_740091151011_item	3644722	et	3	main
on	doc_740091151011_item	3644721	et	4	main
keskkonda	doc_740091151011_item	3644583	et	4	main
mõjutada	doc_740091151011_item	3644582	et	3	main
võib	doc_740091151011_item	3644581	et	3	main
rahvus	doc_740091151011_item	3644580	et	3	main
kuidas	doc_740091151011_item	3644579	et	3	main
näide	doc_740091151011_item	3644578	et	3	main
hea	doc_740091151011_item	3644577	et	4	main
raames	doc_740091151011_item	3644574	et	4	main
seda	doc_740091151011_item	3644569	et	3	main
sellest	doc_740091151011_item	3644550	et	4	main
ja	doc_740091151011_item	3644549	et	3	main
on	doc_740091151011_item	3644543	et	4	main
areng	doc_740091151010_item	3644173	et	3	main
areng	doc_740091151010_item	3644168	et	3	main
essee	doc_740091151010_item	3644165	et	4	main
kõneldud	doc_740091151010_item	3644309	et	4	main
oleks	doc_740091151010_item	3644308	et	3	main
antud	doc_740091151010_item	3644306	et	4	main
kui	doc_740091151010_item	3644305	et	3	main
loobuda	doc_740091151010_item	3644304	et	3	main
plaanist	doc_740091151010_item	3644303	et	3	main
oma	doc_740091151010_item	3644302	et	4	main
emt	doc_740091151010_item	3644301	et	4	main
otsustas	doc_740091151010_item	3644300	et	3	main
tõttu	doc_740091151010_item	3644299	et	4	main
vastukaja	doc_740091151010_item	3644298	et	4	main
negatiivse	doc_740091151010_item	3644297	et	3	main
väga	doc_740091151010_item	3644296	et	3	main
ja	doc_740091151010_item	3644295	et	3	main
avaldada	doc_740091151010_item	3644294	et	3	main
arvamust	doc_740091151010_item	3644293	et	3	main
kultuuriruumi	doc_740091151011_item	3644737	et	4	main
ühise	doc_740091151011_item	3644736	et	3	main
moodustavadgi	doc_740091151011_item	3644735	et	4	main
segmendid	doc_740091151011_item	3644734	et	3	main
need	doc_740091151011_item	3644733	et	3	main
olla	doc_740091151011_item	3644732	et	3	main
võib	doc_740091151011_item	3644731	et	3	main
kuid	doc_740091151011_item	3644730	et	4	main
kultuuriga	doc_740091151011_item	3644729	et	4	main
oma	doc_740091151011_item	3644728	et	4	main
eestlased	doc_740091151011_item	3644727	et	3	main
on	doc_740091151011_item	3644726	et	4	main
kultuuriga	doc_740091151011_item	3644724	et	4	main
ka	doc_740091151011_item	3644718	et	3	main
mis	doc_740091151011_item	3644568	et	4	main
puudutab	doc_740091151011_item	3644560	et	3	main
omad	doc_740091151011_item	3644548	et	4	main
mis	doc_740091151011_item	3644542	et	4	main
firmasid	doc_740091151011_item	3644541	et	3	main
nende	doc_740091151011_item	3644536	et	4	main
teisest	doc_740091151011_item	3644535	et	4	main
teine	doc_740091151011_item	3644534	et	3	main
eraldatud	doc_740091151011_item	3644533	et	4	main
nagu	doc_740091151011_item	3644532	et	3	main
inimesed	doc_740091151011_item	3644531	et	3	main
elavad	doc_740091151011_item	3644530	et	4	main
eestis	doc_740091151011_item	3644529	et	3	main
kus	doc_740091151011_item	3644528	et	3	main
valdkondi	doc_740091151011_item	3644527	et	4	main
on	doc_740091151011_item	3644525	et	4	main
mittu	doc_740091151011_item	3644526	et	4	main
küljest	doc_740091151011_item	3644524	et	4	main
teisest	doc_740091151011_item	3644523	et	4	main
kedagi	doc_740091151011_item	3644522	et	4	main
üllata	doc_740091151011_item	3644521	et	4	main
ei	doc_740091151011_item	3644520	et	4	main
lapsel	doc_740091151011_item	3644519	et	4	main
emakeelt	doc_740091151011_item	3644518	et	4	main
nähtus	doc_740091151011_item	3644512	et	4	main
sündinud	doc_740091151011_item	3644511	et	4	main
ka	doc_740091151011_item	3644509	et	3	main
paljud	doc_740091151011_item	3644504	et	3	main
väga	doc_740091151011_item	3644503	et	3	main
juba	doc_740091151011_item	3644501	et	3	main
kõrvuti	doc_740091151011_item	3644500	et	3	main
et	doc_740091151011_item	3644491	et	3	main
ütleks	doc_740091151011_item	3644490	et	3	main
süvenemata	doc_740091151011_item	3644489	et	4	main
on	doc_740091151011_item	3644698	et	4	main
kontingent	doc_740091151011_item	3644697	et	3	main
peamine	doc_740091151011_item	3644696	et	3	main
nende	doc_740091151011_item	3644695	et	4	main
kes	doc_740091151011_item	3644694	et	4	main
võib	doc_740091151011_item	3644690	et	3	main
võiks	doc_740091151011_item	3644664	et	4	main
nimelt	doc_740091151011_item	3644655	et	4	main
kooli	doc_740091151011_item	3644633	et	4	main
vene	doc_740091151011_item	3644621	et	4	main
on	doc_740091151011_item	3644620	et	4	main
vene	doc_740091151011_item	3644614	et	4	main
on	doc_740091151011_item	3644611	et	4	main
lugu	doc_740091151011_item	3644607	et	4	main
tööd	doc_740091151011_item	3644604	et	4	main
vene	doc_740091151013_item	3644974	et	4	main
mind	doc_740091151013_item	3644948	et	4	main
kuigi	doc_740091151013_item	3644947	et	3	main
koos	doc_740091151013_item	3644945	et	4	main
pinnal	doc_740091151013_item	3644943	et	3	main
eestimaa	doc_740091151013_item	3644942	et	4	main
vahel	doc_740091151013_item	3644911	et	4	main
käisin	doc_740091151013_item	3644903	et	3	main
järgi	doc_740091151013_item	3644899	et	4	main
lahterda	doc_740091151013_item	3644896	et	4	main
keelt	doc_740091151013_item	3644887	et	4	main
vaatamata	doc_740091151013_item	3644879	et	4	main
nagu	doc_740091151011_item	3644516	et	3	main
on	doc_740091151011_item	3644508	et	4	main
siin	doc_740091151011_item	3644499	et	4	main
elavad	doc_740091151011_item	3644498	et	4	main
venelased	doc_740091151011_item	3644497	et	3	main
ja	doc_740091151011_item	3644496	et	3	main
eestlased	doc_740091151011_item	3644495	et	3	main
olemas	doc_740091151011_item	3644494	et	4	main
teemasse	doc_740091151011_item	3644488	et	4	main
tasandil	doc_740091151011_item	3644487	et	3	main
nooremad	doc_740091151011_item	3644701	et	4	main
kohta	doc_740091151011_item	3644689	et	4	main
ürituste	doc_740091151011_item	3644688	et	4	main
igasuguste	doc_740091151011_item	3644687	et	3	main
toimuvate	doc_740091151011_item	3644686	et	4	main
eestis	doc_740091151011_item	3644685	et	3	main
siin	doc_740091151011_item	3644684	et	4	main
näiteks	doc_740091151011_item	3644683	et	4	main
ja	doc_740091151011_item	3644682	et	3	main
elab	doc_740091151011_item	3644681	et	3	main
ta	doc_740091151011_item	3644680	et	4	main
uudistega	doc_740091151011_item	3644679	et	3	main
milliste	doc_740091151011_item	3644678	et	3	main
samastab	doc_740091151011_item	3644677	et	3	main
ennast	doc_740091151011_item	3644676	et	4	main
venelane	doc_740091151011_item	3644675	et	3	main
elav	doc_740091151011_item	3644674	et	4	main
siin	doc_740091151011_item	3644673	et	4	main
riigiga	doc_740091151011_item	3644672	et	3	main
mis	doc_740091151011_item	3644671	et	4	main
tähts	doc_740091151011_item	3644670	et	4	main
on	doc_740091151011_item	3644669	et	4	main
et	doc_740091151011_item	3644668	et	3	main
seda	doc_740091151011_item	3644667	et	3	main
ka	doc_740091151011_item	3644666	et	3	main
mainida	doc_740091151011_item	3644665	et	3	main
siin	doc_740091151011_item	3644663	et	4	main
loeb	doc_740091151011_item	3644662	et	3	main
lehte	doc_740091151011_item	3644661	et	4	main
millised	doc_740091151011_item	3644660	et	3	main
vaatab	doc_740091151011_item	3644659	et	3	main
kuid	doc_740091151011_item	3644649	et	4	main
allikad	doc_740091151011_item	3644648	et	3	main
ja	doc_740091151011_item	3644647	et	3	main
võimalused	doc_740091151011_item	3644646	et	3	main
samad	doc_740091151011_item	3644645	et	3	main
inimestel	doc_740091151011_item	3644642	et	3	main
eestis	doc_740091151011_item	3644640	et	3	main
puudutab	doc_740091151011_item	3644637	et	3	main
hoiakud	doc_740091151011_item	3644630	et	3	main
ja	doc_740091151011_item	3644629	et	3	main
õppemeetodid	doc_740091151011_item	3644628	et	3	main
vanu	doc_740091151011_item	3644625	et	4	main
eesti	doc_740091151011_item	3644612	et	4	main
organiseerivad	doc_740091151011_item	3644605	et	4	main
oma	doc_740091151011_item	3644603	et	4	main
näiteks	doc_740091151011_item	3644602	et	4	main
nad	doc_740091151011_item	3644601	et	3	main
mitmeid	doc_740091151013_item	3644973	et	4	main
tutvusringkonnas	doc_740091151013_item	3644971	et	4	main
minu	doc_740091151013_item	3644970	et	3	main
ka	doc_740091151013_item	3644969	et	3	main
et	doc_740091151013_item	3644968	et	3	main
märganud	doc_740091151013_item	3644967	et	4	main
piiri	doc_740091151013_item	3644961	et	4	main
rõhutatud	doc_740091151013_item	3644960	et	4	main
ja	doc_740091151013_item	3644959	et	3	main
ajalugu	doc_740091151013_item	3644958	et	4	main
väga	doc_740091151013_item	3644951	et	3	main
ja	doc_740091151013_item	3644913	et	3	main
täpsem	doc_740091151013_item	3644912	et	4	main
oli	doc_740091151013_item	3644905	et	3	main
ma	doc_740091151013_item	3644901	et	3	main
rahvuse	doc_740091151013_item	3644898	et	3	main
noored	doc_740091151013_item	3644883	et	3	main
eesti	doc_740091151013_item	3644882	et	4	main
valikust	doc_740091151011_item	3644654	et	4	main
on	doc_740091151011_item	3644643	et	4	main
elavatel	doc_740091151011_item	3644641	et	4	main
meediat	doc_740091151011_item	3644638	et	3	main
mis	doc_740091151011_item	3644636	et	4	main
omadest	doc_740091151011_item	3644635	et	3	main
õpetajate	doc_740091151011_item	3644634	et	4	main
hetkel	doc_740091151011_item	3644619	et	4	main
praegusel	doc_740091151011_item	3644618	et	3	main
ja	doc_740091151011_item	3644617	et	3	main
sarnane	doc_740091151011_item	3644606	et	4	main
rahvusest	doc_740091151013_item	3644975	et	4	main
on	doc_740091151013_item	3644972	et	4	main
tuletatud	doc_740091151013_item	3644956	et	4	main
kasvatatud	doc_740091151013_item	3644950	et	4	main
eksisteerida	doc_740091151013_item	3644946	et	3	main
suudame	doc_740091151013_item	3644940	et	3	main
edasi	doc_740091151013_item	3644937	et	3	main
on	doc_740091151013_item	3644890	et	4	main
palju	doc_740091151013_item	3644885	et	4	main
väga	doc_740091151013_item	3644884	et	3	main
on	doc_740091151013_item	3644875	et	4	main
on	doc_740091151013_item	3644865	et	4	main
kuidas	doc_740091151013_item	3644864	et	3	main
viidi	doc_740091151013_item	3644863	et	4	main
noorusaja	doc_740091151013_item	3644857	et	3	main
hakkas	doc_740091151013_item	3644853	et	3	main
uskuda	doc_740091151013_item	3644844	et	3	main
suutnud	doc_740091151013_item	3644843	et	4	main
hämmingus	doc_740091151013_item	3644837	et	3	main
ülistavad	doc_740091151013_item	3644817	et	4	main
ja	doc_740091151013_item	3644816	et	3	main
pikad	doc_740091151013_item	3644815	et	4	main
eesti	doc_740091151013_item	3644811	et	4	main
enda	doc_740091151013_item	3644808	et	4	main
pere	doc_740091151013_item	3644805	et	4	main
vene	doc_740091151013_item	3644804	et	4	main
kuidas	doc_740091151013_item	3644803	et	3	main
telesaated	doc_740091151013_item	3644802	et	3	main
meediakajastused	doc_740091151013_item	3644801	et	3	main
aastad	doc_740091151013_item	3644793	et	3	main
venelaste	doc_740091151013_item	3644780	et	4	main
ja	doc_740091151013_item	3644779	et	3	main
eesti	doc_740091151011_item	3644632	et	4	main
õpetajaid	doc_740091151011_item	3644626	et	4	main
ka	doc_740091151011_item	3644624	et	3	main
veel	doc_740091151011_item	3644623	et	4	main
koolides	doc_740091151011_item	3644622	et	3	main
ja	doc_740091151011_item	3644613	et	3	main
meil	doc_740091151011_item	3644610	et	4	main
koolidega	doc_740091151011_item	3644609	et	3	main
ka	doc_740091151011_item	3644608	et	3	main
kuidas	doc_740091151011_item	3644600	et	3	main
selles	doc_740091151011_item	3644599	et	4	main
väljendub	doc_740091151011_item	3644598	et	3	main
see	doc_740091151011_item	3644597	et	3	main
ja	doc_740091151011_item	3644596	et	3	main
poolest	doc_740091151011_item	3644595	et	4	main
temperamenti	doc_740091151011_item	3644594	et	4	main
ja	doc_740091151011_item	3644593	et	3	main
iseloomu	doc_740091151011_item	3644592	et	4	main
oma	doc_740091151011_item	3644591	et	4	main
erinevad	doc_740091151011_item	3644590	et	4	main
väga	doc_740091151011_item	3644589	et	3	main
lihtsalt	doc_740091151011_item	3644588	et	4	main
on	doc_740091151011_item	3644587	et	4	main
venelased	doc_740091151011_item	3644586	et	3	main
eksisteerimine	doc_740091151013_item	3645134	et	4	main
koos	doc_740091151013_item	3645133	et	4	main
peetri	doc_740091151013_item	3645132	et	3	main
ajal	doc_740091151013_item	3644966	et	4	main
viimasel	doc_740091151013_item	3644965	et	3	main
meie	doc_740091151013_item	3644957	et	4	main
on	doc_740091151013_item	3644949	et	4	main
siin	doc_740091151013_item	3644941	et	4	main
seda	doc_740091151013_item	3644938	et	3	main
mida	doc_740091151013_item	3644935	et	4	main
et	doc_740091151013_item	3644934	et	3	main
usun	doc_740091151013_item	3644933	et	3	main
üldjoontes	doc_740091151013_item	3644932	et	3	main
kuid	doc_740091151013_item	3644931	et	4	main
vaenuõhutajaid	doc_740091151013_item	3644930	et	3	main
ja	doc_740091151013_item	3644929	et	3	main
intriigitsejaid	doc_740091151013_item	3644928	et	4	main
ole	doc_740091151013_item	3644927	et	4	main
seltskonnas	doc_740091151013_item	3644926	et	3	main
igas	doc_740091151013_item	3644925	et	3	main
eks	doc_740091151013_item	3644924	et	3	main
teevad	doc_740091151013_item	3644923	et	3	main
seda	doc_740091151013_item	3644922	et	3	main
noored	doc_740091151013_item	3644921	et	3	main
praegused	doc_740091151013_item	3644920	et	3	main
kui	doc_740091151013_item	3644919	et	3	main
nii	doc_740091151013_item	3644917	et	3	main
omavahel	doc_740091151013_item	3644916	et	3	main
suheldud	doc_740091151013_item	3644915	et	4	main
palju	doc_740091151013_item	3644918	et	4	main
ei	doc_740091151013_item	3644914	et	4	main
venelaste	doc_740091151013_item	3644910	et	4	main
ja	doc_740091151013_item	3644909	et	3	main
eestlaste	doc_740091151013_item	3644908	et	4	main
piir	doc_740091151013_item	3644907	et	3	main
see	doc_740091151013_item	3644906	et	3	main
keskkoolis	doc_740091151013_item	3644902	et	4	main
kui	doc_740091151013_item	3644900	et	3	main
inimesi	doc_740091151013_item	3644897	et	4	main
räägi	doc_740091151013_item	3644889	et	4	main
ei	doc_740091151013_item	3644888	et	4	main
et	doc_740091151013_item	3644881	et	3	main
on	doc_740091151013_item	3644870	et	4	main
milline	doc_740091151013_item	3644869	et	3	main
kohelnud	doc_740091151013_item	3644868	et	4	main
eestlasi	doc_740091151013_item	3644867	et	3	main
venelased	doc_740091151013_item	3644866	et	3	main
tema	doc_740091151013_item	3644860	et	4	main
kuidas	doc_740091151013_item	3644859	et	3	main
lugusid	doc_740091151013_item	3644858	et	3	main
miks	doc_740091151013_item	3644845	et	4	main
mäletan	doc_740091151013_item	3644838	et	3	main
ajalehtedes	doc_740091151013_item	3644813	et	4	main
hoole	doc_740091151013_item	3644809	et	4	main
suveks	doc_740091151013_item	3644807	et	3	main
seoses	doc_740091151013_item	3644797	et	4	main
edukalt	doc_740091151013_item	3644796	et	4	main
väga	doc_740091151013_item	3644795	et	3	main
tagasi	doc_740091151013_item	3644794	et	3	main
mõned	doc_740091151013_item	3644792	et	3	main
meile	doc_740091151013_item	3644788	et	4	main
see	doc_740091151013_item	3644786	et	3	main
paremaks	doc_740091151013_item	3644784	et	4	main
problemaatilisemaks	doc_740091151013_item	3644775	et	4	main
siis	doc_740091151013_item	3644904	et	3	main
ei	doc_740091151013_item	3644895	et	4	main
ja	doc_740091151013_item	3644894	et	3	main
suhtlemisaltid	doc_740091151013_item	3644893	et	3	main
alati	doc_740091151013_item	3644892	et	4	main
nad	doc_740091151013_item	3644891	et	3	main
vene	doc_740091151013_item	3644886	et	4	main
sellele	doc_740091151013_item	3644880	et	4	main
generatsioon	doc_740091151013_item	3644874	et	3	main
me	doc_740091151013_item	3644846	et	4	main
et	doc_740091151013_item	3644839	et	3	main
osalenute	doc_740091151013_item	3644820	et	4	main
projektis	doc_740091151013_item	3644819	et	3	main
lapsed	doc_740091151013_item	3644812	et	3	main
integratsiooniprojektid	doc_740091151013_item	3644790	et	3	main
kas	doc_740091151013_item	3644785	et	3	main
kunagi	doc_740091151013_item	3644783	et	3	main
muutub	doc_740091151013_item	3644782	et	3	main
veelgi	doc_740091151013_item	3644774	et	4	main
seda	doc_740091151013_item	3644754	et	3	main
teema	doc_740091151013_item	3644753	et	4	main
populaarne	doc_740091151013_item	3644752	et	3	main
väga	doc_740091151013_item	3644751	et	3	main
ja	doc_740091151013_item	3644743	et	3	main
dimat	doc_740091151013_item	3644742	et	4	main
sa	doc_740091151013_item	3644741	et	3	main
essee	doc_740091151013_item	3644739	et	4	main
kuid	doc_740091151013_item	3645125	et	4	main
me	doc_740091151013_item	3645123	et	4	main
keelt	doc_740091151013_item	3645122	et	4	main
kus	doc_740091151013_item	3645116	et	3	main
ka	doc_740091151013_item	3645115	et	3	main
meie	doc_740091151013_item	3645107	et	4	main
pidada	doc_740091151013_item	3645106	et	4	main
pühaks	doc_740091151013_item	3645105	et	3	main
ja	doc_740091151013_item	3645104	et	3	main
hümni	doc_740091151013_item	3645103	et	4	main
peast	doc_740091151013_item	3645101	et	4	main
ajalugu	doc_740091151013_item	3645099	et	4	main
on	doc_740091151013_item	3645093	et	4	main
vanaema	doc_740091151013_item	3645091	et	4	main
või	doc_740091151013_item	3645090	et	4	main
minu	doc_740091151013_item	3645088	et	3	main
mina	doc_740091151013_item	3645087	et	4	main
kokku	doc_740091151013_item	3645085	et	3	main
vähem	doc_740091151013_item	3645084	et	4	main
kui	doc_740091151013_item	3645086	et	3	main
siiralt	doc_740091151013_item	3645077	et	4	main
loodan	doc_740091151013_item	3645076	et	3	main
haridust	doc_740091151013_item	3645075	et	4	main
saada	doc_740091151013_item	3645073	et	4	main
ja	doc_740091151013_item	3645072	et	3	main
läbi	doc_740091151013_item	3645068	et	4	main
palju	doc_740091151013_item	3644877	et	4	main
noorem	doc_740091151013_item	3644873	et	4	main
meie	doc_740091151013_item	3644871	et	4	main
siberisse	doc_740091151013_item	3644862	et	4	main
oma	doc_740091151013_item	3644856	et	4	main
ta	doc_740091151013_item	3644854	et	4	main
ei	doc_740091151013_item	3644842	et	4	main
oli	doc_740091151013_item	3644836	et	3	main
generatsioon	doc_740091151013_item	3644835	et	3	main
vanem	doc_740091151013_item	3644834	et	4	main
kuid	doc_740091151013_item	3644833	et	4	main
minimaalset	doc_740091151013_item	3644832	et	3	main
väga	doc_740091151013_item	3644831	et	3	main
vastukaja	doc_740091151013_item	3644830	et	4	main
negatiivset	doc_740091151013_item	3644829	et	3	main
jõudis	doc_740091151013_item	3644828	et	3	main
meediasse	doc_740091151013_item	3644827	et	4	main
raadiosaated	doc_740091151013_item	3644826	et	3	main
ka	doc_740091151013_item	3644825	et	3	main
jäänud	doc_740091151013_item	3644824	et	4	main
ei	doc_740091151013_item	3644823	et	4	main
puutumata	doc_740091151013_item	3644822	et	4	main
kohta	doc_740091151013_item	3644821	et	4	main
leplikum	doc_740091151013_item	3644878	et	4	main
aga	doc_740091151013_item	3644876	et	3	main
ajalugu	doc_740091151013_item	3644872	et	4	main
vanemad	doc_740091151013_item	3644861	et	4	main
rääkima	doc_740091151013_item	3644855	et	3	main
perioodil	doc_740091151013_item	3644852	et	3	main
sellel	doc_740091151013_item	3644851	et	4	main
just	doc_740091151013_item	3644850	et	3	main
sõbruneda	doc_740091151013_item	3644849	et	3	main
vaenlasega	doc_740091151013_item	3644848	et	3	main
soovime	doc_740091151013_item	3644847	et	4	main
vanaema	doc_740091151013_item	3644841	et	4	main
minu	doc_740091151013_item	3644840	et	3	main
olid	doc_740091151013_item	3644814	et	4	main
alla	doc_740091151013_item	3644810	et	3	main
võttis	doc_740091151013_item	3644806	et	3	main
toimusid	doc_740091151013_item	3644799	et	4	main
sellega	doc_740091151013_item	3644798	et	3	main
käivitusid	doc_740091151013_item	3644791	et	4	main
vahel	doc_740091151013_item	3644781	et	4	main
läbisaamine	doc_740091151013_item	3644777	et	4	main
lõhe	doc_740091151013_item	3644768	et	4	main
saatnud	doc_740091151013_item	3644756	et	4	main
on	doc_740091151013_item	3644747	et	4	main
integratsioon	doc_740091151013_item	3644746	et	3	main
dima	doc_740091151013_item	3645130	et	4	main
ka	doc_740091151013_item	3645129	et	3	main
oluline	doc_740091151013_item	3645128	et	4	main
me	doc_740091151013_item	3645118	et	4	main
unustada	doc_740091151013_item	3645114	et	3	main
tohi	doc_740091151013_item	3645112	et	4	main
ei	doc_740091151013_item	3645111	et	4	main
kindlasti	doc_740091151013_item	3645110	et	3	main
eesti	doc_740091151013_item	3645102	et	4	main
rahva	doc_740091151013_item	3645098	et	3	main
pidada	doc_740091151013_item	3645096	et	4	main
meeles	doc_740091151013_item	3645095	et	3	main
tähtis	doc_740091151013_item	3645094	et	4	main
probleemiga	doc_740091151013_item	3645083	et	4	main
selle	doc_740091151013_item	3645082	et	4	main
ei	doc_740091151013_item	3645031	et	4	main
järgi	doc_740091151013_item	3645021	et	4	main
sünniaasta	doc_740091151013_item	3645020	et	4	main
töövestlustel	doc_740091151013_item	3645019	et	3	main
kuuleb	doc_740091151013_item	3645018	et	3	main
tihedamini	doc_740091151013_item	3645017	et	4	main
aina	doc_740091151013_item	3645016	et	4	main
projekte	doc_740091151013_item	3645015	et	3	main
arusaamatused	doc_740091151013_item	3645007	et	4	main
valestimõistmised	doc_740091151013_item	3645006	et	3	main
tekivad	doc_740091151013_item	3645005	et	3	main
sellega	doc_740091151013_item	3645004	et	3	main
seoses	doc_740091151013_item	3645003	et	4	main
muu	doc_740091151013_item	3644995	et	4	main
inimese	doc_740091151013_item	3644991	et	4	main
loovad	doc_740091151013_item	3644986	et	4	main
ju	doc_740091151013_item	3644979	et	3	main
oma	doc_740091151015_item	3645401	et	4	main
enamus	doc_740091151015_item	3645399	et	4	main
istun	doc_740091151015_item	3645398	et	3	main
mina	doc_740091151015_item	3645397	et	4	main
artiklid	doc_740091151013_item	3644818	et	3	main
mitmed	doc_740091151013_item	3644800	et	4	main
vajalik	doc_740091151013_item	3644789	et	3	main
on	doc_740091151013_item	3644787	et	4	main
kas	doc_740091151013_item	3644776	et	3	main
muutunud	doc_740091151013_item	3644773	et	4	main
on	doc_740091151013_item	3644772	et	4	main
vahel	doc_740091151013_item	3644771	et	4	main
rahvuse	doc_740091151013_item	3644770	et	3	main
kahe	doc_740091151013_item	3644769	et	3	main
olnud	doc_740091151013_item	3644762	et	4	main
on	doc_740091151013_item	3644755	et	4	main
aastatel	doc_740091151013_item	3644750	et	4	main
viimastel	doc_740091151013_item	3644749	et	3	main
olnud	doc_740091151013_item	3644748	et	4	main
tead	doc_740091151013_item	3644745	et	4	main
peetrit	doc_740091151013_item	3644744	et	3	main
kas	doc_740091151013_item	3644740	et	3	main
ja	doc_740091151013_item	3645131	et	3	main
räägime	doc_740091151013_item	3645124	et	3	main
riigis	doc_740091151013_item	3645117	et	3	main
laulda	doc_740091151013_item	3645100	et	4	main
oma	doc_740091151013_item	3645097	et	4	main
muidugi	doc_740091151013_item	3645092	et	4	main
ema	doc_740091151013_item	3645089	et	4	main
karjääri	doc_740091151013_item	3645070	et	4	main
rahvusest	doc_740091151013_item	3645063	et	4	main
vene	doc_740091151013_item	3645062	et	4	main
keelt	doc_740091151013_item	3645054	et	4	main
venelastel	doc_740091151013_item	3645050	et	4	main
aga	doc_740091151013_item	3645049	et	3	main
nii	doc_740091151013_item	3645043	et	3	main
keelt	doc_740091151013_item	3645030	et	4	main
vaja	doc_740091151013_item	3645013	et	4	main
loodud	doc_740091151013_item	3645002	et	4	main
eelarvamused	doc_740091151013_item	3645001	et	3	main
teise	doc_740091151013_item	3644990	et	4	main
inimene	doc_740091151013_item	3644981	et	3	main
on	doc_740091151013_item	3644978	et	4	main
tähtis	doc_740091151013_item	3644977	et	4	main
noori	doc_740091151013_item	3644976	et	3	main
ajast	doc_740091151015_item	3645400	et	4	main
kõik	doc_740091151015_item	3645392	et	4	main
pubi	doc_740091151015_item	3645391	et	4	main
kohvik	doc_740091151015_item	3645390	et	3	main
teater	doc_740091151015_item	3645389	et	3	main
võimalusi	doc_740091151015_item	3645384	et	3	main
reaalset	doc_740091151015_item	3645379	et	3	main
mina	doc_740091151015_item	3645364	et	4	main
saavutanud	doc_740091151015_item	3645356	et	4	main
kumbki	doc_740091151015_item	3645348	et	4	main
me	doc_740091151015_item	3645347	et	4	main
tema	doc_740091151015_item	3645345	et	4	main
oli	doc_740091151015_item	3645339	et	3	main
naine	doc_740091151015_item	3645338	et	3	main
maha	doc_740091151015_item	3645336	et	4	main
nagu	doc_740091151015_item	3645322	et	3	main
on	doc_740091151015_item	3645318	et	4	main
kuid	doc_740091151015_item	3645316	et	4	main
mind	doc_740091151015_item	3645312	et	4	main
eestlaste	doc_740091151013_item	3644778	et	4	main
kuna	doc_740091151013_item	3644767	et	3	main
keeruline	doc_740091151013_item	3644766	et	4	main
väga	doc_740091151013_item	3644765	et	3	main
teema	doc_740091151013_item	3644764	et	4	main
see	doc_740091151013_item	3644763	et	3	main
on	doc_740091151013_item	3644761	et	4	main
aprillirahutusi	doc_740091151013_item	3644760	et	4	main
peale	doc_740091151013_item	3644759	et	4	main
meediakajastus	doc_740091151013_item	3644758	et	3	main
jõuline	doc_740091151013_item	3644757	et	4	main
on	doc_740091151013_item	3645127	et	4	main
samas	doc_740091151013_item	3645126	et	4	main
mis	doc_740091151013_item	3645121	et	4	main
ja	doc_740091151013_item	3645120	et	3	main
elame	doc_740091151013_item	3645119	et	3	main
ära	doc_740091151013_item	3645113	et	4	main
lippu	doc_740091151013_item	3645109	et	4	main
puutuvad	doc_740091151013_item	3645081	et	4	main
lapsed	doc_740091151013_item	3645080	et	3	main
minu	doc_740091151013_item	3645079	et	3	main
et	doc_740091151013_item	3645078	et	3	main
piiramatuid	doc_740091151013_item	3645065	et	4	main
inimestele	doc_740091151013_item	3645064	et	3	main
läbi	doc_740091151013_item	3645057	et	4	main
eesti	doc_740091151013_item	3645053	et	4	main
määravaks	doc_740091151013_item	3645044	et	4	main
nagunii	doc_740091151013_item	3645028	et	3	main
laps	doc_740091151013_item	3645026	et	4	main
selle	doc_740091151013_item	3645024	et	4	main
oled	doc_740091151013_item	3645023	et	3	main
meil	doc_740091151013_item	3645012	et	4	main
ongi	doc_740091151013_item	3645011	et	4	main
sellepärast	doc_740091151013_item	3645010	et	3	main
intriigid	doc_740091151013_item	3645009	et	3	main
ja	doc_740091151013_item	3645008	et	3	main
sellise	doc_740091151013_item	3644996	et	4	main
keelebarjääri	doc_740091151013_item	3644993	et	4	main
probleemi	doc_740091151013_item	3644989	et	4	main
mitte	doc_740091151013_item	3644983	et	3	main
riigi	doc_740091151013_item	3645108	et	3	main
korralikku	doc_740091151013_item	3645074	et	4	main
teha	doc_740091151013_item	3645071	et	3	main
lüüa	doc_740091151013_item	3645069	et	3	main
siin	doc_740091151013_item	3645056	et	4	main
et	doc_740091151013_item	3645055	et	3	main
õppida	doc_740091151013_item	3645052	et	3	main
vajalik	doc_740091151013_item	3645051	et	3	main
on	doc_740091151013_item	3645048	et	4	main
küll	doc_740091151013_item	3645047	et	4	main
varem	doc_740091151013_item	3645046	et	4	main
kui	doc_740091151013_item	3645045	et	3	main
vene	doc_740091151013_item	3645039	et	4	main
pea	doc_740091151013_item	3645038	et	4	main
ei	doc_740091151013_item	3645037	et	4	main
tööandjad	doc_740091151013_item	3645036	et	3	main
et	doc_740091151013_item	3645035	et	3	main
tundub	doc_740091151013_item	3645034	et	3	main
elus	doc_740091151013_item	3645067	et	4	main
võimalusi	doc_740091151013_item	3645066	et	3	main
annab	doc_740091151013_item	3645061	et	3	main
oskus	doc_740091151013_item	3645060	et	3	main
eestikeele	doc_740091151013_item	3645059	et	4	main
lüüa	doc_740091151013_item	3645058	et	3	main
enam	doc_740091151013_item	3645042	et	4	main
oskust	doc_740091151013_item	3645041	et	3	main
keele	doc_740091151013_item	3645040	et	4	main
sa	doc_740091151013_item	3645027	et	3	main
on	doc_740091151013_item	3645000	et	4	main
nii	doc_740091151013_item	3644999	et	3	main
ja	doc_740091151013_item	3644998	et	3	main
kohta	doc_740091151013_item	3644997	et	4	main
alateadvusesse	doc_740091151013_item	3644988	et	4	main
paljud	doc_740091151013_item	3644985	et	3	main
on	doc_740091151015_item	3645393	et	4	main
see	doc_740091151015_item	3645386	et	3	main
pole	doc_740091151015_item	3645382	et	3	main
minu	doc_740091151015_item	3645370	et	3	main
ent	doc_740091151015_item	3645354	et	3	main
aastat	doc_740091151015_item	3645351	et	3	main
mu	doc_740091151015_item	3645340	et	3	main
maailmas	doc_740091151015_item	3645332	et	3	main
virtuaalses	doc_740091151015_item	3645331	et	3	main
õnnelikena	doc_740091151015_item	3645329	et	3	main
kellega	doc_740091151015_item	3645326	et	3	main
vabadused	doc_740091151015_item	3645321	et	4	main
lahterdust	doc_740091151013_item	3645033	et	4	main
oska	doc_740091151013_item	3645032	et	4	main
vene	doc_740091151013_item	3645029	et	4	main
ajastu	doc_740091151013_item	3645025	et	4	main
sina	doc_740091151013_item	3645022	et	4	main
integratsiooni	doc_740091151013_item	3645014	et	4	main
või	doc_740091151013_item	3644994	et	4	main
rahvuse	doc_740091151013_item	3644992	et	3	main
endale	doc_740091151013_item	3644987	et	4	main
rahvus	doc_740091151013_item	3644984	et	3	main
ise	doc_740091151013_item	3644982	et	4	main
ikkagi	doc_740091151013_item	3644980	et	4	main
kino	doc_740091151015_item	3645388	et	4	main
piisavalt	doc_740091151015_item	3645383	et	4	main
tal	doc_740091151015_item	3645381	et	3	main
midagi	doc_740091151015_item	3645377	et	4	main
maailma	doc_740091151015_item	3645371	et	4	main
lõppeesmärki	doc_740091151015_item	3645357	et	4	main
elust	doc_740091151015_item	3645353	et	3	main
paar	doc_740091151015_item	3645350	et	3	main
oma	doc_740091151015_item	3645346	et	4	main
mina	doc_740091151015_item	3645344	et	4	main
olin	doc_740091151015_item	3645343	et	3	main
mind	doc_740091151015_item	3645335	et	4	main
püsida	doc_740091151015_item	3645328	et	3	main
otsin	doc_740091151015_item	3645324	et	3	main
samasugused	doc_740091151015_item	3645320	et	3	main
liitlasena	doc_740091151015_item	3645317	et	3	main
maha	doc_740091151015_item	3645315	et	4	main
päeval	doc_740091151015_item	3645314	et	3	main
ühel	doc_740091151015_item	3645313	et	3	main
kas	doc_740091151015_item	3645298	et	3	main
2	doc_740091151015_item	3645296	et	2	main
enam	doc_740091151015_item	3645294	et	4	main
või	doc_740091151015_item	3645285	et	4	main
rikkam	doc_740091151015_item	3645284	et	4	main
või	doc_740091151015_item	3645279	et	4	main
musta-	doc_740091151015_item	3645278	et	4	main
noorem	doc_740091151015_item	3645275	et	4	main
peaksin	doc_740091151015_item	3645272	et	4	main
välimust	doc_740091151015_item	3645271	et	4	main
leian	doc_740091151015_item	3645265	et	3	main
maailmas	doc_740091151015_item	3645256	et	3	main
ma	doc_740091151015_item	3645252	et	3	main
see	doc_740091151015_item	3645244	et	3	main
ei	doc_740091151015_item	3645243	et	4	main
invaliid	doc_740091151015_item	3645242	et	4	main
suhtele	doc_740091151015_item	3645227	et	3	main
lausa	doc_740091151015_item	3645218	et	4	main
ju	doc_740091151015_item	3645217	et	3	main
olime	doc_740091151015_item	3645216	et	3	main
küll	doc_740091151015_item	3645215	et	4	main
miks	doc_740091151015_item	3645214	et	4	main
maha	doc_740091151015_item	3645213	et	4	main
ta	doc_740091151015_item	3645190	et	4	main
kohe	doc_740091151015_item	3645185	et	4	main
kus	doc_740091151015_item	3645181	et	3	main
interneti	doc_740091151015_item	3645179	et	4	main
ameerika	doc_740091151015_item	3645169	et	3	main
kordki	doc_740091151015_item	3645147	et	4	main
ei	doc_740091151015_item	3645142	et	4	main
kes	doc_740091151015_item	3645140	et	4	main
virtuaalne	doc_740091151015_item	3645138	et	3	main
minu	doc_740091151015_item	3645137	et	3	main
siis	doc_740091151015_item	3645467	et	3	main
lohutust	doc_740091151015_item	3645492	et	4	main
leian	doc_740091151015_item	3645491	et	3	main
kust	doc_740091151015_item	3645490	et	4	main
ja	doc_740091151015_item	3645489	et	3	main
kuulun	doc_740091151015_item	3645488	et	3	main
kuhu	doc_740091151015_item	3645487	et	3	main
tean	doc_740091151015_item	3645486	et	3	main
õnnelik	doc_740091151015_item	3645485	et	3	main
olen	doc_740091151015_item	3645484	et	3	main
ma	doc_740091151015_item	3645483	et	3	main
kus	doc_740091151015_item	3645482	et	3	main
maailm	doc_740091151015_item	3645481	et	3	main
oma	doc_740091151015_item	3645480	et	4	main
on	doc_740091151015_item	3645479	et	4	main
mul	doc_740091151015_item	3645478	et	3	main
kuid	doc_740091151015_item	3645477	et	4	main
õnnetuna	doc_740091151015_item	3645476	et	4	main
näida	doc_740091151015_item	3645475	et	4	main
ma	doc_740091151015_item	3645474	et	3	main
võin	doc_740091151015_item	3645473	et	3	main
reaalsuses	doc_740091151015_item	3645472	et	4	main
saame	doc_740091151015_item	3645471	et	4	main
kõrvetada	doc_740091151015_item	3645470	et	3	main
kui	doc_740091151015_item	3645469	et	3	main
päralt	doc_740091151015_item	3645396	et	4	main
inimeste	doc_740091151015_item	3645395	et	3	main
nende	doc_740091151015_item	3645394	et	4	main
õige	doc_740091151015_item	3645387	et	4	main
nii	doc_740091151015_item	3645378	et	3	main
otsima	doc_740091151015_item	3645375	et	4	main
virtuaalmaailmast	doc_740091151015_item	3645376	et	4	main
ta	doc_740091151015_item	3645374	et	4	main
leida	doc_740091151015_item	3645385	et	3	main
kas	doc_740091151015_item	3645380	et	3	main
miks	doc_740091151015_item	3645372	et	4	main
tungis	doc_740091151015_item	3645369	et	4	main
tema	doc_740091151015_item	3645368	et	4	main
ei	doc_740091151015_item	3645363	et	4	main
ju	doc_740091151015_item	3645360	et	3	main
oleksin	doc_740091151015_item	3645359	et	3	main
mina	doc_740091151015_item	3645358	et	4	main
ei	doc_740091151015_item	3645355	et	4	main
endi	doc_740091151015_item	3645352	et	4	main
jätnud	doc_740091151015_item	3645337	et	4	main
ja	doc_740091151015_item	3645333	et	3	main
tal	doc_740091151015_item	3645319	et	3	main
et	doc_740091151015_item	3645308	et	3	main
mõistan	doc_740091151015_item	3645307	et	3	main
liitlane	doc_740091151015_item	3645306	et	3	main
ohver	doc_740091151015_item	3645304	et	3	main
minu	doc_740091151015_item	3645303	et	3	main
järgmine	doc_740091151015_item	3645300	et	3	main
aastat	doc_740091151015_item	3645297	et	3	main
valgenahaline	doc_740091151015_item	3645280	et	4	main
või	doc_740091151015_item	3645276	et	4	main
olema	doc_740091151015_item	3645274	et	4	main
tuleks	doc_740091151015_item	3645269	et	4	main
ja	doc_740091151015_item	3645257	et	3	main
jäägu	doc_740091151015_item	3645245	et	3	main
kellepoole	doc_740091151015_item	3645234	et	4	main
inetu	doc_740091151015_item	3645233	et	4	main
ja	doc_740091151015_item	3645232	et	3	main
teise	doc_740091151015_item	3645204	et	4	main
ning	doc_740091151015_item	3645186	et	3	main
tutvusime	doc_740091151015_item	3645178	et	4	main
armastuse	doc_740091151015_item	3645177	et	4	main
naise	doc_740091151015_item	3645176	et	3	main
idaeurooplasest	doc_740091151015_item	3645175	et	3	main
armsa	doc_740091151015_item	3645174	et	3	main
noore	doc_740091151015_item	3645173	et	3	main
pälvis	doc_740091151015_item	3645172	et	3	main
sportlik	doc_740091151015_item	3645167	et	3	main
saavutanud	doc_740091151015_item	3645164	et	4	main
olen	doc_740091151015_item	3645162	et	3	main
halbade	doc_740091151015_item	3645154	et	3	main
välimuse	doc_740091151015_item	3645153	et	3	main
kelle	doc_740091151015_item	3645152	et	4	main
keda	doc_740091151015_item	3645146	et	4	main
inimene	doc_740091151015_item	3645145	et	3	main
tahaks	doc_740091151015_item	3645143	et	3	main
ninaotsa	doc_740091151015_item	3645459	et	4	main
seal	doc_740091151015_item	3645425	et	4	main
trügi	doc_740091151015_item	3645414	et	4	main
kaaslaseks	doc_740091151015_item	3645404	et	3	main
pärast	doc_740091151016_item	3645946	et	4	main
oma	doc_740091151016_item	3645944	et	4	main
juhtuda	doc_740091151016_item	3645942	et	3	main
on	doc_740091151016_item	3645936	et	4	main
maailm	doc_740091151016_item	3645935	et	3	main
stsenaariume	doc_740091151016_item	3645934	et	3	main
tumedaid	doc_740091151016_item	3645933	et	3	main
neid	doc_740091151016_item	3645932	et	4	main
vältida	doc_740091151016_item	3645931	et	3	main
kellel	doc_740091151016_item	3645922	et	4	main
mõista	doc_740091151016_item	3645913	et	4	main
ei	doc_740091151016_item	3645909	et	4	main
inimene	doc_740091151016_item	3645908	et	3	main
stsenaariumitest	doc_740091151016_item	3645897	et	4	main
selleks	doc_740091151016_item	3645803	et	4	main
veel	doc_740091151016_item	3645802	et	4	main
ühiskonnast	doc_740091151016_item	3645798	et	4	main
taolisest	doc_740091151016_item	3645797	et	3	main
kuid	doc_740091151016_item	3645791	et	4	main
peaks	doc_740091151016_item	3645788	et	4	main
omalt	doc_740091151016_item	3645776	et	4	main
uue	doc_740091151016_item	3645773	et	3	main
mis	doc_740091151016_item	3645761	et	4	main
tuleb	doc_740091151015_item	3645373	et	3	main
sest	doc_740091151015_item	3645367	et	4	main
ohver	doc_740091151015_item	3645366	et	3	main
olin	doc_740091151015_item	3645365	et	3	main
jätkata	doc_740091151015_item	3645362	et	4	main
tahtnud	doc_740091151015_item	3645361	et	4	main
kulutasime	doc_740091151015_item	3645349	et	3	main
või	doc_740091151015_item	3645342	et	4	main
ohver	doc_740091151015_item	3645341	et	3	main
kas	doc_740091151015_item	3645334	et	3	main
oma	doc_740091151015_item	3645330	et	4	main
võiksime	doc_740091151015_item	3645327	et	3	main
liitlast	doc_740091151015_item	3645325	et	3	main
mul	doc_740091151015_item	3645323	et	3	main
ta	doc_740091151015_item	3645311	et	4	main
jätaks	doc_740091151015_item	3645310	et	3	main
ohvrina	doc_740091151015_item	3645309	et	3	main
või	doc_740091151015_item	3645305	et	4	main
on	doc_740091151015_item	3645302	et	4	main
kaaslane	doc_740091151015_item	3645301	et	3	main
kui	doc_740091151015_item	3645295	et	3	main
paneks	doc_740091151015_item	3645291	et	4	main
tulemust	doc_740091151015_item	3645289	et	4	main
saavutada	doc_740091151015_item	3645288	et	3	main
kuidas	doc_740091151015_item	3645287	et	3	main
vaesem	doc_740091151015_item	3645286	et	4	main
vanem	doc_740091151015_item	3645277	et	4	main
ehk	doc_740091151015_item	3645268	et	3	main
ma	doc_740091151015_item	3645264	et	3	main
hoida	doc_740091151015_item	3645254	et	3	main
2	doc_740091151015_item	3645249	et	2	main
lihtsalt	doc_740091151015_item	3645241	et	4	main
olen	doc_740091151015_item	3645237	et	3	main
vaadata	doc_740091151015_item	3645236	et	4	main
olen	doc_740091151015_item	3645228	et	3	main
jättis	doc_740091151015_item	3645209	et	3	main
oodanud	doc_740091151015_item	3645208	et	4	main
järele	doc_740091151015_item	3645207	et	4	main
ning	doc_740091151015_item	3645203	et	3	main
ühtisid	doc_740091151015_item	3645189	et	4	main
maailmavaatedki	doc_740091151015_item	3645188	et	3	main
klappis	doc_740091151015_item	3645184	et	3	main
kodanik	doc_740091151015_item	3645170	et	3	main
32-aastane	doc_740091151015_item	3645166	et	4	main
või	doc_740091151015_item	3645156	et	4	main
harjumuste	doc_740091151015_item	3645155	et	4	main
elus	doc_740091151015_item	3645148	et	4	main
olla	doc_740091151015_item	3645144	et	3	main
tahetud	doc_740091151015_item	3645421	et	4	main
ei	doc_740091151015_item	3645418	et	4	main
minu	doc_740091151015_item	3645299	et	3	main
kestma	doc_740091151015_item	3645293	et	3	main
mis	doc_740091151015_item	3645290	et	4	main
või	doc_740091151015_item	3645282	et	4	main
pikem	doc_740091151015_item	3645281	et	4	main
ma	doc_740091151015_item	3645273	et	3	main
armastuse	doc_740091151015_item	3645267	et	4	main
uue	doc_740091151015_item	3645266	et	3	main
ei	doc_740091151015_item	3645263	et	4	main
üksindusega	doc_740091151015_item	3645262	et	3	main
taas	doc_740091151015_item	3645261	et	3	main
leppima	doc_740091151015_item	3645260	et	3	main
pean	doc_740091151015_item	3645259	et	4	main
oma	doc_740091151015_item	3645255	et	4	main
teda	doc_740091151015_item	3645253	et	4	main
suutsin	doc_740091151015_item	3645251	et	3	main
aastat	doc_740091151015_item	3645250	et	3	main
vaid	doc_740091151015_item	3645248	et	3	main
või	doc_740091151015_item	3645240	et	4	main
ühiskonnaheidik	doc_740091151015_item	3645238	et	3	main
vana	doc_740091151015_item	3645231	et	4	main
ehk	doc_740091151015_item	3645230	et	3	main
ma	doc_740091151015_item	3645229	et	3	main
idüllilisele	doc_740091151015_item	3645226	et	4	main
meie	doc_740091151015_item	3645225	et	4	main
lõpu	doc_740091151015_item	3645224	et	3	main
tegi	doc_740091151015_item	3645223	et	4	main
reaalsus	doc_740091151015_item	3645222	et	4	main
abielluma	doc_740091151015_item	3645221	et	3	main
pidime	doc_740091151015_item	3645220	et	3	main
hingesugulased	doc_740091151015_item	3645219	et	3	main
viimaks	doc_740091151015_item	3645212	et	4	main
mu	doc_740091151015_item	3645211	et	3	main
ta	doc_740091151015_item	3645210	et	4	main
minu	doc_740091151015_item	3645206	et	3	main
suhte	doc_740091151015_item	3645292	et	3	main
lühem	doc_740091151015_item	3645283	et	4	main
muuta	doc_740091151015_item	3645270	et	4	main
nüüd	doc_740091151015_item	3645258	et	4	main
teada	doc_740091151015_item	3645247	et	3	main
minu	doc_740091151015_item	3645246	et	3	main
nõdrameelne	doc_740091151015_item	3645239	et	3	main
ei	doc_740091151015_item	3645235	et	4	main
aasta	doc_740091151015_item	3645205	et	4	main
juba	doc_740091151015_item	3645201	et	3	main
aasta	doc_740091151015_item	3645200	et	4	main
kuigi	doc_740091151015_item	3645199	et	3	main
supermees	doc_740091151015_item	3645198	et	4	main
olingi	doc_740091151015_item	3645197	et	3	main
juba	doc_740091151015_item	3645196	et	3	main
ja	doc_740091151015_item	3645195	et	3	main
fotodesse	doc_740091151015_item	3645194	et	3	main
suhelnud	doc_740091151015_item	3645202	et	4	main
mu	doc_740091151015_item	3645193	et	3	main
meie	doc_740091151015_item	3645187	et	4	main
kes	doc_740091151015_item	3645171	et	4	main
kena	doc_740091151015_item	3645168	et	4	main
olen	doc_740091151015_item	3645165	et	3	main
selle	doc_740091151015_item	3645163	et	4	main
mina	doc_740091151015_item	3645161	et	4	main
kurdeta	doc_740091151015_item	3645160	et	3	main
ei	doc_740091151015_item	3645159	et	4	main
üle	doc_740091151015_item	3645158	et	3	main
mõistuse	doc_740091151015_item	3645157	et	3	main
jumaldatakse	doc_740091151015_item	3645149	et	3	main
meist	doc_740091151015_item	3645141	et	3	main
identiteet	doc_740091151015_item	3645139	et	4	main
essee	doc_740091151015_item	3645136	et	4	main
süüdistagem	doc_740091151015_item	3645466	et	3	main
kuulu	doc_740091151015_item	3645465	et	4	main
me	doc_740091151015_item	3645463	et	4	main
kuhu	doc_740091151015_item	3645462	et	3	main
sinna	doc_740091151015_item	3645461	et	3	main
pista	doc_740091151015_item	3645460	et	4	main
ju	doc_740091151015_item	3645457	et	3	main
me	doc_740091151015_item	3645455	et	4	main
ole	doc_740091151015_item	3645419	et	4	main
on	doc_740091151015_item	3645408	et	4	main
see	doc_740091151015_item	3645407	et	3	main
arvuti	doc_740091151015_item	3645406	et	4	main
nurgas	doc_740091151015_item	3645403	et	3	main
lasta	doc_740091151016_item	3645940	et	4	main
et	doc_740091151016_item	3645939	et	3	main
loomingulisust	doc_740091151016_item	3645928	et	4	main
oluliselt	doc_740091151016_item	3645925	et	4	main
olend	doc_740091151016_item	3645921	et	3	main
olemusega	doc_740091151016_item	3645906	et	3	main
ole	doc_740091151016_item	3645801	et	4	main
veel	doc_740091151016_item	3645794	et	4	main
bõnesi	doc_740091151016_item	3645784	et	4	main
poolt	doc_740091151016_item	3645777	et	4	main
ühiskonna	doc_740091151016_item	3645774	et	4	main
luua	doc_740091151016_item	3645772	et	4	main
endasse	doc_740091151016_item	3645763	et	4	main
kultuuriruumi	doc_740091151016_item	3645759	et	4	main
oodata	doc_740091151016_item	3645756	et	4	main
tuleks	doc_740091151016_item	3645755	et	4	main
kultuuri	doc_740091151016_item	3645752	et	4	main
ja	doc_740091151016_item	3645749	et	3	main
keelele	doc_740091151016_item	3645748	et	4	main
ühele	doc_740091151016_item	3645747	et	3	main
üleminekud	doc_740091151016_item	3645746	et	3	main
kartma	doc_740091151016_item	3645745	et	3	main
ressurside	doc_740091151016_item	3645727	et	4	main
mõjust	doc_740091151016_item	3645720	et	3	main
elanikele	doc_740091151016_item	3645714	et	3	main
kui	doc_740091151016_item	3645711	et	3	main
et	doc_740091151016_item	3645703	et	3	main
kaoksid	doc_740091151016_item	3645672	et	4	main
kui	doc_740091151016_item	3645660	et	3	main
piirid	doc_740091151016_item	3645657	et	3	main
kõikidele	doc_740091151016_item	3645653	et	4	main
avatuse	doc_740091151016_item	3645652	et	4	main
ühiskonna	doc_740091151016_item	3645651	et	4	main
uue	doc_740091151016_item	3645650	et	3	main
ühiskonna	doc_740091151016_item	3645645	et	4	main
multikultuurse	doc_740091151016_item	3645644	et	3	main
ühise	doc_740091151016_item	3645643	et	3	main
eesmärk	doc_740091151016_item	3645641	et	3	main
on	doc_740091151016_item	3645640	et	4	main
poolepealt	doc_740091151016_item	3645639	et	3	main
arvamusi	doc_740091151016_item	3645632	et	3	main
ainult	doc_740091151016_item	3645627	et	4	main
varases	doc_740091151016_item	3645616	et	4	main
protsess	doc_740091151016_item	3645613	et	3	main
kuna	doc_740091151016_item	3645611	et	3	main
suhtest	doc_740091151016_item	3645573	et	4	main
ebausklik	doc_740091151016_item	3645570	et	3	main
kergelt	doc_740091151016_item	3645567	et	4	main
olla	doc_740091151016_item	3645566	et	3	main
tavaks	doc_740091151016_item	3645565	et	3	main
edasi	doc_740091151016_item	3645553	et	3	main
hajuvad	doc_740091151016_item	3645547	et	4	main
kohe	doc_740091151015_item	3645192	et	4	main
armus	doc_740091151015_item	3645191	et	4	main
jutt	doc_740091151015_item	3645183	et	3	main
meie	doc_740091151015_item	3645182	et	4	main
jututoas	doc_740091151015_item	3645180	et	3	main
keegi	doc_740091151015_item	3645151	et	4	main
olla	doc_740091151015_item	3645150	et	3	main
iseennast	doc_740091151015_item	3645468	et	3	main
ei	doc_740091151015_item	3645464	et	4	main
oma	doc_740091151015_item	3645458	et	4	main
tunne	doc_740091151015_item	3645424	et	4	main
ei	doc_740091151015_item	3645423	et	4	main
ma	doc_740091151015_item	3645422	et	3	main
ei	doc_740091151015_item	3645413	et	4	main
ma	doc_740091151015_item	3645412	et	3	main
ja	doc_740091151015_item	3645411	et	3	main
maailm	doc_740091151015_item	3645410	et	3	main
minu	doc_740091151015_item	3645409	et	3	main
et	doc_740091151016_item	3645930	et	3	main
arvan	doc_740091151016_item	3645915	et	3	main
seda	doc_740091151016_item	3645911	et	3	main
suuda	doc_740091151016_item	3645910	et	4	main
et	doc_740091151016_item	3645907	et	3	main
mis	doc_740091151016_item	3645902	et	4	main
imelises	doc_740091151016_item	3645900	et	4	main
elama	doc_740091151016_item	3645899	et	3	main
tegelikult	doc_740091151016_item	3645898	et	4	main
on	doc_740091151016_item	3645793	et	4	main
praegu	doc_740091151016_item	3645792	et	3	main
olevaid	doc_740091151016_item	3645783	et	4	main
andes	doc_740091151016_item	3645775	et	4	main
kõiki	doc_740091151016_item	3645764	et	4	main
kasutamine	doc_740091151016_item	3645729	et	4	main
endale	doc_740091151016_item	3645717	et	4	main
mis	doc_740091151016_item	3645707	et	4	main
maailmas	doc_740091151016_item	3645706	et	3	main
elab	doc_740091151016_item	3645705	et	3	main
kus	doc_740091151016_item	3645700	et	3	main
rahvuslikud	doc_740091151016_item	3645662	et	3	main
olema	doc_740091151016_item	3645649	et	4	main
teha	doc_740091151016_item	3645642	et	3	main
äärmiselt	doc_740091151016_item	3645636	et	4	main
prognoosida	doc_740091151016_item	3645621	et	4	main
alles	doc_740091151016_item	3645615	et	3	main
ühiskonnas	doc_740091151016_item	3645610	et	4	main
toimuvad	doc_740091151016_item	3645609	et	4	main
võime	doc_740091151015_item	3645456	et	4	main
kaklema	doc_740091151015_item	3645454	et	3	main
peale	doc_740091151015_item	3645453	et	4	main
õue	doc_740091151015_item	3645452	et	4	main
meie	doc_740091151015_item	3645451	et	4	main
tulevad	doc_740091151015_item	3645450	et	4	main
siis	doc_740091151015_item	3645449	et	3	main
nad	doc_740091151015_item	3645448	et	3	main
miks	doc_740091151015_item	3645447	et	4	main
aga	doc_740091151015_item	3645446	et	3	main
ütles	doc_740091151015_item	3645445	et	3	main
imelikki	doc_740091151015_item	3645444	et	3	main
nagu	doc_740091151015_item	3645443	et	3	main
teen	doc_740091151015_item	3645442	et	3	main
haiget	doc_740091151015_item	3645441	et	3	main
kellelegi	doc_740091151015_item	3645440	et	4	main
identiteedita	doc_740091151015_item	3645439	et	4	main
virtuaalse	doc_740091151015_item	3645438	et	3	main
oma	doc_740091151015_item	3645437	et	4	main
ma	doc_740091151015_item	3645436	et	3	main
kui	doc_740091151015_item	3645435	et	3	main
kahju	doc_740091151015_item	3645434	et	4	main
ka	doc_740091151015_item	3645433	et	3	main
mul	doc_740091151015_item	3645432	et	3	main
ole	doc_740091151015_item	3645431	et	4	main
ei	doc_740091151015_item	3645430	et	4	main
seepärast	doc_740091151015_item	3645429	et	3	main
ja	doc_740091151015_item	3645428	et	3	main
hästi	doc_740091151015_item	3645427	et	3	main
end	doc_740091151015_item	3645426	et	4	main
sinna	doc_740091151015_item	3645420	et	3	main
ma	doc_740091151015_item	3645417	et	3	main
maailma	doc_740091151015_item	3645416	et	4	main
teiste	doc_740091151015_item	3645415	et	4	main
vaid	doc_740091151015_item	3645405	et	3	main
toa	doc_740091151015_item	3645402	et	3	main
imeline	doc_740091151016_item	3645938	et	4	main
liiga	doc_740091151016_item	3645937	et	4	main
inimlikust	doc_740091151016_item	3645929	et	4	main
eriline	doc_740091151016_item	3645920	et	4	main
on	doc_740091151016_item	3645918	et	4	main
inimene	doc_740091151016_item	3645917	et	3	main
hetkel	doc_740091151016_item	3645914	et	4	main
nii	doc_740091151016_item	3645904	et	3	main
on	doc_740091151016_item	3645903	et	4	main
maailmas	doc_740091151016_item	3645901	et	3	main
valmis	doc_740091151016_item	3645804	et	4	main
ei	doc_740091151016_item	3645800	et	4	main
inimesed	doc_740091151016_item	3645799	et	3	main
räkida	doc_740091151016_item	3645796	et	4	main
vara	doc_740091151016_item	3645795	et	4	main
helge	doc_740091151016_item	3645790	et	4	main
ühiskonna	doc_740091151016_item	3645786	et	4	main
sellise	doc_740091151016_item	3645785	et	4	main
paremat	doc_740091151016_item	3645779	et	4	main
kõike	doc_740091151016_item	3645778	et	4	main
rahvasid	doc_740091151016_item	3645765	et	4	main
universaalse	doc_740091151016_item	3645758	et	3	main
peaks	doc_740091151016_item	3645744	et	4	main
ole	doc_740091151016_item	3645739	et	4	main
kasutamine	doc_740091151016_item	3645734	et	4	main
otstarbekas	doc_740091151016_item	3645733	et	4	main
ja	doc_740091151016_item	3645732	et	3	main
mõistlik	doc_740091151016_item	3645731	et	3	main
jaotus	doc_740091151016_item	3645730	et	4	main
maa	doc_740091151016_item	3645726	et	4	main
oleks	doc_740091151016_item	3645725	et	3	main
näiteks	doc_740091151016_item	3645724	et	4	main
eredaks	doc_740091151016_item	3645723	et	3	main
oleks	doc_740091151016_item	3645715	et	3	main
ta	doc_740091151016_item	3645701	et	4	main
pidurdavad	doc_740091151016_item	3645674	et	4	main
elukvaliteedile	doc_740091151016_item	3645670	et	3	main
kõrgemale	doc_740091151016_item	3645669	et	4	main
hoopis	doc_740091151016_item	3645668	et	3	main
tõuseks	doc_740091151016_item	3645667	et	4	main
ühiskond	doc_740091151016_item	3645666	et	3	main
see	doc_740091151016_item	3645665	et	3	main
etnilised	doc_740091151016_item	3645664	et	3	main
ja	doc_740091151016_item	3645663	et	3	main
kaduma	doc_740091151016_item	3645656	et	4	main
inimestele	doc_740091151016_item	3645654	et	3	main
selle	doc_740091151016_item	3645646	et	4	main
erinevad	doc_740091151016_item	3645637	et	4	main
mis	doc_740091151016_item	3645633	et	4	main
avaldada	doc_740091151016_item	3645630	et	3	main
arutleda	doc_740091151016_item	3645628	et	3	main
võib	doc_740091151016_item	3645626	et	3	main
hetkel	doc_740091151016_item	3645625	et	4	main
väljaviib	doc_740091151016_item	3645624	et	4	main
see	doc_740091151016_item	3645623	et	3	main
kuna	doc_740091151016_item	3645622	et	3	main
globaliseerimise	doc_740091151016_item	3645612	et	4	main
kuna	doc_740091151016_item	3645574	et	3	main
või	doc_740091151016_item	3645569	et	4	main
pessimistlik	doc_740091151016_item	3645568	et	3	main
protsess	doc_740091151016_item	3645562	et	3	main
täiesti	doc_740091151016_item	3645558	et	3	main
see	doc_740091151016_item	3645556	et	3	main
läheb	doc_740091151016_item	3645552	et	3	main
ebatäpseteks	doc_740091151016_item	3645545	et	3	main
väike	doc_740091151016_item	3645855	et	4	main
püüdlevad	doc_740091151016_item	3645842	et	4	main
kuhu	doc_740091151016_item	3645840	et	3	main
kes	doc_740091151016_item	3645833	et	4	main
juhte	doc_740091151016_item	3645832	et	4	main
ikka	doc_740091151016_item	3645807	et	4	main
mõistetavaks	doc_740091151016_item	3645530	et	4	main
iseenesest	doc_740091151016_item	3645529	et	4	main
ütle	doc_740091151016_item	3645524	et	4	main
ka	doc_740091151016_item	3645517	et	3	main
kääkirja	doc_740091151016_item	3645945	et	4	main
vabandan	doc_740091151016_item	3645943	et	3	main
sellele	doc_740091151016_item	3645941	et	4	main
positiivsust	doc_740091151016_item	3645927	et	4	main
rohkem	doc_740091151016_item	3645926	et	4	main
siiski	doc_740091151016_item	3645924	et	4	main
on	doc_740091151016_item	3645923	et	4	main
nii	doc_740091151016_item	3645919	et	3	main
et	doc_740091151016_item	3645916	et	3	main
kõike	doc_740091151016_item	3645912	et	4	main
keeruka	doc_740091151016_item	3645905	et	3	main
võimatustest	doc_740091151016_item	3645896	et	4	main
või	doc_740091151016_item	3645895	et	4	main
võimalikest	doc_740091151016_item	3645894	et	4	main
üks	doc_740091151016_item	3645893	et	3	main
on	doc_740091151016_item	3645892	et	4	main
kõik	doc_740091151016_item	3645891	et	4	main
see	doc_740091151016_item	3645890	et	3	main
kuid	doc_740091151016_item	3645889	et	4	main
surmaga	doc_740091151016_item	3645888	et	3	main
isiksuse	doc_740091151016_item	3645887	et	3	main
võrdväärne	doc_740091151016_item	3645886	et	3	main
põhimõtteliselt	doc_740091151016_item	3645885	et	4	main
on	doc_740091151016_item	3645884	et	4	main
mis	doc_740091151016_item	3645883	et	4	main
võimalus	doc_740091151016_item	3645882	et	3	main
valiku	doc_740091151016_item	3645881	et	3	main
tegelikult	doc_740091151016_item	3645880	et	4	main
inimestelt	doc_740091151016_item	3645879	et	3	main
võetakse	doc_740091151016_item	3645878	et	3	main
fantoomist	doc_740091151016_item	3645877	et	4	main
olema	doc_740091151016_item	3645789	et	4	main
tulevik	doc_740091151016_item	3645787	et	3	main
hetkel	doc_740091151016_item	3645782	et	4	main
parandades	doc_740091151016_item	3645781	et	3	main
sellega	doc_740091151016_item	3645780	et	3	main
aitavad	doc_740091151016_item	3645771	et	4	main
erinevused	doc_740091151016_item	3645770	et	4	main
kultuursed	doc_740091151016_item	3645769	et	3	main
need	doc_740091151016_item	3645768	et	3	main
just	doc_740091151016_item	3645767	et	3	main
ja	doc_740091151016_item	3645766	et	3	main
hõlmab	doc_740091151016_item	3645762	et	3	main
pigem	doc_740091151016_item	3645754	et	3	main
väljasuremist	doc_740091151016_item	3645753	et	3	main
rahvuste	doc_740091151016_item	3645751	et	3	main
kartma	doc_740091151016_item	3645750	et	3	main
ohtlik	doc_740091151016_item	3645740	et	3	main
ühiskond	doc_740091151016_item	3645737	et	3	main
uus	doc_740091151016_item	3645735	et	3	main
tegevuse	doc_740091151016_item	3645719	et	4	main
oma	doc_740091151016_item	3645718	et	4	main
teistele	doc_740091151016_item	3645713	et	4	main
talle	doc_740091151016_item	3645710	et	4	main
samavõrdselt	doc_740091151016_item	3645709	et	4	main
kuulub	doc_740091151016_item	3645708	et	3	main
elab	doc_740091151016_item	3645702	et	3	main
on	doc_740091151016_item	3645698	et	4	main
ta	doc_740091151016_item	3645697	et	4	main
kes	doc_740091151016_item	3645696	et	4	main
eneseteadvustamine	doc_740091151016_item	3645695	et	3	main
täielik	doc_740091151016_item	3645694	et	3	main
inimeste	doc_740091151016_item	3645693	et	3	main
oleks	doc_740091151016_item	3645692	et	3	main
ideaaliks	doc_740091151016_item	3645691	et	4	main
globaalseks	doc_740091151016_item	3645690	et	4	main
primitiivne	doc_740091151016_item	3645689	et	3	main
suht	doc_740091151016_item	3645688	et	4	main
on	doc_740091151016_item	3645687	et	4	main
see	doc_740091151016_item	3645686	et	3	main
endaga	doc_740091151016_item	3645685	et	4	main
ise	doc_740091151016_item	3645684	et	4	main
inimesed	doc_740091151016_item	3645683	et	3	main
võitlevad	doc_740091151016_item	3645682	et	4	main
tegelikult	doc_740091151016_item	3645681	et	4	main
ühiskond	doc_740091151016_item	3645680	et	3	main
kogu	doc_740091151016_item	3645679	et	4	main
võitleb	doc_740091151016_item	3645678	et	3	main
praegu	doc_740091151016_item	3645677	et	3	main
millega	doc_740091151016_item	3645676	et	3	main
protsessid	doc_740091151016_item	3645675	et	4	main
need	doc_740091151016_item	3645673	et	3	main
kuna	doc_740091151016_item	3645671	et	3	main
kaa	doc_740091151016_item	3645661	et	4	main
nii	doc_740091151016_item	3645658	et	3	main
peaksid	doc_740091151016_item	3645655	et	4	main
peaks	doc_740091151016_item	3645648	et	4	main
sotsiaalse	doc_740091151016_item	3645638	et	3	main
on	doc_740091151016_item	3645634	et	4	main
oma	doc_740091151016_item	3645631	et	4	main
ja	doc_740091151016_item	3645629	et	3	main
on	doc_740091151016_item	3645618	et	4	main
staadiumis	doc_740091151016_item	3645617	et	3	main
tekket	doc_740091151016_item	3645760	et	4	main
uue	doc_740091151016_item	3645757	et	3	main
ei	doc_740091151016_item	3645743	et	4	main
kultuurile	doc_740091151016_item	3645742	et	3	main
maailma	doc_740091151016_item	3645741	et	4	main
ei	doc_740091151016_item	3645738	et	4	main
multikultuurne	doc_740091151016_item	3645736	et	3	main
ühis	doc_740091151016_item	3645728	et	4	main
selle	doc_740091151016_item	3645722	et	4	main
ümbritsevale	doc_740091151016_item	3645721	et	4	main
teadvustanud	doc_740091151016_item	3645716	et	4	main
ka	doc_740091151016_item	3645712	et	3	main
ta	doc_740091151016_item	3645704	et	4	main
ja	doc_740091151016_item	3645699	et	3	main
territoriaalsed	doc_740091151016_item	3645659	et	3	main
võluks	doc_740091151016_item	3645647	et	4	main
kindlasti	doc_740091151016_item	3645635	et	3	main
raske	doc_740091151016_item	3645620	et	4	main
äärmiselt	doc_740091151016_item	3645619	et	4	main
mis	doc_740091151016_item	3645608	et	4	main
arenemist	doc_740091151016_item	3645607	et	4	main
protsesside	doc_740091151016_item	3645606	et	3	main
kõikide	doc_740091151016_item	3645605	et	4	main
põhjustab	doc_740091151016_item	3645604	et	3	main
inimene	doc_740091151016_item	3645603	et	3	main
just	doc_740091151016_item	3645602	et	3	main
tegelikult	doc_740091151016_item	3645601	et	4	main
ja	doc_740091151016_item	3645600	et	3	main
kohanemisvõime	doc_740091151016_item	3645599	et	4	main
parem	doc_740091151016_item	3645598	et	4	main
kõige	doc_740091151016_item	3645597	et	4	main
inimestel	doc_740091151016_item	3645596	et	3	main
on	doc_740091151016_item	3645595	et	4	main
muutustega	doc_740091151016_item	3645593	et	4	main
õnneks	doc_740091151016_item	3645594	et	4	main
tulevaste	doc_740091151016_item	3645592	et	4	main
kohaneda	doc_740091151016_item	3645591	et	3	main
suudab	doc_740091151016_item	3645590	et	3	main
ta	doc_740091151016_item	3645589	et	4	main
kas	doc_740091151016_item	3645588	et	3	main
muret	doc_740091151016_item	3645587	et	3	main
tunneb	doc_740091151016_item	3645586	et	3	main
inimene	doc_740091151016_item	3645585	et	3	main
elu	doc_740091151016_item	3645584	et	4	main
inimeste	doc_740091151016_item	3645583	et	3	main
muudavad	doc_740091151016_item	3645582	et	4	main
muutused	doc_740091151016_item	3645581	et	4	main
tulevased	doc_740091151016_item	3645580	et	4	main
need	doc_740091151016_item	3645579	et	3	main
kuidas	doc_740091151016_item	3645578	et	3	main
tea	doc_740091151016_item	3645577	et	4	main
ei	doc_740091151016_item	3645576	et	4	main
nad	doc_740091151016_item	3645575	et	3	main
muutuste	doc_740091151016_item	3645572	et	4	main
uute	doc_740091151016_item	3645571	et	3	main
inimestel	doc_740091151016_item	3645563	et	3	main
paratamatu	doc_740091151016_item	3645561	et	4	main
ja	doc_740091151016_item	3645560	et	3	main
on	doc_740091151016_item	3645557	et	4	main
sellises	doc_740091151016_item	3645548	et	4	main
võim	doc_740091151016_item	3645861	et	3	main
valitsus	doc_740091151016_item	3645853	et	4	main
on	doc_740091151016_item	3645614	et	4	main
väga	doc_740091151016_item	3645544	et	3	main
kavatsused	doc_740091151016_item	3645540	et	4	main
kogu	doc_740091151016_item	3645870	et	4	main
probleem	doc_740091151016_item	3645869	et	3	main
keerukaim	doc_740091151016_item	3645868	et	4	main
tekkib	doc_740091151016_item	3645867	et	3	main
olukorras	doc_740091151016_item	3645866	et	3	main
sellises	doc_740091151016_item	3645865	et	4	main
niidid	doc_740091151016_item	3645864	et	3	main
kogu	doc_740091151016_item	3645860	et	4	main
kellel	doc_740091151016_item	3645858	et	4	main
inimesi	doc_740091151016_item	3645857	et	4	main
hulk	doc_740091151016_item	3645856	et	3	main
ehk	doc_740091151016_item	3645851	et	3	main
millised	doc_740091151016_item	3645836	et	3	main
nad	doc_740091151016_item	3645834	et	3	main
eriti	doc_740091151016_item	3645828	et	3	main
vaja	doc_740091151016_item	3645826	et	4	main
võiks	doc_740091151016_item	3645822	et	4	main
sellega	doc_740091151016_item	3645819	et	3	main
on	doc_740091151016_item	3645816	et	4	main
mõtteviis	doc_740091151016_item	3645815	et	3	main
inimese	doc_740091151016_item	3645814	et	4	main
tänapäeva	doc_740091151016_item	3645813	et	4	main
arengud	doc_740091151016_item	3645812	et	3	main
pidurdavad	doc_740091151016_item	3645811	et	4	main
mis	doc_740091151016_item	3645810	et	4	main
mehanismid	doc_740091151016_item	3645809	et	4	main
on	doc_740091151016_item	3645564	et	4	main
loomulik	doc_740091151016_item	3645559	et	3	main
muutus	doc_740091151016_item	3645555	et	4	main
ühiskond	doc_740091151016_item	3645554	et	3	main
elu	doc_740091151016_item	3645551	et	4	main
väljenduses	doc_740091151016_item	3645550	et	4	main
mastaabses	doc_740091151016_item	3645549	et	4	main
õiged	doc_740091151016_item	3645539	et	3	main
suuna	doc_740091151016_item	3645538	et	4	main
selle	doc_740091151016_item	3645537	et	4	main
kuid	doc_740091151016_item	3645536	et	4	main
global	doc_740091151016_item	3645535	et	4	main
olemuse	doc_740091151016_item	3645876	et	3	main
selle	doc_740091151016_item	3645875	et	4	main
või	doc_740091151016_item	3645874	et	4	main
juures	doc_740091151016_item	3645873	et	4	main
vabaduse	doc_740091151016_item	3645872	et	4	main
oma	doc_740091151016_item	3645871	et	4	main
ja	doc_740091151016_item	3645546	et	3	main
jäävad	doc_740091151016_item	3645543	et	4	main
eesmärgid	doc_740091151016_item	3645542	et	3	main
ja	doc_740091151016_item	3645541	et	3	main
kõik	doc_740091151016_item	3645862	et	4	main
on	doc_740091151016_item	3645859	et	4	main
suhtkond	doc_740091151016_item	3645850	et	4	main
globaalne	doc_740091151016_item	3645849	et	3	main
on	doc_740091151016_item	3645848	et	4	main
aspektiks	doc_740091151016_item	3645847	et	3	main
olulisemaks	doc_740091151016_item	3645846	et	4	main
ka	doc_740091151016_item	3645841	et	3	main
nende	doc_740091151016_item	3645838	et	4	main
on	doc_740091151016_item	3645835	et	4	main
meie	doc_740091151016_item	3645831	et	4	main
vaatame	doc_740091151016_item	3645830	et	3	main
ta	doc_740091151016_item	3645821	et	4	main
suhteliselt	doc_740091151016_item	3645817	et	4	main
sugugi	doc_740091151016_item	3645527	et	4	main
termin	doc_740091151016_item	3645526	et	3	main
see	doc_740091151016_item	3645525	et	3	main
tava	doc_740091151016_item	3645518	et	4	main
jooksul	doc_740091151016_item	3645501	et	4	main
aastate	doc_740091151016_item	3645500	et	3	main
viimaste	doc_740091151016_item	3645499	et	3	main
ka	doc_366216787891_item	3646144	et	3	main
populaarne	doc_366216787891_item	3646141	et	3	main
et	doc_366216787891_item	3646137	et	3	main
kohe	doc_366216787891_item	3646135	et	4	main
kuulavad	doc_366216787891_item	3646133	et	4	main
niisugune	doc_366216787891_item	3646126	et	3	main
oluline	doc_366216787891_item	3646103	et	4	main
folklöör	doc_366216787891_item	3646100	et	4	main
hingeline	doc_366216787891_item	3646082	et	4	main
kurb	doc_366216787891_item	3646081	et	3	main
ja	doc_366216787891_item	3646045	et	3	main
nagu	doc_366216787891_item	3646042	et	3	main
on	doc_366216787891_item	3646041	et	4	main
heli	doc_366216787891_item	3646040	et	4	main
eestlased	doc_366216787891_item	3646032	et	3	main
vilistati	doc_366216787891_item	3646029	et	3	main
või	doc_366216787891_item	3646027	et	4	main
väga	doc_366216787891_item	3646015	et	3	main
tuhat	doc_366216787891_item	3646008	et	4	main
sellest	doc_366216787891_item	3645997	et	4	main
tantsuga	doc_366216787891_item	3645996	et	3	main
või	doc_366216787891_item	3645995	et	4	main
rahvas	doc_366216787891_item	3645990	et	4	main
keele	doc_366216787891_item	3645953	et	4	main
ilusasti	doc_366216787891_item	3646187	et	3	main
põhjus	doc_366216787891_item	3646179	et	4	main
paderi	doc_366216787891_item	3646172	et	4	main
eurovisiooni	doc_366216787891_item	3646167	et	4	main
palju	doc_366216787891_item	3646153	et	4	main
laulupeod	doc_366216787891_item	3646150	et	4	main
ta	doc_399014257171_item	3646365	et	4	main
tööd	doc_399014257171_item	3646363	et	4	main
saas	doc_399014257171_item	3646358	et	4	main
hundipassi	doc_399014257171_item	3646357	et	4	main
miks	doc_399014257171_item	3646346	et	4	main
ei	doc_399014257171_item	3646339	et	4	main
ja	doc_399014257171_item	3646308	et	3	main
peeter	doc_399014257171_item	3646304	et	3	main
tööd	doc_399014257171_item	3646302	et	4	main
uut	doc_399014257171_item	3646301	et	3	main
leidma	doc_399014257171_item	3646300	et	3	main
pidis	doc_399014257171_item	3646299	et	4	main
laisk	doc_399014257171_item	3646292	et	3	main
peeter	doc_399014257171_item	3646290	et	3	main
arukas	doc_399014257171_item	3646278	et	4	main
ta	doc_399014257171_item	3646264	et	4	main
et	doc_399014257171_item	3646263	et	3	main
töötas	doc_399014257171_item	3646235	et	3	main
ta	doc_399014257171_item	3646234	et	4	main
kunagi	doc_399014257171_item	3646225	et	3	main
olnud	doc_399014257171_item	3646224	et	4	main
ta	doc_399014257171_item	3646222	et	4	main
ja	doc_399014257171_item	3646221	et	3	main
arto	doc_399014257171_item	3646207	et	4	main
ja	doc_399014257171_item	3646205	et	3	main
meest	doc_399014257171_item	3646198	et	4	main
ta	doc_464301607732_item	3646441	et	4	main
juhtimise	doc_740091151016_item	3645863	et	4	main
tegelikkusse	doc_740091151016_item	3645854	et	4	main
globaliseerimise	doc_740091151016_item	3645845	et	4	main
ideaalid	doc_740091151016_item	3645839	et	3	main
on	doc_740091151016_item	3645837	et	4	main
kaugele	doc_740091151016_item	3645829	et	4	main
olla	doc_740091151016_item	3645824	et	3	main
milleks	doc_740091151016_item	3645820	et	4	main
primitiivne	doc_740091151016_item	3645818	et	3	main
sõna	doc_740091151016_item	3645534	et	4	main
terminit	doc_740091151016_item	3645533	et	3	main
seda	doc_740091151016_item	3645532	et	3	main
ei	doc_740091151016_item	3645523	et	4	main
inimestele	doc_740091151016_item	3645522	et	3	main
tava	doc_740091151016_item	3645521	et	4	main
sõna	doc_740091151016_item	3645511	et	4	main
seda	doc_740091151016_item	3645510	et	3	main
mõjukaim	doc_740091151016_item	3645506	et	4	main
ja	doc_740091151016_item	3645505	et	3	main
sellest	doc_366216787891_item	3646145	et	4	main
on	doc_366216787891_item	3646140	et	4	main
on	doc_366216787891_item	3646124	et	4	main
eestis	doc_366216787891_item	3646123	et	3	main
kui	doc_366216787891_item	3646122	et	3	main
et	doc_366216787891_item	3646121	et	3	main
arutleda	doc_366216787891_item	3646120	et	3	main
ka	doc_366216787891_item	3646119	et	3	main
võiks	doc_366216787891_item	3646118	et	4	main
selle	doc_366216787891_item	3646108	et	4	main
on	doc_366216787891_item	3646101	et	4	main
kurba	doc_366216787891_item	3646088	et	4	main
ja	doc_366216787891_item	3646084	et	3	main
kui	doc_366216787891_item	3646037	et	3	main
rahvas	doc_366216787891_item	3646036	et	4	main
lauludega	doc_366216787891_item	3646031	et	3	main
hobu	doc_366216787891_item	3646028	et	4	main
saame	doc_366216787891_item	3646022	et	4	main
siis	doc_366216787891_item	3646021	et	3	main
sügavalt	doc_366216787891_item	3646020	et	4	main
arvan	doc_366216787891_item	3646002	et	3	main
miks	doc_366216787891_item	3646001	et	4	main
seotud	doc_366216787891_item	3645993	et	4	main
teise	doc_366216787891_item	3645952	et	4	main
kui	doc_366216787891_item	3645951	et	3	main
keele	doc_366216787891_item	3645950	et	4	main
suurepärane	doc_366216787891_item	3646178	et	4	main
laul	doc_366216787891_item	3646176	et	4	main
taneli	doc_366216787891_item	3646171	et	4	main
inimesi	doc_366216787891_item	3646154	et	4	main
mees	doc_399014257171_item	3646368	et	4	main
ei	doc_399014257171_item	3646360	et	4	main
ta	doc_399014257171_item	3646356	et	4	main
tea	doc_399014257171_item	3646345	et	4	main
vabakutselisena	doc_399014257171_item	3646336	et	4	main
peeter	doc_399014257171_item	3646334	et	3	main
eelmistel	doc_399014257171_item	3646332	et	3	main
saanud	doc_399014257171_item	3646329	et	4	main
agentuuris	doc_399014257171_item	3646325	et	3	main
vestlus	doc_399014257171_item	3646324	et	3	main
oli	doc_399014257171_item	3646322	et	3	main
saanud	doc_399014257171_item	3646320	et	4	main
oli	doc_399014257171_item	3646313	et	3	main
tal	doc_399014257171_item	3646312	et	3	main
oli	doc_399014257171_item	3646310	et	3	main
ta	doc_399014257171_item	3646298	et	4	main
tema	doc_399014257171_item	3646286	et	4	main
ja	doc_399014257171_item	3646285	et	3	main
globaalne	doc_740091151016_item	3645852	et	3	main
tegelevad	doc_740091151016_item	3645844	et	4	main
millega	doc_740091151016_item	3645843	et	3	main
minna	doc_740091151016_item	3645827	et	3	main
pole	doc_740091151016_item	3645825	et	3	main
juba	doc_740091151016_item	3645823	et	3	main
on	doc_740091151016_item	3645806	et	4	main
meil	doc_740091151016_item	3645805	et	4	main
palju	doc_740091151016_item	3645528	et	4	main
kuid	doc_740091151016_item	3645520	et	4	main
vestlustes	doc_740091151016_item	3645519	et	3	main
globaliseerimine	doc_740091151016_item	3645509	et	4	main
suund	doc_740091151016_item	3645508	et	3	main
võlu	doc_740091151016_item	3645496	et	4	main
need	doc_740091151016_item	3645808	et	3	main
teeb	doc_740091151016_item	3645531	et	3	main
on	doc_740091151016_item	3645512	et	4	main
valu	doc_740091151016_item	3645498	et	4	main
ja	doc_740091151016_item	3645497	et	3	main
räägib	doc_366216787891_item	3646146	et	3	main
laulupeod	doc_366216787891_item	3646139	et	4	main
kombe	doc_366216787891_item	3646127	et	4	main
on	doc_366216787891_item	3646116	et	4	main
nad	doc_366216787891_item	3646115	et	3	main
praegu	doc_366216787891_item	3646114	et	3	main
kui	doc_366216787891_item	3646113	et	3	main
laulupeod	doc_366216787891_item	3646112	et	4	main
organiseerid	doc_366216787891_item	3646111	et	3	main
väga	doc_366216787891_item	3646102	et	3	main
eesti	doc_366216787891_item	3646099	et	4	main
tore	doc_366216787891_item	3646098	et	3	main
muidugi	doc_366216787891_item	3646097	et	4	main
laulsid	doc_366216787891_item	3646087	et	4	main
nad	doc_366216787891_item	3646086	et	3	main
siis	doc_366216787891_item	3646085	et	3	main
siis	doc_366216787891_item	3646078	et	3	main
kombe	doc_366216787891_item	3646043	et	4	main
väga	doc_366216787891_item	3646034	et	3	main
kutsuti	doc_366216787891_item	3646030	et	3	main
ette	doc_366216787891_item	3646024	et	4	main
oli	doc_366216787891_item	3646014	et	3	main
millal	doc_366216787891_item	3646011	et	3	main
aastat	doc_366216787891_item	3646009	et	3	main
juba	doc_366216787891_item	3646007	et	3	main
on	doc_366216787891_item	3646005	et	4	main
see	doc_366216787891_item	3646004	et	3	main
et	doc_366216787891_item	3646003	et	3	main
lauluga	doc_366216787891_item	3645994	et	4	main
eesti	doc_366216787891_item	3645989	et	4	main
maailmas	doc_366216787891_item	3645988	et	3	main
mõttes	doc_366216787891_item	3645987	et	3	main
seda	doc_366216787891_item	3646186	et	3	main
teevad	doc_366216787891_item	3646185	et	3	main
ja	doc_366216787891_item	3646184	et	3	main
laulda	doc_366216787891_item	3646183	et	4	main
armastavad	doc_366216787891_item	3646182	et	4	main
ja	doc_740091151016_item	3645516	et	3	main
uudistes	doc_740091151016_item	3645515	et	3	main
igapäev	doc_740091151016_item	3645514	et	3	main
kuulda	doc_740091151016_item	3645513	et	4	main
ühiskonna	doc_740091151016_item	3645507	et	4	main
olulisem	doc_740091151016_item	3645504	et	4	main
üks	doc_740091151016_item	3645503	et	3	main
tekinud	doc_740091151016_item	3645502	et	4	main
globaliseerimise	doc_740091151016_item	3645495	et	4	main
essee	doc_740091151016_item	3645494	et	4	main
tegevusala	doc_366216787891_item	3646142	et	4	main
mõtlevad	doc_366216787891_item	3646136	et	4	main
säilinud	doc_366216787891_item	3646125	et	4	main
otsustati	doc_366216787891_item	3646110	et	3	main
eest	doc_366216787891_item	3646109	et	4	main
on	doc_366216787891_item	3646096	et	4	main
see	doc_366216787891_item	3646095	et	3	main
siis	doc_366216787891_item	3646094	et	3	main
tagasi	doc_366216787891_item	3646093	et	3	main
seisukord	doc_366216787891_item	3646083	et	3	main
oli	doc_366216787891_item	3646080	et	3	main
naistel	doc_366216787891_item	3646079	et	3	main
sõjad	doc_366216787891_item	3646077	et	3	main
kui	doc_366216787891_item	3646143	et	3	main
eestimaal	doc_366216787891_item	3646138	et	4	main
sellest	doc_366216787891_item	3646134	et	4	main
kes	doc_366216787891_item	3646132	et	4	main
need	doc_366216787891_item	3646131	et	3	main
siis	doc_366216787891_item	3646130	et	3	main
traditsioon	doc_366216787891_item	3646129	et	3	main
ja	doc_366216787891_item	3646128	et	3	main
traditsioonilised	doc_366216787891_item	3646117	et	4	main
vara	doc_366216787891_item	3646107	et	4	main
riiklik	doc_366216787891_item	3646106	et	3	main
nagu	doc_366216787891_item	3646105	et	3	main
tegur	doc_366216787891_item	3646104	et	3	main
tulevad	doc_366216787891_item	3646092	et	4	main
mehed	doc_366216787891_item	3646091	et	3	main
kui	doc_366216787891_item	3646090	et	3	main
lauluid	doc_366216787891_item	3646089	et	3	main
näiteks	doc_366216787891_item	3646076	et	4	main
aeg	doc_366216787891_item	3646075	et	3	main
keeruline	doc_366216787891_item	3646074	et	4	main
väga	doc_366216787891_item	3646073	et	3	main
oli	doc_366216787891_item	3646072	et	3	main
see	doc_366216787891_item	3646071	et	3	main
arengus	doc_366216787891_item	3646070	et	3	main
oli	doc_366216787891_item	3646069	et	3	main
protsess	doc_366216787891_item	3646068	et	3	main
see	doc_366216787891_item	3646067	et	3	main
kui	doc_366216787891_item	3646066	et	3	main
seisukorras	doc_366216787891_item	3646065	et	3	main
heas	doc_366216787891_item	3646064	et	3	main
on	doc_366216787891_item	3646063	et	4	main
hing	doc_366216787891_item	3646062	et	3	main
inimeste	doc_366216787891_item	3646061	et	3	main
lauluga	doc_366216787891_item	3646060	et	4	main
sest	doc_366216787891_item	3646059	et	4	main
laulda	doc_366216787891_item	3646058	et	4	main
võiks	doc_366216787891_item	3646057	et	4	main
loobuda	doc_366216787891_item	3646056	et	3	main
hästi	doc_366216787891_item	3646055	et	3	main
pingedest	doc_366216787891_item	3646054	et	4	main
et	doc_366216787891_item	3646053	et	3	main
meeleolu	doc_366216787891_item	3646052	et	4	main
hea	doc_366216787891_item	3646051	et	4	main
ja	doc_366216787891_item	3646050	et	3	main
rõõmu	doc_366216787891_item	3646049	et	4	main
inimestele	doc_366216787891_item	3646048	et	3	main
toovad	doc_366216787891_item	3646047	et	4	main
tants	doc_366216787891_item	3646046	et	3	main
iga	doc_366216787891_item	3646039	et	4	main
ka	doc_366216787891_item	3646038	et	3	main
on	doc_366216787891_item	3646033	et	4	main
natuke	doc_366216787891_item	3646019	et	4	main
laul	doc_366216787891_item	3646044	et	4	main
usklik	doc_366216787891_item	3646035	et	3	main
lehma	doc_366216787891_item	3646026	et	4	main
et	doc_366216787891_item	3646025	et	3	main
kujutada	doc_366216787891_item	3646023	et	3	main
kalapüüdmine	doc_366216787891_item	3646013	et	3	main
kujunenud	doc_366216787891_item	3646006	et	4	main
kohe	doc_366216787891_item	3645992	et	4	main
minu	doc_366216787891_item	3645986	et	3	main
näidetega	doc_366216787891_item	3645985	et	3	main
illustreerida	doc_366216787891_item	3645984	et	3	main
soovitatav	doc_366216787891_item	3645983	et	4	main
on	doc_366216787891_item	3645982	et	4	main
faktidele	doc_366216787891_item	3645980	et	3	main
väiteid	doc_366216787891_item	3645981	et	4	main
esitatud	doc_366216787891_item	3645979	et	4	main
lugemistekstis	doc_366216787891_item	3645978	et	3	main
ja	doc_366216787891_item	3645977	et	3	main
loengus	doc_366216787891_item	3645976	et	3	main
tuginema	doc_366216787891_item	3645975	et	3	main
üldistav	doc_366216787891_item	3645974	et	4	main
ja	doc_366216787891_item	3645973	et	3	main
analüüsiv	doc_366216787891_item	3645972	et	4	main
arutlev	doc_366216787891_item	3645971	et	4	main
olema	doc_366216787891_item	3645970	et	4	main
peab	doc_366216787891_item	3645969	et	4	main
essee	doc_366216787891_item	3645968	et	4	main
sõna	doc_366216787891_item	3645967	et	4	main
350	doc_366216787891_item	3645966	et	2	main
300	doc_366216787891_item	3645965	et	2	main
pikkus	doc_366216787891_item	3645964	et	4	main
essee	doc_366216787891_item	3645963	et	4	main
laulurahva	doc_366216787891_item	3645962	et	3	main
eestlastest	doc_366216787891_item	3645961	et	4	main
teeb	doc_366216787891_item	3645960	et	3	main
mis	doc_366216787891_item	3645959	et	4	main
teemal	doc_366216787891_item	3645958	et	3	main
essee	doc_366216787891_item	3645957	et	4	main
kirjutage	doc_366216787891_item	3645956	et	3	main
kirjutamine	doc_366216787891_item	3645955	et	4	main
test	doc_366216787891_item	3645954	et	3	main
mõtleme	doc_366216787891_item	3646018	et	3	main
kui	doc_366216787891_item	3646017	et	3	main
populaarne	doc_366216787891_item	3646016	et	3	main
põllutööd	doc_366216787891_item	3646012	et	4	main
tagasi	doc_366216787891_item	3646010	et	3	main
küsimus	doc_366216787891_item	3646000	et	4	main
tekkib	doc_366216787891_item	3645999	et	3	main
ka	doc_366216787891_item	3645998	et	3	main
on	doc_366216787891_item	3645991	et	4	main
eesti	doc_366216787891_item	3645949	et	4	main
oli	doc_366216787891_item	3646177	et	3	main
bentone	doc_366216787891_item	3646175	et	4	main
deiv	doc_366216787891_item	3646174	et	4	main
ja	doc_366216787891_item	3646173	et	3	main
konkursi	doc_366216787891_item	3646169	et	3	main
võitis	doc_366216787891_item	3646165	et	3	main
oli	doc_399014257171_item	3646372	et	3	main
peeter	doc_399014257171_item	3646371	et	3	main
vana	doc_399014257171_item	3646367	et	4	main
sest	doc_399014257171_item	3646364	et	4	main
uut	doc_399014257171_item	3646362	et	3	main
leidnud	doc_399014257171_item	3646361	et	4	main
kõrgharidusega	doc_399014257171_item	3646354	et	3	main
ma	doc_399014257171_item	3646343	et	3	main
filmis	doc_399014257171_item	3646342	et	4	main
hästi	doc_399014257171_item	3646341	et	3	main
aga	doc_399014257171_item	3646337	et	3	main
aastatel	doc_399014257171_item	3646333	et	4	main
ta	doc_399014257171_item	3646327	et	4	main
koolis	doc_399014257171_item	3646315	et	4	main
olla	doc_399014257171_item	3646307	et	3	main
armastas	doc_399014257171_item	3646305	et	3	main
siiski	doc_399014257171_item	3646303	et	4	main
hundipassi	doc_399014257171_item	3646295	et	4	main
sellepärast	doc_399014257171_item	3646293	et	3	main
on	doc_399014257171_item	3646291	et	4	main
hästi	doc_399014257171_item	3646284	et	3	main
ei	doc_399014257171_item	3646282	et	4	main
ta	doc_399014257171_item	3646281	et	4	main
aga	doc_399014257171_item	3646280	et	3	main
mees	doc_399014257171_item	3646279	et	4	main
habe	doc_399014257171_item	3646274	et	3	main
hall	doc_399014257171_item	3646273	et	4	main
tal	doc_399014257171_item	3646271	et	3	main
vana	doc_399014257171_item	3646269	et	4	main
50	doc_399014257171_item	3646267	et	2	main
umbes	doc_399014257171_item	3646266	et	4	main
oli	doc_399014257171_item	3646265	et	3	main
aga	doc_399014257171_item	3646255	et	3	main
vana	doc_399014257171_item	3646254	et	4	main
aastat	doc_399014257171_item	3646253	et	3	main
44	doc_399014257171_item	3646252	et	2	main
oli	doc_399014257171_item	3646251	et	3	main
peeter	doc_399014257171_item	3646250	et	3	main
huvim	doc_399014257171_item	3646247	et	4	main
ja	doc_399014257171_item	3646233	et	3	main
vana	doc_399014257171_item	3646232	et	4	main
aastat	doc_399014257171_item	3646231	et	3	main
tööl	doc_399014257171_item	3646227	et	3	main
ei	doc_399014257171_item	3646223	et	4	main
projektijuhtina	doc_399014257171_item	3646215	et	4	main
töötas	doc_399014257171_item	3646214	et	3	main
nende	doc_399014257171_item	3646200	et	4	main
filmi	doc_399014257171_item	3646195	et	4	main
vaatasin	doc_399014257171_item	3646194	et	3	main
ma	doc_399014257171_item	3646193	et	3	main
nädalal	doc_399014257171_item	3646192	et	3	main
eelmisel	doc_399014257171_item	3646191	et	3	main
mees	doc_399014257171_item	3646393	et	4	main
ta	doc_464301607732_item	3646443	et	4	main
jaapani	doc_464301607732_item	3646426	et	4	main
koolis	doc_744962874528_item	3646492	et	4	main
venemad	doc_744962874528_item	3646489	et	4	main
korras	doc_744962874528_item	3646487	et	4	main
on	doc_744962874528_item	3646486	et	4	main
tarkus	doc_744962874528_item	3646477	et	4	main
palk	doc_744962874528_item	3646469	et	3	main
linnas	doc_744962874528_item	3646465	et	4	main
inimene	doc_744962874528_item	3646462	et	3	main
väga	doc_767882159212_item	3646662	et	3	main
elavad	doc_767882159212_item	3646657	et	4	main
loomulikult	doc_767882159212_item	3646649	et	4	main
essee	doc_366216787891_item	3645948	et	4	main
eestimaal	doc_366216787891_item	3646181	et	4	main
kus	doc_366216787891_item	3646170	et	3	main
laulu	doc_366216787891_item	3646168	et	4	main
ka	doc_366216787891_item	3646166	et	3	main
eesti	doc_366216787891_item	3646164	et	4	main
et	doc_366216787891_item	3646163	et	3	main
unustada	doc_366216787891_item	3646162	et	3	main
ka	doc_366216787891_item	3646161	et	3	main
saa	doc_366216787891_item	3646160	et	4	main
korjavad	doc_366216787891_item	3646152	et	4	main
eestis	doc_366216787891_item	3646151	et	3	main
situatsioon	doc_366216787891_item	3646149	et	3	main
ajalooline	doc_366216787891_item	3646148	et	4	main
ka	doc_366216787891_item	3646147	et	3	main
meelest	doc_399014257171_item	3646370	et	4	main
mu	doc_399014257171_item	3646369	et	3	main
ta	doc_399014257171_item	3646359	et	4	main
ta	doc_399014257171_item	3646348	et	4	main
võib-olla	doc_399014257171_item	3646347	et	3	main
töötanud	doc_399014257171_item	3646340	et	4	main
ei	doc_399014257171_item	3646328	et	4	main
tal	doc_399014257171_item	3646321	et	3	main
ei	doc_399014257171_item	3646319	et	4	main
töökohita	doc_399014257171_item	3646318	et	3	main
ta	doc_399014257171_item	3646317	et	4	main
aga	doc_399014257171_item	3646316	et	3	main
ja	doc_399014257171_item	3646297	et	3	main
ta	doc_399014257171_item	3646294	et	4	main
et	doc_399014257171_item	3646289	et	3	main
mötles	doc_399014257171_item	3646288	et	4	main
peremees	doc_399014257171_item	3646287	et	4	main
töötanud	doc_399014257171_item	3646283	et	4	main
oli	doc_399014257171_item	3646276	et	3	main
sest	doc_399014257171_item	3646270	et	4	main
aastat	doc_399014257171_item	3646268	et	3	main
meelest	doc_399014257171_item	3646257	et	4	main
mu	doc_399014257171_item	3646256	et	3	main
mees	doc_399014257171_item	3646248	et	4	main
kõige	doc_399014257171_item	3646246	et	4	main
oli	doc_399014257171_item	3646245	et	3	main
vabakutselisena	doc_399014257171_item	3646236	et	4	main
ametlikult	doc_399014257171_item	3646226	et	4	main
georg	doc_399014257171_item	3646216	et	4	main
oli	doc_399014257171_item	3646208	et	3	main
peeter	doc_399014257171_item	3646206	et	3	main
georg	doc_399014257171_item	3646204	et	4	main
eesti	doc_399014257171_item	3646197	et	4	main
essee	doc_399014257171_item	3646189	et	4	main
imelik	doc_399014257171_item	3646392	et	3	main
arto	doc_399014257171_item	3646389	et	4	main
et	doc_399014257171_item	3646388	et	3	main
ma	doc_399014257171_item	3646386	et	3	main
ja	doc_399014257171_item	3646385	et	3	main
mõtlesin	doc_399014257171_item	3646387	et	3	main
ütles	doc_464301607732_item	3646442	et	3	main
eesti	doc_464301607732_item	3646439	et	4	main
jaapani	doc_464301607732_item	3646431	et	4	main
teab	doc_464301607732_item	3646430	et	3	main
sõber	doc_464301607732_item	3646429	et	3	main
minu	doc_464301607732_item	3646428	et	3	main
muusiku	doc_464301607732_item	3646427	et	4	main
keelt	doc_464301607732_item	3646422	et	4	main
eesti	doc_464301607732_item	3646421	et	4	main
ja	doc_464301607732_item	3646420	et	3	main
keelt	doc_464301607732_item	3646419	et	4	main
aitavad	doc_744962874528_item	3646490	et	4	main
elus	doc_744962874528_item	3646488	et	4	main
ja	doc_744962874528_item	3646484	et	3	main
on	doc_744962874528_item	3646482	et	4	main
elus	doc_744962874528_item	3646476	et	4	main
sest	doc_744962874528_item	3646473	et	4	main
vajalikud	doc_744962874528_item	3646472	et	3	main
on	doc_744962874528_item	3646471	et	4	main
on	doc_767882159212_item	3646661	et	4	main
eestlased	doc_767882159212_item	3646651	et	3	main
äärde	doc_767882159212_item	3646643	et	4	main
et	doc_366216787891_item	3646180	et	3	main
ei	doc_366216787891_item	3646159	et	4	main
välismaalt	doc_366216787891_item	3646158	et	3	main
ka	doc_366216787891_item	3646157	et	3	main
kui	doc_366216787891_item	3646156	et	3	main
eestimaalt	doc_366216787891_item	3646155	et	3	main
on	doc_399014257171_item	3646366	et	4	main
pärast	doc_399014257171_item	3646355	et	4	main
oli	doc_399014257171_item	3646353	et	3	main
ta	doc_399014257171_item	3646352	et	4	main
sest	doc_399014257171_item	3646351	et	4	main
tüdinenud	doc_399014257171_item	3646350	et	4	main
oli	doc_399014257171_item	3646349	et	3	main
ärritav	doc_399014257171_item	3646384	et	4	main
oli	doc_399014257171_item	3646383	et	3	main
sest	doc_399014257171_item	3646382	et	4	main
george	doc_399014257171_item	3646381	et	4	main
meeldi	doc_399014257171_item	3646380	et	4	main
ei	doc_399014257171_item	3646379	et	4	main
mulle	doc_399014257171_item	3646378	et	4	main
georg	doc_399014257171_item	3646377	et	4	main
ja	doc_399014257171_item	3646376	et	3	main
arto	doc_399014257171_item	3646375	et	4	main
kui	doc_399014257171_item	3646374	et	3	main
huvim	doc_399014257171_item	3646373	et	4	main
ei	doc_399014257171_item	3646344	et	4	main
ta	doc_399014257171_item	3646338	et	4	main
töötas	doc_399014257171_item	3646335	et	3	main
tööd	doc_399014257171_item	3646331	et	4	main
seda	doc_399014257171_item	3646330	et	3	main
aga	doc_399014257171_item	3646326	et	3	main
ka	doc_399014257171_item	3646323	et	3	main
vestlus	doc_399014257171_item	3646314	et	3	main
alkoholiprobleemid	doc_399014257171_item	3646311	et	3	main
tal	doc_399014257171_item	3646309	et	3	main
üksi	doc_399014257171_item	3646306	et	4	main
saas	doc_399014257171_item	3646296	et	4	main
väga	doc_399014257171_item	3646277	et	3	main
mõtlesin	doc_399014257171_item	3646262	et	3	main
vanem	doc_399014257171_item	3646260	et	4	main
näis	doc_399014257171_item	3646259	et	3	main
ta	doc_399014257171_item	3646258	et	4	main
ta	doc_399014257171_item	3646244	et	4	main
meelest	doc_399014257171_item	3646243	et	4	main
mu	doc_399014257171_item	3646242	et	3	main
sest	doc_399014257171_item	3646241	et	4	main
kohta	doc_399014257171_item	3646240	et	4	main
44	doc_399014257171_item	3646230	et	2	main
oli	doc_399014257171_item	3646229	et	3	main
peeter	doc_399014257171_item	3646228	et	3	main
ta	doc_399014257171_item	3646213	et	4	main
ja	doc_399014257171_item	3646212	et	3	main
vana	doc_399014257171_item	3646211	et	4	main
aastat	doc_399014257171_item	3646210	et	3	main
kohta	doc_399014257171_item	3646199	et	4	main
peeter	doc_399014257171_item	3646190	et	3	main
jaapansse	doc_464301607732_item	3646445	et	4	main
muusiku	doc_464301607732_item	3646432	et	4	main
meie	doc_464301607732_item	3646423	et	4	main
raakime	doc_464301607732_item	3646417	et	4	main
kui	doc_464301607732_item	3646416	et	3	main
niiedasi	doc_744962874528_item	3646494	et	4	main
kõik	doc_744962874528_item	3646485	et	4	main
edukas	doc_744962874528_item	3646483	et	4	main
see	doc_744962874528_item	3646481	et	3	main
tähtis	doc_744962874528_item	3646480	et	4	main
väga	doc_744962874528_item	3646479	et	3	main
on	doc_744962874528_item	3646478	et	4	main
aitavad	doc_744962874528_item	3646475	et	4	main
nad	doc_744962874528_item	3646474	et	3	main
on	doc_744962874528_item	3646467	et	4	main
tundlikud	doc_767882159212_item	3646663	et	3	main
maadel	doc_767882159212_item	3646658	et	4	main
eestlasi	doc_767882159212_item	3646656	et	3	main
veel	doc_767882159212_item	3646654	et	4	main
ajal	doc_767882159212_item	3646653	et	4	main
sellest	doc_767882159212_item	3646646	et	4	main
saada	doc_767882159212_item	3646645	et	4	main
ja	doc_767882159212_item	3646644	et	3	main
on	doc_767882159212_item	3646633	et	4	main
isamaa	doc_767882159212_item	3646624	et	4	main
kinnitati	doc_767882159212_item	3646617	et	4	main
rahvas	doc_767882159212_item	3646614	et	4	main
väga	doc_767882159212_item	3646612	et	3	main
eesti	doc_767882159212_item	3646603	et	4	main
rõõm	doc_767882159212_item	3646602	et	3	main
ja	doc_767882159212_item	3646601	et	3	main
õnn	doc_767882159212_item	3646600	et	3	main
mu	doc_767882159212_item	3646599	et	3	main
jannsen	doc_767882159212_item	3646592	et	4	main
peeti	doc_767882159212_item	3646578	et	4	main
laulupidu	doc_767882159212_item	3646577	et	4	main
esimene	doc_767882159212_item	3646576	et	3	main
sai	doc_767882159212_item	3646570	et	4	main
mis	doc_767882159212_item	3646569	et	4	main
peeter	doc_399014257171_item	3646275	et	3	main
oli	doc_399014257171_item	3646272	et	3	main
ma	doc_399014257171_item	3646261	et	3	main
filmis	doc_399014257171_item	3646249	et	4	main
peeteri	doc_399014257171_item	3646239	et	4	main
kirjutan	doc_399014257171_item	3646238	et	3	main
ma	doc_399014257171_item	3646237	et	3	main
vana	doc_399014257171_item	3646220	et	4	main
aastat	doc_399014257171_item	3646219	et	3	main
33	doc_399014257171_item	3646218	et	2	main
oli	doc_399014257171_item	3646217	et	3	main
22	doc_399014257171_item	3646209	et	2	main
arto	doc_399014257171_item	3646203	et	4	main
oli	doc_399014257171_item	3646202	et	3	main
nimid	doc_399014257171_item	3646201	et	4	main
kolme	doc_399014257171_item	3646196	et	4	main
vaga	doc_399014257171_item	3646391	et	4	main
oli	doc_399014257171_item	3646390	et	3	main
tuleksi	doc_464301607732_item	3646444	et	4	main
sõberist	doc_464301607732_item	3646440	et	4	main
muusiku	doc_464301607732_item	3646437	et	4	main
meie	doc_464301607732_item	3646415	et	4	main
söökde	doc_464301607732_item	3646414	et	4	main
jaapani	doc_464301607732_item	3646413	et	4	main
süüa	doc_464301607732_item	3646412	et	3	main
tegime	doc_464301607732_item	3646411	et	3	main
meie	doc_464301607732_item	3646410	et	4	main
ja	doc_464301607732_item	3646409	et	3	main
filmide	doc_464301607732_item	3646408	et	3	main
jaapani	doc_464301607732_item	3646407	et	4	main
nägime	doc_464301607732_item	3646406	et	3	main
meie	doc_464301607732_item	3646405	et	4	main
pühapäeval	doc_464301607732_item	3646404	et	3	main
toasse	doc_464301607732_item	3646403	et	3	main
sõberi	doc_464301607732_item	3646402	et	4	main
eesti	doc_464301607732_item	3646401	et	4	main
minu	doc_464301607732_item	3646400	et	3	main
käisin	doc_464301607732_item	3646399	et	3	main
ma	doc_464301607732_item	3646398	et	3	main
nädalalõpp	doc_464301607732_item	3646397	et	3	main
minu	doc_464301607732_item	3646396	et	3	main
essee	doc_464301607732_item	3646395	et	4	main
elus	doc_744962874528_item	3646491	et	4	main
sõbrad	doc_744962874528_item	3646470	et	3	main
minu	doc_464301607732_item	3646438	et	3	main
jaapani	doc_464301607732_item	3646436	et	4	main
õppisin	doc_464301607732_item	3646435	et	3	main
ma	doc_464301607732_item	3646434	et	3	main
ja	doc_464301607732_item	3646433	et	3	main
raakime	doc_464301607732_item	3646425	et	4	main
kui	doc_464301607732_item	3646424	et	3	main
jaapani	doc_464301607732_item	3646418	et	4	main
ja	doc_744962874528_item	3646493	et	3	main
suur	doc_744962874528_item	3646468	et	3	main
tal	doc_744962874528_item	3646466	et	3	main
heas	doc_744962874528_item	3646464	et	3	main
elab	doc_744962874528_item	3646463	et	3	main
kui	doc_744962874528_item	3646461	et	3	main
ehkki	doc_744962874528_item	3646460	et	3	main
tähtis	doc_744962874528_item	3646459	et	4	main
väga	doc_744962874528_item	3646458	et	3	main
on	doc_744962874528_item	3646457	et	4	main
elukoht	doc_744962874528_item	3646456	et	3	main
elus	doc_744962874528_item	3646455	et	4	main
aitab	doc_744962874528_item	3646454	et	3	main
haridus	doc_744962874528_item	3646453	et	3	main
sest	doc_744962874528_item	3646452	et	4	main
tähtis	doc_744962874528_item	3646451	et	4	main
väga	doc_744962874528_item	3646450	et	3	main
on	doc_744962874528_item	3646449	et	4	main
haridus	doc_744962874528_item	3646448	et	3	main
essee	doc_744962874528_item	3646447	et	4	main
nendel	doc_767882159212_item	3646659	et	4	main
meie	doc_767882159212_item	3646652	et	4	main
teevad	doc_767882159212_item	3646650	et	3	main
loodus	doc_767882159212_item	3646635	et	4	main
oma	doc_767882159212_item	3646623	et	4	main
seda	doc_767882159212_item	3646616	et	3	main
oli	doc_767882159212_item	3646611	et	3	main
laul	doc_767882159212_item	3646610	et	4	main
see	doc_767882159212_item	3646609	et	3	main
tundlik	doc_767882159212_item	3646607	et	3	main
voldemar	doc_767882159212_item	3646591	et	4	main
sada	doc_767882159212_item	3646573	et	4	main
traditsiooniks	doc_767882159212_item	3646572	et	3	main
oma	doc_767882159212_item	3646567	et	4	main
lauluväljakule	doc_767882159212_item	3646563	et	3	main
väiteid	doc_767882159212_item	3646529	et	4	main
faktidele	doc_767882159212_item	3646528	et	3	main
ja	doc_767882159212_item	3646521	et	3	main
300	doc_767882159212_item	3646513	et	2	main
mõtteviisi	doc_767882159212_item	3646796	et	4	main
ja	doc_767882159212_item	3646792	et	3	main
ainulaadsed	doc_767882159212_item	3646790	et	3	main
europasse	doc_767882159212_item	3646787	et	4	main
võtab	doc_767882159212_item	3646786	et	3	main
muusika	doc_767882159212_item	3646772	et	4	main
loodus	doc_767882159212_item	3646766	et	4	main
aga	doc_767882159212_item	3646660	et	3	main
palju	doc_767882159212_item	3646655	et	4	main
palju	doc_767882159212_item	3646636	et	4	main
elavad	doc_767882159212_item	3646629	et	4	main
väga	doc_767882159212_item	3646622	et	3	main
meeldivad	doc_767882159212_item	3646621	et	4	main
eestlased	doc_767882159212_item	3646620	et	3	main
hümniks	doc_767882159212_item	3646619	et	3	main
eesti	doc_767882159212_item	3646618	et	4	main
ning	doc_767882159212_item	3646608	et	3	main
on	doc_767882159212_item	3646605	et	4	main
rahv	doc_767882159212_item	3646604	et	4	main
ise	doc_767882159212_item	3646594	et	4	main
kes	doc_767882159212_item	3646593	et	4	main
aastad	doc_767882159212_item	3646574	et	3	main
meeldivad	doc_767882159212_item	3646566	et	4	main
väga	doc_767882159212_item	3646565	et	3	main
eestlased	doc_767882159212_item	3646564	et	3	main
vaadata	doc_767882159212_item	3646553	et	4	main
neid	doc_767882159212_item	3646552	et	4	main
on	doc_767882159212_item	3646530	et	4	main
essee	doc_767882159212_item	3646516	et	4	main
eestlastest	doc_767882159212_item	3646509	et	4	main
teise	doc_767882159212_item	3646500	et	4	main
ning	doc_767882159212_item	3646794	et	3	main
laulupeod	doc_767882159212_item	3646776	et	4	main
kallim	doc_767882159212_item	3646770	et	4	main
mida	doc_767882159212_item	3646648	et	4	main
naudingut	doc_767882159212_item	3646647	et	3	main
vaikne	doc_767882159212_item	3646634	et	3	main
ja	doc_767882159212_item	3646631	et	3	main
ja	doc_767882159212_item	3646615	et	3	main
väga	doc_767882159212_item	3646606	et	3	main
johann	doc_767882159212_item	3646590	et	4	main
oli	doc_767882159212_item	3646589	et	3	main
eestvedajaks	doc_767882159212_item	3646588	et	3	main
seda	doc_767882159212_item	3646587	et	3	main
aastal	doc_767882159212_item	3646586	et	3	main
50	doc_767882159212_item	3646585	et	2	main
tagasi	doc_767882159212_item	3646575	et	3	main
nende	doc_767882159212_item	3646571	et	4	main
kaasneb	doc_767882159212_item	3646558	et	3	main
soovitatav	doc_767882159212_item	3646531	et	4	main
üldistav	doc_767882159212_item	3646522	et	4	main
olema	doc_767882159212_item	3646518	et	4	main
peab	doc_767882159212_item	3646517	et	4	main
pikkus	doc_767882159212_item	3646512	et	4	main
laulurahva	doc_767882159212_item	3646510	et	3	main
mis	doc_767882159212_item	3646507	et	4	main
keele	doc_767882159212_item	3646501	et	4	main
keele	doc_767882159212_item	3646498	et	4	main
eesti	doc_767882159212_item	3646497	et	4	main
rohelise	doc_767882159212_item	3646795	et	4	main
oma	doc_767882159212_item	3646789	et	4	main
traditsioniks	doc_767882159212_item	3646779	et	4	main
jaoks	doc_767882159212_item	3646773	et	4	main
on	doc_767882159212_item	3646768	et	4	main
mere	doc_767882159212_item	3646642	et	3	main
sõida	doc_767882159212_item	3646641	et	4	main
võib	doc_767882159212_item	3646640	et	3	main
koguaeg	doc_767882159212_item	3646639	et	3	main
ja	doc_767882159212_item	3646638	et	3	main
metsi	doc_767882159212_item	3646637	et	4	main
seal	doc_767882159212_item	3646632	et	4	main
põhjal	doc_767882159212_item	3646630	et	4	main
nad	doc_767882159212_item	3646628	et	3	main
loodus	doc_767882159212_item	3646627	et	4	main
oma	doc_767882159212_item	3646626	et	4	main
ning	doc_767882159212_item	3646625	et	3	main
popularne	doc_767882159212_item	3646613	et	4	main
isamaa	doc_767882159212_item	3646598	et	4	main
mu	doc_767882159212_item	3646597	et	3	main
laulu	doc_767882159212_item	3646596	et	4	main
kirjutas	doc_767882159212_item	3646595	et	3	main
kaotamise	doc_767882159212_item	3646584	et	4	main
pärisorjuse	doc_767882159212_item	3646583	et	3	main
tänu	doc_767882159212_item	3646582	et	4	main
ning	doc_767882159212_item	3646581	et	3	main
juubeli	doc_767882159212_item	3646580	et	3	main
tartus	doc_767882159212_item	3646579	et	3	main
laulupidu	doc_767882159212_item	3646568	et	4	main
väljakult	doc_767882159212_item	3646562	et	4	main
vabaduse	doc_767882159212_item	3646561	et	4	main
rongkäiguga	doc_767882159212_item	3646560	et	3	main
inimeste	doc_767882159212_item	3646559	et	3	main
laulupidu	doc_767882159212_item	3646557	et	4	main
see	doc_767882159212_item	3646556	et	3	main
kuulajat	doc_767882159212_item	3646555	et	4	main
tuhandeid	doc_767882159212_item	3646554	et	3	main
üldlaulu-	doc_767882159212_item	3646535	et	4	main
esitatud	doc_767882159212_item	3646527	et	4	main
lugemistekstis	doc_767882159212_item	3646526	et	3	main
ja	doc_767882159212_item	3646525	et	3	main
loengus	doc_767882159212_item	3646524	et	3	main
tuginema	doc_767882159212_item	3646523	et	3	main
350	doc_767882159212_item	3646514	et	2	main
kirjutamine	doc_767882159212_item	3646503	et	4	main
test	doc_767882159212_item	3646502	et	3	main
essee	doc_767882159212_item	3646496	et	4	main
eesti	doc_767882159212_item	3646785	et	4	main
leedus	doc_767882159212_item	3646784	et	4	main
ka	doc_767882159212_item	3646783	et	3	main
kui	doc_767882159212_item	3646782	et	3	main
lätis	doc_767882159212_item	3646781	et	4	main
nii	doc_767882159212_item	3646780	et	3	main
põhjaloodus	doc_767882159212_item	3646775	et	4	main
eriti	doc_767882159212_item	3646774	et	3	main
kõige	doc_767882159212_item	3646769	et	4	main
loodus	doc_767882159212_item	3646767	et	4	main
teeb	doc_767882159212_item	3646763	et	3	main
nende	doc_767882159212_item	3646754	et	4	main
et	doc_767882159212_item	3646753	et	3	main
siis	doc_767882159212_item	3646745	et	3	main
või	doc_767882159212_item	3646743	et	4	main
näiteks	doc_767882159212_item	3646741	et	4	main
pidu	doc_767882159212_item	3646740	et	4	main
neil	doc_767882159212_item	3646737	et	4	main
kui	doc_767882159212_item	3646736	et	3	main
laulavad	doc_767882159212_item	3646721	et	4	main
oma	doc_767882159212_item	3646719	et	4	main
kuulda	doc_767882159212_item	3646715	et	4	main
maadel	doc_767882159212_item	3646712	et	4	main
tulevad	doc_767882159212_item	3646551	et	4	main
ning	doc_767882159212_item	3646550	et	3	main
osalejat	doc_767882159212_item	3646549	et	4	main
tuhandeid	doc_767882159212_item	3646548	et	3	main
tantsivad	doc_767882159212_item	3646547	et	4	main
ja	doc_767882159212_item	3646546	et	3	main
laulavad	doc_767882159212_item	3646545	et	4	main
rahvariietes	doc_767882159212_item	3646544	et	3	main
seal	doc_767882159212_item	3646543	et	4	main
järel	doc_767882159212_item	3646542	et	4	main
aasta	doc_767882159212_item	3646541	et	4	main
viie	doc_767882159212_item	3646540	et	3	main
toimub	doc_767882159212_item	3646538	et	3	main
iga	doc_767882159212_item	3646539	et	4	main
tantsupidu	doc_767882159212_item	3646537	et	4	main
ja	doc_767882159212_item	3646536	et	3	main
eestlastel	doc_767882159212_item	3646534	et	4	main
näidetega	doc_767882159212_item	3646533	et	3	main
illustreerida	doc_767882159212_item	3646532	et	3	main
analüüsiv	doc_767882159212_item	3646520	et	4	main
arutlev	doc_767882159212_item	3646519	et	4	main
sõna	doc_767882159212_item	3646515	et	4	main
essee	doc_767882159212_item	3646511	et	4	main
teeb	doc_767882159212_item	3646508	et	3	main
teemal	doc_767882159212_item	3646506	et	3	main
essee	doc_767882159212_item	3646505	et	4	main
kirjutage	doc_767882159212_item	3646504	et	3	main
kui	doc_767882159212_item	3646499	et	3	main
tantsupeod	doc_767882159212_item	3646793	et	4	main
laulu	doc_767882159212_item	3646791	et	4	main
kaasa	doc_767882159212_item	3646788	et	4	main
saanud	doc_767882159212_item	3646778	et	4	main
on	doc_767882159212_item	3646777	et	4	main
alikas	doc_767882159212_item	3646771	et	4	main
laulurahva	doc_767882159212_item	3646765	et	3	main
eestlastest	doc_767882159212_item	3646764	et	4	main
minu	doc_767882159212_item	3646761	et	3	main
kõige	doc_767882159212_item	3646759	et	4	main
rahulik	doc_767882159212_item	3646758	et	3	main
rohkem	doc_767882159212_item	3646757	et	4	main
on	doc_767882159212_item	3646756	et	4	main
ma	doc_767882159212_item	3646751	et	3	main
lõbusait	doc_767882159212_item	3646748	et	3	main
muidugi	doc_767882159212_item	3646735	et	4	main
teeb	doc_767882159212_item	3646728	et	3	main
neid	doc_767882159212_item	3646729	et	4	main
muusika	doc_767882159212_item	3646727	et	4	main
meestega	doc_767882159212_item	3646720	et	4	main
muusikat	doc_767882159212_item	3646704	et	3	main
kirjutama	doc_767882159212_item	3646703	et	3	main
hakkavad	doc_767882159212_item	3646702	et	4	main
inimestele	doc_767882159212_item	3646697	et	3	main
loodus	doc_767882159212_item	3646695	et	4	main
laul	doc_767882159237_item	3647099	et	4	main
elama	doc_767882159237_item	3647094	et	3	main
arvan	doc_767882159237_item	3647090	et	3	main
on	doc_767882159237_item	3647088	et	4	main
eesti	doc_767882159237_item	3647076	et	4	main
laulus	doc_767882159237_item	3647074	et	3	main
laule	doc_767882159237_item	3647062	et	4	main
kõnelevad	doc_767882159237_item	3647058	et	4	main
rock-festival	doc_767882159237_item	3647056	et	3	main
kus	doc_767882159237_item	3647043	et	3	main
populaarne	doc_767882159237_item	3647038	et	3	main
on	doc_767882159237_item	3647036	et	4	main
korraldavad	doc_767882159237_item	3647034	et	4	main
ansamblid	doc_767882159237_item	3647033	et	3	main
heliloojad	doc_767882159237_item	3647032	et	3	main
uued	doc_767882159237_item	3647031	et	3	main
tulevad	doc_767882159237_item	3647030	et	4	main
ärkamisaeg	doc_767882159237_item	3647029	et	3	main
rahvus	doc_767882159237_item	3647028	et	3	main
eestis	doc_767882159237_item	3647027	et	3	main
instrumendid	doc_767882159237_item	3647020	et	3	main
rahvalaulu	doc_767882159237_item	3647012	et	4	main
sajandi	doc_767882159237_item	3647011	et	3	main
tutvustumine	doc_767882159237_item	3647008	et	4	main
laulu	doc_767882159237_item	3647001	et	4	main
esinevad	doc_767882159237_item	3646995	et	4	main
laulmine	doc_767882159237_item	3646980	et	4	main
et	doc_767882159237_item	3646976	et	3	main
alati	doc_767882159237_item	3646962	et	4	main
rohkem	doc_767882159212_item	3646760	et	4	main
rahvamuusika	doc_767882159212_item	3646755	et	4	main
arvan	doc_767882159212_item	3646752	et	3	main
on	doc_767882159212_item	3646738	et	4	main
paeva	doc_767882159212_item	3646733	et	4	main
pärast	doc_767882159212_item	3646731	et	4	main
rahulikum	doc_767882159212_item	3646730	et	4	main
koos	doc_767882159212_item	3646718	et	4	main
naised	doc_767882159212_item	3646717	et	3	main
võib	doc_767882159212_item	3646713	et	3	main
alati	doc_767882159212_item	3646711	et	4	main
nad	doc_767882159212_item	3646701	et	3	main
ning	doc_767882159212_item	3646700	et	3	main
positiivselt	doc_767882159212_item	3646699	et	4	main
väga	doc_767882159212_item	3646698	et	3	main
on	doc_767882159212_item	3646683	et	4	main
ümber	doc_767882159212_item	3646682	et	3	main
nende	doc_767882159212_item	3646681	et	4	main
kukk	doc_767882159212_item	3646678	et	3	main
laulu	doc_767882159212_item	3646677	et	4	main
oma	doc_767882159212_item	3646676	et	4	main
laulab	doc_767882159212_item	3646675	et	3	main
kuidas	doc_767882159212_item	3646674	et	3	main
kulavad	doc_767882159212_item	3646673	et	4	main
nad	doc_767882159212_item	3646672	et	3	main
hommikul	doc_767882159212_item	3646671	et	3	main
koguaeg	doc_767882159212_item	3646670	et	3	main
koos	doc_767882159212_item	3646669	et	4	main
loodusega	doc_767882159212_item	3646668	et	4	main
elavad	doc_767882159212_item	3646667	et	4	main
nad	doc_767882159212_item	3646666	et	3	main
sest	doc_767882159212_item	3646665	et	4	main
arvates	doc_767882159212_item	3646762	et	4	main
aga	doc_767882159212_item	3646750	et	3	main
laulu	doc_767882159212_item	3646749	et	4	main
laulavad	doc_767882159212_item	3646747	et	4	main
nad	doc_767882159212_item	3646746	et	3	main
pulm	doc_767882159212_item	3646744	et	3	main
mingi	doc_767882159212_item	3646739	et	4	main
töötamist	doc_767882159212_item	3646734	et	4	main
laulu	doc_767882159212_item	3646725	et	4	main
ainulaadsed	doc_767882159212_item	3646724	et	3	main
vaiksed	doc_767882159212_item	3646723	et	3	main
sellised	doc_767882159212_item	3646722	et	4	main
kuidas	doc_767882159212_item	3646716	et	3	main
mõjub	doc_767882159212_item	3646696	et	3	main
laulu	doc_767882159212_item	3646694	et	4	main
lindude	doc_767882159212_item	3646693	et	4	main
kuulavad	doc_767882159212_item	3646692	et	4	main
nad	doc_767882159212_item	3646691	et	3	main
magama	doc_767882159212_item	3646690	et	3	main
lähevad	doc_767882159212_item	3646689	et	3	main
inimesed	doc_767882159212_item	3646688	et	3	main
kui	doc_767882159212_item	3646687	et	3	main
ning	doc_767882159212_item	3646686	et	3	main
loomad	doc_767882159212_item	3646685	et	3	main
päeva	doc_767882159212_item	3646680	et	4	main
terve	doc_767882159212_item	3646679	et	4	main
rahva	doc_767882159237_item	3647098	et	3	main
eluosa	doc_767882159237_item	3647089	et	4	main
see	doc_767882159237_item	3647087	et	3	main
traditsioon	doc_767882159237_item	3647086	et	3	main
vana	doc_767882159237_item	3647085	et	4	main
ja	doc_767882159237_item	3647084	et	3	main
ajaloo	doc_767882159237_item	3647079	et	4	main
populaarsed	doc_767882159237_item	3647073	et	3	main
sest	doc_767882159237_item	3647063	et	4	main
korraldavad	doc_767882159237_item	3647052	et	4	main
eestis	doc_767882159237_item	3647051	et	3	main
nüüdaegsel	doc_767882159237_item	3647050	et	3	main
ja	doc_767882159237_item	3647049	et	3	main
rahvariided	doc_767882159237_item	3647048	et	3	main
tantsud	doc_767882159237_item	3647047	et	3	main
rahvalaulud	doc_767882159237_item	3647046	et	3	main
klarneet	doc_767882159237_item	3647021	et	4	main
on	doc_767882159237_item	3647004	et	4	main
lauludes	doc_767882159237_item	3647003	et	3	main
kaudu	doc_767882159237_item	3647002	et	3	main
sünnipäev	doc_767882159212_item	3646742	et	3	main
terve	doc_767882159212_item	3646732	et	4	main
seelline	doc_767882159212_item	3646726	et	4	main
õhtudel	doc_767882159212_item	3646714	et	4	main
looduse	doc_767882159212_item	3646709	et	4	main
lauludes	doc_767882159212_item	3646708	et	3	main
oma	doc_767882159212_item	3646707	et	4	main
peegeldavad	doc_767882159212_item	3646706	et	4	main
ja	doc_767882159212_item	3646705	et	3	main
erinevad	doc_767882159212_item	3646684	et	4	main
kõrvad	doc_767882159212_item	3646664	et	3	main
nagu	doc_767882159237_item	3647096	et	3	main
hakkab	doc_767882159237_item	3647093	et	3	main
et	doc_767882159237_item	3647091	et	3	main
kultuur	doc_767882159237_item	3647077	et	3	main
väga	doc_767882159237_item	3647072	et	3	main
aga	doc_767882159237_item	3647057	et	3	main
värska	doc_767882159237_item	3647055	et	4	main
laulupidu	doc_767882159237_item	3647042	et	4	main
festivali	doc_767882159237_item	3647035	et	4	main
bojaan	doc_767882159237_item	3647022	et	4	main
tulevad	doc_767882159237_item	3647018	et	4	main
uue	doc_767882159237_item	3647010	et	3	main
ja	doc_767882159237_item	3647007	et	3	main
eestlased	doc_767882159237_item	3646998	et	3	main
pärast	doc_767882159237_item	3646985	et	4	main
ja	doc_767882159237_item	3646984	et	3	main
hakkas	doc_767882159237_item	3646983	et	3	main
naine	doc_767882159237_item	3646982	et	3	main
üks	doc_767882159237_item	3646981	et	3	main
vanasti	doc_767882159237_item	3646977	et	3	main
vaheldusega	doc_767882159237_item	3646969	et	4	main
laulavad	doc_767882159237_item	3646968	et	4	main
ning	doc_767882159237_item	3646967	et	3	main
ja	doc_767882159237_item	3646961	et	3	main
laulavad	doc_767882159237_item	3646954	et	4	main
ja	doc_767882159237_item	3646952	et	3	main
on	doc_767882159237_item	3646945	et	4	main
rahvalaule	doc_767882159237_item	3646939	et	4	main
vokaalset	doc_767882159237_item	3646935	et	3	main
regilaulude	doc_767882159237_item	3646900	et	3	main
on	doc_767882159237_item	3646896	et	4	main
laulud	doc_767882159237_item	3646895	et	3	main
need	doc_767882159237_item	3646894	et	3	main
käsitööga	doc_767882159237_item	3646893	et	3	main
lapsega	doc_767882159237_item	3646892	et	3	main
tagasi	doc_767882159237_item	3646884	et	3	main
on	doc_767882159237_item	3646876	et	4	main
regilaul	doc_767882159237_item	3646875	et	4	main
rahvalaul	doc_767882159237_item	3646874	et	4	main
heelingud	doc_767882159212_item	3646710	et	4	main
alati	doc_767882159237_item	3647095	et	4	main
ta	doc_767882159237_item	3647092	et	4	main
üldlaulupidu	doc_767882159237_item	3647080	et	4	main
on	doc_767882159237_item	3647075	et	4	main
rahva	doc_767882159237_item	3647061	et	3	main
vana	doc_767882159237_item	3647060	et	4	main
nn	doc_767882159237_item	3647054	et	4	main
festivali	doc_767882159237_item	3647053	et	4	main
on	doc_767882159237_item	3647044	et	4	main
traditsioon	doc_767882159237_item	3647041	et	3	main
ja	doc_767882159237_item	3647039	et	3	main
väga	doc_767882159237_item	3647037	et	3	main
20	doc_767882159237_item	3647024	et	2	main
läti	doc_767882159237_item	3647017	et	4	main
venemaa	doc_767882159237_item	3647016	et	4	main
naabrid	doc_767882159237_item	3647015	et	3	main
riigi	doc_767882159237_item	3647014	et	3	main
mõjutasid	doc_767882159237_item	3647013	et	4	main
väljandavad	doc_767882159237_item	3646999	et	4	main
on	doc_767882159237_item	3646992	et	4	main
eestis	doc_767882159237_item	3646991	et	3	main
laulja	doc_767882159237_item	3646971	et	4	main
hakkab	doc_767882159237_item	3646970	et	3	main
palju	doc_767882159237_item	3646960	et	4	main
juba	doc_767882159237_item	3646956	et	3	main
tähtis	doc_767882159237_item	3646949	et	4	main
mitmekülgsed	doc_767882159237_item	3646946	et	3	main
laulud	doc_767882159237_item	3646944	et	3	main
rahvaluuletusi	doc_767882159237_item	3646942	et	4	main
tekisid	doc_767882159237_item	3646941	et	4	main
zanre	doc_767882159237_item	3646936	et	4	main
ilma	doc_767882159237_item	3646898	et	4	main
vookalsed	doc_767882159237_item	3646897	et	4	main
naisi	doc_767882159237_item	3646888	et	3	main
regilaulud	doc_767882159237_item	3646885	et	3	main
on	doc_767882159237_item	3646870	et	4	main
see	doc_767882159237_item	3646869	et	3	main
tants	doc_767882159237_item	3646863	et	3	main
ja	doc_767882159237_item	3646862	et	3	main
ajast	doc_767882159237_item	3646844	et	4	main
vanast	doc_767882159237_item	3646843	et	3	main
juba	doc_767882159237_item	3646842	et	3	main
eestis	doc_767882159237_item	3646837	et	3	main
näidetega	doc_767882159237_item	3646835	et	3	main
soovitatav	doc_767882159237_item	3646833	et	4	main
pikkus	doc_767882159237_item	3646814	et	4	main
eestlastest	doc_767882159237_item	3646811	et	4	main
teeb	doc_767882159237_item	3646810	et	3	main
mis	doc_767882159237_item	3646809	et	4	main
teemal	doc_767882159237_item	3646808	et	3	main
keele	doc_767882159237_item	3646803	et	4	main
teise	doc_767882159237_item	3646802	et	4	main
kui	doc_767882159237_item	3646801	et	3	main
keele	doc_767882159237_item	3646800	et	4	main
palju	doc_767882159237_item	3646934	et	4	main
laulud	doc_767882159237_item	3646925	et	3	main
riimiline	doc_767882159237_item	3646916	et	4	main
tekis	doc_767882159237_item	3646915	et	3	main
19	doc_767882159237_item	3646913	et	2	main
maie	doc_767882159237_item	3646907	et	4	main
neie	doc_767882159237_item	3646903	et	4	main
et	doc_767882159237_item	3646902	et	3	main
luab	doc_901133458144_item	3647153	et	4	main
tarkus	doc_901133458144_item	3647147	et	4	main
palju	doc_901133458144_item	3647133	et	4	main
annab	doc_901133458144_item	3647132	et	3	main
ja	doc_901133458144_item	3647111	et	3	main
väga	doc_901133458144_item	3647104	et	3	main
rikkad	doc_986203247099_item	3647239	et	4	main
maailmas	doc_986203247099_item	3647236	et	3	main
eraldi	doc_986203247099_item	3647235	et	4	main
käivad	doc_986203247099_item	3647234	et	4	main
käivad	doc_986203247099_item	3647228	et	4	main
et	doc_986203247099_item	3647222	et	3	main
kasti	doc_986203247099_item	3647200	et	4	main
koos	doc_986203247099_item	3647197	et	4	main
väide	doc_986203247099_item	3647190	et	4	main
sest	doc_986203247099_item	3647184	et	4	main
koolil	doc_986203247099_item	3647179	et	4	main
eesti	doc_767882159237_item	3647097	et	4	main
hea	doc_767882159237_item	3647083	et	4	main
väga	doc_767882159237_item	3647082	et	3	main
on	doc_767882159237_item	3647081	et	4	main
ja	doc_767882159237_item	3647078	et	3	main
on	doc_767882159237_item	3647071	et	4	main
nad	doc_767882159237_item	3647070	et	3	main
rahvatantsud	doc_767882159237_item	3647069	et	3	main
laulud	doc_767882159237_item	3647068	et	3	main
sõnadega	doc_767882159237_item	3647067	et	3	main
seotud	doc_767882159237_item	3647066	et	4	main
on	doc_767882159237_item	3647065	et	4	main
eestlased	doc_767882159237_item	3647064	et	3	main
setulaule	doc_767882159237_item	3647059	et	4	main
esitatud	doc_767882159237_item	3647045	et	4	main
juba	doc_767882159237_item	3647040	et	3	main
on	doc_767882159237_item	3647026	et	4	main
sajandil	doc_767882159237_item	3647025	et	3	main
19	doc_767882159237_item	3647023	et	2	main
uued	doc_767882159237_item	3647019	et	3	main
eestlastega	doc_767882159237_item	3647009	et	4	main
ajaloo	doc_767882159237_item	3647006	et	4	main
eesti	doc_767882159237_item	3647005	et	4	main
enast	doc_767882159237_item	3647000	et	4	main
koor	doc_767882159237_item	3646996	et	4	main
populaarne	doc_767882159237_item	3646993	et	3	main
pärast	doc_767882159237_item	3646990	et	4	main
koor	doc_767882159237_item	3646973	et	4	main
ja	doc_767882159237_item	3646972	et	3	main
koor	doc_767882159237_item	3646964	et	4	main
esineb	doc_767882159237_item	3646963	et	3	main
laulavad	doc_767882159237_item	3646959	et	4	main
eestlased	doc_767882159237_item	3646955	et	3	main
miks	doc_767882159237_item	3646951	et	4	main
mis	doc_767882159237_item	3646940	et	4	main
tegelesid	doc_767882159237_item	3646891	et	4	main
kui	doc_767882159237_item	3646890	et	3	main
aastat	doc_767882159237_item	3646883	et	3	main
kujunenud	doc_767882159237_item	3646881	et	4	main
jagatakse	doc_767882159237_item	3646865	et	3	main
pillimäng	doc_767882159237_item	3646861	et	3	main
laul	doc_767882159237_item	3646860	et	4	main
osaks	doc_767882159237_item	3646859	et	3	main
3	doc_767882159237_item	3646858	et	2	main
jagunud	doc_767882159237_item	3646857	et	4	main
eesti	doc_767882159237_item	3646854	et	4	main
kultuurinähtus	doc_767882159237_item	3646839	et	4	main
üldistav	doc_767882159237_item	3646824	et	4	main
ja	doc_767882159237_item	3646823	et	3	main
essee	doc_767882159237_item	3646818	et	4	main
sõna	doc_767882159237_item	3646817	et	4	main
kirjutamine	doc_767882159237_item	3646805	et	4	main
essee	doc_767882159237_item	3646798	et	4	main
juba	doc_767882159237_item	3646926	et	3	main
sõnad	doc_767882159237_item	3646921	et	4	main
paar	doc_767882159237_item	3646920	et	3	main
on	doc_767882159237_item	3646919	et	4	main
sama	doc_767882159237_item	3646911	et	4	main
sõnad	doc_767882159237_item	3646909	et	4	main
või	doc_767882159237_item	3646908	et	4	main
lõpus	doc_767882159237_item	3646905	et	4	main
lapsi	doc_901133458144_item	3647154	et	4	main
tähtis	doc_901133458144_item	3647150	et	4	main
oma	doc_901133458144_item	3647144	et	4	main
võimalus	doc_901133458144_item	3647143	et	3	main
annab	doc_901133458144_item	3647142	et	3	main
ta	doc_901133458144_item	3647141	et	4	main
mulle	doc_901133458144_item	3647114	et	4	main
annavad	doc_901133458144_item	3647113	et	3	main
nad	doc_901133458144_item	3647112	et	3	main
on	doc_901133458144_item	3647107	et	4	main
lauljaga	doc_767882159237_item	3646997	et	4	main
kui	doc_767882159237_item	3646994	et	3	main
selle	doc_767882159237_item	3646989	et	4	main
olla	doc_767882159237_item	3646988	et	3	main
võib	doc_767882159237_item	3646987	et	3	main
teised	doc_767882159237_item	3646986	et	4	main
spontaalne	doc_767882159237_item	3646979	et	4	main
oli	doc_767882159237_item	3646978	et	3	main
huvitav	doc_767882159237_item	3646975	et	4	main
pärast	doc_767882159237_item	3646974	et	4	main
laulja	doc_767882159237_item	3646966	et	4	main
ja	doc_767882159237_item	3646965	et	3	main
ajast	doc_767882159237_item	3646958	et	4	main
milleks	doc_767882159237_item	3646953	et	4	main
alati	doc_767882159237_item	3646948	et	4	main
järgi	doc_767882159237_item	3646943	et	4	main
mitte	doc_767882159237_item	3646937	et	3	main
näiteks	doc_767882159237_item	3646889	et	4	main
rohkem	doc_767882159237_item	3646887	et	4	main
lauldi	doc_767882159237_item	3646886	et	3	main
tuhat	doc_767882159237_item	3646882	et	4	main
on	doc_767882159237_item	3646880	et	4	main
mis	doc_767882159237_item	3646879	et	4	main
vanim	doc_767882159237_item	3646878	et	3	main
rimiline	doc_767882159237_item	3646873	et	4	main
ja	doc_767882159237_item	3646872	et	3	main
grupiks	doc_767882159237_item	3646868	et	3	main
kaheks	doc_767882159237_item	3646867	et	4	main
ka	doc_767882159237_item	3646866	et	3	main
laulmine	doc_767882159237_item	3646847	et	4	main
seni	doc_767882159237_item	3646846	et	3	main
ja	doc_767882159237_item	3646845	et	3	main
on	doc_767882159237_item	3646832	et	4	main
väiteid	doc_767882159237_item	3646831	et	4	main
faktidele	doc_767882159237_item	3646830	et	3	main
arutlev	doc_767882159237_item	3646821	et	4	main
300	doc_767882159237_item	3646815	et	2	main
laulurahva	doc_767882159237_item	3646812	et	3	main
arhiivis	doc_767882159237_item	3646932	et	3	main
kui	doc_767882159237_item	3646930	et	3	main
muusikaga	doc_767882159237_item	3646928	et	3	main
tähega	doc_767882159237_item	3646912	et	3	main
kasvatama	doc_901133458144_item	3647155	et	4	main
tulevikus	doc_901133458144_item	3647135	et	4	main
võimaluse	doc_901133458144_item	3647134	et	3	main
vaja	doc_901133458144_item	3647108	et	4	main
inimesed	doc_986203247099_item	3647242	et	3	main
ühiskonnas	doc_986203247099_item	3647237	et	4	main
tarkus	doc_986203247099_item	3647233	et	4	main
ja	doc_986203247099_item	3647232	et	3	main
tarkus	doc_986203247099_item	3647227	et	4	main
ja	doc_986203247099_item	3647226	et	3	main
on	doc_986203247099_item	3647205	et	4	main
tarkus	doc_986203247099_item	3647194	et	4	main
ja	doc_986203247099_item	3647193	et	3	main
kaasa	doc_986203247099_item	3647187	et	4	main
aitab	doc_986203247099_item	3647186	et	3	main
see	doc_986203247099_item	3647185	et	3	main
oma	doc_986203247099_item	3647182	et	4	main
ja	doc_986203247099_item	3647174	et	3	main
esitage	doc_986203247099_item	3647172	et	3	main
neist	doc_986203247099_item	3647161	et	4	main
väiteid	doc_986203247099_item	3647159	et	4	main
arvamus	doc_986203247099_item	3647157	et	3	main
ja	doc_986203247099_item	3647338	et	3	main
väga	doc_986203247099_item	3647334	et	3	main
aga	doc_986203247099_item	3647331	et	3	main
olen	doc_986203247099_item	3647329	et	3	main
ma	doc_986203247099_item	3647328	et	3	main
siis	doc_986203247099_item	3647327	et	3	main
mõistust	doc_986203247099_item	3647326	et	4	main
karjääri	doc_986203247099_item	3647311	et	4	main
teevad	doc_986203247099_item	3647310	et	3	main
võimalus	doc_986203247099_item	3647298	et	3	main
on	doc_986203247099_item	3647297	et	4	main
siis	doc_986203247099_item	3647296	et	3	main
õppida	doc_986203247099_item	3647280	et	3	main
vanast	doc_767882159237_item	3646957	et	3	main
kellele	doc_767882159237_item	3646950	et	4	main
oli	doc_767882159237_item	3646947	et	3	main
ainult	doc_767882159237_item	3646938	et	4	main
erinevus	doc_767882159237_item	3646901	et	4	main
muusikata	doc_767882159237_item	3646899	et	3	main
eesti	doc_767882159237_item	3646877	et	4	main
regilaul	doc_767882159237_item	3646871	et	4	main
laul	doc_767882159237_item	3646864	et	4	main
folkloor	doc_767882159237_item	3646855	et	4	main
laulsid	doc_767882159237_item	3646841	et	4	main
eestlased	doc_767882159237_item	3646840	et	3	main
esitatud	doc_767882159237_item	3646829	et	4	main
lugemistekstis	doc_767882159237_item	3646828	et	3	main
ja	doc_767882159237_item	3646827	et	3	main
loengus	doc_767882159237_item	3646826	et	3	main
tuginema	doc_767882159237_item	3646825	et	3	main
350	doc_767882159237_item	3646816	et	2	main
essee	doc_767882159237_item	3646813	et	4	main
test	doc_767882159237_item	3646804	et	3	main
on	doc_767882159237_item	3646933	et	4	main
vaadata	doc_767882159237_item	3646931	et	4	main
eestis	doc_767882159237_item	3646929	et	3	main
lauldi	doc_767882159237_item	3646927	et	3	main
mind	doc_767882159237_item	3646923	et	4	main
sajandil	doc_767882159237_item	3646914	et	3	main
algavad	doc_767882159237_item	3646910	et	4	main
on	doc_767882159237_item	3646906	et	4	main
ta	doc_901133458144_item	3647152	et	4	main
on	doc_901133458144_item	3647148	et	4	main
muutuma	doc_901133458144_item	3647146	et	4	main
elu	doc_901133458144_item	3647145	et	4	main
väga	doc_901133458144_item	3647138	et	3	main
on	doc_901133458144_item	3647137	et	4	main
saatus	doc_901133458144_item	3647136	et	3	main
ta	doc_901133458144_item	3647131	et	4	main
sest	doc_901133458144_item	3647130	et	4	main
tähtis	doc_901133458144_item	3647129	et	4	main
väga	doc_901133458144_item	3647128	et	3	main
on	doc_901133458144_item	3647127	et	4	main
sünnikoht	doc_901133458144_item	3647126	et	3	main
nendega	doc_901133458144_item	3647125	et	4	main
ajal	doc_901133458144_item	3647124	et	4	main
vabal	doc_901133458144_item	3647123	et	3	main
puhkan	doc_901133458144_item	3647122	et	3	main
ma	doc_901133458144_item	3647121	et	3	main
sest	doc_901133458144_item	3647120	et	4	main
tähtsad	doc_901133458144_item	3647119	et	3	main
väga	doc_901133458144_item	3647118	et	3	main
on	doc_901133458144_item	3647117	et	4	main
sõbrad	doc_901133458144_item	3647116	et	3	main
on	doc_767882159237_item	3646856	et	4	main
rahvuline	doc_767882159237_item	3646853	et	4	main
ning	doc_767882159237_item	3646852	et	3	main
populaarne	doc_767882159237_item	3646851	et	3	main
väga	doc_767882159237_item	3646850	et	3	main
eestis	doc_767882159237_item	3646849	et	3	main
on	doc_767882159237_item	3646848	et	4	main
on	doc_767882159237_item	3646838	et	4	main
laulmine	doc_767882159237_item	3646836	et	4	main
illustreerida	doc_767882159237_item	3646834	et	3	main
analüüsiv	doc_767882159237_item	3646822	et	4	main
olema	doc_767882159237_item	3646820	et	4	main
peab	doc_767882159237_item	3646819	et	4	main
essee	doc_767882159237_item	3646807	et	4	main
kirjutage	doc_767882159237_item	3646806	et	3	main
eesti	doc_767882159237_item	3646799	et	4	main
need	doc_767882159237_item	3646924	et	3	main
sind	doc_767882159237_item	3646922	et	4	main
laulul	doc_767882159237_item	3646918	et	3	main
rahvalaul	doc_767882159237_item	3646917	et	4	main
rea	doc_767882159237_item	3646904	et	3	main
sest	doc_901133458144_item	3647151	et	4	main
väga	doc_901133458144_item	3647149	et	3	main
sest	doc_901133458144_item	3647140	et	4	main
tähtis	doc_901133458144_item	3647139	et	4	main
kõikile	doc_901133458144_item	3647115	et	4	main
nendele	doc_901133458144_item	3647110	et	4	main
aidata	doc_901133458144_item	3647109	et	4	main
sest	doc_901133458144_item	3647106	et	4	main
on	doc_901133458144_item	3647103	et	4	main
essee	doc_901133458144_item	3647101	et	4	main
inimesed	doc_986203247099_item	3647240	et	3	main
rikkus	doc_986203247099_item	3647231	et	4	main
harilikult	doc_986203247099_item	3647230	et	4	main
koos	doc_986203247099_item	3647229	et	4	main
alati	doc_986203247099_item	3647224	et	4	main
u	doc_986203247099_item	3647206	et	4	main
nõutav	doc_986203247099_item	3647203	et	4	main
teksti	doc_986203247099_item	3647202	et	4	main
kirjutage	doc_986203247099_item	3647198	et	3	main
tekkimisele	doc_986203247099_item	3647189	et	4	main
koolivorm	doc_986203247099_item	3647183	et	3	main
olema	doc_986203247099_item	3647181	et	4	main
üks	doc_986203247099_item	3647162	et	3	main
tähtsad	doc_901133458144_item	3647105	et	3	main
vanemad	doc_901133458144_item	3647102	et	4	main
on	doc_986203247099_item	3647238	et	4	main
sisse	doc_986203247099_item	3647201	et	4	main
rikkus	doc_986203247099_item	3647192	et	4	main
2	doc_986203247099_item	3647191	et	2	main
peaks	doc_986203247099_item	3647180	et	4	main
igal	doc_986203247099_item	3647178	et	3	main
väide	doc_986203247099_item	3647176	et	4	main
poolt-	doc_986203247099_item	3647173	et	4	main
mitte	doc_986203247099_item	3647171	et	3	main
või	doc_986203247099_item	3647170	et	4	main
tavaliselt	doc_986203247099_item	3647336	et	4	main
rikkaks	doc_986203247099_item	3647324	et	4	main
olen	doc_986203247099_item	3647317	et	3	main
kõrgetasuline	doc_986203247099_item	3647314	et	4	main
saavad	doc_986203247099_item	3647313	et	4	main
siis	doc_986203247099_item	3647312	et	3	main
targed	doc_986203247099_item	3647306	et	3	main
raha	doc_986203247099_item	3647295	et	4	main
nad	doc_986203247099_item	3647282	et	3	main
nad	doc_986203247099_item	3647278	et	3	main
võivad	doc_986203247099_item	3647275	et	4	main
inimestel	doc_986203247111_item	3647581	et	3	main
kõikidel	doc_986203247111_item	3647580	et	4	main
oleks	doc_986203247111_item	3647579	et	3	main
koos	doc_986203247111_item	3647573	et	4	main
tarkus	doc_986203247111_item	3647571	et	4	main
rikkus	doc_986203247111_item	3647569	et	4	main
kellel	doc_986203247111_item	3647568	et	4	main
inimesi	doc_986203247111_item	3647567	et	4	main
kuskil	doc_986203247111_item	3647554	et	3	main
töö	doc_986203247111_item	3647550	et	4	main
ta	doc_986203247111_item	3647547	et	4	main
kellel	doc_986203247111_item	3647543	et	4	main
ja	doc_986203247111_item	3647540	et	3	main
saada	doc_986203247111_item	3647533	et	4	main
ja	doc_986203247111_item	3647532	et	3	main
ei	doc_986203247111_item	3647520	et	4	main
teadmisegaja	doc_986203247111_item	3647513	et	4	main
ainult	doc_986203247111_item	3647512	et	4	main
valdab	doc_986203247111_item	3647511	et	3	main
on	doc_986203247111_item	3647508	et	4	main
minna	doc_986203247111_item	3647501	et	3	main
ole	doc_986203247111_item	3647498	et	4	main
ei	doc_986203247111_item	3647497	et	4	main
ja	doc_986203247111_item	3647496	et	3	main
kõrgharidus	doc_986203247111_item	3647491	et	3	main
on	doc_986203247111_item	3647490	et	4	main
nendel	doc_986203247111_item	3647489	et	4	main
õppisid	doc_986203247111_item	3647488	et	4	main
palju	doc_986203247111_item	3647484	et	4	main
ole	doc_986203247111_item	3647475	et	4	main
mida	doc_986203247111_item	3647466	et	4	main
tea	doc_986203247111_item	3647465	et	4	main
raha	doc_986203247111_item	3647461	et	4	main
palju	doc_986203247111_item	3647460	et	4	main
palju	doc_986203247111_item	3647453	et	4	main
nad	doc_986203247111_item	3647452	et	3	main
ja	doc_986203247111_item	3647451	et	3	main
töö	doc_986203247111_item	3647450	et	4	main
hea	doc_986203247111_item	3647449	et	4	main
töötada	doc_986203247111_item	3647443	et	3	main
saavad	doc_986203247111_item	3647436	et	4	main
paljud	doc_986203247111_item	3647435	et	3	main
erinevalt	doc_986203247111_item	3647434	et	4	main
ei	doc_986203247111_item	3647428	et	4	main
ja	doc_986203247111_item	3647426	et	3	main
alati	doc_986203247111_item	3647410	et	4	main
tarkus	doc_986203247111_item	3647408	et	4	main
üldselt	doc_574559240058_item	3647664	et	4	main
ma	doc_574559240058_item	3647655	et	3	main
olid	doc_574559240058_item	3647652	et	4	main
et	doc_574559240058_item	3647650	et	3	main
vöib	doc_574559240058_item	3647648	et	4	main
valo	doc_574559240058_item	3647627	et	4	main
nimega	doc_574559240058_item	3647626	et	3	main
pesupulbrit	doc_574559240058_item	3647625	et	3	main
ulatus	doc_574559240058_item	3647619	et	4	main
säär	doc_574559240058_item	3647614	et	3	main
sukka	doc_574559240058_item	3647612	et	4	main
lubas	doc_574559240058_item	3647598	et	3	main
targed	doc_986203247099_item	3647352	et	3	main
on	doc_986203247099_item	3647351	et	4	main
nendest	doc_986203247099_item	3647350	et	4	main
inimesed	doc_986203247099_item	3647349	et	3	main
kõik	doc_986203247099_item	3647348	et	4	main
mitte	doc_986203247099_item	3647347	et	3	main
aga	doc_986203247099_item	3647346	et	3	main
inimesed	doc_986203247099_item	3647345	et	3	main
rikkad	doc_986203247099_item	3647344	et	4	main
palju	doc_986203247099_item	3647343	et	4	main
praegu	doc_986203247099_item	3647342	et	3	main
eraldi	doc_986203247099_item	3647341	et	4	main
käivad	doc_986203247099_item	3647340	et	4	main
tarkus	doc_986203247099_item	3647339	et	4	main
targed	doc_986203247099_item	3647241	et	3	main
rikkus	doc_986203247099_item	3647225	et	4	main
mitte	doc_986203247099_item	3647223	et	3	main
sellepärast	doc_986203247099_item	3647221	et	3	main
nõus	doc_986203247099_item	3647220	et	4	main
ole	doc_986203247099_item	3647219	et	4	main
ei	doc_986203247099_item	3647218	et	4	main
ma	doc_986203247099_item	3647217	et	3	main
kinnitusega	doc_986203247099_item	3647216	et	4	main
sellega	doc_986203247099_item	3647215	et	3	main
koos	doc_986203247099_item	3647214	et	4	main
alati	doc_986203247099_item	3647213	et	4	main
käivad	doc_986203247099_item	3647212	et	4	main
tarkus	doc_986203247099_item	3647211	et	4	main
ja	doc_986203247099_item	3647210	et	3	main
rikkus	doc_986203247099_item	3647209	et	4	main
sõna	doc_986203247099_item	3647208	et	4	main
160	doc_986203247099_item	3647207	et	2	main
pikkus	doc_986203247099_item	3647204	et	4	main
joonitud	doc_986203247099_item	3647199	et	4	main
alati	doc_986203247099_item	3647196	et	4	main
käivad	doc_986203247099_item	3647195	et	4	main
omakoolitunde	doc_986203247099_item	3647188	et	4	main
nõus	doc_986203247099_item	3647169	et	4	main
väitega	doc_986203247099_item	3647168	et	3	main
valige	doc_986203247099_item	3647160	et	3	main
lugege	doc_986203247099_item	3647158	et	3	main
läbi	doc_986203247099_item	3647325	et	4	main
nõus	doc_986203247099_item	3647318	et	4	main
sellepärast	doc_986203247099_item	3647307	et	3	main
ka	doc_986203247099_item	3647305	et	3	main
võivad	doc_986203247099_item	3647303	et	4	main
rikkad	doc_986203247099_item	3647301	et	4	main
kõrgharidus	doc_986203247099_item	3647300	et	3	main
saada	doc_986203247099_item	3647299	et	4	main
siin	doc_986203247099_item	3647291	et	4	main
õppida	doc_986203247099_item	3647290	et	3	main
võivad	doc_986203247099_item	3647289	et	4	main
nad	doc_986203247099_item	3647288	et	3	main
eestis	doc_986203247099_item	3647287	et	3	main
töötada	doc_986203247099_item	3647286	et	3	main
kutseid	doc_986203247099_item	3647285	et	3	main
igasuguseid	doc_986203247099_item	3647284	et	3	main
saavad	doc_986203247099_item	3647283	et	4	main
lugu	doc_986203247111_item	3647584	et	4	main
et	doc_986203247111_item	3647578	et	3	main
rõõmus	doc_986203247111_item	3647577	et	4	main
väga	doc_986203247111_item	3647576	et	3	main
on	doc_986203247111_item	3647565	et	4	main
vähe	doc_986203247111_item	3647564	et	3	main
kasutada	doc_986203247111_item	3647556	et	3	main
ei	doc_986203247111_item	3647552	et	4	main
tundub	doc_986203247111_item	3647548	et	3	main
raha	doc_986203247111_item	3647535	et	4	main
praegu	doc_986203247111_item	3647524	et	3	main
eesti	doc_986203247111_item	3647522	et	4	main
oska	doc_986203247111_item	3647521	et	4	main
ole	doc_986203247111_item	3647516	et	4	main
ei	doc_986203247111_item	3647515	et	4	main
nendele	doc_986203247111_item	3647509	et	4	main
muidugi	doc_986203247111_item	3647506	et	4	main
et	doc_986203247111_item	3647500	et	3	main
ma	doc_986203247111_item	3647482	et	3	main
on	doc_986203247111_item	3647480	et	4	main
nendel	doc_986203247111_item	3647473	et	4	main
ja	doc_986203247111_item	3647462	et	3	main
andekad	doc_986203247111_item	3647444	et	3	main
ole	doc_986203247111_item	3647429	et	4	main
targad	doc_986203247111_item	3647423	et	3	main
on	doc_986203247111_item	3647421	et	4	main
paljud	doc_986203247111_item	3647419	et	3	main
nõus	doc_986203247111_item	3647417	et	4	main
selle	doc_986203247111_item	3647415	et	4	main
neist	doc_986203247111_item	3647358	et	4	main
valige	doc_986203247111_item	3647357	et	3	main
reklaamid	doc_574559240058_item	3647663	et	4	main
et	doc_574559240058_item	3647662	et	3	main
niigi	doc_574559240058_item	3647661	et	4	main
ehk	doc_574559240058_item	3647660	et	3	main
oli	doc_574559240058_item	3647659	et	3	main
keda	doc_574559240058_item	3647654	et	4	main
valgus	doc_574559240058_item	3647629	et	4	main
valgus	doc_574559240058_item	3647628	et	4	main
värv	doc_574559240058_item	3647600	et	3	main
kes	doc_574559240058_item	3647597	et	4	main
huulepulga	doc_574559240058_item	3647595	et	3	main
ponds	doc_574559240058_item	3647594	et	4	main
oli	doc_574559240058_item	3647593	et	3	main
aastalt	doc_574559240058_item	3647591	et	3	main
reklaamid	doc_574559240058_item	3647589	et	4	main
mäletan	doc_574559240058_item	3647587	et	3	main
arvamus	doc_574559240058_item	3647586	et	3	main
tee	doc_609075653183_item	3647843	et	4	main
oma	doc_609075653183_item	3647828	et	4	main
füüsika	doc_609075653183_item	3647815	et	4	main
palju	doc_609075653183_item	3647808	et	4	main
on	doc_609075653183_item	3647801	et	4	main
miks	doc_609075653183_item	3647785	et	4	main
õppida	doc_609075653183_item	3647784	et	3	main
1	doc_986203247099_item	3647177	et	2	main
vastuargumente	doc_986203247099_item	3647175	et	3	main
selle	doc_986203247099_item	3647167	et	4	main
olete	doc_986203247099_item	3647166	et	3	main
kas	doc_986203247099_item	3647165	et	3	main
kirjutage	doc_986203247099_item	3647164	et	3	main
ning	doc_986203247099_item	3647163	et	3	main
harva	doc_986203247099_item	3647335	et	4	main
on	doc_986203247099_item	3647333	et	4	main
saavad	doc_986203247099_item	3647323	et	4	main
inimesed	doc_986203247099_item	3647322	et	3	main
ma	doc_986203247099_item	3647316	et	3	main
eriala	doc_986203247099_item	3647315	et	4	main
et	doc_986203247099_item	3647308	et	3	main
olla	doc_986203247099_item	3647304	et	3	main
on	doc_986203247099_item	3647294	et	4	main
kui	doc_986203247099_item	3647293	et	3	main
eestis	doc_986203247099_item	3647292	et	3	main
välismaal	doc_986203247099_item	3647281	et	4	main
igasuguseid	doc_986203247099_item	3647276	et	3	main
nad	doc_986203247099_item	3647274	et	3	main
oleksin	doc_986203247111_item	3647575	et	3	main
ja	doc_986203247111_item	3647570	et	3	main
väga	doc_986203247111_item	3647563	et	3	main
leida	doc_986203247111_item	3647561	et	3	main
rakendada	doc_986203247111_item	3647555	et	3	main
saa	doc_986203247111_item	3647553	et	4	main
haridus	doc_986203247111_item	3647546	et	3	main
on	doc_986203247111_item	3647544	et	4	main
töötus	doc_986203247111_item	3647539	et	4	main
töö	doc_986203247111_item	3647531	et	4	main
on	doc_986203247111_item	3647525	et	4	main
ta	doc_986203247111_item	3647519	et	4	main
ja	doc_986203247111_item	3647518	et	3	main
praktikat	doc_986203247111_item	3647517	et	3	main
edasi	doc_986203247111_item	3647504	et	3	main
ja	doc_986203247111_item	3647502	et	3	main
raha	doc_986203247111_item	3647499	et	4	main
ole	doc_986203247111_item	3647495	et	4	main
tean	doc_986203247111_item	3647483	et	3	main
on	doc_986203247111_item	3647471	et	4	main
inimesed	doc_986203247111_item	3647470	et	3	main
need	doc_986203247111_item	3647469	et	3	main
teha	doc_986203247111_item	3647468	et	3	main
nad	doc_986203247111_item	3647463	et	3	main
on	doc_986203247111_item	3647459	et	4	main
inimesed	doc_986203247111_item	3647445	et	3	main
vaja	doc_986203247111_item	3647441	et	4	main
on	doc_986203247111_item	3647440	et	4	main
saavad	doc_986203247111_item	3647432	et	4	main
inimesed	doc_986203247111_item	3647431	et	3	main
otstarbekad	doc_986203247111_item	3647425	et	3	main
väga	doc_986203247111_item	3647422	et	3	main
sest	doc_986203247111_item	3647418	et	4	main
väitega	doc_986203247111_item	3647416	et	3	main
koos	doc_986203247111_item	3647411	et	4	main
selle	doc_986203247111_item	3647364	et	4	main
olete	doc_986203247111_item	3647363	et	3	main
kas	doc_986203247111_item	3647362	et	3	main
kirjutage	doc_986203247111_item	3647361	et	3	main
ning	doc_986203247111_item	3647360	et	3	main
üks	doc_986203247111_item	3647359	et	3	main
arvamus	doc_986203247111_item	3647354	et	3	main
rikkus	doc_986203247099_item	3647337	et	4	main
see	doc_986203247099_item	3647332	et	3	main
nõus	doc_986203247099_item	3647330	et	4	main
kui	doc_986203247099_item	3647321	et	3	main
kinnitusega	doc_986203247099_item	3647320	et	4	main
sellega	doc_986203247099_item	3647319	et	3	main
inimesed	doc_986203247099_item	3647309	et	3	main
inimesed	doc_986203247099_item	3647302	et	3	main
võivad	doc_986203247099_item	3647279	et	4	main
võimalusi	doc_986203247099_item	3647277	et	3	main
ja	doc_986203247099_item	3647273	et	3	main
raha	doc_986203247099_item	3647272	et	4	main
omavad	doc_986203247099_item	3647271	et	4	main
inimesed	doc_986203247099_item	3647270	et	3	main
rikkad	doc_986203247099_item	3647269	et	4	main
ise	doc_986203247099_item	3647268	et	4	main
realiseerida	doc_986203247099_item	3647267	et	3	main
võimalusi	doc_986203247099_item	3647266	et	3	main
ei	doc_986203247099_item	3647264	et	4	main
ole	doc_986203247099_item	3647265	et	4	main
neil	doc_986203247099_item	3647263	et	4	main
palka	doc_986203247099_item	3647262	et	4	main
väike	doc_986203247099_item	3647261	et	4	main
kätte	doc_986203247099_item	3647260	et	4	main
saavad	doc_986203247099_item	3647259	et	4	main
tööt	doc_986203247099_item	3647258	et	4	main
musta	doc_986203247099_item	3647257	et	4	main
teevad	doc_986203247099_item	3647256	et	3	main
tehases	doc_986203247099_item	3647255	et	3	main
töötavad	doc_986203247099_item	3647254	et	4	main
inimesed	doc_986203247099_item	3647253	et	3	main
tavalised	doc_986203247099_item	3647252	et	4	main
inimesed	doc_986203247099_item	3647251	et	3	main
rikkad	doc_986203247099_item	3647250	et	4	main
ole	doc_986203247099_item	3647249	et	4	main
ei	doc_986203247099_item	3647248	et	4	main
alati	doc_986203247099_item	3647247	et	4	main
mitte	doc_986203247099_item	3647246	et	3	main
inimesed	doc_986203247099_item	3647245	et	3	main
targed	doc_986203247099_item	3647244	et	3	main
tavaliselt	doc_986203247099_item	3647243	et	4	main
ma	doc_986203247111_item	3647574	et	3	main
neid	doc_986203247111_item	3647566	et	4	main
ja	doc_986203247111_item	3647557	et	3	main
ja	doc_986203247111_item	3647551	et	3	main
kõrg	doc_986203247111_item	3647545	et	4	main
palju	doc_986203247111_item	3647534	et	4	main
raske	doc_986203247111_item	3647526	et	4	main
keelt	doc_986203247111_item	3647523	et	4	main
kes	doc_986203247111_item	3647510	et	4	main
raske	doc_986203247111_item	3647507	et	4	main
hea	doc_986203247111_item	3647583	et	4	main
niisugune	doc_986203247111_item	3647582	et	3	main
käivad	doc_986203247111_item	3647572	et	4	main
töö	doc_986203247111_item	3647562	et	4	main
looduses	doc_986203247111_item	3647560	et	4	main
kodus	doc_986203247111_item	3647559	et	4	main
istub	doc_986203247111_item	3647558	et	3	main
oma	doc_986203247111_item	3647549	et	4	main
inimesed	doc_986203247111_item	3647542	et	3	main
on	doc_986203247111_item	3647541	et	4	main
suur	doc_986203247111_item	3647538	et	3	main
on	doc_986203247111_item	3647537	et	4	main
eestis	doc_986203247111_item	3647536	et	3	main
hea	doc_986203247111_item	3647530	et	4	main
leida	doc_986203247111_item	3647529	et	3	main
et	doc_986203247111_item	3647528	et	3	main
aeg	doc_986203247111_item	3647527	et	3	main
temal	doc_986203247111_item	3647514	et	3	main
ja	doc_986203247111_item	3647505	et	3	main
õppima	doc_986203247111_item	3647503	et	3	main
ei	doc_986203247111_item	3647474	et	4	main
nendega	doc_986203247111_item	3647467	et	4	main
kellel	doc_986203247111_item	3647458	et	4	main
niisugused	doc_986203247111_item	3647457	et	3	main
on	doc_986203247111_item	3647456	et	4	main
aga	doc_986203247111_item	3647455	et	3	main
leia	doc_986203247111_item	3647448	et	4	main
õppida	doc_986203247111_item	3647447	et	3	main
lihtsalt	doc_986203247111_item	3647437	et	4	main
rikad	doc_986203247111_item	3647430	et	4	main
andekad	doc_986203247111_item	3647424	et	3	main
ole	doc_986203247111_item	3647414	et	4	main
ei	doc_986203247111_item	3647413	et	4	main
kaasa	doc_986203247111_item	3647384	et	4	main
aitab	doc_986203247111_item	3647383	et	3	main
see	doc_986203247111_item	3647382	et	3	main
sest	doc_986203247111_item	3647381	et	4	main
koolivorm	doc_986203247111_item	3647380	et	3	main
oma	doc_986203247111_item	3647379	et	4	main
olema	doc_986203247111_item	3647378	et	4	main
peaks	doc_986203247111_item	3647377	et	4	main
koolil	doc_986203247111_item	3647376	et	4	main
igal	doc_986203247111_item	3647375	et	3	main
1	doc_986203247111_item	3647374	et	2	main
väide	doc_986203247111_item	3647373	et	4	main
vastuargumente	doc_986203247111_item	3647372	et	3	main
ja	doc_986203247111_item	3647371	et	3	main
esitage	doc_986203247111_item	3647369	et	3	main
poolt-	doc_986203247111_item	3647370	et	4	main
mitte	doc_986203247111_item	3647368	et	3	main
või	doc_986203247111_item	3647367	et	4	main
nõus	doc_986203247111_item	3647366	et	4	main
ei	doc_986203247111_item	3647494	et	4	main
tööd	doc_986203247111_item	3647493	et	4	main
aga	doc_986203247111_item	3647492	et	3	main
palju	doc_986203247111_item	3647487	et	4	main
kes	doc_986203247111_item	3647486	et	4	main
inimesi	doc_986203247111_item	3647485	et	4	main
igav	doc_986203247111_item	3647481	et	3	main
elu	doc_986203247111_item	3647479	et	4	main
nende	doc_986203247111_item	3647478	et	4	main
ja	doc_986203247111_item	3647477	et	3	main
muret	doc_986203247111_item	3647476	et	3	main
laiad	doc_986203247111_item	3647472	et	4	main
ei	doc_986203247111_item	3647464	et	4	main
töötavad	doc_986203247111_item	3647454	et	4	main
soovivad	doc_986203247111_item	3647446	et	4	main
palju	doc_986203247111_item	3647442	et	4	main
teisele	doc_986203247111_item	3647439	et	4	main
aga	doc_986203247111_item	3647438	et	3	main
raha	doc_986203247111_item	3647433	et	4	main
nad	doc_986203247111_item	3647427	et	3	main
inimesed	doc_986203247111_item	3647420	et	3	main
ma	doc_986203247111_item	3647412	et	3	main
käivad	doc_986203247111_item	3647409	et	4	main
ja	doc_986203247111_item	3647407	et	3	main
rikkus	doc_986203247111_item	3647406	et	4	main
sõna	doc_986203247111_item	3647405	et	4	main
160	doc_986203247111_item	3647404	et	2	main
u	doc_986203247111_item	3647403	et	4	main
on	doc_986203247111_item	3647402	et	4	main
pikkus	doc_986203247111_item	3647401	et	4	main
nõutav	doc_986203247111_item	3647400	et	4	main
teksti	doc_986203247111_item	3647399	et	4	main
sisse	doc_986203247111_item	3647398	et	4	main
kasti	doc_986203247111_item	3647397	et	4	main
joonitud	doc_986203247111_item	3647396	et	4	main
kirjutage	doc_986203247111_item	3647395	et	3	main
koos	doc_986203247111_item	3647394	et	4	main
alati	doc_986203247111_item	3647393	et	4	main
käivad	doc_986203247111_item	3647392	et	4	main
tarkus	doc_986203247111_item	3647391	et	4	main
ja	doc_986203247111_item	3647390	et	3	main
rikkus	doc_986203247111_item	3647389	et	4	main
2	doc_986203247111_item	3647388	et	2	main
väide	doc_986203247111_item	3647387	et	4	main
tekkimisele	doc_986203247111_item	3647386	et	4	main
omakoolitunde	doc_986203247111_item	3647385	et	4	main
väitega	doc_986203247111_item	3647365	et	3	main
lugege	doc_986203247111_item	3647355	et	3	main
olid	doc_574559240058_item	3647665	et	4	main
tähele	doc_574559240058_item	3647656	et	3	main
see	doc_574559240058_item	3647618	et	3	main
nii	doc_574559240058_item	3647616	et	3	main
ja	doc_574559240058_item	3647613	et	3	main
kudus	doc_574559240058_item	3647611	et	4	main
naine	doc_574559240058_item	3647610	et	3	main
ajal	doc_574559240058_item	3647609	et	4	main
samal	doc_574559240058_item	3647608	et	3	main
ja	doc_574559240058_item	3647607	et	3	main
suudlesid	doc_574559240058_item	3647606	et	4	main
et	doc_574559240058_item	3647599	et	3	main
haridust	doc_609075653183_item	3647840	et	4	main
noored	doc_609075653183_item	3647838	et	3	main
ala	doc_609075653183_item	3647829	et	4	main
on	doc_609075653183_item	3647823	et	4	main
tänapäeval	doc_609075653183_item	3647822	et	3	main
väiteid	doc_986203247111_item	3647356	et	4	main
soomes	doc_574559240058_item	3647666	et	4	main
või	doc_574559240058_item	3647658	et	4	main
panin	doc_574559240058_item	3647657	et	3	main
reklaamis	doc_574559240058_item	3647624	et	4	main
teine	doc_574559240058_item	3647623	et	3	main
mahani	doc_574559240058_item	3647622	et	4	main
et	doc_574559240058_item	3647617	et	3	main
pikenes	doc_574559240058_item	3647615	et	3	main
naine	doc_574559240058_item	3647603	et	3	main
püsib	doc_574559240058_item	3647601	et	3	main
üks	doc_574559240058_item	3647592	et	3	main
viiekümnendalt	doc_574559240058_item	3647590	et	3	main
paar	doc_574559240058_item	3647588	et	3	main
see	doc_609075653183_item	3647841	et	3	main
haridust	doc_609075653183_item	3647836	et	4	main
master	doc_609075653183_item	3647827	et	4	main
soovid	doc_609075653183_item	3647819	et	4	main
on	doc_609075653183_item	3647813	et	4	main
siis	doc_609075653183_item	3647812	et	3	main
näiteks	doc_609075653183_item	3647811	et	4	main
kes	doc_609075653183_item	3647804	et	4	main
harjutust	doc_609075653183_item	3647799	et	4	main
võiks	doc_609075653183_item	3647775	et	4	main
siis	doc_609075653183_item	3647774	et	3	main
asjad	doc_609075653183_item	3647773	et	3	main
tahan	doc_609075653183_item	3647765	et	3	main
kõik	doc_609075653183_item	3647762	et	4	main
arvan	doc_609075653183_item	3647726	et	3	main
lihtsalt	doc_609075653183_item	3647714	et	4	main
inimesed	doc_609075653183_item	3647711	et	3	main
kui	doc_609075653183_item	3647710	et	3	main
revolutsioon	doc_862226128014_item	3647973	et	3	main
partei	doc_862226128014_item	3647970	et	4	main
rajas	doc_862226128014_item	3647968	et	4	main
savisaar	doc_862226128014_item	3647967	et	3	main
eesti	doc_862226128014_item	3647947	et	4	main
liidus	doc_862226128014_item	3647939	et	4	main
madalal	doc_862226128014_item	3647929	et	4	main
oli	doc_862226128014_item	3647928	et	3	main
lipp	doc_862226128014_item	3647917	et	3	main
kriis	doc_862226128014_item	3647915	et	3	main
võetud	doc_862226128014_item	3647913	et	4	main
ei	doc_862226128014_item	3647912	et	4	main
kooliõpilastele	doc_862226128014_item	3647907	et	4	main
kohustuslik	doc_862226128014_item	3647906	et	3	main
brošüür	doc_862226128014_item	3647905	et	2	main
brežnev	doc_862226128014_item	3647864	et	2	main
1989	doc_862226128014_item	3647861	et	2	main
mujal	doc_640286507875_item	3648005	et	3	main
ev-ajakirjanduse	doc_640286507875_item	3647990	et	3	main
kirjandusvool	doc_640286507875_item	3647988	et	4	main
kui	doc_640286507875_item	3647987	et	3	main
realism	doc_640286507875_item	3647986	et	3	main
2	doc_640286507875_item	3647984	et	2	main
1	doc_640286507875_item	3647976	et	2	main
ühiskonnas	doc_640286507875_item	3648117	et	4	main
sotsialistlikus	doc_640286507875_item	3648116	et	4	main
elada	doc_640286507875_item	3648115	et	3	main
hästi	doc_640286507875_item	3648114	et	3	main
kuidas	doc_640286507875_item	3648113	et	3	main
ja	doc_640286507875_item	3648112	et	3	main
oli	doc_640286507875_item	3648111	et	3	main
kui	doc_640286507875_item	3648107	et	3	main
huvitavad	doc_574559240058_item	3647681	et	4	main
olid	doc_574559240058_item	3647680	et	4	main
nad	doc_574559240058_item	3647679	et	3	main
algusel	doc_574559240058_item	3647678	et	4	main
et	doc_574559240058_item	3647677	et	3	main
arvan	doc_574559240058_item	3647676	et	3	main
reklaamid	doc_574559240058_item	3647675	et	4	main
sellega	doc_574559240058_item	3647674	et	3	main
ja	doc_574559240058_item	3647673	et	3	main
tuli	doc_574559240058_item	3647672	et	4	main
televiisor	doc_574559240058_item	3647671	et	3	main
kui	doc_574559240058_item	3647670	et	3	main
haruldased	doc_574559240058_item	3647669	et	3	main
ajal	doc_574559240058_item	3647668	et	4	main
sel	doc_574559240058_item	3647667	et	3	main
mäleta	doc_574559240058_item	3647691	et	4	main
enam	doc_574559240058_item	3647690	et	4	main
ei	doc_574559240058_item	3647689	et	4	main
ma	doc_574559240058_item	3647688	et	3	main
neid	doc_574559240058_item	3647687	et	4	main
sõpradega	doc_574559240058_item	3647686	et	3	main
koolis	doc_574559240058_item	3647685	et	4	main
räägiti	doc_574559240058_item	3647684	et	3	main
nendest	doc_574559240058_item	3647683	et	4	main
ja	doc_574559240058_item	3647682	et	3	main
esmased	doc_574559240058_item	3647653	et	3	main
nad	doc_574559240058_item	3647651	et	3	main
olla	doc_574559240058_item	3647649	et	3	main
valgemad	doc_574559240058_item	3647647	et	4	main
olid	doc_574559240058_item	3647646	et	4	main
rõivad	doc_574559240058_item	3647645	et	3	main
valge	doc_574559240058_item	3647644	et	4	main
kumma	doc_574559240058_item	3647643	et	3	main
teisega	doc_574559240058_item	3647642	et	4	main
võrdlemas	doc_574559240058_item	3647640	et	3	main
teine	doc_574559240058_item	3647641	et	3	main
perenaist	doc_574559240058_item	3647639	et	3	main
kahta	doc_574559240058_item	3647638	et	4	main
olnud	doc_574559240058_item	3647637	et	4	main
veel	doc_574559240058_item	3647636	et	4	main
ei	doc_574559240058_item	3647635	et	4	main
reklaamis	doc_574559240058_item	3647634	et	4	main
aga	doc_574559240058_item	3647633	et	3	main
lööklause	doc_574559240058_item	3647632	et	4	main
oli	doc_574559240058_item	3647631	et	3	main
valgendab	doc_574559240058_item	3647630	et	3	main
ülevalt	doc_574559240058_item	3647621	et	4	main
leheküljel	doc_574559240058_item	3647620	et	3	main
mees	doc_574559240058_item	3647605	et	4	main
ja	doc_574559240058_item	3647604	et	3	main
reklaamis	doc_574559240058_item	3647602	et	4	main
on	doc_609075653183_item	3647842	et	4	main
tänapäeva	doc_609075653183_item	3647833	et	4	main
kas	doc_609075653183_item	3647832	et	3	main
6	doc_609075653183_item	3647831	et	2	main
meester	doc_609075653183_item	3647830	et	4	main
vaja	doc_609075653183_item	3647824	et	4	main
venemaal	doc_609075653183_item	3647806	et	4	main
aitab	doc_609075653183_item	3647805	et	3	main
hea	doc_609075653183_item	3647798	et	4	main
venemaal	doc_609075653183_item	3647792	et	4	main
kus	doc_609075653183_item	3647781	et	3	main
huvitavad	doc_609075653183_item	3647772	et	4	main
palju	doc_609075653183_item	3647771	et	4	main
on	doc_609075653183_item	3647770	et	4	main
siis	doc_609075653183_item	3647769	et	3	main
sest	doc_609075653183_item	3647768	et	4	main
asjad	doc_609075653183_item	3647761	et	3	main
uued	doc_609075653183_item	3647758	et	3	main
uued	doc_609075653183_item	3647756	et	3	main
kui	doc_609075653183_item	3647750	et	3	main
on	doc_609075653183_item	3647730	et	4	main
on	doc_609075653183_item	3647718	et	4	main
asjad	doc_609075653183_item	3647715	et	3	main
haridust	doc_609075653183_item	3647709	et	4	main
oleda	doc_609075653183_item	3647708	et	4	main
sest	doc_609075653183_item	3647702	et	4	main
õpin	doc_609075653183_item	3647701	et	3	main
ma	doc_609075653183_item	3647700	et	3	main
õpin	doc_609075653183_item	3647699	et	3	main
ma	doc_609075653183_item	3647698	et	3	main
miks	doc_609075653183_item	3647697	et	4	main
1	doc_609075653183_item	3647696	et	2	main
reklaam	doc_574559240058_item	3647596	et	3	main
elus	doc_609075653183_item	3647844	et	4	main
värtustavad	doc_609075653183_item	3647839	et	4	main
tänapäeval	doc_609075653183_item	3647837	et	3	main
värtustavad	doc_609075653183_item	3647835	et	4	main
noored	doc_609075653183_item	3647834	et	3	main
kes	doc_609075653183_item	3647826	et	4	main
inimesed	doc_609075653183_item	3647825	et	3	main
miks	doc_609075653183_item	3647818	et	4	main
5	doc_609075653183_item	3647817	et	2	main
fakultetid	doc_609075653183_item	3647816	et	4	main
kõrgkoolid	doc_609075653183_item	3647810	et	3	main
huvitavad	doc_609075653183_item	3647809	et	4	main
sõbrad	doc_609075653183_item	3647803	et	3	main
palju	doc_609075653183_item	3647802	et	4	main
väga	doc_609075653183_item	3647797	et	3	main
on	doc_609075653183_item	3647796	et	4	main
sest	doc_609075653183_item	3647794	et	4	main
edasi	doc_609075653183_item	3647783	et	3	main
lihtsam	doc_609075653183_item	3647779	et	4	main
eesti	doc_609075653183_item	3647777	et	4	main
õppiks	doc_609075653183_item	3647776	et	4	main
uued	doc_609075653183_item	3647760	et	3	main
seatused	doc_609075653183_item	3647757	et	4	main
tean	doc_609075653183_item	3647749	et	3	main
ma	doc_609075653183_item	3647748	et	3	main
sest	doc_609075653183_item	3647747	et	4	main
välismaal	doc_609075653183_item	3647746	et	4	main
õppida	doc_609075653183_item	3647745	et	3	main
õppetöös	doc_609075653183_item	3647729	et	3	main
on	doc_609075653183_item	3647723	et	4	main
missugused	doc_609075653183_item	3647721	et	3	main
siis	doc_609075653183_item	3647716	et	3	main
kõik	doc_609075653183_item	3647705	et	4	main
vaja	doc_609075653183_item	3647704	et	4	main
on	doc_609075653183_item	3647703	et	4	main
lennart	doc_862226128014_item	3647964	et	4	main
esimene	doc_862226128014_item	3647961	et	3	main
euroopaga	doc_862226128014_item	3647958	et	3	main
idee	doc_862226128014_item	3647943	et	4	main
1992	doc_862226128014_item	3647937	et	2	main
eesti	doc_862226128014_item	3647920	et	4	main
enam	doc_862226128014_item	3647909	et	4	main
nliitu	doc_862226128014_item	3647908	et	4	main
moskvas	doc_862226128014_item	3647873	et	4	main
olümpiamängud	doc_862226128014_item	3647872	et	3	main
ajad	doc_862226128014_item	3647870	et	4	main
viimase	doc_862226128014_item	3647869	et	3	main
valitsemise	doc_862226128014_item	3647868	et	4	main
1980	doc_862226128014_item	3647871	et	2	main
omandada	doc_609075653183_item	3647821	et	3	main
kõrgharjutust	doc_609075653183_item	3647820	et	4	main
palju	doc_609075653183_item	3647814	et	4	main
on	doc_609075653183_item	3647807	et	4	main
siis	doc_609075653183_item	3647800	et	3	main
siis	doc_609075653183_item	3647795	et	3	main
eestis	doc_609075653183_item	3647793	et	3	main
või	doc_609075653183_item	3647791	et	4	main
eestis	doc_609075653183_item	3647790	et	3	main
õppida	doc_609075653183_item	3647789	et	3	main
edasi	doc_609075653183_item	3647788	et	3	main
tahan	doc_609075653183_item	3647787	et	3	main
ma	doc_609075653183_item	3647786	et	3	main
4	doc_609075653183_item	3647780	et	2	main
tallinnas	doc_609075653183_item	3647767	et	4	main
ma	doc_609075653183_item	3647764	et	3	main
õppida	doc_609075653183_item	3647751	et	3	main
et	doc_609075653183_item	3647743	et	3	main
arvan	doc_609075653183_item	3647742	et	3	main
varem	doc_609075653183_item	3647744	et	4	main
ma	doc_609075653183_item	3647741	et	3	main
välismaal	doc_609075653183_item	3647740	et	4	main
või	doc_609075653183_item	3647739	et	4	main
eestis	doc_609075653183_item	3647738	et	3	main
õppida	doc_609075653183_item	3647737	et	3	main
varem	doc_609075653183_item	3647736	et	4	main
on	doc_609075653183_item	3647735	et	4	main
kus	doc_609075653183_item	3647734	et	3	main
3	doc_609075653183_item	3647733	et	2	main
raskusi	doc_609075653183_item	3647732	et	4	main
vaga	doc_609075653183_item	3647731	et	4	main
sooviksid	doc_609075653183_item	3647782	et	4	main
keelt	doc_609075653183_item	3647778	et	4	main
elada	doc_609075653183_item	3647766	et	3	main
uued	doc_609075653183_item	3647763	et	3	main
inimesed	doc_609075653183_item	3647759	et	3	main
on	doc_609075653183_item	3647755	et	4	main
välismaalis	doc_609075653183_item	3647754	et	3	main
aga	doc_609075653183_item	3647753	et	3	main
eestis	doc_609075653183_item	3647752	et	3	main
minu	doc_609075653183_item	3647728	et	3	main
õppetöös	doc_609075653183_item	3647724	et	3	main
2	doc_609075653183_item	3647720	et	2	main
nad	doc_609075653183_item	3647717	et	3	main
peaksid	doc_609075653183_item	3647707	et	4	main
inimesed	doc_609075653183_item	3647706	et	3	main
laulev	doc_862226128014_item	3647972	et	4	main
esimene	doc_862226128014_item	3647969	et	3	main
president	doc_862226128014_item	3647963	et	3	main
1994	doc_862226128014_item	3647956	et	2	main
esimesed	doc_862226128014_item	3647954	et	3	main
ev	doc_862226128014_item	3647952	et	4	main
juuni	doc_862226128014_item	3647951	et	4	main
28	doc_862226128014_item	3647950	et	2	main
juunis	doc_862226128014_item	3647949	et	3	main
kroon	doc_862226128014_item	3647948	et	3	main
raha	doc_862226128014_item	3647942	et	4	main
uue	doc_862226128014_item	3647941	et	3	main
tekkib	doc_862226128014_item	3647940	et	3	main
venemaa	doc_862226128014_item	3647933	et	4	main
1991	doc_862226128014_item	3647932	et	2	main
taasiseseisvunud	doc_862226128014_item	3647919	et	4	main
poliitikaga	doc_862226128014_item	3647901	et	3	main
midagi	doc_862226128014_item	3647900	et	4	main
ostma	doc_862226128014_item	3647899	et	3	main
eesti	doc_862226128014_item	3647852	et	4	main
kontrolltöö	doc_862226128014_item	3647846	et	4	main
arenenud	doc_640286507875_item	3648003	et	4	main
elus	doc_640286507875_item	3647999	et	4	main
ensv-aegses	doc_640286507875_item	3647998	et	3	main
ka	doc_640286507875_item	3647997	et	3	main
lubamatu	doc_640286507875_item	3647995	et	4	main
sotsialistlik	doc_640286507875_item	3647985	et	3	main
ev	doc_640286507875_item	3647978	et	4	main
elu	doc_640286507875_item	3648109	et	4	main
kirjeldas	doc_640286507875_item	3648103	et	3	main
propagandaga	doc_640286507875_item	3648100	et	3	main
tsensuuri-	doc_640286507875_item	3648098	et	4	main
kommunistliku	doc_640286507875_item	3648097	et	3	main
seotud	doc_640286507875_item	3648096	et	4	main
edasiminekut	doc_640286507875_item	3648088	et	3	main
informeeritusele	doc_640286507875_item	3648085	et	4	main
kunstnikud	doc_640286507875_item	3648049	et	3	main
keelatud	doc_640286507875_item	3648047	et	4	main
oli	doc_640286507875_item	3648046	et	3	main
muusika	doc_640286507875_item	3648045	et	4	main
see	doc_640286507875_item	3648044	et	3	main
moskvas	doc_640286507875_item	3648043	et	4	main
et	doc_609075653183_item	3647727	et	3	main
ma	doc_609075653183_item	3647725	et	3	main
rasskused	doc_609075653183_item	3647722	et	4	main
lollid	doc_609075653183_item	3647719	et	3	main
teada	doc_609075653183_item	3647713	et	3	main
ei	doc_609075653183_item	3647712	et	4	main
küsimusele	doc_609075653183_item	3647695	et	4	main
vastus	doc_609075653183_item	3647694	et	3	main
edgar	doc_862226128014_item	3647966	et	4	main
eesti	doc_862226128014_item	3647962	et	4	main
jogurti	doc_862226128014_item	3647960	et	3	main
vabakaubanduse	doc_862226128014_item	3647957	et	3	main
iseseisvust	doc_862226128014_item	3647936	et	4	main
tunnistub	doc_862226128014_item	3647934	et	4	main
majandus	doc_862226128014_item	3647931	et	4	main
tasemel	doc_862226128014_item	3647930	et	3	main
elu	doc_862226128014_item	3647922	et	4	main
poliitiline	doc_862226128014_item	3647921	et	3	main
peale	doc_862226128014_item	3647918	et	4	main
sinine-must-valge	doc_862226128014_item	3647916	et	4	main
majandus	doc_862226128014_item	3647914	et	4	main
maa	doc_862226128014_item	3647904	et	4	main
väike	doc_862226128014_item	3647903	et	4	main
seotud	doc_862226128014_item	3647902	et	4	main
peab	doc_862226128014_item	3647897	et	4	main
siis	doc_862226128014_item	3647896	et	3	main
suri	doc_862226128014_item	3647863	et	3	main
1	doc_862226128014_item	3647860	et	2	main
laulev	doc_862226128014_item	3647858	et	4	main
taasiseseisvunud	doc_862226128014_item	3647851	et	4	main
muudatused	doc_862226128014_item	3647850	et	3	main
ja	doc_862226128014_item	3647849	et	3	main
1	doc_862226128014_item	3647847	et	2	main
2	doc_862226128014_item	3647971	et	2	main
meri	doc_862226128014_item	3647965	et	3	main
banaane	doc_862226128014_item	3647959	et	3	main
valitsused	doc_862226128014_item	3647955	et	4	main
põhiseadus	doc_862226128014_item	3647953	et	4	main
kasutusele	doc_862226128014_item	3647946	et	4	main
võetakse	doc_862226128014_item	3647945	et	3	main
euro	doc_862226128014_item	3647944	et	4	main
euroopa	doc_862226128014_item	3647938	et	4	main
eesti	doc_862226128014_item	3647935	et	4	main
ikka	doc_862226128014_item	3647927	et	4	main
aga	doc_862226128014_item	3647926	et	3	main
muutunud	doc_862226128014_item	3647925	et	4	main
väga	doc_862226128014_item	3647924	et	3	main
on	doc_862226128014_item	3647923	et	4	main
tõsiselt	doc_862226128014_item	3647911	et	4	main
väga	doc_862226128014_item	3647910	et	3	main
ka	doc_862226128014_item	3647898	et	3	main
raamatu	doc_862226128014_item	3647895	et	4	main
osta	doc_862226128014_item	3647894	et	4	main
tahad	doc_862226128014_item	3647893	et	3	main
kui	doc_862226128014_item	3647892	et	3	main
kaupu	doc_862226128014_item	3647891	et	3	main
igapäevaseid	doc_862226128014_item	3647890	et	4	main
osta	doc_862226128014_item	3647889	et	4	main
tuli	doc_862226128014_item	3647888	et	4	main
kohustuslik	doc_862226128014_item	3647887	et	3	main
pakkid	doc_862226128014_item	3647886	et	4	main
toiduabi	doc_862226128014_item	3647885	et	4	main
tasemel	doc_862226128014_item	3647884	et	3	main
madalal	doc_862226128014_item	3647883	et	4	main
oli	doc_862226128014_item	3647882	et	3	main
om	doc_862226128014_item	3647880	et	4	main
majandus	doc_862226128014_item	3647881	et	4	main
tulnud	doc_862226128014_item	3647879	et	4	main
ei	doc_862226128014_item	3647878	et	4	main
mõned	doc_862226128014_item	3647877	et	3	main
siis	doc_862226128014_item	3647876	et	3	main
sõda	doc_862226128014_item	3647875	et	4	main
afganistani	doc_862226128014_item	3647874	et	4	main
isikukultuse	doc_862226128014_item	3647865	et	3	main
mida	doc_862226128014_item	3647856	et	4	main
muutused	doc_862226128014_item	3647848	et	4	main
kui	doc_640286507875_item	3648004	et	3	main
kultuurielu	doc_640286507875_item	3648000	et	4	main
pärastsõjajärgset	doc_640286507875_item	3647982	et	3	main
aegset	doc_640286507875_item	3647979	et	3	main
võrrelge	doc_640286507875_item	3647977	et	3	main
realism	doc_640286507875_item	3648102	et	3	main
ja	doc_640286507875_item	3648099	et	3	main
sotsialistlik	doc_640286507875_item	3648090	et	3	main
jätkus	doc_640286507875_item	3648087	et	4	main
eesti	doc_640286507875_item	3648048	et	4	main
nsvl-s	doc_640286507875_item	3648040	et	3	main
eestis	doc_640286507875_item	3648037	et	3	main
jne	doc_826196946513_item	3648257	et	4	main
täpp	doc_826196946513_item	3648255	et	3	main
entel-tentel	doc_826196946513_item	3648252	et	4	main
televisioon	doc_826196946513_item	3648247	et	4	main
tema	doc_862226128014_item	3647867	et	4	main
periood	doc_862226128014_item	3647866	et	3	main
a	doc_862226128014_item	3647862	et	4	main
revolutsioon	doc_862226128014_item	3647859	et	3	main
tähendab	doc_862226128014_item	3647857	et	3	main
2	doc_862226128014_item	3647855	et	2	main
elus	doc_862226128014_item	3647854	et	4	main
poliitilises	doc_862226128014_item	3647853	et	3	main
oli	doc_640286507875_item	3648001	et	3	main
aga	doc_640286507875_item	3647996	et	3	main
ja	doc_640286507875_item	3647994	et	3	main
lubatu	doc_640286507875_item	3647993	et	4	main
kultuurielu	doc_640286507875_item	3647983	et	4	main
ja	doc_640286507875_item	3647980	et	3	main
kontrolltöö	doc_640286507875_item	3647975	et	4	main
hea	doc_640286507875_item	3648108	et	4	main
st	doc_640286507875_item	3648106	et	3	main
elu	doc_640286507875_item	3648105	et	4	main
otseselt	doc_640286507875_item	3648095	et	4	main
oli	doc_640286507875_item	3648094	et	3	main
kirjandusvool	doc_640286507875_item	3648093	et	4	main
kui	doc_640286507875_item	3648092	et	3	main
realism	doc_640286507875_item	3648091	et	3	main
kuid	doc_640286507875_item	3648042	et	4	main
esimene	doc_640286507875_item	3648039	et	3	main
lõpus	doc_640286507875_item	3648036	et	4	main
aastate	doc_640286507875_item	3648035	et	3	main
60ndate	doc_640286507875_item	3648034	et	4	main
töid	doc_640286507875_item	3648033	et	3	main
nende	doc_640286507875_item	3648032	et	4	main
ja	doc_826196946513_item	3648254	et	3	main
nagu	doc_826196946513_item	3648251	et	3	main
saateid	doc_826196946513_item	3648250	et	3	main
arenema	doc_826196946513_item	3648246	et	3	main
sillamäe	doc_826196946513_item	3648242	et	3	main
linnas	doc_826196946513_item	3648233	et	4	main
moodustatakse	doc_826196946513_item	3648228	et	3	main
hääletu	doc_826196946513_item	3648224	et	4	main
raamat	doc_826196946513_item	3648223	et	3	main
keelne	doc_826196946513_item	3648222	et	3	main
pärast	doc_826196946513_item	3648195	et	4	main
teha	doc_826196946513_item	3648194	et	3	main
tegemeseks	doc_826196946513_item	3648190	et	4	main
piimatoodete	doc_826196946513_item	3648174	et	3	main
seetõttu	doc_826196946513_item	3648169	et	3	main
vastu	doc_826196946513_item	3648166	et	3	main
haiguste	doc_826196946513_item	3648165	et	4	main
jne	doc_826196946513_item	3648158	et	4	main
parem	doc_640286507875_item	3648002	et	4	main
sõnavabadus	doc_640286507875_item	3647992	et	4	main
ja	doc_640286507875_item	3647991	et	3	main
1	doc_640286507875_item	3647989	et	2	main
ensv	doc_640286507875_item	3647981	et	4	main
neil	doc_640286507875_item	3648110	et	4	main
töölisklassi	doc_640286507875_item	3648104	et	4	main
sotsialistlik	doc_640286507875_item	3648101	et	3	main
2	doc_640286507875_item	3648089	et	2	main
kultuur	doc_640286507875_item	3648086	et	3	main
ja	doc_640286507875_item	3648084	et	3	main
vastu	doc_640286507875_item	3648083	et	3	main
kultuuri	doc_640286507875_item	3648082	et	4	main
armastusele	doc_640286507875_item	3648081	et	4	main
inimeste	doc_640286507875_item	3648080	et	3	main
tänul	doc_640286507875_item	3648079	et	3	main
aga	doc_640286507875_item	3648078	et	3	main
arengule	doc_640286507875_item	3648077	et	3	main
kultuuri	doc_640286507875_item	3648076	et	4	main
takistusi	doc_640286507875_item	3648075	et	4	main
tegid	doc_640286507875_item	3648074	et	4	main
võimuorganid	doc_640286507875_item	3648073	et	3	main
nsvl-s	doc_640286507875_item	3648072	et	3	main
mujal	doc_640286507875_item	3648071	et	3	main
kui	doc_640286507875_item	3648070	et	3	main
laiemad	doc_640286507875_item	3648069	et	4	main
olid	doc_640286507875_item	3648068	et	4	main
piirid	doc_640286507875_item	3648067	et	3	main
lubatu	doc_640286507875_item	3648066	et	4	main
kultuuri	doc_640286507875_item	3648065	et	4	main
ensv	doc_640286507875_item	3648064	et	4	main
ka	doc_640286507875_item	3648063	et	3	main
kuid	doc_640286507875_item	3648062	et	4	main
vabameelsem	doc_640286507875_item	3648061	et	4	main
palju	doc_640286507875_item	3648060	et	4	main
küll	doc_640286507875_item	3648059	et	4	main
on	doc_640286507875_item	3648058	et	4	main
kultuurielu	doc_640286507875_item	3648057	et	4	main
aegne	doc_640286507875_item	3648056	et	3	main
ev	doc_640286507875_item	3648055	et	4	main
kunstivooludega	doc_640286507875_item	3648054	et	3	main
levinud	doc_640286507875_item	3648053	et	4	main
maailmas	doc_640286507875_item	3648052	et	3	main
kaasa	doc_640286507875_item	3648051	et	4	main
läksid	doc_640286507875_item	3648050	et	4	main
taasavaldama	doc_640286507875_item	3648031	et	3	main
hakkati	doc_640286507875_item	3648030	et	3	main
ja	doc_640286507875_item	3648029	et	3	main
liitudesse	doc_640286507875_item	3648028	et	3	main
loominguliste	doc_640286507875_item	3648027	et	4	main
ennistamine	doc_640286507875_item	3648026	et	4	main
kuritegijate	doc_640286507875_item	3648025	et	3	main
kultuuri	doc_640286507875_item	3648024	et	4	main
algas	doc_640286507875_item	3648023	et	3	main
pärast	doc_640286507875_item	3648022	et	4	main
paljastamine	doc_640286507875_item	3648021	et	4	main
kuritegude	doc_640286507875_item	3648020	et	3	main
stalini	doc_640286507875_item	3648019	et	4	main
algas	doc_640286507875_item	3648018	et	3	main
1956	doc_640286507875_item	3648017	et	2	main
jne	doc_640286507875_item	3648016	et	4	main
heliplaadid	doc_640286507875_item	3648015	et	3	main
rõivad	doc_640286507875_item	3648014	et	3	main
moodsad	doc_640286507875_item	3648013	et	3	main
tulid	doc_640286507875_item	3648012	et	4	main
sealt	doc_640286507875_item	3648011	et	4	main
läänestumine	doc_640286507875_item	3648010	et	4	main
iseloomulik	doc_640286507875_item	3648009	et	3	main
oli	doc_640286507875_item	3648008	et	3	main
eestile	doc_640286507875_item	3648007	et	3	main
nsvl-s	doc_640286507875_item	3648006	et	3	main
tipp	doc_826196946513_item	3648253	et	3	main
näiteks	doc_826196946513_item	3648249	et	4	main
lahemaa	doc_826196946513_item	3648229	et	4	main
1974	doc_826196946513_item	3648226	et	2	main
keved	doc_826196946513_item	3648225	et	4	main
metsa	doc_826196946513_item	3648192	et	4	main
asju	doc_826196946513_item	3648189	et	3	main
majanduses	doc_826196946513_item	3648187	et	4	main
suurendada	doc_826196946513_item	3648186	et	3	main
rohtu	doc_826196946513_item	3648164	et	4	main
teha	doc_826196946513_item	3648163	et	3	main
kus	doc_826196946513_item	3648152	et	3	main
2	doc_826196946513_item	3648128	et	2	main
nsv-s	doc_826196946513_item	3648127	et	3	main
eesti	doc_826196946513_item	3648126	et	4	main
moraalne	doc_48663839466_item	3648398	et	3	main
ei	doc_48663839466_item	3648379	et	4	main
elus	doc_48663839466_item	3648369	et	4	main
surnul	doc_48663839466_item	3648359	et	4	main
nimetada	doc_48663839466_item	3648352	et	3	main
veel	doc_48663839466_item	3648348	et	4	main
hauda	doc_48663839466_item	3648335	et	4	main
laibaga	doc_48663839466_item	3648334	et	3	main
maa	doc_48663839466_item	3648331	et	4	main
on	doc_48663839466_item	3648299	et	4	main
kohas	doc_48663839466_item	3648297	et	4	main
varasemast	doc_48663839466_item	3648284	et	4	main
elama	doc_48663839466_item	3648283	et	3	main
eesti	doc_48663839466_item	3648262	et	4	main
kiviaeg	doc_48663839466_item	3648261	et	3	main
džaasifestival	doc_640286507875_item	3648041	et	2	main
toimus	doc_640286507875_item	3648038	et	3	main
televisioon	doc_826196946513_item	3648248	et	4	main
valja	doc_826196946513_item	3648238	et	3	main
saanud	doc_826196946513_item	3648237	et	4	main
rahvuspark	doc_826196946513_item	3648230	et	3	main
a	doc_826196946513_item	3648227	et	4	main
jne	doc_826196946513_item	3648198	et	4	main
mööblit	doc_826196946513_item	3648197	et	3	main
paberit	doc_826196946513_item	3648196	et	3	main
kasvatati	doc_826196946513_item	3648191	et	3	main
ja	doc_826196946513_item	3648173	et	3	main
kasvas	doc_826196946513_item	3648170	et	3	main
loomi	doc_826196946513_item	3648168	et	4	main
kasvatati	doc_826196946513_item	3648167	et	3	main
hakatikasvatama	doc_826196946513_item	3648159	et	4	main
metalli	doc_826196946513_item	3648156	et	4	main
erikal	doc_826196946513_item	3648136	et	4	main
kas	doc_826196946513_item	3648135	et	3	main
identiteediprobleemid	doc_826196946513_item	3648134	et	3	main
suuremad	doc_826196946513_item	3648133	et	4	main
kellel	doc_826196946513_item	3648129	et	4	main
materiaalne	doc_48663839466_item	3648396	et	3	main
teatud	doc_48663839466_item	3648393	et	4	main
kultuur	doc_48663839466_item	3648392	et	3	main
või	doc_48663839466_item	3648378	et	4	main
jaht	doc_48663839466_item	3648377	et	3	main
õnenstub	doc_48663839466_item	3648376	et	4	main
nad	doc_48663839466_item	3648371	et	3	main
kui	doc_48663839466_item	3648366	et	3	main
neid	doc_48663839466_item	3648361	et	4	main
pärast	doc_48663839466_item	3648356	et	4	main
et	doc_48663839466_item	3648355	et	3	main
religioon	doc_48663839466_item	3648345	et	3	main
ka	doc_48663839466_item	3648343	et	3	main
pandi	doc_48663839466_item	3648337	et	4	main
sisse	doc_48663839466_item	3648336	et	4	main
kaua	doc_48663839466_item	3648298	et	3	main
ühes	doc_48663839466_item	3648296	et	4	main
elanud	doc_48663839466_item	3648295	et	4	main
ilmselt	doc_48663839466_item	3648291	et	4	main
eesti	doc_48663839466_item	3648286	et	4	main
kiviajast	doc_48663839466_item	3648285	et	4	main
tagasi	doc_48663839466_item	3648278	et	3	main
aastat	doc_48663839466_item	3648277	et	3	main
umbes	doc_48663839466_item	3648275	et	4	main
1	doc_48663839466_item	3648269	et	2	main
arheoloogiline	doc_48663839466_item	3648266	et	4	main
uudiseid	doc_826196946513_item	3648256	et	3	main
hakkas	doc_826196946513_item	3648245	et	3	main
1970	doc_826196946513_item	3648243	et	2	main
loata	doc_826196946513_item	3648241	et	4	main
ilma	doc_826196946513_item	3648240	et	4	main
sõita	doc_826196946513_item	3648239	et	3	main
linnad	doc_826196946513_item	3648232	et	3	main
kinnised	doc_826196946513_item	3648231	et	4	main
ilmus	doc_826196946513_item	3648220	et	4	main
a	doc_826196946513_item	3648219	et	4	main
1968	doc_826196946513_item	3648218	et	2	main
elektrijaam	doc_826196946513_item	3648217	et	3	main
ja	doc_826196946513_item	3648216	et	3	main
soojus	doc_826196946513_item	3648215	et	4	main
balti	doc_826196946513_item	3648214	et	3	main
ehitati	doc_826196946513_item	3648213	et	3	main
a	doc_826196946513_item	3648212	et	4	main
inimesi	doc_826196946513_item	3648210	et	4	main
palju	doc_826196946513_item	3648209	et	4	main
läheb	doc_826196946513_item	3648208	et	3	main
eestist	doc_826196946513_item	3648207	et	3	main
ja	doc_826196946513_item	3648206	et	3	main
tuleb	doc_826196946513_item	3648205	et	3	main
eestisse	doc_826196946513_item	3648204	et	4	main
migratsioon	doc_826196946513_item	3648203	et	3	main
iseloomulikuks	doc_826196946513_item	3648202	et	3	main
saab	doc_826196946513_item	3648201	et	3	main
a	doc_826196946513_item	3648200	et	4	main
1970	doc_826196946513_item	3648199	et	2	main
aastatel	doc_826196946513_item	3648244	et	4	main
ei	doc_826196946513_item	3648236	et	4	main
inimesed	doc_826196946513_item	3648235	et	3	main
kust	doc_826196946513_item	3648234	et	4	main
eesti	doc_826196946513_item	3648221	et	4	main
1973	doc_826196946513_item	3648211	et	2	main
et	doc_826196946513_item	3648193	et	3	main
vajaline	doc_826196946513_item	3648188	et	4	main
ja	doc_826196946513_item	3648185	et	3	main
raha	doc_826196946513_item	3648184	et	4	main
teenida	doc_826196946513_item	3648183	et	3	main
inimestele	doc_826196946513_item	3648182	et	3	main
võimalust	doc_826196946513_item	3648181	et	3	main
anda	doc_826196946513_item	3648180	et	3	main
et	doc_826196946513_item	3648179	et	3	main
tehaseid	doc_826196946513_item	3648178	et	3	main
liha-	doc_826196946513_item	3648172	et	4	main
suureks	doc_826196946513_item	3648171	et	4	main
tööriistu	doc_826196946513_item	3648157	et	3	main
varastati	doc_826196946513_item	3648155	et	3	main
või	doc_826196946513_item	3648137	et	4	main
on	doc_826196946513_item	3648130	et	4	main
ja	doc_48663839466_item	3648397	et	3	main
inimgruppile	doc_48663839466_item	3648394	et	4	main
arheoloogiline	doc_48663839466_item	3648391	et	4	main
2	doc_48663839466_item	3648390	et	2	main
hõimud	doc_48663839466_item	3648383	et	4	main
baltimaade	doc_48663839466_item	3648382	et	3	main
arvatavasti	doc_48663839466_item	3648381	et	3	main
neil	doc_48663839466_item	3648375	et	4	main
smmuti	doc_48663839466_item	3648370	et	4	main
ta	doc_48663839466_item	3648367	et	4	main
teda	doc_48663839466_item	3648365	et	4	main
ümbritses	doc_48663839466_item	3648364	et	3	main
mis	doc_48663839466_item	3648363	et	4	main
asju	doc_48663839466_item	3648362	et	3	main
tohiks	doc_48663839466_item	3648350	et	3	main
kuigi	doc_48663839466_item	3648346	et	3	main
oma	doc_48663839466_item	3648344	et	4	main
muidugi	doc_48663839466_item	3648341	et	4	main
loomakujukesi	doc_48663839466_item	3648340	et	4	main
sisse	doc_48663839466_item	3648332	et	4	main
inimesi	doc_48663839466_item	3648329	et	4	main
venekirves	doc_48663839466_item	3648328	et	4	main
ehitama	doc_826196946513_item	3648177	et	4	main
hakati	doc_826196946513_item	3648176	et	3	main
müük	doc_826196946513_item	3648175	et	3	main
saasta	doc_826196946513_item	3648162	et	4	main
et	doc_826196946513_item	3648161	et	3	main
taimi	doc_826196946513_item	3648160	et	4	main
nad	doc_826196946513_item	3648153	et	3	main
varastasid	doc_826196946513_item	3648150	et	4	main
sakslast	doc_826196946513_item	3648142	et	3	main
armastasin	doc_826196946513_item	3648141	et	3	main
arvates	doc_826196946513_item	3648132	et	4	main
teie	doc_826196946513_item	3648131	et	4	main
kultuur	doc_48663839466_item	3648399	et	3	main
volgalt	doc_48663839466_item	3648387	et	4	main
territooriumile	doc_48663839466_item	3648386	et	3	main
eesti	doc_48663839466_item	3648385	et	4	main
tulid	doc_48663839466_item	3648384	et	4	main
jälgisid	doc_48663839466_item	3648372	et	4	main
vaja	doc_48663839466_item	3648360	et	4	main
uskusid	doc_48663839466_item	3648354	et	4	main
inimesed	doc_48663839466_item	3648353	et	3	main
ei	doc_48663839466_item	3648349	et	4	main
seda	doc_48663839466_item	3648347	et	3	main
oli	doc_48663839466_item	3648342	et	3	main
et	doc_48663839466_item	3648293	et	3	main
vähe	doc_48663839466_item	3648289	et	3	main
territooriumil	doc_48663839466_item	3648287	et	3	main
eesti	doc_48663839466_item	3648273	et	4	main
töötasid	doc_826196946513_item	3648154	et	4	main
sealt	doc_826196946513_item	3648151	et	4	main
inimesed	doc_826196946513_item	3648149	et	3	main
riigivargus	doc_826196946513_item	3648148	et	3	main
oli	doc_826196946513_item	3648147	et	3	main
aastatel	doc_826196946513_item	3648146	et	4	main
1970	doc_826196946513_item	3648145	et	2	main
1	doc_826196946513_item	3648144	et	2	main
põhjendage	doc_826196946513_item	3648143	et	3	main
ma	doc_826196946513_item	3648140	et	3	main
tammsaare	doc_826196946513_item	3648139	et	3	main
oskaril	doc_826196946513_item	3648138	et	4	main
1970ndate	doc_826196946513_item	3648125	et	4	main
vastasseis	doc_826196946513_item	3648124	et	3	main
loodushoiu	doc_826196946513_item	3648123	et	3	main
ja	doc_826196946513_item	3648122	et	3	main
majanduse	doc_826196946513_item	3648121	et	4	main
1	doc_826196946513_item	3648120	et	2	main
kontrolltöö	doc_826196946513_item	3648119	et	4	main
omane	doc_48663839466_item	3648395	et	3	main
baikaalilt	doc_48663839466_item	3648389	et	4	main
ja	doc_48663839466_item	3648388	et	3	main
jne	doc_48663839466_item	3648380	et	4	main
kas	doc_48663839466_item	3648374	et	3	main
taevast	doc_48663839466_item	3648373	et	4	main
oli	doc_48663839466_item	3648368	et	3	main
on	doc_48663839466_item	3648358	et	4	main
surma	doc_48663839466_item	3648357	et	4	main
nii	doc_48663839466_item	3648351	et	3	main
ehti	doc_48663839466_item	3648339	et	4	main
tööriistu	doc_48663839466_item	3648338	et	3	main
koos	doc_48663839466_item	3648333	et	4	main
maeti	doc_48663839466_item	3648330	et	3	main
ja	doc_48663839466_item	3648327	et	3	main
nöörkeraamika	doc_48663839466_item	3648326	et	4	main
aastatuhandel	doc_48663839466_item	3648325	et	4	main
iii	doc_48663839466_item	3648324	et	4	main
hiljem	doc_48663839466_item	3648323	et	3	main
kammkeraamika	doc_48663839466_item	3648322	et	4	main
ilmus	doc_48663839466_item	3648321	et	4	main
aastatuhandel	doc_48663839466_item	3648320	et	4	main
iv	doc_48663839466_item	3648319	et	4	main
umbes	doc_48663839466_item	3648318	et	4	main
keraamika	doc_48663839466_item	3648317	et	4	main
tööriistad	doc_48663839466_item	3648316	et	3	main
ka	doc_48663839466_item	3648315	et	3	main
ilmunud	doc_48663839466_item	3648314	et	4	main
juba	doc_48663839466_item	3648313	et	3	main
on	doc_48663839466_item	3648312	et	4	main
kiviajal	doc_48663839466_item	3648311	et	3	main
hilisemal	doc_48663839466_item	3648310	et	4	main
jahil	doc_48663839466_item	3648309	et	3	main
käisid	doc_48663839466_item	3648308	et	4	main
ja	doc_48663839466_item	3648307	et	3	main
korjamisega	doc_48663839466_item	3648306	et	4	main
kalapüügiga	doc_48663839466_item	3648305	et	3	main
tegelesid	doc_48663839466_item	3648304	et	4	main
eesvanemad	doc_48663839466_item	3648303	et	4	main
meie	doc_48663839466_item	3648302	et	4	main
et	doc_48663839466_item	3648301	et	3	main
teada	doc_48663839466_item	3648300	et	3	main
sellepärast	doc_48663839466_item	3648292	et	3	main
siin	doc_48663839466_item	3648282	et	4	main
inimesed	doc_48663839466_item	3648281	et	3	main
siis	doc_48663839466_item	3648279	et	3	main
praeguse	doc_48663839466_item	3648272	et	3	main
mandrijääst	doc_48663839466_item	3648270	et	3	main
tähendus	doc_48663839466_item	3648268	et	4	main
ei	doc_48663839466_item	3648294	et	4	main
säilinud	doc_48663839466_item	3648290	et	4	main
on	doc_48663839466_item	3648288	et	4	main
hakkasid	doc_48663839466_item	3648280	et	4	main
9000	doc_48663839466_item	3648276	et	2	main
territoorium	doc_48663839466_item	3648274	et	3	main
vabanes	doc_48663839466_item	3648271	et	3	main
kultuur	doc_48663839466_item	3648267	et	3	main
mõiste	doc_48663839466_item	3648265	et	4	main
2	doc_48663839466_item	3648264	et	2	main
territooriumil	doc_48663839466_item	3648263	et	3	main
kontrolltöö	doc_48663839466_item	3648259	et	4	main
territoorium	doc_48663839466_item	3648413	et	3	main
ajajärg	doc_48663839466_item	3648412	et	3	main
leiud	doc_48663839466_item	3648411	et	3	main
ja	doc_48663839466_item	3648410	et	3	main
mõisted	doc_48663839466_item	3648409	et	3	main
sarnased	doc_48663839466_item	3648408	et	4	main
omased	doc_48663839466_item	3648407	et	3	main
kultuurile	doc_48663839466_item	3648406	et	3	main
igale	doc_48663839466_item	3648405	et	3	main
järgi	doc_48663839466_item	3648404	et	4	main
leidude	doc_48663839466_item	3648403	et	4	main
arheoloogiliste	doc_48663839466_item	3648402	et	4	main
selgub	doc_48663839466_item	3648401	et	3	main
mis	doc_48663839466_item	3648400	et	4	main
1	doc_48663839466_item	3648260	et	2	main
meeldib	doc_901133458163_item	3648922	et	3	main
meeldib	doc_901133458163_item	3648919	et	3	main
puhkad	doc_901133458163_item	3648917	et	3	main
kas	doc_901133458163_item	3648905	et	3	main
õde	doc_901133458163_item	3648866	et	4	main
on	doc_901133458163_item	3648848	et	4	main
kõrval	doc_901133458163_item	3648835	et	4	main
laste	doc_901133458163_item	3648832	et	4	main
on	doc_901133458163_item	3648830	et	4	main
ta	doc_901133458163_item	3648829	et	4	main
suur	doc_901133458163_item	3648828	et	3	main
ja	doc_901133458163_item	3648819	et	3	main
paremale	doc_901133458163_item	3648818	et	4	main
keerake	doc_901133458163_item	3648817	et	3	main
kodu	doc_901133458163_item	3648785	et	4	main
mis	doc_901133458163_item	3648777	et	4	main
küsimustele	doc_901133458163_item	3648771	et	4	main
järgmistele	doc_901133458163_item	3648770	et	3	main
kolmapäeviti	doc_901133458164_item	3649062	et	4	main
on	doc_901133458164_item	3649045	et	4	main
ema	doc_901133458164_item	3649033	et	4	main
väike	doc_901133458164_item	3649032	et	4	main
millega	doc_901133458164_item	3649025	et	3	main
huvitavat	doc_901133458164_item	3648963	et	4	main
kodulinnas	doc_901133458164_item	3648962	et	4	main
sinu	doc_901133458164_item	3648961	et	3	main
midagi	doc_901133458164_item	3648956	et	4	main
vastus	doc_901133458164_item	3648949	et	3	main
ma	doc_901133458164_item	3649108	et	3	main
ja	doc_901133458164_item	3649105	et	3	main
sa	doc_901133458164_item	3649086	et	3	main
sinu	doc_901133458164_item	3649083	et	3	main
mis	doc_901133458164_item	3649081	et	4	main
hobisid	doc_901133458164_item	3649080	et	3	main
puhkan	doc_901133458165_item	3649266	et	3	main
kooki	doc_901133458165_item	3649244	et	4	main
küpsetada	doc_901133458165_item	3649243	et	3	main
meeldib	doc_901133458165_item	3649242	et	3	main
mulle	doc_901133458165_item	3649241	et	4	main
kas	doc_901133458165_item	3649228	et	3	main
õppib	doc_901133458165_item	3649216	et	4	main
tütar	doc_901133458165_item	3649215	et	3	main
minu	doc_901133458165_item	3649214	et	3	main
tallinnas	doc_901133458165_item	3649210	et	4	main
poeg	doc_901133458165_item	3649208	et	3	main
pojengi	doc_901133458163_item	3648924	et	4	main
on	doc_901133458163_item	3648907	et	4	main
sul	doc_901133458163_item	3648906	et	3	main
teha	doc_901133458163_item	3648904	et	3	main
sulle	doc_901133458163_item	3648900	et	3	main
3	doc_901133458163_item	3648898	et	2	main
pere	doc_901133458163_item	3648897	et	4	main
pingeid	doc_901133458163_item	3648896	et	3	main
mina	doc_901133458163_item	3648869	et	4	main
ja	doc_901133458163_item	3648868	et	3	main
ema	doc_901133458163_item	3648865	et	4	main
meie	doc_901133458163_item	3648859	et	4	main
perekonna	doc_901133458163_item	3648858	et	4	main
suur	doc_901133458163_item	3648857	et	3	main
pereliikmed	doc_901133458163_item	3648854	et	3	main
milline	doc_901133458163_item	3648847	et	3	main
kaske	doc_901133458163_item	3648845	et	4	main
vaher	doc_901133458163_item	3648843	et	3	main
toominga	doc_901133458163_item	3648841	et	3	main
taga	doc_901133458163_item	3648838	et	4	main
kodu	doc_901133458163_item	3648837	et	4	main
majas	doc_901133458163_item	3648836	et	3	main
platsi	doc_901133458163_item	3648833	et	4	main
platsini	doc_901133458163_item	3648816	et	4	main
peetri	doc_901133458163_item	3648815	et	3	main
koduümbrus	doc_901133458163_item	3648787	et	3	main
kodulinnast	doc_901133458163_item	3648776	et	4	main
oma	doc_901133458163_item	3648775	et	4	main
vasta	doc_901133458163_item	3648769	et	4	main
küsimusele	doc_901133458163_item	3648768	et	4	main
vastus	doc_901133458163_item	3648767	et	3	main
on	doc_901133458163_item	3648927	et	4	main
hobisid	doc_901133458163_item	3648926	et	3	main
minu	doc_901133458163_item	3648925	et	3	main
mulle	doc_901133458163_item	3648921	et	4	main
lilled	doc_901133458163_item	3648920	et	3	main
sa	doc_901133458163_item	3648915	et	3	main
lemmiktegevus	doc_901133458163_item	3648913	et	4	main
on	doc_901133458163_item	3648911	et	4	main
mis	doc_901133458163_item	3648910	et	4	main
hobisid	doc_901133458163_item	3648909	et	3	main
mingeid	doc_901133458163_item	3648908	et	3	main
vabal	doc_901133458163_item	3648902	et	3	main
meeldib	doc_901133458163_item	3648901	et	3	main
liiget	doc_901133458163_item	3648863	et	3	main
on	doc_901133458163_item	3648861	et	4	main
perennas	doc_901133458163_item	3648860	et	4	main
mul	doc_901133458163_item	3648855	et	3	main
tegelevad	doc_901133458163_item	3648852	et	4	main
millega	doc_901133458163_item	3648851	et	3	main
perekond	doc_901133458163_item	3648850	et	3	main
kirjutan	doc_901133458163_item	3648928	et	3	main
vend	doc_901133458163_item	3648867	et	3	main
isa	doc_901133458163_item	3648864	et	4	main
viis	doc_901133458163_item	3648862	et	4	main
on	doc_901133458163_item	3648856	et	4	main
sinu	doc_901133458163_item	3648853	et	3	main
sinu	doc_901133458163_item	3648849	et	3	main
2	doc_901133458163_item	3648846	et	2	main
sirel	doc_901133458163_item	3648842	et	3	main
on	doc_901133458163_item	3648827	et	4	main
kunstihoone	doc_901133458163_item	3648824	et	4	main
narvas	doc_901133458163_item	3648822	et	4	main
on	doc_901133458163_item	3648778	et	4	main
kirjuta	doc_901133458163_item	3648773	et	4	main
1	doc_901133458163_item	3648772	et	2	main
kas	doc_901133458164_item	3649076	et	3	main
teha	doc_901133458164_item	3649075	et	3	main
vabal	doc_901133458164_item	3649073	et	3	main
meeldib	doc_901133458164_item	3649072	et	3	main
sulle	doc_901133458164_item	3649071	et	3	main
mida	doc_901133458164_item	3649070	et	4	main
sõita	doc_901133458164_item	3649067	et	3	main
ma	doc_901133458164_item	3649066	et	3	main
tahaksin	doc_901133458164_item	3649065	et	3	main
järgmisel	doc_901133458164_item	3649063	et	3	main
tunnid	doc_901133458164_item	3649058	et	3	main
must	doc_901133458164_item	3649046	et	4	main
elavad	doc_901133458164_item	3649039	et	4	main
venda	doc_901133458164_item	3649037	et	4	main
isa	doc_901133458164_item	3649034	et	4	main
väike	doc_901133458164_item	3648980	et	4	main
on	doc_901133458164_item	3648960	et	4	main
kirjuta	doc_901133458164_item	3648955	et	4	main
1	doc_901133458164_item	3648954	et	2	main
kohvikus	doc_901133458164_item	3649112	et	3	main
puhkan	doc_901133458164_item	3649109	et	3	main
lemmiktegevus	doc_901133458164_item	3649084	et	4	main
on	doc_901133458164_item	3649082	et	4	main
narva-jõesuusse	doc_901133458165_item	3649267	et	3	main
sportiga	doc_901133458165_item	3649256	et	4	main
tegelevad	doc_901133458165_item	3649255	et	4	main
mingeid	doc_901133458165_item	3649231	et	3	main
joonistada	doc_901133458163_item	3648946	et	3	main
ja	doc_901133458163_item	3648945	et	3	main
päevitada	doc_901133458163_item	3648944	et	3	main
supelda	doc_901133458163_item	3648943	et	4	main
armastan	doc_901133458163_item	3648942	et	3	main
ma	doc_901133458163_item	3648941	et	3	main
maal	doc_901133458163_item	3648940	et	4	main
puhkan	doc_901133458163_item	3648939	et	3	main
ma	doc_901133458163_item	3648938	et	3	main
suvel	doc_901133458163_item	3648937	et	3	main
kuulan	doc_901133458163_item	3648935	et	3	main
muusika	doc_901133458163_item	3648936	et	4	main
ja	doc_901133458163_item	3648934	et	3	main
telerit	doc_901133458163_item	3648933	et	3	main
vaatan	doc_901133458163_item	3648932	et	3	main
meeldib	doc_901133458163_item	3648931	et	3	main
mulle	doc_901133458163_item	3648930	et	4	main
luuletuse	doc_901133458163_item	3648929	et	4	main
astrit	doc_901133458163_item	3648923	et	3	main
mulle	doc_901133458163_item	3648918	et	4	main
suvel	doc_901133458163_item	3648916	et	3	main
kus	doc_901133458163_item	3648914	et	3	main
sinu	doc_901133458163_item	3648912	et	3	main
ajal	doc_901133458163_item	3648903	et	4	main
mida	doc_901133458163_item	3648899	et	4	main
valtrida	doc_901133458163_item	3648895	et	4	main
püüame	doc_901133458163_item	3648894	et	3	main
me	doc_901133458163_item	3648893	et	4	main
ebameeldivusi	doc_901133458163_item	3648892	et	4	main
valtida	doc_901133458163_item	3648891	et	4	main
püüame	doc_901133458163_item	3648890	et	3	main
me	doc_901133458163_item	3648889	et	4	main
abistama	doc_901133458163_item	3648888	et	3	main
üksteist	doc_901133458163_item	3648887	et	4	main
valmis	doc_901133458163_item	3648886	et	4	main
oleme	doc_901133458163_item	3648885	et	3	main
üksteisega	doc_901133458163_item	3648884	et	3	main
arvestame	doc_901133458163_item	3648883	et	3	main
me	doc_901133458163_item	3648882	et	4	main
traditsione	doc_901133458163_item	3648881	et	4	main
perekonna	doc_901133458163_item	3648880	et	4	main
oma	doc_901133458163_item	3648879	et	4	main
on	doc_901133458163_item	3648878	et	4	main
minul	doc_901133458163_item	3648877	et	3	main
joulud	doc_901133458163_item	3648876	et	4	main
ja	doc_901133458163_item	3648875	et	3	main
lihavõtte	doc_901133458163_item	3648874	et	4	main
juubeleid	doc_901133458163_item	3648873	et	3	main
sünnipäevi	doc_901133458163_item	3648872	et	4	main
tähistame	doc_901133458163_item	3648871	et	3	main
me	doc_901133458163_item	3648870	et	4	main
ja	doc_901133458163_item	3648844	et	3	main
on	doc_901133458163_item	3648834	et	4	main
üheksakorruseline	doc_901133458163_item	3648831	et	4	main
kodu	doc_901133458163_item	3648826	et	4	main
on	doc_901133458163_item	3648823	et	4	main
paistab	doc_901133458163_item	3648821	et	3	main
raekoda	doc_901133458163_item	3648820	et	4	main
kuni	doc_901133458163_item	3648814	et	3	main
otse	doc_901133458163_item	3648813	et	4	main
minge	doc_901133458163_item	3648812	et	3	main
asjad	doc_901133458163_item	3648811	et	3	main
ilus	doc_901133458163_item	3648810	et	4	main
müüakse	doc_901133458163_item	3648809	et	3	main
kus	doc_901133458163_item	3648808	et	3	main
poodi	doc_901133458163_item	3648807	et	4	main
huvitavat	doc_901133458163_item	3648806	et	4	main
on	doc_901133458163_item	3648805	et	4	main
kodulinnas	doc_901133458163_item	3648804	et	4	main
pargi	doc_901133458163_item	3648803	et	4	main
ilus	doc_901133458163_item	3648802	et	4	main
on	doc_901133458163_item	3648801	et	4	main
narvas	doc_901133458163_item	3648800	et	4	main
maakonnas	doc_901133458163_item	3648799	et	4	main
ida-viru	doc_901133458163_item	3648798	et	4	main
asub	doc_901133458163_item	3648797	et	3	main
narva	doc_901133458163_item	3648796	et	4	main
narva	doc_901133458163_item	3648795	et	4	main
on	doc_901133458163_item	3648794	et	4	main
kodulinnas	doc_901133458163_item	3648793	et	4	main
minu	doc_901133458163_item	3648792	et	3	main
ilus	doc_901133458163_item	3648791	et	4	main
on	doc_901133458163_item	3648790	et	4	main
kodulinnas	doc_901133458163_item	3648789	et	4	main
minu	doc_901133458163_item	3648788	et	3	main
puud	doc_901133458163_item	3648840	et	4	main
kasvama	doc_901133458163_item	3648839	et	3	main
minu	doc_901133458163_item	3648825	et	3	main
on	doc_901133458163_item	3648783	et	4	main
kodulinnas	doc_901133458163_item	3648780	et	4	main
sinu	doc_901133458163_item	3648779	et	3	main
midagi	doc_901133458163_item	3648774	et	4	main
esmaspäeviti	doc_901133458164_item	3649060	et	4	main
on	doc_901133458164_item	3649059	et	4	main
keelt	doc_901133458164_item	3649057	et	4	main
rootsi	doc_901133458164_item	3649056	et	4	main
ma	doc_901133458164_item	3649055	et	3	main
õpin	doc_901133458164_item	3649054	et	3	main
õhtuti	doc_901133458164_item	3649053	et	3	main
jalutame	doc_901133458164_item	3649052	et	3	main
pereliikmes	doc_901133458164_item	3649051	et	3	main
tegeleme	doc_901133458164_item	3649050	et	3	main
me	doc_901133458164_item	3649049	et	4	main
kass	doc_901133458164_item	3649048	et	3	main
mul	doc_901133458164_item	3649044	et	3	main
tallinnas	doc_901133458164_item	3649040	et	4	main
nad	doc_901133458164_item	3649038	et	3	main
kaks	doc_901133458164_item	3649036	et	3	main
ja	doc_901133458164_item	3649035	et	3	main
pere	doc_901133458164_item	3649030	et	4	main
minu	doc_901133458164_item	3649029	et	3	main
pereliikmed	doc_901133458164_item	3649028	et	3	main
sinu	doc_901133458164_item	3649027	et	3	main
mulle	doc_901133458164_item	3648988	et	4	main
seal	doc_901133458164_item	3648983	et	4	main
mis	doc_901133458164_item	3648959	et	4	main
küsimustele	doc_901133458164_item	3648953	et	4	main
järgmistele	doc_901133458164_item	3648952	et	3	main
vasta	doc_901133458164_item	3648951	et	4	main
käia	doc_901133458164_item	3649111	et	4	main
ja	doc_901133458164_item	3649110	et	3	main
päevitan	doc_901133458164_item	3649106	et	3	main
meeldib	doc_901133458164_item	3649103	et	3	main
suvel	doc_901133458164_item	3649101	et	3	main
kus	doc_901133458164_item	3649085	et	3	main
ja	doc_901133458165_item	3649263	et	3	main
õpida	doc_901133458165_item	3649261	et	4	main
lemmiktegevus	doc_901133458165_item	3649259	et	4	main
minu	doc_901133458165_item	3649258	et	3	main
reisima	doc_901133458165_item	3649257	et	3	main
jaa	doc_901133458165_item	3649249	et	3	main
koeraga	doc_901133458165_item	3649248	et	3	main
jalutan	doc_901133458165_item	3649247	et	3	main
raamatud	doc_901133458165_item	3649246	et	4	main
lugeda	doc_901133458165_item	3649245	et	3	main
on	doc_901133458165_item	3649234	et	4	main
sul	doc_901133458165_item	3649229	et	3	main
teha	doc_901133458165_item	3649227	et	3	main
vabal	doc_901133458165_item	3649225	et	3	main
meeldib	doc_901133458165_item	3649224	et	3	main
mida	doc_901133458165_item	3649222	et	4	main
sadamas	doc_901133458165_item	3649213	et	4	main
narva	doc_901133458165_item	3649205	et	4	main
töötab	doc_901133458165_item	3649203	et	3	main
minu	doc_901133458165_item	3649201	et	3	main
mina	doc_901133458165_item	3649200	et	4	main
ja	doc_901133458165_item	3649199	et	3	main
poeg	doc_901133458165_item	3649198	et	3	main
last	doc_901133458165_item	3649195	et	4	main
tuba	doc_901133458165_item	3649161	et	4	main
köök	doc_901133458165_item	3649158	et	3	main
esik	doc_901133458165_item	3649156	et	3	main
minu	doc_901133458165_item	3649148	et	3	main
korteris	doc_901133458165_item	3649147	et	3	main
kolmetoalises	doc_901133458165_item	3649146	et	4	main
elan	doc_901133458165_item	3649145	et	3	main
ma	doc_901133458165_item	3649144	et	3	main
ja	doc_901133458165_item	3649134	et	3	main
sinu	doc_901133458165_item	3649132	et	3	main
on	doc_901133458165_item	3649131	et	4	main
missugune	doc_901133458165_item	3649130	et	3	main
ääres	doc_901133458166_item	3649408	et	4	main
kooki	doc_901133458166_item	3649402	et	4	main
mingeid	doc_901133458166_item	3649384	et	3	main
laheb	doc_901133458166_item	3649369	et	4	main
töötab	doc_901133458166_item	3649362	et	3	main
ja	doc_901133458166_item	3649356	et	3	main
ja	doc_901133458163_item	3648786	et	3	main
sinu	doc_901133458163_item	3648784	et	3	main
missugune	doc_901133458163_item	3648782	et	3	main
huvitavat	doc_901133458163_item	3648781	et	4	main
ajal	doc_901133458164_item	3649074	et	4	main
3	doc_901133458164_item	3649069	et	2	main
rootsile	doc_901133458164_item	3649068	et	3	main
suvel	doc_901133458164_item	3649064	et	3	main
ilusane	doc_901133458164_item	3649047	et	4	main
üksi	doc_901133458164_item	3649043	et	4	main
ma	doc_901133458164_item	3649041	et	3	main
on	doc_901133458164_item	3649031	et	4	main
perekond	doc_901133458164_item	3649024	et	3	main
on	doc_901133458164_item	3648982	et	4	main
suvel	doc_901133458164_item	3648981	et	3	main
oma	doc_901133458164_item	3648957	et	4	main
küsimusele	doc_901133458164_item	3648950	et	4	main
suvel	doc_901133458164_item	3649107	et	3	main
jalutada	doc_901133458164_item	3649104	et	3	main
on	doc_901133458164_item	3649099	et	4	main
ma	doc_901133458165_item	3649265	et	3	main
eestikelt	doc_901133458165_item	3649262	et	4	main
on	doc_901133458165_item	3649260	et	4	main
meeldib	doc_901133458165_item	3649254	et	3	main
mulle	doc_901133458165_item	3649253	et	4	main
hobisid	doc_901133458165_item	3649252	et	3	main
puhkad	doc_901133458165_item	3649240	et	3	main
suvel	doc_901133458165_item	3649239	et	3	main
sa	doc_901133458165_item	3649238	et	3	main
kus	doc_901133458165_item	3649237	et	3	main
lemmiktegevus	doc_901133458165_item	3649236	et	4	main
sinu	doc_901133458165_item	3649235	et	3	main
on	doc_901133458165_item	3649230	et	4	main
sulle	doc_901133458165_item	3649223	et	3	main
3	doc_901133458165_item	3649221	et	2	main
sportiga	doc_901133458165_item	3649220	et	4	main
tegeleb	doc_901133458165_item	3649219	et	3	main
töötab	doc_901133458165_item	3649212	et	3	main
leib	doc_901133458165_item	3649206	et	3	main
on	doc_901133458164_item	3649078	et	4	main
mingeid	doc_901133458164_item	3649079	et	3	main
sul	doc_901133458164_item	3649077	et	3	main
ja	doc_901133458164_item	3649061	et	3	main
elan	doc_901133458164_item	3649042	et	3	main
tegelevad	doc_901133458164_item	3649026	et	4	main
sinu	doc_901133458164_item	3649023	et	3	main
on	doc_901133458164_item	3649022	et	4	main
milline	doc_901133458164_item	3649021	et	3	main
2	doc_901133458164_item	3649020	et	2	main
korter	doc_901133458164_item	3649019	et	3	main
toaline	doc_901133458164_item	3649018	et	4	main
kolme	doc_901133458164_item	3649017	et	4	main
on	doc_901133458164_item	3649016	et	4	main
mul	doc_901133458164_item	3649015	et	3	main
korter	doc_901133458164_item	3649014	et	3	main
suur	doc_901133458164_item	3649013	et	3	main
on	doc_901133458164_item	3649012	et	4	main
mul	doc_901133458164_item	3649011	et	3	main
hasti	doc_901133458164_item	3649010	et	4	main
vaga	doc_901133458164_item	3649009	et	4	main
ja	doc_901133458164_item	3649008	et	3	main
ilus	doc_901133458164_item	3649007	et	4	main
on	doc_901133458164_item	3649006	et	4	main
seal	doc_901133458164_item	3649005	et	4	main
kesklinnas	doc_901133458164_item	3649004	et	4	main
elan	doc_901133458164_item	3649003	et	3	main
ma	doc_901133458164_item	3649002	et	3	main
kunstigalerii	doc_901133458164_item	3649001	et	4	main
on	doc_901133458164_item	3649000	et	4	main
tänaval	doc_901133458164_item	3648999	et	4	main
vestervali	doc_901133458164_item	3648998	et	4	main
liiv	doc_901133458164_item	3648997	et	3	main
saksa	doc_901133458164_item	3648996	et	4	main
monument	doc_901133458164_item	3648995	et	3	main
on	doc_901133458164_item	3648994	et	4	main
narvas	doc_901133458164_item	3648993	et	4	main
puhkab	doc_901133458164_item	3648992	et	3	main
kindlus	doc_901133458164_item	3648991	et	4	main
suvel	doc_901133458164_item	3648990	et	3	main
meeldib	doc_901133458164_item	3648989	et	3	main
ka	doc_901133458164_item	3648987	et	3	main
turiste	doc_901133458164_item	3648986	et	3	main
palju	doc_901133458164_item	3648985	et	4	main
alati	doc_901133458164_item	3648984	et	4	main
aga	doc_901133458164_item	3648979	et	3	main
linn	doc_901133458164_item	3648977	et	3	main
ilus	doc_901133458164_item	3648978	et	4	main
meie	doc_901133458164_item	3648976	et	4	main
kindluses	doc_901133458164_item	3648975	et	4	main
on	doc_901133458164_item	3648974	et	4	main
ajaloomuuseum	doc_901133458164_item	3648973	et	3	main
kodulinnas	doc_901133458164_item	3648972	et	4	main
meelib	doc_901133458164_item	3648971	et	4	main
mulle	doc_901133458164_item	3648970	et	4	main
koduümbrus	doc_901133458164_item	3648969	et	3	main
ja	doc_901133458164_item	3648968	et	3	main
kodu	doc_901133458164_item	3648967	et	4	main
sinu	doc_901133458164_item	3648966	et	3	main
on	doc_901133458164_item	3648965	et	4	main
missugune	doc_901133458164_item	3648964	et	3	main
kodulinnast	doc_901133458164_item	3648958	et	4	main
mulle	doc_901133458164_item	3649102	et	4	main
küpsetada	doc_901133458164_item	3649100	et	3	main
hobi	doc_901133458164_item	3649098	et	4	main
mul	doc_901133458164_item	3649097	et	3	main
telerit	doc_901133458164_item	3649096	et	3	main
vaadata	doc_901133458164_item	3649095	et	4	main
ja	doc_901133458164_item	3649094	et	3	main
teha	doc_901133458164_item	3649093	et	3	main
süüa	doc_901133458164_item	3649092	et	3	main
jalutada	doc_901133458164_item	3649091	et	3	main
meeldib	doc_901133458164_item	3649090	et	3	main
mulle	doc_901133458164_item	3649089	et	4	main
puhkad	doc_901133458164_item	3649088	et	3	main
suvel	doc_901133458164_item	3649087	et	3	main
inglisekelt	doc_901133458165_item	3649264	et	4	main
on	doc_901133458165_item	3649251	et	4	main
mul	doc_901133458165_item	3649250	et	3	main
mis	doc_901133458165_item	3649233	et	4	main
hobisid	doc_901133458165_item	3649232	et	3	main
elab	doc_901133458165_item	3649209	et	3	main
abikaasa	doc_901133458165_item	3649202	et	4	main
minu	doc_901133458165_item	3649192	et	3	main
inemest	doc_901133458165_item	3649191	et	4	main
neli	doc_901133458165_item	3649190	et	3	main
keskmine	doc_901133458165_item	3649189	et	3	main
on	doc_901133458165_item	3649188	et	4	main
perekond	doc_901133458165_item	3649187	et	3	main
minu	doc_901133458165_item	3649186	et	3	main
pereliikmed	doc_901133458165_item	3649185	et	3	main
sinu	doc_901133458165_item	3649184	et	3	main
tegelevad	doc_901133458165_item	3649183	et	4	main
millega	doc_901133458165_item	3649182	et	3	main
perekond	doc_901133458165_item	3649181	et	3	main
sinu	doc_901133458165_item	3649180	et	3	main
on	doc_901133458165_item	3649179	et	4	main
milline	doc_901133458165_item	3649178	et	3	main
2	doc_901133458165_item	3649177	et	2	main
lasteaed	doc_901133458165_item	3649176	et	3	main
kool	doc_901133458165_item	3649175	et	4	main
baar	doc_901133458165_item	3649173	et	3	main
kohvik	doc_901133458165_item	3649172	et	3	main
juuksur	doc_901133458165_item	3649171	et	3	main
staadion	doc_901133458165_item	3649174	et	3	main
saun	doc_901133458165_item	3649170	et	3	main
postkontor	doc_901133458165_item	3649169	et	3	main
apteek	doc_901133458165_item	3649168	et	3	main
pood	doc_901133458165_item	3649167	et	4	main
eraldi	doc_901133458165_item	3649151	et	4	main
palju	doc_901133458165_item	3649142	et	4	main
huvitavat	doc_901133458165_item	3649139	et	4	main
kodulinnas	doc_901133458165_item	3649137	et	4	main
minu	doc_901133458165_item	3649136	et	3	main
koduümbrus	doc_901133458165_item	3649135	et	3	main
kodu	doc_901133458165_item	3649133	et	4	main
mis	doc_901133458165_item	3649125	et	4	main
ma	doc_901133458166_item	3649409	et	3	main
ma	doc_901133458166_item	3649405	et	3	main
kuulata	doc_901133458166_item	3649403	et	4	main
küpsetada	doc_901133458166_item	3649401	et	3	main
lemmiktegevus	doc_901133458166_item	3649389	et	4	main
sinu	doc_901133458166_item	3649388	et	3	main
on	doc_901133458166_item	3649387	et	4	main
sul	doc_901133458166_item	3649382	et	3	main
tütar	doc_901133458166_item	3649368	et	3	main
servis	doc_901133458166_item	3649364	et	4	main
abikassa	doc_901133458166_item	3649361	et	4	main
on	doc_901133458166_item	3649359	et	4	main
tütar	doc_901133458166_item	3649357	et	3	main
last	doc_901133458166_item	3649354	et	4	main
on	doc_901133458166_item	3649349	et	4	main
kõrval	doc_901133458166_item	3649331	et	4	main
ajal	doc_901133458165_item	3649226	et	4	main
ja	doc_901133458165_item	3649218	et	3	main
koolis	doc_901133458165_item	3649217	et	4	main
ja	doc_901133458165_item	3649211	et	3	main
minu	doc_901133458165_item	3649207	et	3	main
as	doc_901133458165_item	3649204	et	4	main
tütar	doc_901133458165_item	3649196	et	3	main
kaks	doc_901133458165_item	3649194	et	3	main
suur	doc_901133458165_item	3649160	et	3	main
on	doc_901133458165_item	3649150	et	4	main
korteris	doc_901133458165_item	3649149	et	3	main
jõgi	doc_901133458165_item	3649141	et	3	main
kodulinnas	doc_901133458165_item	3649128	et	4	main
on	doc_901133458165_item	3649126	et	4	main
lähen	doc_901133458166_item	3649410	et	3	main
puhkan	doc_901133458166_item	3649406	et	3	main
puhkad	doc_901133458166_item	3649393	et	3	main
suvel	doc_901133458166_item	3649392	et	3	main
sa	doc_901133458166_item	3649391	et	3	main
kus	doc_901133458166_item	3649390	et	3	main
on	doc_901133458166_item	3649383	et	4	main
ajal	doc_901133458166_item	3649379	et	4	main
meeldib	doc_901133458166_item	3649377	et	3	main
mida	doc_901133458166_item	3649375	et	4	main
kursusel	doc_901133458166_item	3649373	et	3	main
koolis	doc_901133458166_item	3649367	et	4	main
õppib	doc_901133458166_item	3649366	et	4	main
abielus	doc_901133458166_item	3649350	et	4	main
maja	doc_901133458166_item	3649333	et	4	main
asub	doc_901133458166_item	3649332	et	3	main
pood	doc_901133458166_item	3649328	et	4	main
2	doc_901133458166_item	3649310	et	2	main
suur	doc_901133458166_item	3649308	et	3	main
on	doc_901133458166_item	3649307	et	4	main
linnas	doc_901133458166_item	3649306	et	4	main
narva	doc_901133458166_item	3649299	et	4	main
linn	doc_901133458166_item	3649298	et	3	main
asub	doc_901133458166_item	3649292	et	3	main
koduümbrus	doc_901133458166_item	3649290	et	3	main
kodu	doc_901133458166_item	3649288	et	4	main
sinu	doc_901133458166_item	3649287	et	3	main
on	doc_901133458166_item	3649286	et	4	main
missugune	doc_901133458166_item	3649285	et	3	main
huvitavat	doc_901133458166_item	3649284	et	4	main
tantsida	doc_901133458167_item	3649565	et	3	main
jalutada	doc_901133458167_item	3649560	et	3	main
tegeleda	doc_901133458167_item	3649556	et	3	main
suvel	doc_901133458167_item	3649551	et	3	main
sinu	doc_901133458167_item	3649547	et	3	main
teha	doc_901133458167_item	3649539	et	3	main
3	doc_901133458167_item	3649533	et	2	main
pereliikmed	doc_901133458167_item	3649484	et	3	main
ma	doc_901133458173_item	3649771	et	3	main
jalutan	doc_901133458173_item	3649759	et	3	main
maale	doc_901133458173_item	3649757	et	4	main
ma	doc_901133458173_item	3649755	et	3	main
hobbi	doc_901133458173_item	3649743	et	4	main
internetis	doc_901133458173_item	3649733	et	4	main
istuda	doc_901133458173_item	3649732	et	3	main
meeldivad	doc_901133458173_item	3649731	et	4	main
on	doc_901133458173_item	3649692	et	4	main
vana	doc_901133458173_item	3649689	et	4	main
on	doc_901133458173_item	3649686	et	4	main
on	doc_901133458173_item	3649679	et	4	main
poeg	doc_901133458173_item	3649674	et	3	main
minu	doc_901133458173_item	3649673	et	3	main
tegelevad	doc_901133458173_item	3649658	et	4	main
väga	doc_901133458173_item	3649650	et	3	main
minu	doc_901133458173_item	3649647	et	3	main
ma	doc_901133458173_item	3649641	et	3	main
on	doc_901133458173_item	3649634	et	4	main
linn	doc_901133458173_item	3649633	et	3	main
minu	doc_901133458173_item	3649632	et	3	main
korteris	doc_901133458173_item	3649631	et	3	main
narva	doc_901133458173_item	3649609	et	4	main
narvas	doc_901133458173_item	3649608	et	4	main
elan	doc_901133458173_item	3649607	et	3	main
ma	doc_901133458173_item	3649606	et	3	main
koduümbrus	doc_901133458173_item	3649605	et	3	main
ja	doc_901133458173_item	3649604	et	3	main
on	doc_901133458173_item	3649596	et	4	main
oma	doc_901133458173_item	3649593	et	4	main
midagi	doc_901133458173_item	3649592	et	4	main
ja	doc_901133458165_item	3649197	et	3	main
abikaasa	doc_901133458165_item	3649193	et	4	main
majas	doc_901133458165_item	3649164	et	3	main
lastetuba	doc_901133458165_item	3649162	et	4	main
suur	doc_901133458165_item	3649155	et	3	main
tualettiruum	doc_901133458165_item	3649154	et	4	main
ja	doc_901133458165_item	3649153	et	3	main
vannituba	doc_901133458165_item	3649152	et	4	main
lossi	doc_901133458165_item	3649140	et	4	main
on	doc_901133458165_item	3649138	et	4	main
sinu	doc_901133458165_item	3649127	et	3	main
asub	doc_901133458165_item	3649166	et	3	main
juures	doc_901133458165_item	3649165	et	4	main
minu	doc_901133458165_item	3649163	et	3	main
magamistuba	doc_901133458165_item	3649159	et	4	main
rõdu	doc_901133458165_item	3649157	et	4	main
roheluse	doc_901133458165_item	3649143	et	3	main
huvitavat	doc_901133458165_item	3649129	et	4	main
kodulinnast	doc_901133458165_item	3649124	et	4	main
oma	doc_901133458165_item	3649123	et	4	main
midagi	doc_901133458165_item	3649122	et	4	main
kirjuta	doc_901133458165_item	3649121	et	4	main
1	doc_901133458165_item	3649120	et	2	main
küsimustele	doc_901133458165_item	3649119	et	4	main
järgmistele	doc_901133458165_item	3649118	et	3	main
vasta	doc_901133458165_item	3649117	et	4	main
küsimusele	doc_901133458165_item	3649116	et	4	main
vastus	doc_901133458165_item	3649115	et	3	main
maale	doc_901133458166_item	3649411	et	4	main
muusikat	doc_901133458166_item	3649404	et	3	main
ja	doc_901133458166_item	3649400	et	3	main
lapsega	doc_901133458166_item	3649399	et	3	main
mängida	doc_901133458166_item	3649398	et	3	main
raamatud	doc_901133458166_item	3649397	et	4	main
lugeda	doc_901133458166_item	3649396	et	3	main
meeldil	doc_901133458166_item	3649395	et	4	main
mis	doc_901133458166_item	3649386	et	4	main
hobisid	doc_901133458166_item	3649385	et	3	main
teha	doc_901133458166_item	3649380	et	3	main
vabal	doc_901133458166_item	3649378	et	3	main
kreenholm	doc_901133458166_item	3649363	et	4	main
koer	doc_901133458166_item	3649360	et	3	main
mul	doc_901133458166_item	3649358	et	3	main
poeg	doc_901133458166_item	3649355	et	3	main
2	doc_901133458166_item	3649353	et	2	main
on	doc_901133458166_item	3649352	et	4	main
mul	doc_901133458166_item	3649351	et	3	main
suur	doc_901133458166_item	3649346	et	3	main
on	doc_901133458166_item	3649345	et	4	main
pereliikmed	doc_901133458166_item	3649343	et	3	main
sinu	doc_901133458166_item	3649342	et	3	main
sinu	doc_901133458166_item	3649338	et	3	main
on	doc_901133458166_item	3649337	et	4	main
milline	doc_901133458166_item	3649336	et	3	main
astri-narva	doc_901133458166_item	3649329	et	4	main
jõe	doc_901133458166_item	3649407	et	3	main
mulle	doc_901133458166_item	3649394	et	4	main
kas	doc_901133458166_item	3649381	et	3	main
sulle	doc_901133458166_item	3649376	et	3	main
3	doc_901133458166_item	3649374	et	2	main
lahen	doc_901133458166_item	3649372	et	4	main
mina	doc_901133458166_item	3649371	et	4	main
lasteajas	doc_901133458166_item	3649370	et	3	main
poeg	doc_901133458166_item	3649365	et	3	main
pere	doc_901133458166_item	3649347	et	4	main
mul	doc_901133458166_item	3649344	et	3	main
tegelevad	doc_901133458166_item	3649341	et	4	main
perekond	doc_901133458166_item	3649339	et	3	main
on	doc_901133458166_item	3649330	et	4	main
puud	doc_901133458166_item	3649327	et	4	main
korrusel	doc_901133458166_item	3649323	et	3	main
5	doc_901133458166_item	3649322	et	2	main
koduümbris	doc_901133458166_item	3649324	et	3	main
elan	doc_901133458166_item	3649321	et	3	main
ma	doc_901133458166_item	3649320	et	3	main
suur	doc_901133458166_item	3649319	et	3	main
on	doc_901133458166_item	3649318	et	4	main
maja	doc_901133458166_item	3649317	et	4	main
maanteel	doc_901133458166_item	3649316	et	3	main
tallinna	doc_901133458166_item	3649315	et	4	main
elan	doc_901133458166_item	3649314	et	3	main
ma	doc_901133458166_item	3649313	et	3	main
ajaloomuuseum	doc_901133458166_item	3649312	et	3	main
pargi	doc_901133458166_item	3649311	et	4	main
on	doc_901133458166_item	3649296	et	4	main
see	doc_901133458166_item	3649295	et	3	main
eestis	doc_901133458166_item	3649294	et	3	main
juunis	doc_901133458167_item	3649575	et	3	main
minu	doc_901133458167_item	3649567	et	3	main
õmmelda	doc_901133458167_item	3649561	et	4	main
laulda	doc_901133458167_item	3649555	et	4	main
kus	doc_901133458167_item	3649549	et	3	main
mis	doc_901133458167_item	3649545	et	4	main
on	doc_901133458167_item	3649542	et	4	main
vabal	doc_901133458167_item	3649537	et	3	main
peterburgas	doc_901133458167_item	3649532	et	4	main
elavad	doc_901133458167_item	3649530	et	4	main
on	doc_901133458167_item	3649526	et	4	main
on	doc_901133458167_item	3649486	et	4	main
mul	doc_901133458166_item	3649348	et	3	main
millega	doc_901133458166_item	3649340	et	3	main
2	doc_901133458166_item	3649335	et	2	main
juures	doc_901133458166_item	3649334	et	4	main
on	doc_901133458166_item	3649325	et	4	main
roheline	doc_901133458166_item	3649305	et	4	main
ilus	doc_901133458166_item	3649297	et	4	main
ma	doc_901133458167_item	3649572	et	3	main
reisida	doc_901133458167_item	3649566	et	3	main
küpsetada	doc_901133458167_item	3649562	et	3	main
pereda	doc_901133458167_item	3649557	et	4	main
puhkad	doc_901133458167_item	3649552	et	3	main
sa	doc_901133458167_item	3649550	et	3	main
on	doc_901133458167_item	3649546	et	4	main
ajal	doc_901133458167_item	3649538	et	4	main
mida	doc_901133458167_item	3649534	et	4	main
sankt	doc_901133458167_item	3649531	et	4	main
on	doc_901133458167_item	3649490	et	4	main
mul	doc_901133458167_item	3649489	et	3	main
perekond	doc_901133458167_item	3649488	et	3	main
väike	doc_901133458167_item	3649487	et	4	main
lilled	doc_901133458173_item	3649773	et	3	main
supelda	doc_901133458173_item	3649770	et	4	main
ma	doc_901133458173_item	3649758	et	3	main
floristika	doc_901133458173_item	3649751	et	4	main
taimid	doc_901133458173_item	3649750	et	3	main
on	doc_901133458173_item	3649744	et	4	main
jalatada	doc_901133458173_item	3649740	et	4	main
mulle	doc_901133458173_item	3649730	et	4	main
lemmiktegevus	doc_901133458173_item	3649725	et	4	main
sinu	doc_901133458173_item	3649724	et	3	main
hobisid	doc_901133458173_item	3649721	et	3	main
on	doc_901133458173_item	3649719	et	4	main
kaheksateist	doc_901133458173_item	3649687	et	4	main
õpilane	doc_901133458173_item	3649680	et	3	main
eesnimi	doc_901133458173_item	3649678	et	3	main
palju	doc_901133458166_item	3649326	et	4	main
kindlus	doc_901133458166_item	3649309	et	4	main
ääres	doc_901133458166_item	3649302	et	4	main
jõe	doc_901133458166_item	3649301	et	3	main
asub	doc_901133458166_item	3649300	et	3	main
kirde	doc_901133458166_item	3649293	et	4	main
päevitan	doc_901133458167_item	3649574	et	3	main
seiping	doc_901133458167_item	3649570	et	4	main
hobbi	doc_901133458167_item	3649568	et	4	main
teha	doc_901133458167_item	3649564	et	3	main
mängida	doc_901133458167_item	3649558	et	3	main
meeldib	doc_901133458167_item	3649554	et	3	main
lemmiktegevus	doc_901133458167_item	3649548	et	4	main
mingeid	doc_901133458167_item	3649543	et	3	main
kas	doc_901133458167_item	3649540	et	3	main
meeldib	doc_901133458167_item	3649536	et	3	main
nad	doc_901133458167_item	3649529	et	3	main
ukrainast	doc_901133458167_item	3649528	et	4	main
parit	doc_901133458167_item	3649527	et	4	main
mulle	doc_901133458173_item	3649768	et	4	main
mul	doc_901133458173_item	3649765	et	3	main
puhkan	doc_901133458173_item	3649756	et	3	main
suvel	doc_901133458173_item	3649754	et	3	main
meeldivad	doc_901133458173_item	3649747	et	4	main
mulle	doc_901133458173_item	3649746	et	4	main
muusikat	doc_901133458173_item	3649739	et	3	main
raamatud	doc_901133458173_item	3649737	et	4	main
telerik	doc_901133458173_item	3649735	et	4	main
vaatada	doc_901133458173_item	3649734	et	4	main
mis	doc_901133458173_item	3649722	et	4	main
mingeid	doc_901133458173_item	3649720	et	3	main
sul	doc_901133458173_item	3649718	et	3	main
parit	doc_901133458173_item	3649693	et	4	main
vanemad	doc_901133458173_item	3649691	et	4	main
koolis	doc_901133458173_item	3649684	et	4	main
pähklimäe	doc_901133458173_item	3649683	et	3	main
elab	doc_901133458173_item	3649676	et	3	main
ritšard	doc_901133458173_item	3649672	et	2	main
on	doc_901133458173_item	3649670	et	4	main
eesnimi	doc_901133458173_item	3649668	et	3	main
millega	doc_901133458173_item	3649657	et	3	main
on	doc_901133458173_item	3649649	et	4	main
linn	doc_901133458173_item	3649648	et	3	main
ääres	doc_901133458173_item	3649640	et	4	main
x-y	doc_901133458173_item	3649627	et	4	main
on	doc_901133458173_item	3649601	et	4	main
missugune	doc_901133458173_item	3649600	et	3	main
mis	doc_901133458173_item	3649595	et	4	main
vasta	doc_901133458173_item	3649587	et	4	main
sinu	doc_901133458167_item	3649479	et	3	main
milline	doc_901133458167_item	3649477	et	3	main
monumentit	doc_901133458167_item	3649475	et	4	main
kindluses	doc_901133458167_item	3649474	et	4	main
meil	doc_901133458167_item	3649449	et	4	main
on	doc_901133458167_item	3649446	et	4	main
narvas	doc_901133458167_item	3649438	et	4	main
vasta	doc_901133458167_item	3649416	et	4	main
küsimusele	doc_901133458167_item	3649415	et	4	main
vastus	doc_901133458167_item	3649414	et	3	main
olen	doc_901133458167_item	3649506	et	3	main
on	doc_901133458166_item	3649304	et	4	main
narva	doc_901133458166_item	3649303	et	4	main
narva	doc_901133458166_item	3649291	et	4	main
ja	doc_901133458166_item	3649289	et	3	main
kodulinnas	doc_901133458166_item	3649283	et	4	main
sinu	doc_901133458166_item	3649282	et	3	main
on	doc_901133458166_item	3649281	et	4	main
mis	doc_901133458166_item	3649280	et	4	main
kodulinnast	doc_901133458166_item	3649279	et	4	main
oma	doc_901133458166_item	3649278	et	4	main
midagi	doc_901133458166_item	3649277	et	4	main
kirjuta	doc_901133458166_item	3649276	et	4	main
1	doc_901133458166_item	3649275	et	2	main
küsimustele	doc_901133458166_item	3649274	et	4	main
järgmistele	doc_901133458166_item	3649273	et	3	main
vasta	doc_901133458166_item	3649272	et	4	main
küsimusele	doc_901133458166_item	3649271	et	4	main
vastus	doc_901133458166_item	3649270	et	3	main
marju	doc_901133458167_item	3649582	et	3	main
korjan	doc_901133458167_item	3649581	et	3	main
ma	doc_901133458167_item	3649580	et	3	main
juulis	doc_901133458167_item	3649579	et	3	main
praktikal	doc_901133458167_item	3649578	et	3	main
ma	doc_901133458167_item	3649576	et	3	main
olen	doc_901133458167_item	3649577	et	3	main
puhkan	doc_901133458167_item	3649573	et	3	main
suvel	doc_901133458167_item	3649571	et	3	main
on	doc_901133458167_item	3649569	et	4	main
süüa	doc_901133458167_item	3649563	et	3	main
lapsega	doc_901133458167_item	3649559	et	3	main
mulle	doc_901133458167_item	3649553	et	4	main
hobisid	doc_901133458167_item	3649544	et	3	main
sul	doc_901133458167_item	3649541	et	3	main
sulle	doc_901133458167_item	3649535	et	3	main
vanemad	doc_901133458167_item	3649525	et	4	main
minu	doc_901133458167_item	3649524	et	3	main
sugulasi	doc_901133458167_item	3649523	et	3	main
palju	doc_901133458167_item	3649522	et	4	main
on	doc_901133458167_item	3649521	et	4	main
mul	doc_901133458167_item	3649520	et	3	main
es	doc_901133458167_item	3649519	et	4	main
balti	doc_901133458167_item	3649518	et	3	main
töötad	doc_901133458167_item	3649517	et	3	main
ta	doc_901133458167_item	3649516	et	4	main
aastat	doc_901133458167_item	3649515	et	3	main
32	doc_901133458167_item	3649514	et	2	main
ta	doc_901133458167_item	3649513	et	4	main
eesnimi	doc_901133458167_item	3649512	et	3	main
nimi	doc_901133458167_item	3649511	et	3	main
abikasa	doc_901133458167_item	3649510	et	4	main
minu	doc_901133458167_item	3649509	et	3	main
aastat	doc_901133458167_item	3649508	et	3	main
6	doc_901133458167_item	3649507	et	2	main
lauldab	doc_901133458167_item	3649504	et	4	main
tegelevad	doc_901133458167_item	3649503	et	4	main
ta	doc_901133458167_item	3649502	et	4	main
lasteaeg	doc_901133458167_item	3649501	et	3	main
lähed	doc_901133458167_item	3649500	et	3	main
ta	doc_901133458167_item	3649499	et	4	main
eesnimi	doc_901133458167_item	3649498	et	3	main
nimi	doc_901133458167_item	3649497	et	3	main
tütar	doc_901133458167_item	3649496	et	3	main
minu	doc_901133458167_item	3649495	et	3	main
mees	doc_901133458167_item	3649494	et	4	main
ja	doc_901133458167_item	3649493	et	3	main
tütar	doc_901133458167_item	3649492	et	3	main
1	doc_901133458167_item	3649491	et	2	main
mul	doc_901133458167_item	3649485	et	3	main
sinu	doc_901133458167_item	3649483	et	3	main
suvilasse	doc_901133458173_item	3649767	et	4	main
on	doc_901133458173_item	3649766	et	4	main
metsesse	doc_901133458173_item	3649760	et	3	main
lemmiktegevus	doc_901133458173_item	3649753	et	4	main
on	doc_901133458173_item	3649752	et	4	main
floristika	doc_901133458173_item	3649745	et	4	main
koeraga	doc_901133458173_item	3649741	et	3	main
on	doc_901133458173_item	3649723	et	4	main
ta	doc_901133458173_item	3649685	et	4	main
s-peterburis	doc_901133458173_item	3649677	et	4	main
perekond	doc_901133458173_item	3649656	et	3	main
milline	doc_901133458173_item	3649653	et	3	main
kodu	doc_901133458173_item	3649646	et	4	main
kodulinn	doc_901133458173_item	3649644	et	3	main
minu	doc_901133458173_item	3649643	et	3	main
armastan	doc_901133458173_item	3649642	et	3	main
kolmetoalises	doc_901133458173_item	3649630	et	4	main
huvitavat	doc_901133458173_item	3649599	et	4	main
küsimustele	doc_901133458173_item	3649589	et	4	main
järgmistele	doc_901133458173_item	3649588	et	3	main
tegelevad	doc_901133458167_item	3649482	et	4	main
millega	doc_901133458167_item	3649481	et	3	main
2	doc_901133458167_item	3649476	et	2	main
lillid	doc_901133458167_item	3649453	et	3	main
palju	doc_901133458167_item	3649451	et	4	main
kasvavad	doc_901133458167_item	3649450	et	4	main
narva	doc_901133458167_item	3649439	et	4	main
sinu	doc_901133458167_item	3649431	et	3	main
kodulinnas	doc_901133458167_item	3649427	et	4	main
oma	doc_901133458167_item	3649422	et	4	main
kõik	doc_901133458174_item	3649931	et	4	main
päevitada	doc_901133458174_item	3649930	et	3	main
ja	doc_901133458174_item	3649929	et	3	main
ujuda	doc_901133458174_item	3649928	et	3	main
saab	doc_901133458174_item	3649927	et	3	main
suve	doc_901133458174_item	3649921	et	4	main
meeldib	doc_901133458174_item	3649920	et	3	main
toalille	doc_901133458174_item	3649916	et	4	main
laulda	doc_901133458174_item	3649912	et	4	main
hobisid	doc_901133458174_item	3649898	et	3	main
sul	doc_901133458174_item	3649895	et	3	main
ajal	doc_901133458174_item	3649892	et	4	main
elektrijaamas	doc_901133458174_item	3649886	et	3	main
balti	doc_901133458174_item	3649885	et	3	main
eesnimi	doc_901133458174_item	3649879	et	3	main
eesnimi	doc_901133458174_item	3649876	et	3	main
abielus	doc_901133458174_item	3649861	et	4	main
olen	doc_901133458174_item	3649860	et	3	main
ma	doc_901133458174_item	3649859	et	3	main
pereliikmed	doc_901133458174_item	3649858	et	3	main
sinu	doc_901133458174_item	3649857	et	3	main
tegelevad	doc_901133458174_item	3649856	et	4	main
millega	doc_901133458174_item	3649855	et	3	main
2	doc_901133458174_item	3649850	et	2	main
käime	doc_901133458174_item	3649847	et	4	main
oma	doc_901133458174_item	3649843	et	4	main
suhtlen	doc_901133458174_item	3649842	et	3	main
kasvatan	doc_901133458173_item	3649772	et	3	main
meeldivad	doc_901133458173_item	3649769	et	4	main
seeni	doc_901133458173_item	3649764	et	3	main
ja	doc_901133458173_item	3649763	et	3	main
marju	doc_901133458173_item	3649762	et	3	main
korjan	doc_901133458173_item	3649761	et	3	main
puud	doc_901133458173_item	3649749	et	4	main
lilled	doc_901133458173_item	3649748	et	3	main
minu	doc_901133458173_item	3649742	et	3	main
kuulata	doc_901133458173_item	3649738	et	4	main
lugeda	doc_901133458173_item	3649736	et	3	main
puhkad	doc_901133458173_item	3649729	et	3	main
suvel	doc_901133458173_item	3649728	et	3	main
sa	doc_901133458173_item	3649727	et	3	main
kus	doc_901133458173_item	3649726	et	3	main
kas	doc_901133458173_item	3649717	et	3	main
teha	doc_901133458173_item	3649716	et	3	main
ajal	doc_901133458173_item	3649715	et	4	main
vabal	doc_901133458173_item	3649714	et	3	main
meeldib	doc_901133458173_item	3649713	et	3	main
sulle	doc_901133458173_item	3649712	et	3	main
mida	doc_901133458173_item	3649711	et	4	main
3	doc_901133458173_item	3649710	et	2	main
last	doc_901133458173_item	3649709	et	4	main
kaks	doc_901133458173_item	3649708	et	3	main
on	doc_901133458173_item	3649707	et	4	main
tal	doc_901133458173_item	3649706	et	3	main
berliinis	doc_901133458173_item	3649705	et	4	main
elab	doc_901133458173_item	3649704	et	3	main
ta	doc_901133458173_item	3649703	et	4	main
õde	doc_901133458173_item	3649702	et	4	main
on	doc_901133458173_item	3649701	et	4	main
mul	doc_901133458173_item	3649700	et	3	main
narvas	doc_901133458173_item	3649699	et	4	main
elavad	doc_901133458173_item	3649698	et	4	main
nad	doc_901133458173_item	3649697	et	3	main
praegu	doc_901133458173_item	3649696	et	3	main
aga	doc_901133458173_item	3649695	et	3	main
venemaalt	doc_901133458173_item	3649694	et	3	main
minu	doc_901133458173_item	3649690	et	3	main
aastat	doc_901133458173_item	3649688	et	3	main
õpin	doc_901133458173_item	3649682	et	3	main
ta	doc_901133458173_item	3649681	et	4	main
eesnimi	doc_901133458173_item	3649675	et	3	main
mul	doc_901133458173_item	3649669	et	3	main
tütar	doc_901133458173_item	3649667	et	3	main
mina	doc_901133458173_item	3649665	et	4	main
sinu	doc_901133458173_item	3649655	et	3	main
ilus	doc_901133458173_item	3649651	et	4	main
minu	doc_901133458173_item	3649645	et	3	main
pargi	doc_901133458173_item	3649639	et	4	main
elan	doc_901133458173_item	3649638	et	3	main
ma	doc_901133458173_item	3649637	et	3	main
roheline	doc_901133458173_item	3649636	et	4	main
elan	doc_901133458173_item	3649629	et	3	main
kodu	doc_901133458173_item	3649603	et	4	main
sinu	doc_901133458173_item	3649602	et	3	main
kirjuta	doc_901133458173_item	3649591	et	4	main
1	doc_901133458173_item	3649590	et	2	main
on	doc_901133458167_item	3649473	et	4	main
maja	doc_901133458167_item	3649448	et	4	main
ääres	doc_901133458167_item	3649444	et	4	main
lemmiklinnast	doc_901133458167_item	3649441	et	4	main
minu	doc_901133458167_item	3649440	et	3	main
koduümbrus	doc_901133458167_item	3649434	et	3	main
on	doc_901133458167_item	3649430	et	4	main
huvitavat	doc_901133458167_item	3649428	et	4	main
sinu	doc_901133458167_item	3649426	et	3	main
mis	doc_901133458167_item	3649424	et	4	main
kodulinnast	doc_901133458167_item	3649423	et	4	main
midagi	doc_901133458167_item	3649421	et	4	main
kirjuta	doc_901133458167_item	3649420	et	4	main
eesnimi	doc_901133458167_item	3649505	et	3	main
ilus	doc_901133458174_item	3649926	et	4	main
on	doc_901133458174_item	3649925	et	4	main
ilm	doc_901133458174_item	3649924	et	3	main
pärast	doc_901133458174_item	3649923	et	4	main
kuulata	doc_901133458174_item	3649917	et	4	main
mida	doc_901133458174_item	3649888	et	4	main
on	doc_901133458174_item	3649867	et	4	main
eesnimi	doc_901133458174_item	3649866	et	3	main
perekond	doc_901133458174_item	3649854	et	3	main
elumajad	doc_901133458174_item	3649840	et	3	main
rajoonis	doc_901133458174_item	3649832	et	4	main
väga	doc_901133458174_item	3649823	et	3	main
oma	doc_901133458174_item	3649784	et	4	main
munu	doc_901133458176_item	3650074	et	4	main
lugeda	doc_901133458176_item	3650073	et	3	main
hobisid	doc_901133458176_item	3650069	et	3	main
külas	doc_901133458176_item	3650059	et	3	main
käia	doc_901133458176_item	3650058	et	4	main
on	doc_901133458176_item	3650046	et	4	main
ajal	doc_901133458176_item	3650038	et	4	main
sulle	doc_901133458176_item	3650035	et	3	main
teisel	doc_901133458176_item	3649997	et	4	main
aga	doc_901133458176_item	3649996	et	3	main
elan	doc_901133458176_item	3649990	et	3	main
ma	doc_901133458176_item	3649989	et	3	main
koer	doc_901133458173_item	3649671	et	3	main
ja	doc_901133458173_item	3649666	et	3	main
pere	doc_901133458173_item	3649664	et	4	main
vaike	doc_901133458173_item	3649663	et	3	main
on	doc_901133458173_item	3649662	et	4	main
mul	doc_901133458173_item	3649661	et	3	main
pereliikmed	doc_901133458173_item	3649660	et	3	main
sinu	doc_901133458173_item	3649659	et	3	main
on	doc_901133458173_item	3649654	et	4	main
2	doc_901133458173_item	3649652	et	2	main
vaga	doc_901133458173_item	3649635	et	4	main
ma	doc_901133458173_item	3649628	et	3	main
joala	doc_901133458173_item	3649626	et	4	main
on	doc_901133458173_item	3649625	et	4	main
aadress	doc_901133458173_item	3649624	et	3	main
kodune	doc_901133458173_item	3649623	et	4	main
minu	doc_901133458173_item	3649622	et	3	main
kunstigalerii	doc_901133458173_item	3649621	et	4	main
ja	doc_901133458173_item	3649620	et	3	main
ajaloomuuseum	doc_901133458173_item	3649619	et	3	main
loss	doc_901133458173_item	3649618	et	3	main
hermani	doc_901133458173_item	3649617	et	4	main
on	doc_901133458173_item	3649616	et	4	main
narvas	doc_901133458173_item	3649615	et	4	main
ääres	doc_901133458173_item	3649614	et	4	main
jõe	doc_901133458173_item	3649613	et	3	main
narova	doc_901133458173_item	3649612	et	4	main
ida-virumaal	doc_901133458173_item	3649611	et	4	main
asub	doc_901133458173_item	3649610	et	3	main
kodulinnas	doc_901133458173_item	3649598	et	4	main
sinu	doc_901133458173_item	3649597	et	3	main
kodulinnast	doc_901133458173_item	3649594	et	4	main
vastus	doc_901133458173_item	3649585	et	3	main
ajaloomuseum	doc_901133458167_item	3649472	et	4	main
mul	doc_901133458167_item	3649445	et	3	main
asubjoe	doc_901133458167_item	3649443	et	4	main
narva	doc_901133458167_item	3649442	et	4	main
ma	doc_901133458167_item	3649435	et	3	main
kodu	doc_901133458167_item	3649432	et	4	main
mulle	doc_901133458174_item	3649919	et	4	main
muusikat	doc_901133458174_item	3649918	et	3	main
küpsetada	doc_901133458174_item	3649913	et	3	main
mis	doc_901133458174_item	3649899	et	4	main
kas	doc_901133458174_item	3649894	et	3	main
meeldib	doc_901133458174_item	3649890	et	3	main
mees	doc_901133458174_item	3649883	et	4	main
koolis	doc_901133458174_item	3649881	et	4	main
on	doc_901133458174_item	3649872	et	4	main
eesnimi	doc_901133458174_item	3649871	et	3	main
aastat	doc_901133458174_item	3649869	et	3	main
on	doc_901133458174_item	3649852	et	4	main
pood	doc_901133458174_item	3649837	et	4	main
juures	doc_901133458174_item	3649835	et	4	main
üheksakorruselises	doc_901133458174_item	3649827	et	4	main
elan	doc_901133458174_item	3649826	et	3	main
ma	doc_901133458174_item	3649825	et	3	main
suvel	doc_901133458174_item	3649821	et	3	main
et	doc_901133458174_item	3649819	et	3	main
küsimustele	doc_901133458174_item	3649780	et	4	main
järgmistele	doc_901133458174_item	3649779	et	3	main
küsimusele	doc_901133458173_item	3649586	et	4	main
perekond	doc_901133458167_item	3649480	et	3	main
on	doc_901133458167_item	3649478	et	4	main
kuustigalerii	doc_901133458167_item	3649471	et	4	main
on	doc_901133458167_item	3649470	et	4	main
veel	doc_901133458167_item	3649469	et	4	main
bastionid	doc_901133458167_item	3649468	et	3	main
palju	doc_901133458167_item	3649467	et	4	main
hermani	doc_901133458167_item	3649466	et	4	main
kindlus	doc_901133458167_item	3649465	et	4	main
plats	doc_901133458167_item	3649464	et	4	main
raekoja	doc_901133458167_item	3649463	et	3	main
on	doc_901133458167_item	3649462	et	4	main
narvas	doc_901133458167_item	3649461	et	4	main
vaatamisväärsus	doc_901133458167_item	3649460	et	4	main
palju	doc_901133458167_item	3649459	et	4	main
on	doc_901133458167_item	3649458	et	4	main
narvas	doc_901133458167_item	3649457	et	4	main
õhk	doc_901133458167_item	3649456	et	3	main
värske	doc_901133458167_item	3649455	et	4	main
alati	doc_901133458167_item	3649454	et	4	main
puud	doc_901133458167_item	3649452	et	4	main
oma	doc_901133458167_item	3649447	et	4	main
sündinud	doc_901133458167_item	3649437	et	4	main
olen	doc_901133458167_item	3649436	et	3	main
ja	doc_901133458167_item	3649433	et	3	main
missugune	doc_901133458167_item	3649429	et	3	main
on	doc_901133458167_item	3649425	et	4	main
1	doc_901133458167_item	3649419	et	2	main
küsimustele	doc_901133458167_item	3649418	et	4	main
järgmistele	doc_901133458167_item	3649417	et	3	main
kasvatada	doc_901133458174_item	3649915	et	3	main
raamatut	doc_901133458174_item	3649911	et	3	main
mingeid	doc_901133458174_item	3649897	et	3	main
3	doc_901133458174_item	3649887	et	2	main
töötab	doc_901133458174_item	3649884	et	3	main
minu	doc_901133458174_item	3649882	et	3	main
õpib	doc_901133458174_item	3649880	et	3	main
õpib	doc_901133458174_item	3649877	et	3	main
vana	doc_901133458174_item	3649875	et	4	main
aastat	doc_901133458174_item	3649874	et	3	main
20	doc_901133458174_item	3649868	et	2	main
sinu	doc_901133458174_item	3649853	et	3	main
külas	doc_901133458174_item	3649849	et	3	main
ma	doc_901133458174_item	3649841	et	3	main
kool	doc_901133458174_item	3649839	et	4	main
lasteaed	doc_901133458174_item	3649838	et	3	main
asuvad	doc_901133458174_item	3649836	et	4	main
lihakombinati	doc_901133458174_item	3649831	et	4	main
korrusel	doc_901133458174_item	3649830	et	3	main
viiendal	doc_901133458174_item	3649829	et	3	main
majas	doc_901133458174_item	3649828	et	3	main
on	doc_901133458174_item	3649822	et	4	main
kirjuta	doc_901133458174_item	3649782	et	4	main
vasta	doc_901133458174_item	3649778	et	4	main
küsimusele	doc_901133458174_item	3649777	et	4	main
televiisorit	doc_901133458176_item	3650070	et	3	main
lõunat	doc_901133458176_item	3650060	et	3	main
hobisid	doc_901133458176_item	3650044	et	3	main
vabal	doc_901133458176_item	3650037	et	3	main
mida	doc_901133458176_item	3650034	et	4	main
3	doc_901133458176_item	3650033	et	2	main
lasteaias	doc_901133458176_item	3650032	et	4	main
käib	doc_901133458176_item	3650031	et	3	main
milline	doc_901133458176_item	3650004	et	3	main
ja	doc_901133458176_item	3650001	et	3	main
teatris	doc_901133458174_item	3649941	et	3	main
käia	doc_901133458174_item	3649940	et	4	main
sõbradega	doc_901133458174_item	3649939	et	4	main
suhelda	doc_901133458174_item	3649938	et	4	main
rohkem	doc_901133458174_item	3649937	et	4	main
kõige	doc_901133458174_item	3649936	et	4	main
mulle	doc_901133458174_item	3649934	et	4	main
õitsevad	doc_901133458174_item	3649933	et	4	main
meeldib	doc_901133458174_item	3649935	et	3	main
lilled	doc_901133458174_item	3649932	et	3	main
selle	doc_901133458174_item	3649922	et	4	main
kooki	doc_901133458174_item	3649914	et	4	main
lugeda	doc_901133458174_item	3649910	et	3	main
joonistada	doc_901133458174_item	3649909	et	3	main
meeldib	doc_901133458174_item	3649908	et	3	main
mulle	doc_901133458174_item	3649907	et	4	main
puhkad	doc_901133458174_item	3649906	et	3	main
suvel	doc_901133458174_item	3649905	et	3	main
sa	doc_901133458174_item	3649904	et	3	main
kus	doc_901133458174_item	3649903	et	3	main
lemmiktegevus	doc_901133458174_item	3649902	et	4	main
sinu	doc_901133458174_item	3649901	et	3	main
on	doc_901133458174_item	3649900	et	4	main
on	doc_901133458174_item	3649896	et	4	main
teha	doc_901133458174_item	3649893	et	3	main
vabal	doc_901133458174_item	3649891	et	3	main
sulle	doc_901133458174_item	3649889	et	3	main
s-peterburgis	doc_901133458174_item	3649878	et	4	main
18	doc_901133458174_item	3649873	et	2	main
vana	doc_901133458174_item	3649870	et	4	main
last	doc_901133458174_item	3649865	et	4	main
kaks	doc_901133458174_item	3649864	et	3	main
on	doc_901133458174_item	3649863	et	4	main
mul	doc_901133458174_item	3649862	et	3	main
milline	doc_901133458174_item	3649851	et	3	main
teineteisel	doc_901133458174_item	3649848	et	3	main
vestlime	doc_901133458174_item	3649846	et	4	main
me	doc_901133458174_item	3649845	et	4	main
naabritega	doc_901133458174_item	3649844	et	3	main
meie	doc_901133458174_item	3649833	et	4	main
midagi	doc_901133458174_item	3649783	et	4	main
raamatut	doc_901133458176_item	3650072	et	3	main
vaadata	doc_901133458176_item	3650071	et	4	main
on	doc_901133458176_item	3650068	et	4	main
mul	doc_901133458176_item	3650067	et	3	main
kuulata	doc_901133458176_item	3650066	et	4	main
teha	doc_901133458176_item	3650057	et	3	main
ajal	doc_901133458176_item	3650056	et	4	main
vabal	doc_901133458176_item	3650055	et	3	main
mingeid	doc_901133458176_item	3650043	et	3	main
on	doc_901133458176_item	3650042	et	4	main
kas	doc_901133458176_item	3650040	et	3	main
lasteaed	doc_901133458176_item	3650002	et	3	main
park	doc_901133458176_item	3650000	et	3	main
rahval	doc_491521502110_item	3650523	et	3	main
arendada	doc_491521502110_item	3650519	et	3	main
et	doc_491521502110_item	3650516	et	3	main
tähtsus	doc_491521502110_item	3650509	et	4	main
3	doc_491521502110_item	3650504	et	2	main
maja	doc_901133458174_item	3649834	et	4	main
roheline	doc_901133458174_item	3649824	et	4	main
narva	doc_901133458174_item	3649820	et	4	main
vastus	doc_901133458174_item	3649776	et	3	main
meeldib	doc_901133458174_item	3649818	et	3	main
mulle	doc_901133458174_item	3649817	et	4	main
kunstigaleri	doc_901133458174_item	3649816	et	4	main
bastioonid	doc_901133458174_item	3649815	et	4	main
veehoidla	doc_901133458174_item	3649814	et	4	main
pimeaed	doc_901133458174_item	3649813	et	3	main
kosed	doc_901133458174_item	3649812	et	3	main
jõgi	doc_901133458174_item	3649811	et	3	main
narva	doc_901133458174_item	3649810	et	4	main
loss	doc_901133458174_item	3649809	et	3	main
kindlus	doc_901133458174_item	3649808	et	4	main
hermanni	doc_901133458174_item	3649807	et	4	main
vaatamisvärtused	doc_901133458174_item	3649806	et	4	main
tööstuslinn	doc_901133458174_item	3649805	et	3	main
ja	doc_901133458174_item	3649804	et	3	main
piirilinn	doc_901133458174_item	3649803	et	3	main
on	doc_901133458174_item	3649802	et	4	main
narva	doc_901133458174_item	3649801	et	4	main
maakonnas	doc_901133458174_item	3649800	et	4	main
jola-virumaa	doc_901133458174_item	3649799	et	4	main
asub	doc_901133458174_item	3649798	et	3	main
narva	doc_901133458174_item	3649797	et	4	main
koduümbrus	doc_901133458174_item	3649796	et	3	main
ja	doc_901133458174_item	3649795	et	3	main
kodu	doc_901133458174_item	3649794	et	4	main
sinu	doc_901133458174_item	3649793	et	3	main
on	doc_901133458174_item	3649792	et	4	main
missugune	doc_901133458174_item	3649791	et	3	main
huvitavat	doc_901133458174_item	3649790	et	4	main
kodulinnas	doc_901133458174_item	3649789	et	4	main
sinu	doc_901133458174_item	3649788	et	3	main
on	doc_901133458174_item	3649787	et	4	main
mis	doc_901133458174_item	3649786	et	4	main
kodulinnast	doc_901133458174_item	3649785	et	4	main
1	doc_901133458174_item	3649781	et	2	main
ääres	doc_901133458176_item	3650063	et	4	main
mere	doc_901133458176_item	3650062	et	3	main
teha	doc_901133458176_item	3650061	et	3	main
mulle	doc_901133458176_item	3650053	et	4	main
mis	doc_901133458176_item	3650045	et	4	main
sul	doc_901133458176_item	3650041	et	3	main
teha	doc_901133458176_item	3650039	et	3	main
meeldib	doc_901133458176_item	3650036	et	3	main
2	doc_901133458176_item	3650003	et	2	main
on	doc_901133458176_item	3649999	et	4	main
pool	doc_901133458176_item	3649998	et	4	main
kesklinnas	doc_901133458176_item	3649991	et	4	main
korter	doc_901133458176_item	3649988	et	3	main
kahetoaline	doc_901133458176_item	3649987	et	4	main
väike	doc_901133458176_item	3649986	et	4	main
on	doc_901133458176_item	3649985	et	4	main
mul	doc_901133458176_item	3649984	et	3	main
vastus	doc_901133458176_item	3649944	et	3	main
ääres	doc_901133458176_item	3650083	et	4	main
mere	doc_901133458176_item	3650082	et	3	main
suvel	doc_901133458176_item	3650081	et	3	main
puhkan	doc_901133458176_item	3650080	et	3	main
ma	doc_901133458176_item	3650079	et	3	main
tort	doc_901133458176_item	3650078	et	3	main
küpsetama	doc_901133458176_item	3650077	et	4	main
lemmiktegevus	doc_901133458176_item	3650076	et	4	main
on	doc_901133458176_item	3650075	et	4	main
muusikat	doc_901133458176_item	3650065	et	3	main
puhata	doc_901133458176_item	3650064	et	4	main
meeldib	doc_901133458176_item	3650054	et	3	main
puhkad	doc_901133458176_item	3650052	et	3	main
suvel	doc_901133458176_item	3650051	et	3	main
sa	doc_901133458176_item	3650050	et	3	main
kus	doc_901133458176_item	3650049	et	3	main
lemmiktegevus	doc_901133458176_item	3650048	et	4	main
sinu	doc_901133458176_item	3650047	et	3	main
ta	doc_901133458176_item	3650030	et	4	main
vana	doc_901133458176_item	3650029	et	4	main
aastat	doc_901133458176_item	3650028	et	3	main
4	doc_901133458176_item	3650027	et	2	main
on	doc_901133458176_item	3650026	et	4	main
ta	doc_901133458176_item	3650025	et	4	main
eesnimi	doc_901133458176_item	3650024	et	3	main
on	doc_901133458176_item	3650023	et	4	main
nimi	doc_901133458176_item	3650022	et	3	main
tütar	doc_901133458176_item	3650021	et	3	main
minu	doc_901133458176_item	3650020	et	3	main
tütar	doc_901133458176_item	3650019	et	3	main
minu	doc_901133458176_item	3650018	et	3	main
ja	doc_901133458176_item	3650017	et	3	main
ma	doc_901133458176_item	3650016	et	3	main
väike	doc_901133458176_item	3650015	et	4	main
on	doc_901133458176_item	3650014	et	4	main
pere	doc_901133458176_item	3650013	et	4	main
minu	doc_901133458176_item	3650012	et	3	main
pereliikmed	doc_901133458176_item	3650011	et	3	main
sinu	doc_901133458176_item	3650010	et	3	main
tegelevad	doc_901133458176_item	3650009	et	4	main
millega	doc_901133458176_item	3650008	et	3	main
perekond	doc_901133458176_item	3650007	et	3	main
sinu	doc_901133458176_item	3650006	et	3	main
on	doc_901133458176_item	3650005	et	4	main
tänav	doc_901133458176_item	3649995	et	4	main
asub	doc_901133458176_item	3649994	et	3	main
pool	doc_901133458176_item	3649993	et	4	main
esimisel	doc_901133458176_item	3649992	et	4	main
korrusel	doc_901133458176_item	3649983	et	3	main
elan	doc_901133458176_item	3649981	et	3	main
kolmel	doc_901133458176_item	3649982	et	4	main
ma	doc_901133458176_item	3649980	et	3	main
kivimajas	doc_901133458176_item	3649979	et	4	main
nelikorruselises	doc_901133458176_item	3649978	et	4	main
elan	doc_901133458176_item	3649977	et	3	main
ma	doc_901133458176_item	3649976	et	3	main
loss	doc_901133458176_item	3649975	et	3	main
on	doc_901133458176_item	3649974	et	4	main
linnas	doc_901133458176_item	3649973	et	4	main
ajalugu	doc_901133458176_item	3649972	et	4	main
huvitav	doc_901133458176_item	3649971	et	4	main
on	doc_901133458176_item	3649970	et	4	main
linna	doc_901133458176_item	3649969	et	4	main
minu	doc_901133458176_item	3649968	et	3	main
narvas	doc_901133458176_item	3649967	et	4	main
elan	doc_901133458176_item	3649966	et	3	main
ma	doc_901133458176_item	3649965	et	3	main
koduümbrus	doc_901133458176_item	3649964	et	3	main
ja	doc_901133458176_item	3649963	et	3	main
kodu	doc_901133458176_item	3649962	et	4	main
sinu	doc_901133458176_item	3649961	et	3	main
on	doc_901133458176_item	3649960	et	4	main
missugune	doc_901133458176_item	3649959	et	3	main
huvitavat	doc_901133458176_item	3649958	et	4	main
kodulinnas	doc_901133458176_item	3649957	et	4	main
sinu	doc_901133458176_item	3649956	et	3	main
on	doc_901133458176_item	3649955	et	4	main
mis	doc_901133458176_item	3649954	et	4	main
kodulinnast	doc_901133458176_item	3649953	et	4	main
oma	doc_901133458176_item	3649952	et	4	main
midagi	doc_901133458176_item	3649951	et	4	main
kirjuta	doc_901133458176_item	3649950	et	4	main
1	doc_901133458176_item	3649949	et	2	main
küsimustele	doc_901133458176_item	3649948	et	4	main
järgmistele	doc_901133458176_item	3649947	et	3	main
vasta	doc_901133458176_item	3649946	et	4	main
küsimusele	doc_901133458176_item	3649945	et	4	main
suits	doc_491521502110_item	3650527	et	3	main
ja	doc_491521502110_item	3650508	et	3	main
olemus	doc_491521502110_item	3650507	et	3	main
majanduslik	doc_491521502110_item	3650488	et	3	main
vabariik	doc_491521502110_item	3650439	et	3	main
eesti	doc_491521502110_item	3650438	et	4	main
1	doc_491521502110_item	3650437	et	2	main
alguses	doc_491521502110_item	3650436	et	4	main
tunnused	doc_491521502110_item	3650435	et	3	main
peamised	doc_491521502110_item	3650434	et	3	main
tagada	doc_491521502110_item	3650424	et	3	main
esivanemate	doc_491521502110_item	3650412	et	4	main
olid	doc_491521502110_item	3650373	et	4	main
eeltingimusteks	doc_491521502110_item	3650372	et	3	main
g	doc_491521502110_item	3650526	et	4	main
eesti	doc_491521502110_item	3650522	et	4	main
rahvusliku	doc_491521502110_item	3650520	et	3	main
selleks	doc_491521502110_item	3650515	et	4	main
oli	doc_491521502110_item	3650514	et	3	main
rühmitus	doc_491521502110_item	3650513	et	4	main
see	doc_491521502110_item	3650512	et	3	main
noor-eesti	doc_491521502110_item	3650506	et	4	main
pärast	doc_491521502110_item	3650502	et	4	main
aga	doc_491521502110_item	3650501	et	3	main
tööd	doc_491521502110_item	3650500	et	4	main
jätkunud	doc_491521502110_item	3650499	et	4	main
ei	doc_491521502110_item	3650491	et	4	main
eriti	doc_491521502110_item	3650490	et	3	main
kriis	doc_491521502110_item	3650489	et	3	main
olid	doc_491521502110_item	3650483	et	4	main
riiasse	doc_491521502110_item	3650480	et	4	main
lennulit	doc_491521502110_item	3650478	et	4	main
narvast	doc_491521502110_item	3650471	et	4	main
majandust	doc_491521502110_item	3650432	et	4	main
vabariigi	doc_491521502110_item	3650431	et	3	main
eesti	doc_491521502110_item	3650430	et	4	main
2	doc_491521502110_item	3650429	et	2	main
tuleviku	doc_491521502110_item	3650428	et	4	main
oli	doc_491521502110_item	3650525	et	3	main
kultuuriloos	doc_491521502110_item	3650511	et	4	main
ei	doc_491521502110_item	3650498	et	4	main
kui	doc_491521502110_item	3650497	et	3	main
aeg	doc_491521502110_item	3650496	et	3	main
a-te	doc_491521502110_item	3650487	et	3	main
venemaaga	doc_491521502110_item	3650484	et	3	main
suhted	doc_491521502110_item	3650482	et	3	main
elankutele	doc_491521502110_item	3650426	et	4	main
oma	doc_491521502110_item	3650420	et	4	main
aeg	doc_491521502110_item	3650417	et	3	main
oma	doc_491521502110_item	3650411	et	4	main
loetle	doc_491521502110_item	3650374	et	4	main
1	doc_491521502110_item	3650369	et	2	main
juhiks	doc_491521502110_item	3650524	et	4	main
teadvuse	doc_491521502110_item	3650521	et	4	main
ja	doc_491521502110_item	3650518	et	3	main
kasvatada	doc_491521502110_item	3650517	et	3	main
eesti	doc_491521502110_item	3650510	et	4	main
rühmituse	doc_491521502110_item	3650505	et	4	main
tööjõupuudus	doc_491521502110_item	3650503	et	3	main
1930-te	doc_491521502110_item	3650486	et	3	main
venemaale	doc_491521502110_item	3650472	et	4	main
andis	doc_491521502110_item	3650469	et	3	main
ka	doc_491521502110_item	3650468	et	3	main
eestimaa	doc_491521502110_item	3650467	et	4	main
aga	doc_491521502110_item	3650466	et	3	main
rahuldamine	doc_491521502110_item	3650465	et	4	main
vajadust	doc_491521502110_item	3650464	et	4	main
vajadust	doc_491521502110_item	3650463	et	4	main
sisemist	doc_491521502110_item	3650462	et	4	main
riigi	doc_491521502110_item	3650461	et	3	main
tagasid	doc_491521502110_item	3650460	et	4	main
mis	doc_491521502110_item	3650459	et	4	main
ettevõtted	doc_491521502110_item	3650458	et	3	main
väikesed	doc_491521502110_item	3650457	et	4	main
tekkisid	doc_491521502110_item	3650456	et	4	main
kohal	doc_491521502110_item	3650455	et	4	main
tähtsal	doc_491521502110_item	3650454	et	3	main
oli	doc_491521502110_item	3650453	et	3	main
piimatööstus	doc_491521502110_item	3650452	et	3	main
ja	doc_491521502110_item	3650451	et	3	main
majandusmasinate	doc_491521502110_item	3650449	et	3	main
metallitööstus	doc_491521502110_item	3650448	et	3	main
tootmine	doc_491521502110_item	3650450	et	4	main
toodang	doc_491521502110_item	3650447	et	3	main
põlevkivi	doc_491521502110_item	3650446	et	4	main
oli	doc_491521502110_item	3650445	et	3	main
tööstuses	doc_491521502110_item	3650444	et	3	main
oluline	doc_491521502110_item	3650443	et	4	main
turult	doc_491521502110_item	3650442	et	3	main
euroopa	doc_491521502110_item	3650441	et	4	main
sõltus	doc_491521502110_item	3650440	et	4	main
alguses	doc_491521502110_item	3650495	et	4	main
oli	doc_491521502110_item	3650494	et	3	main
eestit	doc_491521502110_item	3650493	et	3	main
puudutanud	doc_491521502110_item	3650492	et	4	main
inglismaaga	doc_491521502110_item	3650485	et	3	main
majanduslikud	doc_491521502110_item	3650481	et	3	main
liin	doc_491521502110_item	3650479	et	3	main
8	doc_491521502110_item	3650477	et	2	main
lennundus	doc_491521502110_item	3650476	et	3	main
laevandus	doc_491521502110_item	3650475	et	3	main
eesti	doc_491521502110_item	3650474	et	4	main
arenes	doc_491521502110_item	3650473	et	3	main
energiat	doc_491521502110_item	3650470	et	3	main
iseloomustavad	doc_491521502110_item	3650433	et	4	main
eestimaa	doc_491521502110_item	3650425	et	4	main
ehitada	doc_491521502110_item	3650422	et	3	main
euroopas	doc_491521502110_item	3650419	et	3	main
juba	doc_491521502110_item	3650416	et	3	main
tuli	doc_491521502110_item	3650415	et	4	main
peale	doc_491521502110_item	3650414	et	4	main
ärkamise	doc_491521502110_item	3650371	et	4	main
eksamitöö	doc_491521502110_item	3650368	et	4	main
et	doc_491521502110_item	3650423	et	3	main
rahvusriigi	doc_491521502110_item	3650421	et	3	main
nagu	doc_491521502110_item	3650418	et	3	main
õigus	doc_491521502110_item	3650410	et	4	main
on	doc_491521502110_item	3650409	et	4	main
rahval	doc_491521502110_item	3650408	et	3	main
igal	doc_491521502110_item	3650407	et	3	main
et	doc_491521502110_item	3650406	et	3	main
kõne	doc_491521502110_item	3650405	et	4	main
jakobsoni	doc_491521502110_item	3650404	et	4	main
soodustas	doc_491521502110_item	3650403	et	3	main
sellele	doc_491521502110_item	3650402	et	4	main
vabaneda	doc_491521502110_item	3650401	et	3	main
alt	doc_491521502110_item	3650400	et	4	main
võimu	doc_491521502110_item	3650399	et	4	main
baltisakslaste	doc_491521502110_item	3650398	et	4	main
tahtsid	doc_491521502110_item	3650397	et	4	main
inimesed	doc_491521502110_item	3650396	et	3	main
eesti	doc_491521502110_item	3650395	et	4	main
saada	doc_491521502110_item	3650394	et	4	main
vabadust	doc_491521502110_item	3650393	et	4	main
rohkem	doc_491521502110_item	3650392	et	4	main
tuleb	doc_491521502110_item	3650391	et	3	main
et	doc_491521502110_item	3650390	et	3	main
mõtlema	doc_491521502110_item	3650389	et	3	main
hakkasid	doc_491521502110_item	3650388	et	4	main
nad	doc_491521502110_item	3650387	et	3	main
ja	doc_491521502110_item	3650386	et	3	main
mehi	doc_491521502110_item	3650385	et	3	main
haritud	doc_491521502110_item	3650384	et	4	main
palju	doc_491521502110_item	3650383	et	4	main
kogunes	doc_491521502110_item	3650382	et	3	main
lõpul	doc_491521502110_item	3650381	et	3	main
sajandi	doc_491521502110_item	3650380	et	3	main
19	doc_491521502110_item	3650379	et	2	main
eestis	doc_491521502110_item	3650378	et	3	main
peamised	doc_491521502110_item	3650377	et	3	main
arvates	doc_491521502110_item	3650376	et	4	main
enda	doc_491521502110_item	3650375	et	4	main
vaba	doc_491521502110_item	3650427	et	4	main
maa	doc_491521502110_item	3650413	et	4	main
rahvusliku	doc_491521502110_item	3650370	et	3	main
1938	doc_491521502118_item	3652260	et	2	main
viiest	doc_491521502118_item	3652257	et	4	main
üks	doc_491521502118_item	3652256	et	3	main
kuni	doc_491521502118_item	3652251	et	3	main
kuulus	doc_491521502118_item	3652240	et	4	main
kuna	doc_491521502118_item	3652238	et	3	main
ta	doc_491521502118_item	3652220	et	4	main
pätsi	doc_491521502118_item	3652212	et	4	main
a	doc_491521502118_item	3652245	et	4	main
hulka	doc_491521502118_item	3652243	et	4	main
pätsu	doc_491521502118_item	3652227	et	4	main
valiti	doc_491521502118_item	3652226	et	3	main
asutas	doc_491521502118_item	3652221	et	3	main
pärit	doc_491521502118_item	3652218	et	3	main
suguvõsa	doc_491521502118_item	3652216	et	4	main
vabariigis	doc_491521502118_item	3652215	et	3	main
eesti	doc_491521502118_item	3652214	et	4	main
roll	doc_491521502118_item	3652213	et	3	main
weizenberg	doc_491521502118_item	3652207	et	4	main
vassili	doc_491521502118_item	3652204	et	4	main
kujunes	doc_491521502118_item	3652186	et	3	main
wilhelm	doc_491521502118_item	3652183	et	4	main
selts	doc_491521502118_item	3652182	et	3	main
liikumise	doc_491521502118_item	3652172	et	4	main
rahvusliku	doc_491521502118_item	3652171	et	3	main
alguse	doc_491521502118_item	3652170	et	3	main
pani	doc_491521502118_item	3652169	et	4	main
ja	doc_491521502118_item	3652167	et	3	main
petersonid	doc_491521502118_item	3652165	et	4	main
jannseni	doc_491521502118_item	3652157	et	4	main
kristjan	doc_491521502118_item	3652148	et	4	main
postimee	doc_491521502118_item	3652147	et	3	main
nimeta	doc_491521502118_item	3652141	et	4	main
ja	doc_491521502118_item	3652140	et	3	main
kultuuritegelasi	doc_491521502118_item	3652139	et	3	main
ärkamisaegseid	doc_491521502118_item	3652138	et	3	main
jäänud	doc_491521502118_item	3652128	et	4	main
rahuleping	doc_491521502118_item	3652122	et	3	main
tartu	doc_491521502118_item	3652121	et	4	main
sõlmiti	doc_491521502118_item	3652120	et	3	main
veebruaris	doc_491521502118_item	3652119	et	3	main
pidurdus	doc_491521502118_item	3652110	et	4	main
eestimaa	doc_491521502118_item	3652100	et	4	main
meheni	doc_491521502118_item	3652099	et	3	main
kui	doc_491521502118_item	3652073	et	3	main
ida	doc_491521502118_item	3652071	et	4	main
samal	doc_491521502118_item	3652060	et	3	main
euroopa	doc_491521502118_item	3652057	et	4	main
poska	doc_491521502119_item	3652486	et	4	main
laidoner	doc_491521502119_item	3652485	et	4	main
oma	doc_491521502119_item	3652476	et	4	main
võimalus	doc_491521502119_item	3652475	et	3	main
oht	doc_491521502119_item	3652471	et	3	main
02021918	doc_491521502119_item	3652451	et	2	main
on	doc_491521502119_item	3652445	et	4	main
sai	doc_491521502118_item	3652262	et	4	main
oli	doc_491521502118_item	3652255	et	3	main
1934	doc_491521502118_item	3652252	et	2	main
isikute	doc_491521502118_item	3652242	et	4	main
ta	doc_491521502118_item	3652239	et	4	main
a	doc_491521502118_item	3652225	et	4	main
1905	doc_491521502118_item	3652224	et	2	main
on	doc_491521502118_item	3652217	et	4	main
konstantin	doc_491521502118_item	3652211	et	4	main
demut-malinovski	doc_491521502118_item	3652205	et	4	main
tolli	doc_491521502118_item	3652203	et	4	main
de	doc_491521502118_item	3652202	et	4	main
oli	doc_491521502118_item	3652197	et	3	main
rektor	doc_491521502118_item	3652196	et	3	main
maailma	doc_491521502118_item	3652189	et	4	main
tähetorn	doc_491521502118_item	3652188	et	3	main
jakob	doc_491521502118_item	3652178	et	4	main
päts	doc_491521502118_item	3652263	et	3	main
juhiks	doc_491521502118_item	3652259	et	4	main
valituse	doc_491521502118_item	3652258	et	4	main
päts	doc_491521502118_item	3652254	et	3	main
tipptasemel	doc_491521502118_item	3652250	et	3	main
seotud	doc_491521502118_item	3652248	et	4	main
1920	doc_491521502118_item	3652244	et	2	main
soome	doc_491521502118_item	3652235	et	3	main
ta	doc_491521502118_item	3652234	et	4	main
ajalehe	doc_491521502118_item	3652222	et	3	main
3	doc_491521502118_item	3652210	et	2	main
baclay	doc_491521502118_item	3652201	et	4	main
astronoomiakeskuseks	doc_491521502118_item	3652192	et	4	main
kirjameeste	doc_491521502118_item	3652181	et	4	main
eesti	doc_491521502118_item	3652180	et	4	main
hurt	doc_491521502118_item	3652179	et	3	main
tartus	doc_491521502118_item	3652174	et	3	main
keskuse	doc_491521502118_item	3652173	et	3	main
üldlaulupidu	doc_491521502118_item	3652161	et	4	main
jannsen	doc_491521502118_item	3652145	et	4	main
loetle	doc_491521502118_item	3652136	et	4	main
2	doc_491521502118_item	3652135	et	2	main
tulla	doc_491521502118_item	3652134	et	3	main
tagasi	doc_491521502118_item	3652133	et	3	main
eestisse	doc_491521502118_item	3652132	et	4	main
võimaluse	doc_491521502118_item	3652131	et	3	main
said	doc_491521502118_item	3652130	et	4	main
eestlased	doc_491521502118_item	3652129	et	3	main
oluline	doc_491521502118_item	3652115	et	4	main
väga	doc_491521502118_item	3652114	et	3	main
oli	doc_491521502118_item	3652113	et	3	main
majanduskriis	doc_491521502118_item	3652108	et	3	main
jätkunud	doc_491521502118_item	3652104	et	4	main
turust	doc_491521502118_item	3652072	et	3	main
presidendiks	doc_491521502118_item	3652267	et	4	main
vabariigi	doc_491521502118_item	3652266	et	3	main
eesti	doc_491521502118_item	3652265	et	4	main
esimeseks	doc_491521502118_item	3652264	et	3	main
a-l	doc_491521502118_item	3652261	et	3	main
a-ni	doc_491521502118_item	3652253	et	2	main
valimisega	doc_491521502118_item	3652249	et	4	main
ta	doc_491521502118_item	3652247	et	4	main
oli	doc_491521502118_item	3652246	et	3	main
ebameeldivate	doc_491521502118_item	3652241	et	3	main
aastaks	doc_491521502118_item	3652237	et	4	main
kolmeks	doc_491521502118_item	3652236	et	4	main
põgenes	doc_491521502118_item	3652233	et	3	main
pärast	doc_491521502118_item	3652232	et	4	main
aasta	doc_491521502118_item	3652231	et	4	main
abilisena	doc_491521502118_item	3652230	et	4	main
linnapea	doc_491521502118_item	3652229	et	4	main
tallinna	doc_491521502118_item	3652228	et	4	main
teataja	doc_491521502118_item	3652223	et	4	main
viljandimaalt	doc_491521502118_item	3652219	et	3	main
adamson	doc_491521502118_item	3652209	et	4	main
amandus	doc_491521502118_item	3652208	et	4	main
skulptorid	doc_491521502118_item	3652200	et	3	main
parrot	doc_491521502118_item	3652199	et	4	main
tähtsamaks	doc_491521502118_item	3652191	et	4	main
üheks	doc_491521502118_item	3652190	et	3	main
juhtimisel	doc_491521502118_item	3652185	et	4	main
vanemuine	doc_491521502118_item	3652177	et	4	main
a	doc_491521502118_item	3652176	et	4	main
1865	doc_491521502118_item	3652175	et	2	main
august	doc_491521502118_item	3652206	et	4	main
georg	doc_491521502118_item	3652198	et	4	main
ülikooli	doc_491521502118_item	3652195	et	4	main
tartu	doc_491521502118_item	3652194	et	4	main
esimene	doc_491521502118_item	3652193	et	3	main
tartu	doc_491521502118_item	3652187	et	4	main
struve	doc_491521502118_item	3652184	et	4	main
koidula	doc_491521502118_item	3652168	et	4	main
vennad	doc_491521502118_item	3652164	et	3	main
jaan	doc_491521502118_item	3652162	et	3	main
tartus	doc_491521502118_item	3652156	et	3	main
a	doc_491521502118_item	3652155	et	4	main
1869	doc_491521502118_item	3652154	et	2	main
ilukirjandusega	doc_491521502118_item	3652153	et	3	main
tegeles	doc_491521502118_item	3652152	et	3	main
perno	doc_491521502118_item	3652146	et	4	main
tähtsamaid	doc_491521502118_item	3652137	et	4	main
venemaale	doc_491521502118_item	3652127	et	4	main
venemaa	doc_491521502118_item	3652125	et	4	main
ja	doc_491521502118_item	3652124	et	3	main
eesti	doc_491521502118_item	3652123	et	4	main
kultuuritegevus	doc_491521502118_item	3652111	et	4	main
oli	doc_491521502118_item	3652106	et	3	main
sai	doc_491521502118_item	3652075	et	4	main
ajal	doc_491521502118_item	3652061	et	4	main
e	doc_491521502119_item	3652480	et	4	main
akt	doc_491521502119_item	3652479	et	3	main
loomiseks	doc_491521502119_item	3652478	et	4	main
riigi	doc_491521502119_item	3652477	et	3	main
vm	doc_491521502119_item	3652472	et	4	main
oluline	doc_491521502119_item	3652468	et	4	main
eestl	doc_491521502119_item	3652466	et	4	main
rahu	doc_491521502119_item	3652465	et	4	main
petendeerimisele	doc_491521502119_item	3652461	et	4	main
igasug	doc_491521502119_item	3652460	et	4	main
millega	doc_491521502119_item	3652457	et	3	main
alla	doc_491521502119_item	3652455	et	3	main
kui	doc_491521502119_item	3652452	et	3	main
üle	doc_491521502119_item	3652447	et	3	main
vaimujõud	doc_491521502119_item	3652444	et	4	main
no	doc_491521502119_item	3652443	et	3	main
haridust	doc_491521502119_item	3652442	et	4	main
edendada	doc_491521502119_item	3652441	et	3	main
riikidele	doc_491521502119_item	3652435	et	3	main
kuhugi	doc_491521502119_item	3652424	et	4	main
vene	doc_491521502119_item	3652400	et	4	main
ja	doc_491521502119_item	3652399	et	3	main
suuremate	doc_491521502119_item	3652361	et	4	main
i	doc_491521502118_item	3652160	et	4	main
oli	doc_491521502118_item	3652159	et	3	main
eestvõtel	doc_491521502118_item	3652158	et	3	main
peterson	doc_491521502118_item	3652149	et	4	main
nende	doc_491521502118_item	3652142	et	4	main
vahel	doc_491521502118_item	3652126	et	4	main
eestlastel	doc_491521502118_item	3652112	et	4	main
suur	doc_491521502118_item	3652107	et	3	main
mln	doc_491521502118_item	3652098	et	4	main
1	doc_491521502118_item	3652097	et	2	main
küündis	doc_491521502118_item	3652096	et	3	main
suurus	doc_491521502118_item	3652095	et	4	main
väe	doc_491521502118_item	3652094	et	3	main
geograafia	doc_491521502118_item	3652049	et	4	main
heas	doc_491521502118_item	3652048	et	3	main
väga	doc_491521502118_item	3652047	et	3	main
olid	doc_491521502118_item	3652046	et	4	main
liivikupermangud	doc_491521502118_item	3652045	et	4	main
ja	doc_491521502118_item	3652044	et	3	main
eesti	doc_491521502118_item	3652043	et	4	main
regioon	doc_491521502118_item	3652042	et	3	main
arenem	doc_491521502118_item	3652041	et	4	main
kõige	doc_491521502118_item	3652040	et	4	main
aendast	doc_491521502118_item	3652039	et	4	main
esines	doc_491521502118_item	3652038	et	3	main
ta	doc_491521502118_item	3652037	et	4	main
osa	doc_491521502118_item	3652036	et	4	main
impeeriumi	doc_491521502118_item	3652035	et	4	main
vene	doc_491521502118_item	3652034	et	4	main
oli	doc_491521502118_item	3652033	et	3	main
eeesti	doc_491521502118_item	3652032	et	4	main
kui	doc_491521502118_item	3652031	et	3	main
sündmustele	doc_491521502118_item	3652030	et	3	main
järgmistele	doc_491521502118_item	3652029	et	3	main
tänu	doc_491521502118_item	3652028	et	4	main
võimalikuks	doc_491521502118_item	3652027	et	3	main
sai	doc_491521502118_item	3652026	et	4	main
loomine	doc_491521502118_item	3652025	et	4	main
vabariigi	doc_491521502118_item	3652024	et	3	main
eesti	doc_491521502118_item	3652074	et	4	main
sõltus	doc_491521502118_item	3652069	et	4	main
eesti	doc_491521502118_item	3652067	et	4	main
et	doc_491521502118_item	3652066	et	3	main
seda	doc_491521502118_item	3652065	et	3	main
tähendas	doc_491521502118_item	3652064	et	3	main
venemaaga	doc_491521502118_item	3652063	et	3	main
seos	doc_491521502118_item	3652062	et	3	main
vahel	doc_491521502118_item	3652058	et	4	main
olukorras	doc_491521502118_item	3652050	et	3	main
jt	doc_491521502119_item	3652487	et	4	main
päts	doc_491521502119_item	3652484	et	3	main
jannsen	doc_491521502118_item	3652166	et	4	main
adamson	doc_491521502118_item	3652163	et	4	main
jakobon	doc_491521502118_item	3652151	et	4	main
luuletja	doc_491521502118_item	3652150	et	4	main
voldemar	doc_491521502118_item	3652144	et	4	main
töid	doc_491521502118_item	3652143	et	3	main
a	doc_491521502118_item	3652118	et	4	main
1920	doc_491521502118_item	3652117	et	2	main
maareform	doc_491521502118_item	3652116	et	3	main
kütusepuudus	doc_491521502118_item	3652109	et	3	main
toitu	doc_491521502118_item	3652105	et	4	main
ei	doc_491521502118_item	3652103	et	4	main
välja	doc_491521502118_item	3652102	et	4	main
kurnati	doc_491521502118_item	3652101	et	3	main
eesti	doc_491521502118_item	3652023	et	4	main
1	doc_491521502118_item	3652022	et	2	main
eksamitöö	doc_491521502118_item	3652021	et	4	main
vene	doc_491521502118_item	3652093	et	4	main
ja	doc_491521502118_item	3652092	et	3	main
venemaa	doc_491521502118_item	3652091	et	4	main
võõrtöölisi	doc_491521502118_item	3652090	et	3	main
10000	doc_491521502118_item	3652089	et	2	main
üle	doc_491521502118_item	3652088	et	3	main
oli	doc_491521502118_item	3652087	et	3	main
eestis	doc_491521502118_item	3652086	et	3	main
1914-1915	doc_491521502118_item	3652085	et	2	main
vahel	doc_491521502118_item	3652084	et	4	main
suhete	doc_491521502118_item	3652083	et	3	main
venemaa	doc_491521502118_item	3652082	et	4	main
ja	doc_491521502118_item	3652081	et	3	main
euroopa	doc_491521502118_item	3652080	et	4	main
roll	doc_491521502118_item	3652079	et	3	main
tema	doc_491521502118_item	3652078	et	4	main
vähene	doc_491521502118_item	3652077	et	4	main
vabaduse	doc_491521502118_item	3652076	et	4	main
väga	doc_491521502118_item	3652070	et	3	main
ökonoomika	doc_491521502118_item	3652068	et	4	main
aga	doc_491521502118_item	3652059	et	3	main
ja	doc_491521502118_item	3652056	et	3	main
venemaa	doc_491521502118_item	3652055	et	4	main
piir	doc_491521502118_item	3652054	et	3	main
nagu	doc_491521502118_item	3652053	et	3	main
oli	doc_491521502118_item	3652052	et	3	main
see	doc_491521502118_item	3652051	et	3	main
kaob	doc_491521502119_item	3652469	et	3	main
suhtes	doc_491521502119_item	3652463	et	4	main
eesti	doc_491521502119_item	3652462	et	4	main
venemaa	doc_491521502119_item	3652453	et	4	main
tartu	doc_491521502119_item	3652449	et	4	main
rusikajõust	doc_491521502119_item	3652446	et	3	main
ei	doc_491521502119_item	3652437	et	4	main
vastu	doc_491521502119_item	3652436	et	3	main
nagu	doc_491521502119_item	3652423	et	3	main
eesti	doc_491521502119_item	3652410	et	4	main
pidas	doc_491521502119_item	3652409	et	3	main
hariduse	doc_491521502119_item	3652408	et	3	main
teoloogilise	doc_491521502119_item	3652407	et	4	main
tük-s	doc_491521502119_item	3652406	et	3	main
saksa	doc_491521502119_item	3652398	et	4	main
naistel	doc_491521502119_item	3652347	et	3	main
ka	doc_491521502119_item	3652346	et	3	main
naisseltsid	doc_491521502119_item	3652343	et	3	main
talurahvale	doc_491521502119_item	3652342	et	3	main
lihtrahvale	doc_491521502119_item	3652341	et	3	main
ka	doc_491521502119_item	3652340	et	3	main
kättesaadav	doc_491521502119_item	3652339	et	4	main
oli	doc_491521502119_item	3652338	et	3	main
estonia	doc_491521502119_item	3652311	et	4	main
vanemuine	doc_491521502119_item	3652310	et	4	main
eõs	doc_491521502119_item	3652303	et	4	main
ekms	doc_491521502119_item	3652302	et	4	main
tähtsalt	doc_491521502119_item	3652299	et	4	main
ka	doc_491521502119_item	3652293	et	3	main
määral	doc_491521502119_item	3652292	et	3	main
mingil	doc_491521502119_item	3652291	et	4	main
tegeles	doc_491521502119_item	3652290	et	3	main
selts	doc_491521502119_item	3652289	et	3	main
olulisel	doc_491521502119_item	3652280	et	4	main
p	doc_491521502119_item	3652279	et	4	main
s	doc_491521502119_item	3652277	et	4	main
osatähtsusest	doc_491521502119_item	3652271	et	4	main
esindaja	doc_491521502119_item	3652387	et	4	main
j	doc_491521502119_item	3652382	et	4	main
eestis	doc_491521502119_item	3652381	et	3	main
ärkamisaegses	doc_491521502119_item	3652380	et	3	main
roll	doc_491521502119_item	3652379	et	3	main
hurda	doc_491521502119_item	3652378	et	3	main
jakob	doc_491521502119_item	3652377	et	4	main
2	doc_491521502119_item	3652376	et	2	main
rahvusest	doc_491521502119_item	3652375	et	4	main
kultuurist	doc_491521502119_item	3652374	et	3	main
oma	doc_491521502119_item	3652373	et	4	main
teada	doc_491521502119_item	3652372	et	3	main
rahvale	doc_491521502119_item	3652371	et	3	main
anti	doc_491521502119_item	3652370	et	3	main
kätte	doc_491521502119_item	3652369	et	4	main
suuna	doc_491521502119_item	3652368	et	4	main
andis	doc_491521502119_item	3652367	et	3	main
mis	doc_491521502119_item	3652366	et	4	main
pol	doc_491521502119_item	3652481	et	4	main
poolt	doc_491521502119_item	3652473	et	4	main
tartu	doc_491521502119_item	3652464	et	4	main
loobub	doc_491521502119_item	3652458	et	3	main
rahu	doc_491521502119_item	3652450	et	4	main
3	doc_491521502119_item	3652448	et	2	main
seep	doc_491521502119_item	3652439	et	4	main
tug	doc_491521502119_item	3652434	et	4	main
on	doc_491521502119_item	3652428	et	4	main
ning	doc_491521502119_item	3652415	et	3	main
teda	doc_491521502119_item	3652412	et	4	main
kuna	doc_491521502119_item	3652403	et	3	main
vahel	doc_491521502119_item	3652402	et	4	main
tee	doc_491521502119_item	3652401	et	4	main
taotlused	doc_491521502119_item	3652360	et	4	main
eesmärgid	doc_491521502119_item	3652359	et	3	main
ühised	doc_491521502119_item	3652358	et	3	main
enam-vähem	doc_491521502119_item	3652357	et	3	main
neil	doc_491521502119_item	3652356	et	4	main
olid	doc_491521502119_item	3652355	et	4	main
rahvast	doc_491521502119_item	3652354	et	4	main
seltsid	doc_491521502119_item	3652352	et	4	main
end	doc_491521502119_item	3652348	et	4	main
ideed	doc_491521502119_item	3652333	et	4	main
rahvusl	doc_491521502119_item	3652332	et	4	main
seltside	doc_491521502119_item	3652329	et	3	main
ning	doc_491521502119_item	3652326	et	3	main
eüs	doc_491521502119_item	3652305	et	4	main
ka	doc_491521502119_item	3652304	et	3	main
kohal	doc_491521502119_item	3652300	et	4	main
tuletõrjeseltsid	doc_491521502119_item	3652283	et	3	main
radikaal-dem	doc_491521502119_item	3652385	et	4	main
kultuuri	doc_491521502120_item	3652870	et	4	main
oma	doc_491521502120_item	3652869	et	4	main
proppageerima	doc_491521502120_item	3652868	et	4	main
nii	doc_491521502120_item	3652862	et	3	main
õpetajate	doc_491521502120_item	3652858	et	4	main
esti	doc_491521502120_item	3652857	et	4	main
1930	doc_491521502120_item	3652856	et	2	main
selts	doc_491521502120_item	3652855	et	3	main
kirjanikude	doc_491521502120_item	3652854	et	3	main
eüs	doc_491521502120_item	3652846	et	4	main
lubanud	doc_491521502120_item	3652825	et	4	main
tol	doc_491521502120_item	3652822	et	3	main
edendasid	doc_491521502120_item	3652820	et	4	main
väikesed	doc_491521502120_item	3652812	et	4	main
kõigepealt	doc_491521502120_item	3652811	et	3	main
ja	doc_491521502120_item	3652810	et	3	main
rootslased	doc_491521502120_item	3652809	et	3	main
sakslased	doc_491521502120_item	3652808	et	3	main
venelased	doc_491521502120_item	3652807	et	3	main
kohta	doc_491521502120_item	3652804	et	4	main
keskõige	doc_491521502120_item	3652788	et	4	main
kultuuriinimesed	doc_491521502120_item	3652771	et	3	main
kultuuri	doc_491521502120_item	3652743	et	4	main
euroopaliku	doc_491521502120_item	3652742	et	3	main
vabastamine	doc_491521502120_item	3652736	et	4	main
olid	doc_491521502120_item	3652662	et	4	main
tuntud	doc_491521502120_item	3652636	et	4	main
oli	doc_491521502120_item	3652634	et	3	main
1816	doc_491521502120_item	3652632	et	2	main
oli	doc_491521502120_item	3652629	et	3	main
ärkmisaeg	doc_491521502120_item	3652628	et	4	main
eestis	doc_491521502120_item	3652627	et	3	main
ärkamisaegses	doc_491521502120_item	3652626	et	3	main
roll	doc_491521502120_item	3652625	et	3	main
v	doc_491521502120_item	3652611	et	4	main
palju	doc_491521502120_item	3652604	et	4	main
väga	doc_491521502120_item	3652603	et	3	main
oli	doc_491521502120_item	3652602	et	3	main
ülikooli	doc_491521502120_item	3652597	et	4	main
tartu	doc_491521502120_item	3652596	et	4	main
kutseharidust	doc_491521502120_item	3652584	et	4	main
lõpetamist	doc_491521502120_item	3652580	et	4	main
pärast	doc_491521502120_item	3652578	et	4	main
k	doc_491521502119_item	3652483	et	4	main
liidrid	doc_491521502119_item	3652482	et	3	main
tek	doc_491521502119_item	3652474	et	4	main
otsene	doc_491521502119_item	3652470	et	3	main
v	doc_491521502119_item	3652467	et	4	main
oma	doc_491521502119_item	3652459	et	4	main
lepingule	doc_491521502119_item	3652456	et	3	main
kirj	doc_491521502119_item	3652454	et	4	main
vaja	doc_491521502119_item	3652440	et	4	main
eesti	doc_491521502119_item	3652427	et	4	main
et	doc_491521502119_item	3652426	et	3	main
arvas	doc_491521502119_item	3652425	et	3	main
kuulunudki	doc_491521502119_item	3652421	et	4	main
ei	doc_491521502119_item	3652420	et	4	main
lõpptulemusena	doc_491521502119_item	3652419	et	3	main
pooldajaks	doc_491521502119_item	3652418	et	4	main
eestl	doc_491521502119_item	3652417	et	4	main
baltisakslased	doc_491521502119_item	3652416	et	3	main
baltisaksl	doc_491521502119_item	3652413	et	4	main
rahvas	doc_491521502119_item	3652411	et	4	main
seltside	doc_491521502119_item	3652362	et	3	main
kondasid	doc_491521502119_item	3652353	et	4	main
kuna	doc_491521502119_item	3652351	et	3	main
jne	doc_491521502119_item	3652350	et	4	main
jne	doc_491521502119_item	3652334	et	4	main
kaudu	doc_491521502119_item	3652330	et	3	main
kult	doc_491521502119_item	3652324	et	3	main
oli	doc_491521502119_item	3652322	et	3	main
linnades	doc_491521502119_item	3652320	et	3	main
n	doc_491521502119_item	3652309	et	4	main
mänguseltsid	doc_491521502119_item	3652308	et	3	main
ja	doc_491521502119_item	3652307	et	3	main
laulu-	doc_491521502119_item	3652306	et	4	main
nö	doc_491521502119_item	3652297	et	4	main
rahvusküsimustega	doc_491521502119_item	3652296	et	3	main
ja	doc_491521502119_item	3652295	et	3	main
poliitikaga	doc_491521502119_item	3652294	et	3	main
põllumajandusseltsid	doc_491521502119_item	3652282	et	3	main
ii	doc_491521502119_item	3652278	et	4	main
19	doc_491521502119_item	3652276	et	2	main
tek	doc_491521502119_item	3652275	et	4	main
seltsiliikumine	doc_491521502119_item	3652274	et	3	main
1seltsiliikumise	doc_491521502119_item	3652270	et	3	main
eesti	doc_491521502119_item	3652396	et	4	main
leida	doc_491521502119_item	3652394	et	3	main
suuna	doc_491521502119_item	3652386	et	4	main
oli	doc_491521502119_item	3652364	et	3	main
hakkasid	doc_491521502120_item	3652867	et	4	main
oli	doc_491521502120_item	3652861	et	3	main
lit	doc_491521502120_item	3652859	et	4	main
lomeühenguid	doc_491521502120_item	3652849	et	4	main
sellides	doc_491521502120_item	3652844	et	3	main
ilmusid	doc_491521502120_item	3652842	et	4	main
gümnaasiumil	doc_491521502120_item	3652832	et	3	main
vähemusrahvaste	doc_491521502120_item	3652831	et	4	main
seltsielu	doc_491521502120_item	3652826	et	4	main
altiivsemaid	doc_491521502120_item	3652815	et	4	main
kõige	doc_491521502120_item	3652814	et	4	main
rahvad	doc_491521502120_item	3652813	et	3	main
seadus	doc_491521502120_item	3652800	et	4	main
vastu	doc_491521502120_item	3652799	et	3	main
võeti	doc_491521502120_item	3652798	et	3	main
1925	doc_491521502120_item	3652797	et	2	main
riigitoetus	doc_491521502120_item	3652796	et	4	main
olingi	doc_491521502120_item	3652795	et	3	main
rahvaelu	doc_491521502120_item	3652793	et	4	main
ja	doc_491521502120_item	3652792	et	3	main
man	doc_491521502120_item	3652791	et	3	main
kirjutas	doc_491521502120_item	3652790	et	3	main
parem	doc_491521502120_item	3652789	et	4	main
sellele	doc_491521502120_item	3652787	et	4	main
poole	doc_491521502120_item	3652770	et	4	main
arenema	doc_491521502120_item	3652768	et	3	main
hakkas	doc_491521502120_item	3652767	et	3	main
kultuuriellu	doc_491521502120_item	3652766	et	3	main
ja	doc_491521502120_item	3652757	et	3	main
ta	doc_491521502120_item	3652753	et	4	main
ja	doc_491521502120_item	3652751	et	3	main
jakobson	doc_491521502120_item	3652748	et	4	main
kirja-lugemisoskust	doc_491521502120_item	3652747	et	3	main
omandasid	doc_491521502120_item	3652746	et	4	main
saa	doc_491521502119_item	3652438	et	4	main
suurtele	doc_491521502119_item	3652433	et	3	main
sõjalised	doc_491521502119_item	3652432	et	4	main
ning	doc_491521502119_item	3652431	et	3	main
riik	doc_491521502119_item	3652430	et	3	main
väike	doc_491521502119_item	3652429	et	4	main
ta	doc_491521502119_item	3652422	et	4	main
pooldajaks	doc_491521502119_item	3652414	et	4	main
saanud	doc_491521502119_item	3652405	et	4	main
oli	doc_491521502119_item	3652404	et	3	main
eesotsas	doc_491521502119_item	3652363	et	4	main
peeti	doc_491521502119_item	3652335	et	4	main
levitati	doc_491521502119_item	3652331	et	4	main
tarbija	doc_491521502119_item	3652325	et	4	main
akt	doc_491521502119_item	3652323	et	3	main
iga	doc_491521502119_item	3652288	et	4	main
kohal	doc_491521502119_item	3652281	et	4	main
omariikluse	doc_491521502119_item	3652272	et	4	main
teed	doc_491521502119_item	3652397	et	4	main
hurt	doc_491521502119_item	3652383	et	3	main
välismaal	doc_491521502120_item	3652871	et	4	main
edukas	doc_491521502120_item	3652863	et	4	main
e	doc_491521502120_item	3652853	et	4	main
oli	doc_491521502120_item	3652852	et	3	main
1922	doc_491521502120_item	3652851	et	2	main
oli	doc_491521502120_item	3652837	et	3	main
juudi	doc_491521502120_item	3652836	et	3	main
ajal	doc_491521502120_item	3652823	et	4	main
seltse	doc_491521502120_item	3652821	et	3	main
kes	doc_491521502120_item	3652819	et	4	main
juudid	doc_491521502120_item	3652818	et	3	main
olid	doc_491521502120_item	3652817	et	4	main
oli	doc_491521502120_item	3652806	et	3	main
see	doc_491521502120_item	3652794	et	3	main
teadvustad	doc_491521502119_item	3652349	et	3	main
võimaluse	doc_491521502119_item	3652345	et	3	main
andsid	doc_491521502119_item	3652344	et	4	main
mis	doc_491521502119_item	3652337	et	4	main
kõnesid	doc_491521502119_item	3652336	et	3	main
looja	doc_491521502119_item	3652328	et	4	main
ka	doc_491521502119_item	3652327	et	3	main
rahvas	doc_491521502119_item	3652321	et	4	main
külades	doc_491521502119_item	3652319	et	3	main
ka	doc_491521502119_item	3652318	et	3	main
vallas	doc_491521502119_item	3652317	et	3	main
igas	doc_491521502119_item	3652316	et	3	main
tegutsesid	doc_491521502119_item	3652314	et	4	main
seltsid	doc_491521502119_item	3652313	et	4	main
praktil	doc_491521502119_item	3652315	et	4	main
jt	doc_491521502119_item	3652312	et	4	main
ka	doc_491521502119_item	3652301	et	3	main
hariduselus	doc_491521502119_item	3652298	et	4	main
praktiliselt	doc_491521502119_item	3652287	et	4	main
karskusseltsid	doc_491521502119_item	3652286	et	3	main
ka	doc_491521502119_item	3652285	et	3	main
alguss	doc_491521502119_item	3652284	et	3	main
kujundajana	doc_491521502119_item	3652273	et	4	main
eksamitöö	doc_491521502119_item	3652269	et	4	main
oma	doc_491521502119_item	3652395	et	4	main
üritas	doc_491521502119_item	3652393	et	3	main
vahel	doc_491521502119_item	3652392	et	4	main
jakobsoni	doc_491521502119_item	3652391	et	4	main
ja	doc_491521502119_item	3652390	et	3	main
jannseni	doc_491521502119_item	3652389	et	4	main
ning	doc_491521502119_item	3652388	et	3	main
oli	doc_491521502119_item	3652384	et	3	main
intelligents	doc_491521502119_item	3652365	et	3	main
isegi	doc_491521502120_item	3652866	et	4	main
eestlased	doc_491521502120_item	3652865	et	3	main
et	doc_491521502120_item	3652864	et	3	main
kunsti	doc_491521502120_item	3652850	et	4	main
leehtedes	doc_491521502120_item	3652845	et	4	main
algkool	doc_491521502120_item	3652840	et	4	main
soome	doc_491521502120_item	3652839	et	3	main
tegutsesid	doc_491521502120_item	3652830	et	4	main
ajal	doc_491521502120_item	3652829	et	4	main
tol	doc_491521502120_item	3652828	et	3	main
oli	doc_491521502120_item	3652824	et	3	main
vähemusrahvaste	doc_491521502120_item	3652801	et	4	main
hea	doc_491521502120_item	3652769	et	4	main
vabariigis	doc_491521502120_item	3652765	et	3	main
eesti	doc_491521502120_item	3652764	et	4	main
hariduselu	doc_491521502120_item	3652763	et	4	main
ja	doc_491521502120_item	3652762	et	3	main
mitemid	doc_491521502120_item	3652755	et	4	main
huvi	doc_491521502120_item	3652741	et	4	main
pärisorjusest	doc_491521502120_item	3652735	et	4	main
koiduaeg	doc_491521502120_item	3652734	et	3	main
kõned	doc_491521502120_item	3652661	et	3	main
robert	doc_491521502120_item	3652623	et	4	main
j	doc_491521502120_item	3652610	et	4	main
1632	doc_491521502120_item	3652598	et	2	main
avati	doc_491521502120_item	3652595	et	3	main
kui	doc_491521502120_item	3652594	et	3	main
ndatel	doc_491521502120_item	3652593	et	4	main
1630	doc_491521502120_item	3652592	et	2	main
saada	doc_491521502120_item	3652583	et	4	main
minna	doc_491521502120_item	3652582	et	3	main
nende	doc_491521502120_item	3652579	et	4	main
või	doc_491521502120_item	3652568	et	4	main
progümnaasium	doc_491521502120_item	3652567	et	4	main
muutus	doc_491521502120_item	3652562	et	4	main
täiendav	doc_491521502120_item	3652558	et	4	main
tekkisid	doc_491521502120_item	3652552	et	4	main
ja	doc_491521502120_item	3652550	et	3	main
pärast	doc_491521502120_item	3652543	et	4	main
oli	doc_491521502120_item	3652504	et	3	main
3	doc_491521502120_item	3652733	et	2	main
aeg	doc_491521502120_item	3652732	et	3	main
raske	doc_491521502120_item	3652731	et	4	main
see	doc_491521502120_item	3652728	et	3	main
lesta	doc_491521502120_item	3652726	et	4	main
palju	doc_491521502120_item	3652725	et	4	main
et	doc_491521502120_item	3652720	et	3	main
huvi	doc_491521502120_item	3652711	et	4	main
2	doc_491521502120_item	3652707	et	2	main
eestlastel	doc_491521502120_item	3652705	et	4	main
ajal	doc_491521502120_item	3652685	et	4	main
tol	doc_491521502120_item	3652684	et	3	main
kultuuriarenemine	doc_491521502120_item	3652860	et	3	main
igasuguseid	doc_491521502120_item	3652848	et	3	main
tekkisid	doc_491521502120_item	3652847	et	4	main
ajakirjad	doc_491521502120_item	3652843	et	3	main
ka	doc_491521502120_item	3652841	et	3	main
ka	doc_491521502120_item	3652838	et	3	main
rootsi	doc_491521502120_item	3652835	et	4	main
vene	doc_491521502120_item	3652834	et	4	main
saksa	doc_491521502120_item	3652833	et	4	main
usubadus	doc_491521502120_item	3652827	et	4	main
vähemusrahvastest	doc_491521502120_item	3652816	et	4	main
vähemusrahvas	doc_491521502120_item	3652805	et	4	main
autonoomia	doc_491521502120_item	3652803	et	4	main
kultuuri	doc_491521502120_item	3652802	et	4	main
preemia	doc_491521502120_item	3652786	et	4	main
anti	doc_491521502120_item	3652785	et	3	main
a	doc_491521502120_item	3652784	et	4	main
1937	doc_491521502120_item	3652783	et	2	main
riigivanema	doc_491521502120_item	3652782	et	4	main
auhinda	doc_491521502120_item	3652781	et	4	main
preemiat	doc_491521502120_item	3652780	et	3	main
anti	doc_491521502120_item	3652779	et	3	main
välja	doc_491521502120_item	3652778	et	4	main
a	doc_491521502120_item	3652777	et	4	main
1933	doc_491521502120_item	3652776	et	2	main
alates	doc_491521502120_item	3652775	et	3	main
riigitoetust	doc_491521502120_item	3652774	et	4	main
saama	doc_491521502120_item	3652773	et	4	main
hakkasid	doc_491521502120_item	3652772	et	4	main
kultuuri-	doc_491521502120_item	3652761	et	4	main
vähemusrahvuste	doc_491521502120_item	3652760	et	3	main
3	doc_491521502120_item	3652759	et	2	main
õpikuid	doc_491521502120_item	3652758	et	4	main
raamatuid	doc_491521502120_item	3652756	et	3	main
poliitikuna	doc_491521502120_item	3652750	et	3	main
rahvusarkamine	doc_491521502120_item	3652740	et	4	main
eestlaste	doc_491521502120_item	3652667	et	4	main
muudatustest	doc_491521502120_item	3652666	et	3	main
tol	doc_491521502120_item	3652637	et	3	main
jakobsoni	doc_491521502120_item	3652624	et	4	main
valmistati	doc_491521502120_item	3652619	et	4	main
eestis	doc_491521502120_item	3652617	et	3	main
väga	doc_491521502120_item	3652615	et	3	main
oli	doc_491521502120_item	3652614	et	3	main
aavik	doc_491521502120_item	3652609	et	4	main
kadlusi	doc_491521502120_item	3652605	et	4	main
eestis	doc_491521502120_item	3652601	et	3	main
tol	doc_491521502120_item	3652599	et	3	main
mis	doc_491521502120_item	3652585	et	4	main
algkooli	doc_491521502120_item	3652574	et	4	main
5-	doc_491521502120_item	3652565	et	4	main
algkool	doc_491521502120_item	3652561	et	4	main
19334-1937	doc_491521502120_item	3652556	et	2	main
ja	doc_491521502120_item	3652554	et	3	main
eesti	doc_491521502120_item	3652548	et	4	main
ja	doc_491521502120_item	3652541	et	3	main
klassiline	doc_491521502120_item	3652539	et	4	main
oli	doc_491521502120_item	3652537	et	3	main
800	doc_491521502120_item	3652500	et	2	main
eksamitöö	doc_491521502120_item	3652489	et	4	main
liiga	doc_491521502120_item	3652724	et	4	main
oli	doc_491521502120_item	3652719	et	3	main
tema	doc_491521502120_item	3652717	et	4	main
pimedusaeg	doc_491521502120_item	3652708	et	4	main
valgusaeg	doc_491521502120_item	3652706	et	3	main
oli	doc_491521502120_item	3652704	et	3	main
kostab	doc_491521502120_item	3652754	et	3	main
õpetajana	doc_491521502120_item	3652752	et	4	main
jätkab	doc_491521502120_item	3652749	et	3	main
liikumine	doc_491521502120_item	3652739	et	4	main
rääkisid	doc_491521502120_item	3652665	et	4	main
mis	doc_491521502120_item	3652664	et	4	main
dokumendid	doc_491521502120_item	3652663	et	3	main
seltsis	doc_491521502120_item	3652659	et	4	main
vanemuise	doc_491521502120_item	3652658	et	4	main
tartus	doc_491521502120_item	3652657	et	3	main
peeti	doc_491521502120_item	3652656	et	4	main
kõnet	doc_491521502120_item	3652655	et	3	main
sellist	doc_491521502120_item	3652654	et	4	main
ajast	doc_491521502120_item	3652653	et	4	main
koidu	doc_491521502120_item	3652652	et	3	main
ja	doc_491521502120_item	3652651	et	3	main
pimeduse	doc_491521502120_item	3652650	et	4	main
valguse	doc_491521502120_item	3652649	et	4	main
rahva	doc_491521502120_item	3652648	et	3	main
eesti	doc_491521502120_item	3652647	et	4	main
kõnet	doc_491521502120_item	3652646	et	3	main
isamaa	doc_491521502120_item	3652645	et	4	main
esimest	doc_491521502120_item	3652644	et	4	main
oma	doc_491521502120_item	3652643	et	4	main
ta	doc_491521502120_item	3652642	et	4	main
pidas	doc_491521502120_item	3652641	et	3	main
1864	doc_491521502120_item	3652640	et	2	main
et	doc_491521502120_item	3652639	et	3	main
ajal	doc_491521502120_item	3652638	et	4	main
85	doc_491521502120_item	3652745	et	2	main
vastu	doc_491521502120_item	3652744	et	3	main
massiline	doc_491521502120_item	3652738	et	4	main
1870-1880	doc_491521502120_item	3652737	et	2	main
need	doc_491521502120_item	3652660	et	3	main
carl	doc_491521502120_item	3652622	et	4	main
2	doc_491521502120_item	3652621	et	2	main
isegi	doc_491521502120_item	3652618	et	4	main
j	doc_491521502120_item	3652608	et	4	main
nagu	doc_491521502120_item	3652607	et	3	main
selliseid	doc_491521502120_item	3652606	et	4	main
ta	doc_491521502120_item	3652635	et	4	main
a	doc_491521502120_item	3652633	et	4	main
alates	doc_491521502120_item	3652631	et	3	main
eestis	doc_491521502120_item	3652630	et	3	main
lennukeid	doc_491521502120_item	3652620	et	3	main
arenemisriik	doc_491521502120_item	3652616	et	3	main
eesti	doc_491521502120_item	3652613	et	4	main
veski	doc_491521502120_item	3652612	et	4	main
kestas	doc_491521502120_item	3652586	et	4	main
saaksid	doc_491521502120_item	3652581	et	4	main
teine	doc_491521502120_item	3652569	et	3	main
kui	doc_491521502120_item	3652560	et	3	main
hakkati	doc_491521502120_item	3652544	et	3	main
reaali	doc_491521502120_item	3652540	et	4	main
mis	doc_491521502120_item	3652536	et	4	main
ajal	doc_491521502120_item	3652600	et	4	main
oli	doc_491521502120_item	3652591	et	3	main
algusaasta	doc_491521502120_item	3652590	et	4	main
teaduse	doc_491521502120_item	3652589	et	3	main
aastat	doc_491521502120_item	3652588	et	3	main
3	doc_491521502120_item	3652587	et	2	main
klassi	doc_491521502120_item	3652573	et	4	main
6	doc_491521502120_item	3652572	et	2	main
oli	doc_491521502120_item	3652571	et	3	main
võimalus	doc_491521502120_item	3652570	et	3	main
klassiliseks	doc_491521502120_item	3652564	et	4	main
4	doc_491521502120_item	3652563	et	2	main
spetsialisti	doc_491521502120_item	3652546	et	4	main
vajama	doc_491521502120_item	3652545	et	3	main
algkool	doc_491521502120_item	3652535	et	4	main
klassiline	doc_491521502120_item	3652534	et	4	main
6	doc_491521502120_item	3652533	et	2	main
koolisüsteem	doc_491521502120_item	3652532	et	3	main
kaheastmeline	doc_491521502120_item	3652531	et	4	main
tekkis	doc_491521502120_item	3652530	et	3	main
aga	doc_491521502120_item	3652529	et	3	main
hiljem	doc_491521502120_item	3652528	et	3	main
haridus	doc_491521502120_item	3652527	et	3	main
klassikaline	doc_491521502120_item	3652526	et	4	main
4	doc_491521502120_item	3652525	et	2	main
kohustuslik	doc_491521502120_item	3652524	et	3	main
tegi	doc_491521502120_item	3652523	et	4	main
tehnilist	doc_491521502120_item	3652522	et	3	main
põllumajanduslikk	doc_491521502120_item	3652521	et	4	main
kõrgharidus	doc_491521502120_item	3652520	et	3	main
saada	doc_491521502120_item	3652519	et	4	main
võimalik	doc_491521502120_item	3652518	et	3	main
oli	doc_491521502120_item	3652517	et	3	main
ülikooliks	doc_491521502120_item	3652516	et	4	main
eestikeelse	doc_491521502120_item	3652515	et	3	main
ülikool	doc_491521502120_item	3652514	et	4	main
tartu	doc_491521502120_item	3652513	et	4	main
sai	doc_491521502120_item	3652512	et	4	main
1919	doc_491521502120_item	3652511	et	2	main
nov	doc_491521502120_item	3652510	et	4	main
11	doc_491521502120_item	3652509	et	2	main
oluline	doc_491521502120_item	3652508	et	4	main
väga	doc_491521502120_item	3652507	et	3	main
ajal	doc_491521502120_item	3652506	et	4	main
eestlast	doc_491521502120_item	3652501	et	4	main
vabariigis	doc_491521502120_item	3652496	et	3	main
oli	doc_491521502120_item	3652729	et	3	main
ei	doc_491521502120_item	3652722	et	4	main
see	doc_491521502120_item	3652721	et	3	main
arvamus	doc_491521502120_item	3652718	et	3	main
pärisorjastamine	doc_491521502120_item	3652716	et	3	main
reaalgümnaasiumi	doc_491521502120_item	3652577	et	4	main
aastat	doc_491521502120_item	3652576	et	3	main
3	doc_491521502120_item	3652575	et	2	main
klassi	doc_491521502120_item	3652566	et	4	main
haridusreform	doc_491521502120_item	3652559	et	3	main
oli	doc_491521502120_item	3652557	et	3	main
koolid	doc_491521502120_item	3652555	et	3	main
kutseharidus	doc_491521502120_item	3652553	et	3	main
seetõttu	doc_491521502120_item	3652551	et	3	main
arenes	doc_491521502120_item	3652549	et	3	main
sest	doc_491521502120_item	3652547	et	4	main
komertsharidus	doc_491521502120_item	3652542	et	3	main
5	doc_491521502120_item	3652538	et	2	main
tol	doc_491521502120_item	3652505	et	3	main
kõrgharidussüsteem	doc_491521502120_item	3652503	et	3	main
evs	doc_491521502120_item	3652498	et	4	main
eesti	doc_491521502120_item	3652495	et	4	main
teadus	doc_491521502120_item	3652494	et	4	main
ja	doc_491521502120_item	3652493	et	3	main
kõrgharidus	doc_491521502120_item	3652492	et	3	main
omakeelne	doc_491521502120_item	3652491	et	3	main
1	doc_491521502120_item	3652490	et	2	main
saanud	doc_491521502120_item	3652723	et	4	main
muinasaeg	doc_491521502120_item	3652703	et	3	main
sellele	doc_491521502120_item	3652701	et	4	main
et	doc_491521502120_item	3652691	et	3	main
kõne	doc_491521502123_item	3652997	et	4	main
kolm	doc_491521502123_item	3652992	et	3	main
astronoomia	doc_491521502123_item	3652981	et	4	main
ül	doc_491521502123_item	3652979	et	4	main
tartu	doc_491521502123_item	3652978	et	4	main
vene	doc_491521502123_item	3652959	et	4	main
oli	doc_491521502123_item	3652958	et	3	main
klassi	doc_491521502123_item	3652948	et	4	main
4	doc_491521502123_item	3652947	et	2	main
ja	doc_491521502123_item	3652946	et	3	main
intelegentsust	doc_491521502123_item	3652938	et	4	main
eesti	doc_491521502123_item	3652934	et	4	main
emakeelne	doc_491521502123_item	3652929	et	3	main
hariduse	doc_491521502123_item	3652927	et	3	main
tegema	doc_491521502123_item	3652924	et	3	main
siis	doc_491521502123_item	3652922	et	3	main
tähtis	doc_491521502123_item	3652917	et	4	main
inimesed	doc_491521502123_item	3652914	et	3	main
teadusega	doc_491521502123_item	3652907	et	3	main
arsti	doc_491521502123_item	3652906	et	4	main
ja	doc_491521502123_item	3652905	et	3	main
füüsika	doc_491521502123_item	3652903	et	4	main
väga	doc_491521502123_item	3652901	et	3	main
osakond	doc_491521502123_item	3652900	et	3	main
jälle	doc_491521502123_item	3652892	et	3	main
ta	doc_491521502123_item	3652887	et	4	main
tü	doc_491521502123_item	3652885	et	4	main
avatud	doc_491521502123_item	3652884	et	4	main
läbi	doc_491521502123_item	3653114	et	4	main
seltsid	doc_491521502123_item	3653111	et	4	main
vene	doc_491521502123_item	3653103	et	4	main
ja	doc_491521502123_item	3653102	et	3	main
saksa	doc_491521502123_item	3653101	et	4	main
olemas	doc_491521502123_item	3653100	et	4	main
oli	doc_491521502123_item	3653095	et	3	main
oma	doc_491521502123_item	3653093	et	4	main
elus	doc_491521502123_item	3653087	et	4	main
kultuuri	doc_491521502123_item	3653086	et	4	main
ajalehti	doc_491521502123_item	3653082	et	4	main
rootslased	doc_491521502123_item	3653076	et	3	main
tema	doc_491521502123_item	3653062	et	4	main
kirjameesti	doc_491521502123_item	3653052	et	4	main
laisad	doc_491521502123_item	3653045	et	3	main
ta	doc_491521502123_item	3653040	et	4	main
oli	doc_491521502123_item	3653038	et	3	main
j	doc_491521502123_item	3653037	et	4	main
oli	doc_491521502123_item	3653023	et	3	main
teine	doc_491521502123_item	3653021	et	3	main
pärisorjusest	doc_491521502123_item	3653020	et	4	main
pimedus	doc_491521502123_item	3653010	et	4	main
selline	doc_491521502123_item	3653009	et	4	main
romantiline	doc_491521502123_item	3653008	et	3	main
muinasaeg	doc_491521502123_item	3653007	et	3	main
ehk	doc_491521502123_item	3653006	et	3	main
oma	doc_491521502124_item	3653254	et	4	main
omakeelse	doc_491521502120_item	3652502	et	3	main
omandasid	doc_491521502120_item	3652499	et	4	main
kõrgharidusega	doc_491521502120_item	3652497	et	3	main
väga	doc_491521502120_item	3652730	et	3	main
sest	doc_491521502120_item	3652727	et	4	main
eestlaste	doc_491521502120_item	3652715	et	4	main
ristirüütlid	doc_491521502120_item	3652714	et	3	main
jõudsid	doc_491521502120_item	3652713	et	4	main
eestis	doc_491521502120_item	3652712	et	3	main
13	doc_491521502120_item	3652709	et	2	main
eestlastel	doc_491521502120_item	3652695	et	4	main
oli	doc_491521502120_item	3652694	et	3	main
ristiusku	doc_491521502120_item	3652693	et	4	main
enne	doc_491521502120_item	3652692	et	4	main
asi	doc_491521502120_item	3652683	et	4	main
huvtav	doc_491521502120_item	3652682	et	4	main
idealiseeritud	doc_491521502120_item	3652681	et	4	main
mis	doc_491521502120_item	3652680	et	4	main
faktid	doc_491521502120_item	3652679	et	3	main
ajaloolised	doc_491521502120_item	3652678	et	4	main
raakis	doc_491521502120_item	3652677	et	4	main
saj	doc_491521502120_item	3652676	et	4	main
13	doc_491521502120_item	3652675	et	2	main
enne	doc_491521502120_item	3652674	et	4	main
oli	doc_491521502120_item	3652673	et	3	main
muinasaeg	doc_491521502120_item	3652672	et	3	main
ehk	doc_491521502120_item	3652671	et	3	main
valgus	doc_491521502120_item	3652670	et	4	main
1	doc_491521502120_item	3652669	et	2	main
elus	doc_491521502120_item	3652668	et	4	main
valguse	doc_491521502123_item	3652998	et	4	main
ärkamisaegses	doc_491521502123_item	3652987	et	3	main
robert	doc_491521502123_item	3652984	et	4	main
carl	doc_491521502123_item	3652983	et	4	main
2	doc_491521502123_item	3652982	et	2	main
etnograafia	doc_491521502123_item	3652980	et	4	main
mõju	doc_491521502123_item	3652957	et	4	main
suur	doc_491521502123_item	3652956	et	3	main
ja	doc_491521502123_item	3652955	et	3	main
ma	doc_491521502123_item	3652940	et	3	main
eesti	doc_491521502123_item	3652937	et	4	main
kõrgharidus	doc_491521502123_item	3652930	et	3	main
peale	doc_491521502123_item	3652928	et	4	main
suur	doc_491521502123_item	3652925	et	3	main
kui	doc_491521502123_item	3652919	et	3	main
olid	doc_491521502123_item	3652911	et	4	main
saj	doc_491521502120_item	3652710	et	4	main
et	doc_491521502120_item	3652702	et	3	main
pimeduse	doc_491521502123_item	3652999	et	4	main
kõnet	doc_491521502123_item	3652994	et	3	main
isamaa	doc_491521502123_item	3652993	et	4	main
kõnet	doc_491521502123_item	3652991	et	3	main
pidas	doc_491521502123_item	3652990	et	3	main
jakobson	doc_491521502123_item	3652989	et	4	main
keskus	doc_491521502123_item	3652977	et	3	main
arheoloogia	doc_491521502123_item	3652976	et	4	main
1	doc_491521502123_item	3652975	et	2	main
tü	doc_491521502123_item	3652964	et	4	main
ja	doc_491521502123_item	3652963	et	3	main
teadlastest	doc_491521502123_item	3652962	et	3	main
eesti	doc_491521502123_item	3652951	et	4	main
tabas	doc_491521502123_item	3652933	et	4	main
riigiülestõus	doc_491521502123_item	3652921	et	4	main
algkool	doc_491521502123_item	3652918	et	4	main
ja	doc_491521502123_item	3652915	et	3	main
haritud	doc_491521502123_item	3652913	et	4	main
vajad	doc_491521502123_item	3652912	et	4	main
keemia	doc_491521502123_item	3652904	et	4	main
palju	doc_491521502123_item	3652902	et	4	main
keelne	doc_491521502123_item	3652898	et	3	main
kinni	doc_491521502123_item	3652891	et	3	main
oli	doc_491521502123_item	3652888	et	3	main
eestis	doc_491521502123_item	3653112	et	3	main
ühinguid	doc_491521502123_item	3653094	et	3	main
rajada	doc_491521502123_item	3653092	et	3	main
emakeeles	doc_491521502123_item	3653085	et	4	main
anti	doc_491521502123_item	3653080	et	3	main
keeles	doc_491521502123_item	3653079	et	4	main
nende	doc_491521502123_item	3653078	et	4	main
vähemusrahvas	doc_491521502123_item	3653074	et	4	main
eesti	doc_491521502123_item	3653072	et	4	main
3	doc_491521502123_item	3653067	et	2	main
ärkamisajal	doc_491521502123_item	3653066	et	3	main
tõuke	doc_491521502123_item	3653065	et	4	main
seotus	doc_491521502123_item	3653057	et	4	main
ta	doc_491521502123_item	3653054	et	4	main
arvas	doc_491521502123_item	3653041	et	3	main
ja	doc_491521502123_item	3653031	et	3	main
valitsust	doc_491521502123_item	3653030	et	4	main
rootsi	doc_491521502123_item	3653029	et	4	main
tõstis	doc_491521502123_item	3653028	et	4	main
ta	doc_491521502123_item	3653027	et	4	main
et	doc_491521502123_item	3653026	et	3	main
sellega	doc_491521502123_item	3653025	et	3	main
oma	doc_491521502124_item	3653252	et	4	main
luua	doc_491521502124_item	3653242	et	4	main
seltse	doc_491521502124_item	3653241	et	3	main
omakeelseid	doc_491521502124_item	3653240	et	3	main
võisid	doc_491521502124_item	3653239	et	4	main
vähemusrahvused	doc_491521502124_item	3653238	et	3	main
vabariigis	doc_491521502124_item	3653237	et	3	main
algatajaid	doc_491521502124_item	3653228	et	4	main
rahvusliikumise	doc_491521502124_item	3653227	et	3	main
üks	doc_491521502124_item	3653226	et	3	main
oli	doc_491521502124_item	3653225	et	3	main
kasutamist	doc_491521502124_item	3653224	et	4	main
ning	doc_491521502124_item	3653223	et	3	main
eesti	doc_491521502124_item	3653205	et	4	main
võitles	doc_491521502124_item	3653204	et	3	main
carl	doc_491521502124_item	3653195	et	4	main
põhjalikult	doc_491521502124_item	3653165	et	4	main
meditsiini	doc_491521502124_item	3653158	et	4	main
kirjandust	doc_491521502124_item	3653157	et	3	main
eesti	doc_491521502124_item	3653145	et	4	main
teadus	doc_491521502124_item	3653132	et	4	main
ja	doc_491521502124_item	3653131	et	3	main
kõrgharidus	doc_491521502124_item	3653130	et	3	main
omakeelne	doc_491521502124_item	3653129	et	3	main
ta	doc_491521502120_item	3652700	et	4	main
tuleb	doc_491521502120_item	3652699	et	3	main
kokkuvõttes	doc_491521502120_item	3652698	et	3	main
usk	doc_491521502120_item	3652697	et	3	main
parem	doc_491521502120_item	3652696	et	4	main
arvas	doc_491521502120_item	3652690	et	3	main
ta	doc_491521502120_item	3652689	et	4	main
mütoloogia	doc_491521502120_item	3652688	et	4	main
uus	doc_491521502120_item	3652687	et	3	main
oli	doc_491521502120_item	3652686	et	3	main
enne	doc_491521502123_item	3653003	et	4	main
tema	doc_491521502123_item	3652995	et	4	main
eestis	doc_491521502123_item	3652988	et	3	main
jakobsoni	doc_491521502123_item	3652985	et	4	main
tõuge	doc_491521502123_item	3652968	et	4	main
suur	doc_491521502123_item	3652967	et	3	main
oli	doc_491521502123_item	3652966	et	3	main
rajamine	doc_491521502123_item	3652965	et	4	main
1630	doc_491521502123_item	3652954	et	2	main
algas	doc_491521502123_item	3652953	et	3	main
teadus	doc_491521502123_item	3652952	et	4	main
prestiizne	doc_491521502123_item	3652945	et	4	main
oli	doc_491521502123_item	3652944	et	3	main
haridus	doc_491521502123_item	3652943	et	3	main
kirjutasin	doc_491521502123_item	3652942	et	3	main
juba	doc_491521502123_item	3652941	et	3	main
mis	doc_491521502123_item	3652932	et	4	main
oli	doc_491521502123_item	3652920	et	3	main
oli	doc_491521502123_item	3652916	et	3	main
ülikoolis	doc_491521502123_item	3652895	et	4	main
lahti	doc_491521502123_item	3652894	et	4	main
läks	doc_491521502123_item	3652893	et	3	main
eksamitöö	doc_491521502123_item	3652873	et	4	main
ja	doc_491521502123_item	3653113	et	3	main
olid	doc_491521502123_item	3653110	et	4	main
sest	doc_491521502123_item	3653109	et	4	main
isamaaga	doc_491521502123_item	3653108	et	3	main
seadus	doc_491521502123_item	3653096	et	4	main
eseltse	doc_491521502123_item	3653091	et	4	main
oma	doc_491521502123_item	3653090	et	4	main
oma	doc_491521502123_item	3653084	et	4	main
venelased	doc_491521502123_item	3653075	et	3	main
hariduselu	doc_491521502123_item	3653071	et	4	main
ja	doc_491521502123_item	3653070	et	3	main
kultuur-	doc_491521502123_item	3653069	et	3	main
vähemusrahvuste	doc_491521502123_item	3653068	et	3	main
on	doc_491521502123_item	3653059	et	4	main
selts	doc_491521502123_item	3653053	et	3	main
eesti	doc_491521502123_item	3653051	et	4	main
avatud	doc_491521502123_item	3653050	et	4	main
oli	doc_491521502123_item	3653049	et	3	main
et	doc_491521502123_item	3653042	et	3	main
loiaalne	doc_491521502123_item	3653039	et	4	main
selt	doc_491521502123_item	3653036	et	3	main
eesti	doc_491521502123_item	3653035	et	4	main
kõne	doc_491521502123_item	3653022	et	4	main
on	doc_491521502123_item	3653011	et	4	main
13	doc_491521502123_item	3653004	et	2	main
usu	doc_491521502124_item	3653253	et	4	main
kultuurilised	doc_491521502124_item	3653246	et	4	main
hariduselu	doc_491521502124_item	3653235	et	4	main
ja	doc_491521502124_item	3653234	et	3	main
kultuur-	doc_491521502124_item	3653233	et	3	main
vähemusrahvaste	doc_491521502124_item	3653232	et	4	main
3	doc_491521502124_item	3653231	et	2	main
hurdaga	doc_491521502124_item	3653230	et	3	main
eest	doc_491521502124_item	3653208	et	4	main
jakobson	doc_491521502124_item	3653203	et	4	main
jakobsoni	doc_491521502124_item	3653197	et	4	main
uuriti	doc_491521502124_item	3653164	et	3	main
jne	doc_491521502124_item	3653159	et	4	main
keelt	doc_491521502124_item	3653155	et	4	main
eesti	doc_491521502124_item	3653154	et	4	main
õpetati	doc_491521502124_item	3653153	et	3	main
keeles	doc_491521502124_item	3653146	et	4	main
eesti	doc_491521502124_item	3653135	et	4	main
vabariigis	doc_491521502124_item	3653134	et	3	main
eesti	doc_491521502124_item	3653133	et	4	main
ka	doc_491521502130_item	3653372	et	3	main
eestlased	doc_491521502130_item	3653369	et	3	main
eesti	doc_491521502130_item	3653356	et	4	main
tekstiilitootmine	doc_491521502130_item	3653346	et	3	main
nendest	doc_491521502123_item	3653125	et	4	main
teatasid	doc_491521502123_item	3653124	et	4	main
seal	doc_491521502123_item	3653123	et	4	main
ja	doc_491521502123_item	3653122	et	3	main
isamaal	doc_491521502123_item	3653121	et	4	main
toimub	doc_491521502123_item	3653120	et	3	main
mis	doc_491521502123_item	3653119	et	4	main
kursis	doc_491521502123_item	3653118	et	3	main
olid	doc_491521502123_item	3653117	et	4	main
nad	doc_491521502123_item	3653116	et	3	main
nende	doc_491521502123_item	3653115	et	4	main
valgus	doc_491521502123_item	3653002	et	4	main
koiduajast	doc_491521502123_item	3653001	et	4	main
ja	doc_491521502123_item	3653000	et	3	main
esimene	doc_491521502123_item	3652996	et	3	main
roll	doc_491521502123_item	3652986	et	3	main
uurija	doc_491521502123_item	3652974	et	4	main
anderson	doc_491521502123_item	3652972	et	4	main
muinasjutude	doc_491521502123_item	3652973	et	4	main
keeleuuendus	doc_491521502123_item	3652971	et	3	main
aavik	doc_491521502123_item	3652970	et	4	main
näiteks	doc_491521502123_item	3652969	et	4	main
saksa	doc_491521502123_item	3652961	et	4	main
ja	doc_491521502123_item	3652960	et	3	main
kohustuslikku	doc_491521502123_item	3652950	et	4	main
oli	doc_491521502123_item	3652949	et	3	main
nagu	doc_491521502123_item	3652939	et	3	main
ja	doc_491521502123_item	3652936	et	3	main
keelt	doc_491521502123_item	3652935	et	4	main
süsteem	doc_491521502123_item	3652931	et	3	main
aktsent	doc_491521502123_item	3652926	et	3	main
hakkati	doc_491521502123_item	3652923	et	3	main
väga	doc_491521502123_item	3652910	et	3	main
osakonnad	doc_491521502123_item	3652909	et	4	main
tulid	doc_491521502123_item	3652908	et	4	main
pandud	doc_491521502123_item	3652890	et	4	main
ka	doc_491521502123_item	3652889	et	3	main
aga	doc_491521502123_item	3652886	et	3	main
kontakteerida	doc_491521502123_item	3653106	et	4	main
ning	doc_491521502123_item	3653105	et	3	main
gümnaasiumid	doc_491521502123_item	3653104	et	3	main
võisid	doc_491521502123_item	3653089	et	4	main
nad	doc_491521502123_item	3653088	et	3	main
õppisid	doc_491521502123_item	3653083	et	4	main
sakslased	doc_491521502123_item	3653077	et	3	main
vabariigis	doc_491521502123_item	3653073	et	3	main
et	doc_491521502123_item	3653061	et	3	main
see	doc_491521502123_item	3653060	et	3	main
rahvusliikumisega	doc_491521502123_item	3653056	et	3	main
oli	doc_491521502123_item	3653055	et	3	main
filoloogia	doc_491521502123_item	3652899	et	4	main
eesti	doc_491521502123_item	3652897	et	4	main
avati	doc_491521502123_item	3652896	et	3	main
oli	doc_491521502123_item	3652883	et	3	main
a	doc_491521502123_item	3652882	et	4	main
1632	doc_491521502123_item	3652881	et	2	main
vabariigis	doc_491521502123_item	3652880	et	3	main
eesti	doc_491521502123_item	3652879	et	4	main
teadus	doc_491521502123_item	3652878	et	4	main
ja	doc_491521502123_item	3652877	et	3	main
kõrgharidus	doc_491521502123_item	3652876	et	3	main
omakeelne	doc_491521502123_item	3652875	et	3	main
1	doc_491521502123_item	3652874	et	2	main
oma	doc_491521502123_item	3653107	et	4	main
olid	doc_491521502123_item	3653099	et	4	main
autonoomiast	doc_491521502123_item	3653098	et	3	main
vähemusrahva	doc_491521502123_item	3653097	et	3	main
välja	doc_491521502123_item	3653081	et	4	main
antsid	doc_491521502123_item	3653064	et	4	main
kõned	doc_491521502123_item	3653063	et	3	main
olulisem	doc_491521502123_item	3653058	et	4	main
peavad	doc_491521502123_item	3653047	et	4	main
on	doc_491521502123_item	3653044	et	4	main
talupojad	doc_491521502123_item	3653043	et	4	main
vabastamine	doc_491521502123_item	3653019	et	4	main
on	doc_491521502123_item	3653018	et	4	main
see	doc_491521502123_item	3653017	et	3	main
koiduaeg	doc_491521502123_item	3653016	et	3	main
ja	doc_491521502123_item	3653015	et	3	main
pärisorjusega	doc_491521502123_item	3653014	et	3	main
ristirüütlitega	doc_491521502123_item	3653013	et	3	main
tõusema	doc_491521502123_item	3653048	et	4	main
et	doc_491521502123_item	3653046	et	3	main
õpetatud	doc_491521502123_item	3653034	et	4	main
õpe	doc_491521502123_item	3653033	et	3	main
hindab	doc_491521502123_item	3653032	et	3	main
seotud	doc_491521502123_item	3653024	et	4	main
seotud	doc_491521502123_item	3653012	et	4	main
s	doc_491521502123_item	3653005	et	4	main
keele	doc_491521502124_item	3653251	et	4	main
olid	doc_491521502124_item	3653245	et	4	main
suurematel	doc_491521502124_item	3653243	et	4	main
koos	doc_491521502124_item	3653229	et	4	main
keele	doc_491521502124_item	3653221	et	4	main
haridust	doc_491521502124_item	3653217	et	4	main
omakeelset	doc_491521502124_item	3653216	et	3	main
saada	doc_491521502124_item	3653215	et	4	main
võimalik	doc_491521502124_item	3653214	et	3	main
oleks	doc_491521502124_item	3653213	et	3	main
eestis	doc_491521502124_item	3653212	et	3	main
et	doc_491521502124_item	3653211	et	3	main
tahtis	doc_491521502124_item	3653210	et	3	main
ta	doc_491521502124_item	3653209	et	4	main
2	doc_491521502124_item	3653194	et	2	main
viidi	doc_491521502124_item	3653176	et	4	main
ja	doc_491521502124_item	3653175	et	3	main
õpetati	doc_491521502124_item	3653174	et	3	main
seda	doc_491521502124_item	3653173	et	3	main
meditsiin	doc_491521502124_item	3653172	et	3	main
ka	doc_491521502124_item	3653171	et	3	main
arenes	doc_491521502124_item	3653170	et	3	main
muudeti	doc_491521502124_item	3653168	et	3	main
eestlasteks	doc_491521502124_item	3653276	et	4	main
täiesti	doc_491521502124_item	3653275	et	3	main
muutuma	doc_491521502124_item	3653274	et	4	main
ning	doc_491521502124_item	3653273	et	3	main
unustama	doc_491521502124_item	3653272	et	3	main
juured	doc_491521502124_item	3653271	et	3	main
oma	doc_491521502124_item	3653270	et	4	main
peavad	doc_491521502124_item	3653269	et	4	main
vähemusrahvused	doc_491521502124_item	3653268	et	3	main
et	doc_491521502124_item	3653267	et	3	main
poliitikat	doc_491521502124_item	3653266	et	3	main
sellist	doc_491521502124_item	3653265	et	4	main
olnud	doc_491521502124_item	3653264	et	4	main
ei	doc_491521502124_item	3653263	et	4	main
saada	doc_491521502124_item	3653262	et	4	main
keeles	doc_491521502124_item	3653261	et	4	main
oma	doc_491521502124_item	3653260	et	4	main
algharidust	doc_491521502124_item	3653259	et	4	main
ka	doc_491521502124_item	3653258	et	3	main
võisid	doc_491521502124_item	3653257	et	4	main
nad	doc_491521502124_item	3653256	et	3	main
kombed	doc_491521502124_item	3653255	et	3	main
oma	doc_491521502124_item	3653250	et	4	main
eesti	doc_491521502124_item	3653236	et	4	main
eesti	doc_491521502124_item	3653220	et	4	main
ning	doc_491521502124_item	3653218	et	3	main
kultuuri	doc_491521502124_item	3653206	et	4	main
robert	doc_491521502124_item	3653202	et	4	main
carl	doc_491521502124_item	3653201	et	4	main
eestis	doc_491521502124_item	3653200	et	3	main
ärkamisaegses	doc_491521502124_item	3653199	et	3	main
roll	doc_491521502124_item	3653198	et	3	main
robert	doc_491521502124_item	3653196	et	4	main
õpetajateks	doc_491521502124_item	3653193	et	4	main
pastoriteks	doc_491521502124_item	3653192	et	3	main
seminarides	doc_491521502124_item	3653191	et	3	main
õpida	doc_491521502124_item	3653190	et	4	main
võis	doc_491521502124_item	3653189	et	4	main
keeles	doc_491521502124_item	3653188	et	4	main
eesti	doc_491521502124_item	3653187	et	4	main
hoogsalt	doc_491521502124_item	3653186	et	4	main
samuti	doc_491521502124_item	3653185	et	3	main
arenesid	doc_491521502124_item	3653184	et	4	main
bioloogia	doc_491521502124_item	3653183	et	4	main
astronoomia	doc_491521502124_item	3653182	et	4	main
füüsika	doc_491521502124_item	3653181	et	4	main
tartu	doc_491521502124_item	3653179	et	4	main
ülikoolis	doc_491521502124_item	3653180	et	4	main
uurimusi	doc_491521502124_item	3653178	et	3	main
läbi	doc_491521502124_item	3653177	et	4	main
keelt	doc_491521502124_item	3653167	et	4	main
keeleteadus	doc_491521502124_item	3653163	et	4	main
hakkas	doc_491521502124_item	3653160	et	3	main
eesti	doc_491521502124_item	3653150	et	4	main
oli	doc_491521502124_item	3653149	et	3	main
ülikool	doc_491521502124_item	3653148	et	4	main
tartu	doc_491521502124_item	3653147	et	4	main
1	doc_491521502124_item	3653128	et	2	main
rühmituse	doc_491521502130_item	3653351	et	4	main
3	doc_491521502130_item	3653350	et	2	main
põhjamaadest	doc_491521502130_item	3653338	et	4	main
inglismaalt	doc_491521502130_item	3653337	et	3	main
tagasilangus	doc_491521502130_item	3653326	et	4	main
järgnes	doc_491521502130_item	3653325	et	3	main
majanduse	doc_491521502130_item	3653322	et	4	main
peamised	doc_491521502130_item	3653319	et	3	main
iseloomustavad	doc_491521502130_item	3653318	et	4	main
oma	doc_491521502130_item	3653311	et	4	main
tahtmine	doc_491521502130_item	3653300	et	4	main
2	doc_491521502130_item	3653298	et	2	main
kaotamine	doc_491521502130_item	3653297	et	4	main
pärisorjuse	doc_491521502130_item	3653296	et	3	main
daomineerib	doc_491521502132_item	3653722	et	4	main
eesti	doc_491521502132_item	3653715	et	4	main
valu	doc_491521502132_item	3653714	et	4	main
rahvuslikult	doc_491521502132_item	3653708	et	4	main
ka	doc_491521502132_item	3653700	et	3	main
f	doc_491521502132_item	3653692	et	4	main
adson	doc_491521502132_item	3653691	et	4	main
kirjanikke	doc_491521502132_item	3653690	et	3	main
koondas	doc_491521502132_item	3653689	et	3	main
sweda	doc_491521502132_item	3653684	et	4	main
kirjanduslik	doc_491521502132_item	3653675	et	3	main
alatoon	doc_491521502132_item	3653674	et	3	main
säilitasid	doc_491521502124_item	3653249	et	4	main
vähemusrahvused	doc_491521502124_item	3653248	et	3	main
autonoomiad	doc_491521502124_item	3653247	et	3	main
neist	doc_491521502124_item	3653244	et	4	main
arendamist	doc_491521502124_item	3653222	et	4	main
propagandeeris	doc_491521502124_item	3653219	et	4	main
taasärkamise	doc_491521502124_item	3653207	et	4	main
eesti	doc_491521502124_item	3653166	et	4	main
kiiremini	doc_491521502124_item	3653161	et	4	main
keskuseks	doc_491521502124_item	3653152	et	4	main
hariduse	doc_491521502124_item	3653151	et	3	main
kõrgharidust	doc_491521502124_item	3653144	et	4	main
saada	doc_491521502124_item	3653139	et	4	main
vabariigis	doc_491521502124_item	3653136	et	3	main
eksamitöö	doc_491521502124_item	3653127	et	4	main
see	doc_491521502130_item	3653374	et	3	main
eurooplasteks	doc_491521502130_item	3653373	et	3	main
saagem	doc_491521502130_item	3653371	et	3	main
kõlanud	doc_491521502130_item	3653367	et	4	main
motoks	doc_491521502130_item	3653360	et	3	main
noor-eesti	doc_491521502130_item	3653359	et	4	main
tähtsus	doc_491521502130_item	3653355	et	4	main
ja	doc_491521502130_item	3653354	et	3	main
majandus	doc_491521502130_item	3653340	et	4	main
3	doc_491521502130_item	3653339	et	2	main
majandust	doc_491521502130_item	3653317	et	4	main
vabariigi	doc_491521502130_item	3653316	et	3	main
vajadus	doc_491521502130_item	3653306	et	3	main
3	doc_491521502130_item	3653305	et	2	main
suur	doc_491521502130_item	3653299	et	3	main
alatoon	doc_491521502132_item	3653724	et	3	main
olid	doc_491521502132_item	3653707	et	4	main
kirjanikud	doc_491521502132_item	3653706	et	3	main
gailit	doc_491521502132_item	3653695	et	4	main
visnapuu	doc_491521502132_item	3653694	et	4	main
tegevust	doc_491521502132_item	3653685	et	4	main
nimetus	doc_491521502132_item	3653682	et	4	main
pärast	doc_491521502132_item	3653678	et	4	main
vabriigi	doc_491521502132_item	3653670	et	4	main
loomine	doc_491521502132_item	3653664	et	4	main
on	doc_491521502132_item	3653662	et	4	main
nimigi	doc_491521502132_item	3653660	et	3	main
kultuuriloos	doc_491521502132_item	3653657	et	4	main
eesti	doc_491521502132_item	3653656	et	4	main
rühmituse	doc_491521502132_item	3653651	et	4	main
3	doc_491521502132_item	3653650	et	2	main
väikeettevõttetele	doc_491521502132_item	3653646	et	4	main
puudutasid	doc_491521502132_item	3653644	et	4	main
mis	doc_491521502132_item	3653643	et	4	main
tööstusharusid	doc_491521502132_item	3653642	et	3	main
aastani	doc_491521502132_item	3653624	et	3	main
ev	doc_491521502132_item	3653619	et	4	main
oli	doc_491521502132_item	3653618	et	3	main
juur-	doc_491521502132_item	3653614	et	3	main
papa	doc_491521502132_item	3653444	et	4	main
jne	doc_491521502132_item	3653432	et	4	main
elab	doc_491521502132_item	3653431	et	3	main
liivimaa	doc_491521502132_item	3653421	et	4	main
eestimaa	doc_491521502132_item	3653417	et	4	main
tomus	doc_491521502132_item	3653405	et	4	main
peamised	doc_491521502132_item	3653403	et	3	main
enda	doc_491521502132_item	3653401	et	4	main
olid	doc_491521502132_item	3653399	et	4	main
vi	doc_491521502132_item	3653607	et	4	main
kanamunad	doc_491521502132_item	3653606	et	3	main
v	doc_491521502132_item	3653605	et	4	main
tekstiilitööstus	doc_491521502132_item	3653604	et	3	main
kasutas	doc_491521502132_item	3653603	et	3	main
iv	doc_491521502132_item	3653601	et	4	main
miinustes	doc_491521502132_item	3653573	et	3	main
maksis	doc_491521502132_item	3653569	et	4	main
kahekordselt	doc_491521502132_item	3653563	et	4	main
ületas	doc_491521502132_item	3653562	et	3	main
see	doc_491521502132_item	3653561	et	3	main
alustati	doc_491521502132_item	3653550	et	4	main
kindlustada	doc_491521502132_item	3653547	et	3	main
venemaast	doc_491521502132_item	3653541	et	3	main
leedust	doc_491521502132_item	3653537	et	4	main
teisi	doc_491521502132_item	3653527	et	4	main
nüüd	doc_491521502132_item	3653524	et	4	main
katkenud	doc_491521502132_item	3653522	et	4	main
seda	doc_491521502124_item	3653169	et	3	main
arenema	doc_491521502124_item	3653162	et	3	main
juurat	doc_491521502124_item	3653156	et	3	main
ka	doc_491521502124_item	3653143	et	3	main
kui	doc_491521502124_item	3653142	et	3	main
alg-	doc_491521502124_item	3653141	et	3	main
nii	doc_491521502124_item	3653140	et	3	main
võimalik	doc_491521502124_item	3653138	et	3	main
oli	doc_491521502124_item	3653137	et	3	main
aga	doc_491521502130_item	3653370	et	3	main
võib	doc_491521502130_item	3653361	et	3	main
olemus	doc_491521502130_item	3653353	et	3	main
noor-eesti	doc_491521502130_item	3653352	et	4	main
vajadustele	doc_491521502130_item	3653345	et	4	main
orienteerutud	doc_491521502130_item	3653343	et	4	main
majandusturg	doc_491521502130_item	3653335	et	3	main
aa	doc_491521502130_item	3653334	et	3	main
eesti	doc_491521502130_item	3653328	et	4	main
2	doc_491521502130_item	3653314	et	2	main
säilitamises	doc_491521502130_item	3653313	et	4	main
mõju	doc_491521502130_item	3653303	et	4	main
a	doc_491521502130_item	3653294	et	4	main
1819	doc_491521502130_item	3653293	et	2	main
eestimaal	doc_491521502130_item	3653291	et	4	main
ja	doc_491521502130_item	3653292	et	3	main
a	doc_491521502130_item	3653290	et	4	main
1816	doc_491521502130_item	3653289	et	2	main
1	doc_491521502130_item	3653288	et	2	main
peamised	doc_491521502130_item	3653287	et	3	main
arvates	doc_491521502130_item	3653286	et	4	main
enda	doc_491521502130_item	3653285	et	4	main
loetle	doc_491521502130_item	3653284	et	4	main
olid	doc_491521502130_item	3653283	et	4	main
eeltingimusteks	doc_491521502130_item	3653282	et	3	main
ärkamise	doc_491521502130_item	3653281	et	4	main
rahvusliku	doc_491521502130_item	3653280	et	3	main
1	doc_491521502130_item	3653279	et	2	main
eksamitöö	doc_491521502130_item	3653278	et	4	main
ühiskonda	doc_491521502132_item	3653720	et	4	main
meelestatud	doc_491521502132_item	3653709	et	4	main
53	doc_491521502132_item	3653703	et	2	main
albumeid	doc_491521502132_item	3653702	et	3	main
kirjanduslikke	doc_491521502132_item	3653701	et	3	main
tuglas	doc_491521502132_item	3653693	et	4	main
noor-eesti	doc_491521502132_item	3653687	et	4	main
siuru	doc_491521502132_item	3653683	et	4	main
poeetiline	doc_491521502132_item	3653681	et	3	main
laululinnu	doc_491521502132_item	3653680	et	4	main
ilusa	doc_491521502132_item	3653679	et	3	main
kirjanduses	doc_491521502132_item	3653672	et	3	main
tähtsus	doc_491521502132_item	3653655	et	4	main
ja	doc_491521502132_item	3653654	et	3	main
olemus	doc_491521502132_item	3653653	et	3	main
kahjuks	doc_491521502132_item	3653647	et	4	main
1924	doc_491521502132_item	3653636	et	2	main
ülesehituse	doc_491521502132_item	3653621	et	3	main
puuvilju	doc_491521502132_item	3653616	et	3	main
eksporditi	doc_491521502132_item	3653613	et	3	main
nimetab	doc_491521502132_item	3653443	et	3	main
mis	doc_491521502132_item	3653438	et	4	main
kus	doc_491521502132_item	3653429	et	3	main
valida	doc_491521502132_item	3653428	et	3	main
sai	doc_491521502132_item	3653427	et	4	main
talupoeg	doc_491521502132_item	3653426	et	3	main
pärisorjus	doc_491521502132_item	3653425	et	3	main
kubermangus	doc_491521502132_item	3653422	et	3	main
lutsuga	doc_491521502130_item	3653392	et	3	main
nt	doc_491521502130_item	3653391	et	4	main
esindajatega	doc_491521502130_item	3653390	et	4	main
realismi	doc_491521502130_item	3653389	et	4	main
elitaarsusele	doc_491521502130_item	3653388	et	4	main
püüd	doc_491521502130_item	3653387	et	4	main
suur	doc_491521502130_item	3653386	et	3	main
oli	doc_491521502130_item	3653385	et	3	main
nooreestlastel	doc_491521502130_item	3653384	et	4	main
tuglas	doc_491521502130_item	3653383	et	4	main
friedebert	doc_491521502130_item	3653382	et	4	main
oli	doc_491521502130_item	3653381	et	3	main
esindaja	doc_491521502130_item	3653380	et	4	main
kuulus	doc_491521502130_item	3653379	et	4	main
teine	doc_491521502130_item	3653378	et	3	main
a	doc_491521502130_item	3653377	et	4	main
1905	doc_491521502130_item	3653376	et	2	main
opli	doc_491521502130_item	3653375	et	4	main
olgem	doc_491521502130_item	3653368	et	3	main
suu	doc_491521502130_item	3653366	et	4	main
suitsu	doc_491521502130_item	3653365	et	4	main
gustav	doc_491521502130_item	3653364	et	4	main
läbi	doc_491521502130_item	3653363	et	4	main
pidada	doc_491521502130_item	3653362	et	4	main
rühmituse	doc_491521502130_item	3653358	et	4	main
kultuuriloos	doc_491521502130_item	3653357	et	4	main
tootmine	doc_491521502130_item	3653349	et	4	main
ehitusmaterjalide	doc_491521502130_item	3653348	et	3	main
paberitööstus	doc_491521502130_item	3653347	et	3	main
venemaa	doc_491521502130_item	3653344	et	4	main
peamiselt	doc_491521502130_item	3653342	et	4	main
oli	doc_491521502130_item	3653341	et	3	main
sõltuvuses	doc_491521502130_item	3653330	et	4	main
majandus	doc_491521502130_item	3653329	et	4	main
esialgne	doc_491521502130_item	3653323	et	3	main
1	doc_491521502130_item	3653321	et	2	main
tunnused	doc_491521502130_item	3653320	et	3	main
identiteedi	doc_491521502130_item	3653312	et	4	main
keele	doc_491521502130_item	3653309	et	4	main
baltisakslaste	doc_491521502130_item	3653302	et	4	main
vabaneda	doc_491521502130_item	3653301	et	3	main
traagiline	doc_491521502132_item	3653723	et	3	main
ja	doc_491521502132_item	3653718	et	3	main
vabariigi	doc_491521502132_item	3653716	et	3	main
kuulus	doc_491521502132_item	3653705	et	4	main
rühmitus	doc_491521502132_item	3653688	et	4	main
esimese	doc_491521502132_item	3653668	et	3	main
noor-eesti	doc_491521502132_item	3653663	et	4	main
ütleb	doc_491521502132_item	3653661	et	3	main
nagu	doc_491521502132_item	3653658	et	3	main
tuli	doc_491521502132_item	3653648	et	4	main
eksporti	doc_491521502132_item	3653645	et	4	main
a	doc_491521502132_item	3653637	et	4	main
sisse	doc_491521502132_item	3653612	et	4	main
ise	doc_491521502132_item	3653611	et	4	main
ilmuna	doc_491521502132_item	3653440	et	4	main
eesti	doc_491521502132_item	3653436	et	4	main
1864	doc_491521502132_item	3653435	et	2	main
postimehes	doc_491521502132_item	3653434	et	3	main
perno	doc_491521502132_item	3653433	et	4	main
sunnismaine	doc_491521502132_item	3653424	et	4	main
kaotati	doc_491521502132_item	3653423	et	3	main
a	doc_491521502132_item	3653415	et	4	main
talude	doc_491521502132_item	3653406	et	3	main
1866	doc_491521502132_item	3653404	et	2	main
teravilja	doc_491521502132_item	3653608	et	4	main
eesti	doc_491521502132_item	3653571	et	4	main
kuid	doc_491521502132_item	3653560	et	4	main
võlgu	doc_491521502132_item	3653556	et	4	main
kaevandamisega	doc_491521502132_item	3653552	et	4	main
forforiidi	doc_491521502132_item	3653551	et	4	main
oma	doc_491521502132_item	3653545	et	4	main
mõttes	doc_491521502132_item	3653539	et	3	main
rohkem	doc_491521502132_item	3653526	et	4	main
tunnused	doc_491521502132_item	3653510	et	3	main
majandust	doc_491521502132_item	3653507	et	4	main
eesti	doc_491521502132_item	3653505	et	4	main
kujunemine	doc_491521502132_item	3653503	et	4	main
oluline	doc_491521502132_item	3653497	et	4	main
oli	doc_491521502132_item	3653496	et	3	main
areng	doc_491521502132_item	3653495	et	3	main
väägveres	doc_491521502132_item	3653491	et	4	main
selts	doc_491521502132_item	3653488	et	3	main
laulu-	doc_491521502132_item	3653485	et	4	main
vanemuise	doc_491521502132_item	3653484	et	4	main
1875	doc_491521502132_item	3653483	et	2	main
linnades	doc_491521502183_item	3653876	et	3	main
kaotamist	doc_491521502183_item	3653870	et	4	main
pärisorjuse	doc_491521502183_item	3653869	et	3	main
ka	doc_491521502183_item	3653857	et	3	main
1832	doc_491521502183_item	3653855	et	2	main
võimalus	doc_491521502183_item	3653853	et	3	main
ka	doc_491521502183_item	3653850	et	3	main
osta	doc_491521502183_item	3653840	et	4	main
müüa	doc_491521502183_item	3653839	et	3	main
vallasvara	doc_491521502183_item	3653834	et	4	main
lepinguid	doc_491521502183_item	3653833	et	3	main
isiklikult	doc_491521502183_item	3653829	et	4	main
1819	doc_491521502183_item	3653827	et	2	main
ilmub	doc_491521502183_item	3653815	et	3	main
trükiseid	doc_491521502183_item	3653814	et	3	main
enamik	doc_491521502183_item	3653813	et	3	main
1870	doc_491521502183_item	3653808	et	2	main
sõnu	doc_491521502183_item	3653807	et	4	main
uus	doc_491521502183_item	3653800	et	3	main
sõltus	doc_491521502130_item	3653336	et	4	main
1920	doc_491521502130_item	3653333	et	2	main
turust	doc_491521502130_item	3653332	et	3	main
euroopa	doc_491521502130_item	3653331	et	4	main
2	doc_491521502130_item	3653327	et	2	main
elavnemisele	doc_491521502130_item	3653324	et	4	main
eesti	doc_491521502130_item	3653315	et	4	main
arenemises	doc_491521502130_item	3653310	et	4	main
eesti	doc_491521502130_item	3653308	et	4	main
oma	doc_491521502130_item	3653307	et	4	main
allt	doc_491521502130_item	3653304	et	4	main
liivimaal	doc_491521502130_item	3653295	et	4	main
kirjanduses	doc_491521502132_item	3653721	et	3	main
sotsiaalselt	doc_491521502132_item	3653719	et	4	main
kujunemist	doc_491521502132_item	3653717	et	4	main
elu	doc_491521502132_item	3653713	et	4	main
eesti	doc_491521502132_item	3653712	et	4	main
kujutasid	doc_491521502132_item	3653711	et	4	main
ja	doc_491521502132_item	3653710	et	3	main
kirjanikku	doc_491521502132_item	3653704	et	4	main
välja	doc_491521502132_item	3653699	et	4	main
anti	doc_491521502132_item	3653698	et	3	main
suits	doc_491521502132_item	3653697	et	3	main
g	doc_491521502132_item	3653696	et	4	main
jätkas	doc_491521502132_item	3653686	et	3	main
loodi	doc_491521502132_item	3653677	et	4	main
rähmitus	doc_491521502132_item	3653676	et	4	main
sünniga	doc_491521502132_item	3653671	et	3	main
tegevus	doc_491521502132_item	3653666	et	4	main
noor-eesti	doc_491521502132_item	3653652	et	4	main
neid	doc_491521502132_item	3653641	et	4	main
eelkõige	doc_491521502132_item	3653640	et	3	main
puudutas	doc_491521502132_item	3653639	et	3	main
töölisi	doc_491521502132_item	3653635	et	3	main
poolast	doc_491521502132_item	3653634	et	3	main
toodi	doc_491521502132_item	3653633	et	4	main
tööjõupuudus	doc_491521502132_item	3653632	et	3	main
juba	doc_491521502132_item	3653631	et	3	main
oli	doc_491521502132_item	3653630	et	3	main
a	doc_491521502132_item	3653629	et	4	main
1937	doc_491521502132_item	3653628	et	2	main
alates	doc_491521502132_item	3653627	et	3	main
tööpuudus	doc_491521502132_item	3653626	et	3	main
oli	doc_491521502132_item	3653625	et	3	main
1934	doc_491521502132_item	3653623	et	2	main
a	doc_491521502132_item	3653442	et	4	main
1857	doc_491521502132_item	3653441	et	2	main
ta	doc_491521502132_item	3653430	et	4	main
a	doc_491521502132_item	3653411	et	4	main
1865	doc_491521502132_item	3653410	et	2	main
arvates	doc_491521502132_item	3653402	et	4	main
loetle	doc_491521502132_item	3653400	et	4	main
eeltingimusteks	doc_491521502132_item	3653398	et	3	main
ärkamise	doc_491521502132_item	3653397	et	4	main
rahvusliku	doc_491521502132_item	3653396	et	3	main
1	doc_491521502132_item	3653395	et	2	main
traagiline	doc_491521502132_item	3653673	et	3	main
eesti	doc_491521502132_item	3653669	et	4	main
seotud	doc_491521502132_item	3653667	et	4	main
ja	doc_491521502132_item	3653665	et	3	main
juba	doc_491521502132_item	3653659	et	3	main
see	doc_491521502132_item	3653649	et	3	main
majkriis	doc_491521502132_item	3653638	et	4	main
aastad	doc_491521502132_item	3653622	et	3	main
majandusliku	doc_491521502132_item	3653620	et	3	main
19191924	doc_491521502132_item	3653617	et	2	main
ja	doc_491521502132_item	3653615	et	3	main
hakkas	doc_491521502132_item	3653439	et	3	main
postimees	doc_491521502132_item	3653437	et	4	main
a	doc_491521502132_item	3653420	et	4	main
kubermangus	doc_491521502132_item	3653418	et	3	main
kaotati	doc_491521502132_item	3653416	et	3	main
1816	doc_491521502132_item	3653414	et	2	main
kodukariõigus	doc_491521502132_item	3653413	et	4	main
kaotati	doc_491521502132_item	3653412	et	3	main
venemaale	doc_491521502132_item	3653600	et	4	main
inglismaale	doc_491521502132_item	3653599	et	4	main
põhil	doc_491521502132_item	3653598	et	4	main
loomad	doc_491521502132_item	3653597	et	3	main
iii	doc_491521502132_item	3653596	et	4	main
juust	doc_491521502132_item	3653595	et	4	main
ii	doc_491521502132_item	3653594	et	4	main
või	doc_491521502132_item	3653593	et	4	main
i	doc_491521502132_item	3653592	et	4	main
piimatooteid	doc_491521502132_item	3653591	et	4	main
peamiselt	doc_491521502132_item	3653590	et	4	main
eksporditi	doc_491521502132_item	3653589	et	3	main
ette	doc_491521502132_item	3653588	et	4	main
isegi	doc_491521502132_item	3653587	et	4	main
tööstusest	doc_491521502132_item	3653586	et	4	main
metallurgia	doc_491521502132_item	3653585	et	4	main
ja	doc_491521502132_item	3653584	et	3	main
masina-	doc_491521502132_item	3653583	et	3	main
jõudis	doc_491521502132_item	3653582	et	3	main
esikohale	doc_491521502132_item	3653581	et	4	main
jõudis	doc_491521502132_item	3653580	et	3	main
võtma	doc_491521502132_item	3653579	et	3	main
juurde	doc_491521502132_item	3653578	et	4	main
hoogu	doc_491521502132_item	3653577	et	4	main
hakkas	doc_491521502132_item	3653576	et	3	main
aga	doc_491521502132_item	3653575	et	3	main
soomele	doc_491521502132_item	3653558	et	4	main
vabariik	doc_491521502132_item	3653554	et	3	main
siseturgu	doc_491521502132_item	3653546	et	4	main
ka	doc_491521502132_item	3653540	et	3	main
eesti	doc_491521502132_item	3653530	et	4	main
kuid	doc_491521502132_item	3653523	et	4	main
ei	doc_491521502132_item	3653521	et	4	main
uued	doc_491521502132_item	3653511	et	3	main
arenemine	doc_491521502132_item	3653500	et	4	main
i	doc_491521502132_item	3653490	et	4	main
koore	doc_491521502132_item	3653482	et	4	main
vabrikud	doc_491521502183_item	3653878	et	3	main
linnas	doc_491521502183_item	3653874	et	4	main
pärast	doc_491521502183_item	3653868	et	4	main
nälgi	doc_491521502183_item	3653866	et	4	main
kohtukorraldust	doc_491521502183_item	3653858	et	3	main
alles	doc_491521502183_item	3653854	et	3	main
vabalt	doc_491521502183_item	3653848	et	4	main
1819	doc_491521502132_item	3653419	et	2	main
passiseadus	doc_491521502132_item	3653409	et	4	main
1863	doc_491521502132_item	3653408	et	2	main
päriseksostmine	doc_491521502132_item	3653407	et	3	main
eksamitöö	doc_491521502132_item	3653394	et	4	main
osteti	doc_491521502132_item	3653610	et	3	main
aga	doc_491521502132_item	3653609	et	3	main
lambavilla	doc_491521502132_item	3653602	et	4	main
tekstiilitööstus	doc_491521502132_item	3653574	et	3	main
venemaa	doc_491521502132_item	3653570	et	4	main
kuldrubla	doc_491521502132_item	3653566	et	4	main
miljonit	doc_491521502132_item	3653565	et	3	main
15	doc_491521502132_item	3653564	et	2	main
raha	doc_491521502132_item	3653557	et	4	main
et	doc_491521502132_item	3653544	et	3	main
kehtestati	doc_491521502132_item	3653542	et	3	main
ja	doc_491521502132_item	3653536	et	3	main
balkanimaadest	doc_491521502132_item	3653534	et	4	main
ette	doc_491521502132_item	3653533	et	4	main
jõudnud	doc_491521502132_item	3653532	et	4	main
oli	doc_491521502132_item	3653531	et	3	main
võlisturgusid	doc_491521502132_item	3653528	et	4	main
küll	doc_491521502132_item	3653520	et	4	main
vallas	doc_491521502132_item	3653519	et	3	main
põlevkivi	doc_491521502132_item	3653515	et	4	main
paekivimurrud	doc_491521502132_item	3653514	et	3	main
kaevandus-	doc_491521502132_item	3653513	et	4	main
tööstusharud	doc_491521502132_item	3653512	et	3	main
iseloomustavad	doc_491521502132_item	3653508	et	4	main
vabariigi	doc_491521502132_item	3653506	et	3	main
2	doc_491521502132_item	3653504	et	2	main
kõrgkultuuri	doc_491521502132_item	3653499	et	4	main
rahvusliku	doc_491521502132_item	3653498	et	3	main
teaduse	doc_491521502132_item	3653492	et	3	main
ja	doc_491521502132_item	3653486	et	3	main
asutati	doc_491521502132_item	3653481	et	4	main
ka	doc_491521502132_item	3653479	et	3	main
arendati	doc_491521502132_item	3653478	et	3	main
kuigi	doc_491521502132_item	3653477	et	3	main
poliitikat	doc_491521502132_item	3653476	et	3	main
võib	doc_491521502183_item	3653880	et	3	main
kasvama	doc_491521502183_item	3653875	et	3	main
eestlaste	doc_491521502183_item	3653872	et	4	main
hakkab	doc_491521502183_item	3653871	et	3	main
linnadesse	doc_491521502183_item	3653847	et	3	main
ise	doc_491521502183_item	3653832	et	4	main
sõlmivad	doc_491521502183_item	3653831	et	4	main
talupojad	doc_491521502183_item	3653828	et	4	main
1816	doc_491521502183_item	3653825	et	2	main
2	doc_491521502183_item	3653823	et	2	main
kreutzwald	doc_491521502183_item	3653822	et	4	main
ka	doc_491521502183_item	3653821	et	3	main
pooldab	doc_491521502183_item	3653820	et	3	main
ideid	doc_491521502183_item	3653819	et	3	main
uus	doc_491521502183_item	3653810	et	3	main
keelde	doc_491521502183_item	3653805	et	4	main
keelt	doc_491521502183_item	3653792	et	4	main
pärisorjus	doc_491521502183_item	3653761	et	3	main
ning	doc_491521502183_item	3653758	et	3	main
valgustuslikke	doc_491521502183_item	3653756	et	3	main
parrot	doc_491521502183_item	3653754	et	4	main
rektoriks	doc_491521502183_item	3653753	et	3	main
1802	doc_491521502183_item	3653749	et	2	main
pärisorjusest	doc_491521502183_item	3653740	et	4	main
2	doc_491521502183_item	3653736	et	2	main
tähtsus	doc_491521502183_item	3653731	et	4	main
ülikooli	doc_491521502183_item	3653729	et	4	main
müüa	doc_491521502183_item	3653885	et	3	main
kokku	doc_491521502186_item	3654112	et	3	main
väga	doc_491521502186_item	3654102	et	3	main
ta	doc_491521502186_item	3654100	et	4	main
venestamist	doc_491521502186_item	3654099	et	4	main
väga	doc_491521502186_item	3654098	et	3	main
kartis	doc_491521502186_item	3654097	et	3	main
ja	doc_491521502186_item	3654096	et	3	main
saksameelne	doc_491521502186_item	3654095	et	3	main
oli	doc_491521502186_item	3654094	et	3	main
ettekande	doc_491521502186_item	3654091	et	4	main
esitas	doc_491521502186_item	3654089	et	3	main
ja	doc_491521502186_item	3654087	et	3	main
kergem	doc_491521502186_item	3654083	et	4	main
oli	doc_491521502132_item	3653572	et	3	main
miljonit	doc_491521502132_item	3653568	et	3	main
15	doc_491521502132_item	3653567	et	2	main
inglismaale	doc_491521502132_item	3653559	et	4	main
oli	doc_491521502132_item	3653555	et	3	main
eesti	doc_491521502132_item	3653553	et	4	main
a	doc_491521502132_item	3653549	et	4	main
1821	doc_491521502132_item	3653548	et	2	main
kaitsetollid	doc_491521502132_item	3653543	et	3	main
mõnes	doc_491521502132_item	3653538	et	3	main
poolast	doc_491521502132_item	3653535	et	3	main
läänest	doc_491521502132_item	3653529	et	4	main
otsiti	doc_491521502132_item	3653525	et	3	main
majanduse	doc_491521502132_item	3653518	et	4	main
sidemed	doc_491521502132_item	3653516	et	3	main
intelligentsi	doc_491521502132_item	3653502	et	4	main
tehnika	doc_491521502132_item	3653494	et	4	main
rahvuskultuuri	doc_491521502132_item	3653480	et	4	main
sageli	doc_491521502132_item	3653475	et	3	main
aeti	doc_491521502132_item	3653474	et	3	main
varjus	doc_491521502132_item	3653473	et	4	main
seltside	doc_491521502132_item	3653472	et	3	main
tegevusest	doc_491521502132_item	3653471	et	4	main
ühingute	doc_491521502132_item	3653470	et	3	main
ja	doc_491521502132_item	3653469	et	3	main
seltside	doc_491521502132_item	3653468	et	3	main
teada	doc_491521502132_item	3653467	et	3	main
said	doc_491521502132_item	3653466	et	4	main
ääremaad	doc_491521502132_item	3653465	et	4	main
ka	doc_491521502132_item	3653464	et	3	main
1870-ndatel	doc_491521502132_item	3653463	et	2	main
sünd	doc_491521502132_item	3653462	et	3	main
ajakirjanduse	doc_491521502132_item	3653461	et	3	main
rahvuslikule	doc_491521502132_item	3653460	et	3	main
tõusule	doc_491521502132_item	3653459	et	4	main
iseteadvuse	doc_491521502132_item	3653458	et	4	main
eestl	doc_491521502132_item	3653457	et	4	main
ja	doc_491521502132_item	3653456	et	3	main
kultuuri	doc_491521502132_item	3653455	et	4	main
eesti	doc_491521502132_item	3653454	et	4	main
panus	doc_491521502132_item	3653453	et	4	main
suur	doc_491521502132_item	3653452	et	3	main
isamaakõnet	doc_491521502132_item	3653451	et	3	main
iii	doc_491521502132_item	3653450	et	4	main
jakobsoni	doc_491521502132_item	3653449	et	4	main
rahvaks	doc_491521502132_item	3653448	et	3	main
rahvast	doc_491521502132_item	3653446	et	4	main
eesti	doc_491521502132_item	3653447	et	4	main
jansen	doc_491521502132_item	3653445	et	4	main
venemaaga	doc_491521502132_item	3653517	et	3	main
peamised	doc_491521502132_item	3653509	et	3	main
eestlastest	doc_491521502132_item	3653501	et	4	main
ja	doc_491521502132_item	3653493	et	3	main
pasunakoore	doc_491521502132_item	3653489	et	4	main
mängu	doc_491521502132_item	3653487	et	4	main
1810	doc_491521502183_item	3653879	et	2	main
arv	doc_491521502183_item	3653873	et	3	main
ei	doc_491521502183_item	3653865	et	4	main
talupoeg	doc_491521502183_item	3653864	et	3	main
algul	doc_491521502183_item	3653863	et	4	main
saj	doc_491521502183_item	3653862	et	4	main
19	doc_491521502183_item	3653861	et	2	main
ihunuhtlus	doc_491521502183_item	3653859	et	3	main
see	doc_491521502183_item	3653852	et	3	main
said	doc_491521502183_item	3653846	et	4	main
kodanikuõigusi	doc_491521502183_item	3653844	et	4	main
sai	doc_491521502183_item	3653843	et	4	main
talupoeg	doc_491521502183_item	3653842	et	3	main
vahetada	doc_491521502183_item	3653841	et	3	main
kinnisvara	doc_491521502183_item	3653835	et	4	main
võidu	doc_491521502183_item	3653812	et	4	main
soome	doc_491521502183_item	3653796	et	3	main
kirja	doc_491521502183_item	3653794	et	4	main
tuleb	doc_491521502183_item	3653762	et	3	main
arvab	doc_491521502183_item	3653759	et	3	main
ideid	doc_491521502183_item	3653757	et	3	main
pooldab	doc_491521502183_item	3653755	et	3	main
mida	doc_491521502183_item	3653742	et	4	main
ja	doc_491521502183_item	3653741	et	3	main
eesti	doc_491521502183_item	3653732	et	4	main
tartu	doc_491521502183_item	3653728	et	4	main
1	doc_491521502183_item	3653727	et	2	main
kontrolltöö	doc_491521502183_item	3653726	et	4	main
1856	doc_491521502183_item	3653886	et	2	main
sulada	doc_491521502186_item	3654113	et	3	main
euroopa	doc_491521502186_item	3654110	et	4	main
faehlmann	doc_491521502186_item	3654093	et	4	main
rahvaluulesse	doc_491521502186_item	3654086	et	4	main
oli	doc_491521502186_item	3654080	et	3	main
saanud	doc_491521502186_item	3654076	et	4	main
hariduse	doc_491521502186_item	3654075	et	3	main
faehlmann	doc_491521502186_item	3654071	et	4	main
a	doc_491521502186_item	3654061	et	4	main
1838	doc_491521502186_item	3654060	et	2	main
uurimine	doc_491521502186_item	3654059	et	4	main
eestlasi	doc_491521502186_item	3654053	et	3	main
oli	doc_491521502186_item	3654050	et	3	main
talupojad	doc_491521502183_item	3653893	et	4	main
rikkad	doc_491521502183_item	3653892	et	4	main
ka	doc_491521502183_item	3653891	et	3	main
tekkisid	doc_491521502183_item	3653890	et	4	main
seadus	doc_491521502183_item	3653889	et	4	main
päriseksostmise	doc_491521502183_item	3653888	et	3	main
talude	doc_491521502183_item	3653887	et	3	main
tekivad	doc_491521502183_item	3653877	et	3	main
enam	doc_491521502183_item	3653867	et	4	main
kaotati	doc_491521502183_item	3653860	et	3	main
täpsustati	doc_491521502183_item	3653856	et	4	main
venemaalt	doc_491521502183_item	3653851	et	3	main
rännata	doc_491521502183_item	3653849	et	4	main
perekonnanime	doc_491521502183_item	3653845	et	4	main
saa	doc_491521502183_item	3653838	et	4	main
ei	doc_491521502183_item	3653837	et	4	main
talupoegi	doc_491521502183_item	3653836	et	4	main
vabad	doc_491521502183_item	3653830	et	3	main
liivimaal	doc_491521502183_item	3653826	et	4	main
eestimaal	doc_491521502183_item	3653824	et	4	main
kirjaviis	doc_491521502183_item	3653811	et	4	main
kirjaviis	doc_491521502183_item	3653801	et	4	main
1843	doc_491521502183_item	3653799	et	2	main
eeskujul	doc_491521502183_item	3653798	et	3	main
panema	doc_491521502183_item	3653795	et	3	main
eesti	doc_491521502183_item	3653791	et	4	main
keelt	doc_491521502183_item	3653790	et	4	main
eesti	doc_491521502183_item	3653789	et	4	main
õppida	doc_491521502183_item	3653788	et	3	main
võimalik	doc_491521502183_item	3653787	et	3	main
on	doc_491521502183_item	3653786	et	4	main
lektor	doc_491521502183_item	3653785	et	3	main
keele	doc_491521502183_item	3653784	et	4	main
eesti	doc_491521502183_item	3653783	et	4	main
pidama	doc_491521502183_item	3653782	et	4	main
loenguid	doc_491521502183_item	3653781	et	4	main
taas	doc_491521502183_item	3653751	et	3	main
sisuliselt	doc_491521502183_item	3653746	et	4	main
nende	doc_491521502183_item	3653744	et	4	main
see	doc_491521502183_item	3653743	et	3	main
millal	doc_491521502183_item	3653737	et	3	main
kultuurielule	doc_491521502183_item	3653735	et	3	main
toodangut	doc_491521502183_item	3653884	et	3	main
vabalt	doc_491521502183_item	3653882	et	4	main
kultuuriga	doc_491521502186_item	3654111	et	4	main
ka	doc_491521502186_item	3654090	et	3	main
ta	doc_491521502186_item	3654088	et	4	main
ja	doc_491521502186_item	3654078	et	3	main
eesti	doc_491521502186_item	3654065	et	4	main
keele	doc_491521502186_item	3654058	et	4	main
pärast	doc_491521502186_item	3654046	et	4	main
tööd	doc_491521502186_item	3654001	et	4	main
hurda	doc_491521502186_item	3653994	et	3	main
eesotsas	doc_491521502186_item	3653990	et	4	main
oli	doc_491521502186_item	3653987	et	3	main
hurt	doc_491521502186_item	3653986	et	3	main
tänu	doc_491521502186_item	3653969	et	4	main
j	doc_491521502186_item	3653963	et	4	main
kreutzwaldiga	doc_491521502186_item	3653962	et	4	main
tähtis	doc_491521502186_item	3653953	et	4	main
ja	doc_491521502186_item	3653946	et	3	main
ustavaks	doc_491521502186_item	3653932	et	4	main
kultuurilukku	doc_491521502186_item	3653921	et	4	main
mille	doc_491521502189_item	3654324	et	3	main
kultuuri	doc_491521502189_item	3654317	et	4	main
eestlaste	doc_491521502189_item	3654308	et	4	main
keelt	doc_491521502189_item	3654304	et	4	main
selline	doc_491521502189_item	3654298	et	4	main
huvi	doc_491521502189_item	3654289	et	4	main
ajal	doc_491521502189_item	3654283	et	4	main
pani	doc_491521502189_item	3654280	et	4	main
tuntud	doc_491521502189_item	3654275	et	4	main
on	doc_491521502189_item	3654274	et	4	main
tänu	doc_491521502189_item	3654265	et	4	main
kultuuri	doc_491521502189_item	3654226	et	4	main
ja	doc_491521502189_item	3654224	et	3	main
arengut	doc_491521502189_item	3654215	et	3	main
ahrensi	doc_491521502183_item	3653818	et	4	main
kirjaviisis	doc_491521502183_item	3653817	et	3	main
uues	doc_491521502183_item	3653816	et	3	main
saab	doc_491521502183_item	3653809	et	3	main
uusi	doc_491521502183_item	3653806	et	3	main
eesti	doc_491521502183_item	3653804	et	4	main
toob	doc_491521502183_item	3653803	et	3	main
ahrens	doc_491521502183_item	3653802	et	4	main
et	doc_491521502183_item	3653760	et	3	main
avatakse	doc_491521502183_item	3653750	et	4	main
tähendas	doc_491521502183_item	3653747	et	3	main
jaoks	doc_491521502183_item	3653745	et	4	main
vabastati	doc_491521502183_item	3653738	et	3	main
haridus-	doc_491521502183_item	3653733	et	3	main
sakslaste	doc_491521502186_item	3654108	et	3	main
et	doc_491521502186_item	3654106	et	3	main
eesti	doc_491521502186_item	3654085	et	4	main
süveneda	doc_491521502186_item	3654084	et	3	main
ta	doc_491521502186_item	3654072	et	4	main
hakkas	doc_491521502186_item	3654055	et	3	main
keele	doc_491521502186_item	3654045	et	4	main
hurt	doc_491521502186_item	3654011	et	3	main
kõrvaldati	doc_491521502186_item	3654008	et	3	main
ta	doc_491521502186_item	3654006	et	4	main
postimehes	doc_491521502186_item	3654004	et	3	main
väljatöötamise	doc_491521502186_item	3653997	et	3	main
rahvusideoloogia	doc_491521502186_item	3653996	et	4	main
väga	doc_491521502186_item	3653991	et	3	main
liikumise	doc_491521502186_item	3653967	et	4	main
läbi	doc_491521502186_item	3653961	et	4	main
hästi	doc_491521502186_item	3653960	et	3	main
sai	doc_491521502186_item	3653959	et	4	main
ja	doc_491521502186_item	3653958	et	3	main
keeleteadlane	doc_491521502186_item	3653957	et	3	main
rahvaluule	doc_491521502186_item	3653948	et	4	main
tähtis	doc_491521502186_item	3653945	et	4	main
jaoks	doc_491521502186_item	3653944	et	4	main
tema	doc_491521502186_item	3653937	et	4	main
teha	doc_491521502186_item	3653936	et	3	main
soovides	doc_491521502186_item	3653935	et	4	main
rahvale	doc_491521502186_item	3653934	et	3	main
ta	doc_491521502186_item	3653929	et	4	main
peal	doc_491521502186_item	3653925	et	4	main
rahatähe	doc_491521502186_item	3653924	et	3	main
10-kroonise	doc_491521502186_item	3653923	et	4	main
1	doc_491521502186_item	3653922	et	2	main
nende	doc_491521502186_item	3653918	et	4	main
milline	doc_491521502186_item	3653916	et	3	main
ja	doc_491521502186_item	3653915	et	3	main
estofiilid	doc_491521502186_item	3653914	et	3	main
poolest	doc_491521502189_item	3654325	et	4	main
kirjakeelt	doc_491521502189_item	3654323	et	4	main
keele	doc_491521502189_item	3654321	et	4	main
eesti	doc_491521502189_item	3654320	et	4	main
eesti	doc_491521502189_item	3654313	et	4	main
arendasid	doc_491521502189_item	3654312	et	4	main
nad	doc_491521502189_item	3654311	et	3	main
sest	doc_491521502189_item	3654305	et	4	main
ise	doc_491521502189_item	3654301	et	4	main
et	doc_491521502189_item	3654299	et	3	main
kultuurilukku	doc_491521502189_item	3654296	et	4	main
panus	doc_491521502189_item	3654294	et	4	main
2	doc_491521502189_item	3654284	et	2	main
hurt	doc_491521502189_item	3654273	et	3	main
jakob	doc_491521502189_item	3654272	et	4	main
haridus	doc_491521502189_item	3654271	et	3	main
ja	doc_491521502189_item	3654270	et	3	main
keel	doc_491521502189_item	3654269	et	4	main
arendada	doc_491521502189_item	3654230	et	3	main
keele	doc_491521502183_item	3653797	et	4	main
hakatakse	doc_491521502183_item	3653793	et	3	main
tü	doc_491521502183_item	3653780	et	4	main
hakkab	doc_491521502183_item	3653779	et	3	main
1802	doc_491521502183_item	3653778	et	2	main
võlgu	doc_491521502183_item	3653777	et	4	main
kohtule	doc_491521502183_item	3653776	et	3	main
ega	doc_491521502183_item	3653775	et	3	main
mõisale	doc_491521502183_item	3653774	et	3	main
olda	doc_491521502183_item	3653773	et	3	main
ei	doc_491521502183_item	3653772	et	4	main
et	doc_491521502183_item	3653771	et	3	main
tingimusel	doc_491521502183_item	3653770	et	3	main
müüapärandada	doc_491521502183_item	3653769	et	4	main
võib	doc_491521502183_item	3653768	et	3	main
mida	doc_491521502183_item	3653767	et	4	main
vallasvara	doc_491521502183_item	3653766	et	4	main
oma	doc_491521502183_item	3653765	et	4	main
talupoegadel	doc_491521502183_item	3653764	et	3	main
kaotada	doc_491521502183_item	3653763	et	3	main
tü	doc_491521502183_item	3653752	et	4	main
1	doc_491521502183_item	3653748	et	2	main
eestlased	doc_491521502183_item	3653739	et	3	main
ja	doc_491521502183_item	3653734	et	3	main
taasavamise	doc_491521502183_item	3653730	et	4	main
oma	doc_491521502183_item	3653883	et	4	main
talupoeg	doc_491521502183_item	3653881	et	3	main
ja	doc_491521502186_item	3654109	et	3	main
kiiremini	doc_491521502186_item	3654107	et	4	main
haridust	doc_491521502186_item	3654105	et	4	main
emakeelset	doc_491521502186_item	3654104	et	3	main
vajalikuks	doc_491521502186_item	3654103	et	3	main
pidas	doc_491521502186_item	3654101	et	3	main
kalevipojast	doc_491521502186_item	3654092	et	4	main
palju	doc_491521502186_item	3654082	et	4	main
tal	doc_491521502186_item	3654081	et	3	main
seepärast	doc_491521502186_item	3654079	et	3	main
eestlane	doc_491521502186_item	3654077	et	3	main
saksa	doc_491521502186_item	3654074	et	4	main
õpetatud	doc_491521502186_item	3654064	et	4	main
tartusse	doc_491521502186_item	3654063	et	3	main
loodi	doc_491521502186_item	3654062	et	4	main
eesti	doc_491521502186_item	3654057	et	4	main
arenema	doc_491521502186_item	3654056	et	3	main
saanud	doc_491521502186_item	3654052	et	4	main
eesti	doc_491521502186_item	3654044	et	4	main
ja	doc_491521502186_item	3654043	et	3	main
kultuuri	doc_491521502186_item	3654042	et	4	main
eesti	doc_491521502186_item	3654041	et	4	main
muret	doc_491521502186_item	3654040	et	3	main
tundsid	doc_491521502186_item	3654039	et	4	main
kes	doc_491521502186_item	3654038	et	4	main
sakslased	doc_491521502186_item	3654037	et	3	main
balti	doc_491521502186_item	3654036	et	3	main
2	doc_491521502186_item	3654035	et	2	main
toovat	doc_491521502186_item	3654034	et	4	main
kahju	doc_491521502186_item	3654033	et	4	main
sakslastele	doc_491521502186_item	3654032	et	3	main
tundus	doc_491521502186_item	3654031	et	3	main
mis	doc_491521502186_item	3654030	et	4	main
kirjutamine	doc_491521502186_item	3654029	et	4	main
artiklite	doc_491521502186_item	3654028	et	3	main
oli	doc_491521502186_item	3654027	et	3	main
põhjuseks	doc_491521502186_item	3654026	et	3	main
hiljem	doc_491521502186_item	3654025	et	3	main
kõrvaldati	doc_491521502186_item	3654024	et	3	main
samuti	doc_491521502186_item	3654023	et	3	main
ta	doc_491521502186_item	3654022	et	4	main
kust	doc_491521502186_item	3654021	et	4	main
töötanud	doc_491521502186_item	3654020	et	4	main
hurt	doc_491521502186_item	3654019	et	3	main
oli	doc_491521502186_item	3654018	et	3	main
sakalas	doc_491521502186_item	3654017	et	4	main
ka	doc_491521502186_item	3654016	et	3	main
kultuuri	doc_491521502186_item	3654015	et	4	main
oluliseks	doc_491521502186_item	3654014	et	4	main
väga	doc_491521502186_item	3654013	et	3	main
kust	doc_491521502186_item	3654005	et	4	main
eesti	doc_491521502186_item	3654003	et	4	main
ka	doc_491521502186_item	3654002	et	3	main
töö	doc_491521502186_item	3653995	et	4	main
terviklikumaks	doc_491521502186_item	3653982	et	4	main
oli	doc_491521502186_item	3654073	et	3	main
seal	doc_491521502186_item	3654070	et	4	main
oli	doc_491521502186_item	3654069	et	3	main
tegelaseks	doc_491521502186_item	3654068	et	3	main
tähtsamaks	doc_491521502186_item	3654067	et	4	main
selts	doc_491521502186_item	3654066	et	3	main
edasi	doc_491521502186_item	3654054	et	3	main
haridust	doc_491521502186_item	3654051	et	4	main
seas	doc_491521502186_item	3654049	et	4	main
nende	doc_491521502186_item	3654048	et	4	main
estofiilid	doc_491521502186_item	3654047	et	3	main
pidas	doc_491521502186_item	3654012	et	3	main
koos	doc_491521502186_item	3654009	et	4	main
hiljem	doc_491521502186_item	3654007	et	3	main
tegi	doc_491521502186_item	3654000	et	4	main
hurt	doc_491521502186_item	3653999	et	3	main
alal	doc_491521502186_item	3653998	et	4	main
on	doc_491521502186_item	3653993	et	4	main
kirjameeste	doc_491521502186_item	3653988	et	4	main
j	doc_491521502186_item	3653985	et	4	main
sihikindlamaks	doc_491521502186_item	3653984	et	4	main
ning	doc_491521502186_item	3653983	et	3	main
hurdast	doc_491521502186_item	3653964	et	4	main
oli	doc_491521502186_item	3653956	et	3	main
hurt	doc_491521502186_item	3653955	et	3	main
j	doc_491521502186_item	3653954	et	4	main
ajaloo	doc_491521502186_item	3653950	et	4	main
ja	doc_491521502186_item	3653949	et	3	main
oluline	doc_491521502186_item	3653947	et	4	main
tööd	doc_491521502186_item	3653939	et	4	main
heaks	doc_491521502186_item	3653938	et	4	main
jäänud	doc_491521502186_item	3653931	et	4	main
oli	doc_491521502186_item	3653930	et	3	main
eesti	doc_491521502186_item	3653920	et	4	main
saksa	doc_491521502189_item	3654327	et	4	main
ja	doc_491521502189_item	3654315	et	3	main
konkurentsi	doc_491521502189_item	3654307	et	4	main
õpisid	doc_491521502189_item	3654302	et	4	main
eesti	doc_491521502189_item	3654295	et	4	main
tundsid	doc_491521502189_item	3654288	et	4	main
eesti	doc_491521502189_item	3654277	et	4	main
kultuuritegelane	doc_491521502189_item	3654276	et	3	main
eesti	doc_491521502189_item	3654268	et	4	main
arenes	doc_491521502189_item	3654267	et	3	main
temale	doc_491521502189_item	3654266	et	3	main
eestlastele	doc_491521502189_item	3654228	et	4	main
vastu	doc_491521502189_item	3654221	et	3	main
võib	doc_491521502189_item	3654216	et	3	main
kultuuri	doc_491521502189_item	3654205	et	4	main
ta	doc_491521502189_item	3654202	et	4	main
kirjameeste	doc_491521502189_item	3654200	et	4	main
ja	doc_491521502189_item	3654198	et	3	main
hurt	doc_491521502189_item	3654187	et	3	main
liider	doc_491521502189_item	3654179	et	3	main
teadmiste	doc_491521502189_item	3654160	et	4	main
tegevus	doc_491521502189_item	3654152	et	4	main
kujutatud	doc_491521502189_item	3654146	et	4	main
kultuurilukku	doc_491521502189_item	3654141	et	4	main
poed	doc_491521502192_item	3654639	et	4	main
kogu	doc_491521502192_item	3654626	et	4	main
teevad	doc_491521502192_item	3654625	et	3	main
riiste	doc_491521502192_item	3654620	et	3	main
hakatakse	doc_491521502192_item	3654616	et	3	main
elanikud	doc_491521502192_item	3654609	et	3	main
väljaostmine	doc_491521502192_item	3654602	et	3	main
a-	doc_491521502192_item	3654600	et	4	main
usku	doc_491521502192_item	3654598	et	4	main
19	doc_491521502192_item	3654558	et	2	main
raha	doc_491521502192_item	3654555	et	4	main
perekonnanimesi	doc_491521502192_item	3654531	et	4	main
neid	doc_491521502192_item	3654523	et	4	main
2	doc_491521502192_item	3654508	et	2	main
korteris	doc_491521502192_item	3654507	et	3	main
said	doc_491521502192_item	3654498	et	4	main
stependiumi	doc_491521502192_item	3654496	et	4	main
said	doc_491521502192_item	3654495	et	4	main
mõned	doc_491521502192_item	3654494	et	3	main
ja	doc_491521502192_item	3654493	et	3	main
juurde	doc_491521502192_item	3654472	et	4	main
saama	doc_491521502192_item	3654467	et	4	main
ja	doc_491521502192_item	3654466	et	3	main
pidi	doc_491521502192_item	3654462	et	4	main
jakobsoniga	doc_491521502186_item	3654010	et	4	main
tähtis	doc_491521502186_item	3653992	et	4	main
seltsi	doc_491521502186_item	3653989	et	4	main
liikumine	doc_491521502186_item	3653980	et	4	main
rahvuslik	doc_491521502186_item	3653979	et	3	main
hakanud	doc_491521502186_item	3653978	et	4	main
suhtlema	doc_491521502186_item	3653977	et	3	main
omavahel	doc_491521502186_item	3653976	et	3	main
liikmed	doc_491521502186_item	3653975	et	3	main
tegutsenud	doc_491521502186_item	3653974	et	4	main
eraldi	doc_491521502186_item	3653973	et	4	main
seni	doc_491521502186_item	3653972	et	3	main
oli	doc_491521502186_item	3653971	et	3	main
hurdale	doc_491521502186_item	3653970	et	3	main
muutus	doc_491521502186_item	3653981	et	4	main
vaimuvara	doc_491521502186_item	3653941	et	4	main
rahva	doc_491521502186_item	3653940	et	3	main
oma	doc_491521502186_item	3653933	et	4	main
hurt	doc_491521502186_item	3653928	et	3	main
oli	doc_491521502186_item	3653917	et	3	main
olid	doc_491521502186_item	3653913	et	4	main
kes	doc_491521502186_item	3653912	et	4	main
2	doc_491521502186_item	3653911	et	2	main
teate	doc_491521502186_item	3653910	et	4	main
tegevusest	doc_491521502186_item	3653909	et	4	main
tema	doc_491521502186_item	3653908	et	4	main
te	doc_491521502186_item	3653907	et	4	main
mida	doc_491521502186_item	3653906	et	4	main
peal	doc_491521502186_item	3653905	et	4	main
rahatähe	doc_491521502186_item	3653904	et	3	main
10-kroonise	doc_491521502186_item	3653903	et	4	main
eesti	doc_491521502186_item	3653902	et	4	main
kujutatud	doc_491521502186_item	3653901	et	4	main
on	doc_491521502186_item	3653900	et	4	main
kultuuritegelane	doc_491521502186_item	3653899	et	3	main
ärkamisaja	doc_491521502186_item	3653898	et	3	main
milline	doc_491521502186_item	3653897	et	3	main
1	doc_491521502186_item	3653896	et	2	main
kontrolltöö	doc_491521502186_item	3653895	et	4	main
liider	doc_491521502186_item	3653968	et	3	main
aleksandrikooli	doc_491521502186_item	3653966	et	4	main
sai	doc_491521502186_item	3653965	et	4	main
rahvale	doc_491521502186_item	3653952	et	3	main
tagasiandmine	doc_491521502186_item	3653951	et	3	main
tema	doc_491521502186_item	3653943	et	4	main
oli	doc_491521502186_item	3653942	et	3	main
jakob	doc_491521502186_item	3653927	et	4	main
on	doc_491521502186_item	3653926	et	4	main
panus	doc_491521502186_item	3653919	et	4	main
keelest	doc_491521502189_item	3654328	et	4	main
grammatikat	doc_491521502189_item	3654322	et	3	main
uurisid	doc_491521502189_item	3654319	et	4	main
estofiilid	doc_491521502189_item	3654318	et	3	main
samuti	doc_491521502189_item	3654310	et	3	main
seast	doc_491521502189_item	3654309	et	4	main
vastu	doc_491521502189_item	3654292	et	3	main
kultuurielu	doc_491521502189_item	3654291	et	4	main
kes	doc_491521502189_item	3654287	et	4	main
balti-sakslased	doc_491521502189_item	3654286	et	3	main
sellele	doc_491521502189_item	3654282	et	4	main
vaid	doc_491521502189_item	3654229	et	3	main
seista	doc_491521502189_item	3654222	et	4	main
et	doc_491521502189_item	3654218	et	3	main
eestlaste	doc_491521502189_item	3654204	et	4	main
selts	doc_491521502189_item	3654201	et	3	main
eesti	doc_491521502189_item	3654199	et	4	main
komitee	doc_491521502189_item	3654197	et	4	main
koostöö	doc_491521502189_item	3654190	et	4	main
temaga	doc_491521502189_item	3654189	et	3	main
jakobson	doc_491521502189_item	3654180	et	4	main
liikumise	doc_491521502189_item	3654178	et	4	main
seotud	doc_491521502189_item	3654154	et	4	main
10-kroonise	doc_491521502189_item	3654148	et	4	main
1	doc_491521502189_item	3654142	et	2	main
eesti	doc_491521502189_item	3654140	et	4	main
nende	doc_491521502189_item	3654138	et	4	main
erineb	doc_491521502189_item	3654326	et	3	main
hariduse	doc_491521502189_item	3654316	et	3	main
keele	doc_491521502189_item	3654314	et	4	main
kardsid	doc_491521502189_item	3654306	et	4	main
eesti	doc_491521502189_item	3654303	et	4	main
nad	doc_491521502189_item	3654300	et	3	main
oli	doc_491521502189_item	3654297	et	3	main
nende	doc_491521502189_item	3654293	et	4	main
eesti	doc_491521502189_item	3654290	et	4	main
estofiilid	doc_491521502189_item	3654285	et	3	main
aluse	doc_491521502189_item	3654281	et	4	main
kes	doc_491521502189_item	3654279	et	4	main
ärkamisajas	doc_491521502189_item	3654278	et	3	main
just	doc_491521502189_item	3654264	et	3	main
et	doc_491521502189_item	3654263	et	3	main
öelda	doc_491521502189_item	3654262	et	4	main
võib	doc_491521502189_item	3654261	et	3	main
siis	doc_491521502189_item	3654260	et	3	main
hurdale	doc_491521502189_item	3654259	et	3	main
allutatud	doc_491521502189_item	3654258	et	4	main
oli	doc_491521502189_item	3654257	et	3	main
selts	doc_491521502189_item	3654256	et	3	main
kirjameeste	doc_491521502189_item	3654255	et	4	main
eesti	doc_491521502189_item	3654254	et	4	main
kuna	doc_491521502189_item	3654253	et	3	main
eest	doc_491521502189_item	3654252	et	4	main
tegevuste	doc_491521502189_item	3654251	et	4	main
ja	doc_491521502189_item	3654250	et	3	main
huvide	doc_491521502189_item	3654249	et	3	main
tema	doc_491521502189_item	3654248	et	4	main
seisid	doc_491521502189_item	3654247	et	4	main
kes	doc_491521502189_item	3654246	et	4	main
pooldajaid	doc_491521502189_item	3654245	et	4	main
palju	doc_491521502189_item	3654244	et	4	main
oli	doc_491521502189_item	3654243	et	3	main
hurdal	doc_491521502189_item	3654242	et	3	main
hariduse	doc_491521502189_item	3654241	et	3	main
vene	doc_491521502189_item	3654240	et	4	main
allutamist	doc_491521502189_item	3654239	et	4	main
koolisüsteemi	doc_491521502189_item	3654238	et	4	main
eesti	doc_491521502189_item	3654237	et	4	main
pooldanud	doc_491521502189_item	3654236	et	4	main
ei	doc_491521502189_item	3654235	et	4	main
ta	doc_491521502189_item	3654234	et	4	main
kultuuri	doc_491521502189_item	3654233	et	4	main
rahva	doc_491521502189_item	3654232	et	3	main
oma	doc_491521502189_item	3654231	et	4	main
ühendamisele	doc_491521502189_item	3654227	et	4	main
vene	doc_491521502189_item	3654223	et	4	main
hurt	doc_491521502189_item	3654219	et	3	main
öelda	doc_491521502189_item	3654217	et	4	main
vaimu	doc_491521502189_item	3654214	et	4	main
tegutsesid	doc_491521502189_item	3654194	et	4	main
all	doc_491521502189_item	3654193	et	3	main
kontrolli	doc_491521502189_item	3654192	et	4	main
hurda	doc_491521502189_item	3654191	et	3	main
rolli	doc_491521502189_item	3654184	et	4	main
ärkamisajas	doc_491521502189_item	3654182	et	3	main
kreutzwaldiga	doc_491521502189_item	3654170	et	4	main
ajaloo	doc_491521502189_item	3654159	et	4	main
ja	doc_491521502189_item	3654158	et	3	main
ta	doc_491521502189_item	3654151	et	4	main
on	doc_491521502189_item	3654145	et	4	main
hurt	doc_491521502189_item	3654144	et	3	main
panus	doc_491521502189_item	3654139	et	4	main
ja	doc_491521502189_item	3654135	et	3	main
estofiilid	doc_491521502189_item	3654134	et	3	main
olid	doc_491521502189_item	3654133	et	4	main
ärkamisaja	doc_491521502189_item	3654118	et	3	main
milline	doc_491521502189_item	3654117	et	3	main
1	doc_491521502189_item	3654116	et	2	main
kontrolltöö	doc_491521502189_item	3654115	et	4	main
postijaamad	doc_491521502192_item	3654641	et	3	main
väiksed	doc_491521502192_item	3654637	et	4	main
tekivad	doc_491521502192_item	3654636	et	3	main
töö	doc_491521502192_item	3654627	et	4	main
tikke	doc_491521502192_item	3654618	et	4	main
tallinas	doc_491521502192_item	3654615	et	4	main
jne	doc_491521502192_item	3654614	et	4	main
postsepaks	doc_491521502192_item	3654613	et	3	main
rätsepaks	doc_491521502192_item	3654612	et	3	main
hakkab	doc_491521502192_item	3654605	et	3	main
a	doc_491521502192_item	3654593	et	4	main
tekkivad	doc_491521502192_item	3654589	et	4	main
ülejäänud	doc_491521502192_item	3654587	et	4	main
või	doc_491521502192_item	3654549	et	4	main
saksa	doc_491521502189_item	3654225	et	4	main
püüdis	doc_491521502189_item	3654220	et	3	main
eesti	doc_491521502189_item	3654208	et	4	main
hariduse	doc_491521502189_item	3654207	et	3	main
st	doc_491521502189_item	3654206	et	3	main
aleksandrikooli	doc_491521502189_item	3654196	et	4	main
tähtsat	doc_491521502189_item	3654183	et	3	main
koostööd	doc_491521502189_item	3654169	et	4	main
tegi	doc_491521502189_item	3654168	et	4	main
ja	doc_491521502189_item	3654167	et	3	main
keeleteadlane	doc_491521502189_item	3654166	et	3	main
oli	doc_491521502189_item	3654165	et	3	main
hurt	doc_491521502189_item	3654164	et	3	main
j	doc_491521502189_item	3654163	et	4	main
rahvale	doc_491521502189_item	3654162	et	3	main
üleandmisega	doc_491521502189_item	3654161	et	3	main
rahvaluule	doc_491521502189_item	3654157	et	4	main
vaimuvara	doc_491521502189_item	3654156	et	4	main
rahva	doc_491521502189_item	3654155	et	3	main
peal	doc_491521502189_item	3654150	et	4	main
rahatähe	doc_491521502189_item	3654149	et	3	main
jakob	doc_491521502189_item	3654143	et	4	main
kes	doc_491521502189_item	3654132	et	4	main
2	doc_491521502189_item	3654131	et	2	main
tegevusest	doc_491521502189_item	3654129	et	4	main
teate	doc_491521502189_item	3654130	et	4	main
tema	doc_491521502189_item	3654128	et	4	main
te	doc_491521502189_item	3654127	et	4	main
mida	doc_491521502189_item	3654126	et	4	main
peal	doc_491521502189_item	3654125	et	4	main
rahatähe	doc_491521502189_item	3654124	et	3	main
10-kroonise	doc_491521502189_item	3654123	et	4	main
eesti	doc_491521502189_item	3654122	et	4	main
kujutatud	doc_491521502189_item	3654121	et	4	main
on	doc_491521502189_item	3654120	et	4	main
kultuuritegelane	doc_491521502189_item	3654119	et	3	main
poodnikud	doc_491521502192_item	3654638	et	3	main
vähem	doc_491521502192_item	3654635	et	4	main
makstakse	doc_491521502192_item	3654634	et	3	main
lastele	doc_491521502192_item	3654633	et	4	main
ja	doc_491521502192_item	3654632	et	3	main
naistele	doc_491521502192_item	3654631	et	3	main
inimese	doc_491521502192_item	3654628	et	4	main
tööpuudus	doc_491521502192_item	3654622	et	3	main
tööle	doc_491521502192_item	3654611	et	3	main
arv	doc_491521502192_item	3654604	et	3	main
1860	doc_491521502192_item	3654599	et	2	main
muutma	doc_491521502192_item	3654597	et	3	main
talurahvast	doc_491521502192_item	3654596	et	4	main
osa	doc_491521502192_item	3654595	et	4	main
hakkab	doc_491521502192_item	3654594	et	3	main
jõukad	doc_491521502192_item	3654590	et	3	main
kõrvale	doc_491521502192_item	3654556	et	4	main
linna	doc_491521502192_item	3654548	et	4	main
minna	doc_491521502192_item	3654547	et	3	main
talupojad	doc_491521502192_item	3654546	et	4	main
saa	doc_491521502192_item	3654525	et	4	main
lõuna-eestit	doc_491521502192_item	3654515	et	3	main
ja	doc_491521502192_item	3654514	et	3	main
a	doc_491521502192_item	3654513	et	4	main
1816	doc_491521502192_item	3654512	et	2	main
pärisorjusest	doc_491521502192_item	3654511	et	4	main
vabastati	doc_491521502192_item	3654510	et	3	main
põhja-eestit	doc_491521502192_item	3654509	et	3	main
palka	doc_491521502192_item	3654499	et	4	main
protessorid	doc_491521502192_item	3654497	et	4	main
süüa	doc_491521502192_item	3654492	et	3	main
rahva	doc_491521502189_item	3654213	et	3	main
ja	doc_491521502189_item	3654212	et	3	main
kirjakeele	doc_491521502189_item	3654211	et	4	main
samuti	doc_491521502189_item	3654210	et	3	main
keele	doc_491521502189_item	3654209	et	4	main
arendas	doc_491521502189_item	3654203	et	3	main
eesti	doc_491521502189_item	3654195	et	4	main
tegi	doc_491521502189_item	3654188	et	4	main
j	doc_491521502189_item	3654186	et	4	main
ja	doc_491521502189_item	3654185	et	3	main
mängis	doc_491521502189_item	3654181	et	3	main
aleksandrikooli	doc_491521502189_item	3654177	et	4	main
sai	doc_491521502189_item	3654176	et	4	main
temast	doc_491521502189_item	3654175	et	3	main
samuti	doc_491521502189_item	3654174	et	3	main
et	doc_491521502189_item	3654173	et	3	main
teada	doc_491521502189_item	3654172	et	3	main
on	doc_491521502189_item	3654171	et	4	main
on	doc_491521502189_item	3654153	et	4	main
eesti	doc_491521502189_item	3654147	et	4	main
oli	doc_491521502189_item	3654137	et	3	main
milline	doc_491521502189_item	3654136	et	3	main
postkontorid	doc_491521502192_item	3654640	et	3	main
eest	doc_491521502192_item	3654629	et	4	main
masinad	doc_491521502192_item	3654624	et	3	main
põllumaj	doc_491521502192_item	3654619	et	4	main
tooma	doc_491521502192_item	3654617	et	3	main
hakkavad	doc_491521502192_item	3654610	et	4	main
igas	doc_491521502192_item	3654607	et	3	main
talupojad	doc_491521502192_item	3654591	et	4	main
panna	doc_491521502192_item	3654557	et	4	main
oskasid	doc_491521502192_item	3654554	et	4	main
talupojad	doc_491521502192_item	3654553	et	4	main
välismaale	doc_491521502192_item	3654550	et	4	main
maad	doc_491521502192_item	3654541	et	4	main
rebane	doc_491521502192_item	3654534	et	4	main
pukk	doc_491521502192_item	3654533	et	3	main
nt	doc_491521502192_item	3654532	et	4	main
ei	doc_491521502192_item	3654524	et	4	main
400	doc_491521502192_item	3654500	et	2	main
kuulusid	doc_491521502192_item	3654473	et	4	main
aru	doc_491521502192_item	3654468	et	4	main
õpilane	doc_491521502192_item	3654461	et	3	main
ladina	doc_491521502192_item	3654459	et	4	main
7	doc_491521502192_item	3654454	et	2	main
kell	doc_491521502192_item	3654453	et	3	main
algasid	doc_491521502192_item	3654452	et	4	main
loengud	doc_491521502192_item	3654451	et	3	main
oli	doc_491521502192_item	3654445	et	3	main
loengul	doc_491521502192_item	3654443	et	3	main
poisid	doc_491521502192_item	3654395	et	4	main
gümnaasiumis	doc_491521502192_item	3654393	et	3	main
gümnaasiumi	doc_491521502192_item	3654387	et	4	main
saada	doc_491521502192_item	3654386	et	4	main
et	doc_491521502192_item	3654385	et	3	main
gümnaasium	doc_491521502192_item	3654384	et	3	main
anoloogne	doc_491521502192_item	3654383	et	4	main
andreas	doc_491521502192_item	3654366	et	4	main
õppis	doc_491521502192_item	3654365	et	3	main
oli	doc_491521502192_item	3654360	et	3	main
taasavamise	doc_491521502192_item	3654334	et	4	main
võisid	doc_491521502192_item	3654438	et	4	main
ei	doc_491521502193_item	3654954	et	4	main
talurahva	doc_491521502193_item	3654946	et	3	main
pärisorjuse	doc_491521502193_item	3654922	et	3	main
tõrva	doc_491521502193_item	3654905	et	4	main
kadrioru	doc_491521502193_item	3654872	et	3	main
18	doc_491521502193_item	3654866	et	2	main
komisjoni	doc_491521502193_item	3654857	et	4	main
kutsuti	doc_491521502193_item	3654856	et	3	main
üliõpilas	doc_491521502193_item	3654854	et	4	main
harinud	doc_491521502193_item	3654853	et	4	main
piltlikult	doc_491521502193_item	3654845	et	4	main
9	doc_491521502193_item	3654840	et	2	main
diplom	doc_491521502193_item	3654821	et	3	main
lõpetamise	doc_491521502193_item	3654814	et	4	main
tulla	doc_491521502193_item	3654803	et	3	main
oli	doc_491521502193_item	3654798	et	3	main
ainetes	doc_491521502193_item	3654796	et	3	main
poolt	doc_491521502193_item	3654794	et	4	main
tema	doc_491521502193_item	3654793	et	4	main
eksam	doc_491521502193_item	3654792	et	3	main
ära	doc_491521502192_item	3654630	et	4	main
kuna	doc_491521502192_item	3654623	et	3	main
tekib	doc_491521502192_item	3654621	et	3	main
linnas	doc_491521502192_item	3654608	et	4	main
kasvama	doc_491521502192_item	3654606	et	3	main
linnaelanike	doc_491521502192_item	3654603	et	3	main
talude	doc_491521502192_item	3654601	et	3	main
1840	doc_491521502192_item	3654592	et	2	main
maal	doc_491521502192_item	3654588	et	4	main
linnas	doc_491521502192_item	3654586	et	4	main
elab	doc_491521502192_item	3654585	et	3	main
inimestest	doc_491521502192_item	3654584	et	3	main
9	doc_491521502192_item	3654583	et	2	main
osta	doc_491521502192_item	3654582	et	4	main
maad	doc_491521502192_item	3654581	et	4	main
saavad	doc_491521502192_item	3654580	et	4	main
nad	doc_491521502192_item	3654579	et	3	main
ja	doc_491521502192_item	3654578	et	3	main
raha	doc_491521502192_item	3654577	et	4	main
koguvada	doc_491521502192_item	3654576	et	4	main
talupojad	doc_491521502192_item	3654575	et	4	main
rahateenimisvõimalus	doc_491521502192_item	3654574	et	3	main
on	doc_491521502192_item	3654573	et	4	main
see	doc_491521502192_item	3654572	et	3	main
lina	doc_491521502192_item	3654571	et	4	main
kasvatatakse	doc_491521502192_item	3654570	et	3	main
lõuna-eestis	doc_491521502192_item	3654569	et	3	main
tulu	doc_491521502192_item	3654568	et	4	main
head	doc_491521502192_item	3654567	et	4	main
väga	doc_491521502192_item	3654566	et	3	main
kartulist	doc_491521502192_item	3654565	et	4	main
saab	doc_491521502192_item	3654564	et	3	main
põhja-eesti	doc_491521502192_item	3654563	et	4	main
kartulit	doc_491521502192_item	3654562	et	3	main
kasvatama	doc_491521502192_item	3654561	et	4	main
hakkatakse	doc_491521502192_item	3654560	et	4	main
saj	doc_491521502192_item	3654559	et	4	main
nutikamad	doc_491521502192_item	3654552	et	4	main
elama	doc_491521502192_item	3654551	et	3	main
said	doc_491521502192_item	3654545	et	4	main
a	doc_491521502192_item	3654544	et	4	main
1832	doc_491521502192_item	3654543	et	2	main
rentima	doc_491521502192_item	3654542	et	3	main
maad	doc_491521502192_item	3654535	et	4	main
osta	doc_491521502192_item	3654526	et	4	main
a	doc_491521502192_item	3654517	et	4	main
1819	doc_491521502192_item	3654516	et	2	main
hõbedat	doc_491521502192_item	3654501	et	3	main
said	doc_491521502192_item	3654488	et	4	main
üliõpilased	doc_491521502192_item	3654487	et	3	main
professorit	doc_491521502192_item	3654486	et	3	main
toetusele	doc_491521502192_item	3654482	et	4	main
ja	doc_491521502192_item	3654480	et	3	main
keeles	doc_491521502192_item	3654470	et	4	main
lugema	doc_491521502192_item	3654465	et	4	main
11-12	doc_491521502192_item	3654441	et	2	main
haridust	doc_491521502192_item	3654399	et	4	main
tüdrukutele	doc_491521502192_item	3654398	et	4	main
tuli	doc_491521502192_item	3654388	et	4	main
1631	doc_491521502192_item	3654379	et	2	main
said	doc_491521502192_item	3654375	et	4	main
gümnaasium	doc_491521502192_item	3654373	et	3	main
tartusse	doc_491521502192_item	3654371	et	3	main
asutati	doc_491521502192_item	3654370	et	4	main
1630	doc_491521502192_item	3654368	et	2	main
esto	doc_491521502192_item	3654367	et	4	main
kolitada	doc_491521502192_item	3654361	et	4	main
a	doc_491521502192_item	3654354	et	4	main
sisuliselt	doc_491521502192_item	3654350	et	4	main
jaoks	doc_491521502192_item	3654349	et	4	main
vabastati	doc_491521502192_item	3654342	et	3	main
2	doc_491521502192_item	3654340	et	2	main
ja	doc_491521502192_item	3654338	et	3	main
tartu	doc_491521502192_item	3654332	et	4	main
a	doc_491521502192_item	3654414	et	4	main
1632	doc_491521502192_item	3654413	et	2	main
2510	doc_491521502192_item	3654412	et	2	main
avati	doc_491521502192_item	3654410	et	3	main
tü	doc_491521502192_item	3654411	et	4	main
pidulikult	doc_491521502192_item	3654409	et	4	main
ülikooliks	doc_491521502192_item	3654408	et	4	main
tartu	doc_491521502192_item	3654407	et	4	main
muutub	doc_491521502192_item	3654406	et	3	main
gümnaasium	doc_491521502192_item	3654405	et	3	main
tartu	doc_491521502192_item	3654404	et	4	main
a	doc_491521502192_item	3654403	et	4	main
enam	doc_491521502193_item	3654956	et	4	main
vabastati	doc_491521502193_item	3654951	et	3	main
eestis	doc_491521502193_item	3654948	et	3	main
1816	doc_491521502193_item	3654944	et	2	main
tinu	doc_491521502193_item	3654941	et	4	main
kingseppad	doc_491521502193_item	3654931	et	4	main
olid	doc_491521502193_item	3654930	et	4	main
rahva	doc_491521502193_item	3654926	et	3	main
kaotamist	doc_491521502193_item	3654923	et	4	main
müüa	doc_491521502193_item	3654920	et	3	main
mõisnikukule	doc_491521502193_item	3654918	et	4	main
vaimalik	doc_491521502193_item	3654914	et	4	main
oli	doc_491521502193_item	3654913	et	3	main
rohkem	doc_491521502193_item	3654906	et	4	main
liha	doc_491521502193_item	3654903	et	4	main
barokk	doc_491521502193_item	3654871	et	3	main
valdavaks	doc_491521502193_item	3654869	et	4	main
saj	doc_491521502193_item	3654867	et	4	main
küsimustele	doc_491521502193_item	3654863	et	4	main
pidi	doc_491521502193_item	3654861	et	4	main
aastail	doc_491521502193_item	3654852	et	4	main
pidid	doc_491521502192_item	3654540	et	4	main
nad	doc_491521502192_item	3654539	et	3	main
mõisnukule	doc_491521502192_item	3654538	et	4	main
kuulusid	doc_491521502192_item	3654537	et	4	main
aga	doc_491521502192_item	3654536	et	3	main
pandma	doc_491521502192_item	3654530	et	4	main
hakkati	doc_491521502192_item	3654529	et	3	main
müüa	doc_491521502192_item	3654528	et	3	main
ja	doc_491521502192_item	3654527	et	3	main
kinnisvara	doc_491521502192_item	3654522	et	4	main
omada	doc_491521502192_item	3654521	et	3	main
võimalus	doc_491521502192_item	3654520	et	3	main
oli	doc_491521502192_item	3654519	et	3	main
talupoegadel	doc_491521502192_item	3654518	et	3	main
rektori	doc_491521502192_item	3654506	et	3	main
oli	doc_491521502192_item	3654505	et	3	main
ristimine	doc_491521502192_item	3654504	et	4	main
rebaste	doc_491521502192_item	3654503	et	4	main
aastas	doc_491521502192_item	3654502	et	3	main
mittu	doc_491521502192_item	3654489	et	4	main
30	doc_491521502192_item	3654485	et	2	main
kinnitati	doc_491521502192_item	3654484	et	4	main
õpilaste	doc_491521502192_item	3654481	et	4	main
tü	doc_491521502192_item	3654471	et	4	main
kirjutama	doc_491521502192_item	3654464	et	3	main
käimine	doc_491521502192_item	3654444	et	4	main
a	doc_491521502192_item	3654442	et	4	main
1632	doc_491521502192_item	3654402	et	2	main
ei	doc_491521502192_item	3654400	et	4	main
klassilis	doc_491521502192_item	3654391	et	4	main
3-	doc_491521502192_item	3654390	et	4	main
õppida	doc_491521502192_item	3654389	et	3	main
tallinnasse	doc_491521502192_item	3654382	et	3	main
asutati	doc_491521502192_item	3654381	et	4	main
ainult	doc_491521502192_item	3654377	et	4	main
esimene	doc_491521502192_item	3654372	et	3	main
tõlgi	doc_491521502192_item	3654362	et	4	main
jesuiitide	doc_491521502192_item	3654357	et	3	main
tartusse	doc_491521502192_item	3654356	et	3	main
1583	doc_491521502192_item	3654353	et	2	main
tähendas	doc_491521502192_item	3654351	et	3	main
eesti	doc_491521502192_item	3654336	et	4	main
tähtsus	doc_491521502192_item	3654335	et	4	main
poisid	doc_491521502192_item	3654440	et	4	main
astuda	doc_491521502192_item	3654439	et	3	main
päevas	doc_491521502192_item	3654491	et	3	main
korda	doc_491521502192_item	3654490	et	4	main
tü	doc_491521502192_item	3654483	et	4	main
maksmisele	doc_491521502192_item	3654479	et	4	main
palga	doc_491521502192_item	3654478	et	3	main
läks	doc_491521502192_item	3654477	et	3	main
tulu	doc_491521502192_item	3654476	et	4	main
talupoegade	doc_491521502192_item	3654475	et	3	main
mõisad	doc_491521502192_item	3654474	et	3	main
selles	doc_491521502192_item	3654469	et	4	main
oskama	doc_491521502192_item	3654463	et	3	main
keeles	doc_491521502192_item	3654460	et	4	main
olid	doc_491521502192_item	3654458	et	4	main
nad	doc_491521502192_item	3654457	et	3	main
ja	doc_491521502192_item	3654456	et	3	main
hommikul	doc_491521502192_item	3654455	et	3	main
kohustuslik	doc_491521502192_item	3654446	et	3	main
antud	doc_491521502192_item	3654401	et	4	main
a	doc_491521502192_item	3654397	et	4	main
õppisid	doc_491521502192_item	3654394	et	4	main
a	doc_491521502192_item	3654380	et	4	main
õppida	doc_491521502192_item	3654376	et	3	main
ülikoolis	doc_491521502192_item	3654364	et	4	main
eesmärk	doc_491521502192_item	3654359	et	3	main
asutati	doc_491521502192_item	3654355	et	4	main
1	doc_491521502192_item	3654352	et	2	main
ülikooli	doc_491521502192_item	3654333	et	4	main
müüa	doc_491521502193_item	3654957	et	3	main
pärisorjusest	doc_491521502193_item	3654952	et	4	main
seadus	doc_491521502193_item	3654947	et	4	main
paberivabrik	doc_491521502193_item	3654943	et	3	main
värvimine	doc_491521502193_item	3654937	et	4	main
müürsepad	doc_491521502193_item	3654933	et	3	main
arv	doc_491521502193_item	3654927	et	3	main
hakkas	doc_491521502193_item	3654924	et	3	main
viina	doc_491521502193_item	3654911	et	4	main
meremeeste	doc_491521502193_item	3654910	et	4	main
ka	doc_491521502193_item	3654909	et	3	main
samuti	doc_491521502193_item	3654904	et	3	main
ja	doc_491521502193_item	3654902	et	3	main
kultuur	doc_491521502193_item	3654864	et	3	main
ette	doc_491521502193_item	3654858	et	4	main
kandidaat	doc_491521502193_item	3654855	et	3	main
sai	doc_491521502193_item	3654850	et	4	main
inimesest	doc_491521502193_item	3654849	et	3	main
kuidas	doc_491521502193_item	3654847	et	3	main
löömine	doc_491521502193_item	3654844	et	4	main
depositsioon	doc_491521502193_item	3654842	et	4	main
aastane	doc_491521502193_item	3654841	et	4	main
saj	doc_491521502193_item	3654838	et	4	main
õppemaksu	doc_491521502193_item	3654825	et	4	main
lõpemese	doc_491521502193_item	3654819	et	4	main
ei	doc_491521502193_item	3654816	et	4	main
rootsist	doc_491521502193_item	3654810	et	3	main
tuli	doc_491521502193_item	3654789	et	4	main
kuu	doc_491521502192_item	3654450	et	4	main
iga	doc_491521502192_item	3654449	et	4	main
olid	doc_491521502192_item	3654448	et	4	main
eksamid	doc_491521502192_item	3654447	et	3	main
13-14	doc_491521502192_item	3654396	et	2	main
linnakoolis	doc_491521502192_item	3654392	et	4	main
poisid	doc_491521502192_item	3654378	et	4	main
kus	doc_491521502192_item	3654374	et	3	main
a	doc_491521502192_item	3654369	et	4	main
tartu	doc_491521502192_item	3654363	et	4	main
seminar	doc_491521502192_item	3654358	et	3	main
nende	doc_491521502192_item	3654348	et	4	main
see	doc_491521502192_item	3654347	et	3	main
mida	doc_491521502192_item	3654346	et	4	main
ja	doc_491521502192_item	3654345	et	3	main
pärisorjusest	doc_491521502192_item	3654344	et	4	main
eestlased	doc_491521502192_item	3654343	et	3	main
millal	doc_491521502192_item	3654341	et	3	main
kultuurielule	doc_491521502192_item	3654339	et	3	main
haridus-	doc_491521502192_item	3654337	et	3	main
1	doc_491521502192_item	3654331	et	2	main
kontrolltöö	doc_491521502192_item	3654330	et	4	main
ülikooli	doc_491521502192_item	3654437	et	4	main
noormees	doc_491521502192_item	3654436	et	4	main
19a	doc_491521502192_item	3654435	et	4	main
saada	doc_491521502192_item	3654434	et	4	main
võis	doc_491521502192_item	3654433	et	4	main
osas	doc_491521502192_item	3654431	et	4	main
mitmes	doc_491521502192_item	3654430	et	4	main
raamat	doc_491521502192_item	3654429	et	3	main
rektoriks	doc_491521502192_item	3654432	et	3	main
ajalooline	doc_491521502192_item	3654428	et	4	main
trk	doc_491521502192_item	3654427	et	4	main
välja	doc_491521502192_item	3654426	et	4	main
anti	doc_491521502192_item	3654425	et	3	main
a	doc_491521502192_item	3654424	et	4	main
1680	doc_491521502192_item	3654423	et	2	main
filosoofiat	doc_491521502192_item	3654422	et	3	main
ja	doc_491521502192_item	3654421	et	3	main
usuteaduskonnas	doc_491521502192_item	3654420	et	4	main
arstiteaduskonnas	doc_491521502192_item	3654419	et	4	main
õigusteaduskonnas	doc_491521502192_item	3654418	et	4	main
õppida	doc_491521502192_item	3654417	et	3	main
võis	doc_491521502192_item	3654416	et	4	main
seal	doc_491521502192_item	3654415	et	4	main
saanud	doc_491521502193_item	3654955	et	4	main
1819	doc_491521502193_item	3654949	et	2	main
tekstiil	doc_491521502193_item	3654939	et	3	main
vabrikud	doc_491521502193_item	3654935	et	3	main
rätsepad	doc_491521502193_item	3654932	et	3	main
eestlased	doc_491521502193_item	3654929	et	3	main
kasvama	doc_491521502193_item	3654928	et	3	main
linnades	doc_491521502193_item	3654925	et	3	main
pärast	doc_491521502193_item	3654921	et	4	main
ära	doc_491521502193_item	3654919	et	4	main
ja	doc_491521502193_item	3654917	et	3	main
tooma	doc_491521502193_item	3654916	et	3	main
seda	doc_491521502193_item	3654915	et	3	main
varem	doc_491521502193_item	3654908	et	4	main
kui	doc_491521502193_item	3654907	et	3	main
näidati	doc_491521502193_item	3654846	et	3	main
rebaseks	doc_491521502193_item	3654843	et	4	main
osta	doc_491521502193_item	3654958	et	4	main
neid	doc_491521502193_item	3654953	et	4	main
leedus	doc_491521502193_item	3654950	et	4	main
uus	doc_491521502193_item	3654945	et	3	main
vabrik	doc_491521502193_item	3654942	et	3	main
tööstus	doc_491521502193_item	3654940	et	3	main
sits	doc_491521502193_item	3654938	et	3	main
kanga	doc_491521502193_item	3654936	et	3	main
tekivad	doc_491521502193_item	3654934	et	3	main
baltimaadel	doc_491521502193_item	3654912	et	4	main
kanepit	doc_491521502193_item	3654901	et	3	main
vajati	doc_491521502193_item	3654900	et	3	main
arenguga	doc_491521502193_item	3654899	et	3	main
laevanduse	doc_491521502193_item	3654898	et	3	main
seoses	doc_491521502193_item	3654897	et	4	main
priiks	doc_491521502193_item	3654896	et	3	main
seaduslikult	doc_491521502193_item	3654895	et	4	main
pärisorjusest	doc_491521502193_item	3654894	et	4	main
eestlased	doc_491521502193_item	3654893	et	3	main
said	doc_491521502193_item	3654892	et	4	main
ajal	doc_491521502193_item	3654891	et	4	main
valitsuse	doc_491521502193_item	3654890	et	4	main
tema	doc_491521502193_item	3654889	et	4	main
i	doc_491521502193_item	3654888	et	4	main
aleksander	doc_491521502193_item	3654887	et	4	main
troonile	doc_491521502193_item	3654886	et	3	main
venemaal	doc_491521502193_item	3654885	et	4	main
tõuseb	doc_491521502193_item	3654884	et	3	main
1801	doc_491521502193_item	3654883	et	2	main
minevikku	doc_491521502193_item	3654882	et	4	main
rahvaste	doc_491521502193_item	3654881	et	4	main
euroopa	doc_491521502193_item	3654880	et	4	main
ülistama	doc_491521502193_item	3654879	et	3	main
hakatakse	doc_491521502193_item	3654878	et	3	main
romantism	doc_491521502193_item	3654877	et	3	main
1700	doc_491521502193_item	3654876	et	2	main
kivisild	doc_491521502193_item	3654875	et	3	main
tartu	doc_491521502193_item	3654874	et	4	main
loss	doc_491521502193_item	3654873	et	3	main
kunstistiiliks	doc_491521502193_item	3654870	et	3	main
oli	doc_491521502193_item	3654868	et	3	main
kuni	doc_491521502193_item	3654865	et	3	main
vastama	doc_491521502193_item	3654862	et	3	main
ta	doc_491521502193_item	3654860	et	4	main
ja	doc_491521502193_item	3654859	et	3	main
harimatust	doc_491521502193_item	3654848	et	4	main
oli	doc_491521502193_item	3654839	et	3	main
17	doc_491521502193_item	3654837	et	2	main
üliõpilane	doc_491521502193_item	3654836	et	3	main
noorim	doc_491521502193_item	3654835	et	3	main
stipendiume	doc_491521502193_item	3654834	et	3	main
said	doc_491521502193_item	3654833	et	4	main
üliõpilased	doc_491521502193_item	3654832	et	3	main
puhul	doc_491521502193_item	3654815	et	4	main
kõige	doc_491521502193_item	3654806	et	4	main
linnakodanikud	doc_491521502193_item	3654805	et	3	main
ka	doc_491521502193_item	3654804	et	3	main
vaid	doc_491521502193_item	3654784	et	3	main
õpetati	doc_491521502193_item	3654783	et	3	main
keelt	doc_491521502193_item	3654782	et	4	main
tund	doc_491521502193_item	3654781	et	3	main
1	doc_491521502193_item	3654780	et	2	main
loeng	doc_491521502193_item	3654779	et	3	main
üks	doc_491521502193_item	3654778	et	3	main
professorit	doc_491521502193_item	3654777	et	3	main
30	doc_491521502193_item	3654776	et	2	main
kinnitati	doc_491521502193_item	3654775	et	4	main
ülikoolis	doc_491521502193_item	3654774	et	4	main
tartu	doc_491521502193_item	3654773	et	4	main
majandamiseks	doc_491521502193_item	3654772	et	4	main
ülikooli	doc_491521502193_item	3654771	et	4	main
läks	doc_491521502193_item	3654770	et	3	main
tulu	doc_491521502193_item	3654769	et	4	main
saanud	doc_491521502193_item	3654768	et	4	main
saagist	doc_491521502193_item	3654767	et	4	main
talupoegade	doc_491521502193_item	3654766	et	3	main
mõisad	doc_491521502193_item	3654765	et	3	main
kuulusid	doc_491521502193_item	3654764	et	4	main
juurde	doc_491521502193_item	3654763	et	4	main
ülikooli	doc_491521502193_item	3654762	et	4	main
tartu	doc_491521502193_item	3654761	et	4	main
andreas	doc_491521502193_item	3654760	et	4	main
professor	doc_491521502193_item	3654759	et	3	main
aastane	doc_491521502193_item	3654752	et	4	main
tartu	doc_491521502193_item	3654724	et	4	main
pidi	doc_491521502193_item	3654695	et	4	main
pääseda	doc_491521502193_item	3654694	et	3	main
adolfi	doc_491521502193_item	3654688	et	4	main
asutati	doc_491521502193_item	3654679	et	4	main
nende	doc_491521502193_item	3654661	et	4	main
ja	doc_491521502193_item	3654658	et	3	main
kultuurielule	doc_491521502193_item	3654652	et	3	main
ülikooli	doc_491521502193_item	3654851	et	4	main
palju	doc_491521502193_item	3654831	et	4	main
väga	doc_491521502193_item	3654830	et	3	main
ühistoidul	doc_491521502193_item	3654829	et	3	main
kooli	doc_491521502193_item	3654813	et	4	main
soomest	doc_491521502193_item	3654812	et	3	main
ja	doc_491521502193_item	3654811	et	3	main
kuulama	doc_491521502193_item	3654802	et	3	main
avalik	doc_491521502193_item	3654799	et	3	main
eksam	doc_491521502193_item	3654797	et	3	main
valitud	doc_491521502193_item	3654795	et	4	main
j	doc_491521502193_item	3654753	et	4	main
ajal	doc_491521502193_item	3654749	et	4	main
tollel	doc_491521502193_item	3654748	et	4	main
tulid	doc_491521502193_item	3654740	et	4	main
tartusse	doc_491521502193_item	3654739	et	3	main
usuteaduskond	doc_491521502193_item	3654738	et	3	main
4	doc_491521502193_item	3654737	et	2	main
arstiteaduskond	doc_491521502193_item	3654736	et	3	main
3	doc_491521502193_item	3654735	et	2	main
tartu	doc_491521502193_item	3654722	et	4	main
hariduse	doc_491521502193_item	3654707	et	3	main
väga	doc_491521502193_item	3654705	et	3	main
et	doc_491521502193_item	3654692	et	3	main
tartus	doc_491521502193_item	3654677	et	3	main
tõlke	doc_491521502193_item	3654671	et	4	main
jesuiitide	doc_491521502193_item	3654667	et	3	main
sisuliselt	doc_491521502193_item	3654663	et	4	main
jaoks	doc_491521502193_item	3654662	et	4	main
mida	doc_491521502193_item	3654659	et	4	main
arendama	doc_491521502196_item	3655182	et	3	main
ka	doc_491521502196_item	3655180	et	3	main
valdkondades	doc_491521502196_item	3655178	et	3	main
uuringuid	doc_491521502196_item	3655176	et	3	main
võimalus	doc_491521502196_item	3655174	et	3	main
inimesed	doc_491521502196_item	3655163	et	3	main
ülikoolis	doc_491521502196_item	3655161	et	4	main
sai	doc_491521502196_item	3655158	et	4	main
tähtis	doc_491521502196_item	3655152	et	4	main
valgustusideaalidest	doc_491521502196_item	3655148	et	3	main
huvitatud	doc_491521502196_item	3655147	et	4	main
olid	doc_491521502196_item	3655146	et	4	main
jakobi	doc_491521502196_item	3655137	et	4	main
embrüoloogia	doc_491521502196_item	3655135	et	4	main
inimesi	doc_491521502196_item	3655130	et	4	main
riikidest	doc_491521502196_item	3655120	et	3	main
ja	doc_491521502196_item	3655117	et	3	main
saksa	doc_491521502196_item	3655110	et	4	main
veel	doc_491521502196_item	3655109	et	4	main
ikka	doc_491521502196_item	3655108	et	4	main
uuesti	doc_491521502196_item	3655102	et	3	main
avati	doc_491521502196_item	3655101	et	3	main
sisuliselt	doc_491521502196_item	3654980	et	4	main
jaoks	doc_491521502196_item	3654979	et	4	main
ja	doc_491521502196_item	3654975	et	3	main
pärisorjusest	doc_491521502196_item	3654974	et	4	main
ja	doc_491521502196_item	3654968	et	3	main
haridus-	doc_491521502196_item	3654967	et	3	main
tartu	doc_491521502196_item	3654962	et	4	main
talupoeg	doc_491521502196_item	3655084	et	3	main
kuigi	doc_491521502196_item	3655075	et	3	main
talupoeg	doc_491521502196_item	3655060	et	3	main
tundis	doc_491521502196_item	3655059	et	3	main
tähendas	doc_491521502196_item	3655048	et	3	main
vaatamata	doc_491521502196_item	3655045	et	4	main
aga	doc_491521502196_item	3655044	et	3	main
karmimaks	doc_491521502196_item	3655043	et	4	main
seda	doc_491521502196_item	3655033	et	3	main
tähendanud	doc_491521502196_item	3655032	et	4	main
talupoeg	doc_491521502196_item	3655025	et	3	main
sai	doc_491521502196_item	3655024	et	4	main
omavalitsuse	doc_491521502196_item	3655023	et	3	main
maksma	doc_491521502196_item	3655022	et	3	main
renti	doc_491521502196_item	3655019	et	4	main
olid	doc_491521502193_item	3654828	et	4	main
üliõpilasi	doc_491521502193_item	3654827	et	3	main
enamik	doc_491521502193_item	3654826	et	3	main
nõutud	doc_491521502193_item	3654824	et	4	main
ei	doc_491521502193_item	3654823	et	4	main
ülikoolis	doc_491521502193_item	3654822	et	4	main
dokumenti	doc_491521502193_item	3654820	et	4	main
mingit	doc_491521502193_item	3654818	et	3	main
antud	doc_491521502193_item	3654817	et	4	main
üliõpilaste	doc_491521502193_item	3654809	et	4	main
oli	doc_491521502193_item	3654808	et	3	main
rohkem	doc_491521502193_item	3654807	et	4	main
võisid	doc_491521502193_item	3654801	et	4	main
eksamil	doc_491521502193_item	3654800	et	3	main
kuus	doc_491521502193_item	3654788	et	4	main
igas	doc_491521502193_item	3654787	et	3	main
paasil	doc_491521502193_item	3654786	et	4	main
grammatika	doc_491521502193_item	3654785	et	4	main
ülikooli	doc_491521502193_item	3654758	et	4	main
19	doc_491521502193_item	3654751	et	2	main
ülikooli	doc_491521502193_item	3654746	et	4	main
lapsed	doc_491521502193_item	3654744	et	3	main
2	doc_491521502193_item	3654733	et	2	main
ülikooliks	doc_491521502193_item	3654723	et	4	main
andmist	doc_491521502193_item	3654708	et	4	main
kuningriik	doc_491521502193_item	3654703	et	3	main
linnakoolis	doc_491521502193_item	3654701	et	4	main
klassis	doc_491521502193_item	3654700	et	3	main
gümnaasiumi	doc_491521502193_item	3654689	et	4	main
gustav	doc_491521502193_item	3654687	et	4	main
1631	doc_491521502193_item	3654678	et	2	main
kes	doc_491521502193_item	3654672	et	4	main
eesmärk	doc_491521502193_item	3654669	et	3	main
1	doc_491521502193_item	3654665	et	2	main
arenemisest	doc_491521502196_item	3655171	et	4	main
hariduse	doc_491521502196_item	3655170	et	3	main
kultuuri	doc_491521502196_item	3655168	et	4	main
aja	doc_491521502196_item	3655154	et	4	main
ülikolis	doc_491521502196_item	3655145	et	3	main
tartu	doc_491521502196_item	3655144	et	4	main
struve	doc_491521502196_item	3655139	et	4	main
maailma	doc_491521502196_item	3655131	et	4	main
tartust	doc_491521502196_item	3655121	et	3	main
keeles	doc_491521502196_item	3655111	et	4	main
1802	doc_491521502196_item	3655099	et	2	main
taasavamise	doc_491521502196_item	3654964	et	4	main
nüüd	doc_491521502196_item	3655092	et	4	main
erdell	doc_491521502196_item	3655086	et	4	main
m	doc_491521502196_item	3655085	et	4	main
tol	doc_491521502196_item	3655076	et	3	main
ise	doc_491521502196_item	3655064	et	4	main
vastutas	doc_491521502196_item	3655063	et	3	main
ta	doc_491521502196_item	3655062	et	4	main
psühholoogiliselt	doc_491521502196_item	3655057	et	4	main
talupoja	doc_491521502196_item	3655053	et	4	main
väga	doc_491521502196_item	3655051	et	3	main
vabastamine	doc_491521502196_item	3655050	et	4	main
isegi	doc_491521502196_item	3655042	et	4	main
ta	doc_491521502196_item	3655041	et	4	main
kergemaks	doc_491521502196_item	3655037	et	4	main
elu	doc_491521502196_item	3655036	et	4	main
veel	doc_491521502196_item	3655014	et	4	main
talupoegadel	doc_491521502196_item	3655013	et	3	main
rendileppingu	doc_491521502196_item	3655009	et	4	main
üliõpilasel	doc_491521502193_item	3654791	et	3	main
teha	doc_491521502193_item	3654790	et	3	main
juhtis	doc_491521502193_item	3654757	et	3	main
tegelikult	doc_491521502193_item	3654756	et	4	main
kuid	doc_491521502193_item	3654755	et	4	main
oli	doc_491521502193_item	3654750	et	3	main
rektoriks	doc_491521502193_item	3654747	et	3	main
tartu	doc_491521502193_item	3654745	et	4	main
aadlike	doc_491521502193_item	3654743	et	4	main
õigusteaduskond	doc_491521502193_item	3654734	et	3	main
ajal	doc_491521502193_item	3654728	et	4	main
tol	doc_491521502193_item	3654727	et	3	main
oli	doc_491521502193_item	3654726	et	3	main
ülikoolis	doc_491521502193_item	3654725	et	4	main
tartu	doc_491521502193_item	3654719	et	4	main
vajalikuks	doc_491521502193_item	3654706	et	3	main
pidas	doc_491521502193_item	3654704	et	3	main
rootsi	doc_491521502193_item	3654702	et	4	main
3	doc_491521502193_item	3654699	et	2	main
triviaalkoolis	doc_491521502193_item	3654698	et	4	main
õppima	doc_491521502193_item	3654697	et	3	main
kõigepealt	doc_491521502193_item	3654696	et	3	main
selleks	doc_491521502193_item	3654691	et	4	main
1630	doc_491521502193_item	3654675	et	2	main
aitaks	doc_491521502193_item	3654673	et	3	main
koolitada	doc_491521502193_item	3654670	et	3	main
seminar	doc_491521502193_item	3654668	et	3	main
1583	doc_491521502193_item	3654666	et	2	main
tähendas	doc_491521502193_item	3654664	et	3	main
see	doc_491521502193_item	3654660	et	3	main
pärisorjusest	doc_491521502193_item	3654657	et	4	main
eestlased	doc_491521502193_item	3654656	et	3	main
vabastati	doc_491521502193_item	3654655	et	3	main
millal	doc_491521502193_item	3654654	et	3	main
2	doc_491521502193_item	3654653	et	2	main
oli	doc_491521502196_item	3655172	et	3	main
eesti	doc_491521502196_item	3655167	et	4	main
õppisid	doc_491521502196_item	3655162	et	4	main
tartu	doc_491521502196_item	3655160	et	4	main
töötasid	doc_491521502196_item	3655143	et	4	main
von	doc_491521502196_item	3655133	et	4	main
kultuuri	doc_491521502196_item	3655123	et	4	main
tulema	doc_491521502196_item	3655115	et	4	main
aegadele	doc_491521502196_item	3655097	et	3	main
liivimaal	doc_491521502196_item	3654987	et	4	main
skytre	doc_491521502193_item	3654754	et	4	main
vaesemate	doc_491521502193_item	3654742	et	4	main
enamasti	doc_491521502193_item	3654741	et	4	main
filosoofia	doc_491521502193_item	3654732	et	4	main
1	doc_491521502193_item	3654731	et	2	main
teaduskonda	doc_491521502193_item	3654730	et	4	main
4	doc_491521502193_item	3654729	et	2	main
muudeti	doc_491521502193_item	3654721	et	3	main
gümnaasium	doc_491521502193_item	3654720	et	3	main
1632	doc_491521502193_item	3654718	et	2	main
gustav	doc_491521502193_item	3654710	et	4	main
provintsides	doc_491521502193_item	3654709	et	3	main
gümnaasiumisi	doc_491521502193_item	3654693	et	4	main
eelkäiaks	doc_491521502193_item	3654690	et	3	main
tänapäeva	doc_491521502193_item	3654686	et	4	main
peetakse	doc_491521502193_item	3654685	et	3	main
mida	doc_491521502193_item	3654684	et	4	main
tallinnas	doc_491521502193_item	3654683	et	4	main
ka	doc_491521502193_item	3654682	et	3	main
gümnaasium	doc_491521502193_item	3654681	et	3	main
analoogne	doc_491521502193_item	3654680	et	3	main
gümnaasium	doc_491521502193_item	3654676	et	3	main
vaimulikke	doc_491521502193_item	3654674	et	3	main
ja	doc_491521502193_item	3654651	et	3	main
haridus-	doc_491521502193_item	3654650	et	3	main
eesti	doc_491521502193_item	3654649	et	4	main
tähtsus	doc_491521502193_item	3654648	et	4	main
taasavamise	doc_491521502193_item	3654647	et	4	main
ülikooli	doc_491521502193_item	3654646	et	4	main
tartu	doc_491521502193_item	3654645	et	4	main
1	doc_491521502193_item	3654644	et	2	main
kontrolltöö	doc_491521502193_item	3654643	et	4	main
asutamisele	doc_491521502193_item	3654717	et	4	main
ülikooli	doc_491521502193_item	3654716	et	4	main
tartu	doc_491521502193_item	3654715	et	4	main
alla	doc_491521502193_item	3654714	et	3	main
kirjutas	doc_491521502193_item	3654713	et	3	main
adolf	doc_491521502193_item	3654712	et	4	main
ii	doc_491521502193_item	3654711	et	4	main
nüüd	doc_491521502196_item	3655173	et	4	main
ja	doc_491521502196_item	3655169	et	3	main
huvitatud	doc_491521502196_item	3655166	et	4	main
olid	doc_491521502196_item	3655165	et	4	main
kättesaadavaks	doc_491521502196_item	3655159	et	4	main
kultuuri	doc_491521502196_item	3655155	et	4	main
oli	doc_491521502196_item	3655150	et	3	main
kes	doc_491521502196_item	3655142	et	4	main
paljud	doc_491521502196_item	3655141	et	3	main
tuntud	doc_491521502196_item	3655132	et	4	main
sai	doc_491521502196_item	3655122	et	4	main
teistest	doc_491521502196_item	3655119	et	4	main
ülikool	doc_491521502196_item	3655104	et	4	main
tartu	doc_491521502196_item	3655103	et	4	main
aastal	doc_491521502196_item	3655100	et	3	main
parematele	doc_491521502196_item	3655096	et	4	main
ja	doc_491521502196_item	3655094	et	3	main
1816	doc_491521502196_item	3654986	et	2	main
eestimaal	doc_491521502196_item	3654985	et	4	main
kaotati	doc_491521502196_item	3654984	et	3	main
pärisorjus	doc_491521502196_item	3654983	et	3	main
2	doc_491521502196_item	3654982	et	2	main
tähendas	doc_491521502196_item	3654981	et	3	main
mida	doc_491521502196_item	3654976	et	4	main
millal	doc_491521502196_item	3654971	et	3	main
eesti	doc_491521502196_item	3654966	et	4	main
tähtsus	doc_491521502196_item	3654965	et	4	main
1	doc_491521502196_item	3654961	et	2	main
oli	doc_491521502196_item	3655091	et	3	main
ajal	doc_491521502196_item	3655077	et	4	main
talupojal	doc_491521502196_item	3655069	et	4	main
oli	doc_491521502196_item	3655068	et	3	main
see	doc_491521502196_item	3655055	et	3	main
neid	doc_491521502196_item	3655181	et	4	main
ja	doc_491521502196_item	3655179	et	3	main
paljudes	doc_491521502196_item	3655177	et	3	main
teha	doc_491521502196_item	3655175	et	3	main
kes	doc_491521502196_item	3655164	et	4	main
kõrgharidus	doc_491521502196_item	3655157	et	3	main
arengule	doc_491521502196_item	3655156	et	3	main
toll	doc_491521502196_item	3655153	et	3	main
väga	doc_491521502196_item	3655151	et	3	main
see	doc_491521502196_item	3655149	et	3	main
astronoom	doc_491521502196_item	3655140	et	3	main
w	doc_491521502196_item	3655138	et	4	main
rajaja	doc_491521502196_item	3655136	et	4	main
baer	doc_491521502196_item	3655134	et	4	main
palju	doc_491521502196_item	3655129	et	4	main
töötas	doc_491521502196_item	3655128	et	3	main
tartus	doc_491521502196_item	3655127	et	3	main
keskus	doc_491521502196_item	3655126	et	3	main
hariduse	doc_491521502196_item	3655125	et	3	main
ja	doc_491521502196_item	3655124	et	3	main
teadlased	doc_491521502196_item	3655118	et	3	main
professorid	doc_491521502196_item	3655116	et	3	main
eestisse	doc_491521502196_item	3655114	et	4	main
hakkasid	doc_491521502196_item	3655113	et	4	main
jälle	doc_491521502196_item	3655112	et	3	main
seal	doc_491521502196_item	3655107	et	4	main
toimus	doc_491521502196_item	3655106	et	3	main
õppetöö	doc_491521502196_item	3655105	et	4	main
1	doc_491521502196_item	3655098	et	2	main
lootus	doc_491521502196_item	3655095	et	4	main
nende	doc_491521502196_item	3654978	et	4	main
see	doc_491521502196_item	3654977	et	3	main
ülikooli	doc_491521502196_item	3654963	et	4	main
usk	doc_491521502196_item	3655093	et	3	main
talupojal	doc_491521502196_item	3655090	et	4	main
mõisaomanikuks	doc_491521502196_item	3655088	et	4	main
sai	doc_491521502196_item	3655087	et	4	main
nüüd	doc_491521502196_item	3655067	et	4	main
eest	doc_491521502196_item	3655066	et	4	main
enda	doc_491521502196_item	3655065	et	4	main
nüüd	doc_491521502196_item	3655058	et	4	main
jaoks	doc_491521502196_item	3655054	et	4	main
palju	doc_491521502196_item	3655052	et	4	main
kohati	doc_491521502196_item	3655039	et	4	main
kinni	doc_491521502196_item	3655021	et	3	main
nad	doc_491521502196_item	3655018	et	3	main
olnud	doc_491521502196_item	3655016	et	4	main
eestlased	doc_491521502196_item	3654973	et	3	main
vabastati	doc_491521502196_item	3654972	et	3	main
2	doc_491521502196_item	3654970	et	2	main
kultuurielule	doc_491521502196_item	3654969	et	3	main
kontrolltöö	doc_491521502196_item	3654960	et	4	main
eesti	doc_491521502196_item	3655089	et	4	main
näiteks	doc_491521502196_item	3655083	et	4	main
aga	doc_491521502196_item	3655082	et	3	main
unistus	doc_491521502196_item	3655081	et	4	main
ainult	doc_491521502196_item	3655080	et	4	main
oli	doc_491521502196_item	3655079	et	3	main
see	doc_491521502196_item	3655078	et	3	main
osta	doc_491521502196_item	3655074	et	4	main
välja	doc_491521502196_item	3655073	et	4	main
maad	doc_491521502196_item	3655072	et	4	main
oma	doc_491521502196_item	3655071	et	4	main
võimalus	doc_491521502196_item	3655070	et	3	main
vabadust	doc_491521502196_item	3655061	et	4	main
mõjutas	doc_491521502196_item	3655056	et	3	main
parisorjusest	doc_491521502196_item	3655049	et	4	main
rasketele	doc_491521502196_item	3655046	et	3	main
taluoja	doc_491521502196_item	3655035	et	4	main
et	doc_491521502196_item	3655034	et	3	main
ainult	doc_491521502196_item	3655026	et	4	main
raha	doc_491521502196_item	3655012	et	4	main
kuna	doc_491521502196_item	3655011	et	3	main
elutingimuste	doc_491521502196_item	3655047	et	3	main
muutus	doc_491521502196_item	3655040	et	4	main
muutub	doc_491521502196_item	3655038	et	3	main
ei	doc_491521502196_item	3655031	et	4	main
kaotamine	doc_491521502196_item	3655030	et	4	main
pärisorjuse	doc_491521502196_item	3655029	et	3	main
tasandil	doc_491521502196_item	3655028	et	3	main
valla	doc_491521502196_item	3655027	et	4	main
tööga	doc_491521502196_item	3655020	et	3	main
pidid	doc_491521502196_item	3655017	et	4	main
ei	doc_491521502196_item	3655015	et	4	main
eesti	doc_491521502198_item	3655740	et	4	main
materiaalne	doc_491521502198_item	3655738	et	3	main
taibas	doc_491521502198_item	3655729	et	4	main
asutas	doc_491521502198_item	3655722	et	3	main
kõik	doc_491521502198_item	3655706	et	4	main
probleemidega	doc_491521502198_item	3655703	et	3	main
küsimustega	doc_491521502198_item	3655701	et	4	main
väga	doc_491521502198_item	3655699	et	3	main
tegeles	doc_491521502198_item	3655695	et	3	main
ões	doc_491521502198_item	3655694	et	4	main
selts	doc_491521502198_item	3655693	et	3	main
tema	doc_491521502198_item	3655688	et	4	main
erikorda	doc_491521502198_item	3655671	et	4	main
j	doc_491521502198_item	3655663	et	4	main
haridusedga	doc_491521502198_item	3655653	et	4	main
maksimaalse	doc_491521502198_item	3655652	et	3	main
loodusteaduste	doc_491521502198_item	3655642	et	3	main
eitasid	doc_491521502198_item	3655630	et	4	main
midagi	doc_491521502198_item	3655628	et	4	main
ise	doc_491521502198_item	3655627	et	4	main
inimese	doc_491521502198_item	3655622	et	4	main
valgustus	doc_491521502198_item	3655609	et	4	main
toimub	doc_491521502198_item	3655608	et	3	main
nii	doc_491521502198_item	3655601	et	3	main
emakeeles	doc_491521502198_item	3655590	et	4	main
kuna	doc_491521502198_item	3655585	et	3	main
sõlmima	doc_491521502196_item	3655010	et	4	main
taluomanikuga	doc_491521502196_item	3655008	et	3	main
pidid	doc_491521502196_item	3655007	et	4	main
nad	doc_491521502196_item	3655006	et	3	main
ja	doc_491521502196_item	3655005	et	3	main
maata	doc_491521502196_item	3655004	et	3	main
ilma	doc_491521502196_item	3655003	et	4	main
vabastati	doc_491521502196_item	3655002	et	3	main
talupoegi	doc_491521502196_item	3655001	et	4	main
piiratud	doc_491521502196_item	3655000	et	4	main
ikka	doc_491521502196_item	3654999	et	4	main
oli	doc_491521502196_item	3654998	et	3	main
liikumi	doc_491521502196_item	3654997	et	4	main
ikka	doc_491521502196_item	3654996	et	4	main
säilis	doc_491521502196_item	3654995	et	4	main
teoorjus	doc_491521502196_item	3654994	et	3	main
aga	doc_491521502196_item	3654993	et	3	main
pärisorjus	doc_491521502196_item	3654992	et	3	main
kaotatud	doc_491521502196_item	3654991	et	4	main
oli	doc_491521502196_item	3654990	et	3	main
a	doc_491521502196_item	3654989	et	4	main
1819	doc_491521502196_item	3654988	et	2	main
palju	doc_491521502198_item	3655730	et	4	main
hurt	doc_491521502198_item	3655723	et	3	main
eesti	doc_491521502198_item	3655720	et	4	main
kultuur	doc_491521502198_item	3655711	et	3	main
huvitas	doc_491521502198_item	3655705	et	3	main
ja	doc_491521502198_item	3655702	et	3	main
õpetatud	doc_491521502198_item	3655691	et	4	main
et	doc_491521502198_item	3655685	et	3	main
ehk	doc_491521502198_item	3655683	et	3	main
oma	doc_491521502198_item	3655675	et	4	main
kelle	doc_491521502198_item	3655665	et	4	main
herder	doc_491521502198_item	3655664	et	4	main
sellelperioodil	doc_491521502198_item	3655657	et	4	main
inimesed	doc_491521502198_item	3655656	et	3	main
teadmistega	doc_491521502198_item	3655655	et	4	main
ja	doc_491521502198_item	3655654	et	3	main
monarhia	doc_491521502198_item	3655649	et	4	main
arenemine	doc_491521502198_item	3655647	et	4	main
toimub	doc_491521502198_item	3655644	et	3	main
ratsionalism	doc_491521502198_item	3655639	et	3	main
nõudsid	doc_491521502198_item	3655632	et	4	main
pärisorjust	doc_491521502198_item	3655631	et	3	main
enda	doc_491521502198_item	3655623	et	4	main
haridus	doc_491521502198_item	3655614	et	3	main
kunst	doc_491521502198_item	3655613	et	3	main
toetas	doc_491521502198_item	3655612	et	3	main
valgustusfilosoofiat	doc_491521502198_item	3655611	et	3	main
ka	doc_491521502198_item	3655604	et	3	main
kui	doc_491521502198_item	3655603	et	3	main
jõudsid	doc_491521502198_item	3655600	et	4	main
võrdsed	doc_491521502198_item	3655598	et	3	main
on	doc_491521502198_item	3655597	et	4	main
suhtlesid	doc_491521502198_item	3655587	et	4	main
oli	doc_491521502198_item	3655542	et	3	main
vastu	doc_491521502198_item	3655540	et	3	main
sellise	doc_491521502198_item	3655534	et	4	main
talurahvas	doc_491521502198_item	3655528	et	4	main
ülejäänud	doc_491521502198_item	3655524	et	4	main
omaks	doc_491521502198_item	3655510	et	4	main
mõisnike	doc_491521502198_item	3655509	et	3	main
ehk	doc_491521502198_item	3655508	et	3	main
selts	doc_491521502198_item	3655741	et	3	main
õpetatud	doc_491521502198_item	3655739	et	4	main
mitte	doc_491521502198_item	3655737	et	3	main
oli	doc_491521502198_item	3655742	et	3	main
elu	doc_491521502198_item	3655736	et	4	main
vaimulik	doc_491521502198_item	3655735	et	3	main
huvitas	doc_491521502198_item	3655734	et	3	main
teda	doc_491521502198_item	3655733	et	4	main
elust	doc_491521502198_item	3655732	et	3	main
rahva	doc_491521502198_item	3655731	et	3	main
kes	doc_491521502198_item	3655724	et	4	main
seltsi	doc_491521502198_item	3655721	et	4	main
õpetatud	doc_491521502198_item	3655719	et	4	main
kultuurilooga	doc_491521502198_item	3655718	et	4	main
elu-ja	doc_491521502198_item	3655717	et	3	main
tegeles	doc_491521502198_item	3655716	et	3	main
mis	doc_491521502198_item	3655707	et	4	main
ões-it	doc_491521502198_item	3655704	et	4	main
nad	doc_491521502198_item	3655686	et	3	main
rahvaga	doc_491521502198_item	3655682	et	3	main
tahtis	doc_491521502198_item	3655679	et	3	main
ta	doc_491521502198_item	3655678	et	4	main
sellega	doc_491521502198_item	3655677	et	3	main
i	doc_491521502198_item	3655674	et	4	main
peeter	doc_491521502198_item	3655673	et	3	main
säilis	doc_491521502198_item	3655672	et	4	main
edasi	doc_491521502198_item	3655646	et	3	main
saavutustele	doc_491521502198_item	3655641	et	4	main
paremaks	doc_491521502198_item	3655625	et	4	main
valgustusidee	doc_491521502198_item	3655617	et	4	main
sellel	doc_491521502198_item	3655606	et	4	main
inimesed	doc_491521502198_item	3655596	et	3	main
kõik	doc_491521502198_item	3655595	et	4	main
talupoegadega	doc_491521502198_item	3655588	et	3	main
tartus	doc_491521502198_item	3655746	et	3	main
a	doc_491521502198_item	3655745	et	4	main
1838	doc_491521502198_item	3655744	et	2	main
asutatud	doc_491521502198_item	3655743	et	4	main
kuid	doc_491521502198_item	3655728	et	4	main
poliitik	doc_491521502198_item	3655727	et	3	main
vilets	doc_491521502198_item	3655726	et	3	main
oli	doc_491521502198_item	3655725	et	3	main
peamiselt	doc_491521502198_item	3655715	et	4	main
kuid	doc_491521502198_item	3655714	et	4	main
haridus	doc_491521502198_item	3655713	et	3	main
kirjandus	doc_491521502198_item	3655712	et	3	main
eestirahvaga	doc_491521502198_item	3655710	et	3	main
seotud	doc_491521502198_item	3655709	et	4	main
oli	doc_491521502198_item	3655708	et	3	main
eesti	doc_491521502198_item	3655692	et	4	main
2	doc_491521502198_item	3655690	et	2	main
pool	doc_491521502198_item	3655689	et	4	main
oleksid	doc_491521502198_item	3655687	et	4	main
tahtis	doc_491521502198_item	3655684	et	3	main
baltikumi	doc_491521502198_item	3655681	et	4	main
läheneda	doc_491521502198_item	3655680	et	3	main
tegevusele	doc_491521502198_item	3655666	et	4	main
tuntud	doc_491521502198_item	3655661	et	4	main
väga	doc_491521502198_item	3655660	et	3	main
euroopas	doc_491521502198_item	3655659	et	3	main
oli	doc_491521502198_item	3655658	et	3	main
peaksid	doc_491521502198_item	3655650	et	4	main
teaduste	doc_491521502198_item	3655645	et	3	main
tugines	doc_491521502198_item	3655640	et	3	main
valgustusajastu	doc_491521502198_item	3655635	et	4	main
tegema	doc_491521502198_item	3655629	et	3	main
elu	doc_491521502198_item	3655624	et	4	main
teadus	doc_491521502198_item	3655616	et	4	main
ja	doc_491521502198_item	3655615	et	3	main
levik	doc_491521502198_item	3655610	et	3	main
perioodil	doc_491521502198_item	3655607	et	3	main
põhja-	doc_491521502198_item	3655602	et	4	main
need	doc_491521502198_item	3655599	et	3	main
hernhuutlased	doc_491521502198_item	3655594	et	3	main
eestisse	doc_491521502198_item	3655593	et	4	main
levisid	doc_491521502198_item	3655592	et	4	main
1730-1740	doc_491521502198_item	3655591	et	2	main
balti-sakslased	doc_491521502198_item	3655586	et	3	main
keelt	doc_491521502198_item	3655584	et	4	main
talupoegade	doc_491521502198_item	3655543	et	3	main
see	doc_491521502198_item	3655541	et	3	main
mõisnikele	doc_491521502198_item	3655539	et	3	main
õigus	doc_491521502198_item	3655533	et	4	main
maal	doc_491521502198_item	3655527	et	4	main
elab	doc_491521502198_item	3655526	et	3	main
on	doc_491521502198_item	3655522	et	4	main
need	doc_491521502198_item	3655521	et	3	main
10	doc_491521502198_item	3655519	et	2	main
ainult	doc_491521502198_item	3655518	et	4	main
elab	doc_491521502198_item	3655517	et	3	main
linnades	doc_491521502198_item	3655516	et	3	main
seadused	doc_491521502198_item	3655515	et	3	main
rootsiaja	doc_491521502198_item	3655514	et	3	main
kehtivad	doc_491521502198_item	3655513	et	4	main
rolli	doc_491521502201_item	3655978	et	4	main
toimus	doc_491521502201_item	3655970	et	3	main
vanglasse	doc_491521502201_item	3655963	et	4	main
kaaslasi	doc_491521502201_item	3655962	et	3	main
köleri	doc_491521502201_item	3655961	et	4	main
päästis	doc_491521502201_item	3655960	et	3	main
ta	doc_491521502201_item	3655959	et	4	main
liikumise	doc_491521502201_item	3655947	et	4	main
teatud	doc_491521502201_item	3655942	et	4	main
jakob	doc_491521502201_item	3655939	et	4	main
jätkas	doc_491521502201_item	3655937	et	3	main
tööd	doc_491521502201_item	3655936	et	4	main
seltsi	doc_491521502201_item	3655921	et	4	main
ilmalikku	doc_491521502201_item	3655908	et	4	main
keeles	doc_491521502201_item	3655904	et	4	main
lõunaeesti	doc_491521502201_item	3655903	et	3	main
välja	doc_491521502201_item	3655902	et	4	main
andis	doc_491521502201_item	3655901	et	3	main
see	doc_491521502201_item	3655900	et	3	main
hakkas	doc_491521502201_item	3655871	et	3	main
balti	doc_491521502201_item	3655868	et	3	main
eestikeelseks	doc_491521502201_item	3655853	et	4	main
andnud	doc_491521502201_item	3655846	et	4	main
mõisnikud	doc_491521502201_item	3655838	et	3	main
sakslastest	doc_491521502201_item	3655837	et	3	main
tähtsate	doc_491521502198_item	3655700	et	3	main
jaoks	doc_491521502198_item	3655698	et	4	main
eestirahva	doc_491521502198_item	3655697	et	3	main
eestis	doc_491521502198_item	3655696	et	3	main
kasuks	doc_491521502198_item	3655676	et	4	main
balti	doc_491521502198_item	3655670	et	3	main
sünd	doc_491521502198_item	3655669	et	3	main
rahvaluule	doc_491521502198_item	3655668	et	4	main
järgnes	doc_491521502198_item	3655667	et	3	main
mees	doc_491521502198_item	3655662	et	4	main
olema	doc_491521502198_item	3655651	et	4	main
valgustatud	doc_491521502198_item	3655648	et	4	main
alas	doc_491521502198_item	3655643	et	3	main
ratsionalismi	doc_491521502198_item	3655636	et	4	main
vabadust	doc_491521502198_item	3655634	et	4	main
isikute	doc_491521502198_item	3655633	et	4	main
peab	doc_491521502198_item	3655626	et	4	main
kirikut	doc_491521502198_item	3655621	et	3	main
ja	doc_491521502198_item	3655620	et	3	main
feodaalkorda	doc_491521502198_item	3655619	et	4	main
kritiseeris	doc_491521502198_item	3655618	et	3	main
lõuna-eestisse	doc_491521502198_item	3655605	et	4	main
nende	doc_491521502198_item	3655589	et	4	main
erikord	doc_491521502198_item	3655581	et	3	main
balti	doc_491521502198_item	3655580	et	3	main
et	doc_491521502198_item	3655579	et	3	main
arvatakse	doc_491521502198_item	3655578	et	3	main
valgustusajastu	doc_491521502198_item	3655577	et	4	main
baltikumi	doc_491521502198_item	3655576	et	4	main
jõuab	doc_491521502198_item	3655575	et	3	main
euroopas	doc_491521502198_item	3655574	et	3	main
kui	doc_491521502198_item	3655573	et	3	main
hiljem	doc_491521502198_item	3655572	et	3	main
aastat	doc_491521502198_item	3655571	et	3	main
100	doc_491521502198_item	3655570	et	2	main
dogmast	doc_491521502198_item	3655569	et	4	main
neid	doc_491521502198_item	3655568	et	4	main
vabastada	doc_491521502198_item	3655567	et	3	main
püüti	doc_491521502198_item	3655566	et	3	main
haridust	doc_491521502198_item	3655565	et	4	main
inimeste	doc_491521502198_item	3655564	et	3	main
süvendada	doc_491521502198_item	3655563	et	3	main
taheti	doc_491521502198_item	3655562	et	3	main
sellega	doc_491521502198_item	3655561	et	3	main
entsüklopeediat	doc_491521502198_item	3655560	et	3	main
kujulise	doc_491521502198_item	3655559	et	4	main
sõnaraamatu	doc_491521502198_item	3655558	et	4	main
välja	doc_491521502198_item	3655557	et	4	main
antakse	doc_491521502198_item	3655556	et	3	main
aastal	doc_491521502198_item	3655555	et	3	main
1751	doc_491521502198_item	3655554	et	2	main
kehale	doc_491521502198_item	3655553	et	3	main
häbimärk	doc_491521502198_item	3655552	et	3	main
talle	doc_491521502198_item	3655551	et	4	main
pandi	doc_491521502198_item	3655550	et	4	main
üles	doc_491521502198_item	3655549	et	3	main
põgeneja	doc_491521502198_item	3655548	et	4	main
leiti	doc_491521502198_item	3655547	et	3	main
kui	doc_491521502198_item	3655546	et	3	main
venemaale	doc_491521502198_item	3655545	et	4	main
põgenemine	doc_491521502198_item	3655544	et	4	main
eesti	doc_491521502198_item	3655583	et	4	main
päästis	doc_491521502198_item	3655582	et	3	main
korra	doc_491521502198_item	3655535	et	4	main
sellel	doc_491521502198_item	3655529	et	4	main
suhtes	doc_491521502198_item	3655512	et	4	main
talupoegade	doc_491521502198_item	3655511	et	3	main
talupojad	doc_491521502198_item	3655505	et	4	main
kõik	doc_491521502198_item	3655504	et	4	main
uurimises	doc_491521502201_item	3655981	et	4	main
mängis	doc_491521502201_item	3655976	et	3	main
tartus	doc_491521502201_item	3655971	et	3	main
algatusel	doc_491521502201_item	3655969	et	4	main
sattumisest	doc_491521502201_item	3655964	et	4	main
postimees	doc_491521502201_item	3655953	et	4	main
aleksandrikooli	doc_491521502201_item	3655946	et	4	main
sai	doc_491521502201_item	3655945	et	4	main
ning	doc_491521502201_item	3655944	et	3	main
tema	doc_491521502201_item	3655935	et	4	main
teiste	doc_491521502201_item	3655930	et	4	main
kasutades	doc_491521502201_item	3655929	et	3	main
kalevipoeg	doc_491521502201_item	3655928	et	3	main
rahvuseepose	doc_491521502201_item	3655927	et	3	main
eesti	doc_491521502201_item	3655926	et	4	main
koostama	doc_491521502201_item	3655925	et	3	main
hakkas	doc_491521502201_item	3655924	et	3	main
r	doc_491521502201_item	3655917	et	4	main
aabitsaid	doc_491521502201_item	3655905	et	3	main
2	doc_491521502201_item	3655875	et	2	main
erikorraga	doc_491521502201_item	3655869	et	3	main
rahul	doc_491521502201_item	3655867	et	4	main
esimene	doc_491521502201_item	3655864	et	3	main
keiser	doc_491521502201_item	3655862	et	3	main
vormi	doc_491521502201_item	3655861	et	4	main
suulise	doc_491521502201_item	3655860	et	4	main
saab	doc_491521502201_item	3655859	et	3	main
protest	doc_491521502201_item	3655858	et	3	main
talurahva	doc_491521502201_item	3655857	et	3	main
et	doc_491521502201_item	3655856	et	3	main
jäi	doc_491521502201_item	3655852	et	3	main
võimaluse	doc_491521502201_item	3655847	et	3	main
tahtnud	doc_491521502201_item	3655840	et	4	main
et	doc_491521502201_item	3655831	et	3	main
haridus	doc_491521502201_item	3655826	et	3	main
pärisorja	doc_491521502201_item	3655822	et	4	main
oma	doc_491521502201_item	3655821	et	4	main
poolvabad	doc_491521502201_item	3655808	et	3	main
see	doc_491521502201_item	3655798	et	3	main
kapitalistlik	doc_491521502201_item	3655789	et	3	main
euroopas	doc_491521502201_item	3655786	et	3	main
täielik	doc_491521502201_item	3655784	et	3	main
talupoeg	doc_491521502201_item	3655782	et	3	main
10	doc_491521502201_item	3655779	et	2	main
ja	doc_491521502201_item	3655778	et	3	main
talurahvast	doc_491521502201_item	3655777	et	4	main
90	doc_491521502201_item	3655776	et	2	main
hakkavad	doc_491521502198_item	3655537	et	4	main
pärast	doc_491521502198_item	3655536	et	4	main
teha	doc_491521502198_item	3655506	et	3	main
tugevnes	doc_491521502198_item	3655502	et	3	main
isegi	doc_491521502198_item	3655501	et	4	main
pärisorjus	doc_491521502198_item	3655500	et	3	main
venemaal	doc_491521502198_item	3655499	et	4	main
ja	doc_491521502198_item	3655498	et	3	main
baltikumis	doc_491521502198_item	3655497	et	4	main
põhjasõda	doc_491521502198_item	3655496	et	4	main
pärast	doc_491521502198_item	3655495	et	4	main
kaotatud	doc_491521502198_item	3655494	et	4	main
see	doc_491521502198_item	3655493	et	3	main
oli	doc_491521502198_item	3655492	et	3	main
euroopas	doc_491521502198_item	3655491	et	3	main
kuid	doc_491521502198_item	3655490	et	4	main
pärisori	doc_491521502198_item	3655489	et	4	main
talupoeg	doc_491521502198_item	3655488	et	3	main
alla	doc_491521502198_item	3655487	et	3	main
võimu	doc_491521502198_item	3655486	et	4	main
isanda	doc_491521502198_item	3655485	et	3	main
2	doc_491521502198_item	3655484	et	2	main
langeb	doc_491521502198_item	3655483	et	3	main
talupoeg	doc_491521502198_item	3655482	et	3	main
1	doc_491521502198_item	3655481	et	2	main
kuulusid	doc_491521502198_item	3655480	et	4	main
sinna	doc_491521502198_item	3655479	et	3	main
kes	doc_491521502198_item	3655478	et	4	main
ja	doc_491521502198_item	3655477	et	3	main
selts	doc_491521502198_item	3655476	et	3	main
eesti	doc_491521502198_item	3655475	et	4	main
õpetatud	doc_491521502198_item	3655474	et	4	main
tegeles	doc_491521502198_item	3655473	et	3	main
millega	doc_491521502198_item	3655472	et	3	main
2	doc_491521502198_item	3655471	et	2	main
erikord	doc_491521502198_item	3655470	et	3	main
balti	doc_491521502198_item	3655469	et	3	main
tähendab	doc_491521502198_item	3655468	et	3	main
1	doc_491521502198_item	3655466	et	2	main
mida	doc_491521502198_item	3655467	et	4	main
kontrolltöö	doc_491521502198_item	3655465	et	4	main
ilmub	doc_491521502198_item	3655638	et	3	main
mõiste	doc_491521502198_item	3655637	et	4	main
arendamises	doc_491521502201_item	3655983	et	4	main
suurt	doc_491521502201_item	3655977	et	3	main
talupojad	doc_491521502198_item	3655538	et	4	main
kodukari	doc_491521502198_item	3655532	et	4	main
ilmub	doc_491521502198_item	3655531	et	3	main
ajal	doc_491521502198_item	3655530	et	4	main
rahvas	doc_491521502198_item	3655525	et	4	main
maaaadlikud	doc_491521502198_item	3655523	et	3	main
inimestest	doc_491521502198_item	3655520	et	3	main
pärisorjadeks	doc_491521502198_item	3655507	et	3	main
taheti	doc_491521502198_item	3655503	et	3	main
ja	doc_491521502201_item	3655982	et	3	main
keele	doc_491521502201_item	3655980	et	4	main
eesti	doc_491521502201_item	3655979	et	4	main
üldlaulupidu	doc_491521502201_item	3655973	et	4	main
tema	doc_491521502201_item	3655968	et	4	main
eest	doc_491521502201_item	3655967	et	4	main
saatmise	doc_491521502201_item	3655966	et	4	main
ja	doc_491521502201_item	3655954	et	3	main
välja	doc_491521502201_item	3655951	et	4	main
oli	doc_491521502201_item	3655941	et	3	main
kogutud	doc_491521502201_item	3655933	et	4	main
liikmete	doc_491521502201_item	3655931	et	3	main
kreutzwald	doc_491521502201_item	3655918	et	4	main
muid	doc_491521502201_item	3655907	et	4	main
ja	doc_491521502201_item	3655906	et	3	main
uurimisega	doc_491521502201_item	3655896	et	4	main
keele	doc_491521502201_item	3655895	et	4	main
eesti	doc_491521502201_item	3655894	et	4	main
tegeles	doc_491521502201_item	3655893	et	3	main
selts	doc_491521502201_item	3655892	et	3	main
eesti	doc_491521502201_item	3655891	et	4	main
õpetatud	doc_491521502201_item	3655890	et	4	main
faehlmann	doc_491521502201_item	3655889	et	4	main
r	doc_491521502201_item	3655888	et	4	main
f	doc_491521502201_item	3655887	et	4	main
oli	doc_491521502201_item	3655886	et	3	main
tegelaseks	doc_491521502201_item	3655885	et	3	main
tähtsamaks	doc_491521502201_item	3655884	et	4	main
aastal	doc_491521502201_item	3655883	et	3	main
1839	doc_491521502201_item	3655882	et	2	main
tartus	doc_491521502201_item	3655881	et	3	main
loodud	doc_491521502201_item	3655880	et	4	main
oli	doc_491521502201_item	3655879	et	3	main
selts	doc_491521502201_item	3655878	et	3	main
eesti	doc_491521502201_item	3655877	et	4	main
õpetatud	doc_491521502201_item	3655876	et	4	main
seltsi	doc_491521502201_item	3655975	et	4	main
õpetatud	doc_491521502201_item	3655974	et	4	main
oli	doc_491521502201_item	3655955	et	3	main
liideriks	doc_491521502201_item	3655948	et	4	main
keeleteadlane	doc_491521502201_item	3655943	et	3	main
faehlmann	doc_491521502201_item	3655923	et	4	main
liider	doc_491521502201_item	3655922	et	3	main
trükimisi	doc_491521502201_item	3655899	et	4	main
eestikeelseid	doc_491521502201_item	3655898	et	3	main
korraldas	doc_491521502201_item	3655897	et	3	main
ellu	doc_491521502201_item	3655873	et	4	main
ning	doc_491521502201_item	3655870	et	3	main
kartsid	doc_491521502201_item	3655855	et	4	main
see	doc_491521502201_item	3655832	et	3	main
võib	doc_491521502201_item	3655829	et	3	main
oli	doc_491521502201_item	3655827	et	3	main
balti	doc_491521502201_item	3655823	et	3	main
kuid	doc_491521502201_item	3655809	et	4	main
talupojad	doc_491521502201_item	3655806	et	4	main
täielikuks	doc_491521502201_item	3655803	et	3	main
mõisniku	doc_491521502201_item	3655802	et	3	main
pärisorjus	doc_491521502201_item	3655792	et	3	main
tähendab	doc_491521502201_item	3655767	et	3	main
kes	doc_491521502201_item	3655761	et	4	main
ja	doc_491521502201_item	3655760	et	3	main
selts	doc_491521502201_item	3655759	et	3	main
eesti	doc_491521502201_item	3655758	et	4	main
õpetatud	doc_491521502204_item	3656116	et	4	main
samuti	doc_491521502204_item	3656101	et	3	main
tööd	doc_491521502204_item	3656094	et	4	main
faehlmann	doc_491521502204_item	3656092	et	4	main
suunas	doc_491521502204_item	3656091	et	4	main
eesti	doc_491521502204_item	3656073	et	4	main
tegeles	doc_491521502204_item	3656072	et	3	main
selts	doc_491521502204_item	3656071	et	3	main
surmani	doc_491521502204_item	3656070	et	3	main
kuni	doc_491521502204_item	3656069	et	3	main
faehlmann	doc_491521502204_item	3656064	et	4	main
asutatud	doc_491521502204_item	3656055	et	4	main
oli	doc_491521502204_item	3656054	et	3	main
tartus	doc_491521502204_item	3656053	et	3	main
aastal	doc_491521502204_item	3656052	et	3	main
2	doc_491521502204_item	3656050	et	2	main
ümber	doc_491521502204_item	3656046	et	3	main
omavalitsust	doc_491521502204_item	3656044	et	3	main
aadli	doc_491521502204_item	3656043	et	3	main
säilis	doc_491521502204_item	3656039	et	4	main
eestis	doc_491521502204_item	3656004	et	3	main
kes	doc_491521502204_item	3655998	et	4	main
ja	doc_491521502204_item	3655997	et	3	main
eesti	doc_491521502204_item	3655995	et	4	main
millega	doc_491521502204_item	3655992	et	3	main
erikord	doc_491521502204_item	3655990	et	3	main
i	doc_491521502201_item	3655972	et	4	main
palvekirju	doc_491521502201_item	3655965	et	4	main
postipapa	doc_491521502201_item	3655958	et	4	main
nagu	doc_491521502201_item	3655957	et	3	main
tuntud	doc_491521502201_item	3655956	et	4	main
ajalehte	doc_491521502201_item	3655952	et	4	main
andis	doc_491521502201_item	3655950	et	3	main
jannsen	doc_491521502201_item	3655949	et	4	main
hurt	doc_491521502201_item	3655940	et	3	main
kreutzwald	doc_491521502201_item	3655938	et	4	main
materjale	doc_491521502201_item	3655934	et	3	main
poolt	doc_491521502201_item	3655932	et	4	main
jannsen	doc_491521502201_item	3655920	et	4	main
ja	doc_491521502201_item	3655919	et	3	main
viima	doc_491521502201_item	3655874	et	3	main
venestuspoliitikat	doc_491521502201_item	3655872	et	3	main
ei	doc_491521502201_item	3655865	et	4	main
aleksander	doc_491521502201_item	3655863	et	4	main
ei	doc_491521502201_item	3655845	et	4	main
nad	doc_491521502201_item	3655844	et	3	main
saksastuks	doc_491521502201_item	3655843	et	3	main
talurahvas	doc_491521502201_item	3655842	et	4	main
et	doc_491521502201_item	3655841	et	3	main
sest	doc_491521502201_item	3655836	et	4	main
eesti	doc_491521502201_item	3655834	et	4	main
öelda	doc_491521502201_item	3655830	et	4	main
saksakeelne	doc_491521502201_item	3655828	et	3	main
isegi	doc_491521502201_item	3655819	et	4	main
jäid	doc_491521502201_item	3655811	et	4	main
omandiks	doc_491521502201_item	3655804	et	3	main
oli	doc_491521502201_item	3655801	et	3	main
eestis	doc_491521502201_item	3655797	et	3	main
kadunud	doc_491521502201_item	3655795	et	4	main
oli	doc_491521502201_item	3655793	et	3	main
ja	doc_491521502201_item	3655791	et	3	main
kord	doc_491521502201_item	3655790	et	4	main
oli	doc_491521502201_item	3655783	et	3	main
elas	doc_491521502201_item	3655775	et	3	main
erikord	doc_491521502201_item	3655766	et	3	main
kuulusid	doc_491521502201_item	3655763	et	4	main
eesti	doc_491521502204_item	3656117	et	4	main
ka	doc_491521502204_item	3656111	et	3	main
sinna	doc_491521502204_item	3656109	et	3	main
selles	doc_491521502204_item	3656090	et	4	main
ões	doc_491521502204_item	3656067	et	4	main
õli	doc_491521502204_item	3656066	et	4	main
r	doc_491521502204_item	3656063	et	4	main
fr	doc_491521502204_item	3656062	et	4	main
sai	doc_491521502204_item	3656061	et	4	main
1838	doc_491521502204_item	3656051	et	2	main
kuulusid	doc_491521502204_item	3656000	et	4	main
sinna	doc_491521502204_item	3655999	et	3	main
balti	doc_491521502204_item	3655989	et	3	main
mida	doc_491521502204_item	3655987	et	4	main
teda	doc_491521502207_item	3656182	et	4	main
pandi	doc_491521502207_item	3656180	et	4	main
alla	doc_491521502207_item	3656178	et	3	main
on	doc_491521502207_item	3656170	et	4	main
inimesi	doc_491521502207_item	3656163	et	4	main
on	doc_491521502207_item	3656148	et	4	main
inimesed	doc_491521502207_item	3656147	et	3	main
ajal	doc_491521502207_item	3656146	et	4	main
põletusmatused	doc_491521502207_item	3656144	et	3	main
pealt	doc_491521502207_item	3656133	et	4	main
kõige	doc_491521502207_item	3656132	et	4	main
1	doc_491521502207_item	3656131	et	2	main
alepõllundus	doc_491521502207_item	3656130	et	3	main
kontrolltöö	doc_491521502207_item	3656122	et	4	main
hirss	doc_491521502207_item	3656281	et	3	main
kanep	doc_491521502207_item	3656280	et	3	main
vilja	doc_491521502207_item	3656276	et	4	main
sai	doc_491521502207_item	3656274	et	4	main
põlludel	doc_491521502207_item	3656273	et	4	main
maa	doc_491521502207_item	3656262	et	4	main
see	doc_491521502207_item	3656261	et	3	main
põletati	doc_491521502207_item	3656260	et	3	main
on	doc_491521502207_item	3656248	et	4	main
moodi	doc_491521502207_item	3656243	et	4	main
sümbol	doc_491521502207_item	3656205	et	3	main
sümbol	doc_491521502207_item	3656203	et	3	main
parandab	doc_491521502207_item	3656197	et	3	main
et	doc_491521502207_item	3656195	et	3	main
olnud	doc_491521502201_item	3655866	et	4	main
mõisnikud	doc_491521502201_item	3655854	et	3	main
talurahvas	doc_491521502201_item	3655851	et	4	main
sellepärast	doc_491521502201_item	3655850	et	3	main
ning	doc_491521502201_item	3655849	et	3	main
õppida	doc_491521502201_item	3655848	et	3	main
ei	doc_491521502201_item	3655839	et	4	main
päästis	doc_491521502201_item	3655833	et	3	main
ajal	doc_491521502201_item	3655825	et	4	main
erikorra	doc_491521502201_item	3655824	et	3	main
võis	doc_491521502201_item	3655818	et	4	main
ta	doc_491521502201_item	3655817	et	4	main
õigus	doc_491521502201_item	3655816	et	4	main
siiski	doc_491521502201_item	3655810	et	4	main
olid	doc_491521502201_item	3655807	et	4	main
mõned	doc_491521502201_item	3655805	et	3	main
talupoeg	doc_491521502201_item	3655800	et	3	main
valitses	doc_491521502201_item	3655787	et	3	main
aadlikke	doc_491521502201_item	3655781	et	3	main
võimu	doc_491521502201_item	3655773	et	4	main
aadlike	doc_491521502201_item	3655772	et	4	main
rootsi	doc_491521502201_item	3655771	et	4	main
ja	doc_491521502201_item	3655770	et	3	main
1	doc_491521502201_item	3655764	et	2	main
sinna	doc_491521502201_item	3655762	et	3	main
õpetatud	doc_491521502201_item	3655757	et	4	main
tegeles	doc_491521502201_item	3655756	et	3	main
millega	doc_491521502201_item	3655755	et	3	main
2	doc_491521502201_item	3655754	et	2	main
erikord	doc_491521502201_item	3655753	et	3	main
balti	doc_491521502201_item	3655752	et	3	main
tähendab	doc_491521502201_item	3655751	et	3	main
rolli	doc_491521502204_item	3656120	et	4	main
edendas	doc_491521502204_item	3656115	et	3	main
ärkamisajal	doc_491521502204_item	3656114	et	3	main
ajaloost	doc_491521502204_item	3656108	et	4	main
eesti	doc_491521502204_item	3656107	et	4	main
õe	doc_491521502204_item	3656102	et	4	main
tema	doc_491521502204_item	3656093	et	4	main
selle	doc_491521502204_item	3656081	et	4	main
säilitamisega	doc_491521502204_item	3656079	et	4	main
arenemisega	doc_491521502204_item	3656077	et	4	main
tegelaseks	doc_491521502204_item	3656060	et	3	main
tähtsamaks	doc_491521502204_item	3656059	et	4	main
selts	doc_491521502204_item	3656058	et	3	main
eeskujul	doc_491521502204_item	3656049	et	3	main
vene	doc_491521502204_item	3656047	et	4	main
kui	doc_491521502204_item	3656042	et	3	main
selts	doc_491521502204_item	3655996	et	3	main
õpetatud	doc_491521502204_item	3655994	et	4	main
tegeles	doc_491521502204_item	3655993	et	3	main
2	doc_491521502204_item	3655991	et	2	main
tähendab	doc_491521502204_item	3655988	et	3	main
1	doc_491521502204_item	3655986	et	2	main
kontrolltöö	doc_491521502204_item	3655985	et	4	main
jäänud	doc_491521502207_item	3656186	et	4	main
kivikalmed	doc_491521502207_item	3656169	et	3	main
kivikalmedesse	doc_491521502207_item	3656168	et	4	main
maeti	doc_491521502207_item	3656162	et	3	main
on	doc_491521502207_item	3656153	et	4	main
herneid	doc_491521502207_item	3656152	et	3	main
ube	doc_491521502207_item	3656150	et	3	main
ohverdanud	doc_491521502207_item	3656149	et	4	main
tuli	doc_491521502207_item	3656143	et	4	main
rääkida	doc_491521502207_item	3656140	et	3	main
ei	doc_491521502207_item	3656138	et	4	main
nendest	doc_491521502207_item	3656137	et	4	main
inimesi	doc_491521502207_item	3656136	et	4	main
2	doc_491521502207_item	3656127	et	2	main
oder	doc_491521502207_item	3656277	et	3	main
kasvatada	doc_491521502207_item	3656275	et	3	main
nende	doc_491521502207_item	3656272	et	4	main
alepõllundus	doc_491521502207_item	3656271	et	3	main
2	doc_491521502207_item	3656254	et	2	main
maagiasse	doc_491521502207_item	3656253	et	4	main
usk	doc_491521502207_item	3656252	et	3	main
oli	doc_491521502207_item	3656251	et	3	main
mõnedel	doc_491521502207_item	3656250	et	3	main
hing	doc_491521502207_item	3656249	et	3	main
et	doc_491521502207_item	3656246	et	3	main
nemad	doc_491521502207_item	3656245	et	3	main
elab	doc_491521502207_item	3656241	et	3	main
näha	doc_491521502207_item	3656214	et	3	main
võib	doc_491521502207_item	3656213	et	3	main
kalmistul	doc_491521502207_item	3656212	et	3	main
sellest	doc_491521502207_item	3656206	et	4	main
keele	doc_491521502201_item	3655835	et	4	main
tappa	doc_491521502201_item	3655820	et	4	main
kodukari	doc_491521502201_item	3655815	et	4	main
oli	doc_491521502201_item	3655814	et	3	main
mõisnikul	doc_491521502201_item	3655813	et	3	main
pärisorjadeks	doc_491521502201_item	3655812	et	3	main
tugevnes	doc_491521502201_item	3655799	et	3	main
aga	doc_491521502201_item	3655796	et	3	main
ammu	doc_491521502201_item	3655794	et	4	main
juba	doc_491521502201_item	3655788	et	3	main
pärisori	doc_491521502201_item	3655785	et	4	main
maa	doc_491521502201_item	3655780	et	4	main
i	doc_491521502201_item	3655769	et	4	main
peeter	doc_491521502201_item	3655768	et	3	main
mida	doc_491521502201_item	3655750	et	4	main
tähtsamat	doc_491521502204_item	3656119	et	4	main
jakob	doc_491521502204_item	3656112	et	4	main
huvitatud	doc_491521502204_item	3656106	et	4	main
olid	doc_491521502204_item	3656105	et	4	main
tegelased	doc_491521502204_item	3656104	et	3	main
õhtud	doc_491521502204_item	3656100	et	3	main
nn	doc_491521502204_item	3656098	et	4	main
tegi	doc_491521502204_item	3656089	et	4	main
seltsi	doc_491521502204_item	3656082	et	4	main
esimeheks	doc_491521502204_item	3656068	et	3	main
eesti	doc_491521502204_item	3656057	et	4	main
sisekubermangude	doc_491521502204_item	3656048	et	3	main
1780	doc_491521502204_item	3656040	et	2	main
olukord	doc_491521502204_item	3656038	et	3	main
ja	doc_491521502204_item	3656020	et	3	main
maksustuskord	doc_491521502204_item	3656019	et	4	main
oma	doc_491521502204_item	3656018	et	4	main
asjaajamine	doc_491521502204_item	3656017	et	4	main
saksakeelne	doc_491521502204_item	3656016	et	3	main
säilis	doc_491521502204_item	3656015	et	4	main
sajandil	doc_491521502204_item	3656014	et	3	main
18	doc_491521502204_item	3656013	et	2	main
samuti	doc_491521502204_item	3656012	et	3	main
ajal	doc_491521502204_item	3656011	et	4	main
rootsi	doc_491521502204_item	3656010	et	4	main
oli	doc_491521502204_item	3656009	et	3	main
nagu	doc_491521502204_item	3656008	et	3	main
kubermangudeks	doc_491521502204_item	3656007	et	3	main
haldusjaotus	doc_491521502204_item	3656006	et	4	main
säilis	doc_491521502204_item	3656005	et	4	main
maal	doc_491521502201_item	3655774	et	4	main
balti	doc_491521502201_item	3655765	et	3	main
1	doc_491521502201_item	3655749	et	2	main
kontrolltöö	doc_491521502201_item	3655748	et	4	main
f	doc_491521502201_item	3655916	et	4	main
hurt	doc_491521502201_item	3655915	et	3	main
jakob	doc_491521502201_item	3655914	et	4	main
ka	doc_491521502201_item	3655913	et	3	main
tegutsesid	doc_491521502201_item	3655912	et	4	main
ajal	doc_491521502201_item	3655911	et	4	main
seltsi	doc_491521502201_item	3655910	et	4	main
kirjandust	doc_491521502201_item	3655909	et	3	main
selts	doc_491521502204_item	3656118	et	3	main
hurt	doc_491521502204_item	3656113	et	3	main
kuulus	doc_491521502204_item	3656110	et	4	main
seltsi	doc_491521502204_item	3656103	et	4	main
kalevipoja	doc_491521502204_item	3656099	et	4	main
toimusid	doc_491521502204_item	3656097	et	4	main
kreutzwald	doc_491521502204_item	3656096	et	4	main
lõpetas	doc_491521502204_item	3656095	et	3	main
sammud	doc_491521502204_item	3656088	et	4	main
esimesed	doc_491521502204_item	3656087	et	3	main
kirjutamisega	doc_491521502204_item	3656086	et	4	main
rahvuseepose	doc_491521502204_item	3656085	et	3	main
tegelesid	doc_491521502204_item	3656084	et	4	main
liikmed	doc_491521502204_item	3656083	et	3	main
samuti	doc_491521502204_item	3656080	et	3	main
ja	doc_491521502204_item	3656078	et	3	main
kirjanduse	doc_491521502204_item	3656076	et	3	main
ja	doc_491521502204_item	3656075	et	3	main
keele	doc_491521502204_item	3656074	et	4	main
kes	doc_491521502204_item	3656065	et	4	main
õpetatud	doc_491521502204_item	3656056	et	4	main
korraldati	doc_491521502204_item	3656045	et	3	main
aastateni	doc_491521502204_item	3656041	et	3	main
selline	doc_491521502204_item	3656037	et	4	main
omavalitsussüsteem	doc_491521502204_item	3656036	et	3	main
autonoomne	doc_491521502204_item	3656035	et	3	main
erikord	doc_491521502204_item	3656034	et	3	main
balti	doc_491521502204_item	3656033	et	3	main
oma	doc_491521502204_item	3656032	et	4	main
säilitada	doc_491521502204_item	3656031	et	3	main
õnnestus	doc_491521502204_item	3656030	et	4	main
aadlil	doc_491521502204_item	3656029	et	3	main
baltisaksa	doc_491521502204_item	3656028	et	4	main
kirikul	doc_491521502204_item	3656027	et	3	main
luteri	doc_491521502204_item	3656026	et	3	main
oli	doc_491521502204_item	3656025	et	3	main
koht	doc_491521502204_item	3656024	et	3	main
domineeriv	doc_491521502204_item	3656023	et	4	main
vaimuelus	doc_491521502204_item	3656022	et	4	main
õigussüsteem	doc_491521502204_item	3656021	et	3	main
põhjasõda	doc_491521502204_item	3656003	et	4	main
pärast	doc_491521502204_item	3656002	et	4	main
1	doc_491521502204_item	3656001	et	2	main
kive	doc_491521502207_item	3656183	et	3	main
leitud	doc_491521502207_item	3656171	et	4	main
varandus	doc_491521502207_item	3656160	et	3	main
halvasti	doc_491521502207_item	3656141	et	3	main
tohtinud	doc_491521502207_item	3656139	et	4	main
üldiseloomustus	doc_491521502207_item	3656126	et	4	main
nisu	doc_491521502207_item	3656278	et	4	main
sinna	doc_491521502207_item	3656267	et	3	main
tehti	doc_491521502207_item	3656266	et	3	main
seda	doc_491521502207_item	3656265	et	3	main
peale	doc_491521502207_item	3656264	et	4	main
mets	doc_491521502207_item	3656257	et	3	main
algul	doc_491521502207_item	3656255	et	4	main
õlitaim	doc_491521502207_item	3656284	et	3	main
väärtuslik	doc_491521502207_item	3656283	et	3	main
tuder	doc_491521502207_item	3656282	et	3	main
on	doc_491521502207_item	3656185	et	4	main
ümber	doc_491521502207_item	3656181	et	3	main
maa	doc_491521502207_item	3656177	et	4	main
maetud	doc_491521502207_item	3656176	et	4	main
ka	doc_491521502207_item	3656167	et	3	main
maeti	doc_491521502207_item	3656166	et	3	main
inimesi	doc_491521502207_item	3656165	et	4	main
lõuna-eestis	doc_491521502207_item	3656161	et	3	main
ehted	doc_491521502207_item	3656158	et	3	main
inimesega	doc_491521502207_item	3656157	et	3	main
koos	doc_491521502207_item	3656156	et	4	main
ka	doc_491521502207_item	3656155	et	3	main
maetud	doc_491521502207_item	3656154	et	4	main
siiamaani	doc_491521502207_item	3656184	et	3	main
vaid	doc_491521502207_item	3656179	et	3	main
ei	doc_491521502207_item	3656175	et	4	main
inimest	doc_491521502207_item	3656174	et	3	main
eestis	doc_491521502207_item	3656173	et	3	main
ka	doc_491521502207_item	3656172	et	3	main
liivakääpadesse	doc_491521502207_item	3656164	et	4	main
tööriistad	doc_491521502207_item	3656159	et	3	main
matuste	doc_491521502207_item	3656145	et	3	main
on	doc_491521502207_item	3656129	et	4	main
eestlaste	doc_491521502207_item	3656124	et	4	main
ongi	doc_491521502207_item	3656270	et	4	main
see	doc_491521502207_item	3656269	et	3	main
põld	doc_491521502207_item	3656268	et	3	main
maha	doc_491521502207_item	3656258	et	4	main
rajuti	doc_491521502207_item	3656256	et	4	main
saanud	doc_491521502207_item	3656208	et	4	main
on	doc_491521502207_item	3656207	et	4	main
saanud	doc_491521502207_item	3656201	et	4	main
ristist	doc_491521502207_item	3656199	et	4	main
silmanägemise	doc_491521502207_item	3656198	et	3	main
allikavesi	doc_491521502207_item	3656196	et	4	main
usuti	doc_491521502207_item	3656194	et	3	main
allikavett	doc_491521502207_item	3656192	et	3	main
juuakse	doc_491521502207_item	3656191	et	3	main
varasel	doc_491521502208_item	3656431	et	4	main
inimesed	doc_491521502208_item	3656428	et	3	main
alepõllundusega	doc_491521502208_item	3656427	et	3	main
peale	doc_491521502208_item	3656426	et	4	main
algust	doc_491521502208_item	3656425	et	4	main
alustatakse	doc_491521502208_item	3656424	et	3	main
ning	doc_491521502208_item	3656423	et	3	main
maa	doc_491521502208_item	3656416	et	4	main
kui	doc_491521502208_item	3656415	et	3	main
viljekuks	doc_491521502208_item	3656409	et	4	main
siis	doc_491521502208_item	3656405	et	3	main
2	doc_491521502208_item	3656395	et	2	main
toimus	doc_491521502208_item	3656392	et	3	main
näitabki	doc_491521502208_item	3656389	et	3	main
ja	doc_491521502208_item	3656384	et	3	main
surnute	doc_491521502208_item	3656382	et	4	main
inimesed	doc_491521502208_item	3656378	et	3	main
järgmises	doc_491521502208_item	3656372	et	3	main
peale	doc_491521502208_item	3656364	et	4	main
maeti	doc_491521502208_item	3656362	et	3	main
komme	doc_491521502208_item	3656360	et	4	main
tuule	doc_491521502208_item	3656359	et	3	main
jaani	doc_491521502208_item	3656358	et	4	main
pärineb	doc_491521502208_item	3656357	et	3	main
maagilised	doc_491521502208_item	3656345	et	4	main
rauaajal	doc_491521502208_item	3656344	et	3	main
koos	doc_491521502208_item	3656340	et	4	main
kuna	doc_491521502208_item	3656337	et	3	main
ei	doc_491521502208_item	3656335	et	4	main
hingest	doc_491521502208_item	3656334	et	4	main
mis	doc_491521502208_item	3656307	et	4	main
inimeste	doc_491521502208_item	3656298	et	3	main
neoliitikumi	doc_491521502208_item	3656296	et	4	main
on	doc_491521502208_item	3656293	et	4	main
eestlaste	doc_491521502208_item	3656288	et	4	main
kontrolltöö	doc_491521502208_item	3656286	et	4	main
juures	doc_491521502211_item	3656591	et	4	main
veekogude	doc_491521502211_item	3656590	et	3	main
hobuloomad	doc_491521502211_item	3656576	et	3	main
ja	doc_491521502207_item	3656151	et	3	main
13saj	doc_491521502207_item	3656142	et	4	main
surnuid	doc_491521502207_item	3656135	et	4	main
austati	doc_491521502207_item	3656134	et	3	main
mis	doc_491521502207_item	3656128	et	4	main
muinasusundi	doc_491521502207_item	3656125	et	3	main
1	doc_491521502207_item	3656123	et	2	main
lina	doc_491521502207_item	3656279	et	4	main
ja	doc_491521502207_item	3656263	et	3	main
siis	doc_491521502207_item	3656259	et	3	main
loodusel	doc_491521502207_item	3656247	et	4	main
nagu	doc_491521502207_item	3656244	et	3	main
tänapäeva	doc_491521502207_item	3656211	et	4	main
surmasümbol	doc_491521502207_item	3656210	et	3	main
ka	doc_491521502207_item	3656209	et	3	main
millesegi	doc_491521502207_item	3656188	et	4	main
usk	doc_491521502207_item	3656187	et	3	main
samat	doc_491521502207_item	3656242	et	4	main
loodus	doc_491521502207_item	3656240	et	4	main
et	doc_491521502207_item	3656239	et	3	main
sellesse	doc_491521502207_item	3656238	et	4	main
ka	doc_491521502207_item	3656237	et	3	main
ususid	doc_491521502207_item	3656236	et	4	main
inimesed	doc_491521502207_item	3656235	et	3	main
kohtades	doc_491521502207_item	3656234	et	3	main
teistes	doc_491521502207_item	3656233	et	4	main
inimesed	doc_491521502207_item	3656232	et	3	main
usuvad	doc_491521502207_item	3656231	et	3	main
millesse	doc_491521502207_item	3656230	et	3	main
ja	doc_491521502207_item	3656229	et	3	main
usundist	doc_491521502207_item	3656228	et	3	main
inimestele	doc_491521502207_item	3656227	et	3	main
rääkisid	doc_491521502207_item	3656226	et	4	main
nad	doc_491521502207_item	3656225	et	3	main
rändmungad	doc_491521502207_item	3656224	et	3	main
tulema	doc_491521502207_item	3656223	et	4	main
hakksid	doc_491521502207_item	3656222	et	4	main
lõuna-eestist	doc_491521502207_item	3656221	et	3	main
rist	doc_491521502207_item	3656220	et	3	main
on	doc_491521502207_item	3656219	et	4	main
peal	doc_491521502207_item	3656218	et	4	main
mille	doc_491521502207_item	3656217	et	3	main
haudasi	doc_491521502207_item	3656216	et	3	main
palju	doc_491521502207_item	3656215	et	4	main
kannatuse	doc_491521502207_item	3656204	et	4	main
kiriku	doc_491521502207_item	3656202	et	3	main
puhasvesi	doc_491521502207_item	3656193	et	4	main
kirikus	doc_491521502207_item	3656190	et	3	main
näiteks	doc_491521502207_item	3656189	et	4	main
halvenevad	doc_491521502208_item	3656418	et	4	main
omadused	doc_491521502208_item	3656417	et	4	main
aastate	doc_491521502208_item	3656412	et	3	main
seda	doc_491521502208_item	3656410	et	3	main
saab	doc_491521502208_item	3656408	et	3	main
so	doc_491521502208_item	3656397	et	4	main
et	doc_491521502208_item	3656390	et	3	main
religiooniga	doc_491521502208_item	3656386	et	3	main
jooksul	doc_491521502208_item	3656377	et	4	main
päris	doc_491521502208_item	3656349	et	4	main
juba	doc_491521502208_item	3656348	et	3	main
inimestega	doc_491521502208_item	3656341	et	3	main
selges	doc_491521502208_item	3656332	et	3	main
ning	doc_491521502208_item	3656331	et	3	main
jne	doc_491521502208_item	3656330	et	4	main
ehted	doc_491521502208_item	3656329	et	3	main
loomakujukesed	doc_491521502208_item	3656328	et	4	main
on	doc_491521502207_item	3656200	et	4	main
tegelema	doc_491521502208_item	3656430	et	3	main
hakkasid	doc_491521502208_item	3656429	et	4	main
rajatakse	doc_491521502208_item	3656402	et	4	main
mets	doc_491521502208_item	3656401	et	3	main
areng	doc_491521502208_item	3656394	et	3	main
see	doc_491521502208_item	3656388	et	3	main
huvitama	doc_491521502208_item	3656385	et	3	main
holitsema	doc_491521502208_item	3656381	et	4	main
rohkem	doc_491521502208_item	3656380	et	4	main
aja	doc_491521502208_item	3656376	et	4	main
on	doc_491521502208_item	3656374	et	4	main
on	doc_491521502208_item	3656371	et	4	main
mis	doc_491521502208_item	3656370	et	4	main
esemed	doc_491521502208_item	3656369	et	3	main
mõned	doc_491521502208_item	3656368	et	3	main
ajast	doc_491521502208_item	3656356	et	4	main
vanemal	doc_491521502208_item	3656343	et	4	main
religioon	doc_491521502208_item	3656338	et	3	main
näiteks	doc_491521502208_item	3656326	et	4	main
pani	doc_491521502208_item	3656323	et	4	main
magavas	doc_491521502208_item	3656319	et	4	main
saanud	doc_491521502208_item	3656305	et	4	main
ei	doc_491521502208_item	3656304	et	4	main
nad	doc_491521502208_item	3656303	et	3	main
keeruline	doc_491521502208_item	3656302	et	4	main
oli	doc_491521502208_item	3656301	et	3	main
üldiseloomustus	doc_491521502208_item	3656290	et	4	main
muinasusundi	doc_491521502208_item	3656289	et	3	main
kasvatamisega	doc_491521502211_item	3656586	et	4	main
kuna	doc_491521502211_item	3656575	et	3	main
palju	doc_491521502211_item	3656572	et	4	main
aktiivsed	doc_491521502211_item	3656566	et	3	main
tuleb	doc_491521502211_item	3656549	et	3	main
kaalusüsteem	doc_491521502211_item	3656547	et	3	main
linna	doc_491521502211_item	3656524	et	4	main
suur	doc_491521502211_item	3656514	et	3	main
räägitakse	doc_491521502211_item	3656510	et	3	main
pikemad	doc_491521502211_item	3656507	et	4	main
sõjalisi	doc_491521502211_item	3656500	et	4	main
hõbedat	doc_491521502211_item	3656486	et	3	main
maksti	doc_491521502211_item	3656478	et	3	main
pkr	doc_491521502211_item	3656448	et	4	main
800-1050	doc_491521502211_item	3656447	et	2	main
territooriumil	doc_491521502211_item	3656446	et	3	main
viikingiaeg	doc_491521502211_item	3656436	et	3	main
rauaaja	doc_491521502211_item	3656648	et	3	main
kristluse	doc_491521502211_item	3656646	et	4	main
kuni	doc_491521502211_item	3656645	et	3	main
kestab	doc_491521502211_item	3656644	et	4	main
mis	doc_491521502211_item	3656643	et	4	main
ajavahemik	doc_491521502211_item	3656642	et	3	main
muinasaeg	doc_491521502211_item	3656641	et	3	main
2	doc_491521502211_item	3656640	et	2	main
loomulikult	doc_491521502211_item	3656635	et	4	main
ja	doc_491521502211_item	3656634	et	3	main
üle	doc_491521502211_item	3656626	et	3	main
oli	doc_491521502211_item	3656625	et	3	main
vilja	doc_491521502211_item	3656624	et	4	main
areneda	doc_491521502211_item	3656623	et	3	main
põllumajandust	doc_491521502211_item	3656622	et	3	main
rauaajal	doc_491521502208_item	3656432	et	3	main
ära	doc_491521502208_item	3656422	et	4	main
põletatakse	doc_491521502208_item	3656421	et	3	main
aga	doc_491521502208_item	3656414	et	3	main
jooksul	doc_491521502208_item	3656413	et	4	main
maa	doc_491521502208_item	3656407	et	4	main
kui	doc_491521502208_item	3656406	et	3	main
põletatakse	doc_491521502208_item	3656404	et	3	main
ja	doc_491521502208_item	3656403	et	3	main
millal	doc_491521502208_item	3656400	et	3	main
viis	doc_491521502208_item	3656399	et	4	main
maaharimise	doc_491521502208_item	3656398	et	3	main
vaimne	doc_491521502208_item	3656393	et	3	main
inimestel	doc_491521502208_item	3656391	et	3	main
ning	doc_491521502208_item	3656387	et	3	main
eest	doc_491521502208_item	3656383	et	4	main
hakkasid	doc_491521502208_item	3656379	et	4	main
vajalikud	doc_491521502208_item	3656375	et	3	main
elus	doc_491521502208_item	3656373	et	4	main
anti	doc_491521502208_item	3656366	et	3	main
ning	doc_491521502208_item	3656365	et	3	main
surnuid	doc_491521502208_item	3656361	et	4	main
et	doc_491521502208_item	3656354	et	3	main
olid	doc_491521502208_item	3656347	et	4	main
toimingud	doc_491521502208_item	3656346	et	3	main
areneb	doc_491521502208_item	3656339	et	3	main
tööriistu	doc_491521502208_item	3656327	et	3	main
nn	doc_491521502208_item	3656324	et	4	main
sisse	doc_491521502208_item	3656322	et	4	main
haua	doc_491521502208_item	3656321	et	3	main
alla	doc_491521502208_item	3656318	et	3	main
püstkoja	doc_491521502208_item	3656316	et	3	main
tihti	doc_491521502208_item	3656314	et	3	main
aru	doc_491521502208_item	3656306	et	4	main
uskust	doc_491521502208_item	3656300	et	4	main
mis	doc_491521502208_item	3656292	et	4	main
kõik	doc_491521502208_item	3656420	et	4	main
jälle	doc_491521502208_item	3656419	et	3	main
kasutatakse	doc_491521502208_item	3656411	et	3	main
alepõllundus	doc_491521502208_item	3656396	et	3	main
neile	doc_491521502208_item	3656367	et	4	main
maa	doc_491521502208_item	3656363	et	4	main
sellest	doc_491521502208_item	3656355	et	4	main
arvatakse	doc_491521502208_item	3656353	et	3	main
jaoks	doc_491521502208_item	3656352	et	4	main
inimeste	doc_491521502208_item	3656351	et	3	main
tähtsad	doc_491521502208_item	3656350	et	3	main
siis	doc_491521502208_item	3656342	et	3	main
olnud	doc_491521502208_item	3656336	et	4	main
ettekujutust	doc_491521502208_item	3656333	et	4	main
hauapanuseid	doc_491521502208_item	3656325	et	3	main
asendis	doc_491521502208_item	3656320	et	3	main
territooriumile	doc_491521502208_item	3656313	et	3	main
sängitati	doc_491521502208_item	3656311	et	3	main
surnuid	doc_491521502208_item	3656310	et	4	main
surm	doc_491521502208_item	3656309	et	3	main
on	doc_491521502208_item	3656308	et	4	main
ettekujutus	doc_491521502208_item	3656299	et	4	main
ajal	doc_491521502208_item	3656297	et	4	main
1	doc_491521502208_item	3656295	et	2	main
alepõllundus	doc_491521502208_item	3656294	et	3	main
1	doc_491521502208_item	3656287	et	2	main
saab	doc_491521502211_item	3656594	et	3	main
kus	doc_491521502211_item	3656593	et	3	main
seal	doc_491521502211_item	3656592	et	4	main
elasid	doc_491521502211_item	3656588	et	4	main
koduloomade	doc_491521502211_item	3656585	et	4	main
väga	doc_491521502211_item	3656578	et	3	main
münte	doc_491521502211_item	3656574	et	3	main
suhtes	doc_491521502211_item	3656569	et	4	main
mis	doc_491521502211_item	3656548	et	4	main
kasutusel	doc_491521502211_item	3656546	et	4	main
on	doc_491521502211_item	3656545	et	4	main
järve	doc_491521502211_item	3656538	et	4	main
peipsi	doc_491521502211_item	3656537	et	4	main
sajandil	doc_491521502211_item	3656536	et	3	main
9-10	doc_491521502211_item	3656535	et	2	main
ka	doc_491521502211_item	3656533	et	3	main
vene	doc_491521502211_item	3656529	et	4	main
jurjev	doc_491521502211_item	3656525	et	4	main
sõjakontlikt	doc_491521502211_item	3656515	et	4	main
skandinaavlastega	doc_491521502211_item	3656503	et	3	main
põranda	doc_491521502208_item	3656317	et	3	main
ka	doc_491521502208_item	3656315	et	3	main
asula	doc_491521502208_item	3656312	et	4	main
2	doc_491521502208_item	3656291	et	2	main
inimesed	doc_491521502211_item	3656587	et	3	main
paljud	doc_491521502211_item	3656583	et	3	main
siis	doc_491521502211_item	3656582	et	3	main
kallid	doc_491521502211_item	3656581	et	3	main
ja	doc_491521502211_item	3656580	et	3	main
vajalikud	doc_491521502211_item	3656579	et	3	main
lääne	doc_491521502211_item	3656568	et	4	main
aga	doc_491521502211_item	3656567	et	3	main
ka	doc_491521502211_item	3656550	et	3	main
slavlasttel	doc_491521502211_item	3656544	et	4	main
kroonikas	doc_491521502211_item	3656534	et	3	main
tugipunktiks	doc_491521502211_item	3656530	et	4	main
räägitakse	doc_491521502211_item	3656505	et	3	main
kontlikte	doc_491521502211_item	3656501	et	4	main
palju	doc_491521502211_item	3656499	et	4	main
oli	doc_491521502211_item	3656498	et	3	main
ajal	doc_491521502211_item	3656497	et	4	main
gr	doc_491521502211_item	3656489	et	4	main
maksis	doc_491521502211_item	3656484	et	4	main
hõbega	doc_491521502211_item	3656477	et	4	main
sellele	doc_491521502211_item	3656475	et	4	main
kuuluvad	doc_491521502211_item	3656474	et	4	main
vaht	doc_491521502211_item	3656458	et	3	main
mesi	doc_491521502211_item	3656457	et	4	main
oli	doc_491521502211_item	3656456	et	3	main
toodeks	doc_491521502211_item	3656455	et	3	main
kauplesid	doc_491521502211_item	3656453	et	4	main
kes	doc_491521502211_item	3656452	et	4	main
kaupmehed	doc_491521502211_item	3656451	et	3	main
olid	doc_491521502211_item	3656450	et	4	main
viikingiaeg	doc_491521502211_item	3656443	et	3	main
1	doc_491521502211_item	3656435	et	2	main
lõpuni	doc_491521502211_item	3656649	et	3	main
olid	doc_491521502211_item	3656632	et	4	main
on	doc_491521502212_item	3657020	et	4	main
1	doc_491521502212_item	3657018	et	2	main
kaalu	doc_491521502212_item	3657016	et	4	main
kasutusele	doc_491521502212_item	3657014	et	4	main
maakundade	doc_491521502212_item	3657004	et	4	main
on	doc_491521502212_item	3656993	et	4	main
et	doc_491521502212_item	3656991	et	3	main
uskusid	doc_491521502212_item	3656990	et	4	main
kalmed	doc_491521502212_item	3656988	et	3	main
olid	doc_491521502212_item	3656987	et	4	main
sellest	doc_491521502212_item	3656969	et	4	main
potikedrad	doc_491521502212_item	3656962	et	3	main
maksu	doc_491521502212_item	3656937	et	4	main
tark	doc_491521502212_item	3656927	et	3	main
tartu	doc_491521502212_item	3656923	et	4	main
pronksi	doc_491521502211_item	3656601	et	4	main
juba	doc_491521502211_item	3656600	et	3	main
oskasid	doc_491521502211_item	3656599	et	4	main
heina	doc_491521502211_item	3656597	et	4	main
inimesed	doc_491521502211_item	3656598	et	3	main
head	doc_491521502211_item	3656596	et	4	main
palju	doc_491521502211_item	3656595	et	4	main
rohkem	doc_491521502211_item	3656589	et	4	main
tegelesid	doc_491521502211_item	3656584	et	4	main
olid	doc_491521502211_item	3656577	et	4	main
sõjaliselt	doc_491521502211_item	3656565	et	4	main
ka	doc_491521502211_item	3656564	et	3	main
olid	doc_491521502211_item	3656563	et	4	main
ise	doc_491521502211_item	3656562	et	4	main
eestlased	doc_491521502211_item	3656561	et	3	main
kaal	doc_491521502211_item	3656560	et	3	main
besmen	doc_491521502211_item	3656559	et	4	main
nt	doc_491521502211_item	3656558	et	4	main
sõnad	doc_491521502211_item	3656557	et	4	main
mõned	doc_491521502211_item	3656556	et	3	main
ka	doc_491521502211_item	3656555	et	3	main
tulevad	doc_491521502211_item	3656554	et	4	main
sellest	doc_491521502211_item	3656553	et	4	main
territooriumi	doc_491521502211_item	3656552	et	4	main
araabia	doc_491521502211_item	3656573	et	4	main
leitud	doc_491521502211_item	3656571	et	4	main
on	doc_491521502211_item	3656570	et	4	main
eesti	doc_491521502211_item	3656551	et	4	main
kirjutatakse	doc_491521502211_item	3656532	et	3	main
rajab	doc_491521502211_item	3656523	et	3	main
tark	doc_491521502211_item	3656522	et	3	main
jaroslav	doc_491521502211_item	3656521	et	4	main
ajal	doc_491521502211_item	3656520	et	4	main
esimene	doc_491521502211_item	3656513	et	3	main
tähtsadest	doc_491521502211_item	3656511	et	4	main
kus	doc_491521502211_item	3656509	et	3	main
200	doc_491521502211_item	3656488	et	2	main
250-300gr	doc_491521502211_item	3656485	et	4	main
hobune	doc_491521502211_item	3656483	et	4	main
nt	doc_491521502211_item	3656482	et	4	main
ajale	doc_491521502211_item	3656476	et	3	main
tähendus	doc_491521502211_item	3656442	et	4	main
muinasaeg	doc_491521502211_item	3656441	et	3	main
mõiste	doc_491521502211_item	3656440	et	4	main
2	doc_491521502211_item	3656439	et	2	main
territooriumil	doc_491521502211_item	3656438	et	3	main
oma	doc_491521502211_item	3656638	et	4	main
kaitsta	doc_491521502211_item	3656637	et	4	main
inimesed	doc_491521502211_item	3656631	et	3	main
müüdi	doc_491521502211_item	3656630	et	4	main
seda	doc_491521502211_item	3656629	et	3	main
aitasid	doc_491521502211_item	3656620	et	4	main
oder	doc_491521502211_item	3656617	et	3	main
kirves	doc_491521502211_item	3656616	et	4	main
sirp	doc_491521502211_item	3656615	et	3	main
nt	doc_491521502211_item	3656614	et	4	main
teraga	doc_491521502211_item	3656613	et	3	main
tugev	doc_491521502211_item	3656612	et	4	main
paremad	doc_491521502211_item	3656611	et	4	main
juba	doc_491521502211_item	3656610	et	3	main
olid	doc_491521502211_item	3656609	et	4	main
tööriistad	doc_491521502211_item	3656608	et	3	main
seetõttu	doc_491521502211_item	3656607	et	3	main
suulata	doc_491521502211_item	3656606	et	4	main
ja	doc_491521502211_item	3656605	et	3	main
töödelda	doc_491521502211_item	3656604	et	4	main
metalli	doc_491521502211_item	3656603	et	4	main
ja	doc_491521502211_item	3656602	et	3	main
irboska	doc_491521502211_item	3656543	et	4	main
asulad	doc_491521502211_item	3656542	et	3	main
slaavi	doc_491521502211_item	3656541	et	3	main
tekivad	doc_491521502211_item	3656540	et	3	main
ääres	doc_491521502211_item	3656539	et	4	main
millest	doc_491521502211_item	3656531	et	3	main
esimeseks	doc_491521502211_item	3656528	et	3	main
sai	doc_491521502211_item	3656527	et	4	main
see	doc_491521502211_item	3656526	et	3	main
sellel	doc_491521502211_item	3656519	et	4	main
aastal	doc_491521502211_item	3656518	et	3	main
1030	doc_491521502211_item	3656517	et	2	main
oli	doc_491521502211_item	3656516	et	3	main
ajaloosündusdest	doc_491521502211_item	3656512	et	4	main
lugulaulud	doc_491521502211_item	3656508	et	3	main
saagades	doc_491521502211_item	3656506	et	3	main
sellest	doc_491521502211_item	3656504	et	4	main
eriti	doc_491521502211_item	3656502	et	3	main
sellel	doc_491521502211_item	3656496	et	4	main
hõbedat	doc_491521502211_item	3656495	et	3	main
gr	doc_491521502211_item	3656494	et	4	main
orjatar	doc_491521502211_item	3656487	et	3	main
vikingid	doc_491521502211_item	3656449	et	4	main
eesti	doc_491521502211_item	3656437	et	4	main
kontrolltöö	doc_491521502211_item	3656434	et	4	main
tulekut	doc_491521502211_item	3656647	et	3	main
tahtsid	doc_491521502211_item	3656636	et	4	main
pärast	doc_491521502211_item	3656628	et	4	main
mille	doc_491521502211_item	3656627	et	3	main
tööriistad	doc_491521502211_item	3656619	et	3	main
eesti	doc_491521502212_item	3657030	et	4	main
leitud	doc_491521502212_item	3657021	et	4	main
süsteem	doc_491521502212_item	3657017	et	3	main
eriline	doc_491521502212_item	3656994	et	4	main
juba	doc_491521502212_item	3656986	et	3	main
jne	doc_491521502212_item	3656975	et	4	main
ja	doc_491521502212_item	3656974	et	3	main
sõjadest	doc_491521502212_item	3656973	et	4	main
toimus	doc_491521502212_item	3656972	et	3	main
300	doc_491521502211_item	3656493	et	2	main
org	doc_491521502211_item	3656492	et	3	main
aga	doc_491521502211_item	3656491	et	3	main
h	doc_491521502211_item	3656490	et	4	main
eest	doc_491521502211_item	3656481	et	4	main
toodete	doc_491521502211_item	3656480	et	3	main
kõige	doc_491521502211_item	3656479	et	4	main
mis	doc_491521502211_item	3656473	et	4	main
münte	doc_491521502211_item	3656472	et	3	main
hõbe	doc_491521502211_item	3656471	et	3	main
leitud	doc_491521502211_item	3656470	et	4	main
on	doc_491521502211_item	3656469	et	4	main
territooriumil	doc_491521502211_item	3656468	et	3	main
eesti	doc_491521502211_item	3656467	et	4	main
hõbe	doc_491521502211_item	3656466	et	3	main
oli	doc_491521502211_item	3656465	et	3	main
metall	doc_491521502211_item	3656464	et	3	main
väärtuslikum	doc_491521502211_item	3656463	et	4	main
kõige	doc_491521502211_item	3656462	et	4	main
koduloomad	doc_491521502211_item	3656461	et	3	main
ehted	doc_491521502211_item	3656460	et	3	main
orjed	doc_491521502211_item	3656459	et	4	main
eestlastega	doc_491521502211_item	3656454	et	4	main
eesti	doc_491521502211_item	3656445	et	4	main
oli	doc_491521502211_item	3656444	et	3	main
varat	doc_491521502211_item	3656639	et	4	main
rikkamad	doc_491521502211_item	3656633	et	4	main
ka	doc_491521502211_item	3656621	et	3	main
need	doc_491521502211_item	3656618	et	3	main
võõramaiseid	doc_491521502212_item	3657023	et	4	main
seotud	doc_491521502212_item	3657008	et	4	main
oli	doc_491521502212_item	3657007	et	3	main
see	doc_491521502212_item	3657006	et	3	main
tekkisid	doc_491521502212_item	3657002	et	4	main
ja	doc_491521502212_item	3657000	et	3	main
matused	doc_491521502212_item	3656985	et	3	main
inimese	doc_491521502212_item	3656984	et	4	main
levis	doc_491521502212_item	3656978	et	4	main
saagid	doc_491521502212_item	3656965	et	3	main
hakkasid	doc_491521502212_item	3656963	et	4	main
toodi	doc_491521502212_item	3656961	et	4	main
neile	doc_491521502212_item	3656935	et	4	main
asukaid	doc_491521502212_item	3656934	et	4	main
et	doc_491521502212_item	3656932	et	3	main
tahtsid	doc_491521502212_item	3656931	et	4	main
slaavlased	doc_491521502212_item	3656930	et	3	main
jaroslav	doc_491521502212_item	3656926	et	4	main
hakkasid	doc_491521502212_item	3656917	et	4	main
kujunevad	doc_491521502212_item	3656898	et	4	main
koduloomi	doc_491521502212_item	3656880	et	4	main
kõige	doc_491521502212_item	3656876	et	4	main
kõige	doc_491521502212_item	3656865	et	4	main
tol	doc_491521502212_item	3656863	et	3	main
1	doc_491521502212_item	3656849	et	2	main
läbi	doc_491521502212_item	3657029	et	4	main
palju	doc_491521502212_item	3657022	et	4	main
eestis	doc_491521502212_item	3657019	et	3	main
uus	doc_491521502212_item	3657015	et	3	main
tuli	doc_491521502212_item	3657013	et	4	main
kliimaga	doc_491521502212_item	3657012	et	3	main
ja	doc_491521502212_item	3657011	et	3	main
loodesega	doc_491521502212_item	3657010	et	4	main
ka	doc_491521502212_item	3657009	et	3	main
praeguste	doc_491521502212_item	3657003	et	3	main
allikad	doc_491521502212_item	3656999	et	3	main
loodusel	doc_491521502212_item	3656992	et	4	main
inimesed	doc_491521502212_item	3656989	et	3	main
ajal	doc_491521502212_item	3656977	et	4	main
hiljemal	doc_491521502212_item	3656976	et	4	main
jutustati	doc_491521502212_item	3656968	et	3	main
ilmselt	doc_491521502212_item	3656940	et	4	main
mis	doc_491521502212_item	3656939	et	4	main
maksaksid	doc_491521502212_item	3656938	et	4	main
jurjevi	doc_491521502212_item	3656929	et	4	main
tänapäevase	doc_491521502212_item	3656922	et	4	main
ka	doc_491521502212_item	3656920	et	3	main
müüdi	doc_491521502212_item	3656888	et	4	main
toimub	doc_491521502212_item	3656885	et	3	main
hobune	doc_491521502212_item	3656879	et	4	main
oli	doc_491521502212_item	3656878	et	3	main
viikingiaeg	doc_491521502212_item	3656850	et	3	main
pronksiaeg	doc_491521502212_item	3657044	et	3	main
kiviaeg	doc_491521502212_item	3657043	et	3	main
areng	doc_491521502212_item	3657042	et	3	main
algne	doc_491521502212_item	3657041	et	3	main
inimese	doc_491521502212_item	3657040	et	4	main
ekr	doc_491521502212_item	3657039	et	4	main
mis	doc_491521502212_item	3657037	et	4	main
oli	doc_491521502212_item	3657038	et	3	main
kõik	doc_491521502212_item	3657036	et	4	main
muinasaeg	doc_491521502212_item	3657035	et	3	main
2	doc_491521502212_item	3657034	et	2	main
kaubateed	doc_491521502212_item	3657033	et	4	main
paljud	doc_491521502212_item	3657032	et	3	main
läksid	doc_491521502212_item	3657031	et	4	main
et	doc_491521502212_item	3657028	et	3	main
öölda	doc_491521502212_item	3657027	et	4	main
võib	doc_491521502212_item	3657026	et	3	main
seetõttu	doc_491521502212_item	3657025	et	3	main
münte	doc_491521502212_item	3657024	et	3	main
piirid	doc_491521502212_item	3657005	et	3	main
jne	doc_491521502212_item	3657001	et	4	main
puud	doc_491521502212_item	3656998	et	4	main
pühad	doc_491521502212_item	3656997	et	3	main
olid	doc_491521502212_item	3656996	et	4	main
võim	doc_491521502212_item	3656995	et	3	main
said	doc_491521502212_item	3656983	et	4	main
tähtsaksedeks	doc_491521502212_item	3656982	et	4	main
väga	doc_491521502212_item	3656981	et	3	main
sõnaraamat	doc_491521502212_item	3656980	et	3	main
ka	doc_491521502212_item	3656979	et	3	main
kus	doc_491521502212_item	3656967	et	3	main
levima	doc_491521502212_item	3656964	et	3	main
ader	doc_491521502212_item	3656959	et	3	main
saagid	doc_491521502212_item	3656958	et	3	main
kirved	doc_491521502212_item	3656957	et	3	main
mugavamad	doc_491521502212_item	3656956	et	4	main
ja	doc_491521502212_item	3656955	et	3	main
paremad	doc_491521502212_item	3656954	et	4	main
juba	doc_491521502212_item	3656953	et	3	main
olid	doc_491521502212_item	3656952	et	4	main
tööriistad	doc_491521502212_item	3656951	et	3	main
põllumajandusega	doc_491521502212_item	3656950	et	3	main
ja	doc_491521502212_item	3656949	et	3	main
käsitööga	doc_491521502212_item	3656948	et	3	main
palju	doc_491521502212_item	3656947	et	4	main
tegelesid	doc_491521502212_item	3656946	et	4	main
meeldinud	doc_491521502212_item	3656942	et	4	main
ümber	doc_491521502212_item	3656971	et	3	main
mis	doc_491521502212_item	3656970	et	4	main
laulud	doc_491521502212_item	3656966	et	3	main
siia	doc_491521502212_item	3656960	et	4	main
ka	doc_491521502212_item	3656936	et	3	main
nad	doc_491521502212_item	3656928	et	3	main
ajaga	doc_491521502212_item	3656916	et	3	main
slaavi	doc_491521502212_item	3656914	et	3	main
peipsi	doc_491521502212_item	3656912	et	4	main
konflikte	doc_491521502212_item	3656909	et	3	main
maa	doc_491521502212_item	3656900	et	4	main
orje	doc_491521502212_item	3656891	et	3	main
intensiivne	doc_491521502212_item	3656886	et	3	main
rohkem	doc_491521502212_item	3656884	et	4	main
palju	doc_491521502212_item	3656883	et	4	main
kallim	doc_491521502212_item	3656877	et	4	main
asjade	doc_491521502212_item	3656874	et	3	main
loomade	doc_491521502212_item	3656872	et	4	main
hõbedas	doc_491521502212_item	3656870	et	3	main
metall	doc_491521502212_item	3656867	et	3	main
mõiste	doc_491521502212_item	3656854	et	4	main
territooriumil	doc_491521502212_item	3656852	et	3	main
inimesed	doc_491521502212_item	3656945	et	3	main
kohaliku	doc_491521502212_item	3656943	et	3	main
ei	doc_491521502212_item	3656941	et	4	main
siinseid	doc_491521502212_item	3656933	et	3	main
asutasid	doc_491521502212_item	3656925	et	4	main
kohapeal	doc_491521502212_item	3656924	et	3	main
konflikte	doc_491521502212_item	3656921	et	3	main
slaavlastega	doc_491521502212_item	3656918	et	3	main
ääres	doc_491521502212_item	3656913	et	4	main
tekkis	doc_491521502212_item	3656911	et	3	main
9-10s	doc_491521502212_item	3656910	et	3	main
sõjalisi	doc_491521502212_item	3656908	et	4	main
röövimisi	doc_491521502212_item	3656907	et	4	main
palju	doc_491521502212_item	3656906	et	4	main
ka	doc_491521502212_item	3656905	et	3	main
oli	doc_491521502212_item	3656904	et	3	main
aga	doc_491521502212_item	3656903	et	3	main
pärandama	doc_491521502212_item	3656902	et	3	main
hakkatakse	doc_491521502212_item	3656901	et	4	main
tekkima	doc_491521502212_item	3656919	et	3	main
asustus	doc_491521502212_item	3656915	et	4	main
1	doc_491521502212_item	3656897	et	2	main
saada	doc_491521502212_item	3656895	et	4	main
oli	doc_491521502212_item	3656892	et	3	main
mett	doc_491521502212_item	3656890	et	4	main
karusnahku	doc_491521502212_item	3656889	et	3	main
kasutati	doc_491521502212_item	3656882	et	4	main
juba	doc_491521502212_item	3656881	et	3	main
hinde	doc_491521502212_item	3656875	et	4	main
ja	doc_491521502212_item	3656873	et	3	main
arvutati	doc_491521502212_item	3656871	et	4	main
tähendus	doc_491521502212_item	3656856	et	4	main
muinasaeg	doc_491521502212_item	3656855	et	3	main
2	doc_491521502212_item	3656853	et	2	main
jõudu	doc_491521502215_item	3657726	et	4	main
kasutama	doc_491521502215_item	3657724	et	3	main
tekkima	doc_491521502215_item	3657719	et	3	main
lähimatele	doc_491521502215_item	3657714	et	4	main
käsitöö	doc_491521502215_item	3657708	et	4	main
inimesed	doc_491521502215_item	3657702	et	3	main
majanduslik	doc_491521502215_item	3657695	et	3	main
vikat	doc_491521502215_item	3657693	et	3	main
maaharimisega	doc_491521502215_item	3657685	et	3	main
sõna	doc_491521502215_item	3657674	et	4	main
kasutama	doc_491521502215_item	3657673	et	3	main
hakkati	doc_491521502215_item	3657672	et	3	main
rikkam	doc_491521502215_item	3657671	et	4	main
oma	doc_491521502215_item	3657666	et	4	main
hakkavad	doc_491521502215_item	3657659	et	4	main
pidasid	doc_491521502215_item	3657651	et	4	main
rootslased	doc_491521502215_item	3657650	et	3	main
hoolitsesid	doc_491521502215_item	3657628	et	4	main
ümber	doc_491521502215_item	3657626	et	3	main
kividega	doc_491521502215_item	3657625	et	3	main
pandi	doc_491521502215_item	3657624	et	4	main
inimesi	doc_491521502215_item	3657618	et	4	main
mõisad	doc_491521502212_item	3656899	et	3	main
välismaariideid	doc_491521502212_item	3656896	et	3	main
võimalik	doc_491521502212_item	3656894	et	3	main
juba	doc_491521502212_item	3656893	et	3	main
kauplemine	doc_491521502212_item	3656887	et	4	main
hõbe	doc_491521502212_item	3656869	et	3	main
oli	doc_491521502212_item	3656868	et	3	main
väärtuslikum	doc_491521502212_item	3656866	et	4	main
ajal	doc_491521502212_item	3656864	et	4	main
retked	doc_491521502212_item	3656862	et	3	main
skandinaavia	doc_491521502212_item	3656861	et	4	main
muistsete	doc_491521502212_item	3656860	et	3	main
800-1050	doc_491521502212_item	3656859	et	2	main
viikingiaeg	doc_491521502212_item	3656858	et	3	main
1	doc_491521502212_item	3656857	et	2	main
eesti	doc_491521502212_item	3656851	et	4	main
kontrolltöö	doc_491521502212_item	3656848	et	4	main
rahvusele	doc_491521502212_item	3656944	et	3	main
aga	doc_491521502215_item	3657727	et	3	main
võõrast	doc_491521502215_item	3657725	et	4	main
hakkavad	doc_491521502215_item	3657723	et	4	main
kaubandus	doc_491521502215_item	3657710	et	3	main
meisterdamine	doc_491521502215_item	3657709	et	4	main
kauplevad	doc_491521502215_item	3657703	et	4	main
kirves	doc_491521502215_item	3657694	et	4	main
tulevad	doc_491521502215_item	3657691	et	4	main
kasutusele	doc_491521502215_item	3657690	et	4	main
hakkasid	doc_491521502215_item	3657682	et	4	main
sai	doc_491521502215_item	3657669	et	4	main
oli	doc_491521502215_item	3657665	et	3	main
maeti	doc_491521502215_item	3657656	et	3	main
kätte	doc_491521502215_item	3657649	et	4	main
neid	doc_491521502215_item	3657648	et	4	main
varanduse	doc_491521502215_item	3657641	et	3	main
vaid	doc_491521502215_item	3657623	et	3	main
maa	doc_491521502215_item	3657621	et	4	main
inimeste	doc_491521502215_item	3657608	et	3	main
ajaks	doc_491521502215_item	3657599	et	4	main
rändamise	doc_491521502215_item	3657598	et	4	main
suureks	doc_491521502215_item	3657596	et	4	main
saj	doc_491521502215_item	3657593	et	4	main
rauaaeg	doc_491521502215_item	3657591	et	3	main
keskmine	doc_491521502215_item	3657590	et	3	main
tegemiskombed	doc_491521502215_item	3657589	et	3	main
jaanitule	doc_491521502215_item	3657588	et	4	main
ka	doc_491521502215_item	3657587	et	3	main
oli	doc_491521502215_item	3657586	et	3	main
hakati	doc_491521502215_item	3657554	et	3	main
ekr	doc_491521502215_item	3657553	et	4	main
viitavad	doc_491521502215_item	3657540	et	4	main
mõisad	doc_491521502215_item	3657720	et	3	main
maad	doc_491521502215_item	3657711	et	4	main
jääb	doc_491521502215_item	3657700	et	3	main
toitu	doc_491521502215_item	3657699	et	4	main
inimestel	doc_491521502215_item	3657697	et	3	main
sirp	doc_491521502215_item	3657692	et	3	main
tegelema	doc_491521502215_item	3657684	et	3	main
inimesed	doc_491521502215_item	3657681	et	3	main
9-13	doc_491521502215_item	3657678	et	2	main
rauaaeg	doc_491521502215_item	3657677	et	3	main
noorem	doc_491521502215_item	3657676	et	4	main
kõige	doc_491521502215_item	3657670	et	4	main
külas	doc_491521502215_item	3657664	et	3	main
lõuna-eestis	doc_491521502215_item	3657655	et	3	main
saaks	doc_491521502215_item	3657647	et	3	main
ei	doc_491521502215_item	3657646	et	4	main
vargad	doc_491521502215_item	3657645	et	3	main
et	doc_491521502215_item	3657644	et	3	main
inimesed	doc_491521502215_item	3657627	et	3	main
sisse	doc_491521502215_item	3657622	et	4	main
ka	doc_491521502215_item	3657616	et	3	main
kivikalmed	doc_491521502215_item	3657613	et	3	main
sulatama	doc_491521502215_item	3657557	et	4	main
rauda	doc_491521502215_item	3657556	et	4	main
raud	doc_491521502215_item	3657547	et	3	main
levinud	doc_491521502215_item	3657492	et	4	main
kasvatama	doc_491521502215_item	3657478	et	4	main
eestis	doc_491521502215_item	3657476	et	3	main
ja	doc_491521502215_item	3657474	et	3	main
leitud	doc_491521502215_item	3657472	et	4	main
ka	doc_491521502215_item	3657467	et	3	main
riiki	doc_491521502215_item	3657728	et	4	main
inimesed	doc_491521502215_item	3657722	et	3	main
pojale	doc_491521502215_item	3657717	et	4	main
oma	doc_491521502215_item	3657713	et	4	main
kasutusele	doc_491521502215_item	3657707	et	4	main
tuleb	doc_491521502215_item	3657706	et	3	main
viljaga	doc_491521502215_item	3657705	et	3	main
oma	doc_491521502215_item	3657704	et	4	main
äärde	doc_491521502215_item	3657689	et	4	main
veekogude	doc_491521502215_item	3657688	et	3	main
rohkem	doc_491521502215_item	3657683	et	4	main
pkr	doc_491521502215_item	3657680	et	4	main
kuningas	doc_491521502215_item	3657675	et	4	main
pealikuks	doc_491521502215_item	3657668	et	4	main
igas	doc_491521502215_item	3657663	et	3	main
suured	doc_491521502215_item	3657661	et	3	main
liivakääpadesse	doc_491521502215_item	3657658	et	4	main
rikkamaid	doc_491521502215_item	3657653	et	4	main
maa	doc_491521502215_item	3657642	et	4	main
oma	doc_491521502215_item	3657640	et	4	main
inimesed	doc_491521502215_item	3657638	et	3	main
maetud	doc_491521502215_item	3657620	et	4	main
leitud	doc_491521502215_item	3657615	et	4	main
skandinaaviaga	doc_491521502215_item	3657612	et	4	main
tekib	doc_491521502215_item	3657611	et	3	main
konflikt	doc_491521502215_item	3657610	et	3	main
vahel	doc_491521502215_item	3657609	et	4	main
konflikte	doc_491521502215_item	3657607	et	3	main
rohkem	doc_491521502215_item	3657605	et	4	main
rahutu	doc_491521502215_item	3657602	et	4	main
see	doc_491521502215_item	3657600	et	3	main
piirkonnad	doc_491521502215_item	3657585	et	4	main
suured	doc_491521502215_item	3657584	et	3	main
skandinaaviast	doc_491521502215_item	3657560	et	3	main
1300a	doc_491521502215_item	3657552	et	4	main
haualt	doc_491521502215_item	3657551	et	3	main
linu	doc_491521502215_item	3657543	et	4	main
et	doc_491521502215_item	3657542	et	3	main
sellele	doc_491521502215_item	3657541	et	4	main
on	doc_491521502215_item	3657528	et	4	main
alguses	doc_491521502215_item	3657521	et	4	main
20	doc_491521502215_item	3657519	et	2	main
ja	doc_491521502215_item	3657518	et	3	main
ära	doc_491521502215_item	3657486	et	4	main
sigu	doc_491521502215_item	3657480	et	3	main
hakati	doc_491521502215_item	3657477	et	3	main
lõuna	doc_491521502215_item	3657475	et	4	main
ei	doc_491521502215_item	3657738	et	4	main
tekkima	doc_491521502215_item	3657734	et	3	main
hakkas	doc_491521502215_item	3657733	et	3	main
saaremaalt	doc_491521502215_item	3657446	et	4	main
leitud	doc_491521502215_item	3657445	et	4	main
1	doc_491521502215_item	3657437	et	2	main
hing	doc_491521502215_item	3657761	et	3	main
on	doc_491521502215_item	3657760	et	4	main
kõikidel	doc_491521502215_item	3657759	et	4	main
neil	doc_491521502215_item	3657758	et	4	main
lilledel	doc_491521502215_item	3657757	et	4	main
majadel	doc_491521502215_item	3657756	et	3	main
rohul	doc_491521502215_item	3657755	et	4	main
puudel	doc_491521502215_item	3657754	et	4	main
näiteks	doc_491521502215_item	3657753	et	4	main
hing	doc_491521502215_item	3657752	et	3	main
on	doc_491521502215_item	3657751	et	4	main
asjadel	doc_491521502215_item	3657750	et	3	main
kõikidel	doc_491521502215_item	3657749	et	4	main
et	doc_491521502215_item	3657748	et	3	main
arvasid	doc_491521502215_item	3657747	et	4	main
inimesed	doc_491521502215_item	3657746	et	3	main
ajal	doc_491521502215_item	3657745	et	4	main
tol	doc_491521502215_item	3657744	et	3	main
tähendus	doc_491521502215_item	3657743	et	4	main
animism	doc_491521502215_item	3657742	et	3	main
ja	doc_491521502215_item	3657721	et	3	main
hakkavad	doc_491521502215_item	3657718	et	4	main
isa	doc_491521502215_item	3657716	et	4	main
sugulastele	doc_491521502215_item	3657715	et	4	main
pärandati	doc_491521502215_item	3657712	et	4	main
üle	doc_491521502215_item	3657701	et	3	main
tõuseb	doc_491521502215_item	3657698	et	3	main
olukord	doc_491521502215_item	3657696	et	3	main
koonduvad	doc_491521502215_item	3657687	et	4	main
asulad	doc_491521502215_item	3657686	et	3	main
saj	doc_491521502215_item	3657679	et	4	main
pealik	doc_491521502215_item	3657667	et	4	main
asulad	doc_491521502215_item	3657662	et	3	main
tekkima	doc_491521502215_item	3657660	et	3	main
inimesi	doc_491521502215_item	3657657	et	4	main
matusi	doc_491521502215_item	3657654	et	4	main
kõige	doc_491521502215_item	3657652	et	4	main
alla	doc_491521502215_item	3657643	et	3	main
ehteid	doc_491521502215_item	3657637	et	3	main
peitsid	doc_491521502215_item	3657639	et	4	main
tööriistu	doc_491521502215_item	3657636	et	3	main
kaasa	doc_491521502215_item	3657635	et	4	main
asju	doc_491521502215_item	3657634	et	3	main
ka	doc_491521502215_item	3657633	et	3	main
pandi	doc_491521502215_item	3657632	et	4	main
surnutele	doc_491521502215_item	3657631	et	4	main
eest	doc_491521502215_item	3657630	et	4	main
surnute	doc_491521502215_item	3657629	et	4	main
ei	doc_491521502215_item	3657619	et	4	main
sõdu	doc_491521502215_item	3657606	et	3	main
oli	doc_491521502215_item	3657604	et	3	main
rahvaste	doc_491521502215_item	3657597	et	4	main
saarte	doc_491521502215_item	3657583	et	3	main
ja	doc_491521502215_item	3657582	et	3	main
eesti	doc_491521502215_item	3657581	et	4	main
lääne	doc_491521502215_item	3657580	et	4	main
ja	doc_491521502215_item	3657579	et	3	main
lõuna-	doc_491521502215_item	3657578	et	4	main
põhja-eesti	doc_491521502215_item	3657577	et	4	main
ja	doc_491521502215_item	3657576	et	3	main
kesk-	doc_491521502215_item	3657575	et	3	main
selgesti	doc_491521502215_item	3657574	et	3	main
rauaajal	doc_491521502215_item	3657573	et	3	main
rooma	doc_491521502215_item	3657572	et	4	main
eristuvad	doc_491521502215_item	3657571	et	4	main
põhjal	doc_491521502215_item	3657570	et	4	main
kalmete	doc_491521502215_item	3657569	et	3	main
saj	doc_491521502215_item	3657568	et	4	main
1-5	doc_491521502215_item	3657567	et	2	main
rauaaeg	doc_491521502215_item	3657566	et	3	main
vanem	doc_491521502215_item	3657565	et	4	main
pronksigi	doc_491521502215_item	3657564	et	4	main
nagu	doc_491521502215_item	3657563	et	3	main
nii	doc_491521502215_item	3657562	et	3	main
rauda	doc_491521502215_item	3657561	et	4	main
eestist	doc_491521502215_item	3657617	et	3	main
on	doc_491521502215_item	3657614	et	4	main
aeg	doc_491521502215_item	3657603	et	3	main
oli	doc_491521502215_item	3657601	et	3	main
peetakse	doc_491521502215_item	3657595	et	3	main
pkr	doc_491521502215_item	3657594	et	4	main
5-8	doc_491521502215_item	3657592	et	2	main
toodi	doc_491521502215_item	3657559	et	4	main
esialgu	doc_491521502215_item	3657558	et	3	main
egiptlaste	doc_491521502215_item	3657550	et	3	main
leitud	doc_491521502215_item	3657549	et	4	main
on	doc_491521502215_item	3657535	et	4	main
tekstiilileiud	doc_491521502215_item	3657534	et	3	main
vanad	doc_491521502215_item	3657533	et	3	main
väga	doc_491521502215_item	3657532	et	3	main
sünvoolne	doc_491521502215_item	3657531	et	4	main
väga	doc_491521502215_item	3657530	et	3	main
see	doc_491521502215_item	3657529	et	3	main
kasvatama	doc_491521502215_item	3657524	et	4	main
tööriistad	doc_491521502215_item	3657493	et	3	main
tehtud	doc_491521502215_item	3657490	et	4	main
on	doc_491521502215_item	3657489	et	4	main
kõblas	doc_491521502215_item	3657488	et	3	main
maaharimisvahend	doc_491521502215_item	3657487	et	3	main
hobuseid	doc_491521502215_item	3657482	et	4	main
ja	doc_491521502215_item	3657481	et	3	main
asulaid	doc_491521502215_item	3657470	et	4	main
kasvatus	doc_491521502215_item	3657469	et	4	main
kivist	doc_491521502215_item	3657459	et	4	main
mõiste	doc_491521502215_item	3657741	et	4	main
teki	doc_491521502215_item	3657730	et	4	main
vanim	doc_491521502215_item	3657452	et	3	main
töötlema	doc_491521502215_item	3657451	et	3	main
pronksi	doc_491521502215_item	3657450	et	4	main
kohapeal	doc_491521502215_item	3657449	et	3	main
õpiti	doc_491521502215_item	3657448	et	3	main
siis	doc_491521502215_item	3657447	et	3	main
ja	doc_491521502215_item	3657439	et	3	main
pärit	doc_491521502216_item	3657998	et	3	main
see	doc_491521502216_item	3657987	et	3	main
kivi	doc_491521502216_item	3657986	et	4	main
pae	doc_491521502216_item	3657985	et	3	main
taratega	doc_491521502216_item	3657978	et	4	main
et	doc_491521502216_item	3657955	et	3	main
teisi	doc_491521502216_item	3657952	et	4	main
küünlate	doc_491521502216_item	3657947	et	4	main
rõivast	doc_491521502216_item	3657928	et	4	main
looduslikult	doc_491521502215_item	3657555	et	4	main
on	doc_491521502215_item	3657548	et	4	main
2	doc_491521502215_item	3657546	et	2	main
tehtud	doc_491521502215_item	3657545	et	4	main
on	doc_491521502215_item	3657544	et	4	main
mis	doc_491521502215_item	3657539	et	4	main
tööriistu	doc_491521502215_item	3657538	et	3	main
ja	doc_491521502215_item	3657537	et	3	main
leitud	doc_491521502215_item	3657536	et	4	main
hakati	doc_491521502215_item	3657523	et	3	main
kultuuriainetest	doc_491521502215_item	3657522	et	4	main
nad	doc_491521502215_item	3657514	et	3	main
keelati	doc_491521502215_item	3657485	et	4	main
veiseid	doc_491521502215_item	3657479	et	3	main
lääne	doc_491521502215_item	3657473	et	4	main
hulgas	doc_491521502215_item	3657466	et	4	main
põllumajandusega	doc_491521502215_item	3657464	et	3	main
tegelema	doc_491521502215_item	3657463	et	3	main
hakkavad	doc_491521502215_item	3657462	et	4	main
luust	doc_491521502215_item	3657461	et	4	main
ja	doc_491521502215_item	3657460	et	3	main
eestis	doc_491521502215_item	3657737	et	3	main
aga	doc_491521502215_item	3657736	et	3	main
linnakultuur	doc_491521502215_item	3657735	et	3	main
linnades	doc_491521502215_item	3657732	et	3	main
teistes	doc_491521502215_item	3657731	et	4	main
ei	doc_491521502215_item	3657729	et	4	main
pronksiaeg	doc_491521502215_item	3657453	et	3	main
2	doc_491521502215_item	3657440	et	2	main
jõudnud	doc_491521502215_item	3657435	et	4	main
arvatud	doc_491521502215_item	3657431	et	4	main
lõuna-eesti	doc_491521502216_item	3658003	et	4	main
mõõk	doc_491521502216_item	3657999	et	3	main
kaaned	doc_491521502216_item	3657984	et	3	main
röövima	doc_491521502216_item	3657953	et	4	main
hakkasid	doc_491521502216_item	3657951	et	4	main
hõimud	doc_491521502216_item	3657950	et	4	main
ühed	doc_491521502216_item	3657949	et	3	main
rasva	doc_491521502216_item	3657945	et	4	main
ajal	doc_491521502216_item	3657940	et	4	main
mulgist	doc_491521502216_item	3657938	et	3	main
koidula	doc_491521502216_item	3657936	et	4	main
kasvatus	doc_491521502216_item	3657926	et	4	main
kultuurtaimed	doc_491521502216_item	3657924	et	3	main
teravilja	doc_491521502216_item	3657920	et	4	main
hea	doc_491521502216_item	3657919	et	4	main
oleks	doc_491521502216_item	3657918	et	3	main
inimesed	doc_491521502216_item	3657912	et	3	main
et	doc_491521502216_item	3657911	et	3	main
sai	doc_491521502216_item	3657895	et	4	main
lõigata	doc_491521502216_item	3657896	et	4	main
oli	doc_491521502216_item	3657892	et	3	main
kõblas	doc_491521502216_item	3657887	et	3	main
maakogestamis	doc_491521502216_item	3657885	et	4	main
kitsetele	doc_491521502216_item	3657877	et	4	main
lisaks	doc_491521502216_item	3657874	et	4	main
inimesed	doc_491521502216_item	3657872	et	3	main
vähe	doc_491521502216_item	3657871	et	3	main
neid	doc_491521502216_item	3657870	et	4	main
rohkem	doc_491521502216_item	3657864	et	4	main
oligi	doc_491521502216_item	3657858	et	3	main
koduloomade	doc_491521502216_item	3657849	et	4	main
põllumajandusega	doc_491521502216_item	3657847	et	3	main
jaoks	doc_491521502215_item	3657527	et	4	main
eestlaste	doc_491521502215_item	3657526	et	4	main
lina	doc_491521502215_item	3657525	et	4	main
saj	doc_491521502215_item	3657520	et	4	main
19	doc_491521502215_item	3657517	et	2	main
kasutusel	doc_491521502215_item	3657516	et	4	main
olid	doc_491521502215_item	3657515	et	4	main
jahvatada	doc_491521502215_item	3657513	et	3	main
jahuks	doc_491521502215_item	3657512	et	3	main
teravilja	doc_491521502215_item	3657511	et	4	main
ka	doc_491521502215_item	3657510	et	3	main
osati	doc_491521502215_item	3657509	et	3	main
saaki	doc_491521502215_item	3657508	et	4	main
paremat	doc_491521502215_item	3657507	et	4	main
saada	doc_491521502215_item	3657506	et	4	main
et	doc_491521502215_item	3657505	et	3	main
veekogudes	doc_491521502215_item	3657504	et	3	main
leiti	doc_491521502215_item	3657503	et	3	main
tähendus	doc_491521502215_item	3657502	et	4	main
maagiline	doc_491521502215_item	3657501	et	4	main
on	doc_491521502215_item	3657500	et	4	main
sellel	doc_491521502215_item	3657499	et	4	main
vilja	doc_491521502215_item	3657498	et	4	main
koristati	doc_491521502215_item	3657497	et	3	main
sellega	doc_491521502215_item	3657496	et	3	main
sirp	doc_491521502215_item	3657495	et	3	main
on	doc_491521502215_item	3657494	et	4	main
kivist	doc_491521502215_item	3657491	et	4	main
söömine	doc_491521502215_item	3657484	et	4	main
hobuseliha	doc_491521502215_item	3657483	et	4	main
on	doc_491521502215_item	3657471	et	4	main
loomade	doc_491521502215_item	3657468	et	4	main
seal	doc_491521502215_item	3657465	et	4	main
2	doc_491521502215_item	3657740	et	2	main
tekkinud	doc_491521502215_item	3657739	et	4	main
valgast	doc_491521502215_item	3657438	et	3	main
pronks	doc_491521502215_item	3657436	et	3	main
on	doc_491521502215_item	3657434	et	4	main
eestisse	doc_491521502215_item	3657433	et	4	main
et	doc_491521502215_item	3657432	et	3	main
hõimud	doc_491521502216_item	3658004	et	4	main
haud	doc_491521502216_item	3658002	et	4	main
lae	doc_491521502216_item	3658001	et	4	main
põld	doc_491521502216_item	3658000	et	3	main
germaani	doc_491521502216_item	3657997	et	3	main
sõnad	doc_491521502216_item	3657996	et	4	main
jõuavad	doc_491521502216_item	3657995	et	4	main
kivikirst	doc_491521502216_item	3657983	et	3	main
matusetraditsioon	doc_491521502216_item	3657980	et	3	main
selleks	doc_491521502216_item	3657954	et	4	main
hülgepüügiga	doc_491521502216_item	3657944	et	3	main
kalapüügiga	doc_491521502216_item	3657942	et	3	main
lydia	doc_491521502216_item	3657935	et	4	main
tegelema	doc_491521502216_item	3657934	et	3	main
sellega	doc_491521502216_item	3657933	et	3	main
esimesena	doc_491521502216_item	3657932	et	3	main
hakkaid	doc_491521502216_item	3657931	et	4	main
mulk	doc_491521502216_item	3657930	et	3	main
viljandimaamehed	doc_491521502216_item	3657929	et	3	main
on	doc_491521502215_item	3657444	et	4	main
pronksesemed	doc_491521502215_item	3657443	et	3	main
esimesed	doc_491521502215_item	3657442	et	3	main
skandinaaviast	doc_491521502215_item	3657441	et	3	main
on	doc_491521502215_item	3657430	et	4	main
lähis-idas	doc_491521502215_item	3657429	et	3	main
kasutati	doc_491521502215_item	3657428	et	4	main
tina	doc_491521502215_item	3657427	et	4	main
vask	doc_491521502215_item	3657426	et	3	main
pronks	doc_491521502215_item	3657425	et	3	main
ekr	doc_491521502215_item	3657424	et	4	main
saj	doc_491521502215_item	3657423	et	4	main
5	doc_491521502215_item	3657422	et	2	main
kr	doc_491521502215_item	3657421	et	4	main
e	doc_491521502215_item	3657420	et	4	main
keskel	doc_491521502215_item	3657419	et	3	main
aasttuh	doc_491521502215_item	3657418	et	4	main
ii	doc_491521502215_item	3657417	et	4	main
pronksiaeg	doc_491521502215_item	3657416	et	3	main
1	doc_491521502215_item	3657415	et	2	main
1	doc_491521502215_item	3657414	et	2	main
tähendus	doc_491521502215_item	3657413	et	4	main
animism	doc_491521502215_item	3657412	et	3	main
mõiste	doc_491521502215_item	3657411	et	4	main
2	doc_491521502215_item	3657410	et	2	main
territooriumil	doc_491521502215_item	3657409	et	3	main
eesti	doc_491521502215_item	3657408	et	4	main
metalliaeg	doc_491521502215_item	3657407	et	3	main
varane	doc_491521502215_item	3657406	et	4	main
1	doc_491521502215_item	3657405	et	2	main
kontrolltöö	doc_491521502215_item	3657404	et	4	main
valmistati	doc_491521502215_item	3657458	et	4	main
kr	doc_491521502215_item	3657457	et	4	main
e	doc_491521502215_item	3657456	et	4	main
a	doc_491521502215_item	3657455	et	4	main
ii	doc_491521502215_item	3657454	et	4	main
skandinaaviast	doc_491521502216_item	3657982	et	3	main
uus	doc_491521502216_item	3657979	et	3	main
valmistamiseks	doc_491521502216_item	3657948	et	4	main
ja	doc_491521502216_item	3657943	et	3	main
tegeleti	doc_491521502216_item	3657941	et	3	main
tol	doc_491521502216_item	3657939	et	3	main
kirjutas	doc_491521502216_item	3657937	et	3	main
hing	doc_491521502216_item	3658025	et	3	main
on	doc_491521502216_item	3658024	et	4	main
puudel	doc_491521502216_item	3658023	et	4	main
nt	doc_491521502216_item	3658022	et	4	main
hing	doc_491521502216_item	3658021	et	3	main
ka	doc_491521502216_item	3658020	et	3	main
on	doc_491521502216_item	3658019	et	4	main
loodusel	doc_491521502216_item	3658018	et	4	main
eluta	doc_491521502216_item	3658017	et	3	main
et	doc_491521502216_item	3658016	et	3	main
uskumus	doc_491521502216_item	3658015	et	3	main
on	doc_491521502216_item	3658014	et	4	main
see	doc_491521502216_item	3658013	et	3	main
animism	doc_491521502216_item	3658012	et	3	main
2	doc_491521502216_item	3658011	et	2	main
skandinaaviaga	doc_491521502216_item	3658010	et	4	main
enam	doc_491521502216_item	3658009	et	4	main
p-e	doc_491521502216_item	3658008	et	3	main
hõimudega	doc_491521502216_item	3658007	et	3	main
volga	doc_491521502216_item	3658006	et	4	main
kontakteerisid	doc_491521502216_item	3658005	et	4	main
eestis	doc_491521502216_item	3657994	et	3	main
põhja	doc_491521502216_item	3657993	et	4	main
ja	doc_491521502216_item	3657992	et	3	main
saartel	doc_491521502216_item	3657991	et	3	main
levinud	doc_491521502216_item	3657990	et	4	main
eriti	doc_491521502216_item	3657989	et	3	main
oli	doc_491521502216_item	3657988	et	3	main
pärib	doc_491521502216_item	3657981	et	3	main
müüritega	doc_491521502216_item	3657977	et	4	main
linnuseid	doc_491521502216_item	3657976	et	3	main
muinas	doc_491521502216_item	3657975	et	4	main
ehitama	doc_491521502216_item	3657974	et	4	main
hakkati	doc_491521502216_item	3657973	et	3	main
ajal	doc_491521502216_item	3657972	et	4	main
tol	doc_491521502216_item	3657971	et	3	main
sõnnik	doc_491521502216_item	3657970	et	3	main
savi	doc_491521502216_item	3657969	et	4	main
pandi	doc_491521502216_item	3657968	et	4	main
siis	doc_491521502216_item	3657967	et	3	main
peale	doc_491521502216_item	3657966	et	4	main
ja	doc_491521502216_item	3657965	et	3	main
puu	doc_491521502216_item	3657964	et	4	main
oli	doc_491521502216_item	3657963	et	3	main
see	doc_491521502216_item	3657962	et	3	main
kaivama	doc_491521502216_item	3657961	et	4	main
maase	doc_491521502216_item	3657960	et	4	main
hakkati	doc_491521502216_item	3657959	et	3	main
kaitsta	doc_491521502216_item	3657958	et	4	main
vara	doc_491521502216_item	3657957	et	4	main
oma	doc_491521502216_item	3657956	et	4	main
kasutati	doc_491521502216_item	3657946	et	4	main
kooti	doc_491521502216_item	3657927	et	4	main
abil	doc_491521502216_item	3657923	et	4	main
jahutati	doc_491521502216_item	3657921	et	4	main
viskasid	doc_491521502216_item	3657913	et	4	main
tal	doc_491521502216_item	3657902	et	3	main
ja	doc_491521502216_item	3657898	et	3	main
vilju	doc_491521502216_item	3657897	et	4	main
pronksist	doc_491521502216_item	3657893	et	4	main
veeloomadena	doc_491521502216_item	3657883	et	3	main
hobuseid	doc_491521502216_item	3657880	et	4	main
ja	doc_491521502216_item	3657879	et	3	main
sigu	doc_491521502216_item	3657878	et	3	main
on	doc_491521502216_item	3657869	et	4	main
lõunas	doc_491521502216_item	3657868	et	3	main
pärast	doc_491521502216_item	3657861	et	4	main
ääres	doc_491521502216_item	3657856	et	4	main
kasvatamisega	doc_491521502216_item	3657850	et	4	main
hakkatakse	doc_491521502216_item	3657844	et	4	main
ja	doc_491521502216_item	3657841	et	3	main
ekr	doc_491521502216_item	3657834	et	4	main
keskel	doc_491521502216_item	3657833	et	3	main
jooksul	doc_491521502216_item	3657827	et	4	main
sõja	doc_491521502216_item	3657826	et	3	main
ja	doc_491521502216_item	3657825	et	3	main
said	doc_491521502216_item	3657822	et	4	main
asju	doc_491521502216_item	3657821	et	3	main
pronksist	doc_491521502216_item	3657820	et	4	main
et	doc_491521502216_item	3657819	et	3	main
nii	doc_491521502216_item	3657818	et	3	main
on	doc_491521502216_item	3657805	et	4	main
pronks	doc_491521502216_item	3657796	et	3	main
oli	doc_491521502216_item	3657795	et	3	main
metall	doc_491521502216_item	3657794	et	3	main
egiptuses	doc_491521502216_item	3657792	et	4	main
leiti	doc_491521502216_item	3657791	et	3	main
ja	doc_491521502216_item	3657787	et	3	main
seda	doc_491521502216_item	3657783	et	3	main
kulda	doc_491521502216_item	3657781	et	4	main
ei	doc_491521502216_item	3657779	et	4	main
eestis	doc_491521502216_item	3657778	et	3	main
kuld	doc_491521502216_item	3657777	et	3	main
oli	doc_491521502216_item	3657776	et	3	main
metall	doc_491521502216_item	3657775	et	3	main
esimene	doc_491521502216_item	3657774	et	3	main
ja	doc_491521502218_item	3658106	et	3	main
rääbis	doc_491521502218_item	3658098	et	3	main
nagu	doc_491521502218_item	3658095	et	3	main
pärit	doc_491521502218_item	3658092	et	3	main
on	doc_491521502218_item	3658091	et	4	main
ajalt	doc_491521502218_item	3658090	et	4	main
tolt	doc_491521502218_item	3658089	et	3	main
oli	doc_491521502218_item	3658082	et	3	main
nahka	doc_491521502218_item	3658077	et	4	main
saadi	doc_491521502218_item	3658075	et	4	main
sellelt	doc_491521502218_item	3658074	et	4	main
saak	doc_491521502218_item	3658073	et	3	main
oli	doc_491521502218_item	3658068	et	3	main
ekr	doc_491521502218_item	3658063	et	4	main
2	doc_491521502218_item	3658322	et	2	main
pandud	doc_491521502218_item	3658312	et	4	main
ümber	doc_491521502218_item	3658311	et	3	main
kividega	doc_491521502218_item	3658310	et	3	main
suurte	doc_491521502218_item	3658309	et	3	main
sest	doc_491521502218_item	3658295	et	4	main
teha	doc_491521502218_item	3658294	et	3	main
natuke	doc_491521502218_item	3658287	et	4	main
neid	doc_491521502218_item	3658271	et	4	main
venekirvestel	doc_491521502218_item	3658267	et	4	main
abil	doc_491521502218_item	3658264	et	4	main
nööri	doc_491521502218_item	3658263	et	4	main
a	doc_491521502218_item	3658258	et	4	main
2200	doc_491521502218_item	3658257	et	2	main
käsikivi	doc_491521502216_item	3657922	et	4	main
ilm	doc_491521502216_item	3657917	et	3	main
et	doc_491521502216_item	3657916	et	3	main
vette	doc_491521502216_item	3657915	et	3	main
sirpi	doc_491521502216_item	3657914	et	4	main
sest	doc_491521502216_item	3657910	et	4	main
leiti	doc_491521502216_item	3657908	et	3	main
maagiline	doc_491521502216_item	3657904	et	4	main
oli	doc_491521502216_item	3657903	et	3	main
kasutati	doc_491521502216_item	3657900	et	4	main
sellega	doc_491521502216_item	3657894	et	3	main
sirp	doc_491521502216_item	3657891	et	3	main
kivist	doc_491521502216_item	3657890	et	4	main
põlluriistad	doc_491521502216_item	3657884	et	3	main
kasutati	doc_491521502216_item	3657882	et	4	main
hobuseid	doc_491521502216_item	3657881	et	4	main
ja	doc_491521502216_item	3657867	et	3	main
äres	doc_491521502216_item	3657866	et	4	main
peipsi	doc_491521502216_item	3657865	et	4	main
kiviajal	doc_491521502216_item	3657859	et	3	main
veekogude	doc_491521502216_item	3657855	et	3	main
ikka	doc_491521502216_item	3657853	et	4	main
ja	doc_491521502216_item	3657848	et	3	main
tegelema	doc_491521502216_item	3657846	et	3	main
kivist	doc_491521502216_item	3657840	et	4	main
pkr	doc_491521502216_item	3657837	et	4	main
saj	doc_491521502216_item	3657836	et	4	main
1	doc_491521502216_item	3657835	et	2	main
metalliaeg	doc_491521502216_item	3657829	et	3	main
varane	doc_491521502216_item	3657828	et	4	main
kauba	doc_491521502216_item	3657823	et	3	main
leitud	doc_491521502216_item	3657806	et	4	main
esemeid	doc_491521502216_item	3657804	et	3	main
pronksi	doc_491521502216_item	3657803	et	4	main
esimesed	doc_491521502216_item	3657802	et	3	main
lähis-idas	doc_491521502216_item	3657801	et	3	main
teine	doc_491521502216_item	3657793	et	3	main
palju	doc_491521502216_item	3657790	et	4	main
väga	doc_491521502216_item	3657789	et	3	main
ka	doc_491521502216_item	3657788	et	3	main
leiab	doc_491521502216_item	3657784	et	3	main
aga	doc_491521502216_item	3657782	et	3	main
leia	doc_491521502216_item	3657780	et	4	main
1	doc_491521502216_item	3657773	et	2	main
tähendus	doc_491521502216_item	3657772	et	4	main
animism	doc_491521502216_item	3657771	et	3	main
eesti	doc_491521502216_item	3657767	et	4	main
varane	doc_491521502216_item	3657765	et	4	main
töö-	doc_491521502218_item	3658108	et	4	main
metssiga	doc_491521502218_item	3658104	et	4	main
peale	doc_491521502218_item	3658099	et	4	main
kalanimetused	doc_491521502218_item	3658094	et	4	main
niisugused	doc_491521502218_item	3658093	et	3	main
ja	doc_491521502218_item	3658085	et	3	main
jahimeeste	doc_491521502218_item	3658084	et	4	main
rasva	doc_491521502218_item	3658079	et	4	main
hea	doc_491521502218_item	3658072	et	4	main
ajal	doc_491521502218_item	3658070	et	4	main
tol	doc_491521502218_item	3658069	et	3	main
põhjapõtraküttid	doc_491521502218_item	3658066	et	4	main
nad	doc_491521502218_item	3658064	et	3	main
mesoliitikumis	doc_491521502218_item	3658059	et	3	main
kultuur	doc_491521502218_item	3658324	et	3	main
tähendus	doc_491521502216_item	3657905	et	4	main
oli	doc_491521502216_item	3657889	et	3	main
vahend	doc_491521502216_item	3657886	et	3	main
lamastele	doc_491521502216_item	3657875	et	4	main
kasvatasid	doc_491521502216_item	3657873	et	4	main
elab	doc_491521502216_item	3657863	et	3	main
neid	doc_491521502216_item	3657862	et	4	main
nagu	doc_491521502216_item	3657857	et	3	main
veel	doc_491521502216_item	3657854	et	4	main
on	doc_491521502216_item	3657852	et	4	main
asulad	doc_491521502216_item	3657851	et	3	main
intensiivselt	doc_491521502216_item	3657845	et	4	main
lina	doc_491521502216_item	3657925	et	4	main
vees	doc_491521502216_item	3657909	et	3	main
seda	doc_491521502216_item	3657907	et	3	main
ja	doc_491521502216_item	3657906	et	3	main
rituaalides	doc_491521502216_item	3657901	et	3	main
seda	doc_491521502216_item	3657899	et	3	main
mis	doc_491521502216_item	3657888	et	4	main
ja	doc_491521502216_item	3657876	et	3	main
selle	doc_491521502216_item	3657860	et	4	main
tehti	doc_491521502216_item	3657839	et	3	main
aastatuh	doc_491521502216_item	3657832	et	4	main
ii	doc_491521502216_item	3657831	et	4	main
eestis	doc_491521502216_item	3657830	et	3	main
vahetuses	doc_491521502216_item	3657824	et	4	main
sealsete	doc_491521502216_item	3657816	et	4	main
ka	doc_491521502216_item	3657815	et	3	main
kaubeldi	doc_491521502216_item	3657814	et	3	main
mere	doc_491521502216_item	3657813	et	3	main
üle	doc_491521502216_item	3657812	et	3	main
palju	doc_491521502216_item	3657811	et	4	main
väga	doc_491521502216_item	3657810	et	3	main
sõideti	doc_491521502216_item	3657809	et	3	main
kuna	doc_491521502216_item	3657808	et	3	main
saaremaalt	doc_491521502216_item	3657807	et	4	main
tina	doc_491521502216_item	3657798	et	4	main
vask	doc_491521502216_item	3657797	et	3	main
mandrilt	doc_491521502216_item	3657786	et	4	main
ameerika	doc_491521502216_item	3657785	et	3	main
mõiste	doc_491521502216_item	3657770	et	4	main
1	doc_491521502216_item	3657764	et	2	main
kontrolltöö	doc_491521502216_item	3657763	et	4	main
rauaajal	doc_491521502216_item	3657843	et	3	main
asuniketega	doc_491521502216_item	3657817	et	4	main
kasutati	doc_491521502216_item	3657800	et	4	main
seda	doc_491521502216_item	3657799	et	3	main
territooriumil	doc_491521502216_item	3657768	et	3	main
metalliaeg	doc_491521502216_item	3657766	et	3	main
kobrast	doc_491521502218_item	3658107	et	4	main
põhjapõtra	doc_491521502218_item	3658100	et	4	main
hauk	doc_491521502218_item	3658097	et	4	main
kiviaeg	doc_491521502218_item	3658081	et	3	main
väga	doc_491521502218_item	3658071	et	3	main
põder	doc_491521502218_item	3658067	et	3	main
aa	doc_491521502218_item	3658062	et	3	main
peale	doc_491521502218_item	3658308	et	4	main
muutusid	doc_491521502218_item	3658304	et	4	main
veekogude	doc_491521502218_item	3658302	et	3	main
põllumajandusega	doc_491521502218_item	3658289	et	3	main
inimesed	doc_491521502218_item	3658285	et	3	main
teisel	doc_491521502218_item	3658283	et	4	main
aja	doc_491521502218_item	3658282	et	4	main
tähtsus	doc_491521502218_item	3658270	et	4	main
e	doc_491521502218_item	3658254	et	4	main
pajad	doc_491521502218_item	3658244	et	4	main
põhjaga	doc_491521502218_item	3658243	et	3	main
2500-2200	doc_491521502218_item	3658239	et	2	main
inimesed	doc_491521502218_item	3658215	et	3	main
ekr	doc_491521502218_item	3658212	et	4	main
aa	doc_491521502218_item	3658211	et	3	main
neoliitikum	doc_491521502218_item	3658209	et	3	main
kiviaeg	doc_491521502218_item	3658207	et	3	main
ta	doc_491521502218_item	3658197	et	4	main
pandi	doc_491521502218_item	3658188	et	4	main
amuletidel	doc_491521502218_item	3658181	et	4	main
oli	doc_491521502218_item	3658177	et	3	main
tol	doc_491521502218_item	3658175	et	3	main
ja	doc_491521502218_item	3658171	et	3	main
püstkoja	doc_491521502218_item	3658164	et	3	main
asula	doc_491521502218_item	3658160	et	4	main
maeti	doc_491521502218_item	3658159	et	3	main
surnuid	doc_491521502218_item	3658158	et	4	main
hoolisid	doc_491521502218_item	3658154	et	4	main
keeruline	doc_491521502218_item	3658150	et	4	main
territoorium	doc_491521502222_item	3658654	et	3	main
on	doc_491521502222_item	3658651	et	4	main
käigus	doc_491521502222_item	3658642	et	4	main
uurimistöö	doc_491521502222_item	3658641	et	4	main
arheoloogilise	doc_491521502222_item	3658640	et	4	main
välja	doc_491521502222_item	3658639	et	4	main
kujuneb	doc_491521502222_item	3658638	et	3	main
mis	doc_491521502222_item	3658637	et	4	main
teatud	doc_491521502222_item	3658633	et	4	main
arheoloogiline	doc_491521502222_item	3658631	et	4	main
ja	doc_491521502222_item	3658618	et	3	main
välja	doc_491521502222_item	3658578	et	4	main
nöörkeraamika	doc_491521502222_item	3658576	et	4	main
kaunistatud	doc_491521502222_item	3658569	et	4	main
teokarpe	doc_491521502222_item	3658563	et	4	main
segati	doc_491521502222_item	3658562	et	3	main
keraamikat	doc_491521502222_item	3658558	et	3	main
narva	doc_491521502222_item	3658555	et	4	main
valmistamisvõtted	doc_491521502222_item	3658544	et	3	main
lihvitud	doc_491521502222_item	3658538	et	4	main
kvartsi	doc_491521502222_item	3658534	et	4	main
sellepärast	doc_491521502222_item	3658532	et	3	main
esemed	doc_491521502222_item	3658521	et	3	main
tihedalt	doc_491521502222_item	3658510	et	4	main
väga	doc_491521502222_item	3658509	et	3	main
oli	doc_491521502222_item	3658508	et	3	main
veekogude	doc_491521502222_item	3658502	et	3	main
elasid	doc_491521502222_item	3658500	et	4	main
inimesed	doc_491521502222_item	3658499	et	3	main
et	doc_491521502222_item	3658498	et	3	main
uue	doc_491521502222_item	3658494	et	3	main
nad	doc_491521502222_item	3658492	et	3	main
rohkem	doc_491521502222_item	3658484	et	4	main
st	doc_491521502222_item	3658483	et	3	main
elamiseks	doc_491521502222_item	3658482	et	4	main
endale	doc_491521502222_item	3658476	et	4	main
hõimud	doc_491521502222_item	3658474	et	4	main
balti	doc_491521502222_item	3658473	et	3	main
et	doc_491521502222_item	3658472	et	3	main
luust	doc_491521502216_item	3657842	et	4	main
ehteid	doc_491521502216_item	3657838	et	3	main
2	doc_491521502216_item	3657769	et	2	main
ja	doc_491521502218_item	3658109	et	3	main
kitse	doc_491521502218_item	3658105	et	4	main
ka	doc_491521502218_item	3658103	et	3	main
mehed	doc_491521502218_item	3658102	et	3	main
siig	doc_491521502218_item	3658096	et	3	main
kalastajate	doc_491521502218_item	3658083	et	4	main
olid	doc_491521502218_item	3658065	et	4	main
7500	doc_491521502218_item	3658060	et	2	main
ühele	doc_491521502218_item	3658325	et	3	main
pereliikmeid	doc_491521502218_item	3658321	et	3	main
selle	doc_491521502218_item	3658317	et	4	main
maa	doc_491521502218_item	3658307	et	4	main
elama	doc_491521502218_item	3658301	et	3	main
venekirved	doc_491521502218_item	3658280	et	3	main
oli	doc_491521502218_item	3658268	et	3	main
mustriga	doc_491521502218_item	3658266	et	3	main
tehtud	doc_491521502218_item	3658265	et	4	main
ekr	doc_491521502218_item	3658259	et	4	main
aukudega	doc_491521502218_item	3658252	et	3	main
teokarpe	doc_491521502218_item	3658235	et	4	main
hakkasid	doc_491521502218_item	3658216	et	4	main
sest	doc_491521502218_item	3658199	et	4	main
nagu	doc_491521502218_item	3658196	et	3	main
maeti	doc_491521502218_item	3658194	et	3	main
silmadele	doc_491521502218_item	3658192	et	3	main
tähendus	doc_491521502218_item	3658186	et	4	main
suur	doc_491521502218_item	3658185	et	3	main
oli	doc_491521502218_item	3658184	et	3	main
päikesekivist	doc_491521502218_item	3658183	et	4	main
eriti	doc_491521502218_item	3658182	et	3	main
alla	doc_491521502218_item	3658166	et	3	main
keha	doc_491521502218_item	3658156	et	4	main
surnu	doc_491521502218_item	3658155	et	4	main
käigul	doc_491521502218_item	3658337	et	3	main
kaevandamiste	doc_491521502218_item	3658336	et	4	main
arheoloogiliste	doc_491521502218_item	3658335	et	4	main
tehtud	doc_491521502218_item	3658334	et	4	main
kindlaks	doc_491521502218_item	3658333	et	3	main
on	doc_491521502218_item	3658332	et	4	main
mis	doc_491521502218_item	3658331	et	4	main
kombed	doc_491521502218_item	3658330	et	3	main
usund	doc_491521502218_item	3658329	et	3	main
eluviis	doc_491521502218_item	3658328	et	3	main
iseloomulik	doc_491521502218_item	3658327	et	3	main
inimgrupile	doc_491521502218_item	3658326	et	3	main
küttisid	doc_491521502218_item	3658101	et	4	main
õitsenguaeg	doc_491521502218_item	3658088	et	4	main
korjajate	doc_491521502218_item	3658087	et	4	main
metsaandide	doc_491521502218_item	3658086	et	3	main
keskmine	doc_491521502218_item	3658080	et	3	main
ja	doc_491521502218_item	3658078	et	3	main
liha	doc_491521502218_item	3658076	et	4	main
3000	doc_491521502218_item	3658061	et	2	main
ainult	doc_491521502218_item	3658058	et	4	main
inimesed	doc_491521502218_item	3658057	et	3	main
esimesed	doc_491521502218_item	3658056	et	3	main
asusid	doc_491521502218_item	3658055	et	4	main
territooriumile	doc_491521502218_item	3658054	et	3	main
eesti	doc_491521502218_item	3658053	et	4	main
territooriumil	doc_491521502218_item	3658051	et	3	main
eesti	doc_491521502218_item	3658050	et	4	main
asula	doc_491521502218_item	3658049	et	4	main
esimene	doc_491521502218_item	3658048	et	3	main
tähendab	doc_491521502218_item	3658052	et	3	main
küla	doc_491521502218_item	3658047	et	4	main
pulli	doc_491521502218_item	3658046	et	4	main
lähedal	doc_491521502218_item	3658045	et	4	main
sindi	doc_491521502218_item	3658044	et	4	main
kaldal	doc_491521502218_item	3658043	et	3	main
jõe	doc_491521502218_item	3658042	et	3	main
pärnu	doc_491521502218_item	3658041	et	4	main
ekr	doc_491521502218_item	3658040	et	4	main
7500	doc_491521502218_item	3658038	et	2	main
a	doc_491521502218_item	3658039	et	4	main
1	doc_491521502218_item	3658037	et	2	main
tähendus	doc_491521502218_item	3658036	et	4	main
arheoloogiline	doc_491521502218_item	3658034	et	4	main
kultuur	doc_491521502218_item	3658035	et	3	main
mõiste	doc_491521502218_item	3658033	et	4	main
territooriumil	doc_491521502218_item	3658031	et	3	main
2	doc_491521502218_item	3658032	et	2	main
eesti	doc_491521502218_item	3658030	et	4	main
kiviaeg	doc_491521502218_item	3658029	et	3	main
1	doc_491521502218_item	3658028	et	2	main
kontrolltöö	doc_491521502218_item	3658027	et	4	main
arheoloogiline	doc_491521502218_item	3658323	et	4	main
teisi	doc_491521502218_item	3658320	et	4	main
ümber	doc_491521502218_item	3658318	et	3	main
matmiskombed	doc_491521502218_item	3658305	et	3	main
ääres	doc_491521502218_item	3658303	et	4	main
eelistasid	doc_491521502218_item	3658300	et	4	main
inimesed	doc_491521502218_item	3658299	et	3	main
primitiivsed	doc_491521502218_item	3658298	et	3	main
olid	doc_491521502218_item	3658297	et	4	main
kõiki	doc_491521502218_item	3658319	et	4	main
pereisa	doc_491521502218_item	3658316	et	4	main
maeti	doc_491521502218_item	3658315	et	3	main
keskele	doc_491521502218_item	3658314	et	3	main
haua	doc_491521502218_item	3658313	et	3	main
maeti	doc_491521502218_item	3658306	et	3	main
raske	doc_491521502218_item	3658293	et	4	main
väga	doc_491521502218_item	3658292	et	3	main
oli	doc_491521502218_item	3658291	et	3	main
see	doc_491521502218_item	3658290	et	3	main
hakkasid	doc_491521502218_item	3658286	et	4	main
pool	doc_491521502218_item	3658284	et	4	main
mõned	doc_491521502218_item	3658279	et	3	main
isegi	doc_491521502218_item	3658272	et	4	main
kaunistatud	doc_491521502218_item	3658262	et	4	main
venekirveste	doc_491521502218_item	3658255	et	4	main
abil	doc_491521502218_item	3658251	et	4	main
tehtud	doc_491521502218_item	3658249	et	4	main
terava	doc_491521502218_item	3658242	et	3	main
kiviputru	doc_491521502218_item	3658234	et	4	main
segati	doc_491521502218_item	3658233	et	3	main
sisse	doc_491521502218_item	3658232	et	4	main
kuhu	doc_491521502218_item	3658231	et	3	main
savist	doc_491521502218_item	3658230	et	4	main
jämedast	doc_491521502218_item	3658229	et	3	main
tehti	doc_491521502218_item	3658228	et	3	main
ekr	doc_491521502218_item	3658227	et	4	main
aa	doc_491521502218_item	3658226	et	3	main
3000-2200	doc_491521502218_item	3658225	et	2	main
keraamika	doc_491521502218_item	3658224	et	4	main
narva	doc_491521502218_item	3658223	et	4	main
tüüp	doc_491521502218_item	3658222	et	3	main
keraamika	doc_491521502218_item	3658221	et	4	main
tegelema	doc_491521502218_item	3658217	et	3	main
esimene	doc_491521502218_item	3658213	et	3	main
3000-2500	doc_491521502218_item	3658210	et	2	main
tavaline	doc_491521502218_item	3658204	et	4	main
ja	doc_491521502218_item	3658203	et	3	main
kindel	doc_491521502218_item	3658202	et	3	main
oli	doc_491521502218_item	3658201	et	3	main
surm	doc_491521502218_item	3658200	et	3	main
inimese	doc_491521502218_item	3658191	et	4	main
surnu	doc_491521502218_item	3658190	et	4	main
usund	doc_491521502218_item	3658179	et	3	main
sest	doc_491521502218_item	3658174	et	4	main
põranda	doc_491521502218_item	3658165	et	3	main
vahel	doc_491521502218_item	3658162	et	4	main
usundite	doc_491521502218_item	3658151	et	3	main
ajajärk	doc_491521502222_item	3658656	et	3	main
igal	doc_491521502222_item	3658648	et	3	main
teadmisi	doc_491521502222_item	3658646	et	4	main
toie	doc_491521502222_item	3658627	et	4	main
loomahambaid	doc_491521502222_item	3658617	et	3	main
olla	doc_491521502222_item	3658609	et	3	main
kultuuri	doc_491521502222_item	3658584	et	4	main
kammkeraamika	doc_491521502222_item	3658568	et	4	main
sisse	doc_491521502222_item	3658561	et	4	main
tööriistad	doc_491521502218_item	3658296	et	3	main
tegelema	doc_491521502218_item	3658288	et	3	main
neoliitikumi	doc_491521502218_item	3658281	et	4	main
leitud	doc_491521502218_item	3658278	et	4	main
on	doc_491521502218_item	3658277	et	4	main
põhjal	doc_491521502218_item	3658276	et	4	main
jõe	doc_491521502218_item	3658275	et	3	main
võhandu	doc_491521502218_item	3658274	et	4	main
ohverdati	doc_491521502218_item	3658273	et	3	main
suur	doc_491521502218_item	3658269	et	3	main
olid	doc_491521502218_item	3658261	et	4	main
pajad	doc_491521502218_item	3658260	et	4	main
nöörkeraamika	doc_491521502218_item	3658253	et	4	main
kammi	doc_491521502218_item	3658250	et	4	main
ja	doc_491521502218_item	3658248	et	3	main
keraamikatüüp	doc_491521502218_item	3658241	et	4	main
kammkeraamika	doc_491521502218_item	3658238	et	4	main
taimi	doc_491521502218_item	3658237	et	4	main
ja	doc_491521502218_item	3658236	et	3	main
vanem	doc_491521502218_item	3658220	et	4	main
pool	doc_491521502218_item	3658214	et	4	main
e	doc_491521502218_item	3658208	et	4	main
vanem	doc_491521502218_item	3658206	et	4	main
magab	doc_491521502218_item	3658198	et	3	main
asendis	doc_491521502218_item	3658195	et	3	main
surnuid	doc_491521502218_item	3658193	et	4	main
merevaiku	doc_491521502218_item	3658187	et	4	main
ja	doc_491521502218_item	3658180	et	3	main
animistlik	doc_491521502218_item	3658178	et	3	main
ajal	doc_491521502218_item	3658176	et	4	main
mingi	doc_491521502218_item	3658172	et	4	main
tööriistu	doc_491521502218_item	3658170	et	3	main
pandi	doc_491521502218_item	3658168	et	4	main
hauda	doc_491521502218_item	3658167	et	4	main
isegi	doc_491521502218_item	3658163	et	4	main
territooriumile	doc_491521502218_item	3658161	et	3	main
inimesed	doc_491521502218_item	3658153	et	3	main
oli	doc_491521502218_item	3658148	et	3	main
tulekivist	doc_491521502218_item	3658120	et	4	main
isegi	doc_491521502218_item	3658119	et	4	main
tehti	doc_491521502218_item	3658118	et	3	main
tööriistu	doc_491521502218_item	3658117	et	3	main
väiksemaid	doc_491521502218_item	3658116	et	4	main
kivist	doc_491521502218_item	3658115	et	4	main
ja	doc_491521502218_item	3658114	et	3	main
savist	doc_491521502218_item	3658113	et	4	main
puust	doc_491521502218_item	3658112	et	4	main
valmistati	doc_491521502218_item	3658111	et	4	main
jahiriistu	doc_491521502218_item	3658110	et	3	main
muistised	doc_491521502222_item	3658653	et	3	main
arheoloogilisel	doc_491521502222_item	3658649	et	4	main
et	doc_491521502222_item	3658647	et	3	main
meile	doc_491521502222_item	3658645	et	4	main
annab	doc_491521502222_item	3658644	et	3	main
mis	doc_491521502222_item	3658643	et	4	main
inimgrupile	doc_491521502222_item	3658634	et	3	main
kultuur	doc_491521502222_item	3658632	et	3	main
2	doc_491521502222_item	3658630	et	2	main
päikesekivi	doc_491521502222_item	3658629	et	4	main
puhul	doc_491521502222_item	3658628	et	4	main
ka	doc_491521502222_item	3658624	et	3	main
sunutele	doc_491521502222_item	3658622	et	4	main
pandi	doc_491521502222_item	3658621	et	4	main
mõnikord	doc_491521502222_item	3658620	et	3	main
kihvu	doc_491521502222_item	3658619	et	3	main
ka	doc_491521502222_item	3658614	et	3	main
elus	doc_491521502222_item	3658612	et	4	main
teispoolses	doc_491521502222_item	3658611	et	3	main
noorimas	doc_491521502222_item	3658581	et	4	main
kammivajutustega	doc_491521502222_item	3658570	et	4	main
kultuur	doc_491521502218_item	3658256	et	3	main
kujunditega	doc_491521502218_item	3658247	et	3	main
geomeetriliste	doc_491521502218_item	3658246	et	4	main
kaunistatud	doc_491521502218_item	3658245	et	4	main
järgmine	doc_491521502218_item	3658240	et	3	main
kõige	doc_491521502218_item	3658219	et	4	main
keraamikaga	doc_491521502218_item	3658218	et	3	main
asi	doc_491521502218_item	3658205	et	4	main
isegi	doc_491521502218_item	3658189	et	4	main
loomakujukesi	doc_491521502218_item	3658173	et	4	main
väikeseid	doc_491521502218_item	3658169	et	4	main
eest	doc_491521502218_item	3658157	et	4	main
süsteem	doc_491521502218_item	3658152	et	3	main
väga	doc_491521502218_item	3658149	et	3	main
ajal	doc_491521502218_item	3658147	et	4	main
tol	doc_491521502218_item	3658146	et	3	main
toitu	doc_491521502218_item	3658145	et	4	main
küpsetati	doc_491521502218_item	3658144	et	3	main
peal	doc_491521502218_item	3658143	et	4	main
mille	doc_491521502218_item	3658142	et	3	main
kolle	doc_491521502218_item	3658141	et	4	main
asus	doc_491521502218_item	3658140	et	4	main
keskel	doc_491521502218_item	3658139	et	3	main
püstkoja	doc_491521502218_item	3658138	et	3	main
moodustasid	doc_491521502218_item	3658136	et	4	main
kodukondadega	doc_491521502218_item	3658137	et	4	main
püstkoda	doc_491521502218_item	3658135	et	4	main
10-70	doc_491521502218_item	3658134	et	2	main
inimest	doc_491521502218_item	3658133	et	3	main
4-10	doc_491521502218_item	3658132	et	2	main
elas	doc_491521502218_item	3658131	et	3	main
püstkojas	doc_491521502218_item	3658130	et	3	main
ühes	doc_491521502218_item	3658129	et	4	main
ehitistes	doc_491521502218_item	3658128	et	3	main
tehtud	doc_491521502218_item	3658127	et	4	main
puuokstest	doc_491521502218_item	3658126	et	3	main
koonusekujulistes	doc_491521502218_item	3658125	et	4	main
puitkodades	doc_491521502218_item	3658124	et	3	main
elati	doc_491521502218_item	3658123	et	3	main
kvartsist	doc_491521502218_item	3658122	et	4	main
ja	doc_491521502218_item	3658121	et	3	main
sarnased	doc_491521502222_item	3658652	et	4	main
leiul	doc_491521502222_item	3658650	et	3	main
kultuur	doc_491521502222_item	3658636	et	3	main
raviva	doc_491521502222_item	3658626	et	4	main
kaasa	doc_491521502222_item	3658623	et	4	main
ehteid	doc_491521502222_item	3658616	et	3	main
leidub	doc_491521502222_item	3658613	et	3	main
kasulik	doc_491521502222_item	3658610	et	3	main
e	doc_491521502222_item	3658580	et	4	main
neoliitikumis	doc_491521502222_item	3658579	et	3	main
keraamika	doc_491521502222_item	3658571	et	4	main
isegi	doc_491521502222_item	3658566	et	4	main
ja	doc_491521502222_item	3658565	et	3	main
valmistati	doc_491521502222_item	3658557	et	4	main
välja	doc_491521502222_item	3658551	et	4	main
oli	doc_491521502222_item	3658550	et	3	main
olid	doc_491521502222_item	3658541	et	4	main
kiviajal	doc_491521502222_item	3658535	et	3	main
tehti	doc_491521502222_item	3658522	et	3	main
veekogusid	doc_491521502222_item	3658514	et	4	main
ja	doc_491521502222_item	3658655	et	3	main
iseloomulik	doc_491521502222_item	3658635	et	3	main
merevaik	doc_491521502222_item	3658625	et	3	main
kalmetest	doc_491521502222_item	3658615	et	3	main
võiks	doc_491521502222_item	3658608	et	4	main
arvati	doc_491521502222_item	3658607	et	4	main
mis	doc_491521502222_item	3658606	et	4	main
tarbeese	doc_491521502222_item	3658605	et	3	main
või	doc_491521502222_item	3658604	et	4	main
tööriist	doc_491521502222_item	3658603	et	3	main
pandi	doc_491521502222_item	3658602	et	4	main
kaasa	doc_491521502222_item	3658601	et	4	main
kägiras	doc_491521502222_item	3658600	et	4	main
või	doc_491521502222_item	3658599	et	4	main
külili	doc_491521502222_item	3658598	et	3	main
sängitati	doc_491521502222_item	3658597	et	3	main
territooriumile	doc_491521502222_item	3658596	et	3	main
baltimaade	doc_491521502222_item	3658595	et	3	main
surnud	doc_491521502222_item	3658594	et	4	main
pärast	doc_491521502222_item	3658593	et	4	main
kirviste	doc_491521502222_item	3658592	et	4	main
meenutavate	doc_491521502222_item	3658591	et	4	main
paati	doc_491521502222_item	3658590	et	4	main
kultuuriks	doc_491521502222_item	3658589	et	4	main
sõjakirviste	doc_491521502222_item	3658588	et	4	main
vene-lik	doc_491521502222_item	3658587	et	4	main
ka	doc_491521502222_item	3658586	et	3	main
nimetatakse	doc_491521502222_item	3658585	et	3	main
selle	doc_491521502222_item	3658583	et	4	main
kiviajas	doc_491521502222_item	3658582	et	3	main
kujunes	doc_491521502222_item	3658577	et	3	main
ekr	doc_491521502222_item	3658575	et	4	main
lõpul	doc_491521502222_item	3658574	et	3	main
aastatuhandete	doc_491521502222_item	3658573	et	4	main
iv	doc_491521502222_item	3658572	et	4	main
taimi	doc_491521502222_item	3658567	et	4	main
mille	doc_491521502222_item	3658560	et	3	main
kultuur	doc_491521502222_item	3658554	et	3	main
kujunenud	doc_491521502222_item	3658552	et	4	main
kivimetest	doc_491521502222_item	3658540	et	4	main
leidub	doc_491521502222_item	3658536	et	3	main
kasutati	doc_491521502222_item	3658533	et	4	main
suhteliselt	doc_491521502222_item	3658530	et	4	main
oli	doc_491521502222_item	3658529	et	3	main
eestis	doc_491521502222_item	3658528	et	3	main
tulekiviesemed	doc_491521502222_item	3658527	et	3	main
sarvidest	doc_491521502222_item	3658526	et	3	main
ja	doc_491521502222_item	3658525	et	3	main
luust	doc_491521502222_item	3658524	et	4	main
kiviajal	doc_491521502222_item	3658516	et	3	main
liiklusteedena	doc_491521502222_item	3658515	et	3	main
ka	doc_491521502222_item	3658513	et	3	main
puid	doc_491521502222_item	3658511	et	3	main
metsas	doc_491521502222_item	3658507	et	3	main
ääres	doc_491521502222_item	3658503	et	4	main
peamiselt	doc_491521502222_item	3658501	et	4	main
elupaiga	doc_491521502222_item	3658495	et	4	main
siid	doc_491521502222_item	3658491	et	3	main
soojem	doc_491521502222_item	3658469	et	3	main
oleks	doc_491521502222_item	3658468	et	3	main
et	doc_491521502222_item	3658467	et	3	main
vähe	doc_491521502222_item	3658456	et	3	main
neid	doc_491521502222_item	3658454	et	4	main
kahjuks	doc_491521502222_item	3658453	et	4	main
aga	doc_491521502222_item	3658452	et	3	main
arvatavasti	doc_491521502222_item	3658447	et	3	main
olid	doc_491521502222_item	3658436	et	4	main
tarberiistad	doc_491521502222_item	3658435	et	3	main
soojust	doc_491521502222_item	3658427	et	4	main
andis	doc_491521502222_item	3658426	et	3	main
mõiste	doc_491521502222_item	3658345	et	4	main
2	doc_491521502222_item	3658344	et	2	main
kobrasteküttimiseks	doc_491521502222_item	3658412	et	4	main
ja	doc_491521502222_item	3658411	et	3	main
hülje-	doc_491521502222_item	3658410	et	4	main
et	doc_491521502222_item	3658409	et	3	main
teada	doc_491521502222_item	3658408	et	3	main
karusloomi	doc_491521502222_item	3658399	et	4	main
iv	doc_491521502222_item	3658371	et	4	main
lõpp	doc_491521502222_item	3658370	et	3	main
aastatuhande	doc_491521502222_item	3658369	et	4	main
hakkati	doc_491521502223_item	3658925	et	3	main
soome-ugri	doc_491521502223_item	3658899	et	3	main
nende	doc_491521502223_item	3658889	et	4	main
sarv	doc_491521502223_item	3658885	et	3	main
korjamine	doc_491521502223_item	3658874	et	4	main
pähklite	doc_491521502223_item	3658873	et	3	main
juurte	doc_491521502223_item	3658872	et	3	main
tähtis	doc_491521502223_item	3658867	et	4	main
luust	doc_491521502223_item	3658862	et	4	main
ja	doc_491521502223_item	3658849	et	3	main
aga	doc_491521502223_item	3658839	et	3	main
riist	doc_491521502223_item	3658835	et	3	main
rolli	doc_491521502223_item	3658833	et	4	main
püstkoha	doc_491521502223_item	3658800	et	4	main
puukoorte	doc_491521502223_item	3658799	et	3	main
nahkade	doc_491521502223_item	3658798	et	3	main
koonusekujulistes	doc_491521502223_item	3658791	et	4	main
inimesed	doc_491521502223_item	3658779	et	3	main
välja	doc_491521502223_item	3658770	et	4	main
kohapealseid	doc_491521502223_item	3658766	et	3	main
tööristu	doc_491521502223_item	3658763	et	4	main
vastavaid	doc_491521502223_item	3658762	et	4	main
inimesed	doc_491521502223_item	3658755	et	3	main
paremini-	doc_491521502223_item	3658754	et	4	main
valmistamiseks	doc_491521502223_item	3658740	et	4	main
nahka	doc_491521502223_item	3658738	et	4	main
oli	doc_491521502223_item	3658736	et	3	main
põhjapõder	doc_491521502223_item	3658731	et	3	main
kivipuru	doc_491521502222_item	3658564	et	4	main
savist	doc_491521502222_item	3658559	et	4	main
kiviajal	doc_491521502222_item	3658549	et	3	main
kivilihvimine	doc_491521502222_item	3658548	et	3	main
ja	doc_491521502222_item	3658547	et	3	main
saagimine	doc_491521502222_item	3658546	et	4	main
ka	doc_491521502222_item	3658542	et	3	main
tööriistu	doc_491521502222_item	3658539	et	3	main
juba	doc_491521502222_item	3658537	et	3	main
vähe	doc_491521502222_item	3658531	et	3	main
kunda	doc_491521502222_item	3658519	et	4	main
kujuneb	doc_491521502222_item	3658517	et	3	main
tead	doc_491521502222_item	3658497	et	4	main
loodusande	doc_491521502222_item	3658485	et	4	main
kohti	doc_491521502222_item	3658477	et	4	main
uued	doc_491521502222_item	3658543	et	3	main
kultuuris	doc_491521502222_item	3658556	et	3	main
narva	doc_491521502222_item	3658553	et	4	main
puurimine	doc_491521502222_item	3658545	et	4	main
veel	doc_491521502222_item	3658523	et	4	main
kultuur	doc_491521502222_item	3658520	et	3	main
välja	doc_491521502222_item	3658518	et	4	main
sel	doc_491521502222_item	3658505	et	3	main
on	doc_491521502222_item	3658496	et	4	main
otsisid	doc_491521502222_item	3658493	et	4	main
otsa	doc_491521502222_item	3658490	et	4	main
said	doc_491521502222_item	3658489	et	4	main
loodusressursid	doc_491521502222_item	3658488	et	3	main
kui	doc_491521502222_item	3658487	et	3	main
kuid	doc_491521502222_item	3658486	et	4	main
mätastega	doc_491521502222_item	3658465	et	3	main
ka	doc_491521502222_item	3658464	et	3	main
kuid	doc_491521502222_item	3658463	et	4	main
okastega	doc_491521502222_item	3658462	et	3	main
nahaga	doc_491521502222_item	3658461	et	3	main
kaetud	doc_491521502222_item	3658460	et	4	main
olid	doc_491521502222_item	3658459	et	4	main
püstkojad	doc_491521502222_item	3658458	et	3	main
säilinud	doc_491521502222_item	3658457	et	4	main
on	doc_491521502222_item	3658455	et	4	main
olid	doc_491521502222_item	3658448	et	4	main
kvartsist	doc_491521502222_item	3658446	et	4	main
kivist	doc_491521502222_item	3658440	et	4	main
savist	doc_491521502222_item	3658438	et	4	main
luust	doc_491521502222_item	3658437	et	4	main
küttimiseks	doc_491521502222_item	3658401	et	4	main
ja	doc_491521502222_item	3658400	et	3	main
aastatuhande	doc_491521502222_item	3658372	et	4	main
kvarts	doc_491521502223_item	3658948	et	2	main
taimed	doc_491521502223_item	3658944	et	3	main
keraamika	doc_491521502223_item	3658942	et	4	main
kultuur	doc_491521502223_item	3658941	et	3	main
välja	doc_491521502223_item	3658932	et	4	main
osati	doc_491521502223_item	3658931	et	3	main
lammas	doc_491521502223_item	3658930	et	3	main
kits	doc_491521502223_item	3658929	et	3	main
pidama	doc_491521502223_item	3658926	et	4	main
tuntakse	doc_491521502223_item	3658918	et	3	main
nöörkeraamika	doc_491521502223_item	3658913	et	4	main
ornamendiga	doc_491521502223_item	3658912	et	3	main
sarnaneva	doc_491521502223_item	3658911	et	4	main
vajutistega	doc_491521502223_item	3658910	et	3	main
kaunistatud	doc_491521502223_item	3658907	et	4	main
meieni	doc_491521502223_item	3658898	et	4	main
luu	doc_491521502223_item	3658884	et	4	main
muutused	doc_491521502223_item	3658883	et	4	main
seente	doc_491521502223_item	3658870	et	3	main
kasutati	doc_491521502222_item	3658512	et	4	main
ajal	doc_491521502222_item	3658506	et	4	main
kuna	doc_491521502222_item	3658504	et	3	main
tingimused	doc_491521502222_item	3658481	et	3	main
parimad	doc_491521502222_item	3658480	et	4	main
olid	doc_491521502222_item	3658479	et	4	main
kus	doc_491521502222_item	3658478	et	3	main
otsisid	doc_491521502222_item	3658475	et	4	main
esemed	doc_491521502222_item	3658450	et	3	main
leidub	doc_491521502222_item	3658442	et	3	main
a	doc_491521502222_item	3658434	et	4	main
koonusekujulistes	doc_491521502222_item	3658419	et	4	main
kogukondades	doc_491521502222_item	3658418	et	3	main
liikmestes	doc_491521502222_item	3658417	et	4	main
20-40	doc_491521502222_item	3658416	et	2	main
kultuur	doc_491521502222_item	3658347	et	3	main
arheoloogiline	doc_491521502222_item	3658346	et	4	main
kontrolltöö	doc_491521502222_item	3658339	et	4	main
on	doc_491521502222_item	3658407	et	4	main
presoliitikum	doc_491521502222_item	3658367	et	4	main
kiviaeg	doc_491521502222_item	3658366	et	3	main
graniiditükkid	doc_491521502223_item	3658949	et	2	main
kultuur	doc_491521502223_item	3658946	et	3	main
neemevi	doc_491521502223_item	3658945	et	4	main
savi	doc_491521502223_item	3658943	et	4	main
koduloomi	doc_491521502223_item	3658927	et	4	main
kaunistatud	doc_491521502223_item	3658923	et	4	main
vahendiks	doc_491521502223_item	3658921	et	3	main
seda	doc_491521502223_item	3658919	et	3	main
järgi	doc_491521502223_item	3658917	et	4	main
kirvete	doc_491521502223_item	3658916	et	4	main
eesnevatest	doc_491521502223_item	3658904	et	4	main
on	doc_491521502223_item	3658903	et	4	main
nõud	doc_491521502223_item	3658902	et	3	main
need	doc_491521502223_item	3658901	et	3	main
kammkeraamika	doc_491521502223_item	3658895	et	4	main
kivilihvimine	doc_491521502223_item	3658894	et	3	main
erinevad	doc_491521502223_item	3658890	et	4	main
laemalt	doc_491521502223_item	3658887	et	4	main
sel	doc_491521502223_item	3658881	et	3	main
kasutusele	doc_491521502223_item	3658879	et	4	main
võeti	doc_491521502223_item	3658878	et	3	main
neoliitikumis	doc_491521502223_item	3658877	et	3	main
savinõud	doc_491521502223_item	3658876	et	3	main
mitmesuguste	doc_491521502223_item	3658868	et	3	main
kiviajal	doc_491521502223_item	3658865	et	3	main
puust	doc_491521502223_item	3658864	et	4	main
õngekonksud	doc_491521502223_item	3658845	et	3	main
luust	doc_491521502223_item	3658844	et	4	main
pealt	doc_491521502223_item	3658795	et	4	main
ehitatud	doc_491521502223_item	3658790	et	4	main
kallastel	doc_491521502223_item	3658786	et	4	main
paremini	doc_491521502223_item	3658761	et	4	main
läks	doc_491521502223_item	3658753	et	3	main
sarvi	doc_491521502223_item	3658744	et	4	main
katmiseks	doc_491521502223_item	3658743	et	4	main
oli	doc_491521502223_item	3658732	et	3	main
nad	doc_491521502223_item	3658728	et	3	main
kala	doc_491521502223_item	3658726	et	4	main
taandudes	doc_491521502223_item	3658717	et	3	main
tööriiste	doc_491521502223_item	3658715	et	3	main
leiti	doc_491521502223_item	3658713	et	3	main
juures	doc_491521502223_item	3658712	et	4	main
sest	doc_491521502223_item	3658703	et	4	main
leida	doc_491521502223_item	3658702	et	3	main
raske	doc_491521502223_item	3658701	et	4	main
ole	doc_491521502223_item	3658696	et	4	main
ei	doc_491521502223_item	3658695	et	4	main
peatuspaiku	doc_491521502223_item	3658694	et	3	main
poleoliitikume	doc_491521502223_item	3658691	et	4	main
eestist	doc_491521502223_item	3658689	et	3	main
selle	doc_491521502223_item	3658680	et	4	main
leedus	doc_491521502223_item	3658674	et	4	main
ekr	doc_491521502223_item	3658672	et	4	main
tähendus	doc_491521502223_item	3658667	et	4	main
kultuur	doc_491521502223_item	3658666	et	3	main
olid	doc_491521502229_item	3659091	et	4	main
oma	doc_491521502229_item	3659087	et	4	main
ka	doc_491521502229_item	3659081	et	3	main
ühiskond	doc_491521502229_item	3659060	et	3	main
patriarhaarne	doc_491521502229_item	3659059	et	4	main
teada	doc_491521502222_item	3658471	et	3	main
on	doc_491521502222_item	3658470	et	4	main
talveti	doc_491521502222_item	3658466	et	4	main
puust	doc_491521502222_item	3658451	et	4	main
ja	doc_491521502222_item	3658445	et	3	main
samuti	doc_491521502222_item	3658443	et	3	main
mis	doc_491521502222_item	3658425	et	4	main
asus	doc_491521502222_item	3658423	et	4	main
territooriumil	doc_491521502222_item	3658343	et	3	main
eesti	doc_491521502222_item	3658342	et	4	main
1	doc_491521502222_item	3658340	et	2	main
elati	doc_491521502222_item	3658415	et	3	main
kuid	doc_491521502222_item	3658406	et	4	main
viii	doc_491521502222_item	3658368	et	4	main
ka	doc_491521502222_item	3658449	et	3	main
tulekivist	doc_491521502222_item	3658444	et	4	main
kuid	doc_491521502222_item	3658441	et	4	main
ja	doc_491521502222_item	3658439	et	3	main
töö-	doc_491521502222_item	3658433	et	4	main
söögi	doc_491521502222_item	3658432	et	4	main
küpsetati	doc_491521502222_item	3658431	et	3	main
samuti	doc_491521502222_item	3658430	et	3	main
valgust	doc_491521502222_item	3658429	et	4	main
ja	doc_491521502222_item	3658428	et	3	main
kolle	doc_491521502222_item	3658424	et	4	main
keskel	doc_491521502222_item	3658422	et	3	main
mille	doc_491521502222_item	3658421	et	3	main
püstkodades	doc_491521502222_item	3658420	et	3	main
kiviaeg	doc_491521502222_item	3658341	et	3	main
harpuunid	doc_491521502222_item	3658414	et	4	main
olid	doc_491521502222_item	3658413	et	4	main
torkeodadega	doc_491521502222_item	3658405	et	3	main
ja	doc_491521502222_item	3658404	et	3	main
viske-	doc_491521502222_item	3658403	et	3	main
peamiselt	doc_491521502222_item	3658402	et	4	main
põtru	doc_491521502222_item	3658398	et	3	main
kütiti	doc_491521502222_item	3658397	et	3	main
võrguid	doc_491521502222_item	3658396	et	4	main
algeliseid	doc_491521502222_item	3658395	et	4	main
ja	doc_491521502222_item	3658394	et	3	main
õngekonksuid	doc_491521502222_item	3658393	et	4	main
ahingut	doc_491521502222_item	3658392	et	3	main
luust	doc_491521502222_item	3658391	et	4	main
kasutati	doc_491521502222_item	3658390	et	4	main
kalapüügiks	doc_491521502222_item	3658389	et	3	main
marju	doc_491521502222_item	3658388	et	3	main
ja	doc_491521502222_item	3658387	et	3	main
juurikaid	doc_491521502222_item	3658386	et	4	main
söödavaid	doc_491521502222_item	3658385	et	4	main
pähkleid	doc_491521502222_item	3658384	et	3	main
seene	doc_491521502222_item	3658383	et	3	main
korjati	doc_491521502222_item	3658382	et	3	main
korjamisega	doc_491521502222_item	3658381	et	4	main
loodusandide	doc_491521502222_item	3658380	et	3	main
ja	doc_491521502222_item	3658379	et	3	main
kalapüügi	doc_491521502222_item	3658378	et	4	main
küttimise	doc_491521502222_item	3658377	et	4	main
tegelesid	doc_491521502222_item	3658376	et	4	main
inimesed	doc_491521502222_item	3658375	et	3	main
ekr	doc_491521502222_item	3658374	et	4	main
keskpaik	doc_491521502222_item	3658373	et	3	main
keskmine	doc_491521502222_item	3658365	et	3	main
ekr	doc_491521502222_item	3658364	et	4	main
saj	doc_491521502222_item	3658363	et	4	main
viii	doc_491521502222_item	3658362	et	4	main
pullis	doc_491521502222_item	3658361	et	4	main
ääres	doc_491521502222_item	3658360	et	4	main
pärnu	doc_491521502222_item	3658359	et	4	main
leitud	doc_491521502222_item	3658358	et	4	main
asula	doc_491521502222_item	3658357	et	4	main
vanim	doc_491521502222_item	3658356	et	3	main
ekr	doc_491521502222_item	3658355	et	4	main
saj	doc_491521502222_item	3658354	et	4	main
viii	doc_491521502222_item	3658353	et	4	main
paleoliitikum	doc_491521502222_item	3658352	et	3	main
kiviaeg	doc_491521502222_item	3658351	et	3	main
vanem	doc_491521502222_item	3658350	et	4	main
kiviaeg	doc_491521502222_item	3658349	et	3	main
tähendus	doc_491521502222_item	3658348	et	4	main
savi	doc_491521502223_item	3658947	et	4	main
kivist	doc_491521502223_item	3658939	et	4	main
ja	doc_491521502223_item	3658938	et	3	main
luust	doc_491521502223_item	3658937	et	4	main
kultuur	doc_491521502223_item	3658936	et	3	main
kunda	doc_491521502223_item	3658935	et	4	main
2	doc_491521502223_item	3658934	et	2	main
kasvatada	doc_491521502223_item	3658933	et	3	main
keraamikatüüp	doc_491521502223_item	3658924	et	4	main
nöörivajutistega	doc_491521502223_item	3658922	et	3	main
kultuuri	doc_491521502223_item	3658920	et	4	main
paati	doc_491521502223_item	3658914	et	4	main
üleni	doc_491521502223_item	3658908	et	3	main
ja	doc_491521502223_item	3658906	et	3	main
hõimud	doc_491521502223_item	3658900	et	4	main
puurimine	doc_491521502223_item	3658893	et	4	main
saagimine	doc_491521502223_item	3658892	et	4	main
levisid	doc_491521502223_item	3658888	et	4	main
kiviesemed	doc_491521502223_item	3658886	et	3	main
keraamika	doc_491521502223_item	3658875	et	4	main
vibu	doc_491521502223_item	3658856	et	4	main
torkeodadega	doc_491521502223_item	3658855	et	3	main
kui	doc_491521502223_item	3658854	et	3	main
metsloomi	doc_491521502223_item	3658848	et	4	main
kasutusele	doc_491521502223_item	3658842	et	4	main
tulid	doc_491521502223_item	3658841	et	4	main
luust	doc_491521502223_item	3658837	et	4	main
okste	doc_491521502223_item	3658797	et	3	main
kaetud	doc_491521502223_item	3658796	et	4	main
kiviaja	doc_491521502223_item	3658775	et	3	main
vaimne	doc_491521502223_item	3658773	et	3	main
nii	doc_491521502223_item	3658768	et	3	main
kõige	doc_491521502223_item	3658760	et	4	main
oludele	doc_491521502223_item	3658759	et	3	main
kliima	doc_491521502223_item	3658750	et	4	main
noorem	doc_491521502223_item	3658747	et	4	main
tegemiseks	doc_491521502223_item	3658746	et	4	main
tarberiistade	doc_491521502223_item	3658745	et	3	main
ja	doc_491521502223_item	3658741	et	3	main
söök	doc_491521502223_item	3658737	et	3	main
saak	doc_491521502223_item	3658734	et	3	main
püüdsid	doc_491521502223_item	3658725	et	4	main
küttisid	doc_491521502223_item	3658724	et	4	main
poole	doc_491521502223_item	3658720	et	4	main
liikusid	doc_491521502223_item	3658718	et	4	main
narva	doc_491521502223_item	3658940	et	4	main
siga	doc_491521502223_item	3658928	et	4	main
meenutavate	doc_491521502223_item	3658915	et	4	main
kammi	doc_491521502223_item	3658909	et	4	main
kvaliteetsemad	doc_491521502223_item	3658905	et	4	main
tõid	doc_491521502223_item	3658897	et	4	main
kultuuri	doc_491521502223_item	3658896	et	4	main
valmistamisvõtted	doc_491521502223_item	3658891	et	3	main
ajajargu	doc_491521502223_item	3658882	et	4	main
keraamika	doc_491521502223_item	3658880	et	4	main
töödavate	doc_491521502223_item	3658871	et	4	main
marjade	doc_491521502223_item	3658869	et	3	main
oli	doc_491521502223_item	3658866	et	3	main
sarvast	doc_491521502223_item	3658863	et	3	main
kivist	doc_491521502223_item	3658861	et	4	main
tehti	doc_491521502223_item	3658860	et	3	main
riistad	doc_491521502223_item	3658859	et	3	main
nooltega	doc_491521502223_item	3658858	et	3	main
ja	doc_491521502223_item	3658857	et	3	main
viske	doc_491521502223_item	3658853	et	3	main
nii	doc_491521502223_item	3658852	et	3	main
kütiti	doc_491521502223_item	3658851	et	3	main
linde	doc_491521502223_item	3658850	et	4	main
hiljem	doc_491521502223_item	3658840	et	3	main
oli	doc_491521502223_item	3658836	et	3	main
kalapüük	doc_491521502223_item	3658834	et	3	main
ritvadest	doc_491521502223_item	3658789	et	3	main
tavaliselt	doc_491521502223_item	3658787	et	4	main
järvede	doc_491521502223_item	3658785	et	3	main
või	doc_491521502223_item	3658784	et	4	main
jõgede	doc_491521502223_item	3658783	et	3	main
paiknesid	doc_491521502223_item	3658782	et	4	main
kultuur	doc_491521502223_item	3658774	et	3	main
materiaalne	doc_491521502223_item	3658771	et	3	main
kujunes	doc_491521502223_item	3658769	et	3	main
materjale	doc_491521502223_item	3658767	et	3	main
selleks	doc_491521502223_item	3658765	et	4	main
kohalikele	doc_491521502223_item	3658758	et	3	main
valmistama	doc_491521502223_item	3658757	et	3	main
õppisid	doc_491521502223_item	3658756	et	4	main
ja	doc_491521502223_item	3658751	et	3	main
neoliitikum	doc_491521502223_item	3658749	et	3	main
püstkodade	doc_491521502223_item	3658742	et	3	main
liha	doc_491521502223_item	3658735	et	4	main
küttisid	doc_491521502223_item	3658729	et	4	main
elanikud	doc_491521502223_item	3658723	et	3	main
ikka	doc_491521502223_item	3658710	et	4	main
liikuva	doc_491521502223_item	3658707	et	4	main
suhteliselt	doc_491521502223_item	3658706	et	4	main
on	doc_491521502223_item	3658700	et	4	main
asulakoha	doc_491521502223_item	3658682	et	4	main
avastatud	doc_491521502223_item	3658676	et	4	main
on	doc_491521502223_item	3658675	et	4	main
puust	doc_491521502229_item	3659083	et	4	main
aga	doc_491521502229_item	3659080	et	3	main
tehtudpronksist	doc_491521502229_item	3659078	et	4	main
tööriistad	doc_491521502229_item	3659076	et	3	main
küttimine	doc_491521502229_item	3659073	et	4	main
tegevusega	doc_491521502229_item	3659071	et	4	main
iseloomuliku	doc_491521502229_item	3659070	et	3	main
kiviajale	doc_491521502229_item	3659069	et	3	main
ka	doc_491521502229_item	3659068	et	3	main
kui	doc_491521502229_item	3659067	et	3	main
loomakasvatusega	doc_491521502229_item	3659066	et	3	main
tegeldi	doc_491521502229_item	3659065	et	3	main
roll	doc_491521502229_item	3659064	et	3	main
tähtsam	doc_491521502229_item	3659063	et	4	main
oli	doc_491521502229_item	3659062	et	3	main
mehe	doc_491521502229_item	3659061	et	3	main
tol	doc_491521502229_item	3659055	et	3	main
künnipõlendus	doc_491521502229_item	3659054	et	4	main
tekkis	doc_491521502229_item	3659052	et	3	main
mindi	doc_491521502229_item	3659049	et	3	main
rahvaste	doc_491521502229_item	3659043	et	4	main
või	doc_491521502229_item	3659039	et	4	main
pronksi	doc_491521502229_item	3659032	et	4	main
kasutama	doc_491521502229_item	3659031	et	3	main
võrgud	doc_491521502223_item	3658847	et	3	main
ja	doc_491521502223_item	3658846	et	3	main
ka	doc_491521502223_item	3658843	et	3	main
ahing	doc_491521502223_item	3658838	et	3	main
olid	doc_491521502223_item	3658794	et	4	main
mis	doc_491521502223_item	3658793	et	4	main
püstkodades	doc_491521502223_item	3658792	et	3	main
elati	doc_491521502223_item	3658788	et	3	main
mis	doc_491521502223_item	3658781	et	4	main
asulates	doc_491521502223_item	3658780	et	4	main
20-40	doc_491521502223_item	3658778	et	2	main
elasid	doc_491521502223_item	3658777	et	4	main
asukad	doc_491521502223_item	3658776	et	3	main
ja	doc_491521502223_item	3658772	et	3	main
kasutades	doc_491521502223_item	3658764	et	3	main
loodusolude	doc_491521502223_item	3658752	et	3	main
kiviaeg	doc_491521502223_item	3658748	et	3	main
rõivaste	doc_491521502223_item	3658739	et	4	main
hea	doc_491521502223_item	3658733	et	4	main
põhjapõdru	doc_491521502223_item	3658730	et	4	main
korjasid	doc_491521502223_item	3658727	et	4	main
esimesed	doc_491521502223_item	3658722	et	3	main
põhja	doc_491521502223_item	3658719	et	4	main
salgad	doc_491521502223_item	3658721	et	4	main
olid	doc_491521502223_item	3658705	et	4	main
inimesed	doc_491521502223_item	3658704	et	3	main
avastatud	doc_491521502223_item	3658698	et	4	main
leedus	doc_491521502223_item	3658686	et	4	main
et	doc_491521502223_item	3658685	et	3	main
näitab	doc_491521502223_item	3658684	et	3	main
leiumaterjal	doc_491521502223_item	3658683	et	3	main
algus	doc_491521502223_item	3658671	et	4	main
mandrijää	doc_491521502223_item	3658716	et	4	main
palju	doc_491521502223_item	3658714	et	4	main
põllu	doc_491521502223_item	3658711	et	3	main
eluviisiga	doc_491521502223_item	3658708	et	4	main
neid	doc_491521502223_item	3658699	et	4	main
põhjapõdraküttide	doc_491521502223_item	3658693	et	3	main
ajajargu	doc_491521502223_item	3658681	et	4	main
ast	doc_491521502223_item	3658670	et	3	main
viii	doc_491521502223_item	3658669	et	4	main
1	doc_491521502223_item	3658668	et	2	main
1	doc_491521502223_item	3658659	et	2	main
kontrolltöö	doc_491521502223_item	3658658	et	4	main
tähtsat	doc_491521502223_item	3658832	et	3	main
etendas	doc_491521502223_item	3658831	et	3	main
neoliitikumis	doc_491521502223_item	3658830	et	3	main
keraamika	doc_491521502223_item	3658829	et	4	main
oli	doc_491521502223_item	3658828	et	3	main
tahtsaks	doc_491521502223_item	3658826	et	4	main
uuenduseks	doc_491521502223_item	3658827	et	4	main
kivikõrveid	doc_491521502223_item	3658825	et	4	main
ka	doc_491521502223_item	3658824	et	3	main
valimistati	doc_491521502223_item	3658823	et	3	main
kivist	doc_491521502223_item	3658822	et	4	main
sarvest	doc_491521502223_item	3658821	et	4	main
luust	doc_491521502223_item	3658820	et	4	main
valmistatud	doc_491521502223_item	3658819	et	4	main
oli	doc_491521502223_item	3658818	et	3	main
erberiistu	doc_491521502223_item	3658817	et	4	main
ja	doc_491521502223_item	3658816	et	3	main
töö	doc_491521502223_item	3658815	et	4	main
osa	doc_491521502223_item	3658814	et	4	main
suur	doc_491521502223_item	3658813	et	3	main
toitu	doc_491521502223_item	3658812	et	4	main
küpsetati	doc_491521502223_item	3658811	et	3	main
ka	doc_491521502223_item	3658810	et	3	main
millel	doc_491521502223_item	3658809	et	3	main
soojust	doc_491521502223_item	3658808	et	4	main
ja	doc_491521502223_item	3658807	et	3	main
valgust	doc_491521502223_item	3658806	et	4	main
andis	doc_491521502223_item	3658805	et	3	main
mis	doc_491521502223_item	3658804	et	4	main
kolle	doc_491521502223_item	3658803	et	4	main
asub	doc_491521502223_item	3658802	et	3	main
keskes	doc_491521502223_item	3658801	et	4	main
viimistletud	doc_491521502229_item	3659095	et	4	main
kogemust	doc_491521502229_item	3659089	et	3	main
inimesed	doc_491521502229_item	3659085	et	3	main
osaliselt	doc_491521502229_item	3659079	et	4	main
olid	doc_491521502229_item	3659077	et	4	main
aga	doc_491521502223_item	3658709	et	3	main
veel	doc_491521502223_item	3658697	et	4	main
kuuluvad	doc_491521502223_item	3658692	et	4	main
poole	doc_491521502223_item	3658690	et	4	main
inimesi	doc_491521502223_item	3658688	et	4	main
saabus	doc_491521502223_item	3658687	et	3	main
saja	doc_491521502223_item	3658679	et	4	main
üle	doc_491521502223_item	3658678	et	3	main
juba	doc_491521502223_item	3658677	et	3	main
vanakiviaeg	doc_491521502223_item	3658673	et	3	main
arheoloogiline	doc_491521502223_item	3658665	et	4	main
mõiste	doc_491521502223_item	3658664	et	4	main
2	doc_491521502223_item	3658663	et	2	main
territooriumil	doc_491521502223_item	3658662	et	3	main
eesti	doc_491521502223_item	3658661	et	4	main
kiviaeg	doc_491521502223_item	3658660	et	3	main
paremini	doc_491521502229_item	3659094	et	4	main
ja	doc_491521502229_item	3659093	et	3	main
tugevamad	doc_491521502229_item	3659092	et	4	main
esivanemate	doc_491521502229_item	3659088	et	4	main
kasutasid	doc_491521502229_item	3659086	et	4	main
kivist	doc_491521502229_item	3659082	et	4	main
koristamine	doc_491521502229_item	3659075	et	4	main
oli	doc_491521502229_item	3659057	et	3	main
kätte	doc_491521502229_item	3659038	et	4	main
skandinaaviast	doc_491521502229_item	3659037	et	3	main
arvatavasti	doc_491521502229_item	3659036	et	3	main
aja	doc_491521502229_item	3659014	et	4	main
uskumused	doc_491521502229_item	3659298	et	3	main
süsteemid	doc_491521502229_item	3659297	et	3	main
totemistlik	doc_491521502229_item	3659296	et	3	main
ja	doc_491521502229_item	3659295	et	3	main
animalistlik	doc_491521502229_item	3659294	et	4	main
oli	doc_491521502229_item	3659293	et	3	main
asjadel	doc_491521502229_item	3659292	et	3	main
loodusel	doc_491521502229_item	3659291	et	4	main
elulisel	doc_491521502229_item	3659290	et	4	main
kui	doc_491521502229_item	3659289	et	3	main
eluta	doc_491521502229_item	3659288	et	3	main
nii	doc_491521502229_item	3659287	et	3	main
kõikjal	doc_491521502229_item	3659286	et	3	main
on	doc_491521502229_item	3659285	et	4	main
hing	doc_491521502229_item	3659284	et	3	main
et	doc_491521502229_item	3659283	et	3	main
arvasid	doc_491521502229_item	3659282	et	4	main
inimesed	doc_491521502229_item	3659281	et	3	main
järgi	doc_491521502229_item	3659280	et	4	main
selle	doc_491521502229_item	3659279	et	4	main
süsteem	doc_491521502229_item	3659278	et	3	main
uskumuste	doc_491521502229_item	3659277	et	4	main
iseloomulik	doc_491521502229_item	3659276	et	3	main
muinasajale	doc_491521502229_item	3659275	et	3	main
üldse	doc_491521502229_item	3659274	et	3	main
ja	doc_491521502229_item	3659273	et	3	main
kiviajale	doc_491521502229_item	3659272	et	3	main
käsikivi	doc_491521502229_item	3659102	et	4	main
ka	doc_491521502229_item	3659101	et	3	main
aga	doc_491521502229_item	3659100	et	3	main
sirp	doc_491521502229_item	3659099	et	3	main
kõblas	doc_491521502229_item	3659098	et	3	main
olid	doc_491521502229_item	3659097	et	4	main
uued	doc_491521502229_item	3659096	et	3	main
tööriistad	doc_491521502229_item	3659090	et	3	main
luust	doc_491521502229_item	3659084	et	4	main
kalandus	doc_491521502229_item	3659074	et	3	main
nagu	doc_491521502229_item	3659072	et	3	main
perioodil	doc_491521502229_item	3659056	et	3	main
viljelusmajandusele	doc_491521502229_item	3659051	et	3	main
annastavalt	doc_491521502229_item	3659047	et	4	main
mindi	doc_491521502229_item	3659045	et	3	main
neile	doc_491521502229_item	3659035	et	4	main
hakkasid	doc_491521502229_item	3659030	et	4	main
inimesed	doc_491521502229_item	3659029	et	3	main
pronksiajal	doc_491521502229_item	3659028	et	3	main
toimunud	doc_491521502229_item	3659027	et	4	main
ei	doc_491521502229_item	3659026	et	4	main
muutusi	doc_491521502229_item	3659025	et	4	main
suuri	doc_491521502229_item	3659024	et	3	main
sest	doc_491521502229_item	3659023	et	4	main
teha	doc_491521502229_item	3659022	et	3	main
piiri	doc_491521502229_item	3659021	et	4	main
jooni	doc_491521502229_item	3659020	et	4	main
kindlat	doc_491521502229_item	3659019	et	3	main
raske	doc_491521502229_item	3659018	et	4	main
üsna	doc_491521502229_item	3659017	et	3	main
on	doc_491521502229_item	3659016	et	4	main
vahel	doc_491521502229_item	3659015	et	4	main
aja	doc_491521502229_item	3659007	et	4	main
mida	doc_491521502229_item	3659003	et	4	main
kuni	doc_491521502229_item	3658998	et	3	main
kr	doc_491521502229_item	3658993	et	4	main
pronksiaeg	doc_491521502229_item	3658985	et	3	main
13	doc_491521502229_item	3658980	et	2	main
muistse	doc_491521502229_item	3658977	et	3	main
eesti	doc_491521502229_item	3658974	et	4	main
ekr	doc_491521502229_item	3658973	et	4	main
8000	doc_491521502229_item	3658972	et	2	main
rohkem	doc_491521502229_item	3659249	et	4	main
andis	doc_491521502229_item	3659247	et	3	main
metalli	doc_491521502229_item	3659245	et	4	main
käigul	doc_491521502229_item	3659244	et	3	main
seega	doc_491521502229_item	3659228	et	4	main
rauaajaga	doc_491521502229_item	3659227	et	3	main
keskmise	doc_491521502229_item	3659226	et	3	main
kaubandus	doc_491521502229_item	3659203	et	3	main
tekkima	doc_491521502229_item	3659202	et	3	main
inimeste	doc_491521502229_item	3659200	et	3	main
elanikud	doc_491521502229_item	3659142	et	3	main
e	doc_491521502229_item	3659137	et	4	main
ekr	doc_491521502229_item	3659122	et	4	main
rääkida	doc_491521502229_item	3659115	et	3	main
maaveljelus	doc_491521502229_item	3659113	et	4	main
ekr	doc_491521502229_item	3659110	et	4	main
aladel	doc_491521502229_item	3659104	et	3	main
juba	doc_491521502229_item	3659058	et	3	main
alepõlendus	doc_491521502229_item	3659053	et	4	main
üle	doc_491521502229_item	3659050	et	3	main
kaudu	doc_491521502229_item	3659044	et	3	main
volga	doc_491521502229_item	3659042	et	4	main
variant	doc_491521502229_item	3659041	et	3	main
teine	doc_491521502229_item	3659040	et	3	main
mis	doc_491521502229_item	3659033	et	4	main
tegelikult	doc_491521502229_item	3659009	et	4	main
kr	doc_491521502229_item	3659002	et	4	main
kestis	doc_491521502229_item	3658997	et	4	main
pronksiaeg	doc_491521502229_item	3658995	et	3	main
rauaaeg	doc_491521502229_item	3658987	et	3	main
ja	doc_491521502229_item	3658986	et	3	main
saabumisest	doc_491521502229_item	3658971	et	4	main
inimeste	doc_491521502229_item	3658970	et	3	main
esimesest	doc_491521502229_item	3658969	et	3	main
algab	doc_491521502229_item	3658968	et	3	main
võimalusi	doc_491521502229_item	3659250	et	3	main
inimkonnale	doc_491521502229_item	3659248	et	4	main
rauaajal	doc_491521502229_item	3659240	et	3	main
algusel	doc_491521502229_item	3659234	et	4	main
metalliaja	doc_491521502229_item	3659233	et	3	main
enam	doc_491521502229_item	3659221	et	4	main
algusesse	doc_491521502229_item	3659213	et	4	main
juba	doc_491521502229_item	3659198	et	3	main
metalliajal	doc_491521502229_item	3659197	et	3	main
varasel	doc_491521502229_item	3659196	et	4	main
väga	doc_491521502229_item	3659185	et	3	main
elatusala	doc_491521502229_item	3659150	et	4	main
peamine	doc_491521502229_item	3659149	et	3	main
sulata	doc_491521502229_item	3659148	et	4	main
rauda	doc_491521502229_item	3659147	et	4	main
majanduselt	doc_491521502229_item	3659048	et	4	main
üle	doc_491521502229_item	3659046	et	3	main
tuli	doc_491521502229_item	3659034	et	4	main
varase	doc_491521502229_item	3659012	et	4	main
ja	doc_491521502229_item	3659011	et	3	main
pronksi	doc_491521502229_item	3659010	et	4	main
e	doc_491521502229_item	3659001	et	4	main
kiviaja	doc_491521502229_item	3658989	et	3	main
pärast	doc_491521502229_item	3658988	et	4	main
kiviaeg	doc_491521502229_item	3658984	et	3	main
kaotuseni	doc_491521502229_item	3658979	et	4	main
kuni	doc_491521502229_item	3658976	et	3	main
mis	doc_491521502229_item	3658967	et	4	main
metalli	doc_491521502229_item	3659013	et	4	main
metalli	doc_491521502229_item	3659006	et	4	main
varase	doc_491521502229_item	3659005	et	4	main
saj	doc_491521502229_item	3659000	et	4	main
lõppu	doc_491521502229_item	3658990	et	4	main
olemas	doc_491521502229_item	3658983	et	4	main
sajandil	doc_491521502229_item	3658981	et	3	main
vabaduse	doc_491521502229_item	3658978	et	4	main
aladele	doc_491521502229_item	3658975	et	3	main
ajajärku	doc_491521502229_item	3658966	et	4	main
nimetatakse	doc_491521502229_item	3658965	et	3	main
ajaks	doc_491521502229_item	3658964	et	4	main
muistseks	doc_491521502229_item	3658963	et	3	main
eestis	doc_491521502229_item	3658962	et	3	main
1	doc_491521502229_item	3658961	et	2	main
tähendus	doc_491521502229_item	3658960	et	4	main
animism	doc_491521502229_item	3658959	et	3	main
mõiste	doc_491521502229_item	3658958	et	4	main
2	doc_491521502229_item	3658957	et	2	main
territooriumil	doc_491521502229_item	3658956	et	3	main
eesti	doc_491521502229_item	3658955	et	4	main
metalliaeg	doc_491521502229_item	3658954	et	3	main
varane	doc_491521502229_item	3658953	et	4	main
1	doc_491521502229_item	3658952	et	2	main
kontrolltöö	doc_491521502229_item	3658951	et	4	main
animism	doc_491521502229_item	3659271	et	3	main
2	doc_491521502229_item	3659270	et	2	main
ajaloos	doc_491521502229_item	3659269	et	4	main
maailma	doc_491521502229_item	3659268	et	4	main
lüli	doc_491521502229_item	3659267	et	4	main
tähtis	doc_491521502229_item	3659266	et	4	main
on	doc_491521502229_item	3659265	et	4	main
metalliaeg	doc_491521502229_item	3659264	et	3	main
arengule	doc_491521502229_item	3659263	et	3	main
kultuuride	doc_491521502229_item	3659262	et	3	main
inimkonna	doc_491521502229_item	3659261	et	4	main
kiiruse	doc_491521502229_item	3659260	et	4	main
andis	doc_491521502229_item	3659259	et	3	main
kasutuselevõtt	doc_491521502229_item	3659258	et	3	main
metalli	doc_491521502229_item	3659257	et	4	main
ja	doc_491521502229_item	3659256	et	3	main
elu	doc_491521502229_item	3659255	et	4	main
määral	doc_491521502229_item	3659254	et	3	main
mingil	doc_491521502229_item	3659253	et	4	main
kergendas	doc_491521502229_item	3659252	et	3	main
ja	doc_491521502229_item	3659251	et	3	main
kasutuselevõtt	doc_491521502229_item	3659246	et	3	main
ajaloo	doc_491521502229_item	3659243	et	4	main
varasel	doc_491521502229_item	3659239	et	4	main
pronksi	doc_491521502229_item	3659237	et	4	main
aluseks	doc_491521502229_item	3659008	et	4	main
nimetatakse	doc_491521502229_item	3659004	et	3	main
6	doc_491521502229_item	3658999	et	2	main
mis	doc_491521502229_item	3658996	et	4	main
algas	doc_491521502229_item	3658994	et	3	main
e	doc_491521502229_item	3658992	et	4	main
2000	doc_491521502229_item	3658991	et	2	main
on	doc_491521502229_item	3658982	et	4	main
murrang	doc_491521502229_item	3659242	et	3	main
ja	doc_491521502229_item	3659238	et	3	main
päiksed	doc_491521502229_item	3659223	et	3	main
metalliajal	doc_491521502229_item	3659220	et	3	main
olid	doc_491521502229_item	3659218	et	4	main
inimesed	doc_491521502229_item	3659217	et	3	main
ajale	doc_491521502229_item	3659216	et	3	main
vikingi	doc_491521502229_item	3659215	et	4	main
kuuluva	doc_491521502229_item	3659214	et	4	main
sai	doc_491521502229_item	3659205	et	4	main
muutusid	doc_491521502229_item	3659195	et	4	main
igapäevane	doc_491521502229_item	3659190	et	4	main
huvitav	doc_491521502229_item	3659186	et	4	main
jooksul	doc_491521502229_item	3659183	et	4	main
ise	doc_491521502229_item	3659145	et	4	main
saj	doc_491521502229_item	3659136	et	4	main
varane	doc_491521502229_item	3659133	et	4	main
oli	doc_491521502229_item	3659131	et	3	main
mille	doc_491521502229_item	3659130	et	3	main
ring	doc_491521502229_item	3659129	et	3	main
suurematest	doc_491521502229_item	3659126	et	4	main
kivikirstkalmed	doc_491521502229_item	3659125	et	4	main
maapealsed	doc_491521502229_item	3659124	et	3	main
perioodil	doc_491521502229_item	3659118	et	3	main
ei	doc_491521502229_item	3659107	et	4	main
toimus	doc_491521502229_item	3659241	et	3	main
näiteks	doc_491521502229_item	3659225	et	4	main
võrreldes	doc_491521502229_item	3659224	et	3	main
rauaaja	doc_491521502229_item	3659212	et	3	main
noorema	doc_491521502229_item	3659211	et	4	main
ja	doc_491521502229_item	3659210	et	3	main
rauaajale	doc_491521502229_item	3659209	et	3	main
rooma	doc_491521502229_item	3659208	et	4	main
jooneks	doc_491521502229_item	3659207	et	3	main
iseloomulikuks	doc_491521502229_item	3659206	et	3	main
hakkasid	doc_491521502229_item	3659199	et	4	main
elu	doc_491521502229_item	3659191	et	4	main
inimeste	doc_491521502229_item	3659189	et	3	main
jälgida	doc_491521502229_item	3659187	et	3	main
on	doc_491521502229_item	3659184	et	4	main
arengu	doc_491521502229_item	3659182	et	3	main
ajaloo	doc_491521502229_item	3659181	et	4	main
määral	doc_491521502229_item	3659180	et	3	main
suurel	doc_491521502229_item	3659179	et	3	main
elu	doc_491521502229_item	3659178	et	4	main
inimeste	doc_491521502229_item	3659177	et	3	main
mõjutas	doc_491521502229_item	3659176	et	3	main
kasutuselevõtt	doc_491521502229_item	3659175	et	3	main
rauda	doc_491521502229_item	3659174	et	4	main
rauast	doc_491521502229_item	3659173	et	4	main
pronksist	doc_491521502229_item	3659172	et	4	main
luust	doc_491521502229_item	3659171	et	4	main
puust	doc_491521502229_item	3659170	et	4	main
nii	doc_491521502229_item	3659169	et	3	main
tehti	doc_491521502229_item	3659168	et	3	main
tööriistad	doc_491521502229_item	3659167	et	3	main
muinaslinnused	doc_491521502229_item	3659166	et	3	main
linnused	doc_491521502229_item	3659165	et	3	main
tekkima	doc_491521502229_item	3659164	et	3	main
hakkasid	doc_491521502229_item	3659163	et	4	main
saj	doc_491521502229_item	3659162	et	4	main
14	doc_491521502229_item	3659161	et	2	main
ainult	doc_491521502229_item	3659160	et	4	main
loobuti	doc_491521502229_item	3659159	et	3	main
söömisest	doc_491521502229_item	3659158	et	4	main
mille	doc_491521502229_item	3659157	et	3	main
hobused	doc_491521502229_item	3659156	et	4	main
sead	doc_491521502229_item	3659155	et	4	main
lambad	doc_491521502229_item	3659154	et	3	main
veised	doc_491521502229_item	3659153	et	3	main
koduloomapidamine	doc_491521502229_item	3659152	et	3	main
oli	doc_491521502229_item	3659151	et	3	main
püüdsid	doc_491521502229_item	3659143	et	4	main
1	doc_491521502229_item	3659139	et	2	main
tähendab	doc_491521502229_item	3659236	et	3	main
see	doc_491521502229_item	3659235	et	3	main
et	doc_491521502229_item	3659232	et	3	main
öelda	doc_491521502229_item	3659231	et	4	main
võib	doc_491521502229_item	3659230	et	3	main
kokkuvõtteks	doc_491521502229_item	3659229	et	3	main
vähem	doc_491521502229_item	3659222	et	4	main
varasel	doc_491521502229_item	3659219	et	4	main
mis	doc_491521502229_item	3659204	et	4	main
elus	doc_491521502229_item	3659201	et	4	main
kultuur	doc_491521502229_item	3659194	et	3	main
ja	doc_491521502229_item	3659193	et	3	main
maailmavaated	doc_491521502229_item	3659192	et	3	main
kuidas	doc_491521502229_item	3659188	et	3	main
soomaagist	doc_491521502229_item	3659146	et	4	main
siinsed	doc_491521502229_item	3659141	et	3	main
kr	doc_491521502229_item	3659138	et	4	main
olid	doc_491521502229_item	3659123	et	4	main
ekr	doc_491521502229_item	3659120	et	4	main
matmiskommetest	doc_491521502229_item	3659116	et	4	main
veel	doc_491521502229_item	3659106	et	4	main
juba	doc_491521502229_item	3659144	et	3	main
saj	doc_491521502229_item	3659140	et	4	main
6	doc_491521502229_item	3659135	et	2	main
kivist	doc_491521502229_item	3659132	et	4	main
tehti	doc_491521502229_item	3659128	et	3	main
kividest	doc_491521502229_item	3659127	et	3	main
6saj	doc_491521502229_item	3659121	et	4	main
siis	doc_491521502229_item	3659117	et	3	main
tunti	doc_491521502229_item	3659111	et	3	main
1000	doc_491521502229_item	3659109	et	2	main
tuntud	doc_491521502229_item	3659108	et	4	main
metalliaeg	doc_491521502229_item	3659134	et	3	main
2000	doc_491521502229_item	3659119	et	2	main
kui	doc_491521502229_item	3659114	et	3	main
juba	doc_491521502229_item	3659112	et	3	main
väetamist	doc_491521502229_item	3659105	et	4	main
siinsetel	doc_491521502229_item	3659103	et	4	main
mitte	doc_491521502237_item	3660617	et	3	main
keda	doc_491521502237_item	3660615	et	4	main
minna	doc_491521502237_item	3660606	et	3	main
tahtsid	doc_491521502237_item	3660604	et	4	main
ise	doc_491521502237_item	3660603	et	4	main
astuma	doc_491521502237_item	3660586	et	3	main
hakkas	doc_491521502237_item	3660447	et	3	main
visalt	doc_491521502237_item	3660437	et	4	main
kolhooside	doc_491521502237_item	3660426	et	3	main
leningraadi	doc_491521502237_item	3660384	et	4	main
poliitika	doc_491521502237_item	3660369	et	4	main
kontrolli	doc_491521502237_item	3660367	et	4	main
kõik	doc_491521502237_item	3660365	et	4	main
politiseeritud	doc_491521502237_item	3660364	et	4	main
on	doc_491521502237_item	3660363	et	4	main
valdkonnad	doc_491521502237_item	3660362	et	4	main
elu	doc_491521502237_item	3660361	et	4	main
kohad	doc_491521502237_item	3660342	et	4	main
ametnike	doc_491521502237_item	3660341	et	3	main
nad	doc_491521502237_item	3660336	et	3	main
nii	doc_491521502237_item	3660332	et	3	main
oska	doc_491521502237_item	3660330	et	4	main
toovad	doc_491521502237_item	3660324	et	4	main
tagasi	doc_491521502237_item	3660323	et	3	main
eestisse	doc_491521502237_item	3660319	et	4	main
majanduses	doc_491521502237_item	3660304	et	4	main
ja	doc_491521502237_item	3660303	et	3	main
õnnestu	doc_491521502237_item	3660578	et	4	main
ev	doc_491521502237_item	3660575	et	4	main
et	doc_491521502237_item	3660574	et	3	main
vajalikuks	doc_491521502237_item	3660569	et	3	main
keda	doc_491521502237_item	3660568	et	4	main
need	doc_491521502237_item	3660567	et	3	main
tapeti	doc_491521502237_item	3660566	et	3	main
nõukogude	doc_491521502237_item	3660559	et	3	main
püüab	doc_491521502237_item	3660557	et	3	main
ungaris	doc_491521502237_item	3660555	et	4	main
rääkid	doc_491521502237_item	3660546	et	4	main
võib	doc_491521502237_item	3660545	et	3	main
beriaga	doc_491521502237_item	3660537	et	4	main
kasvatamist	doc_491521502237_item	3660531	et	4	main
hruštsovi	doc_491521502237_item	3660527	et	2	main
n	doc_491521502237_item	3660526	et	4	main
2	doc_491521502237_item	3660524	et	2	main
kultuurimälu	doc_491521502237_item	3660523	et	4	main
rahva	doc_491521502237_item	3660522	et	3	main
hävitada	doc_491521502237_item	3660521	et	3	main
rajati	doc_491521502237_item	3660515	et	3	main
oli	doc_491521502237_item	3660513	et	3	main
hästi	doc_491521502237_item	3660611	et	3	main
nt	doc_491521502237_item	3660599	et	4	main
kohustuslik	doc_491521502237_item	3660598	et	3	main
kommunistlikusse	doc_491521502237_item	3660587	et	4	main
hakatakse	doc_491521502237_item	3660583	et	3	main
visalt	doc_491521502237_item	3660445	et	4	main
kolhoosi	doc_491521502237_item	3660435	et	4	main
vaesemad	doc_491521502237_item	3660432	et	4	main
ettevõtmisi	doc_491521502237_item	3660425	et	3	main
isikuvabadust	doc_491521502237_item	3660387	et	4	main
põlvkivi	doc_491521502237_item	3660375	et	4	main
ainuparteilisus	doc_491521502237_item	3660359	et	4	main
sotsiolism	doc_491521502237_item	3660353	et	4	main
oli	doc_491521502237_item	3660352	et	3	main
kuid	doc_491521502237_item	3660343	et	4	main
ei	doc_491521502237_item	3660329	et	4	main
nad	doc_491521502237_item	3660328	et	3	main
venemaa	doc_491521502237_item	3660322	et	4	main
eestlased	doc_491521502237_item	3660321	et	3	main
hrustshovi	doc_491521502237_item	3660313	et	4	main
nn	doc_491521502237_item	3660312	et	4	main
kõneldakse	doc_491521502237_item	3660311	et	3	main
ühiskonnakorralduses	doc_491521502237_item	3660302	et	3	main
saada	doc_491521502237_item	3660558	et	4	main
ungari	doc_491521502237_item	3660556	et	4	main
sündmused	doc_491521502237_item	3660554	et	3	main
1956a	doc_491521502237_item	3660553	et	4	main
sulast	doc_491521502237_item	3660544	et	4	main
alatest	doc_491521502237_item	3660543	et	3	main
teostama	doc_491521502237_item	3660542	et	3	main
eesmärk	doc_491521502237_item	3660520	et	3	main
ev	doc_491521502237_item	3660519	et	4	main
prestiizne	doc_491521502237_item	3660514	et	4	main
ei	doc_491521502237_item	3660479	et	4	main
oodatud	doc_491521502237_item	3660477	et	4	main
siberi	doc_491521502237_item	3660476	et	4	main
astuma	doc_491521502231_item	3660925	et	3	main
omad	doc_491521502231_item	3660902	et	4	main
eestlastele	doc_491521502231_item	3660847	et	4	main
ooperid	doc_491521502231_item	3660845	et	3	main
ka	doc_491521502231_item	3660844	et	3	main
hakkasid	doc_491521502231_item	3660842	et	4	main
oli	doc_491521502231_item	3660837	et	3	main
eestlaste	doc_491521502231_item	3660835	et	4	main
kohal	doc_491521502231_item	3660834	et	4	main
kaitseliit	doc_491521502231_item	3660828	et	3	main
tekkisid	doc_491521502231_item	3660827	et	4	main
ühiskondlikud	doc_491521502231_item	3660825	et	3	main
eesti	doc_491521502231_item	3660819	et	4	main
muulase	doc_491521502231_item	3660808	et	4	main
100000	doc_491521502231_item	3660807	et	2	main
sisse	doc_491521502231_item	3660801	et	4	main
jms	doc_491521502231_item	3660791	et	4	main
jne	doc_491521502231_item	3660773	et	4	main
elama	doc_491521502231_item	3660769	et	3	main
asub	doc_491521502231_item	3660765	et	3	main
vaadati	doc_491521502237_item	3660612	et	3	main
saanud	doc_491521502237_item	3660610	et	4	main
tihti	doc_491521502237_item	3660608	et	3	main
parteisse	doc_491521502237_item	3660605	et	3	main
isegi	doc_491521502237_item	3660597	et	4	main
see	doc_491521502237_item	3660596	et	3	main
oli	doc_491521502237_item	3660595	et	3	main
tihti	doc_491521502237_item	3660594	et	3	main
üha	doc_491521502237_item	3660584	et	3	main
uut	doc_491521502237_item	3660439	et	3	main
astusid	doc_491521502237_item	3660434	et	4	main
vaesemad	doc_491521502237_item	3660430	et	4	main
astuvad	doc_491521502237_item	3660429	et	4	main
ühismajanditesse	doc_491521502237_item	3660428	et	3	main
eestis	doc_491521502237_item	3660423	et	3	main
piirama	doc_491521502237_item	3660389	et	3	main
oblastit	doc_491521502237_item	3660385	et	3	main
elektritootmist	doc_491521502237_item	3660378	et	3	main
kultuur	doc_491521502237_item	3660370	et	3	main
all	doc_491521502237_item	3660368	et	3	main
oli	doc_491521502237_item	3660366	et	3	main
kõik	doc_491521502237_item	3660360	et	4	main
võimu	doc_491521502237_item	3660355	et	4	main
poliitilise	doc_491521502237_item	3660354	et	3	main
ei	doc_491521502237_item	3660344	et	4	main
nõukogude-meelsed	doc_491521502237_item	3660338	et	3	main
kultuuri	doc_491521502237_item	3660327	et	4	main
pöörduvad	doc_491521502237_item	3660320	et	4	main
ensv	doc_491521502237_item	3660318	et	4	main
sisuline	doc_491521502237_item	3660317	et	4	main
kultuuriajaloos	doc_491521502237_item	3660310	et	4	main
ensv	doc_491521502237_item	3660301	et	4	main
nii	doc_491521502237_item	3660579	et	3	main
ei	doc_491521502237_item	3660577	et	4	main
taastada	doc_491521502237_item	3660576	et	3	main
aru	doc_491521502237_item	3660573	et	4	main
tankid	doc_491521502237_item	3660565	et	3	main
kohale	doc_491521502237_item	3660564	et	4	main
saatis	doc_491521502237_item	3660563	et	3	main
on	doc_491521502237_item	3660552	et	4	main
põhjuseks	doc_491521502237_item	3660551	et	3	main
üheks	doc_491521502237_item	3660550	et	3	main
süsteemiga	doc_491521502237_item	3660549	et	3	main
ideed	doc_491521502237_item	3660541	et	4	main
hakkab	doc_491521502237_item	3660540	et	3	main
ning	doc_491521502237_item	3660539	et	3	main
palju	doc_491521502237_item	3660536	et	4	main
1957-1968	doc_491521502237_item	3660525	et	2	main
internaate	doc_491521502237_item	3660516	et	4	main
inimesi	doc_491521502237_item	3660474	et	4	main
rohkem	doc_491521502237_item	3660473	et	4	main
aina	doc_491521502231_item	3660923	et	4	main
ajal	doc_491521502231_item	3660921	et	4	main
saa	doc_491521502231_item	3660919	et	4	main
ei	doc_491521502231_item	3660918	et	4	main
niipea	doc_491521502231_item	3660917	et	3	main
taastada	doc_491521502231_item	3660916	et	3	main
ev	doc_491521502231_item	3660915	et	4	main
et	doc_491521502231_item	3660914	et	3	main
ära	doc_491521502231_item	3660906	et	4	main
tapeti	doc_491521502231_item	3660905	et	3	main
käia	doc_491521502231_item	3660849	et	4	main
ballettid	doc_491521502231_item	3660846	et	4	main
tekkima	doc_491521502231_item	3660843	et	3	main
soovitati	doc_491521502237_item	3660616	et	4	main
peale	doc_491521502237_item	3660614	et	4	main
ei	doc_491521502237_item	3660609	et	4	main
sinna	doc_491521502237_item	3660607	et	3	main
tahtest	doc_491521502237_item	3660593	et	4	main
vaid	doc_491521502237_item	3660592	et	3	main
lojaalsusest	doc_491521502237_item	3660591	et	4	main
mitte	doc_491521502237_item	3660590	et	3	main
seda	doc_491521502237_item	3660589	et	3	main
parteisse	doc_491521502237_item	3660588	et	3	main
moskva	doc_491521502237_item	3660446	et	4	main
suhteliselt	doc_491521502237_item	3660444	et	4	main
läheb	doc_491521502237_item	3660443	et	3	main
loomine	doc_491521502237_item	3660442	et	4	main
kolhooside	doc_491521502237_item	3660441	et	3	main
väga	doc_491521502237_item	3660436	et	3	main
talupojad	doc_491521502237_item	3660433	et	4	main
inimesed	doc_491521502237_item	3660431	et	3	main
esimesi	doc_491521502237_item	3660424	et	4	main
elektriga	doc_491521502237_item	3660386	et	3	main
usinalt	doc_491521502237_item	3660381	et	4	main
eriti	doc_491521502237_item	3660380	et	3	main
tegi	doc_491521502237_item	3660624	et	4	main
ettepaneku	doc_491521502237_item	3660623	et	3	main
seda	doc_491521502237_item	3660622	et	3	main
ise	doc_491521502237_item	3660621	et	4	main
kes	doc_491521502237_item	3660620	et	4	main
peale	doc_491521502237_item	3660619	et	4	main
nende	doc_491521502237_item	3660618	et	4	main
nende	doc_491521502237_item	3660613	et	4	main
kes	doc_491521502237_item	3660602	et	4	main
need	doc_491521502237_item	3660601	et	3	main
direktorid	doc_491521502237_item	3660600	et	3	main
enam	doc_491521502237_item	3660585	et	4	main
küüditamist	doc_491521502237_item	3660440	et	4	main
kartsid	doc_491521502237_item	3660438	et	4	main
asutamiseks	doc_491521502237_item	3660427	et	4	main
alustati	doc_491521502237_item	3660422	et	4	main
1947	doc_491521502237_item	3660421	et	2	main
toetas	doc_491521502237_item	3660420	et	3	main
riik	doc_491521502237_item	3660419	et	3	main
need	doc_491521502237_item	3660418	et	3	main
sovhoose	doc_491521502237_item	3660417	et	3	main
loodi	doc_491521502237_item	3660416	et	4	main
hiljem	doc_491521502237_item	3660415	et	3	main
puudus	doc_491521502237_item	3660414	et	4	main
toetus	doc_491521502237_item	3660413	et	4	main
riigi	doc_491521502237_item	3660412	et	3	main
majandama	doc_491521502237_item	3660411	et	3	main
end	doc_491521502237_item	3660410	et	4	main
ise	doc_491521502237_item	3660409	et	4	main
pidid	doc_491521502237_item	3660408	et	4	main
mis	doc_491521502237_item	3660407	et	4	main
majandid	doc_491521502237_item	3660406	et	3	main
olid	doc_491521502237_item	3660405	et	4	main
kolhoose	doc_491521502237_item	3660404	et	3	main
loodi	doc_491521502237_item	3660403	et	4	main
majandus	doc_491521502237_item	3660402	et	4	main
ev	doc_491521502237_item	3660401	et	4	main
jms	doc_491521502237_item	3660400	et	4	main
tegevus	doc_491521502237_item	3660399	et	4	main
taustu	doc_491521502237_item	3660398	et	3	main
inimeste	doc_491521502237_item	3660397	et	3	main
kontrolliti	doc_491521502237_item	3660396	et	3	main
julgeolekomitee	doc_491521502237_item	3660395	et	4	main
kgb	doc_491521502237_item	3660394	et	4	main
tegevust	doc_491521502237_item	3660393	et	4	main
a	doc_491521502237_item	3660391	et	4	main
1946	doc_491521502237_item	3660390	et	2	main
hakkab	doc_491521502237_item	3660392	et	3	main
hakati	doc_491521502237_item	3660388	et	3	main
varustas	doc_491521502237_item	3660383	et	3	main
eesti	doc_491521502237_item	3660382	et	4	main
ja	doc_491521502237_item	3660377	et	3	main
tööstust	doc_491521502237_item	3660376	et	4	main
poliitika	doc_491521502237_item	3660374	et	4	main
mõjutab	doc_491521502237_item	3660373	et	3	main
majandus	doc_491521502237_item	3660372	et	4	main
liidus	doc_491521502237_item	3660351	et	4	main
nõukogude	doc_491521502237_item	3660350	et	3	main
midagi	doc_491521502237_item	3660349	et	4	main
suurt	doc_491521502237_item	3660348	et	3	main
elust	doc_491521502237_item	3660347	et	3	main
siinsest	doc_491521502237_item	3660346	et	3	main
tea	doc_491521502237_item	3660345	et	4	main
saavad	doc_491521502237_item	3660340	et	4	main
on	doc_491521502237_item	3660337	et	4	main
keelt	doc_491521502237_item	3660335	et	4	main
hästi	doc_491521502237_item	3660333	et	3	main
oma	doc_491521502237_item	3660326	et	4	main
a	doc_491521502237_item	3660316	et	4	main
1947	doc_491521502237_item	3660315	et	2	main
sulast	doc_491521502237_item	3660314	et	4	main
ja	doc_491521502237_item	3660300	et	3	main
ev	doc_491521502237_item	3660299	et	4	main
erinevused	doc_491521502237_item	3660298	et	4	main
peamised	doc_491521502237_item	3660297	et	3	main
välja	doc_491521502237_item	3660296	et	4	main
tooge	doc_491521502237_item	3660295	et	3	main
1	doc_491521502237_item	3660294	et	2	main
kontrolltöö	doc_491521502237_item	3660293	et	4	main
perioodil	doc_491521502237_item	3660582	et	3	main
sel	doc_491521502237_item	3660581	et	3	main
pea	doc_491521502237_item	3660580	et	4	main
said	doc_491521502237_item	3660572	et	4	main
nsvl	doc_491521502237_item	3660562	et	4	main
vabaks	doc_491521502237_item	3660561	et	3	main
sarnaselt	doc_491521502237_item	3660538	et	4	main
hruštsov	doc_491521502237_item	3660534	et	2	main
võimule	doc_491521502237_item	3660532	et	3	main
propageeris	doc_491521502237_item	3660529	et	3	main
sula	doc_491521502237_item	3660528	et	4	main
maalaste	doc_491521502237_item	3660517	et	4	main
viidi	doc_491521502237_item	3660475	et	4	main
arendati	doc_491521502237_item	3660379	et	3	main
ja	doc_491521502237_item	3660371	et	3	main
muutmine	doc_491521502237_item	3660358	et	4	main
majanduse	doc_491521502237_item	3660357	et	4	main
haaramine	doc_491521502237_item	3660356	et	4	main
nad	doc_491521502237_item	3660339	et	3	main
eesti	doc_491521502237_item	3660334	et	4	main
enam	doc_491521502237_item	3660331	et	4	main
kaasa	doc_491521502237_item	3660325	et	4	main
ensv	doc_491521502237_item	3660309	et	4	main
kui	doc_491521502237_item	3660308	et	3	main
mõeldakse	doc_491521502237_item	3660307	et	3	main
mida	doc_491521502237_item	3660306	et	4	main
2	doc_491521502237_item	3660305	et	2	main
eestased	doc_491521502237_item	3660571	et	4	main
peeti	doc_491521502237_item	3660570	et	4	main
liidust	doc_491521502237_item	3660560	et	4	main
kohanemisest	doc_491521502237_item	3660548	et	4	main
eestlaste	doc_491521502237_item	3660547	et	4	main
mõtleb	doc_491521502237_item	3660535	et	3	main
saab	doc_491521502237_item	3660533	et	3	main
maisi	doc_491521502237_item	3660530	et	4	main
jaoks	doc_491521502237_item	3660518	et	4	main
haridus	doc_491521502237_item	3660512	et	3	main
sõda	doc_491521502237_item	3660511	et	4	main
pärast	doc_491521502237_item	3660510	et	4	main
keel	doc_491521502237_item	3660509	et	4	main
kohalik	doc_491521502237_item	3660508	et	3	main
asjaajamiskeeleks	doc_491521502237_item	3660507	et	4	main
kohalikke	doc_491521502237_item	3660506	et	4	main
edutas	doc_491521502237_item	3660505	et	3	main
ta	doc_491521502237_item	3660504	et	4	main
beria	doc_491521502237_item	3660503	et	4	main
tuli	doc_491521502237_item	3660502	et	4	main
võimule	doc_491521502237_item	3660501	et	3	main
suri	doc_491521502237_item	3660500	et	3	main
stalin	doc_491521502237_item	3660499	et	4	main
nälgisid	doc_491521502237_item	3660498	et	4	main
loomad	doc_491521502237_item	3660497	et	3	main
vangi	doc_491521502237_item	3660496	et	4	main
varas	doc_491521502237_item	3660495	et	4	main
pandi	doc_491521502237_item	3660494	et	4	main
näpati	doc_491521502237_item	3660493	et	3	main
tagant	doc_491521502237_item	3660492	et	3	main
kolhoos	doc_491521502237_item	3660491	et	3	main
kui	doc_491521502237_item	3660490	et	3	main
ühinema	doc_491521502237_item	3660489	et	3	main
hakkasid	doc_491521502237_item	3660488	et	4	main
kolhoosid	doc_491521502237_item	3660487	et	3	main
vaesemad	doc_491521502237_item	3660486	et	4	main
arvestatud	doc_491521502237_item	3660485	et	4	main
ei	doc_491521502237_item	3660484	et	4	main
oludega	doc_491521502237_item	3660483	et	3	main
kohalike	doc_491521502237_item	3660482	et	4	main
sest	doc_491521502237_item	3660481	et	4	main
tulnud	doc_491521502237_item	3660480	et	4	main
majanduskasvu	doc_491521502237_item	3660478	et	4	main
küüditati	doc_491521502237_item	3660472	et	3	main
rohkem	doc_491521502231_item	3660924	et	4	main
aru	doc_491521502231_item	3660913	et	4	main
said	doc_491521502231_item	3660912	et	4	main
eestlased	doc_491521502231_item	3660911	et	3	main
20700	doc_491521502237_item	3660471	et	2	main
ebalojaalsuga	doc_491521502237_item	3660470	et	2	main
põhjendati	doc_491521502237_item	3660469	et	3	main
mida	doc_491521502237_item	3660468	et	4	main
küüditamine	doc_491521502237_item	3660467	et	4	main
suur	doc_491521502237_item	3660466	et	3	main
1949	doc_491521502237_item	3660465	et	2	main
kartsid	doc_491521502237_item	3660464	et	4	main
talupojad	doc_491521502237_item	3660463	et	4	main
jõukamad	doc_491521502237_item	3660462	et	4	main
mida	doc_491521502237_item	3660461	et	4	main
selle	doc_491521502237_item	3660460	et	4	main
kaasa	doc_491521502237_item	3660459	et	4	main
tõi	doc_491521502237_item	3660458	et	3	main
see	doc_491521502237_item	3660457	et	3	main
radikaalset	doc_491521502237_item	3660456	et	3	main
midagi	doc_491521502237_item	3660455	et	4	main
võtaks	doc_491521502237_item	3660454	et	3	main
ette	doc_491521502237_item	3660453	et	4	main
midagi	doc_491521502237_item	3660452	et	4	main
partei	doc_491521502237_item	3660451	et	4	main
eestis	doc_491521502237_item	3660450	et	3	main
et	doc_491521502237_item	3660449	et	3	main
nõudma	doc_491521502237_item	3660448	et	3	main
tihti	doc_491521502231_item	3660928	et	3	main
parteisse	doc_491521502231_item	3660927	et	3	main
sel	doc_491521502231_item	3660920	et	3	main
keda	doc_491521502231_item	3660908	et	4	main
need	doc_491521502231_item	3660907	et	3	main
omad	doc_491521502231_item	3660901	et	4	main
siis	doc_491521502231_item	3660868	et	3	main
hruštsov	doc_491521502231_item	3660867	et	2	main
rahvuslik	doc_491521502231_item	3660852	et	3	main
tekkis	doc_491521502231_item	3660851	et	3	main
kinos	doc_491521502231_item	3660850	et	3	main
tegid	doc_491521502231_item	3660954	et	4	main
ettepaneku	doc_491521502231_item	3660953	et	3	main
ise	doc_491521502231_item	3660952	et	4	main
kes	doc_491521502231_item	3660951	et	4	main
neid	doc_491521502231_item	3660950	et	4	main
mitte	doc_491521502231_item	3660949	et	3	main
keda	doc_491521502231_item	3660947	et	4	main
soovitati	doc_491521502231_item	3660948	et	4	main
perteisse	doc_491521502231_item	3660946	et	4	main
neid	doc_491521502231_item	3660945	et	4	main
võeti	doc_491521502231_item	3660944	et	3	main
meelega	doc_491521502231_item	3660943	et	4	main
parema	doc_491521502231_item	3660942	et	4	main
saanud	doc_491521502231_item	3660941	et	4	main
ei	doc_491521502231_item	3660940	et	4	main
peal	doc_491521502231_item	3660939	et	4	main
tihti	doc_491521502231_item	3660938	et	3	main
minna	doc_491521502231_item	3660937	et	3	main
parteisse	doc_491521502231_item	3660936	et	3	main
tahtsid	doc_491521502231_item	3660935	et	4	main
ise	doc_491521502231_item	3660934	et	4	main
kes	doc_491521502231_item	3660933	et	4	main
need	doc_491521502231_item	3660932	et	3	main
kohustuslik	doc_491521502231_item	3660931	et	3	main
see	doc_491521502231_item	3660930	et	3	main
oli	doc_491521502231_item	3660929	et	3	main
kommunistlikusse	doc_491521502231_item	3660926	et	4	main
hakataxe	doc_491521502231_item	3660922	et	4	main
ja	doc_491521502231_item	3660904	et	3	main
saatis	doc_491521502231_item	3660900	et	3	main
nsvl	doc_491521502231_item	3660899	et	4	main
kuid	doc_491521502231_item	3660898	et	4	main
vabaks	doc_491521502231_item	3660897	et	3	main
liidust	doc_491521502231_item	3660896	et	4	main
nõukogude	doc_491521502231_item	3660895	et	3	main
saada	doc_491521502231_item	3660894	et	4	main
püüdis	doc_491521502231_item	3660893	et	3	main
ungari	doc_491521502231_item	3660892	et	4	main
süsteemiga	doc_491521502231_item	3660891	et	3	main
kohanemisest	doc_491521502231_item	3660890	et	4	main
eestlaste	doc_491521502231_item	3660889	et	4	main
rääkida	doc_491521502231_item	3660888	et	3	main
võib	doc_491521502231_item	3660887	et	3	main
siis	doc_491521502231_item	3660886	et	3	main
ungaris	doc_491521502231_item	3660885	et	4	main
sündmused	doc_491521502231_item	3660884	et	3	main
a	doc_491521502231_item	3660883	et	4	main
1956	doc_491521502231_item	3660882	et	2	main
teostama	doc_491521502231_item	3660881	et	3	main
iseid	doc_491521502231_item	3660880	et	4	main
hakkas	doc_491521502231_item	3660879	et	3	main
ta	doc_491521502231_item	3660878	et	4	main
ja	doc_491521502231_item	3660877	et	3	main
daknast	doc_491521502231_item	3660876	et	4	main
palju	doc_491521502231_item	3660875	et	4	main
beriaga	doc_491521502231_item	3660874	et	4	main
mõtles	doc_491521502231_item	3660873	et	3	main
hruštšov	doc_491521502231_item	3660872	et	2	main
sulast	doc_491521502231_item	3660871	et	4	main
rääkida	doc_491521502231_item	3660870	et	3	main
võime	doc_491521502231_item	3660869	et	4	main
oli	doc_491521502231_item	3660910	et	3	main
vaja	doc_491521502231_item	3660909	et	4	main
jõud	doc_491521502231_item	3660903	et	4	main
teatrit	doc_491521502231_item	3660841	et	3	main
810	doc_491521502231_item	3660839	et	2	main
ev	doc_491521502231_item	3660824	et	4	main
sealt	doc_491521502231_item	3660822	et	4	main
ida-viru	doc_491521502231_item	3660816	et	4	main
sillamäe	doc_491521502231_item	3660812	et	3	main
elavale	doc_491521502231_item	3660792	et	4	main
keelt	doc_491521502231_item	3660786	et	4	main
eesti	doc_491521502231_item	3660784	et	4	main
pühapäevakoolis	doc_491521502231_item	3660783	et	4	main
tööd	doc_491521502231_item	3660778	et	4	main
rootsi	doc_491521502231_item	3660772	et	4	main
kui	doc_491521502231_item	3660751	et	3	main
eesmärk	doc_491521502231_item	3660748	et	3	main
pagulasvalitsus	doc_491521502231_item	3660740	et	3	main
rootsis	doc_491521502231_item	3660738	et	3	main
uus	doc_491521502231_item	3660732	et	3	main
julgeolekukomitee	doc_491521502231_item	3660720	et	4	main
eesti	doc_491521502231_item	3660719	et	4	main
tegutsema	doc_491521502231_item	3660718	et	3	main
venemaad	doc_491521502231_item	3660713	et	4	main
elektriga	doc_491521502231_item	3660711	et	3	main
hakkavad	doc_491521502231_item	3660701	et	4	main
venemaa	doc_491521502231_item	3660698	et	4	main
tulevad	doc_491521502231_item	3660697	et	4	main
ei	doc_491521502231_item	3660694	et	4	main
määral	doc_491521502231_item	3660688	et	3	main
või	doc_491521502231_item	3660686	et	4	main
rohkemal	doc_491521502231_item	3660685	et	4	main
kaasa	doc_491521502231_item	3660680	et	4	main
nö	doc_491521502231_item	3660675	et	4	main
eesti	doc_491521502231_item	3660672	et	4	main
nõukogude	doc_491521502231_item	3660671	et	3	main
e	doc_491521502231_item	3660670	et	4	main
muutusid	doc_491521502231_item	3660664	et	4	main
piirid	doc_491521502231_item	3660663	et	3	main
eesti	doc_491521502231_item	3660662	et	4	main
on	doc_491521502231_item	3660655	et	4	main
eesotsas	doc_491521502231_item	3660654	et	4	main
eestis	doc_491521502231_item	3660653	et	3	main
tugevaimax	doc_491521502231_item	3660854	et	4	main
meeldis	doc_491521502231_item	3660848	et	3	main
kutselist	doc_491521502231_item	3660840	et	4	main
elus	doc_491521502231_item	3660836	et	4	main
tähtsal	doc_491521502231_item	3660833	et	3	main
jne	doc_491521502231_item	3660832	et	4	main
maanaisteselts	doc_491521502231_item	3660831	et	3	main
haridusselts	doc_491521502231_item	3660830	et	3	main
kolivad	doc_491521502231_item	3660821	et	4	main
tööstusrajoonix	doc_491521502231_item	3660818	et	4	main
üle	doc_491521502231_item	3660806	et	3	main
toodi	doc_491521502231_item	3660805	et	4	main
baltikumi	doc_491521502231_item	3660804	et	4	main
võõrtööjõudu	doc_491521502231_item	3660803	et	4	main
rahvast	doc_491521502231_item	3660799	et	4	main
sõda	doc_491521502231_item	3660797	et	4	main
rahvale	doc_491521502231_item	3660793	et	3	main
majad	doc_491521502231_item	3660789	et	3	main
õppimas	doc_491521502231_item	3660787	et	3	main
baseeruvad	doc_491521502231_item	3660775	et	4	main
taasiseseisvumiseni	doc_491521502231_item	3660762	et	3	main
ev	doc_491521502231_item	3660761	et	4	main
kuni	doc_491521502231_item	3660760	et	3	main
tegutsevad	doc_491521502231_item	3660759	et	4	main
üle	doc_491521502231_item	3660758	et	3	main
juhul	doc_491521502231_item	3660750	et	3	main
eesti	doc_491521502231_item	3660739	et	4	main
moodustati	doc_491521502231_item	3660737	et	3	main
1944	doc_491521502231_item	3660735	et	2	main
metsavendlus	doc_491521502231_item	3660734	et	3	main
maha	doc_491521502231_item	3660727	et	4	main
kütusega	doc_491521502231_item	3660714	et	3	main
varustama	doc_491521502231_item	3660710	et	3	main
valitsema	doc_491521502231_item	3660702	et	3	main
ja	doc_491521502231_item	3660700	et	3	main
eestlased	doc_491521502231_item	3660699	et	3	main
meeldi	doc_491521502231_item	3660695	et	4	main
see	doc_491521502231_item	3660693	et	3	main
nõukogude	doc_491521502231_item	3660689	et	3	main
vähemal	doc_491521502231_item	3660687	et	4	main
nsv	doc_491521502231_item	3660669	et	4	main
ms	doc_491521502231_item	3660661	et	4	main
barbarus	doc_491521502231_item	3660658	et	4	main
võim	doc_491521502231_item	3660651	et	3	main
nõukogude	doc_491521502231_item	3660650	et	3	main
filmikunst	doc_491521502231_item	3660853	et	3	main
teater	doc_491521502231_item	3660838	et	3	main
tuletõrjeselts	doc_491521502231_item	3660829	et	3	main
organisatsioonid	doc_491521502231_item	3660826	et	3	main
talup	doc_491521502231_item	3660820	et	4	main
muldmetellidega	doc_491521502231_item	3660815	et	4	main
tegeldi	doc_491521502231_item	3660814	et	3	main
kogu	doc_491521502231_item	3660809	et	4	main
toodi	doc_491521502231_item	3660802	et	4	main
eestis	doc_491521502231_item	3660798	et	3	main
peale	doc_491521502231_item	3660796	et	4	main
ettevõtmised	doc_491521502231_item	3660795	et	3	main
omased	doc_491521502231_item	3660794	et	3	main
seltsitegevus	doc_491521502231_item	3660790	et	4	main
kuluurii	doc_491521502231_item	3660785	et	4	main
arhiivides	doc_491521502231_item	3660779	et	3	main
saavad	doc_491521502231_item	3660777	et	4	main
rootsi	doc_491521502231_item	3660776	et	4	main
kanada	doc_491521502231_item	3660771	et	4	main
eestlast	doc_491521502231_item	3660768	et	4	main
40000	doc_491521502231_item	3660766	et	2	main
pärast	doc_491521502231_item	3660763	et	4	main
koguneb	doc_491521502231_item	3660754	et	3	main
valitsus	doc_491521502231_item	3660753	et	4	main
oli	doc_491521502231_item	3660749	et	3	main
moodustavad	doc_491521502231_item	3660746	et	4	main
emigreeruvad	doc_491521502231_item	3660745	et	4	main
sõjakriisis	doc_491521502231_item	3660744	et	3	main
on	doc_491521502231_item	3660743	et	4	main
kes	doc_491521502231_item	3660742	et	4	main
haritlased	doc_491521502231_item	3660741	et	3	main
minema	doc_491521502231_item	3660823	et	3	main
muutub	doc_491521502231_item	3660817	et	3	main
linn	doc_491521502231_item	3660813	et	3	main
loodi	doc_491521502231_item	3660811	et	4	main
nsvlst	doc_491521502231_item	3660810	et	4	main
tühi	doc_491521502231_item	3660800	et	3	main
eesti	doc_491521502231_item	3660788	et	4	main
käia	doc_491521502231_item	3660782	et	4	main
saavad	doc_491521502231_item	3660781	et	4	main
lapsed	doc_491521502231_item	3660780	et	3	main
keeleinim	doc_491521502231_item	3660774	et	4	main
välismaale	doc_491521502231_item	3660770	et	4	main
inimest	doc_491521502231_item	3660767	et	3	main
võda	doc_491521502231_item	3660764	et	4	main
võimu	doc_491521502231_item	3660757	et	4	main
nemad	doc_491521502231_item	3660756	et	3	main
tavad	doc_491521502231_item	3660755	et	3	main
nõukogude	doc_491521502231_item	3660752	et	3	main
valitsuse	doc_491521502231_item	3660747	et	4	main
a	doc_491521502231_item	3660736	et	4	main
piirama	doc_491521502231_item	3660730	et	3	main
kgb	doc_491521502231_item	3660721	et	4	main
vajavad	doc_491521502231_item	3660705	et	4	main
tööstused	doc_491521502231_item	3660704	et	3	main
et	doc_491521502231_item	3660696	et	3	main
eestlastele	doc_491521502231_item	3660692	et	4	main
ideoloogiast	doc_491521502231_item	3660690	et	3	main
tausta	doc_491521502231_item	3660683	et	4	main
kultuuri	doc_491521502231_item	3660682	et	4	main
oma	doc_491521502231_item	3660681	et	4	main
eestlased	doc_491521502231_item	3660677	et	3	main
eesti	doc_491521502231_item	3660668	et	4	main
kehtestatakse	doc_491521502231_item	3660667	et	3	main
a	doc_491521502231_item	3660666	et	4	main
1947	doc_491521502231_item	3660665	et	2	main
ii	doc_491521502231_item	3660660	et	4	main
vares	doc_491521502231_item	3660657	et	4	main
oli	doc_491521502231_item	3660857	et	3	main
filmimaailmas	doc_491521502231_item	3660856	et	3	main
küljex	doc_491521502231_item	3660855	et	4	main
nähtus	doc_491521502231_item	3660733	et	4	main
isikuvabadust	doc_491521502231_item	3660728	et	4	main
hakab	doc_491521502231_item	3660717	et	4	main
põlevkivi	doc_491521502231_item	3660703	et	4	main
paixetele	doc_491521502231_item	3660691	et	4	main
ja	doc_491521502231_item	3660678	et	3	main
venemaa	doc_491521502231_item	3660676	et	4	main
eestisse	doc_491521502231_item	3660673	et	4	main
kehtestataxe	doc_491521502231_item	3660652	et	4	main
a	doc_491521502231_item	3660649	et	4	main
1944	doc_491521502231_item	3660648	et	2	main
1	doc_491521502231_item	3660647	et	2	main
sulast	doc_491521502231_item	3660646	et	4	main
hrustshovi	doc_491521502231_item	3660645	et	4	main
nn	doc_491521502231_item	3660644	et	4	main
kõneldakse	doc_491521502231_item	3660643	et	3	main
kutluuriajaloos	doc_491521502231_item	3660642	et	4	main
ensv	doc_491521502231_item	3660641	et	4	main
kui	doc_491521502231_item	3660640	et	3	main
2	doc_491521502231_item	3660637	et	2	main
mida	doc_491521502231_item	3660638	et	4	main
mõeldakse	doc_491521502231_item	3660639	et	3	main
majanduses	doc_491521502231_item	3660636	et	4	main
ja	doc_491521502231_item	3660635	et	3	main
ühiskonnakorralduses	doc_491521502231_item	3660634	et	3	main
ensv	doc_491521502231_item	3660633	et	4	main
ja	doc_491521502231_item	3660632	et	3	main
ev	doc_491521502231_item	3660631	et	4	main
erinevused	doc_491521502231_item	3660630	et	4	main
peamised	doc_491521502231_item	3660629	et	3	main
välja	doc_491521502231_item	3660628	et	4	main
tooge	doc_491521502231_item	3660627	et	3	main
1	doc_491521502231_item	3660626	et	2	main
kontrolltöö	doc_491521502231_item	3660625	et	4	main
saab	doc_491521502231_item	3660866	et	3	main
võimule	doc_491521502231_item	3660865	et	3	main
kui	doc_491521502231_item	3660864	et	3	main
2	doc_491521502231_item	3660863	et	2	main
raadios	doc_491521502231_item	3660862	et	3	main
jõuavad	doc_491521502231_item	3660861	et	4	main
a	doc_491521502231_item	3660860	et	4	main
1926	doc_491521502231_item	3660859	et	2	main
dokumentalistika	doc_491521502231_item	3660858	et	4	main
tekib	doc_491521502231_item	3660731	et	3	main
hakati	doc_491521502231_item	3660729	et	3	main
end	doc_491521502231_item	3660726	et	4	main
barbarus	doc_491521502231_item	3660725	et	4	main
laseb	doc_491521502231_item	3660724	et	3	main
aastal	doc_491521502231_item	3660723	et	3	main
sel	doc_491521502231_item	3660722	et	3	main
a	doc_491521502231_item	3660716	et	4	main
1946	doc_491521502231_item	3660715	et	2	main
novgorodi	doc_491521502231_item	3660712	et	4	main
hakab	doc_491521502231_item	3660709	et	4	main
eesti	doc_491521502231_item	3660708	et	4	main
ja	doc_491521502231_item	3660707	et	3	main
energiat	doc_491521502231_item	3660706	et	3	main
mõjutatud	doc_491521502231_item	3660684	et	4	main
toovad	doc_491521502231_item	3660679	et	4	main
tulevad	doc_491521502231_item	3660674	et	4	main
pärast	doc_491521502231_item	3660659	et	4	main
j	doc_491521502231_item	3660656	et	4	main
kaudu	doc_491521502244_item	3662187	et	3	main
igapäevase	doc_491521502244_item	3662184	et	4	main
õnnestub	doc_491521502244_item	3662183	et	3	main
see	doc_491521502244_item	3662182	et	3	main
kus	doc_491521502244_item	3662171	et	3	main
riigi	doc_491521502244_item	3662169	et	3	main
teada	doc_491521502244_item	3662167	et	3	main
mitte-eestlastele	doc_491521502244_item	3662163	et	4	main
alu	doc_491521502244_item	3662158	et	4	main
võrrelda	doc_491521502244_item	3662154	et	4	main
lubab	doc_491521502244_item	3662153	et	3	main
see	doc_491521502244_item	3662152	et	3	main
ajalooliselt	doc_491521502244_item	3662151	et	4	main
ainult	doc_491521502244_item	3662136	et	4	main
mitte	doc_491521502244_item	3662135	et	3	main
sobib	doc_491521502244_item	3662134	et	3	main
ja	doc_491521502244_item	3662129	et	3	main
probleemid	doc_491521502244_item	3662128	et	3	main
oli	doc_491521502244_item	3662126	et	3	main
tõesti	doc_491521502244_item	3662125	et	3	main
see	doc_491521502244_item	3662124	et	3	main
nii	doc_491521502244_item	3662122	et	3	main
tolleaegsete	doc_491521502244_item	3662118	et	4	main
see	doc_491521502244_item	3662115	et	3	main
põhikooli	doc_491521502244_item	3662109	et	4	main
lutsu	doc_491521502244_item	3662104	et	4	main
tulemus	doc_491521502244_item	3662098	et	3	main
arusaamise	doc_491521502244_item	3662186	et	4	main
paremini	doc_491521502244_item	3662176	et	4	main
aitab	doc_491521502244_item	3662175	et	3	main
alati	doc_491521502244_item	3662165	et	4	main
õpilastele	doc_491521502244_item	3662162	et	4	main
nt	doc_491521502244_item	3662159	et	4	main
elu	doc_491521502244_item	3662185	et	4	main
paremini	doc_491521502244_item	3662181	et	4	main
tähtis	doc_491521502244_item	3662166	et	4	main
suhtumine	doc_491521502244_item	3662161	et	4	main
filmon	doc_491521502244_item	3662148	et	4	main
aja	doc_491521502244_item	3662145	et	4	main
mineviku	doc_491521502244_item	3662144	et	3	main
kui	doc_491521502244_item	3662143	et	3	main
lihtsalt	doc_491521502244_item	3662142	et	4	main
õpilastele	doc_491521502244_item	3662141	et	4	main
see	doc_491521502244_item	3662133	et	3	main
elu	doc_491521502244_item	3662121	et	4	main
näitab	doc_491521502244_item	3662117	et	3	main
et	doc_491521502244_item	3662114	et	3	main
arvates	doc_491521502244_item	3662101	et	4	main
aga	doc_491521502244_item	3662096	et	3	main
kultuuri	doc_491521502244_item	3662083	et	4	main
vähendada	doc_491521502244_item	3662081	et	3	main
selleks	doc_491521502244_item	3662079	et	4	main
viis	doc_491521502244_item	3662078	et	4	main
poliitiline	doc_491521502244_item	3662077	et	3	main
samuti	doc_491521502244_item	3662076	et	3	main
oli	doc_491521502244_item	3662075	et	3	main
see	doc_491521502244_item	3662074	et	3	main
aga	doc_491521502244_item	3662073	et	3	main
oli	doc_491521502244_item	3662067	et	3	main
migrantide	doc_491521502244_item	3662064	et	3	main
et	doc_491521502244_item	3662063	et	3	main
suur	doc_491521502244_item	3662054	et	3	main
väga	doc_491521502244_item	3662053	et	3	main
oli	doc_491521502244_item	3662052	et	3	main
vahel	doc_491521502244_item	3662051	et	4	main
mis	doc_491521502244_item	3662043	et	4	main
riigid	doc_491521502244_item	3662042	et	3	main
nagu	doc_491521502244_item	3662040	et	3	main
salased	doc_491521502244_item	3662032	et	4	main
nagu	doc_491521502244_item	3662031	et	3	main
olid	doc_491521502244_item	3662030	et	4	main
nt	doc_491521502244_item	3662026	et	4	main
staatuse	doc_491521502244_item	3662025	et	3	main
kinnise	doc_491521502244_item	3662023	et	4	main
palju	doc_491521502244_item	3662013	et	4	main
ja	doc_491521502244_item	3662012	et	3	main
puid	doc_491521502244_item	3662011	et	3	main
said	doc_491521502244_item	3661996	et	4	main
järjekord	doc_491521502244_item	3661989	et	3	main
nsv-liidu	doc_491521502244_item	3661982	et	3	main
ainult	doc_491521502244_item	3661981	et	4	main
pidid	doc_491521502244_item	3661979	et	4	main
kes	doc_491521502244_item	3661973	et	4	main
migrantidega	doc_491521502244_item	3661972	et	3	main
seotud	doc_491521502244_item	3661971	et	4	main
probleemid	doc_491521502244_item	3661970	et	3	main
uued	doc_491521502244_item	3661969	et	3	main
eestisse	doc_491521502244_item	3661960	et	4	main
ida-virumaal	doc_491521502244_item	3661941	et	4	main
loodud	doc_491521502244_item	3661939	et	4	main
olid	doc_491521502244_item	3661938	et	4	main
vana	doc_491521502244_item	3661931	et	4	main
aga	doc_491521502244_item	3661930	et	3	main
tegutses	doc_491521502244_item	3661929	et	3	main
midagi	doc_491521502244_item	3661922	et	4	main
2	doc_491521502244_item	3661891	et	2	main
nsv-s	doc_491521502244_item	3661890	et	3	main
eesti	doc_491521502244_item	3661889	et	4	main
selle	doc_491521502244_item	3662168	et	4	main
see	doc_491521502244_item	3662174	et	3	main
ajalugu	doc_491521502244_item	3662170	et	4	main
õpetajate	doc_491521502244_item	3662160	et	4	main
mineviku	doc_491521502244_item	3662155	et	3	main
meelest	doc_491521502244_item	3662132	et	4	main
nagu	doc_491521502244_item	3662123	et	3	main
inimeste	doc_491521502244_item	3662120	et	3	main
mitte-eestlastest	doc_491521502244_item	3662108	et	4	main
sobiks	doc_491521502244_item	3662107	et	4	main
o	doc_491521502244_item	3662103	et	4	main
minu	doc_491521502244_item	3662100	et	3	main
sellel	doc_491521502244_item	3662094	et	4	main
erinevust	doc_491521502244_item	3662093	et	4	main
muulaste	doc_491521502244_item	3662092	et	4	main
ja	doc_491521502244_item	3662091	et	3	main
eestlaste	doc_491521502244_item	3662090	et	4	main
vähendada	doc_491521502244_item	3662089	et	3	main
rahvast	doc_491521502244_item	3662088	et	4	main
üleliidu	doc_491521502244_item	3662087	et	3	main
luua	doc_491521502244_item	3662086	et	4	main
ja	doc_491521502244_item	3662085	et	3	main
tähtsus	doc_491521502244_item	3662084	et	4	main
eestisse	doc_491521502244_item	3662066	et	4	main
arvan	doc_491521502244_item	3662062	et	3	main
venestuspoliitika	doc_491521502244_item	3662060	et	4	main
ja	doc_491521502244_item	3662049	et	3	main
eluga	doc_491521502244_item	3662046	et	3	main
eriloaga	doc_491521502244_item	3662039	et	4	main
ainult	doc_491521502244_item	3662038	et	4	main
need	doc_491521502244_item	3662029	et	3	main
ja	doc_491521502244_item	3662019	et	3	main
elasid	doc_491521502244_item	3662018	et	4	main
kus	doc_491521502244_item	3662017	et	3	main
linnad	doc_491521502244_item	3662016	et	3	main
mõned	doc_491521502244_item	3662015	et	3	main
loodusobjekte	doc_491521502244_item	3662014	et	3	main
nappis	doc_491521502244_item	3662010	et	3	main
ei	doc_491521502244_item	3661974	et	4	main
ettevoted	doc_491521502244_item	3661951	et	4	main
need	doc_491521502244_item	3661950	et	3	main
põhja-eestis	doc_491521502244_item	3661949	et	3	main
ja	doc_491521502244_item	3661948	et	3	main
elektrijaam	doc_491521502244_item	3661947	et	3	main
soojus	doc_491521502244_item	3661946	et	4	main
balti	doc_491521502244_item	3661945	et	3	main
ettevõted	doc_491521502244_item	3661937	et	4	main
suured	doc_491521502244_item	3661936	et	3	main
uued	doc_491521502244_item	3661935	et	3	main
kõigepealt	doc_491521502244_item	3661934	et	3	main
tuleks	doc_491521502244_item	3661924	et	4	main
ajal	doc_491521502245_item	3662446	et	4	main
ja	doc_491521502245_item	3662437	et	3	main
talumeeste	doc_491521502245_item	3662436	et	4	main
aga	doc_491521502245_item	3662429	et	3	main
õpilastele	doc_491521502245_item	3662428	et	4	main
eestis	doc_491521502245_item	3662411	et	3	main
ka	doc_491521502245_item	3662408	et	3	main
suunati	doc_491521502245_item	3662396	et	4	main
saamist	doc_491521502245_item	3662395	et	4	main
ameti	doc_491521502245_item	3662394	et	3	main
loaga	doc_491521502245_item	3662391	et	4	main
üldse	doc_491521502245_item	3662382	et	3	main
saarele	doc_491521502245_item	3662380	et	3	main
tsoonid	doc_491521502245_item	3662375	et	3	main
on	doc_491521502245_item	3662373	et	4	main
tahavad	doc_491521502245_item	3662372	et	3	main
nad	doc_491521502245_item	3662371	et	3	main
elavad	doc_491521502244_item	3662173	et	4	main
nad	doc_491521502244_item	3662172	et	3	main
on	doc_491521502244_item	3662164	et	4	main
tähtis	doc_491521502244_item	3662150	et	4	main
väga	doc_491521502244_item	3662149	et	3	main
eesti	doc_491521502244_item	3662140	et	4	main
ka	doc_491521502244_item	3662139	et	3	main
aga	doc_491521502244_item	3662138	et	3	main
minu	doc_491521502244_item	3662131	et	3	main
noorte	doc_491521502244_item	3662119	et	3	main
selgelt	doc_491521502244_item	3662116	et	4	main
poolest	doc_491521502244_item	3662113	et	4	main
selle	doc_491521502244_item	3662112	et	4	main
kõigepealt	doc_491521502244_item	3662111	et	3	main
järgi	doc_491521502244_item	3662106	et	4	main
film	doc_491521502244_item	3662102	et	3	main
2	doc_491521502244_item	3662099	et	2	main
vastupidine	doc_491521502244_item	3662097	et	3	main
oli	doc_491521502244_item	3662095	et	3	main
eestlaste	doc_491521502244_item	3662082	et	4	main
et	doc_491521502244_item	3662080	et	3	main
tingitud	doc_491521502244_item	3662068	et	4	main
vool	doc_491521502244_item	3662065	et	4	main
ma	doc_491521502244_item	3662061	et	3	main
algas	doc_491521502244_item	3662059	et	3	main
et	doc_491521502244_item	3662058	et	3	main
sellele	doc_491521502244_item	3662057	et	4	main
migrantide	doc_491521502244_item	3662050	et	3	main
erinevus	doc_491521502244_item	3662047	et	4	main
lubatud	doc_491521502244_item	3662037	et	4	main
oli	doc_491521502244_item	3662036	et	3	main
sissepääs	doc_491521502244_item	3662035	et	3	main
kuhu	doc_491521502244_item	3662034	et	3	main
narva	doc_491521502244_item	3662028	et	4	main
töötasid	doc_491521502244_item	3662020	et	4	main
kiir	doc_491521502244_item	3662002	et	4	main
ettevõtete	doc_491521502244_item	3662001	et	3	main
suurte	doc_491521502244_item	3662000	et	3	main
järjekorrata	doc_491521502244_item	3661999	et	3	main
15-20	doc_491521502244_item	3661991	et	2	main
jaoks	doc_491521502244_item	3661987	et	4	main
osaks	doc_491521502244_item	3661983	et	3	main
seda	doc_491521502244_item	3661980	et	3	main
omapära	doc_491521502244_item	3661977	et	4	main
eesti	doc_491521502244_item	3661976	et	4	main
tekkisid	doc_491521502244_item	3661968	et	4	main
siis	doc_491521502244_item	3661967	et	3	main
aastal	doc_491521502244_item	3661966	et	3	main
inimest	doc_491521502244_item	3661965	et	3	main
20000	doc_491521502244_item	3661964	et	2	main
seotus	doc_491521502244_item	3661942	et	4	main
järgi	doc_491521502244_item	3661933	et	4	main
parandada	doc_491521502244_item	3661923	et	3	main
seosed	doc_491521502244_item	3661887	et	3	main
migratsiooni	doc_491521502244_item	3661886	et	4	main
ja	doc_491521502244_item	3661885	et	3	main
majanduse	doc_491521502244_item	3661884	et	4	main
kontrolltöö	doc_491521502244_item	3661882	et	4	main
1	doc_491521502244_item	3661883	et	2	main
milline	doc_491521502245_item	3662449	et	3	main
hästi	doc_491521502245_item	3662442	et	3	main
mitte-eestlastele	doc_491521502245_item	3662427	et	4	main
õpilastele	doc_491521502245_item	3662423	et	4	main
õppevahendiks	doc_491521502245_item	3662421	et	3	main
sobiks	doc_491521502245_item	3662418	et	4	main
lutsu	doc_491521502245_item	3662416	et	4	main
et	doc_491521502245_item	3662415	et	3	main
arvan	doc_491521502245_item	3662414	et	3	main
ma	doc_491521502245_item	3662413	et	3	main
2	doc_491521502245_item	3662412	et	2	main
sees	doc_491521502245_item	3662409	et	4	main
oli	doc_491521502245_item	3662400	et	3	main
kuhu	doc_491521502245_item	3662399	et	3	main
sinna	doc_491521502245_item	3662398	et	3	main
inimest	doc_491521502245_item	3662397	et	3	main
oleviku	doc_491521502244_item	3662157	et	3	main
ja	doc_491521502244_item	3662156	et	3	main
see	doc_491521502244_item	3662147	et	3	main
näide	doc_491521502244_item	3662146	et	3	main
mitte-eestlastele	doc_491521502244_item	3662137	et	4	main
rõõmud	doc_491521502244_item	3662130	et	3	main
nende	doc_491521502244_item	3662127	et	4	main
õpilastele	doc_491521502244_item	3662110	et	4	main
kevade	doc_491521502244_item	3662105	et	4	main
nappimisega	doc_491521502244_item	3662072	et	4	main
tööjõu	doc_491521502244_item	3662071	et	3	main
tänu	doc_491521502244_item	3662056	et	4	main
oma	doc_491521502244_item	3662045	et	4	main
väikesed	doc_491521502244_item	3662041	et	4	main
migrantid	doc_491521502244_item	3662021	et	4	main
rohkem	doc_491521502244_item	3662009	et	4	main
halvenemist	doc_491521502244_item	3662007	et	4	main
loodusprobleemide	doc_491521502244_item	3662006	et	3	main
kaasa	doc_491521502244_item	3662005	et	4	main
tõi	doc_491521502244_item	3662004	et	3	main
arenemine	doc_491521502244_item	3662003	et	4	main
tihti	doc_491521502244_item	3661995	et	3	main
migrantid	doc_491521502244_item	3661994	et	4	main
siis	doc_491521502244_item	3661993	et	3	main
aastani	doc_491521502244_item	3661992	et	3	main
vaid	doc_491521502244_item	3661978	et	3	main
peamiselt	doc_491521502244_item	3661961	et	4	main
järsk	doc_491521502244_item	3661957	et	3	main
algas	doc_491521502244_item	3661956	et	3	main
siis	doc_491521502244_item	3661955	et	3	main
kaevandamisega	doc_491521502244_item	3661944	et	4	main
skeemi	doc_491521502244_item	3661932	et	4	main
keskvõim	doc_491521502244_item	3661928	et	3	main
lahendusi	doc_491521502244_item	3661927	et	4	main
uusi	doc_491521502244_item	3661926	et	3	main
leida	doc_491521502244_item	3661925	et	3	main
kruusemendilutsu	doc_491521502244_item	3661892	et	4	main
oli	doc_491521502245_item	3662450	et	3	main
tol	doc_491521502245_item	3662445	et	3	main
on	doc_491521502245_item	3662441	et	4	main
elu	doc_491521502245_item	3662439	et	4	main
kirjeldatud	doc_491521502245_item	3662434	et	4	main
ainult	doc_491521502245_item	3662426	et	4	main
omapärane	doc_491521502245_item	3662405	et	4	main
vaja	doc_491521502245_item	3662402	et	4	main
teda	doc_491521502245_item	3662401	et	4	main
olid	doc_491521502245_item	3662385	et	4	main
aj	doc_491521502245_item	3662378	et	4	main
omapärased	doc_491521502245_item	3662374	et	4	main
nägu	doc_491521502245_item	3662370	et	4	main
nii	doc_491521502245_item	3662369	et	3	main
töölised	doc_491521502245_item	3662350	et	3	main
paldiski	doc_491521502245_item	3662347	et	4	main
pääse	doc_491521502245_item	3662345	et	4	main
ei	doc_491521502245_item	3662344	et	4	main
suurenes	doc_491521502245_item	3662332	et	4	main
arv	doc_491521502245_item	3662331	et	3	main
rahvast	doc_491521502245_item	3662329	et	4	main
kohalikusest	doc_491521502245_item	3662328	et	4	main
nad	doc_491521502245_item	3662320	et	3	main
kiire	doc_491521502245_item	3662315	et	4	main
haritlase	doc_491521502245_item	3662298	et	3	main
tasemele	doc_491521502245_item	3662279	et	3	main
kõrgele	doc_491521502245_item	3662277	et	4	main
tehaseid	doc_491521502245_item	3662274	et	3	main
raskeks	doc_491521502245_item	3662271	et	3	main
väga	doc_491521502245_item	3662270	et	3	main
ainult	doc_491521502244_item	3662070	et	4	main
mitte	doc_491521502244_item	3662069	et	3	main
osaliselt	doc_491521502244_item	3662055	et	4	main
eestlaste	doc_491521502244_item	3662048	et	4	main
elasid	doc_491521502244_item	3662044	et	4	main
linnas	doc_491521502244_item	3662033	et	4	main
sillamäe	doc_491521502244_item	3662027	et	3	main
linna	doc_491521502244_item	3662024	et	4	main
said	doc_491521502244_item	3662022	et	4	main
kõige	doc_491521502244_item	3662008	et	4	main
ilma	doc_491521502244_item	3661998	et	4	main
elupinda	doc_491521502244_item	3661997	et	4	main
suurenes	doc_491521502244_item	3661990	et	4	main
korteri	doc_491521502244_item	3661988	et	3	main
põliselanikute	doc_491521502244_item	3661986	et	4	main
kui	doc_491521502244_item	3661985	et	3	main
nt	doc_491521502244_item	3661984	et	4	main
tunnustanud	doc_491521502244_item	3661975	et	4	main
umbes	doc_491521502244_item	3661963	et	4	main
venelased	doc_491521502244_item	3661962	et	3	main
vool	doc_491521502244_item	3661959	et	4	main
migrantide	doc_491521502244_item	3661958	et	3	main
tööjõudu	doc_491521502244_item	3661954	et	4	main
aga	doc_491521502244_item	3661953	et	3	main
nõudsid	doc_491521502244_item	3661952	et	4	main
põlevkivi	doc_491521502244_item	3661943	et	4	main
peamiselt	doc_491521502244_item	3661940	et	4	main
et	doc_491521502244_item	3661921	et	3	main
selleks	doc_491521502244_item	3661920	et	4	main
süvenemine	doc_491521502244_item	3661919	et	4	main
probleemide	doc_491521502244_item	3661918	et	3	main
kultuuri	doc_491521502244_item	3661917	et	4	main
ja	doc_491521502244_item	3661916	et	3	main
majanduse	doc_491521502244_item	3661915	et	4	main
toimus	doc_491521502244_item	3661914	et	3	main
siis	doc_491521502244_item	3661913	et	3	main
ajaloos	doc_491521502244_item	3661912	et	4	main
eesti	doc_491521502244_item	3661911	et	4	main
algus	doc_491521502244_item	3661910	et	4	main
perioodi	doc_491521502244_item	3661909	et	4	main
stagnatsiooni	doc_491521502244_item	3661908	et	4	main
on	doc_491521502244_item	3661907	et	4	main
kõige	doc_491521502244_item	3662180	et	4	main
olemust	doc_491521502244_item	3662179	et	3	main
eestlaste	doc_491521502244_item	3662178	et	4	main
mõista	doc_491521502244_item	3662177	et	4	main
aastad	doc_491521502244_item	3661906	et	3	main
1970ndad	doc_491521502244_item	3661905	et	4	main
1	doc_491521502244_item	3661904	et	2	main
õpilastele	doc_491521502244_item	3661903	et	4	main
põhikooli	doc_491521502244_item	3661902	et	4	main
mitte-eestlastest	doc_491521502244_item	3661901	et	4	main
õppevahendiks	doc_491521502244_item	3661900	et	3	main
film	doc_491521502244_item	3661899	et	3	main
see	doc_491521502244_item	3661898	et	3	main
sobiks	doc_491521502244_item	3661897	et	4	main
kuidas	doc_491521502244_item	3661896	et	3	main
ja	doc_491521502244_item	3661895	et	3	main
kas	doc_491521502244_item	3661894	et	3	main
kevade	doc_491521502244_item	3661893	et	4	main
1970ndate	doc_491521502244_item	3661888	et	4	main
õpetati	doc_491521502245_item	3662448	et	3	main
kuidas	doc_491521502245_item	3662444	et	3	main
seal	doc_491521502245_item	3662440	et	4	main
kooilaste	doc_491521502245_item	3662438	et	4	main
filmis	doc_491521502245_item	3662432	et	4	main
eestlasele	doc_491521502245_item	3662431	et	3	main
ka	doc_491521502245_item	3662430	et	3	main
aga	doc_491521502245_item	3662424	et	3	main
väga	doc_491521502245_item	3662419	et	3	main
kevad	doc_491521502245_item	3662417	et	3	main
et	doc_491521502245_item	3662404	et	3	main
nii	doc_491521502245_item	3662403	et	3	main
pärast	doc_491521502245_item	3662393	et	4	main
pääseda	doc_491521502245_item	3662384	et	3	main
ruhnu	doc_491521502245_item	3662379	et	4	main
kihnu	doc_491521502245_item	3662377	et	4	main
saa	doc_491521502245_item	3662365	et	4	main
ei	doc_491521502245_item	3662364	et	4	main
sinna	doc_491521502245_item	3662348	et	3	main
kuhu	doc_491521502245_item	3662341	et	3	main
venelaste	doc_491521502245_item	3662330	et	4	main
töötama	doc_491521502245_item	3662325	et	3	main
asuvad	doc_491521502245_item	3662321	et	4	main
arvu	doc_491521502245_item	3662318	et	4	main
valdkondi	doc_491521502245_item	3662309	et	4	main
elu	doc_491521502245_item	3662291	et	4	main
nsv-s	doc_491521502245_item	3662290	et	3	main
kuidas	doc_491521502245_item	3662289	et	3	main
euroopale	doc_491521502245_item	3662288	et	3	main
näidet	doc_491521502245_item	3662287	et	3	main
jõuda	doc_491521502245_item	3662276	et	3	main
juurde	doc_491521502245_item	3662273	et	4	main
ehitatakse	doc_491521502245_item	3662272	et	3	main
maal	doc_491521502245_item	3662268	et	4	main
elu	doc_491521502245_item	3662267	et	4	main
järgult	doc_491521502245_item	3662250	et	3	main
langes	doc_491521502245_item	3662248	et	4	main
aastatega	doc_491521502245_item	3662246	et	3	main
oli	doc_491521502245_item	3662242	et	3	main
esialgu	doc_491521502245_item	3662237	et	3	main
brežnev	doc_491521502245_item	3662221	et	2	main
võimule	doc_491521502245_item	3662219	et	3	main
1968	doc_491521502245_item	3662215	et	2	main
aastaid	doc_491521502245_item	3662212	et	4	main
kas	doc_491521502245_item	3662201	et	3	main
kruusemendilutsu	doc_491521502245_item	3662199	et	4	main
nsv-s	doc_491521502245_item	3662197	et	3	main
lõbus	doc_491521502245_item	3662511	et	4	main
on	doc_491521502245_item	3662509	et	4	main
see	doc_491521502245_item	3662508	et	3	main
vahel	doc_491521502245_item	3662507	et	4	main
koolimaja	doc_491521502245_item	3662501	et	4	main
riietus	doc_491521502245_item	3662500	et	4	main
koolielu	doc_491521502245_item	3662532	et	4	main
laste	doc_491521502245_item	3662531	et	4	main
tänaste	doc_491521502245_item	3662530	et	3	main
ja	doc_491521502245_item	3662529	et	3	main
tollaste	doc_491521502245_item	3662528	et	3	main
võrrelda	doc_491521502245_item	3662527	et	4	main
ka	doc_491521502245_item	3662526	et	3	main
saab	doc_491521502245_item	3662525	et	3	main
kultuuri	doc_491521502245_item	3662524	et	4	main
eesti	doc_491521502245_item	3662523	et	4	main
mõista	doc_491521502245_item	3662522	et	4	main
parem	doc_491521502245_item	3662521	et	4	main
saavad	doc_491521502245_item	3662520	et	4	main
lapsed	doc_491521502245_item	3662519	et	3	main
vene	doc_491521502245_item	3662518	et	4	main
võib-olla	doc_491521502245_item	3662517	et	3	main
õpetlik	doc_491521502245_item	3662516	et	3	main
väga	doc_491521502245_item	3662515	et	3	main
on	doc_491521502245_item	3662514	et	4	main
koolis	doc_491521502245_item	3662447	et	4	main
näha	doc_491521502245_item	3662443	et	3	main
eesti	doc_491521502245_item	3662435	et	4	main
on	doc_491521502245_item	3662433	et	4	main
mitte	doc_491521502245_item	3662425	et	3	main
põhikooli	doc_491521502245_item	3662422	et	4	main
hästi	doc_491521502245_item	3662420	et	3	main
pool	doc_491521502245_item	3662410	et	4	main
toimus	doc_491521502245_item	3662407	et	3	main
migratsioon	doc_491521502245_item	3662406	et	3	main
kohad	doc_491521502245_item	3662386	et	4	main
polnud	doc_491521502245_item	3662381	et	3	main
maal	doc_491521502245_item	3662368	et	4	main
omal	doc_491521502245_item	3662367	et	3	main
liikuda	doc_491521502245_item	3662366	et	3	main
eestlased	doc_491521502245_item	3662363	et	3	main
töötajad	doc_491521502245_item	3662362	et	4	main
saadetud	doc_491521502245_item	3662361	et	4	main
nsvliidust	doc_491521502245_item	3662360	et	4	main
ainult	doc_491521502245_item	3662359	et	4	main
elama	doc_491521502245_item	3662358	et	3	main
asuvad	doc_491521502245_item	3662357	et	4	main
kus	doc_491521502245_item	3662356	et	3	main
regioonid	doc_491521502245_item	3662355	et	3	main
terved	doc_491521502245_item	3662354	et	4	main
olemas	doc_491521502245_item	3662353	et	4	main
on	doc_491521502245_item	3662352	et	4	main
venemaalt	doc_491521502245_item	3662351	et	3	main
sattuvad	doc_491521502245_item	3662349	et	4	main
eestlased	doc_491521502245_item	3662342	et	3	main
ilmuvad	doc_491521502245_item	3662338	et	4	main
suurenesid	doc_491521502245_item	3662335	et	4	main
ka	doc_491521502245_item	3662334	et	3	main
ja	doc_491521502245_item	3662333	et	3	main
midagi	doc_491521502245_item	3662327	et	4	main
siia	doc_491521502245_item	3662322	et	4	main
toimub	doc_491521502245_item	3662314	et	3	main
teisi	doc_491521502245_item	3662308	et	4	main
ka	doc_491521502245_item	3662307	et	3	main
ja	doc_491521502245_item	3662306	et	3	main
selleks	doc_491521502245_item	3662299	et	4	main
ja	doc_491521502245_item	3662297	et	3	main
jätku	doc_491521502245_item	3662295	et	4	main
tahetakse	doc_491521502245_item	3662285	et	4	main
ei	doc_491521502245_item	3662282	et	4	main
majanduslikule	doc_491521502245_item	3662278	et	3	main
püütakse	doc_491521502245_item	3662275	et	3	main
mis	doc_491521502245_item	3662244	et	4	main
saab	doc_491521502245_item	3662224	et	3	main
aega	doc_491521502245_item	3662223	et	4	main
tuli	doc_491521502245_item	3662220	et	4	main
ja	doc_491521502245_item	3662218	et	3	main
lõppes	doc_491521502245_item	3662216	et	4	main
stagnatsiooniperioodiks	doc_491521502245_item	3662214	et	3	main
film	doc_491521502245_item	3662206	et	3	main
see	doc_491521502245_item	3662205	et	3	main
1	doc_491521502245_item	3662190	et	2	main
kontrolltöö	doc_491521502245_item	3662189	et	4	main
töötajate	doc_491521502245_item	3662506	et	4	main
nägu	doc_491521502245_item	3662499	et	4	main
pisiasjad	doc_491521502245_item	3662498	et	3	main
tavalise	doc_491521502245_item	3662483	et	4	main
vene	doc_491521502245_item	3662475	et	4	main
lapsed	doc_491521502245_item	3662473	et	3	main
talviseid	doc_491521502245_item	3662471	et	4	main
peetkase	doc_491521502245_item	3662470	et	3	main
minna	doc_491521502245_item	3662392	et	3	main
spetsiaalse	doc_491521502245_item	3662390	et	3	main
ainult	doc_491521502245_item	3662389	et	4	main
sai	doc_491521502245_item	3662388	et	4	main
kuhu	doc_491521502245_item	3662387	et	3	main
võimalik	doc_491521502245_item	3662383	et	3	main
näiteks	doc_491521502245_item	3662376	et	4	main
üldse	doc_491521502245_item	3662343	et	3	main
kinnised	doc_491521502245_item	3662339	et	4	main
probleemid	doc_491521502245_item	3662337	et	3	main
omavahelised	doc_491521502245_item	3662336	et	4	main
teadmata	doc_491521502245_item	3662326	et	4	main
ja	doc_491521502245_item	3662324	et	3	main
kasv	doc_491521502245_item	3662319	et	3	main
venelaste	doc_491521502245_item	3662317	et	4	main
välismaalaste	doc_491521502245_item	3662316	et	4	main
eestisse	doc_491521502245_item	3662313	et	4	main
suunatakse	doc_491521502245_item	3662311	et	4	main
venemaalt	doc_491521502245_item	3662310	et	3	main
põlevkivi	doc_491521502245_item	3662302	et	4	main
arendada	doc_491521502245_item	3662301	et	3	main
et	doc_491521502245_item	3662300	et	3	main
spetsialiste	doc_491521502245_item	3662296	et	3	main
ei	doc_491521502245_item	3662294	et	4	main
siin	doc_491521502245_item	3662293	et	4	main
käib	doc_491521502245_item	3662292	et	3	main
eestist	doc_491521502245_item	3662284	et	3	main
õnnestu	doc_491521502245_item	3662283	et	4	main
see	doc_491521502245_item	3662281	et	3	main
kuigi	doc_491521502245_item	3662280	et	3	main
urbaniseerumine	doc_491521502245_item	3662266	et	4	main
olukord	doc_491521502245_item	3662241	et	3	main
majanduse	doc_491521502245_item	3662238	et	4	main
sulaperiood	doc_491521502245_item	3662217	et	3	main
nimetatakse	doc_491521502245_item	3662213	et	3	main
70	doc_491521502245_item	3662211	et	2	main
õpilastele	doc_491521502245_item	3662210	et	4	main
kuidas	doc_491521502245_item	3662203	et	3	main
kevade	doc_491521502245_item	3662200	et	4	main
film	doc_491521502245_item	3662512	et	3	main
ja	doc_491521502245_item	3662504	et	3	main
õpilaste	doc_491521502245_item	3662503	et	4	main
sellised	doc_491521502245_item	3662497	et	4	main
huvitavad	doc_491521502245_item	3662496	et	4	main
jaoks	doc_491521502245_item	3662493	et	4	main
saavad	doc_491521502245_item	3662480	et	4	main
ka	doc_491521502245_item	3662477	et	3	main
nii	doc_491521502245_item	3662474	et	3	main
pühi	doc_491521502245_item	3662472	et	4	main
last	doc_491521502245_item	3662469	et	4	main
sillamäe	doc_491521502245_item	3662346	et	3	main
linnad	doc_491521502245_item	3662340	et	3	main
elama	doc_491521502245_item	3662323	et	3	main
tööjõud	doc_491521502245_item	3662312	et	4	main
elektritööstust	doc_491521502245_item	3662305	et	4	main
ja	doc_491521502245_item	3662304	et	3	main
nafta-	doc_491521502245_item	3662303	et	4	main
teha	doc_491521502245_item	3662286	et	3	main
saab	doc_491521502245_item	3662269	et	3	main
toimub	doc_491521502245_item	3662265	et	3	main
elektri-toodangut	doc_491521502245_item	3662264	et	3	main
ja	doc_491521502245_item	3662263	et	3	main
nafta-	doc_491521502245_item	3662262	et	4	main
arendada	doc_491521502245_item	3662261	et	3	main
püütakse	doc_491521502245_item	3662260	et	3	main
võimalik	doc_491521502245_item	3662259	et	3	main
ole	doc_491521502245_item	3662258	et	4	main
ei	doc_491521502245_item	3662257	et	4	main
teha	doc_491521502245_item	3662256	et	3	main
praktiliselt	doc_491521502245_item	3662255	et	4	main
mida	doc_491521502245_item	3662254	et	4	main
palju	doc_491521502245_item	3662253	et	4	main
nõuab	doc_491521502245_item	3662252	et	3	main
riik	doc_491521502245_item	3662251	et	3	main
järg	doc_491521502245_item	3662249	et	3	main
juurdekasv	doc_491521502245_item	3662247	et	3	main
sulaajal	doc_491521502245_item	3662245	et	3	main
ja	doc_491521502245_item	3662240	et	3	main
põhikooli	doc_491521502245_item	3662209	et	4	main
ja	doc_491521502245_item	3662202	et	3	main
2	doc_491521502245_item	3662198	et	2	main
eesti	doc_491521502245_item	3662196	et	4	main
1970ndate	doc_491521502245_item	3662195	et	4	main
seosed	doc_491521502245_item	3662194	et	3	main
mis	doc_491521502245_item	3662513	et	4	main
hea	doc_491521502245_item	3662510	et	4	main
suhted	doc_491521502245_item	3662502	et	3	main
isegi	doc_491521502245_item	3662495	et	4	main
olid	doc_491521502245_item	3662494	et	4	main
minu	doc_491521502245_item	3662492	et	3	main
süsteemist	doc_491521502245_item	3662491	et	4	main
kooli	doc_491521502245_item	3662490	et	4	main
ka	doc_491521502245_item	3662489	et	3	main
ja	doc_491521502245_item	3662488	et	3	main
probleemidest	doc_491521502245_item	3662487	et	3	main
ja	doc_491521502245_item	3662486	et	3	main
elust	doc_491521502245_item	3662485	et	3	main
rahva	doc_491521502245_item	3662484	et	3	main
omad	doc_491521502245_item	3662479	et	4	main
sama	doc_491521502245_item	3662243	et	4	main
kasv	doc_491521502245_item	3662239	et	3	main
tagasi	doc_491521502245_item	3662236	et	3	main
tulid	doc_491521502245_item	3662235	et	4	main
stalinismile	doc_491521502245_item	3662234	et	4	main
iseloomulikud	doc_491521502245_item	3662233	et	3	main
olid	doc_491521502245_item	3662232	et	4	main
mis	doc_491521502245_item	3662231	et	4	main
jooned	doc_491521502245_item	3662230	et	3	main
paljud	doc_491521502245_item	3662229	et	3	main
sest	doc_491521502245_item	3662228	et	4	main
taasstalinismiks	doc_491521502245_item	3662227	et	4	main
ka	doc_491521502245_item	3662226	et	3	main
nimetada	doc_491521502245_item	3662225	et	3	main
seda	doc_491521502245_item	3662222	et	3	main
mitte-eestlastest	doc_491521502245_item	3662208	et	4	main
õppevahendiks	doc_491521502245_item	3662207	et	3	main
sobiks	doc_491521502245_item	3662204	et	4	main
migratsiooni	doc_491521502245_item	3662193	et	4	main
ja	doc_491521502245_item	3662192	et	3	main
majanduse	doc_491521502245_item	3662191	et	4	main
kooli	doc_491521502245_item	3662505	et	4	main
hea	doc_491521502245_item	3662481	et	4	main
kui	doc_491521502245_item	3662476	et	3	main
ristitakse	doc_491521502245_item	3662468	et	4	main
nõukogude	doc_491521502246_item	3662810	et	3	main
sõjast	doc_491521502246_item	3662793	et	3	main
oma	doc_491521502246_item	3662786	et	4	main
looming	doc_491521502246_item	3662781	et	3	main
horoskoop	doc_491521502246_item	3662778	et	3	main
keemias	doc_491521502246_item	3662776	et	3	main
matemaatikas	doc_491521502246_item	3662775	et	3	main
panna	doc_491521502246_item	3662774	et	4	main
teadmisi	doc_491521502246_item	3662773	et	4	main
oli	doc_491521502246_item	3662772	et	3	main
telekanalid	doc_491521502246_item	3662769	et	3	main
mitte	doc_491521502246_item	3662766	et	3	main
pükstes	doc_491521502246_item	3662764	et	3	main
jne	doc_491521502246_item	3662740	et	4	main
kriimsilm	doc_491521502246_item	3662739	et	3	main
hunt	doc_491521502246_item	3662738	et	3	main
lastesaateid	doc_491521502246_item	3662737	et	3	main
näidati	doc_491521502246_item	3662736	et	3	main
saateid	doc_491521502246_item	3662735	et	3	main
13	doc_491521502246_item	3662730	et	2	main
on	doc_491521502246_item	3662721	et	4	main
7	doc_491521502246_item	3662718	et	2	main
saadet	doc_491521502246_item	3662717	et	3	main
ettekujutuse	doc_491521502245_item	3662482	et	4	main
eesti	doc_491521502245_item	3662478	et	4	main
kuidas	doc_491521502245_item	3662467	et	3	main
näha	doc_491521502245_item	3662466	et	3	main
saab	doc_491521502245_item	3662465	et	3	main
traditsioonidest	doc_491521502245_item	3662464	et	3	main
eesti	doc_491521502245_item	3662463	et	4	main
ettekujutuse	doc_491521502245_item	3662462	et	4	main
ka	doc_491521502245_item	3662461	et	3	main
saab	doc_491521502245_item	3662460	et	3	main
filmis	doc_491521502245_item	3662459	et	4	main
selles	doc_491521502245_item	3662458	et	4	main
probleemid	doc_491521502245_item	3662457	et	3	main
omavahelised	doc_491521502245_item	3662456	et	4	main
sakslastega	doc_491521502245_item	3662455	et	3	main
suhted	doc_491521502245_item	3662454	et	3	main
kord	doc_491521502245_item	3662453	et	4	main
kooli	doc_491521502245_item	3662452	et	4	main
sisene	doc_491521502245_item	3662451	et	4	main
telerist	doc_491521502246_item	3662815	et	4	main
olema	doc_491521502246_item	3662809	et	4	main
kus	doc_491521502246_item	3662803	et	3	main
reklaamindus	doc_491521502246_item	3662800	et	3	main
täpp	doc_491521502246_item	3662797	et	3	main
aj	doc_491521502246_item	3662796	et	4	main
tipp	doc_491521502246_item	3662795	et	3	main
nukulavastused	doc_491521502246_item	3662794	et	3	main
loole	doc_491521502246_item	3662790	et	4	main
laulud	doc_491521502246_item	3662782	et	3	main
oma	doc_491521502246_item	3662780	et	4	main
loodusteaduses	doc_491521502246_item	3662777	et	3	main
veel	doc_491521502246_item	3662767	et	4	main
lubati	doc_491521502246_item	3662762	et	3	main
kontrollima	doc_491521502246_item	3662758	et	4	main
teatris	doc_491521502246_item	3662749	et	3	main
äia	doc_491521502246_item	3662748	et	4	main
eestlased	doc_491521502246_item	3662746	et	3	main
oli	doc_491521502246_item	3662731	et	3	main
praegune	doc_491521502246_item	3662728	et	3	main
samuti	doc_491521502246_item	3662726	et	3	main
pidi	doc_491521502246_item	3662808	et	4	main
kaupu	doc_491521502246_item	3662806	et	3	main
näidati	doc_491521502246_item	3662791	et	3	main
meeldinud	doc_491521502246_item	3662789	et	4	main
enam	doc_491521502246_item	3662788	et	4	main
ülesandeks	doc_491521502246_item	3662771	et	4	main
käia	doc_491521502246_item	3662763	et	4	main
muulased	doc_491521502246_item	3662750	et	4	main
armastasid	doc_491521502246_item	3662747	et	4	main
võimalus	doc_491521502246_item	3662745	et	3	main
oli	doc_491521502246_item	3662744	et	3	main
televiktoriinid	doc_491521502246_item	3662743	et	3	main
olümpiaadid	doc_491521502246_item	3662742	et	3	main
toimusid	doc_491521502246_item	3662741	et	4	main
ka	doc_491521502246_item	3662732	et	3	main
õnne	doc_491521502246_item	3662729	et	4	main
ka	doc_491521502246_item	3662727	et	3	main
säilitanud	doc_491521502246_item	3662725	et	4	main
mis	doc_491521502246_item	3662720	et	4	main
vaprat	doc_491521502246_item	3662719	et	3	main
näitama	doc_491521502246_item	3662716	et	3	main
aastavahetus	doc_491521502246_item	3662813	et	4	main
kirjutatud	doc_491521502246_item	3662812	et	4	main
vaimus	doc_491521502246_item	3662811	et	4	main
tutvustati	doc_491521502246_item	3662804	et	4	main
dokumentaalkaadreid	doc_491521502246_item	3662792	et	3	main
autorite	doc_491521502246_item	3662779	et	3	main
nende	doc_491521502246_item	3662770	et	4	main
aga	doc_491521502246_item	3662765	et	3	main
aga	doc_491521502246_item	3662751	et	3	main
keelega	doc_491521502246_item	3662733	et	3	main
siiani	doc_491521502246_item	3662724	et	4	main
programm	doc_491521502246_item	3662814	et	3	main
kirjandus	doc_491521502246_item	3662807	et	3	main
uusi	doc_491521502246_item	3662805	et	3	main
meelelahutussaade	doc_491521502246_item	3662802	et	4	main
reklaamiklubid	doc_491521502246_item	3662801	et	3	main
eesti	doc_491521502246_item	3662799	et	4	main
tegutses	doc_491521502246_item	3662798	et	3	main
hääl	doc_491521502246_item	3662787	et	3	main
anda	doc_491521502246_item	3662785	et	3	main
võimalus	doc_491521502246_item	3662784	et	3	main
oli	doc_491521502246_item	3662783	et	3	main
teksaastes	doc_491521502246_item	3662768	et	4	main
tüdrukutel	doc_491521502246_item	3662761	et	4	main
tundides	doc_491521502246_item	3662760	et	3	main
õpilase	doc_491521502246_item	3662759	et	3	main
hakati	doc_491521502246_item	3662757	et	3	main
muutus	doc_491521502246_item	3662756	et	4	main
toimus	doc_491521502246_item	3662755	et	3	main
kooliprogrammis	doc_491521502246_item	3662754	et	3	main
kinos	doc_491521502246_item	3662753	et	3	main
pigem	doc_491521502246_item	3662752	et	3	main
seotud	doc_491521502246_item	3662734	et	4	main
oma	doc_491521502246_item	3662722	et	4	main
nime	doc_491521502246_item	3662723	et	4	main
hakati	doc_491521502246_item	3662715	et	3	main
6a	doc_491521502246_item	3662714	et	4	main
a	doc_491521502246_item	3662713	et	4	main
5	doc_491521502246_item	3662712	et	2	main
a	doc_491521502246_item	3662711	et	4	main
4	doc_491521502246_item	3662710	et	2	main
siis	doc_491521502246_item	3662709	et	3	main
aastased	doc_491521502246_item	3662708	et	4	main
3	doc_491521502246_item	3662707	et	2	main
algul	doc_491521502246_item	3662706	et	4	main
lapsed	doc_491521502246_item	3662705	et	3	main
pisikesed	doc_491521502246_item	3662704	et	4	main
esinema	doc_491521502246_item	3662703	et	3	main
hakkasid	doc_491521502246_item	3662702	et	4	main
entel-tentel	doc_491521502246_item	3662701	et	4	main
lapstähed	doc_491521502246_item	3662700	et	3	main
esinesid	doc_491521502246_item	3662699	et	4	main
etv	doc_491521502246_item	3662698	et	4	main
riigikanaleid	doc_491521502246_item	3662697	et	4	main
üks	doc_491521502246_item	3662696	et	3	main
oli	doc_491521502246_item	3662695	et	3	main
ajal	doc_491521502246_item	3662694	et	4	main
tollel	doc_491521502246_item	3662693	et	4	main
eestlase	doc_491521502246_item	3662692	et	3	main
925000	doc_491521502246_item	3662691	et	2	main
elas	doc_491521502246_item	3662690	et	3	main
eestis	doc_491521502246_item	3662689	et	3	main
1	doc_491521502246_item	3662688	et	2	main
musternäidis	doc_491521502246_item	3662687	et	4	main
realismi	doc_491521502246_item	3662686	et	4	main
sotsialistliku	doc_491521502246_item	3662685	et	3	main
kui	doc_491521502246_item	3662684	et	3	main
koordis	doc_491521502246_item	3662683	et	4	main
valgus	doc_491521502246_item	3662682	et	4	main
2	doc_491521502246_item	3662681	et	2	main
nsvs	doc_491521502246_item	3662680	et	4	main
eesti	doc_491521502246_item	3662679	et	4	main
1970ndate	doc_491521502246_item	3662678	et	4	main
kultuurielu	doc_491521502246_item	3662677	et	4	main
1	doc_491521502246_item	3662676	et	2	main
kontrolltöö	doc_491521502246_item	3662675	et	4	main
linna	doc_491521502248_item	3663503	et	4	main
kinni	doc_491521502248_item	3663500	et	3	main
maakooli	doc_491521502248_item	3663498	et	4	main
ei	doc_491521502248_item	3663487	et	4	main
kohalolekut	doc_491521502248_item	3663483	et	3	main
ei	doc_491521502248_item	3663470	et	4	main
puudus	doc_491521502248_item	3663465	et	4	main
koop	doc_491521502248_item	3663463	et	4	main
kaotas	doc_491521502248_item	3663453	et	3	main
tagajärjel	doc_491521502248_item	3663452	et	3	main
sügise	doc_491521502248_item	3663451	et	3	main
ka	doc_491521502248_item	3663447	et	3	main
ära	doc_491521502248_item	3663445	et	4	main
vanu	doc_491521502248_item	3663442	et	4	main
parandati	doc_491521502248_item	3663441	et	3	main
rahvakultuurseid	doc_491521502248_item	3663440	et	3	main
mitte	doc_491521502248_item	3663439	et	3	main
tekste	doc_491521502248_item	3663438	et	3	main
70ndatel	doc_491521502248_item	3663430	et	4	main
ka	doc_491521502248_item	3663427	et	3	main
rääkisid	doc_491521502248_item	3663425	et	4	main
dokumentaalkaadreid	doc_491521502248_item	3663424	et	3	main
näidati	doc_491521502248_item	3663423	et	3	main
analüüsiti	doc_491521502248_item	3663422	et	3	main
25	doc_491521502248_item	3663412	et	2	main
lastesaadetele	doc_491521502248_item	3663402	et	3	main
70ndate	doc_491521502248_item	3663386	et	4	main
vaimus	doc_491521502248_item	3663374	et	4	main
nõukogude	doc_491521502248_item	3663373	et	3	main
kinos	doc_491521502248_item	3663369	et	3	main
televiktoriinid	doc_491521502248_item	3663362	et	3	main
väljaspool	doc_491521502248_item	3663358	et	3	main
teistele	doc_491521502248_item	3663356	et	4	main
saateid	doc_491521502248_item	3663351	et	3	main
keeleõppega	doc_491521502248_item	3663349	et	3	main
enda	doc_491521502248_item	3663333	et	4	main
sai	doc_491521502248_item	3663331	et	4	main
keeles	doc_491521502248_item	3663329	et	4	main
eesti	doc_491521502248_item	3663328	et	4	main
televisioonil	doc_491521502248_item	3663318	et	4	main
samuti	doc_491521502249_item	3663552	et	3	main
raamatuid	doc_491521502249_item	3663550	et	3	main
loeti	doc_491521502249_item	3663549	et	3	main
ja	doc_491521502249_item	3663548	et	3	main
ja	doc_491521502249_item	3663544	et	3	main
teatris	doc_491521502249_item	3663536	et	3	main
käis	doc_491521502249_item	3663535	et	4	main
are	doc_491521502249_item	3663526	et	3	main
arenema	doc_491521502249_item	3663524	et	3	main
musternäidis	doc_491521502249_item	3663517	et	4	main
sotsialistliku	doc_491521502249_item	3663515	et	3	main
eesti	doc_491521502249_item	3663509	et	4	main
1970ndate	doc_491521502249_item	3663508	et	4	main
kultuurielu	doc_491521502249_item	3663507	et	4	main
sotsialismist	doc_491521502249_item	3663739	et	4	main
lähtekohad	doc_491521502249_item	3663736	et	4	main
õppejõud	doc_491521502248_item	3663486	et	4	main
mõttelaad	doc_491521502248_item	3663479	et	3	main
aga	doc_491521502248_item	3663467	et	3	main
tü	doc_491521502248_item	3663454	et	4	main
folkloorliikumine	doc_491521502248_item	3663432	et	4	main
aktiviseerus	doc_491521502248_item	3663431	et	3	main
ii	doc_491521502248_item	3663416	et	4	main
käsitleb	doc_491521502248_item	3663415	et	3	main
tagasi	doc_491521502248_item	3663414	et	3	main
aastat	doc_491521502248_item	3663413	et	3	main
tipp	doc_491521502248_item	3663403	et	3	main
lõpus	doc_491521502248_item	3663387	et	4	main
välja	doc_491521502248_item	3663381	et	4	main
kolleegium	doc_491521502248_item	3663379	et	3	main
pidi	doc_491521502248_item	3663371	et	4	main
õppeprogrammi	doc_491521502248_item	3663360	et	4	main
huvilistele	doc_491521502248_item	3663357	et	4	main
ka	doc_491521502248_item	3663348	et	3	main
13	doc_491521502248_item	3663346	et	2	main
praegu	doc_491521502248_item	3663344	et	3	main
nagu	doc_491521502248_item	3663343	et	3	main
uudist	doc_491521502248_item	3663342	et	3	main
peres	doc_491521502248_item	3663341	et	3	main
koorta	doc_491521502248_item	3663340	et	4	main
hääle	doc_491521502248_item	3663334	et	3	main
anda	doc_491521502248_item	3663332	et	3	main
vapraga	doc_491521502248_item	3663325	et	3	main
praegu	doc_491521502248_item	3663323	et	3	main
sarnane	doc_491521502248_item	3663322	et	4	main
horoskoop	doc_491521502248_item	3663321	et	3	main
roll	doc_491521502248_item	3663320	et	3	main
sest	doc_491521502248_item	3663497	et	4	main
vähenes	doc_491521502248_item	3663496	et	3	main
maalaste	doc_491521502248_item	3663494	et	4	main
ka	doc_491521502248_item	3663492	et	3	main
ka	doc_491521502248_item	3663485	et	3	main
ülikoolis	doc_491521502248_item	3663480	et	4	main
ning	doc_491521502248_item	3663477	et	3	main
positsioon	doc_491521502248_item	3663476	et	3	main
oli	doc_491521502248_item	3663475	et	3	main
kõrgharidus	doc_491521502248_item	3663466	et	3	main
oma	doc_491521502248_item	3663456	et	4	main
rektor	doc_491521502248_item	3663455	et	3	main
vanu	doc_491521502248_item	3663448	et	4	main
õppida	doc_491521502248_item	3663446	et	3	main
üritati	doc_491521502248_item	3663444	et	3	main
pille	doc_491521502248_item	3663443	et	3	main
sõjasosalenud	doc_491521502248_item	3663428	et	4	main
täna	doc_491521502248_item	3663411	et	4	main
valdo	doc_491521502248_item	3663409	et	4	main
kriimsilm	doc_491521502248_item	3663407	et	3	main
suundus	doc_491521502248_item	3663502	et	4	main
rahvas	doc_491521502248_item	3663501	et	4	main
arv	doc_491521502248_item	3663495	et	3	main
kontrolliti	doc_491521502248_item	3663491	et	3	main
pandi	doc_491521502248_item	3663499	et	4	main
seda	doc_491521502248_item	3663493	et	3	main
hilineda	doc_491521502248_item	3663490	et	3	main
kontrollima	doc_491521502248_item	3663484	et	4	main
hakati	doc_491521502248_item	3663481	et	3	main
ajal	doc_491521502248_item	3663469	et	4	main
sel	doc_491521502248_item	3663468	et	3	main
kellel	doc_491521502248_item	3663464	et	4	main
arnold	doc_491521502248_item	3663462	et	4	main
ametisse	doc_491521502248_item	3663461	et	3	main
saab	doc_491521502248_item	3663460	et	3	main
asemele	doc_491521502248_item	3663459	et	4	main
tartu	doc_491521502248_item	3663450	et	4	main
laule	doc_491521502248_item	3663449	et	4	main
esitasid	doc_491521502248_item	3663434	et	4	main
külakapellid	doc_491521502248_item	3663433	et	3	main
sõda	doc_491521502248_item	3663420	et	4	main
mängiti	doc_491521502248_item	3663419	et	3	main
stuudios	doc_491521502248_item	3663418	et	3	main
maailmasõda	doc_491521502248_item	3663417	et	4	main
pant	doc_491521502248_item	3663410	et	3	main
jt	doc_491521502248_item	3663408	et	4	main
täpp	doc_491521502248_item	3663405	et	3	main
ja	doc_491521502248_item	3663404	et	3	main
tekstid	doc_491521502248_item	3663401	et	3	main
uno	doc_491521502248_item	3663398	et	4	main
ning	doc_491521502248_item	3663394	et	3	main
nsv-lik	doc_491521502248_item	3663385	et	4	main
vahetati	doc_491521502248_item	3663380	et	4	main
olema	doc_491521502248_item	3663372	et	4	main
haridussaateid	doc_491521502248_item	3663353	et	3	main
ning	doc_491521502248_item	3663352	et	3	main
tõsielusarja	doc_491521502248_item	3663338	et	4	main
esimest	doc_491521502248_item	3663337	et	4	main
näitama	doc_491521502248_item	3663336	et	3	main
rahvas	doc_491521502248_item	3663330	et	4	main
reklaami	doc_491521502248_item	3663317	et	4	main
saateid	doc_491521502248_item	3663314	et	3	main
1	doc_491521502248_item	3663307	et	2	main
realismi	doc_491521502248_item	3663305	et	4	main
sotsialistliku	doc_491521502248_item	3663304	et	3	main
kui	doc_491521502248_item	3663303	et	3	main
koordis	doc_491521502248_item	3663302	et	4	main
valgus	doc_491521502248_item	3663301	et	4	main
2	doc_491521502248_item	3663300	et	2	main
nsvs	doc_491521502248_item	3663299	et	4	main
eesti	doc_491521502248_item	3663298	et	4	main
1970ndate	doc_491521502248_item	3663297	et	4	main
kultuurielu	doc_491521502248_item	3663296	et	4	main
1	doc_491521502248_item	3663295	et	2	main
kontrolltöö	doc_491521502248_item	3663294	et	4	main
põhja-eestis	doc_491521502249_item	3663553	et	3	main
palju	doc_491521502249_item	3663546	et	4	main
odava	doc_491521502249_item	3663545	et	3	main
1970ndal	doc_491521502249_item	3663540	et	4	main
kinos	doc_491521502249_item	3663539	et	3	main
muulased	doc_491521502249_item	3663538	et	4	main
armastasid	doc_491521502249_item	3663534	et	4	main
eestlased	doc_491521502249_item	3663533	et	3	main
jne	doc_491521502249_item	3663532	et	4	main
kirjandus	doc_491521502249_item	3663527	et	3	main
1970ndate	doc_491521502249_item	3663520	et	4	main
realismi	doc_491521502249_item	3663516	et	4	main
kui	doc_491521502249_item	3663514	et	3	main
sotsialistliku	doc_491521502249_item	3663746	et	3	main
näidatud	doc_491521502249_item	3663745	et	4	main
filmis	doc_491521502249_item	3663741	et	4	main
tollest	doc_491521502249_item	3663732	et	4	main
näide	doc_491521502249_item	3663731	et	3	main
loomingumeetodina	doc_491521502249_item	3663724	et	3	main
nimetatud	doc_491521502249_item	3663723	et	4	main
loengusse	doc_491521502248_item	3663489	et	4	main
tohtinud	doc_491521502248_item	3663488	et	4	main
üliõpilaste	doc_491521502248_item	3663482	et	4	main
nõukogudelik	doc_491521502248_item	3663478	et	4	main
tähtis	doc_491521502248_item	3663474	et	4	main
esmatähtis	doc_491521502248_item	3663473	et	3	main
haridus	doc_491521502248_item	3663472	et	3	main
olnudki	doc_491521502248_item	3663471	et	4	main
tema	doc_491521502248_item	3663458	et	4	main
ameti	doc_491521502248_item	3663457	et	3	main
kohandatud	doc_491521502248_item	3663437	et	4	main
poolt	doc_491521502248_item	3663436	et	4	main
autori	doc_491521502248_item	3663435	et	3	main
inimesed	doc_491521502248_item	3663429	et	3	main
kaasa	doc_491521502248_item	3663426	et	4	main
läbi	doc_491521502248_item	3663421	et	4	main
hunt	doc_491521502248_item	3663406	et	3	main
leies	doc_491521502248_item	3663399	et	3	main
palju	doc_491521502248_item	3663396	et	4	main
teles	doc_491521502248_item	3663393	et	3	main
polnud	doc_491521502248_item	3663383	et	3	main
kuna	doc_491521502248_item	3663382	et	3	main
raamatukogu	doc_491521502248_item	3663378	et	4	main
loomingu	doc_491521502248_item	3663377	et	3	main
nt	doc_491521502248_item	3663376	et	4	main
armastati	doc_491521502248_item	3663363	et	3	main
ja	doc_491521502248_item	3663355	et	3	main
seotud	doc_491521502248_item	3663350	et	4	main
mis	doc_491521502248_item	3663339	et	4	main
õpetlik	doc_491521502248_item	3663319	et	3	main
hiljem	doc_491521502248_item	3663315	et	3	main
uusi	doc_491521502248_item	3663313	et	3	main
palju	doc_491521502248_item	3663312	et	4	main
näitama	doc_491521502248_item	3663310	et	3	main
hakkas	doc_491521502248_item	3663309	et	3	main
etv	doc_491521502248_item	3663308	et	4	main
musternäidis	doc_491521502248_item	3663306	et	4	main
telesaateid	doc_491521502249_item	3663557	et	3	main
populaarsed	doc_491521502249_item	3663555	et	3	main
ajalehti	doc_491521502249_item	3663551	et	4	main
olid	doc_491521502249_item	3663541	et	4	main
muusika	doc_491521502249_item	3663528	et	4	main
kultuurielu	doc_491521502249_item	3663519	et	4	main
koordis	doc_491521502249_item	3663513	et	4	main
2	doc_491521502249_item	3663511	et	2	main
nsvs	doc_491521502249_item	3663510	et	4	main
kontrolltöö	doc_491521502249_item	3663505	et	4	main
valgus	doc_491521502249_item	3663742	et	4	main
utoplikust	doc_491521502249_item	3663738	et	4	main
realismi	doc_491521502249_item	3663735	et	4	main
sotsialistliku	doc_491521502249_item	3663734	et	3	main
ajast	doc_491521502249_item	3663733	et	4	main
valgus	doc_491521502249_item	3663728	et	4	main
film	doc_491521502249_item	3663727	et	3	main
on	doc_491521502249_item	3663726	et	4	main
samamoodi	doc_491521502249_item	3663725	et	3	main
kunstiteadlased	doc_491521502249_item	3663719	et	3	main
mida	doc_491521502249_item	3663717	et	4	main
annab	doc_491521502249_item	3663708	et	3	main
ajal	doc_491521502249_item	3663705	et	4	main
realismi	doc_491521502249_item	3663704	et	4	main
sotsialistliku	doc_491521502249_item	3663703	et	3	main
koordis	doc_491521502249_item	3663691	et	4	main
eestlaste	doc_491521502249_item	3663685	et	4	main
edasisele	doc_491521502249_item	3663664	et	3	main
mõju	doc_491521502249_item	3663663	et	4	main
kultuurielu	doc_491521502249_item	3663657	et	4	main
filmikunstiga	doc_491521502249_item	3663651	et	4	main
kes	doc_491521502249_item	3663647	et	4	main
eest	doc_491521502249_item	3663641	et	4	main
luuletajad	doc_491521502249_item	3663592	et	4	main
reliikvia	doc_491521502249_item	3663586	et	4	main
viimane	doc_491521502249_item	3663585	et	3	main
lutsu	doc_491521502249_item	3663578	et	4	main
neist	doc_491521502249_item	3663573	et	4	main
sest	doc_491521502249_item	3663558	et	4	main
aus	doc_491521502250_item	3664132	et	4	main
komenteerima	doc_491521502250_item	3664130	et	4	main
seda	doc_491521502250_item	3664129	et	3	main
raske	doc_491521502250_item	3664128	et	4	main
väga	doc_491521502250_item	3664127	et	3	main
lõi	doc_491521502248_item	3663400	et	4	main
lastesaateid	doc_491521502248_item	3663397	et	3	main
hästi	doc_491521502248_item	3663395	et	3	main
aastavahetuseprogrammid	doc_491521502248_item	3663392	et	4	main
kultuuriüritus	doc_491521502248_item	3663391	et	3	main
noorte	doc_491521502248_item	3663390	et	3	main
sügis	doc_491521502248_item	3663389	et	3	main
tartu	doc_491521502248_item	3663388	et	4	main
piisavalt	doc_491521502248_item	3663384	et	4	main
kirjutatud	doc_491521502248_item	3663375	et	4	main
kirjandus	doc_491521502248_item	3663370	et	3	main
pigem	doc_491521502248_item	3663368	et	3	main
käisid	doc_491521502248_item	3663367	et	4	main
muulased	doc_491521502248_item	3663366	et	4	main
teatris	doc_491521502248_item	3663365	et	3	main
käia	doc_491521502248_item	3663364	et	4	main
olümpiaadid	doc_491521502248_item	3663361	et	3	main
kooli	doc_491521502248_item	3663359	et	4	main
õpilastele	doc_491521502248_item	3663354	et	4	main
oli	doc_491521502248_item	3663347	et	3	main
õnne	doc_491521502248_item	3663345	et	4	main
hakati	doc_491521502248_item	3663335	et	3	main
esitati	doc_491521502248_item	3663327	et	4	main
laulud	doc_491521502248_item	3663326	et	3	main
7	doc_491521502248_item	3663324	et	2	main
ka	doc_491521502248_item	3663316	et	3	main
väga	doc_491521502248_item	3663311	et	3	main
kättesaadavad	doc_491521502249_item	3663543	et	3	main
kuid	doc_491521502249_item	3663537	et	4	main
ja	doc_491521502249_item	3663529	et	3	main
suurt	doc_491521502249_item	3663525	et	3	main
nsvs	doc_491521502249_item	3663522	et	4	main
eesti	doc_491521502249_item	3663521	et	4	main
1	doc_491521502249_item	3663518	et	2	main
valgus	doc_491521502249_item	3663512	et	4	main
1	doc_491521502249_item	3663506	et	2	main
on	doc_491521502249_item	3663744	et	4	main
koordis	doc_491521502249_item	3663743	et	4	main
hea	doc_491521502249_item	3663730	et	4	main
martistlikud	doc_491521502249_item	3663718	et	4	main
see	doc_491521502249_item	3663707	et	3	main
sündmusi	doc_491521502249_item	3663700	et	3	main
näidimuster	doc_491521502249_item	3663695	et	4	main
realismi	doc_491521502249_item	3663694	et	4	main
sotsialistliku	doc_491521502249_item	3663693	et	3	main
kui	doc_491521502249_item	3663692	et	3	main
elu	doc_491521502249_item	3663686	et	4	main
paremini	doc_491521502249_item	3663683	et	4	main
muusika	doc_491521502249_item	3663668	et	4	main
kunsti	doc_491521502249_item	3663665	et	4	main
avaldas	doc_491521502249_item	3663662	et	3	main
nsvs	doc_491521502249_item	3663661	et	4	main
rezissör	doc_491521502249_item	3663656	et	4	main
tegelema	doc_491521502249_item	3663650	et	3	main
korda	doc_491521502249_item	3663639	et	4	main
moortele	doc_491521502249_item	3663633	et	4	main
tuntuks	doc_491521502249_item	3663591	et	4	main
kevade	doc_491521502249_item	3663584	et	4	main
film	doc_491521502249_item	3663583	et	3	main
põhjal	doc_491521502249_item	3663580	et	4	main
on	doc_491521502249_item	3663576	et	4	main
palju	doc_491521502249_item	3663570	et	4	main
küljest	doc_491521502249_item	3663563	et	4	main
mul	doc_491521502250_item	3664125	et	3	main
oli	doc_491521502250_item	3664111	et	3	main
näidatakse	doc_491521502250_item	3664110	et	3	main
seal	doc_491521502250_item	3664109	et	4	main
eriti	doc_491521502250_item	3664101	et	3	main
vastama	doc_491521502250_item	3664088	et	3	main
kino	doc_491521502250_item	3664082	et	4	main
kirjandus	doc_491521502250_item	3664081	et	3	main
range	doc_491521502250_item	3664075	et	4	main
kehtis	doc_491521502250_item	3664074	et	3	main
viisil	doc_491521502250_item	3664066	et	4	main
mõtlema	doc_491521502250_item	3664061	et	3	main
olukorda	doc_491521502250_item	3664058	et	4	main
täielikusest	doc_491521502250_item	3664048	et	4	main
tõetruu	doc_491521502249_item	3663754	et	4	main
tegelikkuse	doc_491521502249_item	3663753	et	4	main
ja	doc_491521502249_item	3663752	et	3	main
rahvalikkus	doc_491521502249_item	3663751	et	4	main
parteilisus	doc_491521502249_item	3663750	et	4	main
kommunistlik	doc_491521502249_item	3663749	et	3	main
tunnus	doc_491521502249_item	3663748	et	3	main
realismi	doc_491521502249_item	3663747	et	4	main
soome	doc_491521502249_item	3663556	et	3	main
oli	doc_491521502249_item	3663554	et	3	main
ostei	doc_491521502249_item	3663547	et	4	main
raamatud	doc_491521502249_item	3663542	et	4	main
massiteava	doc_491521502249_item	3663531	et	4	main
filmikunst	doc_491521502249_item	3663530	et	3	main
hakkasid	doc_491521502249_item	3663523	et	4	main
lenililt	doc_491521502249_item	3663740	et	4	main
pärinevad	doc_491521502249_item	3663737	et	4	main
on	doc_491521502249_item	3663720	et	4	main
kunstivool	doc_491521502249_item	3663716	et	4	main
kajastab	doc_491521502249_item	3663699	et	3	main
eesti	doc_491521502249_item	3663675	et	4	main
ja	doc_491521502249_item	3663667	et	3	main
1970ndatel	doc_491521502249_item	3663658	et	4	main
hiljem	doc_491521502249_item	3663648	et	3	main
tegi	doc_491521502249_item	3663645	et	4	main
lavaetendusi	doc_491521502249_item	3663644	et	3	main
nsvs	doc_491521502249_item	3663642	et	4	main
lastele	doc_491521502249_item	3663635	et	4	main
kui	doc_491521502249_item	3663634	et	3	main
said	doc_491521502249_item	3663590	et	4	main
kirjanduses	doc_491521502249_item	3663589	et	3	main
kruusemendi	doc_491521502249_item	3663582	et	4	main
filme	doc_491521502249_item	3663572	et	3	main
eesti	doc_491521502249_item	3663571	et	4	main
tehti	doc_491521502249_item	3663569	et	3	main
elu	doc_491521502249_item	3663561	et	4	main
näidati	doc_491521502249_item	3663560	et	3	main
näinud	doc_491521502250_item	3664123	et	4	main
filmi	doc_491521502250_item	3664122	et	4	main
ise	doc_491521502250_item	3664119	et	4	main
ma	doc_491521502250_item	3664118	et	3	main
mõeldis	doc_491521502250_item	3664115	et	3	main
välja	doc_491521502250_item	3664114	et	4	main
üks	doc_491521502250_item	3664113	et	3	main
teadsid	doc_491521502250_item	3664105	et	4	main
ei	doc_491521502250_item	3664102	et	4	main
seda	doc_491521502250_item	3664099	et	3	main
eestlased	doc_491521502250_item	3664097	et	3	main
pidid	doc_491521502250_item	3664087	et	4	main
teatri	doc_491521502250_item	3664085	et	3	main
ja	doc_491521502250_item	3664084	et	3	main
muusika	doc_491521502250_item	3664083	et	4	main
kõik	doc_491521502250_item	3664077	et	4	main
tsensuur	doc_491521502250_item	3664076	et	3	main
tekkinud	doc_491521502250_item	3664057	et	4	main
hakkama	doc_491521502250_item	3664056	et	3	main
ülistada	doc_491521502250_item	3664055	et	3	main
oli	doc_491521502250_item	3664054	et	3	main
juba	doc_491521502250_item	3664047	et	3	main
toimusid	doc_491521502250_item	3664027	et	4	main
pravdale	doc_491521502250_item	3664024	et	4	main
see	doc_491521502250_item	3664015	et	3	main
hoida	doc_491521502250_item	3664011	et	3	main
lihtsalt	doc_491521502250_item	3664004	et	4	main
see	doc_491521502250_item	3664002	et	3	main
et	doc_491521502250_item	3664001	et	3	main
arvasid	doc_491521502250_item	3664000	et	4	main
ja	doc_491521502250_item	3663999	et	3	main
võimalik	doc_491521502250_item	3663998	et	3	main
on	doc_491521502250_item	3663997	et	4	main
vaadeti	doc_491521502250_item	3663986	et	4	main
käisid	doc_491521502250_item	3663968	et	4	main
kino	doc_491521502250_item	3663957	et	4	main
kiisk	doc_491521502250_item	3663956	et	3	main
lavastused	doc_491521502250_item	3663944	et	4	main
j	doc_491521502250_item	3663938	et	4	main
populaarsed	doc_491521502250_item	3663937	et	3	main
väga	doc_491521502250_item	3663936	et	3	main
palju	doc_491521502250_item	3663931	et	4	main
töötasid	doc_491521502250_item	3663927	et	4	main
ja	doc_491521502250_item	3663925	et	3	main
sai	doc_491521502250_item	3663900	et	4	main
1960ndates	doc_491521502250_item	3663894	et	4	main
kohta	doc_491521502250_item	3663892	et	4	main
ka	doc_491521502250_item	3663890	et	3	main
käib	doc_491521502250_item	3663889	et	3	main
ainult	doc_491521502250_item	3663856	et	4	main
vastavat	doc_491521502250_item	3663846	et	4	main
a	doc_491521502250_item	3663840	et	4	main
tartu	doc_491521502250_item	3663817	et	4	main
nn	doc_491521502250_item	3663816	et	4	main
tsensuuri	doc_491521502250_item	3663793	et	4	main
1	doc_491521502250_item	3663757	et	2	main
diktaadita	doc_491521502250_item	3663807	et	3	main
koordis	doc_491521502249_item	3663729	et	4	main
käsitlenud	doc_491521502249_item	3663721	et	4	main
tollest	doc_491521502249_item	3663711	et	4	main
ettekujutuse	doc_491521502249_item	3663710	et	4	main
meile	doc_491521502249_item	3663709	et	4	main
mis	doc_491521502249_item	3663701	et	4	main
valgus	doc_491521502249_item	3663697	et	4	main
valgus	doc_491521502249_item	3663690	et	4	main
2	doc_491521502249_item	3663689	et	2	main
läinud	doc_491521502249_item	3663674	et	4	main
filmid	doc_491521502249_item	3663672	et	4	main
teosed	doc_491521502249_item	3663671	et	3	main
paljud	doc_491521502249_item	3663670	et	3	main
eesti	doc_491521502249_item	3663660	et	4	main
filmi	doc_491521502249_item	3663655	et	4	main
hakkas	doc_491521502249_item	3663649	et	3	main
toimus	doc_491521502249_item	3663640	et	3	main
1970ndatel	doc_491521502249_item	3663636	et	4	main
nii	doc_491521502249_item	3663632	et	3	main
kross	doc_491521502249_item	3663607	et	3	main
j	doc_491521502249_item	3663606	et	4	main
nt	doc_491521502249_item	3663605	et	4	main
romaane	doc_491521502249_item	3663604	et	3	main
ajaloolisi	doc_491521502249_item	3663603	et	4	main
lugeda	doc_491521502249_item	3663602	et	3	main
võimalik	doc_491521502249_item	3663601	et	3	main
oli	doc_491521502249_item	3663600	et	3	main
proosakirjandusest	doc_491521502249_item	3663599	et	4	main
ivask	doc_491521502249_item	3663598	et	4	main
i	doc_491521502249_item	3663597	et	4	main
lepik	doc_491521502249_item	3663596	et	3	main
nii	doc_491521502249_item	3663722	et	3	main
on	doc_491521502249_item	3663715	et	4	main
realism	doc_491521502249_item	3663714	et	3	main
sotsialistlik	doc_491521502249_item	3663713	et	3	main
ajast	doc_491521502249_item	3663712	et	4	main
ning	doc_491521502249_item	3663706	et	3	main
toimusid	doc_491521502249_item	3663702	et	4	main
kordis	doc_491521502249_item	3663698	et	4	main
film	doc_491521502249_item	3663696	et	3	main
nsvs	doc_491521502249_item	3663688	et	4	main
eesti	doc_491521502249_item	3663687	et	4	main
iseloomustavad	doc_491521502249_item	3663684	et	4	main
kõige	doc_491521502249_item	3663682	et	4	main
nad	doc_491521502249_item	3663681	et	3	main
vaadatakse	doc_491521502249_item	3663680	et	3	main
ja	doc_491521502249_item	3663679	et	3	main
loetakse	doc_491521502249_item	3663678	et	3	main
neid	doc_491521502249_item	3663677	et	4	main
kultuuriajalukku	doc_491521502249_item	3663676	et	4	main
on	doc_491521502249_item	3663673	et	4	main
arengule	doc_491521502249_item	3663669	et	3	main
filmikunsti	doc_491521502249_item	3663666	et	4	main
aastatel	doc_491521502249_item	3663659	et	4	main
tuntud	doc_491521502249_item	3663654	et	4	main
samuti	doc_491521502249_item	3663653	et	3	main
oli	doc_491521502249_item	3663652	et	3	main
komissarov	doc_491521502249_item	3663646	et	4	main
džassfestival	doc_491521502249_item	3663643	et	2	main
esimest	doc_491521502249_item	3663638	et	4	main
aastal	doc_491521502249_item	3663637	et	3	main
lauluvõistlusi	doc_491521502249_item	3663631	et	3	main
esimesi	doc_491521502249_item	3663630	et	4	main
korraldama	doc_491521502249_item	3663629	et	3	main
hakati	doc_491521502249_item	3663628	et	3	main
nsvs	doc_491521502249_item	3663627	et	4	main
eesti	doc_491521502249_item	3663626	et	4	main
piimamees	doc_491521502249_item	3663625	et	4	main
mäeküla	doc_491521502249_item	3663624	et	4	main
teos	doc_491521502249_item	3663623	et	4	main
tuntud	doc_491521502249_item	3663622	et	4	main
triik	doc_491521502249_item	3663621	et	4	main
rummo	doc_491521502249_item	3663620	et	4	main
luuletajad	doc_491521502249_item	3663619	et	4	main
kirjutamine	doc_491521502249_item	3663618	et	4	main
luule	doc_491521502249_item	3663617	et	4	main
perioodil	doc_491521502249_item	3663616	et	3	main
sel	doc_491521502249_item	3663615	et	3	main
oli	doc_491521502249_item	3663614	et	3	main
iseloomulikum	doc_491521502249_item	3663613	et	4	main
kõige	doc_491521502249_item	3663612	et	4	main
kuid	doc_491521502249_item	3663611	et	4	main
vahel	doc_491521502249_item	3663610	et	4	main
katku	doc_491521502249_item	3663609	et	4	main
kolme	doc_491521502249_item	3663608	et	4	main
k	doc_491521502249_item	3663595	et	4	main
kordis	doc_491521502249_item	3663588	et	4	main
teose	doc_491521502249_item	3663579	et	3	main
o	doc_491521502249_item	3663577	et	4	main
tuntumad	doc_491521502249_item	3663575	et	4	main
kõige	doc_491521502249_item	3663574	et	4	main
under	doc_491521502249_item	3663594	et	4	main
maria	doc_491521502249_item	3663593	et	4	main
valgus	doc_491521502249_item	3663587	et	4	main
tehtud	doc_491521502249_item	3663581	et	4	main
1970ndatel	doc_491521502249_item	3663568	et	4	main
uudiseid	doc_491521502249_item	3663567	et	3	main
vaadati	doc_491521502249_item	3663566	et	3	main
samuti	doc_491521502249_item	3663565	et	3	main
paremast	doc_491521502249_item	3663564	et	4	main
teisest	doc_491521502249_item	3663562	et	4	main
seal	doc_491521502249_item	3663559	et	4	main
on	doc_491521502250_item	3664126	et	4	main
siis	doc_491521502250_item	3664124	et	3	main
tegelikult	doc_491521502250_item	3664112	et	4	main
sest	doc_491521502250_item	3664104	et	4	main
selle	doc_491521502250_item	3664095	et	4	main
valgus	doc_491521502250_item	3664092	et	4	main
lavastused	doc_491521502250_item	3664086	et	4	main
elu	doc_491521502250_item	3664078	et	4	main
hea	doc_491521502250_item	3664070	et	4	main
seisnes	doc_491521502250_item	3664069	et	3	main
konflikt	doc_491521502250_item	3664068	et	3	main
optimistlik	doc_491521502250_item	3664067	et	3	main
elu	doc_491521502250_item	3664063	et	4	main
rääkida	doc_491521502250_item	3664046	et	3	main
džässifestivalid	doc_491521502250_item	3664031	et	2	main
muutused	doc_491521502250_item	3664029	et	4	main
vaatamata	doc_491521502250_item	3664006	et	4	main
on	doc_491521502250_item	3664003	et	4	main
elu	doc_491521502250_item	3663996	et	4	main
uskunud	doc_491521502250_item	3663993	et	4	main
ette	doc_491521502250_item	3663983	et	4	main
takti	doc_491521502250_item	3663982	et	4	main
metskapten	doc_491521502250_item	3663964	et	3	main
laev	doc_491521502250_item	3663963	et	3	main
valge	doc_491521502250_item	3663962	et	4	main
debuteerisid	doc_491521502250_item	3663948	et	4	main
kino	doc_491521502250_item	3663946	et	4	main
eesti	doc_491521502250_item	3663945	et	4	main
toomingu	doc_491521502250_item	3663939	et	4	main
inimesi	doc_491521502250_item	3663932	et	4	main
endiselt	doc_491521502250_item	3663928	et	4	main
kino	doc_491521502250_item	3663926	et	4	main
teater	doc_491521502250_item	3663924	et	3	main
ka	doc_491521502250_item	3663923	et	3	main
vastu	doc_491521502250_item	3663922	et	3	main
ajaloo	doc_491521502250_item	3663921	et	4	main
rahvusliku	doc_491521502250_item	3663920	et	3	main
m	doc_491521502250_item	3663912	et	4	main
1970ndates	doc_491521502250_item	3663899	et	4	main
siis	doc_491521502250_item	3663898	et	3	main
luule	doc_491521502250_item	3663897	et	4	main
kirjanduse	doc_491521502250_item	3663891	et	3	main
varem	doc_491521502250_item	3663851	et	4	main
oli	doc_491521502250_item	3663850	et	3	main
ei	doc_491521502250_item	3663844	et	4	main
oli	doc_491521502250_item	3663838	et	3	main
tartu	doc_491521502250_item	3663835	et	4	main
süütu	doc_491521502250_item	3663832	et	4	main
lavakeelu	doc_491521502250_item	3663830	et	3	main
alates	doc_491521502250_item	3663826	et	3	main
noored	doc_491521502250_item	3663823	et	3	main
a	doc_491521502250_item	3663815	et	4	main
tuua	doc_491521502250_item	3663813	et	3	main
vahel	doc_491521502250_item	3663795	et	4	main
valgus	doc_491521502250_item	3663763	et	4	main
2	doc_491521502250_item	3663762	et	2	main
nsvs	doc_491521502250_item	3663761	et	4	main
eesti	doc_491521502250_item	3663760	et	4	main
võimatu	doc_491521502250_item	3663809	et	4	main
vähemalt	doc_491521502250_item	3664131	et	4	main
seda	doc_491521502250_item	3664121	et	3	main
pole	doc_491521502250_item	3664120	et	3	main
mis	doc_491521502250_item	3664108	et	4	main
vaadanud	doc_491521502250_item	3664103	et	4	main
näidiseks	doc_491521502250_item	3664096	et	3	main
mudelile	doc_491521502250_item	3664090	et	3	main
peegeldavad	doc_491521502250_item	3664079	et	4	main
parema	doc_491521502250_item	3664072	et	4	main
ja	doc_491521502250_item	3664071	et	3	main
areneb	doc_491521502250_item	3664064	et	3	main
et	doc_491521502250_item	3664062	et	3	main
pidid	doc_491521502250_item	3664060	et	4	main
kõik	doc_491521502250_item	3664059	et	4	main
realismi	doc_491521502250_item	3664052	et	4	main
sotsialistliku	doc_491521502250_item	3664051	et	3	main
saab	doc_491521502250_item	3664045	et	3	main
alates	doc_491521502250_item	3664044	et	3	main
a-st	doc_491521502250_item	3664043	et	3	main
1983	doc_491521502250_item	3664042	et	2	main
ja	doc_491521502250_item	3664041	et	3	main
tuli	doc_491521502250_item	3664039	et	4	main
võimule	doc_491521502250_item	3664038	et	3	main
surma	doc_491521502250_item	3664037	et	4	main
brežnevi	doc_491521502250_item	3664036	et	2	main
andropov	doc_491521502250_item	3664040	et	4	main
pärast	doc_491521502250_item	3664035	et	4	main
populaarsed	doc_491521502250_item	3664034	et	3	main
endiselt	doc_491521502250_item	3664033	et	4	main
olid	doc_491521502250_item	3664032	et	4	main
muusikas	doc_491521502250_item	3664026	et	3	main
40	doc_491521502250_item	3664022	et	2	main
keeruliseks	doc_491521502250_item	3664018	et	4	main
üsna	doc_491521502250_item	3664017	et	3	main
muutus	doc_491521502250_item	3664016	et	4	main
lääne	doc_491521502250_item	3664012	et	4	main
sidet	doc_491521502250_item	3664010	et	4	main
propaganda	doc_491521502250_item	3664005	et	4	main
televisiooni	doc_491521502250_item	3663989	et	4	main
soome	doc_491521502250_item	3663988	et	3	main
ka	doc_491521502250_item	3663987	et	3	main
komissarov	doc_491521502250_item	3663961	et	4	main
l	doc_491521502250_item	3663951	et	4	main
lavastajad	doc_491521502250_item	3663947	et	4	main
teatris	doc_491521502250_item	3663929	et	3	main
kroos	doc_491521502250_item	3663916	et	4	main
j	doc_491521502250_item	3663915	et	4	main
ja	doc_491521502250_item	3663914	et	3	main
traat	doc_491521502250_item	3663913	et	3	main
nagu	doc_491521502250_item	3663909	et	3	main
populaarseks	doc_491521502250_item	3663901	et	4	main
seisaku	doc_491521502250_item	3663864	et	4	main
kui	doc_491521502250_item	3663863	et	3	main
tuntakse	doc_491521502250_item	3663862	et	3	main
kes	doc_491521502250_item	3663849	et	4	main
ja	doc_491521502250_item	3663848	et	3	main
tegelikult	doc_491521502250_item	3663843	et	4	main
rektoriks	doc_491521502250_item	3663837	et	3	main
saada	doc_491521502250_item	3663829	et	4	main
võimalik	doc_491521502250_item	3663828	et	3	main
nüüdsest	doc_491521502250_item	3663825	et	3	main
said	doc_491521502250_item	3663821	et	4	main
üürituse	doc_491521502250_item	3663819	et	4	main
üheks	doc_491521502250_item	3663810	et	3	main
kultuuritegelaste	doc_491521502250_item	3663794	et	3	main
kehtestati	doc_491521502250_item	3663792	et	3	main
1968	doc_491521502250_item	3663770	et	2	main
koordis	doc_491521502250_item	3663764	et	4	main
kuna	doc_491521502250_item	3664117	et	3	main
aga	doc_491521502250_item	3664116	et	3	main
kõik	doc_491521502250_item	3664107	et	4	main
et	doc_491521502250_item	3664106	et	3	main
filmi	doc_491521502250_item	3664100	et	4	main
aga	doc_491521502250_item	3664098	et	3	main
ongi	doc_491521502250_item	3664094	et	4	main
koordis	doc_491521502250_item	3664093	et	4	main
kino	doc_491521502250_item	3664091	et	4	main
sotsialistlikule	doc_491521502250_item	3664089	et	3	main
valdkonnad	doc_491521502250_item	3664080	et	4	main
vahel	doc_491521502250_item	3664073	et	4	main
demokraatlikul	doc_491521502250_item	3664065	et	3	main
ülesandeks	doc_491521502250_item	3664053	et	4	main
2	doc_491521502250_item	3664050	et	2	main
stagnaperioodist	doc_491521502250_item	3664049	et	3	main
ka	doc_491521502250_item	3664025	et	3	main
dissidendid	doc_491521502250_item	3664021	et	3	main
kuigi	doc_491521502250_item	3664014	et	3	main
selline	doc_491521502250_item	3663995	et	4	main
ei	doc_491521502250_item	3663992	et	4	main
muulased	doc_491521502250_item	3663991	et	4	main
kuigi	doc_491521502250_item	3663990	et	3	main
jne	doc_491521502250_item	3663984	et	4	main
rohkem	doc_491521502250_item	3663967	et	4	main
aga	doc_491521502250_item	3663966	et	3	main
kinos	doc_491521502250_item	3663965	et	3	main
k	doc_491521502250_item	3663955	et	4	main
ja	doc_491521502250_item	3663954	et	3	main
müür	doc_491521502250_item	3663953	et	3	main
laius	doc_491521502250_item	3663952	et	4	main
murdmaa	doc_491521502250_item	3663943	et	4	main
ja	doc_491521502250_item	3663942	et	3	main
olid	doc_491521502250_item	3663935	et	4	main
eestlasi	doc_491521502250_item	3663934	et	3	main
eriti	doc_491521502250_item	3663933	et	3	main
aga	doc_491521502250_item	3664030	et	3	main
teatud	doc_491521502250_item	3664028	et	4	main
kiri	doc_491521502250_item	3664023	et	3	main
aktiviseerusid	doc_491521502250_item	3664020	et	4	main
asjaks	doc_491521502250_item	3664019	et	3	main
kultuuriareaaliga	doc_491521502250_item	3664013	et	3	main
siiski	doc_491521502250_item	3664009	et	4	main
püüti	doc_491521502250_item	3664008	et	3	main
sellele	doc_491521502250_item	3664007	et	4	main
et	doc_491521502250_item	3663994	et	3	main
põhja-eestis	doc_491521502250_item	3663985	et	3	main
kaks	doc_491521502250_item	3663981	et	3	main
horoskoop	doc_491521502250_item	3663980	et	3	main
televiktoriinid	doc_491521502250_item	3663979	et	3	main
ja	doc_491521502250_item	3663978	et	3	main
saaded	doc_491521502250_item	3663977	et	4	main
meelelahutuslikud	doc_491521502250_item	3663976	et	3	main
eriti	doc_491521502250_item	3663975	et	3	main
televisioon	doc_491521502250_item	3663974	et	4	main
populaarne	doc_491521502250_item	3663973	et	3	main
väga	doc_491521502250_item	3663972	et	3	main
oli	doc_491521502250_item	3663971	et	3	main
tollal	doc_491521502250_item	3663970	et	3	main
muulased	doc_491521502250_item	3663969	et	4	main
k	doc_491521502250_item	3663960	et	4	main
töötas	doc_491521502250_item	3663959	et	3	main
režissöörina	doc_491521502250_item	3663958	et	2	main
1960ndates	doc_491521502250_item	3663950	et	4	main
juba	doc_491521502250_item	3663949	et	3	main
vilimaa	doc_491521502250_item	3663941	et	4	main
ü	doc_491521502250_item	3663940	et	4	main
käis	doc_491521502250_item	3663930	et	4	main
olid	doc_491521502250_item	3663911	et	4	main
need	doc_491521502250_item	3663910	et	3	main
autoreid	doc_491521502250_item	3663908	et	4	main
selliseid	doc_491521502250_item	3663907	et	4	main
nimetada	doc_491521502250_item	3663906	et	3	main
kindlasti	doc_491521502250_item	3663905	et	3	main
tuleb	doc_491521502250_item	3663904	et	3	main
siin	doc_491521502250_item	3663903	et	4	main
kui	doc_491521502250_item	3663893	et	3	main
sama	doc_491521502250_item	3663888	et	4	main
kõrge	doc_491521502250_item	3663887	et	4	main
perioodi	doc_491521502250_item	3663861	et	4	main
seda	doc_491521502250_item	3663860	et	3	main
inimesed	doc_491521502250_item	3663859	et	3	main
lojaalsed	doc_491521502250_item	3663858	et	3	main
pääsesid	doc_491521502250_item	3663855	et	4	main
madrus	doc_491521502250_item	3663853	et	3	main
tavaline	doc_491521502250_item	3663852	et	4	main
olnud	doc_491521502250_item	3663845	et	4	main
määratud	doc_491521502250_item	3663839	et	4	main
ülikooli	doc_491521502250_item	3663836	et	4	main
eest	doc_491521502250_item	3663834	et	4	main
tegude	doc_491521502250_item	3663833	et	3	main
tähelepanu	doc_491521502250_item	3663919	et	4	main
suur	doc_491521502250_item	3663918	et	3	main
pöörati	doc_491521502250_item	3663917	et	3	main
proosa	doc_491521502250_item	3663902	et	4	main
rohkem	doc_491521502250_item	3663896	et	4	main
kirjutati	doc_491521502250_item	3663895	et	3	main
ja	doc_491521502250_item	3663886	et	3	main
stabiilne	doc_491521502250_item	3663885	et	3	main
ikkagi	doc_491521502250_item	3663884	et	4	main
oli	doc_491521502250_item	3663883	et	3	main
tase	doc_491521502250_item	3663882	et	3	main
helikunsti	doc_491521502250_item	3663881	et	4	main
ja	doc_491521502250_item	3663880	et	3	main
kujutava-	doc_491521502250_item	3663879	et	4	main
üldine	doc_491521502250_item	3663878	et	4	main
vastupidi	doc_491521502250_item	3663877	et	3	main
arenenud	doc_491521502250_item	3663876	et	4	main
ei	doc_491521502250_item	3663875	et	4	main
kultuur	doc_491521502250_item	3663874	et	3	main
ajal	doc_491521502250_item	3663873	et	4	main
sellel	doc_491521502250_item	3663872	et	4	main
et	doc_491521502250_item	3663871	et	3	main
öelda	doc_491521502250_item	3663870	et	4	main
saa	doc_491521502250_item	3663869	et	4	main
ei	doc_491521502250_item	3663868	et	4	main
siiski	doc_491521502250_item	3663867	et	4	main
kuid	doc_491521502250_item	3663866	et	4	main
aega	doc_491521502250_item	3663865	et	4	main
nõukogudele	doc_491521502250_item	3663857	et	3	main
nomenklatuuri	doc_491521502250_item	3663854	et	4	main
haridust	doc_491521502250_item	3663847	et	4	main
kellel	doc_491521502250_item	3663842	et	4	main
kroop	doc_491521502250_item	3663841	et	3	main
kultuuritegelased	doc_491521502250_item	3663824	et	3	main
kokku	doc_491521502250_item	3663822	et	3	main
1968	doc_491521502250_item	3663814	et	2	main
võib	doc_491521502250_item	3663812	et	3	main
kultuurielu	doc_491521502250_item	3663758	et	4	main
tunne	doc_491521502250_item	3663801	et	4	main
ka	doc_491521502250_item	3663831	et	3	main
oli	doc_491521502250_item	3663827	et	3	main
kus	doc_491521502250_item	3663820	et	3	main
sügist	doc_491521502250_item	3663818	et	3	main
näidiseks	doc_491521502250_item	3663811	et	3	main
kultuurielus	doc_491521502250_item	3663791	et	4	main
ka	doc_491521502250_item	3663790	et	3	main
see	doc_491521502250_item	3663789	et	3	main
kajastus	doc_491521502250_item	3663788	et	4	main
loomulikult	doc_491521502250_item	3663787	et	4	main
valdkondades	doc_491521502250_item	3663786	et	3	main
kõikides	doc_491521502250_item	3663785	et	4	main
süvenemine	doc_491521502250_item	3663784	et	4	main
diktatuuri	doc_491521502250_item	3663783	et	4	main
levima	doc_491521502250_item	3663782	et	3	main
tasapisi	doc_491521502250_item	3663781	et	3	main
hakkas	doc_491521502250_item	3663780	et	3	main
staatust	doc_491521502250_item	3663779	et	3	main
riikide	doc_491521502250_item	3663778	et	3	main
nsv-liidu	doc_491521502250_item	3663777	et	3	main
väikede	doc_491521502250_item	3663776	et	4	main
kõikide	doc_491521502250_item	3663775	et	4	main
mõjusid	doc_491521502250_item	3663774	et	4	main
tšehhoslovaakias	doc_491521502250_item	3663773	et	2	main
sündmused	doc_491521502250_item	3663772	et	3	main
a	doc_491521502250_item	3663771	et	4	main
1	doc_491521502250_item	3663769	et	2	main
musternäidis	doc_491521502250_item	3663768	et	4	main
realismi	doc_491521502250_item	3663767	et	4	main
sotsialistliku	doc_491521502250_item	3663766	et	3	main
kui	doc_491521502250_item	3663765	et	3	main
1970ndate	doc_491521502250_item	3663759	et	4	main
ilma	doc_491521502250_item	3663806	et	4	main
elu	doc_491521502250_item	3663805	et	4	main
et	doc_491521502250_item	3663804	et	3	main
selgeks	doc_491521502250_item	3663803	et	3	main
sai	doc_491521502250_item	3663802	et	4	main
kontrolltöö	doc_491521502250_item	3663756	et	4	main
on	doc_491521502250_item	3663808	et	4	main
väljapääsmatuse	doc_491521502250_item	3663800	et	3	main
ja	doc_491521502250_item	3663799	et	3	main
pessimis	doc_491521502250_item	3663798	et	4	main
levima	doc_491521502250_item	3663797	et	3	main
hakkas	doc_491521502250_item	3663796	et	3	main
tipp	doc_491521502256_item	3664739	et	3	main
metalli	doc_491521502256_item	3664642	et	4	main
varastati	doc_491521502256_item	3664641	et	3	main
töötasid	doc_491521502256_item	3664640	et	4	main
nad	doc_491521502256_item	3664639	et	3	main
kus	doc_491521502256_item	3664638	et	3	main
sealt	doc_491521502256_item	3664637	et	4	main
oli	doc_491521502256_item	3664633	et	3	main
1970	doc_491521502256_item	3664631	et	2	main
põhjendage	doc_491521502256_item	3664629	et	3	main
arvates	doc_491521502256_item	3664618	et	4	main
kellel	doc_491521502256_item	3664615	et	4	main
nsv-s	doc_491521502256_item	3664613	et	3	main
eesti	doc_491521502256_item	3664612	et	4	main
loata	doc_491521502256_item	3664727	et	4	main
ilma	doc_491521502256_item	3664726	et	4	main
sõita	doc_491521502256_item	3664725	et	3	main
valja	doc_491521502256_item	3664724	et	3	main
lahemaa	doc_491521502256_item	3664715	et	4	main
a	doc_491521502256_item	3664698	et	4	main
1973	doc_491521502256_item	3664697	et	2	main
jne	doc_491521502256_item	3664684	et	4	main
mööblit	doc_491521502256_item	3664683	et	3	main
paberit	doc_491521502256_item	3664682	et	3	main
uudiseid	doc_491521502256_item	3664742	et	3	main
ja	doc_491521502256_item	3664740	et	3	main
varastasid	doc_491521502256_item	3664636	et	4	main
aastatel	doc_491521502256_item	3664632	et	4	main
teie	doc_491521502256_item	3664617	et	4	main
1970ndate	doc_491521502256_item	3664611	et	4	main
saanud	doc_491521502256_item	3664723	et	4	main
kinnised	doc_491521502256_item	3664717	et	4	main
moodustatakse	doc_491521502256_item	3664714	et	3	main
1974	doc_491521502256_item	3664712	et	2	main
inimesi	doc_491521502256_item	3664696	et	4	main
metsa	doc_491521502256_item	3664678	et	4	main
võimalust	doc_491521502256_item	3664667	et	3	main
sotsialismi	doc_491521502260_item	3664974	et	4	main
ja	doc_491521502260_item	3664960	et	3	main
moskva	doc_491521502260_item	3664958	et	4	main
arenema	doc_491521502260_item	3664956	et	3	main
olema	doc_491521502260_item	3664954	et	4	main
pidi	doc_491521502260_item	3664953	et	4	main
kultuurielu	doc_491521502260_item	3664906	et	4	main
taastamisega	doc_491521502260_item	3664902	et	4	main
ja	doc_491521502260_item	3664891	et	3	main
algul	doc_491521502260_item	3664888	et	4	main
moodustama	doc_491521502260_item	3664876	et	3	main
entsüklopeedia	doc_491521502260_item	3664855	et	4	main
selts	doc_491521502260_item	3664826	et	3	main
kultuurielu	doc_491521502260_item	3664818	et	4	main
ka	doc_491521502260_item	3664817	et	3	main
kuid	doc_491521502260_item	3664812	et	4	main
linnastus	doc_491521502260_item	3664806	et	4	main
kultuur	doc_491521502260_item	3664805	et	3	main
suurenema	doc_491521502260_item	3664804	et	3	main
ka	doc_491521502260_item	3664800	et	3	main
teatreid	doc_491521502260_item	3664796	et	3	main
ev	doc_491521502260_item	3664760	et	4	main
1	doc_491521502260_item	3664759	et	2	main
kontrolltöö	doc_491521502260_item	3664745	et	4	main
miinustest	doc_491521502260_item	3665010	et	4	main
jne	doc_491521502256_item	3664743	et	4	main
täpp	doc_491521502256_item	3664741	et	3	main
saateid	doc_491521502256_item	3664736	et	3	main
näiteks	doc_491521502256_item	3664735	et	4	main
televisioon	doc_491521502256_item	3664733	et	4	main
hakkas	doc_491521502256_item	3664731	et	3	main
on	doc_491521502256_item	3664616	et	4	main
2	doc_491521502256_item	3664614	et	2	main
linnas	doc_491521502256_item	3664719	et	4	main
linnad	doc_491521502256_item	3664718	et	3	main
keved	doc_491521502256_item	3664711	et	4	main
hääletu	doc_491521502256_item	3664710	et	4	main
raamat	doc_491521502256_item	3664709	et	3	main
ilmus	doc_491521502256_item	3664706	et	4	main
1968	doc_491521502256_item	3664704	et	2	main
elektrijaam	doc_491521502256_item	3664703	et	3	main
ja	doc_491521502256_item	3664702	et	3	main
soojus	doc_491521502256_item	3664701	et	4	main
balti	doc_491521502256_item	3664700	et	3	main
ehitati	doc_491521502256_item	3664699	et	3	main
eestisse	doc_491521502256_item	3664690	et	4	main
migratsioon	doc_491521502256_item	3664689	et	3	main
iseloomulikuks	doc_491521502256_item	3664688	et	3	main
saab	doc_491521502256_item	3664687	et	3	main
a	doc_491521502256_item	3664686	et	4	main
1970	doc_491521502256_item	3664685	et	2	main
pärast	doc_491521502256_item	3664681	et	4	main
asju	doc_491521502256_item	3664675	et	3	main
majanduses	doc_491521502256_item	3664673	et	4	main
suurendada	doc_491521502256_item	3664672	et	3	main
ja	doc_491521502256_item	3664671	et	3	main
raha	doc_491521502256_item	3664670	et	4	main
teenida	doc_491521502256_item	3664669	et	3	main
inimestele	doc_491521502256_item	3664668	et	3	main
nagu	doc_491521502256_item	3664737	et	3	main
riigivargus	doc_491521502256_item	3664634	et	3	main
kontrolltöö	doc_491521502256_item	3664605	et	4	main
1970	doc_491521502256_item	3664729	et	2	main
sillamäe	doc_491521502256_item	3664728	et	3	main
kust	doc_491521502256_item	3664720	et	4	main
rahvuspark	doc_491521502256_item	3664716	et	3	main
a	doc_491521502256_item	3664713	et	4	main
eesti	doc_491521502256_item	3664707	et	4	main
a	doc_491521502256_item	3664705	et	4	main
palju	doc_491521502256_item	3664695	et	4	main
läheb	doc_491521502256_item	3664694	et	3	main
et	doc_491521502256_item	3664679	et	3	main
vajaline	doc_491521502256_item	3664674	et	4	main
tehaseid	doc_491521502256_item	3664664	et	3	main
see	doc_491521502260_item	3664983	et	3	main
kriitikale	doc_491521502260_item	3664982	et	3	main
suunatud	doc_491521502260_item	3664973	et	4	main
oli	doc_491521502260_item	3664972	et	3	main
2	doc_491521502260_item	3664969	et	2	main
vaidlesid	doc_491521502260_item	3664963	et	4	main
tahtis	doc_491521502260_item	3664959	et	3	main
nagu	doc_491521502260_item	3664957	et	3	main
ja	doc_491521502260_item	3664955	et	3	main
kõik	doc_491521502260_item	3664952	et	4	main
sõnaga	doc_491521502260_item	3664951	et	3	main
aastad	doc_491521502260_item	3664905	et	3	main
kuid	doc_491521502260_item	3664903	et	4	main
entel-tentel	doc_491521502256_item	3664738	et	4	main
televisioon	doc_491521502256_item	3664734	et	4	main
arenema	doc_491521502256_item	3664732	et	3	main
aastatel	doc_491521502256_item	3664730	et	4	main
inimesed	doc_491521502256_item	3664635	et	3	main
1	doc_491521502256_item	3664630	et	2	main
sakslast	doc_491521502256_item	3664628	et	3	main
armastasin	doc_491521502256_item	3664627	et	3	main
ma	doc_491521502256_item	3664626	et	3	main
tammsaare	doc_491521502256_item	3664625	et	3	main
oskaril	doc_491521502256_item	3664624	et	4	main
või	doc_491521502256_item	3664623	et	4	main
erikal	doc_491521502256_item	3664622	et	4	main
kas	doc_491521502256_item	3664621	et	3	main
identiteediprobleemid	doc_491521502256_item	3664620	et	3	main
suuremad	doc_491521502256_item	3664619	et	4	main
vastasseis	doc_491521502256_item	3664610	et	3	main
loodushoiu	doc_491521502256_item	3664609	et	3	main
ja	doc_491521502256_item	3664608	et	3	main
majanduse	doc_491521502256_item	3664607	et	4	main
1	doc_491521502256_item	3664606	et	2	main
ei	doc_491521502256_item	3664722	et	4	main
inimesed	doc_491521502256_item	3664721	et	3	main
keelne	doc_491521502256_item	3664708	et	3	main
eestist	doc_491521502256_item	3664693	et	3	main
ja	doc_491521502256_item	3664692	et	3	main
tuleb	doc_491521502256_item	3664691	et	3	main
teha	doc_491521502256_item	3664680	et	3	main
anda	doc_491521502256_item	3664666	et	3	main
hakati	doc_491521502256_item	3664662	et	3	main
režiimi	doc_491521502260_item	3664981	et	2	main
sotsialistlikus	doc_491521502260_item	3664976	et	4	main
ületamisele	doc_491521502260_item	3664975	et	4	main
selle	doc_491521502260_item	3664964	et	4	main
muidugi	doc_491521502260_item	3664961	et	4	main
seltsid	doc_491521502260_item	3664947	et	4	main
paljud	doc_491521502260_item	3664946	et	3	main
kinni	doc_491521502260_item	3664945	et	3	main
pandi	doc_491521502260_item	3664944	et	4	main
oma	doc_491521502260_item	3664900	et	4	main
inimesed	doc_491521502260_item	3664898	et	3	main
rääkida	doc_491521502260_item	3664897	et	3	main
millest	doc_491521502260_item	3664896	et	3	main
esimestel	doc_491521502260_item	3664892	et	4	main
väga	doc_491521502260_item	3664889	et	3	main
oli	doc_491521502260_item	3664887	et	3	main
pärastsõjajärgne	doc_491521502260_item	3664885	et	3	main
ensv	doc_491521502260_item	3664884	et	4	main
keeles	doc_491521502260_item	3664883	et	4	main
võimalik	doc_491521502260_item	3664878	et	3	main
ka	doc_491521502260_item	3664873	et	3	main
ilmus	doc_491521502260_item	3664852	et	4	main
ajal	doc_491521502260_item	3664851	et	4	main
kõikvõimalikud	doc_491521502260_item	3664823	et	3	main
tegutsesid	doc_491521502260_item	3664822	et	4	main
urbaniseerumisega	doc_491521502260_item	3664815	et	4	main
hakas	doc_491521502260_item	3664803	et	4	main
näitlejaid	doc_491521502260_item	3664799	et	4	main
hakati	doc_491521502260_item	3664797	et	3	main
kultuurielu	doc_491521502260_item	3664762	et	4	main
ees	doc_491521502260_item	3665015	et	4	main
ja	doc_491521502260_item	3665014	et	3	main
nsv	doc_491521502260_item	3665009	et	4	main
selles	doc_491521502260_item	3665005	et	4	main
kasvatati	doc_491521502256_item	3664677	et	3	main
tegemeseks	doc_491521502256_item	3664676	et	4	main
et	doc_491521502256_item	3664665	et	3	main
ehitama	doc_491521502256_item	3664663	et	4	main
müük	doc_491521502256_item	3664661	et	3	main
piimatoodete	doc_491521502256_item	3664660	et	3	main
ja	doc_491521502256_item	3664659	et	3	main
suureks	doc_491521502256_item	3664657	et	4	main
kasvas	doc_491521502256_item	3664656	et	3	main
seetõttu	doc_491521502256_item	3664655	et	3	main
liha-	doc_491521502256_item	3664658	et	4	main
loomi	doc_491521502256_item	3664654	et	4	main
kasvatati	doc_491521502256_item	3664653	et	3	main
vastu	doc_491521502256_item	3664652	et	3	main
haiguste	doc_491521502256_item	3664651	et	4	main
rohtu	doc_491521502256_item	3664650	et	4	main
teha	doc_491521502256_item	3664649	et	3	main
saasta	doc_491521502256_item	3664648	et	4	main
et	doc_491521502256_item	3664647	et	3	main
taimi	doc_491521502256_item	3664646	et	4	main
hakatikasvatama	doc_491521502256_item	3664645	et	4	main
jne	doc_491521502256_item	3664644	et	4	main
tööriistu	doc_491521502256_item	3664643	et	3	main
tundub	doc_491521502260_item	3664984	et	3	main
olnud	doc_491521502260_item	3664979	et	4	main
kirjanduses	doc_491521502260_item	3664977	et	3	main
sotsialistlik	doc_491521502260_item	3664970	et	3	main
arreteerimist	doc_491521502260_item	3664968	et	4	main
kardeti	doc_491521502260_item	3664967	et	3	main
sest	doc_491521502260_item	3664966	et	4	main
vastu	doc_491521502260_item	3664965	et	3	main
vähesed	doc_491521502260_item	3664962	et	3	main
ühe	doc_491521502260_item	3664950	et	4	main
venestumispoliitika	doc_491521502260_item	3664949	et	4	main
algas	doc_491521502260_item	3664948	et	3	main
vara	doc_491521502260_item	3664901	et	4	main
tegelesid	doc_491521502260_item	3664899	et	4	main
kultuuri	doc_491521502260_item	3664895	et	4	main
polnudki	doc_491521502260_item	3664894	et	3	main
algkooli	doc_491521502260_item	3664880	et	4	main
saada	doc_491521502260_item	3664879	et	4	main
kultuuri	doc_491521502260_item	3664866	et	4	main
ja	doc_491521502260_item	3664865	et	3	main
keele	doc_491521502260_item	3664864	et	4	main
eesti	doc_491521502260_item	3664863	et	4	main
koolitama	doc_491521502260_item	3664862	et	3	main
hakati	doc_491521502260_item	3664861	et	3	main
teaduskond	doc_491521502260_item	3664860	et	3	main
eesti	doc_491521502260_item	3664854	et	4	main
esimene	doc_491521502260_item	3664853	et	3	main
linna	doc_491521502260_item	3664819	et	4	main
nüüd	doc_491521502260_item	3664813	et	4	main
varem	doc_491521502260_item	3664807	et	4	main
kommunism	doc_491521502260_item	3665018	et	3	main
ootas	doc_491521502260_item	3665017	et	3	main
elustiili	doc_491521502260_item	3664999	et	4	main
selle	doc_491521502260_item	3664998	et	4	main
kannatanud	doc_491521502260_item	3664997	et	4	main
on	doc_491521502260_item	3664996	et	4	main
inimesi	doc_491521502260_item	3664995	et	4	main
palju	doc_491521502260_item	3664994	et	4	main
kui	doc_491521502260_item	3664993	et	3	main
sellest	doc_491521502260_item	3664992	et	4	main
öeldud	doc_491521502260_item	3664991	et	4	main
olnud	doc_491521502260_item	3664990	et	4	main
ei	doc_491521502260_item	3664989	et	4	main
seal	doc_491521502260_item	3664988	et	4	main
sest	doc_491521502260_item	3664987	et	4	main
utoopiliselt	doc_491521502260_item	3664986	et	4	main
küll	doc_491521502260_item	3664985	et	4	main
kohta	doc_491521502260_item	3664980	et	4	main
ei	doc_491521502260_item	3664978	et	4	main
realism	doc_491521502260_item	3664971	et	3	main
siiberisse	doc_491521502260_item	3664943	et	3	main
represeeriti	doc_491521502260_item	3664942	et	4	main
kirjanikud	doc_491521502260_item	3664941	et	3	main
ja	doc_491521502260_item	3664940	et	3	main
paljud	doc_491521502260_item	3664938	et	3	main
režiimi	doc_491521502260_item	3664937	et	2	main
teadlased	doc_491521502260_item	3664939	et	3	main
nõukogude	doc_491521502260_item	3664936	et	3	main
tõstma	doc_491521502260_item	3664935	et	3	main
esile	doc_491521502260_item	3664933	et	3	main
pidi	doc_491521502260_item	3664934	et	4	main
järgi	doc_491521502260_item	3664932	et	4	main
mudeli	doc_491521502260_item	3664931	et	3	main
sotsialistliku	doc_491521502260_item	3664930	et	3	main
arenema	doc_491521502260_item	3664929	et	3	main
pidi	doc_491521502260_item	3664928	et	4	main
kultuur	doc_491521502260_item	3664927	et	3	main
üldse	doc_491521502260_item	3664926	et	3	main
keelatud	doc_491521502260_item	3664925	et	4	main
nüüd	doc_491521502260_item	3664924	et	4	main
oli	doc_491521502260_item	3664923	et	3	main
ajal	doc_491521502260_item	3664922	et	4	main
ev	doc_491521502260_item	3664921	et	4	main
ilmunud	doc_491521502260_item	3664920	et	4	main
oli	doc_491521502260_item	3664919	et	3	main
mis	doc_491521502260_item	3664918	et	4	main
kirjandus	doc_491521502260_item	3664917	et	3	main
muutunud	doc_491521502260_item	3664916	et	4	main
pisut	doc_491521502260_item	3664915	et	3	main
juba	doc_491521502260_item	3664914	et	3	main
oli	doc_491521502260_item	3664913	et	3	main
see	doc_491521502260_item	3664912	et	3	main
ja	doc_491521502260_item	3664911	et	3	main
näitama	doc_491521502260_item	3664910	et	3	main
ennast	doc_491521502260_item	3664909	et	4	main
hakas	doc_491521502260_item	3664908	et	4	main
juba	doc_491521502260_item	3664907	et	3	main
järgnevad	doc_491521502260_item	3664904	et	4	main
raske	doc_491521502260_item	3664890	et	4	main
oma	doc_491521502260_item	3664882	et	4	main
hariduse	doc_491521502260_item	3664881	et	3	main
seltse	doc_491521502260_item	3664875	et	3	main
tüs	doc_491521502260_item	3664856	et	4	main
ev	doc_491521502260_item	3664850	et	4	main
selts	doc_491521502260_item	3664828	et	3	main
naiste	doc_491521502260_item	3664827	et	3	main
kirjanike	doc_491521502260_item	3664825	et	3	main
seltsid	doc_491521502260_item	3664824	et	4	main
kolis	doc_491521502260_item	3664816	et	4	main
maal	doc_491521502260_item	3664811	et	4	main
rohkesti	doc_491521502260_item	3664810	et	3	main
toimos	doc_491521502260_item	3664809	et	4	main
kultuurielu	doc_491521502260_item	3664808	et	4	main
arv	doc_491521502260_item	3664802	et	3	main
kinomajade	doc_491521502260_item	3664801	et	3	main
koolitama	doc_491521502260_item	3664798	et	3	main
jne	doc_491521502260_item	3664793	et	4	main
2	doc_491521502260_item	3664754	et	2	main
kultuurielu	doc_491521502260_item	3664753	et	4	main
pärastsõjajärgset	doc_491521502260_item	3664752	et	3	main
ensv	doc_491521502260_item	3664751	et	4	main
ja	doc_491521502260_item	3664750	et	3	main
aegset	doc_491521502260_item	3664749	et	3	main
hea	doc_491521502260_item	3665013	et	4	main
oli	doc_491521502260_item	3665012	et	3	main
ei	doc_491521502260_item	3665007	et	4	main
aastatel	doc_491521502260_item	3664893	et	4	main
elu	doc_491521502260_item	3664886	et	4	main
oli	doc_491521502260_item	3664877	et	3	main
oma	doc_491521502260_item	3664874	et	4	main
võimelised	doc_491521502260_item	3664872	et	4	main
oli	doc_491521502260_item	3664871	et	3	main
rahvused	doc_491521502260_item	3664870	et	3	main
väiksed	doc_491521502260_item	3664869	et	4	main
kuid	doc_491521502260_item	3664868	et	4	main
teadlasi	doc_491521502260_item	3664867	et	3	main
keele	doc_491521502260_item	3664859	et	4	main
eesti	doc_491521502260_item	3664858	et	4	main
avati	doc_491521502260_item	3664857	et	3	main
legaalne	doc_491521502260_item	3664849	et	3	main
ajal	doc_491521502260_item	3664848	et	4	main
tol	doc_491521502260_item	3664847	et	3	main
oli	doc_491521502260_item	3664846	et	3	main
mis	doc_491521502260_item	3664845	et	4	main
prostitutsioonist	doc_491521502260_item	3664844	et	3	main
ka	doc_491521502260_item	3664843	et	3	main
veel	doc_491521502260_item	3664842	et	4	main
ja	doc_491521502260_item	3664841	et	3	main
müügist	doc_491521502260_item	3664840	et	3	main
alkoholi	doc_491521502260_item	3664839	et	4	main
ja	doc_491521502260_item	3664838	et	3	main
tubakatoodete	doc_491521502260_item	3664837	et	3	main
tuli	doc_491521502260_item	3664836	et	4	main
finanseerimine	doc_491521502260_item	3664835	et	4	main
kultuurielu	doc_491521502260_item	3664834	et	4	main
et	doc_491521502260_item	3664833	et	3	main
huvitav	doc_491521502260_item	3664832	et	4	main
on	doc_491521502260_item	3664831	et	4	main
mis	doc_491521502260_item	3664830	et	4	main
jne	doc_491521502260_item	3664829	et	4	main
ajal	doc_491521502260_item	3664821	et	4	main
tol	doc_491521502260_item	3664820	et	3	main
seoses	doc_491521502260_item	3664814	et	4	main
avati	doc_491521502260_item	3664795	et	3	main
eestis	doc_491521502260_item	3664794	et	3	main
kirjandusvool	doc_491521502260_item	3664758	et	4	main
kui	doc_491521502260_item	3664757	et	3	main
realism	doc_491521502260_item	3664756	et	3	main
sotsialistlik	doc_491521502260_item	3664755	et	3	main
kõiki	doc_491521502260_item	3665016	et	4	main
suund	doc_491521502260_item	3665001	et	3	main
pärast	doc_491521502260_item	3665000	et	4	main
geograafid	doc_491521502260_item	3664792	et	4	main
astronoomid	doc_491521502260_item	3664791	et	3	main
kuulsuse	doc_491521502260_item	3664790	et	4	main
rahvusvahelise	doc_491521502260_item	3664789	et	4	main
said	doc_491521502260_item	3664788	et	4	main
teadlased	doc_491521502260_item	3664787	et	3	main
eestlastest	doc_491521502260_item	3664786	et	4	main
arenema	doc_491521502260_item	3664785	et	3	main
hakasid	doc_491521502260_item	3664784	et	4	main
teadused	doc_491521502260_item	3664783	et	3	main
paljud	doc_491521502260_item	3664782	et	3	main
a	doc_491521502260_item	3664781	et	4	main
1919	doc_491521502260_item	3664780	et	2	main
ülikool	doc_491521502260_item	3664779	et	4	main
tartu	doc_491521502260_item	3664778	et	4	main
taasavati	doc_491521502260_item	3664777	et	3	main
jpm	doc_491521502260_item	3664776	et	4	main
haridus	doc_491521502260_item	3664775	et	3	main
kirjandeid	doc_491521502260_item	3664774	et	3	main
palju	doc_491521502260_item	3664773	et	4	main
väga	doc_491521502260_item	3664772	et	3	main
ilmus	doc_491521502260_item	3664771	et	4	main
arenemine	doc_491521502260_item	3664770	et	4	main
eesti	doc_491521502260_item	3664769	et	4	main
oli	doc_491521502260_item	3664768	et	3	main
peamiseks	doc_491521502260_item	3664767	et	3	main
ja	doc_491521502260_item	3664766	et	3	main
arenemisele	doc_491521502260_item	3664765	et	4	main
suunatud	doc_491521502260_item	3664764	et	4	main
oli	doc_491521502260_item	3664763	et	3	main
ajal	doc_491521502260_item	3664761	et	4	main
ev	doc_491521502260_item	3664748	et	4	main
võrrelge	doc_491521502260_item	3664747	et	3	main
1	doc_491521502260_item	3664746	et	2	main
kõik	doc_491521502260_item	3665011	et	4	main
kirjutatud	doc_491521502260_item	3665008	et	4	main
kirjanduses	doc_491521502260_item	3665006	et	3	main
tulevikule	doc_491521502260_item	3665004	et	4	main
nendele	doc_491521502260_item	3665003	et	4	main
oli	doc_491521502260_item	3665002	et	3	main
a	doc_491521502261_item	3665597	et	4	main
välja	doc_491521502261_item	3665589	et	4	main
heidetakse	doc_491521502261_item	3665588	et	4	main
puhastuse	doc_491521502261_item	3665587	et	4	main
teeb	doc_491521502261_item	3665586	et	3	main
liit	doc_491521502261_item	3665585	et	3	main
kirjanike	doc_491521502261_item	3665584	et	3	main
likvideerimine	doc_491521502261_item	3665580	et	4	main
hävitati	doc_491521502261_item	3665575	et	3	main
välismaal	doc_491521502261_item	3665563	et	4	main
tädi	doc_491521502261_item	3665560	et	4	main
võimuürganid	doc_491521502261_item	3665529	et	4	main
täitev	doc_491521502261_item	3665526	et	4	main
ümber	doc_491521502261_item	3665519	et	3	main
linnad	doc_491521502261_item	3665512	et	3	main
skulptor	doc_491521502261_item	3665599	et	3	main
3	doc_491521502261_item	3665581	et	2	main
2	doc_491521502261_item	3665578	et	2	main
onu	doc_491521502261_item	3665561	et	4	main
nt	doc_491521502261_item	3665559	et	4	main
kirjutanud	doc_491521502261_item	3665558	et	4	main
valesti	doc_491521502261_item	3665557	et	3	main
midagi	doc_491521502261_item	3665556	et	4	main
vares-barbarus	doc_491521502261_item	3665523	et	4	main
muudatused	doc_491521502261_item	3665516	et	3	main
25081940	doc_491521502261_item	3665514	et	2	main
tulevad	doc_491521502261_item	3665506	et	4	main
tasuta	doc_491521502261_item	3665500	et	4	main
hakati	doc_491521502261_item	3665491	et	3	main
vabariigis	doc_491521502261_item	3665479	et	3	main
on	doc_491521502261_item	3665470	et	4	main
poliitika	doc_491521502261_item	3665467	et	4	main
inimesed	doc_491521502261_item	3665454	et	3	main
kartulit	doc_491521502261_item	3665452	et	3	main
said	doc_491521502261_item	3665449	et	4	main
aga	doc_491521502261_item	3665448	et	3	main
lihtsalt	doc_491521502261_item	3665441	et	4	main
nad	doc_491521502261_item	3665440	et	3	main
esimesed	doc_491521502261_item	3665435	et	3	main
ei	doc_491521502261_item	3665425	et	4	main
talupoeg	doc_491521502261_item	3665424	et	3	main
a	doc_491521502261_item	3665423	et	4	main
1949	doc_491521502261_item	3665422	et	2	main
märts	doc_491521502261_item	3665421	et	3	main
olid	doc_491521502261_item	3665417	et	4	main
tööriistu	doc_491521502261_item	3665415	et	3	main
olnud	doc_491521502261_item	3665414	et	4	main
jõukamad	doc_491521502261_item	3665402	et	4	main
lauter	doc_491521502261_item	3665598	et	3	main
vallandati	doc_491521502261_item	3665582	et	3	main
ilukirjandust	doc_491521502261_item	3665577	et	3	main
hävitamise	doc_491521502261_item	3665574	et	4	main
on	doc_491521502261_item	3665568	et	4	main
1950	doc_491521502261_item	3665567	et	2	main
töölt	doc_491521502261_item	3665566	et	3	main
elavad	doc_491521502261_item	3665562	et	4	main
a	doc_491521502261_item	3665533	et	4	main
komitee	doc_491521502261_item	3665527	et	4	main
esimees	doc_491521502261_item	3665525	et	4	main
presiidiumi	doc_491521502261_item	3665524	et	4	main
nimetati	doc_491521502261_item	3665518	et	4	main
riigikogu	doc_491521502261_item	3665517	et	4	main
toimusid	doc_491521502261_item	3665515	et	4	main
asemetele	doc_491521502261_item	3665505	et	4	main
maalt	doc_491521502261_item	3665503	et	3	main
starkopp	doc_491521502261_item	3665601	et	4	main
teatritegelane	doc_491521502261_item	3665596	et	3	main
tuglas	doc_491521502261_item	3665595	et	4	main
beti	doc_491521502261_item	3665593	et	4	main
nt	doc_491521502261_item	3665592	et	4	main
kirjanikud	doc_491521502261_item	3665591	et	3	main
paljud	doc_491521502261_item	3665590	et	3	main
komitlased	doc_491521502261_item	3665583	et	4	main
koolist	doc_491521502261_item	3665565	et	4	main
vallandati	doc_491521502261_item	3665564	et	3	main
kohalikud	doc_491521502261_item	3665528	et	3	main
ensv	doc_491521502261_item	3665520	et	4	main
2	doc_491521502261_item	3665513	et	2	main
ümber	doc_491521502261_item	3665509	et	3	main
tulema	doc_491521502261_item	3665502	et	4	main
kõik	doc_491521502261_item	3665498	et	4	main
võimalus	doc_491521502261_item	3665495	et	3	main
oli	doc_491521502261_item	3665494	et	3	main
ka	doc_491521502261_item	3665489	et	3	main
taastati	doc_491521502261_item	3665488	et	4	main
teatri	doc_491521502261_item	3665486	et	3	main
edandada	doc_491521502261_item	3665483	et	4	main
kultuuri	doc_491521502261_item	3665482	et	4	main
võimalik	doc_491521502261_item	3665481	et	3	main
suhteliselt	doc_491521502261_item	3665453	et	4	main
kapsast	doc_491521502261_item	3665450	et	4	main
ei	doc_491521502261_item	3665442	et	4	main
aastad	doc_491521502261_item	3665436	et	3	main
perekonnad	doc_491521502261_item	3665433	et	4	main
20702	doc_491521502261_item	3665431	et	2	main
nõukogude	doc_491521502261_item	3665429	et	3	main
25-26	doc_491521502261_item	3665420	et	2	main
tahtnud	doc_491521502261_item	3665408	et	4	main
ei	doc_491521502261_item	3665407	et	4	main
talupojad	doc_491521502261_item	3665406	et	4	main
astusid	doc_491521502261_item	3665401	et	4	main
mõjutama	doc_491521502261_item	3665387	et	4	main
amakorda	doc_491521502261_item	3665386	et	4	main
hakkab	doc_491521502261_item	3665385	et	3	main
partei	doc_491521502261_item	3665384	et	4	main
800	doc_491521502261_item	3665377	et	2	main
ja	doc_491521502261_item	3665372	et	3	main
kõrgkoolide	doc_491521502261_item	3665370	et	3	main
algab	doc_491521502261_item	3665368	et	3	main
õppida	doc_491521502261_item	3665366	et	3	main
teatrid	doc_491521502261_item	3665358	et	3	main
sõpruskondi	doc_491521502261_item	3665356	et	4	main
moodustatakse	doc_491521502261_item	3665354	et	3	main
klubid	doc_491521502261_item	3665353	et	3	main
tekkivad	doc_491521502261_item	3665352	et	4	main
kultuurielu	doc_491521502261_item	3665342	et	4	main
ismid	doc_491521502261_item	3665336	et	3	main
ajaloolisi	doc_491521502261_item	3665329	et	4	main
loeti	doc_491521502261_item	3665328	et	3	main
kunstiloomind	doc_491521502261_item	3665327	et	3	main
1	doc_491521502261_item	3665325	et	2	main
kirjandusvool	doc_491521502261_item	3665324	et	4	main
a	doc_491521502261_item	3665600	et	4	main
allver	doc_491521502261_item	3665594	et	4	main
seltside	doc_491521502261_item	3665579	et	3	main
palju	doc_491521502261_item	3665576	et	4	main
raamatute	doc_491521502261_item	3665573	et	3	main
kaasa	doc_491521502261_item	3665572	et	4	main
tõi	doc_491521502261_item	3665571	et	3	main
1	doc_491521502261_item	3665570	et	2	main
terror	doc_491521502261_item	3665569	et	3	main
on	doc_491521502261_item	3665555	et	4	main
inimene	doc_491521502261_item	3665554	et	3	main
kui	doc_491521502261_item	3665553	et	3	main
ankeet	doc_491521502261_item	3665552	et	3	main
puhas	doc_491521502261_item	3665551	et	3	main
siberisse	doc_491521502261_item	3665550	et	4	main
saadeti	doc_491521502261_item	3665549	et	3	main
või	doc_491521502261_item	3665548	et	4	main
vangi	doc_491521502261_item	3665547	et	4	main
sattusid	doc_491521502261_item	3665546	et	4	main
kunstnikud	doc_491521502261_item	3665545	et	3	main
kirjanikud	doc_491521502261_item	3665544	et	3	main
kommunism	doc_491521502261_item	3665543	et	3	main
realism	doc_491521502261_item	3665542	et	3	main
sotsialistlik	doc_491521502261_item	3665541	et	3	main
rahvuslik	doc_491521502261_item	3665540	et	3	main
vorm	doc_491521502261_item	3665539	et	3	main
sotsialistlik	doc_491521502261_item	3665538	et	3	main
sisu	doc_491521502261_item	3665537	et	4	main
folkloor	doc_491521502261_item	3665536	et	4	main
poliitiline	doc_491521502261_item	3665535	et	3	main
tekkis	doc_491521502261_item	3665534	et	3	main
1941	doc_491521502261_item	3665532	et	2	main
juuni	doc_491521502261_item	3665531	et	4	main
14	doc_491521502261_item	3665530	et	2	main
j	doc_491521502261_item	3665522	et	4	main
ülemnõukoguks	doc_491521502261_item	3665521	et	3	main
ja	doc_491521502261_item	3665511	et	3	main
maakondade	doc_491521502261_item	3665504	et	3	main
on	doc_491521502261_item	3665480	et	4	main
a	doc_491521502261_item	3665476	et	4	main
ja	doc_491521502261_item	3665451	et	3	main
pidanud	doc_491521502261_item	3665443	et	4	main
siberis	doc_491521502261_item	3665437	et	4	main
lahutati	doc_491521502261_item	3665434	et	3	main
inimest	doc_491521502261_item	3665432	et	3	main
omaks	doc_491521502261_item	3665427	et	4	main
võta	doc_491521502261_item	3665426	et	4	main
väga	doc_491521502261_item	3665418	et	3	main
külad	doc_491521502261_item	3665416	et	3	main
olid	doc_491521502261_item	3665397	et	4	main
ligi	doc_491521502261_item	3665376	et	3	main
3-8	doc_491521502261_item	3665374	et	2	main
haridustee	doc_491521502261_item	3665369	et	4	main
tahtsid	doc_491521502261_item	3665365	et	4	main
kes	doc_491521502261_item	3665364	et	4	main
kõrgkoolid	doc_491521502261_item	3665363	et	3	main
ka	doc_491521502261_item	3665362	et	3	main
olid	doc_491521502261_item	3665361	et	4	main
tekkivad	doc_491521502261_item	3665357	et	4	main
erinevaid	doc_491521502261_item	3665355	et	4	main
olnud	doc_491521502261_item	3665332	et	4	main
kui	doc_491521502261_item	3665323	et	3	main
tänavad	doc_491521502261_item	3665510	et	4	main
nimetat	doc_491521502261_item	3665508	et	4	main
rajoonid	doc_491521502261_item	3665507	et	4	main
hakkati	doc_491521502261_item	3665501	et	3	main
oli	doc_491521502261_item	3665499	et	3	main
elada	doc_491521502261_item	3665497	et	3	main
hariduselu	doc_491521502261_item	3665490	et	4	main
taastamine	doc_491521502261_item	3665487	et	4	main
nt	doc_491521502261_item	3665484	et	4	main
et	doc_491521502261_item	3665478	et	3	main
keel	doc_491521502261_item	3665474	et	4	main
põhiseaduse	doc_491521502261_item	3665473	et	3	main
keel	doc_491521502261_item	3665472	et	4	main
kohalik	doc_491521502261_item	3665471	et	3	main
asjaajamiskeel	doc_491521502261_item	3665469	et	4	main
töötasu	doc_491521502261_item	3665445	et	4	main
vastu	doc_491521502261_item	3665444	et	3	main
sisse	doc_491521502261_item	3665409	et	4	main
talupojad	doc_491521502261_item	3665403	et	4	main
edukamad	doc_491521502261_item	3665399	et	4	main
all	doc_491521502261_item	3665395	et	3	main
on	doc_491521502261_item	3665392	et	4	main
harrastustega	doc_491521502261_item	3665383	et	4	main
erinevate	doc_491521502261_item	3665382	et	4	main
tegeleda	doc_491521502261_item	3665381	et	3	main
oli	doc_491521502261_item	3665380	et	3	main
võimalus	doc_491521502261_item	3665379	et	3	main
linna	doc_491521502261_item	3665351	et	4	main
maalt	doc_491521502261_item	3665350	et	3	main
nautida	doc_491521502261_item	3665341	et	3	main
ostakse	doc_491521502261_item	3665338	et	4	main
tulevad	doc_491521502261_item	3665335	et	4	main
meelelahutus	doc_491521502261_item	3665334	et	4	main
odav	doc_491521502261_item	3665333	et	3	main
prop	doc_491521502261_item	3665326	et	4	main
2	doc_491521502261_item	3665320	et	2	main
kultuurielu	doc_491521502261_item	3665319	et	4	main
õppida	doc_491521502261_item	3665496	et	3	main
internaate	doc_491521502261_item	3665493	et	4	main
ehitama	doc_491521502261_item	3665492	et	4	main
eetonia	doc_491521502261_item	3665485	et	4	main
usuti	doc_491521502261_item	3665477	et	3	main
1947	doc_491521502261_item	3665475	et	2	main
rahvusriikides	doc_491521502261_item	3665468	et	3	main
uus	doc_491521502261_item	3665466	et	3	main
nälga	doc_491521502261_item	3665465	et	4	main
surid	doc_491521502261_item	3665464	et	4	main
looma	doc_491521502261_item	3665463	et	4	main
maksma	doc_491521502261_item	3665462	et	3	main
makse	doc_491521502261_item	3665461	et	4	main
pidid	doc_491521502261_item	3665460	et	4	main
sohvoos	doc_491521502261_item	3665459	et	4	main
ja	doc_491521502261_item	3665458	et	3	main
kolhoos	doc_491521502261_item	3665457	et	3	main
sest	doc_491521502261_item	3665456	et	4	main
nälgisid	doc_491521502261_item	3665455	et	4	main
makstus	doc_491521502261_item	3665447	et	4	main
ei	doc_491521502261_item	3665446	et	4	main
surid	doc_491521502261_item	3665439	et	4	main
inimesed	doc_491521502261_item	3665438	et	3	main
süsteemi	doc_491521502261_item	3665430	et	4	main
uut	doc_491521502261_item	3665428	et	3	main
vaesed	doc_491521502261_item	3665419	et	4	main
ei	doc_491521502261_item	3665413	et	4	main
neil	doc_491521502261_item	3665412	et	4	main
kuna	doc_491521502261_item	3665411	et	3	main
astuda	doc_491521502261_item	3665410	et	3	main
vaesemad	doc_491521502261_item	3665405	et	4	main
aga	doc_491521502261_item	3665404	et	3	main
kolhoosidesse	doc_491521502261_item	3665400	et	3	main
sohvoosid	doc_491521502261_item	3665396	et	4	main
võimu	doc_491521502261_item	3665394	et	4	main
majandus	doc_491521502261_item	3665391	et	4	main
ja	doc_491521502261_item	3665390	et	3	main
kultuur	doc_491521502261_item	3665389	et	3	main
majandust	doc_491521502261_item	3665388	et	4	main
eestis	doc_491521502261_item	3665371	et	3	main
13-17	doc_491521502261_item	3665367	et	2	main
ja	doc_491521502261_item	3665359	et	3	main
ja	doc_491521502261_item	3665340	et	3	main
ei	doc_491521502261_item	3665331	et	4	main
teose	doc_491521502261_item	3665330	et	3	main
realism	doc_491521502261_item	3665322	et	3	main
ensv	doc_491521502261_item	3665317	et	4	main
ja	doc_491521502261_item	3665316	et	3	main
aegset	doc_491521502261_item	3665315	et	3	main
majand	doc_491521502261_item	3665398	et	3	main
poliitilise	doc_491521502261_item	3665393	et	3	main
raamatukogu	doc_491521502261_item	3665378	et	4	main
tegutses	doc_491521502261_item	3665375	et	3	main
euroopas	doc_491521502261_item	3665373	et	3	main
kinod	doc_491521502261_item	3665360	et	3	main
kolivad	doc_491521502261_item	3665349	et	4	main
inimesed	doc_491521502261_item	3665348	et	3	main
külas	doc_491521502261_item	3665347	et	3	main
ja	doc_491521502261_item	3665346	et	3	main
maal	doc_491521502261_item	3665345	et	4	main
toimus	doc_491521502261_item	3665344	et	3	main
linnastub	doc_491521502261_item	3665343	et	3	main
hinnata	doc_491521502261_item	3665339	et	4	main
seda	doc_491521502261_item	3665337	et	3	main
sotsialistlik	doc_491521502261_item	3665321	et	3	main
pärastsõjajärgset	doc_491521502261_item	3665318	et	3	main
ev	doc_491521502261_item	3665314	et	4	main
võrrelge	doc_491521502261_item	3665313	et	3	main
1	doc_491521502261_item	3665312	et	2	main
kontrolltöö	doc_491521502261_item	3665311	et	4	main
edasiminekut	doc_491521502265_item	3666293	et	3	main
kultuur	doc_491521502265_item	3666291	et	3	main
ja	doc_491521502265_item	3666289	et	3	main
vastu	doc_491521502265_item	3666288	et	3	main
tegid	doc_491521502265_item	3666279	et	4	main
kultuuri	doc_491521502265_item	3666281	et	4	main
takistusi	doc_491521502265_item	3666280	et	4	main
kultuuri	doc_491521502265_item	3666270	et	4	main
küll	doc_491521502265_item	3666264	et	4	main
kultuurielu	doc_491521502265_item	3666262	et	4	main
aegne	doc_491521502265_item	3666261	et	3	main
ev	doc_491521502265_item	3666260	et	4	main
kunstivooludega	doc_491521502265_item	3666259	et	3	main
kunstnikud	doc_491521502265_item	3666254	et	3	main
eesti	doc_491521502265_item	3666253	et	4	main
nende	doc_491521502265_item	3666237	et	4	main
taasavaldama	doc_491521502265_item	3666236	et	3	main
hakkati	doc_491521502265_item	3666235	et	3	main
ja	doc_491521502265_item	3666234	et	3	main
heliplaadid	doc_491521502265_item	3666220	et	3	main
moodsad	doc_491521502265_item	3666218	et	3	main
nsvl-s	doc_491521502265_item	3666211	et	3	main
elus	doc_491521502265_item	3666204	et	4	main
ensv-aegses	doc_491521502265_item	3666203	et	3	main
ka	doc_491521502265_item	3666202	et	3	main
aga	doc_491521502265_item	3666201	et	3	main
1	doc_491521502265_item	3666194	et	2	main
sotsialistlik	doc_491521502265_item	3666190	et	3	main
kultuurielu	doc_491521502265_item	3666188	et	4	main
käitumise	doc_491521502267_item	3666566	et	4	main
iseenda	doc_491521502267_item	3666562	et	3	main
ka	doc_491521502267_item	3666561	et	3	main
näeb	doc_491521502267_item	3666560	et	3	main
keegi	doc_491521502267_item	3666559	et	4	main
võib-olla	doc_491521502267_item	3666558	et	3	main
ja	doc_491521502267_item	3666557	et	3	main
kirjandusvool	doc_491521502265_item	3666298	et	4	main
kui	doc_491521502265_item	3666297	et	3	main
realism	doc_491521502265_item	3666296	et	3	main
jätkus	doc_491521502265_item	3666292	et	4	main
informeeritusele	doc_491521502265_item	3666290	et	4	main
mujal	doc_491521502265_item	3666276	et	3	main
kui	doc_491521502265_item	3666275	et	3	main
olid	doc_491521502265_item	3666273	et	4	main
piirid	doc_491521502265_item	3666272	et	3	main
lubatu	doc_491521502265_item	3666271	et	4	main
vabameelsem	doc_491521502265_item	3666266	et	4	main
keelatud	doc_491521502265_item	3666252	et	4	main
oli	doc_491521502265_item	3666251	et	3	main
kuid	doc_491521502265_item	3666247	et	4	main
nsvl-s	doc_491521502265_item	3666245	et	3	main
1956	doc_491521502265_item	3666222	et	2	main
rõivad	doc_491521502265_item	3666219	et	3	main
eestile	doc_491521502265_item	3666212	et	3	main
lubamatu	doc_491521502265_item	3666200	et	4	main
ja	doc_491521502265_item	3666199	et	3	main
lubatu	doc_491521502265_item	3666198	et	4	main
kirjandusvool	doc_491521502265_item	3666193	et	4	main
kui	doc_491521502265_item	3666192	et	3	main
aegset	doc_491521502265_item	3666184	et	3	main
ev	doc_491521502265_item	3666183	et	4	main
üle	doc_491521502267_item	3666567	et	3	main
küljest	doc_491521502267_item	3666556	et	4	main
võimaluse	doc_491521502267_item	3666551	et	3	main
see	doc_491521502267_item	3666548	et	3	main
isegi	doc_491521502267_item	3666533	et	4	main
tekkinud	doc_491521502267_item	3666528	et	4	main
saa	doc_491521502267_item	3666526	et	4	main
agressiivsuse	doc_491521502267_item	3666514	et	4	main
tegelikuses	doc_491521502267_item	3666502	et	4	main
nad	doc_491521502267_item	3666494	et	3	main
teised	doc_491521502267_item	3666459	et	4	main
ka	doc_491521502267_item	3666458	et	3	main
ja	doc_491521502267_item	3666457	et	3	main
turims	doc_491521502267_item	3666448	et	4	main
ei	doc_491521502267_item	3666442	et	4	main
kuskil	doc_491521502267_item	3666440	et	3	main
jne	doc_491521502267_item	3666426	et	4	main
mängud	doc_491521502267_item	3666425	et	3	main
2	doc_491521502265_item	3666294	et	2	main
nsvl-s	doc_491521502265_item	3666277	et	3	main
laiemad	doc_491521502265_item	3666274	et	4	main
kuid	doc_491521502265_item	3666267	et	4	main
kaasa	doc_491521502265_item	3666256	et	4	main
60ndate	doc_491521502265_item	3666239	et	4	main
iseloomulik	doc_491521502265_item	3666214	et	3	main
mujal	doc_491521502265_item	3666210	et	3	main
ensv	doc_491521502265_item	3666186	et	4	main
1	doc_491521502265_item	3666181	et	2	main
sotsialistlikus	doc_491521502265_item	3666321	et	4	main
ühiskonnas	doc_491521502265_item	3666322	et	4	main
elada	doc_491521502265_item	3666320	et	3	main
hästi	doc_491521502265_item	3666319	et	3	main
kuidas	doc_491521502265_item	3666318	et	3	main
ja	doc_491521502265_item	3666317	et	3	main
neil	doc_491521502265_item	3666315	et	4	main
oli	doc_491521502265_item	3666316	et	3	main
elu	doc_491521502265_item	3666314	et	4	main
hea	doc_491521502265_item	3666313	et	4	main
kui	doc_491521502265_item	3666312	et	3	main
st	doc_491521502265_item	3666311	et	3	main
elu	doc_491521502265_item	3666310	et	4	main
töölisklassi	doc_491521502265_item	3666309	et	4	main
kirjeldas	doc_491521502265_item	3666308	et	3	main
realism	doc_491521502265_item	3666307	et	3	main
sotsialistlik	doc_491521502265_item	3666306	et	3	main
propagandaga	doc_491521502265_item	3666305	et	3	main
ja	doc_491521502265_item	3666304	et	3	main
tsensuuri-	doc_491521502265_item	3666303	et	4	main
kommunistliku	doc_491521502265_item	3666302	et	3	main
seotud	doc_491521502265_item	3666301	et	4	main
otseselt	doc_491521502265_item	3666300	et	4	main
oli	doc_491521502265_item	3666299	et	3	main
sotsialistlik	doc_491521502265_item	3666295	et	3	main
kultuuri	doc_491521502265_item	3666287	et	4	main
armastusele	doc_491521502265_item	3666286	et	4	main
inimeste	doc_491521502265_item	3666285	et	3	main
tänul	doc_491521502265_item	3666284	et	3	main
aga	doc_491521502265_item	3666283	et	3	main
arengule	doc_491521502265_item	3666282	et	3	main
võimuorganid	doc_491521502265_item	3666278	et	3	main
ensv	doc_491521502265_item	3666269	et	4	main
ka	doc_491521502265_item	3666268	et	3	main
palju	doc_491521502265_item	3666265	et	4	main
on	doc_491521502265_item	3666263	et	4	main
läksid	doc_491521502265_item	3666255	et	4	main
moskvas	doc_491521502265_item	3666248	et	4	main
esimene	doc_491521502265_item	3666244	et	3	main
eestis	doc_491521502265_item	3666242	et	3	main
aastate	doc_491521502265_item	3666240	et	3	main
töid	doc_491521502265_item	3666238	et	3	main
liitudesse	doc_491521502265_item	3666233	et	3	main
loominguliste	doc_491521502265_item	3666232	et	4	main
ennistamine	doc_491521502265_item	3666231	et	4	main
kuritegijate	doc_491521502265_item	3666230	et	3	main
kultuuri	doc_491521502265_item	3666229	et	4	main
algas	doc_491521502265_item	3666228	et	3	main
pärast	doc_491521502265_item	3666227	et	4	main
paljastamine	doc_491521502265_item	3666226	et	4	main
kuritegude	doc_491521502265_item	3666225	et	3	main
stalini	doc_491521502265_item	3666224	et	4	main
algas	doc_491521502265_item	3666223	et	3	main
levinud	doc_491521502265_item	3666258	et	4	main
maailmas	doc_491521502265_item	3666257	et	3	main
muusika	doc_491521502265_item	3666250	et	4	main
see	doc_491521502265_item	3666249	et	3	main
džaasifestival	doc_491521502265_item	3666246	et	2	main
toimus	doc_491521502265_item	3666243	et	3	main
lõpus	doc_491521502265_item	3666241	et	4	main
jne	doc_491521502265_item	3666221	et	4	main
tulid	doc_491521502265_item	3666217	et	4	main
sealt	doc_491521502265_item	3666216	et	4	main
läänestumine	doc_491521502265_item	3666215	et	4	main
arenenud	doc_491521502265_item	3666208	et	4	main
sõnavabadus	doc_491521502265_item	3666197	et	4	main
ja	doc_491521502265_item	3666196	et	3	main
2	doc_491521502265_item	3666189	et	2	main
pärastsõjajärgset	doc_491521502265_item	3666187	et	3	main
vaadata	doc_491521502267_item	3666552	et	4	main
selle	doc_491521502267_item	3666537	et	4	main
minna	doc_491521502267_item	3666531	et	3	main
mõtlemisviisi	doc_491521502267_item	3666529	et	4	main
ammu	doc_491521502267_item	3666527	et	4	main
näitab	doc_491521502267_item	3666519	et	3	main
ema	doc_491521502267_item	3666508	et	4	main
ta	doc_491521502267_item	3666505	et	4	main
keda	doc_491521502267_item	3666493	et	4	main
oli	doc_491521502265_item	3666213	et	3	main
kui	doc_491521502265_item	3666209	et	3	main
parem	doc_491521502265_item	3666207	et	4	main
oli	doc_491521502265_item	3666206	et	3	main
kultuurielu	doc_491521502265_item	3666205	et	4	main
ev-ajakirjanduse	doc_491521502265_item	3666195	et	3	main
realism	doc_491521502265_item	3666191	et	3	main
ja	doc_491521502265_item	3666185	et	3	main
võrrelge	doc_491521502265_item	3666182	et	3	main
kontrolltöö	doc_491521502265_item	3666180	et	4	main
oma	doc_491521502267_item	3666565	et	4	main
mõtleb	doc_491521502267_item	3666564	et	3	main
ning	doc_491521502267_item	3666563	et	3	main
tegutsemisele	doc_491521502267_item	3666554	et	4	main
romaan	doc_491521502267_item	3666546	et	3	main
võita	doc_491521502267_item	3666539	et	4	main
üle	doc_491521502267_item	3666538	et	3	main
vastu	doc_491521502267_item	3666530	et	3	main
teadmatust	doc_491521502267_item	3666521	et	4	main
see	doc_491521502267_item	3666518	et	3	main
ohvriks	doc_491521502267_item	3666515	et	3	main
ja	doc_491521502267_item	3666513	et	3	main
kartuste	doc_491521502267_item	3666512	et	3	main
inimeste	doc_491521502267_item	3666511	et	3	main
pärast	doc_491521502267_item	3666510	et	4	main
saatuse	doc_491521502267_item	3666509	et	3	main
sai	doc_491521502267_item	3666506	et	4	main
süütu	doc_491521502267_item	3666504	et	4	main
on	doc_491521502267_item	3666503	et	4	main
süüdlaseks	doc_491521502267_item	3666496	et	3	main
valivad	doc_491521502267_item	3666495	et	4	main
sellele	doc_491521502267_item	3666492	et	4	main
tunda	doc_491521502267_item	3666466	et	3	main
eestile	doc_491521502267_item	3666464	et	3	main
andsid	doc_491521502267_item	3666463	et	4	main
nendest	doc_491521502267_item	3666462	et	4	main
need	doc_491521502267_item	3666455	et	3	main
avati	doc_491521502267_item	3666452	et	3	main
olnud	doc_491521502267_item	3666443	et	4	main
veel	doc_491521502267_item	3666441	et	4	main
nsvl-s	doc_491521502267_item	3666439	et	3	main
reklammikool	doc_491521502267_item	3666436	et	4	main
ka	doc_491521502267_item	3666435	et	3	main
asus	doc_491521502267_item	3666434	et	4	main
kõik	doc_491521502267_item	3666428	et	4	main
see	doc_491521502267_item	3666427	et	3	main
oli	doc_491521502267_item	3666417	et	3	main
kõige	doc_491521502267_item	3666353	et	4	main
arvates	doc_491521502267_item	3666352	et	4	main
minu	doc_491521502267_item	3666351	et	3	main
ajaloodokument	doc_491521502267_item	3666346	et	3	main
teisest	doc_491521502267_item	3666555	et	4	main
suurepärase	doc_491521502267_item	3666550	et	4	main
saanud	doc_491521502267_item	3666536	et	4	main
ei	doc_491521502267_item	3666535	et	4	main
ning	doc_491521502267_item	3666532	et	3	main
ja	doc_491521502267_item	3666522	et	3	main
inimeste	doc_491521502267_item	3666520	et	3	main
arvates	doc_491521502267_item	3666517	et	4	main
minu	doc_491521502267_item	3666516	et	3	main
oma	doc_491521502267_item	3666507	et	4	main
suunatud	doc_491521502267_item	3666491	et	4	main
on	doc_491521502267_item	3666490	et	4	main
mis	doc_491521502267_item	3666489	et	4	main
agressiivsust	doc_491521502267_item	3666488	et	4	main
ebaõiglast	doc_491521502267_item	3666487	et	3	main
inimeste	doc_491521502267_item	3666486	et	3	main
ja	doc_491521502267_item	3666485	et	3	main
vastu	doc_491521502267_item	3666484	et	3	main
nähtuste	doc_491521502267_item	3666483	et	4	main
ebaloomulike	doc_491521502267_item	3666482	et	3	main
kartust	doc_491521502267_item	3666481	et	3	main
inimkonna	doc_491521502267_item	3666480	et	4	main
peegeldab	doc_491521502267_item	3666479	et	3	main
see	doc_491521502267_item	3666478	et	3	main
ühiskonnakriitika	doc_491521502267_item	3666477	et	4	main
rohkem	doc_491521502267_item	3666476	et	4	main
on	doc_491521502267_item	3666475	et	4	main
libahunt	doc_491521502267_item	3666474	et	3	main
mängufilm	doc_491521502267_item	3666473	et	3	main
llaiuse	doc_491521502267_item	3666472	et	4	main
arvates	doc_491521502267_item	3666471	et	4	main
minu	doc_491521502267_item	3666470	et	3	main
2	doc_491521502267_item	3666469	et	2	main
lähisvälismaana	doc_491521502267_item	3666468	et	3	main
tulenevad	doc_491521502267_item	3666461	et	4	main
tähtis	doc_491521502267_item	3666447	et	4	main
väga	doc_491521502267_item	3666446	et	3	main
oli	doc_491521502267_item	3666445	et	3	main
samuti	doc_491521502267_item	3666444	et	3	main
eestis	doc_491521502267_item	3666433	et	3	main
lastesaaded	doc_491521502267_item	3666423	et	4	main
populaarne	doc_491521502267_item	3666422	et	3	main
väga	doc_491521502267_item	3666421	et	3	main
arvates	doc_491521502267_item	3666416	et	4	main
teguriks	doc_491521502267_item	3666414	et	3	main
on	doc_491521502267_item	3666412	et	4	main
elu	doc_491521502267_item	3666411	et	4	main
piiramist	doc_491521502267_item	3666380	et	4	main
mis	doc_491521502267_item	3666356	et	4	main
tegur	doc_491521502267_item	3666355	et	3	main
miks	doc_491521502267_item	3666349	et	4	main
ühiskonnakriitika	doc_491521502267_item	3666348	et	4	main
arvates	doc_491521502267_item	3666345	et	4	main
end	doc_491521502267_item	3666335	et	4	main
tunda	doc_491521502267_item	3666334	et	3	main
põhjust	doc_491521502267_item	3666331	et	4	main
tegurid	doc_491521502267_item	3666328	et	3	main
inimeste	doc_491521502267_item	3666553	et	3	main
annab	doc_491521502267_item	3666549	et	3	main
sest	doc_491521502267_item	3666547	et	4	main
hea	doc_491521502267_item	3666545	et	4	main
väga	doc_491521502267_item	3666544	et	3	main
on	doc_491521502267_item	3666543	et	4	main
see	doc_491521502267_item	3666542	et	3	main
et	doc_491521502267_item	3666541	et	3	main
arvan	doc_491521502267_item	3666540	et	3	main
armastus	doc_491521502267_item	3666534	et	4	main
ei	doc_491521502267_item	3666525	et	4	main
nad	doc_491521502267_item	3666524	et	3	main
nõrgust	doc_491521502267_item	3666523	et	3	main
kes	doc_491521502267_item	3666501	et	4	main
süüdlane	doc_491521502267_item	3666500	et	3	main
see	doc_491521502267_item	3666499	et	3	main
ongi	doc_491521502267_item	3666498	et	4	main
tiina	doc_491521502267_item	3666497	et	4	main
end	doc_491521502267_item	3666467	et	4	main
põhjust	doc_491521502267_item	3666465	et	4	main
tegurid	doc_491521502267_item	3666456	et	3	main
valuutakauplused	doc_491521502267_item	3666453	et	3	main
asja	doc_491521502267_item	3666438	et	4	main
niisugust	doc_491521502267_item	3666437	et	3	main
elanikutega	doc_491521502267_item	3666432	et	4	main
siide	doc_491521502267_item	3666431	et	3	main
etv	doc_491521502267_item	3666419	et	4	main
etv	doc_491521502267_item	3666418	et	4	main
tähtsam	doc_491521502267_item	3666354	et	4	main
teie	doc_491521502267_item	3666344	et	4	main
libahunt	doc_491521502267_item	3666342	et	3	main
mängufilm	doc_491521502267_item	3666341	et	3	main
l	doc_491521502267_item	3666339	et	4	main
andsid	doc_491521502267_item	3666329	et	4	main
missugused	doc_491521502267_item	3666326	et	3	main
põhjustas	doc_491521502267_item	3666378	et	3	main
läänega	doc_491521502267_item	3666375	et	3	main
tegevus	doc_491521502271_item	3666888	et	4	main
liikmed	doc_491521502271_item	3666886	et	3	main
kgb	doc_491521502271_item	3666885	et	4	main
liidu	doc_491521502271_item	3666884	et	3	main
nsv	doc_491521502271_item	3666883	et	4	main
samuti	doc_491521502271_item	3666882	et	3	main
tegelaseks	doc_491521502271_item	3666866	et	3	main
ja	doc_491521502271_item	3666854	et	3	main
elu	doc_491521502271_item	3666835	et	4	main
varsti	doc_491521502271_item	3666833	et	3	main
tõhus	doc_491521502271_item	3666831	et	4	main
oli	doc_491521502271_item	3666830	et	3	main
läti	doc_491521502271_item	3666823	et	4	main
kui	doc_491521502271_item	3666821	et	3	main
rahasumma	doc_491521502271_item	3666819	et	4	main
oli	doc_491521502271_item	3666816	et	3	main
mis	doc_491521502267_item	3666460	et	4	main
kõik	doc_491521502267_item	3666454	et	4	main
jaoks	doc_491521502267_item	3666451	et	4	main
nende	doc_491521502267_item	3666450	et	4	main
just	doc_491521502267_item	3666449	et	3	main
tugeva	doc_491521502267_item	3666430	et	4	main
tegi	doc_491521502267_item	3666429	et	4	main
oli	doc_491521502267_item	3666420	et	3	main
minu	doc_491521502267_item	3666415	et	3	main
kultuuriliseks	doc_491521502267_item	3666413	et	4	main
missugune	doc_491521502267_item	3666410	et	3	main
ja	doc_491521502267_item	3666409	et	3	main
elati	doc_491521502267_item	3666408	et	3	main
seal	doc_491521502267_item	3666407	et	4	main
kuidas	doc_491521502267_item	3666406	et	3	main
said	doc_491521502267_item	3666405	et	4	main
nad	doc_491521502267_item	3666404	et	3	main
kust	doc_491521502267_item	3666403	et	4	main
vaadata	doc_491521502267_item	3666402	et	4	main
tv	doc_491521502267_item	3666401	et	4	main
soome	doc_491521502267_item	3666400	et	3	main
ka	doc_491521502267_item	3666399	et	3	main
võimalus	doc_491521502267_item	3666398	et	3	main
oli	doc_491521502267_item	3666397	et	3	main
elanikutel	doc_491521502267_item	3666396	et	4	main
põhja-eesti	doc_491521502267_item	3666395	et	4	main
lähedal	doc_491521502267_item	3666394	et	4	main
liiga	doc_491521502267_item	3666393	et	4	main
riigipiiri	doc_491521502267_item	3666392	et	4	main
olid	doc_491521502267_item	3666391	et	4	main
need	doc_491521502267_item	3666390	et	3	main
sest	doc_491521502267_item	3666389	et	4	main
väikestele	doc_491521502267_item	3666388	et	4	main
eriti	doc_491521502267_item	3666387	et	3	main
saartele	doc_491521502267_item	3666386	et	3	main
sõita	doc_491521502267_item	3666385	et	3	main
raske	doc_491521502267_item	3666384	et	4	main
väga	doc_491521502267_item	3666383	et	3	main
oli	doc_491521502267_item	3666382	et	3	main
televiktoriinid	doc_491521502267_item	3666424	et	3	main
näiteks	doc_491521502267_item	3666381	et	4	main
1	doc_491521502267_item	3666350	et	2	main
nsvi	doc_491521502267_item	3666333	et	4	main
1970ndatel	doc_491521502267_item	3666330	et	4	main
1	doc_491521502267_item	3666325	et	2	main
see	doc_491521502267_item	3666376	et	3	main
takistada	doc_491521502271_item	3666876	et	3	main
et	doc_491521502271_item	3666875	et	3	main
korraldasid	doc_491521502271_item	3666871	et	4	main
oppositsioonis	doc_491521502271_item	3666860	et	4	main
oli	doc_491521502271_item	3666859	et	3	main
interrinne	doc_491521502271_item	3666858	et	3	main
peatamine	doc_491521502271_item	3666853	et	4	main
lammutamise	doc_491521502271_item	3666852	et	4	main
nsvl	doc_491521502271_item	3666851	et	4	main
interrinne	doc_491521502271_item	3666841	et	3	main
elanikule	doc_491521502271_item	3666826	et	3	main
nt	doc_491521502271_item	3666822	et	4	main
aastas	doc_491521502271_item	3666820	et	3	main
pärast	doc_491521502271_item	3666631	et	4	main
liidu	doc_491521502271_item	3666625	et	3	main
arengust	doc_491521502271_item	3666617	et	3	main
oma	doc_491521502271_item	3666609	et	4	main
elusfäärid	doc_491521502271_item	3666608	et	3	main
nsv	doc_491521502271_item	3666607	et	4	main
seoses	doc_491521502271_item	3666598	et	4	main
madal	doc_491521502271_item	3666597	et	3	main
väga	doc_491521502271_item	3666596	et	3	main
elutase	doc_491521502271_item	3666595	et	3	main
taasiseseisvumine	doc_491521502271_item	3666585	et	3	main
eesti	doc_491521502271_item	3666580	et	4	main
majanduselus	doc_491521502271_item	3666576	et	4	main
eesti	doc_491521502271_item	3666575	et	4	main
välisinvesteeringutele	doc_491521502271_item	3666812	et	3	main
tänu	doc_491521502271_item	3666811	et	4	main
võrreldes	doc_491521502271_item	3666810	et	3	main
riikide	doc_491521502271_item	3666809	et	3	main
teiste	doc_491521502271_item	3666806	et	4	main
1994	doc_491521502271_item	3666800	et	2	main
eesti	doc_491521502271_item	3666795	et	4	main
hakkas	doc_491521502271_item	3666792	et	3	main
seda	doc_491521502271_item	3666777	et	3	main
väikesed	doc_491521502271_item	3666772	et	4	main
bankrotti	doc_491521502271_item	3666770	et	4	main
kiire	doc_491521502271_item	3666765	et	4	main
liidust	doc_491521502271_item	3666764	et	4	main
iseseisev	doc_491521502271_item	3666757	et	3	main
lahendada	doc_491521502271_item	3666752	et	3	main
mõne	doc_491521502271_item	3666746	et	3	main
ainult	doc_491521502271_item	3666745	et	4	main
rahapoliitika	doc_491521502271_item	3666738	et	4	main
hoiusi	doc_491521502271_item	3666736	et	4	main
kaotasid	doc_491521502271_item	3666734	et	4	main
ja	doc_491521502271_item	3666733	et	3	main
vahetada	doc_491521502271_item	3666732	et	3	main
peale	doc_491521502271_item	3666731	et	4	main
uue	doc_491521502271_item	3666730	et	3	main
ei	doc_491521502271_item	3666726	et	4	main
sissetoomine	doc_491521502273_item	3667084	et	4	main
80-nde	doc_491521502273_item	3667082	et	4	main
poliitikat	doc_491521502273_item	3667081	et	3	main
täielikult	doc_491521502273_item	3667072	et	4	main
tsensuuri	doc_491521502273_item	3667066	et	4	main
kõik	doc_491521502273_item	3667062	et	4	main
nõukogu	doc_491521502273_item	3667051	et	4	main
tähtsus	doc_491521502273_item	3667050	et	4	main
avalikult	doc_491521502273_item	3667040	et	4	main
ja	doc_491521502273_item	3667039	et	3	main
tsensuur	doc_491521502273_item	3667027	et	3	main
vangle	doc_491521502273_item	3667025	et	4	main
1	doc_491521502273_item	3667018	et	2	main
kommunismi	doc_491521502273_item	3666982	et	4	main
mis	doc_491521502273_item	3666977	et	4	main
mis	doc_491521502273_item	3666971	et	4	main
probleemidele	doc_491521502273_item	3666970	et	3	main
rohkem	doc_491521502273_item	3666969	et	4	main
keskendusid	doc_491521502273_item	3666968	et	4	main
elu	doc_491521502273_item	3666951	et	4	main
balti	doc_491521502273_item	3666949	et	3	main
riikide	doc_491521502273_item	3666947	et	3	main
või	doc_491521502267_item	3666347	et	4	main
laiuse	doc_491521502267_item	3666340	et	4	main
2	doc_491521502267_item	3666338	et	2	main
lähisvälismaana	doc_491521502267_item	3666337	et	3	main
nsvl	doc_491521502267_item	3666336	et	4	main
eesti	doc_491521502267_item	3666332	et	4	main
kontrolltöö	doc_491521502267_item	3666324	et	4	main
side	doc_491521502267_item	3666374	et	4	main
kas	doc_491521502267_item	3666343	et	3	main
majanduslikud-kultuurilised	doc_491521502267_item	3666327	et	4	main
liikumise	doc_491521502267_item	3666379	et	4	main
ka	doc_491521502267_item	3666377	et	3	main
alati	doc_491521502267_item	3666372	et	4	main
sadamalinn	doc_491521502267_item	3666369	et	3	main
on	doc_491521502267_item	3666368	et	4	main
ning	doc_491521502267_item	3666370	et	3	main
eesti	doc_491521502267_item	3666367	et	4	main
et	doc_491521502267_item	3666366	et	3	main
see	doc_491521502267_item	3666365	et	3	main
on	doc_491521502267_item	3666364	et	4	main
lähivälismaana	doc_491521502267_item	3666363	et	3	main
end	doc_491521502267_item	3666362	et	4	main
tunda	doc_491521502267_item	3666361	et	3	main
nsvl	doc_491521502267_item	3666360	et	4	main
eesti	doc_491521502267_item	3666359	et	4	main
põhjust	doc_491521502267_item	3666358	et	4	main
andis	doc_491521502267_item	3666357	et	3	main
tegutsesid	doc_491521502271_item	3666881	et	4	main
meeleavaldusi	doc_491521502271_item	3666872	et	3	main
liikmed	doc_491521502271_item	3666870	et	3	main
kellam	doc_491521502271_item	3666868	et	4	main
tähtsamaks	doc_491521502271_item	3666865	et	4	main
natsionalismile	doc_491521502271_item	3666856	et	3	main
eesti	doc_491521502271_item	3666855	et	4	main
sai	doc_491521502271_item	3666843	et	4	main
liikumine	doc_491521502271_item	3666842	et	4	main
2	doc_491521502271_item	3666840	et	2	main
töötama	doc_491521502271_item	3666839	et	3	main
hakkasid	doc_491521502271_item	3666838	et	4	main
majandussfäärid	doc_491521502271_item	3666837	et	3	main
kõik	doc_491521502271_item	3666834	et	4	main
leedu	doc_491521502271_item	3666825	et	4	main
toimus	doc_491521502271_item	3666643	et	3	main
majandusreforme	doc_491521502271_item	3666639	et	3	main
läbi	doc_491521502271_item	3666637	et	4	main
valitsus	doc_491521502271_item	3666636	et	4	main
uus	doc_491521502271_item	3666635	et	3	main
hakkas	doc_491521502271_item	3666634	et	3	main
juhtkonna	doc_491521502271_item	3666627	et	4	main
kannatada	doc_491521502271_item	3666623	et	3	main
samuti	doc_491521502271_item	3666621	et	3	main
majanduse	doc_491521502271_item	3666616	et	4	main
taasiseseisvumisest	doc_491521502271_item	3666614	et	3	main
ilmuma	doc_491521502271_item	3666612	et	3	main
liidus	doc_491521502271_item	3666600	et	4	main
eesti	doc_491521502271_item	3666591	et	4	main
oli	doc_491521502271_item	3666590	et	3	main
etapil	doc_491521502271_item	3666589	et	3	main
sellel	doc_491521502271_item	3666588	et	4	main
200891	doc_491521502271_item	3666587	et	2	main
1	doc_491521502271_item	3666582	et	2	main
inerrinde	doc_491521502271_item	3666578	et	4	main
kontrolltöö	doc_491521502271_item	3666569	et	4	main
eesti	doc_491521502271_item	3666802	et	4	main
nõukogu	doc_491521502271_item	3666798	et	4	main
kaubandusest	doc_491521502271_item	3666791	et	4	main
algusel	doc_491521502271_item	3666785	et	4	main
65	doc_491521502271_item	3666783	et	2	main
iseenda	doc_491521502271_item	3666781	et	3	main
eesti	doc_491521502271_item	3666780	et	4	main
varsti	doc_491521502271_item	3666778	et	3	main
ei	doc_491521502271_item	3666775	et	4	main
pärast	doc_491521502271_item	3666748	et	4	main
kaasa	doc_491521502271_item	3666741	et	4	main
oma	doc_491521502271_item	3666735	et	4	main
oli	doc_491521502267_item	3666373	et	3	main
sellel	doc_491521502267_item	3666371	et	4	main
ja	doc_491521502271_item	3666873	et	3	main
oli	doc_491521502271_item	3666867	et	3	main
selle	doc_491521502271_item	3666864	et	4	main
rahvarindega	doc_491521502271_item	3666863	et	3	main
ja	doc_491521502271_item	3666862	et	3	main
ekp	doc_491521502271_item	3666861	et	4	main
selle	doc_491521502271_item	3666847	et	4	main
aastal	doc_491521502271_item	3666846	et	3	main
1988	doc_491521502271_item	3666845	et	2	main
alguse	doc_491521502271_item	3666844	et	3	main
suunatud	doc_491521502271_item	3666828	et	4	main
läände	doc_491521502271_item	3666827	et	3	main
antud	doc_491521502271_item	3666817	et	4	main
a	doc_491521502271_item	3666642	et	4	main
taastamist	doc_491521502271_item	3666633	et	4	main
iseseisvumise	doc_491521502271_item	3666632	et	3	main
majandus	doc_491521502271_item	3666626	et	4	main
eesti	doc_491521502271_item	3666606	et	4	main
läbi	doc_491521502271_item	3666601	et	4	main
majanduse	doc_491521502271_item	3666592	et	4	main
ametlik	doc_491521502271_item	3666584	et	3	main
muutused	doc_491521502271_item	3666571	et	4	main
1	doc_491521502271_item	3666570	et	2	main
saanud	doc_491521502271_item	3666808	et	4	main
täisliikmeks	doc_491521502271_item	3666799	et	3	main
eksport	doc_491521502271_item	3666794	et	3	main
arenema	doc_491521502271_item	3666793	et	3	main
euroopaga	doc_491521502271_item	3666789	et	3	main
sõlmitud	doc_491521502271_item	3666787	et	4	main
riik	doc_491521502271_item	3666774	et	3	main
minema	doc_491521502271_item	3666771	et	3	main
pärast	doc_491521502271_item	3666768	et	4	main
arengu	doc_491521502271_item	3666767	et	3	main
mitte	doc_491521502271_item	3666761	et	3	main
võimaldas	doc_491521502271_item	3666760	et	3	main
mis	doc_491521502271_item	3666759	et	4	main
samuti	doc_491521502271_item	3666754	et	3	main
oli	doc_491521502271_item	3666753	et	3	main
seda	doc_491521502271_item	3666751	et	3	main
segadust	doc_491521502271_item	3666743	et	4	main
samuti	doc_491521502271_item	3666742	et	3	main
tõi	doc_491521502271_item	3666739	et	3	main
kes	doc_491521502271_item	3666725	et	4	main
inimestel	doc_491521502271_item	3666724	et	3	main
probleemid	doc_491521502271_item	3666723	et	3	main
suured	doc_491521502271_item	3666722	et	3	main
nsv	doc_491521502273_item	3667074	et	4	main
nsv	doc_491521502273_item	3667068	et	4	main
ja	doc_491521502273_item	3667067	et	3	main
puudust	doc_491521502273_item	3667060	et	4	main
peod	doc_491521502273_item	3667046	et	4	main
omasid	doc_491521502273_item	3667044	et	4	main
isamaale	doc_491521502273_item	3667038	et	4	main
tagasi	doc_491521502273_item	3667037	et	3	main
tulla	doc_491521502273_item	3667036	et	3	main
kes	doc_491521502273_item	3667030	et	4	main
esiteks	doc_491521502273_item	3667022	et	3	main
muutused	doc_491521502273_item	3667019	et	4	main
osavõtjat	doc_491521502273_item	3667016	et	3	main
18	doc_491521502273_item	3667014	et	2	main
riikide	doc_491521502273_item	3667010	et	3	main
inkorporeeritud	doc_491521502273_item	3667009	et	4	main
nsv-sse	doc_491521502273_item	3667008	et	3	main
balti	doc_491521502273_item	3666973	et	3	main
riigid	doc_491521502273_item	3666967	et	3	main
euroopa	doc_491521502273_item	3666966	et	4	main
riikide	doc_491521502273_item	3666950	et	3	main
maailma	doc_491521502273_item	3666946	et	4	main
viia	doc_491521502273_item	3666945	et	3	main
püüdsid	doc_491521502273_item	3666944	et	4	main
inimesed	doc_491521502273_item	3666943	et	3	main
suur	doc_491521502273_item	3666935	et	3	main
balti	doc_491521502273_item	3666931	et	3	main
baltikumi	doc_491521502273_item	3666926	et	4	main
rõhutavad	doc_491521502273_item	3667147	et	4	main
kunstnikud	doc_491521502273_item	3667146	et	3	main
uute	doc_491521502273_item	3667124	et	3	main
loominguid	doc_491521502273_item	3667123	et	3	main
märgata	doc_491521502273_item	3667116	et	4	main
takistusi	doc_491521502271_item	3666908	et	4	main
tegevusele	doc_491521502271_item	3666907	et	4	main
rahvarinde	doc_491521502271_item	3666906	et	4	main
tegi	doc_491521502271_item	3666905	et	4	main
lihtsalt	doc_491521502271_item	3666904	et	4	main
see	doc_491521502271_item	3666903	et	3	main
suur	doc_491521502271_item	3666902	et	3	main
kuidagi	doc_491521502271_item	3666901	et	3	main
roll	doc_491521502271_item	3666900	et	3	main
polnud	doc_491521502271_item	3666898	et	3	main
interrinde	doc_491521502271_item	3666899	et	4	main
meelest	doc_491521502271_item	3666897	et	4	main
minu	doc_491521502271_item	3666896	et	3	main
taasiseseisvumist	doc_491521502271_item	3666895	et	3	main
eesti	doc_491521502271_item	3666894	et	4	main
takistada	doc_491521502271_item	3666893	et	3	main
et	doc_491521502271_item	3666892	et	3	main
sellele	doc_491521502271_item	3666891	et	4	main
suunatud	doc_491521502271_item	3666890	et	4	main
oli	doc_491521502271_item	3666889	et	3	main
kelle	doc_491521502271_item	3666887	et	4	main
sees	doc_491521502271_item	3666880	et	4	main
interrinne	doc_491521502271_item	3666879	et	3	main
tegevust	doc_491521502271_item	3666878	et	4	main
rahvarinde	doc_491521502271_item	3666877	et	4	main
streike	doc_491521502271_item	3666874	et	3	main
interrinne	doc_491521502271_item	3666869	et	3	main
vastuseis	doc_491521502271_item	3666857	et	4	main
impeeriumi	doc_491521502271_item	3666850	et	4	main
oli	doc_491521502271_item	3666849	et	3	main
põhieesmärgiks	doc_491521502271_item	3666848	et	3	main
ja	doc_491521502271_item	3666836	et	3	main
ning	doc_491521502271_item	3666832	et	3	main
majandus	doc_491521502271_item	3666829	et	4	main
või	doc_491521502271_item	3666824	et	4	main
suurem	doc_491521502271_item	3666818	et	4	main
elanikule	doc_491521502271_item	3666815	et	3	main
kõik	doc_491521502271_item	3666649	et	4	main
tagastatud	doc_491521502271_item	3666648	et	4	main
olid	doc_491521502271_item	3666647	et	4	main
käigus	doc_491521502271_item	3666646	et	4	main
selle	doc_491521502271_item	3666645	et	4	main
maareform	doc_491521502271_item	3666644	et	3	main
esiteks	doc_491521502271_item	3666640	et	3	main
keegi	doc_491521502271_item	3666618	et	4	main
hakkasid	doc_491521502271_item	3666611	et	4	main
arengu	doc_491521502271_item	3666610	et	3	main
uuendamisega	doc_491521502271_item	3666603	et	4	main
viidud	doc_491521502271_item	3666602	et	4	main
üldine	doc_491521502271_item	3666594	et	4	main
ja	doc_491521502271_item	3666593	et	3	main
toimus	doc_491521502271_item	3666586	et	3	main
roll	doc_491521502271_item	3666579	et	3	main
eesti	doc_491521502271_item	3666814	et	4	main
ühele	doc_491521502271_item	3666813	et	3	main
iseseisvuse	doc_491521502271_item	3666807	et	4	main
kiiremini	doc_491521502271_item	3666805	et	4	main
kõige	doc_491521502271_item	3666804	et	4	main
arenes	doc_491521502271_item	3666803	et	3	main
sai	doc_491521502271_item	3666796	et	4	main
takistanud	doc_491521502271_item	3666776	et	4	main
hakkasid	doc_491521502271_item	3666769	et	4	main
majanduse	doc_491521502271_item	3666766	et	4	main
eelarve	doc_491521502271_item	3666758	et	4	main
aja	doc_491521502271_item	3666747	et	4	main
endaga	doc_491521502271_item	3666740	et	4	main
kindel	doc_491521502271_item	3666737	et	3	main
tööjõu	doc_491521502273_item	3667083	et	3	main
integreerimis	doc_491521502273_item	3667080	et	4	main
hakkas	doc_491521502273_item	3667079	et	3	main
eesti	doc_491521502273_item	3667078	et	4	main
vastu	doc_491521502273_item	3667077	et	3	main
liitlaste	doc_491521502273_item	3667076	et	3	main
poliitikat	doc_491521502273_item	3667075	et	3	main
kontrolli	doc_491521502273_item	3667069	et	4	main
õppematerjalid	doc_491521502273_item	3667063	et	3	main
suurt	doc_491521502273_item	3667059	et	3	main
suletakse	doc_491521502273_item	3667056	et	4	main
majad	doc_491521502273_item	3667054	et	3	main
kultuuri	doc_491521502273_item	3667053	et	4	main
liidu	doc_491521502273_item	3667052	et	3	main
rahvalaulu	doc_491521502273_item	3667045	et	4	main
tähtsust	doc_491521502273_item	3667043	et	4	main
suurt	doc_491521502273_item	3667042	et	3	main
looma	doc_491521502273_item	3667041	et	4	main
võimaluse	doc_491521502273_item	3667035	et	3	main
kultuuritegelased	doc_491521502273_item	3667029	et	3	main
suured	doc_491521502273_item	3667021	et	3	main
miljonit	doc_491521502273_item	3667015	et	3	main
balti	doc_491521502273_item	3667012	et	3	main
eeskujuks	doc_491521502273_item	3667011	et	3	main
surmaks	doc_491521502273_item	3666983	et	4	main
viib	doc_491521502273_item	3666979	et	3	main
1991	doc_491521502271_item	3666641	et	2	main
viima	doc_491521502271_item	3666638	et	3	main
tõttu	doc_491521502271_item	3666630	et	4	main
poliitika	doc_491521502271_item	3666629	et	4	main
ebakindla	doc_491521502271_item	3666628	et	3	main
nsv	doc_491521502271_item	3666624	et	4	main
sai	doc_491521502271_item	3666622	et	4	main
hoolitsenud	doc_491521502271_item	3666620	et	4	main
ei	doc_491521502271_item	3666619	et	4	main
ning	doc_491521502271_item	3666615	et	3	main
mõtted	doc_491521502271_item	3666613	et	3	main
kõik	doc_491521502271_item	3666605	et	4	main
pidurdasid	doc_491521502271_item	3666604	et	4	main
nsv	doc_491521502271_item	3666599	et	4	main
eesti	doc_491521502271_item	3666583	et	4	main
taasiseseisvumisprotsessis	doc_491521502271_item	3666581	et	3	main
2	doc_491521502271_item	3666577	et	2	main
taasiseseisvunud	doc_491521502271_item	3666574	et	4	main
muudatused	doc_491521502271_item	3666573	et	3	main
ja	doc_491521502271_item	3666572	et	3	main
aastal	doc_491521502271_item	3666801	et	3	main
euroopa	doc_491521502271_item	3666797	et	4	main
vaba	doc_491521502271_item	3666790	et	4	main
leping	doc_491521502271_item	3666788	et	3	main
oli	doc_491521502271_item	3666786	et	3	main
1990-te	doc_491521502271_item	3666784	et	3	main
majandanud	doc_491521502271_item	3666782	et	4	main
oli	doc_491521502271_item	3666779	et	3	main
ettevõtted	doc_491521502271_item	3666773	et	3	main
ens	doc_491521502271_item	3666763	et	4	main
sõltuda	doc_491521502271_item	3666762	et	3	main
ev	doc_491521502271_item	3666756	et	4	main
loodud	doc_491521502271_item	3666755	et	4	main
õnnestus	doc_491521502271_item	3666750	et	4	main
valitsusel	doc_491521502271_item	3666749	et	4	main
panganduses	doc_491521502271_item	3666744	et	3	main
raha	doc_491521502271_item	3666729	et	4	main
kaasnesid	doc_491521502271_item	3666721	et	4	main
sellega	doc_491521502271_item	3666720	et	3	main
margaga	doc_491521502271_item	3666719	et	3	main
saksa	doc_491521502271_item	3666718	et	4	main
seotud	doc_491521502271_item	3666717	et	4	main
oli	doc_491521502271_item	3666716	et	3	main
mis	doc_491521502271_item	3666715	et	4	main
kroon	doc_491521502271_item	3666714	et	3	main
eesti	doc_491521502271_item	3666713	et	4	main
valuuta	doc_491521502271_item	3666712	et	4	main
oma	doc_491521502271_item	3666711	et	4	main
sai	doc_491521502271_item	3666710	et	4	main
eesti	doc_491521502271_item	3666709	et	4	main
reform	doc_491521502271_item	3666708	et	3	main
raha	doc_491521502271_item	3666707	et	4	main
viidud	doc_491521502271_item	3666706	et	4	main
läbi	doc_491521502271_item	3666705	et	4	main
oli	doc_491521502271_item	3666704	et	3	main
a	doc_491521502271_item	3666703	et	4	main
1992	doc_491521502271_item	3666702	et	2	main
üürinikud	doc_491521502271_item	3666701	et	4	main
kohtulikud	doc_491521502271_item	3666700	et	3	main
nn	doc_491521502271_item	3666699	et	4	main
sattusid	doc_491521502271_item	3666698	et	4	main
olukorda	doc_491521502271_item	3666697	et	4	main
halvema	doc_491521502271_item	3666696	et	4	main
lahendada	doc_491521502271_item	3666695	et	3	main
neid	doc_491521502271_item	3666694	et	4	main
said	doc_491521502271_item	3666693	et	4	main
elamispaigadega	doc_491521502271_item	3666692	et	4	main
probleemid	doc_491521502271_item	3666691	et	3	main
olid	doc_491521502271_item	3666690	et	4	main
põhjendasid	doc_491521502273_item	3667073	et	4	main
koostatud	doc_491521502273_item	3667065	et	4	main
õppematerjalidest	doc_491521502273_item	3667061	et	3	main
vana	doc_491521502271_item	3666728	et	4	main
jõudnud	doc_491521502271_item	3666727	et	4	main
inimesed	doc_491521502271_item	3666688	et	3	main
kellel	doc_491521502271_item	3666689	et	4	main
paljud	doc_491521502271_item	3666687	et	3	main
abil	doc_491521502271_item	3666686	et	4	main
kaartide	doc_491521502271_item	3666685	et	3	main
kollaste	doc_491521502271_item	3666684	et	4	main
saadud	doc_491521502271_item	3666683	et	4	main
poolt	doc_491521502271_item	3666682	et	4	main
riigi	doc_491521502271_item	3666681	et	3	main
omanikule	doc_491521502271_item	3666680	et	3	main
ühele	doc_491521502271_item	3666679	et	3	main
koondumist	doc_491521502271_item	3666678	et	4	main
aktsiaid	doc_491521502271_item	3666677	et	3	main
osa	doc_491521502271_item	3666676	et	4	main
suurima	doc_491521502271_item	3666675	et	4	main
tähendas	doc_491521502271_item	3666674	et	3	main
mis	doc_491521502271_item	3666673	et	4	main
erastamine	doc_491521502271_item	3666672	et	4	main
edukalt	doc_491521502271_item	3666671	et	4	main
väga	doc_491521502271_item	3666670	et	3	main
toimus	doc_491521502271_item	3666669	et	3	main
kõrvalt	doc_491521502271_item	3666668	et	4	main
kinnisvarasid	doc_491521502271_item	3666666	et	3	main
selle	doc_491521502271_item	3666667	et	4	main
kätte	doc_491521502271_item	3666665	et	4	main
said	doc_491521502271_item	3666664	et	4	main
sugulased	doc_491521502271_item	3666663	et	3	main
kauged	doc_491521502271_item	3666662	et	3	main
üsna	doc_491521502271_item	3666661	et	3	main
isegi	doc_491521502271_item	3666660	et	4	main
omanikele	doc_491521502271_item	3666659	et	3	main
endistele	doc_491521502271_item	3666658	et	3	main
korterid	doc_491521502271_item	3666657	et	3	main
ja	doc_491521502271_item	3666656	et	3	main
maavarad	doc_491521502271_item	3666655	et	3	main
võetud	doc_491521502271_item	3666654	et	4	main
ära	doc_491521502271_item	3666653	et	4	main
ajal	doc_491521502271_item	3666652	et	4	main
liidu	doc_491521502271_item	3666651	et	3	main
nsv	doc_491521502271_item	3666650	et	4	main
mis	doc_491521502273_item	3667071	et	4	main
all	doc_491521502273_item	3667070	et	3	main
olid	doc_491521502273_item	3667064	et	4	main
eesti	doc_491521502273_item	3667057	et	4	main
kultuuri	doc_491521502273_item	3667049	et	4	main
rahva	doc_491521502273_item	3667048	et	3	main
välismaal	doc_491521502273_item	3667032	et	4	main
tegutsesid	doc_491521502273_item	3667031	et	4	main
kõik	doc_491521502273_item	3667028	et	4	main
nsv	doc_491521502273_item	3667026	et	4	main
oli	doc_491521502273_item	3667023	et	3	main
ellu	doc_491521502273_item	3667004	et	4	main
iseseisvusest	doc_491521502273_item	3667003	et	4	main
unistuse	doc_491521502273_item	3667002	et	4	main
oma	doc_491521502273_item	3667001	et	4	main
viia	doc_491521502273_item	3667000	et	3	main
edukalt	doc_491521502273_item	3666999	et	4	main
saaksid	doc_491521502273_item	3666998	et	4	main
üheskoos	doc_491521502273_item	3666997	et	3	main
riigid	doc_491521502273_item	3666996	et	3	main
balti	doc_491521502273_item	3666995	et	3	main
et	doc_491521502273_item	3666994	et	3	main
näitas	doc_491521502273_item	3666993	et	3	main
kett	doc_491521502273_item	3666992	et	4	main
balti	doc_491521502273_item	3666991	et	3	main
võimatust	doc_491521502273_item	3666990	et	4	main
elamisvõime	doc_491521502273_item	3666989	et	4	main
kommunismi	doc_491521502273_item	3666988	et	4	main
väljendada	doc_491521502273_item	3666987	et	3	main
täielikult	doc_491521502273_item	3666986	et	4	main
võiks	doc_491521502273_item	3666985	et	4	main
mis	doc_491521502273_item	3666984	et	4	main
nsv	doc_491521502273_item	3666980	et	4	main
omajärel	doc_491521502273_item	3666978	et	3	main
taastamist	doc_491521502273_item	3666976	et	4	main
iseseisvuse	doc_491521502273_item	3666975	et	4	main
riikide	doc_491521502273_item	3666974	et	3	main
aitaksid	doc_491521502273_item	3666972	et	4	main
aktsioni	doc_491521502273_item	3666965	et	4	main
peale	doc_491521502273_item	3666952	et	4	main
pikkus	doc_491521502273_item	3666939	et	4	main
pandud	doc_491521502273_item	3666934	et	4	main
maailmale	doc_491521502273_item	3666929	et	4	main
ja	doc_491521502273_item	3666928	et	3	main
rahavstele	doc_491521502273_item	3666927	et	4	main
eluvastuvõttmine	doc_491521502273_item	3667150	et	4	main
seltskonna	doc_491521502273_item	3667149	et	3	main
oma	doc_491521502273_item	3667130	et	4	main
resurse	doc_491521502273_item	3667127	et	4	main
polnud	doc_491521502273_item	3667126	et	3	main
ajutilist	doc_491521502273_item	3667117	et	4	main
filmi	doc_491521502273_item	3667113	et	4	main
põlvkond	doc_491521502273_item	3667112	et	3	main
uute	doc_491521502273_item	3667110	et	3	main
teosed	doc_491521502273_item	3667107	et	3	main
trükitatud	doc_491521502273_item	3667103	et	4	main
suhtes	doc_491521502273_item	3667101	et	4	main
oli	doc_491521502278_item	3667478	et	3	main
see	doc_491521502278_item	3667477	et	3	main
mln	doc_491521502278_item	3667472	et	4	main
pikkus	doc_491521502278_item	3667459	et	4	main
tunneb	doc_491521502273_item	3667058	et	3	main
aktiivselt	doc_491521502273_item	3667055	et	4	main
kõrgenes	doc_491521502273_item	3667047	et	3	main
suurepärase	doc_491521502273_item	3667034	et	4	main
said	doc_491521502273_item	3667033	et	4	main
likvideeritud	doc_491521502273_item	3667024	et	4	main
olid	doc_491521502273_item	3667020	et	4	main
1989	doc_491521502273_item	3667017	et	2	main
kett	doc_491521502273_item	3667013	et	4	main
teistele	doc_491521502273_item	3667007	et	4	main
olla	doc_491521502273_item	3667006	et	3	main
ja	doc_491521502273_item	3667005	et	3	main
lagunemiseks	doc_491521502273_item	3666981	et	4	main
ekp	doc_491521502273_item	3666953	et	4	main
tähelepanu	doc_491521502273_item	3666948	et	4	main
km	doc_491521502273_item	3666942	et	4	main
600	doc_491521502273_item	3666941	et	2	main
oli	doc_491521502273_item	3666940	et	3	main
tähendus	doc_491521502273_item	3666925	et	4	main
taasiseseisvunud	doc_491521502273_item	3666915	et	4	main
muudatused	doc_491521502273_item	3666914	et	3	main
ja	doc_491521502273_item	3666913	et	3	main
muutused	doc_491521502273_item	3666912	et	4	main
1	doc_491521502273_item	3666911	et	2	main
kontrolltöö	doc_491521502273_item	3666910	et	4	main
ühinevad	doc_491521502273_item	3667154	et	4	main
nad	doc_491521502273_item	3667153	et	3	main
kuidas	doc_491521502273_item	3667152	et	3	main
muutub	doc_491521502273_item	3667151	et	3	main
eesti	doc_491521502273_item	3667145	et	4	main
obstraktsianism	doc_491521502273_item	3667144	et	4	main
ning	doc_491521502273_item	3667143	et	3	main
arusaam	doc_491521502273_item	3667142	et	3	main
tunnistajate	doc_491521502273_item	3667140	et	4	main
kommunismi	doc_491521502273_item	3667141	et	4	main
sotsrealism	doc_491521502273_item	3667139	et	3	main
populaarseks	doc_491521502273_item	3667138	et	4	main
sai	doc_491521502273_item	3667137	et	4	main
ajal	doc_491521502273_item	3667136	et	4	main
viimasel	doc_491521502273_item	3667135	et	3	main
maalikunst	doc_491521502273_item	3667134	et	3	main
lindid	doc_491521502273_item	3667133	et	3	main
ajaloolised	doc_491521502273_item	3667132	et	4	main
päpast	doc_491521502273_item	3666964	et	4	main
seas	doc_491521502273_item	3666963	et	4	main
masside	doc_491521502273_item	3666962	et	3	main
levitamine	doc_491521502273_item	3666961	et	4	main
mõistete	doc_491521502273_item	3666960	et	3	main
natsionaal	doc_491521502273_item	3666959	et	4	main
konkreetne	doc_491521502273_item	3666958	et	3	main
oli	doc_491521502273_item	3666957	et	3	main
reaktsioon	doc_491521502273_item	3666956	et	3	main
moskva	doc_491521502273_item	3666955	et	4	main
ja	doc_491521502273_item	3666954	et	3	main
oli	doc_491521502273_item	3666933	et	3	main
2	doc_491521502273_item	3666930	et	2	main
kett	doc_491521502273_item	3666923	et	4	main
balti	doc_491521502273_item	3666922	et	3	main
oli	doc_491521502273_item	3666921	et	3	main
sündmus	doc_491521502273_item	3666920	et	3	main
mis	doc_491521502273_item	3666919	et	4	main
2	doc_491521502273_item	3666918	et	2	main
kultuurielus	doc_491521502273_item	3666917	et	4	main
rahvaks	doc_491521502273_item	3667156	et	3	main
üheks	doc_491521502273_item	3667155	et	3	main
sarjad	doc_491521502273_item	3667131	et	4	main
ilmusid	doc_491521502273_item	3667129	et	4	main
edaspidi	doc_491521502273_item	3667128	et	3	main
püüdi	doc_491521502273_item	3667119	et	4	main
seisakut	doc_491521502273_item	3667118	et	3	main
läbinud	doc_491521502273_item	3667105	et	4	main
umbes	doc_491521502278_item	3667470	et	4	main
vapustavas	doc_491521502278_item	3667466	et	4	main
aastapäeval	doc_491521502278_item	3667447	et	3	main
2	doc_491521502278_item	3667435	et	2	main
selle	doc_491521502273_item	3666938	et	4	main
tähendus	doc_491521502273_item	3666937	et	4	main
poliitiline	doc_491521502273_item	3666936	et	3	main
kettil	doc_491521502273_item	3666932	et	4	main
selle	doc_491521502273_item	3666924	et	4	main
eesti	doc_491521502273_item	3666916	et	4	main
eestlaste	doc_491521502273_item	3667148	et	4	main
jaoks	doc_491521502273_item	3667125	et	4	main
oli	doc_491521502273_item	3667115	et	3	main
kirjanikude	doc_491521502273_item	3667111	et	3	main
tegutsema	doc_491521502273_item	3667109	et	3	main
mitte	doc_491521502273_item	3667104	et	3	main
olid	doc_491521502273_item	3667102	et	4	main
vabadust	doc_491521502278_item	3667476	et	4	main
2	doc_491521502278_item	3667471	et	2	main
maade	doc_491521502278_item	3667455	et	3	main
läbi	doc_491521502278_item	3667453	et	4	main
inimketti	doc_491521502278_item	3667452	et	4	main
endast	doc_491521502278_item	3667451	et	4	main
kujutas	doc_491521502278_item	3667450	et	3	main
50	doc_491521502278_item	3667446	et	2	main
molotov-ribbentropi	doc_491521502278_item	3667444	et	4	main
aastal	doc_491521502278_item	3667443	et	3	main
23081989	doc_491521502278_item	3667442	et	2	main
toimus	doc_491521502278_item	3667441	et	3	main
mis	doc_491521502278_item	3667440	et	4	main
üritus	doc_491521502278_item	3667439	et	4	main
oli	doc_491521502278_item	3667438	et	3	main
instituut	doc_491521502278_item	3667401	et	3	main
eesti	doc_491521502278_item	3667397	et	4	main
eestit	doc_491521502278_item	3667395	et	3	main
saab	doc_491521502278_item	3667391	et	3	main
luuletajatele	doc_491521502278_item	3667389	et	4	main
preemia	doc_491521502278_item	3667388	et	4	main
andma	doc_491521502278_item	3667384	et	3	main
nimesid	doc_491521502278_item	3667376	et	3	main
tagasi	doc_491521502278_item	3667366	et	3	main
tulevad	doc_491521502278_item	3667365	et	4	main
kultuurtegelased	doc_491521502278_item	3667360	et	3	main
volbriöö	doc_491521502278_item	3667356	et	4	main
okupatsiooni	doc_491521502278_item	3667352	et	4	main
olid	doc_491521502278_item	3667351	et	4	main
unustatud	doc_491521502278_item	3667342	et	4	main
olid	doc_491521502278_item	3667341	et	4	main
mõlemast	doc_491521502278_item	3667328	et	3	main
selts	doc_491521502278_item	3667324	et	3	main
oli	doc_491521502278_item	3667322	et	3	main
veljesto	doc_491521502278_item	3667319	et	4	main
väga	doc_491521502278_item	3667314	et	3	main
taandus	doc_491521502278_item	3667292	et	4	main
koolivorm	doc_491521502278_item	3667291	et	3	main
numbrid	doc_491521502278_item	3667290	et	3	main
tundmatud	doc_491521502278_item	3667278	et	4	main
rahvale	doc_491521502278_item	3667277	et	3	main
seni	doc_491521502278_item	3667276	et	3	main
usuteadus	doc_491521502278_item	3667269	et	4	main
erialasid	doc_491521502278_item	3667261	et	4	main
õpetama	doc_491521502278_item	3667258	et	3	main
graadid	doc_491521502278_item	3667256	et	4	main
magistri	doc_491521502278_item	3667255	et	3	main
ja	doc_491521502278_item	3667254	et	3	main
bakalaureuse	doc_491521502278_item	3667253	et	3	main
ilmusid	doc_491521502278_item	3667252	et	4	main
mis	doc_491521502278_item	3667244	et	4	main
see	doc_491521502278_item	3667239	et	3	main
õppetooliga	doc_491521502278_item	3667235	et	4	main
muudati	doc_491521502278_item	3667230	et	3	main
ja	doc_491521502278_item	3667229	et	3	main
ümber	doc_491521502278_item	3667228	et	3	main
nimetati	doc_491521502278_item	3667227	et	4	main
samuti	doc_491521502278_item	3667226	et	3	main
vanu	doc_491521502273_item	3667122	et	4	main
propageerida	doc_491521502273_item	3667121	et	3	main
rohkem	doc_491521502273_item	3667120	et	4	main
kunstis	doc_491521502273_item	3667114	et	3	main
tsensuuri	doc_491521502273_item	3667106	et	4	main
kirjanduse	doc_491521502273_item	3667100	et	3	main
riigikeeles	doc_491521502273_item	3667099	et	4	main
võimalus	doc_491521502273_item	3667098	et	3	main
kõrghariduse	doc_491521502273_item	3667097	et	3	main
keelele	doc_491521502273_item	3667096	et	4	main
eesti	doc_491521502273_item	3667095	et	4	main
õppeprotsessi	doc_491521502273_item	3667094	et	4	main
üleminekut	doc_491521502273_item	3667093	et	3	main
eeldavad	doc_491521502273_item	3667092	et	4	main
õppekavad	doc_491521502273_item	3667091	et	3	main
laagrid	doc_491521502273_item	3667090	et	3	main
integreerimis	doc_491521502273_item	3667089	et	4	main
loodud	doc_491521502273_item	3667088	et	4	main
seltskonda	doc_491521502273_item	3667087	et	4	main
eesti	doc_491521502273_item	3667086	et	4	main
integreerimine	doc_491521502273_item	3667085	et	4	main
hakkas	doc_491521502273_item	3667108	et	3	main
osa	doc_491521502278_item	3667469	et	4	main
ürituses	doc_491521502278_item	3667467	et	4	main
selles	doc_491521502278_item	3667465	et	4	main
ning	doc_491521502278_item	3667464	et	3	main
km	doc_491521502278_item	3667463	et	4	main
600	doc_491521502278_item	3667462	et	2	main
üle	doc_491521502278_item	3667461	et	3	main
oli	doc_491521502278_item	3667460	et	3	main
rahvastele	doc_491521502278_item	3667503	et	4	main
ida-euroopa	doc_491521502278_item	3667502	et	4	main
teiste	doc_491521502278_item	3667501	et	4	main
ka	doc_491521502278_item	3667500	et	3	main
eeskujuks	doc_491521502278_item	3667499	et	3	main
omamoodi	doc_491521502278_item	3667498	et	3	main
sai	doc_491521502278_item	3667497	et	4	main
kett	doc_491521502278_item	3667496	et	4	main
balti	doc_491521502278_item	3667495	et	3	main
teadvamusele	doc_491521502278_item	3667494	et	4	main
iseseisvusetaotluse	doc_491521502278_item	3667493	et	4	main
riikide	doc_491521502278_item	3667492	et	3	main
balti	doc_491521502278_item	3667491	et	3	main
kaasa	doc_491521502278_item	3667490	et	4	main
oluliselt	doc_491521502278_item	3667489	et	4	main
aitas	doc_491521502278_item	3667488	et	3	main
ning	doc_491521502278_item	3667487	et	3	main
maailmas	doc_491521502278_item	3667486	et	3	main
kogu	doc_491521502278_item	3667485	et	4	main
tähelepanu	doc_491521502278_item	3667484	et	4	main
äratas	doc_491521502278_item	3667483	et	3	main
e	doc_491521502278_item	3667482	et	4	main
meeleavaldus	doc_491521502278_item	3667481	et	3	main
originaalne	doc_491521502278_item	3667480	et	3	main
niivõrd	doc_491521502278_item	3667479	et	3	main
nõudsid	doc_491521502278_item	3667475	et	4	main
kes	doc_491521502278_item	3667474	et	4	main
inimest	doc_491521502278_item	3667473	et	3	main
võttis	doc_491521502278_item	3667468	et	3	main
et	doc_491521502278_item	3667457	et	3	main
balti	doc_491521502278_item	3667454	et	3	main
balti	doc_491521502278_item	3667448	et	3	main
pakti	doc_491521502278_item	3667445	et	4	main
tsensuur	doc_491521502278_item	3667434	et	3	main
taandus	doc_491521502278_item	3667433	et	4	main
riigikeeleks	doc_491521502278_item	3667432	et	4	main
saab	doc_491521502278_item	3667431	et	3	main
keel	doc_491521502278_item	3667430	et	4	main
eesti	doc_491521502278_item	3667429	et	4	main
tallinnas	doc_491521502278_item	3667428	et	4	main
selts	doc_491521502278_item	3667427	et	3	main
saarlaste	doc_491521502278_item	3667426	et	4	main
nt	doc_491521502278_item	3667425	et	4	main
seltse	doc_491521502278_item	3667424	et	3	main
oma	doc_491521502278_item	3667423	et	4	main
moodustama	doc_491521502278_item	3667422	et	3	main
hakkavad	doc_491521502278_item	3667421	et	4	main
rühmad	doc_491521502278_item	3667420	et	4	main
etnilised	doc_491521502278_item	3667419	et	3	main
murre-küsimus	doc_491521502278_item	3667418	et	4	main
ka	doc_491521502278_item	3667417	et	3	main
tekkib	doc_491521502278_item	3667416	et	3	main
jt	doc_491521502278_item	3667415	et	4	main
estonia	doc_491521502278_item	3667414	et	4	main
hilarious	doc_491521502278_item	3667413	et	4	main
people	doc_491521502278_item	3667412	et	4	main
estonian	doc_491521502278_item	3667411	et	4	main
nt	doc_491521502278_item	3667410	et	4	main
keeltes	doc_491521502278_item	3667409	et	3	main
suuremateks	doc_491521502278_item	3667408	et	4	main
maailma	doc_491521502278_item	3667407	et	4	main
eestist	doc_491521502278_item	3667406	et	3	main
brošüüre	doc_491521502278_item	3667405	et	2	main
andma	doc_491521502278_item	3667404	et	3	main
keti	doc_491521502278_item	3667458	et	3	main
arvatakse	doc_491521502278_item	3667456	et	3	main
kett	doc_491521502278_item	3667449	et	4	main
kett	doc_491521502278_item	3667437	et	4	main
balti	doc_491521502278_item	3667436	et	3	main
välja	doc_491521502278_item	3667403	et	4	main
eesti	doc_491521502278_item	3667400	et	4	main
rahvast	doc_491521502278_item	3667398	et	4	main
ja	doc_491521502278_item	3667396	et	3	main
nimelise	doc_491521502278_item	3667387	et	4	main
looming	doc_491521502278_item	3667378	et	3	main
arvo	doc_491521502278_item	3667374	et	4	main
eestisse	doc_491521502278_item	3667367	et	4	main
välja	doc_491521502278_item	3667363	et	4	main
kes	doc_491521502278_item	3667361	et	4	main
jne	doc_491521502278_item	3667359	et	4	main
1	doc_491521502278_item	3667357	et	2	main
nt	doc_491521502278_item	3667355	et	4	main
keelatud	doc_491521502278_item	3667354	et	4	main
nsv	doc_491521502278_item	3667343	et	4	main
tavad	doc_491521502278_item	3667339	et	3	main
taastati	doc_491521502278_item	3667336	et	4	main
selts	doc_491521502278_item	3667335	et	3	main
akadeemiline	doc_491521502278_item	3667333	et	3	main
ka	doc_491521502278_item	3667332	et	3	main
taassünnib	doc_491521502278_item	3667331	et	3	main
isikud	doc_491521502278_item	3667330	et	3	main
selts	doc_491521502278_item	3667318	et	3	main
korporatsioonid	doc_491521502278_item	3667310	et	3	main
uuesti	doc_491521502278_item	3667308	et	3	main
et	doc_491521502278_item	3667306	et	3	main
seda	doc_491521502278_item	3667305	et	3	main
tähendas	doc_491521502278_item	3667303	et	3	main
nüüdsest	doc_491521502278_item	3667300	et	3	main
19	doc_491521502278_item	3667297	et	2	main
mütsidki	doc_491521502278_item	3667296	et	3	main
üliõpilaste	doc_491521502278_item	3667295	et	4	main
nagu	doc_491521502278_item	3667294	et	3	main
nii	doc_491521502278_item	3667293	et	3	main
muutuvad	doc_491521502278_item	3667284	et	4	main
sotsiaal-psühholoogi-eriala	doc_491521502278_item	3667282	et	4	main
võib	doc_491521502278_item	3667280	et	3	main
näidena	doc_491521502278_item	3667279	et	4	main
erialasid	doc_491521502278_item	3667273	et	4	main
uusi	doc_491521502278_item	3667272	et	3	main
ka	doc_491521502278_item	3667271	et	3	main
samuti	doc_491521502278_item	3667270	et	3	main
nagu	doc_491521502278_item	3667267	et	3	main
graad	doc_491521502278_item	3667250	et	4	main
kandidaadi	doc_491521502278_item	3667249	et	3	main
aastat	doc_491521502278_item	3667248	et	3	main
10	doc_491521502278_item	3667247	et	2	main
juba	doc_491521502278_item	3667246	et	3	main
muidu	doc_491521502278_item	3667241	et	3	main
ainekavadega	doc_491521502278_item	3667238	et	3	main
kursused	doc_491521502278_item	3667236	et	3	main
vahetus	doc_491521502278_item	3667234	et	4	main
kateeder	doc_491521502278_item	3667233	et	3	main
süsteem	doc_491521502278_item	3667232	et	3	main
õpetamise	doc_491521502278_item	3667231	et	4	main
tänapäeval	doc_491521502278_item	3667222	et	3	main
tegutsevad	doc_491521502278_item	3667220	et	4	main
rakenduslikku	doc_491521502278_item	3667215	et	4	main
andis	doc_491521502278_item	3667214	et	3	main
vahetati	doc_491521502278_item	3667200	et	4	main
haridus	doc_491521502278_item	3667199	et	3	main
peegeldus	doc_491521502278_item	3667190	et	4	main
sündmus	doc_491521502278_item	3667189	et	3	main
suur	doc_491521502278_item	3667188	et	3	main
hakkab	doc_491521502278_item	3667402	et	3	main
tutvustada	doc_491521502278_item	3667394	et	3	main
kuidas	doc_491521502278_item	3667393	et	3	main
kangro	doc_491521502278_item	3667386	et	4	main
välja	doc_491521502278_item	3667383	et	4	main
hakatakse	doc_491521502278_item	3667382	et	3	main
väärtseks	doc_491521502278_item	3667381	et	3	main
jälle	doc_491521502278_item	3667380	et	3	main
sai	doc_491521502278_item	3667379	et	4	main
siin	doc_491521502278_item	3667368	et	4	main
ajal	doc_491521502278_item	3667353	et	4	main
ajal	doc_491521502278_item	3667345	et	4	main
liidu	doc_491521502278_item	3667344	et	3	main
mis	doc_491521502278_item	3667340	et	4	main
kommed	doc_491521502278_item	3667337	et	4	main
teoloogia	doc_491521502278_item	3667334	et	4	main
soost	doc_491521502278_item	3667329	et	4	main
võisid	doc_491521502278_item	3667326	et	4	main
tudengite	doc_491521502278_item	3667317	et	3	main
ka	doc_491521502278_item	3667312	et	3	main
ajal	doc_491521502278_item	3667265	et	4	main
mis	doc_491521502278_item	3667262	et	4	main
neid	doc_491521502278_item	3667260	et	4	main
kestab	doc_491521502278_item	3667245	et	4	main
oli	doc_491521502278_item	3667240	et	3	main
aga	doc_491521502278_item	3667237	et	3	main
narvas	doc_491521502278_item	3667225	et	4	main
ülikoolist	doc_491521502278_item	3667207	et	4	main
sai	doc_491521502278_item	3667204	et	4	main
nii	doc_491521502278_item	3667203	et	3	main
küsimus	doc_491521502278_item	3667392	et	4	main
pärdi	doc_491521502278_item	3667375	et	4	main
järvi	doc_491521502278_item	3667372	et	4	main
neeme	doc_491521502278_item	3667371	et	4	main
nimetada	doc_491521502278_item	3667370	et	3	main
tuleb	doc_491521502278_item	3667369	et	3	main
olid	doc_491521502278_item	3667362	et	4	main
tähistama	doc_491521502278_item	3667348	et	3	main
jälle	doc_491521502278_item	3667347	et	3	main
hakati	doc_491521502278_item	3667346	et	3	main
ja	doc_491521502278_item	3667338	et	3	main
see	doc_491521502278_item	3667321	et	3	main
tartus	doc_491521502278_item	3667320	et	3	main
erialaseltsid	doc_491521502278_item	3667313	et	3	main
ja	doc_491521502278_item	3667311	et	3	main
tegutsema	doc_491521502278_item	3667309	et	3	main
hakkasid	doc_491521502278_item	3667307	et	4	main
veel	doc_491521502278_item	3667304	et	4	main
taasiseseisvus	doc_491521502278_item	3667302	et	4	main
ära	doc_491521502278_item	3667289	et	4	main
kaovad	doc_491521502278_item	3667288	et	3	main
uuesti	doc_491521502278_item	3667287	et	3	main
keskkoolis	doc_491521502278_item	3667283	et	4	main
tuua	doc_491521502278_item	3667281	et	3	main
mis	doc_491521502278_item	3667274	et	4	main
näiteks	doc_491521502278_item	3667268	et	4	main
taandus	doc_491521502278_item	3667251	et	4	main
keeruline	doc_491521502278_item	3667242	et	4	main
pärnus	doc_491521502278_item	3667223	et	3	main
kolledžid	doc_491521502278_item	3667219	et	2	main
tartu	doc_491521502278_item	3667217	et	4	main
kõrgharidust	doc_491521502278_item	3667216	et	4	main
mõistekolledž	doc_491521502278_item	3667212	et	2	main
riigi	doc_491521502278_item	3667206	et	3	main
nimetused	doc_491521502278_item	3667202	et	4	main
kõrgkoolide	doc_491521502278_item	3667201	et	3	main
ka	doc_491521502278_item	3667196	et	3	main
mõjutas	doc_491521502278_item	3667194	et	3	main
valdkondades	doc_491521502278_item	3667193	et	3	main
elu	doc_491521502278_item	3667192	et	4	main
20081991	doc_491521502278_item	3667185	et	2	main
taastati	doc_491521502278_item	3667183	et	4	main
eestis	doc_491521502278_item	3667182	et	3	main
1	doc_491521502278_item	3667178	et	2	main
maailmale	doc_491521502278_item	3667177	et	4	main
rahavstele	doc_491521502278_item	3667175	et	4	main
sündmus	doc_491521502278_item	3667168	et	3	main
kättest	doc_491521502279_item	3667853	et	4	main
eesti	doc_491521502279_item	3667843	et	4	main
probleemiks	doc_491521502279_item	3667824	et	4	main
rohkem	doc_491521502279_item	3667813	et	4	main
noored	doc_491521502279_item	3667807	et	3	main
kommed	doc_491521502279_item	3667804	et	4	main
valida	doc_491521502279_item	3667795	et	3	main
õigesti	doc_491521502279_item	3667794	et	3	main
kurssi	doc_491521502279_item	3667793	et	4	main
oli	doc_491521502279_item	3667791	et	3	main
raske	doc_491521502279_item	3667790	et	4	main
nt	doc_491521502279_item	3667786	et	4	main
et	doc_491521502279_item	3667784	et	3	main
välismaalastele	doc_491521502278_item	3667399	et	4	main
probleemseks	doc_491521502278_item	3667390	et	4	main
b	doc_491521502278_item	3667385	et	4	main
nende	doc_491521502278_item	3667377	et	4	main
ja	doc_491521502278_item	3667373	et	3	main
tõrjutud	doc_491521502278_item	3667364	et	4	main
mai	doc_491521502278_item	3667358	et	4	main
mis	doc_491521502278_item	3667350	et	4	main
tähtpäeva	doc_491521502278_item	3667349	et	4	main
kuuluda	doc_491521502278_item	3667327	et	4	main
kuhu	doc_491521502278_item	3667325	et	3	main
ainuke	doc_491521502278_item	3667323	et	4	main
oli	doc_491521502278_item	3667316	et	3	main
aktiivne	doc_491521502278_item	3667315	et	3	main
põhikool	doc_491521502278_item	3667301	et	4	main
on	doc_491521502278_item	3667299	et	4	main
klass	doc_491521502278_item	3667298	et	3	main
nimetustest	doc_491521502278_item	3667286	et	4	main
gümnaasiumideks	doc_491521502278_item	3667285	et	3	main
olid	doc_491521502278_item	3667275	et	4	main
keelatud	doc_491521502278_item	3667266	et	4	main
nõukogude	doc_491521502278_item	3667264	et	3	main
olid	doc_491521502278_item	3667263	et	4	main
uuesti	doc_491521502278_item	3667259	et	3	main
hakati	doc_491521502278_item	3667257	et	3	main
protsess	doc_491521502278_item	3667243	et	3	main
ja	doc_491521502278_item	3667224	et	3	main
mis	doc_491521502278_item	3667213	et	4	main
ilmus	doc_491521502278_item	3667210	et	4	main
kultuurielu	doc_491521502278_item	3667198	et	4	main
oluliselt	doc_491521502278_item	3667195	et	4	main
kõikides	doc_491521502278_item	3667191	et	4	main
ja	doc_491521502278_item	3667176	et	3	main
kett	doc_491521502278_item	3667171	et	4	main
balti	doc_491521502278_item	3667170	et	3	main
oli	doc_491521502278_item	3667169	et	3	main
kultuurielus	doc_491521502278_item	3667165	et	4	main
taasiseseisvunud	doc_491521502278_item	3667163	et	4	main
muudatused	doc_491521502278_item	3667162	et	3	main
ja	doc_491521502278_item	3667161	et	3	main
muutused	doc_491521502278_item	3667160	et	4	main
1	doc_491521502278_item	3667159	et	2	main
ka	doc_491521502278_item	3667221	et	3	main
ülikooli	doc_491521502278_item	3667218	et	4	main
uus	doc_491521502278_item	3667211	et	3	main
ülikool	doc_491521502278_item	3667209	et	4	main
tartu	doc_491521502278_item	3667208	et	4	main
tartu	doc_491521502278_item	3667205	et	4	main
baltikumi	doc_491521502278_item	3667174	et	4	main
mis	doc_491521502278_item	3667167	et	4	main
eesti	doc_491521502278_item	3667164	et	4	main
tõesti	doc_491521502279_item	3667866	et	3	main
vabadusele	doc_491521502279_item	3667862	et	4	main
tahtsid	doc_491521502279_item	3667856	et	4	main
kinni	doc_491521502279_item	3667854	et	3	main
leedu	doc_491521502279_item	3667846	et	4	main
ja	doc_491521502279_item	3667845	et	3	main
läti	doc_491521502279_item	3667844	et	4	main
sellel	doc_491521502279_item	3667838	et	4	main
toimus	doc_491521502279_item	3667834	et	3	main
samuti	doc_491521502279_item	3667829	et	3	main
sai	doc_491521502279_item	3667825	et	4	main
saavad	doc_491521502279_item	3667820	et	4	main
palju	doc_491521502279_item	3667818	et	4	main
vaatasid	doc_491521502279_item	3667808	et	4	main
vanad	doc_491521502279_item	3667803	et	3	main
poliitilise	doc_491521502279_item	3667792	et	3	main
eesti	doc_491521502278_item	3667197	et	4	main
aastal	doc_491521502278_item	3667186	et	3	main
tähendus	doc_491521502278_item	3667173	et	4	main
2	doc_491521502278_item	3667166	et	2	main
pööras	doc_491521502279_item	3667865	et	4	main
oma	doc_491521502279_item	3667860	et	4	main
näidata	doc_491521502279_item	3667859	et	4	main
võetes	doc_491521502279_item	3667851	et	4	main
ketti	doc_491521502279_item	3667850	et	4	main
päeval	doc_491521502279_item	3667839	et	3	main
nn	doc_491521502279_item	3667835	et	4	main
2	doc_491521502279_item	3667832	et	2	main
suureks	doc_491521502279_item	3667823	et	4	main
tööd	doc_491521502279_item	3667819	et	4	main
üsna	doc_491521502279_item	3667817	et	3	main
sotsiaalprobleemidele	doc_491521502279_item	3667816	et	3	main
arusaamad	doc_491521502279_item	3667805	et	3	main
keskealised	doc_491521502279_item	3667799	et	4	main
ja	doc_491521502279_item	3667798	et	3	main
muulasi	doc_491521502279_item	3667789	et	4	main
sellel	doc_491521502279_item	3667770	et	4	main
öelda	doc_491521502279_item	3667767	et	4	main
ajal	doc_491521502279_item	3667765	et	4	main
poliitika	doc_491521502279_item	3667763	et	4	main
tööd	doc_491521502279_item	3667757	et	4	main
sama	doc_491521502279_item	3667756	et	4	main
uuesti	doc_491521502279_item	3667755	et	3	main
ajal	doc_491521502279_item	3667749	et	4	main
õigel	doc_491521502279_item	3667748	et	3	main
salvesta	doc_491521502279_item	3667747	et	4	main
arvutite	doc_491521502279_item	3667739	et	4	main
aga	doc_491521502279_item	3667738	et	3	main
mobiiltelefone	doc_491521502279_item	3667737	et	3	main
selle	doc_491521502279_item	3667726	et	4	main
nt	doc_491521502279_item	3667720	et	4	main
preemiat	doc_491521502279_item	3667719	et	3	main
andma	doc_491521502279_item	3667718	et	3	main
hakati	doc_491521502279_item	3667717	et	3	main
neeme	doc_491521502279_item	3667712	et	4	main
oma	doc_491521502279_item	3667707	et	4	main
pöördusid	doc_491521502279_item	3667700	et	4	main
kirjanikud	doc_491521502279_item	3667699	et	3	main
nendel	doc_491521502279_item	3667691	et	4	main
kes	doc_491521502279_item	3667682	et	4	main
setu	doc_491521502279_item	3667676	et	4	main
see	doc_491521502278_item	3667187	et	3	main
iseseisvus	doc_491521502278_item	3667184	et	4	main
et	doc_491521502278_item	3667181	et	3	main
sellega	doc_491521502278_item	3667180	et	3	main
alustan	doc_491521502278_item	3667179	et	3	main
selle	doc_491521502278_item	3667172	et	4	main
kontrolltöö	doc_491521502278_item	3667158	et	4	main
suurt	doc_491521502279_item	3667867	et	3	main
sündmus	doc_491521502279_item	3667864	et	3	main
püüdlust	doc_491521502279_item	3667861	et	3	main
sellega	doc_491521502279_item	3667855	et	3	main
millioni	doc_491521502279_item	3667842	et	4	main
2	doc_491521502279_item	3667841	et	2	main
kett	doc_491521502279_item	3667837	et	4	main
tegelevad	doc_491521502279_item	3667830	et	4	main
eest	doc_491521502279_item	3667822	et	4	main
hakatakse	doc_491521502279_item	3667812	et	3	main
poole	doc_491521502279_item	3667811	et	4	main
euroopa	doc_491521502279_item	3667810	et	4	main
ettepoole	doc_491521502279_item	3667809	et	3	main
vanad	doc_491521502279_item	3667797	et	3	main
sest	doc_491521502279_item	3667796	et	4	main
40	doc_491521502279_item	3667788	et	2	main
eestis	doc_491521502279_item	3667785	et	3	main
see	doc_491521502279_item	3667783	et	3	main
probleemidele	doc_491521502279_item	3667870	et	3	main
baltikumi	doc_491521502279_item	3667869	et	4	main
tähelepanu	doc_491521502279_item	3667868	et	4	main
see	doc_491521502279_item	3667863	et	3	main
maailmale	doc_491521502279_item	3667858	et	4	main
nad	doc_491521502279_item	3667857	et	3	main
kõik	doc_491521502279_item	3667852	et	4	main
pikka	doc_491521502279_item	3667849	et	4	main
moodustasid	doc_491521502279_item	3667848	et	4	main
elanikku	doc_491521502279_item	3667847	et	4	main
umbes	doc_491521502279_item	3667840	et	4	main
balti	doc_491521502279_item	3667836	et	3	main
23089	doc_491521502279_item	3667833	et	2	main
sotsiaaltöötajad	doc_491521502279_item	3667831	et	3	main
millega	doc_491521502279_item	3667828	et	3	main
narkomaania	doc_491521502279_item	3667827	et	4	main
ka	doc_491521502279_item	3667826	et	3	main
nende	doc_491521502279_item	3667821	et	4	main
pööratakse	doc_491521502279_item	3667815	et	3	main
tähelepanu	doc_491521502279_item	3667814	et	4	main
aga	doc_491521502279_item	3667806	et	3	main
tagapoole	doc_491521502279_item	3667802	et	4	main
veel	doc_491521502279_item	3667801	et	4	main
vaatasid	doc_491521502279_item	3667800	et	4	main
oli	doc_491521502279_item	3667787	et	3	main
aga	doc_491521502279_item	3667782	et	3	main
oli	doc_491521502279_item	3667781	et	3	main
probleemiks	doc_491521502279_item	3667780	et	4	main
suureks	doc_491521502279_item	3667779	et	4	main
liikmed	doc_491521502279_item	3667778	et	3	main
el	doc_491521502279_item	3667777	et	4	main
potentsiaalsed	doc_491521502279_item	3667776	et	3	main
oli	doc_491521502279_item	3667775	et	3	main
eesti	doc_491521502279_item	3667774	et	4	main
ja	doc_491521502279_item	3667773	et	3	main
läti	doc_491521502279_item	3667772	et	4	main
ajal	doc_491521502279_item	3667771	et	4	main
juba	doc_491521502279_item	3667769	et	3	main
võib	doc_491521502279_item	3667766	et	3	main
eesti	doc_491521502279_item	3667759	et	4	main
võib	doc_491521502279_item	3667751	et	3	main
ka	doc_491521502279_item	3667742	et	3	main
kasutamine	doc_491521502279_item	3667740	et	4	main
igalpool	doc_491521502279_item	3667732	et	4	main
aja	doc_491521502279_item	3667727	et	4	main
preemia	doc_491521502279_item	3667725	et	4	main
kirjaniketele	doc_491521502279_item	3667716	et	4	main
part	doc_491521502279_item	3667711	et	4	main
arvo	doc_491521502279_item	3667710	et	4	main
nt	doc_491521502279_item	3667709	et	4	main
kultuuri	doc_491521502279_item	3667708	et	4	main
tutvustavad	doc_491521502279_item	3667704	et	4	main
ja	doc_491521502279_item	3667703	et	3	main
et	doc_491521502279_item	3667768	et	3	main
taasiseseisvuse	doc_491521502279_item	3667764	et	4	main
integratsiooni	doc_491521502279_item	3667762	et	4	main
ja	doc_491521502279_item	3667761	et	3	main
peab	doc_491521502279_item	3667754	et	4	main
siis	doc_491521502279_item	3667753	et	3	main
kaduda	doc_491521502279_item	3667752	et	3	main
kõik	doc_491521502279_item	3667750	et	4	main
telefoni	doc_491521502279_item	3667736	et	4	main
arvutit	doc_491521502279_item	3667735	et	3	main
kasutama	doc_491521502279_item	3667734	et	3	main
hakati	doc_491521502279_item	3667733	et	3	main
tehtikaareng	doc_491521502279_item	3667731	et	4	main
kiire	doc_491521502279_item	3667730	et	4	main
ka	doc_491521502279_item	3667729	et	3	main
iseloomustab	doc_491521502279_item	3667728	et	4	main
nimeline	doc_491521502279_item	3667724	et	4	main
kangro	doc_491521502279_item	3667723	et	4	main
b	doc_491521502279_item	3667714	et	4	main
nüüd	doc_491521502279_item	3667705	et	4	main
kõrgkultuur	doc_491521502279_item	3667697	et	3	main
on	doc_491521502279_item	3667690	et	4	main
seetõttu	doc_491521502279_item	3667689	et	3	main
sfääris	doc_491521502279_item	3667687	et	3	main
õigeusu	doc_491521502279_item	3667685	et	3	main
pidada	doc_491521502279_item	3667675	et	4	main
eraldi	doc_491521502279_item	3667672	et	4	main
murreid	doc_491521502279_item	3667668	et	4	main
ka	doc_491521502279_item	3667667	et	3	main
hakati	doc_491521502279_item	3667666	et	3	main
eestis	doc_491521502279_item	3667665	et	3	main
eesti	doc_491521502279_item	3667661	et	4	main
õiget	doc_491521502279_item	3667660	et	3	main
üht	doc_491521502279_item	3667659	et	3	main
kasutama	doc_491521502279_item	3667658	et	3	main
kultuurilelule	doc_491521502279_item	3667650	et	3	main
mõju	doc_491521502279_item	3667649	et	4	main
avaldas	doc_491521502279_item	3667647	et	3	main
regionaalne	doc_491521502279_item	3667645	et	3	main
välismaaga	doc_491521502279_item	3667644	et	3	main
kultuurisuhted	doc_491521502279_item	3667643	et	3	main
nad	doc_491521502279_item	3667640	et	3	main
ka	doc_491521502279_item	3667637	et	3	main
ats	doc_491521502279_item	3667633	et	3	main
ars	doc_491521502279_item	3667632	et	4	main
uuesti	doc_491521502279_item	3667623	et	3	main
võiks	doc_491521502279_item	3667622	et	4	main
koolivormi	doc_491521502279_item	3667621	et	4	main
palju	doc_491521502279_item	3667618	et	4	main
2	doc_491521502279_item	3667513	et	2	main
kultuurielus	doc_491521502279_item	3667512	et	4	main
ja	doc_491521502279_item	3667508	et	3	main
mees-	doc_491521502279_item	3667607	et	4	main
nt	doc_491521502279_item	3667599	et	4	main
kultuuri	doc_491521502279_item	3667598	et	4	main
korporatsiooni	doc_491521502279_item	3667597	et	4	main
varem	doc_491521502279_item	3667563	et	4	main
varem	doc_491521502279_item	3667553	et	4	main
ülikoolides	doc_491521502279_item	3667552	et	3	main
1-9	doc_491521502279_item	3667549	et	2	main
keele	doc_491521502279_item	3667760	et	4	main
tegema	doc_491521502279_item	3667758	et	3	main
ei	doc_491521502279_item	3667746	et	4	main
kui	doc_491521502279_item	3667744	et	3	main
järvi	doc_491521502279_item	3667713	et	4	main
eesti	doc_491521502279_item	3667706	et	4	main
paljud	doc_491521502279_item	3667698	et	3	main
kultuur	doc_491521502279_item	3667695	et	3	main
rahvaks	doc_491521502279_item	3667673	et	3	main
näiteks	doc_491521502279_item	3667670	et	4	main
taasiseseisvunud	doc_491521502279_item	3667664	et	4	main
pidid	doc_491521502279_item	3667657	et	4	main
ei	doc_491521502279_item	3667653	et	4	main
nl-s	doc_491521502279_item	3667651	et	3	main
ões	doc_491521502279_item	3667631	et	4	main
sellest	doc_491521502279_item	3667619	et	4	main
tü	doc_491521502279_item	3667534	et	4	main
tr	doc_491521502279_item	3667533	et	4	main
nt	doc_491521502279_item	3667532	et	4	main
nimetused	doc_491521502279_item	3667531	et	4	main
paljud	doc_491521502279_item	3667530	et	3	main
muudeti	doc_491521502279_item	3667529	et	3	main
1	doc_491521502279_item	3667528	et	2	main
ajal	doc_491521502279_item	3667527	et	4	main
taasiseseisvuse	doc_491521502279_item	3667526	et	4	main
hariduselu	doc_491521502279_item	3667525	et	4	main
maailmale	doc_491521502279_item	3667524	et	4	main
ja	doc_491521502279_item	3667523	et	3	main
rahavstele	doc_491521502279_item	3667522	et	4	main
baltikumi	doc_491521502279_item	3667521	et	4	main
tähendus	doc_491521502279_item	3667520	et	4	main
selle	doc_491521502279_item	3667519	et	4	main
kett	doc_491521502279_item	3667518	et	4	main
balti	doc_491521502279_item	3667517	et	3	main
oli	doc_491521502279_item	3667516	et	3	main
sündmus	doc_491521502279_item	3667515	et	3	main
mis	doc_491521502279_item	3667514	et	4	main
infot	doc_491521502279_item	3667745	et	3	main
ohtlik	doc_491521502279_item	3667743	et	3	main
on	doc_491521502279_item	3667741	et	4	main
b	doc_491521502279_item	3667722	et	4	main
oli	doc_491521502279_item	3667721	et	3	main
kangro	doc_491521502279_item	3667715	et	4	main
kodumaale	doc_491521502279_item	3667702	et	4	main
välismaalt	doc_491521502279_item	3667701	et	3	main
oli	doc_491521502279_item	3667683	et	3	main
rahvas	doc_491521502279_item	3667681	et	4	main
piiriäärne	doc_491521502279_item	3667680	et	3	main
on	doc_491521502279_item	3667679	et	4	main
see	doc_491521502279_item	3667678	et	3	main
rahva	doc_491521502279_item	3667677	et	3	main
peaaegu	doc_491521502279_item	3667671	et	3	main
õpetama	doc_491521502279_item	3667669	et	3	main
keelt	doc_491521502279_item	3667662	et	4	main
tohtinud	doc_491521502279_item	3667654	et	4	main
regionaalkeelt	doc_491521502279_item	3667652	et	4	main
poliitika	doc_491521502279_item	3667646	et	4	main
normaliseeruda	doc_491521502279_item	3667642	et	3	main
välja	doc_491521502279_item	3667636	et	4	main
nt	doc_491521502279_item	3667630	et	4	main
erialaseltse	doc_491521502279_item	3667629	et	3	main
ka	doc_491521502279_item	3667628	et	3	main
et	doc_491521502279_item	3667620	et	3	main
räägitakse	doc_491521502279_item	3667617	et	3	main
taasiseseisvunud	doc_491521502279_item	3667510	et	4	main
kuigi	doc_491521502279_item	3667614	et	3	main
kaob	doc_491521502279_item	3667612	et	3	main
soost	doc_491521502279_item	3667610	et	4	main
kuhu	doc_491521502279_item	3667604	et	3	main
selts	doc_491521502279_item	3667603	et	3	main
veljesto	doc_491521502279_item	3667601	et	4	main
eüs	doc_491521502279_item	3667600	et	4	main
taastati	doc_491521502279_item	3667596	et	4	main
5	doc_491521502279_item	3667595	et	2	main
vastupidi	doc_491521502279_item	3667594	et	3	main
ja	doc_491521502279_item	3667593	et	3	main
välismaalt	doc_491521502279_item	3667592	et	3	main
õpilase	doc_491521502279_item	3667591	et	3	main
tuleb	doc_491521502279_item	3667590	et	3	main
teaduskonnad	doc_491521502279_item	3667561	et	4	main
2	doc_491521502279_item	3667558	et	2	main
gümnaasiumiks	doc_491521502279_item	3667548	et	3	main
pandi	doc_491521502279_item	3667536	et	4	main
koolidele	doc_491521502279_item	3667535	et	3	main
tekkeni	doc_491521502283_item	3668237	et	3	main
poliitika	doc_491521502283_item	3668232	et	4	main
gorbtšov	doc_491521502283_item	3668230	et	2	main
protsessid	doc_491521502283_item	3668228	et	4	main
süvenenud	doc_491521502283_item	3668206	et	4	main
niivõrd	doc_491521502283_item	3668205	et	3	main
veel	doc_491521502283_item	3668200	et	4	main
selleks	doc_491521502283_item	3668191	et	4	main
neid	doc_491521502283_item	3668187	et	4	main
liberaalsemaks	doc_491521502283_item	3668174	et	4	main
poliitika	doc_491521502283_item	3668173	et	4	main
liidu	doc_491521502283_item	3668172	et	3	main
perestroika	doc_491521502283_item	3667884	et	4	main
2	doc_491521502283_item	3667878	et	2	main
taasiseseivumisprotsessis	doc_491521502283_item	3667877	et	4	main
terroreziimist	doc_491521502283_item	3668154	et	4	main
aegses	doc_491521502283_item	3668153	et	3	main
kombed	doc_491521502279_item	3667696	et	3	main
keel	doc_491521502279_item	3667694	et	4	main
oma	doc_491521502279_item	3667693	et	4	main
inimestel	doc_491521502279_item	3667692	et	3	main
ja	doc_491521502279_item	3667688	et	3	main
mõju	doc_491521502279_item	3667686	et	4	main
kaua	doc_491521502279_item	3667684	et	3	main
võib	doc_491521502279_item	3667674	et	3	main
nüüd	doc_491521502279_item	3667663	et	4	main
kõik	doc_491521502279_item	3667656	et	4	main
rääkida	doc_491521502279_item	3667655	et	3	main
ka	doc_491521502279_item	3667648	et	3	main
püüdsid	doc_491521502279_item	3667641	et	4	main
oma	doc_491521502279_item	3667638	et	4	main
andsid	doc_491521502279_item	3667635	et	4	main
mõned	doc_491521502279_item	3667634	et	3	main
kasutusele	doc_491521502279_item	3667624	et	4	main
muudatused	doc_491521502279_item	3667509	et	3	main
kontrolltöö	doc_491521502279_item	3667505	et	4	main
praegu	doc_491521502279_item	3667615	et	3	main
6	doc_491521502279_item	3667611	et	2	main
naiss	doc_491521502279_item	3667609	et	4	main
kui	doc_491521502279_item	3667608	et	3	main
mõned	doc_491521502279_item	3667560	et	3	main
taastatakse	doc_491521502279_item	3667559	et	3	main
nüüd	doc_491521502279_item	3667556	et	4	main
katedraal	doc_491521502279_item	3667555	et	3	main
nimetama	doc_491521502279_item	3667547	et	3	main
kolledž	doc_491521502279_item	3667544	et	2	main
suud	doc_491521502283_item	3668233	et	4	main
valitud	doc_491521502283_item	3668231	et	4	main
muud	doc_491521502283_item	3668211	et	4	main
polnud	doc_491521502283_item	3668210	et	3	main
kriis	doc_491521502283_item	3668203	et	3	main
liitu	doc_491521502283_item	3668198	et	4	main
mõrenevat	doc_491521502283_item	3668196	et	4	main
ja	doc_491521502283_item	3668195	et	3	main
uut	doc_491521502283_item	3668181	et	3	main
tähendus	doc_491521502283_item	3668179	et	4	main
nsv	doc_491521502283_item	3668171	et	4	main
tähendas	doc_491521502283_item	3668170	et	3	main
eesti	doc_491521502283_item	3667876	et	4	main
roll	doc_491521502283_item	3667875	et	3	main
kontrolltöö	doc_491521502283_item	3667872	et	4	main
rääkima	doc_491521502283_item	3668151	et	3	main
et	doc_491521502283_item	3668148	et	3	main
tähendust	doc_491521502283_item	3668146	et	4	main
gorbatšoviga	doc_491521502283_item	3668144	et	2	main
mihhail	doc_491521502283_item	3668143	et	4	main
presidendi	doc_491521502283_item	3668142	et	4	main
liidu	doc_491521502283_item	3668141	et	3	main
a	doc_491521502283_item	3668132	et	4	main
1985	doc_491521502283_item	3668131	et	2	main
kaks	doc_491521502283_item	3668127	et	3	main
ja	doc_491521502283_item	3668122	et	3	main
möödus	doc_491521502283_item	3668115	et	3	main
eesti	doc_491521502283_item	3668113	et	4	main
oli	doc_491521502283_item	3668109	et	3	main
kuid	doc_491521502283_item	3668095	et	4	main
moskva-meelseks	doc_491521502283_item	3668094	et	3	main
suure	doc_491521502283_item	3668086	et	3	main
peaministri	doc_491521502283_item	3668077	et	3	main
edgar	doc_491521502283_item	3668075	et	4	main
eesti	doc_491521502283_item	3668060	et	4	main
veebruar	doc_491521502283_item	3668058	et	3	main
aug	doc_491521502283_item	3668047	et	4	main
kes	doc_491521502283_item	3668043	et	4	main
nendest	doc_491521502283_item	3668041	et	4	main
üks	doc_491521502283_item	3668040	et	3	main
ka	doc_491521502283_item	3668039	et	3	main
läbimõeldud	doc_491521502283_item	3668034	et	4	main
emotsionaalselt	doc_491521502283_item	3668031	et	4	main
mitte	doc_491521502283_item	3668030	et	3	main
rahvusrinde	doc_491521502283_item	3668015	et	4	main
ka	doc_491521502283_item	3668014	et	3	main
vastu	doc_491521502283_item	3668013	et	3	main
võttis	doc_491521502283_item	3668012	et	3	main
eesti	doc_491521502283_item	3668002	et	4	main
interliikumist	doc_491521502283_item	3667956	et	3	main
eesti	doc_491521502283_item	3667953	et	4	main
uuendus	doc_491521502283_item	3667949	et	4	main
ajakirju	doc_491521502279_item	3667639	et	4	main
taastati	doc_491521502279_item	3667627	et	4	main
7	doc_491521502279_item	3667626	et	2	main
võtta	doc_491521502279_item	3667625	et	3	main
eesti	doc_491521502279_item	3667511	et	4	main
muutused	doc_491521502279_item	3667507	et	4	main
juba	doc_491521502279_item	3667616	et	3	main
koolivorm	doc_491521502279_item	3667613	et	3	main
nii	doc_491521502279_item	3667606	et	3	main
ainuke	doc_491521502279_item	3667602	et	4	main
hakab	doc_491521502279_item	3667586	et	4	main
4	doc_491521502279_item	3667585	et	2	main
järgi	doc_491521502279_item	3667584	et	4	main
32	doc_491521502279_item	3667582	et	2	main
programmi	doc_491521502279_item	3667583	et	4	main
õpitakse	doc_491521502279_item	3667581	et	4	main
aastal	doc_491521502279_item	3667580	et	3	main
viimasel	doc_491521502279_item	3667579	et	3	main
ainekavadele	doc_491521502279_item	3667578	et	3	main
üle	doc_491521502279_item	3667577	et	3	main
minnakse	doc_491521502279_item	3667576	et	3	main
süsteemist	doc_491521502279_item	3667575	et	4	main
kursuse	doc_491521502279_item	3667574	et	3	main
süsteem	doc_491521502279_item	3667573	et	3	main
uus	doc_491521502279_item	3667572	et	3	main
on	doc_491521502279_item	3667571	et	4	main
ülikoolides	doc_491521502279_item	3667570	et	3	main
3	doc_491521502279_item	3667569	et	2	main
usuteadus	doc_491521502279_item	3667568	et	4	main
1	doc_491521502279_item	3667506	et	2	main
kuulusid	doc_491521502279_item	3667605	et	4	main
eestisse	doc_491521502279_item	3667589	et	4	main
välisvahetus	doc_491521502279_item	3667588	et	4	main
toimuma	doc_491521502279_item	3667587	et	3	main
nt	doc_491521502279_item	3667567	et	4	main
keelatud	doc_491521502279_item	3667566	et	4	main
olid	doc_491521502279_item	3667565	et	4	main
nl-s	doc_491521502279_item	3667564	et	3	main
õppetool	doc_491521502279_item	3667557	et	3	main
oli	doc_491521502279_item	3667554	et	3	main
põhikooliks	doc_491521502279_item	3667551	et	4	main
klass	doc_491521502279_item	3667550	et	3	main
hakatakse	doc_491521502279_item	3667546	et	3	main
kasutusele	doc_491521502279_item	3667540	et	4	main
nimed	doc_491521502279_item	3667539	et	3	main
uued	doc_491521502279_item	3667538	et	3	main
ka	doc_491521502279_item	3667537	et	3	main
vabariigi	doc_491521502283_item	3668236	et	3	main
nsv	doc_491521502283_item	3668197	et	4	main
mis	doc_491521502279_item	3667562	et	4	main
eesti	doc_491521502283_item	3668235	et	4	main
ensv	doc_491521502283_item	3668225	et	4	main
ka	doc_491521502283_item	3668224	et	3	main
sai	doc_491521502283_item	3668222	et	4	main
protsesse	doc_491521502283_item	3668221	et	3	main
ksoteh	doc_491521502283_item	3668214	et	4	main
kui	doc_491521502283_item	3668213	et	3	main
võimalust	doc_491521502283_item	3668212	et	3	main
et	doc_491521502283_item	3668207	et	3	main
kuid	doc_491521502283_item	3668202	et	4	main
niigi	doc_491521502283_item	3668193	et	4	main
et	doc_491521502283_item	3668192	et	3	main
muutmist	doc_491521502283_item	3668175	et	4	main
ja	doc_491521502283_item	3667883	et	3	main
mõisted	doc_491521502283_item	3667881	et	3	main
tähendavad	doc_491521502283_item	3667880	et	4	main
rahvarinde	doc_491521502283_item	3667874	et	4	main
mõtte-	doc_491521502283_item	3668166	et	3	main
staali	doc_491521502283_item	3668152	et	4	main
avalikult	doc_491521502283_item	3668150	et	4	main
hakati	doc_491521502283_item	3668149	et	3	main
nsv	doc_491521502283_item	3668140	et	4	main
viimase	doc_491521502283_item	3668139	et	3	main
esimese	doc_491521502283_item	3668137	et	3	main
tulnud	doc_491521502283_item	3668136	et	4	main
ehk	doc_491521502283_item	3668124	et	3	main
jaoks	doc_491521502283_item	3668117	et	4	main
selline	doc_491521502283_item	3668096	et	4	main
kuuluga	doc_491521502283_item	3668087	et	4	main
taasiseseisvumisprotsessis	doc_491521502283_item	3668084	et	3	main
panus	doc_491521502283_item	3668082	et	4	main
rahvarinde	doc_491521502283_item	3668081	et	4	main
et	doc_491521502283_item	3668080	et	3	main
rahvarinde	doc_491521502283_item	3668073	et	4	main
sai	doc_491521502283_item	3668072	et	4	main
a	doc_491521502283_item	3668067	et	4	main
1991	doc_491521502283_item	3668066	et	2	main
sept	doc_491521502283_item	3668065	et	4	main
20	doc_491521502283_item	3668064	et	2	main
komitee	doc_491521502283_item	3668061	et	4	main
24	doc_491521502283_item	3668057	et	2	main
ketti	doc_491521502283_item	3668050	et	4	main
23	doc_491521502283_item	3668046	et	2	main
rühmitustest	doc_491521502283_item	3668042	et	4	main
oli	doc_491521502283_item	3668038	et	3	main
küll	doc_491521502283_item	3668029	et	4	main
tegutses	doc_491521502283_item	3668028	et	3	main
rahvusrinne	doc_491521502283_item	3668027	et	3	main
riikliku	doc_491521502283_item	3668024	et	3	main
nõudmised	doc_491521502283_item	3668016	et	4	main
mille	doc_491521502283_item	3668004	et	3	main
programmi	doc_491521502283_item	3668003	et	4	main
1987	doc_491521502283_item	3667999	et	2	main
läbisuruda	doc_491521502283_item	3667997	et	4	main
bürokraatia	doc_491521502283_item	3667958	et	4	main
rahvas	doc_491521502283_item	3667954	et	4	main
meelestatud	doc_491521502283_item	3667952	et	4	main
keskkooli	doc_491521502279_item	3667545	et	4	main
mõiste	doc_491521502279_item	3667543	et	4	main
uus	doc_491521502279_item	3667542	et	3	main
tuli	doc_491521502279_item	3667541	et	4	main
viisid	doc_491521502283_item	3668234	et	4	main
ja	doc_491521502283_item	3668229	et	3	main
need	doc_491521502283_item	3668227	et	3	main
kus	doc_491521502283_item	3668226	et	3	main
tunda	doc_491521502283_item	3668223	et	3	main
kõiki	doc_491521502283_item	3668215	et	4	main
nsv	doc_491521502283_item	3668208	et	4	main
oli	doc_491521502283_item	3668204	et	3	main
kuidagi	doc_491521502283_item	3668199	et	3	main
gorbatšov	doc_491521502283_item	3668190	et	2	main
võttis	doc_491521502283_item	3668189	et	3	main
meetmeid	doc_491521502283_item	3668188	et	3	main
kõiki	doc_491521502283_item	3668186	et	4	main
kooperatiivid	doc_491521502283_item	3668185	et	3	main
ühistud	doc_491521502283_item	3668184	et	3	main
mõtlemise	doc_491521502283_item	3668183	et	4	main
see	doc_491521502283_item	3668180	et	3	main
majanduses	doc_491521502283_item	3668178	et	4	main
lähedasemaks	doc_491521502283_item	3668177	et	4	main
rahvale	doc_491521502283_item	3668176	et	3	main
perestroika	doc_491521502283_item	3668169	et	4	main
sõnavabadust	doc_491521502283_item	3668168	et	4	main
ja	doc_491521502283_item	3668167	et	3	main
rahvarinne	doc_491521502283_item	3667886	et	3	main
1	doc_491521502283_item	3667885	et	2	main
glasnost	doc_491521502283_item	3667882	et	4	main
sai	doc_491521502283_item	3668164	et	4	main
poliitikast	doc_491521502283_item	3668162	et	4	main
varjatud	doc_491521502283_item	3668161	et	4	main
liidu	doc_491521502283_item	3668160	et	3	main
nsv	doc_491521502283_item	3668159	et	4	main
ka	doc_491521502283_item	3668158	et	3	main
ning	doc_491521502283_item	3668157	et	3	main
repressioonidest	doc_491521502283_item	3668156	et	3	main
küüsitamistest	doc_491521502283_item	3668155	et	4	main
nsv	doc_491521502283_item	3668133	et	4	main
terminit	doc_491521502283_item	3668128	et	3	main
perestroika	doc_491521502283_item	3668123	et	4	main
rahva	doc_491521502283_item	3668116	et	3	main
see	doc_491521502283_item	3668111	et	3	main
sest	doc_491521502283_item	3668104	et	4	main
ja	doc_491521502283_item	3668101	et	3	main
pigem	doc_491521502283_item	3668099	et	3	main
oli	doc_491521502283_item	3668098	et	3	main
arvan	doc_491521502283_item	3668079	et	3	main
savisaar	doc_491521502283_item	3668076	et	3	main
juht	doc_491521502283_item	3668074	et	3	main
1990	doc_491521502283_item	3668059	et	2	main
veel	doc_491521502283_item	3668056	et	4	main
ei	doc_491521502283_item	3668053	et	4	main
1990	doc_491521502283_item	3668048	et	2	main
võttis	doc_491521502283_item	3668044	et	3	main
hoolutud	doc_491521502283_item	3668035	et	4	main
tegi	doc_491521502283_item	3668033	et	4	main
vaid	doc_491521502283_item	3668032	et	3	main
staatuse	doc_491521502283_item	3668025	et	3	main
keelele	doc_491521502283_item	3668023	et	4	main
riigi	doc_491521502283_item	3668022	et	3	main
eesti	doc_491521502283_item	3668021	et	4	main
kui	doc_491521502283_item	3668020	et	3	main
keelelele	doc_491521502283_item	3668019	et	4	main
ekp	doc_491521502283_item	3668011	et	4	main
savisaar	doc_491521502283_item	3668010	et	3	main
isemajandava	doc_491521502283_item	3668001	et	3	main
ka	doc_491521502283_item	3667998	et	3	main
aktiivselt	doc_491521502283_item	3667965	et	4	main
võtab	doc_491521502283_item	3667964	et	3	main
interrinne	doc_491521502283_item	3667963	et	3	main
proletariaat	doc_491521502283_item	3667962	et	3	main
siinne	doc_491521502283_item	3667961	et	3	main
ja	doc_491521502283_item	3667960	et	3	main
aga	doc_491521502283_item	3667955	et	3	main
ja	doc_491521502283_item	3667950	et	3	main
isamaaliitu	doc_491521502283_item	3667936	et	4	main
seltsi	doc_491521502283_item	3667930	et	4	main
terve	doc_491521502285_item	3668400	et	4	main
õnnestunud	doc_491521502285_item	3668397	et	4	main
ei	doc_491521502285_item	3668396	et	4	main
käivaid	doc_491521502283_item	3668220	et	4	main
käsikäes	doc_491521502283_item	3668219	et	3	main
glasnostiga	doc_491521502283_item	3668218	et	4	main
ja	doc_491521502283_item	3668217	et	3	main
perestroika	doc_491521502283_item	3668216	et	4	main
liidul	doc_491521502283_item	3668209	et	3	main
päästa	doc_491521502283_item	3668201	et	4	main
pankrotistuvat	doc_491521502283_item	3668194	et	4	main
moodi	doc_491521502283_item	3668182	et	4	main
mida	doc_491521502283_item	3667879	et	4	main
1	doc_491521502283_item	3667873	et	2	main
rohkem	doc_491521502283_item	3668165	et	4	main
ajakirjandus	doc_491521502283_item	3668163	et	3	main
seda	doc_491521502283_item	3668147	et	3	main
ja	doc_491521502283_item	3668138	et	3	main
käisid	doc_491521502283_item	3668130	et	4	main
ometi	doc_491521502283_item	3668105	et	3	main
ratsionaalne	doc_491521502283_item	3668102	et	3	main
ja	doc_491521502283_item	3668093	et	3	main
reetlikuks	doc_491521502283_item	3668092	et	3	main
tegevust	doc_491521502283_item	3668091	et	4	main
savisaare	doc_491521502283_item	3668090	et	3	main
hindasid	doc_491521502283_item	3668089	et	4	main
mõned	doc_491521502283_item	3668088	et	3	main
valimistel	doc_491521502283_item	3668071	et	4	main
kuid	doc_491521502283_item	3668063	et	4	main
osa	doc_491521502283_item	3668055	et	4	main
võimule	doc_491521502283_item	3668135	et	3	main
glasnost	doc_491521502283_item	3668145	et	4	main
liidus	doc_491521502283_item	3668134	et	4	main
mis	doc_491521502283_item	3668129	et	4	main
avalikustamine	doc_491521502283_item	3668121	et	4	main
glasnost	doc_491521502283_item	3668120	et	4	main
2	doc_491521502283_item	3668119	et	2	main
veretult	doc_491521502283_item	3668118	et	4	main
taasiseseisvumine	doc_491521502283_item	3668114	et	3	main
et	doc_491521502283_item	3668112	et	3	main
ka	doc_491521502283_item	3668110	et	3	main
teeneks	doc_491521502283_item	3668108	et	4	main
rahvarinde	doc_491521502283_item	3668107	et	4	main
ka	doc_491521502283_item	3668106	et	3	main
shokegija	doc_491521502283_item	3668103	et	4	main
hoolutletud	doc_491521502283_item	3668100	et	4	main
käitumise	doc_491521502283_item	3668097	et	4	main
on	doc_491521502283_item	3668085	et	4	main
eesti	doc_491521502283_item	3668083	et	4	main
koha	doc_491521502283_item	3668078	et	4	main
presidendi	doc_491521502283_item	3668070	et	4	main
ja	doc_491521502283_item	3668069	et	3	main
riigikogu	doc_491521502283_item	3668068	et	4	main
valimistest	doc_491521502283_item	3668062	et	4	main
võtnud	doc_491521502283_item	3668054	et	4	main
rahvarinne	doc_491521502283_item	3668052	et	3	main
organiseerimises	doc_491521502283_item	3668051	et	4	main
osa	doc_491521502283_item	3668045	et	4	main
andmise	doc_491521502283_item	3668026	et	4	main
kodakondsusest	doc_491521502283_item	3668017	et	4	main
loojaks	doc_491521502283_item	3668006	et	4	main
üheks	doc_491521502283_item	3668005	et	3	main
ime	doc_491521502283_item	3668000	et	4	main
lodvik	doc_491521502283_item	3667959	et	4	main
vabameelselt	doc_491521502283_item	3667951	et	4	main
toetas	doc_491521502283_item	3667948	et	3	main
rahvarinnet	doc_491521502283_item	3667947	et	3	main
astusid	doc_491521502283_item	3667934	et	4	main
omaalgatusliku	doc_491521502283_item	3667891	et	3	main
laostus	doc_491521502285_item	3668399	et	4	main
vaid	doc_491521502285_item	3668398	et	3	main
eluviisi	doc_491521502285_item	3668383	et	4	main
vana	doc_491521502285_item	3668382	et	4	main
laostama	doc_491521502285_item	3668381	et	3	main
pidi	doc_491521502285_item	3668380	et	4	main
programm	doc_491521502285_item	3668379	et	3	main
uus	doc_491521502285_item	3668378	et	3	main
see	doc_491521502285_item	3668377	et	3	main
paremaks	doc_491521502285_item	3668371	et	4	main
gorbatsjovi	doc_491521502285_item	3668366	et	4	main
läinud	doc_491521502285_item	3668362	et	4	main
lihtsalt	doc_491521502285_item	3668359	et	4	main
oli	doc_491521502285_item	3668357	et	3	main
mida	doc_491521502285_item	3668348	et	4	main
siis	doc_491521502285_item	3668339	et	3	main
vabadus	doc_491521502285_item	3668334	et	4	main
kõige	doc_491521502285_item	3668327	et	4	main
oli	doc_491521502285_item	3668326	et	3	main
taasiseseisvumisprotsessis	doc_491521502285_item	3668325	et	3	main
inimesed	doc_491521502285_item	3668301	et	3	main
ja	doc_491521502285_item	3668296	et	3	main
võitlema	doc_491521502285_item	3668292	et	3	main
teda	doc_491521502285_item	3668291	et	4	main
rääkima	doc_491521502285_item	3668288	et	3	main
aita	doc_491521502285_item	3668281	et	4	main
lagunemine	doc_491521502287_item	3668625	et	4	main
nii	doc_491521502287_item	3668610	et	3	main
mõtleme	doc_491521502287_item	3668435	et	3	main
esitas	doc_491521502287_item	3668431	et	3	main
e	doc_491521502287_item	3668428	et	4	main
luua	doc_491521502287_item	3668426	et	4	main
rahvarinde	doc_491521502287_item	3668405	et	4	main
1	doc_491521502287_item	3668404	et	2	main
kontrolltöö	doc_491521502287_item	3668403	et	4	main
viia	doc_491521502287_item	3668609	et	3	main
siiski	doc_491521502287_item	3668603	et	4	main
langema	doc_491521502287_item	3668602	et	3	main
g	doc_491521502287_item	3668548	et	4	main
kriisini	doc_491521502287_item	3668547	et	3	main
tarbekaupade	doc_491521502287_item	3668546	et	3	main
balti	doc_491521502283_item	3668049	et	3	main
rahvarinne	doc_491521502283_item	3668037	et	3	main
otsuseid	doc_491521502283_item	3668036	et	3	main
eesti	doc_491521502283_item	3668018	et	4	main
edgar	doc_491521502283_item	3668009	et	4	main
ka	doc_491521502283_item	3668008	et	3	main
oli	doc_491521502283_item	3668007	et	3	main
ekp	doc_491521502283_item	3667996	et	4	main
püüdis	doc_491521502283_item	3667995	et	3	main
rahvarinne	doc_491521502283_item	3667994	et	3	main
vabaks	doc_491521502283_item	3667993	et	3	main
end	doc_491521502283_item	3667992	et	4	main
laulis	doc_491521502283_item	3667991	et	4	main
rahvas	doc_491521502283_item	3667990	et	4	main
kus	doc_491521502283_item	3667989	et	3	main
revolutsiooniks	doc_491521502283_item	3667988	et	3	main
laulvaks	doc_491521502283_item	3667987	et	4	main
ajaloos	doc_491521502283_item	3667986	et	4	main
nimetati	doc_491521502283_item	3667985	et	4	main
öid	doc_491521502283_item	3667984	et	3	main
neid	doc_491521502283_item	3667983	et	4	main
rahvussümboolikat	doc_491521502283_item	3667982	et	3	main
eesti	doc_491521502283_item	3667981	et	4	main
kasutati	doc_491521502283_item	3667980	et	4	main
ja	doc_491521502283_item	3667979	et	3	main
laule	doc_491521502283_item	3667978	et	4	main
isamaalisi	doc_491521502283_item	3667977	et	4	main
lauldi	doc_491521502283_item	3667976	et	3	main
kus	doc_491521502283_item	3667975	et	3	main
kokkusaamistel	doc_491521502283_item	3667974	et	4	main
öisetel	doc_491521502283_item	3667973	et	4	main
inimeste	doc_491521502283_item	3667972	et	3	main
toimuvatest	doc_491521502283_item	3667971	et	4	main
lauluväljakul	doc_491521502283_item	3667970	et	3	main
tallinna	doc_491521502283_item	3667969	et	4	main
1988	doc_491521502283_item	3667968	et	2	main
ka	doc_491521502283_item	3667967	et	3	main
osa	doc_491521502283_item	3667966	et	4	main
moskva	doc_491521502283_item	3667957	et	4	main
impeeriumimeelselt	doc_491521502283_item	3667941	et	4	main
vastukaaluks	doc_491521502283_item	3667940	et	3	main
ka	doc_491521502283_item	3667939	et	3	main
tekkis	doc_491521502283_item	3667938	et	3	main
rahvarinne	doc_491521502283_item	3667937	et	3	main
tõusis	doc_491521502283_item	3667895	et	4	main
etteotsa	doc_491521502283_item	3667894	et	3	main
mille	doc_491521502283_item	3667893	et	3	main
organisatsioonina	doc_491521502283_item	3667892	et	3	main
a	doc_491521502283_item	3667889	et	4	main
1988	doc_491521502283_item	3667888	et	2	main
loodi	doc_491521502283_item	3667887	et	4	main
riigi	doc_491521502285_item	3668401	et	3	main
riiki	doc_491521502285_item	3668375	et	4	main
viis	doc_491521502285_item	3668374	et	4	main
perestroika	doc_491521502285_item	3668363	et	4	main
tahad	doc_491521502285_item	3668349	et	3	main
öelda	doc_491521502285_item	3668345	et	4	main
räägiti	doc_491521502285_item	3668340	et	3	main
tuli	doc_491521502285_item	3668337	et	4	main
nsvsse	doc_491521502285_item	3668336	et	4	main
kui	doc_491521502285_item	3668335	et	3	main
kodumaa	doc_491521502285_item	3668294	et	4	main
ja	doc_491521502285_item	3668289	et	3	main
rahvaga	doc_491521502285_item	3668287	et	3	main
ju	doc_491521502285_item	3668285	et	3	main
teda	doc_491521502285_item	3668279	et	4	main
interliikumisel	doc_491521502283_item	3667946	et	3	main
muulastest	doc_491521502283_item	3667944	et	4	main
peamiselt	doc_491521502283_item	3667943	et	4	main
ja	doc_491521502283_item	3667942	et	3	main
paljud	doc_491521502283_item	3667933	et	3	main
poliitikutel	doc_491521502283_item	3667931	et	3	main
meelestatud	doc_491521502283_item	3667927	et	4	main
radikaalselt	doc_491521502283_item	3667926	et	4	main
kui	doc_491521502283_item	3667925	et	3	main
tagasihoidlikum	doc_491521502283_item	3667924	et	4	main
veidi	doc_491521502283_item	3667923	et	3	main
oli	doc_491521502283_item	3667922	et	3	main
hoiak	doc_491521502283_item	3667921	et	3	main
poliitiline	doc_491521502283_item	3667920	et	3	main
rahvarinde	doc_491521502283_item	3667919	et	4	main
staatuse	doc_491521502283_item	3667918	et	3	main
autonoomia	doc_491521502283_item	3667917	et	4	main
eestile	doc_491521502283_item	3667916	et	3	main
pigem	doc_491521502283_item	3667915	et	3	main
taotledes	doc_491521502283_item	3667914	et	3	main
liidust	doc_491521502283_item	3667913	et	4	main
nsv	doc_491521502283_item	3667912	et	4	main
astumist	doc_491521502283_item	3667911	et	4	main
välja	doc_491521502283_item	3667910	et	4	main
eesti	doc_491521502283_item	3667909	et	4	main
nõudnud	doc_491521502283_item	3667908	et	4	main
ei	doc_491521502283_item	3667907	et	4	main
otseselt	doc_491521502283_item	3667906	et	4	main
kes	doc_491521502283_item	3667905	et	4	main
kultuuritegelasi	doc_491521502283_item	3667904	et	3	main
ja	doc_491521502283_item	3667903	et	3	main
poliitikuid	doc_491521502283_item	3667902	et	3	main
vabameelseid	doc_491521502283_item	3667901	et	3	main
endasse	doc_491521502283_item	3667900	et	4	main
koondas	doc_491521502283_item	3667899	et	3	main
rahvarinne	doc_491521502283_item	3667898	et	3	main
savisaar	doc_491521502283_item	3667897	et	3	main
koosnevale	doc_491521502283_item	3667945	et	4	main
hiljem	doc_491521502283_item	3667935	et	3	main
kellest	doc_491521502283_item	3667932	et	4	main
muinsuskaitse	doc_491521502283_item	3667929	et	4	main
eesti	doc_491521502283_item	3667928	et	4	main
edgar	doc_491521502283_item	3667896	et	4	main
rahva	doc_491521502283_item	3667890	et	3	main
gumannsem	doc_491521502285_item	3668391	et	4	main
ja	doc_491521502285_item	3668390	et	3	main
kaasaegsem	doc_491521502285_item	3668389	et	4	main
on	doc_491521502285_item	3668388	et	4	main
kuid	doc_491521502285_item	3668373	et	4	main
tegema	doc_491521502285_item	3668372	et	3	main
on	doc_491521502285_item	3668365	et	4	main
see	doc_491521502285_item	3668364	et	3	main
pidavat	doc_491521502285_item	3668351	et	4	main
tsensuur	doc_491521502285_item	3668350	et	3	main
sõna	doc_491521502285_item	3668333	et	4	main
eesti	doc_491521502285_item	3668324	et	4	main
roll	doc_491521502285_item	3668323	et	3	main
aspekt	doc_491521502285_item	3668299	et	3	main
veel	doc_491521502285_item	3668297	et	4	main
oma	doc_491521502285_item	3668293	et	4	main
julgustama	doc_491521502285_item	3668290	et	3	main
keegi	doc_491521502285_item	3668284	et	4	main
ülevalt	doc_491521502285_item	3668283	et	4	main
kui	doc_491521502285_item	3668278	et	3	main
sai	doc_491521502287_item	3668623	et	4	main
alguse	doc_491521502287_item	3668622	et	3	main
õnnestunud	doc_491521502287_item	3668621	et	4	main
kommunism	doc_491521502287_item	3668612	et	3	main
ta	doc_491521502287_item	3668430	et	4	main
rr	doc_491521502287_item	3668425	et	4	main
rahvus-meelsed	doc_491521502287_item	3668422	et	3	main
kuhu	doc_491521502287_item	3668420	et	3	main
oli	doc_491521502287_item	3668418	et	3	main
rr	doc_491521502287_item	3668417	et	4	main
1	doc_491521502287_item	3668416	et	2	main
läbi	doc_491521502287_item	3668608	et	4	main
tasapisi	doc_491521502287_item	3668601	et	3	main
hakkas	doc_491521502287_item	3668600	et	3	main
eesriie	doc_491521502287_item	3668599	et	3	main
raudne	doc_491521502287_item	3668598	et	3	main
riikigeda	doc_491521502287_item	3668597	et	4	main
taastamine	doc_491521502287_item	3668595	et	4	main
toiduainete	doc_491521502287_item	3668544	et	3	main
nsvl-halb	doc_491521502287_item	3668540	et	3	main
oli	doc_491521502287_item	3668539	et	3	main
tuli	doc_491521502287_item	3668538	et	4	main
võimule	doc_491521502287_item	3668537	et	3	main
gorbatšov	doc_491521502287_item	3668536	et	2	main
kui	doc_491521502287_item	3668535	et	3	main
süsteemi	doc_491521502287_item	3668525	et	4	main
koos	doc_491521502287_item	3668523	et	4	main
omanikele	doc_491521502287_item	3668517	et	3	main
sai	doc_491521502287_item	3668504	et	4	main
hiljem	doc_491521502287_item	3668503	et	3	main
kelam	doc_491521502287_item	3668502	et	4	main
t	doc_491521502287_item	3668501	et	4	main
andis	doc_491521502287_item	3668482	et	3	main
on	doc_491521502283_item	3668126	et	4	main
uuendamine	doc_491521502283_item	3668125	et	4	main
kuid	doc_491521502285_item	3668392	et	4	main
ehitama	doc_491521502285_item	3668385	et	4	main
ja	doc_491521502285_item	3668384	et	3	main
pidi	doc_491521502285_item	3668369	et	4	main
mis	doc_491521502285_item	3668368	et	4	main
programm	doc_491521502285_item	3668367	et	3	main
leebemaks	doc_491521502285_item	3668361	et	4	main
kaoma	doc_491521502285_item	3668353	et	4	main
üldse	doc_491521502285_item	3668352	et	3	main
ja	doc_491521502285_item	3668346	et	3	main
võib	doc_491521502285_item	3668343	et	3	main
glasnost	doc_491521502285_item	3668338	et	4	main
2	doc_491521502285_item	3668331	et	2	main
otsustavam	doc_491521502285_item	3668330	et	4	main
ja	doc_491521502285_item	3668329	et	3	main
suurem	doc_491521502285_item	3668328	et	4	main
et	doc_491521502285_item	3668321	et	3	main
arvan	doc_491521502285_item	3668320	et	3	main
mina	doc_491521502285_item	3668319	et	4	main
siis	doc_491521502285_item	3668318	et	3	main
nii	doc_491521502285_item	3668317	et	3	main
rääkida	doc_491521502285_item	3668316	et	3	main
millest	doc_491521502285_item	3668315	et	3	main
teadma	doc_491521502285_item	3668314	et	3	main
pavad	doc_491521502285_item	3668313	et	4	main
inimesed	doc_491521502285_item	3668312	et	3	main
need	doc_491521502285_item	3668311	et	3	main
ja	doc_491521502285_item	3668310	et	3	main
astmel	doc_491521502285_item	3668309	et	3	main
poliitilisel	doc_491521502285_item	3668308	et	3	main
kõrgemal	doc_491521502285_item	3668307	et	4	main
kes	doc_491521502285_item	3668305	et	4	main
inimestega	doc_491521502285_item	3668304	et	3	main
seisavad	doc_491521502285_item	3668306	et	3	main
rääkima	doc_491521502285_item	3668303	et	3	main
peavad	doc_491521502285_item	3668302	et	4	main
see	doc_491521502285_item	3668395	et	3	main
näha	doc_491521502285_item	3668394	et	3	main
nagu	doc_491521502285_item	3668393	et	3	main
mis	doc_491521502285_item	3668387	et	4	main
uue	doc_491521502285_item	3668386	et	3	main
vaesusesse	doc_491521502285_item	3668376	et	4	main
elu	doc_491521502285_item	3668370	et	4	main
natuke	doc_491521502285_item	3668360	et	4	main
see	doc_491521502285_item	3668358	et	3	main
arust	doc_491521502285_item	3668356	et	4	main
minu	doc_491521502285_item	3668355	et	3	main
kuid	doc_491521502285_item	3668354	et	4	main
teha	doc_491521502285_item	3668347	et	3	main
kõike	doc_491521502285_item	3668344	et	4	main
nüüd	doc_491521502285_item	3668342	et	4	main
et	doc_491521502285_item	3668341	et	3	main
glasnost	doc_491521502285_item	3668332	et	4	main
rahvarinde	doc_491521502285_item	3668322	et	4	main
üks	doc_491521502285_item	3668298	et	3	main
eest	doc_491521502285_item	3668295	et	4	main
keegi	doc_491521502285_item	3668282	et	4	main
jõuda	doc_491521502285_item	3668277	et	3	main
ei	doc_491521502287_item	3668620	et	4	main
see	doc_491521502287_item	3668619	et	3	main
kuju	doc_491521502287_item	3668618	et	4	main
uue	doc_491521502287_item	3668617	et	3	main
säilib	doc_491521502287_item	3668613	et	3	main
veel	doc_491521502287_item	3668436	et	4	main
telesaates	doc_491521502287_item	3668434	et	3	main
savisaarelt	doc_491521502287_item	3668429	et	3	main
inimesed	doc_491521502287_item	3668423	et	3	main
koondusid	doc_491521502287_item	3668421	et	4	main
massiprganisatsioon	doc_491521502287_item	3668419	et	4	main
g	doc_491521502287_item	3668605	et	4	main
lootis	doc_491521502287_item	3668604	et	3	main
perestroika	doc_491521502287_item	3668559	et	4	main
alustas	doc_491521502287_item	3668557	et	3	main
saa	doc_491521502287_item	3668555	et	4	main
ei	doc_491521502287_item	3668554	et	4	main
minna	doc_491521502287_item	3668553	et	3	main
edasi	doc_491521502287_item	3668552	et	3	main
nii	doc_491521502287_item	3668551	et	3	main
et	doc_491521502287_item	3668550	et	3	main
leidis	doc_491521502287_item	3668549	et	4	main
viis	doc_491521502287_item	3668543	et	4	main
doturimine	doc_491521502287_item	3668542	et	4	main
vastu	doc_491521502287_item	3668526	et	3	main
vara	doc_491521502287_item	3668518	et	4	main
eelarve	doc_491521502287_item	3668514	et	4	main
kes	doc_491521502287_item	3668510	et	4	main
peaminister	doc_491521502287_item	3668509	et	3	main
eesti	doc_491521502287_item	3668508	et	4	main
laulev	doc_491521502287_item	3668493	et	4	main
põhilise	doc_491521502287_item	3668483	et	3	main
peatataks	doc_491521502287_item	3668480	et	4	main
lammutamine	doc_491521502287_item	3668479	et	4	main
nsvl	doc_491521502287_item	3668478	et	4	main
et	doc_491521502287_item	3668477	et	3	main
mis	doc_491521502287_item	3668452	et	4	main
savisaar	doc_491521502287_item	3668451	et	3	main
ime	doc_491521502287_item	3668445	et	4	main
valitud	doc_491521502285_item	3668300	et	4	main
peab	doc_491521502285_item	3668286	et	4	main
ei	doc_491521502285_item	3668280	et	4	main
kaugele	doc_491521502285_item	3668276	et	4	main
saa	doc_491521502285_item	3668275	et	4	main
ei	doc_491521502285_item	3668274	et	4	main
rahvas	doc_491521502285_item	3668273	et	4	main
osa	doc_491521502285_item	3668271	et	4	main
kuid	doc_491521502285_item	3668272	et	4	main
surt	doc_491521502285_item	3668270	et	4	main
isesesvumisprotsessis	doc_491521502285_item	3668269	et	4	main
mängis	doc_491521502285_item	3668268	et	3	main
rahvas	doc_491521502285_item	3668267	et	4	main
eesti	doc_491521502285_item	3668266	et	4	main
ka	doc_491521502285_item	3668265	et	3	main
muidugi	doc_491521502285_item	3668264	et	4	main
otsustav	doc_491521502285_item	3668263	et	4	main
isegi	doc_491521502285_item	3668262	et	4	main
võib-olla	doc_491521502285_item	3668261	et	3	main
oluline	doc_491521502285_item	3668260	et	4	main
väga	doc_491521502285_item	3668259	et	3	main
väga	doc_491521502285_item	3668258	et	3	main
roll	doc_491521502285_item	3668257	et	3	main
rahvarinde	doc_491521502285_item	3668256	et	4	main
on	doc_491521502285_item	3668255	et	4	main
arvates	doc_491521502285_item	3668254	et	4	main
minu	doc_491521502285_item	3668253	et	3	main
1	doc_491521502285_item	3668252	et	2	main
perestroika	doc_491521502285_item	3668251	et	4	main
ja	doc_491521502285_item	3668250	et	3	main
glasnost	doc_491521502285_item	3668249	et	4	main
mõisted	doc_491521502285_item	3668248	et	3	main
tähendavad	doc_491521502285_item	3668247	et	4	main
mida	doc_491521502285_item	3668246	et	4	main
2	doc_491521502285_item	3668245	et	2	main
taasiseseivumisprotsessis	doc_491521502285_item	3668244	et	4	main
eesti	doc_491521502285_item	3668243	et	4	main
roll	doc_491521502285_item	3668242	et	3	main
rahvarinde	doc_491521502285_item	3668241	et	4	main
1	doc_491521502285_item	3668240	et	2	main
kontrolltöö	doc_491521502285_item	3668239	et	4	main
et	doc_491521502287_item	3668611	et	3	main
luulsas	doc_491521502287_item	3668433	et	4	main
tuli	doc_491521502287_item	3668427	et	4	main
nsvl	doc_491521502287_item	3668624	et	4	main
lihtsalt	doc_491521502287_item	3668616	et	4	main
võtab	doc_491521502287_item	3668615	et	3	main
see	doc_491521502287_item	3668614	et	3	main
selle	doc_491521502287_item	3668432	et	4	main
idee	doc_491521502287_item	3668424	et	4	main
glasnost	doc_491521502287_item	3668413	et	4	main
mõisted	doc_491521502287_item	3668412	et	3	main
tähendavad	doc_491521502287_item	3668411	et	4	main
mida	doc_491521502287_item	3668410	et	4	main
2	doc_491521502287_item	3668409	et	2	main
kutmist	doc_491521502287_item	3668607	et	4	main
hulka	doc_491521502287_item	3668591	et	4	main
poliitika	doc_491521502287_item	3668590	et	4	main
uue	doc_491521502287_item	3668589	et	3	main
g	doc_491521502287_item	3668588	et	4	main
adekolonnid	doc_491521502287_item	3668587	et	4	main
odavad	doc_491521502287_item	3668586	et	3	main
annoll	doc_491521502287_item	3668585	et	4	main
olmekuviin	doc_491521502287_item	3668584	et	4	main
piiritust	doc_491521502287_item	3668583	et	4	main
sisaldas	doc_491521502287_item	3668582	et	3	main
mis	doc_491521502287_item	3668581	et	4	main
kõike	doc_491521502287_item	3668580	et	4	main
jooma	doc_491521502287_item	3668579	et	4	main
hakati	doc_491521502287_item	3668578	et	3	main
saanud	doc_491521502287_item	3668577	et	4	main
ei	doc_491521502287_item	3668576	et	4	main
enam	doc_491521502287_item	3668575	et	4	main
viina	doc_491521502287_item	3668574	et	4	main
sest	doc_491521502287_item	3668573	et	4	main
olukorda	doc_491521502287_item	3668572	et	4	main
halvendas	doc_491521502287_item	3668571	et	3	main
tegelikult	doc_491521502287_item	3668570	et	4	main
mis	doc_491521502287_item	3668569	et	4	main
alkoholipoliitika	doc_491521502287_item	3668568	et	4	main
rangem	doc_491521502287_item	3668567	et	4	main
senisest	doc_491521502287_item	3668566	et	3	main
nutmine	doc_491521502287_item	3668565	et	4	main
kui	doc_491521502287_item	3668564	et	3	main
tõlgiti	doc_491521502287_item	3668563	et	3	main
keelde	doc_491521502287_item	3668562	et	4	main
eesti	doc_491521502287_item	3668561	et	4	main
ümberehitamine	doc_491521502287_item	3668560	et	3	main
perestroika	doc_491521502287_item	3668415	et	4	main
ja	doc_491521502287_item	3668414	et	3	main
taasiseseivumisprotsessis	doc_491521502287_item	3668408	et	4	main
eesti	doc_491521502287_item	3668407	et	4	main
roll	doc_491521502287_item	3668406	et	3	main
oma	doc_491521502287_item	3668606	et	4	main
lääne	doc_491521502287_item	3668596	et	4	main
suhete	doc_491521502287_item	3668594	et	3	main
ka	doc_491521502287_item	3668593	et	3	main
kuulus	doc_491521502287_item	3668592	et	4	main
reforme	doc_491521502287_item	3668558	et	3	main
ja	doc_491521502287_item	3668556	et	3	main
ja	doc_491521502287_item	3668545	et	3	main
pidev	doc_491521502287_item	3668541	et	3	main
2	doc_491521502287_item	3668534	et	2	main
sini-must-valge	doc_491521502287_item	3668533	et	4	main
välja	doc_491521502287_item	3668532	et	4	main
tekitas	doc_491521502287_item	3668521	et	3	main
rr	doc_491521502287_item	3668520	et	4	main
õigusjärgsetele	doc_491521502287_item	3668516	et	3	main
ja	doc_491521502287_item	3668515	et	3	main
iseseisev	doc_491521502287_item	3668513	et	3	main
alustas	doc_491521502287_item	3668511	et	3	main
toetusele	doc_491521502287_item	3668492	et	4	main
suurele	doc_491521502287_item	3668491	et	4	main
rahva	doc_491521502287_item	3668490	et	3	main
nõudsid	doc_491521502287_item	3668476	et	4	main
venelased	doc_491521502287_item	3668475	et	3	main
loodi	doc_491521502287_item	3668458	et	4	main
nsvl-st	doc_491521502287_item	3668456	et	3	main
autonoomiat	doc_491521502287_item	3668455	et	3	main
majanduslikku	doc_491521502287_item	3668454	et	4	main
taotlse	doc_491521502287_item	3668453	et	4	main
made	doc_491521502287_item	3668448	et	3	main
isemajandav	doc_491521502287_item	3668446	et	3	main
hiljem	doc_491521502287_item	3668439	et	3	main
teised	doc_491521502307_item	3668778	et	4	main
liidu	doc_491521502307_item	3668773	et	3	main
kuulusid	doc_491521502307_item	3668771	et	4	main
eesti	doc_491521502307_item	3668769	et	4	main
kaksteist	doc_491521502307_item	3668768	et	4	main
paljud	doc_491521502307_item	3668756	et	3	main
alasid	doc_491521502307_item	3668754	et	4	main
baltimaade	doc_491521502307_item	3668737	et	3	main
ühendus	doc_491521502307_item	3668736	et	4	main
liit	doc_491521502307_item	3668733	et	3	main
hansa	doc_491521502307_item	3668732	et	4	main
2	doc_491521502307_item	3668731	et	2	main
saanud	doc_491521502307_item	3668701	et	4	main
talurahvast	doc_491521502307_item	3668695	et	4	main
samuti	doc_491521502307_item	3668689	et	3	main
tegevuse	doc_491521502307_item	3668687	et	4	main
nad	doc_491521502307_item	3668676	et	3	main
paikne	doc_491521502307_item	3668673	et	4	main
suur	doc_491521502307_item	3668666	et	3	main
juhti	doc_491521502287_item	3668524	et	4	main
ühtustunde	doc_491521502287_item	3668522	et	4	main
tagastamine	doc_491521502287_item	3668519	et	4	main
reforme	doc_491521502287_item	3668512	et	3	main
savisaarest	doc_491521502287_item	3668505	et	4	main
parraleelselt	doc_491521502287_item	3668496	et	4	main
rr-ga	doc_491521502287_item	3668495	et	3	main
revolutsioon	doc_491521502287_item	3668494	et	3	main
taasiseseivumises	doc_491521502287_item	3668485	et	4	main
tõkke	doc_491521502287_item	3668484	et	3	main
neist	doc_491521502287_item	3668474	et	4	main
enamik	doc_491521502287_item	3668473	et	3	main
töölised	doc_491521502287_item	3668472	et	3	main
lihtrahvas	doc_491521502287_item	3668471	et	4	main
kuulusid	doc_491521502287_item	3668470	et	4	main
kuhu	doc_491521502287_item	3668469	et	3	main
ühendus	doc_491521502287_item	3668468	et	4	main
moodustatud	doc_491521502287_item	3668467	et	4	main
vanameelsete	doc_491521502287_item	3668466	et	3	main
interrindega	doc_491521502287_item	3668465	et	3	main
vastasseis	doc_491521502287_item	3668464	et	3	main
i	doc_491521502287_item	3668463	et	4	main
rr-	doc_491521502287_item	3668462	et	4	main
gorbatšovi	doc_491521502287_item	3668461	et	2	main
toetada	doc_491521502287_item	3668460	et	3	main
et	doc_491521502287_item	3668459	et	3	main
rr	doc_491521502287_item	3668457	et	4	main
sai	doc_491521502287_item	3668438	et	4	main
tallinn	doc_491521502307_item	3668774	et	4	main
korraldas	doc_491521502307_item	3668765	et	3	main
tekkisid	doc_491521502307_item	3668758	et	4	main
ja	doc_491521502307_item	3668749	et	3	main
osaliselt	doc_491521502307_item	3668741	et	4	main
algas	doc_491521502307_item	3668740	et	3	main
uuele	doc_491521502307_item	3668722	et	3	main
harjuda	doc_491521502307_item	3668721	et	3	main
et	doc_491521502307_item	3668720	et	3	main
vaja	doc_491521502307_item	3668718	et	4	main
oli	doc_491521502307_item	3668717	et	3	main
talupoegadele	doc_491521502307_item	3668716	et	3	main
kirjandust	doc_491521502307_item	3668715	et	3	main
aru	doc_491521502307_item	3668703	et	4	main
ristima	doc_491521502307_item	3668694	et	4	main
tulid	doc_491521502307_item	3668693	et	4	main
iseloomust	doc_491521502307_item	3668688	et	4	main
põllumajandusliku	doc_491521502307_item	3668686	et	3	main
veel	doc_491521502307_item	3668685	et	4	main
tulenes	doc_491521502307_item	3668684	et	3	main
traditsioonilisus	doc_491521502307_item	3668683	et	4	main
see	doc_491521502307_item	3668682	et	3	main
toodi	doc_491521502287_item	3668531	et	4	main
miitinguid	doc_491521502287_item	3668530	et	3	main
rahvakogunemisi	doc_491521502287_item	3668529	et	3	main
korraldati	doc_491521502287_item	3668528	et	3	main
astuda	doc_491521502287_item	3668527	et	3	main
taasiseseisvunud	doc_491521502287_item	3668507	et	4	main
esimene	doc_491521502287_item	3668506	et	3	main
komitee	doc_491521502287_item	3668500	et	4	main
kodanike	doc_491521502287_item	3668499	et	3	main
ka	doc_491521502287_item	3668498	et	3	main
tegutses	doc_491521502287_item	3668497	et	3	main
tänu	doc_491521502287_item	3668489	et	4	main
võimsaks	doc_491521502287_item	3668488	et	3	main
nii	doc_491521502287_item	3668487	et	3	main
kujunes	doc_491521502287_item	3668486	et	3	main
rr	doc_491521502287_item	3668481	et	4	main
titme	doc_491521502287_item	3668449	et	4	main
eesti	doc_491521502287_item	3668447	et	4	main
välja	doc_491521502287_item	3668444	et	4	main
pakuti	doc_491521502287_item	3668443	et	3	main
esialgu	doc_491521502287_item	3668442	et	3	main
juht	doc_491521502287_item	3668441	et	3	main
pr-i	doc_491521502287_item	3668440	et	4	main
narva	doc_491521502307_item	3668776	et	4	main
hansa	doc_491521502307_item	3668772	et	4	main
linnad	doc_491521502307_item	3668770	et	3	main
hansakaupmeeste	doc_491521502307_item	3668759	et	4	main
nende	doc_491521502307_item	3668750	et	4	main
hansakaupmeestele	doc_491521502307_item	3668743	et	4	main
rahvaste	doc_491521502307_item	3668738	et	4	main
kaupmeeste	doc_491521502307_item	3668735	et	4	main
oli	doc_491521502307_item	3668734	et	3	main
jaoks	doc_491521502307_item	3668728	et	4	main
nende	doc_491521502307_item	3668727	et	4	main
emakeele	doc_491521502307_item	3668714	et	4	main
olnud	doc_491521502307_item	3668713	et	4	main
pärast	doc_491521502307_item	3668706	et	4	main
ei	doc_491521502307_item	3668700	et	4	main
talupojad	doc_491521502307_item	3668699	et	4	main
kohakeelt	doc_491521502307_item	3668698	et	4	main
linnades	doc_491521502307_item	3668681	et	3	main
talurahva	doc_491521502307_item	3668670	et	3	main
vahel	doc_491521502307_item	3668664	et	4	main
eesti	doc_491521502312_item	3668879	et	4	main
oli	doc_491521502312_item	3668877	et	3	main
see	doc_491521502312_item	3668871	et	3	main
ilmus	doc_491521502312_item	3668870	et	4	main
aastal	doc_491521502312_item	3668869	et	3	main
sajandil	doc_491521502312_item	3668867	et	3	main
keeles	doc_491521502312_item	3668865	et	4	main
ladina	doc_491521502312_item	3668864	et	4	main
liivimaa	doc_491521502312_item	3668862	et	4	main
1208	doc_491521502312_item	3668843	et	2	main
ta	doc_491521502312_item	3668839	et	4	main
ja	doc_491521502312_item	3668824	et	3	main
henrik	doc_491521502312_item	3668821	et	4	main
a	doc_491521502312_item	3668811	et	4	main
1224-1227	doc_491521502312_item	3668810	et	2	main
eestimaa	doc_491521502312_item	3668800	et	4	main
jutustab	doc_491521502312_item	3668799	et	3	main
vaidlemata	doc_491521502312_item	3668794	et	4	main
1	doc_491521502312_item	3668793	et	2	main
teoorjus	doc_491521502312_item	3668792	et	3	main
tähendab	doc_491521502312_item	3668791	et	3	main
mida	doc_491521502312_item	3668790	et	4	main
meile	doc_491521502312_item	3668786	et	4	main
kirjalikud	doc_491521502312_item	3668783	et	3	main
kuid	doc_491521502312_item	3668986	et	4	main
mõisale	doc_491521502312_item	3668979	et	3	main
mõisamajandus	doc_491521502312_item	3668976	et	3	main
teoorjuslik	doc_491521502312_item	3668975	et	3	main
ajal	doc_491521502312_item	3668972	et	4	main
rootsi	doc_491521502312_item	3668971	et	4	main
teoorjus	doc_491521502312_item	3668970	et	3	main
2	doc_491521502312_item	3668969	et	2	main
keeles	doc_491521502312_item	3668961	et	4	main
kelli	doc_491521502312_item	3668958	et	4	main
eestimaa	doc_491521502312_item	3668931	et	4	main
visitatsiooni	doc_491521502312_item	3668926	et	4	main
tähtis	doc_491521502312_item	3668923	et	4	main
samuti	doc_491521502312_item	3668921	et	3	main
kallas	doc_491521502287_item	3668450	et	4	main
savisaarest	doc_491521502287_item	3668437	et	4	main
tartu	doc_491521502307_item	3668775	et	4	main
konkurentsi	doc_491521502307_item	3668764	et	4	main
kontrollis	doc_491521502307_item	3668763	et	4	main
liit	doc_491521502307_item	3668762	et	3	main
hansa	doc_491521502307_item	3668761	et	4	main
initsiatiivil	doc_491521502307_item	3668760	et	3	main
linnad	doc_491521502307_item	3668757	et	3	main
paganate	doc_491521502307_item	3668753	et	3	main
tee	doc_491521502307_item	3668751	et	4	main
šokk	doc_491521502307_item	3668730	et	2	main
poleks	doc_491521502307_item	3668726	et	3	main
see	doc_491521502307_item	3668725	et	3	main
sest	doc_491521502307_item	3668724	et	4	main
ei	doc_491521502307_item	3668712	et	4	main
samuti	doc_491521502307_item	3668711	et	3	main
kohakeeles	doc_491521502307_item	3668710	et	4	main
kirikureformatsiooni	doc_491521502307_item	3668705	et	4	main
ainult	doc_491521502307_item	3668704	et	4	main
jumalasõnast	doc_491521502307_item	3668702	et	4	main
osanud	doc_491521502307_item	3668697	et	4	main
mis	doc_491521502307_item	3668692	et	4	main
piiskopid	doc_491521502307_item	3668691	et	3	main
toimus	doc_491521502307_item	3668680	et	3	main
teadnud	doc_491521502307_item	3668678	et	4	main
siis	doc_491521502307_item	3668674	et	3	main
oli	doc_491521502307_item	3668672	et	3	main
ja	doc_491521502307_item	3668668	et	3	main
külade	doc_491521502307_item	3668663	et	3	main
keeles	doc_491521502312_item	3668874	et	4	main
eesti	doc_491521502312_item	3668873	et	4	main
juba	doc_491521502312_item	3668872	et	3	main
esimest	doc_491521502312_item	3668859	et	4	main
eesti	doc_491521502312_item	3668856	et	4	main
misionääriks	doc_491521502312_item	3668841	et	4	main
aastal	doc_491521502312_item	3668838	et	3	main
magdeburgis	doc_491521502312_item	3668829	et	4	main
aastal	doc_491521502312_item	3668828	et	3	main
lettus	doc_491521502312_item	3668823	et	4	main
de	doc_491521502312_item	3668822	et	4	main
ennast	doc_491521502312_item	3668816	et	4	main
nimetas	doc_491521502312_item	3668815	et	3	main
henrik	doc_491521502312_item	3668814	et	4	main
kroonik	doc_491521502312_item	3668813	et	3	main
balti	doc_491521502312_item	3668812	et	3	main
kroonika	doc_491521502312_item	3668805	et	4	main
on	doc_491521502312_item	3668802	et	4	main
keskajast	doc_491521502312_item	3668801	et	4	main
allikad	doc_491521502312_item	3668784	et	3	main
kontrolltöö	doc_491521502312_item	3668780	et	4	main
pärisorjus	doc_491521502312_item	3668991	et	3	main
olnud	doc_491521502312_item	3668989	et	4	main
liiklusvabadus	doc_491521502312_item	3668983	et	4	main
nende	doc_491521502312_item	3668982	et	4	main
tegema	doc_491521502312_item	3668981	et	3	main
jumalasõna	doc_491521502312_item	3668966	et	4	main
kuid	doc_491521502312_item	3668962	et	4	main
russov	doc_491521502312_item	3668942	et	4	main
keskajast	doc_491521502312_item	3668938	et	4	main
jne	doc_491521502312_item	3668937	et	4	main
laulud	doc_491521502312_item	3668936	et	3	main
rahva	doc_491521502312_item	3668935	et	3	main
esimesed	doc_491521502312_item	3668934	et	3	main
kommed	doc_491521502312_item	3668933	et	4	main
rahva	doc_491521502312_item	3668932	et	3	main
protokollides	doc_491521502312_item	3668927	et	4	main
oma	doc_491521502312_item	3668914	et	4	main
ei	doc_491521502312_item	3668911	et	4	main
baltimaade	doc_491521502312_item	3668898	et	3	main
iga	doc_491521502312_item	3668895	et	4	main
ja	doc_491521502307_item	3668777	et	3	main
keskajal	doc_491521502307_item	3668767	et	3	main
tootmist	doc_491521502307_item	3668766	et	4	main
samuti	doc_491521502307_item	3668755	et	3	main
läbis	doc_491521502307_item	3668752	et	3	main
läänemerele	doc_491521502307_item	3668748	et	3	main
väljapääsu	doc_491521502307_item	3668747	et	4	main
said	doc_491521502307_item	3668746	et	4	main
nad	doc_491521502307_item	3668745	et	3	main
sest	doc_491521502307_item	3668744	et	4	main
tänu	doc_491521502307_item	3668742	et	4	main
ristiusustamine	doc_491521502307_item	3668739	et	3	main
kultuurne	doc_491521502307_item	3668729	et	3	main
eluviisile	doc_491521502307_item	3668723	et	3	main
aega	doc_491521502307_item	3668719	et	4	main
pidama	doc_491521502307_item	3668709	et	4	main
jumalateenistust	doc_491521502307_item	3668708	et	3	main
hakati	doc_491521502307_item	3668707	et	3	main
ei	doc_491521502307_item	3668696	et	4	main
mõned	doc_491521502307_item	3668690	et	3	main
mida	doc_491521502307_item	3668679	et	4	main
ei	doc_491521502307_item	3668677	et	4	main
tihti	doc_491521502307_item	3668675	et	3	main
kui	doc_491521502307_item	3668669	et	3	main
erinevus	doc_491521502307_item	3668667	et	4	main
oli	doc_491521502307_item	3668665	et	3	main
ja	doc_491521502307_item	3668662	et	3	main
pandud	doc_491521502312_item	3668878	et	4	main
korda	doc_491521502312_item	3668860	et	4	main
leedu	doc_491521502312_item	3668858	et	4	main
liivimaale	doc_491521502312_item	3668842	et	4	main
1205	doc_491521502312_item	3668837	et	2	main
lubecki	doc_491521502312_item	3668835	et	4	main
kloostrikoolis	doc_491521502312_item	3668834	et	4	main
hariduse	doc_491521502312_item	3668833	et	3	main
sündis	doc_491521502312_item	3668825	et	3	main
lätimaalt	doc_491521502312_item	3668818	et	3	main
kirjutatud	doc_491521502312_item	3668809	et	4	main
arvatavasti	doc_491521502312_item	3668807	et	3	main
mis	doc_491521502312_item	3668798	et	4	main
piiratud	doc_491521502312_item	3668985	et	4	main
oli	doc_491521502312_item	3668984	et	3	main
pidid	doc_491521502312_item	3668978	et	4	main
oli	doc_491521502312_item	3668973	et	3	main
oli	doc_491521502312_item	3668964	et	3	main
põhja-eesti	doc_491521502312_item	3668960	et	4	main
wandradt	doc_491521502312_item	3668957	et	4	main
ilmus	doc_491521502312_item	3668956	et	4	main
baltazar	doc_491521502312_item	3668941	et	4	main
ka	doc_491521502312_item	3668940	et	3	main
kirjeldatud	doc_491521502312_item	3668929	et	4	main
väga	doc_491521502312_item	3668922	et	3	main
on	doc_491521502312_item	3668920	et	4	main
pööraks	doc_491521502312_item	3668912	et	4	main
eestlased	doc_491521502312_item	3668910	et	3	main
protokollid	doc_491521502312_item	3668906	et	4	main
keskajal	doc_491521502312_item	3668901	et	3	main
tõlhitud	doc_491521502312_item	3668888	et	4	main
kroonika	doc_491521502312_item	3668887	et	4	main
nii	doc_491521502314_item	3669140	et	3	main
iga	doc_491521502314_item	3669135	et	4	main
ta	doc_491521502314_item	3669133	et	4	main
talupoeg	doc_491521502314_item	3669130	et	3	main
kui	doc_491521502314_item	3669129	et	3	main
siis	doc_491521502314_item	3669128	et	3	main
liikuda	doc_491521502314_item	3669127	et	3	main
maksma	doc_491521502314_item	3669120	et	3	main
pidid	doc_491521502314_item	3669118	et	4	main
talupojad	doc_491521502314_item	3669117	et	4	main
teoorjus	doc_491521502314_item	3669107	et	3	main
ja	doc_491521502314_item	3669104	et	3	main
meile	doc_491521502314_item	3669100	et	4	main
visitatsioonid	doc_491521502314_item	3669097	et	3	main
ja	doc_491521502314_item	3669094	et	3	main
välja	doc_491521502314_item	3669090	et	4	main
mida	doc_491521502314_item	3669088	et	4	main
katekismus	doc_491521502314_item	3669087	et	3	main
usu	doc_491521502314_item	3669086	et	4	main
luteri	doc_491521502314_item	3669085	et	3	main
keelne	doc_491521502314_item	3669084	et	3	main
teada	doc_491521502314_item	3669080	et	3	main
meile	doc_491521502314_item	3669079	et	4	main
annab	doc_491521502314_item	3669078	et	3	main
määral	doc_491521502314_item	3669077	et	3	main
mingil	doc_491521502314_item	3669076	et	4	main
kohta	doc_491521502314_item	3669075	et	4	main
peamiselt	doc_491521502314_item	3669072	et	4	main
kirjutab	doc_491521502314_item	3669071	et	3	main
annab	doc_491521502314_item	3669065	et	3	main
teda	doc_491521502314_item	3669043	et	4	main
aastal	doc_491521502314_item	3669026	et	3	main
siin	doc_491521502314_item	3669019	et	4	main
eluviis	doc_491521502307_item	3668671	et	3	main
linnade	doc_491521502307_item	3668661	et	3	main
kõigepealt	doc_491521502307_item	3668660	et	3	main
põhjusi	doc_491521502307_item	3668659	et	3	main
mitu	doc_491521502307_item	3668658	et	4	main
oli	doc_491521502307_item	3668657	et	3	main
selleks	doc_491521502307_item	3668656	et	4	main
säilijaks	doc_491521502307_item	3668655	et	4	main
kommete	doc_491521502307_item	3668654	et	4	main
ja	doc_491521502307_item	3668653	et	3	main
keele	doc_491521502307_item	3668652	et	4	main
kultuuri	doc_491521502307_item	3668651	et	4	main
traditsioonilise	doc_491521502307_item	3668650	et	4	main
ajaks	doc_491521502307_item	3668649	et	4	main
pikaks	doc_491521502307_item	3668648	et	4	main
jäi	doc_491521502307_item	3668647	et	3	main
talurahvas	doc_491521502307_item	3668646	et	4	main
keskusteks	doc_491521502307_item	3668645	et	4	main
kultuuri	doc_491521502307_item	3668644	et	4	main
olid	doc_491521502307_item	3668643	et	4	main
linnad	doc_491521502307_item	3668642	et	3	main
kui	doc_491521502307_item	3668641	et	3	main
1	doc_491521502307_item	3668640	et	2	main
liit	doc_491521502307_item	3668639	et	3	main
hansa	doc_491521502307_item	3668638	et	4	main
oli	doc_491521502307_item	3668637	et	3	main
mis	doc_491521502307_item	3668636	et	4	main
2	doc_491521502307_item	3668635	et	2	main
juures	doc_491521502307_item	3668634	et	4	main
eestlaste	doc_491521502307_item	3668633	et	4	main
säilimist	doc_491521502307_item	3668632	et	4	main
muinasusundi	doc_491521502307_item	3668631	et	3	main
soodustas	doc_491521502307_item	3668630	et	3	main
mis	doc_491521502307_item	3668629	et	4	main
1	doc_491521502307_item	3668628	et	2	main
kontrolltöö	doc_491521502307_item	3668627	et	4	main
korda	doc_491521502312_item	3668876	et	4	main
esimest	doc_491521502312_item	3668875	et	4	main
1881	doc_491521502312_item	3668868	et	2	main
18	doc_491521502312_item	3668866	et	2	main
ilmus	doc_491521502312_item	3668861	et	4	main
ja	doc_491521502312_item	3668857	et	3	main
läti	doc_491521502312_item	3668855	et	4	main
keeli	doc_491521502312_item	3668854	et	4	main
preester	doc_491521502312_item	3668847	et	4	main
sai	doc_491521502312_item	3668846	et	4	main
kroonika	doc_491521502312_item	3668863	et	4	main
kohalike	doc_491521502312_item	3668853	et	4	main
hästi	doc_491521502312_item	3668852	et	3	main
väga	doc_491521502312_item	3668851	et	3	main
henrik	doc_491521502312_item	3668850	et	4	main
ilmselt	doc_491521502312_item	3668848	et	4	main
oskas	doc_491521502312_item	3668849	et	3	main
temast	doc_491521502312_item	3668845	et	3	main
tuli	doc_491521502312_item	3668840	et	4	main
lähedal	doc_491521502312_item	3668836	et	4	main
ning	doc_491521502312_item	3668830	et	3	main
1185	doc_491521502312_item	3668827	et	2	main
umbes	doc_491521502312_item	3668826	et	4	main
henrikuks	doc_491521502312_item	3668817	et	4	main
oli	doc_491521502312_item	3668808	et	3	main
liivimaa	doc_491521502312_item	3668804	et	4	main
allikas	doc_491521502312_item	3668797	et	4	main
2	doc_491521502312_item	3668789	et	2	main
keskajast	doc_491521502312_item	3668788	et	4	main
jutustavad	doc_491521502312_item	3668785	et	4	main
millised	doc_491521502312_item	3668782	et	3	main
a	doc_491521502312_item	3668844	et	4	main
oma	doc_491521502312_item	3668832	et	4	main
sai	doc_491521502312_item	3668831	et	4	main
keeles	doc_491521502312_item	3668820	et	4	main
lad	doc_491521502312_item	3668819	et	4	main
mis	doc_491521502312_item	3668806	et	4	main
henriku	doc_491521502312_item	3668803	et	4	main
olulisem	doc_491521502312_item	3668796	et	4	main
kõige	doc_491521502312_item	3668795	et	4	main
eestimaa	doc_491521502312_item	3668787	et	4	main
1	doc_491521502312_item	3668781	et	2	main
ei	doc_491521502312_item	3668988	et	4	main
teorjus	doc_491521502312_item	3668987	et	4	main
tööd	doc_491521502312_item	3668980	et	4	main
talupojad	doc_491521502312_item	3668977	et	4	main
iseloomulik	doc_491521502312_item	3668974	et	3	main
pigem	doc_491521502312_item	3668965	et	3	main
see	doc_491521502312_item	3668963	et	3	main
katekismus	doc_491521502312_item	3668959	et	3	main
on	doc_491521502312_item	3668952	et	4	main
autotiks	doc_491521502312_item	3668951	et	3	main
mille	doc_491521502312_item	3668950	et	3	main
grammatikast	doc_491521502312_item	3668949	et	4	main
saxo	doc_491521502312_item	3668948	et	4	main
ka	doc_491521502312_item	3668947	et	3	main
leida	doc_491521502312_item	3668946	et	3	main
võib	doc_491521502312_item	3668945	et	3	main
informatsiooni	doc_491521502312_item	3668944	et	4	main
põnevat	doc_491521502312_item	3668943	et	3	main
kirjutas	doc_491521502312_item	3668939	et	3	main
näiteks	doc_491521502312_item	3668930	et	4	main
allikas	doc_491521502312_item	3668925	et	4	main
tagasi	doc_491521502312_item	3668913	et	3	main
et	doc_491521502312_item	3668909	et	3	main
visitatsiooni	doc_491521502312_item	3668905	et	4	main
nn	doc_491521502312_item	3668904	et	4	main
koostama	doc_491521502312_item	3668903	et	3	main
hakati	doc_491521502312_item	3668902	et	3	main
tutvustada	doc_491521502312_item	3668897	et	3	main
maailma	doc_491521502312_item	3668890	et	4	main
eesnimesid	doc_491521502312_item	3668883	et	3	main
mõisanikumaal	doc_491521502314_item	3669145	et	4	main
kui	doc_491521502314_item	3669143	et	3	main
talupojad	doc_491521502314_item	3669138	et	4	main
karistuse	doc_491521502314_item	3669134	et	4	main
saab	doc_491521502314_item	3669132	et	3	main
olnud	doc_491521502314_item	3669114	et	4	main
rahva	doc_491521502314_item	3669102	et	3	main
koell	doc_491521502314_item	3669096	et	4	main
s	doc_491521502314_item	3669092	et	4	main
keskajast	doc_491521502314_item	3669082	et	4	main
olukorra	doc_491521502314_item	3669074	et	3	main
talupoegade	doc_491521502314_item	3669073	et	3	main
ülevaade	doc_491521502314_item	3669064	et	3	main
veel	doc_491521502312_item	3668990	et	4	main
infoallikas	doc_491521502312_item	3668968	et	4	main
kui	doc_491521502312_item	3668967	et	3	main
a	doc_491521502312_item	3668955	et	4	main
1535	doc_491521502312_item	3668954	et	2	main
taanlane	doc_491521502312_item	3668953	et	3	main
on	doc_491521502312_item	3668928	et	4	main
ajalooline	doc_491521502312_item	3668924	et	4	main
jälgiti	doc_491521502312_item	3668908	et	3	main
ajalooga	doc_491521502312_item	3668900	et	4	main
ühele	doc_491521502312_item	3668896	et	3	main
võimaluse	doc_491521502312_item	3668894	et	3	main
annab	doc_491521502312_item	3668893	et	3	main
mis	doc_491521502312_item	3668892	et	4	main
keeltesse	doc_491521502312_item	3668891	et	3	main
suurematesse	doc_491521502312_item	3668889	et	4	main
tänapäeval	doc_491521502312_item	3668884	et	3	main
ka	doc_491521502314_item	3669144	et	3	main
päev	doc_491521502314_item	3669136	et	3	main
põgeneb	doc_491521502314_item	3669131	et	3	main
tohtinud	doc_491521502314_item	3669126	et	4	main
ei	doc_491521502314_item	3669125	et	4	main
nad	doc_491521502314_item	3669124	et	3	main
ja	doc_491521502314_item	3669123	et	3	main
töötama	doc_491521502314_item	3669122	et	3	main
makse	doc_491521502314_item	3669119	et	4	main
teada	doc_491521502314_item	3669101	et	3	main
annavad	doc_491521502314_item	3669099	et	3	main
j	doc_491521502314_item	3669095	et	4	main
wandradt	doc_491521502314_item	3669093	et	4	main
ta	doc_491521502314_item	3669070	et	4	main
tuntakse	doc_491521502314_item	3669044	et	3	main
ei	doc_491521502314_item	3669040	et	4	main
käsikiri	doc_491521502314_item	3669038	et	3	main
ristiusk	doc_491521502314_item	3669036	et	3	main
ja	doc_491521502314_item	3669035	et	3	main
ladina	doc_491521502314_item	3669027	et	4	main
kirjutatud	doc_491521502314_item	3669023	et	4	main
ema	doc_491521502318_item	3669549	et	4	main
murred	doc_491521502318_item	3669535	et	4	main
kultuur	doc_491521502318_item	3669534	et	3	main
ja	doc_491521502318_item	3669533	et	3	main
maa	doc_491521502318_item	3669521	et	4	main
mis	doc_491521502312_item	3668919	et	4	main
poole	doc_491521502312_item	3668918	et	4	main
tavade	doc_491521502312_item	3668917	et	3	main
paganliku	doc_491521502312_item	3668916	et	3	main
vanade	doc_491521502312_item	3668915	et	3	main
nii	doc_491521502312_item	3668907	et	3	main
keskaja	doc_491521502312_item	3668899	et	3	main
liivimaa	doc_491521502312_item	3668886	et	4	main
omal	doc_491521502314_item	3669141	et	3	main
töötama	doc_491521502314_item	3669139	et	3	main
pidid	doc_491521502314_item	3669137	et	4	main
palju	doc_491521502314_item	3669121	et	4	main
ei	doc_491521502314_item	3669113	et	4	main
talupoegael	doc_491521502314_item	3669112	et	3	main
siinsetel	doc_491521502314_item	3669111	et	4	main
et	doc_491521502314_item	3669110	et	3	main
seda	doc_491521502314_item	3669109	et	3	main
tähendab	doc_491521502314_item	3669108	et	3	main
2	doc_491521502314_item	3669106	et	2	main
tavadest	doc_491521502314_item	3669105	et	3	main
eesti	doc_491521502314_item	3669083	et	4	main
ruussov	doc_491521502314_item	3669069	et	4	main
b	doc_491521502314_item	3669068	et	4	main
kroonik	doc_491521502314_item	3669067	et	3	main
aga	doc_491521502314_item	3669042	et	3	main
jutustab	doc_491521502314_item	3669029	et	3	main
viidi	doc_491521502318_item	3669546	et	4	main
omaette	doc_491521502318_item	3669531	et	3	main
eesti	doc_491521502318_item	3669524	et	4	main
korralduse	doc_491521502318_item	3669523	et	4	main
administratiivse	doc_491521502318_item	3669522	et	3	main
kirik	doc_491521502318_item	3669513	et	3	main
nt	doc_491521502318_item	3669497	et	4	main
kaupmehed	doc_491521502318_item	3669485	et	3	main
koos	doc_491521502318_item	3669483	et	4	main
kohtu	doc_491521502318_item	3669470	et	4	main
linnakodanike	doc_491521502318_item	3669468	et	3	main
aasta	doc_491521502318_item	3669464	et	4	main
toimusid	doc_491521502318_item	3669462	et	4	main
valimised	doc_491521502318_item	3669461	et	4	main
ja	doc_491521502318_item	3669451	et	3	main
seadustega	doc_491521502318_item	3669450	et	3	main
nagu	doc_491521502318_item	3669446	et	3	main
henriku	doc_491521502312_item	3668885	et	4	main
eestlaste	doc_491521502312_item	3668882	et	4	main
ja	doc_491521502312_item	3668881	et	3	main
keelt	doc_491521502312_item	3668880	et	4	main
maal	doc_491521502314_item	3669142	et	4	main
inimõigusi	doc_491521502314_item	3669116	et	4	main
peaaegu	doc_491521502314_item	3669115	et	3	main
kommetest	doc_491521502314_item	3669103	et	4	main
protokollid	doc_491521502314_item	3669098	et	4	main
kirikuõpetajad	doc_491521502314_item	3669091	et	3	main
andsid	doc_491521502314_item	3669089	et	4	main
eestimaa	doc_491521502314_item	3669081	et	4	main
meile	doc_491521502314_item	3669066	et	4	main
hea	doc_491521502314_item	3669063	et	4	main
kohta	doc_491521502314_item	3669062	et	4	main
keskaja	doc_491521502314_item	3669061	et	3	main
veel	doc_491521502314_item	3669060	et	4	main
lahing	doc_491521502314_item	3669059	et	3	main
ümera	doc_491521502314_item	3669058	et	4	main
nagu	doc_491521502314_item	3669057	et	3	main
lahingust	doc_491521502314_item	3669056	et	4	main
tähtsast	doc_491521502314_item	3669055	et	3	main
sellest	doc_491521502314_item	3669054	et	4	main
näiteks	doc_491521502314_item	3669053	et	4	main
kohta	doc_491521502314_item	3669052	et	4	main
lahingute	doc_491521502314_item	3669051	et	4	main
palju	doc_491521502314_item	3669050	et	4	main
kirjutab	doc_491521502314_item	3669049	et	3	main
henrik	doc_491521502314_item	3669048	et	4	main
läti	doc_491521502314_item	3669047	et	4	main
kaudu	doc_491521502314_item	3669046	et	3	main
ole	doc_491521502314_item	3669041	et	4	main
säilinud	doc_491521502314_item	3669039	et	4	main
levis	doc_491521502314_item	3669037	et	4	main
toimusid	doc_491521502314_item	3669034	et	4	main
sõjad	doc_491521502314_item	3669033	et	3	main
kuidas	doc_491521502314_item	3669032	et	3	main
keeles	doc_491521502314_item	3669028	et	4	main
umbes	doc_491521502314_item	3669024	et	4	main
on	doc_491521502314_item	3669022	et	4	main
ta	doc_491521502314_item	3669021	et	4	main
toimus	doc_491521502314_item	3669020	et	3	main
ümberkirjutamise	doc_491521502314_item	3669045	et	3	main
sellest	doc_491521502314_item	3669031	et	4	main
peamiselt	doc_491521502314_item	3669030	et	4	main
1224-12278	doc_491521502314_item	3669025	et	2	main
kõik	doc_491521502314_item	3669018	et	4	main
kuidas	doc_491521502314_item	3669017	et	3	main
sellest	doc_491521502314_item	3669016	et	4	main
ülevaate	doc_491521502314_item	3669015	et	4	main
annab	doc_491521502314_item	3669014	et	3	main
mis	doc_491521502314_item	3669013	et	4	main
teos	doc_491521502314_item	3669012	et	4	main
esimene	doc_491521502314_item	3669011	et	3	main
on	doc_491521502314_item	3669010	et	4	main
kroonika	doc_491521502314_item	3669009	et	4	main
liivimaa	doc_491521502314_item	3669008	et	4	main
henriku	doc_491521502314_item	3669007	et	4	main
1	doc_491521502314_item	3669006	et	2	main
teoorjus	doc_491521502314_item	3669005	et	3	main
tähendab	doc_491521502314_item	3669004	et	3	main
mida	doc_491521502314_item	3669003	et	4	main
2	doc_491521502314_item	3669002	et	2	main
keskajast	doc_491521502314_item	3669001	et	4	main
eestimaa	doc_491521502314_item	3669000	et	4	main
meile	doc_491521502314_item	3668999	et	4	main
jutustavad	doc_491521502314_item	3668998	et	4	main
allikad	doc_491521502314_item	3668997	et	3	main
kirjalikud	doc_491521502314_item	3668996	et	3	main
millised	doc_491521502314_item	3668995	et	3	main
1	doc_491521502314_item	3668994	et	2	main
kontrolltöö	doc_491521502314_item	3668993	et	4	main
jumalateenistus	doc_491521502318_item	3669545	et	3	main
kombed	doc_491521502318_item	3669532	et	3	main
iga	doc_491521502318_item	3669528	et	4	main
jagatud	doc_491521502318_item	3669526	et	4	main
oli	doc_491521502318_item	3669525	et	3	main
võim	doc_491521502318_item	3669517	et	3	main
nadu	doc_491521502318_item	3669515	et	4	main
muidugi	doc_491521502318_item	3669511	et	4	main
olid	doc_491521502318_item	3669496	et	4	main
organiseeritud	doc_491521502318_item	3669492	et	4	main
linna	doc_491521502318_item	3669477	et	4	main
võtta	doc_491521502318_item	3669476	et	3	main
tema	doc_491521502318_item	3669465	et	4	main
kõrgeim	doc_491521502318_item	3669453	et	4	main
oma	doc_491521502318_item	3669449	et	4	main
oli	doc_491521502318_item	3669445	et	3	main
olid	doc_491521502318_item	3669434	et	4	main
selle	doc_491521502318_item	3669433	et	4	main
aga	doc_491521502318_item	3669427	et	3	main
tuhat	doc_491521502318_item	3669425	et	4	main
olid	doc_491521502318_item	3669417	et	4	main
viirumaa	doc_491521502318_item	3669410	et	4	main
saare-lääne	doc_491521502318_item	3669406	et	4	main
rannik	doc_491521502318_item	3669401	et	3	main
ordumeister	doc_491521502318_item	3669400	et	3	main
oli	doc_491521502318_item	3669399	et	3	main
tähtsam	doc_491521502318_item	3669395	et	4	main
kõige	doc_491521502318_item	3669394	et	4	main
ordule	doc_491521502318_item	3669393	et	3	main
läbi	doc_491521502318_item	3669547	et	4	main
ema	doc_491521502318_item	3669543	et	4	main
hakati	doc_491521502318_item	3669541	et	3	main
jumalasõna	doc_491521502318_item	3669540	et	4	main
korruptsiooniga	doc_491521502318_item	3669539	et	3	main
võitlus	doc_491521502318_item	3669538	et	3	main
usupuhastus	doc_491521502318_item	3669537	et	3	main
reformatsioon	doc_491521502318_item	3669536	et	3	main
kihelkonnal	doc_491521502318_item	3669529	et	3	main
võimuesindajad	doc_491521502318_item	3669512	et	3	main
kokku	doc_491521502318_item	3669493	et	3	main
olid	doc_491521502318_item	3669491	et	4	main
või	doc_491521502318_item	3669486	et	4	main
seal	doc_491521502318_item	3669482	et	4	main
gildisse	doc_491521502318_item	3669481	et	3	main
koondasid	doc_491521502318_item	3669480	et	4	main
linnaelanikud	doc_491521502318_item	3669479	et	3	main
elama	doc_491521502318_item	3669478	et	3	main
pidamine	doc_491521502318_item	3669471	et	4	main
road	doc_491521502318_item	3669457	et	4	main
oli	doc_491521502318_item	3669456	et	3	main
koht	doc_491521502318_item	3669455	et	3	main
linnavalitsuse	doc_491521502318_item	3669454	et	3	main
linn	doc_491521502318_item	3669444	et	3	main
hansa	doc_491521502318_item	3669441	et	4	main
linnad	doc_491521502318_item	3669440	et	3	main
peale	doc_491521502318_item	3669432	et	4	main
inimest	doc_491521502318_item	3669431	et	3	main
umbes	doc_491521502318_item	3669423	et	4	main
tallinnas	doc_491521502318_item	3669421	et	4	main
tartu	doc_491521502318_item	3669420	et	4	main
ja	doc_491521502318_item	3669419	et	3	main
kõige	doc_491521502318_item	3669413	et	4	main
piiskopkonnale	doc_491521502318_item	3669412	et	3	main
ja	doc_491521502318_item	3669408	et	3	main
kuulus	doc_491521502318_item	3669402	et	4	main
ka	doc_491521502318_item	3669548	et	3	main
keelde	doc_491521502318_item	3669544	et	4	main
tilkima	doc_491521502318_item	3669542	et	4	main
oli	doc_491521502318_item	3669530	et	3	main
kirikukihelkondadeks	doc_491521502318_item	3669527	et	3	main
ja	doc_491521502318_item	3669510	et	3	main
kaupmehed	doc_491521502318_item	3669509	et	3	main
käsitöömeistrid	doc_491521502318_item	3669508	et	3	main
olid	doc_491521502318_item	3669507	et	4	main
sakslased	doc_491521502318_item	3669506	et	3	main
aga	doc_491521502318_item	3669505	et	3	main
lihtkäistöölised	doc_491521502318_item	3669504	et	4	main
põhiliselt	doc_491521502318_item	3669503	et	4	main
olid	doc_491521502318_item	3669502	et	4	main
eestlased	doc_491521502318_item	3669501	et	3	main
linnaselavad	doc_491521502318_item	3669500	et	4	main
pagarad	doc_491521502318_item	3669499	et	4	main
käsitöölised	doc_491521502318_item	3669498	et	3	main
keeles	doc_491521502318_item	3669550	et	4	main
ümber	doc_491521502318_item	3669520	et	3	main
korraldas	doc_491521502318_item	3669519	et	3	main
see	doc_491521502318_item	3669518	et	3	main
ii	doc_491521502318_item	3669516	et	4	main
oli	doc_491521502318_item	3669514	et	3	main
seal	doc_491521502318_item	3669495	et	4	main
tsunftis	doc_491521502318_item	3669494	et	3	main
selle	doc_491521502318_item	3669489	et	4	main
peale	doc_491521502318_item	3669488	et	4	main
töötasid	doc_491521502318_item	3669484	et	4	main
keda	doc_491521502318_item	3669475	et	4	main
ja	doc_491521502318_item	3669474	et	3	main
kas	doc_491521502318_item	3669473	et	3	main
magistraati	doc_491521502318_item	3669460	et	4	main
magistraat	doc_491521502318_item	3669459	et	3	main
ja	doc_491521502318_item	3669458	et	3	main
punkt	doc_491521502318_item	3669448	et	4	main
omavalitsuse	doc_491521502318_item	3669447	et	3	main
iga	doc_491521502318_item	3669443	et	4	main
inimest	doc_491521502318_item	3669426	et	3	main
tallinn	doc_491521502318_item	3669418	et	4	main
tartu	doc_491521502318_item	3669411	et	4	main
saare-lääne	doc_491521502318_item	3669404	et	4	main
liivi	doc_491521502318_item	3669392	et	4	main
piirkondadeks	doc_491521502318_item	3669387	et	3	main
territooriumi	doc_491521502318_item	3669382	et	4	main
1	doc_491521502318_item	3669350	et	2	main
kontrolltöö	doc_491521502318_item	3669349	et	4	main
inimesed	doc_491521502318_item	3669490	et	3	main
käsitöölised	doc_491521502318_item	3669487	et	3	main
otsustamine	doc_491521502318_item	3669472	et	4	main
maksustamine	doc_491521502318_item	3669469	et	4	main
olid	doc_491521502318_item	3669467	et	4	main
ülesanned	doc_491521502318_item	3669466	et	4	main
iga	doc_491521502318_item	3669463	et	4	main
valitsusega	doc_491521502318_item	3669452	et	4	main
viljandi	doc_491521502318_item	3669436	et	4	main
ka	doc_491521502318_item	3669435	et	3	main
tartus	doc_491521502318_item	3669428	et	3	main
7-8	doc_491521502318_item	3669424	et	2	main
elas	doc_491521502318_item	3669422	et	3	main
tollajal	doc_491521502318_item	3669416	et	4	main
taanile	doc_491521502318_item	3669403	et	4	main
mees	doc_491521502318_item	3669397	et	4	main
keskosa	doc_491521502318_item	3669390	et	4	main
ja	doc_491521502318_item	3669389	et	3	main
neljaks	doc_491521502318_item	3669385	et	4	main
mõjus	doc_491521502318_item	3669377	et	4	main
ristisõda	doc_491521502318_item	3669376	et	4	main
kätte	doc_491521502318_item	3669375	et	4	main
enda	doc_491521502318_item	3669374	et	4	main
võimu	doc_491521502318_item	3669373	et	4	main
võtab	doc_491521502318_item	3669372	et	3	main
kirik	doc_491521502318_item	3669371	et	3	main
katoliku	doc_491521502318_item	3669370	et	3	main
kui	doc_491521502318_item	3669369	et	3	main
alguses	doc_491521502318_item	3669368	et	4	main
saj	doc_491521502318_item	3669367	et	4	main
13	doc_491521502318_item	3669366	et	2	main
katkestatud	doc_491521502318_item	3669365	et	4	main
oli	doc_491521502318_item	3669364	et	3	main
ühiskonnakorraldus	doc_491521502318_item	3669363	et	3	main
iseseisev	doc_491521502318_item	3669362	et	3	main
1	doc_491521502318_item	3669361	et	2	main
reformatsioon	doc_491521502318_item	3669360	et	3	main
tähendab	doc_491521502318_item	3669359	et	3	main
mida	doc_491521502318_item	3669358	et	4	main
2	doc_491521502318_item	3669357	et	2	main
sajandil	doc_491521502318_item	3669356	et	3	main
1316	doc_491521502318_item	3669355	et	2	main
ühiskonnakorraldusele	doc_491521502318_item	3669354	et	3	main
eesti	doc_491521502318_item	3669353	et	4	main
mõjud	doc_491521502318_item	3669352	et	4	main
ristiusustamise	doc_491521502318_item	3669351	et	3	main
liidus	doc_491521502318_item	3669442	et	4	main
need	doc_491521502318_item	3669439	et	3	main
uus-pärnu	doc_491521502318_item	3669438	et	4	main
ja	doc_491521502318_item	3669437	et	3	main
tuh	doc_491521502318_item	3669430	et	4	main
5-6	doc_491521502318_item	3669429	et	2	main
linnad	doc_491521502318_item	3669415	et	3	main
suuremad	doc_491521502318_item	3669414	et	4	main
lõuna	doc_491521502318_item	3669409	et	4	main
piiskopkonnale	doc_491521502318_item	3669407	et	3	main
eesti	doc_491521502318_item	3669405	et	4	main
kuulus	doc_491521502318_item	3669391	et	4	main
omaette	doc_491521502318_item	3669386	et	3	main
jagama	doc_491521502318_item	3669384	et	3	main
23	doc_491521501874_item	3670074	et	2	main
tunnustatakse	doc_491521501874_item	3670062	et	3	main
sept	doc_491521501874_item	3670059	et	4	main
kasutusele	doc_491521501874_item	3670044	et	4	main
uuesti	doc_491521501874_item	3670043	et	3	main
inimesi	doc_491521501874_item	3670033	et	4	main
valitakse	doc_491521501874_item	3670032	et	3	main
protokolli	doc_491521501874_item	3670021	et	4	main
sõlmitud	doc_491521501874_item	3670015	et	4	main
oli	doc_491521501874_item	3670014	et	3	main
mis	doc_491521501874_item	3670013	et	4	main
pakt	doc_491521501874_item	3670012	et	3	main
salaprotokoll	doc_491521501874_item	3670009	et	4	main
esimest	doc_491521501874_item	3670003	et	4	main
nl-	doc_491521501874_item	3670002	et	4	main
seal	doc_491521502318_item	3669398	et	4	main
mee	doc_491521502318_item	3669396	et	3	main
lõuna	doc_491521502318_item	3669388	et	4	main
hakati	doc_491521502318_item	3669383	et	3	main
eesti	doc_491521502318_item	3669381	et	4	main
ühiskonnakorraldusele	doc_491521502318_item	3669380	et	3	main
eesti	doc_491521502318_item	3669379	et	4	main
väga	doc_491521502318_item	3669378	et	3	main
juuni	doc_491521501874_item	3670075	et	4	main
a	doc_491521501874_item	3670061	et	4	main
6	doc_491521501874_item	3670058	et	2	main
ev	doc_491521501874_item	3670054	et	4	main
kes	doc_491521501874_item	3670034	et	4	main
a	doc_491521501874_item	3670025	et	4	main
1990	doc_491521501874_item	3670024	et	2	main
tühistatakse	doc_491521501874_item	3670023	et	3	main
nl	doc_491521501874_item	3670018	et	4	main
ja	doc_491521501874_item	3670017	et	3	main
saksamaa	doc_491521501874_item	3670016	et	4	main
tunnustab	doc_491521501874_item	3670005	et	3	main
korda	doc_491521501874_item	3670004	et	4	main
tähelepanu	doc_491521501874_item	3669991	et	4	main
äratas	doc_491521501874_item	3669990	et	3	main
kett	doc_491521501874_item	3669989	et	4	main
balti	doc_491521501874_item	3669988	et	3	main
inimest	doc_491521501874_item	3669987	et	3	main
pikk	doc_491521501874_item	3669972	et	4	main
nov	doc_491521501874_item	3669956	et	4	main
nl	doc_491521501874_item	3669952	et	4	main
valitsema	doc_491521501874_item	3669943	et	3	main
edasi	doc_491521501874_item	3669942	et	3	main
süsteem	doc_491521501874_item	3669941	et	3	main
nõukogude	doc_491521501874_item	3669940	et	3	main
baltikas	doc_491521501874_item	3669937	et	4	main
kus	doc_491521501874_item	3669917	et	3	main
mis	doc_491521501874_item	3669901	et	4	main
mida	doc_491521501874_item	3669875	et	4	main
teoseid	doc_491521501874_item	3669873	et	3	main
ja	doc_491521501874_item	3669871	et	3	main
väliseesti	doc_491521501874_item	3669869	et	4	main
eesti	doc_491521501874_item	3669863	et	4	main
tegid	doc_491521501874_item	3669861	et	4	main
eesti	doc_491521501874_item	3670148	et	4	main
eesti	doc_491521501874_item	3670072	et	4	main
1992	doc_491521501874_item	3670067	et	2	main
venemaa	doc_491521501874_item	3670065	et	4	main
iseseisva	doc_491521501874_item	3670057	et	3	main
saab	doc_491521501874_item	3670055	et	3	main
savisaar	doc_491521501874_item	3670053	et	3	main
1992	doc_491521501874_item	3670076	et	2	main
kasutusele	doc_491521501874_item	3670071	et	4	main
juunis	doc_491521501874_item	3670069	et	3	main
poolest	doc_491521501874_item	3670066	et	4	main
iseseisvust	doc_491521501874_item	3670064	et	4	main
1991	doc_491521501874_item	3670060	et	2	main
oma	doc_491521501874_item	3670056	et	4	main
juhima	doc_491521501874_item	3670051	et	4	main
valitsus	doc_491521501874_item	3670049	et	4	main
uut	doc_491521501874_item	3670048	et	3	main
vabariigi	doc_491521501874_item	3670046	et	3	main
a	doc_491521501874_item	3670041	et	4	main
8	doc_491521501874_item	3670038	et	2	main
õigust	doc_491521501874_item	3670022	et	4	main
ribbentropi	doc_491521501874_item	3670011	et	4	main
olemas	doc_491521501874_item	3670008	et	4	main
on	doc_491521501874_item	3670007	et	4	main
et	doc_491521501874_item	3670006	et	3	main
24	doc_491521501874_item	3669998	et	2	main
iseseisvuspüüde	doc_491521501874_item	3669997	et	4	main
rahulik	doc_491521501874_item	3669996	et	3	main
oli	doc_491521501874_item	3669995	et	3	main
kogu	doc_491521501874_item	3669992	et	4	main
hermann	doc_491521501874_item	3669973	et	4	main
a	doc_491521501874_item	3669969	et	4	main
24	doc_491521501874_item	3669966	et	2	main
iseseisvusdeklaratsioon	doc_491521501874_item	3669965	et	3	main
e	doc_491521501874_item	3669964	et	4	main
deklaratsioon	doc_491521501874_item	3669963	et	3	main
suveräänsuse	doc_491521501874_item	3669962	et	4	main
vastu	doc_491521501874_item	3669961	et	3	main
eestis	doc_491521501874_item	3669960	et	3	main
võetakse	doc_491521501874_item	3669959	et	3	main
ära	doc_491521501874_item	3669954	et	4	main
elavad	doc_491521501874_item	3669945	et	4	main
nad	doc_491521501874_item	3669944	et	3	main
interrinde	doc_491521501874_item	3669927	et	4	main
avaldatakse	doc_491521501874_item	3669918	et	3	main
lippu	doc_491521501874_item	3669912	et	4	main
kasutada	doc_491521501874_item	3669910	et	3	main
tartu	doc_491521501874_item	3669907	et	4	main
gorbatšovi	doc_491521501874_item	3669904	et	2	main
m	doc_491521501874_item	3669903	et	4	main
toetab	doc_491521501874_item	3669902	et	3	main
kujutas	doc_491521501874_item	3669876	et	3	main
kirjanikke	doc_491521501874_item	3669870	et	3	main
nimetage	doc_491521501874_item	3669868	et	3	main
2	doc_491521501874_item	3669867	et	2	main
aastatel	doc_491521501874_item	3669866	et	4	main
eesnimi	doc_491521501874_item	3669853	et	3	main
vastus	doc_491521501874_item	3669851	et	3	main
võiks	doc_491521501874_item	3670146	et	4	main
et	doc_491521501874_item	3670144	et	3	main
vastu	doc_491521501874_item	3670142	et	3	main
venestuspoliitika	doc_491521501874_item	3670141	et	4	main
mis	doc_491521501874_item	3670134	et	4	main
on	doc_491521501874_item	3670132	et	4	main
tartu	doc_491521501874_item	3670120	et	4	main
kangro	doc_491521501874_item	3670117	et	4	main
olid	doc_491521501874_item	3670111	et	4	main
oli	doc_491521501875_item	3670264	et	3	main
sees	doc_491521501875_item	3670262	et	4	main
kooliprogrammi	doc_491521501875_item	3670261	et	4	main
olid	doc_491521501875_item	3670249	et	4	main
jakobson	doc_491521501875_item	3670241	et	4	main
kirjanikest	doc_491521501875_item	3670239	et	3	main
poeem	doc_491521501875_item	3670230	et	3	main
peamised	doc_491521501875_item	3670227	et	3	main
ilmunud	doc_491521501875_item	3670226	et	4	main
põhiliselt	doc_491521501875_item	3670219	et	4	main
ilmusid	doc_491521501875_item	3670218	et	4	main
võitlus	doc_491521501875_item	3670210	et	3	main
keskseks	doc_491521501875_item	3670204	et	4	main
oli	doc_491521501875_item	3670202	et	3	main
stalinile	doc_491521501875_item	3670201	et	4	main
pühendatud	doc_491521501875_item	3670200	et	4	main
oli	doc_491521501875_item	3670199	et	3	main
kirjandus	doc_491521501875_item	3670198	et	3	main
sõbrad	doc_980560860272_item	3670346	et	3	main
me	doc_980560860272_item	3670339	et	4	main
kroon	doc_491521501874_item	3670073	et	3	main
tuleb	doc_491521501874_item	3670070	et	3	main
eestis	doc_491521501874_item	3670068	et	3	main
ev	doc_491521501874_item	3670063	et	4	main
edgar	doc_491521501874_item	3670052	et	4	main
nimetus	doc_491521501874_item	3670047	et	4	main
eesti	doc_491521501874_item	3670045	et	4	main
1990	doc_491521501874_item	3670040	et	2	main
mai	doc_491521501874_item	3670039	et	4	main
kodanikud	doc_491521501874_item	3670037	et	3	main
eesti	doc_491521501874_item	3670036	et	4	main
sellelle	doc_491521501874_item	3670031	et	4	main
kongress	doc_491521501874_item	3670030	et	3	main
eesti	doc_491521501874_item	3670029	et	4	main
selle	doc_491521501874_item	3670020	et	4	main
molotovi	doc_491521501874_item	3670010	et	4	main
see	doc_491521501874_item	3669994	et	3	main
kett	doc_491521501874_item	3669984	et	4	main
balti	doc_491521501874_item	3669983	et	3	main
nn	doc_491521501874_item	3669982	et	4	main
toimub	doc_491521501874_item	3669981	et	3	main
1989	doc_491521501874_item	3669980	et	2	main
aug	doc_491521501874_item	3669979	et	4	main
23	doc_491521501874_item	3669978	et	2	main
lipp	doc_491521501874_item	3669977	et	3	main
a	doc_491521501874_item	3669958	et	4	main
1988	doc_491521501874_item	3669957	et	2	main
sp	doc_491521501874_item	3669948	et	4	main
ja	doc_491521501874_item	3669947	et	3	main
hästi	doc_491521501874_item	3669946	et	3	main
kes	doc_491521501874_item	3669934	et	4	main
toeta	doc_491521501874_item	3669926	et	4	main
ei	doc_491521501874_item	3669925	et	4	main
ja	doc_491521501874_item	3669924	et	3	main
ekp	doc_491521501874_item	3669915	et	4	main
september	doc_491521501874_item	3669913	et	3	main
lubab	doc_491521501874_item	3669909	et	3	main
hakkab	doc_491521501874_item	3670050	et	3	main
võetakse	doc_491521501874_item	3670042	et	3	main
on	doc_491521501874_item	3670035	et	4	main
valitakse	doc_491521501874_item	3670028	et	3	main
dets	doc_491521501874_item	3670027	et	4	main
24	doc_491521501874_item	3670026	et	2	main
vahel	doc_491521501874_item	3670019	et	4	main
dets	doc_491521501874_item	3669999	et	4	main
2mlj	doc_491521501874_item	3669986	et	4	main
osales	doc_491521501874_item	3669985	et	3	main
korda	doc_491521501874_item	3669975	et	4	main
esimest	doc_491521501874_item	3669974	et	4	main
tornile	doc_491521501874_item	3669971	et	3	main
riputakse	doc_491521501874_item	3669970	et	3	main
langeks	doc_491521501874_item	3669953	et	4	main
taha	doc_491521501874_item	3669950	et	4	main
ei	doc_491521501874_item	3669949	et	4	main
oleks	doc_491521501874_item	3669938	et	3	main
et	doc_491521501874_item	3669936	et	3	main
tahavad	doc_491521501874_item	3669935	et	3	main
inimesed	doc_491521501874_item	3669933	et	3	main
kuuluvad	doc_491521501874_item	3669932	et	4	main
siia	doc_491521501874_item	3669931	et	4	main
interrinne	doc_491521501874_item	3669930	et	3	main
eestis	doc_491521501874_item	3669929	et	3	main
rahvarinnet	doc_491521501874_item	3669923	et	3	main
toetab	doc_491521501874_item	3669922	et	3	main
parti	doc_491521501874_item	3669921	et	4	main
pleenum	doc_491521501874_item	3669916	et	3	main
sini-must-valge	doc_491521501874_item	3669911	et	4	main
linnavalitsus	doc_491521501874_item	3669908	et	3	main
1988	doc_491521501874_item	3669906	et	2	main
poliitikat	doc_491521501874_item	3669905	et	3	main
rahvarinne	doc_491521501874_item	3669899	et	3	main
1990	doc_491521501874_item	3669865	et	2	main
tegurid	doc_491521501874_item	3669860	et	3	main
05062003	doc_491521501874_item	3669856	et	2	main
keeles	doc_491521501874_item	3670149	et	4	main
moskvasse	doc_491521501874_item	3670138	et	4	main
intelligent	doc_491521501874_item	3670137	et	3	main
kirjad	doc_491521501874_item	3670133	et	4	main
3	doc_491521501874_item	3670130	et	2	main
nagu	doc_491521501874_item	3670129	et	3	main
kirjutas	doc_491521501874_item	3670119	et	3	main
a	doc_491521501874_item	3670001	et	4	main
1989	doc_491521501874_item	3670000	et	2	main
maailmas	doc_491521501874_item	3669993	et	3	main
sini-must-valge	doc_491521501874_item	3669976	et	4	main
1989	doc_491521501874_item	3669968	et	2	main
veebruar	doc_491521501874_item	3669967	et	3	main
16	doc_491521501874_item	3669955	et	2	main
et	doc_491521501874_item	3669951	et	3	main
edasi	doc_491521501874_item	3669939	et	3	main
tegevust	doc_491521501874_item	3669928	et	4	main
toetamist	doc_491521501874_item	3669920	et	4	main
rahvarinnet	doc_491521501874_item	3669919	et	3	main
1988	doc_491521501874_item	3669914	et	2	main
idee	doc_491521501874_item	3669900	et	4	main
sünnib	doc_491521501874_item	3669898	et	3	main
eestiga	doc_491521501874_item	3669897	et	4	main
isemajandava	doc_491521501874_item	3669896	et	3	main
seoses	doc_491521501874_item	3669895	et	4	main
aprillis	doc_491521501874_item	3669894	et	3	main
a	doc_491521501874_item	3669893	et	4	main
1988	doc_491521501874_item	3669892	et	2	main
süsteemile	doc_491521501874_item	3669891	et	3	main
isemajandamise	doc_491521501874_item	3669890	et	3	main
minna	doc_491521501874_item	3669889	et	3	main
üle	doc_491521501874_item	3669888	et	3	main
eesti	doc_491521501874_item	3669887	et	4	main
et	doc_491521501874_item	3669886	et	3	main
idee	doc_491521501874_item	3669885	et	4	main
tekib	doc_491521501874_item	3669884	et	3	main
1987	doc_491521501874_item	3669883	et	2	main
sept	doc_491521501874_item	3669882	et	4	main
26	doc_491521501874_item	3669881	et	2	main
1	doc_491521501874_item	3669880	et	2	main
kiri	doc_491521501874_item	3669879	et	3	main
40	doc_491521501874_item	3669878	et	2	main
endast	doc_491521501874_item	3669877	et	4	main
nende	doc_491521501874_item	3669872	et	4	main
võimalikuks	doc_491521501874_item	3669862	et	3	main
millised	doc_491521501874_item	3669858	et	3	main
perekonnanimi	doc_491521501874_item	3669854	et	3	main
olid	doc_491521501874_item	3670140	et	4	main
nad	doc_491521501874_item	3670139	et	3	main
teised	doc_491521501874_item	3670128	et	4	main
under	doc_491521501874_item	3670126	et	4	main
kes	doc_491521501874_item	3670118	et	4	main
b	doc_491521501874_item	3670116	et	4	main
öö	doc_491521501874_item	3670115	et	4	main
hingede	doc_491521501874_item	3670114	et	3	main
allutatud	doc_491521501875_item	3670265	et	4	main
kirjandus	doc_491521501875_item	3670263	et	3	main
nad	doc_491521501875_item	3670259	et	3	main
ainult	doc_491521501875_item	3670246	et	4	main
august	doc_491521501875_item	3670240	et	4	main
drama	doc_491521501875_item	3670238	et	4	main
domineerisid	doc_491521501875_item	3670234	et	4	main
kirjandusžanrid	doc_491521501875_item	3670228	et	2	main
ei	doc_491521501875_item	3670225	et	4	main
kirjandust	doc_491521501875_item	3670224	et	3	main
võõrkeelest	doc_491521501875_item	3670223	et	4	main
tõlked	doc_491521501875_item	3670220	et	3	main
stalinismi	doc_491521501875_item	3670216	et	4	main
kodaniku	doc_491521501875_item	3670214	et	3	main
imperialismiga	doc_491521501875_item	3670212	et	3	main
3	doc_491521501874_item	3669874	et	2	main
taasiseseisvumise	doc_491521501874_item	3669864	et	3	main
kultuurilis-poliitilised	doc_491521501874_item	3669859	et	3	main
1	doc_491521501874_item	3669857	et	2	main
kuupäev	doc_491521501874_item	3669855	et	3	main
küsimusele	doc_491521501874_item	3669852	et	4	main
saada	doc_491521501874_item	3670147	et	4	main
haridus	doc_491521501874_item	3670145	et	3	main
eesti	doc_491521501874_item	3670136	et	4	main
ja	doc_491521501874_item	3670127	et	3	main
m	doc_491521501874_item	3670125	et	4	main
naiskirjanik	doc_491521501874_item	3670124	et	3	main
tuntud	doc_491521501874_item	3670123	et	4	main
ristikivi	doc_491521501874_item	3670113	et	4	main
need	doc_491521501874_item	3670110	et	3	main
emigratsioonis	doc_491521501874_item	3670109	et	3	main
elada	doc_491521501874_item	3670108	et	3	main
sündinud	doc_491521501874_item	3670107	et	4	main
kes	doc_491521501874_item	3670105	et	4	main
olid	doc_491521501874_item	3670106	et	4	main
kirjanikutena	doc_491521501874_item	3670104	et	4	main
eesti	doc_491521501874_item	3670103	et	4	main
kirjutatud	doc_491521501874_item	3670102	et	4	main
olid	doc_491521501874_item	3670101	et	4	main
teosed	doc_491521501874_item	3670100	et	3	main
tähtsad	doc_491521501874_item	3670099	et	3	main
palju	doc_491521501874_item	3670098	et	4	main
kolk	doc_491521501874_item	3670097	et	3	main
raimond	doc_491521501874_item	3670096	et	4	main
luuletaja	doc_491521501874_item	3670095	et	4	main
2	doc_491521501874_item	3670094	et	2	main
riigikogu	doc_491521501874_item	3670093	et	4	main
valitakse	doc_491521501874_item	3670092	et	3	main
ja	doc_491521501874_item	3670091	et	3	main
meri	doc_491521501874_item	3670090	et	3	main
lennart	doc_491521501874_item	3670089	et	4	main
valitakse	doc_491521501874_item	3670088	et	3	main
presidendiks	doc_491521501874_item	3670087	et	4	main
esimeseks	doc_491521501874_item	3670086	et	3	main
ev	doc_491521501874_item	3670085	et	4	main
1992	doc_491521501874_item	3670084	et	2	main
sept	doc_491521501874_item	3670083	et	4	main
20	doc_491521501874_item	3670082	et	2	main
põhiseaduse	doc_491521501874_item	3670081	et	3	main
ev	doc_491521501874_item	3670080	et	4	main
vastu	doc_491521501874_item	3670079	et	3	main
võetakse	doc_491521501874_item	3670078	et	3	main
tahtside	doc_491521501874_item	3670143	et	4	main
kirjutasid	doc_491521501874_item	3670135	et	4	main
need	doc_491521501874_item	3670131	et	3	main
veel	doc_491521501874_item	3670122	et	4	main
elust	doc_491521501874_item	3670121	et	3	main
k	doc_491521501874_item	3670112	et	4	main
fr	doc_491521501875_item	3670256	et	4	main
ja	doc_491521501875_item	3670255	et	3	main
koidula	doc_491521501875_item	3670254	et	4	main
kirjanikut	doc_491521501875_item	3670248	et	4	main
kaks	doc_491521501875_item	3670247	et	3	main
praktiliselt	doc_491521501875_item	3670243	et	4	main
smuul	doc_491521501875_item	3670236	et	4	main
draama	doc_491521501875_item	3670232	et	4	main
olid	doc_491521501875_item	3670229	et	4	main
natsionalismiga	doc_491521501875_item	3670215	et	3	main
oli	doc_491521501875_item	3670209	et	3	main
teemaks	doc_491521501875_item	3670206	et	4	main
a	doc_491521501874_item	3670077	et	4	main
parteikontrollile	doc_491521501875_item	3670266	et	3	main
olid	doc_491521501875_item	3670260	et	4	main
kreutzwald	doc_491521501875_item	3670258	et	4	main
l	doc_491521501875_item	3670253	et	4	main
ajal	doc_491521501875_item	3670252	et	4	main
nõukogude	doc_491521501875_item	3670251	et	3	main
ilmunud	doc_491521501875_item	3670245	et	4	main
romaane	doc_491521501875_item	3670242	et	3	main
poeetidest	doc_491521501875_item	3670233	et	3	main
keelest	doc_491521501875_item	3670222	et	4	main
ajal	doc_491521501875_item	3670217	et	4	main
ja	doc_491521501875_item	3670213	et	3	main
kodaniku	doc_491521501875_item	3670211	et	3	main
kirjanduses	doc_491521501875_item	3670208	et	3	main
smuul	doc_491521501875_item	3670197	et	4	main
pidi	doc_491521501875_item	3670169	et	4	main
mis	doc_491521501875_item	3670168	et	4	main
kirjandus	doc_491521501875_item	3670167	et	3	main
on	doc_491521501875_item	3670166	et	4	main
see	doc_491521501875_item	3670165	et	3	main
realism	doc_491521501875_item	3670164	et	3	main
sotsialistlik	doc_491521501875_item	3670163	et	3	main
kirjandusstiil	doc_491521501875_item	3670162	et	3	main
see	doc_491521501875_item	3670160	et	3	main
näiteid	doc_491521501875_item	3670159	et	3	main
tooge	doc_491521501875_item	3670158	et	3	main
realism	doc_491521501875_item	3670157	et	3	main
on	doc_491521501875_item	3670161	et	4	main
sotsialistlik	doc_491521501875_item	3670156	et	3	main
tähendab	doc_491521501875_item	3670155	et	3	main
mida	doc_491521501875_item	3670154	et	4	main
küsimusele	doc_491521501875_item	3670153	et	4	main
vastus	doc_491521501875_item	3670152	et	3	main
näitada	doc_980560860272_item	3670347	et	4	main
käisin	doc_980560860272_item	3670345	et	3	main
jalgratas	doc_980560860272_item	3670343	et	3	main
kui	doc_980560860272_item	3670338	et	3	main
oma	doc_980560860272_item	3670321	et	4	main
ma	doc_980560860272_item	3670317	et	3	main
olid	doc_980560860272_item	3670312	et	4	main
15-aastane	doc_980560860272_item	3670302	et	4	main
sa	doc_980560860272_item	3670296	et	3	main
ma	doc_980560860272_item	3670294	et	3	main
olid	doc_980560860272_item	3670283	et	4	main
sa	doc_980560860272_item	3670282	et	3	main
tsensuur	doc_491521501875_item	3670269	et	3	main
tugev	doc_491521501875_item	3670268	et	4	main
oli	doc_491521501875_item	3670267	et	3	main
r	doc_491521501875_item	3670257	et	4	main
lubatud	doc_491521501875_item	3670250	et	4	main
ei	doc_491521501875_item	3670244	et	4	main
ja	doc_491521501875_item	3670237	et	3	main
juhan	doc_491521501875_item	3670235	et	3	main
ja	doc_491521501875_item	3670231	et	3	main
vene	doc_491521501875_item	3670221	et	4	main
tähtsaks	doc_491521501875_item	3670205	et	4	main
stalini	doc_491521501875_item	3670203	et	4	main
mina	doc_491521501875_item	3670193	et	4	main
näiteks	doc_491521501875_item	3670192	et	4	main
olid	doc_491521501875_item	3670191	et	4	main
pealkirjad	doc_491521501875_item	3670190	et	3	main
poeemide	doc_491521501875_item	3670189	et	3	main
kirjutada	doc_491521501875_item	3670188	et	3	main
vaja	doc_491521501875_item	3670187	et	4	main
oli	doc_491521501875_item	3670186	et	3	main
millest	doc_491521501875_item	3670185	et	3	main
teemad	doc_491521501875_item	3670184	et	3	main
konkreetsed	doc_491521501875_item	3670183	et	3	main
olid	doc_491521501875_item	3670182	et	4	main
vaid	doc_491521501875_item	3670181	et	3	main
meeldib	doc_491521501875_item	3670180	et	3	main
nendele	doc_491521501875_item	3670179	et	4	main
mis	doc_491521501875_item	3670178	et	4	main
sellest	doc_491521501875_item	3670177	et	4	main
kirjutanud	doc_491521501875_item	3670176	et	4	main
ei	doc_491521501875_item	3670175	et	4	main
kirjanikud	doc_491521501875_item	3670174	et	3	main
rahvalik	doc_491521501875_item	3670173	et	3	main
ideeline	doc_491521501875_item	3670172	et	4	main
parteine	doc_491521501875_item	3670171	et	4	main
olema	doc_491521501875_item	3670170	et	4	main
esimese	doc_980560860272_item	3670337	et	3	main
said	doc_980560860272_item	3670335	et	4	main
läksime	doc_980560860272_item	3670333	et	3	main
kohtusid	doc_980560860272_item	3670320	et	4	main
reisil	doc_980560860272_item	3670316	et	3	main
kui	doc_980560860272_item	3670299	et	3	main
vanavanemad	doc_980560860272_item	3670292	et	4	main
tollases	doc_491521501875_item	3670207	et	3	main
j	doc_491521501875_item	3670196	et	4	main
noor	doc_491521501875_item	3670195	et	3	main
kommunistlik	doc_491521501875_item	3670194	et	3	main
sain	doc_980560860272_item	3670340	et	3	main
kohtusin	doc_980560860272_item	3670325	et	4	main
kui	doc_980560860272_item	3670324	et	3	main
sõbraga	doc_980560860272_item	3670323	et	3	main
parima	doc_980560860272_item	3670322	et	4	main
türgi	doc_980560860272_item	3670319	et	4	main
läksin	doc_980560860272_item	3670318	et	3	main
viimasel	doc_980560860272_item	3670315	et	3	main
viimasel	doc_980560860272_item	3670313	et	3	main
sa	doc_980560860272_item	3670311	et	3	main
olin	doc_980560860272_item	3670301	et	3	main
15-aastane	doc_980560860272_item	3670298	et	4	main
ja	doc_980560860272_item	3670293	et	3	main
sagelis	doc_980560860272_item	3670291	et	4	main
läksin	doc_980560860272_item	3670290	et	3	main
ma	doc_980560860272_item	3670289	et	3	main
7-aastane	doc_980560860272_item	3670288	et	4	main
olin	doc_980560860272_item	3670287	et	3	main
ma	doc_980560860272_item	3670286	et	3	main
kui	doc_980560860272_item	3670285	et	3	main
olid	doc_980560860272_item	3670280	et	4	main
noorte	doc_491521502234_item	3670857	et	3	main
tasuta	doc_491521502234_item	3670853	et	4	main
energeetika	doc_491521502234_item	3670847	et	4	main
positsioon	doc_491521502234_item	3670839	et	3	main
eluks	doc_491521502234_item	3670835	et	3	main
rahulduma	doc_491521502234_item	3670834	et	3	main
eelised	doc_491521502234_item	3670824	et	4	main
ilma	doc_491521502234_item	3670821	et	4	main
tohtinud	doc_491521502234_item	3670819	et	4	main
ei	doc_491521502234_item	3670818	et	4	main
eluga	doc_491521502234_item	3670813	et	3	main
ma	doc_980560860272_item	3670344	et	3	main
esimese	doc_980560860272_item	3670342	et	3	main
minu	doc_980560860272_item	3670341	et	3	main
oma	doc_980560860272_item	3670336	et	4	main
pubis	doc_980560860272_item	3670334	et	4	main
me	doc_980560860272_item	3670332	et	4	main
ja	doc_980560860272_item	3670331	et	3	main
rääkisime	doc_980560860272_item	3670330	et	3	main
me	doc_980560860272_item	3670329	et	4	main
sõbraga	doc_980560860272_item	3670328	et	3	main
reisil	doc_980560860272_item	3670314	et	3	main
raamatud	doc_980560860272_item	3670310	et	4	main
paljud	doc_980560860272_item	3670309	et	3	main
lugin	doc_980560860272_item	3670308	et	4	main
ma	doc_980560860272_item	3670307	et	3	main
ja	doc_980560860272_item	3670306	et	3	main
ma	doc_980560860272_item	3670300	et	3	main
olid	doc_980560860272_item	3670297	et	4	main
mängisin	doc_980560860272_item	3670295	et	3	main
kui	doc_980560860272_item	3670281	et	3	main
kus	doc_980560860272_item	3670279	et	3	main
tegid	doc_980560860272_item	3670278	et	4	main
sa	doc_980560860272_item	3670277	et	3	main
mida	doc_980560860272_item	3670276	et	4	main
kirjuta	doc_980560860272_item	3670275	et	4	main
3	doc_980560860272_item	3670274	et	2	main
küsimusele	doc_980560860272_item	3670273	et	4	main
vastus	doc_980560860272_item	3670272	et	3	main
parima	doc_980560860272_item	3670327	et	4	main
minu	doc_980560860272_item	3670326	et	3	main
mitu	doc_980560860272_item	3670305	et	4	main
õppisin	doc_980560860272_item	3670304	et	3	main
ma	doc_980560860272_item	3670303	et	3	main
7-aastane	doc_980560860272_item	3670284	et	4	main
pioneerid	doc_491521502234_item	3670855	et	3	main
venemaale	doc_491521502234_item	3670852	et	4	main
elektri	doc_491521502234_item	3670850	et	3	main
seoses	doc_491521502234_item	3670849	et	4	main
loeb	doc_491521502234_item	3670838	et	3	main
vaja	doc_491521502234_item	3670836	et	4	main
nõusolekuta	doc_491521502234_item	3670823	et	3	main
valimised	doc_491521502234_item	3670805	et	4	main
mitte	doc_491521502234_item	3670804	et	3	main
või	doc_491521502234_item	3670803	et	4	main
võõrtööjõud	doc_491521502234_item	3670796	et	4	main
juhid	doc_491521502234_item	3670791	et	4	main
väheneb	doc_491521502234_item	3670782	et	3	main
haritlased	doc_491521502234_item	3670777	et	3	main
eestis	doc_491521502234_item	3670775	et	3	main
rasketööstuse	doc_491521502234_item	3670773	et	3	main
in	doc_491521502234_item	3670770	et	4	main
21000	doc_491521502234_item	3670769	et	2	main
massiline	doc_491521502234_item	3670765	et	4	main
nii	doc_491521502234_item	3670760	et	3	main
kaasa	doc_491521502234_item	3670759	et	4	main
tootmisega	doc_491521502234_item	3670851	et	4	main
ülemanõukogu	doc_491521502234_item	3670841	et	4	main
partei	doc_491521502234_item	3670822	et	4	main
teha	doc_491521502234_item	3670820	et	3	main
jne	doc_491521502234_item	3670815	et	4	main
majandusega	doc_491521502234_item	3670814	et	4	main
sisse	doc_491521502234_item	3670795	et	4	main
valitakse	doc_491521502234_item	3670789	et	3	main
eestlaste	doc_491521502234_item	3670787	et	4	main
tagasipöördunud	doc_491521502234_item	3670786	et	4	main
arenguga	doc_491521502234_item	3670774	et	3	main
sisse	doc_491521502234_item	3670767	et	4	main
sohvooside	doc_491521502234_item	3670744	et	4	main
ja	doc_491521502234_item	3670743	et	3	main
majand	doc_491521502234_item	3670742	et	3	main
iseseisev	doc_491521502234_item	3670741	et	3	main
kolhooside	doc_491521502234_item	3670740	et	3	main
natsionaliseeriti	doc_491521502234_item	3670733	et	3	main
kogusest	doc_491521502234_item	3670729	et	4	main
tootma	doc_491521502234_item	3670724	et	3	main
palju	doc_491521502234_item	3670722	et	4	main
kui	doc_491521502234_item	3670721	et	3	main
plaani	doc_491521502234_item	3670720	et	4	main
ette	doc_491521502234_item	3670719	et	4	main
kingissepa	doc_491521502234_item	3670700	et	3	main
eesti	doc_491521502234_item	3670692	et	4	main
viidi	doc_491521502234_item	3670689	et	4	main
maailmajaod	doc_491521502234_item	3670684	et	3	main
tekkis	doc_491521502234_item	3670681	et	3	main
verd	doc_491521502234_item	3670678	et	3	main
juhte	doc_491521502234_item	3670650	et	4	main
vahel	doc_491521502234_item	3670646	et	4	main
välislektorid	doc_491521502234_item	3670634	et	3	main
oma	doc_491521502234_item	3670621	et	4	main
kasvatas	doc_491521502234_item	3670620	et	3	main
ja	doc_491521502234_item	3670619	et	3	main
eesti	doc_491521502234_item	3670607	et	4	main
lugeda	doc_491521502234_item	3670597	et	3	main
ajal	doc_491521502234_item	3670592	et	4	main
stalini	doc_491521502234_item	3670591	et	4	main
kirjanikke	doc_491521502234_item	3670582	et	3	main
heidetud	doc_491521502234_item	3670581	et	4	main
välja	doc_491521502234_item	3670580	et	4	main
ajal	doc_491521502234_item	3670577	et	4	main
kord	doc_491521502234_item	3670570	et	4	main
majanduses	doc_491521502234_item	3670558	et	4	main
ühiskonnakorralduses	doc_491521502234_item	3670556	et	3	main
suvepäevad	doc_491521502234_item	3670858	et	3	main
malevad	doc_491521502234_item	3670856	et	3	main
laienemine	doc_491521502234_item	3670848	et	4	main
ensv	doc_491521502234_item	3670840	et	4	main
minevaga	doc_491521502234_item	3670837	et	4	main
pidi	doc_491521502234_item	3670833	et	4	main
lihtrahvas	doc_491521502234_item	3670832	et	4	main
korterid	doc_491521502234_item	3670831	et	3	main
riikidesse	doc_491521502234_item	3670830	et	3	main
sots	doc_491521502234_item	3670829	et	3	main
tuusikud	doc_491521502234_item	3670828	et	3	main
liigutust	doc_491521502234_item	3670817	et	4	main
kõigega	doc_491521502234_item	3670810	et	3	main
praktiliselt	doc_491521502234_item	3670809	et	4	main
tegeleb	doc_491521502234_item	3670808	et	3	main
partei	doc_491521502234_item	3670807	et	4	main
demonstratiivsed	doc_491521502234_item	3670806	et	3	main
tuuakse	doc_491521502234_item	3670794	et	3	main
uued	doc_491521502234_item	3670790	et	3	main
ja	doc_491521502234_item	3670784	et	3	main
arv	doc_491521502234_item	3670781	et	3	main
siberisse	doc_491521502234_item	3670779	et	4	main
ümberasustamine	doc_491521502234_item	3670776	et	3	main
võõrtööjõu	doc_491521502234_item	3670766	et	3	main
inimeste	doc_491521502234_item	3670763	et	3	main
loomade	doc_491521502234_item	3670761	et	4	main
mis	doc_491521502234_item	3670756	et	4	main
tuleb	doc_491521502234_item	3670753	et	3	main
olev	doc_491521502234_item	3670746	et	4	main
riigitoetusel	doc_491521502234_item	3670745	et	4	main
maad	doc_491521502234_item	3670737	et	4	main
tehaseid	doc_491521502234_item	3670736	et	3	main
tootmine	doc_491521502234_item	3670731	et	4	main
hea	doc_491521502234_item	3670725	et	4	main
rubla	doc_491521502234_item	3670715	et	4	main
piirid	doc_491521502234_item	3670693	et	3	main
püüdlevad	doc_491521502234_item	3670686	et	4	main
kes	doc_491521502234_item	3670685	et	4	main
kõik	doc_491521502234_item	3670683	et	4	main
sinna	doc_491521502234_item	3670680	et	3	main
tööliste	doc_491521502234_item	3670677	et	4	main
sümboliseeris	doc_491521502234_item	3670676	et	4	main
tegelevad	doc_491521502234_item	3670654	et	4	main
oktoobrilapsed	doc_491521502234_item	3670854	et	3	main
ja	doc_491521502234_item	3670846	et	3	main
põlevkivitööstuse	doc_491521502234_item	3670845	et	3	main
teke	doc_491521502234_item	3670844	et	3	main
elektroonikatööstuse	doc_491521502234_item	3670843	et	3	main
rasketööstuse	doc_491521502234_item	3670842	et	3	main
ostuload	doc_491521502234_item	3670827	et	4	main
liikmetele	doc_491521502234_item	3670826	et	3	main
partei	doc_491521502234_item	3670825	et	4	main
ühtegi	doc_491521502234_item	3670816	et	4	main
puudus	doc_491521502234_item	3670793	et	4	main
venemaalt	doc_491521502234_item	3670785	et	3	main
toomine	doc_491521502234_item	3670768	et	4	main
tõi	doc_491521502234_item	3670758	et	3	main
kõik	doc_491521502234_item	3670752	et	4	main
loomi	doc_491521502234_item	3670738	et	4	main
näitaja	doc_491521502234_item	3670726	et	4	main
peab	doc_491521502234_item	3670723	et	4	main
kehtinud	doc_491521502234_item	3670714	et	4	main
viktor	doc_491521502234_item	3670699	et	4	main
kingissepa	doc_491521502234_item	3670698	et	3	main
kuressaare	doc_491521502234_item	3670697	et	4	main
rajoon	doc_491521502234_item	3670696	et	3	main
maakond	doc_491521502234_item	3670695	et	3	main
haldusreform	doc_491521502234_item	3670691	et	3	main
läbi	doc_491521502234_item	3670690	et	4	main
poole	doc_491521502234_item	3670688	et	4	main
kommunismi	doc_491521502234_item	3670687	et	4	main
viisnurk	doc_491521502234_item	3670682	et	3	main
ja	doc_491521502234_item	3670679	et	3	main
punane	doc_491521502234_item	3670674	et	4	main
sai	doc_491521502234_item	3670673	et	4	main
värviks	doc_491521502234_item	3670672	et	4	main
ise	doc_491521502234_item	3670651	et	4	main
olnud	doc_491521502234_item	3670641	et	4	main
erialadel	doc_491521502234_item	3670632	et	3	main
väga	doc_491521502234_item	3670630	et	3	main
löögi	doc_491521502234_item	3670603	et	4	main
sattus	doc_491521502234_item	3670602	et	3	main
kirin	doc_491521502234_item	3670601	et	3	main
suits	doc_491521502234_item	3670600	et	3	main
ja	doc_491521502234_item	3670599	et	3	main
raamatuid	doc_491521502234_item	3670594	et	3	main
muid	doc_491521502234_item	3670584	et	4	main
ja	doc_491521502234_item	3670583	et	3	main
veidi	doc_491521502234_item	3670572	et	3	main
nn	doc_491521502234_item	3670566	et	4	main
kõneldakse	doc_491521502234_item	3670565	et	3	main
ev	doc_491521502234_item	3670553	et	4	main
kultuur	doc_491521502217_item	3671246	et	3	main
narva	doc_491521502217_item	3671241	et	4	main
omane	doc_491521502217_item	3671233	et	3	main
on	doc_491521502217_item	3671232	et	4	main
kultuur	doc_491521502217_item	3671231	et	3	main
kultuuriline	doc_491521502217_item	3671226	et	4	main
püstkodade	doc_491521502217_item	3671146	et	3	main
veel	doc_491521502217_item	3671144	et	4	main
olid	doc_491521502217_item	3671135	et	4	main
inimesed	doc_491521502217_item	3671126	et	3	main
noorkeraamika	doc_491521502217_item	3671125	et	4	main
segainimestega	doc_491521502217_item	3671124	et	3	main
kammkeraamika	doc_491521502217_item	3671118	et	4	main
umbes	doc_491521502217_item	3671115	et	4	main
olnud	doc_491521502217_item	3671100	et	4	main
küttimine	doc_491521502217_item	3671076	et	4	main
domineeris	doc_491521502217_item	3671071	et	3	main
ajal	doc_491521502217_item	3671068	et	4	main
sel	doc_491521502217_item	3671067	et	3	main
savist	doc_491521502217_item	3671054	et	4	main
kultuuri	doc_491521502217_item	3671049	et	4	main
kuulusid	doc_491521502217_item	3671045	et	4	main
eestlased	doc_491521502217_item	3671044	et	3	main
muistsed	doc_491521502217_item	3671043	et	3	main
savinõud	doc_491521502217_item	3671042	et	3	main
neoliitikumi	doc_491521502217_item	3671020	et	4	main
kui	doc_491521502217_item	3671009	et	3	main
iseloomusta	doc_491521502217_item	3671008	et	4	main
e	doc_491521502217_item	3670999	et	4	main
neoliitikum	doc_491521502217_item	3670998	et	3	main
pärnu	doc_491521502217_item	3670982	et	4	main
hülgeid	doc_491521502217_item	3670973	et	3	main
ning	doc_491521502217_item	3670972	et	3	main
vibudega	doc_491521502217_item	3670966	et	3	main
kütiti	doc_491521502217_item	3670958	et	3	main
koriluse	doc_491521502217_item	3670945	et	4	main
kalanduse	doc_491521502217_item	3670944	et	3	main
õhukesi	doc_491521502217_item	3670936	et	4	main
isikliku	doc_491521502234_item	3670812	et	3	main
inimeste	doc_491521502234_item	3670811	et	3	main
kuuluti	doc_491521502234_item	3670802	et	4	main
kas	doc_491521502234_item	3670801	et	3	main
sinna	doc_491521502234_item	3670800	et	3	main
ekp	doc_491521502234_item	3670799	et	4	main
partei	doc_491521502234_item	3670798	et	4	main
üks	doc_491521502234_item	3670797	et	3	main
tööjõu	doc_491521502234_item	3670792	et	3	main
seast	doc_491521502234_item	3670788	et	4	main
lihtrahva	doc_491521502234_item	3670783	et	3	main
rahva	doc_491521502234_item	3670780	et	3	main
küüditati	doc_491521502234_item	3670778	et	3	main
energeetika	doc_491521502234_item	3670772	et	4	main
seoses	doc_491521502234_item	3670771	et	4	main
nälgimise	doc_491521502234_item	3670764	et	4	main
kui	doc_491521502234_item	3670762	et	3	main
tegelikkuses	doc_491521502234_item	3670757	et	4	main
ühisomandisse	doc_491521502234_item	3670755	et	3	main
anda	doc_491521502234_item	3670754	et	3	main
muudeti	doc_491521502234_item	3670750	et	3	main
loomine	doc_491521502234_item	3670748	et	4	main
majand	doc_491521502234_item	3670747	et	3	main
jne	doc_491521502234_item	3670739	et	4	main
riigiomand	doc_491521502234_item	3670732	et	3	main
üle	doc_491521502234_item	3670730	et	3	main
ettenähtud	doc_491521502234_item	3670728	et	4	main
on	doc_491521502234_item	3670727	et	4	main
annab	doc_491521502234_item	3670718	et	3	main
riik	doc_491521502234_item	3670717	et	3	main
plaanimaj	doc_491521502234_item	3670716	et	4	main
ensv	doc_491521502234_item	3670711	et	4	main
leerimine	doc_491521502234_item	3670710	et	4	main
kodutütred	doc_491521502234_item	3670709	et	3	main
noorkotkad	doc_491521502234_item	3670708	et	3	main
skaudid	doc_491521502234_item	3670707	et	3	main
gaidid	doc_491521502234_item	3670706	et	3	main
ümbernimetamine	doc_491521502234_item	3670705	et	3	main
tänavanimede	doc_491521502234_item	3670704	et	3	main
külanõukogu	doc_491521502234_item	3670703	et	4	main
vald	doc_491521502234_item	3670702	et	3	main
auks	doc_491521502234_item	3670701	et	3	main
tausta	doc_491521502234_item	3670671	et	4	main
lipu	doc_491521502234_item	3670670	et	3	main
poliitikaga	doc_491521502234_item	3670658	et	3	main
ja	doc_491521502234_item	3670657	et	3	main
riigiasjade	doc_491521502234_item	3670656	et	3	main
ainult	doc_491521502234_item	3670655	et	4	main
oma	doc_491521502234_item	3670649	et	4	main
saab	doc_491521502234_item	3670648	et	3	main
demokraatia	doc_491521502234_item	3670642	et	4	main
erialadel	doc_491521502234_item	3670635	et	3	main
spetsiifilistel	doc_491521502234_item	3670631	et	3	main
kasutati	doc_491521502234_item	3670629	et	4	main
müüs	doc_491521502234_item	3670627	et	4	main
siis	doc_491521502234_item	3670626	et	3	main
jäi	doc_491521502234_item	3670625	et	3	main
üle	doc_491521502234_item	3670624	et	3	main
kui	doc_491521502234_item	3670623	et	3	main
loomi	doc_491521502234_item	3670622	et	4	main
ev	doc_491521502234_item	3670606	et	4	main
1	doc_491521502234_item	3670605	et	2	main
alla	doc_491521502234_item	3670604	et	3	main
jälle	doc_491521502234_item	3670596	et	3	main
kunstiinimesi	doc_491521502234_item	3670585	et	4	main
liitudest	doc_491521502234_item	3670578	et	3	main
rehalibiteeriti	doc_491521502234_item	3670575	et	4	main
ensv	doc_491521502234_item	3670563	et	4	main
kui	doc_491521502234_item	3670562	et	3	main
mõeldakse	doc_491521502234_item	3670561	et	3	main
kultuur	doc_491521502217_item	3671248	et	3	main
kammkeraamika	doc_491521502217_item	3671243	et	4	main
enne	doc_491521502217_item	3671235	et	4	main
ajaloole	doc_491521502217_item	3671234	et	4	main
arheoloogilistel	doc_491521502217_item	3671220	et	4	main
kultuur	doc_491521502217_item	3671219	et	3	main
sõjakamaks	doc_491521502217_item	3671214	et	4	main
iv	doc_491521502217_item	3671138	et	4	main
matmiskombed	doc_491521502217_item	3671137	et	3	main
omapärased	doc_491521502217_item	3671136	et	4	main
üheks	doc_491521502217_item	3671130	et	3	main
varatuteks	doc_491521502234_item	3670751	et	4	main
inimesed	doc_491521502234_item	3670749	et	3	main
vabrikuid	doc_491521502234_item	3670735	et	3	main
kõike	doc_491521502234_item	3670734	et	4	main
nsvl-s	doc_491521502234_item	3670713	et	3	main
kogu	doc_491521502234_item	3670712	et	4	main
muutusid	doc_491521502234_item	3670694	et	4	main
mis	doc_491521502234_item	3670675	et	4	main
parteid	doc_491521502234_item	3670653	et	4	main
valida	doc_491521502234_item	3670652	et	3	main
rahvas	doc_491521502234_item	3670647	et	4	main
partei	doc_491521502234_item	3670645	et	4	main
mitme	doc_491521502234_item	3670644	et	4	main
võitlus	doc_491521502234_item	3670643	et	3	main
eesti	doc_491521502234_item	3670638	et	4	main
spetsialiste	doc_491521502234_item	3670637	et	3	main
mille	doc_491521502234_item	3670636	et	3	main
võõrtööjõudu	doc_491521502234_item	3670628	et	4	main
vastavalt	doc_491521502234_item	3670611	et	4	main
toodetakse	doc_491521502234_item	3670610	et	3	main
tohtis	doc_491521502234_item	3670595	et	3	main
said	doc_491521502234_item	3670586	et	4	main
eu	doc_491521502234_item	3670579	et	4	main
2	doc_491521502234_item	3670569	et	2	main
sulast	doc_491521502234_item	3670568	et	4	main
hrustshovi	doc_491521502234_item	3670567	et	4	main
mida	doc_491521502234_item	3670560	et	4	main
ja	doc_491521502234_item	3670557	et	3	main
ensv	doc_491521502234_item	3670555	et	4	main
kultuur	doc_491521502217_item	3671244	et	3	main
kultuur	doc_491521502217_item	3671242	et	3	main
kultuuridest	doc_491521502217_item	3671240	et	3	main
arheoloogilistest	doc_491521502217_item	3671239	et	4	main
näided	doc_491521502217_item	3671238	et	4	main
ning	doc_491521502217_item	3671227	et	3	main
eri	doc_491521502217_item	3671224	et	4	main
põhinev	doc_491521502217_item	3671223	et	4	main
muististel	doc_491521502217_item	3671222	et	3	main
leidudel	doc_491521502217_item	3671221	et	3	main
ta	doc_491521502217_item	3671215	et	4	main
tuhandel	doc_491521502217_item	3671140	et	3	main
alal	doc_491521502217_item	3671134	et	4	main
eesti	doc_491521502217_item	3671133	et	4	main
ka	doc_491521502217_item	3671132	et	3	main
tunnuseks	doc_491521502217_item	3671131	et	3	main
ja	doc_491521502217_item	3671122	et	3	main
valgusallikana	doc_491521502217_item	3671110	et	4	main
põtru	doc_491521502217_item	3671104	et	3	main
toiduallikas	doc_491521502217_item	3671102	et	4	main
algelist	doc_491521502217_item	3671082	et	4	main
kasutama	doc_491521502217_item	3671081	et	3	main
eluviis	doc_491521502217_item	3671075	et	3	main
amestav	doc_491521502217_item	3671074	et	4	main
neoliitikumis	doc_491521502217_item	3671070	et	3	main
valmistatud	doc_491521502217_item	3671057	et	4	main
teokarpidest	doc_491521502217_item	3671056	et	3	main
ja	doc_491521502217_item	3671055	et	3	main
koonusekujulised	doc_491521502217_item	3671041	et	4	main
nöörivajutistega	doc_491521502217_item	3671040	et	3	main
kultuurikiht	doc_491521502217_item	3671016	et	3	main
paremini	doc_491521502217_item	3671007	et	4	main
10	doc_491521502217_item	3670994	et	2	main
kultuur	doc_491521502217_item	3670992	et	3	main
et	doc_491521502217_item	3670990	et	3	main
väita	doc_491521502217_item	3670989	et	4	main
põhjal	doc_491521502217_item	3670987	et	4	main
jõe	doc_491521502217_item	3670983	et	3	main
on	doc_491521502217_item	3670975	et	4	main
kivist	doc_491521502217_item	3670961	et	4	main
ning	doc_491521502217_item	3670960	et	3	main
eestis	doc_491521502217_item	3670939	et	3	main
ii	doc_491521502217_item	3670895	et	4	main
aastatuhat	doc_491521502217_item	3670893	et	4	main
iii	doc_491521502217_item	3670892	et	4	main
ehk	doc_491521502217_item	3670888	et	3	main
ekr	doc_491521502217_item	3670887	et	4	main
at	doc_491521502217_item	3670886	et	4	main
viii	doc_491521502217_item	3670878	et	4	main
kiviaeg	doc_491521502217_item	3670877	et	3	main
sai	doc_491521502217_item	3671211	et	4	main
suhteline	doc_491521502217_item	3671191	et	4	main
oli	doc_491521502217_item	3671188	et	3	main
ei	doc_491521502234_item	3670640	et	4	main
lihtsalt	doc_491521502234_item	3670639	et	4	main
näit	doc_491521502234_item	3670633	et	3	main
põldu	doc_491521502234_item	3670618	et	4	main
oma	doc_491521502234_item	3670617	et	4	main
haris	doc_491521502234_item	3670616	et	3	main
mees	doc_491521502234_item	3670615	et	4	main
iga	doc_491521502234_item	3670614	et	4	main
vajadustele	doc_491521502234_item	3670612	et	4	main
eraomand	doc_491521502234_item	3670613	et	3	main
vabamaj	doc_491521502234_item	3670609	et	4	main
kroon	doc_491521502234_item	3670608	et	3	main
under	doc_491521502234_item	3670598	et	4	main
keelatud	doc_491521502234_item	3670593	et	4	main
mõningaid	doc_491521502234_item	3670590	et	3	main
tagasi	doc_491521502234_item	3670589	et	3	main
staatuse	doc_491521502234_item	3670588	et	3	main
oma	doc_491521502234_item	3670587	et	4	main
stalini	doc_491521502234_item	3670576	et	4	main
näiteks	doc_491521502234_item	3670574	et	4	main
vabamaks	doc_491521502234_item	3670573	et	4	main
muutus	doc_491521502234_item	3670571	et	4	main
kutluuriajaloos	doc_491521502234_item	3670564	et	4	main
2	doc_491521502234_item	3670559	et	2	main
ja	doc_491521502234_item	3670554	et	3	main
erinevused	doc_491521502234_item	3670552	et	4	main
peamised	doc_491521502234_item	3670551	et	3	main
välja	doc_491521502234_item	3670550	et	4	main
tooge	doc_491521502234_item	3670549	et	3	main
1	doc_491521502234_item	3670548	et	2	main
kontrolltöö	doc_491521502234_item	3670547	et	4	main
muutus	doc_491521502234_item	3670669	et	4	main
sümboolika	doc_491521502234_item	3670668	et	4	main
riigi	doc_491521502234_item	3670667	et	3	main
riigikogu	doc_491521502234_item	3670666	et	4	main
101-liikmeline	doc_491521502234_item	3670665	et	4	main
raha	doc_491521502234_item	3670664	et	4	main
loeb	doc_491521502234_item	3670663	et	3	main
kodanikele	doc_491521502234_item	3670662	et	3	main
kõigile	doc_491521502234_item	3670661	et	4	main
võimalused	doc_491521502234_item	3670660	et	3	main
ühesugund	doc_491521502234_item	3670659	et	4	main
nöörkeraamika	doc_491521502217_item	3671245	et	4	main
arheoloogiline	doc_491521502217_item	3671230	et	4	main
kultuur	doc_491521502217_item	3671229	et	3	main
arheoloogiline	doc_491521502217_item	3671218	et	4	main
seda	doc_491521502217_item	3671213	et	3	main
isegi	doc_491521502217_item	3671145	et	4	main
inimesi	doc_491521502217_item	3671143	et	4	main
maeti	doc_491521502217_item	3671142	et	3	main
ekr	doc_491521502217_item	3671141	et	4	main
aasta	doc_491521502217_item	3671139	et	4	main
neoliitikumi	doc_491521502217_item	3671129	et	4	main
indoeurooplastega	doc_491521502217_item	3671128	et	3	main
sarnanesid	doc_491521502217_item	3671120	et	4	main
kütiti	doc_491521502217_item	3671103	et	3	main
peamine	doc_491521502217_item	3671101	et	3	main
kuid	doc_491521502217_item	3671097	et	4	main
kalastamine	doc_491521502217_item	3671077	et	4	main
veel	doc_491521502217_item	3671072	et	4	main
omane	doc_491521502217_item	3671069	et	3	main
eestile	doc_491521502217_item	3671066	et	3	main
tunnuseks	doc_491521502217_item	3671051	et	3	main
selle	doc_491521502217_item	3671050	et	4	main
narva	doc_491521502217_item	3671048	et	4	main
ajajärgul	doc_491521502217_item	3671047	et	3	main
tol	doc_491521502217_item	3671046	et	3	main
tähtsamaks	doc_491521502217_item	3671021	et	4	main
näiteks	doc_491521502217_item	3671010	et	4	main
noorem	doc_491521502217_item	3671000	et	4	main
000	doc_491521502217_item	3670995	et	2	main
on	doc_491521502217_item	3670993	et	4	main
võib	doc_491521502217_item	3670988	et	3	main
asula	doc_491521502217_item	3670981	et	4	main
asula	doc_491521502217_item	3670979	et	4	main
esimene	doc_491521502217_item	3670978	et	3	main
mesoliitikumist	doc_491521502217_item	3670974	et	4	main
kalu	doc_491521502217_item	3670971	et	4	main
ning	doc_491521502217_item	3670968	et	3	main
kunda	doc_491521502217_item	3671247	et	4	main
kasutuselevõttu	doc_491521502217_item	3671237	et	4	main
kirja	doc_491521502217_item	3671236	et	4	main
materiaalne	doc_491521502217_item	3671228	et	3	main
rahvaste	doc_491521502217_item	3671225	et	4	main
2	doc_491521502217_item	3671217	et	2	main
muutus	doc_491521502217_item	3671216	et	4	main
inimene	doc_491521502217_item	3671212	et	3	main
europiidide	doc_491521502217_item	3671123	et	3	main
mongoliidide	doc_491521502217_item	3671121	et	3	main
inimesed	doc_491521502217_item	3671119	et	3	main
inimest	doc_491521502217_item	3671117	et	3	main
kasutati	doc_491521502217_item	3671109	et	4	main
rasva	doc_491521502217_item	3671108	et	4	main
hüljeste	doc_491521502217_item	3671107	et	3	main
karusid	doc_491521502217_item	3671106	et	3	main
see	doc_491521502217_item	3671098	et	3	main
hirssi	doc_491521502217_item	3671095	et	4	main
lelistellkividest	doc_491521502217_item	3671091	et	4	main
tulekivist	doc_491521502217_item	3671090	et	4	main
kivist	doc_491521502217_item	3671089	et	4	main
valdavalt	doc_491521502217_item	3671088	et	4	main
ajal	doc_491521502217_item	3671087	et	4	main
sel	doc_491521502217_item	3671086	et	3	main
tehti	doc_491521502217_item	3671085	et	3	main
tööriistad	doc_491521502217_item	3671084	et	3	main
sarnanesid	doc_491521502217_item	3671127	et	4	main
100	doc_491521502217_item	3671116	et	2	main
oli	doc_491521502217_item	3671114	et	3	main
kogukonnas	doc_491521502217_item	3671113	et	4	main
püstkodades	doc_491521502217_item	3671112	et	3	main
elati	doc_491521502217_item	3671111	et	3	main
metstarvast	doc_491521502217_item	3671105	et	4	main
ei	doc_491521502217_item	3671099	et	4	main
otri	doc_491521502217_item	3671096	et	3	main
nisu	doc_491521502217_item	3671094	et	4	main
kasvatati	doc_491521502217_item	3671093	et	3	main
põldude	doc_491521502217_item	3671092	et	4	main
hakati	doc_491521502217_item	3671080	et	3	main
kuid	doc_491521502217_item	3671079	et	4	main
korilus	doc_491521502217_item	3671078	et	4	main
jämedast	doc_491521502217_item	3671053	et	3	main
nöörkeraamika	doc_491521502217_item	3671039	et	4	main
levis	doc_491521502217_item	3671038	et	4	main
leitud	doc_491521502217_item	3671015	et	4	main
sel	doc_491521502217_item	3671013	et	3	main
eestit	doc_491521502217_item	3671005	et	3	main
võib	doc_491521502217_item	3671004	et	3	main
ajajärgul	doc_491521502217_item	3671003	et	3	main
sellel	doc_491521502217_item	3671002	et	4	main
kiviaeg	doc_491521502217_item	3671001	et	3	main
aastat	doc_491521502217_item	3670996	et	3	main
selle	doc_491521502217_item	3670985	et	4	main
lähedal	doc_491521502217_item	3670984	et	4	main
kõplapõllundust	doc_491521502217_item	3671083	et	4	main
valdavalt	doc_491521502217_item	3671073	et	4	main
on	doc_491521502217_item	3671065	et	4	main
kirvedega	doc_491521502217_item	3671064	et	4	main
kujuliste	doc_491521502217_item	3671063	et	4	main
pooside	doc_491521502217_item	3671062	et	3	main
kultuur	doc_491521502217_item	3671061	et	3	main
venekirve	doc_491521502217_item	3671060	et	3	main
ka	doc_491521502217_item	3671059	et	3	main
nõud	doc_491521502217_item	3671058	et	3	main
oli	doc_491521502217_item	3671052	et	3	main
ekr	doc_491521502217_item	3671037	et	4	main
at	doc_491521502217_item	3671036	et	4	main
iii	doc_491521502217_item	3671035	et	4	main
ning	doc_491521502217_item	3671034	et	3	main
nõud	doc_491521502217_item	3671033	et	3	main
alusega	doc_491521502217_item	3671032	et	4	main
koonuselise	doc_491521502217_item	3671031	et	4	main
kammivajutistega	doc_491521502217_item	3671030	et	4	main
kammkeraamika	doc_491521502217_item	3671029	et	4	main
levis	doc_491521502217_item	3671028	et	4	main
atekr	doc_491521502217_item	3671027	et	4	main
vi	doc_491521502217_item	3671026	et	4	main
kasutuselevõtt	doc_491521502217_item	3671025	et	3	main
keraamika	doc_491521502217_item	3671024	et	4	main
oli	doc_491521502217_item	3671023	et	3	main
tunnuseks	doc_491521502217_item	3671022	et	3	main
paksem	doc_491521502217_item	3671019	et	4	main
märksa	doc_491521502217_item	3671018	et	3	main
on	doc_491521502217_item	3671017	et	4	main
ajal	doc_491521502217_item	3671014	et	4	main
sest	doc_491521502217_item	3671012	et	4	main
mesoliitikul	doc_491521502217_item	3671011	et	4	main
palju	doc_491521502217_item	3671006	et	4	main
vana	doc_491521502217_item	3670997	et	4	main
eesti	doc_491521502217_item	3670991	et	4	main
leidude	doc_491521502217_item	3670986	et	4	main
eesti	doc_491521502217_item	3670977	et	4	main
pärit	doc_491521502217_item	3670976	et	3	main
harpuunidega	doc_491521502217_item	3670969	et	3	main
põtru	doc_491521502217_item	3670967	et	3	main
luust	doc_491521502217_item	3670959	et	4	main
ei	doc_491521502217_item	3670956	et	4	main
seeni	doc_491521502217_item	3670953	et	3	main
ja	doc_491521502217_item	3670951	et	3	main
marju	doc_491521502217_item	3670950	et	3	main
valdavalt	doc_491521502217_item	3670949	et	4	main
korjati	doc_491521502217_item	3670948	et	3	main
küttimisega	doc_491521502217_item	3670947	et	4	main
ning	doc_491521502217_item	3670946	et	3	main
mesoliitikumit	doc_491521502217_item	3670938	et	4	main
jäänud	doc_491521502217_item	3670935	et	4	main
tekkis	doc_491521502217_item	3670903	et	3	main
neoliitikum	doc_491521502217_item	3670891	et	3	main
kiviaeg	doc_491521502217_item	3670890	et	3	main
keskmine	doc_491521502217_item	3670889	et	3	main
pulli	doc_491521502217_item	3670980	et	4	main
püüti	doc_491521502217_item	3670970	et	3	main
puust	doc_491521502217_item	3670965	et	4	main
ning	doc_491521502217_item	3670964	et	3	main
praktiliselt	doc_491521502217_item	3670955	et	4	main
juurikaid	doc_491521502217_item	3670952	et	4	main
iseloomustada	doc_491521502217_item	3670941	et	4	main
võib	doc_491521502217_item	3670940	et	3	main
eriti	doc_491521502217_item	3670930	et	3	main
baltimaades	doc_491521502217_item	3670929	et	4	main
kuigi	doc_491521502217_item	3670928	et	3	main
puudus	doc_491521502217_item	3670927	et	4	main
inimasustus	doc_491521502217_item	3670926	et	3	main
eestis	doc_491521502217_item	3670925	et	3	main
ajal	doc_491521502217_item	3670924	et	4	main
paleoliitikumi	doc_491521502217_item	3670923	et	4	main
asjad	doc_491521502217_item	3670922	et	3	main
savist	doc_491521502217_item	3670921	et	4	main
ja	doc_491521502217_item	3670920	et	3	main
luust	doc_491521502217_item	3670919	et	4	main
on	doc_491521502217_item	3670918	et	4	main
tunnuseks	doc_491521502217_item	3670917	et	3	main
kultuurisse	doc_491521502217_item	3670916	et	3	main
kunda	doc_491521502217_item	3670915	et	4	main
ajal	doc_491521502217_item	3670914	et	4	main
mesoliitikumi	doc_491521502217_item	3670913	et	4	main
eesti	doc_491521502217_item	3670912	et	4	main
kuulus	doc_491521502217_item	3670911	et	4	main
poolest	doc_491521502217_item	3670910	et	4	main
kultuuri	doc_491521502217_item	3670909	et	4	main
arheoloogilise	doc_491521502217_item	3670908	et	4	main
ajal	doc_491521502217_item	3670907	et	4	main
mesoliitikumi	doc_491521502217_item	3670906	et	4	main
alles	doc_491521502217_item	3670905	et	3	main
nooleotsiga	doc_491521502217_item	3670963	et	4	main
valmistatud	doc_491521502217_item	3670962	et	4	main
tarvitatud	doc_491521502217_item	3670957	et	4	main
soogiks	doc_491521502217_item	3670954	et	4	main
praktiliselt	doc_491521502217_item	3670943	et	4	main
tegeldi	doc_491521502217_item	3670942	et	3	main
kultuurikihti	doc_491521502217_item	3670937	et	4	main
muistsetelt	doc_491521502217_item	3670933	et	3	main
leiti	doc_491521502217_item	3670932	et	3	main
leedus	doc_491521502217_item	3670931	et	4	main
elu	doc_491521502217_item	3670904	et	4	main
alal	doc_491521502217_item	3670902	et	4	main
eesti	doc_491521502217_item	3670901	et	4	main
kiviaeg	doc_491521502217_item	3670899	et	3	main
ekr	doc_491521502217_item	3670884	et	4	main
mesoliitikum	doc_491521502217_item	3670881	et	3	main
osavamaks	doc_491521502217_item	3671210	et	4	main
ja	doc_491521502217_item	3671209	et	3	main
puudus	doc_491521502217_item	3671198	et	4	main
varanduse	doc_491521502217_item	3671190	et	3	main
selle	doc_491521502217_item	3671186	et	4	main
ajaloos	doc_491521502217_item	3671185	et	4	main
kui	doc_491521502217_item	3671177	et	3	main
iseloomustada	doc_491521502217_item	3671176	et	4	main
võib	doc_491521502217_item	3671175	et	3	main
surma	doc_491521502217_item	3671172	et	4	main
elusse	doc_491521502217_item	3671170	et	3	main
usuti	doc_491521502217_item	3671169	et	3	main
kujusid	doc_491521502217_item	3671168	et	3	main
animeeritud	doc_491521502217_item	3671167	et	4	main
1	doc_491521502217_item	3670861	et	2	main
kontrolltöö	doc_491521502217_item	3670860	et	4	main
tähendust	doc_491521502206_item	3671479	et	4	main
esimesed	doc_491521502206_item	3671473	et	3	main
ristikujulisi	doc_491521502206_item	3671469	et	4	main
lõpus	doc_491521502206_item	3671456	et	4	main
vikingi	doc_491521502206_item	3671454	et	4	main
vilju	doc_491521502206_item	3671444	et	4	main
suuri	doc_491521502206_item	3671439	et	3	main
ja	doc_491521502206_item	3671436	et	3	main
mis	doc_491521502206_item	3671434	et	4	main
ole	doc_491521502206_item	3671432	et	4	main
ei	doc_491521502206_item	3671431	et	4	main
suuri	doc_491521502206_item	3671425	et	3	main
tähtsaks	doc_491521502206_item	3671423	et	4	main
peeti	doc_491521502206_item	3671421	et	4	main
eest	doc_491521502206_item	3671417	et	4	main
kurja	doc_491521502206_item	3671415	et	4	main
tõenäoliselt	doc_491521502206_item	3671407	et	4	main
kus	doc_491521502206_item	3671406	et	3	main
tähendus	doc_491521502206_item	3671373	et	4	main
suur	doc_491521502206_item	3671372	et	3	main
tähendust	doc_491521502206_item	3671371	et	4	main
kindlat	doc_491521502206_item	3671370	et	3	main
ainult	doc_491521502206_item	3671355	et	4	main
ei	doc_491521502206_item	3671352	et	4	main
saada	doc_491521502206_item	3671340	et	4	main
esivanemaid	doc_491521502206_item	3671335	et	4	main
surnuid	doc_491521502206_item	3671334	et	4	main
jooneks	doc_491521502206_item	3671326	et	3	main
väga	doc_491521502206_item	3671324	et	3	main
oli	doc_491521502206_item	3671322	et	3	main
arheoloogilised	doc_491521502206_item	3671285	et	4	main
kui	doc_491521502206_item	3671282	et	3	main
palju	doc_491521502206_item	3671279	et	4	main
päris	doc_491521502206_item	3671278	et	4	main
homo	doc_491521502206_item	3671271	et	4	main
mis	doc_491521502206_item	3671256	et	4	main
2	doc_491521502206_item	3671255	et	2	main
midagi	doc_491521502206_item	3671584	et	4	main
ühte	doc_491521502206_item	3671575	et	4	main
seda	doc_491521502206_item	3671569	et	3	main
kalapüügist	doc_491521502206_item	3671532	et	3	main
toitusid	doc_491521502206_item	3671528	et	4	main
tipphetk	doc_491521502206_item	3671521	et	3	main
ja	doc_491521502194_item	3671844	et	3	main
kuu	doc_491521502194_item	3671836	et	4	main
iga	doc_491521502194_item	3671835	et	4	main
väga	doc_491521502194_item	3671830	et	3	main
ajalooline	doc_491521502194_item	3671826	et	4	main
välja	doc_491521502194_item	3671824	et	4	main
inimestel	doc_491521502217_item	3670934	et	3	main
praeguse	doc_491521502217_item	3670900	et	3	main
ekr	doc_491521502217_item	3670894	et	4	main
ix	doc_491521502217_item	3670882	et	4	main
at	doc_491521502217_item	3670879	et	4	main
mida	doc_491521502217_item	3671207	et	4	main
hõre	doc_491521502217_item	3671206	et	3	main
oli	doc_491521502217_item	3671205	et	3	main
ei	doc_491521502217_item	3671194	et	4	main
eesti	doc_491521502217_item	3671184	et	4	main
vähe	doc_491521502217_item	3671183	et	3	main
oli	doc_491521502217_item	3671182	et	3	main
sõdu	doc_491521502217_item	3671181	et	3	main
eestis	doc_491521502217_item	3671174	et	3	main
usuga	doc_491521502206_item	3671477	et	3	main
arvatavasti	doc_491521502206_item	3671471	et	3	main
ehteid	doc_491521502206_item	3671470	et	3	main
leitud	doc_491521502206_item	3671468	et	4	main
rohkesti	doc_491521502206_item	3671467	et	3	main
on	doc_491521502206_item	3671466	et	4	main
alates	doc_491521502206_item	3671465	et	3	main
aja	doc_491521502206_item	3671455	et	4	main
tekkima	doc_491521502206_item	3671453	et	3	main
hakkavad	doc_491521502206_item	3671452	et	4	main
esivanemate	doc_491521502206_item	3671446	et	4	main
surnutele	doc_491521502206_item	3671442	et	4	main
jne	doc_491521502206_item	3671441	et	4	main
mis	doc_491521502206_item	3671437	et	4	main
põhjusega	doc_491521502206_item	3671435	et	3	main
millestesse	doc_491521502206_item	3671427	et	4	main
töövahendeid	doc_491521502206_item	3671420	et	3	main
tööriistu	doc_491521502206_item	3671419	et	3	main
läinud	doc_491521502206_item	3671410	et	4	main
selle	doc_491521502206_item	3671379	et	4	main
merevaigul	doc_491521502206_item	3671377	et	3	main
jaoks	doc_491521502206_item	3671376	et	4	main
eestlaste	doc_491521502206_item	3671375	et	4	main
oli	doc_491521502206_item	3671374	et	3	main
mis	doc_491521502206_item	3671367	et	4	main
ehteid	doc_491521502206_item	3671366	et	3	main
surnutele	doc_491521502206_item	3671363	et	4	main
on	doc_491521502206_item	3671361	et	4	main
ajast	doc_491521502206_item	3671357	et	4	main
kristlaste	doc_491521502206_item	3671356	et	3	main
kaasa	doc_491521502206_item	3671344	et	4	main
anti	doc_491521502206_item	3671343	et	3	main
inimestele	doc_491521502206_item	3671342	et	3	main
matmispaikadelt	doc_491521502206_item	3671341	et	3	main
väga	doc_491521502206_item	3671336	et	3	main
muistsed	doc_491521502206_item	3671330	et	3	main
arheoloogilisi	doc_491521502206_item	3671273	et	4	main
religiosusega	doc_491521502206_item	3671272	et	4	main
et	doc_491521502206_item	3671267	et	3	main
on	doc_491521502206_item	3671265	et	4	main
arva	doc_491521502206_item	3671264	et	4	main
ajaloolased	doc_491521502206_item	3671263	et	3	main
ning	doc_491521502206_item	3671262	et	3	main
arheoloogid	doc_491521502206_item	3671261	et	3	main
paljud	doc_491521502206_item	3671260	et	3	main
seal	doc_491521502206_item	3671579	et	4	main
puhkama	doc_491521502206_item	3671578	et	3	main
jäeti	doc_491521502206_item	3671577	et	3	main
kuid	doc_491521502206_item	3671535	et	4	main
ning	doc_491521502206_item	3671533	et	3	main
saj	doc_491521502206_item	3671526	et	4	main
õpiti	doc_491521502194_item	3671842	et	3	main
7	doc_491521502194_item	3671840	et	2	main
loengud	doc_491521502194_item	3671837	et	3	main
oli	doc_491521502194_item	3671829	et	3	main
filosoofiat	doc_491521502194_item	3671820	et	3	main
õppida	doc_491521502194_item	3671815	et	3	main
õppida	doc_491521502194_item	3671806	et	3	main
klassi	doc_491521502194_item	3671802	et	4	main
õppida	doc_491521502194_item	3671799	et	3	main
ainult	doc_491521502194_item	3671792	et	4	main
õppida	doc_491521502194_item	3671791	et	3	main
said	doc_491521502194_item	3671790	et	4	main
gümnaasiumis	doc_491521502194_item	3671789	et	3	main
gümnaasium	doc_491521502194_item	3671788	et	3	main
esimene	doc_491521502194_item	3671787	et	3	main
tartusse	doc_491521502194_item	3671786	et	3	main
noorem	doc_491521502217_item	3670898	et	4	main
ehk	doc_491521502217_item	3670897	et	3	main
atek	doc_491521502217_item	3670896	et	4	main
iv	doc_491521502217_item	3670885	et	4	main
at	doc_491521502217_item	3670883	et	4	main
ekr	doc_491521502217_item	3670880	et	4	main
rikkamaks	doc_491521502217_item	3671208	et	4	main
söögiülejääke	doc_491521502217_item	3671193	et	4	main
osaliselt	doc_491521502217_item	3671189	et	4	main
kiviaega	doc_491521502217_item	3671173	et	4	main
pärast	doc_491521502217_item	3671171	et	4	main
et	doc_491521502206_item	3671481	et	3	main
mingit	doc_491521502206_item	3671476	et	3	main
matmiskombed	doc_491521502206_item	3671474	et	3	main
ajast	doc_491521502206_item	3671464	et	4	main
rändavatelt	doc_491521502206_item	3671460	et	4	main
mungadelt	doc_491521502206_item	3671459	et	4	main
aa	doc_491521502206_item	3671458	et	3	main
800-1030	doc_491521502206_item	3671457	et	2	main
eesmärgiga	doc_491521502206_item	3671438	et	3	main
teada	doc_491521502206_item	3671433	et	3	main
tehti	doc_491521502206_item	3671428	et	3	main
aitasid	doc_491521502206_item	3671414	et	4	main
ellu	doc_491521502206_item	3671405	et	4	main
maagilistesse	doc_491521502206_item	3671380	et	4	main
usuti	doc_491521502206_item	3671378	et	3	main
oma	doc_491521502206_item	3671369	et	4	main
omasid	doc_491521502206_item	3671368	et	4	main
pandud	doc_491521502206_item	3671362	et	4	main
varem	doc_491521502206_item	3671360	et	4	main
ka	doc_491521502206_item	3671359	et	3	main
vaid	doc_491521502206_item	3671358	et	3	main
ole	doc_491521502206_item	3671353	et	4	main
rist	doc_491521502206_item	3671351	et	3	main
võib	doc_491521502206_item	3671339	et	3	main
oma	doc_491521502206_item	3671333	et	4	main
see	doc_491521502206_item	3671328	et	3	main
teised	doc_491521502206_item	3671284	et	4	main
ka	doc_491521502206_item	3671283	et	3	main
asustus	doc_491521502217_item	3671204	et	4	main
inimeste	doc_491521502217_item	3671203	et	3	main
ka	doc_491521502217_item	3671202	et	3	main
sõjaks	doc_491521502217_item	3671201	et	3	main
motiiv	doc_491521502217_item	3671200	et	3	main
otsene	doc_491521502217_item	3671199	et	3	main
seega	doc_491521502217_item	3671197	et	4	main
ja	doc_491521502217_item	3671196	et	3	main
tekkinud	doc_491521502217_item	3671195	et	4	main
nappus	doc_491521502217_item	3671192	et	4	main
perioodi	doc_491521502217_item	3671180	et	4	main
ning	doc_491521502217_item	3671166	et	3	main
kujukesi	doc_491521502217_item	3671165	et	4	main
ehteid	doc_491521502217_item	3671164	et	3	main
tööriistu	doc_491521502217_item	3671163	et	3	main
kaasa	doc_491521502217_item	3671162	et	4	main
pandi	doc_491521502217_item	3671161	et	4	main
surnutele	doc_491521502217_item	3671160	et	4	main
magamisasendit	doc_491521502217_item	3671159	et	3	main
inimeste	doc_491521502217_item	3671158	et	3	main
matkida	doc_491521502217_item	3671157	et	3	main
püüti	doc_491521502217_item	3671156	et	3	main
matmisel	doc_491521502217_item	3671155	et	4	main
väljaspool	doc_491521502217_item	3671154	et	3	main
külast	doc_491521502217_item	3671153	et	4	main
surnuid	doc_491521502217_item	3671152	et	4	main
maeti	doc_491521502217_item	3671151	et	3	main
levimisel	doc_491521502217_item	3671150	et	4	main
kultuuri	doc_491521502217_item	3671149	et	4	main
nöörkeraamika	doc_491521502217_item	3671148	et	4	main
alla	doc_491521502217_item	3671147	et	3	main
vanem	doc_491521502217_item	3670876	et	4	main
ehk	doc_491521502217_item	3670875	et	3	main
paleoliitikum	doc_491521502217_item	3670874	et	3	main
periodiseerida	doc_491521502217_item	3670873	et	3	main
võib	doc_491521502217_item	3670872	et	3	main
kiviaega	doc_491521502217_item	3670871	et	4	main
1	doc_491521502217_item	3670870	et	2	main
tähendus	doc_491521502217_item	3670869	et	4	main
kultuur	doc_491521502217_item	3670868	et	3	main
arheoloogiline	doc_491521502217_item	3670867	et	4	main
mõiste	doc_491521502217_item	3670866	et	4	main
2	doc_491521502217_item	3670865	et	2	main
põhjuseks	doc_491521502217_item	3671187	et	3	main
rahulikku	doc_491521502217_item	3671179	et	4	main
suhteliselt	doc_491521502217_item	3671178	et	4	main
territooriumil	doc_491521502217_item	3670864	et	3	main
see	doc_491521502206_item	3671480	et	3	main
ka	doc_491521502206_item	3671472	et	3	main
levitajatelt	doc_491521502206_item	3671462	et	4	main
religiooni	doc_491521502206_item	3671461	et	4	main
kristlaste	doc_491521502206_item	3671450	et	3	main
allikad	doc_491521502206_item	3671449	et	3	main
esimesed	doc_491521502206_item	3671448	et	3	main
puid	doc_491521502206_item	3671440	et	3	main
auke	doc_491521502206_item	3671429	et	4	main
mis	doc_491521502206_item	3671413	et	4	main
ehteid	doc_491521502206_item	3671412	et	3	main
nii	doc_491521502206_item	3671411	et	3	main
maavälisse	doc_491521502206_item	3671404	et	4	main
usuti	doc_491521502206_item	3671403	et	3	main
eesti	doc_491521502217_item	3670863	et	4	main
kiviaeg	doc_491521502217_item	3670862	et	3	main
tegemiseks	doc_491521502206_item	3671603	et	4	main
linade	doc_491521502206_item	3671602	et	3	main
ka	doc_491521502206_item	3671601	et	3	main
kasvatati	doc_491521502206_item	3671600	et	3	main
vilja	doc_491521502206_item	3671599	et	4	main
ja	doc_491521502206_item	3671598	et	3	main
jahut	doc_491521502206_item	3671597	et	4	main
teha	doc_491521502206_item	3671596	et	3	main
oskasid	doc_491521502206_item	3671595	et	4	main
inimesed	doc_491521502206_item	3671594	et	3	main
tolleaegsed	doc_491521502206_item	3671593	et	3	main
et	doc_491521502206_item	3671592	et	3	main
teada	doc_491521502206_item	3671591	et	3	main
veel	doc_491521502206_item	3671590	et	4	main
on	doc_491521502206_item	3671589	et	4	main
muidu	doc_491521502206_item	3671588	et	3	main
alepõllundus	doc_491521502206_item	3671587	et	3	main
koosneski	doc_491521502206_item	3671586	et	3	main
sellest	doc_491521502206_item	3671585	et	4	main
üks	doc_491521502206_item	3671582	et	3	main
seotud	doc_491521502206_item	3671478	et	4	main
kannavad	doc_491521502206_item	3671475	et	3	main
sellest	doc_491521502206_item	3671463	et	4	main
religioonist	doc_491521502206_item	3671451	et	3	main
lugupidamisele	doc_491521502206_item	3671447	et	3	main
viitab	doc_491521502206_item	3671445	et	3	main
ohverdati	doc_491521502206_item	3671443	et	3	main
veel	doc_491521502206_item	3671430	et	4	main
kive	doc_491521502206_item	3671426	et	3	main
loodusjõude	doc_491521502206_item	3671424	et	3	main
väga	doc_491521502206_item	3671422	et	3	main
kui	doc_491521502206_item	3671418	et	3	main
jõu	doc_491521502206_item	3671416	et	3	main
vaja	doc_491521502206_item	3671409	et	4	main
oleks	doc_491521502206_item	3671408	et	3	main
et	doc_491521502206_item	3671402	et	3	main
tähendab	doc_491521502206_item	3671401	et	3	main
ehteid	doc_491521502206_item	3671400	et	3	main
ja	doc_491521502206_item	3671399	et	3	main
tööriistu	doc_491521502206_item	3671398	et	3	main
kaasa	doc_491521502206_item	3671397	et	4	main
surnutele	doc_491521502206_item	3671396	et	4	main
panid	doc_491521502206_item	3671395	et	4	main
eestlased	doc_491521502206_item	3671394	et	3	main
muistsed	doc_491521502206_item	3671393	et	3	main
et	doc_491521502206_item	3671392	et	3	main
see	doc_491521502206_item	3671391	et	3	main
eesmärgiga	doc_491521502206_item	3671390	et	3	main
tervendava	doc_491521502206_item	3671389	et	4	main
merevaigu	doc_491521502206_item	3671388	et	3	main
kohale	doc_491521502206_item	3671387	et	4	main
silmade	doc_491521502206_item	3671386	et	3	main
pandi	doc_491521502206_item	3671385	et	4	main
surnutele	doc_491521502206_item	3671384	et	4	main
toimedesse	doc_491521502206_item	3671383	et	3	main
tervendavatesse	doc_491521502206_item	3671382	et	4	main
ristikujulisi	doc_491521502206_item	3671365	et	4	main
tuntud	doc_491521502206_item	3671354	et	4	main
näiteks	doc_491521502206_item	3671350	et	4	main
tähendusega	doc_491521502206_item	3671349	et	4	main
infot	doc_491521502206_item	3671338	et	3	main
austasid	doc_491521502206_item	3671332	et	4	main
et	doc_491521502206_item	3671329	et	3	main
äike	doc_491521502206_item	3671323	et	3	main
näiteks	doc_491521502206_item	3671287	et	4	main
leiud	doc_491521502206_item	3671286	et	3	main
matmiskombed	doc_491521502206_item	3671281	et	3	main
on	doc_491521502206_item	3671277	et	4	main
kohta	doc_491521502206_item	3671276	et	4	main
homo	doc_491521502206_item	3671268	et	4	main
aasta	doc_491521502206_item	3671583	et	4	main
kasvatatud	doc_491521502206_item	3671581	et	4	main
septembris	doc_491521502206_item	3671573	et	3	main
augustis	doc_491521502206_item	3671571	et	3	main
teisel	doc_491521502206_item	3671567	et	4	main
siis	doc_491521502206_item	3671527	et	3	main
keskmisel	doc_491521502206_item	3671523	et	3	main
põllunduse	doc_491521502206_item	3671520	et	3	main
lugema	doc_491521502194_item	3671845	et	4	main
ja	doc_491521502206_item	3671381	et	3	main
kaasa	doc_491521502206_item	3671364	et	4	main
maagilise	doc_491521502206_item	3671348	et	4	main
ehteid	doc_491521502206_item	3671347	et	3	main
ja	doc_491521502206_item	3671346	et	3	main
tööriistu	doc_491521502206_item	3671345	et	3	main
palju	doc_491521502206_item	3671337	et	4	main
eestlased	doc_491521502206_item	3671331	et	3	main
oli	doc_491521502206_item	3671327	et	3	main
iseloomustavaks	doc_491521502206_item	3671325	et	4	main
abi	doc_491521502206_item	3671321	et	4	main
ja	doc_491521502206_item	3671320	et	3	main
jõudu	doc_491521502206_item	3671319	et	4	main
paluti	doc_491521502206_item	3671318	et	3	main
millelt	doc_491521502206_item	3671317	et	3	main
loodusjõud	doc_491521502206_item	3671316	et	4	main
pronksiaeg	doc_491521502206_item	3671315	et	3	main
vanem	doc_491521502206_item	3671314	et	4	main
saaki	doc_491521502206_item	3671313	et	4	main
paremat	doc_491521502206_item	3671312	et	4	main
saada	doc_491521502206_item	3671311	et	4	main
et	doc_491521502206_item	3671310	et	3	main
selleks	doc_491521502206_item	3671309	et	4	main
sirpe	doc_491521502206_item	3671308	et	3	main
ohverdati	doc_491521502206_item	3671307	et	3	main
arvatavasti	doc_491521502206_item	3671306	et	3	main
ese	doc_491521502206_item	3671305	et	3	main
tähendusega	doc_491521502206_item	3671304	et	4	main
maagilise	doc_491521502206_item	3671303	et	4	main
ka	doc_491521502206_item	3671302	et	3	main
kuid	doc_491521502206_item	3671301	et	4	main
töövahend	doc_491521502206_item	3671300	et	3	main
ainult	doc_491521502206_item	3671299	et	4	main
olnud	doc_491521502206_item	3671298	et	4	main
ei	doc_491521502206_item	3671297	et	4	main
sirp	doc_491521502206_item	3671296	et	3	main
et	doc_491521502206_item	3671295	et	3	main
tähendab	doc_491521502206_item	3671294	et	3	main
see	doc_491521502206_item	3671293	et	3	main
sirpe	doc_491521502206_item	3671292	et	3	main
palju	doc_491521502206_item	3671291	et	4	main
leiti	doc_491521502206_item	3671290	et	3	main
jões	doc_491521502206_item	3671289	et	3	main
võhandu	doc_491521502206_item	3671288	et	4	main
nii	doc_491521502206_item	3671280	et	3	main
selle	doc_491521502206_item	3671275	et	4	main
tõendeid	doc_491521502206_item	3671274	et	3	main
veendunud	doc_491521502206_item	3671266	et	4	main
1	doc_491521502206_item	3671259	et	2	main
alepõllundus	doc_491521502206_item	3671258	et	3	main
on	doc_491521502206_item	3671257	et	4	main
kontrolltöö	doc_491521502206_item	3671250	et	4	main
ei	doc_491521502206_item	3671580	et	4	main
ja	doc_491521502206_item	3671574	et	3	main
istutati	doc_491521502206_item	3671570	et	3	main
osaks	doc_491521502206_item	3671562	et	3	main
kolmeks	doc_491521502206_item	3671561	et	4	main
jaotatud	doc_491521502206_item	3671560	et	4	main
oli	doc_491521502206_item	3671559	et	3	main
põld	doc_491521502206_item	3671558	et	3	main
kolmeväljasüsteem	doc_491521502206_item	3671557	et	3	main
kasutusel	doc_491521502206_item	3671556	et	4	main
oli	doc_491521502206_item	3671555	et	3	main
et	doc_491521502206_item	3671554	et	3	main
see	doc_491521502206_item	3671553	et	3	main
oli	doc_491521502206_item	3671552	et	3	main
tunnuseks	doc_491521502206_item	3671551	et	3	main
selle	doc_491521502206_item	3671550	et	4	main
alepõllundus	doc_491521502206_item	3671549	et	3	main
tekkis	doc_491521502206_item	3671548	et	3	main
ajal	doc_491521502206_item	3671547	et	4	main
sel	doc_491521502206_item	3671546	et	3	main
et	doc_491521502206_item	3671545	et	3	main
teada	doc_491521502206_item	3671544	et	3	main
on	doc_491521502206_item	3671543	et	4	main
põlluharimine	doc_491521502206_item	3671542	et	3	main
oli	doc_491521502206_item	3671541	et	3	main
tähelepanu	doc_491521502206_item	3671540	et	4	main
suuremat	doc_491521502206_item	3671539	et	4	main
pöörati	doc_491521502206_item	3671538	et	3	main
millele	doc_491521502206_item	3671537	et	3	main
tegevusala	doc_491521502206_item	3671536	et	4	main
võrdub	doc_491521502206_item	3671270	et	3	main
sapiens	doc_491521502206_item	3671269	et	4	main
üldiseloomustus	doc_491521502206_item	3671254	et	4	main
muinasusundi	doc_491521502206_item	3671253	et	3	main
eestlaste	doc_491521502206_item	3671252	et	4	main
1	doc_491521502206_item	3671251	et	2	main
osat	doc_491521502206_item	3671576	et	4	main
või	doc_491521502206_item	3671572	et	4	main
talverukkist	doc_491521502206_item	3671568	et	4	main
suverukkist	doc_491521502206_item	3671566	et	4	main
kasvatati	doc_491521502206_item	3671565	et	3	main
esimesel	doc_491521502206_item	3671564	et	3	main
ning	doc_491521502206_item	3671563	et	3	main
jahtimisest	doc_491521502206_item	3671534	et	4	main
viljast	doc_491521502206_item	3671531	et	4	main
rohkesti	doc_491521502206_item	3671530	et	3	main
muinasinimesed	doc_491521502206_item	3671529	et	3	main
9-13	doc_491521502206_item	3671525	et	2	main
kell	doc_491521502194_item	3671839	et	3	main
olid	doc_491521502194_item	3671834	et	4	main
eksamid	doc_491521502194_item	3671833	et	3	main
ülikoolis	doc_491521502194_item	3671828	et	4	main
trs	doc_491521502194_item	3671825	et	4	main
1680	doc_491521502194_item	3671821	et	2	main
ülikool	doc_491521502194_item	3671812	et	4	main
gümnaasiumisse	doc_491521502194_item	3671796	et	3	main
saada	doc_491521502194_item	3671795	et	4	main
tõlke	doc_491521502194_item	3671779	et	4	main
rajamine	doc_491521502194_item	3671768	et	4	main
mõisnikutele	doc_491521502194_item	3671743	et	4	main
1816	doc_491521502194_item	3671721	et	2	main
1837	doc_491521502194_item	3671719	et	2	main
aerulaevad	doc_491521502194_item	3671718	et	4	main
väikesed	doc_491521502194_item	3671713	et	4	main
põllum	doc_491521502194_item	3671703	et	4	main
falck	doc_491521502194_item	3671681	et	4	main
potsepaks	doc_491521502194_item	3671678	et	4	main
talupojad	doc_491521502194_item	3671658	et	4	main
saavad	doc_491521502194_item	3671652	et	4	main
nad	doc_491521502194_item	3671651	et	3	main
ja	doc_491521502194_item	3671650	et	3	main
raha	doc_491521502194_item	3671649	et	4	main
kasvatatakse	doc_491521502194_item	3671642	et	3	main
väga	doc_491521502194_item	3671638	et	3	main
saab	doc_491521502194_item	3671635	et	3	main
nende	doc_491521502194_item	3671623	et	4	main
eesti	doc_491521502194_item	3671611	et	4	main
taasavamise	doc_491521502194_item	3671609	et	4	main
eestofile	doc_491521502190_item	3672130	et	4	main
eesti	doc_491521502190_item	3672121	et	4	main
inimestele	doc_491521502190_item	3672120	et	3	main
arvates	doc_491521502190_item	3672111	et	4	main
minu	doc_491521502190_item	3672110	et	3	main
vägivalgne	doc_491521502190_item	3672103	et	4	main
muinasajast	doc_491521502190_item	3672096	et	4	main
eesti	doc_491521502190_item	3672095	et	4	main
merkel	doc_491521502190_item	3672092	et	4	main
tuleb	doc_491521502190_item	3672090	et	3	main
ja	doc_491521502190_item	3672082	et	3	main
cr	doc_491521502190_item	3672080	et	4	main
elu	doc_491521502190_item	3672075	et	4	main
ja	doc_491521502190_item	3672064	et	3	main
panuse	doc_491521502190_item	3672051	et	3	main
suure	doc_491521502190_item	3672050	et	3	main
tegi	doc_491521502190_item	3672049	et	4	main
hurt	doc_491521502190_item	3672048	et	3	main
j	doc_491521502190_item	3672047	et	4	main
ajalehes	doc_491521502190_item	3672046	et	3	main
töötas	doc_491521502190_item	3672032	et	3	main
lahkuda	doc_491521502190_item	3672030	et	3	main
suunatud	doc_491521502190_item	3672028	et	4	main
hurt	doc_491521502190_item	3672026	et	3	main
saavutamine	doc_491521502190_item	3672024	et	4	main
kõige	doc_491521502190_item	3672018	et	4	main
kultuur	doc_491521502190_item	3672012	et	3	main
põhimõttet	doc_491521502190_item	3672008	et	4	main
vastaspervedel	doc_491521502190_item	3672005	et	3	main
meelest	doc_491521502190_item	3671987	et	4	main
kuidagi	doc_491521502190_item	3671983	et	3	main
oma	doc_491521502190_item	3671972	et	4	main
võitlusele	doc_491521502190_item	3671971	et	3	main
rauaajal	doc_491521502206_item	3671524	et	3	main
oli	doc_491521502206_item	3671522	et	3	main
2	doc_491521502206_item	3671519	et	2	main
jne	doc_491521502206_item	3671518	et	4	main
paeladega	doc_491521502206_item	3671517	et	4	main
puid	doc_491521502206_item	3671516	et	3	main
inimesed	doc_491521502206_item	3671514	et	3	main
kus	doc_491521502206_item	3671513	et	3	main
ehtisid	doc_491521502206_item	3671515	et	4	main
religioonist	doc_491521502206_item	3671512	et	3	main
muinasaja	doc_491521502206_item	3671511	et	3	main
vaid	doc_491521502206_item	3671510	et	3	main
usundist	doc_491521502206_item	3671509	et	3	main
kristlaste	doc_491521502206_item	3671508	et	3	main
tule	doc_491521502206_item	3671507	et	4	main
ei	doc_491521502206_item	3671506	et	4	main
see	doc_491521502206_item	3671505	et	3	main
ehtimine	doc_491521502206_item	3671504	et	4	main
kuuse	doc_491521502206_item	3671503	et	4	main
ajal	doc_491521502206_item	3671502	et	4	main
jõulude	doc_491521502206_item	3671501	et	3	main
näiteks	doc_491521502206_item	3671500	et	4	main
kombeid	doc_491521502206_item	3671499	et	4	main
muistseestlaste	doc_491521502206_item	3671498	et	4	main
mõnesid	doc_491521502206_item	3671497	et	3	main
kasutame	doc_491521502206_item	3671496	et	3	main
me	doc_491521502206_item	3671495	et	4	main
tänapäevalgi	doc_491521502206_item	3671494	et	4	main
kaitstud	doc_491521502206_item	3671493	et	4	main
omamoodi	doc_491521502206_item	3671492	et	3	main
on	doc_491521502206_item	3671491	et	4	main
see	doc_491521502206_item	3671490	et	3	main
et	doc_491521502206_item	3671489	et	3	main
tähendama	doc_491521502206_item	3671488	et	3	main
ju	doc_491521502206_item	3671487	et	3	main
pidi	doc_491521502206_item	3671486	et	4	main
ümbritsetud	doc_491521502206_item	3671484	et	4	main
oli	doc_491521502206_item	3671483	et	3	main
kividega	doc_491521502206_item	3671485	et	3	main
matmispaik	doc_491521502206_item	3671482	et	3	main
välja	doc_491521502194_item	3671854	et	4	main
visati	doc_491521502194_item	3671853	et	3	main
seda	doc_491521502194_item	3671852	et	3	main
saanud	doc_491521502194_item	3671851	et	4	main
ei	doc_491521502194_item	3671850	et	4	main
aru	doc_491521502194_item	3671849	et	4	main
kes	doc_491521502194_item	3671848	et	4	main
keeles	doc_491521502194_item	3671847	et	4	main
ladina	doc_491521502194_item	3671846	et	4	main
raamat	doc_491521502194_item	3671827	et	3	main
ja	doc_491521502194_item	3671818	et	3	main
õigusteadust	doc_491521502194_item	3671816	et	4	main
võib	doc_491521502194_item	3671814	et	3	main
saanud	doc_491521502194_item	3671805	et	4	main
3	doc_491521502194_item	3671801	et	2	main
poisid	doc_491521502194_item	3671793	et	4	main
vaimulikke	doc_491521502194_item	3671782	et	3	main
on	doc_491521502194_item	3671777	et	4	main
tartusse	doc_491521502194_item	3671773	et	3	main
ülikooli	doc_491521502194_item	3671767	et	4	main
2	doc_491521502194_item	3671765	et	2	main
kõrtsmikud	doc_491521502194_item	3671764	et	3	main
nt	doc_491521502194_item	3671763	et	4	main
kõrvale	doc_491521502194_item	3671761	et	4	main
raha	doc_491521502194_item	3671760	et	4	main
oskasid	doc_491521502194_item	3671759	et	4	main
talupojad	doc_491521502194_item	3671758	et	4	main
nutikamad	doc_491521502194_item	3671757	et	4	main
elama	doc_491521502194_item	3671756	et	3	main
välismaale	doc_491521502194_item	3671755	et	4	main
kirjutama	doc_491521502194_item	3671843	et	3	main
hommikul	doc_491521502194_item	3671841	et	3	main
hakkasid	doc_491521502194_item	3671838	et	4	main
kord	doc_491521502194_item	3671832	et	4	main
range	doc_491521502194_item	3671831	et	4	main
a	doc_491521502194_item	3671822	et	4	main
arstiteadust	doc_491521502194_item	3671819	et	4	main
a	doc_491521502194_item	3671809	et	4	main
1632	doc_491521502194_item	3671808	et	2	main
tüdrukud	doc_491521502194_item	3671807	et	3	main
gümnaasiumis	doc_491521502194_item	3671803	et	3	main
et	doc_491521502194_item	3671794	et	3	main
a	doc_491521502194_item	3671770	et	4	main
1632	doc_491521502194_item	3671769	et	2	main
panna	doc_491521502194_item	3671762	et	4	main
või	doc_491521502194_item	3671754	et	4	main
minna	doc_491521502194_item	3671752	et	3	main
a	doc_491521502194_item	3671749	et	4	main
maad	doc_491521502194_item	3671741	et	4	main
perekonnanimed	doc_491521502194_item	3671740	et	3	main
panema	doc_491521502194_item	3671739	et	3	main
hakkati	doc_491521502194_item	3671738	et	3	main
müüa	doc_491521502194_item	3671737	et	3	main
osta	doc_491521502194_item	3671736	et	4	main
põhja-eesti	doc_491521502194_item	3671723	et	4	main
postkontorid	doc_491521502194_item	3671716	et	3	main
toodanguid	doc_491521502194_item	3671710	et	3	main
saavad	doc_491521502194_item	3671708	et	4	main
talupojad	doc_491521502194_item	3671707	et	4	main
endale	doc_491521502194_item	3671687	et	4	main
soetab	doc_491521502194_item	3671686	et	3	main
aga	doc_491521502194_item	3671685	et	3	main
puumeistrina	doc_491521502194_item	3671684	et	3	main
tööle	doc_491521502194_item	3671683	et	3	main
tuleb	doc_491521502194_item	3671682	et	3	main
jne	doc_491521502194_item	3671679	et	4	main
tööle	doc_491521502194_item	3671676	et	3	main
talurahvast	doc_491521502194_item	3671662	et	4	main
osta	doc_491521502194_item	3671655	et	4	main
talupojad	doc_491521502194_item	3671647	et	4	main
rahateenimisvõimalus	doc_491521502194_item	3671646	et	3	main
eestis	doc_491521502194_item	3671637	et	3	main
saj	doc_491521502194_item	3671629	et	4	main
19	doc_491521502194_item	3671628	et	2	main
tartu	doc_491521502194_item	3671607	et	4	main
1	doc_491521502194_item	3671606	et	2	main
mõjutas	doc_491521502190_item	3672131	et	3	main
ja	doc_491521502190_item	3672126	et	3	main
kirjutasid	doc_491521502190_item	3672118	et	4	main
nemad	doc_491521502190_item	3672117	et	3	main
sest	doc_491521502190_item	3672116	et	4	main
estofiilideks	doc_491521502190_item	3672115	et	3	main
pidada	doc_491521502190_item	3672114	et	4	main
baltisakslasi	doc_491521502190_item	3672113	et	3	main
võib	doc_491521502190_item	3672112	et	3	main
mainitud	doc_491521502190_item	3672101	et	4	main
esimest	doc_491521502190_item	3672098	et	4	main
raamatu	doc_491521502190_item	3672094	et	4	main
likvideerida	doc_491521502190_item	3672091	et	3	main
merkel	doc_491521502190_item	3672083	et	4	main
talupoegade	doc_491521502190_item	3672074	et	3	main
huvitatud	doc_491521502190_item	3672067	et	4	main
olid	doc_491521502190_item	3672066	et	4	main
hoolitsesid	doc_491521502190_item	3672061	et	4	main
kes	doc_491521502190_item	3672060	et	4	main
inimesed	doc_491521502190_item	3672059	et	3	main
need	doc_491521502190_item	3672058	et	3	main
olid	doc_491521502190_item	3672057	et	4	main
eestist	doc_491521502190_item	3672029	et	3	main
aga	doc_491521502190_item	3672021	et	3	main
tähtsam	doc_491521502190_item	3672019	et	4	main
arvates	doc_491521502190_item	3672017	et	4	main
jakobsoni	doc_491521502190_item	3672016	et	4	main
oli	doc_491521502190_item	3672013	et	3	main
jaoks	doc_491521502190_item	3672011	et	4	main
j	doc_491521502190_item	3672009	et	4	main
2	doc_491521502190_item	3672007	et	2	main
oli	doc_491521502190_item	3672006	et	3	main
mille	doc_491521502190_item	3672004	et	3	main
liikumises	doc_491521502190_item	3672001	et	4	main
tekkis	doc_491521502190_item	3671999	et	3	main
anti	doc_491521502194_item	3671823	et	3	main
usu-	doc_491521502194_item	3671817	et	4	main
ülikoolis	doc_491521502194_item	3671813	et	4	main
gümnaasiumist	doc_491521502194_item	3671811	et	4	main
muutub	doc_491521502194_item	3671810	et	3	main
ei	doc_491521502194_item	3671804	et	4	main
linnakoolis	doc_491521502194_item	3671800	et	4	main
tuli	doc_491521502194_item	3671798	et	4	main
sisse	doc_491521502194_item	3671797	et	4	main
asutati	doc_491521502194_item	3671785	et	4	main
1630	doc_491521502194_item	3671784	et	2	main
jumalateenistust	doc_491521502194_item	3671783	et	3	main
abistasid	doc_491521502194_item	3671781	et	4	main
kes	doc_491521502194_item	3671780	et	4	main
eesmärk	doc_491521502194_item	3671776	et	3	main
seminaar	doc_491521502194_item	3671775	et	4	main
asutati	doc_491521502194_item	3671772	et	4	main
1583a	doc_491521502194_item	3671771	et	4	main
tartu	doc_491521502194_item	3671766	et	4	main
linna	doc_491521502194_item	3671753	et	4	main
kuulusid	doc_491521502194_item	3671742	et	4	main
ei	doc_491521502194_item	3671734	et	4	main
omada	doc_491521502194_item	3671731	et	3	main
võimalus	doc_491521502194_item	3671730	et	3	main
a	doc_491521502194_item	3671722	et	4	main
a	doc_491521502194_item	3671706	et	4	main
1810	doc_491521502194_item	3671705	et	2	main
riiste	doc_491521502194_item	3671704	et	3	main
jõukad	doc_491521502194_item	3671657	et	3	main
tekkivad	doc_491521502194_item	3671656	et	4	main
maad	doc_491521502194_item	3671654	et	4	main
koolitada	doc_491521502194_item	3671778	et	3	main
jesuiitide	doc_491521502194_item	3671774	et	3	main
said	doc_491521502194_item	3671750	et	4	main
nad	doc_491521502194_item	3671733	et	3	main
a	doc_491521502194_item	3671720	et	4	main
poed	doc_491521502194_item	3671715	et	4	main
tekkivad	doc_491521502194_item	3671712	et	4	main
usku	doc_491521502194_item	3671664	et	4	main
muutma	doc_491521502194_item	3671663	et	3	main
1840a	doc_491521502194_item	3671659	et	4	main
koguvad	doc_491521502194_item	3671648	et	4	main
tulu	doc_491521502194_item	3671640	et	4	main
põhja	doc_491521502194_item	3671636	et	4	main
algul	doc_491521502194_item	3671630	et	4	main
see	doc_491521502194_item	3671622	et	3	main
vabastati	doc_491521502194_item	3671617	et	3	main
2	doc_491521502194_item	3671615	et	2	main
kultuurielule	doc_491521502194_item	3671614	et	3	main
tähtsus	doc_491521502194_item	3671610	et	4	main
ülikooli	doc_491521502194_item	3671608	et	4	main
nad	doc_491521502194_item	3671751	et	3	main
1832	doc_491521502194_item	3671748	et	2	main
rentima	doc_491521502194_item	3671747	et	3	main
maad	doc_491521502194_item	3671746	et	4	main
pidid	doc_491521502194_item	3671745	et	4	main
nad	doc_491521502194_item	3671744	et	3	main
saa	doc_491521502194_item	3671735	et	4	main
kinnisvara	doc_491521502194_item	3671732	et	4	main
on	doc_491521502194_item	3671729	et	4	main
talupoegadel	doc_491521502194_item	3671728	et	3	main
lõuna-eesti	doc_491521502194_item	3671727	et	4	main
a	doc_491521502194_item	3671726	et	4	main
vabaks1819	doc_491521502194_item	3671725	et	2	main
pärisorjuseks	doc_491521502194_item	3671724	et	3	main
postijaamad	doc_491521502194_item	3671717	et	3	main
poodnikud	doc_491521502194_item	3671714	et	3	main
müüa	doc_491521502194_item	3671711	et	3	main
oma	doc_491521502194_item	3671709	et	4	main
tikke	doc_491521502194_item	3671702	et	4	main
tootma	doc_491521502194_item	3671701	et	3	main
hakkatakse	doc_491521502194_item	3671700	et	4	main
tallinnas	doc_491521502194_item	3671699	et	4	main
jne	doc_491521502194_item	3671698	et	4	main
ketramismasinad	doc_491521502194_item	3671697	et	4	main
esimesed	doc_491521502194_item	3671696	et	3	main
vabriku	doc_491521502194_item	3671695	et	3	main
tõelise	doc_491521502194_item	3671694	et	4	main
esimese	doc_491521502194_item	3671693	et	3	main
narva	doc_491521502194_item	3671692	et	4	main
rajab	doc_491521502194_item	3671691	et	3	main
schwartz	doc_491521502194_item	3671690	et	4	main
vabriku	doc_491521502194_item	3671689	et	3	main
paberi	doc_491521502194_item	3671688	et	3	main
hans	doc_491521502194_item	3671680	et	4	main
rätsepaks	doc_491521502194_item	3671677	et	3	main
hakkavad	doc_491521502194_item	3671675	et	4	main
elanikud	doc_491521502194_item	3671674	et	3	main
linnas	doc_491521502194_item	3671673	et	4	main
igas	doc_491521502194_item	3671672	et	3	main
kasvama	doc_491521502194_item	3671671	et	3	main
hakkab	doc_491521502194_item	3671670	et	3	main
arv	doc_491521502194_item	3671669	et	3	main
linnaelanike	doc_491521502194_item	3671668	et	3	main
väljaostmine	doc_491521502194_item	3671667	et	3	main
talude	doc_491521502194_item	3671666	et	3	main
1860a	doc_491521502194_item	3671665	et	4	main
osa	doc_491521502194_item	3671661	et	4	main
hakkab	doc_491521502194_item	3671660	et	3	main
päriseks	doc_491521502194_item	3671653	et	4	main
head	doc_491521502194_item	3671639	et	4	main
kartulist	doc_491521502194_item	3671634	et	4	main
kasvatama	doc_491521502194_item	3671633	et	4	main
kartulit	doc_491521502194_item	3671632	et	3	main
hakatakse	doc_491521502194_item	3671631	et	3	main
jaoks	doc_491521502194_item	3671624	et	4	main
ja	doc_491521502194_item	3671620	et	3	main
pärisorjusest	doc_491521502194_item	3671619	et	4	main
ja	doc_491521502194_item	3671613	et	3	main
kontrolltöö	doc_491521502194_item	3671605	et	4	main
inimeste	doc_491521502190_item	3672128	et	3	main
siinsete	doc_491521502190_item	3672119	et	4	main
õnnetus	doc_491521502190_item	3672109	et	4	main
suur	doc_491521502190_item	3672108	et	3	main
jaoks	doc_491521502190_item	3672107	et	4	main
rahva	doc_491521502190_item	3672106	et	3	main
oli	doc_491521502190_item	3672105	et	3	main
ristitamine	doc_491521502190_item	3672104	et	4	main
tuntuimaid	doc_491521502190_item	3672076	et	4	main
selles	doc_491521502190_item	3672071	et	4	main
kultuuris	doc_491521502190_item	3672069	et	3	main
keelest	doc_491521502190_item	3672065	et	4	main
ajaloost	doc_491521502190_item	3672063	et	4	main
eestofilid	doc_491521502190_item	3672056	et	4	main
2	doc_491521502190_item	3672055	et	2	main
arengule	doc_491521502190_item	3672054	et	3	main
oli	doc_491521502190_item	3672027	et	3	main
j	doc_491521502190_item	3672025	et	4	main
oli	doc_491521502190_item	3672020	et	3	main
hurda	doc_491521502190_item	3672010	et	3	main
suur	doc_491521502190_item	3672002	et	3	main
ja	doc_491521502190_item	3671994	et	3	main
säilitamiseks	doc_491521502190_item	3671993	et	4	main
tema	doc_491521502190_item	3671986	et	4	main
sest	doc_491521502190_item	3671985	et	4	main
olnud	doc_491521502190_item	3671981	et	4	main
kirikut	doc_491521502190_item	3671977	et	3	main
ka	doc_491521502190_item	3671976	et	3	main
kritiseeris	doc_491521502190_item	3671975	et	3	main
eest	doc_491521502190_item	3671974	et	4	main
eemaldama	doc_491521502190_item	3671934	et	3	main
on	doc_491521502194_item	3671645	et	4	main
see	doc_491521502194_item	3671644	et	3	main
lina	doc_491521502194_item	3671643	et	4	main
lõuna-eestis	doc_491521502194_item	3671641	et	3	main
2	doc_491521502194_item	3671627	et	2	main
tähendas	doc_491521502194_item	3671626	et	3	main
sisuliselt	doc_491521502194_item	3671625	et	4	main
mida	doc_491521502194_item	3671621	et	4	main
eestlased	doc_491521502194_item	3671618	et	3	main
millal	doc_491521502194_item	3671616	et	3	main
haridus-	doc_491521502194_item	3671612	et	3	main
valgustusfilosoofia	doc_491521502190_item	3672132	et	4	main
haritas	doc_491521502190_item	3672124	et	4	main
et	doc_491521502190_item	3672102	et	3	main
kes	doc_491521502190_item	3672084	et	4	main
parandada	doc_491521502190_item	3672073	et	3	main
ning	doc_491521502190_item	3672070	et	3	main
eesti	doc_491521502190_item	3672062	et	4	main
kultuuri	doc_491521502190_item	3672053	et	4	main
silmaringi	doc_491521502190_item	3672129	et	4	main
laiendas	doc_491521502190_item	3672127	et	3	main
rahva	doc_491521502190_item	3672125	et	3	main
mis	doc_491521502190_item	3672123	et	4	main
keeles	doc_491521502190_item	3672122	et	4	main
oli	doc_491521502190_item	3672100	et	3	main
korda	doc_491521502190_item	3672099	et	4	main
kus	doc_491521502190_item	3672097	et	3	main
kirjutas	doc_491521502190_item	3672093	et	3	main
pärisorjuslikkorda	doc_491521502190_item	3672089	et	4	main
et	doc_491521502190_item	3672088	et	3	main
rääkima	doc_491521502190_item	3672087	et	3	main
hakkasid	doc_491521502190_item	3672086	et	4	main
esimestena	doc_491521502190_item	3672085	et	3	main
peetri	doc_491521502190_item	3672081	et	3	main
j	doc_491521502190_item	3672079	et	4	main
oli	doc_491521502190_item	3672078	et	3	main
neist	doc_491521502190_item	3672077	et	4	main
et	doc_491521502190_item	3672072	et	3	main
rahva	doc_491521502190_item	3672068	et	3	main
eesti	doc_491521502190_item	3672052	et	4	main
isegi	doc_491521502190_item	3672045	et	4	main
avaldatud	doc_491521502190_item	3672044	et	4	main
olnud	doc_491521502190_item	3672043	et	4	main
ei	doc_491521502190_item	3672042	et	4	main
see	doc_491521502190_item	3672041	et	3	main
kuid	doc_491521502190_item	3672040	et	4	main
epigrammi	doc_491521502190_item	3672039	et	4	main
kirjutas	doc_491521502190_item	3672038	et	3	main
ta	doc_491521502190_item	3672037	et	4	main
surma	doc_491521502190_item	3672036	et	4	main
jakobsoni	doc_491521502190_item	3672035	et	4	main
pärast	doc_491521502190_item	3672034	et	4	main
venemaal	doc_491521502190_item	3672033	et	4	main
ning	doc_491521502190_item	3672031	et	3	main
pöörde	doc_491521502190_item	3672023	et	3	main
kohal	doc_491521502190_item	3672015	et	4	main
määrav	doc_491521502190_item	3671996	et	4	main
kõlbluse	doc_491521502190_item	3671992	et	4	main
tähtis	doc_491521502190_item	3671991	et	4	main
väga	doc_491521502190_item	3671990	et	3	main
oli	doc_491521502190_item	3671989	et	3	main
religioon	doc_491521502190_item	3671988	et	3	main
nõus	doc_491521502190_item	3671984	et	4	main
ajalehe	doc_491521502190_item	3671932	et	3	main
kui	doc_491521502190_item	3671923	et	3	main
postimees	doc_491521502190_item	3671918	et	4	main
tegevusest	doc_491521502190_item	3671870	et	4	main
10-kroonise	doc_491521502190_item	3671864	et	4	main
1	doc_491521502190_item	3671857	et	2	main
nende	doc_491521502190_item	3671879	et	4	main
sotsiaal-majandusliku	doc_491521502190_item	3672022	et	3	main
esimesel	doc_491521502190_item	3672014	et	3	main
lõhe	doc_491521502190_item	3672003	et	4	main
rahvuse	doc_491521502190_item	3672000	et	3	main
sellega	doc_491521502190_item	3671982	et	3	main
ei	doc_491521502190_item	3671980	et	4	main
hurt	doc_491521502190_item	3671979	et	3	main
j	doc_491521502190_item	3671978	et	4	main
rahvast	doc_491521502190_item	3671970	et	4	main
äratas	doc_491521502190_item	3671969	et	3	main
et	doc_491521502190_item	3671968	et	3	main
sellele	doc_491521502190_item	3671967	et	4	main
lisaks	doc_491521502190_item	3671966	et	4	main
mis	doc_491521502190_item	3671965	et	4	main
ajalehte	doc_491521502190_item	3671964	et	4	main
sakala	doc_491521502190_item	3671963	et	4	main
andma	doc_491521502190_item	3671962	et	3	main
välja	doc_491521502190_item	3671961	et	4	main
jakobson	doc_491521502190_item	3671960	et	4	main
hakkas	doc_491521502190_item	3671959	et	3	main
a	doc_491521502190_item	3671958	et	4	main
1878	doc_491521502190_item	3671957	et	2	main
nimelt	doc_491521502190_item	3671956	et	4	main
tekkisid	doc_491521502190_item	3671954	et	4	main
konfliktid	doc_491521502190_item	3671955	et	3	main
vahel	doc_491521502190_item	3671953	et	4	main
nende	doc_491521502190_item	3671952	et	4	main
ka	doc_491521502190_item	3671951	et	3	main
kuid	doc_491521502190_item	3671950	et	4	main
vahel	doc_491521502190_item	3671949	et	4	main
nende	doc_491521502190_item	3671948	et	4	main
koostööd	doc_491521502190_item	3671947	et	4	main
tihedat	doc_491521502190_item	3671946	et	3	main
tingis	doc_491521502190_item	3671945	et	3	main
mis	doc_491521502190_item	3671944	et	4	main
väljapoole	doc_491521502190_item	3671943	et	3	main
ajalehe	doc_491521502190_item	3671942	et	3	main
hurt	doc_491521502190_item	3671941	et	3	main
ja	doc_491521502190_item	3671940	et	3	main
sattusid	doc_491521502190_item	3671938	et	4	main
jakobson	doc_491521502190_item	3671939	et	4	main
nii	doc_491521502190_item	3671937	et	3	main
mõlemaid	doc_491521502190_item	3671936	et	3	main
neid	doc_491521502190_item	3671935	et	4	main
nii	doc_491521502190_item	3671998	et	3	main
jõud	doc_491521502190_item	3671997	et	4	main
vaimuelu	doc_491521502190_item	3671995	et	4	main
õiguste	doc_491521502190_item	3671973	et	4	main
oli	doc_491521502190_item	3671930	et	3	main
ka	doc_491521502190_item	3671924	et	3	main
hurt	doc_491521502190_item	3671922	et	3	main
töötas	doc_491521502190_item	3671920	et	3	main
välja	doc_491521502190_item	3671914	et	4	main
hakkas	doc_491521502190_item	3671913	et	3	main
tema	doc_491521502190_item	3671869	et	4	main
eesti	doc_491521502190_item	3671863	et	4	main
kes	doc_491521502190_item	3671893	et	4	main
jakob	doc_491521502190_item	3671890	et	4	main
kujutatud	doc_491521502190_item	3671889	et	4	main
1	doc_491521502190_item	3671883	et	2	main
oli	doc_491521502190_item	3671878	et	3	main
balti	doc_491521502188_item	3672442	et	3	main
mitte	doc_491521502188_item	3672438	et	3	main
oleks	doc_491521502188_item	3672433	et	3	main
arvates	doc_491521502188_item	3672432	et	4	main
taandumist	doc_491521502188_item	3672430	et	4	main
ei	doc_491521502188_item	3672416	et	4	main
hurt	doc_491521502188_item	3672415	et	3	main
majanduse	doc_491521502188_item	3672406	et	4	main
rõhus	doc_491521502188_item	3672404	et	4	main
jakobson	doc_491521502188_item	3672403	et	4	main
tõstmist	doc_491521502188_item	3672402	et	4	main
kultuuri	doc_491521502188_item	3672398	et	4	main
mõlemal	doc_491521502188_item	3672389	et	3	main
ja	doc_491521502188_item	3672383	et	3	main
aleksandrikooli	doc_491521502188_item	3672380	et	4	main
ja	doc_491521502188_item	3672379	et	3	main
seltsis	doc_491521502188_item	3672378	et	4	main
1878	doc_491521502188_item	3672372	et	2	main
nende	doc_491521502188_item	3672366	et	4	main
paati	doc_491521502188_item	3672365	et	4	main
ja	doc_491521502188_item	3672348	et	3	main
juurest	doc_491521502190_item	3671933	et	4	main
jannsen	doc_491521502190_item	3671929	et	4	main
r	doc_491521502190_item	3671926	et	4	main
te	doc_491521502190_item	3671868	et	4	main
kujutatud	doc_491521502190_item	3671862	et	4	main
kontrolltöö	doc_491521502190_item	3671856	et	4	main
10-kroonise	doc_491521502190_item	3671885	et	4	main
eesti	doc_491521502190_item	3671884	et	4	main
kukutamiseks	doc_491521502188_item	3672444	et	4	main
erikorra	doc_491521502188_item	3672443	et	3	main
koostööd	doc_491521502188_item	3672440	et	4	main
tulnud	doc_491521502188_item	3672434	et	4	main
hurda	doc_491521502188_item	3672431	et	3	main
ning	doc_491521502188_item	3672424	et	3	main
venestamist	doc_491521502188_item	3672423	et	4	main
võimudega	doc_491521502188_item	3672421	et	3	main
vaimuelu	doc_491521502188_item	3672414	et	4	main
ka	doc_491521502188_item	3672413	et	3	main
arenema	doc_491521502188_item	3672412	et	3	main
pidi	doc_491521502188_item	3672411	et	4	main
hardustaseme	doc_491521502188_item	3672401	et	4	main
hurt	doc_491521502188_item	3672395	et	3	main
edendamisest	doc_491521502188_item	3672394	et	4	main
rahvuse	doc_491521502188_item	3672393	et	3	main
nägemus	doc_491521502188_item	3672392	et	3	main
peakomitees	doc_491521502188_item	3672381	et	3	main
tihe	doc_491521502188_item	3672369	et	3	main
vahel	doc_491521502188_item	3672367	et	4	main
sunnil	doc_491521502188_item	3672362	et	4	main
olukorra	doc_491521502188_item	3672361	et	3	main
ta	doc_491521502188_item	3672360	et	4	main
sattus	doc_491521502188_item	3672359	et	3	main
hiljem	doc_491521502188_item	3672358	et	3	main
oluliseks	doc_491521502188_item	3672346	et	4	main
1839-1907	doc_491521502188_item	3672342	et	2	main
hurt	doc_491521502188_item	3672341	et	3	main
kultuurilukku	doc_491521502188_item	3672338	et	4	main
tegevusest	doc_491521502188_item	3672326	et	4	main
on	doc_491521502188_item	3672317	et	4	main
kultuuritegelane	doc_491521502188_item	3672316	et	3	main
ärkamisaja	doc_491521502188_item	3672315	et	3	main
milline	doc_491521502188_item	3672314	et	3	main
1	doc_491521502188_item	3672313	et	2	main
kultuuri	doc_491521502188_item	3672486	et	4	main
suunatud	doc_491521502190_item	3671931	et	4	main
c	doc_491521502190_item	3671925	et	4	main
nii	doc_491521502190_item	3671921	et	3	main
kus	doc_491521502190_item	3671919	et	3	main
eesti	doc_491521502190_item	3671917	et	4	main
ajalehte	doc_491521502190_item	3671916	et	4	main
andma	doc_491521502190_item	3671915	et	3	main
eesti	doc_491521502190_item	3671908	et	4	main
tagasiandmine	doc_491521502190_item	3671907	et	3	main
rahvaluule	doc_491521502190_item	3671906	et	4	main
ja	doc_491521502190_item	3671905	et	3	main
vaimnekultuur	doc_491521502190_item	3671904	et	4	main
oli	doc_491521502190_item	3671903	et	3	main
oluline	doc_491521502190_item	3671902	et	4	main
väga	doc_491521502190_item	3671901	et	3	main
meelest	doc_491521502190_item	3671900	et	4	main
hurda	doc_491521502190_item	3671899	et	3	main
j	doc_491521502190_item	3671898	et	4	main
liidriks	doc_491521502190_item	3671897	et	3	main
liikumise	doc_491521502190_item	3671896	et	4	main
aleksandrikooli	doc_491521502190_item	3671895	et	4	main
oli	doc_491521502190_item	3671894	et	3	main
milline	doc_491521502190_item	3671877	et	3	main
ja	doc_491521502190_item	3671876	et	3	main
estofiilid	doc_491521502190_item	3671875	et	3	main
olid	doc_491521502190_item	3671874	et	4	main
kes	doc_491521502190_item	3671873	et	4	main
2	doc_491521502190_item	3671872	et	2	main
teate	doc_491521502190_item	3671871	et	4	main
kuid	doc_491521502190_item	3671928	et	4	main
jakobson	doc_491521502190_item	3671927	et	4	main
jannsen	doc_491521502190_item	3671912	et	4	main
a	doc_491521502190_item	3671911	et	4	main
1864	doc_491521502190_item	3671910	et	2	main
rahvale	doc_491521502190_item	3671909	et	3	main
mida	doc_491521502190_item	3671867	et	4	main
peal	doc_491521502190_item	3671866	et	4	main
rahatähe	doc_491521502190_item	3671865	et	3	main
ärkamisaja	doc_491521502190_item	3671859	et	3	main
1839-1907	doc_491521502190_item	3671892	et	2	main
kultuurilukku	doc_491521502190_item	3671882	et	4	main
eesti	doc_491521502190_item	3671881	et	4	main
venelastega	doc_491521502188_item	3672441	et	4	main
teha	doc_491521502188_item	3672439	et	3	main
teed	doc_491521502188_item	3672437	et	4	main
jakobsoni	doc_491521502188_item	3672418	et	4	main
läbi	doc_491521502188_item	3672410	et	4	main
mille	doc_491521502188_item	3672409	et	3	main
keele	doc_491521502188_item	3672399	et	4	main
kuna	doc_491521502188_item	3672388	et	3	main
vahel	doc_491521502188_item	3672385	et	4	main
kirjameeste	doc_491521502188_item	3672377	et	4	main
eesti	doc_491521502188_item	3672376	et	4	main
koostöö	doc_491521502188_item	3672370	et	4	main
oli	doc_491521502188_item	3672368	et	3	main
jakobsoniga	doc_491521502188_item	3672363	et	4	main
1	doc_491521502188_item	3672339	et	2	main
kes	doc_491521502188_item	3672329	et	4	main
2	doc_491521502188_item	3672328	et	2	main
teate	doc_491521502188_item	3672327	et	4	main
kujutatud	doc_491521502188_item	3672318	et	4	main
säilimine	doc_491521502188_item	3672487	et	4	main
on	doc_491521502190_item	3671861	et	4	main
kultuuritegelane	doc_491521502190_item	3671860	et	3	main
milline	doc_491521502190_item	3671858	et	3	main
hurt	doc_491521502190_item	3671891	et	3	main
on	doc_491521502190_item	3671888	et	4	main
peal	doc_491521502190_item	3671887	et	4	main
rahatähe	doc_491521502190_item	3671886	et	3	main
panus	doc_491521502190_item	3671880	et	4	main
otsida	doc_491521502188_item	3672435	et	4	main
pooldanud	doc_491521502188_item	3672417	et	4	main
arengule	doc_491521502188_item	3672408	et	3	main
aga	doc_491521502188_item	3672405	et	3	main
tähtsamaks	doc_491521502188_item	3672397	et	4	main
pidas	doc_491521502188_item	3672396	et	3	main
lahkarvamused	doc_491521502188_item	3672387	et	3	main
ühte	doc_491521502188_item	3672364	et	4	main
pidas	doc_491521502188_item	3672345	et	3	main
keeleteadlane	doc_491521502188_item	3672343	et	3	main
mida	doc_491521502188_item	3672323	et	4	main
kontrolltöö	doc_491521502188_item	3672312	et	4	main
keel	doc_491521502188_item	3672489	et	4	main
eesti	doc_491521502188_item	3672488	et	4	main
pooldajate	doc_491521502188_item	3672448	et	4	main
tema	doc_491521502188_item	3672447	et	4	main
ja	doc_491521502188_item	3672446	et	3	main
jakobsoni	doc_491521502188_item	3672445	et	4	main
oma	doc_491521502188_item	3672436	et	4	main
usu	doc_491521502188_item	3672429	et	4	main
luteri	doc_491521502188_item	3672428	et	3	main
ja	doc_491521502188_item	3672427	et	3	main
keele	doc_491521502188_item	3672426	et	4	main
eesti	doc_491521502188_item	3672425	et	4	main
kartes	doc_491521502188_item	3672422	et	3	main
vene	doc_491521502188_item	3672420	et	4	main
koostööd	doc_491521502188_item	3672419	et	4	main
kiiremale	doc_491521502188_item	3672407	et	4	main
arendamist	doc_491521502188_item	3672400	et	4	main
oma	doc_491521502188_item	3672391	et	4	main
oli	doc_491521502188_item	3672390	et	3	main
tekkisid	doc_491521502188_item	3672386	et	4	main
hurda	doc_491521502188_item	3672384	et	3	main
jakobsoni	doc_491521502188_item	3672382	et	4	main
kaasa	doc_491521502188_item	3672375	et	4	main
lõi	doc_491521502188_item	3672374	et	4	main
hurt	doc_491521502188_item	3672373	et	3	main
kuni	doc_491521502188_item	3672371	et	3	main
kuid	doc_491521502188_item	3672357	et	4	main
kreuzwaldiga	doc_491521502188_item	3672356	et	4	main
kontaktid	doc_491521502188_item	3672355	et	3	main
olid	doc_491521502188_item	3672354	et	4	main
tal	doc_491521502188_item	3672353	et	3	main
juht	doc_491521502188_item	3672352	et	3	main
liikumise	doc_491521502188_item	3672351	et	4	main
aleksandrikooli	doc_491521502188_item	3672350	et	4	main
ajalugu	doc_491521502188_item	3672349	et	4	main
rahvaluulet	doc_491521502188_item	3672347	et	3	main
kes	doc_491521502188_item	3672344	et	4	main
olid	doc_491521502188_item	3672330	et	4	main
te	doc_491521502188_item	3672324	et	4	main
10-kroonise	doc_491521502188_item	3672320	et	4	main
eesti	doc_491521502188_item	3672319	et	4	main
tähtis	doc_491521502188_item	3672484	et	4	main
oli	doc_491521502188_item	3672483	et	3	main
jakob	doc_491521502188_item	3672340	et	4	main
eesti	doc_491521502188_item	3672337	et	4	main
panus	doc_491521502188_item	3672336	et	4	main
nende	doc_491521502188_item	3672335	et	4	main
oli	doc_491521502188_item	3672334	et	3	main
milline	doc_491521502188_item	3672333	et	3	main
ja	doc_491521502188_item	3672332	et	3	main
estofiilid	doc_491521502188_item	3672331	et	3	main
tema	doc_491521502188_item	3672325	et	4	main
peal	doc_491521502188_item	3672322	et	4	main
rahatähe	doc_491521502188_item	3672321	et	3	main
eesti	doc_491521502188_item	3672485	et	4	main
neile	doc_491521502188_item	3672482	et	4	main
kogumisega	doc_491521502188_item	3672481	et	4	main
rahvapärimuse	doc_491521502188_item	3672480	et	3	main
tegelesid	doc_491521502188_item	3672479	et	4	main
estofiilid	doc_491521502188_item	3672478	et	3	main
2	doc_491521502188_item	3672477	et	2	main
võimule	doc_491521502188_item	3672475	et	3	main
pääseda	doc_491521502188_item	3672476	et	3	main
ise	doc_491521502188_item	3672474	et	4	main
tahtsid	doc_491521502188_item	3672473	et	4	main
kes	doc_491521502188_item	3672472	et	4	main
poolt	doc_491521502188_item	3672471	et	4	main
järeltulijate	doc_491521502188_item	3672470	et	3	main
jakobsoni	doc_491521502188_item	3672469	et	4	main
sealt	doc_491521502188_item	3672468	et	4	main
kõrvaldati	doc_491521502188_item	3672467	et	3	main
ta	doc_491521502188_item	3672466	et	4	main
õigemini	doc_491521502188_item	3672465	et	4	main
areenilt	doc_491521502188_item	3672464	et	3	main
hurt	doc_491521502188_item	3672463	et	3	main
lahkus	doc_491521502188_item	3672462	et	4	main
skandaali	doc_491521502188_item	3672461	et	4	main
ostu	doc_491521502188_item	3672460	et	4	main
maja	doc_491521502188_item	3672459	et	4	main
aleksandrikooli	doc_491521502188_item	3672458	et	4	main
pärast	doc_491521502188_item	3672457	et	4	main
ekms	doc_491521502188_item	3672456	et	4	main
juhitud	doc_491521502188_item	3672455	et	4	main
hurda	doc_491521502188_item	3672454	et	3	main
ka	doc_491521502188_item	3672453	et	3	main
üle	doc_491521502188_item	3672452	et	3	main
hiljem	doc_491521502188_item	3672451	et	3	main
võeti	doc_491521502188_item	3672450	et	3	main
poolt	doc_491521502188_item	3672449	et	4	main
periood	doc_491521502184_item	3672972	et	3	main
ülikoolides	doc_491521502184_item	3672969	et	3	main
muutus	doc_491521502184_item	3672961	et	4	main
põhikool	doc_491521502184_item	3672960	et	4	main
haridusreform	doc_491521502184_item	3672959	et	3	main
ajateenimises	doc_491521502184_item	3672958	et	3	main
kaitseväes	doc_491521502184_item	3672957	et	3	main
ümberkorraldused	doc_491521502184_item	3672956	et	3	main
liikmeks	doc_491521502184_item	3672955	et	3	main
liitu	doc_491521502184_item	3672950	et	4	main
101	doc_491521502184_item	3672946	et	2	main
president	doc_491521502184_item	3672944	et	3	main
1992	doc_491521502184_item	3672941	et	2	main
vastuvõtmine	doc_491521502184_item	3672940	et	3	main
ev	doc_491521502184_item	3672938	et	4	main
soikujäämise	doc_491521502184_item	3672937	et	4	main
sulgemine	doc_491521502184_item	3672931	et	4	main
toiduainete	doc_491521502184_item	3672928	et	3	main
saaduste	doc_491521502184_item	3672926	et	4	main
mis	doc_491521502184_item	3672915	et	4	main
riikidega	doc_491521502184_item	3672914	et	3	main
muutused	doc_491521502184_item	3672867	et	4	main
1	doc_491521502184_item	3672866	et	2	main
loomingu	doc_491521502184_item	3673021	et	3	main
välja	doc_491521502184_item	3673014	et	4	main
kultuuritegelased	doc_491521502184_item	3673013	et	3	main
ka	doc_491521502184_item	3673011	et	3	main
kodumaale	doc_491521502184_item	3672997	et	4	main
rehabiliteeriti	doc_491521502184_item	3672990	et	3	main
loodusjõuks	doc_491521502181_item	3673220	et	3	main
edu	doc_491521502181_item	3673206	et	4	main
keda	doc_491521502181_item	3673201	et	4	main
valvavad	doc_491521502181_item	3673194	et	4	main
allikaveele	doc_491521502181_item	3673178	et	3	main
paelu	doc_491521502181_item	3673174	et	4	main
puudele	doc_491521502181_item	3673171	et	4	main
hingedele	doc_491521502181_item	3673157	et	3	main
ohverdati	doc_491521502181_item	3673155	et	3	main
seal	doc_491521502181_item	3673154	et	4	main
matusepaigad	doc_491521502181_item	3673153	et	3	main
muistsed	doc_491521502181_item	3673152	et	3	main
e	doc_491521502181_item	3673151	et	4	main
kalmed	doc_491521502181_item	3673150	et	3	main
see	doc_491521502181_item	3673149	et	3	main
saj	doc_491521502181_item	3673141	et	4	main
ohverdamine	doc_491521502181_item	3673122	et	4	main
vägi	doc_491521502181_item	3673119	et	3	main
näiteks	doc_491521502181_item	3673085	et	4	main
et	doc_491521502181_item	3673084	et	3	main
usuti	doc_491521502181_item	3673083	et	3	main
iseloomulik	doc_491521502181_item	3673081	et	3	main
riigikorraldusega	doc_491521502184_item	3672980	et	3	main
algas	doc_491521502184_item	3672973	et	3	main
2	doc_491521502184_item	3672970	et	2	main
gümnaasiumi	doc_491521502184_item	3672967	et	4	main
seda	doc_491521502184_item	3672964	et	3	main
astumiseks	doc_491521502184_item	3672951	et	4	main
liiget	doc_491521502184_item	3672947	et	3	main
riigikogus	doc_491521502184_item	3672945	et	4	main
sai	doc_491521502184_item	3672943	et	4	main
riigipeaks	doc_491521502184_item	3672942	et	3	main
põhiseaduse	doc_491521502184_item	3672939	et	3	main
kolhooside	doc_491521502184_item	3672930	et	3	main
vabakaubanduslepingu	doc_491521502184_item	3672911	et	3	main
nõukogu	doc_491521502184_item	3672906	et	4	main
euroopa	doc_491521502184_item	3672905	et	4	main
ja	doc_491521502184_item	3672904	et	3	main
uus	doc_491521502184_item	3672881	et	3	main
kuldsete	doc_491521502184_item	3672879	et	4	main
ja	doc_491521502184_item	3672878	et	3	main
periood	doc_491521502184_item	3672877	et	3	main
2	doc_491521502184_item	3672874	et	2	main
poliitilises	doc_491521502184_item	3672872	et	3	main
eesti	doc_491521502184_item	3672871	et	4	main
paljud	doc_491521502184_item	3673012	et	3	main
ilus	doc_491521502184_item	3673009	et	4	main
kõik	doc_491521502184_item	3673008	et	4	main
oli	doc_491521502184_item	3673007	et	3	main
olnud	doc_491521502184_item	3673001	et	4	main
ei	doc_491521502184_item	3673000	et	4	main
kortereid	doc_491521502184_item	3672989	et	3	main
seal	doc_491521502184_item	3672987	et	4	main
taarat	doc_491521502181_item	3673205	et	3	main
ka	doc_491521502181_item	3673199	et	3	main
seda	doc_491521502181_item	3673189	et	3	main
usuti	doc_491521502181_item	3673188	et	3	main
joomine	doc_491521502181_item	3673184	et	4	main
allikavee	doc_491521502181_item	3673183	et	3	main
selle	doc_491521502181_item	3673182	et	4	main
ja	doc_491521502181_item	3673181	et	3	main
valati	doc_491521502181_item	3673176	et	3	main
juurtele	doc_491521502181_item	3673175	et	3	main
ohverdati	doc_491521502181_item	3673172	et	3	main
kalmistupühad	doc_491521502181_item	3673170	et	3	main
esivanematega	doc_491521502181_item	3673169	et	4	main
uue	doc_491521502184_item	3672979	et	3	main
1958	doc_491521502184_item	3672976	et	2	main
a	doc_491521502184_item	3672966	et	4	main
peale	doc_491521502184_item	3672963	et	4	main
9-klassiliseks	doc_491521502184_item	3672962	et	4	main
sai	doc_491521502184_item	3672953	et	4	main
eesti	doc_491521502184_item	3672952	et	4	main
läbirääkimised	doc_491521502184_item	3672948	et	3	main
maaelu	doc_491521502184_item	3672936	et	4	main
kodumaiste	doc_491521502184_item	3672924	et	4	main
ja	doc_491521502184_item	3672923	et	3	main
odavate	doc_491521502184_item	3672918	et	3	main
tõi	doc_491521502184_item	3672916	et	3	main
sõlmimine	doc_491521502184_item	3672912	et	4	main
1990te	doc_491521502184_item	3672909	et	4	main
täieõiguslikuks	doc_491521502184_item	3672907	et	3	main
kohanema	doc_491521502184_item	3672981	et	3	main
hakkasid	doc_491521502184_item	3672978	et	4	main
hruštšovi	doc_491521502184_item	3672974	et	2	main
sula	doc_491521502184_item	3672971	et	4	main
euroopa	doc_491521502184_item	3672949	et	4	main
kaasa	doc_491521502184_item	3672935	et	4	main
tõi	doc_491521502184_item	3672934	et	3	main
laialijagamine	doc_491521502184_item	3672933	et	3	main
kolhoosivarade	doc_491521502184_item	3672932	et	3	main
täis	doc_491521502184_item	3672920	et	4	main
keemiat	doc_491521502184_item	3672919	et	3	main
kaasa	doc_491521502184_item	3672917	et	4	main
algus	doc_491521502184_item	3672910	et	4	main
sula-	doc_491521502184_item	3672876	et	4	main
kross	doc_491521502184_item	3673020	et	3	main
nt	doc_491521502184_item	3673018	et	4	main
rehabiliteeriti	doc_491521502184_item	3673010	et	3	main
loodi	doc_491521502184_item	3673003	et	4	main
kunstlikult	doc_491521502184_item	3673002	et	4	main
pääsesid	doc_491521502184_item	3672996	et	4	main
inimesed	doc_491521502184_item	3672995	et	3	main
ja	doc_491521502184_item	3672994	et	3	main
likvideeriti	doc_491521502184_item	3672993	et	3	main
läbisaamisest	doc_491521502181_item	3673215	et	4	main
heast	doc_491521502181_item	3673214	et	3	main
eestlaste	doc_491521502181_item	3673212	et	4	main
muistsete	doc_491521502181_item	3673211	et	3	main
sõltus	doc_491521502181_item	3673210	et	4	main
õnn	doc_491521502181_item	3673209	et	3	main
majanduslik	doc_491521502181_item	3673208	et	3	main
ja	doc_491521502181_item	3673207	et	3	main
usuti	doc_491521502181_item	3673202	et	3	main
jumalad	doc_491521502181_item	3673200	et	3	main
hõberaha	doc_491521502181_item	3673180	et	4	main
surnud	doc_491521502181_item	3673168	et	4	main
kokkukuuluvus	doc_491521502181_item	3673167	et	4	main
toitu	doc_491521502181_item	3673158	et	4	main
peale	doc_491521502181_item	3673146	et	4	main
põletusmatus	doc_491521502181_item	3673145	et	3	main
teoseid	doc_491521502184_item	3673043	et	3	main
tuglas	doc_491521502184_item	3673042	et	4	main
nt	doc_491521502184_item	3673041	et	4	main
kirjanike	doc_491521502184_item	3673040	et	3	main
rehabiliteeritud	doc_491521502184_item	3673039	et	4	main
anti	doc_491521502184_item	3673037	et	3	main
uuesti	doc_491521502184_item	3673036	et	3	main
põhjal	doc_491521502184_item	3673035	et	4	main
välja	doc_491521502184_item	3673038	et	4	main
tõlke	doc_491521502184_item	3673034	et	4	main
venekeelse	doc_491521502184_item	3673033	et	3	main
ka	doc_491521502184_item	3673032	et	3	main
tõlgiti	doc_491521502184_item	3673031	et	3	main
maailmaklassikat	doc_491521502184_item	3673030	et	3	main
keelustada	doc_491521502184_item	3673029	et	3	main
püüti	doc_491521502184_item	3673028	et	3	main
aeg-ajalt	doc_491521502184_item	3673027	et	4	main
mida	doc_491521502184_item	3673026	et	4	main
tõlketeosed	doc_491521502184_item	3673025	et	3	main
ilmuma	doc_491521502184_item	3673024	et	3	main
hakkasid	doc_491521502184_item	3673023	et	4	main
raamatukogus	doc_491521502184_item	3673022	et	4	main
inimesed	doc_491521502184_item	3672977	et	3	main
võimulepääsemisega	doc_491521502184_item	3672975	et	4	main
ka	doc_491521502184_item	3672968	et	3	main
3	doc_491521502184_item	3672965	et	2	main
nato	doc_491521502184_item	3672954	et	4	main
seismajäämise	doc_491521502184_item	3672929	et	4	main
ja	doc_491521502184_item	3672927	et	3	main
põllumaj	doc_491521502184_item	3672925	et	4	main
sissetoomise	doc_491521502184_item	3672922	et	4	main
importtoiduainete	doc_491521502184_item	3672921	et	3	main
euroopa	doc_491521502184_item	3672913	et	4	main
liikmeks	doc_491521502184_item	3672908	et	3	main
üro	doc_491521502184_item	3672903	et	4	main
sai	doc_491521502184_item	3672902	et	4	main
eesti	doc_491521502184_item	3672901	et	4	main
eek	doc_491521502184_item	3672900	et	4	main
rahale	doc_491521502184_item	3672899	et	4	main
oma	doc_491521502184_item	3672898	et	4	main
üle	doc_491521502184_item	3672897	et	3	main
mindi	doc_491521502184_item	3672896	et	3	main
suvel	doc_491521502184_item	3672895	et	3	main
1992	doc_491521502184_item	3672894	et	2	main
rahareform	doc_491521502184_item	3672893	et	3	main
omanikule	doc_491521502184_item	3672892	et	3	main
õigusjärgsetele	doc_491521502184_item	3672891	et	3	main
tagastamine	doc_491521502184_item	3672890	et	4	main
majade	doc_491521502184_item	3672889	et	3	main
ja	doc_491521502184_item	3672888	et	3	main
talude	doc_491521502184_item	3672887	et	3	main
maade	doc_491521502184_item	3672886	et	3	main
omandireform	doc_491521502184_item	3672885	et	3	main
1	doc_491521502184_item	3672884	et	2	main
situatsioon	doc_491521502184_item	3672883	et	3	main
kult	doc_491521502184_item	3672882	et	3	main
nn	doc_491521502184_item	3672875	et	4	main
kontrolltöö	doc_491521502184_item	3672865	et	4	main
runnel	doc_491521502184_item	3673019	et	4	main
tegijad	doc_491521502184_item	3673017	et	4	main
uued	doc_491521502184_item	3673016	et	3	main
näiliselt	doc_491521502184_item	3673006	et	4	main
vangilaagrid	doc_491521502184_item	3672992	et	3	main
tasuta	doc_491521502184_item	3672988	et	4	main
jagati	doc_491521502184_item	3672986	et	3	main
ja	doc_491521502184_item	3672985	et	3	main
kuuekümnendate	doc_491521502184_item	3672880	et	4	main
elus	doc_491521502184_item	3672873	et	4	main
taasiseseisvunud	doc_491521502184_item	3672870	et	4	main
muudatused	doc_491521502184_item	3672869	et	3	main
ja	doc_491521502184_item	3672868	et	3	main
ilmusid	doc_491521502184_item	3673015	et	4	main
töökohti	doc_491521502184_item	3673005	et	4	main
uusi	doc_491521502184_item	3673004	et	3	main
tööpuudust	doc_491521502184_item	3672999	et	4	main
tagasi	doc_491521502184_item	3672998	et	3	main
inimesi	doc_491521502184_item	3672991	et	4	main
karpmaju	doc_491521502184_item	3672984	et	3	main
ajutisi	doc_491521502184_item	3672983	et	3	main
ehitati	doc_491521502184_item	3672982	et	3	main
tugevamaks	doc_491521502181_item	3673219	et	4	main
esivanematega	doc_491521502181_item	3673217	et	4	main
surnud	doc_491521502181_item	3673216	et	4	main
uskusid	doc_491521502181_item	3673204	et	4	main
tekkisid	doc_491521502181_item	3673198	et	4	main
vaimud	doc_491521502181_item	3673197	et	3	main
kaitsevad	doc_491521502181_item	3673196	et	4	main
ja	doc_491521502181_item	3673195	et	3	main
tervisele	doc_491521502181_item	3673186	et	3	main
ohvrijooki	doc_491521502181_item	3673177	et	4	main
värvilisi	doc_491521502181_item	3673173	et	4	main
eestlastel	doc_491521502181_item	3673166	et	4	main
on	doc_491521502181_item	3673165	et	4	main
päevani	doc_491521502181_item	3673164	et	3	main
tänase	doc_491521502181_item	3673163	et	3	main
kuni	doc_491521502181_item	3673162	et	3	main
jm	doc_491521502181_item	3673161	et	4	main
herned	doc_491521502181_item	3673160	et	3	main
oad	doc_491521502181_item	3673159	et	3	main
surnute	doc_491521502181_item	3673156	et	4	main
inimesi	doc_491521502181_item	3673143	et	4	main
maeti	doc_491521502181_item	3673142	et	3	main
maagia	doc_491521502181_item	3673138	et	4	main
ohverdamisega	doc_491521502181_item	3673136	et	4	main
leiba	doc_491521502181_item	3673128	et	4	main
et	doc_491521502181_item	3673115	et	3	main
pidama	doc_491521502181_item	3673112	et	4	main
kive	doc_491521502181_item	3673108	et	3	main
puid	doc_491521502181_item	3673107	et	3	main
protsessi	doc_491521502181_item	3673079	et	4	main
korrati	doc_491521502181_item	3673077	et	4	main
pärast	doc_491521502181_item	3673076	et	4	main
kasvatati	doc_491521502181_item	3673070	et	3	main
langes	doc_491521502181_item	3673069	et	4	main
paar	doc_491521502181_item	3673064	et	3	main
jäi	doc_491521502181_item	3673060	et	3	main
põletati	doc_491521502181_item	3673057	et	3	main
2	doc_491521502181_item	3673050	et	2	main
üldiseloomustus	doc_491521502181_item	3673049	et	4	main
muinasusundi	doc_491521502181_item	3673048	et	3	main
eestlaste	doc_491521502181_item	3673047	et	4	main
1	doc_491521502181_item	3673046	et	2	main
eesti	doc_491521502121_item	3673618	et	4	main
seltsielu	doc_491521502121_item	3673616	et	4	main
lubatud	doc_491521502121_item	3673615	et	4	main
taotlesid	doc_491521502121_item	3673613	et	4	main
nad	doc_491521502121_item	3673612	et	3	main
in	doc_491521502121_item	3673611	et	4	main
3000	doc_491521502121_item	3673610	et	2	main
registreeritud	doc_491521502121_item	3673607	et	4	main
need	doc_491521502121_item	3673604	et	3	main
keeles	doc_491521502121_item	3673600	et	4	main
hääleõigus	doc_491521502121_item	3673592	et	4	main
seadus	doc_491521502121_item	3673582	et	4	main
vastu	doc_491521502121_item	3673581	et	3	main
võeti	doc_491521502121_item	3673580	et	3	main
tavalist	doc_491521502121_item	3673526	et	4	main
minema	doc_491521502121_item	3673523	et	3	main
ei	doc_491521502121_item	3673521	et	4	main
aga	doc_491521502121_item	3673520	et	3	main
poisski	doc_491521502121_item	3673519	et	3	main
nagu	doc_491521502121_item	3673518	et	3	main
haridust	doc_491521502121_item	3673517	et	4	main
samasugust	doc_491521502121_item	3673516	et	3	main
äike	doc_491521502181_item	3673222	et	3	main
oli	doc_491521502181_item	3673221	et	3	main
kõige	doc_491521502181_item	3673218	et	4	main
arvates	doc_491521502181_item	3673213	et	4	main
eestlased	doc_491521502181_item	3673203	et	3	main
loodust	doc_491521502181_item	3673193	et	4	main
et	doc_491521502181_item	3673192	et	3	main
usuti	doc_491521502181_item	3673191	et	3	main
veel	doc_491521502181_item	3673190	et	4	main
hästi	doc_491521502181_item	3673187	et	3	main
mõjub	doc_491521502181_item	3673185	et	3	main
viidud	doc_491521502181_item	3673179	et	4	main
lõppes	doc_491521502181_item	3673148	et	4	main
ristiusustamist	doc_491521502181_item	3673147	et	3	main
13	doc_491521502181_item	3673140	et	2	main
liha	doc_491521502181_item	3673129	et	4	main
vilja	doc_491521502181_item	3673127	et	4	main
villa	doc_491521502181_item	3673126	et	4	main
ohverdati	doc_491521502181_item	3673125	et	3	main
põhiliselt	doc_491521502181_item	3673124	et	4	main
loodusobjektidele	doc_491521502181_item	3673123	et	3	main
oli	doc_491521502181_item	3673121	et	3	main
sest	doc_491521502181_item	3673113	et	4	main
pühaks	doc_491521502181_item	3673111	et	3	main
hakati	doc_491521502181_item	3673110	et	3	main
allikaid	doc_491521502181_item	3673109	et	3	main
eluta	doc_491521502181_item	3673086	et	3	main
aasta	doc_491521502181_item	3673075	et	4	main
viljakus	doc_491521502181_item	3673068	et	4	main
ainult	doc_491521502181_item	3673063	et	4	main
väetiseks	doc_491521502181_item	3673061	et	3	main
raiuti	doc_491521502181_item	3673056	et	3	main
põletatult	doc_491521502181_item	3673144	et	4	main
kuni	doc_491521502181_item	3673139	et	3	main
kaasnes	doc_491521502181_item	3673137	et	3	main
ka	doc_491521502181_item	3673135	et	3	main
loomi	doc_491521502181_item	3673134	et	4	main
vahel	doc_491521502181_item	3673133	et	4	main
ning	doc_491521502181_item	3673132	et	3	main
ehteid	doc_491521502181_item	3673131	et	3	main
ka	doc_491521502181_item	3673130	et	3	main
levinud	doc_491521502181_item	3673120	et	4	main
suur	doc_491521502181_item	3673118	et	3	main
on	doc_491521502181_item	3673117	et	4	main
neil	doc_491521502181_item	3673116	et	4	main
mulla	doc_491521502181_item	3673067	et	4	main
kuni	doc_491521502181_item	3673066	et	3	main
2	doc_491521502181_item	3673054	et	2	main
kontrolltöö	doc_491521502181_item	3673045	et	4	main
kui	doc_491521502121_item	3673609	et	3	main
oli	doc_491521502121_item	3673606	et	3	main
kohalikus	doc_491521502121_item	3673599	et	4	main
kõnepidamiseks	doc_491521502121_item	3673598	et	3	main
1902	doc_491521502121_item	3673596	et	2	main
kultuuri	doc_491521502121_item	3673595	et	4	main
omakeelse	doc_491521502121_item	3673594	et	3	main
mõtteid	doc_491521502121_item	3673590	et	3	main
õigus	doc_491521502121_item	3673586	et	4	main
vähemusrahvastel	doc_491521502121_item	3673584	et	4	main
et	doc_491521502121_item	3673583	et	3	main
alt	doc_491521502121_item	3673571	et	4	main
ning	doc_491521502121_item	3673537	et	3	main
usuti	doc_491521502181_item	3673114	et	3	main
looduses	doc_491521502181_item	3673106	et	4	main
eluta	doc_491521502181_item	3673105	et	3	main
elus	doc_491521502181_item	3673104	et	4	main
vägi	doc_491521502181_item	3673103	et	3	main
ka	doc_491521502181_item	3673102	et	3	main
tähtis	doc_491521502181_item	3673101	et	4	main
oli	doc_491521502181_item	3673100	et	3	main
kõrval	doc_491521502181_item	3673099	et	4	main
hinge	doc_491521502181_item	3673098	et	4	main
austamine	doc_491521502181_item	3673097	et	4	main
esivanemate	doc_491521502181_item	3673096	et	4	main
surnute	doc_491521502181_item	3673095	et	4	main
hing	doc_491521502181_item	3673094	et	3	main
on	doc_491521502181_item	3673093	et	4	main
kividel	doc_491521502181_item	3673092	et	3	main
puudel	doc_491521502181_item	3673091	et	4	main
loodusel	doc_491521502181_item	3673090	et	4	main
elus	doc_491521502181_item	3673089	et	4	main
ja	doc_491521502181_item	3673088	et	3	main
loodusel	doc_491521502181_item	3673087	et	4	main
animism	doc_491521502181_item	3673082	et	3	main
1	doc_491521502181_item	3673080	et	2	main
mõnekümne	doc_491521502181_item	3673074	et	4	main
aastat	doc_491521502181_item	3673065	et	3	main
kasutati	doc_491521502181_item	3673062	et	4	main
maha	doc_491521502181_item	3673058	et	4	main
alepõllundus	doc_491521502181_item	3673053	et	3	main
on	doc_491521502181_item	3673052	et	4	main
usuvabadus	doc_491521502121_item	3673617	et	4	main
sakslased	doc_491521502121_item	3673602	et	3	main
väljendada	doc_491521502121_item	3673589	et	3	main
taheti	doc_491521502121_item	3673575	et	3	main
tütarlaps	doc_491521502121_item	3673513	et	4	main
et	doc_491521502121_item	3673512	et	3	main
leidis	doc_491521502121_item	3673511	et	4	main
toob	doc_491521502121_item	3673504	et	3	main
on	doc_491521502121_item	3673501	et	4	main
alguseks	doc_491521502121_item	3673500	et	4	main
aga	doc_491521502121_item	3673491	et	3	main
algul	doc_491521502121_item	3673489	et	4	main
nõiaprotsessidega	doc_491521502121_item	3673461	et	3	main
saksakeelne	doc_491521502121_item	3673451	et	3	main
eesti	doc_491521502121_item	3673437	et	4	main
kõne	doc_491521502121_item	3673435	et	4	main
tuntuks	doc_491521502121_item	3673432	et	4	main
saab	doc_491521502121_item	3673431	et	3	main
pärisorjus	doc_491521502121_item	3673426	et	3	main
ristirüütlite	doc_491521502121_item	3673422	et	3	main
s	doc_491521502121_item	3673420	et	4	main
pimedus	doc_491521502121_item	3673418	et	4	main
pole	doc_491521502121_item	3673409	et	3	main
et	doc_491521502121_item	3673397	et	3	main
leidis	doc_491521502121_item	3673396	et	4	main
süsteem	doc_491521502121_item	3673395	et	3	main
jumalate	doc_491521502121_item	3673394	et	3	main
maad	doc_491521502121_item	3673387	et	4	main
võõrast	doc_491521502121_item	3673386	et	4	main
astronoomia	doc_491521502121_item	3673330	et	4	main
etnograafia	doc_491521502121_item	3673329	et	4	main
oli	doc_491521502121_item	3673328	et	3	main
muuk	doc_491521502121_item	3673293	et	3	main
kogu	doc_491521502181_item	3673078	et	4	main
peale	doc_491521502181_item	3673073	et	4	main
võsa	doc_491521502181_item	3673072	et	4	main
uus	doc_491521502181_item	3673071	et	3	main
tuhk	doc_491521502181_item	3673059	et	3	main
mets	doc_491521502181_item	3673055	et	3	main
mis	doc_491521502181_item	3673051	et	4	main
vabariigis	doc_491521502121_item	3673619	et	3	main
rootslased	doc_491521502121_item	3673603	et	3	main
said	doc_491521502121_item	3673593	et	4	main
emakeeles	doc_491521502121_item	3673591	et	4	main
oma	doc_491521502121_item	3673587	et	4	main
on	doc_491521502121_item	3673585	et	4	main
autonoomiat	doc_491521502121_item	3673576	et	3	main
omakeelset	doc_491521502121_item	3673535	et	3	main
omada	doc_491521502121_item	3673534	et	3	main
nad	doc_491521502121_item	3673532	et	3	main
püüab	doc_491521502121_item	3673525	et	3	main
saa	doc_491521502121_item	3673515	et	4	main
kõige	doc_491521502121_item	3673499	et	4	main
brošüürid	doc_491521502121_item	3673498	et	2	main
näitused	doc_491521502121_item	3673497	et	3	main
jakobsonile	doc_491521502121_item	3673494	et	4	main
1857	doc_491521502121_item	3673492	et	2	main
seotud	doc_491521502121_item	3673460	et	4	main
kõne	doc_491521502121_item	3673459	et	4	main
kolmas	doc_491521502121_item	3673458	et	3	main
seltsi	doc_491521502121_item	3673448	et	4	main
orjusest	doc_491521502121_item	3673430	et	4	main
13	doc_491521502121_item	3673419	et	2	main
sõjaväge	doc_491521502121_item	3673417	et	3	main
eestlane	doc_491521502121_item	3673410	et	3	main
13	doc_491521502121_item	3673407	et	2	main
usustamine	doc_491521502121_item	3673406	et	4	main
oli	doc_491521502121_item	3673393	et	3	main
vaja	doc_491521502121_item	3673389	et	4	main
sirur	doc_491521502121_item	3673341	et	4	main
akadeemia	doc_491521502121_item	3673340	et	4	main
teaduste	doc_491521502121_item	3673339	et	3	main
avatakse	doc_491521502121_item	3673334	et	4	main
puusepp	doc_491521502121_item	3673332	et	3	main
keeli	doc_491521502121_item	3673296	et	4	main
teadussõnavara	doc_491521502121_item	3673294	et	4	main
keele	doc_491521502121_item	3673288	et	4	main
eesti	doc_491521502121_item	3673287	et	4	main
toimus	doc_491521502121_item	3673286	et	3	main
avati	doc_491521502121_item	3673279	et	3	main
reaakool	doc_491521502121_item	3673273	et	4	main
kl	doc_491521502121_item	3673272	et	4	main
3	doc_491521502121_item	3673271	et	2	main
algk	doc_491521502121_item	3673270	et	2	main
klass	doc_491521502121_item	3673262	et	3	main
hariuds	doc_491521502121_item	3673236	et	4	main
haridus	doc_491521502121_item	3673231	et	3	main
õpetajaid	doc_491521502121_item	3673228	et	4	main
eijätku	doc_491521502121_item	3673227	et	4	main
valguseaeg	doc_491521502121_item	3673376	et	3	main
roll	doc_491521502121_item	3673359	et	3	main
jakobsoni	doc_491521502121_item	3673358	et	4	main
tegid	doc_980560860275_item	3673646	et	4	main
sa	doc_980560860275_item	3673645	et	3	main
3	doc_980560860275_item	3673642	et	2	main
küsimusele	doc_980560860275_item	3673641	et	4	main
vastus	doc_980560860275_item	3673640	et	3	main
on	doc_980560860275_item	3673715	et	4	main
nimi	doc_980560860275_item	3673714	et	3	main
sõbra	doc_980560860275_item	3673713	et	3	main
sõitsin	doc_980560860275_item	3673685	et	3	main
olid	doc_980560860275_item	3673681	et	4	main
ma	doc_980560860275_item	3673673	et	3	main
sõitaime	doc_980560860275_item	3673660	et	4	main
pere	doc_980560860275_item	3673659	et	4	main
ja	doc_980560860275_item	3673658	et	3	main
ma	doc_980560860275_item	3673657	et	3	main
7-aastane	doc_980560860275_item	3673652	et	4	main
koera	doc_980560860274_item	3673823	et	4	main
oma	doc_980560860274_item	3673821	et	4	main
parima	doc_980560860274_item	3673802	et	4	main
oma	doc_980560860274_item	3673801	et	4	main
suveniir	doc_980560860274_item	3673799	et	3	main
palju	doc_980560860274_item	3673798	et	4	main
loomeühingud	doc_491521502121_item	3673637	et	3	main
loodud	doc_491521502121_item	3673636	et	4	main
olid	doc_491521502121_item	3673635	et	4	main
kõrgharidussüsteem	doc_491521502121_item	3673634	et	3	main
emakeelne	doc_491521502121_item	3673633	et	3	main
ajakirjad	doc_491521502121_item	3673632	et	3	main
keeles	doc_491521502121_item	3673631	et	4	main
saksa	doc_491521502121_item	3673630	et	4	main
vene	doc_491521502121_item	3673629	et	4	main
rootsi	doc_491521502121_item	3673628	et	4	main
algkool	doc_491521502121_item	3673627	et	4	main
keeles	doc_491521502121_item	3673626	et	4	main
soome	doc_491521502121_item	3673625	et	3	main
gümnaasiumid	doc_491521502121_item	3673624	et	3	main
juudi	doc_491521502121_item	3673623	et	3	main
rootsi	doc_491521502121_item	3673622	et	4	main
saksa	doc_491521502121_item	3673621	et	4	main
vene	doc_491521502121_item	3673620	et	4	main
kultuurautonoomiat	doc_491521502121_item	3673614	et	3	main
vähem	doc_491521502121_item	3673608	et	4	main
kus	doc_491521502121_item	3673605	et	3	main
venelased	doc_491521502121_item	3673601	et	3	main
luba	doc_491521502121_item	3673597	et	4	main
keele	doc_491521502121_item	3673588	et	4	main
1925	doc_491521502121_item	3673579	et	2	main
rahvusriiki	doc_491521502121_item	3673578	et	4	main
mitte	doc_491521502121_item	3673577	et	3	main
hulgas	doc_491521502121_item	3673574	et	4	main
rahva	doc_491521502121_item	3673573	et	3	main
ühe	doc_491521502121_item	3673572	et	4	main
vastu	doc_491521502121_item	3673570	et	3	main
keskvõimu	doc_491521502121_item	3673569	et	4	main
protest	doc_491521502121_item	3673568	et	3	main
oli	doc_491521502121_item	3673567	et	3	main
ida-euroopas	doc_491521502121_item	3673566	et	3	main
natsionalism	doc_491521502121_item	3673565	et	3	main
mõistet	doc_491521502121_item	3673564	et	3	main
selgitab	doc_491521502121_item	3673563	et	3	main
kool	doc_491521502121_item	3673562	et	4	main
maailmatähendust	doc_491521502121_item	3673561	et	3	main
väärtushinnanguid	doc_491521502121_item	3673560	et	3	main
kooliga	doc_491521502121_item	3673558	et	4	main
emakeeles	doc_491521502121_item	3673557	et	4	main
juurutati	doc_491521502121_item	3673559	et	3	main
oleks	doc_491521502121_item	3673556	et	3	main
kultuurisündmused	doc_491521502121_item	3673555	et	3	main
ka	doc_491521502121_item	3673554	et	3	main
aga	doc_491521502121_item	3673553	et	3	main
raamatuid	doc_491521502121_item	3673552	et	3	main
õpikuid	doc_491521502121_item	3673551	et	4	main
kirjandust	doc_491521502121_item	3673550	et	3	main
keelset	doc_491521502121_item	3673549	et	3	main
oma	doc_491521502121_item	3673548	et	4	main
välja	doc_491521502121_item	3673547	et	4	main
antaks	doc_491521502121_item	3673546	et	3	main
et	doc_491521502121_item	3673545	et	3	main
keeles	doc_491521502121_item	3673544	et	4	main
arusaadavas	doc_491521502121_item	3673543	et	3	main
nendele	doc_491521502121_item	3673542	et	4	main
toimuks	doc_491521502121_item	3673541	et	3	main
see	doc_491521502121_item	3673540	et	3	main
et	doc_491521502121_item	3673539	et	3	main
hariduselu	doc_491521502121_item	3673538	et	4	main
kultuuri	doc_491521502121_item	3673536	et	4	main
tahtsid	doc_491521502121_item	3673533	et	4	main
tegid	doc_491521502121_item	3673530	et	4	main
vähemusrahvused	doc_491521502121_item	3673529	et	3	main
haridust	doc_491521502121_item	3673527	et	4	main
linnakooli	doc_491521502121_item	3673524	et	4	main
pea	doc_491521502121_item	3673522	et	4	main
kooli	doc_491521502121_item	3673510	et	4	main
õmblusmampside	doc_491521502121_item	3673509	et	4	main
taunis	doc_491521502121_item	3673508	et	3	main
jakobson	doc_491521502121_item	3673507	et	4	main
4	doc_491521502121_item	3673506	et	2	main
põllumeeste	doc_491521502121_item	3673486	et	4	main
eesti	doc_491521502121_item	3673485	et	4	main
tartus	doc_491521502121_item	3673484	et	3	main
1870	doc_491521502121_item	3673483	et	2	main
3	doc_491521502121_item	3673482	et	2	main
küsimus	doc_491521502121_item	3673481	et	4	main
2	doc_491521502121_item	3673480	et	2	main
vabariigis	doc_491521502121_item	3673479	et	3	main
eesti	doc_491521502121_item	3673478	et	4	main
hariduselu	doc_491521502121_item	3673477	et	4	main
ja	doc_491521502121_item	3673476	et	3	main
kultuuri-	doc_491521502121_item	3673475	et	4	main
vähemusrahvuste	doc_491521502121_item	3673474	et	3	main
3	doc_491521502121_item	3673473	et	2	main
viljandis	doc_491521502121_item	3673472	et	4	main
sakala	doc_491521502121_item	3673471	et	4	main
ajaleht	doc_491521502121_item	3673470	et	3	main
kirjaviisis	doc_491521502121_item	3673469	et	3	main
uues	doc_491521502121_item	3673468	et	3	main
kirjanduslik	doc_491521502121_item	3673467	et	3	main
majanduslik	doc_491521502121_item	3673466	et	3	main
poliitiline	doc_491521502121_item	3673465	et	3	main
1878	doc_491521502121_item	3673463	et	2	main
kultuurautonoomiat	doc_491521502121_item	3673531	et	3	main
3	doc_491521502121_item	3673528	et	2	main
tulu	doc_491521502121_item	3673505	et	4	main
piimakase	doc_491521502121_item	3673502	et	4	main
lõned	doc_491521502121_item	3673496	et	4	main
läksid	doc_491521502121_item	3673493	et	4	main
jakobsoni	doc_491521502121_item	3673464	et	4	main
rootslaset	doc_491521502121_item	3673441	et	4	main
hindab	doc_491521502121_item	3673440	et	3	main
arengust	doc_491521502121_item	3673439	et	3	main
kirjanduse	doc_491521502121_item	3673438	et	3	main
peab	doc_491521502121_item	3673514	et	4	main
mis	doc_491521502121_item	3673503	et	4	main
kes	doc_491521502121_item	3673495	et	4	main
jannsenil	doc_491521502121_item	3673490	et	4	main
oli	doc_491521502121_item	3673488	et	3	main
selts	doc_491521502121_item	3673487	et	3	main
eesti	doc_491521502121_item	3673456	et	4	main
propageerima	doc_491521502121_item	3673455	et	3	main
peab	doc_491521502121_item	3673454	et	4	main
et	doc_491521502121_item	3673453	et	3	main
leiab	doc_491521502121_item	3673452	et	3	main
tegevus	doc_491521502121_item	3673450	et	4	main
õpetatud	doc_491521502121_item	3673446	et	4	main
kultuuri	doc_491521502121_item	3673444	et	4	main
arendada	doc_491521502121_item	3673443	et	3	main
püüet	doc_491521502121_item	3673442	et	3	main
vabastas	doc_491521502121_item	3673429	et	3	main
alistub	doc_491521502121_item	3673425	et	3	main
tulekuga	doc_491521502121_item	3673423	et	3	main
algasid	doc_491521502121_item	3673400	et	4	main
probleemid	doc_491521502121_item	3673399	et	3	main
muinasnnud	doc_491521502121_item	3673392	et	4	main
esivanemate	doc_491521502121_item	3673384	et	4	main
asutusi	doc_491521502121_item	3673336	et	4	main
neurokirurgia	doc_491521502121_item	3673333	et	4	main
sasreste	doc_491521502121_item	3673291	et	4	main
lahkusid	doc_491521502121_item	3673285	et	4	main
ük	doc_491521502121_item	3673281	et	4	main
juba	doc_491521502121_item	3673276	et	3	main
progm	doc_491521502121_item	3673266	et	4	main
haridusreform	doc_491521502121_item	3673259	et	3	main
kaheastmeline	doc_491521502121_item	3673238	et	4	main
siis	doc_491521502121_item	3673237	et	3	main
1930	doc_491521502121_item	3673232	et	2	main
s	doc_491521502121_item	3673380	et	4	main
isamaa	doc_491521502121_item	3673366	et	4	main
kolm	doc_491521502121_item	3673365	et	3	main
pidas	doc_491521502121_item	3673364	et	3	main
kõned	doc_491521502121_item	3673363	et	3	main
1	doc_491521502121_item	3673362	et	2	main
eestis	doc_491521502121_item	3673361	et	3	main
ärkamisaegses	doc_491521502121_item	3673360	et	3	main
kus	doc_980560860275_item	3673647	et	3	main
päikesepäisteline	doc_980560860275_item	3673740	et	4	main
ta	doc_980560860275_item	3673738	et	4	main
vana	doc_980560860275_item	3673727	et	4	main
aastat	doc_980560860275_item	3673726	et	3	main
neli	doc_980560860275_item	3673725	et	3	main
olin	doc_980560860275_item	3673724	et	3	main
ma	doc_980560860275_item	3673712	et	3	main
parima	doc_980560860275_item	3673709	et	4	main
ma	doc_980560860275_item	3673684	et	3	main
viimasel	doc_980560860275_item	3673682	et	3	main
töötasin	doc_980560860275_item	3673671	et	3	main
ma	doc_980560860275_item	3673653	et	3	main
sain	doc_980560860274_item	3673820	et	3	main
oma	doc_980560860274_item	3673817	et	4	main
juuksed	doc_980560860274_item	3673815	et	3	main
minu	doc_980560860274_item	3673814	et	3	main
lõikas	doc_980560860274_item	3673813	et	3	main
merisse	doc_980560860274_item	3673811	et	4	main
läksime	doc_980560860274_item	3673810	et	3	main
me	doc_980560860274_item	3673809	et	4	main
sõbraga	doc_980560860274_item	3673803	et	3	main
koreasse	doc_980560860274_item	3673792	et	4	main
õpilane	doc_980560860274_item	3673784	et	3	main
aga	doc_980560860274_item	3673779	et	3	main
õppisin	doc_980560860274_item	3673777	et	3	main
ma	doc_980560860274_item	3673776	et	3	main
keskkooli	doc_980560860274_item	3673775	et	4	main
käisin	doc_980560860274_item	3673774	et	3	main
koera	doc_980560860274_item	3673761	et	4	main
hitrone	doc_980560860273_item	3673936	et	4	main
ostman	doc_980560860273_item	3673934	et	4	main
muusikakeskusis	doc_980560860273_item	3673932	et	3	main
muusikat	doc_980560860273_item	3673931	et	3	main
oma	doc_980560860273_item	3673927	et	4	main
said	doc_980560860273_item	3673926	et	4	main
jaanuar	doc_980560860273_item	3673925	et	3	main
käisin	doc_980560860273_item	3673919	et	3	main
sõbraga	doc_980560860273_item	3673917	et	3	main
oma	doc_980560860273_item	3673915	et	4	main
2	doc_491521502121_item	3673462	et	2	main
keelt	doc_491521502121_item	3673457	et	4	main
kus	doc_491521502121_item	3673449	et	3	main
eesti	doc_491521502121_item	3673447	et	4	main
süüdistab	doc_491521502121_item	3673445	et	3	main
oli	doc_491521502121_item	3673436	et	3	main
teine	doc_491521502121_item	3673434	et	3	main
rahvane	doc_491521502121_item	3673433	et	4	main
koiduaeg	doc_491521502121_item	3673427	et	3	main
eestlane	doc_491521502121_item	3673424	et	3	main
algas	doc_491521502121_item	3673421	et	3	main
korda	doc_491521502121_item	3673416	et	4	main
politilist	doc_491521502121_item	3673415	et	4	main
aga	doc_491521502121_item	3673414	et	3	main
pole	doc_491521502121_item	3673413	et	3	main
mahajäänum	doc_491521502121_item	3673412	et	3	main
kõik	doc_491521502121_item	3673398	et	4	main
maale	doc_491521502121_item	3673385	et	4	main
eesti	doc_491521502121_item	3673338	et	4	main
1938	doc_491521502121_item	3673337	et	2	main
tähtis	doc_491521502121_item	3673327	et	4	main
uuriti	doc_491521502121_item	3673297	et	3	main
soomeugri	doc_491521502121_item	3673295	et	4	main
veski	doc_491521502121_item	3673292	et	4	main
vene	doc_491521502121_item	3673282	et	4	main
1632	doc_491521502121_item	3673278	et	2	main
teadus	doc_491521502121_item	3673274	et	4	main
kl	doc_491521502121_item	3673265	et	4	main
5	doc_491521502121_item	3673264	et	2	main
4	doc_491521502121_item	3673261	et	2	main
aastane	doc_491521502121_item	3673235	et	4	main
4	doc_491521502121_item	3673234	et	2	main
vabariigis	doc_491521502121_item	3673226	et	3	main
muinasaeg	doc_491521502121_item	3673377	et	3	main
pimeduse	doc_491521502121_item	3673373	et	4	main
valguse	doc_491521502121_item	3673372	et	4	main
a	doc_491521502121_item	3673369	et	4	main
1864	doc_491521502121_item	3673368	et	2	main
kõnet	doc_491521502121_item	3673367	et	3	main
olid	doc_980560860275_item	3673651	et	4	main
kui	doc_980560860275_item	3673649	et	3	main
mida	doc_980560860275_item	3673644	et	4	main
vanemad	doc_980560860275_item	3673732	et	4	main
ja	doc_980560860275_item	3673731	et	3	main
õde	doc_980560860275_item	3673730	et	4	main
ja	doc_980560860275_item	3673729	et	3	main
ma	doc_980560860275_item	3673728	et	3	main
oma	doc_980560860275_item	3673721	et	4	main
telekat	doc_980560860275_item	3673719	et	3	main
lilien	doc_980560860275_item	3673716	et	4	main
sõbraga	doc_980560860275_item	3673710	et	3	main
sa	doc_980560860275_item	3673680	et	3	main
haigla	doc_980560860275_item	3673672	et	4	main
15-aastane	doc_980560860275_item	3673669	et	4	main
olid	doc_980560860275_item	3673668	et	4	main
sa	doc_980560860275_item	3673667	et	3	main
kooli	doc_980560860275_item	3673656	et	4	main
kodus	doc_980560860274_item	3673808	et	4	main
sõber	doc_980560860274_item	3673805	et	3	main
lõuna	doc_980560860274_item	3673791	et	4	main
sõitsin	doc_980560860274_item	3673790	et	3	main
ma	doc_980560860274_item	3673789	et	3	main
tark	doc_980560860274_item	3673783	et	3	main
ma	doc_980560860274_item	3673773	et	3	main
sa	doc_980560860274_item	3673770	et	3	main
omasin	doc_980560860274_item	3673760	et	3	main
keiser	doc_491521502121_item	3673428	et	3	main
läänemererahvastest	doc_491521502121_item	3673411	et	4	main
s	doc_491521502121_item	3673408	et	4	main
vägivaldne	doc_491521502121_item	3673405	et	3	main
toimus	doc_491521502121_item	3673404	et	3	main
sest	doc_491521502121_item	3673403	et	4	main
tulekuga	doc_491521502121_item	3673402	et	3	main
ristisõdijate	doc_491521502121_item	3673401	et	3	main
tähtis	doc_491521502121_item	3673391	et	4	main
jumaldada	doc_491521502121_item	3673390	et	3	main
pole	doc_491521502121_item	3673388	et	3	main
õigus	doc_491521502121_item	3673383	et	4	main
rahval	doc_491521502121_item	3673382	et	3	main
mitmeid	doc_491521502121_item	3673335	et	4	main
arstiteadusarenes	doc_491521502121_item	3673331	et	4	main
rahvalauluuurija	doc_491521502121_item	3673326	et	4	main
tampere	doc_491521502121_item	3673325	et	4	main
eestikeelemuinasjutte	doc_491521502121_item	3673324	et	3	main
uuriti	doc_491521502121_item	3673323	et	3	main
erl	doc_491521502121_item	3673322	et	4	main
oli	doc_491521502121_item	3673321	et	3	main
nekkus	doc_491521502121_item	3673320	et	4	main
rahvaluulekogumine	doc_491521502121_item	3673319	et	4	main
toimus	doc_491521502121_item	3673318	et	3	main
peajooned	doc_491521502121_item	3673317	et	3	main
kirjandus	doc_491521502121_item	3673316	et	3	main
eesti	doc_491521502121_item	3673315	et	4	main
kampmaa	doc_491521502121_item	3673314	et	4	main
kohta	doc_491521502121_item	3673313	et	4	main
kalevipoja	doc_491521502121_item	3673312	et	4	main
kirjutas	doc_491521502121_item	3673311	et	3	main
annist	doc_491521502121_item	3673310	et	3	main
kreutzwald	doc_491521502121_item	3673309	et	4	main
peterson	doc_491521502121_item	3673308	et	4	main
koidula	doc_491521502121_item	3673307	et	4	main
uits	doc_491521502121_item	3673306	et	4	main
lugemine	doc_491521502121_item	3673305	et	4	main
kirjanduse	doc_491521502121_item	3673304	et	3	main
eesti	doc_491521502121_item	3673303	et	4	main
mägiste	doc_491521502121_item	3673302	et	4	main
ariste	doc_491521502121_item	3673301	et	4	main
selts	doc_491521502121_item	3673300	et	3	main
emakeele	doc_491521502121_item	3673299	et	4	main
akadeemiline	doc_491521502121_item	3673298	et	3	main
aavik	doc_491521502121_item	3673290	et	4	main
teadland	doc_491521502121_item	3673284	et	4	main
kl	doc_491521502121_item	3673269	et	4	main
6	doc_491521502121_item	3673268	et	2	main
2	doc_491521502121_item	3673267	et	2	main
1	doc_491521502121_item	3673260	et	2	main
täiendkool	doc_491521502121_item	3673257	et	4	main
uurimine	doc_491521502121_item	3673289	et	4	main
saksa	doc_491521502121_item	3673283	et	4	main
tartu	doc_491521502121_item	3673280	et	4	main
1630	doc_491521502121_item	3673277	et	2	main
algas	doc_491521502121_item	3673275	et	3	main
algkoll	doc_491521502121_item	3673263	et	3	main
1934-37	doc_491521502121_item	3673258	et	2	main
rahvaülikool	doc_491521502121_item	3673256	et	4	main
olid	doc_491521502121_item	3673255	et	4	main
vähem	doc_491521502121_item	3673254	et	4	main
raha	doc_491521502121_item	3673253	et	4	main
kel	doc_491521502121_item	3673252	et	3	main
vanematele	doc_491521502121_item	3673251	et	4	main
tasuta	doc_491521502121_item	3673250	et	4	main
algkool	doc_491521502121_item	3673249	et	4	main
kommerts	doc_491521502121_item	3673248	et	3	main
reaal-	doc_491521502121_item	3673247	et	3	main
humanitaar	doc_491521502121_item	3673246	et	4	main
keskkoll	doc_491521502121_item	3673245	et	3	main
kekkool	doc_491521502121_item	3673244	et	4	main
5	doc_491521502121_item	3673242	et	2	main
kl	doc_491521502121_item	3673243	et	4	main
algkool	doc_491521502121_item	3673241	et	4	main
kl	doc_491521502121_item	3673240	et	4	main
6	doc_491521502121_item	3673239	et	2	main
a	doc_491521502121_item	3673233	et	4	main
oli	doc_491521502121_item	3673229	et	3	main
eesti	doc_491521502121_item	3673225	et	4	main
eksamitöö	doc_491521502121_item	3673224	et	4	main
romantiline	doc_491521502121_item	3673381	et	3	main
ja	doc_491521502121_item	3673374	et	3	main
rahva	doc_491521502121_item	3673371	et	3	main
eesti	doc_491521502121_item	3673370	et	4	main
carl	doc_491521502121_item	3673356	et	4	main
2	doc_491521502121_item	3673355	et	2	main
areng	doc_491521502121_item	3673354	et	3	main
kirjanduse	doc_491521502121_item	3673353	et	3	main
talvet	doc_491521502121_item	3673352	et	4	main
alver	doc_491521502121_item	3673351	et	4	main
arbujad	doc_491521502121_item	3673350	et	4	main
rühmitus	doc_491521502121_item	3673349	et	4	main
looming	doc_491521502121_item	3673348	et	3	main
ajakiri	doc_491521502121_item	3673347	et	3	main
tuglas	doc_491521502121_item	3673346	et	4	main
gailit	doc_491521502121_item	3673345	et	4	main
adson	doc_491521502121_item	3673344	et	4	main
visnapuu	doc_491521502121_item	3673343	et	4	main
rühmitus	doc_491521502121_item	3673342	et	4	main
emakeelne	doc_491521502121_item	3673230	et	3	main
13	doc_491521502121_item	3673379	et	2	main
enne	doc_491521502121_item	3673378	et	4	main
koiduajast	doc_491521502121_item	3673375	et	4	main
robert	doc_491521502121_item	3673357	et	4	main
olid	doc_980560860275_item	3673648	et	4	main
läänemerile	doc_980560860275_item	3673734	et	4	main
sõitsime	doc_980560860275_item	3673733	et	3	main
esimese	doc_980560860275_item	3673722	et	3	main
vaatasime	doc_980560860275_item	3673718	et	3	main
meie	doc_980560860275_item	3673717	et	4	main
parima	doc_980560860275_item	3673704	et	4	main
reisil	doc_980560860275_item	3673683	et	3	main
ujuma	doc_980560860275_item	3673678	et	3	main
käisin	doc_980560860275_item	3673677	et	3	main
horvaatiale	doc_980560860275_item	3673675	et	4	main
puhkusele	doc_980560860275_item	3673661	et	4	main
alustasin	doc_980560860275_item	3673654	et	3	main
sa	doc_980560860275_item	3673650	et	3	main
kirjuta	doc_980560860275_item	3673643	et	4	main
oli	doc_980560860275_item	3673739	et	3	main
randle	doc_980560860275_item	3673737	et	4	main
elasime	doc_980560860275_item	3673736	et	3	main
meie	doc_980560860275_item	3673735	et	4	main
ma	doc_980560860275_item	3673723	et	3	main
said	doc_980560860275_item	3673720	et	4	main
veebruars	doc_980560860275_item	3673711	et	4	main
oma	doc_980560860275_item	3673708	et	4	main
kohtusin	doc_980560860275_item	3673707	et	4	main
ma	doc_980560860275_item	3673706	et	3	main
sõbraga	doc_980560860275_item	3673705	et	3	main
oma	doc_980560860275_item	3673703	et	4	main
kohtusid	doc_980560860275_item	3673702	et	4	main
pärnus	doc_980560860275_item	3673701	et	3	main
jäime	doc_980560860275_item	3673700	et	3	main
meie	doc_980560860275_item	3673699	et	4	main
auto	doc_980560860275_item	3673698	et	4	main
läksime	doc_980560860275_item	3673697	et	3	main
meie	doc_980560860275_item	3673696	et	4	main
kuuresaare	doc_980560860275_item	3673695	et	4	main
ja	doc_980560860275_item	3673694	et	3	main
pärnu	doc_980560860275_item	3673693	et	4	main
narva	doc_980560860275_item	3673692	et	4	main
otsisime	doc_980560860275_item	3673691	et	3	main
sõbrad	doc_980560860275_item	3673690	et	3	main
minu	doc_980560860275_item	3673689	et	3	main
ja	doc_980560860275_item	3673688	et	3	main
ma	doc_980560860275_item	3673687	et	3	main
eestile	doc_980560860275_item	3673686	et	3	main
klubis	doc_980560860275_item	3673679	et	3	main
ma	doc_980560860275_item	3673676	et	3	main
sõitsin	doc_980560860275_item	3673674	et	3	main
ma	doc_980560860275_item	3673670	et	3	main
kirjutama	doc_980560860275_item	3673666	et	3	main
ja	doc_980560860275_item	3673665	et	3	main
lugema	doc_980560860275_item	3673664	et	4	main
õppisin	doc_980560860275_item	3673663	et	3	main
ma	doc_980560860275_item	3673662	et	3	main
lähen	doc_980560860275_item	3673655	et	3	main
esimese	doc_980560860274_item	3673818	et	3	main
said	doc_980560860274_item	3673816	et	4	main
ta	doc_980560860274_item	3673812	et	4	main
jäi	doc_980560860274_item	3673806	et	3	main
minu	doc_980560860274_item	3673804	et	3	main
kohtusid	doc_980560860274_item	3673800	et	4	main
me	doc_980560860274_item	3673796	et	4	main
sõbraga	doc_980560860274_item	3673795	et	3	main
läksin	doc_980560860274_item	3673794	et	3	main
ma	doc_980560860274_item	3673793	et	3	main
sa	doc_980560860274_item	3673785	et	3	main
ei	doc_980560860274_item	3673781	et	4	main
15-aastane	doc_980560860274_item	3673772	et	4	main
olid	doc_980560860274_item	3673771	et	4	main
kümme-aastane	doc_980560860273_item	3673940	et	4	main
rääkisin	doc_980560860273_item	3673922	et	3	main
2007	doc_980560860273_item	3673913	et	2	main
ma	doc_980560860273_item	3673867	et	3	main
olid	doc_980560860273_item	3673864	et	4	main
kui	doc_980560860273_item	3673847	et	3	main
sa	doc_980560860273_item	3673844	et	3	main
elavad	doc_542009824749_item	3674095	et	4	main
kes	doc_542009824749_item	3674093	et	4	main
inimestest	doc_542009824749_item	3674092	et	3	main
peaksid	doc_542009824749_item	3674085	et	4	main
ja	doc_542009824749_item	3674083	et	3	main
kus	doc_542009824749_item	3674080	et	3	main
veel	doc_542009824749_item	3674066	et	4	main
koidula	doc_542009824749_item	3674062	et	4	main
nagu	doc_542009824749_item	3674060	et	3	main
tuntum	doc_542009824749_item	3674051	et	4	main
see	doc_542009824749_item	3674047	et	3	main
tema	doc_542009824749_item	3674044	et	4	main
oskar	doc_542009824749_item	3674041	et	4	main
ennkõige	doc_542009824749_item	3674040	et	4	main
meenub	doc_542009824749_item	3674039	et	3	main
iga	doc_542009824749_item	3674003	et	4	main
koera	doc_980560860274_item	3673831	et	4	main
seda	doc_980560860274_item	3673830	et	3	main
armastasin	doc_980560860274_item	3673829	et	3	main
ma	doc_980560860274_item	3673828	et	3	main
aastane	doc_980560860274_item	3673827	et	4	main
6	doc_980560860274_item	3673826	et	2	main
olin	doc_980560860274_item	3673825	et	3	main
ma	doc_980560860274_item	3673824	et	3	main
esimese	doc_980560860274_item	3673822	et	3	main
ma	doc_980560860274_item	3673819	et	3	main
minu	doc_980560860274_item	3673807	et	3	main
viimasel	doc_980560860274_item	3673787	et	3	main
olid	doc_980560860274_item	3673786	et	4	main
raske	doc_980560860274_item	3673778	et	4	main
keelt	doc_980560860274_item	3673769	et	4	main
ma	doc_980560860274_item	3673759	et	3	main
algkooli	doc_980560860274_item	3673758	et	4	main
käisin	doc_980560860274_item	3673757	et	3	main
ma	doc_980560860274_item	3673756	et	3	main
7-aastane	doc_980560860274_item	3673755	et	4	main
olid	doc_980560860274_item	3673754	et	4	main
sa	doc_980560860274_item	3673753	et	3	main
kui	doc_980560860274_item	3673752	et	3	main
olid	doc_980560860274_item	3673751	et	4	main
kus	doc_980560860274_item	3673750	et	3	main
tegid	doc_980560860274_item	3673749	et	4	main
sa	doc_980560860274_item	3673748	et	3	main
mida	doc_980560860274_item	3673747	et	4	main
kirjuta	doc_980560860274_item	3673746	et	4	main
3	doc_980560860274_item	3673745	et	2	main
küsimusele	doc_980560860274_item	3673744	et	4	main
vastus	doc_980560860274_item	3673743	et	3	main
hoorlanis	doc_980560860273_item	3673937	et	4	main
hollandis	doc_980560860273_item	3673924	et	4	main
sõbraga	doc_980560860273_item	3673923	et	3	main
ma	doc_980560860273_item	3673921	et	3	main
parima	doc_980560860273_item	3673916	et	4	main
restoranis	doc_980560860273_item	3673911	et	3	main
sõbraga	doc_980560860273_item	3673908	et	3	main
sõbraga	doc_980560860273_item	3673875	et	3	main
ma	doc_980560860273_item	3673873	et	3	main
vaatasin	doc_980560860273_item	3673852	et	3	main
ma	doc_980560860273_item	3673851	et	3	main
ma	doc_980560860273_item	3673848	et	3	main
olid	doc_980560860273_item	3673845	et	4	main
olid	doc_980560860273_item	3673842	et	4	main
kus	doc_980560860273_item	3673841	et	3	main
siin	doc_542009824749_item	3674094	et	4	main
ja	doc_542009824749_item	3674091	et	3	main
inimesed	doc_542009824749_item	3674086	et	3	main
maitsev	doc_542009824749_item	3674074	et	4	main
sest	doc_542009824749_item	3674070	et	4	main
meenub	doc_542009824749_item	3674068	et	3	main
paljud	doc_542009824749_item	3674064	et	3	main
teisi	doc_542009824749_item	3674058	et	4	main
vist	doc_542009824749_item	3674049	et	4	main
mulle	doc_542009824749_item	3674038	et	4	main
siis	doc_542009824749_item	3674037	et	3	main
kultuur	doc_542009824749_item	3674036	et	3	main
eesti	doc_542009824749_item	3674035	et	4	main
käituma	doc_542009824749_item	3674005	et	3	main
inimene	doc_542009824749_item	3674004	et	3	main
kultuur	doc_542009824749_item	3673996	et	3	main
toime	doc_542009824749_item	3673986	et	4	main
igapäevases	doc_542009824749_item	3673984	et	4	main
oluline	doc_542009824749_item	3673974	et	4	main
teada	doc_542009824749_item	3673968	et	3	main
tahaksin	doc_542009824749_item	3673966	et	3	main
eestlased	doc_542009824745_item	3674190	et	3	main
puudub	doc_542009824745_item	3674137	et	3	main
ka	doc_542009824745_item	3674136	et	3	main
siia	doc_542009824745_item	3674135	et	4	main
ühiskonnades	doc_542009824745_item	3674129	et	3	main
ostsime	doc_980560860274_item	3673797	et	3	main
reisil	doc_980560860274_item	3673788	et	3	main
oli	doc_980560860274_item	3673782	et	3	main
ma	doc_980560860274_item	3673780	et	3	main
jaapani	doc_980560860274_item	3673768	et	4	main
õppisin	doc_980560860274_item	3673767	et	3	main
ma	doc_980560860274_item	3673766	et	3	main
tüdruk	doc_980560860274_item	3673765	et	3	main
väike	doc_980560860274_item	3673764	et	4	main
olin	doc_980560860274_item	3673763	et	3	main
ma	doc_980560860274_item	3673762	et	3	main
olin	doc_980560860273_item	3673939	et	3	main
ma	doc_980560860273_item	3673929	et	3	main
esimese	doc_980560860273_item	3673928	et	3	main
ma	doc_980560860273_item	3673918	et	3	main
novembri	doc_980560860273_item	3673912	et	3	main
ma	doc_980560860273_item	3673906	et	3	main
käisin	doc_980560860273_item	3673904	et	3	main
vaatisin	doc_980560860273_item	3673877	et	4	main
koolis	doc_980560860273_item	3673872	et	4	main
kaisin	doc_980560860273_item	3673871	et	4	main
ma	doc_980560860273_item	3673870	et	3	main
15-aastane	doc_980560860273_item	3673869	et	4	main
olin	doc_980560860273_item	3673868	et	3	main
kui	doc_980560860273_item	3673866	et	3	main
sa	doc_980560860273_item	3673863	et	3	main
ma	doc_980560860273_item	3673938	et	3	main
cd	doc_980560860273_item	3673935	et	4	main
ma	doc_980560860273_item	3673933	et	3	main
kuulasin	doc_980560860273_item	3673930	et	3	main
pubis	doc_980560860273_item	3673920	et	4	main
käisin	doc_980560860273_item	3673910	et	3	main
pubis	doc_980560860273_item	3673905	et	4	main
berlinis	doc_980560860273_item	3673902	et	4	main
ma	doc_980560860273_item	3673900	et	3	main
berlinis	doc_980560860273_item	3673899	et	4	main
reisil	doc_980560860273_item	3673898	et	3	main
viimasel	doc_980560860273_item	3673897	et	3	main
olin	doc_980560860273_item	3673896	et	3	main
ma	doc_980560860273_item	3673895	et	3	main
reisil	doc_980560860273_item	3673894	et	3	main
viimasel	doc_980560860273_item	3673893	et	3	main
olid	doc_980560860273_item	3673892	et	4	main
sa	doc_980560860273_item	3673891	et	3	main
kodus	doc_980560860273_item	3673890	et	4	main
olin	doc_980560860273_item	3673889	et	3	main
ma	doc_980560860273_item	3673888	et	3	main
käisin	doc_980560860273_item	3673886	et	3	main
ma	doc_980560860273_item	3673885	et	3	main
poes	doc_980560860273_item	3673887	et	3	main
kinos	doc_980560860273_item	3673884	et	3	main
käisin	doc_980560860273_item	3673883	et	3	main
ma	doc_980560860273_item	3673882	et	3	main
muusikat	doc_980560860273_item	3673881	et	3	main
kuulasin	doc_980560860273_item	3673880	et	3	main
ja	doc_980560860273_item	3673879	et	3	main
telekat	doc_980560860273_item	3673878	et	3	main
kohtusid	doc_980560860273_item	3673914	et	4	main
ma	doc_980560860273_item	3673909	et	3	main
rääkisin	doc_980560860273_item	3673907	et	3	main
ma	doc_980560860273_item	3673903	et	3	main
julatasin	doc_980560860273_item	3673901	et	4	main
7-aastane	doc_980560860273_item	3673850	et	4	main
olin	doc_980560860273_item	3673849	et	3	main
rääkima	doc_542009824749_item	3674088	et	3	main
isegi	doc_542009824749_item	3674079	et	4	main
tea	doc_542009824749_item	3674078	et	4	main
on	doc_542009824749_item	3674072	et	4	main
ja	doc_542009824749_item	3674063	et	3	main
tammsaare	doc_542009824749_item	3674061	et	3	main
kirjanikke	doc_542009824749_item	3674059	et	3	main
on	doc_542009824749_item	3674048	et	4	main
peab	doc_542009824749_item	3674002	et	4	main
kuidas	doc_542009824749_item	3674001	et	3	main
see	doc_542009824749_item	3674000	et	3	main
on	doc_542009824749_item	3673999	et	4	main
tuleme	doc_542009824749_item	3673987	et	3	main
asi	doc_542009824749_item	3673975	et	4	main
nende	doc_542009824749_item	3673969	et	4	main
sest	doc_542009824749_item	3673965	et	4	main
kohe	doc_542009824745_item	3674196	et	4	main
teised	doc_542009824745_item	3674188	et	4	main
sellest	doc_542009824745_item	3674139	et	4	main
teadus	doc_542009824745_item	3674138	et	4	main
sõna	doc_542009824745_item	3674106	et	4	main
1	doc_542009824745_item	3674105	et	2	main
kultuur	doc_542009824745_item	3674104	et	3	main
eest	doc_542009824745_item	3674179	et	4	main
meie	doc_542009824745_item	3674150	et	4	main
toimub	doc_542009824745_item	3674145	et	3	main
ja	doc_542009824745_item	3674144	et	3	main
toimus	doc_542009824745_item	3674143	et	3	main
maailmas	doc_542009824745_item	3674142	et	3	main
millal	doc_542009824743_item	3674317	et	3	main
endale	doc_542009824743_item	3674309	et	4	main
midagi	doc_542009824743_item	3674308	et	4	main
kultuuridest	doc_542009824743_item	3674307	et	3	main
ei	doc_542009824743_item	3674295	et	4	main
tuntuv	doc_542009824743_item	3674283	et	4	main
aeg	doc_542009824743_item	3674282	et	3	main
kogu	doc_542009824743_item	3674281	et	4	main
on	doc_542009824743_item	3674280	et	4	main
see	doc_542009824743_item	3674279	et	3	main
aeg	doc_542009824743_item	3674246	et	3	main
jaoks	doc_542009824743_item	3674239	et	4	main
kultuur	doc_542009824743_item	3674236	et	3	main
ja	doc_542009824741_item	3674413	et	3	main
ma	doc_542009824741_item	3674402	et	3	main
ja	doc_542009824741_item	3674395	et	3	main
kultuur	doc_542009824741_item	3674379	et	3	main
2	doc_542009824741_item	3674377	et	2	main
meist	doc_542009824741_item	3674374	et	3	main
iga	doc_542009824741_item	3674365	et	4	main
et	doc_542009824741_item	3674364	et	3	main
ma	doc_542009824741_item	3674362	et	3	main
teistest	doc_542009824741_item	3674360	et	4	main
kultuur	doc_542009824741_item	3674349	et	3	main
kultuur	doc_542009824741_item	3674343	et	3	main
et	doc_842434202395_item	3674452	et	3	main
ma	doc_842434202395_item	3674450	et	3	main
vastus	doc_842434202395_item	3674445	et	3	main
keskkond	doc_842434202395_item	3674517	et	3	main
reosta	doc_842434202395_item	3674515	et	4	main
ei	doc_842434202395_item	3674514	et	4	main
ja	doc_842434202395_item	3674513	et	3	main
noor	doc_842434202395_item	3674512	et	3	main
väga	doc_842434202395_item	3674511	et	3	main
palju	doc_842434202395_item	3674505	et	4	main
ei	doc_842434202395_item	3674502	et	4	main
on	doc_842434202395_item	3674498	et	4	main
on	doc_842434202395_item	3674494	et	4	main
disain	doc_842434202395_item	3674491	et	3	main
ilus	doc_842434202395_item	3674490	et	4	main
on	doc_842434202395_item	3674481	et	4	main
oleks	doc_842434202395_item	3674454	et	3	main
mul	doc_842434202395_item	3674453	et	3	main
ma	doc_980560860273_item	3673876	et	3	main
rääkisin	doc_980560860273_item	3673874	et	3	main
15-aastane	doc_980560860273_item	3673865	et	4	main
kodus	doc_980560860273_item	3673862	et	4	main
olin	doc_980560860273_item	3673861	et	3	main
ma	doc_980560860273_item	3673860	et	3	main
sõbraga	doc_980560860273_item	3673859	et	3	main
mangisin	doc_980560860273_item	3673858	et	4	main
ja	doc_980560860273_item	3673857	et	3	main
rääkisin	doc_980560860273_item	3673856	et	3	main
muusikat	doc_980560860273_item	3673855	et	3	main
kuulasin	doc_980560860273_item	3673854	et	3	main
telekat	doc_980560860273_item	3673853	et	3	main
7-aastane	doc_980560860273_item	3673846	et	4	main
kui	doc_980560860273_item	3673843	et	3	main
tegid	doc_980560860273_item	3673840	et	4	main
sa	doc_980560860273_item	3673839	et	3	main
mida	doc_980560860273_item	3673838	et	4	main
kirjuta	doc_980560860273_item	3673837	et	4	main
3	doc_980560860273_item	3673836	et	2	main
küsimusele	doc_980560860273_item	3673835	et	4	main
vastus	doc_980560860273_item	3673834	et	3	main
teistele	doc_542009824749_item	3674089	et	4	main
ei	doc_542009824749_item	3674077	et	4	main
inimesed	doc_542009824749_item	3674076	et	3	main
paljud	doc_542009824749_item	3674075	et	3	main
see	doc_542009824749_item	3674071	et	3	main
teised	doc_542009824749_item	3674065	et	4	main
palju	doc_542009824749_item	3674057	et	4	main
ka	doc_542009824749_item	3674056	et	3	main
veel	doc_542009824749_item	3674055	et	4	main
kõige	doc_542009824749_item	3674050	et	4	main
kevad	doc_542009824749_item	3674046	et	3	main
peale	doc_542009824749_item	3673994	et	4	main
toitu	doc_542009824749_item	3673992	et	4	main
rahva	doc_542009824749_item	3673991	et	3	main
kombeid	doc_542009824749_item	3673990	et	4	main
tähendab	doc_542009824749_item	3673989	et	3	main
see	doc_542009824749_item	3673988	et	3	main
elus	doc_542009824749_item	3673985	et	4	main
me	doc_542009824749_item	3673983	et	4	main
kuidas	doc_542009824749_item	3673982	et	3	main
see	doc_542009824749_item	3673981	et	3	main
kõige	doc_542009824749_item	3673973	et	4	main
aga	doc_542009824749_item	3673972	et	3	main
riigid	doc_542009824749_item	3673964	et	3	main
meenutan	doc_542009824745_item	3674197	et	3	main
eesti	doc_542009824745_item	3674194	et	4	main
tuntud	doc_542009824745_item	3674189	et	4	main
kultuur	doc_542009824745_item	3674130	et	3	main
rääkime	doc_542009824745_item	3674119	et	4	main
mõtleme	doc_542009824745_item	3674118	et	3	main
terve	doc_542009824745_item	3674112	et	4	main
1	doc_542009824745_item	3674100	et	2	main
küsimusele	doc_542009824745_item	3674099	et	4	main
moodi	doc_542009824745_item	3674178	et	4	main
on	doc_542009824745_item	3674155	et	4	main
kultuur	doc_542009824745_item	3674154	et	3	main
eesti	doc_542009824745_item	3674153	et	4	main
2	doc_542009824745_item	3674152	et	2	main
elu	doc_542009824745_item	3674151	et	4	main
eestist	doc_542009824749_item	3674090	et	3	main
eestist	doc_542009824749_item	3674087	et	3	main
sellepärast	doc_542009824749_item	3674084	et	3	main
eesti	doc_542009824749_item	3674082	et	4	main
asub	doc_542009824749_item	3674081	et	3	main
väga	doc_542009824749_item	3674073	et	3	main
rahvatoit	doc_542009824749_item	3674069	et	3	main
mulle	doc_542009824749_item	3674067	et	4	main
on	doc_542009824749_item	3674054	et	4	main
eestis	doc_542009824749_item	3674053	et	3	main
kirjanik	doc_542009824749_item	3674052	et	3	main
teos	doc_542009824749_item	3674045	et	4	main
ja	doc_542009824749_item	3674043	et	3	main
luts	doc_542009824749_item	3674042	et	3	main
sõna	doc_542009824749_item	3674034	et	4	main
kuulen	doc_542009824749_item	3674033	et	3	main
ma	doc_542009824749_item	3674032	et	3	main
kui	doc_542009824749_item	3674031	et	3	main
2	doc_542009824749_item	3674030	et	2	main
mulje	doc_542009824749_item	3674029	et	4	main
halb	doc_542009824749_item	3674028	et	3	main
jääb	doc_542009824749_item	3674027	et	3	main
inimestest	doc_542009824749_item	3674026	et	3	main
sellistest	doc_542009824749_item	3674025	et	4	main
sest	doc_542009824749_item	3674024	et	4	main
riigile	doc_542009824749_item	3674023	et	3	main
kasuks	doc_542009824749_item	3674022	et	4	main
tule	doc_542009824749_item	3674021	et	4	main
ei	doc_542009824749_item	3674020	et	4	main
see	doc_542009824749_item	3674019	et	3	main
ja	doc_542009824749_item	3674018	et	3	main
kohas	doc_542009824749_item	3674017	et	4	main
muus	doc_542009824749_item	3674016	et	4	main
või	doc_542009824749_item	3674015	et	4	main
tänaval	doc_542009824749_item	3674014	et	4	main
teisi	doc_542009824749_item	3674013	et	4	main
sõimab	doc_542009824749_item	3674012	et	3	main
ta	doc_542009824749_item	3674011	et	4	main
kui	doc_542009824749_item	3674010	et	3	main
meeldiks	doc_542009824749_item	3674009	et	3	main
ei	doc_542009824749_item	3674008	et	4	main
kellelegi	doc_542009824749_item	3674007	et	4	main
näiteks	doc_542009824749_item	3674006	et	4	main
meelest	doc_542009824749_item	3673998	et	4	main
minu	doc_542009824749_item	3673997	et	3	main
seda	doc_542009824749_item	3673995	et	3	main
laule	doc_542009824749_item	3673993	et	4	main
kultuur	doc_542009824749_item	3673979	et	3	main
sõna	doc_542009824749_item	3673978	et	4	main
kuulen	doc_542009824749_item	3673977	et	3	main
kui	doc_542009824749_item	3673976	et	3	main
rohkem	doc_542009824749_item	3673967	et	4	main
erinevad	doc_542009824749_item	3673963	et	4	main
meelde	doc_542009824749_item	3673962	et	3	main
tulevad	doc_542009824749_item	3673961	et	4	main
kreutzwald	doc_542009824745_item	3674186	et	4	main
lidia	doc_542009824745_item	3674184	et	4	main
see	doc_542009824745_item	3674131	et	3	main
käituda	doc_542009824745_item	3674127	et	3	main
me	doc_542009824745_item	3674117	et	4	main
kuidas	doc_542009824745_item	3674116	et	3	main
käitumine	doc_542009824745_item	3674115	et	4	main
eesti	doc_542009824745_item	3674103	et	4	main
2	doc_542009824745_item	3674102	et	2	main
kultuur	doc_542009824745_item	3674101	et	3	main
peale	doc_542009824743_item	3674314	et	4	main
ole	doc_542009824743_item	3674296	et	4	main
on	doc_542009824743_item	3674288	et	4	main
eesti	doc_542009824743_item	3674285	et	4	main
areneb	doc_542009824743_item	3674247	et	3	main
kultuur	doc_542009824743_item	3674244	et	3	main
hea	doc_542009824743_item	3674242	et	4	main
käitumine	doc_542009824743_item	3674241	et	4	main
minu	doc_542009824743_item	3674238	et	3	main
kultuur	doc_542009824743_item	3674237	et	3	main
kultuur	doc_542009824743_item	3674234	et	3	main
fraasi	doc_542009824743_item	3674232	et	4	main
kuulate	doc_542009824743_item	3674231	et	3	main
te	doc_542009824743_item	3674230	et	4	main
kui	doc_542009824743_item	3674229	et	3	main
mõtlete	doc_542009824743_item	3674228	et	3	main
te	doc_542009824743_item	3674227	et	4	main
mida	doc_542009824743_item	3674226	et	4	main
2	doc_542009824743_item	3674225	et	2	main
kultuur	doc_542009824743_item	3674224	et	3	main
sõna	doc_542009824743_item	3674223	et	4	main
kuulate	doc_542009824743_item	3674222	et	3	main
te	doc_542009824743_item	3674221	et	4	main
kui	doc_542009824743_item	3674220	et	3	main
mõtlete	doc_542009824743_item	3674219	et	3	main
te	doc_542009824743_item	3674218	et	4	main
mida	doc_542009824743_item	3674217	et	4	main
1	doc_542009824743_item	3674216	et	2	main
küsimusele	doc_542009824743_item	3674215	et	4	main
vastus	doc_542009824743_item	3674214	et	3	main
tantsisid	doc_542009824741_item	3674421	et	4	main
ei	doc_542009824741_item	3674403	et	4	main
on	doc_542009824741_item	3674398	et	4	main
ka	doc_542009824741_item	3674397	et	3	main
kultuur	doc_542009824741_item	3674394	et	3	main
kui	doc_542009824741_item	3674380	et	3	main
seda	doc_542009824741_item	3674375	et	3	main
kahjuks	doc_542009824741_item	3674372	et	4	main
peab	doc_542009824741_item	3674367	et	4	main
traditsioonidest	doc_542009824741_item	3674357	et	3	main
kombest	doc_542009824741_item	3674355	et	4	main
koosneb	doc_542009824741_item	3674354	et	3	main
see	doc_542009824741_item	3674353	et	3	main
mahukas	doc_542009824741_item	3674352	et	4	main
on	doc_542009824749_item	3673980	et	4	main
rohkem	doc_542009824749_item	3673971	et	4	main
kultuurist	doc_542009824749_item	3673970	et	3	main
pealt	doc_542009824749_item	3673960	et	4	main
kõige	doc_542009824749_item	3673959	et	4	main
mulle	doc_542009824749_item	3673958	et	4	main
siis	doc_542009824749_item	3673957	et	3	main
kultuur	doc_542009824749_item	3673956	et	3	main
sõna	doc_542009824749_item	3673955	et	4	main
kuulen	doc_542009824749_item	3673954	et	3	main
ma	doc_542009824749_item	3673953	et	3	main
kui	doc_542009824749_item	3673952	et	3	main
1	doc_542009824749_item	3673951	et	2	main
vastused	doc_542009824749_item	3673950	et	3	main
kultuur	doc_542009824749_item	3673949	et	3	main
eesti	doc_542009824749_item	3673948	et	4	main
2	doc_542009824749_item	3673947	et	2	main
kultuur	doc_542009824749_item	3673946	et	3	main
1	doc_542009824749_item	3673945	et	2	main
küsimusele	doc_542009824749_item	3673944	et	4	main
vastus	doc_542009824749_item	3673943	et	3	main
riigiks	doc_542009824745_item	3674211	et	3	main
iseseisevaks	doc_542009824745_item	3674210	et	3	main
sai	doc_542009824745_item	3674209	et	4	main
ta	doc_542009824745_item	3674208	et	4	main
kuidas	doc_542009824745_item	3674207	et	3	main
ja	doc_542009824745_item	3674206	et	3	main
sssrs	doc_542009824745_item	3674205	et	4	main
oli	doc_542009824745_item	3674203	et	3	main
eesti	doc_542009824745_item	3674204	et	4	main
enne	doc_542009824745_item	3674202	et	4	main
kuidas	doc_542009824745_item	3674201	et	3	main
ja	doc_542009824745_item	3674200	et	3	main
1991	doc_542009824745_item	3674199	et	2	main
aasta	doc_542009824745_item	3674198	et	4	main
kultuur	doc_542009824745_item	3674195	et	3	main
sõnad	doc_542009824745_item	3674193	et	4	main
kuulan	doc_542009824745_item	3674192	et	3	main
kui	doc_542009824745_item	3674191	et	3	main
ja	doc_542009824745_item	3674187	et	3	main
koidula	doc_542009824745_item	3674185	et	4	main
seotud	doc_542009824745_item	3674183	et	4	main
mis	doc_542009824745_item	3674141	et	4	main
et	doc_542009824745_item	3674140	et	3	main
austus	doc_542009824745_item	3674134	et	4	main
ka	doc_542009824745_item	3674133	et	3	main
on	doc_542009824745_item	3674132	et	4	main
erinevates	doc_542009824745_item	3674128	et	4	main
tunneme	doc_542009824745_item	3674122	et	3	main
me	doc_542009824745_item	3674121	et	4	main
kuidas	doc_542009824745_item	3674120	et	3	main
eluga	doc_542009824745_item	3674113	et	3	main
mul	doc_542009824745_item	3674110	et	3	main
vastus	doc_542009824745_item	3674098	et	3	main
on	doc_542009824745_item	3674182	et	4	main
mul	doc_542009824745_item	3674181	et	3	main
teist	doc_542009824745_item	3674177	et	4	main
kõik	doc_542009824745_item	3674176	et	4	main
tundub	doc_542009824745_item	3674175	et	3	main
mul	doc_542009824745_item	3674174	et	3	main
riikiges	doc_542009824745_item	3674173	et	4	main
teistes	doc_542009824745_item	3674172	et	4	main
ja	doc_542009824745_item	3674171	et	3	main
elan	doc_542009824745_item	3674170	et	3	main
siin	doc_542009824745_item	3674169	et	4	main
et	doc_542009824745_item	3674168	et	3	main
pärast	doc_542009824745_item	3674167	et	4	main
selle	doc_542009824745_item	3674166	et	4	main
vist	doc_542009824745_item	3674165	et	4	main
kultuurig	doc_542009824745_item	3674164	et	4	main
teiste	doc_542009824745_item	3674163	et	4	main
erinev	doc_542009824745_item	3674162	et	4	main
on	doc_542009824745_item	3674161	et	4	main
ek	doc_542009824745_item	3674160	et	4	main
keel	doc_542009824745_item	3674159	et	4	main
oma	doc_542009824745_item	3674158	et	4	main
ajalugu	doc_542009824745_item	3674157	et	4	main
eesti	doc_542009824745_item	3674156	et	4	main
vaja	doc_542009824745_item	3674126	et	4	main
on	doc_542009824745_item	3674125	et	4	main
kuidas	doc_542009824745_item	3674124	et	3	main
et	doc_542009824745_item	3674123	et	3	main
meie	doc_542009824745_item	3674114	et	4	main
meie	doc_542009824745_item	3674111	et	4	main
seostatud	doc_542009824745_item	3674109	et	4	main
on	doc_542009824745_item	3674108	et	4	main
kultuur	doc_542009824745_item	3674107	et	3	main
kultuur	doc_542009824745_item	3674180	et	3	main
on	doc_542009824745_item	3674148	et	4	main
kultuur	doc_542009824745_item	3674147	et	3	main
praegu	doc_542009824745_item	3674146	et	3	main
aja	doc_542009824743_item	3674316	et	4	main
nõukogumiste	doc_542009824743_item	3674315	et	4	main
tihti	doc_542009824743_item	3674304	et	3	main
kultuur	doc_542009824743_item	3674302	et	3	main
on	doc_542009824743_item	3674300	et	4	main
kultuur	doc_542009824743_item	3674299	et	3	main
eesti	doc_542009824743_item	3674298	et	4	main
suur	doc_542009824743_item	3674297	et	3	main
eesti	doc_542009824743_item	3674287	et	4	main
2	doc_542009824743_item	3674284	et	2	main
kogu	doc_542009824743_item	3674245	et	4	main
suhtlemine	doc_542009824743_item	3674243	et	4	main
ja	doc_542009824741_item	3674422	et	3	main
et	doc_542009824741_item	3674418	et	3	main
tundub	doc_542009824741_item	3674417	et	3	main
laulupeod	doc_542009824741_item	3674415	et	4	main
kultuur	doc_542009824741_item	3674401	et	3	main
on	doc_542009824741_item	3674392	et	4	main
rahval	doc_542009824741_item	3674391	et	3	main
igal	doc_542009824741_item	3674390	et	3	main
teada	doc_542009824741_item	3674368	et	3	main
asjadest	doc_542009824741_item	3674361	et	3	main
paljudest	doc_542009824741_item	3674359	et	3	main
ja	doc_542009824741_item	3674358	et	3	main
ajaloost	doc_542009824741_item	3674356	et	4	main
üldiselt	doc_542009824741_item	3674347	et	4	main
unistuse	doc_842434202395_item	3674448	et	4	main
nagu	doc_842434202395_item	3674520	et	3	main
raisata	doc_842434202395_item	3674507	et	4	main
raha	doc_842434202395_item	3674506	et	4	main
kütusekulu	doc_842434202395_item	3674500	et	4	main
väikestel	doc_842434202395_item	3674496	et	4	main
moodne	doc_842434202395_item	3674495	et	3	main
ta	doc_842434202395_item	3674493	et	4	main
ja	doc_842434202395_item	3674492	et	3	main
ilm	doc_842434202395_item	3674483	et	3	main
kuiv	doc_842434202395_item	3674482	et	3	main
on	doc_723935141569_item	3674632	et	4	main
et	doc_723935141569_item	3674618	et	3	main
ajalugu	doc_723935141569_item	3674607	et	4	main
toimus	doc_723935141569_item	3674593	et	3	main
mis	doc_723935141569_item	3674591	et	4	main
on	doc_723935141569_item	3674582	et	4	main
kultuur	doc_723935141569_item	3674580	et	3	main
rääkime	doc_723935141569_item	3674570	et	4	main
mõtleme	doc_723935141569_item	3674569	et	3	main
üldiselt	doc_542009824745_item	3674149	et	4	main
areneb	doc_542009824743_item	3674313	et	3	main
kiiresti	doc_542009824743_item	3674312	et	3	main
kultuur	doc_542009824743_item	3674311	et	3	main
teistest	doc_542009824743_item	3674306	et	4	main
ka	doc_542009824743_item	3674294	et	3	main
kultuur	doc_542009824743_item	3674293	et	3	main
meie	doc_542009824743_item	3674292	et	4	main
kultuur	doc_542009824743_item	3674286	et	3	main
hea	doc_542009824743_item	3674240	et	4	main
alati	doc_542009824741_item	3674420	et	4	main
mul	doc_542009824741_item	3674416	et	3	main
rahvatantsud	doc_542009824741_item	3674412	et	3	main
rohkem	doc_542009824743_item	3674329	et	4	main
natuke	doc_542009824743_item	3674328	et	4	main
sellest	doc_542009824743_item	3674327	et	4	main
teada	doc_542009824743_item	3674326	et	3	main
tahaks	doc_542009824743_item	3674325	et	3	main
omapärane	doc_542009824743_item	3674324	et	4	main
väga	doc_542009824743_item	3674323	et	3	main
on	doc_542009824743_item	3674322	et	4	main
kultuur	doc_542009824743_item	3674321	et	3	main
eesti	doc_542009824743_item	3674320	et	4	main
seisis	doc_542009824743_item	3674319	et	4	main
see	doc_542009824743_item	3674318	et	3	main
eesti	doc_542009824743_item	3674310	et	4	main
laenavad	doc_542009824743_item	3674305	et	4	main
eestlased	doc_542009824743_item	3674303	et	3	main
segu	doc_542009824743_item	3674301	et	4	main
ja	doc_542009824743_item	3674291	et	3	main
riik	doc_542009824743_item	3674290	et	3	main
väike	doc_542009824743_item	3674289	et	4	main
vaid	doc_542009824743_item	3674278	et	3	main
puutuda	doc_542009824743_item	3674277	et	3	main
saa	doc_542009824743_item	3674276	et	4	main
ei	doc_542009824743_item	3674275	et	4	main
mis	doc_542009824743_item	3674274	et	4	main
see	doc_542009824743_item	3674273	et	3	main
on	doc_542009824743_item	3674272	et	4	main
kultuur	doc_542009824743_item	3674271	et	3	main
edasi	doc_542009824743_item	3674270	et	3	main
anname	doc_542009824743_item	3674269	et	3	main
me	doc_542009824743_item	3674268	et	4	main
mis	doc_542009824743_item	3674267	et	4	main
ja	doc_542009824743_item	3674266	et	3	main
vanematest	doc_542009824743_item	3674265	et	4	main
meie	doc_542009824743_item	3674264	et	4	main
meile	doc_542009824743_item	3674263	et	4	main
jaanud	doc_542009824743_item	3674262	et	4	main
mis	doc_542009824743_item	3674261	et	4	main
see	doc_542009824743_item	3674260	et	3	main
on	doc_542009824743_item	3674259	et	4	main
see	doc_542009824743_item	3674258	et	3	main
kultuur	doc_542009824743_item	3674257	et	3	main
poole	doc_542009824743_item	3674256	et	4	main
paremale	doc_542009824743_item	3674255	et	4	main
liigub	doc_542009824743_item	3674254	et	3	main
aeg	doc_542009824743_item	3674253	et	3	main
kogu	doc_542009824743_item	3674252	et	4	main
mitte	doc_542009824743_item	3674251	et	3	main
arenemine	doc_542009824743_item	3674250	et	4	main
see	doc_542009824743_item	3674249	et	3	main
aga	doc_542009824743_item	3674248	et	3	main
1	doc_542009824743_item	3674235	et	2	main
eesti	doc_542009824743_item	3674233	et	4	main
eestlased	doc_542009824741_item	3674419	et	3	main
rahvariided	doc_542009824741_item	3674414	et	3	main
kohe	doc_542009824741_item	3674411	et	4	main
minu	doc_542009824741_item	3674408	et	3	main
aga	doc_542009824741_item	3674407	et	3	main
hästi	doc_542009824741_item	3674406	et	3	main
seda	doc_542009824741_item	3674405	et	3	main
tea	doc_542009824741_item	3674404	et	4	main
ajalooline	doc_542009824741_item	3674400	et	4	main
oma	doc_542009824741_item	3674399	et	4	main
et	doc_542009824741_item	3674389	et	3	main
mõtlen	doc_542009824741_item	3674387	et	3	main
ma	doc_542009824741_item	3674386	et	3	main
kultuur	doc_542009824741_item	3674385	et	3	main
eesti	doc_542009824741_item	3674384	et	4	main
sõnaühend	doc_542009824741_item	3674383	et	3	main
kuulan	doc_542009824741_item	3674382	et	3	main
ma	doc_542009824741_item	3674381	et	3	main
eesti	doc_542009824741_item	3674378	et	4	main
tunnevad	doc_542009824741_item	3674376	et	3	main
vähesed	doc_542009824741_item	3674373	et	3	main
kultuurit	doc_542009824741_item	3674370	et	4	main
oma	doc_542009824741_item	3674369	et	4	main
rahval	doc_542009824741_item	3674346	et	3	main
on	doc_542009824741_item	3674344	et	4	main
sellest	doc_542009824741_item	3674442	et	4	main
õelda	doc_542009824741_item	3674441	et	4	main
palju	doc_542009824741_item	3674440	et	4	main
saa	doc_542009824741_item	3674439	et	4	main
ei	doc_542009824741_item	3674438	et	4	main
ja	doc_542009824741_item	3674437	et	3	main
hästi	doc_542009824741_item	3674436	et	3	main
neid	doc_542009824741_item	3674435	et	4	main
tea	doc_542009824741_item	3674434	et	4	main
ei	doc_542009824741_item	3674433	et	4	main
ma	doc_542009824741_item	3674432	et	3	main
aga	doc_542009824741_item	3674431	et	3	main
kombesid	doc_542009824741_item	3674430	et	4	main
ja	doc_542009824741_item	3674429	et	3	main
traditsioone	doc_542009824741_item	3674428	et	3	main
palju	doc_542009824741_item	3674427	et	4	main
on	doc_542009824741_item	3674426	et	4	main
kultuuris	doc_542009824741_item	3674425	et	3	main
nende	doc_542009824741_item	3674424	et	4	main
laulsid	doc_542009824741_item	3674423	et	4	main
tulevad	doc_542009824741_item	3674410	et	4	main
meelde	doc_542009824741_item	3674409	et	3	main
eestlastel	doc_542009824741_item	3674396	et	4	main
oma	doc_542009824741_item	3674393	et	4	main
sellest	doc_542009824741_item	3674388	et	4	main
aga	doc_542009824741_item	3674371	et	3	main
inimene	doc_542009824741_item	3674366	et	3	main
arvan	doc_542009824741_item	3674363	et	3	main
on	doc_542009824741_item	3674350	et	4	main
auto	doc_842434202395_item	3674449	et	4	main
nii	doc_842434202395_item	3674518	et	3	main
meie	doc_842434202395_item	3674516	et	4	main
on	doc_842434202395_item	3674510	et	4	main
vaja	doc_842434202395_item	3674504	et	4	main
on	doc_842434202395_item	3674489	et	4	main
temal	doc_842434202395_item	3674488	et	3	main
kui	doc_842434202395_item	3674480	et	3	main
lidia	doc_723935141569_item	3674634	et	4	main
kultluur	doc_723935141569_item	3674630	et	4	main
kultuurig	doc_723935141569_item	3674614	et	4	main
eesti	doc_723935141569_item	3674606	et	4	main
meie	doc_723935141569_item	3674600	et	4	main
üldiselt	doc_723935141569_item	3674599	et	4	main
maailmas	doc_723935141569_item	3674592	et	3	main
siia	doc_723935141569_item	3674585	et	4	main
see	doc_723935141569_item	3674581	et	3	main
ühiskonnades	doc_723935141569_item	3674579	et	3	main
käituda	doc_723935141569_item	3674577	et	3	main
vaja	doc_723935141569_item	3674576	et	4	main
on	doc_723935141569_item	3674575	et	4	main
kuidas	doc_723935141569_item	3674574	et	3	main
tunneme	doc_723935141569_item	3674573	et	3	main
vanemad	doc_516622545496_item	3674780	et	4	main
aga	doc_516622545496_item	3674779	et	3	main
täiskasvasel	doc_516622545496_item	3674772	et	3	main
ka	doc_516622545496_item	3674764	et	3	main
kasutab	doc_516622545496_item	3674761	et	3	main
inimened	doc_516622545496_item	3674759	et	4	main
inimesele	doc_516622545496_item	3674758	et	3	main
asi	doc_516622545496_item	3674754	et	4	main
väga	doc_516622545496_item	3674750	et	3	main
moobiiltelefon	doc_516622545496_item	3674749	et	4	main
et	doc_516622545496_item	3674743	et	3	main
arvan	doc_516622545496_item	3674742	et	3	main
raske	doc_516622545496_item	3674734	et	4	main
on	doc_516622545496_item	3674733	et	4	main
see	doc_516622545496_item	3674732	et	3	main
mobiiltelefon	doc_516622545496_item	3674731	et	3	main
moodi	doc_516622545496_item	3674725	et	4	main
teis	doc_516622545496_item	3674724	et	4	main
väga	doc_542009824741_item	3674351	et	3	main
sõna	doc_542009824741_item	3674348	et	4	main
igal	doc_542009824741_item	3674345	et	3	main
mingisugune	doc_542009824741_item	3674342	et	3	main
kultuur	doc_542009824741_item	3674341	et	3	main
sõna	doc_542009824741_item	3674340	et	4	main
kuulate	doc_542009824741_item	3674339	et	3	main
kui	doc_542009824741_item	3674338	et	3	main
mõtlete	doc_542009824741_item	3674337	et	3	main
te	doc_542009824741_item	3674336	et	4	main
mida	doc_542009824741_item	3674335	et	4	main
1	doc_542009824741_item	3674334	et	2	main
küsimusele	doc_542009824741_item	3674333	et	4	main
vastus	doc_542009824741_item	3674332	et	3	main
minu	doc_842434202395_item	3674447	et	3	main
palju	doc_842434202395_item	3674519	et	4	main
auto	doc_842434202395_item	3674509	et	4	main
see	doc_842434202395_item	3674508	et	3	main
ja	doc_842434202395_item	3674501	et	3	main
väike	doc_842434202395_item	3674499	et	4	main
kattuseta	doc_842434202395_item	3674487	et	4	main
sõita	doc_842434202395_item	3674486	et	3	main
võimalik	doc_842434202395_item	3674485	et	3	main
on	doc_842434202395_item	3674484	et	4	main
ja	doc_842434202395_item	3674478	et	3	main
teised	doc_723935141569_item	3674638	et	4	main
ja	doc_723935141569_item	3674637	et	3	main
kreutzwald	doc_723935141569_item	3674636	et	4	main
pärast	doc_723935141569_item	3674617	et	4	main
selle	doc_723935141569_item	3674616	et	4	main
on	doc_723935141569_item	3674611	et	4	main
keel	doc_723935141569_item	3674609	et	4	main
kultuur	doc_723935141569_item	3674604	et	3	main
eesti	doc_723935141569_item	3674603	et	4	main
2	doc_723935141569_item	3674602	et	2	main
elu	doc_723935141569_item	3674601	et	4	main
ja	doc_723935141569_item	3674594	et	3	main
sellest	doc_723935141569_item	3674589	et	4	main
puudub	doc_723935141569_item	3674587	et	3	main
ka	doc_723935141569_item	3674586	et	3	main
ka	doc_723935141569_item	3674583	et	3	main
erinevates	doc_723935141569_item	3674578	et	4	main
me	doc_723935141569_item	3674568	et	4	main
kuidas	doc_723935141569_item	3674567	et	3	main
palju	doc_516622545496_item	3674777	et	4	main
ainult	doc_516622545496_item	3674771	et	4	main
ma	doc_516622545496_item	3674765	et	3	main
muugav	doc_516622545496_item	3674753	et	4	main
ja	doc_516622545496_item	3674752	et	3	main
hea	doc_516622545496_item	3674751	et	4	main
inimesed	doc_516622545496_item	3674744	et	3	main
ma	doc_516622545496_item	3674686	et	3	main
aga	doc_516622545496_item	3674685	et	3	main
savisaar	doc_601001696377_item	3674823	et	3	main
ja	doc_601001696377_item	3674818	et	3	main
2	doc_601001696377_item	3674809	et	2	main
said	doc_601001696377_item	3674841	et	4	main
noored	doc_601001696377_item	3674840	et	3	main
ettepanekul	doc_601001696377_item	3674839	et	3	main
tehti	doc_601001696377_item	3674837	et	3	main
vanemmeelsem	doc_601001696377_item	3674831	et	4	main
aastal	doc_601001696377_item	3674829	et	3	main
rahvarinnet	doc_601001696377_item	3674827	et	3	main
tahtnud	doc_601001696376_item	3675044	et	4	main
ei	doc_601001696376_item	3675043	et	4	main
inimesed	doc_601001696376_item	3675042	et	3	main
ja	doc_601001696376_item	3675041	et	3	main
palju	doc_601001696376_item	3675040	et	4	main
lõpetama	doc_601001696376_item	3675032	et	4	main
probleemid	doc_601001696376_item	3675025	et	3	main
levisid	doc_601001696376_item	3675022	et	4	main
meeldi	doc_842434202395_item	3674546	et	4	main
mull	doc_842434202395_item	3674544	et	3	main
variandit	doc_842434202395_item	3674543	et	4	main
ei	doc_842434202395_item	3674545	et	4	main
teised	doc_842434202395_item	3674542	et	4	main
sest	doc_842434202395_item	3674541	et	4	main
sedaan	doc_842434202395_item	3674540	et	4	main
olema	doc_842434202395_item	3674539	et	4	main
peab	doc_842434202395_item	3674538	et	4	main
auto	doc_842434202395_item	3674537	et	4	main
unistuse	doc_842434202395_item	3674536	et	4	main
minu	doc_842434202395_item	3674535	et	3	main
metallik	doc_842434202395_item	3674534	et	4	main
hall	doc_842434202395_item	3674533	et	4	main
on	doc_842434202395_item	3674532	et	4	main
ta	doc_842434202395_item	3674531	et	4	main
kui	doc_842434202395_item	3674530	et	3	main
parem	doc_842434202395_item	3674529	et	4	main
aga	doc_842434202395_item	3674528	et	3	main
on	doc_842434202395_item	3674527	et	4	main
tall	doc_842434202395_item	3674526	et	3	main
värv	doc_842434202395_item	3674525	et	3	main
milline	doc_842434202395_item	3674524	et	3	main
ükskõikselt	doc_842434202395_item	3674523	et	4	main
žiguli	doc_842434202395_item	3674522	et	2	main
tahaksin	doc_842434202395_item	3674451	et	3	main
küsimusele	doc_842434202395_item	3674446	et	4	main
vana	doc_842434202395_item	3674521	et	4	main
ole	doc_842434202395_item	3674503	et	4	main
autodel	doc_842434202395_item	3674497	et	3	main
suvel	doc_842434202395_item	3674479	et	3	main
kabriolett	doc_842434202395_item	3674477	et	3	main
on	doc_842434202395_item	3674476	et	4	main
see	doc_842434202395_item	3674474	et	3	main
auto	doc_842434202395_item	3674475	et	4	main
veel	doc_842434202395_item	3674473	et	4	main
parkida	doc_842434202395_item	3674472	et	4	main
lihtne	doc_842434202395_item	3674471	et	3	main
on	doc_842434202395_item	3674470	et	4	main
auto	doc_842434202395_item	3674469	et	4	main
väike	doc_842434202395_item	3674468	et	4	main
sõita	doc_842434202395_item	3674467	et	3	main
temaga	doc_842434202395_item	3674466	et	3	main
kerge	doc_842434202395_item	3674465	et	4	main
ja	doc_842434202395_item	3674464	et	3	main
väike	doc_842434202395_item	3674463	et	4	main
on	doc_842434202395_item	3674462	et	4	main
ta	doc_842434202395_item	3674461	et	4	main
sest	doc_842434202395_item	3674460	et	4	main
tt	doc_842434202395_item	3674459	et	4	main
audi	doc_842434202395_item	3674458	et	3	main
nagu	doc_842434202395_item	3674457	et	3	main
auto	doc_842434202395_item	3674456	et	4	main
selline	doc_842434202395_item	3674455	et	4	main
kui	doc_723935141569_item	3674641	et	3	main
koidula	doc_723935141569_item	3674635	et	4	main
vist	doc_723935141569_item	3674615	et	4	main
erinev	doc_723935141569_item	3674612	et	4	main
on	doc_723935141569_item	3674605	et	4	main
on	doc_723935141569_item	3674598	et	4	main
kultuur	doc_723935141569_item	3674597	et	3	main
praegu	doc_723935141569_item	3674596	et	3	main
austus	doc_723935141569_item	3674584	et	4	main
käitumine	doc_723935141569_item	3674566	et	4	main
meie	doc_723935141569_item	3674565	et	4	main
eluga	doc_723935141569_item	3674564	et	3	main
maksvad	doc_516622545496_item	3674781	et	4	main
räägida	doc_516622545496_item	3674778	et	4	main
et	doc_516622545496_item	3674767	et	3	main
mobiiltelefone	doc_516622545496_item	3674762	et	3	main
palju	doc_516622545496_item	3674746	et	4	main
väga	doc_516622545496_item	3674745	et	3	main
mina	doc_516622545496_item	3674741	et	4	main
selline	doc_516622545496_item	3674740	et	4	main
perestroika	doc_601001696377_item	3674826	et	4	main
võttis	doc_601001696377_item	3674820	et	3	main
13	doc_601001696377_item	3674814	et	2	main
võttis	doc_601001696377_item	3674812	et	3	main
laulev	doc_601001696377_item	3674810	et	4	main
sisu	doc_601001696377_item	3674808	et	4	main
ja	doc_601001696377_item	3674807	et	3	main
tähendus	doc_601001696377_item	3674806	et	4	main
revolutsiooni	doc_601001696377_item	3674797	et	4	main
isamaa	doc_601001696377_item	3674847	et	4	main
moskva	doc_601001696377_item	3674838	et	4	main
riigiks	doc_723935141569_item	3674662	et	3	main
iseseisvaks	doc_723935141569_item	3674661	et	3	main
sai	doc_723935141569_item	3674660	et	4	main
ta	doc_723935141569_item	3674659	et	4	main
kuidas	doc_723935141569_item	3674658	et	3	main
ja	doc_723935141569_item	3674657	et	3	main
s	doc_723935141569_item	3674656	et	4	main
sssr	doc_723935141569_item	3674655	et	4	main
eesti	doc_723935141569_item	3674654	et	4	main
oli	doc_723935141569_item	3674653	et	3	main
enne	doc_723935141569_item	3674652	et	4	main
kuidas	doc_723935141569_item	3674651	et	3	main
ja	doc_723935141569_item	3674650	et	3	main
1991	doc_723935141569_item	3674649	et	2	main
aasta	doc_723935141569_item	3674648	et	4	main
meenutan	doc_723935141569_item	3674647	et	3	main
kohe	doc_723935141569_item	3674646	et	4	main
kultuur	doc_723935141569_item	3674645	et	3	main
esti	doc_723935141569_item	3674644	et	4	main
sõnad	doc_723935141569_item	3674643	et	4	main
kuulan	doc_723935141569_item	3674642	et	3	main
eestlased	doc_723935141569_item	3674640	et	3	main
tuntud	doc_723935141569_item	3674639	et	4	main
seotud	doc_723935141569_item	3674633	et	4	main
mul	doc_723935141569_item	3674631	et	3	main
eest	doc_723935141569_item	3674629	et	4	main
moodi	doc_723935141569_item	3674628	et	4	main
teist	doc_723935141569_item	3674627	et	4	main
kõik	doc_723935141569_item	3674626	et	4	main
tundub	doc_723935141569_item	3674625	et	3	main
mul	doc_723935141569_item	3674624	et	3	main
riikiges	doc_723935141569_item	3674623	et	4	main
teistes	doc_723935141569_item	3674622	et	4	main
ja	doc_723935141569_item	3674621	et	3	main
elan	doc_723935141569_item	3674620	et	3	main
siin	doc_723935141569_item	3674619	et	4	main
teiste	doc_723935141569_item	3674613	et	4	main
ek	doc_723935141569_item	3674610	et	4	main
oma	doc_723935141569_item	3674608	et	4	main
toimub	doc_723935141569_item	3674595	et	3	main
et	doc_723935141569_item	3674590	et	3	main
teadus	doc_723935141569_item	3674588	et	4	main
me	doc_723935141569_item	3674572	et	4	main
kuidas	doc_723935141569_item	3674571	et	3	main
terve	doc_723935141569_item	3674563	et	4	main
meie	doc_723935141569_item	3674562	et	4	main
mul	doc_723935141569_item	3674561	et	3	main
seotud	doc_723935141569_item	3674560	et	4	main
on	doc_723935141569_item	3674559	et	4	main
kultuur	doc_723935141569_item	3674558	et	3	main
sõna	doc_723935141569_item	3674557	et	4	main
1	doc_723935141569_item	3674556	et	2	main
kultuur	doc_723935141569_item	3674555	et	3	main
eesti	doc_723935141569_item	3674554	et	4	main
2	doc_723935141569_item	3674553	et	2	main
kultuur	doc_723935141569_item	3674552	et	3	main
1	doc_723935141569_item	3674551	et	2	main
küsimusele	doc_723935141569_item	3674550	et	4	main
vastus	doc_723935141569_item	3674549	et	3	main
olema	doc_516622545496_item	3674770	et	4	main
peab	doc_516622545496_item	3674769	et	4	main
mobiiltelefon	doc_516622545496_item	3674768	et	3	main
laisk	doc_516622545496_item	3674763	et	3	main
mõjutab	doc_516622545496_item	3674757	et	3	main
mobiiltelefoni	doc_516622545496_item	3674748	et	4	main
kasutavad	doc_516622545496_item	3674747	et	4	main
olema	doc_516622545496_item	3674730	et	4	main
peab	doc_516622545496_item	3674729	et	4	main
kas	doc_516622545496_item	3674726	et	3	main
arvavad	doc_516622545496_item	3674723	et	4	main
inimesed	doc_516622545496_item	3674722	et	3	main
teised	doc_516622545496_item	3674721	et	4	main
olla	doc_516622545496_item	3674720	et	3	main
uskan	doc_516622545496_item	3674687	et	4	main
looen	doc_516622545496_item	3674683	et	4	main
lõi	doc_601001696377_item	3674825	et	4	main
vastu	doc_601001696377_item	3674821	et	3	main
glasnostj	doc_601001696377_item	3674805	et	4	main
ja	doc_601001696377_item	3674804	et	3	main
laulva	doc_601001696377_item	3674796	et	4	main
ja	doc_601001696377_item	3674795	et	3	main
laulsid	doc_601001696377_item	3674846	et	4	main
ja	doc_601001696377_item	3674845	et	3	main
seda	doc_601001696377_item	3674836	et	3	main
parteijuht	doc_601001696377_item	3674832	et	3	main
tööd	doc_601001696376_item	3675035	et	4	main
kolhoosid	doc_601001696376_item	3675034	et	3	main
mõned	doc_601001696376_item	3675033	et	3	main
hakkasid	doc_601001696376_item	3675026	et	4	main
kingiseff	doc_601001696376_item	3675015	et	4	main
selle	doc_601001696376_item	3675011	et	4	main
saaremal	doc_601001696376_item	3675003	et	3	main
kolhooside	doc_601001696376_item	3675001	et	3	main
oli	doc_601001696376_item	3674988	et	3	main
rolli	doc_601001696376_item	3674967	et	4	main
ka	doc_601001696376_item	3674965	et	3	main
ja	doc_601001696376_item	3674961	et	3	main
avatati	doc_601001696376_item	3674950	et	3	main
ka	doc_601001696376_item	3674947	et	3	main
laborotoorium	doc_601001696376_item	3674946	et	4	main
arvest	doc_516622545496_item	3674782	et	4	main
väga	doc_516622545496_item	3674776	et	3	main
lapsed	doc_516622545496_item	3674775	et	3	main
et	doc_516622545496_item	3674774	et	3	main
selleparast	doc_516622545496_item	3674773	et	3	main
arvan	doc_516622545496_item	3674766	et	3	main
kes	doc_516622545496_item	3674760	et	4	main
mobiiltelefon	doc_516622545496_item	3674756	et	3	main
vaid	doc_516622545496_item	3674755	et	3	main
on	doc_516622545496_item	3674739	et	4	main
arvamus	doc_516622545496_item	3674738	et	3	main
minu	doc_516622545496_item	3674737	et	3	main
aga	doc_516622545496_item	3674736	et	3	main
küsimus	doc_516622545496_item	3674735	et	4	main
inimesel	doc_516622545496_item	3674728	et	3	main
igal	doc_516622545496_item	3674727	et	3	main
võib	doc_516622545496_item	3674719	et	3	main
juuhus	doc_516622545496_item	3674718	et	4	main
olla	doc_516622545496_item	3674717	et	3	main
võib	doc_516622545496_item	3674716	et	3	main
elust	doc_516622545496_item	3674715	et	3	main
et	doc_516622545496_item	3674714	et	3	main
arvan	doc_516622545496_item	3674713	et	3	main
ma	doc_516622545496_item	3674712	et	3	main
ka	doc_516622545496_item	3674711	et	3	main
elust	doc_516622545496_item	3674710	et	3	main
oma	doc_516622545496_item	3674709	et	4	main
haakama	doc_516622545496_item	3674708	et	4	main
saab	doc_516622545496_item	3674707	et	3	main
inimene	doc_516622545496_item	3674706	et	3	main
julge	doc_516622545496_item	3674705	et	4	main
ja	doc_516622545496_item	3674704	et	3	main
tugev	doc_516622545496_item	3674703	et	4	main
alnult	doc_516622545496_item	3674702	et	4	main
et	doc_516622545496_item	3674701	et	3	main
arvan	doc_516622545496_item	3674700	et	3	main
mina	doc_516622545496_item	3674699	et	4	main
elust	doc_516622545496_item	3674698	et	3	main
oma	doc_516622545496_item	3674697	et	4	main
muutab	doc_516622545496_item	3674696	et	4	main
midagi	doc_516622545496_item	3674695	et	4	main
võib	doc_516622545496_item	3674694	et	3	main
inimene	doc_516622545496_item	3674693	et	3	main
et	doc_516622545496_item	3674692	et	3	main
arvan	doc_516622545496_item	3674691	et	3	main
ma	doc_516622545496_item	3674690	et	3	main
heast	doc_516622545496_item	3674689	et	3	main
alnul	doc_516622545496_item	3674688	et	4	main
goroskopi	doc_516622545496_item	3674684	et	4	main
tihti	doc_516622545496_item	3674682	et	3	main
ma	doc_516622545496_item	3674681	et	3	main
saatus	doc_516622545496_item	3674680	et	3	main
mõjutab	doc_516622545496_item	3674679	et	3	main
kõige	doc_516622545496_item	3674677	et	4	main
elu	doc_516622545496_item	3674676	et	4	main
rohkem	doc_516622545496_item	3674678	et	4	main
inimese	doc_516622545496_item	3674675	et	4	main
kõigepealt	doc_516622545496_item	3674674	et	3	main
t	doc_516622545496_item	3674673	et	4	main
arvane	doc_516622545496_item	3674672	et	4	main
mina	doc_516622545496_item	3674671	et	4	main
rohkem	doc_516622545496_item	3674670	et	4	main
kõige	doc_516622545496_item	3674669	et	4	main
elu	doc_516622545496_item	3674668	et	4	main
inimese	doc_516622545496_item	3674667	et	4	main
mõjutab	doc_516622545496_item	3674666	et	3	main
mis	doc_516622545496_item	3674665	et	4	main
kontrolltöö	doc_516622545496_item	3674664	et	4	main
edgar	doc_601001696377_item	3674822	et	4	main
selle	doc_601001696377_item	3674819	et	4	main
aastal	doc_601001696377_item	3674817	et	3	main
aprillil	doc_601001696377_item	3674815	et	3	main
perestroika	doc_601001696377_item	3674803	et	4	main
sõnade	doc_601001696377_item	3674802	et	3	main
eesti	doc_601001696377_item	3674799	et	4	main
osa	doc_601001696377_item	3674798	et	4	main
vahetati	doc_601001696377_item	3674830	et	4	main
samal	doc_601001696377_item	3674828	et	3	main
maksta	doc_601001696376_item	3675045	et	4	main
oli	doc_601001696376_item	3675038	et	3	main
varsti	doc_601001696376_item	3675030	et	3	main
maksutasu	doc_601001696376_item	3675029	et	4	main
ruttu	doc_601001696376_item	3675023	et	4	main
võiksid	doc_601001696376_item	3675017	et	4	main
kolhoosidesse	doc_601001696376_item	3675016	et	3	main
nimi	doc_601001696376_item	3675012	et	3	main
6091947	doc_601001696376_item	3675004	et	2	main
ettevalmistused	doc_601001696376_item	3675000	et	3	main
a	doc_601001696376_item	3674998	et	4	main
1947	doc_601001696376_item	3674997	et	2	main
nda	doc_601001696376_item	3674992	et	4	main
ajal	doc_601001696376_item	3674987	et	4	main
võistlustega	doc_601001696376_item	3674984	et	3	main
juhtis	doc_601001696376_item	3674982	et	3	main
kõvemaks	doc_601001696376_item	3674980	et	4	main
armiat	doc_601001696376_item	3674979	et	4	main
tegi	doc_601001696376_item	3674978	et	4	main
strateeg	doc_601001696376_item	3674977	et	3	main
hea	doc_601001696376_item	3674976	et	4	main
väga	doc_601001696376_item	3674975	et	3	main
oli	doc_601001696376_item	3674974	et	3	main
polkovnik	doc_601001696376_item	3674969	et	3	main
tähtsat	doc_601001696376_item	3674966	et	3	main
vabadusse	doc_601001696376_item	3674964	et	4	main
inimeste	doc_601001696376_item	3674962	et	3	main
vaim	doc_601001696376_item	3674960	et	3	main
eriti	doc_601001696376_item	3674907	et	3	main
palju	doc_601001696376_item	3674903	et	4	main
kuiroteod	doc_601001696377_item	3674876	et	4	main
stalinismi	doc_601001696377_item	3674875	et	4	main
ning	doc_601001696377_item	3674874	et	3	main
keskkonnaprobleemid	doc_601001696377_item	3674873	et	3	main
vaated	doc_601001696377_item	3674872	et	3	main
seisukohtade	doc_601001696377_item	3674871	et	3	main
kriitiliste	doc_601001696377_item	3674870	et	3	main
võimalikuks	doc_601001696377_item	3674869	et	3	main
sai	doc_601001696377_item	3674868	et	4	main
kus	doc_601001696377_item	3674867	et	3	main
keskust	doc_601001696377_item	3674866	et	4	main
impeeriumi	doc_601001696377_item	3674865	et	4	main
peamiselt	doc_601001696377_item	3674864	et	4	main
savisaar	doc_601001696377_item	3674824	et	3	main
1988	doc_601001696377_item	3674816	et	2	main
aset	doc_601001696377_item	3674813	et	3	main
revolutsioon	doc_601001696377_item	3674811	et	3	main
3	doc_601001696377_item	3674801	et	2	main
taasiseseisvumisel	doc_601001696377_item	3674800	et	3	main
öölaulupidude	doc_601001696377_item	3674794	et	4	main
nn	doc_601001696377_item	3674793	et	4	main
2	doc_601001696377_item	3674792	et	2	main
kultuurielu	doc_601001696377_item	3674791	et	4	main
eesti	doc_601001696377_item	3674790	et	4	main
a-te	doc_601001696377_item	3674789	et	3	main
1980	doc_601001696377_item	3674788	et	2	main
1970	doc_601001696377_item	3674787	et	2	main
iseloomustage	doc_601001696377_item	3674786	et	4	main
1	doc_601001696377_item	3674785	et	2	main
kontrolltöö	doc_601001696377_item	3674784	et	4	main
hõlmas	doc_601001696377_item	3674863	et	4	main
see	doc_601001696377_item	3674862	et	3	main
avalikustamine	doc_601001696377_item	3674861	et	4	main
on	doc_601001696377_item	3674860	et	4	main
see	doc_601001696377_item	3674859	et	3	main
sõnadega	doc_601001696377_item	3674858	et	3	main
teiste	doc_601001696377_item	3674857	et	4	main
ajal	doc_601001696377_item	3674856	et	4	main
gorbatsõvi	doc_601001696377_item	3674855	et	4	main
oli	doc_601001696377_item	3674854	et	3	main
glasnostj	doc_601001696377_item	3674853	et	4	main
ja	doc_601001696377_item	3674852	et	3	main
perestroika	doc_601001696377_item	3674851	et	4	main
3	doc_601001696377_item	3674850	et	2	main
laulud	doc_601001696377_item	3674849	et	3	main
liidu	doc_601001696377_item	3674848	et	3	main
öösiti	doc_601001696377_item	3674844	et	4	main
lauluväljakul	doc_601001696377_item	3674843	et	3	main
kokku	doc_601001696377_item	3674842	et	3	main
ja	doc_601001696377_item	3674835	et	3	main
teiseks	doc_601001696377_item	3674833	et	4	main
liiga	doc_601001696376_item	3675039	et	4	main
pidid	doc_601001696376_item	3675031	et	4	main
esimesed	doc_601001696376_item	3675024	et	3	main
kd	doc_601001696376_item	3675021	et	4	main
kõik	doc_601001696376_item	3675019	et	4	main
tulla	doc_601001696376_item	3675018	et	3	main
oli	doc_601001696376_item	3675013	et	3	main
külas	doc_601001696376_item	3675010	et	3	main
sakala	doc_601001696376_item	3675009	et	4	main
kolhoos	doc_601001696376_item	3675008	et	3	main
esimene	doc_601001696376_item	3675007	et	3	main
oli	doc_601001696376_item	3675006	et	3	main
juhiks	doc_601001696377_item	3674834	et	4	main
neid	doc_601001696376_item	3675037	et	4	main
sest	doc_601001696376_item	3675036	et	4	main
hakkas	doc_601001696376_item	3675028	et	3	main
kui	doc_601001696376_item	3675027	et	3	main
a	doc_601001696376_item	3675005	et	4	main
40	doc_601001696376_item	3674991	et	2	main
ideoloogia	doc_601001696376_item	3674990	et	4	main
tol	doc_601001696376_item	3674986	et	3	main
ja	doc_601001696376_item	3674981	et	3	main
tegi	doc_601001696376_item	3674972	et	4	main
võidu	doc_601001696376_item	3674955	et	4	main
vabadussõja	doc_601001696376_item	3674954	et	3	main
2	doc_601001696376_item	3674953	et	2	main
instituut	doc_601001696376_item	3674952	et	3	main
kaotas	doc_601001696376_item	3674925	et	3	main
tähetorn	doc_601001696376_item	3674924	et	3	main
hakkasid	doc_601001696376_item	3674917	et	4	main
instituudid	doc_601001696376_item	3674916	et	3	main
instituut	doc_601001696376_item	3674914	et	3	main
palju	doc_601001696376_item	3674908	et	4	main
ew	doc_601001696376_item	3674901	et	4	main
teaduselu	doc_601001696376_item	3674898	et	4	main
iseloomustab	doc_601001696376_item	3674881	et	4	main
alepõllundus	doc_872470917319_item	3675157	et	3	main
näitabki	doc_872470917319_item	3675150	et	3	main
huvitama	doc_872470917319_item	3675146	et	3	main
jooksul	doc_872470917319_item	3675138	et	4	main
aja	doc_872470917319_item	3675137	et	4	main
mis	doc_872470917319_item	3675131	et	4	main
esemed	doc_872470917319_item	3675130	et	3	main
komme	doc_872470917319_item	3675121	et	4	main
tuule	doc_872470917319_item	3675120	et	3	main
jaani	doc_872470917319_item	3675119	et	4	main
pärineb	doc_872470917319_item	3675118	et	3	main
ajast	doc_872470917319_item	3675117	et	4	main
inimeste	doc_872470917319_item	3675112	et	3	main
rauaajal	doc_872470917319_item	3675105	et	3	main
koos	doc_872470917319_item	3675101	et	4	main
kuna	doc_872470917319_item	3675098	et	3	main
ei	doc_872470917319_item	3675096	et	4	main
jne	doc_872470917319_item	3675091	et	4	main
ehted	doc_872470917319_item	3675090	et	3	main
loomakujukesed	doc_872470917319_item	3675089	et	4	main
tööriistu	doc_872470917319_item	3675088	et	3	main
asendis	doc_872470917319_item	3675081	et	3	main
ka	doc_872470917319_item	3675076	et	3	main
rauaajal	doc_872470917319_item	3675193	et	3	main
inimesed	doc_872470917319_item	3675189	et	3	main
alepõllundusega	doc_872470917319_item	3675188	et	3	main
peale	doc_872470917319_item	3675187	et	4	main
omadused	doc_872470917319_item	3675178	et	4	main
jooksul	doc_872470917319_item	3675174	et	4	main
kasutatakse	doc_872470917319_item	3675172	et	3	main
vabatahtlikult	doc_601001696376_item	3675020	et	4	main
viktor	doc_601001696376_item	3675014	et	4	main
jaoks	doc_601001696376_item	3675002	et	4	main
hakkasid	doc_601001696376_item	3674999	et	4	main
kevadel	doc_601001696376_item	3674996	et	4	main
stalini	doc_601001696376_item	3674989	et	4	main
1	doc_601001696376_item	3674985	et	2	main
paljude	doc_601001696376_item	3674983	et	3	main
armiat	doc_601001696376_item	3674973	et	4	main
mängis	doc_601001696376_item	3674968	et	3	main
usk	doc_601001696376_item	3674963	et	3	main
hinge	doc_601001696376_item	3674959	et	4	main
olid	doc_601001696376_item	3674958	et	4	main
põhjused	doc_601001696376_item	3674957	et	3	main
peamised	doc_601001696376_item	3674956	et	3	main
ajal	doc_601001696376_item	3674949	et	4	main
ew	doc_601001696376_item	3674948	et	4	main
õlikikvide	doc_601001696376_item	3674944	et	4	main
ka	doc_601001696376_item	3674923	et	3	main
tähtis	doc_601001696376_item	3674921	et	4	main
arenema	doc_601001696376_item	3674918	et	3	main
näiteks	doc_601001696376_item	3674912	et	4	main
nendest	doc_601001696376_item	3674909	et	4	main
ajal	doc_601001696376_item	3674902	et	4	main
olid	doc_601001696376_item	3674890	et	4	main
millised	doc_601001696376_item	3674889	et	3	main
2	doc_601001696376_item	3674888	et	2	main
süsteemi	doc_601001696376_item	3674887	et	4	main
maaharimise	doc_872470917319_item	3675159	et	3	main
et	doc_872470917319_item	3675151	et	3	main
ja	doc_872470917319_item	3675145	et	3	main
hakkasid	doc_872470917319_item	3675140	et	4	main
sellest	doc_872470917319_item	3675116	et	4	main
et	doc_872470917319_item	3675115	et	3	main
juba	doc_872470917319_item	3675109	et	3	main
toimingud	doc_872470917319_item	3675107	et	3	main
vanemal	doc_872470917319_item	3675104	et	4	main
inimestega	doc_872470917319_item	3675102	et	3	main
religioon	doc_872470917319_item	3675099	et	3	main
nn	doc_872470917319_item	3675085	et	4	main
neoliitikumi	doc_872470917319_item	3675057	et	4	main
eestlaste	doc_872470917319_item	3675049	et	4	main
varasel	doc_872470917319_item	3675192	et	4	main
hakkasid	doc_872470917319_item	3675190	et	4	main
algust	doc_872470917319_item	3675186	et	4	main
alustatakse	doc_872470917319_item	3675185	et	3	main
ning	doc_872470917319_item	3675184	et	3	main
viljekuks	doc_872470917319_item	3675170	et	4	main
saab	doc_872470917319_item	3675169	et	3	main
põletatakse	doc_872470917319_item	3675165	et	3	main
rajatakse	doc_872470917319_item	3675163	et	4	main
kollektivisatsioon	doc_601001696376_item	3674995	et	4	main
hakkas	doc_601001696376_item	3674994	et	3	main
lõppul	doc_601001696376_item	3674993	et	4	main
ta	doc_601001696376_item	3674971	et	4	main
laidoner	doc_601001696376_item	3674970	et	4	main
õigusteaduse	doc_601001696376_item	3674951	et	3	main
uurimise	doc_601001696376_item	3674945	et	4	main
oli	doc_601001696376_item	3674943	et	3	main
oli	doc_601001696376_item	3674922	et	3	main
teadused	doc_601001696376_item	3674920	et	3	main
kujunenud	doc_601001696376_item	3674906	et	4	main
oli	doc_601001696376_item	3674905	et	3	main
võiu	doc_601001696376_item	3674892	et	4	main
vabadussõja	doc_601001696376_item	3674891	et	3	main
nõukogude	doc_601001696376_item	3674882	et	3	main
1	doc_601001696376_item	3674879	et	2	main
kontrolltöö	doc_601001696376_item	3674878	et	4	main
2	doc_872470917319_item	3675156	et	2	main
see	doc_872470917319_item	3675149	et	3	main
inimesed	doc_872470917319_item	3675139	et	3	main
on	doc_872470917319_item	3675132	et	4	main
neile	doc_872470917319_item	3675128	et	4	main
anti	doc_872470917319_item	3675127	et	3	main
ning	doc_872470917319_item	3675126	et	3	main
siis	doc_872470917319_item	3675103	et	3	main
näiteks	doc_872470917319_item	3675087	et	4	main
hauapanuseid	doc_872470917319_item	3675086	et	3	main
sisse	doc_872470917319_item	3675083	et	4	main
magavas	doc_872470917319_item	3675080	et	4	main
territooriumile	doc_872470917319_item	3675074	et	3	main
1	doc_872470917319_item	3675056	et	2	main
on	doc_872470917319_item	3675054	et	4	main
mis	doc_872470917319_item	3675053	et	4	main
2	doc_872470917319_item	3675052	et	2	main
kontrolltöö	doc_872470917319_item	3675047	et	4	main
tegelema	doc_872470917319_item	3675191	et	3	main
halvenevad	doc_872470917319_item	3675179	et	4	main
aga	doc_872470917319_item	3675175	et	3	main
aastate	doc_872470917319_item	3675173	et	3	main
kui	doc_872470917319_item	3675167	et	3	main
siis	doc_872470917319_item	3675166	et	3	main
rajatud	doc_601001696376_item	3674942	et	4	main
majandusteadus	doc_601001696376_item	3674941	et	4	main
ka	doc_601001696376_item	3674940	et	3	main
arenema	doc_601001696376_item	3674939	et	3	main
hakkas	doc_601001696376_item	3674938	et	3	main
matemaatikat	doc_601001696376_item	3674937	et	3	main
1922	doc_601001696376_item	3674936	et	2	main
teadust	doc_601001696376_item	3674935	et	4	main
uut	doc_601001696376_item	3674934	et	3	main
võeti	doc_601001696376_item	3674933	et	3	main
tartus	doc_601001696376_item	3674932	et	3	main
keeled	doc_601001696376_item	3674931	et	3	main
saksa	doc_601001696376_item	3674930	et	4	main
ja	doc_601001696376_item	3674929	et	3	main
vene	doc_601001696376_item	3674928	et	4	main
mõjumist	doc_601001696376_item	3674927	et	4	main
oma	doc_601001696376_item	3674926	et	4	main
tehnilised	doc_601001696376_item	3674919	et	3	main
arstiteaduse	doc_601001696376_item	3674915	et	3	main
bakterioloogia	doc_601001696376_item	3674913	et	4	main
tartus	doc_601001696376_item	3674911	et	3	main
olid	doc_601001696376_item	3674910	et	4	main
instituute	doc_601001696376_item	3674904	et	3	main
teaduselu	doc_601001696376_item	3674900	et	4	main
majanduslikku	doc_601001696376_item	3674886	et	4	main
ja	doc_601001696376_item	3674885	et	3	main
poliitilist	doc_601001696376_item	3674884	et	3	main
ühiskonna	doc_601001696376_item	3674883	et	4	main
mis	doc_601001696376_item	3674880	et	4	main
areng	doc_872470917319_item	3675155	et	3	main
toimus	doc_872470917319_item	3675153	et	3	main
ning	doc_872470917319_item	3675148	et	3	main
religiooniga	doc_872470917319_item	3675147	et	3	main
surnute	doc_872470917319_item	3675143	et	4	main
holitsema	doc_872470917319_item	3675142	et	4	main
rohkem	doc_872470917319_item	3675141	et	4	main
maa	doc_872470917319_item	3675124	et	4	main
maeti	doc_872470917319_item	3675123	et	3	main
surnuid	doc_872470917319_item	3675122	et	4	main
arvatakse	doc_872470917319_item	3675114	et	3	main
päris	doc_872470917319_item	3675110	et	4	main
olid	doc_872470917319_item	3675108	et	4	main
maagilised	doc_872470917319_item	3675106	et	4	main
olnud	doc_872470917319_item	3675097	et	4	main
ettekujutust	doc_872470917319_item	3675094	et	4	main
haua	doc_872470917319_item	3675082	et	3	main
alla	doc_872470917319_item	3675079	et	3	main
püstkoja	doc_872470917319_item	3675077	et	3	main
asula	doc_872470917319_item	3675073	et	4	main
sängitati	doc_872470917319_item	3675072	et	3	main
inimeste	doc_872470917319_item	3675059	et	3	main
3	doc_601001696376_item	3674899	et	2	main
ew	doc_601001696376_item	3674897	et	4	main
iseloomustage	doc_601001696376_item	3674896	et	4	main
3	doc_601001696376_item	3674895	et	2	main
põhjused	doc_601001696376_item	3674894	et	3	main
peamised	doc_601001696376_item	3674893	et	3	main
so	doc_872470917319_item	3675158	et	4	main
vaimne	doc_872470917319_item	3675154	et	3	main
inimestel	doc_872470917319_item	3675152	et	3	main
eest	doc_872470917319_item	3675144	et	4	main
vajalikud	doc_872470917319_item	3675136	et	3	main
on	doc_872470917319_item	3675135	et	4	main
elus	doc_872470917319_item	3675134	et	4	main
järgmises	doc_872470917319_item	3675133	et	3	main
mõned	doc_872470917319_item	3675129	et	3	main
peale	doc_872470917319_item	3675125	et	4	main
jaoks	doc_872470917319_item	3675113	et	4	main
tähtsad	doc_872470917319_item	3675111	et	3	main
areneb	doc_872470917319_item	3675100	et	3	main
hingest	doc_872470917319_item	3675095	et	4	main
selges	doc_872470917319_item	3675093	et	3	main
ning	doc_872470917319_item	3675092	et	3	main
pani	doc_872470917319_item	3675084	et	4	main
põranda	doc_872470917319_item	3675078	et	3	main
tihti	doc_872470917319_item	3675075	et	3	main
surnuid	doc_872470917319_item	3675071	et	4	main
surm	doc_872470917319_item	3675070	et	3	main
on	doc_872470917319_item	3675069	et	4	main
mis	doc_872470917319_item	3675068	et	4	main
aru	doc_872470917319_item	3675067	et	4	main
saanud	doc_872470917319_item	3675066	et	4	main
ei	doc_872470917319_item	3675065	et	4	main
nad	doc_872470917319_item	3675064	et	3	main
keeruline	doc_872470917319_item	3675063	et	4	main
oli	doc_872470917319_item	3675062	et	3	main
ettekujutus	doc_872470917319_item	3675060	et	4	main
uskust	doc_872470917319_item	3675061	et	4	main
üldiseloomustus	doc_872470917319_item	3675051	et	4	main
muinasusundi	doc_872470917319_item	3675050	et	3	main
1	doc_872470917319_item	3675048	et	2	main
kõik	doc_872470917319_item	3675181	et	4	main
jälle	doc_872470917319_item	3675180	et	3	main
kui	doc_872470917319_item	3675176	et	3	main
seda	doc_872470917319_item	3675171	et	3	main
maa	doc_872470917319_item	3675168	et	4	main
ja	doc_872470917319_item	3675164	et	3	main
viis	doc_872470917319_item	3675160	et	4	main
peetakse	doc_854846908871_item	3675504	et	3	main
2	doc_854846908871_item	3675498	et	2	main
kivist	doc_854846908871_item	3675496	et	4	main
rändjutustajad	doc_854846908871_item	3675480	et	3	main
esimesed	doc_854846908871_item	3675479	et	3	main
rist	doc_854846908871_item	3675478	et	3	main
oli	doc_854846908871_item	3675477	et	3	main
maeti	doc_854846908871_item	3675471	et	3	main
10-20	doc_854846908871_item	3675464	et	2	main
eestisse	doc_854846908871_item	3675452	et	4	main
juba	doc_854846908871_item	3675451	et	3	main
oli	doc_854846908871_item	3675450	et	3	main
sead	doc_854846908871_item	3675446	et	4	main
ajal	doc_872470917319_item	3675058	et	4	main
alepõllundus	doc_872470917319_item	3675055	et	3	main
ära	doc_872470917319_item	3675183	et	4	main
põletatakse	doc_872470917319_item	3675182	et	3	main
maa	doc_872470917319_item	3675177	et	4	main
mets	doc_872470917319_item	3675162	et	3	main
millal	doc_872470917319_item	3675161	et	3	main
aeg	doc_854846908871_item	3675502	et	3	main
isegi	doc_854846908871_item	3675494	et	4	main
baltimaades	doc_854846908871_item	3675484	et	4	main
ka	doc_854846908871_item	3675483	et	3	main
kolima	doc_854846908871_item	3675482	et	3	main
peale	doc_854846908871_item	3675473	et	4	main
maa	doc_854846908871_item	3675472	et	4	main
surnuid	doc_854846908871_item	3675470	et	4	main
vanematega	doc_854846908871_item	3675469	et	4	main
kõik	doc_854846908871_item	3675466	et	4	main
elati	doc_854846908871_item	3675463	et	3	main
gruppidena	doc_854846908871_item	3675461	et	3	main
raud	doc_854846908871_item	3675449	et	3	main
hobused	doc_854846908871_item	3675445	et	4	main
loomade	doc_854846908871_item	3675443	et	4	main
lina	doc_854846908871_item	3675419	et	4	main
oder	doc_854846908871_item	3675418	et	3	main
nahku	doc_854846908871_item	3675417	et	4	main
rauda	doc_854846908871_item	3675412	et	4	main
olid	doc_854846908871_item	3675389	et	4	main
linnad	doc_854846908871_item	3675388	et	3	main
tolleaegsed	doc_854846908871_item	3675387	et	3	main
enamasti	doc_854846908871_item	3675378	et	4	main
saj	doc_854846908871_item	3675374	et	4	main
territooriumil	doc_854846908871_item	3675371	et	3	main
tähendus	doc_854846908871_item	3675367	et	4	main
loole	doc_860756017856_item	3675642	et	4	main
oli	doc_860756017856_item	3675624	et	3	main
telekanalid	doc_860756017856_item	3675621	et	3	main
kontrollima	doc_860756017856_item	3675610	et	4	main
aga	doc_860756017856_item	3675603	et	3	main
teatris	doc_860756017856_item	3675601	et	3	main
näidati	doc_860756017856_item	3675588	et	3	main
õnne	doc_860756017856_item	3675581	et	4	main
a	doc_860756017856_item	3675565	et	4	main
pisikesed	doc_860756017856_item	3675556	et	4	main
1	doc_860756017856_item	3675528	et	2	main
kontrolltöö	doc_860756017856_item	3675527	et	4	main
koordis	doc_860756017856_item	3675535	et	4	main
a	doc_866101568972_item	3675958	et	4	main
beti	doc_866101568972_item	3675951	et	4	main
nt	doc_866101568972_item	3675950	et	4	main
kirjanikud	doc_866101568972_item	3675949	et	3	main
paljud	doc_866101568972_item	3675948	et	3	main
välja	doc_866101568972_item	3675947	et	4	main
heidetakse	doc_866101568972_item	3675946	et	4	main
kaasa	doc_866101568972_item	3675930	et	4	main
1	doc_866101568972_item	3675928	et	2	main
välismaal	doc_866101568972_item	3675921	et	4	main
elavad	doc_866101568972_item	3675920	et	4	main
seda	doc_854846908871_item	3675509	et	3	main
muinasajaks	doc_854846908871_item	3675503	et	3	main
so	doc_854846908871_item	3675500	et	4	main
puust	doc_854846908871_item	3675497	et	4	main
savist	doc_854846908871_item	3675495	et	4	main
hakkasid	doc_854846908871_item	3675481	et	4	main
keskel	doc_854846908871_item	3675476	et	3	main
koos	doc_854846908871_item	3675468	et	4	main
perekond	doc_854846908871_item	3675467	et	3	main
aega	doc_854846908871_item	3675505	et	4	main
raua	doc_854846908871_item	3675501	et	3	main
jaid	doc_854846908871_item	3675493	et	4	main
tööriistad	doc_854846908871_item	3675492	et	3	main
peamised	doc_854846908871_item	3675491	et	3	main
toimusid	doc_854846908871_item	3675489	et	4	main
kus	doc_854846908871_item	3675488	et	3	main
kirikuid	doc_854846908871_item	3675487	et	4	main
rajama	doc_854846908871_item	3675486	et	3	main
hakati	doc_854846908871_item	3675485	et	3	main
kividest	doc_854846908871_item	3675474	et	3	main
tulnud	doc_854846908871_item	3675453	et	4	main
veised	doc_854846908871_item	3675447	et	3	main
ja	doc_854846908871_item	3675442	et	3	main
jne	doc_854846908871_item	3675441	et	4	main
sest	doc_854846908871_item	3675424	et	4	main
hea	doc_854846908871_item	3675422	et	4	main
oli	doc_854846908871_item	3675421	et	3	main
viina	doc_854846908871_item	3675414	et	4	main
metallid	doc_854846908871_item	3675413	et	3	main
ajajärku	doc_854846908871_item	3675400	et	4	main
m	doc_854846908871_item	3675399	et	4	main
mis	doc_854846908871_item	3675393	et	4	main
ja	doc_854846908871_item	3675391	et	3	main
tallinn	doc_854846908871_item	3675390	et	4	main
ekr	doc_854846908871_item	3675375	et	4	main
oli	doc_854846908871_item	3675372	et	3	main
1	doc_854846908871_item	3675368	et	2	main
muinasaeg	doc_854846908871_item	3675366	et	3	main
mõiste	doc_854846908871_item	3675365	et	4	main
meeldinud	doc_860756017856_item	3675641	et	4	main
hääl	doc_860756017856_item	3675639	et	3	main
anda	doc_860756017856_item	3675637	et	3	main
laulud	doc_860756017856_item	3675634	et	3	main
oma	doc_860756017856_item	3675632	et	4	main
autorite	doc_860756017856_item	3675631	et	3	main
horoskoop	doc_860756017856_item	3675630	et	3	main
loodusteaduses	doc_860756017856_item	3675629	et	3	main
keemias	doc_860756017856_item	3675628	et	3	main
matemaatikas	doc_860756017856_item	3675627	et	3	main
panna	doc_860756017856_item	3675626	et	4	main
toimus	doc_860756017856_item	3675607	et	3	main
jne	doc_860756017856_item	3675592	et	4	main
seotud	doc_860756017856_item	3675586	et	4	main
ka	doc_860756017856_item	3675584	et	3	main
ka	doc_860756017856_item	3675579	et	3	main
5	doc_860756017856_item	3675564	et	2	main
4	doc_860756017856_item	3675562	et	2	main
esinesid	doc_860756017856_item	3675551	et	4	main
riigikanaleid	doc_860756017856_item	3675549	et	4	main
üks	doc_860756017856_item	3675548	et	3	main
ajal	doc_860756017856_item	3675546	et	4	main
925000	doc_860756017856_item	3675543	et	2	main
elas	doc_860756017856_item	3675542	et	3	main
1	doc_860756017856_item	3675540	et	2	main
allver	doc_866101568972_item	3675952	et	4	main
kirjanike	doc_866101568972_item	3675942	et	3	main
seltside	doc_866101568972_item	3675937	et	3	main
palju	doc_866101568972_item	3675934	et	4	main
on	doc_866101568972_item	3675926	et	4	main
tädi	doc_866101568972_item	3675918	et	4	main
sisu	doc_866101568972_item	3675895	et	4	main
juuni	doc_866101568972_item	3675889	et	4	main
kohalikud	doc_866101568972_item	3675886	et	3	main
nimetati	doc_866101568972_item	3675876	et	4	main
riigikogu	doc_866101568972_item	3675875	et	4	main
toimusid	doc_866101568972_item	3675873	et	4	main
25081940	doc_866101568972_item	3675872	et	2	main
2	doc_866101568972_item	3675871	et	2	main
ümber	doc_866101568972_item	3675867	et	3	main
õppida	doc_866101568972_item	3675854	et	3	main
1947	doc_866101568972_item	3675833	et	2	main
rahvusriikides	doc_866101568972_item	3675826	et	3	main
surid	doc_866101568972_item	3675822	et	4	main
töötasu	doc_866101568972_item	3675803	et	4	main
olnud	doc_866101568972_item	3675772	et	4	main
ei	doc_866101568972_item	3675765	et	4	main
hulgas	doc_854846908871_item	3675525	et	4	main
talupojade	doc_854846908871_item	3675524	et	3	main
oskus	doc_854846908871_item	3675523	et	3	main
keele	doc_854846908871_item	3675522	et	4	main
eesti	doc_854846908871_item	3675521	et	4	main
levis	doc_854846908871_item	3675520	et	4	main
kui	doc_854846908871_item	3675519	et	3	main
seda	doc_854846908871_item	3675518	et	3	main
enne	doc_854846908871_item	3675517	et	4	main
ja	doc_854846908871_item	3675516	et	3	main
kristlus	doc_854846908871_item	3675515	et	4	main
ja	doc_854846908871_item	3675514	et	3	main
письменность	doc_854846908871_item	3675513	et	2	main
kirjakeel	doc_854846908871_item	3675512	et	4	main
levitati	doc_854846908871_item	3675511	et	4	main
kui	doc_854846908871_item	3675510	et	3	main
enne	doc_854846908871_item	3675508	et	4	main
oli	doc_854846908871_item	3675507	et	3	main
mis	doc_854846908871_item	3675506	et	4	main
muinasaeg	doc_854846908871_item	3675499	et	3	main
palvesid	doc_854846908871_item	3675490	et	4	main
ring	doc_854846908871_item	3675475	et	3	main
inimest	doc_854846908871_item	3675465	et	3	main
koos	doc_854846908871_item	3675462	et	4	main
elasid	doc_854846908871_item	3675460	et	4	main
inimesed	doc_854846908871_item	3675459	et	3	main
teha	doc_854846908871_item	3675458	et	3	main
siin	doc_854846908871_item	3675457	et	4	main
ka	doc_854846908871_item	3675456	et	3	main
hakati	doc_854846908871_item	3675455	et	3	main
seda	doc_854846908871_item	3675454	et	3	main
jne	doc_854846908871_item	3675448	et	4	main
lina	doc_854846908871_item	3675440	et	4	main
odra	doc_854846908871_item	3675439	et	3	main
tatra	doc_854846908871_item	3675438	et	3	main
kasvatati	doc_854846908871_item	3675437	et	3	main
põllumajandus	doc_854846908871_item	3675436	et	3	main
küttimine	doc_854846908871_item	3675435	et	4	main
oli	doc_854846908871_item	3675434	et	3	main
tegevusalaks	doc_854846908871_item	3675433	et	3	main
peamiseks	doc_854846908871_item	3675432	et	3	main
eestlaste	doc_854846908871_item	3675431	et	4	main
venemaad	doc_854846908871_item	3675430	et	4	main
ja	doc_854846908871_item	3675429	et	3	main
baltimaad	doc_854846908871_item	3675428	et	4	main
euroopa	doc_854846908871_item	3675427	et	4	main
seos	doc_854846908871_item	3675426	et	3	main
liit	doc_854846908871_item	3675404	et	3	main
kaubanduslik	doc_854846908871_item	3675403	et	3	main
so	doc_854846908871_item	3675402	et	4	main
tartu	doc_854846908871_item	3675392	et	4	main
kuid	doc_854846908871_item	3675380	et	4	main
maal	doc_854846908871_item	3675379	et	4	main
viikingiaeg	doc_854846908871_item	3675369	et	3	main
tipp	doc_860756017856_item	3675647	et	3	main
teadmisi	doc_860756017856_item	3675625	et	4	main
pigem	doc_860756017856_item	3675604	et	3	main
hunt	doc_860756017856_item	3675590	et	3	main
lastesaateid	doc_860756017856_item	3675589	et	3	main
aastased	doc_860756017856_item	3675560	et	4	main
1970ndate	doc_860756017856_item	3675530	et	4	main
oli	doc_860756017856_item	3675547	et	3	main
tollel	doc_860756017856_item	3675545	et	4	main
eestlase	doc_860756017856_item	3675544	et	3	main
eestis	doc_860756017856_item	3675541	et	3	main
musternäidis	doc_860756017856_item	3675539	et	4	main
realismi	doc_860756017856_item	3675538	et	4	main
sotsialistliku	doc_860756017856_item	3675537	et	3	main
kui	doc_860756017856_item	3675536	et	3	main
puhastuse	doc_866101568972_item	3675945	et	4	main
vallandati	doc_866101568972_item	3675940	et	3	main
likvideerimine	doc_866101568972_item	3675938	et	4	main
2	doc_866101568972_item	3675936	et	2	main
ilukirjandust	doc_866101568972_item	3675935	et	3	main
hävitati	doc_866101568972_item	3675933	et	3	main
hävitamise	doc_866101568972_item	3675932	et	4	main
raamatute	doc_866101568972_item	3675931	et	3	main
1950	doc_866101568972_item	3675925	et	2	main
koolist	doc_866101568972_item	3675923	et	4	main
nt	doc_866101568972_item	3675917	et	4	main
siberisse	doc_866101568972_item	3675908	et	4	main
vangi	doc_866101568972_item	3675905	et	4	main
sattusid	doc_866101568972_item	3675904	et	4	main
kunstnikud	doc_866101568972_item	3675903	et	3	main
kirjanikud	doc_866101568972_item	3675902	et	3	main
kommunism	doc_866101568972_item	3675901	et	3	main
realism	doc_866101568972_item	3675900	et	3	main
sotsialistlik	doc_866101568972_item	3675899	et	3	main
rahvuslik	doc_866101568972_item	3675898	et	3	main
vorm	doc_866101568972_item	3675897	et	3	main
sotsialistlik	doc_866101568972_item	3675896	et	3	main
esimees	doc_866101568972_item	3675883	et	4	main
kasvatamine	doc_854846908871_item	3675444	et	4	main
ta	doc_854846908871_item	3675425	et	4	main
transiitmaa	doc_854846908871_item	3675423	et	4	main
viidi	doc_854846908871_item	3675416	et	4	main
eestist	doc_854846908871_item	3675415	et	3	main
soola	doc_854846908871_item	3675411	et	4	main
viidi	doc_854846908871_item	3675410	et	4	main
sisse	doc_854846908871_item	3675409	et	4	main
areng	doc_854846908871_item	3675408	et	3	main
kaubanduslik	doc_854846908871_item	3675407	et	3	main
toimus	doc_854846908871_item	3675406	et	3	main
linnades	doc_854846908871_item	3675405	et	3	main
saj	doc_854846908871_item	3675398	et	4	main
13	doc_854846908871_item	3675397	et	2	main
kõige	doc_854846908871_item	3675385	et	4	main
linnused	doc_854846908871_item	3675384	et	3	main
linnades	doc_854846908871_item	3675383	et	3	main
ka	doc_854846908871_item	3675382	et	3	main
mõned	doc_854846908871_item	3675381	et	3	main
5-8	doc_854846908871_item	3675373	et	2	main
eesti	doc_854846908871_item	3675370	et	4	main
nukulavastused	doc_860756017856_item	3675646	et	3	main
dokumentaalkaadreid	doc_860756017856_item	3675644	et	3	main
enam	doc_860756017856_item	3675640	et	4	main
oma	doc_860756017856_item	3675638	et	4	main
oli	doc_860756017856_item	3675635	et	3	main
nende	doc_860756017856_item	3675622	et	4	main
hakati	doc_860756017856_item	3675609	et	3	main
muutus	doc_860756017856_item	3675608	et	4	main
kooliprogrammis	doc_860756017856_item	3675606	et	3	main
muulased	doc_860756017856_item	3675602	et	4	main
kriimsilm	doc_860756017856_item	3675591	et	3	main
saateid	doc_860756017856_item	3675587	et	3	main
13	doc_860756017856_item	3675582	et	2	main
samuti	doc_860756017856_item	3675578	et	3	main
siiani	doc_860756017856_item	3675576	et	4	main
hakati	doc_860756017856_item	3675567	et	3	main
a	doc_860756017856_item	3675563	et	4	main
3	doc_860756017856_item	3675559	et	2	main
lapsed	doc_860756017856_item	3675557	et	3	main
esinema	doc_860756017856_item	3675555	et	3	main
kultuurielu	doc_860756017856_item	3675529	et	4	main
skulptor	doc_866101568972_item	3675957	et	3	main
a	doc_866101568972_item	3675955	et	4	main
teeb	doc_866101568972_item	3675944	et	3	main
komitlased	doc_866101568972_item	3675941	et	4	main
tõi	doc_866101568972_item	3675929	et	3	main
terror	doc_866101568972_item	3675927	et	3	main
töölt	doc_866101568972_item	3675924	et	3	main
vallandati	doc_866101568972_item	3675922	et	3	main
a	doc_866101568972_item	3675891	et	4	main
presiidiumi	doc_866101568972_item	3675882	et	4	main
oli	doc_866101568972_item	3675857	et	3	main
internaate	doc_866101568972_item	3675851	et	4	main
hakati	doc_866101568972_item	3675849	et	3	main
hariduselu	doc_866101568972_item	3675848	et	4	main
ka	doc_866101568972_item	3675847	et	3	main
usuti	doc_866101568972_item	3675835	et	3	main
a	doc_866101568972_item	3675834	et	4	main
keel	doc_866101568972_item	3675832	et	4	main
põhiseaduse	doc_866101568972_item	3675831	et	3	main
keel	doc_866101568972_item	3675830	et	4	main
kohalik	doc_866101568972_item	3675829	et	3	main
on	doc_866101568972_item	3675828	et	4	main
uus	doc_866101568972_item	3675824	et	3	main
looma	doc_866101568972_item	3675821	et	4	main
nälgisid	doc_866101568972_item	3675813	et	4	main
inimesed	doc_866101568972_item	3675812	et	3	main
ei	doc_866101568972_item	3675804	et	4	main
külad	doc_866101568972_item	3675774	et	3	main
talupojad	doc_866101568972_item	3675764	et	4	main
võimu	doc_866101568972_item	3675752	et	4	main
amakorda	doc_866101568972_item	3675744	et	4	main
hakkab	doc_866101568972_item	3675743	et	3	main
raamatukogu	doc_866101568972_item	3675736	et	4	main
3-8	doc_866101568972_item	3675732	et	2	main
tekkivad	doc_866101568972_item	3675715	et	4	main
maalt	doc_866101568972_item	3675708	et	3	main
ja	doc_866101568972_item	3675698	et	3	main
ismid	doc_866101568972_item	3675694	et	3	main
prop	doc_866101568972_item	3675684	et	4	main
eesti	doc_854846908871_item	3675420	et	4	main
hansaliitu	doc_854846908871_item	3675401	et	4	main
pärast	doc_854846908871_item	3675396	et	4	main
ka	doc_854846908871_item	3675395	et	3	main
kuulusid	doc_854846908871_item	3675394	et	4	main
suuremad	doc_854846908871_item	3675386	et	4	main
elasid	doc_854846908871_item	3675377	et	4	main
eestlased	doc_854846908871_item	3675376	et	3	main
2	doc_854846908871_item	3675364	et	2	main
territooriumil	doc_854846908871_item	3675363	et	3	main
eesti	doc_854846908871_item	3675362	et	4	main
viikingiaeg	doc_854846908871_item	3675361	et	3	main
1	doc_854846908871_item	3675360	et	2	main
kontrolltöö	doc_854846908871_item	3675359	et	4	main
telerist	doc_860756017856_item	3675667	et	4	main
programm	doc_860756017856_item	3675666	et	3	main
aastavahetus	doc_860756017856_item	3675665	et	4	main
kirjutatud	doc_860756017856_item	3675664	et	4	main
vaimus	doc_860756017856_item	3675663	et	4	main
nõukogude	doc_860756017856_item	3675662	et	3	main
olema	doc_860756017856_item	3675661	et	4	main
pidi	doc_860756017856_item	3675660	et	4	main
kirjandus	doc_860756017856_item	3675659	et	3	main
kaupu	doc_860756017856_item	3675658	et	3	main
uusi	doc_860756017856_item	3675657	et	3	main
tutvustati	doc_860756017856_item	3675656	et	4	main
kus	doc_860756017856_item	3675655	et	3	main
meelelahutussaade	doc_860756017856_item	3675654	et	4	main
reklaamiklubid	doc_860756017856_item	3675653	et	3	main
reklaamindus	doc_860756017856_item	3675652	et	3	main
eesti	doc_860756017856_item	3675651	et	4	main
tegutses	doc_860756017856_item	3675650	et	3	main
täpp	doc_860756017856_item	3675649	et	3	main
aj	doc_860756017856_item	3675648	et	4	main
sõjast	doc_860756017856_item	3675645	et	3	main
näidati	doc_860756017856_item	3675643	et	3	main
võimalus	doc_860756017856_item	3675636	et	3	main
looming	doc_860756017856_item	3675633	et	3	main
ülesandeks	doc_860756017856_item	3675623	et	4	main
teksaastes	doc_860756017856_item	3675620	et	4	main
veel	doc_860756017856_item	3675619	et	4	main
mitte	doc_860756017856_item	3675618	et	3	main
aga	doc_860756017856_item	3675617	et	3	main
pükstes	doc_860756017856_item	3675616	et	3	main
käia	doc_860756017856_item	3675615	et	4	main
lubati	doc_860756017856_item	3675614	et	3	main
tüdrukutel	doc_860756017856_item	3675613	et	4	main
tundides	doc_860756017856_item	3675612	et	3	main
õpilase	doc_860756017856_item	3675611	et	3	main
kinos	doc_860756017856_item	3675605	et	3	main
käia	doc_860756017856_item	3675600	et	4	main
armastasid	doc_860756017856_item	3675599	et	4	main
eestlased	doc_860756017856_item	3675598	et	3	main
võimalus	doc_860756017856_item	3675597	et	3	main
oli	doc_860756017856_item	3675596	et	3	main
televiktoriinid	doc_860756017856_item	3675595	et	3	main
olümpiaadid	doc_860756017856_item	3675594	et	3	main
toimusid	doc_860756017856_item	3675593	et	4	main
keelega	doc_860756017856_item	3675585	et	3	main
oli	doc_860756017856_item	3675583	et	3	main
praegune	doc_860756017856_item	3675580	et	3	main
säilitanud	doc_860756017856_item	3675577	et	4	main
nime	doc_860756017856_item	3675575	et	4	main
oma	doc_860756017856_item	3675574	et	4	main
on	doc_860756017856_item	3675573	et	4	main
mis	doc_860756017856_item	3675572	et	4	main
vaprat	doc_860756017856_item	3675571	et	3	main
7	doc_860756017856_item	3675570	et	2	main
saadet	doc_860756017856_item	3675569	et	3	main
näitama	doc_860756017856_item	3675568	et	3	main
6a	doc_860756017856_item	3675566	et	4	main
siis	doc_860756017856_item	3675561	et	3	main
algul	doc_860756017856_item	3675558	et	4	main
hakkasid	doc_860756017856_item	3675554	et	4	main
entel-tentel	doc_860756017856_item	3675553	et	4	main
lapstähed	doc_860756017856_item	3675552	et	3	main
etv	doc_860756017856_item	3675550	et	4	main
valgus	doc_860756017856_item	3675534	et	4	main
2	doc_860756017856_item	3675533	et	2	main
nsvs	doc_860756017856_item	3675532	et	4	main
eesti	doc_860756017856_item	3675531	et	4	main
starkopp	doc_866101568972_item	3675959	et	4	main
lauter	doc_866101568972_item	3675956	et	3	main
teatritegelane	doc_866101568972_item	3675954	et	3	main
tuglas	doc_866101568972_item	3675953	et	4	main
liit	doc_866101568972_item	3675943	et	3	main
3	doc_866101568972_item	3675939	et	2	main
kirjutanud	doc_866101568972_item	3675916	et	4	main
valesti	doc_866101568972_item	3675915	et	3	main
saadeti	doc_866101568972_item	3675907	et	3	main
folkloor	doc_866101568972_item	3675894	et	4	main
poliitiline	doc_866101568972_item	3675893	et	3	main
14	doc_866101568972_item	3675888	et	2	main
vares-barbarus	doc_866101568972_item	3675881	et	4	main
linnad	doc_866101568972_item	3675870	et	3	main
nimetat	doc_866101568972_item	3675866	et	4	main
tulevad	doc_866101568972_item	3675864	et	4	main
asemetele	doc_866101568972_item	3675863	et	4	main
maakondade	doc_866101568972_item	3675862	et	3	main
maalt	doc_866101568972_item	3675861	et	3	main
tulema	doc_866101568972_item	3675860	et	4	main
onu	doc_866101568972_item	3675919	et	4	main
midagi	doc_866101568972_item	3675914	et	4	main
on	doc_866101568972_item	3675913	et	4	main
inimene	doc_866101568972_item	3675912	et	3	main
kui	doc_866101568972_item	3675911	et	3	main
ankeet	doc_866101568972_item	3675910	et	3	main
puhas	doc_866101568972_item	3675909	et	3	main
või	doc_866101568972_item	3675906	et	4	main
tekkis	doc_866101568972_item	3675892	et	3	main
1941	doc_866101568972_item	3675890	et	2	main
võimuürganid	doc_866101568972_item	3675887	et	4	main
komitee	doc_866101568972_item	3675885	et	4	main
täitev	doc_866101568972_item	3675884	et	4	main
j	doc_866101568972_item	3675880	et	4	main
muudatused	doc_866101568972_item	3675874	et	3	main
tänavad	doc_866101568972_item	3675868	et	4	main
hakkati	doc_866101568972_item	3675859	et	3	main
kõik	doc_866101568972_item	3675856	et	4	main
võimalus	doc_866101568972_item	3675853	et	3	main
taastamine	doc_866101568972_item	3675845	et	4	main
on	doc_866101568972_item	3675838	et	4	main
vabariigis	doc_866101568972_item	3675837	et	3	main
et	doc_866101568972_item	3675836	et	3	main
asjaajamiskeel	doc_866101568972_item	3675827	et	4	main
pidid	doc_866101568972_item	3675818	et	4	main
ja	doc_866101568972_item	3675816	et	3	main
kolhoos	doc_866101568972_item	3675815	et	3	main
sest	doc_866101568972_item	3675814	et	4	main
tahtnud	doc_866101568972_item	3675766	et	4	main
jõukamad	doc_866101568972_item	3675760	et	4	main
poliitilise	doc_866101568972_item	3675751	et	3	main
kultuur	doc_866101568972_item	3675747	et	3	main
harrastustega	doc_866101568972_item	3675741	et	4	main
ja	doc_866101568972_item	3675730	et	3	main
kõrgkoolide	doc_866101568972_item	3675728	et	3	main
kes	doc_866101568972_item	3675722	et	4	main
kõrgkoolid	doc_866101568972_item	3675721	et	3	main
ka	doc_866101568972_item	3675720	et	3	main
olid	doc_866101568972_item	3675719	et	4	main
kinod	doc_866101568972_item	3675718	et	3	main
ja	doc_866101568972_item	3675717	et	3	main
teatrid	doc_866101568972_item	3675716	et	3	main
moodustatakse	doc_866101568972_item	3675712	et	3	main
klubid	doc_866101568972_item	3675711	et	3	main
tekkivad	doc_866101568972_item	3675710	et	4	main
nautida	doc_866101568972_item	3675699	et	3	main
seda	doc_866101568972_item	3675695	et	3	main
meelelahutus	doc_866101568972_item	3675692	et	4	main
odav	doc_866101568972_item	3675691	et	3	main
kirjandusvool	doc_866101568972_item	3675682	et	4	main
pärastsõjajärgset	doc_866101568972_item	3675676	et	3	main
ka	doc_513103214317_item	3676112	et	3	main
omal	doc_513103214317_item	3676109	et	3	main
päev	doc_513103214317_item	3676104	et	3	main
töötama	doc_513103214317_item	3676090	et	3	main
olnud	doc_513103214317_item	3676082	et	4	main
ei	doc_513103214317_item	3676081	et	4	main
talupoegael	doc_513103214317_item	3676080	et	3	main
tavadest	doc_513103214317_item	3676073	et	3	main
kommetest	doc_513103214317_item	3676071	et	4	main
meile	doc_513103214317_item	3676068	et	4	main
annavad	doc_513103214317_item	3676067	et	3	main
protokollid	doc_513103214317_item	3676066	et	4	main
visitatsioonid	doc_513103214317_item	3676065	et	3	main
kirikuõpetajad	doc_513103214317_item	3676059	et	3	main
välja	doc_513103214317_item	3676058	et	4	main
keelne	doc_513103214317_item	3676052	et	3	main
keskajast	doc_513103214317_item	3676050	et	4	main
olukorra	doc_513103214317_item	3676042	et	3	main
talupoegade	doc_513103214317_item	3676041	et	3	main
peamiselt	doc_513103214317_item	3676040	et	4	main
ruussov	doc_513103214317_item	3676037	et	4	main
kroonik	doc_513103214317_item	3676035	et	3	main
meile	doc_513103214317_item	3676034	et	4	main
annab	doc_513103214317_item	3676033	et	3	main
ülevaade	doc_513103214317_item	3676032	et	3	main
lahingust	doc_513103214317_item	3676024	et	4	main
tähtsast	doc_513103214317_item	3676023	et	3	main
ülemnõukoguks	doc_866101568972_item	3675879	et	3	main
ensv	doc_866101568972_item	3675878	et	4	main
ümber	doc_866101568972_item	3675877	et	3	main
ja	doc_866101568972_item	3675869	et	3	main
rajoonid	doc_866101568972_item	3675865	et	4	main
elada	doc_866101568972_item	3675855	et	3	main
oli	doc_866101568972_item	3675852	et	3	main
teatri	doc_866101568972_item	3675844	et	3	main
eetonia	doc_866101568972_item	3675843	et	4	main
nt	doc_866101568972_item	3675842	et	4	main
edandada	doc_866101568972_item	3675841	et	4	main
nälga	doc_866101568972_item	3675823	et	4	main
maksma	doc_866101568972_item	3675820	et	3	main
makse	doc_866101568972_item	3675819	et	4	main
suhteliselt	doc_866101568972_item	3675811	et	4	main
kartulit	doc_866101568972_item	3675810	et	3	main
kapsast	doc_866101568972_item	3675808	et	4	main
sisse	doc_866101568972_item	3675767	et	4	main
talupojad	doc_866101568972_item	3675761	et	4	main
edukamad	doc_866101568972_item	3675757	et	4	main
majand	doc_866101568972_item	3675756	et	3	main
on	doc_866101568972_item	3675750	et	4	main
majandust	doc_866101568972_item	3675746	et	4	main
mõjutama	doc_866101568972_item	3675745	et	4	main
võimalus	doc_866101568972_item	3675737	et	3	main
800	doc_866101568972_item	3675735	et	2	main
ligi	doc_866101568972_item	3675734	et	3	main
tegutses	doc_866101568972_item	3675733	et	3	main
algab	doc_866101568972_item	3675726	et	3	main
tahtsid	doc_866101568972_item	3675723	et	4	main
erinevaid	doc_866101568972_item	3675713	et	4	main
kultuurielu	doc_866101568972_item	3675700	et	4	main
olnud	doc_866101568972_item	3675690	et	4	main
ei	doc_866101568972_item	3675689	et	4	main
teose	doc_866101568972_item	3675688	et	3	main
kui	doc_866101568972_item	3675681	et	3	main
2	doc_866101568972_item	3675678	et	2	main
ensv	doc_866101568972_item	3675675	et	4	main
talupojad	doc_513103214317_item	3676106	et	4	main
iga	doc_513103214317_item	3676103	et	4	main
maksma	doc_513103214317_item	3676088	et	3	main
makse	doc_513103214317_item	3676087	et	4	main
2	doc_513103214317_item	3676074	et	2	main
ja	doc_513103214317_item	3676072	et	3	main
rahva	doc_513103214317_item	3676070	et	3	main
s	doc_513103214317_item	3676060	et	4	main
mida	doc_513103214317_item	3676056	et	4	main
katekismus	doc_513103214317_item	3676055	et	3	main
usu	doc_513103214317_item	3676054	et	4	main
eesti	doc_513103214317_item	3676051	et	4	main
ta	doc_513103214317_item	3676038	et	4	main
b	doc_513103214317_item	3676036	et	4	main
lahing	doc_513103214317_item	3676027	et	3	main
ümera	doc_513103214317_item	3676026	et	4	main
nagu	doc_513103214317_item	3676025	et	3	main
kohta	doc_513103214317_item	3676020	et	4	main
palju	doc_513103214317_item	3676018	et	4	main
siis	doc_513103214317_item	3676096	et	3	main
ei	doc_513103214317_item	3676093	et	4	main
vaatamist	doc_973441205335_item	3676218	et	4	main
kuulamist	doc_973441205335_item	3676216	et	4	main
väga	doc_973441205335_item	3676212	et	3	main
peterburis	doc_973441205335_item	3676173	et	4	main
ballett	doc_973441205335_item	3676162	et	3	main
tantsivad	doc_973441205335_item	3676154	et	4	main
balletti	doc_973441205335_item	3676145	et	4	main
mulle	doc_973441205335_item	3676142	et	4	main
draamit	doc_973441205335_item	3676124	et	4	main
küsimusele	doc_973441205335_item	3676117	et	4	main
väga	doc_973441205330_item	3676313	et	3	main
õppida	doc_973441205330_item	3676311	et	3	main
elada	doc_973441205330_item	3676309	et	3	main
et	doc_973441205330_item	3676308	et	3	main
on	doc_973441205330_item	3676302	et	4	main
õppimine	doc_973441205330_item	3676301	et	4	main
raha	doc_973441205330_item	3676299	et	4	main
küllalduselt	doc_973441205330_item	3676298	et	3	main
pole	doc_973441205330_item	3676296	et	3	main
lihtsal	doc_973441205330_item	3676292	et	3	main
sellel	doc_973441205330_item	3676291	et	4	main
võimalik	doc_973441205330_item	3676289	et	3	main
tasuta	doc_866101568972_item	3675858	et	4	main
ehitama	doc_866101568972_item	3675850	et	4	main
taastati	doc_866101568972_item	3675846	et	4	main
kultuuri	doc_866101568972_item	3675840	et	4	main
võimalik	doc_866101568972_item	3675839	et	3	main
poliitika	doc_866101568972_item	3675825	et	4	main
sohvoos	doc_866101568972_item	3675817	et	4	main
ja	doc_866101568972_item	3675809	et	3	main
said	doc_866101568972_item	3675807	et	4	main
aga	doc_866101568972_item	3675806	et	3	main
makstus	doc_866101568972_item	3675805	et	4	main
vastu	doc_866101568972_item	3675802	et	3	main
pidanud	doc_866101568972_item	3675801	et	4	main
ei	doc_866101568972_item	3675800	et	4	main
lihtsalt	doc_866101568972_item	3675799	et	4	main
nad	doc_866101568972_item	3675798	et	3	main
surid	doc_866101568972_item	3675797	et	4	main
inimesed	doc_866101568972_item	3675796	et	3	main
siberis	doc_866101568972_item	3675795	et	4	main
aastad	doc_866101568972_item	3675794	et	3	main
esimesed	doc_866101568972_item	3675793	et	3	main
lahutati	doc_866101568972_item	3675792	et	3	main
perekonnad	doc_866101568972_item	3675791	et	4	main
inimest	doc_866101568972_item	3675790	et	3	main
20702	doc_866101568972_item	3675789	et	2	main
süsteemi	doc_866101568972_item	3675788	et	4	main
nõukogude	doc_866101568972_item	3675787	et	3	main
uut	doc_866101568972_item	3675786	et	3	main
omaks	doc_866101568972_item	3675785	et	4	main
võta	doc_866101568972_item	3675784	et	4	main
ei	doc_866101568972_item	3675783	et	4	main
talupoeg	doc_866101568972_item	3675782	et	3	main
a	doc_866101568972_item	3675781	et	4	main
1949	doc_866101568972_item	3675780	et	2	main
märts	doc_866101568972_item	3675779	et	3	main
25-26	doc_866101568972_item	3675778	et	2	main
vaesed	doc_866101568972_item	3675777	et	4	main
väga	doc_866101568972_item	3675776	et	3	main
olid	doc_866101568972_item	3675775	et	4	main
tööriistu	doc_866101568972_item	3675773	et	3	main
ei	doc_866101568972_item	3675771	et	4	main
neil	doc_866101568972_item	3675770	et	4	main
kuna	doc_866101568972_item	3675769	et	3	main
astuda	doc_866101568972_item	3675768	et	3	main
vaesemad	doc_866101568972_item	3675763	et	4	main
aga	doc_866101568972_item	3675762	et	3	main
astusid	doc_866101568972_item	3675759	et	4	main
olid	doc_866101568972_item	3675755	et	4	main
partei	doc_866101568972_item	3675742	et	4	main
euroopas	doc_866101568972_item	3675731	et	3	main
13-17	doc_866101568972_item	3675725	et	2	main
õppida	doc_866101568972_item	3675724	et	3	main
sõpruskondi	doc_866101568972_item	3675714	et	4	main
linna	doc_866101568972_item	3675709	et	4	main
kolivad	doc_866101568972_item	3675707	et	4	main
inimesed	doc_866101568972_item	3675706	et	3	main
külas	doc_866101568972_item	3675705	et	3	main
ja	doc_866101568972_item	3675704	et	3	main
maal	doc_866101568972_item	3675703	et	4	main
toimus	doc_866101568972_item	3675702	et	3	main
linnastub	doc_866101568972_item	3675701	et	3	main
hinnata	doc_866101568972_item	3675697	et	4	main
ostakse	doc_866101568972_item	3675696	et	4	main
tulevad	doc_866101568972_item	3675693	et	4	main
1	doc_866101568972_item	3675683	et	2	main
kultuurielu	doc_866101568972_item	3675677	et	4	main
mõisanikumaal	doc_513103214317_item	3676113	et	4	main
kui	doc_513103214317_item	3676111	et	3	main
maal	doc_513103214317_item	3676110	et	4	main
töötama	doc_513103214317_item	3676107	et	3	main
karistuse	doc_513103214317_item	3676102	et	4	main
palju	doc_513103214317_item	3676089	et	4	main
inimõigusi	doc_513103214317_item	3676084	et	4	main
peaaegu	doc_513103214317_item	3676083	et	3	main
teoorjus	doc_513103214317_item	3676075	et	3	main
andsid	doc_513103214317_item	3676057	et	4	main
meile	doc_513103214317_item	3676047	et	4	main
annab	doc_513103214317_item	3676046	et	3	main
määral	doc_513103214317_item	3676045	et	3	main
hea	doc_513103214317_item	3676031	et	4	main
sellest	doc_513103214317_item	3676022	et	4	main
lahingute	doc_513103214317_item	3676019	et	4	main
kirjutab	doc_513103214317_item	3676017	et	3	main
henrik	doc_513103214317_item	3676016	et	4	main
kuidas	doc_513103214317_item	3676000	et	3	main
1	doc_513103214317_item	3675962	et	2	main
talupoeg	doc_513103214317_item	3676098	et	3	main
ja	doc_973441205335_item	3676217	et	3	main
peale	doc_973441205335_item	3676214	et	4	main
minule	doc_973441205335_item	3676211	et	3	main
ise	doc_973441205335_item	3676177	et	4	main
ma	doc_973441205335_item	3676176	et	3	main
et	doc_973441205335_item	3676175	et	3	main
sellepärast	doc_973441205335_item	3676174	et	3	main
juljetta	doc_973441205335_item	3676165	et	4	main
romeo	doc_973441205335_item	3676163	et	4	main
minu	doc_973441205335_item	3676160	et	3	main
on	doc_973441205335_item	3676159	et	4	main
meeldejäävamad	doc_973441205335_item	3676158	et	4	main
ja	doc_973441205335_item	3676153	et	3	main
näitlevad	doc_973441205335_item	3676152	et	4	main
kui	doc_973441205335_item	3676150	et	3	main
vaadata	doc_973441205335_item	3676149	et	4	main
meeldib	doc_973441205335_item	3676148	et	3	main
mulle	doc_973441205335_item	3676147	et	4	main
käiä	doc_973441205335_item	3676143	et	4	main
meeldib	doc_973441205335_item	3676141	et	3	main
kõige	doc_973441205335_item	3676139	et	4	main
teatris	doc_973441205335_item	3676131	et	3	main
vaatama	doc_973441205335_item	3676123	et	3	main
saaksite	doc_973441205335_item	3676119	et	3	main
õppelaenu	doc_973441205330_item	3676307	et	4	main
tuleb	doc_973441205330_item	3676305	et	3	main
selleks	doc_973441205330_item	3676297	et	4	main
kõik	doc_973441205330_item	3676277	et	4	main
kahjuks	doc_973441205330_item	3676260	et	4	main
kuid	doc_973441205330_item	3676256	et	4	main
piiramist	doc_460280307198_item	3676444	et	4	main
ohutu	doc_460280307198_item	3676440	et	4	main
elu	doc_460280307198_item	3676437	et	4	main
kolhoosidesse	doc_866101568972_item	3675758	et	3	main
sohvoosid	doc_866101568972_item	3675754	et	4	main
all	doc_866101568972_item	3675753	et	3	main
majandus	doc_866101568972_item	3675749	et	4	main
ja	doc_866101568972_item	3675748	et	3	main
erinevate	doc_866101568972_item	3675740	et	4	main
tegeleda	doc_866101568972_item	3675739	et	3	main
oli	doc_866101568972_item	3675738	et	3	main
eestis	doc_866101568972_item	3675729	et	3	main
haridustee	doc_866101568972_item	3675727	et	4	main
ajaloolisi	doc_866101568972_item	3675687	et	4	main
loeti	doc_866101568972_item	3675686	et	3	main
kunstiloomind	doc_866101568972_item	3675685	et	3	main
realism	doc_866101568972_item	3675680	et	3	main
ja	doc_866101568972_item	3675674	et	3	main
aegset	doc_866101568972_item	3675673	et	3	main
ev	doc_866101568972_item	3675672	et	4	main
võrrelge	doc_866101568972_item	3675671	et	3	main
1	doc_866101568972_item	3675670	et	2	main
kontrolltöö	doc_866101568972_item	3675669	et	4	main
pidid	doc_513103214317_item	3676105	et	4	main
siinsetel	doc_513103214317_item	3676079	et	4	main
et	doc_513103214317_item	3676078	et	3	main
seda	doc_513103214317_item	3676077	et	3	main
teada	doc_513103214317_item	3676069	et	3	main
koell	doc_513103214317_item	3676064	et	4	main
luteri	doc_513103214317_item	3676053	et	3	main
mingil	doc_513103214317_item	3676044	et	4	main
kohta	doc_513103214317_item	3676043	et	4	main
kohta	doc_513103214317_item	3676030	et	4	main
näiteks	doc_513103214317_item	3676021	et	4	main
toimusid	doc_513103214317_item	3676002	et	4	main
jutustavad	doc_513103214317_item	3675966	et	4	main
liikuda	doc_513103214317_item	3676095	et	3	main
ja	doc_513103214317_item	3676091	et	3	main
ja	doc_973441205335_item	3676223	et	3	main
rahuldatult	doc_973441205335_item	3676222	et	4	main
koju	doc_973441205335_item	3676221	et	3	main
tulen	doc_973441205335_item	3676220	et	3	main
ma	doc_973441205335_item	3676219	et	3	main
sügavalt	doc_973441205335_item	3676213	et	4	main
hingeliselt	doc_973441205335_item	3676210	et	4	main
tegevus	doc_973441205335_item	3676205	et	4	main
ja	doc_973441205335_item	3676204	et	3	main
laul	doc_973441205335_item	3676203	et	4	main
muusika	doc_973441205335_item	3676202	et	4	main
head	doc_973441205335_item	3676188	et	4	main
siiski	doc_973441205335_item	3676167	et	4	main
kuid	doc_973441205335_item	3676166	et	4	main
inimesed	doc_973441205335_item	3676151	et	3	main
vaatamas	doc_973441205335_item	3676144	et	3	main
rohkem	doc_973441205335_item	3676140	et	4	main
draamat	doc_973441205335_item	3676138	et	3	main
ka	doc_973441205335_item	3676137	et	3	main
kui	doc_973441205335_item	3676136	et	3	main
baletti	doc_973441205335_item	3676135	et	4	main
ooperit	doc_973441205335_item	3676134	et	3	main
nii	doc_973441205335_item	3676133	et	3	main
olen	doc_973441205335_item	3676129	et	3	main
sotsialistlik	doc_866101568972_item	3675679	et	3	main
nii	doc_513103214317_item	3676108	et	3	main
pidid	doc_513103214317_item	3676086	et	4	main
talupojad	doc_513103214317_item	3676085	et	4	main
tähendab	doc_513103214317_item	3676076	et	3	main
j	doc_513103214317_item	3676063	et	4	main
ja	doc_513103214317_item	3676062	et	3	main
wandradt	doc_513103214317_item	3676061	et	4	main
eestimaa	doc_513103214317_item	3676049	et	4	main
teada	doc_513103214317_item	3676048	et	3	main
kirjutab	doc_513103214317_item	3676039	et	3	main
keskaja	doc_513103214317_item	3676029	et	3	main
veel	doc_513103214317_item	3676028	et	4	main
läti	doc_513103214317_item	3676015	et	4	main
kaudu	doc_513103214317_item	3676014	et	3	main
ümberkirjutamise	doc_513103214317_item	3676013	et	3	main
tuntakse	doc_513103214317_item	3676012	et	3	main
teda	doc_513103214317_item	3676011	et	4	main
aga	doc_513103214317_item	3676010	et	3	main
ole	doc_513103214317_item	3676009	et	4	main
ei	doc_513103214317_item	3676008	et	4	main
säilinud	doc_513103214317_item	3676007	et	4	main
käsikiri	doc_513103214317_item	3676006	et	3	main
levis	doc_513103214317_item	3676005	et	4	main
ristiusk	doc_513103214317_item	3676004	et	3	main
ja	doc_513103214317_item	3676003	et	3	main
sõjad	doc_513103214317_item	3676001	et	3	main
allikad	doc_513103214317_item	3675965	et	3	main
kirjalikud	doc_513103214317_item	3675964	et	3	main
millised	doc_513103214317_item	3675963	et	3	main
kontrolltöö	doc_513103214317_item	3675961	et	4	main
ta	doc_513103214317_item	3676101	et	4	main
saab	doc_513103214317_item	3676100	et	3	main
põgeneb	doc_513103214317_item	3676099	et	3	main
uue	doc_973441205335_item	3676226	et	3	main
ooperi	doc_973441205335_item	3676215	et	3	main
mõjub	doc_973441205335_item	3676209	et	3	main
ühendatud	doc_973441205335_item	3676201	et	4	main
laulmist	doc_973441205335_item	3676180	et	4	main
harrastan	doc_973441205335_item	3676179	et	3	main
ka	doc_973441205335_item	3676178	et	3	main
külastan	doc_973441205335_item	3676171	et	3	main
rohkem	doc_973441205335_item	3676169	et	4	main
kõige	doc_973441205335_item	3676157	et	4	main
saatel	doc_973441205335_item	3676156	et	4	main
vaatamas	doc_973441205335_item	3676132	et	3	main
balletti	doc_973441205335_item	3676127	et	4	main
või	doc_973441205335_item	3676126	et	4	main
ooperit	doc_973441205335_item	3676125	et	3	main
valida	doc_973441205335_item	3676120	et	3	main
ka	doc_973441205330_item	3676303	et	3	main
kõigil	doc_973441205330_item	3676295	et	4	main
põhjusel	doc_973441205330_item	3676293	et	3	main
parimatesse	doc_973441205330_item	3676281	et	4	main
sisse	doc_973441205330_item	3676280	et	4	main
et	doc_973441205330_item	3676276	et	3	main
nii	doc_973441205330_item	3676275	et	3	main
õpeasutustesse	doc_973441205330_item	3676274	et	4	main
kõrgematesse	doc_973441205330_item	3676273	et	4	main
kõigile	doc_973441205330_item	3676253	et	4	main
autolikluse	doc_460280307198_item	3676443	et	4	main
peab	doc_460280307198_item	3676438	et	4	main
lisaks	doc_460280307198_item	3676421	et	4	main
töödelda	doc_460280307198_item	3676418	et	4	main
klaasile	doc_460280307198_item	3676412	et	3	main
teha	doc_460280307198_item	3676409	et	3	main
prügi	doc_460280307198_item	3676406	et	4	main
viskaks	doc_460280307198_item	3676405	et	3	main
ja	doc_460280307198_item	3676370	et	3	main
oleks	doc_460280307198_item	3676368	et	3	main
sellest	doc_513103214317_item	3675999	et	4	main
peamiselt	doc_513103214317_item	3675998	et	4	main
jutustab	doc_513103214317_item	3675997	et	3	main
keeles	doc_513103214317_item	3675996	et	4	main
ladina	doc_513103214317_item	3675995	et	4	main
aastal	doc_513103214317_item	3675994	et	3	main
1224-12278	doc_513103214317_item	3675993	et	2	main
umbes	doc_513103214317_item	3675992	et	4	main
kirjutatud	doc_513103214317_item	3675991	et	4	main
on	doc_513103214317_item	3675990	et	4	main
ta	doc_513103214317_item	3675989	et	4	main
toimus	doc_513103214317_item	3675988	et	3	main
siin	doc_513103214317_item	3675987	et	4	main
kõik	doc_513103214317_item	3675986	et	4	main
kuidas	doc_513103214317_item	3675985	et	3	main
sellest	doc_513103214317_item	3675984	et	4	main
ülevaate	doc_513103214317_item	3675983	et	4	main
annab	doc_513103214317_item	3675982	et	3	main
mis	doc_513103214317_item	3675981	et	4	main
teos	doc_513103214317_item	3675980	et	4	main
esimene	doc_513103214317_item	3675979	et	3	main
on	doc_513103214317_item	3675978	et	4	main
kroonika	doc_513103214317_item	3675977	et	4	main
liivimaa	doc_513103214317_item	3675976	et	4	main
henriku	doc_513103214317_item	3675975	et	4	main
1	doc_513103214317_item	3675974	et	2	main
teoorjus	doc_513103214317_item	3675973	et	3	main
tähendab	doc_513103214317_item	3675972	et	3	main
mida	doc_513103214317_item	3675971	et	4	main
2	doc_513103214317_item	3675970	et	2	main
keskajast	doc_513103214317_item	3675969	et	4	main
eestimaa	doc_513103214317_item	3675968	et	4	main
meile	doc_513103214317_item	3675967	et	4	main
kui	doc_513103214317_item	3676097	et	3	main
tohtinud	doc_513103214317_item	3676094	et	4	main
nad	doc_513103214317_item	3676092	et	3	main
mis	doc_973441205335_item	3676208	et	4	main
sulamiks	doc_973441205335_item	3676207	et	4	main
üheks	doc_973441205335_item	3676206	et	3	main
on	doc_973441205335_item	3676200	et	4	main
kus	doc_973441205335_item	3676199	et	3	main
teater	doc_973441205335_item	3676198	et	3	main
on	doc_973441205335_item	3676197	et	4	main
ooper	doc_973441205335_item	3676196	et	3	main
kindlalt	doc_973441205335_item	3676195	et	4	main
laval	doc_973441205335_item	3676194	et	3	main
end	doc_973441205335_item	3676193	et	4	main
tunda	doc_973441205335_item	3676192	et	3	main
vajadust	doc_973441205335_item	3676191	et	4	main
ja	doc_973441205335_item	3676190	et	3	main
esinemiskultuuri	doc_973441205335_item	3676189	et	4	main
ooperit	doc_973441205335_item	3676232	et	3	main
armastan	doc_973441205335_item	3676231	et	3	main
ma	doc_973441205335_item	3676230	et	3	main
seepärast	doc_973441205335_item	3676229	et	3	main
elamusega	doc_973441205335_item	3676228	et	3	main
värske	doc_973441205335_item	3676227	et	4	main
kord	doc_973441205335_item	3676225	et	4	main
iga	doc_973441205335_item	3676224	et	4	main
omandada	doc_973441205335_item	3676187	et	3	main
ja	doc_973441205335_item	3676186	et	3	main
näha	doc_973441205335_item	3676185	et	3	main
tahtis	doc_973441205335_item	3676184	et	3	main
on	doc_973441205335_item	3676183	et	4	main
jaoks	doc_973441205335_item	3676182	et	4	main
minu	doc_973441205335_item	3676181	et	3	main
ooperiteatrit	doc_973441205335_item	3676172	et	3	main
ma	doc_973441205335_item	3676170	et	3	main
kõige	doc_973441205335_item	3676168	et	4	main
ja	doc_973441205335_item	3676164	et	3	main
jaoks	doc_973441205335_item	3676161	et	4	main
muusika	doc_973441205335_item	3676155	et	4	main
sest	doc_973441205335_item	3676146	et	4	main
käinud	doc_973441205335_item	3676130	et	4	main
ma	doc_973441205335_item	3676128	et	3	main
läheksite	doc_973441205335_item	3676122	et	3	main
vastus	doc_973441205335_item	3676116	et	3	main
kas	doc_973441205335_item	3676121	et	3	main
kui	doc_973441205335_item	3676118	et	3	main
ainult	doc_973441205330_item	3676312	et	4	main
ja	doc_973441205330_item	3676310	et	3	main
võtta	doc_973441205330_item	3676306	et	3	main
peale	doc_973441205330_item	3676283	et	4	main
koolidesse	doc_973441205330_item	3676282	et	3	main
õpilasi	doc_973441205330_item	3676269	et	3	main
võetakse	doc_973441205330_item	3676268	et	3	main
eliitkoolidesse	doc_973441205330_item	3676267	et	3	main
et	doc_973441205330_item	3676266	et	3	main
sellepärast	doc_973441205330_item	3676265	et	3	main
eelkõige	doc_973441205330_item	3676264	et	3	main
seda	doc_973441205330_item	3676263	et	3	main
elukorda	doc_973441205330_item	3676262	et	4	main
teistsugust	doc_973441205330_item	3676261	et	3	main
tegelik	doc_973441205330_item	3676257	et	3	main
peaks	doc_973441205330_item	3676252	et	4	main
minu	doc_460280307198_item	3676441	et	3	main
jalgrattateed	doc_460280307198_item	3676424	et	4	main
ehitaksin	doc_460280307198_item	3676423	et	3	main
ei	doc_460280307198_item	3676404	et	4	main
inimesed	doc_460280307198_item	3676403	et	3	main
väiksem	doc_460280307198_item	3676356	et	4	main
üha	doc_460280307198_item	3676355	et	3	main
lillede	doc_460280307198_item	3676352	et	4	main
siis	doc_460280307198_item	3676338	et	3	main
et	doc_460280307197_item	3676583	et	3	main
närvi	doc_460280307197_item	3676573	et	4	main
sünnitada	doc_460280307197_item	3676550	et	3	main
suurlinnas	doc_460280307197_item	3676532	et	4	main
tähelepanelikult	doc_460280307197_item	3676525	et	4	main
vaatame	doc_460280307197_item	3676524	et	3	main
me	doc_460280307197_item	3676523	et	4	main
klubid	doc_460280307197_item	3676517	et	3	main
hooned	doc_460280307197_item	3676507	et	4	main
kaasaegsed	doc_460280307197_item	3676506	et	3	main
eluviis	doc_460280307197_item	3676505	et	3	main
aktiivne	doc_460280307197_item	3676504	et	3	main
on	doc_460280307197_item	3676503	et	4	main
puudused	doc_460280307197_item	3676490	et	3	main
suurlinnas	doc_460280307197_item	3676485	et	4	main
osa	doc_460280307197_item	3676479	et	4	main
suurem	doc_460280307197_item	3676478	et	4	main
ja	doc_460280307197_item	3676474	et	3	main
arvates	doc_460280307197_item	3676471	et	4	main
teie	doc_460280307197_item	3676470	et	4	main
infot	doc_460280307196_item	3676763	et	3	main
avalikku	doc_460280307196_item	3676762	et	4	main
reklaami	doc_460280307196_item	3676756	et	4	main
trükiksin	doc_460280307196_item	3676755	et	3	main
lõpuks	doc_460280307196_item	3676749	et	4	main
puhtam	doc_460280307196_item	3676735	et	4	main
oleks	doc_460280307196_item	3676734	et	3	main
linn	doc_460280307196_item	3676733	et	3	main
inimesed	doc_460280307196_item	3676727	et	3	main
on	doc_460280307196_item	3676718	et	4	main
taimi	doc_460280307196_item	3676706	et	4	main
loodust	doc_460280307196_item	3676703	et	4	main
ja	doc_460280307196_item	3676652	et	3	main
vaja	doc_460280307196_item	3676646	et	4	main
on	doc_460280307196_item	3676645	et	4	main
hukuvad	doc_460280307196_item	3676644	et	3	main
veetaimed	doc_460280307196_item	3676643	et	3	main
ja	doc_460280307196_item	3676642	et	3	main
veelomad	doc_460280307196_item	3676641	et	3	main
prügikastid	doc_460280307196_item	3676640	et	3	main
suured	doc_460280307196_item	3676639	et	3	main
nagu	doc_460280307196_item	3676638	et	3	main
on	doc_460280307196_item	3676630	et	4	main
volikogu	doc_460280307196_item	3676615	et	4	main
liige	doc_460280307196_item	3676611	et	4	main
et	doc_460280307196_item	3676682	et	3	main
et	doc_460280307196_item	3676676	et	3	main
on	doc_460280307196_item	3676674	et	4	main
tulevik	doc_460280307196_item	3676673	et	3	main
meie	doc_460280307196_item	3676672	et	4	main
veel	doc_15203423350_item	3676884	et	4	main
või	doc_15203423350_item	3676874	et	4	main
tavaliselt	doc_15203423350_item	3676871	et	4	main
ma	doc_15203423350_item	3676866	et	3	main
kus	doc_15203423350_item	3676865	et	3	main
kättesaadav	doc_973441205330_item	3676329	et	4	main
ühesuguselt	doc_973441205330_item	3676328	et	4	main
kõigil	doc_973441205330_item	3676327	et	4	main
veel	doc_973441205330_item	3676326	et	4	main
pole	doc_973441205330_item	3676325	et	3	main
haridus	doc_973441205330_item	3676324	et	3	main
hea	doc_973441205330_item	3676323	et	4	main
meil	doc_973441205330_item	3676322	et	4	main
et	doc_973441205330_item	3676321	et	3	main
arvan	doc_973441205330_item	3676320	et	3	main
seega	doc_973441205330_item	3676319	et	4	main
haridus	doc_973441205330_item	3676318	et	3	main
tasuta	doc_973441205330_item	3676317	et	4	main
saavad	doc_973441205330_item	3676316	et	4	main
üliõpilased	doc_973441205330_item	3676315	et	3	main
edukad	doc_973441205330_item	3676314	et	3	main
tasuline	doc_973441205330_item	3676304	et	4	main
ülikoolides	doc_973441205330_item	3676300	et	3	main
et	doc_973441205330_item	3676294	et	3	main
astuda	doc_973441205330_item	3676290	et	3	main
kõigil	doc_973441205330_item	3676288	et	4	main
ka	doc_973441205330_item	3676287	et	3	main
pole	doc_973441205330_item	3676286	et	3	main
erakoolidesse	doc_973441205330_item	3676285	et	3	main
selle	doc_973441205330_item	3676284	et	4	main
samuti	doc_973441205330_item	3676272	et	3	main
alusel	doc_973441205330_item	3676271	et	4	main
konkursi	doc_973441205330_item	3676270	et	3	main
elu	doc_973441205330_item	3676258	et	4	main
riigis	doc_973441205330_item	3676251	et	3	main
meie	doc_973441205330_item	3676250	et	4	main
haridus	doc_973441205330_item	3676249	et	3	main
hea	doc_973441205330_item	3676248	et	4	main
konstitutsioonile	doc_973441205330_item	3676247	et	3	main
vabariigi	doc_973441205330_item	3676246	et	3	main
eesti	doc_973441205330_item	3676245	et	4	main
vastavalt	doc_973441205330_item	3676244	et	4	main
kättesaadav	doc_973441205330_item	3676243	et	4	main
kõigile	doc_973441205330_item	3676242	et	4	main
on	doc_973441205330_item	3676241	et	4	main
eestis	doc_973441205330_item	3676240	et	3	main
haridus	doc_973441205330_item	3676239	et	3	main
hea	doc_973441205330_item	3676238	et	4	main
kas	doc_973441205330_item	3676237	et	3	main
küsimusele	doc_973441205330_item	3676236	et	4	main
vastus	doc_973441205330_item	3676235	et	3	main
arvates	doc_460280307198_item	3676442	et	4	main
jalgrattaga	doc_460280307198_item	3676430	et	3	main
sõita	doc_460280307198_item	3676429	et	3	main
ohtlik	doc_460280307198_item	3676428	et	3	main
on	doc_460280307198_item	3676427	et	4	main
kuna	doc_460280307198_item	3676426	et	3	main
elamurajoonides	doc_460280307198_item	3676425	et	3	main
neid	doc_460280307198_item	3676419	et	4	main
oleks	doc_460280307198_item	3676416	et	3	main
paberitele	doc_460280307198_item	3676414	et	3	main
ja	doc_460280307198_item	3676413	et	3	main
et	doc_460280307198_item	3676402	et	3	main
õhk	doc_460280307198_item	3676367	et	3	main
ohus	doc_460280307198_item	3676348	et	3	main
kõigepealt	doc_460280307198_item	3676339	et	3	main
kaasaegseid	doc_460280307197_item	3676587	et	3	main
hulk	doc_460280307197_item	3676586	et	3	main
öeldu	doc_460280307197_item	3676581	et	4	main
turvaliselt	doc_460280307197_item	3676578	et	4	main
ei	doc_460280307197_item	3676575	et	4	main
inimesed	doc_460280307197_item	3676574	et	3	main
on	doc_460280307197_item	3676567	et	4	main
puud	doc_460280307197_item	3676555	et	4	main
suurlinnas	doc_460280307197_item	3676552	et	4	main
lapsi	doc_460280307197_item	3676551	et	4	main
haigused	doc_460280307197_item	3676542	et	4	main
hingamisteede	doc_460280307197_item	3676541	et	3	main
kopsudega	doc_460280307197_item	3676540	et	3	main
probleeme	doc_460280307197_item	3676539	et	3	main
on	doc_460280307197_item	3676538	et	4	main
nendel	doc_460280307197_item	3676537	et	4	main
ohus	doc_460280307197_item	3676536	et	3	main
kui	doc_460280307197_item	3676522	et	3	main
meelelahutused	doc_460280307197_item	3676521	et	4	main
linnas	doc_460280307197_item	3676509	et	4	main
pääse	doc_973441205330_item	3676279	et	4	main
ei	doc_973441205330_item	3676278	et	4	main
näitab	doc_973441205330_item	3676259	et	3	main
kättesaadav	doc_973441205330_item	3676255	et	4	main
olema	doc_973441205330_item	3676254	et	4	main
palju	doc_460280307198_item	3676465	et	4	main
liiga	doc_460280307198_item	3676464	et	4	main
ole	doc_460280307198_item	3676463	et	4	main
ei	doc_460280307198_item	3676462	et	4	main
ka	doc_460280307198_item	3676461	et	3	main
autosid	doc_460280307198_item	3676460	et	3	main
ole	doc_460280307198_item	3676459	et	4	main
ei	doc_460280307198_item	3676458	et	4	main
praktiliselt	doc_460280307198_item	3676457	et	4	main
ummikuid	doc_460280307198_item	3676456	et	4	main
suur	doc_460280307198_item	3676455	et	3	main
ole	doc_460280307198_item	3676454	et	4	main
ei	doc_460280307198_item	3676453	et	4	main
linn	doc_460280307198_item	3676452	et	3	main
meie	doc_460280307198_item	3676451	et	4	main
narvas	doc_460280307198_item	3676450	et	4	main
vaja	doc_460280307198_item	3676449	et	4	main
ole	doc_460280307198_item	3676448	et	4	main
ei	doc_460280307198_item	3676447	et	4	main
üldse	doc_460280307198_item	3676446	et	3	main
kesklinnas	doc_460280307198_item	3676445	et	4	main
olema	doc_460280307198_item	3676439	et	4	main
meie	doc_460280307198_item	3676436	et	4	main
juhtuvad	doc_460280307198_item	3676434	et	4	main
tihti	doc_460280307198_item	3676433	et	3	main
teedel	doc_460280307198_item	3676432	et	3	main
suurtel	doc_460280307198_item	3676431	et	3	main
spetsiaalsed	doc_460280307198_item	3676410	et	3	main
võiks	doc_460280307198_item	3676408	et	4	main
maha	doc_460280307198_item	3676407	et	4	main
inimestel	doc_460280307198_item	3676371	et	3	main
et	doc_460280307198_item	3676366	et	3	main
on	doc_460280307198_item	3676354	et	4	main
puude	doc_460280307198_item	3676350	et	4	main
taimede	doc_460280307198_item	3676349	et	4	main
on	doc_460280307198_item	3676347	et	4	main
linnas	doc_460280307198_item	3676346	et	4	main
meie	doc_460280307198_item	3676345	et	4	main
oodus	doc_460280307198_item	3676344	et	4	main
elamurajoone	doc_460280307198_item	3676343	et	3	main
uusi	doc_460280307198_item	3676342	et	3	main
haljastada	doc_460280307198_item	3676341	et	3	main
liige	doc_460280307198_item	3676337	et	4	main
on	doc_460280307197_item	3676585	et	4	main
kõik	doc_460280307197_item	3676579	et	4	main
ja	doc_460280307197_item	3676569	et	3	main
halvasti	doc_460280307197_item	3676553	et	3	main
saa	doc_460280307197_item	3676549	et	4	main
ei	doc_460280307197_item	3676548	et	4	main
paar	doc_460280307197_item	3676547	et	3	main
mõnus	doc_460280307197_item	3676530	et	4	main
nii	doc_460280307197_item	3676529	et	3	main
on	doc_460280307197_item	3676528	et	4	main
teised	doc_460280307197_item	3676520	et	4	main
ja	doc_460280307197_item	3676519	et	3	main
on	doc_460280307197_item	3676516	et	4	main
ole	doc_460280307197_item	3676511	et	4	main
seal	doc_460280307197_item	3676502	et	4	main
omandada	doc_460280307197_item	3676500	et	3	main
haridus	doc_460280307197_item	3676501	et	3	main
ja	doc_460280307197_item	3676499	et	3	main
tööd	doc_460280307197_item	3676498	et	4	main
leia	doc_460280307197_item	3676497	et	4	main
noortele	doc_460280307197_item	3676496	et	3	main
võimalusi	doc_460280307197_item	3676495	et	3	main
rohkem	doc_460280307197_item	3676494	et	4	main
on	doc_460280307197_item	3676493	et	4	main
avariid	doc_460280307198_item	3676435	et	4	main
ma	doc_460280307198_item	3676422	et	3	main
jäätmeid	doc_460280307198_item	3676420	et	3	main
võimalus	doc_460280307198_item	3676417	et	3	main
siis	doc_460280307198_item	3676415	et	3	main
prügikastid	doc_460280307198_item	3676411	et	3	main
prügikastid	doc_460280307198_item	3676401	et	3	main
puhtam	doc_460280307198_item	3676369	et	4	main
väiksem	doc_460280307198_item	3676358	et	4	main
ja	doc_460280307198_item	3676357	et	3	main
tuleks	doc_460280307198_item	3676340	et	4	main
narva	doc_460280307198_item	3676335	et	4	main
volikogu	doc_460280307198_item	3676336	et	4	main
oleksin	doc_460280307198_item	3676334	et	3	main
ma	doc_460280307198_item	3676333	et	3	main
kui	doc_460280307198_item	3676332	et	3	main
arvamus	doc_460280307198_item	3676331	et	3	main
paigaldaksin	doc_460280307198_item	3676400	et	3	main
seda	doc_460280307198_item	3676398	et	3	main
ma	doc_460280307198_item	3676399	et	3	main
pärast	doc_460280307198_item	3676397	et	4	main
augud	doc_460280307198_item	3676396	et	3	main
on	doc_460280307198_item	3676395	et	4	main
pool	doc_460280307198_item	3676394	et	4	main
igal	doc_460280307198_item	3676393	et	3	main
hirmus	doc_460280307198_item	3676392	et	4	main
on	doc_460280307198_item	3676391	et	4	main
seisund	doc_460280307198_item	3676390	et	3	main
teede	doc_460280307198_item	3676389	et	3	main
praegune	doc_460280307198_item	3676388	et	3	main
linna	doc_460280307198_item	3676387	et	4	main
meie	doc_460280307198_item	3676386	et	4	main
narvas	doc_460280307198_item	3676385	et	4	main
tänavaid	doc_460280307198_item	3676384	et	4	main
asfalteerima	doc_460280307198_item	3676383	et	3	main
peab	doc_460280307198_item	3676382	et	4	main
jooksul	doc_460280307198_item	3676381	et	4	main
aasta	doc_460280307198_item	3676380	et	4	main
viie	doc_460280307198_item	3676379	et	3	main
järgmise	doc_460280307198_item	3676378	et	3	main
veel	doc_460280307198_item	3676377	et	4	main
majaümbuuses	doc_460280307198_item	3676376	et	4	main
oma	doc_460280307198_item	3676375	et	4	main
jalutada	doc_460280307198_item	3676374	et	3	main
põnev	doc_460280307198_item	3676373	et	3	main
oleks	doc_460280307198_item	3676372	et	3	main
taimi	doc_460280307198_item	3676365	et	4	main
rohkem	doc_460280307198_item	3676364	et	4	main
vajab	doc_460280307198_item	3676363	et	3	main
linn	doc_460280307198_item	3676362	et	3	main
väheneb	doc_460280307198_item	3676361	et	3	main
hulk	doc_460280307198_item	3676360	et	3	main
hapniku	doc_460280307198_item	3676359	et	3	main
hulk	doc_460280307198_item	3676353	et	3	main
ja	doc_460280307198_item	3676351	et	3	main
näitab	doc_460280307197_item	3676582	et	3	main
see	doc_460280307197_item	3676571	et	3	main
vägivald	doc_460280307197_item	3676568	et	3	main
kasvavad	doc_460280307197_item	3676554	et	4	main
seitsmes	doc_460280307197_item	3676546	et	4	main
on	doc_460280307197_item	3676535	et	4	main
tervis	doc_460280307197_item	3676534	et	3	main
inimeste	doc_460280307197_item	3676533	et	3	main
kõik	doc_460280307197_item	3676527	et	4	main
mitte	doc_460280307197_item	3676526	et	3	main
ei	doc_460280307197_item	3676510	et	4	main
linnas	doc_460280307197_item	3676492	et	4	main
ja	doc_460280307197_item	3676489	et	3	main
elus	doc_460280307197_item	3676484	et	4	main
muidugi	doc_460280307197_item	3676483	et	4	main
maailmas	doc_460280307197_item	3676477	et	3	main
suurlinna	doc_460280307197_item	3676472	et	4	main
mis	doc_460280307197_item	3676468	et	4	main
rohkem	doc_460280307196_item	3676761	et	4	main
saaksid	doc_460280307196_item	3676760	et	4	main
inimesed	doc_460280307196_item	3676759	et	3	main
viiksin	doc_460280307196_item	3676751	et	3	main
töödelda	doc_460280307196_item	3676746	et	4	main
siis	doc_460280307196_item	3676743	et	3	main
prügi	doc_460280307196_item	3676730	et	4	main
selleks	doc_460280307196_item	3676719	et	4	main
minu	doc_460280307196_item	3676714	et	3	main
ka	doc_460280307196_item	3676711	et	3	main
inimestel	doc_460280307196_item	3676654	et	3	main
kalad	doc_460280307196_item	3676636	et	3	main
soiseks	doc_460280307196_item	3676635	et	4	main
vesi	doc_460280307196_item	3676629	et	4	main
liige	doc_460280307196_item	3676616	et	4	main
volikogu	doc_460280307196_item	3676610	et	4	main
oleksid	doc_460280307196_item	3676608	et	4	main
mis	doc_460280307196_item	3676604	et	4	main
ja	doc_460280307196_item	3676681	et	3	main
heas	doc_460280307196_item	3676679	et	3	main
meeldib	doc_15203423350_item	3676886	et	3	main
mulle	doc_15203423350_item	3676885	et	4	main
sest	doc_15203423350_item	3676881	et	4	main
on	doc_15203423350_item	3676878	et	4	main
kõlab	doc_15203423350_item	3676872	et	3	main
tahad	doc_15203423350_item	3676862	et	3	main
või	doc_15203423350_item	3676847	et	4	main
linna	doc_15203423350_item	3676846	et	4	main
teise	doc_15203423350_item	3676845	et	4	main
sõidan	doc_15203423350_item	3676844	et	3	main
sest	doc_15203423350_item	3676827	et	4	main
see	doc_15203423350_item	3676824	et	3	main
muusikat	doc_15203423350_item	3676822	et	3	main
ka	doc_15203423350_item	3676820	et	3	main
mulle	doc_15203423350_item	3676818	et	4	main
täisealised	doc_15203423350_item	3676817	et	4	main
piiramine	doc_15203423350_item	3676811	et	4	main
toimuvad	doc_15203423350_item	3676806	et	4	main
kontserditele	doc_15203423350_item	3676799	et	4	main
piletid	doc_15203423350_item	3676796	et	3	main
võimalus	doc_15203423350_item	3676794	et	3	main
rahulik	doc_460280307197_item	3676601	et	3	main
ja	doc_460280307197_item	3676600	et	3	main
tervislik	doc_460280307197_item	3676599	et	3	main
ole	doc_460280307197_item	3676598	et	4	main
ei	doc_460280307197_item	3676597	et	4	main
seal	doc_460280307197_item	3676596	et	4	main
elu	doc_460280307197_item	3676595	et	4	main
aga	doc_460280307197_item	3676594	et	3	main
areng	doc_460280307197_item	3676593	et	3	main
tehnika	doc_460280307197_item	3676592	et	4	main
kõrge	doc_460280307197_item	3676591	et	4	main
on	doc_460280307197_item	3676590	et	4	main
ja	doc_460280307197_item	3676589	et	3	main
mugavusi	doc_460280307197_item	3676588	et	4	main
suurlinnas	doc_460280307197_item	3676584	et	4	main
ülapool	doc_460280307197_item	3676580	et	4	main
end	doc_460280307197_item	3676577	et	4	main
tunne	doc_460280307197_item	3676576	et	4	main
ajab	doc_460280307197_item	3676572	et	3	main
müra	doc_460280307197_item	3676570	et	4	main
tänavatel	doc_460280307197_item	3676566	et	4	main
poolt	doc_460280307197_item	3676565	et	4	main
suurettevõtete	doc_460280307197_item	3676564	et	3	main
ja	doc_460280307197_item	3676563	et	3	main
transpordi	doc_460280307197_item	3676562	et	4	main
heitgaasidega	doc_460280307197_item	3676561	et	3	main
saatatud	doc_460280307197_item	3676560	et	3	main
on	doc_460280307197_item	3676559	et	4	main
õhk	doc_460280307197_item	3676558	et	3	main
põõsad	doc_460280307197_item	3676557	et	3	main
ja	doc_460280307197_item	3676556	et	3	main
iga	doc_460280307197_item	3676545	et	4	main
allergiad	doc_460280307197_item	3676544	et	3	main
ja	doc_460280307197_item	3676543	et	3	main
elus	doc_460280307197_item	3676531	et	4	main
üritused	doc_460280307197_item	3676518	et	4	main
pool	doc_460280307197_item	3676515	et	4	main
igal	doc_460280307197_item	3676514	et	3	main
igav	doc_460280307197_item	3676513	et	3	main
kunagi	doc_460280307197_item	3676512	et	3	main
kõigepealt	doc_460280307197_item	3676491	et	3	main
eelised	doc_460280307197_item	3676488	et	4	main
oma	doc_460280307197_item	3676487	et	4	main
puudused	doc_460280307197_item	3676475	et	3	main
eelised	doc_460280307197_item	3676473	et	4	main
kaubakeskused	doc_460280307197_item	3676508	et	3	main
on	doc_460280307197_item	3676486	et	4	main
inimesi	doc_460280307197_item	3676480	et	4	main
tänapäeva	doc_460280307197_item	3676476	et	4	main
on	doc_460280307197_item	3676469	et	4	main
abil	doc_460280307196_item	3676758	et	4	main
ma	doc_460280307196_item	3676750	et	3	main
neid	doc_460280307196_item	3676747	et	4	main
võimalus	doc_460280307196_item	3676745	et	3	main
paberitele	doc_460280307196_item	3676742	et	3	main
prügikaste	doc_460280307196_item	3676739	et	4	main
spetsiaalseid	doc_460280307196_item	3676738	et	3	main
teha	doc_460280307196_item	3676737	et	3	main
maale	doc_460280307196_item	3676731	et	4	main
et	doc_460280307196_item	3676726	et	3	main
looduskaitseala	doc_460280307196_item	3676716	et	4	main
ja	doc_460280307196_item	3676705	et	3	main
linnas	doc_460280307197_item	3676482	et	4	main
elab	doc_460280307197_item	3676481	et	3	main
arvamus	doc_460280307197_item	3676467	et	3	main
see	doc_460280307196_item	3676764	et	3	main
ja	doc_460280307196_item	3676754	et	3	main
loodusesõbrad	doc_460280307196_item	3676753	et	3	main
ürituse	doc_460280307196_item	3676752	et	4	main
ja	doc_460280307196_item	3676732	et	3	main
viskaks	doc_460280307196_item	3676729	et	3	main
ma	doc_460280307196_item	3676723	et	3	main
lisaks	doc_460280307196_item	3676722	et	4	main
meetod	doc_460280307196_item	3676721	et	3	main
hea	doc_460280307196_item	3676720	et	4	main
arvates	doc_460280307196_item	3676715	et	4	main
tulevastele	doc_460280307196_item	3676712	et	4	main
säiliks	doc_460280307196_item	3676710	et	3	main
põnev	doc_460280307196_item	3676656	et	3	main
on	doc_460280307196_item	3676637	et	4	main
on	doc_460280307196_item	3676627	et	4	main
meie	doc_460280307196_item	3676622	et	4	main
puhastamist	doc_460280307196_item	3676621	et	4	main
veekogude	doc_460280307196_item	3676620	et	3	main
kui	doc_460280307196_item	3676612	et	3	main
linna	doc_460280307196_item	3676609	et	4	main
kasvaksid	doc_460280307196_item	3676678	et	4	main
tähtis	doc_460280307196_item	3676675	et	4	main
keha	doc_15203423350_item	3676891	et	4	main
puhkavad	doc_15203423350_item	3676888	et	4	main
dzhäss	doc_15203423350_item	3676887	et	4	main
joonistada	doc_15203423350_item	3676880	et	3	main
parem	doc_15203423350_item	3676879	et	4	main
nii	doc_15203423350_item	3676877	et	3	main
muusika	doc_15203423350_item	3676876	et	4	main
ajal	doc_15203423350_item	3676870	et	4	main
tunni	doc_15203423350_item	3676869	et	3	main
joonistamise	doc_15203423350_item	3676868	et	4	main
käin	doc_15203423350_item	3676867	et	3	main
kunstistuudios	doc_15203423350_item	3676864	et	3	main
cdpleier	doc_15203423350_item	3676853	et	4	main
oma	doc_15203423350_item	3676837	et	4	main
teha	doc_15203423350_item	3676836	et	3	main
ise	doc_15203423350_item	3676835	et	4	main
võib	doc_15203423350_item	3676834	et	3	main
ja	doc_15203423350_item	3676833	et	3	main
selge	doc_15203423350_item	3676832	et	4	main
kõla	doc_15203423350_item	3676831	et	4	main
mugav	doc_15203423350_item	3676826	et	3	main
meeldib	doc_15203423350_item	3676819	et	3	main
et	doc_15203423350_item	3676812	et	3	main
on	doc_15203423350_item	3676810	et	4	main
tihti	doc_15203423350_item	3676809	et	3	main
lemmiklauljate	doc_15203423350_item	3676798	et	3	main
minu	doc_15203423350_item	3676797	et	3	main
eelistate	doc_15203423350_item	3676785	et	3	main
muusikat	doc_15203423350_item	3676784	et	3	main
makilindilt	doc_15203423350_item	3676781	et	3	main
kuulata	doc_15203423350_item	3676778	et	4	main
või	doc_15203423350_item	3676777	et	4	main
loodusekaitsmist	doc_460280307196_item	3676768	et	3	main
propageerida	doc_460280307196_item	3676767	et	3	main
ka	doc_460280307196_item	3676766	et	3	main
aitaks	doc_460280307196_item	3676765	et	3	main
selle	doc_460280307196_item	3676757	et	4	main
jäätmeid	doc_460280307196_item	3676748	et	3	main
oleks	doc_460280307196_item	3676744	et	3	main
ja	doc_460280307196_item	3676741	et	3	main
klaasile	doc_460280307196_item	3676740	et	3	main
võiks	doc_460280307196_item	3676736	et	4	main
ei	doc_460280307196_item	3676728	et	4	main
prügikaste	doc_460280307196_item	3676725	et	4	main
paigaldaksin	doc_460280307196_item	3676724	et	3	main
rajamine	doc_460280307196_item	3676717	et	4	main
põlvadele	doc_460280307196_item	3676713	et	4	main
loodus	doc_460280307196_item	3676709	et	4	main
eesti	doc_460280307196_item	3676708	et	4	main
et	doc_460280307196_item	3676707	et	3	main
loomi	doc_460280307196_item	3676704	et	4	main
kaunist	doc_460280307196_item	3676702	et	4	main
kaitsma	doc_460280307196_item	3676701	et	3	main
peame	doc_460280307196_item	3676700	et	4	main
me	doc_460280307196_item	3676699	et	4	main
hädaohus	doc_460280307196_item	3676698	et	3	main
on	doc_460280307196_item	3676697	et	4	main
tervis	doc_460280307196_item	3676696	et	3	main
inimeste	doc_460280307196_item	3676695	et	3	main
looduskaitseala	doc_460280307196_item	3676694	et	4	main
rajaksin	doc_460280307196_item	3676693	et	3	main
ma	doc_460280307196_item	3676692	et	3	main
seda	doc_460280307196_item	3676691	et	3	main
pärast	doc_460280307196_item	3676690	et	4	main
suhtlemiseks	doc_460280307196_item	3676689	et	4	main
sõpradega	doc_460280307196_item	3676688	et	3	main
ja	doc_460280307196_item	3676687	et	3	main
mängudeks	doc_460280307196_item	3676686	et	3	main
koht	doc_460280307196_item	3676685	et	3	main
oleks	doc_460280307196_item	3676684	et	3	main
neil	doc_460280307196_item	3676683	et	4	main
lapsed	doc_460280307196_item	3676670	et	3	main
renoveerimist	doc_460280307196_item	3676669	et	4	main
finantseeriksin	doc_460280307196_item	3676667	et	3	main
lastemaänguväljakute	doc_460280307196_item	3676668	et	4	main
ma	doc_460280307196_item	3676666	et	3	main
veel	doc_460280307196_item	3676665	et	4	main
vees	doc_460280307196_item	3676664	et	3	main
supelda	doc_460280307196_item	3676663	et	4	main
ning	doc_460280307196_item	3676662	et	3	main
kaldal	doc_460280307196_item	3676661	et	3	main
veekogu	doc_460280307196_item	3676660	et	4	main
puhata	doc_460280307196_item	3676659	et	4	main
ja	doc_460280307196_item	3676658	et	3	main
jalutada	doc_460280307196_item	3676657	et	3	main
oleks	doc_460280307196_item	3676655	et	3	main
ekosüsteemi	doc_460280307196_item	3676651	et	4	main
et	doc_460280307196_item	3676649	et	3	main
et	doc_460280307196_item	3676653	et	3	main
parendada	doc_460280307196_item	3676650	et	3	main
veekogusid	doc_460280307196_item	3676648	et	4	main
reostatud	doc_460280307196_item	3676631	et	4	main
hirmus	doc_460280307196_item	3676628	et	4	main
veekogude	doc_460280307196_item	3676625	et	3	main
linna	doc_460280307196_item	3676623	et	4	main
oleksin	doc_460280307196_item	3676614	et	3	main
ma	doc_460280307196_item	3676613	et	3	main
teeksid	doc_460280307196_item	3676606	et	4	main
nad	doc_460280307196_item	3676677	et	3	main
on	doc_460280307196_item	3676671	et	4	main
ja	doc_15203423350_item	3676890	et	3	main
hing	doc_15203423350_item	3676889	et	3	main
puhastada	doc_460280307196_item	3676647	et	3	main
muutub	doc_460280307196_item	3676634	et	3	main
ja	doc_460280307196_item	3676633	et	3	main
õitseb	doc_460280307196_item	3676632	et	4	main
seisund	doc_460280307196_item	3676626	et	3	main
praegune	doc_460280307196_item	3676624	et	3	main
rahastaksin	doc_460280307196_item	3676619	et	4	main
kõigepealt	doc_460280307196_item	3676618	et	3	main
siis	doc_460280307196_item	3676617	et	3	main
kui	doc_460280307196_item	3676607	et	3	main
sa	doc_460280307196_item	3676605	et	3	main
arvamus	doc_460280307196_item	3676603	et	3	main
olukorras	doc_460280307196_item	3676680	et	3	main
võin	doc_15203423350_item	3676882	et	3	main
klassikaline	doc_15203423350_item	3676875	et	4	main
mõelda	doc_15203423350_item	3676863	et	4	main
huvitavad	doc_15203423350_item	3676859	et	4	main
alati	doc_15203423350_item	3676851	et	4	main
on	doc_15203423350_item	3676850	et	4	main
mul	doc_15203423350_item	3676849	et	3	main
riiki	doc_15203423350_item	3676848	et	4	main
või	doc_15203423350_item	3676843	et	4	main
üksi	doc_15203423350_item	3676842	et	4	main
jalutan	doc_15203423350_item	3676841	et	3	main
kui	doc_15203423350_item	3676840	et	3	main
kuulata	doc_15203423350_item	3676821	et	4	main
niisugused	doc_15203423350_item	3676807	et	3	main
narvas	doc_15203423350_item	3676804	et	4	main
ja	doc_15203423350_item	3676803	et	3	main
kallid	doc_15203423350_item	3676802	et	3	main
liiga	doc_15203423350_item	3676801	et	4	main
kahjuks	doc_15203423350_item	3676795	et	4	main
käia	doc_15203423350_item	3676790	et	4	main
lõõgastada	doc_15203423350_item	3676883	et	3	main
rokk	doc_15203423350_item	3676873	et	3	main
milledest	doc_15203423350_item	3676861	et	3	main
sõnad	doc_15203423350_item	3676860	et	4	main
on	doc_15203423350_item	3676858	et	4	main
rokklauludel	doc_15203423350_item	3676857	et	3	main
rokkmuusikat	doc_15203423350_item	3676856	et	3	main
kuulata	doc_15203423350_item	3676855	et	4	main
eelistan	doc_15203423350_item	3676854	et	3	main
on	doc_15203423350_item	3676829	et	4	main
cd-l	doc_15203423350_item	3676828	et	3	main
on	doc_15203423350_item	3676825	et	4	main
cd-lt	doc_15203423350_item	3676823	et	3	main
võivad	doc_15203423350_item	3676814	et	4	main
kontserdile	doc_15203423350_item	3676813	et	3	main
on	doc_15203423350_item	3676800	et	4	main
kontserditel	doc_15203423350_item	3676791	et	4	main
loomulikult	doc_491521501925_item	3677595	et	4	main
ta	doc_491521501925_item	3677588	et	4	main
et	doc_491521501925_item	3677579	et	3	main
et	doc_491521501925_item	3677573	et	3	main
arvan	doc_491521501925_item	3677558	et	3	main
ei	doc_491521501925_item	3677543	et	4	main
horoskoope	doc_491521501925_item	3677542	et	3	main
isa	doc_491521501925_item	3677532	et	4	main
kuid	doc_491521501925_item	3677523	et	4	main
teinud	doc_491521501925_item	3677517	et	4	main
eritsooni	doc_491521501925_item	3677274	et	4	main
köitis	doc_491521501925_item	3677266	et	3	main
ma	doc_491521501925_item	3677513	et	3	main
tahaksite	doc_491521501925_item	3677511	et	3	main
millises	doc_491521501925_item	3677507	et	3	main
ettevõtmisi	doc_491521501925_item	3677504	et	3	main
kaasas	doc_15203423350_item	3676852	et	4	main
cd	doc_15203423350_item	3676839	et	4	main
lemmiklaulude	doc_15203423350_item	3676838	et	3	main
muusika	doc_15203423350_item	3676830	et	4	main
ainult	doc_15203423350_item	3676816	et	4	main
minna	doc_15203423350_item	3676815	et	3	main
üritused	doc_15203423350_item	3676808	et	4	main
harva	doc_15203423350_item	3676805	et	4	main
on	doc_15203423350_item	3676793	et	4	main
kui	doc_15203423350_item	3676792	et	3	main
miks	doc_15203423350_item	3676787	et	4	main
cd-lt	doc_15203423350_item	3676782	et	3	main
raadiost	doc_15203423350_item	3676780	et	3	main
eelistan	doc_15203423350_item	3676789	et	3	main
ma	doc_15203423350_item	3676788	et	3	main
kuulata	doc_15203423350_item	3676786	et	4	main
millist	doc_15203423350_item	3676783	et	3	main
muusikat	doc_15203423350_item	3676779	et	3	main
kontserditel	doc_15203423350_item	3676776	et	4	main
käia	doc_15203423350_item	3676775	et	4	main
eelistate	doc_15203423350_item	3676774	et	3	main
kas	doc_15203423350_item	3676773	et	3	main
küsimusele	doc_15203423350_item	3676772	et	4	main
vastus	doc_15203423350_item	3676771	et	3	main
on	doc_491521501925_item	3677594	et	4	main
meelest	doc_491521501925_item	3677587	et	4	main
minu	doc_491521501925_item	3677586	et	3	main
4	doc_491521501925_item	3677585	et	2	main
tugev	doc_491521501925_item	3677576	et	4	main
temal	doc_491521501925_item	3677574	et	3	main
võib	doc_491521501925_item	3677599	et	3	main
kohtus	doc_491521501925_item	3677591	et	4	main
töötada	doc_491521501925_item	3677590	et	3	main
võiks	doc_491521501925_item	3677589	et	4	main
2	doc_491521501925_item	3677563	et	2	main
see	doc_491521501925_item	3677560	et	3	main
asi	doc_491521501925_item	3677555	et	4	main
ka	doc_491521501925_item	3677538	et	3	main
siiski	doc_491521501925_item	3677524	et	4	main
saada	doc_491521501925_item	3677261	et	4	main
vastus	doc_491521501925_item	3677256	et	3	main
eesti	doc_491521501925_item	3677510	et	4	main
riigis	doc_491521501925_item	3677508	et	3	main
pooleli	doc_491521501925_item	3677505	et	3	main
päris	doc_491521501925_item	3677492	et	4	main
ole	doc_491521501925_item	3677489	et	4	main
jaoks	doc_491521501925_item	3677428	et	4	main
tõsta	doc_491521501925_item	3677400	et	4	main
tahaks	doc_491521501925_item	3677399	et	3	main
eelkõige	doc_491521501925_item	3677398	et	3	main
targemaks	doc_491521501925_item	3677397	et	4	main
saada	doc_491521501925_item	3677396	et	4	main
et	doc_491521501925_item	3677395	et	3	main
lugeda	doc_491521501925_item	3677394	et	3	main
rohkem	doc_491521501925_item	3677383	et	4	main
peale	doc_491521501925_item	3677379	et	4	main
ja	doc_491521501925_item	3677369	et	3	main
kohlta-järve	doc_491521501925_item	3677341	et	4	main
pööraseim	doc_491521501925_item	3677330	et	4	main
mis	doc_491521501925_item	3677325	et	4	main
selliste	doc_491521501925_item	3677321	et	4	main
hoidun	doc_491521501925_item	3677319	et	3	main
petnud	doc_491521501925_item	3677317	et	4	main
mind	doc_491521501925_item	3677316	et	4	main
üldiselt	doc_491521501925_item	3677308	et	4	main
veel	doc_491521501925_item	3677298	et	4	main
suurimaks	doc_491521501925_item	3677289	et	4	main
peate	doc_491521501925_item	3677286	et	4	main
töötada	doc_491521501925_item	3677600	et	3	main
ta	doc_491521501925_item	3677580	et	4	main
iseloom	doc_491521501925_item	3677577	et	3	main
on	doc_491521501925_item	3677575	et	4	main
mulle	doc_491521501925_item	3677571	et	4	main
juristina	doc_491521501925_item	3677569	et	3	main
töötab	doc_491521501925_item	3677568	et	3	main
ta	doc_491521501925_item	3677567	et	4	main
et	doc_491521501925_item	3677566	et	3	main
mõtlen	doc_491521501925_item	3677565	et	3	main
nendest	doc_491521501925_item	3677550	et	4	main
neid	doc_491521501925_item	3677547	et	4	main
usu	doc_491521501925_item	3677546	et	4	main
kas	doc_491521501925_item	3677540	et	3	main
peab	doc_491521501925_item	3677537	et	4	main
öeldut	doc_491521501925_item	3677533	et	4	main
parem	doc_491521501925_item	3677529	et	4	main
kõige	doc_491521501925_item	3677528	et	4	main
mul	doc_491521501925_item	3677527	et	3	main
eestis	doc_491521501925_item	3677526	et	3	main
venemaal	doc_491521501925_item	3677520	et	4	main
nii	doc_491521501925_item	3677519	et	3	main
mida	doc_491521501925_item	3677285	et	4	main
muutusid	doc_491521501925_item	3677284	et	4	main
huvid	doc_491521501925_item	3677283	et	3	main
hiljem	doc_491521501925_item	3677282	et	3	main
aga	doc_491521501925_item	3677281	et	3	main
nemad	doc_491521501925_item	3677280	et	3	main
nagu	doc_491521501925_item	3677279	et	3	main
sööst	doc_491521501925_item	3677273	et	3	main
elanud	doc_491521501925_item	3677515	et	4	main
ole	doc_491521501925_item	3677500	et	4	main
alguses	doc_491521501925_item	3677496	et	4	main
ma	doc_491521501925_item	3677495	et	3	main
mida	doc_491521501925_item	3677494	et	4	main
see	doc_491521501925_item	3677493	et	3	main
iga	doc_491521501925_item	3677490	et	4	main
ei	doc_491521501925_item	3677488	et	4	main
tulemus	doc_491521501925_item	3677487	et	3	main
see	doc_491521501925_item	3677486	et	3	main
kui	doc_491521501925_item	3677485	et	3	main
siis	doc_491521501925_item	3677484	et	3	main
isegi	doc_491521501925_item	3677483	et	4	main
lõpuni	doc_491521501925_item	3677482	et	3	main
aga	doc_491521501925_item	3677601	et	3	main
ta	doc_491521501925_item	3677598	et	4	main
päeval	doc_491521501925_item	3677597	et	3	main
öökullitüüpi	doc_491521501925_item	3677596	et	4	main
ta	doc_491521501925_item	3677593	et	4	main
5	doc_491521501925_item	3677592	et	2	main
lõpuni	doc_491521501925_item	3677584	et	3	main
asjad	doc_491521501925_item	3677583	et	3	main
kõik	doc_491521501925_item	3677582	et	4	main
teeb	doc_491521501925_item	3677581	et	3	main
targemaks	doc_491521501925_item	3677617	et	4	main
saada	doc_491521501925_item	3677616	et	4	main
et	doc_491521501925_item	3677615	et	3	main
lugeda	doc_491521501925_item	3677614	et	3	main
palju	doc_491521501925_item	3677613	et	4	main
väga	doc_491521501925_item	3677612	et	3	main
tahab	doc_491521501925_item	3677611	et	3	main
ta	doc_491521501925_item	3677610	et	4	main
lauses	doc_491521501925_item	3677609	et	3	main
neljas	doc_491521501925_item	3677608	et	4	main
kirjutasin	doc_491521501925_item	3677607	et	3	main
juba	doc_491521501925_item	3677606	et	3	main
ma	doc_491521501925_item	3677605	et	3	main
6	doc_491521501925_item	3677604	et	2	main
õppida	doc_491521501925_item	3677603	et	3	main
õhtuti	doc_491521501925_item	3677602	et	3	main
sellepärast	doc_491521501925_item	3677578	et	3	main
ma	doc_491521501925_item	3677564	et	3	main
et	doc_491521501925_item	3677559	et	3	main
ma	doc_491521501925_item	3677557	et	3	main
tõsine	doc_491521501925_item	3677554	et	4	main
huvitu	doc_491521501925_item	3677549	et	4	main
ega	doc_491521501925_item	3677548	et	3	main
loete	doc_491521501925_item	3677541	et	4	main
seal	doc_491521501925_item	3677536	et	4	main
sündisid	doc_491521501925_item	3677535	et	4	main
kus	doc_491521501925_item	3677534	et	3	main
oma	doc_491521501925_item	3677531	et	4	main
järgin	doc_491521501925_item	3677530	et	3	main
saksamaal	doc_491521501925_item	3677522	et	4	main
kui	doc_491521501925_item	3677521	et	3	main
ja	doc_491521501925_item	3677516	et	3	main
samasuguseks	doc_491521501925_item	3677278	et	4	main
film	doc_491521501925_item	3677272	et	3	main
dessantväelasest	doc_491521501925_item	3677270	et	3	main
väga	doc_491521501925_item	3677268	et	3	main
mind	doc_491521501925_item	3677265	et	4	main
luurajaks	doc_491521501925_item	3677264	et	4	main
saada	doc_491521501925_item	3677263	et	4	main
unistasin	doc_491521501925_item	3677262	et	3	main
küsimusele	doc_491521501925_item	3677257	et	4	main
elada	doc_491521501925_item	3677512	et	3	main
peale	doc_491521501925_item	3677509	et	4	main
jätta	doc_491521501925_item	3677506	et	3	main
oma	doc_491521501925_item	3677503	et	4	main
kombeks	doc_491521501925_item	3677502	et	4	main
mul	doc_491521501925_item	3677501	et	3	main
lootnud	doc_491521501925_item	3677498	et	4	main
siis	doc_491521501925_item	3677447	et	3	main
võimalikult	doc_491521501925_item	3677436	et	4	main
inimesi	doc_491521501925_item	3677435	et	4	main
kohtuasjades	doc_491521501925_item	3677434	et	3	main
mille	doc_491521501925_item	3677427	et	3	main
vasknarva	doc_491521501925_item	3677426	et	4	main
karjamaa	doc_491521501925_item	3677425	et	4	main
alajõe	doc_491521501925_item	3677424	et	3	main
kant	doc_491521501925_item	3677423	et	3	main
peipsi-äärne	doc_491521501925_item	3677422	et	3	main
valitud	doc_491521501925_item	3677403	et	4	main
taset	doc_491521501925_item	3677402	et	3	main
palju	doc_491521501925_item	3677393	et	4	main
osta	doc_491521501925_item	3677389	et	4	main
kulub	doc_491521501925_item	3677380	et	3	main
võimu	doc_491521501925_item	3677370	et	4	main
rohkem	doc_491521501925_item	3677367	et	4	main
mida	doc_491521501925_item	3677366	et	4	main
juures	doc_491521501925_item	3677362	et	4	main
ja	doc_491521501925_item	3677360	et	3	main
rikkad	doc_491521501925_item	3677359	et	4	main
õhk	doc_491521501925_item	3677342	et	3	main
selle	doc_491521501925_item	3677338	et	4	main
see	doc_491521501925_item	3677334	et	3	main
elu	doc_491521501925_item	3677329	et	4	main
puutumast	doc_491521501925_item	3677324	et	4	main
ma	doc_491521501925_item	3677306	et	3	main
reeturlus	doc_491521501925_item	3677303	et	4	main
mind	doc_491521501925_item	3677297	et	4	main
elu	doc_491521501925_item	3677288	et	4	main
seal	doc_634572338201_item	3677781	et	4	main
tihti	doc_634572338201_item	3677777	et	3	main
mind	doc_634572338201_item	3677772	et	4	main
tähte	doc_634572338201_item	3677766	et	4	main
oli	doc_634572338201_item	3677764	et	3	main
koolis	doc_634572338201_item	3677762	et	4	main
kontsert	doc_634572338201_item	3677759	et	3	main
kord	doc_634572338201_item	3677756	et	4	main
teine	doc_634572338201_item	3677755	et	3	main
esse	doc_634572338201_item	3677754	et	3	main
kirjutama	doc_634572338201_item	3677753	et	3	main
pean	doc_634572338201_item	3677752	et	4	main
aga	doc_634572338201_item	3677748	et	3	main
oli	doc_634572338201_item	3677743	et	3	main
kuhu	doc_634572338201_item	3677721	et	3	main
arvate	doc_634572338201_item	3677720	et	3	main
tegin	doc_634572338201_item	3677707	et	3	main
mina	doc_634572338201_item	3677705	et	4	main
tõmban	doc_634572338201_item	3677684	et	3	main
annab	doc_634572338201_item	3677678	et	3	main
tundub	doc_491521501925_item	3677572	et	3	main
3	doc_491521501925_item	3677570	et	2	main
mees	doc_491521501925_item	3677562	et	4	main
on	doc_491521501925_item	3677561	et	4	main
1	doc_491521501925_item	3677556	et	2	main
ole	doc_491521501925_item	3677553	et	4	main
ei	doc_491521501925_item	3677552	et	4	main
see	doc_491521501925_item	3677551	et	3	main
ei	doc_491521501925_item	3677545	et	4	main
ma	doc_491521501925_item	3677544	et	3	main
elama	doc_491521501925_item	3677539	et	3	main
on	doc_491521501925_item	3677525	et	4	main
tööd	doc_491521501925_item	3677518	et	4	main
saada	doc_491521501925_item	3677277	et	4	main
tahtsin	doc_491521501925_item	3677276	et	3	main
ja	doc_491521501925_item	3677275	et	3	main
tehtud	doc_491521501925_item	3677271	et	4	main
tolleaegne	doc_491521501925_item	3677269	et	3	main
ka	doc_491521501925_item	3677267	et	3	main
lapsepõlves	doc_491521501925_item	3677260	et	4	main
tahtsite	doc_491521501925_item	3677259	et	3	main
kelleks	doc_491521501925_item	3677258	et	4	main
olen	doc_491521501925_item	3677514	et	3	main
asjad	doc_491521501925_item	3677481	et	3	main
viia	doc_491521501925_item	3677480	et	3	main
järjekindlus	doc_491521501925_item	3677479	et	4	main
on	doc_491521501925_item	3677478	et	4	main
see	doc_491521501925_item	3677477	et	3	main
et	doc_491521501925_item	3677476	et	3	main
arvan	doc_491521501925_item	3677475	et	3	main
ma	doc_491521501925_item	3677474	et	3	main
küljeks	doc_491521501925_item	3677473	et	3	main
tugevaimaks	doc_491521501925_item	3677472	et	4	main
oma	doc_491521501925_item	3677471	et	4	main
peate	doc_491521501925_item	3677470	et	4	main
omadust	doc_491521501925_item	3677469	et	4	main
millist	doc_491521501925_item	3677468	et	3	main
öötundidel	doc_491521501925_item	3677467	et	3	main
hilistel	doc_491521501925_item	3677466	et	3	main
ka	doc_491521501925_item	3677465	et	3	main
tegema	doc_491521501925_item	3677464	et	3	main
tööd	doc_491521501925_item	3677463	et	4	main
harjunud	doc_491521501925_item	3677462	et	4	main
olen	doc_491521501925_item	3677461	et	3	main
seetõttu	doc_491521501925_item	3677460	et	3	main
ja	doc_491521501925_item	3677459	et	3	main
inimene	doc_491521501925_item	3677458	et	3	main
tüüpi	doc_491521501925_item	3677457	et	4	main
öökulli	doc_491521501925_item	3677456	et	4	main
loomult	doc_491521501925_item	3677455	et	3	main
olen	doc_491521501925_item	3677454	et	3	main
ma	doc_491521501925_item	3677453	et	3	main
kuid	doc_491521501925_item	3677452	et	4	main
valmistuda	doc_491521501925_item	3677451	et	3	main
paremini	doc_491521501925_item	3677450	et	4	main
veelgi	doc_491521501925_item	3677449	et	4	main
jõuaks	doc_491521501925_item	3677448	et	3	main
aidata	doc_491521501925_item	3677438	et	4	main
hästi	doc_491521501925_item	3677437	et	3	main
ei	doc_491521501925_item	3677429	et	4	main
teie	doc_491521501925_item	3677419	et	4	main
väga	doc_491521501925_item	3677392	et	3	main
kõige	doc_491521501925_item	3677382	et	4	main
teil	doc_491521501925_item	3677381	et	4	main
ei	doc_491521501925_item	3677499	et	4	main
olin	doc_491521501925_item	3677497	et	3	main
kord	doc_491521501925_item	3677491	et	4	main
aega	doc_491521501925_item	3677446	et	4	main
natukene	doc_491521501925_item	3677444	et	4	main
tahan	doc_491521501925_item	3677433	et	3	main
kuna	doc_491521501925_item	3677432	et	3	main
aega	doc_491521501925_item	3677431	et	4	main
on	doc_491521501925_item	3677418	et	4	main
milline	doc_491521501925_item	3677417	et	3	main
looduses	doc_491521501925_item	3677416	et	4	main
kusagil	doc_491521501925_item	3677415	et	3	main
perega	doc_491521501925_item	3677414	et	3	main
koos	doc_491521501925_item	3677413	et	4	main
oma	doc_491521501925_item	3677401	et	4	main
ma	doc_491521501925_item	3677390	et	3	main
tahaksite	doc_491521501925_item	3677388	et	3	main
mille	doc_491521501925_item	3677378	et	3	main
rohkem	doc_491521501925_item	3677374	et	4	main
on	doc_491521501925_item	3677371	et	4	main
raha	doc_491521501925_item	3677368	et	4	main
sest	doc_491521501925_item	3677365	et	4	main
inimesed	doc_491521501925_item	3677364	et	3	main
ei	doc_491521501925_item	3677355	et	4	main
kindlasti	doc_491521501925_item	3677354	et	3	main
kuid	doc_491521501925_item	3677353	et	4	main
öelda	doc_491521501925_item	3677352	et	4	main
tegu	doc_491521501925_item	3677331	et	4	main
on	doc_491521501925_item	3677326	et	4	main
inimestega	doc_491521501925_item	3677322	et	3	main
välja	doc_491521501925_item	3677312	et	4	main
inimestele	doc_491521501925_item	3677311	et	3	main
ütle	doc_491521501925_item	3677310	et	4	main
ei	doc_491521501925_item	3677309	et	4	main
ja	doc_491521501925_item	3677304	et	3	main
ärritab	doc_491521501925_item	3677302	et	3	main
ootab	doc_491521501925_item	3677296	et	3	main
saavutus	doc_491521501925_item	3677295	et	4	main
selline	doc_491521501925_item	3677294	et	4	main
et	doc_491521501925_item	3677293	et	3	main
loodan	doc_491521501925_item	3677292	et	3	main
oma	doc_491521501925_item	3677287	et	4	main
kuj	doc_634572338201_item	3677779	et	4	main
küsis	doc_634572338201_item	3677771	et	3	main
ja	doc_634572338201_item	3677768	et	3	main
mina	doc_634572338201_item	3677751	et	4	main
seepärast	doc_634572338201_item	3677750	et	3	main
ja	doc_634572338201_item	3677745	et	3	main
poppi	doc_634572338201_item	3677708	et	4	main
mina	doc_634572338201_item	3677698	et	4	main
seda	doc_634572338201_item	3677697	et	3	main
just	doc_634572338201_item	3677696	et	3	main
dvd	doc_634572338201_item	3677695	et	4	main
teen	doc_634572338201_item	3677694	et	3	main
ja	doc_634572338201_item	3677693	et	3	main
seda	doc_634572338201_item	3677690	et	3	main
tegevuses	doc_634572338201_item	3677669	et	4	main
filmide	doc_634572338201_item	3677668	et	3	main
se	doc_634572338201_item	3677661	et	4	main
raske	doc_634572338201_item	3677658	et	4	main
video	doc_634572338201_item	3677647	et	4	main
töötama	doc_634572338201_item	3677642	et	3	main
sel	doc_634572338201_item	3677637	et	3	main
kultuuri	doc_491521502185_item	3678057	et	4	main
selle	doc_491521502185_item	3678046	et	4	main
territooriumitest	doc_491521502185_item	3678045	et	3	main
liikumine	doc_491521502185_item	3678035	et	4	main
vennastekoguduse	doc_491521502185_item	3678034	et	3	main
liivimaat	doc_491521502185_item	3678030	et	3	main
mis	doc_491521502185_item	3678018	et	4	main
kalevipoeg	doc_491521502185_item	3678017	et	3	main
eepost	doc_491521502185_item	3678016	et	3	main
1878	doc_491521502185_item	3677971	et	2	main
ka	doc_491521502185_item	3677968	et	3	main
andekamaid	doc_491521502185_item	3677961	et	4	main
kuulsa	doc_491521502185_item	3677957	et	3	main
vanemuise	doc_491521502185_item	3677953	et	4	main
1869	doc_491521502185_item	3677951	et	2	main
toimumine	doc_491521502185_item	3677950	et	4	main
üldlaulupeo	doc_491521502185_item	3677949	et	4	main
ja	doc_491521502185_item	3677926	et	3	main
iseteadvust	doc_491521502185_item	3677925	et	4	main
rohkem	doc_491521501925_item	3677445	et	4	main
oleks	doc_491521501925_item	3677443	et	3	main
et	doc_491521501925_item	3677442	et	3	main
alati	doc_491521501925_item	3677441	et	4	main
tundub	doc_491521501925_item	3677440	et	3	main
siis	doc_491521501925_item	3677439	et	3	main
jätku	doc_491521501925_item	3677430	et	4	main
ida-virumaal	doc_491521501925_item	3677421	et	4	main
lemmikkoht	doc_491521501925_item	3677420	et	3	main
olla	doc_491521501925_item	3677412	et	3	main
puhkus	doc_491521501925_item	3677411	et	3	main
parim	doc_491521501925_item	3677410	et	4	main
jaoks	doc_491521501925_item	3677409	et	4	main
teie	doc_491521501925_item	3677408	et	4	main
on	doc_491521501925_item	3677407	et	4	main
mis	doc_491521501925_item	3677406	et	4	main
õigusteaduses	doc_491521501925_item	3677405	et	3	main
erialal	doc_491521501925_item	3677404	et	3	main
tahan	doc_491521501925_item	3677391	et	3	main
mida	doc_491521501925_item	3677387	et	4	main
peale	doc_491521501925_item	3677386	et	4	main
kommunaalkulude	doc_491521501925_item	3677385	et	3	main
raha	doc_491521501925_item	3677384	et	4	main
probleeme	doc_491521501925_item	3677377	et	3	main
käes	doc_491521501925_item	3677372	et	4	main
ainult	doc_491521501925_item	3677358	et	4	main
need	doc_491521501925_item	3677357	et	3	main
ole	doc_491521501925_item	3677356	et	4	main
raske	doc_491521501925_item	3677351	et	4	main
elada	doc_491521501925_item	3677350	et	3	main
hea	doc_491521501925_item	3677349	et	4	main
eestis	doc_491521501925_item	3677348	et	3	main
tänapäeva	doc_491521501925_item	3677347	et	4	main
on	doc_491521501925_item	3677346	et	4	main
kellel	doc_491521501925_item	3677345	et	4	main
saaks	doc_491521501925_item	3677344	et	3	main
puhtaks	doc_491521501925_item	3677343	et	3	main
ka	doc_491521501925_item	3677376	et	3	main
on	doc_491521501925_item	3677375	et	4	main
seda	doc_491521501925_item	3677373	et	3	main
olevad	doc_491521501925_item	3677363	et	4	main
võimu	doc_491521501925_item	3677361	et	4	main
praegune	doc_491521501925_item	3677336	et	3	main
ongi	doc_491521501925_item	3677333	et	4	main
ilmselt	doc_491521501925_item	3677332	et	4	main
teie	doc_491521501925_item	3677328	et	4	main
olnud	doc_491521501925_item	3677327	et	4	main
kokku	doc_491521501925_item	3677323	et	3	main
edaspidi	doc_491521501925_item	3677320	et	3	main
kuid	doc_491521501925_item	3677318	et	4	main
valetamine	doc_491521501925_item	3677305	et	4	main
teid	doc_491521501925_item	3677301	et	4	main
mis	doc_491521501925_item	3677300	et	4	main
mängisin	doc_634572338201_item	3677776	et	3	main
ka-	doc_634572338201_item	3677774	et	3	main
õppealajuhataja	doc_634572338201_item	3677770	et	4	main
minu	doc_634572338201_item	3677769	et	3	main
minu	doc_634572338201_item	3677760	et	3	main
mul	doc_634572338201_item	3677757	et	3	main
pragu	doc_634572338201_item	3677749	et	4	main
lihtsalt	doc_634572338201_item	3677706	et	4	main
kord	doc_634572338201_item	3677704	et	4	main
üks	doc_634572338201_item	3677703	et	3	main
loengust	doc_634572338201_item	3677702	et	4	main
puutusin	doc_634572338201_item	3677701	et	3	main
töötan	doc_634572338201_item	3677691	et	3	main
arvutile	doc_634572338201_item	3677687	et	4	main
video	doc_634572338201_item	3677685	et	4	main
mina	doc_634572338201_item	3677683	et	4	main
seda	doc_634572338201_item	3677682	et	3	main
pärast	doc_634572338201_item	3677681	et	4	main
kasetti	doc_634572338201_item	3677680	et	4	main
huvitanud	doc_634572338201_item	3677667	et	4	main
olin	doc_634572338201_item	3677666	et	3	main
alati	doc_634572338201_item	3677665	et	4	main
seotud	doc_634572338201_item	3677646	et	4	main
tihti	doc_634572338201_item	3677640	et	3	main
päeval	doc_634572338201_item	3677638	et	3	main
kolmapäev	doc_634572338201_item	3677635	et	3	main
oli	doc_634572338201_item	3677633	et	3	main
meil	doc_634572338201_item	3677632	et	4	main
loeng	doc_634572338201_item	3677631	et	3	main
oma	doc_491521502185_item	3678056	et	4	main
eest	doc_491521502185_item	3678050	et	4	main
selle	doc_491521502185_item	3678049	et	4	main
liikmed	doc_491521502185_item	3678048	et	3	main
üks	doc_491521502185_item	3678043	et	3	main
2	doc_491521502185_item	3678026	et	2	main
ja	doc_491521502185_item	3678022	et	3	main
1862	doc_491521502185_item	3678020	et	2	main
ilmus	doc_491521502185_item	3678019	et	4	main
oma	doc_491521502185_item	3677975	et	4	main
võitles	doc_491521502185_item	3677974	et	3	main
sakala	doc_491521502185_item	3677970	et	4	main
pids	doc_491521502185_item	3677955	et	4	main
a	doc_491521502185_item	3677952	et	4	main
tema	doc_491521502185_item	3677935	et	4	main
veel	doc_491521502185_item	3677932	et	4	main
lisada	doc_491521502185_item	3677931	et	3	main
võib	doc_491521502185_item	3677930	et	3	main
jannsenist	doc_491521502185_item	3677929	et	4	main
mis	doc_491521502185_item	3677922	et	4	main
al	doc_491521502185_item	3677915	et	4	main
tähtis	doc_491521502185_item	3677906	et	4	main
ikkagi	doc_491521502185_item	3677905	et	4	main
see	doc_491521502185_item	3677904	et	3	main
oli	doc_491521502185_item	3677903	et	3	main
see	doc_491521502185_item	3677898	et	3	main
ja	doc_491521502185_item	3677894	et	3	main
nõudmised	doc_491521502185_item	3677891	et	4	main
kontaktidest	doc_491521502185_item	3677862	et	3	main
grupp	doc_491521502185_item	3677856	et	3	main
peterburi	doc_491521502185_item	3677854	et	4	main
juhatamisel	doc_491521502185_item	3677852	et	4	main
kelle	doc_491521502185_item	3677851	et	4	main
ülipopulaarseks	doc_491521502185_item	3677847	et	4	main
postimees	doc_491521502185_item	3677842	et	4	main
hakkas	doc_491521502185_item	3677839	et	3	main
keeles	doc_609075653186_item	3678246	et	4	main
et	doc_491521501925_item	3677340	et	3	main
nimel	doc_491521501925_item	3677339	et	3	main
võitlus	doc_491521501925_item	3677337	et	3	main
minu	doc_491521501925_item	3677335	et	3	main
on	doc_491521501925_item	3677315	et	4	main
nad	doc_491521501925_item	3677314	et	3	main
et	doc_491521501925_item	3677313	et	3	main
küll	doc_491521501925_item	3677307	et	4	main
ees	doc_491521501925_item	3677299	et	4	main
ma	doc_491521501925_item	3677291	et	3	main
saavutuseks	doc_491521501925_item	3677290	et	4	main
õppisin	doc_634572338201_item	3677780	et	3	main
mina	doc_634572338201_item	3677775	et	4	main
nn	doc_634572338201_item	3677765	et	4	main
seal	doc_634572338201_item	3677763	et	4	main
endises	doc_634572338201_item	3677761	et	3	main
oli	doc_634572338201_item	3677758	et	3	main
põnev	doc_634572338201_item	3677746	et	3	main
te	doc_634572338201_item	3677719	et	4	main
kuidas	doc_634572338201_item	3677718	et	3	main
plaan	doc_634572338201_item	3677717	et	3	main
geniaalne	doc_634572338201_item	3677716	et	3	main
sündis	doc_634572338201_item	3677715	et	3	main
sõpradega	doc_634572338201_item	3677714	et	3	main
kuj	doc_634572338201_item	3677700	et	4	main
tegin	doc_634572338201_item	3677699	et	3	main
ja	doc_634572338201_item	3677688	et	3	main
kaheksa	doc_634572338201_item	3677785	et	4	main
juba	doc_634572338201_item	3677784	et	3	main
gitari	doc_634572338201_item	3677783	et	4	main
mängin	doc_634572338201_item	3677782	et	3	main
loengutest	doc_634572338201_item	3677805	et	4	main
puutusin	doc_634572338201_item	3677804	et	3	main
kui	doc_634572338201_item	3677803	et	3	main
tegin	doc_634572338201_item	3677802	et	3	main
ma	doc_634572338201_item	3677801	et	3	main
mida	doc_634572338201_item	3677800	et	4	main
sellest	doc_634572338201_item	3677799	et	4	main
jutustus	doc_634572338201_item	3677798	et	4	main
lõbus	doc_634572338201_item	3677797	et	4	main
ja	doc_634572338201_item	3677796	et	3	main
aus	doc_634572338201_item	3677795	et	4	main
minu	doc_634572338201_item	3677794	et	3	main
on	doc_634572338201_item	3677793	et	4	main
see	doc_634572338201_item	3677792	et	3	main
haridus	doc_634572338201_item	3677791	et	3	main
muusika	doc_634572338201_item	3677790	et	4	main
noorem	doc_634572338201_item	3677789	et	4	main
on	doc_634572338201_item	3677788	et	4	main
mul	doc_634572338201_item	3677787	et	3	main
aastat	doc_634572338201_item	3677786	et	3	main
koolis	doc_634572338201_item	3677778	et	4	main
mängida	doc_634572338201_item	3677773	et	3	main
kontsert	doc_634572338201_item	3677767	et	3	main
päev	doc_634572338201_item	3677747	et	3	main
lõbus	doc_634572338201_item	3677744	et	4	main
vaadata	doc_634572338201_item	3677742	et	4	main
neid	doc_634572338201_item	3677741	et	4	main
otsustaime	doc_634572338201_item	3677740	et	4	main
ja	doc_634572338201_item	3677739	et	3	main
ahvi	doc_634572338201_item	3677738	et	4	main
sugulasi-	doc_634572338201_item	3677737	et	2	main
meie	doc_634572338201_item	3677736	et	4	main
näinud	doc_634572338201_item	3677735	et	4	main
ei	doc_634572338201_item	3677734	et	4	main
ammu	doc_634572338201_item	3677733	et	4	main
juba	doc_634572338201_item	3677732	et	3	main
et	doc_634572338201_item	3677731	et	3	main
aru	doc_634572338201_item	3677730	et	4	main
me	doc_634572338201_item	3677728	et	4	main
saime	doc_634572338201_item	3677729	et	3	main
loomaaja	doc_634572338201_item	3677727	et	4	main
muidugi	doc_634572338201_item	3677726	et	4	main
üliõppilased	doc_634572338201_item	3677725	et	4	main
kahekümneaastased	doc_634572338201_item	3677724	et	4	main
tulla	doc_634572338201_item	3677723	et	3	main
võivad	doc_634572338201_item	3677722	et	4	main
meil	doc_634572338201_item	3677713	et	4	main
ja	doc_634572338201_item	3677712	et	3	main
septembris	doc_634572338201_item	3677711	et	3	main
oli	doc_634572338201_item	3677710	et	3	main
see	doc_634572338201_item	3677709	et	3	main
sellega	doc_634572338201_item	3677692	et	3	main
pärast	doc_634572338201_item	3677689	et	4	main
minu	doc_634572338201_item	3677686	et	3	main
mulle	doc_634572338201_item	3677679	et	4	main
video	doc_634572338201_item	3677674	et	4	main
mina	doc_634572338201_item	3677664	et	4	main
meeldib	doc_634572338201_item	3677663	et	3	main
vidio	doc_634572338201_item	3677651	et	4	main
tegelen	doc_634572338201_item	3677650	et	3	main
töö	doc_634572338201_item	3677644	et	4	main
minu	doc_634572338201_item	3677643	et	3	main
mina	doc_634572338201_item	3677639	et	4	main
ja	doc_634572338201_item	3677636	et	3	main
iga	doc_634572338201_item	3677634	et	4	main
võimalus	doc_491521502185_item	3678055	et	3	main
oleks	doc_491521502185_item	3678054	et	3	main
rahval	doc_491521502185_item	3678053	et	3	main
igal	doc_491521502185_item	3678052	et	3	main
et	doc_491521502185_item	3678051	et	3	main
harituimateist	doc_491521502185_item	3678044	et	4	main
sellele	doc_491521502185_item	3678039	et	4	main
iseteadvust	doc_491521502185_item	3678025	et	4	main
tõstis	doc_491521502185_item	3678023	et	4	main
a	doc_491521502185_item	3678021	et	4	main
suure	doc_491521502185_item	3678011	et	3	main
kogusid	doc_491521502185_item	3678010	et	4	main
mis	doc_491521502185_item	3677973	et	4	main
ajaleht	doc_491521502185_item	3677969	et	3	main
ilmus	doc_491521502185_item	3677967	et	4	main
algatusel	doc_491521502185_item	3677966	et	4	main
tema	doc_491521502185_item	3677965	et	4	main
üks	doc_491521502185_item	3677960	et	3	main
isamaakõne	doc_491521502185_item	3677959	et	4	main
esimese	doc_491521502185_item	3677958	et	3	main
algatusel	doc_491521502185_item	3677936	et	4	main
et	doc_491521502185_item	3677934	et	3	main
tõstis	doc_491521502185_item	3677923	et	4	main
a	doc_491521502185_item	3677917	et	4	main
kes	doc_491521502185_item	3677914	et	4	main
koidula	doc_491521502185_item	3677912	et	4	main
lydia	doc_491521502185_item	3677911	et	4	main
tütar	doc_491521502185_item	3677910	et	3	main
löögi	doc_491521502185_item	3677902	et	4	main
kuigi	doc_491521502185_item	3677897	et	3	main
teatavaks	doc_491521502185_item	3677870	et	4	main
keisrile	doc_491521502185_item	3677869	et	3	main
saatmine	doc_491521502185_item	3677867	et	4	main
palvekirjade	doc_491521502185_item	3677866	et	3	main
sai	doc_491521502185_item	3677864	et	4	main
j	doc_491521502185_item	3677860	et	4	main
patriootide	doc_491521502185_item	3677858	et	3	main
köler	doc_491521502185_item	3677850	et	4	main
mis	doc_491521502185_item	3677843	et	4	main
ja	doc_634572338201_item	3677677	et	3	main
operaator	doc_634572338201_item	3677675	et	3	main
töö	doc_634572338201_item	3677673	et	4	main
minu	doc_634572338201_item	3677672	et	3	main
koosneb	doc_634572338201_item	3677671	et	3	main
millest	doc_634572338201_item	3677670	et	3	main
mulle	doc_634572338201_item	3677662	et	4	main
töö	doc_634572338201_item	3677659	et	4	main
mina	doc_634572338201_item	3677649	et	4	main
filmidega	doc_634572338201_item	3677648	et	3	main
pidin	doc_634572338201_item	3677641	et	3	main
töötasin	doc_634572338201_item	3677630	et	3	main
mina	doc_634572338201_item	3677629	et	4	main
esmakordselt	doc_634572338201_item	3677628	et	4	main
loengul	doc_634572338201_item	3677627	et	3	main
puutusin	doc_634572338201_item	3677626	et	3	main
kui	doc_634572338201_item	3677625	et	3	main
tegin	doc_634572338201_item	3677624	et	3	main
ma	doc_634572338201_item	3677623	et	3	main
mida	doc_634572338201_item	3677622	et	4	main
küsimusele	doc_634572338201_item	3677621	et	4	main
vastus	doc_634572338201_item	3677620	et	3	main
filmistab	doc_634572338201_item	3677676	et	4	main
aga	doc_634572338201_item	3677660	et	3	main
ajal	doc_634572338201_item	3677657	et	4	main
samal	doc_634572338201_item	3677656	et	3	main
ja	doc_634572338201_item	3677655	et	3	main
huvitav	doc_634572338201_item	3677654	et	4	main
väga	doc_634572338201_item	3677653	et	3	main
montaziga	doc_634572338201_item	3677652	et	4	main
on	doc_634572338201_item	3677645	et	4	main
eesti	doc_491521502185_item	3678042	et	4	main
tänu	doc_491521502185_item	3678037	et	4	main
ilmselt	doc_491521502185_item	3678036	et	4	main
ja	doc_491521502185_item	3678031	et	3	main
eestlaste	doc_491521502185_item	3678024	et	4	main
ja	doc_491521502185_item	3678014	et	3	main
rahvaluulet	doc_491521502185_item	3678013	et	3	main
hulga	doc_491521502185_item	3678012	et	4	main
jakobson	doc_491521502185_item	3677964	et	4	main
tegelasi	doc_491521502185_item	3677963	et	3	main
oma	doc_491521502185_item	3677956	et	4	main
i	doc_491521502185_item	3677948	et	4	main
oli	doc_491521502185_item	3677947	et	3	main
tagajärjeks	doc_491521502185_item	3677946	et	3	main
mille	doc_491521502185_item	3677945	et	3	main
1865	doc_491521502185_item	3677943	et	2	main
vanemuine	doc_491521502185_item	3677942	et	4	main
mänguselts	doc_491521502185_item	3677941	et	3	main
ja	doc_491521502185_item	3677940	et	3	main
laulu-	doc_491521502185_item	3677939	et	4	main
asustatud	doc_491521502185_item	3677938	et	4	main
oli	doc_491521502185_item	3677937	et	3	main
seda	doc_491521502185_item	3677933	et	3	main
eestlaste	doc_491521502185_item	3677924	et	4	main
oma	doc_491521502185_item	3677919	et	4	main
kirjutas	doc_491521502185_item	3677918	et	3	main
ajaloos	doc_491521502185_item	3677908	et	4	main
sai	doc_491521502185_item	3677900	et	4	main
aladel	doc_491521502185_item	3677896	et	3	main
keele	doc_491521502185_item	3677892	et	4	main
teha	doc_491521502185_item	3677871	et	3	main
köleri	doc_491521502185_item	3677861	et	4	main
eeskätt	doc_491521502185_item	3677859	et	3	main
johan	doc_491521502185_item	3677849	et	4	main
aastaga	doc_491521502185_item	3677846	et	3	main
perno	doc_491521502185_item	3677841	et	4	main
teised	doc_609075653186_item	3678250	et	4	main
toimub	doc_609075653186_item	3678104	et	3	main
teada	doc_609075653186_item	3678098	et	3	main
silmaringi	doc_609075653186_item	3678096	et	4	main
tulevikus	doc_609075653186_item	3678239	et	4	main
õppetööd	doc_609075653186_item	3678232	et	4	main
ja	doc_609075653186_item	3678228	et	3	main
isikulised	doc_609075653186_item	3678226	et	4	main
kõrgkooli	doc_609075653186_item	3678213	et	4	main
enda	doc_609075653186_item	3678204	et	4	main
sa	doc_609075653186_item	3678203	et	3	main
ülesanded	doc_609075653186_item	3678202	et	3	main
missugused	doc_609075653186_item	3678201	et	3	main
eksamite	doc_609075653186_item	3678194	et	3	main
ruttada	doc_609075653186_item	3678176	et	2	main
vaja	doc_609075653186_item	3678175	et	4	main
oma	doc_609075653186_item	3678170	et	4	main
minna	doc_609075653186_item	3678169	et	3	main
et	doc_609075653186_item	3678167	et	3	main
püstitama	doc_609075653186_item	3678159	et	3	main
peab	doc_609075653186_item	3678158	et	4	main
õpilane	doc_609075653186_item	3678157	et	3	main
pealt	doc_609075653186_item	3678156	et	4	main
jaoks	doc_609075653186_item	3678153	et	4	main
paremate	doc_609075653186_item	3678145	et	4	main
kannatlikuse	doc_609075653186_item	3678127	et	4	main
kuidas	doc_609075653186_item	3678112	et	3	main
õpilaste	doc_609075653185_item	3678414	et	4	main
suhted	doc_609075653185_item	3678413	et	3	main
mis	doc_609075653185_item	3678409	et	4	main
kooliga	doc_609075653185_item	3678407	et	4	main
mitte	doc_609075653185_item	3678405	et	3	main
seotud	doc_609075653185_item	3678404	et	4	main
nad	doc_609075653185_item	3678403	et	3	main
ja	doc_609075653185_item	3678402	et	3	main
ülesandeid	doc_609075653185_item	3678401	et	3	main
ees	doc_491521502185_item	3678070	et	4	main
võrdsed	doc_491521502185_item	3678071	et	3	main
jumala	doc_491521502185_item	3678069	et	3	main
on	doc_491521502185_item	3678068	et	4	main
inimesed	doc_491521502185_item	3678067	et	3	main
kõik	doc_491521502185_item	3678066	et	4	main
väitsid	doc_491521502185_item	3678064	et	4	main
et	doc_491521502185_item	3678065	et	3	main
kes	doc_491521502185_item	3678063	et	4	main
need	doc_491521502185_item	3678062	et	3	main
ka	doc_491521502185_item	3678061	et	3	main
olid	doc_491521502185_item	3678060	et	4	main
nemad	doc_491521502185_item	3678059	et	3	main
luua	doc_491521502185_item	3678058	et	4	main
liikumise	doc_491521502185_item	3678047	et	4	main
oli	doc_491521502185_item	3678041	et	3	main
liikumisele	doc_491521502185_item	3678040	et	4	main
just	doc_491521502185_item	3678038	et	3	main
haaras	doc_491521502185_item	3678033	et	4	main
eestimaat	doc_491521502185_item	3678032	et	3	main
kogu	doc_491521502185_item	3678029	et	4	main
a	doc_491521502185_item	3678028	et	4	main
1730	doc_491521502185_item	3678027	et	2	main
koostasid	doc_491521502185_item	3678015	et	4	main
kes	doc_491521502185_item	3678009	et	4	main
kreutzwald	doc_491521502185_item	3678008	et	4	main
fr	doc_491521502185_item	3678007	et	4	main
ja	doc_491521502185_item	3678006	et	3	main
faehlmann	doc_491521502185_item	3678005	et	4	main
r	doc_491521502185_item	3678004	et	4	main
f	doc_491521502185_item	3678003	et	4	main
pooldaja	doc_491521502185_item	3678002	et	4	main
hariduse	doc_491521502185_item	3678001	et	3	main
eelkõige	doc_491521502185_item	3678000	et	3	main
moraali	doc_491521502185_item	3677999	et	4	main
eetilise	doc_491521502185_item	3677998	et	3	main
oli	doc_491521502185_item	3677997	et	3	main
kes	doc_491521502185_item	3677996	et	4	main
kes	doc_491521502185_item	3677995	et	4	main
hurti	doc_491521502185_item	3677994	et	4	main
jakob	doc_491521502185_item	3677993	et	4	main
ka	doc_491521502185_item	3677992	et	3	main
pidada	doc_491521502185_item	3677991	et	4	main
võib	doc_491521502185_item	3677990	et	3	main
juhiks	doc_491521502185_item	3677989	et	4	main
liikumise	doc_491521502185_item	3677988	et	4	main
rahvusliku	doc_491521502185_item	3677987	et	3	main
eesti	doc_491521502185_item	3677986	et	4	main
õigusi	doc_491521502185_item	3677985	et	4	main
võrdseid	doc_491521502185_item	3677984	et	3	main
eestlastele	doc_491521502185_item	3677983	et	4	main
nõudis	doc_491521502185_item	3677982	et	3	main
jakobson	doc_491521502185_item	3677981	et	4	main
robert	doc_491521502185_item	3677980	et	4	main
carl	doc_491521502185_item	3677979	et	4	main
eest	doc_491521502185_item	3677978	et	4	main
õiguste	doc_491521502185_item	3677977	et	4	main
rahva	doc_491521502185_item	3677976	et	3	main
a	doc_491521502185_item	3677972	et	4	main
liikumise	doc_491521502185_item	3677962	et	4	main
seltsis	doc_491521502185_item	3677954	et	4	main
a	doc_491521502185_item	3677944	et	4	main
võidelda	doc_491521502185_item	3677928	et	4	main
tahet	doc_491521502185_item	3677927	et	3	main
isamaalaule	doc_491521502185_item	3677921	et	4	main
esimesi	doc_491521502185_item	3677920	et	4	main
jannseni	doc_491521502185_item	3677909	et	4	main
tugeva	doc_491521502185_item	3677901	et	4	main
kiriku	doc_491521502185_item	3677895	et	3	main
lisandid	doc_491521502185_item	3677890	et	3	main
olid	doc_491521502185_item	3677889	et	4	main
poolt	doc_491521502185_item	3677888	et	4	main
jakobsoni	doc_491521502185_item	3677887	et	4	main
märt	doc_491521502185_item	3677886	et	4	main
ja	doc_491521502185_item	3677885	et	3	main
adamson	doc_491521502185_item	3677884	et	4	main
jaan	doc_491521502185_item	3677883	et	3	main
sisn	doc_491521502185_item	3677882	et	4	main
palvekirja	doc_491521502185_item	3677881	et	4	main
kirjutasid	doc_491521502185_item	3677880	et	4	main
petersonid	doc_491521502185_item	3677879	et	4	main
köler	doc_491521502185_item	3677877	et	4	main
vennad	doc_491521502185_item	3677878	et	3	main
j	doc_491521502185_item	3677876	et	4	main
salakoosolekul	doc_491521502185_item	3677875	et	3	main
olukorrast	doc_491521502185_item	3677874	et	4	main
raskest	doc_491521502185_item	3677873	et	3	main
rahva	doc_491521502185_item	3677872	et	3	main
1864	doc_491521502185_item	3677916	et	2	main
1843-1886	doc_491521502185_item	3677913	et	2	main
rahvaliikumise	doc_491521502185_item	3677907	et	3	main
liikus	doc_491521502185_item	3677899	et	3	main
hariduse	doc_491521502185_item	3677893	et	3	main
eesmärgiga	doc_491521502185_item	3677868	et	3	main
alguse	doc_491521502185_item	3677865	et	3	main
isamaaga	doc_491521502185_item	3677863	et	3	main
patriootide	doc_491521502185_item	3677855	et	3	main
ja	doc_609075653186_item	3678247	et	3	main
ja	doc_609075653186_item	3678103	et	3	main
mis	doc_609075653186_item	3678100	et	4	main
kõik	doc_609075653186_item	3678099	et	4	main
ja	doc_609075653186_item	3678097	et	3	main
kaasaaegses	doc_609075653186_item	3678089	et	3	main
haritud	doc_609075653186_item	3678088	et	4	main
olla	doc_609075653186_item	3678087	et	3	main
tahan	doc_609075653186_item	3678086	et	3	main
mõjutavad	doc_609075653186_item	3678230	et	4	main
probleemid	doc_609075653186_item	3678227	et	3	main
pean	doc_609075653186_item	3678208	et	4	main
ma	doc_609075653186_item	3678207	et	3	main
ja	doc_609075653186_item	3678196	et	3	main
on	doc_609075653186_item	3678192	et	4	main
peamised	doc_609075653186_item	3678190	et	3	main
õppe-eesmärgid	doc_609075653186_item	3678188	et	3	main
suur	doc_609075653186_item	3678181	et	3	main
olema	doc_609075653186_item	3678180	et	4	main
ole	doc_609075653186_item	3678174	et	4	main
jaoks	doc_609075653186_item	3678161	et	4	main
õppetöös	doc_609075653186_item	3678154	et	3	main
on	doc_609075653186_item	3678150	et	4	main
4	doc_609075653186_item	3678148	et	2	main
hulgas	doc_609075653186_item	3678147	et	4	main
kõike	doc_609075653186_item	3678144	et	4	main
kõrged	doc_609075653186_item	3678141	et	3	main
olid	doc_609075653186_item	3678140	et	4	main
hinned	doc_609075653186_item	3678139	et	4	main
hästi	doc_609075653186_item	3678138	et	3	main
väga	doc_609075653186_item	3678137	et	3	main
õppisin	doc_609075653186_item	3678136	et	3	main
ma	doc_609075653186_item	3678125	et	3	main
vaid	doc_609075653186_item	3678120	et	3	main
peterburi	doc_491521502185_item	3677857	et	4	main
tegutses	doc_491521502185_item	3677853	et	3	main
leheks	doc_491521502185_item	3677848	et	3	main
paari	doc_491521502185_item	3677845	et	4	main
sai	doc_491521502185_item	3677844	et	4	main
ilmuma	doc_491521502185_item	3677840	et	3	main
algatusel	doc_491521502185_item	3677838	et	4	main
1819-1890	doc_491521502185_item	3677836	et	2	main
kelle	doc_491521502185_item	3677837	et	4	main
jannsen	doc_491521502185_item	3677835	et	4	main
voldemar	doc_491521502185_item	3677834	et	4	main
johann	doc_491521502185_item	3677833	et	4	main
on	doc_491521502185_item	3677832	et	4	main
tegelased	doc_491521502185_item	3677831	et	3	main
ärkamisaja	doc_491521502185_item	3677830	et	3	main
rahvusliku	doc_491521502185_item	3677829	et	3	main
esimese	doc_491521502185_item	3677828	et	3	main
tähtsamad	doc_491521502185_item	3677827	et	4	main
1	doc_491521502185_item	3677826	et	2	main
edendamisse	doc_491521502185_item	3677825	et	4	main
eestlaste	doc_491521502185_item	3677823	et	4	main
hariduselu	doc_491521502185_item	3677824	et	4	main
panus	doc_491521502185_item	3677822	et	4	main
liikumise	doc_491521502185_item	3677821	et	4	main
vennastekoguduse	doc_491521502185_item	3677820	et	3	main
2	doc_491521502185_item	3677819	et	2	main
miks	doc_491521502185_item	3677818	et	4	main
meelest	doc_491521502185_item	3677817	et	4	main
sinu	doc_491521502185_item	3677816	et	3	main
tegelased	doc_491521502185_item	3677815	et	3	main
ärkamisaja	doc_491521502185_item	3677814	et	3	main
rahvusliku	doc_491521502185_item	3677813	et	3	main
esimese	doc_491521502185_item	3677812	et	3	main
tähtsamad	doc_491521502185_item	3677811	et	4	main
olid	doc_491521502185_item	3677810	et	4	main
kes	doc_491521502185_item	3677809	et	4	main
1	doc_491521502185_item	3677808	et	2	main
kontrolltöö	doc_491521502185_item	3677807	et	4	main
on	doc_609075653186_item	3678249	et	4	main
on	doc_609075653186_item	3678108	et	4	main
maailmas	doc_609075653186_item	3678106	et	3	main
toimus	doc_609075653186_item	3678101	et	3	main
laiendada	doc_609075653186_item	3678094	et	3	main
tahan	doc_609075653186_item	3678092	et	3	main
ma	doc_609075653186_item	3678091	et	3	main
maailmas	doc_609075653186_item	3678090	et	3	main
tulevikus	doc_609075653186_item	3678243	et	4	main
õppinguid	doc_609075653186_item	3678242	et	4	main
eksamid	doc_609075653186_item	3678248	et	3	main
tee	doc_609075653186_item	3678109	et	4	main
haridus	doc_609075653186_item	3678107	et	3	main
ma	doc_609075653186_item	3678085	et	3	main
sest	doc_609075653186_item	3678084	et	4	main
rohkem	doc_609075653186_item	3678093	et	4	main
õppida	doc_609075653186_item	3678083	et	3	main
tahan	doc_609075653186_item	3678082	et	3	main
mina	doc_609075653186_item	3678081	et	4	main
õppida	doc_609075653186_item	3678080	et	3	main
tahan	doc_609075653186_item	3678079	et	3	main
ma	doc_609075653186_item	3678078	et	3	main
miks	doc_609075653186_item	3678077	et	4	main
1	doc_609075653186_item	3678076	et	2	main
küsimusele	doc_609075653186_item	3678075	et	4	main
vastus	doc_609075653186_item	3678074	et	3	main
8	doc_609075653186_item	3678233	et	2	main
pere	doc_609075653186_item	3678229	et	4	main
tuju	doc_609075653186_item	3678225	et	4	main
õppetööd	doc_609075653186_item	3678224	et	4	main
sinu	doc_609075653186_item	3678223	et	3	main
mõjutab	doc_609075653186_item	3678222	et	3	main
mis	doc_609075653186_item	3678221	et	4	main
7	doc_609075653186_item	3678220	et	2	main
tööd	doc_609075653186_item	3678219	et	4	main
lemmikku	doc_609075653186_item	3678218	et	4	main
leidma	doc_609075653186_item	3678217	et	3	main
tulevikus	doc_609075653186_item	3678216	et	4	main
ja	doc_609075653186_item	3678215	et	3	main
sisse	doc_609075653186_item	3678214	et	4	main
astuma	doc_609075653186_item	3678212	et	3	main
praegu	doc_609075653186_item	3678105	et	3	main
varem	doc_609075653186_item	3678102	et	4	main
oma	doc_609075653186_item	3678095	et	4	main
eesti	doc_609075653186_item	3678245	et	4	main
raskem	doc_609075653186_item	3678244	et	4	main
ma	doc_609075653186_item	3678240	et	3	main
õppinguid	doc_609075653186_item	3678238	et	4	main
oma	doc_609075653186_item	3678237	et	4	main
näed	doc_609075653186_item	3678236	et	3	main
sa	doc_609075653186_item	3678235	et	3	main
kuidas	doc_609075653186_item	3678234	et	3	main
eksame	doc_609075653186_item	3678211	et	4	main
sooritama	doc_609075653186_item	3678210	et	3	main
edukalt	doc_609075653186_item	3678209	et	4	main
6	doc_609075653186_item	3678200	et	2	main
saamine	doc_609075653186_item	3678199	et	4	main
kõrghariduse	doc_609075653186_item	3678198	et	3	main
edasise	doc_609075653186_item	3678197	et	3	main
veel	doc_609075653186_item	3678177	et	4	main
eesmärgile	doc_609075653186_item	3678171	et	2	main
kannatlikus	doc_609075653186_item	3678166	et	2	main
peab	doc_609075653186_item	3678164	et	4	main
tal	doc_609075653186_item	3678163	et	3	main
eesmärgi	doc_609075653186_item	3678162	et	4	main
kõige	doc_609075653186_item	3678155	et	4	main
ma	doc_609075653186_item	3678142	et	3	main
varem	doc_609075653186_item	3678134	et	4	main
tunnen	doc_609075653186_item	3678126	et	3	main
natuke	doc_609075653186_item	3678123	et	4	main
tahaksin	doc_609075653186_item	3678121	et	3	main
2	doc_609075653186_item	3678111	et	2	main
7	doc_609075653185_item	3678408	et	2	main
ainul	doc_609075653185_item	3678406	et	4	main
palju	doc_609075653185_item	3678400	et	4	main
6	doc_609075653185_item	3678388	et	2	main
olema	doc_609075653185_item	3678386	et	4	main
peab	doc_609075653185_item	3678385	et	4	main
igaühel	doc_609075653185_item	3678384	et	3	main
mõtle	doc_609075653185_item	3678335	et	4	main
ei	doc_609075653185_item	3678334	et	4	main
tähtsaim	doc_609075653185_item	3678330	et	4	main
et	doc_609075653185_item	3678325	et	3	main
õppisid	doc_609075653185_item	3678314	et	4	main
varem	doc_609075653185_item	3678313	et	4	main
sa	doc_609075653185_item	3678312	et	3	main
kuidas	doc_609075653185_item	3678311	et	3	main
mulle	doc_609075653185_item	3678304	et	4	main
näiteks	doc_609075653185_item	3678303	et	4	main
probleemid	doc_609075653185_item	3678302	et	3	main
ka	doc_609075653185_item	3678301	et	3	main
õppin	doc_609075653185_item	3678293	et	4	main
ma	doc_609075653185_item	3678292	et	3	main
praegu	doc_609075653185_item	3678291	et	3	main
et	doc_609075653185_item	3678290	et	3	main
kaotas	doc_975151536919_item	3678511	et	3	main
puhul	doc_975151536919_item	3678509	et	4	main
aleksandri	doc_975151536919_item	3678507	et	4	main
saama	doc_975151536919_item	3678506	et	4	main
pidi	doc_975151536919_item	3678493	et	4	main
aleksandrikooli	doc_975151536919_item	3678488	et	4	main
sai	doc_975151536919_item	3678487	et	4	main
temast	doc_975151536919_item	3678486	et	3	main
ajalugu	doc_975151536919_item	3678479	et	4	main
on	doc_975151536919_item	3678473	et	4	main
rahvale	doc_975151536919_item	3678472	et	3	main
et	doc_975151536919_item	3678471	et	3	main
arvas	doc_975151536919_item	3678470	et	3	main
nende	doc_975151536919_item	3678462	et	4	main
oli	doc_975151536919_item	3678461	et	3	main
milline	doc_975151536919_item	3678460	et	3	main
ja	doc_975151536919_item	3678459	et	3	main
ei	doc_975151536919_item	3678591	et	4	main
ue	doc_975151536919_item	3678582	et	4	main
peterburgi	doc_975151536919_item	3678559	et	4	main
oli	doc_975151536919_item	3678557	et	3	main
tegutsevaid	doc_975151536919_item	3678549	et	4	main
oma	doc_975151536919_item	3678543	et	4	main
seotud	doc_975151536919_item	3678524	et	4	main
ainult	doc_975151536919_item	3678517	et	4	main
jäigi	doc_975151536919_item	3678516	et	4	main
näen	doc_609075653186_item	3678241	et	3	main
oma	doc_609075653186_item	3678231	et	4	main
jaoks	doc_609075653186_item	3678205	et	4	main
sooritamine	doc_609075653186_item	3678195	et	4	main
edukas	doc_609075653186_item	3678193	et	4	main
õppe-eesmärgid	doc_609075653186_item	3678191	et	3	main
minu	doc_609075653186_item	3678189	et	3	main
peamised	doc_609075653186_item	3678187	et	3	main
peab	doc_609075653186_item	3678179	et	4	main
muidugi	doc_609075653186_item	3678178	et	4	main
tal	doc_609075653186_item	3678172	et	3	main
järk-järgult	doc_609075653186_item	3678168	et	3	main
enda	doc_609075653186_item	3678160	et	4	main
õpilaste	doc_609075653186_item	3678146	et	4	main
ma	doc_609075653186_item	3678135	et	3	main
õppisid	doc_609075653186_item	3678133	et	4	main
varem	doc_609075653186_item	3678132	et	4	main
3	doc_609075653186_item	3678129	et	2	main
puudust	doc_609075653186_item	3678128	et	4	main
õppin	doc_609075653186_item	3678118	et	4	main
ma	doc_609075653186_item	3678117	et	3	main
praegu	doc_609075653186_item	3678116	et	3	main
ellu	doc_609075653186_item	3678110	et	4	main
mõjutab	doc_609075653185_item	3678410	et	3	main
on	doc_609075653185_item	3678399	et	4	main
mul	doc_609075653185_item	3678398	et	3	main
tea	doc_609075653185_item	3678397	et	4	main
ülikoolis	doc_609075653185_item	3678381	et	4	main
edasi	doc_609075653185_item	3678380	et	3	main
õppida	doc_609075653185_item	3678379	et	3	main
minna	doc_609075653185_item	3678378	et	3	main
ja	doc_609075653185_item	3678377	et	3	main
püstitasid	doc_609075653186_item	3678206	et	4	main
sinu	doc_609075653186_item	3678186	et	3	main
on	doc_609075653186_item	3678185	et	4	main
missugused	doc_609075653186_item	3678184	et	3	main
5	doc_609075653186_item	3678183	et	2	main
soov	doc_609075653186_item	3678182	et	3	main
ei	doc_609075653186_item	3678173	et	4	main
olema	doc_609075653186_item	3678165	et	4	main
sinu	doc_609075653186_item	3678152	et	3	main
peamine	doc_609075653186_item	3678151	et	3	main
mis	doc_609075653186_item	3678149	et	4	main
olin	doc_609075653186_item	3678143	et	3	main
sa	doc_609075653186_item	3678131	et	3	main
kuidas	doc_609075653186_item	3678130	et	3	main
parem	doc_609075653186_item	3678124	et	4	main
õppida	doc_609075653186_item	3678122	et	3	main
keskmiselt	doc_609075653186_item	3678119	et	4	main
praegu	doc_609075653186_item	3678115	et	3	main
õpid	doc_609075653186_item	3678114	et	4	main
sa	doc_609075653186_item	3678113	et	3	main
sinu	doc_609075653185_item	3678411	et	3	main
ei	doc_609075653185_item	3678396	et	4	main
ma	doc_609075653185_item	3678395	et	3	main
enda	doc_609075653185_item	3678392	et	4	main
sa	doc_609075653185_item	3678391	et	3	main
mis	doc_609075653185_item	3678338	et	4	main
nii	doc_609075653185_item	3678336	et	3	main
koolis	doc_609075653185_item	3678327	et	4	main
on	doc_609075653185_item	3678305	et	4	main
head	doc_609075653185_item	3678297	et	4	main
ülikoolis	doc_609075653185_item	3678434	et	4	main
tallinnas	doc_609075653185_item	3678433	et	4	main
õppisin	doc_609075653185_item	3678432	et	3	main
ma	doc_609075653185_item	3678431	et	3	main
et	doc_609075653185_item	3678430	et	3	main
näen	doc_609075653185_item	3678429	et	3	main
ma	doc_609075653185_item	3678428	et	3	main
tulevikus	doc_609075653185_item	3678427	et	4	main
õpinguid	doc_609075653185_item	3678426	et	3	main
oma	doc_609075653185_item	3678425	et	4	main
näed	doc_609075653185_item	3678424	et	3	main
sa	doc_609075653185_item	3678423	et	3	main
kuidas	doc_609075653185_item	3678422	et	3	main
8	doc_609075653185_item	3678421	et	2	main
õppetööd	doc_609075653185_item	3678420	et	4	main
minu	doc_609075653185_item	3678419	et	3	main
mõjutab	doc_609075653185_item	3678418	et	3	main
vahel	doc_609075653185_item	3678417	et	4	main
õpetajate	doc_609075653185_item	3678416	et	4	main
ja	doc_609075653185_item	3678415	et	3	main
õppetööd	doc_609075653185_item	3678412	et	4	main
jaoks	doc_609075653185_item	3678393	et	4	main
missugused	doc_609075653185_item	3678389	et	3	main
amet	doc_609075653185_item	3678387	et	3	main
kool	doc_609075653185_item	3678376	et	4	main
lõpetada	doc_609075653185_item	3678375	et	3	main
vaja	doc_609075653185_item	3678374	et	4	main
on	doc_609075653185_item	3678373	et	4	main
minule	doc_609075653185_item	3678372	et	3	main
et	doc_609075653185_item	3678371	et	3	main
arvan	doc_609075653185_item	3678370	et	3	main
õppe-eesmärgid	doc_609075653185_item	3678369	et	3	main
peamised	doc_609075653185_item	3678368	et	3	main
sinu	doc_609075653185_item	3678367	et	3	main
on	doc_609075653185_item	3678366	et	4	main
missugused	doc_609075653185_item	3678365	et	3	main
5	doc_609075653185_item	3678364	et	2	main
töötada	doc_609075653185_item	3678363	et	3	main
raske	doc_609075653185_item	3678362	et	4	main
on	doc_609075653185_item	3678361	et	4	main
müra	doc_609075653185_item	3678360	et	4	main
ja	doc_609075653185_item	3678359	et	3	main
kära	doc_609075653185_item	3678358	et	4	main
on	doc_609075653185_item	3678357	et	4	main
klassis	doc_609075653185_item	3678356	et	3	main
kui	doc_609075653185_item	3678355	et	3	main
sest	doc_609075653185_item	3678354	et	4	main
õppida	doc_609075653185_item	3678353	et	3	main
peab	doc_609075653185_item	3678351	et	4	main
tahama	doc_609075653185_item	3678352	et	4	main
igaüks	doc_609075653185_item	3678350	et	3	main
atmosfäär	doc_609075653185_item	3678349	et	3	main
soobiv	doc_609075653185_item	3678348	et	4	main
olema	doc_609075653185_item	3678347	et	4	main
peab	doc_609075653185_item	3678346	et	4	main
klassis	doc_609075653185_item	3678345	et	3	main
kõigepealt	doc_609075653185_item	3678344	et	3	main
õppetöös	doc_609075653185_item	3678343	et	3	main
jaoks	doc_609075653185_item	3678342	et	4	main
sinu	doc_609075653185_item	3678341	et	3	main
peamine	doc_609075653185_item	3678340	et	3	main
püstitasid	doc_609075653185_item	3678394	et	4	main
ülesanded	doc_609075653185_item	3678390	et	3	main
arvates	doc_609075653185_item	3678383	et	4	main
minu	doc_609075653185_item	3678382	et	3	main
nüüd	doc_609075653185_item	3678333	et	4	main
mõtlesin	doc_609075653185_item	3678324	et	3	main
parem	doc_609075653185_item	3678318	et	4	main
õppisin	doc_609075653185_item	3678317	et	3	main
ma	doc_609075653185_item	3678316	et	3	main
varem	doc_609075653185_item	3678315	et	4	main
on	doc_609075653185_item	3678296	et	4	main
mul	doc_609075653185_item	3678295	et	3	main
hästi	doc_609075653185_item	3678294	et	3	main
õppid	doc_609075653185_item	3678287	et	4	main
1816-1919	doc_975151536919_item	3678514	et	2	main
i	doc_975151536919_item	3678508	et	4	main
mis	doc_975151536919_item	3678492	et	4	main
suure	doc_975151536919_item	3678482	et	3	main
rahvavaimuvara	doc_975151536919_item	3678475	et	4	main
panus	doc_975151536919_item	3678463	et	4	main
elus	doc_975151536919_item	3678589	et	4	main
aga	doc_975151536919_item	3678588	et	3	main
peterburgi	doc_975151536919_item	3678587	et	4	main
jõudis	doc_975151536919_item	3678586	et	3	main
kiri	doc_975151536919_item	3678585	et	3	main
abiga	doc_975151536919_item	3678584	et	3	main
köleri	doc_975151536919_item	3678583	et	4	main
usundivabadus	doc_975151536919_item	3678580	et	4	main
selles	doc_975151536919_item	3678560	et	4	main
eestimaal	doc_975151536919_item	3678550	et	4	main
pärast	doc_975151536919_item	3678541	et	4	main
maalikunsti	doc_975151536919_item	3678539	et	4	main
õppinud	doc_975151536919_item	3678537	et	4	main
oli	doc_975151536919_item	3678536	et	3	main
kes	doc_975151536919_item	3678535	et	4	main
aga	doc_975151536919_item	3678526	et	3	main
kahjuks	doc_820667236801_item	3678815	et	4	main
m	doc_820667236801_item	3678806	et	4	main
reformide	doc_820667236801_item	3678789	et	3	main
et	doc_820667236801_item	3678786	et	3	main
võib	doc_820667236801_item	3678784	et	3	main
vaadates	doc_820667236801_item	3678783	et	3	main
rääkisid	doc_820667236801_item	3678773	et	4	main
teised	doc_820667236801_item	3678770	et	4	main
eesti	doc_820667236801_item	3678768	et	4	main
tähelepanu	doc_820667236801_item	3678759	et	4	main
suurt	doc_820667236801_item	3678758	et	3	main
lisada	doc_820667236801_item	3678745	et	3	main
arenema	doc_820667236801_item	3678740	et	3	main
meri	doc_820667236801_item	3678738	et	3	main
õnimõigused	doc_820667236801_item	3678733	et	4	main
kontroll	doc_820667236801_item	3678726	et	3	main
sai	doc_820667236801_item	3678721	et	4	main
ühiskondliku	doc_820667236801_item	3678712	et	3	main
oma	doc_820667236801_item	3678711	et	4	main
massiteabe	doc_820667236801_item	3678696	et	3	main
välismaale	doc_820667236801_item	3678692	et	4	main
sõitsid	doc_820667236801_item	3678691	et	4	main
eestlasi	doc_820667236801_item	3678690	et	3	main
helilooja	doc_820667236801_item	3678684	et	4	main
laulupidude	doc_820667236801_item	3678681	et	4	main
taastas	doc_820667236801_item	3678680	et	3	main
näiteks	doc_820667236801_item	3678654	et	4	main
kirjandus	doc_820667236801_item	3678649	et	3	main
eesti	doc_820667236801_item	3678648	et	4	main
kultuurielus	doc_820667236801_item	3678640	et	4	main
perioodil	doc_820667236801_item	3678639	et	3	main
sellel	doc_820667236801_item	3678638	et	4	main
enesetaastamiseks	doc_820667236801_item	3678637	et	3	main
aeg	doc_820667236801_item	3678632	et	3	main
periood	doc_820667236801_item	3678630	et	3	main
hrustshovi	doc_820667236801_item	3678628	et	4	main
aastad	doc_820667236801_item	3678626	et	3	main
nende	doc_820667236801_item	3678622	et	4	main
ja	doc_820667236801_item	3678621	et	3	main
kirjanikke	doc_820667236801_item	3678620	et	3	main
tuntumaid	doc_820667236801_item	3678619	et	4	main
taasiseseisvumist	doc_820667236801_item	3678614	et	3	main
saab	doc_640286507878_item	3679139	et	3	main
pool	doc_640286507878_item	3679129	et	4	main
igal	doc_640286507878_item	3679128	et	3	main
on	doc_609075653185_item	3678339	et	4	main
4	doc_609075653185_item	3678337	et	2	main
kõige	doc_609075653185_item	3678329	et	4	main
on	doc_609075653185_item	3678328	et	4	main
ma	doc_609075653185_item	3678323	et	3	main
varem	doc_609075653185_item	3678322	et	4	main
praegu	doc_609075653185_item	3678320	et	3	main
3	doc_609075653185_item	3678310	et	2	main
keelt	doc_609075653185_item	3678309	et	4	main
on	doc_609075653185_item	3678300	et	4	main
vaid	doc_609075653185_item	3678299	et	3	main
praegu	doc_609075653185_item	3678288	et	3	main
kuidas	doc_609075653185_item	3678285	et	3	main
aleksandrikool	doc_975151536919_item	3678515	et	4	main
kes	doc_975151536919_item	3678510	et	4	main
põhjal	doc_975151536919_item	3678497	et	4	main
aleksandrikool	doc_975151536919_item	3678490	et	4	main
liider	doc_975151536919_item	3678489	et	3	main
keeleteadlane	doc_975151536919_item	3678484	et	3	main
kultuurilukku	doc_975151536919_item	3678465	et	4	main
õppejõud	doc_975151536919_item	3678595	et	4	main
midagi	doc_975151536919_item	3678590	et	4	main
ja	doc_975151536919_item	3678581	et	3	main
maapindade	doc_975151536919_item	3678578	et	3	main
olid	doc_975151536919_item	3678577	et	4	main
kiri	doc_975151536919_item	3678558	et	3	main
isikuid	doc_975151536919_item	3678548	et	4	main
jättis	doc_975151536919_item	3678542	et	3	main
köler	doc_975151536919_item	3678534	et	4	main
on	doc_975151536919_item	3678533	et	4	main
nimedest	doc_975151536919_item	3678532	et	3	main
sellistest	doc_975151536919_item	3678531	et	4	main
üks	doc_975151536919_item	3678530	et	3	main
eestimaalt	doc_975151536919_item	3678529	et	3	main
pärit	doc_975151536919_item	3678528	et	3	main
polnud	doc_975151536919_item	3678527	et	3	main
olid	doc_975151536919_item	3678523	et	4	main
inimesed	doc_975151536919_item	3678521	et	3	main
2	doc_975151536919_item	3678519	et	2	main
ideeks	doc_975151536919_item	3678518	et	3	main
teoseid	doc_820667236801_item	3678813	et	3	main
tema	doc_820667236801_item	3678811	et	4	main
arvo	doc_820667236801_item	3678808	et	4	main
hint	doc_820667236801_item	3678807	et	4	main
kohaneda	doc_820667236801_item	3678799	et	3	main
raske	doc_820667236801_item	3678798	et	4	main
oli	doc_820667236801_item	3678797	et	3	main
reformidega	doc_820667236801_item	3678796	et	3	main
languse	doc_820667236801_item	3678795	et	3	main
algus	doc_820667236801_item	3678790	et	4	main
teisest	doc_820667236801_item	3678781	et	4	main
tagastada	doc_820667236801_item	3678777	et	3	main
sellega	doc_820667236801_item	3678766	et	3	main
seotud	doc_820667236801_item	3678765	et	4	main
on	doc_820667236801_item	3678764	et	4	main
poolest	doc_820667236801_item	3678762	et	4	main
riikide	doc_820667236801_item	3678761	et	3	main
teiste	doc_820667236801_item	3678760	et	4	main
balti	doc_820667236801_item	3678751	et	3	main
sündmustest	doc_820667236801_item	3678750	et	4	main
taasiseseisvumisperioodi	doc_820667236801_item	3678749	et	4	main
ma	doc_820667236801_item	3678743	et	3	main
kultuuri	doc_820667236801_item	3678741	et	4	main
hakkasid	doc_820667236801_item	3678739	et	4	main
presidendiks	doc_820667236801_item	3678735	et	4	main
hakkasid	doc_820667236801_item	3678728	et	4	main
kirjandusele	doc_820667236801_item	3678727	et	3	main
uueneti	doc_820667236801_item	3678723	et	3	main
poliitilis	doc_820667236801_item	3678713	et	4	main
taasiseseisvumist	doc_820667236801_item	3678702	et	3	main
osakaal	doc_820667236801_item	3678697	et	3	main
suurenes	doc_820667236801_item	3678695	et	4	main
palju	doc_820667236801_item	3678689	et	4	main
1970	doc_820667236801_item	3678688	et	2	main
sotsioloogia	doc_820667236801_item	3678678	et	4	main
ilmus	doc_820667236801_item	3678670	et	4	main
psühholoogilise	doc_820667236801_item	3678643	et	4	main
võimalust	doc_820667236801_item	3678635	et	3	main
on	doc_820667236801_item	3678627	et	4	main
1	doc_820667236801_item	3678624	et	2	main
kaasaegseid	doc_820667236801_item	3678617	et	3	main
aga	doc_609075653185_item	3678332	et	3	main
aine	doc_609075653185_item	3678331	et	4	main
õppida	doc_609075653185_item	3678326	et	3	main
sest	doc_609075653185_item	3678321	et	4	main
kui	doc_609075653185_item	3678319	et	3	main
eesti	doc_609075653185_item	3678308	et	4	main
õppida	doc_609075653185_item	3678307	et	3	main
raske	doc_609075653185_item	3678306	et	4	main
hinned	doc_609075653185_item	3678298	et	4	main
arvan	doc_609075653185_item	3678289	et	3	main
sa	doc_609075653185_item	3678286	et	3	main
2	doc_609075653185_item	3678284	et	2	main
lõpetamist	doc_609075653185_item	3678283	et	4	main
kooli	doc_609075653185_item	3678282	et	4	main
pärast	doc_609075653185_item	3678281	et	4	main
töö	doc_609075653185_item	3678280	et	4	main
leida	doc_609075653185_item	3678279	et	3	main
aitab	doc_609075653185_item	3678278	et	3	main
see	doc_609075653185_item	3678277	et	3	main
veel	doc_609075653185_item	3678276	et	4	main
tulevikus	doc_609075653185_item	3678275	et	4	main
võimalusi	doc_609075653185_item	3678274	et	3	main
palju	doc_609075653185_item	3678273	et	4	main
meile	doc_609075653185_item	3678272	et	4	main
annab	doc_609075653185_item	3678271	et	3	main
õppimine	doc_609075653185_item	3678270	et	4	main
inimeste	doc_609075653185_item	3678268	et	3	main
eest	doc_609075653185_item	3678269	et	4	main
iga	doc_609075653185_item	3678267	et	4	main
vajalik	doc_609075653185_item	3678266	et	3	main
on	doc_609075653185_item	3678265	et	4	main
see	doc_609075653185_item	3678264	et	3	main
sest	doc_609075653185_item	3678263	et	4	main
õppida	doc_609075653185_item	3678262	et	3	main
tahan	doc_609075653185_item	3678261	et	3	main
ma	doc_609075653185_item	3678260	et	3	main
õppida	doc_609075653185_item	3678259	et	3	main
tahan	doc_609075653185_item	3678258	et	3	main
ma	doc_609075653185_item	3678257	et	3	main
miks	doc_609075653185_item	3678256	et	4	main
1	doc_609075653185_item	3678255	et	2	main
küsimusele	doc_609075653185_item	3678254	et	4	main
vastus	doc_609075653185_item	3678253	et	3	main
eestimaal	doc_975151536919_item	3678512	et	4	main
pidi	doc_975151536919_item	3678505	et	4	main
annuste	doc_975151536919_item	3678496	et	3	main
rahva	doc_975151536919_item	3678495	et	3	main
eksisteerima	doc_975151536919_item	3678494	et	4	main
nimega	doc_975151536919_item	3678483	et	3	main
oli	doc_975151536919_item	3678481	et	3	main
välismaalt	doc_975151536919_item	3678596	et	3	main
pärisorjuse	doc_975151536919_item	3678513	et	3	main
aleksandrinimetuse	doc_975151536919_item	3678504	et	4	main
keeles	doc_975151536919_item	3678503	et	4	main
eesti	doc_975151536919_item	3678502	et	4	main
toimuma	doc_975151536919_item	3678501	et	3	main
pidi	doc_975151536919_item	3678500	et	4	main
õppimisprotsess	doc_975151536919_item	3678499	et	3	main
kus	doc_975151536919_item	3678498	et	3	main
õppeasutus	doc_975151536919_item	3678491	et	4	main
pärast	doc_975151536919_item	3678485	et	4	main
ta	doc_975151536919_item	3678480	et	4	main
rahva	doc_975151536919_item	3678478	et	3	main
ja	doc_975151536919_item	3678477	et	3	main
rahvaluule	doc_975151536919_item	3678476	et	4	main
tähtis	doc_975151536919_item	3678474	et	4	main
1839-1907	doc_975151536919_item	3678469	et	2	main
hurt	doc_975151536919_item	3678468	et	3	main
jakob	doc_975151536919_item	3678467	et	4	main
1	doc_975151536919_item	3678466	et	2	main
estofiilid	doc_975151536919_item	3678458	et	3	main
olid	doc_975151536919_item	3678457	et	4	main
kes	doc_975151536919_item	3678456	et	4	main
2	doc_975151536919_item	3678455	et	2	main
teate	doc_975151536919_item	3678454	et	4	main
tegevusest	doc_975151536919_item	3678453	et	4	main
tema	doc_975151536919_item	3678452	et	4	main
te	doc_975151536919_item	3678451	et	4	main
mida	doc_975151536919_item	3678450	et	4	main
peal	doc_975151536919_item	3678449	et	4	main
rahatähe	doc_975151536919_item	3678448	et	3	main
10-kroonise	doc_975151536919_item	3678447	et	4	main
eesti	doc_975151536919_item	3678446	et	4	main
kujutatud	doc_975151536919_item	3678445	et	4	main
on	doc_975151536919_item	3678444	et	4	main
kultuuritegelane	doc_975151536919_item	3678443	et	3	main
ärkamisaja	doc_975151536919_item	3678442	et	3	main
milline	doc_975151536919_item	3678441	et	3	main
1	doc_975151536919_item	3678440	et	2	main
kultuuriloost	doc_975151536919_item	3678439	et	4	main
eesti	doc_975151536919_item	3678438	et	4	main
kontrolltöö	doc_975151536919_item	3678437	et	4	main
kontrolltöö	doc_975151536919_item	3678436	et	4	main
tegutsesid	doc_975151536919_item	3678594	et	4	main
nende	doc_975151536919_item	3678554	et	4	main
palju	doc_975151536919_item	3678553	et	4	main
sellised	doc_975151536919_item	3678547	et	4	main
eestis	doc_975151536919_item	3678546	et	3	main
jälje	doc_975151536919_item	3678545	et	3	main
kunsti	doc_975151536919_item	3678544	et	4	main
mäleta	doc_820667236801_item	3678817	et	4	main
ja	doc_820667236801_item	3678810	et	3	main
valton	doc_820667236801_item	3678809	et	4	main
kross	doc_820667236801_item	3678803	et	3	main
jaan	doc_820667236801_item	3678802	et	3	main
näiteks	doc_820667236801_item	3678801	et	4	main
3	doc_820667236801_item	3678800	et	2	main
ja	doc_820667236801_item	3678788	et	3	main
uuenduste	doc_820667236801_item	3678787	et	4	main
eesti	doc_975151536919_item	3678464	et	4	main
eestis	doc_975151536919_item	3678593	et	3	main
muutunud	doc_975151536919_item	3678592	et	4	main
väljaostmisõigused	doc_975151536919_item	3678579	et	4	main
nõudmised	doc_975151536919_item	3678576	et	4	main
võimu	doc_975151536919_item	3678575	et	4	main
sakslaste	doc_975151536919_item	3678574	et	3	main
releerima	doc_975151536919_item	3678573	et	4	main
pidid	doc_975151536919_item	3678572	et	4	main
lootes	doc_975151536919_item	3678571	et	4	main
nende	doc_975151536919_item	3678570	et	4	main
mis	doc_975151536919_item	3678569	et	4	main
nõudmised	doc_975151536919_item	3678568	et	4	main
muud	doc_975151536919_item	3678567	et	4	main
ja	doc_975151536919_item	3678566	et	3	main
majanduslikud	doc_975151536919_item	3678565	et	3	main
kõik	doc_975151536919_item	3678564	et	4	main
kirjutatud	doc_975151536919_item	3678563	et	4	main
olid	doc_975151536919_item	3678562	et	4	main
kirjas	doc_975151536919_item	3678561	et	4	main
pannus	doc_975151536919_item	3678556	et	4	main
suurim	doc_975151536919_item	3678555	et	3	main
päris	doc_975151536919_item	3678552	et	4	main
oli	doc_975151536919_item	3678551	et	3	main
ja	doc_975151536919_item	3678540	et	3	main
peterburis	doc_975151536919_item	3678538	et	4	main
eestiga	doc_975151536919_item	3678525	et	4	main
kes	doc_975151536919_item	3678522	et	4	main
estofiilid	doc_975151536919_item	3678520	et	3	main
ei	doc_820667236801_item	3678816	et	4	main
romaanid	doc_820667236801_item	3678812	et	3	main
l	doc_820667236801_item	3678804	et	4	main
tõi	doc_820667236801_item	3678791	et	3	main
aga	doc_820667236801_item	3678780	et	3	main
püües	doc_820667236801_item	3678776	et	3	main
riigid	doc_820667236801_item	3678772	et	3	main
balti	doc_820667236801_item	3678771	et	3	main
ja	doc_820667236801_item	3678769	et	3	main
muidugi	doc_820667236801_item	3678753	et	4	main
riikidele	doc_820667236801_item	3678752	et	3	main
tahaksin	doc_820667236801_item	3678744	et	3	main
lennart	doc_820667236801_item	3678737	et	4	main
sai	doc_820667236801_item	3678736	et	4	main
uueks	doc_820667236801_item	3678734	et	3	main
välja	doc_820667236801_item	3678732	et	4	main
töötati	doc_820667236801_item	3678731	et	4	main
poolitikaelu	doc_820667236801_item	3678730	et	4	main
taastama	doc_820667236801_item	3678729	et	3	main
haridussüsteemi	doc_820667236801_item	3678724	et	4	main
avatuks	doc_820667236801_item	3678722	et	4	main
elu	doc_820667236801_item	3678720	et	4	main
ühiskondlik	doc_820667236801_item	3678719	et	3	main
et	doc_820667236801_item	3678718	et	3	main
arvan	doc_820667236801_item	3678717	et	3	main
ma	doc_820667236801_item	3678716	et	3	main
taastada	doc_820667236801_item	3678715	et	3	main
süsteemi	doc_820667236801_item	3678714	et	4	main
mina	doc_820667236801_item	3678814	et	4	main
promet	doc_820667236801_item	3678805	et	4	main
elatutaseme	doc_820667236801_item	3678794	et	4	main
eestile	doc_820667236801_item	3678793	et	3	main
kaasa	doc_820667236801_item	3678792	et	4	main
iseseisvust	doc_820667236801_item	3678779	et	4	main
endale	doc_820667236801_item	3678778	et	4	main
sõna	doc_820667236801_item	3678775	et	4	main
et	doc_820667236801_item	3678767	et	3	main
pärast	doc_820667236801_item	3678748	et	4	main
üldse	doc_820667236801_item	3678747	et	3	main
et	doc_820667236801_item	3678746	et	3	main
vähenes	doc_820667236801_item	3678725	et	3	main
raske	doc_820667236801_item	3678706	et	4	main
oli	doc_820667236801_item	3678705	et	3	main
pärast	doc_820667236801_item	3678701	et	4	main
üldises	doc_820667236801_item	3678698	et	3	main
sellel	doc_820667236801_item	3678693	et	4	main
gustav	doc_820667236801_item	3678685	et	4	main
traitsioon	doc_820667236801_item	3678682	et	4	main
küberneetika	doc_820667236801_item	3678679	et	4	main
kontakteerida	doc_820667236801_item	3678672	et	4	main
võimalus	doc_820667236801_item	3678671	et	3	main
taastamine	doc_820667236801_item	3678645	et	4	main
teatri	doc_820667236801_item	3678644	et	3	main
osaliseks	doc_820667236801_item	3678636	et	4	main
eesti	doc_820667236801_item	3678618	et	4	main
pärast	doc_820667236801_item	3678613	et	4	main
eestis	doc_820667236801_item	3678612	et	3	main
toimusid	doc_820667236801_item	3678611	et	4	main
muutused	doc_820667236801_item	3678610	et	4	main
ühiskondlik-poliitilised	doc_820667236801_item	3678609	et	3	main
missugused	doc_820667236801_item	3678608	et	3	main
2	doc_820667236801_item	3678607	et	2	main
aastattel	doc_820667236801_item	3678606	et	4	main
19601970ndatel	doc_820667236801_item	3678605	et	4	main
kultuuritarbimist	doc_820667236801_item	3678604	et	3	main
eestlaste	doc_820667236801_item	3678603	et	4	main
iseloomustavad	doc_820667236801_item	3678602	et	4	main
tunnused	doc_820667236801_item	3678601	et	3	main
millised	doc_820667236801_item	3678600	et	3	main
1	doc_820667236801_item	3678599	et	2	main
kontrolltöö	doc_820667236801_item	3678598	et	4	main
pöörama	doc_820667236801_item	3678757	et	3	main
hakati	doc_820667236801_item	3678756	et	3	main
ka	doc_820667236801_item	3678755	et	3	main
eestile	doc_820667236801_item	3678754	et	3	main
tulevik	doc_640286507878_item	3679138	et	3	main
kord	doc_640286507878_item	3679134	et	4	main
old	doc_640286507878_item	3679117	et	4	main
kirjandus	doc_640286507878_item	3679109	et	3	main
ii	doc_640286507878_item	3679095	et	4	main
muutusid	doc_640286507878_item	3679087	et	4	main
hakati	doc_640286507878_item	3679020	et	3	main
pleeniumi	doc_640286507878_item	3679017	et	4	main
kahjuks	doc_640286507878_item	3679014	et	4	main
saavutus	doc_640286507878_item	3679013	et	4	main
õpilastest	doc_640286507878_item	3678991	et	4	main
oli	doc_640286507878_item	3678988	et	3	main
ka	doc_640286507878_item	3678986	et	3	main
hävitatud	doc_640286507878_item	3678961	et	4	main
üldse	doc_640286507878_item	3678960	et	3	main
ja	doc_640286507878_item	3678959	et	3	main
välja	doc_640286507878_item	3678954	et	4	main
ütelda	doc_820667236801_item	3678785	et	4	main
küljest	doc_820667236801_item	3678782	et	4	main
oma	doc_820667236801_item	3678774	et	4	main
see	doc_820667236801_item	3678763	et	3	main
organisatsioonid	doc_820667236801_item	3678742	et	3	main
ta	doc_820667236801_item	3678710	et	4	main
pidi	doc_820667236801_item	3678709	et	4	main
millal	doc_820667236801_item	3678708	et	3	main
aeg	doc_820667236801_item	3678707	et	3	main
eesti	doc_820667236801_item	3678703	et	4	main
kultuuritarbimises	doc_820667236801_item	3678699	et	3	main
perioodil	doc_820667236801_item	3678694	et	3	main
psühholoogia	doc_820667236801_item	3678677	et	4	main
pegelased	doc_820667236801_item	3678651	et	4	main
jalale	doc_820667236801_item	3678647	et	3	main
tõusis	doc_820667236801_item	3678646	et	4	main
andis	doc_820667236801_item	3678633	et	3	main
see	doc_820667236801_item	3678631	et	3	main
nimetage	doc_820667236801_item	3678616	et	3	main
helde	doc_640286507878_item	3679141	et	4	main
siis	doc_640286507878_item	3679136	et	3	main
peab	doc_640286507878_item	3679127	et	4	main
elus	doc_640286507878_item	3679126	et	4	main
et	doc_640286507878_item	3679125	et	3	main
võib	doc_640286507878_item	3679104	et	3	main
nõukogude	doc_640286507878_item	3679101	et	3	main
lõpus	doc_640286507878_item	3679098	et	4	main
1940-ndate	doc_640286507878_item	3679096	et	4	main
trasitsioonid	doc_640286507878_item	3679090	et	4	main
ilmalikud	doc_640286507878_item	3679089	et	3	main
uued	doc_640286507878_item	3679088	et	3	main
likvideeruma	doc_640286507878_item	3679021	et	3	main
17	doc_640286507878_item	3678990	et	2	main
haridus	doc_640286507878_item	3678985	et	3	main
meelelahutuseks	doc_640286507878_item	3678981	et	4	main
lugeda	doc_640286507878_item	3678978	et	3	main
meeldis	doc_640286507878_item	3678977	et	3	main
keelatud	doc_640286507878_item	3678958	et	4	main
olid	doc_640286507878_item	3678957	et	4	main
massiline	doc_640286507878_item	3678944	et	4	main
seltse	doc_640286507878_item	3678933	et	3	main
voole	doc_640286507878_item	3678932	et	4	main
erinevaid	doc_640286507878_item	3678931	et	4	main
situatsiooni	doc_640286507878_item	3678920	et	4	main
seda	doc_640286507878_item	3678919	et	3	main
kultuurielu	doc_640286507878_item	3678881	et	4	main
maanaisteselts	doc_640286507878_item	3678869	et	3	main
ev	doc_640286507878_item	3678855	et	4	main
kultuurielus	doc_640286507878_item	3678854	et	4	main
toimus	doc_640286507878_item	3678853	et	3	main
tähtsat	doc_640286507878_item	3678852	et	3	main
kui	doc_640286507878_item	3678831	et	3	main
tähtsamaks	doc_640286507878_item	3679086	et	4	main
kiriku	doc_640286507878_item	3679078	et	3	main
õigus	doc_640286507878_item	3679065	et	4	main
oli	doc_640286507878_item	3679064	et	3	main
inimestel	doc_640286507878_item	3679063	et	3	main
veel	doc_640286507878_item	3679060	et	4	main
jaoks	doc_820667236801_item	3678704	et	4	main
2	doc_820667236801_item	3678700	et	2	main
1960	doc_820667236801_item	3678687	et	2	main
ernesaks	doc_820667236801_item	3678686	et	4	main
tuntuim	doc_820667236801_item	3678683	et	4	main
said	doc_820667236801_item	3678676	et	4	main
tegevusaladeks	doc_820667236801_item	3678675	et	3	main
moodsateks	doc_820667236801_item	3678674	et	3	main
väliseestlastega	doc_820667236801_item	3678673	et	4	main
avatus	doc_820667236801_item	3678669	et	4	main
elu	doc_820667236801_item	3678668	et	4	main
ühiskondliku	doc_820667236801_item	3678667	et	3	main
laienes	doc_820667236801_item	3678666	et	3	main
aeg	doc_820667236801_item	3678665	et	3	main
ümberorienteerumise	doc_820667236801_item	3678664	et	3	main
kultuuril	doc_820667236801_item	3678663	et	3	main
oli	doc_820667236801_item	3678662	et	3	main
aastatel	doc_820667236801_item	3678661	et	4	main
1960	doc_820667236801_item	3678660	et	2	main
under	doc_820667236801_item	3678659	et	4	main
marie	doc_820667236801_item	3678658	et	4	main
ja	doc_820667236801_item	3678657	et	3	main
ristikivi	doc_820667236801_item	3678656	et	4	main
karl	doc_820667236801_item	3678655	et	4	main
ja	doc_820667236801_item	3678652	et	3	main
kirjanikud	doc_820667236801_item	3678653	et	3	main
tuntumaid	doc_820667236801_item	3678650	et	4	main
hea	doc_820667236801_item	3678642	et	4	main
toimus	doc_820667236801_item	3678641	et	3	main
eestile	doc_820667236801_item	3678634	et	3	main
sulaaja	doc_820667236801_item	3678629	et	3	main
1960-1970	doc_820667236801_item	3678625	et	2	main
teoseid	doc_820667236801_item	3678623	et	3	main
3	doc_820667236801_item	3678615	et	2	main
olla	doc_640286507878_item	3679140	et	3	main
keelatud	doc_640286507878_item	3679150	et	4	main
tsensuuriga	doc_640286507878_item	3679149	et	3	main
olid	doc_640286507878_item	3679148	et	4	main
teised	doc_640286507878_item	3679147	et	4	main
lugeda	doc_640286507878_item	3679146	et	3	main
lubatud	doc_640286507878_item	3679145	et	4	main
oli	doc_640286507878_item	3679144	et	3	main
raamatud	doc_640286507878_item	3679143	et	4	main
inimeste	doc_640286507878_item	3679137	et	3	main
sotsialostlik	doc_640286507878_item	3679132	et	4	main
kord	doc_640286507878_item	3679131	et	4	main
ramatud	doc_640286507878_item	3679119	et	4	main
need	doc_640286507878_item	3679118	et	3	main
täis	doc_640286507878_item	3679115	et	4	main
sotsiolismi	doc_640286507878_item	3679113	et	4	main
ajal	doc_640286507878_item	3679112	et	4	main
arendada	doc_640286507878_item	3679105	et	3	main
sotsialistlik	doc_640286507878_item	3679102	et	3	main
et	doc_640286507878_item	3679100	et	3	main
sünnipäeva	doc_640286507878_item	3679093	et	4	main
häivitatakse	doc_640286507878_item	3679025	et	4	main
instituute	doc_640286507878_item	3679024	et	3	main
ja	doc_640286507878_item	3679023	et	3	main
kõrgkoole	doc_640286507878_item	3679022	et	4	main
1950	doc_640286507878_item	3679018	et	2	main
jaoks	doc_640286507878_item	3679011	et	4	main
ev	doc_640286507878_item	3679010	et	4	main
oli	doc_640286507878_item	3679009	et	3	main
see	doc_640286507878_item	3679008	et	3	main
keeles	doc_640286507878_item	3679007	et	4	main
eesti	doc_640286507878_item	3679006	et	4	main
loenguid	doc_640286507878_item	3679005	et	4	main
peeti	doc_640286507878_item	3679004	et	4	main
kõrgkoolis	doc_640286507878_item	3679003	et	4	main
kunsti	doc_640286507878_item	3679002	et	4	main
ülikoolis	doc_640286507878_item	3679001	et	4	main
tartu	doc_640286507878_item	3679000	et	4	main
kõrgkoolides	doc_640286507878_item	3678999	et	3	main
haridus	doc_640286507878_item	3678998	et	3	main
emakeelne	doc_640286507878_item	3678997	et	3	main
arenes	doc_640286507878_item	3678996	et	3	main
aktiivselt	doc_640286507878_item	3678995	et	4	main
kõrgkoolides	doc_640286507878_item	3678994	et	3	main
õpingut	doc_640286507878_item	3678993	et	3	main
jätkasid	doc_640286507878_item	3678992	et	4	main
õppida	doc_640286507878_item	3678984	et	3	main
ajal	doc_640286507878_item	3678967	et	4	main
mehilas	doc_640286507878_item	3678950	et	4	main
k	doc_640286507878_item	3678949	et	4	main
hakkas	doc_640286507878_item	3678943	et	3	main
selts	doc_640286507878_item	3678942	et	3	main
rahvaluule	doc_640286507878_item	3678941	et	4	main
akadeemiline	doc_640286507878_item	3678940	et	3	main
selts	doc_640286507878_item	3678939	et	3	main
eesti	doc_640286507878_item	3678938	et	4	main
keelati	doc_640286507878_item	3678930	et	4	main
teistsugune	doc_640286507878_item	3678929	et	3	main
üldse	doc_640286507878_item	3678928	et	3	main
oli	doc_640286507878_item	3678927	et	3	main
pilt	doc_640286507878_item	3678926	et	3	main
et	doc_640286507878_item	3678925	et	3	main
parastsõjajärgse	doc_640286507878_item	3678921	et	4	main
kirjanikud	doc_640286507878_item	3678891	et	3	main
kulus	doc_640286507878_item	3678886	et	4	main
finantseeris	doc_640286507878_item	3678884	et	3	main
tuletõrjeselts	doc_640286507878_item	3678866	et	3	main
kaitseliit	doc_640286507878_item	3678865	et	3	main
ajal	doc_640286507878_item	3678856	et	4	main
need	doc_640286507878_item	3679142	et	3	main
ainult	doc_640286507878_item	3679135	et	4	main
range	doc_640286507878_item	3679133	et	4	main
olema	doc_640286507878_item	3679130	et	4	main
sellest	doc_640286507878_item	3679124	et	4	main
kirjutati	doc_640286507878_item	3679123	et	3	main
sotsiolismi	doc_640286507878_item	3679122	et	4	main
kiideti	doc_640286507878_item	3679121	et	3	main
kus	doc_640286507878_item	3679120	et	3	main
lubatud	doc_640286507878_item	3679116	et	4	main
ideed	doc_640286507878_item	3679114	et	4	main
kogu	doc_640286507878_item	3679108	et	4	main
kultuurielu	doc_640286507878_item	3679107	et	4	main
ka	doc_640286507878_item	3679106	et	3	main
realism	doc_640286507878_item	3679103	et	3	main
usuti	doc_640286507878_item	3679099	et	3	main
aastate	doc_640286507878_item	3679097	et	3	main
nt	doc_640286507878_item	3679092	et	4	main
kombed	doc_640286507878_item	3679091	et	3	main
a	doc_640286507878_item	3679019	et	4	main
tahtsid	doc_640286507878_item	3678983	et	4	main
nad	doc_640286507878_item	3678982	et	3	main
ainult	doc_640286507878_item	3678980	et	4	main
eestlastele	doc_640286507878_item	3678976	et	4	main
kasvas	doc_640286507878_item	3678975	et	3	main
arv	doc_640286507878_item	3678974	et	3	main
raamatukogude	doc_640286507878_item	3678973	et	3	main
raamatud	doc_640286507878_item	3678972	et	4	main
uued	doc_640286507878_item	3678971	et	3	main
kirjutati	doc_640286507878_item	3678970	et	3	main
vastupidi	doc_640286507878_item	3678969	et	3	main
oli	doc_640286507878_item	3678968	et	3	main
ev	doc_640286507878_item	3678966	et	4	main
keelatud	doc_640286507878_item	3678965	et	4	main
marmortahvlil	doc_640286507878_item	3678964	et	3	main
raamatud	doc_640286507878_item	3678956	et	4	main
paljud	doc_640286507878_item	3678955	et	3	main
f	doc_640286507878_item	3678947	et	4	main
õpetatud	doc_640286507878_item	3678937	et	4	main
öelda	doc_640286507878_item	3678924	et	4	main
sellel	doc_640286507878_item	3679111	et	4	main
oli	doc_640286507878_item	3679110	et	3	main
pidamine	doc_640286507878_item	3679094	et	4	main
ev	doc_640286507878_item	3679027	et	4	main
ka	doc_640286507878_item	3679026	et	3	main
märtsi	doc_640286507878_item	3679016	et	4	main
parast	doc_640286507878_item	3679015	et	3	main
suur	doc_640286507878_item	3679012	et	3	main
populaarne	doc_640286507878_item	3678989	et	3	main
kõrgharidus	doc_640286507878_item	3678987	et	3	main
mitte	doc_640286507878_item	3678979	et	3	main
nimed	doc_640286507878_item	3678963	et	3	main
nt	doc_640286507878_item	3678962	et	4	main
tuglas	doc_640286507878_item	3678948	et	4	main
ajaga	doc_640286507878_item	3678922	et	3	main
võrrelda	doc_640286507878_item	3678918	et	4	main
kui	doc_640286507878_item	3678917	et	3	main
tasandil	doc_640286507878_item	3678916	et	3	main
euroopa	doc_640286507878_item	3678915	et	4	main
on	doc_640286507878_item	3678914	et	4	main
rahvateadus	doc_640286507878_item	3678913	et	4	main
ja	doc_640286507878_item	3678912	et	3	main
rahvakultuur	doc_640286507878_item	3678911	et	3	main
ajal	doc_640286507878_item	3678910	et	4	main
sellel	doc_640286507878_item	3678909	et	4	main
et	doc_640286507878_item	3678908	et	3	main
öelda	doc_640286507878_item	3678907	et	4	main
võib	doc_640286507878_item	3678906	et	3	main
rahvusteadus	doc_640286507878_item	3678905	et	4	main
ka	doc_640286507878_item	3678904	et	3	main
areneb	doc_640286507878_item	3678903	et	3	main
õigus	doc_640286507878_item	3678902	et	4	main
ja	doc_640286507878_item	3678901	et	3	main
tõde	doc_640286507878_item	3678900	et	4	main
tammsaare	doc_640286507878_item	3678899	et	3	main
oli	doc_640286507878_item	3678898	et	3	main
esimene	doc_640286507878_item	3678897	et	3	main
auhinda	doc_640286507878_item	3678896	et	4	main
ja	doc_640286507878_item	3678895	et	3	main
stipendiumit	doc_640286507878_item	3678894	et	3	main
isegi	doc_640286507878_item	3678893	et	4	main
said	doc_640286507878_item	3678892	et	4	main
selle	doc_640286507878_item	3678887	et	4	main
valitsus	doc_640286507878_item	3678883	et	4	main
arenemiseks	doc_640286507878_item	3678882	et	4	main
koonduvad	doc_640286507878_item	3678875	et	4	main
nad	doc_640286507878_item	3678874	et	3	main
kodutütred	doc_640286507878_item	3678873	et	3	main
noorkotkad	doc_640286507878_item	3678872	et	3	main
gaidid	doc_640286507878_item	3678871	et	3	main
skaudid	doc_640286507878_item	3678870	et	3	main
ja	doc_640286507878_item	3678863	et	3	main
hakkavad	doc_640286507878_item	3678858	et	4	main
esiteks	doc_640286507878_item	3678857	et	3	main
mida	doc_640286507878_item	3678851	et	4	main
kirjandusvool	doc_640286507878_item	3678832	et	4	main
tähtsad	doc_640286507878_item	3679082	et	3	main
tahab	doc_640286507878_item	3679077	et	3	main
ja	doc_640286507878_item	3679072	et	3	main
ajal	doc_640286507878_item	3679062	et	4	main
julgust	doc_323697784328_item	3679533	et	4	main
vastu	doc_323697784328_item	3679526	et	3	main
liidust	doc_640286507878_item	3678953	et	4	main
kirjaniku	doc_640286507878_item	3678952	et	3	main
visati	doc_640286507878_item	3678951	et	3	main
vallatamie	doc_640286507878_item	3678946	et	4	main
haritlasi	doc_640286507878_item	3678945	et	3	main
nt	doc_640286507878_item	3678936	et	4	main
likvideeriti	doc_640286507878_item	3678935	et	3	main
lammutati	doc_640286507878_item	3678934	et	3	main
võib	doc_640286507878_item	3678923	et	3	main
palju	doc_640286507878_item	3678889	et	4	main
töötavad	doc_640286507878_item	3678880	et	4	main
ja	doc_640286507878_item	3678879	et	3	main
kokku	doc_640286507878_item	3678878	et	3	main
karskusselts	doc_640286507878_item	3678868	et	3	main
erinevad	doc_640286507878_item	3678861	et	4	main
tegutsema	doc_640286507878_item	3678860	et	3	main
aktiivselt	doc_640286507878_item	3678859	et	4	main
sotsialistlik	doc_640286507878_item	3678829	et	3	main
kultuurielu	doc_640286507878_item	3678827	et	4	main
ja	doc_640286507878_item	3678824	et	3	main
palju	doc_640286507878_item	3679085	et	4	main
traditsioonid	doc_640286507878_item	3679079	et	3	main
ta	doc_640286507878_item	3679076	et	4	main
seda	doc_640286507878_item	3679074	et	3	main
uskuda	doc_640286507878_item	3679073	et	3	main
tahab	doc_640286507878_item	3679071	et	3	main
inimesi	doc_323697784328_item	3679529	et	4	main
süsteemi	doc_323697784328_item	3679525	et	4	main
peitub	doc_323697784328_item	3679523	et	3	main
et	doc_323697784328_item	3679521	et	3	main
ja	doc_323697784328_item	3679519	et	3	main
aru	doc_323697784328_item	3679518	et	4	main
sest	doc_323697784328_item	3679513	et	4	main
loomine	doc_323697784328_item	3679506	et	4	main
uute	doc_323697784328_item	3679504	et	3	main
ühisfirmade	doc_323697784328_item	3679486	et	3	main
sõnavabadus	doc_323697784328_item	3679485	et	4	main
ülemnõukogu	doc_323697784328_item	3679480	et	4	main
a	doc_323697784328_item	3679474	et	4	main
1990	doc_323697784328_item	3679473	et	2	main
1	doc_323697784328_item	3679472	et	2	main
revolutsioon	doc_323697784328_item	3679471	et	3	main
2	doc_323697784328_item	3679467	et	2	main
tartu	doc_57773893367_item	3679452	et	4	main
rootslased	doc_57773893367_item	3679450	et	3	main
a	doc_57773893367_item	3679449	et	4	main
misjonäär	doc_57773893367_item	3679440	et	4	main
keeli	doc_57773893367_item	3679435	et	4	main
tartu	doc_57773893367_item	3679430	et	4	main
a	doc_57773893367_item	3679425	et	4	main
2	doc_57773893367_item	3679422	et	2	main
sajandiks	doc_57773893367_item	3679420	et	3	main
kümme	doc_57773893367_item	3679416	et	3	main
gregooriuse	doc_57773893367_item	3679414	et	4	main
poolakatele	doc_57773893367_item	3679400	et	4	main
lõuna-eesti	doc_57773893367_item	3679396	et	4	main
kuningriik	doc_57773893367_item	3679395	et	3	main
rootsi	doc_57773893367_item	3679394	et	4	main
võimule	doc_57773893367_item	3679393	et	3	main
tuleb	doc_57773893367_item	3679392	et	3	main
17	doc_57773893367_item	3679389	et	2	main
tartu	doc_57773893367_item	3679326	et	4	main
kõige	doc_57773893367_item	3679321	et	4	main
stiilils	doc_57773893367_item	3679313	et	4	main
gooti	doc_57773893367_item	3679312	et	4	main
raha	doc_640286507878_item	3678890	et	4	main
peale	doc_640286507878_item	3678888	et	4	main
kultuurielu	doc_640286507878_item	3678885	et	4	main
inimesi	doc_640286507878_item	3678877	et	4	main
harituid	doc_640286507878_item	3678876	et	4	main
haridusselts	doc_640286507878_item	3678867	et	3	main
liidud	doc_640286507878_item	3678864	et	3	main
seltsid	doc_640286507878_item	3678862	et	4	main
ajal	doc_640286507878_item	3678850	et	4	main
sellel	doc_640286507878_item	3678849	et	4	main
tollal	doc_640286507878_item	3678848	et	3	main
oli	doc_640286507878_item	3678847	et	3	main
ta	doc_640286507878_item	3678846	et	4	main
milline	doc_640286507878_item	3678845	et	3	main
vaadelda	doc_640286507878_item	3678844	et	4	main
tuleb	doc_640286507878_item	3678843	et	3	main
kultuurielu	doc_640286507878_item	3678842	et	4	main
pärastsõjajärjgset	doc_640286507878_item	3678841	et	4	main
ensv	doc_640286507878_item	3678840	et	4	main
ja	doc_640286507878_item	3678839	et	3	main
aegset	doc_640286507878_item	3678838	et	3	main
ev	doc_640286507878_item	3678837	et	4	main
võrrelda	doc_640286507878_item	3678836	et	4	main
et	doc_640286507878_item	3678835	et	3	main
realism	doc_640286507878_item	3678830	et	3	main
pärastsõjajärgset	doc_640286507878_item	3678826	et	3	main
aegset	doc_640286507878_item	3678823	et	3	main
1	doc_640286507878_item	3678820	et	2	main
kontrolltöö	doc_640286507878_item	3678819	et	4	main
nõukogude	doc_640286507878_item	3679083	et	3	main
olid	doc_640286507878_item	3679080	et	4	main
mida	doc_640286507878_item	3679075	et	4	main
ta	doc_640286507878_item	3679070	et	4	main
milles	doc_640286507878_item	3679069	et	3	main
kirikus	doc_640286507878_item	3679068	et	3	main
selles	doc_640286507878_item	3679067	et	4	main
ja	doc_323697784328_item	3679530	et	3	main
see	doc_323697784328_item	3679527	et	3	main
võim	doc_323697784328_item	3679524	et	3	main
ühenduses	doc_323697784328_item	3679522	et	4	main
tänu	doc_323697784328_item	3679514	et	4	main
revolutsioon	doc_323697784328_item	3679509	et	3	main
2	doc_323697784328_item	3679507	et	2	main
algas	doc_323697784328_item	3679503	et	3	main
toimus	doc_323697784328_item	3679490	et	3	main
initsiatiivi	doc_323697784328_item	3679488	et	4	main
komiteedi	doc_323697784328_item	3679477	et	4	main
e	doc_323697784328_item	3679476	et	4	main
toimusid	doc_323697784328_item	3679475	et	4	main
muutused	doc_323697784328_item	3679460	et	4	main
1	doc_323697784328_item	3679459	et	2	main
1629	doc_57773893367_item	3679453	et	2	main
poole	doc_57773893367_item	3679444	et	4	main
selleks	doc_640286507878_item	3678834	et	4	main
1	doc_640286507878_item	3678833	et	2	main
2	doc_640286507878_item	3678828	et	2	main
ensv	doc_640286507878_item	3678825	et	4	main
ev	doc_640286507878_item	3678822	et	4	main
võrrelge	doc_640286507878_item	3678821	et	3	main
ajal	doc_640286507878_item	3679084	et	4	main
väga	doc_640286507878_item	3679081	et	3	main
käia	doc_640286507878_item	3679066	et	4	main
ev	doc_640286507878_item	3679061	et	4	main
ja	doc_640286507878_item	3679059	et	3	main
ajal	doc_640286507878_item	3679058	et	4	main
ev	doc_640286507878_item	3679057	et	4	main
saavutatud	doc_640286507878_item	3679056	et	4	main
oli	doc_640286507878_item	3679055	et	3	main
mis	doc_640286507878_item	3679054	et	4	main
sead	doc_640286507878_item	3679053	et	4	main
häivitada	doc_640286507878_item	3679052	et	4	main
kultuurimälu	doc_640286507878_item	3679051	et	4	main
rahva	doc_640286507878_item	3679050	et	3	main
häivitada	doc_640286507878_item	3679049	et	4	main
et	doc_640286507878_item	3679048	et	3	main
selles	doc_640286507878_item	3679047	et	4	main
kõik	doc_640286507878_item	3679046	et	4	main
tehakse	doc_640286507878_item	3679045	et	3	main
ajal	doc_640286507878_item	3679044	et	4	main
nõukogude	doc_640286507878_item	3679043	et	3	main
et	doc_640286507878_item	3679042	et	3	main
öelda	doc_640286507878_item	3679041	et	4	main
võiks	doc_640286507878_item	3679040	et	4	main
lühidalt	doc_640286507878_item	3679039	et	4	main
riigisümboolika	doc_640286507878_item	3679038	et	4	main
vahetub	doc_640286507878_item	3679037	et	3	main
ümber	doc_640286507878_item	3679036	et	3	main
linnad	doc_640286507878_item	3679035	et	3	main
ja	doc_640286507878_item	3679034	et	3	main
tänavad	doc_640286507878_item	3679033	et	4	main
kõik	doc_640286507878_item	3679032	et	4	main
nimetatakse	doc_640286507878_item	3679031	et	3	main
selle	doc_640286507878_item	3679030	et	4	main
peale	doc_640286507878_item	3679029	et	4	main
monumente	doc_640286507878_item	3679028	et	3	main
andis	doc_323697784328_item	3679531	et	3	main
said	doc_323697784328_item	3679517	et	4	main
inimesed	doc_323697784328_item	3679516	et	3	main
sellele	doc_323697784328_item	3679515	et	4	main
oli	doc_323697784328_item	3679510	et	3	main
laulev	doc_323697784328_item	3679508	et	4	main
erakondade	doc_323697784328_item	3679505	et	3	main
neile	doc_323697784328_item	3679532	et	4	main
vaimustas	doc_323697784328_item	3679528	et	3	main
tundsid	doc_323697784328_item	3679520	et	4	main
tähtis	doc_323697784328_item	3679512	et	4	main
seltsid	doc_323697784328_item	3679501	et	4	main
suletud	doc_323697784328_item	3679500	et	4	main
taastati	doc_323697784328_item	3679499	et	4	main
avalikustamine	doc_323697784328_item	3679498	et	4	main
vaimueluga	doc_323697784328_item	3679497	et	3	main
maailma	doc_323697784328_item	3679496	et	4	main
side	doc_323697784328_item	3679495	et	4	main
taastus	doc_323697784328_item	3679494	et	4	main
süsteemile	doc_323697784328_item	3679493	et	3	main
üleminek	doc_323697784328_item	3679491	et	3	main
väga	doc_323697784328_item	3679511	et	3	main
ja	doc_323697784328_item	3679484	et	3	main
ajakirjanduse	doc_323697784328_item	3679483	et	3	main
ilmus	doc_323697784328_item	3679482	et	4	main
ja	doc_323697784328_item	3679478	et	3	main
laulev	doc_323697784328_item	3679470	et	4	main
kontrolltöö	doc_323697784328_item	3679458	et	4	main
rootsi	doc_57773893367_item	3679443	et	4	main
usk	doc_57773893367_item	3679442	et	3	main
katoliiklik	doc_57773893367_item	3679441	et	3	main
läti	doc_57773893367_item	3679436	et	4	main
ülikooli	doc_57773893367_item	3679431	et	4	main
peetakse	doc_57773893367_item	3679429	et	3	main
mitmeks	doc_57773893367_item	3679419	et	4	main
a	doc_57773893367_item	3679412	et	4	main
1582	doc_57773893367_item	3679411	et	2	main
tavad	doc_57773893367_item	3679410	et	3	main
alguses	doc_57773893367_item	3679391	et	4	main
puruksmkivipommidega	doc_57773893367_item	3679388	et	4	main
pommitatakse	doc_57773893367_item	3679387	et	3	main
hävitamine	doc_57773893367_item	3679386	et	4	main
stiilis	doc_57773893367_item	3679325	et	4	main
hooned	doc_57773893367_item	3679314	et	4	main
gootika	doc_57773893367_item	3679311	et	4	main
kirikud	doc_57773893367_item	3679309	et	3	main
oli	doc_57773893367_item	3679307	et	3	main
rajama	doc_57773893367_item	3679302	et	3	main
frantsihlased	doc_57773893367_item	3679294	et	4	main
pirita	doc_57773893367_item	3679292	et	4	main
a	doc_57773893367_item	3679291	et	4	main
1436	doc_57773893367_item	3679290	et	2	main
tallinn	doc_57773893367_item	3679289	et	4	main
dominiiklaste	doc_57773893367_item	3679287	et	3	main
uusi	doc_57773893367_item	3679283	et	3	main
arstid	doc_57773893367_item	3679281	et	4	main
omapärased	doc_57773893367_item	3679280	et	4	main
ka	doc_57773893367_item	3679279	et	3	main
ii	doc_57773893367_item	3679266	et	4	main
19	doc_57773893367_item	3679264	et	2	main
suuline	doc_57773893367_item	3679255	et	4	main
rahvalaule	doc_57773893367_item	3679238	et	4	main
leida	doc_57773893367_item	3679237	et	3	main
võib	doc_57773893367_item	3679236	et	3	main
kasutaks	doc_57773893367_item	3679230	et	4	main
oli	doc_57773893367_item	3679211	et	3	main
aeg	doc_57773893367_item	3679204	et	3	main
hea	doc_57773893367_item	3679203	et	4	main
hansa	doc_57773893367_item	3679193	et	4	main
väiksemad	doc_57773893367_item	3679187	et	4	main
usklikke	doc_57773893367_item	3679365	et	3	main
vene-liivi	doc_57773893367_item	3679357	et	4	main
organisatsioonid	doc_323697784328_item	3679502	et	3	main
tõus	doc_323697784328_item	3679489	et	4	main
tekkimine	doc_323697784328_item	3679487	et	4	main
e	doc_323697784328_item	3679479	et	4	main
tähendab	doc_323697784328_item	3679469	et	3	main
poliitilises	doc_323697784328_item	3679465	et	3	main
eesti	doc_323697784328_item	3679464	et	4	main
taasiseseisvunud	doc_323697784328_item	3679463	et	4	main
muudatused	doc_323697784328_item	3679462	et	3	main
ja	doc_323697784328_item	3679461	et	3	main
a	doc_57773893367_item	3679454	et	4	main
vallutavad	doc_57773893367_item	3679451	et	4	main
1625	doc_57773893367_item	3679448	et	2	main
sõda	doc_57773893367_item	3679445	et	4	main
koolitati	doc_57773893367_item	3679438	et	4	main
eesti	doc_57773893367_item	3679437	et	4	main
õpetati	doc_57773893367_item	3679433	et	3	main
seminar	doc_57773893367_item	3679428	et	3	main
jesuiitide	doc_57773893367_item	3679426	et	3	main
kalendri	doc_57773893367_item	3679423	et	3	main
jääb	doc_57773893367_item	3679421	et	3	main
päeva	doc_57773893367_item	3679417	et	4	main
kalender	doc_57773893367_item	3679415	et	3	main
uus	doc_57773893367_item	3679413	et	3	main
vanad	doc_57773893367_item	3679408	et	3	main
ajaks	doc_57773893367_item	3679399	et	4	main
läheb	doc_57773893367_item	3679397	et	3	main
saj	doc_57773893367_item	3679390	et	4	main
b	doc_57773893367_item	3679331	et	4	main
uhkem	doc_57773893367_item	3679322	et	4	main
olid	doc_57773893367_item	3679310	et	4	main
avalikku	doc_57773893367_item	3679303	et	4	main
olid	doc_57773893367_item	3679278	et	4	main
kodust	doc_57773893367_item	3679272	et	4	main
folkloor	doc_57773893367_item	3679258	et	4	main
ehk	doc_57773893367_item	3679257	et	3	main
tähtsaim	doc_57773893367_item	3679244	et	4	main
teatud	doc_57773893367_item	3679241	et	4	main
kirikukihelkond	doc_57773893367_item	3679240	et	3	main
jne	doc_57773893367_item	3679239	et	4	main
kombeid	doc_57773893367_item	3679232	et	4	main
vanu	doc_57773893367_item	3679231	et	4	main
paganad	doc_57773893367_item	3679228	et	3	main
isemajandamisele	doc_323697784328_item	3679492	et	3	main
valimiskampaania	doc_323697784328_item	3679481	et	4	main
mida	doc_323697784328_item	3679468	et	4	main
elus	doc_323697784328_item	3679466	et	4	main
rahu	doc_57773893367_item	3679456	et	4	main
altmarki	doc_57773893367_item	3679455	et	4	main
kaotavad	doc_57773893367_item	3679447	et	4	main
poolakad	doc_57773893367_item	3679446	et	4	main
tõlke	doc_57773893367_item	3679439	et	4	main
kohalike	doc_57773893367_item	3679434	et	4	main
eelkäijaks	doc_57773893367_item	3679432	et	3	main
kolleegium	doc_57773893367_item	3679427	et	3	main
1585	doc_57773893367_item	3679424	et	2	main
enne	doc_57773893367_item	3679418	et	4	main
valitsus	doc_57773893367_item	3679404	et	4	main
a	doc_57773893367_item	3679402	et	4	main
1582	doc_57773893367_item	3679401	et	2	main
kloostri	doc_57773893367_item	3679385	et	3	main
pirita	doc_57773893367_item	3679384	et	4	main
vene-liivi	doc_57773893367_item	3679329	et	4	main
2	doc_57773893367_item	3679328	et	2	main
toomkirik	doc_57773893367_item	3679327	et	3	main
hoone	doc_57773893367_item	3679323	et	4	main
kaunistamine	doc_57773893367_item	3679319	et	4	main
hoonete	doc_57773893367_item	3679318	et	4	main
monumentaalsed	doc_57773893367_item	3679317	et	3	main
suured	doc_57773893367_item	3679316	et	3	main
olid	doc_57773893367_item	3679315	et	4	main
hakkatakse	doc_57773893367_item	3679301	et	4	main
begardid	doc_57773893367_item	3679299	et	4	main
15	doc_57773893367_item	3679297	et	2	main
klooster	doc_57773893367_item	3679288	et	3	main
pääse	doc_57773893367_item	3679270	et	4	main
ei	doc_57773893367_item	3679269	et	4	main
talupoeg	doc_57773893367_item	3679268	et	3	main
saj	doc_57773893367_item	3679265	et	4	main
püsib	doc_57773893367_item	3679263	et	3	main
on	doc_57773893367_item	3679254	et	4	main
murraks	doc_57773893367_item	3679253	et	3	main
keelemurre	doc_57773893367_item	3679252	et	4	main
ühtne	doc_57773893367_item	3679251	et	3	main
kujuneb	doc_57773893367_item	3679250	et	3	main
üksus	doc_57773893367_item	3679249	et	3	main
kirik	doc_57773893367_item	3679245	et	3	main
emakirik	doc_57773893367_item	3679243	et	3	main
visitat	doc_57773893367_item	3679234	et	4	main
praegu	doc_57773893367_item	3679233	et	3	main
et	doc_57773893367_item	3679227	et	3	main
korraldusel	doc_57773893367_item	3679225	et	4	main
kirik	doc_57773893367_item	3679221	et	3	main
vaimulik	doc_57773893367_item	3679220	et	3	main
kirik	doc_57773893367_item	3679217	et	3	main
oli	doc_57773893367_item	3679202	et	3	main
tähtis	doc_57773893367_item	3679199	et	4	main
samuti	doc_57773893367_item	3679197	et	3	main
uus-pärnu	doc_57773893367_item	3679188	et	4	main
tähtsamad	doc_57773893367_item	3679183	et	4	main
elanike	doc_57773893367_item	3679179	et	3	main
vaimulikud	doc_57773893367_item	3679176	et	3	main
eestiga	doc_57773893367_item	3679363	et	4	main
kombed	doc_57773893367_item	3679409	et	3	main
taastas	doc_57773893367_item	3679407	et	3	main
kirik	doc_57773893367_item	3679406	et	3	main
katoliklik	doc_57773893367_item	3679405	et	4	main
poola	doc_57773893367_item	3679403	et	4	main
mõneks	doc_57773893367_item	3679398	et	3	main
tugevad	doc_57773893367_item	3679383	et	4	main
julmad	doc_57773893367_item	3679382	et	3	main
väga	doc_57773893367_item	3679381	et	3	main
olid	doc_57773893367_item	3679380	et	4	main
tatarlased	doc_57773893367_item	3679379	et	3	main
vastu	doc_57773893367_item	3679378	et	3	main
a	doc_57773893367_item	3679356	et	4	main
1559	doc_57773893367_item	3679355	et	2	main
maksti	doc_57773893367_item	3679354	et	3	main
venemaale	doc_57773893367_item	3679353	et	4	main
vaherahu	doc_57773893367_item	3679352	et	4	main
venemaaga	doc_57773893367_item	3679351	et	3	main
oli	doc_57773893367_item	3679350	et	3	main
varem	doc_57773893367_item	3679349	et	4	main
riigiks	doc_57773893367_item	3679348	et	3	main
agressivseks	doc_57773893367_item	3679347	et	4	main
muutus	doc_57773893367_item	3679346	et	4	main
venemaa	doc_57773893367_item	3679345	et	4	main
julm	doc_57773893367_item	3679344	et	3	main
iv	doc_57773893367_item	3679343	et	4	main
ivan	doc_57773893367_item	3679342	et	4	main
valitses	doc_57773893367_item	3679341	et	3	main
moskvas	doc_57773893367_item	3679340	et	4	main
16	doc_57773893367_item	3679338	et	2	main
saj	doc_57773893367_item	3679339	et	4	main
elu	doc_57773893367_item	3679337	et	4	main
talupoegade	doc_57773893367_item	3679336	et	3	main
kirjeldab	doc_57773893367_item	3679335	et	3	main
kroonika	doc_57773893367_item	3679334	et	4	main
liivimaa	doc_57773893367_item	3679333	et	4	main
russowi	doc_57773893367_item	3679332	et	4	main
sõda	doc_57773893367_item	3679330	et	4	main
gooti	doc_57773893367_item	3679324	et	4	main
raekivist	doc_57773893367_item	3679320	et	4	main
kõige	doc_57773893367_item	3679305	et	4	main
haiglaid	doc_57773893367_item	3679304	et	3	main
klooster	doc_57773893367_item	3679293	et	3	main
a	doc_57773893367_item	3679286	et	4	main
asju	doc_57773893367_item	3679284	et	3	main
oma	doc_57773893367_item	3679271	et	4	main
pärimus	doc_57773893367_item	3679256	et	4	main
rahvakultuuri	doc_57773893367_item	3679248	et	4	main
territoorium	doc_57773893367_item	3679242	et	3	main
ei	doc_57773893367_item	3679229	et	4	main
jälgiti	doc_57773893367_item	3679226	et	3	main
piiskopi	doc_57773893367_item	3679224	et	4	main
visitatsioonid	doc_57773893367_item	3679223	et	3	main
piiskop	doc_57773893367_item	3679218	et	3	main
ii	doc_57773893367_item	3679215	et	4	main
konflikte	doc_57773893367_item	3679214	et	3	main
palju	doc_57773893367_item	3679213	et	4	main
väga	doc_57773893367_item	3679212	et	3	main
jaoks	doc_57773893367_item	3679207	et	4	main
suhteliselt	doc_57773893367_item	3679201	et	4	main
väga	doc_57773893367_item	3679198	et	3	main
kuuluvad	doc_57773893367_item	3679192	et	4	main
tartu	doc_57773893367_item	3679186	et	4	main
inimesi	doc_57773893367_item	3679182	et	4	main
sõda	doc_57773893367_item	3679358	et	4	main
raekoda	doc_57773893367_item	3679308	et	4	main
tähtsam	doc_57773893367_item	3679306	et	4	main
begiinid	doc_57773893367_item	3679300	et	4	main
saj	doc_57773893367_item	3679298	et	4	main
mungad	doc_57773893367_item	3679296	et	3	main
hallid	doc_57773893367_item	3679295	et	4	main
1229	doc_57773893367_item	3679285	et	2	main
õptasid	doc_57773893367_item	3679282	et	4	main
tegevusega	doc_57773893367_item	3679277	et	4	main
missiooni	doc_57773893367_item	3679276	et	4	main
tegelesdi	doc_57773893367_item	3679275	et	4	main
rändmungad	doc_57773893367_item	3679274	et	3	main
paiksus	doc_57773893367_item	3679273	et	4	main
pooleni	doc_57773893367_item	3679267	et	3	main
kõik	doc_57773893367_item	3679262	et	4	main
see	doc_57773893367_item	3679261	et	3	main
rõivastus	doc_57773893367_item	3679260	et	4	main
ja	doc_57773893367_item	3679259	et	3	main
väike	doc_57773893367_item	3679247	et	4	main
kihelkond	doc_57773893367_item	3679246	et	3	main
protokollides	doc_57773893367_item	3679235	et	4	main
teostas	doc_57773893367_item	3679222	et	3	main
oli	doc_57773893367_item	3679219	et	3	main
võim	doc_57773893367_item	3679216	et	3	main
linnavõimude	doc_57773893367_item	3679209	et	3	main
aga	doc_57773893367_item	3679208	et	3	main
riia	doc_57773893367_item	3679195	et	4	main
liitu	doc_57773893367_item	3679194	et	4	main
viljandi	doc_57773893367_item	3679189	et	4	main
linnad	doc_57773893367_item	3679184	et	3	main
keskaegne	doc_57773893367_item	3679177	et	3	main
linnaelanikud	doc_57773893367_item	3679175	et	3	main
matsmaarahvas	doc_57773893367_item	3679172	et	4	main
jagunesid	doc_57773893367_item	3679171	et	4	main
kiusatakse	doc_57773893367_item	3679364	et	3	main
liivimaaga	doc_57773893367_item	3679362	et	3	main
võitles	doc_57773893367_item	3679361	et	3	main
iv	doc_57773893367_item	3679360	et	4	main
vaehl	doc_57773893367_item	3679210	et	4	main
talupoegade	doc_57773893367_item	3679206	et	3	main
isegi	doc_57773893367_item	3679205	et	4	main
kaubanduslinn	doc_57773893367_item	3679200	et	3	main
on	doc_57773893367_item	3679196	et	4	main
nad	doc_57773893367_item	3679191	et	3	main
kõik	doc_57773893367_item	3679190	et	4	main
tallinn	doc_57773893367_item	3679185	et	4	main
200000	doc_57773893367_item	3679181	et	2	main
arv	doc_57773893367_item	3679180	et	3	main
linnakultuur	doc_57773893367_item	3679178	et	3	main
sakssakslased	doc_57773893367_item	3679174	et	4	main
eestlased	doc_57773893367_item	3679173	et	3	main
inimesed	doc_57773893367_item	3679170	et	3	main
keskaeg	doc_57773893367_item	3679169	et	3	main
1270-1558	doc_57773893367_item	3679168	et	2	main
1	doc_57773893367_item	3679167	et	2	main
sõda	doc_57773893367_item	3679166	et	4	main
vene-liivi	doc_57773893367_item	3679165	et	4	main
võimalikuks	doc_57773893367_item	3679164	et	3	main
sa	doc_57773893367_item	3679163	et	3	main
miks	doc_57773893367_item	3679162	et	4	main
2	doc_57773893367_item	3679161	et	2	main
linnakultuur	doc_57773893367_item	3679160	et	3	main
keskaegne	doc_57773893367_item	3679159	et	3	main
oli	doc_57773893367_item	3679158	et	3	main
missugune	doc_57773893367_item	3679157	et	3	main
1	doc_57773893367_item	3679156	et	2	main
kultuuriloost	doc_57773893367_item	3679155	et	4	main
eesti	doc_57773893367_item	3679154	et	4	main
kontrolltöö	doc_57773893367_item	3679153	et	4	main
kontrolltöö	doc_57773893367_item	3679152	et	4	main
tatarlaste	doc_57773893367_item	3679377	et	3	main
võitlema	doc_57773893367_item	3679376	et	3	main
asub	doc_57773893367_item	3679375	et	3	main
reliikvia	doc_57773893367_item	3679374	et	4	main
viimne	doc_57773893367_item	3679373	et	3	main
schnkenberg	doc_57773893367_item	3679372	et	4	main
ivo	doc_57773893367_item	3679371	et	4	main
a	doc_57773893367_item	3679370	et	4	main
1573	doc_57773893367_item	3679369	et	2	main
euroopaga	doc_57773893367_item	3679368	et	3	main
kauplemine	doc_57773893367_item	3679367	et	4	main
oli	doc_57773893367_item	3679366	et	3	main
ivan	doc_57773893367_item	3679359	et	4	main
kirves	doc_491521501817_item	3680777	et	4	main
ketassaag	doc_491521501817_item	3680772	et	3	main
näpitstangid	doc_491521501817_item	3680770	et	3	main
muruniiduk	doc_491521501817_item	3680768	et	3	main
kohviveski	doc_491521501817_item	3680766	et	4	main
see	doc_491521501817_item	3680763	et	3	main
prits	doc_491521501817_item	3680759	et	3	main
töötavad	doc_491521501817_item	3680751	et	4	main
puur	doc_491521501817_item	3680750	et	3	main
pump	doc_491521501817_item	3680781	et	3	main
akulaadija	doc_491521501817_item	3680778	et	4	main
prits	doc_491521501817_item	3680773	et	3	main
pump	doc_491521501817_item	3680767	et	3	main
teine	doc_491521501817_item	3680765	et	3	main
juukseföön	doc_491521501817_item	3680745	et	3	main
töötavad	doc_491521501817_item	3680743	et	4	main
6-b	doc_491521501817_item	3680737	et	4	main
enda	doc_491521501817_item	3680728	et	4	main
on	doc_491521501817_item	3680727	et	4	main
olemas	doc_491521501817_item	3680723	et	4	main
on	doc_491521501817_item	3680721	et	4	main
teeb	doc_491521501817_item	3680712	et	3	main
ta	doc_491521501817_item	3680711	et	4	main
d	doc_491521501817_item	3680710	et	4	main
tulnud	doc_491521501817_item	3680704	et	4	main
ei	doc_491521501817_item	3680703	et	4	main
b	doc_491521501817_item	3680701	et	4	main
tähelepanu	doc_491521501817_item	3680700	et	4	main
all	doc_491521501817_item	3680686	et	3	main
on	doc_491521501817_item	3680684	et	4	main
maapõhja	doc_491521501817_item	3680682	et	4	main
luust	doc_491521501817_item	3680675	et	4	main
selle	doc_491521501817_item	3680659	et	4	main
d	doc_491521501817_item	3680651	et	4	main
toetuda	doc_491521501817_item	3680650	et	3	main
tean	doc_491521501817_item	3680644	et	3	main
hetkel	doc_491521501817_item	3680642	et	4	main
abil	doc_491521501817_item	3680499	et	4	main
nuppude	doc_491521501817_item	3680498	et	3	main
toatemperatuuri	doc_491521501817_item	3680497	et	4	main
reguleerida	doc_491521501817_item	3680496	et	3	main
ja	doc_491521501817_item	3680495	et	3	main
teie	doc_491521501817_item	3680489	et	4	main
helistab	doc_491521501817_item	3680488	et	3	main
suulise	doc_491521501817_item	3680481	et	4	main
töötab	doc_491521501817_item	3680480	et	3	main
mis	doc_491521501817_item	3680479	et	4	main
valgustuse	doc_491521501817_item	3680478	et	4	main
koju	doc_491521501817_item	3680477	et	3	main
paigutada	doc_491521501817_item	3680476	et	3	main
praegu	doc_491521501817_item	3680475	et	3	main
juba	doc_491521501817_item	3680474	et	3	main
võite	doc_491521501817_item	3680473	et	4	main
teine	doc_491521501817_item	3680613	et	3	main
aeg	doc_491521501817_item	3680610	et	3	main
sõna	doc_491521501817_item	3680578	et	4	main
уже	doc_491521501817_item	3680559	et	2	main
дороге	doc_491521501817_item	3680556	et	2	main
кнопок	doc_491521501817_item	3680551	et	2	main
juukseföön	doc_491521501817_item	3680776	et	3	main
nii	doc_491521501817_item	3680762	et	3	main
muruvõti	doc_491521501817_item	3680754	et	4	main
näpitstangid	doc_491521501817_item	3680753	et	3	main
elektrita	doc_491521501817_item	3680752	et	3	main
sõnad	doc_491521501817_item	3680740	et	4	main
jagage	doc_491521501817_item	3680739	et	3	main
23	doc_491521501817_item	3680738	et	2	main
mind	doc_491521501817_item	3680717	et	4	main
kiusab	doc_491521501817_item	3680716	et	3	main
ära	doc_491521501817_item	3680709	et	4	main
kergelt	doc_491521501817_item	3680706	et	4	main
sellega	doc_491521501817_item	3680695	et	3	main
nägi	doc_491521501817_item	3680694	et	3	main
ta	doc_491521501817_item	3680693	et	4	main
6	doc_491521501817_item	3680692	et	2	main
liiga	doc_491521501817_item	3680691	et	4	main
ta	doc_491521501817_item	3680688	et	4	main
ja	doc_491521501817_item	3680676	et	3	main
ajab	doc_491521501817_item	3680671	et	3	main
leidke	doc_491521501817_item	3680666	et	3	main
aeglustub	doc_491521501817_item	3680664	et	3	main
pulssi	doc_491521501817_item	3680658	et	4	main
talle	doc_491521501817_item	3680649	et	4	main
võin	doc_491521501817_item	3680646	et	3	main
raskel	doc_491521501817_item	3680641	et	3	main
mind	doc_491521501817_item	3680639	et	4	main
toetab	doc_491521501817_item	3680638	et	3	main
kes	doc_491521501817_item	3680637	et	4	main
sõber	doc_491521501817_item	3680636	et	3	main
наконец-то	doc_491521501817_item	3680509	et	2	main
arvutivõrgu	doc_491521501817_item	3680507	et	3	main
taga	doc_491521501817_item	3680491	et	4	main
ukse	doc_491521501817_item	3680490	et	3	main
näitab	doc_491521501817_item	3680486	et	3	main
mis	doc_491521501817_item	3680485	et	4	main
täitumas	doc_491521501817_item	3680467	et	4	main
eksamitöö	doc_491521501817_item	3680460	et	4	main
kaua	doc_491521501817_item	3680622	et	3	main
nii	doc_491521501817_item	3680621	et	3	main
äraminekuga	doc_491521501817_item	3680620	et	3	main
venitasin	doc_491521501817_item	3680619	et	3	main
ma	doc_491521501817_item	3680618	et	3	main
teosammul	doc_491521501817_item	3680617	et	4	main
venib	doc_491521501817_item	3680616	et	3	main
aga	doc_491521501817_item	3680615	et	3	main
tuleb	doc_491521501817_item	3680606	et	3	main
sobiv	doc_491521501817_item	3680577	et	4	main
tegevust	doc_491521501817_item	3680572	et	4	main
väljapoole	doc_491521501817_item	3680570	et	3	main
кондиционер	doc_491521501817_item	3680553	et	2	main
mobiiltelefoni	doc_491521501816_item	3681096	et	4	main
kasutage	doc_491521501816_item	3681095	et	3	main
мобильным	doc_491521501816_item	3681090	et	2	main
главе	doc_491521501816_item	3680883	et	2	main
архитекторам	doc_491521501816_item	3680878	et	2	main
эндрю	doc_491521501816_item	3680874	et	2	main
или	doc_491521501816_item	3680866	et	2	main
не	doc_491521501816_item	3680862	et	2	main
кого	doc_491521501816_item	3680856	et	2	main
ajalehti	doc_491521501816_item	3680853	et	4	main
isegi	doc_491521501816_item	3680852	et	4	main
korral	doc_491521501816_item	3680851	et	4	main
ja	doc_491521501816_item	3680841	et	3	main
asju	doc_491521501816_item	3680830	et	3	main
kodus	doc_491521501816_item	3680827	et	4	main
pardel	doc_491521501817_item	3680774	et	4	main
kui	doc_491521501817_item	3680764	et	3	main
tolmuimeja	doc_491521501817_item	3680749	et	4	main
akulaadija	doc_491521501817_item	3680748	et	4	main
elektriga	doc_491521501817_item	3680744	et	3	main
f	doc_491521501817_item	3680726	et	4	main
ta	doc_491521501817_item	3680715	et	4	main
korraldab	doc_491521501817_item	3680708	et	3	main
see	doc_491521501817_item	3680702	et	3	main
vaeva	doc_491521501817_item	3680696	et	4	main
rohu	doc_491521501817_item	3680660	et	4	main
selle	doc_491521501817_item	3680654	et	4	main
aeglustama	doc_491521501817_item	3680653	et	3	main
aeglustuma	doc_491521501817_item	3680652	et	3	main
et	doc_491521501817_item	3680645	et	3	main
tõeline	doc_491521501817_item	3680635	et	4	main
rääkimata	doc_491521501817_item	3680505	et	4	main
ette	doc_491521501817_item	3680494	et	4	main
kardinad	doc_491521501817_item	3680493	et	4	main
kes	doc_491521501817_item	3680487	et	4	main
valvekaamera	doc_491521501817_item	3680484	et	4	main
peale	doc_491521501817_item	3680483	et	4	main
käskluse	doc_491521501817_item	3680482	et	3	main
digitaaltehnoloogiale	doc_491521501817_item	3680472	et	3	main
tänu	doc_491521501817_item	3680469	et	4	main
nüüd	doc_491521501817_item	3680462	et	4	main
1tõlkige	doc_491521501817_item	3680461	et	3	main
et	doc_491521501817_item	3680607	et	3	main
lünka	doc_491521501817_item	3680576	et	4	main
kirjutage	doc_491521501817_item	3680575	et	3	main
höövel	doc_491521501817_item	3680788	et	3	main
jootekolb	doc_491521501817_item	3680787	et	4	main
haamer	doc_491521501817_item	3680786	et	3	main
muruniiduk	doc_491521501817_item	3680785	et	3	main
puur	doc_491521501817_item	3680784	et	3	main
viil	doc_491521501817_item	3680783	et	3	main
mutrivõti	doc_491521501817_item	3680782	et	4	main
kruvikeeraja	doc_491521501817_item	3680780	et	4	main
tolmuimeja	doc_491521501817_item	3680779	et	4	main
kohviveski	doc_491521501817_item	3680775	et	4	main
lood	doc_491521501817_item	3680771	et	4	main
ketassaag	doc_491521501817_item	3680769	et	3	main
höövel	doc_491521501817_item	3680761	et	3	main
lood	doc_491521501817_item	3680760	et	4	main
kruvikeeraja	doc_491521501817_item	3680758	et	4	main
kirves	doc_491521501817_item	3680757	et	4	main
haamer	doc_491521501817_item	3680756	et	3	main
viil	doc_491521501817_item	3680755	et	3	main
jootekolb	doc_491521501817_item	3680747	et	4	main
1-c	doc_491521501817_item	3680732	et	4	main
tige	doc_491521501817_item	3680731	et	3	main
väga	doc_491521501817_item	3680730	et	3	main
peale	doc_491521501817_item	3680729	et	4	main
raamatutegelased	doc_491521501817_item	3680725	et	3	main
päriselt	doc_491521501817_item	3680722	et	3	main
ülekohut	doc_491521501817_item	3680714	et	3	main
mulle	doc_491521501817_item	3680713	et	4	main
erilist	doc_491521501817_item	3680699	et	4	main
pälvib	doc_491521501817_item	3680698	et	3	main
mulle	doc_491521501817_item	3680690	et	4	main
teeb	doc_491521501817_item	3680689	et	3	main
pardel	doc_491521501817_item	3680746	et	4	main
rühma	doc_491521501817_item	3680742	et	4	main
kolme	doc_491521501817_item	3680741	et	4	main
5-d	doc_491521501817_item	3680736	et	4	main
4-a	doc_491521501817_item	3680735	et	4	main
3-f	doc_491521501817_item	3680734	et	4	main
2-e	doc_491521501817_item	3680733	et	3	main
mitte	doc_491521501817_item	3680724	et	3	main
kes	doc_491521501817_item	3680720	et	4	main
inimesed	doc_491521501817_item	3680719	et	3	main
e	doc_491521501817_item	3680718	et	4	main
c	doc_491521501817_item	3680707	et	4	main
talle	doc_491521501817_item	3680705	et	4	main
a	doc_491521501817_item	3680697	et	4	main
lihast	doc_491521501817_item	3680677	et	4	main
joonde	doc_491521501817_item	3680673	et	4	main
1	doc_491521501817_item	3680670	et	2	main
väljendite	doc_491521501817_item	3680668	et	3	main
20	doc_491521501817_item	3680665	et	2	main
teie	doc_491521501817_item	3680662	et	4	main
tarvitamisel	doc_491521501817_item	3680661	et	4	main
aeglustab	doc_491521501817_item	3680657	et	3	main
ma	doc_491521501817_item	3680643	et	3	main
igal	doc_491521501817_item	3680640	et	3	main
toetama	doc_491521501817_item	3680632	et	3	main
toetuma	doc_491521501817_item	3680631	et	4	main
ehitamisest	doc_491521501817_item	3680508	et	4	main
koduse	doc_491521501817_item	3680506	et	4	main
koduteel	doc_491521501817_item	3680504	et	3	main
juba	doc_491521501817_item	3680503	et	3	main
sisse	doc_491521501817_item	3680502	et	4	main
5	doc_491521501817_item	3680687	et	2	main
luubi	doc_491521501817_item	3680685	et	3	main
4	doc_491521501817_item	3680683	et	2	main
ennast	doc_491521501817_item	3680681	et	4	main
kirub	doc_491521501817_item	3680680	et	3	main
3	doc_491521501817_item	3680679	et	2	main
inimesed	doc_491521501817_item	3680678	et	3	main
2	doc_491521501817_item	3680674	et	2	main
asjad	doc_491521501817_item	3680672	et	3	main
paarid	doc_491521501817_item	3680669	et	4	main
sünonüümsete	doc_491521501817_item	3680667	et	3	main
pulss	doc_491521501817_item	3680663	et	3	main
tarvitamine	doc_491521501817_item	3680656	et	4	main
rohu	doc_491521501817_item	3680655	et	4	main
hetkel	doc_491521501817_item	3680648	et	4	main
raskel	doc_491521501817_item	3680647	et	3	main
on	doc_491521501817_item	3680634	et	4	main
ta	doc_491521501817_item	3680633	et	4	main
c	doc_491521501817_item	3680630	et	4	main
lahkuma	doc_491521501817_item	3680629	et	3	main
siiski	doc_491521501817_item	3680628	et	4	main
pidin	doc_491521501817_item	3680627	et	3	main
lõpuks	doc_491521501817_item	3680626	et	4	main
aga	doc_491521501817_item	3680625	et	3	main
oskasin	doc_491521501817_item	3680624	et	3	main
kui	doc_491521501817_item	3680623	et	3	main
благодаря	doc_491521501817_item	3680521	et	2	main
очередь	doc_491521501817_item	3680520	et	2	main
первую	doc_491521501817_item	3680519	et	2	main
в	doc_491521501817_item	3680518	et	2	main
можете	doc_491521501817_item	3680517	et	2	main
вы	doc_491521501817_item	3680516	et	2	main
сегодня	doc_491521501817_item	3680515	et	2	main
уже	doc_491521501817_item	3680514	et	2	main
сбываются	doc_491521501817_item	3680513	et	2	main
мечты	doc_491521501817_item	3680512	et	2	main
теперь	doc_491521501817_item	3680510	et	2	main
эти	doc_491521501817_item	3680511	et	2	main
õhukonditsioneeri	doc_491521501817_item	3680501	et	4	main
lülitada	doc_491521501817_item	3680500	et	3	main
tõmmata	doc_491521501817_item	3680492	et	4	main
ja	doc_491521501817_item	3680471	et	3	main
kord	doc_491521501817_item	3680614	et	4	main
väga	doc_491521501817_item	3680611	et	3	main
mõnikord	doc_491521501817_item	3680608	et	3	main
see	doc_491521501817_item	3680604	et	3	main
venitama	doc_491521501817_item	3680602	et	4	main
venima	doc_491521501817_item	3680601	et	3	main
tegusõna	doc_491521501817_item	3680574	et	4	main
suunatud	doc_491521501817_item	3680571	et	4	main
enesekohast	doc_491521501817_item	3680566	et	4	main
5	doc_491521501817_item	3680564	et	2	main
компьютерной	doc_491521501817_item	3680562	et	2	main
о	doc_491521501817_item	3680560	et	2	main
домой	doc_491521501817_item	3680557	et	2	main
уже	doc_491521501817_item	3680554	et	2	main
ärge	doc_491521501816_item	3681094	et	3	main
не	doc_491521501816_item	3681088	et	2	main
tõlkige	doc_491521501816_item	3681086	et	3	main
kurdiks	doc_491521501816_item	3681084	et	4	main
и	doc_491521501816_item	3680886	et	2	main
кто	doc_491521501816_item	3680881	et	2	main
и	doc_491521501816_item	3680876	et	2	main
гатеси	doc_491521501816_item	3680873	et	2	main
свекровь	doc_491521501816_item	3680868	et	2	main
служанку	doc_491521501816_item	3680865	et	2	main
благодарить	doc_491521501816_item	3680860	et	2	main
хотя	doc_491521501816_item	3680855	et	2	main
loeb	doc_491521501816_item	3680849	et	3	main
teie	doc_491521501816_item	3680845	et	4	main
hoolitseb	doc_491521501816_item	3680844	et	3	main
toidu	doc_491521501816_item	3680839	et	3	main
kütmise	doc_491521501816_item	3680838	et	4	main
ajab	doc_491521501816_item	3680828	et	3	main
on	doc_491521501816_item	3680817	et	4	main
kübermaailma	doc_491521501816_item	3680814	et	4	main
andrew	doc_491521501816_item	3680810	et	4	main
gatesile	doc_491521501816_item	3680809	et	4	main
ei	doc_491521501816_item	3680798	et	4	main
tänada	doc_491521501816_item	3680797	et	3	main
kõige	doc_491521501816_item	3681067	et	4	main
muutud	doc_491521501816_item	3681057	et	4	main
suheldes	doc_491521501816_item	3681056	et	3	main
saavas	doc_491521501816_item	3681020	et	4	main
nad	doc_491521501816_item	3681007	et	3	main
ta	doc_491521501816_item	3680994	et	4	main
peab	doc_491521501816_item	3680984	et	4	main
voodis	doc_491521501816_item	3680983	et	3	main
nakkav	doc_491521501816_item	3680968	et	4	main
jäi	doc_491521501816_item	3680956	et	3	main
saanud	doc_491521501816_item	3680952	et	4	main
читать	doc_491521501816_item	3680921	et	2	main
о	doc_491521501816_item	3680915	et	2	main
поливкой	doc_491521501816_item	3680911	et	2	main
дома	doc_491521501816_item	3680907	et	2	main
mikroprotsessoreile	doc_491521501817_item	3680470	et	3	main
eeskätt	doc_491521501817_item	3680468	et	3	main
viimaks	doc_491521501817_item	3680466	et	4	main
unistused	doc_491521501817_item	3680465	et	4	main
need	doc_491521501817_item	3680464	et	3	main
on	doc_491521501817_item	3680463	et	4	main
kiiresti	doc_491521501817_item	3680612	et	3	main
lendab	doc_491521501817_item	3680609	et	3	main
küll	doc_491521501817_item	3680605	et	4	main
millest	doc_491521501817_item	3680603	et	3	main
b	doc_491521501817_item	3680600	et	4	main
ära	doc_491521501817_item	3680599	et	4	main
keele	doc_491521501817_item	3680598	et	4	main
kõrvetad	doc_491521501817_item	3680597	et	3	main
muidu	doc_491521501817_item	3680596	et	3	main
ära	doc_491521501817_item	3680595	et	4	main
tee	doc_491521501817_item	3680594	et	4	main
jahuta	doc_491521501817_item	3680593	et	4	main
ära	doc_491521501817_item	3680592	et	4	main
keele	doc_491521501817_item	3680591	et	4	main
kõrvetad	doc_491521501817_item	3680590	et	3	main
muidu	doc_491521501817_item	3680589	et	3	main
jahtub	doc_491521501817_item	3680588	et	3	main
ära	doc_491521501817_item	3680587	et	4	main
tee	doc_491521501817_item	3680586	et	4	main
kuni	doc_491521501817_item	3680585	et	3	main
oota	doc_491521501817_item	3680584	et	4	main
jahutama	doc_491521501817_item	3680583	et	3	main
jahtuma	doc_491521501817_item	3680582	et	3	main
a	doc_491521501817_item	3680581	et	4	main
vormis	doc_491521501817_item	3680580	et	4	main
õiges	doc_491521501817_item	3680579	et	3	main
väljendav	doc_491521501817_item	3680573	et	4	main
või	doc_491521501817_item	3680569	et	4	main
включать	doc_491521501817_item	3680552	et	2	main
помощи	doc_491521501817_item	3680550	et	2	main
при	doc_491521501817_item	3680549	et	2	main
температуру	doc_491521501817_item	3680548	et	2	main
комнатную	doc_491521501817_item	3680547	et	2	main
регулировать	doc_491521501817_item	3680546	et	2	main
и	doc_491521501817_item	3680545	et	2	main
поднимать	doc_491521501817_item	3680543	et	2	main
занавеси	doc_491521501817_item	3680544	et	2	main
дверью	doc_491521501817_item	3680542	et	2	main
вашей	doc_491521501817_item	3680541	et	2	main
звонит	doc_491521501817_item	3680539	et	2	main
за	doc_491521501817_item	3680540	et	2	main
кто	doc_491521501817_item	3680538	et	2	main
показывающую	doc_491521501817_item	3680537	et	2	main
слежения	doc_491521501817_item	3680536	et	2	main
камеру	doc_491521501817_item	3680535	et	2	main
приказу	doc_491521501817_item	3680534	et	2	main
устному	doc_491521501817_item	3680533	et	2	main
которое	doc_491521501817_item	3680530	et	2	main
по	doc_491521501817_item	3680532	et	2	main
работает	doc_491521501817_item	3680531	et	2	main
освещение	doc_491521501817_item	3680529	et	2	main
доме	doc_491521501817_item	3680528	et	2	main
технологиям	doc_491521501817_item	3680525	et	2	main
в	doc_491521501817_item	3680527	et	2	main
дигитальным	doc_491521501817_item	3680524	et	2	main
установить	doc_491521501817_item	3680526	et	2	main
и	doc_491521501817_item	3680523	et	2	main
микропроцессорам	doc_491521501817_item	3680522	et	2	main
заправке	doc_491521501816_item	3681093	et	2	main
haigeks	doc_491521501816_item	3681083	et	4	main
jälle	doc_491521501816_item	3681082	et	3	main
человеческих	doc_491521501816_item	3680884	et	2	main
кибернетического	doc_491521501816_item	3680879	et	2	main
грови	doc_491521501816_item	3680875	et	2	main
благодарственное	doc_491521501816_item	3680870	et	2	main
что	doc_491521501816_item	3680864	et	2	main
подготовку	doc_491521501816_item	3680859	et	2	main
ette	doc_491521501816_item	3680854	et	4	main
eest	doc_491521501816_item	3680847	et	4	main
hommikukohvi	doc_491521501816_item	3680835	et	4	main
korraldab	doc_491521501816_item	3680834	et	3	main
see	doc_491521501816_item	3680833	et	3	main
joonde	doc_491521501816_item	3680831	et	4	main
väljendav	doc_491521501817_item	3680568	et	4	main
tegevust	doc_491521501817_item	3680567	et	4	main
kas	doc_491521501817_item	3680565	et	3	main
сети	doc_491521501817_item	3680563	et	2	main
домашней	doc_491521501817_item	3680561	et	2	main
неговоря	doc_491521501817_item	3680558	et	2	main
по	doc_491521501817_item	3680555	et	2	main
kulu	doc_491521501816_item	3681104	et	4	main
телефоном	doc_491521501816_item	3681091	et	2	main
d	doc_491521501816_item	3681087	et	4	main
jääda	doc_491521501816_item	3681085	et	4	main
kardab	doc_491521501816_item	3681081	et	4	main
новшеств	doc_491521501816_item	3680885	et	2	main
мира	doc_491521501816_item	3680880	et	2	main
письмо	doc_491521501816_item	3680871	et	2	main
пошлите	doc_491521501816_item	3680869	et	2	main
думайте	doc_491521501816_item	3680863	et	2	main
их	doc_491521501816_item	3680858	et	2	main
soovi	doc_491521501816_item	3680850	et	4	main
tellimise	doc_491521501816_item	3680840	et	4	main
maja	doc_491521501816_item	3680837	et	4	main
keetmise	doc_491521501816_item	3680836	et	4	main
enamiku	doc_491521501816_item	3680829	et	3	main
kus	doc_491521501816_item	3680826	et	3	main
meid	doc_491521501816_item	3680824	et	4	main
ootab	doc_491521501816_item	3680823	et	3	main
varsti	doc_491521501816_item	3680822	et	3	main
postkompuutriajastusse	doc_491521501816_item	3680821	et	4	main
uude	doc_491521501816_item	3680820	et	3	main
kes	doc_491521501816_item	3680816	et	4	main
arhitektidele	doc_491521501816_item	3680815	et	3	main
saatke	doc_491521501816_item	3680806	et	3	main
ämma	doc_491521501816_item	3680805	et	4	main
või	doc_491521501816_item	3680803	et	4	main
nende	doc_491521501816_item	3680794	et	4	main
tõlkige	doc_491521501816_item	3680791	et	3	main
need	doc_491521501816_item	3681070	et	3	main
linnas	doc_491521501816_item	3681066	et	4	main
meie	doc_491521501816_item	3681065	et	4	main
seda	doc_491521501816_item	3681062	et	3	main
inimene	doc_491521501816_item	3681053	et	3	main
käändes	doc_491521501816_item	3681021	et	3	main
sõna	doc_491521501816_item	3681019	et	4	main
sobiv	doc_491521501816_item	3681018	et	4	main
lünkadesse	doc_491521501816_item	3681017	et	3	main
kirjutage	doc_491521501816_item	3681016	et	3	main
4	doc_491521501816_item	3681015	et	2	main
hakkama	doc_491521501816_item	3681014	et	3	main
sellega	doc_491521501816_item	3681013	et	3	main
7	doc_491521501816_item	3681006	et	2	main
retsepti	doc_491521501816_item	3681004	et	4	main
kirjutab	doc_491521501816_item	3681003	et	3	main
arst	doc_491521501816_item	3681002	et	3	main
retsepti	doc_491521501816_item	3681001	et	4	main
kirjutab	doc_491521501816_item	3681000	et	3	main
tema	doc_491521501816_item	3680988	et	4	main
see	doc_491521501816_item	3680980	et	3	main
on	doc_491521501816_item	3680979	et	4	main
kõige	doc_491521501816_item	3680975	et	4	main
on	doc_491521501816_item	3680967	et	4	main
4	doc_491521501816_item	3680964	et	2	main
millal	doc_491521501816_item	3680959	et	3	main
haigeks	doc_491521501816_item	3680955	et	4	main
spetsialistile	doc_491521501816_item	3681119	et	3	main
tööd	doc_491521501816_item	3681118	et	4	main
suured	doc_491521501816_item	3681117	et	3	main
elektri	doc_491521501816_item	3681116	et	3	main
jätke	doc_491521501816_item	3681115	et	4	main
специалиста	doc_491521501816_item	3681114	et	2	main
электричеству	doc_491521501816_item	3681112	et	2	main
по	doc_491521501816_item	3681111	et	2	main
на	doc_491521501816_item	3681113	et	2	main
работы	doc_491521501816_item	3681110	et	2	main
большие	doc_491521501816_item	3681109	et	2	main
оставьте	doc_491521501816_item	3681108	et	2	main
f	doc_491521501816_item	3681107	et	4	main
voolumõõtja	doc_491521501816_item	3681106	et	4	main
mõõdab	doc_491521501816_item	3681105	et	3	main
электросчетчик	doc_491521501816_item	3681102	et	2	main
elektri	doc_491521501816_item	3681103	et	3	main
измеряет	doc_491521501816_item	3681101	et	2	main
расход	doc_491521501816_item	3681099	et	2	main
электричества	doc_491521501816_item	3681100	et	2	main
e	doc_491521501816_item	3681098	et	4	main
tanklas	doc_491521501816_item	3681097	et	3	main
на	doc_491521501816_item	3681092	et	2	main
пользуйтесь	doc_491521501816_item	3681089	et	2	main
sest	doc_491521501816_item	3681080	et	4	main
võistlustel	doc_491521501816_item	3681079	et	3	main
osale	doc_491521501816_item	3681078	et	4	main
ei	doc_491521501816_item	3681077	et	4	main
ta	doc_491521501816_item	3681076	et	4	main
f	doc_491521501816_item	3681075	et	4	main
õhtusöögiks	doc_491521501816_item	3681074	et	3	main
sobi	doc_491521501816_item	3681073	et	4	main
ei	doc_491521501816_item	3681072	et	4	main
riided	doc_491521501816_item	3681071	et	3	main
жизнь	doc_491521501816_item	3680892	et	2	main
нас	doc_491521501816_item	3680891	et	2	main
ожидает	doc_491521501816_item	3680890	et	2	main
скоро	doc_491521501816_item	3680889	et	2	main
века	doc_491521501816_item	3680888	et	2	main
посткомпьютерного	doc_491521501816_item	3680887	et	2	main
во	doc_491521501816_item	3680882	et	2	main
другим	doc_491521501816_item	3680877	et	2	main
биллу	doc_491521501816_item	3680872	et	2	main
усердную	doc_491521501816_item	3680867	et	2	main
нет	doc_491521501816_item	3680861	et	2	main
за	doc_491521501816_item	3680857	et	2	main
ning	doc_491521501816_item	3680848	et	3	main
tervise	doc_491521501816_item	3680846	et	3	main
kastmise	doc_491521501816_item	3680843	et	4	main
muru	doc_491521501816_item	3680842	et	4	main
arvutivõrk	doc_491521501816_item	3680832	et	3	main
inimkonda	doc_491521501816_item	3680819	et	4	main
teistele	doc_491521501816_item	3680813	et	4	main
kuid	doc_491521501816_item	3680792	et	4	main
eksamitöö	doc_491521501816_item	3680789	et	4	main
temaga	doc_491521501816_item	3681055	et	3	main
nii	doc_491521501816_item	3681051	et	3	main
on	doc_491521501816_item	3681050	et	4	main
ta	doc_491521501816_item	3681049	et	4	main
c	doc_491521501816_item	3681048	et	4	main
tervist	doc_491521501816_item	3681047	et	4	main
inimeste	doc_491521501816_item	3681046	et	3	main
kahjustab	doc_491521501816_item	3681045	et	3	main
see	doc_491521501816_item	3681044	et	3	main
ja	doc_491521501816_item	3681043	et	3	main
rahutuks	doc_491521501816_item	3681042	et	4	main
aeg	doc_491521501816_item	3681041	et	3	main
kogu	doc_491521501816_item	3681040	et	4	main
muutub	doc_491521501816_item	3681039	et	3	main
elu	doc_491521501816_item	3681038	et	4	main
b	doc_491521501816_item	3681037	et	4	main
kooli	doc_491521501816_item	3681036	et	4	main
jääda	doc_491521501816_item	3681035	et	4	main
eelistasid	doc_491521501816_item	3681034	et	4	main
kes	doc_491521501816_item	3681033	et	4	main
nendeks	doc_491521501816_item	3681032	et	4	main
ja	doc_491521501816_item	3681031	et	3	main
kontserdile	doc_491521501816_item	3681030	et	3	main
minna	doc_491521501816_item	3681029	et	3	main
tahtsid	doc_491521501816_item	3681028	et	4	main
kes	doc_491521501816_item	3681027	et	4	main
nendeks	doc_491521501816_item	3681026	et	4	main
kaheks	doc_491521501816_item	3681025	et	4	main
jagunesid	doc_491521501816_item	3681024	et	4	main
saavad	doc_491521501816_item	3681012	et	4	main
nad	doc_491521501816_item	3681011	et	3	main
saavad	doc_491521501816_item	3681008	et	4	main
välja	doc_491521501816_item	3681005	et	4	main
välja	doc_491521501816_item	3680999	et	4	main
arst	doc_491521501816_item	3680998	et	3	main
ta	doc_491521501816_item	3680982	et	4	main
et	doc_491521501816_item	3680981	et	3	main
raskem	doc_491521501816_item	3680976	et	4	main
koju	doc_491521501816_item	3680973	et	3	main
juurde	doc_491521501816_item	3680972	et	4	main
teie	doc_491521501816_item	3680971	et	4	main
tuleb	doc_491521501816_item	3680970	et	3	main
arst	doc_491521501816_item	3680969	et	3	main
haigus	doc_491521501816_item	3680966	et	4	main
see	doc_491521501816_item	3680965	et	3	main
haigeks	doc_491521501816_item	3680963	et	4	main
jäi	doc_491521501816_item	3680962	et	3	main
tütar	doc_491521501816_item	3680961	et	3	main
sinu	doc_491521501816_item	3680960	et	3	main
elu	doc_491521501816_item	3680825	et	4	main
ja	doc_491521501816_item	3680812	et	3	main
tänuavaldused	doc_491521501816_item	3680807	et	3	main
virka	doc_491521501816_item	3680804	et	4	main
teenijannat	doc_491521501816_item	3680802	et	4	main
et	doc_491521501816_item	3680801	et	3	main
arvake	doc_491521501816_item	3680800	et	3	main
ärge	doc_491521501816_item	3680799	et	3	main
keda	doc_491521501816_item	3680793	et	4	main
peetakse	doc_491521501816_item	3681064	et	3	main
d	doc_491521501816_item	3681061	et	4	main
toredaks	doc_491521501816_item	3681060	et	3	main
ise	doc_491521501816_item	3681059	et	4	main
ka	doc_491521501816_item	3681058	et	3	main
tore	doc_491521501816_item	3681052	et	3	main
õpilased	doc_491521501816_item	3681023	et	3	main
hakkama	doc_491521501816_item	3681009	et	3	main
peab	doc_491521501816_item	3680993	et	4	main
et	doc_491521501816_item	3680992	et	3	main
see	doc_491521501816_item	3680991	et	3	main
on	doc_491521501816_item	3680990	et	4	main
raskem	doc_491521501816_item	3680987	et	4	main
jaoks	doc_491521501816_item	3680978	et	4	main
tema	doc_491521501816_item	3680977	et	4	main
5	doc_491521501816_item	3680974	et	2	main
sinu	doc_491521501816_item	3680957	et	3	main
3	doc_491521501816_item	3680953	et	2	main
даже	doc_491521501816_item	3680922	et	2	main
и	doc_491521501816_item	3680918	et	2	main
будет	doc_491521501816_item	3680913	et	2	main
заказом	doc_491521501816_item	3680908	et	2	main
mobiil	doc_491521501814_item	3681759	et	3	main
на	doc_491521501814_item	3681755	et	2	main
не	doc_491521501814_item	3681751	et	2	main
et	doc_491521501814_item	3681717	et	3	main
inimene	doc_491521501814_item	3681716	et	3	main
on	doc_491521501814_item	3681713	et	4	main
c	doc_491521501814_item	3681711	et	4	main
tervist	doc_491521501814_item	3681710	et	4	main
inimeste	doc_491521501814_item	3681709	et	3	main
kahjustab	doc_491521501814_item	3681708	et	3	main
see	doc_491521501814_item	3681707	et	3	main
ja	doc_491521501814_item	3681706	et	3	main
ebatervislikuks	doc_491521501814_item	3681705	et	3	main
aeg	doc_491521501814_item	3681704	et	3	main
eelistasid	doc_491521501814_item	3681697	et	4	main
nendeks	doc_491521501814_item	3681695	et	4	main
minna	doc_491521501814_item	3681692	et	3	main
tahtsid	doc_491521501814_item	3681691	et	4	main
kes	doc_491521501814_item	3681690	et	4	main
a	doc_491521501814_item	3681685	et	4	main
käändes	doc_491521501814_item	3681684	et	3	main
hakkama	doc_491521501814_item	3681677	et	3	main
saavad	doc_491521501814_item	3681671	et	4	main
lamama	doc_491521501814_item	3681659	et	4	main
ta	doc_491521501814_item	3681656	et	4	main
lihast	doc_491521501829_item	3681337	et	4	main
luust	doc_491521501829_item	3681335	et	4	main
aeglustub	doc_491521501829_item	3681324	et	3	main
aeglustuma	doc_491521501829_item	3681312	et	3	main
võin	doc_491521501829_item	3681306	et	3	main
ma	doc_491521501829_item	3681303	et	3	main
raskel	doc_491521501829_item	3681301	et	3	main
on	doc_491521501829_item	3681294	et	4	main
toetama	doc_491521501829_item	3681292	et	3	main
kui	doc_491521501829_item	3681283	et	3	main
tuleb	doc_491521501829_item	3681266	et	3	main
see	doc_491521501829_item	3681264	et	3	main
venitama	doc_491521501829_item	3681262	et	4	main
muidu	doc_491521501829_item	3681256	et	3	main
jahtub	doc_491521501829_item	3681248	et	3	main
tegusõna	doc_491521501829_item	3681234	et	4	main
väljendav	doc_491521501829_item	3681228	et	4	main
домашней	doc_491521501829_item	3681221	et	2	main
по	doc_491521501829_item	3681192	et	2	main
микропроцессорам	doc_491521501829_item	3681182	et	2	main
сбываются	doc_491521501829_item	3681173	et	2	main
arvutivõrgu	doc_491521501829_item	3681167	et	3	main
toatemperatuuri	doc_491521501829_item	3681157	et	4	main
kardinad	doc_491521501829_item	3681153	et	4	main
tõmmata	doc_491521501829_item	3681152	et	4	main
juhtimas	doc_491521501816_item	3680818	et	4	main
groveile	doc_491521501816_item	3680811	et	2	main
bill	doc_491521501816_item	3680808	et	3	main
eest	doc_491521501816_item	3680796	et	4	main
ettevalmistuste	doc_491521501816_item	3680795	et	4	main
1	doc_491521501816_item	3680790	et	2	main
e	doc_491521501816_item	3681069	et	4	main
paremaks	doc_491521501816_item	3681068	et	4	main
haiglat	doc_491521501816_item	3681063	et	3	main
et	doc_491521501816_item	3681054	et	3	main
a	doc_491521501816_item	3681022	et	4	main
sellega	doc_491521501816_item	3681010	et	3	main
6	doc_491521501816_item	3680997	et	2	main
lamama	doc_491521501816_item	3680996	et	4	main
voodis	doc_491521501816_item	3680995	et	3	main
jaoks	doc_491521501816_item	3680989	et	4	main
kõige	doc_491521501816_item	3680986	et	4	main
lamama	doc_491521501816_item	3680985	et	4	main
tütar	doc_491521501816_item	3680958	et	3	main
millal	doc_491521501816_item	3680954	et	3	main
terveks	doc_491521501816_item	3680951	et	4	main
juba	doc_491521501816_item	3680950	et	3	main
on	doc_491521501816_item	3680949	et	4	main
ta	doc_491521501816_item	3680948	et	4	main
juba	doc_491521501816_item	3680947	et	3	main
saanud	doc_491521501816_item	3680946	et	4	main
terveks	doc_491521501816_item	3680945	et	4	main
on	doc_491521501816_item	3680944	et	4	main
ta	doc_491521501816_item	3680943	et	4	main
2	doc_491521501816_item	3680942	et	2	main
juurde	doc_491521501816_item	3680941	et	4	main
arsti	doc_491521501816_item	3680940	et	4	main
homme	doc_491521501816_item	3680939	et	3	main
läheb	doc_491521501816_item	3680938	et	3	main
tütar	doc_491521501816_item	3680937	et	3	main
minu	doc_491521501816_item	3680936	et	3	main
juurde	doc_491521501816_item	3680935	et	4	main
arsti	doc_491521501816_item	3680934	et	4	main
läheb	doc_491521501816_item	3680933	et	3	main
homme	doc_491521501816_item	3680932	et	3	main
tütar	doc_491521501816_item	3680931	et	3	main
minu	doc_491521501816_item	3680930	et	3	main
1	doc_491521501816_item	3680929	et	2	main
parandust	doc_491521501816_item	3680928	et	4	main
põhjendage	doc_491521501816_item	3680927	et	3	main
sõnajärjevead	doc_491521501816_item	3680926	et	3	main
parandage	doc_491521501816_item	3680925	et	3	main
17	doc_491521501816_item	3680924	et	2	main
желании	doc_491521501816_item	3680920	et	2	main
здоровье	doc_491521501816_item	3680917	et	2	main
и	doc_491521501816_item	3680910	et	2	main
jaamal	doc_491521501814_item	3681762	et	3	main
bensiini	doc_491521501814_item	3681761	et	4	main
telefon	doc_491521501814_item	3681760	et	3	main
ära	doc_491521501814_item	3681757	et	4	main
d	doc_491521501814_item	3681750	et	4	main
võistlustel	doc_491521501814_item	3681743	et	3	main
temaga	doc_491521501814_item	3681718	et	3	main
muutub	doc_491521501814_item	3681702	et	3	main
jääda	doc_491521501814_item	3681698	et	4	main
kontserdile	doc_491521501814_item	3681693	et	3	main
при	doc_491521501816_item	3680919	et	2	main
вашем	doc_491521501816_item	3680916	et	2	main
травы	doc_491521501816_item	3680912	et	2	main
уборкой	doc_491521501816_item	3680906	et	2	main
кофе	doc_491521501816_item	3680905	et	2	main
утреннего	doc_491521501816_item	3680904	et	2	main
управлять	doc_491521501816_item	3680902	et	2	main
приготовлением	doc_491521501816_item	3680903	et	2	main
будет	doc_491521501816_item	3680901	et	2	main
которая	doc_491521501816_item	3680900	et	2	main
связь	doc_491521501816_item	3680899	et	2	main
компьютерная	doc_491521501816_item	3680898	et	2	main
будет	doc_491521501816_item	3680896	et	2	main
выполнять	doc_491521501816_item	3680897	et	2	main
дел	doc_491521501816_item	3680895	et	2	main
большинство	doc_491521501816_item	3680894	et	2	main
где	doc_491521501816_item	3680893	et	2	main
телефоном	doc_491521501814_item	3681754	et	2	main
sest	doc_491521501814_item	3681744	et	4	main
muutud	doc_491521501814_item	3681720	et	4	main
tore	doc_491521501814_item	3681715	et	3	main
b	doc_491521501814_item	3681700	et	4	main
kaheks	doc_491521501814_item	3681688	et	4	main
4	doc_491521501814_item	3681678	et	2	main
saavad	doc_491521501814_item	3681675	et	4	main
nad	doc_491521501814_item	3681670	et	3	main
6	doc_491521501814_item	3681660	et	2	main
paarid	doc_491521501829_item	3681329	et	4	main
väljendite	doc_491521501829_item	3681328	et	3	main
leidke	doc_491521501829_item	3681326	et	3	main
raskel	doc_491521501829_item	3681307	et	3	main
igal	doc_491521501829_item	3681300	et	3	main
toetab	doc_491521501829_item	3681298	et	3	main
ta	doc_491521501829_item	3681293	et	4	main
oskasin	doc_491521501829_item	3681284	et	3	main
ära	doc_491521501829_item	3681255	et	4	main
tee	doc_491521501829_item	3681254	et	4	main
ära	doc_491521501829_item	3681247	et	4	main
tee	doc_491521501829_item	3681246	et	4	main
vormis	doc_491521501829_item	3681240	et	4	main
väljendav	doc_491521501829_item	3681233	et	4	main
tegevust	doc_491521501829_item	3681227	et	4	main
о	doc_491521501829_item	3681220	et	2	main
показывающую	doc_491521501829_item	3681197	et	2	main
устному	doc_491521501829_item	3681193	et	2	main
доме	doc_491521501829_item	3681188	et	2	main
дигитальным	doc_491521501829_item	3681184	et	2	main
первую	doc_491521501829_item	3681179	et	2	main
сегодня	doc_491521501829_item	3681175	et	2	main
наконец-то	doc_491521501829_item	3681169	et	2	main
lülitada	doc_491521501829_item	3681160	et	3	main
abil	doc_491521501829_item	3681159	et	4	main
teie	doc_491521501829_item	3681149	et	4	main
helistab	doc_491521501829_item	3681148	et	3	main
valvekaamera	doc_491521501829_item	3681144	et	4	main
käskluse	doc_491521501829_item	3681142	et	3	main
ja	doc_491521501829_item	3681131	et	3	main
tänu	doc_491521501829_item	3681129	et	4	main
täitumas	doc_491521501829_item	3681127	et	4	main
viimaks	doc_491521501829_item	3681126	et	4	main
eksamitöö	doc_491521501829_item	3681120	et	4	main
on	doc_491521501814_item	3681651	et	4	main
raskem	doc_491521501814_item	3681650	et	4	main
kõige	doc_491521501814_item	3681649	et	4	main
on	doc_491521501814_item	3681642	et	4	main
nakkav	doc_491521501814_item	3681631	et	4	main
газеты	doc_491521501816_item	3680923	et	2	main
заботиться	doc_491521501816_item	3680914	et	2	main
еды	doc_491521501816_item	3680909	et	2	main
электричества	doc_491521501814_item	3681765	et	2	main
kasuta	doc_491521501814_item	3681758	et	4	main
заправке	doc_491521501814_item	3681756	et	2	main
пользуйтесь	doc_491521501814_item	3681752	et	2	main
tõlkige	doc_491521501814_item	3681749	et	3	main
jääda	doc_491521501814_item	3681748	et	4	main
viimaks	doc_491521501814_item	3681747	et	4	main
jälle	doc_491521501814_item	3681746	et	3	main
suheldes	doc_491521501814_item	3681719	et	3	main
kogu	doc_491521501814_item	3681703	et	4	main
kes	doc_491521501814_item	3681696	et	4	main
ja	doc_491521501814_item	3681694	et	3	main
jagunesid	doc_491521501814_item	3681687	et	4	main
õpilased	doc_491521501814_item	3681686	et	3	main
sõna	doc_491521501814_item	3681682	et	4	main
kirjutage	doc_491521501814_item	3681679	et	3	main
nad	doc_491521501814_item	3681674	et	3	main
välja	doc_491521501814_item	3681662	et	4	main
arst	doc_491521501814_item	3681661	et	3	main
peab	doc_491521501814_item	3681657	et	4	main
3	doc_491521501829_item	3681339	et	2	main
sünonüümsete	doc_491521501829_item	3681327	et	3	main
pulssi	doc_491521501829_item	3681318	et	4	main
aeglustab	doc_491521501829_item	3681317	et	3	main
talle	doc_491521501829_item	3681309	et	4	main
hetkel	doc_491521501829_item	3681308	et	4	main
lõpuks	doc_491521501829_item	3681286	et	4	main
aga	doc_491521501829_item	3681285	et	3	main
spetsialistile	doc_491521501814_item	3681783	et	3	main
elektritööd	doc_491521501814_item	3681782	et	4	main
suured	doc_491521501814_item	3681781	et	3	main
maha	doc_491521501814_item	3681780	et	4	main
специалиста	doc_491521501814_item	3681778	et	2	main
на	doc_491521501814_item	3681777	et	2	main
jätke	doc_491521501814_item	3681779	et	4	main
электричеству	doc_491521501814_item	3681776	et	2	main
по	doc_491521501814_item	3681775	et	2	main
работы	doc_491521501814_item	3681774	et	2	main
большие	doc_491521501814_item	3681773	et	2	main
оставьте	doc_491521501814_item	3681772	et	2	main
f	doc_491521501814_item	3681771	et	4	main
elektromeeter	doc_491521501814_item	3681770	et	3	main
mõõdab	doc_491521501814_item	3681769	et	3	main
elektrikulud	doc_491521501814_item	3681768	et	4	main
электросчетчик	doc_491521501814_item	3681767	et	2	main
измеряет	doc_491521501814_item	3681766	et	2	main
расход	doc_491521501814_item	3681764	et	2	main
e	doc_491521501814_item	3681763	et	4	main
мобильным	doc_491521501814_item	3681753	et	2	main
kardab	doc_491521501814_item	3681745	et	4	main
osale	doc_491521501814_item	3681742	et	4	main
ei	doc_491521501814_item	3681741	et	4	main
ta	doc_491521501814_item	3681740	et	4	main
f	doc_491521501814_item	3681739	et	4	main
ajaks	doc_491521501814_item	3681738	et	4	main
suve	doc_491521501814_item	3681737	et	4	main
sobi	doc_491521501814_item	3681736	et	4	main
ei	doc_491521501814_item	3681735	et	4	main
riided	doc_491521501814_item	3681734	et	3	main
need	doc_491521501814_item	3681733	et	3	main
e	doc_491521501814_item	3681732	et	4	main
paremaks	doc_491521501814_item	3681731	et	4	main
kõige	doc_491521501814_item	3681730	et	4	main
linnas	doc_491521501814_item	3681729	et	4	main
meie	doc_491521501814_item	3681728	et	4	main
peetakse	doc_491521501814_item	3681727	et	3	main
haiglat	doc_491521501814_item	3681726	et	3	main
seda	doc_491521501814_item	3681725	et	3	main
d	doc_491521501814_item	3681724	et	4	main
toredamaks	doc_491521501814_item	3681723	et	4	main
ise	doc_491521501814_item	3681722	et	4	main
ka	doc_491521501814_item	3681721	et	3	main
nii	doc_491521501814_item	3681714	et	3	main
ta	doc_491521501814_item	3681712	et	4	main
elu	doc_491521501814_item	3681701	et	4	main
kooli	doc_491521501814_item	3681699	et	4	main
nendeks	doc_491521501814_item	3681689	et	4	main
saavas	doc_491521501814_item	3681683	et	4	main
sobiv	doc_491521501814_item	3681681	et	4	main
lünkadesse	doc_491521501814_item	3681680	et	3	main
sellega	doc_491521501814_item	3681673	et	3	main
hakkama	doc_491521501814_item	3681672	et	3	main
välja	doc_491521501814_item	3681668	et	4	main
kirjutab	doc_491521501814_item	3681666	et	3	main
arst	doc_491521501814_item	3681665	et	3	main
voodis	doc_491521501814_item	3681658	et	3	main
kirub	doc_491521501829_item	3681340	et	3	main
inimesed	doc_491521501829_item	3681338	et	3	main
ja	doc_491521501829_item	3681336	et	3	main
2	doc_491521501829_item	3681334	et	2	main
joonde	doc_491521501829_item	3681333	et	4	main
asjad	doc_491521501829_item	3681332	et	3	main
ajab	doc_491521501829_item	3681331	et	3	main
1	doc_491521501829_item	3681330	et	2	main
pulss	doc_491521501829_item	3681323	et	3	main
teie	doc_491521501829_item	3681322	et	4	main
rohu	doc_491521501829_item	3681320	et	4	main
selle	doc_491521501829_item	3681319	et	4	main
tean	doc_491521501829_item	3681304	et	3	main
hetkel	doc_491521501829_item	3681302	et	4	main
mind	doc_491521501829_item	3681299	et	4	main
kes	doc_491521501829_item	3681297	et	4	main
sõber	doc_491521501829_item	3681296	et	3	main
tõeline	doc_491521501829_item	3681295	et	4	main
toetuma	doc_491521501829_item	3681291	et	4	main
c	doc_491521501829_item	3681290	et	4	main
lahkuma	doc_491521501829_item	3681289	et	3	main
mõnikord	doc_491521501829_item	3681268	et	3	main
keele	doc_491521501829_item	3681258	et	4	main
kõrvetad	doc_491521501829_item	3681257	et	3	main
keele	doc_491521501829_item	3681251	et	4	main
kõrvetad	doc_491521501829_item	3681250	et	3	main
muidu	doc_491521501829_item	3681249	et	3	main
a	doc_491521501829_item	3681241	et	4	main
õiges	doc_491521501829_item	3681239	et	3	main
tegevust	doc_491521501829_item	3681232	et	4	main
enesekohast	doc_491521501829_item	3681226	et	4	main
kas	doc_491521501829_item	3681225	et	3	main
5	doc_491521501829_item	3681224	et	2	main
уже	doc_491521501829_item	3681219	et	2	main
вашей	doc_491521501829_item	3681201	et	2	main
приказу	doc_491521501829_item	3681194	et	2	main
освещение	doc_491521501829_item	3681189	et	2	main
установить	doc_491521501829_item	3681186	et	2	main
очередь	doc_491521501829_item	3681180	et	2	main
вы	doc_491521501829_item	3681176	et	2	main
уже	doc_491521501829_item	3681174	et	2	main
теперь	doc_491521501829_item	3681170	et	2	main
koduse	doc_491521501829_item	3681166	et	4	main
rääkimata	doc_491521501829_item	3681165	et	4	main
koduteel	doc_491521501829_item	3681164	et	3	main
juba	doc_491521501829_item	3681163	et	3	main
sisse	doc_491521501829_item	3681162	et	4	main
reguleerida	doc_491521501829_item	3681156	et	3	main
kes	doc_491521501829_item	3681147	et	4	main
võite	doc_491521501829_item	3681133	et	4	main
mikroprotsessoreile	doc_491521501829_item	3681130	et	3	main
nüüd	doc_491521501829_item	3681122	et	4	main
1tõlkige	doc_491521501829_item	3681121	et	3	main
peab	doc_491521501814_item	3681647	et	4	main
jaoks	doc_491521501814_item	3681641	et	4	main
raskem	doc_491521501814_item	3681639	et	4	main
kõige	doc_491521501814_item	3681638	et	4	main
5	doc_491521501814_item	3681637	et	2	main
koju	doc_491521501814_item	3681636	et	3	main
arsti	doc_491521501814_item	3681597	et	4	main
parandust	doc_491521501814_item	3681591	et	4	main
здоровье	doc_491521501814_item	3681578	et	2	main
дома	doc_491521501814_item	3681573	et	2	main
утреннего	doc_491521501814_item	3681568	et	2	main
sellega	doc_491521501814_item	3681676	et	3	main
7	doc_491521501814_item	3681669	et	2	main
retsepti	doc_491521501814_item	3681667	et	4	main
retsepti	doc_491521501814_item	3681664	et	4	main
kirjutab	doc_491521501814_item	3681663	et	3	main
20	doc_491521501829_item	3681325	et	2	main
tarvitamisel	doc_491521501829_item	3681321	et	4	main
tarvitamine	doc_491521501829_item	3681316	et	4	main
rohu	doc_491521501829_item	3681315	et	4	main
selle	doc_491521501829_item	3681314	et	4	main
aeglustama	doc_491521501829_item	3681313	et	3	main
d	doc_491521501829_item	3681311	et	4	main
toetuda	doc_491521501829_item	3681310	et	3	main
et	doc_491521501829_item	3681305	et	3	main
siiski	doc_491521501829_item	3681288	et	4	main
pidin	doc_491521501829_item	3681287	et	3	main
kaua	doc_491521501829_item	3681282	et	3	main
nii	doc_491521501829_item	3681281	et	3	main
äraminekuga	doc_491521501829_item	3681280	et	3	main
venitasin	doc_491521501829_item	3681279	et	3	main
ma	doc_491521501829_item	3681278	et	3	main
teosammul	doc_491521501829_item	3681277	et	4	main
venib	doc_491521501829_item	3681276	et	3	main
aga	doc_491521501829_item	3681275	et	3	main
kord	doc_491521501829_item	3681274	et	4	main
kiiresti	doc_491521501829_item	3681272	et	3	main
väga	doc_491521501829_item	3681271	et	3	main
aeg	doc_491521501829_item	3681270	et	3	main
lendab	doc_491521501829_item	3681269	et	3	main
teine	doc_491521501829_item	3681273	et	3	main
küll	doc_491521501829_item	3681265	et	4	main
venima	doc_491521501829_item	3681261	et	3	main
ära	doc_491521501829_item	3681259	et	4	main
jahuta	doc_491521501829_item	3681253	et	4	main
kuni	doc_491521501829_item	3681245	et	3	main
oota	doc_491521501829_item	3681244	et	4	main
jahutama	doc_491521501829_item	3681243	et	3	main
jahtuma	doc_491521501829_item	3681242	et	3	main
sõna	doc_491521501829_item	3681238	et	4	main
sobiv	doc_491521501829_item	3681237	et	4	main
suunatud	doc_491521501829_item	3681231	et	4	main
väljapoole	doc_491521501829_item	3681230	et	3	main
või	doc_491521501829_item	3681229	et	4	main
компьютерной	doc_491521501829_item	3681222	et	2	main
слежения	doc_491521501829_item	3681196	et	2	main
работает	doc_491521501829_item	3681191	et	2	main
в	doc_491521501829_item	3681187	et	2	main
и	doc_491521501829_item	3681183	et	2	main
в	doc_491521501829_item	3681178	et	2	main
мечты	doc_491521501829_item	3681172	et	2	main
ehitamisest	doc_491521501829_item	3681168	et	4	main
nuppude	doc_491521501829_item	3681158	et	3	main
ette	doc_491521501829_item	3681154	et	4	main
näitab	doc_491521501829_item	3681146	et	3	main
suulise	doc_491521501829_item	3681141	et	4	main
töötab	doc_491521501829_item	3681140	et	3	main
mis	doc_491521501829_item	3681139	et	4	main
eeskätt	doc_491521501829_item	3681128	et	3	main
jaoks	doc_491521501814_item	3681653	et	4	main
lamama	doc_491521501814_item	3681648	et	4	main
voodis	doc_491521501814_item	3681646	et	3	main
ta	doc_491521501814_item	3681645	et	4	main
teie	doc_491521501814_item	3681634	et	4	main
tuleb	doc_491521501814_item	3681633	et	3	main
arst	doc_491521501814_item	3681632	et	3	main
et	doc_491521501829_item	3681267	et	3	main
millest	doc_491521501829_item	3681263	et	3	main
b	doc_491521501829_item	3681260	et	4	main
ära	doc_491521501829_item	3681252	et	4	main
lünka	doc_491521501829_item	3681236	et	4	main
kirjutage	doc_491521501829_item	3681235	et	3	main
сети	doc_491521501829_item	3681223	et	2	main
неговоря	doc_491521501829_item	3681218	et	2	main
домой	doc_491521501829_item	3681217	et	2	main
дороге	doc_491521501829_item	3681216	et	2	main
по	doc_491521501829_item	3681215	et	2	main
уже	doc_491521501829_item	3681214	et	2	main
кондиционер	doc_491521501829_item	3681213	et	2	main
включать	doc_491521501829_item	3681212	et	2	main
кнопок	doc_491521501829_item	3681211	et	2	main
помощи	doc_491521501829_item	3681210	et	2	main
температуру	doc_491521501829_item	3681208	et	2	main
комнатную	doc_491521501829_item	3681207	et	2	main
при	doc_491521501829_item	3681209	et	2	main
регулировать	doc_491521501829_item	3681206	et	2	main
занавеси	doc_491521501829_item	3681204	et	2	main
поднимать	doc_491521501829_item	3681203	et	2	main
и	doc_491521501829_item	3681205	et	2	main
дверью	doc_491521501829_item	3681202	et	2	main
за	doc_491521501829_item	3681200	et	2	main
звонит	doc_491521501829_item	3681199	et	2	main
кто	doc_491521501829_item	3681198	et	2	main
камеру	doc_491521501829_item	3681195	et	2	main
которое	doc_491521501829_item	3681190	et	2	main
технологиям	doc_491521501829_item	3681185	et	2	main
благодаря	doc_491521501829_item	3681181	et	2	main
можете	doc_491521501829_item	3681177	et	2	main
эти	doc_491521501829_item	3681171	et	2	main
õhukonditsioneeri	doc_491521501829_item	3681161	et	4	main
ja	doc_491521501829_item	3681155	et	3	main
mis	doc_491521501829_item	3681145	et	4	main
peale	doc_491521501829_item	3681143	et	4	main
digitaaltehnoloogiale	doc_491521501829_item	3681132	et	3	main
on	doc_491521501829_item	3681123	et	4	main
see	doc_491521501814_item	3681654	et	3	main
juurde	doc_491521501814_item	3681635	et	4	main
haigus	doc_491521501814_item	3681629	et	4	main
see	doc_491521501814_item	3681628	et	3	main
4	doc_491521501814_item	3681627	et	2	main
jäi	doc_491521501814_item	3681626	et	3	main
haigeks	doc_491521501814_item	3681625	et	4	main
tütar	doc_491521501814_item	3681624	et	3	main
sinu	doc_491521501814_item	3681623	et	3	main
millal	doc_491521501814_item	3681622	et	3	main
tütar	doc_491521501814_item	3681621	et	3	main
sinu	doc_491521501814_item	3681620	et	3	main
jäi	doc_491521501814_item	3681619	et	3	main
haigeks	doc_491521501814_item	3681618	et	4	main
millal	doc_491521501814_item	3681617	et	3	main
3	doc_491521501814_item	3681616	et	2	main
saanud	doc_491521501814_item	3681615	et	4	main
terveks	doc_491521501814_item	3681614	et	4	main
juba	doc_491521501814_item	3681613	et	3	main
on	doc_491521501814_item	3681612	et	4	main
ta	doc_491521501814_item	3681611	et	4	main
juba	doc_491521501814_item	3681610	et	3	main
saanud	doc_491521501814_item	3681609	et	4	main
terveks	doc_491521501814_item	3681608	et	4	main
on	doc_491521501814_item	3681607	et	4	main
ta	doc_491521501814_item	3681606	et	4	main
2	doc_491521501814_item	3681605	et	2	main
juurde	doc_491521501814_item	3681604	et	4	main
läheb	doc_491521501814_item	3681601	et	3	main
juurde	doc_491521501814_item	3681598	et	4	main
о	doc_491521501814_item	3681576	et	2	main
обогревание	doc_491521501814_item	3681572	et	2	main
за	doc_491521501814_item	3681570	et	2	main
за	doc_491521501814_item	3681566	et	2	main
компьютерная	doc_491521501814_item	3681561	et	2	main
жизнь	doc_491521501814_item	3681554	et	2	main
новую	doc_491521501814_item	3681548	et	2	main
кубернет-мира	doc_491521501814_item	3681543	et	2	main
гатешлу	doc_491521501814_item	3681537	et	2	main
или	doc_491521501814_item	3681530	et	2	main
приготавления	doc_491521501814_item	3681524	et	2	main
enamiku	doc_491521501814_item	3681493	et	3	main
inimkonda	doc_491521501814_item	3681483	et	4	main
gatesile	doc_491521501814_item	3681473	et	4	main
ärge	doc_491521501814_item	3681463	et	3	main
höövel	doc_491521501829_item	3681425	et	3	main
elektrita	doc_491521501829_item	3681416	et	3	main
puur	doc_491521501829_item	3681414	et	3	main
töötavad	doc_491521501829_item	3681407	et	4	main
korral	doc_491521501829_item	3681404	et	4	main
taga	doc_491521501829_item	3681151	et	4	main
ukse	doc_491521501829_item	3681150	et	3	main
valgustuse	doc_491521501829_item	3681138	et	4	main
koju	doc_491521501829_item	3681137	et	3	main
paigutada	doc_491521501829_item	3681136	et	3	main
praegu	doc_491521501829_item	3681135	et	3	main
juba	doc_491521501829_item	3681134	et	3	main
unistused	doc_491521501829_item	3681125	et	4	main
need	doc_491521501829_item	3681124	et	3	main
et	doc_491521501814_item	3681655	et	3	main
tema	doc_491521501814_item	3681652	et	4	main
et	doc_491521501814_item	3681644	et	3	main
see	doc_491521501814_item	3681643	et	3	main
tema	doc_491521501814_item	3681640	et	4	main
on	doc_491521501814_item	3681630	et	4	main
arsti	doc_491521501814_item	3681603	et	4	main
homme	doc_491521501814_item	3681602	et	3	main
minu	doc_491521501814_item	3681599	et	3	main
tütar	doc_491521501814_item	3681594	et	3	main
1	doc_491521501814_item	3681592	et	2	main
вашем	doc_491521501814_item	3681577	et	2	main
заботиться	doc_491521501814_item	3681575	et	2	main
топление	doc_491521501814_item	3681571	et	2	main
приготовление	doc_491521501814_item	3681567	et	2	main
будет	doc_491521501814_item	3681564	et	2	main
будет	doc_491521501814_item	3681559	et	2	main
где	doc_491521501814_item	3681555	et	2	main
эпоху	doc_491521501814_item	3681550	et	2	main
ввели	doc_491521501814_item	3681545	et	2	main
и	doc_491521501814_item	3681540	et	2	main
благодарности	doc_491521501814_item	3681535	et	2	main
свекровь	doc_491521501814_item	3681532	et	2	main
не	doc_491521501814_item	3681526	et	2	main
благодарить	doc_491521501814_item	3681521	et	2	main
ette	doc_491521501814_item	3681518	et	4	main
läheb	doc_491521501814_item	3681596	et	3	main
minu	doc_491521501814_item	3681593	et	3	main
põhjendage	doc_491521501814_item	3681590	et	3	main
будет	doc_491521501814_item	3681574	et	2	main
кофе	doc_491521501814_item	3681569	et	2	main
она	doc_491521501814_item	3681563	et	2	main
вещей	doc_491521501814_item	3681558	et	2	main
ждёт	doc_491521501814_item	3681553	et	2	main
посткомпьютерную	doc_491521501814_item	3681549	et	2	main
которые	doc_491521501814_item	3681544	et	2	main
груву	doc_491521501814_item	3681539	et	2	main
изъявления	doc_491521501814_item	3681534	et	2	main
служанку	doc_491521501814_item	3681529	et	2	main
нет	doc_491521501814_item	3681525	et	2	main
кого	doc_491521501814_item	3681519	et	2	main
ajalehti	doc_491521501814_item	3681517	et	4	main
ning	doc_491521501814_item	3681512	et	3	main
eest	doc_491521501814_item	3681511	et	4	main
tervise	doc_491521501814_item	3681510	et	3	main
teie	doc_491521501814_item	3681509	et	4	main
hoolitseb	doc_491521501814_item	3681508	et	3	main
kastmise	doc_491521501814_item	3681507	et	4	main
ja	doc_491521501814_item	3681505	et	3	main
muru	doc_491521501814_item	3681506	et	4	main
tellimise	doc_491521501814_item	3681504	et	4	main
toidu	doc_491521501814_item	3681503	et	3	main
kütmise	doc_491521501814_item	3681502	et	4	main
maja	doc_491521501814_item	3681501	et	4	main
keetmise	doc_491521501814_item	3681500	et	4	main
hommikukohvi	doc_491521501814_item	3681499	et	4	main
korraldab	doc_491521501814_item	3681498	et	3	main
see	doc_491521501814_item	3681497	et	3	main
arvutivõrk	doc_491521501814_item	3681496	et	3	main
joonde	doc_491521501814_item	3681495	et	4	main
asju	doc_491521501814_item	3681494	et	3	main
bill	doc_491521501814_item	3681472	et	3	main
tänuavaldused	doc_491521501814_item	3681471	et	3	main
saatke	doc_491521501814_item	3681470	et	3	main
ämma	doc_491521501814_item	3681469	et	4	main
virka	doc_491521501814_item	3681468	et	4	main
arvake	doc_491521501814_item	3681464	et	3	main
tänada	doc_491521501814_item	3681461	et	3	main
ettevalmistuste	doc_491521501814_item	3681459	et	4	main
1	doc_491521501814_item	3681454	et	2	main
eksamitöö	doc_491521501814_item	3681453	et	4	main
jootekolb	doc_491521501829_item	3681451	et	4	main
haamer	doc_491521501829_item	3681450	et	3	main
muruniiduk	doc_491521501829_item	3681449	et	3	main
puur	doc_491521501829_item	3681448	et	3	main
see	doc_491521501829_item	3681427	et	3	main
prits	doc_491521501829_item	3681423	et	3	main
kruvikeeraja	doc_491521501829_item	3681422	et	4	main
kirves	doc_491521501829_item	3681421	et	4	main
haamer	doc_491521501829_item	3681420	et	3	main
viil	doc_491521501829_item	3681419	et	3	main
töötavad	doc_491521501829_item	3681415	et	4	main
akulaadija	doc_491521501829_item	3681412	et	4	main
jootekolb	doc_491521501829_item	3681411	et	4	main
kasutage	doc_491521501829_item	3681405	et	3	main
4-a	doc_491521501829_item	3681395	et	4	main
3-f	doc_491521501829_item	3681394	et	4	main
tütar	doc_491521501814_item	3681600	et	3	main
homme	doc_491521501814_item	3681595	et	3	main
отвечать	doc_491521501814_item	3681565	et	2	main
управлять	doc_491521501814_item	3681560	et	2	main
дома	doc_491521501814_item	3681556	et	2	main
скоро	doc_491521501814_item	3681551	et	2	main
человечество	doc_491521501814_item	3681546	et	2	main
другим	doc_491521501814_item	3681541	et	2	main
андрею	doc_491521501814_item	3681538	et	2	main
усердную	doc_491521501814_item	3681531	et	2	main
думайте	doc_491521501814_item	3681527	et	2	main
за	doc_491521501814_item	3681522	et	2	main
korral	doc_491521501814_item	3681515	et	4	main
soovi	doc_491521501814_item	3681514	et	4	main
loeb	doc_491521501814_item	3681513	et	3	main
kodus	doc_491521501814_item	3681491	et	4	main
meid	doc_491521501814_item	3681488	et	4	main
ootab	doc_491521501814_item	3681487	et	3	main
varsti	doc_491521501814_item	3681486	et	3	main
juhtimas	doc_491521501814_item	3681482	et	4	main
on	doc_491521501814_item	3681481	et	4	main
kes	doc_491521501814_item	3681480	et	4	main
arhitektidele	doc_491521501814_item	3681479	et	3	main
kübermaailma	doc_491521501814_item	3681478	et	4	main
et	doc_491521501814_item	3681465	et	3	main
eest	doc_491521501814_item	3681460	et	4	main
nende	doc_491521501814_item	3681458	et	4	main
teine	doc_491521501829_item	3681429	et	3	main
näpitstangid	doc_491521501829_item	3681417	et	3	main
tolmuimeja	doc_491521501829_item	3681413	et	4	main
sõnaraamatut	doc_491521501829_item	3681406	et	3	main
rühma	doc_491521501829_item	3681402	et	4	main
sõnad	doc_491521501829_item	3681400	et	4	main
jagage	doc_491521501829_item	3681399	et	3	main
2-e	doc_491521501829_item	3681393	et	3	main
ära	doc_491521501829_item	3681369	et	4	main
b	doc_491521501829_item	3681361	et	4	main
a	doc_491521501829_item	3681357	et	4	main
ta	doc_491521501829_item	3681353	et	4	main
sõnajärjevead	doc_491521501814_item	3681589	et	3	main
17	doc_491521501814_item	3681587	et	2	main
газеты	doc_491521501814_item	3681584	et	2	main
по	doc_491521501814_item	3681581	et	2	main
и	doc_491521501814_item	3681579	et	2	main
kogunesid	doc_278690626961_item	3681923	et	4	main
suurüritusteks	doc_278690626961_item	3681914	et	3	main
eesti	doc_278690626961_item	3681904	et	4	main
voldemar	doc_278690626961_item	3681892	et	4	main
tuli	doc_278690626961_item	3681887	et	4	main
kindla	doc_278690626961_item	3681869	et	3	main
rakendatud	doc_278690626961_item	3681868	et	4	main
algselt	doc_278690626961_item	3681862	et	4	main
üsna	doc_278690626961_item	3681851	et	3	main
on	doc_278690626961_item	3681823	et	4	main
on	doc_278690626961_item	3681818	et	4	main
väiteid	doc_278690626961_item	3681817	et	4	main
faktidele	doc_278690626961_item	3681816	et	3	main
olema	doc_278690626961_item	3681806	et	4	main
essee	doc_278690626961_item	3681804	et	4	main
eestlastest	doc_278690626961_item	3681798	et	4	main
kirjutamine	doc_278690626961_item	3681792	et	4	main
test	doc_278690626961_item	3681791	et	3	main
keele	doc_278690626961_item	3681790	et	4	main
kes	doc_278690626961_item	3681965	et	4	main
korda	doc_278690626961_item	3681945	et	4	main
kestnud	doc_278690626961_item	3681935	et	4	main
laulupeole	doc_278690626961_item	3681928	et	4	main
сеть	doc_491521501814_item	3681562	et	2	main
большинством	doc_491521501814_item	3681557	et	2	main
нас	doc_491521501814_item	3681552	et	2	main
в	doc_491521501814_item	3681547	et	2	main
архитекторам	doc_491521501814_item	3681542	et	2	main
биллу	doc_491521501814_item	3681536	et	2	main
пошлите	doc_491521501814_item	3681533	et	2	main
что	doc_491521501814_item	3681528	et	2	main
эти	doc_491521501814_item	3681523	et	2	main
же	doc_491521501814_item	3681520	et	2	main
isegi	doc_491521501814_item	3681516	et	4	main
kus	doc_491521501814_item	3681490	et	3	main
elu	doc_491521501814_item	3681489	et	4	main
postkompuutriajastusse	doc_491521501814_item	3681485	et	4	main
uude	doc_491521501814_item	3681484	et	3	main
andrew	doc_491521501814_item	3681474	et	4	main
teenijannat	doc_491521501814_item	3681466	et	4	main
ei	doc_491521501814_item	3681462	et	4	main
kui	doc_491521501829_item	3681428	et	3	main
lood	doc_491521501829_item	3681424	et	4	main
pardel	doc_491521501829_item	3681410	et	4	main
juukseföön	doc_491521501829_item	3681409	et	3	main
elektriga	doc_491521501829_item	3681408	et	3	main
vajaduse	doc_491521501829_item	3681403	et	3	main
d	doc_491521501829_item	3681370	et	4	main
tähelepanu	doc_491521501829_item	3681360	et	4	main
ta	doc_491521501829_item	3681348	et	4	main
5	doc_491521501829_item	3681347	et	2	main
all	doc_491521501829_item	3681346	et	3	main
luubi	doc_491521501829_item	3681345	et	3	main
on	doc_491521501829_item	3681344	et	4	main
4	doc_491521501829_item	3681343	et	2	main
grammatika	doc_491521501814_item	3681586	et	4	main
читать	doc_491521501814_item	3681583	et	2	main
будет	doc_491521501814_item	3681580	et	2	main
tuhanded	doc_278690626961_item	3681924	et	3	main
kadriorus	doc_278690626961_item	3681917	et	3	main
muutusid	doc_278690626961_item	3681911	et	4	main
vabadussõda	doc_278690626961_item	3681910	et	4	main
ja	doc_278690626961_item	3681909	et	3	main
aastal	doc_278690626961_item	3681908	et	3	main
1918	doc_278690626961_item	3681907	et	2	main
loomist	doc_278690626961_item	3681906	et	4	main
vabariigi	doc_278690626961_item	3681905	et	3	main
alati	doc_278690626961_item	3681897	et	4	main
toimumisse	doc_278690626961_item	3681895	et	4	main
laulupidude	doc_278690626961_item	3681894	et	4	main
seltsist	doc_278690626961_item	3681889	et	4	main
idee	doc_278690626961_item	3681884	et	4	main
korraldamise	doc_278690626961_item	3681883	et	4	main
mille	doc_278690626961_item	3681882	et	3	main
tartus	doc_278690626961_item	3681881	et	3	main
aastal	doc_278690626961_item	3681880	et	3	main
1869	doc_278690626961_item	3681879	et	2	main
laulupidu	doc_278690626961_item	3681878	et	4	main
kujunes	doc_278690626961_item	3681875	et	3	main
on	doc_278690626961_item	3681867	et	4	main
mis	doc_278690626961_item	3681861	et	4	main
300-350	doc_278690626961_item	3681802	et	2	main
mis	doc_278690626961_item	3681796	et	4	main
teemal	doc_278690626961_item	3681795	et	3	main
kirjutage	doc_278690626961_item	3681793	et	3	main
eesti	doc_278690626961_item	3681786	et	4	main
essee	doc_278690626961_item	3681785	et	4	main
kõik	doc_278690626961_item	3681963	et	4	main
pärast	doc_278690626961_item	3681961	et	4	main
laulurahva	doc_278690626961_item	3681959	et	3	main
on	doc_278690626961_item	3681958	et	4	main
eestlased	doc_278690626961_item	3681957	et	3	main
et	doc_278690626961_item	3681956	et	3	main
arvan	doc_278690626961_item	3681955	et	3	main
ma	doc_278690626961_item	3681954	et	3	main
tallinnas	doc_278690626961_item	3681953	et	4	main
ja	doc_278690626961_item	3681952	et	3	main
tartus	doc_278690626961_item	3681951	et	3	main
üldlaulupidu	doc_278690626961_item	3681942	et	4	main
aasta	doc_278690626961_item	3681934	et	4	main
viie	doc_278690626961_item	3681933	et	3	main
lauluväljakule	doc_278690626961_item	3681927	et	3	main
ttüs	doc_187964557902_item	3682116	et	4	main
keele	doc_187964557902_item	3682111	et	4	main
ajab	doc_491521501814_item	3681492	et	3	main
teistele	doc_491521501814_item	3681477	et	4	main
ja	doc_491521501814_item	3681476	et	3	main
groveile	doc_491521501814_item	3681475	et	2	main
või	doc_491521501814_item	3681467	et	4	main
keda	doc_491521501814_item	3681457	et	4	main
kuid	doc_491521501814_item	3681456	et	4	main
tõlkige	doc_491521501814_item	3681455	et	3	main
höövel	doc_491521501829_item	3681452	et	3	main
viil	doc_491521501829_item	3681447	et	3	main
mutrivõti	doc_491521501829_item	3681446	et	4	main
pump	doc_491521501829_item	3681445	et	3	main
kruvikeeraja	doc_491521501829_item	3681444	et	4	main
tolmuimeja	doc_491521501829_item	3681443	et	4	main
akulaadija	doc_491521501829_item	3681442	et	4	main
kirves	doc_491521501829_item	3681441	et	4	main
juukseföön	doc_491521501829_item	3681440	et	3	main
kohviveski	doc_491521501829_item	3681439	et	4	main
pardel	doc_491521501829_item	3681438	et	4	main
prits	doc_491521501829_item	3681437	et	3	main
ketassaag	doc_491521501829_item	3681436	et	3	main
lood	doc_491521501829_item	3681435	et	4	main
näpitstangid	doc_491521501829_item	3681434	et	3	main
ketassaag	doc_491521501829_item	3681433	et	3	main
muruniiduk	doc_491521501829_item	3681432	et	3	main
pump	doc_491521501829_item	3681431	et	3	main
kohviveski	doc_491521501829_item	3681430	et	4	main
nii	doc_491521501829_item	3681426	et	3	main
muruvõti	doc_491521501829_item	3681418	et	4	main
5-d	doc_491521501829_item	3681396	et	4	main
c	doc_491521501829_item	3681367	et	4	main
talle	doc_491521501829_item	3681365	et	4	main
tulnud	doc_491521501829_item	3681364	et	4	main
erilist	doc_491521501829_item	3681359	et	4	main
sellega	doc_491521501829_item	3681355	et	3	main
nägi	doc_491521501829_item	3681354	et	3	main
6	doc_491521501829_item	3681352	et	2	main
liiga	doc_491521501829_item	3681351	et	4	main
maapõhja	doc_491521501829_item	3681342	et	4	main
parandage	doc_491521501814_item	3681588	et	3	main
вслух	doc_491521501814_item	3681585	et	2	main
желанию	doc_491521501814_item	3681582	et	2	main
juulis	doc_278690626961_item	3681922	et	3	main
lauluväljakul	doc_278690626961_item	3681919	et	3	main
on	doc_278690626961_item	3681896	et	4	main
eesotsas	doc_278690626961_item	3681890	et	4	main
esimene	doc_278690626961_item	3681876	et	3	main
tähtusega	doc_278690626961_item	3681873	et	2	main
mida	doc_278690626961_item	3681866	et	4	main
ning	doc_278690626961_item	3681865	et	3	main
folkloorist	doc_278690626961_item	3681864	et	4	main
tulevikusse	doc_278690626961_item	3681850	et	4	main
kultuurinähtus	doc_278690626961_item	3681825	et	4	main
arutlev	doc_278690626961_item	3681807	et	4	main
peab	doc_278690626961_item	3681805	et	4	main
teeb	doc_278690626961_item	3681797	et	3	main
elasid	doc_278690626961_item	3681966	et	4	main
linnas	doc_278690626961_item	3681950	et	4	main
kahes	doc_278690626961_item	3681949	et	4	main
traditsiooni	doc_278690626961_item	3681937	et	4	main
sada	doc_278690626961_item	3681931	et	4	main
tähistada	doc_278690626961_item	3681930	et	3	main
et	doc_278690626961_item	3681929	et	3	main
aitavad	doc_187964557902_item	3682113	et	4	main
ootan	doc_187964557902_item	3682108	et	3	main
ja	doc_187964557902_item	3682102	et	3	main
teistega	doc_187964557902_item	3682100	et	4	main
tutvuda	doc_187964557902_item	3682099	et	3	main
võimalus	doc_187964557902_item	3682098	et	3	main
on	doc_187964557902_item	3682097	et	4	main
tunnis	doc_187964557902_item	3682096	et	3	main
võib	doc_187964557902_item	3682090	et	3	main
lõpema	doc_187964557902_item	3682069	et	4	main
tahaks	doc_187964557902_item	3682068	et	3	main
ka	doc_187964557902_item	3682067	et	3	main
mina	doc_187964557902_item	3682066	et	4	main
on	doc_187964557902_item	3682058	et	4	main
mul	doc_187964557902_item	3682057	et	3	main
õpisin	doc_187964557902_item	3682053	et	4	main
ja	doc_187964557902_item	3682043	et	3	main
armastan	doc_187964557902_item	3682040	et	3	main
eriala	doc_187964557902_item	3682037	et	4	main
seda	doc_187964557902_item	3682031	et	3	main
eesti	doc_187964557902_item	3682015	et	4	main
kõik	doc_187964557902_item	3682014	et	4	main
unustasin	doc_187964557902_item	3682013	et	3	main
ja	doc_187964557902_item	3682012	et	3	main
seal	doc_187964557902_item	3682007	et	4	main
kuut	doc_187964557902_item	3682006	et	4	main
3	doc_187964557902_item	3682005	et	2	main
kutseõppekeskust	doc_187964557902_item	3682002	et	4	main
seda	doc_187964557902_item	3681996	et	3	main
kohti	doc_873901597502_item	3682277	et	4	main
neid	doc_873901597502_item	3682276	et	4	main
jattan	doc_873901597502_item	3682267	et	4	main
on	doc_873901597502_item	3682263	et	4	main
läbi	doc_873901597502_item	3682261	et	4	main
jooksis	doc_873901597502_item	3682259	et	4	main
elu	doc_873901597502_item	3682258	et	4	main
ja	doc_873901597502_item	3682257	et	3	main
minu	doc_873901597502_item	3682247	et	3	main
oli	doc_873901597502_item	3682246	et	3	main
see	doc_873901597502_item	3682244	et	3	main
otsustasin	doc_873901597502_item	3682242	et	3	main
kõik	doc_873901597502_item	3682205	et	4	main
noh	doc_873901597502_item	3682197	et	3	main
teadvuse	doc_873901597502_item	3682196	et	4	main
oma	doc_873901597502_item	3682195	et	4	main
et	doc_873901597502_item	3682190	et	3	main
kolme	doc_491521501829_item	3681401	et	4	main
23	doc_491521501829_item	3681398	et	2	main
6-b	doc_491521501829_item	3681397	et	4	main
ta	doc_491521501829_item	3681371	et	4	main
ei	doc_491521501829_item	3681363	et	4	main
see	doc_491521501829_item	3681362	et	3	main
pälvib	doc_491521501829_item	3681358	et	3	main
vaeva	doc_491521501829_item	3681356	et	4	main
ennast	doc_491521501829_item	3681341	et	4	main
lauljad	doc_278690626961_item	3681925	et	4	main
aasta	doc_278690626961_item	3681921	et	4	main
jatnud	doc_278690626961_item	3681899	et	4	main
jälje	doc_278690626961_item	3681898	et	3	main
jannseniga	doc_278690626961_item	3681893	et	4	main
vanemuise	doc_278690626961_item	3681888	et	4	main
sündmuseks	doc_278690626961_item	3681874	et	3	main
ajaloolise	doc_278690626961_item	3681872	et	4	main
eesmärgi	doc_278690626961_item	3681870	et	4	main
pärinevad	doc_278690626961_item	3681863	et	4	main
on	doc_278690626961_item	3681853	et	4	main
sageli	doc_278690626961_item	3681852	et	3	main
tähelepanuväärne	doc_278690626961_item	3681824	et	3	main
laulmine	doc_278690626961_item	3681822	et	4	main
näidetega	doc_278690626961_item	3681821	et	3	main
illustreerida	doc_278690626961_item	3681820	et	3	main
soovitatav	doc_278690626961_item	3681819	et	4	main
analüüsiv	doc_278690626961_item	3681808	et	4	main
pikkus	doc_278690626961_item	3681801	et	4	main
laulurahva	doc_278690626961_item	3681799	et	3	main
essee	doc_278690626961_item	3681794	et	4	main
keele	doc_278690626961_item	3681787	et	4	main
elavad	doc_278690626961_item	3681967	et	4	main
et	doc_278690626961_item	3681962	et	3	main
selle	doc_278690626961_item	3681960	et	4	main
ja	doc_278690626961_item	3681946	et	3	main
kahekumne	doc_278690626961_item	3681943	et	4	main
eesti	doc_278690626961_item	3681941	et	4	main
korraldati	doc_278690626961_item	3681940	et	3	main
suvel	doc_278690626961_item	3681939	et	3	main
tol	doc_278690626961_item	3681938	et	3	main
kahekumne	doc_278690626961_item	3681932	et	4	main
mulle	doc_187964557902_item	3682114	et	4	main
nendega	doc_187964557902_item	3682104	et	4	main
keele	doc_187964557902_item	3682095	et	4	main
keel	doc_187964557902_item	3682089	et	4	main
keele	doc_187964557902_item	3682080	et	4	main
eesti	doc_187964557902_item	3682079	et	4	main
et	doc_187964557902_item	3682078	et	3	main
loodan	doc_187964557902_item	3682077	et	3	main
sõbrad	doc_187964557902_item	3682065	et	3	main
töötab	doc_187964557902_item	3682056	et	3	main
see	doc_187964557902_item	3682055	et	3	main
oli	doc_187964557902_item	3682047	et	3	main
remonteerima	doc_187964557902_item	3682042	et	4	main
tehnikat	doc_187964557902_item	3682041	et	3	main
narvas	doc_187964557902_item	3682038	et	4	main
seda	doc_187964557902_item	3682036	et	3	main
õpisin	doc_187964557902_item	3682035	et	4	main
tulin	doc_187964557902_item	3682030	et	3	main
mehhatroonika	doc_187964557902_item	3682028	et	4	main
1-c	doc_491521501829_item	3681392	et	4	main
tige	doc_491521501829_item	3681391	et	3	main
väga	doc_491521501829_item	3681390	et	3	main
peale	doc_491521501829_item	3681389	et	4	main
enda	doc_491521501829_item	3681388	et	4	main
on	doc_491521501829_item	3681387	et	4	main
f	doc_491521501829_item	3681386	et	4	main
raamatutegelased	doc_491521501829_item	3681385	et	3	main
mitte	doc_491521501829_item	3681384	et	3	main
olemas	doc_491521501829_item	3681383	et	4	main
päriselt	doc_491521501829_item	3681382	et	3	main
on	doc_491521501829_item	3681381	et	4	main
kes	doc_491521501829_item	3681380	et	4	main
inimesed	doc_491521501829_item	3681379	et	3	main
e	doc_491521501829_item	3681378	et	4	main
mind	doc_491521501829_item	3681377	et	4	main
kiusab	doc_491521501829_item	3681376	et	3	main
ta	doc_491521501829_item	3681375	et	4	main
ülekohut	doc_491521501829_item	3681374	et	3	main
mulle	doc_491521501829_item	3681373	et	4	main
teeb	doc_491521501829_item	3681372	et	3	main
korraldab	doc_491521501829_item	3681368	et	3	main
kergelt	doc_491521501829_item	3681366	et	4	main
mulle	doc_491521501829_item	3681350	et	4	main
teeb	doc_491521501829_item	3681349	et	3	main
lauludega	doc_278690626961_item	3681973	et	3	main
elavad	doc_278690626961_item	3681972	et	4	main
nad	doc_278690626961_item	3681971	et	3	main
elama	doc_278690626961_item	3681970	et	3	main
hakkavad	doc_278690626961_item	3681969	et	4	main
1994	doc_278690626961_item	3681920	et	2	main
praegusel	doc_278690626961_item	3681918	et	3	main
toimusid	doc_278690626961_item	3681916	et	4	main
mis	doc_278690626961_item	3681915	et	4	main
muusika	doc_278690626961_item	3681913	et	4	main
laulupeod	doc_278690626961_item	3681912	et	4	main
pärast	doc_278690626961_item	3681903	et	4	main
olud	doc_278690626961_item	3681902	et	3	main
poliitilised	doc_278690626961_item	3681901	et	3	main
valitsenud	doc_278690626961_item	3681900	et	4	main
johann	doc_278690626961_item	3681891	et	4	main
teostus	doc_278690626961_item	3681886	et	4	main
ja	doc_278690626961_item	3681885	et	3	main
ülemaaline	doc_278690626961_item	3681877	et	4	main
saavutamiseks	doc_278690626961_item	3681871	et	4	main
laul	doc_278690626961_item	3681860	et	4	main
ka	doc_278690626961_item	3681859	et	3	main
sealhulgas	doc_278690626961_item	3681858	et	3	main
sümbolitele	doc_278690626961_item	3681857	et	3	main
rajatud	doc_278690626961_item	3681856	et	4	main
kultuur	doc_278690626961_item	3681855	et	3	main
rahvuslik	doc_278690626961_item	3681854	et	3	main
tuleb	doc_278690626961_item	3681849	et	3	main
ja	doc_278690626961_item	3681847	et	3	main
rahvalauluga	doc_278690626961_item	3681848	et	4	main
minevik	doc_278690626961_item	3681846	et	3	main
rahva	doc_278690626961_item	3681845	et	3	main
kajastub	doc_278690626961_item	3681844	et	3	main
rahvalauludes	doc_278690626961_item	3681843	et	3	main
eesti	doc_278690626961_item	3681842	et	4	main
kiigutades	doc_278690626961_item	3681841	et	3	main
last	doc_278690626961_item	3681840	et	4	main
töötades	doc_278690626961_item	3681839	et	3	main
olles	doc_278690626961_item	3681838	et	3	main
lauldi	doc_278690626961_item	3681836	et	3	main
üksi	doc_278690626961_item	3681837	et	4	main
tegevus	doc_278690626961_item	3681835	et	4	main
sotsiaalne	doc_278690626961_item	3681834	et	3	main
ka	doc_278690626961_item	3681833	et	3	main
aga	doc_278690626961_item	3681832	et	3	main
väljendusvahend	doc_278690626961_item	3681831	et	3	main
emotsionaalne	doc_278690626961_item	3681830	et	3	main
ja	doc_278690626961_item	3681829	et	3	main
esteetiline	doc_278690626961_item	3681828	et	3	main
on	doc_278690626961_item	3681827	et	4	main
see	doc_278690626961_item	3681826	et	3	main
esitatud	doc_278690626961_item	3681815	et	4	main
lugemistekstis	doc_278690626961_item	3681814	et	3	main
ja	doc_278690626961_item	3681813	et	3	main
loengus	doc_278690626961_item	3681812	et	3	main
tuginema	doc_278690626961_item	3681811	et	3	main
üldistav	doc_278690626961_item	3681810	et	4	main
ja	doc_278690626961_item	3681809	et	3	main
sõna	doc_278690626961_item	3681803	et	4	main
essee	doc_278690626961_item	3681800	et	4	main
teise	doc_278690626961_item	3681789	et	4	main
kui	doc_278690626961_item	3681788	et	3	main
ja	doc_278690626961_item	3681968	et	3	main
eestlased	doc_278690626961_item	3681964	et	3	main
erakorraliselt	doc_278690626961_item	3681948	et	4	main
sedapuhku	doc_278690626961_item	3681947	et	3	main
teist	doc_278690626961_item	3681944	et	4	main
laulupidude	doc_278690626961_item	3681936	et	4	main
tallinna	doc_278690626961_item	3681926	et	4	main
opida	doc_187964557902_item	3682115	et	4	main
eesti	doc_187964557902_item	3682110	et	4	main
keeles	doc_187964557902_item	3682106	et	4	main
siis	doc_187964557902_item	3682086	et	3	main
keeles	doc_187964557902_item	3682085	et	4	main
räägin	doc_187964557902_item	3682083	et	3	main
ma	doc_187964557902_item	3682082	et	3	main
tunnis	doc_187964557902_item	3682081	et	3	main
kõrg	doc_187964557902_item	3682075	et	4	main
mul	doc_187964557902_item	3682072	et	3	main
palju	doc_187964557902_item	3682064	et	4	main
kuidas	doc_187964557902_item	3682054	et	3	main
seal	doc_187964557902_item	3682052	et	4	main
praaktika	doc_187964557902_item	3682048	et	3	main
veel	doc_187964557902_item	3682039	et	4	main
eriala	doc_187964557902_item	3682032	et	4	main
erialas	doc_187964557902_item	3682029	et	3	main
ttüs	doc_187964557902_item	3682027	et	4	main
õpin	doc_187964557902_item	3682026	et	3	main
praegu	doc_187964557902_item	3682025	et	3	main
hea	doc_187964557902_item	3682024	et	4	main
väga	doc_187964557902_item	3682023	et	3	main
keel	doc_187964557902_item	3682016	et	4	main
keeles	doc_187964557902_item	3682011	et	4	main
olid	doc_187964557902_item	3681998	et	4	main
loengud	doc_187964557902_item	3682112	et	3	main
et	doc_187964557902_item	3682109	et	3	main
veel	doc_187964557902_item	3682107	et	4	main
eesti	doc_187964557902_item	3682105	et	4	main
õpilastega	doc_187964557902_item	3682101	et	4	main
veel	doc_187964557902_item	3682093	et	4	main
hea	doc_187964557902_item	3682092	et	4	main
olla	doc_187964557902_item	3682091	et	3	main
minu	doc_187964557902_item	3682087	et	3	main
eesti	doc_187964557902_item	3682084	et	4	main
tehnilise	doc_187964557902_item	3682074	et	3	main
ttüs	doc_187964557902_item	3682070	et	4	main
head	doc_187964557902_item	3682059	et	4	main
jamas	doc_187964557902_item	3682051	et	4	main
balti	doc_187964557902_item	3682050	et	3	main
narva	doc_187964557902_item	3682049	et	4	main
narvas	doc_187964557902_item	3682046	et	4	main
edasi	doc_187964557902_item	3682045	et	3	main
nii	doc_187964557902_item	3682044	et	3	main
on	doc_187964557902_item	3682022	et	4	main
aga	doc_187964557902_item	3682017	et	3	main
head	doc_187964557902_item	3681999	et	4	main
selline	doc_873901597502_item	3682264	et	4	main
põhimõtte	doc_873901597502_item	3682262	et	3	main
minust	doc_873901597502_item	3682260	et	3	main
ei	doc_873901597502_item	3682252	et	4	main
ma	doc_873901597502_item	3682251	et	3	main
ja	doc_873901597502_item	3682250	et	3	main
essee	doc_873901597502_item	3682240	et	4	main
hetkel	doc_873901597502_item	3682235	et	4	main
sel	doc_873901597502_item	3682234	et	3	main
ja	doc_873901597502_item	3682233	et	3	main
sõbrad	doc_873901597502_item	3682207	et	3	main
ennast	doc_873901597502_item	3682199	et	4	main
ma	doc_873901597502_item	3682191	et	3	main
nii	doc_873901597502_item	3682187	et	3	main
on	doc_873901597502_item	3682173	et	4	main
tunnis	doc_873901597502_item	3682168	et	3	main
keskmine	doc_873901597502_item	3682162	et	3	main
kui	doc_873901597502_item	3682160	et	3	main
vastan	doc_873901597502_item	3682150	et	3	main
tahan	doc_873901597502_item	3682127	et	3	main
mägid	doc_193540241555_item	3682364	et	4	main
selle	doc_193540241555_item	3682362	et	4	main
väikese	doc_193540241555_item	3682359	et	4	main
kõrval	doc_193540241555_item	3682335	et	4	main
ma	doc_193540241555_item	3682321	et	3	main
aastat	doc_193540241555_item	3682319	et	3	main
kolm	doc_193540241555_item	3682316	et	3	main
sündiks	doc_193540241555_item	3682315	et	4	main
kui	doc_193540241555_item	3682307	et	3	main
palju	doc_193540241555_item	3682418	et	4	main
teha	doc_193540241555_item	3682411	et	3	main
ma	doc_193540241555_item	3682408	et	3	main
süüa	doc_193540241555_item	3682403	et	3	main
mulle	doc_193540241555_item	3682401	et	4	main
ei	doc_59711134417_item	3682649	et	4	main
raske	doc_59711134417_item	3682644	et	4	main
otsast	doc_59711134417_item	3682635	et	4	main
selle	doc_59711134417_item	3682627	et	4	main
aastat	doc_59711134417_item	3682624	et	3	main
õpis	doc_59711134417_item	3682622	et	3	main
see	doc_59711134417_item	3682616	et	3	main
õppeained	doc_59711134417_item	3682615	et	3	main
on	doc_59711134417_item	3682611	et	4	main
ülikoolis	doc_59711134417_item	3682609	et	4	main
hea	doc_59711134417_item	3682599	et	4	main
saab	doc_59711134417_item	3682574	et	3	main
ei	doc_59711134417_item	3682565	et	4	main
sest	doc_59711134417_item	3682564	et	4	main
siin	doc_59711134417_item	3682555	et	4	main
mitte	doc_59711134417_item	3682554	et	3	main
aga	doc_59711134417_item	3682553	et	3	main
sundivad	doc_59711134417_item	3682549	et	4	main
tal	doc_59711134417_item	3682537	et	3	main
vene	doc_59711134417_item	3682514	et	4	main
minema	doc_59711134417_item	3682513	et	3	main
pidin	doc_59711134417_item	3682512	et	3	main
mulle	doc_59711134417_item	3682473	et	4	main
pakus	doc_59711134417_item	3682472	et	3	main
ma	doc_59711134417_item	3682464	et	3	main
tipikas	doc_59711134417_item	3682463	et	4	main
majandusteaduskonna	doc_59711134417_item	3682462	et	4	main
räägida	doc_187964557902_item	3682103	et	4	main
eesti	doc_187964557902_item	3682094	et	4	main
eesti	doc_187964557902_item	3682088	et	4	main
haridus	doc_187964557902_item	3682076	et	3	main
on	doc_187964557902_item	3682073	et	4	main
siis	doc_187964557902_item	3682071	et	3	main
õpivad	doc_187964557902_item	3682063	et	3	main
ttüs	doc_187964557902_item	3682062	et	4	main
ttüst	doc_187964557902_item	3682061	et	4	main
muljed	doc_187964557902_item	3682060	et	3	main
sest	doc_187964557902_item	3682034	et	4	main
õppima	doc_187964557902_item	3682033	et	3	main
keel	doc_187964557902_item	3682021	et	4	main
inglise	doc_187964557902_item	3682020	et	4	main
minu	doc_187964557902_item	3682019	et	3	main
praegu	doc_187964557902_item	3682018	et	3	main
inglise	doc_187964557902_item	3682010	et	4	main
ainult	doc_187964557902_item	3682009	et	4	main
hollandias	doc_187964557902_item	3682004	et	4	main
maha	doc_873901597502_item	3682269	et	4	main
et	doc_873901597502_item	3682265	et	3	main
mõttetu	doc_873901597502_item	3682249	et	4	main
suvi	doc_873901597502_item	3682245	et	3	main
et	doc_873901597502_item	3682243	et	3	main
ma	doc_873901597502_item	3682241	et	3	main
selle	doc_873901597502_item	3682239	et	4	main
kirjutama	doc_873901597502_item	3682238	et	3	main
hakkasin	doc_873901597502_item	3682237	et	3	main
kui	doc_873901597502_item	3682236	et	3	main
mu	doc_873901597502_item	3682206	et	3	main
selles	doc_873901597502_item	3682203	et	4	main
on	doc_873901597502_item	3682202	et	4	main
probleem	doc_873901597502_item	3682201	et	3	main
kaotanud	doc_873901597502_item	3682194	et	4	main
et	doc_873901597502_item	3682171	et	3	main
on	doc_873901597502_item	3682153	et	4	main
nüüd	doc_873901597502_item	3682148	et	4	main
poole	doc_873901597502_item	3682139	et	4	main
ma	doc_873901597502_item	3682138	et	3	main
et	doc_873901597502_item	3682129	et	3	main
känud	doc_873901597502_item	3682122	et	4	main
olen	doc_873901597502_item	3682121	et	3	main
ma	doc_873901597502_item	3682120	et	3	main
kus	doc_873901597502_item	3682119	et	3	main
essee	doc_873901597502_item	3682118	et	4	main
pruuni	doc_193540241555_item	3682337	et	4	main
maja	doc_193540241555_item	3682330	et	4	main
õpetaja	doc_193540241555_item	3682310	et	4	main
inglise	doc_193540241555_item	3682305	et	4	main
keel	doc_193540241555_item	3682303	et	4	main
meeldib	doc_193540241555_item	3682295	et	3	main
tahan	doc_193540241555_item	3682290	et	3	main
räägisin	doc_187964557902_item	3682008	et	4	main
elasin	doc_187964557902_item	3682003	et	3	main
pärast	doc_187964557902_item	3682001	et	4	main
eksamihindad	doc_187964557902_item	3682000	et	4	main
koolis	doc_187964557902_item	3681997	et	4	main
lõpetanud	doc_187964557902_item	3681995	et	4	main
olen	doc_187964557902_item	3681994	et	3	main
ja	doc_187964557902_item	3681993	et	3	main
kutseõppekeskuses	doc_187964557902_item	3681992	et	4	main
narva	doc_187964557902_item	3681991	et	4	main
õpisin	doc_187964557902_item	3681990	et	4	main
gümnaasiumi	doc_187964557902_item	3681989	et	4	main
pärast	doc_187964557902_item	3681988	et	4	main
gümnaasium	doc_187964557902_item	3681987	et	3	main
pähklimäe	doc_187964557902_item	3681986	et	3	main
narva	doc_187964557902_item	3681985	et	4	main
lõpetanud	doc_187964557902_item	3681984	et	4	main
olen	doc_187964557902_item	3681983	et	3	main
aastat	doc_187964557902_item	3681982	et	3	main
12	doc_187964557902_item	3681981	et	2	main
narvas	doc_187964557902_item	3681980	et	4	main
elasin	doc_187964557902_item	3681979	et	3	main
ülikool	doc_187964557902_item	3681978	et	4	main
ja	doc_187964557902_item	3681977	et	3	main
mina	doc_187964557902_item	3681976	et	4	main
essee	doc_187964557902_item	3681975	et	4	main
joomise	doc_873901597502_item	3682268	et	4	main
jaoks	doc_873901597502_item	3682248	et	4	main
pildituks	doc_873901597502_item	3682200	et	4	main
olen	doc_873901597502_item	3682193	et	3	main
sõitnud	doc_873901597502_item	3682174	et	4	main
see	doc_873901597502_item	3682169	et	3	main
sada	doc_873901597502_item	3682166	et	4	main
lihtne	doc_873901597502_item	3682159	et	3	main
on	doc_873901597502_item	3682158	et	4	main
vastus	doc_873901597502_item	3682157	et	3	main
toimunud	doc_873901597502_item	3682156	et	4	main
alati	doc_873901597502_item	3682155	et	4	main
nii	doc_873901597502_item	3682154	et	3	main
küsimusele	doc_873901597502_item	3682151	et	4	main
tallinnast	doc_873901597502_item	3682146	et	3	main
seitsekümmend	doc_873901597502_item	3682144	et	4	main
pärast	doc_873901597502_item	3682137	et	4	main
selle	doc_873901597502_item	3682136	et	4	main
ja	doc_873901597502_item	3682135	et	3	main
öelda	doc_873901597502_item	3682128	et	4	main
näinud	doc_873901597502_item	3682126	et	4	main
mida	doc_873901597502_item	3682124	et	4	main
näinud	doc_873901597502_item	3682286	et	4	main
olen	doc_873901597502_item	3682285	et	3	main
mida	doc_873901597502_item	3682284	et	4	main
asju	doc_873901597502_item	3682283	et	3	main
neid	doc_873901597502_item	3682282	et	4	main
ja	doc_873901597502_item	3682281	et	3	main
käinud	doc_873901597502_item	3682280	et	4	main
olen	doc_873901597502_item	3682279	et	3	main
kus	doc_873901597502_item	3682278	et	3	main
teile	doc_873901597502_item	3682275	et	4	main
kirjeldan	doc_873901597502_item	3682274	et	3	main
ma	doc_873901597502_item	3682273	et	3	main
sügisel	doc_873901597502_item	3682272	et	3	main
järgmisel	doc_873901597502_item	3682271	et	3	main
ja	doc_873901597502_item	3682270	et	3	main
ma	doc_873901597502_item	3682266	et	3	main
jooma	doc_873901597502_item	3682256	et	4	main
palju	doc_873901597502_item	3682255	et	4	main
nii	doc_873901597502_item	3682254	et	3	main
pidanud	doc_873901597502_item	3682253	et	4	main
näinud	doc_873901597502_item	3682232	et	4	main
midagi	doc_873901597502_item	3682231	et	4	main
kunagi	doc_873901597502_item	3682230	et	3	main
poole	doc_873901597502_item	3682229	et	4	main
ma	doc_873901597502_item	3682228	et	3	main
päriselt	doc_873901597502_item	3682227	et	3	main
kui	doc_873901597502_item	3682226	et	3	main
usaldada	doc_873901597502_item	3682225	et	3	main
neid	doc_873901597502_item	3682224	et	4	main
saan	doc_873901597502_item	3682223	et	4	main
kuidas	doc_873901597502_item	3682221	et	3	main
ma	doc_873901597502_item	3682222	et	3	main
aga	doc_873901597502_item	3682220	et	3	main
viljandis	doc_873901597502_item	3682219	et	4	main
tartus	doc_873901597502_item	3682218	et	3	main
pärnus	doc_873901597502_item	3682217	et	3	main
näiteks	doc_873901597502_item	3682216	et	4	main
kaugemal	doc_873901597502_item	3682215	et	4	main
ka	doc_873901597502_item	3682214	et	3	main
käinud	doc_873901597502_item	3682213	et	4	main
oleme	doc_873901597502_item	3682212	et	3	main
me	doc_873901597502_item	3682211	et	4	main
et	doc_873901597502_item	3682210	et	3	main
tõestada	doc_873901597502_item	3682209	et	3	main
üritavad	doc_873901597502_item	3682208	et	4	main
et	doc_873901597502_item	3682204	et	3	main
jõin	doc_873901597502_item	3682198	et	3	main
peaaegu	doc_873901597502_item	3682192	et	3	main
jumala	doc_873901597502_item	3682188	et	3	main
ta	doc_873901597502_item	3682172	et	4	main
kiirus	doc_873901597502_item	3682163	et	4	main
auto	doc_873901597502_item	3682161	et	4	main
miks	doc_873901597502_item	3682152	et	4	main
kaugemale	doc_873901597502_item	3682142	et	4	main
saabunud	doc_873901597502_item	3682141	et	4	main
kunagi	doc_873901597502_item	3682140	et	3	main
inimene	doc_873901597502_item	3682134	et	3	main
liiga	doc_873901597502_item	3682132	et	4	main
olen	doc_873901597502_item	3682131	et	3	main
oleks	doc_193540241555_item	3682363	et	3	main
sest	doc_193540241555_item	3682361	et	4	main
maale	doc_193540241555_item	3682360	et	4	main
ma	doc_193540241555_item	3682357	et	3	main
lõuna-jaapanis	doc_193540241555_item	3682355	et	4	main
elaks	doc_193540241555_item	3682354	et	3	main
maja	doc_193540241555_item	3682334	et	4	main
oleks	doc_193540241555_item	3682333	et	3	main
aed	doc_193540241555_item	3682332	et	3	main
taga	doc_193540241555_item	3682331	et	4	main
puu	doc_193540241555_item	3682328	et	4	main
aedga	doc_193540241555_item	3682326	et	4	main
elada	doc_193540241555_item	3682323	et	3	main
kolmkümmend	doc_193540241555_item	3682318	et	4	main
ma	doc_193540241555_item	3682308	et	3	main
jaapani	doc_193540241555_item	3682302	et	4	main
õpetaks	doc_193540241555_item	3682301	et	3	main
ma	doc_193540241555_item	3682300	et	3	main
inimesega	doc_193540241555_item	3682299	et	3	main
räägida	doc_193540241555_item	3682296	et	4	main
olla	doc_193540241555_item	3682291	et	3	main
essee	doc_193540241555_item	3682288	et	4	main
raha	doc_193540241555_item	3682424	et	4	main
olaks	doc_193540241555_item	3682422	et	4	main
mul	doc_193540241555_item	3682421	et	3	main
igapäeval	doc_193540241555_item	3682415	et	3	main
õlu	doc_193540241555_item	3682414	et	3	main
ja	doc_193540241555_item	3682412	et	3	main
süüa	doc_193540241555_item	3682410	et	3	main
jüüa	doc_193540241555_item	3682406	et	4	main
juatäis	doc_873901597502_item	3682189	et	4	main
juba	doc_873901597502_item	3682186	et	3	main
olema	doc_873901597502_item	3682185	et	4	main
alati	doc_873901597502_item	3682184	et	4	main
pidin	doc_873901597502_item	3682183	et	3	main
ma	doc_873901597502_item	3682182	et	3	main
ajaga	doc_873901597502_item	3682181	et	3	main
selle	doc_873901597502_item	3682180	et	4	main
ja	doc_873901597502_item	3682179	et	3	main
minutiga	doc_873901597502_item	3682178	et	3	main
neljakümne	doc_873901597502_item	3682177	et	4	main
kilomeetrit	doc_873901597502_item	3682176	et	4	main
seitsekümmend	doc_873901597502_item	3682175	et	4	main
tähendab	doc_873901597502_item	3682170	et	3	main
kilomeetrit	doc_873901597502_item	3682167	et	4	main
umbes	doc_873901597502_item	3682165	et	4	main
on	doc_873901597502_item	3682164	et	4	main
ma	doc_873901597502_item	3682149	et	3	main
ja	doc_873901597502_item	3682147	et	3	main
kilomeetrit	doc_873901597502_item	3682145	et	4	main
kui	doc_873901597502_item	3682143	et	3	main
aktiivne	doc_873901597502_item	3682133	et	3	main
ma	doc_873901597502_item	3682130	et	3	main
olen	doc_873901597502_item	3682125	et	3	main
ja	doc_873901597502_item	3682123	et	3	main
elaks	doc_193540241555_item	3682358	et	3	main
ma	doc_193540241555_item	3682353	et	3	main
oleks	doc_193540241555_item	3682329	et	3	main
majas	doc_193540241555_item	3682325	et	3	main
tahan	doc_193540241555_item	3682322	et	3	main
vanani	doc_193540241555_item	3682320	et	3	main
lapsid	doc_193540241555_item	3682317	et	3	main
ma	doc_193540241555_item	3682314	et	3	main
lapsid	doc_193540241555_item	3682313	et	3	main
armastan	doc_193540241555_item	3682312	et	3	main
ma	doc_193540241555_item	3682311	et	3	main
ja	doc_193540241555_item	3682297	et	3	main
mulle	doc_193540241555_item	3682294	et	4	main
sest	doc_193540241555_item	3682293	et	4	main
jutt	doc_193540241555_item	3682427	et	3	main
oli	doc_193540241555_item	3682426	et	3	main
palju	doc_193540241555_item	3682423	et	4	main
kui	doc_193540241555_item	3682420	et	3	main
õlid	doc_193540241555_item	3682419	et	3	main
tahaks	doc_193540241555_item	3682409	et	3	main
ja	doc_193540241555_item	3682405	et	3	main
väga	doc_59711134417_item	3682653	et	3	main
koolis	doc_59711134417_item	3682651	et	4	main
uskuda	doc_59711134417_item	3682645	et	3	main
mul	doc_59711134417_item	3682642	et	3	main
harjuma	doc_59711134417_item	3682638	et	3	main
peab	doc_59711134417_item	3682637	et	4	main
peale	doc_59711134417_item	3682636	et	4	main
ülikoolois	doc_59711134417_item	3682632	et	4	main
sõpradeks	doc_59711134417_item	3682631	et	3	main
suurteks	doc_59711134417_item	3682630	et	3	main
saime	doc_59711134417_item	3682629	et	3	main
ajaga	doc_59711134417_item	3682628	et	3	main
klass	doc_59711134417_item	3682621	et	3	main
semester	doc_59711134417_item	3682613	et	3	main
asjad	doc_59711134417_item	3682604	et	3	main
millised	doc_59711134417_item	3682603	et	3	main
rääkida	doc_59711134417_item	3682602	et	3	main
tahan	doc_59711134417_item	3682601	et	3	main
nüüd	doc_59711134417_item	3682600	et	4	main
tudeng	doc_59711134417_item	3682573	et	3	main
seda	doc_59711134417_item	3682571	et	3	main
või	doc_59711134417_item	3682569	et	4	main
ole	doc_59711134417_item	3682566	et	4	main
õpid	doc_59711134417_item	3682557	et	4	main
sa	doc_59711134417_item	3682556	et	3	main
õpetajad	doc_59711134417_item	3682548	et	4	main
ülikoolis	doc_59711134417_item	3682542	et	4	main
sellest	doc_59711134417_item	3682529	et	4	main
raskem	doc_59711134417_item	3682526	et	4	main
rahvamajanduses	doc_59711134417_item	3682524	et	3	main
jaanuaril	doc_193540241555_item	3682449	et	3	main
neli	doc_193540241555_item	3682448	et	3	main
kakskümmend	doc_193540241555_item	3682447	et	4	main
tagasi	doc_193540241555_item	3682446	et	3	main
jaapanisse	doc_193540241555_item	3682445	et	4	main
tulen	doc_193540241555_item	3682444	et	3	main
ma	doc_193540241555_item	3682443	et	3	main
jaapanisse	doc_193540241555_item	3682442	et	4	main
tulen	doc_193540241555_item	3682441	et	3	main
tagasi	doc_193540241555_item	3682440	et	3	main
ma	doc_193540241555_item	3682439	et	3	main
pärast	doc_193540241555_item	3682438	et	4	main
sõbraga	doc_193540241555_item	3682437	et	3	main
minu	doc_193540241555_item	3682436	et	3	main
jaanuaril	doc_193540241555_item	3682435	et	3	main
itaaliasse	doc_193540241555_item	3682434	et	4	main
prantsusmaale	doc_193540241555_item	3682433	et	4	main
belgiasse	doc_193540241555_item	3682432	et	4	main
saksamaale	doc_193540241555_item	3682431	et	4	main
lähen	doc_193540241555_item	3682430	et	3	main
ma	doc_193540241555_item	3682429	et	3	main
aga	doc_193540241555_item	3682428	et	3	main
aga	doc_193540241555_item	3682356	et	3	main
kunagi	doc_193540241555_item	3682352	et	3	main
mitte	doc_193540241555_item	3682351	et	3	main
lõuna-jaapanis	doc_193540241555_item	3682350	et	4	main
elanud	doc_193540241555_item	3682349	et	4	main
oli	doc_193540241555_item	3682348	et	3	main
ei	doc_193540241555_item	3682347	et	4	main
ma	doc_193540241555_item	3682346	et	3	main
muri	doc_193540241555_item	3682345	et	2	main
oleks	doc_193540241555_item	3682344	et	3	main
nimi	doc_193540241555_item	3682343	et	3	main
koera	doc_193540241555_item	3682342	et	4	main
ees	doc_193540241555_item	3682341	et	4	main
maja	doc_193540241555_item	3682340	et	4	main
koer	doc_193540241555_item	3682338	et	3	main
oleks	doc_193540241555_item	3682339	et	3	main
ja	doc_193540241555_item	3682336	et	3	main
suure	doc_193540241555_item	3682327	et	3	main
suure	doc_193540241555_item	3682324	et	3	main
oleks	doc_193540241555_item	3682309	et	3	main
keel	doc_193540241555_item	3682306	et	4	main
või	doc_193540241555_item	3682304	et	4	main
kuuleda	doc_193540241555_item	3682298	et	4	main
õpetaja	doc_193540241555_item	3682292	et	4	main
ma	doc_193540241555_item	3682289	et	3	main
need	doc_193540241555_item	3682425	et	3	main
ostaks	doc_193540241555_item	3682417	et	3	main
õppida	doc_59711134417_item	3682662	et	3	main
meeldib	doc_59711134417_item	3682661	et	3	main
rohkem	doc_59711134417_item	3682648	et	4	main
et	doc_59711134417_item	3682646	et	3	main
algusel	doc_59711134417_item	3682641	et	4	main
teine	doc_59711134417_item	3682639	et	3	main
hakab	doc_59711134417_item	3682633	et	4	main
huvitav	doc_59711134417_item	3682618	et	4	main
iga	doc_59711134417_item	3682612	et	4	main
ma	doc_193540241555_item	3682416	et	3	main
jüüa	doc_193540241555_item	3682413	et	4	main
õlu	doc_193540241555_item	3682407	et	3	main
teha	doc_193540241555_item	3682404	et	3	main
meeldib	doc_193540241555_item	3682402	et	3	main
päikese	doc_193540241555_item	3682400	et	4	main
oleks	doc_193540241555_item	3682399	et	3	main
kui	doc_193540241555_item	3682398	et	3	main
jalgsiga	doc_193540241555_item	3682397	et	4	main
läheks	doc_193540241555_item	3682396	et	3	main
ma	doc_193540241555_item	3682395	et	3	main
aga	doc_193540241555_item	3682394	et	3	main
sadaks	doc_193540241555_item	3682393	et	4	main
vihma	doc_193540241555_item	3682392	et	4	main
kui	doc_193540241555_item	3682391	et	3	main
autoga	doc_193540241555_item	3682390	et	3	main
minu	doc_193540241555_item	3682389	et	3	main
tööle	doc_193540241555_item	3682388	et	3	main
läheks	doc_193540241555_item	3682387	et	3	main
ma	doc_193540241555_item	3682386	et	3	main
töötama	doc_193540241555_item	3682385	et	3	main
pean	doc_193540241555_item	3682384	et	4	main
ma	doc_193540241555_item	3682383	et	3	main
mangida	doc_193540241555_item	3682382	et	4	main
alati	doc_193540241555_item	3682381	et	4	main
tahaks	doc_193540241555_item	3682380	et	3	main
ei	doc_193540241555_item	3682379	et	4	main
ma	doc_193540241555_item	3682378	et	3	main
aga	doc_193540241555_item	3682377	et	3	main
meris	doc_193540241555_item	3682376	et	4	main
ujuks	doc_193540241555_item	3682375	et	4	main
matkama	doc_193540241555_item	3682374	et	3	main
mägisse	doc_193540241555_item	3682373	et	4	main
läheks	doc_193540241555_item	3682372	et	3	main
ma	doc_193540241555_item	3682371	et	3	main
loomusega	doc_193540241555_item	3682370	et	3	main
olla	doc_193540241555_item	3682369	et	3	main
meeldib	doc_193540241555_item	3682368	et	3	main
mulle	doc_193540241555_item	3682367	et	4	main
meri	doc_193540241555_item	3682366	et	3	main
ja	doc_193540241555_item	3682365	et	3	main
ülikoolis	doc_59711134417_item	3682663	et	4	main
mulle	doc_59711134417_item	3682660	et	4	main
ja	doc_59711134417_item	3682657	et	3	main
oma	doc_59711134417_item	3682655	et	4	main
igatsesin	doc_59711134417_item	3682654	et	3	main
ma	doc_59711134417_item	3682652	et	3	main
õpi	doc_59711134417_item	3682650	et	4	main
oli	doc_59711134417_item	3682643	et	3	main
kõik	doc_59711134417_item	3682634	et	4	main
ja	doc_59711134417_item	3682626	et	3	main
on	doc_59711134417_item	3682617	et	4	main
edukas	doc_59711134417_item	3682674	et	4	main
oleks	doc_59711134417_item	3682673	et	3	main
session	doc_59711134417_item	3682672	et	4	main
esimene	doc_59711134417_item	3682671	et	3	main
et	doc_59711134417_item	3682670	et	3	main
jaoks	doc_59711134417_item	3682669	et	4	main
minu	doc_59711134417_item	3682668	et	3	main
tähtsam	doc_59711134417_item	3682667	et	4	main
kõige	doc_59711134417_item	3682666	et	4	main
on	doc_59711134417_item	3682665	et	4	main
praegu	doc_59711134417_item	3682664	et	3	main
aga	doc_59711134417_item	3682659	et	3	main
klassikaaslasi	doc_59711134417_item	3682658	et	3	main
klassijuhatajat	doc_59711134417_item	3682656	et	3	main
ma	doc_59711134417_item	3682647	et	3	main
teisega	doc_59711134417_item	3682640	et	4	main
koos	doc_59711134417_item	3682625	et	4	main
kaksteist	doc_59711134417_item	3682623	et	4	main
meie	doc_59711134417_item	3682620	et	4	main
koolis	doc_59711134417_item	3682619	et	4	main
uued	doc_59711134417_item	3682614	et	3	main
ülikoolis	doc_59711134417_item	3682610	et	4	main
ja	doc_59711134417_item	3682608	et	3	main
moodi	doc_59711134417_item	3682598	et	4	main
oma	doc_59711134417_item	3682597	et	4	main
aga	doc_59711134417_item	3682596	et	3	main
on	doc_59711134417_item	3682595	et	4	main
ülikoolis	doc_59711134417_item	3682594	et	4	main
hea	doc_59711134417_item	3682593	et	4	main
moodi	doc_59711134417_item	3682592	et	4	main
oma	doc_59711134417_item	3682591	et	4	main
oli	doc_59711134417_item	3682590	et	3	main
koolis	doc_59711134417_item	3682589	et	4	main
sest	doc_59711134417_item	3682588	et	4	main
õppida	doc_59711134417_item	3682587	et	3	main
meeldib	doc_59711134417_item	3682586	et	3	main
rohkem	doc_59711134417_item	3682585	et	4	main
mulle	doc_59711134417_item	3682584	et	4	main
kus	doc_59711134417_item	3682583	et	3	main
ütelda	doc_59711134417_item	3682582	et	4	main
oska	doc_59711134417_item	3682581	et	4	main
ei	doc_59711134417_item	3682580	et	4	main
ma	doc_59711134417_item	3682579	et	3	main
aega	doc_59711134417_item	3682578	et	4	main
oma	doc_59711134417_item	3682577	et	4	main
ise	doc_59711134417_item	3682575	et	4	main
jagada	doc_59711134417_item	3682576	et	3	main
vähe	doc_59711134417_item	3682572	et	3	main
on	doc_59711134417_item	3682561	et	4	main
jaoks	doc_59711134417_item	3682559	et	4	main
oma	doc_59711134417_item	3682558	et	4	main
koolis	doc_59711134417_item	3682547	et	4	main
õppimisest	doc_59711134417_item	3682545	et	4	main
väga	doc_59711134417_item	3682543	et	3	main
õppimine	doc_59711134417_item	3682541	et	4	main
raske	doc_59711134417_item	3682540	et	4	main
ta	doc_59711134417_item	3682533	et	4	main
kuigi	doc_59711134417_item	3682532	et	3	main
sõbrannalt	doc_59711134417_item	3682531	et	3	main
õppida	doc_59711134417_item	3682527	et	3	main
on	doc_59711134417_item	3682525	et	4	main
sest	doc_59711134417_item	3682523	et	4	main
kahetse	doc_59711134417_item	3682522	et	4	main
keeles	doc_59711134417_item	3682511	et	4	main
eesti	doc_59711134417_item	3682510	et	4	main
huvi	doc_59711134417_item	3682474	et	4	main
üksendal	doc_59711134417_item	3682469	et	4	main
ülikool	doc_59711134417_item	3682454	et	4	main
ilusad	doc_59711134411_item	3682749	et	3	main
näiteks	doc_59711134411_item	3682738	et	4	main
saaremaal	doc_59711134411_item	3682733	et	4	main
koolis	doc_59711134417_item	3682607	et	4	main
meeldivad	doc_59711134417_item	3682606	et	4	main
mulle	doc_59711134417_item	3682605	et	4	main
on	doc_59711134417_item	3682570	et	4	main
kodutööd	doc_59711134417_item	3682568	et	4	main
vabaaega	doc_59711134417_item	3682563	et	4	main
ülikoolis	doc_59711134417_item	3682560	et	4	main
õppida	doc_59711134417_item	3682551	et	3	main
koolis	doc_59711134417_item	3682546	et	4	main
erineb	doc_59711134417_item	3682544	et	3	main
on	doc_59711134417_item	3682538	et	4	main
koolis	doc_59711134417_item	3682536	et	4	main
eesti	doc_59711134417_item	3682535	et	4	main
õpis	doc_59711134417_item	3682534	et	3	main
tean	doc_59711134417_item	3682528	et	3	main
ärindust	doc_59711134417_item	3682516	et	3	main
gruppi	doc_59711134417_item	3682515	et	4	main
klassil	doc_59711134417_item	3682470	et	3	main
juba	doc_59711134417_item	3682468	et	3	main
valisin	doc_59711134417_item	3682465	et	3	main
igapäevast	doc_59711134417_item	3682567	et	4	main
rohkem	doc_59711134417_item	3682562	et	4	main
ülikoolis	doc_59711134417_item	3682552	et	4	main
sind	doc_59711134417_item	3682550	et	4	main
ikkagi	doc_59711134417_item	3682539	et	4	main
oma	doc_59711134417_item	3682530	et	4	main
ei	doc_59711134417_item	3682521	et	4	main
ma	doc_59711134417_item	3682520	et	3	main
praegu	doc_59711134417_item	3682519	et	3	main
aga	doc_59711134417_item	3682518	et	3	main
õppima	doc_59711134417_item	3682517	et	3	main
ainult	doc_59711134417_item	3682509	et	4	main
õppida	doc_59711134417_item	3682508	et	3	main
võimalik	doc_59711134417_item	3682507	et	3	main
on	doc_59711134417_item	3682506	et	4	main
rahvamajandust	doc_59711134417_item	3682505	et	3	main
kuna	doc_59711134417_item	3682504	et	3	main
halvasti	doc_59711134417_item	3682503	et	3	main
eksami	doc_59711134417_item	3682502	et	3	main
keele	doc_59711134417_item	3682501	et	4	main
eesti	doc_59711134417_item	3682500	et	4	main
sooritasin	doc_59711134417_item	3682499	et	3	main
kuid	doc_59711134417_item	3682498	et	4	main
rahvamajandust	doc_59711134417_item	3682497	et	3	main
õppima	doc_59711134417_item	3682496	et	3	main
minna	doc_59711134417_item	3682495	et	3	main
tahtsin	doc_59711134417_item	3682494	et	3	main
ma	doc_59711134417_item	3682493	et	3	main
esialgu	doc_59711134417_item	3682492	et	3	main
erialat	doc_59711134417_item	3682491	et	4	main
seda	doc_59711134417_item	3682490	et	3	main
õpis	doc_59711134417_item	3682489	et	3	main
ta	doc_59711134417_item	3682488	et	4	main
ja	doc_59711134417_item	3682487	et	3	main
raamatupidaja	doc_59711134417_item	3682486	et	4	main
on	doc_59711134417_item	3682485	et	4	main
minu	doc_59711134417_item	3682483	et	3	main
ema	doc_59711134417_item	3682484	et	4	main
emalt	doc_59711134417_item	3682482	et	3	main
sellest	doc_59711134417_item	3682481	et	4	main
kuulnud	doc_59711134417_item	3682480	et	4	main
palju	doc_59711134417_item	3682479	et	4	main
olen	doc_59711134417_item	3682478	et	3	main
ma	doc_59711134417_item	3682477	et	3	main
et	doc_59711134417_item	3682476	et	3	main
sellepärast	doc_59711134417_item	3682475	et	3	main
kohad	doc_59711134411_item	3682750	et	4	main
on	doc_59711134411_item	3682747	et	4	main
eestis	doc_59711134411_item	3682746	et	3	main
me	doc_59711134411_item	3682734	et	4	main
saaremaal	doc_59711134411_item	3682726	et	4	main
majandus	doc_59711134417_item	3682471	et	4	main
erialat	doc_59711134417_item	3682467	et	4	main
seda	doc_59711134417_item	3682466	et	3	main
ja	doc_59711134417_item	3682453	et	3	main
mina	doc_59711134417_item	3682452	et	4	main
essee	doc_59711134417_item	3682451	et	4	main
kus	doc_59711134411_item	3682751	et	3	main
kohti	doc_59711134411_item	3682737	et	4	main
turistid	doc_59711134411_item	3682718	et	3	main
on	doc_59711134411_item	3682713	et	4	main
on	doc_59711134411_item	3682699	et	4	main
suureim	doc_59711134411_item	3682695	et	4	main
saaremaa	doc_59711134411_item	3682693	et	4	main
minu	doc_59711134411_item	3682691	et	3	main
koos	doc_59711134411_item	3682690	et	4	main
näiteks	doc_343606542360_item	3682897	et	4	main
tootest	doc_343606542360_item	3682896	et	4	main
sellest	doc_343606542360_item	3682895	et	4	main
selline	doc_343606542360_item	3682887	et	4	main
jääb	doc_343606542360_item	3682886	et	3	main
paremad	doc_343606542360_item	3682880	et	4	main
laps	doc_343606542360_item	3682863	et	4	main
ka	doc_343606542360_item	3682861	et	3	main
aru	doc_343606542360_item	3682859	et	4	main
on	doc_343606542360_item	3682849	et	4	main
kaplinksi	doc_343606542360_item	3682841	et	4	main
jaan	doc_343606542360_item	3682840	et	3	main
tappa	doc_343606542360_item	3682839	et	4	main
reklaamist	doc_343606542360_item	3682832	et	4	main
natukene	doc_343606542360_item	3682828	et	4	main
vaadata	doc_59711134411_item	3682809	et	4	main
ma	doc_59711134411_item	3682807	et	3	main
me	doc_59711134411_item	3682778	et	4	main
vanemad	doc_59711134411_item	3682777	et	4	main
minu	doc_59711134411_item	3682776	et	3	main
linn	doc_59711134411_item	3682767	et	3	main
see	doc_59711134411_item	3682764	et	3	main
ma	doc_59711134411_item	3682761	et	3	main
kaks	doc_59711134411_item	3682758	et	3	main
minu	doc_59711134411_item	3682756	et	3	main
külastama	doc_399014257207_item	3682987	et	3	main
reismasin	doc_399014257207_item	3682974	et	4	main
ma	doc_399014257207_item	3682964	et	3	main
olema	doc_399014257207_item	3682961	et	4	main
väga	doc_399014257207_item	3682953	et	3	main
joulud	doc_399014257207_item	3682950	et	4	main
oli	doc_399014257207_item	3682948	et	3	main
lennukaugus	doc_399014257207_item	3682947	et	4	main
ma	doc_399014257207_item	3682946	et	3	main
ja	doc_399014257207_item	3682937	et	3	main
õde	doc_399014257207_item	3682936	et	4	main
minu	doc_399014257207_item	3682935	et	3	main
pean	doc_399014257207_item	3683036	et	4	main
ma	doc_399014257207_item	3683035	et	3	main
minema	doc_399014257207_item	3683014	et	3	main
väga	doc_399014257207_item	3683008	et	3	main
hoidsin	doc_399014257206_item	3683156	et	3	main
aga	doc_399014257206_item	3683154	et	3	main
ma	doc_399014257206_item	3683151	et	3	main
kaks	doc_399014257206_item	3683142	et	3	main
mina	doc_399014257206_item	3683139	et	4	main
nii	doc_399014257206_item	3683138	et	3	main
rase	doc_399014257206_item	3683137	et	3	main
ja	doc_399014257206_item	3683102	et	3	main
eriti	doc_399014257206_item	3683093	et	3	main
mulle	doc_399014257206_item	3683092	et	4	main
ei	doc_399014257206_item	3683090	et	4	main
see	doc_399014257206_item	3683089	et	3	main
golfimängija	doc_399014257206_item	3683088	et	4	main
golfiväljak	doc_399014257206_item	3683083	et	3	main
korter	doc_213943984964_item	3683410	et	3	main
pole	doc_213943984964_item	3683399	et	3	main
me	doc_213943984964_item	3683378	et	4	main
ole	doc_213943984964_item	3683369	et	4	main
soola	doc_213943984964_item	3683360	et	4	main
alati	doc_213943984964_item	3683354	et	4	main
telekat	doc_213943984964_item	3683353	et	3	main
tüütavad	doc_213943984964_item	3683343	et	4	main
lärm	doc_213943984964_item	3683340	et	3	main
liiklus	doc_213943984964_item	3683338	et	3	main
kogu	doc_213943984964_item	3683335	et	4	main
olen	doc_59711134417_item	3682461	et	3	main
ma	doc_59711134417_item	3682460	et	3	main
ja	doc_59711134417_item	3682459	et	3	main
eesnimi	doc_59711134417_item	3682458	et	3	main
on	doc_59711134417_item	3682457	et	4	main
nimi	doc_59711134417_item	3682456	et	3	main
minu	doc_59711134417_item	3682455	et	3	main
ma	doc_59711134411_item	3682752	et	3	main
palju	doc_59711134411_item	3682748	et	4	main
et	doc_59711134411_item	3682745	et	3	main
tean	doc_59711134411_item	3682744	et	3	main
ma	doc_59711134411_item	3682743	et	3	main
park	doc_59711134411_item	3682742	et	3	main
toila	doc_59711134411_item	3682741	et	4	main
ja	doc_59711134411_item	3682740	et	3	main
tuntuvaid	doc_59711134411_item	3682736	et	4	main
me	doc_59711134411_item	3682731	et	4	main
talud	doc_59711134411_item	3682729	et	4	main
palju	doc_59711134411_item	3682717	et	4	main
järv	doc_59711134411_item	3682711	et	3	main
tänapäeval	doc_59711134411_item	3682709	et	3	main
mis	doc_59711134411_item	3682708	et	4	main
kraater	doc_59711134411_item	3682707	et	2	main
meteoriiti	doc_59711134411_item	3682706	et	4	main
asub	doc_59711134411_item	3682705	et	3	main
palju	doc_59711134411_item	3682700	et	4	main
sõtsin	doc_59711134411_item	3682689	et	4	main
ma	doc_59711134411_item	3682688	et	3	main
on	doc_343606542360_item	3682921	et	4	main
teade	doc_343606542360_item	3682893	et	4	main
kus	doc_343606542360_item	3682884	et	3	main
sellised	doc_343606542360_item	3682883	et	4	main
et	doc_343606542360_item	3682878	et	3	main
arvan	doc_343606542360_item	3682877	et	3	main
ma	doc_343606542360_item	3682876	et	3	main
kasutada	doc_343606542360_item	3682875	et	3	main
verb	doc_343606542360_item	3682874	et	3	main
tugev	doc_343606542360_item	3682873	et	4	main
üsna	doc_343606542360_item	3682872	et	3	main
ka	doc_343606542360_item	3682871	et	3	main
võiks	doc_343606542360_item	3682864	et	4	main
väike	doc_343606542360_item	3682862	et	4	main
neid	doc_343606542360_item	3682854	et	4	main
ära	doc_343606542360_item	3682838	et	4	main
putukad	doc_343606542360_item	3682837	et	3	main
on	doc_343606542360_item	3682831	et	4	main
näide	doc_343606542360_item	3682830	et	3	main
asju	doc_343606542360_item	3682827	et	3	main
uskuma	doc_343606542360_item	3682825	et	3	main
arvutiga	doc_343606542360_item	3682820	et	4	main
on	doc_343606542360_item	3682819	et	4	main
realiseeruma	doc_59711134411_item	3682815	et	3	main
minu	doc_59711134411_item	3682813	et	3	main
et	doc_59711134411_item	3682812	et	3	main
tahn	doc_59711134411_item	3682808	et	4	main
viljandis	doc_59711134411_item	3682768	et	4	main
väga	doc_59711134411_item	3682765	et	3	main
koos	doc_59711134411_item	3682755	et	4	main
sõber	doc_399014257207_item	3682989	et	3	main
majasse	doc_399014257207_item	3682976	et	3	main
päev	doc_399014257207_item	3682972	et	3	main
ma	doc_399014257207_item	3682969	et	3	main
siis	doc_399014257207_item	3682962	et	3	main
lapsevoodis	doc_399014257207_item	3682960	et	3	main
ma	doc_399014257207_item	3682958	et	3	main
väga	doc_399014257207_item	3682956	et	3	main
aga	doc_399014257207_item	3682955	et	3	main
paev	doc_399014257207_item	3682951	et	4	main
viivitamasin	doc_399014257207_item	3682949	et	4	main
kaalus	doc_399014257207_item	3683043	et	4	main
tahtma	doc_399014257207_item	3683042	et	3	main
ma	doc_399014257207_item	3683041	et	3	main
nimestik	doc_399014257207_item	3683040	et	3	main
algul	doc_399014257207_item	3683039	et	4	main
lehekülje	doc_399014257207_item	3683038	et	3	main
tegema	doc_399014257207_item	3683037	et	3	main
või	doc_399014257207_item	3683032	et	4	main
koostama	doc_399014257207_item	3683030	et	3	main
lõpuks	doc_399014257207_item	3683021	et	4	main
päeval	doc_399014257207_item	3683019	et	3	main
üliväsinud	doc_399014257207_item	3683009	et	3	main
ostma	doc_399014257206_item	3683152	et	3	main
viis	doc_399014257206_item	3683149	et	4	main
kakskummend	doc_399014257206_item	3683148	et	4	main
ontika	doc_59711134411_item	3682739	et	4	main
küllastasime	doc_59711134411_item	3682735	et	3	main
sõitsime	doc_59711134411_item	3682732	et	3	main
kui	doc_59711134411_item	3682730	et	3	main
palju	doc_59711134411_item	3682728	et	4	main
on	doc_59711134411_item	3682727	et	4	main
et	doc_59711134411_item	3682721	et	3	main
sõitsivad	doc_59711134411_item	3682719	et	2	main
see	doc_59711134411_item	3682712	et	3	main
on	doc_59711134411_item	3682710	et	4	main
vaatamis	doc_59711134411_item	3682701	et	4	main
saar	doc_59711134411_item	3682696	et	3	main
saaremaal	doc_59711134411_item	3682687	et	4	main
olin	doc_59711134411_item	3682686	et	3	main
ma	doc_59711134411_item	3682685	et	3	main
aastal	doc_59711134411_item	3682684	et	3	main
eelmisel	doc_59711134411_item	3682683	et	3	main
vaatasin	doc_59711134411_item	3682682	et	3	main
ma	doc_59711134411_item	3682681	et	3	main
mis	doc_59711134411_item	3682680	et	4	main
olin	doc_59711134411_item	3682679	et	3	main
ma	doc_59711134411_item	3682678	et	3	main
kus	doc_59711134411_item	3682677	et	3	main
essee	doc_59711134411_item	3682676	et	4	main
weebileheküljele	doc_343606542360_item	3682917	et	4	main
toote	doc_343606542360_item	3682916	et	4	main
näiteks	doc_343606542360_item	3682915	et	4	main
läheb	doc_343606542360_item	3682914	et	3	main
tarbija	doc_343606542360_item	3682913	et	4	main
et	doc_343606542360_item	3682912	et	3	main
seda	doc_343606542360_item	3682911	et	3	main
tahabgi	doc_343606542360_item	3682910	et	4	main
muidugi	doc_343606542360_item	3682909	et	4	main
reklaamija	doc_343606542360_item	3682908	et	4	main
muud	doc_343606542360_item	3682907	et	4	main
midagi	doc_343606542360_item	3682906	et	4	main
ega	doc_343606542360_item	3682905	et	3	main
nimi	doc_343606542360_item	3682904	et	3	main
huvitav	doc_343606542360_item	3682903	et	4	main
mingisugune	doc_343606542360_item	3682902	et	3	main
on	doc_343606542360_item	3682901	et	4	main
millel	doc_343606542360_item	3682900	et	3	main
reklaam	doc_343606542360_item	3682899	et	3	main
järv	doc_59711134411_item	3682725	et	3	main
see	doc_59711134411_item	3682724	et	3	main
vaatavad	doc_59711134411_item	3682723	et	4	main
oleks	doc_59711134411_item	3682722	et	3	main
koht	doc_59711134411_item	3682716	et	3	main
väga	doc_59711134411_item	3682714	et	3	main
saaremaal	doc_59711134411_item	3682698	et	4	main
on	doc_59711134411_item	3682694	et	4	main
sõbradega	doc_59711134411_item	3682692	et	4	main
asi	doc_343606542360_item	3682920	et	4	main
milles	doc_343606542360_item	3682919	et	3	main
vaatama	doc_343606542360_item	3682918	et	3	main
selline	doc_343606542360_item	3682898	et	4	main
et	doc_343606542360_item	3682890	et	3	main
suhu	doc_343606542360_item	3682889	et	3	main
maitse	doc_343606542360_item	3682888	et	4	main
on	doc_343606542360_item	3682882	et	4	main
reklaamid	doc_343606542360_item	3682881	et	4	main
tapma	doc_343606542360_item	3682869	et	3	main
jääda	doc_343606542360_item	3682868	et	4	main
kurvaks	doc_343606542360_item	3682867	et	3	main
kõiki	doc_343606542360_item	3682855	et	4	main
muidugi	doc_343606542360_item	3682847	et	4	main
arvamuse	doc_343606542360_item	3682846	et	3	main
reklaamist	doc_343606542360_item	3682845	et	4	main
raidi	doc_343606542360_item	3682844	et	3	main
kõik	doc_343606542360_item	3682836	et	4	main
inimene	doc_343606542360_item	3682824	et	3	main
plaanid	doc_59711134411_item	3682814	et	4	main
loodan	doc_59711134411_item	3682811	et	3	main
ilus	doc_59711134411_item	3682780	et	4	main
vaatasime	doc_59711134411_item	3682779	et	3	main
huvitavad	doc_59711134411_item	3682771	et	4	main
palju	doc_59711134411_item	3682770	et	4	main
on	doc_59711134411_item	3682769	et	4	main
ilus	doc_59711134411_item	3682766	et	4	main
viljandis	doc_59711134411_item	3682763	et	4	main
sõitsin	doc_59711134411_item	3682762	et	3	main
tagasi	doc_59711134411_item	3682760	et	3	main
sõbradega	doc_59711134411_item	3682757	et	4	main
eesnimi	doc_399014257207_item	3682990	et	3	main
ma	doc_399014257207_item	3682985	et	3	main
reismasin	doc_399014257207_item	3682983	et	4	main
täpselt	doc_399014257207_item	3682979	et	4	main
detsember	doc_399014257207_item	3682977	et	3	main
me	doc_399014257207_item	3682973	et	4	main
terve	doc_399014257207_item	3682971	et	4	main
kui	doc_399014257207_item	3682968	et	3	main
hommikueine	doc_399014257207_item	3682963	et	4	main
omamasin	doc_399014257207_item	3682959	et	3	main
hasti	doc_399014257207_item	3682957	et	4	main
vaikne	doc_399014257207_item	3682954	et	3	main
tingitud	doc_399014257207_item	3682943	et	4	main
hiljem	doc_399014257207_item	3682942	et	3	main
saabuma	doc_399014257207_item	3682941	et	3	main
cardiffa	doc_399014257207_item	3682940	et	4	main
ma	doc_399014257207_item	3682939	et	3	main
õemees	doc_399014257207_item	3682938	et	4	main
sugugi	doc_399014257207_item	3683053	et	4	main
mitte	doc_399014257207_item	3683052	et	3	main
saaremaal	doc_59711134411_item	3682720	et	4	main
tuntub	doc_59711134411_item	3682715	et	4	main
on	doc_59711134411_item	3682704	et	4	main
seal	doc_59711134411_item	3682703	et	4	main
värtsusi	doc_59711134411_item	3682702	et	2	main
eestis	doc_59711134411_item	3682697	et	3	main
midagi	doc_343606542360_item	3682894	et	4	main
tarbijale	doc_343606542360_item	3682885	et	4	main
kõige	doc_343606542360_item	3682879	et	4	main
reklaamist	doc_343606542360_item	3682866	et	4	main
et	doc_343606542360_item	3682860	et	3	main
miks	doc_343606542360_item	3682853	et	4	main
putukaid	doc_343606542360_item	3682852	et	3	main
kasulikke	doc_343606542360_item	3682851	et	3	main
ka	doc_343606542360_item	3682850	et	3	main
sellisest	doc_343606542360_item	3682843	et	4	main
kirjutas	doc_343606542360_item	3682842	et	3	main
aias	doc_343606542360_item	3682835	et	4	main
lubab	doc_343606542360_item	3682834	et	3	main
kurvem	doc_343606542360_item	3682829	et	4	main
võimatuid	doc_343606542360_item	3682826	et	4	main
panna	doc_343606542360_item	3682823	et	4	main
kerge	doc_343606542360_item	3682822	et	4	main
tänavu	doc_343606542360_item	3682818	et	3	main
arvamus	doc_343606542360_item	3682817	et	3	main
tahan	doc_59711134411_item	3682753	et	3	main
veel	doc_343606542360_item	3682892	et	4	main
tahaks	doc_343606542360_item	3682891	et	3	main
on	doc_343606542360_item	3682870	et	4	main
sellisest	doc_343606542360_item	3682865	et	4	main
saan	doc_343606542360_item	3682858	et	4	main
ma	doc_343606542360_item	3682857	et	3	main
tappa	doc_343606542360_item	3682856	et	4	main
aias	doc_343606542360_item	3682848	et	4	main
mis	doc_343606542360_item	3682833	et	4	main
muidugi	doc_343606542360_item	3682821	et	4	main
see	doc_59711134411_item	3682810	et	3	main
tuletorn	doc_59711134411_item	3682806	et	3	main
vaneim	doc_59711134411_item	3682805	et	4	main
on	doc_59711134411_item	3682804	et	4	main
hiiumal	doc_59711134411_item	3682803	et	4	main
et	doc_59711134411_item	3682802	et	3	main
kuulan	doc_59711134411_item	3682801	et	3	main
ma	doc_59711134411_item	3682800	et	3	main
hiiumaal	doc_59711134411_item	3682799	et	4	main
sõitsida	doc_59711134411_item	3682798	et	2	main
tahan	doc_59711134411_item	3682797	et	3	main
ma	doc_59711134411_item	3682796	et	3	main
aastal	doc_59711134411_item	3682795	et	3	main
sellel	doc_59711134411_item	3682794	et	4	main
pilt	doc_59711134411_item	3682793	et	3	main
ilus	doc_59711134411_item	3682792	et	4	main
väga	doc_59711134411_item	3682791	et	3	main
see	doc_59711134411_item	3682789	et	3	main
oli	doc_59711134411_item	3682787	et	3	main
on	doc_59711134411_item	3682790	et	4	main
lumis	doc_59711134411_item	3682788	et	4	main
ta	doc_59711134411_item	3682786	et	4	main
ja	doc_59711134411_item	3682785	et	3	main
talvel	doc_59711134411_item	3682784	et	4	main
oli	doc_59711134411_item	3682783	et	3	main
see	doc_59711134411_item	3682782	et	3	main
loss	doc_59711134411_item	3682781	et	3	main
koos	doc_59711134411_item	3682775	et	4	main
sõitsin	doc_59711134411_item	3682774	et	3	main
ma	doc_59711134411_item	3682773	et	3	main
kohad	doc_59711134411_item	3682772	et	4	main
aastat	doc_59711134411_item	3682759	et	3	main
sõitsida	doc_59711134411_item	3682754	et	2	main
kedagi	doc_399014257207_item	3682986	et	4	main
ma	doc_399014257207_item	3682982	et	3	main
seesama	doc_399014257207_item	3682980	et	3	main
27	doc_399014257207_item	3682978	et	2	main
sööma	doc_399014257207_item	3682965	et	4	main
ilmastik	doc_399014257207_item	3682945	et	4	main
halb	doc_399014257207_item	3682944	et	3	main
on	doc_399014257207_item	3683051	et	4	main
mul	doc_399014257207_item	3683050	et	3	main
tean	doc_399014257207_item	3683049	et	3	main
mina	doc_399014257207_item	3683048	et	4	main
kui	doc_399014257207_item	3683047	et	3	main
niipalju	doc_399014257207_item	3683046	et	3	main
võtma	doc_399014257207_item	3683045	et	3	main
vaatamata	doc_399014257207_item	3683034	et	4	main
sellele	doc_399014257207_item	3683031	et	4	main
ma	doc_399014257207_item	3683015	et	3	main
tööle	doc_399014257207_item	3683013	et	3	main
aga	doc_399014257207_item	3683010	et	3	main
oli	doc_399014257207_item	3683007	et	3	main
selleks	doc_399014257207_item	3683004	et	4	main
detsember	doc_399014257207_item	3683002	et	3	main
ma	doc_399014257206_item	3683155	et	3	main
beebi	doc_399014257206_item	3683145	et	4	main
kuid	doc_399014257206_item	3683136	et	4	main
puutub	doc_399014257206_item	3683110	et	3	main
aga	doc_399014257206_item	3683108	et	3	main
hasti	doc_399014257206_item	3683106	et	4	main
vaga	doc_399014257206_item	3683105	et	4	main
fi	doc_399014257206_item	3683100	et	4	main
kompakt-plaati	doc_399014257206_item	3683099	et	4	main
kaks	doc_399014257206_item	3683098	et	3	main
mis	doc_399014257206_item	3683094	et	4	main
jooksul	doc_399014257206_item	3683082	et	4	main
kaks	doc_399014257206_item	3683079	et	3	main
hakkan	doc_213943984964_item	3683412	et	3	main
väike	doc_213943984964_item	3683408	et	4	main
ja	doc_213943984964_item	3683405	et	3	main
tudeng	doc_213943984964_item	3683404	et	3	main
põhjus	doc_213943984964_item	3683391	et	4	main
üks	doc_213943984964_item	3683390	et	3	main
korteri	doc_213943984964_item	3683384	et	3	main
maksta	doc_213943984964_item	3683381	et	4	main
kõik	doc_213943984964_item	3683375	et	4	main
et	doc_213943984964_item	3683374	et	3	main
selles	doc_213943984964_item	3683373	et	4	main
aga	doc_213943984964_item	3683366	et	3	main
teises	doc_213943984964_item	3683364	et	4	main
elada	doc_213943984964_item	3683363	et	3	main
tahaksin	doc_213943984964_item	3683362	et	3	main
jne	doc_213943984964_item	3683361	et	4	main
õhtul	doc_213943984964_item	3683346	et	3	main
hilja	doc_213943984964_item	3683345	et	3	main
väga	doc_213943984964_item	3683341	et	3	main
ja	doc_213943984964_item	3683339	et	3	main
on	doc_213943984964_item	3683337	et	4	main
on	doc_213943984964_item	3683329	et	4	main
minu	doc_399014257207_item	3682988	et	3	main
londonisse	doc_399014257207_item	3682984	et	4	main
päev	doc_399014257207_item	3682981	et	3	main
vanemle	doc_399014257207_item	3682975	et	4	main
saaksime	doc_399014257207_item	3682970	et	3	main
palju	doc_399014257207_item	3682967	et	4	main
niisama	doc_399014257207_item	3682966	et	3	main
oli	doc_399014257207_item	3682952	et	3	main
külasin	doc_399014257207_item	3682934	et	4	main
mina	doc_399014257207_item	3682933	et	4	main
küllalt	doc_399014257207_item	3682932	et	4	main
pikk	doc_399014257207_item	3682931	et	4	main
not	doc_399014257207_item	3682930	et	4	main
oli	doc_399014257207_item	3682929	et	3	main
puhkepäev	doc_399014257207_item	3682928	et	3	main
jõulud	doc_399014257207_item	3682927	et	3	main
minu	doc_399014257207_item	3682926	et	3	main
homework	doc_399014257207_item	3682925	et	4	main
estonian	doc_399014257207_item	3682924	et	4	main
essee	doc_399014257207_item	3682923	et	4	main
maha	doc_399014257207_item	3683044	et	4	main
kõigele	doc_399014257207_item	3683033	et	4	main
nimekirja	doc_399014257207_item	3683029	et	4	main
ma	doc_399014257207_item	3683028	et	3	main
uusaasta	doc_399014257207_item	3683027	et	4	main
esimene	doc_399014257207_item	3683026	et	3	main
jaanuar	doc_399014257207_item	3683025	et	3	main
üliõpilane	doc_399014257207_item	3683024	et	3	main
olen	doc_399014257207_item	3683023	et	3	main
ma	doc_399014257207_item	3683022	et	3	main
lõppude	doc_399014257207_item	3683020	et	4	main
ma	doc_399014257207_item	3683011	et	3	main
ma	doc_399014257207_item	3683006	et	3	main
29	doc_399014257207_item	3683003	et	2	main
glasgows	doc_399014257207_item	3683000	et	4	main
järgnev	doc_399014257207_item	3683018	et	4	main
viis	doc_399014257207_item	3683017	et	4	main
töötamasin	doc_399014257207_item	3683016	et	3	main
pean	doc_399014257207_item	3683012	et	4	main
ajaks	doc_399014257207_item	3683005	et	4	main
saabuma	doc_399014257207_item	3683001	et	3	main
ma	doc_399014257207_item	3682999	et	3	main
öö	doc_399014257207_item	3682998	et	4	main
kogu	doc_399014257207_item	3682997	et	4	main
tantsimasin	doc_399014257207_item	3682996	et	4	main
me	doc_399014257207_item	3682995	et	4	main
kokku	doc_399014257207_item	3682994	et	3	main
harva	doc_399014257207_item	3682993	et	4	main
puutume	doc_399014257207_item	3682992	et	4	main
me	doc_399014257207_item	3682991	et	4	main
habemeajamisvesi	doc_399014257206_item	3683153	et	4	main
komplekti	doc_399014257206_item	3683144	et	4	main
hellitama	doc_399014257206_item	3683143	et	3	main
viimaseid	doc_399014257206_item	3683135	et	3	main
samuel	doc_399014257206_item	3683104	et	4	main
ema	doc_399014257206_item	3683097	et	4	main
agar	doc_399014257206_item	3683087	et	4	main
väga	doc_399014257206_item	3683086	et	3	main
püksid	doc_399014257206_item	3683081	et	3	main
ei	doc_399014257206_item	3683124	et	4	main
tema	doc_399014257206_item	3683123	et	4	main
särk	doc_399014257206_item	3683122	et	3	main
kirju	doc_399014257206_item	3683121	et	4	main
uus	doc_399014257206_item	3683120	et	3	main
mehevend	doc_399014257206_item	3683119	et	3	main
minu	doc_399014257206_item	3683118	et	3	main
ostma	doc_399014257206_item	3683117	et	3	main
mina	doc_399014257206_item	3683116	et	4	main
parem	doc_399014257206_item	3683115	et	4	main
on	doc_399014257206_item	3683114	et	4	main
dion	doc_399014257206_item	3683113	et	4	main
celine	doc_399014257206_item	3683112	et	4	main
minussa	doc_399014257206_item	3683111	et	4	main
kahetoaline	doc_213943984964_item	3683409	et	4	main
sobib	doc_213943984964_item	3683407	et	3	main
mulle	doc_213943984964_item	3683406	et	4	main
veel	doc_213943984964_item	3683403	et	4	main
olen	doc_213943984964_item	3683402	et	3	main
ma	doc_213943984964_item	3683401	et	3	main
aga	doc_213943984964_item	3683397	et	3	main
korteris	doc_213943984964_item	3683396	et	3	main
elame	doc_213943984964_item	3683394	et	3	main
me	doc_213943984964_item	3683393	et	4	main
meid	doc_213943984964_item	3683387	et	4	main
rahuldab	doc_213943984964_item	3683386	et	3	main
rohkem	doc_213943984964_item	3683382	et	4	main
saa	doc_213943984964_item	3683380	et	4	main
ei	doc_213943984964_item	3683379	et	4	main
on	doc_213943984964_item	3683372	et	4	main
probleem	doc_213943984964_item	3683371	et	3	main
võimalust	doc_213943984964_item	3683370	et	3	main
või	doc_213943984964_item	3683359	et	4	main
vaatavad	doc_213943984964_item	3683352	et	4	main
liiga	doc_213943984964_item	3683347	et	4	main
mastercard	doc_399014257206_item	3683167	et	4	main
krediitkaart	doc_399014257206_item	3683168	et	4	main
aitah	doc_399014257206_item	3683166	et	4	main
suur	doc_399014257206_item	3683165	et	3	main
mõnikord	doc_399014257206_item	3683164	et	3	main
hasti	doc_399014257206_item	3683163	et	4	main
väga	doc_399014257206_item	3683162	et	3	main
saad	doc_399014257206_item	3683161	et	4	main
auhindi	doc_399014257206_item	3683160	et	4	main
jaoks	doc_399014257206_item	3683159	et	4	main
enda	doc_399014257206_item	3683158	et	4	main
seda	doc_399014257206_item	3683157	et	3	main
jaanuar	doc_399014257206_item	3683150	et	3	main
tema	doc_399014257206_item	3683141	et	4	main
õde	doc_399014257206_item	3683133	et	4	main
mis	doc_399014257206_item	3683109	et	4	main
evelin	doc_399014257206_item	3683103	et	4	main
minu	doc_399014257206_item	3683096	et	3	main
on	doc_399014257206_item	3683085	et	4	main
isa	doc_399014257206_item	3683078	et	4	main
minu	doc_399014257206_item	3683077	et	3	main
ostma	doc_399014257206_item	3683076	et	3	main
mina	doc_399014257206_item	3683075	et	4	main
halvasti	doc_399014257206_item	3683074	et	3	main
väga	doc_399014257206_item	3683073	et	3	main
palju	doc_399014257206_item	3683072	et	4	main
väga	doc_399014257206_item	3683071	et	3	main
kulutama	doc_399014257206_item	3683070	et	4	main
mina	doc_399014257206_item	3683069	et	4	main
poodi	doc_399014257206_item	3683068	et	4	main
jõulud	doc_399014257206_item	3683067	et	3	main
minu	doc_399014257206_item	3683066	et	3	main
lõppis	doc_399014257206_item	3683065	et	3	main
käima	doc_399014257206_item	3683064	et	4	main
mina	doc_399014257206_item	3683063	et	4	main
minema	doc_399014257206_item	3683062	et	3	main
poodi	doc_399014257206_item	3683061	et	4	main
läinud	doc_399014257206_item	3683060	et	4	main
mina	doc_399014257206_item	3683059	et	4	main
eile	doc_399014257206_item	3683058	et	3	main
poodi	doc_399014257206_item	3683057	et	4	main
läheme	doc_399014257206_item	3683056	et	3	main
essee	doc_399014257206_item	3683055	et	4	main
minu	doc_399014257206_item	3683132	et	3	main
kumbki	doc_399014257206_item	3683131	et	4	main
ei	doc_399014257206_item	3683130	et	4	main
mulle	doc_399014257206_item	3683129	et	4	main
riided	doc_399014257206_item	3683128	et	3	main
omama	doc_399014257206_item	3683127	et	4	main
maitset	doc_399014257206_item	3683126	et	3	main
head	doc_399014257206_item	3683125	et	4	main
on	doc_399014257206_item	3683147	et	4	main
tähtaeg	doc_399014257206_item	3683146	et	3	main
ostma	doc_399014257206_item	3683140	et	3	main
on	doc_399014257206_item	3683134	et	4	main
laulja	doc_399014257206_item	3683107	et	4	main
divo	doc_399014257206_item	3683101	et	4	main
puutub	doc_399014257206_item	3683095	et	3	main
meeldi	doc_399014257206_item	3683091	et	4	main
tema	doc_399014257206_item	3683084	et	4	main
rohelised	doc_399014257206_item	3683080	et	4	main
kui	doc_213943984964_item	3683411	et	3	main
viga	doc_213943984964_item	3683400	et	4	main
ikkagi	doc_213943984964_item	3683398	et	4	main
selles	doc_213943984964_item	3683395	et	4	main
miks	doc_213943984964_item	3683392	et	4	main
tasu	doc_213943984964_item	3683385	et	4	main
rahast	doc_213943984964_item	3683377	et	4	main
sõltub	doc_213943984964_item	3683376	et	3	main
praegu	doc_213943984964_item	3683367	et	3	main
või	doc_213943984964_item	3683351	et	4	main
muusikat	doc_213943984964_item	3683350	et	3	main
kõvasti	doc_213943984964_item	3683348	et	3	main
väga	doc_213943984964_item	3683330	et	3	main
mind	doc_213943984964_item	3683321	et	4	main
häirib	doc_213943984964_item	3683320	et	3	main
jääda	doc_213943984964_item	3683319	et	4	main
talvel	doc_213943984964_item	3683316	et	4	main
mulle	doc_213943984964_item	3683302	et	4	main
meeldi	doc_213943984964_item	3683301	et	4	main
et	doc_213943984964_item	3683300	et	3	main
kõigepealt	doc_213943984964_item	3683299	et	3	main
seisukorras	doc_213943984964_item	3683298	et	3	main
vanas	doc_213943984964_item	3683293	et	3	main
me	doc_213943984964_item	3683290	et	4	main
ei	doc_213943984964_item	3683285	et	4	main
korteriperenaine	doc_213943984964_item	3683279	et	3	main
tallinnas	doc_213943984964_item	3683274	et	4	main
tänavad	doc_213943984964_item	3683272	et	4	main
ühest	doc_213943984964_item	3683261	et	4	main
hästi	doc_213943984964_item	3683259	et	3	main
kui	doc_213943984964_item	3683258	et	3	main
lähedal	doc_213943984964_item	3683257	et	4	main
asuvad	doc_213943984964_item	3683256	et	4	main
kuna	doc_213943984964_item	3683251	et	3	main
mugavaks	doc_213943984964_item	3683250	et	3	main
teeb	doc_213943984964_item	3683249	et	3	main
see	doc_213943984964_item	3683248	et	3	main
et	doc_213943984964_item	3683244	et	3	main
selle	doc_213943984964_item	3683242	et	4	main
harjunud	doc_213943984964_item	3683236	et	4	main
ümbrusele	doc_213943984964_item	3683222	et	3	main
aastat	doc_213943984964_item	3683206	et	3	main
valikut	doc_213943984964_item	3683196	et	3	main
eraldi	doc_213943984964_item	3683178	et	4	main
elan	doc_213943984964_item	3683177	et	3	main
ma	doc_213943984964_item	3683176	et	3	main
aastat	doc_213943984964_item	3683175	et	3	main
pool	doc_213943984964_item	3683174	et	4	main
juba	doc_213943984964_item	3683173	et	3	main
korter	doc_213943984964_item	3683172	et	3	main
minu	doc_213943984964_item	3683171	et	3	main
essee	doc_213943984964_item	3683170	et	4	main
mul	doc_491521501997_item	3683455	et	3	main
ei	doc_491521501997_item	3683453	et	4	main
ma	doc_491521501997_item	3683452	et	3	main
praegu	doc_491521501997_item	3683451	et	3	main
laborantina	doc_491521501997_item	3683450	et	4	main
töötasin	doc_491521501997_item	3683449	et	3	main
ma	doc_491521501997_item	3683448	et	3	main
polütehnikumis	doc_491521501997_item	3683443	et	3	main
aga	doc_491521501997_item	3683439	et	3	main
sündisin	doc_491521501997_item	3683437	et	3	main
tahan	doc_213943984964_item	3683420	et	3	main
ma	doc_213943984964_item	3683419	et	3	main
mida	doc_213943984964_item	3683418	et	4	main
korteri	doc_213943984964_item	3683417	et	3	main
ostan	doc_213943984964_item	3683416	et	3	main
siis	doc_213943984964_item	3683415	et	3	main
teenima	doc_213943984964_item	3683414	et	3	main
raha	doc_213943984964_item	3683413	et	4	main
on	doc_213943984964_item	3683389	et	4	main
see	doc_213943984964_item	3683388	et	3	main
aga	doc_213943984964_item	3683383	et	3	main
ei	doc_213943984964_item	3683368	et	4	main
kohas	doc_213943984964_item	3683365	et	4	main
tikkud	doc_213943984964_item	3683358	et	4	main
küsivad	doc_213943984964_item	3683357	et	4	main
ja	doc_213943984964_item	3683356	et	3	main
koputavad	doc_213943984964_item	3683355	et	4	main
kuulavad	doc_213943984964_item	3683349	et	4	main
esimesel	doc_213943984964_item	3683326	et	3	main
asub	doc_213943984964_item	3683325	et	3	main
et	doc_213943984964_item	3683323	et	3	main
naabrid	doc_213943984964_item	3683344	et	3	main
tihti	doc_213943984964_item	3683342	et	3	main
aeg	doc_213943984964_item	3683336	et	3	main
põrand	doc_213943984964_item	3683328	et	3	main
korter	doc_213943984964_item	3683324	et	3	main
mitte	doc_213943984964_item	3683317	et	3	main
et	doc_213943984964_item	3683315	et	3	main
võtta	doc_213943984964_item	3683312	et	3	main
majas	doc_213943984964_item	3683294	et	3	main
mõttet	doc_213943984964_item	3683287	et	4	main
ole	doc_213943984964_item	3683286	et	4	main
omamoodi	doc_213943984964_item	3683284	et	3	main
ole	doc_213943984964_item	3683278	et	4	main
liiga	doc_213943984964_item	3683270	et	4	main
küljest	doc_213943984964_item	3683269	et	4	main
küljest	doc_213943984964_item	3683262	et	4	main
paigad	doc_213943984964_item	3683254	et	3	main
kõik	doc_213943984964_item	3683252	et	4	main
ta	doc_213943984964_item	3683245	et	4	main
esiteks	doc_213943984964_item	3683237	et	3	main
elades	doc_213943984964_item	3683223	et	4	main
me	doc_213943984964_item	3683207	et	4	main
kaks	doc_213943984964_item	3683205	et	3	main
elab	doc_213943984964_item	3683203	et	3	main
minu	doc_213943984964_item	3683200	et	3	main
pärast	doc_213943984964_item	3683198	et	4	main
korteris	doc_213943984964_item	3683193	et	3	main
kas	doc_213943984964_item	3683190	et	3	main
abikassa	doc_491521501997_item	3683463	et	4	main
perekond	doc_491521501997_item	3683458	et	3	main
tööta	doc_491521501997_item	3683454	et	4	main
praegu	doc_491521501997_item	3683444	et	3	main
vana	doc_491521501997_item	3683431	et	4	main
aastat	doc_491521501997_item	3683430	et	3	main
nelikümand	doc_491521501997_item	3683429	et	4	main
olen	doc_491521501997_item	3683428	et	3	main
on	doc_491521501997_item	3683425	et	4	main
nimi	doc_491521501997_item	3683424	et	3	main
minu	doc_491521501997_item	3683423	et	3	main
essee	doc_491521501997_item	3683422	et	4	main
lõpetasin	doc_491521501997_item	3683498	et	3	main
vana	doc_491521501997_item	3683496	et	4	main
aatat	doc_491521501997_item	3683495	et	4	main
kaheksatist	doc_491521501997_item	3683494	et	4	main
katja	doc_491521501997_item	3683483	et	4	main
irina	doc_491521501997_item	3683478	et	3	main
nimi	doc_491521501997_item	3683476	et	3	main
minu	doc_634572338205_item	3683651	et	3	main
loodan	doc_634572338205_item	3683649	et	3	main
vaadata	doc_634572338205_item	3683647	et	4	main
tahan	doc_634572338205_item	3683635	et	3	main
sellel	doc_634572338205_item	3683632	et	4	main
koos	doc_634572338205_item	3683613	et	4	main
sõitsin	doc_634572338205_item	3683612	et	3	main
on	doc_634572338205_item	3683607	et	4	main
viljandis	doc_634572338205_item	3683601	et	4	main
minu	doc_634572338205_item	3683594	et	3	main
kus	doc_634572338205_item	3683589	et	3	main
on	doc_634572338205_item	3683585	et	4	main
tean	doc_634572338205_item	3683582	et	3	main
saaremaal	doc_634572338205_item	3683571	et	4	main
sõitsime	doc_634572338205_item	3683570	et	3	main
me	doc_634572338205_item	3683569	et	4	main
kui	doc_634572338205_item	3683568	et	3	main
järv	doc_634572338205_item	3683563	et	3	main
et	doc_634572338205_item	3683559	et	3	main
saaremaal	doc_634572338205_item	3683558	et	4	main
turistid	doc_634572338205_item	3683556	et	3	main
alt	doc_213943984964_item	3683334	et	4	main
akna	doc_213943984964_item	3683333	et	3	main
ja	doc_213943984964_item	3683332	et	3	main
külm	doc_213943984964_item	3683331	et	3	main
korrusel	doc_213943984964_item	3683327	et	3	main
see	doc_213943984964_item	3683322	et	3	main
külmeks	doc_213943984964_item	3683318	et	3	main
puid	doc_213943984964_item	3683314	et	3	main
piisavalt	doc_213943984964_item	3683313	et	4	main
probleemi	doc_213943984964_item	3683310	et	4	main
tekitab	doc_213943984964_item	3683308	et	3	main
on	doc_213943984964_item	3683306	et	4	main
kehvas	doc_213943984964_item	3683297	et	3	main
väga	doc_213943984964_item	3683292	et	3	main
midagi	doc_213943984964_item	3683288	et	4	main
korterierat	doc_213943984964_item	3683283	et	4	main
teha	doc_213943984964_item	3683282	et	3	main
saa	doc_213943984964_item	3683281	et	4	main
ei	doc_213943984964_item	3683277	et	4	main
ma	doc_213943984964_item	3683276	et	3	main
on	doc_213943984964_item	3683273	et	4	main
müüra	doc_213943984964_item	3683271	et	4	main
hea	doc_213943984964_item	3683266	et	4	main
väga	doc_213943984964_item	3683265	et	3	main
on	doc_213943984964_item	3683264	et	4	main
see	doc_213943984964_item	3683263	et	3	main
vajalikud	doc_213943984964_item	3683253	et	3	main
kesklinnas	doc_213943984964_item	3683247	et	4	main
tingimused	doc_213943984964_item	3683233	et	3	main
halveme	doc_213943984964_item	3683231	et	4	main
maal	doc_213943984964_item	3683224	et	4	main
õde	doc_213943984964_item	3683202	et	4	main
vanem	doc_213943984964_item	3683201	et	4	main
et	doc_213943984964_item	3683199	et	3	main
mul	doc_213943984964_item	3683194	et	3	main
või	doc_213943984964_item	3683192	et	4	main
kus	doc_213943984964_item	3683188	et	3	main
tekkinud	doc_213943984964_item	3683186	et	4	main
minu	doc_491521501997_item	3683462	et	3	main
on	doc_491521501997_item	3683456	et	4	main
ma	doc_491521501997_item	3683445	et	3	main
valgeneskeskkoolis	doc_491521501997_item	3683441	et	4	main
kazahstanis	doc_491521501997_item	3683438	et	4	main
haridus	doc_491521501997_item	3683435	et	3	main
kesk-tehniline	doc_491521501997_item	3683434	et	3	main
on	doc_491521501997_item	3683433	et	4	main
mul	doc_491521501997_item	3683432	et	3	main
on	doc_491521501997_item	3683493	et	4	main
vana	doc_491521501997_item	3683488	et	4	main
aastat	doc_491521501997_item	3683487	et	3	main
tütar	doc_491521501997_item	3683480	et	3	main
on	doc_491521501997_item	3683477	et	4	main
vanem	doc_491521501997_item	3683474	et	4	main
tütard	doc_491521501997_item	3683473	et	4	main
me	doc_634572338205_item	3683616	et	4	main
palju	doc_634572338205_item	3683608	et	4	main
sõitsin	doc_634572338205_item	3683600	et	3	main
sõbradega	doc_634572338205_item	3683595	et	4	main
ilusad	doc_634572338205_item	3683587	et	3	main
tuntuvaid	doc_634572338205_item	3683574	et	4	main
küllastasime	doc_634572338205_item	3683573	et	3	main
palju	doc_634572338205_item	3683566	et	4	main
tuntub	doc_634572338205_item	3683553	et	4	main
on	doc_634572338205_item	3683551	et	4	main
järv	doc_634572338205_item	3683549	et	3	main
kulutusi	doc_842434202401_item	3683769	et	4	main
teoreetiliselt	doc_842434202401_item	3683767	et	4	main
kust	doc_213943984964_item	3683311	et	4	main
palju	doc_213943984964_item	3683309	et	4	main
ahjuküte	doc_213943984964_item	3683307	et	3	main
korteris	doc_213943984964_item	3683305	et	3	main
et	doc_213943984964_item	3683304	et	3	main
see	doc_213943984964_item	3683303	et	3	main
mis	doc_213943984964_item	3683295	et	4	main
elame	doc_213943984964_item	3683291	et	3	main
ei	doc_213943984964_item	3683280	et	4	main
kuna	doc_213943984964_item	3683275	et	3	main
teisest	doc_213943984964_item	3683268	et	4	main
aga	doc_213943984964_item	3683267	et	3	main
mõelda	doc_213943984964_item	3683260	et	4	main
hooned	doc_213943984964_item	3683255	et	4	main
uus	doc_213943984964_item	3683240	et	3	main
kiita	doc_213943984964_item	3683239	et	4	main
juba	doc_213943984964_item	3683235	et	3	main
ette	doc_213943984964_item	3683227	et	4	main
kujutanud	doc_213943984964_item	3683226	et	4	main
pole	doc_213943984964_item	3683225	et	3	main
selle	doc_213943984964_item	3683197	et	4	main
vanematest	doc_213943984964_item	3683179	et	4	main
on	doc_213943984964_item	3683296	et	4	main
muuta	doc_213943984964_item	3683289	et	4	main
asub	doc_213943984964_item	3683246	et	3	main
eest	doc_213943984964_item	3683243	et	4	main
korterit	doc_213943984964_item	3683241	et	3	main
tahan	doc_213943984964_item	3683238	et	3	main
olen	doc_213943984964_item	3683234	et	3	main
elu	doc_213943984964_item	3683232	et	4	main
on	doc_213943984964_item	3683230	et	4	main
pealinnas	doc_213943984964_item	3683229	et	4	main
et	doc_213943984964_item	3683228	et	3	main
adapteerida	doc_213943984964_item	3683221	et	3	main
oli	doc_213943984964_item	3683220	et	3	main
raske	doc_213943984964_item	3683219	et	4	main
jaoks	doc_213943984964_item	3683218	et	4	main
minu	doc_213943984964_item	3683217	et	3	main
kodu	doc_213943984964_item	3683216	et	4	main
oma	doc_213943984964_item	3683215	et	4	main
meenuta	doc_213943984964_item	3683214	et	4	main
ei	doc_213943984964_item	3683213	et	4	main
midagi	doc_213943984964_item	3683212	et	4	main
mitte	doc_213943984964_item	3683211	et	3	main
kui	doc_213943984964_item	3683210	et	3	main
korterit	doc_213943984964_item	3683209	et	3	main
üürime	doc_213943984964_item	3683208	et	3	main
tallinnas	doc_213943984964_item	3683204	et	4	main
pole	doc_213943984964_item	3683195	et	3	main
ühiselamuses	doc_213943984964_item	3683191	et	3	main
elada	doc_213943984964_item	3683189	et	3	main
küsimust	doc_213943984964_item	3683187	et	4	main
pole	doc_213943984964_item	3683185	et	3	main
mul	doc_213943984964_item	3683184	et	3	main
pealinnasse	doc_213943984964_item	3683183	et	4	main
kolisin	doc_213943984964_item	3683182	et	3	main
ma	doc_213943984964_item	3683181	et	3	main
kui	doc_213943984964_item	3683180	et	3	main
ma	doc_491521501997_item	3683459	et	3	main
suur	doc_491521501997_item	3683457	et	3	main
elan	doc_491521501997_item	3683446	et	3	main
pärast	doc_491521501997_item	3683442	et	4	main
õppisin	doc_491521501997_item	3683440	et	3	main
katja	doc_491521501997_item	3683497	et	4	main
töötu	doc_491521501997_item	3683491	et	4	main
on	doc_491521501997_item	3683485	et	4	main
irina	doc_491521501997_item	3683484	et	3	main
noorema	doc_491521501997_item	3683479	et	4	main
tütar	doc_491521501997_item	3683475	et	3	main
realiseeruma	doc_634572338205_item	3683653	et	3	main
see	doc_634572338205_item	3683648	et	3	main
tahn	doc_634572338205_item	3683646	et	4	main
ma	doc_634572338205_item	3683645	et	3	main
tuletorn	doc_634572338205_item	3683644	et	3	main
vaneim	doc_634572338205_item	3683643	et	4	main
sõitsida	doc_634572338205_item	3683636	et	2	main
oli	doc_634572338205_item	3683625	et	3	main
vanemad	doc_634572338205_item	3683615	et	4	main
minu	doc_634572338205_item	3683614	et	3	main
huvitavad	doc_634572338205_item	3683609	et	4	main
ilus	doc_634572338205_item	3683604	et	4	main
ma	doc_634572338205_item	3683599	et	3	main
tagasi	doc_634572338205_item	3683598	et	3	main
kohad	doc_634572338205_item	3683588	et	4	main
et	doc_634572338205_item	3683583	et	3	main
toila	doc_634572338205_item	3683579	et	4	main
ontika	doc_634572338205_item	3683577	et	4	main
on	doc_634572338205_item	3683565	et	4	main
saaremaal	doc_634572338205_item	3683564	et	4	main
väga	doc_634572338205_item	3683552	et	3	main
tahavad	doc_842434202401_item	3683755	et	3	main
ma	doc_842434202401_item	3683743	et	3	main
võtta	doc_842434202401_item	3683730	et	3	main
maksuvaba	doc_842434202401_item	3683727	et	4	main
on	doc_842434202401_item	3683719	et	4	main
just	doc_842434202401_item	3683715	et	3	main
tuntuks	doc_842434202401_item	3683706	et	4	main
äri	doc_842434202401_item	3683692	et	4	main
kellel	doc_842434202401_item	3683691	et	4	main
selles	doc_842434202401_item	3683671	et	4	main
rohkem	doc_881412446067_item	3684062	et	4	main
värsket	doc_881412446067_item	3684050	et	4	main
me	doc_881412446067_item	3684048	et	4	main
on	doc_881412446067_item	3684025	et	4	main
seisukoht	doc_881412446067_item	3684024	et	3	main
sellel	doc_881412446067_item	3684009	et	4	main
metsalagendikut	doc_881412446067_item	3683991	et	4	main
kultuurselt	doc_881412446067_item	3683980	et	4	main
inimesed	doc_881412446067_item	3683976	et	3	main
šašlõkki	doc_881412446067_item	3683972	et	2	main
sõpradega	doc_881412446067_item	3683970	et	3	main
sugulaste	doc_881412446067_item	3683968	et	4	main
oma	doc_881412446067_item	3683967	et	4	main
jaoks	doc_881412446067_item	3683956	et	4	main
minu	doc_881412446067_item	3683955	et	3	main
kasutada	doc_881412446067_item	3683951	et	3	main
ajal	doc_881412446067_item	3683936	et	4	main
samal	doc_881412446067_item	3683935	et	3	main
minu	doc_881412446067_item	3683928	et	3	main
ühele	doc_881412446067_item	3683927	et	3	main
praegu	doc_881412446067_item	3683926	et	3	main
neid	doc_881412446067_item	3683925	et	4	main
sellega	doc_881412446067_item	3683892	et	3	main
oma	doc_881412446067_item	3683886	et	4	main
paremiseks	doc_881412446067_item	3683879	et	4	main
nimelt	doc_881412446067_item	3683874	et	4	main
teen	doc_881412446067_item	3683873	et	3	main
mida	doc_881412446067_item	3683872	et	4	main
ainult	doc_881412446067_item	3683859	et	4	main
lügeda	doc_491521501997_item	3683512	et	4	main
meldib	doc_491521501997_item	3683511	et	4	main
mülle	doc_491521501997_item	3683510	et	4	main
infotehnoloog	doc_491521501997_item	3683509	et	4	main
eriala	doc_491521501997_item	3683508	et	4	main
отделение	doc_491521501997_item	3683507	et	2	main
osakonda	doc_491521501997_item	3683506	et	4	main
kõrgemasse	doc_491521501997_item	3683505	et	4	main
pölütehnikumi	doc_491521501997_item	3683504	et	4	main
kohtla-järve	doc_491521501997_item	3683503	et	4	main
astub	doc_491521501997_item	3683502	et	3	main
ta	doc_491521501997_item	3683501	et	4	main
gümnaasiumis	doc_491521501997_item	3683500	et	3	main
kohtla-järvel	doc_491521501997_item	3683499	et	4	main
abielus	doc_491521501997_item	3683461	et	4	main
olen	doc_491521501997_item	3683460	et	3	main
kohtla-järvel	doc_491521501997_item	3683447	et	4	main
ma	doc_491521501997_item	3683427	et	3	main
katja	doc_491521501997_item	3683492	et	4	main
kakskümand	doc_491521501997_item	3683486	et	4	main
kaks	doc_491521501997_item	3683472	et	3	main
on	doc_491521501997_item	3683471	et	4	main
mul	doc_491521501997_item	3683470	et	3	main
elektriik	doc_491521501997_item	3683469	et	4	main
on	doc_491521501997_item	3683468	et	4	main
ta	doc_491521501997_item	3683467	et	4	main
eesnimi	doc_491521501997_item	3683466	et	3	main
on	doc_491521501997_item	3683465	et	4	main
nimi	doc_491521501997_item	3683464	et	3	main
on	doc_634572338205_item	3683642	et	4	main
on	doc_634572338205_item	3683628	et	4	main
see	doc_634572338205_item	3683627	et	3	main
lumis	doc_634572338205_item	3683626	et	4	main
ma	doc_634572338205_item	3683611	et	3	main
viljandis	doc_634572338205_item	3683606	et	4	main
väga	doc_634572338205_item	3683603	et	3	main
kaks	doc_634572338205_item	3683596	et	3	main
sõitsida	doc_634572338205_item	3683592	et	2	main
park	doc_634572338205_item	3683580	et	3	main
talud	doc_634572338205_item	3683567	et	4	main
see	doc_634572338205_item	3683562	et	3	main
sõitsivad	doc_634572338205_item	3683557	et	2	main
ma	doc_491521501997_item	3683436	et	3	main
eesnimi	doc_491521501997_item	3683426	et	3	main
on	doc_491521501997_item	3683490	et	4	main
ta	doc_491521501997_item	3683489	et	4	main
on	doc_491521501997_item	3683482	et	4	main
nimi	doc_491521501997_item	3683481	et	3	main
plaanid	doc_634572338205_item	3683652	et	4	main
et	doc_634572338205_item	3683650	et	3	main
hiiumal	doc_634572338205_item	3683641	et	4	main
et	doc_634572338205_item	3683640	et	3	main
kuulan	doc_634572338205_item	3683639	et	3	main
ma	doc_634572338205_item	3683638	et	3	main
hiiumaal	doc_634572338205_item	3683637	et	4	main
ma	doc_634572338205_item	3683634	et	3	main
aastal	doc_634572338205_item	3683633	et	3	main
pilt	doc_634572338205_item	3683631	et	3	main
ilus	doc_634572338205_item	3683630	et	4	main
väga	doc_634572338205_item	3683629	et	3	main
ta	doc_634572338205_item	3683624	et	4	main
ja	doc_634572338205_item	3683623	et	3	main
talvel	doc_634572338205_item	3683622	et	4	main
oli	doc_634572338205_item	3683621	et	3	main
see	doc_634572338205_item	3683620	et	3	main
loss	doc_634572338205_item	3683619	et	3	main
ilus	doc_634572338205_item	3683618	et	4	main
vaatasime	doc_634572338205_item	3683617	et	3	main
kohad	doc_634572338205_item	3683610	et	4	main
linn	doc_634572338205_item	3683605	et	3	main
see	doc_634572338205_item	3683602	et	3	main
aastat	doc_634572338205_item	3683597	et	3	main
koos	doc_634572338205_item	3683593	et	4	main
tahan	doc_634572338205_item	3683591	et	3	main
ma	doc_634572338205_item	3683590	et	3	main
palju	doc_634572338205_item	3683586	et	4	main
eestis	doc_634572338205_item	3683584	et	3	main
ma	doc_634572338205_item	3683581	et	3	main
ja	doc_634572338205_item	3683578	et	3	main
näiteks	doc_634572338205_item	3683576	et	4	main
kohti	doc_634572338205_item	3683575	et	4	main
me	doc_634572338205_item	3683572	et	4	main
vaatavad	doc_634572338205_item	3683561	et	4	main
oleks	doc_634572338205_item	3683560	et	3	main
palju	doc_634572338205_item	3683555	et	4	main
koht	doc_634572338205_item	3683554	et	3	main
näitavad	doc_842434202401_item	3683764	et	4	main
samuti	doc_842434202401_item	3683763	et	3	main
ja	doc_842434202401_item	3683762	et	3	main
hoida	doc_842434202401_item	3683761	et	3	main
kokku	doc_842434202401_item	3683760	et	3	main
rohkem	doc_842434202401_item	3683751	et	4	main
püüab	doc_842434202401_item	3683750	et	3	main
riik	doc_842434202401_item	3683749	et	3	main
kui	doc_842434202401_item	3683748	et	3	main
samuti	doc_842434202401_item	3683747	et	3	main
maksma	doc_842434202401_item	3683746	et	3	main
maksu	doc_842434202401_item	3683745	et	4	main
hüvitamisest	doc_842434202401_item	3683741	et	4	main
ainult	doc_842434202401_item	3683731	et	4	main
tulu	doc_842434202401_item	3683728	et	4	main
võib	doc_842434202401_item	3683726	et	3	main
arvutamisel	doc_842434202401_item	3683725	et	4	main
tulumaksu	doc_842434202401_item	3683724	et	4	main
kui	doc_842434202401_item	3683717	et	3	main
sellepärast	doc_842434202401_item	3683716	et	3	main
ja	doc_842434202401_item	3683714	et	3	main
suureks	doc_842434202401_item	3683705	et	4	main
neile	doc_842434202401_item	3683703	et	4	main
kahjum	doc_842434202401_item	3683702	et	3	main
see	doc_842434202401_item	3683701	et	3	main
olukorda	doc_842434202401_item	3683697	et	4	main
lähe	doc_842434202401_item	3683695	et	4	main
ei	doc_842434202401_item	3683694	et	4	main
hästi	doc_842434202401_item	3683693	et	3	main
see	doc_634572338205_item	3683550	et	3	main
tänapäeval	doc_634572338205_item	3683547	et	3	main
on	doc_634572338205_item	3683548	et	4	main
mis	doc_634572338205_item	3683546	et	4	main
kraater	doc_634572338205_item	3683545	et	2	main
meteoriiti	doc_634572338205_item	3683544	et	4	main
asub	doc_634572338205_item	3683543	et	3	main
on	doc_634572338205_item	3683542	et	4	main
seal	doc_634572338205_item	3683541	et	4	main
värtsusi	doc_634572338205_item	3683540	et	2	main
vaatamis	doc_634572338205_item	3683539	et	4	main
palju	doc_634572338205_item	3683538	et	4	main
on	doc_634572338205_item	3683537	et	4	main
saaremaal	doc_634572338205_item	3683536	et	4	main
eestis	doc_634572338205_item	3683535	et	3	main
saar	doc_634572338205_item	3683534	et	3	main
suureim	doc_634572338205_item	3683533	et	4	main
on	doc_634572338205_item	3683532	et	4	main
saaremaa	doc_634572338205_item	3683531	et	4	main
sõbradega	doc_634572338205_item	3683530	et	4	main
minu	doc_634572338205_item	3683529	et	3	main
koos	doc_634572338205_item	3683528	et	4	main
sõtsin	doc_634572338205_item	3683527	et	4	main
ma	doc_634572338205_item	3683526	et	3	main
saaremaal	doc_634572338205_item	3683525	et	4	main
olin	doc_634572338205_item	3683524	et	3	main
ma	doc_634572338205_item	3683523	et	3	main
aastal	doc_634572338205_item	3683522	et	3	main
eelmisel	doc_634572338205_item	3683521	et	3	main
vaatasin	doc_634572338205_item	3683520	et	3	main
ma	doc_634572338205_item	3683519	et	3	main
mis	doc_634572338205_item	3683518	et	4	main
olin	doc_634572338205_item	3683517	et	3	main
ma	doc_634572338205_item	3683516	et	3	main
kus	doc_634572338205_item	3683515	et	3	main
essee	doc_634572338205_item	3683514	et	4	main
seotud	doc_842434202401_item	3683768	et	4	main
korjata	doc_842434202401_item	3683754	et	4	main
kokku	doc_842434202401_item	3683753	et	3	main
raha	doc_842434202401_item	3683752	et	4	main
pean	doc_842434202401_item	3683742	et	4	main
on	doc_842434202401_item	3683735	et	4	main
töökohas	doc_842434202401_item	3683733	et	4	main
ühes	doc_842434202401_item	3683732	et	4	main
arvesse	doc_842434202401_item	3683729	et	4	main
töökohta	doc_842434202401_item	3683721	et	4	main
töötajal	doc_842434202401_item	3683718	et	4	main
on	doc_842434202401_item	3683772	et	4	main
tegelikus	doc_842434202401_item	3683773	et	4	main
kui	doc_842434202401_item	3683771	et	3	main
suuremaid	doc_842434202401_item	3683770	et	4	main
raha	doc_842434202401_item	3683759	et	4	main
selle	doc_842434202401_item	3683740	et	4	main
tekitanud	doc_842434202401_item	3683738	et	4	main
mulle	doc_842434202401_item	3683736	et	4	main
mitu	doc_842434202401_item	3683720	et	4	main
huvides	doc_842434202401_item	3683713	et	3	main
mitte	doc_842434202401_item	3683711	et	3	main
eriti	doc_842434202401_item	3683704	et	3	main
et	doc_842434202401_item	3683700	et	3	main
võimaluse	doc_842434202401_item	3683689	et	3	main
annab	doc_842434202401_item	3683688	et	3	main
see	doc_842434202401_item	3683687	et	3	main
rohkem	doc_842434202401_item	3683686	et	4	main
oleks	doc_842434202401_item	3683685	et	3	main
maksjaid	doc_842434202401_item	3683684	et	4	main
maksu	doc_842434202401_item	3683683	et	4	main
et	doc_842434202401_item	3683682	et	3	main
huvitatud	doc_842434202401_item	3683681	et	4	main
on	doc_842434202401_item	3683680	et	4	main
riik	doc_842434202401_item	3683679	et	3	main
tulumaksust	doc_842434202401_item	3683678	et	4	main
vabastatud	doc_842434202401_item	3683677	et	4	main
on	doc_842434202401_item	3683676	et	4	main
kasum	doc_842434202401_item	3683675	et	3	main
taasinvesteeritud	doc_842434202401_item	3683674	et	4	main
et	doc_842434202401_item	3683672	et	3	main
tulumaksuseaduse	doc_842434202401_item	3683668	et	3	main
on	doc_842434202401_item	3683663	et	4	main
summa	doc_842434202401_item	3683661	et	4	main
inemesed	doc_881412446067_item	3684060	et	4	main
maailma	doc_881412446067_item	3684043	et	4	main
olema	doc_881412446067_item	3684031	et	4	main
rangem	doc_881412446067_item	3684030	et	4	main
minu	doc_881412446067_item	3684023	et	3	main
metsaraie	doc_881412446067_item	3684019	et	4	main
loodust	doc_881412446067_item	3684014	et	4	main
jargmises	doc_881412446067_item	3684012	et	4	main
ka	doc_881412446067_item	3684011	et	3	main
kohal	doc_881412446067_item	3684010	et	4	main
ju	doc_881412446067_item	3684005	et	3	main
samasugune	doc_881412446067_item	3684001	et	3	main
puhast	doc_881412446067_item	3683990	et	3	main
saa	doc_881412446067_item	3683979	et	4	main
mõned	doc_881412446067_item	3683975	et	3	main
aega	doc_881412446067_item	3683966	et	4	main
paljudele	doc_881412446067_item	3683962	et	3	main
tähtis	doc_881412446067_item	3683959	et	4	main
järgi	doc_881412446067_item	3683953	et	4	main
tihti	doc_881412446067_item	3683943	et	3	main
ja	doc_881412446067_item	3683934	et	3	main
meeldib	doc_881412446067_item	3683931	et	3	main
kasuta	doc_881412446067_item	3683924	et	4	main
vaatamata	doc_881412446067_item	3683919	et	4	main
elektrotehnika	doc_881412446067_item	3683918	et	4	main
kõik	doc_881412446067_item	3683917	et	4	main
vee	doc_881412446067_item	3683884	et	3	main
ma	doc_881412446067_item	3683881	et	3	main
ja	doc_881412446067_item	3683865	et	3	main
oma	doc_881412446067_item	3683863	et	4	main
firmaga	doc_842434202401_item	3683766	et	3	main
oma	doc_842434202401_item	3683765	et	4	main
oma	doc_842434202401_item	3683758	et	4	main
ettevõtted	doc_842434202401_item	3683757	et	3	main
ka	doc_842434202401_item	3683756	et	3	main
veel	doc_842434202401_item	3683744	et	4	main
ja	doc_842434202401_item	3683739	et	3	main
kahju	doc_842434202401_item	3683737	et	4	main
keegi	doc_842434202401_item	3683734	et	4	main
kinnipeetava	doc_842434202401_item	3683723	et	4	main
siis	doc_842434202401_item	3683722	et	3	main
summa	doc_842434202401_item	3683709	et	4	main
maksuvaba	doc_842434202401_item	3683708	et	4	main
2	doc_842434202401_item	3683707	et	2	main
ilma	doc_842434202401_item	3683699	et	4	main
ettevõttesse	doc_842434202401_item	3683673	et	4	main
suurendamine	doc_842434202401_item	3683662	et	4	main
nägema	doc_881412446067_item	3684058	et	3	main
et	doc_881412446067_item	3684055	et	3	main
tahan	doc_881412446067_item	3684053	et	3	main
töö	doc_881412446067_item	3684046	et	4	main
see	doc_881412446067_item	3684040	et	3	main
teadma	doc_881412446067_item	3684037	et	3	main
väga	doc_881412446067_item	3684020	et	3	main
liigne	doc_881412446067_item	3684018	et	3	main
vaja	doc_881412446067_item	3684016	et	4	main
puhata	doc_881412446067_item	3684008	et	4	main
tahaksime	doc_881412446067_item	3684007	et	3	main
me	doc_881412446067_item	3684006	et	4	main
puhkuse	doc_881412446067_item	3683996	et	3	main
jaoks	doc_881412446067_item	3683993	et	4	main
puhkuse	doc_881412446067_item	3683992	et	3	main
kaunist	doc_881412446067_item	3683989	et	4	main
väikset	doc_881412446067_item	3683988	et	4	main
leidsin	doc_881412446067_item	3683987	et	3	main
ei	doc_881412446067_item	3683978	et	4	main
riigi	doc_842434202401_item	3683712	et	3	main
suurendamine	doc_842434202401_item	3683710	et	4	main
parandada	doc_842434202401_item	3683698	et	3	main
oma	doc_842434202401_item	3683696	et	4	main
ettevõtlustel	doc_842434202401_item	3683690	et	3	main
põhimõtte	doc_842434202401_item	3683669	et	3	main
huvides	doc_842434202401_item	3683666	et	3	main
maksustava	doc_842434202401_item	3683664	et	4	main
seisneb	doc_842434202401_item	3683670	et	3	main
uue	doc_842434202401_item	3683667	et	3	main
isiku	doc_842434202401_item	3683665	et	3	main
maksuvaba	doc_842434202401_item	3683660	et	4	main
1	doc_842434202401_item	3683659	et	2	main
ja	doc_842434202401_item	3683658	et	3	main
tulumaks	doc_842434202401_item	3683657	et	3	main
eksam	doc_842434202401_item	3683656	et	3	main
essee	doc_842434202401_item	3683655	et	4	main
et	doc_881412446067_item	3684059	et	3	main
öelda	doc_881412446067_item	3684054	et	4	main
lõpetuseks	doc_881412446067_item	3684052	et	4	main
õhku	doc_881412446067_item	3684051	et	4	main
tänades	doc_881412446067_item	3684047	et	3	main
metsa	doc_881412446067_item	3684045	et	4	main
kopsud	doc_881412446067_item	3684044	et	4	main
mets	doc_881412446067_item	3684039	et	3	main
peavad	doc_881412446067_item	3684036	et	4	main
kõik	doc_881412446067_item	3684035	et	4	main
suureneb	doc_881412446067_item	3684034	et	3	main
röövpüük	doc_881412446067_item	3684033	et	3	main
kuna	doc_881412446067_item	3684032	et	3	main
selline	doc_881412446067_item	3684026	et	4	main
häirib	doc_881412446067_item	3684021	et	3	main
kaitsta	doc_881412446067_item	3684017	et	4	main
pärast	doc_881412446067_item	3683997	et	4	main
siis	doc_881412446067_item	3683994	et	3	main
või	doc_881412446067_item	3683985	et	4	main
sõprade	doc_881412446067_item	3683984	et	3	main
ma	doc_881412446067_item	3683983	et	3	main
kui	doc_881412446067_item	3683982	et	3	main
puhata	doc_881412446067_item	3683981	et	4	main
ikkagi	doc_881412446067_item	3683977	et	4	main
valmistada	doc_881412446067_item	3683973	et	3	main
loodusesse	doc_881412446067_item	3683961	et	4	main
muidugi	doc_881412446067_item	3683954	et	4	main
vaja	doc_881412446067_item	3683950	et	4	main
elektienergiat	doc_881412446067_item	3683948	et	4	main
et	doc_881412446067_item	3683947	et	3	main
katsun	doc_881412446067_item	3683942	et	3	main
nüüd	doc_881412446067_item	3683940	et	4	main
häälita	doc_881412446067_item	3683939	et	4	main
ei	doc_881412446067_item	3683923	et	4	main
ma	doc_881412446067_item	3683922	et	3	main
et	doc_881412446067_item	3683921	et	3	main
hoolikalt	doc_881412446067_item	3683883	et	4	main
suhtun	doc_881412446067_item	3683882	et	3	main
kõigepealt	doc_881412446067_item	3683880	et	3	main
olukorra	doc_881412446067_item	3683878	et	3	main
maailma	doc_881412446067_item	3683877	et	4	main
kogu	doc_881412446067_item	3683876	et	4	main
ka	doc_881412446067_item	3683862	et	3	main
mõju	doc_881412446067_item	3683850	et	4	main
oleks	doc_881412446067_item	3683835	et	3	main
ma	doc_881412446067_item	3683830	et	3	main
kokku	doc_881412446067_item	3683828	et	3	main
me	doc_881412446067_item	3683826	et	4	main
millega	doc_881412446067_item	3683825	et	3	main
kõik	doc_881412446067_item	3683824	et	4	main
on	doc_881412446067_item	3683819	et	4	main
saastatus	doc_881412446067_item	3683815	et	4	main
mageveevaru	doc_881412446067_item	3683802	et	4	main
üha	doc_881412446067_item	3683798	et	3	main
ökoelu	doc_881412446067_item	3683777	et	4	main
minu	doc_881412446067_item	3683776	et	3	main
essee	doc_881412446067_item	3683775	et	4	main
iseennast	doc_881412446067_item	3684072	et	3	main
üha	doc_881412446067_item	3684061	et	3	main
meeldiv	doc_881412446067_item	3684057	et	4	main
eriti	doc_881412446067_item	3684056	et	3	main
hingame	doc_881412446067_item	3684049	et	3	main
meie	doc_881412446067_item	3684042	et	4	main
on	doc_881412446067_item	3684041	et	4	main
et	doc_881412446067_item	3684038	et	3	main
peab	doc_881412446067_item	3684029	et	4	main
seadus	doc_881412446067_item	3684028	et	4	main
et	doc_881412446067_item	3684027	et	3	main
mind	doc_881412446067_item	3684022	et	4	main
on	doc_881412446067_item	3684015	et	4	main
korras	doc_881412446067_item	3684013	et	4	main
algus	doc_881412446067_item	3684004	et	4	main
oli	doc_881412446067_item	3684003	et	3	main
missugune	doc_881412446067_item	3684002	et	3	main
on	doc_881412446067_item	3684000	et	4	main
koht	doc_881412446067_item	3683999	et	3	main
see	doc_881412446067_item	3683998	et	3	main
meie	doc_881412446067_item	3683995	et	4	main
pereliikmetega	doc_881412446067_item	3683986	et	3	main
aga	doc_881412446067_item	3683974	et	3	main
looduses	doc_881412446067_item	3683971	et	4	main
või	doc_881412446067_item	3683969	et	4	main
veeta	doc_881412446067_item	3683965	et	4	main
meeldib	doc_881412446067_item	3683964	et	3	main
inmestele	doc_881412446067_item	3683963	et	4	main
suhtumine	doc_881412446067_item	3683960	et	4	main
väga	doc_881412446067_item	3683958	et	3	main
on	doc_881412446067_item	3683957	et	4	main
ettekirjutuse	doc_881412446067_item	3683952	et	3	main
on	doc_881412446067_item	3683949	et	4	main
selles	doc_881412446067_item	3683946	et	4	main
vaadata	doc_881412446067_item	3683938	et	4	main
telerit	doc_881412446067_item	3683937	et	3	main
muusikat	doc_881412446067_item	3683932	et	3	main
väga	doc_881412446067_item	3683930	et	3	main
sellele	doc_881412446067_item	3683920	et	4	main
elus	doc_881412446067_item	3683888	et	4	main
igapäevases	doc_881412446067_item	3683887	et	4	main
mina	doc_881412446067_item	3683875	et	4	main
lapselaste	doc_881412446067_item	3683866	et	4	main
aga	doc_881412446067_item	3683861	et	3	main
ükskõikne	doc_881412446067_item	3683855	et	3	main
ole	doc_881412446067_item	3683854	et	4	main
saaksime	doc_881412446067_item	3683847	et	3	main
me	doc_881412446067_item	3683846	et	4	main
teda	doc_881412446067_item	3683840	et	4	main
ja	doc_881412446067_item	3683839	et	3	main
et	doc_881412446067_item	3683832	et	3	main
on	doc_881412446067_item	3683823	et	4	main
langus	doc_881412446067_item	3683811	et	4	main
vähendamine	doc_881412446067_item	3683803	et	4	main
meie	doc_881412446067_item	3683778	et	4	main
kui	doc_881412446067_item	3684073	et	3	main
et	doc_881412446067_item	3684068	et	3	main
see	doc_881412446067_item	3684066	et	3	main
kui	doc_881412446068_item	3684354	et	3	main
selle	doc_881412446068_item	3684341	et	4	main
või	doc_881412446068_item	3684332	et	4	main
saastava	doc_881412446068_item	3684324	et	4	main
ka	doc_881412446068_item	3684323	et	3	main
rehvid	doc_881412446068_item	3684322	et	4	main
vanad	doc_881412446068_item	3684321	et	3	main
loodus	doc_881412446068_item	3684320	et	4	main
üks	doc_881412446068_item	3684315	et	3	main
ainul	doc_881412446068_item	3684314	et	4	main
ole	doc_881412446068_item	3684313	et	4	main
saastamine	doc_881412446068_item	3684296	et	4	main
ka	doc_881412446068_item	3684295	et	3	main
väheneb	doc_881412446068_item	3684294	et	3	main
kasutamine	doc_881412446068_item	3684293	et	4	main
vähenev	doc_881412446068_item	3684292	et	4	main
et	doc_881412446068_item	3684291	et	3	main
ja	doc_881412446068_item	3684290	et	3	main
näiteks	doc_881412446068_item	3684277	et	4	main
aga	doc_881412446068_item	3684276	et	3	main
üks	doc_881412446068_item	3684274	et	3	main
on	doc_881412446068_item	3684265	et	4	main
teda	doc_881412446067_item	3683945	et	4	main
veenda	doc_881412446067_item	3683944	et	4	main
ma	doc_881412446067_item	3683941	et	3	main
kuulata	doc_881412446067_item	3683933	et	4	main
tuttavale	doc_881412446067_item	3683929	et	4	main
ja	doc_881412446067_item	3683916	et	3	main
toas	doc_881412446067_item	3683915	et	3	main
igas	doc_881412446067_item	3683914	et	3	main
valgus	doc_881412446067_item	3683913	et	4	main
lülitatud	doc_881412446067_item	3683912	et	4	main
on	doc_881412446067_item	3683911	et	4	main
korteris	doc_881412446067_item	3683910	et	3	main
minu	doc_881412446067_item	3683909	et	3	main
kui	doc_881412446067_item	3683908	et	3	main
kannata	doc_881412446067_item	3683907	et	4	main
ei	doc_881412446067_item	3683906	et	4	main
ma	doc_881412446067_item	3683905	et	3	main
peale	doc_881412446067_item	3683904	et	4	main
selle	doc_881412446067_item	3683903	et	4	main
vajaduseta	doc_881412446067_item	3683902	et	3	main
jookse	doc_881412446067_item	3683901	et	4	main
ei	doc_881412446067_item	3683900	et	4	main
küll	doc_881412446067_item	3683899	et	4	main
ja	doc_881412446067_item	3683898	et	3	main
kraanist	doc_881412446067_item	3683897	et	3	main
tilgu	doc_881412446067_item	3683896	et	4	main
ei	doc_881412446067_item	3683895	et	4	main
vee	doc_881412446067_item	3683894	et	3	main
et	doc_881412446067_item	3683893	et	3	main
pidevalt	doc_881412446067_item	3683891	et	4	main
jalgin	doc_881412446067_item	3683890	et	4	main
ma	doc_881412446067_item	3683889	et	3	main
kasutamisse	doc_881412446067_item	3683885	et	4	main
aga	doc_881412446067_item	3683871	et	3	main
küsite	doc_881412446067_item	3683870	et	3	main
te	doc_881412446067_item	3683869	et	4	main
nähtavasti	doc_881412446067_item	3683868	et	3	main
elust	doc_881412446067_item	3683867	et	3	main
laste	doc_881412446067_item	3683864	et	4	main
mõtle	doc_881412446067_item	3683858	et	4	main
kahjulikku	doc_881412446067_item	3683849	et	4	main
sellel	doc_881412446067_item	3683844	et	4	main
ainult	doc_881412446067_item	3683843	et	4	main
tähelepanelik	doc_881412446067_item	3683836	et	4	main
täna	doc_881412446067_item	3683829	et	4	main
tähtsam	doc_881412446067_item	3683818	et	4	main
ja	doc_881412446067_item	3683816	et	3	main
õhu	doc_881412446067_item	3683814	et	3	main
metsaraie	doc_881412446067_item	3683813	et	4	main
liigne	doc_881412446067_item	3683812	et	3	main
kliima	doc_881412446067_item	3683805	et	4	main
globaalne	doc_881412446067_item	3683804	et	3	main
maavarade	doc_881412446067_item	3683800	et	3	main
rohkem	doc_881412446067_item	3683799	et	4	main
suureneb	doc_881412446067_item	3683797	et	3	main
elanikute	doc_881412446067_item	3683795	et	4	main
maailma	doc_881412446067_item	3683794	et	4	main
kuna	doc_881412446067_item	3683793	et	3	main
ühel	doc_881412446067_item	3683780	et	3	main
ajal	doc_881412446067_item	3683779	et	4	main
tulevikusest	doc_881412446067_item	3684075	et	4	main
ka	doc_881412446067_item	3684074	et	3	main
mõtlevad	doc_881412446067_item	3684070	et	4	main
inimesed	doc_881412446068_item	3684352	et	3	main
aga	doc_881412446068_item	3684340	et	3	main
äres	doc_881412446068_item	3684339	et	4	main
visatut	doc_881412446068_item	3684329	et	4	main
saatsab	doc_881412446068_item	3684319	et	4	main
kasutamine	doc_881412446068_item	3684311	et	4	main
benziini	doc_881412446068_item	3684310	et	4	main
aga	doc_881412446068_item	3684309	et	3	main
ülikooli	doc_881412446068_item	3684308	et	4	main
vaheneb	doc_881412446068_item	3684287	et	4	main
inimest	doc_881412446068_item	3684283	et	3	main
sõitsid	doc_881412446068_item	3684281	et	4	main
kõiges	doc_881412446068_item	3684279	et	4	main
praegu	doc_881412446068_item	3684255	et	3	main
palju	doc_881412446068_item	3684253	et	4	main
need	doc_881412446068_item	3684250	et	3	main
väga	doc_881412446068_item	3684246	et	3	main
või	doc_881412446068_item	3684244	et	4	main
mootoriga	doc_881412446068_item	3684243	et	4	main
elektri	doc_881412446068_item	3684242	et	3	main
sõidavad	doc_881412446068_item	3684241	et	3	main
bussiga	doc_881412446068_item	3684233	et	3	main
sõidavad	doc_881412446068_item	3684215	et	3	main
ega	doc_881412446068_item	3684190	et	3	main
ei	doc_881412446068_item	3684187	et	4	main
säästamine	doc_881412446068_item	3684184	et	4	main
looduse	doc_881412446068_item	3684183	et	4	main
visata	doc_881412446068_item	3684177	et	4	main
iseennast	doc_881412446067_item	3683860	et	3	main
kuna	doc_881412446067_item	3683856	et	3	main
nende	doc_881412446067_item	3683848	et	4	main
ümbritsevasse	doc_881412446067_item	3683841	et	4	main
suhtumine	doc_881412446067_item	3683837	et	4	main
inimesel	doc_881412446067_item	3683834	et	3	main
tahaksin	doc_881412446067_item	3683831	et	3	main
puutume	doc_881412446067_item	3683827	et	4	main
inimeste	doc_881412446067_item	3683820	et	3	main
kõige	doc_881412446067_item	3683817	et	4	main
põlvkonnast	doc_881412446067_item	3684076	et	4	main
probleemidest	doc_881412446067_item	3684065	et	3	main
globaalsetest	doc_881412446067_item	3684064	et	4	main
muretsevad	doc_881412446067_item	3684063	et	4	main
olukorda	doc_881412446067_item	3683792	et	4	main
teravaks	doc_881412446067_item	3683791	et	4	main
probleemid	doc_881412446067_item	3683790	et	3	main
need	doc_881412446067_item	3683789	et	3	main
ajavad	doc_881412446067_item	3683788	et	4	main
päevaga	doc_881412446067_item	3683787	et	3	main
iga	doc_881412446067_item	3683786	et	4	main
probleemid	doc_881412446067_item	3683785	et	3	main
globaalsed	doc_881412446067_item	3683784	et	3	main
on	doc_881412446067_item	3683783	et	4	main
näiteks	doc_881412446068_item	3684355	et	4	main
loodust	doc_881412446068_item	3684350	et	4	main
ei	doc_881412446068_item	3684348	et	4	main
eest	doc_881412446068_item	3684343	et	4	main
näide	doc_881412446068_item	3684342	et	3	main
keegi	doc_881412446068_item	3684334	et	4	main
kui	doc_881412446068_item	3684333	et	3	main
välja	doc_881412446068_item	3684328	et	4	main
on	doc_881412446068_item	3684327	et	4	main
kui	doc_881412446068_item	3684325	et	3	main
mis	doc_881412446068_item	3684318	et	4	main
ei	doc_881412446068_item	3684312	et	4	main
tavaliselt	doc_881412446068_item	3684269	et	4	main
ja	doc_881412446068_item	3684254	et	3	main
on	doc_881412446068_item	3684238	et	4	main
juba	doc_881412446068_item	3684237	et	3	main
praegu	doc_881412446068_item	3684236	et	3	main
kui	doc_881412446068_item	3684231	et	3	main
aga	doc_881412446068_item	3684227	et	3	main
saastab	doc_881412446068_item	3684225	et	3	main
see	doc_881412446068_item	3684224	et	3	main
sõidan	doc_881412446068_item	3684220	et	3	main
ma	doc_881412446068_item	3684218	et	3	main
autoga	doc_881412446068_item	3684217	et	3	main
tööle	doc_881412446068_item	3684216	et	3	main
inimeset	doc_881412446068_item	3684209	et	3	main
one	doc_881412446068_item	3684204	et	4	main
ei	doc_881412446068_item	3684203	et	4	main
see	doc_881412446068_item	3684202	et	3	main
aga	doc_881412446068_item	3684201	et	3	main
loodust	doc_881412446068_item	3684200	et	4	main
saasta	doc_881412446068_item	3684199	et	4	main
aga	doc_881412446068_item	3684192	et	3	main
ole	doc_881412446068_item	3684188	et	4	main
õun	doc_881412446068_item	3684186	et	3	main
ei	doc_881412446068_item	3684181	et	4	main
see	doc_881412446068_item	3684180	et	3	main
metsa	doc_881412446068_item	3684149	et	4	main
mina	doc_881412446068_item	3684144	et	4	main
kui	doc_881412446068_item	3684143	et	3	main
ise	doc_881412446068_item	3684125	et	4	main
inimene	doc_881412446068_item	3684124	et	3	main
saastavad	doc_881412446068_item	3684117	et	4	main
saastavad	doc_881412446068_item	3684115	et	4	main
ei	doc_881412446068_item	3684108	et	4	main
ei	doc_881412446067_item	3683857	et	4	main
ei	doc_881412446067_item	3683853	et	4	main
mul	doc_881412446067_item	3683852	et	3	main
vähendama	doc_881412446067_item	3683851	et	3	main
juhul	doc_881412446067_item	3683845	et	3	main
keskkonnasse	doc_881412446067_item	3683842	et	4	main
loodusse	doc_881412446067_item	3683838	et	4	main
igal	doc_881412446067_item	3683833	et	3	main
see	doc_881412446067_item	3683822	et	3	main
ebateadlikkus	doc_881412446067_item	3683821	et	4	main
mullaviljakuse	doc_881412446067_item	3683810	et	4	main
happevihmad	doc_881412446067_item	3683809	et	3	main
hõrenemine	doc_881412446067_item	3683808	et	4	main
osoonikihi	doc_881412446067_item	3683807	et	3	main
soojenemine	doc_881412446067_item	3683806	et	4	main
ja	doc_881412446067_item	3683801	et	3	main
arv	doc_881412446067_item	3683796	et	3	main
nii	doc_881412446067_item	3684071	et	3	main
nad	doc_881412446067_item	3684069	et	3	main
tähendab	doc_881412446067_item	3684067	et	3	main
kohal	doc_881412446067_item	3683782	et	4	main
tähtsamaid	doc_881412446067_item	3683781	et	4	main
saastavad	doc_881412446068_item	3684351	et	4	main
saastavad	doc_881412446068_item	3684349	et	4	main
asjad	doc_881412446068_item	3684347	et	3	main
et	doc_881412446068_item	3684346	et	3	main
auto	doc_881412446068_item	3684337	et	4	main
oma	doc_881412446068_item	3684336	et	4	main
peseb	doc_881412446068_item	3684335	et	3	main
kuskilt	doc_881412446068_item	3684330	et	4	main
need	doc_881412446068_item	3684326	et	3	main
autos	doc_881412446068_item	3684317	et	3	main
asi	doc_881412446068_item	3684316	et	4	main
sõidan	doc_881412446068_item	3684303	et	3	main
ma	doc_881412446068_item	3684302	et	3	main
siis	doc_881412446068_item	3684301	et	3	main
võimalus	doc_881412446068_item	3684300	et	3	main
on	doc_881412446068_item	3684299	et	4	main
mul	doc_881412446068_item	3684298	et	3	main
kui	doc_881412446068_item	3684297	et	3	main
kasutamine	doc_881412446068_item	3684286	et	4	main
siis	doc_881412446068_item	3684284	et	3	main
inimene	doc_881412446068_item	3684275	et	3	main
kahjuks	doc_881412446068_item	3684268	et	4	main
et	doc_881412446068_item	3684267	et	3	main
sellist	doc_881412446068_item	3684266	et	4	main
maksavad	doc_881412446068_item	3684251	et	3	main
aga	doc_881412446068_item	3684249	et	3	main
kasutavad	doc_881412446068_item	3684245	et	4	main
mis	doc_881412446068_item	3684240	et	4	main
autod	doc_881412446068_item	3684239	et	3	main
sõita	doc_881412446068_item	3684232	et	3	main
on	doc_881412446068_item	3684229	et	4	main
loodust	doc_881412446068_item	3684226	et	4	main
et	doc_881412446068_item	3684223	et	3	main
autoga	doc_881412446068_item	3684221	et	3	main
ise	doc_881412446068_item	3684219	et	4	main
rohkem	doc_881412446068_item	3684208	et	4	main
aga	doc_881412446068_item	3684206	et	3	main
ei	doc_881412446068_item	3684198	et	4	main
plastmassist	doc_881412446068_item	3684189	et	3	main
õuna	doc_881412446068_item	3684179	et	4	main
vana	doc_881412446068_item	3684178	et	4	main
kõik	doc_881412446068_item	3684155	et	4	main
pärast	doc_881412446068_item	3684153	et	4	main
teha	doc_881412446068_item	3684151	et	3	main
kuskilt	doc_881412446068_item	3684148	et	4	main
läheme	doc_881412446068_item	3684147	et	3	main
läks	doc_881412446068_item	3684141	et	3	main
pudelid	doc_881412446068_item	3684138	et	3	main
oni	doc_881412446068_item	3684134	et	4	main
palju	doc_881412446068_item	3684130	et	4	main
vaadata	doc_881412446068_item	3684129	et	4	main
võib	doc_881412446068_item	3684128	et	3	main
metsas	doc_881412446068_item	3684127	et	3	main
näitaks	doc_881412446068_item	3684126	et	3	main
asjad	doc_881412446068_item	3684121	et	3	main
looduse	doc_881412446068_item	3684118	et	4	main
looduse	doc_881412446068_item	3684116	et	4	main
mis	doc_881412446068_item	3684105	et	4	main
ökoelu	doc_881412446068_item	3684404	et	4	main
et	doc_881412446068_item	3684353	et	3	main
vaadata	doc_881412446068_item	3684345	et	4	main
võib	doc_881412446068_item	3684344	et	3	main
jõe	doc_881412446068_item	3684338	et	3	main
metsas	doc_881412446068_item	3684331	et	3	main
pärast	doc_881412446068_item	3684307	et	4	main
ja	doc_881412446068_item	3684306	et	3	main
tööle	doc_881412446068_item	3684305	et	3	main
emaga	doc_881412446068_item	3684304	et	3	main
kordseks	doc_881412446068_item	3684289	et	4	main
kahe	doc_881412446068_item	3684288	et	3	main
beziini	doc_881412446068_item	3684285	et	4	main
2	doc_881412446068_item	3684282	et	2	main
autodes	doc_881412446068_item	3684280	et	3	main
kui	doc_881412446068_item	3684278	et	3	main
ainult	doc_881412446068_item	3684273	et	4	main
sõidab	doc_881412446068_item	3684272	et	3	main
autos	doc_881412446068_item	3684271	et	3	main
ühes	doc_881412446068_item	3684270	et	4	main
asi	doc_881412446068_item	3684264	et	4	main
ka	doc_881412446068_item	3684263	et	3	main
osta	doc_881412446068_item	3684262	et	4	main
autot	doc_881412446068_item	3684261	et	3	main
sellest	doc_881412446068_item	3684260	et	4	main
võimaluse	doc_881412446068_item	3684259	et	3	main
ole	doc_881412446068_item	3684258	et	4	main
ei	doc_881412446068_item	3684257	et	4	main
mul	doc_881412446068_item	3684256	et	3	main
väga	doc_881412446068_item	3684252	et	3	main
benziini	doc_881412446068_item	3684248	et	4	main
inimesi	doc_881412446068_item	3684214	et	4	main
palju	doc_881412446068_item	3684213	et	4	main
et	doc_881412446068_item	3684212	et	3	main
loodust	doc_881412446068_item	3684211	et	4	main
glaasist	doc_881412446068_item	3684191	et	4	main
ses	doc_881412446068_item	3684185	et	3	main
saslõket	doc_881412446068_item	3684150	et	4	main
sõpradega	doc_881412446068_item	3684146	et	3	main
koos	doc_881412446068_item	3684145	et	4	main
ja	doc_881412446068_item	3684140	et	3	main
seal	doc_881412446068_item	3684139	et	4	main
keegi	doc_881412446068_item	3684133	et	4	main
pudelit	doc_881412446068_item	3684131	et	3	main
aga	doc_881412446068_item	3684122	et	3	main
ei	doc_881412446068_item	3684114	et	4	main
saad	doc_881412446068_item	3684097	et	4	main
ole	doc_881412446068_item	3684089	et	4	main
enam	doc_881412446068_item	3684401	et	4	main
ääres	doc_881412446068_item	3684392	et	4	main
need	doc_881412446068_item	3684390	et	3	main
viska	doc_881412446068_item	3684383	et	4	main
ise	doc_881412446068_item	3684375	et	4	main
on	doc_881412446070_item	3684559	et	4	main
kõige	doc_881412446070_item	3684555	et	4	main
ma	doc_881412446070_item	3684546	et	3	main
säästan	doc_881412446070_item	3684543	et	2	main
sõita	doc_881412446070_item	3684538	et	3	main
vee	doc_881412446070_item	3684528	et	3	main
säästa	doc_881412446070_item	3684513	et	4	main
vee	doc_881412446070_item	3684512	et	3	main
et	doc_881412446070_item	3684511	et	3	main
kui	doc_881412446070_item	3684482	et	3	main
teadvusega	doc_881412446070_item	3684475	et	4	main
ma	doc_881412446070_item	3684472	et	3	main
säästab	doc_881412446070_item	3684464	et	3	main
aga	doc_881412446070_item	3684457	et	3	main
seadused	doc_881412446070_item	3684455	et	3	main
kirjutab	doc_881412446070_item	3684453	et	3	main
keegi	doc_881412446070_item	3684452	et	4	main
ökoloogiks	doc_881412446070_item	3684451	et	2	main
töötab	doc_881412446070_item	3684450	et	3	main
on	doc_881412446070_item	3684446	et	4	main
vähe	doc_881412446068_item	3684247	et	3	main
trolliga	doc_881412446068_item	3684235	et	4	main
või	doc_881412446068_item	3684234	et	4	main
mugavam	doc_881412446068_item	3684230	et	4	main
see	doc_881412446068_item	3684228	et	3	main
tean	doc_881412446068_item	3684222	et	3	main
saastavad	doc_881412446068_item	3684210	et	4	main
kõige	doc_881412446068_item	3684207	et	4	main
nii	doc_881412446068_item	3684205	et	3	main
plastmass	doc_881412446068_item	3684197	et	3	main
et	doc_881412446068_item	3684196	et	3	main
arvavad	doc_881412446068_item	3684195	et	4	main
inimesed	doc_881412446068_item	3684194	et	3	main
mõned	doc_881412446068_item	3684193	et	3	main
ole	doc_881412446068_item	3684182	et	4	main
välja	doc_881412446068_item	3684176	et	4	main
kui	doc_881412446068_item	3684175	et	3	main
et	doc_881412446068_item	3684174	et	3	main
tean	doc_881412446068_item	3684173	et	3	main
ma	doc_881412446068_item	3684172	et	3	main
kauplusse	doc_881412446068_item	3684171	et	3	main
tagasi	doc_881412446068_item	3684170	et	3	main
pudelid	doc_881412446068_item	3684169	et	3	main
tühjad	doc_881412446068_item	3684168	et	3	main
anname	doc_881412446068_item	3684167	et	3	main
võimalus	doc_881412446068_item	3684166	et	3	main
on	doc_881412446068_item	3684165	et	4	main
või	doc_881412446068_item	3684163	et	4	main
linnas	doc_881412446068_item	3684162	et	4	main
kui	doc_881412446068_item	3684164	et	3	main
juba	doc_881412446068_item	3684161	et	3	main
teda	doc_881412446068_item	3684160	et	4	main
viskame	doc_881412446068_item	3684159	et	3	main
ja	doc_881412446068_item	3684158	et	3	main
kaasa	doc_881412446068_item	3684157	et	4	main
prügi	doc_881412446068_item	3684156	et	4	main
seal	doc_881412446068_item	3684135	et	4	main
plasmassist	doc_881412446068_item	3684132	et	4	main
ainult	doc_881412446068_item	3684123	et	4	main
mitte	doc_881412446068_item	3684119	et	3	main
kõik	doc_881412446068_item	3684111	et	4	main
et	doc_881412446068_item	3684110	et	3	main
ütle	doc_881412446068_item	3684109	et	4	main
a	doc_881412446068_item	3684104	et	4	main
ise	doc_881412446068_item	3684096	et	4	main
sa	doc_881412446068_item	3684095	et	3	main
kuidas	doc_881412446068_item	3684094	et	3	main
aga	doc_881412446068_item	3684093	et	3	main
ei	doc_881412446068_item	3684088	et	4	main
või	doc_881412446068_item	3684387	et	4	main
ainult	doc_881412446068_item	3684379	et	4	main
autod	doc_881412446068_item	3684378	et	3	main
me	doc_881412446070_item	3684562	et	4	main
mida	doc_881412446070_item	3684561	et	4	main
balansseerima	doc_881412446070_item	3684560	et	3	main
nafta	doc_881412446070_item	3684548	et	4	main
ma	doc_881412446070_item	3684542	et	3	main
ja	doc_881412446070_item	3684540	et	3	main
tundi	doc_881412446070_item	3684519	et	4	main
2	doc_881412446070_item	3684518	et	2	main
all	doc_881412446070_item	3684517	et	3	main
radioaktiivsed	doc_881412446070_item	3684509	et	4	main
utiliseerin	doc_881412446070_item	3684506	et	3	main
prügi	doc_881412446070_item	3684487	et	4	main
võtame	doc_881412446068_item	3684154	et	3	main
siis	doc_881412446068_item	3684152	et	3	main
ära	doc_881412446068_item	3684142	et	4	main
tühjat	doc_881412446068_item	3684137	et	4	main
lase	doc_881412446068_item	3684136	et	4	main
inimese	doc_881412446068_item	3684120	et	4	main
asjat	doc_881412446068_item	3684113	et	4	main
mu	doc_881412446068_item	3684112	et	3	main
hea	doc_881412446068_item	3684101	et	4	main
ainult	doc_881412446068_item	3684090	et	4	main
nimetada	doc_881412446068_item	3684403	et	3	main
elu	doc_881412446068_item	3684399	et	4	main
mu	doc_881412446068_item	3684398	et	3	main
et	doc_881412446068_item	3684397	et	3	main
arvan	doc_881412446068_item	3684396	et	3	main
ma	doc_881412446068_item	3684395	et	3	main
pärast	doc_881412446068_item	3684394	et	4	main
tee	doc_881412446068_item	3684391	et	4	main
lase	doc_881412446068_item	3684389	et	4	main
ei	doc_881412446068_item	3684388	et	4	main
ei	doc_881412446068_item	3684382	et	4	main
ja	doc_881412446068_item	3684381	et	3	main
autopesulas	doc_881412446068_item	3684380	et	3	main
ma	doc_881412446068_item	3684107	et	3	main
mitte	doc_881412446068_item	3684106	et	3	main
on	doc_881412446068_item	3684100	et	4	main
mis	doc_881412446068_item	3684099	et	4	main
aru	doc_881412446068_item	3684098	et	4	main
kasutamine	doc_881412446068_item	3684091	et	4	main
et	doc_881412446068_item	3684086	et	3	main
see	doc_881412446068_item	3684393	et	3	main
rehvid	doc_881412446068_item	3684385	et	4	main
vanad	doc_881412446068_item	3684384	et	3	main
kusiklt	doc_881412446068_item	3684374	et	4	main
teha	doc_881412446068_item	3684373	et	3	main
seda	doc_881412446068_item	3684372	et	3	main
kui	doc_881412446068_item	3684371	et	3	main
saastatud	doc_881412446068_item	3684370	et	4	main
vähem	doc_881412446068_item	3684369	et	4	main
palju	doc_881412446068_item	3684368	et	4	main
von	doc_881412446068_item	3684367	et	4	main
loodus	doc_881412446068_item	3684366	et	4	main
siis	doc_881412446068_item	3684365	et	3	main
autopesulas	doc_881412446068_item	3684364	et	3	main
autod	doc_881412446068_item	3684363	et	3	main
pese	doc_881412446068_item	3684362	et	4	main
ja	doc_881412446068_item	3684361	et	3	main
kohta	doc_881412446068_item	3684360	et	4	main
spetsiaalsesse	doc_881412446068_item	3684359	et	4	main
rehvid	doc_881412446068_item	3684358	et	4	main
kasutatud	doc_881412446068_item	3684357	et	4	main
viia	doc_881412446068_item	3684356	et	3	main
arvan	doc_881412446068_item	3684085	et	3	main
ma	doc_881412446068_item	3684084	et	3	main
ökoeluviis	doc_881412446068_item	3684083	et	3	main
on	doc_881412446068_item	3684082	et	4	main
mis	doc_881412446068_item	3684081	et	4	main
ökoelu	doc_881412446068_item	3684080	et	4	main
minu	doc_881412446068_item	3684079	et	3	main
essee	doc_881412446068_item	3684078	et	4	main
mattin	doc_881412446070_item	3684550	et	4	main
ja	doc_881412446070_item	3684549	et	3	main
näiteks	doc_881412446070_item	3684545	et	4	main
suitseta	doc_881412446070_item	3684532	et	4	main
ei	doc_881412446070_item	3684531	et	4	main
ma	doc_881412446070_item	3684530	et	3	main
maksta	doc_881412446070_item	3684529	et	4	main
pea	doc_881412446070_item	3684527	et	4	main
ei	doc_881412446070_item	3684526	et	4	main
ja	doc_881412446070_item	3684525	et	3	main
üliõpilasuhiselamus	doc_881412446070_item	3684524	et	2	main
elan	doc_881412446070_item	3684523	et	3	main
ma	doc_881412446070_item	3684522	et	3	main
ained	doc_881412446070_item	3684510	et	3	main
alati	doc_881412446070_item	3684505	et	4	main
veel	doc_881412446070_item	3684503	et	4	main
näiteks	doc_881412446070_item	3684480	et	4	main
ja	doc_881412446070_item	3684463	et	3	main
eest	doc_881412446068_item	3684103	et	4	main
looduse	doc_881412446068_item	3684102	et	4	main
ükokaubad	doc_881412446068_item	3684092	et	4	main
see	doc_881412446068_item	3684087	et	3	main
vähem	doc_881412446068_item	3684402	et	4	main
võib	doc_881412446068_item	3684400	et	3	main
metsa	doc_881412446068_item	3684386	et	4	main
pesen	doc_881412446068_item	3684377	et	3	main
mina	doc_881412446068_item	3684376	et	4	main
arvates	doc_881412446070_item	3684554	et	4	main
minu	doc_881412446070_item	3684553	et	3	main
maha	doc_881412446070_item	3684552	et	4	main
seda	doc_881412446070_item	3684551	et	3	main
muidugi	doc_881412446070_item	3684541	et	4	main
autoga	doc_881412446070_item	3684539	et	3	main
ei	doc_881412446070_item	3684537	et	4	main
loodus	doc_881412446070_item	3684536	et	4	main
säästa	doc_881412446070_item	3684535	et	4	main
et	doc_881412446070_item	3684534	et	3	main
ja	doc_881412446070_item	3684533	et	3	main
dussi	doc_881412446070_item	3684516	et	4	main
käin	doc_881412446070_item	3684515	et	3	main
ma	doc_881412446070_item	3684514	et	3	main
ja	doc_881412446070_item	3684508	et	3	main
toksilised	doc_881412446070_item	3684507	et	4	main
keskkonna	doc_881412446070_item	3684479	et	3	main
ja	doc_881412446070_item	3684477	et	3	main
väga	doc_881412446070_item	3684474	et	3	main
lülitab	doc_881412446070_item	3684462	et	3	main
variandi	doc_881412446070_item	3684448	et	4	main
siin	doc_881412446070_item	3684445	et	4	main
essee	doc_881412446070_item	3684406	et	4	main
nimel	doc_881412446070_item	3684587	et	3	main
elu	doc_881412446070_item	3684586	et	4	main
tuleviku	doc_881412446070_item	3684585	et	4	main
ja	doc_881412446070_item	3684584	et	3	main
tänapäeva	doc_881412446070_item	3684583	et	4	main
keskkonna	doc_881412446070_item	3684582	et	3	main
säästa	doc_881412446070_item	3684581	et	4	main
peab	doc_881412446070_item	3684580	et	4	main
inimene	doc_881412446070_item	3684579	et	3	main
iga	doc_881412446070_item	3684578	et	4	main
et	doc_881412446070_item	3684577	et	3	main
öelda	doc_881412446070_item	3684576	et	4	main
tahan	doc_881412446070_item	3684575	et	3	main
kokkuvõtteks	doc_881412446070_item	3684574	et	3	main
keskkonna	doc_881412446070_item	3684573	et	3	main
taastame	doc_881412446070_item	3684572	et	3	main
ja	doc_881412446070_item	3684571	et	3	main
säästame	doc_881412446070_item	3684570	et	2	main
me	doc_881412446070_item	3684569	et	4	main
kuidas	doc_881412446070_item	3684568	et	3	main
anname	doc_881412446070_item	3684567	et	3	main
mida	doc_881412446070_item	3684566	et	4	main
ja	doc_881412446070_item	3684565	et	3	main
loodust	doc_881412446070_item	3684564	et	4	main
võtame	doc_881412446070_item	3684563	et	3	main
ülesanne	doc_881412446070_item	3684558	et	4	main
sotsiaalne	doc_881412446070_item	3684557	et	3	main
oluline	doc_881412446070_item	3684556	et	4	main
ostan	doc_881412446070_item	3684547	et	3	main
maavarad	doc_881412446070_item	3684544	et	3	main
sest	doc_881412446070_item	3684521	et	4	main
päevas	doc_881412446070_item	3684520	et	3	main
ma	doc_881412446070_item	3684504	et	3	main
pargis	doc_881412446070_item	3684502	et	3	main
juures	doc_881412446070_item	3684501	et	4	main
ülikooli	doc_881412446070_item	3684500	et	4	main
nende	doc_881412446070_item	3684499	et	4	main
põletan	doc_881412446070_item	3684498	et	2	main
ma	doc_881412446070_item	3684497	et	3	main
autorehvidest	doc_881412446070_item	3684496	et	3	main
vanadest	doc_881412446070_item	3684495	et	3	main
vabanema	doc_881412446070_item	3684494	et	3	main
et	doc_881412446070_item	3684493	et	3	main
meres	doc_881412446070_item	3684492	et	3	main
seda	doc_881412446070_item	3684491	et	3	main
utiliseerin	doc_881412446070_item	3684490	et	3	main
ja	doc_881412446070_item	3684489	et	3	main
õues	doc_881412446070_item	3684488	et	4	main
ma	doc_881412446070_item	3684485	et	3	main
koristan	doc_881412446070_item	3684486	et	3	main
magavad	doc_881412446070_item	3684484	et	4	main
hommikul	doc_881412446070_item	3684481	et	3	main
olend	doc_881412446070_item	3684476	et	3	main
oma	doc_881412446070_item	3684470	et	4	main
jutustada	doc_881412446070_item	3684469	et	3	main
keegi	doc_881412446070_item	3684449	et	4	main
säästa	doc_881412446070_item	3684444	et	4	main
keskkonna	doc_881412446070_item	3684443	et	3	main
et	doc_881412446070_item	3684442	et	3	main
võimalik	doc_881412446070_item	3684441	et	3	main
on	doc_881412446070_item	3684440	et	4	main
mis	doc_881412446070_item	3684439	et	4	main
kõik	doc_881412446070_item	3684438	et	4	main
teha	doc_881412446070_item	3684437	et	3	main
ja	doc_881412446070_item	3684436	et	3	main
keskkonna	doc_881412446070_item	3684435	et	3	main
hoolitsema	doc_881412446070_item	3684434	et	4	main
peab	doc_881412446070_item	3684433	et	4	main
inimene	doc_881412446070_item	3684432	et	3	main
iga	doc_881412446070_item	3684431	et	4	main
arvates	doc_881412446070_item	3684430	et	4	main
minu	doc_881412446070_item	3684429	et	3	main
juures	doc_881412446070_item	3684428	et	4	main
linnade	doc_881412446070_item	3684427	et	3	main
suurde	doc_881412446070_item	3684426	et	3	main
kasvavad	doc_881412446070_item	3684425	et	4	main
prugimäed	doc_881412446070_item	3684424	et	2	main
aga	doc_881412446070_item	3684423	et	3	main
reostamisest	doc_881412446070_item	3684422	et	4	main
kannatavad	doc_881412446070_item	3684421	et	4	main
loodus	doc_881412446070_item	3684420	et	4	main
ja	doc_881412446070_item	3684419	et	3	main
inemesed	doc_881412446070_item	3684418	et	4	main
maailmas	doc_881412446070_item	3684417	et	3	main
tänapäeva	doc_881412446070_item	3684416	et	4	main
probleem	doc_881412446070_item	3684415	et	3	main
aktuaalne	doc_881412446070_item	3684414	et	3	main
väga	doc_881412446070_item	3684413	et	3	main
on	doc_881412446070_item	3684412	et	4	main
keskkonnakaitse	doc_881412446070_item	3684411	et	4	main
ja	doc_881412446070_item	3684410	et	3	main
ökoloogia	doc_881412446070_item	3684409	et	4	main
inimesed	doc_881412446070_item	3684483	et	3	main
säästan	doc_881412446070_item	3684478	et	2	main
olen	doc_881412446070_item	3684473	et	3	main
ökoelust	doc_881412446070_item	3684471	et	3	main
tahan	doc_881412446070_item	3684468	et	3	main
ma	doc_881412446070_item	3684467	et	3	main
kodus	doc_881412446070_item	3684466	et	4	main
vee	doc_881412446070_item	3684465	et	3	main
välja	doc_881412446070_item	3684461	et	4	main
inimene	doc_881412446070_item	3684459	et	3	main
haralik	doc_881412446070_item	3684458	et	4	main
parlamendis	doc_881412446070_item	3684456	et	3	main
uued	doc_881412446070_item	3684454	et	3	main
valgust	doc_881412446070_item	3684460	et	4	main
mitu	doc_881412446070_item	3684447	et	4	main
ökoelu	doc_881412446070_item	3684408	et	4	main
minu	doc_881412446070_item	3684407	et	3	main
kõige	doc_769634019911_item	3685470	et	4	main
on	doc_769634019911_item	3685472	et	4	main
algab	doc_769634019911_item	3685468	et	3	main
minu	doc_769634019911_item	3685445	et	3	main
sest	doc_769634019911_item	3685437	et	4	main
algab	doc_769634019911_item	3685417	et	3	main
semester	doc_769634019911_item	3685416	et	3	main
meeldib	doc_769634019911_item	3685405	et	3	main
helendavad	doc_769634019911_item	3685393	et	4	main
lilled	doc_769634019911_item	3685392	et	3	main
ja	doc_769634019911_item	3685391	et	3	main
kollane	doc_769634019911_item	3685390	et	4	main
on	doc_769634019911_item	3685387	et	4	main
saab	doc_769634019911_item	3685357	et	3	main
on	doc_769634019911_item	3685354	et	4	main
tärkavad	doc_769634019911_item	3685351	et	4	main
puud	doc_769634019911_item	3685350	et	4	main
ja	doc_769634019911_item	3685349	et	3	main
kasvab	doc_769634019911_item	3685348	et	3	main
kevade	doc_769634019911_item	3685342	et	4	main
talv	doc_769634019911_item	3685336	et	3	main
suvi	doc_769634019911_item	3685333	et	3	main
on	doc_769634019911_item	3685331	et	4	main
lemmikloom	doc_769634019910_item	3685614	et	3	main
ja	doc_769634019910_item	3685611	et	3	main
ma	doc_769634019910_item	3685602	et	3	main
pärit	doc_769634019910_item	3685599	et	3	main
minu	doc_769634019910_item	3685594	et	3	main
prantsuse	doc_769634019910_item	3685590	et	3	main
inglise	doc_769634019910_item	3685589	et	4	main
ja	doc_769634019910_item	3685576	et	3	main
aastat	doc_769634019910_item	3685574	et	3	main
ta	doc_769634019910_item	3685571	et	4	main
vanemand	doc_769634019910_item	3685554	et	3	main
töötab	doc_769634019910_item	3685545	et	3	main
insenerbüroos	doc_769634019910_item	3685542	et	4	main
töötab	doc_769634019910_item	3685541	et	3	main
ta	doc_769634019910_item	3685540	et	4	main
minu	doc_769634019910_item	3685534	et	3	main
sinised	doc_769634019910_item	3685533	et	4	main
ilusem	doc_769634019911_item	3685471	et	4	main
uus	doc_769634019911_item	3685466	et	3	main
ja	doc_769634019911_item	3685464	et	3	main
saab	doc_769634019911_item	3685462	et	3	main
talvel	doc_769634019911_item	3685461	et	4	main
krudiseb	doc_769634019911_item	3685460	et	3	main
all	doc_769634019911_item	3685459	et	3	main
viimane	doc_769634019911_item	3685443	et	3	main
lehed	doc_769634019911_item	3685441	et	3	main
värvib	doc_769634019911_item	3685439	et	3	main
vihm	doc_769634019911_item	3685438	et	3	main
pruun	doc_769634019911_item	3685436	et	3	main
on	doc_769634019911_item	3685435	et	4	main
sügis	doc_769634019911_item	3685434	et	3	main
et	doc_769634019911_item	3685433	et	3	main
arvan	doc_769634019911_item	3685432	et	3	main
festivalikäia	doc_769634019911_item	3685406	et	4	main
mulle	doc_769634019911_item	3685404	et	4	main
pida	doc_769634019911_item	3685398	et	4	main
piknikuid	doc_769634019911_item	3685397	et	3	main
saab	doc_769634019911_item	3685396	et	3	main
suvel	doc_769634019911_item	3685395	et	3	main
erivärvisiled	doc_769634019911_item	3685394	et	4	main
kirju	doc_769634019911_item	3685385	et	4	main
on	doc_769634019911_item	3685384	et	4	main
sula	doc_769634019911_item	3685355	et	4	main
lund	doc_769634019911_item	3685353	et	3	main
kevadel	doc_769634019911_item	3685339	et	4	main
kevad	doc_769634019911_item	3685332	et	3	main
kass	doc_769634019910_item	3685616	et	3	main
muusika	doc_769634019910_item	3685609	et	4	main
mulle	doc_769634019910_item	3685607	et	4	main
keelt	doc_769634019910_item	3685606	et	4	main
isa	doc_769634019910_item	3685596	et	4	main
kolm	doc_769634019910_item	3685587	et	3	main
ma	doc_769634019910_item	3685585	et	3	main
inglise	doc_769634019910_item	3685583	et	4	main
üks	doc_769634019910_item	3685581	et	3	main
õpib	doc_769634019910_item	3685580	et	3	main
minu	doc_769634019910_item	3685566	et	3	main
sinised	doc_769634019910_item	3685539	et	4	main
ka	doc_769634019910_item	3685538	et	3	main
on	doc_769634019910_item	3685532	et	4	main
ei	doc_769634019910_item	3685520	et	4	main
ma	doc_769634019910_item	3685519	et	3	main
aga	doc_769634019910_item	3685518	et	3	main
teha	doc_769634019910_item	3685517	et	3	main
jõulud	doc_769634019911_item	3685474	et	3	main
pruunid	doc_769634019911_item	3685442	et	3	main
langenud	doc_769634019911_item	3685440	et	4	main
tagasi	doc_769634019911_item	3685420	et	3	main
ja	doc_769634019911_item	3685418	et	3	main
langevad	doc_769634019911_item	3685414	et	4	main
kui	doc_769634019911_item	3685412	et	3	main
sügis	doc_769634019911_item	3685411	et	3	main
ujuda	doc_769634019911_item	3685400	et	3	main
kõik	doc_769634019911_item	3685383	et	4	main
suvel	doc_769634019911_item	3685382	et	3	main
saksamaa	doc_769634019911_item	3685376	et	4	main
kuiv	doc_769634019911_item	3685375	et	3	main
ja	doc_769634019911_item	3685374	et	3	main
nelja	doc_769634019911_item	3685329	et	4	main
aastaajad	doc_769634019911_item	3685328	et	3	main
essee	doc_769634019911_item	3685327	et	4	main
palav	doc_769634019911_item	3685373	et	4	main
suvi	doc_769634019911_item	3685371	et	3	main
ideaalne	doc_769634019911_item	3685370	et	3	main
suvi	doc_769634019911_item	3685369	et	3	main
on	doc_769634019911_item	3685372	et	4	main
tuleb	doc_769634019911_item	3685368	et	3	main
seda	doc_769634019911_item	3685367	et	3	main
pärast	doc_769634019911_item	3685366	et	4	main
osterfest	doc_769634019911_item	3685365	et	4	main
zum	doc_769634019911_item	3685364	et	4	main
valged	doc_769634019911_item	3685473	et	3	main
aasta	doc_769634019911_item	3685467	et	4	main
uisutada	doc_769634019911_item	3685465	et	3	main
susatada	doc_769634019911_item	3685463	et	4	main
jalge	doc_769634019911_item	3685458	et	4	main
lumi	doc_769634019911_item	3685457	et	3	main
kui	doc_769634019911_item	3685456	et	3	main
armastan	doc_769634019911_item	3685455	et	3	main
ma	doc_769634019911_item	3685454	et	3	main
ja	doc_769634019911_item	3685453	et	3	main
veebruaris	doc_769634019911_item	3685452	et	3	main
sünnipäev	doc_769634019911_item	3685451	et	3	main
oma	doc_769634019911_item	3685450	et	4	main
järgneb	doc_769634019911_item	3685444	et	3	main
ma	doc_769634019911_item	3685431	et	3	main
koristada	doc_769634019911_item	3685430	et	3	main
viljad	doc_769634019911_item	3685429	et	3	main
ja	doc_769634019911_item	3685428	et	3	main
matkama	doc_769634019911_item	3685427	et	3	main
korjata	doc_769634019911_item	3685426	et	4	main
seeni	doc_769634019911_item	3685425	et	3	main
saab	doc_769634019911_item	3685424	et	3	main
sügisel	doc_769634019911_item	3685423	et	3	main
puhkusereisid	doc_769634019911_item	3685422	et	3	main
jõuavad	doc_769634019911_item	3685421	et	4	main
ja	doc_769634019911_item	3685469	et	3	main
pidutsen	doc_769634019911_item	3685449	et	3	main
ma	doc_769634019911_item	3685448	et	3	main
talv	doc_769634019911_item	3685447	et	3	main
lemmikaastaaeg	doc_769634019911_item	3685446	et	3	main
lehed	doc_769634019911_item	3685413	et	3	main
järgmine	doc_769634019911_item	3685409	et	3	main
hästi	doc_769634019911_item	3685408	et	3	main
sinine	doc_769634019911_item	3685388	et	4	main
taevas	doc_769634019911_item	3685386	et	4	main
alati	doc_769634019911_item	3685380	et	4	main
ole	doc_769634019911_item	3685379	et	4	main
ei	doc_769634019911_item	3685378	et	4	main
suved	doc_769634019911_item	3685377	et	3	main
kevadel	doc_769634019911_item	3685356	et	4	main
kui	doc_769634019911_item	3685352	et	3	main
algab	doc_769634019911_item	3685338	et	3	main
sügis	doc_769634019911_item	3685334	et	3	main
filmid	doc_769634019910_item	3685612	et	4	main
eesti	doc_769634019910_item	3685605	et	4	main
vist	doc_769634019910_item	3685601	et	4	main
eestis	doc_769634019910_item	3685600	et	3	main
on	doc_769634019910_item	3685598	et	4	main
võõrkeeli	doc_769634019910_item	3685588	et	3	main
keelt	doc_769634019910_item	3685584	et	4	main
võõrkeelt	doc_769634019910_item	3685582	et	4	main
ta	doc_769634019910_item	3685579	et	4	main
ning	doc_769634019910_item	3685564	et	3	main
üks	doc_769634019910_item	3685562	et	3	main
neil	doc_769634019910_item	3685560	et	4	main
vana	doc_769634019910_item	3685559	et	4	main
aastat	doc_769634019910_item	3685558	et	3	main
üks	doc_769634019910_item	3685557	et	3	main
nad	doc_769634019910_item	3685547	et	3	main
minu	doc_769634019910_item	3685543	et	3	main
isa	doc_769634019910_item	3685535	et	4	main
ja	doc_769634019910_item	3685514	et	3	main
uisutada	doc_769634019910_item	3685511	et	3	main
opin	doc_769634019910_item	3685502	et	4	main
ma	doc_769634019910_item	3685501	et	3	main
göttingenis	doc_769634019910_item	3685500	et	4	main
elan	doc_769634019910_item	3685499	et	3	main
ma	doc_769634019910_item	3685498	et	3	main
ei	doc_680929863178_item	3685735	et	4	main
ma	doc_680929863178_item	3685734	et	3	main
aga	doc_680929863178_item	3685733	et	3	main
tundsin	doc_680929863178_item	3685726	et	3	main
ükskõik	doc_680929863178_item	3685724	et	3	main
lätis	doc_680929863178_item	3685714	et	4	main
nii	doc_680929863178_item	3685694	et	3	main
et	doc_680929863178_item	3685641	et	3	main
ja	doc_680929863178_item	3685634	et	3	main
tõesti	doc_680929863178_item	3685631	et	3	main
ei	doc_680929863178_item	3685629	et	4	main
ma	doc_680929863178_item	3685628	et	3	main
sest	doc_680929863178_item	3685627	et	4	main
sakslaste	doc_680929863178_item	3685619	et	3	main
pidutsevad	doc_680929863178_item	3685673	et	4	main
kui	doc_680929863178_item	3685663	et	3	main
rohkem	doc_680929863178_item	3685661	et	4	main
söin	doc_464301607742_item	3685825	et	4	main
vaatasin	doc_464301607742_item	3685807	et	3	main
join	doc_464301607742_item	3685785	et	4	main
ole	doc_680929863180_item	3685941	et	4	main
voivad	doc_680929863180_item	3685934	et	4	main
on	doc_680929863180_item	3685928	et	4	main
elada	doc_680929863180_item	3685924	et	3	main
pihlakad	doc_680929863180_item	3685919	et	3	main
ja	doc_680929863180_item	3685894	et	3	main
aeas	doc_680929863180_item	3685889	et	4	main
meil	doc_680929863180_item	3685884	et	4	main
laps	doc_680929863180_item	3685883	et	4	main
koer	doc_680929863180_item	3685870	et	3	main
ole	doc_680929863180_item	3685864	et	4	main
matk	doc_680929863180_item	3686075	et	3	main
soomes	doc_680929863180_item	3686055	et	4	main
asja	doc_680929863180_item	3686049	et	4	main
sest	doc_680929863180_item	3686040	et	4	main
koera	doc_680929863180_item	3686037	et	4	main
hea	doc_680929863180_item	3686035	et	4	main
on	doc_680929863180_item	3686027	et	4	main
perekond	doc_680929863180_item	3686023	et	3	main
kasvanud	doc_680929863180_item	3686008	et	4	main
inimesed	doc_769634019911_item	3685419	et	3	main
uus	doc_769634019911_item	3685415	et	3	main
algab	doc_769634019911_item	3685410	et	3	main
eriti	doc_769634019911_item	3685407	et	3	main
korjata	doc_769634019911_item	3685403	et	4	main
lilled	doc_769634019911_item	3685402	et	3	main
ja	doc_769634019911_item	3685401	et	3	main
meres	doc_769634019911_item	3685399	et	3	main
päike	doc_769634019911_item	3685389	et	3	main
selline	doc_769634019911_item	3685381	et	4	main
lihavõttepühadel	doc_769634019911_item	3685363	et	3	main
otsida	doc_769634019911_item	3685362	et	4	main
munad	doc_769634019911_item	3685361	et	3	main
ja	doc_769634019911_item	3685360	et	3	main
rulluisutada	doc_769634019911_item	3685359	et	3	main
jalutada	doc_769634019911_item	3685358	et	3	main
sest	doc_769634019911_item	3685346	et	4	main
roheline	doc_769634019911_item	3685345	et	4	main
on	doc_769634019911_item	3685344	et	4	main
värv	doc_769634019911_item	3685343	et	3	main
aastaring	doc_769634019911_item	3685337	et	3	main
aastaajad	doc_769634019911_item	3685330	et	3	main
on	doc_769634019910_item	3685615	et	4	main
peatselt	doc_769634019910_item	3685604	et	4	main
oskan	doc_769634019910_item	3685603	et	3	main
vanaema	doc_769634019910_item	3685595	et	4	main
keelt	doc_769634019910_item	3685593	et	4	main
ja	doc_769634019910_item	3685591	et	3	main
käib	doc_769634019910_item	3685577	et	3	main
on	doc_769634019910_item	3685572	et	4	main
esnimi	doc_769634019910_item	3685570	et	4	main
on	doc_769634019910_item	3685569	et	4	main
nimi	doc_769634019910_item	3685568	et	3	main
venna	doc_769634019910_item	3685567	et	3	main
aed	doc_769634019910_item	3685565	et	3	main
nelikümmend	doc_769634019910_item	3685556	et	4	main
on	doc_769634019910_item	3685555	et	4	main
elendis	doc_769634019910_item	3685552	et	4	main
elavad	doc_769634019910_item	3685551	et	4	main
vend	doc_769634019910_item	3685550	et	3	main
minu	doc_769634019910_item	3685549	et	3	main
ja	doc_769634019910_item	3685548	et	3	main
on	doc_769634019910_item	3685537	et	4	main
silmad	doc_769634019910_item	3685536	et	4	main
väike	doc_769634019910_item	3685529	et	4	main
ega	doc_769634019910_item	3685528	et	3	main
ei	doc_769634019910_item	3685525	et	4	main
süüa	doc_769634019910_item	3685516	et	3	main
ja	doc_769634019910_item	3685512	et	3	main
ülikoolis	doc_769634019910_item	3685508	et	4	main
saksa	doc_769634019910_item	3685505	et	4	main
ja	doc_769634019910_item	3685504	et	3	main
üldkeeleteadust	doc_769634019910_item	3685503	et	4	main
puudun	doc_680929863178_item	3685742	et	3	main
õelda	doc_680929863178_item	3685737	et	4	main
osa	doc_680929863178_item	3685736	et	4	main
on	doc_680929863178_item	3685731	et	4	main
oli	doc_680929863178_item	3685723	et	3	main
ja	doc_680929863178_item	3685721	et	3	main
elasin	doc_680929863178_item	3685713	et	3	main
sakslased	doc_680929863178_item	3685710	et	3	main
ole	doc_680929863178_item	3685693	et	4	main
euro	doc_680929863178_item	3685691	et	4	main
näiteks	doc_680929863178_item	3685690	et	4	main
lätlased	doc_680929863178_item	3685642	et	3	main
ma	doc_680929863178_item	3685637	et	3	main
lätlaste	doc_680929863178_item	3685635	et	3	main
sakslaste	doc_680929863178_item	3685633	et	3	main
raske	doc_680929863178_item	3685625	et	4	main
on	doc_680929863178_item	3685624	et	4	main
see	doc_680929863178_item	3685623	et	3	main
ka	doc_680929863178_item	3685672	et	3	main
nad	doc_680929863178_item	3685671	et	3	main
rohi	doc_769634019911_item	3685347	et	4	main
meelest	doc_769634019911_item	3685341	et	4	main
minu	doc_769634019911_item	3685340	et	3	main
ja	doc_769634019911_item	3685335	et	3	main
minu	doc_769634019910_item	3685613	et	3	main
raamatud	doc_769634019910_item	3685610	et	4	main
meeldib	doc_769634019910_item	3685608	et	3	main
ema	doc_769634019910_item	3685597	et	4	main
latinise	doc_769634019910_item	3685592	et	4	main
oskan	doc_769634019910_item	3685586	et	3	main
koolis	doc_769634019910_item	3685578	et	4	main
vana	doc_769634019910_item	3685575	et	4	main
kümme	doc_769634019910_item	3685573	et	3	main
maja	doc_769634019910_item	3685563	et	4	main
on	doc_769634019910_item	3685561	et	4	main
minu	doc_769634019910_item	3685553	et	3	main
pangas	doc_769634019910_item	3685546	et	4	main
ema	doc_769634019910_item	3685544	et	4	main
silmad	doc_769634019910_item	3685531	et	4	main
minu	doc_769634019910_item	3685530	et	3	main
ole	doc_769634019910_item	3685526	et	4	main
laulda	doc_769634019910_item	3685523	et	4	main
üldse	doc_769634019910_item	3685522	et	3	main
oska	doc_769634019910_item	3685521	et	4	main
natuke	doc_769634019910_item	3685515	et	4	main
kududa	doc_769634019910_item	3685513	et	3	main
miks	doc_680929863178_item	3685738	et	4	main
erinevad	doc_680929863178_item	3685732	et	4	main
ma	doc_680929863178_item	3685725	et	3	main
see	doc_680929863178_item	3685722	et	3	main
seda	doc_680929863178_item	3685720	et	3	main
ma	doc_680929863178_item	3685712	et	3	main
nii	doc_680929863178_item	3685707	et	3	main
aga	doc_680929863178_item	3685696	et	3	main
ja	doc_680929863178_item	3685687	et	3	main
filmi	doc_680929863178_item	3685685	et	4	main
sageli	doc_680929863178_item	3685638	et	3	main
erinevusi	doc_680929863178_item	3685636	et	4	main
seletada	doc_680929863178_item	3685632	et	3	main
ja	doc_680929863178_item	3685620	et	3	main
essee	doc_680929863178_item	3685618	et	4	main
üks	doc_680929863178_item	3685676	et	3	main
omasid	doc_680929863178_item	3685668	et	4	main
nad	doc_680929863178_item	3685666	et	3	main
sakslased	doc_680929863178_item	3685664	et	3	main
kell	doc_464301607742_item	3685822	et	3	main
pikk	doc_769634019910_item	3685527	et	4	main
ma	doc_769634019910_item	3685524	et	3	main
ja	doc_680929863178_item	3685729	et	3	main
lätlased	doc_680929863178_item	3685728	et	3	main
ole	doc_680929863178_item	3685718	et	4	main
kui	doc_680929863178_item	3685711	et	3	main
kui	doc_680929863178_item	3685709	et	3	main
bürokraatilised	doc_680929863178_item	3685708	et	4	main
ole	doc_680929863178_item	3685706	et	4	main
lätlased	doc_680929863178_item	3685704	et	3	main
ei	doc_680929863178_item	3685705	et	4	main
lopesa	doc_680929863178_item	3685703	et	4	main
dženifera	doc_680929863178_item	3685702	et	2	main
on	doc_680929863178_item	3685701	et	4	main
lopez	doc_680929863178_item	3685700	et	4	main
jennifer	doc_680929863178_item	3685699	et	4	main
ja	doc_680929863178_item	3685698	et	3	main
eiro	doc_680929863178_item	3685697	et	4	main
oskan	doc_769634019910_item	3685510	et	3	main
ma	doc_769634019910_item	3685509	et	3	main
göttingeni	doc_769634019910_item	3685507	et	4	main
filoloogiat	doc_769634019910_item	3685506	et	3	main
oktoobril	doc_769634019910_item	3685497	et	3	main
peale	doc_769634019910_item	3685496	et	4	main
aga	doc_769634019910_item	3685495	et	3	main
wernigerodis	doc_769634019910_item	3685494	et	4	main
saksamaal	doc_769634019910_item	3685493	et	4	main
sündinud	doc_769634019910_item	3685492	et	4	main
olen	doc_769634019910_item	3685491	et	3	main
ma	doc_769634019910_item	3685490	et	3	main
perekonnanimi	doc_769634019910_item	3685489	et	3	main
on	doc_769634019910_item	3685488	et	4	main
perekonnanimi	doc_769634019910_item	3685487	et	3	main
minu	doc_769634019910_item	3685486	et	3	main
vana	doc_769634019910_item	3685485	et	4	main
aastat	doc_769634019910_item	3685484	et	3	main
üheksateist	doc_769634019910_item	3685483	et	4	main
olen	doc_769634019910_item	3685482	et	3	main
ma	doc_769634019910_item	3685481	et	3	main
eesnimi	doc_769634019910_item	3685480	et	3	main
on	doc_769634019910_item	3685479	et	4	main
nimi	doc_769634019910_item	3685478	et	3	main
minu	doc_769634019910_item	3685477	et	3	main
essee	doc_769634019910_item	3685476	et	4	main
näite	doc_680929863178_item	3685743	et	4	main
praegu	doc_680929863178_item	3685741	et	3	main
ma	doc_680929863178_item	3685740	et	3	main
ja	doc_680929863178_item	3685739	et	3	main
sakslased	doc_680929863178_item	3685730	et	3	main
et	doc_680929863178_item	3685727	et	3	main
teadnud	doc_680929863178_item	3685719	et	4	main
ei	doc_680929863178_item	3685717	et	4	main
ametiisik	doc_680929863178_item	3685716	et	3	main
mitte	doc_680929863178_item	3685715	et	3	main
lätis	doc_680929863178_item	3685695	et	4	main
ei	doc_680929863178_item	3685692	et	4	main
ei	doc_680929863178_item	3685643	et	4	main
lätis	doc_680929863178_item	3685640	et	4	main
küsimus	doc_680929863178_item	3685626	et	4	main
lätlaste	doc_680929863178_item	3685621	et	3	main
on	doc_680929863178_item	3685678	et	4	main
erinevus	doc_680929863178_item	3685677	et	4	main
pidupäeve	doc_680929863178_item	3685675	et	3	main
rohkem	doc_680929863178_item	3685674	et	4	main
traditsioone	doc_680929863178_item	3685669	et	3	main
tunnevad	doc_680929863178_item	3685667	et	3	main
aga	doc_680929863178_item	3685665	et	3	main
melanhoolsed	doc_680929863178_item	3685662	et	3	main
vaatasin	doc_464301607742_item	3685828	et	3	main
ma	doc_464301607742_item	3685827	et	3	main
hommikuusööki	doc_464301607742_item	3685826	et	4	main
ärasin	doc_464301607742_item	3685821	et	4	main
kaks	doc_464301607742_item	3685818	et	3	main
ma	doc_464301607742_item	3685814	et	3	main
ma	doc_464301607742_item	3685806	et	3	main
kinno	doc_464301607742_item	3685803	et	3	main
keelt	doc_464301607742_item	3685795	et	4	main
sõnu	doc_680929863178_item	3685689	et	4	main
võõrkeelse	doc_680929863178_item	3685688	et	3	main
tiitre	doc_680929863178_item	3685686	et	4	main
näiteks	doc_680929863178_item	3685684	et	4	main
kõike	doc_680929863178_item	3685683	et	4	main
tõlgivad	doc_680929863178_item	3685682	et	3	main
lätlased	doc_680929863178_item	3685681	et	3	main
et	doc_680929863178_item	3685680	et	3	main
tundsin	doc_680929863178_item	3685639	et	3	main
oska	doc_680929863178_item	3685630	et	4	main
erinevused	doc_680929863178_item	3685622	et	4	main
see	doc_680929863178_item	3685679	et	3	main
ja	doc_680929863178_item	3685670	et	3	main
ja	doc_464301607742_item	3685824	et	3	main
ma	doc_464301607742_item	3685820	et	3	main
kell	doc_464301607742_item	3685817	et	3	main
tulin	doc_464301607742_item	3685815	et	3	main
sõbraga	doc_464301607742_item	3685813	et	3	main
ma	doc_464301607742_item	3685810	et	3	main
vene	doc_464301607742_item	3685804	et	4	main
läksin	doc_464301607742_item	3685802	et	3	main
natuke	doc_464301607742_item	3685797	et	4	main
ja	doc_464301607742_item	3685796	et	3	main
öhtupoolikul	doc_464301607742_item	3685787	et	4	main
kus	doc_464301607742_item	3685783	et	3	main
midagi	doc_680929863180_item	3685946	et	4	main
ei	doc_680929863180_item	3685940	et	4	main
meie	doc_680929863180_item	3685938	et	4	main
metsas	doc_680929863180_item	3685936	et	3	main
se	doc_680929863180_item	3685927	et	4	main
ääres	doc_680929863180_item	3685926	et	4	main
tammid	doc_680929863180_item	3685921	et	3	main
mets	doc_680929863180_item	3685915	et	3	main
taga	doc_680929863180_item	3685913	et	4	main
lilli	doc_680929863180_item	3685911	et	4	main
õunapuud	doc_680929863180_item	3685891	et	4	main
veel	doc_680929863180_item	3685886	et	4	main
olin	doc_680929863180_item	3685882	et	3	main
ma	doc_680929863180_item	3685881	et	3	main
on	doc_680929863180_item	3685877	et	4	main
suvel	doc_680929863180_item	3685875	et	3	main
kukk	doc_680929863180_item	3685874	et	3	main
ja	doc_680929863180_item	3685873	et	3	main
kanad	doc_680929863180_item	3685872	et	3	main
on	doc_680929863180_item	3685868	et	4	main
ei	doc_680929863180_item	3685863	et	4	main
essee	doc_680929863180_item	3685854	et	4	main
bussiga	doc_680929863180_item	3686073	et	3	main
päev	doc_680929863180_item	3686072	et	3	main
sõitavad	doc_680929863180_item	3686070	et	4	main
lapsed	doc_680929863180_item	3686069	et	3	main
ja	doc_680929863180_item	3686068	et	3	main
ole	doc_680929863180_item	3686058	et	4	main
saksamaal	doc_680929863180_item	3686052	et	4	main
tänaval	doc_680929863180_item	3686045	et	4	main
mängida	doc_680929863180_item	3686044	et	3	main
lastelega	doc_680929863180_item	3686039	et	4	main
paras	doc_680929863180_item	3686028	et	3	main
suureks	doc_680929863180_item	3686009	et	4	main
kui	doc_680929863180_item	3686002	et	3	main
iga	doc_680929863180_item	3685996	et	4	main
võib	doc_680929863180_item	3685995	et	3	main
linnas	doc_680929863180_item	3685994	et	4	main
ja	doc_680929863181_item	3686311	et	3	main
võimalik	doc_680929863181_item	3686300	et	3	main
ja	doc_680929863181_item	3686294	et	3	main
vesterålenid	doc_680929863181_item	3686280	et	4	main
aga	doc_680929863181_item	3686279	et	3	main
maal	doc_680929863181_item	3686278	et	4	main
ei	doc_680929863181_item	3686270	et	4	main
sajab	doc_680929863181_item	3686265	et	3	main
põhis	doc_680929863181_item	3686263	et	3	main
lund	doc_680929863181_item	3686260	et	3	main
mulle	doc_680929863181_item	3686256	et	4	main
olema	doc_680929863181_item	3686254	et	4	main
ma	doc_680929863181_item	3686247	et	3	main
vesterålenil	doc_680929863181_item	3686243	et	4	main
ma	doc_680929863181_item	3686241	et	3	main
väga	doc_680929863181_item	3686239	et	3	main
jooksma	doc_680929863181_item	3686222	et	3	main
värvikaid	doc_680929863181_item	3686211	et	4	main
on	doc_680929863181_item	3686210	et	4	main
on	doc_680929863178_item	3685660	et	4	main
lätlased	doc_680929863178_item	3685659	et	3	main
et	doc_680929863178_item	3685658	et	3	main
arvan	doc_680929863178_item	3685657	et	3	main
ma	doc_680929863178_item	3685656	et	3	main
südamlikud	doc_680929863178_item	3685655	et	3	main
väga	doc_680929863178_item	3685654	et	3	main
on	doc_680929863178_item	3685653	et	4	main
sakslased	doc_680929863178_item	3685652	et	3	main
kas	doc_680929863178_item	3685651	et	3	main
tea	doc_680929863178_item	3685650	et	4	main
ei	doc_680929863178_item	3685649	et	4	main
ma	doc_680929863178_item	3685648	et	3	main
aga	doc_680929863178_item	3685647	et	3	main
südamlikud	doc_680929863178_item	3685646	et	3	main
nii	doc_680929863178_item	3685645	et	3	main
ole	doc_680929863178_item	3685644	et	4	main
üksteist	doc_464301607742_item	3685823	et	4	main
pühapäeval	doc_464301607742_item	3685819	et	3	main
koju	doc_464301607742_item	3685816	et	3	main
baari	doc_464301607742_item	3685812	et	4	main
läksin	doc_464301607742_item	3685811	et	3	main
teatri	doc_464301607742_item	3685805	et	3	main
ma	doc_464301607742_item	3685801	et	3	main
öhtul	doc_464301607742_item	3685800	et	4	main
vene	doc_464301607742_item	3685794	et	4	main
peab	doc_680929863180_item	3685947	et	4	main
natuke	doc_464301607742_item	3685852	et	4	main
veel	doc_464301607742_item	3685851	et	4	main
õppisin	doc_464301607742_item	3685850	et	3	main
ma	doc_464301607742_item	3685849	et	3	main
õhtul	doc_464301607742_item	3685848	et	3	main
pühapäeva	doc_464301607742_item	3685847	et	4	main
mitte	doc_464301607742_item	3685846	et	3	main
ostnud	doc_464301607742_item	3685845	et	4	main
ei	doc_464301607742_item	3685844	et	4	main
ma	doc_464301607742_item	3685843	et	3	main
aga	doc_464301607742_item	3685842	et	3	main
jõuluturul	doc_464301607742_item	3685841	et	3	main
platsil	doc_464301607742_item	3685840	et	3	main
raekoja	doc_464301607742_item	3685839	et	3	main
käisin	doc_464301607742_item	3685838	et	3	main
ma	doc_464301607742_item	3685837	et	3	main
linna	doc_464301607742_item	3685836	et	4	main
läksin	doc_464301607742_item	3685835	et	3	main
mö	doc_464301607742_item	3685834	et	4	main
1	doc_464301607742_item	3685833	et	2	main
kell	doc_464301607742_item	3685832	et	3	main
ja	doc_464301607742_item	3685831	et	3	main
televiisori	doc_464301607742_item	3685830	et	4	main
ka	doc_464301607742_item	3685829	et	3	main
filmi	doc_464301607742_item	3685809	et	4	main
filmi	doc_464301607742_item	3685808	et	4	main
keelt	doc_464301607742_item	3685799	et	4	main
eesti	doc_464301607742_item	3685798	et	4	main
oppisin	doc_464301607742_item	3685793	et	4	main
ma	doc_464301607742_item	3685792	et	3	main
kus	doc_464301607742_item	3685791	et	3	main
raamatukogus	doc_464301607742_item	3685790	et	4	main
olin	doc_464301607742_item	3685789	et	3	main
ma	doc_464301607742_item	3685788	et	3	main
ma	doc_464301607742_item	3685784	et	3	main
kohvikusse	doc_464301607742_item	3685782	et	4	main
läksin	doc_464301607742_item	3685781	et	3	main
ma	doc_464301607742_item	3685780	et	3	main
esiteks	doc_464301607742_item	3685779	et	3	main
kesklinna	doc_464301607742_item	3685778	et	4	main
läksin	doc_464301607742_item	3685777	et	3	main
ma	doc_464301607742_item	3685776	et	3	main
ja	doc_464301607742_item	3685775	et	3	main
11	doc_464301607742_item	3685774	et	2	main
kell	doc_464301607742_item	3685773	et	3	main
kodust	doc_464301607742_item	3685772	et	4	main
läksin	doc_464301607742_item	3685771	et	3	main
ma	doc_464301607742_item	3685770	et	3	main
laupäeval	doc_464301607742_item	3685769	et	3	main
televiisorid	doc_464301607742_item	3685768	et	3	main
vaatasin	doc_464301607742_item	3685767	et	3	main
ma	doc_464301607742_item	3685766	et	3	main
seel	doc_464301607742_item	3685765	et	4	main
ja	doc_464301607742_item	3685764	et	3	main
kodus	doc_464301607742_item	3685763	et	4	main
olin	doc_464301607742_item	3685762	et	3	main
ma	doc_464301607742_item	3685761	et	3	main
õhtul	doc_464301607742_item	3685760	et	3	main
siis	doc_464301607742_item	3685759	et	3	main
raamatukogus	doc_464301607742_item	3685758	et	4	main
olin	doc_464301607742_item	3685757	et	3	main
ma	doc_464301607742_item	3685756	et	3	main
õhtupoolikul	doc_464301607742_item	3685755	et	3	main
ja	doc_464301607742_item	3685754	et	3	main
ülikoolis	doc_464301607742_item	3685753	et	4	main
kui	doc_680929863180_item	3685943	et	3	main
hea	doc_680929863180_item	3685930	et	4	main
eriti	doc_680929863180_item	3685929	et	3	main
metsa	doc_680929863180_item	3685925	et	4	main
ja	doc_680929863180_item	3685920	et	3	main
meie	doc_680929863180_item	3685888	et	4	main
kun	doc_680929863180_item	3685880	et	4	main
meil	doc_680929863180_item	3685876	et	4	main
talu	doc_680929863180_item	3685865	et	4	main
meil	doc_680929863180_item	3685862	et	4	main
maal	doc_680929863180_item	3685861	et	4	main
hommikuukohvi	doc_464301607742_item	3685786	et	4	main
keelt	doc_464301607742_item	3685752	et	4	main
prantsuse	doc_464301607742_item	3685751	et	3	main
oppisin	doc_464301607742_item	3685750	et	4	main
ma	doc_464301607742_item	3685749	et	3	main
reedel	doc_464301607742_item	3685748	et	3	main
nädalavahetus	doc_464301607742_item	3685747	et	4	main
minu	doc_464301607742_item	3685746	et	3	main
essee	doc_464301607742_item	3685745	et	4	main
teise	doc_680929863180_item	3685949	et	4	main
otsida	doc_680929863180_item	3685945	et	4	main
tahab	doc_680929863180_item	3685944	et	3	main
külas	doc_680929863180_item	3685939	et	3	main
sest	doc_680929863180_item	3685932	et	4	main
lastele	doc_680929863180_item	3685931	et	4	main
mulle	doc_680929863180_item	3685922	et	4	main
kasvavad	doc_680929863180_item	3685917	et	4	main
pirnipuud	doc_680929863180_item	3685892	et	4	main
oli	doc_680929863180_item	3685885	et	3	main
ka	doc_680929863180_item	3685878	et	3	main
elavad	doc_680929863180_item	3685860	et	4	main
ehk	doc_680929863180_item	3686077	et	3	main
elavad	doc_680929863180_item	3686065	et	4	main
inimesed	doc_680929863180_item	3686064	et	3	main
mõni	doc_680929863180_item	3686063	et	3	main
saksamaal	doc_680929863180_item	3686056	et	4	main
maal	doc_680929863180_item	3686051	et	4	main
elada	doc_680929863180_item	3686050	et	3	main
voi	doc_680929863180_item	3686043	et	4	main
elada	doc_680929863180_item	3686036	et	3	main
ole	doc_680929863180_item	3686034	et	4	main
ei	doc_680929863180_item	3686033	et	4	main
maal	doc_680929863180_item	3686026	et	4	main
elada	doc_680929863180_item	3686025	et	3	main
ja	doc_680929863180_item	3686024	et	3	main
on	doc_680929863180_item	3686020	et	4	main
sest	doc_680929863180_item	3686015	et	4	main
maal	doc_680929863180_item	3686014	et	4	main
elada	doc_680929863180_item	3686013	et	3	main
taas	doc_680929863180_item	3686012	et	3	main
tahan	doc_680929863180_item	3686011	et	3	main
ma	doc_680929863180_item	3686010	et	3	main
tahab	doc_680929863180_item	3686003	et	3	main
kinnos	doc_680929863180_item	3686001	et	4	main
peole	doc_680929863180_item	3685999	et	4	main
käia	doc_680929863180_item	3685998	et	4	main
õhtul	doc_680929863180_item	3685997	et	3	main
ja	doc_680929863180_item	3685992	et	3	main
meeldib	doc_680929863180_item	3685989	et	3	main
liiga	doc_680929863181_item	3686326	et	4	main
sest	doc_680929863181_item	3686324	et	4	main
seal	doc_680929863181_item	3686323	et	4	main
elada	doc_680929863181_item	3686322	et	3	main
puhkusel	doc_680929863181_item	3686315	et	4	main
olla	doc_680929863181_item	3686314	et	3	main
tore	doc_680929863181_item	3686313	et	3	main
väga	doc_680929863181_item	3686309	et	3	main
põhitulid	doc_680929863181_item	3686302	et	4	main
on	doc_680929863181_item	3686291	et	4	main
talvel	doc_680929863181_item	3686290	et	4	main
asuvad	doc_680929863181_item	3686281	et	4	main
lund	doc_680929863181_item	3686267	et	3	main
ja	doc_680929863181_item	3686262	et	3	main
meeldib	doc_680929863181_item	3686257	et	3	main
suvel	doc_680929863181_item	3686245	et	3	main
ajal	doc_680929863181_item	3686231	et	4	main
paksu	doc_680929863181_item	3686212	et	4	main
on	doc_680929863181_item	3686206	et	4	main
kividest	doc_680929863181_item	3686172	et	3	main
on	doc_680929863181_item	3686144	et	4	main
see	doc_680929863181_item	3686143	et	3	main
ja	doc_680929863181_item	3686142	et	3	main
linn	doc_680929863181_item	3686141	et	3	main
üks	doc_680929863181_item	3686140	et	3	main
linnas	doc_680929863180_item	3686082	et	4	main
elada	doc_680929863180_item	3686081	et	3	main
parem	doc_680929863180_item	3686080	et	4	main
on	doc_680929863180_item	3686079	et	4	main
sõitma	doc_680929863180_item	3685948	et	3	main
kauplust	doc_680929863180_item	3685942	et	4	main
aga	doc_680929863180_item	3685937	et	3	main
mängida	doc_680929863180_item	3685935	et	3	main
nad	doc_680929863180_item	3685933	et	3	main
meeldib	doc_680929863180_item	3685923	et	3	main
männid	doc_680929863180_item	3685918	et	3	main
metsas	doc_680929863180_item	3685916	et	3	main
on	doc_680929863180_item	3685914	et	4	main
aeda	doc_680929863180_item	3685912	et	4	main
palju	doc_680929863180_item	3685910	et	4	main
ja	doc_680929863180_item	3685909	et	3	main
maasikaid	doc_680929863180_item	3685908	et	3	main
veel	doc_680929863180_item	3685907	et	4	main
siis	doc_680929863180_item	3685906	et	3	main
ja	doc_680929863180_item	3685905	et	3	main
tomateid	doc_680929863180_item	3685904	et	3	main
ja	doc_680929863180_item	3685903	et	3	main
kõrvitsaid	doc_680929863180_item	3685902	et	3	main
porgandeid	doc_680929863180_item	3685901	et	3	main
näiteks	doc_680929863180_item	3685900	et	4	main
viljad	doc_680929863180_item	3685899	et	3	main
ka	doc_680929863180_item	3685898	et	3	main
kasvavad	doc_680929863180_item	3685897	et	4	main
seal	doc_680929863180_item	3685896	et	4	main
viinamarid	doc_680929863180_item	3685895	et	3	main
ploomipuud	doc_680929863180_item	3685893	et	4	main
kasvavad	doc_680929863180_item	3685890	et	4	main
jänesid	doc_680929863180_item	3685887	et	4	main
tibud	doc_680929863180_item	3685879	et	3	main
ja	doc_680929863180_item	3685871	et	3	main
vana	doc_680929863180_item	3685869	et	4	main
meil	doc_680929863180_item	3685867	et	4	main
aga	doc_680929863180_item	3685866	et	3	main
vanemad	doc_680929863180_item	3685859	et	4	main
minu	doc_680929863180_item	3685858	et	3	main
linn	doc_680929863180_item	3685857	et	3	main
ja	doc_680929863180_item	3685856	et	3	main
soomes	doc_680929863180_item	3686078	et	4	main
koolini	doc_680929863180_item	3686076	et	4	main
iga	doc_680929863180_item	3686071	et	4	main
metsa	doc_680929863180_item	3686067	et	4	main
keskel	doc_680929863180_item	3686066	et	3	main
ei	doc_680929863180_item	3686057	et	4	main
või	doc_680929863180_item	3686053	et	4	main
on	doc_680929863180_item	3686047	et	4	main
kindlasti	doc_680929863180_item	3686046	et	3	main
nad	doc_680929863180_item	3686041	et	3	main
linnas	doc_680929863180_item	3686032	et	4	main
ja	doc_680929863180_item	3686022	et	3	main
mulla	doc_680929863180_item	3686019	et	4	main
tahan	doc_680929863180_item	3686017	et	3	main
ma	doc_680929863180_item	3686016	et	3	main
kui	doc_680929863180_item	3686005	et	3	main
või	doc_680929863180_item	3686000	et	4	main
inimesi	doc_680929863181_item	3686328	et	4	main
alati	doc_680929863181_item	3686321	et	4	main
on	doc_680929863181_item	3686312	et	4	main
ka	doc_680929863181_item	3686299	et	3	main
on	doc_680929863181_item	3686298	et	4	main
olla	doc_680929863181_item	3686296	et	3	main
lund	doc_680929863181_item	3686293	et	3	main
ma	doc_680929863181_item	3686286	et	3	main
sellepärst	doc_680929863181_item	3686285	et	4	main
kaua	doc_680929863181_item	3686282	et	3	main
norras	doc_680929863181_item	3686264	et	4	main
peab	doc_680929863181_item	3686253	et	4	main
aga	doc_680929863181_item	3686246	et	3	main
vain	doc_680929863181_item	3686244	et	3	main
välja	doc_680929863181_item	3686238	et	4	main
näeb	doc_680929863181_item	3686237	et	3	main
seda	doc_680929863181_item	3686236	et	3	main
ja	doc_680929863181_item	3686235	et	3	main
tiibadega	doc_680929863181_item	3686234	et	3	main
löövad	doc_680929863181_item	3686233	et	4	main
maa	doc_680929863180_item	3685855	et	4	main
kaua	doc_680929863180_item	3686074	et	3	main
soomes	doc_680929863180_item	3686062	et	4	main
linnani	doc_680929863180_item	3686061	et	3	main
kauge	doc_680929863180_item	3686060	et	4	main
kunagi	doc_680929863180_item	3686059	et	3	main
näiteks	doc_680929863180_item	3686054	et	4	main
eri	doc_680929863180_item	3686048	et	4	main
ei	doc_680929863180_item	3686042	et	4	main
ja	doc_680929863180_item	3686038	et	3	main
lastele	doc_680929863180_item	3686031	et	4	main
ja	doc_680929863180_item	3686030	et	3	main
koerale	doc_680929863180_item	3686029	et	3	main
koer	doc_680929863180_item	3686021	et	3	main
et	doc_680929863180_item	3686018	et	3	main
aga	doc_680929863180_item	3686004	et	3	main
sest	doc_680929863180_item	3685993	et	4	main
autoga	doc_680929863180_item	3685990	et	3	main
autoga	doc_680929863180_item	3685986	et	3	main
sõita	doc_680929863180_item	3685985	et	3	main
vaja	doc_680929863180_item	3685984	et	4	main
ole	doc_680929863180_item	3685983	et	4	main
ei	doc_680929863180_item	3685982	et	4	main
sest	doc_680929863180_item	3685981	et	4	main
linnas	doc_680929863180_item	3685980	et	4	main
elada	doc_680929863180_item	3685979	et	3	main
taha	doc_680929863181_item	3686320	et	4	main
on	doc_680929863181_item	3686308	et	4	main
norras	doc_680929863181_item	3686307	et	4	main
loodus	doc_680929863181_item	3686305	et	4	main
nägema	doc_680929863181_item	3686301	et	3	main
et	doc_680929863181_item	3686297	et	3	main
võib	doc_680929863181_item	3686295	et	3	main
palju	doc_680929863181_item	3686292	et	4	main
ja	doc_680929863181_item	3686284	et	3	main
põhis	doc_680929863181_item	3686283	et	3	main
ääres	doc_680929863181_item	3686269	et	4	main
mere	doc_680929863181_item	3686268	et	3	main
sajab	doc_680929863181_item	3686261	et	3	main
kui	doc_680929863181_item	3686259	et	3	main
seal	doc_680929863181_item	3686252	et	4	main
talvel	doc_680929863181_item	3686251	et	4	main
arvan	doc_680929863181_item	3686248	et	3	main
nad	doc_680929863181_item	3686232	et	3	main
hoogu	doc_680929863181_item	3686229	et	4	main
neil	doc_680929863181_item	3686226	et	4	main
kuni	doc_680929863181_item	3686225	et	3	main
pinnal	doc_680929863181_item	3686224	et	3	main
eelkõige	doc_680929863181_item	3686221	et	3	main
linnudest	doc_680929863181_item	3686205	et	4	main
õhusse	doc_680929863181_item	3686204	et	3	main
vett	doc_680929863181_item	3686203	et	3	main
ja	doc_680929863181_item	3686184	et	3	main
liivirannad	doc_680929863181_item	3686178	et	3	main
olemas	doc_680929863181_item	3686176	et	4	main
randa	doc_680929863181_item	3686165	et	4	main
mõni	doc_680929863181_item	3686164	et	3	main
ka	doc_680929863181_item	3686163	et	3	main
on	doc_680929863181_item	3686162	et	4	main
saarel	doc_680929863181_item	3686161	et	3	main
ilus	doc_680929863181_item	3686160	et	4	main
oli	doc_680929863181_item	3686159	et	3	main
on	doc_680929863181_item	3686150	et	4	main
osa	doc_680929863181_item	3686148	et	4	main
suurim	doc_680929863181_item	3686147	et	3	main
linn	doc_680929863181_item	3686146	et	3	main
sinine	doc_680929863181_item	3686145	et	4	main
lambaid	doc_680929863181_item	3686136	et	3	main
vesterålen-saarila	doc_680929863181_item	3686106	et	4	main
maa	doc_680929863181_item	3686103	et	4	main
mulle	doc_680929863181_item	3686100	et	4	main
palju	doc_680929863181_item	3686099	et	4	main
ka	doc_680929863181_item	3686094	et	3	main
maa	doc_680929863181_item	3686085	et	4	main
päike	doc_680929863185_item	3686397	et	3	main
pilvisusega	doc_680929863185_item	3686383	et	4	main
olen	doc_680929863180_item	3686007	et	3	main
ma	doc_680929863180_item	3686006	et	3	main
sõita	doc_680929863180_item	3685991	et	3	main
ei	doc_680929863180_item	3685988	et	4	main
mulle	doc_680929863180_item	3685987	et	4	main
meeldib	doc_680929863180_item	3685978	et	3	main
mulle	doc_680929863180_item	3685977	et	4	main
nüüd	doc_680929863180_item	3685976	et	4	main
autoga	doc_680929863180_item	3685975	et	3	main
sõitma	doc_680929863180_item	3685974	et	3	main
pea	doc_680929863180_item	3685973	et	4	main
ei	doc_680929863180_item	3685972	et	4	main
lähedal	doc_680929863180_item	3685971	et	4	main
asub	doc_680929863180_item	3685970	et	3	main
kõig	doc_680929863180_item	3685969	et	4	main
et	doc_680929863180_item	3685968	et	3	main
se	doc_680929863180_item	3685967	et	4	main
hea	doc_680929863180_item	3685966	et	4	main
ka	doc_680929863180_item	3685965	et	3	main
on	doc_680929863180_item	3685964	et	4	main
linnas	doc_680929863180_item	3685963	et	4	main
kauplust	doc_680929863180_item	3685962	et	4	main
palju	doc_680929863180_item	3685961	et	4	main
asub	doc_680929863180_item	3685960	et	3	main
linnas	doc_680929863180_item	3685959	et	4	main
sest	doc_680929863180_item	3685958	et	4	main
probleem	doc_680929863180_item	3685957	et	3	main
ole	doc_680929863180_item	3685956	et	4	main
ei	doc_680929863180_item	3685955	et	4	main
seda	doc_680929863180_item	3685954	et	3	main
linnas	doc_680929863180_item	3685953	et	4	main
elab	doc_680929863180_item	3685952	et	3	main
kui	doc_680929863180_item	3685951	et	3	main
külasse	doc_680929863180_item	3685950	et	3	main
lambaid	doc_680929863181_item	3686332	et	3	main
palju	doc_680929863181_item	3686331	et	4	main
liiga	doc_680929863181_item	3686330	et	4	main
ja	doc_680929863181_item	3686329	et	3	main
vähe	doc_680929863181_item	3686327	et	3	main
on	doc_680929863181_item	3686325	et	4	main
ei	doc_680929863181_item	3686319	et	4	main
ma	doc_680929863181_item	3686318	et	3	main
aga	doc_680929863181_item	3686317	et	3	main
seal	doc_680929863181_item	3686316	et	4	main
ilus	doc_680929863181_item	3686310	et	4	main
põhis	doc_680929863181_item	3686306	et	3	main
öösel	doc_680929863181_item	3686304	et	4	main
nordlichter	doc_680929863181_item	3686303	et	4	main
seal	doc_680929863181_item	3686289	et	4	main
et	doc_680929863181_item	3686288	et	3	main
arvan	doc_680929863181_item	3686287	et	3	main
jää	doc_680929863181_item	3686277	et	4	main
lund	doc_680929863181_item	3686276	et	3	main
et	doc_680929863181_item	3686275	et	3	main
külm	doc_680929863181_item	3686274	et	3	main
piisav	doc_680929863181_item	3686273	et	4	main
alati	doc_680929863181_item	3686272	et	4	main
ole	doc_680929863181_item	3686271	et	4	main
palju	doc_680929863181_item	3686266	et	4	main
palju	doc_680929863181_item	3686258	et	4	main
ilus	doc_680929863181_item	3686255	et	4	main
ka	doc_680929863181_item	3686250	et	3	main
et	doc_680929863181_item	3686249	et	3	main
olin	doc_680929863181_item	3686242	et	3	main
kummaliselt	doc_680929863181_item	3686240	et	4	main
on	doc_680929863181_item	3686227	et	4	main
vee	doc_680929863181_item	3686223	et	3	main
peavad	doc_680929863181_item	3686220	et	4	main
nad	doc_680929863181_item	3686219	et	3	main
lennata	doc_680929863181_item	3686218	et	4	main
tahavad	doc_680929863181_item	3686217	et	3	main
nad	doc_680929863181_item	3686216	et	3	main
kui	doc_680929863181_item	3686215	et	3	main
ja	doc_680929863181_item	3686214	et	3	main
lindu	doc_680929863181_item	3686213	et	4	main
lõbusaim	doc_680929863181_item	3686207	et	4	main
ovad	doc_680929863181_item	3686167	et	4	main
nad	doc_680929863181_item	3686166	et	3	main
aga	doc_680929863181_item	3686157	et	3	main
asuvad	doc_680929863181_item	3686112	et	4	main
nad	doc_680929863181_item	3686111	et	3	main
sest	doc_680929863181_item	3686110	et	4	main
puid	doc_680929863181_item	3686109	et	3	main
seal	doc_680929863181_item	3686105	et	4	main
eriti	doc_680929863181_item	3686102	et	3	main
vesterålen-saarila	doc_680929863181_item	3686095	et	4	main
norras	doc_680929863181_item	3686087	et	4	main
loodus	doc_680929863181_item	3686086	et	4	main
seal	doc_680929863181_item	3686230	et	4	main
piisav	doc_680929863181_item	3686228	et	4	main
papageientaucher	doc_680929863181_item	3686208	et	4	main
vaatama	doc_680929863181_item	3686200	et	3	main
rannalt	doc_680929863181_item	3686199	et	3	main
ka	doc_680929863181_item	3686198	et	3	main
võib	doc_680929863181_item	3686197	et	3	main
wale	doc_680929863181_item	3686196	et	4	main
elavad	doc_680929863181_item	3686195	et	4	main
meres	doc_680929863181_item	3686194	et	3	main
vee	doc_680929863181_item	3686193	et	3	main
soojendab	doc_680929863181_item	3686192	et	3	main
golfstrom	doc_680929863181_item	3686191	et	4	main
sest	doc_680929863181_item	3686190	et	4	main
külm	doc_680929863181_item	3686189	et	3	main
väga	doc_680929863181_item	3686188	et	3	main
ole	doc_680929863181_item	3686187	et	4	main
nad	doc_680929863181_item	3686209	et	3	main
puhuma	doc_680929863181_item	3686202	et	3	main
nende	doc_680929863181_item	3686201	et	4	main
ei	doc_680929863181_item	3686186	et	4	main
lõunamerel	doc_680929863181_item	3686183	et	3	main
nagu	doc_680929863181_item	3686181	et	3	main
näevad	doc_680929863181_item	3686179	et	3	main
on	doc_680929863181_item	3686174	et	4	main
aga	doc_680929863181_item	3686173	et	3	main
miks	doc_680929863181_item	3686156	et	4	main
ei	doc_680929863181_item	3686154	et	4	main
ma	doc_680929863181_item	3686153	et	3	main
siniseks	doc_680929863181_item	3686152	et	3	main
maalatud	doc_680929863181_item	3686151	et	4	main
saaril	doc_680929863181_item	3686137	et	3	main
inimesi	doc_680929863181_item	3686133	et	4	main
liiga	doc_680929863181_item	3686113	et	4	main
me	doc_680929863181_item	3686096	et	4	main
norras	doc_680929863181_item	3686091	et	4	main
perekonnaga	doc_680929863181_item	3686090	et	4	main
olin	doc_680929863181_item	3686088	et	3	main
soojad	doc_680929863185_item	3686394	et	3	main
saksalased	doc_680929863185_item	3686385	et	4	main
on	doc_680929863185_item	3686369	et	4	main
lilled	doc_680929863185_item	3686361	et	3	main
vaba	doc_680929863185_item	3686359	et	4	main
meri	doc_680929863181_item	3686185	et	3	main
liivirannad	doc_680929863181_item	3686182	et	3	main
välja	doc_680929863181_item	3686180	et	4	main
liivirannad	doc_680929863181_item	3686177	et	3	main
ka	doc_680929863181_item	3686175	et	3	main
ovad	doc_680929863181_item	3686171	et	4	main
mõned	doc_680929863181_item	3686170	et	3	main
erilised	doc_680929863181_item	3686169	et	4	main
väga	doc_680929863181_item	3686168	et	3	main
see	doc_680929863181_item	3686158	et	3	main
tea	doc_680929863181_item	3686155	et	4	main
hoonest	doc_680929863181_item	3686149	et	4	main
on	doc_680929863181_item	3686138	et	4	main
ja	doc_680929863181_item	3686134	et	3	main
pari	doc_680929863181_item	3686132	et	4	main
elavad	doc_680929863181_item	3686131	et	4	main
saarel	doc_680929863181_item	3686130	et	3	main
murakaid	doc_680929863181_item	3686129	et	3	main
palju	doc_680929863181_item	3686128	et	4	main
veel	doc_680929863181_item	3686127	et	4	main
siis	doc_680929863181_item	3686126	et	3	main
ja	doc_680929863181_item	3686125	et	3	main
rohi	doc_680929863181_item	3686124	et	4	main
vain	doc_680929863181_item	3686123	et	3	main
kasavab	doc_680929863181_item	3686122	et	4	main
tuuline	doc_680929863181_item	3686120	et	3	main
väga	doc_680929863181_item	3686119	et	3	main
seal	doc_680929863181_item	3686121	et	4	main
alati	doc_680929863181_item	3686118	et	4	main
on	doc_680929863181_item	3686117	et	4	main
ja	doc_680929863181_item	3686116	et	3	main
põhis	doc_680929863181_item	3686115	et	3	main
kauge	doc_680929863181_item	3686114	et	4	main
vain	doc_680929863181_item	3686139	et	3	main
palju	doc_680929863181_item	3686135	et	4	main
kasva	doc_680929863181_item	3686108	et	4	main
seal	doc_680929863181_item	3686098	et	4	main
jalutasime	doc_680929863181_item	3686097	et	3	main
olime	doc_680929863181_item	3686093	et	3	main
essee	doc_680929863181_item	3686084	et	4	main
tavaliselt	doc_680929863185_item	3686393	et	4	main
ja	doc_680929863185_item	3686384	et	3	main
on	doc_680929863185_item	3686381	et	4	main
jahedat	doc_680929863185_item	3686374	et	3	main
aga	doc_680929863185_item	3686367	et	3	main
õitsema	doc_680929863185_item	3686363	et	3	main
jääme	doc_680929863185_item	3686472	et	4	main
lund	doc_680929863185_item	3686466	et	3	main
oma	doc_680929863185_item	3686457	et	4	main
korjama	doc_680929863185_item	3686456	et	3	main
seened	doc_680929863185_item	3686455	et	3	main
metsäs	doc_680929863185_item	3686449	et	4	main
ja	doc_680929863185_item	3686445	et	3	main
vihmased	doc_680929863185_item	3686431	et	4	main
pühad	doc_680929863185_item	3686427	et	3	main
pühitseme	doc_680929863185_item	3686425	et	3	main
pikad	doc_680929863185_item	3686420	et	4	main
on	doc_680929863185_item	3686419	et	4	main
kunagi	doc_35015649957_item	3686658	et	3	main
tulen	doc_35015649957_item	3686656	et	3	main
ilus	doc_35015649957_item	3686650	et	4	main
on	doc_35015649957_item	3686649	et	4	main
see	doc_35015649957_item	3686648	et	3	main
eesti	doc_35015649957_item	3686635	et	4	main
mulle	doc_35015649957_item	3686633	et	4	main
on	doc_35015649957_item	3686627	et	4	main
ja	doc_35015649957_item	3686620	et	3	main
sulatavad	doc_35015649957_item	3686611	et	4	main
üles	doc_35015649957_item	3686610	et	3	main
kõigile	doc_35015649957_item	3686598	et	4	main
peaaegu	doc_35015649957_item	3686597	et	3	main
näedsid	doc_35015649957_item	3686596	et	4	main
ma	doc_35015649957_item	3686595	et	3	main
õtteppale	doc_35015649957_item	3686594	et	4	main
ja	doc_35015649957_item	3686593	et	3	main
eestis	doc_35015649957_item	3686586	et	3	main
eestlased	doc_35015649957_item	3686585	et	3	main
joogikäitumine	doc_35015649957_item	3686584	et	3	main
ja	doc_35015649957_item	3686583	et	3	main
turisted	doc_35015649957_item	3686582	et	4	main
mulle	doc_35015649957_item	3686578	et	4	main
keskaeg	doc_35015649957_item	3686577	et	3	main
kui	doc_35015649957_item	3686576	et	3	main
tunnen	doc_35015649957_item	3686575	et	3	main
poolt	doc_35015649957_item	3686544	et	4	main
leidsin	doc_35015649957_item	3686539	et	3	main
ma	doc_35015649957_item	3686538	et	3	main
randle	doc_35015649957_item	3686537	et	4	main
ja	doc_35015649957_item	3686531	et	3	main
ülikooli	doc_35015649957_item	3686528	et	4	main
keel	doc_35015649957_item	3686526	et	4	main
ja	doc_35015649957_item	3686508	et	3	main
ei	doc_680929863181_item	3686107	et	4	main
loodus	doc_680929863181_item	3686104	et	4	main
meeldis	doc_680929863181_item	3686101	et	3	main
puhkusel	doc_680929863181_item	3686092	et	4	main
oma	doc_680929863181_item	3686089	et	4	main
ja	doc_680929863185_item	3686395	et	3	main
ovad	doc_680929863185_item	3686392	et	4	main
tahab	doc_680929863185_item	3686390	et	3	main
mis	doc_680929863185_item	3686389	et	4	main
teeb	doc_680929863185_item	3686388	et	3	main
aprill	doc_680929863185_item	3686387	et	3	main
on	doc_680929863185_item	3686377	et	4	main
rohi	doc_680929863185_item	3686376	et	4	main
ja	doc_680929863185_item	3686375	et	3	main
kevadet	doc_680929863185_item	3686368	et	4	main
ja	doc_680929863185_item	3686364	et	3	main
lueme	doc_680929863185_item	3686475	et	4	main
kasvavad	doc_680929863185_item	3686459	et	4	main
ajas	doc_680929863185_item	3686458	et	4	main
aga	doc_680929863185_item	3686448	et	3	main
udused	doc_680929863185_item	3686434	et	4	main
ja	doc_680929863185_item	3686433	et	3	main
tuulised	doc_680929863185_item	3686432	et	3	main
on	doc_680929863185_item	3686429	et	4	main
palju	doc_680929863185_item	3686426	et	4	main
me	doc_680929863185_item	3686424	et	4	main
ja	doc_680929863185_item	3686423	et	3	main
õppetööle	doc_35015649957_item	3686661	et	3	main
mulle	doc_35015649957_item	3686637	et	4	main
päikesepaisteline	doc_35015649957_item	3686628	et	4	main
vihmane	doc_35015649957_item	3686621	et	4	main
talvel	doc_35015649957_item	3686617	et	4	main
okay	doc_35015649957_item	3686615	et	4	main
ilm	doc_35015649957_item	3686613	et	3	main
nad	doc_35015649957_item	3686605	et	3	main
aga	doc_35015649957_item	3686604	et	3	main
saaremaale	doc_35015649957_item	3686592	et	4	main
palju	doc_35015649957_item	3686581	et	4	main
ja	doc_35015649957_item	3686571	et	3	main
ülikool	doc_35015649957_item	3686530	et	4	main
tallinna	doc_35015649957_item	3686527	et	4	main
eesti	doc_35015649957_item	3686509	et	4	main
mina	doc_35015649957_item	3686507	et	4	main
mitu	doc_384045275274_item	3686744	et	4	main
olin	doc_384045275274_item	3686743	et	3	main
et	doc_384045275274_item	3686742	et	3	main
endale	doc_384045275274_item	3686741	et	4	main
ei	doc_384045275274_item	3686738	et	4	main
tõttu	doc_384045275274_item	3686736	et	4	main
haiguse	doc_384045275274_item	3686735	et	4	main
tekis	doc_384045275274_item	3686734	et	3	main
mis	doc_384045275274_item	3686733	et	4	main
pärast	doc_384045275274_item	3686730	et	4	main
minul	doc_384045275274_item	3686696	et	3	main
puutub	doc_384045275274_item	3686695	et	3	main
minusse	doc_384045275274_item	3686694	et	3	main
erinevaid	doc_384045275274_item	3686685	et	4	main
ja	doc_384045275274_item	3686684	et	3	main
kelgutama	doc_680929863185_item	3686504	et	3	main
ja	doc_680929863185_item	3686503	et	3	main
suusatama	doc_680929863185_item	3686502	et	3	main
läheme	doc_680929863185_item	3686501	et	3	main
paistab	doc_680929863185_item	3686500	et	3	main
päike	doc_680929863185_item	3686499	et	3	main
kui	doc_680929863185_item	3686498	et	3	main
jääd	doc_680929863185_item	3686497	et	4	main
on	doc_680929863185_item	3686496	et	4	main
järvel	doc_680929863185_item	3686495	et	4	main
ja	doc_680929863185_item	3686494	et	3	main
pakast	doc_680929863185_item	3686493	et	3	main
öös	doc_680929863185_item	3686491	et	4	main
on	doc_680929863185_item	3686492	et	4	main
kaasas	doc_680929863185_item	3686490	et	4	main
pere	doc_680929863185_item	3686489	et	4	main
kodu	doc_680929863185_item	3686488	et	4	main
kõik	doc_680929863185_item	3686487	et	4	main
oleme	doc_680929863185_item	3686486	et	3	main
me	doc_680929863185_item	3686485	et	4	main
ilusad	doc_680929863185_item	3686396	et	3	main
suved	doc_680929863185_item	3686391	et	3	main
ütlevad	doc_680929863185_item	3686386	et	4	main
päikesepaistelised	doc_680929863185_item	3686370	et	4	main
laulavad	doc_680929863185_item	3686366	et	4	main
linnud	doc_680929863185_item	3686365	et	3	main
hakkavad	doc_680929863185_item	3686362	et	4	main
olla	doc_680929863185_item	3686358	et	3	main
hakkavad	doc_680929863185_item	3686357	et	4	main
jõed	doc_680929863185_item	3686356	et	3	main
ja	doc_680929863185_item	3686355	et	3	main
järved	doc_680929863185_item	3686354	et	3	main
sulab	doc_680929863185_item	3686353	et	3	main
lumi	doc_680929863185_item	3686352	et	3	main
ja	doc_680929863185_item	3686351	et	3	main
enam	doc_680929863185_item	3686350	et	4	main
paistab	doc_680929863185_item	3686349	et	3	main
päike	doc_680929863185_item	3686348	et	3	main
kevadel	doc_680929863185_item	3686347	et	4	main
talv	doc_680929863185_item	3686346	et	3	main
ja	doc_680929863185_item	3686345	et	3	main
sügis	doc_680929863185_item	3686344	et	3	main
suvi	doc_680929863185_item	3686343	et	3	main
kevad	doc_680929863185_item	3686342	et	3	main
aastaaega	doc_680929863185_item	3686341	et	4	main
neli	doc_680929863185_item	3686340	et	3	main
saksamal	doc_680929863185_item	3686339	et	4	main
on	doc_680929863185_item	3686338	et	4	main
meil	doc_680929863185_item	3686337	et	4	main
saksamaal	doc_680929863185_item	3686336	et	4	main
aastaajad	doc_680929863185_item	3686335	et	3	main
essee	doc_680929863185_item	3686334	et	4	main
ja	doc_680929863185_item	3686484	et	3	main
aastavahetus	doc_680929863185_item	3686483	et	4	main
ja	doc_680929863185_item	3686482	et	3	main
jõulud	doc_680929863185_item	3686481	et	3	main
ka	doc_680929863185_item	3686480	et	3	main
on	doc_680929863185_item	3686479	et	4	main
siis	doc_680929863185_item	3686478	et	3	main
raamatut	doc_680929863185_item	3686477	et	3	main
palju	doc_680929863185_item	3686476	et	4	main
vahelduva	doc_680929863185_item	3686382	et	4	main
taevas	doc_680929863185_item	3686380	et	4	main
tihti	doc_680929863185_item	3686379	et	3	main
niiske	doc_680929863185_item	3686378	et	4	main
veel	doc_680929863185_item	3686373	et	4	main
on	doc_680929863185_item	3686372	et	4	main
need	doc_680929863185_item	3686371	et	3	main
jääst	doc_680929863185_item	3686360	et	3	main
me	doc_680929863185_item	3686471	et	4	main
ja	doc_680929863185_item	3686470	et	3	main
külm	doc_680929863185_item	3686469	et	3	main
ja	doc_680929863185_item	3686461	et	3	main
vihma	doc_680929863185_item	3686437	et	4	main
sajab	doc_680929863185_item	3686436	et	3	main
tihti	doc_680929863185_item	3686435	et	3	main
ööd	doc_680929863185_item	3686418	et	4	main
äitäh	doc_35015649957_item	3686659	et	4	main
ja	doc_35015649957_item	3686653	et	3	main
meeldib	doc_35015649957_item	3686638	et	3	main
ja	doc_680929863185_item	3686474	et	3	main
kodu	doc_680929863185_item	3686473	et	4	main
väljas	doc_680929863185_item	3686467	et	4	main
sajab	doc_680929863185_item	3686465	et	3	main
talves	doc_680929863185_item	3686464	et	4	main
vahel	doc_680929863185_item	3686463	et	4	main
pirnid	doc_680929863185_item	3686462	et	3	main
õunad	doc_680929863185_item	3686460	et	3	main
käime	doc_680929863185_item	3686454	et	4	main
me	doc_680929863185_item	3686453	et	4	main
ja	doc_680929863185_item	3686452	et	3	main
seened	doc_680929863185_item	3686451	et	3	main
kasvavad	doc_680929863185_item	3686450	et	4	main
langevad	doc_680929863185_item	3686446	et	4	main
sügised	doc_680929863185_item	3686428	et	3	main
mereääres	doc_680929863185_item	3686417	et	3	main
jalgrataga	doc_680929863185_item	3686415	et	4	main
terviseks	doc_35015649957_item	3686662	et	3	main
ma	doc_35015649957_item	3686655	et	3	main
tallinnas	doc_35015649957_item	3686652	et	4	main
söök	doc_35015649957_item	3686636	et	3	main
see	doc_35015649957_item	3686626	et	3	main
olin	doc_35015649957_item	3686618	et	3	main
aga	doc_35015649957_item	3686616	et	3	main
on	doc_35015649957_item	3686614	et	4	main
eesti	doc_35015649957_item	3686612	et	4	main
sõitsid	doc_35015649957_item	3686588	et	4	main
ma	doc_35015649957_item	3686587	et	3	main
ma	doc_35015649957_item	3686574	et	3	main
keskus	doc_35015649957_item	3686570	et	3	main
ajalooline	doc_35015649957_item	3686568	et	4	main
tallinnas	doc_35015649957_item	3686565	et	4	main
lähedal	doc_35015649957_item	3686535	et	4	main
on	doc_35015649957_item	3686534	et	4	main
tallinna	doc_35015649957_item	3686529	et	4	main
sotsiaal	doc_35015649957_item	3686522	et	4	main
õpin	doc_35015649957_item	3686521	et	3	main
ma	doc_35015649957_item	3686520	et	3	main
elumaja	doc_35015649957_item	3686519	et	4	main
üliõpilased	doc_35015649957_item	3686518	et	3	main
elasid	doc_35015649957_item	3686517	et	4	main
ja	doc_35015649957_item	3686516	et	3	main
ma	doc_35015649957_item	3686510	et	3	main
essee	doc_35015649957_item	3686506	et	4	main
vastupidavus	doc_384045275274_item	3686732	et	4	main
raske	doc_384045275274_item	3686724	et	4	main
voib	doc_384045275274_item	3686690	et	4	main
probleemid	doc_384045275274_item	3686677	et	3	main
eesti	doc_384045275274_item	3686670	et	4	main
on	doc_680929863185_item	3686468	et	4	main
siis	doc_680929863185_item	3686447	et	3	main
kollased	doc_680929863185_item	3686444	et	4	main
ja	doc_680929863185_item	3686443	et	3	main
pruunid	doc_680929863185_item	3686442	et	3	main
punased	doc_680929863185_item	3686441	et	4	main
olla	doc_680929863185_item	3686440	et	3	main
hakkavad	doc_680929863185_item	3686439	et	4	main
lehed	doc_680929863185_item	3686438	et	3	main
saksamal	doc_680929863185_item	3686430	et	4	main
valged	doc_680929863185_item	3686422	et	3	main
ja	doc_680929863185_item	3686421	et	3	main
juhtime	doc_680929863185_item	3686416	et	4	main
ja	doc_680929863185_item	3686414	et	3	main
meres	doc_680929863185_item	3686413	et	3	main
ujume	doc_680929863185_item	3686412	et	3	main
me	doc_680929863185_item	3686411	et	4	main
nädalavahetusel	doc_680929863185_item	3686410	et	4	main
parkis	doc_680929863185_item	3686409	et	3	main
päevitame	doc_680929863185_item	3686408	et	3	main
ja	doc_680929863185_item	3686407	et	3	main
piknikut	doc_680929863185_item	3686406	et	3	main
palju	doc_680929863185_item	3686405	et	4	main
peame	doc_680929863185_item	3686404	et	4	main
me	doc_680929863185_item	3686403	et	4	main
siks	doc_680929863185_item	3686402	et	3	main
kuiv	doc_680929863185_item	3686401	et	3	main
on	doc_680929863185_item	3686400	et	4	main
ja	doc_680929863185_item	3686399	et	3	main
paistab	doc_680929863185_item	3686398	et	3	main
kena	doc_35015649957_item	3686660	et	4	main
tagasi	doc_35015649957_item	3686657	et	3	main
eestis	doc_35015649957_item	3686654	et	3	main
aeg	doc_35015649957_item	3686651	et	3	main
pelmenid	doc_35015649957_item	3686647	et	4	main
ja	doc_35015649957_item	3686646	et	3	main
kohuke	doc_35015649957_item	3686645	et	3	main
ja	doc_35015649957_item	3686644	et	3	main
kohupiim	doc_35015649957_item	3686643	et	3	main
ja	doc_35015649957_item	3686642	et	3	main
hapukoor	doc_35015649957_item	3686641	et	4	main
ja	doc_35015649957_item	3686640	et	3	main
pannkoogi	doc_35015649957_item	3686639	et	4	main
soe	doc_35015649957_item	3686632	et	4	main
ja	doc_35015649957_item	3686631	et	3	main
on	doc_35015649957_item	3686624	et	4	main
ilm	doc_35015649957_item	3686623	et	3	main
praegu	doc_35015649957_item	3686622	et	3	main
nad	doc_35015649957_item	3686609	et	3	main
pikk	doc_35015649957_item	3686607	et	4	main
vajanad	doc_35015649957_item	3686606	et	4	main
inimested	doc_35015649957_item	3686603	et	4	main
sõbralik	doc_35015649957_item	3686602	et	3	main
on	doc_35015649957_item	3686601	et	4	main
eestlased	doc_35015649957_item	3686600	et	3	main
eestis	doc_35015649957_item	3686599	et	3	main
narvasse	doc_35015649957_item	3686591	et	4	main
tartusse	doc_35015649957_item	3686590	et	3	main
meeldi	doc_35015649957_item	3686580	et	4	main
vanalinnas	doc_35015649957_item	3686573	et	4	main
linna	doc_35015649957_item	3686569	et	4	main
meeldib	doc_35015649957_item	3686567	et	3	main
mulle	doc_35015649957_item	3686566	et	4	main
igal	doc_35015649957_item	3686543	et	3	main
sõberedga	doc_35015649957_item	3686542	et	4	main
elasin	doc_35015649957_item	3686541	et	3	main
ja	doc_35015649957_item	3686540	et	3	main
elumaja	doc_35015649957_item	3686533	et	4	main
üliõpilased	doc_35015649957_item	3686532	et	3	main
meeldib	doc_35015649957_item	3686634	et	3	main
taevas	doc_35015649957_item	3686630	et	4	main
sinine	doc_35015649957_item	3686629	et	4	main
ilus	doc_35015649957_item	3686625	et	4	main
külm	doc_35015649957_item	3686619	et	3	main
kuni	doc_35015649957_item	3686608	et	3	main
pärnusse	doc_35015649957_item	3686589	et	4	main
ei	doc_35015649957_item	3686579	et	4	main
linnamüür	doc_35015649957_item	3686572	et	3	main
parem	doc_35015649957_item	3686564	et	4	main
kõige	doc_35015649957_item	3686563	et	4	main
on	doc_35015649957_item	3686562	et	4	main
linna	doc_35015649957_item	3686561	et	4	main
vana	doc_35015649957_item	3686560	et	4	main
linn	doc_35015649957_item	3686559	et	3	main
ilus	doc_35015649957_item	3686558	et	4	main
on	doc_35015649957_item	3686557	et	4	main
tallinn	doc_35015649957_item	3686556	et	4	main
leedusse	doc_35015649957_item	3686555	et	4	main
ja	doc_35015649957_item	3686554	et	3	main
lätisse	doc_35015649957_item	3686553	et	4	main
soomesse	doc_35015649957_item	3686552	et	3	main
venesse	doc_35015649957_item	3686551	et	3	main
sõitsime	doc_35015649957_item	3686550	et	3	main
sinne	doc_35015649957_item	3686549	et	4	main
maailmas	doc_35015649957_item	3686548	et	3	main
where	doc_35015649957_item	3686547	et	4	main
every	doc_35015649957_item	3686546	et	4	main
from	doc_35015649957_item	3686545	et	4	main
olev	doc_35015649957_item	3686536	et	4	main
eesti	doc_35015649957_item	3686525	et	4	main
ja	doc_35015649957_item	3686524	et	3	main
elan	doc_35015649957_item	3686515	et	3	main
ma	doc_35015649957_item	3686514	et	3	main
veebruaris	doc_35015649957_item	3686513	et	3	main
eestis	doc_35015649957_item	3686512	et	3	main
saavutan	doc_35015649957_item	3686511	et	3	main
leia	doc_384045275274_item	3686739	et	4	main
aastate	doc_384045275274_item	3686729	et	3	main
mis	doc_384045275274_item	3686693	et	4	main
ületada	doc_384045275274_item	3686692	et	3	main
õppida	doc_384045275274_item	3686683	et	3	main
meid	doc_384045275274_item	3686680	et	4	main
tekivad	doc_384045275274_item	3686676	et	3	main
puudusin	doc_384045275274_item	3686669	et	3	main
töö	doc_35015649957_item	3686523	et	4	main
õigustuse	doc_384045275274_item	3686740	et	4	main
ma	doc_384045275274_item	3686737	et	3	main
väike	doc_384045275274_item	3686731	et	4	main
kahe	doc_384045275274_item	3686726	et	3	main
alati	doc_384045275274_item	3686689	et	4	main
mitte	doc_384045275274_item	3686688	et	3	main
saavutada	doc_384045275274_item	3686687	et	3	main
edusid	doc_384045275274_item	3686686	et	3	main
normaalselt	doc_384045275274_item	3686681	et	4	main
segavad	doc_384045275274_item	3686679	et	4	main
mis	doc_384045275274_item	3686678	et	4	main
igal	doc_384045275274_item	3686673	et	3	main
keele	doc_384045275274_item	3686671	et	4	main
eesnimi	doc_384045275274_item	3686768	et	3	main
lugupidamisega	doc_384045275274_item	3686767	et	3	main
katseks	doc_384045275274_item	3686766	et	4	main
õigustamise	doc_384045275274_item	3686765	et	4	main
essee	doc_384045275274_item	3686764	et	4	main
selle	doc_384045275274_item	3686763	et	4	main
mitte	doc_384045275274_item	3686761	et	3	main
paluksin	doc_384045275274_item	3686760	et	3	main
vastama	doc_384045275274_item	3686759	et	3	main
arvada	doc_384045275274_item	3686762	et	4	main
eest	doc_384045275274_item	3686758	et	4	main
vigade	doc_384045275274_item	3686757	et	3	main
oma	doc_384045275274_item	3686756	et	4	main
ise	doc_384045275274_item	3686755	et	4	main
peab	doc_384045275274_item	3686754	et	4	main
iga	doc_384045275274_item	3686753	et	4	main
et	doc_384045275274_item	3686752	et	3	main
veendunud	doc_384045275274_item	3686751	et	4	main
olen	doc_384045275274_item	3686750	et	3	main
sest	doc_384045275274_item	3686749	et	4	main
puudunud	doc_384045275274_item	3686748	et	4	main
loengutest	doc_384045275274_item	3686747	et	4	main
keele	doc_384045275274_item	3686746	et	4	main
eesti	doc_384045275274_item	3686745	et	4	main
oppimiseta	doc_384045275274_item	3686728	et	4	main
peaaegu	doc_384045275274_item	3686727	et	3	main
omandatud	doc_384045275274_item	3686725	et	4	main
väga	doc_384045275274_item	3686723	et	3	main
oli	doc_384045275274_item	3686722	et	3	main
mis	doc_384045275274_item	3686721	et	4	main
koormus	doc_384045275274_item	3686720	et	4	main
ilmunud	doc_384045275274_item	3686719	et	4	main
järsult	doc_384045275274_item	3686718	et	4	main
materjalimaht	doc_384045275274_item	3686717	et	3	main
suur	doc_384045275274_item	3686716	et	3	main
raskelt	doc_384045275274_item	3686715	et	4	main
pisavalt	doc_384045275274_item	3686714	et	4	main
jaoks	doc_384045275274_item	3686713	et	4	main
minu	doc_384045275274_item	3686712	et	3	main
alanud	doc_384045275274_item	3686711	et	4	main
on	doc_384045275274_item	3686710	et	4	main
see	doc_384045275274_item	3686708	et	3	main
õppesta	doc_384045275274_item	3686709	et	4	main
ka	doc_384045275274_item	3686706	et	3	main
õppimisel	doc_384045275274_item	3686707	et	4	main
kahjuks	doc_384045275274_item	3686705	et	4	main
viia	doc_384045275274_item	3686704	et	3	main
elusse	doc_384045275274_item	3686703	et	3	main
plaani	doc_384045275274_item	3686702	et	4	main
oma	doc_384045275274_item	3686701	et	4	main
pidevalt	doc_384045275274_item	3686700	et	4	main
klappi	doc_384045275274_item	3686699	et	4	main
ei	doc_384045275274_item	3686698	et	4	main
ka	doc_384045275274_item	3686697	et	3	main
neid	doc_384045275274_item	3686691	et	4	main
töötada	doc_384045275274_item	3686682	et	3	main
aeg-ajalt	doc_384045275274_item	3686675	et	4	main
meist	doc_384045275274_item	3686674	et	3	main
loengutest	doc_384045275274_item	3686672	et	4	main
kui	doc_384045275274_item	3686668	et	3	main
tegin	doc_384045275274_item	3686667	et	3	main
mina	doc_384045275274_item	3686666	et	4	main
essee	doc_384045275274_item	3686664	et	4	main
mida	doc_384045275274_item	3686665	et	4	main
osa	doc_237983010021_item	3687134	et	4	\N
teine	doc_237983010021_item	3687133	et	3	\N
kodutöö	doc_237983010021_item	3687132	et	4	\N
saatsin	doc_237983010021_item	3687130	et	3	\N
teile	doc_237983010021_item	3687131	et	4	\N
sellega	doc_59711134406_item	3687377	et	3	main
lugema	doc_59711134406_item	3687374	et	4	main
et	doc_59711134406_item	3687369	et	3	main
mulle	doc_59711134406_item	3687358	et	4	main
aga	doc_59711134406_item	3687351	et	3	main
ei	doc_59711134406_item	3687340	et	4	main
inimesed	doc_59711134406_item	3687339	et	3	main
teha	doc_59711134406_item	3687332	et	3	main
õppima	doc_59711134406_item	3687327	et	3	main
vaja	doc_59711134406_item	3687326	et	4	main
inemesed	doc_59711134406_item	3687322	et	4	main
kõik	doc_59711134406_item	3687321	et	4	main
ma	doc_59711134406_item	3687316	et	3	main
väga	doc_59711134406_item	3687314	et	3	main
inimesed	doc_59711134406_item	3687312	et	3	main
tähtsam	doc_59711134406_item	3687298	et	4	main
inimesele	doc_59711134406_item	3687279	et	3	main
kasulik	doc_59711134406_item	3687210	et	3	main
ja	doc_59711134406_item	3687209	et	3	main
põnev	doc_59711134406_item	3687208	et	3	main
väga	doc_59711134406_item	3687207	et	3	main
ma	doc_59711134406_item	3687194	et	3	main
nad	doc_59711134406_item	3687263	et	3	main
homme	doc_59711134406_item	3687260	et	3	main
mida	doc_59711134406_item	3687258	et	4	main
ei	doc_59711134406_item	3687256	et	4	main
veel	doc_59711134406_item	3687249	et	4	main
aga	doc_59711134406_item	3687248	et	3	main
kus	doc_59711134409_item	3687542	et	3	main
ta	doc_59711134409_item	3687538	et	4	main
mis	doc_59711134409_item	3687536	et	4	main
mõtleb	doc_59711134409_item	3687531	et	3	main
kes	doc_59711134409_item	3687530	et	4	main
need	doc_59711134409_item	3687529	et	3	main
selle	doc_59711134409_item	3687528	et	4	main
eksamite	doc_59711134409_item	3687514	et	3	main
tahavad	doc_59711134406_item	3687372	et	3	main
palju	doc_59711134406_item	3687370	et	4	main
asjad	doc_59711134406_item	3687367	et	3	main
palun	doc_59711134406_item	3687364	et	3	main
on	doc_59711134406_item	3687352	et	4	main
oma	doc_59711134406_item	3687348	et	4	main
õppe	doc_59711134406_item	3687341	et	4	main
on	doc_59711134406_item	3687335	et	4	main
see	doc_59711134406_item	3687333	et	3	main
te	doc_59711134406_item	3687308	et	4	main
on	doc_59711134406_item	3687297	et	4	main
elama	doc_59711134406_item	3687295	et	3	main
kuidas	doc_59711134406_item	3687293	et	3	main
looteri	doc_59711134406_item	3687281	et	3	main
kes	doc_59711134406_item	3687280	et	4	main
on	doc_59711134406_item	3687276	et	4	main
et	doc_59711134406_item	3687204	et	3	main
olen	doc_59711134406_item	3687199	et	3	main
aastat	doc_59711134406_item	3687192	et	3	main
üheksateist	doc_59711134406_item	3687191	et	4	main
olen	doc_59711134406_item	3687190	et	3	main
ma	doc_59711134406_item	3687189	et	3	main
ametlik	doc_59711134406_item	3687159	et	3	main
neist	doc_59711134406_item	3687267	et	4	main
olevad	doc_59711134406_item	3687261	et	4	main
nad	doc_59711134406_item	3687259	et	3	main
teavad	doc_59711134406_item	3687257	et	3	main
inimesed	doc_59711134406_item	3687255	et	3	main
korras	doc_59711134406_item	3687247	et	4	main
nendel	doc_59711134406_item	3687244	et	4	main
rühmad	doc_59711134406_item	3687218	et	4	main
tahab	doc_59711134409_item	3687539	et	3	main
omade	doc_59711134409_item	3687532	et	3	main
noorte	doc_59711134409_item	3687505	et	3	main
ja	doc_59711134409_item	3687498	et	3	main
muidugi	doc_59711134409_item	3687490	et	4	main
rääkisid	doc_59711134409_item	3687472	et	4	main
tänapäevased	doc_59711134409_item	3687464	et	4	main
mõtlevad	doc_59711134409_item	3687455	et	4	main
minu	doc_59711134409_item	3687453	et	3	main
tean	doc_59711134409_item	3687450	et	3	main
mõtlevad	doc_59711134409_item	3687444	et	4	main
enamus	doc_59711134409_item	3687440	et	4	main
et	doc_59711134409_item	3687439	et	3	main
tegevust	doc_59711134409_item	3687430	et	4	main
palju	doc_59711134409_item	3687421	et	4	main
vanemad	doc_59711134409_item	3687420	et	4	main
nende	doc_59711134409_item	3687419	et	4	main
hästi	doc_59711134409_item	3687415	et	3	main
tööid	doc_59711134406_item	3687376	et	4	main
teie	doc_59711134406_item	3687375	et	4	main
edasi	doc_59711134406_item	3687365	et	3	main
kirjutage	doc_59711134406_item	3687363	et	3	main
meldis	doc_59711134406_item	3687362	et	3	main
võimalusest	doc_59711134406_item	3687350	et	4	main
halbadest	doc_59711134406_item	3687349	et	3	main
tööta	doc_59711134406_item	3687343	et	4	main
ei	doc_59711134406_item	3687342	et	4	main
nendele	doc_59711134406_item	3687334	et	4	main
aga	doc_59711134406_item	3687331	et	3	main
ennast	doc_59711134406_item	3687330	et	4	main
töötama	doc_59711134406_item	3687329	et	3	main
nõus	doc_59711134406_item	3687320	et	4	main
on	doc_59711134406_item	3687313	et	4	main
hoopis	doc_59711134406_item	3687311	et	3	main
et	doc_59711134406_item	3687310	et	3	main
kirjutasite	doc_59711134406_item	3687309	et	3	main
kui	doc_59711134406_item	3687301	et	3	main
nendele	doc_59711134406_item	3687296	et	4	main
inemisi	doc_59711134406_item	3687371	et	4	main
arvan	doc_59711134406_item	3687368	et	3	main
väga	doc_59711134406_item	3687361	et	3	main
juhtkiri	doc_59711134406_item	3687360	et	3	main
teie	doc_59711134406_item	3687359	et	4	main
ennasele	doc_59711134406_item	3687357	et	4	main
usuma	doc_59711134406_item	3687356	et	4	main
teistmodi	doc_59711134406_item	3687355	et	4	main
tehe	doc_59711134406_item	3687354	et	3	main
mõtlevad	doc_59711134406_item	3687347	et	4	main
nad	doc_59711134406_item	3687346	et	3	main
et	doc_59711134406_item	3687345	et	3	main
selleparast	doc_59711134406_item	3687344	et	3	main
ja	doc_59711134406_item	3687328	et	3	main
on	doc_59711134406_item	3687325	et	4	main
et	doc_59711134406_item	3687324	et	3	main
teavad	doc_59711134406_item	3687323	et	3	main
sellega	doc_59711134406_item	3687318	et	3	main
kodu	doc_59711134406_item	3687307	et	4	main
ja	doc_59711134406_item	3687306	et	3	main
pere	doc_59711134406_item	3687305	et	4	main
palk	doc_59711134406_item	3687304	et	3	main
mõtlevad	doc_59711134406_item	3687292	et	4	main
ülikoolis	doc_59711134406_item	3687284	et	4	main
nõus	doc_59711134406_item	3687215	et	4	main
teiega	doc_59711134406_item	3687214	et	3	main
olen	doc_59711134406_item	3687213	et	3	main
ma	doc_59711134406_item	3687212	et	3	main
tekst	doc_59711134406_item	3687211	et	3	main
on	doc_59711134406_item	3687206	et	4	main
vana	doc_59711134406_item	3687193	et	4	main
erialalas	doc_59711134406_item	3687188	et	2	main
kiri	doc_59711134406_item	3687161	et	3	main
kiri	doc_59711134406_item	3687160	et	3	main
tea	doc_59711134406_item	3687265	et	4	main
tegema	doc_59711134406_item	3687262	et	3	main
on	doc_59711134406_item	3687250	et	4	main
nad	doc_59711134406_item	3687224	et	3	main
millega	doc_59711134406_item	3687223	et	3	main
maria	doc_237983010021_item	3687158	et	4	\N
lugupidamisega	doc_237983010021_item	3687157	et	3	\N
raskused	doc_237983010021_item	3687156	et	4	\N
tekkitud	doc_237983010021_item	3687155	et	2	\N
on	doc_237983010021_item	3687154	et	4	\N
mul	doc_237983010021_item	3687153	et	3	\N
sest	doc_237983010021_item	3687152	et	4	\N
öösel	doc_237983010021_item	3687151	et	4	\N
hiljem	doc_237983010021_item	3687150	et	3	\N
teile	doc_237983010021_item	3687149	et	4	\N
saadata	doc_237983010021_item	3687148	et	2	\N
rektsioonimallidega	doc_237983010021_item	3687146	et	2	\N
lisandunud	doc_237983010021_item	3687145	et	4	\N
koos	doc_237983010021_item	3687144	et	4	\N
saan	doc_237983010021_item	3687147	et	4	\N
osa	doc_237983010021_item	3687143	et	4	\N
esimene	doc_237983010021_item	3687142	et	3	\N
õigesti	doc_237983010021_item	3687141	et	3	\N
seda	doc_237983010021_item	3687140	et	3	\N
olen	doc_237983010021_item	3687138	et	3	\N
et	doc_237983010021_item	3687137	et	3	\N
tehtud	doc_237983010021_item	3687139	et	4	\N
loodan	doc_237983010021_item	3687136	et	3	\N
osaliselt	doc_237983010021_item	3687135	et	4	\N
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_59711134406_item	3687384	et	4	main
eesnimi	doc_59711134406_item	3687383	et	3	main
lugupidamisega	doc_59711134406_item	3687382	et	3	main
kiri	doc_59711134406_item	3687381	et	3	main
oma	doc_59711134406_item	3687380	et	4	main
lõpetasin	doc_59711134406_item	3687379	et	3	main
ma	doc_59711134406_item	3687378	et	3	main
veel	doc_59711134406_item	3687373	et	4	main
niisugused	doc_59711134406_item	3687366	et	3	main
vaja	doc_59711134406_item	3687353	et	4	main
tihti	doc_59711134406_item	3687338	et	3	main
raske	doc_59711134406_item	3687337	et	4	main
väga	doc_59711134406_item	3687336	et	3	main
ka	doc_59711134406_item	3687319	et	3	main
olen	doc_59711134406_item	3687317	et	3	main
realistlikud	doc_59711134406_item	3687315	et	3	main
hea	doc_59711134406_item	3687303	et	4	main
tulevik	doc_59711134406_item	3687302	et	3	main
päev	doc_59711134406_item	3687300	et	3	main
tänane	doc_59711134406_item	3687299	et	3	main
tulevikus	doc_59711134406_item	3687294	et	4	main
ei	doc_59711134406_item	3687291	et	4	main
rühmast	doc_59711134406_item	3687290	et	4	main
sellest	doc_59711134406_item	3687289	et	4	main
inemesed	doc_59711134406_item	3687288	et	4	main
üldselt	doc_59711134406_item	3687287	et	4	main
põlvkonnadele	doc_59711134406_item	3687286	et	3	main
ja	doc_59711134406_item	3687285	et	3	main
see	doc_59711134406_item	3687205	et	3	main
jõuelektronika	doc_59711134406_item	3687187	et	4	main
ja	doc_59711134406_item	3687186	et	3	main
elektriajamite	doc_59711134406_item	3687185	et	3	main
kursusel	doc_59711134406_item	3687184	et	3	main
esimesel	doc_59711134406_item	3687183	et	3	main
tehnikaülikoolis	doc_59711134406_item	3687182	et	4	main
riigieksamite	doc_59711134406_item	3687272	et	3	main
nad	doc_59711134406_item	3687269	et	3	main
saab	doc_59711134406_item	3687268	et	3	main
rühmas	doc_59711134406_item	3687254	et	4	main
järgmises	doc_59711134406_item	3687253	et	3	main
rühmad	doc_59711134406_item	3687252	et	4	main
on	doc_59711134406_item	3687246	et	4	main
töö	doc_59711134406_item	3687243	et	4	main
uus	doc_59711134406_item	3687242	et	3	main
endale	doc_59711134406_item	3687241	et	4	main
võtavad	doc_59711134406_item	3687240	et	3	main
nad	doc_59711134406_item	3687239	et	3	main
siis	doc_59711134406_item	3687238	et	3	main
käinud	doc_59711134406_item	3687237	et	4	main
läbi	doc_59711134406_item	3687236	et	4	main
on	doc_59711134406_item	3687235	et	4	main
eesmärk	doc_59711134406_item	3687234	et	3	main
kui	doc_59711134406_item	3687233	et	3	main
lähevad	doc_59711134406_item	3687232	et	3	main
nad	doc_59711134406_item	3687231	et	3	main
kuhu	doc_59711134406_item	3687230	et	3	main
eesmärk	doc_59711134406_item	3687229	et	3	main
on	doc_59711134406_item	3687228	et	4	main
nendel	doc_59711134406_item	3687227	et	4	main
on	doc_59711134406_item	3687283	et	4	main
pärast	doc_59711134406_item	3687282	et	4	main
halvasti	doc_59711134406_item	3687278	et	3	main
väga	doc_59711134406_item	3687277	et	3	main
see	doc_59711134406_item	3687275	et	3	main
looteriga	doc_59711134406_item	3687274	et	4	main
tulemuse	doc_59711134406_item	3687273	et	3	main
on	doc_59711134406_item	3687217	et	4	main
et	doc_59711134406_item	3687216	et	3	main
arvan	doc_59711134406_item	3687203	et	3	main
lugenud	doc_59711134406_item	3687202	et	4	main
juhtkiri	doc_59711134406_item	3687201	et	3	main
teie	doc_59711134406_item	3687200	et	4	main
et	doc_59711134406_item	3687198	et	3	main
sellepärast	doc_59711134406_item	3687197	et	3	main
teile	doc_59711134406_item	3687196	et	4	main
kirjutan	doc_59711134406_item	3687195	et	3	main
tallinna	doc_59711134406_item	3687181	et	4	main
õpin	doc_59711134406_item	3687180	et	3	main
ma	doc_59711134406_item	3687179	et	3	main
lugenud	doc_59711134406_item	3687178	et	4	main
juhtkiri	doc_59711134406_item	3687177	et	3	main
teie	doc_59711134406_item	3687176	et	4	main
olen	doc_59711134406_item	3687175	et	3	main
et	doc_59711134406_item	3687174	et	3	main
sellepärast	doc_59711134406_item	3687173	et	3	main
kirjutan	doc_59711134406_item	3687171	et	3	main
teile	doc_59711134406_item	3687172	et	4	main
eesnimi	doc_59711134406_item	3687170	et	3	main
on	doc_59711134406_item	3687169	et	4	main
nimi	doc_59711134406_item	3687168	et	3	main
minu	doc_59711134406_item	3687167	et	3	main
kaalep	doc_59711134406_item	3687166	et	4	main
tiina	doc_59711134406_item	3687165	et	4	main
lp	doc_59711134406_item	3687164	et	4	main
kaalepile	doc_59711134406_item	3687163	et	4	main
tiina	doc_59711134406_item	3687162	et	4	main
õppima	doc_59711134406_item	3687271	et	3	main
tuulevad	doc_59711134406_item	3687270	et	4	main
mis	doc_59711134406_item	3687266	et	4	main
ei	doc_59711134406_item	3687264	et	4	main
teised	doc_59711134406_item	3687251	et	4	main
kõik	doc_59711134406_item	3687245	et	4	main
tegelevad	doc_59711134406_item	3687226	et	4	main
tulevikus	doc_59711134406_item	3687225	et	4	main
õppida	doc_59711134409_item	3687540	et	3	main
eriala	doc_59711134409_item	3687537	et	4	main
ta	doc_59711134409_item	3687534	et	4	main
tulimuse	doc_59711134409_item	3687533	et	4	main
näiteks	doc_59711134409_item	3687524	et	4	main
tea	doc_59711134409_item	3687512	et	4	main
rägite	doc_59711134409_item	3687503	et	2	main
teie	doc_59711134409_item	3687500	et	4	main
probleemid	doc_59711134409_item	3687497	et	3	main
on	doc_59711134409_item	3687489	et	4	main
see	doc_59711134409_item	3687488	et	3	main
on	doc_59711134409_item	3687482	et	4	main
noored	doc_59711134409_item	3687481	et	3	main
inimesed	doc_59711134409_item	3687471	et	3	main
paljud	doc_59711134409_item	3687470	et	3	main
huviallad	doc_59711134409_item	3687469	et	4	main
rääkida	doc_59711134409_item	3687462	et	3	main
teavad	doc_59711134406_item	3687222	et	3	main
täesti	doc_59711134406_item	3687221	et	4	main
ja	doc_59711134409_item	3687541	et	3	main
takkistab	doc_59711134409_item	3687507	et	4	main
te	doc_59711134409_item	3687502	et	4	main
sest	doc_59711134409_item	3687491	et	4	main
nagu	doc_59711134409_item	3687484	et	3	main
maksimalistid	doc_59711134409_item	3687483	et	3	main
muutu	doc_59711134409_item	3687477	et	4	main
inimesed	doc_59711134409_item	3687475	et	3	main
et	doc_59711134409_item	3687474	et	3	main
sellest	doc_59711134409_item	3687473	et	4	main
et	doc_59711134409_item	3687463	et	3	main
tohi	doc_59711134409_item	3687461	et	4	main
ta	doc_59711134409_item	3687459	et	4	main
ainult	doc_59711134409_item	3687445	et	4	main
samas	doc_59711134409_item	3687435	et	4	main
perspektiivne	doc_59711134409_item	3687434	et	3	main
oleks	doc_59711134409_item	3687433	et	3	main
edasi	doc_59711134409_item	3687432	et	3	main
töötama	doc_59711134409_item	3687422	et	3	main
ma	doc_59711134409_item	3687416	et	3	main
elada	doc_59711134409_item	3687414	et	3	main
ja	doc_59711134409_item	3687412	et	3	main
ei	doc_59711134409_item	3687398	et	4	main
ja	doc_59711134409_item	3687397	et	3	main
artikli	doc_59711134409_item	3687396	et	3	main
nshfhfaban	doc_708250025260_item	3687583	et	2	\N
esimesed	doc_59711134406_item	3687220	et	3	main
rahvast	doc_59711134406_item	3687219	et	4	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_59711134409_item	3687579	et	4	main
eesnimi	doc_59711134409_item	3687578	et	3	main
lugupidamisega	doc_59711134409_item	3687577	et	3	main
rohkem	doc_59711134409_item	3687576	et	4	main
väga	doc_59711134409_item	3687575	et	3	main
on	doc_59711134409_item	3687574	et	4	main
teema	doc_59711134409_item	3687573	et	4	main
see	doc_59711134409_item	3687572	et	3	main
artikel	doc_59711134409_item	3687571	et	4	main
teile	doc_59711134409_item	3687570	et	4	main
meeldib	doc_59711134409_item	3687569	et	3	main
mulle	doc_59711134409_item	3687568	et	4	main
probleem	doc_59711134409_item	3687567	et	3	main
suur	doc_59711134409_item	3687566	et	3	main
on	doc_59711134409_item	3687565	et	4	main
see	doc_59711134409_item	3687564	et	3	main
õppida	doc_59711134409_item	3687563	et	3	main
võiksid	doc_59711134409_item	3687562	et	4	main
nad	doc_59711134409_item	3687561	et	3	main
kus	doc_59711134409_item	3687560	et	3	main
kohad	doc_59711134409_item	3687559	et	4	main
teised	doc_59711134409_item	3687558	et	4	main
ja	doc_59711134409_item	3687557	et	3	main
ülikoolised	doc_59711134409_item	3687556	et	2	main
hsrgfhequrhjbkvfearguerhfqrjhyqtqiuf	doc_541159270916_item	3687581	et	2	\N
es	doc_708250025260_item	3687582	et	4	\N
teab	doc_59711134409_item	3687535	et	3	main
saavutasid	doc_59711134409_item	3687527	et	4	main
õppima	doc_59711134409_item	3687526	et	3	main
meditsiini	doc_59711134409_item	3687525	et	4	main
saada	doc_59711134409_item	3687523	et	4	main
kuhu	doc_59711134409_item	3687522	et	3	main
siht	doc_59711134409_item	3687521	et	3	main
oli	doc_59711134409_item	3687520	et	3	main
kellel	doc_59711134409_item	3687519	et	4	main
õpilased	doc_59711134409_item	3687518	et	3	main
need	doc_59711134409_item	3687517	et	3	main
see	doc_59711134409_item	3687516	et	3	main
tulemusi	doc_59711134409_item	3687515	et	4	main
ei	doc_59711134409_item	3687511	et	4	main
nad	doc_59711134409_item	3687510	et	3	main
et	doc_59711134409_item	3687509	et	3	main
see	doc_59711134409_item	3687508	et	3	main
ajal	doc_59711134409_item	3687494	et	4	main
igal	doc_59711134409_item	3687493	et	3	main
et	doc_59711134409_item	3687492	et	3	main
vanemad	doc_59711134409_item	3687486	et	4	main
nende	doc_59711134409_item	3687485	et	4	main
tänapäevased	doc_59711134409_item	3687480	et	4	main
et	doc_59711134409_item	3687479	et	3	main
teistest	doc_59711134409_item	3687468	et	4	main
printsiibid	doc_59711134409_item	3687458	et	3	main
huvid	doc_59711134409_item	3687457	et	3	main
omad	doc_59711134409_item	3687456	et	4	main
et	doc_59711134409_item	3687451	et	3	main
abiturientidest	doc_59711134409_item	3687441	et	3	main
teised	doc_59711134409_item	3687429	et	4	main
arvan	doc_59711134409_item	3687417	et	3	main
taha	doc_59711134409_item	3687410	et	4	main
ülikooli	doc_59711134409_item	3687407	et	4	main
et	doc_59711134409_item	3687405	et	3	main
te	doc_59711134409_item	3687403	et	4	main
omade	doc_59711134409_item	3687513	et	3	main
valikut	doc_59711134409_item	3687506	et	3	main
et	doc_59711134409_item	3687504	et	3	main
artiklis	doc_59711134409_item	3687501	et	3	main
teine	doc_59711134409_item	3687499	et	3	main
omad	doc_59711134409_item	3687496	et	4	main
on	doc_59711134409_item	3687495	et	4	main
olid	doc_59711134409_item	3687487	et	4	main
tähendab	doc_59711134409_item	3687478	et	3	main
ei	doc_59711134409_item	3687476	et	4	main
erinevad	doc_59711134409_item	3687467	et	4	main
kuidagi	doc_59711134409_item	3687466	et	3	main
noored	doc_59711134409_item	3687465	et	3	main
ei	doc_59711134409_item	3687460	et	4	main
kõik	doc_59711134409_item	3687452	et	4	main
mina	doc_59711134409_item	3687449	et	4	main
nagu	doc_59711134409_item	3687448	et	3	main
palgast	doc_59711134409_item	3687447	et	4	main
eriala	doc_59711134409_item	3687443	et	4	main
valides	doc_59711134409_item	3687442	et	3	main
öelda	doc_59711134409_item	3687438	et	4	main
või	doc_59711134409_item	3687437	et	4	main
mis	doc_59711134409_item	3687431	et	4	main
stimuleerib	doc_59711134409_item	3687425	et	3	main
see	doc_59711134409_item	3687424	et	3	main
ja	doc_59711134409_item	3687423	et	3	main
ei	doc_59711134409_item	3687409	et	4	main
õpilased	doc_59711134409_item	3687408	et	3	main
praegu	doc_59711134409_item	3687406	et	3	main
sõbrad	doc_59711134409_item	3687454	et	3	main
tulevast	doc_59711134409_item	3687446	et	4	main
ei	doc_59711134409_item	3687436	et	4	main
otsivad	doc_59711134409_item	3687428	et	4	main
inimesed	doc_59711134409_item	3687427	et	3	main
noored	doc_59711134409_item	3687426	et	3	main
et	doc_59711134409_item	3687418	et	3	main
ole	doc_59711134409_item	3687399	et	4	main
teie	doc_59711134409_item	3687395	et	4	main
lugesin	doc_59711134409_item	3687394	et	3	main
eesnimi	doc_59711134409_item	3687393	et	3	main
lugeja	doc_59711134409_item	3687392	et	4	main
teile	doc_59711134409_item	3687391	et	4	main
kirjutab	doc_59711134409_item	3687390	et	3	main
kaalep	doc_59711134409_item	3687389	et	4	main
tiina	doc_59711134409_item	3687388	et	4	main
kiri	doc_59711134409_item	3687386	et	3	main
ametlik	doc_59711134409_item	3687385	et	3	main
lugupeetud	doc_59711134409_item	3687387	et	4	main
infot	doc_59711134409_item	3687555	et	3	main
vahe	doc_59711134409_item	3687554	et	4	main
teavad	doc_59711134409_item	3687553	et	3	main
üliõpilased	doc_59711134409_item	3687552	et	3	main
et	doc_59711134409_item	3687551	et	3	main
sellega	doc_59711134409_item	3687550	et	3	main
nõus	doc_59711134409_item	3687549	et	4	main
olen	doc_59711134409_item	3687548	et	3	main
ma	doc_59711134409_item	3687547	et	3	main
samas	doc_59711134409_item	3687546	et	4	main
õppida	doc_59711134409_item	3687545	et	3	main
tahab	doc_59711134409_item	3687544	et	3	main
ta	doc_59711134409_item	3687543	et	4	main
soovivad	doc_59711134409_item	3687413	et	4	main
töötada	doc_59711134409_item	3687411	et	3	main
kirjutate	doc_59711134409_item	3687404	et	3	main
esimene	doc_59711134409_item	3687402	et	3	main
teiega	doc_59711134409_item	3687401	et	3	main
nõus	doc_59711134409_item	3687400	et	4	main
essee	doc_399014257215_item	3689578	et	0	main
minu	doc_399014257215_item	3689579	et	0	main
pere	doc_399014257215_item	3689580	et	0	main
mul	doc_399014257215_item	3689581	et	0	main
on	doc_399014257215_item	3689582	et	0	main
vaike	doc_399014257215_item	3689583	et	0	main
pere	doc_399014257215_item	3689584	et	0	main
minu	doc_399014257215_item	3689585	et	0	main
pere	doc_399014257215_item	3689586	et	0	main
elab	doc_399014257215_item	3689587	et	0	main
inglismaal	doc_399014257215_item	3689588	et	0	main
aga	doc_399014257215_item	3689589	et	0	main
ma	doc_399014257215_item	3689590	et	0	main
elan	doc_399014257215_item	3689591	et	0	main
šotimaal	doc_399014257215_item	3689592	et	0	main
mul	doc_399014257215_item	3689593	et	0	main
on	doc_399014257215_item	3689594	et	0	main
oma	doc_399014257215_item	3689595	et	0	main
korter	doc_399014257215_item	3689596	et	0	main
ma	doc_399014257215_item	3689597	et	0	main
olen	doc_399014257215_item	3689598	et	0	main
vallaline	doc_399014257215_item	3689599	et	0	main
ja	doc_399014257215_item	3689600	et	0	main
olen	doc_399014257215_item	3689601	et	0	main
kakskümmend	doc_399014257215_item	3689602	et	0	main
kolm	doc_399014257215_item	3689603	et	0	main
aastat	doc_399014257215_item	3689604	et	0	main
vana	doc_399014257215_item	3689605	et	0	main
mul	doc_399014257215_item	3689606	et	0	main
on	doc_399014257215_item	3689607	et	0	main
üks	doc_399014257215_item	3689608	et	0	main
õde	doc_399014257215_item	3689609	et	0	main
teie	doc_399014257215_item	3689610	et	0	main
nimi	doc_399014257215_item	3689611	et	0	main
on	doc_399014257215_item	3689612	et	0	main
eesnimi	doc_399014257215_item	3689613	et	0	main
eesnimi	doc_399014257215_item	3689614	et	0	main
on	doc_399014257215_item	3689615	et	0	main
kakskümmend	doc_399014257215_item	3689616	et	0	main
üheksa	doc_399014257215_item	3689617	et	0	main
ja	doc_399014257215_item	3689618	et	0	main
ta	doc_399014257215_item	3689619	et	0	main
on	doc_399014257215_item	3689620	et	0	main
abielus	doc_399014257215_item	3689621	et	0	main
eesnimi	doc_399014257215_item	3689622	et	0	main
eesnimi	doc_399014257215_item	3689623	et	0	main
on	doc_399014257215_item	3689624	et	0	main
rase	doc_399014257215_item	3689625	et	0	main
ja	doc_399014257215_item	3689626	et	0	main
tingitud	doc_399014257215_item	3689627	et	0	main
sünnitama	doc_399014257215_item	3689628	et	0	main
üks	doc_399014257215_item	3689629	et	0	main
poiss	doc_399014257215_item	3689630	et	0	main
jaanuar	doc_399014257215_item	3689631	et	0	main
eesnimi	doc_399014257215_item	3689632	et	0	main
töötab	doc_399014257215_item	3689633	et	0	main
bbc	doc_399014257215_item	3689634	et	0	main
ta	doc_399014257215_item	3689635	et	0	main
on	doc_399014257215_item	3689636	et	0	main
fotoreporter	doc_399014257215_item	3689637	et	0	main
kinooperaator	doc_399014257215_item	3689638	et	0	main
minu	doc_399014257215_item	3689639	et	0	main
isa	doc_399014257215_item	3689640	et	0	main
nimi	doc_399014257215_item	3689641	et	0	main
on	doc_399014257215_item	3689642	et	0	main
eesnimi	doc_399014257215_item	3689643	et	0	main
ja	doc_399014257215_item	3689644	et	0	main
ta	doc_399014257215_item	3689645	et	0	main
on	doc_399014257215_item	3689646	et	0	main
viiskümmend	doc_399014257215_item	3689647	et	0	main
üheksa	doc_399014257215_item	3689648	et	0	main
vana	doc_399014257215_item	3689649	et	0	main
sõber	doc_399014257215_item	3689650	et	0	main
ta	doc_399014257215_item	3689651	et	0	main
on	doc_399014257215_item	3689652	et	0	main
pensionil	doc_399014257215_item	3689653	et	0	main
õpetaja	doc_399014257215_item	3689654	et	0	main
talle	doc_399014257215_item	3689655	et	0	main
meeldib	doc_399014257215_item	3689656	et	0	main
jalgpall	doc_399014257215_item	3689657	et	0	main
glasgow	doc_399014257215_item	3689658	et	0	main
celtic	doc_399014257215_item	3689659	et	0	main
toetama	doc_399014257215_item	3689660	et	0	main
minu	doc_399014257215_item	3689661	et	0	main
ema	doc_399014257215_item	3689662	et	0	main
nimi	doc_399014257215_item	3689663	et	0	main
on	doc_399014257215_item	3689664	et	0	main
eesnimi	doc_399014257215_item	3689665	et	0	main
ja	doc_399014257215_item	3689666	et	0	main
ta	doc_399014257215_item	3689667	et	0	main
on	doc_399014257215_item	3689668	et	0	main
viiskümmend	doc_399014257215_item	3689669	et	0	main
kuus	doc_399014257215_item	3689670	et	0	main
aastat	doc_399014257215_item	3689671	et	0	main
vana	doc_399014257215_item	3689672	et	0	main
ta	doc_399014257215_item	3689673	et	0	main
on	doc_399014257215_item	3689674	et	0	main
koolijuhataja	doc_399014257215_item	3689675	et	0	main
päsis	doc_399014257215_item	3689676	et	0	main
raske	doc_399014257215_item	3689677	et	0	main
töö	doc_399014257215_item	3689678	et	0	main
või	doc_399014257215_item	3689679	et	0	main
ülesanne	doc_399014257215_item	3689680	et	0	main
tema	doc_399014257215_item	3689681	et	0	main
on	doc_399014257215_item	3689682	et	0	main
väga	doc_399014257215_item	3689683	et	0	main
armas	doc_399014257215_item	3689684	et	0	main
tema	doc_399014257215_item	3689685	et	0	main
armistad	doc_399014257215_item	3689686	et	0	main
eestimaad	doc_399014257215_item	3689687	et	0	main
minu	doc_399014257215_item	3689688	et	0	main
vanavanemad	doc_399014257215_item	3689689	et	0	main
igalt	doc_399014257215_item	3689690	et	0	main
poolt	doc_399014257215_item	3689691	et	0	main
on	doc_399014257215_item	3689692	et	0	main
surnud	doc_399014257215_item	3689693	et	0	main
kurb	doc_399014257215_item	3689694	et	0	main
aga	doc_399014257215_item	3689695	et	0	main
reaalsus	doc_399014257215_item	3689696	et	0	main
see	doc_399014257215_item	3689697	et	0	main
on	doc_399014257215_item	3689698	et	0	main
elu	doc_399014257215_item	3689699	et	0	main
minu	doc_399014257215_item	3689700	et	0	main
tädi	doc_399014257215_item	3689701	et	0	main
on	doc_399014257215_item	3689702	et	0	main
surnud	doc_399014257215_item	3689703	et	0	main
ta	doc_399014257215_item	3689704	et	0	main
suri	doc_399014257215_item	3689705	et	0	main
üheksakümnendatel	doc_399014257215_item	3689706	et	0	main
aastatel	doc_399014257215_item	3689707	et	0	main
kopsuvähktõbi	doc_399014257215_item	3689708	et	0	main
tema	doc_399014257215_item	3689709	et	0	main
oli	doc_399014257215_item	3689710	et	0	main
inspiratsioon	doc_399014257215_item	3689711	et	0	main
me	doc_399014257215_item	3689712	et	0	main
tunneme	doc_399014257215_item	3689713	et	0	main
tema	doc_399014257215_item	3689714	et	0	main
järele	doc_399014257215_item	3689715	et	0	main
suurt	doc_399014257215_item	3689716	et	0	main
puudust	doc_399014257215_item	3689717	et	0	main
mul	doc_399014257215_item	3689718	et	0	main
on	doc_399014257215_item	3689719	et	0	main
kolm	doc_399014257215_item	3689720	et	0	main
onu	doc_399014257215_item	3689721	et	0	main
eesnimi	doc_399014257215_item	3689722	et	0	main
eesnimi	doc_399014257215_item	3689723	et	0	main
ja	doc_399014257215_item	3689724	et	0	main
eesnimi	doc_399014257215_item	3689725	et	0	main
eesnimi	doc_399014257215_item	3689726	et	0	main
elab	doc_399014257215_item	3689727	et	0	main
glasgows	doc_399014257215_item	3689728	et	0	main
eesnimi	doc_399014257215_item	3689729	et	0	main
elab	doc_399014257215_item	3689730	et	0	main
belfastis	doc_399014257215_item	3689731	et	0	main
ning	doc_399014257215_item	3689732	et	0	main
eesnimi	doc_399014257215_item	3689733	et	0	main
elab	doc_399014257215_item	3689734	et	0	main
iraag	doc_399014257215_item	3689735	et	0	main
mul	doc_399014257215_item	3689736	et	0	main
on	doc_399014257215_item	3689737	et	0	main
üks	doc_399014257215_item	3689738	et	0	main
imelik	doc_399014257215_item	3689739	et	0	main
kass	doc_399014257215_item	3689740	et	0	main
ta	doc_399014257215_item	3689741	et	0	main
nimi	doc_399014257215_item	3689742	et	0	main
on	doc_399014257215_item	3689743	et	0	main
nimi	doc_399014257215_item	3689744	et	0	main
tema	doc_399014257215_item	3689745	et	0	main
on	doc_399014257215_item	3689746	et	0	main
umbes	doc_399014257215_item	3689747	et	0	main
kumme	doc_399014257215_item	3689748	et	0	main
astat	doc_399014257215_item	3689749	et	0	main
vana	doc_399014257215_item	3689750	et	0	main
nimi	doc_399014257215_item	3689751	et	0	main
elab	doc_399014257215_item	3689752	et	0	main
emaga	doc_399014257215_item	3689753	et	0	main
ja	doc_399014257215_item	3689754	et	0	main
isaga	doc_399014257215_item	3689755	et	0	main
nimi	doc_399014257215_item	3689756	et	0	main
on	doc_399014257215_item	3689757	et	0	main
minu	doc_399014257215_item	3689758	et	0	main
lemmik	doc_399014257215_item	3689759	et	0	main
mul	doc_399014257215_item	3689760	et	0	main
ei	doc_399014257215_item	3689761	et	0	main
ole	doc_399014257215_item	3689762	et	0	main
lemmikloom	doc_399014257215_item	3689763	et	0	main
glasgows	doc_399014257215_item	3689764	et	0	main
minu	doc_399014257215_item	3689765	et	0	main
hamster	doc_399014257215_item	3689766	et	0	main
suri	doc_399014257215_item	3689767	et	0	main
möödunud	doc_399014257215_item	3689768	et	0	main
aastal	doc_399014257215_item	3689769	et	0	main
nimi	doc_399014257215_item	3689770	et	0	main
tema	doc_399014257215_item	3689771	et	0	main
nimi	doc_399014257215_item	3689772	et	0	main
essee	doc_120968879154_item	3689773	et	0	main
kus	doc_120968879154_item	3689774	et	0	main
ma	doc_120968879154_item	3689775	et	0	main
olen	doc_120968879154_item	3689776	et	0	main
käinud	doc_120968879154_item	3689777	et	0	main
mida	doc_120968879154_item	3689778	et	0	main
olen	doc_120968879154_item	3689779	et	0	main
nainud	doc_120968879154_item	3689780	et	0	main
mõõdunud	doc_120968879154_item	3689781	et	0	main
suve	doc_120968879154_item	3689782	et	0	main
ma	doc_120968879154_item	3689783	et	0	main
olin	doc_120968879154_item	3689784	et	0	main
sankt	doc_120968879154_item	3689785	et	0	main
peterburis	doc_120968879154_item	3689786	et	0	main
seal	doc_120968879154_item	3689787	et	0	main
ma	doc_120968879154_item	3689788	et	0	main
kohtusin	doc_120968879154_item	3689789	et	0	main
oma	doc_120968879154_item	3689790	et	0	main
sõbra	doc_120968879154_item	3689791	et	0	main
see	doc_120968879154_item	3689792	et	0	main
on	doc_120968879154_item	3689793	et	0	main
väga	doc_120968879154_item	3689794	et	0	main
hea	doc_120968879154_item	3689795	et	0	main
sõber	doc_120968879154_item	3689796	et	0	main
tema	doc_120968879154_item	3689797	et	0	main
nimi	doc_120968879154_item	3689798	et	0	main
on	doc_120968879154_item	3689799	et	0	main
eesnimi	doc_120968879154_item	3689800	et	0	main
ta	doc_120968879154_item	3689801	et	0	main
elab	doc_120968879154_item	3689802	et	0	main
sankt	doc_120968879154_item	3689803	et	0	main
peterburis	doc_120968879154_item	3689804	et	0	main
ta	doc_120968879154_item	3689805	et	0	main
on	doc_120968879154_item	3689806	et	0	main
minust	doc_120968879154_item	3689807	et	0	main
aastat	doc_120968879154_item	3689808	et	0	main
vanem	doc_120968879154_item	3689809	et	0	main
ta	doc_120968879154_item	3689810	et	0	main
elab	doc_120968879154_item	3689811	et	0	main
kesklinnas	doc_120968879154_item	3689812	et	0	main
ja	doc_120968879154_item	3689813	et	0	main
seal	doc_120968879154_item	3689814	et	0	main
on	doc_120968879154_item	3689815	et	0	main
palju	doc_120968879154_item	3689816	et	0	main
kool	doc_120968879154_item	3689817	et	0	main
lasteaia	doc_120968879154_item	3689818	et	0	main
spordiklubisid	doc_120968879154_item	3689819	et	0	main
ja	doc_120968879154_item	3689820	et	0	main
muuseumid	doc_120968879154_item	3689821	et	0	main
selles	doc_120968879154_item	3689822	et	0	main
rajoonis	doc_120968879154_item	3689823	et	0	main
asub	doc_120968879154_item	3689824	et	0	main
väga	doc_120968879154_item	3689825	et	0	main
palju	doc_120968879154_item	3689826	et	0	main
kinnosid	doc_120968879154_item	3689827	et	0	main
ja	doc_120968879154_item	3689828	et	0	main
raamatukogud	doc_120968879154_item	3689829	et	0	main
me	doc_120968879154_item	3689830	et	0	main
oleme	doc_120968879154_item	3689831	et	0	main
käinud	doc_120968879154_item	3689832	et	0	main
ermitaažile	doc_120968879154_item	3689833	et	0	main
oli	doc_120968879154_item	3689834	et	0	main
väga	doc_120968879154_item	3689835	et	0	main
huvitav	doc_120968879154_item	3689836	et	0	main
sellepärast	doc_120968879154_item	3689837	et	0	main
ma	doc_120968879154_item	3689838	et	0	main
ei	doc_120968879154_item	3689839	et	0	main
näinud	doc_120968879154_item	3689840	et	0	main
nii	doc_120968879154_item	3689841	et	0	main
palju	doc_120968879154_item	3689842	et	0	main
pildid	doc_120968879154_item	3689843	et	0	main
eestis	doc_120968879154_item	3689844	et	0	main
ka	doc_120968879154_item	3689845	et	0	main
me	doc_120968879154_item	3689846	et	0	main
vaatasime	doc_120968879154_item	3689847	et	0	main
sõja	doc_120968879154_item	3689848	et	0	main
laevad	doc_120968879154_item	3689849	et	0	main
need	doc_120968879154_item	3689850	et	0	main
on	doc_120968879154_item	3689851	et	0	main
väga	doc_120968879154_item	3689852	et	0	main
pikk	doc_120968879154_item	3689853	et	0	main
ja	doc_120968879154_item	3689854	et	0	main
suur	doc_120968879154_item	3689855	et	0	main
olime	doc_120968879154_item	3689856	et	0	main
delfinariesil	doc_120968879154_item	3689857	et	0	main
nimi	doc_120968879154_item	3689858	et	0	main
nimi	doc_120968879154_item	3689859	et	0	main
ja	doc_120968879154_item	3689860	et	0	main
nimi	doc_120968879154_item	3689861	et	0	main
teegisid	doc_120968879154_item	3689862	et	0	main
huvitavaid	doc_120968879154_item	3689863	et	0	main
трюки	doc_120968879154_item	3689864	et	0	main
ma	doc_120968879154_item	3689865	et	0	main
ei	doc_120968879154_item	3689866	et	0	main
nainud	doc_120968879154_item	3689867	et	0	main
ilusaid	doc_120968879154_item	3689868	et	0	main
fontaanid	doc_120968879154_item	3689869	et	0	main
selle	doc_120968879154_item	3689870	et	0	main
pärast	doc_120968879154_item	3689871	et	0	main
et	doc_120968879154_item	3689872	et	0	main
nad	doc_120968879154_item	3689873	et	0	main
olin	doc_120968879154_item	3689874	et	0	main
remondiks	doc_120968879154_item	3689875	et	0	main
sankt	doc_120968879154_item	3689876	et	0	main
peeterburis	doc_120968879154_item	3689877	et	0	main
ma	doc_120968879154_item	3689878	et	0	main
ostsin	doc_120968879154_item	3689879	et	0	main
palju	doc_120968879154_item	3689880	et	0	main
dvd	doc_120968879154_item	3689881	et	0	main
filmid	doc_120968879154_item	3689882	et	0	main
uus	doc_120968879154_item	3689883	et	0	main
mp3	doc_120968879154_item	3689884	et	0	main
mängija	doc_120968879154_item	3689885	et	0	main
suvenirid	doc_120968879154_item	3689886	et	0	main
õlu	doc_120968879154_item	3689887	et	0	main
vodka	doc_120968879154_item	3689888	et	0	main
ja	doc_120968879154_item	3689889	et	0	main
palju	doc_120968879154_item	3689890	et	0	main
palju	doc_120968879154_item	3689891	et	0	main
palju	doc_120968879154_item	3689892	et	0	main
ma	doc_120968879154_item	3689893	et	0	main
olin	doc_120968879154_item	3689894	et	0	main
seal	doc_120968879154_item	3689895	et	0	main
4	doc_120968879154_item	3689896	et	0	main
päevad	doc_120968879154_item	3689897	et	0	main
ja	doc_120968879154_item	3689898	et	0	main
sõidu	doc_120968879154_item	3689899	et	0	main
tagasi	doc_120968879154_item	3689900	et	0	main
eestil	doc_120968879154_item	3689901	et	0	main
bussiga	doc_120968879154_item	3689902	et	0	main
aga	doc_120968879154_item	3689903	et	0	main
ma	doc_120968879154_item	3689904	et	0	main
ei	doc_120968879154_item	3689905	et	0	main
tahtnud	doc_120968879154_item	3689906	et	0	main
sõida	doc_120968879154_item	3689907	et	0	main
tagasi	doc_120968879154_item	3689908	et	0	main
nüüd	doc_120968879154_item	3689909	et	0	main
ma	doc_120968879154_item	3689910	et	0	main
võin	doc_120968879154_item	3689911	et	0	main
sõidan	doc_120968879154_item	3689912	et	0	main
oma	doc_120968879154_item	3689913	et	0	main
autos	doc_120968879154_item	3689914	et	0	main
moskvasse	doc_120968879154_item	3689915	et	0	main
seal	doc_120968879154_item	3689916	et	0	main
on	doc_120968879154_item	3689917	et	0	main
ka	doc_120968879154_item	3689918	et	0	main
minu	doc_120968879154_item	3689919	et	0	main
sõbrad	doc_120968879154_item	3689920	et	0	main
ja	doc_120968879154_item	3689921	et	0	main
naad	doc_120968879154_item	3689922	et	0	main
ottavad	doc_120968879154_item	3689923	et	0	main
mind	doc_120968879154_item	3689924	et	0	main
essee	doc_120968879156_item	3689925	et	0	main
kus	doc_120968879156_item	3689926	et	0	main
olen	doc_120968879156_item	3689927	et	0	main
käinud	doc_120968879156_item	3689928	et	0	main
ja	doc_120968879156_item	3689929	et	0	main
mida	doc_120968879156_item	3689930	et	0	main
olen	doc_120968879156_item	3689931	et	0	main
näinud	doc_120968879156_item	3689932	et	0	main
kolmekümnendal	doc_120968879156_item	3689933	et	0	main
septembril	doc_120968879156_item	3689934	et	0	main
tallinnas	doc_120968879156_item	3689935	et	0	main
lauluväljakul	doc_120968879156_item	3689936	et	0	main
oli	doc_120968879156_item	3689937	et	0	main
kassinäitus	doc_120968879156_item	3689938	et	0	main
sest	doc_120968879156_item	3689939	et	0	main
et	doc_120968879156_item	3689940	et	0	main
kassid	doc_120968879156_item	3689941	et	0	main
on	doc_120968879156_item	3689942	et	0	main
minu	doc_120968879156_item	3689943	et	0	main
lemmik	doc_120968879156_item	3689944	et	0	main
loomad	doc_120968879156_item	3689945	et	0	main
ma	doc_120968879156_item	3689946	et	0	main
olen	doc_120968879156_item	3689947	et	0	main
käinud	doc_120968879156_item	3689948	et	0	main
sinna	doc_120968879156_item	3689949	et	0	main
see	doc_120968879156_item	3689950	et	0	main
oli	doc_120968879156_item	3689951	et	0	main
väga	doc_120968879156_item	3689952	et	0	main
huvitav	doc_120968879156_item	3689953	et	0	main
üritust	doc_120968879156_item	3689954	et	0	main
sest	doc_120968879156_item	3689955	et	0	main
et	doc_120968879156_item	3689956	et	0	main
piletid	doc_120968879156_item	3689957	et	0	main
ei	doc_120968879156_item	3689958	et	0	main
olnud	doc_120968879156_item	3689959	et	0	main
väga	doc_120968879156_item	3689960	et	0	main
kallid	doc_120968879156_item	3689961	et	0	main
seal	doc_120968879156_item	3689962	et	0	main
olid	doc_120968879156_item	3689963	et	0	main
palju	doc_120968879156_item	3689964	et	0	main
külastajaid	doc_120968879156_item	3689965	et	0	main
kellele	doc_120968879156_item	3689966	et	0	main
ka	doc_120968879156_item	3689967	et	0	main
meeldivad	doc_120968879156_item	3689968	et	0	main
kassid	doc_120968879156_item	3689969	et	0	main
lapsed	doc_120968879156_item	3689970	et	0	main
täiskasvanud	doc_120968879156_item	3689971	et	0	main
ja	doc_120968879156_item	3689972	et	0	main
vanad	doc_120968879156_item	3689973	et	0	main
inimesed	doc_120968879156_item	3689974	et	0	main
näituses	doc_120968879156_item	3689975	et	0	main
oli	doc_120968879156_item	3689976	et	0	main
esindanud	doc_120968879156_item	3689977	et	0	main
palju	doc_120968879156_item	3689978	et	0	main
erinevaid	doc_120968879156_item	3689979	et	0	main
kassitõuguid	doc_120968879156_item	3689980	et	0	main
kassid	doc_120968879156_item	3689981	et	0	main
olid	doc_120968879156_item	3689982	et	0	main
igasuguseid	doc_120968879156_item	3689983	et	0	main
väikesed	doc_120968879156_item	3689984	et	0	main
ja	doc_120968879156_item	3689985	et	0	main
suured	doc_120968879156_item	3689986	et	0	main
pehmed	doc_120968879156_item	3689987	et	0	main
ja	doc_120968879156_item	3689988	et	0	main
paljapeased	doc_120968879156_item	3689989	et	0	main
mänglevad	doc_120968879156_item	3689990	et	0	main
ja	doc_120968879156_item	3689991	et	0	main
unised	doc_120968879156_item	3689992	et	0	main
kui	doc_120968879156_item	3689993	et	0	main
inimestele	doc_120968879156_item	3689994	et	0	main
meeldis	doc_120968879156_item	3689995	et	0	main
kassi	doc_120968879156_item	3689996	et	0	main
siis	doc_120968879156_item	3689997	et	0	main
seal	doc_120968879156_item	3689998	et	0	main
oli	doc_120968879156_item	3689999	et	0	main
võimalus	doc_120968879156_item	3690000	et	0	main
osta	doc_120968879156_item	3690001	et	0	main
kassipoega	doc_120968879156_item	3690002	et	0	main
ma	doc_120968879156_item	3690003	et	0	main
nägin	doc_120968879156_item	3690004	et	0	main
seal	doc_120968879156_item	3690005	et	0	main
ühe	doc_120968879156_item	3690006	et	0	main
ilusa	doc_120968879156_item	3690007	et	0	main
kassipoega	doc_120968879156_item	3690008	et	0	main
ta	doc_120968879156_item	3690009	et	0	main
oli	doc_120968879156_item	3690010	et	0	main
valge	doc_120968879156_item	3690011	et	0	main
sinise	doc_120968879156_item	3690012	et	0	main
silmadega	doc_120968879156_item	3690013	et	0	main
tema	doc_120968879156_item	3690014	et	0	main
tõug	doc_120968879156_item	3690015	et	0	main
on	doc_120968879156_item	3690016	et	0	main
nevskaja	doc_120968879156_item	3690017	et	0	main
maskaradnaja	doc_120968879156_item	3690018	et	0	main
ma	doc_120968879156_item	3690019	et	0	main
otsustasin	doc_120968879156_item	3690020	et	0	main
osta	doc_120968879156_item	3690021	et	0	main
seda	doc_120968879156_item	3690022	et	0	main
kassi	doc_120968879156_item	3690023	et	0	main
nüüd	doc_120968879156_item	3690024	et	0	main
minu	doc_120968879156_item	3690025	et	0	main
korteris	doc_120968879156_item	3690026	et	0	main
elab	doc_120968879156_item	3690027	et	0	main
väike	doc_120968879156_item	3690028	et	0	main
ime	doc_120968879156_item	3690029	et	0	main
tema	doc_120968879156_item	3690030	et	0	main
nimi	doc_120968879156_item	3690031	et	0	main
on	doc_120968879156_item	3690032	et	0	main
nimi	doc_120968879156_item	3690033	et	0	main
essee	doc_399014257212_item	3690034	et	0	main
minu	doc_399014257212_item	3690035	et	0	main
tuba	doc_399014257212_item	3690036	et	0	main
minu	doc_399014257212_item	3690037	et	0	main
tuba	doc_399014257212_item	3690038	et	0	main
on	doc_399014257212_item	3690039	et	0	main
väike	doc_399014257212_item	3690040	et	0	main
minu	doc_399014257212_item	3690041	et	0	main
korter	doc_399014257212_item	3690042	et	0	main
on	doc_399014257212_item	3690043	et	0	main
väga	doc_399014257212_item	3690044	et	0	main
uus	doc_399014257212_item	3690045	et	0	main
üks	doc_399014257212_item	3690046	et	0	main
aastat	doc_399014257212_item	3690047	et	0	main
vana	doc_399014257212_item	3690048	et	0	main
ma	doc_399014257212_item	3690049	et	0	main
voodi	doc_399014257212_item	3690050	et	0	main
on	doc_399014257212_item	3690051	et	0	main
kesk	doc_399014257212_item	3690052	et	0	main
tuba	doc_399014257212_item	3690053	et	0	main
ma	doc_399014257212_item	3690054	et	0	main
armistan	doc_399014257212_item	3690055	et	0	main
voodi	doc_399014257212_item	3690056	et	0	main
televiisor	doc_399014257212_item	3690057	et	0	main
on	doc_399014257212_item	3690058	et	0	main
laua	doc_399014257212_item	3690059	et	0	main
peal	doc_399014257212_item	3690060	et	0	main
minu	doc_399014257212_item	3690061	et	0	main
tuba	doc_399014257212_item	3690062	et	0	main
on	doc_399014257212_item	3690063	et	0	main
sisseehitatud	doc_399014257212_item	3690064	et	0	main
kappi	doc_399014257212_item	3690065	et	0	main
pilt	doc_399014257212_item	3690066	et	0	main
celine	doc_399014257212_item	3690067	et	0	main
dion	doc_399014257212_item	3690068	et	0	main
on	doc_399014257212_item	3690069	et	0	main
seina	doc_399014257212_item	3690070	et	0	main
peal	doc_399014257212_item	3690071	et	0	main
padi	doc_399014257212_item	3690072	et	0	main
on	doc_399014257212_item	3690073	et	0	main
voodi	doc_399014257212_item	3690074	et	0	main
peal	doc_399014257212_item	3690075	et	0	main
sinine	doc_399014257212_item	3690076	et	0	main
eelm	doc_399014257212_item	3690077	et	0	main
öökapp	doc_399014257212_item	3690078	et	0	main
on	doc_399014257212_item	3690079	et	0	main
voodi	doc_399014257212_item	3690080	et	0	main
kõrval	doc_399014257212_item	3690081	et	0	main
põrand	doc_399014257212_item	3690082	et	0	main
on	doc_399014257212_item	3690083	et	0	main
beež	doc_399014257212_item	3690084	et	0	main
vaip	doc_399014257212_item	3690085	et	0	main
peal	doc_399014257212_item	3690086	et	0	main
ma	doc_399014257212_item	3690087	et	0	main
köögi	doc_399014257212_item	3690088	et	0	main
on	doc_399014257212_item	3690089	et	0	main
väga	doc_399014257212_item	3690090	et	0	main
vaike	doc_399014257212_item	3690091	et	0	main
aga	doc_399014257212_item	3690092	et	0	main
väga	doc_399014257212_item	3690093	et	0	main
stiilne	doc_399014257212_item	3690094	et	0	main
pesumasin	doc_399014257212_item	3690095	et	0	main
on	doc_399014257212_item	3690096	et	0	main
tööpind	doc_399014257212_item	3690097	et	0	main
all	doc_399014257212_item	3690098	et	0	main
minu	doc_399014257212_item	3690099	et	0	main
elutuba	doc_399014257212_item	3690100	et	0	main
jälle	doc_399014257212_item	3690101	et	0	main
on	doc_399014257212_item	3690102	et	0	main
väike	doc_399014257212_item	3690103	et	0	main
akna	doc_399014257212_item	3690104	et	0	main
ees	doc_399014257212_item	3690105	et	0	main
roheline	doc_399014257212_item	3690106	et	0	main
kardin	doc_399014257212_item	3690107	et	0	main
kaks	doc_399014257212_item	3690108	et	0	main
must	doc_399014257212_item	3690109	et	0	main
tugitool	doc_399014257212_item	3690110	et	0	main
on	doc_399014257212_item	3690111	et	0	main
riiuli	doc_399014257212_item	3690112	et	0	main
kõrval	doc_399014257212_item	3690113	et	0	main
suur	doc_399014257212_item	3690114	et	0	main
maali	doc_399014257212_item	3690115	et	0	main
on	doc_399014257212_item	3690116	et	0	main
seina	doc_399014257212_item	3690117	et	0	main
peal	doc_399014257212_item	3690118	et	0	main
riiuli	doc_399014257212_item	3690119	et	0	main
peal	doc_399014257212_item	3690120	et	0	main
on	doc_399014257212_item	3690121	et	0	main
raamatut	doc_399014257212_item	3690122	et	0	main
lambi	doc_399014257212_item	3690123	et	0	main
on	doc_399014257212_item	3690124	et	0	main
laua	doc_399014257212_item	3690125	et	0	main
peal	doc_399014257212_item	3690126	et	0	main
ma	doc_399014257212_item	3690127	et	0	main
esiku	doc_399014257212_item	3690128	et	0	main
on	doc_399014257212_item	3690129	et	0	main
suur	doc_399014257212_item	3690130	et	0	main
väga	doc_399014257212_item	3690131	et	0	main
kasulik	doc_399014257212_item	3690132	et	0	main
kummut	doc_399014257212_item	3690133	et	0	main
on	doc_399014257212_item	3690134	et	0	main
vannituba	doc_399014257212_item	3690135	et	0	main
kõrval	doc_399014257212_item	3690136	et	0	main
arvuti	doc_399014257212_item	3690137	et	0	main
on	doc_399014257212_item	3690138	et	0	main
kappi	doc_399014257212_item	3690139	et	0	main
peal	doc_399014257212_item	3690140	et	0	main
ja	doc_399014257212_item	3690141	et	0	main
sinine	doc_399014257212_item	3690142	et	0	main
vaip	doc_399014257212_item	3690143	et	0	main
on	doc_399014257212_item	3690144	et	0	main
põrand	doc_399014257212_item	3690145	et	0	main
peal	doc_399014257212_item	3690146	et	0	main
minu	doc_399014257212_item	3690147	et	0	main
korter	doc_399014257212_item	3690148	et	0	main
puhas	doc_399014257212_item	3690149	et	0	main
mulle	doc_399014257212_item	3690150	et	0	main
meeldiv	doc_399014257212_item	3690151	et	0	main
puhtus	doc_399014257212_item	3690152	et	0	main
minu	doc_399014257212_item	3690153	et	0	main
telefoninumber	doc_399014257212_item	3690154	et	0	main
on	doc_399014257212_item	3690155	et	0	main
null	doc_399014257212_item	3690156	et	0	main
seitse	doc_399014257212_item	3690157	et	0	main
üheksa	doc_399014257212_item	3690158	et	0	main
seitse	doc_399014257212_item	3690159	et	0	main
üks	doc_399014257212_item	3690160	et	0	main
null	doc_399014257212_item	3690161	et	0	main
kolm	doc_399014257212_item	3690162	et	0	main
kuskümmendseitse	doc_399014257212_item	3690163	et	0	main
nelikümmend	doc_399014257212_item	3690164	et	0	main
üks	doc_399014257212_item	3690165	et	0	main
07971	doc_399014257212_item	3690166	et	0	main
03	doc_399014257212_item	3690167	et	0	main
67	doc_399014257212_item	3690168	et	0	main
41	doc_399014257212_item	3690169	et	0	main
minu	doc_399014257212_item	3690170	et	0	main
majanumber	doc_399014257212_item	3690171	et	0	main
on	doc_399014257212_item	3690172	et	0	main
sada	doc_399014257212_item	3690173	et	0	main
kolmkummend	doc_399014257212_item	3690174	et	0	main
kolm	doc_399014257212_item	3690175	et	0	main
minu	doc_399014257212_item	3690176	et	0	main
korterinumber	doc_399014257212_item	3690177	et	0	main
on	doc_399014257212_item	3690178	et	0	main
kaks	doc_399014257212_item	3690179	et	0	main
põrand	doc_399014257212_item	3690180	et	0	main
korteri	doc_399014257212_item	3690181	et	0	main
viis	doc_399014257212_item	3690182	et	0	main
minu	doc_399014257212_item	3690183	et	0	main
aadress	doc_399014257212_item	3690184	et	0	main
xxxx	doc_399014257212_item	3690185	et	0	main
glasgows	doc_399014257212_item	3690186	et	0	main
šotimaal	doc_399014257212_item	3690187	et	0	main
essee	doc_491521501849_item	3690189	et	0	main
nimed	doc_491521501849_item	3690190	et	0	main
marmortahvlil	doc_491521501849_item	3690191	et	0	main
nimed	doc_491521501849_item	3690192	et	0	main
marmortahvlil	doc_491521501849_item	3690193	et	0	main
film	doc_491521501849_item	3690194	et	0	main
mis	doc_491521501849_item	3690195	et	0	main
soovitav	doc_491521501849_item	3690196	et	0	main
kõigil	doc_491521501849_item	3690197	et	0	main
vaadata	doc_491521501849_item	3690198	et	0	main
mitte	doc_491521501849_item	3690199	et	0	main
ainult	doc_491521501849_item	3690200	et	0	main
täiskasvanutele	doc_491521501849_item	3690201	et	0	main
vaid	doc_491521501849_item	3690202	et	0	main
ka	doc_491521501849_item	3690203	et	0	main
lastele	doc_491521501849_item	3690204	et	0	main
teie	doc_491521501849_item	3690205	et	0	main
küsite	doc_491521501849_item	3690206	et	0	main
miks	doc_491521501849_item	3690207	et	0	main
sellepärast	doc_491521501849_item	3690208	et	0	main
et	doc_491521501849_item	3690209	et	0	main
oma	doc_491521501849_item	3690210	et	0	main
sünnimaa	doc_491521501849_item	3690211	et	0	main
ajalugu	doc_491521501849_item	3690212	et	0	main
peab	doc_491521501849_item	3690213	et	0	main
teadma	doc_491521501849_item	3690214	et	0	main
igaüks	doc_491521501849_item	3690215	et	0	main
igaüks	doc_491521501849_item	3690216	et	0	main
inimene	doc_491521501849_item	3690217	et	0	main
peab	doc_491521501849_item	3690218	et	0	main
teadma	doc_491521501849_item	3690219	et	0	main
kuidas	doc_491521501849_item	3690220	et	0	main
meie	doc_491521501849_item	3690221	et	0	main
riik	doc_491521501849_item	3690222	et	0	main
iseseisvus	doc_491521501849_item	3690223	et	0	main
kui	doc_491521501849_item	3690224	et	0	main
palju	doc_491521501849_item	3690225	et	0	main
elusid	doc_491521501849_item	3690226	et	0	main
oli	doc_491521501849_item	3690227	et	0	main
kaotatud	doc_491521501849_item	3690228	et	0	main
nendel	doc_491521501849_item	3690229	et	0	main
rasketel	doc_491521501849_item	3690230	et	0	main
aastatel	doc_491521501849_item	3690231	et	0	main
sellise	doc_491521501849_item	3690232	et	0	main
väikse	doc_491521501849_item	3690233	et	0	main
riiki	doc_491521501849_item	3690234	et	0	main
jaoks	doc_491521501849_item	3690235	et	0	main
nagu	doc_491521501849_item	3690236	et	0	main
seda	doc_491521501849_item	3690237	et	0	main
on	doc_491521501849_item	3690238	et	0	main
eesti	doc_491521501849_item	3690239	et	0	main
on	doc_491521501849_item	3690240	et	0	main
1918	doc_491521501849_item	3690241	et	0	main
a	doc_491521501849_item	3690242	et	0	main
oli	doc_491521501849_item	3690243	et	0	main
väga	doc_491521501849_item	3690244	et	0	main
raske	doc_491521501849_item	3690245	et	0	main
ja	doc_491521501849_item	3690246	et	0	main
seda	doc_491521501849_item	3690247	et	0	main
peavad	doc_491521501849_item	3690248	et	0	main
teadma	doc_491521501849_item	3690249	et	0	main
ja	doc_491521501849_item	3690250	et	0	main
mäletama	doc_491521501849_item	3690251	et	0	main
kõik	doc_491521501849_item	3690252	et	0	main
kõik	doc_491521501849_item	3690253	et	0	main
peavad	doc_491521501849_item	3690254	et	0	main
mälestama	doc_491521501849_item	3690255	et	0	main
neid	doc_491521501849_item	3690256	et	0	main
kes	doc_491521501849_item	3690257	et	0	main
said	doc_491521501849_item	3690258	et	0	main
nendel	doc_491521501849_item	3690259	et	0	main
rasketel	doc_491521501849_item	3690260	et	0	main
aastatel	doc_491521501849_item	3690261	et	0	main
surma	doc_491521501849_item	3690262	et	0	main
film	doc_491521501849_item	3690263	et	0	main
on	doc_491521501849_item	3690264	et	0	main
pühendatud	doc_491521501849_item	3690265	et	0	main
vabadussõjale	doc_491521501849_item	3690266	et	0	main
milles	doc_491521501849_item	3690267	et	0	main
hukkus	doc_491521501849_item	3690268	et	0	main
palju	doc_491521501849_item	3690269	et	0	main
noori	doc_491521501849_item	3690270	et	0	main
sõdureid	doc_491521501849_item	3690271	et	0	main
noored	doc_491521501849_item	3690272	et	0	main
sõdurid	doc_491521501849_item	3690273	et	0	main
läksid	doc_491521501849_item	3690274	et	0	main
surma	doc_491521501849_item	3690275	et	0	main
et	doc_491521501849_item	3690276	et	0	main
muuta	doc_491521501849_item	3690277	et	0	main
iseseisvaks	doc_491521501849_item	3690278	et	0	main
oma	doc_491521501849_item	3690279	et	0	main
riik	doc_491521501849_item	3690280	et	0	main
sõdurid	doc_491521501849_item	3690281	et	0	main
surid	doc_491521501849_item	3690282	et	0	main
oma	doc_491521501849_item	3690283	et	0	main
kodumaa	doc_491521501849_item	3690284	et	0	main
eest	doc_491521501849_item	3690285	et	0	main
peategelane	doc_491521501849_item	3690286	et	0	main
henn	doc_491521501849_item	3690287	et	0	main
ahase	doc_491521501849_item	3690288	et	0	main
priit	doc_491521501849_item	3690289	et	0	main
võigemast	doc_491521501849_item	3690290	et	0	main
gümnasist	doc_491521501849_item	3690291	et	0	main
kes	doc_491521501849_item	3690292	et	0	main
ei	doc_491521501849_item	3690293	et	0	main
löönud	doc_491521501849_item	3690294	et	0	main
kartma	doc_491521501849_item	3690295	et	0	main
läks	doc_491521501849_item	3690296	et	0	main
oma	doc_491521501849_item	3690297	et	0	main
klassivendadega	doc_491521501849_item	3690298	et	0	main
sõtta	doc_491521501849_item	3690299	et	0	main
oma	doc_491521501849_item	3690300	et	0	main
kodumaad	doc_491521501849_item	3690301	et	0	main
kaitsma	doc_491521501849_item	3690302	et	0	main
gümnasistid	doc_491521501849_item	3690303	et	0	main
uskusid	doc_491521501849_item	3690304	et	0	main
pühalikult	doc_491521501849_item	3690305	et	0	main
oma	doc_491521501849_item	3690306	et	0	main
eesmärkidesse	doc_491521501849_item	3690307	et	0	main
omandada	doc_491521501849_item	3690308	et	0	main
lõpuks	doc_491521501849_item	3690309	et	0	main
kauaoodatud	doc_491521501849_item	3690310	et	0	main
iseseisvust	doc_491521501849_item	3690311	et	0	main
noormehed	doc_491521501849_item	3690312	et	0	main
tahtsid	doc_491521501849_item	3690313	et	0	main
lõpuks	doc_491521501849_item	3690314	et	0	main
tunda	doc_491521501849_item	3690315	et	0	main
vabaduse	doc_491521501849_item	3690316	et	0	main
hõngu	doc_491521501849_item	3690317	et	0	main
tol	doc_491521501849_item	3690318	et	0	main
ajal	doc_491521501849_item	3690319	et	0	main
arvasid	doc_491521501849_item	3690320	et	0	main
nad	doc_491521501849_item	3690321	et	0	main
et	doc_491521501849_item	3690322	et	0	main
sellest	doc_491521501849_item	3690323	et	0	main
sõjast	doc_491521501849_item	3690324	et	0	main
sõltub	doc_491521501849_item	3690325	et	0	main
nende	doc_491521501849_item	3690326	et	0	main
laste	doc_491521501849_item	3690327	et	0	main
ja	doc_491521501849_item	3690328	et	0	main
iseendi	doc_491521501849_item	3690329	et	0	main
ja	doc_491521501849_item	3690330	et	0	main
lõpuks	doc_491521501849_item	3690331	et	0	main
ka	doc_491521501849_item	3690332	et	0	main
kodumaa	doc_491521501849_item	3690333	et	0	main
tulevik	doc_491521501849_item	3690334	et	0	main
ma	doc_491521501849_item	3690335	et	0	main
arvan	doc_491521501849_item	3690336	et	0	main
et	doc_491521501849_item	3690337	et	0	main
need	doc_491521501849_item	3690338	et	0	main
sõdurid	doc_491521501849_item	3690339	et	0	main
olid	doc_491521501849_item	3690340	et	0	main
tõelised	doc_491521501849_item	3690341	et	0	main
kangelased	doc_491521501849_item	3690342	et	0	main
sest	doc_491521501849_item	3690343	et	0	main
et	doc_491521501849_item	3690344	et	0	main
nad	doc_491521501849_item	3690345	et	0	main
läksid	doc_491521501849_item	3690346	et	0	main
vabatahtlikult	doc_491521501849_item	3690347	et	0	main
kõige	doc_491521501849_item	3690348	et	0	main
hullemasse	doc_491521501849_item	3690349	et	0	main
kohta	doc_491521501849_item	3690350	et	0	main
maailmas	doc_491521501849_item	3690351	et	0	main
peategelast	doc_491521501849_item	3690352	et	0	main
aitas	doc_491521501849_item	3690353	et	0	main
oma	doc_491521501849_item	3690354	et	0	main
võimetesse	doc_491521501849_item	3690355	et	0	main
uskuda	doc_491521501849_item	3690356	et	0	main
tundeküllasse	doc_491521501849_item	3690357	et	0	main
suhtesse	doc_491521501849_item	3690358	et	0	main
martasse	doc_491521501849_item	3690359	et	0	main
hele	doc_491521501849_item	3690360	et	0	main
kõre	doc_491521501849_item	3690361	et	0	main
oma	doc_491521501849_item	3690362	et	0	main
armastusega	doc_491521501849_item	3690363	et	0	main
aitas	doc_491521501849_item	3690364	et	0	main
marta	doc_491521501849_item	3690365	et	0	main
teda	doc_491521501849_item	3690366	et	0	main
raskel	doc_491521501849_item	3690367	et	0	main
ajal	doc_491521501849_item	3690368	et	0	main
uskuda	doc_491521501849_item	3690369	et	0	main
tema	doc_491521501849_item	3690370	et	0	main
jõusse	doc_491521501849_item	3690371	et	0	main
minu	doc_491521501849_item	3690372	et	0	main
arust	doc_491521501849_item	3690373	et	0	main
just	doc_491521501849_item	3690374	et	0	main
tänu	doc_491521501849_item	3690375	et	0	main
sellistele	doc_491521501849_item	3690376	et	0	main
poistele	doc_491521501849_item	3690377	et	0	main
elame	doc_491521501849_item	3690378	et	0	main
me	doc_491521501849_item	3690379	et	0	main
praegu	doc_491521501849_item	3690380	et	0	main
vabas	doc_491521501849_item	3690381	et	0	main
ja	doc_491521501849_item	3690382	et	0	main
iseseisvas	doc_491521501849_item	3690383	et	0	main
riigis	doc_491521501849_item	3690384	et	0	main
ma	doc_491521501849_item	3690385	et	0	main
arvan	doc_491521501849_item	3690386	et	0	main
et	doc_491521501849_item	3690387	et	0	main
see	doc_491521501849_item	3690388	et	0	main
film	doc_491521501849_item	3690389	et	0	main
näitas	doc_491521501849_item	3690390	et	0	main
paljudele	doc_491521501849_item	3690391	et	0	main
kui	doc_491521501849_item	3690392	et	0	main
vapraks	doc_491521501849_item	3690393	et	0	main
ja	doc_491521501849_item	3690394	et	0	main
tugevaks	doc_491521501849_item	3690395	et	0	main
rahvaks	doc_491521501849_item	3690396	et	0	main
suudame	doc_491521501849_item	3690397	et	0	main
me	doc_491521501849_item	3690398	et	0	main
raskel	doc_491521501849_item	3690399	et	0	main
hetkel	doc_491521501849_item	3690400	et	0	main
saada	doc_491521501849_item	3690401	et	0	main
ma	doc_491521501849_item	3690402	et	0	main
olen	doc_491521501849_item	3690403	et	0	main
väga	doc_491521501849_item	3690404	et	0	main
uhke	doc_491521501849_item	3690405	et	0	main
selliste	doc_491521501849_item	3690406	et	0	main
inimeste	doc_491521501849_item	3690407	et	0	main
üle	doc_491521501849_item	3690408	et	0	main
nagu	doc_491521501849_item	3690409	et	0	main
nemad	doc_491521501849_item	3690410	et	0	main
sest	doc_491521501849_item	3690411	et	0	main
need	doc_491521501849_item	3690412	et	0	main
noored	doc_491521501849_item	3690413	et	0	main
poisid	doc_491521501849_item	3690414	et	0	main
võitlesid	doc_491521501849_item	3690415	et	0	main
meie	doc_491521501849_item	3690416	et	0	main
eest	doc_491521501849_item	3690417	et	0	main
riskides	doc_491521501849_item	3690418	et	0	main
kõigega	doc_491521501849_item	3690419	et	0	main
seal	doc_491521501849_item	3690420	et	0	main
hulgas	doc_491521501849_item	3690421	et	0	main
ka	doc_491521501849_item	3690422	et	0	main
kõige	doc_491521501849_item	3690423	et	0	main
kallima	doc_491521501849_item	3690424	et	0	main
asjaga	doc_491521501849_item	3690425	et	0	main
maailmas	doc_491521501849_item	3690426	et	0	main
eluga	doc_491521501849_item	3690427	et	0	main
meie	doc_491521501849_item	3690428	et	0	main
noored	doc_491521501849_item	3690429	et	0	main
inimesed	doc_491521501849_item	3690430	et	0	main
peame	doc_491521501849_item	3690431	et	0	main
mälestama	doc_491521501849_item	3690432	et	0	main
ja	doc_491521501849_item	3690433	et	0	main
mäletama	doc_491521501849_item	3690434	et	0	main
selliseid	doc_491521501849_item	3690435	et	0	main
inimesi	doc_491521501849_item	3690436	et	0	main
nagu	doc_491521501849_item	3690437	et	0	main
filmi	doc_491521501849_item	3690438	et	0	main
peategelased	doc_491521501849_item	3690439	et	0	main
rohkem	doc_491521501849_item	3690440	et	0	main
austama	doc_491521501849_item	3690441	et	0	main
vanemaid	doc_491521501849_item	3690442	et	0	main
inimesi	doc_491521501849_item	3690443	et	0	main
isegi	doc_491521501849_item	3690444	et	0	main
kui	doc_491521501849_item	3690445	et	0	main
meie	doc_491521501849_item	3690446	et	0	main
arvamused	doc_491521501849_item	3690447	et	0	main
ei	doc_491521501849_item	3690448	et	0	main
ühti	doc_491521501849_item	3690449	et	0	main
kes	doc_491521501849_item	3690450	et	0	main
teab	doc_491521501849_item	3690451	et	0	main
võib-olla	doc_491521501849_item	3690452	et	0	main
just	doc_491521501849_item	3690453	et	0	main
sellile	doc_491521501849_item	3690454	et	0	main
inimesele	doc_491521501849_item	3690455	et	0	main
olen	doc_491521501849_item	3690456	et	0	main
ma	doc_491521501849_item	3690457	et	0	main
võlgu	doc_491521501849_item	3690458	et	0	main
oma	doc_491521501849_item	3690459	et	0	main
elu	doc_491521501849_item	3690460	et	0	main
ja	doc_491521501849_item	3690461	et	0	main
vabaduse	doc_491521501849_item	3690462	et	0	main
essee	doc_973441205333_item	3690463	et	0	main
teater	doc_973441205333_item	3690464	et	0	main
see	doc_973441205333_item	3690465	et	0	main
on	doc_973441205333_item	3690466	et	0	main
elupeegel	doc_973441205333_item	3690467	et	0	main
mina	doc_973441205333_item	3690468	et	0	main
arvan	doc_973441205333_item	3690469	et	0	main
et	doc_973441205333_item	3690470	et	0	main
teater	doc_973441205333_item	3690471	et	0	main
on	doc_973441205333_item	3690472	et	0	main
üks	doc_973441205333_item	3690473	et	0	main
liik	doc_973441205333_item	3690474	et	0	main
kaunitest	doc_973441205333_item	3690475	et	0	main
kunstidest	doc_973441205333_item	3690476	et	0	main
mis	doc_973441205333_item	3690477	et	0	main
kujutab	doc_973441205333_item	3690478	et	0	main
endast	doc_973441205333_item	3690479	et	0	main
tegeliku	doc_973441205333_item	3690480	et	0	main
elu	doc_973441205333_item	3690481	et	0	main
ja	doc_973441205333_item	3690482	et	0	main
teatritüki	doc_973441205333_item	3690483	et	0	main
autori	doc_973441205333_item	3690484	et	0	main
fantaasia	doc_973441205333_item	3690485	et	0	main
sulamit	doc_973441205333_item	3690486	et	0	main
ning	doc_973441205333_item	3690487	et	0	main
annab	doc_973441205333_item	3690488	et	0	main
võimaluse	doc_973441205333_item	3690489	et	0	main
teatrikülastajale	doc_973441205333_item	3690490	et	0	main
põgeneda	doc_973441205333_item	3690491	et	0	main
tegeliku	doc_973441205333_item	3690492	et	0	main
elu	doc_973441205333_item	3690493	et	0	main
reaalsusest	doc_973441205333_item	3690494	et	0	main
umbes	doc_973441205333_item	3690495	et	0	main
nii	doc_973441205333_item	3690496	et	0	main
on	doc_973441205333_item	3690497	et	0	main
öelnud	doc_973441205333_item	3690498	et	0	main
mark	doc_973441205333_item	3690499	et	0	main
soosaar	doc_973441205333_item	3690500	et	0	main
hiljutises	doc_973441205333_item	3690501	et	0	main
viker	doc_973441205333_item	3690502	et	0	main
raadio	doc_973441205333_item	3690503	et	0	main
öö	doc_973441205333_item	3690504	et	0	main
ülikoolis	doc_973441205333_item	3690505	et	0	main
vaatajad	doc_973441205333_item	3690506	et	0	main
teatrietenduse	doc_973441205333_item	3690507	et	0	main
ajal	doc_973441205333_item	3690508	et	0	main
sukelduvad	doc_973441205333_item	3690509	et	0	main
kujutlusmaailma	doc_973441205333_item	3690510	et	0	main
kus	doc_973441205333_item	3690511	et	0	main
elatakse	doc_973441205333_item	3690512	et	0	main
laval	doc_973441205333_item	3690513	et	0	main
läbi	doc_973441205333_item	3690514	et	0	main
teiste	doc_973441205333_item	3690515	et	0	main
inimeste	doc_973441205333_item	3690516	et	0	main
elusid	doc_973441205333_item	3690517	et	0	main
ja	doc_973441205333_item	3690518	et	0	main
unustatakse	doc_973441205333_item	3690519	et	0	main
enda	doc_973441205333_item	3690520	et	0	main
tegelikud	doc_973441205333_item	3690521	et	0	main
probleemid	doc_973441205333_item	3690522	et	0	main
teatri	doc_973441205333_item	3690523	et	0	main
iseloomustavaks	doc_973441205333_item	3690524	et	0	main
jooneks	doc_973441205333_item	3690525	et	0	main
on	doc_973441205333_item	3690526	et	0	main
see	doc_973441205333_item	3690527	et	0	main
et	doc_973441205333_item	3690528	et	0	main
pühendutakse	doc_973441205333_item	3690529	et	0	main
tegelaste	doc_973441205333_item	3690530	et	0	main
sisemaailma	doc_973441205333_item	3690531	et	0	main
nende	doc_973441205333_item	3690532	et	0	main
keerulistele	doc_973441205333_item	3690533	et	0	main
hingelistele	doc_973441205333_item	3690534	et	0	main
kokkupõrgetele	doc_973441205333_item	3690535	et	0	main
ja	doc_973441205333_item	3690536	et	0	main
kaasaegse	doc_973441205333_item	3690537	et	0	main
inimenese	doc_973441205333_item	3690538	et	0	main
psühholoogiale	doc_973441205333_item	3690539	et	0	main
kus	doc_973441205333_item	3690540	et	0	main
peale	doc_973441205333_item	3690541	et	0	main
teatri	doc_973441205333_item	3690542	et	0	main
te	doc_973441205333_item	3690543	et	0	main
võite	doc_973441205333_item	3690544	et	0	main
vaadata	doc_973441205333_item	3690545	et	0	main
iseenda	doc_973441205333_item	3690546	et	0	main
peale	doc_973441205333_item	3690547	et	0	main
ja	doc_973441205333_item	3690548	et	0	main
mõista	doc_973441205333_item	3690549	et	0	main
kui	doc_973441205333_item	3690550	et	0	main
keeruline	doc_973441205333_item	3690551	et	0	main
on	doc_973441205333_item	3690552	et	0	main
maailm	doc_973441205333_item	3690553	et	0	main
meie	doc_973441205333_item	3690554	et	0	main
ümber	doc_973441205333_item	3690555	et	0	main
nähes	doc_973441205333_item	3690556	et	0	main
tegeliku	doc_973441205333_item	3690557	et	0	main
elu	doc_973441205333_item	3690558	et	0	main
peegeldust	doc_973441205333_item	3690559	et	0	main
teatris	doc_973441205333_item	3690560	et	0	main
me	doc_973441205333_item	3690561	et	0	main
mõistame	doc_973441205333_item	3690562	et	0	main
kui	doc_973441205333_item	3690563	et	0	main
tähtsad	doc_973441205333_item	3690564	et	0	main
on	doc_973441205333_item	3690565	et	0	main
positiivsed	doc_973441205333_item	3690566	et	0	main
emotsioonid	doc_973441205333_item	3690567	et	0	main
ja	doc_973441205333_item	3690568	et	0	main
ideaalid	doc_973441205333_item	3690569	et	0	main
mis	doc_973441205333_item	3690570	et	0	main
muudavad	doc_973441205333_item	3690571	et	0	main
meid	doc_973441205333_item	3690572	et	0	main
ja	doc_973441205333_item	3690573	et	0	main
meie	doc_973441205333_item	3690574	et	0	main
kaudu	doc_973441205333_item	3690575	et	0	main
paremaks	doc_973441205333_item	3690576	et	0	main
ka	doc_973441205333_item	3690577	et	0	main
meie	doc_973441205333_item	3690578	et	0	main
elukvaliteeti	doc_973441205333_item	3690579	et	0	main
teater	doc_973441205333_item	3690580	et	0	main
peegeldades	doc_973441205333_item	3690581	et	0	main
tegeliku	doc_973441205333_item	3690582	et	0	main
elu	doc_973441205333_item	3690583	et	0	main
ennast	doc_973441205333_item	3690584	et	0	main
teeb	doc_973441205333_item	3690585	et	0	main
meile	doc_973441205333_item	3690586	et	0	main
arusaadavaks	doc_973441205333_item	3690587	et	0	main
motivit	doc_973441205333_item	3690588	et	0	main
mis	doc_973441205333_item	3690589	et	0	main
panevad	doc_973441205333_item	3690590	et	0	main
tegutsema	doc_973441205333_item	3690591	et	0	main
inimesi	doc_973441205333_item	3690592	et	0	main
heas	doc_973441205333_item	3690593	et	0	main
ja	doc_973441205333_item	3690594	et	0	main
halvas	doc_973441205333_item	3690595	et	0	main
sunas	doc_973441205333_item	3690596	et	0	main
seega	doc_973441205333_item	3690597	et	0	main
teater	doc_973441205333_item	3690598	et	0	main
on	doc_973441205333_item	3690599	et	0	main
suur	doc_973441205333_item	3690600	et	0	main
eluõpetaja	doc_973441205333_item	3690601	et	0	main
ning	doc_973441205333_item	3690602	et	0	main
ka	doc_973441205333_item	3690603	et	0	main
meelelahetus	doc_973441205333_item	3690604	et	0	main
kus	doc_973441205333_item	3690605	et	0	main
saame	doc_973441205333_item	3690606	et	0	main
ennast	doc_973441205333_item	3690607	et	0	main
lõdvaks	doc_973441205333_item	3690608	et	0	main
lasta	doc_973441205333_item	3690609	et	0	main
ja	doc_973441205333_item	3690610	et	0	main
pageda	doc_973441205333_item	3690611	et	0	main
oma	doc_973441205333_item	3690612	et	0	main
igapäevastest	doc_973441205333_item	3690613	et	0	main
eluraskustest	doc_973441205333_item	3690614	et	0	main
see	doc_973441205333_item	3690615	et	0	main
minu	doc_973441205333_item	3690616	et	0	main
arvamus	doc_973441205333_item	3690617	et	0	main
tänaseks	doc_973441205333_item	3690618	et	0	main
kuid	doc_973441205333_item	3690619	et	0	main
see	doc_973441205333_item	3690620	et	0	main
võib	doc_973441205333_item	3690621	et	0	main
ka	doc_973441205333_item	3690622	et	0	main
edaspidi	doc_973441205333_item	3690623	et	0	main
muutuda	doc_973441205333_item	3690624	et	0	main
sest	doc_973441205333_item	3690625	et	0	main
loodan	doc_973441205333_item	3690626	et	0	main
et	doc_973441205333_item	3690627	et	0	main
tulevikus	doc_973441205333_item	3690628	et	0	main
on	doc_973441205333_item	3690629	et	0	main
mul	doc_973441205333_item	3690630	et	0	main
rohkem	doc_973441205333_item	3690631	et	0	main
elukogemust	doc_973441205333_item	3690632	et	0	main
ja	doc_973441205333_item	3690633	et	0	main
silma	doc_973441205333_item	3690634	et	0	main
et	doc_973441205333_item	3690635	et	0	main
hinnata	doc_973441205333_item	3690636	et	0	main
ja	doc_973441205333_item	3690637	et	0	main
näha	doc_973441205333_item	3690638	et	0	main
teatri	doc_973441205333_item	3690639	et	0	main
kogu	doc_973441205333_item	3690640	et	0	main
tegeliku	doc_973441205333_item	3690641	et	0	main
väärtust	doc_973441205333_item	3690642	et	0	main
essee	doc_769634019913_item	3690976	et	0	main
saaremaalt	doc_769634019913_item	3690977	et	0	main
tagasi	doc_769634019913_item	3690978	et	0	main
erzgebirges	doc_769634019913_item	3690979	et	0	main
mina	doc_769634019913_item	3690980	et	0	main
käisin	doc_769634019913_item	3690981	et	0	main
nädalavahetusel	doc_769634019913_item	3690982	et	0	main
saaremaal	doc_769634019913_item	3690983	et	0	main
saaremaa	doc_769634019913_item	3690984	et	0	main
on	doc_769634019913_item	3690985	et	0	main
eesti	doc_769634019913_item	3690986	et	0	main
suurim	doc_769634019913_item	3690987	et	0	main
saar	doc_769634019913_item	3690988	et	0	main
ja	doc_769634019913_item	3690989	et	0	main
asub	doc_769634019913_item	3690990	et	0	main
läänemeres	doc_769634019913_item	3690991	et	0	main
ma	doc_769634019913_item	3690992	et	0	main
ööbisin	doc_769634019913_item	3690993	et	0	main
kihelkonnas	doc_769634019913_item	3690994	et	0	main
ja	doc_769634019913_item	3690995	et	0	main
meri	doc_769634019913_item	3690996	et	0	main
ei	doc_769634019913_item	3690997	et	0	main
olnud	doc_769634019913_item	3690998	et	0	main
kaugel	doc_769634019913_item	3690999	et	0	main
käisin	doc_769634019913_item	3691000	et	0	main
igal	doc_769634019913_item	3691001	et	0	main
hommikul	doc_769634019913_item	3691002	et	0	main
meres	doc_769634019913_item	3691003	et	0	main
ujuma	doc_769634019913_item	3691004	et	0	main
ja	doc_769634019913_item	3691005	et	0	main
siis	doc_769634019913_item	3691006	et	0	main
sőin	doc_769634019913_item	3691007	et	0	main
rannas	doc_769634019913_item	3691008	et	0	main
hommikusööki	doc_769634019913_item	3691009	et	0	main
nautisin	doc_769634019913_item	3691010	et	0	main
saaremaa	doc_769634019913_item	3691011	et	0	main
loodust	doc_769634019913_item	3691012	et	0	main
mere	doc_769634019913_item	3691013	et	0	main
ääres	doc_769634019913_item	3691014	et	0	main
ja	doc_769634019913_item	3691015	et	0	main
päevitasin	doc_769634019913_item	3691016	et	0	main
terve	doc_769634019913_item	3691017	et	0	main
päeva	doc_769634019913_item	3691018	et	0	main
őhtuti	doc_769634019913_item	3691019	et	0	main
istusin	doc_769634019913_item	3691020	et	0	main
ma	doc_769634019913_item	3691021	et	0	main
vőrkkiigis	doc_769634019913_item	3691022	et	0	main
ja	doc_769634019913_item	3691023	et	0	main
vaatasin	doc_769634019913_item	3691024	et	0	main
päikeseloojakut	doc_769634019913_item	3691025	et	0	main
täna	doc_769634019913_item	3691026	et	0	main
tulin	doc_769634019913_item	3691027	et	0	main
tagasi	doc_769634019913_item	3691028	et	0	main
saksamaale	doc_769634019913_item	3691029	et	0	main
ma	doc_769634019913_item	3691030	et	0	main
elan	doc_769634019913_item	3691031	et	0	main
ida-saksamaal	doc_769634019913_item	3691032	et	0	main
sachsenis	doc_769634019913_item	3691033	et	0	main
ühes	doc_769634019913_item	3691034	et	0	main
väikes	doc_769634019913_item	3691035	et	0	main
linnas	doc_769634019913_item	3691036	et	0	main
erzgebirges	doc_769634019913_item	3691037	et	0	main
seal	doc_769634019913_item	3691038	et	0	main
on	doc_769634019913_item	3691039	et	0	main
teistsugune	doc_769634019913_item	3691040	et	0	main
loodus	doc_769634019913_item	3691041	et	0	main
kui	doc_769634019913_item	3691042	et	0	main
saaremaal	doc_769634019913_item	3691043	et	0	main
erzgebirge	doc_769634019913_item	3691044	et	0	main
on	doc_769634019913_item	3691045	et	0	main
mäestik	doc_769634019913_item	3691046	et	0	main
ja	doc_769634019913_item	3691047	et	0	main
sellepärast	doc_769634019913_item	3691048	et	0	main
on	doc_769634019913_item	3691049	et	0	main
seal	doc_769634019913_item	3691050	et	0	main
palju	doc_769634019913_item	3691051	et	0	main
mägesid	doc_769634019913_item	3691052	et	0	main
ükskőik	doc_769634019913_item	3691053	et	0	main
kuhu	doc_769634019913_item	3691054	et	0	main
ma	doc_769634019913_item	3691055	et	0	main
lähen	doc_769634019913_item	3691056	et	0	main
alati	doc_769634019913_item	3691057	et	0	main
on	doc_769634019913_item	3691058	et	0	main
mägine	doc_769634019913_item	3691059	et	0	main
erzgebirges	doc_769634019913_item	3691060	et	0	main
on	doc_769634019913_item	3691061	et	0	main
ilusad	doc_769634019913_item	3691062	et	0	main
linnad	doc_769634019913_item	3691063	et	0	main
aga	doc_769634019913_item	3691064	et	0	main
linnades	doc_769634019913_item	3691065	et	0	main
on	doc_769634019913_item	3691066	et	0	main
muidugi	doc_769634019913_item	3691067	et	0	main
ka	doc_769634019913_item	3691068	et	0	main
mäed	doc_769634019913_item	3691069	et	0	main
mőned	doc_769634019913_item	3691070	et	0	main
ütlevad	doc_769634019913_item	3691071	et	0	main
et	doc_769634019913_item	3691072	et	0	main
mäedel	doc_769634019913_item	3691073	et	0	main
elab	doc_769634019913_item	3691074	et	0	main
imelik	doc_769634019913_item	3691075	et	0	main
mägirahvas	doc_769634019913_item	3691076	et	0	main
ma	doc_769634019913_item	3691077	et	0	main
ei	doc_769634019913_item	3691078	et	0	main
ole	doc_769634019913_item	3691079	et	0	main
kindel	doc_769634019913_item	3691080	et	0	main
kas	doc_769634019913_item	3691081	et	0	main
need	doc_769634019913_item	3691082	et	0	main
inimesed	doc_769634019913_item	3691083	et	0	main
on	doc_769634019913_item	3691084	et	0	main
tőesti	doc_769634019913_item	3691085	et	0	main
nii	doc_769634019913_item	3691086	et	0	main
imelikud	doc_769634019913_item	3691087	et	0	main
neile	doc_769634019913_item	3691088	et	0	main
meeldib	doc_769634019913_item	3691089	et	0	main
üksik	doc_769634019913_item	3691090	et	0	main
olla	doc_769634019913_item	3691091	et	0	main
ja	doc_769634019913_item	3691092	et	0	main
nad	doc_769634019913_item	3691093	et	0	main
räägivad	doc_769634019913_item	3691094	et	0	main
murrakut	doc_769634019913_item	3691095	et	0	main
mina	doc_769634019913_item	3691096	et	0	main
saan	doc_769634019913_item	3691097	et	0	main
nendest	doc_769634019913_item	3691098	et	0	main
aru	doc_769634019913_item	3691099	et	0	main
ja	doc_769634019913_item	3691100	et	0	main
räägin	doc_769634019913_item	3691101	et	0	main
ka	doc_769634019913_item	3691102	et	0	main
natukene	doc_769634019913_item	3691103	et	0	main
murrakut	doc_769634019913_item	3691104	et	0	main
aga	doc_769634019913_item	3691105	et	0	main
teised	doc_769634019913_item	3691106	et	0	main
inimesed	doc_769634019913_item	3691107	et	0	main
kes	doc_769634019913_item	3691108	et	0	main
ei	doc_769634019913_item	3691109	et	0	main
ole	doc_769634019913_item	3691110	et	0	main
pärit	doc_769634019913_item	3691111	et	0	main
erzgebirgest	doc_769634019913_item	3691112	et	0	main
ei	doc_769634019913_item	3691113	et	0	main
saa	doc_769634019913_item	3691114	et	0	main
kőigest	doc_769634019913_item	3691115	et	0	main
aru	doc_769634019913_item	3691116	et	0	main
ja	doc_769634019913_item	3691117	et	0	main
naerad	doc_769634019913_item	3691118	et	0	main
erzgebirges	doc_769634019913_item	3691119	et	0	main
on	doc_769634019913_item	3691120	et	0	main
palju	doc_769634019913_item	3691121	et	0	main
metsi	doc_769634019913_item	3691122	et	0	main
ja	doc_769634019913_item	3691123	et	0	main
mulle	doc_769634019913_item	3691124	et	0	main
meeldib	doc_769634019913_item	3691125	et	0	main
metsades	doc_769634019913_item	3691126	et	0	main
jalutama	doc_769634019913_item	3691127	et	0	main
ja	doc_769634019913_item	3691128	et	0	main
suvel	doc_769634019913_item	3691129	et	0	main
seeni	doc_769634019913_item	3691130	et	0	main
korjata	doc_769634019913_item	3691131	et	0	main
talvel	doc_769634019913_item	3691132	et	0	main
saab	doc_769634019913_item	3691133	et	0	main
maasusatama	doc_769634019913_item	3691134	et	0	main
ja	doc_769634019913_item	3691135	et	0	main
mägedes	doc_769634019913_item	3691136	et	0	main
ka	doc_769634019913_item	3691137	et	0	main
mäesuusatamist	doc_769634019913_item	3691138	et	0	main
teha	doc_769634019913_item	3691139	et	0	main
lapsed	doc_769634019913_item	3691140	et	0	main
kelgutavad	doc_769634019913_item	3691141	et	0	main
ja	doc_769634019913_item	3691142	et	0	main
ehitavad	doc_769634019913_item	3691143	et	0	main
lumememme	doc_769634019913_item	3691144	et	0	main
mőnidel	doc_769634019913_item	3691145	et	0	main
talvidel	doc_769634019913_item	3691146	et	0	main
saab	doc_769634019913_item	3691147	et	0	main
mägedes	doc_769634019913_item	3691148	et	0	main
hästi	doc_769634019913_item	3691149	et	0	main
külm	doc_769634019913_item	3691150	et	0	main
olla	doc_769634019913_item	3691151	et	0	main
kevadel	doc_769634019913_item	3691152	et	0	main
hakkab	doc_769634019913_item	3691153	et	0	main
loodus	doc_769634019913_item	3691154	et	0	main
ärkama	doc_769634019913_item	3691155	et	0	main
lumi	doc_769634019913_item	3691156	et	0	main
sulab	doc_769634019913_item	3691157	et	0	main
ära	doc_769634019913_item	3691158	et	0	main
ja	doc_769634019913_item	3691159	et	0	main
lilled	doc_769634019913_item	3691160	et	0	main
hakkavad	doc_769634019913_item	3691161	et	0	main
őitsema	doc_769634019913_item	3691162	et	0	main
linnud	doc_769634019913_item	3691163	et	0	main
tulevad	doc_769634019913_item	3691164	et	0	main
lőunast	doc_769634019913_item	3691165	et	0	main
tagasi	doc_769634019913_item	3691166	et	0	main
ja	doc_769634019913_item	3691167	et	0	main
laulavad	doc_769634019913_item	3691168	et	0	main
suviti	doc_769634019913_item	3691169	et	0	main
on	doc_769634019913_item	3691170	et	0	main
mőnikord	doc_769634019913_item	3691171	et	0	main
vihmane	doc_769634019913_item	3691172	et	0	main
ja	doc_769634019913_item	3691173	et	0	main
mőnikord	doc_769634019913_item	3691174	et	0	main
päikesepaisteline	doc_769634019913_item	3691175	et	0	main
kui	doc_769634019913_item	3691176	et	0	main
ilus	doc_769634019913_item	3691177	et	0	main
ilm	doc_769634019913_item	3691178	et	0	main
on	doc_769634019913_item	3691179	et	0	main
saab	doc_769634019913_item	3691180	et	0	main
järvedes	doc_769634019913_item	3691181	et	0	main
ujuma	doc_769634019913_item	3691182	et	0	main
minna	doc_769634019913_item	3691183	et	0	main
vői	doc_769634019913_item	3691184	et	0	main
metsas	doc_769634019913_item	3691185	et	0	main
vaikust	doc_769634019913_item	3691186	et	0	main
nautida	doc_769634019913_item	3691187	et	0	main
siis	doc_769634019913_item	3691188	et	0	main
on	doc_769634019913_item	3691189	et	0	main
sügis	doc_769634019913_item	3691190	et	0	main
käes	doc_769634019913_item	3691191	et	0	main
ja	doc_769634019913_item	3691192	et	0	main
lehed	doc_769634019913_item	3691193	et	0	main
hakkavad	doc_769634019913_item	3691194	et	0	main
langema	doc_769634019913_item	3691195	et	0	main
jőulud	doc_769634019913_item	3691196	et	0	main
on	doc_769634019913_item	3691197	et	0	main
erzgebirges	doc_769634019913_item	3691198	et	0	main
viies	doc_769634019913_item	3691199	et	0	main
aastaaeg	doc_769634019913_item	3691200	et	0	main
erzgebirge	doc_769634019913_item	3691201	et	0	main
on	doc_769634019913_item	3691202	et	0	main
jőulugi	doc_769634019913_item	3691203	et	0	main
tőttu	doc_769634019913_item	3691204	et	0	main
väga	doc_769634019913_item	3691205	et	0	main
kuulus	doc_769634019913_item	3691206	et	0	main
igal	doc_769634019913_item	3691207	et	0	main
pool	doc_769634019913_item	3691208	et	0	main
on	doc_769634019913_item	3691209	et	0	main
väikesed	doc_769634019913_item	3691210	et	0	main
ettevőtted	doc_769634019913_item	3691211	et	0	main
kus	doc_769634019913_item	3691212	et	0	main
käsitöödrahvakunsti	doc_769634019913_item	3691213	et	0	main
valmistati	doc_769634019913_item	3691214	et	0	main
väga	doc_769634019913_item	3691215	et	0	main
tuntud	doc_769634019913_item	3691216	et	0	main
on	doc_769634019913_item	3691217	et	0	main
suitsumehed	doc_769634019913_item	3691218	et	0	main
räuchermännchen	doc_769634019913_item	3691219	et	0	main
ehk	doc_769634019913_item	3691220	et	0	main
raachermannln	doc_769634019913_item	3691221	et	0	main
ja	doc_769634019913_item	3691222	et	0	main
inglid	doc_769634019913_item	3691223	et	0	main
inimesed	doc_769634019913_item	3691224	et	0	main
panevad	doc_769634019913_item	3691225	et	0	main
jőuluajal	doc_769634019913_item	3691226	et	0	main
schwibbögenlichterbögen	doc_769634019913_item	3691227	et	0	main
aknade	doc_769634019913_item	3691228	et	0	main
ette	doc_769634019913_item	3691229	et	0	main
mulle	doc_769634019913_item	3691230	et	0	main
meeldib	doc_769634019913_item	3691231	et	0	main
erzgebirges	doc_769634019913_item	3691232	et	0	main
olla	doc_769634019913_item	3691233	et	0	main
eriti	doc_769634019913_item	3691234	et	0	main
jőuluajal	doc_769634019913_item	3691235	et	0	main
siis	doc_769634019913_item	3691236	et	0	main
tean	doc_769634019913_item	3691237	et	0	main
et	doc_769634019913_item	3691238	et	0	main
olen	doc_769634019913_item	3691239	et	0	main
kodus	doc_769634019913_item	3691240	et	0	main
aga	doc_769634019913_item	3691241	et	0	main
mulle	doc_769634019913_item	3691242	et	0	main
meeldib	doc_769634019913_item	3691243	et	0	main
ka	doc_769634019913_item	3691244	et	0	main
saaremaal	doc_769634019913_item	3691245	et	0	main
olla	doc_769634019913_item	3691246	et	0	main
sest	doc_769634019913_item	3691247	et	0	main
seal	doc_769634019913_item	3691248	et	0	main
on	doc_769634019913_item	3691249	et	0	main
meri	doc_769634019913_item	3691250	et	0	main
palju	doc_769634019913_item	3691251	et	0	main
inimesi	doc_769634019913_item	3691252	et	0	main
küsivad	doc_769634019913_item	3691253	et	0	main
kas	doc_769634019913_item	3691254	et	0	main
elamine	doc_769634019913_item	3691255	et	0	main
on	doc_769634019913_item	3691256	et	0	main
maal	doc_769634019913_item	3691257	et	0	main
või	doc_769634019913_item	3691258	et	0	main
linnas	doc_769634019913_item	3691259	et	0	main
parem	doc_769634019913_item	3691260	et	0	main
mina	doc_769634019913_item	3691261	et	0	main
elan	doc_769634019913_item	3691262	et	0	main
praegu	doc_769634019913_item	3691263	et	0	main
göttingeni	doc_769634019913_item	3691264	et	0	main
linnas	doc_769634019913_item	3691265	et	0	main
sest	doc_769634019913_item	3691266	et	0	main
ma	doc_769634019913_item	3691267	et	0	main
õpin	doc_769634019913_item	3691268	et	0	main
seal	doc_769634019913_item	3691269	et	0	main
ma	doc_769634019913_item	3691270	et	0	main
olen	doc_769634019913_item	3691271	et	0	main
ühes	doc_769634019913_item	3691272	et	0	main
väikeses	doc_769634019913_item	3691273	et	0	main
linnas	doc_769634019913_item	3691274	et	0	main
kasvanud	doc_769634019913_item	3691275	et	0	main
thalheimis	doc_769634019913_item	3691276	et	0	main
thalheim	doc_769634019913_item	3691277	et	0	main
asub	doc_769634019913_item	3691278	et	0	main
sachsenis	doc_769634019913_item	3691279	et	0	main
zwönitzi	doc_769634019913_item	3691280	et	0	main
jõe	doc_769634019913_item	3691281	et	0	main
ääres	doc_769634019913_item	3691282	et	0	main
meil	doc_769634019913_item	3691283	et	0	main
oli	doc_769634019913_item	3691284	et	0	main
seal	doc_769634019913_item	3691285	et	0	main
suur	doc_769634019913_item	3691286	et	0	main
korter	doc_769634019913_item	3691287	et	0	main
ja	doc_769634019913_item	3691288	et	0	main
suur	doc_769634019913_item	3691289	et	0	main
osa	doc_769634019913_item	3691290	et	0	main
meie	doc_769634019913_item	3691291	et	0	main
suguvõsast	doc_769634019913_item	3691292	et	0	main
elas	doc_769634019913_item	3691293	et	0	main
või	doc_769634019913_item	3691294	et	0	main
elab	doc_769634019913_item	3691295	et	0	main
thalheimis	doc_769634019913_item	3691296	et	0	main
ma	doc_769634019913_item	3691297	et	0	main
käisin	doc_769634019913_item	3691298	et	0	main
thalheimis	doc_769634019913_item	3691299	et	0	main
koolis	doc_769634019913_item	3691300	et	0	main
ja	doc_769634019913_item	3691301	et	0	main
mul	doc_769634019913_item	3691302	et	0	main
on	doc_769634019913_item	3691303	et	0	main
ka	doc_769634019913_item	3691304	et	0	main
palju	doc_769634019913_item	3691305	et	0	main
sõpru	doc_769634019913_item	3691306	et	0	main
selles	doc_769634019913_item	3691307	et	0	main
linnas	doc_769634019913_item	3691308	et	0	main
ma	doc_769634019913_item	3691309	et	0	main
mäletan	doc_769634019913_item	3691310	et	0	main
et	doc_769634019913_item	3691311	et	0	main
ma	doc_769634019913_item	3691312	et	0	main
olin	doc_769634019913_item	3691313	et	0	main
tihti	doc_769634019913_item	3691314	et	0	main
ühes	doc_769634019913_item	3691315	et	0	main
raamatupoes	doc_769634019913_item	3691316	et	0	main
kui	doc_769634019913_item	3691317	et	0	main
ma	doc_769634019913_item	3691318	et	0	main
koolist	doc_769634019913_item	3691319	et	0	main
koju	doc_769634019913_item	3691320	et	0	main
tulin	doc_769634019913_item	3691321	et	0	main
raamatumüüja	doc_769634019913_item	3691322	et	0	main
oli	doc_769634019913_item	3691323	et	0	main
sõbralik	doc_769634019913_item	3691324	et	0	main
naine	doc_769634019913_item	3691325	et	0	main
kellele	doc_769634019913_item	3691326	et	0	main
meeldis	doc_769634019913_item	3691327	et	0	main
juttu	doc_769634019913_item	3691328	et	0	main
ajada	doc_769634019913_item	3691329	et	0	main
thalheimis	doc_769634019913_item	3691330	et	0	main
käisime	doc_769634019913_item	3691331	et	0	main
ka	doc_769634019913_item	3691332	et	0	main
tihti	doc_769634019913_item	3691333	et	0	main
sõpradele	doc_769634019913_item	3691334	et	0	main
või	doc_769634019913_item	3691335	et	0	main
sugulastele	doc_769634019913_item	3691336	et	0	main
külla	doc_769634019913_item	3691337	et	0	main
mulle	doc_769634019913_item	3691338	et	0	main
meeldis	doc_769634019913_item	3691339	et	0	main
ka	doc_769634019913_item	3691340	et	0	main
meie	doc_769634019913_item	3691341	et	0	main
aias	doc_769634019913_item	3691342	et	0	main
olla	doc_769634019913_item	3691343	et	0	main
aed	doc_769634019913_item	3691344	et	0	main
asub	doc_769634019913_item	3691345	et	0	main
äärelinnas	doc_769634019913_item	3691346	et	0	main
mäe	doc_769634019913_item	3691347	et	0	main
peal	doc_769634019913_item	3691348	et	0	main
ja	doc_769634019913_item	3691349	et	0	main
aias	doc_769634019913_item	3691350	et	0	main
on	doc_769634019913_item	3691351	et	0	main
väike	doc_769634019913_item	3691352	et	0	main
maja	doc_769634019913_item	3691353	et	0	main
kus	doc_769634019913_item	3691354	et	0	main
saab	doc_769634019913_item	3691355	et	0	main
ka	doc_769634019913_item	3691356	et	0	main
puhata	doc_769634019913_item	3691357	et	0	main
suviti	doc_769634019913_item	3691358	et	0	main
ööbisime	doc_769634019913_item	3691359	et	0	main
mõnikord	doc_769634019913_item	3691360	et	0	main
selles	doc_769634019913_item	3691361	et	0	main
suvilas	doc_769634019913_item	3691362	et	0	main
või	doc_769634019913_item	3691363	et	0	main
lihtsalt	doc_769634019913_item	3691364	et	0	main
grillisime	doc_769634019913_item	3691365	et	0	main
maja	doc_769634019913_item	3691366	et	0	main
ees	doc_769634019913_item	3691367	et	0	main
ja	doc_769634019913_item	3691368	et	0	main
olime	doc_769634019913_item	3691369	et	0	main
sõpradega	doc_769634019913_item	3691370	et	0	main
koos	doc_769634019913_item	3691371	et	0	main
suveõhtud	doc_769634019913_item	3691372	et	0	main
olid	doc_769634019913_item	3691373	et	0	main
väga	doc_769634019913_item	3691374	et	0	main
toredad	doc_769634019913_item	3691375	et	0	main
1996	doc_769634019913_item	3691376	et	0	main
aastal	doc_769634019913_item	3691377	et	0	main
kolis	doc_769634019913_item	3691378	et	0	main
mu	doc_769634019913_item	3691379	et	0	main
pere	doc_769634019913_item	3691380	et	0	main
jahnsdorfisse	doc_769634019913_item	3691381	et	0	main
see	doc_769634019913_item	3691382	et	0	main
on	doc_769634019913_item	3691383	et	0	main
küla	doc_769634019913_item	3691384	et	0	main
thalheimi	doc_769634019913_item	3691385	et	0	main
lähedal	doc_769634019913_item	3691386	et	0	main
me	doc_769634019913_item	3691387	et	0	main
kolisime	doc_769634019913_item	3691388	et	0	main
sest	doc_769634019913_item	3691389	et	0	main
mu	doc_769634019913_item	3691390	et	0	main
vanemad	doc_769634019913_item	3691391	et	0	main
ostsid	doc_769634019913_item	3691392	et	0	main
maja	doc_769634019913_item	3691393	et	0	main
mina	doc_769634019913_item	3691394	et	0	main
olin	doc_769634019913_item	3691395	et	0	main
kurb	doc_769634019913_item	3691396	et	0	main
sest	doc_769634019913_item	3691397	et	0	main
ma	doc_769634019913_item	3691398	et	0	main
tahtsin	doc_769634019913_item	3691399	et	0	main
thalheimis	doc_769634019913_item	3691400	et	0	main
elada	doc_769634019913_item	3691401	et	0	main
ja	doc_769634019913_item	3691402	et	0	main
seal	doc_769634019913_item	3691403	et	0	main
koolis	doc_769634019913_item	3691404	et	0	main
käia	doc_769634019913_item	3691405	et	0	main
ma	doc_769634019913_item	3691406	et	0	main
igatsesin	doc_769634019913_item	3691407	et	0	main
selle	doc_769634019913_item	3691408	et	0	main
mugava	doc_769634019913_item	3691409	et	0	main
kodulinna	doc_769634019913_item	3691410	et	0	main
jahnsdorf	doc_769634019913_item	3691411	et	0	main
on	doc_769634019913_item	3691412	et	0	main
igav	doc_769634019913_item	3691413	et	0	main
ja	doc_769634019913_item	3691414	et	0	main
jahnsdorfi	doc_769634019913_item	3691415	et	0	main
inimesed	doc_769634019913_item	3691416	et	0	main
on	doc_769634019913_item	3691417	et	0	main
imelikud	doc_769634019913_item	3691418	et	0	main
ja	doc_769634019913_item	3691419	et	0	main
mulle	doc_769634019913_item	3691420	et	0	main
ei	doc_769634019913_item	3691421	et	0	main
meeldi	doc_769634019913_item	3691422	et	0	main
seal	doc_769634019913_item	3691423	et	0	main
eriti	doc_769634019913_item	3691424	et	0	main
üheks	doc_769634019913_item	3691425	et	0	main
aastaks	doc_769634019913_item	3691426	et	0	main
elasin	doc_769634019913_item	3691427	et	0	main
ma	doc_769634019913_item	3691428	et	0	main
lõunaeesti	doc_769634019913_item	3691429	et	0	main
linnas	doc_769634019913_item	3691430	et	0	main
tõrvas	doc_769634019913_item	3691431	et	0	main
tõrva	doc_769634019913_item	3691432	et	0	main
on	doc_769634019913_item	3691433	et	0	main
väike	doc_769634019913_item	3691434	et	0	main
ja	doc_769634019913_item	3691435	et	0	main
armas	doc_769634019913_item	3691436	et	0	main
linn	doc_769634019913_item	3691437	et	0	main
kui	doc_769634019913_item	3691438	et	0	main
tõrva	doc_769634019913_item	3691439	et	0	main
asuks	doc_769634019913_item	3691440	et	0	main
saksamaal	doc_769634019913_item	3691441	et	0	main
siis	doc_769634019913_item	3691442	et	0	main
oleks	doc_769634019913_item	3691443	et	0	main
küla	doc_769634019913_item	3691444	et	0	main
aga	doc_769634019913_item	3691445	et	0	main
lõunaeestis	doc_769634019913_item	3691446	et	0	main
on	doc_769634019913_item	3691447	et	0	main
see	doc_769634019913_item	3691448	et	0	main
üsna	doc_769634019913_item	3691449	et	0	main
suur	doc_769634019913_item	3691450	et	0	main
ja	doc_769634019913_item	3691451	et	0	main
tuntud	doc_769634019913_item	3691452	et	0	main
linn	doc_769634019913_item	3691453	et	0	main
tõrva	doc_769634019913_item	3691454	et	0	main
kesklinnas	doc_769634019913_item	3691455	et	0	main
on	doc_769634019913_item	3691456	et	0	main
kohvikud	doc_769634019913_item	3691457	et	0	main
ja	doc_769634019913_item	3691458	et	0	main
poed	doc_769634019913_item	3691459	et	0	main
isegi	doc_769634019913_item	3691460	et	0	main
kaubakeskus	doc_769634019913_item	3691461	et	0	main
oli	doc_769634019913_item	3691462	et	0	main
ehitatud	doc_769634019913_item	3691463	et	0	main
tõrva	doc_769634019913_item	3691464	et	0	main
gümnaasiumi	doc_769634019913_item	3691465	et	0	main
lähedal	doc_769634019913_item	3691466	et	0	main
on	doc_769634019913_item	3691467	et	0	main
väga	doc_769634019913_item	3691468	et	0	main
ilus	doc_769634019913_item	3691469	et	0	main
järv	doc_769634019913_item	3691470	et	0	main
ja	doc_769634019913_item	3691471	et	0	main
ka	doc_769634019913_item	3691472	et	0	main
teistes	doc_769634019913_item	3691473	et	0	main
kohtades	doc_769634019913_item	3691474	et	0	main
on	doc_769634019913_item	3691475	et	0	main
järved	doc_769634019913_item	3691476	et	0	main
kui	doc_769634019913_item	3691477	et	0	main
ma	doc_769634019913_item	3691478	et	0	main
tõrvas	doc_769634019913_item	3691479	et	0	main
olen	doc_769634019913_item	3691480	et	0	main
saan	doc_769634019913_item	3691481	et	0	main
ma	doc_769634019913_item	3691482	et	0	main
siis	doc_769634019913_item	3691483	et	0	main
ujuda	doc_769634019913_item	3691484	et	0	main
või	doc_769634019913_item	3691485	et	0	main
kohvikutes	doc_769634019913_item	3691486	et	0	main
sõpradega	doc_769634019913_item	3691487	et	0	main
aega	doc_769634019913_item	3691488	et	0	main
veeta	doc_769634019913_item	3691489	et	0	main
mulle	doc_769634019913_item	3691490	et	0	main
meeldis	doc_769634019913_item	3691491	et	0	main
tõrvas	doc_769634019913_item	3691492	et	0	main
elada	doc_769634019913_item	3691493	et	0	main
sest	doc_769634019913_item	3691494	et	0	main
väikese	doc_769634019913_item	3691495	et	0	main
linnana	doc_769634019913_item	3691496	et	0	main
on	doc_769634019913_item	3691497	et	0	main
see	doc_769634019913_item	3691498	et	0	main
mõnus	doc_769634019913_item	3691499	et	0	main
linn	doc_769634019913_item	3691500	et	0	main
keskuses	doc_769634019913_item	3691501	et	0	main
on	doc_769634019913_item	3691502	et	0	main
tavaline	doc_769634019913_item	3691503	et	0	main
linn	doc_769634019913_item	3691504	et	0	main
majadega	doc_769634019913_item	3691505	et	0	main
ja	doc_769634019913_item	3691506	et	0	main
ääres	doc_769634019913_item	3691507	et	0	main
on	doc_769634019913_item	3691508	et	0	main
järved	doc_769634019913_item	3691509	et	0	main
ja	doc_769634019913_item	3691510	et	0	main
põllud	doc_769634019913_item	3691511	et	0	main
hetkel	doc_769634019913_item	3691512	et	0	main
elan	doc_769634019913_item	3691513	et	0	main
ma	doc_769634019913_item	3691514	et	0	main
göttingenis	doc_769634019913_item	3691515	et	0	main
kui	doc_769634019913_item	3691516	et	0	main
ma	doc_769634019913_item	3691517	et	0	main
võrdlen	doc_769634019913_item	3691518	et	0	main
göttingen	doc_769634019913_item	3691519	et	0	main
ja	doc_769634019913_item	3691520	et	0	main
teised	doc_769634019913_item	3691521	et	0	main
kohad	doc_769634019913_item	3691522	et	0	main
kus	doc_769634019913_item	3691523	et	0	main
ma	doc_769634019913_item	3691524	et	0	main
elanud	doc_769634019913_item	3691525	et	0	main
olen	doc_769634019913_item	3691526	et	0	main
on	doc_769634019913_item	3691527	et	0	main
see	doc_769634019913_item	3691528	et	0	main
suur	doc_769634019913_item	3691529	et	0	main
linn	doc_769634019913_item	3691530	et	0	main
aga	doc_769634019913_item	3691531	et	0	main
tegelikult	doc_769634019913_item	3691532	et	0	main
ei	doc_769634019913_item	3691533	et	0	main
ole	doc_769634019913_item	3691534	et	0	main
nii	doc_769634019913_item	3691535	et	0	main
suur	doc_769634019913_item	3691536	et	0	main
göttingeni	doc_769634019913_item	3691537	et	0	main
kesklinnas	doc_769634019913_item	3691538	et	0	main
on	doc_769634019913_item	3691539	et	0	main
vanad	doc_769634019913_item	3691540	et	0	main
majad	doc_769634019913_item	3691541	et	0	main
ja	doc_769634019913_item	3691542	et	0	main
alati	doc_769634019913_item	3691543	et	0	main
palju	doc_769634019913_item	3691544	et	0	main
noori	doc_769634019913_item	3691545	et	0	main
inimesi	doc_769634019913_item	3691546	et	0	main
väga	doc_769634019913_item	3691547	et	0	main
tuttav	doc_769634019913_item	3691548	et	0	main
on	doc_769634019913_item	3691549	et	0	main
göttingeni	doc_769634019913_item	3691550	et	0	main
ülikool	doc_769634019913_item	3691551	et	0	main
kuna	doc_769634019913_item	3691552	et	0	main
göttingenis	doc_769634019913_item	3691553	et	0	main
on	doc_769634019913_item	3691554	et	0	main
palju	doc_769634019913_item	3691555	et	0	main
üliõpilasi	doc_769634019913_item	3691556	et	0	main
on	doc_769634019913_item	3691557	et	0	main
siin	doc_769634019913_item	3691558	et	0	main
natuke	doc_769634019913_item	3691559	et	0	main
tartupärane	doc_769634019913_item	3691560	et	0	main
kokkuvõtteks	doc_769634019913_item	3691561	et	0	main
saan	doc_769634019913_item	3691562	et	0	main
ma	doc_769634019913_item	3691563	et	0	main
ütelda	doc_769634019913_item	3691564	et	0	main
et	doc_769634019913_item	3691565	et	0	main
elamisel	doc_769634019913_item	3691566	et	0	main
nii	doc_769634019913_item	3691567	et	0	main
maal	doc_769634019913_item	3691568	et	0	main
kui	doc_769634019913_item	3691569	et	0	main
ka	doc_769634019913_item	3691570	et	0	main
linnas	doc_769634019913_item	3691571	et	0	main
on	doc_769634019913_item	3691572	et	0	main
eelised	doc_769634019913_item	3691573	et	0	main
ja	doc_769634019913_item	3691574	et	0	main
halvemused	doc_769634019913_item	3691575	et	0	main
linnas	doc_769634019913_item	3691576	et	0	main
on	doc_769634019913_item	3691577	et	0	main
lihtsam	doc_769634019913_item	3691578	et	0	main
ühest	doc_769634019913_item	3691579	et	0	main
punktist	doc_769634019913_item	3691580	et	0	main
teisesse	doc_769634019913_item	3691581	et	0	main
punktisse	doc_769634019913_item	3691582	et	0	main
tulla	doc_769634019913_item	3691583	et	0	main
sest	doc_769634019913_item	3691584	et	0	main
terve	doc_769634019913_item	3691585	et	0	main
transpordistruktuur	doc_769634019913_item	3691586	et	0	main
on	doc_769634019913_item	3691587	et	0	main
parem	doc_769634019913_item	3691588	et	0	main
kui	doc_769634019913_item	3691589	et	0	main
maal	doc_769634019913_item	3691590	et	0	main
linnades	doc_769634019913_item	3691591	et	0	main
on	doc_769634019913_item	3691592	et	0	main
kinod	doc_769634019913_item	3691593	et	0	main
ja	doc_769634019913_item	3691594	et	0	main
teaterid	doc_769634019913_item	3691595	et	0	main
spordikeskused	doc_769634019913_item	3691596	et	0	main
ujulad	doc_769634019913_item	3691597	et	0	main
baarid	doc_769634019913_item	3691598	et	0	main
restoranid	doc_769634019913_item	3691599	et	0	main
muuseumid	doc_769634019913_item	3691600	et	0	main
jne	doc_769634019913_item	3691601	et	0	main
kõikjal	doc_769634019913_item	3691602	et	0	main
on	doc_769634019913_item	3691603	et	0	main
poed	doc_769634019913_item	3691604	et	0	main
ja	doc_769634019913_item	3691605	et	0	main
peod	doc_769634019913_item	3691606	et	0	main
ja	doc_769634019913_item	3691607	et	0	main
elu	doc_769634019913_item	3691608	et	0	main
ei	doc_769634019913_item	3691609	et	0	main
saa	doc_769634019913_item	3691610	et	0	main
igaveks	doc_769634019913_item	3691611	et	0	main
muuta	doc_769634019913_item	3691612	et	0	main
veel	doc_769634019913_item	3691613	et	0	main
saab	doc_769634019913_item	3691614	et	0	main
linnas	doc_769634019913_item	3691615	et	0	main
sõpru	doc_769634019913_item	3691616	et	0	main
leida	doc_769634019913_item	3691617	et	0	main
kellega	doc_769634019913_item	3691618	et	0	main
midagi	doc_769634019913_item	3691619	et	0	main
teha	doc_769634019913_item	3691620	et	0	main
saab	doc_769634019913_item	3691621	et	0	main
maal	doc_769634019913_item	3691622	et	0	main
elada	doc_769634019913_item	3691623	et	0	main
on	doc_769634019913_item	3691624	et	0	main
teistmoodi	doc_769634019913_item	3691625	et	0	main
seal	doc_769634019913_item	3691626	et	0	main
pole	doc_769634019913_item	3691627	et	0	main
palju	doc_769634019913_item	3691628	et	0	main
inimesi	doc_769634019913_item	3691629	et	0	main
ja	doc_769634019913_item	3691630	et	0	main
võibolla	doc_769634019913_item	3691631	et	0	main
on	doc_769634019913_item	3691632	et	0	main
tee	doc_769634019913_item	3691633	et	0	main
linna	doc_769634019913_item	3691634	et	0	main
liiga	doc_769634019913_item	3691635	et	0	main
pikk	doc_769634019913_item	3691636	et	0	main
et	doc_769634019913_item	3691637	et	0	main
ei	doc_769634019913_item	3691638	et	0	main
saa	doc_769634019913_item	3691639	et	0	main
iga	doc_769634019913_item	3691640	et	0	main
päev	doc_769634019913_item	3691641	et	0	main
linnas	doc_769634019913_item	3691642	et	0	main
käia	doc_769634019913_item	3691643	et	0	main
on	doc_769634019913_item	3691644	et	0	main
muidugi	doc_769634019913_item	3691645	et	0	main
ka	doc_769634019913_item	3691646	et	0	main
raske	doc_769634019913_item	3691647	et	0	main
kui	doc_769634019913_item	3691648	et	0	main
autot	doc_769634019913_item	3691649	et	0	main
ei	doc_769634019913_item	3691650	et	0	main
ole	doc_769634019913_item	3691651	et	0	main
sest	doc_769634019913_item	3691652	et	0	main
autota	doc_769634019913_item	3691653	et	0	main
on	doc_769634019913_item	3691654	et	0	main
halb	doc_769634019913_item	3691655	et	0	main
suureid	doc_769634019913_item	3691656	et	0	main
sisseosteid	doc_769634019913_item	3691657	et	0	main
teha	doc_769634019913_item	3691658	et	0	main
või	doc_769634019913_item	3691659	et	0	main
spontaanselt	doc_769634019913_item	3691660	et	0	main
kuhugi	doc_769634019913_item	3691661	et	0	main
sõita	doc_769634019913_item	3691662	et	0	main
aga	doc_769634019913_item	3691663	et	0	main
maa	doc_769634019913_item	3691664	et	0	main
eelised	doc_769634019913_item	3691665	et	0	main
on	doc_769634019913_item	3691666	et	0	main
ka	doc_769634019913_item	3691667	et	0	main
näiteks	doc_769634019913_item	3691668	et	0	main
saab	doc_769634019913_item	3691669	et	0	main
omas	doc_769634019913_item	3691670	et	0	main
majas	doc_769634019913_item	3691671	et	0	main
või	doc_769634019913_item	3691672	et	0	main
talus	doc_769634019913_item	3691673	et	0	main
alati	doc_769634019913_item	3691674	et	0	main
see	doc_769634019913_item	3691675	et	0	main
teha	doc_769634019913_item	3691676	et	0	main
mis	doc_769634019913_item	3691677	et	0	main
meeldib	doc_769634019913_item	3691678	et	0	main
ja	doc_769634019913_item	3691679	et	0	main
millal	doc_769634019913_item	3691680	et	0	main
meeldib	doc_769634019913_item	3691681	et	0	main
maal	doc_769634019913_item	3691682	et	0	main
on	doc_769634019913_item	3691683	et	0	main
ka	doc_769634019913_item	3691684	et	0	main
vaiksem	doc_769634019913_item	3691685	et	0	main
kui	doc_769634019913_item	3691686	et	0	main
linnas	doc_769634019913_item	3691687	et	0	main
võibolla	doc_769634019913_item	3691688	et	0	main
oleks	doc_769634019913_item	3691689	et	0	main
hea	doc_769634019913_item	3691690	et	0	main
mõte	doc_769634019913_item	3691691	et	0	main
maal	doc_769634019913_item	3691692	et	0	main
elada	doc_769634019913_item	3691693	et	0	main
ja	doc_769634019913_item	3691694	et	0	main
linnas	doc_769634019913_item	3691695	et	0	main
töötada	doc_769634019913_item	3691696	et	0	main
niimoodi	doc_769634019913_item	3691697	et	0	main
oleks	doc_769634019913_item	3691698	et	0	main
võimalik	doc_769634019913_item	3691699	et	0	main
iga	doc_769634019913_item	3691700	et	0	main
päev	doc_769634019913_item	3691701	et	0	main
inimesi	doc_769634019913_item	3691702	et	0	main
linnas	doc_769634019913_item	3691703	et	0	main
kohtuda	doc_769634019913_item	3691704	et	0	main
ja	doc_769634019913_item	3691705	et	0	main
linna	doc_769634019913_item	3691706	et	0	main
eeliseid	doc_769634019913_item	3691707	et	0	main
kasutada	doc_769634019913_item	3691708	et	0	main
ja	doc_769634019913_item	3691709	et	0	main
õhtul	doc_769634019913_item	3691710	et	0	main
või	doc_769634019913_item	3691711	et	0	main
nädalavahetusel	doc_769634019913_item	3691712	et	0	main
saaks	doc_769634019913_item	3691713	et	0	main
rahulikem	doc_769634019913_item	3691714	et	0	main
olla	doc_769634019913_item	3691715	et	0	main
essee	doc_278690626941_item	3691716	et	0	main
eesti	doc_278690626941_item	3691717	et	0	main
keele	doc_278690626941_item	3691718	et	0	main
kui	doc_278690626941_item	3691719	et	0	main
teise	doc_278690626941_item	3691720	et	0	main
keele	doc_278690626941_item	3691721	et	0	main
test	doc_278690626941_item	3691722	et	0	main
kirjutamine	doc_278690626941_item	3691723	et	0	main
kirjutage	doc_278690626941_item	3691724	et	0	main
essee	doc_278690626941_item	3691725	et	0	main
teemal	doc_278690626941_item	3691726	et	0	main
mis	doc_278690626941_item	3691727	et	0	main
teeb	doc_278690626941_item	3691728	et	0	main
eestlastest	doc_278690626941_item	3691729	et	0	main
laulurahva	doc_278690626941_item	3691730	et	0	main
essee	doc_278690626941_item	3691731	et	0	main
pikkus	doc_278690626941_item	3691732	et	0	main
300	doc_278690626941_item	3691733	et	0	main
350	doc_278690626941_item	3691734	et	0	main
sõna	doc_278690626941_item	3691735	et	0	main
essee	doc_278690626941_item	3691736	et	0	main
peab	doc_278690626941_item	3691737	et	0	main
olema	doc_278690626941_item	3691738	et	0	main
arutlev	doc_278690626941_item	3691739	et	0	main
analüüsiv	doc_278690626941_item	3691740	et	0	main
ja	doc_278690626941_item	3691741	et	0	main
üldistav	doc_278690626941_item	3691742	et	0	main
tuginema	doc_278690626941_item	3691743	et	0	main
loengus	doc_278690626941_item	3691744	et	0	main
ja	doc_278690626941_item	3691745	et	0	main
lugemistekstis	doc_278690626941_item	3691746	et	0	main
esitatud	doc_278690626941_item	3691747	et	0	main
faktidele	doc_278690626941_item	3691748	et	0	main
väiteid	doc_278690626941_item	3691749	et	0	main
on	doc_278690626941_item	3691750	et	0	main
soovitatav	doc_278690626941_item	3691751	et	0	main
illustreerida	doc_278690626941_item	3691752	et	0	main
näidetega	doc_278690626941_item	3691753	et	0	main
juba	doc_278690626941_item	3691754	et	0	main
vanasti	doc_278690626941_item	3691755	et	0	main
laulmine	doc_278690626941_item	3691756	et	0	main
oli	doc_278690626941_item	3691757	et	0	main
esteetiline	doc_278690626941_item	3691758	et	0	main
ja	doc_278690626941_item	3691759	et	0	main
emotsionaalne	doc_278690626941_item	3691760	et	0	main
väljendusvahend	doc_278690626941_item	3691761	et	0	main
aga	doc_278690626941_item	3691762	et	0	main
ka	doc_278690626941_item	3691763	et	0	main
sootsialne	doc_278690626941_item	3691764	et	0	main
tegevus	doc_278690626941_item	3691765	et	0	main
nad	doc_278690626941_item	3691766	et	0	main
kasutasid	doc_278690626941_item	3691767	et	0	main
laulud	doc_278690626941_item	3691768	et	0	main
kui	doc_278690626941_item	3691769	et	0	main
nad	doc_278690626941_item	3691770	et	0	main
oli	doc_278690626941_item	3691771	et	0	main
töö	doc_278690626941_item	3691772	et	0	main
näitek	doc_278690626941_item	3691773	et	0	main
põllul	doc_278690626941_item	3691774	et	0	main
või	doc_278690626941_item	3691775	et	0	main
kodus	doc_278690626941_item	3691776	et	0	main
ka	doc_278690626941_item	3691777	et	0	main
vanasti	doc_278690626941_item	3691778	et	0	main
rohkem	doc_278690626941_item	3691779	et	0	main
laulasid	doc_278690626941_item	3691780	et	0	main
naised	doc_278690626941_item	3691781	et	0	main
aga	doc_278690626941_item	3691782	et	0	main
mehed	doc_278690626941_item	3691783	et	0	main
ka	doc_278690626941_item	3691784	et	0	main
laulasid	doc_278690626941_item	3691785	et	0	main
pulma	doc_278690626941_item	3691786	et	0	main
laulu	doc_278690626941_item	3691787	et	0	main
siit	doc_278690626941_item	3691788	et	0	main
me	doc_278690626941_item	3691789	et	0	main
näeme	doc_278690626941_item	3691790	et	0	main
et	doc_278690626941_item	3691791	et	0	main
see	doc_278690626941_item	3691792	et	0	main
on	doc_278690626941_item	3691793	et	0	main
väga	doc_278690626941_item	3691794	et	0	main
oluline	doc_278690626941_item	3691795	et	0	main
et	doc_278690626941_item	3691796	et	0	main
elus	doc_278690626941_item	3691797	et	0	main
oli	doc_278690626941_item	3691798	et	0	main
laulmine	doc_278690626941_item	3691799	et	0	main
ristiusuga	doc_278690626941_item	3691800	et	0	main
kaasnes	doc_278690626941_item	3691801	et	0	main
vaimulike	doc_278690626941_item	3691802	et	0	main
laulude	doc_278690626941_item	3691803	et	0	main
laulmine	doc_278690626941_item	3691804	et	0	main
kirikus	doc_278690626941_item	3691805	et	0	main
see	doc_278690626941_item	3691806	et	0	main
hakkas	doc_278690626941_item	3691807	et	0	main
1800	doc_278690626941_item	3691808	et	0	main
sajandil	doc_278690626941_item	3691809	et	0	main
seal	doc_278690626941_item	3691810	et	0	main
nad	doc_278690626941_item	3691811	et	0	main
laulasid	doc_278690626941_item	3691812	et	0	main
üksinda	doc_278690626941_item	3691813	et	0	main
või	doc_278690626941_item	3691814	et	0	main
ka	doc_278690626941_item	3691815	et	0	main
kooriga	doc_278690626941_item	3691816	et	0	main
vanema	doc_278690626941_item	3691817	et	0	main
ja	doc_278690626941_item	3691818	et	0	main
euroopas	doc_278690626941_item	3691819	et	0	main
laenatud	doc_278690626941_item	3691820	et	0	main
laulutraditsiooni	doc_278690626941_item	3691821	et	0	main
koosmõju	doc_278690626941_item	3691822	et	0	main
lõi	doc_278690626941_item	3691823	et	0	main
1900	doc_278690626941_item	3691824	et	0	main
sajandil	doc_278690626941_item	3691825	et	0	main
eeldused	doc_278690626941_item	3691826	et	0	main
uue	doc_278690626941_item	3691827	et	0	main
riimilise	doc_278690626941_item	3691828	et	0	main
rahvalaulu	doc_278690626941_item	3691829	et	0	main
tekkes	doc_278690626941_item	3691830	et	0	main
need	doc_278690626941_item	3691831	et	0	main
laulud	doc_278690626941_item	3691832	et	0	main
on	doc_278690626941_item	3691833	et	0	main
välja	doc_278690626941_item	3691834	et	0	main
kujunenud	doc_278690626941_item	3691835	et	0	main
euroopa	doc_278690626941_item	3691836	et	0	main
muusika	doc_278690626941_item	3691837	et	0	main
eelkõige	doc_278690626941_item	3691838	et	0	main
saksa	doc_278690626941_item	3691839	et	0	main
aga	doc_278690626941_item	3691840	et	0	main
ka	doc_278690626941_item	3691841	et	0	main
rootsi	doc_278690626941_item	3691842	et	0	main
või	doc_278690626941_item	3691843	et	0	main
soome	doc_278690626941_item	3691844	et	0	main
või	doc_278690626941_item	3691845	et	0	main
slaavi	doc_278690626941_item	3691846	et	0	main
muusika	doc_278690626941_item	3691847	et	0	main
mõjul	doc_278690626941_item	3691848	et	0	main
ajaloolise	doc_278690626941_item	3691849	et	0	main
tähtsusega	doc_278690626941_item	3691850	et	0	main
sundmuseks	doc_278690626941_item	3691851	et	0	main
kujunes	doc_278690626941_item	3691852	et	0	main
esimene	doc_278690626941_item	3691853	et	0	main
ülemaalne	doc_278690626941_item	3691854	et	0	main
laulupidu	doc_278690626941_item	3691855	et	0	main
1869	doc_278690626941_item	3691856	et	0	main
aastal	doc_278690626941_item	3691857	et	0	main
tartus	doc_278690626941_item	3691858	et	0	main
idee	doc_278690626941_item	3691859	et	0	main
ja	doc_278690626941_item	3691860	et	0	main
teostus	doc_278690626941_item	3691861	et	0	main
tuli	doc_278690626941_item	3691862	et	0	main
vanemuise	doc_278690626941_item	3691863	et	0	main
seltsist	doc_278690626941_item	3691864	et	0	main
eesotsas	doc_278690626941_item	3691865	et	0	main
johann	doc_278690626941_item	3691866	et	0	main
voldemar	doc_278690626941_item	3691867	et	0	main
jannseniga	doc_278690626941_item	3691868	et	0	main
peol	doc_278690626941_item	3691869	et	0	main
osales	doc_278690626941_item	3691870	et	0	main
822	doc_278690626941_item	3691871	et	0	main
laulja	doc_278690626941_item	3691872	et	0	main
46	doc_278690626941_item	3691873	et	0	main
meeskoori	doc_278690626941_item	3691874	et	0	main
56	doc_278690626941_item	3691875	et	0	main
mängijaga	doc_278690626941_item	3691876	et	0	main
ja	doc_278690626941_item	3691877	et	0	main
5	doc_278690626941_item	3691878	et	0	main
puhkpilliorkestrit	doc_278690626941_item	3691879	et	0	main
see	doc_278690626941_item	3691880	et	0	main
oli	doc_278690626941_item	3691881	et	0	main
esimen	doc_278690626941_item	3691882	et	0	main
suur	doc_278690626941_item	3691883	et	0	main
ja	doc_278690626941_item	3691884	et	0	main
väga	doc_278690626941_item	3691885	et	0	main
tähtis	doc_278690626941_item	3691886	et	0	main
moment	doc_278690626941_item	3691887	et	0	main
nendele	doc_278690626941_item	3691888	et	0	main
kes	doc_278690626941_item	3691889	et	0	main
osales	doc_278690626941_item	3691890	et	0	main
ja	doc_278690626941_item	3691891	et	0	main
lihtsalt	doc_278690626941_item	3691892	et	0	main
eestile	doc_278690626941_item	3691893	et	0	main
ja	doc_278690626941_item	3691894	et	0	main
eesti	doc_278690626941_item	3691895	et	0	main
kuulturiosanadele	doc_278690626941_item	3691896	et	0	main
pärast	doc_278690626941_item	3691897	et	0	main
eesti	doc_278690626941_item	3691898	et	0	main
vabarigi	doc_278690626941_item	3691899	et	0	main
loomist	doc_278690626941_item	3691900	et	0	main
1918	doc_278690626941_item	3691901	et	0	main
aastal	doc_278690626941_item	3691902	et	0	main
ja	doc_278690626941_item	3691903	et	0	main
vabadussõda	doc_278690626941_item	3691904	et	0	main
muutusid	doc_278690626941_item	3691905	et	0	main
laulupeod	doc_278690626941_item	3691906	et	0	main
muusika	doc_278690626941_item	3691907	et	0	main
suurüritusteks	doc_278690626941_item	3691908	et	0	main
mis	doc_278690626941_item	3691909	et	0	main
toimusid	doc_278690626941_item	3691910	et	0	main
kadriorus	doc_278690626941_item	3691911	et	0	main
praegusel	doc_278690626941_item	3691912	et	0	main
lauluväljakul	doc_278690626941_item	3691913	et	0	main
1928	doc_278690626941_item	3691914	et	0	main
1980	doc_278690626941_item	3691915	et	0	main
aasta	doc_278690626941_item	3691916	et	0	main
lõpus	doc_278690626941_item	3691917	et	0	main
alanud	doc_278690626941_item	3691918	et	0	main
teise	doc_278690626941_item	3691919	et	0	main
teise	doc_278690626941_item	3691920	et	0	main
ärkamisaja	doc_278690626941_item	3691921	et	0	main
julis	doc_278690626941_item	3691922	et	0	main
kogunesid	doc_278690626941_item	3691923	et	0	main
tuhanded	doc_278690626941_item	3691924	et	0	main
lauljad	doc_278690626941_item	3691925	et	0	main
tallinna	doc_278690626941_item	3691926	et	0	main
lauluväljakule	doc_278690626941_item	3691927	et	0	main
laulupeole	doc_278690626941_item	3691928	et	0	main
et	doc_278690626941_item	3691929	et	0	main
tähistada	doc_278690626941_item	3691930	et	0	main
kestnud	doc_278690626941_item	3691931	et	0	main
laulupidude	doc_278690626941_item	3691932	et	0	main
traditsioon	doc_278690626941_item	3691933	et	0	main
siin	doc_278690626941_item	3691934	et	0	main
võtsid	doc_278690626941_item	3691935	et	0	main
osa	doc_278690626941_item	3691936	et	0	main
väga	doc_278690626941_item	3691937	et	0	main
palju	doc_278690626941_item	3691938	et	0	main
lauljat	doc_278690626941_item	3691939	et	0	main
esinejat	doc_278690626941_item	3691940	et	0	main
jne	doc_278690626941_item	3691941	et	0	main
sellel	doc_278690626941_item	3691942	et	0	main
pidul	doc_278690626941_item	3691943	et	0	main
oli	doc_278690626941_item	3691944	et	0	main
üle	doc_278690626941_item	3691945	et	0	main
200	doc_278690626941_item	3691946	et	0	main
000	doc_278690626941_item	3691947	et	0	main
tuhad	doc_278690626941_item	3691948	et	0	main
inimesed	doc_278690626941_item	3691949	et	0	main
see	doc_278690626941_item	3691950	et	0	main
kõik	doc_278690626941_item	3691951	et	0	main
näitab	doc_278690626941_item	3691952	et	0	main
et	doc_278690626941_item	3691953	et	0	main
kõik	doc_278690626941_item	3691954	et	0	main
laulupidu	doc_278690626941_item	3691955	et	0	main
suur	doc_278690626941_item	3691956	et	0	main
laulu	doc_278690626941_item	3691957	et	0	main
ajalugu	doc_278690626941_item	3691958	et	0	main
ja	doc_278690626941_item	3691959	et	0	main
palju	doc_278690626941_item	3691960	et	0	main
muut	doc_278690626941_item	3691961	et	0	main
asjad	doc_278690626941_item	3691962	et	0	main
teeb	doc_278690626941_item	3691963	et	0	main
eestlastest	doc_278690626941_item	3691964	et	0	main
laulurahva	doc_278690626941_item	3691965	et	0	main
essee	doc_366216787906_item	3691966	et	0	main
eesti	doc_366216787906_item	3691967	et	0	main
keele	doc_366216787906_item	3691968	et	0	main
kui	doc_366216787906_item	3691969	et	0	main
teise	doc_366216787906_item	3691970	et	0	main
keele	doc_366216787906_item	3691971	et	0	main
test	doc_366216787906_item	3691972	et	0	main
kirjutamine	doc_366216787906_item	3691973	et	0	main
kirjutage	doc_366216787906_item	3691974	et	0	main
essee	doc_366216787906_item	3691975	et	0	main
teemal	doc_366216787906_item	3691976	et	0	main
mis	doc_366216787906_item	3691977	et	0	main
teeb	doc_366216787906_item	3691978	et	0	main
eestlastest	doc_366216787906_item	3691979	et	0	main
laulurahva	doc_366216787906_item	3691980	et	0	main
essee	doc_366216787906_item	3691981	et	0	main
pikkus	doc_366216787906_item	3691982	et	0	main
300	doc_366216787906_item	3691983	et	0	main
350	doc_366216787906_item	3691984	et	0	main
sõna	doc_366216787906_item	3691985	et	0	main
essee	doc_366216787906_item	3691986	et	0	main
peab	doc_366216787906_item	3691987	et	0	main
olema	doc_366216787906_item	3691988	et	0	main
arutlev	doc_366216787906_item	3691989	et	0	main
analüüsiv	doc_366216787906_item	3691990	et	0	main
ja	doc_366216787906_item	3691991	et	0	main
üldistav	doc_366216787906_item	3691992	et	0	main
tuginema	doc_366216787906_item	3691993	et	0	main
loengus	doc_366216787906_item	3691994	et	0	main
ja	doc_366216787906_item	3691995	et	0	main
lugemistekstis	doc_366216787906_item	3691996	et	0	main
esitatud	doc_366216787906_item	3691997	et	0	main
faktidele	doc_366216787906_item	3691998	et	0	main
väiteid	doc_366216787906_item	3691999	et	0	main
on	doc_366216787906_item	3692000	et	0	main
soovitatav	doc_366216787906_item	3692001	et	0	main
illustreerida	doc_366216787906_item	3692002	et	0	main
näidetega	doc_366216787906_item	3692003	et	0	main
laulurahva	doc_366216787906_item	3692004	et	0	main
laul	doc_366216787906_item	3692005	et	0	main
on	doc_366216787906_item	3692006	et	0	main
eestlaste	doc_366216787906_item	3692007	et	0	main
kultuuriidentiteet	doc_366216787906_item	3692008	et	0	main
ja	doc_366216787906_item	3692009	et	0	main
laulutraditsioon	doc_366216787906_item	3692010	et	0	main
vanal	doc_366216787906_item	3692011	et	0	main
ajal	doc_366216787906_item	3692012	et	0	main
eestlased	doc_366216787906_item	3692013	et	0	main
kasutasid	doc_366216787906_item	3692014	et	0	main
laulu	doc_366216787906_item	3692015	et	0	main
töötades	doc_366216787906_item	3692016	et	0	main
pulmades	doc_366216787906_item	3692017	et	0	main
mängudes	doc_366216787906_item	3692018	et	0	main
tantsudes	doc_366216787906_item	3692019	et	0	main
ja	doc_366216787906_item	3692020	et	0	main
mõnedes	doc_366216787906_item	3692021	et	0	main
tegevuses	doc_366216787906_item	3692022	et	0	main
kui	doc_366216787906_item	3692023	et	0	main
see	doc_366216787906_item	3692024	et	0	main
oli	doc_366216787906_item	3692025	et	0	main
seotud	doc_366216787906_item	3692026	et	0	main
lauluga	doc_366216787906_item	3692027	et	0	main
kõige	doc_366216787906_item	3692028	et	0	main
oluline	doc_366216787906_item	3692029	et	0	main
oli	doc_366216787906_item	3692030	et	0	main
see	doc_366216787906_item	3692031	et	0	main
aeg	doc_366216787906_item	3692032	et	0	main
mis	doc_366216787906_item	3692033	et	0	main
andis	doc_366216787906_item	3692034	et	0	main
edasi	doc_366216787906_item	3692035	et	0	main
rohkem	doc_366216787906_item	3692036	et	0	main
arendada	doc_366216787906_item	3692037	et	0	main
rahvalaulu	doc_366216787906_item	3692038	et	0	main
see	doc_366216787906_item	3692039	et	0	main
oli	doc_366216787906_item	3692040	et	0	main
esimene	doc_366216787906_item	3692041	et	0	main
rahvalaulupidu	doc_366216787906_item	3692042	et	0	main
korraldas	doc_366216787906_item	3692043	et	0	main
seda	doc_366216787906_item	3692044	et	0	main
j	doc_366216787906_item	3692045	et	0	main
jannsen	doc_366216787906_item	3692046	et	0	main
ta	doc_366216787906_item	3692047	et	0	main
kogunes	doc_366216787906_item	3692048	et	0	main
eestis	doc_366216787906_item	3692049	et	0	main
kõi	doc_366216787906_item	3692050	et	0	main
lauluseltsid	doc_366216787906_item	3692051	et	0	main
ja	doc_366216787906_item	3692052	et	0	main
tegi	doc_366216787906_item	3692053	et	0	main
esimene	doc_366216787906_item	3692054	et	0	main
laulurahvapidu	doc_366216787906_item	3692055	et	0	main
1869	doc_366216787906_item	3692056	et	0	main
a	doc_366216787906_item	3692057	et	0	main
tartus	doc_366216787906_item	3692058	et	0	main
muidugi	doc_366216787906_item	3692059	et	0	main
eestlastel	doc_366216787906_item	3692060	et	0	main
oli	doc_366216787906_item	3692061	et	0	main
raske	doc_366216787906_item	3692062	et	0	main
teha	doc_366216787906_item	3692063	et	0	main
niisugused	doc_366216787906_item	3692064	et	0	main
suured	doc_366216787906_item	3692065	et	0	main
üritused	doc_366216787906_item	3692066	et	0	main
sest	doc_366216787906_item	3692067	et	0	main
tol	doc_366216787906_item	3692068	et	0	main
ajal	doc_366216787906_item	3692069	et	0	main
nad	doc_366216787906_item	3692070	et	0	main
ei	doc_366216787906_item	3692071	et	0	main
olnud	doc_366216787906_item	3692072	et	0	main
veel	doc_366216787906_item	3692073	et	0	main
iseseisvad	doc_366216787906_item	3692074	et	0	main
ja	doc_366216787906_item	3692075	et	0	main
vabad	doc_366216787906_item	3692076	et	0	main
nende	doc_366216787906_item	3692077	et	0	main
peal	doc_366216787906_item	3692078	et	0	main
oli	doc_366216787906_item	3692079	et	0	main
suur	doc_366216787906_item	3692080	et	0	main
jälgimine	doc_366216787906_item	3692081	et	0	main
ja	doc_366216787906_item	3692082	et	0	main
kontrollimine	doc_366216787906_item	3692083	et	0	main
nõukogude	doc_366216787906_item	3692084	et	0	main
kommunistliku	doc_366216787906_item	3692085	et	0	main
poolt	doc_366216787906_item	3692086	et	0	main
aga	doc_366216787906_item	3692087	et	0	main
ei	doc_366216787906_item	3692088	et	0	main
pane	doc_366216787906_item	3692089	et	0	main
tähele	doc_366216787906_item	3692090	et	0	main
sellele	doc_366216787906_item	3692091	et	0	main
eesti	doc_366216787906_item	3692092	et	0	main
rahv	doc_366216787906_item	3692093	et	0	main
ikkagi	doc_366216787906_item	3692094	et	0	main
kogunes	doc_366216787906_item	3692095	et	0	main
laulis	doc_366216787906_item	3692096	et	0	main
tantsis	doc_366216787906_item	3692097	et	0	main
ja	doc_366216787906_item	3692098	et	0	main
rõõmustas	doc_366216787906_item	3692099	et	0	main
praegu	doc_366216787906_item	3692100	et	0	main
ei	doc_366216787906_item	3692101	et	0	main
ole	doc_366216787906_item	3692102	et	0	main
niisugune	doc_366216787906_item	3692103	et	0	main
aeg	doc_366216787906_item	3692104	et	0	main
mis	doc_366216787906_item	3692105	et	0	main
oli	doc_366216787906_item	3692106	et	0	main
15	doc_366216787906_item	3692107	et	0	main
aastad	doc_366216787906_item	3692108	et	0	main
tagasi	doc_366216787906_item	3692109	et	0	main
eesti	doc_366216787906_item	3692110	et	0	main
on	doc_366216787906_item	3692111	et	0	main
iseseisev	doc_366216787906_item	3692112	et	0	main
riik	doc_366216787906_item	3692113	et	0	main
ja	doc_366216787906_item	3692114	et	0	main
kõik	doc_366216787906_item	3692115	et	0	main
on	doc_366216787906_item	3692116	et	0	main
juba	doc_366216787906_item	3692117	et	0	main
muutunud	doc_366216787906_item	3692118	et	0	main
väljaarvatud	doc_366216787906_item	3692119	et	0	main
eesti	doc_366216787906_item	3692120	et	0	main
kultuuridentiteet	doc_366216787906_item	3692121	et	0	main
ja	doc_366216787906_item	3692122	et	0	main
laulutraditsioon	doc_366216787906_item	3692123	et	0	main
see	doc_366216787906_item	3692124	et	0	main
jaab	doc_366216787906_item	3692125	et	0	main
samaks	doc_366216787906_item	3692126	et	0	main
mis	doc_366216787906_item	3692127	et	0	main
oli	doc_366216787906_item	3692128	et	0	main
ammu	doc_366216787906_item	3692129	et	0	main
aastad	doc_366216787906_item	3692130	et	0	main
tagasi	doc_366216787906_item	3692131	et	0	main
noored	doc_366216787906_item	3692132	et	0	main
inimesed	doc_366216787906_item	3692133	et	0	main
praegu	doc_366216787906_item	3692134	et	0	main
ei	doc_366216787906_item	3692135	et	0	main
tunne	doc_366216787906_item	3692136	et	0	main
huvi	doc_366216787906_item	3692137	et	0	main
vanades	doc_366216787906_item	3692138	et	0	main
rahvalauludest	doc_366216787906_item	3692139	et	0	main
ja	doc_366216787906_item	3692140	et	0	main
kultuuridest	doc_366216787906_item	3692141	et	0	main
aga	doc_366216787906_item	3692142	et	0	main
sellepärast	doc_366216787906_item	3692143	et	0	main
on	doc_366216787906_item	3692144	et	0	main
meil	doc_366216787906_item	3692145	et	0	main
eestil	doc_366216787906_item	3692146	et	0	main
paljud	doc_366216787906_item	3692147	et	0	main
muuseumid	doc_366216787906_item	3692148	et	0	main
ja	doc_366216787906_item	3692149	et	0	main
laulukooli	doc_366216787906_item	3692150	et	0	main
et	doc_366216787906_item	3692151	et	0	main
säilitada	doc_366216787906_item	3692152	et	0	main
vanalaulu	doc_366216787906_item	3692153	et	0	main
ja	doc_366216787906_item	3692154	et	0	main
kultuuri	doc_366216787906_item	3692155	et	0	main
mõned	doc_366216787906_item	3692156	et	0	main
poissid	doc_366216787906_item	3692157	et	0	main
ja	doc_366216787906_item	3692158	et	0	main
tüdrukud	doc_366216787906_item	3692159	et	0	main
muidugi	doc_366216787906_item	3692160	et	0	main
õppivad	doc_366216787906_item	3692161	et	0	main
laulu	doc_366216787906_item	3692162	et	0	main
ja	doc_366216787906_item	3692163	et	0	main
mõni	doc_366216787906_item	3692164	et	0	main
vanu	doc_366216787906_item	3692165	et	0	main
muusikapille	doc_366216787906_item	3692166	et	0	main
mina	doc_366216787906_item	3692167	et	0	main
arvan	doc_366216787906_item	3692168	et	0	main
et	doc_366216787906_item	3692169	et	0	main
eesti	doc_366216787906_item	3692170	et	0	main
rahv	doc_366216787906_item	3692171	et	0	main
peab	doc_366216787906_item	3692172	et	0	main
kindlasti	doc_366216787906_item	3692173	et	0	main
teadma	doc_366216787906_item	3692174	et	0	main
oma	doc_366216787906_item	3692175	et	0	main
ajaloost	doc_366216787906_item	3692176	et	0	main
kõik	doc_366216787906_item	3692177	et	0	main
ja	doc_366216787906_item	3692178	et	0	main
olema	doc_366216787906_item	3692179	et	0	main
uhke	doc_366216787906_item	3692180	et	0	main
selle	doc_366216787906_item	3692181	et	0	main
peale	doc_366216787906_item	3692182	et	0	main
et	doc_366216787906_item	3692183	et	0	main
nad	doc_366216787906_item	3692184	et	0	main
tegid	doc_366216787906_item	3692185	et	0	main
suurt	doc_366216787906_item	3692186	et	0	main
tööd	doc_366216787906_item	3692187	et	0	main
et	doc_366216787906_item	3692188	et	0	main
saavutada	doc_366216787906_item	3692189	et	0	main
niisugused	doc_366216787906_item	3692190	et	0	main
tulemused	doc_366216787906_item	3692191	et	0	main
see	doc_366216787906_item	3692192	et	0	main
ei	doc_366216787906_item	3692193	et	0	main
olnud	doc_366216787906_item	3692194	et	0	main
ka	doc_366216787906_item	3692195	et	0	main
nii	doc_366216787906_item	3692196	et	0	main
lihtne	doc_366216787906_item	3692197	et	0	main
teha	doc_366216787906_item	3692198	et	0	main
et	doc_366216787906_item	3692199	et	0	main
eesti	doc_366216787906_item	3692200	et	0	main
saaks	doc_366216787906_item	3692201	et	0	main
vabaks	doc_366216787906_item	3692202	et	0	main
aga	doc_366216787906_item	3692203	et	0	main
inimesed	doc_366216787906_item	3692204	et	0	main
uskusid	doc_366216787906_item	3692205	et	0	main
et	doc_366216787906_item	3692206	et	0	main
kui	doc_366216787906_item	3692207	et	0	main
nad	doc_366216787906_item	3692208	et	0	main
on	doc_366216787906_item	3692209	et	0	main
koos	doc_366216787906_item	3692210	et	0	main
siis	doc_366216787906_item	3692211	et	0	main
tuleb	doc_366216787906_item	3692212	et	0	main
nendel	doc_366216787906_item	3692213	et	0	main
palju	doc_366216787906_item	3692214	et	0	main
lihtsam	doc_366216787906_item	3692215	et	0	main
sellepärast	doc_366216787906_item	3692216	et	0	main
olid	doc_366216787906_item	3692217	et	0	main
organiiseeritud	doc_366216787906_item	3692218	et	0	main
suured	doc_366216787906_item	3692219	et	0	main
peod	doc_366216787906_item	3692220	et	0	main
näiteks	doc_366216787906_item	3692221	et	0	main
rahvalaulupidu	doc_366216787906_item	3692222	et	0	main
muidugi	doc_366216787906_item	3692223	et	0	main
eestlastel	doc_366216787906_item	3692224	et	0	main
ei	doc_366216787906_item	3692225	et	0	main
olnud	doc_366216787906_item	3692226	et	0	main
eesmärgiks	doc_366216787906_item	3692227	et	0	main
koos	doc_366216787906_item	3692228	et	0	main
olla	doc_366216787906_item	3692229	et	0	main
et	doc_366216787906_item	3692230	et	0	main
saata	doc_366216787906_item	3692231	et	0	main
vabaks	doc_366216787906_item	3692232	et	0	main
oli	doc_366216787906_item	3692233	et	0	main
oluline	doc_366216787906_item	3692234	et	0	main
põhjus	doc_366216787906_item	3692235	et	0	main
see	doc_366216787906_item	3692236	et	0	main
oli	doc_366216787906_item	3692237	et	0	main
see	doc_366216787906_item	3692238	et	0	main
et	doc_366216787906_item	3692239	et	0	main
kui	doc_366216787906_item	3692240	et	0	main
nad	doc_366216787906_item	3692241	et	0	main
olid	doc_366216787906_item	3692242	et	0	main
koos	doc_366216787906_item	3692243	et	0	main
siis	doc_366216787906_item	3692244	et	0	main
nendel	doc_366216787906_item	3692245	et	0	main
oli	doc_366216787906_item	3692246	et	0	main
suur	doc_366216787906_item	3692247	et	0	main
võim	doc_366216787906_item	3692248	et	0	main
ja	doc_366216787906_item	3692249	et	0	main
niimoodi	doc_366216787906_item	3692250	et	0	main
vaikselt	doc_366216787906_item	3692251	et	0	main
aastast	doc_366216787906_item	3692252	et	0	main
aastani	doc_366216787906_item	3692253	et	0	main
eesti	doc_366216787906_item	3692254	et	0	main
rahv	doc_366216787906_item	3692255	et	0	main
jõudis	doc_366216787906_item	3692256	et	0	main
selleni	doc_366216787906_item	3692257	et	0	main
et	doc_366216787906_item	3692258	et	0	main
vananõukogu	doc_366216787906_item	3692259	et	0	main
ei	doc_366216787906_item	3692260	et	0	main
saanud	doc_366216787906_item	3692261	et	0	main
üldse	doc_366216787906_item	3692262	et	0	main
kontrollima	doc_366216787906_item	3692263	et	0	main
inemisi	doc_366216787906_item	3692264	et	0	main
riikides	doc_366216787906_item	3692265	et	0	main
ja	doc_366216787906_item	3692266	et	0	main
paljud	doc_366216787906_item	3692267	et	0	main
teised	doc_366216787906_item	3692268	et	0	main
riigid	doc_366216787906_item	3692269	et	0	main
kasutasid	doc_366216787906_item	3692270	et	0	main
samuti	doc_366216787906_item	3692271	et	0	main
eesti	doc_366216787906_item	3692272	et	0	main
seda	doc_366216787906_item	3692273	et	0	main
võimalusi	doc_366216787906_item	3692274	et	0	main
eesti	doc_366216787906_item	3692275	et	0	main
rahvalaul	doc_366216787906_item	3692276	et	0	main
annab	doc_366216787906_item	3692277	et	0	main
iga	doc_366216787906_item	3692278	et	0	main
eestlastele	doc_366216787906_item	3692279	et	0	main
mälestusi	doc_366216787906_item	3692280	et	0	main
oma	doc_366216787906_item	3692281	et	0	main
rahvast	doc_366216787906_item	3692282	et	0	main
ja	doc_366216787906_item	3692283	et	0	main
suure	doc_366216787906_item	3692284	et	0	main
võimu	doc_366216787906_item	3692285	et	0	main
elada	doc_366216787906_item	3692286	et	0	main
edasi	doc_366216787906_item	3692287	et	0	main
kontrolltöö	doc_27046690324_item	3692288	et	0	main
1	doc_27046690324_item	3692289	et	0	main
iseloomustage	doc_27046690324_item	3692290	et	0	main
1970	doc_27046690324_item	3692291	et	0	main
1980	doc_27046690324_item	3692292	et	0	main
a-te	doc_27046690324_item	3692293	et	0	main
eesti	doc_27046690324_item	3692294	et	0	main
kultuurielu	doc_27046690324_item	3692295	et	0	main
2	doc_27046690324_item	3692296	et	0	main
nn	doc_27046690324_item	3692297	et	0	main
öölaulupidude	doc_27046690324_item	3692298	et	0	main
ja	doc_27046690324_item	3692299	et	0	main
laulva	doc_27046690324_item	3692300	et	0	main
revolutsiooni	doc_27046690324_item	3692301	et	0	main
osa	doc_27046690324_item	3692302	et	0	main
eesti	doc_27046690324_item	3692303	et	0	main
taasiseseisvumisel	doc_27046690324_item	3692304	et	0	main
3	doc_27046690324_item	3692305	et	0	main
sõnade	doc_27046690324_item	3692306	et	0	main
perestroika	doc_27046690324_item	3692307	et	0	main
ja	doc_27046690324_item	3692308	et	0	main
glasnostj	doc_27046690324_item	3692309	et	0	main
tähendus	doc_27046690324_item	3692310	et	0	main
ja	doc_27046690324_item	3692311	et	0	main
sisu	doc_27046690324_item	3692312	et	0	main
1	doc_27046690324_item	3692313	et	0	main
1965	doc_27046690324_item	3692314	et	0	main
oli	doc_27046690324_item	3692315	et	0	main
võimuvahetus	doc_27046690324_item	3692316	et	0	main
kremlis	doc_27046690324_item	3692317	et	0	main
nlkp	doc_27046690324_item	3692318	et	0	main
juhiks	doc_27046690324_item	3692319	et	0	main
sai	doc_27046690324_item	3692320	et	0	main
l	doc_27046690324_item	3692321	et	0	main
brezhniv	doc_27046690324_item	3692322	et	0	main
partei	doc_27046690324_item	3692323	et	0	main
liikmeskonna	doc_27046690324_item	3692324	et	0	main
kihistumine	doc_27046690324_item	3692325	et	0	main
takistati	doc_27046690324_item	3692326	et	0	main
intelligentsi	doc_27046690324_item	3692327	et	0	main
astumist	doc_27046690324_item	3692328	et	0	main
parteisse	doc_27046690324_item	3692329	et	0	main
üleminek	doc_27046690324_item	3692330	et	0	main
eesti	doc_27046690324_item	3692331	et	0	main
keelsele	doc_27046690324_item	3692332	et	0	main
asjaajamisele	doc_27046690324_item	3692333	et	0	main
segakoolide	doc_27046690324_item	3692334	et	0	main
suurendamine	doc_27046690324_item	3692335	et	0	main
1970	doc_27046690324_item	3692336	et	0	main
1980	doc_27046690324_item	3692337	et	0	main
paljud	doc_27046690324_item	3692338	et	0	main
noored	doc_27046690324_item	3692339	et	0	main
kogunesid	doc_27046690324_item	3692340	et	0	main
ka	doc_27046690324_item	3692341	et	0	main
lauluväljakul	doc_27046690324_item	3692342	et	0	main
ja	doc_27046690324_item	3692343	et	0	main
laulsid	doc_27046690324_item	3692344	et	0	main
erinevaid	doc_27046690324_item	3692345	et	0	main
rahvaslaule	doc_27046690324_item	3692346	et	0	main
mis	doc_27046690324_item	3692347	et	0	main
olid	doc_27046690324_item	3692348	et	0	main
eesti	doc_27046690324_item	3692349	et	0	main
vabaduse	doc_27046690324_item	3692350	et	0	main
vastu	doc_27046690324_item	3692351	et	0	main
propageeriti	doc_27046690324_item	3692352	et	0	main
kakskeelsust	doc_27046690324_item	3692353	et	0	main
2	doc_27046690324_item	3692354	et	0	main
öölaulupeol	doc_27046690324_item	3692355	et	0	main
võeti	doc_27046690324_item	3692356	et	0	main
vastu	doc_27046690324_item	3692357	et	0	main
palju	doc_27046690324_item	3692358	et	0	main
noori	doc_27046690324_item	3692359	et	0	main
nad	doc_27046690324_item	3692360	et	0	main
laulsid	doc_27046690324_item	3692361	et	0	main
isamaalaule	doc_27046690324_item	3692362	et	0	main
ning	doc_27046690324_item	3692363	et	0	main
olid	doc_27046690324_item	3692364	et	0	main
eesti	doc_27046690324_item	3692365	et	0	main
vabaduse	doc_27046690324_item	3692366	et	0	main
vastu	doc_27046690324_item	3692367	et	0	main
laulev	doc_27046690324_item	3692368	et	0	main
revolutsioon	doc_27046690324_item	3692369	et	0	main
aitas	doc_27046690324_item	3692370	et	0	main
kaasa	doc_27046690324_item	3692371	et	0	main
ka	doc_27046690324_item	3692372	et	0	main
suuremate	doc_27046690324_item	3692373	et	0	main
poliitiliste	doc_27046690324_item	3692374	et	0	main
rahvaliikumiste	doc_27046690324_item	3692375	et	0	main
tekkell	doc_27046690324_item	3692376	et	0	main
3	doc_27046690324_item	3692377	et	0	main
1988	doc_27046690324_item	3692378	et	0	main
a	doc_27046690324_item	3692379	et	0	main
esines	doc_27046690324_item	3692380	et	0	main
savisaar	doc_27046690324_item	3692381	et	0	main
üleskutse	doc_27046690324_item	3692382	et	0	main
luua	doc_27046690324_item	3692383	et	0	main
perestroika	doc_27046690324_item	3692384	et	0	main
meelsema	doc_27046690324_item	3692385	et	0	main
vaino	doc_27046690324_item	3692386	et	0	main
väljase	doc_27046690324_item	3692387	et	0	main
vastu	doc_27046690324_item	3692388	et	0	main
kes	doc_27046690324_item	3692389	et	0	main
võttis	doc_27046690324_item	3692390	et	0	main
osa	doc_27046690324_item	3692391	et	0	main
rahvarinde	doc_27046690324_item	3692392	et	0	main
nõudmisest	doc_27046690324_item	3692393	et	0	main
juunil	doc_27046690324_item	3692394	et	0	main
rahvarinde	doc_27046690324_item	3692395	et	0	main
suur	doc_27046690324_item	3692396	et	0	main
meelevaldus	doc_27046690324_item	3692397	et	0	main
perestroika	doc_27046690324_item	3692398	et	0	main
ja	doc_27046690324_item	3692399	et	0	main
glasnost	doc_27046690324_item	3692400	et	0	main
ehk	doc_27046690324_item	3692401	et	0	main
avalikustamine	doc_27046690324_item	3692402	et	0	main
võitlus	doc_27046690324_item	3692403	et	0	main
võimul	doc_27046690324_item	3692404	et	0	main
püsimuse	doc_27046690324_item	3692405	et	0	main
eest	doc_27046690324_item	3692406	et	0	main
sundis	doc_27046690324_item	3692407	et	0	main
gorbatshovi	doc_27046690324_item	3692408	et	0	main
otsima	doc_27046690324_item	3692409	et	0	main
toetust	doc_27046690324_item	3692410	et	0	main
väljaspoolt	doc_27046690324_item	3692411	et	0	main
parteid	doc_27046690324_item	3692412	et	0	main
räägiti	doc_27046690324_item	3692413	et	0	main
kahest	doc_27046690324_item	3692414	et	0	main
kõige	doc_27046690324_item	3692415	et	0	main
tähtsamatest	doc_27046690324_item	3692416	et	0	main
probleemidest	doc_27046690324_item	3692417	et	0	main
keskkonnaprobleemidest	doc_27046690324_item	3692418	et	0	main
ning	doc_27046690324_item	3692419	et	0	main
stalinismi	doc_27046690324_item	3692420	et	0	main
kuriteodest	doc_27046690324_item	3692421	et	0	main
kontrolltöö	doc_527420171754_item	3692639	et	0	main
1	doc_527420171754_item	3692640	et	0	main
iseloomustage	doc_527420171754_item	3692641	et	0	main
19701980	doc_527420171754_item	3692642	et	0	main
a-te	doc_527420171754_item	3692643	et	0	main
eesti	doc_527420171754_item	3692644	et	0	main
kultuurielu	doc_527420171754_item	3692645	et	0	main
2	doc_527420171754_item	3692646	et	0	main
nn	doc_527420171754_item	3692647	et	0	main
öölaulupidude	doc_527420171754_item	3692648	et	0	main
ja	doc_527420171754_item	3692649	et	0	main
laulva	doc_527420171754_item	3692650	et	0	main
revolutsiooni	doc_527420171754_item	3692651	et	0	main
osa	doc_527420171754_item	3692652	et	0	main
eesti	doc_527420171754_item	3692653	et	0	main
taasiseseisvumisel	doc_527420171754_item	3692654	et	0	main
3	doc_527420171754_item	3692655	et	0	main
sõnade	doc_527420171754_item	3692656	et	0	main
perestroika	doc_527420171754_item	3692657	et	0	main
ja	doc_527420171754_item	3692658	et	0	main
glasnostj	doc_527420171754_item	3692659	et	0	main
tähendus	doc_527420171754_item	3692660	et	0	main
ja	doc_527420171754_item	3692661	et	0	main
sisu	doc_527420171754_item	3692662	et	0	main
3	doc_527420171754_item	3692663	et	0	main
suur	doc_527420171754_item	3692664	et	0	main
vajas	doc_527420171754_item	3692665	et	0	main
reformaatorit	doc_527420171754_item	3692666	et	0	main
selleks	doc_527420171754_item	3692667	et	0	main
reformaatoriks	doc_527420171754_item	3692668	et	0	main
sai	doc_527420171754_item	3692669	et	0	main
1986	doc_527420171754_item	3692670	et	0	main
a	doc_527420171754_item	3692671	et	0	main
martsis	doc_527420171754_item	3692672	et	0	main
mihhail	doc_527420171754_item	3692673	et	0	main
gorbatshov	doc_527420171754_item	3692674	et	0	main
ta	doc_527420171754_item	3692675	et	0	main
alustas	doc_527420171754_item	3692676	et	0	main
uue	doc_527420171754_item	3692677	et	0	main
poliitikat	doc_527420171754_item	3692678	et	0	main
perestroika	doc_527420171754_item	3692679	et	0	main
perestroika	doc_527420171754_item	3692680	et	0	main
eesmärgiks	doc_527420171754_item	3692681	et	0	main
oli	doc_527420171754_item	3692682	et	0	main
valitseva	doc_527420171754_item	3692683	et	0	main
rezhiimi	doc_527420171754_item	3692684	et	0	main
kriisist	doc_527420171754_item	3692685	et	0	main
välja	doc_527420171754_item	3692686	et	0	main
viimine	doc_527420171754_item	3692687	et	0	main
täiendamine	doc_527420171754_item	3692688	et	0	main
rekonstrueerimine	doc_527420171754_item	3692689	et	0	main
see	doc_527420171754_item	3692690	et	0	main
aga	doc_527420171754_item	3692691	et	0	main
ei	doc_527420171754_item	3692692	et	0	main
juhtunud	doc_527420171754_item	3692693	et	0	main
vii	doc_527420171754_item	3692694	et	0	main
see	doc_527420171754_item	3692695	et	0	main
poliitika	doc_527420171754_item	3692696	et	0	main
1991a	doc_527420171754_item	3692697	et	0	main
nsv	doc_527420171754_item	3692698	et	0	main
liidu	doc_527420171754_item	3692699	et	0	main
lagunemiseni	doc_527420171754_item	3692700	et	0	main
see	doc_527420171754_item	3692701	et	0	main
andis	doc_527420171754_item	3692702	et	0	main
võimalust	doc_527420171754_item	3692703	et	0	main
väikestele	doc_527420171754_item	3692704	et	0	main
rahvastele	doc_527420171754_item	3692705	et	0	main
oma	doc_527420171754_item	3692706	et	0	main
iseseisvuse	doc_527420171754_item	3692707	et	0	main
taastada	doc_527420171754_item	3692708	et	0	main
glasnost	doc_527420171754_item	3692709	et	0	main
oli	doc_527420171754_item	3692710	et	0	main
ka	doc_527420171754_item	3692711	et	0	main
gorbatshovi	doc_527420171754_item	3692712	et	0	main
ajal	doc_527420171754_item	3692713	et	0	main
tähendas	doc_527420171754_item	3692714	et	0	main
tsensuuri	doc_527420171754_item	3692715	et	0	main
nõrgustamist	doc_527420171754_item	3692716	et	0	main
keegi	doc_527420171754_item	3692717	et	0	main
ei	doc_527420171754_item	3692718	et	0	main
takistanud	doc_527420171754_item	3692719	et	0	main
mõtte	doc_527420171754_item	3692720	et	0	main
vaba	doc_527420171754_item	3692721	et	0	main
levikut	doc_527420171754_item	3692722	et	0	main
ühiskonnas	doc_527420171754_item	3692723	et	0	main
2	doc_527420171754_item	3692724	et	0	main
17	doc_527420171754_item	3692725	et	0	main
juunil	doc_527420171754_item	3692726	et	0	main
tallinna	doc_527420171754_item	3692727	et	0	main
laulu	doc_527420171754_item	3692728	et	0	main
väljakul	doc_527420171754_item	3692729	et	0	main
kokkukutsutud	doc_527420171754_item	3692730	et	0	main
meeleavaldus	doc_527420171754_item	3692731	et	0	main
muutus	doc_527420171754_item	3692732	et	0	main
võidurõõmuks	doc_527420171754_item	3692733	et	0	main
sinimust	doc_527420171754_item	3692734	et	0	main
valgete	doc_527420171754_item	3692735	et	0	main
lippude	doc_527420171754_item	3692736	et	0	main
all	doc_527420171754_item	3692737	et	0	main
kus	doc_527420171754_item	3692738	et	0	main
osales	doc_527420171754_item	3692739	et	0	main
umbes	doc_527420171754_item	3692740	et	0	main
150	doc_527420171754_item	3692741	et	0	main
000	doc_527420171754_item	3692742	et	0	main
inimest	doc_527420171754_item	3692743	et	0	main
pärast	doc_527420171754_item	3692744	et	0	main
seda	doc_527420171754_item	3692745	et	0	main
tõstati	doc_527420171754_item	3692746	et	0	main
küsimus	doc_527420171754_item	3692747	et	0	main
eesti	doc_527420171754_item	3692748	et	0	main
keel	doc_527420171754_item	3692749	et	0	main
kuulutada	doc_527420171754_item	3692750	et	0	main
riigi	doc_527420171754_item	3692751	et	0	main
keeleks	doc_527420171754_item	3692752	et	0	main
ekp	doc_527420171754_item	3692753	et	0	main
puudis	doc_527420171754_item	3692754	et	0	main
toetama	doc_527420171754_item	3692755	et	0	main
ime	doc_527420171754_item	3692756	et	0	main
1988a	doc_527420171754_item	3692757	et	0	main
lauluväljakul	doc_527420171754_item	3692758	et	0	main
toimus	doc_527420171754_item	3692759	et	0	main
eestimaa	doc_527420171754_item	3692760	et	0	main
laul	doc_527420171754_item	3692761	et	0	main
mis	doc_527420171754_item	3692762	et	0	main
muutus	doc_527420171754_item	3692763	et	0	main
meeleavalduseks	doc_527420171754_item	3692764	et	0	main
ürituses	doc_527420171754_item	3692765	et	0	main
osales	doc_527420171754_item	3692766	et	0	main
300000	doc_527420171754_item	3692767	et	0	main
inimest	doc_527420171754_item	3692768	et	0	main
seak	doc_527420171754_item	3692769	et	0	main
kõlas	doc_527420171754_item	3692770	et	0	main
üleskutse	doc_527420171754_item	3692771	et	0	main
oma	doc_527420171754_item	3692772	et	0	main
riikliku	doc_527420171754_item	3692773	et	0	main
iseseisvuse	doc_527420171754_item	3692774	et	0	main
taastamiseks	doc_527420171754_item	3692775	et	0	main
samuti	doc_527420171754_item	3692776	et	0	main
toimusid	doc_527420171754_item	3692777	et	0	main
öölaulupidud	doc_527420171754_item	3692778	et	0	main
seal	doc_527420171754_item	3692779	et	0	main
osalesid	doc_527420171754_item	3692780	et	0	main
noori	doc_527420171754_item	3692781	et	0	main
protesti	doc_527420171754_item	3692782	et	0	main
vaimust	doc_527420171754_item	3692783	et	0	main
noored	doc_527420171754_item	3692784	et	0	main
kes	doc_527420171754_item	3692785	et	0	main
tundsid	doc_527420171754_item	3692786	et	0	main
ohutunnet	doc_527420171754_item	3692787	et	0	main
oma	doc_527420171754_item	3692788	et	0	main
kultuuri	doc_527420171754_item	3692789	et	0	main
eest	doc_527420171754_item	3692790	et	0	main
1	doc_527420171754_item	3692791	et	0	main
1970-	doc_527420171754_item	3692792	et	0	main
1980a	doc_527420171754_item	3692793	et	0	main
eesti	doc_527420171754_item	3692794	et	0	main
kultuurielu	doc_527420171754_item	3692795	et	0	main
oli	doc_527420171754_item	3692796	et	0	main
ideoloogilise	doc_527420171754_item	3692797	et	0	main
surve	doc_527420171754_item	3692798	et	0	main
all	doc_527420171754_item	3692799	et	0	main
oli	doc_527420171754_item	3692800	et	0	main
range	doc_527420171754_item	3692801	et	0	main
tsensuur	doc_527420171754_item	3692802	et	0	main
mis	doc_527420171754_item	3692803	et	0	main
takistas	doc_527420171754_item	3692804	et	0	main
vaba	doc_527420171754_item	3692805	et	0	main
mõtte	doc_527420171754_item	3692806	et	0	main
levikut	doc_527420171754_item	3692807	et	0	main
ühiskonnas	doc_527420171754_item	3692808	et	0	main
eraldatus	doc_527420171754_item	3692809	et	0	main
maailmast	doc_527420171754_item	3692810	et	0	main
kaasnes	doc_527420171754_item	3692811	et	0	main
infosulg	doc_527420171754_item	3692812	et	0	main
läänevaimsetest	doc_527420171754_item	3692813	et	0	main
arengutest	doc_527420171754_item	3692814	et	0	main
see	doc_527420171754_item	3692815	et	0	main
tähendas	doc_527420171754_item	3692816	et	0	main
sundorienteeritust	doc_527420171754_item	3692817	et	0	main
vene	doc_527420171754_item	3692818	et	0	main
kultuurile	doc_527420171754_item	3692819	et	0	main
toimus	doc_527420171754_item	3692820	et	0	main
raamatukogude	doc_527420171754_item	3692821	et	0	main
puhastamine	doc_527420171754_item	3692822	et	0	main
kogu	doc_527420171754_item	3692823	et	0	main
ebasovita	doc_527420171754_item	3692824	et	0	main
kirjasõna	doc_527420171754_item	3692825	et	0	main
pandi	doc_527420171754_item	3692826	et	0	main
erifondi	doc_527420171754_item	3692827	et	0	main
oli	doc_527420171754_item	3692828	et	0	main
sundorienteeritus	doc_527420171754_item	3692829	et	0	main
vene	doc_527420171754_item	3692830	et	0	main
keelele	doc_527420171754_item	3692831	et	0	main
propageeriti	doc_527420171754_item	3692832	et	0	main
kakskeelsus	doc_527420171754_item	3692833	et	0	main
aga	doc_527420171754_item	3692834	et	0	main
see	doc_527420171754_item	3692835	et	0	main
oli	doc_527420171754_item	3692836	et	0	main
ühe	doc_527420171754_item	3692837	et	0	main
poolne	doc_527420171754_item	3692838	et	0	main
kakskeelsus	doc_527420171754_item	3692839	et	0	main
eestlased	doc_527420171754_item	3692840	et	0	main
pidid	doc_527420171754_item	3692841	et	0	main
õppima	doc_527420171754_item	3692842	et	0	main
vene	doc_527420171754_item	3692843	et	0	main
keelt	doc_527420171754_item	3692844	et	0	main
aga	doc_527420171754_item	3692845	et	0	main
venelased	doc_527420171754_item	3692846	et	0	main
eesti	doc_527420171754_item	3692847	et	0	main
keelt	doc_527420171754_item	3692848	et	0	main
ei	doc_527420171754_item	3692849	et	0	main
õppinud	doc_527420171754_item	3692850	et	0	main
see	doc_527420171754_item	3692851	et	0	main
teravdas	doc_527420171754_item	3692852	et	0	main
ohutunnet	doc_527420171754_item	3692853	et	0	main
oma	doc_527420171754_item	3692854	et	0	main
rahvuskultuuri	doc_527420171754_item	3692855	et	0	main
eest	doc_527420171754_item	3692856	et	0	main
eksamitöö	doc_491521502109_item	3693138	et	0	main
1	doc_491521502109_item	3693139	et	0	main
rahvusliku	doc_491521502109_item	3693140	et	0	main
ärkamise	doc_491521502109_item	3693141	et	0	main
eeltingimusteks	doc_491521502109_item	3693142	et	0	main
olid	doc_491521502109_item	3693143	et	0	main
loetle	doc_491521502109_item	3693144	et	0	main
enda	doc_491521502109_item	3693145	et	0	main
arvates	doc_491521502109_item	3693146	et	0	main
peamised	doc_491521502109_item	3693147	et	0	main
18	doc_491521502109_item	3693148	et	0	main
saj	doc_491521502109_item	3693149	et	0	main
euroopas	doc_491521502109_item	3693150	et	0	main
levima	doc_491521502109_item	3693151	et	0	main
hakanud	doc_491521502109_item	3693152	et	0	main
valgustusesaj	doc_491521502109_item	3693153	et	0	main
järgsed	doc_491521502109_item	3693154	et	0	main
ideed	doc_491521502109_item	3693155	et	0	main
rahvuse	doc_491521502109_item	3693156	et	0	main
pinnal	doc_491521502109_item	3693157	et	0	main
avaliku	doc_491521502109_item	3693158	et	0	main
arvamise	doc_491521502109_item	3693159	et	0	main
teke	doc_491521502109_item	3693160	et	0	main
rahvusliku	doc_491521502109_item	3693161	et	0	main
identiteedi	doc_491521502109_item	3693162	et	0	main
otsingud	doc_491521502109_item	3693163	et	0	main
rahvuskultuurist	doc_491521502109_item	3693164	et	0	main
sai	doc_491521502109_item	3693165	et	0	main
tasahilju	doc_491521502109_item	3693166	et	0	main
rahvuskultuur	doc_491521502109_item	3693167	et	0	main
eestimaal	doc_491521502109_item	3693168	et	0	main
huvitusid	doc_491521502109_item	3693169	et	0	main
kohalikud	doc_491521502109_item	3693170	et	0	main
baltisakslased	doc_491521502109_item	3693171	et	0	main
nn	doc_491521502109_item	3693172	et	0	main
masarahva	doc_491521502109_item	3693173	et	0	main
kultuurist	doc_491521502109_item	3693174	et	0	main
tekkis	doc_491521502109_item	3693175	et	0	main
ka	doc_491521502109_item	3693176	et	0	main
eestlastest	doc_491521502109_item	3693177	et	0	main
haritlaste	doc_491521502109_item	3693178	et	0	main
seltskond	doc_491521502109_item	3693179	et	0	main
kes	doc_491521502109_item	3693180	et	0	main
tegutsesid	doc_491521502109_item	3693181	et	0	main
rahva	doc_491521502109_item	3693182	et	0	main
eneseteadvuse	doc_491521502109_item	3693183	et	0	main
arendamise	doc_491521502109_item	3693184	et	0	main
nimel	doc_491521502109_item	3693185	et	0	main
suur	doc_491521502109_item	3693186	et	0	main
roll	doc_491521502109_item	3693187	et	0	main
faehlmanni	doc_491521502109_item	3693188	et	0	main
ja	doc_491521502109_item	3693189	et	0	main
kreutzwaldil	doc_491521502109_item	3693190	et	0	main
kalevipoja	doc_491521502109_item	3693191	et	0	main
kui	doc_491521502109_item	3693192	et	0	main
kultpol	doc_491521502109_item	3693193	et	0	main
teose	doc_491521502109_item	3693194	et	0	main
koostamisel	doc_491521502109_item	3693195	et	0	main
samuti	doc_491521502109_item	3693196	et	0	main
1838	doc_491521502109_item	3693197	et	0	main
õpetatud	doc_491521502109_item	3693198	et	0	main
eesti	doc_491521502109_item	3693199	et	0	main
seltsil	doc_491521502109_item	3693200	et	0	main
ja	doc_491521502109_item	3693201	et	0	main
õpetajate	doc_491521502109_item	3693202	et	0	main
koolituse	doc_491521502109_item	3693203	et	0	main
seminaridel	doc_491521502109_item	3693204	et	0	main
nende	doc_491521502109_item	3693205	et	0	main
kaudu	doc_491521502109_item	3693206	et	0	main
levisid	doc_491521502109_item	3693207	et	0	main
ideed	doc_491521502109_item	3693208	et	0	main
talupoegade	doc_491521502109_item	3693209	et	0	main
seas	doc_491521502109_item	3693210	et	0	main
tugev	doc_491521502109_item	3693211	et	0	main
initsiatiivgrupp	doc_491521502109_item	3693212	et	0	main
ja	doc_491521502109_item	3693213	et	0	main
nende	doc_491521502109_item	3693214	et	0	main
inimeste	doc_491521502109_item	3693215	et	0	main
meelekindlus	doc_491521502109_item	3693216	et	0	main
olid	doc_491521502109_item	3693217	et	0	main
minu	doc_491521502109_item	3693218	et	0	main
arvates	doc_491521502109_item	3693219	et	0	main
rahvusliku	doc_491521502109_item	3693220	et	0	main
ärkamise	doc_491521502109_item	3693221	et	0	main
tugipunktideks	doc_491521502109_item	3693222	et	0	main
2	doc_491521502109_item	3693223	et	0	main
eesti	doc_491521502109_item	3693224	et	0	main
vabariigi	doc_491521502109_item	3693225	et	0	main
majandust	doc_491521502109_item	3693226	et	0	main
iseloomustavad	doc_491521502109_item	3693227	et	0	main
peamised	doc_491521502109_item	3693228	et	0	main
tunnused	doc_491521502109_item	3693229	et	0	main
otsiti	doc_491521502109_item	3693230	et	0	main
turgu	doc_491521502109_item	3693231	et	0	main
välismaal	doc_491521502109_item	3693232	et	0	main
peamised	doc_491521502109_item	3693233	et	0	main
ekspordiartiklid	doc_491521502109_item	3693234	et	0	main
eesti	doc_491521502109_item	3693235	et	0	main
või	doc_491521502109_item	3693236	et	0	main
juust	doc_491521502109_item	3693237	et	0	main
sealiha	doc_491521502109_item	3693238	et	0	main
peekon	doc_491521502109_item	3693239	et	0	main
areng	doc_491521502109_item	3693240	et	0	main
suht	doc_491521502109_item	3693241	et	0	main
positiivne	doc_491521502109_item	3693242	et	0	main
võrreldes	doc_491521502109_item	3693243	et	0	main
venemaaga	doc_491521502109_item	3693244	et	0	main
euroopaga	doc_491521502109_item	3693245	et	0	main
palgad	doc_491521502109_item	3693246	et	0	main
võrrelda	doc_491521502109_item	3693247	et	0	main
ei	doc_491521502109_item	3693248	et	0	main
andnud	doc_491521502109_item	3693249	et	0	main
kalandusega	doc_491521502109_item	3693250	et	0	main
tegeleti	doc_491521502109_item	3693251	et	0	main
samuti	doc_491521502109_item	3693252	et	0	main
ekspordiks	doc_491521502109_item	3693253	et	0	main
metsaraiele	doc_491521502109_item	3693254	et	0	main
sõja	doc_491521502109_item	3693255	et	0	main
ajal	doc_491521502109_item	3693256	et	0	main
liiga	doc_491521502109_item	3693257	et	0	main
tehtud	doc_491521502109_item	3693258	et	0	main
see	doc_491521502109_item	3693259	et	0	main
haru	doc_491521502109_item	3693260	et	0	main
pidas	doc_491521502109_item	3693261	et	0	main
madalat	doc_491521502109_item	3693262	et	0	main
profiili	doc_491521502109_item	3693263	et	0	main
tekstiilitööstus	doc_491521502109_item	3693264	et	0	main
tugev	doc_491521502109_item	3693265	et	0	main
lisaks	doc_491521502109_item	3693266	et	0	main
metallitööstus	doc_491521502109_item	3693267	et	0	main
tsemendivabrikud	doc_491521502109_item	3693268	et	0	main
aparaadivabrikud	doc_491521502109_item	3693269	et	0	main
3	doc_491521502109_item	3693270	et	0	main
rühmituse	doc_491521502109_item	3693271	et	0	main
noor-eesti	doc_491521502109_item	3693272	et	0	main
olemus	doc_491521502109_item	3693273	et	0	main
ja	doc_491521502109_item	3693274	et	0	main
tähtsus	doc_491521502109_item	3693275	et	0	main
eesti	doc_491521502109_item	3693276	et	0	main
kultuuriloos	doc_491521502109_item	3693277	et	0	main
1905-15	doc_491521502109_item	3693278	et	0	main
tegutses	doc_491521502109_item	3693279	et	0	main
ka	doc_491521502109_item	3693280	et	0	main
peale	doc_491521502109_item	3693281	et	0	main
a	doc_491521502109_item	3693282	et	0	main
1925	doc_491521502109_item	3693283	et	0	main
gustav	doc_491521502109_item	3693284	et	0	main
suitsu	doc_491521502109_item	3693285	et	0	main
loosung	doc_491521502109_item	3693286	et	0	main
saagem	doc_491521502109_item	3693287	et	0	main
eurooplasteks	doc_491521502109_item	3693288	et	0	main
kuid	doc_491521502109_item	3693289	et	0	main
jäägem	doc_491521502109_item	3693290	et	0	main
eestlasteks	doc_491521502109_item	3693291	et	0	main
rohkem	doc_491521502109_item	3693292	et	0	main
euroopalist	doc_491521502109_item	3693293	et	0	main
kultuuri	doc_491521502109_item	3693294	et	0	main
ilmusid	doc_491521502109_item	3693295	et	0	main
rühmituse	doc_491521502109_item	3693296	et	0	main
albumid	doc_491521502109_item	3693297	et	0	main
luulekogud	doc_491521502109_item	3693298	et	0	main
põhirõhk	doc_491521502109_item	3693299	et	0	main
luulel	doc_491521502109_item	3693300	et	0	main
friedeberg	doc_491521502109_item	3693301	et	0	main
tuglas	doc_491521502109_item	3693302	et	0	main
pani	doc_491521502109_item	3693303	et	0	main
aluse	doc_491521502109_item	3693304	et	0	main
eesti	doc_491521502109_item	3693305	et	0	main
proffessionaalsele	doc_491521502109_item	3693306	et	0	main
kirjandus-	doc_491521502109_item	3693307	et	0	main
ja	doc_491521502109_item	3693308	et	0	main
kunstikriitikale	doc_491521502109_item	3693309	et	0	main
tema	doc_491521502109_item	3693310	et	0	main
novellikogud	doc_491521502109_item	3693311	et	0	main
rääkisid	doc_491521502109_item	3693312	et	0	main
tugevast	doc_491521502109_item	3693313	et	0	main
avatusest	doc_491521502109_item	3693314	et	0	main
euroopa	doc_491521502109_item	3693315	et	0	main
mõjudele	doc_491521502109_item	3693316	et	0	main
palju	doc_491521502109_item	3693317	et	0	main
ekspermenteeritud	doc_491521502109_item	3693318	et	0	main
suurepärane	doc_491521502109_item	3693319	et	0	main
stiilitunnetus	doc_491521502109_item	3693320	et	0	main
marie	doc_491521502109_item	3693321	et	0	main
underi	doc_491521502109_item	3693322	et	0	main
sonetid	doc_491521502109_item	3693323	et	0	main
müüdi	doc_491521502109_item	3693324	et	0	main
kohe	doc_491521502109_item	3693325	et	0	main
läbi	doc_491521502109_item	3693326	et	0	main
julge	doc_491521502109_item	3693327	et	0	main
armuluule	doc_491521502109_item	3693328	et	0	main
rõõm	doc_491521502109_item	3693329	et	0	main
armastusest	doc_491521502109_item	3693330	et	0	main
noor-eesti	doc_491521502109_item	3693331	et	0	main
avardas	doc_491521502109_item	3693332	et	0	main
eestlase	doc_491521502109_item	3693333	et	0	main
maailmapilti	doc_491521502109_item	3693334	et	0	main
omas	doc_491521502109_item	3693335	et	0	main
pos	doc_491521502109_item	3693336	et	0	main
mõju	doc_491521502109_item	3693337	et	0	main
kultuurielule	doc_491521502109_item	3693338	et	0	main
koondas	doc_491521502109_item	3693339	et	0	main
oma	doc_491521502109_item	3693340	et	0	main
aja	doc_491521502109_item	3693341	et	0	main
tipud	doc_491521502109_item	3693342	et	0	main
vahendas	doc_491521502109_item	3693343	et	0	main
maailmamtippude	doc_491521502109_item	3693344	et	0	main
kirjandust	doc_491521502109_item	3693345	et	0	main
eestlasele	doc_491521502109_item	3693346	et	0	main
saagem	doc_491521502109_item	3693347	et	0	main
suureks	doc_491521502109_item	3693348	et	0	main
vaimult	doc_491521502109_item	3693349	et	0	main
mitte	doc_491521502109_item	3693350	et	0	main
rahvarvult	doc_491521502109_item	3693351	et	0	main
jakob	doc_491521502109_item	3693352	et	0	main
hurt	doc_491521502109_item	3693353	et	0	main
juba	doc_491521502109_item	3693354	et	0	main
noore	doc_491521502109_item	3693355	et	0	main
mehena	doc_491521502109_item	3693356	et	0	main
sekkus	doc_491521502109_item	3693357	et	0	main
eesti	doc_491521502109_item	3693358	et	0	main
kultuuriellu	doc_491521502109_item	3693359	et	0	main
esinemine	doc_491521502109_item	3693360	et	0	main
1869	doc_491521502109_item	3693361	et	0	main
a	doc_491521502109_item	3693362	et	0	main
i	doc_491521502109_item	3693363	et	0	main
üldlaulupeol	doc_491521502109_item	3693364	et	0	main
hiljem	doc_491521502109_item	3693365	et	0	main
kaastöö	doc_491521502109_item	3693366	et	0	main
postimehele	doc_491521502109_item	3693367	et	0	main
kahjuks	doc_491521502109_item	3693368	et	0	main
katkes	doc_491521502109_item	3693369	et	0	main
pooldas	doc_491521502109_item	3693370	et	0	main
eestikeelsetmeelset	doc_491521502109_item	3693371	et	0	main
kooliharidust	doc_491521502109_item	3693372	et	0	main
tema	doc_491521502109_item	3693373	et	0	main
konseptisoon	doc_491521502109_item	3693374	et	0	main
nägi	doc_491521502109_item	3693375	et	0	main
välja	doc_491521502109_item	3693376	et	0	main
taoline	doc_491521502109_item	3693377	et	0	main
vene	doc_491521502109_item	3693378	et	0	main
tee	doc_491521502109_item	3693379	et	0	main
eesti	doc_491521502109_item	3693380	et	0	main
tee	doc_491521502109_item	3693381	et	0	main
pidi	doc_491521502109_item	3693382	et	0	main
olema	doc_491521502109_item	3693383	et	0	main
midagi	doc_491521502109_item	3693384	et	0	main
nende	doc_491521502109_item	3693385	et	0	main
kahe	doc_491521502109_item	3693386	et	0	main
vahepealset	doc_491521502109_item	3693387	et	0	main
saksa	doc_491521502109_item	3693388	et	0	main
tee	doc_491521502109_item	3693389	et	0	main
kahjuks	doc_491521502109_item	3693390	et	0	main
tugevad	doc_491521502109_item	3693391	et	0	main
vastuolud	doc_491521502109_item	3693392	et	0	main
jakobsoniga	doc_491521502109_item	3693393	et	0	main
kes	doc_491521502109_item	3693394	et	0	main
süüdistas	doc_491521502109_item	3693395	et	0	main
teda	doc_491521502109_item	3693396	et	0	main
liigses	doc_491521502109_item	3693397	et	0	main
saksameelsuses	doc_491521502109_item	3693398	et	0	main
mis	doc_491521502109_item	3693399	et	0	main
jakobsoni	doc_491521502109_item	3693400	et	0	main
meelest	doc_491521502109_item	3693401	et	0	main
lausa	doc_491521502109_item	3693402	et	0	main
orjameelsus	doc_491521502109_item	3693403	et	0	main
hurdale	doc_491521502109_item	3693404	et	0	main
vastumeelt	doc_491521502109_item	3693405	et	0	main
jakobsoni	doc_491521502109_item	3693406	et	0	main
venemaale	doc_491521502109_item	3693407	et	0	main
orienteeritus	doc_491521502109_item	3693408	et	0	main
80	doc_491521502109_item	3693409	et	0	main
ndate	doc_491521502109_item	3693410	et	0	main
alguses	doc_491521502109_item	3693411	et	0	main
lahkus	doc_491521502109_item	3693412	et	0	main
peterburi	doc_491521502109_item	3693413	et	0	main
tegutses	doc_491521502109_item	3693414	et	0	main
sealse	doc_491521502109_item	3693415	et	0	main
eesti	doc_491521502109_item	3693416	et	0	main
kogukonna	doc_491521502109_item	3693417	et	0	main
pastorina	doc_491521502109_item	3693418	et	0	main
eksamitöö	doc_491521502111_item	3693419	et	0	main
1	doc_491521502111_item	3693420	et	0	main
seltsiliikumise	doc_491521502111_item	3693421	et	0	main
osatähtsusest	doc_491521502111_item	3693422	et	0	main
omariikluse	doc_491521502111_item	3693423	et	0	main
kujundajana	doc_491521502111_item	3693424	et	0	main
1	doc_491521502111_item	3693425	et	0	main
seltsid	doc_491521502111_item	3693426	et	0	main
hakkasid	doc_491521502111_item	3693427	et	0	main
kujunema	doc_491521502111_item	3693428	et	0	main
juba	doc_491521502111_item	3693429	et	0	main
1632	doc_491521502111_item	3693430	et	0	main
aastal	doc_491521502111_item	3693431	et	0	main
mitteamet	doc_491521502111_item	3693432	et	0	main
tartu	doc_491521502111_item	3693433	et	0	main
ülikoolis	doc_491521502111_item	3693434	et	0	main
see	doc_491521502111_item	3693435	et	0	main
oli	doc_491521502111_item	3693436	et	0	main
tü	doc_491521502111_item	3693437	et	0	main
traditsioon	doc_491521502111_item	3693438	et	0	main
1882	doc_491521502111_item	3693439	et	0	main
a	doc_491521502111_item	3693440	et	0	main
kujunes	doc_491521502111_item	3693441	et	0	main
ametl	doc_491521502111_item	3693442	et	0	main
välja	doc_491521502111_item	3693443	et	0	main
eüs	doc_491521502111_item	3693444	et	0	main
sini-must-valge	doc_491521502111_item	3693445	et	0	main
rahvuslipp	doc_491521502111_item	3693446	et	0	main
sai	doc_491521502111_item	3693447	et	0	main
sealt	doc_491521502111_item	3693448	et	0	main
oma	doc_491521502111_item	3693449	et	0	main
alguse	doc_491521502111_item	3693450	et	0	main
1920	doc_491521502111_item	3693451	et	0	main
kujunesid	doc_491521502111_item	3693452	et	0	main
1	doc_491521502111_item	3693453	et	0	main
naisliikumised	doc_491521502111_item	3693454	et	0	main
kodumaa	doc_491521502111_item	3693455	et	0	main
tütred	doc_491521502111_item	3693456	et	0	main
pärast	doc_491521502111_item	3693457	et	0	main
nad	doc_491521502111_item	3693458	et	0	main
hakkasid	doc_491521502111_item	3693459	et	0	main
aktiivsemalt	doc_491521502111_item	3693460	et	0	main
tegutsema	doc_491521502111_item	3693461	et	0	main
põllumajanduse	doc_491521502111_item	3693462	et	0	main
seltsid	doc_491521502111_item	3693463	et	0	main
tegutsid	doc_491521502111_item	3693464	et	0	main
põllumajanduse	doc_491521502111_item	3693465	et	0	main
parandamisega	doc_491521502111_item	3693466	et	0	main
tekkisid	doc_491521502111_item	3693467	et	0	main
ka	doc_491521502111_item	3693468	et	0	main
ühispangud	doc_491521502111_item	3693469	et	0	main
eestlased	doc_491521502111_item	3693470	et	0	main
aitasid	doc_491521502111_item	3693471	et	0	main
teineteist	doc_491521502111_item	3693472	et	0	main
tekkisid	doc_491521502111_item	3693473	et	0	main
palju	doc_491521502111_item	3693474	et	0	main
heategevuse	doc_491521502111_item	3693475	et	0	main
seltse	doc_491521502111_item	3693476	et	0	main
aga	doc_491521502111_item	3693477	et	0	main
nendest	doc_491521502111_item	3693478	et	0	main
palju	doc_491521502111_item	3693479	et	0	main
kasu	doc_491521502111_item	3693480	et	0	main
ei	doc_491521502111_item	3693481	et	0	main
olnud	doc_491521502111_item	3693482	et	0	main
sest	doc_491521502111_item	3693483	et	0	main
kõik	doc_491521502111_item	3693484	et	0	main
seltsid	doc_491521502111_item	3693485	et	0	main
mis	doc_491521502111_item	3693486	et	0	main
tegelesid	doc_491521502111_item	3693487	et	0	main
poliitikuga	doc_491521502111_item	3693488	et	0	main
olid	doc_491521502111_item	3693489	et	0	main
põranda	doc_491521502111_item	3693490	et	0	main
all	doc_491521502111_item	3693491	et	0	main
aga	doc_491521502111_item	3693492	et	0	main
ikka	doc_491521502111_item	3693493	et	0	main
need	doc_491521502111_item	3693494	et	0	main
saladusseltsid	doc_491521502111_item	3693495	et	0	main
koos	doc_491521502111_item	3693496	et	0	main
ajalehtedega	doc_491521502111_item	3693497	et	0	main
tegid	doc_491521502111_item	3693498	et	0	main
palju	doc_491521502111_item	3693499	et	0	main
rahvusliikumise	doc_491521502111_item	3693500	et	0	main
ajal	doc_491521502111_item	3693501	et	0	main
aga	doc_491521502111_item	3693502	et	0	main
oli	doc_491521502111_item	3693503	et	0	main
suur	doc_491521502111_item	3693504	et	0	main
tsensuur	doc_491521502111_item	3693505	et	0	main
ja	doc_491521502111_item	3693506	et	0	main
keelatus	doc_491521502111_item	3693507	et	0	main
tänu	doc_491521502111_item	3693508	et	0	main
sellele	doc_491521502111_item	3693509	et	0	main
seltsiliikumisele	doc_491521502111_item	3693510	et	0	main
eesti	doc_491521502111_item	3693511	et	0	main
rahvad	doc_491521502111_item	3693512	et	0	main
sai	doc_491521502111_item	3693513	et	0	main
teada	doc_491521502111_item	3693514	et	0	main
et	doc_491521502111_item	3693515	et	0	main
eestl	doc_491521502111_item	3693516	et	0	main
on	doc_491521502111_item	3693517	et	0	main
ühised	doc_491521502111_item	3693518	et	0	main
ja	doc_491521502111_item	3693519	et	0	main
nad	doc_491521502111_item	3693520	et	0	main
aitavad	doc_491521502111_item	3693521	et	0	main
teineteist	doc_491521502111_item	3693522	et	0	main
ja	doc_491521502111_item	3693523	et	0	main
keegi	doc_491521502111_item	3693524	et	0	main
püüab	doc_491521502111_item	3693525	et	0	main
nende	doc_491521502111_item	3693526	et	0	main
elu	doc_491521502111_item	3693527	et	0	main
parem	doc_491521502111_item	3693528	et	0	main
teha	doc_491521502111_item	3693529	et	0	main
nendel	doc_491521502111_item	3693530	et	0	main
sala	doc_491521502111_item	3693531	et	0	main
seltsidel	doc_491521502111_item	3693532	et	0	main
olid	doc_491521502111_item	3693533	et	0	main
siided	doc_491521502111_item	3693534	et	0	main
venemaa	doc_491521502111_item	3693535	et	0	main
salaliikumisega	doc_491521502111_item	3693536	et	0	main
poliit	doc_491521502111_item	3693537	et	0	main
in	doc_491521502111_item	3693538	et	0	main
tahtsid	doc_491521502111_item	3693539	et	0	main
poliitilist	doc_491521502111_item	3693540	et	0	main
vadadust	doc_491521502111_item	3693541	et	0	main
sõna-vabadust	doc_491521502111_item	3693542	et	0	main
ja	doc_491521502111_item	3693543	et	0	main
kõik	doc_491521502111_item	3693544	et	0	main
mis	doc_491521502111_item	3693545	et	0	main
puudutas	doc_491521502111_item	3693546	et	0	main
tööd	doc_491521502111_item	3693547	et	0	main
kestvust	doc_491521502111_item	3693548	et	0	main
palk	doc_491521502111_item	3693549	et	0	main
jne	doc_491521502111_item	3693550	et	0	main
2	doc_491521502111_item	3693551	et	0	main
jakob	doc_491521502111_item	3693552	et	0	main
hurda	doc_491521502111_item	3693553	et	0	main
roll	doc_491521502111_item	3693554	et	0	main
kaasaegses	doc_491521502111_item	3693555	et	0	main
eestis	doc_491521502111_item	3693556	et	0	main
2	doc_491521502111_item	3693557	et	0	main
jakob	doc_491521502111_item	3693558	et	0	main
hurt	doc_491521502111_item	3693559	et	0	main
oli	doc_491521502111_item	3693560	et	0	main
jakobsoni	doc_491521502111_item	3693561	et	0	main
ja	doc_491521502111_item	3693562	et	0	main
jannseni	doc_491521502111_item	3693563	et	0	main
vahel	doc_491521502111_item	3693564	et	0	main
ta	doc_491521502111_item	3693565	et	0	main
püüdis	doc_491521502111_item	3693566	et	0	main
leida	doc_491521502111_item	3693567	et	0	main
kompromisse	doc_491521502111_item	3693568	et	0	main
ja	doc_491521502111_item	3693569	et	0	main
3	doc_491521502111_item	3693570	et	0	main
teed	doc_491521502111_item	3693571	et	0	main
aga	doc_491521502111_item	3693572	et	0	main
tema	doc_491521502111_item	3693573	et	0	main
tee	doc_491521502111_item	3693574	et	0	main
ka	doc_491521502111_item	3693575	et	0	main
ei	doc_491521502111_item	3693576	et	0	main
sobinud	doc_491521502111_item	3693577	et	0	main
nendele	doc_491521502111_item	3693578	et	0	main
vene	doc_491521502111_item	3693579	et	0	main
t	doc_491521502111_item	3693580	et	0	main
hurt	doc_491521502111_item	3693581	et	0	main
bsaks	doc_491521502111_item	3693582	et	0	main
1870	doc_491521502111_item	3693583	et	0	main
a	doc_491521502111_item	3693584	et	0	main
kõige	doc_491521502111_item	3693585	et	0	main
tähtsam	doc_491521502111_item	3693586	et	0	main
oli	doc_491521502111_item	3693587	et	0	main
aleksandri	doc_491521502111_item	3693588	et	0	main
kooli	doc_491521502111_item	3693589	et	0	main
komitee	doc_491521502111_item	3693590	et	0	main
president	doc_491521502111_item	3693591	et	0	main
oli	doc_491521502111_item	3693592	et	0	main
j	doc_491521502111_item	3693593	et	0	main
hurt	doc_491521502111_item	3693594	et	0	main
korraldati	doc_491521502111_item	3693595	et	0	main
õhtud	doc_491521502111_item	3693596	et	0	main
ja	doc_491521502111_item	3693597	et	0	main
kog	doc_491521502111_item	3693598	et	0	main
raha	doc_491521502111_item	3693599	et	0	main
andsid	doc_491521502111_item	3693600	et	0	main
koolidele	doc_491521502111_item	3693601	et	0	main
seda	doc_491521502111_item	3693602	et	0	main
nimetati	doc_491521502111_item	3693603	et	0	main
1	doc_491521502111_item	3693604	et	0	main
parlamendiks	doc_491521502111_item	3693605	et	0	main
see	doc_491521502111_item	3693606	et	0	main
ei	doc_491521502111_item	3693607	et	0	main
meeldinud	doc_491521502111_item	3693608	et	0	main
b-sakslastele	doc_491521502111_item	3693609	et	0	main
nad	doc_491521502111_item	3693610	et	0	main
olid	doc_491521502111_item	3693611	et	0	main
selle	doc_491521502111_item	3693612	et	0	main
vastu	doc_491521502111_item	3693613	et	0	main
aga	doc_491521502111_item	3693614	et	0	main
tuntuvus	doc_491521502111_item	3693615	et	0	main
ei	doc_491521502111_item	3693616	et	0	main
vähenenud	doc_491521502111_item	3693617	et	0	main
1871	doc_491521502111_item	3693618	et	0	main
a	doc_491521502111_item	3693619	et	0	main
ametlikult	doc_491521502111_item	3693620	et	0	main
fikseeriti	doc_491521502111_item	3693621	et	0	main
eesti	doc_491521502111_item	3693622	et	0	main
kirjameeste	doc_491521502111_item	3693623	et	0	main
seltsi	doc_491521502111_item	3693624	et	0	main
nende	doc_491521502111_item	3693625	et	0	main
põhiülesanne	doc_491521502111_item	3693626	et	0	main
oli	doc_491521502111_item	3693627	et	0	main
eesti	doc_491521502111_item	3693628	et	0	main
keele	doc_491521502111_item	3693629	et	0	main
ja	doc_491521502111_item	3693630	et	0	main
kirjanduse	doc_491521502111_item	3693631	et	0	main
arendamine	doc_491521502111_item	3693632	et	0	main
rahvaluule	doc_491521502111_item	3693633	et	0	main
ja	doc_491521502111_item	3693634	et	0	main
3	doc_491521502111_item	3693635	et	0	main
tartu	doc_491521502111_item	3693636	et	0	main
rahu	doc_491521502111_item	3693637	et	0	main
anograatilise	doc_491521502111_item	3693638	et	0	main
materjaale	doc_491521502111_item	3693639	et	0	main
kogunemine	doc_491521502111_item	3693640	et	0	main
tegelesid	doc_491521502111_item	3693641	et	0	main
teadusega	doc_491521502111_item	3693642	et	0	main
president	doc_491521502111_item	3693643	et	0	main
j	doc_491521502111_item	3693644	et	0	main
hurt	doc_491521502111_item	3693645	et	0	main
1882a	doc_491521502111_item	3693646	et	0	main
hurt	doc_491521502111_item	3693647	et	0	main
on	doc_491521502111_item	3693648	et	0	main
otepää	doc_491521502111_item	3693649	et	0	main
pastor	doc_491521502111_item	3693650	et	0	main
ja	doc_491521502111_item	3693651	et	0	main
peab	doc_491521502111_item	3693652	et	0	main
sakslaste	doc_491521502111_item	3693653	et	0	main
nõudmisega	doc_491521502111_item	3693654	et	0	main
arvestama	doc_491521502111_item	3693655	et	0	main
aga	doc_491521502111_item	3693656	et	0	main
selts	doc_491521502111_item	3693657	et	0	main
tegutses	doc_491521502111_item	3693658	et	0	main
väga	doc_491521502111_item	3693659	et	0	main
aktiivselt	doc_491521502111_item	3693660	et	0	main
1	doc_491521502111_item	3693661	et	0	main
kohal	doc_491521502111_item	3693662	et	0	main
üle	doc_491521502111_item	3693663	et	0	main
poole	doc_491521502111_item	3693664	et	0	main
liiki	doc_491521502111_item	3693665	et	0	main
olid	doc_491521502111_item	3693666	et	0	main
õpetajad	doc_491521502111_item	3693667	et	0	main
1	doc_491521502111_item	3693668	et	0	main
intelligentsi	doc_491521502111_item	3693669	et	0	main
selts	doc_491521502111_item	3693670	et	0	main
hurt	doc_491521502111_item	3693671	et	0	main
tegi	doc_491521502111_item	3693672	et	0	main
üsna	doc_491521502111_item	3693673	et	0	main
palju	doc_491521502111_item	3693674	et	0	main
seltsi	doc_491521502111_item	3693675	et	0	main
elus	doc_491521502111_item	3693676	et	0	main
vaid	doc_491521502111_item	3693677	et	0	main
ta	doc_491521502111_item	3693678	et	0	main
3	doc_491521502111_item	3693679	et	0	main
teed	doc_491521502111_item	3693680	et	0	main
ei	doc_491521502111_item	3693681	et	0	main
leidnud	doc_491521502111_item	3693682	et	0	main
see	doc_491521502111_item	3693683	et	0	main
oli	doc_491521502111_item	3693684	et	0	main
tema	doc_491521502111_item	3693685	et	0	main
puudus	doc_491521502111_item	3693686	et	0	main
ta	doc_491521502111_item	3693687	et	0	main
kogu	doc_491521502111_item	3693688	et	0	main
aeg	doc_491521502111_item	3693689	et	0	main
püüdis	doc_491521502111_item	3693690	et	0	main
leida	doc_491521502111_item	3693691	et	0	main
kompromisse	doc_491521502111_item	3693692	et	0	main
kahe	doc_491521502111_item	3693693	et	0	main
võimu	doc_491521502111_item	3693694	et	0	main
vahel	doc_491521502111_item	3693695	et	0	main
aga	doc_491521502111_item	3693696	et	0	main
tema	doc_491521502111_item	3693697	et	0	main
abiga	doc_491521502111_item	3693698	et	0	main
tegutsesid	doc_491521502111_item	3693699	et	0	main
seltsid	doc_491521502111_item	3693700	et	0	main
mis	doc_491521502111_item	3693701	et	0	main
tegid	doc_491521502111_item	3693702	et	0	main
üsna	doc_491521502111_item	3693703	et	0	main
palju	doc_491521502111_item	3693704	et	0	main
eesti	doc_491521502111_item	3693705	et	0	main
rahvale	doc_491521502111_item	3693706	et	0	main
3	doc_491521502111_item	3693707	et	0	main
tartu	doc_491521502111_item	3693708	et	0	main
rahu	doc_491521502111_item	3693709	et	0	main
hakati	doc_491521502111_item	3693710	et	0	main
kirjutama	doc_491521502111_item	3693711	et	0	main
5	doc_491521502111_item	3693712	et	0	main
detsembril	doc_491521502111_item	3693713	et	0	main
31	doc_491521502111_item	3693714	et	0	main
dets	doc_491521502111_item	3693715	et	0	main
kirjutati	doc_491521502111_item	3693716	et	0	main
alla	doc_491521502111_item	3693717	et	0	main
vaherahule	doc_491521502111_item	3693718	et	0	main
millega	doc_491521502111_item	3693719	et	0	main
lõpetati	doc_491521502111_item	3693720	et	0	main
sõjategevus	doc_491521502111_item	3693721	et	0	main
ja	doc_491521502111_item	3693722	et	0	main
2	doc_491521502111_item	3693723	et	0	main
veebruaril	doc_491521502111_item	3693724	et	0	main
1920	doc_491521502111_item	3693725	et	0	main
tartu	doc_491521502111_item	3693726	et	0	main
rahulepingule	doc_491521502111_item	3693727	et	0	main
mõlema	doc_491521502111_item	3693728	et	0	main
venemaa	doc_491521502111_item	3693729	et	0	main
eesti	doc_491521502111_item	3693730	et	0	main
riigi	doc_491521502111_item	3693731	et	0	main
vahel	doc_491521502111_item	3693732	et	0	main
kehtestati	doc_491521502111_item	3693733	et	0	main
diplomaatilised	doc_491521502111_item	3693734	et	0	main
suhted	doc_491521502111_item	3693735	et	0	main
eesti	doc_491521502111_item	3693736	et	0	main
valitsus	doc_491521502111_item	3693737	et	0	main
kohustus	doc_491521502111_item	3693738	et	0	main
omalt	doc_491521502111_item	3693739	et	0	main
poolt	doc_491521502111_item	3693740	et	0	main
likvideerima	doc_491521502111_item	3693741	et	0	main
eesti	doc_491521502111_item	3693742	et	0	main
alale	doc_491521502111_item	3693743	et	0	main
taganenud	doc_491521502111_item	3693744	et	0	main
loodearmee	doc_491521502111_item	3693745	et	0	main
riismed	doc_491521502111_item	3693746	et	0	main
ka	doc_491521502111_item	3693747	et	0	main
inglise	doc_491521502111_item	3693748	et	0	main
laevastik	doc_491521502111_item	3693749	et	0	main
pidi	doc_491521502111_item	3693750	et	0	main
eesti	doc_491521502111_item	3693751	et	0	main
vetest	doc_491521502111_item	3693752	et	0	main
lahkuma	doc_491521502111_item	3693753	et	0	main
tartu	doc_491521502111_item	3693754	et	0	main
leping	doc_491521502111_item	3693755	et	0	main
sõlmiti	doc_491521502111_item	3693756	et	0	main
pärast	doc_491521502111_item	3693757	et	0	main
kojusõjat	doc_491521502111_item	3693758	et	0	main
ja	doc_491521502111_item	3693759	et	0	main
interventsiooni	doc_491521502111_item	3693760	et	0	main
pärast	doc_491521502111_item	3693761	et	0	main
seda	doc_491521502111_item	3693762	et	0	main
hakati	doc_491521502111_item	3693763	et	0	main
taastama	doc_491521502111_item	3693764	et	0	main
oma	doc_491521502111_item	3693765	et	0	main
riiki	doc_491521502111_item	3693766	et	0	main
25	doc_491521502111_item	3693767	et	0	main
aug	doc_491521502111_item	3693768	et	0	main
voetakse	doc_491521502111_item	3693769	et	0	main
vastu	doc_491521502111_item	3693770	et	0	main
1	doc_491521502111_item	3693771	et	0	main
põhiseadus	doc_491521502111_item	3693772	et	0	main
baseerus	doc_491521502111_item	3693773	et	0	main
see	doc_491521502111_item	3693774	et	0	main
kod	doc_491521502111_item	3693775	et	0	main
demokr	doc_491521502111_item	3693776	et	0	main
eksamitöö	doc_491521502117_item	3693777	et	0	main
1	doc_491521502117_item	3693778	et	0	main
omakeelne	doc_491521502117_item	3693779	et	0	main
kõrgharidus	doc_491521502117_item	3693780	et	0	main
ja	doc_491521502117_item	3693781	et	0	main
teadus	doc_491521502117_item	3693782	et	0	main
eesti	doc_491521502117_item	3693783	et	0	main
vabariigis	doc_491521502117_item	3693784	et	0	main
1906	doc_491521502117_item	3693785	et	0	main
a	doc_491521502117_item	3693786	et	0	main
algkoolides	doc_491521502117_item	3693787	et	0	main
on	doc_491521502117_item	3693788	et	0	main
lubatud	doc_491521502117_item	3693789	et	0	main
emakeelne	doc_491521502117_item	3693790	et	0	main
õpetus	doc_491521502117_item	3693791	et	0	main
asutavad	doc_491521502117_item	3693792	et	0	main
eestikeelseid	doc_491521502117_item	3693793	et	0	main
erakoole	doc_491521502117_item	3693794	et	0	main
riik	doc_491521502117_item	3693795	et	0	main
ei	doc_491521502117_item	3693796	et	0	main
toitnud	doc_491521502117_item	3693797	et	0	main
neid	doc_491521502117_item	3693798	et	0	main
tekkivad	doc_491521502117_item	3693799	et	0	main
kutsekoolid	doc_491521502117_item	3693800	et	0	main
1914	doc_491521502117_item	3693801	et	0	main
a	doc_491521502117_item	3693802	et	0	main
luuakse	doc_491521502117_item	3693803	et	0	main
tallinna	doc_491521502117_item	3693804	et	0	main
kunst-tööstuskool	doc_491521502117_item	3693805	et	0	main
eesti	doc_491521502117_item	3693806	et	0	main
kunsti	doc_491521502117_item	3693807	et	0	main
akadeemia	doc_491521502117_item	3693808	et	0	main
eesti	doc_491521502117_item	3693809	et	0	main
keelne	doc_491521502117_item	3693810	et	0	main
kõrghariduse	doc_491521502117_item	3693811	et	0	main
süsteem	doc_491521502117_item	3693812	et	0	main
tabas	doc_491521502117_item	3693813	et	0	main
eesti	doc_491521502117_item	3693814	et	0	main
k	doc_491521502117_item	3693815	et	0	main
ja	doc_491521502117_item	3693816	et	0	main
eesti	doc_491521502117_item	3693817	et	0	main
keelse	doc_491521502117_item	3693818	et	0	main
intelligentsi	doc_491521502117_item	3693819	et	0	main
kõrghariduse	doc_491521502117_item	3693820	et	0	main
omamine	doc_491521502117_item	3693821	et	0	main
oli	doc_491521502117_item	3693822	et	0	main
prestiižne	doc_491521502117_item	3693823	et	0	main
koolid	doc_491521502117_item	3693824	et	0	main
erakoolid	doc_491521502117_item	3693825	et	0	main
kutsekoolid	doc_491521502117_item	3693826	et	0	main
politsei	doc_491521502117_item	3693827	et	0	main
koolid	doc_491521502117_item	3693828	et	0	main
täienduskoolid	doc_491521502117_item	3693829	et	0	main
tallinnas	doc_491521502117_item	3693830	et	0	main
asuti	doc_491521502117_item	3693831	et	0	main
tallinna	doc_491521502117_item	3693832	et	0	main
tehnikakool	doc_491521502117_item	3693833	et	0	main
iseseisva	doc_491521502117_item	3693834	et	0	main
e	doc_491521502117_item	3693835	et	0	main
alguses	doc_491521502117_item	3693836	et	0	main
vene	doc_491521502117_item	3693837	et	0	main
ja	doc_491521502117_item	3693838	et	0	main
saksa	doc_491521502117_item	3693839	et	0	main
teadlaste	doc_491521502117_item	3693840	et	0	main
mõju	doc_491521502117_item	3693841	et	0	main
ja	doc_491521502117_item	3693842	et	0	main
tegevus	doc_491521502117_item	3693843	et	0	main
rahvusteadus	doc_491521502117_item	3693844	et	0	main
eesti	doc_491521502117_item	3693845	et	0	main
keele	doc_491521502117_item	3693846	et	0	main
uurimine	doc_491521502117_item	3693847	et	0	main
a	doc_491521502117_item	3693848	et	0	main
saareste	doc_491521502117_item	3693849	et	0	main
keeleuuendus	doc_491521502117_item	3693850	et	0	main
j	doc_491521502117_item	3693851	et	0	main
aavik	doc_491521502117_item	3693852	et	0	main
akad	doc_491521502117_item	3693853	et	0	main
emakeel	doc_491521502117_item	3693854	et	0	main
selts	doc_491521502117_item	3693855	et	0	main
j	doc_491521502117_item	3693856	et	0	main
mägiste	doc_491521502117_item	3693857	et	0	main
p	doc_491521502117_item	3693858	et	0	main
aariste	doc_491521502117_item	3693859	et	0	main
soome-ugri	doc_491521502117_item	3693860	et	0	main
keeleuurijad	doc_491521502117_item	3693861	et	0	main
oli	doc_491521502117_item	3693862	et	0	main
võimalik	doc_491521502117_item	3693863	et	0	main
kirjutada	doc_491521502117_item	3693864	et	0	main
teadus-	doc_491521502117_item	3693865	et	0	main
ja	doc_491521502117_item	3693866	et	0	main
ilukirjuanduse	doc_491521502117_item	3693867	et	0	main
töid	doc_491521502117_item	3693868	et	0	main
w	doc_491521502117_item	3693869	et	0	main
anderson	doc_491521502117_item	3693870	et	0	main
muinasjutude	doc_491521502117_item	3693871	et	0	main
uurija	doc_491521502117_item	3693872	et	0	main
h	doc_491521502117_item	3693873	et	0	main
tampere	doc_491521502117_item	3693874	et	0	main
esimene	doc_491521502117_item	3693875	et	0	main
muusika	doc_491521502117_item	3693876	et	0	main
kõrgharidusega	doc_491521502117_item	3693877	et	0	main
mees	doc_491521502117_item	3693878	et	0	main
2	doc_491521502117_item	3693879	et	0	main
carl	doc_491521502117_item	3693880	et	0	main
robert	doc_491521502117_item	3693881	et	0	main
jakobsoni	doc_491521502117_item	3693882	et	0	main
roll	doc_491521502117_item	3693883	et	0	main
ärkamisaegses	doc_491521502117_item	3693884	et	0	main
eestis	doc_491521502117_item	3693885	et	0	main
c	doc_491521502117_item	3693886	et	0	main
r	doc_491521502117_item	3693887	et	0	main
jakobson	doc_491521502117_item	3693888	et	0	main
3	doc_491521502117_item	3693889	et	0	main
kõnet	doc_491521502117_item	3693890	et	0	main
valguse-	doc_491521502117_item	3693891	et	0	main
pimeduse-	doc_491521502117_item	3693892	et	0	main
ja	doc_491521502117_item	3693893	et	0	main
koduajast	doc_491521502117_item	3693894	et	0	main
1	doc_491521502117_item	3693895	et	0	main
valgus	doc_491521502117_item	3693896	et	0	main
muinasaeg	doc_491521502117_item	3693897	et	0	main
enne	doc_491521502117_item	3693898	et	0	main
13	doc_491521502117_item	3693899	et	0	main
saj	doc_491521502117_item	3693900	et	0	main
uus	doc_491521502117_item	3693901	et	0	main
mütoloogia	doc_491521502117_item	3693902	et	0	main
jakobson	doc_491521502117_item	3693903	et	0	main
arvas	doc_491521502117_item	3693904	et	0	main
et	doc_491521502117_item	3693905	et	0	main
enne	doc_491521502117_item	3693906	et	0	main
ristiusku	doc_491521502117_item	3693907	et	0	main
eestlastel	doc_491521502117_item	3693908	et	0	main
oli	doc_491521502117_item	3693909	et	0	main
parem	doc_491521502117_item	3693910	et	0	main
usk	doc_491521502117_item	3693911	et	0	main
2	doc_491521502117_item	3693912	et	0	main
pimeduse	doc_491521502117_item	3693913	et	0	main
aeg	doc_491521502117_item	3693914	et	0	main
13	doc_491521502117_item	3693915	et	0	main
sajandist	doc_491521502117_item	3693916	et	0	main
tulid	doc_491521502117_item	3693917	et	0	main
ristirüütlid	doc_491521502117_item	3693918	et	0	main
pärisorjastamine	doc_491521502117_item	3693919	et	0	main
3	doc_491521502117_item	3693920	et	0	main
toiduaeg	doc_491521502117_item	3693921	et	0	main
pärisorjusest	doc_491521502117_item	3693922	et	0	main
vabastamine	doc_491521502117_item	3693923	et	0	main
1970-80	doc_491521502117_item	3693924	et	0	main
massiline	doc_491521502117_item	3693925	et	0	main
liikumine	doc_491521502117_item	3693926	et	0	main
rahvusärkamine	doc_491521502117_item	3693927	et	0	main
kultuuri	doc_491521502117_item	3693928	et	0	main
liikumine	doc_491521502117_item	3693929	et	0	main
85	doc_491521502117_item	3693930	et	0	main
omandasid	doc_491521502117_item	3693931	et	0	main
kirjaoskust	doc_491521502117_item	3693932	et	0	main
lugemisoskust	doc_491521502117_item	3693933	et	0	main
jakobsoni	doc_491521502117_item	3693934	et	0	main
roll	doc_491521502117_item	3693935	et	0	main
on	doc_491521502117_item	3693936	et	0	main
väga	doc_491521502117_item	3693937	et	0	main
suur	doc_491521502117_item	3693938	et	0	main
ta	doc_491521502117_item	3693939	et	0	main
oli	doc_491521502117_item	3693940	et	0	main
poliitik	doc_491521502117_item	3693941	et	0	main
õpetaja	doc_491521502117_item	3693942	et	0	main
kostas	doc_491521502117_item	3693943	et	0	main
kooliõpikuid	doc_491521502117_item	3693944	et	0	main
koolilugemikke	doc_491521502117_item	3693945	et	0	main
liiga	doc_491521502117_item	3693946	et	0	main
radikaalsed	doc_491521502117_item	3693947	et	0	main
ta	doc_491521502117_item	3693948	et	0	main
oli	doc_491521502117_item	3693949	et	0	main
eesti	doc_491521502117_item	3693950	et	0	main
põllumeeste	doc_491521502117_item	3693951	et	0	main
seltsis	doc_491521502117_item	3693952	et	0	main
1870	doc_491521502117_item	3693953	et	0	main
poliitik	doc_491521502117_item	3693954	et	0	main
jakobsoni	doc_491521502117_item	3693955	et	0	main
all	doc_491521502117_item	3693956	et	0	main
ilmus	doc_491521502117_item	3693957	et	0	main
sakala	doc_491521502117_item	3693958	et	0	main
ajaleht	doc_491521502117_item	3693959	et	0	main
viljandis	doc_491521502117_item	3693960	et	0	main
see	doc_491521502117_item	3693961	et	0	main
oli	doc_491521502117_item	3693962	et	0	main
poliitika	doc_491521502117_item	3693963	et	0	main
põllundus-majandus	doc_491521502117_item	3693964	et	0	main
ajaleht	doc_491521502117_item	3693965	et	0	main
3	doc_491521502117_item	3693966	et	0	main
vähemusrahvuste	doc_491521502117_item	3693967	et	0	main
kultuuri-	doc_491521502117_item	3693968	et	0	main
ja	doc_491521502117_item	3693969	et	0	main
hariduselu	doc_491521502117_item	3693970	et	0	main
eesti	doc_491521502117_item	3693971	et	0	main
vabariigis	doc_491521502117_item	3693972	et	0	main
xx	doc_491521502117_item	3693973	et	0	main
sa	doc_491521502117_item	3693974	et	0	main
alguses	doc_491521502117_item	3693975	et	0	main
tegutseid	doc_491521502117_item	3693976	et	0	main
saksa	doc_491521502117_item	3693977	et	0	main
vene	doc_491521502117_item	3693978	et	0	main
juudi	doc_491521502117_item	3693979	et	0	main
rootsi	doc_491521502117_item	3693980	et	0	main
gümnaasiumid	doc_491521502117_item	3693981	et	0	main
soomekeelne	doc_491521502117_item	3693982	et	0	main
algkool	doc_491521502117_item	3693983	et	0	main
ilmusid	doc_491521502117_item	3693984	et	0	main
saksa-	doc_491521502117_item	3693985	et	0	main
rootsi-	doc_491521502117_item	3693986	et	0	main
ja	doc_491521502117_item	3693987	et	0	main
venekeelsed	doc_491521502117_item	3693988	et	0	main
ajakirjad	doc_491521502117_item	3693989	et	0	main
kontrolltöö	doc_491521502240_item	3693990	et	0	main
1	doc_491521502240_item	3693991	et	0	main
tooge	doc_491521502240_item	3693992	et	0	main
välja	doc_491521502240_item	3693993	et	0	main
peamised	doc_491521502240_item	3693994	et	0	main
erinevused	doc_491521502240_item	3693995	et	0	main
ev	doc_491521502240_item	3693996	et	0	main
ja	doc_491521502240_item	3693997	et	0	main
ensv	doc_491521502240_item	3693998	et	0	main
ühiskonnakorralduses	doc_491521502240_item	3693999	et	0	main
ja	doc_491521502240_item	3694000	et	0	main
majanduses	doc_491521502240_item	3694001	et	0	main
2	doc_491521502240_item	3694002	et	0	main
mida	doc_491521502240_item	3694003	et	0	main
mõeldakse	doc_491521502240_item	3694004	et	0	main
kui	doc_491521502240_item	3694005	et	0	main
ensv	doc_491521502240_item	3694006	et	0	main
kultuuriajaloos	doc_491521502240_item	3694007	et	0	main
kõneldakse	doc_491521502240_item	3694008	et	0	main
nn	doc_491521502240_item	3694009	et	0	main
hrustshovi	doc_491521502240_item	3694010	et	0	main
sulast	doc_491521502240_item	3694011	et	0	main
1	doc_491521502240_item	3694012	et	0	main
24	doc_491521502240_item	3694013	et	0	main
veebruaril	doc_491521502240_item	3694014	et	0	main
1918	doc_491521502240_item	3694015	et	0	main
a	doc_491521502240_item	3694016	et	0	main
eesti	doc_491521502240_item	3694017	et	0	main
sai	doc_491521502240_item	3694018	et	0	main
iseseisvuse	doc_491521502240_item	3694019	et	0	main
siis	doc_491521502240_item	3694020	et	0	main
oli	doc_491521502240_item	3694021	et	0	main
saksa	doc_491521502240_item	3694022	et	0	main
okupatsioon	doc_491521502240_item	3694023	et	0	main
ja	doc_491521502240_item	3694024	et	0	main
hiljem	doc_491521502240_item	3694025	et	0	main
vabadussõda	doc_491521502240_item	3694026	et	0	main
mille	doc_491521502240_item	3694027	et	0	main
lõpus	doc_491521502240_item	3694028	et	0	main
kirjutati	doc_491521502240_item	3694029	et	0	main
alla	doc_491521502240_item	3694030	et	0	main
tartu	doc_491521502240_item	3694031	et	0	main
rahule	doc_491521502240_item	3694032	et	0	main
ja	doc_491521502240_item	3694033	et	0	main
eesti	doc_491521502240_item	3694034	et	0	main
hakkas	doc_491521502240_item	3694035	et	0	main
ise	doc_491521502240_item	3694036	et	0	main
edasi	doc_491521502240_item	3694037	et	0	main
arenema	doc_491521502240_item	3694038	et	0	main
valiti	doc_491521502240_item	3694039	et	0	main
riigikogu	doc_491521502240_item	3694040	et	0	main
ja	doc_491521502240_item	3694041	et	0	main
võeti	doc_491521502240_item	3694042	et	0	main
vastu	doc_491521502240_item	3694043	et	0	main
esimene	doc_491521502240_item	3694044	et	0	main
põhiseadus	doc_491521502240_item	3694045	et	0	main
presidenti	doc_491521502240_item	3694046	et	0	main
polnud	doc_491521502240_item	3694047	et	0	main
riigipeaks	doc_491521502240_item	3694048	et	0	main
sai	doc_491521502240_item	3694049	et	0	main
k	doc_491521502240_item	3694050	et	0	main
päts	doc_491521502240_item	3694051	et	0	main
kellest	doc_491521502240_item	3694052	et	0	main
ka	doc_491521502240_item	3694053	et	0	main
hiljem	doc_491521502240_item	3694054	et	0	main
sai	doc_491521502240_item	3694055	et	0	main
i	doc_491521502240_item	3694056	et	0	main
eesti	doc_491521502240_item	3694057	et	0	main
president	doc_491521502240_item	3694058	et	0	main
nüüd	doc_491521502240_item	3694059	et	0	main
eestil	doc_491521502240_item	3694060	et	0	main
oli	doc_491521502240_item	3694061	et	0	main
oma	doc_491521502240_item	3694062	et	0	main
valitsus	doc_491521502240_item	3694063	et	0	main
mis	doc_491521502240_item	3694064	et	0	main
koosnes	doc_491521502240_item	3694065	et	0	main
mitmetest	doc_491521502240_item	3694066	et	0	main
erakondadest	doc_491521502240_item	3694067	et	0	main
eestis	doc_491521502240_item	3694068	et	0	main
algas	doc_491521502240_item	3694069	et	0	main
demokraatliku	doc_491521502240_item	3694070	et	0	main
arengu	doc_491521502240_item	3694071	et	0	main
periood	doc_491521502240_item	3694072	et	0	main
vaatamata	doc_491521502240_item	3694073	et	0	main
paljudele	doc_491521502240_item	3694074	et	0	main
raskustele	doc_491521502240_item	3694075	et	0	main
eesti	doc_491521502240_item	3694076	et	0	main
majanduslik	doc_491521502240_item	3694077	et	0	main
areng	doc_491521502240_item	3694078	et	0	main
oli	doc_491521502240_item	3694079	et	0	main
edukas	doc_491521502240_item	3694080	et	0	main
muidugi	doc_491521502240_item	3694081	et	0	main
suur	doc_491521502240_item	3694082	et	0	main
depressioon	doc_491521502240_item	3694083	et	0	main
1929	doc_491521502240_item	3694084	et	0	main
a	doc_491521502240_item	3694085	et	0	main
kajastus	doc_491521502240_item	3694086	et	0	main
ka	doc_491521502240_item	3694087	et	0	main
eesti	doc_491521502240_item	3694088	et	0	main
majanduses	doc_491521502240_item	3694089	et	0	main
mis	doc_491521502240_item	3694090	et	0	main
omamoodi	doc_491521502240_item	3694091	et	0	main
sai	doc_491521502240_item	3694092	et	0	main
ka	doc_491521502240_item	3694093	et	0	main
põhjuseks	doc_491521502240_item	3694094	et	0	main
parlamentaarsele	doc_491521502240_item	3694095	et	0	main
kriisile	doc_491521502240_item	3694096	et	0	main
ühiskondlikus	doc_491521502240_item	3694097	et	0	main
elus	doc_491521502240_item	3694098	et	0	main
oli	doc_491521502240_item	3694099	et	0	main
ka	doc_491521502240_item	3694100	et	0	main
kiire	doc_491521502240_item	3694101	et	0	main
areng	doc_491521502240_item	3694102	et	0	main
probleemiks	doc_491521502240_item	3694103	et	0	main
küll	doc_491521502240_item	3694104	et	0	main
oli	doc_491521502240_item	3694105	et	0	main
iseseisvuse	doc_491521502240_item	3694106	et	0	main
vastane	doc_491521502240_item	3694107	et	0	main
võitlus	doc_491521502240_item	3694108	et	0	main
aga	doc_491521502240_item	3694109	et	0	main
vaatamata	doc_491521502240_item	3694110	et	0	main
sellele	doc_491521502240_item	3694111	et	0	main
ühiskonnas	doc_491521502240_item	3694112	et	0	main
oli	doc_491521502240_item	3694113	et	0	main
optimistlik	doc_491521502240_item	3694114	et	0	main
meeleolu	doc_491521502240_item	3694115	et	0	main
avati	doc_491521502240_item	3694116	et	0	main
eesti	doc_491521502240_item	3694117	et	0	main
keelseid	doc_491521502240_item	3694118	et	0	main
kooli	doc_491521502240_item	3694119	et	0	main
taasavati	doc_491521502240_item	3694120	et	0	main
tartu	doc_491521502240_item	3694121	et	0	main
ülikool	doc_491521502240_item	3694122	et	0	main
hakkasid	doc_491521502240_item	3694123	et	0	main
tegutsema	doc_491521502240_item	3694124	et	0	main
igasugused	doc_491521502240_item	3694125	et	0	main
seltsid	doc_491521502240_item	3694126	et	0	main
hakkas	doc_491521502240_item	3694127	et	0	main
töötama	doc_491521502240_item	3694128	et	0	main
tallinna	doc_491521502240_item	3694129	et	0	main
tehnikakõrgkool	doc_491521502240_item	3694130	et	0	main
ttü	doc_491521502240_item	3694131	et	0	main
praegu	doc_491521502240_item	3694132	et	0	main
kunstikool	doc_491521502240_item	3694133	et	0	main
konservatoorium	doc_491521502240_item	3694134	et	0	main
arenesid	doc_491521502240_item	3694135	et	0	main
teadused	doc_491521502240_item	3694136	et	0	main
eriti	doc_491521502240_item	3694137	et	0	main
rahvusteadused	doc_491521502240_item	3694138	et	0	main
e	doc_491521502240_item	3694139	et	0	main
etnoloogia	doc_491521502240_item	3694140	et	0	main
arheoloogia	doc_491521502240_item	3694141	et	0	main
ajalugu	doc_491521502240_item	3694142	et	0	main
muusika	doc_491521502240_item	3694143	et	0	main
kunsti	doc_491521502240_item	3694144	et	0	main
kirjanduse	doc_491521502240_item	3694145	et	0	main
kultuuri	doc_491521502240_item	3694146	et	0	main
tegelased	doc_491521502240_item	3694147	et	0	main
koos	doc_491521502240_item	3694148	et	0	main
iseseisvusega	doc_491521502240_item	3694149	et	0	main
said	doc_491521502240_item	3694150	et	0	main
nagu	doc_491521502240_item	3694151	et	0	main
inspiratsiooni	doc_491521502240_item	3694152	et	0	main
ja	doc_491521502240_item	3694153	et	0	main
hakkasid	doc_491521502240_item	3694154	et	0	main
looma	doc_491521502240_item	3694155	et	0	main
kultuur	doc_491521502240_item	3694156	et	0	main
arenes	doc_491521502240_item	3694157	et	0	main
kiiresti	doc_491521502240_item	3694158	et	0	main
ja	doc_491521502240_item	3694159	et	0	main
edukalt	doc_491521502240_item	3694160	et	0	main
rõhutati	doc_491521502240_item	3694161	et	0	main
rahvust	doc_491521502240_item	3694162	et	0	main
elu	doc_491521502240_item	3694163	et	0	main
muutus	doc_491521502240_item	3694164	et	0	main
paremaks	doc_491521502240_item	3694165	et	0	main
kõik	doc_491521502240_item	3694166	et	0	main
muutus	doc_491521502240_item	3694167	et	0	main
pärast	doc_491521502240_item	3694168	et	0	main
okupatsiooni	doc_491521502240_item	3694169	et	0	main
pärast	doc_491521502240_item	3694170	et	0	main
ii	doc_491521502240_item	3694171	et	0	main
ms	doc_491521502240_item	3694172	et	0	main
eesti	doc_491521502240_item	3694173	et	0	main
sai	doc_491521502240_item	3694174	et	0	main
okupeeritud	doc_491521502240_item	3694175	et	0	main
alaks	doc_491521502240_item	3694176	et	0	main
nsvl	doc_491521502240_item	3694177	et	0	main
poolt	doc_491521502240_item	3694178	et	0	main
ja	doc_491521502240_item	3694179	et	0	main
olukord	doc_491521502240_item	3694180	et	0	main
hakkas	doc_491521502240_item	3694181	et	0	main
muutuma	doc_491521502240_item	3694182	et	0	main
paljud	doc_491521502240_item	3694183	et	0	main
inimesed	doc_491521502240_item	3694184	et	0	main
põgenesid	doc_491521502240_item	3694185	et	0	main
läände	doc_491521502240_item	3694186	et	0	main
rootsi	doc_491521502240_item	3694187	et	0	main
kanadasse	doc_491521502240_item	3694188	et	0	main
austraaliasse	doc_491521502240_item	3694189	et	0	main
nl	doc_491521502240_item	3694190	et	0	main
võim	doc_491521502240_item	3694191	et	0	main
tõi	doc_491521502240_item	3694192	et	0	main
kaasa	doc_491521502240_item	3694193	et	0	main
ühiskonda	doc_491521502240_item	3694194	et	0	main
hirmu	doc_491521502240_item	3694195	et	0	main
ja	doc_491521502240_item	3694196	et	0	main
viha	doc_491521502240_item	3694197	et	0	main
algas	doc_491521502240_item	3694198	et	0	main
ideoloogiline	doc_491521502240_item	3694199	et	0	main
surutis	doc_491521502240_item	3694200	et	0	main
repressioonid	doc_491521502240_item	3694201	et	0	main
juhikultus	doc_491521502240_item	3694202	et	0	main
ja	doc_491521502240_item	3694203	et	0	main
üldse	doc_491521502240_item	3694204	et	0	main
hirmuseisund	doc_491521502240_item	3694205	et	0	main
mille	doc_491521502240_item	3694206	et	0	main
abil	doc_491521502240_item	3694207	et	0	main
valitses	doc_491521502240_item	3694208	et	0	main
stalin	doc_491521502240_item	3694209	et	0	main
võrreldes	doc_491521502240_item	3694210	et	0	main
ev	doc_491521502240_item	3694211	et	0	main
perioodiga	doc_491521502240_item	3694212	et	0	main
oli	doc_491521502240_item	3694213	et	0	main
võimatu	doc_491521502240_item	3694214	et	0	main
kannatada	doc_491521502240_item	3694215	et	0	main
majanduses	doc_491521502240_item	3694216	et	0	main
arendati	doc_491521502240_item	3694217	et	0	main
rasketööstus	doc_491521502240_item	3694218	et	0	main
hinnad	doc_491521502240_item	3694219	et	0	main
tõsteti	doc_491521502240_item	3694220	et	0	main
maksud	doc_491521502240_item	3694221	et	0	main
samuti	doc_491521502240_item	3694222	et	0	main
majandus	doc_491521502240_item	3694223	et	0	main
oli	doc_491521502240_item	3694224	et	0	main
tsentraliseeritud	doc_491521502240_item	3694225	et	0	main
ja	doc_491521502240_item	3694226	et	0	main
plaanimajandus	doc_491521502240_item	3694227	et	0	main
alguses	doc_491521502240_item	3694228	et	0	main
inimesed	doc_491521502240_item	3694229	et	0	main
püüdsid	doc_491521502240_item	3694230	et	0	main
selle	doc_491521502240_item	3694231	et	0	main
vastu	doc_491521502240_item	3694232	et	0	main
võidelda	doc_491521502240_item	3694233	et	0	main
tekkis	doc_491521502240_item	3694234	et	0	main
metsavendlus	doc_491521502240_item	3694235	et	0	main
kuid	doc_491521502240_item	3694236	et	0	main
lõpuks	doc_491521502240_item	3694237	et	0	main
hakati	doc_491521502240_item	3694238	et	0	main
sellega	doc_491521502240_item	3694239	et	0	main
kuidagi	doc_491521502240_item	3694240	et	0	main
elama	doc_491521502240_item	3694241	et	0	main
õppima	doc_491521502240_item	3694242	et	0	main
ja	doc_491521502240_item	3694243	et	0	main
harjuma	doc_491521502240_item	3694244	et	0	main
sellega	doc_491521502240_item	3694245	et	0	main
õnneks	doc_491521502240_item	3694246	et	0	main
see	doc_491521502240_item	3694247	et	0	main
kõik	doc_491521502240_item	3694248	et	0	main
lõppes	doc_491521502240_item	3694249	et	0	main
eesti	doc_491521502240_item	3694250	et	0	main
taasiseseisvumisega	doc_491521502240_item	3694251	et	0	main
ja	doc_491521502240_item	3694252	et	0	main
eesti	doc_491521502240_item	3694253	et	0	main
jälle	doc_491521502240_item	3694254	et	0	main
on	doc_491521502240_item	3694255	et	0	main
vaba	doc_491521502240_item	3694256	et	0	main
ja	doc_491521502240_item	3694257	et	0	main
iseseisev	doc_491521502240_item	3694258	et	0	main
ning	doc_491521502240_item	3694259	et	0	main
praegune	doc_491521502240_item	3694260	et	0	main
ev	doc_491521502240_item	3694261	et	0	main
olukord	doc_491521502240_item	3694262	et	0	main
võrreldes	doc_491521502240_item	3694263	et	0	main
ensv-ga	doc_491521502240_item	3694264	et	0	main
on	doc_491521502240_item	3694265	et	0	main
palju	doc_491521502240_item	3694266	et	0	main
parem	doc_491521502240_item	3694267	et	0	main
ehitati	doc_491521502240_item	3694268	et	0	main
kolhoose	doc_491521502240_item	3694269	et	0	main
ja	doc_491521502240_item	3694270	et	0	main
sovhoose	doc_491521502240_item	3694271	et	0	main
nsvl-s	doc_491521502240_item	3694272	et	0	main
läbi	doc_491521502240_item	3694273	et	0	main
viidi	doc_491521502240_item	3694274	et	0	main
reforme	doc_491521502240_item	3694275	et	0	main
ehitati	doc_491521502240_item	3694276	et	0	main
kommunismi	doc_491521502240_item	3694277	et	0	main
ideeks	doc_491521502240_item	3694278	et	0	main
oli	doc_491521502240_item	3694279	et	0	main
homo	doc_491521502240_item	3694280	et	0	main
sovetikus	doc_491521502240_item	3694281	et	0	main
mille	doc_491521502240_item	3694282	et	0	main
tõttu	doc_491521502240_item	3694283	et	0	main
vähem	doc_491521502240_item	3694284	et	0	main
rahvaste	doc_491521502240_item	3694285	et	0	main
kultuuri	doc_491521502240_item	3694286	et	0	main
arengust	doc_491521502240_item	3694287	et	0	main
eriti	doc_491521502240_item	3694288	et	0	main
ei	doc_491521502240_item	3694289	et	0	main
muretsenud	doc_491521502240_item	3694290	et	0	main
kõik	doc_491521502240_item	3694291	et	0	main
oli	doc_491521502240_item	3694292	et	0	main
riigi	doc_491521502240_item	3694293	et	0	main
kontrolli	doc_491521502240_item	3694294	et	0	main
all	doc_491521502240_item	3694295	et	0	main
2	doc_491521502240_item	3694296	et	0	main
hrustsovi	doc_491521502240_item	3694297	et	0	main
sula	doc_491521502240_item	3694298	et	0	main
see	doc_491521502240_item	3694299	et	0	main
on	doc_491521502240_item	3694300	et	0	main
hilistalinismile	doc_491521502240_item	3694301	et	0	main
järgnev	doc_491521502240_item	3694302	et	0	main
periood	doc_491521502240_item	3694303	et	0	main
millal	doc_491521502240_item	3694304	et	0	main
nsvl	doc_491521502240_item	3694305	et	0	main
võimul	doc_491521502240_item	3694306	et	0	main
oli	doc_491521502240_item	3694307	et	0	main
nikita	doc_491521502240_item	3694308	et	0	main
hrustsov	doc_491521502240_item	3694309	et	0	main
lõppes	doc_491521502240_item	3694310	et	0	main
selline	doc_491521502240_item	3694311	et	0	main
massiline	doc_491521502240_item	3694312	et	0	main
vägivalla	doc_491521502240_item	3694313	et	0	main
poliitika	doc_491521502240_item	3694314	et	0	main
majanduses	doc_491521502240_item	3694315	et	0	main
algasid	doc_491521502240_item	3694316	et	0	main
ümberkorraldused	doc_491521502240_item	3694317	et	0	main
ja	doc_491521502240_item	3694318	et	0	main
kampaaniad	doc_491521502240_item	3694319	et	0	main
maisi	doc_491521502240_item	3694320	et	0	main
hobuste	doc_491521502240_item	3694321	et	0	main
sel	doc_491521502240_item	3694322	et	0	main
perioodil	doc_491521502240_item	3694323	et	0	main
toimus	doc_491521502240_item	3694324	et	0	main
destaliniseerumine	doc_491521502240_item	3694325	et	0	main
lõppesid	doc_491521502240_item	3694326	et	0	main
repressioonid	doc_491521502240_item	3694327	et	0	main
algas	doc_491521502240_item	3694328	et	0	main
reabiliteerimine	doc_491521502240_item	3694329	et	0	main
paljud	doc_491521502240_item	3694330	et	0	main
inimesed	doc_491521502240_item	3694331	et	0	main
tulid	doc_491521502240_item	3694332	et	0	main
koju	doc_491521502240_item	3694333	et	0	main
tagasi	doc_491521502240_item	3694334	et	0	main
majanduses	doc_491521502240_item	3694335	et	0	main
on	doc_491521502240_item	3694336	et	0	main
suhteliselt	doc_491521502240_item	3694337	et	0	main
hea	doc_491521502240_item	3694338	et	0	main
aeg	doc_491521502240_item	3694339	et	0	main
sest	doc_491521502240_item	3694340	et	0	main
areng	doc_491521502240_item	3694341	et	0	main
toimus	doc_491521502240_item	3694342	et	0	main
suhteliselt	doc_491521502240_item	3694343	et	0	main
kiiresti	doc_491521502240_item	3694344	et	0	main
ühiskondlikus	doc_491521502240_item	3694345	et	0	main
plaanis	doc_491521502240_item	3694346	et	0	main
võib	doc_491521502240_item	3694347	et	0	main
öelda	doc_491521502240_item	3694348	et	0	main
et	doc_491521502240_item	3694349	et	0	main
hrustsov	doc_491521502240_item	3694350	et	0	main
oli	doc_491521502240_item	3694351	et	0	main
pehmem	doc_491521502240_item	3694352	et	0	main
kui	doc_491521502240_item	3694353	et	0	main
teised	doc_491521502240_item	3694354	et	0	main
võimukandjad	doc_491521502240_item	3694355	et	0	main
sellepärastki	doc_491521502240_item	3694356	et	0	main
nimetatakse	doc_491521502240_item	3694357	et	0	main
seda	doc_491521502240_item	3694358	et	0	main
perioodi	doc_491521502240_item	3694359	et	0	main
sulaks	doc_491521502240_item	3694360	et	0	main
ta	doc_491521502240_item	3694361	et	0	main
valitses	doc_491521502240_item	3694362	et	0	main
rohkem	doc_491521502240_item	3694363	et	0	main
intuitsiooni	doc_491521502240_item	3694364	et	0	main
järgi	doc_491521502240_item	3694365	et	0	main
mille	doc_491521502240_item	3694366	et	0	main
tõttu	doc_491521502240_item	3694367	et	0	main
stalini	doc_491521502240_item	3694368	et	0	main
poliitika	doc_491521502240_item	3694369	et	0	main
pooldajatega	doc_491521502240_item	3694370	et	0	main
ja	doc_491521502240_item	3694371	et	0	main
kõrgintelligentsiga	doc_491521502240_item	3694372	et	0	main
tal	doc_491521502240_item	3694373	et	0	main
olid	doc_491521502240_item	3694374	et	0	main
konfliktid	doc_491521502240_item	3694375	et	0	main
tema	doc_491521502240_item	3694376	et	0	main
valitsemisperioodil	doc_491521502240_item	3694377	et	0	main
üldine	doc_491521502240_item	3694378	et	0	main
olukord	doc_491521502240_item	3694379	et	0	main
paranes	doc_491521502240_item	3694380	et	0	main
elu	doc_491521502240_item	3694381	et	0	main
muutus	doc_491521502240_item	3694382	et	0	main
kergemaks	doc_491521502240_item	3694383	et	0	main
mis	doc_491521502240_item	3694384	et	0	main
puudutab	doc_491521502240_item	3694385	et	0	main
eestit	doc_491521502240_item	3694386	et	0	main
siis	doc_491521502240_item	3694387	et	0	main
arvatakse	doc_491521502240_item	3694388	et	0	main
et	doc_491521502240_item	3694389	et	0	main
nsvl	doc_491521502240_item	3694390	et	0	main
võimul	doc_491521502240_item	3694391	et	0	main
olevatest	doc_491521502240_item	3694392	et	0	main
inimestest	doc_491521502240_item	3694393	et	0	main
hrustsov	doc_491521502240_item	3694394	et	0	main
oli	doc_491521502240_item	3694395	et	0	main
kõige	doc_491521502240_item	3694396	et	0	main
inimlikum	doc_491521502240_item	3694397	et	0	main
valitseja	doc_491521502240_item	3694398	et	0	main
vaatamata	doc_491521502240_item	3694399	et	0	main
ka	doc_491521502240_item	3694400	et	0	main
tema	doc_491521502240_item	3694401	et	0	main
reformidele	doc_491521502240_item	3694402	et	0	main
kultuurielus	doc_491521502240_item	3694403	et	0	main
toimuvad	doc_491521502240_item	3694404	et	0	main
muutused	doc_491521502240_item	3694405	et	0	main
andsid	doc_491521502240_item	3694406	et	0	main
lootuse	doc_491521502240_item	3694407	et	0	main
mõnedele	doc_491521502240_item	3694408	et	0	main
inimestele	doc_491521502240_item	3694409	et	0	main
riigi	doc_491521502240_item	3694410	et	0	main
taasiseseisvumisele	doc_491521502240_item	3694411	et	0	main
ja	doc_491521502240_item	3694412	et	0	main
oma	doc_491521502240_item	3694413	et	0	main
rahvuse	doc_491521502240_item	3694414	et	0	main
säilitamisele	doc_491521502240_item	3694415	et	0	main
andsid	doc_491521502240_item	3694416	et	0	main
ka	doc_491521502240_item	3694417	et	0	main
julguse	doc_491521502240_item	3694418	et	0	main
mis	doc_491521502240_item	3694419	et	0	main
hiljem	doc_491521502240_item	3694420	et	0	main
tekitas	doc_491521502240_item	3694421	et	0	main
dissidentluse	doc_491521502240_item	3694422	et	0	main
tuntuimad	doc_491521502240_item	3694423	et	0	main
dissidendid	doc_491521502240_item	3694424	et	0	main
on	doc_491521502240_item	3694425	et	0	main
sahharov	doc_491521502240_item	3694426	et	0	main
ja	doc_491521502240_item	3694427	et	0	main
solženitsõn	doc_491521502240_item	3694428	et	0	main
palju	doc_491521502240_item	3694429	et	0	main
ehitati	doc_491521502240_item	3694430	et	0	main
eriti	doc_491521502240_item	3694431	et	0	main
elamisrajoone	doc_491521502240_item	3694432	et	0	main
mida	doc_491521502240_item	3694433	et	0	main
ka	doc_491521502240_item	3694434	et	0	main
praegu	doc_491521502240_item	3694435	et	0	main
võime	doc_491521502240_item	3694436	et	0	main
näha	doc_491521502240_item	3694437	et	0	main
igas	doc_491521502240_item	3694438	et	0	main
endises	doc_491521502240_item	3694439	et	0	main
nsvl	doc_491521502240_item	3694440	et	0	main
linnas	doc_491521502240_item	3694441	et	0	main
aga	doc_491521502240_item	3694442	et	0	main
kõigile	doc_491521502240_item	3694443	et	0	main
tuleb	doc_491521502240_item	3694444	et	0	main
lõpp	doc_491521502240_item	3694445	et	0	main
sulale	doc_491521502240_item	3694446	et	0	main
järgnes	doc_491521502240_item	3694447	et	0	main
brežnevi	doc_491521502240_item	3694448	et	0	main
valitsemisperiood	doc_491521502240_item	3694449	et	0	main
ja	doc_491521502240_item	3694450	et	0	main
stagnatsioon	doc_491521502240_item	3694451	et	0	main
kontrolltöö	doc_491521502247_item	3694452	et	0	main
1	doc_491521502247_item	3694453	et	0	main
kultuurielu	doc_491521502247_item	3694454	et	0	main
1970ndate	doc_491521502247_item	3694455	et	0	main
eesti	doc_491521502247_item	3694456	et	0	main
nsvs	doc_491521502247_item	3694457	et	0	main
2	doc_491521502247_item	3694458	et	0	main
valgus	doc_491521502247_item	3694459	et	0	main
koordis	doc_491521502247_item	3694460	et	0	main
kui	doc_491521502247_item	3694461	et	0	main
sotsialistliku	doc_491521502247_item	3694462	et	0	main
realismi	doc_491521502247_item	3694463	et	0	main
musternäidis	doc_491521502247_item	3694464	et	0	main
1	doc_491521502247_item	3694465	et	0	main
1970ndate	doc_491521502247_item	3694466	et	0	main
eestinsv	doc_491521502247_item	3694467	et	0	main
kultuurielus	doc_491521502247_item	3694468	et	0	main
saab	doc_491521502247_item	3694469	et	0	main
populaarseks	doc_491521502247_item	3694470	et	0	main
ja	doc_491521502247_item	3694471	et	0	main
oluliseks	doc_491521502247_item	3694472	et	0	main
etv	doc_491521502247_item	3694473	et	0	main
tehakse	doc_491521502247_item	3694474	et	0	main
palju	doc_491521502247_item	3694475	et	0	main
huvitavaid	doc_491521502247_item	3694476	et	0	main
lastesadeid	doc_491521502247_item	3694477	et	0	main
reklaame	doc_491521502247_item	3694478	et	0	main
viktoriinimänge	doc_491521502247_item	3694479	et	0	main
teleke	doc_491521502247_item	3694480	et	0	main
teleteatrilastusi	doc_491521502247_item	3694481	et	0	main
see	doc_491521502247_item	3694482	et	0	main
tendents	doc_491521502247_item	3694483	et	0	main
nõrgeneb	doc_491521502247_item	3694484	et	0	main
eesti	doc_491521502247_item	3694485	et	0	main
kultuurielu	doc_491521502247_item	3694486	et	0	main
kooskäimine	doc_491521502247_item	3694487	et	0	main
ja	doc_491521502247_item	3694488	et	0	main
kultuurüritused	doc_491521502247_item	3694489	et	0	main
ei	doc_491521502247_item	3694490	et	0	main
ole	doc_491521502247_item	3694491	et	0	main
enam	doc_491521502247_item	3694492	et	0	main
moes	doc_491521502247_item	3694493	et	0	main
inimesed	doc_491521502247_item	3694494	et	0	main
eelistavad	doc_491521502247_item	3694495	et	0	main
televiisori	doc_491521502247_item	3694496	et	0	main
vaatamist	doc_491521502247_item	3694497	et	0	main
selle	doc_491521502247_item	3694498	et	0	main
aja	doc_491521502247_item	3694499	et	0	main
tuntud	doc_491521502247_item	3694500	et	0	main
televisiooni	doc_491521502247_item	3694501	et	0	main
tegelased	doc_491521502247_item	3694502	et	0	main
on	doc_491521502247_item	3694503	et	0	main
valdo	doc_491521502247_item	3694504	et	0	main
pant	doc_491521502247_item	3694505	et	0	main
uno	doc_491521502247_item	3694506	et	0	main
leiis	doc_491521502247_item	3694507	et	0	main
1970	doc_491521502247_item	3694508	et	0	main
alates	doc_491521502247_item	3694509	et	0	main
tõuseb	doc_491521502247_item	3694510	et	0	main
migratsioon	doc_491521502247_item	3694511	et	0	main
eestisse	doc_491521502247_item	3694512	et	0	main
sest	doc_491521502247_item	3694513	et	0	main
majandus	doc_491521502247_item	3694514	et	0	main
arenes	doc_491521502247_item	3694515	et	0	main
kaevandused	doc_491521502247_item	3694516	et	0	main
näiteks	doc_491521502247_item	3694517	et	0	main
ja	doc_491521502247_item	3694518	et	0	main
riigile	doc_491521502247_item	3694519	et	0	main
oli	doc_491521502247_item	3694520	et	0	main
vaja	doc_491521502247_item	3694521	et	0	main
kvalititseeritud	doc_491521502247_item	3694522	et	0	main
tööjõudu	doc_491521502247_item	3694523	et	0	main
see	doc_491521502247_item	3694524	et	0	main
et	doc_491521502247_item	3694525	et	0	main
eestis	doc_491521502247_item	3694526	et	0	main
oli	doc_491521502247_item	3694527	et	0	main
suur	doc_491521502247_item	3694528	et	0	main
protsent	doc_491521502247_item	3694529	et	0	main
muulasi	doc_491521502247_item	3694530	et	0	main
mõjutas	doc_491521502247_item	3694531	et	0	main
ka	doc_491521502247_item	3694532	et	0	main
kultuurielu	doc_491521502247_item	3694533	et	0	main
muusikaelus	doc_491521502247_item	3694534	et	0	main
aktiviseeris	doc_491521502247_item	3694535	et	0	main
folkloori	doc_491521502247_item	3694536	et	0	main
liikumine	doc_491521502247_item	3694537	et	0	main
tekkisid	doc_491521502247_item	3694538	et	0	main
uued	doc_491521502247_item	3694539	et	0	main
ansamblid	doc_491521502247_item	3694540	et	0	main
nagu	doc_491521502247_item	3694541	et	0	main
neid	doc_491521502247_item	3694542	et	0	main
iseloomustas	doc_491521502247_item	3694543	et	0	main
audentsus	doc_491521502247_item	3694544	et	0	main
mis	doc_491521502247_item	3694545	et	0	main
ei	doc_491521502247_item	3694546	et	0	main
olnud	doc_491521502247_item	3694547	et	0	main
spetsialselt	doc_491521502247_item	3694548	et	0	main
lava	doc_491521502247_item	3694549	et	0	main
jaoks	doc_491521502247_item	3694550	et	0	main
läbimõeldud	doc_491521502247_item	3694551	et	0	main
kirjutati	doc_491521502247_item	3694552	et	0	main
palju	doc_491521502247_item	3694553	et	0	main
külakopelle	doc_491521502247_item	3694554	et	0	main
mis	doc_491521502247_item	3694555	et	0	main
olid	doc_491521502247_item	3694556	et	0	main
klassikalise	doc_491521502247_item	3694557	et	0	main
muusika	doc_491521502247_item	3694558	et	0	main
lähedased	doc_491521502247_item	3694559	et	0	main
kerge	doc_491521502247_item	3694560	et	0	main
popmuusika	doc_491521502247_item	3694561	et	0	main
oli	doc_491521502247_item	3694562	et	0	main
keelatud	doc_491521502247_item	3694563	et	0	main
sest	doc_491521502247_item	3694564	et	0	main
põhiliselt	doc_491521502247_item	3694565	et	0	main
oli	doc_491521502247_item	3694566	et	0	main
ta	doc_491521502247_item	3694567	et	0	main
võõrkeeles	doc_491521502247_item	3694568	et	0	main
kõik	doc_491521502247_item	3694569	et	0	main
pidi	doc_491521502247_item	3694570	et	0	main
olema	doc_491521502247_item	3694571	et	0	main
tõlgitud	doc_491521502247_item	3694572	et	0	main
eesti	doc_491521502247_item	3694573	et	0	main
keelde	doc_491521502247_item	3694574	et	0	main
see	doc_491521502247_item	3694575	et	0	main
soodustas	doc_491521502247_item	3694576	et	0	main
oma	doc_491521502247_item	3694577	et	0	main
muusika	doc_491521502247_item	3694578	et	0	main
kirjutamist	doc_491521502247_item	3694579	et	0	main
lavatsensuur	doc_491521502247_item	3694580	et	0	main
oli	doc_491521502247_item	3694581	et	0	main
suur	doc_491521502247_item	3694582	et	0	main
keelati	doc_491521502247_item	3694583	et	0	main
improviseerimine	doc_491521502247_item	3694584	et	0	main
esinemine	doc_491521502247_item	3694585	et	0	main
pidi	doc_491521502247_item	3694586	et	0	main
olema	doc_491521502247_item	3694587	et	0	main
kindla	doc_491521502247_item	3694588	et	0	main
kava	doc_491521502247_item	3694589	et	0	main
järgi	doc_491521502247_item	3694590	et	0	main
ansambel	doc_491521502247_item	3694591	et	0	main
hellero	doc_491521502247_item	3694592	et	0	main
keelati	doc_491521502247_item	3694593	et	0	main
näiteks	doc_491521502247_item	3694594	et	0	main
sest	doc_491521502247_item	3694595	et	0	main
lauljad	doc_491521502247_item	3694596	et	0	main
esinesid	doc_491521502247_item	3694597	et	0	main
erinevates	doc_491521502247_item	3694598	et	0	main
riietes	doc_491521502247_item	3694599	et	0	main
kultuurielus	doc_491521502247_item	3694600	et	0	main
oli	doc_491521502247_item	3694601	et	0	main
ka	doc_491521502247_item	3694602	et	0	main
selline	doc_491521502247_item	3694603	et	0	main
tähtis	doc_491521502247_item	3694604	et	0	main
muudatus	doc_491521502247_item	3694605	et	0	main
et	doc_491521502247_item	3694606	et	0	main
tü	doc_491521502247_item	3694607	et	0	main
vahetati	doc_491521502247_item	3694608	et	0	main
rektorit	doc_491521502247_item	3694609	et	0	main
uus	doc_491521502247_item	3694610	et	0	main
rektor	doc_491521502247_item	3694611	et	0	main
oli	doc_491521502247_item	3694612	et	0	main
nõrga	doc_491521502247_item	3694613	et	0	main
haridusega	doc_491521502247_item	3694614	et	0	main
ta	doc_491521502247_item	3694615	et	0	main
oli	doc_491521502247_item	3694616	et	0	main
meremees	doc_491521502247_item	3694617	et	0	main
ja	doc_491521502247_item	3694618	et	0	main
võib	doc_491521502247_item	3694619	et	0	main
olla	doc_491521502247_item	3694620	et	0	main
seelle	doc_491521502247_item	3694621	et	0	main
pärast	doc_491521502247_item	3694622	et	0	main
teema	doc_491521502247_item	3694623	et	0	main
uuendused	doc_491521502247_item	3694624	et	0	main
ei	doc_491521502247_item	3694625	et	0	main
olnud	doc_491521502247_item	3694626	et	0	main
eriti	doc_491521502247_item	3694627	et	0	main
kasulikut	doc_491521502247_item	3694628	et	0	main
tü	doc_491521502247_item	3694629	et	0	main
jaoks	doc_491521502247_item	3694630	et	0	main
näiteks	doc_491521502247_item	3694631	et	0	main
hinnet	doc_491521502247_item	3694632	et	0	main
pandi	doc_491521502247_item	3694633	et	0	main
selle	doc_491521502247_item	3694634	et	0	main
järgi	doc_491521502247_item	3694635	et	0	main
kuidas	doc_491521502247_item	3694636	et	0	main
tudeng	doc_491521502247_item	3694637	et	0	main
loengutel	doc_491521502247_item	3694638	et	0	main
oli	doc_491521502247_item	3694639	et	0	main
käinud	doc_491521502247_item	3694640	et	0	main
kõik	doc_491521502247_item	3694641	et	0	main
poisid	doc_491521502247_item	3694642	et	0	main
õpingu	doc_491521502247_item	3694643	et	0	main
sees	doc_491521502247_item	3694644	et	0	main
pidid	doc_491521502247_item	3694645	et	0	main
tegema	doc_491521502247_item	3694646	et	0	main
sõjaväelise	doc_491521502247_item	3694647	et	0	main
ettevalmistuseksami	doc_491521502247_item	3694648	et	0	main
muidu	doc_491521502247_item	3694649	et	0	main
edasi	doc_491521502247_item	3694650	et	0	main
õppida	doc_491521502247_item	3694651	et	0	main
ei	doc_491521502247_item	3694652	et	0	main
saa	doc_491521502247_item	3694653	et	0	main
tüdrukud	doc_491521502247_item	3694654	et	0	main
pidid	doc_491521502247_item	3694655	et	0	main
läbima	doc_491521502247_item	3694656	et	0	main
medõe	doc_491521502247_item	3694657	et	0	main
kursused	doc_491521502247_item	3694658	et	0	main
hariduse	doc_491521502247_item	3694659	et	0	main
kohta	doc_491521502247_item	3694660	et	0	main
võiks	doc_491521502247_item	3694661	et	0	main
lisada	doc_491521502247_item	3694662	et	0	main
ka	doc_491521502247_item	3694663	et	0	main
see	doc_491521502247_item	3694664	et	0	main
et	doc_491521502247_item	3694665	et	0	main
eesti	doc_491521502247_item	3694666	et	0	main
ja	doc_491521502247_item	3694667	et	0	main
vene	doc_491521502247_item	3694668	et	0	main
haridusprogramm	doc_491521502247_item	3694669	et	0	main
ei	doc_491521502247_item	3694670	et	0	main
langenud	doc_491521502247_item	3694671	et	0	main
kokku	doc_491521502247_item	3694672	et	0	main
eesti	doc_491521502247_item	3694673	et	0	main
koolis	doc_491521502247_item	3694674	et	0	main
õpiti	doc_491521502247_item	3694675	et	0	main
10	doc_491521502247_item	3694676	et	0	main
a	doc_491521502247_item	3694677	et	0	main
aga	doc_491521502247_item	3694678	et	0	main
vene	doc_491521502247_item	3694679	et	0	main
koolis	doc_491521502247_item	3694680	et	0	main
11	doc_491521502247_item	3694681	et	0	main
aastad	doc_491521502247_item	3694682	et	0	main
eesti	doc_491521502247_item	3694683	et	0	main
koolides	doc_491521502247_item	3694684	et	0	main
õpiti	doc_491521502247_item	3694685	et	0	main
palju	doc_491521502247_item	3694686	et	0	main
vene	doc_491521502247_item	3694687	et	0	main
keelt	doc_491521502247_item	3694688	et	0	main
nädalas	doc_491521502247_item	3694689	et	0	main
oli	doc_491521502247_item	3694690	et	0	main
4	doc_491521502247_item	3694691	et	0	main
tundi	doc_491521502247_item	3694692	et	0	main
vene	doc_491521502247_item	3694693	et	0	main
keelt	doc_491521502247_item	3694694	et	0	main
võrreldes	doc_491521502247_item	3694695	et	0	main
sellega	doc_491521502247_item	3694696	et	0	main
eesti	doc_491521502247_item	3694697	et	0	main
ja	doc_491521502247_item	3694698	et	0	main
võõrkeelt	doc_491521502247_item	3694699	et	0	main
oli	doc_491521502247_item	3694700	et	0	main
vähem	doc_491521502247_item	3694701	et	0	main
2	doc_491521502247_item	3694702	et	0	main
tundi	doc_491521502247_item	3694703	et	0	main
avati	doc_491521502247_item	3694704	et	0	main
sellel	doc_491521502247_item	3694705	et	0	main
ajal	doc_491521502247_item	3694706	et	0	main
uus	doc_491521502247_item	3694707	et	0	main
asutus	doc_491521502247_item	3694708	et	0	main
sotsioloogia	doc_491521502247_item	3694709	et	0	main
labor	doc_491521502247_item	3694710	et	0	main
seal	doc_491521502247_item	3694711	et	0	main
töötasid	doc_491521502247_item	3694712	et	0	main
näiteks	doc_491521502247_item	3694713	et	0	main
vooglaid	doc_491521502247_item	3694714	et	0	main
m	doc_491521502247_item	3694715	et	0	main
lauristin	doc_491521502247_item	3694716	et	0	main
aga	doc_491521502247_item	3694717	et	0	main
väga	doc_491521502247_item	3694718	et	0	main
kiiresti	doc_491521502247_item	3694719	et	0	main
nende	doc_491521502247_item	3694720	et	0	main
töö	doc_491521502247_item	3694721	et	0	main
oli	doc_491521502247_item	3694722	et	0	main
keelatud	doc_491521502247_item	3694723	et	0	main
ja	doc_491521502247_item	3694724	et	0	main
asutus	doc_491521502247_item	3694725	et	0	main
pandi	doc_491521502247_item	3694726	et	0	main
kinni	doc_491521502247_item	3694727	et	0	main
sest	doc_491521502247_item	3694728	et	0	main
ta	doc_491521502247_item	3694729	et	0	main
ei	doc_491521502247_item	3694730	et	0	main
olnud	doc_491521502247_item	3694731	et	0	main
vastuvõttav	doc_491521502247_item	3694732	et	0	main
nl-le	doc_491521502247_item	3694733	et	0	main
70-ndatel	doc_491521502247_item	3694734	et	0	main
aastatel	doc_491521502247_item	3694735	et	0	main
paranes	doc_491521502247_item	3694736	et	0	main
inimeste	doc_491521502247_item	3694737	et	0	main
heaolu	doc_491521502247_item	3694738	et	0	main
tarbekaupa	doc_491521502247_item	3694739	et	0	main
võis	doc_491521502247_item	3694740	et	0	main
osta	doc_491521502247_item	3694741	et	0	main
järelmaksuga	doc_491521502247_item	3694742	et	0	main
vaibad	doc_491521502247_item	3694743	et	0	main
diivanid	doc_491521502247_item	3694744	et	0	main
oli	doc_491521502247_item	3694745	et	0	main
võimalik	doc_491521502247_item	3694746	et	0	main
saada	doc_491521502247_item	3694747	et	0	main
erisoodustused	doc_491521502247_item	3694748	et	0	main
luksuskaubadele	doc_491521502247_item	3694749	et	0	main
auto	doc_491521502247_item	3694750	et	0	main
külmkapp	doc_491521502247_item	3694751	et	0	main
samal	doc_491521502247_item	3694752	et	0	main
ajal	doc_491521502247_item	3694753	et	0	main
toodeti	doc_491521502247_item	3694754	et	0	main
ka	doc_491521502247_item	3694755	et	0	main
palju	doc_491521502247_item	3694756	et	0	main
mõttetu	doc_491521502247_item	3694757	et	0	main
asju	doc_491521502247_item	3694758	et	0	main
nt	doc_491521502247_item	3694759	et	0	main
märke	doc_491521502247_item	3694760	et	0	main
1972-73	doc_491521502247_item	3694761	et	0	main
tüdrukud	doc_491521502247_item	3694762	et	0	main
said	doc_491521502247_item	3694763	et	0	main
kanda	doc_491521502247_item	3694764	et	0	main
püksid	doc_491521502247_item	3694765	et	0	main
nagu	doc_491521502247_item	3694766	et	0	main
koolivorm	doc_491521502247_item	3694767	et	0	main
1973	doc_491521502247_item	3694768	et	0	main
a	doc_491521502247_item	3694769	et	0	main
avati	doc_491521502247_item	3694770	et	0	main
1	doc_491521502247_item	3694771	et	0	main
koomiksiline	doc_491521502247_item	3694772	et	0	main
trükitis	doc_491521502247_item	3694773	et	0	main
1970	doc_491521502247_item	3694774	et	0	main
a	doc_491521502247_item	3694775	et	0	main
ilmus	doc_491521502247_item	3694776	et	0	main
eesti	doc_491521502247_item	3694777	et	0	main
keelne	doc_491521502247_item	3694778	et	0	main
raamat	doc_491521502247_item	3694779	et	0	main
avameelselt	doc_491521502247_item	3694780	et	0	main
abielust	doc_491521502247_item	3694781	et	0	main
need	doc_491521502247_item	3694782	et	0	main
väikesed	doc_491521502247_item	3694783	et	0	main
muudatused	doc_491521502247_item	3694784	et	0	main
andsid	doc_491521502247_item	3694785	et	0	main
eestlastel	doc_491521502247_item	3694786	et	0	main
võimaluse	doc_491521502247_item	3694787	et	0	main
tunda	doc_491521502247_item	3694788	et	0	main
ennast	doc_491521502247_item	3694789	et	0	main
rohkem	doc_491521502247_item	3694790	et	0	main
lääne	doc_491521502247_item	3694791	et	0	main
rahvana	doc_491521502247_item	3694792	et	0	main
suurt	doc_491521502247_item	3694793	et	0	main
mõju	doc_491521502247_item	3694794	et	0	main
avaldas	doc_491521502247_item	3694795	et	0	main
kindlasti	doc_491521502247_item	3694796	et	0	main
soome	doc_491521502247_item	3694797	et	0	main
televisioon	doc_491521502247_item	3694798	et	0	main
mida	doc_491521502247_item	3694799	et	0	main
põhja-eestlased	doc_491521502247_item	3694800	et	0	main
said	doc_491521502247_item	3694801	et	0	main
vaadata	doc_491521502247_item	3694802	et	0	main
70ndatel	doc_491521502247_item	3694803	et	0	main
hakab	doc_491521502247_item	3694804	et	0	main
töötama	doc_491521502247_item	3694805	et	0	main
helsingi-tallinna	doc_491521502247_item	3694806	et	0	main
laevaliin	doc_491521502247_item	3694807	et	0	main
mis	doc_491521502247_item	3694808	et	0	main
toob	doc_491521502247_item	3694809	et	0	main
eestisse	doc_491521502247_item	3694810	et	0	main
palju	doc_491521502247_item	3694811	et	0	main
turiste	doc_491521502247_item	3694812	et	0	main
avati	doc_491521502247_item	3694813	et	0	main
viru	doc_491521502247_item	3694814	et	0	main
hotell	doc_491521502247_item	3694815	et	0	main
ja	doc_491521502247_item	3694816	et	0	main
palju	doc_491521502247_item	3694817	et	0	main
valutakauplusi	doc_491521502247_item	3694818	et	0	main
kus	doc_491521502247_item	3694819	et	0	main
mundi	doc_491521502247_item	3694820	et	0	main
eesti	doc_491521502247_item	3694821	et	0	main
rahva	doc_491521502247_item	3694822	et	0	main
käsitöösuveniire	doc_491521502247_item	3694823	et	0	main
kui	doc_491521502247_item	3694824	et	0	main
rääkida	doc_491521502247_item	3694825	et	0	main
70ndate	doc_491521502247_item	3694826	et	0	main
aastate	doc_491521502247_item	3694827	et	0	main
kirjandusest	doc_491521502247_item	3694828	et	0	main
võib	doc_491521502247_item	3694829	et	0	main
öelda	doc_491521502247_item	3694830	et	0	main
et	doc_491521502247_item	3694831	et	0	main
paljud	doc_491521502247_item	3694832	et	0	main
eesti	doc_491521502247_item	3694833	et	0	main
kirjanikud	doc_491521502247_item	3694834	et	0	main
olid	doc_491521502247_item	3694835	et	0	main
sellel	doc_491521502247_item	3694836	et	0	main
ajal	doc_491521502247_item	3694837	et	0	main
välismaal	doc_491521502247_item	3694838	et	0	main
ja	doc_491521502247_item	3694839	et	0	main
kirjutasid	doc_491521502247_item	3694840	et	0	main
seal	doc_491521502247_item	3694841	et	0	main
väliseesti	doc_491521502247_item	3694842	et	0	main
kirjanikud	doc_491521502247_item	3694843	et	0	main
olid	doc_491521502247_item	3694844	et	0	main
nt	doc_491521502247_item	3694845	et	0	main
j	doc_491521502247_item	3694846	et	0	main
vask	doc_491521502247_item	3694847	et	0	main
k	doc_491521502247_item	3694848	et	0	main
lepik	doc_491521502247_item	3694849	et	0	main
m	doc_491521502247_item	3694850	et	0	main
under	doc_491521502247_item	3694851	et	0	main
selle	doc_491521502247_item	3694852	et	0	main
aja	doc_491521502247_item	3694853	et	0	main
tuntumaid	doc_491521502247_item	3694854	et	0	main
teosed	doc_491521502247_item	3694855	et	0	main
olid	doc_491521502247_item	3694856	et	0	main
a	doc_491521502247_item	3694857	et	0	main
hint	doc_491521502247_item	3694858	et	0	main
tuuline	doc_491521502247_item	3694859	et	0	main
rand	doc_491521502247_item	3694860	et	0	main
m	doc_491521502247_item	3694861	et	0	main
traat	doc_491521502247_item	3694862	et	0	main
inger	doc_491521502247_item	3694863	et	0	main
härala	doc_491521502247_item	3694864	et	0	main
elulood	doc_491521502247_item	3694865	et	0	main
romaanide	doc_491521502247_item	3694866	et	0	main
järdi	doc_491521502247_item	3694867	et	0	main
tehti	doc_491521502247_item	3694868	et	0	main
ka	doc_491521502247_item	3694869	et	0	main
palju	doc_491521502247_item	3694870	et	0	main
filme	doc_491521502247_item	3694871	et	0	main
nt	doc_491521502247_item	3694872	et	0	main
k	doc_491521502247_item	3694873	et	0	main
kiisk	doc_491521502247_item	3694874	et	0	main
hullumeesus	doc_491521502247_item	3694875	et	0	main
tuntud	doc_491521502247_item	3694876	et	0	main
eesti	doc_491521502247_item	3694877	et	0	main
režissöörid	doc_491521502247_item	3694878	et	0	main
olid	doc_491521502247_item	3694879	et	0	main
ka	doc_491521502247_item	3694880	et	0	main
l	doc_491521502247_item	3694881	et	0	main
laius	doc_491521502247_item	3694882	et	0	main
ja	doc_491521502247_item	3694883	et	0	main
k	doc_491521502247_item	3694884	et	0	main
komissarov	doc_491521502247_item	3694885	et	0	main
2	doc_491521502247_item	3694886	et	0	main
valgus	doc_491521502247_item	3694887	et	0	main
koordis	doc_491521502247_item	3694888	et	0	main
on	doc_491521502247_item	3694889	et	0	main
kindlasti	doc_491521502247_item	3694890	et	0	main
väga	doc_491521502247_item	3694891	et	0	main
hea	doc_491521502247_item	3694892	et	0	main
näidis	doc_491521502247_item	3694893	et	0	main
sellest	doc_491521502247_item	3694894	et	0	main
kuidas	doc_491521502247_item	3694895	et	0	main
sotsialistlik	doc_491521502247_item	3694896	et	0	main
realism	doc_491521502247_item	3694897	et	0	main
oli	doc_491521502247_item	3694898	et	0	main
väga	doc_491521502247_item	3694899	et	0	main
laualt	doc_491521502247_item	3694900	et	0	main
levinud	doc_491521502247_item	3694901	et	0	main
nl	doc_491521502247_item	3694902	et	0	main
kunstis	doc_491521502247_item	3694903	et	0	main
filmikunstis	doc_491521502247_item	3694904	et	0	main
kirjanduses	doc_491521502247_item	3694905	et	0	main
muusikas	doc_491521502247_item	3694906	et	0	main
seal	doc_491521502247_item	3694907	et	0	main
näidatakse	doc_491521502247_item	3694908	et	0	main
kuidas	doc_491521502247_item	3694909	et	0	main
peab	doc_491521502247_item	3694910	et	0	main
võib	doc_491521502247_item	3694911	et	0	main
sotsialismi	doc_491521502247_item	3694912	et	0	main
ajal	doc_491521502247_item	3694913	et	0	main
elada	doc_491521502247_item	3694914	et	0	main
millised	doc_491521502247_item	3694915	et	0	main
inimesed	doc_491521502247_item	3694916	et	0	main
peavad	doc_491521502247_item	3694917	et	0	main
olema	doc_491521502247_item	3694918	et	0	main
millega	doc_491521502247_item	3694919	et	0	main
nad	doc_491521502247_item	3694920	et	0	main
tegelevad	doc_491521502247_item	3694921	et	0	main
ja	doc_491521502247_item	3694922	et	0	main
kuidas	doc_491521502247_item	3694923	et	0	main
sellesse	doc_491521502247_item	3694924	et	0	main
sõimusse	doc_491521502247_item	3694925	et	0	main
sotsialistlikku	doc_491521502247_item	3694926	et	0	main
suhtutakse	doc_491521502247_item	3694927	et	0	main
kontrolltöö	doc_491521502252_item	3694928	et	0	main
1	doc_491521502252_item	3694929	et	0	main
majanduse	doc_491521502252_item	3694930	et	0	main
ja	doc_491521502252_item	3694931	et	0	main
loodushoiu	doc_491521502252_item	3694932	et	0	main
vastasseis	doc_491521502252_item	3694933	et	0	main
1970ndate	doc_491521502252_item	3694934	et	0	main
eesti	doc_491521502252_item	3694935	et	0	main
nsv-s	doc_491521502252_item	3694936	et	0	main
2	doc_491521502252_item	3694937	et	0	main
kellel	doc_491521502252_item	3694938	et	0	main
on	doc_491521502252_item	3694939	et	0	main
teie	doc_491521502252_item	3694940	et	0	main
arvates	doc_491521502252_item	3694941	et	0	main
suuremad	doc_491521502252_item	3694942	et	0	main
identiteediprobleemid	doc_491521502252_item	3694943	et	0	main
kas	doc_491521502252_item	3694944	et	0	main
erikal	doc_491521502252_item	3694945	et	0	main
või	doc_491521502252_item	3694946	et	0	main
oskaril	doc_491521502252_item	3694947	et	0	main
tammsaare	doc_491521502252_item	3694948	et	0	main
ma	doc_491521502252_item	3694949	et	0	main
armastasin	doc_491521502252_item	3694950	et	0	main
sakslast	doc_491521502252_item	3694951	et	0	main
põhjendage	doc_491521502252_item	3694952	et	0	main
1	doc_491521502252_item	3694953	et	0	main
1970ndatel	doc_491521502252_item	3694954	et	0	main
algas	doc_491521502252_item	3694955	et	0	main
eesti	doc_491521502252_item	3694956	et	0	main
nsv-s	doc_491521502252_item	3694957	et	0	main
suur	doc_491521502252_item	3694958	et	0	main
põlevkivi	doc_491521502252_item	3694959	et	0	main
kaevandamine	doc_491521502252_item	3694960	et	0	main
tööliseid	doc_491521502252_item	3694961	et	0	main
viidi	doc_491521502252_item	3694962	et	0	main
sisse	doc_491521502252_item	3694963	et	0	main
nsvl-st	doc_491521502252_item	3694964	et	0	main
ja	doc_491521502252_item	3694965	et	0	main
eestis	doc_491521502252_item	3694966	et	0	main
oli	doc_491521502252_item	3694967	et	0	main
suur	doc_491521502252_item	3694968	et	0	main
nn	doc_491521502252_item	3694969	et	0	main
massiline	doc_491521502252_item	3694970	et	0	main
sissevool	doc_491521502252_item	3694971	et	0	main
välismaalasi	doc_491521502252_item	3694972	et	0	main
kaevandamine	doc_491521502252_item	3694973	et	0	main
oli	doc_491521502252_item	3694974	et	0	main
grandioosne	doc_491521502252_item	3694975	et	0	main
ja	doc_491521502252_item	3694976	et	0	main
keegi	doc_491521502252_item	3694977	et	0	main
tol	doc_491521502252_item	3694978	et	0	main
ajal	doc_491521502252_item	3694979	et	0	main
ei	doc_491521502252_item	3694980	et	0	main
mõelnud	doc_491521502252_item	3694981	et	0	main
ja	doc_491521502252_item	3694982	et	0	main
ei	doc_491521502252_item	3694983	et	0	main
arvestatud	doc_491521502252_item	3694984	et	0	main
sellega	doc_491521502252_item	3694985	et	0	main
millised	doc_491521502252_item	3694986	et	0	main
tulemused	doc_491521502252_item	3694987	et	0	main
see	doc_491521502252_item	3694988	et	0	main
toob	doc_491521502252_item	3694989	et	0	main
eestise	doc_491521502252_item	3694990	et	0	main
pärast	doc_491521502252_item	3694991	et	0	main
millised	doc_491521502252_item	3694992	et	0	main
ökoloogilised	doc_491521502252_item	3694993	et	0	main
probleemid	doc_491521502252_item	3694994	et	0	main
kaevandamine	doc_491521502252_item	3694995	et	0	main
ei	doc_491521502252_item	3694996	et	0	main
olnud	doc_491521502252_item	3694997	et	0	main
ratsionalistlik	doc_491521502252_item	3694998	et	0	main
ja	doc_491521502252_item	3694999	et	0	main
sellega	doc_491521502252_item	3695000	et	0	main
eesti	doc_491521502252_item	3695001	et	0	main
loodusvarad	doc_491521502252_item	3695002	et	0	main
maavarad	doc_491521502252_item	3695003	et	0	main
peaaegu	doc_491521502252_item	3695004	et	0	main
tühistati	doc_491521502252_item	3695005	et	0	main
kui	doc_491521502252_item	3695006	et	0	main
sama	doc_491521502252_item	3695007	et	0	main
tegevus	doc_491521502252_item	3695008	et	0	main
ei	doc_491521502252_item	3695009	et	0	main
lõpeks	doc_491521502252_item	3695010	et	0	main
siis	doc_491521502252_item	3695011	et	0	main
1973	doc_491521502252_item	3695012	et	0	main
a	doc_491521502252_item	3695013	et	0	main
ehitatakse	doc_491521502252_item	3695014	et	0	main
balti	doc_491521502252_item	3695015	et	0	main
soojus	doc_491521502252_item	3695016	et	0	main
elektrijaam	doc_491521502252_item	3695017	et	0	main
põlevkivi	doc_491521502252_item	3695018	et	0	main
saakd	doc_491521502252_item	3695019	et	0	main
olla	doc_491521502252_item	3695020	et	0	main
peaaegu	doc_491521502252_item	3695021	et	0	main
kõik	doc_491521502252_item	3695022	et	0	main
kaendatud	doc_491521502252_item	3695023	et	0	main
põlevkivi	doc_491521502252_item	3695024	et	0	main
kasutati	doc_491521502252_item	3695025	et	0	main
majade	doc_491521502252_item	3695026	et	0	main
ehitamiseks	doc_491521502252_item	3695027	et	0	main
ja	doc_491521502252_item	3695028	et	0	main
teiste	doc_491521502252_item	3695029	et	0	main
vajaduste	doc_491521502252_item	3695030	et	0	main
jaoks	doc_491521502252_item	3695031	et	0	main
kuid	doc_491521502252_item	3695032	et	0	main
ei	doc_491521502252_item	3695033	et	0	main
olnud	doc_491521502252_item	3695034	et	0	main
vajalik	doc_491521502252_item	3695035	et	0	main
nii	doc_491521502252_item	3695036	et	0	main
palju	doc_491521502252_item	3695037	et	0	main
kaevandata	doc_491521502252_item	3695038	et	0	main
selleks	doc_491521502252_item	3695039	et	0	main
tuli	doc_491521502252_item	3695040	et	0	main
ka	doc_491521502252_item	3695041	et	0	main
tööle	doc_491521502252_item	3695042	et	0	main
võtta	doc_491521502252_item	3695043	et	0	main
palju	doc_491521502252_item	3695044	et	0	main
inimesi	doc_491521502252_item	3695045	et	0	main
töölisi	doc_491521502252_item	3695046	et	0	main
eestisse	doc_491521502252_item	3695047	et	0	main
emmigreerisid	doc_491521502252_item	3695048	et	0	main
paljud	doc_491521502252_item	3695049	et	0	main
nsvl	doc_491521502252_item	3695050	et	0	main
erinevates	doc_491521502252_item	3695051	et	0	main
kohtades	doc_491521502252_item	3695052	et	0	main
elanud	doc_491521502252_item	3695053	et	0	main
muulaste	doc_491521502252_item	3695054	et	0	main
migratsioon	doc_491521502252_item	3695055	et	0	main
oli	doc_491521502252_item	3695056	et	0	main
nii	doc_491521502252_item	3695057	et	0	main
suur	doc_491521502252_item	3695058	et	0	main
et	doc_491521502252_item	3695059	et	0	main
iga	doc_491521502252_item	3695060	et	0	main
aastane	doc_491521502252_item	3695061	et	0	main
sissevool	doc_491521502252_item	3695062	et	0	main
oli	doc_491521502252_item	3695063	et	0	main
10000	doc_491521502252_item	3695064	et	0	main
inimest	doc_491521502252_item	3695065	et	0	main
seega	doc_491521502252_item	3695066	et	0	main
1970ndate	doc_491521502252_item	3695067	et	0	main
lõpus	doc_491521502252_item	3695068	et	0	main
osakaal	doc_491521502252_item	3695069	et	0	main
muulasi	doc_491521502252_item	3695070	et	0	main
eestis	doc_491521502252_item	3695071	et	0	main
oli	doc_491521502252_item	3695072	et	0	main
33	doc_491521502252_item	3695073	et	0	main
kõike	doc_491521502252_item	3695074	et	0	main
selle	doc_491521502252_item	3695075	et	0	main
tulemusega	doc_491521502252_item	3695076	et	0	main
hakkas	doc_491521502252_item	3695077	et	0	main
suur	doc_491521502252_item	3695078	et	0	main
loodushoiu	doc_491521502252_item	3695079	et	0	main
vastasseis	doc_491521502252_item	3695080	et	0	main
rohelised	doc_491521502252_item	3695081	et	0	main
hakkasid	doc_491521502252_item	3695082	et	0	main
rohkem	doc_491521502252_item	3695083	et	0	main
mõtlema	doc_491521502252_item	3695084	et	0	main
eestimaa	doc_491521502252_item	3695085	et	0	main
looduse	doc_491521502252_item	3695086	et	0	main
ja	doc_491521502252_item	3695087	et	0	main
maavarade	doc_491521502252_item	3695088	et	0	main
säilitamisest	doc_491521502252_item	3695089	et	0	main
1974	doc_491521502252_item	3695090	et	0	main
a	doc_491521502252_item	3695091	et	0	main
avati	doc_491521502252_item	3695092	et	0	main
esimene	doc_491521502252_item	3695093	et	0	main
eestis	doc_491521502252_item	3695094	et	0	main
ja	doc_491521502252_item	3695095	et	0	main
ka	doc_491521502252_item	3695096	et	0	main
baltikumis	doc_491521502252_item	3695097	et	0	main
rahvuspark	doc_491521502252_item	3695098	et	0	main
lahemaa	doc_491521502252_item	3695099	et	0	main
rahvuspark	doc_491521502252_item	3695100	et	0	main
majandus	doc_491521502252_item	3695101	et	0	main
ei	doc_491521502252_item	3695102	et	0	main
olnud	doc_491521502252_item	3695103	et	0	main
korras	doc_491521502252_item	3695104	et	0	main
ka	doc_491521502252_item	3695105	et	0	main
palju	doc_491521502252_item	3695106	et	0	main
tooteid	doc_491521502252_item	3695107	et	0	main
ei	doc_491521502252_item	3695108	et	0	main
olnud	doc_491521502252_item	3695109	et	0	main
lihtsalt	doc_491521502252_item	3695110	et	0	main
võimalik	doc_491521502252_item	3695111	et	0	main
kauplustes	doc_491521502252_item	3695112	et	0	main
leida	doc_491521502252_item	3695113	et	0	main
inimestel	doc_491521502252_item	3695114	et	0	main
oli	doc_491521502252_item	3695115	et	0	main
raha	doc_491521502252_item	3695116	et	0	main
kuid	doc_491521502252_item	3695117	et	0	main
selleks	doc_491521502252_item	3695118	et	0	main
et	doc_491521502252_item	3695119	et	0	main
osta	doc_491521502252_item	3695120	et	0	main
midagi	doc_491521502252_item	3695121	et	0	main
defitsiitset	doc_491521502252_item	3695122	et	0	main
oli	doc_491521502252_item	3695123	et	0	main
vaja	doc_491521502252_item	3695124	et	0	main
oodata	doc_491521502252_item	3695125	et	0	main
mõne	doc_491521502252_item	3695126	et	0	main
aja	doc_491521502252_item	3695127	et	0	main
näiteks	doc_491521502252_item	3695128	et	0	main
et	doc_491521502252_item	3695129	et	0	main
osta	doc_491521502252_item	3695130	et	0	main
auto	doc_491521502252_item	3695131	et	0	main
või	doc_491521502252_item	3695132	et	0	main
jääkappi	doc_491521502252_item	3695133	et	0	main
pidi	doc_491521502252_item	3695134	et	0	main
saama	doc_491521502252_item	3695135	et	0	main
luba	doc_491521502252_item	3695136	et	0	main
millega	doc_491521502252_item	3695137	et	0	main
sulle	doc_491521502252_item	3695138	et	0	main
anti	doc_491521502252_item	3695139	et	0	main
võimalust	doc_491521502252_item	3695140	et	0	main
seda	doc_491521502252_item	3695141	et	0	main
teha	doc_491521502252_item	3695142	et	0	main
niisugune	doc_491521502252_item	3695143	et	0	main
situatsioon	doc_491521502252_item	3695144	et	0	main
viis	doc_491521502252_item	3695145	et	0	main
sellele	doc_491521502252_item	3695146	et	0	main
et	doc_491521502252_item	3695147	et	0	main
hakkas	doc_491521502252_item	3695148	et	0	main
tegutsema	doc_491521502252_item	3695149	et	0	main
nn	doc_491521502252_item	3695150	et	0	main
laua	doc_491521502252_item	3695151	et	0	main
aluna	doc_491521502252_item	3695152	et	0	main
turg	doc_491521502252_item	3695153	et	0	main
sina	doc_491521502252_item	3695154	et	0	main
mulle	doc_491521502252_item	3695155	et	0	main
ja	doc_491521502252_item	3695156	et	0	main
mina	doc_491521502252_item	3695157	et	0	main
sulle	doc_491521502252_item	3695158	et	0	main
muidugi	doc_491521502252_item	3695159	et	0	main
rahvas	doc_491521502252_item	3695160	et	0	main
ei	doc_491521502252_item	3695161	et	0	main
olnud	doc_491521502252_item	3695162	et	0	main
sellega	doc_491521502252_item	3695163	et	0	main
rahul	doc_491521502252_item	3695164	et	0	main
ja	doc_491521502252_item	3695165	et	0	main
hakkas	doc_491521502252_item	3695166	et	0	main
natuke	doc_491521502252_item	3695167	et	0	main
paranes	doc_491521502252_item	3695168	et	0	main
kuid	doc_491521502252_item	3695169	et	0	main
samal	doc_491521502252_item	3695170	et	0	main
ajal	doc_491521502252_item	3695171	et	0	main
peaaegu	doc_491521502252_item	3695172	et	0	main
ei	doc_491521502252_item	3695173	et	0	main
muutunud	doc_491521502252_item	3695174	et	0	main
2	doc_491521502252_item	3695175	et	0	main
minu	doc_491521502252_item	3695176	et	0	main
arvates	doc_491521502252_item	3695177	et	0	main
nii	doc_491521502252_item	3695178	et	0	main
oskaril	doc_491521502252_item	3695179	et	0	main
kui	doc_491521502252_item	3695180	et	0	main
ka	doc_491521502252_item	3695181	et	0	main
erikal	doc_491521502252_item	3695182	et	0	main
on	doc_491521502252_item	3695183	et	0	main
identiteediprobleemid	doc_491521502252_item	3695184	et	0	main
erika	doc_491521502252_item	3695185	et	0	main
on	doc_491521502252_item	3695186	et	0	main
sakslanna	doc_491521502252_item	3695187	et	0	main
ta	doc_491521502252_item	3695188	et	0	main
on	doc_491521502252_item	3695189	et	0	main
rikast	doc_491521502252_item	3695190	et	0	main
perekonnast	doc_491521502252_item	3695191	et	0	main
ja	doc_491521502252_item	3695192	et	0	main
tema	doc_491521502252_item	3695193	et	0	main
kartused	doc_491521502252_item	3695194	et	0	main
on	doc_491521502252_item	3695195	et	0	main
minu	doc_491521502252_item	3695196	et	0	main
meelest	doc_491521502252_item	3695197	et	0	main
põhjendattud	doc_491521502252_item	3695198	et	0	main
mingil	doc_491521502252_item	3695199	et	0	main
moel	doc_491521502252_item	3695200	et	0	main
ta	doc_491521502252_item	3695201	et	0	main
peab	doc_491521502252_item	3695202	et	0	main
mõtlema	doc_491521502252_item	3695203	et	0	main
sellest	doc_491521502252_item	3695204	et	0	main
et	doc_491521502252_item	3695205	et	0	main
ta	doc_491521502252_item	3695206	et	0	main
perekond	doc_491521502252_item	3695207	et	0	main
jätis	doc_491521502252_item	3695208	et	0	main
oma	doc_491521502252_item	3695209	et	0	main
nime	doc_491521502252_item	3695210	et	0	main
ja	doc_491521502252_item	3695211	et	0	main
tähtsuse	doc_491521502252_item	3695212	et	0	main
alguses	doc_491521502252_item	3695213	et	0	main
ta	doc_491521502252_item	3695214	et	0	main
üldse	doc_491521502252_item	3695215	et	0	main
ei	doc_491521502252_item	3695216	et	0	main
tea	doc_491521502252_item	3695217	et	0	main
mida	doc_491521502252_item	3695218	et	0	main
teha	doc_491521502252_item	3695219	et	0	main
ja	doc_491521502252_item	3695220	et	0	main
kuidas	doc_491521502252_item	3695221	et	0	main
talle	doc_491521502252_item	3695222	et	0	main
edasi	doc_491521502252_item	3695223	et	0	main
elada	doc_491521502252_item	3695224	et	0	main
ta	doc_491521502252_item	3695225	et	0	main
armastab	doc_491521502252_item	3695226	et	0	main
eestlasest	doc_491521502252_item	3695227	et	0	main
poissi	doc_491521502252_item	3695228	et	0	main
ja	doc_491521502252_item	3695229	et	0	main
samal	doc_491521502252_item	3695230	et	0	main
ajal	doc_491521502252_item	3695231	et	0	main
hoolitseb	doc_491521502252_item	3695232	et	0	main
sellest	doc_491521502252_item	3695233	et	0	main
mida	doc_491521502252_item	3695234	et	0	main
see	doc_491521502252_item	3695235	et	0	main
armastus	doc_491521502252_item	3695236	et	0	main
toob	doc_491521502252_item	3695237	et	0	main
kuidas	doc_491521502252_item	3695238	et	0	main
ta	doc_491521502252_item	3695239	et	0	main
ütleb	doc_491521502252_item	3695240	et	0	main
oma	doc_491521502252_item	3695241	et	0	main
vanaisale	doc_491521502252_item	3695242	et	0	main
et	doc_491521502252_item	3695243	et	0	main
tahab	doc_491521502252_item	3695244	et	0	main
abielluda	doc_491521502252_item	3695245	et	0	main
ta	doc_491521502252_item	3695246	et	0	main
töötas	doc_491521502252_item	3695247	et	0	main
tuutorina	doc_491521502252_item	3695248	et	0	main
perekonnas	doc_491521502252_item	3695249	et	0	main
kus	doc_491521502252_item	3695250	et	0	main
kõik	doc_491521502252_item	3695251	et	0	main
tahtsid	doc_491521502252_item	3695252	et	0	main
talle	doc_491521502252_item	3695253	et	0	main
nõu	doc_491521502252_item	3695254	et	0	main
anda	doc_491521502252_item	3695255	et	0	main
tema	doc_491521502252_item	3695256	et	0	main
ja	doc_491521502252_item	3695257	et	0	main
oskari	doc_491521502252_item	3695258	et	0	main
üle	doc_491521502252_item	3695259	et	0	main
mõnikord	doc_491521502252_item	3695260	et	0	main
ka	doc_491521502252_item	3695261	et	0	main
naeratakse	doc_491521502252_item	3695262	et	0	main
seal	doc_491521502252_item	3695263	et	0	main
kõik	doc_491521502252_item	3695264	et	0	main
nägid	doc_491521502252_item	3695265	et	0	main
mis	doc_491521502252_item	3695266	et	0	main
nende	doc_491521502252_item	3695267	et	0	main
vahel	doc_491521502252_item	3695268	et	0	main
toimub	doc_491521502252_item	3695269	et	0	main
kuid	doc_491521502252_item	3695270	et	0	main
noored	doc_491521502252_item	3695271	et	0	main
inimesed	doc_491521502252_item	3695272	et	0	main
ei	doc_491521502252_item	3695273	et	0	main
tahtnud	doc_491521502252_item	3695274	et	0	main
anda	doc_491521502252_item	3695275	et	0	main
selle	doc_491521502252_item	3695276	et	0	main
perekonnaliikmetele	doc_491521502252_item	3695277	et	0	main
võimalust	doc_491521502252_item	3695278	et	0	main
fantaseerida	doc_491521502252_item	3695279	et	0	main
oskariga	doc_491521502252_item	3695280	et	0	main
on	doc_491521502252_item	3695281	et	0	main
mu	doc_491521502252_item	3695282	et	0	main
arvates	doc_491521502252_item	3695283	et	0	main
palju	doc_491521502252_item	3695284	et	0	main
raskem	doc_491521502252_item	3695285	et	0	main
juhus	doc_491521502252_item	3695286	et	0	main
ta	doc_491521502252_item	3695287	et	0	main
juba	doc_491521502252_item	3695288	et	0	main
oma	doc_491521502252_item	3695289	et	0	main
lapsepõlvest	doc_491521502252_item	3695290	et	0	main
armunud	doc_491521502252_item	3695291	et	0	main
eerikast	doc_491521502252_item	3695292	et	0	main
ja	doc_491521502252_item	3695293	et	0	main
juba	doc_491521502252_item	3695294	et	0	main
sellest	doc_491521502252_item	3695295	et	0	main
ajal	doc_491521502252_item	3695296	et	0	main
tal	doc_491521502252_item	3695297	et	0	main
on	doc_491521502252_item	3695298	et	0	main
mälestused	doc_491521502252_item	3695299	et	0	main
temast	doc_491521502252_item	3695300	et	0	main
ta	doc_491521502252_item	3695301	et	0	main
nägi	doc_491521502252_item	3695302	et	0	main
kui	doc_491521502252_item	3695303	et	0	main
ta	doc_491521502252_item	3695304	et	0	main
mängis	doc_491521502252_item	3695305	et	0	main
lapsena	doc_491521502252_item	3695306	et	0	main
valges	doc_491521502252_item	3695307	et	0	main
ilusas	doc_491521502252_item	3695308	et	0	main
kleidis	doc_491521502252_item	3695309	et	0	main
fortepiano	doc_491521502252_item	3695310	et	0	main
ja	doc_491521502252_item	3695311	et	0	main
imetles	doc_491521502252_item	3695312	et	0	main
seda	doc_491521502252_item	3695313	et	0	main
olles	doc_491521502252_item	3695314	et	0	main
juba	doc_491521502252_item	3695315	et	0	main
noormehena	doc_491521502252_item	3695316	et	0	main
ta	doc_491521502252_item	3695317	et	0	main
armastus	doc_491521502252_item	3695318	et	0	main
kuskile	doc_491521502252_item	3695319	et	0	main
ei	doc_491521502252_item	3695320	et	0	main
kao	doc_491521502252_item	3695321	et	0	main
ühelt	doc_491521502252_item	3695322	et	0	main
poolt	doc_491521502252_item	3695323	et	0	main
ta	doc_491521502252_item	3695324	et	0	main
tunded	doc_491521502252_item	3695325	et	0	main
on	doc_491521502252_item	3695326	et	0	main
nii	doc_491521502252_item	3695327	et	0	main
ilusad	doc_491521502252_item	3695328	et	0	main
ja	doc_491521502252_item	3695329	et	0	main
tõsised	doc_491521502252_item	3695330	et	0	main
et	doc_491521502252_item	3695331	et	0	main
oskar	doc_491521502252_item	3695332	et	0	main
on	doc_491521502252_item	3695333	et	0	main
valmis	doc_491521502252_item	3695334	et	0	main
kõike	doc_491521502252_item	3695335	et	0	main
teha	doc_491521502252_item	3695336	et	0	main
et	doc_491521502252_item	3695337	et	0	main
erikaga	doc_491521502252_item	3695338	et	0	main
elada	doc_491521502252_item	3695339	et	0	main
samal	doc_491521502252_item	3695340	et	0	main
ajal	doc_491521502252_item	3695341	et	0	main
temas	doc_491521502252_item	3695342	et	0	main
on	doc_491521502252_item	3695343	et	0	main
suured	doc_491521502252_item	3695344	et	0	main
kartrused	doc_491521502252_item	3695345	et	0	main
ja	doc_491521502252_item	3695346	et	0	main
mingil	doc_491521502252_item	3695347	et	0	main
moel	doc_491521502252_item	3695348	et	0	main
ka	doc_491521502252_item	3695349	et	0	main
endaga	doc_491521502252_item	3695350	et	0	main
rahulolematus	doc_491521502252_item	3695351	et	0	main
millest	doc_491521502252_item	3695352	et	0	main
pääseda	doc_491521502252_item	3695353	et	0	main
ta	doc_491521502252_item	3695354	et	0	main
siiski	doc_491521502252_item	3695355	et	0	main
ei	doc_491521502252_item	3695356	et	0	main
saa	doc_491521502252_item	3695357	et	0	main
ma	doc_491521502252_item	3695358	et	0	main
olen	doc_491521502252_item	3695359	et	0	main
kindel	doc_491521502252_item	3695360	et	0	main
et	doc_491521502252_item	3695361	et	0	main
ka	doc_491521502252_item	3695362	et	0	main
välised	doc_491521502252_item	3695363	et	0	main
faktorid	doc_491521502252_item	3695364	et	0	main
mõjutasid	doc_491521502252_item	3695365	et	0	main
selle	doc_491521502252_item	3695366	et	0	main
loo	doc_491521502252_item	3695367	et	0	main
finalli	doc_491521502252_item	3695368	et	0	main
kuid	doc_491521502252_item	3695369	et	0	main
siiski	doc_491521502252_item	3695370	et	0	main
peamiseks	doc_491521502252_item	3695371	et	0	main
süütjaks	doc_491521502252_item	3695372	et	0	main
ma	doc_491521502252_item	3695373	et	0	main
nimetaksin	doc_491521502252_item	3695374	et	0	main
neid	doc_491521502252_item	3695375	et	0	main
oskari	doc_491521502252_item	3695376	et	0	main
ja	doc_491521502252_item	3695377	et	0	main
erika	doc_491521502252_item	3695378	et	0	main
nende	doc_491521502252_item	3695379	et	0	main
armastus	doc_491521502252_item	3695380	et	0	main
oli	doc_491521502252_item	3695381	et	0	main
nii	doc_491521502252_item	3695382	et	0	main
suur	doc_491521502252_item	3695383	et	0	main
ja	doc_491521502252_item	3695384	et	0	main
tõeline	doc_491521502252_item	3695385	et	0	main
et	doc_491521502252_item	3695386	et	0	main
võis	doc_491521502252_item	3695387	et	0	main
veel	doc_491521502252_item	3695388	et	0	main
kaua	doc_491521502252_item	3695389	et	0	main
elada	doc_491521502252_item	3695390	et	0	main
kuid	doc_491521502252_item	3695391	et	0	main
sisemised	doc_491521502252_item	3695392	et	0	main
kartused	doc_491521502252_item	3695393	et	0	main
ja	doc_491521502252_item	3695394	et	0	main
identiteediprobleemid	doc_491521502252_item	3695395	et	0	main
kõike	doc_491521502252_item	3695396	et	0	main
seda	doc_491521502252_item	3695397	et	0	main
hävitasid	doc_491521502252_item	3695398	et	0	main
kontrolltöö	doc_491521502263_item	3695399	et	0	main
1	doc_491521502263_item	3695400	et	0	main
võrrelge	doc_491521502263_item	3695401	et	0	main
ev	doc_491521502263_item	3695402	et	0	main
aegset	doc_491521502263_item	3695403	et	0	main
ja	doc_491521502263_item	3695404	et	0	main
ensv	doc_491521502263_item	3695405	et	0	main
pärastsõjajärgset	doc_491521502263_item	3695406	et	0	main
kultuurielu	doc_491521502263_item	3695407	et	0	main
2	doc_491521502263_item	3695408	et	0	main
sotsialistlik	doc_491521502263_item	3695409	et	0	main
realism	doc_491521502263_item	3695410	et	0	main
kui	doc_491521502263_item	3695411	et	0	main
kirjandusvool	doc_491521502263_item	3695412	et	0	main
24	doc_491521502263_item	3695413	et	0	main
veeb	doc_491521502263_item	3695414	et	0	main
1918	doc_491521502263_item	3695415	et	0	main
28	doc_491521502263_item	3695416	et	0	main
sep	doc_491521502263_item	3695417	et	0	main
1939	doc_491521502263_item	3695418	et	0	main
a	doc_491521502263_item	3695419	et	0	main
funktsioneeris	doc_491521502263_item	3695420	et	0	main
ev	doc_491521502263_item	3695421	et	0	main
2	doc_491521502263_item	3695422	et	0	main
veeb	doc_491521502263_item	3695423	et	0	main
1920	doc_491521502263_item	3695424	et	0	main
tartu	doc_491521502263_item	3695425	et	0	main
rahu	doc_491521502263_item	3695426	et	0	main
majandus	doc_491521502263_item	3695427	et	0	main
majanduses	doc_491521502263_item	3695428	et	0	main
olid	doc_491521502263_item	3695429	et	0	main
tehtud	doc_491521502263_item	3695430	et	0	main
olulised	doc_491521502263_item	3695431	et	0	main
muutused	doc_491521502263_item	3695432	et	0	main
maa	doc_491521502263_item	3695433	et	0	main
mis	doc_491521502263_item	3695434	et	0	main
oli	doc_491521502263_item	3695435	et	0	main
57	doc_491521502263_item	3695436	et	0	main
mõisnikute	doc_491521502263_item	3695437	et	0	main
käes	doc_491521502263_item	3695438	et	0	main
oli	doc_491521502263_item	3695439	et	0	main
antud	doc_491521502263_item	3695440	et	0	main
talupoegadele	doc_491521502263_item	3695441	et	0	main
suurimad	doc_491521502263_item	3695442	et	0	main
vabrikud	doc_491521502263_item	3695443	et	0	main
pandi	doc_491521502263_item	3695444	et	0	main
kinni	doc_491521502263_item	3695445	et	0	main
tekkisid	doc_491521502263_item	3695446	et	0	main
väiksemad	doc_491521502263_item	3695447	et	0	main
mis	doc_491521502263_item	3695448	et	0	main
leidsid	doc_491521502263_item	3695449	et	0	main
toetust	doc_491521502263_item	3695450	et	0	main
erakapitalist	doc_491521502263_item	3695451	et	0	main
eestis	doc_491521502263_item	3695452	et	0	main
toodeti	doc_491521502263_item	3695453	et	0	main
paberit	doc_491521502263_item	3695454	et	0	main
tekstiili	doc_491521502263_item	3695455	et	0	main
keemilisi	doc_491521502263_item	3695456	et	0	main
tooteid	doc_491521502263_item	3695457	et	0	main
saematerialid	doc_491521502263_item	3695458	et	0	main
tekstiili	doc_491521502263_item	3695459	et	0	main
ja	doc_491521502263_item	3695460	et	0	main
masinaid	doc_491521502263_item	3695461	et	0	main
põllumajanduses	doc_491521502263_item	3695462	et	0	main
toodeti	doc_491521502263_item	3695463	et	0	main
võid	doc_491521502263_item	3695464	et	0	main
ja	doc_491521502263_item	3695465	et	0	main
beekoni	doc_491521502263_item	3695466	et	0	main
samas	doc_491521502263_item	3695467	et	0	main
ka	doc_491521502263_item	3695468	et	0	main
teri	doc_491521502263_item	3695469	et	0	main
tarbeid	doc_491521502263_item	3695470	et	0	main
täideti	doc_491521502263_item	3695471	et	0	main
omal	doc_491521502263_item	3695472	et	0	main
jõul	doc_491521502263_item	3695473	et	0	main
inporteeriti	doc_491521502263_item	3695474	et	0	main
eestisse	doc_491521502263_item	3695475	et	0	main
harimismasinaid	doc_491521502263_item	3695476	et	0	main
keemiatooteid	doc_491521502263_item	3695477	et	0	main
pärast	doc_491521502263_item	3695478	et	0	main
maareformi	doc_491521502263_item	3695479	et	0	main
eestis	doc_491521502263_item	3695480	et	0	main
muutus	doc_491521502263_item	3695481	et	0	main
talude	doc_491521502263_item	3695482	et	0	main
arv	doc_491521502263_item	3695483	et	0	main
75000	doc_491521502263_item	3695484	et	0	main
12	doc_491521502263_item	3695485	et	0	main
tuhandeni	doc_491521502263_item	3695486	et	0	main
1920-30	doc_491521502263_item	3695487	et	0	main
kui	doc_491521502263_item	3695488	et	0	main
võrrelda	doc_491521502263_item	3695489	et	0	main
teiste	doc_491521502263_item	3695490	et	0	main
baltiriikidega	doc_491521502263_item	3695491	et	0	main
eestis	doc_491521502263_item	3695492	et	0	main
oli	doc_491521502263_item	3695493	et	0	main
arenemine	doc_491521502263_item	3695494	et	0	main
rohkem	doc_491521502263_item	3695495	et	0	main
balanseeritud	doc_491521502263_item	3695496	et	0	main
kui	doc_491521502263_item	3695497	et	0	main
teistes	doc_491521502263_item	3695498	et	0	main
lätis	doc_491521502263_item	3695499	et	0	main
oli	doc_491521502263_item	3695500	et	0	main
kõvasti	doc_491521502263_item	3695501	et	0	main
arenenud	doc_491521502263_item	3695502	et	0	main
riga	doc_491521502263_item	3695503	et	0	main
tehas	doc_491521502263_item	3695504	et	0	main
tööstus	doc_491521502263_item	3695505	et	0	main
põllumajandus	doc_491521502263_item	3695506	et	0	main
aga	doc_491521502263_item	3695507	et	0	main
jõudis	doc_491521502263_item	3695508	et	0	main
täita	doc_491521502263_item	3695509	et	0	main
riigi	doc_491521502263_item	3695510	et	0	main
tarbeid	doc_491521502263_item	3695511	et	0	main
vaevalt	doc_491521502263_item	3695512	et	0	main
leedu	doc_491521502263_item	3695513	et	0	main
oli	doc_491521502263_item	3695514	et	0	main
rõhutanud	doc_491521502263_item	3695515	et	0	main
põllumajandust	doc_491521502263_item	3695516	et	0	main
rasketööstus	doc_491521502263_item	3695517	et	0	main
oli	doc_491521502263_item	3695518	et	0	main
vilets	doc_491521502263_item	3695519	et	0	main
1929	doc_491521502263_item	3695520	et	0	main
a	doc_491521502263_item	3695521	et	0	main
kriis	doc_491521502263_item	3695522	et	0	main
mõjutas	doc_491521502263_item	3695523	et	0	main
eestit	doc_491521502263_item	3695524	et	0	main
aga	doc_491521502263_item	3695525	et	0	main
vähem	doc_491521502263_item	3695526	et	0	main
kui	doc_491521502263_item	3695527	et	0	main
euroopat	doc_491521502263_item	3695528	et	0	main
elutase	doc_491521502263_item	3695529	et	0	main
oli	doc_491521502263_item	3695530	et	0	main
eestis	doc_491521502263_item	3695531	et	0	main
tol	doc_491521502263_item	3695532	et	0	main
ajal	doc_491521502263_item	3695533	et	0	main
kõrgem	doc_491521502263_item	3695534	et	0	main
kui	doc_491521502263_item	3695535	et	0	main
euroopas	doc_491521502263_item	3695536	et	0	main
1934	doc_491521502263_item	3695537	et	0	main
36	doc_491521502263_item	3695538	et	0	main
eestis	doc_491521502263_item	3695539	et	0	main
on	doc_491521502263_item	3695540	et	0	main
märgata	doc_491521502263_item	3695541	et	0	main
kõva	doc_491521502263_item	3695542	et	0	main
tõusu	doc_491521502263_item	3695543	et	0	main
seletada	doc_491521502263_item	3695544	et	0	main
võib	doc_491521502263_item	3695545	et	0	main
sellega	doc_491521502263_item	3695546	et	0	main
et	doc_491521502263_item	3695547	et	0	main
majandus	doc_491521502263_item	3695548	et	0	main
euroopas	doc_491521502263_item	3695549	et	0	main
enam-vähem	doc_491521502263_item	3695550	et	0	main
stabiliseerus	doc_491521502263_item	3695551	et	0	main
nüüd	doc_491521502263_item	3695552	et	0	main
eesti	doc_491521502263_item	3695553	et	0	main
kaotas	doc_491521502263_item	3695554	et	0	main
venemaal	doc_491521502263_item	3695555	et	0	main
tooteturg	doc_491521502263_item	3695556	et	0	main
ja	doc_491521502263_item	3695557	et	0	main
pühendas	doc_491521502263_item	3695558	et	0	main
oma	doc_491521502263_item	3695559	et	0	main
tähelepanu	doc_491521502263_item	3695560	et	0	main
euroopale	doc_491521502263_item	3695561	et	0	main
tööstustõusu	doc_491521502263_item	3695562	et	0	main
seletab	doc_491521502263_item	3695563	et	0	main
turukaotamine	doc_491521502263_item	3695564	et	0	main
venemaale	doc_491521502263_item	3695565	et	0	main
eksporteeriti	doc_491521502263_item	3695566	et	0	main
xviii-xix	doc_491521502263_item	3695567	et	0	main
teri	doc_491521502263_item	3695568	et	0	main
liha	doc_491521502263_item	3695569	et	0	main
piimatooteid	doc_491521502263_item	3695570	et	0	main
veena	doc_491521502263_item	3695571	et	0	main
praegu	doc_491521502263_item	3695572	et	0	main
eesti	doc_491521502263_item	3695573	et	0	main
pidi	doc_491521502263_item	3695574	et	0	main
muutma	doc_491521502263_item	3695575	et	0	main
majanduspoliitikat	doc_491521502263_item	3695576	et	0	main
pöördudes	doc_491521502263_item	3695577	et	0	main
tööstusele	doc_491521502263_item	3695578	et	0	main
toote	doc_491521502263_item	3695579	et	0	main
kvalitee	doc_491521502263_item	3695580	et	0	main
kultuuriruumis	doc_491521502263_item	3695581	et	0	main
oli	doc_491521502263_item	3695582	et	0	main
ka	doc_491521502263_item	3695583	et	0	main
palju	doc_491521502263_item	3695584	et	0	main
muudatusi	doc_491521502263_item	3695585	et	0	main
oli	doc_491521502263_item	3695586	et	0	main
rajatud	doc_491521502263_item	3695587	et	0	main
eesti	doc_491521502263_item	3695588	et	0	main
kultuurikapital	doc_491521502263_item	3695589	et	0	main
mis	doc_491521502263_item	3695590	et	0	main
andis	doc_491521502263_item	3695591	et	0	main
välja	doc_491521502263_item	3695592	et	0	main
preemiaid	doc_491521502263_item	3695593	et	0	main
väljapaistvatele	doc_491521502263_item	3695594	et	0	main
kultuuritegijatele	doc_491521502263_item	3695595	et	0	main
kirjanikud	doc_491521502263_item	3695596	et	0	main
kunstnikud	doc_491521502263_item	3695597	et	0	main
kõige	doc_491521502263_item	3695598	et	0	main
kuulsam	doc_491521502263_item	3695599	et	0	main
kirjandusnäide	doc_491521502263_item	3695600	et	0	main
oli	doc_491521502263_item	3695601	et	0	main
tammsaare	doc_491521502263_item	3695602	et	0	main
tõde	doc_491521502263_item	3695603	et	0	main
ja	doc_491521502263_item	3695604	et	0	main
õigus	doc_491521502263_item	3695605	et	0	main
mis	doc_491521502263_item	3695606	et	0	main
kirjeldas	doc_491521502263_item	3695607	et	0	main
eesti	doc_491521502263_item	3695608	et	0	main
riigi	doc_491521502263_item	3695609	et	0	main
idee	doc_491521502263_item	3695610	et	0	main
sündmust	doc_491521502263_item	3695611	et	0	main
ja	doc_491521502263_item	3695612	et	0	main
arenemist	doc_491521502263_item	3695613	et	0	main
inimeste	doc_491521502263_item	3695614	et	0	main
eludes	doc_491521502263_item	3695615	et	0	main
ja	doc_491521502263_item	3695616	et	0	main
selle	doc_491521502263_item	3695617	et	0	main
ajamõju	doc_491521502263_item	3695618	et	0	main
inimkäitumisele	doc_491521502263_item	3695619	et	0	main
tuntud	doc_491521502263_item	3695620	et	0	main
oli	doc_491521502263_item	3695621	et	0	main
ka	doc_491521502263_item	3695622	et	0	main
paul	doc_491521502263_item	3695623	et	0	main
keres	doc_491521502263_item	3695624	et	0	main
oma	doc_491521502263_item	3695625	et	0	main
saavutustega	doc_491521502263_item	3695626	et	0	main
mallemaailmas	doc_491521502263_item	3695627	et	0	main
olid	doc_491521502263_item	3695628	et	0	main
loodud	doc_491521502263_item	3695629	et	0	main
teatrid	doc_491521502263_item	3695630	et	0	main
tallinnas	doc_491521502263_item	3695631	et	0	main
tartus	doc_491521502263_item	3695632	et	0	main
ja	doc_491521502263_item	3695633	et	0	main
narvas	doc_491521502263_item	3695634	et	0	main
olid	doc_491521502263_item	3695635	et	0	main
levinud	doc_491521502263_item	3695636	et	0	main
igasugused	doc_491521502263_item	3695637	et	0	main
klubid	doc_491521502263_item	3695638	et	0	main
ja	doc_491521502263_item	3695639	et	0	main
ne	doc_491521502263_item	3695640	et	0	main
poliitikas	doc_491521502263_item	3695641	et	0	main
eesti	doc_491521502263_item	3695642	et	0	main
püüdis	doc_491521502263_item	3695643	et	0	main
saavutada	doc_491521502263_item	3695644	et	0	main
baltikumi	doc_491521502263_item	3695645	et	0	main
liitu	doc_491521502263_item	3695646	et	0	main
mis	doc_491521502263_item	3695647	et	0	main
võiks	doc_491521502263_item	3695648	et	0	main
garanteerida	doc_491521502263_item	3695649	et	0	main
rahu	doc_491521502263_item	3695650	et	0	main
aga	doc_491521502263_item	3695651	et	0	main
sellest	doc_491521502263_item	3695652	et	0	main
midagi	doc_491521502263_item	3695653	et	0	main
ei	doc_491521502263_item	3695654	et	0	main
tulnud	doc_491521502263_item	3695655	et	0	main
välja	doc_491521502263_item	3695656	et	0	main
poole	doc_491521502263_item	3695657	et	0	main
läti	doc_491521502263_item	3695658	et	0	main
leedu	doc_491521502263_item	3695659	et	0	main
soome	doc_491521502263_item	3695660	et	0	main
ida	doc_491521502263_item	3695661	et	0	main
ühing	doc_491521502263_item	3695662	et	0	main
või	doc_491521502263_item	3695663	et	0	main
baltiühing	doc_491521502263_item	3695664	et	0	main
läti	doc_491521502263_item	3695665	et	0	main
leedu	doc_491521502263_item	3695666	et	0	main
eesti	doc_491521502263_item	3695667	et	0	main
ajutis	doc_491521502263_item	3695668	et	0	main
huvi	doc_491521502263_item	3695669	et	0	main
tundus	doc_491521502263_item	3695670	et	0	main
rootsi	doc_491521502263_item	3695671	et	0	main
ühingu	doc_491521502263_item	3695672	et	0	main
vastu	doc_491521502263_item	3695673	et	0	main
aga	doc_491521502263_item	3695674	et	0	main
leedu	doc_491521502263_item	3695675	et	0	main
lähenemine	doc_491521502263_item	3695676	et	0	main
ensv-ga	doc_491521502263_item	3695677	et	0	main
lõhkus	doc_491521502263_item	3695678	et	0	main
selle	doc_491521502263_item	3695679	et	0	main
idee	doc_491521502263_item	3695680	et	0	main
lõppes	doc_491521502263_item	3695681	et	0	main
see	doc_491521502263_item	3695682	et	0	main
kõik	doc_491521502263_item	3695683	et	0	main
läti	doc_491521502263_item	3695684	et	0	main
ja	doc_491521502263_item	3695685	et	0	main
eesti	doc_491521502263_item	3695686	et	0	main
kokkuleppega	doc_491521502263_item	3695687	et	0	main
inimese	doc_491521502263_item	3695688	et	0	main
õiguse	doc_491521502263_item	3695689	et	0	main
suhtes	doc_491521502263_item	3695690	et	0	main
eestis	doc_491521502263_item	3695691	et	0	main
oli	doc_491521502263_item	3695692	et	0	main
täislik	doc_491521502263_item	3695693	et	0	main
vabadus	doc_491521502263_item	3695694	et	0	main
olid	doc_491521502263_item	3695695	et	0	main
legaliseeritud	doc_491521502263_item	3695696	et	0	main
natsionaalvähemused	doc_491521502263_item	3695697	et	0	main
venelased	doc_491521502263_item	3695698	et	0	main
17	doc_491521502263_item	3695699	et	0	main
sakslased	doc_491521502263_item	3695700	et	0	main
5	doc_491521502263_item	3695701	et	0	main
loodud	doc_491521502263_item	3695702	et	0	main
alghariduse	doc_491521502263_item	3695703	et	0	main
võimaluse	doc_491521502263_item	3695704	et	0	main
emakeeles	doc_491521502263_item	3695705	et	0	main
vaba	doc_491521502263_item	3695706	et	0	main
oli	doc_491521502263_item	3695707	et	0	main
kirjanuds	doc_491521502263_item	3695708	et	0	main
usk	doc_491521502263_item	3695709	et	0	main
ja	doc_491521502263_item	3695710	et	0	main
ne	doc_491521502263_item	3695711	et	0	main
põhiseadus	doc_491521502263_item	3695712	et	0	main
eestis	doc_491521502263_item	3695713	et	0	main
1920	doc_491521502263_item	3695714	et	0	main
oli	doc_491521502263_item	3695715	et	0	main
väga	doc_491521502263_item	3695716	et	0	main
demokraatlik	doc_491521502263_item	3695717	et	0	main
selle	doc_491521502263_item	3695718	et	0	main
aja	doc_491521502263_item	3695719	et	0	main
jaoks	doc_491521502263_item	3695720	et	0	main
28	doc_491521502263_item	3695721	et	0	main
sep	doc_491521502263_item	3695722	et	0	main
1939	doc_491521502263_item	3695723	et	0	main
1944	doc_491521502263_item	3695724	et	0	main
20	doc_491521502263_item	3695725	et	0	main
aug	doc_491521502263_item	3695726	et	0	main
191	doc_491521502263_item	3695727	et	0	main
ensv	doc_491521502263_item	3695728	et	0	main
aeg	doc_491521502263_item	3695729	et	0	main
muudatusi	doc_491521502263_item	3695730	et	0	main
oli	doc_491521502263_item	3695731	et	0	main
palju	doc_491521502263_item	3695732	et	0	main
1940	doc_491521502263_item	3695733	et	0	main
ev-inkorporeeritud	doc_491521502263_item	3695734	et	0	main
nõukogude	doc_491521502263_item	3695735	et	0	main
liitu	doc_491521502263_item	3695736	et	0	main
1946	doc_491521502263_item	3695737	et	0	main
muudatused	doc_491521502263_item	3695738	et	0	main
ensv	doc_491521502263_item	3695739	et	0	main
jaotuses	doc_491521502263_item	3695740	et	0	main
uued	doc_491521502263_item	3695741	et	0	main
oblastid	doc_491521502263_item	3695742	et	0	main
3	doc_491521502263_item	3695743	et	0	main
tk	doc_491521502263_item	3695744	et	0	main
1941	doc_491521502263_item	3695745	et	0	main
juuni	doc_491521502263_item	3695746	et	0	main
küüditus	doc_491521502263_item	3695747	et	0	main
10157	doc_491521502263_item	3695748	et	0	main
inimest	doc_491521502263_item	3695749	et	0	main
1949	doc_491521502263_item	3695750	et	0	main
a	doc_491521502263_item	3695751	et	0	main
25	doc_491521502263_item	3695752	et	0	main
märts	doc_491521502263_item	3695753	et	0	main
küüditus	doc_491521502263_item	3695754	et	0	main
20000	doc_491521502263_item	3695755	et	0	main
inimest	doc_491521502263_item	3695756	et	0	main
kultuuri	doc_491521502263_item	3695757	et	0	main
elu	doc_491521502263_item	3695758	et	0	main
sõnavabadus	doc_491521502263_item	3695759	et	0	main
keelatud	doc_491521502263_item	3695760	et	0	main
kõik	doc_491521502263_item	3695761	et	0	main
kokkutulekud	doc_491521502263_item	3695762	et	0	main
keelatud	doc_491521502263_item	3695763	et	0	main
legaalne	doc_491521502263_item	3695764	et	0	main
ainult	doc_491521502263_item	3695765	et	0	main
kp-kokkutulekud	doc_491521502263_item	3695766	et	0	main
range	doc_491521502263_item	3695767	et	0	main
tsensuur	doc_491521502263_item	3695768	et	0	main
ajakirjade	doc_491521502263_item	3695769	et	0	main
ja	doc_491521502263_item	3695770	et	0	main
ajalehtede	doc_491521502263_item	3695771	et	0	main
sulgemine	doc_491521502263_item	3695772	et	0	main
väljapaistvate	doc_491521502263_item	3695773	et	0	main
kultuuritegelaste	doc_491521502263_item	3695774	et	0	main
küüditamine	doc_491521502263_item	3695775	et	0	main
sotsiaalpropaganda	doc_491521502263_item	3695776	et	0	main
kirjanduses	doc_491521502263_item	3695777	et	0	main
kunstis	doc_491521502263_item	3695778	et	0	main
kultuurimajad	doc_491521502263_item	3695779	et	0	main
suletakse	doc_491521502263_item	3695780	et	0	main
kultuurimõiste	doc_491521502263_item	3695781	et	0	main
muutub	doc_491521502263_item	3695782	et	0	main
ekonoomika	doc_491521502263_item	3695783	et	0	main
planeeritud	doc_491521502263_item	3695784	et	0	main
areng	doc_491521502263_item	3695785	et	0	main
ja	doc_491521502263_item	3695786	et	0	main
tööstus	doc_491521502263_item	3695787	et	0	main
tööstus	doc_491521502263_item	3695788	et	0	main
täidab	doc_491521502263_item	3695789	et	0	main
nõukogude	doc_491521502263_item	3695790	et	0	main
liidu	doc_491521502263_item	3695791	et	0	main
tarbeid	doc_491521502263_item	3695792	et	0	main
ehitatakse	doc_491521502263_item	3695793	et	0	main
tehaseid	doc_491521502263_item	3695794	et	0	main
elektrijaame	doc_491521502263_item	3695795	et	0	main
balteks	doc_491521502263_item	3695796	et	0	main
tehas	doc_491521502263_item	3695797	et	0	main
eesti	doc_491521502263_item	3695798	et	0	main
elektrijaam	doc_491521502263_item	3695799	et	0	main
balti	doc_491521502263_item	3695800	et	0	main
elektrijaam	doc_491521502263_item	3695801	et	0	main
sillamäe	doc_491521502263_item	3695802	et	0	main
kinnine	doc_491521502263_item	3695803	et	0	main
linn	doc_491521502263_item	3695804	et	0	main
mis	doc_491521502263_item	3695805	et	0	main
täidab	doc_491521502263_item	3695806	et	0	main
nl	doc_491521502263_item	3695807	et	0	main
sõjaväe	doc_491521502263_item	3695808	et	0	main
tellimusi	doc_491521502263_item	3695809	et	0	main
paldiski	doc_491521502263_item	3695810	et	0	main
on	doc_491521502263_item	3695811	et	0	main
suur	doc_491521502263_item	3695812	et	0	main
nl	doc_491521502263_item	3695813	et	0	main
baas	doc_491521502263_item	3695814	et	0	main
eestisse	doc_491521502263_item	3695815	et	0	main
jõukalt	doc_491521502263_item	3695816	et	0	main
toodi	doc_491521502263_item	3695817	et	0	main
tööjõudu	doc_491521502263_item	3695818	et	0	main
8suurim	doc_491521502263_item	3695819	et	0	main
välisjõu	doc_491521502263_item	3695820	et	0	main
linn	doc_491521502263_item	3695821	et	0	main
narvas	doc_491521502263_item	3695822	et	0	main
1959-67	doc_491521502263_item	3695823	et	0	main
kollektiviseerimine	doc_491521502263_item	3695824	et	0	main
eestis	doc_491521502263_item	3695825	et	0	main
see	doc_491521502263_item	3695826	et	0	main
muidugi	doc_491521502263_item	3695827	et	0	main
oli	doc_491521502263_item	3695828	et	0	main
negatiivne	doc_491521502263_item	3695829	et	0	main
joon	doc_491521502263_item	3695830	et	0	main
põllumajanduse	doc_491521502263_item	3695831	et	0	main
arenemises	doc_491521502263_item	3695832	et	0	main
inimesel	doc_491521502263_item	3695833	et	0	main
polnud	doc_491521502263_item	3695834	et	0	main
entusiasmi	doc_491521502263_item	3695835	et	0	main
raske	doc_491521502263_item	3695836	et	0	main
tööstus	doc_491521502263_item	3695837	et	0	main
eestis	doc_491521502263_item	3695838	et	0	main
olid	doc_491521502263_item	3695839	et	0	main
rajatud	doc_491521502263_item	3695840	et	0	main
tehased	doc_491521502263_item	3695841	et	0	main
mis	doc_491521502263_item	3695842	et	0	main
olid	doc_491521502263_item	3695843	et	0	main
pühendatud	doc_491521502263_item	3695844	et	0	main
masinaehitusele	doc_491521502263_item	3695845	et	0	main
moderniseeritud	doc_491521502263_item	3695846	et	0	main
volta	doc_491521502263_item	3695847	et	0	main
punane	doc_491521502263_item	3695848	et	0	main
peet	doc_491521502263_item	3695849	et	0	main
kaabel	doc_491521502263_item	3695850	et	0	main
masinaid	doc_491521502263_item	3695851	et	0	main
ekspordeeriti	doc_491521502263_item	3695852	et	0	main
nl	doc_491521502263_item	3695853	et	0	main
arenenud	doc_491521502263_item	3695854	et	0	main
oli	doc_491521502263_item	3695855	et	0	main
põlevkivi	doc_491521502263_item	3695856	et	0	main
tööstus	doc_491521502263_item	3695857	et	0	main
ja	doc_491521502263_item	3695858	et	0	main
sellega	doc_491521502263_item	3695859	et	0	main
seotud	doc_491521502263_item	3695860	et	0	main
keemitööstus	doc_491521502263_item	3695861	et	0	main
fosforiidi	doc_491521502263_item	3695862	et	0	main
kampaania	doc_491521502263_item	3695863	et	0	main
leidis	doc_491521502263_item	3695864	et	0	main
kõva	doc_491521502263_item	3695865	et	0	main
vastutegu	doc_491521502263_item	3695866	et	0	main
inimese	doc_491521502263_item	3695867	et	0	main
õigused	doc_491521502263_item	3695868	et	0	main
olid	doc_491521502263_item	3695869	et	0	main
maksimaalselt	doc_491521502263_item	3695870	et	0	main
hävitud	doc_491521502263_item	3695871	et	0	main
sõnavabadust	doc_491521502263_item	3695872	et	0	main
polnud	doc_491521502263_item	3695873	et	0	main
usk	doc_491521502263_item	3695874	et	0	main
luuterlik	doc_491521502263_item	3695875	et	0	main
k	doc_491521502263_item	3695876	et	0	main
õigeusu	doc_491521502263_item	3695877	et	0	main
k	doc_491521502263_item	3695878	et	0	main
religioon	doc_491521502263_item	3695879	et	0	main
oopium	doc_491521502263_item	3695880	et	0	main
rahvale	doc_491521502263_item	3695881	et	0	main
rahvus	doc_491521502263_item	3695882	et	0	main
vähemused	doc_491521502263_item	3695883	et	0	main
koondati	doc_491521502263_item	3695884	et	0	main
nüüd	doc_491521502263_item	3695885	et	0	main
ainult	doc_491521502263_item	3695886	et	0	main
ühine	doc_491521502263_item	3695887	et	0	main
nõukogu	doc_491521502263_item	3695888	et	0	main
rahvas	doc_491521502263_item	3695889	et	0	main
poliitiline	doc_491521502263_item	3695890	et	0	main
vaikus	doc_491521502263_item	3695891	et	0	main
ainult	doc_491521502263_item	3695892	et	0	main
üks	doc_491521502263_item	3695893	et	0	main
partei	doc_491521502263_item	3695894	et	0	main
kp	doc_491521502263_item	3695895	et	0	main
valimised	doc_491521502263_item	3695896	et	0	main
falsititseeritud	doc_491521502263_item	3695897	et	0	main
99	doc_491521502263_item	3695898	et	0	main
ilmunud	doc_491521502263_item	3695899	et	0	main
97	doc_491521502263_item	3695900	et	0	main
hääletasid	doc_491521502263_item	3695901	et	0	main
kandidaadi	doc_491521502263_item	3695902	et	0	main
poolt	doc_491521502263_item	3695903	et	0	main
2	doc_491521502263_item	3695904	et	0	main
kirjandus	doc_491521502263_item	3695905	et	0	main
oli	doc_491521502263_item	3695906	et	0	main
täiuslikult	doc_491521502263_item	3695907	et	0	main
pühendatud	doc_491521502263_item	3695908	et	0	main
sotsiaalideoloogiale	doc_491521502263_item	3695909	et	0	main
terved	doc_491521502263_item	3695910	et	0	main
traktaadid	doc_491521502263_item	3695911	et	0	main
marksism-leninismist	doc_491521502263_item	3695912	et	0	main
trükitut	doc_491521502263_item	3695913	et	0	main
eesti	doc_491521502263_item	3695914	et	0	main
keele	doc_491521502263_item	3695915	et	0	main
kirjanduses	doc_491521502263_item	3695916	et	0	main
ilukirjanduses	doc_491521502263_item	3695917	et	0	main
oli	doc_491521502263_item	3695918	et	0	main
kõik	doc_491521502263_item	3695919	et	0	main
pühendatud	doc_491521502263_item	3695920	et	0	main
ainult	doc_491521502263_item	3695921	et	0	main
ühele	doc_491521502263_item	3695922	et	0	main
ideele	doc_491521502263_item	3695923	et	0	main
sotsialism	doc_491521502263_item	3695924	et	0	main
seisab	doc_491521502263_item	3695925	et	0	main
kapitalismi	doc_491521502263_item	3695926	et	0	main
vastu	doc_491521502263_item	3695927	et	0	main
muidugi	doc_491521502263_item	3695928	et	0	main
raskustega	doc_491521502263_item	3695929	et	0	main
ja	doc_491521502263_item	3695930	et	0	main
mõne	doc_491521502263_item	3695931	et	0	main
aja	doc_491521502263_item	3695932	et	0	main
pärast	doc_491521502263_item	3695933	et	0	main
mädanev	doc_491521502263_item	3695934	et	0	main
kapitalism	doc_491521502263_item	3695935	et	0	main
annab	doc_491521502263_item	3695936	et	0	main
alla	doc_491521502263_item	3695937	et	0	main
see	doc_491521502263_item	3695938	et	0	main
idee	doc_491521502263_item	3695939	et	0	main
on	doc_491521502263_item	3695940	et	0	main
läbitut	doc_491521502263_item	3695941	et	0	main
kõikides	doc_491521502263_item	3695942	et	0	main
zanrites	doc_491521502263_item	3695943	et	0	main
range	doc_491521502263_item	3695944	et	0	main
tsensuur	doc_491521502263_item	3695945	et	0	main
ei	doc_491521502263_item	3695946	et	0	main
lase	doc_491521502263_item	3695947	et	0	main
läbi	doc_491521502263_item	3695948	et	0	main
kirjanikude	doc_491521502263_item	3695949	et	0	main
teoseid	doc_491521502263_item	3695950	et	0	main
teaduses	doc_491521502263_item	3695951	et	0	main
olid	doc_491521502263_item	3695952	et	0	main
vahetatud	doc_491521502263_item	3695953	et	0	main
mõned	doc_491521502263_item	3695954	et	0	main
faktid	doc_491521502263_item	3695955	et	0	main
nt	doc_491521502263_item	3695956	et	0	main
geneetika	doc_491521502263_item	3695957	et	0	main
oli	doc_491521502263_item	3695958	et	0	main
pidurdatud	doc_491521502263_item	3695959	et	0	main
arengus	doc_491521502263_item	3695960	et	0	main
olid	doc_491521502263_item	3695961	et	0	main
hävitatud	doc_491521502263_item	3695962	et	0	main
paljud	doc_491521502263_item	3695963	et	0	main
trükkid	doc_491521502263_item	3695964	et	0	main
mis	doc_491521502263_item	3695965	et	0	main
läksid	doc_491521502263_item	3695966	et	0	main
lahku	doc_491521502263_item	3695967	et	0	main
sotsialismideega	doc_491521502263_item	3695968	et	0	main
neid	doc_491521502263_item	3695969	et	0	main
kas	doc_491521502263_item	3695970	et	0	main
põletati	doc_491521502263_item	3695971	et	0	main
mõned	doc_491521502263_item	3695972	et	0	main
lõked	doc_491521502263_item	3695973	et	0	main
korrekteeriti	doc_491521502263_item	3695974	et	0	main
kontrolltöö	doc_491521502268_item	3695975	et	0	main
1	doc_491521502268_item	3695976	et	0	main
missugused	doc_491521502268_item	3695977	et	0	main
majanduslikud-kultuurilised	doc_491521502268_item	3695978	et	0	main
tegurid	doc_491521502268_item	3695979	et	0	main
andsid	doc_491521502268_item	3695980	et	0	main
1970ndatel	doc_491521502268_item	3695981	et	0	main
põhjust	doc_491521502268_item	3695982	et	0	main
eesti	doc_491521502268_item	3695983	et	0	main
nsvi	doc_491521502268_item	3695984	et	0	main
tunda	doc_491521502268_item	3695985	et	0	main
end	doc_491521502268_item	3695986	et	0	main
nsvl	doc_491521502268_item	3695987	et	0	main
lähisvälismaana	doc_491521502268_item	3695988	et	0	main
2	doc_491521502268_item	3695989	et	0	main
l	doc_491521502268_item	3695990	et	0	main
laiuse	doc_491521502268_item	3695991	et	0	main
mängufilm	doc_491521502268_item	3695992	et	0	main
libahunt	doc_491521502268_item	3695993	et	0	main
kas	doc_491521502268_item	3695994	et	0	main
teie	doc_491521502268_item	3695995	et	0	main
arvates	doc_491521502268_item	3695996	et	0	main
ajaloodokument	doc_491521502268_item	3695997	et	0	main
või	doc_491521502268_item	3695998	et	0	main
ühiskonnakriitika	doc_491521502268_item	3695999	et	0	main
miks	doc_491521502268_item	3696000	et	0	main
2	doc_491521502268_item	3696001	et	0	main
minu	doc_491521502268_item	3696002	et	0	main
arvates	doc_491521502268_item	3696003	et	0	main
ajaloodokument	doc_491521502268_item	3696004	et	0	main
ei	doc_491521502268_item	3696005	et	0	main
saa	doc_491521502268_item	3696006	et	0	main
ta	doc_491521502268_item	3696007	et	0	main
kuskilt	doc_491521502268_item	3696008	et	0	main
otsast	doc_491521502268_item	3696009	et	0	main
olla	doc_491521502268_item	3696010	et	0	main
pigem	doc_491521502268_item	3696011	et	0	main
siis	doc_491521502268_item	3696012	et	0	main
ühiskonnakriitika	doc_491521502268_item	3696013	et	0	main
jah	doc_491521502268_item	3696014	et	0	main
ühiskonnakriitika	doc_491521502268_item	3696015	et	0	main
ikka	doc_491521502268_item	3696016	et	0	main
sest	doc_491521502268_item	3696017	et	0	main
see	doc_491521502268_item	3696018	et	0	main
film	doc_491521502268_item	3696019	et	0	main
oli	doc_491521502268_item	3696020	et	0	main
selleteemaline	doc_491521502268_item	3696021	et	0	main
et	doc_491521502268_item	3696022	et	0	main
keegi	doc_491521502268_item	3696023	et	0	main
ei	doc_491521502268_item	3696024	et	0	main
sallinud	doc_491521502268_item	3696025	et	0	main
tiinat	doc_491521502268_item	3696026	et	0	main
kuna	doc_491521502268_item	3696027	et	0	main
ta	doc_491521502268_item	3696028	et	0	main
ema	doc_491521502268_item	3696029	et	0	main
oli	doc_491521502268_item	3696030	et	0	main
olnud	doc_491521502268_item	3696031	et	0	main
nõid	doc_491521502268_item	3696032	et	0	main
seega	doc_491521502268_item	3696033	et	0	main
pidas	doc_491521502268_item	3696034	et	0	main
ühiskond	doc_491521502268_item	3696035	et	0	main
teda	doc_491521502268_item	3696036	et	0	main
samasuguseks	doc_491521502268_item	3696037	et	0	main
selles	doc_491521502268_item	3696038	et	0	main
filmis	doc_491521502268_item	3696039	et	0	main
heideti	doc_491521502268_item	3696040	et	0	main
pigem	doc_491521502268_item	3696041	et	0	main
varju	doc_491521502268_item	3696042	et	0	main
ühiskonnale	doc_491521502268_item	3696043	et	0	main
ja	doc_491521502268_item	3696044	et	0	main
selle	doc_491521502268_item	3696045	et	0	main
eelarvamustele	doc_491521502268_item	3696046	et	0	main
kui	doc_491521502268_item	3696047	et	0	main
peategelasele	doc_491521502268_item	3696048	et	0	main
arvan	doc_491521502268_item	3696049	et	0	main
et	doc_491521502268_item	3696050	et	0	main
l	doc_491521502268_item	3696051	et	0	main
laiuse	doc_491521502268_item	3696052	et	0	main
film	doc_491521502268_item	3696053	et	0	main
libahunt	doc_491521502268_item	3696054	et	0	main
püüab	doc_491521502268_item	3696055	et	0	main
meile	doc_491521502268_item	3696056	et	0	main
näidata	doc_491521502268_item	3696057	et	0	main
kui	doc_491521502268_item	3696058	et	0	main
kriitiliselt	doc_491521502268_item	3696059	et	0	main
suhtub	doc_491521502268_item	3696060	et	0	main
ühiskond	doc_491521502268_item	3696061	et	0	main
nendesse	doc_491521502268_item	3696062	et	0	main
kes	doc_491521502268_item	3696063	et	0	main
erinevad	doc_491521502268_item	3696064	et	0	main
mingil	doc_491521502268_item	3696065	et	0	main
moel	doc_491521502268_item	3696066	et	0	main
hallist	doc_491521502268_item	3696067	et	0	main
massist	doc_491521502268_item	3696068	et	0	main
tegelikult	doc_491521502268_item	3696069	et	0	main
oli	doc_491521502268_item	3696070	et	0	main
on	doc_491521502268_item	3696071	et	0	main
ja	doc_491521502268_item	3696072	et	0	main
vist	doc_491521502268_item	3696073	et	0	main
jääbki	doc_491521502268_item	3696074	et	0	main
ühiskonnas	doc_491521502268_item	3696075	et	0	main
valitsema	doc_491521502268_item	3696076	et	0	main
arvamus	doc_491521502268_item	3696077	et	0	main
et	doc_491521502268_item	3696078	et	0	main
see	doc_491521502268_item	3696079	et	0	main
kes	doc_491521502268_item	3696080	et	0	main
julgeb	doc_491521502268_item	3696081	et	0	main
erineda	doc_491521502268_item	3696082	et	0	main
on	doc_491521502268_item	3696083	et	0	main
imelik	doc_491521502268_item	3696084	et	0	main
värdjas	doc_491521502268_item	3696085	et	0	main
või	doc_491521502268_item	3696086	et	0	main
hoopiski	doc_491521502268_item	3696087	et	0	main
libahunt	doc_491521502268_item	3696088	et	0	main
veel	doc_491521502268_item	3696089	et	0	main
arvan	doc_491521502268_item	3696090	et	0	main
et	doc_491521502268_item	3696091	et	0	main
filmis	doc_491521502268_item	3696092	et	0	main
mängis	doc_491521502268_item	3696093	et	0	main
suurt	doc_491521502268_item	3696094	et	0	main
rolli	doc_491521502268_item	3696095	et	0	main
ühiskonnakriitika	doc_491521502268_item	3696096	et	0	main
tekkele	doc_491521502268_item	3696097	et	0	main
ka	doc_491521502268_item	3696098	et	0	main
külaelu	doc_491521502268_item	3696099	et	0	main
külas	doc_491521502268_item	3696100	et	0	main
elatakse	doc_491521502268_item	3696101	et	0	main
ju	doc_491521502268_item	3696102	et	0	main
nii	doc_491521502268_item	3696103	et	0	main
et	doc_491521502268_item	3696104	et	0	main
kõik	doc_491521502268_item	3696105	et	0	main
tunnevad	doc_491521502268_item	3696106	et	0	main
kõiki	doc_491521502268_item	3696107	et	0	main
ja	doc_491521502268_item	3696108	et	0	main
kui	doc_491521502268_item	3696109	et	0	main
üks	doc_491521502268_item	3696110	et	0	main
inimene	doc_491521502268_item	3696111	et	0	main
midagi	doc_491521502268_item	3696112	et	0	main
arvab	doc_491521502268_item	3696113	et	0	main
räägib	doc_491521502268_item	3696114	et	0	main
ta	doc_491521502268_item	3696115	et	0	main
seda	doc_491521502268_item	3696116	et	0	main
teistele	doc_491521502268_item	3696117	et	0	main
tähtis	doc_491521502268_item	3696118	et	0	main
ei	doc_491521502268_item	3696119	et	0	main
olegi	doc_491521502268_item	3696120	et	0	main
see	doc_491521502268_item	3696121	et	0	main
kas	doc_491521502268_item	3696122	et	0	main
see	doc_491521502268_item	3696123	et	0	main
jutt	doc_491521502268_item	3696124	et	0	main
on	doc_491521502268_item	3696125	et	0	main
tõsi	doc_491521502268_item	3696126	et	0	main
või	doc_491521502268_item	3696127	et	0	main
mitte	doc_491521502268_item	3696128	et	0	main
ta	doc_491521502268_item	3696129	et	0	main
hakkab	doc_491521502268_item	3696130	et	0	main
levima	doc_491521502268_item	3696131	et	0	main
levides	doc_491521502268_item	3696132	et	0	main
koguvad	doc_491521502268_item	3696133	et	0	main
nad	doc_491521502268_item	3696134	et	0	main
juurde	doc_491521502268_item	3696135	et	0	main
teiste	doc_491521502268_item	3696136	et	0	main
arvamusi	doc_491521502268_item	3696137	et	0	main
ja	doc_491521502268_item	3696138	et	0	main
võib-olla	doc_491521502268_item	3696139	et	0	main
ka	doc_491521502268_item	3696140	et	0	main
põlgust	doc_491521502268_item	3696141	et	0	main
lõpuks	doc_491521502268_item	3696142	et	0	main
tuleb	doc_491521502268_item	3696143	et	0	main
välja	doc_491521502268_item	3696144	et	0	main
hoopiski	doc_491521502268_item	3696145	et	0	main
midagi	doc_491521502268_item	3696146	et	0	main
muud	doc_491521502268_item	3696147	et	0	main
kui	doc_491521502268_item	3696148	et	0	main
alguses	doc_491521502268_item	3696149	et	0	main
oli	doc_491521502268_item	3696150	et	0	main
aga	doc_491521502268_item	3696151	et	0	main
ühiskonnale	doc_491521502268_item	3696152	et	0	main
see	doc_491521502268_item	3696153	et	0	main
meeldib	doc_491521502268_item	3696154	et	0	main
tuua	doc_491521502268_item	3696155	et	0	main
vaheldust	doc_491521502268_item	3696156	et	0	main
kuulujuttudega	doc_491521502268_item	3696157	et	0	main
meie	doc_491521502268_item	3696158	et	0	main
igavasse	doc_491521502268_item	3696159	et	0	main
igapäevaellu	doc_491521502268_item	3696160	et	0	main
libahundiski	doc_491521502268_item	3696161	et	0	main
avaldas	doc_491521502268_item	3696162	et	0	main
üks	doc_491521502268_item	3696163	et	0	main
inimene	doc_491521502268_item	3696164	et	0	main
oma	doc_491521502268_item	3696165	et	0	main
arvamust	doc_491521502268_item	3696166	et	0	main
ja	doc_491521502268_item	3696167	et	0	main
kogu	doc_491521502268_item	3696168	et	0	main
küla	doc_491521502268_item	3696169	et	0	main
toetas	doc_491521502268_item	3696170	et	0	main
teda	doc_491521502268_item	3696171	et	0	main
kontrolltöö	doc_491521502187_item	3696172	et	0	main
1	doc_491521502187_item	3696173	et	0	main
milline	doc_491521502187_item	3696174	et	0	main
ärkamisaja	doc_491521502187_item	3696175	et	0	main
kultuuritegelane	doc_491521502187_item	3696176	et	0	main
on	doc_491521502187_item	3696177	et	0	main
kujutatud	doc_491521502187_item	3696178	et	0	main
eesti	doc_491521502187_item	3696179	et	0	main
10-kroonise	doc_491521502187_item	3696180	et	0	main
rahatähe	doc_491521502187_item	3696181	et	0	main
peal	doc_491521502187_item	3696182	et	0	main
mida	doc_491521502187_item	3696183	et	0	main
te	doc_491521502187_item	3696184	et	0	main
tema	doc_491521502187_item	3696185	et	0	main
tegevusest	doc_491521502187_item	3696186	et	0	main
teate	doc_491521502187_item	3696187	et	0	main
2	doc_491521502187_item	3696188	et	0	main
kes	doc_491521502187_item	3696189	et	0	main
olid	doc_491521502187_item	3696190	et	0	main
estofiilid	doc_491521502187_item	3696191	et	0	main
ja	doc_491521502187_item	3696192	et	0	main
milline	doc_491521502187_item	3696193	et	0	main
oli	doc_491521502187_item	3696194	et	0	main
nende	doc_491521502187_item	3696195	et	0	main
panus	doc_491521502187_item	3696196	et	0	main
eesti	doc_491521502187_item	3696197	et	0	main
kultuurilukku	doc_491521502187_item	3696198	et	0	main
1	doc_491521502187_item	3696199	et	0	main
j	doc_491521502187_item	3696200	et	0	main
hurt	doc_491521502187_item	3696201	et	0	main
õpib	doc_491521502187_item	3696202	et	0	main
tü	doc_491521502187_item	3696203	et	0	main
pastoriks	doc_491521502187_item	3696204	et	0	main
on	doc_491521502187_item	3696205	et	0	main
kujutatud	doc_491521502187_item	3696206	et	0	main
eesti	doc_491521502187_item	3696207	et	0	main
10-kroonise	doc_491521502187_item	3696208	et	0	main
rahatähe	doc_491521502187_item	3696209	et	0	main
peal	doc_491521502187_item	3696210	et	0	main
1860	doc_491521502187_item	3696211	et	0	main
a	doc_491521502187_item	3696212	et	0	main
vanemuine	doc_491521502187_item	3696213	et	0	main
laulu-	doc_491521502187_item	3696214	et	0	main
ja	doc_491521502187_item	3696215	et	0	main
tantsuselts	doc_491521502187_item	3696216	et	0	main
ta	doc_491521502187_item	3696217	et	0	main
oli	doc_491521502187_item	3696218	et	0	main
selle	doc_491521502187_item	3696219	et	0	main
seltsi	doc_491521502187_item	3696220	et	0	main
aktiivne	doc_491521502187_item	3696221	et	0	main
juht	doc_491521502187_item	3696222	et	0	main
19	doc_491521502187_item	3696223	et	0	main
saj	doc_491521502187_item	3696224	et	0	main
lõpuaastad	doc_491521502187_item	3696225	et	0	main
rahvusliku	doc_491521502187_item	3696226	et	0	main
liikumise	doc_491521502187_item	3696227	et	0	main
kriis	doc_491521502187_item	3696228	et	0	main
jacobson	doc_491521502187_item	3696229	et	0	main
hurt	doc_491521502187_item	3696230	et	0	main
vanemuine	doc_491521502187_item	3696231	et	0	main
selts	doc_491521502187_item	3696232	et	0	main
tegutses	doc_491521502187_item	3696233	et	0	main
eesti	doc_491521502187_item	3696234	et	0	main
laulu-	doc_491521502187_item	3696235	et	0	main
ja	doc_491521502187_item	3696236	et	0	main
tantsu	doc_491521502187_item	3696237	et	0	main
arendamisega	doc_491521502187_item	3696238	et	0	main
sellega	doc_491521502187_item	3696239	et	0	main
tegid	doc_491521502187_item	3696240	et	0	main
koostööd	doc_491521502187_item	3696241	et	0	main
paljud	doc_491521502187_item	3696242	et	0	main
eesti	doc_491521502187_item	3696243	et	0	main
huvilised	doc_491521502187_item	3696244	et	0	main
ja	doc_491521502187_item	3696245	et	0	main
kultuuritegelased	doc_491521502187_item	3696246	et	0	main
vanemuine	doc_491521502187_item	3696247	et	0	main
seltsis	doc_491521502187_item	3696248	et	0	main
esmakordselt	doc_491521502187_item	3696249	et	0	main
toimusid	doc_491521502187_item	3696250	et	0	main
näidendid	doc_491521502187_item	3696251	et	0	main
eesti	doc_491521502187_item	3696252	et	0	main
keeles	doc_491521502187_item	3696253	et	0	main
vanemuine	doc_491521502187_item	3696254	et	0	main
seltsi	doc_491521502187_item	3696255	et	0	main
peaülesanneks	doc_491521502187_item	3696256	et	0	main
oli	doc_491521502187_item	3696257	et	0	main
näidata	doc_491521502187_item	3696258	et	0	main
et	doc_491521502187_item	3696259	et	0	main
ka	doc_491521502187_item	3696260	et	0	main
eesti	doc_491521502187_item	3696261	et	0	main
keeles	doc_491521502187_item	3696262	et	0	main
on	doc_491521502187_item	3696263	et	0	main
võimalik	doc_491521502187_item	3696264	et	0	main
silmapaistvaid	doc_491521502187_item	3696265	et	0	main
teoseid	doc_491521502187_item	3696266	et	0	main
luua	doc_491521502187_item	3696267	et	0	main
vanemuise	doc_491521502187_item	3696268	et	0	main
seltsi	doc_491521502187_item	3696269	et	0	main
tegutsemise	doc_491521502187_item	3696270	et	0	main
tagajärjeks	doc_491521502187_item	3696271	et	0	main
oli	doc_491521502187_item	3696272	et	0	main
esimese	doc_491521502187_item	3696273	et	0	main
laulupeo	doc_491521502187_item	3696274	et	0	main
võimine	doc_491521502187_item	3696275	et	0	main
esmakordselt	doc_491521502187_item	3696276	et	0	main
see	doc_491521502187_item	3696277	et	0	main
toimus	doc_491521502187_item	3696278	et	0	main
tartus	doc_491521502187_item	3696279	et	0	main
eellaulupidu	doc_491521502187_item	3696280	et	0	main
ja	doc_491521502187_item	3696281	et	0	main
1867	doc_491521502187_item	3696282	et	0	main
a	doc_491521502187_item	3696283	et	0	main
toimus	doc_491521502187_item	3696284	et	0	main
i	doc_491521502187_item	3696285	et	0	main
laulupidu	doc_491521502187_item	3696286	et	0	main
tallinnas	doc_491521502187_item	3696287	et	0	main
seal	doc_491521502187_item	3696288	et	0	main
pidas	doc_491521502187_item	3696289	et	0	main
kõnet	doc_491521502187_item	3696290	et	0	main
jannesen	doc_491521502187_item	3696291	et	0	main
ja	doc_491521502187_item	3696292	et	0	main
jakobson	doc_491521502187_item	3696293	et	0	main
mängiti	doc_491521502187_item	3696294	et	0	main
erinevaid	doc_491521502187_item	3696295	et	0	main
laulu	doc_491521502187_item	3696296	et	0	main
näiteks	doc_491521502187_item	3696297	et	0	main
l	doc_491521502187_item	3696298	et	0	main
koidula	doc_491521502187_item	3696299	et	0	main
esmakordselt	doc_491521502187_item	3696300	et	0	main
laulupeos	doc_491521502187_item	3696301	et	0	main
lauldi	doc_491521502187_item	3696302	et	0	main
eesti	doc_491521502187_item	3696303	et	0	main
tänapäevane	doc_491521502187_item	3696304	et	0	main
hümn	doc_491521502187_item	3696305	et	0	main
kokkuvõtteks	doc_491521502187_item	3696306	et	0	main
vanemuine	doc_491521502187_item	3696307	et	0	main
laulu-	doc_491521502187_item	3696308	et	0	main
ja	doc_491521502187_item	3696309	et	0	main
tantsuselts	doc_491521502187_item	3696310	et	0	main
tegeles	doc_491521502187_item	3696311	et	0	main
eesti	doc_491521502187_item	3696312	et	0	main
kultuuri	doc_491521502187_item	3696313	et	0	main
arendamisega	doc_491521502187_item	3696314	et	0	main
kaastegijad	doc_491521502187_item	3696315	et	0	main
tähtsid	doc_491521502187_item	3696316	et	0	main
näidata	doc_491521502187_item	3696317	et	0	main
eesti	doc_491521502187_item	3696318	et	0	main
keele	doc_491521502187_item	3696319	et	0	main
ja	doc_491521502187_item	3696320	et	0	main
kultuuri	doc_491521502187_item	3696321	et	0	main
omapärasust	doc_491521502187_item	3696322	et	0	main
ja	doc_491521502187_item	3696323	et	0	main
ilu	doc_491521502187_item	3696324	et	0	main
vanemuise	doc_491521502187_item	3696325	et	0	main
seltsi	doc_491521502187_item	3696326	et	0	main
abil	doc_491521502187_item	3696327	et	0	main
eesti	doc_491521502187_item	3696328	et	0	main
rahvas	doc_491521502187_item	3696329	et	0	main
sai	doc_491521502187_item	3696330	et	0	main
paremini	doc_491521502187_item	3696331	et	0	main
teada	doc_491521502187_item	3696332	et	0	main
oma	doc_491521502187_item	3696333	et	0	main
kirjanikest	doc_491521502187_item	3696334	et	0	main
ja	doc_491521502187_item	3696335	et	0	main
luuletajast	doc_491521502187_item	3696336	et	0	main
seega	doc_491521502187_item	3696337	et	0	main
ka	doc_491521502187_item	3696338	et	0	main
oma	doc_491521502187_item	3696339	et	0	main
kultuurist	doc_491521502187_item	3696340	et	0	main
minevikust	doc_491521502187_item	3696341	et	0	main
2	doc_491521502187_item	3696342	et	0	main
merkel	doc_491521502187_item	3696343	et	0	main
ja	doc_491521502187_item	3696344	et	0	main
j	doc_491521502187_item	3696345	et	0	main
peetri	doc_491521502187_item	3696346	et	0	main
olid	doc_491521502187_item	3696347	et	0	main
estofiilid	doc_491521502187_item	3696348	et	0	main
esto	doc_491521502187_item	3696349	et	0	main
eesti	doc_491521502187_item	3696350	et	0	main
filo	doc_491521502187_item	3696351	et	0	main
armastama	doc_491521502187_item	3696352	et	0	main
estofiilid	doc_491521502187_item	3696353	et	0	main
olid	doc_491521502187_item	3696354	et	0	main
eesti	doc_491521502187_item	3696355	et	0	main
eluolu	doc_491521502187_item	3696356	et	0	main
parandamise	doc_491521502187_item	3696357	et	0	main
huvilised	doc_491521502187_item	3696358	et	0	main
estofilid	doc_491521502187_item	3696359	et	0	main
tegelesid	doc_491521502187_item	3696360	et	0	main
talupoegade	doc_491521502187_item	3696361	et	0	main
olukorra	doc_491521502187_item	3696362	et	0	main
parandamisega	doc_491521502187_item	3696363	et	0	main
ja	doc_491521502187_item	3696364	et	0	main
nende	doc_491521502187_item	3696365	et	0	main
tegevuse	doc_491521502187_item	3696366	et	0	main
tulemusena	doc_491521502187_item	3696367	et	0	main
võime	doc_491521502187_item	3696368	et	0	main
pidada	doc_491521502187_item	3696369	et	0	main
pärisorjuse	doc_491521502187_item	3696370	et	0	main
likvideerimist	doc_491521502187_item	3696371	et	0	main
nad	doc_491521502187_item	3696372	et	0	main
tahtsid	doc_491521502187_item	3696373	et	0	main
anda	doc_491521502187_item	3696374	et	0	main
talupoegadele	doc_491521502187_item	3696375	et	0	main
võimalust	doc_491521502187_item	3696376	et	0	main
ka	doc_491521502187_item	3696377	et	0	main
haridust	doc_491521502187_item	3696378	et	0	main
saada	doc_491521502187_item	3696379	et	0	main
kirjutavad	doc_491521502187_item	3696380	et	0	main
talupoegade	doc_491521502187_item	3696381	et	0	main
seisundi	doc_491521502187_item	3696382	et	0	main
parandamiseks	doc_491521502187_item	3696383	et	0	main
palve	doc_491521502187_item	3696384	et	0	main
merkel	doc_491521502187_item	3696385	et	0	main
ja	doc_491521502187_item	3696386	et	0	main
saadavad	doc_491521502187_item	3696387	et	0	main
seda	doc_491521502187_item	3696388	et	0	main
tsaarile	doc_491521502187_item	3696389	et	0	main
estofilid	doc_491521502187_item	3696390	et	0	main
настаивать	doc_491521502187_item	3696391	et	0	main
selles	doc_491521502187_item	3696392	et	0	main
et	doc_491521502187_item	3696393	et	0	main
tuleb	doc_491521502187_item	3696394	et	0	main
taasavada	doc_491521502187_item	3696395	et	0	main
tartu	doc_491521502187_item	3696396	et	0	main
ülikool	doc_491521502187_item	3696397	et	0	main
1802	doc_491521502187_item	3696398	et	0	main
a	doc_491521502187_item	3696399	et	0	main
avatakse	doc_491521502187_item	3696400	et	0	main
uuesti	doc_491521502187_item	3696401	et	0	main
tü	doc_491521502187_item	3696402	et	0	main
nende	doc_491521502187_item	3696403	et	0	main
tegevuse	doc_491521502187_item	3696404	et	0	main
tulemusena	doc_491521502187_item	3696405	et	0	main
ilmub	doc_491521502187_item	3696406	et	0	main
välja	doc_491521502187_item	3696407	et	0	main
1802	doc_491521502187_item	3696408	et	0	main
a	doc_491521502187_item	3696409	et	0	main
talupoegade	doc_491521502187_item	3696410	et	0	main
määrus	doc_491521502187_item	3696411	et	0	main
igaüks	doc_491521502187_item	3696412	et	0	main
talupojal	doc_491521502187_item	3696413	et	0	main
on	doc_491521502187_item	3696414	et	0	main
õigus	doc_491521502187_item	3696415	et	0	main
vallasvarale	doc_491521502187_item	3696416	et	0	main
mida	doc_491521502187_item	3696417	et	0	main
võib	doc_491521502187_item	3696418	et	0	main
pärandada	doc_491521502187_item	3696419	et	0	main
ja	doc_491521502187_item	3696420	et	0	main
müüa	doc_491521502187_item	3696421	et	0	main
kui	doc_491521502187_item	3696422	et	0	main
majapidamine	doc_491521502187_item	3696423	et	0	main
on	doc_491521502187_item	3696424	et	0	main
korras	doc_491521502187_item	3696425	et	0	main
siis	doc_491521502187_item	3696426	et	0	main
ei	doc_491521502187_item	3696427	et	0	main
saa	doc_491521502187_item	3696428	et	0	main
talupoega	doc_491521502187_item	3696429	et	0	main
tema	doc_491521502187_item	3696430	et	0	main
majast	doc_491521502187_item	3696431	et	0	main
tõsta	doc_491521502187_item	3696432	et	0	main
välja	doc_491521502187_item	3696433	et	0	main
sundida	doc_491521502187_item	3696434	et	0	main
ära	doc_491521502187_item	3696435	et	0	main
minema	doc_491521502187_item	3696436	et	0	main
raetakse	doc_491521502187_item	3696437	et	0	main
vallakohused	doc_491521502187_item	3696438	et	0	main
kuhu	doc_491521502187_item	3696439	et	0	main
talupojad	doc_491521502187_item	3696440	et	0	main
tulid	doc_491521502187_item	3696441	et	0	main
oma	doc_491521502187_item	3696442	et	0	main
kaebustega	doc_491521502187_item	3696443	et	0	main
nendel	doc_491521502187_item	3696444	et	0	main
oli	doc_491521502187_item	3696445	et	0	main
õigus	doc_491521502187_item	3696446	et	0	main
mõisnike	doc_491521502187_item	3696447	et	0	main
tegevused	doc_491521502187_item	3696448	et	0	main
опротестовать	doc_491521502187_item	3696449	et	0	main
läbi	doc_491521502187_item	3696450	et	0	main
vaadata	doc_491521502187_item	3696451	et	0	main
1816	doc_491521502187_item	3696452	et	0	main
a	doc_491521502187_item	3696453	et	0	main
pärisorjuse	doc_491521502187_item	3696454	et	0	main
likvideerimine	doc_491521502187_item	3696455	et	0	main
eestimaal	doc_491521502187_item	3696456	et	0	main
ja	doc_491521502187_item	3696457	et	0	main
1819	doc_491521502187_item	3696458	et	0	main
a	doc_491521502187_item	3696459	et	0	main
liivimaal	doc_491521502187_item	3696460	et	0	main
talupojad	doc_491521502187_item	3696461	et	0	main
said	doc_491521502187_item	3696462	et	0	main
perekonnanimesid	doc_491521502187_item	3696463	et	0	main
negatiivne	doc_491521502187_item	3696464	et	0	main
oli	doc_491521502187_item	3696465	et	0	main
see	doc_491521502187_item	3696466	et	0	main
et	doc_491521502187_item	3696467	et	0	main
talupoegi	doc_491521502187_item	3696468	et	0	main
vabastati	doc_491521502187_item	3696469	et	0	main
kuid	doc_491521502187_item	3696470	et	0	main
nendele	doc_491521502187_item	3696471	et	0	main
maad	doc_491521502187_item	3696472	et	0	main
ei	doc_491521502187_item	3696473	et	0	main
olnud	doc_491521502187_item	3696474	et	0	main
antud	doc_491521502187_item	3696475	et	0	main
ja	doc_491521502187_item	3696476	et	0	main
vaid	doc_491521502187_item	3696477	et	0	main
alates	doc_491521502187_item	3696478	et	0	main
1832a	doc_491521502187_item	3696479	et	0	main
anti	doc_491521502187_item	3696480	et	0	main
talupoegadele	doc_491521502187_item	3696481	et	0	main
õiguse	doc_491521502187_item	3696482	et	0	main
endale	doc_491521502187_item	3696483	et	0	main
elukoha	doc_491521502187_item	3696484	et	0	main
vabalt	doc_491521502187_item	3696485	et	0	main
valida	doc_491521502187_item	3696486	et	0	main
kokkuvõtteks	doc_491521502187_item	3696487	et	0	main
estofiilid	doc_491521502187_item	3696488	et	0	main
andsid	doc_491521502187_item	3696489	et	0	main
suure	doc_491521502187_item	3696490	et	0	main
panuse	doc_491521502187_item	3696491	et	0	main
eesti	doc_491521502187_item	3696492	et	0	main
talupoja	doc_491521502187_item	3696493	et	0	main
olukorra	doc_491521502187_item	3696494	et	0	main
parandamiseks	doc_491521502187_item	3696495	et	0	main
tänu	doc_491521502187_item	3696496	et	0	main
nendele	doc_491521502187_item	3696497	et	0	main
talupoeg	doc_491521502187_item	3696498	et	0	main
sai	doc_491521502187_item	3696499	et	0	main
vabaks	doc_491521502187_item	3696500	et	0	main
tal	doc_491521502187_item	3696501	et	0	main
oli	doc_491521502187_item	3696502	et	0	main
õigus	doc_491521502187_item	3696503	et	0	main
endale	doc_491521502187_item	3696504	et	0	main
oma	doc_491521502187_item	3696505	et	0	main
eluteed	doc_491521502187_item	3696506	et	0	main
valida	doc_491521502187_item	3696507	et	0	main
vabalt	doc_491521502187_item	3696508	et	0	main
kuid	doc_491521502187_item	3696509	et	0	main
see	doc_491521502187_item	3696510	et	0	main
päris	doc_491521502187_item	3696511	et	0	main
niimoodi	doc_491521502187_item	3696512	et	0	main
ei	doc_491521502187_item	3696513	et	0	main
olnud	doc_491521502187_item	3696514	et	0	main
talupojad	doc_491521502187_item	3696515	et	0	main
pidid	doc_491521502187_item	3696516	et	0	main
maad	doc_491521502187_item	3696517	et	0	main
rentima	doc_491521502187_item	3696518	et	0	main
ja	doc_491521502187_item	3696519	et	0	main
maksta	doc_491521502187_item	3696520	et	0	main
selle	doc_491521502187_item	3696521	et	0	main
eest	doc_491521502187_item	3696522	et	0	main
oma	doc_491521502187_item	3696523	et	0	main
tööga	doc_491521502187_item	3696524	et	0	main
või	doc_491521502187_item	3696525	et	0	main
saagiga	doc_491521502187_item	3696526	et	0	main
see	doc_491521502187_item	3696527	et	0	main
oli	doc_491521502187_item	3696528	et	0	main
vaid	doc_491521502187_item	3696529	et	0	main
ainult	doc_491521502187_item	3696530	et	0	main
natukene	doc_491521502187_item	3696531	et	0	main
parem	doc_491521502187_item	3696532	et	0	main
kui	doc_491521502187_item	3696533	et	0	main
nad	doc_491521502187_item	3696534	et	0	main
töötasid	doc_491521502187_item	3696535	et	0	main
mõisniku	doc_491521502187_item	3696536	et	0	main
jaoks	doc_491521502187_item	3696537	et	0	main
sel	doc_491521502187_item	3696538	et	0	main
ajal	doc_491521502187_item	3696539	et	0	main
kui	doc_491521502187_item	3696540	et	0	main
olid	doc_491521502187_item	3696541	et	0	main
orjad	doc_491521502187_item	3696542	et	0	main
rent	doc_491521502187_item	3696543	et	0	main
oli	doc_491521502187_item	3696544	et	0	main
suur	doc_491521502187_item	3696545	et	0	main
kontrolltöö	doc_301901115686_item	3696546	et	0	main
1	doc_301901115686_item	3696547	et	0	main
tooge	doc_301901115686_item	3696548	et	0	main
välja	doc_301901115686_item	3696549	et	0	main
peamised	doc_301901115686_item	3696550	et	0	main
erinevused	doc_301901115686_item	3696551	et	0	main
ev	doc_301901115686_item	3696552	et	0	main
ja	doc_301901115686_item	3696553	et	0	main
ensv	doc_301901115686_item	3696554	et	0	main
ühiskonnakorralduses	doc_301901115686_item	3696555	et	0	main
ja	doc_301901115686_item	3696556	et	0	main
majanduses	doc_301901115686_item	3696557	et	0	main
2	doc_301901115686_item	3696558	et	0	main
mida	doc_301901115686_item	3696559	et	0	main
mõeldakse	doc_301901115686_item	3696560	et	0	main
kui	doc_301901115686_item	3696561	et	0	main
ensv	doc_301901115686_item	3696562	et	0	main
kultuuriajaloos	doc_301901115686_item	3696563	et	0	main
kõneldakse	doc_301901115686_item	3696564	et	0	main
nn	doc_301901115686_item	3696565	et	0	main
hrustshovi	doc_301901115686_item	3696566	et	0	main
sulast	doc_301901115686_item	3696567	et	0	main
1	doc_301901115686_item	3696568	et	0	main
24	doc_301901115686_item	3696569	et	0	main
veebruaril	doc_301901115686_item	3696570	et	0	main
1918	doc_301901115686_item	3696571	et	0	main
a	doc_301901115686_item	3696572	et	0	main
eesti	doc_301901115686_item	3696573	et	0	main
sai	doc_301901115686_item	3696574	et	0	main
iseseisvuse	doc_301901115686_item	3696575	et	0	main
siis	doc_301901115686_item	3696576	et	0	main
oli	doc_301901115686_item	3696577	et	0	main
saksa	doc_301901115686_item	3696578	et	0	main
okupatsioon	doc_301901115686_item	3696579	et	0	main
ja	doc_301901115686_item	3696580	et	0	main
hiljem	doc_301901115686_item	3696581	et	0	main
vabadussõda	doc_301901115686_item	3696582	et	0	main
mille	doc_301901115686_item	3696583	et	0	main
lõpus	doc_301901115686_item	3696584	et	0	main
kirjutati	doc_301901115686_item	3696585	et	0	main
alla	doc_301901115686_item	3696586	et	0	main
tartu	doc_301901115686_item	3696587	et	0	main
rahule	doc_301901115686_item	3696588	et	0	main
ja	doc_301901115686_item	3696589	et	0	main
eesti	doc_301901115686_item	3696590	et	0	main
hakkas	doc_301901115686_item	3696591	et	0	main
ise	doc_301901115686_item	3696592	et	0	main
edasi	doc_301901115686_item	3696593	et	0	main
arenema	doc_301901115686_item	3696594	et	0	main
valiti	doc_301901115686_item	3696595	et	0	main
riigikogu	doc_301901115686_item	3696596	et	0	main
ja	doc_301901115686_item	3696597	et	0	main
võeti	doc_301901115686_item	3696598	et	0	main
vastu	doc_301901115686_item	3696599	et	0	main
esimene	doc_301901115686_item	3696600	et	0	main
põhiseadus	doc_301901115686_item	3696601	et	0	main
presidenti	doc_301901115686_item	3696602	et	0	main
polnud	doc_301901115686_item	3696603	et	0	main
riigipeaks	doc_301901115686_item	3696604	et	0	main
sai	doc_301901115686_item	3696605	et	0	main
k	doc_301901115686_item	3696606	et	0	main
päts	doc_301901115686_item	3696607	et	0	main
kellest	doc_301901115686_item	3696608	et	0	main
ka	doc_301901115686_item	3696609	et	0	main
hiljem	doc_301901115686_item	3696610	et	0	main
sai	doc_301901115686_item	3696611	et	0	main
i	doc_301901115686_item	3696612	et	0	main
eesti	doc_301901115686_item	3696613	et	0	main
president	doc_301901115686_item	3696614	et	0	main
nüüd	doc_301901115686_item	3696615	et	0	main
eestil	doc_301901115686_item	3696616	et	0	main
oli	doc_301901115686_item	3696617	et	0	main
oma	doc_301901115686_item	3696618	et	0	main
valitsus	doc_301901115686_item	3696619	et	0	main
mis	doc_301901115686_item	3696620	et	0	main
koosnes	doc_301901115686_item	3696621	et	0	main
mitmetest	doc_301901115686_item	3696622	et	0	main
erakondadest	doc_301901115686_item	3696623	et	0	main
eestis	doc_301901115686_item	3696624	et	0	main
algas	doc_301901115686_item	3696625	et	0	main
demokraatliku	doc_301901115686_item	3696626	et	0	main
arengu	doc_301901115686_item	3696627	et	0	main
periood	doc_301901115686_item	3696628	et	0	main
vaatamata	doc_301901115686_item	3696629	et	0	main
paljudele	doc_301901115686_item	3696630	et	0	main
raskustele	doc_301901115686_item	3696631	et	0	main
eesti	doc_301901115686_item	3696632	et	0	main
majanduslik	doc_301901115686_item	3696633	et	0	main
areng	doc_301901115686_item	3696634	et	0	main
oli	doc_301901115686_item	3696635	et	0	main
edukas	doc_301901115686_item	3696636	et	0	main
muidugi	doc_301901115686_item	3696637	et	0	main
suur	doc_301901115686_item	3696638	et	0	main
depressioon	doc_301901115686_item	3696639	et	0	main
1929	doc_301901115686_item	3696640	et	0	main
a	doc_301901115686_item	3696641	et	0	main
kajastus	doc_301901115686_item	3696642	et	0	main
ka	doc_301901115686_item	3696643	et	0	main
eesti	doc_301901115686_item	3696644	et	0	main
majanduses	doc_301901115686_item	3696645	et	0	main
mis	doc_301901115686_item	3696646	et	0	main
omamoodi	doc_301901115686_item	3696647	et	0	main
sai	doc_301901115686_item	3696648	et	0	main
ka	doc_301901115686_item	3696649	et	0	main
põhjuseks	doc_301901115686_item	3696650	et	0	main
parlamentaarsele	doc_301901115686_item	3696651	et	0	main
kriisile	doc_301901115686_item	3696652	et	0	main
ühiskondlikus	doc_301901115686_item	3696653	et	0	main
elus	doc_301901115686_item	3696654	et	0	main
oli	doc_301901115686_item	3696655	et	0	main
ka	doc_301901115686_item	3696656	et	0	main
kiire	doc_301901115686_item	3696657	et	0	main
areng	doc_301901115686_item	3696658	et	0	main
probleemiks	doc_301901115686_item	3696659	et	0	main
küll	doc_301901115686_item	3696660	et	0	main
oli	doc_301901115686_item	3696661	et	0	main
iseseisvuse	doc_301901115686_item	3696662	et	0	main
vastane	doc_301901115686_item	3696663	et	0	main
võitlus	doc_301901115686_item	3696664	et	0	main
aga	doc_301901115686_item	3696665	et	0	main
vaatamata	doc_301901115686_item	3696666	et	0	main
sellele	doc_301901115686_item	3696667	et	0	main
ühiskonnas	doc_301901115686_item	3696668	et	0	main
oli	doc_301901115686_item	3696669	et	0	main
optimistlik	doc_301901115686_item	3696670	et	0	main
meeleolu	doc_301901115686_item	3696671	et	0	main
avati	doc_301901115686_item	3696672	et	0	main
eesti	doc_301901115686_item	3696673	et	0	main
keelseid	doc_301901115686_item	3696674	et	0	main
kooli	doc_301901115686_item	3696675	et	0	main
taasavati	doc_301901115686_item	3696676	et	0	main
tartu	doc_301901115686_item	3696677	et	0	main
ülikool	doc_301901115686_item	3696678	et	0	main
hakkasid	doc_301901115686_item	3696679	et	0	main
tegutsema	doc_301901115686_item	3696680	et	0	main
igasugused	doc_301901115686_item	3696681	et	0	main
seltsid	doc_301901115686_item	3696682	et	0	main
hakkas	doc_301901115686_item	3696683	et	0	main
töötama	doc_301901115686_item	3696684	et	0	main
tallinna	doc_301901115686_item	3696685	et	0	main
tehnikakõrgkool	doc_301901115686_item	3696686	et	0	main
ttü	doc_301901115686_item	3696687	et	0	main
praegu	doc_301901115686_item	3696688	et	0	main
kunstikool	doc_301901115686_item	3696689	et	0	main
konservatoorium	doc_301901115686_item	3696690	et	0	main
arenesid	doc_301901115686_item	3696691	et	0	main
teadused	doc_301901115686_item	3696692	et	0	main
eriti	doc_301901115686_item	3696693	et	0	main
rahvusteadused	doc_301901115686_item	3696694	et	0	main
e	doc_301901115686_item	3696695	et	0	main
etnoloogia	doc_301901115686_item	3696696	et	0	main
arheoloogia	doc_301901115686_item	3696697	et	0	main
ajalugu	doc_301901115686_item	3696698	et	0	main
muusika	doc_301901115686_item	3696699	et	0	main
kunsti	doc_301901115686_item	3696700	et	0	main
kirjanduse	doc_301901115686_item	3696701	et	0	main
kultuuri	doc_301901115686_item	3696702	et	0	main
tegelased	doc_301901115686_item	3696703	et	0	main
koos	doc_301901115686_item	3696704	et	0	main
iseseisvusega	doc_301901115686_item	3696705	et	0	main
said	doc_301901115686_item	3696706	et	0	main
nagu	doc_301901115686_item	3696707	et	0	main
inspiratsiooni	doc_301901115686_item	3696708	et	0	main
ja	doc_301901115686_item	3696709	et	0	main
hakkasid	doc_301901115686_item	3696710	et	0	main
looma	doc_301901115686_item	3696711	et	0	main
kultuur	doc_301901115686_item	3696712	et	0	main
arenes	doc_301901115686_item	3696713	et	0	main
kiiresti	doc_301901115686_item	3696714	et	0	main
ja	doc_301901115686_item	3696715	et	0	main
edukalt	doc_301901115686_item	3696716	et	0	main
rõhutati	doc_301901115686_item	3696717	et	0	main
rahvust	doc_301901115686_item	3696718	et	0	main
elu	doc_301901115686_item	3696719	et	0	main
muutus	doc_301901115686_item	3696720	et	0	main
paremaks	doc_301901115686_item	3696721	et	0	main
kõik	doc_301901115686_item	3696722	et	0	main
muutus	doc_301901115686_item	3696723	et	0	main
pärast	doc_301901115686_item	3696724	et	0	main
okupatsiooni	doc_301901115686_item	3696725	et	0	main
pärast	doc_301901115686_item	3696726	et	0	main
ii	doc_301901115686_item	3696727	et	0	main
ms	doc_301901115686_item	3696728	et	0	main
eesti	doc_301901115686_item	3696729	et	0	main
sai	doc_301901115686_item	3696730	et	0	main
okupeeritud	doc_301901115686_item	3696731	et	0	main
alaks	doc_301901115686_item	3696732	et	0	main
nsvl	doc_301901115686_item	3696733	et	0	main
poolt	doc_301901115686_item	3696734	et	0	main
ja	doc_301901115686_item	3696735	et	0	main
olukord	doc_301901115686_item	3696736	et	0	main
hakkas	doc_301901115686_item	3696737	et	0	main
muutuma	doc_301901115686_item	3696738	et	0	main
paljud	doc_301901115686_item	3696739	et	0	main
inimesed	doc_301901115686_item	3696740	et	0	main
põgenesid	doc_301901115686_item	3696741	et	0	main
läände	doc_301901115686_item	3696742	et	0	main
rootsi	doc_301901115686_item	3696743	et	0	main
kanadasse	doc_301901115686_item	3696744	et	0	main
austraaliasse	doc_301901115686_item	3696745	et	0	main
nl	doc_301901115686_item	3696746	et	0	main
võim	doc_301901115686_item	3696747	et	0	main
tõi	doc_301901115686_item	3696748	et	0	main
kaasa	doc_301901115686_item	3696749	et	0	main
ühiskonda	doc_301901115686_item	3696750	et	0	main
hirmu	doc_301901115686_item	3696751	et	0	main
ja	doc_301901115686_item	3696752	et	0	main
viha	doc_301901115686_item	3696753	et	0	main
algas	doc_301901115686_item	3696754	et	0	main
ideoloogiline	doc_301901115686_item	3696755	et	0	main
surutis	doc_301901115686_item	3696756	et	0	main
repressioonid	doc_301901115686_item	3696757	et	0	main
juhikultus	doc_301901115686_item	3696758	et	0	main
ja	doc_301901115686_item	3696759	et	0	main
üldse	doc_301901115686_item	3696760	et	0	main
hirmuseisund	doc_301901115686_item	3696761	et	0	main
mille	doc_301901115686_item	3696762	et	0	main
abil	doc_301901115686_item	3696763	et	0	main
valitses	doc_301901115686_item	3696764	et	0	main
stalin	doc_301901115686_item	3696765	et	0	main
võrreldes	doc_301901115686_item	3696766	et	0	main
ev	doc_301901115686_item	3696767	et	0	main
perioodiga	doc_301901115686_item	3696768	et	0	main
oli	doc_301901115686_item	3696769	et	0	main
võimatu	doc_301901115686_item	3696770	et	0	main
kannatada	doc_301901115686_item	3696771	et	0	main
majanduses	doc_301901115686_item	3696772	et	0	main
arendati	doc_301901115686_item	3696773	et	0	main
rasketööstus	doc_301901115686_item	3696774	et	0	main
hinnad	doc_301901115686_item	3696775	et	0	main
tõsteti	doc_301901115686_item	3696776	et	0	main
maksud	doc_301901115686_item	3696777	et	0	main
samuti	doc_301901115686_item	3696778	et	0	main
majandus	doc_301901115686_item	3696779	et	0	main
oli	doc_301901115686_item	3696780	et	0	main
tsentraliseeritud	doc_301901115686_item	3696781	et	0	main
ja	doc_301901115686_item	3696782	et	0	main
plaanimajandus	doc_301901115686_item	3696783	et	0	main
alguses	doc_301901115686_item	3696784	et	0	main
inimesed	doc_301901115686_item	3696785	et	0	main
püüdsid	doc_301901115686_item	3696786	et	0	main
selle	doc_301901115686_item	3696787	et	0	main
vastu	doc_301901115686_item	3696788	et	0	main
võidelda	doc_301901115686_item	3696789	et	0	main
tekkis	doc_301901115686_item	3696790	et	0	main
metsavendlus	doc_301901115686_item	3696791	et	0	main
kuid	doc_301901115686_item	3696792	et	0	main
lõpuks	doc_301901115686_item	3696793	et	0	main
hakati	doc_301901115686_item	3696794	et	0	main
sellega	doc_301901115686_item	3696795	et	0	main
kuidagi	doc_301901115686_item	3696796	et	0	main
elama	doc_301901115686_item	3696797	et	0	main
õppima	doc_301901115686_item	3696798	et	0	main
ja	doc_301901115686_item	3696799	et	0	main
harjuma	doc_301901115686_item	3696800	et	0	main
sellega	doc_301901115686_item	3696801	et	0	main
õnneks	doc_301901115686_item	3696802	et	0	main
see	doc_301901115686_item	3696803	et	0	main
kõik	doc_301901115686_item	3696804	et	0	main
lõppes	doc_301901115686_item	3696805	et	0	main
eesti	doc_301901115686_item	3696806	et	0	main
taasiseseisvumisega	doc_301901115686_item	3696807	et	0	main
ja	doc_301901115686_item	3696808	et	0	main
eesti	doc_301901115686_item	3696809	et	0	main
jälle	doc_301901115686_item	3696810	et	0	main
on	doc_301901115686_item	3696811	et	0	main
vaba	doc_301901115686_item	3696812	et	0	main
ja	doc_301901115686_item	3696813	et	0	main
iseseisev	doc_301901115686_item	3696814	et	0	main
ning	doc_301901115686_item	3696815	et	0	main
praegune	doc_301901115686_item	3696816	et	0	main
ev	doc_301901115686_item	3696817	et	0	main
olukord	doc_301901115686_item	3696818	et	0	main
võrreldes	doc_301901115686_item	3696819	et	0	main
ensv-ga	doc_301901115686_item	3696820	et	0	main
on	doc_301901115686_item	3696821	et	0	main
palju	doc_301901115686_item	3696822	et	0	main
parem	doc_301901115686_item	3696823	et	0	main
ehitati	doc_301901115686_item	3696824	et	0	main
kolhoose	doc_301901115686_item	3696825	et	0	main
ja	doc_301901115686_item	3696826	et	0	main
sovhoose	doc_301901115686_item	3696827	et	0	main
nsvl-s	doc_301901115686_item	3696828	et	0	main
läbi	doc_301901115686_item	3696829	et	0	main
viidi	doc_301901115686_item	3696830	et	0	main
reforme	doc_301901115686_item	3696831	et	0	main
ehitati	doc_301901115686_item	3696832	et	0	main
kommunismi	doc_301901115686_item	3696833	et	0	main
ideeks	doc_301901115686_item	3696834	et	0	main
oli	doc_301901115686_item	3696835	et	0	main
homo	doc_301901115686_item	3696836	et	0	main
sovetikus	doc_301901115686_item	3696837	et	0	main
mille	doc_301901115686_item	3696838	et	0	main
tõttu	doc_301901115686_item	3696839	et	0	main
vähem	doc_301901115686_item	3696840	et	0	main
rahvaste	doc_301901115686_item	3696841	et	0	main
kultuuri	doc_301901115686_item	3696842	et	0	main
arengust	doc_301901115686_item	3696843	et	0	main
eriti	doc_301901115686_item	3696844	et	0	main
ei	doc_301901115686_item	3696845	et	0	main
muretsenud	doc_301901115686_item	3696846	et	0	main
kõik	doc_301901115686_item	3696847	et	0	main
oli	doc_301901115686_item	3696848	et	0	main
riigi	doc_301901115686_item	3696849	et	0	main
kontrolli	doc_301901115686_item	3696850	et	0	main
all	doc_301901115686_item	3696851	et	0	main
2	doc_301901115686_item	3696852	et	0	main
hrustsovi	doc_301901115686_item	3696853	et	0	main
sula	doc_301901115686_item	3696854	et	0	main
see	doc_301901115686_item	3696855	et	0	main
on	doc_301901115686_item	3696856	et	0	main
hilistalinismile	doc_301901115686_item	3696857	et	0	main
järgnev	doc_301901115686_item	3696858	et	0	main
periood	doc_301901115686_item	3696859	et	0	main
millal	doc_301901115686_item	3696860	et	0	main
nsvl	doc_301901115686_item	3696861	et	0	main
võimul	doc_301901115686_item	3696862	et	0	main
oli	doc_301901115686_item	3696863	et	0	main
nikita	doc_301901115686_item	3696864	et	0	main
hrustsov	doc_301901115686_item	3696865	et	0	main
lõppes	doc_301901115686_item	3696866	et	0	main
selline	doc_301901115686_item	3696867	et	0	main
massiline	doc_301901115686_item	3696868	et	0	main
vägivalla	doc_301901115686_item	3696869	et	0	main
poliitika	doc_301901115686_item	3696870	et	0	main
majanduses	doc_301901115686_item	3696871	et	0	main
algasid	doc_301901115686_item	3696872	et	0	main
ümberkorraldused	doc_301901115686_item	3696873	et	0	main
ja	doc_301901115686_item	3696874	et	0	main
kampaaniad	doc_301901115686_item	3696875	et	0	main
maisi	doc_301901115686_item	3696876	et	0	main
hobuste	doc_301901115686_item	3696877	et	0	main
sel	doc_301901115686_item	3696878	et	0	main
perioodil	doc_301901115686_item	3696879	et	0	main
toimus	doc_301901115686_item	3696880	et	0	main
destaliniseerumine	doc_301901115686_item	3696881	et	0	main
lõppesid	doc_301901115686_item	3696882	et	0	main
repressioonid	doc_301901115686_item	3696883	et	0	main
algas	doc_301901115686_item	3696884	et	0	main
reabiliteerimine	doc_301901115686_item	3696885	et	0	main
paljud	doc_301901115686_item	3696886	et	0	main
inimesed	doc_301901115686_item	3696887	et	0	main
tulid	doc_301901115686_item	3696888	et	0	main
koju	doc_301901115686_item	3696889	et	0	main
tagasi	doc_301901115686_item	3696890	et	0	main
majanduses	doc_301901115686_item	3696891	et	0	main
on	doc_301901115686_item	3696892	et	0	main
suhteliselt	doc_301901115686_item	3696893	et	0	main
hea	doc_301901115686_item	3696894	et	0	main
aeg	doc_301901115686_item	3696895	et	0	main
sest	doc_301901115686_item	3696896	et	0	main
areng	doc_301901115686_item	3696897	et	0	main
toimus	doc_301901115686_item	3696898	et	0	main
suhteliselt	doc_301901115686_item	3696899	et	0	main
kiiresti	doc_301901115686_item	3696900	et	0	main
ühiskondlikus	doc_301901115686_item	3696901	et	0	main
plaanis	doc_301901115686_item	3696902	et	0	main
võib	doc_301901115686_item	3696903	et	0	main
öelda	doc_301901115686_item	3696904	et	0	main
et	doc_301901115686_item	3696905	et	0	main
hrustsov	doc_301901115686_item	3696906	et	0	main
oli	doc_301901115686_item	3696907	et	0	main
pehmem	doc_301901115686_item	3696908	et	0	main
kui	doc_301901115686_item	3696909	et	0	main
teised	doc_301901115686_item	3696910	et	0	main
võimukandjad	doc_301901115686_item	3696911	et	0	main
sellepärastki	doc_301901115686_item	3696912	et	0	main
nimetatakse	doc_301901115686_item	3696913	et	0	main
seda	doc_301901115686_item	3696914	et	0	main
perioodi	doc_301901115686_item	3696915	et	0	main
sulaks	doc_301901115686_item	3696916	et	0	main
ta	doc_301901115686_item	3696917	et	0	main
valitses	doc_301901115686_item	3696918	et	0	main
rohkem	doc_301901115686_item	3696919	et	0	main
intuitsiooni	doc_301901115686_item	3696920	et	0	main
järgi	doc_301901115686_item	3696921	et	0	main
mille	doc_301901115686_item	3696922	et	0	main
tõttu	doc_301901115686_item	3696923	et	0	main
stalini	doc_301901115686_item	3696924	et	0	main
poliitika	doc_301901115686_item	3696925	et	0	main
pooldajatega	doc_301901115686_item	3696926	et	0	main
ja	doc_301901115686_item	3696927	et	0	main
kõrgintelligentsiga	doc_301901115686_item	3696928	et	0	main
tal	doc_301901115686_item	3696929	et	0	main
olid	doc_301901115686_item	3696930	et	0	main
konfliktid	doc_301901115686_item	3696931	et	0	main
tema	doc_301901115686_item	3696932	et	0	main
valitsemisperioodil	doc_301901115686_item	3696933	et	0	main
üldine	doc_301901115686_item	3696934	et	0	main
olukord	doc_301901115686_item	3696935	et	0	main
paranes	doc_301901115686_item	3696936	et	0	main
elu	doc_301901115686_item	3696937	et	0	main
muutus	doc_301901115686_item	3696938	et	0	main
kergemaks	doc_301901115686_item	3696939	et	0	main
mis	doc_301901115686_item	3696940	et	0	main
puudutab	doc_301901115686_item	3696941	et	0	main
eestit	doc_301901115686_item	3696942	et	0	main
siis	doc_301901115686_item	3696943	et	0	main
arvatakse	doc_301901115686_item	3696944	et	0	main
et	doc_301901115686_item	3696945	et	0	main
nsvl	doc_301901115686_item	3696946	et	0	main
võimul	doc_301901115686_item	3696947	et	0	main
olevatest	doc_301901115686_item	3696948	et	0	main
inimestest	doc_301901115686_item	3696949	et	0	main
hrustsov	doc_301901115686_item	3696950	et	0	main
oli	doc_301901115686_item	3696951	et	0	main
kõige	doc_301901115686_item	3696952	et	0	main
inimlikum	doc_301901115686_item	3696953	et	0	main
valitseja	doc_301901115686_item	3696954	et	0	main
vaatamata	doc_301901115686_item	3696955	et	0	main
ka	doc_301901115686_item	3696956	et	0	main
tema	doc_301901115686_item	3696957	et	0	main
reformidele	doc_301901115686_item	3696958	et	0	main
kultuurielus	doc_301901115686_item	3696959	et	0	main
toimuvad	doc_301901115686_item	3696960	et	0	main
muutused	doc_301901115686_item	3696961	et	0	main
andsid	doc_301901115686_item	3696962	et	0	main
lootuse	doc_301901115686_item	3696963	et	0	main
mõnedele	doc_301901115686_item	3696964	et	0	main
inimestele	doc_301901115686_item	3696965	et	0	main
riigi	doc_301901115686_item	3696966	et	0	main
taasiseseisvumisele	doc_301901115686_item	3696967	et	0	main
ja	doc_301901115686_item	3696968	et	0	main
oma	doc_301901115686_item	3696969	et	0	main
rahvuse	doc_301901115686_item	3696970	et	0	main
säilitamisele	doc_301901115686_item	3696971	et	0	main
andsid	doc_301901115686_item	3696972	et	0	main
ka	doc_301901115686_item	3696973	et	0	main
julguse	doc_301901115686_item	3696974	et	0	main
mis	doc_301901115686_item	3696975	et	0	main
hiljem	doc_301901115686_item	3696976	et	0	main
tekitas	doc_301901115686_item	3696977	et	0	main
dissidentluse	doc_301901115686_item	3696978	et	0	main
tuntuimad	doc_301901115686_item	3696979	et	0	main
dissidendid	doc_301901115686_item	3696980	et	0	main
on	doc_301901115686_item	3696981	et	0	main
sahharov	doc_301901115686_item	3696982	et	0	main
ja	doc_301901115686_item	3696983	et	0	main
solženitsõn	doc_301901115686_item	3696984	et	0	main
palju	doc_301901115686_item	3696985	et	0	main
ehitati	doc_301901115686_item	3696986	et	0	main
eriti	doc_301901115686_item	3696987	et	0	main
elamisrajoone	doc_301901115686_item	3696988	et	0	main
mida	doc_301901115686_item	3696989	et	0	main
ka	doc_301901115686_item	3696990	et	0	main
praegu	doc_301901115686_item	3696991	et	0	main
võime	doc_301901115686_item	3696992	et	0	main
näha	doc_301901115686_item	3696993	et	0	main
igas	doc_301901115686_item	3696994	et	0	main
endises	doc_301901115686_item	3696995	et	0	main
nsvl	doc_301901115686_item	3696996	et	0	main
linnas	doc_301901115686_item	3696997	et	0	main
aga	doc_301901115686_item	3696998	et	0	main
kõigile	doc_301901115686_item	3696999	et	0	main
tuleb	doc_301901115686_item	3697000	et	0	main
lõpp	doc_301901115686_item	3697001	et	0	main
sulale	doc_301901115686_item	3697002	et	0	main
järgnes	doc_301901115686_item	3697003	et	0	main
brežnevi	doc_301901115686_item	3697004	et	0	main
valitsemisperiood	doc_301901115686_item	3697005	et	0	main
ja	doc_301901115686_item	3697006	et	0	main
stagnatsioon	doc_301901115686_item	3697007	et	0	main
referaat	doc_881665289253_item	3699955	et	0	cKUAfXynZ
lt	doc_881665289253_item	3699956	et	0	cKUAfXynZ
font	doc_881665289253_item	3699957	et	0	cKUAfXynZ
definitions	doc_881665289253_item	3699958	et	0	cKUAfXynZ
font-face	doc_881665289253_item	3699959	et	0	cKUAfXynZ
font-familycambria	doc_881665289253_item	3699960	et	0	cKUAfXynZ
math	doc_881665289253_item	3699961	et	0	cKUAfXynZ
panose-12	doc_881665289253_item	3699962	et	0	cKUAfXynZ
4	doc_881665289253_item	3699963	et	0	cKUAfXynZ
5	doc_881665289253_item	3699964	et	0	cKUAfXynZ
3	doc_881665289253_item	3699965	et	0	cKUAfXynZ
5	doc_881665289253_item	3699966	et	0	cKUAfXynZ
4	doc_881665289253_item	3699967	et	0	cKUAfXynZ
6	doc_881665289253_item	3699968	et	0	cKUAfXynZ
3	doc_881665289253_item	3699969	et	0	cKUAfXynZ
2	doc_881665289253_item	3699970	et	0	cKUAfXynZ
4	doc_881665289253_item	3699971	et	0	cKUAfXynZ
mso-font-charset1	doc_881665289253_item	3699972	et	0	cKUAfXynZ
mso-generic-font-familyroman	doc_881665289253_item	3699973	et	0	cKUAfXynZ
mso-font-formatother	doc_881665289253_item	3699974	et	0	cKUAfXynZ
mso-font-pitchvariable	doc_881665289253_item	3699975	et	0	cKUAfXynZ
mso-font-signature0	doc_881665289253_item	3699976	et	0	cKUAfXynZ
0	doc_881665289253_item	3699977	et	0	cKUAfXynZ
0	doc_881665289253_item	3699978	et	0	cKUAfXynZ
0	doc_881665289253_item	3699979	et	0	cKUAfXynZ
0	doc_881665289253_item	3699980	et	0	cKUAfXynZ
0	doc_881665289253_item	3699981	et	0	cKUAfXynZ
style	doc_881665289253_item	3699982	et	0	cKUAfXynZ
definitions	doc_881665289253_item	3699983	et	0	cKUAfXynZ
pmsonormal	doc_881665289253_item	3699984	et	0	cKUAfXynZ
limsonormal	doc_881665289253_item	3699985	et	0	cKUAfXynZ
divmsonormal	doc_881665289253_item	3699986	et	0	cKUAfXynZ
mso-style-unhideno	doc_881665289253_item	3699987	et	0	cKUAfXynZ
mso-style-qformatyes	doc_881665289253_item	3699988	et	0	cKUAfXynZ
mso-style-parent	doc_881665289253_item	3699989	et	0	cKUAfXynZ
margin0cm	doc_881665289253_item	3699990	et	0	cKUAfXynZ
margin-bottom0001pt	doc_881665289253_item	3699991	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_881665289253_item	3699992	et	0	cKUAfXynZ
font-size120pt	doc_881665289253_item	3699993	et	0	cKUAfXynZ
font-familytimes	doc_881665289253_item	3699994	et	0	cKUAfXynZ
new	doc_881665289253_item	3699995	et	0	cKUAfXynZ
romanserif	doc_881665289253_item	3699996	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_881665289253_item	3699997	et	0	cKUAfXynZ
new	doc_881665289253_item	3699998	et	0	cKUAfXynZ
roman	doc_881665289253_item	3699999	et	0	cKUAfXynZ
mso-ansi-languageen-us	doc_881665289253_item	3700000	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_881665289253_item	3700001	et	0	cKUAfXynZ
h1	doc_881665289253_item	3700002	et	0	cKUAfXynZ
mso-style-unhideno	doc_881665289253_item	3700003	et	0	cKUAfXynZ
mso-style-qformatyes	doc_881665289253_item	3700004	et	0	cKUAfXynZ
mso-style-linkheading	doc_881665289253_item	3700005	et	0	cKUAfXynZ
1	doc_881665289253_item	3700006	et	0	cKUAfXynZ
char	doc_881665289253_item	3700007	et	0	cKUAfXynZ
mso-style-nextnormal	doc_881665289253_item	3700008	et	0	cKUAfXynZ
margin0cm	doc_881665289253_item	3700009	et	0	cKUAfXynZ
margin-bottom0001pt	doc_881665289253_item	3700010	et	0	cKUAfXynZ
text-aligncenter	doc_881665289253_item	3700011	et	0	cKUAfXynZ
line-height150	doc_881665289253_item	3700012	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_881665289253_item	3700013	et	0	cKUAfXynZ
page-break-afteravoid	doc_881665289253_item	3700014	et	0	cKUAfXynZ
mso-outline-level1	doc_881665289253_item	3700015	et	0	cKUAfXynZ
font-size140pt	doc_881665289253_item	3700016	et	0	cKUAfXynZ
mso-bidi-font-size120pt	doc_881665289253_item	3700017	et	0	cKUAfXynZ
font-familytimes	doc_881665289253_item	3700018	et	0	cKUAfXynZ
new	doc_881665289253_item	3700019	et	0	cKUAfXynZ
romanserif	doc_881665289253_item	3700020	et	0	cKUAfXynZ
mso-font-kerning0pt	doc_881665289253_item	3700021	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_881665289253_item	3700022	et	0	cKUAfXynZ
font-weightnormal	doc_881665289253_item	3700023	et	0	cKUAfXynZ
h2	doc_881665289253_item	3700024	et	0	cKUAfXynZ
mso-style-unhideno	doc_881665289253_item	3700025	et	0	cKUAfXynZ
mso-style-qformatyes	doc_881665289253_item	3700026	et	0	cKUAfXynZ
mso-style-linkheading	doc_881665289253_item	3700027	et	0	cKUAfXynZ
2	doc_881665289253_item	3700028	et	0	cKUAfXynZ
char	doc_881665289253_item	3700029	et	0	cKUAfXynZ
mso-style-nextnormal	doc_881665289253_item	3700030	et	0	cKUAfXynZ
margin0cm	doc_881665289253_item	3700031	et	0	cKUAfXynZ
margin-bottom0001pt	doc_881665289253_item	3700032	et	0	cKUAfXynZ
text-aligncenter	doc_881665289253_item	3700033	et	0	cKUAfXynZ
line-height150	doc_881665289253_item	3700034	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_881665289253_item	3700035	et	0	cKUAfXynZ
page-break-afteravoid	doc_881665289253_item	3700036	et	0	cKUAfXynZ
mso-outline-level2	doc_881665289253_item	3700037	et	0	cKUAfXynZ
font-size160pt	doc_881665289253_item	3700038	et	0	cKUAfXynZ
mso-bidi-font-size120pt	doc_881665289253_item	3700039	et	0	cKUAfXynZ
font-familytimes	doc_881665289253_item	3700040	et	0	cKUAfXynZ
new	doc_881665289253_item	3700041	et	0	cKUAfXynZ
romanserif	doc_881665289253_item	3700042	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_881665289253_item	3700043	et	0	cKUAfXynZ
font-weightnormal	doc_881665289253_item	3700044	et	0	cKUAfXynZ
pmsotoc1	doc_881665289253_item	3700045	et	0	cKUAfXynZ
limsotoc1	doc_881665289253_item	3700046	et	0	cKUAfXynZ
divmsotoc1	doc_881665289253_item	3700047	et	0	cKUAfXynZ
mso-style-updateauto	doc_881665289253_item	3700048	et	0	cKUAfXynZ
mso-style-noshowyes	doc_881665289253_item	3700049	et	0	cKUAfXynZ
mso-style-unhideno	doc_881665289253_item	3700050	et	0	cKUAfXynZ
mso-style-nextnormal	doc_881665289253_item	3700051	et	0	cKUAfXynZ
margin0cm	doc_881665289253_item	3700052	et	0	cKUAfXynZ
margin-bottom0001pt	doc_881665289253_item	3700053	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_881665289253_item	3700054	et	0	cKUAfXynZ
font-size120pt	doc_881665289253_item	3700055	et	0	cKUAfXynZ
font-familytimes	doc_881665289253_item	3700056	et	0	cKUAfXynZ
new	doc_881665289253_item	3700057	et	0	cKUAfXynZ
romanserif	doc_881665289253_item	3700058	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_881665289253_item	3700059	et	0	cKUAfXynZ
new	doc_881665289253_item	3700060	et	0	cKUAfXynZ
roman	doc_881665289253_item	3700061	et	0	cKUAfXynZ
mso-ansi-languageen-us	doc_881665289253_item	3700062	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_881665289253_item	3700063	et	0	cKUAfXynZ
pmsotoc2	doc_881665289253_item	3700064	et	0	cKUAfXynZ
limsotoc2	doc_881665289253_item	3700065	et	0	cKUAfXynZ
divmsotoc2	doc_881665289253_item	3700066	et	0	cKUAfXynZ
mso-style-updateauto	doc_881665289253_item	3700067	et	0	cKUAfXynZ
mso-style-noshowyes	doc_881665289253_item	3700068	et	0	cKUAfXynZ
mso-style-unhideno	doc_881665289253_item	3700069	et	0	cKUAfXynZ
mso-style-nextnormal	doc_881665289253_item	3700070	et	0	cKUAfXynZ
margin-top0cm	doc_881665289253_item	3700071	et	0	cKUAfXynZ
margin-right0cm	doc_881665289253_item	3700072	et	0	cKUAfXynZ
margin-bottom0cm	doc_881665289253_item	3700073	et	0	cKUAfXynZ
margin-left120pt	doc_881665289253_item	3700074	et	0	cKUAfXynZ
margin-bottom0001pt	doc_881665289253_item	3700075	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_881665289253_item	3700076	et	0	cKUAfXynZ
font-size120pt	doc_881665289253_item	3700077	et	0	cKUAfXynZ
font-familytimes	doc_881665289253_item	3700078	et	0	cKUAfXynZ
new	doc_881665289253_item	3700079	et	0	cKUAfXynZ
romanserif	doc_881665289253_item	3700080	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_881665289253_item	3700081	et	0	cKUAfXynZ
new	doc_881665289253_item	3700082	et	0	cKUAfXynZ
roman	doc_881665289253_item	3700083	et	0	cKUAfXynZ
mso-ansi-languageen-us	doc_881665289253_item	3700084	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_881665289253_item	3700085	et	0	cKUAfXynZ
pmsofooter	doc_881665289253_item	3700086	et	0	cKUAfXynZ
limsofooter	doc_881665289253_item	3700087	et	0	cKUAfXynZ
divmsofooter	doc_881665289253_item	3700088	et	0	cKUAfXynZ
mso-style-unhideno	doc_881665289253_item	3700089	et	0	cKUAfXynZ
mso-style-linkfooter	doc_881665289253_item	3700090	et	0	cKUAfXynZ
char	doc_881665289253_item	3700091	et	0	cKUAfXynZ
margin0cm	doc_881665289253_item	3700092	et	0	cKUAfXynZ
margin-bottom0001pt	doc_881665289253_item	3700093	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_881665289253_item	3700094	et	0	cKUAfXynZ
tab-stopscenter	doc_881665289253_item	3700095	et	0	cKUAfXynZ
23385pt	doc_881665289253_item	3700096	et	0	cKUAfXynZ
right	doc_881665289253_item	3700097	et	0	cKUAfXynZ
46775pt	doc_881665289253_item	3700098	et	0	cKUAfXynZ
font-size120pt	doc_881665289253_item	3700099	et	0	cKUAfXynZ
font-familytimes	doc_881665289253_item	3700100	et	0	cKUAfXynZ
new	doc_881665289253_item	3700101	et	0	cKUAfXynZ
romanserif	doc_881665289253_item	3700102	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_881665289253_item	3700103	et	0	cKUAfXynZ
new	doc_881665289253_item	3700104	et	0	cKUAfXynZ
roman	doc_881665289253_item	3700105	et	0	cKUAfXynZ
mso-ansi-languageen-us	doc_881665289253_item	3700106	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_881665289253_item	3700107	et	0	cKUAfXynZ
pmsobodytext	doc_881665289253_item	3700108	et	0	cKUAfXynZ
limsobodytext	doc_881665289253_item	3700109	et	0	cKUAfXynZ
divmsobodytext	doc_881665289253_item	3700110	et	0	cKUAfXynZ
mso-style-unhideno	doc_881665289253_item	3700111	et	0	cKUAfXynZ
mso-style-linkbody	doc_881665289253_item	3700112	et	0	cKUAfXynZ
text	doc_881665289253_item	3700113	et	0	cKUAfXynZ
char	doc_881665289253_item	3700114	et	0	cKUAfXynZ
margin0cm	doc_881665289253_item	3700115	et	0	cKUAfXynZ
margin-bottom0001pt	doc_881665289253_item	3700116	et	0	cKUAfXynZ
text-alignjustify	doc_881665289253_item	3700117	et	0	cKUAfXynZ
line-height150	doc_881665289253_item	3700118	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_881665289253_item	3700119	et	0	cKUAfXynZ
font-size120pt	doc_881665289253_item	3700120	et	0	cKUAfXynZ
font-familytimes	doc_881665289253_item	3700121	et	0	cKUAfXynZ
new	doc_881665289253_item	3700122	et	0	cKUAfXynZ
romanserif	doc_881665289253_item	3700123	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_881665289253_item	3700124	et	0	cKUAfXynZ
new	doc_881665289253_item	3700125	et	0	cKUAfXynZ
roman	doc_881665289253_item	3700126	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_881665289253_item	3700127	et	0	cKUAfXynZ
alink	doc_881665289253_item	3700128	et	0	cKUAfXynZ
spanmsohyperlink	doc_881665289253_item	3700129	et	0	cKUAfXynZ
mso-style-unhideno	doc_881665289253_item	3700130	et	0	cKUAfXynZ
colorblue	doc_881665289253_item	3700131	et	0	cKUAfXynZ
text-decorationunderline	doc_881665289253_item	3700132	et	0	cKUAfXynZ
text-underlinesingle	doc_881665289253_item	3700133	et	0	cKUAfXynZ
avisited	doc_881665289253_item	3700134	et	0	cKUAfXynZ
spanmsohyperlinkfollowed	doc_881665289253_item	3700135	et	0	cKUAfXynZ
mso-style-noshowyes	doc_881665289253_item	3700136	et	0	cKUAfXynZ
mso-style-priority99	doc_881665289253_item	3700137	et	0	cKUAfXynZ
colorpurple	doc_881665289253_item	3700138	et	0	cKUAfXynZ
mso-themecolorfollowedhyperlink	doc_881665289253_item	3700139	et	0	cKUAfXynZ
text-decorationunderline	doc_881665289253_item	3700140	et	0	cKUAfXynZ
text-underlinesingle	doc_881665289253_item	3700141	et	0	cKUAfXynZ
spanheading1char	doc_881665289253_item	3700142	et	0	cKUAfXynZ
mso-style-nameheading	doc_881665289253_item	3700143	et	0	cKUAfXynZ
1	doc_881665289253_item	3700144	et	0	cKUAfXynZ
char	doc_881665289253_item	3700145	et	0	cKUAfXynZ
mso-style-unhideno	doc_881665289253_item	3700146	et	0	cKUAfXynZ
mso-style-lockedyes	doc_881665289253_item	3700147	et	0	cKUAfXynZ
mso-style-linkheading	doc_881665289253_item	3700148	et	0	cKUAfXynZ
1	doc_881665289253_item	3700149	et	0	cKUAfXynZ
mso-ansi-font-size140pt	doc_881665289253_item	3700150	et	0	cKUAfXynZ
mso-bidi-font-size120pt	doc_881665289253_item	3700151	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_881665289253_item	3700152	et	0	cKUAfXynZ
spanheading2char	doc_881665289253_item	3700153	et	0	cKUAfXynZ
mso-style-nameheading	doc_881665289253_item	3700154	et	0	cKUAfXynZ
2	doc_881665289253_item	3700155	et	0	cKUAfXynZ
char	doc_881665289253_item	3700156	et	0	cKUAfXynZ
mso-style-unhideno	doc_881665289253_item	3700157	et	0	cKUAfXynZ
mso-style-lockedyes	doc_881665289253_item	3700158	et	0	cKUAfXynZ
mso-style-linkheading	doc_881665289253_item	3700159	et	0	cKUAfXynZ
2	doc_881665289253_item	3700160	et	0	cKUAfXynZ
mso-ansi-font-size160pt	doc_881665289253_item	3700161	et	0	cKUAfXynZ
mso-bidi-font-size120pt	doc_881665289253_item	3700162	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_881665289253_item	3700163	et	0	cKUAfXynZ
spanbodytextchar	doc_881665289253_item	3700164	et	0	cKUAfXynZ
mso-style-namebody	doc_881665289253_item	3700165	et	0	cKUAfXynZ
text	doc_881665289253_item	3700166	et	0	cKUAfXynZ
char	doc_881665289253_item	3700167	et	0	cKUAfXynZ
mso-style-unhideno	doc_881665289253_item	3700168	et	0	cKUAfXynZ
mso-style-lockedyes	doc_881665289253_item	3700169	et	0	cKUAfXynZ
mso-style-linkbody	doc_881665289253_item	3700170	et	0	cKUAfXynZ
text	doc_881665289253_item	3700171	et	0	cKUAfXynZ
mso-ansi-font-size120pt	doc_881665289253_item	3700172	et	0	cKUAfXynZ
mso-bidi-font-size120pt	doc_881665289253_item	3700173	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_881665289253_item	3700174	et	0	cKUAfXynZ
spanfooterchar	doc_881665289253_item	3700175	et	0	cKUAfXynZ
mso-style-namefooter	doc_881665289253_item	3700176	et	0	cKUAfXynZ
char	doc_881665289253_item	3700177	et	0	cKUAfXynZ
mso-style-unhideno	doc_881665289253_item	3700178	et	0	cKUAfXynZ
mso-style-lockedyes	doc_881665289253_item	3700179	et	0	cKUAfXynZ
mso-style-linkfooter	doc_881665289253_item	3700180	et	0	cKUAfXynZ
mso-ansi-font-size120pt	doc_881665289253_item	3700181	et	0	cKUAfXynZ
mso-bidi-font-size120pt	doc_881665289253_item	3700182	et	0	cKUAfXynZ
mso-ansi-languageen-us	doc_881665289253_item	3700183	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_881665289253_item	3700184	et	0	cKUAfXynZ
msochpdefault	doc_881665289253_item	3700185	et	0	cKUAfXynZ
mso-style-typeexport-only	doc_881665289253_item	3700186	et	0	cKUAfXynZ
mso-default-propsyes	doc_881665289253_item	3700187	et	0	cKUAfXynZ
font-size100pt	doc_881665289253_item	3700188	et	0	cKUAfXynZ
mso-ansi-font-size100pt	doc_881665289253_item	3700189	et	0	cKUAfXynZ
mso-bidi-font-size100pt	doc_881665289253_item	3700190	et	0	cKUAfXynZ
page	doc_881665289253_item	3700191	et	0	cKUAfXynZ
section1	doc_881665289253_item	3700192	et	0	cKUAfXynZ
size5953pt	doc_881665289253_item	3700193	et	0	cKUAfXynZ
8419pt	doc_881665289253_item	3700194	et	0	cKUAfXynZ
margin709pt	doc_881665289253_item	3700195	et	0	cKUAfXynZ
20cm	doc_881665289253_item	3700196	et	0	cKUAfXynZ
709pt	doc_881665289253_item	3700197	et	0	cKUAfXynZ
30cm	doc_881665289253_item	3700198	et	0	cKUAfXynZ
mso-header-margin3545pt	doc_881665289253_item	3700199	et	0	cKUAfXynZ
mso-footer-margin3545pt	doc_881665289253_item	3700200	et	0	cKUAfXynZ
mso-paper-source0	doc_881665289253_item	3700201	et	0	cKUAfXynZ
divsection1	doc_881665289253_item	3700202	et	0	cKUAfXynZ
pagesection1	doc_881665289253_item	3700203	et	0	cKUAfXynZ
list	doc_881665289253_item	3700204	et	0	cKUAfXynZ
definitions	doc_881665289253_item	3700205	et	0	cKUAfXynZ
list	doc_881665289253_item	3700206	et	0	cKUAfXynZ
l0	doc_881665289253_item	3700207	et	0	cKUAfXynZ
mso-list-id832332601	doc_881665289253_item	3700208	et	0	cKUAfXynZ
mso-list-typehybrid	doc_881665289253_item	3700209	et	0	cKUAfXynZ
mso-list-template-ids1051436262	doc_881665289253_item	3700210	et	0	cKUAfXynZ
67698703	doc_881665289253_item	3700211	et	0	cKUAfXynZ
67698713	doc_881665289253_item	3700212	et	0	cKUAfXynZ
67698715	doc_881665289253_item	3700213	et	0	cKUAfXynZ
67698703	doc_881665289253_item	3700214	et	0	cKUAfXynZ
67698713	doc_881665289253_item	3700215	et	0	cKUAfXynZ
67698715	doc_881665289253_item	3700216	et	0	cKUAfXynZ
67698703	doc_881665289253_item	3700217	et	0	cKUAfXynZ
67698713	doc_881665289253_item	3700218	et	0	cKUAfXynZ
67698715	doc_881665289253_item	3700219	et	0	cKUAfXynZ
list	doc_881665289253_item	3700220	et	0	cKUAfXynZ
l0level1	doc_881665289253_item	3700221	et	0	cKUAfXynZ
mso-level-tab-stop360pt	doc_881665289253_item	3700222	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_881665289253_item	3700223	et	0	cKUAfXynZ
text-indent180pt	doc_881665289253_item	3700224	et	0	cKUAfXynZ
mso-ansi-font-stylenormal	doc_881665289253_item	3700225	et	0	cKUAfXynZ
ol	doc_881665289253_item	3700226	et	0	cKUAfXynZ
margin-bottom0cm	doc_881665289253_item	3700227	et	0	cKUAfXynZ
ul	doc_881665289253_item	3700228	et	0	cKUAfXynZ
margin-bottom0cm	doc_881665289253_item	3700229	et	0	cKUAfXynZ
gt	doc_881665289253_item	3700230	et	0	cKUAfXynZ
tallinna	doc_881665289253_item	3700231	et	0	cKUAfXynZ
ülikooli	doc_881665289253_item	3700232	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3700233	et	0	cKUAfXynZ
keele	doc_881665289253_item	3700234	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700235	et	0	cKUAfXynZ
kultuuri	doc_881665289253_item	3700236	et	0	cKUAfXynZ
instituut	doc_881665289253_item	3700237	et	0	cKUAfXynZ
mõnedest	doc_881665289253_item	3700238	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3700239	et	0	cKUAfXynZ
keele	doc_881665289253_item	3700240	et	0	cKUAfXynZ
lihtlausete	doc_881665289253_item	3700241	et	0	cKUAfXynZ
tüüpidest	doc_881665289253_item	3700242	et	0	cKUAfXynZ
referaat	doc_881665289253_item	3700243	et	0	cKUAfXynZ
tallinn	doc_881665289253_item	3700244	et	0	cKUAfXynZ
2010	doc_881665289253_item	3700245	et	0	cKUAfXynZ
sisukord	doc_881665289253_item	3700246	et	0	cKUAfXynZ
sissejuhatus	doc_881665289253_item	3700247	et	0	cKUAfXynZ
3	doc_881665289253_item	3700248	et	0	cKUAfXynZ
1	doc_881665289253_item	3700249	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3700250	et	0	cKUAfXynZ
keele	doc_881665289253_item	3700251	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3700252	et	0	cKUAfXynZ
lausemallide	doc_881665289253_item	3700253	et	0	cKUAfXynZ
ehitusest	doc_881665289253_item	3700254	et	0	cKUAfXynZ
4	doc_881665289253_item	3700255	et	0	cKUAfXynZ
11	doc_881665289253_item	3700256	et	0	cKUAfXynZ
lause	doc_881665289253_item	3700257	et	0	cKUAfXynZ
verbikesksus	doc_881665289253_item	3700258	et	0	cKUAfXynZ
4	doc_881665289253_item	3700259	et	0	cKUAfXynZ
12	doc_881665289253_item	3700260	et	0	cKUAfXynZ
verbikeskne	doc_881665289253_item	3700261	et	0	cKUAfXynZ
lihtlause	doc_881665289253_item	3700262	et	0	cKUAfXynZ
5	doc_881665289253_item	3700263	et	0	cKUAfXynZ
13	doc_881665289253_item	3700264	et	0	cKUAfXynZ
laiendatud	doc_881665289253_item	3700265	et	0	cKUAfXynZ
verbikeksete	doc_881665289253_item	3700266	et	0	cKUAfXynZ
lihtlausete	doc_881665289253_item	3700267	et	0	cKUAfXynZ
redutseerimine	doc_881665289253_item	3700268	et	0	cKUAfXynZ
6	doc_881665289253_item	3700269	et	0	cKUAfXynZ
14	doc_881665289253_item	3700270	et	0	cKUAfXynZ
verbikeskne	doc_881665289253_item	3700271	et	0	cKUAfXynZ
lausemall	doc_881665289253_item	3700272	et	0	cKUAfXynZ
7	doc_881665289253_item	3700273	et	0	cKUAfXynZ
2	doc_881665289253_item	3700274	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3700275	et	0	cKUAfXynZ
lausemallide	doc_881665289253_item	3700276	et	0	cKUAfXynZ
koostisosad	doc_881665289253_item	3700277	et	0	cKUAfXynZ
9	doc_881665289253_item	3700278	et	0	cKUAfXynZ
3	doc_881665289253_item	3700279	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3700280	et	0	cKUAfXynZ
laiendite	doc_881665289253_item	3700281	et	0	cKUAfXynZ
vahekord	doc_881665289253_item	3700282	et	0	cKUAfXynZ
verbiga	doc_881665289253_item	3700283	et	0	cKUAfXynZ
13	doc_881665289253_item	3700284	et	0	cKUAfXynZ
kokkuvõte	doc_881665289253_item	3700285	et	0	cKUAfXynZ
14	doc_881665289253_item	3700286	et	0	cKUAfXynZ
kasutatud	doc_881665289253_item	3700287	et	0	cKUAfXynZ
kirjandus	doc_881665289253_item	3700288	et	0	cKUAfXynZ
15	doc_881665289253_item	3700289	et	0	cKUAfXynZ
sissejuhatus	doc_881665289253_item	3700290	et	0	cKUAfXynZ
igas	doc_881665289253_item	3700291	et	0	cKUAfXynZ
loomulikus	doc_881665289253_item	3700292	et	0	cKUAfXynZ
keeles	doc_881665289253_item	3700293	et	0	cKUAfXynZ
on	doc_881665289253_item	3700294	et	0	cKUAfXynZ
tohutu	doc_881665289253_item	3700295	et	0	cKUAfXynZ
suur	doc_881665289253_item	3700296	et	0	cKUAfXynZ
hulka	doc_881665289253_item	3700297	et	0	cKUAfXynZ
lihtlaused	doc_881665289253_item	3700298	et	0	cKUAfXynZ
kuigi	doc_881665289253_item	3700299	et	0	cKUAfXynZ
mitte	doc_881665289253_item	3700300	et	0	cKUAfXynZ
piiramatu	doc_881665289253_item	3700301	et	0	cKUAfXynZ
nende	doc_881665289253_item	3700302	et	0	cKUAfXynZ
lausete	doc_881665289253_item	3700303	et	0	cKUAfXynZ
struktuuris	doc_881665289253_item	3700304	et	0	cKUAfXynZ
on	doc_881665289253_item	3700305	et	0	cKUAfXynZ
olemas	doc_881665289253_item	3700306	et	0	cKUAfXynZ
oma	doc_881665289253_item	3700307	et	0	cKUAfXynZ
printsiibid	doc_881665289253_item	3700308	et	0	cKUAfXynZ
so	doc_881665289253_item	3700309	et	0	cKUAfXynZ
need	doc_881665289253_item	3700310	et	0	cKUAfXynZ
on	doc_881665289253_item	3700311	et	0	cKUAfXynZ
loodud	doc_881665289253_item	3700312	et	0	cKUAfXynZ
konkreetsete	doc_881665289253_item	3700313	et	0	cKUAfXynZ
mallide	doc_881665289253_item	3700314	et	0	cKUAfXynZ
alusel	doc_881665289253_item	3700315	et	0	cKUAfXynZ
töös	doc_881665289253_item	3700316	et	0	cKUAfXynZ
käsitletakse	doc_881665289253_item	3700317	et	0	cKUAfXynZ
lihtlausete	doc_881665289253_item	3700318	et	0	cKUAfXynZ
süntaksi	doc_881665289253_item	3700319	et	0	cKUAfXynZ
probleemid	doc_881665289253_item	3700320	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3700321	et	0	cKUAfXynZ
keeles	doc_881665289253_item	3700322	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700323	et	0	cKUAfXynZ
analüüsitakse	doc_881665289253_item	3700324	et	0	cKUAfXynZ
abstraksed	doc_881665289253_item	3700325	et	0	cKUAfXynZ
lausemallid	doc_881665289253_item	3700326	et	0	cKUAfXynZ
kus	doc_881665289253_item	3700327	et	0	cKUAfXynZ
lause	doc_881665289253_item	3700328	et	0	cKUAfXynZ
struktuuriline	doc_881665289253_item	3700329	et	0	cKUAfXynZ
keskus	doc_881665289253_item	3700330	et	0	cKUAfXynZ
on	doc_881665289253_item	3700331	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3700332	et	0	cKUAfXynZ
finiitvorm	doc_881665289253_item	3700333	et	0	cKUAfXynZ
mida	doc_881665289253_item	3700334	et	0	cKUAfXynZ
määrab	doc_881665289253_item	3700335	et	0	cKUAfXynZ
palju	doc_881665289253_item	3700336	et	0	cKUAfXynZ
olulist	doc_881665289253_item	3700337	et	0	cKUAfXynZ
lihtlause	doc_881665289253_item	3700338	et	0	cKUAfXynZ
ehituses	doc_881665289253_item	3700339	et	0	cKUAfXynZ
niisiis	doc_881665289253_item	3700340	et	0	cKUAfXynZ
h	doc_881665289253_item	3700341	et	0	cKUAfXynZ
rätsep	doc_881665289253_item	3700342	et	0	cKUAfXynZ
toetub	doc_881665289253_item	3700343	et	0	cKUAfXynZ
verbikesksele	doc_881665289253_item	3700344	et	0	cKUAfXynZ
vaatlusviisile	doc_881665289253_item	3700345	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700346	et	0	cKUAfXynZ
püüab	doc_881665289253_item	3700347	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3700348	et	0	cKUAfXynZ
keele	doc_881665289253_item	3700349	et	0	cKUAfXynZ
lihtlausemalle	doc_881665289253_item	3700350	et	0	cKUAfXynZ
seletada	doc_881665289253_item	3700351	et	0	cKUAfXynZ
johtudes	doc_881665289253_item	3700352	et	0	cKUAfXynZ
verbist	doc_881665289253_item	3700353	et	0	cKUAfXynZ
verbid	doc_881665289253_item	3700354	et	0	cKUAfXynZ
oma	doc_881665289253_item	3700355	et	0	cKUAfXynZ
sõltuvate	doc_881665289253_item	3700356	et	0	cKUAfXynZ
mitmekesiste	doc_881665289253_item	3700357	et	0	cKUAfXynZ
laienditega	doc_881665289253_item	3700358	et	0	cKUAfXynZ
esitavad	doc_881665289253_item	3700359	et	0	cKUAfXynZ
keskset	doc_881665289253_item	3700360	et	0	cKUAfXynZ
osa	doc_881665289253_item	3700361	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3700362	et	0	cKUAfXynZ
keele	doc_881665289253_item	3700363	et	0	cKUAfXynZ
lihtlauses	doc_881665289253_item	3700364	et	0	cKUAfXynZ
nad	doc_881665289253_item	3700365	et	0	cKUAfXynZ
määratlevad	doc_881665289253_item	3700366	et	0	cKUAfXynZ
rohkuski	doc_881665289253_item	3700367	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3700368	et	0	cKUAfXynZ
keele	doc_881665289253_item	3700369	et	0	cKUAfXynZ
lihtlausete	doc_881665289253_item	3700370	et	0	cKUAfXynZ
grammatiliseid	doc_881665289253_item	3700371	et	0	cKUAfXynZ
põhistruktuure	doc_881665289253_item	3700372	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3700373	et	0	cKUAfXynZ
keele	doc_881665289253_item	3700374	et	0	cKUAfXynZ
lausete	doc_881665289253_item	3700375	et	0	cKUAfXynZ
struktuuri	doc_881665289253_item	3700376	et	0	cKUAfXynZ
avarus	doc_881665289253_item	3700377	et	0	cKUAfXynZ
on	doc_881665289253_item	3700378	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3700379	et	0	cKUAfXynZ
suurel	doc_881665289253_item	3700380	et	0	cKUAfXynZ
määral	doc_881665289253_item	3700381	et	0	cKUAfXynZ
verbide	doc_881665289253_item	3700382	et	0	cKUAfXynZ
sematikaga	doc_881665289253_item	3700383	et	0	cKUAfXynZ
niisiis	doc_881665289253_item	3700384	et	0	cKUAfXynZ
h	doc_881665289253_item	3700385	et	0	cKUAfXynZ
rätsep	doc_881665289253_item	3700386	et	0	cKUAfXynZ
lihtlausete	doc_881665289253_item	3700387	et	0	cKUAfXynZ
ehituse	doc_881665289253_item	3700388	et	0	cKUAfXynZ
kirjeldamisel	doc_881665289253_item	3700389	et	0	cKUAfXynZ
tegeleb	doc_881665289253_item	3700390	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3700391	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700392	et	0	cKUAfXynZ
temast	doc_881665289253_item	3700393	et	0	cKUAfXynZ
tingitud	doc_881665289253_item	3700394	et	0	cKUAfXynZ
lauseelementide	doc_881665289253_item	3700395	et	0	cKUAfXynZ
vahekorraga	doc_881665289253_item	3700396	et	0	cKUAfXynZ
h	doc_881665289253_item	3700397	et	0	cKUAfXynZ
rätsep	doc_881665289253_item	3700398	et	0	cKUAfXynZ
rõhutab	doc_881665289253_item	3700399	et	0	cKUAfXynZ
seda	doc_881665289253_item	3700400	et	0	cKUAfXynZ
et	doc_881665289253_item	3700401	et	0	cKUAfXynZ
töös	doc_881665289253_item	3700402	et	0	cKUAfXynZ
ei	doc_881665289253_item	3700403	et	0	cKUAfXynZ
ole	doc_881665289253_item	3700404	et	0	cKUAfXynZ
käsitletud	doc_881665289253_item	3700405	et	0	cKUAfXynZ
sagedamini	doc_881665289253_item	3700406	et	0	cKUAfXynZ
esinevaid	doc_881665289253_item	3700407	et	0	cKUAfXynZ
lihtlausevariante	doc_881665289253_item	3700408	et	0	cKUAfXynZ
vaid	doc_881665289253_item	3700409	et	0	cKUAfXynZ
on	doc_881665289253_item	3700410	et	0	cKUAfXynZ
selgitud	doc_881665289253_item	3700411	et	0	cKUAfXynZ
missugused	doc_881665289253_item	3700412	et	0	cKUAfXynZ
mallid	doc_881665289253_item	3700413	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700414	et	0	cKUAfXynZ
nende	doc_881665289253_item	3700415	et	0	cKUAfXynZ
variandid	doc_881665289253_item	3700416	et	0	cKUAfXynZ
teatud	doc_881665289253_item	3700417	et	0	cKUAfXynZ
tingimustel	doc_881665289253_item	3700418	et	0	cKUAfXynZ
on	doc_881665289253_item	3700419	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3700420	et	0	cKUAfXynZ
keeles	doc_881665289253_item	3700421	et	0	cKUAfXynZ
üldse	doc_881665289253_item	3700422	et	0	cKUAfXynZ
mõeldavad	doc_881665289253_item	3700423	et	0	cKUAfXynZ
1	doc_881665289253_item	3700424	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3700425	et	0	cKUAfXynZ
keele	doc_881665289253_item	3700426	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3700427	et	0	cKUAfXynZ
lausemallide	doc_881665289253_item	3700428	et	0	cKUAfXynZ
ehitusest	doc_881665289253_item	3700429	et	0	cKUAfXynZ
paljud	doc_881665289253_item	3700430	et	0	cKUAfXynZ
keeleuurijad	doc_881665289253_item	3700431	et	0	cKUAfXynZ
on	doc_881665289253_item	3700432	et	0	cKUAfXynZ
keskendanud	doc_881665289253_item	3700433	et	0	cKUAfXynZ
enam	doc_881665289253_item	3700434	et	0	cKUAfXynZ
sõnadevaheliste	doc_881665289253_item	3700435	et	0	cKUAfXynZ
sõltumuste	doc_881665289253_item	3700436	et	0	cKUAfXynZ
probleemidele	doc_881665289253_item	3700437	et	0	cKUAfXynZ
lähtudes	doc_881665289253_item	3700438	et	0	cKUAfXynZ
sellest	doc_881665289253_item	3700439	et	0	cKUAfXynZ
eristatakse	doc_881665289253_item	3700440	et	0	cKUAfXynZ
noomenisüntaksi	doc_881665289253_item	3700441	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700442	et	0	cKUAfXynZ
verbisüntaksi	doc_881665289253_item	3700443	et	0	cKUAfXynZ
igal	doc_881665289253_item	3700444	et	0	cKUAfXynZ
autoril	doc_881665289253_item	3700445	et	0	cKUAfXynZ
neid	doc_881665289253_item	3700446	et	0	cKUAfXynZ
termineid	doc_881665289253_item	3700447	et	0	cKUAfXynZ
on	doc_881665289253_item	3700448	et	0	cKUAfXynZ
vaadeldud	doc_881665289253_item	3700449	et	0	cKUAfXynZ
erinevalt	doc_881665289253_item	3700450	et	0	cKUAfXynZ
antud	doc_881665289253_item	3700451	et	0	cKUAfXynZ
töös	doc_881665289253_item	3700452	et	0	cKUAfXynZ
defineeritakse	doc_881665289253_item	3700453	et	0	cKUAfXynZ
verbisüntaksi	doc_881665289253_item	3700454	et	0	cKUAfXynZ
nagu	doc_881665289253_item	3700455	et	0	cKUAfXynZ
süntaksi	doc_881665289253_item	3700456	et	0	cKUAfXynZ
osa	doc_881665289253_item	3700457	et	0	cKUAfXynZ
kuhu	doc_881665289253_item	3700458	et	0	cKUAfXynZ
kuulub	doc_881665289253_item	3700459	et	0	cKUAfXynZ
kõiki	doc_881665289253_item	3700460	et	0	cKUAfXynZ
verbist	doc_881665289253_item	3700461	et	0	cKUAfXynZ
tema	doc_881665289253_item	3700462	et	0	cKUAfXynZ
vormistikust	doc_881665289253_item	3700463	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700464	et	0	cKUAfXynZ
tähendusest	doc_881665289253_item	3700465	et	0	cKUAfXynZ
tingitud	doc_881665289253_item	3700466	et	0	cKUAfXynZ
lauseehituslikke	doc_881665289253_item	3700467	et	0	cKUAfXynZ
seiku	doc_881665289253_item	3700468	et	0	cKUAfXynZ
alates	doc_881665289253_item	3700469	et	0	cKUAfXynZ
verbivormide	doc_881665289253_item	3700470	et	0	cKUAfXynZ
funktsioonidest	doc_881665289253_item	3700471	et	0	cKUAfXynZ
lauses	doc_881665289253_item	3700472	et	0	cKUAfXynZ
kuni	doc_881665289253_item	3700473	et	0	cKUAfXynZ
verbist	doc_881665289253_item	3700474	et	0	cKUAfXynZ
sõltuvate	doc_881665289253_item	3700475	et	0	cKUAfXynZ
laiendite	doc_881665289253_item	3700476	et	0	cKUAfXynZ
vorminormideni	doc_881665289253_item	3700477	et	0	cKUAfXynZ
rätsep	doc_881665289253_item	3700478	et	0	cKUAfXynZ
1978	doc_881665289253_item	3700479	et	0	cKUAfXynZ
9	doc_881665289253_item	3700480	et	0	cKUAfXynZ
noomenisüntaksi	doc_881665289253_item	3700481	et	0	cKUAfXynZ
määratakse	doc_881665289253_item	3700482	et	0	cKUAfXynZ
süntaksi	doc_881665289253_item	3700483	et	0	cKUAfXynZ
osa	doc_881665289253_item	3700484	et	0	cKUAfXynZ
mis	doc_881665289253_item	3700485	et	0	cKUAfXynZ
hõlmab	doc_881665289253_item	3700486	et	0	cKUAfXynZ
vastavalt	doc_881665289253_item	3700487	et	0	cKUAfXynZ
kõiki	doc_881665289253_item	3700488	et	0	cKUAfXynZ
noomenist	doc_881665289253_item	3700489	et	0	cKUAfXynZ
tema	doc_881665289253_item	3700490	et	0	cKUAfXynZ
vormidest	doc_881665289253_item	3700491	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700492	et	0	cKUAfXynZ
tähendusest	doc_881665289253_item	3700493	et	0	cKUAfXynZ
tingitud	doc_881665289253_item	3700494	et	0	cKUAfXynZ
lauseehitusjooni	doc_881665289253_item	3700495	et	0	cKUAfXynZ
rätsep	doc_881665289253_item	3700496	et	0	cKUAfXynZ
1978	doc_881665289253_item	3700497	et	0	cKUAfXynZ
lk	doc_881665289253_item	3700498	et	0	cKUAfXynZ
9	doc_881665289253_item	3700499	et	0	cKUAfXynZ
11	doc_881665289253_item	3700500	et	0	cKUAfXynZ
lause	doc_881665289253_item	3700501	et	0	cKUAfXynZ
verbikesksus	doc_881665289253_item	3700502	et	0	cKUAfXynZ
autori	doc_881665289253_item	3700503	et	0	cKUAfXynZ
arvates	doc_881665289253_item	3700504	et	0	cKUAfXynZ
lause	doc_881665289253_item	3700505	et	0	cKUAfXynZ
keskmes	doc_881665289253_item	3700506	et	0	cKUAfXynZ
on	doc_881665289253_item	3700507	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3700508	et	0	cKUAfXynZ
finiitvorm	doc_881665289253_item	3700509	et	0	cKUAfXynZ
mis	doc_881665289253_item	3700510	et	0	cKUAfXynZ
määrab	doc_881665289253_item	3700511	et	0	cKUAfXynZ
palju	doc_881665289253_item	3700512	et	0	cKUAfXynZ
olulist	doc_881665289253_item	3700513	et	0	cKUAfXynZ
lihtlause	doc_881665289253_item	3700514	et	0	cKUAfXynZ
struktuuris	doc_881665289253_item	3700515	et	0	cKUAfXynZ
süntaksiuurijad	doc_881665289253_item	3700516	et	0	cKUAfXynZ
palju	doc_881665289253_item	3700517	et	0	cKUAfXynZ
vaidlesid	doc_881665289253_item	3700518	et	0	cKUAfXynZ
selle	doc_881665289253_item	3700519	et	0	cKUAfXynZ
üle	doc_881665289253_item	3700520	et	0	cKUAfXynZ
missugused	doc_881665289253_item	3700521	et	0	cKUAfXynZ
suhted	doc_881665289253_item	3700522	et	0	cKUAfXynZ
on	doc_881665289253_item	3700523	et	0	cKUAfXynZ
öeldise	doc_881665289253_item	3700524	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700525	et	0	cKUAfXynZ
aluse	doc_881665289253_item	3700526	et	0	cKUAfXynZ
vahel	doc_881665289253_item	3700527	et	0	cKUAfXynZ
kas	doc_881665289253_item	3700528	et	0	cKUAfXynZ
alus	doc_881665289253_item	3700529	et	0	cKUAfXynZ
domineerib	doc_881665289253_item	3700530	et	0	cKUAfXynZ
öeldise	doc_881665289253_item	3700531	et	0	cKUAfXynZ
üle	doc_881665289253_item	3700532	et	0	cKUAfXynZ
või	doc_881665289253_item	3700533	et	0	cKUAfXynZ
öeldis	doc_881665289253_item	3700534	et	0	cKUAfXynZ
aluse	doc_881665289253_item	3700535	et	0	cKUAfXynZ
üle	doc_881665289253_item	3700536	et	0	cKUAfXynZ
või	doc_881665289253_item	3700537	et	0	cKUAfXynZ
pole	doc_881665289253_item	3700538	et	0	cKUAfXynZ
nende	doc_881665289253_item	3700539	et	0	cKUAfXynZ
vahel	doc_881665289253_item	3700540	et	0	cKUAfXynZ
üldse	doc_881665289253_item	3700541	et	0	cKUAfXynZ
dominatsioonivahekorda	doc_881665289253_item	3700542	et	0	cKUAfXynZ
rätsep	doc_881665289253_item	3700543	et	0	cKUAfXynZ
1978	doc_881665289253_item	3700544	et	0	cKUAfXynZ
lk	doc_881665289253_item	3700545	et	0	cKUAfXynZ
9	doc_881665289253_item	3700546	et	0	cKUAfXynZ
üldiselt	doc_881665289253_item	3700547	et	0	cKUAfXynZ
aluse-öeldise	doc_881665289253_item	3700548	et	0	cKUAfXynZ
vahekorda	doc_881665289253_item	3700549	et	0	cKUAfXynZ
käsitlevate	doc_881665289253_item	3700550	et	0	cKUAfXynZ
teooriad	doc_881665289253_item	3700551	et	0	cKUAfXynZ
võib	doc_881665289253_item	3700552	et	0	cKUAfXynZ
eristada	doc_881665289253_item	3700553	et	0	cKUAfXynZ
mitme	doc_881665289253_item	3700554	et	0	cKUAfXynZ
koolkoondade	doc_881665289253_item	3700555	et	0	cKUAfXynZ
järgi	doc_881665289253_item	3700556	et	0	cKUAfXynZ
lähtudes	doc_881665289253_item	3700557	et	0	cKUAfXynZ
sellest	doc_881665289253_item	3700558	et	0	cKUAfXynZ
on	doc_881665289253_item	3700559	et	0	cKUAfXynZ
tekkitud	doc_881665289253_item	3700560	et	0	cKUAfXynZ
erinevaid	doc_881665289253_item	3700561	et	0	cKUAfXynZ
teooriad	doc_881665289253_item	3700562	et	0	cKUAfXynZ
mõned	doc_881665289253_item	3700563	et	0	cKUAfXynZ
teadlased	doc_881665289253_item	3700564	et	0	cKUAfXynZ
on	doc_881665289253_item	3700565	et	0	cKUAfXynZ
baseerunud	doc_881665289253_item	3700566	et	0	cKUAfXynZ
lause	doc_881665289253_item	3700567	et	0	cKUAfXynZ
ehituse	doc_881665289253_item	3700568	et	0	cKUAfXynZ
binaarsuse	doc_881665289253_item	3700569	et	0	cKUAfXynZ
teesil	doc_881665289253_item	3700570	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700571	et	0	cKUAfXynZ
see	doc_881665289253_item	3700572	et	0	cKUAfXynZ
omakorda	doc_881665289253_item	3700573	et	0	cKUAfXynZ
põhineb	doc_881665289253_item	3700574	et	0	cKUAfXynZ
otsustuse	doc_881665289253_item	3700575	et	0	cKUAfXynZ
subjekti-predikaadi	doc_881665289253_item	3700576	et	0	cKUAfXynZ
struktuuril	doc_881665289253_item	3700577	et	0	cKUAfXynZ
loogikas	doc_881665289253_item	3700578	et	0	cKUAfXynZ
h	doc_881665289253_item	3700579	et	0	cKUAfXynZ
paul	doc_881665289253_item	3700580	et	0	cKUAfXynZ
i	doc_881665289253_item	3700581	et	0	cKUAfXynZ
meštšaninov	doc_881665289253_item	3700582	et	0	cKUAfXynZ
t	doc_881665289253_item	3700583	et	0	cKUAfXynZ
lomtev	doc_881665289253_item	3700584	et	0	cKUAfXynZ
n	doc_881665289253_item	3700585	et	0	cKUAfXynZ
chomsky	doc_881665289253_item	3700586	et	0	cKUAfXynZ
on	doc_881665289253_item	3700587	et	0	cKUAfXynZ
toetunud	doc_881665289253_item	3700588	et	0	cKUAfXynZ
sellele	doc_881665289253_item	3700589	et	0	cKUAfXynZ
et	doc_881665289253_item	3700590	et	0	cKUAfXynZ
lauseliikmete	doc_881665289253_item	3700591	et	0	cKUAfXynZ
nimelt	doc_881665289253_item	3700592	et	0	cKUAfXynZ
aluse-öeldise	doc_881665289253_item	3700593	et	0	cKUAfXynZ
vahel	doc_881665289253_item	3700594	et	0	cKUAfXynZ
on	doc_881665289253_item	3700595	et	0	cKUAfXynZ
olemas	doc_881665289253_item	3700596	et	0	cKUAfXynZ
vastastikune	doc_881665289253_item	3700597	et	0	cKUAfXynZ
rinnastusvahekord	doc_881665289253_item	3700598	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3700599	et	0	cKUAfXynZ
lk	doc_881665289253_item	3700600	et	0	cKUAfXynZ
9-10	doc_881665289253_item	3700601	et	0	cKUAfXynZ
a	doc_881665289253_item	3700602	et	0	cKUAfXynZ
šahmatov	doc_881665289253_item	3700603	et	0	cKUAfXynZ
a	doc_881665289253_item	3700604	et	0	cKUAfXynZ
peškovski	doc_881665289253_item	3700605	et	0	cKUAfXynZ
jt	doc_881665289253_item	3700606	et	0	cKUAfXynZ
on	doc_881665289253_item	3700607	et	0	cKUAfXynZ
väidanud	doc_881665289253_item	3700608	et	0	cKUAfXynZ
et	doc_881665289253_item	3700609	et	0	cKUAfXynZ
predikaat	doc_881665289253_item	3700610	et	0	cKUAfXynZ
sõltub	doc_881665289253_item	3700611	et	0	cKUAfXynZ
subjektist	doc_881665289253_item	3700612	et	0	cKUAfXynZ
ning	doc_881665289253_item	3700613	et	0	cKUAfXynZ
öeldis	doc_881665289253_item	3700614	et	0	cKUAfXynZ
üheldab	doc_881665289253_item	3700615	et	0	cKUAfXynZ
alusega	doc_881665289253_item	3700616	et	0	cKUAfXynZ
pöördes	doc_881665289253_item	3700617	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700618	et	0	cKUAfXynZ
arvus	doc_881665289253_item	3700619	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3700620	et	0	cKUAfXynZ
lk	doc_881665289253_item	3700621	et	0	cKUAfXynZ
10	doc_881665289253_item	3700622	et	0	cKUAfXynZ
teiste	doc_881665289253_item	3700623	et	0	cKUAfXynZ
süntaksiuurijate	doc_881665289253_item	3700624	et	0	cKUAfXynZ
järgi	doc_881665289253_item	3700625	et	0	cKUAfXynZ
siia	doc_881665289253_item	3700626	et	0	cKUAfXynZ
hulka	doc_881665289253_item	3700627	et	0	cKUAfXynZ
kuulub	doc_881665289253_item	3700628	et	0	cKUAfXynZ
ka	doc_881665289253_item	3700629	et	0	cKUAfXynZ
autor	doc_881665289253_item	3700630	et	0	cKUAfXynZ
ise	doc_881665289253_item	3700631	et	0	cKUAfXynZ
paljudes	doc_881665289253_item	3700632	et	0	cKUAfXynZ
keeltes	doc_881665289253_item	3700633	et	0	cKUAfXynZ
lause	doc_881665289253_item	3700634	et	0	cKUAfXynZ
põhielemendiks	doc_881665289253_item	3700635	et	0	cKUAfXynZ
on	doc_881665289253_item	3700636	et	0	cKUAfXynZ
tavaliselt	doc_881665289253_item	3700637	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3700638	et	0	cKUAfXynZ
finiitvorm	doc_881665289253_item	3700639	et	0	cKUAfXynZ
l	doc_881665289253_item	3700640	et	0	cKUAfXynZ
tesnière	doc_881665289253_item	3700641	et	0	cKUAfXynZ
on	doc_881665289253_item	3700642	et	0	cKUAfXynZ
toetunud	doc_881665289253_item	3700643	et	0	cKUAfXynZ
o	doc_881665289253_item	3700644	et	0	cKUAfXynZ
jespersoni	doc_881665289253_item	3700645	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700646	et	0	cKUAfXynZ
th	doc_881665289253_item	3700647	et	0	cKUAfXynZ
kalepky	doc_881665289253_item	3700648	et	0	cKUAfXynZ
peale	doc_881665289253_item	3700649	et	0	cKUAfXynZ
ning	doc_881665289253_item	3700650	et	0	cKUAfXynZ
käsitlenud	doc_881665289253_item	3700651	et	0	cKUAfXynZ
laused	doc_881665289253_item	3700652	et	0	cKUAfXynZ
hierarhiliselt	doc_881665289253_item	3700653	et	0	cKUAfXynZ
verb	doc_881665289253_item	3700654	et	0	cKUAfXynZ
on	doc_881665289253_item	3700655	et	0	cKUAfXynZ
lauses	doc_881665289253_item	3700656	et	0	cKUAfXynZ
keskne	doc_881665289253_item	3700657	et	0	cKUAfXynZ
j	doc_881665289253_item	3700658	et	0	cKUAfXynZ
erben	doc_881665289253_item	3700659	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700660	et	0	cKUAfXynZ
h	doc_881665289253_item	3700661	et	0	cKUAfXynZ
glinz	doc_881665289253_item	3700662	et	0	cKUAfXynZ
vaadeldasid	doc_881665289253_item	3700663	et	0	cKUAfXynZ
saksa	doc_881665289253_item	3700664	et	0	cKUAfXynZ
keele	doc_881665289253_item	3700665	et	0	cKUAfXynZ
lauset	doc_881665289253_item	3700666	et	0	cKUAfXynZ
samalt	doc_881665289253_item	3700667	et	0	cKUAfXynZ
seisukohalt	doc_881665289253_item	3700668	et	0	cKUAfXynZ
ning	doc_881665289253_item	3700669	et	0	cKUAfXynZ
defineerisid	doc_881665289253_item	3700670	et	0	cKUAfXynZ
seda	doc_881665289253_item	3700671	et	0	cKUAfXynZ
kui	doc_881665289253_item	3700672	et	0	cKUAfXynZ
verbaallauset	doc_881665289253_item	3700673	et	0	cKUAfXynZ
h	doc_881665289253_item	3700674	et	0	cKUAfXynZ
rätsepi	doc_881665289253_item	3700675	et	0	cKUAfXynZ
arvates	doc_881665289253_item	3700676	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3700677	et	0	cKUAfXynZ
keele	doc_881665289253_item	3700678	et	0	cKUAfXynZ
grammatikas	doc_881665289253_item	3700679	et	0	cKUAfXynZ
lihtlause	doc_881665289253_item	3700680	et	0	cKUAfXynZ
grammatilise	doc_881665289253_item	3700681	et	0	cKUAfXynZ
struktuuri	doc_881665289253_item	3700682	et	0	cKUAfXynZ
seletamiseks	doc_881665289253_item	3700683	et	0	cKUAfXynZ
on	doc_881665289253_item	3700684	et	0	cKUAfXynZ
mõistlikum	doc_881665289253_item	3700685	et	0	cKUAfXynZ
analüüsida	doc_881665289253_item	3700686	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3700687	et	0	cKUAfXynZ
finiitvormi	doc_881665289253_item	3700688	et	0	cKUAfXynZ
sest	doc_881665289253_item	3700689	et	0	cKUAfXynZ
see	doc_881665289253_item	3700690	et	0	cKUAfXynZ
on	doc_881665289253_item	3700691	et	0	cKUAfXynZ
lause	doc_881665289253_item	3700692	et	0	cKUAfXynZ
tuum	doc_881665289253_item	3700693	et	0	cKUAfXynZ
millest	doc_881665289253_item	3700694	et	0	cKUAfXynZ
sõltuvad	doc_881665289253_item	3700695	et	0	cKUAfXynZ
lause	doc_881665289253_item	3700696	et	0	cKUAfXynZ
teised	doc_881665289253_item	3700697	et	0	cKUAfXynZ
struktuurilised	doc_881665289253_item	3700698	et	0	cKUAfXynZ
elemendid	doc_881665289253_item	3700699	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700700	et	0	cKUAfXynZ
nende	doc_881665289253_item	3700701	et	0	cKUAfXynZ
morfoloogilised	doc_881665289253_item	3700702	et	0	cKUAfXynZ
vormid	doc_881665289253_item	3700703	et	0	cKUAfXynZ
analüüsides	doc_881665289253_item	3700704	et	0	cKUAfXynZ
lihtlause	doc_881665289253_item	3700705	et	0	cKUAfXynZ
verbe	doc_881665289253_item	3700706	et	0	cKUAfXynZ
autor	doc_881665289253_item	3700707	et	0	cKUAfXynZ
teeb	doc_881665289253_item	3700708	et	0	cKUAfXynZ
järelduse	doc_881665289253_item	3700709	et	0	cKUAfXynZ
et	doc_881665289253_item	3700710	et	0	cKUAfXynZ
verbist	doc_881665289253_item	3700711	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700712	et	0	cKUAfXynZ
selle	doc_881665289253_item	3700713	et	0	cKUAfXynZ
tähendusest	doc_881665289253_item	3700714	et	0	cKUAfXynZ
sõltuvad	doc_881665289253_item	3700715	et	0	cKUAfXynZ
osasubjekti	doc_881665289253_item	3700716	et	0	cKUAfXynZ
kasutamine	doc_881665289253_item	3700717	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700718	et	0	cKUAfXynZ
subjekti	doc_881665289253_item	3700719	et	0	cKUAfXynZ
puudumine	doc_881665289253_item	3700720	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3700721	et	0	cKUAfXynZ
lk	doc_881665289253_item	3700722	et	0	cKUAfXynZ
12	doc_881665289253_item	3700723	et	0	cKUAfXynZ
autori	doc_881665289253_item	3700724	et	0	cKUAfXynZ
huvitab	doc_881665289253_item	3700725	et	0	cKUAfXynZ
lihtlausete	doc_881665289253_item	3700726	et	0	cKUAfXynZ
vormiline	doc_881665289253_item	3700727	et	0	cKUAfXynZ
struktuur	doc_881665289253_item	3700728	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3700729	et	0	cKUAfXynZ
keeles	doc_881665289253_item	3700730	et	0	cKUAfXynZ
ning	doc_881665289253_item	3700731	et	0	cKUAfXynZ
selle	doc_881665289253_item	3700732	et	0	cKUAfXynZ
struktuuri	doc_881665289253_item	3700733	et	0	cKUAfXynZ
elementide	doc_881665289253_item	3700734	et	0	cKUAfXynZ
põhilisemad	doc_881665289253_item	3700735	et	0	cKUAfXynZ
jooned	doc_881665289253_item	3700736	et	0	cKUAfXynZ
ta	doc_881665289253_item	3700737	et	0	cKUAfXynZ
toetub	doc_881665289253_item	3700738	et	0	cKUAfXynZ
verbikesksuse	doc_881665289253_item	3700739	et	0	cKUAfXynZ
põhimõtele	doc_881665289253_item	3700740	et	0	cKUAfXynZ
piiratleb	doc_881665289253_item	3700741	et	0	cKUAfXynZ
vaatluslause	doc_881665289253_item	3700742	et	0	cKUAfXynZ
materjali	doc_881665289253_item	3700743	et	0	cKUAfXynZ
osa	doc_881665289253_item	3700744	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700745	et	0	cKUAfXynZ
võtab	doc_881665289253_item	3700746	et	0	cKUAfXynZ
arvesse	doc_881665289253_item	3700747	et	0	cKUAfXynZ
ainult	doc_881665289253_item	3700748	et	0	cKUAfXynZ
need	doc_881665289253_item	3700749	et	0	cKUAfXynZ
lihlaused	doc_881665289253_item	3700750	et	0	cKUAfXynZ
kus	doc_881665289253_item	3700751	et	0	cKUAfXynZ
on	doc_881665289253_item	3700752	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3700753	et	0	cKUAfXynZ
finiitvorm	doc_881665289253_item	3700754	et	0	cKUAfXynZ
nimelt	doc_881665289253_item	3700755	et	0	cKUAfXynZ
verbaallaused	doc_881665289253_item	3700756	et	0	cKUAfXynZ
verbita	doc_881665289253_item	3700757	et	0	cKUAfXynZ
laused	doc_881665289253_item	3700758	et	0	cKUAfXynZ
ta	doc_881665289253_item	3700759	et	0	cKUAfXynZ
jätab	doc_881665289253_item	3700760	et	0	cKUAfXynZ
välja	doc_881665289253_item	3700761	et	0	cKUAfXynZ
lihtlauseliikide	doc_881665289253_item	3700762	et	0	cKUAfXynZ
moodustamise	doc_881665289253_item	3700763	et	0	cKUAfXynZ
seletamise	doc_881665289253_item	3700764	et	0	cKUAfXynZ
aluseks	doc_881665289253_item	3700765	et	0	cKUAfXynZ
on	doc_881665289253_item	3700766	et	0	cKUAfXynZ
jutustavate	doc_881665289253_item	3700767	et	0	cKUAfXynZ
verbaalsete	doc_881665289253_item	3700768	et	0	cKUAfXynZ
lihtlausete	doc_881665289253_item	3700769	et	0	cKUAfXynZ
põhimallid	doc_881665289253_item	3700770	et	0	cKUAfXynZ
12	doc_881665289253_item	3700771	et	0	cKUAfXynZ
verbikeskne	doc_881665289253_item	3700772	et	0	cKUAfXynZ
lihtlause	doc_881665289253_item	3700773	et	0	cKUAfXynZ
töö	doc_881665289253_item	3700774	et	0	cKUAfXynZ
kekspunktis	doc_881665289253_item	3700775	et	0	cKUAfXynZ
on	doc_881665289253_item	3700776	et	0	cKUAfXynZ
lihtlause	doc_881665289253_item	3700777	et	0	cKUAfXynZ
põhiverb	doc_881665289253_item	3700778	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700779	et	0	cKUAfXynZ
komponendid	doc_881665289253_item	3700780	et	0	cKUAfXynZ
mille	doc_881665289253_item	3700781	et	0	cKUAfXynZ
olemine	doc_881665289253_item	3700782	et	0	cKUAfXynZ
või	doc_881665289253_item	3700783	et	0	cKUAfXynZ
vorm	doc_881665289253_item	3700784	et	0	cKUAfXynZ
määrab	doc_881665289253_item	3700785	et	0	cKUAfXynZ
selles	doc_881665289253_item	3700786	et	0	cKUAfXynZ
lauses	doc_881665289253_item	3700787	et	0	cKUAfXynZ
keskset	doc_881665289253_item	3700788	et	0	cKUAfXynZ
osa	doc_881665289253_item	3700789	et	0	cKUAfXynZ
etendava	doc_881665289253_item	3700790	et	0	cKUAfXynZ
finiitse	doc_881665289253_item	3700791	et	0	cKUAfXynZ
verbivormi	doc_881665289253_item	3700792	et	0	cKUAfXynZ
autor	doc_881665289253_item	3700793	et	0	cKUAfXynZ
arvab	doc_881665289253_item	3700794	et	0	cKUAfXynZ
et	doc_881665289253_item	3700795	et	0	cKUAfXynZ
sellest	doc_881665289253_item	3700796	et	0	cKUAfXynZ
põhiverbist	doc_881665289253_item	3700797	et	0	cKUAfXynZ
oleneb	doc_881665289253_item	3700798	et	0	cKUAfXynZ
kogu	doc_881665289253_item	3700799	et	0	cKUAfXynZ
rida	doc_881665289253_item	3700800	et	0	cKUAfXynZ
lihtlause	doc_881665289253_item	3700801	et	0	cKUAfXynZ
ehituse	doc_881665289253_item	3700802	et	0	cKUAfXynZ
tähtsaid	doc_881665289253_item	3700803	et	0	cKUAfXynZ
jooni	doc_881665289253_item	3700804	et	0	cKUAfXynZ
sellest	doc_881665289253_item	3700805	et	0	cKUAfXynZ
johtub	doc_881665289253_item	3700806	et	0	cKUAfXynZ
ka	doc_881665289253_item	3700807	et	0	cKUAfXynZ
verbikeskse	doc_881665289253_item	3700808	et	0	cKUAfXynZ
lihtlause	doc_881665289253_item	3700809	et	0	cKUAfXynZ
mõiste	doc_881665289253_item	3700810	et	0	cKUAfXynZ
verbikeskset	doc_881665289253_item	3700811	et	0	cKUAfXynZ
lihtlauset	doc_881665289253_item	3700812	et	0	cKUAfXynZ
defineeritakse	doc_881665289253_item	3700813	et	0	cKUAfXynZ
nagu	doc_881665289253_item	3700814	et	0	cKUAfXynZ
lihtlauset	doc_881665289253_item	3700815	et	0	cKUAfXynZ
kus	doc_881665289253_item	3700816	et	0	cKUAfXynZ
on	doc_881665289253_item	3700817	et	0	cKUAfXynZ
olemas	doc_881665289253_item	3700818	et	0	cKUAfXynZ
ainult	doc_881665289253_item	3700819	et	0	cKUAfXynZ
need	doc_881665289253_item	3700820	et	0	cKUAfXynZ
elemendid	doc_881665289253_item	3700821	et	0	cKUAfXynZ
sõnad	doc_881665289253_item	3700822	et	0	cKUAfXynZ
sõnade	doc_881665289253_item	3700823	et	0	cKUAfXynZ
rühmad	doc_881665289253_item	3700824	et	0	cKUAfXynZ
mille	doc_881665289253_item	3700825	et	0	cKUAfXynZ
olemasolu	doc_881665289253_item	3700826	et	0	cKUAfXynZ
või	doc_881665289253_item	3700827	et	0	cKUAfXynZ
vorm	doc_881665289253_item	3700828	et	0	cKUAfXynZ
on	doc_881665289253_item	3700829	et	0	cKUAfXynZ
verbist	doc_881665289253_item	3700830	et	0	cKUAfXynZ
tingitud	doc_881665289253_item	3700831	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3700832	et	0	cKUAfXynZ
lk	doc_881665289253_item	3700833	et	0	cKUAfXynZ
13	doc_881665289253_item	3700834	et	0	cKUAfXynZ
vastutulija	doc_881665289253_item	3700835	et	0	cKUAfXynZ
näis	doc_881665289253_item	3700836	et	0	cKUAfXynZ
mulle	doc_881665289253_item	3700837	et	0	cKUAfXynZ
tuttav	doc_881665289253_item	3700838	et	0	cKUAfXynZ
on	doc_881665289253_item	3700839	et	0	cKUAfXynZ
olemas	doc_881665289253_item	3700840	et	0	cKUAfXynZ
lihtlause	doc_881665289253_item	3700841	et	0	cKUAfXynZ
teine	doc_881665289253_item	3700842	et	0	cKUAfXynZ
tüüp	doc_881665289253_item	3700843	et	0	cKUAfXynZ
mis	doc_881665289253_item	3700844	et	0	cKUAfXynZ
nimetatakse	doc_881665289253_item	3700845	et	0	cKUAfXynZ
laiendatud	doc_881665289253_item	3700846	et	0	cKUAfXynZ
verbikeskseteks	doc_881665289253_item	3700847	et	0	cKUAfXynZ
lihtlauseteks	doc_881665289253_item	3700848	et	0	cKUAfXynZ
selle	doc_881665289253_item	3700849	et	0	cKUAfXynZ
all	doc_881665289253_item	3700850	et	0	cKUAfXynZ
mõistetakse	doc_881665289253_item	3700851	et	0	cKUAfXynZ
neid	doc_881665289253_item	3700852	et	0	cKUAfXynZ
lihtlauseid	doc_881665289253_item	3700853	et	0	cKUAfXynZ
kus	doc_881665289253_item	3700854	et	0	cKUAfXynZ
peale	doc_881665289253_item	3700855	et	0	cKUAfXynZ
verbist	doc_881665289253_item	3700856	et	0	cKUAfXynZ
tingitud	doc_881665289253_item	3700857	et	0	cKUAfXynZ
elementide	doc_881665289253_item	3700858	et	0	cKUAfXynZ
on	doc_881665289253_item	3700859	et	0	cKUAfXynZ
ka	doc_881665289253_item	3700860	et	0	cKUAfXynZ
muid	doc_881665289253_item	3700861	et	0	cKUAfXynZ
kogu	doc_881665289253_item	3700862	et	0	cKUAfXynZ
lausest	doc_881665289253_item	3700863	et	0	cKUAfXynZ
lause	doc_881665289253_item	3700864	et	0	cKUAfXynZ
sisust	doc_881665289253_item	3700865	et	0	cKUAfXynZ
või	doc_881665289253_item	3700866	et	0	cKUAfXynZ
mõnest	doc_881665289253_item	3700867	et	0	cKUAfXynZ
verbist	doc_881665289253_item	3700868	et	0	cKUAfXynZ
tingitud	doc_881665289253_item	3700869	et	0	cKUAfXynZ
elemendist	doc_881665289253_item	3700870	et	0	cKUAfXynZ
omakorda	doc_881665289253_item	3700871	et	0	cKUAfXynZ
tingitud	doc_881665289253_item	3700872	et	0	cKUAfXynZ
elemente	doc_881665289253_item	3700873	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3700874	et	0	cKUAfXynZ
lk	doc_881665289253_item	3700875	et	0	cKUAfXynZ
13	doc_881665289253_item	3700876	et	0	cKUAfXynZ
see	doc_881665289253_item	3700877	et	0	cKUAfXynZ
vastutulija	doc_881665289253_item	3700878	et	0	cKUAfXynZ
näis	doc_881665289253_item	3700879	et	0	cKUAfXynZ
mulle	doc_881665289253_item	3700880	et	0	cKUAfXynZ
natuke	doc_881665289253_item	3700881	et	0	cKUAfXynZ
tuttav	doc_881665289253_item	3700882	et	0	cKUAfXynZ
13	doc_881665289253_item	3700883	et	0	cKUAfXynZ
laiendatud	doc_881665289253_item	3700884	et	0	cKUAfXynZ
verbikeksete	doc_881665289253_item	3700885	et	0	cKUAfXynZ
lihtlausete	doc_881665289253_item	3700886	et	0	cKUAfXynZ
redutseerimine	doc_881665289253_item	3700887	et	0	cKUAfXynZ
antud	doc_881665289253_item	3700888	et	0	cKUAfXynZ
töös	doc_881665289253_item	3700889	et	0	cKUAfXynZ
autori	doc_881665289253_item	3700890	et	0	cKUAfXynZ
huvitab	doc_881665289253_item	3700891	et	0	cKUAfXynZ
verbikesksed	doc_881665289253_item	3700892	et	0	cKUAfXynZ
lihtlaused	doc_881665289253_item	3700893	et	0	cKUAfXynZ
laiendatud	doc_881665289253_item	3700894	et	0	cKUAfXynZ
verbikesksed	doc_881665289253_item	3700895	et	0	cKUAfXynZ
laused	doc_881665289253_item	3700896	et	0	cKUAfXynZ
on	doc_881665289253_item	3700897	et	0	cKUAfXynZ
jäetud	doc_881665289253_item	3700898	et	0	cKUAfXynZ
analüüsist	doc_881665289253_item	3700899	et	0	cKUAfXynZ
kõrvale	doc_881665289253_item	3700900	et	0	cKUAfXynZ
kuna	doc_881665289253_item	3700901	et	0	cKUAfXynZ
nende	doc_881665289253_item	3700902	et	0	cKUAfXynZ
moodustamise	doc_881665289253_item	3700903	et	0	cKUAfXynZ
reeglid	doc_881665289253_item	3700904	et	0	cKUAfXynZ
on	doc_881665289253_item	3700905	et	0	cKUAfXynZ
tuginenud	doc_881665289253_item	3700906	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3700907	et	0	cKUAfXynZ
lihtlausete	doc_881665289253_item	3700908	et	0	cKUAfXynZ
moodustamise	doc_881665289253_item	3700909	et	0	cKUAfXynZ
reeglitele	doc_881665289253_item	3700910	et	0	cKUAfXynZ
analüüsimeetodiks	doc_881665289253_item	3700911	et	0	cKUAfXynZ
on	doc_881665289253_item	3700912	et	0	cKUAfXynZ
redutseerimine	doc_881665289253_item	3700913	et	0	cKUAfXynZ
ehk	doc_881665289253_item	3700914	et	0	cKUAfXynZ
taandamine	doc_881665289253_item	3700915	et	0	cKUAfXynZ
mõningate	doc_881665289253_item	3700916	et	0	cKUAfXynZ
süntaksiprobleemide	doc_881665289253_item	3700917	et	0	cKUAfXynZ
vaatlemisel	doc_881665289253_item	3700918	et	0	cKUAfXynZ
on	doc_881665289253_item	3700919	et	0	cKUAfXynZ
mõistlikum	doc_881665289253_item	3700920	et	0	cKUAfXynZ
keskenduda	doc_881665289253_item	3700921	et	0	cKUAfXynZ
just	doc_881665289253_item	3700922	et	0	cKUAfXynZ
määratletud	doc_881665289253_item	3700923	et	0	cKUAfXynZ
üksusele	doc_881665289253_item	3700924	et	0	cKUAfXynZ
üksuste	doc_881665289253_item	3700925	et	0	cKUAfXynZ
rühmale	doc_881665289253_item	3700926	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700927	et	0	cKUAfXynZ
sellele	doc_881665289253_item	3700928	et	0	cKUAfXynZ
informatsioonile	doc_881665289253_item	3700929	et	0	cKUAfXynZ
mida	doc_881665289253_item	3700930	et	0	cKUAfXynZ
annab	doc_881665289253_item	3700931	et	0	cKUAfXynZ
tema	doc_881665289253_item	3700932	et	0	cKUAfXynZ
kohta	doc_881665289253_item	3700933	et	0	cKUAfXynZ
ring	doc_881665289253_item	3700934	et	0	cKUAfXynZ
selles	doc_881665289253_item	3700935	et	0	cKUAfXynZ
suhtes	doc_881665289253_item	3700936	et	0	cKUAfXynZ
on	doc_881665289253_item	3700937	et	0	cKUAfXynZ
vaja	doc_881665289253_item	3700938	et	0	cKUAfXynZ
materjalist	doc_881665289253_item	3700939	et	0	cKUAfXynZ
välja	doc_881665289253_item	3700940	et	0	cKUAfXynZ
jätta	doc_881665289253_item	3700941	et	0	cKUAfXynZ
mittevastavat	doc_881665289253_item	3700942	et	0	cKUAfXynZ
informatsiooni	doc_881665289253_item	3700943	et	0	cKUAfXynZ
nimelt	doc_881665289253_item	3700944	et	0	cKUAfXynZ
elemente	doc_881665289253_item	3700945	et	0	cKUAfXynZ
mis	doc_881665289253_item	3700946	et	0	cKUAfXynZ
ei	doc_881665289253_item	3700947	et	0	cKUAfXynZ
olene	doc_881665289253_item	3700948	et	0	cKUAfXynZ
määratletud	doc_881665289253_item	3700949	et	0	cKUAfXynZ
tingimusest	doc_881665289253_item	3700950	et	0	cKUAfXynZ
selleks	doc_881665289253_item	3700951	et	0	cKUAfXynZ
et	doc_881665289253_item	3700952	et	0	cKUAfXynZ
saada	doc_881665289253_item	3700953	et	0	cKUAfXynZ
orienteeritud	doc_881665289253_item	3700954	et	0	cKUAfXynZ
fraasi	doc_881665289253_item	3700955	et	0	cKUAfXynZ
niimoodi	doc_881665289253_item	3700956	et	0	cKUAfXynZ
autor	doc_881665289253_item	3700957	et	0	cKUAfXynZ
on	doc_881665289253_item	3700958	et	0	cKUAfXynZ
interpreteerinud	doc_881665289253_item	3700959	et	0	cKUAfXynZ
redutseerimist	doc_881665289253_item	3700960	et	0	cKUAfXynZ
ehk	doc_881665289253_item	3700961	et	0	cKUAfXynZ
taandamist	doc_881665289253_item	3700962	et	0	cKUAfXynZ
igal	doc_881665289253_item	3700963	et	0	cKUAfXynZ
lausel	doc_881665289253_item	3700964	et	0	cKUAfXynZ
saab	doc_881665289253_item	3700965	et	0	cKUAfXynZ
esineda	doc_881665289253_item	3700966	et	0	cKUAfXynZ
palju	doc_881665289253_item	3700967	et	0	cKUAfXynZ
orienteeritud	doc_881665289253_item	3700968	et	0	cKUAfXynZ
fraase	doc_881665289253_item	3700969	et	0	cKUAfXynZ
olenevalt	doc_881665289253_item	3700970	et	0	cKUAfXynZ
sellest	doc_881665289253_item	3700971	et	0	cKUAfXynZ
missugune	doc_881665289253_item	3700972	et	0	cKUAfXynZ
on	doc_881665289253_item	3700973	et	0	cKUAfXynZ
tuumelement	doc_881665289253_item	3700974	et	0	cKUAfXynZ
selles	doc_881665289253_item	3700975	et	0	cKUAfXynZ
töös	doc_881665289253_item	3700976	et	0	cKUAfXynZ
tuumelemendiks	doc_881665289253_item	3700977	et	0	cKUAfXynZ
on	doc_881665289253_item	3700978	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3700979	et	0	cKUAfXynZ
finiitvorm	doc_881665289253_item	3700980	et	0	cKUAfXynZ
ja	doc_881665289253_item	3700981	et	0	cKUAfXynZ
orienteeritud	doc_881665289253_item	3700982	et	0	cKUAfXynZ
fraasiks	doc_881665289253_item	3700983	et	0	cKUAfXynZ
verbikeskne	doc_881665289253_item	3700984	et	0	cKUAfXynZ
lause	doc_881665289253_item	3700985	et	0	cKUAfXynZ
mis	doc_881665289253_item	3700986	et	0	cKUAfXynZ
oli	doc_881665289253_item	3700987	et	0	cKUAfXynZ
saadud	doc_881665289253_item	3700988	et	0	cKUAfXynZ
redutseerimisel	doc_881665289253_item	3700989	et	0	cKUAfXynZ
autori	doc_881665289253_item	3700990	et	0	cKUAfXynZ
küsimus	doc_881665289253_item	3700991	et	0	cKUAfXynZ
seisneb	doc_881665289253_item	3700992	et	0	cKUAfXynZ
selles	doc_881665289253_item	3700993	et	0	cKUAfXynZ
missugused	doc_881665289253_item	3700994	et	0	cKUAfXynZ
elemendid	doc_881665289253_item	3700995	et	0	cKUAfXynZ
on	doc_881665289253_item	3700996	et	0	cKUAfXynZ
vaja	doc_881665289253_item	3700997	et	0	cKUAfXynZ
taandada	doc_881665289253_item	3700998	et	0	cKUAfXynZ
tema	doc_881665289253_item	3700999	et	0	cKUAfXynZ
seisukohalt	doc_881665289253_item	3701000	et	0	cKUAfXynZ
need	doc_881665289253_item	3701001	et	0	cKUAfXynZ
elemendid	doc_881665289253_item	3701002	et	0	cKUAfXynZ
on	doc_881665289253_item	3701003	et	0	cKUAfXynZ
laiendatud	doc_881665289253_item	3701004	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3701005	et	0	cKUAfXynZ
lausete	doc_881665289253_item	3701006	et	0	cKUAfXynZ
kõik	doc_881665289253_item	3701007	et	0	cKUAfXynZ
teise	doc_881665289253_item	3701008	et	0	cKUAfXynZ
kolmanda	doc_881665289253_item	3701009	et	0	cKUAfXynZ
neljanda	doc_881665289253_item	3701010	et	0	cKUAfXynZ
järgu	doc_881665289253_item	3701011	et	0	cKUAfXynZ
laiendid	doc_881665289253_item	3701012	et	0	cKUAfXynZ
näiteks	doc_881665289253_item	3701013	et	0	cKUAfXynZ
atribuutid	doc_881665289253_item	3701014	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701015	et	0	cKUAfXynZ
adverbaalid	doc_881665289253_item	3701016	et	0	cKUAfXynZ
koos	doc_881665289253_item	3701017	et	0	cKUAfXynZ
nende	doc_881665289253_item	3701018	et	0	cKUAfXynZ
laienditega	doc_881665289253_item	3701019	et	0	cKUAfXynZ
töös	doc_881665289253_item	3701020	et	0	cKUAfXynZ
uuritatakse	doc_881665289253_item	3701021	et	0	cKUAfXynZ
põhilisi	doc_881665289253_item	3701022	et	0	cKUAfXynZ
abstrakseid	doc_881665289253_item	3701023	et	0	cKUAfXynZ
lausemalle	doc_881665289253_item	3701024	et	0	cKUAfXynZ
lähtudes	doc_881665289253_item	3701025	et	0	cKUAfXynZ
sellest	doc_881665289253_item	3701026	et	0	cKUAfXynZ
ei	doc_881665289253_item	3701027	et	0	cKUAfXynZ
ole	doc_881665289253_item	3701028	et	0	cKUAfXynZ
mõistlik	doc_881665289253_item	3701029	et	0	cKUAfXynZ
arvestada	doc_881665289253_item	3701030	et	0	cKUAfXynZ
ka	doc_881665289253_item	3701031	et	0	cKUAfXynZ
esimese	doc_881665289253_item	3701032	et	0	cKUAfXynZ
järgu	doc_881665289253_item	3701033	et	0	cKUAfXynZ
laiendite	doc_881665289253_item	3701034	et	0	cKUAfXynZ
täielikke	doc_881665289253_item	3701035	et	0	cKUAfXynZ
eksotsentrilisi	doc_881665289253_item	3701036	et	0	cKUAfXynZ
konstruktsioone	doc_881665289253_item	3701037	et	0	cKUAfXynZ
redutseerimisel	doc_881665289253_item	3701038	et	0	cKUAfXynZ
on	doc_881665289253_item	3701039	et	0	cKUAfXynZ
jäädud	doc_881665289253_item	3701040	et	0	cKUAfXynZ
ainult	doc_881665289253_item	3701041	et	0	cKUAfXynZ
verbivorm	doc_881665289253_item	3701042	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701043	et	0	cKUAfXynZ
esimese	doc_881665289253_item	3701044	et	0	cKUAfXynZ
järgu	doc_881665289253_item	3701045	et	0	cKUAfXynZ
laiendid	doc_881665289253_item	3701046	et	0	cKUAfXynZ
autor	doc_881665289253_item	3701047	et	0	cKUAfXynZ
arvab	doc_881665289253_item	3701048	et	0	cKUAfXynZ
et	doc_881665289253_item	3701049	et	0	cKUAfXynZ
vabad	doc_881665289253_item	3701050	et	0	cKUAfXynZ
laiendid	doc_881665289253_item	3701051	et	0	cKUAfXynZ
mis	doc_881665289253_item	3701052	et	0	cKUAfXynZ
kuuluvad	doc_881665289253_item	3701053	et	0	cKUAfXynZ
esimese	doc_881665289253_item	3701054	et	0	cKUAfXynZ
järgu	doc_881665289253_item	3701055	et	0	cKUAfXynZ
laiendisse	doc_881665289253_item	3701056	et	0	cKUAfXynZ
on	doc_881665289253_item	3701057	et	0	cKUAfXynZ
vaja	doc_881665289253_item	3701058	et	0	cKUAfXynZ
ka	doc_881665289253_item	3701059	et	0	cKUAfXynZ
taandada	doc_881665289253_item	3701060	et	0	cKUAfXynZ
sest	doc_881665289253_item	3701061	et	0	cKUAfXynZ
nad	doc_881665289253_item	3701062	et	0	cKUAfXynZ
on	doc_881665289253_item	3701063	et	0	cKUAfXynZ
fakultatiivsed	doc_881665289253_item	3701064	et	0	cKUAfXynZ
need	doc_881665289253_item	3701065	et	0	cKUAfXynZ
laiendid	doc_881665289253_item	3701066	et	0	cKUAfXynZ
ei	doc_881665289253_item	3701067	et	0	cKUAfXynZ
määra	doc_881665289253_item	3701068	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3701069	et	0	cKUAfXynZ
tähendust	doc_881665289253_item	3701070	et	0	cKUAfXynZ
ega	doc_881665289253_item	3701071	et	0	cKUAfXynZ
muu	doc_881665289253_item	3701072	et	0	cKUAfXynZ
lauseelemendi	doc_881665289253_item	3701073	et	0	cKUAfXynZ
tähendust	doc_881665289253_item	3701074	et	0	cKUAfXynZ
vaid	doc_881665289253_item	3701075	et	0	cKUAfXynZ
kogu	doc_881665289253_item	3701076	et	0	cKUAfXynZ
lause	doc_881665289253_item	3701077	et	0	cKUAfXynZ
sisu	doc_881665289253_item	3701078	et	0	cKUAfXynZ
vabadele	doc_881665289253_item	3701079	et	0	cKUAfXynZ
laienditele	doc_881665289253_item	3701080	et	0	cKUAfXynZ
on	doc_881665289253_item	3701081	et	0	cKUAfXynZ
vastandatud	doc_881665289253_item	3701082	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3701083	et	0	cKUAfXynZ
laiendeid	doc_881665289253_item	3701084	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3701085	et	0	cKUAfXynZ
laiendeid	doc_881665289253_item	3701086	et	0	cKUAfXynZ
on	doc_881665289253_item	3701087	et	0	cKUAfXynZ
defineeritud	doc_881665289253_item	3701088	et	0	cKUAfXynZ
nagu	doc_881665289253_item	3701089	et	0	cKUAfXynZ
laiendeid	doc_881665289253_item	3701090	et	0	cKUAfXynZ
mis	doc_881665289253_item	3701091	et	0	cKUAfXynZ
on	doc_881665289253_item	3701092	et	0	cKUAfXynZ
vahetult	doc_881665289253_item	3701093	et	0	cKUAfXynZ
tingitud	doc_881665289253_item	3701094	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3701095	et	0	cKUAfXynZ
tähendusest	doc_881665289253_item	3701096	et	0	cKUAfXynZ
ent	doc_881665289253_item	3701097	et	0	cKUAfXynZ
on	doc_881665289253_item	3701098	et	0	cKUAfXynZ
võimalik	doc_881665289253_item	3701099	et	0	cKUAfXynZ
ka	doc_881665289253_item	3701100	et	0	cKUAfXynZ
neid	doc_881665289253_item	3701101	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3701102	et	0	cKUAfXynZ
laiendeid	doc_881665289253_item	3701103	et	0	cKUAfXynZ
redutseerida	doc_881665289253_item	3701104	et	0	cKUAfXynZ
kui	doc_881665289253_item	3701105	et	0	cKUAfXynZ
nad	doc_881665289253_item	3701106	et	0	cKUAfXynZ
oma	doc_881665289253_item	3701107	et	0	cKUAfXynZ
vormilt	doc_881665289253_item	3701108	et	0	cKUAfXynZ
kordavad	doc_881665289253_item	3701109	et	0	cKUAfXynZ
teisi	doc_881665289253_item	3701110	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3701111	et	0	cKUAfXynZ
laiendeid	doc_881665289253_item	3701112	et	0	cKUAfXynZ
aga	doc_881665289253_item	3701113	et	0	cKUAfXynZ
on	doc_881665289253_item	3701114	et	0	cKUAfXynZ
olemas	doc_881665289253_item	3701115	et	0	cKUAfXynZ
ka	doc_881665289253_item	3701116	et	0	cKUAfXynZ
erandid	doc_881665289253_item	3701117	et	0	cKUAfXynZ
kus	doc_881665289253_item	3701118	et	0	cKUAfXynZ
ei	doc_881665289253_item	3701119	et	0	cKUAfXynZ
saa	doc_881665289253_item	3701120	et	0	cKUAfXynZ
korduvaid	doc_881665289253_item	3701121	et	0	cKUAfXynZ
lauseliikmeid	doc_881665289253_item	3701122	et	0	cKUAfXynZ
taandada	doc_881665289253_item	3701123	et	0	cKUAfXynZ
sest	doc_881665289253_item	3701124	et	0	cKUAfXynZ
verb	doc_881665289253_item	3701125	et	0	cKUAfXynZ
peab	doc_881665289253_item	3701126	et	0	cKUAfXynZ
tingima	doc_881665289253_item	3701127	et	0	cKUAfXynZ
mitte	doc_881665289253_item	3701128	et	0	cKUAfXynZ
vähem	doc_881665289253_item	3701129	et	0	cKUAfXynZ
kui	doc_881665289253_item	3701130	et	0	cKUAfXynZ
kahe	doc_881665289253_item	3701131	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3701132	et	0	cKUAfXynZ
laiendi	doc_881665289253_item	3701133	et	0	cKUAfXynZ
olemasolu	doc_881665289253_item	3701134	et	0	cKUAfXynZ
lauses	doc_881665289253_item	3701135	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3701136	et	0	cKUAfXynZ
laiendid	doc_881665289253_item	3701137	et	0	cKUAfXynZ
omakorda	doc_881665289253_item	3701138	et	0	cKUAfXynZ
on	doc_881665289253_item	3701139	et	0	cKUAfXynZ
jaotatud	doc_881665289253_item	3701140	et	0	cKUAfXynZ
fakultatiivseteks	doc_881665289253_item	3701141	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701142	et	0	cKUAfXynZ
obligaatorseteks	doc_881665289253_item	3701143	et	0	cKUAfXynZ
obligaatorsed	doc_881665289253_item	3701144	et	0	cKUAfXynZ
laiendid	doc_881665289253_item	3701145	et	0	cKUAfXynZ
on	doc_881665289253_item	3701146	et	0	cKUAfXynZ
tugevam	doc_881665289253_item	3701147	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3701148	et	0	cKUAfXynZ
verbiga	doc_881665289253_item	3701149	et	0	cKUAfXynZ
kui	doc_881665289253_item	3701150	et	0	cKUAfXynZ
fakultatiivsed	doc_881665289253_item	3701151	et	0	cKUAfXynZ
selle	doc_881665289253_item	3701152	et	0	cKUAfXynZ
tugevuse	doc_881665289253_item	3701153	et	0	cKUAfXynZ
põhjuseks	doc_881665289253_item	3701154	et	0	cKUAfXynZ
on	doc_881665289253_item	3701155	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3701156	et	0	cKUAfXynZ
tähenduse	doc_881665289253_item	3701157	et	0	cKUAfXynZ
üldisus	doc_881665289253_item	3701158	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701159	et	0	cKUAfXynZ
ebamäärasus	doc_881665289253_item	3701160	et	0	cKUAfXynZ
mida	doc_881665289253_item	3701161	et	0	cKUAfXynZ
on	doc_881665289253_item	3701162	et	0	cKUAfXynZ
vaja	doc_881665289253_item	3701163	et	0	cKUAfXynZ
obligaatorsete	doc_881665289253_item	3701164	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3701165	et	0	cKUAfXynZ
laiendi	doc_881665289253_item	3701166	et	0	cKUAfXynZ
kaudu	doc_881665289253_item	3701167	et	0	cKUAfXynZ
täpsustada	doc_881665289253_item	3701168	et	0	cKUAfXynZ
kui	doc_881665289253_item	3701169	et	0	cKUAfXynZ
jätta	doc_881665289253_item	3701170	et	0	cKUAfXynZ
seda	doc_881665289253_item	3701171	et	0	cKUAfXynZ
välja	doc_881665289253_item	3701172	et	0	cKUAfXynZ
siis	doc_881665289253_item	3701173	et	0	cKUAfXynZ
lause	doc_881665289253_item	3701174	et	0	cKUAfXynZ
muutub	doc_881665289253_item	3701175	et	0	cKUAfXynZ
puudulikuks	doc_881665289253_item	3701176	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701177	et	0	cKUAfXynZ
halvasti	doc_881665289253_item	3701178	et	0	cKUAfXynZ
moodustatud	doc_881665289253_item	3701179	et	0	cKUAfXynZ
lauseks	doc_881665289253_item	3701180	et	0	cKUAfXynZ
14	doc_881665289253_item	3701181	et	0	cKUAfXynZ
verbikeskne	doc_881665289253_item	3701182	et	0	cKUAfXynZ
lausemall	doc_881665289253_item	3701183	et	0	cKUAfXynZ
autor	doc_881665289253_item	3701184	et	0	cKUAfXynZ
läheb	doc_881665289253_item	3701185	et	0	cKUAfXynZ
üle	doc_881665289253_item	3701186	et	0	cKUAfXynZ
konkreetsete	doc_881665289253_item	3701187	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3701188	et	0	cKUAfXynZ
lausete	doc_881665289253_item	3701189	et	0	cKUAfXynZ
käsitlusest	doc_881665289253_item	3701190	et	0	cKUAfXynZ
abstraksete	doc_881665289253_item	3701191	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3701192	et	0	cKUAfXynZ
lausemallide	doc_881665289253_item	3701193	et	0	cKUAfXynZ
käsitlusele	doc_881665289253_item	3701194	et	0	cKUAfXynZ
selleks	doc_881665289253_item	3701195	et	0	cKUAfXynZ
ta	doc_881665289253_item	3701196	et	0	cKUAfXynZ
paneb	doc_881665289253_item	3701197	et	0	cKUAfXynZ
konkreetsete	doc_881665289253_item	3701198	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3701199	et	0	cKUAfXynZ
lihtlausete	doc_881665289253_item	3701200	et	0	cKUAfXynZ
asemele	doc_881665289253_item	3701201	et	0	cKUAfXynZ
abstraksemate	doc_881665289253_item	3701202	et	0	cKUAfXynZ
konkreetsele	doc_881665289253_item	3701203	et	0	cKUAfXynZ
verbile	doc_881665289253_item	3701204	et	0	cKUAfXynZ
orienteeritud	doc_881665289253_item	3701205	et	0	cKUAfXynZ
konstruktsioonidega	doc_881665289253_item	3701206	et	0	cKUAfXynZ
ehk	doc_881665289253_item	3701207	et	0	cKUAfXynZ
distributsioonivalemitega	doc_881665289253_item	3701208	et	0	cKUAfXynZ
konkreetseid	doc_881665289253_item	3701209	et	0	cKUAfXynZ
verbikeskseid	doc_881665289253_item	3701210	et	0	cKUAfXynZ
lihtalauseid	doc_881665289253_item	3701211	et	0	cKUAfXynZ
on	doc_881665289253_item	3701212	et	0	cKUAfXynZ
ühendatud	doc_881665289253_item	3701213	et	0	cKUAfXynZ
niimoodi	doc_881665289253_item	3701214	et	0	cKUAfXynZ
et	doc_881665289253_item	3701215	et	0	cKUAfXynZ
on	doc_881665289253_item	3701216	et	0	cKUAfXynZ
hoidud	doc_881665289253_item	3701217	et	0	cKUAfXynZ
konkeetseks	doc_881665289253_item	3701218	et	0	cKUAfXynZ
verbe	doc_881665289253_item	3701219	et	0	cKUAfXynZ
aga	doc_881665289253_item	3701220	et	0	cKUAfXynZ
teisi	doc_881665289253_item	3701221	et	0	cKUAfXynZ
sõnu	doc_881665289253_item	3701222	et	0	cKUAfXynZ
lauses	doc_881665289253_item	3701223	et	0	cKUAfXynZ
on	doc_881665289253_item	3701224	et	0	cKUAfXynZ
ühendatud	doc_881665289253_item	3701225	et	0	cKUAfXynZ
selle	doc_881665289253_item	3701226	et	0	cKUAfXynZ
printsiipi	doc_881665289253_item	3701227	et	0	cKUAfXynZ
järgi	doc_881665289253_item	3701228	et	0	cKUAfXynZ
millise	doc_881665289253_item	3701229	et	0	cKUAfXynZ
vormikategooria	doc_881665289253_item	3701230	et	0	cKUAfXynZ
olemasolu	doc_881665289253_item	3701231	et	0	cKUAfXynZ
konkreetne	doc_881665289253_item	3701232	et	0	cKUAfXynZ
verb	doc_881665289253_item	3701233	et	0	cKUAfXynZ
nõuab	doc_881665289253_item	3701234	et	0	cKUAfXynZ
ta	doc_881665289253_item	3701235	et	0	cKUAfXynZ
toob	doc_881665289253_item	3701236	et	0	cKUAfXynZ
esile	doc_881665289253_item	3701237	et	0	cKUAfXynZ
järgmised	doc_881665289253_item	3701238	et	0	cKUAfXynZ
näited	doc_881665289253_item	3701239	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3701240	et	0	cKUAfXynZ
lk	doc_881665289253_item	3701241	et	0	cKUAfXynZ
17	doc_881665289253_item	3701242	et	0	cKUAfXynZ
1	doc_881665289253_item	3701243	et	0	cKUAfXynZ
advokaat	doc_881665289253_item	3701244	et	0	cKUAfXynZ
sulges	doc_881665289253_item	3701245	et	0	cKUAfXynZ
akna	doc_881665289253_item	3701246	et	0	cKUAfXynZ
2	doc_881665289253_item	3701247	et	0	cKUAfXynZ
priidu	doc_881665289253_item	3701248	et	0	cKUAfXynZ
pidas	doc_881665289253_item	3701249	et	0	cKUAfXynZ
külalist	doc_881665289253_item	3701250	et	0	cKUAfXynZ
direktoriks	doc_881665289253_item	3701251	et	0	cKUAfXynZ
3	doc_881665289253_item	3701252	et	0	cKUAfXynZ
tee	doc_881665289253_item	3701253	et	0	cKUAfXynZ
näis	doc_881665289253_item	3701254	et	0	cKUAfXynZ
käskjalale	doc_881665289253_item	3701255	et	0	cKUAfXynZ
pikk	doc_881665289253_item	3701256	et	0	cKUAfXynZ
järgmised	doc_881665289253_item	3701257	et	0	cKUAfXynZ
konkreetsele	doc_881665289253_item	3701258	et	0	cKUAfXynZ
verbile	doc_881665289253_item	3701259	et	0	cKUAfXynZ
orienteeritud	doc_881665289253_item	3701260	et	0	cKUAfXynZ
konstruktsioonid	doc_881665289253_item	3701261	et	0	cKUAfXynZ
1	doc_881665289253_item	3701262	et	0	cKUAfXynZ
a	doc_881665289253_item	3701263	et	0	cKUAfXynZ
n	doc_881665289253_item	3701264	et	0	cKUAfXynZ
1	doc_881665289253_item	3701265	et	0	cKUAfXynZ
nom	doc_881665289253_item	3701266	et	0	cKUAfXynZ
sulges	doc_881665289253_item	3701267	et	0	cKUAfXynZ
n	doc_881665289253_item	3701268	et	0	cKUAfXynZ
2	doc_881665289253_item	3701269	et	0	cKUAfXynZ
gen	doc_881665289253_item	3701270	et	0	cKUAfXynZ
so	doc_881665289253_item	3701271	et	0	cKUAfXynZ
esimene	doc_881665289253_item	3701272	et	0	cKUAfXynZ
substantiiv	doc_881665289253_item	3701273	et	0	cKUAfXynZ
nominatiivis	doc_881665289253_item	3701274	et	0	cKUAfXynZ
sulges	doc_881665289253_item	3701275	et	0	cKUAfXynZ
teine	doc_881665289253_item	3701276	et	0	cKUAfXynZ
substantiiv	doc_881665289253_item	3701277	et	0	cKUAfXynZ
genetiivis	doc_881665289253_item	3701278	et	0	cKUAfXynZ
2	doc_881665289253_item	3701279	et	0	cKUAfXynZ
a	doc_881665289253_item	3701280	et	0	cKUAfXynZ
n	doc_881665289253_item	3701281	et	0	cKUAfXynZ
1	doc_881665289253_item	3701282	et	0	cKUAfXynZ
nom	doc_881665289253_item	3701283	et	0	cKUAfXynZ
pidas	doc_881665289253_item	3701284	et	0	cKUAfXynZ
n	doc_881665289253_item	3701285	et	0	cKUAfXynZ
2	doc_881665289253_item	3701286	et	0	cKUAfXynZ
part	doc_881665289253_item	3701287	et	0	cKUAfXynZ
n	doc_881665289253_item	3701288	et	0	cKUAfXynZ
3	doc_881665289253_item	3701289	et	0	cKUAfXynZ
tr	doc_881665289253_item	3701290	et	0	cKUAfXynZ
so	doc_881665289253_item	3701291	et	0	cKUAfXynZ
esimene	doc_881665289253_item	3701292	et	0	cKUAfXynZ
substantiiv	doc_881665289253_item	3701293	et	0	cKUAfXynZ
nominatiivis	doc_881665289253_item	3701294	et	0	cKUAfXynZ
pidas	doc_881665289253_item	3701295	et	0	cKUAfXynZ
teine	doc_881665289253_item	3701296	et	0	cKUAfXynZ
substantiiv	doc_881665289253_item	3701297	et	0	cKUAfXynZ
partitiivis	doc_881665289253_item	3701298	et	0	cKUAfXynZ
kolmas	doc_881665289253_item	3701299	et	0	cKUAfXynZ
substantiiv	doc_881665289253_item	3701300	et	0	cKUAfXynZ
translatiivis	doc_881665289253_item	3701301	et	0	cKUAfXynZ
3	doc_881665289253_item	3701302	et	0	cKUAfXynZ
a	doc_881665289253_item	3701303	et	0	cKUAfXynZ
n	doc_881665289253_item	3701304	et	0	cKUAfXynZ
1	doc_881665289253_item	3701305	et	0	cKUAfXynZ
nom	doc_881665289253_item	3701306	et	0	cKUAfXynZ
näis	doc_881665289253_item	3701307	et	0	cKUAfXynZ
n	doc_881665289253_item	3701308	et	0	cKUAfXynZ
2	doc_881665289253_item	3701309	et	0	cKUAfXynZ
all	doc_881665289253_item	3701310	et	0	cKUAfXynZ
anom	doc_881665289253_item	3701311	et	0	cKUAfXynZ
so	doc_881665289253_item	3701312	et	0	cKUAfXynZ
esimene	doc_881665289253_item	3701313	et	0	cKUAfXynZ
substantiiv	doc_881665289253_item	3701314	et	0	cKUAfXynZ
nominatiivis	doc_881665289253_item	3701315	et	0	cKUAfXynZ
näis	doc_881665289253_item	3701316	et	0	cKUAfXynZ
teine	doc_881665289253_item	3701317	et	0	cKUAfXynZ
substantiiv	doc_881665289253_item	3701318	et	0	cKUAfXynZ
allatiivis	doc_881665289253_item	3701319	et	0	cKUAfXynZ
adjekstiiv	doc_881665289253_item	3701320	et	0	cKUAfXynZ
nominatiivis	doc_881665289253_item	3701321	et	0	cKUAfXynZ
nendes	doc_881665289253_item	3701322	et	0	cKUAfXynZ
konstruktsioonides	doc_881665289253_item	3701323	et	0	cKUAfXynZ
on	doc_881665289253_item	3701324	et	0	cKUAfXynZ
määratud	doc_881665289253_item	3701325	et	0	cKUAfXynZ
konkreetsed	doc_881665289253_item	3701326	et	0	cKUAfXynZ
verbid	doc_881665289253_item	3701327	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701328	et	0	cKUAfXynZ
nende	doc_881665289253_item	3701329	et	0	cKUAfXynZ
laiendid	doc_881665289253_item	3701330	et	0	cKUAfXynZ
mis	doc_881665289253_item	3701331	et	0	cKUAfXynZ
on	doc_881665289253_item	3701332	et	0	cKUAfXynZ
ühendatud	doc_881665289253_item	3701333	et	0	cKUAfXynZ
vormiklassidega	doc_881665289253_item	3701334	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701335	et	0	cKUAfXynZ
on	doc_881665289253_item	3701336	et	0	cKUAfXynZ
märgitud	doc_881665289253_item	3701337	et	0	cKUAfXynZ
sõnaliigi	doc_881665289253_item	3701338	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701339	et	0	cKUAfXynZ
morfoloogilise	doc_881665289253_item	3701340	et	0	cKUAfXynZ
vormi	doc_881665289253_item	3701341	et	0	cKUAfXynZ
ühiste	doc_881665289253_item	3701342	et	0	cKUAfXynZ
sümbolitega	doc_881665289253_item	3701343	et	0	cKUAfXynZ
niimoodi	doc_881665289253_item	3701344	et	0	cKUAfXynZ
on	doc_881665289253_item	3701345	et	0	cKUAfXynZ
kodeeritud	doc_881665289253_item	3701346	et	0	cKUAfXynZ
abstraksed	doc_881665289253_item	3701347	et	0	cKUAfXynZ
grammatilised	doc_881665289253_item	3701348	et	0	cKUAfXynZ
kategooriad	doc_881665289253_item	3701349	et	0	cKUAfXynZ
autor	doc_881665289253_item	3701350	et	0	cKUAfXynZ
peab	doc_881665289253_item	3701351	et	0	cKUAfXynZ
lauseliikmeid	doc_881665289253_item	3701352	et	0	cKUAfXynZ
valjalikuteks	doc_881665289253_item	3701353	et	0	cKUAfXynZ
üksusteks	doc_881665289253_item	3701354	et	0	cKUAfXynZ
kuid	doc_881665289253_item	3701355	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3701356	et	0	cKUAfXynZ
lausemallide	doc_881665289253_item	3701357	et	0	cKUAfXynZ
struktuuris	doc_881665289253_item	3701358	et	0	cKUAfXynZ
pole	doc_881665289253_item	3701359	et	0	cKUAfXynZ
nende	doc_881665289253_item	3701360	et	0	cKUAfXynZ
määratlemine	doc_881665289253_item	3701361	et	0	cKUAfXynZ
nii	doc_881665289253_item	3701362	et	0	cKUAfXynZ
oluline	doc_881665289253_item	3701363	et	0	cKUAfXynZ
kuna	doc_881665289253_item	3701364	et	0	cKUAfXynZ
konkreetne	doc_881665289253_item	3701365	et	0	cKUAfXynZ
verb	doc_881665289253_item	3701366	et	0	cKUAfXynZ
ei	doc_881665289253_item	3701367	et	0	cKUAfXynZ
nõua	doc_881665289253_item	3701368	et	0	cKUAfXynZ
vahetult	doc_881665289253_item	3701369	et	0	cKUAfXynZ
lauseliikmeid	doc_881665289253_item	3701370	et	0	cKUAfXynZ
vaid	doc_881665289253_item	3701371	et	0	cKUAfXynZ
konkreetsemaid	doc_881665289253_item	3701372	et	0	cKUAfXynZ
morfoloogilisi	doc_881665289253_item	3701373	et	0	cKUAfXynZ
vorme	doc_881665289253_item	3701374	et	0	cKUAfXynZ
niimoodi	doc_881665289253_item	3701375	et	0	cKUAfXynZ
on	doc_881665289253_item	3701376	et	0	cKUAfXynZ
põhjendatud	doc_881665289253_item	3701377	et	0	cKUAfXynZ
miks	doc_881665289253_item	3701378	et	0	cKUAfXynZ
konstruktsioonides	doc_881665289253_item	3701379	et	0	cKUAfXynZ
1	doc_881665289253_item	3701380	et	0	cKUAfXynZ
a	doc_881665289253_item	3701381	et	0	cKUAfXynZ
3	doc_881665289253_item	3701382	et	0	cKUAfXynZ
a	doc_881665289253_item	3701383	et	0	cKUAfXynZ
on	doc_881665289253_item	3701384	et	0	cKUAfXynZ
kasutatud	doc_881665289253_item	3701385	et	0	cKUAfXynZ
subjekti	doc_881665289253_item	3701386	et	0	cKUAfXynZ
asemel	doc_881665289253_item	3701387	et	0	cKUAfXynZ
vormiklass	doc_881665289253_item	3701388	et	0	cKUAfXynZ
nnom	doc_881665289253_item	3701389	et	0	cKUAfXynZ
objekti	doc_881665289253_item	3701390	et	0	cKUAfXynZ
asemel	doc_881665289253_item	3701391	et	0	cKUAfXynZ
ngen	doc_881665289253_item	3701392	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701393	et	0	cKUAfXynZ
npart	doc_881665289253_item	3701394	et	0	cKUAfXynZ
ning	doc_881665289253_item	3701395	et	0	cKUAfXynZ
teiste	doc_881665289253_item	3701396	et	0	cKUAfXynZ
lauseliikmete	doc_881665289253_item	3701397	et	0	cKUAfXynZ
asemel	doc_881665289253_item	3701398	et	0	cKUAfXynZ
vormiklassid	doc_881665289253_item	3701399	et	0	cKUAfXynZ
ntr	doc_881665289253_item	3701400	et	0	cKUAfXynZ
nall	doc_881665289253_item	3701401	et	0	cKUAfXynZ
anom	doc_881665289253_item	3701402	et	0	cKUAfXynZ
töös	doc_881665289253_item	3701403	et	0	cKUAfXynZ
mõiste	doc_881665289253_item	3701404	et	0	cKUAfXynZ
lauseliikme	doc_881665289253_item	3701405	et	0	cKUAfXynZ
on	doc_881665289253_item	3701406	et	0	cKUAfXynZ
asendatud	doc_881665289253_item	3701407	et	0	cKUAfXynZ
sõnadega	doc_881665289253_item	3701408	et	0	cKUAfXynZ
lauseelement	doc_881665289253_item	3701409	et	0	cKUAfXynZ
element	doc_881665289253_item	3701410	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701411	et	0	cKUAfXynZ
komponent	doc_881665289253_item	3701412	et	0	cKUAfXynZ
konkreetse	doc_881665289253_item	3701413	et	0	cKUAfXynZ
verbivormi	doc_881665289253_item	3701414	et	0	cKUAfXynZ
asemel	doc_881665289253_item	3701415	et	0	cKUAfXynZ
on	doc_881665289253_item	3701416	et	0	cKUAfXynZ
kasutatud	doc_881665289253_item	3701417	et	0	cKUAfXynZ
verbiklassi	doc_881665289253_item	3701418	et	0	cKUAfXynZ
mida	doc_881665289253_item	3701419	et	0	cKUAfXynZ
on	doc_881665289253_item	3701420	et	0	cKUAfXynZ
tähistatud	doc_881665289253_item	3701421	et	0	cKUAfXynZ
sümboliga	doc_881665289253_item	3701422	et	0	cKUAfXynZ
v	doc_881665289253_item	3701423	et	0	cKUAfXynZ
h	doc_881665289253_item	3701424	et	0	cKUAfXynZ
rätsepi	doc_881665289253_item	3701425	et	0	cKUAfXynZ
järgi	doc_881665289253_item	3701426	et	0	cKUAfXynZ
abstraktne	doc_881665289253_item	3701427	et	0	cKUAfXynZ
vormel	doc_881665289253_item	3701428	et	0	cKUAfXynZ
on	doc_881665289253_item	3701429	et	0	cKUAfXynZ
verbikeskne	doc_881665289253_item	3701430	et	0	cKUAfXynZ
lausemall	doc_881665289253_item	3701431	et	0	cKUAfXynZ
verbikeskse	doc_881665289253_item	3701432	et	0	cKUAfXynZ
lause	doc_881665289253_item	3701433	et	0	cKUAfXynZ
aluseks	doc_881665289253_item	3701434	et	0	cKUAfXynZ
on	doc_881665289253_item	3701435	et	0	cKUAfXynZ
verbikeskne	doc_881665289253_item	3701436	et	0	cKUAfXynZ
lausemall	doc_881665289253_item	3701437	et	0	cKUAfXynZ
mis	doc_881665289253_item	3701438	et	0	cKUAfXynZ
kujutab	doc_881665289253_item	3701439	et	0	cKUAfXynZ
ette	doc_881665289253_item	3701440	et	0	cKUAfXynZ
abstrakset	doc_881665289253_item	3701441	et	0	cKUAfXynZ
sõnaklasside	doc_881665289253_item	3701442	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701443	et	0	cKUAfXynZ
grammatiliste	doc_881665289253_item	3701444	et	0	cKUAfXynZ
kategooriate	doc_881665289253_item	3701445	et	0	cKUAfXynZ
konstruktsiooni	doc_881665289253_item	3701446	et	0	cKUAfXynZ
see	doc_881665289253_item	3701447	et	0	cKUAfXynZ
konstruktsioon	doc_881665289253_item	3701448	et	0	cKUAfXynZ
peab	doc_881665289253_item	3701449	et	0	cKUAfXynZ
kajastama	doc_881665289253_item	3701450	et	0	cKUAfXynZ
lause	doc_881665289253_item	3701451	et	0	cKUAfXynZ
tähtseid	doc_881665289253_item	3701452	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3701453	et	0	cKUAfXynZ
tähendusest	doc_881665289253_item	3701454	et	0	cKUAfXynZ
tingitud	doc_881665289253_item	3701455	et	0	cKUAfXynZ
süntaktilis-morfoloogilisi	doc_881665289253_item	3701456	et	0	cKUAfXynZ
joone	doc_881665289253_item	3701457	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3701458	et	0	cKUAfXynZ
lk	doc_881665289253_item	3701459	et	0	cKUAfXynZ
18	doc_881665289253_item	3701460	et	0	cKUAfXynZ
rätsepi	doc_881665289253_item	3701461	et	0	cKUAfXynZ
seisukohalt	doc_881665289253_item	3701462	et	0	cKUAfXynZ
sõnaklass	doc_881665289253_item	3701463	et	0	cKUAfXynZ
verb	doc_881665289253_item	3701464	et	0	cKUAfXynZ
tähisega	doc_881665289253_item	3701465	et	0	cKUAfXynZ
v	doc_881665289253_item	3701466	et	0	cKUAfXynZ
lausemallis	doc_881665289253_item	3701467	et	0	cKUAfXynZ
on	doc_881665289253_item	3701468	et	0	cKUAfXynZ
liiga	doc_881665289253_item	3701469	et	0	cKUAfXynZ
üldine	doc_881665289253_item	3701470	et	0	cKUAfXynZ
seepärast	doc_881665289253_item	3701471	et	0	cKUAfXynZ
on	doc_881665289253_item	3701472	et	0	cKUAfXynZ
arukam	doc_881665289253_item	3701473	et	0	cKUAfXynZ
jaotada	doc_881665289253_item	3701474	et	0	cKUAfXynZ
verbiklassi	doc_881665289253_item	3701475	et	0	cKUAfXynZ
allklassideks	doc_881665289253_item	3701476	et	0	cKUAfXynZ
samaste	doc_881665289253_item	3701477	et	0	cKUAfXynZ
distributsioonivalemite	doc_881665289253_item	3701478	et	0	cKUAfXynZ
järgi	doc_881665289253_item	3701479	et	0	cKUAfXynZ
selle	doc_881665289253_item	3701480	et	0	cKUAfXynZ
jaoks	doc_881665289253_item	3701481	et	0	cKUAfXynZ
on	doc_881665289253_item	3701482	et	0	cKUAfXynZ
mitu	doc_881665289253_item	3701483	et	0	cKUAfXynZ
viisi	doc_881665289253_item	3701484	et	0	cKUAfXynZ
töös	doc_881665289253_item	3701485	et	0	cKUAfXynZ
toetatakse	doc_881665289253_item	3701486	et	0	cKUAfXynZ
sellisele	doc_881665289253_item	3701487	et	0	cKUAfXynZ
viisile	doc_881665289253_item	3701488	et	0	cKUAfXynZ
iga	doc_881665289253_item	3701489	et	0	cKUAfXynZ
lausemalli	doc_881665289253_item	3701490	et	0	cKUAfXynZ
juures	doc_881665289253_item	3701491	et	0	cKUAfXynZ
eraldi	doc_881665289253_item	3701492	et	0	cKUAfXynZ
märkida	doc_881665289253_item	3701493	et	0	cKUAfXynZ
missugused	doc_881665289253_item	3701494	et	0	cKUAfXynZ
verbid	doc_881665289253_item	3701495	et	0	cKUAfXynZ
kuuluvad	doc_881665289253_item	3701496	et	0	cKUAfXynZ
antud	doc_881665289253_item	3701497	et	0	cKUAfXynZ
juhul	doc_881665289253_item	3701498	et	0	cKUAfXynZ
klassi	doc_881665289253_item	3701499	et	0	cKUAfXynZ
v	doc_881665289253_item	3701500	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3701501	et	0	cKUAfXynZ
lk	doc_881665289253_item	3701502	et	0	cKUAfXynZ
19	doc_881665289253_item	3701503	et	0	cKUAfXynZ
näiteks	doc_881665289253_item	3701504	et	0	cKUAfXynZ
nagu	doc_881665289253_item	3701505	et	0	cKUAfXynZ
näidetes	doc_881665289253_item	3701506	et	0	cKUAfXynZ
1-3	doc_881665289253_item	3701507	et	0	cKUAfXynZ
kus	doc_881665289253_item	3701508	et	0	cKUAfXynZ
on	doc_881665289253_item	3701509	et	0	cKUAfXynZ
verbikesksed	doc_881665289253_item	3701510	et	0	cKUAfXynZ
lausemallid	doc_881665289253_item	3701511	et	0	cKUAfXynZ
on	doc_881665289253_item	3701512	et	0	cKUAfXynZ
märgitud	doc_881665289253_item	3701513	et	0	cKUAfXynZ
sedapidi	doc_881665289253_item	3701514	et	0	cKUAfXynZ
1	doc_881665289253_item	3701515	et	0	cKUAfXynZ
b	doc_881665289253_item	3701516	et	0	cKUAfXynZ
n	doc_881665289253_item	3701517	et	0	cKUAfXynZ
1	doc_881665289253_item	3701518	et	0	cKUAfXynZ
nom	doc_881665289253_item	3701519	et	0	cKUAfXynZ
v	doc_881665289253_item	3701520	et	0	cKUAfXynZ
n	doc_881665289253_item	3701521	et	0	cKUAfXynZ
2	doc_881665289253_item	3701522	et	0	cKUAfXynZ
gen	doc_881665289253_item	3701523	et	0	cKUAfXynZ
v	doc_881665289253_item	3701524	et	0	cKUAfXynZ
sulgema	doc_881665289253_item	3701525	et	0	cKUAfXynZ
2	doc_881665289253_item	3701526	et	0	cKUAfXynZ
b	doc_881665289253_item	3701527	et	0	cKUAfXynZ
n	doc_881665289253_item	3701528	et	0	cKUAfXynZ
1	doc_881665289253_item	3701529	et	0	cKUAfXynZ
nom	doc_881665289253_item	3701530	et	0	cKUAfXynZ
v	doc_881665289253_item	3701531	et	0	cKUAfXynZ
n	doc_881665289253_item	3701532	et	0	cKUAfXynZ
2	doc_881665289253_item	3701533	et	0	cKUAfXynZ
part	doc_881665289253_item	3701534	et	0	cKUAfXynZ
n	doc_881665289253_item	3701535	et	0	cKUAfXynZ
3	doc_881665289253_item	3701536	et	0	cKUAfXynZ
tr	doc_881665289253_item	3701537	et	0	cKUAfXynZ
v	doc_881665289253_item	3701538	et	0	cKUAfXynZ
pidama	doc_881665289253_item	3701539	et	0	cKUAfXynZ
3	doc_881665289253_item	3701540	et	0	cKUAfXynZ
b	doc_881665289253_item	3701541	et	0	cKUAfXynZ
n	doc_881665289253_item	3701542	et	0	cKUAfXynZ
1	doc_881665289253_item	3701543	et	0	cKUAfXynZ
nom	doc_881665289253_item	3701544	et	0	cKUAfXynZ
v	doc_881665289253_item	3701545	et	0	cKUAfXynZ
n	doc_881665289253_item	3701546	et	0	cKUAfXynZ
2	doc_881665289253_item	3701547	et	0	cKUAfXynZ
all	doc_881665289253_item	3701548	et	0	cKUAfXynZ
atr	doc_881665289253_item	3701549	et	0	cKUAfXynZ
v	doc_881665289253_item	3701550	et	0	cKUAfXynZ
näima	doc_881665289253_item	3701551	et	0	cKUAfXynZ
paistma	doc_881665289253_item	3701552	et	0	cKUAfXynZ
tunduma	doc_881665289253_item	3701553	et	0	cKUAfXynZ
finiitvormi	doc_881665289253_item	3701554	et	0	cKUAfXynZ
tähistatakse	doc_881665289253_item	3701555	et	0	cKUAfXynZ
sümboliga	doc_881665289253_item	3701556	et	0	cKUAfXynZ
v	doc_881665289253_item	3701557	et	0	cKUAfXynZ
1	doc_881665289253_item	3701558	et	0	cKUAfXynZ
märgib	doc_881665289253_item	3701559	et	0	cKUAfXynZ
määratud	doc_881665289253_item	3701560	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3701561	et	0	cKUAfXynZ
finiitses	doc_881665289253_item	3701562	et	0	cKUAfXynZ
personaalses	doc_881665289253_item	3701563	et	0	cKUAfXynZ
vormis	doc_881665289253_item	3701564	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701565	et	0	cKUAfXynZ
muud	doc_881665289253_item	3701566	et	0	cKUAfXynZ
verbivorme	doc_881665289253_item	3701567	et	0	cKUAfXynZ
resp	doc_881665289253_item	3701568	et	0	cKUAfXynZ
tüvesid	doc_881665289253_item	3701569	et	0	cKUAfXynZ
sümbolitega	doc_881665289253_item	3701570	et	0	cKUAfXynZ
v	doc_881665289253_item	3701571	et	0	cKUAfXynZ
2	doc_881665289253_item	3701572	et	0	cKUAfXynZ
v	doc_881665289253_item	3701573	et	0	cKUAfXynZ
3	doc_881665289253_item	3701574	et	0	cKUAfXynZ
jne	doc_881665289253_item	3701575	et	0	cKUAfXynZ
autor	doc_881665289253_item	3701576	et	0	cKUAfXynZ
võtab	doc_881665289253_item	3701577	et	0	cKUAfXynZ
arvesse	doc_881665289253_item	3701578	et	0	cKUAfXynZ
lausemalli	doc_881665289253_item	3701579	et	0	cKUAfXynZ
verbide	doc_881665289253_item	3701580	et	0	cKUAfXynZ
personaalseid	doc_881665289253_item	3701581	et	0	cKUAfXynZ
vorme	doc_881665289253_item	3701582	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701583	et	0	cKUAfXynZ
jätab	doc_881665289253_item	3701584	et	0	cKUAfXynZ
välja	doc_881665289253_item	3701585	et	0	cKUAfXynZ
impersonaali	doc_881665289253_item	3701586	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701587	et	0	cKUAfXynZ
passiivi	doc_881665289253_item	3701588	et	0	cKUAfXynZ
verbivorme	doc_881665289253_item	3701589	et	0	cKUAfXynZ
tema	doc_881665289253_item	3701590	et	0	cKUAfXynZ
sõnul	doc_881665289253_item	3701591	et	0	cKUAfXynZ
antud	doc_881665289253_item	3701592	et	0	cKUAfXynZ
lausemallid	doc_881665289253_item	3701593	et	0	cKUAfXynZ
toetuvad	doc_881665289253_item	3701594	et	0	cKUAfXynZ
verbide	doc_881665289253_item	3701595	et	0	cKUAfXynZ
finiitvormidele	doc_881665289253_item	3701596	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701597	et	0	cKUAfXynZ
lähtudes	doc_881665289253_item	3701598	et	0	cKUAfXynZ
sellest	doc_881665289253_item	3701599	et	0	cKUAfXynZ
iseseisvale	doc_881665289253_item	3701600	et	0	cKUAfXynZ
lihtlausele	doc_881665289253_item	3701601	et	0	cKUAfXynZ
2	doc_881665289253_item	3701602	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3701603	et	0	cKUAfXynZ
lausemallide	doc_881665289253_item	3701604	et	0	cKUAfXynZ
koostisosad	doc_881665289253_item	3701605	et	0	cKUAfXynZ
lausemallides	doc_881665289253_item	3701606	et	0	cKUAfXynZ
on	doc_881665289253_item	3701607	et	0	cKUAfXynZ
esitatud	doc_881665289253_item	3701608	et	0	cKUAfXynZ
kolmsuguseid	doc_881665289253_item	3701609	et	0	cKUAfXynZ
komponente	doc_881665289253_item	3701610	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3701611	et	0	cKUAfXynZ
finiitvorm	doc_881665289253_item	3701612	et	0	cKUAfXynZ
morfoloogilised	doc_881665289253_item	3701613	et	0	cKUAfXynZ
vormiklassid	doc_881665289253_item	3701614	et	0	cKUAfXynZ
substitutsiooniklassid	doc_881665289253_item	3701615	et	0	cKUAfXynZ
morfoloogilises	doc_881665289253_item	3701616	et	0	cKUAfXynZ
vormiklassis	doc_881665289253_item	3701617	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701618	et	0	cKUAfXynZ
substantsiooniklassis	doc_881665289253_item	3701619	et	0	cKUAfXynZ
on	doc_881665289253_item	3701620	et	0	cKUAfXynZ
nii	doc_881665289253_item	3701621	et	0	cKUAfXynZ
obligaatorsed	doc_881665289253_item	3701622	et	0	cKUAfXynZ
kui	doc_881665289253_item	3701623	et	0	cKUAfXynZ
ka	doc_881665289253_item	3701624	et	0	cKUAfXynZ
fakultatiivsed	doc_881665289253_item	3701625	et	0	cKUAfXynZ
elemendid	doc_881665289253_item	3701626	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3701627	et	0	cKUAfXynZ
finiitvorm	doc_881665289253_item	3701628	et	0	cKUAfXynZ
on	doc_881665289253_item	3701629	et	0	cKUAfXynZ
alati	doc_881665289253_item	3701630	et	0	cKUAfXynZ
obligaatorne	doc_881665289253_item	3701631	et	0	cKUAfXynZ
selles	doc_881665289253_item	3701632	et	0	cKUAfXynZ
lihtlauses	doc_881665289253_item	3701633	et	0	cKUAfXynZ
sest	doc_881665289253_item	3701634	et	0	cKUAfXynZ
tegu	doc_881665289253_item	3701635	et	0	cKUAfXynZ
on	doc_881665289253_item	3701636	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3701637	et	0	cKUAfXynZ
lausetega	doc_881665289253_item	3701638	et	0	cKUAfXynZ
autor	doc_881665289253_item	3701639	et	0	cKUAfXynZ
toetub	doc_881665289253_item	3701640	et	0	cKUAfXynZ
sellele	doc_881665289253_item	3701641	et	0	cKUAfXynZ
mõttele	doc_881665289253_item	3701642	et	0	cKUAfXynZ
et	doc_881665289253_item	3701643	et	0	cKUAfXynZ
kõige	doc_881665289253_item	3701644	et	0	cKUAfXynZ
lihtsam	doc_881665289253_item	3701645	et	0	cKUAfXynZ
on	doc_881665289253_item	3701646	et	0	cKUAfXynZ
selgeks	doc_881665289253_item	3701647	et	0	cKUAfXynZ
teha	doc_881665289253_item	3701648	et	0	cKUAfXynZ
lihtlause	doc_881665289253_item	3701649	et	0	cKUAfXynZ
tuumaks	doc_881665289253_item	3701650	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3701651	et	0	cKUAfXynZ
kuna	doc_881665289253_item	3701652	et	0	cKUAfXynZ
tal	doc_881665289253_item	3701653	et	0	cKUAfXynZ
on	doc_881665289253_item	3701654	et	0	cKUAfXynZ
kindlad	doc_881665289253_item	3701655	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701656	et	0	cKUAfXynZ
formaalselt	doc_881665289253_item	3701657	et	0	cKUAfXynZ
selgesti	doc_881665289253_item	3701658	et	0	cKUAfXynZ
diferentseeritud	doc_881665289253_item	3701659	et	0	cKUAfXynZ
omadused	doc_881665289253_item	3701660	et	0	cKUAfXynZ
kuid	doc_881665289253_item	3701661	et	0	cKUAfXynZ
see	doc_881665289253_item	3701662	et	0	cKUAfXynZ
ei	doc_881665289253_item	3701663	et	0	cKUAfXynZ
ole	doc_881665289253_item	3701664	et	0	cKUAfXynZ
alati	doc_881665289253_item	3701665	et	0	cKUAfXynZ
nii	doc_881665289253_item	3701666	et	0	cKUAfXynZ
lause	doc_881665289253_item	3701667	et	0	cKUAfXynZ
verbaalse	doc_881665289253_item	3701668	et	0	cKUAfXynZ
kesksuse	doc_881665289253_item	3701669	et	0	cKUAfXynZ
täpne	doc_881665289253_item	3701670	et	0	cKUAfXynZ
määramine	doc_881665289253_item	3701671	et	0	cKUAfXynZ
toob	doc_881665289253_item	3701672	et	0	cKUAfXynZ
esile	doc_881665289253_item	3701673	et	0	cKUAfXynZ
rea	doc_881665289253_item	3701674	et	0	cKUAfXynZ
probleeme	doc_881665289253_item	3701675	et	0	cKUAfXynZ
selle	doc_881665289253_item	3701676	et	0	cKUAfXynZ
kohta	doc_881665289253_item	3701677	et	0	cKUAfXynZ
need	doc_881665289253_item	3701678	et	0	cKUAfXynZ
probleemid	doc_881665289253_item	3701679	et	0	cKUAfXynZ
on	doc_881665289253_item	3701680	et	0	cKUAfXynZ
jaotatud	doc_881665289253_item	3701681	et	0	cKUAfXynZ
kaheks	doc_881665289253_item	3701682	et	0	cKUAfXynZ
gruppiks	doc_881665289253_item	3701683	et	0	cKUAfXynZ
esimene	doc_881665289253_item	3701684	et	0	cKUAfXynZ
on	doc_881665289253_item	3701685	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3701686	et	0	cKUAfXynZ
mitmesõnaliste	doc_881665289253_item	3701687	et	0	cKUAfXynZ
verbaalsete	doc_881665289253_item	3701688	et	0	cKUAfXynZ
lekseemide	doc_881665289253_item	3701689	et	0	cKUAfXynZ
tuvastamisega	doc_881665289253_item	3701690	et	0	cKUAfXynZ
tavasõnaühenditest	doc_881665289253_item	3701691	et	0	cKUAfXynZ
teine	doc_881665289253_item	3701692	et	0	cKUAfXynZ
on	doc_881665289253_item	3701693	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3701694	et	0	cKUAfXynZ
analüütiliste	doc_881665289253_item	3701695	et	0	cKUAfXynZ
verbivormide	doc_881665289253_item	3701696	et	0	cKUAfXynZ
eristamisega	doc_881665289253_item	3701697	et	0	cKUAfXynZ
autor	doc_881665289253_item	3701698	et	0	cKUAfXynZ
eristab	doc_881665289253_item	3701699	et	0	cKUAfXynZ
väljendverbe	doc_881665289253_item	3701700	et	0	cKUAfXynZ
muudest	doc_881665289253_item	3701701	et	0	cKUAfXynZ
sõnaühenditest	doc_881665289253_item	3701702	et	0	cKUAfXynZ
sh	doc_881665289253_item	3701703	et	0	cKUAfXynZ
ka	doc_881665289253_item	3701704	et	0	cKUAfXynZ
ühendverbidest	doc_881665289253_item	3701705	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3701706	et	0	cKUAfXynZ
keeles	doc_881665289253_item	3701707	et	0	cKUAfXynZ
on	doc_881665289253_item	3701708	et	0	cKUAfXynZ
eristatud	doc_881665289253_item	3701709	et	0	cKUAfXynZ
lihtverbe	doc_881665289253_item	3701710	et	0	cKUAfXynZ
liitsõnalise	doc_881665289253_item	3701711	et	0	cKUAfXynZ
iseloomuga	doc_881665289253_item	3701712	et	0	cKUAfXynZ
liitverbe	doc_881665289253_item	3701713	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701714	et	0	cKUAfXynZ
sõnaühendilisi	doc_881665289253_item	3701715	et	0	cKUAfXynZ
verbe	doc_881665289253_item	3701716	et	0	cKUAfXynZ
siia	doc_881665289253_item	3701717	et	0	cKUAfXynZ
kuuluvad	doc_881665289253_item	3701718	et	0	cKUAfXynZ
väljendverbid	doc_881665289253_item	3701719	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701720	et	0	cKUAfXynZ
ühendverbid	doc_881665289253_item	3701721	et	0	cKUAfXynZ
väljendverbid	doc_881665289253_item	3701722	et	0	cKUAfXynZ
on	doc_881665289253_item	3701723	et	0	cKUAfXynZ
võimalik	doc_881665289253_item	3701724	et	0	cKUAfXynZ
tuvastada	doc_881665289253_item	3701725	et	0	cKUAfXynZ
ühendverbidest	doc_881665289253_item	3701726	et	0	cKUAfXynZ
sõnaliikide	doc_881665289253_item	3701727	et	0	cKUAfXynZ
eristamise	doc_881665289253_item	3701728	et	0	cKUAfXynZ
tasandil	doc_881665289253_item	3701729	et	0	cKUAfXynZ
väljendverb	doc_881665289253_item	3701730	et	0	cKUAfXynZ
ühendab	doc_881665289253_item	3701731	et	0	cKUAfXynZ
oma	doc_881665289253_item	3701732	et	0	cKUAfXynZ
sees	doc_881665289253_item	3701733	et	0	cKUAfXynZ
noomeni	doc_881665289253_item	3701734	et	0	cKUAfXynZ
verbiga	doc_881665289253_item	3701735	et	0	cKUAfXynZ
ühendverb	doc_881665289253_item	3701736	et	0	cKUAfXynZ
omakorda	doc_881665289253_item	3701737	et	0	cKUAfXynZ
ühendab	doc_881665289253_item	3701738	et	0	cKUAfXynZ
adverbi	doc_881665289253_item	3701739	et	0	cKUAfXynZ
verbiga	doc_881665289253_item	3701740	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3701741	et	0	cKUAfXynZ
lk	doc_881665289253_item	3701742	et	0	cKUAfXynZ
21	doc_881665289253_item	3701743	et	0	cKUAfXynZ
väljendverbide	doc_881665289253_item	3701744	et	0	cKUAfXynZ
tuvastamisega	doc_881665289253_item	3701745	et	0	cKUAfXynZ
on	doc_881665289253_item	3701746	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3701747	et	0	cKUAfXynZ
selline	doc_881665289253_item	3701748	et	0	cKUAfXynZ
probleem	doc_881665289253_item	3701749	et	0	cKUAfXynZ
nagu	doc_881665289253_item	3701750	et	0	cKUAfXynZ
nende	doc_881665289253_item	3701751	et	0	cKUAfXynZ
eristamine	doc_881665289253_item	3701752	et	0	cKUAfXynZ
tavalistest	doc_881665289253_item	3701753	et	0	cKUAfXynZ
noomeni	doc_881665289253_item	3701754	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701755	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3701756	et	0	cKUAfXynZ
ühenditest	doc_881665289253_item	3701757	et	0	cKUAfXynZ
lauale	doc_881665289253_item	3701758	et	0	cKUAfXynZ
panema	doc_881665289253_item	3701759	et	0	cKUAfXynZ
raha	doc_881665289253_item	3701760	et	0	cKUAfXynZ
saama	doc_881665289253_item	3701761	et	0	cKUAfXynZ
tuppa	doc_881665289253_item	3701762	et	0	cKUAfXynZ
paistma	doc_881665289253_item	3701763	et	0	cKUAfXynZ
jn	doc_881665289253_item	3701764	et	0	cKUAfXynZ
väljendverbi	doc_881665289253_item	3701765	et	0	cKUAfXynZ
eristatakse	doc_881665289253_item	3701766	et	0	cKUAfXynZ
vabast	doc_881665289253_item	3701767	et	0	cKUAfXynZ
sõnaühendist	doc_881665289253_item	3701768	et	0	cKUAfXynZ
see	doc_881665289253_item	3701769	et	0	cKUAfXynZ
et	doc_881665289253_item	3701770	et	0	cKUAfXynZ
selle	doc_881665289253_item	3701771	et	0	cKUAfXynZ
hulka	doc_881665289253_item	3701772	et	0	cKUAfXynZ
kuulub	doc_881665289253_item	3701773	et	0	cKUAfXynZ
üks	doc_881665289253_item	3701774	et	0	cKUAfXynZ
nominaalne	doc_881665289253_item	3701775	et	0	cKUAfXynZ
laiend	doc_881665289253_item	3701776	et	0	cKUAfXynZ
kindel	doc_881665289253_item	3701777	et	0	cKUAfXynZ
klassi	doc_881665289253_item	3701778	et	0	cKUAfXynZ
esindaja	doc_881665289253_item	3701779	et	0	cKUAfXynZ
kindlas	doc_881665289253_item	3701780	et	0	cKUAfXynZ
grammatilises	doc_881665289253_item	3701781	et	0	cKUAfXynZ
vormis	doc_881665289253_item	3701782	et	0	cKUAfXynZ
autor	doc_881665289253_item	3701783	et	0	cKUAfXynZ
nimetab	doc_881665289253_item	3701784	et	0	cKUAfXynZ
seda	doc_881665289253_item	3701785	et	0	cKUAfXynZ
väljendiverbi	doc_881665289253_item	3701786	et	0	cKUAfXynZ
nominaalset	doc_881665289253_item	3701787	et	0	cKUAfXynZ
komponenti	doc_881665289253_item	3701788	et	0	cKUAfXynZ
püsisõnaks	doc_881665289253_item	3701789	et	0	cKUAfXynZ
mille	doc_881665289253_item	3701790	et	0	cKUAfXynZ
grammatiline	doc_881665289253_item	3701791	et	0	cKUAfXynZ
vorm	doc_881665289253_item	3701792	et	0	cKUAfXynZ
on	doc_881665289253_item	3701793	et	0	cKUAfXynZ
tavaliselt	doc_881665289253_item	3701794	et	0	cKUAfXynZ
määratum	doc_881665289253_item	3701795	et	0	cKUAfXynZ
kui	doc_881665289253_item	3701796	et	0	cKUAfXynZ
vaba	doc_881665289253_item	3701797	et	0	cKUAfXynZ
sõnaühendite	doc_881665289253_item	3701798	et	0	cKUAfXynZ
noomeni	doc_881665289253_item	3701799	et	0	cKUAfXynZ
vorm	doc_881665289253_item	3701800	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3701801	et	0	cKUAfXynZ
lk	doc_881665289253_item	3701802	et	0	cKUAfXynZ
22	doc_881665289253_item	3701803	et	0	cKUAfXynZ
autor	doc_881665289253_item	3701804	et	0	cKUAfXynZ
nimetab	doc_881665289253_item	3701805	et	0	cKUAfXynZ
individualiseeritud	doc_881665289253_item	3701806	et	0	cKUAfXynZ
liikmega	doc_881665289253_item	3701807	et	0	cKUAfXynZ
sõnaühendeid	doc_881665289253_item	3701808	et	0	cKUAfXynZ
ainukordseteks	doc_881665289253_item	3701809	et	0	cKUAfXynZ
sõnaühenditeks	doc_881665289253_item	3701810	et	0	cKUAfXynZ
nendes	doc_881665289253_item	3701811	et	0	cKUAfXynZ
arvestatakse	doc_881665289253_item	3701812	et	0	cKUAfXynZ
varieerimisvõimalusega	doc_881665289253_item	3701813	et	0	cKUAfXynZ
kui	doc_881665289253_item	3701814	et	0	cKUAfXynZ
sõnaühendi	doc_881665289253_item	3701815	et	0	cKUAfXynZ
laiendis	doc_881665289253_item	3701816	et	0	cKUAfXynZ
maad	doc_881665289253_item	3701817	et	0	cKUAfXynZ
jagama	doc_881665289253_item	3701818	et	0	cKUAfXynZ
maid	doc_881665289253_item	3701819	et	0	cKUAfXynZ
jagama	doc_881665289253_item	3701820	et	0	cKUAfXynZ
nii	doc_881665289253_item	3701821	et	0	cKUAfXynZ
ka	doc_881665289253_item	3701822	et	0	cKUAfXynZ
selle	doc_881665289253_item	3701823	et	0	cKUAfXynZ
verbis	doc_881665289253_item	3701824	et	0	cKUAfXynZ
plehku	doc_881665289253_item	3701825	et	0	cKUAfXynZ
panema	doc_881665289253_item	3701826	et	0	cKUAfXynZ
plehku	doc_881665289253_item	3701827	et	0	cKUAfXynZ
pistma	doc_881665289253_item	3701828	et	0	cKUAfXynZ
ning	doc_881665289253_item	3701829	et	0	cKUAfXynZ
sellel	doc_881665289253_item	3701830	et	0	cKUAfXynZ
juhul	doc_881665289253_item	3701831	et	0	cKUAfXynZ
verbide	doc_881665289253_item	3701832	et	0	cKUAfXynZ
hulk	doc_881665289253_item	3701833	et	0	cKUAfXynZ
on	doc_881665289253_item	3701834	et	0	cKUAfXynZ
piiratud	doc_881665289253_item	3701835	et	0	cKUAfXynZ
viie-kuue	doc_881665289253_item	3701836	et	0	cKUAfXynZ
verbiga	doc_881665289253_item	3701837	et	0	cKUAfXynZ
tavaliselt	doc_881665289253_item	3701838	et	0	cKUAfXynZ
aga	doc_881665289253_item	3701839	et	0	cKUAfXynZ
ei	doc_881665289253_item	3701840	et	0	cKUAfXynZ
arvata	doc_881665289253_item	3701841	et	0	cKUAfXynZ
väljendverbide	doc_881665289253_item	3701842	et	0	cKUAfXynZ
hulka	doc_881665289253_item	3701843	et	0	cKUAfXynZ
neid	doc_881665289253_item	3701844	et	0	cKUAfXynZ
sõnaühendeid	doc_881665289253_item	3701845	et	0	cKUAfXynZ
kus	doc_881665289253_item	3701846	et	0	cKUAfXynZ
noomenina	doc_881665289253_item	3701847	et	0	cKUAfXynZ
esineb	doc_881665289253_item	3701848	et	0	cKUAfXynZ
somaatiline	doc_881665289253_item	3701849	et	0	cKUAfXynZ
sõna	doc_881665289253_item	3701850	et	0	cKUAfXynZ
nad	doc_881665289253_item	3701851	et	0	cKUAfXynZ
moodustavad	doc_881665289253_item	3701852	et	0	cKUAfXynZ
erarühma	doc_881665289253_item	3701853	et	0	cKUAfXynZ
töö	doc_881665289253_item	3701854	et	0	cKUAfXynZ
väljaandmise	doc_881665289253_item	3701855	et	0	cKUAfXynZ
perioodiks	doc_881665289253_item	3701856	et	0	cKUAfXynZ
veel	doc_881665289253_item	3701857	et	0	cKUAfXynZ
nimeta	doc_881665289253_item	3701858	et	0	cKUAfXynZ
väljendverbide	doc_881665289253_item	3701859	et	0	cKUAfXynZ
lõplikul	doc_881665289253_item	3701860	et	0	cKUAfXynZ
piiritlemisel	doc_881665289253_item	3701861	et	0	cKUAfXynZ
vastandatakse	doc_881665289253_item	3701862	et	0	cKUAfXynZ
sõnaühendeid	doc_881665289253_item	3701863	et	0	cKUAfXynZ
üksnes	doc_881665289253_item	3701864	et	0	cKUAfXynZ
verbilise	doc_881665289253_item	3701865	et	0	cKUAfXynZ
tsentrumiga	doc_881665289253_item	3701866	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701867	et	0	cKUAfXynZ
väljendverbe	doc_881665289253_item	3701868	et	0	cKUAfXynZ
süntaktiliselt	doc_881665289253_item	3701869	et	0	cKUAfXynZ
lahutamatu	doc_881665289253_item	3701870	et	0	cKUAfXynZ
elemendiga	doc_881665289253_item	3701871	et	0	cKUAfXynZ
esimese	doc_881665289253_item	3701872	et	0	cKUAfXynZ
puhul	doc_881665289253_item	3701873	et	0	cKUAfXynZ
määratletakse	doc_881665289253_item	3701874	et	0	cKUAfXynZ
lauseid	doc_881665289253_item	3701875	et	0	cKUAfXynZ
nagu	doc_881665289253_item	3701876	et	0	cKUAfXynZ
ema	doc_881665289253_item	3701877	et	0	cKUAfXynZ
kallistab	doc_881665289253_item	3701878	et	0	cKUAfXynZ
last	doc_881665289253_item	3701879	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701880	et	0	cKUAfXynZ
mees	doc_881665289253_item	3701881	et	0	cKUAfXynZ
kehitas	doc_881665289253_item	3701882	et	0	cKUAfXynZ
õlgu	doc_881665289253_item	3701883	et	0	cKUAfXynZ
npart	doc_881665289253_item	3701884	et	0	cKUAfXynZ
verbaalse	doc_881665289253_item	3701885	et	0	cKUAfXynZ
tsentrumiga	doc_881665289253_item	3701886	et	0	cKUAfXynZ
lausetena	doc_881665289253_item	3701887	et	0	cKUAfXynZ
ent	doc_881665289253_item	3701888	et	0	cKUAfXynZ
väljendverbide	doc_881665289253_item	3701889	et	0	cKUAfXynZ
puhul	doc_881665289253_item	3701890	et	0	cKUAfXynZ
semantilise	doc_881665289253_item	3701891	et	0	cKUAfXynZ
terviklikkuse	doc_881665289253_item	3701892	et	0	cKUAfXynZ
moodustab	doc_881665289253_item	3701893	et	0	cKUAfXynZ
verb	doc_881665289253_item	3701894	et	0	cKUAfXynZ
koos	doc_881665289253_item	3701895	et	0	cKUAfXynZ
laiendiga	doc_881665289253_item	3701896	et	0	cKUAfXynZ
tähele	doc_881665289253_item	3701897	et	0	cKUAfXynZ
panema	doc_881665289253_item	3701898	et	0	cKUAfXynZ
mis	doc_881665289253_item	3701899	et	0	cKUAfXynZ
omakorda	doc_881665289253_item	3701900	et	0	cKUAfXynZ
erineb	doc_881665289253_item	3701901	et	0	cKUAfXynZ
panema-verbi	doc_881665289253_item	3701902	et	0	cKUAfXynZ
lihtverbina	doc_881665289253_item	3701903	et	0	cKUAfXynZ
lausemallist	doc_881665289253_item	3701904	et	0	cKUAfXynZ
verbid	doc_881665289253_item	3701905	et	0	cKUAfXynZ
mis	doc_881665289253_item	3701906	et	0	cKUAfXynZ
esinevad	doc_881665289253_item	3701907	et	0	cKUAfXynZ
kui	doc_881665289253_item	3701908	et	0	cKUAfXynZ
väljendis	doc_881665289253_item	3701909	et	0	cKUAfXynZ
nii	doc_881665289253_item	3701910	et	0	cKUAfXynZ
ka	doc_881665289253_item	3701911	et	0	cKUAfXynZ
otsese	doc_881665289253_item	3701912	et	0	cKUAfXynZ
tähendusega	doc_881665289253_item	3701913	et	0	cKUAfXynZ
lihtlauses	doc_881665289253_item	3701914	et	0	cKUAfXynZ
kaotavad	doc_881665289253_item	3701915	et	0	cKUAfXynZ
väljendis	doc_881665289253_item	3701916	et	0	cKUAfXynZ
oma	doc_881665289253_item	3701917	et	0	cKUAfXynZ
tausttähenduse	doc_881665289253_item	3701918	et	0	cKUAfXynZ
jalga	doc_881665289253_item	3701919	et	0	cKUAfXynZ
laskma	doc_881665289253_item	3701920	et	0	cKUAfXynZ
põgenema	doc_881665289253_item	3701921	et	0	cKUAfXynZ
omades	doc_881665289253_item	3701922	et	0	cKUAfXynZ
aktuaalse	doc_881665289253_item	3701923	et	0	cKUAfXynZ
tähenduse	doc_881665289253_item	3701924	et	0	cKUAfXynZ
otseses	doc_881665289253_item	3701925	et	0	cKUAfXynZ
tähenduses	doc_881665289253_item	3701926	et	0	cKUAfXynZ
aga	doc_881665289253_item	3701927	et	0	cKUAfXynZ
nõuavad	doc_881665289253_item	3701928	et	0	cKUAfXynZ
aluse	doc_881665289253_item	3701929	et	0	cKUAfXynZ
kaudobjekti	doc_881665289253_item	3701930	et	0	cKUAfXynZ
kohaelemendi	doc_881665289253_item	3701931	et	0	cKUAfXynZ
vahendi	doc_881665289253_item	3701932	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701933	et	0	cKUAfXynZ
objektile	doc_881665289253_item	3701934	et	0	cKUAfXynZ
osutava	doc_881665289253_item	3701935	et	0	cKUAfXynZ
elemendi	doc_881665289253_item	3701936	et	0	cKUAfXynZ
oma	doc_881665289253_item	3701937	et	0	cKUAfXynZ
verbikeskse	doc_881665289253_item	3701938	et	0	cKUAfXynZ
lausemalli	doc_881665289253_item	3701939	et	0	cKUAfXynZ
moodustamiseks	doc_881665289253_item	3701940	et	0	cKUAfXynZ
ma	doc_881665289253_item	3701941	et	0	cKUAfXynZ
lasksin	doc_881665289253_item	3701942	et	0	cKUAfXynZ
talle	doc_881665289253_item	3701943	et	0	cKUAfXynZ
kuuli	doc_881665289253_item	3701944	et	0	cKUAfXynZ
jalga	doc_881665289253_item	3701945	et	0	cKUAfXynZ
kui	doc_881665289253_item	3701946	et	0	cKUAfXynZ
noomeni	doc_881665289253_item	3701947	et	0	cKUAfXynZ
suhtes	doc_881665289253_item	3701948	et	0	cKUAfXynZ
sõnaühendis	doc_881665289253_item	3701949	et	0	cKUAfXynZ
ei	doc_881665289253_item	3701950	et	0	cKUAfXynZ
ole	doc_881665289253_item	3701951	et	0	cKUAfXynZ
võimalik	doc_881665289253_item	3701952	et	0	cKUAfXynZ
esitada	doc_881665289253_item	3701953	et	0	cKUAfXynZ
loomuliku	doc_881665289253_item	3701954	et	0	cKUAfXynZ
küsimuse	doc_881665289253_item	3701955	et	0	cKUAfXynZ
siis	doc_881665289253_item	3701956	et	0	cKUAfXynZ
tehakse	doc_881665289253_item	3701957	et	0	cKUAfXynZ
järelduse	doc_881665289253_item	3701958	et	0	cKUAfXynZ
et	doc_881665289253_item	3701959	et	0	cKUAfXynZ
meie	doc_881665289253_item	3701960	et	0	cKUAfXynZ
ees	doc_881665289253_item	3701961	et	0	cKUAfXynZ
on	doc_881665289253_item	3701962	et	0	cKUAfXynZ
väljendverb	doc_881665289253_item	3701963	et	0	cKUAfXynZ
esineb	doc_881665289253_item	3701964	et	0	cKUAfXynZ
väljendverbe	doc_881665289253_item	3701965	et	0	cKUAfXynZ
nimisõnadega	doc_881665289253_item	3701966	et	0	cKUAfXynZ
erinevates	doc_881665289253_item	3701967	et	0	cKUAfXynZ
käänetes	doc_881665289253_item	3701968	et	0	cKUAfXynZ
adjektiividega	doc_881665289253_item	3701969	et	0	cKUAfXynZ
pronoomidega	doc_881665289253_item	3701970	et	0	cKUAfXynZ
noomeni	doc_881665289253_item	3701971	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701972	et	0	cKUAfXynZ
kaassõnaga	doc_881665289253_item	3701973	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701974	et	0	cKUAfXynZ
ühendverbiga	doc_881665289253_item	3701975	et	0	cKUAfXynZ
viimastele	doc_881665289253_item	3701976	et	0	cKUAfXynZ
autor	doc_881665289253_item	3701977	et	0	cKUAfXynZ
pühendab	doc_881665289253_item	3701978	et	0	cKUAfXynZ
oma	doc_881665289253_item	3701979	et	0	cKUAfXynZ
töös	doc_881665289253_item	3701980	et	0	cKUAfXynZ
eraosa	doc_881665289253_item	3701981	et	0	cKUAfXynZ
ning	doc_881665289253_item	3701982	et	0	cKUAfXynZ
eristab	doc_881665289253_item	3701983	et	0	cKUAfXynZ
ühendverbe	doc_881665289253_item	3701984	et	0	cKUAfXynZ
tähenduse	doc_881665289253_item	3701985	et	0	cKUAfXynZ
järgi	doc_881665289253_item	3701986	et	0	cKUAfXynZ
defineerides	doc_881665289253_item	3701987	et	0	cKUAfXynZ
fraseologismi	doc_881665289253_item	3701988	et	0	cKUAfXynZ
sõnaühendina	doc_881665289253_item	3701989	et	0	cKUAfXynZ
mille	doc_881665289253_item	3701990	et	0	cKUAfXynZ
elemendid	doc_881665289253_item	3701991	et	0	cKUAfXynZ
on	doc_881665289253_item	3701992	et	0	cKUAfXynZ
ainukordsed	doc_881665289253_item	3701993	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701994	et	0	cKUAfXynZ
moodustavad	doc_881665289253_item	3701995	et	0	cKUAfXynZ
ühtse	doc_881665289253_item	3701996	et	0	cKUAfXynZ
süntaktilise	doc_881665289253_item	3701997	et	0	cKUAfXynZ
trentrumi	doc_881665289253_item	3701998	et	0	cKUAfXynZ
ja	doc_881665289253_item	3701999	et	0	cKUAfXynZ
millel	doc_881665289253_item	3702000	et	0	cKUAfXynZ
on	doc_881665289253_item	3702001	et	0	cKUAfXynZ
kaks	doc_881665289253_item	3702002	et	0	cKUAfXynZ
tähendust	doc_881665289253_item	3702003	et	0	cKUAfXynZ
aktuaalne	doc_881665289253_item	3702004	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702005	et	0	cKUAfXynZ
tausttähendus	doc_881665289253_item	3702006	et	0	cKUAfXynZ
st	doc_881665289253_item	3702007	et	0	cKUAfXynZ
mis	doc_881665289253_item	3702008	et	0	cKUAfXynZ
on	doc_881665289253_item	3702009	et	0	cKUAfXynZ
idiomaatilised	doc_881665289253_item	3702010	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3702011	et	0	cKUAfXynZ
lk	doc_881665289253_item	3702012	et	0	cKUAfXynZ
24	doc_881665289253_item	3702013	et	0	cKUAfXynZ
autor	doc_881665289253_item	3702014	et	0	cKUAfXynZ
väidab	doc_881665289253_item	3702015	et	0	cKUAfXynZ
et	doc_881665289253_item	3702016	et	0	cKUAfXynZ
verbiväljendi	doc_881665289253_item	3702017	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702018	et	0	cKUAfXynZ
fraseologisme	doc_881665289253_item	3702019	et	0	cKUAfXynZ
vastastikune	doc_881665289253_item	3702020	et	0	cKUAfXynZ
vahekord	doc_881665289253_item	3702021	et	0	cKUAfXynZ
on	doc_881665289253_item	3702022	et	0	cKUAfXynZ
järgmine	doc_881665289253_item	3702023	et	0	cKUAfXynZ
fr	doc_881665289253_item	3702024	et	0	cKUAfXynZ
def	doc_881665289253_item	3702025	et	0	cKUAfXynZ
vv	doc_881665289253_item	3702026	et	0	cKUAfXynZ
kus	doc_881665289253_item	3702027	et	0	cKUAfXynZ
fr	doc_881665289253_item	3702028	et	0	cKUAfXynZ
def	doc_881665289253_item	3702029	et	0	cKUAfXynZ
on	doc_881665289253_item	3702030	et	0	cKUAfXynZ
ülaltoodud	doc_881665289253_item	3702031	et	0	cKUAfXynZ
fraseologismi	doc_881665289253_item	3702032	et	0	cKUAfXynZ
definitsioon	doc_881665289253_item	3702033	et	0	cKUAfXynZ
ning	doc_881665289253_item	3702034	et	0	cKUAfXynZ
vv	doc_881665289253_item	3702035	et	0	cKUAfXynZ
on	doc_881665289253_item	3702036	et	0	cKUAfXynZ
väljendverb	doc_881665289253_item	3702037	et	0	cKUAfXynZ
lisades	doc_881665289253_item	3702038	et	0	cKUAfXynZ
definitsioonile	doc_881665289253_item	3702039	et	0	cKUAfXynZ
ekspressiivsuse	doc_881665289253_item	3702040	et	0	cKUAfXynZ
tunnust	doc_881665289253_item	3702041	et	0	cKUAfXynZ
saame	doc_881665289253_item	3702042	et	0	cKUAfXynZ
fr	doc_881665289253_item	3702043	et	0	cKUAfXynZ
def	doc_881665289253_item	3702044	et	0	cKUAfXynZ
eksprvvvv	doc_881665289253_item	3702045	et	0	cKUAfXynZ
ehk	doc_881665289253_item	3702046	et	0	cKUAfXynZ
osa	doc_881665289253_item	3702047	et	0	cKUAfXynZ
väljendverbidest	doc_881665289253_item	3702048	et	0	cKUAfXynZ
fraseologismide	doc_881665289253_item	3702049	et	0	cKUAfXynZ
hulgast	doc_881665289253_item	3702050	et	0	cKUAfXynZ
väljaspool	doc_881665289253_item	3702051	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3702052	et	0	cKUAfXynZ
keele	doc_881665289253_item	3702053	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3702054	et	0	cKUAfXynZ
lausemaalide	doc_881665289253_item	3702055	et	0	cKUAfXynZ
ehituse	doc_881665289253_item	3702056	et	0	cKUAfXynZ
arusaamise	doc_881665289253_item	3702057	et	0	cKUAfXynZ
jaoks	doc_881665289253_item	3702058	et	0	cKUAfXynZ
autor	doc_881665289253_item	3702059	et	0	cKUAfXynZ
räägib	doc_881665289253_item	3702060	et	0	cKUAfXynZ
järgmistest	doc_881665289253_item	3702061	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3702062	et	0	cKUAfXynZ
lausemallide	doc_881665289253_item	3702063	et	0	cKUAfXynZ
koostisosadest	doc_881665289253_item	3702064	et	0	cKUAfXynZ
modaalverbidest	doc_881665289253_item	3702065	et	0	cKUAfXynZ
mille	doc_881665289253_item	3702066	et	0	cKUAfXynZ
juures	doc_881665289253_item	3702067	et	0	cKUAfXynZ
siin	doc_881665289253_item	3702068	et	0	cKUAfXynZ
tuuakse	doc_881665289253_item	3702069	et	0	cKUAfXynZ
modaalsuse	doc_881665289253_item	3702070	et	0	cKUAfXynZ
mõistet	doc_881665289253_item	3702071	et	0	cKUAfXynZ
eristatakse	doc_881665289253_item	3702072	et	0	cKUAfXynZ
iseseisvaid	doc_881665289253_item	3702073	et	0	cKUAfXynZ
verbe	doc_881665289253_item	3702074	et	0	cKUAfXynZ
grammatiliste	doc_881665289253_item	3702075	et	0	cKUAfXynZ
tunnuste	doc_881665289253_item	3702076	et	0	cKUAfXynZ
järgi	doc_881665289253_item	3702077	et	0	cKUAfXynZ
täielikke	doc_881665289253_item	3702078	et	0	cKUAfXynZ
modaalverbe	doc_881665289253_item	3702079	et	0	cKUAfXynZ
võima	doc_881665289253_item	3702080	et	0	cKUAfXynZ
pidama	doc_881665289253_item	3702081	et	0	cKUAfXynZ
ilma	doc_881665289253_item	3702082	et	0	cKUAfXynZ
subjektiselektsioonita	doc_881665289253_item	3702083	et	0	cKUAfXynZ
modaalverbe	doc_881665289253_item	3702084	et	0	cKUAfXynZ
võima	doc_881665289253_item	3702085	et	0	cKUAfXynZ
võimalik	doc_881665289253_item	3702086	et	0	cKUAfXynZ
olema	doc_881665289253_item	3702087	et	0	cKUAfXynZ
pidama	doc_881665289253_item	3702088	et	0	cKUAfXynZ
näima	doc_881665289253_item	3702089	et	0	cKUAfXynZ
paistma	doc_881665289253_item	3702090	et	0	cKUAfXynZ
tunduma	doc_881665289253_item	3702091	et	0	cKUAfXynZ
pöörakse	doc_881665289253_item	3702092	et	0	cKUAfXynZ
tähelepanu	doc_881665289253_item	3702093	et	0	cKUAfXynZ
modaalverbide	doc_881665289253_item	3702094	et	0	cKUAfXynZ
olema-abiverbiga	doc_881665289253_item	3702095	et	0	cKUAfXynZ
vahekorrale	doc_881665289253_item	3702096	et	0	cKUAfXynZ
ning	doc_881665289253_item	3702097	et	0	cKUAfXynZ
eraldatakse	doc_881665289253_item	3702098	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3702099	et	0	cKUAfXynZ
tulema	doc_881665289253_item	3702100	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702101	et	0	cKUAfXynZ
ühendverbe	doc_881665289253_item	3702102	et	0	cKUAfXynZ
tarvis	doc_881665289253_item	3702103	et	0	cKUAfXynZ
olema	doc_881665289253_item	3702104	et	0	cKUAfXynZ
vaja	doc_881665289253_item	3702105	et	0	cKUAfXynZ
olema	doc_881665289253_item	3702106	et	0	cKUAfXynZ
jt	doc_881665289253_item	3702107	et	0	cKUAfXynZ
variante	doc_881665289253_item	3702108	et	0	cKUAfXynZ
modaalverbide	doc_881665289253_item	3702109	et	0	cKUAfXynZ
hulgast	doc_881665289253_item	3702110	et	0	cKUAfXynZ
sõnaklassidest	doc_881665289253_item	3702111	et	0	cKUAfXynZ
ehk	doc_881665289253_item	3702112	et	0	cKUAfXynZ
substantiividest	doc_881665289253_item	3702113	et	0	cKUAfXynZ
n	doc_881665289253_item	3702114	et	0	cKUAfXynZ
traditsioonilised	doc_881665289253_item	3702115	et	0	cKUAfXynZ
substantiivid	doc_881665289253_item	3702116	et	0	cKUAfXynZ
personaalpronoomenid	doc_881665289253_item	3702117	et	0	cKUAfXynZ
osa	doc_881665289253_item	3702118	et	0	cKUAfXynZ
indefiniitseid	doc_881665289253_item	3702119	et	0	cKUAfXynZ
pronoomeneid	doc_881665289253_item	3702120	et	0	cKUAfXynZ
jm	doc_881665289253_item	3702121	et	0	cKUAfXynZ
põhiarvsõnad	doc_881665289253_item	3702122	et	0	cKUAfXynZ
adjektiividest	doc_881665289253_item	3702123	et	0	cKUAfXynZ
a	doc_881665289253_item	3702124	et	0	cKUAfXynZ
traditsioonilised	doc_881665289253_item	3702125	et	0	cKUAfXynZ
adjektiivid	doc_881665289253_item	3702126	et	0	cKUAfXynZ
demonstratiivpronoomenid	doc_881665289253_item	3702127	et	0	cKUAfXynZ
osa	doc_881665289253_item	3702128	et	0	cKUAfXynZ
indefiniitseid	doc_881665289253_item	3702129	et	0	cKUAfXynZ
pronoomeneid	doc_881665289253_item	3702130	et	0	cKUAfXynZ
jm	doc_881665289253_item	3702131	et	0	cKUAfXynZ
järgarvsõnad	doc_881665289253_item	3702132	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702133	et	0	cKUAfXynZ
verbidest	doc_881665289253_item	3702134	et	0	cKUAfXynZ
ka	doc_881665289253_item	3702135	et	0	cKUAfXynZ
väljend-	doc_881665289253_item	3702136	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702137	et	0	cKUAfXynZ
ühendverbid	doc_881665289253_item	3702138	et	0	cKUAfXynZ
vormiklassidest	doc_881665289253_item	3702139	et	0	cKUAfXynZ
so	doc_881665289253_item	3702140	et	0	cKUAfXynZ
ühe	doc_881665289253_item	3702141	et	0	cKUAfXynZ
grammatilise	doc_881665289253_item	3702142	et	0	cKUAfXynZ
vormi	doc_881665289253_item	3702143	et	0	cKUAfXynZ
erinevate	doc_881665289253_item	3702144	et	0	cKUAfXynZ
morfoloogiliste	doc_881665289253_item	3702145	et	0	cKUAfXynZ
variandite	doc_881665289253_item	3702146	et	0	cKUAfXynZ
üldistus	doc_881665289253_item	3702147	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3702148	et	0	cKUAfXynZ
lk	doc_881665289253_item	3702149	et	0	cKUAfXynZ
40	doc_881665289253_item	3702150	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3702151	et	0	cKUAfXynZ
laiendite	doc_881665289253_item	3702152	et	0	cKUAfXynZ
substitutsiooniklassid	doc_881665289253_item	3702153	et	0	cKUAfXynZ
on	doc_881665289253_item	3702154	et	0	cKUAfXynZ
iseloomustatud	doc_881665289253_item	3702155	et	0	cKUAfXynZ
üldisemate	doc_881665289253_item	3702156	et	0	cKUAfXynZ
grammatilis-semantiliste	doc_881665289253_item	3702157	et	0	cKUAfXynZ
tunnustega	doc_881665289253_item	3702158	et	0	cKUAfXynZ
sellel	doc_881665289253_item	3702159	et	0	cKUAfXynZ
juhul	doc_881665289253_item	3702160	et	0	cKUAfXynZ
ei	doc_881665289253_item	3702161	et	0	cKUAfXynZ
ole	doc_881665289253_item	3702162	et	0	cKUAfXynZ
grammatiline	doc_881665289253_item	3702163	et	0	cKUAfXynZ
vorm	doc_881665289253_item	3702164	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702165	et	0	cKUAfXynZ
vormiklassi	doc_881665289253_item	3702166	et	0	cKUAfXynZ
valik	doc_881665289253_item	3702167	et	0	cKUAfXynZ
tingitud	doc_881665289253_item	3702168	et	0	cKUAfXynZ
ainult	doc_881665289253_item	3702169	et	0	cKUAfXynZ
verbist	doc_881665289253_item	3702170	et	0	cKUAfXynZ
vaid	doc_881665289253_item	3702171	et	0	cKUAfXynZ
ka	doc_881665289253_item	3702172	et	0	cKUAfXynZ
lause	doc_881665289253_item	3702173	et	0	cKUAfXynZ
tähendusest	doc_881665289253_item	3702174	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702175	et	0	cKUAfXynZ
kohakäänete	doc_881665289253_item	3702176	et	0	cKUAfXynZ
valikust	doc_881665289253_item	3702177	et	0	cKUAfXynZ
direktsionaalid	doc_881665289253_item	3702178	et	0	cKUAfXynZ
on	doc_881665289253_item	3702179	et	0	cKUAfXynZ
jagatud	doc_881665289253_item	3702180	et	0	cKUAfXynZ
ekstralokaalseteks	doc_881665289253_item	3702181	et	0	cKUAfXynZ
de	doc_881665289253_item	3702182	et	0	cKUAfXynZ
kust-suund	doc_881665289253_item	3702183	et	0	cKUAfXynZ
nelablpartgenadverbid	doc_881665289253_item	3702184	et	0	cKUAfXynZ
alt	doc_881665289253_item	3702185	et	0	cKUAfXynZ
eest	doc_881665289253_item	3702186	et	0	cKUAfXynZ
kõrvalt	doc_881665289253_item	3702187	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702188	et	0	cKUAfXynZ
intralokaaseteks	doc_881665289253_item	3702189	et	0	cKUAfXynZ
di	doc_881665289253_item	3702190	et	0	cKUAfXynZ
kuhu-suund	doc_881665289253_item	3702191	et	0	cKUAfXynZ
nillallgenadverbid	doc_881665289253_item	3702192	et	0	cKUAfXynZ
ette	doc_881665289253_item	3702193	et	0	cKUAfXynZ
asemele	doc_881665289253_item	3702194	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702195	et	0	cKUAfXynZ
jt	doc_881665289253_item	3702196	et	0	cKUAfXynZ
mallid	doc_881665289253_item	3702197	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702198	et	0	cKUAfXynZ
translokaalseteks	doc_881665289253_item	3702199	et	0	cKUAfXynZ
dt	doc_881665289253_item	3702200	et	0	cKUAfXynZ
ngenadverbid	doc_881665289253_item	3702201	et	0	cKUAfXynZ
mööda	doc_881665289253_item	3702202	et	0	cKUAfXynZ
kaudu	doc_881665289253_item	3702203	et	0	cKUAfXynZ
jm	doc_881665289253_item	3702204	et	0	cKUAfXynZ
partadverbid	doc_881665289253_item	3702205	et	0	cKUAfXynZ
mööda	doc_881665289253_item	3702206	et	0	cKUAfXynZ
pidi	doc_881665289253_item	3702207	et	0	cKUAfXynZ
jm	doc_881665289253_item	3702208	et	0	cKUAfXynZ
mille	doc_881665289253_item	3702209	et	0	cKUAfXynZ
liikmed	doc_881665289253_item	3702210	et	0	cKUAfXynZ
osutavad	doc_881665289253_item	3702211	et	0	cKUAfXynZ
kohta	doc_881665289253_item	3702212	et	0	cKUAfXynZ
vahepealset	doc_881665289253_item	3702213	et	0	cKUAfXynZ
ala	doc_881665289253_item	3702214	et	0	cKUAfXynZ
teed	doc_881665289253_item	3702215	et	0	cKUAfXynZ
lähtepunkti	doc_881665289253_item	3702216	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702217	et	0	cKUAfXynZ
lõpp-punkti	doc_881665289253_item	3702218	et	0	cKUAfXynZ
vhel	doc_881665289253_item	3702219	et	0	cKUAfXynZ
mida	doc_881665289253_item	3702220	et	0	cKUAfXynZ
mingist	doc_881665289253_item	3702221	et	0	cKUAfXynZ
tegevusest	doc_881665289253_item	3702222	et	0	cKUAfXynZ
osavõttev	doc_881665289253_item	3702223	et	0	cKUAfXynZ
objekt	doc_881665289253_item	3702224	et	0	cKUAfXynZ
läbib	doc_881665289253_item	3702225	et	0	cKUAfXynZ
mida	doc_881665289253_item	3702226	et	0	cKUAfXynZ
mööda	doc_881665289253_item	3702227	et	0	cKUAfXynZ
ta	doc_881665289253_item	3702228	et	0	cKUAfXynZ
liigub	doc_881665289253_item	3702229	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3702230	et	0	cKUAfXynZ
lk	doc_881665289253_item	3702231	et	0	cKUAfXynZ
46	doc_881665289253_item	3702232	et	0	cKUAfXynZ
seisundimodaalid	doc_881665289253_item	3702233	et	0	cKUAfXynZ
jagunevad	doc_881665289253_item	3702234	et	0	cKUAfXynZ
järgmiselt	doc_881665289253_item	3702235	et	0	cKUAfXynZ
modl	doc_881665289253_item	3702236	et	0	cKUAfXynZ
1	doc_881665289253_item	3702237	et	0	cKUAfXynZ
alasti	doc_881665289253_item	3702238	et	0	cKUAfXynZ
harkis	doc_881665289253_item	3702239	et	0	cKUAfXynZ
purjus	doc_881665289253_item	3702240	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702241	et	0	cKUAfXynZ
l	doc_881665289253_item	3702242	et	0	cKUAfXynZ
o	doc_881665289253_item	3702243	et	0	cKUAfXynZ
k	doc_881665289253_item	3702244	et	0	cKUAfXynZ
a	doc_881665289253_item	3702245	et	0	cKUAfXynZ
a	doc_881665289253_item	3702246	et	0	cKUAfXynZ
l	doc_881665289253_item	3702247	et	0	cKUAfXynZ
s	doc_881665289253_item	3702248	et	0	cKUAfXynZ
e	doc_881665289253_item	3702249	et	0	cKUAfXynZ
d	doc_881665289253_item	3702250	et	0	cKUAfXynZ
modl	doc_881665289253_item	3702251	et	0	cKUAfXynZ
modl	doc_881665289253_item	3702252	et	0	cKUAfXynZ
2	doc_881665289253_item	3702253	et	0	cKUAfXynZ
kukili	doc_881665289253_item	3702254	et	0	cKUAfXynZ
selili	doc_881665289253_item	3702255	et	0	cKUAfXynZ
viltu	doc_881665289253_item	3702256	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702257	et	0	cKUAfXynZ
modl	doc_881665289253_item	3702258	et	0	cKUAfXynZ
3	doc_881665289253_item	3702259	et	0	cKUAfXynZ
kõrvu	doc_881665289253_item	3702260	et	0	cKUAfXynZ
risii	doc_881665289253_item	3702261	et	0	cKUAfXynZ
vastastikku	doc_881665289253_item	3702262	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702263	et	0	cKUAfXynZ
seisundimodaalid	doc_881665289253_item	3702264	et	0	cKUAfXynZ
nnom	doc_881665289253_item	3702265	et	0	cKUAfXynZ
verb	doc_881665289253_item	3702266	et	0	cKUAfXynZ
mod	doc_881665289253_item	3702267	et	0	cKUAfXynZ
modi	doc_881665289253_item	3702268	et	0	cKUAfXynZ
1	doc_881665289253_item	3702269	et	0	cKUAfXynZ
alasti	doc_881665289253_item	3702270	et	0	cKUAfXynZ
harki	doc_881665289253_item	3702271	et	0	cKUAfXynZ
purju	doc_881665289253_item	3702272	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702273	et	0	cKUAfXynZ
i	doc_881665289253_item	3702274	et	0	cKUAfXynZ
n	doc_881665289253_item	3702275	et	0	cKUAfXynZ
t	doc_881665289253_item	3702276	et	0	cKUAfXynZ
r	doc_881665289253_item	3702277	et	0	cKUAfXynZ
a	doc_881665289253_item	3702278	et	0	cKUAfXynZ
l	doc_881665289253_item	3702279	et	0	cKUAfXynZ
o	doc_881665289253_item	3702280	et	0	cKUAfXynZ
k	doc_881665289253_item	3702281	et	0	cKUAfXynZ
a	doc_881665289253_item	3702282	et	0	cKUAfXynZ
a	doc_881665289253_item	3702283	et	0	cKUAfXynZ
l	doc_881665289253_item	3702284	et	0	cKUAfXynZ
s	doc_881665289253_item	3702285	et	0	cKUAfXynZ
e	doc_881665289253_item	3702286	et	0	cKUAfXynZ
d	doc_881665289253_item	3702287	et	0	cKUAfXynZ
modi	doc_881665289253_item	3702288	et	0	cKUAfXynZ
modi	doc_881665289253_item	3702289	et	0	cKUAfXynZ
2	doc_881665289253_item	3702290	et	0	cKUAfXynZ
kukili	doc_881665289253_item	3702291	et	0	cKUAfXynZ
selili	doc_881665289253_item	3702292	et	0	cKUAfXynZ
viltu	doc_881665289253_item	3702293	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702294	et	0	cKUAfXynZ
modi	doc_881665289253_item	3702295	et	0	cKUAfXynZ
3	doc_881665289253_item	3702296	et	0	cKUAfXynZ
kõrvu	doc_881665289253_item	3702297	et	0	cKUAfXynZ
risti	doc_881665289253_item	3702298	et	0	cKUAfXynZ
vastastikku	doc_881665289253_item	3702299	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702300	et	0	cKUAfXynZ
vabade	doc_881665289253_item	3702301	et	0	cKUAfXynZ
laiendite	doc_881665289253_item	3702302	et	0	cKUAfXynZ
substitutsiooniklass	doc_881665289253_item	3702303	et	0	cKUAfXynZ
on	doc_881665289253_item	3702304	et	0	cKUAfXynZ
fakultatiivne	doc_881665289253_item	3702305	et	0	cKUAfXynZ
ning	doc_881665289253_item	3702306	et	0	cKUAfXynZ
seda	doc_881665289253_item	3702307	et	0	cKUAfXynZ
ei	doc_881665289253_item	3702308	et	0	cKUAfXynZ
määratleta	doc_881665289253_item	3702309	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3702310	et	0	cKUAfXynZ
lausemalli	doc_881665289253_item	3702311	et	0	cKUAfXynZ
elemendite	doc_881665289253_item	3702312	et	0	cKUAfXynZ
hulka	doc_881665289253_item	3702313	et	0	cKUAfXynZ
kuid	doc_881665289253_item	3702314	et	0	cKUAfXynZ
tähelepanu	doc_881665289253_item	3702315	et	0	cKUAfXynZ
väärivad	doc_881665289253_item	3702316	et	0	cKUAfXynZ
juhtumid	doc_881665289253_item	3702317	et	0	cKUAfXynZ
milledel	doc_881665289253_item	3702318	et	0	cKUAfXynZ
see	doc_881665289253_item	3702319	et	0	cKUAfXynZ
ikkagi	doc_881665289253_item	3702320	et	0	cKUAfXynZ
on	doc_881665289253_item	3702321	et	0	cKUAfXynZ
obligatoorne	doc_881665289253_item	3702322	et	0	cKUAfXynZ
nt	doc_881665289253_item	3702323	et	0	cKUAfXynZ
isa	doc_881665289253_item	3702324	et	0	cKUAfXynZ
jäi	doc_881665289253_item	3702325	et	0	cKUAfXynZ
üksinda	doc_881665289253_item	3702326	et	0	cKUAfXynZ
üksinda	doc_881665289253_item	3702327	et	0	cKUAfXynZ
on	doc_881665289253_item	3702328	et	0	cKUAfXynZ
obligatoorne	doc_881665289253_item	3702329	et	0	cKUAfXynZ
vaba	doc_881665289253_item	3702330	et	0	cKUAfXynZ
laiend	doc_881665289253_item	3702331	et	0	cKUAfXynZ
aga	doc_881665289253_item	3702332	et	0	cKUAfXynZ
mõlemal	doc_881665289253_item	3702333	et	0	cKUAfXynZ
juhul	doc_881665289253_item	3702334	et	0	cKUAfXynZ
võib	doc_881665289253_item	3702335	et	0	cKUAfXynZ
siiski	doc_881665289253_item	3702336	et	0	cKUAfXynZ
esineda	doc_881665289253_item	3702337	et	0	cKUAfXynZ
koos	doc_881665289253_item	3702338	et	0	cKUAfXynZ
iga	doc_881665289253_item	3702339	et	0	cKUAfXynZ
verbiga	doc_881665289253_item	3702340	et	0	cKUAfXynZ
vabade	doc_881665289253_item	3702341	et	0	cKUAfXynZ
laiendite	doc_881665289253_item	3702342	et	0	cKUAfXynZ
obligatoorsed	doc_881665289253_item	3702343	et	0	cKUAfXynZ
substitasiooniklassid	doc_881665289253_item	3702344	et	0	cKUAfXynZ
on	doc_881665289253_item	3702345	et	0	cKUAfXynZ
lokaal	doc_881665289253_item	3702346	et	0	cKUAfXynZ
loc	doc_881665289253_item	3702347	et	0	cKUAfXynZ
näideverb	doc_881665289253_item	3702348	et	0	cKUAfXynZ
asetseda	doc_881665289253_item	3702349	et	0	cKUAfXynZ
ninadgen	doc_881665289253_item	3702350	et	0	cKUAfXynZ
adverbid	doc_881665289253_item	3702351	et	0	cKUAfXynZ
all	doc_881665289253_item	3702352	et	0	cKUAfXynZ
allpool	doc_881665289253_item	3702353	et	0	cKUAfXynZ
asemel	doc_881665289253_item	3702354	et	0	cKUAfXynZ
paremal	doc_881665289253_item	3702355	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702356	et	0	cKUAfXynZ
modaal	doc_881665289253_item	3702357	et	0	cKUAfXynZ
mod	doc_881665289253_item	3702358	et	0	cKUAfXynZ
näideverb	doc_881665289253_item	3702359	et	0	cKUAfXynZ
suhtuma	doc_881665289253_item	3702360	et	0	cKUAfXynZ
nesskomgen	doc_881665289253_item	3702361	et	0	cKUAfXynZ
adverbid	doc_881665289253_item	3702362	et	0	cKUAfXynZ
kombel	doc_881665289253_item	3702363	et	0	cKUAfXynZ
moodi	doc_881665289253_item	3702364	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702365	et	0	cKUAfXynZ
a	doc_881665289253_item	3702366	et	0	cKUAfXynZ
part	doc_881665289253_item	3702367	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702368	et	0	cKUAfXynZ
temporaal	doc_881665289253_item	3702369	et	0	cKUAfXynZ
temp	doc_881665289253_item	3702370	et	0	cKUAfXynZ
näideverb	doc_881665289253_item	3702371	et	0	cKUAfXynZ
juhtuma	doc_881665289253_item	3702372	et	0	cKUAfXynZ
ninadgen	doc_881665289253_item	3702373	et	0	cKUAfXynZ
adverbid	doc_881665289253_item	3702374	et	0	cKUAfXynZ
aegu	doc_881665289253_item	3702375	et	0	cKUAfXynZ
keskel	doc_881665289253_item	3702376	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702377	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702378	et	0	cKUAfXynZ
mesuraaltemporaal	doc_881665289253_item	3702379	et	0	cKUAfXynZ
tempmes	doc_881665289253_item	3702380	et	0	cKUAfXynZ
näideverb	doc_881665289253_item	3702381	et	0	cKUAfXynZ
väldama	doc_881665289253_item	3702382	et	0	cKUAfXynZ
ngentermnom	doc_881665289253_item	3702383	et	0	cKUAfXynZ
mesuraal	doc_881665289253_item	3702384	et	0	cKUAfXynZ
mes	doc_881665289253_item	3702385	et	0	cKUAfXynZ
numnom	doc_881665289253_item	3702386	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702387	et	0	cKUAfXynZ
distributsionaal	doc_881665289253_item	3702388	et	0	cKUAfXynZ
distr	doc_881665289253_item	3702389	et	0	cKUAfXynZ
liikmeteks	doc_881665289253_item	3702390	et	0	cKUAfXynZ
on	doc_881665289253_item	3702391	et	0	cKUAfXynZ
üksi	doc_881665289253_item	3702392	et	0	cKUAfXynZ
kahekesi	doc_881665289253_item	3702393	et	0	cKUAfXynZ
mitmekesi	doc_881665289253_item	3702394	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702395	et	0	cKUAfXynZ
nnom	doc_881665289253_item	3702396	et	0	cKUAfXynZ
frekventaal	doc_881665289253_item	3702397	et	0	cKUAfXynZ
frekv	doc_881665289253_item	3702398	et	0	cKUAfXynZ
liikmed	doc_881665289253_item	3702399	et	0	cKUAfXynZ
on	doc_881665289253_item	3702400	et	0	cKUAfXynZ
harva	doc_881665289253_item	3702401	et	0	cKUAfXynZ
jälle	doc_881665289253_item	3702402	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702403	et	0	cKUAfXynZ
ning	doc_881665289253_item	3702404	et	0	cKUAfXynZ
skeem	doc_881665289253_item	3702405	et	0	cKUAfXynZ
nnom	doc_881665289253_item	3702406	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702407	et	0	cKUAfXynZ
kausaal	doc_881665289253_item	3702408	et	0	cKUAfXynZ
ngen	doc_881665289253_item	3702409	et	0	cKUAfXynZ
tõttutagajärjel	doc_881665289253_item	3702410	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702411	et	0	cKUAfXynZ
kõrvallauseid	doc_881665289253_item	3702412	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3702413	et	0	cKUAfXynZ
laiendite	doc_881665289253_item	3702414	et	0	cKUAfXynZ
klassina	doc_881665289253_item	3702415	et	0	cKUAfXynZ
eristatakse	doc_881665289253_item	3702416	et	0	cKUAfXynZ
verbist	doc_881665289253_item	3702417	et	0	cKUAfXynZ
tingitud	doc_881665289253_item	3702418	et	0	cKUAfXynZ
lauseteks	doc_881665289253_item	3702419	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702420	et	0	cKUAfXynZ
kogu	doc_881665289253_item	3702421	et	0	cKUAfXynZ
lausest	doc_881665289253_item	3702422	et	0	cKUAfXynZ
tingitud	doc_881665289253_item	3702423	et	0	cKUAfXynZ
tervikuteks	doc_881665289253_item	3702424	et	0	cKUAfXynZ
ka	doc_881665289253_item	3702425	et	0	cKUAfXynZ
otsest	doc_881665289253_item	3702426	et	0	cKUAfXynZ
kõnet	doc_881665289253_item	3702427	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702428	et	0	cKUAfXynZ
mõnel	doc_881665289253_item	3702429	et	0	cKUAfXynZ
juhul	doc_881665289253_item	3702430	et	0	cKUAfXynZ
tavalist	doc_881665289253_item	3702431	et	0	cKUAfXynZ
lauset	doc_881665289253_item	3702432	et	0	cKUAfXynZ
nt	doc_881665289253_item	3702433	et	0	cKUAfXynZ
lauses	doc_881665289253_item	3702434	et	0	cKUAfXynZ
jaan	doc_881665289253_item	3702435	et	0	cKUAfXynZ
võttis	doc_881665289253_item	3702436	et	0	cKUAfXynZ
kätte	doc_881665289253_item	3702437	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702438	et	0	cKUAfXynZ
läks	doc_881665289253_item	3702439	et	0	cKUAfXynZ
asja	doc_881665289253_item	3702440	et	0	cKUAfXynZ
ise	doc_881665289253_item	3702441	et	0	cKUAfXynZ
vaatama	doc_881665289253_item	3702442	et	0	cKUAfXynZ
põhjuseks	doc_881665289253_item	3702443	et	0	cKUAfXynZ
on	doc_881665289253_item	3702444	et	0	cKUAfXynZ
lause	doc_881665289253_item	3702445	et	0	cKUAfXynZ
jaan	doc_881665289253_item	3702446	et	0	cKUAfXynZ
võttis	doc_881665289253_item	3702447	et	0	cKUAfXynZ
kätte	doc_881665289253_item	3702448	et	0	cKUAfXynZ
ebaloogilisus	doc_881665289253_item	3702449	et	0	cKUAfXynZ
vaadeldatakse	doc_881665289253_item	3702450	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3702451	et	0	cKUAfXynZ
laiendite	doc_881665289253_item	3702452	et	0	cKUAfXynZ
klassidena	doc_881665289253_item	3702453	et	0	cKUAfXynZ
monograafias	doc_881665289253_item	3702454	et	0	cKUAfXynZ
väidetakse	doc_881665289253_item	3702455	et	0	cKUAfXynZ
et	doc_881665289253_item	3702456	et	0	cKUAfXynZ
possessiivsed	doc_881665289253_item	3702457	et	0	cKUAfXynZ
allatiivi-	doc_881665289253_item	3702458	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702459	et	0	cKUAfXynZ
adessiivivormid	doc_881665289253_item	3702460	et	0	cKUAfXynZ
samuti	doc_881665289253_item	3702461	et	0	cKUAfXynZ
kuuluvad	doc_881665289253_item	3702462	et	0	cKUAfXynZ
verbikesksesse	doc_881665289253_item	3702463	et	0	cKUAfXynZ
lausemalli	doc_881665289253_item	3702464	et	0	cKUAfXynZ
lahutamatu	doc_881665289253_item	3702465	et	0	cKUAfXynZ
s	doc_881665289253_item	3702466	et	0	cKUAfXynZ
o	doc_881665289253_item	3702467	et	0	cKUAfXynZ
tavaliselt	doc_881665289253_item	3702468	et	0	cKUAfXynZ
osade	doc_881665289253_item	3702469	et	0	cKUAfXynZ
nimetused	doc_881665289253_item	3702470	et	0	cKUAfXynZ
või	doc_881665289253_item	3702471	et	0	cKUAfXynZ
sugulusnimetused	doc_881665289253_item	3702472	et	0	cKUAfXynZ
või	doc_881665289253_item	3702473	et	0	cKUAfXynZ
lahutatava	doc_881665289253_item	3702474	et	0	cKUAfXynZ
omadusena	doc_881665289253_item	3702475	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3702476	et	0	cKUAfXynZ
lk	doc_881665289253_item	3702477	et	0	cKUAfXynZ
60	doc_881665289253_item	3702478	et	0	cKUAfXynZ
3	doc_881665289253_item	3702479	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3702480	et	0	cKUAfXynZ
laiendite	doc_881665289253_item	3702481	et	0	cKUAfXynZ
vahekord	doc_881665289253_item	3702482	et	0	cKUAfXynZ
verbiga	doc_881665289253_item	3702483	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3702484	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702485	et	0	cKUAfXynZ
selle	doc_881665289253_item	3702486	et	0	cKUAfXynZ
laiendite	doc_881665289253_item	3702487	et	0	cKUAfXynZ
vahelise	doc_881665289253_item	3702488	et	0	cKUAfXynZ
vahekorda	doc_881665289253_item	3702489	et	0	cKUAfXynZ
analüüsiks	doc_881665289253_item	3702490	et	0	cKUAfXynZ
on	doc_881665289253_item	3702491	et	0	cKUAfXynZ
vaja	doc_881665289253_item	3702492	et	0	cKUAfXynZ
välja	doc_881665289253_item	3702493	et	0	cKUAfXynZ
selgitada	doc_881665289253_item	3702494	et	0	cKUAfXynZ
selle	doc_881665289253_item	3702495	et	0	cKUAfXynZ
vahekorra	doc_881665289253_item	3702496	et	0	cKUAfXynZ
seose	doc_881665289253_item	3702497	et	0	cKUAfXynZ
traditsioonilise	doc_881665289253_item	3702498	et	0	cKUAfXynZ
keeleõpetuse	doc_881665289253_item	3702499	et	0	cKUAfXynZ
mõistetega	doc_881665289253_item	3702500	et	0	cKUAfXynZ
ühindades	doc_881665289253_item	3702501	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702502	et	0	cKUAfXynZ
piirades	doc_881665289253_item	3702503	et	0	cKUAfXynZ
eri	doc_881665289253_item	3702504	et	0	cKUAfXynZ
autorite	doc_881665289253_item	3702505	et	0	cKUAfXynZ
definitsioone	doc_881665289253_item	3702506	et	0	cKUAfXynZ
sh	doc_881665289253_item	3702507	et	0	cKUAfXynZ
kuuluvad	doc_881665289253_item	3702508	et	0	cKUAfXynZ
aaviku	doc_881665289253_item	3702509	et	0	cKUAfXynZ
muugi	doc_881665289253_item	3702510	et	0	cKUAfXynZ
tedre	doc_881665289253_item	3702511	et	0	cKUAfXynZ
mihkla	doc_881665289253_item	3702512	et	0	cKUAfXynZ
remmeli	doc_881665289253_item	3702513	et	0	cKUAfXynZ
valgma	doc_881665289253_item	3702514	et	0	cKUAfXynZ
jt	doc_881665289253_item	3702515	et	0	cKUAfXynZ
definitsioonid	doc_881665289253_item	3702516	et	0	cKUAfXynZ
töös	doc_881665289253_item	3702517	et	0	cKUAfXynZ
tuuakse	doc_881665289253_item	3702518	et	0	cKUAfXynZ
ühe	doc_881665289253_item	3702519	et	0	cKUAfXynZ
enam	doc_881665289253_item	3702520	et	0	cKUAfXynZ
täielikuma	doc_881665289253_item	3702521	et	0	cKUAfXynZ
definitsiooni	doc_881665289253_item	3702522	et	0	cKUAfXynZ
rektsioon	doc_881665289253_item	3702523	et	0	cKUAfXynZ
ehk	doc_881665289253_item	3702524	et	0	cKUAfXynZ
sõltumine	doc_881665289253_item	3702525	et	0	cKUAfXynZ
on	doc_881665289253_item	3702526	et	0	cKUAfXynZ
selline	doc_881665289253_item	3702527	et	0	cKUAfXynZ
alistav	doc_881665289253_item	3702528	et	0	cKUAfXynZ
süntaktiline	doc_881665289253_item	3702529	et	0	cKUAfXynZ
vahekord	doc_881665289253_item	3702530	et	0	cKUAfXynZ
põhisõna	doc_881665289253_item	3702531	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702532	et	0	cKUAfXynZ
laiendi	doc_881665289253_item	3702533	et	0	cKUAfXynZ
vahel	doc_881665289253_item	3702534	et	0	cKUAfXynZ
kus	doc_881665289253_item	3702535	et	0	cKUAfXynZ
põhisõna	doc_881665289253_item	3702536	et	0	cKUAfXynZ
kui	doc_881665289253_item	3702537	et	0	cKUAfXynZ
regeeriva	doc_881665289253_item	3702538	et	0	cKUAfXynZ
sõna	doc_881665289253_item	3702539	et	0	cKUAfXynZ
semantilised	doc_881665289253_item	3702540	et	0	cKUAfXynZ
omadused	doc_881665289253_item	3702541	et	0	cKUAfXynZ
võt	doc_881665289253_item	3702542	et	0	cKUAfXynZ
tähendus	doc_881665289253_item	3702543	et	0	cKUAfXynZ
tervikuna	doc_881665289253_item	3702544	et	0	cKUAfXynZ
tingivad	doc_881665289253_item	3702545	et	0	cKUAfXynZ
laiendi	doc_881665289253_item	3702546	et	0	cKUAfXynZ
grammatilise	doc_881665289253_item	3702547	et	0	cKUAfXynZ
võrmi	doc_881665289253_item	3702548	et	0	cKUAfXynZ
või	doc_881665289253_item	3702549	et	0	cKUAfXynZ
selle	doc_881665289253_item	3702550	et	0	cKUAfXynZ
laiendi	doc_881665289253_item	3702551	et	0	cKUAfXynZ
kuulumise	doc_881665289253_item	3702552	et	0	cKUAfXynZ
teatud	doc_881665289253_item	3702553	et	0	cKUAfXynZ
kindla	doc_881665289253_item	3702554	et	0	cKUAfXynZ
grammatilise	doc_881665289253_item	3702555	et	0	cKUAfXynZ
tunnusega	doc_881665289253_item	3702556	et	0	cKUAfXynZ
klassi	doc_881665289253_item	3702557	et	0	cKUAfXynZ
substitutsiooniklaasi	doc_881665289253_item	3702558	et	0	cKUAfXynZ
sealsamas	doc_881665289253_item	3702559	et	0	cKUAfXynZ
lk	doc_881665289253_item	3702560	et	0	cKUAfXynZ
64	doc_881665289253_item	3702561	et	0	cKUAfXynZ
ühteviisi	doc_881665289253_item	3702562	et	0	cKUAfXynZ
rektsiooni	doc_881665289253_item	3702563	et	0	cKUAfXynZ
mõistega	doc_881665289253_item	3702564	et	0	cKUAfXynZ
kuulub	doc_881665289253_item	3702565	et	0	cKUAfXynZ
määrava	doc_881665289253_item	3702566	et	0	cKUAfXynZ
iseloomuga	doc_881665289253_item	3702567	et	0	cKUAfXynZ
alistava	doc_881665289253_item	3702568	et	0	cKUAfXynZ
vahekorda	doc_881665289253_item	3702569	et	0	cKUAfXynZ
ka	doc_881665289253_item	3702570	et	0	cKUAfXynZ
kongruents	doc_881665289253_item	3702571	et	0	cKUAfXynZ
ehk	doc_881665289253_item	3702572	et	0	cKUAfXynZ
ühildamine	doc_881665289253_item	3702573	et	0	cKUAfXynZ
ning	doc_881665289253_item	3702574	et	0	cKUAfXynZ
sel	doc_881665289253_item	3702575	et	0	cKUAfXynZ
juhul	doc_881665289253_item	3702576	et	0	cKUAfXynZ
on	doc_881665289253_item	3702577	et	0	cKUAfXynZ
laiendi	doc_881665289253_item	3702578	et	0	cKUAfXynZ
vorm	doc_881665289253_item	3702579	et	0	cKUAfXynZ
tingitud	doc_881665289253_item	3702580	et	0	cKUAfXynZ
määrava	doc_881665289253_item	3702581	et	0	cKUAfXynZ
põhisõna	doc_881665289253_item	3702582	et	0	cKUAfXynZ
grammatilisest	doc_881665289253_item	3702583	et	0	cKUAfXynZ
võrmist	doc_881665289253_item	3702584	et	0	cKUAfXynZ
nt	doc_881665289253_item	3702585	et	0	cKUAfXynZ
lauses	doc_881665289253_item	3702586	et	0	cKUAfXynZ
kirjutage	doc_881665289253_item	3702587	et	0	cKUAfXynZ
kiri	doc_881665289253_item	3702588	et	0	cKUAfXynZ
laiendi	doc_881665289253_item	3702589	et	0	cKUAfXynZ
kääne	doc_881665289253_item	3702590	et	0	cKUAfXynZ
nominatiiv	doc_881665289253_item	3702591	et	0	cKUAfXynZ
on	doc_881665289253_item	3702592	et	0	cKUAfXynZ
määratud	doc_881665289253_item	3702593	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3702594	et	0	cKUAfXynZ
imperatiiviga	doc_881665289253_item	3702595	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3702596	et	0	cKUAfXynZ
lausemallide	doc_881665289253_item	3702597	et	0	cKUAfXynZ
edaspidiseks	doc_881665289253_item	3702598	et	0	cKUAfXynZ
käsitlemiseks	doc_881665289253_item	3702599	et	0	cKUAfXynZ
autor	doc_881665289253_item	3702600	et	0	cKUAfXynZ
selgitab	doc_881665289253_item	3702601	et	0	cKUAfXynZ
välja	doc_881665289253_item	3702602	et	0	cKUAfXynZ
millise	doc_881665289253_item	3702603	et	0	cKUAfXynZ
antud	doc_881665289253_item	3702604	et	0	cKUAfXynZ
ajalooperioodi	doc_881665289253_item	3702605	et	0	cKUAfXynZ
süntaksiarenemise	doc_881665289253_item	3702606	et	0	cKUAfXynZ
etapiks	doc_881665289253_item	3702607	et	0	cKUAfXynZ
ilmunud	doc_881665289253_item	3702608	et	0	cKUAfXynZ
valentsiteooriaga	doc_881665289253_item	3702609	et	0	cKUAfXynZ
ta	doc_881665289253_item	3702610	et	0	cKUAfXynZ
hakkab	doc_881665289253_item	3702611	et	0	cKUAfXynZ
arvestama	doc_881665289253_item	3702612	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702613	et	0	cKUAfXynZ
milliste	doc_881665289253_item	3702614	et	0	cKUAfXynZ
tingimustega	doc_881665289253_item	3702615	et	0	cKUAfXynZ
ta	doc_881665289253_item	3702616	et	0	cKUAfXynZ
seda	doc_881665289253_item	3702617	et	0	cKUAfXynZ
kasutab	doc_881665289253_item	3702618	et	0	cKUAfXynZ
g	doc_881665289253_item	3702619	et	0	cKUAfXynZ
helbigi	doc_881665289253_item	3702620	et	0	cKUAfXynZ
a	doc_881665289253_item	3702621	et	0	cKUAfXynZ
holodovitši	doc_881665289253_item	3702622	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702623	et	0	cKUAfXynZ
l	doc_881665289253_item	3702624	et	0	cKUAfXynZ
tesnièrei	doc_881665289253_item	3702625	et	0	cKUAfXynZ
valentsimõistete	doc_881665289253_item	3702626	et	0	cKUAfXynZ
vahel	doc_881665289253_item	3702627	et	0	cKUAfXynZ
töös	doc_881665289253_item	3702628	et	0	cKUAfXynZ
eelistatakse	doc_881665289253_item	3702629	et	0	cKUAfXynZ
viimase	doc_881665289253_item	3702630	et	0	cKUAfXynZ
kolmikjaotuse	doc_881665289253_item	3702631	et	0	cKUAfXynZ
verb	doc_881665289253_item	3702632	et	0	cKUAfXynZ
keskel	doc_881665289253_item	3702633	et	0	cKUAfXynZ
aktandid	doc_881665289253_item	3702634	et	0	cKUAfXynZ
vastavad	doc_881665289253_item	3702635	et	0	cKUAfXynZ
näitlejaile	doc_881665289253_item	3702636	et	0	cKUAfXynZ
substantiivid	doc_881665289253_item	3702637	et	0	cKUAfXynZ
või	doc_881665289253_item	3702638	et	0	cKUAfXynZ
substantiivi	doc_881665289253_item	3702639	et	0	cKUAfXynZ
ekvivalendid	doc_881665289253_item	3702640	et	0	cKUAfXynZ
sirkonstandid	doc_881665289253_item	3702641	et	0	cKUAfXynZ
vastavad	doc_881665289253_item	3702642	et	0	cKUAfXynZ
olukordadele	doc_881665289253_item	3702643	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702644	et	0	cKUAfXynZ
asjaoludele	doc_881665289253_item	3702645	et	0	cKUAfXynZ
ning	doc_881665289253_item	3702646	et	0	cKUAfXynZ
alati	doc_881665289253_item	3702647	et	0	cKUAfXynZ
alluvad	doc_881665289253_item	3702648	et	0	cKUAfXynZ
verbile	doc_881665289253_item	3702649	et	0	cKUAfXynZ
lähtudes	doc_881665289253_item	3702650	et	0	cKUAfXynZ
sellest	doc_881665289253_item	3702651	et	0	cKUAfXynZ
on	doc_881665289253_item	3702652	et	0	cKUAfXynZ
valentsus	doc_881665289253_item	3702653	et	0	cKUAfXynZ
võimalikke	doc_881665289253_item	3702654	et	0	cKUAfXynZ
aktandidega	doc_881665289253_item	3702655	et	0	cKUAfXynZ
seoste	doc_881665289253_item	3702656	et	0	cKUAfXynZ
arv	doc_881665289253_item	3702657	et	0	cKUAfXynZ
verbil	doc_881665289253_item	3702658	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702659	et	0	cKUAfXynZ
vastavalt	doc_881665289253_item	3702660	et	0	cKUAfXynZ
sellele	doc_881665289253_item	3702661	et	0	cKUAfXynZ
verb	doc_881665289253_item	3702662	et	0	cKUAfXynZ
võib	doc_881665289253_item	3702663	et	0	cKUAfXynZ
olla	doc_881665289253_item	3702664	et	0	cKUAfXynZ
nullvalente	doc_881665289253_item	3702665	et	0	cKUAfXynZ
monovalentne	doc_881665289253_item	3702666	et	0	cKUAfXynZ
divalentne	doc_881665289253_item	3702667	et	0	cKUAfXynZ
või	doc_881665289253_item	3702668	et	0	cKUAfXynZ
trivalentne	doc_881665289253_item	3702669	et	0	cKUAfXynZ
ent	doc_881665289253_item	3702670	et	0	cKUAfXynZ
seda	doc_881665289253_item	3702671	et	0	cKUAfXynZ
viimast	doc_881665289253_item	3702672	et	0	cKUAfXynZ
seiku	doc_881665289253_item	3702673	et	0	cKUAfXynZ
autor	doc_881665289253_item	3702674	et	0	cKUAfXynZ
jätab	doc_881665289253_item	3702675	et	0	cKUAfXynZ
oma	doc_881665289253_item	3702676	et	0	cKUAfXynZ
tööst	doc_881665289253_item	3702677	et	0	cKUAfXynZ
välja	doc_881665289253_item	3702678	et	0	cKUAfXynZ
kuna	doc_881665289253_item	3702679	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3702680	et	0	cKUAfXynZ
lausemallide	doc_881665289253_item	3702681	et	0	cKUAfXynZ
liigitus	doc_881665289253_item	3702682	et	0	cKUAfXynZ
on	doc_881665289253_item	3702683	et	0	cKUAfXynZ
tehtud	doc_881665289253_item	3702684	et	0	cKUAfXynZ
mitte	doc_881665289253_item	3702685	et	0	cKUAfXynZ
sisuliselt	doc_881665289253_item	3702686	et	0	cKUAfXynZ
vaid	doc_881665289253_item	3702687	et	0	cKUAfXynZ
vormiliselt	doc_881665289253_item	3702688	et	0	cKUAfXynZ
kokkuvõte	doc_881665289253_item	3702689	et	0	cKUAfXynZ
töös	doc_881665289253_item	3702690	et	0	cKUAfXynZ
on	doc_881665289253_item	3702691	et	0	cKUAfXynZ
vaadeldud	doc_881665289253_item	3702692	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3702693	et	0	cKUAfXynZ
keele	doc_881665289253_item	3702694	et	0	cKUAfXynZ
lihtlausemalle	doc_881665289253_item	3702695	et	0	cKUAfXynZ
lihtlausete	doc_881665289253_item	3702696	et	0	cKUAfXynZ
analüüsimisel	doc_881665289253_item	3702697	et	0	cKUAfXynZ
on	doc_881665289253_item	3702698	et	0	cKUAfXynZ
arvestatud	doc_881665289253_item	3702699	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3702700	et	0	cKUAfXynZ
finiitvorme	doc_881665289253_item	3702701	et	0	cKUAfXynZ
sest	doc_881665289253_item	3702702	et	0	cKUAfXynZ
see	doc_881665289253_item	3702703	et	0	cKUAfXynZ
on	doc_881665289253_item	3702704	et	0	cKUAfXynZ
lause	doc_881665289253_item	3702705	et	0	cKUAfXynZ
tuum	doc_881665289253_item	3702706	et	0	cKUAfXynZ
millest	doc_881665289253_item	3702707	et	0	cKUAfXynZ
sõltuvad	doc_881665289253_item	3702708	et	0	cKUAfXynZ
lause	doc_881665289253_item	3702709	et	0	cKUAfXynZ
teised	doc_881665289253_item	3702710	et	0	cKUAfXynZ
struktuurilised	doc_881665289253_item	3702711	et	0	cKUAfXynZ
elemendid	doc_881665289253_item	3702712	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702713	et	0	cKUAfXynZ
nende	doc_881665289253_item	3702714	et	0	cKUAfXynZ
morfoloogilised	doc_881665289253_item	3702715	et	0	cKUAfXynZ
vormid	doc_881665289253_item	3702716	et	0	cKUAfXynZ
niisiis	doc_881665289253_item	3702717	et	0	cKUAfXynZ
h	doc_881665289253_item	3702718	et	0	cKUAfXynZ
rätsep	doc_881665289253_item	3702719	et	0	cKUAfXynZ
on	doc_881665289253_item	3702720	et	0	cKUAfXynZ
toetunud	doc_881665289253_item	3702721	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3702722	et	0	cKUAfXynZ
keele	doc_881665289253_item	3702723	et	0	cKUAfXynZ
verbisüntaksile	doc_881665289253_item	3702724	et	0	cKUAfXynZ
selles	doc_881665289253_item	3702725	et	0	cKUAfXynZ
töös	doc_881665289253_item	3702726	et	0	cKUAfXynZ
tuumeelemendiks	doc_881665289253_item	3702727	et	0	cKUAfXynZ
on	doc_881665289253_item	3702728	et	0	cKUAfXynZ
olnud	doc_881665289253_item	3702729	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3702730	et	0	cKUAfXynZ
finiitvorm	doc_881665289253_item	3702731	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702732	et	0	cKUAfXynZ
orienteeritud	doc_881665289253_item	3702733	et	0	cKUAfXynZ
fraasiks	doc_881665289253_item	3702734	et	0	cKUAfXynZ
verbikeskne	doc_881665289253_item	3702735	et	0	cKUAfXynZ
lause	doc_881665289253_item	3702736	et	0	cKUAfXynZ
mis	doc_881665289253_item	3702737	et	0	cKUAfXynZ
oli	doc_881665289253_item	3702738	et	0	cKUAfXynZ
saadud	doc_881665289253_item	3702739	et	0	cKUAfXynZ
redutseerimisel	doc_881665289253_item	3702740	et	0	cKUAfXynZ
autor	doc_881665289253_item	3702741	et	0	cKUAfXynZ
on	doc_881665289253_item	3702742	et	0	cKUAfXynZ
uurinud	doc_881665289253_item	3702743	et	0	cKUAfXynZ
abstrakseid	doc_881665289253_item	3702744	et	0	cKUAfXynZ
lausemalle	doc_881665289253_item	3702745	et	0	cKUAfXynZ
kus	doc_881665289253_item	3702746	et	0	cKUAfXynZ
on	doc_881665289253_item	3702747	et	0	cKUAfXynZ
taandatud	doc_881665289253_item	3702748	et	0	cKUAfXynZ
teise	doc_881665289253_item	3702749	et	0	cKUAfXynZ
kolmanda	doc_881665289253_item	3702750	et	0	cKUAfXynZ
neljanda	doc_881665289253_item	3702751	et	0	cKUAfXynZ
järgu	doc_881665289253_item	3702752	et	0	cKUAfXynZ
laiendeid	doc_881665289253_item	3702753	et	0	cKUAfXynZ
tema	doc_881665289253_item	3702754	et	0	cKUAfXynZ
järgi	doc_881665289253_item	3702755	et	0	cKUAfXynZ
laiendid	doc_881665289253_item	3702756	et	0	cKUAfXynZ
on	doc_881665289253_item	3702757	et	0	cKUAfXynZ
jaotatud	doc_881665289253_item	3702758	et	0	cKUAfXynZ
vabateks	doc_881665289253_item	3702759	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702760	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3702761	et	0	cKUAfXynZ
laienditeks	doc_881665289253_item	3702762	et	0	cKUAfXynZ
lihtlausemallides	doc_881665289253_item	3702763	et	0	cKUAfXynZ
on	doc_881665289253_item	3702764	et	0	cKUAfXynZ
määratud	doc_881665289253_item	3702765	et	0	cKUAfXynZ
konkreetsed	doc_881665289253_item	3702766	et	0	cKUAfXynZ
verbid	doc_881665289253_item	3702767	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702768	et	0	cKUAfXynZ
nende	doc_881665289253_item	3702769	et	0	cKUAfXynZ
laiendid	doc_881665289253_item	3702770	et	0	cKUAfXynZ
mis	doc_881665289253_item	3702771	et	0	cKUAfXynZ
on	doc_881665289253_item	3702772	et	0	cKUAfXynZ
ühendatud	doc_881665289253_item	3702773	et	0	cKUAfXynZ
vormiklassidega	doc_881665289253_item	3702774	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702775	et	0	cKUAfXynZ
on	doc_881665289253_item	3702776	et	0	cKUAfXynZ
märgitud	doc_881665289253_item	3702777	et	0	cKUAfXynZ
sõnaliigi	doc_881665289253_item	3702778	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702779	et	0	cKUAfXynZ
morfoloogilise	doc_881665289253_item	3702780	et	0	cKUAfXynZ
vormi	doc_881665289253_item	3702781	et	0	cKUAfXynZ
ühiste	doc_881665289253_item	3702782	et	0	cKUAfXynZ
sümbolitega	doc_881665289253_item	3702783	et	0	cKUAfXynZ
niisiis	doc_881665289253_item	3702784	et	0	cKUAfXynZ
h	doc_881665289253_item	3702785	et	0	cKUAfXynZ
rätsep	doc_881665289253_item	3702786	et	0	cKUAfXynZ
on	doc_881665289253_item	3702787	et	0	cKUAfXynZ
kodeerinud	doc_881665289253_item	3702788	et	0	cKUAfXynZ
abstrakseid	doc_881665289253_item	3702789	et	0	cKUAfXynZ
grammatilisi	doc_881665289253_item	3702790	et	0	cKUAfXynZ
kategooriaid	doc_881665289253_item	3702791	et	0	cKUAfXynZ
autor	doc_881665289253_item	3702792	et	0	cKUAfXynZ
võtab	doc_881665289253_item	3702793	et	0	cKUAfXynZ
arvesse	doc_881665289253_item	3702794	et	0	cKUAfXynZ
lausemalli	doc_881665289253_item	3702795	et	0	cKUAfXynZ
verbide	doc_881665289253_item	3702796	et	0	cKUAfXynZ
personaalseid	doc_881665289253_item	3702797	et	0	cKUAfXynZ
vorme	doc_881665289253_item	3702798	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702799	et	0	cKUAfXynZ
jätab	doc_881665289253_item	3702800	et	0	cKUAfXynZ
välja	doc_881665289253_item	3702801	et	0	cKUAfXynZ
impersonaali	doc_881665289253_item	3702802	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702803	et	0	cKUAfXynZ
passiivi	doc_881665289253_item	3702804	et	0	cKUAfXynZ
verbivorme	doc_881665289253_item	3702805	et	0	cKUAfXynZ
lausemallides	doc_881665289253_item	3702806	et	0	cKUAfXynZ
oli	doc_881665289253_item	3702807	et	0	cKUAfXynZ
esitatud	doc_881665289253_item	3702808	et	0	cKUAfXynZ
kolmsuguseid	doc_881665289253_item	3702809	et	0	cKUAfXynZ
komponente	doc_881665289253_item	3702810	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3702811	et	0	cKUAfXynZ
finiitvorme	doc_881665289253_item	3702812	et	0	cKUAfXynZ
morfoloogilisi	doc_881665289253_item	3702813	et	0	cKUAfXynZ
vormiklasse	doc_881665289253_item	3702814	et	0	cKUAfXynZ
substitutsiooniklasse	doc_881665289253_item	3702815	et	0	cKUAfXynZ
kahte	doc_881665289253_item	3702816	et	0	cKUAfXynZ
viimastele	doc_881665289253_item	3702817	et	0	cKUAfXynZ
kuulusid	doc_881665289253_item	3702818	et	0	cKUAfXynZ
nii	doc_881665289253_item	3702819	et	0	cKUAfXynZ
obligaatorsed	doc_881665289253_item	3702820	et	0	cKUAfXynZ
kui	doc_881665289253_item	3702821	et	0	cKUAfXynZ
ka	doc_881665289253_item	3702822	et	0	cKUAfXynZ
fakultatiivsed	doc_881665289253_item	3702823	et	0	cKUAfXynZ
elemendid	doc_881665289253_item	3702824	et	0	cKUAfXynZ
autoril	doc_881665289253_item	3702825	et	0	cKUAfXynZ
oli	doc_881665289253_item	3702826	et	0	cKUAfXynZ
tekkinud	doc_881665289253_item	3702827	et	0	cKUAfXynZ
mitu	doc_881665289253_item	3702828	et	0	cKUAfXynZ
probleemi	doc_881665289253_item	3702829	et	0	cKUAfXynZ
mis	doc_881665289253_item	3702830	et	0	cKUAfXynZ
oli	doc_881665289253_item	3702831	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3702832	et	0	cKUAfXynZ
lause	doc_881665289253_item	3702833	et	0	cKUAfXynZ
verbaalse	doc_881665289253_item	3702834	et	0	cKUAfXynZ
kesksuse	doc_881665289253_item	3702835	et	0	cKUAfXynZ
selge	doc_881665289253_item	3702836	et	0	cKUAfXynZ
määramisega	doc_881665289253_item	3702837	et	0	cKUAfXynZ
esimeseks	doc_881665289253_item	3702838	et	0	cKUAfXynZ
oli	doc_881665289253_item	3702839	et	0	cKUAfXynZ
mitmesõnaliste	doc_881665289253_item	3702840	et	0	cKUAfXynZ
verbaalsete	doc_881665289253_item	3702841	et	0	cKUAfXynZ
lekseemide	doc_881665289253_item	3702842	et	0	cKUAfXynZ
tuvastamine	doc_881665289253_item	3702843	et	0	cKUAfXynZ
tavasõnaühenditest	doc_881665289253_item	3702844	et	0	cKUAfXynZ
teine	doc_881665289253_item	3702845	et	0	cKUAfXynZ
oli	doc_881665289253_item	3702846	et	0	cKUAfXynZ
seotud	doc_881665289253_item	3702847	et	0	cKUAfXynZ
analüütiliste	doc_881665289253_item	3702848	et	0	cKUAfXynZ
verbivormide	doc_881665289253_item	3702849	et	0	cKUAfXynZ
eristamisega	doc_881665289253_item	3702850	et	0	cKUAfXynZ
töös	doc_881665289253_item	3702851	et	0	cKUAfXynZ
on	doc_881665289253_item	3702852	et	0	cKUAfXynZ
põhjalikult	doc_881665289253_item	3702853	et	0	cKUAfXynZ
vaadeldud	doc_881665289253_item	3702854	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3702855	et	0	cKUAfXynZ
lausemallide	doc_881665289253_item	3702856	et	0	cKUAfXynZ
koostisosasid	doc_881665289253_item	3702857	et	0	cKUAfXynZ
nimelt	doc_881665289253_item	3702858	et	0	cKUAfXynZ
verbi	doc_881665289253_item	3702859	et	0	cKUAfXynZ
finiitvorme	doc_881665289253_item	3702860	et	0	cKUAfXynZ
väljendverbe	doc_881665289253_item	3702861	et	0	cKUAfXynZ
ühendverbe	doc_881665289253_item	3702862	et	0	cKUAfXynZ
modaalverbe	doc_881665289253_item	3702863	et	0	cKUAfXynZ
substantiive	doc_881665289253_item	3702864	et	0	cKUAfXynZ
direkstionaale	doc_881665289253_item	3702865	et	0	cKUAfXynZ
jne	doc_881665289253_item	3702866	et	0	cKUAfXynZ
autor	doc_881665289253_item	3702867	et	0	cKUAfXynZ
määrab	doc_881665289253_item	3702868	et	0	cKUAfXynZ
sobilikke	doc_881665289253_item	3702869	et	0	cKUAfXynZ
valentsuse	doc_881665289253_item	3702870	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702871	et	0	cKUAfXynZ
rektsiooni	doc_881665289253_item	3702872	et	0	cKUAfXynZ
definitsioone	doc_881665289253_item	3702873	et	0	cKUAfXynZ
oma	doc_881665289253_item	3702874	et	0	cKUAfXynZ
edaspidiseks	doc_881665289253_item	3702875	et	0	cKUAfXynZ
tööks	doc_881665289253_item	3702876	et	0	cKUAfXynZ
pühendatud	doc_881665289253_item	3702877	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3702878	et	0	cKUAfXynZ
keelsete	doc_881665289253_item	3702879	et	0	cKUAfXynZ
elementaarlausete	doc_881665289253_item	3702880	et	0	cKUAfXynZ
ja	doc_881665289253_item	3702881	et	0	cKUAfXynZ
verbikesksete	doc_881665289253_item	3702882	et	0	cKUAfXynZ
lausemallide	doc_881665289253_item	3702883	et	0	cKUAfXynZ
uurimisele	doc_881665289253_item	3702884	et	0	cKUAfXynZ
kasutatud	doc_881665289253_item	3702885	et	0	cKUAfXynZ
kirjandus	doc_881665289253_item	3702886	et	0	cKUAfXynZ
rätsep	doc_881665289253_item	3702887	et	0	cKUAfXynZ
huno	doc_881665289253_item	3702888	et	0	cKUAfXynZ
1978	doc_881665289253_item	3702889	et	0	cKUAfXynZ
eesti	doc_881665289253_item	3702890	et	0	cKUAfXynZ
keele	doc_881665289253_item	3702891	et	0	cKUAfXynZ
lihtlausete	doc_881665289253_item	3702892	et	0	cKUAfXynZ
tüübid	doc_881665289253_item	3702893	et	0	cKUAfXynZ
tallinn	doc_881665289253_item	3702894	et	0	cKUAfXynZ
valgus	doc_881665289253_item	3702895	et	0	cKUAfXynZ
referaat	doc_831529852295_item	3707942	et	0	cKUAfXynZ
lt	doc_831529852295_item	3707943	et	0	cKUAfXynZ
font	doc_831529852295_item	3707944	et	0	cKUAfXynZ
definitions	doc_831529852295_item	3707945	et	0	cKUAfXynZ
font-face	doc_831529852295_item	3707946	et	0	cKUAfXynZ
font-familywingdings	doc_831529852295_item	3707947	et	0	cKUAfXynZ
panose-15	doc_831529852295_item	3707948	et	0	cKUAfXynZ
0	doc_831529852295_item	3707949	et	0	cKUAfXynZ
0	doc_831529852295_item	3707950	et	0	cKUAfXynZ
0	doc_831529852295_item	3707951	et	0	cKUAfXynZ
0	doc_831529852295_item	3707952	et	0	cKUAfXynZ
0	doc_831529852295_item	3707953	et	0	cKUAfXynZ
0	doc_831529852295_item	3707954	et	0	cKUAfXynZ
0	doc_831529852295_item	3707955	et	0	cKUAfXynZ
0	doc_831529852295_item	3707956	et	0	cKUAfXynZ
0	doc_831529852295_item	3707957	et	0	cKUAfXynZ
mso-font-charset2	doc_831529852295_item	3707958	et	0	cKUAfXynZ
mso-generic-font-familyauto	doc_831529852295_item	3707959	et	0	cKUAfXynZ
mso-font-pitchvariable	doc_831529852295_item	3707960	et	0	cKUAfXynZ
mso-font-signature0	doc_831529852295_item	3707961	et	0	cKUAfXynZ
268435456	doc_831529852295_item	3707962	et	0	cKUAfXynZ
0	doc_831529852295_item	3707963	et	0	cKUAfXynZ
0	doc_831529852295_item	3707964	et	0	cKUAfXynZ
2147483648	doc_831529852295_item	3707965	et	0	cKUAfXynZ
0	doc_831529852295_item	3707966	et	0	cKUAfXynZ
font-face	doc_831529852295_item	3707967	et	0	cKUAfXynZ
font-familycambria	doc_831529852295_item	3707968	et	0	cKUAfXynZ
math	doc_831529852295_item	3707969	et	0	cKUAfXynZ
panose-12	doc_831529852295_item	3707970	et	0	cKUAfXynZ
4	doc_831529852295_item	3707971	et	0	cKUAfXynZ
5	doc_831529852295_item	3707972	et	0	cKUAfXynZ
3	doc_831529852295_item	3707973	et	0	cKUAfXynZ
5	doc_831529852295_item	3707974	et	0	cKUAfXynZ
4	doc_831529852295_item	3707975	et	0	cKUAfXynZ
6	doc_831529852295_item	3707976	et	0	cKUAfXynZ
3	doc_831529852295_item	3707977	et	0	cKUAfXynZ
2	doc_831529852295_item	3707978	et	0	cKUAfXynZ
4	doc_831529852295_item	3707979	et	0	cKUAfXynZ
mso-font-charset186	doc_831529852295_item	3707980	et	0	cKUAfXynZ
mso-generic-font-familyroman	doc_831529852295_item	3707981	et	0	cKUAfXynZ
mso-font-pitchvariable	doc_831529852295_item	3707982	et	0	cKUAfXynZ
mso-font-signature1610611985	doc_831529852295_item	3707983	et	0	cKUAfXynZ
1107304683	doc_831529852295_item	3707984	et	0	cKUAfXynZ
0	doc_831529852295_item	3707985	et	0	cKUAfXynZ
0	doc_831529852295_item	3707986	et	0	cKUAfXynZ
159	doc_831529852295_item	3707987	et	0	cKUAfXynZ
0	doc_831529852295_item	3707988	et	0	cKUAfXynZ
font-face	doc_831529852295_item	3707989	et	0	cKUAfXynZ
font-familycambria	doc_831529852295_item	3707990	et	0	cKUAfXynZ
panose-12	doc_831529852295_item	3707991	et	0	cKUAfXynZ
4	doc_831529852295_item	3707992	et	0	cKUAfXynZ
5	doc_831529852295_item	3707993	et	0	cKUAfXynZ
3	doc_831529852295_item	3707994	et	0	cKUAfXynZ
5	doc_831529852295_item	3707995	et	0	cKUAfXynZ
4	doc_831529852295_item	3707996	et	0	cKUAfXynZ
6	doc_831529852295_item	3707997	et	0	cKUAfXynZ
3	doc_831529852295_item	3707998	et	0	cKUAfXynZ
2	doc_831529852295_item	3707999	et	0	cKUAfXynZ
4	doc_831529852295_item	3708000	et	0	cKUAfXynZ
mso-font-charset186	doc_831529852295_item	3708001	et	0	cKUAfXynZ
mso-generic-font-familyroman	doc_831529852295_item	3708002	et	0	cKUAfXynZ
mso-font-pitchvariable	doc_831529852295_item	3708003	et	0	cKUAfXynZ
mso-font-signature1610611985	doc_831529852295_item	3708004	et	0	cKUAfXynZ
1073741899	doc_831529852295_item	3708005	et	0	cKUAfXynZ
0	doc_831529852295_item	3708006	et	0	cKUAfXynZ
0	doc_831529852295_item	3708007	et	0	cKUAfXynZ
159	doc_831529852295_item	3708008	et	0	cKUAfXynZ
0	doc_831529852295_item	3708009	et	0	cKUAfXynZ
font-face	doc_831529852295_item	3708010	et	0	cKUAfXynZ
font-familycalibri	doc_831529852295_item	3708011	et	0	cKUAfXynZ
panose-12	doc_831529852295_item	3708012	et	0	cKUAfXynZ
15	doc_831529852295_item	3708013	et	0	cKUAfXynZ
5	doc_831529852295_item	3708014	et	0	cKUAfXynZ
2	doc_831529852295_item	3708015	et	0	cKUAfXynZ
2	doc_831529852295_item	3708016	et	0	cKUAfXynZ
2	doc_831529852295_item	3708017	et	0	cKUAfXynZ
4	doc_831529852295_item	3708018	et	0	cKUAfXynZ
3	doc_831529852295_item	3708019	et	0	cKUAfXynZ
2	doc_831529852295_item	3708020	et	0	cKUAfXynZ
4	doc_831529852295_item	3708021	et	0	cKUAfXynZ
mso-font-charset186	doc_831529852295_item	3708022	et	0	cKUAfXynZ
mso-generic-font-familyswiss	doc_831529852295_item	3708023	et	0	cKUAfXynZ
mso-font-pitchvariable	doc_831529852295_item	3708024	et	0	cKUAfXynZ
mso-font-signature1610611985	doc_831529852295_item	3708025	et	0	cKUAfXynZ
1073750139	doc_831529852295_item	3708026	et	0	cKUAfXynZ
0	doc_831529852295_item	3708027	et	0	cKUAfXynZ
0	doc_831529852295_item	3708028	et	0	cKUAfXynZ
159	doc_831529852295_item	3708029	et	0	cKUAfXynZ
0	doc_831529852295_item	3708030	et	0	cKUAfXynZ
style	doc_831529852295_item	3708031	et	0	cKUAfXynZ
definitions	doc_831529852295_item	3708032	et	0	cKUAfXynZ
pmsonormal	doc_831529852295_item	3708033	et	0	cKUAfXynZ
limsonormal	doc_831529852295_item	3708034	et	0	cKUAfXynZ
divmsonormal	doc_831529852295_item	3708035	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708036	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708037	et	0	cKUAfXynZ
mso-style-parent	doc_831529852295_item	3708038	et	0	cKUAfXynZ
margin-top0cm	doc_831529852295_item	3708039	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708040	et	0	cKUAfXynZ
margin-bottom100pt	doc_831529852295_item	3708041	et	0	cKUAfXynZ
margin-left0cm	doc_831529852295_item	3708042	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708043	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708044	et	0	cKUAfXynZ
font-size110pt	doc_831529852295_item	3708045	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708046	et	0	cKUAfXynZ
mso-fareast-font-familycalibri	doc_831529852295_item	3708047	et	0	cKUAfXynZ
mso-bidi-font-familytimes	doc_831529852295_item	3708048	et	0	cKUAfXynZ
new	doc_831529852295_item	3708049	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708050	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708051	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708052	et	0	cKUAfXynZ
h1	doc_831529852295_item	3708053	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708054	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708055	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708056	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708057	et	0	cKUAfXynZ
1	doc_831529852295_item	3708058	et	0	cKUAfXynZ
char	doc_831529852295_item	3708059	et	0	cKUAfXynZ
mso-style-nextnormal	doc_831529852295_item	3708060	et	0	cKUAfXynZ
margin-top120pt	doc_831529852295_item	3708061	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708062	et	0	cKUAfXynZ
margin-bottom300pt	doc_831529852295_item	3708063	et	0	cKUAfXynZ
margin-left180pt	doc_831529852295_item	3708064	et	0	cKUAfXynZ
text-indent180pt	doc_831529852295_item	3708065	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708066	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708067	et	0	cKUAfXynZ
page-break-afteravoid	doc_831529852295_item	3708068	et	0	cKUAfXynZ
mso-outline-level1	doc_831529852295_item	3708069	et	0	cKUAfXynZ
mso-listl2	doc_831529852295_item	3708070	et	0	cKUAfXynZ
level1	doc_831529852295_item	3708071	et	0	cKUAfXynZ
lfo7	doc_831529852295_item	3708072	et	0	cKUAfXynZ
font-size200pt	doc_831529852295_item	3708073	et	0	cKUAfXynZ
mso-bidi-font-size160pt	doc_831529852295_item	3708074	et	0	cKUAfXynZ
font-familytimes	doc_831529852295_item	3708075	et	0	cKUAfXynZ
new	doc_831529852295_item	3708076	et	0	cKUAfXynZ
romanserif	doc_831529852295_item	3708077	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708078	et	0	cKUAfXynZ
new	doc_831529852295_item	3708079	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708080	et	0	cKUAfXynZ
mso-font-kerning160pt	doc_831529852295_item	3708081	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708082	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708083	et	0	cKUAfXynZ
font-weightnormal	doc_831529852295_item	3708084	et	0	cKUAfXynZ
mso-bidi-font-weightbold	doc_831529852295_item	3708085	et	0	cKUAfXynZ
h2	doc_831529852295_item	3708086	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708087	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708088	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708089	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708090	et	0	cKUAfXynZ
2	doc_831529852295_item	3708091	et	0	cKUAfXynZ
char	doc_831529852295_item	3708092	et	0	cKUAfXynZ
mso-style-nextnormal	doc_831529852295_item	3708093	et	0	cKUAfXynZ
margin-top300pt	doc_831529852295_item	3708094	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708095	et	0	cKUAfXynZ
margin-bottom180pt	doc_831529852295_item	3708096	et	0	cKUAfXynZ
margin-left288pt	doc_831529852295_item	3708097	et	0	cKUAfXynZ
text-indent288pt	doc_831529852295_item	3708098	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708099	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708100	et	0	cKUAfXynZ
page-break-afteravoid	doc_831529852295_item	3708101	et	0	cKUAfXynZ
mso-outline-level2	doc_831529852295_item	3708102	et	0	cKUAfXynZ
mso-listl2	doc_831529852295_item	3708103	et	0	cKUAfXynZ
level2	doc_831529852295_item	3708104	et	0	cKUAfXynZ
lfo7	doc_831529852295_item	3708105	et	0	cKUAfXynZ
font-size140pt	doc_831529852295_item	3708106	et	0	cKUAfXynZ
font-familytimes	doc_831529852295_item	3708107	et	0	cKUAfXynZ
new	doc_831529852295_item	3708108	et	0	cKUAfXynZ
romanserif	doc_831529852295_item	3708109	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708110	et	0	cKUAfXynZ
new	doc_831529852295_item	3708111	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708112	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708113	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708114	et	0	cKUAfXynZ
font-weightnormal	doc_831529852295_item	3708115	et	0	cKUAfXynZ
mso-bidi-font-weightbold	doc_831529852295_item	3708116	et	0	cKUAfXynZ
mso-bidi-font-styleitalic	doc_831529852295_item	3708117	et	0	cKUAfXynZ
h3	doc_831529852295_item	3708118	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708119	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708120	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708121	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708122	et	0	cKUAfXynZ
3	doc_831529852295_item	3708123	et	0	cKUAfXynZ
char	doc_831529852295_item	3708124	et	0	cKUAfXynZ
mso-style-nextnormal	doc_831529852295_item	3708125	et	0	cKUAfXynZ
margin-top120pt	doc_831529852295_item	3708126	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708127	et	0	cKUAfXynZ
margin-bottom30pt	doc_831529852295_item	3708128	et	0	cKUAfXynZ
margin-left360pt	doc_831529852295_item	3708129	et	0	cKUAfXynZ
text-indent360pt	doc_831529852295_item	3708130	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708131	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708132	et	0	cKUAfXynZ
page-break-afteravoid	doc_831529852295_item	3708133	et	0	cKUAfXynZ
mso-outline-level3	doc_831529852295_item	3708134	et	0	cKUAfXynZ
mso-listl2	doc_831529852295_item	3708135	et	0	cKUAfXynZ
level3	doc_831529852295_item	3708136	et	0	cKUAfXynZ
lfo7	doc_831529852295_item	3708137	et	0	cKUAfXynZ
font-size130pt	doc_831529852295_item	3708138	et	0	cKUAfXynZ
font-familycambriaserif	doc_831529852295_item	3708139	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708140	et	0	cKUAfXynZ
new	doc_831529852295_item	3708141	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708142	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708143	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708144	et	0	cKUAfXynZ
h4	doc_831529852295_item	3708145	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708146	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708147	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708148	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708149	et	0	cKUAfXynZ
4	doc_831529852295_item	3708150	et	0	cKUAfXynZ
char	doc_831529852295_item	3708151	et	0	cKUAfXynZ
mso-style-nextnormal	doc_831529852295_item	3708152	et	0	cKUAfXynZ
margin-top120pt	doc_831529852295_item	3708153	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708154	et	0	cKUAfXynZ
margin-bottom30pt	doc_831529852295_item	3708155	et	0	cKUAfXynZ
margin-left432pt	doc_831529852295_item	3708156	et	0	cKUAfXynZ
text-indent432pt	doc_831529852295_item	3708157	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708158	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708159	et	0	cKUAfXynZ
page-break-afteravoid	doc_831529852295_item	3708160	et	0	cKUAfXynZ
mso-outline-level4	doc_831529852295_item	3708161	et	0	cKUAfXynZ
mso-listl2	doc_831529852295_item	3708162	et	0	cKUAfXynZ
level4	doc_831529852295_item	3708163	et	0	cKUAfXynZ
lfo7	doc_831529852295_item	3708164	et	0	cKUAfXynZ
font-size140pt	doc_831529852295_item	3708165	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708166	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708167	et	0	cKUAfXynZ
new	doc_831529852295_item	3708168	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708169	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708170	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708171	et	0	cKUAfXynZ
h5	doc_831529852295_item	3708172	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708173	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708174	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708175	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708176	et	0	cKUAfXynZ
5	doc_831529852295_item	3708177	et	0	cKUAfXynZ
char	doc_831529852295_item	3708178	et	0	cKUAfXynZ
mso-style-nextnormal	doc_831529852295_item	3708179	et	0	cKUAfXynZ
margin-top120pt	doc_831529852295_item	3708180	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708181	et	0	cKUAfXynZ
margin-bottom30pt	doc_831529852295_item	3708182	et	0	cKUAfXynZ
margin-left504pt	doc_831529852295_item	3708183	et	0	cKUAfXynZ
text-indent504pt	doc_831529852295_item	3708184	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708185	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708186	et	0	cKUAfXynZ
mso-outline-level5	doc_831529852295_item	3708187	et	0	cKUAfXynZ
mso-listl2	doc_831529852295_item	3708188	et	0	cKUAfXynZ
level5	doc_831529852295_item	3708189	et	0	cKUAfXynZ
lfo7	doc_831529852295_item	3708190	et	0	cKUAfXynZ
font-size130pt	doc_831529852295_item	3708191	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708192	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708193	et	0	cKUAfXynZ
new	doc_831529852295_item	3708194	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708195	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708196	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708197	et	0	cKUAfXynZ
font-styleitalic	doc_831529852295_item	3708198	et	0	cKUAfXynZ
h6	doc_831529852295_item	3708199	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708200	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708201	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708202	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708203	et	0	cKUAfXynZ
6	doc_831529852295_item	3708204	et	0	cKUAfXynZ
char	doc_831529852295_item	3708205	et	0	cKUAfXynZ
mso-style-nextnormal	doc_831529852295_item	3708206	et	0	cKUAfXynZ
margin-top120pt	doc_831529852295_item	3708207	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708208	et	0	cKUAfXynZ
margin-bottom30pt	doc_831529852295_item	3708209	et	0	cKUAfXynZ
margin-left576pt	doc_831529852295_item	3708210	et	0	cKUAfXynZ
text-indent576pt	doc_831529852295_item	3708211	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708212	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708213	et	0	cKUAfXynZ
mso-outline-level6	doc_831529852295_item	3708214	et	0	cKUAfXynZ
mso-listl2	doc_831529852295_item	3708215	et	0	cKUAfXynZ
level6	doc_831529852295_item	3708216	et	0	cKUAfXynZ
lfo7	doc_831529852295_item	3708217	et	0	cKUAfXynZ
font-size110pt	doc_831529852295_item	3708218	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708219	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708220	et	0	cKUAfXynZ
new	doc_831529852295_item	3708221	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708222	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708223	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708224	et	0	cKUAfXynZ
pmsoheading7	doc_831529852295_item	3708225	et	0	cKUAfXynZ
limsoheading7	doc_831529852295_item	3708226	et	0	cKUAfXynZ
divmsoheading7	doc_831529852295_item	3708227	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708228	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708229	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708230	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708231	et	0	cKUAfXynZ
7	doc_831529852295_item	3708232	et	0	cKUAfXynZ
char	doc_831529852295_item	3708233	et	0	cKUAfXynZ
mso-style-nextnormal	doc_831529852295_item	3708234	et	0	cKUAfXynZ
margin-top120pt	doc_831529852295_item	3708235	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708236	et	0	cKUAfXynZ
margin-bottom30pt	doc_831529852295_item	3708237	et	0	cKUAfXynZ
margin-left648pt	doc_831529852295_item	3708238	et	0	cKUAfXynZ
text-indent648pt	doc_831529852295_item	3708239	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708240	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708241	et	0	cKUAfXynZ
mso-outline-level7	doc_831529852295_item	3708242	et	0	cKUAfXynZ
mso-listl2	doc_831529852295_item	3708243	et	0	cKUAfXynZ
level7	doc_831529852295_item	3708244	et	0	cKUAfXynZ
lfo7	doc_831529852295_item	3708245	et	0	cKUAfXynZ
font-size120pt	doc_831529852295_item	3708246	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708247	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708248	et	0	cKUAfXynZ
new	doc_831529852295_item	3708249	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708250	et	0	cKUAfXynZ
mso-bidi-font-familytimes	doc_831529852295_item	3708251	et	0	cKUAfXynZ
new	doc_831529852295_item	3708252	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708253	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708254	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708255	et	0	cKUAfXynZ
pmsoheading8	doc_831529852295_item	3708256	et	0	cKUAfXynZ
limsoheading8	doc_831529852295_item	3708257	et	0	cKUAfXynZ
divmsoheading8	doc_831529852295_item	3708258	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708259	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708260	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708261	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708262	et	0	cKUAfXynZ
8	doc_831529852295_item	3708263	et	0	cKUAfXynZ
char	doc_831529852295_item	3708264	et	0	cKUAfXynZ
mso-style-nextnormal	doc_831529852295_item	3708265	et	0	cKUAfXynZ
margin-top120pt	doc_831529852295_item	3708266	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708267	et	0	cKUAfXynZ
margin-bottom30pt	doc_831529852295_item	3708268	et	0	cKUAfXynZ
margin-left720pt	doc_831529852295_item	3708269	et	0	cKUAfXynZ
text-indent720pt	doc_831529852295_item	3708270	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708271	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708272	et	0	cKUAfXynZ
mso-outline-level8	doc_831529852295_item	3708273	et	0	cKUAfXynZ
mso-listl2	doc_831529852295_item	3708274	et	0	cKUAfXynZ
level8	doc_831529852295_item	3708275	et	0	cKUAfXynZ
lfo7	doc_831529852295_item	3708276	et	0	cKUAfXynZ
font-size120pt	doc_831529852295_item	3708277	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708278	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708279	et	0	cKUAfXynZ
new	doc_831529852295_item	3708280	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708281	et	0	cKUAfXynZ
mso-bidi-font-familytimes	doc_831529852295_item	3708282	et	0	cKUAfXynZ
new	doc_831529852295_item	3708283	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708284	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708285	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708286	et	0	cKUAfXynZ
font-styleitalic	doc_831529852295_item	3708287	et	0	cKUAfXynZ
pmsoheading9	doc_831529852295_item	3708288	et	0	cKUAfXynZ
limsoheading9	doc_831529852295_item	3708289	et	0	cKUAfXynZ
divmsoheading9	doc_831529852295_item	3708290	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708291	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708292	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708293	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708294	et	0	cKUAfXynZ
9	doc_831529852295_item	3708295	et	0	cKUAfXynZ
char	doc_831529852295_item	3708296	et	0	cKUAfXynZ
mso-style-nextnormal	doc_831529852295_item	3708297	et	0	cKUAfXynZ
margin-top120pt	doc_831529852295_item	3708298	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708299	et	0	cKUAfXynZ
margin-bottom30pt	doc_831529852295_item	3708300	et	0	cKUAfXynZ
margin-left792pt	doc_831529852295_item	3708301	et	0	cKUAfXynZ
text-indent792pt	doc_831529852295_item	3708302	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708303	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708304	et	0	cKUAfXynZ
mso-outline-level9	doc_831529852295_item	3708305	et	0	cKUAfXynZ
mso-listl2	doc_831529852295_item	3708306	et	0	cKUAfXynZ
level9	doc_831529852295_item	3708307	et	0	cKUAfXynZ
lfo7	doc_831529852295_item	3708308	et	0	cKUAfXynZ
font-size110pt	doc_831529852295_item	3708309	et	0	cKUAfXynZ
font-familycambriaserif	doc_831529852295_item	3708310	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708311	et	0	cKUAfXynZ
new	doc_831529852295_item	3708312	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708313	et	0	cKUAfXynZ
mso-bidi-font-familytimes	doc_831529852295_item	3708314	et	0	cKUAfXynZ
new	doc_831529852295_item	3708315	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708316	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708317	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708318	et	0	cKUAfXynZ
pmsotoc1	doc_831529852295_item	3708319	et	0	cKUAfXynZ
limsotoc1	doc_831529852295_item	3708320	et	0	cKUAfXynZ
divmsotoc1	doc_831529852295_item	3708321	et	0	cKUAfXynZ
mso-style-updateauto	doc_831529852295_item	3708322	et	0	cKUAfXynZ
mso-style-priority39	doc_831529852295_item	3708323	et	0	cKUAfXynZ
mso-style-nextnormal	doc_831529852295_item	3708324	et	0	cKUAfXynZ
margin-top0cm	doc_831529852295_item	3708325	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708326	et	0	cKUAfXynZ
margin-bottom100pt	doc_831529852295_item	3708327	et	0	cKUAfXynZ
margin-left0cm	doc_831529852295_item	3708328	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708329	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708330	et	0	cKUAfXynZ
font-size110pt	doc_831529852295_item	3708331	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708332	et	0	cKUAfXynZ
mso-fareast-font-familycalibri	doc_831529852295_item	3708333	et	0	cKUAfXynZ
mso-bidi-font-familytimes	doc_831529852295_item	3708334	et	0	cKUAfXynZ
new	doc_831529852295_item	3708335	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708336	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708337	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708338	et	0	cKUAfXynZ
pmsotoc2	doc_831529852295_item	3708339	et	0	cKUAfXynZ
limsotoc2	doc_831529852295_item	3708340	et	0	cKUAfXynZ
divmsotoc2	doc_831529852295_item	3708341	et	0	cKUAfXynZ
mso-style-updateauto	doc_831529852295_item	3708342	et	0	cKUAfXynZ
mso-style-priority39	doc_831529852295_item	3708343	et	0	cKUAfXynZ
mso-style-nextnormal	doc_831529852295_item	3708344	et	0	cKUAfXynZ
margin-top0cm	doc_831529852295_item	3708345	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708346	et	0	cKUAfXynZ
margin-bottom100pt	doc_831529852295_item	3708347	et	0	cKUAfXynZ
margin-left110pt	doc_831529852295_item	3708348	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708349	et	0	cKUAfXynZ
tab-stops135pt	doc_831529852295_item	3708350	et	0	cKUAfXynZ
440pt	doc_831529852295_item	3708351	et	0	cKUAfXynZ
right	doc_831529852295_item	3708352	et	0	cKUAfXynZ
dotted	doc_831529852295_item	3708353	et	0	cKUAfXynZ
4675pt	doc_831529852295_item	3708354	et	0	cKUAfXynZ
font-size110pt	doc_831529852295_item	3708355	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708356	et	0	cKUAfXynZ
mso-fareast-font-familycalibri	doc_831529852295_item	3708357	et	0	cKUAfXynZ
mso-bidi-font-familytimes	doc_831529852295_item	3708358	et	0	cKUAfXynZ
new	doc_831529852295_item	3708359	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708360	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708361	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708362	et	0	cKUAfXynZ
pmsoheader	doc_831529852295_item	3708363	et	0	cKUAfXynZ
limsoheader	doc_831529852295_item	3708364	et	0	cKUAfXynZ
divmsoheader	doc_831529852295_item	3708365	et	0	cKUAfXynZ
mso-style-noshowyes	doc_831529852295_item	3708366	et	0	cKUAfXynZ
mso-style-priority99	doc_831529852295_item	3708367	et	0	cKUAfXynZ
mso-style-linkheader	doc_831529852295_item	3708368	et	0	cKUAfXynZ
char	doc_831529852295_item	3708369	et	0	cKUAfXynZ
margin0cm	doc_831529852295_item	3708370	et	0	cKUAfXynZ
margin-bottom0001pt	doc_831529852295_item	3708371	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708372	et	0	cKUAfXynZ
tab-stopscenter	doc_831529852295_item	3708373	et	0	cKUAfXynZ
23385pt	doc_831529852295_item	3708374	et	0	cKUAfXynZ
right	doc_831529852295_item	3708375	et	0	cKUAfXynZ
46775pt	doc_831529852295_item	3708376	et	0	cKUAfXynZ
font-size110pt	doc_831529852295_item	3708377	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708378	et	0	cKUAfXynZ
mso-fareast-font-familycalibri	doc_831529852295_item	3708379	et	0	cKUAfXynZ
mso-bidi-font-familytimes	doc_831529852295_item	3708380	et	0	cKUAfXynZ
new	doc_831529852295_item	3708381	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708382	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708383	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708384	et	0	cKUAfXynZ
pmsofooter	doc_831529852295_item	3708385	et	0	cKUAfXynZ
limsofooter	doc_831529852295_item	3708386	et	0	cKUAfXynZ
divmsofooter	doc_831529852295_item	3708387	et	0	cKUAfXynZ
mso-style-priority99	doc_831529852295_item	3708388	et	0	cKUAfXynZ
mso-style-linkfooter	doc_831529852295_item	3708389	et	0	cKUAfXynZ
char	doc_831529852295_item	3708390	et	0	cKUAfXynZ
margin0cm	doc_831529852295_item	3708391	et	0	cKUAfXynZ
margin-bottom0001pt	doc_831529852295_item	3708392	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708393	et	0	cKUAfXynZ
tab-stopscenter	doc_831529852295_item	3708394	et	0	cKUAfXynZ
23385pt	doc_831529852295_item	3708395	et	0	cKUAfXynZ
right	doc_831529852295_item	3708396	et	0	cKUAfXynZ
46775pt	doc_831529852295_item	3708397	et	0	cKUAfXynZ
font-size110pt	doc_831529852295_item	3708398	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708399	et	0	cKUAfXynZ
mso-fareast-font-familycalibri	doc_831529852295_item	3708400	et	0	cKUAfXynZ
mso-bidi-font-familytimes	doc_831529852295_item	3708401	et	0	cKUAfXynZ
new	doc_831529852295_item	3708402	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708403	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708404	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708405	et	0	cKUAfXynZ
alink	doc_831529852295_item	3708406	et	0	cKUAfXynZ
spanmsohyperlink	doc_831529852295_item	3708407	et	0	cKUAfXynZ
mso-style-priority99	doc_831529852295_item	3708408	et	0	cKUAfXynZ
colorblue	doc_831529852295_item	3708409	et	0	cKUAfXynZ
text-decorationunderline	doc_831529852295_item	3708410	et	0	cKUAfXynZ
text-underlinesingle	doc_831529852295_item	3708411	et	0	cKUAfXynZ
avisited	doc_831529852295_item	3708412	et	0	cKUAfXynZ
spanmsohyperlinkfollowed	doc_831529852295_item	3708413	et	0	cKUAfXynZ
mso-style-noshowyes	doc_831529852295_item	3708414	et	0	cKUAfXynZ
mso-style-priority99	doc_831529852295_item	3708415	et	0	cKUAfXynZ
colorpurple	doc_831529852295_item	3708416	et	0	cKUAfXynZ
mso-themecolorfollowedhyperlink	doc_831529852295_item	3708417	et	0	cKUAfXynZ
text-decorationunderline	doc_831529852295_item	3708418	et	0	cKUAfXynZ
text-underlinesingle	doc_831529852295_item	3708419	et	0	cKUAfXynZ
pmsolistparagraph	doc_831529852295_item	3708420	et	0	cKUAfXynZ
limsolistparagraph	doc_831529852295_item	3708421	et	0	cKUAfXynZ
divmsolistparagraph	doc_831529852295_item	3708422	et	0	cKUAfXynZ
mso-style-priority34	doc_831529852295_item	3708423	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708424	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708425	et	0	cKUAfXynZ
margin-top0cm	doc_831529852295_item	3708426	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708427	et	0	cKUAfXynZ
margin-bottom100pt	doc_831529852295_item	3708428	et	0	cKUAfXynZ
margin-left360pt	doc_831529852295_item	3708429	et	0	cKUAfXynZ
mso-add-spaceauto	doc_831529852295_item	3708430	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708431	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708432	et	0	cKUAfXynZ
font-size110pt	doc_831529852295_item	3708433	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708434	et	0	cKUAfXynZ
mso-fareast-font-familycalibri	doc_831529852295_item	3708435	et	0	cKUAfXynZ
mso-bidi-font-familytimes	doc_831529852295_item	3708436	et	0	cKUAfXynZ
new	doc_831529852295_item	3708437	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708438	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708439	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708440	et	0	cKUAfXynZ
pmsolistparagraphcxspfirst	doc_831529852295_item	3708441	et	0	cKUAfXynZ
limsolistparagraphcxspfirst	doc_831529852295_item	3708442	et	0	cKUAfXynZ
divmsolistparagraphcxspfirst	doc_831529852295_item	3708443	et	0	cKUAfXynZ
mso-style-priority34	doc_831529852295_item	3708444	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708445	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708446	et	0	cKUAfXynZ
mso-style-typeexport-only	doc_831529852295_item	3708447	et	0	cKUAfXynZ
margin-top0cm	doc_831529852295_item	3708448	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708449	et	0	cKUAfXynZ
margin-bottom0cm	doc_831529852295_item	3708450	et	0	cKUAfXynZ
margin-left360pt	doc_831529852295_item	3708451	et	0	cKUAfXynZ
margin-bottom0001pt	doc_831529852295_item	3708452	et	0	cKUAfXynZ
mso-add-spaceauto	doc_831529852295_item	3708453	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708454	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708455	et	0	cKUAfXynZ
font-size110pt	doc_831529852295_item	3708456	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708457	et	0	cKUAfXynZ
mso-fareast-font-familycalibri	doc_831529852295_item	3708458	et	0	cKUAfXynZ
mso-bidi-font-familytimes	doc_831529852295_item	3708459	et	0	cKUAfXynZ
new	doc_831529852295_item	3708460	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708461	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708462	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708463	et	0	cKUAfXynZ
pmsolistparagraphcxspmiddle	doc_831529852295_item	3708464	et	0	cKUAfXynZ
limsolistparagraphcxspmiddle	doc_831529852295_item	3708465	et	0	cKUAfXynZ
divmsolistparagraphcxspmiddle	doc_831529852295_item	3708466	et	0	cKUAfXynZ
mso-style-priority34	doc_831529852295_item	3708467	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708468	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708469	et	0	cKUAfXynZ
mso-style-typeexport-only	doc_831529852295_item	3708470	et	0	cKUAfXynZ
margin-top0cm	doc_831529852295_item	3708471	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708472	et	0	cKUAfXynZ
margin-bottom0cm	doc_831529852295_item	3708473	et	0	cKUAfXynZ
margin-left360pt	doc_831529852295_item	3708474	et	0	cKUAfXynZ
margin-bottom0001pt	doc_831529852295_item	3708475	et	0	cKUAfXynZ
mso-add-spaceauto	doc_831529852295_item	3708476	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708477	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708478	et	0	cKUAfXynZ
font-size110pt	doc_831529852295_item	3708479	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708480	et	0	cKUAfXynZ
mso-fareast-font-familycalibri	doc_831529852295_item	3708481	et	0	cKUAfXynZ
mso-bidi-font-familytimes	doc_831529852295_item	3708482	et	0	cKUAfXynZ
new	doc_831529852295_item	3708483	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708484	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708485	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708486	et	0	cKUAfXynZ
pmsolistparagraphcxsplast	doc_831529852295_item	3708487	et	0	cKUAfXynZ
limsolistparagraphcxsplast	doc_831529852295_item	3708488	et	0	cKUAfXynZ
divmsolistparagraphcxsplast	doc_831529852295_item	3708489	et	0	cKUAfXynZ
mso-style-priority34	doc_831529852295_item	3708490	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708491	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708492	et	0	cKUAfXynZ
mso-style-typeexport-only	doc_831529852295_item	3708493	et	0	cKUAfXynZ
margin-top0cm	doc_831529852295_item	3708494	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708495	et	0	cKUAfXynZ
margin-bottom100pt	doc_831529852295_item	3708496	et	0	cKUAfXynZ
margin-left360pt	doc_831529852295_item	3708497	et	0	cKUAfXynZ
mso-add-spaceauto	doc_831529852295_item	3708498	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708499	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708500	et	0	cKUAfXynZ
font-size110pt	doc_831529852295_item	3708501	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3708502	et	0	cKUAfXynZ
mso-fareast-font-familycalibri	doc_831529852295_item	3708503	et	0	cKUAfXynZ
mso-bidi-font-familytimes	doc_831529852295_item	3708504	et	0	cKUAfXynZ
new	doc_831529852295_item	3708505	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708506	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708507	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708508	et	0	cKUAfXynZ
pmsotocheading	doc_831529852295_item	3708509	et	0	cKUAfXynZ
limsotocheading	doc_831529852295_item	3708510	et	0	cKUAfXynZ
divmsotocheading	doc_831529852295_item	3708511	et	0	cKUAfXynZ
mso-style-priority39	doc_831529852295_item	3708512	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708513	et	0	cKUAfXynZ
mso-style-qformatyes	doc_831529852295_item	3708514	et	0	cKUAfXynZ
mso-style-parentheading	doc_831529852295_item	3708515	et	0	cKUAfXynZ
1	doc_831529852295_item	3708516	et	0	cKUAfXynZ
mso-style-nextnormal	doc_831529852295_item	3708517	et	0	cKUAfXynZ
margin-top240pt	doc_831529852295_item	3708518	et	0	cKUAfXynZ
margin-right0cm	doc_831529852295_item	3708519	et	0	cKUAfXynZ
margin-bottom0cm	doc_831529852295_item	3708520	et	0	cKUAfXynZ
margin-left0cm	doc_831529852295_item	3708521	et	0	cKUAfXynZ
margin-bottom0001pt	doc_831529852295_item	3708522	et	0	cKUAfXynZ
line-height115	doc_831529852295_item	3708523	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_831529852295_item	3708524	et	0	cKUAfXynZ
lines-together	doc_831529852295_item	3708525	et	0	cKUAfXynZ
page-break-afteravoid	doc_831529852295_item	3708526	et	0	cKUAfXynZ
font-size140pt	doc_831529852295_item	3708527	et	0	cKUAfXynZ
font-familycambriaserif	doc_831529852295_item	3708528	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708529	et	0	cKUAfXynZ
new	doc_831529852295_item	3708530	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708531	et	0	cKUAfXynZ
mso-bidi-font-familytimes	doc_831529852295_item	3708532	et	0	cKUAfXynZ
new	doc_831529852295_item	3708533	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708534	et	0	cKUAfXynZ
color365f91	doc_831529852295_item	3708535	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708536	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708537	et	0	cKUAfXynZ
font-weightbold	doc_831529852295_item	3708538	et	0	cKUAfXynZ
spanheading1char	doc_831529852295_item	3708539	et	0	cKUAfXynZ
mso-style-nameheading	doc_831529852295_item	3708540	et	0	cKUAfXynZ
1	doc_831529852295_item	3708541	et	0	cKUAfXynZ
char	doc_831529852295_item	3708542	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708543	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708544	et	0	cKUAfXynZ
mso-style-lockedyes	doc_831529852295_item	3708545	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708546	et	0	cKUAfXynZ
1	doc_831529852295_item	3708547	et	0	cKUAfXynZ
mso-ansi-font-size200pt	doc_831529852295_item	3708548	et	0	cKUAfXynZ
mso-bidi-font-size160pt	doc_831529852295_item	3708549	et	0	cKUAfXynZ
font-familytimes	doc_831529852295_item	3708550	et	0	cKUAfXynZ
new	doc_831529852295_item	3708551	et	0	cKUAfXynZ
romanserif	doc_831529852295_item	3708552	et	0	cKUAfXynZ
mso-ascii-font-familytimes	doc_831529852295_item	3708553	et	0	cKUAfXynZ
new	doc_831529852295_item	3708554	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708555	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708556	et	0	cKUAfXynZ
new	doc_831529852295_item	3708557	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708558	et	0	cKUAfXynZ
mso-hansi-font-familytimes	doc_831529852295_item	3708559	et	0	cKUAfXynZ
new	doc_831529852295_item	3708560	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708561	et	0	cKUAfXynZ
mso-font-kerning160pt	doc_831529852295_item	3708562	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708563	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708564	et	0	cKUAfXynZ
mso-bidi-font-weightbold	doc_831529852295_item	3708565	et	0	cKUAfXynZ
spanheading2char	doc_831529852295_item	3708566	et	0	cKUAfXynZ
mso-style-nameheading	doc_831529852295_item	3708567	et	0	cKUAfXynZ
2	doc_831529852295_item	3708568	et	0	cKUAfXynZ
char	doc_831529852295_item	3708569	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708570	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708571	et	0	cKUAfXynZ
mso-style-lockedyes	doc_831529852295_item	3708572	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708573	et	0	cKUAfXynZ
2	doc_831529852295_item	3708574	et	0	cKUAfXynZ
mso-ansi-font-size140pt	doc_831529852295_item	3708575	et	0	cKUAfXynZ
mso-bidi-font-size140pt	doc_831529852295_item	3708576	et	0	cKUAfXynZ
font-familytimes	doc_831529852295_item	3708577	et	0	cKUAfXynZ
new	doc_831529852295_item	3708578	et	0	cKUAfXynZ
romanserif	doc_831529852295_item	3708579	et	0	cKUAfXynZ
mso-ascii-font-familytimes	doc_831529852295_item	3708580	et	0	cKUAfXynZ
new	doc_831529852295_item	3708581	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708582	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708583	et	0	cKUAfXynZ
new	doc_831529852295_item	3708584	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708585	et	0	cKUAfXynZ
mso-hansi-font-familytimes	doc_831529852295_item	3708586	et	0	cKUAfXynZ
new	doc_831529852295_item	3708587	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708588	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708589	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708590	et	0	cKUAfXynZ
mso-bidi-font-weightbold	doc_831529852295_item	3708591	et	0	cKUAfXynZ
mso-bidi-font-styleitalic	doc_831529852295_item	3708592	et	0	cKUAfXynZ
spanheading3char	doc_831529852295_item	3708593	et	0	cKUAfXynZ
mso-style-nameheading	doc_831529852295_item	3708594	et	0	cKUAfXynZ
3	doc_831529852295_item	3708595	et	0	cKUAfXynZ
char	doc_831529852295_item	3708596	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708597	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708598	et	0	cKUAfXynZ
mso-style-lockedyes	doc_831529852295_item	3708599	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708600	et	0	cKUAfXynZ
3	doc_831529852295_item	3708601	et	0	cKUAfXynZ
mso-ansi-font-size130pt	doc_831529852295_item	3708602	et	0	cKUAfXynZ
mso-bidi-font-size130pt	doc_831529852295_item	3708603	et	0	cKUAfXynZ
font-familycambriaserif	doc_831529852295_item	3708604	et	0	cKUAfXynZ
mso-ascii-font-familycambria	doc_831529852295_item	3708605	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708606	et	0	cKUAfXynZ
new	doc_831529852295_item	3708607	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708608	et	0	cKUAfXynZ
mso-hansi-font-familycambria	doc_831529852295_item	3708609	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708610	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708611	et	0	cKUAfXynZ
font-weightbold	doc_831529852295_item	3708612	et	0	cKUAfXynZ
spanheading4char	doc_831529852295_item	3708613	et	0	cKUAfXynZ
mso-style-nameheading	doc_831529852295_item	3708614	et	0	cKUAfXynZ
4	doc_831529852295_item	3708615	et	0	cKUAfXynZ
char	doc_831529852295_item	3708616	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708617	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708618	et	0	cKUAfXynZ
mso-style-lockedyes	doc_831529852295_item	3708619	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708620	et	0	cKUAfXynZ
4	doc_831529852295_item	3708621	et	0	cKUAfXynZ
mso-ansi-font-size140pt	doc_831529852295_item	3708622	et	0	cKUAfXynZ
mso-bidi-font-size140pt	doc_831529852295_item	3708623	et	0	cKUAfXynZ
font-familytimes	doc_831529852295_item	3708624	et	0	cKUAfXynZ
new	doc_831529852295_item	3708625	et	0	cKUAfXynZ
romanserif	doc_831529852295_item	3708626	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708627	et	0	cKUAfXynZ
new	doc_831529852295_item	3708628	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708629	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708630	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708631	et	0	cKUAfXynZ
font-weightbold	doc_831529852295_item	3708632	et	0	cKUAfXynZ
spanheading5char	doc_831529852295_item	3708633	et	0	cKUAfXynZ
mso-style-nameheading	doc_831529852295_item	3708634	et	0	cKUAfXynZ
5	doc_831529852295_item	3708635	et	0	cKUAfXynZ
char	doc_831529852295_item	3708636	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708637	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708638	et	0	cKUAfXynZ
mso-style-lockedyes	doc_831529852295_item	3708639	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708640	et	0	cKUAfXynZ
5	doc_831529852295_item	3708641	et	0	cKUAfXynZ
mso-ansi-font-size130pt	doc_831529852295_item	3708642	et	0	cKUAfXynZ
mso-bidi-font-size130pt	doc_831529852295_item	3708643	et	0	cKUAfXynZ
font-familytimes	doc_831529852295_item	3708644	et	0	cKUAfXynZ
new	doc_831529852295_item	3708645	et	0	cKUAfXynZ
romanserif	doc_831529852295_item	3708646	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708647	et	0	cKUAfXynZ
new	doc_831529852295_item	3708648	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708649	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708650	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708651	et	0	cKUAfXynZ
font-weightbold	doc_831529852295_item	3708652	et	0	cKUAfXynZ
font-styleitalic	doc_831529852295_item	3708653	et	0	cKUAfXynZ
spanheading6char	doc_831529852295_item	3708654	et	0	cKUAfXynZ
mso-style-nameheading	doc_831529852295_item	3708655	et	0	cKUAfXynZ
6	doc_831529852295_item	3708656	et	0	cKUAfXynZ
char	doc_831529852295_item	3708657	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708658	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708659	et	0	cKUAfXynZ
mso-style-lockedyes	doc_831529852295_item	3708660	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708661	et	0	cKUAfXynZ
6	doc_831529852295_item	3708662	et	0	cKUAfXynZ
mso-ansi-font-size110pt	doc_831529852295_item	3708663	et	0	cKUAfXynZ
mso-bidi-font-size110pt	doc_831529852295_item	3708664	et	0	cKUAfXynZ
font-familytimes	doc_831529852295_item	3708665	et	0	cKUAfXynZ
new	doc_831529852295_item	3708666	et	0	cKUAfXynZ
romanserif	doc_831529852295_item	3708667	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708668	et	0	cKUAfXynZ
new	doc_831529852295_item	3708669	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708670	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708671	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708672	et	0	cKUAfXynZ
font-weightbold	doc_831529852295_item	3708673	et	0	cKUAfXynZ
spanheading7char	doc_831529852295_item	3708674	et	0	cKUAfXynZ
mso-style-nameheading	doc_831529852295_item	3708675	et	0	cKUAfXynZ
7	doc_831529852295_item	3708676	et	0	cKUAfXynZ
char	doc_831529852295_item	3708677	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708678	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708679	et	0	cKUAfXynZ
mso-style-lockedyes	doc_831529852295_item	3708680	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708681	et	0	cKUAfXynZ
7	doc_831529852295_item	3708682	et	0	cKUAfXynZ
mso-ansi-font-size120pt	doc_831529852295_item	3708683	et	0	cKUAfXynZ
mso-bidi-font-size120pt	doc_831529852295_item	3708684	et	0	cKUAfXynZ
font-familytimes	doc_831529852295_item	3708685	et	0	cKUAfXynZ
new	doc_831529852295_item	3708686	et	0	cKUAfXynZ
romanserif	doc_831529852295_item	3708687	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708688	et	0	cKUAfXynZ
new	doc_831529852295_item	3708689	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708690	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708691	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708692	et	0	cKUAfXynZ
spanheading8char	doc_831529852295_item	3708693	et	0	cKUAfXynZ
mso-style-nameheading	doc_831529852295_item	3708694	et	0	cKUAfXynZ
8	doc_831529852295_item	3708695	et	0	cKUAfXynZ
char	doc_831529852295_item	3708696	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708697	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708698	et	0	cKUAfXynZ
mso-style-lockedyes	doc_831529852295_item	3708699	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708700	et	0	cKUAfXynZ
8	doc_831529852295_item	3708701	et	0	cKUAfXynZ
mso-ansi-font-size120pt	doc_831529852295_item	3708702	et	0	cKUAfXynZ
mso-bidi-font-size120pt	doc_831529852295_item	3708703	et	0	cKUAfXynZ
font-familytimes	doc_831529852295_item	3708704	et	0	cKUAfXynZ
new	doc_831529852295_item	3708705	et	0	cKUAfXynZ
romanserif	doc_831529852295_item	3708706	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708707	et	0	cKUAfXynZ
new	doc_831529852295_item	3708708	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708709	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708710	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708711	et	0	cKUAfXynZ
font-styleitalic	doc_831529852295_item	3708712	et	0	cKUAfXynZ
spanheading9char	doc_831529852295_item	3708713	et	0	cKUAfXynZ
mso-style-nameheading	doc_831529852295_item	3708714	et	0	cKUAfXynZ
9	doc_831529852295_item	3708715	et	0	cKUAfXynZ
char	doc_831529852295_item	3708716	et	0	cKUAfXynZ
mso-style-priority9	doc_831529852295_item	3708717	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708718	et	0	cKUAfXynZ
mso-style-lockedyes	doc_831529852295_item	3708719	et	0	cKUAfXynZ
mso-style-linkheading	doc_831529852295_item	3708720	et	0	cKUAfXynZ
9	doc_831529852295_item	3708721	et	0	cKUAfXynZ
mso-ansi-font-size110pt	doc_831529852295_item	3708722	et	0	cKUAfXynZ
mso-bidi-font-size110pt	doc_831529852295_item	3708723	et	0	cKUAfXynZ
font-familycambriaserif	doc_831529852295_item	3708724	et	0	cKUAfXynZ
mso-ascii-font-familycambria	doc_831529852295_item	3708725	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_831529852295_item	3708726	et	0	cKUAfXynZ
new	doc_831529852295_item	3708727	et	0	cKUAfXynZ
roman	doc_831529852295_item	3708728	et	0	cKUAfXynZ
mso-hansi-font-familycambria	doc_831529852295_item	3708729	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708730	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708731	et	0	cKUAfXynZ
spanheaderchar	doc_831529852295_item	3708732	et	0	cKUAfXynZ
mso-style-nameheader	doc_831529852295_item	3708733	et	0	cKUAfXynZ
char	doc_831529852295_item	3708734	et	0	cKUAfXynZ
mso-style-noshowyes	doc_831529852295_item	3708735	et	0	cKUAfXynZ
mso-style-priority99	doc_831529852295_item	3708736	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708737	et	0	cKUAfXynZ
mso-style-lockedyes	doc_831529852295_item	3708738	et	0	cKUAfXynZ
mso-style-linkheader	doc_831529852295_item	3708739	et	0	cKUAfXynZ
mso-ansi-font-size110pt	doc_831529852295_item	3708740	et	0	cKUAfXynZ
mso-bidi-font-size110pt	doc_831529852295_item	3708741	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708742	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708743	et	0	cKUAfXynZ
spanfooterchar	doc_831529852295_item	3708744	et	0	cKUAfXynZ
mso-style-namefooter	doc_831529852295_item	3708745	et	0	cKUAfXynZ
char	doc_831529852295_item	3708746	et	0	cKUAfXynZ
mso-style-priority99	doc_831529852295_item	3708747	et	0	cKUAfXynZ
mso-style-unhideno	doc_831529852295_item	3708748	et	0	cKUAfXynZ
mso-style-lockedyes	doc_831529852295_item	3708749	et	0	cKUAfXynZ
mso-style-linkfooter	doc_831529852295_item	3708750	et	0	cKUAfXynZ
mso-ansi-font-size110pt	doc_831529852295_item	3708751	et	0	cKUAfXynZ
mso-bidi-font-size110pt	doc_831529852295_item	3708752	et	0	cKUAfXynZ
mso-ansi-languageru	doc_831529852295_item	3708753	et	0	cKUAfXynZ
mso-fareast-languageen-us	doc_831529852295_item	3708754	et	0	cKUAfXynZ
msochpdefault	doc_831529852295_item	3708755	et	0	cKUAfXynZ
mso-style-typeexport-only	doc_831529852295_item	3708756	et	0	cKUAfXynZ
mso-default-propsyes	doc_831529852295_item	3708757	et	0	cKUAfXynZ
font-size100pt	doc_831529852295_item	3708758	et	0	cKUAfXynZ
mso-ansi-font-size100pt	doc_831529852295_item	3708759	et	0	cKUAfXynZ
mso-bidi-font-size100pt	doc_831529852295_item	3708760	et	0	cKUAfXynZ
mso-ascii-font-familycalibri	doc_831529852295_item	3708761	et	0	cKUAfXynZ
mso-fareast-font-familycalibri	doc_831529852295_item	3708762	et	0	cKUAfXynZ
mso-hansi-font-familycalibri	doc_831529852295_item	3708763	et	0	cKUAfXynZ
page	doc_831529852295_item	3708764	et	0	cKUAfXynZ
section1	doc_831529852295_item	3708765	et	0	cKUAfXynZ
size5953pt	doc_831529852295_item	3708766	et	0	cKUAfXynZ
8419pt	doc_831529852295_item	3708767	et	0	cKUAfXynZ
margin20cm	doc_831529852295_item	3708768	et	0	cKUAfXynZ
418pt	doc_831529852295_item	3708769	et	0	cKUAfXynZ
585pt	doc_831529852295_item	3708770	et	0	cKUAfXynZ
855pt	doc_831529852295_item	3708771	et	0	cKUAfXynZ
mso-header-margin360pt	doc_831529852295_item	3708772	et	0	cKUAfXynZ
mso-footer-margin360pt	doc_831529852295_item	3708773	et	0	cKUAfXynZ
mso-paper-source0	doc_831529852295_item	3708774	et	0	cKUAfXynZ
divsection1	doc_831529852295_item	3708775	et	0	cKUAfXynZ
pagesection1	doc_831529852295_item	3708776	et	0	cKUAfXynZ
list	doc_831529852295_item	3708777	et	0	cKUAfXynZ
definitions	doc_831529852295_item	3708778	et	0	cKUAfXynZ
list	doc_831529852295_item	3708779	et	0	cKUAfXynZ
l0	doc_831529852295_item	3708780	et	0	cKUAfXynZ
mso-list-id730034925	doc_831529852295_item	3708781	et	0	cKUAfXynZ
mso-list-typehybrid	doc_831529852295_item	3708782	et	0	cKUAfXynZ
mso-list-template-ids478594298	doc_831529852295_item	3708783	et	0	cKUAfXynZ
68747281	doc_831529852295_item	3708784	et	0	cKUAfXynZ
68747289	doc_831529852295_item	3708785	et	0	cKUAfXynZ
68747291	doc_831529852295_item	3708786	et	0	cKUAfXynZ
68747279	doc_831529852295_item	3708787	et	0	cKUAfXynZ
68747289	doc_831529852295_item	3708788	et	0	cKUAfXynZ
68747291	doc_831529852295_item	3708789	et	0	cKUAfXynZ
68747279	doc_831529852295_item	3708790	et	0	cKUAfXynZ
68747289	doc_831529852295_item	3708791	et	0	cKUAfXynZ
68747291	doc_831529852295_item	3708792	et	0	cKUAfXynZ
list	doc_831529852295_item	3708793	et	0	cKUAfXynZ
l0level1	doc_831529852295_item	3708794	et	0	cKUAfXynZ
mso-level-text1	doc_831529852295_item	3708795	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708796	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708797	et	0	cKUAfXynZ
text-indent180pt	doc_831529852295_item	3708798	et	0	cKUAfXynZ
list	doc_831529852295_item	3708799	et	0	cKUAfXynZ
l1	doc_831529852295_item	3708800	et	0	cKUAfXynZ
mso-list-id784537919	doc_831529852295_item	3708801	et	0	cKUAfXynZ
mso-list-template-ids1641095446	doc_831529852295_item	3708802	et	0	cKUAfXynZ
list	doc_831529852295_item	3708803	et	0	cKUAfXynZ
l1level1	doc_831529852295_item	3708804	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708805	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708806	et	0	cKUAfXynZ
text-indent180pt	doc_831529852295_item	3708807	et	0	cKUAfXynZ
list	doc_831529852295_item	3708808	et	0	cKUAfXynZ
l1level2	doc_831529852295_item	3708809	et	0	cKUAfXynZ
mso-level-start-at2	doc_831529852295_item	3708810	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3708811	et	0	cKUAfXynZ
mso-level-text12	doc_831529852295_item	3708812	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708813	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708814	et	0	cKUAfXynZ
margin-left431pt	doc_831529852295_item	3708815	et	0	cKUAfXynZ
text-indent360pt	doc_831529852295_item	3708816	et	0	cKUAfXynZ
list	doc_831529852295_item	3708817	et	0	cKUAfXynZ
l1level3	doc_831529852295_item	3708818	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3708819	et	0	cKUAfXynZ
mso-level-text123	doc_831529852295_item	3708820	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708821	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708822	et	0	cKUAfXynZ
margin-left540pt	doc_831529852295_item	3708823	et	0	cKUAfXynZ
text-indent360pt	doc_831529852295_item	3708824	et	0	cKUAfXynZ
list	doc_831529852295_item	3708825	et	0	cKUAfXynZ
l1level4	doc_831529852295_item	3708826	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3708827	et	0	cKUAfXynZ
mso-level-text1234	doc_831529852295_item	3708828	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708829	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708830	et	0	cKUAfXynZ
margin-left720pt	doc_831529852295_item	3708831	et	0	cKUAfXynZ
text-indent540pt	doc_831529852295_item	3708832	et	0	cKUAfXynZ
list	doc_831529852295_item	3708833	et	0	cKUAfXynZ
l1level5	doc_831529852295_item	3708834	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3708835	et	0	cKUAfXynZ
mso-level-text12345	doc_831529852295_item	3708836	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708837	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708838	et	0	cKUAfXynZ
margin-left900pt	doc_831529852295_item	3708839	et	0	cKUAfXynZ
text-indent720pt	doc_831529852295_item	3708840	et	0	cKUAfXynZ
list	doc_831529852295_item	3708841	et	0	cKUAfXynZ
l1level6	doc_831529852295_item	3708842	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3708843	et	0	cKUAfXynZ
mso-level-text123456	doc_831529852295_item	3708844	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708845	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708846	et	0	cKUAfXynZ
margin-left1080pt	doc_831529852295_item	3708847	et	0	cKUAfXynZ
text-indent900pt	doc_831529852295_item	3708848	et	0	cKUAfXynZ
list	doc_831529852295_item	3708849	et	0	cKUAfXynZ
l1level7	doc_831529852295_item	3708850	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3708851	et	0	cKUAfXynZ
mso-level-text1234567	doc_831529852295_item	3708852	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708853	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708854	et	0	cKUAfXynZ
margin-left1080pt	doc_831529852295_item	3708855	et	0	cKUAfXynZ
text-indent900pt	doc_831529852295_item	3708856	et	0	cKUAfXynZ
list	doc_831529852295_item	3708857	et	0	cKUAfXynZ
l1level8	doc_831529852295_item	3708858	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3708859	et	0	cKUAfXynZ
mso-level-text12345678	doc_831529852295_item	3708860	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708861	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708862	et	0	cKUAfXynZ
margin-left1260pt	doc_831529852295_item	3708863	et	0	cKUAfXynZ
text-indent1080pt	doc_831529852295_item	3708864	et	0	cKUAfXynZ
list	doc_831529852295_item	3708865	et	0	cKUAfXynZ
l1level9	doc_831529852295_item	3708866	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3708867	et	0	cKUAfXynZ
mso-level-text123456789	doc_831529852295_item	3708868	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708869	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708870	et	0	cKUAfXynZ
margin-left1440pt	doc_831529852295_item	3708871	et	0	cKUAfXynZ
text-indent1260pt	doc_831529852295_item	3708872	et	0	cKUAfXynZ
list	doc_831529852295_item	3708873	et	0	cKUAfXynZ
l2	doc_831529852295_item	3708874	et	0	cKUAfXynZ
mso-list-id840318118	doc_831529852295_item	3708875	et	0	cKUAfXynZ
mso-list-template-ids1475655294	doc_831529852295_item	3708876	et	0	cKUAfXynZ
list	doc_831529852295_item	3708877	et	0	cKUAfXynZ
l2level1	doc_831529852295_item	3708878	et	0	cKUAfXynZ
mso-level-style-linkheading	doc_831529852295_item	3708879	et	0	cKUAfXynZ
1	doc_831529852295_item	3708880	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708881	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708882	et	0	cKUAfXynZ
margin-left180pt	doc_831529852295_item	3708883	et	0	cKUAfXynZ
text-indent180pt	doc_831529852295_item	3708884	et	0	cKUAfXynZ
mso-ansi-font-size200pt	doc_831529852295_item	3708885	et	0	cKUAfXynZ
positionrelative	doc_831529852295_item	3708886	et	0	cKUAfXynZ
top0pt	doc_831529852295_item	3708887	et	0	cKUAfXynZ
mso-text-raise0pt	doc_831529852295_item	3708888	et	0	cKUAfXynZ
list	doc_831529852295_item	3708889	et	0	cKUAfXynZ
l2level2	doc_831529852295_item	3708890	et	0	cKUAfXynZ
mso-level-style-linkheading	doc_831529852295_item	3708891	et	0	cKUAfXynZ
2	doc_831529852295_item	3708892	et	0	cKUAfXynZ
mso-level-text12	doc_831529852295_item	3708893	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708894	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708895	et	0	cKUAfXynZ
margin-left288pt	doc_831529852295_item	3708896	et	0	cKUAfXynZ
text-indent288pt	doc_831529852295_item	3708897	et	0	cKUAfXynZ
list	doc_831529852295_item	3708898	et	0	cKUAfXynZ
l2level3	doc_831529852295_item	3708899	et	0	cKUAfXynZ
mso-level-style-linkheading	doc_831529852295_item	3708900	et	0	cKUAfXynZ
3	doc_831529852295_item	3708901	et	0	cKUAfXynZ
mso-level-text123	doc_831529852295_item	3708902	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708903	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708904	et	0	cKUAfXynZ
margin-left360pt	doc_831529852295_item	3708905	et	0	cKUAfXynZ
text-indent360pt	doc_831529852295_item	3708906	et	0	cKUAfXynZ
list	doc_831529852295_item	3708907	et	0	cKUAfXynZ
l2level4	doc_831529852295_item	3708908	et	0	cKUAfXynZ
mso-level-style-linkheading	doc_831529852295_item	3708909	et	0	cKUAfXynZ
4	doc_831529852295_item	3708910	et	0	cKUAfXynZ
mso-level-text1234	doc_831529852295_item	3708911	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708912	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708913	et	0	cKUAfXynZ
margin-left432pt	doc_831529852295_item	3708914	et	0	cKUAfXynZ
text-indent432pt	doc_831529852295_item	3708915	et	0	cKUAfXynZ
list	doc_831529852295_item	3708916	et	0	cKUAfXynZ
l2level5	doc_831529852295_item	3708917	et	0	cKUAfXynZ
mso-level-style-linkheading	doc_831529852295_item	3708918	et	0	cKUAfXynZ
5	doc_831529852295_item	3708919	et	0	cKUAfXynZ
mso-level-text12345	doc_831529852295_item	3708920	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708921	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708922	et	0	cKUAfXynZ
margin-left504pt	doc_831529852295_item	3708923	et	0	cKUAfXynZ
text-indent504pt	doc_831529852295_item	3708924	et	0	cKUAfXynZ
list	doc_831529852295_item	3708925	et	0	cKUAfXynZ
l2level6	doc_831529852295_item	3708926	et	0	cKUAfXynZ
mso-level-style-linkheading	doc_831529852295_item	3708927	et	0	cKUAfXynZ
6	doc_831529852295_item	3708928	et	0	cKUAfXynZ
mso-level-text123456	doc_831529852295_item	3708929	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708930	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708931	et	0	cKUAfXynZ
margin-left576pt	doc_831529852295_item	3708932	et	0	cKUAfXynZ
text-indent576pt	doc_831529852295_item	3708933	et	0	cKUAfXynZ
list	doc_831529852295_item	3708934	et	0	cKUAfXynZ
l2level7	doc_831529852295_item	3708935	et	0	cKUAfXynZ
mso-level-style-linkheading	doc_831529852295_item	3708936	et	0	cKUAfXynZ
7	doc_831529852295_item	3708937	et	0	cKUAfXynZ
mso-level-text1234567	doc_831529852295_item	3708938	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708939	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708940	et	0	cKUAfXynZ
margin-left648pt	doc_831529852295_item	3708941	et	0	cKUAfXynZ
text-indent648pt	doc_831529852295_item	3708942	et	0	cKUAfXynZ
list	doc_831529852295_item	3708943	et	0	cKUAfXynZ
l2level8	doc_831529852295_item	3708944	et	0	cKUAfXynZ
mso-level-style-linkheading	doc_831529852295_item	3708945	et	0	cKUAfXynZ
8	doc_831529852295_item	3708946	et	0	cKUAfXynZ
mso-level-text12345678	doc_831529852295_item	3708947	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708948	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708949	et	0	cKUAfXynZ
margin-left720pt	doc_831529852295_item	3708950	et	0	cKUAfXynZ
text-indent720pt	doc_831529852295_item	3708951	et	0	cKUAfXynZ
list	doc_831529852295_item	3708952	et	0	cKUAfXynZ
l2level9	doc_831529852295_item	3708953	et	0	cKUAfXynZ
mso-level-style-linkheading	doc_831529852295_item	3708954	et	0	cKUAfXynZ
9	doc_831529852295_item	3708955	et	0	cKUAfXynZ
mso-level-text123456789	doc_831529852295_item	3708956	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708957	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708958	et	0	cKUAfXynZ
margin-left792pt	doc_831529852295_item	3708959	et	0	cKUAfXynZ
text-indent792pt	doc_831529852295_item	3708960	et	0	cKUAfXynZ
list	doc_831529852295_item	3708961	et	0	cKUAfXynZ
l3	doc_831529852295_item	3708962	et	0	cKUAfXynZ
mso-list-id850998022	doc_831529852295_item	3708963	et	0	cKUAfXynZ
mso-list-template-ids1054271170	doc_831529852295_item	3708964	et	0	cKUAfXynZ
list	doc_831529852295_item	3708965	et	0	cKUAfXynZ
l3level1	doc_831529852295_item	3708966	et	0	cKUAfXynZ
mso-level-start-at2	doc_831529852295_item	3708967	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708968	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708969	et	0	cKUAfXynZ
margin-left270pt	doc_831529852295_item	3708970	et	0	cKUAfXynZ
text-indent270pt	doc_831529852295_item	3708971	et	0	cKUAfXynZ
list	doc_831529852295_item	3708972	et	0	cKUAfXynZ
l3level2	doc_831529852295_item	3708973	et	0	cKUAfXynZ
mso-level-start-at2	doc_831529852295_item	3708974	et	0	cKUAfXynZ
mso-level-text12	doc_831529852295_item	3708975	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708976	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708977	et	0	cKUAfXynZ
margin-left791pt	doc_831529852295_item	3708978	et	0	cKUAfXynZ
text-indent360pt	doc_831529852295_item	3708979	et	0	cKUAfXynZ
list	doc_831529852295_item	3708980	et	0	cKUAfXynZ
l3level3	doc_831529852295_item	3708981	et	0	cKUAfXynZ
mso-level-text123	doc_831529852295_item	3708982	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708983	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708984	et	0	cKUAfXynZ
margin-left1402pt	doc_831529852295_item	3708985	et	0	cKUAfXynZ
text-indent540pt	doc_831529852295_item	3708986	et	0	cKUAfXynZ
list	doc_831529852295_item	3708987	et	0	cKUAfXynZ
l3level4	doc_831529852295_item	3708988	et	0	cKUAfXynZ
mso-level-text1234	doc_831529852295_item	3708989	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708990	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708991	et	0	cKUAfXynZ
margin-left1833pt	doc_831529852295_item	3708992	et	0	cKUAfXynZ
text-indent540pt	doc_831529852295_item	3708993	et	0	cKUAfXynZ
list	doc_831529852295_item	3708994	et	0	cKUAfXynZ
l3level5	doc_831529852295_item	3708995	et	0	cKUAfXynZ
mso-level-text12345	doc_831529852295_item	3708996	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3708997	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3708998	et	0	cKUAfXynZ
margin-left2444pt	doc_831529852295_item	3708999	et	0	cKUAfXynZ
text-indent720pt	doc_831529852295_item	3709000	et	0	cKUAfXynZ
list	doc_831529852295_item	3709001	et	0	cKUAfXynZ
l3level6	doc_831529852295_item	3709002	et	0	cKUAfXynZ
mso-level-text123456	doc_831529852295_item	3709003	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709004	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709005	et	0	cKUAfXynZ
margin-left3055pt	doc_831529852295_item	3709006	et	0	cKUAfXynZ
text-indent900pt	doc_831529852295_item	3709007	et	0	cKUAfXynZ
list	doc_831529852295_item	3709008	et	0	cKUAfXynZ
l3level7	doc_831529852295_item	3709009	et	0	cKUAfXynZ
mso-level-text1234567	doc_831529852295_item	3709010	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709011	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709012	et	0	cKUAfXynZ
margin-left3666pt	doc_831529852295_item	3709013	et	0	cKUAfXynZ
text-indent1080pt	doc_831529852295_item	3709014	et	0	cKUAfXynZ
list	doc_831529852295_item	3709015	et	0	cKUAfXynZ
l3level8	doc_831529852295_item	3709016	et	0	cKUAfXynZ
mso-level-text12345678	doc_831529852295_item	3709017	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709018	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709019	et	0	cKUAfXynZ
margin-left4277pt	doc_831529852295_item	3709020	et	0	cKUAfXynZ
text-indent1260pt	doc_831529852295_item	3709021	et	0	cKUAfXynZ
list	doc_831529852295_item	3709022	et	0	cKUAfXynZ
l3level9	doc_831529852295_item	3709023	et	0	cKUAfXynZ
mso-level-text123456789	doc_831529852295_item	3709024	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709025	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709026	et	0	cKUAfXynZ
margin-left4708pt	doc_831529852295_item	3709027	et	0	cKUAfXynZ
text-indent1260pt	doc_831529852295_item	3709028	et	0	cKUAfXynZ
list	doc_831529852295_item	3709029	et	0	cKUAfXynZ
l4	doc_831529852295_item	3709030	et	0	cKUAfXynZ
mso-list-id1133213412	doc_831529852295_item	3709031	et	0	cKUAfXynZ
mso-list-typehybrid	doc_831529852295_item	3709032	et	0	cKUAfXynZ
mso-list-template-ids182494404	doc_831529852295_item	3709033	et	0	cKUAfXynZ
68747281	doc_831529852295_item	3709034	et	0	cKUAfXynZ
68747289	doc_831529852295_item	3709035	et	0	cKUAfXynZ
68747291	doc_831529852295_item	3709036	et	0	cKUAfXynZ
68747279	doc_831529852295_item	3709037	et	0	cKUAfXynZ
68747289	doc_831529852295_item	3709038	et	0	cKUAfXynZ
68747291	doc_831529852295_item	3709039	et	0	cKUAfXynZ
68747279	doc_831529852295_item	3709040	et	0	cKUAfXynZ
68747289	doc_831529852295_item	3709041	et	0	cKUAfXynZ
68747291	doc_831529852295_item	3709042	et	0	cKUAfXynZ
list	doc_831529852295_item	3709043	et	0	cKUAfXynZ
l4level1	doc_831529852295_item	3709044	et	0	cKUAfXynZ
mso-level-text1	doc_831529852295_item	3709045	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709046	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709047	et	0	cKUAfXynZ
text-indent180pt	doc_831529852295_item	3709048	et	0	cKUAfXynZ
list	doc_831529852295_item	3709049	et	0	cKUAfXynZ
l5	doc_831529852295_item	3709050	et	0	cKUAfXynZ
mso-list-id1259366248	doc_831529852295_item	3709051	et	0	cKUAfXynZ
mso-list-typehybrid	doc_831529852295_item	3709052	et	0	cKUAfXynZ
mso-list-template-ids152275322	doc_831529852295_item	3709053	et	0	cKUAfXynZ
68747279	doc_831529852295_item	3709054	et	0	cKUAfXynZ
68747289	doc_831529852295_item	3709055	et	0	cKUAfXynZ
68747291	doc_831529852295_item	3709056	et	0	cKUAfXynZ
68747279	doc_831529852295_item	3709057	et	0	cKUAfXynZ
68747289	doc_831529852295_item	3709058	et	0	cKUAfXynZ
68747291	doc_831529852295_item	3709059	et	0	cKUAfXynZ
68747279	doc_831529852295_item	3709060	et	0	cKUAfXynZ
68747289	doc_831529852295_item	3709061	et	0	cKUAfXynZ
68747291	doc_831529852295_item	3709062	et	0	cKUAfXynZ
list	doc_831529852295_item	3709063	et	0	cKUAfXynZ
l5level1	doc_831529852295_item	3709064	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709065	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709066	et	0	cKUAfXynZ
text-indent180pt	doc_831529852295_item	3709067	et	0	cKUAfXynZ
list	doc_831529852295_item	3709068	et	0	cKUAfXynZ
l6	doc_831529852295_item	3709069	et	0	cKUAfXynZ
mso-list-id1415280194	doc_831529852295_item	3709070	et	0	cKUAfXynZ
mso-list-typehybrid	doc_831529852295_item	3709071	et	0	cKUAfXynZ
mso-list-template-ids485377560	doc_831529852295_item	3709072	et	0	cKUAfXynZ
1348317126	doc_831529852295_item	3709073	et	0	cKUAfXynZ
68747267	doc_831529852295_item	3709074	et	0	cKUAfXynZ
68747269	doc_831529852295_item	3709075	et	0	cKUAfXynZ
68747265	doc_831529852295_item	3709076	et	0	cKUAfXynZ
68747267	doc_831529852295_item	3709077	et	0	cKUAfXynZ
68747269	doc_831529852295_item	3709078	et	0	cKUAfXynZ
68747265	doc_831529852295_item	3709079	et	0	cKUAfXynZ
68747267	doc_831529852295_item	3709080	et	0	cKUAfXynZ
68747269	doc_831529852295_item	3709081	et	0	cKUAfXynZ
list	doc_831529852295_item	3709082	et	0	cKUAfXynZ
l6level1	doc_831529852295_item	3709083	et	0	cKUAfXynZ
mso-level-start-at0	doc_831529852295_item	3709084	et	0	cKUAfXynZ
mso-level-number-formatbullet	doc_831529852295_item	3709085	et	0	cKUAfXynZ
mso-level-text	doc_831529852295_item	3709086	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709087	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709088	et	0	cKUAfXynZ
margin-left180pt	doc_831529852295_item	3709089	et	0	cKUAfXynZ
text-indent180pt	doc_831529852295_item	3709090	et	0	cKUAfXynZ
font-familycalibrisans-serif	doc_831529852295_item	3709091	et	0	cKUAfXynZ
mso-fareast-font-familycalibri	doc_831529852295_item	3709092	et	0	cKUAfXynZ
mso-bidi-font-familycalibri	doc_831529852295_item	3709093	et	0	cKUAfXynZ
list	doc_831529852295_item	3709094	et	0	cKUAfXynZ
l7	doc_831529852295_item	3709095	et	0	cKUAfXynZ
mso-list-id1892573634	doc_831529852295_item	3709096	et	0	cKUAfXynZ
mso-list-template-ids1641095446	doc_831529852295_item	3709097	et	0	cKUAfXynZ
list	doc_831529852295_item	3709098	et	0	cKUAfXynZ
l7level1	doc_831529852295_item	3709099	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709100	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709101	et	0	cKUAfXynZ
text-indent180pt	doc_831529852295_item	3709102	et	0	cKUAfXynZ
list	doc_831529852295_item	3709103	et	0	cKUAfXynZ
l7level2	doc_831529852295_item	3709104	et	0	cKUAfXynZ
mso-level-start-at2	doc_831529852295_item	3709105	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3709106	et	0	cKUAfXynZ
mso-level-text12	doc_831529852295_item	3709107	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709108	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709109	et	0	cKUAfXynZ
margin-left431pt	doc_831529852295_item	3709110	et	0	cKUAfXynZ
text-indent360pt	doc_831529852295_item	3709111	et	0	cKUAfXynZ
list	doc_831529852295_item	3709112	et	0	cKUAfXynZ
l7level3	doc_831529852295_item	3709113	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3709114	et	0	cKUAfXynZ
mso-level-text123	doc_831529852295_item	3709115	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709116	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709117	et	0	cKUAfXynZ
margin-left540pt	doc_831529852295_item	3709118	et	0	cKUAfXynZ
text-indent360pt	doc_831529852295_item	3709119	et	0	cKUAfXynZ
list	doc_831529852295_item	3709120	et	0	cKUAfXynZ
l7level4	doc_831529852295_item	3709121	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3709122	et	0	cKUAfXynZ
mso-level-text1234	doc_831529852295_item	3709123	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709124	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709125	et	0	cKUAfXynZ
margin-left720pt	doc_831529852295_item	3709126	et	0	cKUAfXynZ
text-indent540pt	doc_831529852295_item	3709127	et	0	cKUAfXynZ
list	doc_831529852295_item	3709128	et	0	cKUAfXynZ
l7level5	doc_831529852295_item	3709129	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3709130	et	0	cKUAfXynZ
mso-level-text12345	doc_831529852295_item	3709131	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709132	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709133	et	0	cKUAfXynZ
margin-left900pt	doc_831529852295_item	3709134	et	0	cKUAfXynZ
text-indent720pt	doc_831529852295_item	3709135	et	0	cKUAfXynZ
list	doc_831529852295_item	3709136	et	0	cKUAfXynZ
l7level6	doc_831529852295_item	3709137	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3709138	et	0	cKUAfXynZ
mso-level-text123456	doc_831529852295_item	3709139	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709140	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709141	et	0	cKUAfXynZ
margin-left1080pt	doc_831529852295_item	3709142	et	0	cKUAfXynZ
text-indent900pt	doc_831529852295_item	3709143	et	0	cKUAfXynZ
list	doc_831529852295_item	3709144	et	0	cKUAfXynZ
l7level7	doc_831529852295_item	3709145	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3709146	et	0	cKUAfXynZ
mso-level-text1234567	doc_831529852295_item	3709147	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709148	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709149	et	0	cKUAfXynZ
margin-left1080pt	doc_831529852295_item	3709150	et	0	cKUAfXynZ
text-indent900pt	doc_831529852295_item	3709151	et	0	cKUAfXynZ
list	doc_831529852295_item	3709152	et	0	cKUAfXynZ
l7level8	doc_831529852295_item	3709153	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3709154	et	0	cKUAfXynZ
mso-level-text12345678	doc_831529852295_item	3709155	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709156	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709157	et	0	cKUAfXynZ
margin-left1260pt	doc_831529852295_item	3709158	et	0	cKUAfXynZ
text-indent1080pt	doc_831529852295_item	3709159	et	0	cKUAfXynZ
list	doc_831529852295_item	3709160	et	0	cKUAfXynZ
l7level9	doc_831529852295_item	3709161	et	0	cKUAfXynZ
mso-level-legal-formatyes	doc_831529852295_item	3709162	et	0	cKUAfXynZ
mso-level-text123456789	doc_831529852295_item	3709163	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709164	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709165	et	0	cKUAfXynZ
margin-left1440pt	doc_831529852295_item	3709166	et	0	cKUAfXynZ
text-indent1260pt	doc_831529852295_item	3709167	et	0	cKUAfXynZ
list	doc_831529852295_item	3709168	et	0	cKUAfXynZ
l8	doc_831529852295_item	3709169	et	0	cKUAfXynZ
mso-list-id1948538037	doc_831529852295_item	3709170	et	0	cKUAfXynZ
mso-list-typehybrid	doc_831529852295_item	3709171	et	0	cKUAfXynZ
mso-list-template-ids1097928406	doc_831529852295_item	3709172	et	0	cKUAfXynZ
68747279	doc_831529852295_item	3709173	et	0	cKUAfXynZ
68747289	doc_831529852295_item	3709174	et	0	cKUAfXynZ
68747291	doc_831529852295_item	3709175	et	0	cKUAfXynZ
68747279	doc_831529852295_item	3709176	et	0	cKUAfXynZ
68747289	doc_831529852295_item	3709177	et	0	cKUAfXynZ
68747291	doc_831529852295_item	3709178	et	0	cKUAfXynZ
68747279	doc_831529852295_item	3709179	et	0	cKUAfXynZ
68747289	doc_831529852295_item	3709180	et	0	cKUAfXynZ
68747291	doc_831529852295_item	3709181	et	0	cKUAfXynZ
list	doc_831529852295_item	3709182	et	0	cKUAfXynZ
l8level1	doc_831529852295_item	3709183	et	0	cKUAfXynZ
mso-level-tab-stopnone	doc_831529852295_item	3709184	et	0	cKUAfXynZ
mso-level-number-positionleft	doc_831529852295_item	3709185	et	0	cKUAfXynZ
text-indent180pt	doc_831529852295_item	3709186	et	0	cKUAfXynZ
ol	doc_831529852295_item	3709187	et	0	cKUAfXynZ
margin-bottom0cm	doc_831529852295_item	3709188	et	0	cKUAfXynZ
ul	doc_831529852295_item	3709189	et	0	cKUAfXynZ
margin-bottom0cm	doc_831529852295_item	3709190	et	0	cKUAfXynZ
gt	doc_831529852295_item	3709191	et	0	cKUAfXynZ
tallinna	doc_831529852295_item	3709192	et	0	cKUAfXynZ
ülikool	doc_831529852295_item	3709193	et	0	cKUAfXynZ
slaavi	doc_831529852295_item	3709194	et	0	cKUAfXynZ
keelte	doc_831529852295_item	3709195	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709196	et	0	cKUAfXynZ
kultuuride	doc_831529852295_item	3709197	et	0	cKUAfXynZ
instituut	doc_831529852295_item	3709198	et	0	cKUAfXynZ
emakeele	doc_831529852295_item	3709199	et	0	cKUAfXynZ
õpetamine	doc_831529852295_item	3709200	et	0	cKUAfXynZ
referaat	doc_831529852295_item	3709201	et	0	cKUAfXynZ
tallinn	doc_831529852295_item	3709202	et	0	cKUAfXynZ
2009	doc_831529852295_item	3709203	et	0	cKUAfXynZ
sisukord	doc_831529852295_item	3709204	et	0	cKUAfXynZ
sissejuhatus	doc_831529852295_item	3709205	et	0	cKUAfXynZ
4	doc_831529852295_item	3709206	et	0	cKUAfXynZ
1	doc_831529852295_item	3709207	et	0	cKUAfXynZ
õpetamismeetodid	doc_831529852295_item	3709208	et	0	cKUAfXynZ
5	doc_831529852295_item	3709209	et	0	cKUAfXynZ
2	doc_831529852295_item	3709210	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3709211	et	0	cKUAfXynZ
6	doc_831529852295_item	3709212	et	0	cKUAfXynZ
21	doc_831529852295_item	3709213	et	0	cKUAfXynZ
väärtustav	doc_831529852295_item	3709214	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3709215	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3709216	et	0	cKUAfXynZ
nautiv	doc_831529852295_item	3709217	et	0	cKUAfXynZ
7	doc_831529852295_item	3709218	et	0	cKUAfXynZ
22	doc_831529852295_item	3709219	et	0	cKUAfXynZ
tähelepanelik	doc_831529852295_item	3709220	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3709221	et	0	cKUAfXynZ
7	doc_831529852295_item	3709222	et	0	cKUAfXynZ
23	doc_831529852295_item	3709223	et	0	cKUAfXynZ
kriitiline	doc_831529852295_item	3709224	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3709225	et	0	cKUAfXynZ
7	doc_831529852295_item	3709226	et	0	cKUAfXynZ
3	doc_831529852295_item	3709227	et	0	cKUAfXynZ
rääkimine	doc_831529852295_item	3709228	et	0	cKUAfXynZ
9	doc_831529852295_item	3709229	et	0	cKUAfXynZ
31	doc_831529852295_item	3709230	et	0	cKUAfXynZ
jutustamine	doc_831529852295_item	3709231	et	0	cKUAfXynZ
9	doc_831529852295_item	3709232	et	0	cKUAfXynZ
32	doc_831529852295_item	3709233	et	0	cKUAfXynZ
vestlus	doc_831529852295_item	3709234	et	0	cKUAfXynZ
10	doc_831529852295_item	3709235	et	0	cKUAfXynZ
33	doc_831529852295_item	3709236	et	0	cKUAfXynZ
diskussioon	doc_831529852295_item	3709237	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3709238	et	0	cKUAfXynZ
arutlus	doc_831529852295_item	3709239	et	0	cKUAfXynZ
10	doc_831529852295_item	3709240	et	0	cKUAfXynZ
34	doc_831529852295_item	3709241	et	0	cKUAfXynZ
väitlus	doc_831529852295_item	3709242	et	0	cKUAfXynZ
10	doc_831529852295_item	3709243	et	0	cKUAfXynZ
35	doc_831529852295_item	3709244	et	0	cKUAfXynZ
läbirääkimised	doc_831529852295_item	3709245	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3709246	et	0	cKUAfXynZ
parlamentaarse	doc_831529852295_item	3709247	et	0	cKUAfXynZ
protseduurijärgimine	doc_831529852295_item	3709248	et	0	cKUAfXynZ
11	doc_831529852295_item	3709249	et	0	cKUAfXynZ
36	doc_831529852295_item	3709250	et	0	cKUAfXynZ
intervjueerimine	doc_831529852295_item	3709251	et	0	cKUAfXynZ
11	doc_831529852295_item	3709252	et	0	cKUAfXynZ
37	doc_831529852295_item	3709253	et	0	cKUAfXynZ
sotsiaalsete	doc_831529852295_item	3709254	et	0	cKUAfXynZ
suhete	doc_831529852295_item	3709255	et	0	cKUAfXynZ
väljendamine	doc_831529852295_item	3709256	et	0	cKUAfXynZ
11	doc_831529852295_item	3709257	et	0	cKUAfXynZ
4	doc_831529852295_item	3709258	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3709259	et	0	cKUAfXynZ
13	doc_831529852295_item	3709260	et	0	cKUAfXynZ
41	doc_831529852295_item	3709261	et	0	cKUAfXynZ
akadeemiline	doc_831529852295_item	3709262	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3709263	et	0	cKUAfXynZ
13	doc_831529852295_item	3709264	et	0	cKUAfXynZ
42	doc_831529852295_item	3709265	et	0	cKUAfXynZ
utilitaarne	doc_831529852295_item	3709266	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3709267	et	0	cKUAfXynZ
13	doc_831529852295_item	3709268	et	0	cKUAfXynZ
43	doc_831529852295_item	3709269	et	0	cKUAfXynZ
romantiline	doc_831529852295_item	3709270	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3709271	et	0	cKUAfXynZ
13	doc_831529852295_item	3709272	et	0	cKUAfXynZ
44	doc_831529852295_item	3709273	et	0	cKUAfXynZ
kognetiivse	doc_831529852295_item	3709274	et	0	cKUAfXynZ
arengu	doc_831529852295_item	3709275	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3709276	et	0	cKUAfXynZ
13	doc_831529852295_item	3709277	et	0	cKUAfXynZ
45	doc_831529852295_item	3709278	et	0	cKUAfXynZ
võrdõiguslik	doc_831529852295_item	3709279	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3709280	et	0	cKUAfXynZ
14	doc_831529852295_item	3709281	et	0	cKUAfXynZ
46	doc_831529852295_item	3709282	et	0	cKUAfXynZ
lugemisprogramm	doc_831529852295_item	3709283	et	0	cKUAfXynZ
14	doc_831529852295_item	3709284	et	0	cKUAfXynZ
5	doc_831529852295_item	3709285	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3709286	et	0	cKUAfXynZ
16	doc_831529852295_item	3709287	et	0	cKUAfXynZ
51	doc_831529852295_item	3709288	et	0	cKUAfXynZ
käekiri	doc_831529852295_item	3709289	et	0	cKUAfXynZ
17	doc_831529852295_item	3709290	et	0	cKUAfXynZ
52	doc_831529852295_item	3709291	et	0	cKUAfXynZ
kirjutamiseks	doc_831529852295_item	3709292	et	0	cKUAfXynZ
valmisolek	doc_831529852295_item	3709293	et	0	cKUAfXynZ
18	doc_831529852295_item	3709294	et	0	cKUAfXynZ
53	doc_831529852295_item	3709295	et	0	cKUAfXynZ
grammatikaõpetamine	doc_831529852295_item	3709296	et	0	cKUAfXynZ
18	doc_831529852295_item	3709297	et	0	cKUAfXynZ
kokkuvõtte	doc_831529852295_item	3709298	et	0	cKUAfXynZ
20	doc_831529852295_item	3709299	et	0	cKUAfXynZ
kasutatud	doc_831529852295_item	3709300	et	0	cKUAfXynZ
kirjandus	doc_831529852295_item	3709301	et	0	cKUAfXynZ
21	doc_831529852295_item	3709302	et	0	cKUAfXynZ
sissejuhatus	doc_831529852295_item	3709303	et	0	cKUAfXynZ
käesolev	doc_831529852295_item	3709304	et	0	cKUAfXynZ
referaat	doc_831529852295_item	3709305	et	0	cKUAfXynZ
on	doc_831529852295_item	3709306	et	0	cKUAfXynZ
pühendatud	doc_831529852295_item	3709307	et	0	cKUAfXynZ
emakeele	doc_831529852295_item	3709308	et	0	cKUAfXynZ
õpetamisele	doc_831529852295_item	3709309	et	0	cKUAfXynZ
referaadis	doc_831529852295_item	3709310	et	0	cKUAfXynZ
kasutatakse	doc_831529852295_item	3709311	et	0	cKUAfXynZ
anne	doc_831529852295_item	3709312	et	0	cKUAfXynZ
uuseni	doc_831529852295_item	3709313	et	0	cKUAfXynZ
raamatu	doc_831529852295_item	3709314	et	0	cKUAfXynZ
emakeele	doc_831529852295_item	3709315	et	0	cKUAfXynZ
õpetamisest	doc_831529852295_item	3709316	et	0	cKUAfXynZ
mis	doc_831529852295_item	3709317	et	0	cKUAfXynZ
on	doc_831529852295_item	3709318	et	0	cKUAfXynZ
seotud	doc_831529852295_item	3709319	et	0	cKUAfXynZ
emakeele	doc_831529852295_item	3709320	et	0	cKUAfXynZ
õpetamisega	doc_831529852295_item	3709321	et	0	cKUAfXynZ
selline	doc_831529852295_item	3709322	et	0	cKUAfXynZ
raamat	doc_831529852295_item	3709323	et	0	cKUAfXynZ
on	doc_831529852295_item	3709324	et	0	cKUAfXynZ
kasulik	doc_831529852295_item	3709325	et	0	cKUAfXynZ
nendele	doc_831529852295_item	3709326	et	0	cKUAfXynZ
keda	doc_831529852295_item	3709327	et	0	cKUAfXynZ
huvitab	doc_831529852295_item	3709328	et	0	cKUAfXynZ
emakeele	doc_831529852295_item	3709329	et	0	cKUAfXynZ
õpetamine	doc_831529852295_item	3709330	et	0	cKUAfXynZ
raamat	doc_831529852295_item	3709331	et	0	cKUAfXynZ
koosneb	doc_831529852295_item	3709332	et	0	cKUAfXynZ
kolmest	doc_831529852295_item	3709333	et	0	cKUAfXynZ
osast	doc_831529852295_item	3709334	et	0	cKUAfXynZ
raamat	doc_831529852295_item	3709335	et	0	cKUAfXynZ
on	doc_831529852295_item	3709336	et	0	cKUAfXynZ
loogiliselt	doc_831529852295_item	3709337	et	0	cKUAfXynZ
ehitatud	doc_831529852295_item	3709338	et	0	cKUAfXynZ
selles	doc_831529852295_item	3709339	et	0	cKUAfXynZ
antakse	doc_831529852295_item	3709340	et	0	cKUAfXynZ
ülevaade	doc_831529852295_item	3709341	et	0	cKUAfXynZ
emakeele	doc_831529852295_item	3709342	et	0	cKUAfXynZ
õpetamise	doc_831529852295_item	3709343	et	0	cKUAfXynZ
alustest	doc_831529852295_item	3709344	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709345	et	0	cKUAfXynZ
võimalustest	doc_831529852295_item	3709346	et	0	cKUAfXynZ
sisaldatakse	doc_831529852295_item	3709347	et	0	cKUAfXynZ
iga	doc_831529852295_item	3709348	et	0	cKUAfXynZ
osaoskuse	doc_831529852295_item	3709349	et	0	cKUAfXynZ
kohta	doc_831529852295_item	3709350	et	0	cKUAfXynZ
näiteid	doc_831529852295_item	3709351	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709352	et	0	cKUAfXynZ
tsiteeritakse	doc_831529852295_item	3709353	et	0	cKUAfXynZ
erinevaid	doc_831529852295_item	3709354	et	0	cKUAfXynZ
autoreid	doc_831529852295_item	3709355	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3709356	et	0	cKUAfXynZ
on	doc_831529852295_item	3709357	et	0	cKUAfXynZ
piisavalt	doc_831529852295_item	3709358	et	0	cKUAfXynZ
termineid	doc_831529852295_item	3709359	et	0	cKUAfXynZ
neid	doc_831529852295_item	3709360	et	0	cKUAfXynZ
kasutatakse	doc_831529852295_item	3709361	et	0	cKUAfXynZ
korrektselt	doc_831529852295_item	3709362	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709363	et	0	cKUAfXynZ
selgelt	doc_831529852295_item	3709364	et	0	cKUAfXynZ
anne	doc_831529852295_item	3709365	et	0	cKUAfXynZ
uusen	doc_831529852295_item	3709366	et	0	cKUAfXynZ
mainib	doc_831529852295_item	3709367	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709368	et	0	cKUAfXynZ
tänab	doc_831529852295_item	3709369	et	0	cKUAfXynZ
oma	doc_831529852295_item	3709370	et	0	cKUAfXynZ
kolleege	doc_831529852295_item	3709371	et	0	cKUAfXynZ
eriti	doc_831529852295_item	3709372	et	0	cKUAfXynZ
mare	doc_831529852295_item	3709373	et	0	cKUAfXynZ
müürseppa	doc_831529852295_item	3709374	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709375	et	0	cKUAfXynZ
krista	doc_831529852295_item	3709376	et	0	cKUAfXynZ
kerget	doc_831529852295_item	3709377	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3709378	et	0	cKUAfXynZ
kirjutatakse	doc_831529852295_item	3709379	et	0	cKUAfXynZ
et	doc_831529852295_item	3709380	et	0	cKUAfXynZ
arenenud	doc_831529852295_item	3709381	et	0	cKUAfXynZ
riikides	doc_831529852295_item	3709382	et	0	cKUAfXynZ
pööratakse	doc_831529852295_item	3709383	et	0	cKUAfXynZ
üha	doc_831529852295_item	3709384	et	0	cKUAfXynZ
rohkem	doc_831529852295_item	3709385	et	0	cKUAfXynZ
tähelepanu	doc_831529852295_item	3709386	et	0	cKUAfXynZ
mõistetud	doc_831529852295_item	3709387	et	0	cKUAfXynZ
õppimisele	doc_831529852295_item	3709388	et	0	cKUAfXynZ
püütakse	doc_831529852295_item	3709389	et	0	cKUAfXynZ
suunata	doc_831529852295_item	3709390	et	0	cKUAfXynZ
õpilasi	doc_831529852295_item	3709391	et	0	cKUAfXynZ
õppimisprotsessi	doc_831529852295_item	3709392	et	0	cKUAfXynZ
juhtima	doc_831529852295_item	3709393	et	0	cKUAfXynZ
mõistma	doc_831529852295_item	3709394	et	0	cKUAfXynZ
analüüsima	doc_831529852295_item	3709395	et	0	cKUAfXynZ
informatsiooni	doc_831529852295_item	3709396	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709397	et	0	cKUAfXynZ
kontrollima	doc_831529852295_item	3709398	et	0	cKUAfXynZ
oma	doc_831529852295_item	3709399	et	0	cKUAfXynZ
tulemusi	doc_831529852295_item	3709400	et	0	cKUAfXynZ
kõik	doc_831529852295_item	3709401	et	0	cKUAfXynZ
see	doc_831529852295_item	3709402	et	0	cKUAfXynZ
on	doc_831529852295_item	3709403	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3709404	et	0	cKUAfXynZ
ka	doc_831529852295_item	3709405	et	0	cKUAfXynZ
emakeeleõpetuse	doc_831529852295_item	3709406	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3709407	et	0	cKUAfXynZ
et	doc_831529852295_item	3709408	et	0	cKUAfXynZ
vallata	doc_831529852295_item	3709409	et	0	cKUAfXynZ
vabalt	doc_831529852295_item	3709410	et	0	cKUAfXynZ
emakeelt	doc_831529852295_item	3709411	et	0	cKUAfXynZ
on	doc_831529852295_item	3709412	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3709413	et	0	cKUAfXynZ
tähelepanu	doc_831529852295_item	3709414	et	0	cKUAfXynZ
pöörata	doc_831529852295_item	3709415	et	0	cKUAfXynZ
kõikidele	doc_831529852295_item	3709416	et	0	cKUAfXynZ
keelelisele	doc_831529852295_item	3709417	et	0	cKUAfXynZ
suhtluse	doc_831529852295_item	3709418	et	0	cKUAfXynZ
osaoskustele	doc_831529852295_item	3709419	et	0	cKUAfXynZ
need	doc_831529852295_item	3709420	et	0	cKUAfXynZ
on	doc_831529852295_item	3709421	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3709422	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3709423	et	0	cKUAfXynZ
rääkimine	doc_831529852295_item	3709424	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709425	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3709426	et	0	cKUAfXynZ
eisele	doc_831529852295_item	3709427	et	0	cKUAfXynZ
1991	doc_831529852295_item	3709428	et	0	cKUAfXynZ
galant	doc_831529852295_item	3709429	et	0	cKUAfXynZ
1990	doc_831529852295_item	3709430	et	0	cKUAfXynZ
jansen	doc_831529852295_item	3709431	et	0	cKUAfXynZ
1978	doc_831529852295_item	3709432	et	0	cKUAfXynZ
viidatud	doc_831529852295_item	3709433	et	0	cKUAfXynZ
uusen	doc_831529852295_item	3709434	et	0	cKUAfXynZ
2002	doc_831529852295_item	3709435	et	0	cKUAfXynZ
järgi	doc_831529852295_item	3709436	et	0	cKUAfXynZ
eestis	doc_831529852295_item	3709437	et	0	cKUAfXynZ
on	doc_831529852295_item	3709438	et	0	cKUAfXynZ
hakatud	doc_831529852295_item	3709439	et	0	cKUAfXynZ
tähelepanu	doc_831529852295_item	3709440	et	0	cKUAfXynZ
nendele	doc_831529852295_item	3709441	et	0	cKUAfXynZ
suundadele	doc_831529852295_item	3709442	et	0	cKUAfXynZ
pöörama	doc_831529852295_item	3709443	et	0	cKUAfXynZ
ka	doc_831529852295_item	3709444	et	0	cKUAfXynZ
kooli	doc_831529852295_item	3709445	et	0	cKUAfXynZ
eesmärgiks	doc_831529852295_item	3709446	et	0	cKUAfXynZ
on	doc_831529852295_item	3709447	et	0	cKUAfXynZ
arendada	doc_831529852295_item	3709448	et	0	cKUAfXynZ
arutlevat	doc_831529852295_item	3709449	et	0	cKUAfXynZ
mõtlemisoskust	doc_831529852295_item	3709450	et	0	cKUAfXynZ
ning	doc_831529852295_item	3709451	et	0	cKUAfXynZ
anda	doc_831529852295_item	3709452	et	0	cKUAfXynZ
vajalikke	doc_831529852295_item	3709453	et	0	cKUAfXynZ
teatmeid	doc_831529852295_item	3709454	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709455	et	0	cKUAfXynZ
oskusi	doc_831529852295_item	3709456	et	0	cKUAfXynZ
mis	doc_831529852295_item	3709457	et	0	cKUAfXynZ
läheksid	doc_831529852295_item	3709458	et	0	cKUAfXynZ
kasuks	doc_831529852295_item	3709459	et	0	cKUAfXynZ
on	doc_831529852295_item	3709460	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3709461	et	0	cKUAfXynZ
et	doc_831529852295_item	3709462	et	0	cKUAfXynZ
laps	doc_831529852295_item	3709463	et	0	cKUAfXynZ
oskaks	doc_831529852295_item	3709464	et	0	cKUAfXynZ
oma	doc_831529852295_item	3709465	et	0	cKUAfXynZ
arvamust	doc_831529852295_item	3709466	et	0	cKUAfXynZ
selgelt	doc_831529852295_item	3709467	et	0	cKUAfXynZ
väljendada	doc_831529852295_item	3709468	et	0	cKUAfXynZ
sellepärast	doc_831529852295_item	3709469	et	0	cKUAfXynZ
ongi	doc_831529852295_item	3709470	et	0	cKUAfXynZ
emakeel	doc_831529852295_item	3709471	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3709472	et	0	cKUAfXynZ
et	doc_831529852295_item	3709473	et	0	cKUAfXynZ
oma	doc_831529852295_item	3709474	et	0	cKUAfXynZ
tegevust	doc_831529852295_item	3709475	et	0	cKUAfXynZ
analüüsida	doc_831529852295_item	3709476	et	0	cKUAfXynZ
mõista	doc_831529852295_item	3709477	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709478	et	0	cKUAfXynZ
hinnata	doc_831529852295_item	3709479	et	0	cKUAfXynZ
tulemusi	doc_831529852295_item	3709480	et	0	cKUAfXynZ
1	doc_831529852295_item	3709481	et	0	cKUAfXynZ
õpetamismeetodid	doc_831529852295_item	3709482	et	0	cKUAfXynZ
emakeele	doc_831529852295_item	3709483	et	0	cKUAfXynZ
õpetamise	doc_831529852295_item	3709484	et	0	cKUAfXynZ
põhimõtted	doc_831529852295_item	3709485	et	0	cKUAfXynZ
on	doc_831529852295_item	3709486	et	0	cKUAfXynZ
järgmised	doc_831529852295_item	3709487	et	0	cKUAfXynZ
terviklikkus	doc_831529852295_item	3709488	et	0	cKUAfXynZ
teadlikkus	doc_831529852295_item	3709489	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709490	et	0	cKUAfXynZ
kommunikatiivsus	doc_831529852295_item	3709491	et	0	cKUAfXynZ
terviklikkus	doc_831529852295_item	3709492	et	0	cKUAfXynZ
tähendab	doc_831529852295_item	3709493	et	0	cKUAfXynZ
et	doc_831529852295_item	3709494	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3709495	et	0	cKUAfXynZ
rääkimine	doc_831529852295_item	3709496	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709497	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3709498	et	0	cKUAfXynZ
on	doc_831529852295_item	3709499	et	0	cKUAfXynZ
omavahel	doc_831529852295_item	3709500	et	0	cKUAfXynZ
seotud	doc_831529852295_item	3709501	et	0	cKUAfXynZ
tunniteema	doc_831529852295_item	3709502	et	0	cKUAfXynZ
lugemispala	doc_831529852295_item	3709503	et	0	cKUAfXynZ
või	doc_831529852295_item	3709504	et	0	cKUAfXynZ
situatsiooni	doc_831529852295_item	3709505	et	0	cKUAfXynZ
kaudu	doc_831529852295_item	3709506	et	0	cKUAfXynZ
õigekirjaküsimus	doc_831529852295_item	3709507	et	0	cKUAfXynZ
tuleneb	doc_831529852295_item	3709508	et	0	cKUAfXynZ
tekstist	doc_831529852295_item	3709509	et	0	cKUAfXynZ
lapse	doc_831529852295_item	3709510	et	0	cKUAfXynZ
enda	doc_831529852295_item	3709511	et	0	cKUAfXynZ
kirjutisest	doc_831529852295_item	3709512	et	0	cKUAfXynZ
või	doc_831529852295_item	3709513	et	0	cKUAfXynZ
situatsioonist	doc_831529852295_item	3709514	et	0	cKUAfXynZ
teadlikkus	doc_831529852295_item	3709515	et	0	cKUAfXynZ
tähendab	doc_831529852295_item	3709516	et	0	cKUAfXynZ
et	doc_831529852295_item	3709517	et	0	cKUAfXynZ
lapsi	doc_831529852295_item	3709518	et	0	cKUAfXynZ
on	doc_831529852295_item	3709519	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3709520	et	0	cKUAfXynZ
suunata	doc_831529852295_item	3709521	et	0	cKUAfXynZ
jälgima	doc_831529852295_item	3709522	et	0	cKUAfXynZ
parandama	doc_831529852295_item	3709523	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709524	et	0	cKUAfXynZ
analüüsima	doc_831529852295_item	3709525	et	0	cKUAfXynZ
kommunikatiivsuse	doc_831529852295_item	3709526	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3709527	et	0	cKUAfXynZ
on	doc_831529852295_item	3709528	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3709529	et	0	cKUAfXynZ
et	doc_831529852295_item	3709530	et	0	cKUAfXynZ
laps	doc_831529852295_item	3709531	et	0	cKUAfXynZ
oskaks	doc_831529852295_item	3709532	et	0	cKUAfXynZ
kedagi	doc_831529852295_item	3709533	et	0	cKUAfXynZ
teist	doc_831529852295_item	3709534	et	0	cKUAfXynZ
kuulata	doc_831529852295_item	3709535	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709536	et	0	cKUAfXynZ
suhelda	doc_831529852295_item	3709537	et	0	cKUAfXynZ
suhtlemiseks	doc_831529852295_item	3709538	et	0	cKUAfXynZ
on	doc_831529852295_item	3709539	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3709540	et	0	cKUAfXynZ
osata	doc_831529852295_item	3709541	et	0	cKUAfXynZ
arutleda	doc_831529852295_item	3709542	et	0	cKUAfXynZ
otsida	doc_831529852295_item	3709543	et	0	cKUAfXynZ
õigeid	doc_831529852295_item	3709544	et	0	cKUAfXynZ
vastuseid	doc_831529852295_item	3709545	et	0	cKUAfXynZ
või	doc_831529852295_item	3709546	et	0	cKUAfXynZ
mingisugust	doc_831529852295_item	3709547	et	0	cKUAfXynZ
infot	doc_831529852295_item	3709548	et	0	cKUAfXynZ
teadlikkust	doc_831529852295_item	3709549	et	0	cKUAfXynZ
sellest	doc_831529852295_item	3709550	et	0	cKUAfXynZ
milliseid	doc_831529852295_item	3709551	et	0	cKUAfXynZ
oskusi	doc_831529852295_item	3709552	et	0	cKUAfXynZ
strateegiat	doc_831529852295_item	3709553	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709554	et	0	cKUAfXynZ
ressursse	doc_831529852295_item	3709555	et	0	cKUAfXynZ
vajatakse	doc_831529852295_item	3709556	et	0	cKUAfXynZ
ülesande	doc_831529852295_item	3709557	et	0	cKUAfXynZ
sooritamiseks	doc_831529852295_item	3709558	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709559	et	0	cKUAfXynZ
võimalust	doc_831529852295_item	3709560	et	0	cKUAfXynZ
kasutada	doc_831529852295_item	3709561	et	0	cKUAfXynZ
enesejuhendamise	doc_831529852295_item	3709562	et	0	cKUAfXynZ
mehhanisme	doc_831529852295_item	3709563	et	0	cKUAfXynZ
ülesandega	doc_831529852295_item	3709564	et	0	cKUAfXynZ
toimetuleku	doc_831529852295_item	3709565	et	0	cKUAfXynZ
kindlustamiseks	doc_831529852295_item	3709566	et	0	cKUAfXynZ
nimetatakse	doc_831529852295_item	3709567	et	0	cKUAfXynZ
metakognitsioonina	doc_831529852295_item	3709568	et	0	cKUAfXynZ
metakognitsioon	doc_831529852295_item	3709569	et	0	cKUAfXynZ
ongi	doc_831529852295_item	3709570	et	0	cKUAfXynZ
oma	doc_831529852295_item	3709571	et	0	cKUAfXynZ
tegevuse	doc_831529852295_item	3709572	et	0	cKUAfXynZ
teadvustatud	doc_831529852295_item	3709573	et	0	cKUAfXynZ
jälgimine	doc_831529852295_item	3709574	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709575	et	0	cKUAfXynZ
arvustamine	doc_831529852295_item	3709576	et	0	cKUAfXynZ
müürsepp	doc_831529852295_item	3709577	et	0	cKUAfXynZ
1997	doc_831529852295_item	3709578	et	0	cKUAfXynZ
riutta	doc_831529852295_item	3709579	et	0	cKUAfXynZ
1996	doc_831529852295_item	3709580	et	0	cKUAfXynZ
sarmavuori	doc_831529852295_item	3709581	et	0	cKUAfXynZ
1993	doc_831529852295_item	3709582	et	0	cKUAfXynZ
kullberg	doc_831529852295_item	3709583	et	0	cKUAfXynZ
1991	doc_831529852295_item	3709584	et	0	cKUAfXynZ
linnakylä	doc_831529852295_item	3709585	et	0	cKUAfXynZ
1988	doc_831529852295_item	3709586	et	0	cKUAfXynZ
taube	doc_831529852295_item	3709587	et	0	cKUAfXynZ
1988	doc_831529852295_item	3709588	et	0	cKUAfXynZ
viidatud	doc_831529852295_item	3709589	et	0	cKUAfXynZ
uusen	doc_831529852295_item	3709590	et	0	cKUAfXynZ
2002	doc_831529852295_item	3709591	et	0	cKUAfXynZ
järgi	doc_831529852295_item	3709592	et	0	cKUAfXynZ
see	doc_831529852295_item	3709593	et	0	cKUAfXynZ
tähendab	doc_831529852295_item	3709594	et	0	cKUAfXynZ
et	doc_831529852295_item	3709595	et	0	cKUAfXynZ
õpilane	doc_831529852295_item	3709596	et	0	cKUAfXynZ
peab	doc_831529852295_item	3709597	et	0	cKUAfXynZ
ise	doc_831529852295_item	3709598	et	0	cKUAfXynZ
midagi	doc_831529852295_item	3709599	et	0	cKUAfXynZ
tegema	doc_831529852295_item	3709600	et	0	cKUAfXynZ
et	doc_831529852295_item	3709601	et	0	cKUAfXynZ
tulemused	doc_831529852295_item	3709602	et	0	cKUAfXynZ
oleksid	doc_831529852295_item	3709603	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3709604	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3709605	et	0	cKUAfXynZ
on	doc_831529852295_item	3709606	et	0	cKUAfXynZ
aidata	doc_831529852295_item	3709607	et	0	cKUAfXynZ
teda	doc_831529852295_item	3709608	et	0	cKUAfXynZ
teha	doc_831529852295_item	3709609	et	0	cKUAfXynZ
õppimist	doc_831529852295_item	3709610	et	0	cKUAfXynZ
tõhusamaks	doc_831529852295_item	3709611	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709612	et	0	cKUAfXynZ
huvitavamaks	doc_831529852295_item	3709613	et	0	cKUAfXynZ
pidades	doc_831529852295_item	3709614	et	0	cKUAfXynZ
silma	doc_831529852295_item	3709615	et	0	cKUAfXynZ
õppekavas	doc_831529852295_item	3709616	et	0	cKUAfXynZ
esitatud	doc_831529852295_item	3709617	et	0	cKUAfXynZ
õppetöökorraldamise	doc_831529852295_item	3709618	et	0	cKUAfXynZ
aluseid	doc_831529852295_item	3709619	et	0	cKUAfXynZ
vastavas	doc_831529852295_item	3709620	et	0	cKUAfXynZ
kooliastmes	doc_831529852295_item	3709621	et	0	cKUAfXynZ
selleks	doc_831529852295_item	3709622	et	0	cKUAfXynZ
peab	doc_831529852295_item	3709623	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3709624	et	0	cKUAfXynZ
küllaltki	doc_831529852295_item	3709625	et	0	cKUAfXynZ
palju	doc_831529852295_item	3709626	et	0	cKUAfXynZ
planeerima	doc_831529852295_item	3709627	et	0	cKUAfXynZ
tunniks	doc_831529852295_item	3709628	et	0	cKUAfXynZ
valmistuma	doc_831529852295_item	3709629	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709630	et	0	cKUAfXynZ
seletama	doc_831529852295_item	3709631	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3709632	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3709633	et	0	cKUAfXynZ
on	doc_831529852295_item	3709634	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3709635	et	0	cKUAfXynZ
programmi	doc_831529852295_item	3709636	et	0	cKUAfXynZ
koostamisel	doc_831529852295_item	3709637	et	0	cKUAfXynZ
teadvustada	doc_831529852295_item	3709638	et	0	cKUAfXynZ
endale	doc_831529852295_item	3709639	et	0	cKUAfXynZ
et	doc_831529852295_item	3709640	et	0	cKUAfXynZ
keelt	doc_831529852295_item	3709641	et	0	cKUAfXynZ
saab	doc_831529852295_item	3709642	et	0	cKUAfXynZ
klassifitseerida	doc_831529852295_item	3709643	et	0	cKUAfXynZ
kahel	doc_831529852295_item	3709644	et	0	cKUAfXynZ
erineval	doc_831529852295_item	3709645	et	0	cKUAfXynZ
moel	doc_831529852295_item	3709646	et	0	cKUAfXynZ
vormi	doc_831529852295_item	3709647	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709648	et	0	cKUAfXynZ
funktsiooni	doc_831529852295_item	3709649	et	0	cKUAfXynZ
järgi	doc_831529852295_item	3709650	et	0	cKUAfXynZ
keele	doc_831529852295_item	3709651	et	0	cKUAfXynZ
neli	doc_831529852295_item	3709652	et	0	cKUAfXynZ
erinevat	doc_831529852295_item	3709653	et	0	cKUAfXynZ
normi	doc_831529852295_item	3709654	et	0	cKUAfXynZ
on	doc_831529852295_item	3709655	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3709656	et	0	cKUAfXynZ
rääkimine	doc_831529852295_item	3709657	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3709658	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709659	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3709660	et	0	cKUAfXynZ
need	doc_831529852295_item	3709661	et	0	cKUAfXynZ
on	doc_831529852295_item	3709662	et	0	cKUAfXynZ
põhilised	doc_831529852295_item	3709663	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709664	et	0	cKUAfXynZ
algklassiõpilastel	doc_831529852295_item	3709665	et	0	cKUAfXynZ
peab	doc_831529852295_item	3709666	et	0	cKUAfXynZ
olema	doc_831529852295_item	3709667	et	0	cKUAfXynZ
võimalus	doc_831529852295_item	3709668	et	0	cKUAfXynZ
nende	doc_831529852295_item	3709669	et	0	cKUAfXynZ
kõikide	doc_831529852295_item	3709670	et	0	cKUAfXynZ
keele	doc_831529852295_item	3709671	et	0	cKUAfXynZ
situatsioonide	doc_831529852295_item	3709672	et	0	cKUAfXynZ
kasutamiseks	doc_831529852295_item	3709673	et	0	cKUAfXynZ
sellele	doc_831529852295_item	3709674	et	0	cKUAfXynZ
järgneb	doc_831529852295_item	3709675	et	0	cKUAfXynZ
et	doc_831529852295_item	3709676	et	0	cKUAfXynZ
õpetajal	doc_831529852295_item	3709677	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3709678	et	0	cKUAfXynZ
püüda	doc_831529852295_item	3709679	et	0	cKUAfXynZ
luua	doc_831529852295_item	3709680	et	0	cKUAfXynZ
realistlikke	doc_831529852295_item	3709681	et	0	cKUAfXynZ
suhtlemisolukordi	doc_831529852295_item	3709682	et	0	cKUAfXynZ
kus	doc_831529852295_item	3709683	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3709684	et	0	cKUAfXynZ
võimalikult	doc_831529852295_item	3709685	et	0	cKUAfXynZ
palju	doc_831529852295_item	3709686	et	0	cKUAfXynZ
erinevaid	doc_831529852295_item	3709687	et	0	cKUAfXynZ
keelefunktsioone	doc_831529852295_item	3709688	et	0	cKUAfXynZ
anne	doc_831529852295_item	3709689	et	0	cKUAfXynZ
uuseni	doc_831529852295_item	3709690	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3709691	et	0	cKUAfXynZ
kirjeldatakse	doc_831529852295_item	3709692	et	0	cKUAfXynZ
neid	doc_831529852295_item	3709693	et	0	cKUAfXynZ
2	doc_831529852295_item	3709694	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3709695	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3709696	et	0	cKUAfXynZ
on	doc_831529852295_item	3709697	et	0	cKUAfXynZ
protsess	doc_831529852295_item	3709698	et	0	cKUAfXynZ
mille	doc_831529852295_item	3709699	et	0	cKUAfXynZ
käigus	doc_831529852295_item	3709700	et	0	cKUAfXynZ
suuline	doc_831529852295_item	3709701	et	0	cKUAfXynZ
kõne	doc_831529852295_item	3709702	et	0	cKUAfXynZ
muutub	doc_831529852295_item	3709703	et	0	cKUAfXynZ
tähenduseks	doc_831529852295_item	3709704	et	0	cKUAfXynZ
lundsteen	doc_831529852295_item	3709705	et	0	cKUAfXynZ
donoghue	doc_831529852295_item	3709706	et	0	cKUAfXynZ
1991	doc_831529852295_item	3709707	et	0	cKUAfXynZ
viidatud	doc_831529852295_item	3709708	et	0	cKUAfXynZ
uusen	doc_831529852295_item	3709709	et	0	cKUAfXynZ
2002	doc_831529852295_item	3709710	et	0	cKUAfXynZ
järgi	doc_831529852295_item	3709711	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3709712	et	0	cKUAfXynZ
räägitakse	doc_831529852295_item	3709713	et	0	cKUAfXynZ
et	doc_831529852295_item	3709714	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3709715	et	0	cKUAfXynZ
pole	doc_831529852295_item	3709716	et	0	cKUAfXynZ
ainult	doc_831529852295_item	3709717	et	0	cKUAfXynZ
esimene	doc_831529852295_item	3709718	et	0	cKUAfXynZ
keelekasutuse	doc_831529852295_item	3709719	et	0	cKUAfXynZ
osaoskus	doc_831529852295_item	3709720	et	0	cKUAfXynZ
vaid	doc_831529852295_item	3709721	et	0	cKUAfXynZ
see	doc_831529852295_item	3709722	et	0	cKUAfXynZ
on	doc_831529852295_item	3709723	et	0	cKUAfXynZ
ka	doc_831529852295_item	3709724	et	0	cKUAfXynZ
aluseks	doc_831529852295_item	3709725	et	0	cKUAfXynZ
teistes	doc_831529852295_item	3709726	et	0	cKUAfXynZ
keelelise	doc_831529852295_item	3709727	et	0	cKUAfXynZ
suhtlemise	doc_831529852295_item	3709728	et	0	cKUAfXynZ
osaoskustest	doc_831529852295_item	3709729	et	0	cKUAfXynZ
edu	doc_831529852295_item	3709730	et	0	cKUAfXynZ
saavutamiseks	doc_831529852295_item	3709731	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3709732	et	0	cKUAfXynZ
on	doc_831529852295_item	3709733	et	0	cKUAfXynZ
ka	doc_831529852295_item	3709734	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3709735	et	0	cKUAfXynZ
vahend	doc_831529852295_item	3709736	et	0	cKUAfXynZ
massi-	doc_831529852295_item	3709737	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709738	et	0	cKUAfXynZ
haridusteabevahenditest	doc_831529852295_item	3709739	et	0	cKUAfXynZ
info	doc_831529852295_item	3709740	et	0	cKUAfXynZ
saamiseks	doc_831529852295_item	3709741	et	0	cKUAfXynZ
see	doc_831529852295_item	3709742	et	0	cKUAfXynZ
aitab	doc_831529852295_item	3709743	et	0	cKUAfXynZ
ka	doc_831529852295_item	3709744	et	0	cKUAfXynZ
arendada	doc_831529852295_item	3709745	et	0	cKUAfXynZ
mõtlemis-	doc_831529852295_item	3709746	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709747	et	0	cKUAfXynZ
järeldusoskust	doc_831529852295_item	3709748	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709749	et	0	cKUAfXynZ
on	doc_831529852295_item	3709750	et	0	cKUAfXynZ
aluseks	doc_831529852295_item	3709751	et	0	cKUAfXynZ
headele	doc_831529852295_item	3709752	et	0	cKUAfXynZ
inimsuhetele	doc_831529852295_item	3709753	et	0	cKUAfXynZ
tavakooli	doc_831529852295_item	3709754	et	0	cKUAfXynZ
õpilased	doc_831529852295_item	3709755	et	0	cKUAfXynZ
harilikult	doc_831529852295_item	3709756	et	0	cKUAfXynZ
küll	doc_831529852295_item	3709757	et	0	cKUAfXynZ
kõik	doc_831529852295_item	3709758	et	0	cKUAfXynZ
kuulevad	doc_831529852295_item	3709759	et	0	cKUAfXynZ
aga	doc_831529852295_item	3709760	et	0	cKUAfXynZ
kuulamisoskus	doc_831529852295_item	3709761	et	0	cKUAfXynZ
vajab	doc_831529852295_item	3709762	et	0	cKUAfXynZ
enamikul	doc_831529852295_item	3709763	et	0	cKUAfXynZ
neist	doc_831529852295_item	3709764	et	0	cKUAfXynZ
süstemaatilist	doc_831529852295_item	3709765	et	0	cKUAfXynZ
harjutamist	doc_831529852295_item	3709766	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3709767	et	0	cKUAfXynZ
peab	doc_831529852295_item	3709768	et	0	cKUAfXynZ
teadma	doc_831529852295_item	3709769	et	0	cKUAfXynZ
millised	doc_831529852295_item	3709770	et	0	cKUAfXynZ
on	doc_831529852295_item	3709771	et	0	cKUAfXynZ
kuulamist	doc_831529852295_item	3709772	et	0	cKUAfXynZ
mõjutavad	doc_831529852295_item	3709773	et	0	cKUAfXynZ
faktorid	doc_831529852295_item	3709774	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709775	et	0	cKUAfXynZ
arvestama	doc_831529852295_item	3709776	et	0	cKUAfXynZ
nendega	doc_831529852295_item	3709777	et	0	cKUAfXynZ
õppetöö	doc_831529852295_item	3709778	et	0	cKUAfXynZ
planeerimisel	doc_831529852295_item	3709779	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709780	et	0	cKUAfXynZ
läbiviimisel	doc_831529852295_item	3709781	et	0	cKUAfXynZ
need	doc_831529852295_item	3709782	et	0	cKUAfXynZ
faktorid	doc_831529852295_item	3709783	et	0	cKUAfXynZ
on	doc_831529852295_item	3709784	et	0	cKUAfXynZ
järgmised	doc_831529852295_item	3709785	et	0	cKUAfXynZ
1	doc_831529852295_item	3709786	et	0	cKUAfXynZ
kuulmismeel	doc_831529852295_item	3709787	et	0	cKUAfXynZ
inimkõrv	doc_831529852295_item	3709788	et	0	cKUAfXynZ
eristab	doc_831529852295_item	3709789	et	0	cKUAfXynZ
20	doc_831529852295_item	3709790	et	0	cKUAfXynZ
20	doc_831529852295_item	3709791	et	0	cKUAfXynZ
000	doc_831529852295_item	3709792	et	0	cKUAfXynZ
võnget	doc_831529852295_item	3709793	et	0	cKUAfXynZ
sekundis	doc_831529852295_item	3709794	et	0	cKUAfXynZ
on	doc_831529852295_item	3709795	et	0	cKUAfXynZ
olemas	doc_831529852295_item	3709796	et	0	cKUAfXynZ
arvamus	doc_831529852295_item	3709797	et	0	cKUAfXynZ
et	doc_831529852295_item	3709798	et	0	cKUAfXynZ
5-10	doc_831529852295_item	3709799	et	0	cKUAfXynZ
koolilastest	doc_831529852295_item	3709800	et	0	cKUAfXynZ
on	doc_831529852295_item	3709801	et	0	cKUAfXynZ
nõrgenenud	doc_831529852295_item	3709802	et	0	cKUAfXynZ
kuulmisvõimega	doc_831529852295_item	3709803	et	0	cKUAfXynZ
2	doc_831529852295_item	3709804	et	0	cKUAfXynZ
kuulajate	doc_831529852295_item	3709805	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709806	et	0	cKUAfXynZ
kuulatava	doc_831529852295_item	3709807	et	0	cKUAfXynZ
materjali	doc_831529852295_item	3709808	et	0	cKUAfXynZ
seotuse	doc_831529852295_item	3709809	et	0	cKUAfXynZ
tase	doc_831529852295_item	3709810	et	0	cKUAfXynZ
siin	doc_831529852295_item	3709811	et	0	cKUAfXynZ
võib	doc_831529852295_item	3709812	et	0	cKUAfXynZ
segada	doc_831529852295_item	3709813	et	0	cKUAfXynZ
monotoonsus	doc_831529852295_item	3709814	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3709815	et	0	cKUAfXynZ
negatiivsed	doc_831529852295_item	3709816	et	0	cKUAfXynZ
emotsioonid	doc_831529852295_item	3709817	et	0	cKUAfXynZ
3	doc_831529852295_item	3709818	et	0	cKUAfXynZ
lapse	doc_831529852295_item	3709819	et	0	cKUAfXynZ
asend	doc_831529852295_item	3709820	et	0	cKUAfXynZ
perekonnas	doc_831529852295_item	3709821	et	0	cKUAfXynZ
kui	doc_831529852295_item	3709822	et	0	cKUAfXynZ
lapse	doc_831529852295_item	3709823	et	0	cKUAfXynZ
perekond	doc_831529852295_item	3709824	et	0	cKUAfXynZ
on	doc_831529852295_item	3709825	et	0	cKUAfXynZ
väike	doc_831529852295_item	3709826	et	0	cKUAfXynZ
siis	doc_831529852295_item	3709827	et	0	cKUAfXynZ
lapsel	doc_831529852295_item	3709828	et	0	cKUAfXynZ
on	doc_831529852295_item	3709829	et	0	cKUAfXynZ
parem	doc_831529852295_item	3709830	et	0	cKUAfXynZ
kuulamisoskus	doc_831529852295_item	3709831	et	0	cKUAfXynZ
esimene	doc_831529852295_item	3709832	et	0	cKUAfXynZ
või	doc_831529852295_item	3709833	et	0	cKUAfXynZ
ainuke	doc_831529852295_item	3709834	et	0	cKUAfXynZ
laps	doc_831529852295_item	3709835	et	0	cKUAfXynZ
peres	doc_831529852295_item	3709836	et	0	cKUAfXynZ
on	doc_831529852295_item	3709837	et	0	cKUAfXynZ
parem	doc_831529852295_item	3709838	et	0	cKUAfXynZ
kuulaja	doc_831529852295_item	3709839	et	0	cKUAfXynZ
kui	doc_831529852295_item	3709840	et	0	cKUAfXynZ
teine	doc_831529852295_item	3709841	et	0	cKUAfXynZ
või	doc_831529852295_item	3709842	et	0	cKUAfXynZ
viimane	doc_831529852295_item	3709843	et	0	cKUAfXynZ
laps	doc_831529852295_item	3709844	et	0	cKUAfXynZ
4	doc_831529852295_item	3709845	et	0	cKUAfXynZ
head	doc_831529852295_item	3709846	et	0	cKUAfXynZ
kuulajad	doc_831529852295_item	3709847	et	0	cKUAfXynZ
kohanevad	doc_831529852295_item	3709848	et	0	cKUAfXynZ
paremini	doc_831529852295_item	3709849	et	0	cKUAfXynZ
kui	doc_831529852295_item	3709850	et	0	cKUAfXynZ
halvemad	doc_831529852295_item	3709851	et	0	cKUAfXynZ
5	doc_831529852295_item	3709852	et	0	cKUAfXynZ
kuulamisvõime	doc_831529852295_item	3709853	et	0	cKUAfXynZ
suureneb	doc_831529852295_item	3709854	et	0	cKUAfXynZ
vastavalt	doc_831529852295_item	3709855	et	0	cKUAfXynZ
vanusele	doc_831529852295_item	3709856	et	0	cKUAfXynZ
6	doc_831529852295_item	3709857	et	0	cKUAfXynZ
kuulamisega	doc_831529852295_item	3709858	et	0	cKUAfXynZ
on	doc_831529852295_item	3709859	et	0	cKUAfXynZ
seotud	doc_831529852295_item	3709860	et	0	cKUAfXynZ
nii	doc_831529852295_item	3709861	et	0	cKUAfXynZ
mõtlemine	doc_831529852295_item	3709862	et	0	cKUAfXynZ
kui	doc_831529852295_item	3709863	et	0	cKUAfXynZ
ka	doc_831529852295_item	3709864	et	0	cKUAfXynZ
arutlemine	doc_831529852295_item	3709865	et	0	cKUAfXynZ
7	doc_831529852295_item	3709866	et	0	cKUAfXynZ
lapse	doc_831529852295_item	3709867	et	0	cKUAfXynZ
sõnavara	doc_831529852295_item	3709868	et	0	cKUAfXynZ
on	doc_831529852295_item	3709869	et	0	cKUAfXynZ
oluliseks	doc_831529852295_item	3709870	et	0	cKUAfXynZ
mõjutajaks	doc_831529852295_item	3709871	et	0	cKUAfXynZ
need	doc_831529852295_item	3709872	et	0	cKUAfXynZ
kellel	doc_831529852295_item	3709873	et	0	cKUAfXynZ
on	doc_831529852295_item	3709874	et	0	cKUAfXynZ
suur	doc_831529852295_item	3709875	et	0	cKUAfXynZ
sõnavara	doc_831529852295_item	3709876	et	0	cKUAfXynZ
saavad	doc_831529852295_item	3709877	et	0	cKUAfXynZ
paljudest	doc_831529852295_item	3709878	et	0	cKUAfXynZ
sõnadest	doc_831529852295_item	3709879	et	0	cKUAfXynZ
aru	doc_831529852295_item	3709880	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709881	et	0	cKUAfXynZ
oskavad	doc_831529852295_item	3709882	et	0	cKUAfXynZ
nautida	doc_831529852295_item	3709883	et	0	cKUAfXynZ
kuulatavat	doc_831529852295_item	3709884	et	0	cKUAfXynZ
8	doc_831529852295_item	3709885	et	0	cKUAfXynZ
füüsiline	doc_831529852295_item	3709886	et	0	cKUAfXynZ
seisund	doc_831529852295_item	3709887	et	0	cKUAfXynZ
kui	doc_831529852295_item	3709888	et	0	cKUAfXynZ
laps	doc_831529852295_item	3709889	et	0	cKUAfXynZ
on	doc_831529852295_item	3709890	et	0	cKUAfXynZ
väsinud	doc_831529852295_item	3709891	et	0	cKUAfXynZ
ei	doc_831529852295_item	3709892	et	0	cKUAfXynZ
suuda	doc_831529852295_item	3709893	et	0	cKUAfXynZ
ta	doc_831529852295_item	3709894	et	0	cKUAfXynZ
kuulata	doc_831529852295_item	3709895	et	0	cKUAfXynZ
tähelepanelikult	doc_831529852295_item	3709896	et	0	cKUAfXynZ
9	doc_831529852295_item	3709897	et	0	cKUAfXynZ
kiirus	doc_831529852295_item	3709898	et	0	cKUAfXynZ
laps	doc_831529852295_item	3709899	et	0	cKUAfXynZ
saab	doc_831529852295_item	3709900	et	0	cKUAfXynZ
paremini	doc_831529852295_item	3709901	et	0	cKUAfXynZ
aru	doc_831529852295_item	3709902	et	0	cKUAfXynZ
kui	doc_831529852295_item	3709903	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3709904	et	0	cKUAfXynZ
räägib	doc_831529852295_item	3709905	et	0	cKUAfXynZ
normaalselt	doc_831529852295_item	3709906	et	0	cKUAfXynZ
mitte	doc_831529852295_item	3709907	et	0	cKUAfXynZ
aeglaselt	doc_831529852295_item	3709908	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709909	et	0	cKUAfXynZ
mitte	doc_831529852295_item	3709910	et	0	cKUAfXynZ
kiiresti	doc_831529852295_item	3709911	et	0	cKUAfXynZ
10	doc_831529852295_item	3709912	et	0	cKUAfXynZ
häälte	doc_831529852295_item	3709913	et	0	cKUAfXynZ
äratundmine	doc_831529852295_item	3709914	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3709915	et	0	cKUAfXynZ
saavad	doc_831529852295_item	3709916	et	0	cKUAfXynZ
paremini	doc_831529852295_item	3709917	et	0	cKUAfXynZ
aru	doc_831529852295_item	3709918	et	0	cKUAfXynZ
üksikutest	doc_831529852295_item	3709919	et	0	cKUAfXynZ
häältest	doc_831529852295_item	3709920	et	0	cKUAfXynZ
mis	doc_831529852295_item	3709921	et	0	cKUAfXynZ
tulevad	doc_831529852295_item	3709922	et	0	cKUAfXynZ
erinevatest	doc_831529852295_item	3709923	et	0	cKUAfXynZ
kohtadest	doc_831529852295_item	3709924	et	0	cKUAfXynZ
11	doc_831529852295_item	3709925	et	0	cKUAfXynZ
klassikeskkond	doc_831529852295_item	3709926	et	0	cKUAfXynZ
kui	doc_831529852295_item	3709927	et	0	cKUAfXynZ
see	doc_831529852295_item	3709928	et	0	cKUAfXynZ
on	doc_831529852295_item	3709929	et	0	cKUAfXynZ
toetav	doc_831529852295_item	3709930	et	0	cKUAfXynZ
siis	doc_831529852295_item	3709931	et	0	cKUAfXynZ
pole	doc_831529852295_item	3709932	et	0	cKUAfXynZ
pinget	doc_831529852295_item	3709933	et	0	cKUAfXynZ
12	doc_831529852295_item	3709934	et	0	cKUAfXynZ
korralikult	doc_831529852295_item	3709935	et	0	cKUAfXynZ
planeeritud	doc_831529852295_item	3709936	et	0	cKUAfXynZ
kuulamise	doc_831529852295_item	3709937	et	0	cKUAfXynZ
programm	doc_831529852295_item	3709938	et	0	cKUAfXynZ
erilist	doc_831529852295_item	3709939	et	0	cKUAfXynZ
tähelepanu	doc_831529852295_item	3709940	et	0	cKUAfXynZ
peab	doc_831529852295_item	3709941	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3709942	et	0	cKUAfXynZ
pöörama	doc_831529852295_item	3709943	et	0	cKUAfXynZ
kuulamisraskustega	doc_831529852295_item	3709944	et	0	cKUAfXynZ
lastele	doc_831529852295_item	3709945	et	0	cKUAfXynZ
nendele	doc_831529852295_item	3709946	et	0	cKUAfXynZ
on	doc_831529852295_item	3709947	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3709948	et	0	cKUAfXynZ
spetsiaalseid	doc_831529852295_item	3709949	et	0	cKUAfXynZ
tingimusi	doc_831529852295_item	3709950	et	0	cKUAfXynZ
on	doc_831529852295_item	3709951	et	0	cKUAfXynZ
oluline	doc_831529852295_item	3709952	et	0	cKUAfXynZ
õige	doc_831529852295_item	3709953	et	0	cKUAfXynZ
koht	doc_831529852295_item	3709954	et	0	cKUAfXynZ
klassis	doc_831529852295_item	3709955	et	0	cKUAfXynZ
istumiskaugus	doc_831529852295_item	3709956	et	0	cKUAfXynZ
peab	doc_831529852295_item	3709957	et	0	cKUAfXynZ
olema	doc_831529852295_item	3709958	et	0	cKUAfXynZ
2	doc_831529852295_item	3709959	et	0	cKUAfXynZ
3	doc_831529852295_item	3709960	et	0	cKUAfXynZ
meetrit	doc_831529852295_item	3709961	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3709962	et	0	cKUAfXynZ
parem	doc_831529852295_item	3709963	et	0	cKUAfXynZ
kui	doc_831529852295_item	3709964	et	0	cKUAfXynZ
laps	doc_831529852295_item	3709965	et	0	cKUAfXynZ
võiks	doc_831529852295_item	3709966	et	0	cKUAfXynZ
endale	doc_831529852295_item	3709967	et	0	cKUAfXynZ
ise	doc_831529852295_item	3709968	et	0	cKUAfXynZ
kohta	doc_831529852295_item	3709969	et	0	cKUAfXynZ
valida	doc_831529852295_item	3709970	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709971	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3709972	et	0	cKUAfXynZ
lubaks	doc_831529852295_item	3709973	et	0	cKUAfXynZ
tal	doc_831529852295_item	3709974	et	0	cKUAfXynZ
pöörata	doc_831529852295_item	3709975	et	0	cKUAfXynZ
hääleallika	doc_831529852295_item	3709976	et	0	cKUAfXynZ
suunas	doc_831529852295_item	3709977	et	0	cKUAfXynZ
peaks	doc_831529852295_item	3709978	et	0	cKUAfXynZ
vältida	doc_831529852295_item	3709979	et	0	cKUAfXynZ
valju	doc_831529852295_item	3709980	et	0	cKUAfXynZ
häält	doc_831529852295_item	3709981	et	0	cKUAfXynZ
ja	doc_831529852295_item	3709982	et	0	cKUAfXynZ
liiga	doc_831529852295_item	3709983	et	0	cKUAfXynZ
suuliigutusi	doc_831529852295_item	3709984	et	0	cKUAfXynZ
ei	doc_831529852295_item	3709985	et	0	cKUAfXynZ
tohiks	doc_831529852295_item	3709986	et	0	cKUAfXynZ
ka	doc_831529852295_item	3709987	et	0	cKUAfXynZ
käte	doc_831529852295_item	3709988	et	0	cKUAfXynZ
või	doc_831529852295_item	3709989	et	0	cKUAfXynZ
raamatu	doc_831529852295_item	3709990	et	0	cKUAfXynZ
rääkimise	doc_831529852295_item	3709991	et	0	cKUAfXynZ
ajal	doc_831529852295_item	3709992	et	0	cKUAfXynZ
hoida	doc_831529852295_item	3709993	et	0	cKUAfXynZ
suu	doc_831529852295_item	3709994	et	0	cKUAfXynZ
ees	doc_831529852295_item	3709995	et	0	cKUAfXynZ
on	doc_831529852295_item	3709996	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3709997	et	0	cKUAfXynZ
koguaeg	doc_831529852295_item	3709998	et	0	cKUAfXynZ
kontrollida	doc_831529852295_item	3709999	et	0	cKUAfXynZ
kas	doc_831529852295_item	3710000	et	0	cKUAfXynZ
probleemne	doc_831529852295_item	3710001	et	0	cKUAfXynZ
laps	doc_831529852295_item	3710002	et	0	cKUAfXynZ
on	doc_831529852295_item	3710003	et	0	cKUAfXynZ
mõistnud	doc_831529852295_item	3710004	et	0	cKUAfXynZ
kuulatavat	doc_831529852295_item	3710005	et	0	cKUAfXynZ
abiks	doc_831529852295_item	3710006	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3710007	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710008	et	0	cKUAfXynZ
kirjutada	doc_831529852295_item	3710009	et	0	cKUAfXynZ
uued	doc_831529852295_item	3710010	et	0	cKUAfXynZ
sõnad	doc_831529852295_item	3710011	et	0	cKUAfXynZ
tahvlile	doc_831529852295_item	3710012	et	0	cKUAfXynZ
korrata	doc_831529852295_item	3710013	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710014	et	0	cKUAfXynZ
on	doc_831529852295_item	3710015	et	0	cKUAfXynZ
niisugune	doc_831529852295_item	3710016	et	0	cKUAfXynZ
vajadus	doc_831529852295_item	3710017	et	0	cKUAfXynZ
võib	doc_831529852295_item	3710018	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710019	et	0	cKUAfXynZ
aidata	doc_831529852295_item	3710020	et	0	cKUAfXynZ
teha	doc_831529852295_item	3710021	et	0	cKUAfXynZ
keeletegevuse	doc_831529852295_item	3710022	et	0	cKUAfXynZ
kus	doc_831529852295_item	3710023	et	0	cKUAfXynZ
on	doc_831529852295_item	3710024	et	0	cKUAfXynZ
oluline	doc_831529852295_item	3710025	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3710026	et	0	cKUAfXynZ
arvatakse	doc_831529852295_item	3710027	et	0	cKUAfXynZ
et	doc_831529852295_item	3710028	et	0	cKUAfXynZ
läheks	doc_831529852295_item	3710029	et	0	cKUAfXynZ
kasuks	doc_831529852295_item	3710030	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710031	et	0	cKUAfXynZ
tegevus	doc_831529852295_item	3710032	et	0	cKUAfXynZ
kus	doc_831529852295_item	3710033	et	0	cKUAfXynZ
kuulamisraskusega	doc_831529852295_item	3710034	et	0	cKUAfXynZ
laps	doc_831529852295_item	3710035	et	0	cKUAfXynZ
tunneks	doc_831529852295_item	3710036	et	0	cKUAfXynZ
eduelamust	doc_831529852295_item	3710037	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3710038	et	0	cKUAfXynZ
pole	doc_831529852295_item	3710039	et	0	cKUAfXynZ
ainult	doc_831529852295_item	3710040	et	0	cKUAfXynZ
vastuvõttev	doc_831529852295_item	3710041	et	0	cKUAfXynZ
keelekasutuse	doc_831529852295_item	3710042	et	0	cKUAfXynZ
oskus	doc_831529852295_item	3710043	et	0	cKUAfXynZ
see	doc_831529852295_item	3710044	et	0	cKUAfXynZ
on	doc_831529852295_item	3710045	et	0	cKUAfXynZ
aktiivne	doc_831529852295_item	3710046	et	0	cKUAfXynZ
protsess	doc_831529852295_item	3710047	et	0	cKUAfXynZ
mis	doc_831529852295_item	3710048	et	0	cKUAfXynZ
nõuab	doc_831529852295_item	3710049	et	0	cKUAfXynZ
mõtlemist	doc_831529852295_item	3710050	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710051	et	0	cKUAfXynZ
kuulatava	doc_831529852295_item	3710052	et	0	cKUAfXynZ
interpretatsiooni	doc_831529852295_item	3710053	et	0	cKUAfXynZ
kuulamisel	doc_831529852295_item	3710054	et	0	cKUAfXynZ
on	doc_831529852295_item	3710055	et	0	cKUAfXynZ
oma	doc_831529852295_item	3710056	et	0	cKUAfXynZ
liike	doc_831529852295_item	3710057	et	0	cKUAfXynZ
neid	doc_831529852295_item	3710058	et	0	cKUAfXynZ
on	doc_831529852295_item	3710059	et	0	cKUAfXynZ
kolm	doc_831529852295_item	3710060	et	0	cKUAfXynZ
21	doc_831529852295_item	3710061	et	0	cKUAfXynZ
väärtustav	doc_831529852295_item	3710062	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3710063	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3710064	et	0	cKUAfXynZ
nautiv	doc_831529852295_item	3710065	et	0	cKUAfXynZ
väärtustava	doc_831529852295_item	3710066	et	0	cKUAfXynZ
kuulamise	doc_831529852295_item	3710067	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3710068	et	0	cKUAfXynZ
on	doc_831529852295_item	3710069	et	0	cKUAfXynZ
eesmärgiks	doc_831529852295_item	3710070	et	0	cKUAfXynZ
nautida	doc_831529852295_item	3710071	et	0	cKUAfXynZ
selline	doc_831529852295_item	3710072	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3710073	et	0	cKUAfXynZ
nõuab	doc_831529852295_item	3710074	et	0	cKUAfXynZ
vähem	doc_831529852295_item	3710075	et	0	cKUAfXynZ
kontsentreerimist	doc_831529852295_item	3710076	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710077	et	0	cKUAfXynZ
tähelepanelik	doc_831529852295_item	3710078	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710079	et	0	cKUAfXynZ
kriitiline	doc_831529852295_item	3710080	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3710081	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710082	et	0	cKUAfXynZ
tunnil	doc_831529852295_item	3710083	et	0	cKUAfXynZ
on	doc_831529852295_item	3710084	et	0	cKUAfXynZ
tegemist	doc_831529852295_item	3710085	et	0	cKUAfXynZ
nautiva	doc_831529852295_item	3710086	et	0	cKUAfXynZ
kuulamisega	doc_831529852295_item	3710087	et	0	cKUAfXynZ
tuleks	doc_831529852295_item	3710088	et	0	cKUAfXynZ
kasuks	doc_831529852295_item	3710089	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710090	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3710091	et	0	cKUAfXynZ
võiksid	doc_831529852295_item	3710092	et	0	cKUAfXynZ
kuulata	doc_831529852295_item	3710093	et	0	cKUAfXynZ
raadiot	doc_831529852295_item	3710094	et	0	cKUAfXynZ
televiisorit	doc_831529852295_item	3710095	et	0	cKUAfXynZ
nukuteatrit	doc_831529852295_item	3710096	et	0	cKUAfXynZ
õpilasaed	doc_831529852295_item	3710097	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3710098	et	0	cKUAfXynZ
joonistada	doc_831529852295_item	3710099	et	0	cKUAfXynZ
või	doc_831529852295_item	3710100	et	0	cKUAfXynZ
teha	doc_831529852295_item	3710101	et	0	cKUAfXynZ
kleeptöid	doc_831529852295_item	3710102	et	0	cKUAfXynZ
muusikast	doc_831529852295_item	3710103	et	0	cKUAfXynZ
maalida	doc_831529852295_item	3710104	et	0	cKUAfXynZ
oma	doc_831529852295_item	3710105	et	0	cKUAfXynZ
tundeid	doc_831529852295_item	3710106	et	0	cKUAfXynZ
poeesiast	doc_831529852295_item	3710107	et	0	cKUAfXynZ
juttudest	doc_831529852295_item	3710108	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3710109	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710110	et	0	cKUAfXynZ
grupis	doc_831529852295_item	3710111	et	0	cKUAfXynZ
üksteistele	doc_831529852295_item	3710112	et	0	cKUAfXynZ
ette	doc_831529852295_item	3710113	et	0	cKUAfXynZ
lugeda	doc_831529852295_item	3710114	et	0	cKUAfXynZ
oluliseks	doc_831529852295_item	3710115	et	0	cKUAfXynZ
faktoriks	doc_831529852295_item	3710116	et	0	cKUAfXynZ
siin	doc_831529852295_item	3710117	et	0	cKUAfXynZ
on	doc_831529852295_item	3710118	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710119	et	0	cKUAfXynZ
suuline	doc_831529852295_item	3710120	et	0	cKUAfXynZ
tegevus	doc_831529852295_item	3710121	et	0	cKUAfXynZ
kuna	doc_831529852295_item	3710122	et	0	cKUAfXynZ
see	doc_831529852295_item	3710123	et	0	cKUAfXynZ
annab	doc_831529852295_item	3710124	et	0	cKUAfXynZ
palju	doc_831529852295_item	3710125	et	0	cKUAfXynZ
võimalusi	doc_831529852295_item	3710126	et	0	cKUAfXynZ
nautiva	doc_831529852295_item	3710127	et	0	cKUAfXynZ
kuulamise	doc_831529852295_item	3710128	et	0	cKUAfXynZ
arendamiseks	doc_831529852295_item	3710129	et	0	cKUAfXynZ
22	doc_831529852295_item	3710130	et	0	cKUAfXynZ
tähelepanelik	doc_831529852295_item	3710131	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3710132	et	0	cKUAfXynZ
tähelepanelik	doc_831529852295_item	3710133	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3710134	et	0	cKUAfXynZ
nõuab	doc_831529852295_item	3710135	et	0	cKUAfXynZ
et	doc_831529852295_item	3710136	et	0	cKUAfXynZ
kuulajate	doc_831529852295_item	3710137	et	0	cKUAfXynZ
tähelepanu	doc_831529852295_item	3710138	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3710139	et	0	cKUAfXynZ
suunatud	doc_831529852295_item	3710140	et	0	cKUAfXynZ
ühele	doc_831529852295_item	3710141	et	0	cKUAfXynZ
häälikallikale	doc_831529852295_item	3710142	et	0	cKUAfXynZ
selline	doc_831529852295_item	3710143	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3710144	et	0	cKUAfXynZ
võimaldab	doc_831529852295_item	3710145	et	0	cKUAfXynZ
mõista	doc_831529852295_item	3710146	et	0	cKUAfXynZ
juhendeid	doc_831529852295_item	3710147	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710148	et	0	cKUAfXynZ
seletusi	doc_831529852295_item	3710149	et	0	cKUAfXynZ
ning	doc_831529852295_item	3710150	et	0	cKUAfXynZ
seega	doc_831529852295_item	3710151	et	0	cKUAfXynZ
hõlmab	doc_831529852295_item	3710152	et	0	cKUAfXynZ
suurema	doc_831529852295_item	3710153	et	0	cKUAfXynZ
osa	doc_831529852295_item	3710154	et	0	cKUAfXynZ
kooliajast	doc_831529852295_item	3710155	et	0	cKUAfXynZ
algklasside	doc_831529852295_item	3710156	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3710157	et	0	cKUAfXynZ
võiksid	doc_831529852295_item	3710158	et	0	cKUAfXynZ
anda	doc_831529852295_item	3710159	et	0	cKUAfXynZ
juhiseid	doc_831529852295_item	3710160	et	0	cKUAfXynZ
üksteisele	doc_831529852295_item	3710161	et	0	cKUAfXynZ
istuda	doc_831529852295_item	3710162	et	0	cKUAfXynZ
vaikselt	doc_831529852295_item	3710163	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710164	et	0	cKUAfXynZ
kuulata	doc_831529852295_item	3710165	et	0	cKUAfXynZ
ümbritsevaid	doc_831529852295_item	3710166	et	0	cKUAfXynZ
hääli	doc_831529852295_item	3710167	et	0	cKUAfXynZ
teha	doc_831529852295_item	3710168	et	0	cKUAfXynZ
ise	doc_831529852295_item	3710169	et	0	cKUAfXynZ
hääli	doc_831529852295_item	3710170	et	0	cKUAfXynZ
klassifitseerida	doc_831529852295_item	3710171	et	0	cKUAfXynZ
hääli	doc_831529852295_item	3710172	et	0	cKUAfXynZ
kõrguse	doc_831529852295_item	3710173	et	0	cKUAfXynZ
või	doc_831529852295_item	3710174	et	0	cKUAfXynZ
kedagi	doc_831529852295_item	3710175	et	0	cKUAfXynZ
kirjeldada	doc_831529852295_item	3710176	et	0	cKUAfXynZ
23	doc_831529852295_item	3710177	et	0	cKUAfXynZ
kriitiline	doc_831529852295_item	3710178	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3710179	et	0	cKUAfXynZ
selline	doc_831529852295_item	3710180	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3710181	et	0	cKUAfXynZ
sisaldab	doc_831529852295_item	3710182	et	0	cKUAfXynZ
otsustamis-	doc_831529852295_item	3710183	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710184	et	0	cKUAfXynZ
analüüsivõimet	doc_831529852295_item	3710185	et	0	cKUAfXynZ
ning	doc_831529852295_item	3710186	et	0	cKUAfXynZ
nõuab	doc_831529852295_item	3710187	et	0	cKUAfXynZ
kõige	doc_831529852295_item	3710188	et	0	cKUAfXynZ
suuremat	doc_831529852295_item	3710189	et	0	cKUAfXynZ
keskendumist	doc_831529852295_item	3710190	et	0	cKUAfXynZ
kriitiline	doc_831529852295_item	3710191	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3710192	et	0	cKUAfXynZ
võimaldab	doc_831529852295_item	3710193	et	0	cKUAfXynZ
õpilastele	doc_831529852295_item	3710194	et	0	cKUAfXynZ
eristama	doc_831529852295_item	3710195	et	0	cKUAfXynZ
fakti	doc_831529852295_item	3710196	et	0	cKUAfXynZ
fantaasiast	doc_831529852295_item	3710197	et	0	cKUAfXynZ
vastavalt	doc_831529852295_item	3710198	et	0	cKUAfXynZ
kindlatele	doc_831529852295_item	3710199	et	0	cKUAfXynZ
kriteeriumitele	doc_831529852295_item	3710200	et	0	cKUAfXynZ
eristama	doc_831529852295_item	3710201	et	0	cKUAfXynZ
asjakohast	doc_831529852295_item	3710202	et	0	cKUAfXynZ
mitteasjakohasest	doc_831529852295_item	3710203	et	0	cKUAfXynZ
eristada	doc_831529852295_item	3710204	et	0	cKUAfXynZ
rääkija	doc_831529852295_item	3710205	et	0	cKUAfXynZ
emotsionaalset	doc_831529852295_item	3710206	et	0	cKUAfXynZ
liialdust	doc_831529852295_item	3710207	et	0	cKUAfXynZ
objektiivsusest	doc_831529852295_item	3710208	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710209	et	0	cKUAfXynZ
hindama	doc_831529852295_item	3710210	et	0	cKUAfXynZ
teemast	doc_831529852295_item	3710211	et	0	cKUAfXynZ
kinnipidamist	doc_831529852295_item	3710212	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710213	et	0	cKUAfXynZ
teemale	doc_831529852295_item	3710214	et	0	cKUAfXynZ
vastavust	doc_831529852295_item	3710215	et	0	cKUAfXynZ
donoghue	doc_831529852295_item	3710216	et	0	cKUAfXynZ
1991	doc_831529852295_item	3710217	et	0	cKUAfXynZ
eisele	doc_831529852295_item	3710218	et	0	cKUAfXynZ
1991	doc_831529852295_item	3710219	et	0	cKUAfXynZ
viidatud	doc_831529852295_item	3710220	et	0	cKUAfXynZ
uusen	doc_831529852295_item	3710221	et	0	cKUAfXynZ
2002	doc_831529852295_item	3710222	et	0	cKUAfXynZ
järgi	doc_831529852295_item	3710223	et	0	cKUAfXynZ
selle	doc_831529852295_item	3710224	et	0	cKUAfXynZ
kuulamise	doc_831529852295_item	3710225	et	0	cKUAfXynZ
arendamiseks	doc_831529852295_item	3710226	et	0	cKUAfXynZ
võiks	doc_831529852295_item	3710227	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3710228	et	0	cKUAfXynZ
lugeda	doc_831529852295_item	3710229	et	0	cKUAfXynZ
ühe	doc_831529852295_item	3710230	et	0	cKUAfXynZ
fantaasiajutu	doc_831529852295_item	3710231	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710232	et	0	cKUAfXynZ
teise	doc_831529852295_item	3710233	et	0	cKUAfXynZ
tõsielujutu	doc_831529852295_item	3710234	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710235	et	0	cKUAfXynZ
pärast	doc_831529852295_item	3710236	et	0	cKUAfXynZ
küsida	doc_831529852295_item	3710237	et	0	cKUAfXynZ
lastelt	doc_831529852295_item	3710238	et	0	cKUAfXynZ
miks	doc_831529852295_item	3710239	et	0	cKUAfXynZ
üks	doc_831529852295_item	3710240	et	0	cKUAfXynZ
on	doc_831529852295_item	3710241	et	0	cKUAfXynZ
fantaasia	doc_831529852295_item	3710242	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710243	et	0	cKUAfXynZ
teine	doc_831529852295_item	3710244	et	0	cKUAfXynZ
tõsieluline	doc_831529852295_item	3710245	et	0	cKUAfXynZ
võiks	doc_831529852295_item	3710246	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710247	et	0	cKUAfXynZ
koostada	doc_831529852295_item	3710248	et	0	cKUAfXynZ
lauseid	doc_831529852295_item	3710249	et	0	cKUAfXynZ
need	doc_831529852295_item	3710250	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3710251	et	0	cKUAfXynZ
olla	doc_831529852295_item	3710252	et	0	cKUAfXynZ
emotsionaalsed	doc_831529852295_item	3710253	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710254	et	0	cKUAfXynZ
objektiivsed	doc_831529852295_item	3710255	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3710256	et	0	cKUAfXynZ
siis	doc_831529852295_item	3710257	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3710258	et	0	cKUAfXynZ
proovida	doc_831529852295_item	3710259	et	0	cKUAfXynZ
ära	doc_831529852295_item	3710260	et	0	cKUAfXynZ
arvata	doc_831529852295_item	3710261	et	0	cKUAfXynZ
mis	doc_831529852295_item	3710262	et	0	cKUAfXynZ
on	doc_831529852295_item	3710263	et	0	cKUAfXynZ
mis	doc_831529852295_item	3710264	et	0	cKUAfXynZ
iga	doc_831529852295_item	3710265	et	0	cKUAfXynZ
kuulamise	doc_831529852295_item	3710266	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3710267	et	0	cKUAfXynZ
lähevad	doc_831529852295_item	3710268	et	0	cKUAfXynZ
kasuks	doc_831529852295_item	3710269	et	0	cKUAfXynZ
kuulamise	doc_831529852295_item	3710270	et	0	cKUAfXynZ
strateegiad	doc_831529852295_item	3710271	et	0	cKUAfXynZ
need	doc_831529852295_item	3710272	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3710273	et	0	cKUAfXynZ
olla	doc_831529852295_item	3710274	et	0	cKUAfXynZ
ajus	doc_831529852295_item	3710275	et	0	cKUAfXynZ
kuulutuspiltide	doc_831529852295_item	3710276	et	0	cKUAfXynZ
moodustamine	doc_831529852295_item	3710277	et	0	cKUAfXynZ
informatsiooni	doc_831529852295_item	3710278	et	0	cKUAfXynZ
klassifitseerimine	doc_831529852295_item	3710279	et	0	cKUAfXynZ
küsimine	doc_831529852295_item	3710280	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710281	et	0	cKUAfXynZ
kontrollimine	doc_831529852295_item	3710282	et	0	cKUAfXynZ
kas	doc_831529852295_item	3710283	et	0	cKUAfXynZ
laps	doc_831529852295_item	3710284	et	0	cKUAfXynZ
on	doc_831529852295_item	3710285	et	0	cKUAfXynZ
õigesti	doc_831529852295_item	3710286	et	0	cKUAfXynZ
kõike	doc_831529852295_item	3710287	et	0	cKUAfXynZ
aru	doc_831529852295_item	3710288	et	0	cKUAfXynZ
saanud	doc_831529852295_item	3710289	et	0	cKUAfXynZ
kasuks	doc_831529852295_item	3710290	et	0	cKUAfXynZ
läheb	doc_831529852295_item	3710291	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710292	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710293	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3710294	et	0	cKUAfXynZ
teevad	doc_831529852295_item	3710295	et	0	cKUAfXynZ
märkmeid	doc_831529852295_item	3710296	et	0	cKUAfXynZ
kirjutavad	doc_831529852295_item	3710297	et	0	cKUAfXynZ
üles	doc_831529852295_item	3710298	et	0	cKUAfXynZ
tähtsat	doc_831529852295_item	3710299	et	0	cKUAfXynZ
infot	doc_831529852295_item	3710300	et	0	cKUAfXynZ
kuulamisega	doc_831529852295_item	3710301	et	0	cKUAfXynZ
on	doc_831529852295_item	3710302	et	0	cKUAfXynZ
seotud	doc_831529852295_item	3710303	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710304	et	0	cKUAfXynZ
palju	doc_831529852295_item	3710305	et	0	cKUAfXynZ
erinevaid	doc_831529852295_item	3710306	et	0	cKUAfXynZ
ülesandeid	doc_831529852295_item	3710307	et	0	cKUAfXynZ
anne	doc_831529852295_item	3710308	et	0	cKUAfXynZ
uuseni	doc_831529852295_item	3710309	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3710310	et	0	cKUAfXynZ
on	doc_831529852295_item	3710311	et	0	cKUAfXynZ
neid	doc_831529852295_item	3710312	et	0	cKUAfXynZ
küllaltki	doc_831529852295_item	3710313	et	0	cKUAfXynZ
palju	doc_831529852295_item	3710314	et	0	cKUAfXynZ
see	doc_831529852295_item	3710315	et	0	cKUAfXynZ
võib	doc_831529852295_item	3710316	et	0	cKUAfXynZ
aidata	doc_831529852295_item	3710317	et	0	cKUAfXynZ
õpetajatele	doc_831529852295_item	3710318	et	0	cKUAfXynZ
teha	doc_831529852295_item	3710319	et	0	cKUAfXynZ
õppimist	doc_831529852295_item	3710320	et	0	cKUAfXynZ
huvitavamaks	doc_831529852295_item	3710321	et	0	cKUAfXynZ
laste	doc_831529852295_item	3710322	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3710323	et	0	cKUAfXynZ
3	doc_831529852295_item	3710324	et	0	cKUAfXynZ
rääkimine	doc_831529852295_item	3710325	et	0	cKUAfXynZ
käesolevas	doc_831529852295_item	3710326	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3710327	et	0	cKUAfXynZ
leiab	doc_831529852295_item	3710328	et	0	cKUAfXynZ
vastust	doc_831529852295_item	3710329	et	0	cKUAfXynZ
küsimustele	doc_831529852295_item	3710330	et	0	cKUAfXynZ
mis	doc_831529852295_item	3710331	et	0	cKUAfXynZ
on	doc_831529852295_item	3710332	et	0	cKUAfXynZ
seotud	doc_831529852295_item	3710333	et	0	cKUAfXynZ
rääkimisega	doc_831529852295_item	3710334	et	0	cKUAfXynZ
rääkimine	doc_831529852295_item	3710335	et	0	cKUAfXynZ
on	doc_831529852295_item	3710336	et	0	cKUAfXynZ
suhtlemisest	doc_831529852295_item	3710337	et	0	cKUAfXynZ
lahutamatu	doc_831529852295_item	3710338	et	0	cKUAfXynZ
osa	doc_831529852295_item	3710339	et	0	cKUAfXynZ
kuna	doc_831529852295_item	3710340	et	0	cKUAfXynZ
laps	doc_831529852295_item	3710341	et	0	cKUAfXynZ
hakkab	doc_831529852295_item	3710342	et	0	cKUAfXynZ
rääkima	doc_831529852295_item	3710343	et	0	cKUAfXynZ
varem	doc_831529852295_item	3710344	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710345	et	0	cKUAfXynZ
kooli	doc_831529852295_item	3710346	et	0	cKUAfXynZ
läheb	doc_831529852295_item	3710347	et	0	cKUAfXynZ
on	doc_831529852295_item	3710348	et	0	cKUAfXynZ
kõneharjumused	doc_831529852295_item	3710349	et	0	cKUAfXynZ
kõikidel	doc_831529852295_item	3710350	et	0	cKUAfXynZ
lastel	doc_831529852295_item	3710351	et	0	cKUAfXynZ
erinevad	doc_831529852295_item	3710352	et	0	cKUAfXynZ
need	doc_831529852295_item	3710353	et	0	cKUAfXynZ
sõltuvad	doc_831529852295_item	3710354	et	0	cKUAfXynZ
perest	doc_831529852295_item	3710355	et	0	cKUAfXynZ
keskkonnast	doc_831529852295_item	3710356	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710357	et	0	cKUAfXynZ
lapse	doc_831529852295_item	3710358	et	0	cKUAfXynZ
isikliku	doc_831529852295_item	3710359	et	0	cKUAfXynZ
kogemusest	doc_831529852295_item	3710360	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3710361	et	0	cKUAfXynZ
peab	doc_831529852295_item	3710362	et	0	cKUAfXynZ
sellega	doc_831529852295_item	3710363	et	0	cKUAfXynZ
arvestama	doc_831529852295_item	3710364	et	0	cKUAfXynZ
programmi	doc_831529852295_item	3710365	et	0	cKUAfXynZ
koostades	doc_831529852295_item	3710366	et	0	cKUAfXynZ
soovitav	doc_831529852295_item	3710367	et	0	cKUAfXynZ
et	doc_831529852295_item	3710368	et	0	cKUAfXynZ
programmis	doc_831529852295_item	3710369	et	0	cKUAfXynZ
oleksid	doc_831529852295_item	3710370	et	0	cKUAfXynZ
kõik	doc_831529852295_item	3710371	et	0	cKUAfXynZ
põhilised	doc_831529852295_item	3710372	et	0	cKUAfXynZ
komponendid	doc_831529852295_item	3710373	et	0	cKUAfXynZ
kõik	doc_831529852295_item	3710374	et	0	cKUAfXynZ
erinevad	doc_831529852295_item	3710375	et	0	cKUAfXynZ
suulise	doc_831529852295_item	3710376	et	0	cKUAfXynZ
keelekasutuse	doc_831529852295_item	3710377	et	0	cKUAfXynZ
funktsioone	doc_831529852295_item	3710378	et	0	cKUAfXynZ
need	doc_831529852295_item	3710379	et	0	cKUAfXynZ
on	doc_831529852295_item	3710380	et	0	cKUAfXynZ
jutustamine	doc_831529852295_item	3710381	et	0	cKUAfXynZ
vestlemine	doc_831529852295_item	3710382	et	0	cKUAfXynZ
arutlemine	doc_831529852295_item	3710383	et	0	cKUAfXynZ
kirjeldamine	doc_831529852295_item	3710384	et	0	cKUAfXynZ
kommunikatiivse	doc_831529852295_item	3710385	et	0	cKUAfXynZ
arengu	doc_831529852295_item	3710386	et	0	cKUAfXynZ
juhul	doc_831529852295_item	3710387	et	0	cKUAfXynZ
tuleks	doc_831529852295_item	3710388	et	0	cKUAfXynZ
pöörata	doc_831529852295_item	3710389	et	0	cKUAfXynZ
tähelepanu	doc_831529852295_item	3710390	et	0	cKUAfXynZ
artikulatsioonile	doc_831529852295_item	3710391	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710392	et	0	cKUAfXynZ
intonatsioonile	doc_831529852295_item	3710393	et	0	cKUAfXynZ
artikulatsiooni	doc_831529852295_item	3710394	et	0	cKUAfXynZ
võib	doc_831529852295_item	3710395	et	0	cKUAfXynZ
korrektiive	doc_831529852295_item	3710396	et	0	cKUAfXynZ
teha	doc_831529852295_item	3710397	et	0	cKUAfXynZ
vajaduse	doc_831529852295_item	3710398	et	0	cKUAfXynZ
puhul	doc_831529852295_item	3710399	et	0	cKUAfXynZ
näiteks	doc_831529852295_item	3710400	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710401	et	0	cKUAfXynZ
lapsel	doc_831529852295_item	3710402	et	0	cKUAfXynZ
on	doc_831529852295_item	3710403	et	0	cKUAfXynZ
artikulatsiooniprobleemid	doc_831529852295_item	3710404	et	0	cKUAfXynZ
et	doc_831529852295_item	3710405	et	0	cKUAfXynZ
programm	doc_831529852295_item	3710406	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3710407	et	0	cKUAfXynZ
efektiivsem	doc_831529852295_item	3710408	et	0	cKUAfXynZ
peab	doc_831529852295_item	3710409	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3710410	et	0	cKUAfXynZ
teadma	doc_831529852295_item	3710411	et	0	cKUAfXynZ
mitmeid	doc_831529852295_item	3710412	et	0	cKUAfXynZ
faktoreid	doc_831529852295_item	3710413	et	0	cKUAfXynZ
kuna	doc_831529852295_item	3710414	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3710415	et	0	cKUAfXynZ
õpivad	doc_831529852295_item	3710416	et	0	cKUAfXynZ
rääkida	doc_831529852295_item	3710417	et	0	cKUAfXynZ
ainult	doc_831529852295_item	3710418	et	0	cKUAfXynZ
rääkides	doc_831529852295_item	3710419	et	0	cKUAfXynZ
peab	doc_831529852295_item	3710420	et	0	cKUAfXynZ
rääkimiskeskkond	doc_831529852295_item	3710421	et	0	cKUAfXynZ
sarnanema	doc_831529852295_item	3710422	et	0	cKUAfXynZ
tegeliku	doc_831529852295_item	3710423	et	0	cKUAfXynZ
suhtlemiskeskkonnaga	doc_831529852295_item	3710424	et	0	cKUAfXynZ
õpetajal	doc_831529852295_item	3710425	et	0	cKUAfXynZ
on	doc_831529852295_item	3710426	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3710427	et	0	cKUAfXynZ
olla	doc_831529852295_item	3710428	et	0	cKUAfXynZ
ühtaegu	doc_831529852295_item	3710429	et	0	cKUAfXynZ
kuulajana	doc_831529852295_item	3710430	et	0	cKUAfXynZ
juhendajana	doc_831529852295_item	3710431	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710432	et	0	cKUAfXynZ
situatsioonis	doc_831529852295_item	3710433	et	0	cKUAfXynZ
osalejana	doc_831529852295_item	3710434	et	0	cKUAfXynZ
õpilasel	doc_831529852295_item	3710435	et	0	cKUAfXynZ
peab	doc_831529852295_item	3710436	et	0	cKUAfXynZ
olema	doc_831529852295_item	3710437	et	0	cKUAfXynZ
võimalus	doc_831529852295_item	3710438	et	0	cKUAfXynZ
aktiivselt	doc_831529852295_item	3710439	et	0	cKUAfXynZ
osaleda	doc_831529852295_item	3710440	et	0	cKUAfXynZ
töös	doc_831529852295_item	3710441	et	0	cKUAfXynZ
see	doc_831529852295_item	3710442	et	0	cKUAfXynZ
võib	doc_831529852295_item	3710443	et	0	cKUAfXynZ
olla	doc_831529852295_item	3710444	et	0	cKUAfXynZ
vestlemine	doc_831529852295_item	3710445	et	0	cKUAfXynZ
klassikaaslasega	doc_831529852295_item	3710446	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3710447	et	0	cKUAfXynZ
töö	doc_831529852295_item	3710448	et	0	cKUAfXynZ
grupis	doc_831529852295_item	3710449	et	0	cKUAfXynZ
laps	doc_831529852295_item	3710450	et	0	cKUAfXynZ
peab	doc_831529852295_item	3710451	et	0	cKUAfXynZ
suutma	doc_831529852295_item	3710452	et	0	cKUAfXynZ
väljendada	doc_831529852295_item	3710453	et	0	cKUAfXynZ
oma	doc_831529852295_item	3710454	et	0	cKUAfXynZ
mõtteid	doc_831529852295_item	3710455	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710456	et	0	cKUAfXynZ
emotsioone	doc_831529852295_item	3710457	et	0	cKUAfXynZ
selleks	doc_831529852295_item	3710458	et	0	cKUAfXynZ
on	doc_831529852295_item	3710459	et	0	cKUAfXynZ
tal	doc_831529852295_item	3710460	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3710461	et	0	cKUAfXynZ
kasutada	doc_831529852295_item	3710462	et	0	cKUAfXynZ
keelt	doc_831529852295_item	3710463	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710464	et	0	cKUAfXynZ
suhtlemisvahendit	doc_831529852295_item	3710465	et	0	cKUAfXynZ
suuline	doc_831529852295_item	3710466	et	0	cKUAfXynZ
keelekasutus	doc_831529852295_item	3710467	et	0	cKUAfXynZ
lubab	doc_831529852295_item	3710468	et	0	cKUAfXynZ
lapsele	doc_831529852295_item	3710469	et	0	cKUAfXynZ
arendada	doc_831529852295_item	3710470	et	0	cKUAfXynZ
sõnavara	doc_831529852295_item	3710471	et	0	cKUAfXynZ
õpetab	doc_831529852295_item	3710472	et	0	cKUAfXynZ
süntaksi	doc_831529852295_item	3710473	et	0	cKUAfXynZ
intonatsiooni	doc_831529852295_item	3710474	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710475	et	0	cKUAfXynZ
artikulatsiooni	doc_831529852295_item	3710476	et	0	cKUAfXynZ
on	doc_831529852295_item	3710477	et	0	cKUAfXynZ
väga	doc_831529852295_item	3710478	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3710479	et	0	cKUAfXynZ
et	doc_831529852295_item	3710480	et	0	cKUAfXynZ
kõik	doc_831529852295_item	3710481	et	0	cKUAfXynZ
suulised	doc_831529852295_item	3710482	et	0	cKUAfXynZ
keelefunktsioonid	doc_831529852295_item	3710483	et	0	cKUAfXynZ
arendaksid	doc_831529852295_item	3710484	et	0	cKUAfXynZ
juba	doc_831529852295_item	3710485	et	0	cKUAfXynZ
algklassides	doc_831529852295_item	3710486	et	0	cKUAfXynZ
ei	doc_831529852295_item	3710487	et	0	cKUAfXynZ
tohiks	doc_831529852295_item	3710488	et	0	cKUAfXynZ
et	doc_831529852295_item	3710489	et	0	cKUAfXynZ
see	doc_831529852295_item	3710490	et	0	cKUAfXynZ
pidurdaks	doc_831529852295_item	3710491	et	0	cKUAfXynZ
31	doc_831529852295_item	3710492	et	0	cKUAfXynZ
jutustamine	doc_831529852295_item	3710493	et	0	cKUAfXynZ
jutustamine	doc_831529852295_item	3710494	et	0	cKUAfXynZ
on	doc_831529852295_item	3710495	et	0	cKUAfXynZ
üks	doc_831529852295_item	3710496	et	0	cKUAfXynZ
suulisekeelekasutuse	doc_831529852295_item	3710497	et	0	cKUAfXynZ
liikidest	doc_831529852295_item	3710498	et	0	cKUAfXynZ
sellel	doc_831529852295_item	3710499	et	0	cKUAfXynZ
on	doc_831529852295_item	3710500	et	0	cKUAfXynZ
neli	doc_831529852295_item	3710501	et	0	cKUAfXynZ
peamist	doc_831529852295_item	3710502	et	0	cKUAfXynZ
eesmärki	doc_831529852295_item	3710503	et	0	cKUAfXynZ
informeerida	doc_831529852295_item	3710504	et	0	cKUAfXynZ
kellegi	doc_831529852295_item	3710505	et	0	cKUAfXynZ
millestki	doc_831529852295_item	3710506	et	0	cKUAfXynZ
põhjustada	doc_831529852295_item	3710507	et	0	cKUAfXynZ
kuulaja	doc_831529852295_item	3710508	et	0	cKUAfXynZ
vaimse	doc_831529852295_item	3710509	et	0	cKUAfXynZ
või	doc_831529852295_item	3710510	et	0	cKUAfXynZ
füüsilise	doc_831529852295_item	3710511	et	0	cKUAfXynZ
tegevuse	doc_831529852295_item	3710512	et	0	cKUAfXynZ
järeluurida	doc_831529852295_item	3710513	et	0	cKUAfXynZ
midagi	doc_831529852295_item	3710514	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3710515	et	0	cKUAfXynZ
mingis	doc_831529852295_item	3710516	et	0	cKUAfXynZ
asjas	doc_831529852295_item	3710517	et	0	cKUAfXynZ
selgust	doc_831529852295_item	3710518	et	0	cKUAfXynZ
saada	doc_831529852295_item	3710519	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710520	et	0	cKUAfXynZ
nautida	doc_831529852295_item	3710521	et	0	cKUAfXynZ
jutustava	doc_831529852295_item	3710522	et	0	cKUAfXynZ
peetakse	doc_831529852295_item	3710523	et	0	cKUAfXynZ
oluliseks	doc_831529852295_item	3710524	et	0	cKUAfXynZ
et	doc_831529852295_item	3710525	et	0	cKUAfXynZ
õpilane	doc_831529852295_item	3710526	et	0	cKUAfXynZ
saaks	doc_831529852295_item	3710527	et	0	cKUAfXynZ
teha	doc_831529852295_item	3710528	et	0	cKUAfXynZ
ettekanne	doc_831529852295_item	3710529	et	0	cKUAfXynZ
ettekandmise	doc_831529852295_item	3710530	et	0	cKUAfXynZ
teemasid	doc_831529852295_item	3710531	et	0	cKUAfXynZ
saab	doc_831529852295_item	3710532	et	0	cKUAfXynZ
leida	doc_831529852295_item	3710533	et	0	cKUAfXynZ
igast	doc_831529852295_item	3710534	et	0	cKUAfXynZ
tekstist	doc_831529852295_item	3710535	et	0	cKUAfXynZ
või	doc_831529852295_item	3710536	et	0	cKUAfXynZ
tunniteemast	doc_831529852295_item	3710537	et	0	cKUAfXynZ
mida	doc_831529852295_item	3710538	et	0	cKUAfXynZ
väiksem	doc_831529852295_item	3710539	et	0	cKUAfXynZ
on	doc_831529852295_item	3710540	et	0	cKUAfXynZ
laps	doc_831529852295_item	3710541	et	0	cKUAfXynZ
seda	doc_831529852295_item	3710542	et	0	cKUAfXynZ
konkreetsem	doc_831529852295_item	3710543	et	0	cKUAfXynZ
peaks	doc_831529852295_item	3710544	et	0	cKUAfXynZ
teema	doc_831529852295_item	3710545	et	0	cKUAfXynZ
olema	doc_831529852295_item	3710546	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3710547	et	0	cKUAfXynZ
peab	doc_831529852295_item	3710548	et	0	cKUAfXynZ
kontrollima	doc_831529852295_item	3710549	et	0	cKUAfXynZ
kas	doc_831529852295_item	3710550	et	0	cKUAfXynZ
ettekanne	doc_831529852295_item	3710551	et	0	cKUAfXynZ
tegemine	doc_831529852295_item	3710552	et	0	cKUAfXynZ
arendab	doc_831529852295_item	3710553	et	0	cKUAfXynZ
last	doc_831529852295_item	3710554	et	0	cKUAfXynZ
põhiliselt	doc_831529852295_item	3710555	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3710556	et	0	cKUAfXynZ
arendada	doc_831529852295_item	3710557	et	0	cKUAfXynZ
keha	doc_831529852295_item	3710558	et	0	cKUAfXynZ
keele	doc_831529852295_item	3710559	et	0	cKUAfXynZ
valitsemist	doc_831529852295_item	3710560	et	0	cKUAfXynZ
auditooriumitunnetust	doc_831529852295_item	3710561	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710562	et	0	cKUAfXynZ
teema	doc_831529852295_item	3710563	et	0	cKUAfXynZ
viimistlust	doc_831529852295_item	3710564	et	0	cKUAfXynZ
donoghue	doc_831529852295_item	3710565	et	0	cKUAfXynZ
1991	doc_831529852295_item	3710566	et	0	cKUAfXynZ
viidatud	doc_831529852295_item	3710567	et	0	cKUAfXynZ
uusen	doc_831529852295_item	3710568	et	0	cKUAfXynZ
2002	doc_831529852295_item	3710569	et	0	cKUAfXynZ
järgi	doc_831529852295_item	3710570	et	0	cKUAfXynZ
suuline	doc_831529852295_item	3710571	et	0	cKUAfXynZ
sõnum	doc_831529852295_item	3710572	et	0	cKUAfXynZ
peab	doc_831529852295_item	3710573	et	0	cKUAfXynZ
olema	doc_831529852295_item	3710574	et	0	cKUAfXynZ
lühike	doc_831529852295_item	3710575	et	0	cKUAfXynZ
täpne	doc_831529852295_item	3710576	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710577	et	0	cKUAfXynZ
täielik	doc_831529852295_item	3710578	et	0	cKUAfXynZ
32	doc_831529852295_item	3710579	et	0	cKUAfXynZ
vestlus	doc_831529852295_item	3710580	et	0	cKUAfXynZ
vestlus	doc_831529852295_item	3710581	et	0	cKUAfXynZ
on	doc_831529852295_item	3710582	et	0	cKUAfXynZ
spontaanne	doc_831529852295_item	3710583	et	0	cKUAfXynZ
mitteametlik	doc_831529852295_item	3710584	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710585	et	0	cKUAfXynZ
arendab	doc_831529852295_item	3710586	et	0	cKUAfXynZ
sotsiaalseid	doc_831529852295_item	3710587	et	0	cKUAfXynZ
oskusi	doc_831529852295_item	3710588	et	0	cKUAfXynZ
hea	doc_831529852295_item	3710589	et	0	cKUAfXynZ
vestlusoskus	doc_831529852295_item	3710590	et	0	cKUAfXynZ
lubab	doc_831529852295_item	3710591	et	0	cKUAfXynZ
lastel	doc_831529852295_item	3710592	et	0	cKUAfXynZ
leida	doc_831529852295_item	3710593	et	0	cKUAfXynZ
sõpru	doc_831529852295_item	3710594	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710595	et	0	cKUAfXynZ
suurendab	doc_831529852295_item	3710596	et	0	cKUAfXynZ
eneseusaldust	doc_831529852295_item	3710597	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3710598	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3710599	et	0	cKUAfXynZ
on	doc_831529852295_item	3710600	et	0	cKUAfXynZ
algata	doc_831529852295_item	3710601	et	0	cKUAfXynZ
juhendada	doc_831529852295_item	3710602	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710603	et	0	cKUAfXynZ
suunata	doc_831529852295_item	3710604	et	0	cKUAfXynZ
vestlust	doc_831529852295_item	3710605	et	0	cKUAfXynZ
vestluse	doc_831529852295_item	3710606	et	0	cKUAfXynZ
korraldamises	doc_831529852295_item	3710607	et	0	cKUAfXynZ
on	doc_831529852295_item	3710608	et	0	cKUAfXynZ
väga	doc_831529852295_item	3710609	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3710610	et	0	cKUAfXynZ
atmosfäär	doc_831529852295_item	3710611	et	0	cKUAfXynZ
klassis	doc_831529852295_item	3710612	et	0	cKUAfXynZ
peab	doc_831529852295_item	3710613	et	0	cKUAfXynZ
olema	doc_831529852295_item	3710614	et	0	cKUAfXynZ
sõbralik	doc_831529852295_item	3710615	et	0	cKUAfXynZ
õhkkond	doc_831529852295_item	3710616	et	0	cKUAfXynZ
tavaliselt	doc_831529852295_item	3710617	et	0	cKUAfXynZ
vestlus	doc_831529852295_item	3710618	et	0	cKUAfXynZ
kulgeb	doc_831529852295_item	3710619	et	0	cKUAfXynZ
teemalt	doc_831529852295_item	3710620	et	0	cKUAfXynZ
teemale	doc_831529852295_item	3710621	et	0	cKUAfXynZ
lastel	doc_831529852295_item	3710622	et	0	cKUAfXynZ
toimuvad	doc_831529852295_item	3710623	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710624	et	0	cKUAfXynZ
sotsiaalsed	doc_831529852295_item	3710625	et	0	cKUAfXynZ
vestlused	doc_831529852295_item	3710626	et	0	cKUAfXynZ
aga	doc_831529852295_item	3710627	et	0	cKUAfXynZ
need	doc_831529852295_item	3710628	et	0	cKUAfXynZ
tihti	doc_831529852295_item	3710629	et	0	cKUAfXynZ
toimuvad	doc_831529852295_item	3710630	et	0	cKUAfXynZ
juba	doc_831529852295_item	3710631	et	0	cKUAfXynZ
klassi	doc_831529852295_item	3710632	et	0	cKUAfXynZ
väljaspool	doc_831529852295_item	3710633	et	0	cKUAfXynZ
kahe	doc_831529852295_item	3710634	et	0	cKUAfXynZ
õpilase	doc_831529852295_item	3710635	et	0	cKUAfXynZ
vaheline	doc_831529852295_item	3710636	et	0	cKUAfXynZ
vestlus	doc_831529852295_item	3710637	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3710638	et	0	cKUAfXynZ
dialoog	doc_831529852295_item	3710639	et	0	cKUAfXynZ
kindlustab	doc_831529852295_item	3710640	et	0	cKUAfXynZ
mõlema	doc_831529852295_item	3710641	et	0	cKUAfXynZ
osavõtu	doc_831529852295_item	3710642	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710643	et	0	cKUAfXynZ
pakub	doc_831529852295_item	3710644	et	0	cKUAfXynZ
inimliku	doc_831529852295_item	3710645	et	0	cKUAfXynZ
lähedust	doc_831529852295_item	3710646	et	0	cKUAfXynZ
see	doc_831529852295_item	3710647	et	0	cKUAfXynZ
pakub	doc_831529852295_item	3710648	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710649	et	0	cKUAfXynZ
tagasisidet	doc_831529852295_item	3710650	et	0	cKUAfXynZ
dialoogi	doc_831529852295_item	3710651	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3710652	et	0	cKUAfXynZ
on	doc_831529852295_item	3710653	et	0	cKUAfXynZ
soovitav	doc_831529852295_item	3710654	et	0	cKUAfXynZ
et	doc_831529852295_item	3710655	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3710656	et	0	cKUAfXynZ
oleksid	doc_831529852295_item	3710657	et	0	cKUAfXynZ
saama	doc_831529852295_item	3710658	et	0	cKUAfXynZ
vanust	doc_831529852295_item	3710659	et	0	cKUAfXynZ
siin	doc_831529852295_item	3710660	et	0	cKUAfXynZ
on	doc_831529852295_item	3710661	et	0	cKUAfXynZ
võrdsed	doc_831529852295_item	3710662	et	0	cKUAfXynZ
võimalused	doc_831529852295_item	3710663	et	0	cKUAfXynZ
suhtlemise	doc_831529852295_item	3710664	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3710665	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710666	et	0	cKUAfXynZ
üks	doc_831529852295_item	3710667	et	0	cKUAfXynZ
on	doc_831529852295_item	3710668	et	0	cKUAfXynZ
vanem	doc_831529852295_item	3710669	et	0	cKUAfXynZ
siis	doc_831529852295_item	3710670	et	0	cKUAfXynZ
ta	doc_831529852295_item	3710671	et	0	cKUAfXynZ
hakkab	doc_831529852295_item	3710672	et	0	cKUAfXynZ
domineerima	doc_831529852295_item	3710673	et	0	cKUAfXynZ
33	doc_831529852295_item	3710674	et	0	cKUAfXynZ
diskussioon	doc_831529852295_item	3710675	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3710676	et	0	cKUAfXynZ
arutlus	doc_831529852295_item	3710677	et	0	cKUAfXynZ
arutlus	doc_831529852295_item	3710678	et	0	cKUAfXynZ
on	doc_831529852295_item	3710679	et	0	cKUAfXynZ
küllaltki	doc_831529852295_item	3710680	et	0	cKUAfXynZ
sarnane	doc_831529852295_item	3710681	et	0	cKUAfXynZ
vestlusega	doc_831529852295_item	3710682	et	0	cKUAfXynZ
kuid	doc_831529852295_item	3710683	et	0	cKUAfXynZ
selle	doc_831529852295_item	3710684	et	0	cKUAfXynZ
eesmärgiks	doc_831529852295_item	3710685	et	0	cKUAfXynZ
on	doc_831529852295_item	3710686	et	0	cKUAfXynZ
probleemi	doc_831529852295_item	3710687	et	0	cKUAfXynZ
lahendamine	doc_831529852295_item	3710688	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710689	et	0	cKUAfXynZ
otsusele	doc_831529852295_item	3710690	et	0	cKUAfXynZ
jõudmine	doc_831529852295_item	3710691	et	0	cKUAfXynZ
diskusiooni	doc_831529852295_item	3710692	et	0	cKUAfXynZ
läbiviimiseks	doc_831529852295_item	3710693	et	0	cKUAfXynZ
on	doc_831529852295_item	3710694	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3710695	et	0	cKUAfXynZ
loov	doc_831529852295_item	3710696	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710697	et	0	cKUAfXynZ
kriitiline	doc_831529852295_item	3710698	et	0	cKUAfXynZ
mõtlemine	doc_831529852295_item	3710699	et	0	cKUAfXynZ
oluliseks	doc_831529852295_item	3710700	et	0	cKUAfXynZ
on	doc_831529852295_item	3710701	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710702	et	0	cKUAfXynZ
teemast	doc_831529852295_item	3710703	et	0	cKUAfXynZ
kinnipidamine	doc_831529852295_item	3710704	et	0	cKUAfXynZ
laste	doc_831529852295_item	3710705	et	0	cKUAfXynZ
paigutus	doc_831529852295_item	3710706	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710707	et	0	cKUAfXynZ
on	doc_831529852295_item	3710708	et	0	cKUAfXynZ
teguriks	doc_831529852295_item	3710709	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710710	et	0	cKUAfXynZ
klassiruum	doc_831529852295_item	3710711	et	0	cKUAfXynZ
võimaldab	doc_831529852295_item	3710712	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3710713	et	0	cKUAfXynZ
hea	doc_831529852295_item	3710714	et	0	cKUAfXynZ
istuda	doc_831529852295_item	3710715	et	0	cKUAfXynZ
ringi	doc_831529852295_item	3710716	et	0	cKUAfXynZ
et	doc_831529852295_item	3710717	et	0	cKUAfXynZ
kõikidele	doc_831529852295_item	3710718	et	0	cKUAfXynZ
lastele	doc_831529852295_item	3710719	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3710720	et	0	cKUAfXynZ
üksteist	doc_831529852295_item	3710721	et	0	cKUAfXynZ
näha	doc_831529852295_item	3710722	et	0	cKUAfXynZ
võib	doc_831529852295_item	3710723	et	0	cKUAfXynZ
teha	doc_831529852295_item	3710724	et	0	cKUAfXynZ
veel	doc_831529852295_item	3710725	et	0	cKUAfXynZ
väikse	doc_831529852295_item	3710726	et	0	cKUAfXynZ
ringi	doc_831529852295_item	3710727	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710728	et	0	cKUAfXynZ
jagada	doc_831529852295_item	3710729	et	0	cKUAfXynZ
kõike	doc_831529852295_item	3710730	et	0	cKUAfXynZ
laste	doc_831529852295_item	3710731	et	0	cKUAfXynZ
gruppidesse	doc_831529852295_item	3710732	et	0	cKUAfXynZ
enne	doc_831529852295_item	3710733	et	0	cKUAfXynZ
ühist	doc_831529852295_item	3710734	et	0	cKUAfXynZ
arutelu	doc_831529852295_item	3710735	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3710736	et	0	cKUAfXynZ
toimuda	doc_831529852295_item	3710737	et	0	cKUAfXynZ
grupisisesed	doc_831529852295_item	3710738	et	0	cKUAfXynZ
arutelud	doc_831529852295_item	3710739	et	0	cKUAfXynZ
pärast	doc_831529852295_item	3710740	et	0	cKUAfXynZ
iga	doc_831529852295_item	3710741	et	0	cKUAfXynZ
grupp	doc_831529852295_item	3710742	et	0	cKUAfXynZ
kannab	doc_831529852295_item	3710743	et	0	cKUAfXynZ
oma	doc_831529852295_item	3710744	et	0	cKUAfXynZ
arutelu	doc_831529852295_item	3710745	et	0	cKUAfXynZ
tulemusi	doc_831529852295_item	3710746	et	0	cKUAfXynZ
teisele	doc_831529852295_item	3710747	et	0	cKUAfXynZ
ette	doc_831529852295_item	3710748	et	0	cKUAfXynZ
väikes	doc_831529852295_item	3710749	et	0	cKUAfXynZ
grupis	doc_831529852295_item	3710750	et	0	cKUAfXynZ
toimuvat	doc_831529852295_item	3710751	et	0	cKUAfXynZ
diskussiooni	doc_831529852295_item	3710752	et	0	cKUAfXynZ
nimetatakse	doc_831529852295_item	3710753	et	0	cKUAfXynZ
ümarlaudiskussiooniks	doc_831529852295_item	3710754	et	0	cKUAfXynZ
gruppe	doc_831529852295_item	3710755	et	0	cKUAfXynZ
suminagruppideks	doc_831529852295_item	3710756	et	0	cKUAfXynZ
soovitav	doc_831529852295_item	3710757	et	0	cKUAfXynZ
et	doc_831529852295_item	3710758	et	0	cKUAfXynZ
väikses	doc_831529852295_item	3710759	et	0	cKUAfXynZ
grupis	doc_831529852295_item	3710760	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3710761	et	0	cKUAfXynZ
3	doc_831529852295_item	3710762	et	0	cKUAfXynZ
8	doc_831529852295_item	3710763	et	0	cKUAfXynZ
last	doc_831529852295_item	3710764	et	0	cKUAfXynZ
võib	doc_831529852295_item	3710765	et	0	cKUAfXynZ
organiseerida	doc_831529852295_item	3710766	et	0	cKUAfXynZ
diskussiooni	doc_831529852295_item	3710767	et	0	cKUAfXynZ
nii	doc_831529852295_item	3710768	et	0	cKUAfXynZ
et	doc_831529852295_item	3710769	et	0	cKUAfXynZ
väike	doc_831529852295_item	3710770	et	0	cKUAfXynZ
grupp	doc_831529852295_item	3710771	et	0	cKUAfXynZ
arutleks	doc_831529852295_item	3710772	et	0	cKUAfXynZ
mingi	doc_831529852295_item	3710773	et	0	cKUAfXynZ
probleemi	doc_831529852295_item	3710774	et	0	cKUAfXynZ
üle	doc_831529852295_item	3710775	et	0	cKUAfXynZ
aga	doc_831529852295_item	3710776	et	0	cKUAfXynZ
suur	doc_831529852295_item	3710777	et	0	cKUAfXynZ
vaataks	doc_831529852295_item	3710778	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710779	et	0	cKUAfXynZ
pärast	doc_831529852295_item	3710780	et	0	cKUAfXynZ
hinnaks	doc_831529852295_item	3710781	et	0	cKUAfXynZ
tuleks	doc_831529852295_item	3710782	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710783	et	0	cKUAfXynZ
valida	doc_831529852295_item	3710784	et	0	cKUAfXynZ
väikese	doc_831529852295_item	3710785	et	0	cKUAfXynZ
grupi	doc_831529852295_item	3710786	et	0	cKUAfXynZ
juhatajat	doc_831529852295_item	3710787	et	0	cKUAfXynZ
kes	doc_831529852295_item	3710788	et	0	cKUAfXynZ
tutvustaks	doc_831529852295_item	3710789	et	0	cKUAfXynZ
liikmeid	doc_831529852295_item	3710790	et	0	cKUAfXynZ
esindaks	doc_831529852295_item	3710791	et	0	cKUAfXynZ
probleemi	doc_831529852295_item	3710792	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710793	et	0	cKUAfXynZ
hoiaks	doc_831529852295_item	3710794	et	0	cKUAfXynZ
diskussiooni	doc_831529852295_item	3710795	et	0	cKUAfXynZ
üleval	doc_831529852295_item	3710796	et	0	cKUAfXynZ
tuleks	doc_831529852295_item	3710797	et	0	cKUAfXynZ
märkida	doc_831529852295_item	3710798	et	0	cKUAfXynZ
et	doc_831529852295_item	3710799	et	0	cKUAfXynZ
osavõtjad	doc_831529852295_item	3710800	et	0	cKUAfXynZ
peavad	doc_831529852295_item	3710801	et	0	cKUAfXynZ
olema	doc_831529852295_item	3710802	et	0	cKUAfXynZ
ette	doc_831529852295_item	3710803	et	0	cKUAfXynZ
valmistatud	doc_831529852295_item	3710804	et	0	cKUAfXynZ
34	doc_831529852295_item	3710805	et	0	cKUAfXynZ
väitlus	doc_831529852295_item	3710806	et	0	cKUAfXynZ
kahe	doc_831529852295_item	3710807	et	0	cKUAfXynZ
rühma	doc_831529852295_item	3710808	et	0	cKUAfXynZ
vahel	doc_831529852295_item	3710809	et	0	cKUAfXynZ
võib	doc_831529852295_item	3710810	et	0	cKUAfXynZ
teha	doc_831529852295_item	3710811	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710812	et	0	cKUAfXynZ
väitlust	doc_831529852295_item	3710813	et	0	cKUAfXynZ
selleks	doc_831529852295_item	3710814	et	0	cKUAfXynZ
peavad	doc_831529852295_item	3710815	et	0	cKUAfXynZ
mõlemad	doc_831529852295_item	3710816	et	0	cKUAfXynZ
grupid	doc_831529852295_item	3710817	et	0	cKUAfXynZ
esitada	doc_831529852295_item	3710818	et	0	cKUAfXynZ
argumente	doc_831529852295_item	3710819	et	0	cKUAfXynZ
väitluse	doc_831529852295_item	3710820	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3710821	et	0	cKUAfXynZ
on	doc_831529852295_item	3710822	et	0	cKUAfXynZ
arendada	doc_831529852295_item	3710823	et	0	cKUAfXynZ
argumenteerimisoskust	doc_831529852295_item	3710824	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710825	et	0	cKUAfXynZ
õpetada	doc_831529852295_item	3710826	et	0	cKUAfXynZ
et	doc_831529852295_item	3710827	et	0	cKUAfXynZ
igal	doc_831529852295_item	3710828	et	0	cKUAfXynZ
vaidlusküsimusel	doc_831529852295_item	3710829	et	0	cKUAfXynZ
võib	doc_831529852295_item	3710830	et	0	cKUAfXynZ
olla	doc_831529852295_item	3710831	et	0	cKUAfXynZ
mitu	doc_831529852295_item	3710832	et	0	cKUAfXynZ
lahendust	doc_831529852295_item	3710833	et	0	cKUAfXynZ
debatil	doc_831529852295_item	3710834	et	0	cKUAfXynZ
peab	doc_831529852295_item	3710835	et	0	cKUAfXynZ
olema	doc_831529852295_item	3710836	et	0	cKUAfXynZ
juht	doc_831529852295_item	3710837	et	0	cKUAfXynZ
kes	doc_831529852295_item	3710838	et	0	cKUAfXynZ
esindab	doc_831529852295_item	3710839	et	0	cKUAfXynZ
teemat	doc_831529852295_item	3710840	et	0	cKUAfXynZ
tutvustab	doc_831529852295_item	3710841	et	0	cKUAfXynZ
osavõtjaid	doc_831529852295_item	3710842	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710843	et	0	cKUAfXynZ
vaatab	doc_831529852295_item	3710844	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710845	et	0	cKUAfXynZ
palju	doc_831529852295_item	3710846	et	0	cKUAfXynZ
aega	doc_831529852295_item	3710847	et	0	cKUAfXynZ
debatid	doc_831529852295_item	3710848	et	0	cKUAfXynZ
võtavad	doc_831529852295_item	3710849	et	0	cKUAfXynZ
ta	doc_831529852295_item	3710850	et	0	cKUAfXynZ
peab	doc_831529852295_item	3710851	et	0	cKUAfXynZ
ka	doc_831529852295_item	3710852	et	0	cKUAfXynZ
otsustama	doc_831529852295_item	3710853	et	0	cKUAfXynZ
milline	doc_831529852295_item	3710854	et	0	cKUAfXynZ
pool	doc_831529852295_item	3710855	et	0	cKUAfXynZ
argumenteeris	doc_831529852295_item	3710856	et	0	cKUAfXynZ
paremini	doc_831529852295_item	3710857	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710858	et	0	cKUAfXynZ
seega	doc_831529852295_item	3710859	et	0	cKUAfXynZ
võitis	doc_831529852295_item	3710860	et	0	cKUAfXynZ
35	doc_831529852295_item	3710861	et	0	cKUAfXynZ
läbirääkimised	doc_831529852295_item	3710862	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3710863	et	0	cKUAfXynZ
parlamentaarse	doc_831529852295_item	3710864	et	0	cKUAfXynZ
protseduurijärgimine	doc_831529852295_item	3710865	et	0	cKUAfXynZ
läbirääkimisi	doc_831529852295_item	3710866	et	0	cKUAfXynZ
on	doc_831529852295_item	3710867	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3710868	et	0	cKUAfXynZ
pidada	doc_831529852295_item	3710869	et	0	cKUAfXynZ
olukordades	doc_831529852295_item	3710870	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710871	et	0	cKUAfXynZ
inimestel	doc_831529852295_item	3710872	et	0	cKUAfXynZ
on	doc_831529852295_item	3710873	et	0	cKUAfXynZ
palju	doc_831529852295_item	3710874	et	0	cKUAfXynZ
erinevaid	doc_831529852295_item	3710875	et	0	cKUAfXynZ
arvamusi	doc_831529852295_item	3710876	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710877	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3710878	et	0	cKUAfXynZ
jõuda	doc_831529852295_item	3710879	et	0	cKUAfXynZ
mingile	doc_831529852295_item	3710880	et	0	cKUAfXynZ
ühisele	doc_831529852295_item	3710881	et	0	cKUAfXynZ
otsustele	doc_831529852295_item	3710882	et	0	cKUAfXynZ
selline	doc_831529852295_item	3710883	et	0	cKUAfXynZ
otsus	doc_831529852295_item	3710884	et	0	cKUAfXynZ
peab	doc_831529852295_item	3710885	et	0	cKUAfXynZ
olema	doc_831529852295_item	3710886	et	0	cKUAfXynZ
enamikule	doc_831529852295_item	3710887	et	0	cKUAfXynZ
meelepärane	doc_831529852295_item	3710888	et	0	cKUAfXynZ
lapsele	doc_831529852295_item	3710889	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3710890	et	0	cKUAfXynZ
õpetada	doc_831529852295_item	3710891	et	0	cKUAfXynZ
käetõstmist	doc_831529852295_item	3710892	et	0	cKUAfXynZ
oma	doc_831529852295_item	3710893	et	0	cKUAfXynZ
kõnejärje	doc_831529852295_item	3710894	et	0	cKUAfXynZ
ootamist	doc_831529852295_item	3710895	et	0	cKUAfXynZ
ning	doc_831529852295_item	3710896	et	0	cKUAfXynZ
oskust	doc_831529852295_item	3710897	et	0	cKUAfXynZ
rääkida	doc_831529852295_item	3710898	et	0	cKUAfXynZ
siis	doc_831529852295_item	3710899	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710900	et	0	cKUAfXynZ
seda	doc_831529852295_item	3710901	et	0	cKUAfXynZ
lubatakse	doc_831529852295_item	3710902	et	0	cKUAfXynZ
nooremates	doc_831529852295_item	3710903	et	0	cKUAfXynZ
klassides	doc_831529852295_item	3710904	et	0	cKUAfXynZ
on	doc_831529852295_item	3710905	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3710906	et	0	cKUAfXynZ
et	doc_831529852295_item	3710907	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3710908	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3710909	et	0	cKUAfXynZ
koosoleku	doc_831529852295_item	3710910	et	0	cKUAfXynZ
juhatajana	doc_831529852295_item	3710911	et	0	cKUAfXynZ
pärast	doc_831529852295_item	3710912	et	0	cKUAfXynZ
kui	doc_831529852295_item	3710913	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3710914	et	0	cKUAfXynZ
on	doc_831529852295_item	3710915	et	0	cKUAfXynZ
juba	doc_831529852295_item	3710916	et	0	cKUAfXynZ
vastavat	doc_831529852295_item	3710917	et	0	cKUAfXynZ
töövormi	doc_831529852295_item	3710918	et	0	cKUAfXynZ
siis	doc_831529852295_item	3710919	et	0	cKUAfXynZ
võib	doc_831529852295_item	3710920	et	0	cKUAfXynZ
juhatajaks	doc_831529852295_item	3710921	et	0	cKUAfXynZ
valida	doc_831529852295_item	3710922	et	0	cKUAfXynZ
mõni	doc_831529852295_item	3710923	et	0	cKUAfXynZ
õpilast	doc_831529852295_item	3710924	et	0	cKUAfXynZ
läbirääkimisel	doc_831529852295_item	3710925	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3710926	et	0	cKUAfXynZ
teha	doc_831529852295_item	3710927	et	0	cKUAfXynZ
järjekorda	doc_831529852295_item	3710928	et	0	cKUAfXynZ
see	doc_831529852295_item	3710929	et	0	cKUAfXynZ
võib	doc_831529852295_item	3710930	et	0	cKUAfXynZ
koosneda	doc_831529852295_item	3710931	et	0	cKUAfXynZ
päevakorra	doc_831529852295_item	3710932	et	0	cKUAfXynZ
kuulatamisest	doc_831529852295_item	3710933	et	0	cKUAfXynZ
ettepanekutest	doc_831529852295_item	3710934	et	0	cKUAfXynZ
parandustest	doc_831529852295_item	3710935	et	0	cKUAfXynZ
pöördumistest	doc_831529852295_item	3710936	et	0	cKUAfXynZ
ettepaneku	doc_831529852295_item	3710937	et	0	cKUAfXynZ
hääletamistest	doc_831529852295_item	3710938	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710939	et	0	cKUAfXynZ
otsuse	doc_831529852295_item	3710940	et	0	cKUAfXynZ
ettelugemisest	doc_831529852295_item	3710941	et	0	cKUAfXynZ
36	doc_831529852295_item	3710942	et	0	cKUAfXynZ
intervjueerimine	doc_831529852295_item	3710943	et	0	cKUAfXynZ
algklassidest	doc_831529852295_item	3710944	et	0	cKUAfXynZ
võib	doc_831529852295_item	3710945	et	0	cKUAfXynZ
teha	doc_831529852295_item	3710946	et	0	cKUAfXynZ
intervjueerimiseks	doc_831529852295_item	3710947	et	0	cKUAfXynZ
rollimänge	doc_831529852295_item	3710948	et	0	cKUAfXynZ
selleks	doc_831529852295_item	3710949	et	0	cKUAfXynZ
on	doc_831529852295_item	3710950	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3710951	et	0	cKUAfXynZ
ette	doc_831529852295_item	3710952	et	0	cKUAfXynZ
kujundada	doc_831529852295_item	3710953	et	0	cKUAfXynZ
mingi	doc_831529852295_item	3710954	et	0	cKUAfXynZ
situatsiooni	doc_831529852295_item	3710955	et	0	cKUAfXynZ
laps	doc_831529852295_item	3710956	et	0	cKUAfXynZ
räägib	doc_831529852295_item	3710957	et	0	cKUAfXynZ
vanematega	doc_831529852295_item	3710958	et	0	cKUAfXynZ
õpilane	doc_831529852295_item	3710959	et	0	cKUAfXynZ
õpetajaga	doc_831529852295_item	3710960	et	0	cKUAfXynZ
vms	doc_831529852295_item	3710961	et	0	cKUAfXynZ
töö	doc_831529852295_item	3710962	et	0	cKUAfXynZ
käigus	doc_831529852295_item	3710963	et	0	cKUAfXynZ
on	doc_831529852295_item	3710964	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3710965	et	0	cKUAfXynZ
tähelepanu	doc_831529852295_item	3710966	et	0	cKUAfXynZ
pöörata	doc_831529852295_item	3710967	et	0	cKUAfXynZ
küsimustele	doc_831529852295_item	3710968	et	0	cKUAfXynZ
nende	doc_831529852295_item	3710969	et	0	cKUAfXynZ
sisukusele	doc_831529852295_item	3710970	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710971	et	0	cKUAfXynZ
sobivustele	doc_831529852295_item	3710972	et	0	cKUAfXynZ
intervjueerimine	doc_831529852295_item	3710973	et	0	cKUAfXynZ
on	doc_831529852295_item	3710974	et	0	cKUAfXynZ
kommunikatiivne	doc_831529852295_item	3710975	et	0	cKUAfXynZ
protsess	doc_831529852295_item	3710976	et	0	cKUAfXynZ
kuna	doc_831529852295_item	3710977	et	0	cKUAfXynZ
intervjueerimise	doc_831529852295_item	3710978	et	0	cKUAfXynZ
käigus	doc_831529852295_item	3710979	et	0	cKUAfXynZ
lapsel	doc_831529852295_item	3710980	et	0	cKUAfXynZ
on	doc_831529852295_item	3710981	et	0	cKUAfXynZ
võimalus	doc_831529852295_item	3710982	et	0	cKUAfXynZ
kuulata	doc_831529852295_item	3710983	et	0	cKUAfXynZ
esitada	doc_831529852295_item	3710984	et	0	cKUAfXynZ
küsimusi	doc_831529852295_item	3710985	et	0	cKUAfXynZ
lugeda	doc_831529852295_item	3710986	et	0	cKUAfXynZ
ja	doc_831529852295_item	3710987	et	0	cKUAfXynZ
kirjutada	doc_831529852295_item	3710988	et	0	cKUAfXynZ
see	doc_831529852295_item	3710989	et	0	cKUAfXynZ
aitab	doc_831529852295_item	3710990	et	0	cKUAfXynZ
arendada	doc_831529852295_item	3710991	et	0	cKUAfXynZ
huvi	doc_831529852295_item	3710992	et	0	cKUAfXynZ
kõikidele	doc_831529852295_item	3710993	et	0	cKUAfXynZ
keelelise	doc_831529852295_item	3710994	et	0	cKUAfXynZ
suhtlemise	doc_831529852295_item	3710995	et	0	cKUAfXynZ
funktsioonide	doc_831529852295_item	3710996	et	0	cKUAfXynZ
vastu	doc_831529852295_item	3710997	et	0	cKUAfXynZ
37	doc_831529852295_item	3710998	et	0	cKUAfXynZ
sotsiaalsete	doc_831529852295_item	3710999	et	0	cKUAfXynZ
suhete	doc_831529852295_item	3711000	et	0	cKUAfXynZ
väljendamine	doc_831529852295_item	3711001	et	0	cKUAfXynZ
sotsiaalsete	doc_831529852295_item	3711002	et	0	cKUAfXynZ
käitumisnormidega	doc_831529852295_item	3711003	et	0	cKUAfXynZ
peab	doc_831529852295_item	3711004	et	0	cKUAfXynZ
last	doc_831529852295_item	3711005	et	0	cKUAfXynZ
tutvustama	doc_831529852295_item	3711006	et	0	cKUAfXynZ
juba	doc_831529852295_item	3711007	et	0	cKUAfXynZ
varasest	doc_831529852295_item	3711008	et	0	cKUAfXynZ
lapseeast	doc_831529852295_item	3711009	et	0	cKUAfXynZ
siin	doc_831529852295_item	3711010	et	0	cKUAfXynZ
on	doc_831529852295_item	3711011	et	0	cKUAfXynZ
kõik	doc_831529852295_item	3711012	et	0	cKUAfXynZ
mida	doc_831529852295_item	3711013	et	0	cKUAfXynZ
oleme	doc_831529852295_item	3711014	et	0	cKUAfXynZ
harjunud	doc_831529852295_item	3711015	et	0	cKUAfXynZ
nimetama	doc_831529852295_item	3711016	et	0	cKUAfXynZ
viisakaks	doc_831529852295_item	3711017	et	0	cKUAfXynZ
suhtluskohale	doc_831529852295_item	3711018	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711019	et	0	cKUAfXynZ
oludele	doc_831529852295_item	3711020	et	0	cKUAfXynZ
vastavaks	doc_831529852295_item	3711021	et	0	cKUAfXynZ
käitumises	doc_831529852295_item	3711022	et	0	cKUAfXynZ
teadmine	doc_831529852295_item	3711023	et	0	cKUAfXynZ
kuidas	doc_831529852295_item	3711024	et	0	cKUAfXynZ
käituda	doc_831529852295_item	3711025	et	0	cKUAfXynZ
erinevates	doc_831529852295_item	3711026	et	0	cKUAfXynZ
olukordades	doc_831529852295_item	3711027	et	0	cKUAfXynZ
aitab	doc_831529852295_item	3711028	et	0	cKUAfXynZ
lapsel	doc_831529852295_item	3711029	et	0	cKUAfXynZ
olla	doc_831529852295_item	3711030	et	0	cKUAfXynZ
enesekindlamaks	doc_831529852295_item	3711031	et	0	cKUAfXynZ
oluline	doc_831529852295_item	3711032	et	0	cKUAfXynZ
faktor	doc_831529852295_item	3711033	et	0	cKUAfXynZ
käitumise	doc_831529852295_item	3711034	et	0	cKUAfXynZ
õpetamisel	doc_831529852295_item	3711035	et	0	cKUAfXynZ
on	doc_831529852295_item	3711036	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3711037	et	0	cKUAfXynZ
eeskuju	doc_831529852295_item	3711038	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3711039	et	0	cKUAfXynZ
seletada	doc_831529852295_item	3711040	et	0	cKUAfXynZ
lapsele	doc_831529852295_item	3711041	et	0	cKUAfXynZ
et	doc_831529852295_item	3711042	et	0	cKUAfXynZ
viisakas	doc_831529852295_item	3711043	et	0	cKUAfXynZ
on	doc_831529852295_item	3711044	et	0	cKUAfXynZ
teistesse	doc_831529852295_item	3711045	et	0	cKUAfXynZ
inimestesse	doc_831529852295_item	3711046	et	0	cKUAfXynZ
lugupidamise	doc_831529852295_item	3711047	et	0	cKUAfXynZ
väljendus	doc_831529852295_item	3711048	et	0	cKUAfXynZ
head	doc_831529852295_item	3711049	et	0	cKUAfXynZ
maneerid	doc_831529852295_item	3711050	et	0	cKUAfXynZ
on	doc_831529852295_item	3711051	et	0	cKUAfXynZ
aluseks	doc_831529852295_item	3711052	et	0	cKUAfXynZ
enesega	doc_831529852295_item	3711053	et	0	cKUAfXynZ
rahuolule	doc_831529852295_item	3711054	et	0	cKUAfXynZ
viisakas	doc_831529852295_item	3711055	et	0	cKUAfXynZ
käitumine	doc_831529852295_item	3711056	et	0	cKUAfXynZ
sõltub	doc_831529852295_item	3711057	et	0	cKUAfXynZ
enamasti	doc_831529852295_item	3711058	et	0	cKUAfXynZ
aususest	doc_831529852295_item	3711059	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711060	et	0	cKUAfXynZ
taktitundest	doc_831529852295_item	3711061	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3711062	et	0	cKUAfXynZ
mainida	doc_831529852295_item	3711063	et	0	cKUAfXynZ
ka	doc_831529852295_item	3711064	et	0	cKUAfXynZ
et	doc_831529852295_item	3711065	et	0	cKUAfXynZ
erinevates	doc_831529852295_item	3711066	et	0	cKUAfXynZ
maades	doc_831529852295_item	3711067	et	0	cKUAfXynZ
maneeride	doc_831529852295_item	3711068	et	0	cKUAfXynZ
traditsioon	doc_831529852295_item	3711069	et	0	cKUAfXynZ
on	doc_831529852295_item	3711070	et	0	cKUAfXynZ
erinev	doc_831529852295_item	3711071	et	0	cKUAfXynZ
aluseks	doc_831529852295_item	3711072	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3711073	et	0	cKUAfXynZ
õpetada	doc_831529852295_item	3711074	et	0	cKUAfXynZ
last	doc_831529852295_item	3711075	et	0	cKUAfXynZ
kuidas	doc_831529852295_item	3711076	et	0	cKUAfXynZ
on	doc_831529852295_item	3711077	et	0	cKUAfXynZ
õigesti	doc_831529852295_item	3711078	et	0	cKUAfXynZ
tutvustada	doc_831529852295_item	3711079	et	0	cKUAfXynZ
on	doc_831529852295_item	3711080	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3711081	et	0	cKUAfXynZ
öelda	doc_831529852295_item	3711082	et	0	cKUAfXynZ
et	doc_831529852295_item	3711083	et	0	cKUAfXynZ
tutvustamisel	doc_831529852295_item	3711084	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3711085	et	0	cKUAfXynZ
peale	doc_831529852295_item	3711086	et	0	cKUAfXynZ
oma	doc_831529852295_item	3711087	et	0	cKUAfXynZ
nime	doc_831529852295_item	3711088	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711089	et	0	cKUAfXynZ
üldiste	doc_831529852295_item	3711090	et	0	cKUAfXynZ
andmete	doc_831529852295_item	3711091	et	0	cKUAfXynZ
öelda	doc_831529852295_item	3711092	et	0	cKUAfXynZ
midagi	doc_831529852295_item	3711093	et	0	cKUAfXynZ
inimese	doc_831529852295_item	3711094	et	0	cKUAfXynZ
kohta	doc_831529852295_item	3711095	et	0	cKUAfXynZ
huvitavat	doc_831529852295_item	3711096	et	0	cKUAfXynZ
tutvustamist	doc_831529852295_item	3711097	et	0	cKUAfXynZ
saab	doc_831529852295_item	3711098	et	0	cKUAfXynZ
õpetada	doc_831529852295_item	3711099	et	0	cKUAfXynZ
rollimängude	doc_831529852295_item	3711100	et	0	cKUAfXynZ
abil	doc_831529852295_item	3711101	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3711102	et	0	cKUAfXynZ
võib	doc_831529852295_item	3711103	et	0	cKUAfXynZ
kontrollida	doc_831529852295_item	3711104	et	0	cKUAfXynZ
kas	doc_831529852295_item	3711105	et	0	cKUAfXynZ
laps	doc_831529852295_item	3711106	et	0	cKUAfXynZ
õigesti	doc_831529852295_item	3711107	et	0	cKUAfXynZ
valib	doc_831529852295_item	3711108	et	0	cKUAfXynZ
käitumisviisi	doc_831529852295_item	3711109	et	0	cKUAfXynZ
kui	doc_831529852295_item	3711110	et	0	cKUAfXynZ
mitte	doc_831529852295_item	3711111	et	0	cKUAfXynZ
siis	doc_831529852295_item	3711112	et	0	cKUAfXynZ
võib	doc_831529852295_item	3711113	et	0	cKUAfXynZ
seda	doc_831529852295_item	3711114	et	0	cKUAfXynZ
pärast	doc_831529852295_item	3711115	et	0	cKUAfXynZ
koos	doc_831529852295_item	3711116	et	0	cKUAfXynZ
lapsega	doc_831529852295_item	3711117	et	0	cKUAfXynZ
analüüsida	doc_831529852295_item	3711118	et	0	cKUAfXynZ
on	doc_831529852295_item	3711119	et	0	cKUAfXynZ
soovitav	doc_831529852295_item	3711120	et	0	cKUAfXynZ
kasutada	doc_831529852295_item	3711121	et	0	cKUAfXynZ
võimalikult	doc_831529852295_item	3711122	et	0	cKUAfXynZ
palju	doc_831529852295_item	3711123	et	0	cKUAfXynZ
erinevaid	doc_831529852295_item	3711124	et	0	cKUAfXynZ
situatsioone	doc_831529852295_item	3711125	et	0	cKUAfXynZ
kuna	doc_831529852295_item	3711126	et	0	cKUAfXynZ
tänapäeval	doc_831529852295_item	3711127	et	0	cKUAfXynZ
üha	doc_831529852295_item	3711128	et	0	cKUAfXynZ
rohkem	doc_831529852295_item	3711129	et	0	cKUAfXynZ
kasutatakse	doc_831529852295_item	3711130	et	0	cKUAfXynZ
telefoni	doc_831529852295_item	3711131	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3711132	et	0	cKUAfXynZ
lapsele	doc_831529852295_item	3711133	et	0	cKUAfXynZ
juba	doc_831529852295_item	3711134	et	0	cKUAfXynZ
varases	doc_831529852295_item	3711135	et	0	cKUAfXynZ
eas	doc_831529852295_item	3711136	et	0	cKUAfXynZ
tutvustada	doc_831529852295_item	3711137	et	0	cKUAfXynZ
telefoni	doc_831529852295_item	3711138	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711139	et	0	cKUAfXynZ
selle	doc_831529852295_item	3711140	et	0	cKUAfXynZ
kasutust	doc_831529852295_item	3711141	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3711142	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3711143	et	0	cKUAfXynZ
mängida	doc_831529852295_item	3711144	et	0	cKUAfXynZ
hambaarstile	doc_831529852295_item	3711145	et	0	cKUAfXynZ
helistamist	doc_831529852295_item	3711146	et	0	cKUAfXynZ
jäätise	doc_831529852295_item	3711147	et	0	cKUAfXynZ
tellimist	doc_831529852295_item	3711148	et	0	cKUAfXynZ
jne	doc_831529852295_item	3711149	et	0	cKUAfXynZ
samuti	doc_831529852295_item	3711150	et	0	cKUAfXynZ
nad	doc_831529852295_item	3711151	et	0	cKUAfXynZ
õppivad	doc_831529852295_item	3711152	et	0	cKUAfXynZ
kuidas	doc_831529852295_item	3711153	et	0	cKUAfXynZ
vastata	doc_831529852295_item	3711154	et	0	cKUAfXynZ
telefonikõnedele	doc_831529852295_item	3711155	et	0	cKUAfXynZ
erinevates	doc_831529852295_item	3711156	et	0	cKUAfXynZ
olukordades	doc_831529852295_item	3711157	et	0	cKUAfXynZ
on	doc_831529852295_item	3711158	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3711159	et	0	cKUAfXynZ
ka	doc_831529852295_item	3711160	et	0	cKUAfXynZ
märkida	doc_831529852295_item	3711161	et	0	cKUAfXynZ
ohutuse	doc_831529852295_item	3711162	et	0	cKUAfXynZ
seisukohalt	doc_831529852295_item	3711163	et	0	cKUAfXynZ
asju	doc_831529852295_item	3711164	et	0	cKUAfXynZ
näiteks	doc_831529852295_item	3711165	et	0	cKUAfXynZ
ei	doc_831529852295_item	3711166	et	0	cKUAfXynZ
tohi	doc_831529852295_item	3711167	et	0	cKUAfXynZ
öelda	doc_831529852295_item	3711168	et	0	cKUAfXynZ
et	doc_831529852295_item	3711169	et	0	cKUAfXynZ
ollakse	doc_831529852295_item	3711170	et	0	cKUAfXynZ
kodus	doc_831529852295_item	3711171	et	0	cKUAfXynZ
üksi	doc_831529852295_item	3711172	et	0	cKUAfXynZ
ei	doc_831529852295_item	3711173	et	0	cKUAfXynZ
tohi	doc_831529852295_item	3711174	et	0	cKUAfXynZ
informeerida	doc_831529852295_item	3711175	et	0	cKUAfXynZ
võõrast	doc_831529852295_item	3711176	et	0	cKUAfXynZ
vanemate	doc_831529852295_item	3711177	et	0	cKUAfXynZ
kohta	doc_831529852295_item	3711178	et	0	cKUAfXynZ
4	doc_831529852295_item	3711179	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3711180	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3711181	et	0	cKUAfXynZ
on	doc_831529852295_item	3711182	et	0	cKUAfXynZ
keelelise	doc_831529852295_item	3711183	et	0	cKUAfXynZ
suhtlemise	doc_831529852295_item	3711184	et	0	cKUAfXynZ
osaoskustest	doc_831529852295_item	3711185	et	0	cKUAfXynZ
raamatutes	doc_831529852295_item	3711186	et	0	cKUAfXynZ
ajakirjanduses	doc_831529852295_item	3711187	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711188	et	0	cKUAfXynZ
uurimistes	doc_831529852295_item	3711189	et	0	cKUAfXynZ
enam	doc_831529852295_item	3711190	et	0	cKUAfXynZ
kajastav	doc_831529852295_item	3711191	et	0	cKUAfXynZ
osaoskus	doc_831529852295_item	3711192	et	0	cKUAfXynZ
barrentine	doc_831529852295_item	3711193	et	0	cKUAfXynZ
1999	doc_831529852295_item	3711194	et	0	cKUAfXynZ
hancock	doc_831529852295_item	3711195	et	0	cKUAfXynZ
1999	doc_831529852295_item	3711196	et	0	cKUAfXynZ
willians	doc_831529852295_item	3711197	et	0	cKUAfXynZ
1999	doc_831529852295_item	3711198	et	0	cKUAfXynZ
strommen	doc_831529852295_item	3711199	et	0	cKUAfXynZ
mates	doc_831529852295_item	3711200	et	0	cKUAfXynZ
1997	doc_831529852295_item	3711201	et	0	cKUAfXynZ
rantanen	doc_831529852295_item	3711202	et	0	cKUAfXynZ
1996	doc_831529852295_item	3711203	et	0	cKUAfXynZ
uusen	doc_831529852295_item	3711204	et	0	cKUAfXynZ
2002	doc_831529852295_item	3711205	et	0	cKUAfXynZ
järgi	doc_831529852295_item	3711206	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3711207	et	0	cKUAfXynZ
annab	doc_831529852295_item	3711208	et	0	cKUAfXynZ
aluse	doc_831529852295_item	3711209	et	0	cKUAfXynZ
kirjutamisele	doc_831529852295_item	3711210	et	0	cKUAfXynZ
rääkimisele	doc_831529852295_item	3711211	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711212	et	0	cKUAfXynZ
kuulamisele	doc_831529852295_item	3711213	et	0	cKUAfXynZ
lugemisoskus	doc_831529852295_item	3711214	et	0	cKUAfXynZ
on	doc_831529852295_item	3711215	et	0	cKUAfXynZ
kompleksne	doc_831529852295_item	3711216	et	0	cKUAfXynZ
see	doc_831529852295_item	3711217	et	0	cKUAfXynZ
sõltub	doc_831529852295_item	3711218	et	0	cKUAfXynZ
kognitsioonist	doc_831529852295_item	3711219	et	0	cKUAfXynZ
motivatsioonist	doc_831529852295_item	3711220	et	0	cKUAfXynZ
visuaalsest	doc_831529852295_item	3711221	et	0	cKUAfXynZ
tajust	doc_831529852295_item	3711222	et	0	cKUAfXynZ
lugeja	doc_831529852295_item	3711223	et	0	cKUAfXynZ
minakontseptsioonist	doc_831529852295_item	3711224	et	0	cKUAfXynZ
loetavast	doc_831529852295_item	3711225	et	0	cKUAfXynZ
materjalist	doc_831529852295_item	3711226	et	0	cKUAfXynZ
ning	doc_831529852295_item	3711227	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3711228	et	0	cKUAfXynZ
efektiivsusest	doc_831529852295_item	3711229	et	0	cKUAfXynZ
lugemises	doc_831529852295_item	3711230	et	0	cKUAfXynZ
on	doc_831529852295_item	3711231	et	0	cKUAfXynZ
oluline	doc_831529852295_item	3711232	et	0	cKUAfXynZ
informatsiooni	doc_831529852295_item	3711233	et	0	cKUAfXynZ
vastuvõtt	doc_831529852295_item	3711234	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711235	et	0	cKUAfXynZ
loetust	doc_831529852295_item	3711236	et	0	cKUAfXynZ
arusaanime	doc_831529852295_item	3711237	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3711238	et	0	cKUAfXynZ
sõltub	doc_831529852295_item	3711239	et	0	cKUAfXynZ
sellest	doc_831529852295_item	3711240	et	0	cKUAfXynZ
kas	doc_831529852295_item	3711241	et	0	cKUAfXynZ
laps	doc_831529852295_item	3711242	et	0	cKUAfXynZ
oskab	doc_831529852295_item	3711243	et	0	cKUAfXynZ
lugeda	doc_831529852295_item	3711244	et	0	cKUAfXynZ
kas	doc_831529852295_item	3711245	et	0	cKUAfXynZ
ta	doc_831529852295_item	3711246	et	0	cKUAfXynZ
oskab	doc_831529852295_item	3711247	et	0	cKUAfXynZ
teha	doc_831529852295_item	3711248	et	0	cKUAfXynZ
vahet	doc_831529852295_item	3711249	et	0	cKUAfXynZ
suurtähtedest	doc_831529852295_item	3711250	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711251	et	0	cKUAfXynZ
väiketähtedest	doc_831529852295_item	3711252	et	0	cKUAfXynZ
kas	doc_831529852295_item	3711253	et	0	cKUAfXynZ
saab	doc_831529852295_item	3711254	et	0	cKUAfXynZ
aru	doc_831529852295_item	3711255	et	0	cKUAfXynZ
häälikute	doc_831529852295_item	3711256	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711257	et	0	cKUAfXynZ
tähtede	doc_831529852295_item	3711258	et	0	cKUAfXynZ
vastavust	doc_831529852295_item	3711259	et	0	cKUAfXynZ
lugemisel	doc_831529852295_item	3711260	et	0	cKUAfXynZ
on	doc_831529852295_item	3711261	et	0	cKUAfXynZ
oma	doc_831529852295_item	3711262	et	0	cKUAfXynZ
eesmärke	doc_831529852295_item	3711263	et	0	cKUAfXynZ
need	doc_831529852295_item	3711264	et	0	cKUAfXynZ
on	doc_831529852295_item	3711265	et	0	cKUAfXynZ
41	doc_831529852295_item	3711266	et	0	cKUAfXynZ
akadeemiline	doc_831529852295_item	3711267	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3711268	et	0	cKUAfXynZ
laps	doc_831529852295_item	3711269	et	0	cKUAfXynZ
õpib	doc_831529852295_item	3711270	et	0	cKUAfXynZ
punktuatsiooni	doc_831529852295_item	3711271	et	0	cKUAfXynZ
hääldust	doc_831529852295_item	3711272	et	0	cKUAfXynZ
käekirja	doc_831529852295_item	3711273	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711274	et	0	cKUAfXynZ
interpretatsiooni	doc_831529852295_item	3711275	et	0	cKUAfXynZ
see	doc_831529852295_item	3711276	et	0	cKUAfXynZ
võimaldab	doc_831529852295_item	3711277	et	0	cKUAfXynZ
saavutada	doc_831529852295_item	3711278	et	0	cKUAfXynZ
akadeemiline	doc_831529852295_item	3711279	et	0	cKUAfXynZ
tase	doc_831529852295_item	3711280	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3711281	et	0	cKUAfXynZ
nn	doc_831529852295_item	3711282	et	0	cKUAfXynZ
haritus	doc_831529852295_item	3711283	et	0	cKUAfXynZ
42	doc_831529852295_item	3711284	et	0	cKUAfXynZ
utilitaarne	doc_831529852295_item	3711285	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3711286	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3711287	et	0	cKUAfXynZ
aitab	doc_831529852295_item	3711288	et	0	cKUAfXynZ
õpilasel	doc_831529852295_item	3711289	et	0	cKUAfXynZ
funktsioneerida	doc_831529852295_item	3711290	et	0	cKUAfXynZ
ühiskonnas	doc_831529852295_item	3711291	et	0	cKUAfXynZ
43	doc_831529852295_item	3711292	et	0	cKUAfXynZ
romantiline	doc_831529852295_item	3711293	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3711294	et	0	cKUAfXynZ
see	doc_831529852295_item	3711295	et	0	cKUAfXynZ
arendab	doc_831529852295_item	3711296	et	0	cKUAfXynZ
lapsel	doc_831529852295_item	3711297	et	0	cKUAfXynZ
iseendast	doc_831529852295_item	3711298	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711299	et	0	cKUAfXynZ
teistest	doc_831529852295_item	3711300	et	0	cKUAfXynZ
arusaamisest	doc_831529852295_item	3711301	et	0	cKUAfXynZ
selleks	doc_831529852295_item	3711302	et	0	cKUAfXynZ
kasutatakse	doc_831529852295_item	3711303	et	0	cKUAfXynZ
lugemisprogrammi	doc_831529852295_item	3711304	et	0	cKUAfXynZ
kus	doc_831529852295_item	3711305	et	0	cKUAfXynZ
rõhutatakse	doc_831529852295_item	3711306	et	0	cKUAfXynZ
keelekogemust	doc_831529852295_item	3711307	et	0	cKUAfXynZ
kirjanduse	doc_831529852295_item	3711308	et	0	cKUAfXynZ
väärtustamist	doc_831529852295_item	3711309	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711310	et	0	cKUAfXynZ
väärtushinnanguid	doc_831529852295_item	3711311	et	0	cKUAfXynZ
44	doc_831529852295_item	3711312	et	0	cKUAfXynZ
kognetiivse	doc_831529852295_item	3711313	et	0	cKUAfXynZ
arengu	doc_831529852295_item	3711314	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3711315	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3711316	et	0	cKUAfXynZ
annab	doc_831529852295_item	3711317	et	0	cKUAfXynZ
õpilasele	doc_831529852295_item	3711318	et	0	cKUAfXynZ
võimalust	doc_831529852295_item	3711319	et	0	cKUAfXynZ
areneda	doc_831529852295_item	3711320	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711321	et	0	cKUAfXynZ
osaleda	doc_831529852295_item	3711322	et	0	cKUAfXynZ
ühiskonna	doc_831529852295_item	3711323	et	0	cKUAfXynZ
arengus	doc_831529852295_item	3711324	et	0	cKUAfXynZ
see	doc_831529852295_item	3711325	et	0	cKUAfXynZ
läheb	doc_831529852295_item	3711326	et	0	cKUAfXynZ
kasuks	doc_831529852295_item	3711327	et	0	cKUAfXynZ
uute	doc_831529852295_item	3711328	et	0	cKUAfXynZ
probleemide	doc_831529852295_item	3711329	et	0	cKUAfXynZ
lahendamisel	doc_831529852295_item	3711330	et	0	cKUAfXynZ
45	doc_831529852295_item	3711331	et	0	cKUAfXynZ
võrdõiguslik	doc_831529852295_item	3711332	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3711333	et	0	cKUAfXynZ
selle	doc_831529852295_item	3711334	et	0	cKUAfXynZ
saavutamiseks	doc_831529852295_item	3711335	et	0	cKUAfXynZ
peavad	doc_831529852295_item	3711336	et	0	cKUAfXynZ
õpilased	doc_831529852295_item	3711337	et	0	cKUAfXynZ
olema	doc_831529852295_item	3711338	et	0	cKUAfXynZ
kindlustatud	doc_831529852295_item	3711339	et	0	cKUAfXynZ
programmiga	doc_831529852295_item	3711340	et	0	cKUAfXynZ
mis	doc_831529852295_item	3711341	et	0	cKUAfXynZ
välistab	doc_831529852295_item	3711342	et	0	cKUAfXynZ
sotsiaalmajandusliku	doc_831529852295_item	3711343	et	0	cKUAfXynZ
diskrimineerimise	doc_831529852295_item	3711344	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711345	et	0	cKUAfXynZ
mis	doc_831529852295_item	3711346	et	0	cKUAfXynZ
on	doc_831529852295_item	3711347	et	0	cKUAfXynZ
kooskõlas	doc_831529852295_item	3711348	et	0	cKUAfXynZ
lugemise	doc_831529852295_item	3711349	et	0	cKUAfXynZ
romantilise	doc_831529852295_item	3711350	et	0	cKUAfXynZ
eesmärgiga	doc_831529852295_item	3711351	et	0	cKUAfXynZ
sarmavuori	doc_831529852295_item	3711352	et	0	cKUAfXynZ
1993	doc_831529852295_item	3711353	et	0	cKUAfXynZ
donoghue	doc_831529852295_item	3711354	et	0	cKUAfXynZ
1991	doc_831529852295_item	3711355	et	0	cKUAfXynZ
jansen	doc_831529852295_item	3711356	et	0	cKUAfXynZ
jacobsen	doc_831529852295_item	3711357	et	0	cKUAfXynZ
jensen	doc_831529852295_item	3711358	et	0	cKUAfXynZ
1978	doc_831529852295_item	3711359	et	0	cKUAfXynZ
viidatud	doc_831529852295_item	3711360	et	0	cKUAfXynZ
uusen	doc_831529852295_item	3711361	et	0	cKUAfXynZ
2002	doc_831529852295_item	3711362	et	0	cKUAfXynZ
järgi	doc_831529852295_item	3711363	et	0	cKUAfXynZ
õpilasi	doc_831529852295_item	3711364	et	0	cKUAfXynZ
peab	doc_831529852295_item	3711365	et	0	cKUAfXynZ
õpetama	doc_831529852295_item	3711366	et	0	cKUAfXynZ
lugemisele	doc_831529852295_item	3711367	et	0	cKUAfXynZ
vastavalt	doc_831529852295_item	3711368	et	0	cKUAfXynZ
nende	doc_831529852295_item	3711369	et	0	cKUAfXynZ
individuaalsele	doc_831529852295_item	3711370	et	0	cKUAfXynZ
tasandile	doc_831529852295_item	3711371	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3711372	et	0	cKUAfXynZ
peab	doc_831529852295_item	3711373	et	0	cKUAfXynZ
sellega	doc_831529852295_item	3711374	et	0	cKUAfXynZ
arvestama	doc_831529852295_item	3711375	et	0	cKUAfXynZ
tundi	doc_831529852295_item	3711376	et	0	cKUAfXynZ
planeerimisel	doc_831529852295_item	3711377	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3711378	et	0	cKUAfXynZ
pöörata	doc_831529852295_item	3711379	et	0	cKUAfXynZ
tähelepanu	doc_831529852295_item	3711380	et	0	cKUAfXynZ
lugemikule	doc_831529852295_item	3711381	et	0	cKUAfXynZ
see	doc_831529852295_item	3711382	et	0	cKUAfXynZ
peab	doc_831529852295_item	3711383	et	0	cKUAfXynZ
arendama	doc_831529852295_item	3711384	et	0	cKUAfXynZ
lapse	doc_831529852295_item	3711385	et	0	cKUAfXynZ
sõnavara	doc_831529852295_item	3711386	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711387	et	0	cKUAfXynZ
seletama	doc_831529852295_item	3711388	et	0	cKUAfXynZ
mida	doc_831529852295_item	3711389	et	0	cKUAfXynZ
see	doc_831529852295_item	3711390	et	0	cKUAfXynZ
sõna	doc_831529852295_item	3711391	et	0	cKUAfXynZ
kontekstis	doc_831529852295_item	3711392	et	0	cKUAfXynZ
tähendab	doc_831529852295_item	3711393	et	0	cKUAfXynZ
lapsel	doc_831529852295_item	3711394	et	0	cKUAfXynZ
peab	doc_831529852295_item	3711395	et	0	cKUAfXynZ
olema	doc_831529852295_item	3711396	et	0	cKUAfXynZ
motivatsioon	doc_831529852295_item	3711397	et	0	cKUAfXynZ
lugeda	doc_831529852295_item	3711398	et	0	cKUAfXynZ
hästi	doc_831529852295_item	3711399	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3711400	et	0	cKUAfXynZ
kui	doc_831529852295_item	3711401	et	0	cKUAfXynZ
loetud	doc_831529852295_item	3711402	et	0	cKUAfXynZ
seostataks	doc_831529852295_item	3711403	et	0	cKUAfXynZ
lapse	doc_831529852295_item	3711404	et	0	cKUAfXynZ
kogemuse	doc_831529852295_item	3711405	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711406	et	0	cKUAfXynZ
taustaga	doc_831529852295_item	3711407	et	0	cKUAfXynZ
oskuste	doc_831529852295_item	3711408	et	0	cKUAfXynZ
praktiseerimine	doc_831529852295_item	3711409	et	0	cKUAfXynZ
on	doc_831529852295_item	3711410	et	0	cKUAfXynZ
lugemise	doc_831529852295_item	3711411	et	0	cKUAfXynZ
lahutamatu	doc_831529852295_item	3711412	et	0	cKUAfXynZ
osa	doc_831529852295_item	3711413	et	0	cKUAfXynZ
hästi	doc_831529852295_item	3711414	et	0	cKUAfXynZ
on	doc_831529852295_item	3711415	et	0	cKUAfXynZ
kui	doc_831529852295_item	3711416	et	0	cKUAfXynZ
laps	doc_831529852295_item	3711417	et	0	cKUAfXynZ
saab	doc_831529852295_item	3711418	et	0	cKUAfXynZ
oma	doc_831529852295_item	3711419	et	0	cKUAfXynZ
oskuste	doc_831529852295_item	3711420	et	0	cKUAfXynZ
praktiseerida	doc_831529852295_item	3711421	et	0	cKUAfXynZ
tavaliselt	doc_831529852295_item	3711422	et	0	cKUAfXynZ
see	doc_831529852295_item	3711423	et	0	cKUAfXynZ
toimub	doc_831529852295_item	3711424	et	0	cKUAfXynZ
tööraamatu	doc_831529852295_item	3711425	et	0	cKUAfXynZ
kirjaliku	doc_831529852295_item	3711426	et	0	cKUAfXynZ
loomingulise	doc_831529852295_item	3711427	et	0	cKUAfXynZ
ülesande	doc_831529852295_item	3711428	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3711429	et	0	cKUAfXynZ
rääkimise	doc_831529852295_item	3711430	et	0	cKUAfXynZ
kaudu	doc_831529852295_item	3711431	et	0	cKUAfXynZ
on	doc_831529852295_item	3711432	et	0	cKUAfXynZ
loogiline	doc_831529852295_item	3711433	et	0	cKUAfXynZ
et	doc_831529852295_item	3711434	et	0	cKUAfXynZ
lugemise	doc_831529852295_item	3711435	et	0	cKUAfXynZ
käigus	doc_831529852295_item	3711436	et	0	cKUAfXynZ
lapsel	doc_831529852295_item	3711437	et	0	cKUAfXynZ
tekivad	doc_831529852295_item	3711438	et	0	cKUAfXynZ
erinevad	doc_831529852295_item	3711439	et	0	cKUAfXynZ
küsimused	doc_831529852295_item	3711440	et	0	cKUAfXynZ
asjade	doc_831529852295_item	3711441	et	0	cKUAfXynZ
kohta	doc_831529852295_item	3711442	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3711443	et	0	cKUAfXynZ
eesmärgiks	doc_831529852295_item	3711444	et	0	cKUAfXynZ
on	doc_831529852295_item	3711445	et	0	cKUAfXynZ
nendele	doc_831529852295_item	3711446	et	0	cKUAfXynZ
küsimustele	doc_831529852295_item	3711447	et	0	cKUAfXynZ
vastata	doc_831529852295_item	3711448	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711449	et	0	cKUAfXynZ
esitada	doc_831529852295_item	3711450	et	0	cKUAfXynZ
lastele	doc_831529852295_item	3711451	et	0	cKUAfXynZ
küsimusi	doc_831529852295_item	3711452	et	0	cKUAfXynZ
ka	doc_831529852295_item	3711453	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3711454	et	0	cKUAfXynZ
küsimused	doc_831529852295_item	3711455	et	0	cKUAfXynZ
peavad	doc_831529852295_item	3711456	et	0	cKUAfXynZ
olema	doc_831529852295_item	3711457	et	0	cKUAfXynZ
sellised	doc_831529852295_item	3711458	et	0	cKUAfXynZ
mis	doc_831529852295_item	3711459	et	0	cKUAfXynZ
nõuavad	doc_831529852295_item	3711460	et	0	cKUAfXynZ
kõrgemat	doc_831529852295_item	3711461	et	0	cKUAfXynZ
mõtlemist	doc_831529852295_item	3711462	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711463	et	0	cKUAfXynZ
suurendavad	doc_831529852295_item	3711464	et	0	cKUAfXynZ
arusaamisoskust	doc_831529852295_item	3711465	et	0	cKUAfXynZ
on	doc_831529852295_item	3711466	et	0	cKUAfXynZ
oluline	doc_831529852295_item	3711467	et	0	cKUAfXynZ
et	doc_831529852295_item	3711468	et	0	cKUAfXynZ
lapsel	doc_831529852295_item	3711469	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3711470	et	0	cKUAfXynZ
tagasiside	doc_831529852295_item	3711471	et	0	cKUAfXynZ
läheb	doc_831529852295_item	3711472	et	0	cKUAfXynZ
kasuks	doc_831529852295_item	3711473	et	0	cKUAfXynZ
kui	doc_831529852295_item	3711474	et	0	cKUAfXynZ
lugemisega	doc_831529852295_item	3711475	et	0	cKUAfXynZ
seotud	doc_831529852295_item	3711476	et	0	cKUAfXynZ
tegevusi	doc_831529852295_item	3711477	et	0	cKUAfXynZ
jagatakse	doc_831529852295_item	3711478	et	0	cKUAfXynZ
kaheks	doc_831529852295_item	3711479	et	0	cKUAfXynZ
kategooriaks	doc_831529852295_item	3711480	et	0	cKUAfXynZ
enne	doc_831529852295_item	3711481	et	0	cKUAfXynZ
lugemist	doc_831529852295_item	3711482	et	0	cKUAfXynZ
lugemise	doc_831529852295_item	3711483	et	0	cKUAfXynZ
ajal	doc_831529852295_item	3711484	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711485	et	0	cKUAfXynZ
pärast	doc_831529852295_item	3711486	et	0	cKUAfXynZ
lugemist	doc_831529852295_item	3711487	et	0	cKUAfXynZ
see	doc_831529852295_item	3711488	et	0	cKUAfXynZ
mis	doc_831529852295_item	3711489	et	0	cKUAfXynZ
on	doc_831529852295_item	3711490	et	0	cKUAfXynZ
enne	doc_831529852295_item	3711491	et	0	cKUAfXynZ
lugemist	doc_831529852295_item	3711492	et	0	cKUAfXynZ
on	doc_831529852295_item	3711493	et	0	cKUAfXynZ
sissejuhatav	doc_831529852295_item	3711494	et	0	cKUAfXynZ
osa	doc_831529852295_item	3711495	et	0	cKUAfXynZ
tegevusi	doc_831529852295_item	3711496	et	0	cKUAfXynZ
mis	doc_831529852295_item	3711497	et	0	cKUAfXynZ
toimub	doc_831529852295_item	3711498	et	0	cKUAfXynZ
pärast	doc_831529852295_item	3711499	et	0	cKUAfXynZ
lugemist	doc_831529852295_item	3711500	et	0	cKUAfXynZ
on	doc_831529852295_item	3711501	et	0	cKUAfXynZ
nagu	doc_831529852295_item	3711502	et	0	cKUAfXynZ
tulemused	doc_831529852295_item	3711503	et	0	cKUAfXynZ
need	doc_831529852295_item	3711504	et	0	cKUAfXynZ
näidavad	doc_831529852295_item	3711505	et	0	cKUAfXynZ
mida	doc_831529852295_item	3711506	et	0	cKUAfXynZ
uut	doc_831529852295_item	3711507	et	0	cKUAfXynZ
sai	doc_831529852295_item	3711508	et	0	cKUAfXynZ
õpilane	doc_831529852295_item	3711509	et	0	cKUAfXynZ
teada	doc_831529852295_item	3711510	et	0	cKUAfXynZ
arvatakse	doc_831529852295_item	3711511	et	0	cKUAfXynZ
et	doc_831529852295_item	3711512	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3711513	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711514	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3711515	et	0	cKUAfXynZ
on	doc_831529852295_item	3711516	et	0	cKUAfXynZ
seotud	doc_831529852295_item	3711517	et	0	cKUAfXynZ
selle	doc_831529852295_item	3711518	et	0	cKUAfXynZ
kohta	doc_831529852295_item	3711519	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3711520	et	0	cKUAfXynZ
kirjutatakse	doc_831529852295_item	3711521	et	0	cKUAfXynZ
et	doc_831529852295_item	3711522	et	0	cKUAfXynZ
seda	doc_831529852295_item	3711523	et	0	cKUAfXynZ
võib	doc_831529852295_item	3711524	et	0	cKUAfXynZ
ka	doc_831529852295_item	3711525	et	0	cKUAfXynZ
rakendada	doc_831529852295_item	3711526	et	0	cKUAfXynZ
praktikas	doc_831529852295_item	3711527	et	0	cKUAfXynZ
selleks	doc_831529852295_item	3711528	et	0	cKUAfXynZ
on	doc_831529852295_item	3711529	et	0	cKUAfXynZ
olemas	doc_831529852295_item	3711530	et	0	cKUAfXynZ
keelekogemuslik	doc_831529852295_item	3711531	et	0	cKUAfXynZ
lähenemine	doc_831529852295_item	3711532	et	0	cKUAfXynZ
kasutades	doc_831529852295_item	3711533	et	0	cKUAfXynZ
oma	doc_831529852295_item	3711534	et	0	cKUAfXynZ
kogemust	doc_831529852295_item	3711535	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3711536	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3711537	et	0	cKUAfXynZ
proovida	doc_831529852295_item	3711538	et	0	cKUAfXynZ
ette	doc_831529852295_item	3711539	et	0	cKUAfXynZ
kujutada	doc_831529852295_item	3711540	et	0	cKUAfXynZ
mis	doc_831529852295_item	3711541	et	0	cKUAfXynZ
juhtub	doc_831529852295_item	3711542	et	0	cKUAfXynZ
raamatu	doc_831529852295_item	3711543	et	0	cKUAfXynZ
tegelastega	doc_831529852295_item	3711544	et	0	cKUAfXynZ
järgmises	doc_831529852295_item	3711545	et	0	cKUAfXynZ
tekstiosas	doc_831529852295_item	3711546	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711547	et	0	cKUAfXynZ
sellest	doc_831529852295_item	3711548	et	0	cKUAfXynZ
kirjutada	doc_831529852295_item	3711549	et	0	cKUAfXynZ
pärast	doc_831529852295_item	3711550	et	0	cKUAfXynZ
õpilased	doc_831529852295_item	3711551	et	0	cKUAfXynZ
esitavad	doc_831529852295_item	3711552	et	0	cKUAfXynZ
mida	doc_831529852295_item	3711553	et	0	cKUAfXynZ
nad	doc_831529852295_item	3711554	et	0	cKUAfXynZ
kirjutasid	doc_831529852295_item	3711555	et	0	cKUAfXynZ
klassi	doc_831529852295_item	3711556	et	0	cKUAfXynZ
ette	doc_831529852295_item	3711557	et	0	cKUAfXynZ
see	doc_831529852295_item	3711558	et	0	cKUAfXynZ
näitab	doc_831529852295_item	3711559	et	0	cKUAfXynZ
et	doc_831529852295_item	3711560	et	0	cKUAfXynZ
laps	doc_831529852295_item	3711561	et	0	cKUAfXynZ
oskab	doc_831529852295_item	3711562	et	0	cKUAfXynZ
mõelda	doc_831529852295_item	3711563	et	0	cKUAfXynZ
sellest	doc_831529852295_item	3711564	et	0	cKUAfXynZ
mida	doc_831529852295_item	3711565	et	0	cKUAfXynZ
ta	doc_831529852295_item	3711566	et	0	cKUAfXynZ
oli	doc_831529852295_item	3711567	et	0	cKUAfXynZ
lugenud	doc_831529852295_item	3711568	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711569	et	0	cKUAfXynZ
kogenud	doc_831529852295_item	3711570	et	0	cKUAfXynZ
selline	doc_831529852295_item	3711571	et	0	cKUAfXynZ
meetod	doc_831529852295_item	3711572	et	0	cKUAfXynZ
rõhutab	doc_831529852295_item	3711573	et	0	cKUAfXynZ
et	doc_831529852295_item	3711574	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3711575	et	0	cKUAfXynZ
on	doc_831529852295_item	3711576	et	0	cKUAfXynZ
osa	doc_831529852295_item	3711577	et	0	cKUAfXynZ
kommunikatsioonist	doc_831529852295_item	3711578	et	0	cKUAfXynZ
või	doc_831529852295_item	3711579	et	0	cKUAfXynZ
keeleprotsessist	doc_831529852295_item	3711580	et	0	cKUAfXynZ
aga	doc_831529852295_item	3711581	et	0	cKUAfXynZ
keelekogemuslikul	doc_831529852295_item	3711582	et	0	cKUAfXynZ
lähenemisel	doc_831529852295_item	3711583	et	0	cKUAfXynZ
on	doc_831529852295_item	3711584	et	0	cKUAfXynZ
olemas	doc_831529852295_item	3711585	et	0	cKUAfXynZ
ka	doc_831529852295_item	3711586	et	0	cKUAfXynZ
miinuseid	doc_831529852295_item	3711587	et	0	cKUAfXynZ
miinuseks	doc_831529852295_item	3711588	et	0	cKUAfXynZ
on	doc_831529852295_item	3711589	et	0	cKUAfXynZ
sõnavara	doc_831529852295_item	3711590	et	0	cKUAfXynZ
piiratus	doc_831529852295_item	3711591	et	0	cKUAfXynZ
kui	doc_831529852295_item	3711592	et	0	cKUAfXynZ
laps	doc_831529852295_item	3711593	et	0	cKUAfXynZ
jutustab	doc_831529852295_item	3711594	et	0	cKUAfXynZ
oma	doc_831529852295_item	3711595	et	0	cKUAfXynZ
sõnadega	doc_831529852295_item	3711596	et	0	cKUAfXynZ
ta	doc_831529852295_item	3711597	et	0	cKUAfXynZ
ei	doc_831529852295_item	3711598	et	0	cKUAfXynZ
rikasta	doc_831529852295_item	3711599	et	0	cKUAfXynZ
oma	doc_831529852295_item	3711600	et	0	cKUAfXynZ
keelt	doc_831529852295_item	3711601	et	0	cKUAfXynZ
peale	doc_831529852295_item	3711602	et	0	cKUAfXynZ
seda	doc_831529852295_item	3711603	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3711604	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3711605	et	0	cKUAfXynZ
tüdida	doc_831529852295_item	3711606	et	0	cKUAfXynZ
pidevast	doc_831529852295_item	3711607	et	0	cKUAfXynZ
ühe	doc_831529852295_item	3711608	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711609	et	0	cKUAfXynZ
sama	doc_831529852295_item	3711610	et	0	cKUAfXynZ
loo	doc_831529852295_item	3711611	et	0	cKUAfXynZ
siis	doc_831529852295_item	3711612	et	0	cKUAfXynZ
ettekujutuseoskus	doc_831529852295_item	3711613	et	0	cKUAfXynZ
ei	doc_831529852295_item	3711614	et	0	cKUAfXynZ
saa	doc_831529852295_item	3711615	et	0	cKUAfXynZ
arendada	doc_831529852295_item	3711616	et	0	cKUAfXynZ
ka	doc_831529852295_item	3711617	et	0	cKUAfXynZ
ühesõnaga	doc_831529852295_item	3711618	et	0	cKUAfXynZ
selline	doc_831529852295_item	3711619	et	0	cKUAfXynZ
meetod	doc_831529852295_item	3711620	et	0	cKUAfXynZ
on	doc_831529852295_item	3711621	et	0	cKUAfXynZ
olemas	doc_831529852295_item	3711622	et	0	cKUAfXynZ
aga	doc_831529852295_item	3711623	et	0	cKUAfXynZ
ei	doc_831529852295_item	3711624	et	0	cKUAfXynZ
ole	doc_831529852295_item	3711625	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3711626	et	0	cKUAfXynZ
sellega	doc_831529852295_item	3711627	et	0	cKUAfXynZ
kuritarvitada	doc_831529852295_item	3711628	et	0	cKUAfXynZ
46	doc_831529852295_item	3711629	et	0	cKUAfXynZ
lugemisprogramm	doc_831529852295_item	3711630	et	0	cKUAfXynZ
selle	doc_831529852295_item	3711631	et	0	cKUAfXynZ
lähenemise	doc_831529852295_item	3711632	et	0	cKUAfXynZ
pooldajate	doc_831529852295_item	3711633	et	0	cKUAfXynZ
põhiargumendiks	doc_831529852295_item	3711634	et	0	cKUAfXynZ
on	doc_831529852295_item	3711635	et	0	cKUAfXynZ
et	doc_831529852295_item	3711636	et	0	cKUAfXynZ
kui	doc_831529852295_item	3711637	et	0	cKUAfXynZ
emakeele	doc_831529852295_item	3711638	et	0	cKUAfXynZ
õpetamise	doc_831529852295_item	3711639	et	0	cKUAfXynZ
lõppeesmärgiks	doc_831529852295_item	3711640	et	0	cKUAfXynZ
on	doc_831529852295_item	3711641	et	0	cKUAfXynZ
mõtlev	doc_831529852295_item	3711642	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711643	et	0	cKUAfXynZ
kirjaoskaja	doc_831529852295_item	3711644	et	0	cKUAfXynZ
ühiskond	doc_831529852295_item	3711645	et	0	cKUAfXynZ
siis	doc_831529852295_item	3711646	et	0	cKUAfXynZ
on	doc_831529852295_item	3711647	et	0	cKUAfXynZ
kõige	doc_831529852295_item	3711648	et	0	cKUAfXynZ
mõttekam	doc_831529852295_item	3711649	et	0	cKUAfXynZ
kohe	doc_831529852295_item	3711650	et	0	cKUAfXynZ
alguses	doc_831529852295_item	3711651	et	0	cKUAfXynZ
alustada	doc_831529852295_item	3711652	et	0	cKUAfXynZ
kokkupuuteid	doc_831529852295_item	3711653	et	0	cKUAfXynZ
kõige	doc_831529852295_item	3711654	et	0	cKUAfXynZ
efektiivsema	doc_831529852295_item	3711655	et	0	cKUAfXynZ
inimliku	doc_831529852295_item	3711656	et	0	cKUAfXynZ
väljendusvormiga	doc_831529852295_item	3711657	et	0	cKUAfXynZ
kirjandusega	doc_831529852295_item	3711658	et	0	cKUAfXynZ
anne	doc_831529852295_item	3711659	et	0	cKUAfXynZ
uusen	doc_831529852295_item	3711660	et	0	cKUAfXynZ
2002	doc_831529852295_item	3711661	et	0	cKUAfXynZ
lugemisprogrammi	doc_831529852295_item	3711662	et	0	cKUAfXynZ
eesmärgiks	doc_831529852295_item	3711663	et	0	cKUAfXynZ
on	doc_831529852295_item	3711664	et	0	cKUAfXynZ
arendada	doc_831529852295_item	3711665	et	0	cKUAfXynZ
laste	doc_831529852295_item	3711666	et	0	cKUAfXynZ
huvi	doc_831529852295_item	3711667	et	0	cKUAfXynZ
loetava	doc_831529852295_item	3711668	et	0	cKUAfXynZ
kirjanduse	doc_831529852295_item	3711669	et	0	cKUAfXynZ
vastu	doc_831529852295_item	3711670	et	0	cKUAfXynZ
lugemisprogramm	doc_831529852295_item	3711671	et	0	cKUAfXynZ
peab	doc_831529852295_item	3711672	et	0	cKUAfXynZ
olema	doc_831529852295_item	3711673	et	0	cKUAfXynZ
balansseeritud	doc_831529852295_item	3711674	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711675	et	0	cKUAfXynZ
koosnema	doc_831529852295_item	3711676	et	0	cKUAfXynZ
raamatutest	doc_831529852295_item	3711677	et	0	cKUAfXynZ
mis	doc_831529852295_item	3711678	et	0	cKUAfXynZ
on	doc_831529852295_item	3711679	et	0	cKUAfXynZ
erinevates	doc_831529852295_item	3711680	et	0	cKUAfXynZ
žanrides	doc_831529852295_item	3711681	et	0	cKUAfXynZ
lugemise	doc_831529852295_item	3711682	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3711683	et	0	cKUAfXynZ
on	doc_831529852295_item	3711684	et	0	cKUAfXynZ
olulised	doc_831529852295_item	3711685	et	0	cKUAfXynZ
tekstiga	doc_831529852295_item	3711686	et	0	cKUAfXynZ
töötamise	doc_831529852295_item	3711687	et	0	cKUAfXynZ
strateegiad	doc_831529852295_item	3711688	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3711689	et	0	cKUAfXynZ
kasulik	doc_831529852295_item	3711690	et	0	cKUAfXynZ
koostada	doc_831529852295_item	3711691	et	0	cKUAfXynZ
arutlusplaani	doc_831529852295_item	3711692	et	0	cKUAfXynZ
mõisteseletuse	doc_831529852295_item	3711693	et	0	cKUAfXynZ
skeeme	doc_831529852295_item	3711694	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711695	et	0	cKUAfXynZ
kirjutada	doc_831529852295_item	3711696	et	0	cKUAfXynZ
välja	doc_831529852295_item	3711697	et	0	cKUAfXynZ
võtmesõnu	doc_831529852295_item	3711698	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3711699	et	0	cKUAfXynZ
võib	doc_831529852295_item	3711700	et	0	cKUAfXynZ
seletada	doc_831529852295_item	3711701	et	0	cKUAfXynZ
lastele	doc_831529852295_item	3711702	et	0	cKUAfXynZ
uusi	doc_831529852295_item	3711703	et	0	cKUAfXynZ
sõnu	doc_831529852295_item	3711704	et	0	cKUAfXynZ
märgistada	doc_831529852295_item	3711705	et	0	cKUAfXynZ
kokkulepitud	doc_831529852295_item	3711706	et	0	cKUAfXynZ
märkidega	doc_831529852295_item	3711707	et	0	cKUAfXynZ
õigesti	doc_831529852295_item	3711708	et	0	cKUAfXynZ
teatud	doc_831529852295_item	3711709	et	0	cKUAfXynZ
asjad	doc_831529852295_item	3711710	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711711	et	0	cKUAfXynZ
valesti	doc_831529852295_item	3711712	et	0	cKUAfXynZ
teatud	doc_831529852295_item	3711713	et	0	cKUAfXynZ
asjad	doc_831529852295_item	3711714	et	0	cKUAfXynZ
kui	doc_831529852295_item	3711715	et	0	cKUAfXynZ
rääkida	doc_831529852295_item	3711716	et	0	cKUAfXynZ
arutlusplaani	doc_831529852295_item	3711717	et	0	cKUAfXynZ
kohta	doc_831529852295_item	3711718	et	0	cKUAfXynZ
see	doc_831529852295_item	3711719	et	0	cKUAfXynZ
võib	doc_831529852295_item	3711720	et	0	cKUAfXynZ
olla	doc_831529852295_item	3711721	et	0	cKUAfXynZ
mingi	doc_831529852295_item	3711722	et	0	cKUAfXynZ
paariline	doc_831529852295_item	3711723	et	0	cKUAfXynZ
tabel	doc_831529852295_item	3711724	et	0	cKUAfXynZ
ühel	doc_831529852295_item	3711725	et	0	cKUAfXynZ
neist	doc_831529852295_item	3711726	et	0	cKUAfXynZ
võib	doc_831529852295_item	3711727	et	0	cKUAfXynZ
väljendada	doc_831529852295_item	3711728	et	0	cKUAfXynZ
oma	doc_831529852295_item	3711729	et	0	cKUAfXynZ
positsiooni	doc_831529852295_item	3711730	et	0	cKUAfXynZ
teistel	doc_831529852295_item	3711731	et	0	cKUAfXynZ
kirjutada	doc_831529852295_item	3711732	et	0	cKUAfXynZ
millest	doc_831529852295_item	3711733	et	0	cKUAfXynZ
oli	doc_831529852295_item	3711734	et	0	cKUAfXynZ
tekstis	doc_831529852295_item	3711735	et	0	cKUAfXynZ
kirjutatud	doc_831529852295_item	3711736	et	0	cKUAfXynZ
pärast	doc_831529852295_item	3711737	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3711738	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3711739	et	0	cKUAfXynZ
üksteisele	doc_831529852295_item	3711740	et	0	cKUAfXynZ
lugeda	doc_831529852295_item	3711741	et	0	cKUAfXynZ
mida	doc_831529852295_item	3711742	et	0	cKUAfXynZ
nad	doc_831529852295_item	3711743	et	0	cKUAfXynZ
kirjutasid	doc_831529852295_item	3711744	et	0	cKUAfXynZ
kui	doc_831529852295_item	3711745	et	0	cKUAfXynZ
tekkib	doc_831529852295_item	3711746	et	0	cKUAfXynZ
diskussioon	doc_831529852295_item	3711747	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3711748	et	0	cKUAfXynZ
peab	doc_831529852295_item	3711749	et	0	cKUAfXynZ
diskussiooni	doc_831529852295_item	3711750	et	0	cKUAfXynZ
juhendama	doc_831529852295_item	3711751	et	0	cKUAfXynZ
niimoodi	doc_831529852295_item	3711752	et	0	cKUAfXynZ
et	doc_831529852295_item	3711753	et	0	cKUAfXynZ
selguksid	doc_831529852295_item	3711754	et	0	cKUAfXynZ
õiged	doc_831529852295_item	3711755	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711756	et	0	cKUAfXynZ
valed	doc_831529852295_item	3711757	et	0	cKUAfXynZ
vaatenurgad	doc_831529852295_item	3711758	et	0	cKUAfXynZ
on	doc_831529852295_item	3711759	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3711760	et	0	cKUAfXynZ
ka	doc_831529852295_item	3711761	et	0	cKUAfXynZ
et	doc_831529852295_item	3711762	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3711763	et	0	cKUAfXynZ
osaks	doc_831529852295_item	3711764	et	0	cKUAfXynZ
õigesti	doc_831529852295_item	3711765	et	0	cKUAfXynZ
seletada	doc_831529852295_item	3711766	et	0	cKUAfXynZ
tuua	doc_831529852295_item	3711767	et	0	cKUAfXynZ
fakti	doc_831529852295_item	3711768	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711769	et	0	cKUAfXynZ
argumente	doc_831529852295_item	3711770	et	0	cKUAfXynZ
on	doc_831529852295_item	3711771	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3711772	et	0	cKUAfXynZ
et	doc_831529852295_item	3711773	et	0	cKUAfXynZ
õpilastel	doc_831529852295_item	3711774	et	0	cKUAfXynZ
ei	doc_831529852295_item	3711775	et	0	cKUAfXynZ
jääks	doc_831529852295_item	3711776	et	0	cKUAfXynZ
väärarusammu	doc_831529852295_item	3711777	et	0	cKUAfXynZ
mõisteseletuse	doc_831529852295_item	3711778	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3711779	et	0	cKUAfXynZ
on	doc_831529852295_item	3711780	et	0	cKUAfXynZ
oluline	doc_831529852295_item	3711781	et	0	cKUAfXynZ
et	doc_831529852295_item	3711782	et	0	cKUAfXynZ
laps	doc_831529852295_item	3711783	et	0	cKUAfXynZ
saaks	doc_831529852295_item	3711784	et	0	cKUAfXynZ
leida	doc_831529852295_item	3711785	et	0	cKUAfXynZ
igasugust	doc_831529852295_item	3711786	et	0	cKUAfXynZ
informatsiooni	doc_831529852295_item	3711787	et	0	cKUAfXynZ
vormistus	doc_831529852295_item	3711788	et	0	cKUAfXynZ
pole	doc_831529852295_item	3711789	et	0	cKUAfXynZ
siin	doc_831529852295_item	3711790	et	0	cKUAfXynZ
oluline	doc_831529852295_item	3711791	et	0	cKUAfXynZ
võtmesõnu	doc_831529852295_item	3711792	et	0	cKUAfXynZ
leitakse	doc_831529852295_item	3711793	et	0	cKUAfXynZ
tekstilõigus	doc_831529852295_item	3711794	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711795	et	0	cKUAfXynZ
nende	doc_831529852295_item	3711796	et	0	cKUAfXynZ
juurde	doc_831529852295_item	3711797	et	0	cKUAfXynZ
kirjutatakse	doc_831529852295_item	3711798	et	0	cKUAfXynZ
olulisi	doc_831529852295_item	3711799	et	0	cKUAfXynZ
sõnu	doc_831529852295_item	3711800	et	0	cKUAfXynZ
võtmesõnu	doc_831529852295_item	3711801	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3711802	et	0	cKUAfXynZ
kirjutada	doc_831529852295_item	3711803	et	0	cKUAfXynZ
eraldi	doc_831529852295_item	3711804	et	0	cKUAfXynZ
sedelitele	doc_831529852295_item	3711805	et	0	cKUAfXynZ
iga	doc_831529852295_item	3711806	et	0	cKUAfXynZ
võtmesõna	doc_831529852295_item	3711807	et	0	cKUAfXynZ
kohta	doc_831529852295_item	3711808	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3711809	et	0	cKUAfXynZ
koostada	doc_831529852295_item	3711810	et	0	cKUAfXynZ
lause	doc_831529852295_item	3711811	et	0	cKUAfXynZ
mis	doc_831529852295_item	3711812	et	0	cKUAfXynZ
on	doc_831529852295_item	3711813	et	0	cKUAfXynZ
kokkuvõttev	doc_831529852295_item	3711814	et	0	cKUAfXynZ
oskus	doc_831529852295_item	3711815	et	0	cKUAfXynZ
teha	doc_831529852295_item	3711816	et	0	cKUAfXynZ
kokkuvõtte	doc_831529852295_item	3711817	et	0	cKUAfXynZ
on	doc_831529852295_item	3711818	et	0	cKUAfXynZ
väga	doc_831529852295_item	3711819	et	0	cKUAfXynZ
vajalik	doc_831529852295_item	3711820	et	0	cKUAfXynZ
õpilastele	doc_831529852295_item	3711821	et	0	cKUAfXynZ
kuna	doc_831529852295_item	3711822	et	0	cKUAfXynZ
tihti	doc_831529852295_item	3711823	et	0	cKUAfXynZ
on	doc_831529852295_item	3711824	et	0	cKUAfXynZ
raske	doc_831529852295_item	3711825	et	0	cKUAfXynZ
tekstist	doc_831529852295_item	3711826	et	0	cKUAfXynZ
leida	doc_831529852295_item	3711827	et	0	cKUAfXynZ
informatsiooni	doc_831529852295_item	3711828	et	0	cKUAfXynZ
mis	doc_831529852295_item	3711829	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3711830	et	0	cKUAfXynZ
esmane	doc_831529852295_item	3711831	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711832	et	0	cKUAfXynZ
saaks	doc_831529852295_item	3711833	et	0	cKUAfXynZ
avada	doc_831529852295_item	3711834	et	0	cKUAfXynZ
teksti	doc_831529852295_item	3711835	et	0	cKUAfXynZ
sisu	doc_831529852295_item	3711836	et	0	cKUAfXynZ
selle	doc_831529852295_item	3711837	et	0	cKUAfXynZ
peab	doc_831529852295_item	3711838	et	0	cKUAfXynZ
kindlasti	doc_831529852295_item	3711839	et	0	cKUAfXynZ
ära	doc_831529852295_item	3711840	et	0	cKUAfXynZ
õppima	doc_831529852295_item	3711841	et	0	cKUAfXynZ
kokkuvõtte	doc_831529852295_item	3711842	et	0	cKUAfXynZ
peab	doc_831529852295_item	3711843	et	0	cKUAfXynZ
lühidalt	doc_831529852295_item	3711844	et	0	cKUAfXynZ
ümber	doc_831529852295_item	3711845	et	0	cKUAfXynZ
jutustada	doc_831529852295_item	3711846	et	0	cKUAfXynZ
teksti	doc_831529852295_item	3711847	et	0	cKUAfXynZ
sisu	doc_831529852295_item	3711848	et	0	cKUAfXynZ
see	doc_831529852295_item	3711849	et	0	cKUAfXynZ
peab	doc_831529852295_item	3711850	et	0	cKUAfXynZ
olema	doc_831529852295_item	3711851	et	0	cKUAfXynZ
konkreetne	doc_831529852295_item	3711852	et	0	cKUAfXynZ
väike	doc_831529852295_item	3711853	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711854	et	0	cKUAfXynZ
täpne	doc_831529852295_item	3711855	et	0	cKUAfXynZ
oskus	doc_831529852295_item	3711856	et	0	cKUAfXynZ
teha	doc_831529852295_item	3711857	et	0	cKUAfXynZ
kokkuvõtte	doc_831529852295_item	3711858	et	0	cKUAfXynZ
sõltub	doc_831529852295_item	3711859	et	0	cKUAfXynZ
kirjutamisoskusest	doc_831529852295_item	3711860	et	0	cKUAfXynZ
5	doc_831529852295_item	3711861	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3711862	et	0	cKUAfXynZ
koolikirjutamise	doc_831529852295_item	3711863	et	0	cKUAfXynZ
eesmärk	doc_831529852295_item	3711864	et	0	cKUAfXynZ
on	doc_831529852295_item	3711865	et	0	cKUAfXynZ
kasvatada	doc_831529852295_item	3711866	et	0	cKUAfXynZ
lapsest	doc_831529852295_item	3711867	et	0	cKUAfXynZ
isiksus	doc_831529852295_item	3711868	et	0	cKUAfXynZ
kes	doc_831529852295_item	3711869	et	0	cKUAfXynZ
julgeb	doc_831529852295_item	3711870	et	0	cKUAfXynZ
oma	doc_831529852295_item	3711871	et	0	cKUAfXynZ
mõtteid	doc_831529852295_item	3711872	et	0	cKUAfXynZ
kirja	doc_831529852295_item	3711873	et	0	cKUAfXynZ
panna	doc_831529852295_item	3711874	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711875	et	0	cKUAfXynZ
kes	doc_831529852295_item	3711876	et	0	cKUAfXynZ
valdab	doc_831529852295_item	3711877	et	0	cKUAfXynZ
kirjutamisega	doc_831529852295_item	3711878	et	0	cKUAfXynZ
nõutaval	doc_831529852295_item	3711879	et	0	cKUAfXynZ
tasemel	doc_831529852295_item	3711880	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3711881	et	0	cKUAfXynZ
arvavad	doc_831529852295_item	3711882	et	0	cKUAfXynZ
et	doc_831529852295_item	3711883	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3711884	et	0	cKUAfXynZ
on	doc_831529852295_item	3711885	et	0	cKUAfXynZ
raskem	doc_831529852295_item	3711886	et	0	cKUAfXynZ
kui	doc_831529852295_item	3711887	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3711888	et	0	cKUAfXynZ
huvi	doc_831529852295_item	3711889	et	0	cKUAfXynZ
kirjutamise	doc_831529852295_item	3711890	et	0	cKUAfXynZ
vastu	doc_831529852295_item	3711891	et	0	cKUAfXynZ
kaob	doc_831529852295_item	3711892	et	0	cKUAfXynZ
juba	doc_831529852295_item	3711893	et	0	cKUAfXynZ
kooliaastate	doc_831529852295_item	3711894	et	0	cKUAfXynZ
alguses	doc_831529852295_item	3711895	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3711896	et	0	cKUAfXynZ
hea	doc_831529852295_item	3711897	et	0	cKUAfXynZ
kui	doc_831529852295_item	3711898	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3711899	et	0	cKUAfXynZ
saaks	doc_831529852295_item	3711900	et	0	cKUAfXynZ
anda	doc_831529852295_item	3711901	et	0	cKUAfXynZ
õpilastele	doc_831529852295_item	3711902	et	0	cKUAfXynZ
niisuguseid	doc_831529852295_item	3711903	et	0	cKUAfXynZ
ülesandeid	doc_831529852295_item	3711904	et	0	cKUAfXynZ
kus	doc_831529852295_item	3711905	et	0	cKUAfXynZ
lastele	doc_831529852295_item	3711906	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3711907	et	0	cKUAfXynZ
huvitav	doc_831529852295_item	3711908	et	0	cKUAfXynZ
rakendada	doc_831529852295_item	3711909	et	0	cKUAfXynZ
oma	doc_831529852295_item	3711910	et	0	cKUAfXynZ
kirjutamisoskust	doc_831529852295_item	3711911	et	0	cKUAfXynZ
need	doc_831529852295_item	3711912	et	0	cKUAfXynZ
ülesanded	doc_831529852295_item	3711913	et	0	cKUAfXynZ
peavad	doc_831529852295_item	3711914	et	0	cKUAfXynZ
olema	doc_831529852295_item	3711915	et	0	cKUAfXynZ
elu	doc_831529852295_item	3711916	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711917	et	0	cKUAfXynZ
lapse	doc_831529852295_item	3711918	et	0	cKUAfXynZ
lähedased	doc_831529852295_item	3711919	et	0	cKUAfXynZ
kirjad	doc_831529852295_item	3711920	et	0	cKUAfXynZ
märkmed	doc_831529852295_item	3711921	et	0	cKUAfXynZ
sünnipäevakutsed	doc_831529852295_item	3711922	et	0	cKUAfXynZ
kuulutused	doc_831529852295_item	3711923	et	0	cKUAfXynZ
retseptid	doc_831529852295_item	3711924	et	0	cKUAfXynZ
reklaamid	doc_831529852295_item	3711925	et	0	cKUAfXynZ
jne	doc_831529852295_item	3711926	et	0	cKUAfXynZ
niimoodi	doc_831529852295_item	3711927	et	0	cKUAfXynZ
õpilastele	doc_831529852295_item	3711928	et	0	cKUAfXynZ
on	doc_831529852295_item	3711929	et	0	cKUAfXynZ
kergem	doc_831529852295_item	3711930	et	0	cKUAfXynZ
kirjutamisega	doc_831529852295_item	3711931	et	0	cKUAfXynZ
hakkama	doc_831529852295_item	3711932	et	0	cKUAfXynZ
saada	doc_831529852295_item	3711933	et	0	cKUAfXynZ
kuna	doc_831529852295_item	3711934	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3711935	et	0	cKUAfXynZ
on	doc_831529852295_item	3711936	et	0	cKUAfXynZ
keerulisem	doc_831529852295_item	3711937	et	0	cKUAfXynZ
kui	doc_831529852295_item	3711938	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3711939	et	0	cKUAfXynZ
selle	doc_831529852295_item	3711940	et	0	cKUAfXynZ
kohta	doc_831529852295_item	3711941	et	0	cKUAfXynZ
võib	doc_831529852295_item	3711942	et	0	cKUAfXynZ
leida	doc_831529852295_item	3711943	et	0	cKUAfXynZ
erinevaid	doc_831529852295_item	3711944	et	0	cKUAfXynZ
definitsioone	doc_831529852295_item	3711945	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3711946	et	0	cKUAfXynZ
tähendab	doc_831529852295_item	3711947	et	0	cKUAfXynZ
erinevate	doc_831529852295_item	3711948	et	0	cKUAfXynZ
tekstide	doc_831529852295_item	3711949	et	0	cKUAfXynZ
koostamist	doc_831529852295_item	3711950	et	0	cKUAfXynZ
mis	doc_831529852295_item	3711951	et	0	cKUAfXynZ
sisaldab	doc_831529852295_item	3711952	et	0	cKUAfXynZ
kirjutamisprotsessi	doc_831529852295_item	3711953	et	0	cKUAfXynZ
kirjutamisprotsess	doc_831529852295_item	3711954	et	0	cKUAfXynZ
sisaldab	doc_831529852295_item	3711955	et	0	cKUAfXynZ
omakorda	doc_831529852295_item	3711956	et	0	cKUAfXynZ
kirjatehnikat	doc_831529852295_item	3711957	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711958	et	0	cKUAfXynZ
grammatikat	doc_831529852295_item	3711959	et	0	cKUAfXynZ
algklassides	doc_831529852295_item	3711960	et	0	cKUAfXynZ
koosneb	doc_831529852295_item	3711961	et	0	cKUAfXynZ
tekstide	doc_831529852295_item	3711962	et	0	cKUAfXynZ
koostamise	doc_831529852295_item	3711963	et	0	cKUAfXynZ
programm	doc_831529852295_item	3711964	et	0	cKUAfXynZ
kahest	doc_831529852295_item	3711965	et	0	cKUAfXynZ
alast	doc_831529852295_item	3711966	et	0	cKUAfXynZ
esimene	doc_831529852295_item	3711967	et	0	cKUAfXynZ
on	doc_831529852295_item	3711968	et	0	cKUAfXynZ
sisu	doc_831529852295_item	3711969	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3711970	et	0	cKUAfXynZ
ideed	doc_831529852295_item	3711971	et	0	cKUAfXynZ
millest	doc_831529852295_item	3711972	et	0	cKUAfXynZ
laps	doc_831529852295_item	3711973	et	0	cKUAfXynZ
tahab	doc_831529852295_item	3711974	et	0	cKUAfXynZ
jutustada	doc_831529852295_item	3711975	et	0	cKUAfXynZ
teine	doc_831529852295_item	3711976	et	0	cKUAfXynZ
on	doc_831529852295_item	3711977	et	0	cKUAfXynZ
kirjutamise	doc_831529852295_item	3711978	et	0	cKUAfXynZ
protsess	doc_831529852295_item	3711979	et	0	cKUAfXynZ
seda	doc_831529852295_item	3711980	et	0	cKUAfXynZ
on	doc_831529852295_item	3711981	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3711982	et	0	cKUAfXynZ
suhtlemiseks	doc_831529852295_item	3711983	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3711984	et	0	cKUAfXynZ
peab	doc_831529852295_item	3711985	et	0	cKUAfXynZ
aru	doc_831529852295_item	3711986	et	0	cKUAfXynZ
saama	doc_831529852295_item	3711987	et	0	cKUAfXynZ
et	doc_831529852295_item	3711988	et	0	cKUAfXynZ
mõlemad	doc_831529852295_item	3711989	et	0	cKUAfXynZ
on	doc_831529852295_item	3711990	et	0	cKUAfXynZ
tähtsad	doc_831529852295_item	3711991	et	0	cKUAfXynZ
ja	doc_831529852295_item	3711992	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3711993	et	0	cKUAfXynZ
kirjutamise	doc_831529852295_item	3711994	et	0	cKUAfXynZ
organiseerida	doc_831529852295_item	3711995	et	0	cKUAfXynZ
sellega	doc_831529852295_item	3711996	et	0	cKUAfXynZ
arvestades	doc_831529852295_item	3711997	et	0	cKUAfXynZ
oluliseks	doc_831529852295_item	3711998	et	0	cKUAfXynZ
siin	doc_831529852295_item	3711999	et	0	cKUAfXynZ
on	doc_831529852295_item	3712000	et	0	cKUAfXynZ
et	doc_831529852295_item	3712001	et	0	cKUAfXynZ
laps	doc_831529852295_item	3712002	et	0	cKUAfXynZ
peab	doc_831529852295_item	3712003	et	0	cKUAfXynZ
aru	doc_831529852295_item	3712004	et	0	cKUAfXynZ
saama	doc_831529852295_item	3712005	et	0	cKUAfXynZ
kirjutamise	doc_831529852295_item	3712006	et	0	cKUAfXynZ
tähendusest	doc_831529852295_item	3712007	et	0	cKUAfXynZ
oma	doc_831529852295_item	3712008	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712009	et	0	cKUAfXynZ
teiste	doc_831529852295_item	3712010	et	0	cKUAfXynZ
elus	doc_831529852295_item	3712011	et	0	cKUAfXynZ
igapäevaste	doc_831529852295_item	3712012	et	0	cKUAfXynZ
kontaktide	doc_831529852295_item	3712013	et	0	cKUAfXynZ
etiketi	doc_831529852295_item	3712014	et	0	cKUAfXynZ
juhendite	doc_831529852295_item	3712015	et	0	cKUAfXynZ
kartide	doc_831529852295_item	3712016	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712017	et	0	cKUAfXynZ
ajalehtede	doc_831529852295_item	3712018	et	0	cKUAfXynZ
kaudu	doc_831529852295_item	3712019	et	0	cKUAfXynZ
õpivad	doc_831529852295_item	3712020	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3712021	et	0	cKUAfXynZ
aru	doc_831529852295_item	3712022	et	0	cKUAfXynZ
saama	doc_831529852295_item	3712023	et	0	cKUAfXynZ
kirjutamise	doc_831529852295_item	3712024	et	0	cKUAfXynZ
tähtsusest	doc_831529852295_item	3712025	et	0	cKUAfXynZ
õpilased	doc_831529852295_item	3712026	et	0	cKUAfXynZ
peavad	doc_831529852295_item	3712027	et	0	cKUAfXynZ
aru	doc_831529852295_item	3712028	et	0	cKUAfXynZ
saama	doc_831529852295_item	3712029	et	0	cKUAfXynZ
et	doc_831529852295_item	3712030	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3712031	et	0	cKUAfXynZ
on	doc_831529852295_item	3712032	et	0	cKUAfXynZ
ühiskonnaelu	doc_831529852295_item	3712033	et	0	cKUAfXynZ
osalemise	doc_831529852295_item	3712034	et	0	cKUAfXynZ
viis	doc_831529852295_item	3712035	et	0	cKUAfXynZ
see	doc_831529852295_item	3712036	et	0	cKUAfXynZ
aitab	doc_831529852295_item	3712037	et	0	cKUAfXynZ
suhelda	doc_831529852295_item	3712038	et	0	cKUAfXynZ
oma	doc_831529852295_item	3712039	et	0	cKUAfXynZ
arvamust	doc_831529852295_item	3712040	et	0	cKUAfXynZ
väljendada	doc_831529852295_item	3712041	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712042	et	0	cKUAfXynZ
näitab	doc_831529852295_item	3712043	et	0	cKUAfXynZ
akadeemilist	doc_831529852295_item	3712044	et	0	cKUAfXynZ
kompetentsust	doc_831529852295_item	3712045	et	0	cKUAfXynZ
raamatu	doc_831529852295_item	3712046	et	0	cKUAfXynZ
autor	doc_831529852295_item	3712047	et	0	cKUAfXynZ
kirjutab	doc_831529852295_item	3712048	et	0	cKUAfXynZ
et	doc_831529852295_item	3712049	et	0	cKUAfXynZ
lapsel	doc_831529852295_item	3712050	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3712051	et	0	cKUAfXynZ
huvitavam	doc_831529852295_item	3712052	et	0	cKUAfXynZ
kirjutada	doc_831529852295_item	3712053	et	0	cKUAfXynZ
tal	doc_831529852295_item	3712054	et	0	cKUAfXynZ
peab	doc_831529852295_item	3712055	et	0	cKUAfXynZ
olema	doc_831529852295_item	3712056	et	0	cKUAfXynZ
palju	doc_831529852295_item	3712057	et	0	cKUAfXynZ
erinevaid	doc_831529852295_item	3712058	et	0	cKUAfXynZ
kogemusi	doc_831529852295_item	3712059	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712060	et	0	cKUAfXynZ
huvisid	doc_831529852295_item	3712061	et	0	cKUAfXynZ
need	doc_831529852295_item	3712062	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3712063	et	0	cKUAfXynZ
olla	doc_831529852295_item	3712064	et	0	cKUAfXynZ
sündmused	doc_831529852295_item	3712065	et	0	cKUAfXynZ
kodus	doc_831529852295_item	3712066	et	0	cKUAfXynZ
koolis	doc_831529852295_item	3712067	et	0	cKUAfXynZ
pargis	doc_831529852295_item	3712068	et	0	cKUAfXynZ
matkad	doc_831529852295_item	3712069	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712070	et	0	cKUAfXynZ
koosolekud	doc_831529852295_item	3712071	et	0	cKUAfXynZ
laps	doc_831529852295_item	3712072	et	0	cKUAfXynZ
võib	doc_831529852295_item	3712073	et	0	cKUAfXynZ
kirjutada	doc_831529852295_item	3712074	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712075	et	0	cKUAfXynZ
erinevatest	doc_831529852295_item	3712076	et	0	cKUAfXynZ
massikommunikatsioonivahenditest	doc_831529852295_item	3712077	et	0	cKUAfXynZ
siia	doc_831529852295_item	3712078	et	0	cKUAfXynZ
kuuluvad	doc_831529852295_item	3712079	et	0	cKUAfXynZ
raamatud	doc_831529852295_item	3712080	et	0	cKUAfXynZ
ajalehed	doc_831529852295_item	3712081	et	0	cKUAfXynZ
televisioon	doc_831529852295_item	3712082	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712083	et	0	cKUAfXynZ
raadio	doc_831529852295_item	3712084	et	0	cKUAfXynZ
huvitav	doc_831529852295_item	3712085	et	0	cKUAfXynZ
teema	doc_831529852295_item	3712086	et	0	cKUAfXynZ
laste	doc_831529852295_item	3712087	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3712088	et	0	cKUAfXynZ
on	doc_831529852295_item	3712089	et	0	cKUAfXynZ
lemmik	doc_831529852295_item	3712090	et	0	cKUAfXynZ
tegevus	doc_831529852295_item	3712091	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3712092	et	0	cKUAfXynZ
sport	doc_831529852295_item	3712093	et	0	cKUAfXynZ
hiljem	doc_831529852295_item	3712094	et	0	cKUAfXynZ
see	doc_831529852295_item	3712095	et	0	cKUAfXynZ
kõik	doc_831529852295_item	3712096	et	0	cKUAfXynZ
täieneb	doc_831529852295_item	3712097	et	0	cKUAfXynZ
õpitavaga	doc_831529852295_item	3712098	et	0	cKUAfXynZ
kodulugu	doc_831529852295_item	3712099	et	0	cKUAfXynZ
sotsiaalsed	doc_831529852295_item	3712100	et	0	cKUAfXynZ
andmed	doc_831529852295_item	3712101	et	0	cKUAfXynZ
tervishoid	doc_831529852295_item	3712102	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712103	et	0	cKUAfXynZ
kirjandus	doc_831529852295_item	3712104	et	0	cKUAfXynZ
kasuks	doc_831529852295_item	3712105	et	0	cKUAfXynZ
läheb	doc_831529852295_item	3712106	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712107	et	0	cKUAfXynZ
enne	doc_831529852295_item	3712108	et	0	cKUAfXynZ
kirjutamist	doc_831529852295_item	3712109	et	0	cKUAfXynZ
laps	doc_831529852295_item	3712110	et	0	cKUAfXynZ
saab	doc_831529852295_item	3712111	et	0	cKUAfXynZ
suhelda	doc_831529852295_item	3712112	et	0	cKUAfXynZ
suuliselt	doc_831529852295_item	3712113	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712114	et	0	cKUAfXynZ
laps	doc_831529852295_item	3712115	et	0	cKUAfXynZ
ei	doc_831529852295_item	3712116	et	0	cKUAfXynZ
ole	doc_831529852295_item	3712117	et	0	cKUAfXynZ
võimeline	doc_831529852295_item	3712118	et	0	cKUAfXynZ
väljendada	doc_831529852295_item	3712119	et	0	cKUAfXynZ
ennast	doc_831529852295_item	3712120	et	0	cKUAfXynZ
suuliselt	doc_831529852295_item	3712121	et	0	cKUAfXynZ
ei	doc_831529852295_item	3712122	et	0	cKUAfXynZ
ole	doc_831529852295_item	3712123	et	0	cKUAfXynZ
ta	doc_831529852295_item	3712124	et	0	cKUAfXynZ
valmis	doc_831529852295_item	3712125	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712126	et	0	cKUAfXynZ
kirjutamiseks	doc_831529852295_item	3712127	et	0	cKUAfXynZ
nagu	doc_831529852295_item	3712128	et	0	cKUAfXynZ
oli	doc_831529852295_item	3712129	et	0	cKUAfXynZ
juba	doc_831529852295_item	3712130	et	0	cKUAfXynZ
mainitud	doc_831529852295_item	3712131	et	0	cKUAfXynZ
oluliseks	doc_831529852295_item	3712132	et	0	cKUAfXynZ
mõjutajaks	doc_831529852295_item	3712133	et	0	cKUAfXynZ
on	doc_831529852295_item	3712134	et	0	cKUAfXynZ
klassikeskkond	doc_831529852295_item	3712135	et	0	cKUAfXynZ
see	doc_831529852295_item	3712136	et	0	cKUAfXynZ
peab	doc_831529852295_item	3712137	et	0	cKUAfXynZ
olema	doc_831529852295_item	3712138	et	0	cKUAfXynZ
toetav	doc_831529852295_item	3712139	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712140	et	0	cKUAfXynZ
kaitsev	doc_831529852295_item	3712141	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712142	et	0	cKUAfXynZ
klassis	doc_831529852295_item	3712143	et	0	cKUAfXynZ
pole	doc_831529852295_item	3712144	et	0	cKUAfXynZ
pinget	doc_831529852295_item	3712145	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3712146	et	0	cKUAfXynZ
usuvad	doc_831529852295_item	3712147	et	0	cKUAfXynZ
et	doc_831529852295_item	3712148	et	0	cKUAfXynZ
nende	doc_831529852295_item	3712149	et	0	cKUAfXynZ
tunded	doc_831529852295_item	3712150	et	0	cKUAfXynZ
väärtushinnangud	doc_831529852295_item	3712151	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712152	et	0	cKUAfXynZ
mõtted	doc_831529852295_item	3712153	et	0	cKUAfXynZ
on	doc_831529852295_item	3712154	et	0	cKUAfXynZ
olulised	doc_831529852295_item	3712155	et	0	cKUAfXynZ
et	doc_831529852295_item	3712156	et	0	cKUAfXynZ
neid	doc_831529852295_item	3712157	et	0	cKUAfXynZ
võib	doc_831529852295_item	3712158	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712159	et	0	cKUAfXynZ
teiste	doc_831529852295_item	3712160	et	0	cKUAfXynZ
inimestega	doc_831529852295_item	3712161	et	0	cKUAfXynZ
jagada	doc_831529852295_item	3712162	et	0	cKUAfXynZ
kirjandus	doc_831529852295_item	3712163	et	0	cKUAfXynZ
laste	doc_831529852295_item	3712164	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3712165	et	0	cKUAfXynZ
peab	doc_831529852295_item	3712166	et	0	cKUAfXynZ
olema	doc_831529852295_item	3712167	et	0	cKUAfXynZ
kvaliteetne	doc_831529852295_item	3712168	et	0	cKUAfXynZ
see	doc_831529852295_item	3712169	et	0	cKUAfXynZ
arendab	doc_831529852295_item	3712170	et	0	cKUAfXynZ
oskust	doc_831529852295_item	3712171	et	0	cKUAfXynZ
kirjutada	doc_831529852295_item	3712172	et	0	cKUAfXynZ
hästi	doc_831529852295_item	3712173	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3712174	et	0	cKUAfXynZ
on	doc_831529852295_item	3712175	et	0	cKUAfXynZ
allikas	doc_831529852295_item	3712176	et	0	cKUAfXynZ
uuteks	doc_831529852295_item	3712177	et	0	cKUAfXynZ
ideedeks	doc_831529852295_item	3712178	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712179	et	0	cKUAfXynZ
sõnadeks	doc_831529852295_item	3712180	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712181	et	0	cKUAfXynZ
see	doc_831529852295_item	3712182	et	0	cKUAfXynZ
on	doc_831529852295_item	3712183	et	0	cKUAfXynZ
võimalik	doc_831529852295_item	3712184	et	0	cKUAfXynZ
on	doc_831529852295_item	3712185	et	0	cKUAfXynZ
kasulik	doc_831529852295_item	3712186	et	0	cKUAfXynZ
käia	doc_831529852295_item	3712187	et	0	cKUAfXynZ
kooliraamatukogus	doc_831529852295_item	3712188	et	0	cKUAfXynZ
laps	doc_831529852295_item	3712189	et	0	cKUAfXynZ
peab	doc_831529852295_item	3712190	et	0	cKUAfXynZ
aru	doc_831529852295_item	3712191	et	0	cKUAfXynZ
saama	doc_831529852295_item	3712192	et	0	cKUAfXynZ
et	doc_831529852295_item	3712193	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3712194	et	0	cKUAfXynZ
sisaldab	doc_831529852295_item	3712195	et	0	cKUAfXynZ
erinevaid	doc_831529852295_item	3712196	et	0	cKUAfXynZ
astmeid	doc_831529852295_item	3712197	et	0	cKUAfXynZ
need	doc_831529852295_item	3712198	et	0	cKUAfXynZ
on	doc_831529852295_item	3712199	et	0	cKUAfXynZ
eeltöö	doc_831529852295_item	3712200	et	0	cKUAfXynZ
ideede	doc_831529852295_item	3712201	et	0	cKUAfXynZ
saamine	doc_831529852295_item	3712202	et	0	cKUAfXynZ
kavandi	doc_831529852295_item	3712203	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3712204	et	0	cKUAfXynZ
parandamine	doc_831529852295_item	3712205	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712206	et	0	cKUAfXynZ
toimetamine	doc_831529852295_item	3712207	et	0	cKUAfXynZ
siia	doc_831529852295_item	3712208	et	0	cKUAfXynZ
kuulub	doc_831529852295_item	3712209	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712210	et	0	cKUAfXynZ
publitseerimine	doc_831529852295_item	3712211	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3712212	et	0	cKUAfXynZ
teistega	doc_831529852295_item	3712213	et	0	cKUAfXynZ
jagamine	doc_831529852295_item	3712214	et	0	cKUAfXynZ
on	doc_831529852295_item	3712215	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3712216	et	0	cKUAfXynZ
et	doc_831529852295_item	3712217	et	0	cKUAfXynZ
laps	doc_831529852295_item	3712218	et	0	cKUAfXynZ
saaks	doc_831529852295_item	3712219	et	0	cKUAfXynZ
aru	doc_831529852295_item	3712220	et	0	cKUAfXynZ
et	doc_831529852295_item	3712221	et	0	cKUAfXynZ
kirjutaja	doc_831529852295_item	3712222	et	0	cKUAfXynZ
suhtleb	doc_831529852295_item	3712223	et	0	cKUAfXynZ
kellegagi	doc_831529852295_item	3712224	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712225	et	0	cKUAfXynZ
kirjutab	doc_831529852295_item	3712226	et	0	cKUAfXynZ
samast	doc_831529852295_item	3712227	et	0	cKUAfXynZ
temast	doc_831529852295_item	3712228	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3712229	et	0	cKUAfXynZ
kirjutada	doc_831529852295_item	3712230	et	0	cKUAfXynZ
erinevalt	doc_831529852295_item	3712231	et	0	cKUAfXynZ
erinevale	doc_831529852295_item	3712232	et	0	cKUAfXynZ
ühiskonnale	doc_831529852295_item	3712233	et	0	cKUAfXynZ
kirjutamisoskuse	doc_831529852295_item	3712234	et	0	cKUAfXynZ
arendamiseks	doc_831529852295_item	3712235	et	0	cKUAfXynZ
on	doc_831529852295_item	3712236	et	0	cKUAfXynZ
oluline	doc_831529852295_item	3712237	et	0	cKUAfXynZ
et	doc_831529852295_item	3712238	et	0	cKUAfXynZ
õpilasel	doc_831529852295_item	3712239	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3712240	et	0	cKUAfXynZ
võimalus	doc_831529852295_item	3712241	et	0	cKUAfXynZ
kirjutada	doc_831529852295_item	3712242	et	0	cKUAfXynZ
kõigil	doc_831529852295_item	3712243	et	0	cKUAfXynZ
kolmel	doc_831529852295_item	3712244	et	0	cKUAfXynZ
eesmärgil	doc_831529852295_item	3712245	et	0	cKUAfXynZ
kirjeldaval	doc_831529852295_item	3712246	et	0	cKUAfXynZ
jutustaval	doc_831529852295_item	3712247	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712248	et	0	cKUAfXynZ
seletaval	doc_831529852295_item	3712249	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712250	et	0	cKUAfXynZ
midagi	doc_831529852295_item	3712251	et	0	cKUAfXynZ
ei	doc_831529852295_item	3712252	et	0	cKUAfXynZ
tule	doc_831529852295_item	3712253	et	0	cKUAfXynZ
välja	doc_831529852295_item	3712254	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3712255	et	0	cKUAfXynZ
peab	doc_831529852295_item	3712256	et	0	cKUAfXynZ
aitama	doc_831529852295_item	3712257	et	0	cKUAfXynZ
parandama	doc_831529852295_item	3712258	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712259	et	0	cKUAfXynZ
toimetama	doc_831529852295_item	3712260	et	0	cKUAfXynZ
õpetajale	doc_831529852295_item	3712261	et	0	cKUAfXynZ
on	doc_831529852295_item	3712262	et	0	cKUAfXynZ
kasulik	doc_831529852295_item	3712263	et	0	cKUAfXynZ
teada	doc_831529852295_item	3712264	et	0	cKUAfXynZ
et	doc_831529852295_item	3712265	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3712266	et	0	cKUAfXynZ
on	doc_831529852295_item	3712267	et	0	cKUAfXynZ
mitmeetapiline	doc_831529852295_item	3712268	et	0	cKUAfXynZ
protsess	doc_831529852295_item	3712269	et	0	cKUAfXynZ
et	doc_831529852295_item	3712270	et	0	cKUAfXynZ
õpilastel	doc_831529852295_item	3712271	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3712272	et	0	cKUAfXynZ
huvitav	doc_831529852295_item	3712273	et	0	cKUAfXynZ
kirjutada	doc_831529852295_item	3712274	et	0	cKUAfXynZ
peab	doc_831529852295_item	3712275	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3712276	et	0	cKUAfXynZ
ise	doc_831529852295_item	3712277	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712278	et	0	cKUAfXynZ
seda	doc_831529852295_item	3712279	et	0	cKUAfXynZ
tegema	doc_831529852295_item	3712280	et	0	cKUAfXynZ
niimoodi	doc_831529852295_item	3712281	et	0	cKUAfXynZ
ta	doc_831529852295_item	3712282	et	0	cKUAfXynZ
tutvub	doc_831529852295_item	3712283	et	0	cKUAfXynZ
ülesannete	doc_831529852295_item	3712284	et	0	cKUAfXynZ
raskusastmega	doc_831529852295_item	3712285	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712286	et	0	cKUAfXynZ
ise	doc_831529852295_item	3712287	et	0	cKUAfXynZ
tutvub	doc_831529852295_item	3712288	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712289	et	0	cKUAfXynZ
tööperioodidega	doc_831529852295_item	3712290	et	0	cKUAfXynZ
oluliseks	doc_831529852295_item	3712291	et	0	cKUAfXynZ
peetakse	doc_831529852295_item	3712292	et	0	cKUAfXynZ
et	doc_831529852295_item	3712293	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3712294	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3712295	et	0	cKUAfXynZ
rõõmus	doc_831529852295_item	3712296	et	0	cKUAfXynZ
ühistöö	doc_831529852295_item	3712297	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3712298	et	0	cKUAfXynZ
ei	doc_831529852295_item	3712299	et	0	cKUAfXynZ
pea	doc_831529852295_item	3712300	et	0	cKUAfXynZ
esmajärjekorras	doc_831529852295_item	3712301	et	0	cKUAfXynZ
hindama	doc_831529852295_item	3712302	et	0	cKUAfXynZ
vaid	doc_831529852295_item	3712303	et	0	cKUAfXynZ
peaks	doc_831529852295_item	3712304	et	0	cKUAfXynZ
juhendama	doc_831529852295_item	3712305	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712306	et	0	cKUAfXynZ
julgustama	doc_831529852295_item	3712307	et	0	cKUAfXynZ
õpilased	doc_831529852295_item	3712308	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3712309	et	0	cKUAfXynZ
juhendada	doc_831529852295_item	3712310	et	0	cKUAfXynZ
üksteist	doc_831529852295_item	3712311	et	0	cKUAfXynZ
nad	doc_831529852295_item	3712312	et	0	cKUAfXynZ
ise	doc_831529852295_item	3712313	et	0	cKUAfXynZ
tunnevad	doc_831529852295_item	3712314	et	0	cKUAfXynZ
väga	doc_831529852295_item	3712315	et	0	cKUAfXynZ
hästi	doc_831529852295_item	3712316	et	0	cKUAfXynZ
omaealiste	doc_831529852295_item	3712317	et	0	cKUAfXynZ
maailma	doc_831529852295_item	3712318	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712319	et	0	cKUAfXynZ
huvisid	doc_831529852295_item	3712320	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3712321	et	0	cKUAfXynZ
on	doc_831529852295_item	3712322	et	0	cKUAfXynZ
õppimise	doc_831529852295_item	3712323	et	0	cKUAfXynZ
osa	doc_831529852295_item	3712324	et	0	cKUAfXynZ
seda	doc_831529852295_item	3712325	et	0	cKUAfXynZ
ei	doc_831529852295_item	3712326	et	0	cKUAfXynZ
saa	doc_831529852295_item	3712327	et	0	cKUAfXynZ
eristada	doc_831529852295_item	3712328	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712329	et	0	cKUAfXynZ
eraldiseisvat	doc_831529852295_item	3712330	et	0	cKUAfXynZ
oskust	doc_831529852295_item	3712331	et	0	cKUAfXynZ
51	doc_831529852295_item	3712332	et	0	cKUAfXynZ
käekiri	doc_831529852295_item	3712333	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3712334	et	0	cKUAfXynZ
asi	doc_831529852295_item	3712335	et	0	cKUAfXynZ
kirjutamises	doc_831529852295_item	3712336	et	0	cKUAfXynZ
on	doc_831529852295_item	3712337	et	0	cKUAfXynZ
kirja	doc_831529852295_item	3712338	et	0	cKUAfXynZ
loetavus	doc_831529852295_item	3712339	et	0	cKUAfXynZ
käekiri	doc_831529852295_item	3712340	et	0	cKUAfXynZ
ei	doc_831529852295_item	3712341	et	0	cKUAfXynZ
pea	doc_831529852295_item	3712342	et	0	cKUAfXynZ
olema	doc_831529852295_item	3712343	et	0	cKUAfXynZ
ilus	doc_831529852295_item	3712344	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712345	et	0	cKUAfXynZ
stiilne	doc_831529852295_item	3712346	et	0	cKUAfXynZ
vaid	doc_831529852295_item	3712347	et	0	cKUAfXynZ
peab	doc_831529852295_item	3712348	et	0	cKUAfXynZ
olema	doc_831529852295_item	3712349	et	0	cKUAfXynZ
loetav	doc_831529852295_item	3712350	et	0	cKUAfXynZ
seda	doc_831529852295_item	3712351	et	0	cKUAfXynZ
on	doc_831529852295_item	3712352	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3712353	et	0	cKUAfXynZ
rõhutada	doc_831529852295_item	3712354	et	0	cKUAfXynZ
käekiri	doc_831529852295_item	3712355	et	0	cKUAfXynZ
on	doc_831529852295_item	3712356	et	0	cKUAfXynZ
suhtlemisvahend	doc_831529852295_item	3712357	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712358	et	0	cKUAfXynZ
inimeste	doc_831529852295_item	3712359	et	0	cKUAfXynZ
kirjutis	doc_831529852295_item	3712360	et	0	cKUAfXynZ
ei	doc_831529852295_item	3712361	et	0	cKUAfXynZ
ole	doc_831529852295_item	3712362	et	0	cKUAfXynZ
loetav	doc_831529852295_item	3712363	et	0	cKUAfXynZ
siis	doc_831529852295_item	3712364	et	0	cKUAfXynZ
suhtlemist	doc_831529852295_item	3712365	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712366	et	0	cKUAfXynZ
ei	doc_831529852295_item	3712367	et	0	cKUAfXynZ
toimu	doc_831529852295_item	3712368	et	0	cKUAfXynZ
keegi	doc_831529852295_item	3712369	et	0	cKUAfXynZ
siis	doc_831529852295_item	3712370	et	0	cKUAfXynZ
ei	doc_831529852295_item	3712371	et	0	cKUAfXynZ
saa	doc_831529852295_item	3712372	et	0	cKUAfXynZ
aru	doc_831529852295_item	3712373	et	0	cKUAfXynZ
mida	doc_831529852295_item	3712374	et	0	cKUAfXynZ
kirjutaja	doc_831529852295_item	3712375	et	0	cKUAfXynZ
tahtis	doc_831529852295_item	3712376	et	0	cKUAfXynZ
öelda	doc_831529852295_item	3712377	et	0	cKUAfXynZ
et	doc_831529852295_item	3712378	et	0	cKUAfXynZ
käekiri	doc_831529852295_item	3712379	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3712380	et	0	cKUAfXynZ
loetav	doc_831529852295_item	3712381	et	0	cKUAfXynZ
laps	doc_831529852295_item	3712382	et	0	cKUAfXynZ
peab	doc_831529852295_item	3712383	et	0	cKUAfXynZ
leidma	doc_831529852295_item	3712384	et	0	cKUAfXynZ
endale	doc_831529852295_item	3712385	et	0	cKUAfXynZ
korrektse	doc_831529852295_item	3712386	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712387	et	0	cKUAfXynZ
sobiva	doc_831529852295_item	3712388	et	0	cKUAfXynZ
kehaasendi	doc_831529852295_item	3712389	et	0	cKUAfXynZ
tal	doc_831529852295_item	3712390	et	0	cKUAfXynZ
peab	doc_831529852295_item	3712391	et	0	cKUAfXynZ
olema	doc_831529852295_item	3712392	et	0	cKUAfXynZ
mugav	doc_831529852295_item	3712393	et	0	cKUAfXynZ
kirjutama	doc_831529852295_item	3712394	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3712395	et	0	cKUAfXynZ
märkida	doc_831529852295_item	3712396	et	0	cKUAfXynZ
et	doc_831529852295_item	3712397	et	0	cKUAfXynZ
käekirja	doc_831529852295_item	3712398	et	0	cKUAfXynZ
mõjutavad	doc_831529852295_item	3712399	et	0	cKUAfXynZ
psüühilised	doc_831529852295_item	3712400	et	0	cKUAfXynZ
mentaalsed	doc_831529852295_item	3712401	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712402	et	0	cKUAfXynZ
emotsionaalsed	doc_831529852295_item	3712403	et	0	cKUAfXynZ
faktorid	doc_831529852295_item	3712404	et	0	cKUAfXynZ
igal	doc_831529852295_item	3712405	et	0	cKUAfXynZ
õpilael	doc_831529852295_item	3712406	et	0	cKUAfXynZ
on	doc_831529852295_item	3712407	et	0	cKUAfXynZ
oma	doc_831529852295_item	3712408	et	0	cKUAfXynZ
isiklik	doc_831529852295_item	3712409	et	0	cKUAfXynZ
kirjutamisstiil	doc_831529852295_item	3712410	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712411	et	0	cKUAfXynZ
kiirus	doc_831529852295_item	3712412	et	0	cKUAfXynZ
kirjutamisülesanded	doc_831529852295_item	3712413	et	0	cKUAfXynZ
ei	doc_831529852295_item	3712414	et	0	cKUAfXynZ
pea	doc_831529852295_item	3712415	et	0	cKUAfXynZ
olema	doc_831529852295_item	3712416	et	0	cKUAfXynZ
suured	doc_831529852295_item	3712417	et	0	cKUAfXynZ
kõige	doc_831529852295_item	3712418	et	0	cKUAfXynZ
efektiivsemad	doc_831529852295_item	3712419	et	0	cKUAfXynZ
on	doc_831529852295_item	3712420	et	0	cKUAfXynZ
kümnest	doc_831529852295_item	3712421	et	0	cKUAfXynZ
kuni	doc_831529852295_item	3712422	et	0	cKUAfXynZ
kahekümne	doc_831529852295_item	3712423	et	0	cKUAfXynZ
minutini	doc_831529852295_item	3712424	et	0	cKUAfXynZ
hästi	doc_831529852295_item	3712425	et	0	cKUAfXynZ
lastele	doc_831529852295_item	3712426	et	0	cKUAfXynZ
mõjub	doc_831529852295_item	3712427	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712428	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712429	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3712430	et	0	cKUAfXynZ
kirjutab	doc_831529852295_item	3712431	et	0	cKUAfXynZ
tahvlile	doc_831529852295_item	3712432	et	0	cKUAfXynZ
või	doc_831529852295_item	3712433	et	0	cKUAfXynZ
näitab	doc_831529852295_item	3712434	et	0	cKUAfXynZ
mingisugust	doc_831529852295_item	3712435	et	0	cKUAfXynZ
eeskuju	doc_831529852295_item	3712436	et	0	cKUAfXynZ
anne	doc_831529852295_item	3712437	et	0	cKUAfXynZ
uuseni	doc_831529852295_item	3712438	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3712439	et	0	cKUAfXynZ
antakse	doc_831529852295_item	3712440	et	0	cKUAfXynZ
lühike	doc_831529852295_item	3712441	et	0	cKUAfXynZ
ülevaade	doc_831529852295_item	3712442	et	0	cKUAfXynZ
spetsiifilise	doc_831529852295_item	3712443	et	0	cKUAfXynZ
kirjutamisele	doc_831529852295_item	3712444	et	0	cKUAfXynZ
tutvustatakse	doc_831529852295_item	3712445	et	0	cKUAfXynZ
soovituseid	doc_831529852295_item	3712446	et	0	cKUAfXynZ
seotud	doc_831529852295_item	3712447	et	0	cKUAfXynZ
kirjutamisõpetamisega	doc_831529852295_item	3712448	et	0	cKUAfXynZ
algklassides	doc_831529852295_item	3712449	et	0	cKUAfXynZ
siin	doc_831529852295_item	3712450	et	0	cKUAfXynZ
oluliseks	doc_831529852295_item	3712451	et	0	cKUAfXynZ
peetakse	doc_831529852295_item	3712452	et	0	cKUAfXynZ
seda	doc_831529852295_item	3712453	et	0	cKUAfXynZ
et	doc_831529852295_item	3712454	et	0	cKUAfXynZ
enne	doc_831529852295_item	3712455	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712456	et	0	cKUAfXynZ
laps	doc_831529852295_item	3712457	et	0	cKUAfXynZ
hakkab	doc_831529852295_item	3712458	et	0	cKUAfXynZ
kirjutama	doc_831529852295_item	3712459	et	0	cKUAfXynZ
ta	doc_831529852295_item	3712460	et	0	cKUAfXynZ
peab	doc_831529852295_item	3712461	et	0	cKUAfXynZ
oskama	doc_831529852295_item	3712462	et	0	cKUAfXynZ
kasutada	doc_831529852295_item	3712463	et	0	cKUAfXynZ
pliiatsit	doc_831529852295_item	3712464	et	0	cKUAfXynZ
ilma	doc_831529852295_item	3712465	et	0	cKUAfXynZ
eriliste	doc_831529852295_item	3712466	et	0	cKUAfXynZ
pingitusteta	doc_831529852295_item	3712467	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712468	et	0	cKUAfXynZ
olema	doc_831529852295_item	3712469	et	0	cKUAfXynZ
võimeline	doc_831529852295_item	3712470	et	0	cKUAfXynZ
kasutama	doc_831529852295_item	3712471	et	0	cKUAfXynZ
sõrmelihaseid	doc_831529852295_item	3712472	et	0	cKUAfXynZ
tähesarnaste	doc_831529852295_item	3712473	et	0	cKUAfXynZ
geomeetriliste	doc_831529852295_item	3712474	et	0	cKUAfXynZ
kujundite	doc_831529852295_item	3712475	et	0	cKUAfXynZ
kopeerimisel	doc_831529852295_item	3712476	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712477	et	0	cKUAfXynZ
lapsel	doc_831529852295_item	3712478	et	0	cKUAfXynZ
need	doc_831529852295_item	3712479	et	0	cKUAfXynZ
lihased	doc_831529852295_item	3712480	et	0	cKUAfXynZ
pingutavad	doc_831529852295_item	3712481	et	0	cKUAfXynZ
üle	doc_831529852295_item	3712482	et	0	cKUAfXynZ
võib	doc_831529852295_item	3712483	et	0	cKUAfXynZ
tal	doc_831529852295_item	3712484	et	0	cKUAfXynZ
tekkida	doc_831529852295_item	3712485	et	0	cKUAfXynZ
vastumeelsus	doc_831529852295_item	3712486	et	0	cKUAfXynZ
kirjutamisele	doc_831529852295_item	3712487	et	0	cKUAfXynZ
ei	doc_831529852295_item	3712488	et	0	cKUAfXynZ
tohi	doc_831529852295_item	3712489	et	0	cKUAfXynZ
suunata	doc_831529852295_item	3712490	et	0	cKUAfXynZ
lapsi	doc_831529852295_item	3712491	et	0	cKUAfXynZ
kirjutama	doc_831529852295_item	3712492	et	0	cKUAfXynZ
enne	doc_831529852295_item	3712493	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712494	et	0	cKUAfXynZ
ta	doc_831529852295_item	3712495	et	0	cKUAfXynZ
on	doc_831529852295_item	3712496	et	0	cKUAfXynZ
selleks	doc_831529852295_item	3712497	et	0	cKUAfXynZ
valmis	doc_831529852295_item	3712498	et	0	cKUAfXynZ
sest	doc_831529852295_item	3712499	et	0	cKUAfXynZ
tal	doc_831529852295_item	3712500	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3712501	et	0	cKUAfXynZ
tekkida	doc_831529852295_item	3712502	et	0	cKUAfXynZ
pikaajalised	doc_831529852295_item	3712503	et	0	cKUAfXynZ
probleemid	doc_831529852295_item	3712504	et	0	cKUAfXynZ
käekirjaga	doc_831529852295_item	3712505	et	0	cKUAfXynZ
on	doc_831529852295_item	3712506	et	0	cKUAfXynZ
olemas	doc_831529852295_item	3712507	et	0	cKUAfXynZ
harjutused	doc_831529852295_item	3712508	et	0	cKUAfXynZ
mis	doc_831529852295_item	3712509	et	0	cKUAfXynZ
arendavad	doc_831529852295_item	3712510	et	0	cKUAfXynZ
vastavaid	doc_831529852295_item	3712511	et	0	cKUAfXynZ
lihaseid	doc_831529852295_item	3712512	et	0	cKUAfXynZ
need	doc_831529852295_item	3712513	et	0	cKUAfXynZ
sisaldavad	doc_831529852295_item	3712514	et	0	cKUAfXynZ
palju	doc_831529852295_item	3712515	et	0	cKUAfXynZ
erinevaid	doc_831529852295_item	3712516	et	0	cKUAfXynZ
ülesandeid	doc_831529852295_item	3712517	et	0	cKUAfXynZ
siia	doc_831529852295_item	3712518	et	0	cKUAfXynZ
kuuluvad	doc_831529852295_item	3712519	et	0	cKUAfXynZ
tükimängud	doc_831529852295_item	3712520	et	0	cKUAfXynZ
konstruktoritega	doc_831529852295_item	3712521	et	0	cKUAfXynZ
tegelemine	doc_831529852295_item	3712522	et	0	cKUAfXynZ
nukumööbliga	doc_831529852295_item	3712523	et	0	cKUAfXynZ
mängimine	doc_831529852295_item	3712524	et	0	cKUAfXynZ
on	doc_831529852295_item	3712525	et	0	cKUAfXynZ
kasulik	doc_831529852295_item	3712526	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712527	et	0	cKUAfXynZ
joonistamine	doc_831529852295_item	3712528	et	0	cKUAfXynZ
paberi	doc_831529852295_item	3712529	et	0	cKUAfXynZ
voltimine	doc_831529852295_item	3712530	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712531	et	0	cKUAfXynZ
lõikamine	doc_831529852295_item	3712532	et	0	cKUAfXynZ
soovitakse	doc_831529852295_item	3712533	et	0	cKUAfXynZ
teha	doc_831529852295_item	3712534	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712535	et	0	cKUAfXynZ
käe-	doc_831529852295_item	3712536	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712537	et	0	cKUAfXynZ
silmakordinatsiooni	doc_831529852295_item	3712538	et	0	cKUAfXynZ
ülesandeid	doc_831529852295_item	3712539	et	0	cKUAfXynZ
need	doc_831529852295_item	3712540	et	0	cKUAfXynZ
on	doc_831529852295_item	3712541	et	0	cKUAfXynZ
seotud	doc_831529852295_item	3712542	et	0	cKUAfXynZ
väikeste	doc_831529852295_item	3712543	et	0	cKUAfXynZ
lihaste	doc_831529852295_item	3712544	et	0	cKUAfXynZ
arenguga	doc_831529852295_item	3712545	et	0	cKUAfXynZ
sellised	doc_831529852295_item	3712546	et	0	cKUAfXynZ
ülesanded	doc_831529852295_item	3712547	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3712548	et	0	cKUAfXynZ
olla	doc_831529852295_item	3712549	et	0	cKUAfXynZ
klaveri	doc_831529852295_item	3712550	et	0	cKUAfXynZ
mängimine	doc_831529852295_item	3712551	et	0	cKUAfXynZ
mitmesugused	doc_831529852295_item	3712552	et	0	cKUAfXynZ
paberitööd	doc_831529852295_item	3712553	et	0	cKUAfXynZ
konstruktorimängud	doc_831529852295_item	3712554	et	0	cKUAfXynZ
52	doc_831529852295_item	3712555	et	0	cKUAfXynZ
kirjutamiseks	doc_831529852295_item	3712556	et	0	cKUAfXynZ
valmisolek	doc_831529852295_item	3712557	et	0	cKUAfXynZ
kirjutamisvahendeid	doc_831529852295_item	3712558	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3712559	et	0	cKUAfXynZ
hoida	doc_831529852295_item	3712560	et	0	cKUAfXynZ
õigesti	doc_831529852295_item	3712561	et	0	cKUAfXynZ
on	doc_831529852295_item	3712562	et	0	cKUAfXynZ
teatud	doc_831529852295_item	3712563	et	0	cKUAfXynZ
rida	doc_831529852295_item	3712564	et	0	cKUAfXynZ
asju	doc_831529852295_item	3712565	et	0	cKUAfXynZ
mille	doc_831529852295_item	3712566	et	0	cKUAfXynZ
järgi	doc_831529852295_item	3712567	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3712568	et	0	cKUAfXynZ
saab	doc_831529852295_item	3712569	et	0	cKUAfXynZ
otsustada	doc_831529852295_item	3712570	et	0	cKUAfXynZ
kas	doc_831529852295_item	3712571	et	0	cKUAfXynZ
laps	doc_831529852295_item	3712572	et	0	cKUAfXynZ
hoiab	doc_831529852295_item	3712573	et	0	cKUAfXynZ
õigesti	doc_831529852295_item	3712574	et	0	cKUAfXynZ
vahendit	doc_831529852295_item	3712575	et	0	cKUAfXynZ
või	doc_831529852295_item	3712576	et	0	cKUAfXynZ
mitte	doc_831529852295_item	3712577	et	0	cKUAfXynZ
näiteks	doc_831529852295_item	3712578	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712579	et	0	cKUAfXynZ
paberis	doc_831529852295_item	3712580	et	0	cKUAfXynZ
on	doc_831529852295_item	3712581	et	0	cKUAfXynZ
augud	doc_831529852295_item	3712582	et	0	cKUAfXynZ
siis	doc_831529852295_item	3712583	et	0	cKUAfXynZ
on	doc_831529852295_item	3712584	et	0	cKUAfXynZ
õpilasel	doc_831529852295_item	3712585	et	0	cKUAfXynZ
väär	doc_831529852295_item	3712586	et	0	cKUAfXynZ
vajutustegevus	doc_831529852295_item	3712587	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712588	et	0	cKUAfXynZ
temast	doc_831529852295_item	3712589	et	0	cKUAfXynZ
võib	doc_831529852295_item	3712590	et	0	cKUAfXynZ
tulla	doc_831529852295_item	3712591	et	0	cKUAfXynZ
aeglane	doc_831529852295_item	3712592	et	0	cKUAfXynZ
kirjutaja	doc_831529852295_item	3712593	et	0	cKUAfXynZ
näitajaks	doc_831529852295_item	3712594	et	0	cKUAfXynZ
on	doc_831529852295_item	3712595	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712596	et	0	cKUAfXynZ
kergus	doc_831529852295_item	3712597	et	0	cKUAfXynZ
millega	doc_831529852295_item	3712598	et	0	cKUAfXynZ
saab	doc_831529852295_item	3712599	et	0	cKUAfXynZ
pliiatsit	doc_831529852295_item	3712600	et	0	cKUAfXynZ
kirjutamise	doc_831529852295_item	3712601	et	0	cKUAfXynZ
ajal	doc_831529852295_item	3712602	et	0	cKUAfXynZ
lapse	doc_831529852295_item	3712603	et	0	cKUAfXynZ
käes	doc_831529852295_item	3712604	et	0	cKUAfXynZ
liigutada	doc_831529852295_item	3712605	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712606	et	0	cKUAfXynZ
laps	doc_831529852295_item	3712607	et	0	cKUAfXynZ
hoiab	doc_831529852295_item	3712608	et	0	cKUAfXynZ
pliiatsit	doc_831529852295_item	3712609	et	0	cKUAfXynZ
liiga	doc_831529852295_item	3712610	et	0	cKUAfXynZ
kõvasti	doc_831529852295_item	3712611	et	0	cKUAfXynZ
ta	doc_831529852295_item	3712612	et	0	cKUAfXynZ
pole	doc_831529852295_item	3712613	et	0	cKUAfXynZ
veel	doc_831529852295_item	3712614	et	0	cKUAfXynZ
kirjutamiseks	doc_831529852295_item	3712615	et	0	cKUAfXynZ
valmis	doc_831529852295_item	3712616	et	0	cKUAfXynZ
et	doc_831529852295_item	3712617	et	0	cKUAfXynZ
olla	doc_831529852295_item	3712618	et	0	cKUAfXynZ
valmis	doc_831529852295_item	3712619	et	0	cKUAfXynZ
kirjutamisoskuse	doc_831529852295_item	3712620	et	0	cKUAfXynZ
arendamiseks	doc_831529852295_item	3712621	et	0	cKUAfXynZ
laps	doc_831529852295_item	3712622	et	0	cKUAfXynZ
peab	doc_831529852295_item	3712623	et	0	cKUAfXynZ
oskama	doc_831529852295_item	3712624	et	0	cKUAfXynZ
sujuvalt	doc_831529852295_item	3712625	et	0	cKUAfXynZ
teha	doc_831529852295_item	3712626	et	0	cKUAfXynZ
sirgeid	doc_831529852295_item	3712627	et	0	cKUAfXynZ
jooni	doc_831529852295_item	3712628	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712629	et	0	cKUAfXynZ
ringe	doc_831529852295_item	3712630	et	0	cKUAfXynZ
et	doc_831529852295_item	3712631	et	0	cKUAfXynZ
selle	doc_831529852295_item	3712632	et	0	cKUAfXynZ
oskust	doc_831529852295_item	3712633	et	0	cKUAfXynZ
arendada	doc_831529852295_item	3712634	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3712635	et	0	cKUAfXynZ
anda	doc_831529852295_item	3712636	et	0	cKUAfXynZ
lapsele	doc_831529852295_item	3712637	et	0	cKUAfXynZ
ülesandeid	doc_831529852295_item	3712638	et	0	cKUAfXynZ
kus	doc_831529852295_item	3712639	et	0	cKUAfXynZ
vajatakse	doc_831529852295_item	3712640	et	0	cKUAfXynZ
joonistada	doc_831529852295_item	3712641	et	0	cKUAfXynZ
ei	doc_831529852295_item	3712642	et	0	cKUAfXynZ
tohiks	doc_831529852295_item	3712643	et	0	cKUAfXynZ
unustada	doc_831529852295_item	3712644	et	0	cKUAfXynZ
sellest	doc_831529852295_item	3712645	et	0	cKUAfXynZ
et	doc_831529852295_item	3712646	et	0	cKUAfXynZ
lapsel	doc_831529852295_item	3712647	et	0	cKUAfXynZ
on	doc_831529852295_item	3712648	et	0	cKUAfXynZ
alati	doc_831529852295_item	3712649	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3712650	et	0	cKUAfXynZ
abi	doc_831529852295_item	3712651	et	0	cKUAfXynZ
kätteõpitud	doc_831529852295_item	3712652	et	0	cKUAfXynZ
kindlad	doc_831529852295_item	3712653	et	0	cKUAfXynZ
mudelid	doc_831529852295_item	3712654	et	0	cKUAfXynZ
lihtsustavad	doc_831529852295_item	3712655	et	0	cKUAfXynZ
lapsele	doc_831529852295_item	3712656	et	0	cKUAfXynZ
kirjutamist	doc_831529852295_item	3712657	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3712658	et	0	cKUAfXynZ
seletada	doc_831529852295_item	3712659	et	0	cKUAfXynZ
lapsel	doc_831529852295_item	3712660	et	0	cKUAfXynZ
et	doc_831529852295_item	3712661	et	0	cKUAfXynZ
kirjutamisel	doc_831529852295_item	3712662	et	0	cKUAfXynZ
on	doc_831529852295_item	3712663	et	0	cKUAfXynZ
niisugune	doc_831529852295_item	3712664	et	0	cKUAfXynZ
mõiste	doc_831529852295_item	3712665	et	0	cKUAfXynZ
nagu	doc_831529852295_item	3712666	et	0	cKUAfXynZ
parem	doc_831529852295_item	3712667	et	0	cKUAfXynZ
vasak	doc_831529852295_item	3712668	et	0	cKUAfXynZ
pool	doc_831529852295_item	3712669	et	0	cKUAfXynZ
siin	doc_831529852295_item	3712670	et	0	cKUAfXynZ
võivad	doc_831529852295_item	3712671	et	0	cKUAfXynZ
aidata	doc_831529852295_item	3712672	et	0	cKUAfXynZ
dramaatilised	doc_831529852295_item	3712673	et	0	cKUAfXynZ
mängud	doc_831529852295_item	3712674	et	0	cKUAfXynZ
kus	doc_831529852295_item	3712675	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3712676	et	0	cKUAfXynZ
midagi	doc_831529852295_item	3712677	et	0	cKUAfXynZ
viia	doc_831529852295_item	3712678	et	0	cKUAfXynZ
ehk	doc_831529852295_item	3712679	et	0	cKUAfXynZ
liigutada	doc_831529852295_item	3712680	et	0	cKUAfXynZ
vasakult	doc_831529852295_item	3712681	et	0	cKUAfXynZ
paremale	doc_831529852295_item	3712682	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712683	et	0	cKUAfXynZ
vastupidi	doc_831529852295_item	3712684	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712685	et	0	cKUAfXynZ
anne	doc_831529852295_item	3712686	et	0	cKUAfXynZ
uuseni	doc_831529852295_item	3712687	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3712688	et	0	cKUAfXynZ
pööratakse	doc_831529852295_item	3712689	et	0	cKUAfXynZ
tähelepanu	doc_831529852295_item	3712690	et	0	cKUAfXynZ
et	doc_831529852295_item	3712691	et	0	cKUAfXynZ
kirjutamise	doc_831529852295_item	3712692	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3712693	et	0	cKUAfXynZ
pole	doc_831529852295_item	3712694	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3712695	et	0	cKUAfXynZ
ainult	doc_831529852295_item	3712696	et	0	cKUAfXynZ
protsess	doc_831529852295_item	3712697	et	0	cKUAfXynZ
vaid	doc_831529852295_item	3712698	et	0	cKUAfXynZ
on	doc_831529852295_item	3712699	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712700	et	0	cKUAfXynZ
tulemus	doc_831529852295_item	3712701	et	0	cKUAfXynZ
selline	doc_831529852295_item	3712702	et	0	cKUAfXynZ
tulemus	doc_831529852295_item	3712703	et	0	cKUAfXynZ
on	doc_831529852295_item	3712704	et	0	cKUAfXynZ
sõna	doc_831529852295_item	3712705	et	0	cKUAfXynZ
mingi	doc_831529852295_item	3712706	et	0	cKUAfXynZ
sõnum	doc_831529852295_item	3712707	et	0	cKUAfXynZ
kiri	doc_831529852295_item	3712708	et	0	cKUAfXynZ
või	doc_831529852295_item	3712709	et	0	cKUAfXynZ
esse	doc_831529852295_item	3712710	et	0	cKUAfXynZ
et	doc_831529852295_item	3712711	et	0	cKUAfXynZ
tekst	doc_831529852295_item	3712712	et	0	cKUAfXynZ
oleks	doc_831529852295_item	3712713	et	0	cKUAfXynZ
korrektne	doc_831529852295_item	3712714	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712715	et	0	cKUAfXynZ
loetav	doc_831529852295_item	3712716	et	0	cKUAfXynZ
teistele	doc_831529852295_item	3712717	et	0	cKUAfXynZ
see	doc_831529852295_item	3712718	et	0	cKUAfXynZ
peab	doc_831529852295_item	3712719	et	0	cKUAfXynZ
olema	doc_831529852295_item	3712720	et	0	cKUAfXynZ
õigesti	doc_831529852295_item	3712721	et	0	cKUAfXynZ
grammatiliselt	doc_831529852295_item	3712722	et	0	cKUAfXynZ
kirjutatud	doc_831529852295_item	3712723	et	0	cKUAfXynZ
53	doc_831529852295_item	3712724	et	0	cKUAfXynZ
grammatikaõpetamine	doc_831529852295_item	3712725	et	0	cKUAfXynZ
grammatikat	doc_831529852295_item	3712726	et	0	cKUAfXynZ
saab	doc_831529852295_item	3712727	et	0	cKUAfXynZ
õpetada	doc_831529852295_item	3712728	et	0	cKUAfXynZ
kahte	doc_831529852295_item	3712729	et	0	cKUAfXynZ
meetodi	doc_831529852295_item	3712730	et	0	cKUAfXynZ
varjatult	doc_831529852295_item	3712731	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712732	et	0	cKUAfXynZ
avatult	doc_831529852295_item	3712733	et	0	cKUAfXynZ
esimene	doc_831529852295_item	3712734	et	0	cKUAfXynZ
meetod	doc_831529852295_item	3712735	et	0	cKUAfXynZ
tähendab	doc_831529852295_item	3712736	et	0	cKUAfXynZ
et	doc_831529852295_item	3712737	et	0	cKUAfXynZ
grammatiline	doc_831529852295_item	3712738	et	0	cKUAfXynZ
teema	doc_831529852295_item	3712739	et	0	cKUAfXynZ
on	doc_831529852295_item	3712740	et	0	cKUAfXynZ
peitetud	doc_831529852295_item	3712741	et	0	cKUAfXynZ
õpilased	doc_831529852295_item	3712742	et	0	cKUAfXynZ
teevad	doc_831529852295_item	3712743	et	0	cKUAfXynZ
mingit	doc_831529852295_item	3712744	et	0	cKUAfXynZ
informatiivsert	doc_831529852295_item	3712745	et	0	cKUAfXynZ
tegevust	doc_831529852295_item	3712746	et	0	cKUAfXynZ
kus	doc_831529852295_item	3712747	et	0	cKUAfXynZ
on	doc_831529852295_item	3712748	et	0	cKUAfXynZ
grammatiline	doc_831529852295_item	3712749	et	0	cKUAfXynZ
vorm	doc_831529852295_item	3712750	et	0	cKUAfXynZ
kuid	doc_831529852295_item	3712751	et	0	cKUAfXynZ
nende	doc_831529852295_item	3712752	et	0	cKUAfXynZ
tähelepanu	doc_831529852295_item	3712753	et	0	cKUAfXynZ
pööratakse	doc_831529852295_item	3712754	et	0	cKUAfXynZ
sisule	doc_831529852295_item	3712755	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712756	et	0	cKUAfXynZ
erilist	doc_831529852295_item	3712757	et	0	cKUAfXynZ
grammatika	doc_831529852295_item	3712758	et	0	cKUAfXynZ
fakti	doc_831529852295_item	3712759	et	0	cKUAfXynZ
pole	doc_831529852295_item	3712760	et	0	cKUAfXynZ
vaja	doc_831529852295_item	3712761	et	0	cKUAfXynZ
rõhutada	doc_831529852295_item	3712762	et	0	cKUAfXynZ
siis	doc_831529852295_item	3712763	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3712764	et	0	cKUAfXynZ
võib	doc_831529852295_item	3712765	et	0	cKUAfXynZ
aidata	doc_831529852295_item	3712766	et	0	cKUAfXynZ
lastele	doc_831529852295_item	3712767	et	0	cKUAfXynZ
praktiseerida	doc_831529852295_item	3712768	et	0	cKUAfXynZ
keelt	doc_831529852295_item	3712769	et	0	cKUAfXynZ
nad	doc_831529852295_item	3712770	et	0	cKUAfXynZ
teevad	doc_831529852295_item	3712771	et	0	cKUAfXynZ
seda	doc_831529852295_item	3712772	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712773	et	0	cKUAfXynZ
omandavad	doc_831529852295_item	3712774	et	0	cKUAfXynZ
keelt	doc_831529852295_item	3712775	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712776	et	0	cKUAfXynZ
terviku	doc_831529852295_item	3712777	et	0	cKUAfXynZ
avatud	doc_831529852295_item	3712778	et	0	cKUAfXynZ
grammatika	doc_831529852295_item	3712779	et	0	cKUAfXynZ
õpetamine	doc_831529852295_item	3712780	et	0	cKUAfXynZ
tähendab	doc_831529852295_item	3712781	et	0	cKUAfXynZ
seda	doc_831529852295_item	3712782	et	0	cKUAfXynZ
et	doc_831529852295_item	3712783	et	0	cKUAfXynZ
lastele	doc_831529852295_item	3712784	et	0	cKUAfXynZ
antakse	doc_831529852295_item	3712785	et	0	cKUAfXynZ
otseselt	doc_831529852295_item	3712786	et	0	cKUAfXynZ
grammatikareegli	doc_831529852295_item	3712787	et	0	cKUAfXynZ
või	doc_831529852295_item	3712788	et	0	cKUAfXynZ
seletuse	doc_831529852295_item	3712789	et	0	cKUAfXynZ
arvatakse	doc_831529852295_item	3712790	et	0	cKUAfXynZ
et	doc_831529852295_item	3712791	et	0	cKUAfXynZ
kõige	doc_831529852295_item	3712792	et	0	cKUAfXynZ
edukam	doc_831529852295_item	3712793	et	0	cKUAfXynZ
grammatikaõpetamismeetod	doc_831529852295_item	3712794	et	0	cKUAfXynZ
on	doc_831529852295_item	3712795	et	0	cKUAfXynZ
selline	doc_831529852295_item	3712796	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712797	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3712798	et	0	cKUAfXynZ
loob	doc_831529852295_item	3712799	et	0	cKUAfXynZ
olukordi	doc_831529852295_item	3712800	et	0	cKUAfXynZ
mis	doc_831529852295_item	3712801	et	0	cKUAfXynZ
on	doc_831529852295_item	3712802	et	0	cKUAfXynZ
nagu	doc_831529852295_item	3712803	et	0	cKUAfXynZ
reaalne	doc_831529852295_item	3712804	et	0	cKUAfXynZ
elu	doc_831529852295_item	3712805	et	0	cKUAfXynZ
siis	doc_831529852295_item	3712806	et	0	cKUAfXynZ
lapsel	doc_831529852295_item	3712807	et	0	cKUAfXynZ
on	doc_831529852295_item	3712808	et	0	cKUAfXynZ
kergem	doc_831529852295_item	3712809	et	0	cKUAfXynZ
keelt	doc_831529852295_item	3712810	et	0	cKUAfXynZ
omandada	doc_831529852295_item	3712811	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3712812	et	0	cKUAfXynZ
kasutavad	doc_831529852295_item	3712813	et	0	cKUAfXynZ
keele	doc_831529852295_item	3712814	et	0	cKUAfXynZ
suhtlemiseks	doc_831529852295_item	3712815	et	0	cKUAfXynZ
nagu	doc_831529852295_item	3712816	et	0	cKUAfXynZ
rollimäng	doc_831529852295_item	3712817	et	0	cKUAfXynZ
arutlevad	doc_831529852295_item	3712818	et	0	cKUAfXynZ
mängivad	doc_831529852295_item	3712819	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712820	et	0	cKUAfXynZ
teevad	doc_831529852295_item	3712821	et	0	cKUAfXynZ
projekte	doc_831529852295_item	3712822	et	0	cKUAfXynZ
need	doc_831529852295_item	3712823	et	0	cKUAfXynZ
keeleomandamise	doc_831529852295_item	3712824	et	0	cKUAfXynZ
tegevused	doc_831529852295_item	3712825	et	0	cKUAfXynZ
on	doc_831529852295_item	3712826	et	0	cKUAfXynZ
kommunikatiivsed	doc_831529852295_item	3712827	et	0	cKUAfXynZ
anne	doc_831529852295_item	3712828	et	0	cKUAfXynZ
uuseni	doc_831529852295_item	3712829	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3712830	et	0	cKUAfXynZ
on	doc_831529852295_item	3712831	et	0	cKUAfXynZ
esindatud	doc_831529852295_item	3712832	et	0	cKUAfXynZ
selliste	doc_831529852295_item	3712833	et	0	cKUAfXynZ
tegevuste	doc_831529852295_item	3712834	et	0	cKUAfXynZ
näiteid	doc_831529852295_item	3712835	et	0	cKUAfXynZ
kokkuvõtte	doc_831529852295_item	3712836	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3712837	et	0	cKUAfXynZ
tehakse	doc_831529852295_item	3712838	et	0	cKUAfXynZ
kokkuvõtte	doc_831529852295_item	3712839	et	0	cKUAfXynZ
sellest	doc_831529852295_item	3712840	et	0	cKUAfXynZ
et	doc_831529852295_item	3712841	et	0	cKUAfXynZ
emakeelel	doc_831529852295_item	3712842	et	0	cKUAfXynZ
on	doc_831529852295_item	3712843	et	0	cKUAfXynZ
suur	doc_831529852295_item	3712844	et	0	cKUAfXynZ
roll	doc_831529852295_item	3712845	et	0	cKUAfXynZ
emakeel	doc_831529852295_item	3712846	et	0	cKUAfXynZ
on	doc_831529852295_item	3712847	et	0	cKUAfXynZ
tähtis	doc_831529852295_item	3712848	et	0	cKUAfXynZ
tegur	doc_831529852295_item	3712849	et	0	cKUAfXynZ
õppimises	doc_831529852295_item	3712850	et	0	cKUAfXynZ
kui	doc_831529852295_item	3712851	et	0	cKUAfXynZ
räägitakse	doc_831529852295_item	3712852	et	0	cKUAfXynZ
et	doc_831529852295_item	3712853	et	0	cKUAfXynZ
inimene	doc_831529852295_item	3712854	et	0	cKUAfXynZ
valdab	doc_831529852295_item	3712855	et	0	cKUAfXynZ
keelt	doc_831529852295_item	3712856	et	0	cKUAfXynZ
arvatakse	doc_831529852295_item	3712857	et	0	cKUAfXynZ
et	doc_831529852295_item	3712858	et	0	cKUAfXynZ
ta	doc_831529852295_item	3712859	et	0	cKUAfXynZ
oskab	doc_831529852295_item	3712860	et	0	cKUAfXynZ
kõike	doc_831529852295_item	3712861	et	0	cKUAfXynZ
funktsioone	doc_831529852295_item	3712862	et	0	cKUAfXynZ
need	doc_831529852295_item	3712863	et	0	cKUAfXynZ
on	doc_831529852295_item	3712864	et	0	cKUAfXynZ
kirjutamine	doc_831529852295_item	3712865	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3712866	et	0	cKUAfXynZ
rääkimine	doc_831529852295_item	3712867	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712868	et	0	cKUAfXynZ
kuulamine	doc_831529852295_item	3712869	et	0	cKUAfXynZ
funktsioonide	doc_831529852295_item	3712870	et	0	cKUAfXynZ
arendamine	doc_831529852295_item	3712871	et	0	cKUAfXynZ
oleneb	doc_831529852295_item	3712872	et	0	cKUAfXynZ
mitte	doc_831529852295_item	3712873	et	0	cKUAfXynZ
ainult	doc_831529852295_item	3712874	et	0	cKUAfXynZ
õpilastest	doc_831529852295_item	3712875	et	0	cKUAfXynZ
vaid	doc_831529852295_item	3712876	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712877	et	0	cKUAfXynZ
õpetajast	doc_831529852295_item	3712878	et	0	cKUAfXynZ
anne	doc_831529852295_item	3712879	et	0	cKUAfXynZ
uuseni	doc_831529852295_item	3712880	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3712881	et	0	cKUAfXynZ
kirjutatakse	doc_831529852295_item	3712882	et	0	cKUAfXynZ
et	doc_831529852295_item	3712883	et	0	cKUAfXynZ
lugemikutekstide	doc_831529852295_item	3712884	et	0	cKUAfXynZ
lugemine	doc_831529852295_item	3712885	et	0	cKUAfXynZ
laste	doc_831529852295_item	3712886	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3712887	et	0	cKUAfXynZ
on	doc_831529852295_item	3712888	et	0	cKUAfXynZ
igav	doc_831529852295_item	3712889	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712890	et	0	cKUAfXynZ
ei	doc_831529852295_item	3712891	et	0	cKUAfXynZ
paku	doc_831529852295_item	3712892	et	0	cKUAfXynZ
eriti	doc_831529852295_item	3712893	et	0	cKUAfXynZ
palju	doc_831529852295_item	3712894	et	0	cKUAfXynZ
naudingut	doc_831529852295_item	3712895	et	0	cKUAfXynZ
selliseks	doc_831529852295_item	3712896	et	0	cKUAfXynZ
on	doc_831529852295_item	3712897	et	0	cKUAfXynZ
olemas	doc_831529852295_item	3712898	et	0	cKUAfXynZ
oma	doc_831529852295_item	3712899	et	0	cKUAfXynZ
põhjused	doc_831529852295_item	3712900	et	0	cKUAfXynZ
need	doc_831529852295_item	3712901	et	0	cKUAfXynZ
on	doc_831529852295_item	3712902	et	0	cKUAfXynZ
laste	doc_831529852295_item	3712903	et	0	cKUAfXynZ
emotsionaalsus	doc_831529852295_item	3712904	et	0	cKUAfXynZ
psüühiline	doc_831529852295_item	3712905	et	0	cKUAfXynZ
seisund	doc_831529852295_item	3712906	et	0	cKUAfXynZ
iseloom	doc_831529852295_item	3712907	et	0	cKUAfXynZ
olukord	doc_831529852295_item	3712908	et	0	cKUAfXynZ
peres	doc_831529852295_item	3712909	et	0	cKUAfXynZ
jne	doc_831529852295_item	3712910	et	0	cKUAfXynZ
isegi	doc_831529852295_item	3712911	et	0	cKUAfXynZ
lapse	doc_831529852295_item	3712912	et	0	cKUAfXynZ
käekiri	doc_831529852295_item	3712913	et	0	cKUAfXynZ
oleneb	doc_831529852295_item	3712914	et	0	cKUAfXynZ
sellest	doc_831529852295_item	3712915	et	0	cKUAfXynZ
missugune	doc_831529852295_item	3712916	et	0	cKUAfXynZ
laps	doc_831529852295_item	3712917	et	0	cKUAfXynZ
on	doc_831529852295_item	3712918	et	0	cKUAfXynZ
missugused	doc_831529852295_item	3712919	et	0	cKUAfXynZ
on	doc_831529852295_item	3712920	et	0	cKUAfXynZ
tema	doc_831529852295_item	3712921	et	0	cKUAfXynZ
iseloom	doc_831529852295_item	3712922	et	0	cKUAfXynZ
tuju	doc_831529852295_item	3712923	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712924	et	0	cKUAfXynZ
harjumused	doc_831529852295_item	3712925	et	0	cKUAfXynZ
kuna	doc_831529852295_item	3712926	et	0	cKUAfXynZ
kõik	doc_831529852295_item	3712927	et	0	cKUAfXynZ
lapsed	doc_831529852295_item	3712928	et	0	cKUAfXynZ
on	doc_831529852295_item	3712929	et	0	cKUAfXynZ
erinevad	doc_831529852295_item	3712930	et	0	cKUAfXynZ
nad	doc_831529852295_item	3712931	et	0	cKUAfXynZ
nõuavad	doc_831529852295_item	3712932	et	0	cKUAfXynZ
erinevat	doc_831529852295_item	3712933	et	0	cKUAfXynZ
õpetamist	doc_831529852295_item	3712934	et	0	cKUAfXynZ
õpetamismeetodeid	doc_831529852295_item	3712935	et	0	cKUAfXynZ
on	doc_831529852295_item	3712936	et	0	cKUAfXynZ
palju	doc_831529852295_item	3712937	et	0	cKUAfXynZ
aga	doc_831529852295_item	3712938	et	0	cKUAfXynZ
mõnikord	doc_831529852295_item	3712939	et	0	cKUAfXynZ
õpetaja	doc_831529852295_item	3712940	et	0	cKUAfXynZ
jaoks	doc_831529852295_item	3712941	et	0	cKUAfXynZ
on	doc_831529852295_item	3712942	et	0	cKUAfXynZ
raske	doc_831529852295_item	3712943	et	0	cKUAfXynZ
valida	doc_831529852295_item	3712944	et	0	cKUAfXynZ
missugust	doc_831529852295_item	3712945	et	0	cKUAfXynZ
tuleb	doc_831529852295_item	3712946	et	0	cKUAfXynZ
rakendada	doc_831529852295_item	3712947	et	0	cKUAfXynZ
anne	doc_831529852295_item	3712948	et	0	cKUAfXynZ
uusen	doc_831529852295_item	3712949	et	0	cKUAfXynZ
pakub	doc_831529852295_item	3712950	et	0	cKUAfXynZ
palju	doc_831529852295_item	3712951	et	0	cKUAfXynZ
erinevaid	doc_831529852295_item	3712952	et	0	cKUAfXynZ
ülesandeid	doc_831529852295_item	3712953	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3712954	et	0	cKUAfXynZ
kogunenud	doc_831529852295_item	3712955	et	0	cKUAfXynZ
materjal	doc_831529852295_item	3712956	et	0	cKUAfXynZ
jutustab	doc_831529852295_item	3712957	et	0	cKUAfXynZ
lastest	doc_831529852295_item	3712958	et	0	cKUAfXynZ
õpetamisest	doc_831529852295_item	3712959	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712960	et	0	cKUAfXynZ
näitab	doc_831529852295_item	3712961	et	0	cKUAfXynZ
kuidas	doc_831529852295_item	3712962	et	0	cKUAfXynZ
võib	doc_831529852295_item	3712963	et	0	cKUAfXynZ
teadmisi	doc_831529852295_item	3712964	et	0	cKUAfXynZ
rakendada	doc_831529852295_item	3712965	et	0	cKUAfXynZ
raamatus	doc_831529852295_item	3712966	et	0	cKUAfXynZ
sisaldatakse	doc_831529852295_item	3712967	et	0	cKUAfXynZ
palju	doc_831529852295_item	3712968	et	0	cKUAfXynZ
näiteid	doc_831529852295_item	3712969	et	0	cKUAfXynZ
ja	doc_831529852295_item	3712970	et	0	cKUAfXynZ
ideed	doc_831529852295_item	3712971	et	0	cKUAfXynZ
sellised	doc_831529852295_item	3712972	et	0	cKUAfXynZ
teadmised	doc_831529852295_item	3712973	et	0	cKUAfXynZ
lähevad	doc_831529852295_item	3712974	et	0	cKUAfXynZ
kasuks	doc_831529852295_item	3712975	et	0	cKUAfXynZ
ka	doc_831529852295_item	3712976	et	0	cKUAfXynZ
tööl	doc_831529852295_item	3712977	et	0	cKUAfXynZ
lastega	doc_831529852295_item	3712978	et	0	cKUAfXynZ
kasutatud	doc_831529852295_item	3712979	et	0	cKUAfXynZ
kirjandus	doc_831529852295_item	3712980	et	0	cKUAfXynZ
uusen	doc_831529852295_item	3712981	et	0	cKUAfXynZ
anne	doc_831529852295_item	3712982	et	0	cKUAfXynZ
2002	doc_831529852295_item	3712983	et	0	cKUAfXynZ
emakeele	doc_831529852295_item	3712984	et	0	cKUAfXynZ
õpetamisest	doc_831529852295_item	3712985	et	0	cKUAfXynZ
tallinn	doc_831529852295_item	3712986	et	0	cKUAfXynZ
tpü	doc_831529852295_item	3712987	et	0	cKUAfXynZ
kirjastus	doc_831529852295_item	3712988	et	0	cKUAfXynZ
149	doc_831529852295_item	3712989	et	0	cKUAfXynZ
lk	doc_831529852295_item	3712990	et	0	cKUAfXynZ
essee	doc_881412446072_item	3712991	et	0	main
minu	doc_881412446072_item	3712992	et	0	main
ökoelu	doc_881412446072_item	3712993	et	0	main
tänapäeval	doc_881412446072_item	3712994	et	0	main
me	doc_881412446072_item	3712995	et	0	main
elame	doc_881412446072_item	3712996	et	0	main
niisuguses	doc_881412446072_item	3712997	et	0	main
maailmas	doc_881412446072_item	3712998	et	0	main
kus	doc_881412446072_item	3712999	et	0	main
valitseb	doc_881412446072_item	3713000	et	0	main
tehniline	doc_881412446072_item	3713001	et	0	main
progress	doc_881412446072_item	3713002	et	0	main
ja	doc_881412446072_item	3713003	et	0	main
tihti	doc_881412446072_item	3713004	et	0	main
juhtub	doc_881412446072_item	3713005	et	0	main
nii	doc_881412446072_item	3713006	et	0	main
et	doc_881412446072_item	3713007	et	0	main
see	doc_881412446072_item	3713008	et	0	main
toob	doc_881412446072_item	3713009	et	0	main
nii	doc_881412446072_item	3713010	et	0	main
inimkonnale	doc_881412446072_item	3713011	et	0	main
kui	doc_881412446072_item	3713012	et	0	main
ka	doc_881412446072_item	3713013	et	0	main
keskkonnale	doc_881412446072_item	3713014	et	0	main
kahju	doc_881412446072_item	3713015	et	0	main
tööstuse	doc_881412446072_item	3713016	et	0	main
liiga	doc_881412446072_item	3713017	et	0	main
dünaamilise	doc_881412446072_item	3713018	et	0	main
arengu	doc_881412446072_item	3713019	et	0	main
tõttu	doc_881412446072_item	3713020	et	0	main
tekkivad	doc_881412446072_item	3713021	et	0	main
probleemid	doc_881412446072_item	3713022	et	0	main
seotud	doc_881412446072_item	3713023	et	0	main
looduse	doc_881412446072_item	3713024	et	0	main
reostamisega	doc_881412446072_item	3713025	et	0	main
kus	doc_881412446072_item	3713026	et	0	main
on	doc_881412446072_item	3713027	et	0	main
meie	doc_881412446072_item	3713028	et	0	main
keskkonnateadlikkus	doc_881412446072_item	3713029	et	0	main
mina	doc_881412446072_item	3713030	et	0	main
olen	doc_881412446072_item	3713031	et	0	main
veendumusel	doc_881412446072_item	3713032	et	0	main
et	doc_881412446072_item	3713033	et	0	main
keskkonnasäästamine	doc_881412446072_item	3713034	et	0	main
algab	doc_881412446072_item	3713035	et	0	main
meie	doc_881412446072_item	3713036	et	0	main
ökoelust	doc_881412446072_item	3713037	et	0	main
keskkonnasaastamine	doc_881412446072_item	3713038	et	0	main
on	doc_881412446072_item	3713039	et	0	main
globaalne	doc_881412446072_item	3713040	et	0	main
probleem	doc_881412446072_item	3713041	et	0	main
sellepärast	doc_881412446072_item	3713042	et	0	main
kõik	doc_881412446072_item	3713043	et	0	main
inimesed	doc_881412446072_item	3713044	et	0	main
peaks	doc_881412446072_item	3713045	et	0	main
seda	doc_881412446072_item	3713046	et	0	main
koos	doc_881412446072_item	3713047	et	0	main
lahendama	doc_881412446072_item	3713048	et	0	main
mitte	doc_881412446072_item	3713049	et	0	main
kõik	doc_881412446072_item	3713050	et	0	main
teavad	doc_881412446072_item	3713051	et	0	main
et	doc_881412446072_item	3713052	et	0	main
kinni	doc_881412446072_item	3713053	et	0	main
tehtud	doc_881412446072_item	3713054	et	0	main
hammaste	doc_881412446072_item	3713055	et	0	main
harjamise	doc_881412446072_item	3713056	et	0	main
ajaks	doc_881412446072_item	3713057	et	0	main
kraan	doc_881412446072_item	3713058	et	0	main
säästab	doc_881412446072_item	3713059	et	0	main
päevas	doc_881412446072_item	3713060	et	0	main
15	doc_881412446072_item	3713061	et	0	main
kuni	doc_881412446072_item	3713062	et	0	main
20	doc_881412446072_item	3713063	et	0	main
liitrit	doc_881412446072_item	3713064	et	0	main
vett	doc_881412446072_item	3713065	et	0	main
vaipu	doc_881412446072_item	3713066	et	0	main
tuleks	doc_881412446072_item	3713067	et	0	main
kloppida	doc_881412446072_item	3713068	et	0	main
õues	doc_881412446072_item	3713069	et	0	main
sest	doc_881412446072_item	3713070	et	0	main
tolmuimeja	doc_881412446072_item	3713071	et	0	main
võtab	doc_881412446072_item	3713072	et	0	main
sama	doc_881412446072_item	3713073	et	0	main
palju	doc_881412446072_item	3713074	et	0	main
energiat	doc_881412446072_item	3713075	et	0	main
kui	doc_881412446072_item	3713076	et	0	main
elektripliit	doc_881412446072_item	3713077	et	0	main
mina	doc_881412446072_item	3713078	et	0	main
ise	doc_881412446072_item	3713079	et	0	main
teen	doc_881412446072_item	3713080	et	0	main
ka	doc_881412446072_item	3713081	et	0	main
teisi	doc_881412446072_item	3713082	et	0	main
asju	doc_881412446072_item	3713083	et	0	main
näiteks	doc_881412446072_item	3713084	et	0	main
lasen	doc_881412446072_item	3713085	et	0	main
päikesel	doc_881412446072_item	3713086	et	0	main
aknast	doc_881412446072_item	3713087	et	0	main
sisse	doc_881412446072_item	3713088	et	0	main
paista	doc_881412446072_item	3713089	et	0	main
sest	doc_881412446072_item	3713090	et	0	main
see	doc_881412446072_item	3713091	et	0	main
hoiab	doc_881412446072_item	3713092	et	0	main
kütet	doc_881412446072_item	3713093	et	0	main
kokku	doc_881412446072_item	3713094	et	0	main
nõude	doc_881412446072_item	3713095	et	0	main
pesemisel	doc_881412446072_item	3713096	et	0	main
täidan	doc_881412446072_item	3713097	et	0	main
kraanikauss	doc_881412446072_item	3713098	et	0	main
veega	doc_881412446072_item	3713099	et	0	main
ja	doc_881412446072_item	3713100	et	0	main
väldi	doc_881412446072_item	3713101	et	0	main
jooksva	doc_881412446072_item	3713102	et	0	main
vee	doc_881412446072_item	3713103	et	0	main
all	doc_881412446072_item	3713104	et	0	main
nõude	doc_881412446072_item	3713105	et	0	main
pesemist	doc_881412446072_item	3713106	et	0	main
toiduvalmistamisel	doc_881412446072_item	3713107	et	0	main
panen	doc_881412446072_item	3713108	et	0	main
potile	doc_881412446072_item	3713109	et	0	main
kaas	doc_881412446072_item	3713110	et	0	main
peale	doc_881412446072_item	3713111	et	0	main
sest	doc_881412446072_item	3713112	et	0	main
see	doc_881412446072_item	3713113	et	0	main
säästab	doc_881412446072_item	3713114	et	0	main
energiat	doc_881412446072_item	3713115	et	0	main
kasutan	doc_881412446072_item	3713116	et	0	main
kotti	doc_881412446072_item	3713117	et	0	main
prügi	doc_881412446072_item	3713118	et	0	main
korjamiseks	doc_881412446072_item	3713119	et	0	main
tõmban	doc_881412446072_item	3713120	et	0	main
öösel	doc_881412446072_item	3713121	et	0	main
akendele	doc_881412446072_item	3713122	et	0	main
kardinad	doc_881412446072_item	3713123	et	0	main
ette	doc_881412446072_item	3713124	et	0	main
sest	doc_881412446072_item	3713125	et	0	main
see	doc_881412446072_item	3713126	et	0	main
hoiab	doc_881412446072_item	3713127	et	0	main
kütet	doc_881412446072_item	3713128	et	0	main
kokku	doc_881412446072_item	3713129	et	0	main
lülitan	doc_881412446072_item	3713130	et	0	main
pliit	doc_881412446072_item	3713131	et	0	main
peer	doc_881412446072_item	3713132	et	0	main
minutit	doc_881412446072_item	3713133	et	0	main
enne	doc_881412446072_item	3713134	et	0	main
toidu	doc_881412446072_item	3713135	et	0	main
lõplikku	doc_881412446072_item	3713136	et	0	main
valmimist	doc_881412446072_item	3713137	et	0	main
välja	doc_881412446072_item	3713138	et	0	main
eelistan	doc_881412446072_item	3713139	et	0	main
osta	doc_881412446072_item	3713140	et	0	main
kaupa	doc_881412446072_item	3713141	et	0	main
suurtes	doc_881412446072_item	3713142	et	0	main
pakkides	doc_881412446072_item	3713143	et	0	main
mitme	doc_881412446072_item	3713144	et	0	main
väikese	doc_881412446072_item	3713145	et	0	main
asemel	doc_881412446072_item	3713146	et	0	main
mina	doc_881412446072_item	3713147	et	0	main
kunagi	doc_881412446072_item	3713148	et	0	main
ei	doc_881412446072_item	3713149	et	0	main
vaska	doc_881412446072_item	3713150	et	0	main
prügi	doc_881412446072_item	3713151	et	0	main
maha	doc_881412446072_item	3713152	et	0	main
alati	doc_881412446072_item	3713153	et	0	main
viskan	doc_881412446072_item	3713154	et	0	main
prügi	doc_881412446072_item	3713155	et	0	main
ambrisse	doc_881412446072_item	3713156	et	0	main
aga	doc_881412446072_item	3713157	et	0	main
kui	doc_881412446072_item	3713158	et	0	main
prügikasti	doc_881412446072_item	3713159	et	0	main
lähedel	doc_881412446072_item	3713160	et	0	main
ei	doc_881412446072_item	3713161	et	0	main
ole	doc_881412446072_item	3713162	et	0	main
siis	doc_881412446072_item	3713163	et	0	main
mina	doc_881412446072_item	3713164	et	0	main
panen	doc_881412446072_item	3713165	et	0	main
prügi	doc_881412446072_item	3713166	et	0	main
tasku	doc_881412446072_item	3713167	et	0	main
plast-	doc_881412446072_item	3713168	et	0	main
ja	doc_881412446072_item	3713169	et	0	main
klaaspudelid	doc_881412446072_item	3713170	et	0	main
aga	doc_881412446072_item	3713171	et	0	main
toon	doc_881412446072_item	3713172	et	0	main
tarapunkti	doc_881412446072_item	3713173	et	0	main
kui	doc_881412446072_item	3713174	et	0	main
on	doc_881412446072_item	3713175	et	0	main
vaja	doc_881412446072_item	3713176	et	0	main
kusagile	doc_881412446072_item	3713177	et	0	main
sõita	doc_881412446072_item	3713178	et	0	main
siis	doc_881412446072_item	3713179	et	0	main
sõidan	doc_881412446072_item	3713180	et	0	main
bussi	doc_881412446072_item	3713181	et	0	main
või	doc_881412446072_item	3713182	et	0	main
trammiga	doc_881412446072_item	3713183	et	0	main
suvel	doc_881412446072_item	3713184	et	0	main
aga	doc_881412446072_item	3713185	et	0	main
sõidan	doc_881412446072_item	3713186	et	0	main
jalgrattaga	doc_881412446072_item	3713187	et	0	main
mina	doc_881412446072_item	3713188	et	0	main
olen	doc_881412446072_item	3713189	et	0	main
seisukohal	doc_881412446072_item	3713190	et	0	main
et	doc_881412446072_item	3713191	et	0	main
kõik	doc_881412446072_item	3713192	et	0	main
algab	doc_881412446072_item	3713193	et	0	main
inimese	doc_881412446072_item	3713194	et	0	main
kultuuritasendist	doc_881412446072_item	3713195	et	0	main
ma	doc_881412446072_item	3713196	et	0	main
pean	doc_881412446072_item	3713197	et	0	main
silmas	doc_881412446072_item	3713198	et	0	main
et	doc_881412446072_item	3713199	et	0	main
inimene	doc_881412446072_item	3713200	et	0	main
kes	doc_881412446072_item	3713201	et	0	main
peab	doc_881412446072_item	3713202	et	0	main
lugu	doc_881412446072_item	3713203	et	0	main
loodust	doc_881412446072_item	3713204	et	0	main
siis	doc_881412446072_item	3713205	et	0	main
ta	doc_881412446072_item	3713206	et	0	main
ei	doc_881412446072_item	3713207	et	0	main
reosta	doc_881412446072_item	3713208	et	0	main
keskkonda	doc_881412446072_item	3713209	et	0	main
on	doc_881412446072_item	3713210	et	0	main
otstarbekam	doc_881412446072_item	3713211	et	0	main
kasutada	doc_881412446072_item	3713212	et	0	main
katalüsaatoriga	doc_881412446072_item	3713213	et	0	main
auto	doc_881412446072_item	3713214	et	0	main
sest	doc_881412446072_item	3713215	et	0	main
see	doc_881412446072_item	3713216	et	0	main
aitab	doc_881412446072_item	3713217	et	0	main
kütusekulutust	doc_881412446072_item	3713218	et	0	main
vähendada	doc_881412446072_item	3713219	et	0	main
järelikult	doc_881412446072_item	3713220	et	0	main
see	doc_881412446072_item	3713221	et	0	main
toob	doc_881412446072_item	3713222	et	0	main
vähem	doc_881412446072_item	3713223	et	0	main
kahju	doc_881412446072_item	3713224	et	0	main
praeguseks	doc_881412446072_item	3713225	et	0	main
on	doc_881412446072_item	3713226	et	0	main
odavam	doc_881412446072_item	3713227	et	0	main
kasutada	doc_881412446072_item	3713228	et	0	main
gaasi-	doc_881412446072_item	3713229	et	0	main
või	doc_881412446072_item	3713230	et	0	main
elektriauto	doc_881412446072_item	3713231	et	0	main
muidugi	doc_881412446072_item	3713232	et	0	main
on	doc_881412446072_item	3713233	et	0	main
aktuaalsem	doc_881412446072_item	3713234	et	0	main
arendada	doc_881412446072_item	3713235	et	0	main
taastuvaid	doc_881412446072_item	3713236	et	0	main
energiaallikaid	doc_881412446072_item	3713237	et	0	main
nagu	doc_881412446072_item	3713238	et	0	main
päikese-	doc_881412446072_item	3713239	et	0	main
tuule-	doc_881412446072_item	3713240	et	0	main
ja	doc_881412446072_item	3713241	et	0	main
hüdroenergiat	doc_881412446072_item	3713242	et	0	main
geotermaalenenergia	doc_881412446072_item	3713243	et	0	main
suuremad	doc_881412446072_item	3713244	et	0	main
maailmariigid	doc_881412446072_item	3713245	et	0	main
ratifitseerivad	doc_881412446072_item	3713246	et	0	main
erinevaid	doc_881412446072_item	3713247	et	0	main
rahvusvaheliseid	doc_881412446072_item	3713248	et	0	main
kollektiivlepinguid	doc_881412446072_item	3713249	et	0	main
et	doc_881412446072_item	3713250	et	0	main
lahendada	doc_881412446072_item	3713251	et	0	main
kõige	doc_881412446072_item	3713252	et	0	main
põletavamaid	doc_881412446072_item	3713253	et	0	main
probleeme	doc_881412446072_item	3713254	et	0	main
nende	doc_881412446072_item	3713255	et	0	main
hulgas	doc_881412446072_item	3713256	et	0	main
on	doc_881412446072_item	3713257	et	0	main
kliima	doc_881412446072_item	3713258	et	0	main
soojenemine	doc_881412446072_item	3713259	et	0	main
hapevihmad	doc_881412446072_item	3713260	et	0	main
osoonikihi	doc_881412446072_item	3713261	et	0	main
hõrenemine	doc_881412446072_item	3713262	et	0	main
mullaviljakuse	doc_881412446072_item	3713263	et	0	main
langus	doc_881412446072_item	3713264	et	0	main
bioloogilise	doc_881412446072_item	3713265	et	0	main
mitmekesisuse	doc_881412446072_item	3713266	et	0	main
vähenemine	doc_881412446072_item	3713267	et	0	main
ja	doc_881412446072_item	3713268	et	0	main
ökoloogiline	doc_881412446072_item	3713269	et	0	main
kriis	doc_881412446072_item	3713270	et	0	main
mina	doc_881412446072_item	3713271	et	0	main
eelistan	doc_881412446072_item	3713272	et	0	main
osta	doc_881412446072_item	3713273	et	0	main
eesti	doc_881412446072_item	3713274	et	0	main
mahetooteid	doc_881412446072_item	3713275	et	0	main
kuna	doc_881412446072_item	3713276	et	0	main
kaupade	doc_881412446072_item	3713277	et	0	main
valik	doc_881412446072_item	3713278	et	0	main
järg-järgult	doc_881412446072_item	3713279	et	0	main
laiendab	doc_881412446072_item	3713280	et	0	main
suured	doc_881412446072_item	3713281	et	0	main
kaubanduskeskused	doc_881412446072_item	3713282	et	0	main
annavad	doc_881412446072_item	3713283	et	0	main
välja	doc_881412446072_item	3713284	et	0	main
katalooge	doc_881412446072_item	3713285	et	0	main
sisseostmeid	doc_881412446072_item	3713286	et	0	main
tehets	doc_881412446072_item	3713287	et	0	main
mina	doc_881412446072_item	3713288	et	0	main
kasutan	doc_881412446072_item	3713289	et	0	main
neid	doc_881412446072_item	3713290	et	0	main
ja	doc_881412446072_item	3713291	et	0	main
valin	doc_881412446072_item	3713292	et	0	main
ainult	doc_881412446072_item	3713293	et	0	main
terviselesõbralikud	doc_881412446072_item	3713294	et	0	main
kaupu	doc_881412446072_item	3713295	et	0	main
lõpetades	doc_881412446072_item	3713296	et	0	main
mina	doc_881412446072_item	3713297	et	0	main
tahaks	doc_881412446072_item	3713298	et	0	main
eriti	doc_881412446072_item	3713299	et	0	main
rõhutada	doc_881412446072_item	3713300	et	0	main
et	doc_881412446072_item	3713301	et	0	main
iga	doc_881412446072_item	3713302	et	0	main
meist	doc_881412446072_item	3713303	et	0	main
on	doc_881412446072_item	3713304	et	0	main
suuteline	doc_881412446072_item	3713305	et	0	main
teha	doc_881412446072_item	3713306	et	0	main
midagi	doc_881412446072_item	3713307	et	0	main
et	doc_881412446072_item	3713308	et	0	main
keskkonna	doc_881412446072_item	3713309	et	0	main
kaitsta	doc_881412446072_item	3713310	et	0	main
sest	doc_881412446072_item	3713311	et	0	main
iga	doc_881412446072_item	3713312	et	0	main
väike	doc_881412446072_item	3713313	et	0	main
samm	doc_881412446072_item	3713314	et	0	main
see	doc_881412446072_item	3713315	et	0	main
on	doc_881412446072_item	3713316	et	0	main
samm	doc_881412446072_item	3713317	et	0	main
ühiskonna	doc_881412446072_item	3713318	et	0	main
globaalse	doc_881412446072_item	3713319	et	0	main
probleemi	doc_881412446072_item	3713320	et	0	main
lahendamise	doc_881412446072_item	3713321	et	0	main
suunas	doc_881412446072_item	3713322	et	0	main
analüüs	doc_491521501755_item	3713323	et	0	main
tallinna	doc_491521501755_item	3713324	et	0	main
pedagoogikaülikool	doc_491521501755_item	3713325	et	0	main
eesnimi	doc_491521501755_item	3713326	et	0	main
perekonnanimi	doc_491521501755_item	3713327	et	0	main
veaanalüüs	doc_491521501755_item	3713328	et	0	main
tallinn	doc_491521501755_item	3713329	et	0	main
2001	doc_491521501755_item	3713330	et	0	main
sissejuhatus	doc_491521501755_item	3713331	et	0	main
käesolevas	doc_491521501755_item	3713332	et	0	main
töös	doc_491521501755_item	3713333	et	0	main
esitatakse	doc_491521501755_item	3713334	et	0	main
eesti	doc_491521501755_item	3713335	et	0	main
keele	doc_491521501755_item	3713336	et	0	main
hälbiva	doc_491521501755_item	3713337	et	0	main
kasutuse	doc_491521501755_item	3713338	et	0	main
näiteid	doc_491521501755_item	3713339	et	0	main
veaanalüüsi	doc_491521501755_item	3713340	et	0	main
materjal	doc_491521501755_item	3713341	et	0	main
on	doc_491521501755_item	3713342	et	0	main
võetud	doc_491521501755_item	3713343	et	0	main
keelekursustel	doc_491521501755_item	3713344	et	0	main
kogutud	doc_491521501755_item	3713345	et	0	main
kirjalikest	doc_491521501755_item	3713346	et	0	main
tekstidest	doc_491521501755_item	3713347	et	0	main
kirjanditest	doc_491521501755_item	3713348	et	0	main
etteütlustest	doc_491521501755_item	3713349	et	0	main
uurimisrühma	doc_491521501755_item	3713350	et	0	main
kuuluvad	doc_491521501755_item	3713351	et	0	main
vene	doc_491521501755_item	3713352	et	0	main
emakeelega	doc_491521501755_item	3713353	et	0	main
15	doc_491521501755_item	3713354	et	0	main
16-aastased	doc_491521501755_item	3713355	et	0	main
õpilased	doc_491521501755_item	3713356	et	0	main
käivad	doc_491521501755_item	3713357	et	0	main
eesti	doc_491521501755_item	3713358	et	0	main
keele	doc_491521501755_item	3713359	et	0	main
kursustel	doc_491521501755_item	3713360	et	0	main
esimest	doc_491521501755_item	3713361	et	0	main
aastat	doc_491521501755_item	3713362	et	0	main
enne	doc_491521501755_item	3713363	et	0	main
keelekursustele	doc_491521501755_item	3713364	et	0	main
minekut	doc_491521501755_item	3713365	et	0	main
õppisid	doc_491521501755_item	3713366	et	0	main
nad	doc_491521501755_item	3713367	et	0	main
eesti	doc_491521501755_item	3713368	et	0	main
keelt	doc_491521501755_item	3713369	et	0	main
koolis	doc_491521501755_item	3713370	et	0	main
7	doc_491521501755_item	3713371	et	0	main
aastat	doc_491521501755_item	3713372	et	0	main
tuleb	doc_491521501755_item	3713373	et	0	main
rõhutada	doc_491521501755_item	3713374	et	0	main
seda	doc_491521501755_item	3713375	et	0	main
et	doc_491521501755_item	3713376	et	0	main
eesti	doc_491521501755_item	3713377	et	0	main
keele	doc_491521501755_item	3713378	et	0	main
õppimine	doc_491521501755_item	3713379	et	0	main
koolis	doc_491521501755_item	3713380	et	0	main
erineb	doc_491521501755_item	3713381	et	0	main
väga	doc_491521501755_item	3713382	et	0	main
tugevasti	doc_491521501755_item	3713383	et	0	main
õppimisest	doc_491521501755_item	3713384	et	0	main
keelekursustel	doc_491521501755_item	3713385	et	0	main
nii	doc_491521501755_item	3713386	et	0	main
et	doc_491521501755_item	3713387	et	0	main
vaatamata	doc_491521501755_item	3713388	et	0	main
sellele	doc_491521501755_item	3713389	et	0	main
et	doc_491521501755_item	3713390	et	0	main
uurimisrühma	doc_491521501755_item	3713391	et	0	main
õppijad	doc_491521501755_item	3713392	et	0	main
on	doc_491521501755_item	3713393	et	0	main
õppinud	doc_491521501755_item	3713394	et	0	main
eesti	doc_491521501755_item	3713395	et	0	main
keelt	doc_491521501755_item	3713396	et	0	main
juba	doc_491521501755_item	3713397	et	0	main
üsna	doc_491521501755_item	3713398	et	0	main
pikka	doc_491521501755_item	3713399	et	0	main
aega	doc_491521501755_item	3713400	et	0	main
on	doc_491521501755_item	3713401	et	0	main
nende	doc_491521501755_item	3713402	et	0	main
keeleoskus	doc_491521501755_item	3713403	et	0	main
ikkagi	doc_491521501755_item	3713404	et	0	main
nõrk	doc_491521501755_item	3713405	et	0	main
nagu	doc_491521501755_item	3713406	et	0	main
praktika	doc_491521501755_item	3713407	et	0	main
näitab	doc_491521501755_item	3713408	et	0	main
hakkab	doc_491521501755_item	3713409	et	0	main
keeleoskuse	doc_491521501755_item	3713410	et	0	main
tase	doc_491521501755_item	3713411	et	0	main
märkimisväärselt	doc_491521501755_item	3713412	et	0	main
paranema	doc_491521501755_item	3713413	et	0	main
alles	doc_491521501755_item	3713414	et	0	main
keelekursustel	doc_491521501755_item	3713415	et	0	main
keelekursuste	doc_491521501755_item	3713416	et	0	main
põhilisteks	doc_491521501755_item	3713417	et	0	main
eelisteks	doc_491521501755_item	3713418	et	0	main
võib	doc_491521501755_item	3713419	et	0	main
nimetada	doc_491521501755_item	3713420	et	0	main
seda	doc_491521501755_item	3713421	et	0	main
et	doc_491521501755_item	3713422	et	0	main
igale	doc_491521501755_item	3713423	et	0	main
õpilasele	doc_491521501755_item	3713424	et	0	main
pühendatakse	doc_491521501755_item	3713425	et	0	main
rohkem	doc_491521501755_item	3713426	et	0	main
tähelepanu	doc_491521501755_item	3713427	et	0	main
on	doc_491521501755_item	3713428	et	0	main
rohkem	doc_491521501755_item	3713429	et	0	main
võimalusi	doc_491521501755_item	3713430	et	0	main
sihtkeelt	doc_491521501755_item	3713431	et	0	main
aktiivselt	doc_491521501755_item	3713432	et	0	main
kasutada	doc_491521501755_item	3713433	et	0	main
toimub	doc_491521501755_item	3713434	et	0	main
suhtlemine	doc_491521501755_item	3713435	et	0	main
sihtkeeles	doc_491521501755_item	3713436	et	0	main
antakse	doc_491521501755_item	3713437	et	0	main
rohkem	doc_491521501755_item	3713438	et	0	main
loovaid	doc_491521501755_item	3713439	et	0	main
kirjalikke	doc_491521501755_item	3713440	et	0	main
ülesandeid	doc_491521501755_item	3713441	et	0	main
õpilasel	doc_491521501755_item	3713442	et	0	main
on	doc_491521501755_item	3713443	et	0	main
rohkem	doc_491521501755_item	3713444	et	0	main
võimalusi	doc_491521501755_item	3713445	et	0	main
arendada	doc_491521501755_item	3713446	et	0	main
oma	doc_491521501755_item	3713447	et	0	main
keeleoskust	doc_491521501755_item	3713448	et	0	main
õpilaste	doc_491521501755_item	3713449	et	0	main
motivatsioon	doc_491521501755_item	3713450	et	0	main
on	doc_491521501755_item	3713451	et	0	main
kõrgem	doc_491521501755_item	3713452	et	0	main
kursustel	doc_491521501755_item	3713453	et	0	main
ei	doc_491521501755_item	3713454	et	0	main
panda	doc_491521501755_item	3713455	et	0	main
hindeid	doc_491521501755_item	3713456	et	0	main
sellepärast	doc_491521501755_item	3713457	et	0	main
ei	doc_491521501755_item	3713458	et	0	main
karda	doc_491521501755_item	3713459	et	0	main
ka	doc_491521501755_item	3713460	et	0	main
õpilased	doc_491521501755_item	3713461	et	0	main
vigu	doc_491521501755_item	3713462	et	0	main
teha	doc_491521501755_item	3713463	et	0	main
ei	doc_491521501755_item	3713464	et	0	main
püüa	doc_491521501755_item	3713465	et	0	main
kahtlastest	doc_491521501755_item	3713466	et	0	main
vormidest	doc_491521501755_item	3713467	et	0	main
kõrvale	doc_491521501755_item	3713468	et	0	main
hiilida	doc_491521501755_item	3713469	et	0	main
ülalmainitud	doc_491521501755_item	3713470	et	0	main
põhjustel	doc_491521501755_item	3713471	et	0	main
sobib	doc_491521501755_item	3713472	et	0	main
veaanalüüsiks	doc_491521501755_item	3713473	et	0	main
paremini	doc_491521501755_item	3713474	et	0	main
just	doc_491521501755_item	3713475	et	0	main
keelekursustel	doc_491521501755_item	3713476	et	0	main
kogutud	doc_491521501755_item	3713477	et	0	main
materjal	doc_491521501755_item	3713478	et	0	main
käesolevas	doc_491521501755_item	3713479	et	0	main
töös	doc_491521501755_item	3713480	et	0	main
analüüsitakse	doc_491521501755_item	3713481	et	0	main
tekstides	doc_491521501755_item	3713482	et	0	main
korduvate	doc_491521501755_item	3713483	et	0	main
tüüpiliste	doc_491521501755_item	3713484	et	0	main
vigade	doc_491521501755_item	3713485	et	0	main
näiteid	doc_491521501755_item	3713486	et	0	main
ortograafilised	doc_491521501755_item	3713487	et	0	main
vead	doc_491521501755_item	3713488	et	0	main
viljandis	doc_491521501755_item	3713489	et	0	main
on	doc_491521501755_item	3713490	et	0	main
teatr	doc_491521501755_item	3713491	et	0	main
viga	doc_491521501755_item	3713492	et	0	main
on	doc_491521501755_item	3713493	et	0	main
tingitud	doc_491521501755_item	3713494	et	0	main
emakeele	doc_491521501755_item	3713495	et	0	main
mõjust	doc_491521501755_item	3713496	et	0	main
vene	doc_491521501755_item	3713497	et	0	main
keeles	doc_491521501755_item	3713498	et	0	main
sõna	doc_491521501755_item	3713499	et	0	main
театр	doc_491521501755_item	3713500	et	0	main
kõlab	doc_491521501755_item	3713501	et	0	main
eesti	doc_491521501755_item	3713502	et	0	main
sõnaga	doc_491521501755_item	3713503	et	0	main
teater	doc_491521501755_item	3713504	et	0	main
sarnaselt	doc_491521501755_item	3713505	et	0	main
kuid	doc_491521501755_item	3713506	et	0	main
kirjapilt	doc_491521501755_item	3713507	et	0	main
on	doc_491521501755_item	3713508	et	0	main
erinev	doc_491521501755_item	3713509	et	0	main
mul	doc_491521501755_item	3713510	et	0	main
on	doc_491521501755_item	3713511	et	0	main
tume	doc_491521501755_item	3713512	et	0	main
sirge	doc_491521501755_item	3713513	et	0	main
lühike	doc_491521501755_item	3713514	et	0	main
juksed	doc_491521501755_item	3713515	et	0	main
ja	doc_491521501755_item	3713516	et	0	main
nöps	doc_491521501755_item	3713517	et	0	main
nina	doc_491521501755_item	3713518	et	0	main
antud	doc_491521501755_item	3713519	et	0	main
lauses	doc_491521501755_item	3713520	et	0	main
esineb	doc_491521501755_item	3713521	et	0	main
mitu	doc_491521501755_item	3713522	et	0	main
eri	doc_491521501755_item	3713523	et	0	main
liiki	doc_491521501755_item	3713524	et	0	main
viga	doc_491521501755_item	3713525	et	0	main
1	doc_491521501755_item	3713526	et	0	main
ühildumisviga	doc_491521501755_item	3713527	et	0	main
mis	doc_491521501755_item	3713528	et	0	main
ei	doc_491521501755_item	3713529	et	0	main
ole	doc_491521501755_item	3713530	et	0	main
tingitud	doc_491521501755_item	3713531	et	0	main
emakeelest	doc_491521501755_item	3713532	et	0	main
vaid	doc_491521501755_item	3713533	et	0	main
pigem	doc_491521501755_item	3713534	et	0	main
tähelepanematusest	doc_491521501755_item	3713535	et	0	main
2	doc_491521501755_item	3713536	et	0	main
pika	doc_491521501755_item	3713537	et	0	main
uu	doc_491521501755_item	3713538	et	0	main
asemel	doc_491521501755_item	3713539	et	0	main
on	doc_491521501755_item	3713540	et	0	main
kasutatud	doc_491521501755_item	3713541	et	0	main
lühike	doc_491521501755_item	3713542	et	0	main
u	doc_491521501755_item	3713543	et	0	main
vene	doc_491521501755_item	3713544	et	0	main
emakeelega	doc_491521501755_item	3713545	et	0	main
õppijal	doc_491521501755_item	3713546	et	0	main
on	doc_491521501755_item	3713547	et	0	main
raske	doc_491521501755_item	3713548	et	0	main
neid	doc_491521501755_item	3713549	et	0	main
eristada	doc_491521501755_item	3713550	et	0	main
kuna	doc_491521501755_item	3713551	et	0	main
vene	doc_491521501755_item	3713552	et	0	main
keeles	doc_491521501755_item	3713553	et	0	main
on	doc_491521501755_item	3713554	et	0	main
kõik	doc_491521501755_item	3713555	et	0	main
häälikud	doc_491521501755_item	3713556	et	0	main
pikkuselt	doc_491521501755_item	3713557	et	0	main
ühesugused	doc_491521501755_item	3713558	et	0	main
3	doc_491521501755_item	3713559	et	0	main
ortograafiline	doc_491521501755_item	3713560	et	0	main
viga	doc_491521501755_item	3713561	et	0	main
sõna	doc_491521501755_item	3713562	et	0	main
kokkukirjutamises	doc_491521501755_item	3713563	et	0	main
mis	doc_491521501755_item	3713564	et	0	main
on	doc_491521501755_item	3713565	et	0	main
tingitud	doc_491521501755_item	3713566	et	0	main
emakeelest	doc_491521501755_item	3713567	et	0	main
kuna	doc_491521501755_item	3713568	et	0	main
venekeelne	doc_491521501755_item	3713569	et	0	main
vaste	doc_491521501755_item	3713570	et	0	main
курносый	doc_491521501755_item	3713571	et	0	main
нос	doc_491521501755_item	3713572	et	0	main
on	doc_491521501755_item	3713573	et	0	main
kahest	doc_491521501755_item	3713574	et	0	main
sõnast	doc_491521501755_item	3713575	et	0	main
koosnev	doc_491521501755_item	3713576	et	0	main
sõnaühend	doc_491521501755_item	3713577	et	0	main
jääniööl	doc_491521501755_item	3713578	et	0	main
tehakse	doc_491521501755_item	3713579	et	0	main
jäänituld	doc_491521501755_item	3713580	et	0	main
viga	doc_491521501755_item	3713581	et	0	main
seisneb	doc_491521501755_item	3713582	et	0	main
vale	doc_491521501755_item	3713583	et	0	main
tähe	doc_491521501755_item	3713584	et	0	main
kirjutamises	doc_491521501755_item	3713585	et	0	main
a	doc_491521501755_item	3713586	et	0	main
asemel	doc_491521501755_item	3713587	et	0	main
on	doc_491521501755_item	3713588	et	0	main
kirjutatud	doc_491521501755_item	3713589	et	0	main
täht	doc_491521501755_item	3713590	et	0	main
ä	doc_491521501755_item	3713591	et	0	main
vene	doc_491521501755_item	3713592	et	0	main
emakeelega	doc_491521501755_item	3713593	et	0	main
õppija	doc_491521501755_item	3713594	et	0	main
ei	doc_491521501755_item	3713595	et	0	main
tee	doc_491521501755_item	3713596	et	0	main
tihtipeale	doc_491521501755_item	3713597	et	0	main
vahet	doc_491521501755_item	3713598	et	0	main
nende	doc_491521501755_item	3713599	et	0	main
tähtede	doc_491521501755_item	3713600	et	0	main
vahel	doc_491521501755_item	3713601	et	0	main
kuna	doc_491521501755_item	3713602	et	0	main
vene	doc_491521501755_item	3713603	et	0	main
keeles	doc_491521501755_item	3713604	et	0	main
täppidega	doc_491521501755_item	3713605	et	0	main
tähti	doc_491521501755_item	3713606	et	0	main
ei	doc_491521501755_item	3713607	et	0	main
ole	doc_491521501755_item	3713608	et	0	main
need	doc_491521501755_item	3713609	et	0	main
inimesed	doc_491521501755_item	3713610	et	0	main
kes	doc_491521501755_item	3713611	et	0	main
keelduvad	doc_491521501755_item	3713612	et	0	main
trahvimaksmast	doc_491521501755_item	3713613	et	0	main
peavad	doc_491521501755_item	3713614	et	0	main
järgmisest	doc_491521501755_item	3713615	et	0	main
peatusest	doc_491521501755_item	3713616	et	0	main
ühis	doc_491521501755_item	3713617	et	0	main
sõidukis	doc_491521501755_item	3713618	et	0	main
väljuma	doc_491521501755_item	3713619	et	0	main
antud	doc_491521501755_item	3713620	et	0	main
lauses	doc_491521501755_item	3713621	et	0	main
on	doc_491521501755_item	3713622	et	0	main
tegemist	doc_491521501755_item	3713623	et	0	main
mitme	doc_491521501755_item	3713624	et	0	main
eri	doc_491521501755_item	3713625	et	0	main
liiki	doc_491521501755_item	3713626	et	0	main
veaga	doc_491521501755_item	3713627	et	0	main
1	doc_491521501755_item	3713628	et	0	main
sõna	doc_491521501755_item	3713629	et	0	main
kokku-ja	doc_491521501755_item	3713630	et	0	main
lahkukirjutamises	doc_491521501755_item	3713631	et	0	main
kaks	doc_491521501755_item	3713632	et	0	main
viga	doc_491521501755_item	3713633	et	0	main
mis	doc_491521501755_item	3713634	et	0	main
on	doc_491521501755_item	3713635	et	0	main
mõlemad	doc_491521501755_item	3713636	et	0	main
põhjustatud	doc_491521501755_item	3713637	et	0	main
emakeele	doc_491521501755_item	3713638	et	0	main
mõjust	doc_491521501755_item	3713639	et	0	main
keelduvad	doc_491521501755_item	3713640	et	0	main
trahvi	doc_491521501755_item	3713641	et	0	main
maksmast	doc_491521501755_item	3713642	et	0	main
venekeelne	doc_491521501755_item	3713643	et	0	main
vaste	doc_491521501755_item	3713644	et	0	main
on	doc_491521501755_item	3713645	et	0	main
отказываются	doc_491521501755_item	3713646	et	0	main
от	doc_491521501755_item	3713647	et	0	main
штрафа	doc_491521501755_item	3713648	et	0	main
üks	doc_491521501755_item	3713649	et	0	main
sõna	doc_491521501755_item	3713650	et	0	main
ühissõiduk	doc_491521501755_item	3713651	et	0	main
venekeelne	doc_491521501755_item	3713652	et	0	main
vaste	doc_491521501755_item	3713653	et	0	main
on	doc_491521501755_item	3713654	et	0	main
общественный	doc_491521501755_item	3713655	et	0	main
транспорт	doc_491521501755_item	3713656	et	0	main
kaks	doc_491521501755_item	3713657	et	0	main
sõna	doc_491521501755_item	3713658	et	0	main
2	doc_491521501755_item	3713659	et	0	main
kolm	doc_491521501755_item	3713660	et	0	main
käändeviga	doc_491521501755_item	3713661	et	0	main
järgmisest	doc_491521501755_item	3713662	et	0	main
peatusest	doc_491521501755_item	3713663	et	0	main
sõidukis	doc_491521501755_item	3713664	et	0	main
väljuma	doc_491521501755_item	3713665	et	0	main
seestütlev	doc_491521501755_item	3713666	et	0	main
ja	doc_491521501755_item	3713667	et	0	main
seesütlev	doc_491521501755_item	3713668	et	0	main
on	doc_491521501755_item	3713669	et	0	main
segi	doc_491521501755_item	3713670	et	0	main
aetud	doc_491521501755_item	3713671	et	0	main
peaks	doc_491521501755_item	3713672	et	0	main
olema	doc_491521501755_item	3713673	et	0	main
vastupidi	doc_491521501755_item	3713674	et	0	main
järgmises	doc_491521501755_item	3713675	et	0	main
peatuses	doc_491521501755_item	3713676	et	0	main
sõidukist	doc_491521501755_item	3713677	et	0	main
väljuma	doc_491521501755_item	3713678	et	0	main
käändevead	doc_491521501755_item	3713679	et	0	main
kohakäänete	doc_491521501755_item	3713680	et	0	main
vead	doc_491521501755_item	3713681	et	0	main
me	doc_491521501755_item	3713682	et	0	main
jalutasime	doc_491521501755_item	3713683	et	0	main
pargus	doc_491521501755_item	3713684	et	0	main
siin	doc_491521501755_item	3713685	et	0	main
on	doc_491521501755_item	3713686	et	0	main
valesti	doc_491521501755_item	3713687	et	0	main
moodustatud	doc_491521501755_item	3713688	et	0	main
omastav	doc_491521501755_item	3713689	et	0	main
kääne	doc_491521501755_item	3713690	et	0	main
siit	doc_491521501755_item	3713691	et	0	main
tuleneb	doc_491521501755_item	3713692	et	0	main
ka	doc_491521501755_item	3713693	et	0	main
vale	doc_491521501755_item	3713694	et	0	main
seesütleva	doc_491521501755_item	3713695	et	0	main
vorm	doc_491521501755_item	3713696	et	0	main
viga	doc_491521501755_item	3713697	et	0	main
võib	doc_491521501755_item	3713698	et	0	main
olla	doc_491521501755_item	3713699	et	0	main
põhjustatud	doc_491521501755_item	3713700	et	0	main
ka	doc_491521501755_item	3713701	et	0	main
emakeele	doc_491521501755_item	3713702	et	0	main
mõjust	doc_491521501755_item	3713703	et	0	main
venekeelne	doc_491521501755_item	3713704	et	0	main
u	doc_491521501755_item	3713705	et	0	main
ja	doc_491521501755_item	3713706	et	0	main
eestikeelne	doc_491521501755_item	3713707	et	0	main
i	doc_491521501755_item	3713708	et	0	main
on	doc_491521501755_item	3713709	et	0	main
segi	doc_491521501755_item	3713710	et	0	main
aetud	doc_491521501755_item	3713711	et	0	main
pane	doc_491521501755_item	3713712	et	0	main
hamstrid	doc_491521501755_item	3713713	et	0	main
purgis	doc_491521501755_item	3713714	et	0	main
viga	doc_491521501755_item	3713715	et	0	main
seisneb	doc_491521501755_item	3713716	et	0	main
vale	doc_491521501755_item	3713717	et	0	main
käände	doc_491521501755_item	3713718	et	0	main
valikus	doc_491521501755_item	3713719	et	0	main
sisseütleva	doc_491521501755_item	3713720	et	0	main
asemel	doc_491521501755_item	3713721	et	0	main
seesütlev	doc_491521501755_item	3713722	et	0	main
kass	doc_491521501755_item	3713723	et	0	main
istub	doc_491521501755_item	3713724	et	0	main
trepis	doc_491521501755_item	3713725	et	0	main
viga	doc_491521501755_item	3713726	et	0	main
on	doc_491521501755_item	3713727	et	0	main
tingitud	doc_491521501755_item	3713728	et	0	main
välis-	doc_491521501755_item	3713729	et	0	main
ja	doc_491521501755_item	3713730	et	0	main
sisekohakäänete	doc_491521501755_item	3713731	et	0	main
segiajamisest	doc_491521501755_item	3713732	et	0	main
tegemist	doc_491521501755_item	3713733	et	0	main
on	doc_491521501755_item	3713734	et	0	main
tüüpilise	doc_491521501755_item	3713735	et	0	main
veaga	doc_491521501755_item	3713736	et	0	main
mida	doc_491521501755_item	3713737	et	0	main
teevad	doc_491521501755_item	3713738	et	0	main
õppijad	doc_491521501755_item	3713739	et	0	main
orienteerudes	doc_491521501755_item	3713740	et	0	main
küsimuse	doc_491521501755_item	3713741	et	0	main
lõpule	doc_491521501755_item	3713742	et	0	main
milline	doc_491521501755_item	3713743	et	0	main
lõpp	doc_491521501755_item	3713744	et	0	main
on	doc_491521501755_item	3713745	et	0	main
küsimusel	doc_491521501755_item	3713746	et	0	main
samasugune	doc_491521501755_item	3713747	et	0	main
lõpp	doc_491521501755_item	3713748	et	0	main
peab	doc_491521501755_item	3713749	et	0	main
olema	doc_491521501755_item	3713750	et	0	main
ka	doc_491521501755_item	3713751	et	0	main
vastusel	doc_491521501755_item	3713752	et	0	main
antud	doc_491521501755_item	3713753	et	0	main
juhul	doc_491521501755_item	3713754	et	0	main
vormi	doc_491521501755_item	3713755	et	0	main
trepis	doc_491521501755_item	3713756	et	0	main
moodustamisel	doc_491521501755_item	3713757	et	0	main
oli	doc_491521501755_item	3713758	et	0	main
lähtealuseks	doc_491521501755_item	3713759	et	0	main
küsimus	doc_491521501755_item	3713760	et	0	main
kus	doc_491521501755_item	3713761	et	0	main
muud	doc_491521501755_item	3713762	et	0	main
käändevead	doc_491521501755_item	3713763	et	0	main
kaks	doc_491521501755_item	3713764	et	0	main
märgi	doc_491521501755_item	3713765	et	0	main
kaks	doc_491521501755_item	3713766	et	0	main
kleebi	doc_491521501755_item	3713767	et	0	main
viga	doc_491521501755_item	3713768	et	0	main
seisneb	doc_491521501755_item	3713769	et	0	main
vale	doc_491521501755_item	3713770	et	0	main
käände	doc_491521501755_item	3713771	et	0	main
valikus	doc_491521501755_item	3713772	et	0	main
osastava	doc_491521501755_item	3713773	et	0	main
asemel	doc_491521501755_item	3713774	et	0	main
omastav	doc_491521501755_item	3713775	et	0	main
sõna	doc_491521501755_item	3713776	et	0	main
kleebi	doc_491521501755_item	3713777	et	0	main
puhul	doc_491521501755_item	3713778	et	0	main
on	doc_491521501755_item	3713779	et	0	main
tegemist	doc_491521501755_item	3713780	et	0	main
ka	doc_491521501755_item	3713781	et	0	main
vale	doc_491521501755_item	3713782	et	0	main
vormi	doc_491521501755_item	3713783	et	0	main
moodustusega	doc_491521501755_item	3713784	et	0	main
õppija	doc_491521501755_item	3713785	et	0	main
ei	doc_491521501755_item	3713786	et	0	main
osanud	doc_491521501755_item	3713787	et	0	main
käänata	doc_491521501755_item	3713788	et	0	main
sõna	doc_491521501755_item	3713789	et	0	main
kleebis	doc_491521501755_item	3713790	et	0	main
ja	doc_491521501755_item	3713791	et	0	main
mõtles	doc_491521501755_item	3713792	et	0	main
oma	doc_491521501755_item	3713793	et	0	main
vormi	doc_491521501755_item	3713794	et	0	main
välja	doc_491521501755_item	3713795	et	0	main
minu	doc_491521501755_item	3713796	et	0	main
ema	doc_491521501755_item	3713797	et	0	main
oleb	doc_491521501755_item	3713798	et	0	main
õpetajaks	doc_491521501755_item	3713799	et	0	main
suureks	doc_491521501755_item	3713800	et	0	main
linnakoolis	doc_491521501755_item	3713801	et	0	main
antud	doc_491521501755_item	3713802	et	0	main
lauses	doc_491521501755_item	3713803	et	0	main
esineb	doc_491521501755_item	3713804	et	0	main
mitu	doc_491521501755_item	3713805	et	0	main
eri	doc_491521501755_item	3713806	et	0	main
liiki	doc_491521501755_item	3713807	et	0	main
viga	doc_491521501755_item	3713808	et	0	main
1	doc_491521501755_item	3713809	et	0	main
verbivormi	doc_491521501755_item	3713810	et	0	main
moodustusviga	doc_491521501755_item	3713811	et	0	main
verbivorm	doc_491521501755_item	3713812	et	0	main
oleb	doc_491521501755_item	3713813	et	0	main
on	doc_491521501755_item	3713814	et	0	main
moodustatud	doc_491521501755_item	3713815	et	0	main
grammatika	doc_491521501755_item	3713816	et	0	main
reeglite	doc_491521501755_item	3713817	et	0	main
alusel	doc_491521501755_item	3713818	et	0	main
ole	doc_491521501755_item	3713819	et	0	main
ma	doc_491521501755_item	3713820	et	0	main
3	doc_491521501755_item	3713821	et	0	main
isiku	doc_491521501755_item	3713822	et	0	main
tunnus	doc_491521501755_item	3713823	et	0	main
b	doc_491521501755_item	3713824	et	0	main
2	doc_491521501755_item	3713825	et	0	main
käändeviga	doc_491521501755_item	3713826	et	0	main
õpetajaks	doc_491521501755_item	3713827	et	0	main
on	doc_491521501755_item	3713828	et	0	main
tingitud	doc_491521501755_item	3713829	et	0	main
emakeele	doc_491521501755_item	3713830	et	0	main
mõjust	doc_491521501755_item	3713831	et	0	main
otsetõlge	doc_491521501755_item	3713832	et	0	main
vene	doc_491521501755_item	3713833	et	0	main
keelest	doc_491521501755_item	3713834	et	0	main
является	doc_491521501755_item	3713835	et	0	main
кем	doc_491521501755_item	3713836	et	0	main
учителем	doc_491521501755_item	3713837	et	0	main
3	doc_491521501755_item	3713838	et	0	main
ühildumisviga	doc_491521501755_item	3713839	et	0	main
suureks	doc_491521501755_item	3713840	et	0	main
linnakoolis	doc_491521501755_item	3713841	et	0	main
on	doc_491521501755_item	3713842	et	0	main
põhjustatud	doc_491521501755_item	3713843	et	0	main
eelmise	doc_491521501755_item	3713844	et	0	main
sõna	doc_491521501755_item	3713845	et	0	main
mõjust	doc_491521501755_item	3713846	et	0	main
tähelepanematusest	doc_491521501755_item	3713847	et	0	main
on	doc_491521501755_item	3713848	et	0	main
see	doc_491521501755_item	3713849	et	0	main
ühildatud	doc_491521501755_item	3713850	et	0	main
eelmise	doc_491521501755_item	3713851	et	0	main
sõnaga	doc_491521501755_item	3713852	et	0	main
õpetajaks	doc_491521501755_item	3713853	et	0	main
verbivormide	doc_491521501755_item	3713854	et	0	main
moodustusvead	doc_491521501755_item	3713855	et	0	main
samuti	doc_491521501755_item	3713856	et	0	main
arvatatakse	doc_491521501755_item	3713857	et	0	main
et	doc_491521501755_item	3713858	et	0	main
ei	doc_491521501755_item	3713859	et	0	main
tohi	doc_491521501755_item	3713860	et	0	main
väljuda	doc_491521501755_item	3713861	et	0	main
kodust	doc_491521501755_item	3713862	et	0	main
ilma	doc_491521501755_item	3713863	et	0	main
rahata	doc_491521501755_item	3713864	et	0	main
viga	doc_491521501755_item	3713865	et	0	main
on	doc_491521501755_item	3713866	et	0	main
tehtud	doc_491521501755_item	3713867	et	0	main
umbisikulise	doc_491521501755_item	3713868	et	0	main
tegumoe	doc_491521501755_item	3713869	et	0	main
moodustamisel	doc_491521501755_item	3713870	et	0	main
umbisikulise	doc_491521501755_item	3713871	et	0	main
tegumoe	doc_491521501755_item	3713872	et	0	main
tunnus	doc_491521501755_item	3713873	et	0	main
takse	doc_491521501755_item	3713874	et	0	main
on	doc_491521501755_item	3713875	et	0	main
lisatud	doc_491521501755_item	3713876	et	0	main
da-infinitiivi	doc_491521501755_item	3713877	et	0	main
vormi	doc_491521501755_item	3713878	et	0	main
lõpule	doc_491521501755_item	3713879	et	0	main
jõuluajal	doc_491521501755_item	3713880	et	0	main
süütakse	doc_491521501755_item	3713881	et	0	main
küünlaid	doc_491521501755_item	3713882	et	0	main
süüdatakse	doc_491521501755_item	3713883	et	0	main
viga	doc_491521501755_item	3713884	et	0	main
on	doc_491521501755_item	3713885	et	0	main
tehtud	doc_491521501755_item	3713886	et	0	main
umbisikulise	doc_491521501755_item	3713887	et	0	main
tegumoe	doc_491521501755_item	3713888	et	0	main
moodustamisel	doc_491521501755_item	3713889	et	0	main
ilmselt	doc_491521501755_item	3713890	et	0	main
on	doc_491521501755_item	3713891	et	0	main
tegemist	doc_491521501755_item	3713892	et	0	main
oma	doc_491521501755_item	3713893	et	0	main
väljamõeldud	doc_491521501755_item	3713894	et	0	main
vormiga	doc_491521501755_item	3713895	et	0	main
kõike	doc_491521501755_item	3713896	et	0	main
ei	doc_491521501755_item	3713897	et	0	main
ole	doc_491521501755_item	3713898	et	0	main
võimalik	doc_491521501755_item	3713899	et	0	main
ülelugeda	doc_491521501755_item	3713900	et	0	main
üles	doc_491521501755_item	3713901	et	0	main
lugeda	doc_491521501755_item	3713902	et	0	main
viga	doc_491521501755_item	3713903	et	0	main
on	doc_491521501755_item	3713904	et	0	main
tehtud	doc_491521501755_item	3713905	et	0	main
ühendverbi	doc_491521501755_item	3713906	et	0	main
moodustamisel	doc_491521501755_item	3713907	et	0	main
viga	doc_491521501755_item	3713908	et	0	main
on	doc_491521501755_item	3713909	et	0	main
põhjustatud	doc_491521501755_item	3713910	et	0	main
emakeele	doc_491521501755_item	3713911	et	0	main
mõjust	doc_491521501755_item	3713912	et	0	main
antud	doc_491521501755_item	3713913	et	0	main
juhul	doc_491521501755_item	3713914	et	0	main
oleks	doc_491521501755_item	3713915	et	0	main
eestikeelse	doc_491521501755_item	3713916	et	0	main
ühendverbi	doc_491521501755_item	3713917	et	0	main
koostisosa	doc_491521501755_item	3713918	et	0	main
üles	doc_491521501755_item	3713919	et	0	main
venekeelseks	doc_491521501755_item	3713920	et	0	main
vasteks	doc_491521501755_item	3713921	et	0	main
prefiks	doc_491521501755_item	3713922	et	0	main
nepe-	doc_491521501755_item	3713923	et	0	main
mida	doc_491521501755_item	3713924	et	0	main
kirjutatakse	doc_491521501755_item	3713925	et	0	main
põhisõnaga	doc_491521501755_item	3713926	et	0	main
kokku	doc_491521501755_item	3713927	et	0	main
пересчитать	doc_491521501755_item	3713928	et	0	main
verbivormide	doc_491521501755_item	3713929	et	0	main
valiku	doc_491521501755_item	3713930	et	0	main
vead	doc_491521501755_item	3713931	et	0	main
ma	doc_491521501755_item	3713932	et	0	main
on	doc_491521501755_item	3713933	et	0	main
nõus	doc_491521501755_item	3713934	et	0	main
viga	doc_491521501755_item	3713935	et	0	main
seisneb	doc_491521501755_item	3713936	et	0	main
verbi	doc_491521501755_item	3713937	et	0	main
olema	doc_491521501755_item	3713938	et	0	main
vale	doc_491521501755_item	3713939	et	0	main
vormi	doc_491521501755_item	3713940	et	0	main
valikus	doc_491521501755_item	3713941	et	0	main
samas	doc_491521501755_item	3713942	et	0	main
on	doc_491521501755_item	3713943	et	0	main
tegemist	doc_491521501755_item	3713944	et	0	main
ka	doc_491521501755_item	3713945	et	0	main
ühildumisveaga	doc_491521501755_item	3713946	et	0	main
alus	doc_491521501755_item	3713947	et	0	main
ja	doc_491521501755_item	3713948	et	0	main
öeldis	doc_491521501755_item	3713949	et	0	main
ei	doc_491521501755_item	3713950	et	0	main
ühildu	doc_491521501755_item	3713951	et	0	main
isikus	doc_491521501755_item	3713952	et	0	main
täna	doc_491521501755_item	3713953	et	0	main
mul	doc_491521501755_item	3713954	et	0	main
kuus	doc_491521501755_item	3713955	et	0	main
tundi	doc_491521501755_item	3713956	et	0	main
verb	doc_491521501755_item	3713957	et	0	main
olema	doc_491521501755_item	3713958	et	0	main
on	doc_491521501755_item	3713959	et	0	main
vahele	doc_491521501755_item	3713960	et	0	main
jäetud	doc_491521501755_item	3713961	et	0	main
viga	doc_491521501755_item	3713962	et	0	main
on	doc_491521501755_item	3713963	et	0	main
tingitud	doc_491521501755_item	3713964	et	0	main
emakeele	doc_491521501755_item	3713965	et	0	main
mõjust	doc_491521501755_item	3713966	et	0	main
vene	doc_491521501755_item	3713967	et	0	main
keeles	doc_491521501755_item	3713968	et	0	main
ei	doc_491521501755_item	3713969	et	0	main
ole	doc_491521501755_item	3713970	et	0	main
sellele	doc_491521501755_item	3713971	et	0	main
verbile	doc_491521501755_item	3713972	et	0	main
vastet	doc_491521501755_item	3713973	et	0	main
ning	doc_491521501755_item	3713974	et	0	main
otsetõlkes	doc_491521501755_item	3713975	et	0	main
kõlab	doc_491521501755_item	3713976	et	0	main
antud	doc_491521501755_item	3713977	et	0	main
lause	doc_491521501755_item	3713978	et	0	main
järgmiselt	doc_491521501755_item	3713979	et	0	main
сегодня	doc_491521501755_item	3713980	et	0	main
у	doc_491521501755_item	3713981	et	0	main
меня	doc_491521501755_item	3713982	et	0	main
шесть	doc_491521501755_item	3713983	et	0	main
уроков	doc_491521501755_item	3713984	et	0	main
koolis	doc_491521501755_item	3713985	et	0	main
me	doc_491521501755_item	3713986	et	0	main
läheme	doc_491521501755_item	3713987	et	0	main
õues	doc_491521501755_item	3713988	et	0	main
ja	doc_491521501755_item	3713989	et	0	main
seal	doc_491521501755_item	3713990	et	0	main
mängime	doc_491521501755_item	3713991	et	0	main
antud	doc_491521501755_item	3713992	et	0	main
lauses	doc_491521501755_item	3713993	et	0	main
esineb	doc_491521501755_item	3713994	et	0	main
vale	doc_491521501755_item	3713995	et	0	main
verb	doc_491521501755_item	3713996	et	0	main
läheme	doc_491521501755_item	3713997	et	0	main
selle	doc_491521501755_item	3713998	et	0	main
asemel	doc_491521501755_item	3713999	et	0	main
peaks	doc_491521501755_item	3714000	et	0	main
olema	doc_491521501755_item	3714001	et	0	main
verb	doc_491521501755_item	3714002	et	0	main
käime	doc_491521501755_item	3714003	et	0	main
õppija	doc_491521501755_item	3714004	et	0	main
ei	doc_491521501755_item	3714005	et	0	main
teinud	doc_491521501755_item	3714006	et	0	main
vahet	doc_491521501755_item	3714007	et	0	main
nende	doc_491521501755_item	3714008	et	0	main
verbide	doc_491521501755_item	3714009	et	0	main
tähenduste	doc_491521501755_item	3714010	et	0	main
vahel	doc_491521501755_item	3714011	et	0	main
kusjuures	doc_491521501755_item	3714012	et	0	main
ka	doc_491521501755_item	3714013	et	0	main
vene	doc_491521501755_item	3714014	et	0	main
keeles	doc_491521501755_item	3714015	et	0	main
on	doc_491521501755_item	3714016	et	0	main
käima	doc_491521501755_item	3714017	et	0	main
ходить	doc_491521501755_item	3714018	et	0	main
ja	doc_491521501755_item	3714019	et	0	main
minema	doc_491521501755_item	3714020	et	0	main
идти	doc_491521501755_item	3714021	et	0	main
kaks	doc_491521501755_item	3714022	et	0	main
erinevat	doc_491521501755_item	3714023	et	0	main
mõistet	doc_491521501755_item	3714024	et	0	main
vead	doc_491521501755_item	3714025	et	0	main
ma-	doc_491521501755_item	3714026	et	0	main
da-infinitiivi	doc_491521501755_item	3714027	et	0	main
kasutuses	doc_491521501755_item	3714028	et	0	main
nad	doc_491521501755_item	3714029	et	0	main
ei	doc_491521501755_item	3714030	et	0	main
armasta	doc_491521501755_item	3714031	et	0	main
lugema	doc_491521501755_item	3714032	et	0	main
ma-	doc_491521501755_item	3714033	et	0	main
ja	doc_491521501755_item	3714034	et	0	main
da-infinitiiv	doc_491521501755_item	3714035	et	0	main
on	doc_491521501755_item	3714036	et	0	main
segi	doc_491521501755_item	3714037	et	0	main
aetud	doc_491521501755_item	3714038	et	0	main
kuna	doc_491521501755_item	3714039	et	0	main
vene	doc_491521501755_item	3714040	et	0	main
keeles	doc_491521501755_item	3714041	et	0	main
on	doc_491521501755_item	3714042	et	0	main
ainult	doc_491521501755_item	3714043	et	0	main
üks	doc_491521501755_item	3714044	et	0	main
verbi	doc_491521501755_item	3714045	et	0	main
infinitiiv	doc_491521501755_item	3714046	et	0	main
eesti	doc_491521501755_item	3714047	et	0	main
keeles	doc_491521501755_item	3714048	et	0	main
on	doc_491521501755_item	3714049	et	0	main
aga	doc_491521501755_item	3714050	et	0	main
kaks	doc_491521501755_item	3714051	et	0	main
siis	doc_491521501755_item	3714052	et	0	main
eksitakse	doc_491521501755_item	3714053	et	0	main
nende	doc_491521501755_item	3714054	et	0	main
eristamisel	doc_491521501755_item	3714055	et	0	main
väga	doc_491521501755_item	3714056	et	0	main
sageli	doc_491521501755_item	3714057	et	0	main
mõtlesin	doc_491521501755_item	3714058	et	0	main
kaua	doc_491521501755_item	3714059	et	0	main
kuidas	doc_491521501755_item	3714060	et	0	main
lähema	doc_491521501755_item	3714061	et	0	main
antud	doc_491521501755_item	3714062	et	0	main
juhul	doc_491521501755_item	3714063	et	0	main
tegemist	doc_491521501755_item	3714064	et	0	main
ei	doc_491521501755_item	3714065	et	0	main
ole	doc_491521501755_item	3714066	et	0	main
ainult	doc_491521501755_item	3714067	et	0	main
vale	doc_491521501755_item	3714068	et	0	main
infinitiivi	doc_491521501755_item	3714069	et	0	main
valikuga	doc_491521501755_item	3714070	et	0	main
kuid	doc_491521501755_item	3714071	et	0	main
ka	doc_491521501755_item	3714072	et	0	main
verbivormi	doc_491521501755_item	3714073	et	0	main
moodustusveaga	doc_491521501755_item	3714074	et	0	main
sõna	doc_491521501755_item	3714075	et	0	main
lähema	doc_491521501755_item	3714076	et	0	main
on	doc_491521501755_item	3714077	et	0	main
moodustatud	doc_491521501755_item	3714078	et	0	main
lisiku	doc_491521501755_item	3714079	et	0	main
verbivormist	doc_491521501755_item	3714080	et	0	main
lähe	doc_491521501755_item	3714081	et	0	main
n	doc_491521501755_item	3714082	et	0	main
ma-infinitiivi	doc_491521501755_item	3714083	et	0	main
tunnus	doc_491521501755_item	3714084	et	0	main
kas	doc_491521501755_item	3714085	et	0	main
te	doc_491521501755_item	3714086	et	0	main
olete	doc_491521501755_item	3714087	et	0	main
võimeline	doc_491521501755_item	3714088	et	0	main
rääkida	doc_491521501755_item	3714089	et	0	main
antud	doc_491521501755_item	3714090	et	0	main
verbivorm	doc_491521501755_item	3714091	et	0	main
rääkida	doc_491521501755_item	3714092	et	0	main
on	doc_491521501755_item	3714093	et	0	main
kasutatud	doc_491521501755_item	3714094	et	0	main
sõnaühendiga	doc_491521501755_item	3714095	et	0	main
olete	doc_491521501755_item	3714096	et	0	main
võimeline	doc_491521501755_item	3714097	et	0	main
analoogia	doc_491521501755_item	3714098	et	0	main
alusel	doc_491521501755_item	3714099	et	0	main
nii	doc_491521501755_item	3714100	et	0	main
nagu	doc_491521501755_item	3714101	et	0	main
verbiga	doc_491521501755_item	3714102	et	0	main
võima	doc_491521501755_item	3714103	et	0	main
rektsioonivead	doc_491521501755_item	3714104	et	0	main
ta	doc_491521501755_item	3714105	et	0	main
käib	doc_491521501755_item	3714106	et	0	main
kooli	doc_491521501755_item	3714107	et	0	main
viga	doc_491521501755_item	3714108	et	0	main
on	doc_491521501755_item	3714109	et	0	main
põhjustatud	doc_491521501755_item	3714110	et	0	main
emakeele	doc_491521501755_item	3714111	et	0	main
mõjust	doc_491521501755_item	3714112	et	0	main
antud	doc_491521501755_item	3714113	et	0	main
lause	doc_491521501755_item	3714114	et	0	main
venekeelne	doc_491521501755_item	3714115	et	0	main
vaste	doc_491521501755_item	3714116	et	0	main
on	doc_491521501755_item	3714117	et	0	main
он	doc_491521501755_item	3714118	et	0	main
ходит	doc_491521501755_item	3714119	et	0	main
куда	doc_491521501755_item	3714120	et	0	main
в	doc_491521501755_item	3714121	et	0	main
школу	doc_491521501755_item	3714122	et	0	main
vene	doc_491521501755_item	3714123	et	0	main
küsimusele	doc_491521501755_item	3714124	et	0	main
куда	doc_491521501755_item	3714125	et	0	main
vastab	doc_491521501755_item	3714126	et	0	main
eesti	doc_491521501755_item	3714127	et	0	main
keeles	doc_491521501755_item	3714128	et	0	main
sisseütlev	doc_491521501755_item	3714129	et	0	main
kääne	doc_491521501755_item	3714130	et	0	main
me	doc_491521501755_item	3714131	et	0	main
aitame	doc_491521501755_item	3714132	et	0	main
teineteisele	doc_491521501755_item	3714133	et	0	main
ja	doc_491521501755_item	3714134	et	0	main
saame	doc_491521501755_item	3714135	et	0	main
tulenevaid	doc_491521501755_item	3714136	et	0	main
raskusi	doc_491521501755_item	3714137	et	0	main
üle	doc_491521501755_item	3714138	et	0	main
me	doc_491521501755_item	3714139	et	0	main
aitame	doc_491521501755_item	3714140	et	0	main
teineteist	doc_491521501755_item	3714141	et	0	main
ning	doc_491521501755_item	3714142	et	0	main
saame	doc_491521501755_item	3714143	et	0	main
olemasolevatest	doc_491521501755_item	3714144	et	0	main
probleemidest	doc_491521501755_item	3714145	et	0	main
üle	doc_491521501755_item	3714146	et	0	main
viga	doc_491521501755_item	3714147	et	0	main
on	doc_491521501755_item	3714148	et	0	main
tingitud	doc_491521501755_item	3714149	et	0	main
emakeele	doc_491521501755_item	3714150	et	0	main
mõjust	doc_491521501755_item	3714151	et	0	main
vene	doc_491521501755_item	3714152	et	0	main
keeles	doc_491521501755_item	3714153	et	0	main
on	doc_491521501755_item	3714154	et	0	main
мы	doc_491521501755_item	3714155	et	0	main
помогаем	doc_491521501755_item	3714156	et	0	main
кому	doc_491521501755_item	3714157	et	0	main
друг	doc_491521501755_item	3714158	et	0	main
другу	doc_491521501755_item	3714159	et	0	main
ja	doc_491521501755_item	3714160	et	0	main
преодолеваем	doc_491521501755_item	3714161	et	0	main
что	doc_491521501755_item	3714162	et	0	main
возникающие	doc_491521501755_item	3714163	et	0	main
сложности	doc_491521501755_item	3714164	et	0	main
vene	doc_491521501755_item	3714165	et	0	main
küsimusele	doc_491521501755_item	3714166	et	0	main
кому	doc_491521501755_item	3714167	et	0	main
vastab	doc_491521501755_item	3714168	et	0	main
eesti	doc_491521501755_item	3714169	et	0	main
keeles	doc_491521501755_item	3714170	et	0	main
alaleütlev	doc_491521501755_item	3714171	et	0	main
küsimusele	doc_491521501755_item	3714172	et	0	main
что	doc_491521501755_item	3714173	et	0	main
aga	doc_491521501755_item	3714174	et	0	main
osastav	doc_491521501755_item	3714175	et	0	main
kääne	doc_491521501755_item	3714176	et	0	main
ma	doc_491521501755_item	3714177	et	0	main
tunnen	doc_491521501755_item	3714178	et	0	main
neid	doc_491521501755_item	3714179	et	0	main
ära	doc_491521501755_item	3714180	et	0	main
suurt	doc_491521501755_item	3714181	et	0	main
huvi	doc_491521501755_item	3714182	et	0	main
ma	doc_491521501755_item	3714183	et	0	main
tuunen	doc_491521501755_item	3714184	et	0	main
nende	doc_491521501755_item	3714185	et	0	main
vastu	doc_491521501755_item	3714186	et	0	main
suurt	doc_491521501755_item	3714187	et	0	main
huvi	doc_491521501755_item	3714188	et	0	main
antud	doc_491521501755_item	3714189	et	0	main
juhul	doc_491521501755_item	3714190	et	0	main
eesti	doc_491521501755_item	3714191	et	0	main
sõnaühend	doc_491521501755_item	3714192	et	0	main
huvi	doc_491521501755_item	3714193	et	0	main
tundma	doc_491521501755_item	3714194	et	0	main
интересоваться	doc_491521501755_item	3714195	et	0	main
on	doc_491521501755_item	3714196	et	0	main
segi	doc_491521501755_item	3714197	et	0	main
aetud	doc_491521501755_item	3714198	et	0	main
teise	doc_491521501755_item	3714199	et	0	main
sõnaühendiga	doc_491521501755_item	3714200	et	0	main
ära	doc_491521501755_item	3714201	et	0	main
tundma	doc_491521501755_item	3714202	et	0	main
узнавать	doc_491521501755_item	3714203	et	0	main
kõik	doc_491521501755_item	3714204	et	0	main
siin	doc_491521501755_item	3714205	et	0	main
tuletab	doc_491521501755_item	3714206	et	0	main
meelde	doc_491521501755_item	3714207	et	0	main
eesti	doc_491521501755_item	3714208	et	0	main
rahva	doc_491521501755_item	3714209	et	0	main
ajaloost	doc_491521501755_item	3714210	et	0	main
kultuurist	doc_491521501755_item	3714211	et	0	main
ja	doc_491521501755_item	3714212	et	0	main
tavadest	doc_491521501755_item	3714213	et	0	main
vea	doc_491521501755_item	3714214	et	0	main
põhjuseks	doc_491521501755_item	3714215	et	0	main
on	doc_491521501755_item	3714216	et	0	main
emakeele	doc_491521501755_item	3714217	et	0	main
mõju	doc_491521501755_item	3714218	et	0	main
lause	doc_491521501755_item	3714219	et	0	main
esineb	doc_491521501755_item	3714220	et	0	main
otsetõlkena	doc_491521501755_item	3714221	et	0	main
vene	doc_491521501755_item	3714222	et	0	main
keelest	doc_491521501755_item	3714223	et	0	main
все	doc_491521501755_item	3714224	et	0	main
здесь	doc_491521501755_item	3714225	et	0	main
напоминает	doc_491521501755_item	3714226	et	0	main
об	doc_491521501755_item	3714227	et	0	main
истории	doc_491521501755_item	3714228	et	0	main
культуре	doc_491521501755_item	3714229	et	0	main
и	doc_491521501755_item	3714230	et	0	main
обычаях	doc_491521501755_item	3714231	et	0	main
эстонского	doc_491521501755_item	3714232	et	0	main
народа	doc_491521501755_item	3714233	et	0	main
vale	doc_491521501755_item	3714234	et	0	main
välde	doc_491521501755_item	3714235	et	0	main
nad	doc_491521501755_item	3714236	et	0	main
on	doc_491521501755_item	3714237	et	0	main
nagu	doc_491521501755_item	3714238	et	0	main
sukk	doc_491521501755_item	3714239	et	0	main
ja	doc_491521501755_item	3714240	et	0	main
sabas	doc_491521501755_item	3714241	et	0	main
vea	doc_491521501755_item	3714242	et	0	main
põhjus	doc_491521501755_item	3714243	et	0	main
seisneb	doc_491521501755_item	3714244	et	0	main
selles	doc_491521501755_item	3714245	et	0	main
et	doc_491521501755_item	3714246	et	0	main
vene	doc_491521501755_item	3714247	et	0	main
emakeelega	doc_491521501755_item	3714248	et	0	main
õppijal	doc_491521501755_item	3714249	et	0	main
on	doc_491521501755_item	3714250	et	0	main
raske	doc_491521501755_item	3714251	et	0	main
teha	doc_491521501755_item	3714252	et	0	main
vahet	doc_491521501755_item	3714253	et	0	main
lühikeste	doc_491521501755_item	3714254	et	0	main
ja	doc_491521501755_item	3714255	et	0	main
pikkade	doc_491521501755_item	3714256	et	0	main
häälikute	doc_491521501755_item	3714257	et	0	main
vahel	doc_491521501755_item	3714258	et	0	main
sest	doc_491521501755_item	3714259	et	0	main
vene	doc_491521501755_item	3714260	et	0	main
keeles	doc_491521501755_item	3714261	et	0	main
on	doc_491521501755_item	3714262	et	0	main
kõik	doc_491521501755_item	3714263	et	0	main
häälikud	doc_491521501755_item	3714264	et	0	main
pikkuse	doc_491521501755_item	3714265	et	0	main
poolest	doc_491521501755_item	3714266	et	0	main
ühesugused	doc_491521501755_item	3714267	et	0	main
konkretses	doc_491521501755_item	3714268	et	0	main
rajonis	doc_491521501755_item	3714269	et	0	main
on	doc_491521501755_item	3714270	et	0	main
tavaliselt	doc_491521501755_item	3714271	et	0	main
üks	doc_491521501755_item	3714272	et	0	main
kaupluss	doc_491521501755_item	3714273	et	0	main
veel	doc_491521501755_item	3714274	et	0	main
üks	doc_491521501755_item	3714275	et	0	main
näide	doc_491521501755_item	3714276	et	0	main
põhjus	doc_491521501755_item	3714277	et	0	main
vt	doc_491521501755_item	3714278	et	0	main
eelm	doc_491521501755_item	3714279	et	0	main
n	doc_491521501755_item	3714280	et	0	main
sellega	doc_491521501755_item	3714281	et	0	main
nad	doc_491521501755_item	3714282	et	0	main
enam	doc_491521501755_item	3714283	et	0	main
ei	doc_491521501755_item	3714284	et	0	main
lebi	doc_491521501755_item	3714285	et	0	main
ei	doc_491521501755_item	3714286	et	0	main
lepi	doc_491521501755_item	3714287	et	0	main
vea	doc_491521501755_item	3714288	et	0	main
põhjus	doc_491521501755_item	3714289	et	0	main
on	doc_491521501755_item	3714290	et	0	main
samuti	doc_491521501755_item	3714291	et	0	main
selles	doc_491521501755_item	3714292	et	0	main
et	doc_491521501755_item	3714293	et	0	main
vene	doc_491521501755_item	3714294	et	0	main
emakeelega	doc_491521501755_item	3714295	et	0	main
õppija	doc_491521501755_item	3714296	et	0	main
ei	doc_491521501755_item	3714297	et	0	main
erista	doc_491521501755_item	3714298	et	0	main
eesti	doc_491521501755_item	3714299	et	0	main
välteid	doc_491521501755_item	3714300	et	0	main
ta	doc_491521501755_item	3714301	et	0	main
ei	doc_491521501755_item	3714302	et	0	main
saa	doc_491521501755_item	3714303	et	0	main
eriti	doc_491521501755_item	3714304	et	0	main
õppimise	doc_491521501755_item	3714305	et	0	main
algetapil	doc_491521501755_item	3714306	et	0	main
kuulmise	doc_491521501755_item	3714307	et	0	main
järgi	doc_491521501755_item	3714308	et	0	main
määratleda	doc_491521501755_item	3714309	et	0	main
kas	doc_491521501755_item	3714310	et	0	main
tegemist	doc_491521501755_item	3714311	et	0	main
on	doc_491521501755_item	3714312	et	0	main
nõrga	doc_491521501755_item	3714313	et	0	main
b-ga	doc_491521501755_item	3714314	et	0	main
või	doc_491521501755_item	3714315	et	0	main
tugeva	doc_491521501755_item	3714316	et	0	main
p-ga	doc_491521501755_item	3714317	et	0	main
sest	doc_491521501755_item	3714318	et	0	main
eesti	doc_491521501755_item	3714319	et	0	main
keeles	doc_491521501755_item	3714320	et	0	main
kõlavad	doc_491521501755_item	3714321	et	0	main
need	doc_491521501755_item	3714322	et	0	main
häälikud	doc_491521501755_item	3714323	et	0	main
tema	doc_491521501755_item	3714324	et	0	main
jaoks	doc_491521501755_item	3714325	et	0	main
sarnaselt	doc_491521501755_item	3714326	et	0	main
paljudel	doc_491521501755_item	3714327	et	0	main
on	doc_491521501755_item	3714328	et	0	main
neist	doc_491521501755_item	3714329	et	0	main
on	doc_491521501755_item	3714330	et	0	main
priti	doc_491521501755_item	3714331	et	0	main
kodaniku	doc_491521501755_item	3714332	et	0	main
pass	doc_491521501755_item	3714333	et	0	main
briti	doc_491521501755_item	3714334	et	0	main
kodaniku	doc_491521501755_item	3714335	et	0	main
pass	doc_491521501755_item	3714336	et	0	main
sama	doc_491521501755_item	3714337	et	0	main
vea	doc_491521501755_item	3714338	et	0	main
veel	doc_491521501755_item	3714339	et	0	main
üks	doc_491521501755_item	3714340	et	0	main
näide	doc_491521501755_item	3714341	et	0	main
vt	doc_491521501755_item	3714342	et	0	main
eelm	doc_491521501755_item	3714343	et	0	main
n	doc_491521501755_item	3714344	et	0	main
vead	doc_491521501755_item	3714345	et	0	main
lausemoodustuses	doc_491521501755_item	3714346	et	0	main
ma	doc_491521501755_item	3714347	et	0	main
pean	doc_491521501755_item	3714348	et	0	main
koju	doc_491521501755_item	3714349	et	0	main
tulema	doc_491521501755_item	3714350	et	0	main
ikkagi	doc_491521501755_item	3714351	et	0	main
teiseks	doc_491521501755_item	3714352	et	0	main
ma	doc_491521501755_item	3714353	et	0	main
pean	doc_491521501755_item	3714354	et	0	main
koju	doc_491521501755_item	3714355	et	0	main
jõudma	doc_491521501755_item	3714356	et	0	main
kella	doc_491521501755_item	3714357	et	0	main
kaheks	doc_491521501755_item	3714358	et	0	main
lause	doc_491521501755_item	3714359	et	0	main
on	doc_491521501755_item	3714360	et	0	main
tõlgitud	doc_491521501755_item	3714361	et	0	main
otse	doc_491521501755_item	3714362	et	0	main
vene	doc_491521501755_item	3714363	et	0	main
keelest	doc_491521501755_item	3714364	et	0	main
я	doc_491521501755_item	3714365	et	0	main
должен	doc_491521501755_item	3714366	et	0	main
прийти	doc_491521501755_item	3714367	et	0	main
домой	doc_491521501755_item	3714368	et	0	main
к	doc_491521501755_item	3714369	et	0	main
двум	doc_491521501755_item	3714370	et	0	main
sõnad	doc_491521501755_item	3714371	et	0	main
kaks	doc_491521501755_item	3714372	et	0	main
ja	doc_491521501755_item	3714373	et	0	main
teine	doc_491521501755_item	3714374	et	0	main
sageli	doc_491521501755_item	3714375	et	0	main
aetakse	doc_491521501755_item	3714376	et	0	main
segi	doc_491521501755_item	3714377	et	0	main
kuigi	doc_491521501755_item	3714378	et	0	main
vene	doc_491521501755_item	3714379	et	0	main
keeles	doc_491521501755_item	3714380	et	0	main
on	doc_491521501755_item	3714381	et	0	main
два	doc_491521501755_item	3714382	et	0	main
ja	doc_491521501755_item	3714383	et	0	main
второй	doc_491521501755_item	3714384	et	0	main
samuti	doc_491521501755_item	3714385	et	0	main
kaks	doc_491521501755_item	3714386	et	0	main
erinevat	doc_491521501755_item	3714387	et	0	main
sõna	doc_491521501755_item	3714388	et	0	main
muidugi	doc_491521501755_item	3714389	et	0	main
väga	doc_491521501755_item	3714390	et	0	main
huvitavalt	doc_491521501755_item	3714391	et	0	main
on	doc_491521501755_item	3714392	et	0	main
see	doc_491521501755_item	3714393	et	0	main
et	doc_491521501755_item	3714394	et	0	main
õppimisega	doc_491521501755_item	3714395	et	0	main
iga	doc_491521501755_item	3714396	et	0	main
inimene	doc_491521501755_item	3714397	et	0	main
saab	doc_491521501755_item	3714398	et	0	main
targemaks	doc_491521501755_item	3714399	et	0	main
muidugi	doc_491521501755_item	3714400	et	0	main
on	doc_491521501755_item	3714401	et	0	main
huvitav	doc_491521501755_item	3714402	et	0	main
see	doc_491521501755_item	3714403	et	0	main
et	doc_491521501755_item	3714404	et	0	main
õppimisega	doc_491521501755_item	3714405	et	0	main
saab	doc_491521501755_item	3714406	et	0	main
iga	doc_491521501755_item	3714407	et	0	main
inimene	doc_491521501755_item	3714408	et	0	main
targemaks	doc_491521501755_item	3714409	et	0	main
antud	doc_491521501755_item	3714410	et	0	main
lauses	doc_491521501755_item	3714411	et	0	main
on	doc_491521501755_item	3714412	et	0	main
2	doc_491521501755_item	3714413	et	0	main
eri	doc_491521501755_item	3714414	et	0	main
liiki	doc_491521501755_item	3714415	et	0	main
viga	doc_491521501755_item	3714416	et	0	main
1	doc_491521501755_item	3714417	et	0	main
sõnade	doc_491521501755_item	3714418	et	0	main
vale	doc_491521501755_item	3714419	et	0	main
järjekord	doc_491521501755_item	3714420	et	0	main
lauses	doc_491521501755_item	3714421	et	0	main
on	doc_491521501755_item	3714422	et	0	main
põhjustatud	doc_491521501755_item	3714423	et	0	main
emakeele	doc_491521501755_item	3714424	et	0	main
mõjust	doc_491521501755_item	3714425	et	0	main
2	doc_491521501755_item	3714426	et	0	main
adverbi	doc_491521501755_item	3714427	et	0	main
kasutamine	doc_491521501755_item	3714428	et	0	main
adjektiivi	doc_491521501755_item	3714429	et	0	main
asemel	doc_491521501755_item	3714430	et	0	main
on	doc_491521501755_item	3714431	et	0	main
samuti	doc_491521501755_item	3714432	et	0	main
tingitud	doc_491521501755_item	3714433	et	0	main
emakeele	doc_491521501755_item	3714434	et	0	main
mõjust	doc_491521501755_item	3714435	et	0	main
vene	doc_491521501755_item	3714436	et	0	main
keeles	doc_491521501755_item	3714437	et	0	main
on	doc_491521501755_item	3714438	et	0	main
очень	doc_491521501755_item	3714439	et	0	main
интересно	doc_491521501755_item	3714440	et	0	main
то	doc_491521501755_item	3714441	et	0	main
что	doc_491521501755_item	3714442	et	0	main
eesti	doc_491521501755_item	3714443	et	0	main
keeles	doc_491521501755_item	3714444	et	0	main
on	doc_491521501755_item	3714445	et	0	main
aga	doc_491521501755_item	3714446	et	0	main
väga	doc_491521501755_item	3714447	et	0	main
huvitav	doc_491521501755_item	3714448	et	0	main
on	doc_491521501755_item	3714449	et	0	main
see	doc_491521501755_item	3714450	et	0	main
et	doc_491521501755_item	3714451	et	0	main
meie	doc_491521501755_item	3714452	et	0	main
andekad	doc_491521501755_item	3714453	et	0	main
õpetajad	doc_491521501755_item	3714454	et	0	main
püüavad	doc_491521501755_item	3714455	et	0	main
anda	doc_491521501755_item	3714456	et	0	main
meile	doc_491521501755_item	3714457	et	0	main
kõike	doc_491521501755_item	3714458	et	0	main
mida	doc_491521501755_item	3714459	et	0	main
aitaks	doc_491521501755_item	3714460	et	0	main
meile	doc_491521501755_item	3714461	et	0	main
saada	doc_491521501755_item	3714462	et	0	main
parimateks	doc_491521501755_item	3714463	et	0	main
ja	doc_491521501755_item	3714464	et	0	main
targemateks	doc_491521501755_item	3714465	et	0	main
püüavad	doc_491521501755_item	3714466	et	0	main
anda	doc_491521501755_item	3714467	et	0	main
omalt	doc_491521501755_item	3714468	et	0	main
poolt	doc_491521501755_item	3714469	et	0	main
kõik	doc_491521501755_item	3714470	et	0	main
et	doc_491521501755_item	3714471	et	0	main
me	doc_491521501755_item	3714472	et	0	main
saaksime	doc_491521501755_item	3714473	et	0	main
parimateks	doc_491521501755_item	3714474	et	0	main
ja	doc_491521501755_item	3714475	et	0	main
targemateks	doc_491521501755_item	3714476	et	0	main
inimesteks	doc_491521501755_item	3714477	et	0	main
viga	doc_491521501755_item	3714478	et	0	main
on	doc_491521501755_item	3714479	et	0	main
põhjustatud	doc_491521501755_item	3714480	et	0	main
emakeelest	doc_491521501755_item	3714481	et	0	main
lause	doc_491521501755_item	3714482	et	0	main
on	doc_491521501755_item	3714483	et	0	main
tõlgitud	doc_491521501755_item	3714484	et	0	main
otse	doc_491521501755_item	3714485	et	0	main
vene	doc_491521501755_item	3714486	et	0	main
keelest	doc_491521501755_item	3714487	et	0	main
наши	doc_491521501755_item	3714488	et	0	main
талантливые	doc_491521501755_item	3714489	et	0	main
учителя	doc_491521501755_item	3714490	et	0	main
стараются	doc_491521501755_item	3714491	et	0	main
дать	doc_491521501755_item	3714492	et	0	main
нам	doc_491521501755_item	3714493	et	0	main
всё	doc_491521501755_item	3714494	et	0	main
что	doc_491521501755_item	3714495	et	0	main
помогло	doc_491521501755_item	3714496	et	0	main
бы	doc_491521501755_item	3714497	et	0	main
нам	doc_491521501755_item	3714498	et	0	main
стать	doc_491521501755_item	3714499	et	0	main
лучше	doc_491521501755_item	3714500	et	0	main
и	doc_491521501755_item	3714501	et	0	main
умнее	doc_491521501755_item	3714502	et	0	main
siit	doc_491521501755_item	3714503	et	0	main
tulevad	doc_491521501755_item	3714504	et	0	main
ka	doc_491521501755_item	3714505	et	0	main
vead	doc_491521501755_item	3714506	et	0	main
nt	doc_491521501755_item	3714507	et	0	main
püüavad	doc_491521501755_item	3714508	et	0	main
anda	doc_491521501755_item	3714509	et	0	main
meile	doc_491521501755_item	3714510	et	0	main
kõike	doc_491521501755_item	3714511	et	0	main
stiiliviga	doc_491521501755_item	3714512	et	0	main
mida	doc_491521501755_item	3714513	et	0	main
aitaks	doc_491521501755_item	3714514	et	0	main
vale	doc_491521501755_item	3714515	et	0	main
kääne	doc_491521501755_item	3714516	et	0	main
sest	doc_491521501755_item	3714517	et	0	main
nii	doc_491521501755_item	3714518	et	0	main
eesti	doc_491521501755_item	3714519	et	0	main
mis	doc_491521501755_item	3714520	et	0	main
kui	doc_491521501755_item	3714521	et	0	main
ka	doc_491521501755_item	3714522	et	0	main
mida	doc_491521501755_item	3714523	et	0	main
tähendavad	doc_491521501755_item	3714524	et	0	main
vene	doc_491521501755_item	3714525	et	0	main
keeles	doc_491521501755_item	3714526	et	0	main
что	doc_491521501755_item	3714527	et	0	main
aitaks	doc_491521501755_item	3714528	et	0	main
meile	doc_491521501755_item	3714529	et	0	main
rektsiooniviga	doc_491521501755_item	3714530	et	0	main
nagu	doc_491521501755_item	3714531	et	0	main
igas	doc_491521501755_item	3714532	et	0	main
töös	doc_491521501755_item	3714533	et	0	main
meil	doc_491521501755_item	3714534	et	0	main
on	doc_491521501755_item	3714535	et	0	main
ka	doc_491521501755_item	3714536	et	0	main
oma	doc_491521501755_item	3714537	et	0	main
raskused	doc_491521501755_item	3714538	et	0	main
nagu	doc_491521501755_item	3714539	et	0	main
igas	doc_491521501755_item	3714540	et	0	main
töös	doc_491521501755_item	3714541	et	0	main
on	doc_491521501755_item	3714542	et	0	main
ka	doc_491521501755_item	3714543	et	0	main
meil	doc_491521501755_item	3714544	et	0	main
omad	doc_491521501755_item	3714545	et	0	main
raskused	doc_491521501755_item	3714546	et	0	main
sõnade	doc_491521501755_item	3714547	et	0	main
vale	doc_491521501755_item	3714548	et	0	main
järjekord	doc_491521501755_item	3714549	et	0	main
lauses	doc_491521501755_item	3714550	et	0	main
mis	doc_491521501755_item	3714551	et	0	main
on	doc_491521501755_item	3714552	et	0	main
tingitud	doc_491521501755_item	3714553	et	0	main
emakeelest	doc_491521501755_item	3714554	et	0	main
aga	doc_491521501755_item	3714555	et	0	main
vaatamata	doc_491521501755_item	3714556	et	0	main
sellele	doc_491521501755_item	3714557	et	0	main
minu	doc_491521501755_item	3714558	et	0	main
õppimine	doc_491521501755_item	3714559	et	0	main
meeldib	doc_491521501755_item	3714560	et	0	main
mulle	doc_491521501755_item	3714561	et	0	main
ja	doc_491521501755_item	3714562	et	0	main
ma	doc_491521501755_item	3714563	et	0	main
ei	doc_491521501755_item	3714564	et	0	main
saa	doc_491521501755_item	3714565	et	0	main
öelda	doc_491521501755_item	3714566	et	0	main
et	doc_491521501755_item	3714567	et	0	main
alati	doc_491521501755_item	3714568	et	0	main
see	doc_491521501755_item	3714569	et	0	main
ei	doc_491521501755_item	3714570	et	0	main
paku	doc_491521501755_item	3714571	et	0	main
mulle	doc_491521501755_item	3714572	et	0	main
rahulolu	doc_491521501755_item	3714573	et	0	main
kuid	doc_491521501755_item	3714574	et	0	main
mõnikord	doc_491521501755_item	3714575	et	0	main
see	doc_491521501755_item	3714576	et	0	main
on	doc_491521501755_item	3714577	et	0	main
nii	doc_491521501755_item	3714578	et	0	main
kui	doc_491521501755_item	3714579	et	0	main
mul	doc_491521501755_item	3714580	et	0	main
on	doc_491521501755_item	3714581	et	0	main
palju	doc_491521501755_item	3714582	et	0	main
ülesandeid	doc_491521501755_item	3714583	et	0	main
ja	doc_491521501755_item	3714584	et	0	main
need	doc_491521501755_item	3714585	et	0	main
on	doc_491521501755_item	3714586	et	0	main
rasked	doc_491521501755_item	3714587	et	0	main
ja	doc_491521501755_item	3714588	et	0	main
ma	doc_491521501755_item	3714589	et	0	main
olen	doc_491521501755_item	3714590	et	0	main
väsinud	doc_491521501755_item	3714591	et	0	main
ent	doc_491521501755_item	3714592	et	0	main
vaatamata	doc_491521501755_item	3714593	et	0	main
sellele	doc_491521501755_item	3714594	et	0	main
meeldib	doc_491521501755_item	3714595	et	0	main
mulle	doc_491521501755_item	3714596	et	0	main
õppimine	doc_491521501755_item	3714597	et	0	main
kuigi	doc_491521501755_item	3714598	et	0	main
ei	doc_491521501755_item	3714599	et	0	main
saaks	doc_491521501755_item	3714600	et	0	main
ütelda	doc_491521501755_item	3714601	et	0	main
et	doc_491521501755_item	3714602	et	0	main
alati	doc_491521501755_item	3714603	et	0	main
see	doc_491521501755_item	3714604	et	0	main
pakuks	doc_491521501755_item	3714605	et	0	main
mulle	doc_491521501755_item	3714606	et	0	main
rahulolu	doc_491521501755_item	3714607	et	0	main
ometigi	doc_491521501755_item	3714608	et	0	main
on	doc_491521501755_item	3714609	et	0	main
nii	doc_491521501755_item	3714610	et	0	main
et	doc_491521501755_item	3714611	et	0	main
kui	doc_491521501755_item	3714612	et	0	main
mulle	doc_491521501755_item	3714613	et	0	main
antakse	doc_491521501755_item	3714614	et	0	main
palju	doc_491521501755_item	3714615	et	0	main
keerulisi	doc_491521501755_item	3714616	et	0	main
ülesandeid	doc_491521501755_item	3714617	et	0	main
võivad	doc_491521501755_item	3714618	et	0	main
need	doc_491521501755_item	3714619	et	0	main
mind	doc_491521501755_item	3714620	et	0	main
väsitada	doc_491521501755_item	3714621	et	0	main
viga	doc_491521501755_item	3714622	et	0	main
on	doc_491521501755_item	3714623	et	0	main
põhjustatud	doc_491521501755_item	3714624	et	0	main
emakeele	doc_491521501755_item	3714625	et	0	main
mõjust	doc_491521501755_item	3714626	et	0	main
lause	doc_491521501755_item	3714627	et	0	main
on	doc_491521501755_item	3714628	et	0	main
tõlgitud	doc_491521501755_item	3714629	et	0	main
otse	doc_491521501755_item	3714630	et	0	main
vene	doc_491521501755_item	3714631	et	0	main
keelesttavaliselt	doc_491521501755_item	3714632	et	0	main
on	doc_491521501755_item	3714633	et	0	main
vene	doc_491521501755_item	3714634	et	0	main
laused	doc_491521501755_item	3714635	et	0	main
konstruktsioonilt	doc_491521501755_item	3714636	et	0	main
pikemad	doc_491521501755_item	3714637	et	0	main
ja	doc_491521501755_item	3714638	et	0	main
keerulisemad	doc_491521501755_item	3714639	et	0	main
kui	doc_491521501755_item	3714640	et	0	main
eesti	doc_491521501755_item	3714641	et	0	main
omad	doc_491521501755_item	3714642	et	0	main
aga	doc_491521501755_item	3714643	et	0	main
antud	doc_491521501755_item	3714644	et	0	main
lause	doc_491521501755_item	3714645	et	0	main
puhul	doc_491521501755_item	3714646	et	0	main
isegi	doc_491521501755_item	3714647	et	0	main
vene	doc_491521501755_item	3714648	et	0	main
keeles	doc_491521501755_item	3714649	et	0	main
kõlaks	doc_491521501755_item	3714650	et	0	main
see	doc_491521501755_item	3714651	et	0	main
ebakorrektselt	doc_491521501755_item	3714652	et	0	main
on	doc_491521501755_item	3714653	et	0	main
vaja	doc_491521501755_item	3714654	et	0	main
valida	doc_491521501755_item	3714655	et	0	main
niisugust	doc_491521501755_item	3714656	et	0	main
tööd	doc_491521501755_item	3714657	et	0	main
et	doc_491521501755_item	3714658	et	0	main
selles	doc_491521501755_item	3714659	et	0	main
oleks	doc_491521501755_item	3714660	et	0	main
kõik	doc_491521501755_item	3714661	et	0	main
mida	doc_491521501755_item	3714662	et	0	main
on	doc_491521501755_item	3714663	et	0	main
vaja	doc_491521501755_item	3714664	et	0	main
et	doc_491521501755_item	3714665	et	0	main
elada	doc_491521501755_item	3714666	et	0	main
ja	doc_491521501755_item	3714667	et	0	main
tunda	doc_491521501755_item	3714668	et	0	main
end	doc_491521501755_item	3714669	et	0	main
vajalikuna	doc_491521501755_item	3714670	et	0	main
teistele	doc_491521501755_item	3714671	et	0	main
tuleks	doc_491521501755_item	3714672	et	0	main
valida	doc_491521501755_item	3714673	et	0	main
selline	doc_491521501755_item	3714674	et	0	main
töö	doc_491521501755_item	3714675	et	0	main
et	doc_491521501755_item	3714676	et	0	main
sellest	doc_491521501755_item	3714677	et	0	main
saaks	doc_491521501755_item	3714678	et	0	main
kõike	doc_491521501755_item	3714679	et	0	main
mida	doc_491521501755_item	3714680	et	0	main
on	doc_491521501755_item	3714681	et	0	main
vaja	doc_491521501755_item	3714682	et	0	main
elada	doc_491521501755_item	3714683	et	0	main
ja	doc_491521501755_item	3714684	et	0	main
tunda	doc_491521501755_item	3714685	et	0	main
ennast	doc_491521501755_item	3714686	et	0	main
vajaliku	doc_491521501755_item	3714687	et	0	main
inimesena	doc_491521501755_item	3714688	et	0	main
tegemist	doc_491521501755_item	3714689	et	0	main
on	doc_491521501755_item	3714690	et	0	main
jällegi	doc_491521501755_item	3714691	et	0	main
emakeelest	doc_491521501755_item	3714692	et	0	main
põhjustatud	doc_491521501755_item	3714693	et	0	main
veaga	doc_491521501755_item	3714694	et	0	main
tavaliselt	doc_491521501755_item	3714695	et	0	main
moodustab	doc_491521501755_item	3714696	et	0	main
eesti	doc_491521501755_item	3714697	et	0	main
keele	doc_491521501755_item	3714698	et	0	main
õppija	doc_491521501755_item	3714699	et	0	main
lauseid	doc_491521501755_item	3714700	et	0	main
just	doc_491521501755_item	3714701	et	0	main
oma	doc_491521501755_item	3714702	et	0	main
emakeele	doc_491521501755_item	3714703	et	0	main
mallist	doc_491521501755_item	3714704	et	0	main
lähtuvalt	doc_491521501755_item	3714705	et	0	main
lause	doc_491521501755_item	3714706	et	0	main
on	doc_491521501755_item	3714707	et	0	main
stiililiselt	doc_491521501755_item	3714708	et	0	main
ebakorrektne	doc_491521501755_item	3714709	et	0	main
kordub	doc_491521501755_item	3714710	et	0	main
on	doc_491521501755_item	3714711	et	0	main
vaja	doc_491521501755_item	3714712	et	0	main
millele	doc_491521501755_item	3714713	et	0	main
õppija	doc_491521501755_item	3714714	et	0	main
ei	doc_491521501755_item	3714715	et	0	main
oska	doc_491521501755_item	3714716	et	0	main
sünonüümi	doc_491521501755_item	3714717	et	0	main
leida	doc_491521501755_item	3714718	et	0	main
peale	doc_491521501755_item	3714719	et	0	main
stiili-	doc_491521501755_item	3714720	et	0	main
ja	doc_491521501755_item	3714721	et	0	main
lausemoodustusvigade	doc_491521501755_item	3714722	et	0	main
esineb	doc_491521501755_item	3714723	et	0	main
antud	doc_491521501755_item	3714724	et	0	main
lauses	doc_491521501755_item	3714725	et	0	main
ka	doc_491521501755_item	3714726	et	0	main
käändeviga	doc_491521501755_item	3714727	et	0	main
valida	doc_491521501755_item	3714728	et	0	main
niisugust	doc_491521501755_item	3714729	et	0	main
tööd	doc_491521501755_item	3714730	et	0	main
otsetõlkes	doc_491521501755_item	3714731	et	0	main
vastab	doc_491521501755_item	3714732	et	0	main
vene	doc_491521501755_item	3714733	et	0	main
винительный	doc_491521501755_item	3714734	et	0	main
käändele	doc_491521501755_item	3714735	et	0	main
eesti	doc_491521501755_item	3714736	et	0	main
osastav	doc_491521501755_item	3714737	et	0	main
iga	doc_491521501755_item	3714738	et	0	main
rahvas	doc_491521501755_item	3714739	et	0	main
omab	doc_491521501755_item	3714740	et	0	main
oma	doc_491521501755_item	3714741	et	0	main
ajalugu	doc_491521501755_item	3714742	et	0	main
ja	doc_491521501755_item	3714743	et	0	main
sellepärast	doc_491521501755_item	3714744	et	0	main
kõigil	doc_491521501755_item	3714745	et	0	main
rahvastel	doc_491521501755_item	3714746	et	0	main
on	doc_491521501755_item	3714747	et	0	main
omad	doc_491521501755_item	3714748	et	0	main
erilisused	doc_491521501755_item	3714749	et	0	main
ja	doc_491521501755_item	3714750	et	0	main
nendega	doc_491521501755_item	3714751	et	0	main
seotud	doc_491521501755_item	3714752	et	0	main
kombed	doc_491521501755_item	3714753	et	0	main
ja	doc_491521501755_item	3714754	et	0	main
traditsioonid	doc_491521501755_item	3714755	et	0	main
igal	doc_491521501755_item	3714756	et	0	main
rahval	doc_491521501755_item	3714757	et	0	main
on	doc_491521501755_item	3714758	et	0	main
oma	doc_491521501755_item	3714759	et	0	main
ajalugu	doc_491521501755_item	3714760	et	0	main
ja	doc_491521501755_item	3714761	et	0	main
sellepärast	doc_491521501755_item	3714762	et	0	main
on	doc_491521501755_item	3714763	et	0	main
kõigil	doc_491521501755_item	3714764	et	0	main
ka	doc_491521501755_item	3714765	et	0	main
omad	doc_491521501755_item	3714766	et	0	main
eripärad	doc_491521501755_item	3714767	et	0	main
ning	doc_491521501755_item	3714768	et	0	main
nendega	doc_491521501755_item	3714769	et	0	main
seotud	doc_491521501755_item	3714770	et	0	main
kombed	doc_491521501755_item	3714771	et	0	main
veel	doc_491521501755_item	3714772	et	0	main
üks	doc_491521501755_item	3714773	et	0	main
näide	doc_491521501755_item	3714774	et	0	main
emakeele	doc_491521501755_item	3714775	et	0	main
mõjust	doc_491521501755_item	3714776	et	0	main
lause	doc_491521501755_item	3714777	et	0	main
moodustamisel	doc_491521501755_item	3714778	et	0	main
antud	doc_491521501755_item	3714779	et	0	main
lauses	doc_491521501755_item	3714780	et	0	main
esineb	doc_491521501755_item	3714781	et	0	main
sõnade	doc_491521501755_item	3714782	et	0	main
vale	doc_491521501755_item	3714783	et	0	main
järjekord	doc_491521501755_item	3714784	et	0	main
sama	doc_491521501755_item	3714785	et	0	main
tüvega	doc_491521501755_item	3714786	et	0	main
sõnade	doc_491521501755_item	3714787	et	0	main
tarbetu	doc_491521501755_item	3714788	et	0	main
kordamine	doc_491521501755_item	3714789	et	0	main
nt	doc_491521501755_item	3714790	et	0	main
omab	doc_491521501755_item	3714791	et	0	main
oma	doc_491521501755_item	3714792	et	0	main
vene	doc_491521501755_item	3714793	et	0	main
keeles	doc_491521501755_item	3714794	et	0	main
имеет	doc_491521501755_item	3714795	et	0	main
свою	doc_491521501755_item	3714796	et	0	main
liigsed	doc_491521501755_item	3714797	et	0	main
sõnad	doc_491521501755_item	3714798	et	0	main
kombed	doc_491521501755_item	3714799	et	0	main
ja	doc_491521501755_item	3714800	et	0	main
traditsioonid	doc_491521501755_item	3714801	et	0	main
on	doc_491521501755_item	3714802	et	0	main
sünonüümid	doc_491521501755_item	3714803	et	0	main
veel	doc_491521501755_item	3714804	et	0	main
eestlased	doc_491521501755_item	3714805	et	0	main
räägivad	doc_491521501755_item	3714806	et	0	main
et	doc_491521501755_item	3714807	et	0	main
kui	doc_491521501755_item	3714808	et	0	main
teid	doc_491521501755_item	3714809	et	0	main
ei	doc_491521501755_item	3714810	et	0	main
tundnud	doc_491521501755_item	3714811	et	0	main
ära	doc_491521501755_item	3714812	et	0	main
teie	doc_491521501755_item	3714813	et	0	main
tuttav	doc_491521501755_item	3714814	et	0	main
see	doc_491521501755_item	3714815	et	0	main
toob	doc_491521501755_item	3714816	et	0	main
rikkus	doc_491521501755_item	3714817	et	0	main
veel	doc_491521501755_item	3714818	et	0	main
räägivad	doc_491521501755_item	3714819	et	0	main
eestlased	doc_491521501755_item	3714820	et	0	main
et	doc_491521501755_item	3714821	et	0	main
kui	doc_491521501755_item	3714822	et	0	main
teid	doc_491521501755_item	3714823	et	0	main
ei	doc_491521501755_item	3714824	et	0	main
tunta	doc_491521501755_item	3714825	et	0	main
ära	doc_491521501755_item	3714826	et	0	main
siis	doc_491521501755_item	3714827	et	0	main
saate	doc_491521501755_item	3714828	et	0	main
rikkaks	doc_491521501755_item	3714829	et	0	main
samal	doc_491521501755_item	3714830	et	0	main
printsiibil	doc_491521501755_item	3714831	et	0	main
põhinev	doc_491521501755_item	3714832	et	0	main
viga	doc_491521501755_item	3714833	et	0	main
õppija	doc_491521501755_item	3714834	et	0	main
püüab	doc_491521501755_item	3714835	et	0	main
vene	doc_491521501755_item	3714836	et	0	main
lauset	doc_491521501755_item	3714837	et	0	main
eesti	doc_491521501755_item	3714838	et	0	main
sõnadega	doc_491521501755_item	3714839	et	0	main
kirja	doc_491521501755_item	3714840	et	0	main
panna	doc_491521501755_item	3714841	et	0	main
ещё	doc_491521501755_item	3714842	et	0	main
эстонцы	doc_491521501755_item	3714843	et	0	main
говорят	doc_491521501755_item	3714844	et	0	main
что	doc_491521501755_item	3714845	et	0	main
если	doc_491521501755_item	3714846	et	0	main
вас	doc_491521501755_item	3714847	et	0	main
не	doc_491521501755_item	3714848	et	0	main
узнал	doc_491521501755_item	3714849	et	0	main
ваш	doc_491521501755_item	3714850	et	0	main
знакомый	doc_491521501755_item	3714851	et	0	main
это	doc_491521501755_item	3714852	et	0	main
принесёт	doc_491521501755_item	3714853	et	0	main
богатство	doc_491521501755_item	3714854	et	0	main
väga	doc_491521501755_item	3714855	et	0	main
ammu	doc_491521501755_item	3714856	et	0	main
kui	doc_491521501755_item	3714857	et	0	main
tallinn	doc_491521501755_item	3714858	et	0	main
ei	doc_491521501755_item	3714859	et	0	main
olnud	doc_491521501755_item	3714860	et	0	main
veel	doc_491521501755_item	3714861	et	0	main
nii	doc_491521501755_item	3714862	et	0	main
ilus	doc_491521501755_item	3714863	et	0	main
ja	doc_491521501755_item	3714864	et	0	main
märgatav	doc_491521501755_item	3714865	et	0	main
linn	doc_491521501755_item	3714866	et	0	main
kui	doc_491521501755_item	3714867	et	0	main
praegu	doc_491521501755_item	3714868	et	0	main
kõik	doc_491521501755_item	3714869	et	0	main
kaubalaevad	doc_491521501755_item	3714870	et	0	main
sõitsid	doc_491521501755_item	3714871	et	0	main
mööda	doc_491521501755_item	3714872	et	0	main
tallinnat	doc_491521501755_item	3714873	et	0	main
sellepärast	doc_491521501755_item	3714874	et	0	main
selle	doc_491521501755_item	3714875	et	0	main
linna	doc_491521501755_item	3714876	et	0	main
majandus	doc_491521501755_item	3714877	et	0	main
ei	doc_491521501755_item	3714878	et	0	main
arenenud	doc_491521501755_item	3714879	et	0	main
väga	doc_491521501755_item	3714880	et	0	main
ammu	doc_491521501755_item	3714881	et	0	main
kui	doc_491521501755_item	3714882	et	0	main
tallinn	doc_491521501755_item	3714883	et	0	main
ei	doc_491521501755_item	3714884	et	0	main
olnud	doc_491521501755_item	3714885	et	0	main
veel	doc_491521501755_item	3714886	et	0	main
nii	doc_491521501755_item	3714887	et	0	main
ilus	doc_491521501755_item	3714888	et	0	main
ja	doc_491521501755_item	3714889	et	0	main
kuulus	doc_491521501755_item	3714890	et	0	main
linn	doc_491521501755_item	3714891	et	0	main
nagu	doc_491521501755_item	3714892	et	0	main
praegu	doc_491521501755_item	3714893	et	0	main
sõitsid	doc_491521501755_item	3714894	et	0	main
kõik	doc_491521501755_item	3714895	et	0	main
kaubalaevad	doc_491521501755_item	3714896	et	0	main
tallinnast	doc_491521501755_item	3714897	et	0	main
mööda	doc_491521501755_item	3714898	et	0	main
ning	doc_491521501755_item	3714899	et	0	main
sellepärast	doc_491521501755_item	3714900	et	0	main
ei	doc_491521501755_item	3714901	et	0	main
arenenud	doc_491521501755_item	3714902	et	0	main
ka	doc_491521501755_item	3714903	et	0	main
majandus	doc_491521501755_item	3714904	et	0	main
tegemist	doc_491521501755_item	3714905	et	0	main
on	doc_491521501755_item	3714906	et	0	main
jälle	doc_491521501755_item	3714907	et	0	main
emakeelest	doc_491521501755_item	3714908	et	0	main
tingitud	doc_491521501755_item	3714909	et	0	main
vigadega	doc_491521501755_item	3714910	et	0	main
sõna	doc_491521501755_item	3714911	et	0	main
märgatav	doc_491521501755_item	3714912	et	0	main
on	doc_491521501755_item	3714913	et	0	main
otsetõlge	doc_491521501755_item	3714914	et	0	main
vene	doc_491521501755_item	3714915	et	0	main
sõnast	doc_491521501755_item	3714916	et	0	main
заметный	doc_491521501755_item	3714917	et	0	main
sõitsid	doc_491521501755_item	3714918	et	0	main
mööda	doc_491521501755_item	3714919	et	0	main
tallinnat	doc_491521501755_item	3714920	et	0	main
проезжали	doc_491521501755_item	3714921	et	0	main
мимо	doc_491521501755_item	3714922	et	0	main
таллинна	doc_491521501755_item	3714923	et	0	main
antud	doc_491521501755_item	3714924	et	0	main
viga	doc_491521501755_item	3714925	et	0	main
muudab	doc_491521501755_item	3714926	et	0	main
ka	doc_491521501755_item	3714927	et	0	main
lause	doc_491521501755_item	3714928	et	0	main
sisu	doc_491521501755_item	3714929	et	0	main
sõnade	doc_491521501755_item	3714930	et	0	main
vale	doc_491521501755_item	3714931	et	0	main
järjekord	doc_491521501755_item	3714932	et	0	main
lauses	doc_491521501755_item	3714933	et	0	main
muud	doc_491521501755_item	3714934	et	0	main
vead	doc_491521501755_item	3714935	et	0	main
mul	doc_491521501755_item	3714936	et	0	main
on	doc_491521501755_item	3714937	et	0	main
püksid	doc_491521501755_item	3714938	et	0	main
seljas	doc_491521501755_item	3714939	et	0	main
vene	doc_491521501755_item	3714940	et	0	main
emakeelega	doc_491521501755_item	3714941	et	0	main
õppijal	doc_491521501755_item	3714942	et	0	main
on	doc_491521501755_item	3714943	et	0	main
raske	doc_491521501755_item	3714944	et	0	main
meelde	doc_491521501755_item	3714945	et	0	main
jätta	doc_491521501755_item	3714946	et	0	main
teatud	doc_491521501755_item	3714947	et	0	main
eesti	doc_491521501755_item	3714948	et	0	main
keele	doc_491521501755_item	3714949	et	0	main
eripära	doc_491521501755_item	3714950	et	0	main
et	doc_491521501755_item	3714951	et	0	main
riietusest	doc_491521501755_item	3714952	et	0	main
rääkides	doc_491521501755_item	3714953	et	0	main
tuleb	doc_491521501755_item	3714954	et	0	main
märkida	doc_491521501755_item	3714955	et	0	main
ka	doc_491521501755_item	3714956	et	0	main
sellega	doc_491521501755_item	3714957	et	0	main
seotud	doc_491521501755_item	3714958	et	0	main
kehaosa	doc_491521501755_item	3714959	et	0	main
antud	doc_491521501755_item	3714960	et	0	main
juhul	doc_491521501755_item	3714961	et	0	main
on	doc_491521501755_item	3714962	et	0	main
tegemist	doc_491521501755_item	3714963	et	0	main
ilmselt	doc_491521501755_item	3714964	et	0	main
kehaosa	doc_491521501755_item	3714965	et	0	main
määratlemise	doc_491521501755_item	3714966	et	0	main
probleemiga	doc_491521501755_item	3714967	et	0	main
vrd	doc_491521501755_item	3714968	et	0	main
nt	doc_491521501755_item	3714969	et	0	main
jalatsid	doc_491521501755_item	3714970	et	0	main
ja	doc_491521501755_item	3714971	et	0	main
sukad	doc_491521501755_item	3714972	et	0	main
on	doc_491521501755_item	3714973	et	0	main
selgelt	doc_491521501755_item	3714974	et	0	main
jalas	doc_491521501755_item	3714975	et	0	main
jope	doc_491521501755_item	3714976	et	0	main
on	doc_491521501755_item	3714977	et	0	main
seljas	doc_491521501755_item	3714978	et	0	main
sellised	doc_491521501755_item	3714979	et	0	main
asjad	doc_491521501755_item	3714980	et	0	main
nagu	doc_491521501755_item	3714981	et	0	main
nt	doc_491521501755_item	3714982	et	0	main
püksid	doc_491521501755_item	3714983	et	0	main
või	doc_491521501755_item	3714984	et	0	main
ülikond	doc_491521501755_item	3714985	et	0	main
tekitavad	doc_491521501755_item	3714986	et	0	main
vene	doc_491521501755_item	3714987	et	0	main
emakeelega	doc_491521501755_item	3714988	et	0	main
õppijatel	doc_491521501755_item	3714989	et	0	main
kahtlusi	doc_491521501755_item	3714990	et	0	main
eriti	doc_491521501755_item	3714991	et	0	main
algetapil	doc_491521501755_item	3714992	et	0	main
lumepall	doc_491521501755_item	3714993	et	0	main
oli	doc_491521501755_item	3714994	et	0	main
nii	doc_491521501755_item	3714995	et	0	main
suur	doc_491521501755_item	3714996	et	0	main
nagu	doc_491521501755_item	3714997	et	0	main
jalgpall	doc_491521501755_item	3714998	et	0	main
siin	doc_491521501755_item	3714999	et	0	main
on	doc_491521501755_item	3715000	et	0	main
tegemist	doc_491521501755_item	3715001	et	0	main
kahe	doc_491521501755_item	3715002	et	0	main
mõiste	doc_491521501755_item	3715003	et	0	main
jalgpall	doc_491521501755_item	3715004	et	0	main
ja	doc_491521501755_item	3715005	et	0	main
jalgpalli	doc_491521501755_item	3715006	et	0	main
pall	doc_491521501755_item	3715007	et	0	main
segiajamisega	doc_491521501755_item	3715008	et	0	main
lubja	doc_491521501755_item	3715009	et	0	main
tänavas	doc_491521501755_item	3715010	et	0	main
asunud	doc_491521501755_item	3715011	et	0	main
tehas	doc_491521501755_item	3715012	et	0	main
oli	doc_491521501755_item	3715013	et	0	main
amortiseerunud	doc_491521501755_item	3715014	et	0	main
ja	doc_491521501755_item	3715015	et	0	main
ennes	doc_491521501755_item	3715016	et	0	main
või	doc_491521501755_item	3715017	et	0	main
ellis	doc_491521501755_item	3715018	et	0	main
toodetud	doc_491521501755_item	3715019	et	0	main
seepi	doc_491521501755_item	3715020	et	0	main
piisas	doc_491521501755_item	3715021	et	0	main
ka	doc_491521501755_item	3715022	et	0	main
meie	doc_491521501755_item	3715023	et	0	main
jaoks	doc_491521501755_item	3715024	et	0	main
ja	doc_491521501755_item	3715025	et	0	main
nsvl-s	doc_491521501755_item	3715026	et	0	main
toodetud	doc_491521501755_item	3715027	et	0	main
seepi	doc_491521501755_item	3715028	et	0	main
piisas	doc_491521501755_item	3715029	et	0	main
ka	doc_491521501755_item	3715030	et	0	main
meie	doc_491521501755_item	3715031	et	0	main
jaoks	doc_491521501755_item	3715032	et	0	main
antud	doc_491521501755_item	3715033	et	0	main
viga	doc_491521501755_item	3715034	et	0	main
on	doc_491521501755_item	3715035	et	0	main
võetud	doc_491521501755_item	3715036	et	0	main
etteütlusest	doc_491521501755_item	3715037	et	0	main
õppija	doc_491521501755_item	3715038	et	0	main
kirjutas	doc_491521501755_item	3715039	et	0	main
kuulmise	doc_491521501755_item	3715040	et	0	main
järgi	doc_491521501755_item	3715041	et	0	main
kuigi	doc_491521501755_item	3715042	et	0	main
ei	doc_491521501755_item	3715043	et	0	main
saanud	doc_491521501755_item	3715044	et	0	main
kirjutatud	doc_491521501755_item	3715045	et	0	main
sõnadest	doc_491521501755_item	3715046	et	0	main
aru	doc_491521501755_item	3715047	et	0	main
pole	doc_491521501755_item	3715048	et	0	main
kahtlust	doc_491521501755_item	3715049	et	0	main
et	doc_491521501755_item	3715050	et	0	main
tööriietusel	doc_491521501755_item	3715051	et	0	main
ei	doc_491521501755_item	3715052	et	0	main
ole	doc_491521501755_item	3715053	et	0	main
firma	doc_491521501755_item	3715054	et	0	main
tegevuses	doc_491521501755_item	3715055	et	0	main
tähtsust	doc_491521501755_item	3715056	et	0	main
pole	doc_491521501755_item	3715057	et	0	main
kahtlust	doc_491521501755_item	3715058	et	0	main
et	doc_491521501755_item	3715059	et	0	main
tööriietusel	doc_491521501755_item	3715060	et	0	main
ei	doc_491521501755_item	3715061	et	0	main
ole	doc_491521501755_item	3715062	et	0	main
firma	doc_491521501755_item	3715063	et	0	main
tegevuses	doc_491521501755_item	3715064	et	0	main
sugugi	doc_491521501755_item	3715065	et	0	main
tähtsuseta	doc_491521501755_item	3715066	et	0	main
osa	doc_491521501755_item	3715067	et	0	main
viga	doc_491521501755_item	3715068	et	0	main
on	doc_491521501755_item	3715069	et	0	main
võetud	doc_491521501755_item	3715070	et	0	main
samuti	doc_491521501755_item	3715071	et	0	main
etteütlusest	doc_491521501755_item	3715072	et	0	main
vea	doc_491521501755_item	3715073	et	0	main
põhjus	doc_491521501755_item	3715074	et	0	main
on	doc_491521501755_item	3715075	et	0	main
sama	doc_491521501755_item	3715076	et	0	main
mis	doc_491521501755_item	3715077	et	0	main
ka	doc_491521501755_item	3715078	et	0	main
eelmise	doc_491521501755_item	3715079	et	0	main
näite	doc_491521501755_item	3715080	et	0	main
puhul	doc_491521501755_item	3715081	et	0	main
õppija	doc_491521501755_item	3715082	et	0	main
kirjutas	doc_491521501755_item	3715083	et	0	main
seda	doc_491521501755_item	3715084	et	0	main
mis	doc_491521501755_item	3715085	et	0	main
jäi	doc_491521501755_item	3715086	et	0	main
talle	doc_491521501755_item	3715087	et	0	main
meelde	doc_491521501755_item	3715088	et	0	main
hoolimata	doc_491521501755_item	3715089	et	0	main
sellest	doc_491521501755_item	3715090	et	0	main
et	doc_491521501755_item	3715091	et	0	main
lause	doc_491521501755_item	3715092	et	0	main
sisu	doc_491521501755_item	3715093	et	0	main
on	doc_491521501755_item	3715094	et	0	main
täiesti	doc_491521501755_item	3715095	et	0	main
muutunud	doc_491521501755_item	3715096	et	0	main
kokkuvõte	doc_491521501755_item	3715097	et	0	main
käesolev	doc_491521501755_item	3715098	et	0	main
veaanalüüs	doc_491521501755_item	3715099	et	0	main
võimaldab	doc_491521501755_item	3715100	et	0	main
järeldada	doc_491521501755_item	3715101	et	0	main
et	doc_491521501755_item	3715102	et	0	main
võõrkeele	doc_491521501755_item	3715103	et	0	main
õppimise	doc_491521501755_item	3715104	et	0	main
algetapil	doc_491521501755_item	3715105	et	0	main
põhjustab	doc_491521501755_item	3715106	et	0	main
kõige	doc_491521501755_item	3715107	et	0	main
rohkem	doc_491521501755_item	3715108	et	0	main
vigu	doc_491521501755_item	3715109	et	0	main
emakeele	doc_491521501755_item	3715110	et	0	main
interferents	doc_491521501755_item	3715111	et	0	main
ehk	doc_491521501755_item	3715112	et	0	main
emakeele	doc_491521501755_item	3715113	et	0	main
mõju	doc_491521501755_item	3715114	et	0	main
siis	doc_491521501755_item	3715115	et	0	main
kui	doc_491521501755_item	3715116	et	0	main
inimene	doc_491521501755_item	3715117	et	0	main
alles	doc_491521501755_item	3715118	et	0	main
hakkab	doc_491521501755_item	3715119	et	0	main
võõrkeelt	doc_491521501755_item	3715120	et	0	main
antud	doc_491521501755_item	3715121	et	0	main
juhul	doc_491521501755_item	3715122	et	0	main
eesti	doc_491521501755_item	3715123	et	0	main
keelt	doc_491521501755_item	3715124	et	0	main
õppima	doc_491521501755_item	3715125	et	0	main
püüab	doc_491521501755_item	3715126	et	0	main
ta	doc_491521501755_item	3715127	et	0	main
oma	doc_491521501755_item	3715128	et	0	main
emakeelt	doc_491521501755_item	3715129	et	0	main
abiks	doc_491521501755_item	3715130	et	0	main
võtta	doc_491521501755_item	3715131	et	0	main
kannab	doc_491521501755_item	3715132	et	0	main
emakeeles	doc_491521501755_item	3715133	et	0	main
kehtivad	doc_491521501755_item	3715134	et	0	main
reeglid	doc_491521501755_item	3715135	et	0	main
sihtlkeelde	doc_491521501755_item	3715136	et	0	main
üle	doc_491521501755_item	3715137	et	0	main
kasutab	doc_491521501755_item	3715138	et	0	main
palju	doc_491521501755_item	3715139	et	0	main
otsetõlget	doc_491521501755_item	3715140	et	0	main
ei	doc_491521501755_item	3715141	et	0	main
arvesta	doc_491521501755_item	3715142	et	0	main
sihtkeele	doc_491521501755_item	3715143	et	0	main
eripärasustega	doc_491521501755_item	3715144	et	0	main
siit	doc_491521501755_item	3715145	et	0	main
tulenevad	doc_491521501755_item	3715146	et	0	main
sellised	doc_491521501755_item	3715147	et	0	main
tüüpilised	doc_491521501755_item	3715148	et	0	main
vead	doc_491521501755_item	3715149	et	0	main
nagu	doc_491521501755_item	3715150	et	0	main
vale	doc_491521501755_item	3715151	et	0	main
verbirektsiooni	doc_491521501755_item	3715152	et	0	main
kasutamine	doc_491521501755_item	3715153	et	0	main
või	doc_491521501755_item	3715154	et	0	main
näiteks	doc_491521501755_item	3715155	et	0	main
lausemoodustuses	doc_491521501755_item	3715156	et	0	main
sõnade	doc_491521501755_item	3715157	et	0	main
vale	doc_491521501755_item	3715158	et	0	main
järjekord	doc_491521501755_item	3715159	et	0	main
liiga	doc_491521501755_item	3715160	et	0	main
pikad	doc_491521501755_item	3715161	et	0	main
ja	doc_491521501755_item	3715162	et	0	main
keerulised	doc_491521501755_item	3715163	et	0	main
ja	doc_491521501755_item	3715164	et	0	main
stiililt	doc_491521501755_item	3715165	et	0	main
ebakorrektsed	doc_491521501755_item	3715166	et	0	main
laused	doc_491521501755_item	3715167	et	0	main
jne	doc_491521501755_item	3715168	et	0	main
kõige	doc_491521501755_item	3715169	et	0	main
rohkem	doc_491521501755_item	3715170	et	0	main
raskusi	doc_491521501755_item	3715171	et	0	main
aga	doc_491521501755_item	3715172	et	0	main
valmistavad	doc_491521501755_item	3715173	et	0	main
õppijale	doc_491521501755_item	3715174	et	0	main
sellised	doc_491521501755_item	3715175	et	0	main
võõrkeele	doc_491521501755_item	3715176	et	0	main
kategooriad	doc_491521501755_item	3715177	et	0	main
ja	doc_491521501755_item	3715178	et	0	main
mõisted	doc_491521501755_item	3715179	et	0	main
millele	doc_491521501755_item	3715180	et	0	main
ei	doc_491521501755_item	3715181	et	0	main
ole	doc_491521501755_item	3715182	et	0	main
vastet	doc_491521501755_item	3715183	et	0	main
tema	doc_491521501755_item	3715184	et	0	main
emakeeles	doc_491521501755_item	3715185	et	0	main
eesti	doc_491521501755_item	3715186	et	0	main
keele	doc_491521501755_item	3715187	et	0	main
puhul	doc_491521501755_item	3715188	et	0	main
on	doc_491521501755_item	3715189	et	0	main
need	doc_491521501755_item	3715190	et	0	main
näiteks	doc_491521501755_item	3715191	et	0	main
ma-	doc_491521501755_item	3715192	et	0	main
ja	doc_491521501755_item	3715193	et	0	main
da-infinitiiv	doc_491521501755_item	3715194	et	0	main
sise-	doc_491521501755_item	3715195	et	0	main
ja	doc_491521501755_item	3715196	et	0	main
väliskohakäänded	doc_491521501755_item	3715197	et	0	main
ühendverbid	doc_491521501755_item	3715198	et	0	main
analüüs	doc_491521501889_item	3718305	et	0	main
tallinna	doc_491521501889_item	3718306	et	0	main
pedagoogikaülikool	doc_491521501889_item	3718307	et	0	main
veaanalüüs	doc_491521501889_item	3718308	et	0	main
rebane	doc_491521501889_item	3718309	et	0	main
ja	doc_491521501889_item	3718310	et	0	main
jänes	doc_491521501889_item	3718311	et	0	main
eesnimi	doc_491521501889_item	3718312	et	0	main
perekonnanimi	doc_491521501889_item	3718313	et	0	main
juhendaja	doc_491521501889_item	3718314	et	0	main
e	doc_491521501889_item	3718315	et	0	main
perekonnanimi	doc_491521501889_item	3718316	et	0	main
tallinn	doc_491521501889_item	3718317	et	0	main
2001	doc_491521501889_item	3718318	et	0	main
harjutamine	doc_491521501889_item	3718319	et	0	main
teeb	doc_491521501889_item	3718320	et	0	main
meistriks	doc_491521501889_item	3718321	et	0	main
kirjutamine	doc_491521501889_item	3718322	et	0	main
see	doc_491521501889_item	3718323	et	0	main
on	doc_491521501889_item	3718324	et	0	main
vist	doc_491521501889_item	3718325	et	0	main
iga	doc_491521501889_item	3718326	et	0	main
keele	doc_491521501889_item	3718327	et	0	main
kõige	doc_491521501889_item	3718328	et	0	main
raskem	doc_491521501889_item	3718329	et	0	main
osa	doc_491521501889_item	3718330	et	0	main
kõik	doc_491521501889_item	3718331	et	0	main
inimesed	doc_491521501889_item	3718332	et	0	main
kes	doc_491521501889_item	3718333	et	0	main
on	doc_491521501889_item	3718334	et	0	main
kunagi	doc_491521501889_item	3718335	et	0	main
kirjutamisega	doc_491521501889_item	3718336	et	0	main
tegelenud	doc_491521501889_item	3718337	et	0	main
võivad	doc_491521501889_item	3718338	et	0	main
öelda	doc_491521501889_item	3718339	et	0	main
et	doc_491521501889_item	3718340	et	0	main
isegi	doc_491521501889_item	3718341	et	0	main
lihtsa	doc_491521501889_item	3718342	et	0	main
kirja	doc_491521501889_item	3718343	et	0	main
koostamiseks	doc_491521501889_item	3718344	et	0	main
on	doc_491521501889_item	3718345	et	0	main
vaja	doc_491521501889_item	3718346	et	0	main
õiget	doc_491521501889_item	3718347	et	0	main
meeleolu	doc_491521501889_item	3718348	et	0	main
mõnikord	doc_491521501889_item	3718349	et	0	main
on	doc_491521501889_item	3718350	et	0	main
liikumapanevaks	doc_491521501889_item	3718351	et	0	main
jõuks	doc_491521501889_item	3718352	et	0	main
vajadus	doc_491521501889_item	3718353	et	0	main
või	doc_491521501889_item	3718354	et	0	main
sundus	doc_491521501889_item	3718355	et	0	main
kas	doc_491521501889_item	3718356	et	0	main
tuleb	doc_491521501889_item	3718357	et	0	main
tuttav	doc_491521501889_item	3718358	et	0	main
ette	doc_491521501889_item	3718359	et	0	main
istumine	doc_491521501889_item	3718360	et	0	main
laua	doc_491521501889_item	3718361	et	0	main
taga	doc_491521501889_item	3718362	et	0	main
ees	doc_491521501889_item	3718363	et	0	main
puhas	doc_491521501889_item	3718364	et	0	main
paberileht	doc_491521501889_item	3718365	et	0	main
ja	doc_491521501889_item	3718366	et	0	main
pea	doc_491521501889_item	3718367	et	0	main
kohal	doc_491521501889_item	3718368	et	0	main
kummitamas	doc_491521501889_item	3718369	et	0	main
kohustus	doc_491521501889_item	3718370	et	0	main
kirjutada	doc_491521501889_item	3718371	et	0	main
teema	doc_491521501889_item	3718372	et	0	main
on	doc_491521501889_item	3718373	et	0	main
teada	doc_491521501889_item	3718374	et	0	main
aga	doc_491521501889_item	3718375	et	0	main
peas	doc_491521501889_item	3718376	et	0	main
liikuvad	doc_491521501889_item	3718377	et	0	main
hoopis	doc_491521501889_item	3718378	et	0	main
teised	doc_491521501889_item	3718379	et	0	main
mõtted	doc_491521501889_item	3718380	et	0	main
aeg	doc_491521501889_item	3718381	et	0	main
läheb	doc_491521501889_item	3718382	et	0	main
ning	doc_491521501889_item	3718383	et	0	main
pikapeale	doc_491521501889_item	3718384	et	0	main
hiilib	doc_491521501889_item	3718385	et	0	main
lähemale	doc_491521501889_item	3718386	et	0	main
paanika	doc_491521501889_item	3718387	et	0	main
veel	doc_491521501889_item	3718388	et	0	main
hullem	doc_491521501889_item	3718389	et	0	main
aga	doc_491521501889_item	3718390	et	0	main
kui	doc_491521501889_item	3718391	et	0	main
sõnavarast	doc_491521501889_item	3718392	et	0	main
ei	doc_491521501889_item	3718393	et	0	main
piisa	doc_491521501889_item	3718394	et	0	main
eneseväljendamiseks	doc_491521501889_item	3718395	et	0	main
või	doc_491521501889_item	3718396	et	0	main
iga	doc_491521501889_item	3718397	et	0	main
uue	doc_491521501889_item	3718398	et	0	main
sõna	doc_491521501889_item	3718399	et	0	main
kirjapanek	doc_491521501889_item	3718400	et	0	main
tekitab	doc_491521501889_item	3718401	et	0	main
raskusi	doc_491521501889_item	3718402	et	0	main
õppijad	doc_491521501889_item	3718403	et	0	main
kurdavad	doc_491521501889_item	3718404	et	0	main
alati	doc_491521501889_item	3718405	et	0	main
et	doc_491521501889_item	3718406	et	0	main
kirjutamine	doc_491521501889_item	3718407	et	0	main
nõuab	doc_491521501889_item	3718408	et	0	main
aega	doc_491521501889_item	3718409	et	0	main
ja	doc_491521501889_item	3718410	et	0	main
pingutust	doc_491521501889_item	3718411	et	0	main
kirjutatuga	doc_491521501889_item	3718412	et	0	main
aga	doc_491521501889_item	3718413	et	0	main
sageli	doc_491521501889_item	3718414	et	0	main
ei	doc_491521501889_item	3718415	et	0	main
jääda	doc_491521501889_item	3718416	et	0	main
rahule	doc_491521501889_item	3718417	et	0	main
õpetaja	doc_491521501889_item	3718418	et	0	main
annab	doc_491521501889_item	3718419	et	0	main
tagasi	doc_491521501889_item	3718420	et	0	main
punasekirju	doc_491521501889_item	3718421	et	0	main
töö	doc_491521501889_item	3718422	et	0	main
viletsa	doc_491521501889_item	3718423	et	0	main
või	doc_491521501889_item	3718424	et	0	main
keskpärase	doc_491521501889_item	3718425	et	0	main
hindega	doc_491521501889_item	3718426	et	0	main
mis	doc_491521501889_item	3718427	et	0	main
annab	doc_491521501889_item	3718428	et	0	main
õppijale	doc_491521501889_item	3718429	et	0	main
aimu	doc_491521501889_item	3718430	et	0	main
tema	doc_491521501889_item	3718431	et	0	main
võimetusest	doc_491521501889_item	3718432	et	0	main
nii	doc_491521501889_item	3718433	et	0	main
et	doc_491521501889_item	3718434	et	0	main
huvituta	doc_491521501889_item	3718435	et	0	main
lõpuks	doc_491521501889_item	3718436	et	0	main
enam	doc_491521501889_item	3718437	et	0	main
sellest	doc_491521501889_item	3718438	et	0	main
kuidas	doc_491521501889_item	3718439	et	0	main
kirjutada	doc_491521501889_item	3718440	et	0	main
mis	doc_491521501889_item	3718441	et	0	main
omakorda	doc_491521501889_item	3718442	et	0	main
eriti	doc_491521501889_item	3718443	et	0	main
ei	doc_491521501889_item	3718444	et	0	main
rõõmusta	doc_491521501889_item	3718445	et	0	main
pedagooge	doc_491521501889_item	3718446	et	0	main
lisaks	doc_491521501889_item	3718447	et	0	main
on	doc_491521501889_item	3718448	et	0	main
veel	doc_491521501889_item	3718449	et	0	main
ka	doc_491521501889_item	3718450	et	0	main
paliu	doc_491521501889_item	3718451	et	0	main
teisi	doc_491521501889_item	3718452	et	0	main
raskusi	doc_491521501889_item	3718453	et	0	main
häid	doc_491521501889_item	3718454	et	0	main
eakohaseid	doc_491521501889_item	3718455	et	0	main
teemasid	doc_491521501889_item	3718456	et	0	main
on	doc_491521501889_item	3718457	et	0	main
raske	doc_491521501889_item	3718458	et	0	main
leida	doc_491521501889_item	3718459	et	0	main
õpilased	doc_491521501889_item	3718460	et	0	main
nurisevad	doc_491521501889_item	3718461	et	0	main
ülesannet	doc_491521501889_item	3718462	et	0	main
saades	doc_491521501889_item	3718463	et	0	main
tööde	doc_491521501889_item	3718464	et	0	main
parandamine	doc_491521501889_item	3718465	et	0	main
võtab	doc_491521501889_item	3718466	et	0	main
palju	doc_491521501889_item	3718467	et	0	main
aega	doc_491521501889_item	3718468	et	0	main
ja	doc_491521501889_item	3718469	et	0	main
nendega	doc_491521501889_item	3718470	et	0	main
rahulolematuses	doc_491521501889_item	3718471	et	0	main
peegeldub	doc_491521501889_item	3718472	et	0	main
ka	doc_491521501889_item	3718473	et	0	main
õpetajate	doc_491521501889_item	3718474	et	0	main
endi	doc_491521501889_item	3718475	et	0	main
möödalaskmistes	doc_491521501889_item	3718476	et	0	main
samas	doc_491521501889_item	3718477	et	0	main
aga	doc_491521501889_item	3718478	et	0	main
kirjutada	doc_491521501889_item	3718479	et	0	main
on	doc_491521501889_item	3718480	et	0	main
vaja	doc_491521501889_item	3718481	et	0	main
ja	doc_491521501889_item	3718482	et	0	main
tuleb	doc_491521501889_item	3718483	et	0	main
kasvõi	doc_491521501889_item	3718484	et	0	main
seetõttu	doc_491521501889_item	3718485	et	0	main
et	doc_491521501889_item	3718486	et	0	main
see	doc_491521501889_item	3718487	et	0	main
on	doc_491521501889_item	3718488	et	0	main
tähtis	doc_491521501889_item	3718489	et	0	main
testide	doc_491521501889_item	3718490	et	0	main
riigieksamite	doc_491521501889_item	3718491	et	0	main
osa	doc_491521501889_item	3718492	et	0	main
ja	doc_491521501889_item	3718493	et	0	main
mida	doc_491521501889_item	3718494	et	0	main
varem	doc_491521501889_item	3718495	et	0	main
seda	doc_491521501889_item	3718496	et	0	main
hakatakse	doc_491521501889_item	3718497	et	0	main
õpetama	doc_491521501889_item	3718498	et	0	main
ning	doc_491521501889_item	3718499	et	0	main
harjutama	doc_491521501889_item	3718500	et	0	main
seda	doc_491521501889_item	3718501	et	0	main
varem	doc_491521501889_item	3718502	et	0	main
hakkab	doc_491521501889_item	3718503	et	0	main
ka	doc_491521501889_item	3718504	et	0	main
õppija	doc_491521501889_item	3718505	et	0	main
ladusamalt	doc_491521501889_item	3718506	et	0	main
kirjutama	doc_491521501889_item	3718507	et	0	main
töötades	doc_491521501889_item	3718508	et	0	main
koolis	doc_491521501889_item	3718509	et	0	main
eesti	doc_491521501889_item	3718510	et	0	main
keele	doc_491521501889_item	3718511	et	0	main
õpetajana	doc_491521501889_item	3718512	et	0	main
olen	doc_491521501889_item	3718513	et	0	main
tähele	doc_491521501889_item	3718514	et	0	main
pannud	doc_491521501889_item	3718515	et	0	main
et	doc_491521501889_item	3718516	et	0	main
kõige	doc_491521501889_item	3718517	et	0	main
rohkem	doc_491521501889_item	3718518	et	0	main
eksitakse	doc_491521501889_item	3718519	et	0	main
ma-	doc_491521501889_item	3718520	et	0	main
da-infinitiivi	doc_491521501889_item	3718521	et	0	main
verbi	doc_491521501889_item	3718522	et	0	main
põhivormide	doc_491521501889_item	3718523	et	0	main
kasutuses	doc_491521501889_item	3718524	et	0	main
nii	doc_491521501889_item	3718525	et	0	main
näiteks	doc_491521501889_item	3718526	et	0	main
võib	doc_491521501889_item	3718527	et	0	main
tihti	doc_491521501889_item	3718528	et	0	main
näha	doc_491521501889_item	3718529	et	0	main
selliseid	doc_491521501889_item	3718530	et	0	main
vorme	doc_491521501889_item	3718531	et	0	main
nagu	doc_491521501889_item	3718532	et	0	main
lugevad	doc_491521501889_item	3718533	et	0	main
olevad	doc_491521501889_item	3718534	et	0	main
meeldib	doc_491521501889_item	3718535	et	0	main
hobutsema	doc_491521501889_item	3718536	et	0	main
ratsutada	doc_491521501889_item	3718537	et	0	main
või	doc_491521501889_item	3718538	et	0	main
tahan	doc_491521501889_item	3718539	et	0	main
õppima	doc_491521501889_item	3718540	et	0	main
pilisima	doc_491521501889_item	3718541	et	0	main
pilliga	doc_491521501889_item	3718542	et	0	main
rnängima	doc_491521501889_item	3718543	et	0	main
pean	doc_491521501889_item	3718544	et	0	main
koristada	doc_491521501889_item	3718545	et	0	main
ning	doc_491521501889_item	3718546	et	0	main
klusiilide	doc_491521501889_item	3718547	et	0	main
näiteks	doc_491521501889_item	3718548	et	0	main
võtan	doc_491521501889_item	3718549	et	0	main
vihikud	doc_491521501889_item	3718550	et	0	main
raamatud	doc_491521501889_item	3718551	et	0	main
joonlautu	doc_491521501889_item	3718552	et	0	main
istun	doc_491521501889_item	3718553	et	0	main
neljantas	doc_491521501889_item	3718554	et	0	main
pinkis	doc_491521501889_item	3718555	et	0	main
ja	doc_491521501889_item	3718556	et	0	main
diftongide	doc_491521501889_item	3718557	et	0	main
näiteks	doc_491521501889_item	3718558	et	0	main
soja	doc_491521501889_item	3718559	et	0	main
sooja	doc_491521501889_item	3718560	et	0	main
kusk	doc_491521501889_item	3718561	et	0	main
kuusk	doc_491521501889_item	3718562	et	0	main
vatan	doc_491521501889_item	3718563	et	0	main
vaatan	doc_491521501889_item	3718564	et	0	main
tomingas	doc_491521501889_item	3718565	et	0	main
toomingas	doc_491521501889_item	3718566	et	0	main
tema	doc_491521501889_item	3718567	et	0	main
jurde	doc_491521501889_item	3718568	et	0	main
juurde	doc_491521501889_item	3718569	et	0	main
õigekirjas	doc_491521501889_item	3718570	et	0	main
nõnda	doc_491521501889_item	3718571	et	0	main
proovisin	doc_491521501889_item	3718572	et	0	main
just	doc_491521501889_item	3718573	et	0	main
antud	doc_491521501889_item	3718574	et	0	main
grammatika	doc_491521501889_item	3718575	et	0	main
osa	doc_491521501889_item	3718576	et	0	main
eriti	doc_491521501889_item	3718577	et	0	main
rõhutada	doc_491521501889_item	3718578	et	0	main
andes	doc_491521501889_item	3718579	et	0	main
tunni	doc_491521501889_item	3718580	et	0	main
ajal	doc_491521501889_item	3718581	et	0	main
nende	doc_491521501889_item	3718582	et	0	main
teemadega	doc_491521501889_item	3718583	et	0	main
seotud	doc_491521501889_item	3718584	et	0	main
lisaülesandeid	doc_491521501889_item	3718585	et	0	main
ja	doc_491521501889_item	3718586	et	0	main
harjutades	doc_491521501889_item	3718587	et	0	main
suulises	doc_491521501889_item	3718588	et	0	main
kõnes	doc_491521501889_item	3718589	et	0	main
teatud	doc_491521501889_item	3718590	et	0	main
šabloonlauseid	doc_491521501889_item	3718591	et	0	main
või	doc_491521501889_item	3718592	et	0	main
mudeleid	doc_491521501889_item	3718593	et	0	main
nt	doc_491521501889_item	3718594	et	0	main
hakkama-tulema-	doc_491521501889_item	3718595	et	0	main
verb	doc_491521501889_item	3718596	et	0	main
õige	doc_491521501889_item	3718597	et	0	main
infinitiiviga	doc_491521501889_item	3718598	et	0	main
lõpus	doc_491521501889_item	3718599	et	0	main
samas	doc_491521501889_item	3718600	et	0	main
aga	doc_491521501889_item	3718601	et	0	main
tuleb	doc_491521501889_item	3718602	et	0	main
mainida	doc_491521501889_item	3718603	et	0	main
et	doc_491521501889_item	3718604	et	0	main
kui	doc_491521501889_item	3718605	et	0	main
õppijal	doc_491521501889_item	3718606	et	0	main
tuleb	doc_491521501889_item	3718607	et	0	main
lahendada	doc_491521501889_item	3718608	et	0	main
konkreetseid	doc_491521501889_item	3718609	et	0	main
ülesandeid	doc_491521501889_item	3718610	et	0	main
ühekahe	doc_491521501889_item	3718611	et	0	main
reegli	doc_491521501889_item	3718612	et	0	main
peal	doc_491521501889_item	3718613	et	0	main
eksib	doc_491521501889_item	3718614	et	0	main
ta	doc_491521501889_item	3718615	et	0	main
märksa	doc_491521501889_item	3718616	et	0	main
vähem	doc_491521501889_item	3718617	et	0	main
võrreldes	doc_491521501889_item	3718618	et	0	main
esseedekirjandite	doc_491521501889_item	3718619	et	0	main
kirjutamisega	doc_491521501889_item	3718620	et	0	main
elus	doc_491521501889_item	3718621	et	0	main
aga	doc_491521501889_item	3718622	et	0	main
tuleb	doc_491521501889_item	3718623	et	0	main
palju	doc_491521501889_item	3718624	et	0	main
rohkem	doc_491521501889_item	3718625	et	0	main
selliseid	doc_491521501889_item	3718626	et	0	main
situatsioone	doc_491521501889_item	3718627	et	0	main
ette	doc_491521501889_item	3718628	et	0	main
kus	doc_491521501889_item	3718629	et	0	main
pead	doc_491521501889_item	3718630	et	0	main
just	doc_491521501889_item	3718631	et	0	main
spontaanse	doc_491521501889_item	3718632	et	0	main
teksti	doc_491521501889_item	3718633	et	0	main
produtseerima	doc_491521501889_item	3718634	et	0	main
mitte	doc_491521501889_item	3718635	et	0	main
aga	doc_491521501889_item	3718636	et	0	main
tüüpväljenditega	doc_491521501889_item	3718637	et	0	main
piirduma	doc_491521501889_item	3718638	et	0	main
siinkohal	doc_491521501889_item	3718639	et	0	main
aga	doc_491521501889_item	3718640	et	0	main
tuleb	doc_491521501889_item	3718641	et	0	main
mainida	doc_491521501889_item	3718642	et	0	main
et	doc_491521501889_item	3718643	et	0	main
töötades	doc_491521501889_item	3718644	et	0	main
teises	doc_491521501889_item	3718645	et	0	main
vahetuses	doc_491521501889_item	3718646	et	0	main
ehk	doc_491521501889_item	3718647	et	0	main
kella	doc_491521501889_item	3718648	et	0	main
14-st	doc_491521501889_item	3718649	et	0	main
20-ni	doc_491521501889_item	3718650	et	0	main
pole	doc_491521501889_item	3718651	et	0	main
ma	doc_491521501889_item	3718652	et	0	main
ise	doc_491521501889_item	3718653	et	0	main
tunni	doc_491521501889_item	3718654	et	0	main
ajal	doc_491521501889_item	3718655	et	0	main
kirjandite	doc_491521501889_item	3718656	et	0	main
koostamise	doc_491521501889_item	3718657	et	0	main
pooldaja	doc_491521501889_item	3718658	et	0	main
jättes	doc_491521501889_item	3718659	et	0	main
neid	doc_491521501889_item	3718660	et	0	main
rohkem	doc_491521501889_item	3718661	et	0	main
kodutööks	doc_491521501889_item	3718662	et	0	main
ning	doc_491521501889_item	3718663	et	0	main
proovin	doc_491521501889_item	3718664	et	0	main
kasutada	doc_491521501889_item	3718665	et	0	main
ülesandeid	doc_491521501889_item	3718666	et	0	main
mis	doc_491521501889_item	3718667	et	0	main
võtavad	doc_491521501889_item	3718668	et	0	main
vähem	doc_491521501889_item	3718669	et	0	main
aega	doc_491521501889_item	3718670	et	0	main
ning	doc_491521501889_item	3718671	et	0	main
on	doc_491521501889_item	3718672	et	0	main
ka	doc_491521501889_item	3718673	et	0	main
natuke	doc_491521501889_item	3718674	et	0	main
põnevamad	doc_491521501889_item	3718675	et	0	main
selleks	doc_491521501889_item	3718676	et	0	main
on	doc_491521501889_item	3718677	et	0	main
ka	doc_491521501889_item	3718678	et	0	main
oma	doc_491521501889_item	3718679	et	0	main
põhjus	doc_491521501889_item	3718680	et	0	main
isikliku	doc_491521501889_item	3718681	et	0	main
kogemuse	doc_491521501889_item	3718682	et	0	main
põhjal	doc_491521501889_item	3718683	et	0	main
tean	doc_491521501889_item	3718684	et	0	main
et	doc_491521501889_item	3718685	et	0	main
isegi	doc_491521501889_item	3718686	et	0	main
kui	doc_491521501889_item	3718687	et	0	main
oled	doc_491521501889_item	3718688	et	0	main
esimese	doc_491521501889_item	3718689	et	0	main
poolpäeva	doc_491521501889_item	3718690	et	0	main
looderdanud	doc_491521501889_item	3718691	et	0	main
mis	doc_491521501889_item	3718692	et	0	main
kaugelt	doc_491521501889_item	3718693	et	0	main
ei	doc_491521501889_item	3718694	et	0	main
pruugi	doc_491521501889_item	3718695	et	0	main
nii	doc_491521501889_item	3718696	et	0	main
olla	doc_491521501889_item	3718697	et	0	main
tuled	doc_491521501889_item	3718698	et	0	main
kooli	doc_491521501889_item	3718699	et	0	main
pisut	doc_491521501889_item	3718700	et	0	main
väsinuna	doc_491521501889_item	3718701	et	0	main
ning	doc_491521501889_item	3718702	et	0	main
siis	doc_491521501889_item	3718703	et	0	main
ei	doc_491521501889_item	3718704	et	0	main
jaksa	doc_491521501889_item	3718705	et	0	main
pea	doc_491521501889_item	3718706	et	0	main
kella	doc_491521501889_item	3718707	et	0	main
18-ks	doc_491521501889_item	3718708	et	0	main
või	doc_491521501889_item	3718709	et	0	main
19-ks	doc_491521501889_item	3718710	et	0	main
paiku	doc_491521501889_item	3718711	et	0	main
absoluutselt	doc_491521501889_item	3718712	et	0	main
kaasa	doc_491521501889_item	3718713	et	0	main
mõelda	doc_491521501889_item	3718714	et	0	main
nõnda	doc_491521501889_item	3718715	et	0	main
üheks	doc_491521501889_item	3718716	et	0	main
mu	doc_491521501889_item	3718717	et	0	main
õpilaste	doc_491521501889_item	3718718	et	0	main
lemmikuks	doc_491521501889_item	3718719	et	0	main
on	doc_491521501889_item	3718720	et	0	main
vigased	doc_491521501889_item	3718721	et	0	main
jutud	doc_491521501889_item	3718722	et	0	main
kus	doc_491521501889_item	3718723	et	0	main
lähtudest	doc_491521501889_item	3718724	et	0	main
oma	doc_491521501889_item	3718725	et	0	main
kogemusest	doc_491521501889_item	3718726	et	0	main
varem	doc_491521501889_item	3718727	et	0	main
õpitud	doc_491521501889_item	3718728	et	0	main
materjalist	doc_491521501889_item	3718729	et	0	main
peavad	doc_491521501889_item	3718730	et	0	main
nad	doc_491521501889_item	3718731	et	0	main
parandama	doc_491521501889_item	3718732	et	0	main
õigekirja-	doc_491521501889_item	3718733	et	0	main
javõi	doc_491521501889_item	3718734	et	0	main
grammatikavigu	doc_491521501889_item	3718735	et	0	main
tavaliselt	doc_491521501889_item	3718736	et	0	main
korraldame	doc_491521501889_item	3718737	et	0	main
me	doc_491521501889_item	3718738	et	0	main
seda	doc_491521501889_item	3718739	et	0	main
võistluse	doc_491521501889_item	3718740	et	0	main
vormis	doc_491521501889_item	3718741	et	0	main
kusjuures	doc_491521501889_item	3718742	et	0	main
kõige	doc_491521501889_item	3718743	et	0	main
tublim	doc_491521501889_item	3718744	et	0	main
ja	doc_491521501889_item	3718745	et	0	main
kiirem	doc_491521501889_item	3718746	et	0	main
õpilane	doc_491521501889_item	3718747	et	0	main
pälvib	doc_491521501889_item	3718748	et	0	main
kirjatarga	doc_491521501889_item	3718749	et	0	main
tiitli	doc_491521501889_item	3718750	et	0	main
ja	doc_491521501889_item	3718751	et	0	main
ka	doc_491521501889_item	3718752	et	0	main
hea	doc_491521501889_item	3718753	et	0	main
hinde	doc_491521501889_item	3718754	et	0	main
päevikusse	doc_491521501889_item	3718755	et	0	main
töö	doc_491521501889_item	3718756	et	0	main
käigus	doc_491521501889_item	3718757	et	0	main
luban	doc_491521501889_item	3718758	et	0	main
kasutada	doc_491521501889_item	3718759	et	0	main
eesti-vene	doc_491521501889_item	3718760	et	0	main
õppesõnastike	doc_491521501889_item	3718761	et	0	main
kuna	doc_491521501889_item	3718762	et	0	main
arvan	doc_491521501889_item	3718763	et	0	main
et	doc_491521501889_item	3718764	et	0	main
nii	doc_491521501889_item	3718765	et	0	main
võib	doc_491521501889_item	3718766	et	0	main
harjuda	doc_491521501889_item	3718767	et	0	main
töötame	doc_491521501889_item	3718768	et	0	main
õppematerjaliga	doc_491521501889_item	3718769	et	0	main
mida	doc_491521501889_item	3718770	et	0	main
teatud	doc_491521501889_item	3718771	et	0	main
õpilased	doc_491521501889_item	3718772	et	0	main
isegi	doc_491521501889_item	3718773	et	0	main
gümnaasiumis	doc_491521501889_item	3718774	et	0	main
ei	doc_491521501889_item	3718775	et	0	main
oska	doc_491521501889_item	3718776	et	0	main
teha	doc_491521501889_item	3718777	et	0	main
ning	doc_491521501889_item	3718778	et	0	main
tänu	doc_491521501889_item	3718779	et	0	main
visuaalsele	doc_491521501889_item	3718780	et	0	main
mälule	doc_491521501889_item	3718781	et	0	main
jätta	doc_491521501889_item	3718782	et	0	main
kiiremini	doc_491521501889_item	3718783	et	0	main
meelde	doc_491521501889_item	3718784	et	0	main
õiget	doc_491521501889_item	3718785	et	0	main
kirjapilti	doc_491521501889_item	3718786	et	0	main
ja	doc_491521501889_item	3718787	et	0	main
ka	doc_491521501889_item	3718788	et	0	main
tihti	doc_491521501889_item	3718789	et	0	main
kohatava	doc_491521501889_item	3718790	et	0	main
sõna	doc_491521501889_item	3718791	et	0	main
tähenduse	doc_491521501889_item	3718792	et	0	main
aeg-ajalt	doc_491521501889_item	3718793	et	0	main
palun	doc_491521501889_item	3718794	et	0	main
ka	doc_491521501889_item	3718795	et	0	main
lisaks	doc_491521501889_item	3718796	et	0	main
saadud	doc_491521501889_item	3718797	et	0	main
teksti	doc_491521501889_item	3718798	et	0	main
kirjalikult	doc_491521501889_item	3718799	et	0	main
või	doc_491521501889_item	3718800	et	0	main
suuliselt	doc_491521501889_item	3718801	et	0	main
emakeelde	doc_491521501889_item	3718802	et	0	main
tõlkida	doc_491521501889_item	3718803	et	0	main
kuna	doc_491521501889_item	3718804	et	0	main
olen	doc_491521501889_item	3718805	et	0	main
kohtunud	doc_491521501889_item	3718806	et	0	main
sellega	doc_491521501889_item	3718807	et	0	main
et	doc_491521501889_item	3718808	et	0	main
põhikoolis	doc_491521501889_item	3718809	et	0	main
paljud	doc_491521501889_item	3718810	et	0	main
ei	doc_491521501889_item	3718811	et	0	main
ole	doc_491521501889_item	3718812	et	0	main
suutelised	doc_491521501889_item	3718813	et	0	main
eri	doc_491521501889_item	3718814	et	0	main
tähendusega	doc_491521501889_item	3718815	et	0	main
võõrkeelseid	doc_491521501889_item	3718816	et	0	main
sõnu	doc_491521501889_item	3718817	et	0	main
omavahel	doc_491521501889_item	3718818	et	0	main
siduma	doc_491521501889_item	3718819	et	0	main
tõlkides	doc_491521501889_item	3718820	et	0	main
neid	doc_491521501889_item	3718821	et	0	main
sõna-sõnaliselt	doc_491521501889_item	3718822	et	0	main
ja	doc_491521501889_item	3718823	et	0	main
saades	doc_491521501889_item	3718824	et	0	main
isegi	doc_491521501889_item	3718825	et	0	main
enda	doc_491521501889_item	3718826	et	0	main
jaoks	doc_491521501889_item	3718827	et	0	main
arusaamatu	doc_491521501889_item	3718828	et	0	main
kalambuuri	doc_491521501889_item	3718829	et	0	main
nagu	doc_491521501889_item	3718830	et	0	main
naiteks	doc_491521501889_item	3718831	et	0	main
seisis	doc_491521501889_item	3718832	et	0	main
kõrval	doc_491521501889_item	3718833	et	0	main
стоял	doc_491521501889_item	3718834	et	0	main
на	doc_491521501889_item	3718835	et	0	main
ушах	doc_491521501889_item	3718836	et	0	main
töid	doc_491521501889_item	3718837	et	0	main
kontrollides	doc_491521501889_item	3718838	et	0	main
parandan	doc_491521501889_item	3718839	et	0	main
vaid	doc_491521501889_item	3718840	et	0	main
neid	doc_491521501889_item	3718841	et	0	main
vigu	doc_491521501889_item	3718842	et	0	main
mis	doc_491521501889_item	3718843	et	0	main
puudutavad	doc_491521501889_item	3718844	et	0	main
selle	doc_491521501889_item	3718845	et	0	main
grammatika	doc_491521501889_item	3718846	et	0	main
osa	doc_491521501889_item	3718847	et	0	main
millega	doc_491521501889_item	3718848	et	0	main
õpilased	doc_491521501889_item	3718849	et	0	main
polnud	doc_491521501889_item	3718850	et	0	main
veel	doc_491521501889_item	3718851	et	0	main
varem	doc_491521501889_item	3718852	et	0	main
kokku	doc_491521501889_item	3718853	et	0	main
puutunud	doc_491521501889_item	3718854	et	0	main
üldiselt	doc_491521501889_item	3718855	et	0	main
märgistan	doc_491521501889_item	3718856	et	0	main
neid	doc_491521501889_item	3718857	et	0	main
allakriipsutamisega	doc_491521501889_item	3718858	et	0	main
või	doc_491521501889_item	3718859	et	0	main
sümbolitega	doc_491521501889_item	3718860	et	0	main
pannes	doc_491521501889_item	3718861	et	0	main
ikkagi	doc_491521501889_item	3718862	et	0	main
hinde	doc_491521501889_item	3718863	et	0	main
välja	doc_491521501889_item	3718864	et	0	main
soovi	doc_491521501889_item	3718865	et	0	main
hea	doc_491521501889_item	3718866	et	0	main
vigade	doc_491521501889_item	3718867	et	0	main
paranduse	doc_491521501889_item	3718868	et	0	main
korral	doc_491521501889_item	3718869	et	0	main
võivad	doc_491521501889_item	3718870	et	0	main
nad	doc_491521501889_item	3718871	et	0	main
saadud	doc_491521501889_item	3718872	et	0	main
tulernust	doc_491521501889_item	3718873	et	0	main
ka	doc_491521501889_item	3718874	et	0	main
parandada	doc_491521501889_item	3718875	et	0	main
kokkuvõteks	doc_491521501889_item	3718876	et	0	main
arutleme	doc_491521501889_item	3718877	et	0	main
kõik	doc_491521501889_item	3718878	et	0	main
vead	doc_491521501889_item	3718879	et	0	main
üle	doc_491521501889_item	3718880	et	0	main
vajaduse	doc_491521501889_item	3718881	et	0	main
korral	doc_491521501889_item	3718882	et	0	main
tehes	doc_491521501889_item	3718883	et	0	main
veel	doc_491521501889_item	3718884	et	0	main
mõningaid	doc_491521501889_item	3718885	et	0	main
harjutusi	doc_491521501889_item	3718886	et	0	main
analoogiliste	doc_491521501889_item	3718887	et	0	main
vigade	doc_491521501889_item	3718888	et	0	main
vältimiseks	doc_491521501889_item	3718889	et	0	main
tulevikus	doc_491521501889_item	3718890	et	0	main
viimane	doc_491521501889_item	3718891	et	0	main
antud	doc_491521501889_item	3718892	et	0	main
tüüpi	doc_491521501889_item	3718893	et	0	main
minikontrolltöö	doc_491521501889_item	3718894	et	0	main
kandis	doc_491521501889_item	3718895	et	0	main
nimetust	doc_491521501889_item	3718896	et	0	main
rebane	doc_491521501889_item	3718897	et	0	main
ja	doc_491521501889_item	3718898	et	0	main
jänes	doc_491521501889_item	3718899	et	0	main
vt	doc_491521501889_item	3718900	et	0	main
lisa	doc_491521501889_item	3718901	et	0	main
1	doc_491521501889_item	3718902	et	0	main
korraldasin	doc_491521501889_item	3718903	et	0	main
selle	doc_491521501889_item	3718904	et	0	main
esimese	doc_491521501889_item	3718905	et	0	main
veerandi	doc_491521501889_item	3718906	et	0	main
lõpus	doc_491521501889_item	3718907	et	0	main
kahes	doc_491521501889_item	3718908	et	0	main
viiendas	doc_491521501889_item	3718909	et	0	main
5	doc_491521501889_item	3718910	et	0	main
b	doc_491521501889_item	3718911	et	0	main
ja	doc_491521501889_item	3718912	et	0	main
c	doc_491521501889_item	3718913	et	0	main
ning	doc_491521501889_item	3718914	et	0	main
kahes	doc_491521501889_item	3718915	et	0	main
seitsmendas	doc_491521501889_item	3718916	et	0	main
7	doc_491521501889_item	3718917	et	0	main
b	doc_491521501889_item	3718918	et	0	main
7	doc_491521501889_item	3718919	et	0	main
c	doc_491521501889_item	3718920	et	0	main
klassis	doc_491521501889_item	3718921	et	0	main
kelle	doc_491521501889_item	3718922	et	0	main
õpilased	doc_491521501889_item	3718923	et	0	main
ei	doc_491521501889_item	3718924	et	0	main
kuulu	doc_491521501889_item	3718925	et	0	main
parimate	doc_491521501889_item	3718926	et	0	main
hulka	doc_491521501889_item	3718927	et	0	main
kes	doc_491521501889_item	3718928	et	0	main
moodustavad	doc_491521501889_item	3718929	et	0	main
aeliitklassi	doc_491521501889_item	3718930	et	0	main
kuid	doc_491521501889_item	3718931	et	0	main
ei	doc_491521501889_item	3718932	et	0	main
ole	doc_491521501889_item	3718933	et	0	main
ka	doc_491521501889_item	3718934	et	0	main
kõige	doc_491521501889_item	3718935	et	0	main
nõrgemad	doc_491521501889_item	3718936	et	0	main
kes	doc_491521501889_item	3718937	et	0	main
on	doc_491521501889_item	3718938	et	0	main
kogunenud	doc_491521501889_item	3718939	et	0	main
dsse	doc_491521501889_item	3718940	et	0	main
eesti	doc_491521501889_item	3718941	et	0	main
keelt	doc_491521501889_item	3718942	et	0	main
on	doc_491521501889_item	3718943	et	0	main
nad	doc_491521501889_item	3718944	et	0	main
õppinud	doc_491521501889_item	3718945	et	0	main
teisest	doc_491521501889_item	3718946	et	0	main
klassist	doc_491521501889_item	3718947	et	0	main
alates	doc_491521501889_item	3718948	et	0	main
4	doc_491521501889_item	3718949	et	0	main
voi	doc_491521501889_item	3718950	et	0	main
5	doc_491521501889_item	3718951	et	0	main
korda	doc_491521501889_item	3718952	et	0	main
nädalas	doc_491521501889_item	3718953	et	0	main
kunstist	doc_491521501889_item	3718954	et	0	main
tantsimisest	doc_491521501889_item	3718955	et	0	main
suure	doc_491521501889_item	3718956	et	0	main
huvitatuse	doc_491521501889_item	3718957	et	0	main
tõttu	doc_491521501889_item	3718958	et	0	main
pole	doc_491521501889_item	3718959	et	0	main
aga	doc_491521501889_item	3718960	et	0	main
see	doc_491521501889_item	3718961	et	0	main
kahjuks	doc_491521501889_item	3718962	et	0	main
nende	doc_491521501889_item	3718963	et	0	main
lemmikaine	doc_491521501889_item	3718964	et	0	main
kuid	doc_491521501889_item	3718965	et	0	main
üldiselt	doc_491521501889_item	3718966	et	0	main
on	doc_491521501889_item	3718967	et	0	main
nad	doc_491521501889_item	3718968	et	0	main
rõõmsameelsed	doc_491521501889_item	3718969	et	0	main
ning	doc_491521501889_item	3718970	et	0	main
väga	doc_491521501889_item	3718971	et	0	main
aktiivsed	doc_491521501889_item	3718972	et	0	main
lapsed	doc_491521501889_item	3718973	et	0	main
kellega	doc_491521501889_item	3718974	et	0	main
on	doc_491521501889_item	3718975	et	0	main
meeldiv	doc_491521501889_item	3718976	et	0	main
tööd	doc_491521501889_item	3718977	et	0	main
teha	doc_491521501889_item	3718978	et	0	main
nüüd	doc_491521501889_item	3718979	et	0	main
aga	doc_491521501889_item	3718980	et	0	main
lähemalt	doc_491521501889_item	3718981	et	0	main
ülesandest	doc_491521501889_item	3718982	et	0	main
endast	doc_491521501889_item	3718983	et	0	main
iga	doc_491521501889_item	3718984	et	0	main
õpilane	doc_491521501889_item	3718985	et	0	main
sai	doc_491521501889_item	3718986	et	0	main
tunni	doc_491521501889_item	3718987	et	0	main
alguses	doc_491521501889_item	3718988	et	0	main
endale	doc_491521501889_item	3718989	et	0	main
paljunduse	doc_491521501889_item	3718990	et	0	main
ning	doc_491521501889_item	3718991	et	0	main
3	doc_491521501889_item	3718992	et	0	main
ülesannet	doc_491521501889_item	3718993	et	0	main
mis	doc_491521501889_item	3718994	et	0	main
olid	doc_491521501889_item	3718995	et	0	main
kirjutatud	doc_491521501889_item	3718996	et	0	main
klassitahvlile	doc_491521501889_item	3718997	et	0	main
lahenduseks	doc_491521501889_item	3718998	et	0	main
oli	doc_491521501889_item	3718999	et	0	main
aega	doc_491521501889_item	3719000	et	0	main
ca	doc_491521501889_item	3719001	et	0	main
25	doc_491521501889_item	3719002	et	0	main
minutit	doc_491521501889_item	3719003	et	0	main
ülesanded	doc_491521501889_item	3719004	et	0	main
kõlasid	doc_491521501889_item	3719005	et	0	main
järgmiselt	doc_491521501889_item	3719006	et	0	main
1	doc_491521501889_item	3719007	et	0	main
kasutades	doc_491521501889_item	3719008	et	0	main
laual	doc_491521501889_item	3719009	et	0	main
olev	doc_491521501889_item	3719010	et	0	main
sõnastikku	doc_491521501889_item	3719011	et	0	main
paranda	doc_491521501889_item	3719012	et	0	main
tekstis	doc_491521501889_item	3719013	et	0	main
olevad	doc_491521501889_item	3719014	et	0	main
vead	doc_491521501889_item	3719015	et	0	main
2	doc_491521501889_item	3719016	et	0	main
kirjuta	doc_491521501889_item	3719017	et	0	main
õige	doc_491521501889_item	3719018	et	0	main
vigadeta	doc_491521501889_item	3719019	et	0	main
tekst	doc_491521501889_item	3719020	et	0	main
oma	doc_491521501889_item	3719021	et	0	main
vihikusse	doc_491521501889_item	3719022	et	0	main
ümber	doc_491521501889_item	3719023	et	0	main
3	doc_491521501889_item	3719024	et	0	main
tõlgi	doc_491521501889_item	3719025	et	0	main
tekst	doc_491521501889_item	3719026	et	0	main
vene	doc_491521501889_item	3719027	et	0	main
keelde	doc_491521501889_item	3719028	et	0	main
vead	doc_491521501889_item	3719029	et	0	main
mis	doc_491521501889_item	3719030	et	0	main
jäid	doc_491521501889_item	3719031	et	0	main
õpilaste	doc_491521501889_item	3719032	et	0	main
töödes	doc_491521501889_item	3719033	et	0	main
märkamata	doc_491521501889_item	3719034	et	0	main
ja	doc_491521501889_item	3719035	et	0	main
ka	doc_491521501889_item	3719036	et	0	main
parandamata	doc_491521501889_item	3719037	et	0	main
on	doc_491521501889_item	3719038	et	0	main
esitatud	doc_491521501889_item	3719039	et	0	main
lähtudes	doc_491521501889_item	3719040	et	0	main
esinemise	doc_491521501889_item	3719041	et	0	main
sageduse	doc_491521501889_item	3719042	et	0	main
järjekorrast	doc_491521501889_item	3719043	et	0	main
tabelis	doc_491521501889_item	3719044	et	0	main
nr	doc_491521501889_item	3719045	et	0	main
1	doc_491521501889_item	3719046	et	0	main
tabei	doc_491521501889_item	3719047	et	0	main
nr	doc_491521501889_item	3719048	et	0	main
1	doc_491521501889_item	3719049	et	0	main
öpilaste	doc_491521501889_item	3719050	et	0	main
parandamata	doc_491521501889_item	3719051	et	0	main
vead	doc_491521501889_item	3719052	et	0	main
5	doc_491521501889_item	3719053	et	0	main
klassi	doc_491521501889_item	3719054	et	0	main
õpilaste	doc_491521501889_item	3719055	et	0	main
vead	doc_491521501889_item	3719056	et	0	main
7	doc_491521501889_item	3719057	et	0	main
klassi	doc_491521501889_item	3719058	et	0	main
õpilaste	doc_491521501889_item	3719059	et	0	main
vead	doc_491521501889_item	3719060	et	0	main
1	doc_491521501889_item	3719061	et	0	main
vead	doc_491521501889_item	3719062	et	0	main
eestikeelses	doc_491521501889_item	3719063	et	0	main
tekstis	doc_491521501889_item	3719064	et	0	main
hüpada	doc_491521501889_item	3719065	et	0	main
18	doc_491521501889_item	3719066	et	0	main
viga	doc_491521501889_item	3719067	et	0	main
hüpada	doc_491521501889_item	3719068	et	0	main
12	doc_491521501889_item	3719069	et	0	main
viga	doc_491521501889_item	3719070	et	0	main
tee	doc_491521501889_item	3719071	et	0	main
ald	doc_491521501889_item	3719072	et	0	main
15	doc_491521501889_item	3719073	et	0	main
viga	doc_491521501889_item	3719074	et	0	main
pole	doc_491521501889_item	3719075	et	0	main
10	doc_491521501889_item	3719076	et	0	main
viga	doc_491521501889_item	3719077	et	0	main
külla	doc_491521501889_item	3719078	et	0	main
10	doc_491521501889_item	3719079	et	0	main
viga	doc_491521501889_item	3719080	et	0	main
küll	doc_491521501889_item	3719081	et	0	main
10	doc_491521501889_item	3719082	et	0	main
viga	doc_491521501889_item	3719083	et	0	main
rebaseld	doc_491521501889_item	3719084	et	0	main
9	doc_491521501889_item	3719085	et	0	main
viga	doc_491521501889_item	3719086	et	0	main
rebaseld	doc_491521501889_item	3719087	et	0	main
5	doc_491521501889_item	3719088	et	0	main
viga	doc_491521501889_item	3719089	et	0	main
kuled	doc_491521501889_item	3719090	et	0	main
9	doc_491521501889_item	3719091	et	0	main
viga	doc_491521501889_item	3719092	et	0	main
te	doc_491521501889_item	3719093	et	0	main
alt	doc_491521501889_item	3719094	et	0	main
5	doc_491521501889_item	3719095	et	0	main
viga	doc_491521501889_item	3719096	et	0	main
üle	doc_491521501889_item	3719097	et	0	main
te	doc_491521501889_item	3719098	et	0	main
7	doc_491521501889_item	3719099	et	0	main
viga	doc_491521501889_item	3719100	et	0	main
ei	doc_491521501889_item	3719101	et	0	main
sa	doc_491521501889_item	3719102	et	0	main
3	doc_491521501889_item	3719103	et	0	main
viga	doc_491521501889_item	3719104	et	0	main
ei	doc_491521501889_item	3719105	et	0	main
sa	doc_491521501889_item	3719106	et	0	main
5	doc_491521501889_item	3719107	et	0	main
viga	doc_491521501889_item	3719108	et	0	main
selle	doc_491521501889_item	3719109	et	0	main
pärast	doc_491521501889_item	3719110	et	0	main
3	doc_491521501889_item	3719111	et	0	main
viga	doc_491521501889_item	3719112	et	0	main
mull	doc_491521501889_item	3719113	et	0	main
5	doc_491521501889_item	3719114	et	0	main
viga	doc_491521501889_item	3719115	et	0	main
silmat	doc_491521501889_item	3719116	et	0	main
3	doc_491521501889_item	3719117	et	0	main
viga	doc_491521501889_item	3719118	et	0	main
vatad	doc_491521501889_item	3719119	et	0	main
4	doc_491521501889_item	3719120	et	0	main
viga	doc_491521501889_item	3719121	et	0	main
vaadan	doc_491521501889_item	3719122	et	0	main
2	doc_491521501889_item	3719123	et	0	main
viga	doc_491521501889_item	3719124	et	0	main
selepärast	doc_491521501889_item	3719125	et	0	main
4	doc_491521501889_item	3719126	et	0	main
viga	doc_491521501889_item	3719127	et	0	main
mis	doc_491521501889_item	3719128	et	0	main
pärast	doc_491521501889_item	3719129	et	0	main
2	doc_491521501889_item	3719130	et	0	main
viga	doc_491521501889_item	3719131	et	0	main
jäänes	doc_491521501889_item	3719132	et	0	main
3	doc_491521501889_item	3719133	et	0	main
viga	doc_491521501889_item	3719134	et	0	main
läpi	doc_491521501889_item	3719135	et	0	main
2	doc_491521501889_item	3719136	et	0	main
viga	doc_491521501889_item	3719137	et	0	main
aladi	doc_491521501889_item	3719138	et	0	main
3	doc_491521501889_item	3719139	et	0	main
viga	doc_491521501889_item	3719140	et	0	main
aladi	doc_491521501889_item	3719141	et	0	main
1	doc_491521501889_item	3719142	et	0	main
viga	doc_491521501889_item	3719143	et	0	main
muiduki	doc_491521501889_item	3719144	et	0	main
3	doc_491521501889_item	3719145	et	0	main
viga	doc_491521501889_item	3719146	et	0	main
iimestab	doc_491521501889_item	3719147	et	0	main
2	doc_491521501889_item	3719148	et	0	main
viga	doc_491521501889_item	3719149	et	0	main
omapärased	doc_491521501889_item	3719150	et	0	main
asendused	doc_491521501889_item	3719151	et	0	main
ika	doc_491521501889_item	3719152	et	0	main
iga	doc_491521501889_item	3719153	et	0	main
3	doc_491521501889_item	3719154	et	0	main
parandust	doc_491521501889_item	3719155	et	0	main
ika	doc_491521501889_item	3719156	et	0	main
iga	doc_491521501889_item	3719157	et	0	main
4	doc_491521501889_item	3719158	et	0	main
parandust	doc_491521501889_item	3719159	et	0	main
külla	doc_491521501889_item	3719160	et	0	main
pole	doc_491521501889_item	3719161	et	0	main
maale	doc_491521501889_item	3719162	et	0	main
3	doc_491521501889_item	3719163	et	0	main
parandust	doc_491521501889_item	3719164	et	0	main
läksid	doc_491521501889_item	3719165	et	0	main
käisid	doc_491521501889_item	3719166	et	0	main
3	doc_491521501889_item	3719167	et	0	main
parandust	doc_491521501889_item	3719168	et	0	main
2	doc_491521501889_item	3719169	et	0	main
tõlkevead	doc_491521501889_item	3719170	et	0	main
küla	doc_491521501889_item	3719171	et	0	main
poole	doc_491521501889_item	3719172	et	0	main
в	doc_491521501889_item	3719173	et	0	main
гости	doc_491521501889_item	3719174	et	0	main
5	doc_491521501889_item	3719175	et	0	main
viga	doc_491521501889_item	3719176	et	0	main
kui	doc_491521501889_item	3719177	et	0	main
on	doc_491521501889_item	3719178	et	0	main
vastutulijaid	doc_491521501889_item	3719179	et	0	main
как	doc_491521501889_item	3719180	et	0	main
вст	doc_491521501889_item	3719181	et	0	main
p	doc_491521501889_item	3719182	et	0	main
ечный	doc_491521501889_item	3719183	et	0	main
2	doc_491521501889_item	3719184	et	0	main
viga	doc_491521501889_item	3719185	et	0	main
mööda	doc_491521501889_item	3719186	et	0	main
teed	doc_491521501889_item	3719187	et	0	main
через	doc_491521501889_item	3719188	et	0	main
дорогу	doc_491521501889_item	3719189	et	0	main
2	doc_491521501889_item	3719190	et	0	main
viga	doc_491521501889_item	3719191	et	0	main
mööda	doc_491521501889_item	3719192	et	0	main
teed	doc_491521501889_item	3719193	et	0	main
мимо	doc_491521501889_item	3719194	et	0	main
дороги	doc_491521501889_item	3719195	et	0	main
2	doc_491521501889_item	3719196	et	0	main
viga	doc_491521501889_item	3719197	et	0	main
läksid	doc_491521501889_item	3719198	et	0	main
ходили	doc_491521501889_item	3719199	et	0	main
xc	doc_491521501889_item	3719200	et	0	main
1	doc_491521501889_item	3719201	et	0	main
viga	doc_491521501889_item	3719202	et	0	main
tee	doc_491521501889_item	3719203	et	0	main
alt	doc_491521501889_item	3719204	et	0	main
ei	doc_491521501889_item	3719205	et	0	main
saa	doc_491521501889_item	3719206	et	0	main
läbi	doc_491521501889_item	3719207	et	0	main
hüpata-	doc_491521501889_item	3719208	et	0	main
вниз	doc_491521501889_item	3719209	et	0	main
нельзя	doc_491521501889_item	3719210	et	0	main
прыгать	doc_491521501889_item	3719211	et	0	main
1viga	doc_491521501889_item	3719212	et	0	main
ü	doc_491521501889_item	3719213	et	0	main
le	doc_491521501889_item	3719214	et	0	main
tee	doc_491521501889_item	3719215	et	0	main
по	doc_491521501889_item	3719216	et	0	main
дороге	doc_491521501889_item	3719217	et	0	main
1	doc_491521501889_item	3719218	et	0	main
viga	doc_491521501889_item	3719219	et	0	main
küsitletud	doc_491521501889_item	3719220	et	0	main
oli	doc_491521501889_item	3719221	et	0	main
20	doc_491521501889_item	3719222	et	0	main
õpilast	doc_491521501889_item	3719223	et	0	main
kusjuures	doc_491521501889_item	3719224	et	0	main
igas	doc_491521501889_item	3719225	et	0	main
töös	doc_491521501889_item	3719226	et	0	main
esines	doc_491521501889_item	3719227	et	0	main
keskmiselt	doc_491521501889_item	3719228	et	0	main
9	doc_491521501889_item	3719229	et	0	main
viga	doc_491521501889_item	3719230	et	0	main
küsitletud	doc_491521501889_item	3719231	et	0	main
oli	doc_491521501889_item	3719232	et	0	main
18	doc_491521501889_item	3719233	et	0	main
õpilast	doc_491521501889_item	3719234	et	0	main
ühes	doc_491521501889_item	3719235	et	0	main
töös	doc_491521501889_item	3719236	et	0	main
leidus	doc_491521501889_item	3719237	et	0	main
4	doc_491521501889_item	3719238	et	0	main
kuni	doc_491521501889_item	3719239	et	0	main
5	doc_491521501889_item	3719240	et	0	main
viga	doc_491521501889_item	3719241	et	0	main
kokku	doc_491521501889_item	3719242	et	0	main
oli	doc_491521501889_item	3719243	et	0	main
küsitletud	doc_491521501889_item	3719244	et	0	main
38	doc_491521501889_item	3719245	et	0	main
põhikooli	doc_491521501889_item	3719246	et	0	main
õpilast	doc_491521501889_item	3719247	et	0	main
vigu	doc_491521501889_item	3719248	et	0	main
analüüsides	doc_491521501889_item	3719249	et	0	main
ja	doc_491521501889_item	3719250	et	0	main
rühmitades	doc_491521501889_item	3719251	et	0	main
võib	doc_491521501889_item	3719252	et	0	main
märgata	doc_491521501889_item	3719253	et	0	main
et	doc_491521501889_item	3719254	et	0	main
kõige	doc_491521501889_item	3719255	et	0	main
rohkem	doc_491521501889_item	3719256	et	0	main
tekitab	doc_491521501889_item	3719257	et	0	main
muret	doc_491521501889_item	3719258	et	0	main
1	doc_491521501889_item	3719259	et	0	main
ma-da-	doc_491521501889_item	3719260	et	0	main
infinitiivi	doc_491521501889_item	3719261	et	0	main
näiteks	doc_491521501889_item	3719262	et	0	main
sõna	doc_491521501889_item	3719263	et	0	main
hüppama	doc_491521501889_item	3719264	et	0	main
minema	doc_491521501889_item	3719265	et	0	main
2	doc_491521501889_item	3719266	et	0	main
kahekordsete	doc_491521501889_item	3719267	et	0	main
häälikute	doc_491521501889_item	3719268	et	0	main
näiteks	doc_491521501889_item	3719269	et	0	main
sõnades	doc_491521501889_item	3719270	et	0	main
vaatad	doc_491521501889_item	3719271	et	0	main
kuuled	doc_491521501889_item	3719272	et	0	main
tee	doc_491521501889_item	3719273	et	0	main
ning	doc_491521501889_item	3719274	et	0	main
3	doc_491521501889_item	3719275	et	0	main
klusiilide	doc_491521501889_item	3719276	et	0	main
k	doc_491521501889_item	3719277	et	0	main
p	doc_491521501889_item	3719278	et	0	main
t	doc_491521501889_item	3719279	et	0	main
g	doc_491521501889_item	3719280	et	0	main
b	doc_491521501889_item	3719281	et	0	main
d	doc_491521501889_item	3719282	et	0	main
õigekiri	doc_491521501889_item	3719283	et	0	main
näiteks	doc_491521501889_item	3719284	et	0	main
problemaatilised	doc_491521501889_item	3719285	et	0	main
sõnad	doc_491521501889_item	3719286	et	0	main
on	doc_491521501889_item	3719287	et	0	main
rebaselt	doc_491521501889_item	3719288	et	0	main
muidugi	doc_491521501889_item	3719289	et	0	main
alati	doc_491521501889_item	3719290	et	0	main
silmad	doc_491521501889_item	3719291	et	0	main
läbi	doc_491521501889_item	3719292	et	0	main
4	doc_491521501889_item	3719293	et	0	main
tõlkides	doc_491521501889_item	3719294	et	0	main
sarnase	doc_491521501889_item	3719295	et	0	main
kõlaga	doc_491521501889_item	3719296	et	0	main
homonüümide	doc_491521501889_item	3719297	et	0	main
näiteks	doc_491521501889_item	3719298	et	0	main
saba	doc_491521501889_item	3719299	et	0	main
ja	doc_491521501889_item	3719300	et	0	main
saapa	doc_491521501889_item	3719301	et	0	main
voi	doc_491521501889_item	3719302	et	0	main
te	doc_491521501889_item	3719303	et	0	main
tee	doc_491521501889_item	3719304	et	0	main
küla	doc_491521501889_item	3719305	et	0	main
külla	doc_491521501889_item	3719306	et	0	main
sa	doc_491521501889_item	3719307	et	0	main
ehk	doc_491521501889_item	3719308	et	0	main
sina	doc_491521501889_item	3719309	et	0	main
ning	doc_491521501889_item	3719310	et	0	main
ei	doc_491521501889_item	3719311	et	0	main
saa	doc_491521501889_item	3719312	et	0	main
või	doc_491521501889_item	3719313	et	0	main
mitmetähenduslike	doc_491521501889_item	3719314	et	0	main
sõnade	doc_491521501889_item	3719315	et	0	main
polüüseemide	doc_491521501889_item	3719316	et	0	main
eristamine	doc_491521501889_item	3719317	et	0	main
näiteks	doc_491521501889_item	3719318	et	0	main
võrrelge	doc_491521501889_item	3719319	et	0	main
sõna	doc_491521501889_item	3719320	et	0	main
mööda	doc_491521501889_item	3719321	et	0	main
tähendusi	doc_491521501889_item	3719322	et	0	main
lähen	doc_491521501889_item	3719323	et	0	main
mööda	doc_491521501889_item	3719324	et	0	main
teed	doc_491521501889_item	3719325	et	0	main
ta	doc_491521501889_item	3719326	et	0	main
pani	doc_491521501889_item	3719327	et	0	main
mööda	doc_491521501889_item	3719328	et	0	main
ta	doc_491521501889_item	3719329	et	0	main
läks	doc_491521501889_item	3719330	et	0	main
meist	doc_491521501889_item	3719331	et	0	main
mööda	doc_491521501889_item	3719332	et	0	main
eksimuste	doc_491521501889_item	3719333	et	0	main
põhjusi	doc_491521501889_item	3719334	et	0	main
ei	doc_491521501889_item	3719335	et	0	main
ole	doc_491521501889_item	3719336	et	0	main
ka	doc_491521501889_item	3719337	et	0	main
raske	doc_491521501889_item	3719338	et	0	main
ära	doc_491521501889_item	3719339	et	0	main
seletada	doc_491521501889_item	3719340	et	0	main
1eesti	doc_491521501889_item	3719341	et	0	main
keeles	doc_491521501889_item	3719342	et	0	main
esineb	doc_491521501889_item	3719343	et	0	main
2	doc_491521501889_item	3719344	et	0	main
infinitiivi	doc_491521501889_item	3719345	et	0	main
ma-	doc_491521501889_item	3719346	et	0	main
ja	doc_491521501889_item	3719347	et	0	main
da-tegevusni	doc_491521501889_item	3719348	et	0	main
ja	doc_491521501889_item	3719349	et	0	main
neil	doc_491521501889_item	3719350	et	0	main
on	doc_491521501889_item	3719351	et	0	main
mitu	doc_491521501889_item	3719352	et	0	main
käändevormi	doc_491521501889_item	3719353	et	0	main
vene	doc_491521501889_item	3719354	et	0	main
keeles	doc_491521501889_item	3719355	et	0	main
on	doc_491521501889_item	3719356	et	0	main
aga	doc_491521501889_item	3719357	et	0	main
vaid	doc_491521501889_item	3719358	et	0	main
üks	doc_491521501889_item	3719359	et	0	main
infinitiiv	doc_491521501889_item	3719360	et	0	main
неопределенная	doc_491521501889_item	3719361	et	0	main
форма	doc_491521501889_item	3719362	et	0	main
ning	doc_491521501889_item	3719363	et	0	main
tal	doc_491521501889_item	3719364	et	0	main
ei	doc_491521501889_item	3719365	et	0	main
ole	doc_491521501889_item	3719366	et	0	main
käändevormi	doc_491521501889_item	3719367	et	0	main
võrrelge	doc_491521501889_item	3719368	et	0	main
näiteks	doc_491521501889_item	3719369	et	0	main
tahan	doc_491521501889_item	3719370	et	0	main
lugeda	doc_491521501889_item	3719371	et	0	main
хочу	doc_491521501889_item	3719372	et	0	main
читать	doc_491521501889_item	3719373	et	0	main
pean	doc_491521501889_item	3719374	et	0	main
lugema	doc_491521501889_item	3719375	et	0	main
должен	doc_491521501889_item	3719376	et	0	main
читать	doc_491521501889_item	3719377	et	0	main
nõnda	doc_491521501889_item	3719378	et	0	main
tegeles	doc_491521501889_item	3719379	et	0	main
uue	doc_491521501889_item	3719380	et	0	main
sõnavara	doc_491521501889_item	3719381	et	0	main
omandamisega	doc_491521501889_item	3719382	et	0	main
tuleb	doc_491521501889_item	3719383	et	0	main
anda	doc_491521501889_item	3719384	et	0	main
3	doc_491521501889_item	3719385	et	0	main
verbi	doc_491521501889_item	3719386	et	0	main
põhivormi	doc_491521501889_item	3719387	et	0	main
nõudes	doc_491521501889_item	3719388	et	0	main
ka	doc_491521501889_item	3719389	et	0	main
nende	doc_491521501889_item	3719390	et	0	main
meeldejätmist	doc_491521501889_item	3719391	et	0	main
2	doc_491521501889_item	3719392	et	0	main
kuna	doc_491521501889_item	3719393	et	0	main
vene	doc_491521501889_item	3719394	et	0	main
keeles	doc_491521501889_item	3719395	et	0	main
on	doc_491521501889_item	3719396	et	0	main
diftonge	doc_491521501889_item	3719397	et	0	main
suhteliselt	doc_491521501889_item	3719398	et	0	main
vähe	doc_491521501889_item	3719399	et	0	main
tuleb	doc_491521501889_item	3719400	et	0	main
juba	doc_491521501889_item	3719401	et	0	main
esimesest	doc_491521501889_item	3719402	et	0	main
keeletundidest	doc_491521501889_item	3719403	et	0	main
alates	doc_491521501889_item	3719404	et	0	main
panna	doc_491521501889_item	3719405	et	0	main
õigele	doc_491521501889_item	3719406	et	0	main
hääldusele	doc_491521501889_item	3719407	et	0	main
rõhku	doc_491521501889_item	3719408	et	0	main
see	doc_491521501889_item	3719409	et	0	main
aitab	doc_491521501889_item	3719410	et	0	main
edaspidi	doc_491521501889_item	3719411	et	0	main
oma	doc_491521501889_item	3719412	et	0	main
kõrva	doc_491521501889_item	3719413	et	0	main
järgi	doc_491521501889_item	3719414	et	0	main
sõnu	doc_491521501889_item	3719415	et	0	main
õigesti	doc_491521501889_item	3719416	et	0	main
kirjutada	doc_491521501889_item	3719417	et	0	main
3	doc_491521501889_item	3719418	et	0	main
klusiilide	doc_491521501889_item	3719419	et	0	main
puhul	doc_491521501889_item	3719420	et	0	main
tekitab	doc_491521501889_item	3719421	et	0	main
raskusi	doc_491521501889_item	3719422	et	0	main
aga	doc_491521501889_item	3719423	et	0	main
see	doc_491521501889_item	3719424	et	0	main
et	doc_491521501889_item	3719425	et	0	main
need	doc_491521501889_item	3719426	et	0	main
häälikud	doc_491521501889_item	3719427	et	0	main
k	doc_491521501889_item	3719428	et	0	main
p	doc_491521501889_item	3719429	et	0	main
t	doc_491521501889_item	3719430	et	0	main
mis	doc_491521501889_item	3719431	et	0	main
on	doc_491521501889_item	3719432	et	0	main
vene	doc_491521501889_item	3719433	et	0	main
keeles	doc_491521501889_item	3719434	et	0	main
nõrgad	doc_491521501889_item	3719435	et	0	main
on	doc_491521501889_item	3719436	et	0	main
eesti	doc_491521501889_item	3719437	et	0	main
keeles	doc_491521501889_item	3719438	et	0	main
tugevad	doc_491521501889_item	3719439	et	0	main
samas	doc_491521501889_item	3719440	et	0	main
tuleb	doc_491521501889_item	3719441	et	0	main
mainida	doc_491521501889_item	3719442	et	0	main
et	doc_491521501889_item	3719443	et	0	main
mida	doc_491521501889_item	3719444	et	0	main
tuttavam	doc_491521501889_item	3719445	et	0	main
on	doc_491521501889_item	3719446	et	0	main
sõna	doc_491521501889_item	3719447	et	0	main
seda	doc_491521501889_item	3719448	et	0	main
vähem	doc_491521501889_item	3719449	et	0	main
selles	doc_491521501889_item	3719450	et	0	main
ka	doc_491521501889_item	3719451	et	0	main
eksitakse	doc_491521501889_item	3719452	et	0	main
nii	doc_491521501889_item	3719453	et	0	main
näiteks	doc_491521501889_item	3719454	et	0	main
sõna	doc_491521501889_item	3719455	et	0	main
silmad	doc_491521501889_item	3719456	et	0	main
on	doc_491521501889_item	3719457	et	0	main
paljudele	doc_491521501889_item	3719458	et	0	main
tuttav	doc_491521501889_item	3719459	et	0	main
juba	doc_491521501889_item	3719460	et	0	main
esimestest	doc_491521501889_item	3719461	et	0	main
keeletundidest	doc_491521501889_item	3719462	et	0	main
alates	doc_491521501889_item	3719463	et	0	main
seepärast	doc_491521501889_item	3719464	et	0	main
eksitakse	doc_491521501889_item	3719465	et	0	main
sellega	doc_491521501889_item	3719466	et	0	main
ka	doc_491521501889_item	3719467	et	0	main
vähe	doc_491521501889_item	3719468	et	0	main
hüpata	doc_491521501889_item	3719469	et	0	main
vormiga	doc_491521501889_item	3719470	et	0	main
on	doc_491521501889_item	3719471	et	0	main
aga	doc_491521501889_item	3719472	et	0	main
harva	doc_491521501889_item	3719473	et	0	main
kes	doc_491521501889_item	3719474	et	0	main
viiendas	doc_491521501889_item	3719475	et	0	main
klassis	doc_491521501889_item	3719476	et	0	main
varem	doc_491521501889_item	3719477	et	0	main
kohtunud	doc_491521501889_item	3719478	et	0	main
nõnda	doc_491521501889_item	3719479	et	0	main
on	doc_491521501889_item	3719480	et	0	main
see	doc_491521501889_item	3719481	et	0	main
ka	doc_491521501889_item	3719482	et	0	main
sagedasemate	doc_491521501889_item	3719483	et	0	main
vigade	doc_491521501889_item	3719484	et	0	main
hulgas	doc_491521501889_item	3719485	et	0	main
4	doc_491521501889_item	3719486	et	0	main
tõlgetest	doc_491521501889_item	3719487	et	0	main
aga	doc_491521501889_item	3719488	et	0	main
nii	doc_491521501889_item	3719489	et	0	main
palju	doc_491521501889_item	3719490	et	0	main
et	doc_491521501889_item	3719491	et	0	main
mida	doc_491521501889_item	3719492	et	0	main
noorem	doc_491521501889_item	3719493	et	0	main
on	doc_491521501889_item	3719494	et	0	main
õpilane	doc_491521501889_item	3719495	et	0	main
seda	doc_491521501889_item	3719496	et	0	main
raskem	doc_491521501889_item	3719497	et	0	main
on	doc_491521501889_item	3719498	et	0	main
tal	doc_491521501889_item	3719499	et	0	main
teksti	doc_491521501889_item	3719500	et	0	main
tõlkida	doc_491521501889_item	3719501	et	0	main
tavaliselt	doc_491521501889_item	3719502	et	0	main
otsivad	doc_491521501889_item	3719503	et	0	main
nad	doc_491521501889_item	3719504	et	0	main
täpse	doc_491521501889_item	3719505	et	0	main
tähenduse	doc_491521501889_item	3719506	et	0	main
sõnastikest	doc_491521501889_item	3719507	et	0	main
välja	doc_491521501889_item	3719508	et	0	main
proovides	doc_491521501889_item	3719509	et	0	main
muutumatuna	doc_491521501889_item	3719510	et	0	main
ehk	doc_491521501889_item	3719511	et	0	main
algvormis	doc_491521501889_item	3719512	et	0	main
paigutada	doc_491521501889_item	3719513	et	0	main
seda	doc_491521501889_item	3719514	et	0	main
lause	doc_491521501889_item	3719515	et	0	main
tulemuseks	doc_491521501889_item	3719516	et	0	main
on	doc_491521501889_item	3719517	et	0	main
sageli	doc_491521501889_item	3719518	et	0	main
väga	doc_491521501889_item	3719519	et	0	main
kohmakad	doc_491521501889_item	3719520	et	0	main
laused	doc_491521501889_item	3719521	et	0	main
siis	doc_491521501889_item	3719522	et	0	main
hakatakse	doc_491521501889_item	3719523	et	0	main
lisama	doc_491521501889_item	3719524	et	0	main
midagi	doc_491521501889_item	3719525	et	0	main
enda	doc_491521501889_item	3719526	et	0	main
poolt	doc_491521501889_item	3719527	et	0	main
saades	doc_491521501889_item	3719528	et	0	main
omapärase	doc_491521501889_item	3719529	et	0	main
jutustuse	doc_491521501889_item	3719530	et	0	main
variandi	doc_491521501889_item	3719531	et	0	main
vt	doc_491521501889_item	3719532	et	0	main
lisa	doc_491521501889_item	3719533	et	0	main
2	doc_491521501889_item	3719534	et	0	main
vanemates	doc_491521501889_item	3719535	et	0	main
klassides	doc_491521501889_item	3719536	et	0	main
on	doc_491521501889_item	3719537	et	0	main
aga	doc_491521501889_item	3719538	et	0	main
juba	doc_491521501889_item	3719539	et	0	main
stiili	doc_491521501889_item	3719540	et	0	main
poolest	doc_491521501889_item	3719541	et	0	main
palju	doc_491521501889_item	3719542	et	0	main
paremad	doc_491521501889_item	3719543	et	0	main
tööd	doc_491521501889_item	3719544	et	0	main
siin	doc_491521501889_item	3719545	et	0	main
pööratakse	doc_491521501889_item	3719546	et	0	main
tähelepanu	doc_491521501889_item	3719547	et	0	main
kontekstile	doc_491521501889_item	3719548	et	0	main
ja	doc_491521501889_item	3719549	et	0	main
ka	doc_491521501889_item	3719550	et	0	main
kahe	doc_491521501889_item	3719551	et	0	main
keelte	doc_491521501889_item	3719552	et	0	main
erinevustele	doc_491521501889_item	3719553	et	0	main
mõningad	doc_491521501889_item	3719554	et	0	main
taipavad	doc_491521501889_item	3719555	et	0	main
näiteks	doc_491521501889_item	3719556	et	0	main
isegi	doc_491521501889_item	3719557	et	0	main
muinasjutu	doc_491521501889_item	3719558	et	0	main
tegelasi	doc_491521501889_item	3719559	et	0	main
kirjutada	doc_491521501889_item	3719560	et	0	main
suure	doc_491521501889_item	3719561	et	0	main
algustähega	doc_491521501889_item	3719562	et	0	main
nii	doc_491521501889_item	3719563	et	0	main
et	doc_491521501889_item	3719564	et	0	main
tööd	doc_491521501889_item	3719565	et	0	main
on	doc_491521501889_item	3719566	et	0	main
palju	doc_491521501889_item	3719567	et	0	main
tõsisemad	doc_491521501889_item	3719568	et	0	main
ja	doc_491521501889_item	3719569	et	0	main
naljakaid	doc_491521501889_item	3719570	et	0	main
variante	doc_491521501889_item	3719571	et	0	main
praktiliselt	doc_491521501889_item	3719572	et	0	main
ei	doc_491521501889_item	3719573	et	0	main
ole	doc_491521501889_item	3719574	et	0	main
niisiis	doc_491521501889_item	3719575	et	0	main
mida	doc_491521501889_item	3719576	et	0	main
vanemad	doc_491521501889_item	3719577	et	0	main
lapsed	doc_491521501889_item	3719578	et	0	main
seda	doc_491521501889_item	3719579	et	0	main
suurem	doc_491521501889_item	3719580	et	0	main
on	doc_491521501889_item	3719581	et	0	main
nende	doc_491521501889_item	3719582	et	0	main
keelepädevus	doc_491521501889_item	3719583	et	0	main
ja	doc_491521501889_item	3719584	et	0	main
väiksem	doc_491521501889_item	3719585	et	0	main
vigade	doc_491521501889_item	3719586	et	0	main
arv	doc_491521501889_item	3719587	et	0	main
mõningaid	doc_491521501889_item	3719588	et	0	main
vigu	doc_491521501889_item	3719589	et	0	main
on	doc_491521501889_item	3719590	et	0	main
aga	doc_491521501889_item	3719591	et	0	main
väga	doc_491521501889_item	3719592	et	0	main
raske	doc_491521501889_item	3719593	et	0	main
klassifitseerida	doc_491521501889_item	3719594	et	0	main
nagu	doc_491521501889_item	3719595	et	0	main
ka	doc_491521501889_item	3719596	et	0	main
öelda	doc_491521501889_item	3719597	et	0	main
kas	doc_491521501889_item	3719598	et	0	main
õpilane	doc_491521501889_item	3719599	et	0	main
väldib	doc_491521501889_item	3719600	et	0	main
teatud	doc_491521501889_item	3719601	et	0	main
sõnade	doc_491521501889_item	3719602	et	0	main
kirjutamist	doc_491521501889_item	3719603	et	0	main
spetsiaalselt	doc_491521501889_item	3719604	et	0	main
kartes	doc_491521501889_item	3719605	et	0	main
eksida	doc_491521501889_item	3719606	et	0	main
või	doc_491521501889_item	3719607	et	0	main
asendab	doc_491521501889_item	3719608	et	0	main
neid	doc_491521501889_item	3719609	et	0	main
kuna	doc_491521501889_item	3719610	et	0	main
oskab	doc_491521501889_item	3719611	et	0	main
väga	doc_491521501889_item	3719612	et	0	main
hästi	doc_491521501889_item	3719613	et	0	main
keelt	doc_491521501889_item	3719614	et	0	main
nii	doc_491521501889_item	3719615	et	0	main
see	doc_491521501889_item	3719616	et	0	main
on	doc_491521501889_item	3719617	et	0	main
näiteks	doc_491521501889_item	3719618	et	0	main
variandis	doc_491521501889_item	3719619	et	0	main
väljendi	doc_491521501889_item	3719620	et	0	main
läksid	doc_491521501889_item	3719621	et	0	main
küla	doc_491521501889_item	3719622	et	0	main
poole	doc_491521501889_item	3719623	et	0	main
sõitsidläksid	doc_491521501889_item	3719624	et	0	main
maale	doc_491521501889_item	3719625	et	0	main
ning	doc_491521501889_item	3719626	et	0	main
minema	doc_491521501889_item	3719627	et	0	main
verbi	doc_491521501889_item	3719628	et	0	main
käima	doc_491521501889_item	3719629	et	0	main
ga	doc_491521501889_item	3719630	et	0	main
asendamise	doc_491521501889_item	3719631	et	0	main
juhul	doc_491521501889_item	3719632	et	0	main
üldiselt	doc_491521501889_item	3719633	et	0	main
sõltub	doc_491521501889_item	3719634	et	0	main
aga	doc_491521501889_item	3719635	et	0	main
palju	doc_491521501889_item	3719636	et	0	main
isikust	doc_491521501889_item	3719637	et	0	main
sellest	doc_491521501889_item	3719638	et	0	main
mis	doc_491521501889_item	3719639	et	0	main
ained	doc_491521501889_item	3719640	et	0	main
on	doc_491521501889_item	3719641	et	0	main
tal	doc_491521501889_item	3719642	et	0	main
lihtsam	doc_491521501889_item	3719643	et	0	main
omandada	doc_491521501889_item	3719644	et	0	main
kui	doc_491521501889_item	3719645	et	0	main
usin	doc_491521501889_item	3719646	et	0	main
ta	doc_491521501889_item	3719647	et	0	main
on	doc_491521501889_item	3719648	et	0	main
ja	doc_491521501889_item	3719649	et	0	main
kas	doc_491521501889_item	3719650	et	0	main
on	doc_491521501889_item	3719651	et	0	main
tal	doc_491521501889_item	3719652	et	0	main
võimalused	doc_491521501889_item	3719653	et	0	main
keelekasutamiseks	doc_491521501889_item	3719654	et	0	main
ka	doc_491521501889_item	3719655	et	0	main
väljaspool	doc_491521501889_item	3719656	et	0	main
kooli	doc_491521501889_item	3719657	et	0	main
võib-olla	doc_491521501889_item	3719658	et	0	main
pole	doc_491521501889_item	3719659	et	0	main
see	doc_491521501889_item	3719660	et	0	main
kõige	doc_491521501889_item	3719661	et	0	main
ilusam	doc_491521501889_item	3719662	et	0	main
ja	doc_491521501889_item	3719663	et	0	main
ka	doc_491521501889_item	3719664	et	0	main
viisakam	doc_491521501889_item	3719665	et	0	main
väljend	doc_491521501889_item	3719666	et	0	main
kuid	doc_491521501889_item	3719667	et	0	main
olen	doc_491521501889_item	3719668	et	0	main
paljudega	doc_491521501889_item	3719669	et	0	main
oma	doc_491521501889_item	3719670	et	0	main
tuttavate	doc_491521501889_item	3719671	et	0	main
pedagoogidega	doc_491521501889_item	3719672	et	0	main
nõus	doc_491521501889_item	3719673	et	0	main
kellele	doc_491521501889_item	3719674	et	0	main
meeldib	doc_491521501889_item	3719675	et	0	main
lisada	doc_491521501889_item	3719676	et	0	main
tublimatel	doc_491521501889_item	3719677	et	0	main
on	doc_491521501889_item	3719678	et	0	main
alati	doc_491521501889_item	3719679	et	0	main
head	doc_491521501889_item	3719680	et	0	main
tööd	doc_491521501889_item	3719681	et	0	main
ja	doc_491521501889_item	3719682	et	0	main
leidub	doc_491521501889_item	3719683	et	0	main
ikkagi	doc_491521501889_item	3719684	et	0	main
paar	doc_491521501889_item	3719685	et	0	main
andekat	doc_491521501889_item	3719686	et	0	main
tegijat	doc_491521501889_item	3719687	et	0	main
klassis	doc_491521501889_item	3719688	et	0	main
kes	doc_491521501889_item	3719689	et	0	main
vaatamata	doc_491521501889_item	3719690	et	0	main
seletamise	doc_491521501889_item	3719691	et	0	main
näitlikusele	doc_491521501889_item	3719692	et	0	main
leiavad	doc_491521501889_item	3719693	et	0	main
kohti	doc_491521501889_item	3719694	et	0	main
kus	doc_491521501889_item	3719695	et	0	main
vigu	doc_491521501889_item	3719696	et	0	main
teha	doc_491521501889_item	3719697	et	0	main
lisa	doc_491521501889_item	3719698	et	0	main
1	doc_491521501889_item	3719699	et	0	main
tekst	doc_491521501889_item	3719700	et	0	main
rebane	doc_491521501889_item	3719701	et	0	main
ja	doc_491521501889_item	3719702	et	0	main
jänes	doc_491521501889_item	3719703	et	0	main
repane	doc_491521501889_item	3719704	et	0	main
ja	doc_491521501889_item	3719705	et	0	main
jäänes	doc_491521501889_item	3719706	et	0	main
laksid	doc_491521501889_item	3719707	et	0	main
möda	doc_491521501889_item	3719708	et	0	main
teed	doc_491521501889_item	3719709	et	0	main
külla	doc_491521501889_item	3719710	et	0	main
pole	doc_491521501889_item	3719711	et	0	main
jänes	doc_491521501889_item	3719712	et	0	main
küsip	doc_491521501889_item	3719713	et	0	main
rebaseld	doc_491521501889_item	3719714	et	0	main
mispärast	doc_491521501889_item	3719715	et	0	main
saa	doc_491521501889_item	3719716	et	0	main
aladi	doc_491521501889_item	3719717	et	0	main
takasi	doc_491521501889_item	3719718	et	0	main
vatad	doc_491521501889_item	3719719	et	0	main
kui	doc_491521501889_item	3719720	et	0	main
mõnnda	doc_491521501889_item	3719721	et	0	main
krabinad	doc_491521501889_item	3719722	et	0	main
kuled	doc_491521501889_item	3719723	et	0	main
rebane	doc_491521501889_item	3719724	et	0	main
vasstas	doc_491521501889_item	3719725	et	0	main
vaadan	doc_491521501889_item	3719726	et	0	main
tagasi	doc_491521501889_item	3719727	et	0	main
selepärast	doc_491521501889_item	3719728	et	0	main
et	doc_491521501889_item	3719729	et	0	main
mul	doc_491521501889_item	3719730	et	0	main
silmat	doc_491521501889_item	3719731	et	0	main
ei	doc_491521501889_item	3719732	et	0	main
ole	doc_491521501889_item	3719733	et	0	main
sappa	doc_491521501889_item	3719734	et	0	main
otsas	doc_491521501889_item	3719735	et	0	main
aga	doc_491521501889_item	3719736	et	0	main
nüüt	doc_491521501889_item	3719737	et	0	main
ütle	doc_491521501889_item	3719738	et	0	main
mule	doc_491521501889_item	3719739	et	0	main
miks	doc_491521501889_item	3719740	et	0	main
sa	doc_491521501889_item	3719741	et	0	main
ika	doc_491521501889_item	3719742	et	0	main
üle	doc_491521501889_item	3719743	et	0	main
te	doc_491521501889_item	3719744	et	0	main
hüpad	doc_491521501889_item	3719745	et	0	main
kui	doc_491521501889_item	3719746	et	0	main
on	doc_491521501889_item	3719747	et	0	main
vastutulijaid	doc_491521501889_item	3719748	et	0	main
ah	doc_491521501889_item	3719749	et	0	main
ule	doc_491521501889_item	3719750	et	0	main
tee	doc_491521501889_item	3719751	et	0	main
üppan	doc_491521501889_item	3719752	et	0	main
iimestab	doc_491521501889_item	3719753	et	0	main
jänes	doc_491521501889_item	3719754	et	0	main
muiduki	doc_491521501889_item	3719755	et	0	main
sellepärast	doc_491521501889_item	3719756	et	0	main
et	doc_491521501889_item	3719757	et	0	main
te	doc_491521501889_item	3719758	et	0	main
ald	doc_491521501889_item	3719759	et	0	main
ei	doc_491521501889_item	3719760	et	0	main
sa	doc_491521501889_item	3719761	et	0	main
läpi	doc_491521501889_item	3719762	et	0	main
hüpada	doc_491521501889_item	3719763	et	0	main
ainetel	doc_491521501889_item	3719764	et	0	main
j	doc_491521501889_item	3719765	et	0	main
palm	doc_491521501889_item	3719766	et	0	main
lisa	doc_491521501889_item	3719767	et	0	main
2	doc_491521501889_item	3719768	et	0	main
ühe	doc_491521501889_item	3719769	et	0	main
viienda	doc_491521501889_item	3719770	et	0	main
klassi	doc_491521501889_item	3719771	et	0	main
õpilase	doc_491521501889_item	3719772	et	0	main
tõlge	doc_491521501889_item	3719773	et	0	main
лиса	doc_491521501889_item	3719774	et	0	main
и	doc_491521501889_item	3719775	et	0	main
заяц	doc_491521501889_item	3719776	et	0	main
лиса	doc_491521501889_item	3719777	et	0	main
и	doc_491521501889_item	3719778	et	0	main
заяц	doc_491521501889_item	3719779	et	0	main
шли	doc_491521501889_item	3719780	et	0	main
мимо	doc_491521501889_item	3719781	et	0	main
дороги	doc_491521501889_item	3719782	et	0	main
в	doc_491521501889_item	3719783	et	0	main
сторону	doc_491521501889_item	3719784	et	0	main
гостей	doc_491521501889_item	3719785	et	0	main
заяц	doc_491521501889_item	3719786	et	0	main
спросил	doc_491521501889_item	3719787	et	0	main
у	doc_491521501889_item	3719788	et	0	main
лисы	doc_491521501889_item	3719789	et	0	main
почему	doc_491521501889_item	3719790	et	0	main
ты	doc_491521501889_item	3719791	et	0	main
всегда	doc_491521501889_item	3719792	et	0	main
в	doc_491521501889_item	3719793	et	0	main
зад	doc_491521501889_item	3719794	et	0	main
смотришь	doc_491521501889_item	3719795	et	0	main
и	doc_491521501889_item	3719796	et	0	main
слышишь	doc_491521501889_item	3719797	et	0	main
какой-то	doc_491521501889_item	3719798	et	0	main
шелест	doc_491521501889_item	3719799	et	0	main
лиса	doc_491521501889_item	3719800	et	0	main
отвечает	doc_491521501889_item	3719801	et	0	main
смотрю	doc_491521501889_item	3719802	et	0	main
в	doc_491521501889_item	3719803	et	0	main
зад	doc_491521501889_item	3719804	et	0	main
так	doc_491521501889_item	3719805	et	0	main
как	doc_491521501889_item	3719806	et	0	main
я	doc_491521501889_item	3719807	et	0	main
думаю	doc_491521501889_item	3719808	et	0	main
что	doc_491521501889_item	3719809	et	0	main
хвост	doc_491521501889_item	3719810	et	0	main
потеряла	doc_491521501889_item	3719811	et	0	main
а	doc_491521501889_item	3719812	et	0	main
теперь	doc_491521501889_item	3719813	et	0	main
отвечайте	doc_491521501889_item	3719814	et	0	main
почему	doc_491521501889_item	3719815	et	0	main
вы	doc_491521501889_item	3719816	et	0	main
прыгаете	doc_491521501889_item	3719817	et	0	main
ох	doc_491521501889_item	3719818	et	0	main
по	doc_491521501889_item	3719819	et	0	main
дороге	doc_491521501889_item	3719820	et	0	main
я	doc_491521501889_item	3719821	et	0	main
прыгаю	doc_491521501889_item	3719822	et	0	main
думает	doc_491521501889_item	3719823	et	0	main
заяц	doc_491521501889_item	3719824	et	0	main
прыгаю	doc_491521501889_item	3719825	et	0	main
что	doc_491521501889_item	3719826	et	0	main
бы	doc_491521501889_item	3719827	et	0	main
было	doc_491521501889_item	3719828	et	0	main
быстрее	doc_491521501889_item	3719829	et	0	main
сказал	doc_491521501889_item	3719830	et	0	main
он	doc_491521501889_item	3719831	et	0	main
kasutatud	doc_491521501889_item	3719832	et	0	main
kirjandus	doc_491521501889_item	3719833	et	0	main
hausenberg	doc_491521501889_item	3719834	et	0	main
a	doc_491521501889_item	3719835	et	0	main
r	doc_491521501889_item	3719836	et	0	main
2001	doc_491521501889_item	3719837	et	0	main
kontrastiivlingvistika	doc_491521501889_item	3719838	et	0	main
loengud	doc_491521501889_item	3719839	et	0	main
tallinn	doc_491521501889_item	3719840	et	0	main
tpü	doc_491521501889_item	3719841	et	0	main
kärtner	doc_491521501889_item	3719842	et	0	main
p	doc_491521501889_item	3719843	et	0	main
2000	doc_491521501889_item	3719844	et	0	main
kirjutamisoskuse	doc_491521501889_item	3719845	et	0	main
arendamine	doc_491521501889_item	3719846	et	0	main
tallinn	doc_491521501889_item	3719847	et	0	main
lk	doc_491521501889_item	3719848	et	0	main
7-11	doc_491521501889_item	3719849	et	0	main
30-32	doc_491521501889_item	3719850	et	0	main
maisla	doc_491521501889_item	3719851	et	0	main
d	doc_491521501889_item	3719852	et	0	main
2000	doc_491521501889_item	3719853	et	0	main
vigade	doc_491521501889_item	3719854	et	0	main
parandamine	doc_491521501889_item	3719855	et	0	main
tallinn	doc_491521501889_item	3719856	et	0	main
lk	doc_491521501889_item	3719857	et	0	main
7-10	doc_491521501889_item	3719858	et	0	main
25-30	doc_491521501889_item	3719859	et	0	main
analüüs	doc_491521501869_item	3719860	et	0	main
tallinna	doc_491521501869_item	3719861	et	0	main
pedagoogikaülikool	doc_491521501869_item	3719862	et	0	main
eesti	doc_491521501869_item	3719863	et	0	main
keele	doc_491521501869_item	3719864	et	0	main
kui	doc_491521501869_item	3719865	et	0	main
võõrkeele	doc_491521501869_item	3719866	et	0	main
õppetool	doc_491521501869_item	3719867	et	0	main
veaanalüüsi	doc_491521501869_item	3719868	et	0	main
kodutöö	doc_491521501869_item	3719869	et	0	main
e	doc_491521501869_item	3719870	et	0	main
perekonnanimi	doc_491521501869_item	3719871	et	0	main
kontrastiivlingvistika	doc_491521501869_item	3719872	et	0	main
loengukursusele	doc_491521501869_item	3719873	et	0	main
eesnimi	doc_491521501869_item	3719874	et	0	main
perekonnanimi	doc_491521501869_item	3719875	et	0	main
tallinn	doc_491521501869_item	3719876	et	0	main
2001	doc_491521501869_item	3719877	et	0	main
eessõna	doc_491521501869_item	3719878	et	0	main
töös	doc_491521501869_item	3719879	et	0	main
on	doc_491521501869_item	3719880	et	0	main
analüüsitud	doc_491521501869_item	3719881	et	0	main
kokku	doc_491521501869_item	3719882	et	0	main
37	doc_491521501869_item	3719883	et	0	main
79	doc_491521501869_item	3719884	et	0	main
klassi	doc_491521501869_item	3719885	et	0	main
õpilase	doc_491521501869_item	3719886	et	0	main
kontrolltööd	doc_491521501869_item	3719887	et	0	main
kogu	doc_491521501869_item	3719888	et	0	main
materjal	doc_491521501869_item	3719889	et	0	main
on	doc_491521501869_item	3719890	et	0	main
saadud	doc_491521501869_item	3719891	et	0	main
ühe	doc_491521501869_item	3719892	et	0	main
narva	doc_491521501869_item	3719893	et	0	main
keskkooli	doc_491521501869_item	3719894	et	0	main
eesti	doc_491521501869_item	3719895	et	0	main
keele	doc_491521501869_item	3719896	et	0	main
kui	doc_491521501869_item	3719897	et	0	main
võõrkeele	doc_491521501869_item	3719898	et	0	main
õpetajalt	doc_491521501869_item	3719899	et	0	main
kes	doc_491521501869_item	3719900	et	0	main
töötab	doc_491521501869_item	3719901	et	0	main
koolis	doc_491521501869_item	3719902	et	0	main
7	doc_491521501869_item	3719903	et	0	main
aastat	doc_491521501869_item	3719904	et	0	main
analüüs	doc_491521501869_item	3719905	et	0	main
õpilaste	doc_491521501869_item	3719906	et	0	main
töödes	doc_491521501869_item	3719907	et	0	main
olid	doc_491521501869_item	3719908	et	0	main
peamised	doc_491521501869_item	3719909	et	0	main
käände-	doc_491521501869_item	3719910	et	0	main
ja	doc_491521501869_item	3719911	et	0	main
õigekirjavead	doc_491521501869_item	3719912	et	0	main
vastavalt	doc_491521501869_item	3719913	et	0	main
30	doc_491521501869_item	3719914	et	0	main
ja	doc_491521501869_item	3719915	et	0	main
17	doc_491521501869_item	3719916	et	0	main
viga	doc_491521501869_item	3719917	et	0	main
käändevead	doc_491521501869_item	3719918	et	0	main
on	doc_491521501869_item	3719919	et	0	main
arvatavasti	doc_491521501869_item	3719920	et	0	main
seotud	doc_491521501869_item	3719921	et	0	main
käändevormide	doc_491521501869_item	3719922	et	0	main
moodustamisega	doc_491521501869_item	3719923	et	0	main
tihti	doc_491521501869_item	3719924	et	0	main
ei	doc_491521501869_item	3719925	et	0	main
tea	doc_491521501869_item	3719926	et	0	main
õpilased	doc_491521501869_item	3719927	et	0	main
kuidas	doc_491521501869_item	3719928	et	0	main
õiget	doc_491521501869_item	3719929	et	0	main
vormi	doc_491521501869_item	3719930	et	0	main
moodustada	doc_491521501869_item	3719931	et	0	main
mõnel	doc_491521501869_item	3719932	et	0	main
juhul	doc_491521501869_item	3719933	et	0	main
on	doc_491521501869_item	3719934	et	0	main
aga	doc_491521501869_item	3719935	et	0	main
selline	doc_491521501869_item	3719936	et	0	main
tunne	doc_491521501869_item	3719937	et	0	main
et	doc_491521501869_item	3719938	et	0	main
õpilane	doc_491521501869_item	3719939	et	0	main
ei	doc_491521501869_item	3719940	et	0	main
saa	doc_491521501869_item	3719941	et	0	main
üldse	doc_491521501869_item	3719942	et	0	main
lause	doc_491521501869_item	3719943	et	0	main
tähendusest	doc_491521501869_item	3719944	et	0	main
aru	doc_491521501869_item	3719945	et	0	main
ja	doc_491521501869_item	3719946	et	0	main
kirjutab	doc_491521501869_item	3719947	et	0	main
selle	doc_491521501869_item	3719948	et	0	main
sõnavormi	doc_491521501869_item	3719949	et	0	main
mis	doc_491521501869_item	3719950	et	0	main
tal	doc_491521501869_item	3719951	et	0	main
esimesena	doc_491521501869_item	3719952	et	0	main
pähe	doc_491521501869_item	3719953	et	0	main
tuleb	doc_491521501869_item	3719954	et	0	main
näiteks	doc_491521501869_item	3719955	et	0	main
vend	doc_491521501869_item	3719956	et	0	main
meisterdas	doc_491521501869_item	3719957	et	0	main
pingile	doc_491521501869_item	3719958	et	0	main
või	doc_491521501869_item	3719959	et	0	main
kui	doc_491521501869_item	3719960	et	0	main
kõrge	doc_491521501869_item	3719961	et	0	main
trepilt	doc_491521501869_item	3719962	et	0	main
juhul	doc_491521501869_item	3719963	et	0	main
juhtub	doc_491521501869_item	3719964	et	0	main
ka	doc_491521501869_item	3719965	et	0	main
nii	doc_491521501869_item	3719966	et	0	main
et	doc_491521501869_item	3719967	et	0	main
õpilane	doc_491521501869_item	3719968	et	0	main
ei	doc_491521501869_item	3719969	et	0	main
tea	doc_491521501869_item	3719970	et	0	main
et	doc_491521501869_item	3719971	et	0	main
omavahel	doc_491521501869_item	3719972	et	0	main
seotud	doc_491521501869_item	3719973	et	0	main
omadussõna	doc_491521501869_item	3719974	et	0	main
ja	doc_491521501869_item	3719975	et	0	main
nimisõna	doc_491521501869_item	3719976	et	0	main
peavad	doc_491521501869_item	3719977	et	0	main
olema	doc_491521501869_item	3719978	et	0	main
ühes	doc_491521501869_item	3719979	et	0	main
ja	doc_491521501869_item	3719980	et	0	main
samas	doc_491521501869_item	3719981	et	0	main
käändes	doc_491521501869_item	3719982	et	0	main
ja	doc_491521501869_item	3719983	et	0	main
ta	doc_491521501869_item	3719984	et	0	main
kirjutab	doc_491521501869_item	3719985	et	0	main
nt	doc_491521501869_item	3719986	et	0	main
seda	doc_491521501869_item	3719987	et	0	main
ivo	doc_491521501869_item	3719988	et	0	main
istub	doc_491521501869_item	3719989	et	0	main
esimeses	doc_491521501869_item	3719990	et	0	main
pingile	doc_491521501869_item	3719991	et	0	main
käändevea	doc_491521501869_item	3719992	et	0	main
kategooriasse	doc_491521501869_item	3719993	et	0	main
tegelikult	doc_491521501869_item	3719994	et	0	main
kuuluvad	doc_491521501869_item	3719995	et	0	main
ka	doc_491521501869_item	3719996	et	0	main
rektsioonivead	doc_491521501869_item	3719997	et	0	main
kuid	doc_491521501869_item	3719998	et	0	main
ikkagi	doc_491521501869_item	3719999	et	0	main
otsustasin	doc_491521501869_item	3720000	et	0	main
panna	doc_491521501869_item	3720001	et	0	main
need	doc_491521501869_item	3720002	et	0	main
eraldi	doc_491521501869_item	3720003	et	0	main
rühma	doc_491521501869_item	3720004	et	0	main
sest	doc_491521501869_item	3720005	et	0	main
selles	doc_491521501869_item	3720006	et	0	main
kategoorias	doc_491521501869_item	3720007	et	0	main
nimisõnad	doc_491521501869_item	3720008	et	0	main
on	doc_491521501869_item	3720009	et	0	main
seotud	doc_491521501869_item	3720010	et	0	main
just	doc_491521501869_item	3720011	et	0	main
verbiga	doc_491521501869_item	3720012	et	0	main
ja	doc_491521501869_item	3720013	et	0	main
verbist	doc_491521501869_item	3720014	et	0	main
sõltuvadki	doc_491521501869_item	3720015	et	0	main
tehtud	doc_491521501869_item	3720016	et	0	main
vead	doc_491521501869_item	3720017	et	0	main
õpilane	doc_491521501869_item	3720018	et	0	main
kasutab	doc_491521501869_item	3720019	et	0	main
tihti	doc_491521501869_item	3720020	et	0	main
eesti	doc_491521501869_item	3720021	et	0	main
rektsiooni	doc_491521501869_item	3720022	et	0	main
asemel	doc_491521501869_item	3720023	et	0	main
vene	doc_491521501869_item	3720024	et	0	main
oma	doc_491521501869_item	3720025	et	0	main
nt	doc_491521501869_item	3720026	et	0	main
lauses	doc_491521501869_item	3720027	et	0	main
küsi	doc_491521501869_item	3720028	et	0	main
seda	doc_491521501869_item	3720029	et	0	main
õelt	doc_491521501869_item	3720030	et	0	main
kirjutas	doc_491521501869_item	3720031	et	0	main
õpilane	doc_491521501869_item	3720032	et	0	main
küsi	doc_491521501869_item	3720033	et	0	main
seda	doc_491521501869_item	3720034	et	0	main
õel	doc_491521501869_item	3720035	et	0	main
just	doc_491521501869_item	3720036	et	0	main
vene	doc_491521501869_item	3720037	et	0	main
rektsiooni	doc_491521501869_item	3720038	et	0	main
mõjul	doc_491521501869_item	3720039	et	0	main
võrdle	doc_491521501869_item	3720040	et	0	main
küsi	doc_491521501869_item	3720041	et	0	main
seda	doc_491521501869_item	3720042	et	0	main
õelt	doc_491521501869_item	3720043	et	0	main
ja	doc_491521501869_item	3720044	et	0	main
õel	doc_491521501869_item	3720045	et	0	main
on	doc_491521501869_item	3720046	et	0	main
rätik	doc_491521501869_item	3720047	et	0	main
käes	doc_491521501869_item	3720048	et	0	main
vene	doc_491521501869_item	3720049	et	0	main
keelsega	doc_491521501869_item	3720050	et	0	main
cnpocu	doc_491521501869_item	3720051	et	0	main
y	doc_491521501869_item	3720052	et	0	main
cecmpы	doc_491521501869_item	3720053	et	0	main
ja	doc_491521501869_item	3720054	et	0	main
у	doc_491521501869_item	3720055	et	0	main
cecmpы	doc_491521501869_item	3720056	et	0	main
в	doc_491521501869_item	3720057	et	0	main
pyкax	doc_491521501869_item	3720058	et	0	main
платок	doc_491521501869_item	3720059	et	0	main
siit	doc_491521501869_item	3720060	et	0	main
võib	doc_491521501869_item	3720061	et	0	main
näha	doc_491521501869_item	3720062	et	0	main
et	doc_491521501869_item	3720063	et	0	main
vene	doc_491521501869_item	3720064	et	0	main
keeles	doc_491521501869_item	3720065	et	0	main
kasutatakse	doc_491521501869_item	3720066	et	0	main
mõlemal	doc_491521501869_item	3720067	et	0	main
juhul	doc_491521501869_item	3720068	et	0	main
üht	doc_491521501869_item	3720069	et	0	main
ja	doc_491521501869_item	3720070	et	0	main
sama	doc_491521501869_item	3720071	et	0	main
vormi	doc_491521501869_item	3720072	et	0	main
õel	doc_491521501869_item	3720073	et	0	main
sellest	doc_491521501869_item	3720074	et	0	main
tulenebki	doc_491521501869_item	3720075	et	0	main
õpilase	doc_491521501869_item	3720076	et	0	main
viga	doc_491521501869_item	3720077	et	0	main
sama	doc_491521501869_item	3720078	et	0	main
kehtib	doc_491521501869_item	3720079	et	0	main
ka	doc_491521501869_item	3720080	et	0	main
teiste	doc_491521501869_item	3720081	et	0	main
sarnaste	doc_491521501869_item	3720082	et	0	main
juhtumite	doc_491521501869_item	3720083	et	0	main
suhtes	doc_491521501869_item	3720084	et	0	main
nt	doc_491521501869_item	3720085	et	0	main
võta	doc_491521501869_item	3720086	et	0	main
sõbralt	doc_491521501869_item	3720087	et	0	main
oli	doc_491521501869_item	3720088	et	0	main
kasutatud	doc_491521501869_item	3720089	et	0	main
võta	doc_491521501869_item	3720090	et	0	main
sõbral	doc_491521501869_item	3720091	et	0	main
too	doc_491521501869_item	3720092	et	0	main
köögist	doc_491521501869_item	3720093	et	0	main
oli	doc_491521501869_item	3720094	et	0	main
too	doc_491521501869_item	3720095	et	0	main
köögis	doc_491521501869_item	3720096	et	0	main
mõned	doc_491521501869_item	3720097	et	0	main
käändevead	doc_491521501869_item	3720098	et	0	main
samuti	doc_491521501869_item	3720099	et	0	main
tulenesid	doc_491521501869_item	3720100	et	0	main
sellest	doc_491521501869_item	3720101	et	0	main
et	doc_491521501869_item	3720102	et	0	main
õpilane	doc_491521501869_item	3720103	et	0	main
ei	doc_491521501869_item	3720104	et	0	main
saanud	doc_491521501869_item	3720105	et	0	main
lausest	doc_491521501869_item	3720106	et	0	main
aru	doc_491521501869_item	3720107	et	0	main
ja	doc_491521501869_item	3720108	et	0	main
lihtsalt	doc_491521501869_item	3720109	et	0	main
kasutas	doc_491521501869_item	3720110	et	0	main
nõutud	doc_491521501869_item	3720111	et	0	main
vormi	doc_491521501869_item	3720112	et	0	main
asemele	doc_491521501869_item	3720113	et	0	main
suvalist	doc_491521501869_item	3720114	et	0	main
mis	doc_491521501869_item	3720115	et	0	main
tal	doc_491521501869_item	3720116	et	0	main
meelde	doc_491521501869_item	3720117	et	0	main
tuli	doc_491521501869_item	3720118	et	0	main
õigekirjavigades	doc_491521501869_item	3720119	et	0	main
esines	doc_491521501869_item	3720120	et	0	main
palju	doc_491521501869_item	3720121	et	0	main
valesti	doc_491521501869_item	3720122	et	0	main
kirjutatud	doc_491521501869_item	3720123	et	0	main
sõnu	doc_491521501869_item	3720124	et	0	main
e	doc_491521501869_item	3720125	et	0	main
sõnas	doc_491521501869_item	3720126	et	0	main
kahe	doc_491521501869_item	3720127	et	0	main
tahe	doc_491521501869_item	3720128	et	0	main
asemel	doc_491521501869_item	3720129	et	0	main
oli	doc_491521501869_item	3720130	et	0	main
kirjutatud	doc_491521501869_item	3720131	et	0	main
üks	doc_491521501869_item	3720132	et	0	main
see	doc_491521501869_item	3720133	et	0	main
võib	doc_491521501869_item	3720134	et	0	main
sõltuda	doc_491521501869_item	3720135	et	0	main
sellest	doc_491521501869_item	3720136	et	0	main
et	doc_491521501869_item	3720137	et	0	main
õpetaja	doc_491521501869_item	3720138	et	0	main
kunagi	doc_491521501869_item	3720139	et	0	main
võis	doc_491521501869_item	3720140	et	0	main
valesti	doc_491521501869_item	3720141	et	0	main
sõna	doc_491521501869_item	3720142	et	0	main
hääldada	doc_491521501869_item	3720143	et	0	main
ja	doc_491521501869_item	3720144	et	0	main
see	doc_491521501869_item	3720145	et	0	main
jäigi	doc_491521501869_item	3720146	et	0	main
sel	doc_491521501869_item	3720147	et	0	main
kujul	doc_491521501869_item	3720148	et	0	main
õpilase	doc_491521501869_item	3720149	et	0	main
mällu	doc_491521501869_item	3720150	et	0	main
ortograafiat	doc_491521501869_item	3720151	et	0	main
saab	doc_491521501869_item	3720152	et	0	main
harjutada	doc_491521501869_item	3720153	et	0	main
nii	doc_491521501869_item	3720154	et	0	main
sõna	doc_491521501869_item	3720155	et	0	main
tahvlile	doc_491521501869_item	3720156	et	0	main
kirjutamise	doc_491521501869_item	3720157	et	0	main
kui	doc_491521501869_item	3720158	et	0	main
ka	doc_491521501869_item	3720159	et	0	main
õpetaja-	doc_491521501869_item	3720160	et	0	main
ja	doc_491521501869_item	3720161	et	0	main
õpilaste	doc_491521501869_item	3720162	et	0	main
kooshääldamise	doc_491521501869_item	3720163	et	0	main
kaudu	doc_491521501869_item	3720164	et	0	main
teiseks	doc_491521501869_item	3720165	et	0	main
allliigiks	doc_491521501869_item	3720166	et	0	main
on	doc_491521501869_item	3720167	et	0	main
aga	doc_491521501869_item	3720168	et	0	main
need	doc_491521501869_item	3720169	et	0	main
sõnad	doc_491521501869_item	3720170	et	0	main
mille	doc_491521501869_item	3720171	et	0	main
õige	doc_491521501869_item	3720172	et	0	main
kirjutamine	doc_491521501869_item	3720173	et	0	main
sõltub	doc_491521501869_item	3720174	et	0	main
reeglite	doc_491521501869_item	3720175	et	0	main
oskusest	doc_491521501869_item	3720176	et	0	main
nt	doc_491521501869_item	3720177	et	0	main
et	doc_491521501869_item	3720178	et	0	main
kõikide	doc_491521501869_item	3720179	et	0	main
keelte	doc_491521501869_item	3720180	et	0	main
nimetused	doc_491521501869_item	3720181	et	0	main
me	doc_491521501869_item	3720182	et	0	main
kirjutame	doc_491521501869_item	3720183	et	0	main
tavaliselt	doc_491521501869_item	3720184	et	0	main
väikse	doc_491521501869_item	3720185	et	0	main
tähega	doc_491521501869_item	3720186	et	0	main
õigekirjavigu	doc_491521501869_item	3720187	et	0	main
tuleb	doc_491521501869_item	3720188	et	0	main
eriti	doc_491521501869_item	3720189	et	0	main
palju	doc_491521501869_item	3720190	et	0	main
etteütluse	doc_491521501869_item	3720191	et	0	main
puhul	doc_491521501869_item	3720192	et	0	main
samasse	doc_491521501869_item	3720193	et	0	main
kategooriasse	doc_491521501869_item	3720194	et	0	main
võiksid	doc_491521501869_item	3720195	et	0	main
kuuluda	doc_491521501869_item	3720196	et	0	main
ka	doc_491521501869_item	3720197	et	0	main
ühilduinisvead	doc_491521501869_item	3720198	et	0	main
need	doc_491521501869_item	3720199	et	0	main
on	doc_491521501869_item	3720200	et	0	main
ka	doc_491521501869_item	3720201	et	0	main
õigekirjavigade	doc_491521501869_item	3720202	et	0	main
hulgast	doc_491521501869_item	3720203	et	0	main
nt	doc_491521501869_item	3720204	et	0	main
kui	doc_491521501869_item	3720205	et	0	main
kirjutame	doc_491521501869_item	3720206	et	0	main
arvsõnu	doc_491521501869_item	3720207	et	0	main
siis	doc_491521501869_item	3720208	et	0	main
peame	doc_491521501869_item	3720209	et	0	main
teadma	doc_491521501869_item	3720210	et	0	main
et	doc_491521501869_item	3720211	et	0	main
sajased	doc_491521501869_item	3720212	et	0	main
üheksasada	doc_491521501869_item	3720213	et	0	main
tuleb	doc_491521501869_item	3720214	et	0	main
kirjutada	doc_491521501869_item	3720215	et	0	main
kokku	doc_491521501869_item	3720216	et	0	main
sama	doc_491521501869_item	3720217	et	0	main
ka	doc_491521501869_item	3720218	et	0	main
kümnete	doc_491521501869_item	3720219	et	0	main
puhul	doc_491521501869_item	3720220	et	0	main
nelikümmend	doc_491521501869_item	3720221	et	0	main
või	doc_491521501869_item	3720222	et	0	main
üheteistkümnendal	doc_491521501869_item	3720223	et	0	main
aga	doc_491521501869_item	3720224	et	0	main
sajased	doc_491521501869_item	3720225	et	0	main
ja	doc_491521501869_item	3720226	et	0	main
kümnesed	doc_491521501869_item	3720227	et	0	main
kirjutame	doc_491521501869_item	3720228	et	0	main
juba	doc_491521501869_item	3720229	et	0	main
lahku	doc_491521501869_item	3720230	et	0	main
üheksasada	doc_491521501869_item	3720231	et	0	main
nelikümmend	doc_491521501869_item	3720232	et	0	main
omadussõna	doc_491521501869_item	3720233	et	0	main
võrdlusastmete	doc_491521501869_item	3720234	et	0	main
moodustamise	doc_491521501869_item	3720235	et	0	main
puhul	doc_491521501869_item	3720236	et	0	main
tuleb	doc_491521501869_item	3720237	et	0	main
õpilastel	doc_491521501869_item	3720238	et	0	main
meelest	doc_491521501869_item	3720239	et	0	main
pidada	doc_491521501869_item	3720240	et	0	main
kaht	doc_491521501869_item	3720241	et	0	main
tingimust	doc_491521501869_item	3720242	et	0	main
moodustame	doc_491521501869_item	3720243	et	0	main
kesk-	doc_491521501869_item	3720244	et	0	main
ja	doc_491521501869_item	3720245	et	0	main
ülivõrret	doc_491521501869_item	3720246	et	0	main
omastavast	doc_491521501869_item	3720247	et	0	main
käändest	doc_491521501869_item	3720248	et	0	main
v	doc_491521501869_item	3720249	et	0	main
a	doc_491521501869_item	3720250	et	0	main
kui	doc_491521501869_item	3720251	et	0	main
sõna	doc_491521501869_item	3720252	et	0	main
ei	doc_491521501869_item	3720253	et	0	main
kuulu	doc_491521501869_item	3720254	et	0	main
erandite	doc_491521501869_item	3720255	et	0	main
hulka	doc_491521501869_item	3720256	et	0	main
kus	doc_491521501869_item	3720257	et	0	main
sõna	doc_491521501869_item	3720258	et	0	main
kesk-	doc_491521501869_item	3720259	et	0	main
j	doc_491521501869_item	3720260	et	0	main
a	doc_491521501869_item	3720261	et	0	main
ülivõrre	doc_491521501869_item	3720262	et	0	main
on	doc_491521501869_item	3720263	et	0	main
hoopis	doc_491521501869_item	3720264	et	0	main
testmoodi	doc_491521501869_item	3720265	et	0	main
tuletatav	doc_491521501869_item	3720266	et	0	main
kuid	doc_491521501869_item	3720267	et	0	main
ikkagi	doc_491521501869_item	3720268	et	0	main
õpilastele	doc_491521501869_item	3720269	et	0	main
tekitab	doc_491521501869_item	3720270	et	0	main
raskusi	doc_491521501869_item	3720271	et	0	main
see	doc_491521501869_item	3720272	et	0	main
kui	doc_491521501869_item	3720273	et	0	main
sõna	doc_491521501869_item	3720274	et	0	main
omastav	doc_491521501869_item	3720275	et	0	main
erineb	doc_491521501869_item	3720276	et	0	main
sõna	doc_491521501869_item	3720277	et	0	main
nimetavast	doc_491521501869_item	3720278	et	0	main
nt	doc_491521501869_item	3720279	et	0	main
kade	doc_491521501869_item	3720280	et	0	main
kadeda	doc_491521501869_item	3720281	et	0	main
või	doc_491521501869_item	3720282	et	0	main
nukker	doc_491521501869_item	3720283	et	0	main
nukra	doc_491521501869_item	3720284	et	0	main
õpilased	doc_491521501869_item	3720285	et	0	main
kasutasid	doc_491521501869_item	3720286	et	0	main
näiteks	doc_491521501869_item	3720287	et	0	main
kõige	doc_491521501869_item	3720288	et	0	main
kadem	doc_491521501869_item	3720289	et	0	main
või	doc_491521501869_item	3720290	et	0	main
nukkrain	doc_491521501869_item	3720291	et	0	main
ja	doc_491521501869_item	3720292	et	0	main
ajasid	doc_491521501869_item	3720293	et	0	main
segi	doc_491521501869_item	3720294	et	0	main
sõna	doc_491521501869_item	3720295	et	0	main
nimetavat	doc_491521501869_item	3720296	et	0	main
j	doc_491521501869_item	3720297	et	0	main
a	doc_491521501869_item	3720298	et	0	main
omastavat	doc_491521501869_item	3720299	et	0	main
käänet	doc_491521501869_item	3720300	et	0	main
verbivormide	doc_491521501869_item	3720301	et	0	main
moodustusvigu	doc_491521501869_item	3720302	et	0	main
oil	doc_491521501869_item	3720303	et	0	main
testides	doc_491521501869_item	3720304	et	0	main
kõige	doc_491521501869_item	3720305	et	0	main
rohkem	doc_491521501869_item	3720306	et	0	main
ebareeglipäraste	doc_491521501869_item	3720307	et	0	main
verbide	doc_491521501869_item	3720308	et	0	main
mineviku	doc_491521501869_item	3720309	et	0	main
eituse	doc_491521501869_item	3720310	et	0	main
moodustamisel	doc_491521501869_item	3720311	et	0	main
e	doc_491521501869_item	3720312	et	0	main
mineviku	doc_491521501869_item	3720313	et	0	main
vormi	doc_491521501869_item	3720314	et	0	main
moodustamise	doc_491521501869_item	3720315	et	0	main
aluseks	doc_491521501869_item	3720316	et	0	main
kasutati	doc_491521501869_item	3720317	et	0	main
valesti	doc_491521501869_item	3720318	et	0	main
tegusõna	doc_491521501869_item	3720319	et	0	main
oleviku	doc_491521501869_item	3720320	et	0	main
l	doc_491521501869_item	3720321	et	0	main
pööret	doc_491521501869_item	3720322	et	0	main
nt	doc_491521501869_item	3720323	et	0	main
ei	doc_491521501869_item	3720324	et	0	main
lähinenud	doc_491521501869_item	3720325	et	0	main
ei	doc_491521501869_item	3720326	et	0	main
joinud	doc_491521501869_item	3720327	et	0	main
ei	doc_491521501869_item	3720328	et	0	main
näiginud	doc_491521501869_item	3720329	et	0	main
ei	doc_491521501869_item	3720330	et	0	main
söinud	doc_491521501869_item	3720331	et	0	main
see	doc_491521501869_item	3720332	et	0	main
arvatavasti	doc_491521501869_item	3720333	et	0	main
tulenes	doc_491521501869_item	3720334	et	0	main
oleviku	doc_491521501869_item	3720335	et	0	main
reeglipärase	doc_491521501869_item	3720336	et	0	main
eituse	doc_491521501869_item	3720337	et	0	main
moodustamise	doc_491521501869_item	3720338	et	0	main
reeglitest	doc_491521501869_item	3720339	et	0	main
seega	doc_491521501869_item	3720340	et	0	main
on	doc_491521501869_item	3720341	et	0	main
õpetajal	doc_491521501869_item	3720342	et	0	main
vaja	doc_491521501869_item	3720343	et	0	main
eraldi	doc_491521501869_item	3720344	et	0	main
rõhutada	doc_491521501869_item	3720345	et	0	main
ebareeglipäraseid	doc_491521501869_item	3720346	et	0	main
vorme	doc_491521501869_item	3720347	et	0	main
ja	doc_491521501869_item	3720348	et	0	main
paremini	doc_491521501869_item	3720349	et	0	main
neid	doc_491521501869_item	3720350	et	0	main
paberile	doc_491521501869_item	3720351	et	0	main
välja	doc_491521501869_item	3720352	et	0	main
kirjutada	doc_491521501869_item	3720353	et	0	main
ja	doc_491521501869_item	3720354	et	0	main
seinale	doc_491521501869_item	3720355	et	0	main
panna	doc_491521501869_item	3720356	et	0	main
et	doc_491521501869_item	3720357	et	0	main
lapsed	doc_491521501869_item	3720358	et	0	main
võiksid	doc_491521501869_item	3720359	et	0	main
neid	doc_491521501869_item	3720360	et	0	main
kogu	doc_491521501869_item	3720361	et	0	main
aeg	doc_491521501869_item	3720362	et	0	main
näha	doc_491521501869_item	3720363	et	0	main
palju	doc_491521501869_item	3720364	et	0	main
vigu	doc_491521501869_item	3720365	et	0	main
teevad	doc_491521501869_item	3720366	et	0	main
lapsed	doc_491521501869_item	3720367	et	0	main
ka	doc_491521501869_item	3720368	et	0	main
verbivormide	doc_491521501869_item	3720369	et	0	main
valikus	doc_491521501869_item	3720370	et	0	main
see	doc_491521501869_item	3720371	et	0	main
seostub	doc_491521501869_item	3720372	et	0	main
peamiselt	doc_491521501869_item	3720373	et	0	main
ma-	doc_491521501869_item	3720374	et	0	main
ja	doc_491521501869_item	3720375	et	0	main
da-infinitiivi	doc_491521501869_item	3720376	et	0	main
valikuga	doc_491521501869_item	3720377	et	0	main
nad	doc_491521501869_item	3720378	et	0	main
ei	doc_491521501869_item	3720379	et	0	main
tea	doc_491521501869_item	3720380	et	0	main
missuguse	doc_491521501869_item	3720381	et	0	main
verbiga	doc_491521501869_item	3720382	et	0	main
missugust	doc_491521501869_item	3720383	et	0	main
infinitiivi	doc_491521501869_item	3720384	et	0	main
kasutada	doc_491521501869_item	3720385	et	0	main
vigade	doc_491521501869_item	3720386	et	0	main
kõrvaldamiseks	doc_491521501869_item	3720387	et	0	main
tuleb	doc_491521501869_item	3720388	et	0	main
minu	doc_491521501869_item	3720389	et	0	main
arvates	doc_491521501869_item	3720390	et	0	main
teha	doc_491521501869_item	3720391	et	0	main
teste	doc_491521501869_item	3720392	et	0	main
kus	doc_491521501869_item	3720393	et	0	main
lastel	doc_491521501869_item	3720394	et	0	main
tuleks	doc_491521501869_item	3720395	et	0	main
valida	doc_491521501869_item	3720396	et	0	main
2	doc_491521501869_item	3720397	et	0	main
vormi	doc_491521501869_item	3720398	et	0	main
vahel	doc_491521501869_item	3720399	et	0	main
heaks	doc_491521501869_item	3720400	et	0	main
võib	doc_491521501869_item	3720401	et	0	main
olla	doc_491521501869_item	3720402	et	0	main
ka	doc_491521501869_item	3720403	et	0	main
loomuliku	doc_491521501869_item	3720404	et	0	main
kõne	doc_491521501869_item	3720405	et	0	main
kuulamine	doc_491521501869_item	3720406	et	0	main
milles	doc_491521501869_item	3720407	et	0	main
tavaliselt	doc_491521501869_item	3720408	et	0	main
kasutatakse	doc_491521501869_item	3720409	et	0	main
palju	doc_491521501869_item	3720410	et	0	main
ma-	doc_491521501869_item	3720411	et	0	main
ja	doc_491521501869_item	3720412	et	0	main
da-infinitiivi	doc_491521501869_item	3720413	et	0	main
selle	doc_491521501869_item	3720414	et	0	main
käigus	doc_491521501869_item	3720415	et	0	main
õpivad	doc_491521501869_item	3720416	et	0	main
lapsed	doc_491521501869_item	3720417	et	0	main
nii	doc_491521501869_item	3720418	et	0	main
õigete	doc_491521501869_item	3720419	et	0	main
vormide	doc_491521501869_item	3720420	et	0	main
kasutamist	doc_491521501869_item	3720421	et	0	main
kui	doc_491521501869_item	3720422	et	0	main
ka	doc_491521501869_item	3720423	et	0	main
üldist	doc_491521501869_item	3720424	et	0	main
lausestruktuuri	doc_491521501869_item	3720425	et	0	main
kõige	doc_491521501869_item	3720426	et	0	main
huvitavamad	doc_491521501869_item	3720427	et	0	main
vead	doc_491521501869_item	3720428	et	0	main
on	doc_491521501869_item	3720429	et	0	main
minu	doc_491521501869_item	3720430	et	0	main
jaoks	doc_491521501869_item	3720431	et	0	main
semantilised	doc_491521501869_item	3720432	et	0	main
vead	doc_491521501869_item	3720433	et	0	main
kitsemalt	doc_491521501869_item	3720434	et	0	main
sõnasemantika	doc_491521501869_item	3720435	et	0	main
vead	doc_491521501869_item	3720436	et	0	main
näiteks	doc_491521501869_item	3720437	et	0	main
oleks	doc_491521501869_item	3720438	et	0	main
väga	doc_491521501869_item	3720439	et	0	main
huvitav	doc_491521501869_item	3720440	et	0	main
küsida	doc_491521501869_item	3720441	et	0	main
millest	doc_491521501869_item	3720442	et	0	main
õpilane	doc_491521501869_item	3720443	et	0	main
juhindub	doc_491521501869_item	3720444	et	0	main
kui	doc_491521501869_item	3720445	et	0	main
ta	doc_491521501869_item	3720446	et	0	main
kasutab	doc_491521501869_item	3720447	et	0	main
ühe	doc_491521501869_item	3720448	et	0	main
sõna	doc_491521501869_item	3720449	et	0	main
asemel	doc_491521501869_item	3720450	et	0	main
teist	doc_491521501869_item	3720451	et	0	main
see	doc_491521501869_item	3720452	et	0	main
toimub	doc_491521501869_item	3720453	et	0	main
tihti	doc_491521501869_item	3720454	et	0	main
kui	doc_491521501869_item	3720455	et	0	main
sõnad	doc_491521501869_item	3720456	et	0	main
on	doc_491521501869_item	3720457	et	0	main
kujult	doc_491521501869_item	3720458	et	0	main
sarnased	doc_491521501869_item	3720459	et	0	main
paronüümsed	doc_491521501869_item	3720460	et	0	main
e	doc_491521501869_item	3720461	et	0	main
morfeemkoosseisu	doc_491521501869_item	3720462	et	0	main
poolest	doc_491521501869_item	3720463	et	0	main
osaliselt	doc_491521501869_item	3720464	et	0	main
kattuvad	doc_491521501869_item	3720465	et	0	main
sõnad	doc_491521501869_item	3720466	et	0	main
minu	doc_491521501869_item	3720467	et	0	main
analüüsitud	doc_491521501869_item	3720468	et	0	main
õpilaste	doc_491521501869_item	3720469	et	0	main
töödes	doc_491521501869_item	3720470	et	0	main
esines	doc_491521501869_item	3720471	et	0	main
vahe	doc_491521501869_item	3720472	et	0	main
paronüümide	doc_491521501869_item	3720473	et	0	main
segi	doc_491521501869_item	3720474	et	0	main
ajamist	doc_491521501869_item	3720475	et	0	main
õppur	doc_491521501869_item	3720476	et	0	main
kirjutas	doc_491521501869_item	3720477	et	0	main
sõna	doc_491521501869_item	3720478	et	0	main
valel	doc_491521501869_item	3720479	et	0	main
asemele	doc_491521501869_item	3720480	et	0	main
sõna	doc_491521501869_item	3720481	et	0	main
vahel	doc_491521501869_item	3720482	et	0	main
on	doc_491521501869_item	3720483	et	0	main
ilmne	doc_491521501869_item	3720484	et	0	main
et	doc_491521501869_item	3720485	et	0	main
paronüümide	doc_491521501869_item	3720486	et	0	main
vale	doc_491521501869_item	3720487	et	0	main
kasutamise	doc_491521501869_item	3720488	et	0	main
põhjuseks	doc_491521501869_item	3720489	et	0	main
on	doc_491521501869_item	3720490	et	0	main
nende	doc_491521501869_item	3720491	et	0	main
sarnane	doc_491521501869_item	3720492	et	0	main
väline	doc_491521501869_item	3720493	et	0	main
kuju	doc_491521501869_item	3720494	et	0	main
võib	doc_491521501869_item	3720495	et	0	main
oletada	doc_491521501869_item	3720496	et	0	main
et	doc_491521501869_item	3720497	et	0	main
vea	doc_491521501869_item	3720498	et	0	main
põhjus	doc_491521501869_item	3720499	et	0	main
on	doc_491521501869_item	3720500	et	0	main
ebakindel	doc_491521501869_item	3720501	et	0	main
sõna	doc_491521501869_item	3720502	et	0	main
tähendusest	doc_491521501869_item	3720503	et	0	main
arusaamine	doc_491521501869_item	3720504	et	0	main
mis	doc_491521501869_item	3720505	et	0	main
viibki	doc_491521501869_item	3720506	et	0	main
sõna	doc_491521501869_item	3720507	et	0	main
valele	doc_491521501869_item	3720508	et	0	main
kasutamisele	doc_491521501869_item	3720509	et	0	main
pragmaatilised	doc_491521501869_item	3720510	et	0	main
vead	doc_491521501869_item	3720511	et	0	main
on	doc_491521501869_item	3720512	et	0	main
vead	doc_491521501869_item	3720513	et	0	main
kui	doc_491521501869_item	3720514	et	0	main
õpilane	doc_491521501869_item	3720515	et	0	main
kasutab	doc_491521501869_item	3720516	et	0	main
emakeele	doc_491521501869_item	3720517	et	0	main
reegleid	doc_491521501869_item	3720518	et	0	main
eesti	doc_491521501869_item	3720519	et	0	main
lause	doc_491521501869_item	3720520	et	0	main
moodustamiseks	doc_491521501869_item	3720521	et	0	main
need	doc_491521501869_item	3720522	et	0	main
on	doc_491521501869_item	3720523	et	0	main
tüüpilised	doc_491521501869_item	3720524	et	0	main
vead	doc_491521501869_item	3720525	et	0	main
kategooriast	doc_491521501869_item	3720526	et	0	main
nii	doc_491521501869_item	3720527	et	0	main
ei	doc_491521501869_item	3720528	et	0	main
räägita	doc_491521501869_item	3720529	et	0	main
et	doc_491521501869_item	3720530	et	0	main
eestlane	doc_491521501869_item	3720531	et	0	main
saab	doc_491521501869_item	3720532	et	0	main
küll	doc_491521501869_item	3720533	et	0	main
aru	doc_491521501869_item	3720534	et	0	main
millest	doc_491521501869_item	3720535	et	0	main
juttu	doc_491521501869_item	3720536	et	0	main
on	doc_491521501869_item	3720537	et	0	main
aga	doc_491521501869_item	3720538	et	0	main
lause	doc_491521501869_item	3720539	et	0	main
ikka	doc_491521501869_item	3720540	et	0	main
tundub	doc_491521501869_item	3720541	et	0	main
väga	doc_491521501869_item	3720542	et	0	main
võõras	doc_491521501869_item	3720543	et	0	main
näiteks	doc_491521501869_item	3720544	et	0	main
lause	doc_491521501869_item	3720545	et	0	main
kell	doc_491521501869_item	3720546	et	0	main
saab	doc_491521501869_item	3720547	et	0	main
on	doc_491521501869_item	3720548	et	0	main
kuue	doc_491521501869_item	3720549	et	0	main
minuti	doc_491521501869_item	3720550	et	0	main
pärast	doc_491521501869_item	3720551	et	0	main
tund	doc_491521501869_item	3720552	et	0	main
kui	doc_491521501869_item	3720553	et	0	main
tõlkida	doc_491521501869_item	3720554	et	0	main
vene	doc_491521501869_item	3720555	et	0	main
keelde	doc_491521501869_item	3720556	et	0	main
tund	doc_491521501869_item	3720557	et	0	main
ongi	doc_491521501869_item	3720558	et	0	main
час	doc_491521501869_item	3720559	et	0	main
siin	doc_491521501869_item	3720560	et	0	main
kohal	doc_491521501869_item	3720561	et	0	main
õpilane	doc_491521501869_item	3720562	et	0	main
juhindus	doc_491521501869_item	3720563	et	0	main
venekeelsest	doc_491521501869_item	3720564	et	0	main
lausest	doc_491521501869_item	3720565	et	0	main
kus	doc_491521501869_item	3720566	et	0	main
tõlgituna	doc_491521501869_item	3720567	et	0	main
eeltoodud	doc_491521501869_item	3720568	et	0	main
lause	doc_491521501869_item	3720569	et	0	main
kõlab	doc_491521501869_item	3720570	et	0	main
nii	doc_491521501869_item	3720571	et	0	main
через	doc_491521501869_item	3720572	et	0	main
шесть	doc_491521501869_item	3720573	et	0	main
минут	doc_491521501869_item	3720574	et	0	main
час	doc_491521501869_item	3720575	et	0	main
miks	doc_491521501869_item	3720576	et	0	main
aga	doc_491521501869_item	3720577	et	0	main
viga	doc_491521501869_item	3720578	et	0	main
mõjutatud	doc_491521501869_item	3720579	et	0	main
vene	doc_491521501869_item	3720580	et	0	main
keelest	doc_491521501869_item	3720581	et	0	main
vene	doc_491521501869_item	3720582	et	0	main
lauses	doc_491521501869_item	3720583	et	0	main
jätame	doc_491521501869_item	3720584	et	0	main
me	doc_491521501869_item	3720585	et	0	main
vahele	doc_491521501869_item	3720586	et	0	main
sõna	doc_491521501869_item	3720587	et	0	main
üks	doc_491521501869_item	3720588	et	0	main
nii	doc_491521501869_item	3720589	et	0	main
kirjutaski	doc_491521501869_item	3720590	et	0	main
laps	doc_491521501869_item	3720591	et	0	main
emakeelest	doc_491521501869_item	3720592	et	0	main
tõlkides	doc_491521501869_item	3720593	et	0	main
saab	doc_491521501869_item	3720594	et	0	main
tund	doc_491521501869_item	3720595	et	0	main
teisest	doc_491521501869_item	3720596	et	0	main
näiteks	doc_491521501869_item	3720597	et	0	main
toodud	doc_491521501869_item	3720598	et	0	main
lausest	doc_491521501869_item	3720599	et	0	main
on	doc_491521501869_item	3720600	et	0	main
kas	doc_491521501869_item	3720601	et	0	main
jäetud	doc_491521501869_item	3720602	et	0	main
vahele	doc_491521501869_item	3720603	et	0	main
sõna	doc_491521501869_item	3720604	et	0	main
nt	doc_491521501869_item	3720605	et	0	main
võiks	doc_491521501869_item	3720606	et	0	main
ütelda	doc_491521501869_item	3720607	et	0	main
kell	doc_491521501869_item	3720608	et	0	main
on	doc_491521501869_item	3720609	et	0	main
täpselt	doc_491521501869_item	3720610	et	0	main
viis	doc_491521501869_item	3720611	et	0	main
aga	doc_491521501869_item	3720612	et	0	main
võiks	doc_491521501869_item	3720613	et	0	main
juhtuda	doc_491521501869_item	3720614	et	0	main
et	doc_491521501869_item	3720615	et	0	main
laps	doc_491521501869_item	3720616	et	0	main
ajas	doc_491521501869_item	3720617	et	0	main
segi	doc_491521501869_item	3720618	et	0	main
sõna	doc_491521501869_item	3720619	et	0	main
täpne	doc_491521501869_item	3720620	et	0	main
sõnaga	doc_491521501869_item	3720621	et	0	main
täpselt	doc_491521501869_item	3720622	et	0	main
samuti	doc_491521501869_item	3720623	et	0	main
emakeelest	doc_491521501869_item	3720624	et	0	main
juhindudes	doc_491521501869_item	3720625	et	0	main
kui	doc_491521501869_item	3720626	et	0	main
aga	doc_491521501869_item	3720627	et	0	main
tahame	doc_491521501869_item	3720628	et	0	main
seda	doc_491521501869_item	3720629	et	0	main
sama	doc_491521501869_item	3720630	et	0	main
ütelda	doc_491521501869_item	3720631	et	0	main
eesti	doc_491521501869_item	3720632	et	0	main
keeles	doc_491521501869_item	3720633	et	0	main
tuleb	doc_491521501869_item	3720634	et	0	main
kasutada	doc_491521501869_item	3720635	et	0	main
kell	doc_491521501869_item	3720636	et	0	main
on	doc_491521501869_item	3720637	et	0	main
õige	doc_491521501869_item	3720638	et	0	main
seda	doc_491521501869_item	3720639	et	0	main
tüüpi	doc_491521501869_item	3720640	et	0	main
vigade	doc_491521501869_item	3720641	et	0	main
vältimiseks	doc_491521501869_item	3720642	et	0	main
tuleb	doc_491521501869_item	3720643	et	0	main
õpilastel	doc_491521501869_item	3720644	et	0	main
jätta	doc_491521501869_item	3720645	et	0	main
õige	doc_491521501869_item	3720646	et	0	main
väljend	doc_491521501869_item	3720647	et	0	main
meelde	doc_491521501869_item	3720648	et	0	main
kõige	doc_491521501869_item	3720649	et	0	main
viimane	doc_491521501869_item	3720650	et	0	main
minu	doc_491521501869_item	3720651	et	0	main
klassifikatsioonis	doc_491521501869_item	3720652	et	0	main
ja	doc_491521501869_item	3720653	et	0	main
kõige	doc_491521501869_item	3720654	et	0	main
arusaamatum	doc_491521501869_item	3720655	et	0	main
juhtum	doc_491521501869_item	3720656	et	0	main
on	doc_491521501869_item	3720657	et	0	main
sõnade	doc_491521501869_item	3720658	et	0	main
juhuslik	doc_491521501869_item	3720659	et	0	main
kasutamine	doc_491521501869_item	3720660	et	0	main
kui	doc_491521501869_item	3720661	et	0	main
õpilane	doc_491521501869_item	3720662	et	0	main
lihtsalt	doc_491521501869_item	3720663	et	0	main
ei	doc_491521501869_item	3720664	et	0	main
tea	doc_491521501869_item	3720665	et	0	main
sobivat	doc_491521501869_item	3720666	et	0	main
sõna	doc_491521501869_item	3720667	et	0	main
ja	doc_491521501869_item	3720668	et	0	main
kasutab	doc_491521501869_item	3720669	et	0	main
selle	doc_491521501869_item	3720670	et	0	main
asemel	doc_491521501869_item	3720671	et	0	main
midagi	doc_491521501869_item	3720672	et	0	main
muud	doc_491521501869_item	3720673	et	0	main
mis	doc_491521501869_item	3720674	et	0	main
kuidagi	doc_491521501869_item	3720675	et	0	main
lausesse	doc_491521501869_item	3720676	et	0	main
ei	doc_491521501869_item	3720677	et	0	main
sobi	doc_491521501869_item	3720678	et	0	main
nt	doc_491521501869_item	3720679	et	0	main
peremees	doc_491521501869_item	3720680	et	0	main
küpsetas	doc_491521501869_item	3720681	et	0	main
vilja	doc_491521501869_item	3720682	et	0	main
selle	doc_491521501869_item	3720683	et	0	main
kõrvaldamiseks	doc_491521501869_item	3720684	et	0	main
on	doc_491521501869_item	3720685	et	0	main
olemas	doc_491521501869_item	3720686	et	0	main
ainus	doc_491521501869_item	3720687	et	0	main
tee	doc_491521501869_item	3720688	et	0	main
keelt	doc_491521501869_item	3720689	et	0	main
õppida	doc_491521501869_item	3720690	et	0	main
süstemaatiliselt	doc_491521501869_item	3720691	et	0	main
ja	doc_491521501869_item	3720692	et	0	main
õpetaja	doc_491521501869_item	3720693	et	0	main
juhendamisel	doc_491521501869_item	3720694	et	0	main
kõige	doc_491521501869_item	3720695	et	0	main
parem	doc_491521501869_item	3720696	et	0	main
on	doc_491521501869_item	3720697	et	0	main
õppida	doc_491521501869_item	3720698	et	0	main
loomulikus	doc_491521501869_item	3720699	et	0	main
keskkonnas	doc_491521501869_item	3720700	et	0	main
kui	doc_491521501869_item	3720701	et	0	main
see	doc_491521501869_item	3720702	et	0	main
võimalus	doc_491521501869_item	3720703	et	0	main
puudub	doc_491521501869_item	3720704	et	0	main
siis	doc_491521501869_item	3720705	et	0	main
süstemaatiliselt	doc_491521501869_item	3720706	et	0	main
ja	doc_491521501869_item	3720707	et	0	main
õpetaja	doc_491521501869_item	3720708	et	0	main
juhendamisel	doc_491521501869_item	3720709	et	0	main
õpetaja	doc_491521501869_item	3720710	et	0	main
juhendamisel	doc_491521501869_item	3720711	et	0	main
õppimine	doc_491521501869_item	3720712	et	0	main
ja	doc_491521501869_item	3720713	et	0	main
loomulikus	doc_491521501869_item	3720714	et	0	main
keskkonnas	doc_491521501869_item	3720715	et	0	main
viibimine	doc_491521501869_item	3720716	et	0	main
annavad	doc_491521501869_item	3720717	et	0	main
minu	doc_491521501869_item	3720718	et	0	main
arvates	doc_491521501869_item	3720719	et	0	main
kõige	doc_491521501869_item	3720720	et	0	main
paremaid	doc_491521501869_item	3720721	et	0	main
tulemusi	doc_491521501869_item	3720722	et	0	main
vigade	doc_491521501869_item	3720723	et	0	main
vältimiseks	doc_491521501869_item	3720724	et	0	main
minu	doc_491521501869_item	3720725	et	0	main
enda	doc_491521501869_item	3720726	et	0	main
vead	doc_491521501869_item	3720727	et	0	main
on	doc_491521501869_item	3720728	et	0	main
leksikaalsel	doc_491521501869_item	3720729	et	0	main
tasandil	doc_491521501869_item	3720730	et	0	main
tehtud	doc_491521501869_item	3720731	et	0	main
vead	doc_491521501869_item	3720732	et	0	main
neist	doc_491521501869_item	3720733	et	0	main
kõige	doc_491521501869_item	3720734	et	0	main
rohkem	doc_491521501869_item	3720735	et	0	main
on	doc_491521501869_item	3720736	et	0	main
sõnade	doc_491521501869_item	3720737	et	0	main
vale	doc_491521501869_item	3720738	et	0	main
kasutamine	doc_491521501869_item	3720739	et	0	main
seda	doc_491521501869_item	3720740	et	0	main
tüüpi	doc_491521501869_item	3720741	et	0	main
vigu	doc_491521501869_item	3720742	et	0	main
teen	doc_491521501869_item	3720743	et	0	main
seetõttu	doc_491521501869_item	3720744	et	0	main
et	doc_491521501869_item	3720745	et	0	main
sõna	doc_491521501869_item	3720746	et	0	main
jääb	doc_491521501869_item	3720747	et	0	main
mul	doc_491521501869_item	3720748	et	0	main
tihti	doc_491521501869_item	3720749	et	0	main
meelde	doc_491521501869_item	3720750	et	0	main
kindlas	doc_491521501869_item	3720751	et	0	main
situatsioonis	doc_491521501869_item	3720752	et	0	main
kus	doc_491521501869_item	3720753	et	0	main
tal	doc_491521501869_item	3720754	et	0	main
on	doc_491521501869_item	3720755	et	0	main
ka	doc_491521501869_item	3720756	et	0	main
üks	doc_491521501869_item	3720757	et	0	main
kindel	doc_491521501869_item	3720758	et	0	main
tähendus	doc_491521501869_item	3720759	et	0	main
sellepärast	doc_491521501869_item	3720760	et	0	main
et	doc_491521501869_item	3720761	et	0	main
mul	doc_491521501869_item	3720762	et	0	main
on	doc_491521501869_item	3720763	et	0	main
väga	doc_491521501869_item	3720764	et	0	main
hea	doc_491521501869_item	3720765	et	0	main
kuulmismälu	doc_491521501869_item	3720766	et	0	main
saan	doc_491521501869_item	3720767	et	0	main
sel	doc_491521501869_item	3720768	et	0	main
viisil	doc_491521501869_item	3720769	et	0	main
teada	doc_491521501869_item	3720770	et	0	main
palju	doc_491521501869_item	3720771	et	0	main
uusi	doc_491521501869_item	3720772	et	0	main
sõnu	doc_491521501869_item	3720773	et	0	main
et	doc_491521501869_item	3720774	et	0	main
paremini	doc_491521501869_item	3720775	et	0	main
need	doc_491521501869_item	3720776	et	0	main
meelde	doc_491521501869_item	3720777	et	0	main
jätta	doc_491521501869_item	3720778	et	0	main
püüan	doc_491521501869_item	3720779	et	0	main
kasutada	doc_491521501869_item	3720780	et	0	main
koheselt	doc_491521501869_item	3720781	et	0	main
tihti	doc_491521501869_item	3720782	et	0	main
juhtub	doc_491521501869_item	3720783	et	0	main
nii	doc_491521501869_item	3720784	et	0	main
et	doc_491521501869_item	3720785	et	0	main
see	doc_491521501869_item	3720786	et	0	main
ei	doc_491521501869_item	3720787	et	0	main
sobi	doc_491521501869_item	3720788	et	0	main
uuesse	doc_491521501869_item	3720789	et	0	main
konteksti	doc_491521501869_item	3720790	et	0	main
kui	doc_491521501869_item	3720791	et	0	main
mind	doc_491521501869_item	3720792	et	0	main
keegi	doc_491521501869_item	3720793	et	0	main
ei	doc_491521501869_item	3720794	et	0	main
paranda	doc_491521501869_item	3720795	et	0	main
tavaliselt	doc_491521501869_item	3720796	et	0	main
ei	doc_491521501869_item	3720797	et	0	main
parandatagi	doc_491521501869_item	3720798	et	0	main
järeldan	doc_491521501869_item	3720799	et	0	main
et	doc_491521501869_item	3720800	et	0	main
see	doc_491521501869_item	3720801	et	0	main
klapib	doc_491521501869_item	3720802	et	0	main
ka	doc_491521501869_item	3720803	et	0	main
line	doc_491521501869_item	3720804	et	0	main
kasutusolukorraga	doc_491521501869_item	3720805	et	0	main
rektsioonivigu	doc_491521501869_item	3720806	et	0	main
teen	doc_491521501869_item	3720807	et	0	main
samal	doc_491521501869_item	3720808	et	0	main
põhjusel	doc_491521501869_item	3720809	et	0	main
nagu	doc_491521501869_item	3720810	et	0	main
ka	doc_491521501869_item	3720811	et	0	main
õpilased	doc_491521501869_item	3720812	et	0	main
ei	doc_491521501869_item	3720813	et	0	main
ole	doc_491521501869_item	3720814	et	0	main
rektsiooni	doc_491521501869_item	3720815	et	0	main
kasutamises	doc_491521501869_item	3720816	et	0	main
kindel	doc_491521501869_item	3720817	et	0	main
püüan	doc_491521501869_item	3720818	et	0	main
küll	doc_491521501869_item	3720819	et	0	main
need	doc_491521501869_item	3720820	et	0	main
kõik	doc_491521501869_item	3720821	et	0	main
meeles	doc_491521501869_item	3720822	et	0	main
pidada	doc_491521501869_item	3720823	et	0	main
kui	doc_491521501869_item	3720824	et	0	main
väsimuse	doc_491521501869_item	3720825	et	0	main
või	doc_491521501869_item	3720826	et	0	main
liigse	doc_491521501869_item	3720827	et	0	main
pinge	doc_491521501869_item	3720828	et	0	main
tõttu	doc_491521501869_item	3720829	et	0	main
mõned	doc_491521501869_item	3720830	et	0	main
ununevad	doc_491521501869_item	3720831	et	0	main
selle	doc_491521501869_item	3720832	et	0	main
töö	doc_491521501869_item	3720833	et	0	main
kirjutamisel	doc_491521501869_item	3720834	et	0	main
tehtud	doc_491521501869_item	3720835	et	0	main
objektivead	doc_491521501869_item	3720836	et	0	main
on	doc_491521501869_item	3720837	et	0	main
põhjustatud	doc_491521501869_item	3720838	et	0	main
verbi	doc_491521501869_item	3720839	et	0	main
aspekti	doc_491521501869_item	3720840	et	0	main
segiajamisest	doc_491521501869_item	3720841	et	0	main
kirjutab	doc_491521501869_item	3720842	et	0	main
seda	doc_491521501869_item	3720843	et	0	main
sõnavormi	doc_491521501869_item	3720844	et	0	main
lausega	doc_491521501869_item	3720845	et	0	main
tahtsin	doc_491521501869_item	3720846	et	0	main
öelda	doc_491521501869_item	3720847	et	0	main
et	doc_491521501869_item	3720848	et	0	main
kirjutab	doc_491521501869_item	3720849	et	0	main
alatiharilikult	doc_491521501869_item	3720850	et	0	main
pidin	doc_491521501869_item	3720851	et	0	main
aga	doc_491521501869_item	3720852	et	0	main
tarvitama	doc_491521501869_item	3720853	et	0	main
täissihitist	doc_491521501869_item	3720854	et	0	main
kuna	doc_491521501869_item	3720855	et	0	main
tegevus	doc_491521501869_item	3720856	et	0	main
lõpetatakse	doc_491521501869_item	3720857	et	0	main
kannab	doc_491521501869_item	3720858	et	0	main
emakeelset	doc_491521501869_item	3720859	et	0	main
malli	doc_491521501869_item	3720860	et	0	main
üle	doc_491521501869_item	3720861	et	0	main
on	doc_491521501869_item	3720862	et	0	main
muidugi	doc_491521501869_item	3720863	et	0	main
kirjutatud	doc_491521501869_item	3720864	et	0	main
valesti	doc_491521501869_item	3720865	et	0	main
üle	doc_491521501869_item	3720866	et	0	main
põhjustab	doc_491521501869_item	3720867	et	0	main
nimetava	doc_491521501869_item	3720868	et	0	main
või	doc_491521501869_item	3720869	et	0	main
omastava	doc_491521501869_item	3720870	et	0	main
käände	doc_491521501869_item	3720871	et	0	main
tarvitamist	doc_491521501869_item	3720872	et	0	main
siin	doc_491521501869_item	3720873	et	0	main
kohal	doc_491521501869_item	3720874	et	0	main
omastava	doc_491521501869_item	3720875	et	0	main
sest	doc_491521501869_item	3720876	et	0	main
ta	doc_491521501869_item	3720877	et	0	main
näitab	doc_491521501869_item	3720878	et	0	main
tegevuse	doc_491521501869_item	3720879	et	0	main
lõpetatust	doc_491521501869_item	3720880	et	0	main
selmet	doc_491521501869_item	3720881	et	0	main
jätta	doc_491521501869_item	3720882	et	0	main
õiget	doc_491521501869_item	3720883	et	0	main
väljendit	doc_491521501869_item	3720884	et	0	main
meelde	doc_491521501869_item	3720885	et	0	main
on	doc_491521501869_item	3720886	et	0	main
vaja	doc_491521501869_item	3720887	et	0	main
kirjutada	doc_491521501869_item	3720888	et	0	main
jätta	doc_491521501869_item	3720889	et	0	main
õige	doc_491521501869_item	3720890	et	0	main
väljend	doc_491521501869_item	3720891	et	0	main
meelde	doc_491521501869_item	3720892	et	0	main
sest	doc_491521501869_item	3720893	et	0	main
õige	doc_491521501869_item	3720894	et	0	main
väljend	doc_491521501869_item	3720895	et	0	main
on	doc_491521501869_item	3720896	et	0	main
da-infinitiivi	doc_491521501869_item	3720897	et	0	main
täissihitis	doc_491521501869_item	3720898	et	0	main
tegin	doc_491521501869_item	3720899	et	0	main
ka	doc_491521501869_item	3720900	et	0	main
stiilivea	doc_491521501869_item	3720901	et	0	main
küll	doc_491521501869_item	3720902	et	0	main
kasutasin	doc_491521501869_item	3720903	et	0	main
sõna	doc_491521501869_item	3720904	et	0	main
samasse	doc_491521501869_item	3720905	et	0	main
argikeelse	doc_491521501869_item	3720906	et	0	main
vormi	doc_491521501869_item	3720907	et	0	main
samma	doc_491521501869_item	3720908	et	0	main
kirjalikus	doc_491521501869_item	3720909	et	0	main
tekstis	doc_491521501869_item	3720910	et	0	main
verbivorm	doc_491521501869_item	3720911	et	0	main
kirjutatuid	doc_491521501869_item	3720912	et	0	main
selmet	doc_491521501869_item	3720913	et	0	main
kirjutatud	doc_491521501869_item	3720914	et	0	main
on	doc_491521501869_item	3720915	et	0	main
samuti	doc_491521501869_item	3720916	et	0	main
tulnud	doc_491521501869_item	3720917	et	0	main
argikeelest	doc_491521501869_item	3720918	et	0	main
minu	doc_491521501869_item	3720919	et	0	main
praegune	doc_491521501869_item	3720920	et	0	main
probleem	doc_491521501869_item	3720921	et	0	main
on	doc_491521501869_item	3720922	et	0	main
selles	doc_491521501869_item	3720923	et	0	main
et	doc_491521501869_item	3720924	et	0	main
ei	doc_491521501869_item	3720925	et	0	main
suuda	doc_491521501869_item	3720926	et	0	main
alati	doc_491521501869_item	3720927	et	0	main
tõmmata	doc_491521501869_item	3720928	et	0	main
piiri	doc_491521501869_item	3720929	et	0	main
erinevate	doc_491521501869_item	3720930	et	0	main
stiilide	doc_491521501869_item	3720931	et	0	main
vahel	doc_491521501869_item	3720932	et	0	main
põhjus	doc_491521501869_item	3720933	et	0	main
on	doc_491521501869_item	3720934	et	0	main
liigses	doc_491521501869_item	3720935	et	0	main
argikeele	doc_491521501869_item	3720936	et	0	main
kuulamises	doc_491521501869_item	3720937	et	0	main
raadiost	doc_491521501869_item	3720938	et	0	main
ja	doc_491521501869_item	3720939	et	0	main
toanaabritelt	doc_491521501869_item	3720940	et	0	main
mis	doc_491521501869_item	3720941	et	0	main
läheb	doc_491521501869_item	3720942	et	0	main
segamini	doc_491521501869_item	3720943	et	0	main
koolis	doc_491521501869_item	3720944	et	0	main
õpitud	doc_491521501869_item	3720945	et	0	main
keele	doc_491521501869_item	3720946	et	0	main
normatiivse	doc_491521501869_item	3720947	et	0	main
keelekasutamisega	doc_491521501869_item	3720948	et	0	main
samuti	doc_491521501869_item	3720949	et	0	main
kui	doc_491521501869_item	3720950	et	0	main
saan	doc_491521501869_item	3720951	et	0	main
teada	doc_491521501869_item	3720952	et	0	main
midagi	doc_491521501869_item	3720953	et	0	main
uut	doc_491521501869_item	3720954	et	0	main
sõna	doc_491521501869_item	3720955	et	0	main
või	doc_491521501869_item	3720956	et	0	main
väljendi	doc_491521501869_item	3720957	et	0	main
püüan	doc_491521501869_item	3720958	et	0	main
analüüsida	doc_491521501869_item	3720959	et	0	main
miks	doc_491521501869_item	3720960	et	0	main
öeldi	doc_491521501869_item	3720961	et	0	main
just	doc_491521501869_item	3720962	et	0	main
nii	doc_491521501869_item	3720963	et	0	main
ja	doc_491521501869_item	3720964	et	0	main
mitte	doc_491521501869_item	3720965	et	0	main
teisti	doc_491521501869_item	3720966	et	0	main
mõnikord	doc_491521501869_item	3720967	et	0	main
järeldan	doc_491521501869_item	3720968	et	0	main
õigesti	doc_491521501869_item	3720969	et	0	main
mõnikord	doc_491521501869_item	3720970	et	0	main
on	doc_491521501869_item	3720971	et	0	main
aga	doc_491521501869_item	3720972	et	0	main
järeldus	doc_491521501869_item	3720973	et	0	main
vale	doc_491521501869_item	3720974	et	0	main
vahel	doc_491521501869_item	3720975	et	0	main
ei	doc_491521501869_item	3720976	et	0	main
saa	doc_491521501869_item	3720977	et	0	main
ka	doc_491521501869_item	3720978	et	0	main
kohe	doc_491521501869_item	3720979	et	0	main
küsida	doc_491521501869_item	3720980	et	0	main
sest	doc_491521501869_item	3720981	et	0	main
loomuliku	doc_491521501869_item	3720982	et	0	main
kõne	doc_491521501869_item	3720983	et	0	main
vool	doc_491521501869_item	3720984	et	0	main
on	doc_491521501869_item	3720985	et	0	main
kiire	doc_491521501869_item	3720986	et	0	main
ja	doc_491521501869_item	3720987	et	0	main
sõna	doc_491521501869_item	3720988	et	0	main
kipub	doc_491521501869_item	3720989	et	0	main
ununema	doc_491521501869_item	3720990	et	0	main
kirjutamise	doc_491521501869_item	3720991	et	0	main
käigus	doc_491521501869_item	3720992	et	0	main
kohtasin	doc_491521501869_item	3720993	et	0	main
ka	doc_491521501869_item	3720994	et	0	main
keerulist	doc_491521501869_item	3720995	et	0	main
juhtumit	doc_491521501869_item	3720996	et	0	main
mida	doc_491521501869_item	3720997	et	0	main
panin	doc_491521501869_item	3720998	et	0	main
muu	doc_491521501869_item	3720999	et	0	main
vigade	doc_491521501869_item	3721000	et	0	main
kategooriasse	doc_491521501869_item	3721001	et	0	main
selmet	doc_491521501869_item	3721002	et	0	main
selle	doc_491521501869_item	3721003	et	0	main
tüübi	doc_491521501869_item	3721004	et	0	main
vigade	doc_491521501869_item	3721005	et	0	main
vältimiseks	doc_491521501869_item	3721006	et	0	main
on	doc_491521501869_item	3721007	et	0	main
õige	doc_491521501869_item	3721008	et	0	main
seda	doc_491521501869_item	3721009	et	0	main
tüüpi	doc_491521501869_item	3721010	et	0	main
vigade	doc_491521501869_item	3721011	et	0	main
vältimiseks	doc_491521501869_item	3721012	et	0	main
mulle	doc_491521501869_item	3721013	et	0	main
seletati	doc_491521501869_item	3721014	et	0	main
nii	doc_491521501869_item	3721015	et	0	main
et	doc_491521501869_item	3721016	et	0	main
kui	doc_491521501869_item	3721017	et	0	main
siihitis	doc_491521501869_item	3721018	et	0	main
on	doc_491521501869_item	3721019	et	0	main
ainsuses	doc_491521501869_item	3721020	et	0	main
tema	doc_491521501869_item	3721021	et	0	main
täiendid	doc_491521501869_item	3721022	et	0	main
on	doc_491521501869_item	3721023	et	0	main
alati	doc_491521501869_item	3721024	et	0	main
omastavas	doc_491521501869_item	3721025	et	0	main
kui	doc_491521501869_item	3721026	et	0	main
on	doc_491521501869_item	3721027	et	0	main
aga	doc_491521501869_item	3721028	et	0	main
sihitis	doc_491521501869_item	3721029	et	0	main
mitmuses	doc_491521501869_item	3721030	et	0	main
täiendeid	doc_491521501869_item	3721031	et	0	main
tuleb	doc_491521501869_item	3721032	et	0	main
kirjutada	doc_491521501869_item	3721033	et	0	main
juba	doc_491521501869_item	3721034	et	0	main
osastavas	doc_491521501869_item	3721035	et	0	main
samasse	doc_491521501869_item	3721036	et	0	main
tüüpi	doc_491521501869_item	3721037	et	0	main
loen	doc_491521501869_item	3721038	et	0	main
ka	doc_491521501869_item	3721039	et	0	main
lauset	doc_491521501869_item	3721040	et	0	main
tihti	doc_491521501869_item	3721041	et	0	main
see	doc_491521501869_item	3721042	et	0	main
toimub	doc_491521501869_item	3721043	et	0	main
eesti	doc_491521501869_item	3721044	et	0	main
keele	doc_491521501869_item	3721045	et	0	main
normaallauses	doc_491521501869_item	3721046	et	0	main
on	doc_491521501869_item	3721047	et	0	main
aga	doc_491521501869_item	3721048	et	0	main
verb	doc_491521501869_item	3721049	et	0	main
2	doc_491521501869_item	3721050	et	0	main
kohal	doc_491521501869_item	3721051	et	0	main
parandatud	doc_491521501869_item	3721052	et	0	main
lause	doc_491521501869_item	3721053	et	0	main
on	doc_491521501869_item	3721054	et	0	main
siis	doc_491521501869_item	3721055	et	0	main
tihti	doc_491521501869_item	3721056	et	0	main
toimub	doc_491521501869_item	3721057	et	0	main
see	doc_491521501869_item	3721058	et	0	main
polüseeme	doc_491521501869_item	3721059	et	0	main
ja	doc_491521501869_item	3721060	et	0	main
homonüüme	doc_491521501869_item	3721061	et	0	main
on	doc_491521501869_item	3721062	et	0	main
vääralt	doc_491521501869_item	3721063	et	0	main
pruukida	doc_491521501869_item	3721064	et	0	main
vist	doc_491521501869_item	3721065	et	0	main
kõige	doc_491521501869_item	3721066	et	0	main
lihtsam	doc_491521501869_item	3721067	et	0	main
siin	doc_491521501869_item	3721068	et	0	main
kohal	doc_491521501869_item	3721069	et	0	main
ja	doc_491521501869_item	3721070	et	0	main
sel	doc_491521501869_item	3721071	et	0	main
juhul	doc_491521501869_item	3721072	et	0	main
väljendeist	doc_491521501869_item	3721073	et	0	main
sain	doc_491521501869_item	3721074	et	0	main
ma	doc_491521501869_item	3721075	et	0	main
kombineerimisega	doc_491521501869_item	3721076	et	0	main
uue	doc_491521501869_item	3721077	et	0	main
siin	doc_491521501869_item	3721078	et	0	main
juhul	doc_491521501869_item	3721079	et	0	main
omastavat	doc_491521501869_item	3721080	et	0	main
ja	doc_491521501869_item	3721081	et	0	main
osastavat	doc_491521501869_item	3721082	et	0	main
segama	doc_491521501869_item	3721083	et	0	main
ja	doc_491521501869_item	3721084	et	0	main
omastavat	doc_491521501869_item	3721085	et	0	main
ja	doc_491521501869_item	3721086	et	0	main
osastavat	doc_491521501869_item	3721087	et	0	main
segi	doc_491521501869_item	3721088	et	0	main
ajama	doc_491521501869_item	3721089	et	0	main
on	doc_491521501869_item	3721090	et	0	main
homonüümid	doc_491521501869_item	3721091	et	0	main
segama	doc_491521501869_item	3721092	et	0	main
tähendus	doc_491521501869_item	3721093	et	0	main
on	doc_491521501869_item	3721094	et	0	main
midagi	doc_491521501869_item	3721095	et	0	main
kuskil	doc_491521501869_item	3721096	et	0	main
segama	doc_491521501869_item	3721097	et	0	main
näiteks	doc_491521501869_item	3721098	et	0	main
putru	doc_491521501869_item	3721099	et	0	main
segama	doc_491521501869_item	3721100	et	0	main
segi	doc_491521501869_item	3721101	et	0	main
ajama	doc_491521501869_item	3721102	et	0	main
on	doc_491521501869_item	3721103	et	0	main
segamini	doc_491521501869_item	3721104	et	0	main
ajama	doc_491521501869_item	3721105	et	0	main
cira	doc_491521501869_item	3721106	et	0	main
vahetama	doc_491521501869_item	3721107	et	0	main
lauses	doc_491521501869_item	3721108	et	0	main
ma	doc_491521501869_item	3721109	et	0	main
muidugi	doc_491521501869_item	3721110	et	0	main
käändeid	doc_491521501869_item	3721111	et	0	main
ei	doc_491521501869_item	3721112	et	0	main
sega	doc_491521501869_item	3721113	et	0	main
vaid	doc_491521501869_item	3721114	et	0	main
ajan	doc_491521501869_item	3721115	et	0	main
segi	doc_491521501869_item	3721116	et	0	main
polüseemidel	doc_491521501869_item	3721117	et	0	main
ei	doc_491521501869_item	3721118	et	0	main
tea	doc_491521501869_item	3721119	et	0	main
ja	doc_491521501869_item	3721120	et	0	main
ei	doc_491521501869_item	3721121	et	0	main
tunne	doc_491521501869_item	3721122	et	0	main
on	doc_491521501869_item	3721123	et	0	main
vene	doc_491521501869_item	3721124	et	0	main
keeles	doc_491521501869_item	3721125	et	0	main
üks	doc_491521501869_item	3721126	et	0	main
ja	doc_491521501869_item	3721127	et	0	main
sama	doc_491521501869_item	3721128	et	0	main
tähendus	doc_491521501869_item	3721129	et	0	main
see	doc_491521501869_item	3721130	et	0	main
oligi	doc_491521501869_item	3721131	et	0	main
vea	doc_491521501869_item	3721132	et	0	main
põhjus	doc_491521501869_item	3721133	et	0	main
vale	doc_491521501869_item	3721134	et	0	main
sõna	doc_491521501869_item	3721135	et	0	main
valik	doc_491521501869_item	3721136	et	0	main
on	doc_491521501869_item	3721137	et	0	main
põhjustatud	doc_491521501869_item	3721138	et	0	main
samuti	doc_491521501869_item	3721139	et	0	main
emakeele	doc_491521501869_item	3721140	et	0	main
mõjust	doc_491521501869_item	3721141	et	0	main
selmet	doc_491521501869_item	3721142	et	0	main
lause	doc_491521501869_item	3721143	et	0	main
kõlab	doc_491521501869_item	3721144	et	0	main
mitte	doc_491521501869_item	3721145	et	0	main
venepäraselt	doc_491521501869_item	3721146	et	0	main
lause	doc_491521501869_item	3721147	et	0	main
ei	doc_491521501869_item	3721148	et	0	main
kõla	doc_491521501869_item	3721149	et	0	main
hästi	doc_491521501869_item	3721150	et	0	main
seletati	doc_491521501869_item	3721151	et	0	main
et	doc_491521501869_item	3721152	et	0	main
esimene	doc_491521501869_item	3721153	et	0	main
variant	doc_491521501869_item	3721154	et	0	main
on	doc_491521501869_item	3721155	et	0	main
kuidagi	doc_491521501869_item	3721156	et	0	main
imelik	doc_491521501869_item	3721157	et	0	main
lapsused	doc_491521501869_item	3721158	et	0	main
e	doc_491521501869_item	3721159	et	0	main
äpardused	doc_491521501869_item	3721160	et	0	main
rõhutada	doc_491521501869_item	3721161	et	0	main
ebareeglipäraste	doc_491521501869_item	3721162	et	0	main
vorme	doc_491521501869_item	3721163	et	0	main
õige	doc_491521501869_item	3721164	et	0	main
reeglipäraseid	doc_491521501869_item	3721165	et	0	main
vorme	doc_491521501869_item	3721166	et	0	main
ja	doc_491521501869_item	3721167	et	0	main
võiks	doc_491521501869_item	3721168	et	0	main
sobivam	doc_491521501869_item	3721169	et	0	main
võib	doc_491521501869_item	3721170	et	0	main
sest	doc_491521501869_item	3721171	et	0	main
konditsionaalsus	doc_491521501869_item	3721172	et	0	main
on	doc_491521501869_item	3721173	et	0	main
juba	doc_491521501869_item	3721174	et	0	main
väljendatud	doc_491521501869_item	3721175	et	0	main
verbi	doc_491521501869_item	3721176	et	0	main
iseendaga	doc_491521501869_item	3721177	et	0	main
võib	doc_491521501869_item	3721178	et	0	main
seletada	doc_491521501869_item	3721179	et	0	main
ainult	doc_491521501869_item	3721180	et	0	main
tähelepanematusega	doc_491521501869_item	3721181	et	0	main
teksti	doc_491521501869_item	3721182	et	0	main
läbi	doc_491521501869_item	3721183	et	0	main
lugemisel	doc_491521501869_item	3721184	et	0	main
veaanalüüs	doc_491521501868_item	3729517	et	0	main
antud	doc_491521501868_item	3729518	et	0	main
töös	doc_491521501868_item	3729519	et	0	main
mina	doc_491521501868_item	3729520	et	0	main
analüüsin	doc_491521501868_item	3729521	et	0	main
vene	doc_491521501868_item	3729522	et	0	main
gümnaasiumi	doc_491521501868_item	3729523	et	0	main
9	doc_491521501868_item	3729524	et	0	main
10	doc_491521501868_item	3729525	et	0	main
ja	doc_491521501868_item	3729526	et	0	main
11	doc_491521501868_item	3729527	et	0	main
kl	doc_491521501868_item	3729528	et	0	main
õpilaste	doc_491521501868_item	3729529	et	0	main
kirjalikke	doc_491521501868_item	3729530	et	0	main
töid	doc_491521501868_item	3729531	et	0	main
materjal	doc_491521501868_item	3729532	et	0	main
oli	doc_491521501868_item	3729533	et	0	main
kogutud	doc_491521501868_item	3729534	et	0	main
praktika	doc_491521501868_item	3729535	et	0	main
ajal	doc_491521501868_item	3729536	et	0	main
vaatamata	doc_491521501868_item	3729537	et	0	main
vanusele	doc_491521501868_item	3729538	et	0	main
kolme	doc_491521501868_item	3729539	et	0	main
klassi	doc_491521501868_item	3729540	et	0	main
õpilaste	doc_491521501868_item	3729541	et	0	main
keeletase	doc_491521501868_item	3729542	et	0	main
oli	doc_491521501868_item	3729543	et	0	main
väga	doc_491521501868_item	3729544	et	0	main
kõrge	doc_491521501868_item	3729545	et	0	main
kui	doc_491521501868_item	3729546	et	0	main
9	doc_491521501868_item	3729547	et	0	main
klassis	doc_491521501868_item	3729548	et	0	main
tekibki	doc_491521501868_item	3729549	et	0	main
raskusi	doc_491521501868_item	3729550	et	0	main
enda	doc_491521501868_item	3729551	et	0	main
väljendamisega	doc_491521501868_item	3729552	et	0	main
eesti	doc_491521501868_item	3729553	et	0	main
keeles	doc_491521501868_item	3729554	et	0	main
siis	doc_491521501868_item	3729555	et	0	main
11	doc_491521501868_item	3729556	et	0	main
klassis	doc_491521501868_item	3729557	et	0	main
seda	doc_491521501868_item	3729558	et	0	main
juba	doc_491521501868_item	3729559	et	0	main
ei	doc_491521501868_item	3729560	et	0	main
juhtu	doc_491521501868_item	3729561	et	0	main
paljud	doc_491521501868_item	3729562	et	0	main
õpilased	doc_491521501868_item	3729563	et	0	main
käivad	doc_491521501868_item	3729564	et	0	main
keelekursustel	doc_491521501868_item	3729565	et	0	main
mõnedel	doc_491521501868_item	3729566	et	0	main
on	doc_491521501868_item	3729567	et	0	main
eraõpetaja	doc_491521501868_item	3729568	et	0	main
ning	doc_491521501868_item	3729569	et	0	main
paljud	doc_491521501868_item	3729570	et	0	main
suhtlevad	doc_491521501868_item	3729571	et	0	main
eesti	doc_491521501868_item	3729572	et	0	main
keelt	doc_491521501868_item	3729573	et	0	main
kõnelevate	doc_491521501868_item	3729574	et	0	main
sõpradega	doc_491521501868_item	3729575	et	0	main
arvan	doc_491521501868_item	3729576	et	0	main
et	doc_491521501868_item	3729577	et	0	main
väga	doc_491521501868_item	3729578	et	0	main
palju	doc_491521501868_item	3729579	et	0	main
sõltub	doc_491521501868_item	3729580	et	0	main
ka	doc_491521501868_item	3729581	et	0	main
keeleõpetajast	doc_491521501868_item	3729582	et	0	main
kelleks	doc_491521501868_item	3729583	et	0	main
nendes	doc_491521501868_item	3729584	et	0	main
klassides	doc_491521501868_item	3729585	et	0	main
oli	doc_491521501868_item	3729586	et	0	main
riigikeeleõpetaja	doc_491521501868_item	3729587	et	0	main
eesnimi	doc_491521501868_item	3729588	et	0	main
perekonnanimi	doc_491521501868_item	3729589	et	0	main
headmuljet	doc_491521501868_item	3729590	et	0	main
teeb	doc_491521501868_item	3729591	et	0	main
mitte	doc_491521501868_item	3729592	et	0	main
vaid	doc_491521501868_item	3729593	et	0	main
eesti	doc_491521501868_item	3729594	et	0	main
keele	doc_491521501868_item	3729595	et	0	main
grammatilise	doc_491521501868_item	3729596	et	0	main
korrektsus	doc_491521501868_item	3729597	et	0	main
vaid	doc_491521501868_item	3729598	et	0	main
õpilaste	doc_491521501868_item	3729599	et	0	main
lai	doc_491521501868_item	3729600	et	0	main
silmaring	doc_491521501868_item	3729601	et	0	main
üldine	doc_491521501868_item	3729602	et	0	main
eruditsioon	doc_491521501868_item	3729603	et	0	main
9	doc_491521501868_item	3729604	et	0	main
klass	doc_491521501868_item	3729605	et	0	main
kontrolltöö	doc_491521501868_item	3729606	et	0	main
teema	doc_491521501868_item	3729607	et	0	main
sport	doc_491521501868_item	3729608	et	0	main
10	doc_491521501868_item	3729609	et	0	main
klass	doc_491521501868_item	3729610	et	0	main
ümberjutustus	doc_491521501868_item	3729611	et	0	main
jaan	doc_491521501868_item	3729612	et	0	main
koorti	doc_491521501868_item	3729613	et	0	main
lemmikloomad	doc_491521501868_item	3729614	et	0	main
11	doc_491521501868_item	3729615	et	0	main
klass	doc_491521501868_item	3729616	et	0	main
ametlike	doc_491521501868_item	3729617	et	0	main
kirjade	doc_491521501868_item	3729618	et	0	main
vormistamine	doc_491521501868_item	3729619	et	0	main
taotlus	doc_491521501868_item	3729620	et	0	main
mõnede	doc_491521501868_item	3729621	et	0	main
õpilaste	doc_491521501868_item	3729622	et	0	main
tööd	doc_491521501868_item	3729623	et	0	main
on	doc_491521501868_item	3729624	et	0	main
lisatud	doc_491521501868_item	3729625	et	0	main
lõpus	doc_491521501868_item	3729626	et	0	main
1	doc_491521501868_item	3729627	et	0	main
hääldus-	doc_491521501868_item	3729628	et	0	main
ja	doc_491521501868_item	3729629	et	0	main
õigekiri	doc_491521501868_item	3729630	et	0	main
kuna	doc_491521501868_item	3729631	et	0	main
10	doc_491521501868_item	3729632	et	0	main
klass	doc_491521501868_item	3729633	et	0	main
kirjutas	doc_491521501868_item	3729634	et	0	main
ümberjutustuse	doc_491521501868_item	3729635	et	0	main
mis	doc_491521501868_item	3729636	et	0	main
oli	doc_491521501868_item	3729637	et	0	main
lindistatud	doc_491521501868_item	3729638	et	0	main
kaseti	doc_491521501868_item	3729639	et	0	main
peale	doc_491521501868_item	3729640	et	0	main
siis	doc_491521501868_item	3729641	et	0	main
neid	doc_491521501868_item	3729642	et	0	main
vigu	doc_491521501868_item	3729643	et	0	main
oli	doc_491521501868_item	3729644	et	0	main
suhteliselt	doc_491521501868_item	3729645	et	0	main
vähe	doc_491521501868_item	3729646	et	0	main
mittu	doc_491521501868_item	3729647	et	0	main
mitu	doc_491521501868_item	3729648	et	0	main
sõna	doc_491521501868_item	3729649	et	0	main
on	doc_491521501868_item	3729650	et	0	main
ii-välteline	doc_491521501868_item	3729651	et	0	main
ning	doc_491521501868_item	3729652	et	0	main
õpilastele	doc_491521501868_item	3729653	et	0	main
tundub	doc_491521501868_item	3729654	et	0	main
et	doc_491521501868_item	3729655	et	0	main
seda	doc_491521501868_item	3729656	et	0	main
hääldatakse	doc_491521501868_item	3729657	et	0	main
pikalt	doc_491521501868_item	3729658	et	0	main
nagu	doc_491521501868_item	3729659	et	0	main
oleks	doc_491521501868_item	3729660	et	0	main
see	doc_491521501868_item	3729661	et	0	main
sõna	doc_491521501868_item	3729662	et	0	main
kahe	doc_491521501868_item	3729663	et	0	main
t-ga	doc_491521501868_item	3729664	et	0	main
skulptoor	doc_491521501868_item	3729665	et	0	main
skulptor	doc_491521501868_item	3729666	et	0	main
see	doc_491521501868_item	3729667	et	0	main
kes	doc_491521501868_item	3729668	et	0	main
loob	doc_491521501868_item	3729669	et	0	main
kirjutame	doc_491521501868_item	3729670	et	0	main
ühe	doc_491521501868_item	3729671	et	0	main
o-ga	doc_491521501868_item	3729672	et	0	main
rõhk	doc_491521501868_item	3729673	et	0	main
esimesel	doc_491521501868_item	3729674	et	0	main
silbil	doc_491521501868_item	3729675	et	0	main
skulptur	doc_491521501868_item	3729676	et	0	main
skulptuur	doc_491521501868_item	3729677	et	0	main
see	doc_491521501868_item	3729678	et	0	main
mida	doc_491521501868_item	3729679	et	0	main
luuakse	doc_491521501868_item	3729680	et	0	main
rõhk	doc_491521501868_item	3729681	et	0	main
on	doc_491521501868_item	3729682	et	0	main
teisel	doc_491521501868_item	3729683	et	0	main
silbil	doc_491521501868_item	3729684	et	0	main
gravur	doc_491521501868_item	3729685	et	0	main
graviaur	doc_491521501868_item	3729686	et	0	main
skulpturiga	doc_491521501868_item	3729687	et	0	main
analoogiline	doc_491521501868_item	3729688	et	0	main
viga	doc_491521501868_item	3729689	et	0	main
rõhk	doc_491521501868_item	3729690	et	0	main
on	doc_491521501868_item	3729691	et	0	main
teisel	doc_491521501868_item	3729692	et	0	main
silbil	doc_491521501868_item	3729693	et	0	main
soobin	doc_491521501868_item	3729694	et	0	main
sobin	doc_491521501868_item	3729695	et	0	main
see	doc_491521501868_item	3729696	et	0	main
viga	doc_491521501868_item	3729697	et	0	main
on	doc_491521501868_item	3729698	et	0	main
väga	doc_491521501868_item	3729699	et	0	main
levinud	doc_491521501868_item	3729700	et	0	main
vene	doc_491521501868_item	3729701	et	0	main
õpilaste	doc_491521501868_item	3729702	et	0	main
kestel	doc_491521501868_item	3729703	et	0	main
seda	doc_491521501868_item	3729704	et	0	main
viga	doc_491521501868_item	3729705	et	0	main
oli	doc_491521501868_item	3729706	et	0	main
parandatud	doc_491521501868_item	3729707	et	0	main
6	doc_491521501868_item	3729708	et	0	main
korda	doc_491521501868_item	3729709	et	0	main
seda	doc_491521501868_item	3729710	et	0	main
võiks	doc_491521501868_item	3729711	et	0	main
seletada	doc_491521501868_item	3729712	et	0	main
nii	doc_491521501868_item	3729713	et	0	main
et	doc_491521501868_item	3729714	et	0	main
vene	doc_491521501868_item	3729715	et	0	main
keeles	doc_491521501868_item	3729716	et	0	main
esimene	doc_491521501868_item	3729717	et	0	main
rõhuline	doc_491521501868_item	3729718	et	0	main
silp	doc_491521501868_item	3729719	et	0	main
on	doc_491521501868_item	3729720	et	0	main
natukene	doc_491521501868_item	3729721	et	0	main
pikem	doc_491521501868_item	3729722	et	0	main
kui	doc_491521501868_item	3729723	et	0	main
teised	doc_491521501868_item	3729724	et	0	main
silbid	doc_491521501868_item	3729725	et	0	main
ja	doc_491521501868_item	3729726	et	0	main
õpilased	doc_491521501868_item	3729727	et	0	main
püüavad	doc_491521501868_item	3729728	et	0	main
hääldada	doc_491521501868_item	3729729	et	0	main
eetikeelse	doc_491521501868_item	3729730	et	0	main
sõna	doc_491521501868_item	3729731	et	0	main
venepäraselt	doc_491521501868_item	3729732	et	0	main
kaa	doc_491521501868_item	3729733	et	0	main
ka	doc_491521501868_item	3729734	et	0	main
samuti	doc_491521501868_item	3729735	et	0	main
paljud	doc_491521501868_item	3729736	et	0	main
päriseestlased	doc_491521501868_item	3729737	et	0	main
hääldavad	doc_491521501868_item	3729738	et	0	main
seda	doc_491521501868_item	3729739	et	0	main
sõna	doc_491521501868_item	3729740	et	0	main
pikalt	doc_491521501868_item	3729741	et	0	main
nii	doc_491521501868_item	3729742	et	0	main
et	doc_491521501868_item	3729743	et	0	main
tekib	doc_491521501868_item	3729744	et	0	main
mulje	doc_491521501868_item	3729745	et	0	main
et	doc_491521501868_item	3729746	et	0	main
sõna	doc_491521501868_item	3729747	et	0	main
kirjutatavat	doc_491521501868_item	3729748	et	0	main
kahe	doc_491521501868_item	3729749	et	0	main
k-ga	doc_491521501868_item	3729750	et	0	main
võib	doc_491521501868_item	3729751	et	0	main
olla	doc_491521501868_item	3729752	et	0	main
sellepärast	doc_491521501868_item	3729753	et	0	main
et	doc_491521501868_item	3729754	et	0	main
tegemist	doc_491521501868_item	3729755	et	0	main
on	doc_491521501868_item	3729756	et	0	main
pika	doc_491521501868_item	3729757	et	0	main
ja	doc_491521501868_item	3729758	et	0	main
lahtise	doc_491521501868_item	3729759	et	0	main
silbiga	doc_491521501868_item	3729760	et	0	main
problemid	doc_491521501868_item	3729761	et	0	main
probleemid	doc_491521501868_item	3729762	et	0	main
kohe	doc_491521501868_item	3729763	et	0	main
näha	doc_491521501868_item	3729764	et	0	main
vene-	doc_491521501868_item	3729765	et	0	main
javõi	doc_491521501868_item	3729766	et	0	main
inglise	doc_491521501868_item	3729767	et	0	main
keelset	doc_491521501868_item	3729768	et	0	main
mõju	doc_491521501868_item	3729769	et	0	main
2	doc_491521501868_item	3729770	et	0	main
astmevaheldus	doc_491521501868_item	3729771	et	0	main
9ndas	doc_491521501868_item	3729772	et	0	main
klassis	doc_491521501868_item	3729773	et	0	main
käsitlesime	doc_491521501868_item	3729774	et	0	main
teemat	doc_491521501868_item	3729775	et	0	main
sport	doc_491521501868_item	3729776	et	0	main
oli	doc_491521501868_item	3729777	et	0	main
2	doc_491521501868_item	3729778	et	0	main
populaarset	doc_491521501868_item	3729779	et	0	main
viga	doc_491521501868_item	3729780	et	0	main
jalgrattas	doc_491521501868_item	3729781	et	0	main
jalgratas	doc_491521501868_item	3729782	et	0	main
klassis	doc_491521501868_item	3729783	et	0	main
oli	doc_491521501868_item	3729784	et	0	main
16	doc_491521501868_item	3729785	et	0	main
õpilast	doc_491521501868_item	3729786	et	0	main
ja	doc_491521501868_item	3729787	et	0	main
õigesti	doc_491521501868_item	3729788	et	0	main
ühe	doc_491521501868_item	3729789	et	0	main
t-ga	doc_491521501868_item	3729790	et	0	main
kirjutasid	doc_491521501868_item	3729791	et	0	main
vaid	doc_491521501868_item	3729792	et	0	main
seitse	doc_491521501868_item	3729793	et	0	main
appi	doc_491521501868_item	3729794	et	0	main
tuli	doc_491521501868_item	3729795	et	0	main
malelaud	doc_491521501868_item	3729796	et	0	main
kus	doc_491521501868_item	3729797	et	0	main
analoogiliselt	doc_491521501868_item	3729798	et	0	main
vahelduvad	doc_491521501868_item	3729799	et	0	main
mustad-valged	doc_491521501868_item	3729800	et	0	main
ruudukesed	doc_491521501868_item	3729801	et	0	main
nim	doc_491521501868_item	3729802	et	0	main
jalgratas	doc_491521501868_item	3729803	et	0	main
j	doc_491521501868_item	3729804	et	0	main
ii	doc_491521501868_item	3729805	et	0	main
välde	doc_491521501868_item	3729806	et	0	main
om	doc_491521501868_item	3729807	et	0	main
jalgratta	doc_491521501868_item	3729808	et	0	main
m	doc_491521501868_item	3729809	et	0	main
iii	doc_491521501868_item	3729810	et	0	main
välde	doc_491521501868_item	3729811	et	0	main
os	doc_491521501868_item	3729812	et	0	main
jalgratast	doc_491521501868_item	3729813	et	0	main
7	doc_491521501868_item	3729814	et	0	main
ii	doc_491521501868_item	3729815	et	0	main
välde	doc_491521501868_item	3729816	et	0	main
k-ütl	doc_491521501868_item	3729817	et	0	main
jalgrattaga	doc_491521501868_item	3729818	et	0	main
m	doc_491521501868_item	3729819	et	0	main
iii	doc_491521501868_item	3729820	et	0	main
välde	doc_491521501868_item	3729821	et	0	main
lippul	doc_491521501868_item	3729822	et	0	main
lipul	doc_491521501868_item	3729823	et	0	main
5	doc_491521501868_item	3729824	et	0	main
opilast	doc_491521501868_item	3729825	et	0	main
kirjutasid	doc_491521501868_item	3729826	et	0	main
selle	doc_491521501868_item	3729827	et	0	main
sõna	doc_491521501868_item	3729828	et	0	main
kahe	doc_491521501868_item	3729829	et	0	main
p-ga	doc_491521501868_item	3729830	et	0	main
nim	doc_491521501868_item	3729831	et	0	main
lipp	doc_491521501868_item	3729832	et	0	main
m	doc_491521501868_item	3729833	et	0	main
iii	doc_491521501868_item	3729834	et	0	main
välde	doc_491521501868_item	3729835	et	0	main
om	doc_491521501868_item	3729836	et	0	main
lipu	doc_491521501868_item	3729837	et	0	main
i-1	doc_491521501868_item	3729838	et	0	main
ii	doc_491521501868_item	3729839	et	0	main
välde	doc_491521501868_item	3729840	et	0	main
os	doc_491521501868_item	3729841	et	0	main
lippu	doc_491521501868_item	3729842	et	0	main
m	doc_491521501868_item	3729843	et	0	main
iii	doc_491521501868_item	3729844	et	0	main
välde	doc_491521501868_item	3729845	et	0	main
alal	doc_491521501868_item	3729846	et	0	main
lipul	doc_491521501868_item	3729847	et	0	main
fi	doc_491521501868_item	3729848	et	0	main
ii	doc_491521501868_item	3729849	et	0	main
välde	doc_491521501868_item	3729850	et	0	main
10	doc_491521501868_item	3729851	et	0	main
klassis	doc_491521501868_item	3729852	et	0	main
oli	doc_491521501868_item	3729853	et	0	main
tehtud	doc_491521501868_item	3729854	et	0	main
vaid	doc_491521501868_item	3729855	et	0	main
üks	doc_491521501868_item	3729856	et	0	main
viga	doc_491521501868_item	3729857	et	0	main
aga	doc_491521501868_item	3729858	et	0	main
jällegi	doc_491521501868_item	3729859	et	0	main
see	doc_491521501868_item	3729860	et	0	main
esines	doc_491521501868_item	3729861	et	0	main
üsna	doc_491521501868_item	3729862	et	0	main
tihti	doc_491521501868_item	3729863	et	0	main
rottile	doc_491521501868_item	3729864	et	0	main
rotile	doc_491521501868_item	3729865	et	0	main
nim	doc_491521501868_item	3729866	et	0	main
rott	doc_491521501868_item	3729867	et	0	main
m	doc_491521501868_item	3729868	et	0	main
iii	doc_491521501868_item	3729869	et	0	main
välde	doc_491521501868_item	3729870	et	0	main
om	doc_491521501868_item	3729871	et	0	main
roti	doc_491521501868_item	3729872	et	0	main
ii	doc_491521501868_item	3729873	et	0	main
välde	doc_491521501868_item	3729874	et	0	main
os	doc_491521501868_item	3729875	et	0	main
rotti	doc_491521501868_item	3729876	et	0	main
m	doc_491521501868_item	3729877	et	0	main
iii	doc_491521501868_item	3729878	et	0	main
välde	doc_491521501868_item	3729879	et	0	main
alale	doc_491521501868_item	3729880	et	0	main
rotile	doc_491521501868_item	3729881	et	0	main
ii	doc_491521501868_item	3729882	et	0	main
välde	doc_491521501868_item	3729883	et	0	main
3	doc_491521501868_item	3729884	et	0	main
objektivead	doc_491521501868_item	3729885	et	0	main
ta	doc_491521501868_item	3729886	et	0	main
armastas	doc_491521501868_item	3729887	et	0	main
loomad	doc_491521501868_item	3729888	et	0	main
ta	doc_491521501868_item	3729889	et	0	main
armastas	doc_491521501868_item	3729890	et	0	main
loomi	doc_491521501868_item	3729891	et	0	main
tegusõna	doc_491521501868_item	3729892	et	0	main
armastama	doc_491521501868_item	3729893	et	0	main
on	doc_491521501868_item	3729894	et	0	main
partitiivverb	doc_491521501868_item	3729895	et	0	main
mis	doc_491521501868_item	3729896	et	0	main
nõuab	doc_491521501868_item	3729897	et	0	main
alati	doc_491521501868_item	3729898	et	0	main
osastava	doc_491521501868_item	3729899	et	0	main
kn	doc_491521501868_item	3729900	et	0	main
k	doc_491521501868_item	3729901	et	0	main
kasutamist	doc_491521501868_item	3729902	et	0	main
vares	doc_491521501868_item	3729903	et	0	main
sõi	doc_491521501868_item	3729904	et	0	main
lihatükki	doc_491521501868_item	3729905	et	0	main
ära	doc_491521501868_item	3729906	et	0	main
sõi	doc_491521501868_item	3729907	et	0	main
lihatüki	doc_491521501868_item	3729908	et	0	main
ära	doc_491521501868_item	3729909	et	0	main
kohe	doc_491521501868_item	3729910	et	0	main
näha	doc_491521501868_item	3729911	et	0	main
et	doc_491521501868_item	3729912	et	0	main
laps	doc_491521501868_item	3729913	et	0	main
ei	doc_491521501868_item	3729914	et	0	main
mõista	doc_491521501868_item	3729915	et	0	main
lõpetatud	doc_491521501868_item	3729916	et	0	main
ja	doc_491521501868_item	3729917	et	0	main
lõpetamatu	doc_491521501868_item	3729918	et	0	main
tegevust	doc_491521501868_item	3729919	et	0	main
kui	doc_491521501868_item	3729920	et	0	main
tegevus	doc_491521501868_item	3729921	et	0	main
on	doc_491521501868_item	3729922	et	0	main
lõpetatud	doc_491521501868_item	3729923	et	0	main
või	doc_491521501868_item	3729924	et	0	main
lõpule	doc_491521501868_item	3729925	et	0	main
viidav	doc_491521501868_item	3729926	et	0	main
resultatiivne	doc_491521501868_item	3729927	et	0	main
siis	doc_491521501868_item	3729928	et	0	main
tarvitatakse	doc_491521501868_item	3729929	et	0	main
täissihitist	doc_491521501868_item	3729930	et	0	main
omastavas	doc_491521501868_item	3729931	et	0	main
või	doc_491521501868_item	3729932	et	0	main
nimetavas	doc_491521501868_item	3729933	et	0	main
käändes	doc_491521501868_item	3729934	et	0	main
osasihitist	doc_491521501868_item	3729935	et	0	main
osastavas	doc_491521501868_item	3729936	et	0	main
käändes	doc_491521501868_item	3729937	et	0	main
kasutatakse	doc_491521501868_item	3729938	et	0	main
siis	doc_491521501868_item	3729939	et	0	main
kui	doc_491521501868_item	3729940	et	0	main
tegevus	doc_491521501868_item	3729941	et	0	main
ei	doc_491521501868_item	3729942	et	0	main
ole	doc_491521501868_item	3729943	et	0	main
lõpetatud	doc_491521501868_item	3729944	et	0	main
vaid	doc_491521501868_item	3729945	et	0	main
parajasti	doc_491521501868_item	3729946	et	0	main
toimuv	doc_491521501868_item	3729947	et	0	main
käesoleval	doc_491521501868_item	3729948	et	0	main
juhul	doc_491521501868_item	3729949	et	0	main
lõpetatud	doc_491521501868_item	3729950	et	0	main
tegevusele	doc_491521501868_item	3729951	et	0	main
viitab	doc_491521501868_item	3729952	et	0	main
sõna	doc_491521501868_item	3729953	et	0	main
ära	doc_491521501868_item	3729954	et	0	main
siis	doc_491521501868_item	3729955	et	0	main
tahtis	doc_491521501868_item	3729956	et	0	main
ta	doc_491521501868_item	3729957	et	0	main
roti	doc_491521501868_item	3729958	et	0	main
kodustada	doc_491521501868_item	3729959	et	0	main
siis	doc_491521501868_item	3729960	et	0	main
tahtis	doc_491521501868_item	3729961	et	0	main
ta	doc_491521501868_item	3729962	et	0	main
rotti	doc_491521501868_item	3729963	et	0	main
kodustada	doc_491521501868_item	3729964	et	0	main
tegevus	doc_491521501868_item	3729965	et	0	main
ei	doc_491521501868_item	3729966	et	0	main
ole	doc_491521501868_item	3729967	et	0	main
lõpetatud	doc_491521501868_item	3729968	et	0	main
tema	doc_491521501868_item	3729969	et	0	main
vaid	doc_491521501868_item	3729970	et	0	main
tahtis	doc_491521501868_item	3729971	et	0	main
kodustada	doc_491521501868_item	3729972	et	0	main
järelikult	doc_491521501868_item	3729973	et	0	main
oleks	doc_491521501868_item	3729974	et	0	main
parem	doc_491521501868_item	3729975	et	0	main
tarvitada	doc_491521501868_item	3729976	et	0	main
osasihitist	doc_491521501868_item	3729977	et	0	main
osast	doc_491521501868_item	3729978	et	0	main
4	doc_491521501868_item	3729979	et	0	main
kohakäänete	doc_491521501868_item	3729980	et	0	main
vead	doc_491521501868_item	3729981	et	0	main
kohakäänded	doc_491521501868_item	3729982	et	0	main
on	doc_491521501868_item	3729983	et	0	main
käänded	doc_491521501868_item	3729984	et	0	main
mis	doc_491521501868_item	3729985	et	0	main
on	doc_491521501868_item	3729986	et	0	main
kujunenud	doc_491521501868_item	3729987	et	0	main
kohasuhteid	doc_491521501868_item	3729988	et	0	main
märkivate	doc_491521501868_item	3729989	et	0	main
tunnuste	doc_491521501868_item	3729990	et	0	main
alusel	doc_491521501868_item	3729991	et	0	main
eesti	doc_491521501868_item	3729992	et	0	main
keeles	doc_491521501868_item	3729993	et	0	main
on	doc_491521501868_item	3729994	et	0	main
kaks	doc_491521501868_item	3729995	et	0	main
kohakäänete	doc_491521501868_item	3729996	et	0	main
sarja	doc_491521501868_item	3729997	et	0	main
sisekohakäänded	doc_491521501868_item	3729998	et	0	main
väljendavad	doc_491521501868_item	3729999	et	0	main
kinnise	doc_491521501868_item	3730000	et	0	main
ruumiga	doc_491521501868_item	3730001	et	0	main
seotud	doc_491521501868_item	3730002	et	0	main
kohasuhteid	doc_491521501868_item	3730003	et	0	main
väliskohakäänded	doc_491521501868_item	3730004	et	0	main
väljendavad	doc_491521501868_item	3730005	et	0	main
avatud	doc_491521501868_item	3730006	et	0	main
pinnaga	doc_491521501868_item	3730007	et	0	main
seotud	doc_491521501868_item	3730008	et	0	main
kohasuhteid	doc_491521501868_item	3730009	et	0	main
ta	doc_491521501868_item	3730010	et	0	main
jättis	doc_491521501868_item	3730011	et	0	main
roti	doc_491521501868_item	3730012	et	0	main
kodus	doc_491521501868_item	3730013	et	0	main
mõnedel	doc_491521501868_item	3730014	et	0	main
on	doc_491521501868_item	3730015	et	0	main
kodusse	doc_491521501868_item	3730016	et	0	main
ta	doc_491521501868_item	3730017	et	0	main
jättis	doc_491521501868_item	3730018	et	0	main
roti	doc_491521501868_item	3730019	et	0	main
koju	doc_491521501868_item	3730020	et	0	main
lause	doc_491521501868_item	3730021	et	0	main
on	doc_491521501868_item	3730022	et	0	main
otseselt	doc_491521501868_item	3730023	et	0	main
tõlgitud	doc_491521501868_item	3730024	et	0	main
vene	doc_491521501868_item	3730025	et	0	main
keelest	doc_491521501868_item	3730026	et	0	main
eesti	doc_491521501868_item	3730027	et	0	main
keelde	doc_491521501868_item	3730028	et	0	main
esimene	doc_491521501868_item	3730029	et	0	main
viga	doc_491521501868_item	3730030	et	0	main
tegusõna	doc_491521501868_item	3730031	et	0	main
jätma	doc_491521501868_item	3730032	et	0	main
on	doc_491521501868_item	3730033	et	0	main
rektsioonitegusõna	doc_491521501868_item	3730034	et	0	main
ning	doc_491521501868_item	3730035	et	0	main
nõuab	doc_491521501868_item	3730036	et	0	main
küsimust	doc_491521501868_item	3730037	et	0	main
kuhu	doc_491521501868_item	3730038	et	0	main
teine	doc_491521501868_item	3730039	et	0	main
viga	doc_491521501868_item	3730040	et	0	main
sõna	doc_491521501868_item	3730041	et	0	main
kodusse	doc_491521501868_item	3730042	et	0	main
on	doc_491521501868_item	3730043	et	0	main
grammatiliselt	doc_491521501868_item	3730044	et	0	main
õige	doc_491521501868_item	3730045	et	0	main
laps	doc_491521501868_item	3730046	et	0	main
võtab	doc_491521501868_item	3730047	et	0	main
sõna	doc_491521501868_item	3730048	et	0	main
om	doc_491521501868_item	3730049	et	0	main
k	doc_491521501868_item	3730050	et	0	main
sisseütleva	doc_491521501868_item	3730051	et	0	main
käändelõpp	doc_491521501868_item	3730052	et	0	main
n	doc_491521501868_item	3730053	et	0	main
kodu	doc_491521501868_item	3730054	et	0	main
im	doc_491521501868_item	3730055	et	0	main
kodu	doc_491521501868_item	3730056	et	0	main
sse	doc_491521501868_item	3730057	et	0	main
os	doc_491521501868_item	3730058	et	0	main
kodu	doc_491521501868_item	3730059	et	0	main
kuid	doc_491521501868_item	3730060	et	0	main
päriseestlane	doc_491521501868_item	3730061	et	0	main
nii	doc_491521501868_item	3730062	et	0	main
kunagi	doc_491521501868_item	3730063	et	0	main
ei	doc_491521501868_item	3730064	et	0	main
ütle	doc_491521501868_item	3730065	et	0	main
ning	doc_491521501868_item	3730066	et	0	main
kasutaks	doc_491521501868_item	3730067	et	0	main
lühikest	doc_491521501868_item	3730068	et	0	main
sisseütl	doc_491521501868_item	3730069	et	0	main
vormi	doc_491521501868_item	3730070	et	0	main
nt	doc_491521501868_item	3730071	et	0	main
koju	doc_491521501868_item	3730072	et	0	main
jõkke	doc_491521501868_item	3730073	et	0	main
majja	doc_491521501868_item	3730074	et	0	main
jne	doc_491521501868_item	3730075	et	0	main
see	doc_491521501868_item	3730076	et	0	main
piisab	doc_491521501868_item	3730077	et	0	main
temale	doc_491521501868_item	3730078	et	0	main
ainult	doc_491521501868_item	3730079	et	0	main
lõunasöögiks	doc_491521501868_item	3730080	et	0	main
sellest	doc_491521501868_item	3730081	et	0	main
piisab	doc_491521501868_item	3730082	et	0	main
jällegi	doc_491521501868_item	3730083	et	0	main
tegemist	doc_491521501868_item	3730084	et	0	main
verbiga	doc_491521501868_item	3730085	et	0	main
mis	doc_491521501868_item	3730086	et	0	main
nõuab	doc_491521501868_item	3730087	et	0	main
enda	doc_491521501868_item	3730088	et	0	main
järgi	doc_491521501868_item	3730089	et	0	main
seestütleva	doc_491521501868_item	3730090	et	0	main
käände	doc_491521501868_item	3730091	et	0	main
lõppu	doc_491521501868_item	3730092	et	0	main
antud	doc_491521501868_item	3730093	et	0	main
juhul	doc_491521501868_item	3730094	et	0	main
millest	doc_491521501868_item	3730095	et	0	main
midagi	doc_491521501868_item	3730096	et	0	main
tulebsaab	doc_491521501868_item	3730097	et	0	main
või	doc_491521501868_item	3730098	et	0	main
jätkub	doc_491521501868_item	3730099	et	0	main
hakkas	doc_491521501868_item	3730100	et	0	main
kitsetalli	doc_491521501868_item	3730101	et	0	main
skulptuuri	doc_491521501868_item	3730102	et	0	main
tegema	doc_491521501868_item	3730103	et	0	main
hakkas	doc_491521501868_item	3730104	et	0	main
kitsetalli	doc_491521501868_item	3730105	et	0	main
järgi	doc_491521501868_item	3730106	et	0	main
skulptuuri	doc_491521501868_item	3730107	et	0	main
tegema	doc_491521501868_item	3730108	et	0	main
kohe	doc_491521501868_item	3730109	et	0	main
näha	doc_491521501868_item	3730110	et	0	main
venekeelset	doc_491521501868_item	3730111	et	0	main
mõju	doc_491521501868_item	3730112	et	0	main
skulptuuri	doc_491521501868_item	3730113	et	0	main
tegema	doc_491521501868_item	3730114	et	0	main
kellemille	doc_491521501868_item	3730115	et	0	main
järgi	doc_491521501868_item	3730116	et	0	main
5	doc_491521501868_item	3730117	et	0	main
muud	doc_491521501868_item	3730118	et	0	main
käändevead	doc_491521501868_item	3730119	et	0	main
väga	doc_491521501868_item	3730120	et	0	main
raskeks	doc_491521501868_item	3730121	et	0	main
peavad	doc_491521501868_item	3730122	et	0	main
õpilased	doc_491521501868_item	3730123	et	0	main
isegi	doc_491521501868_item	3730124	et	0	main
mitmuse	doc_491521501868_item	3730125	et	0	main
osastava	doc_491521501868_item	3730126	et	0	main
käändelõppu	doc_491521501868_item	3730127	et	0	main
ning	doc_491521501868_item	3730128	et	0	main
mitte	doc_491521501868_item	3730129	et	0	main
asjata	doc_491521501868_item	3730130	et	0	main
just	doc_491521501868_item	3730131	et	0	main
selle	doc_491521501868_item	3730132	et	0	main
käändevormi	doc_491521501868_item	3730133	et	0	main
moodustamisel	doc_491521501868_item	3730134	et	0	main
tekkis	doc_491521501868_item	3730135	et	0	main
neil	doc_491521501868_item	3730136	et	0	main
palju	doc_491521501868_item	3730137	et	0	main
raskusi	doc_491521501868_item	3730138	et	0	main
ta	doc_491521501868_item	3730139	et	0	main
armastas	doc_491521501868_item	3730140	et	0	main
loomad	doc_491521501868_item	3730141	et	0	main
loomi	doc_491521501868_item	3730142	et	0	main
n	doc_491521501868_item	3730143	et	0	main
loom	doc_491521501868_item	3730144	et	0	main
iii	doc_491521501868_item	3730145	et	0	main
v	doc_491521501868_item	3730146	et	0	main
om	doc_491521501868_item	3730147	et	0	main
looma	doc_491521501868_item	3730148	et	0	main
ii	doc_491521501868_item	3730149	et	0	main
v	doc_491521501868_item	3730150	et	0	main
os	doc_491521501868_item	3730151	et	0	main
looma	doc_491521501868_item	3730152	et	0	main
iii	doc_491521501868_item	3730153	et	0	main
v	doc_491521501868_item	3730154	et	0	main
mitmuse	doc_491521501868_item	3730155	et	0	main
osastavas	doc_491521501868_item	3730156	et	0	main
a	doc_491521501868_item	3730157	et	0	main
muutub	doc_491521501868_item	3730158	et	0	main
i-ks	doc_491521501868_item	3730159	et	0	main
kui	doc_491521501868_item	3730160	et	0	main
esimeses	doc_491521501868_item	3730161	et	0	main
silbis	doc_491521501868_item	3730162	et	0	main
on	doc_491521501868_item	3730163	et	0	main
eks	doc_491521501868_item	3730164	et	0	main
ämm	doc_491521501868_item	3730165	et	0	main
kodus	doc_491521501868_item	3730166	et	0	main
söö	doc_491521501868_item	3730167	et	0	main
sütt	doc_491521501868_item	3730168	et	0	main
ta	doc_491521501868_item	3730169	et	0	main
töötas	doc_491521501868_item	3730170	et	0	main
kunstnikuks	doc_491521501868_item	3730171	et	0	main
ta	doc_491521501868_item	3730172	et	0	main
töötas	doc_491521501868_item	3730173	et	0	main
kunstnikuna	doc_491521501868_item	3730174	et	0	main
reeglina	doc_491521501868_item	3730175	et	0	main
väljendatakse	doc_491521501868_item	3730176	et	0	main
saava	doc_491521501868_item	3730177	et	0	main
kn	doc_491521501868_item	3730178	et	0	main
abil	doc_491521501868_item	3730179	et	0	main
seisundit	doc_491521501868_item	3730180	et	0	main
millesse	doc_491521501868_item	3730181	et	0	main
siirdutakse	doc_491521501868_item	3730182	et	0	main
sellepärast	doc_491521501868_item	3730183	et	0	main
peab	doc_491521501868_item	3730184	et	0	main
kasutama	doc_491521501868_item	3730185	et	0	main
oleva	doc_491521501868_item	3730186	et	0	main
käändelõppu	doc_491521501868_item	3730187	et	0	main
mis	doc_491521501868_item	3730188	et	0	main
väljendaks	doc_491521501868_item	3730189	et	0	main
objekti	doc_491521501868_item	3730190	et	0	main
olekutseisundit	doc_491521501868_item	3730191	et	0	main
minevikus	doc_491521501868_item	3730192	et	0	main
ja	doc_491521501868_item	3730193	et	0	main
olevikus	doc_491521501868_item	3730194	et	0	main
tunnen	doc_491521501868_item	3730195	et	0	main
et	doc_491521501868_item	3730196	et	0	main
oleksin	doc_491521501868_item	3730197	et	0	main
oma	doc_491521501868_item	3730198	et	0	main
kohal	doc_491521501868_item	3730199	et	0	main
oleksin	doc_491521501868_item	3730200	et	0	main
omal	doc_491521501868_item	3730201	et	0	main
kohal	doc_491521501868_item	3730202	et	0	main
omadussõna	doc_491521501868_item	3730203	et	0	main
ja	doc_491521501868_item	3730204	et	0	main
nimisõna	doc_491521501868_item	3730205	et	0	main
ühilduvad	doc_491521501868_item	3730206	et	0	main
käändes	doc_491521501868_item	3730207	et	0	main
ja	doc_491521501868_item	3730208	et	0	main
arvus	doc_491521501868_item	3730209	et	0	main
va	doc_491521501868_item	3730210	et	0	main
4	doc_491521501868_item	3730211	et	0	main
viimast	doc_491521501868_item	3730212	et	0	main
käänet	doc_491521501868_item	3730213	et	0	main
rajav	doc_491521501868_item	3730214	et	0	main
oma	doc_491521501868_item	3730215	et	0	main
kohani	doc_491521501868_item	3730216	et	0	main
olev	doc_491521501868_item	3730217	et	0	main
oma	doc_491521501868_item	3730218	et	0	main
kohana	doc_491521501868_item	3730219	et	0	main
ilmaütlev	doc_491521501868_item	3730220	et	0	main
oma	doc_491521501868_item	3730221	et	0	main
kohata	doc_491521501868_item	3730222	et	0	main
kaasaütlev	doc_491521501868_item	3730223	et	0	main
oma	doc_491521501868_item	3730224	et	0	main
kohag	doc_491521501868_item	3730225	et	0	main
mul	doc_491521501868_item	3730226	et	0	main
ei	doc_491521501868_item	3730227	et	0	main
ole	doc_491521501868_item	3730228	et	0	main
autojuhilube	doc_491521501868_item	3730229	et	0	main
grammatilisilt	doc_491521501868_item	3730230	et	0	main
on	doc_491521501868_item	3730231	et	0	main
kõik	doc_491521501868_item	3730232	et	0	main
õige	doc_491521501868_item	3730233	et	0	main
kuid	doc_491521501868_item	3730234	et	0	main
kohe	doc_491521501868_item	3730235	et	0	main
tekkib	doc_491521501868_item	3730236	et	0	main
küsimus	doc_491521501868_item	3730237	et	0	main
mitu	doc_491521501868_item	3730238	et	0	main
sul	doc_491521501868_item	3730239	et	0	main
neid	doc_491521501868_item	3730240	et	0	main
on	doc_491521501868_item	3730241	et	0	main
jalle	doc_491521501868_item	3730242	et	0	main
tegemist	doc_491521501868_item	3730243	et	0	main
venekeelse	doc_491521501868_item	3730244	et	0	main
mõjuga	doc_491521501868_item	3730245	et	0	main
mitmuses	doc_491521501868_item	3730246	et	0	main
eesti	doc_491521501868_item	3730247	et	0	main
keeles	doc_491521501868_item	3730248	et	0	main
on	doc_491521501868_item	3730249	et	0	main
see	doc_491521501868_item	3730250	et	0	main
aga	doc_491521501868_item	3730251	et	0	main
ainsuses	doc_491521501868_item	3730252	et	0	main
juhiluba	doc_491521501868_item	3730253	et	0	main
järelikult	doc_491521501868_item	3730254	et	0	main
mul	doc_491521501868_item	3730255	et	0	main
ei	doc_491521501868_item	3730256	et	0	main
ole	doc_491521501868_item	3730257	et	0	main
juhiluba	doc_491521501868_item	3730258	et	0	main
esimene	doc_491521501868_item	3730259	et	0	main
olümpiamäng	doc_491521501868_item	3730260	et	0	main
toimus	doc_491521501868_item	3730261	et	0	main
esimesed	doc_491521501868_item	3730262	et	0	main
olümpiamängud	doc_491521501868_item	3730263	et	0	main
toimusid	doc_491521501868_item	3730264	et	0	main
ei	doc_491521501868_item	3730265	et	0	main
ole	doc_491521501868_item	3730266	et	0	main
arusaadav	doc_491521501868_item	3730267	et	0	main
miks	doc_491521501868_item	3730268	et	0	main
laps	doc_491521501868_item	3730269	et	0	main
otsustas	doc_491521501868_item	3730270	et	0	main
kirjutada	doc_491521501868_item	3730271	et	0	main
ainsuses	doc_491521501868_item	3730272	et	0	main
vene	doc_491521501868_item	3730273	et	0	main
keeles	doc_491521501868_item	3730274	et	0	main
on	doc_491521501868_item	3730275	et	0	main
see	doc_491521501868_item	3730276	et	0	main
ka	doc_491521501868_item	3730277	et	0	main
mitmuses	doc_491521501868_item	3730278	et	0	main
võiks	doc_491521501868_item	3730279	et	0	main
oletada	doc_491521501868_item	3730280	et	0	main
et	doc_491521501868_item	3730281	et	0	main
tegemist	doc_491521501868_item	3730282	et	0	main
on	doc_491521501868_item	3730283	et	0	main
tähelepanematuse	doc_491521501868_item	3730284	et	0	main
või	doc_491521501868_item	3730285	et	0	main
isegi	doc_491521501868_item	3730286	et	0	main
lohakusega	doc_491521501868_item	3730287	et	0	main
6	doc_491521501868_item	3730288	et	0	main
arvsõna	doc_491521501868_item	3730289	et	0	main
käänamine	doc_491521501868_item	3730290	et	0	main
ja	doc_491521501868_item	3730291	et	0	main
kasutamine	doc_491521501868_item	3730292	et	0	main
koort	doc_491521501868_item	3730293	et	0	main
tõi	doc_491521501868_item	3730294	et	0	main
talle	doc_491521501868_item	3730295	et	0	main
kolm	doc_491521501868_item	3730296	et	0	main
varest	doc_491521501868_item	3730297	et	0	main
koort	doc_491521501868_item	3730298	et	0	main
tõi	doc_491521501868_item	3730299	et	0	main
talle	doc_491521501868_item	3730300	et	0	main
kolme	doc_491521501868_item	3730301	et	0	main
varest	doc_491521501868_item	3730302	et	0	main
arvsõnad	doc_491521501868_item	3730303	et	0	main
väljendavad	doc_491521501868_item	3730304	et	0	main
asjade	doc_491521501868_item	3730305	et	0	main
hulka	doc_491521501868_item	3730306	et	0	main
ning	doc_491521501868_item	3730307	et	0	main
muutuvad	doc_491521501868_item	3730308	et	0	main
koos	doc_491521501868_item	3730309	et	0	main
nimisõnadega	doc_491521501868_item	3730310	et	0	main
käändes	doc_491521501868_item	3730311	et	0	main
ja	doc_491521501868_item	3730312	et	0	main
arvus	doc_491521501868_item	3730313	et	0	main
7	doc_491521501868_item	3730314	et	0	main
verbivormide	doc_491521501868_item	3730315	et	0	main
valiku	doc_491521501868_item	3730316	et	0	main
vead	doc_491521501868_item	3730317	et	0	main
tuleb	doc_491521501868_item	3730318	et	0	main
märkida	doc_491521501868_item	3730319	et	0	main
et	doc_491521501868_item	3730320	et	0	main
10klassis	doc_491521501868_item	3730321	et	0	main
paljudele	doc_491521501868_item	3730322	et	0	main
õpilastele	doc_491521501868_item	3730323	et	0	main
pakkus	doc_491521501868_item	3730324	et	0	main
raskust	doc_491521501868_item	3730325	et	0	main
ma-	doc_491521501868_item	3730326	et	0	main
ja	doc_491521501868_item	3730327	et	0	main
da-inf	doc_491521501868_item	3730328	et	0	main
kasutamine	doc_491521501868_item	3730329	et	0	main
kuid	doc_491521501868_item	3730330	et	0	main
hiljem	doc_491521501868_item	3730331	et	0	main
vigade	doc_491521501868_item	3730332	et	0	main
parandust	doc_491521501868_item	3730333	et	0	main
tehes	doc_491521501868_item	3730334	et	0	main
selgus	doc_491521501868_item	3730335	et	0	main
et	doc_491521501868_item	3730336	et	0	main
reegleid	doc_491521501868_item	3730337	et	0	main
tunnevad	doc_491521501868_item	3730338	et	0	main
õpilased	doc_491521501868_item	3730339	et	0	main
hästi	doc_491521501868_item	3730340	et	0	main
aga	doc_491521501868_item	3730341	et	0	main
praktikal	doc_491521501868_item	3730342	et	0	main
ei	doc_491521501868_item	3730343	et	0	main
rakenda	doc_491521501868_item	3730344	et	0	main
võiks	doc_491521501868_item	3730345	et	0	main
jällegi	doc_491521501868_item	3730346	et	0	main
teha	doc_491521501868_item	3730347	et	0	main
järelduse	doc_491521501868_item	3730348	et	0	main
et	doc_491521501868_item	3730349	et	0	main
tegemist	doc_491521501868_item	3730350	et	0	main
on	doc_491521501868_item	3730351	et	0	main
lohakusega	doc_491521501868_item	3730352	et	0	main
tahtis	doc_491521501868_item	3730353	et	0	main
varastama	doc_491521501868_item	3730354	et	0	main
tahtis	doc_491521501868_item	3730355	et	0	main
varastada	doc_491521501868_item	3730356	et	0	main
hakkas	doc_491521501868_item	3730357	et	0	main
teha	doc_491521501868_item	3730358	et	0	main
skulptuuri	doc_491521501868_item	3730359	et	0	main
hakkas	doc_491521501868_item	3730360	et	0	main
skulptuuri	doc_491521501868_item	3730361	et	0	main
tegema	doc_491521501868_item	3730362	et	0	main
läks	doc_491521501868_item	3730363	et	0	main
magada	doc_491521501868_item	3730364	et	0	main
läks	doc_491521501868_item	3730365	et	0	main
magama	doc_491521501868_item	3730366	et	0	main
8	doc_491521501868_item	3730367	et	0	main
sõnatasandivead	doc_491521501868_item	3730368	et	0	main
paronüümid	doc_491521501868_item	3730369	et	0	main
e	doc_491521501868_item	3730370	et	0	main
sarnassõnad	doc_491521501868_item	3730371	et	0	main
kõlalt	doc_491521501868_item	3730372	et	0	main
sarnased	doc_491521501868_item	3730373	et	0	main
tema	doc_491521501868_item	3730374	et	0	main
juures	doc_491521501868_item	3730375	et	0	main
elas	doc_491521501868_item	3730376	et	0	main
veel	doc_491521501868_item	3730377	et	0	main
öökull	doc_491521501868_item	3730378	et	0	main
suur	doc_491521501868_item	3730379	et	0	main
ja	doc_491521501868_item	3730380	et	0	main
näljane	doc_491521501868_item	3730381	et	0	main
naljakas	doc_491521501868_item	3730382	et	0	main
naeruväärne	doc_491521501868_item	3730383	et	0	main
näljane	doc_491521501868_item	3730384	et	0	main
tahab	doc_491521501868_item	3730385	et	0	main
süüa	doc_491521501868_item	3730386	et	0	main
tal	doc_491521501868_item	3730387	et	0	main
elas	doc_491521501868_item	3730388	et	0	main
veel	doc_491521501868_item	3730389	et	0	main
varas	doc_491521501868_item	3730390	et	0	main
krooku	doc_491521501868_item	3730391	et	0	main
vares	doc_491521501868_item	3730392	et	0	main
varas	doc_491521501868_item	3730393	et	0	main
see	doc_491521501868_item	3730394	et	0	main
kes	doc_491521501868_item	3730395	et	0	main
varastab	doc_491521501868_item	3730396	et	0	main
vares	doc_491521501868_item	3730397	et	0	main
lind	doc_491521501868_item	3730398	et	0	main
ta	doc_491521501868_item	3730399	et	0	main
kasutas	doc_491521501868_item	3730400	et	0	main
iga	doc_491521501868_item	3730401	et	0	main
juhti	doc_491521501868_item	3730402	et	0	main
juhust	doc_491521501868_item	3730403	et	0	main
juht	doc_491521501868_item	3730404	et	0	main
üksiksunrmus	doc_491521501868_item	3730405	et	0	main
juhus	doc_491521501868_item	3730406	et	0	main
võimalus	doc_491521501868_item	3730407	et	0	main
alati	doc_491521501868_item	3730408	et	0	main
näljane	doc_491521501868_item	3730409	et	0	main
lind	doc_491521501868_item	3730410	et	0	main
stiilivead	doc_491521501868_item	3730411	et	0	main
11	doc_491521501868_item	3730412	et	0	main
klass	doc_491521501868_item	3730413	et	0	main
kirjutas	doc_491521501868_item	3730414	et	0	main
taotluse	doc_491521501868_item	3730415	et	0	main
otsiti	doc_491521501868_item	3730416	et	0	main
tööd	doc_491521501868_item	3730417	et	0	main
ajalehe	doc_491521501868_item	3730418	et	0	main
kuulutuse	doc_491521501868_item	3730419	et	0	main
järgi	doc_491521501868_item	3730420	et	0	main
mul	doc_491521501868_item	3730421	et	0	main
on	doc_491521501868_item	3730422	et	0	main
keskharidus	doc_491521501868_item	3730423	et	0	main
mul	doc_491521501868_item	3730424	et	0	main
ei	doc_491521501868_item	3730425	et	0	main
ole	doc_491521501868_item	3730426	et	0	main
lapsi	doc_491521501868_item	3730427	et	0	main
mina	doc_491521501868_item	3730428	et	0	main
olen	doc_491521501868_item	3730429	et	0	main
kahekümneaastane	doc_491521501868_item	3730430	et	0	main
mina	doc_491521501868_item	3730431	et	0	main
valdan	doc_491521501868_item	3730432	et	0	main
keeli	doc_491521501868_item	3730433	et	0	main
taotlus	doc_491521501868_item	3730434	et	0	main
on	doc_491521501868_item	3730435	et	0	main
üks	doc_491521501868_item	3730436	et	0	main
ametlikest	doc_491521501868_item	3730437	et	0	main
kirjadest	doc_491521501868_item	3730438	et	0	main
ning	doc_491521501868_item	3730439	et	0	main
mina	doc_491521501868_item	3730440	et	0	main
asesõna	doc_491521501868_item	3730441	et	0	main
kasutamine	doc_491521501868_item	3730442	et	0	main
igas	doc_491521501868_item	3730443	et	0	main
lauses	doc_491521501868_item	3730444	et	0	main
ei	doc_491521501868_item	3730445	et	0	main
ole	doc_491521501868_item	3730446	et	0	main
lubatav	doc_491521501868_item	3730447	et	0	main
oleks	doc_491521501868_item	3730448	et	0	main
parem	doc_491521501868_item	3730449	et	0	main
olen	doc_491521501868_item	3730450	et	0	main
20-aastane	doc_491521501868_item	3730451	et	0	main
keskharidusega	doc_491521501868_item	3730452	et	0	main
neiu	doc_491521501868_item	3730453	et	0	main
valdan	doc_491521501868_item	3730454	et	0	main
keeli	doc_491521501868_item	3730455	et	0	main
olen	doc_491521501868_item	3730456	et	0	main
abielus	doc_491521501868_item	3730457	et	0	main
liitsõnad	doc_491521501868_item	3730458	et	0	main
loomadesõber	doc_491521501868_item	3730459	et	0	main
loomad	doc_491521501868_item	3730460	et	0	main
sõber	doc_491521501868_item	3730461	et	0	main
mitmuse	doc_491521501868_item	3730462	et	0	main
omastavas	doc_491521501868_item	3730463	et	0	main
olev	doc_491521501868_item	3730464	et	0	main
nimisõna	doc_491521501868_item	3730465	et	0	main
kirjutatakse	doc_491521501868_item	3730466	et	0	main
järgnevast	doc_491521501868_item	3730467	et	0	main
nimisõnast	doc_491521501868_item	3730468	et	0	main
harilikult	doc_491521501868_item	3730469	et	0	main
lahku	doc_491521501868_item	3730470	et	0	main
nt	doc_491521501868_item	3730471	et	0	main
vigade	doc_491521501868_item	3730472	et	0	main
parandus	doc_491521501868_item	3730473	et	0	main
järgneva	doc_491521501868_item	3730474	et	0	main
nimisõnaga	doc_491521501868_item	3730475	et	0	main
kokku	doc_491521501868_item	3730476	et	0	main
kirjutatakse	doc_491521501868_item	3730477	et	0	main
kahesilbiline	doc_491521501868_item	3730478	et	0	main
mitmuse	doc_491521501868_item	3730479	et	0	main
omastavas	doc_491521501868_item	3730480	et	0	main
olev	doc_491521501868_item	3730481	et	0	main
nimisõna	doc_491521501868_item	3730482	et	0	main
omaette	doc_491521501868_item	3730483	et	0	main
tähendusega	doc_491521501868_item	3730484	et	0	main
ühendeis	doc_491521501868_item	3730485	et	0	main
nagu	doc_491521501868_item	3730486	et	0	main
nt	doc_491521501868_item	3730487	et	0	main
lasteaed	doc_491521501868_item	3730488	et	0	main
keeltekool	doc_491521501868_item	3730489	et	0	main
t	doc_491521501868_item	3730490	et	0	main
erelt	doc_491521501868_item	3730491	et	0	main
eesti	doc_491521501868_item	3730492	et	0	main
ortograafia	doc_491521501868_item	3730493	et	0	main
1995	doc_491521501868_item	3730494	et	0	main
lk42	doc_491521501868_item	3730495	et	0	main
kadrioorus	doc_491521501868_item	3730496	et	0	main
kadri	doc_491521501868_item	3730497	et	0	main
org	doc_491521501868_item	3730498	et	0	main
kadriorus	doc_491521501868_item	3730499	et	0	main
oma	doc_491521501868_item	3730500	et	0	main
vigade	doc_491521501868_item	3730501	et	0	main
analüüs	doc_491521501868_item	3730502	et	0	main
1	doc_491521501868_item	3730503	et	0	main
9	doc_491521501868_item	3730504	et	0	main
klassis	doc_491521501868_item	3730505	et	0	main
järgarvud	doc_491521501868_item	3730506	et	0	main
kirjutatakse	doc_491521501868_item	3730507	et	0	main
araabia	doc_491521501868_item	3730508	et	0	main
numbritega	doc_491521501868_item	3730509	et	0	main
mille	doc_491521501868_item	3730510	et	0	main
järel	doc_491521501868_item	3730511	et	0	main
on	doc_491521501868_item	3730512	et	0	main
punkt	doc_491521501868_item	3730513	et	0	main
t	doc_491521501868_item	3730514	et	0	main
erelt	doc_491521501868_item	3730515	et	0	main
eesti	doc_491521501868_item	3730516	et	0	main
ortograafia	doc_491521501868_item	3730517	et	0	main
1995	doc_491521501868_item	3730518	et	0	main
lk	doc_491521501868_item	3730519	et	0	main
68	doc_491521501868_item	3730520	et	0	main
2	doc_491521501868_item	3730521	et	0	main
ümberjustuse	doc_491521501868_item	3730522	et	0	main
trükiviga	doc_491521501868_item	3730523	et	0	main
õige	doc_491521501868_item	3730524	et	0	main
oleks	doc_491521501868_item	3730525	et	0	main
ümberjutustuse	doc_491521501868_item	3730526	et	0	main
3	doc_491521501868_item	3730527	et	0	main
viga	doc_491521501868_item	3730528	et	0	main
on	doc_491521501868_item	3730529	et	0	main
laienenud	doc_491521501868_item	3730530	et	0	main
sõna	doc_491521501868_item	3730531	et	0	main
laienenud	doc_491521501868_item	3730532	et	0	main
tähendab	doc_491521501868_item	3730533	et	0	main
vene	doc_491521501868_item	3730534	et	0	main
keeles	doc_491521501868_item	3730535	et	0	main
käesoleval	doc_491521501868_item	3730536	et	0	main
juhul	doc_491521501868_item	3730537	et	0	main
oli	doc_491521501868_item	3730538	et	0	main
mõeldud	doc_491521501868_item	3730539	et	0	main
levinud	doc_491521501868_item	3730540	et	0	main
4	doc_491521501868_item	3730541	et	0	main
see	doc_491521501868_item	3730542	et	0	main
viga	doc_491521501868_item	3730543	et	0	main
oli	doc_491521501868_item	3730544	et	0	main
parandatud	doc_491521501868_item	3730545	et	0	main
6	doc_491521501868_item	3730546	et	0	main
korda	doc_491521501868_item	3730547	et	0	main
lõpetatud	doc_491521501868_item	3730548	et	0	main
tegevus	doc_491521501868_item	3730549	et	0	main
seda	doc_491521501868_item	3730550	et	0	main
viga	doc_491521501868_item	3730551	et	0	main
on	doc_491521501868_item	3730552	et	0	main
parandatud	doc_491521501868_item	3730553	et	0	main
6	doc_491521501868_item	3730554	et	0	main
korda	doc_491521501868_item	3730555	et	0	main
lõpetamata	doc_491521501868_item	3730556	et	0	main
tegevus	doc_491521501868_item	3730557	et	0	main
5	doc_491521501868_item	3730558	et	0	main
sõna	doc_491521501868_item	3730559	et	0	main
kirjutavat	doc_491521501868_item	3730560	et	0	main
jäi	doc_491521501868_item	3730561	et	0	main
vahele	doc_491521501868_item	3730562	et	0	main
umbisikulise	doc_491521501868_item	3730563	et	0	main
tegumoe	doc_491521501868_item	3730564	et	0	main
tunnus	doc_491521501868_item	3730565	et	0	main
ta-	doc_491521501868_item	3730566	et	0	main
sõna	doc_491521501868_item	3730567	et	0	main
kirjutatavat	doc_491521501868_item	3730568	et	0	main
umbisikuline	doc_491521501868_item	3730569	et	0	main
tegumood	doc_491521501868_item	3730570	et	0	main
kaudne	doc_491521501868_item	3730571	et	0	main
kõneviis	doc_491521501868_item	3730572	et	0	main
6	doc_491521501868_item	3730573	et	0	main
esimine	doc_491521501868_item	3730574	et	0	main
trükiviga	doc_491521501868_item	3730575	et	0	main
lohakuse	doc_491521501868_item	3730576	et	0	main
pärast	doc_491521501868_item	3730577	et	0	main
esimene	doc_491521501868_item	3730578	et	0	main
7	doc_491521501868_item	3730579	et	0	main
jälegi	doc_491521501868_item	3730580	et	0	main
trükiviga	doc_491521501868_item	3730581	et	0	main
jällegi	doc_491521501868_item	3730582	et	0	main
8	doc_491521501868_item	3730583	et	0	main
lomi	doc_491521501868_item	3730584	et	0	main
trükiviga	doc_491521501868_item	3730585	et	0	main
loomi	doc_491521501868_item	3730586	et	0	main
9	doc_491521501868_item	3730587	et	0	main
omastav	doc_491521501868_item	3730588	et	0	main
osastav	doc_491521501868_item	3730589	et	0	main
nimetav	doc_491521501868_item	3730590	et	0	main
käänete	doc_491521501868_item	3730591	et	0	main
nimed	doc_491521501868_item	3730592	et	0	main
kirjutatakse	doc_491521501868_item	3730593	et	0	main
väikese	doc_491521501868_item	3730594	et	0	main
tähega	doc_491521501868_item	3730595	et	0	main
omastav	doc_491521501868_item	3730596	et	0	main
osastav	doc_491521501868_item	3730597	et	0	main
nimetav	doc_491521501868_item	3730598	et	0	main
10	doc_491521501868_item	3730599	et	0	main
ei	doc_491521501868_item	3730600	et	0	main
aktsepteeri	doc_491521501868_item	3730601	et	0	main
vale	doc_491521501868_item	3730602	et	0	main
sõna	doc_491521501868_item	3730603	et	0	main
kasutus	doc_491521501868_item	3730604	et	0	main
ei	doc_491521501868_item	3730605	et	0	main
mõista	doc_491521501868_item	3730606	et	0	main
11	doc_491521501868_item	3730607	et	0	main
antut	doc_491521501868_item	3730608	et	0	main
d	doc_491521501868_item	3730609	et	0	main
juhul	doc_491521501868_item	3730610	et	0	main
sellele	doc_491521501868_item	3730611	et	0	main
ühes	doc_491521501868_item	3730612	et	0	main
lauses	doc_491521501868_item	3730613	et	0	main
oli	doc_491521501868_item	3730614	et	0	main
2	doc_491521501868_item	3730615	et	0	main
viga	doc_491521501868_item	3730616	et	0	main
üks	doc_491521501868_item	3730617	et	0	main
neist	doc_491521501868_item	3730618	et	0	main
oli	doc_491521501868_item	3730619	et	0	main
trükiviga	doc_491521501868_item	3730620	et	0	main
antud	doc_491521501868_item	3730621	et	0	main
teine	doc_491521501868_item	3730622	et	0	main
aga	doc_491521501868_item	3730623	et	0	main
vale	doc_491521501868_item	3730624	et	0	main
sõna	doc_491521501868_item	3730625	et	0	main
kasutus	doc_491521501868_item	3730626	et	0	main
õige	doc_491521501868_item	3730627	et	0	main
oleks	doc_491521501868_item	3730628	et	0	main
ütelda	doc_491521501868_item	3730629	et	0	main
käesoleval	doc_491521501868_item	3730630	et	0	main
juhul	doc_491521501868_item	3730631	et	0	main
lõpetatud	doc_491521501868_item	3730632	et	0	main
tegevusele	doc_491521501868_item	3730633	et	0	main
viitab	doc_491521501868_item	3730634	et	0	main
sõna	doc_491521501868_item	3730635	et	0	main
ära	doc_491521501868_item	3730636	et	0	main
12	doc_491521501868_item	3730637	et	0	main
kodust	doc_491521501868_item	3730638	et	0	main
da	doc_491521501868_item	3730639	et	0	main
trükiviga	doc_491521501868_item	3730640	et	0	main
kodustada	doc_491521501868_item	3730641	et	0	main
13	doc_491521501868_item	3730642	et	0	main
kanded	doc_491521501868_item	3730643	et	0	main
trükiviga	doc_491521501868_item	3730644	et	0	main
käänded	doc_491521501868_item	3730645	et	0	main
14	doc_491521501868_item	3730646	et	0	main
täitsa	doc_491521501868_item	3730647	et	0	main
õige	doc_491521501868_item	3730648	et	0	main
on	doc_491521501868_item	3730649	et	0	main
olemas	doc_491521501868_item	3730650	et	0	main
2	doc_491521501868_item	3730651	et	0	main
varianti	doc_491521501868_item	3730652	et	0	main
kas	doc_491521501868_item	3730653	et	0	main
õige	doc_491521501868_item	3730654	et	0	main
või	doc_491521501868_item	3730655	et	0	main
vale	doc_491521501868_item	3730656	et	0	main
sõna	doc_491521501868_item	3730657	et	0	main
täitsa	doc_491521501868_item	3730658	et	0	main
kasutamine	doc_491521501868_item	3730659	et	0	main
kirjakeeles	doc_491521501868_item	3730660	et	0	main
on	doc_491521501868_item	3730661	et	0	main
argikeele	doc_491521501868_item	3730662	et	0	main
mõju	doc_491521501868_item	3730663	et	0	main
15	doc_491521501868_item	3730664	et	0	main
niimodi	doc_491521501868_item	3730665	et	0	main
õige	doc_491521501868_item	3730666	et	0	main
on	doc_491521501868_item	3730667	et	0	main
nii	doc_491521501868_item	3730668	et	0	main
16	doc_491521501868_item	3730669	et	0	main
kokke	doc_491521501868_item	3730670	et	0	main
trükiviga	doc_491521501868_item	3730671	et	0	main
jõkke	doc_491521501868_item	3730672	et	0	main
17	doc_491521501868_item	3730673	et	0	main
hakkas	doc_491521501868_item	3730674	et	0	main
kitsetallist	doc_491521501868_item	3730675	et	0	main
skulptuuri	doc_491521501868_item	3730676	et	0	main
tegema	doc_491521501868_item	3730677	et	0	main
skulptuuri	doc_491521501868_item	3730678	et	0	main
tegema	doc_491521501868_item	3730679	et	0	main
kellemille	doc_491521501868_item	3730680	et	0	main
järgi	doc_491521501868_item	3730681	et	0	main
hakkas	doc_491521501868_item	3730682	et	0	main
kitsetalli	doc_491521501868_item	3730683	et	0	main
järgi	doc_491521501868_item	3730684	et	0	main
skulptuuri	doc_491521501868_item	3730685	et	0	main
tegema	doc_491521501868_item	3730686	et	0	main
18	doc_491521501868_item	3730687	et	0	main
to	doc_491521501868_item	3730688	et	0	main
musid	doc_491521501868_item	3730689	et	0	main
trükiviga	doc_491521501868_item	3730690	et	0	main
toimusid	doc_491521501868_item	3730691	et	0	main
19	doc_491521501868_item	3730692	et	0	main
praktikal	doc_491521501868_item	3730693	et	0	main
ei	doc_491521501868_item	3730694	et	0	main
kasuta	doc_491521501868_item	3730695	et	0	main
on	doc_491521501868_item	3730696	et	0	main
kaks	doc_491521501868_item	3730697	et	0	main
varianti	doc_491521501868_item	3730698	et	0	main
1	doc_491521501868_item	3730699	et	0	main
praktikas	doc_491521501868_item	3730700	et	0	main
ei	doc_491521501868_item	3730701	et	0	main
kasuta	doc_491521501868_item	3730702	et	0	main
2	doc_491521501868_item	3730703	et	0	main
praktika	doc_491521501868_item	3730704	et	0	main
ajal	doc_491521501868_item	3730705	et	0	main
ei	doc_491521501868_item	3730706	et	0	main
kasuta	doc_491521501868_item	3730707	et	0	main
20	doc_491521501868_item	3730708	et	0	main
ei	doc_491521501868_item	3730709	et	0	main
olee	doc_491521501868_item	3730710	et	0	main
trükiviga	doc_491521501868_item	3730711	et	0	main
ei	doc_491521501868_item	3730712	et	0	main
ole	doc_491521501868_item	3730713	et	0	main
analüüs	doc_491521501863_item	3730714	et	0	main
tallinna	doc_491521501863_item	3730715	et	0	main
pedagoogikaulikool	doc_491521501863_item	3730716	et	0	main
eesti	doc_491521501863_item	3730717	et	0	main
keele	doc_491521501863_item	3730718	et	0	main
kui	doc_491521501863_item	3730719	et	0	main
võõrkeele	doc_491521501863_item	3730720	et	0	main
õppetool	doc_491521501863_item	3730721	et	0	main
vead	doc_491521501863_item	3730722	et	0	main
mordvalaste	doc_491521501863_item	3730723	et	0	main
keelekasutuses	doc_491521501863_item	3730724	et	0	main
kontrastiivlingvistika	doc_491521501863_item	3730725	et	0	main
kodutöö	doc_491521501863_item	3730726	et	0	main
eesnimi	doc_491521501863_item	3730727	et	0	main
perekonnanimi	doc_491521501863_item	3730728	et	0	main
tallinn	doc_491521501863_item	3730729	et	0	main
2001	doc_491521501863_item	3730730	et	0	main
sissejuhatus	doc_491521501863_item	3730731	et	0	main
käesoleva	doc_491521501863_item	3730732	et	0	main
veaanalüüsi	doc_491521501863_item	3730733	et	0	main
aluseks	doc_491521501863_item	3730734	et	0	main
on	doc_491521501863_item	3730735	et	0	main
kirjalikest	doc_491521501863_item	3730736	et	0	main
töödest	doc_491521501863_item	3730737	et	0	main
kogutud	doc_491521501863_item	3730738	et	0	main
vead	doc_491521501863_item	3730739	et	0	main
mida	doc_491521501863_item	3730740	et	0	main
on	doc_491521501863_item	3730741	et	0	main
teinud	doc_491521501863_item	3730742	et	0	main
pedagoogikaülikoolis	doc_491521501863_item	3730743	et	0	main
õppivad	doc_491521501863_item	3730744	et	0	main
mordvalased	doc_491521501863_item	3730745	et	0	main
ersad	doc_491521501863_item	3730746	et	0	main
ja	doc_491521501863_item	3730747	et	0	main
moksad	doc_491521501863_item	3730748	et	0	main
kelle	doc_491521501863_item	3730749	et	0	main
emakeel	doc_491521501863_item	3730750	et	0	main
on	doc_491521501863_item	3730751	et	0	main
ersa	doc_491521501863_item	3730752	et	0	main
keel	doc_491521501863_item	3730753	et	0	main
antud	doc_491521501863_item	3730754	et	0	main
juhul	doc_491521501863_item	3730755	et	0	main
on	doc_491521501863_item	3730756	et	0	main
oluline	doc_491521501863_item	3730757	et	0	main
ära	doc_491521501863_item	3730758	et	0	main
märkida	doc_491521501863_item	3730759	et	0	main
et	doc_491521501863_item	3730760	et	0	main
eesti	doc_491521501863_item	3730761	et	0	main
keele	doc_491521501863_item	3730762	et	0	main
õppimist	doc_491521501863_item	3730763	et	0	main
alustasid	doc_491521501863_item	3730764	et	0	main
nad	doc_491521501863_item	3730765	et	0	main
vene	doc_491521501863_item	3730766	et	0	main
keele	doc_491521501863_item	3730767	et	0	main
kaudu	doc_491521501863_item	3730768	et	0	main
nii	doc_491521501863_item	3730769	et	0	main
õpiti	doc_491521501863_item	3730770	et	0	main
eesti	doc_491521501863_item	3730771	et	0	main
keelt	doc_491521501863_item	3730772	et	0	main
terve	doc_491521501863_item	3730773	et	0	main
aasta	doc_491521501863_item	3730774	et	0	main
loomulikult	doc_491521501863_item	3730775	et	0	main
hakkas	doc_491521501863_item	3730776	et	0	main
õpetaja	doc_491521501863_item	3730777	et	0	main
niipea	doc_491521501863_item	3730778	et	0	main
kui	doc_491521501863_item	3730779	et	0	main
võimalik	doc_491521501863_item	3730780	et	0	main
rohkem	doc_491521501863_item	3730781	et	0	main
ja	doc_491521501863_item	3730782	et	0	main
rohkem	doc_491521501863_item	3730783	et	0	main
eesti	doc_491521501863_item	3730784	et	0	main
keelt	doc_491521501863_item	3730785	et	0	main
kasutama	doc_491521501863_item	3730786	et	0	main
õppijate	doc_491521501863_item	3730787	et	0	main
endi	doc_491521501863_item	3730788	et	0	main
sõnade	doc_491521501863_item	3730789	et	0	main
järgi	doc_491521501863_item	3730790	et	0	main
mõtlesidnad	doc_491521501863_item	3730791	et	0	main
eesti	doc_491521501863_item	3730792	et	0	main
keelt	doc_491521501863_item	3730793	et	0	main
õppides	doc_491521501863_item	3730794	et	0	main
vene	doc_491521501863_item	3730795	et	0	main
keeles	doc_491521501863_item	3730796	et	0	main
ja	doc_491521501863_item	3730797	et	0	main
see	doc_491521501863_item	3730798	et	0	main
on	doc_491521501863_item	3730799	et	0	main
nende	doc_491521501863_item	3730800	et	0	main
keelekasutust	doc_491521501863_item	3730801	et	0	main
kindlasti	doc_491521501863_item	3730802	et	0	main
mõjutanud	doc_491521501863_item	3730803	et	0	main
ka	doc_491521501863_item	3730804	et	0	main
kuuldes	doc_491521501863_item	3730805	et	0	main
neid	doc_491521501863_item	3730806	et	0	main
omavahel	doc_491521501863_item	3730807	et	0	main
ersa	doc_491521501863_item	3730808	et	0	main
keeles	doc_491521501863_item	3730809	et	0	main
rääkimas	doc_491521501863_item	3730810	et	0	main
võis	doc_491521501863_item	3730811	et	0	main
märgata	doc_491521501863_item	3730812	et	0	main
et	doc_491521501863_item	3730813	et	0	main
paljud	doc_491521501863_item	3730814	et	0	main
sõnad	doc_491521501863_item	3730815	et	0	main
olid	doc_491521501863_item	3730816	et	0	main
vene	doc_491521501863_item	3730817	et	0	main
keelele	doc_491521501863_item	3730818	et	0	main
väga	doc_491521501863_item	3730819	et	0	main
sarnased	doc_491521501863_item	3730820	et	0	main
samas	doc_491521501863_item	3730821	et	0	main
ütlesid	doc_491521501863_item	3730822	et	0	main
nad	doc_491521501863_item	3730823	et	0	main
et	doc_491521501863_item	3730824	et	0	main
grammatika	doc_491521501863_item	3730825	et	0	main
on	doc_491521501863_item	3730826	et	0	main
pigem	doc_491521501863_item	3730827	et	0	main
sarnane	doc_491521501863_item	3730828	et	0	main
eesti	doc_491521501863_item	3730829	et	0	main
keelele	doc_491521501863_item	3730830	et	0	main
kui	doc_491521501863_item	3730831	et	0	main
vene	doc_491521501863_item	3730832	et	0	main
keelele	doc_491521501863_item	3730833	et	0	main
uuritud	doc_491521501863_item	3730834	et	0	main
tööd	doc_491521501863_item	3730835	et	0	main
on	doc_491521501863_item	3730836	et	0	main
kirjutatud	doc_491521501863_item	3730837	et	0	main
keele	doc_491521501863_item	3730838	et	0	main
õppimise	doc_491521501863_item	3730839	et	0	main
esimesel	doc_491521501863_item	3730840	et	0	main
aasta	doc_491521501863_item	3730841	et	0	main
seega	doc_491521501863_item	3730842	et	0	main
väga	doc_491521501863_item	3730843	et	0	main
alguses	doc_491521501863_item	3730844	et	0	main
praeguseks	doc_491521501863_item	3730845	et	0	main
on	doc_491521501863_item	3730846	et	0	main
nad	doc_491521501863_item	3730847	et	0	main
keelt	doc_491521501863_item	3730848	et	0	main
kasutanud	doc_491521501863_item	3730849	et	0	main
juba	doc_491521501863_item	3730850	et	0	main
3	doc_491521501863_item	3730851	et	0	main
aastat	doc_491521501863_item	3730852	et	0	main
ja	doc_491521501863_item	3730853	et	0	main
räägivad	doc_491521501863_item	3730854	et	0	main
väga	doc_491521501863_item	3730855	et	0	main
hästi	doc_491521501863_item	3730856	et	0	main
nii	doc_491521501863_item	3730857	et	0	main
grammatikat	doc_491521501863_item	3730858	et	0	main
kui	doc_491521501863_item	3730859	et	0	main
ka	doc_491521501863_item	3730860	et	0	main
hääldust	doc_491521501863_item	3730861	et	0	main
silmas	doc_491521501863_item	3730862	et	0	main
pidades	doc_491521501863_item	3730863	et	0	main
töödeks	doc_491521501863_item	3730864	et	0	main
olid	doc_491521501863_item	3730865	et	0	main
põhiliselt	doc_491521501863_item	3730866	et	0	main
kodus	doc_491521501863_item	3730867	et	0	main
kirjutatud	doc_491521501863_item	3730868	et	0	main
kirjandid	doc_491521501863_item	3730869	et	0	main
ja	doc_491521501863_item	3730870	et	0	main
lühemad	doc_491521501863_item	3730871	et	0	main
jutud	doc_491521501863_item	3730872	et	0	main
järgnevalt	doc_491521501863_item	3730873	et	0	main
leitud	doc_491521501863_item	3730874	et	0	main
vead	doc_491521501863_item	3730875	et	0	main
mis	doc_491521501863_item	3730876	et	0	main
on	doc_491521501863_item	3730877	et	0	main
jagatud	doc_491521501863_item	3730878	et	0	main
8	doc_491521501863_item	3730879	et	0	main
gruppi	doc_491521501863_item	3730880	et	0	main
oli	doc_491521501863_item	3730881	et	0	main
ka	doc_491521501863_item	3730882	et	0	main
vigu	doc_491521501863_item	3730883	et	0	main
mida	doc_491521501863_item	3730884	et	0	main
ei	doc_491521501863_item	3730885	et	0	main
osanud	doc_491521501863_item	3730886	et	0	main
kusagile	doc_491521501863_item	3730887	et	0	main
paigutada	doc_491521501863_item	3730888	et	0	main
need	doc_491521501863_item	3730889	et	0	main
on	doc_491521501863_item	3730890	et	0	main
teiste	doc_491521501863_item	3730891	et	0	main
seas	doc_491521501863_item	3730892	et	0	main
töö	doc_491521501863_item	3730893	et	0	main
lõpus	doc_491521501863_item	3730894	et	0	main
grupeerimise	doc_491521501863_item	3730895	et	0	main
järjekord	doc_491521501863_item	3730896	et	0	main
ei	doc_491521501863_item	3730897	et	0	main
ole	doc_491521501863_item	3730898	et	0	main
seotud	doc_491521501863_item	3730899	et	0	main
vigade	doc_491521501863_item	3730900	et	0	main
olulisusega	doc_491521501863_item	3730901	et	0	main
hääldus-	doc_491521501863_item	3730902	et	0	main
ja	doc_491521501863_item	3730903	et	0	main
õigekiri	doc_491521501863_item	3730904	et	0	main
õigekirjavigu	doc_491521501863_item	3730905	et	0	main
uuritud	doc_491521501863_item	3730906	et	0	main
töödes	doc_491521501863_item	3730907	et	0	main
väga	doc_491521501863_item	3730908	et	0	main
palju	doc_491521501863_item	3730909	et	0	main
ei	doc_491521501863_item	3730910	et	0	main
esinenud	doc_491521501863_item	3730911	et	0	main
ja	doc_491521501863_item	3730912	et	0	main
sarnaseid	doc_491521501863_item	3730913	et	0	main
vigu	doc_491521501863_item	3730914	et	0	main
oli	doc_491521501863_item	3730915	et	0	main
vähe	doc_491521501863_item	3730916	et	0	main
leitud	doc_491521501863_item	3730917	et	0	main
vead	doc_491521501863_item	3730918	et	0	main
olid	doc_491521501863_item	3730919	et	0	main
pigem	doc_491521501863_item	3730920	et	0	main
juhuslikud	doc_491521501863_item	3730921	et	0	main
võib	doc_491521501863_item	3730922	et	0	main
arvata	doc_491521501863_item	3730923	et	0	main
et	doc_491521501863_item	3730924	et	0	main
tihti	doc_491521501863_item	3730925	et	0	main
oli	doc_491521501863_item	3730926	et	0	main
tegemist	doc_491521501863_item	3730927	et	0	main
hooletusega	doc_491521501863_item	3730928	et	0	main
sest	doc_491521501863_item	3730929	et	0	main
vead	doc_491521501863_item	3730930	et	0	main
ei	doc_491521501863_item	3730931	et	0	main
kordunud	doc_491521501863_item	3730932	et	0	main
üldjuhul	doc_491521501863_item	3730933	et	0	main
ei	doc_491521501863_item	3730934	et	0	main
võinud	doc_491521501863_item	3730935	et	0	main
ühes	doc_491521501863_item	3730936	et	0	main
töös	doc_491521501863_item	3730937	et	0	main
tehtud	doc_491521501863_item	3730938	et	0	main
viga	doc_491521501863_item	3730939	et	0	main
teises	doc_491521501863_item	3730940	et	0	main
enam	doc_491521501863_item	3730941	et	0	main
leida	doc_491521501863_item	3730942	et	0	main
märkida	doc_491521501863_item	3730943	et	0	main
võis	doc_491521501863_item	3730944	et	0	main
mõningaid	doc_491521501863_item	3730945	et	0	main
õigekirjavigu	doc_491521501863_item	3730946	et	0	main
mis	doc_491521501863_item	3730947	et	0	main
on	doc_491521501863_item	3730948	et	0	main
ilmselt	doc_491521501863_item	3730949	et	0	main
tehtud	doc_491521501863_item	3730950	et	0	main
vene	doc_491521501863_item	3730951	et	0	main
keele	doc_491521501863_item	3730952	et	0	main
mõjutusel	doc_491521501863_item	3730953	et	0	main
vene	doc_491521501863_item	3730954	et	0	main
keeles	doc_491521501863_item	3730955	et	0	main
ei	doc_491521501863_item	3730956	et	0	main
ole	doc_491521501863_item	3730957	et	0	main
pikki	doc_491521501863_item	3730958	et	0	main
vokaale	doc_491521501863_item	3730959	et	0	main
ja	doc_491521501863_item	3730960	et	0	main
seetõttu	doc_491521501863_item	3730961	et	0	main
oli	doc_491521501863_item	3730962	et	0	main
ka	doc_491521501863_item	3730963	et	0	main
eesti	doc_491521501863_item	3730964	et	0	main
keeles	doc_491521501863_item	3730965	et	0	main
kasutatud	doc_491521501863_item	3730966	et	0	main
vene	doc_491521501863_item	3730967	et	0	main
keelele	doc_491521501863_item	3730968	et	0	main
väga	doc_491521501863_item	3730969	et	0	main
sarnastes	doc_491521501863_item	3730970	et	0	main
sõnades	doc_491521501863_item	3730971	et	0	main
pigem	doc_491521501863_item	3730972	et	0	main
lühikesi	doc_491521501863_item	3730973	et	0	main
kui	doc_491521501863_item	3730974	et	0	main
pikki	doc_491521501863_item	3730975	et	0	main
vokaale	doc_491521501863_item	3730976	et	0	main
nt	doc_491521501863_item	3730977	et	0	main
referat	doc_491521501863_item	3730978	et	0	main
pastet	doc_491521501863_item	3730979	et	0	main
sokolad	doc_491521501863_item	3730980	et	0	main
jt	doc_491521501863_item	3730981	et	0	main
teiste	doc_491521501863_item	3730982	et	0	main
leitud	doc_491521501863_item	3730983	et	0	main
õigekirjavigade	doc_491521501863_item	3730984	et	0	main
näiteid	doc_491521501863_item	3730985	et	0	main
ta	doc_491521501863_item	3730986	et	0	main
on	doc_491521501863_item	3730987	et	0	main
pensioner	doc_491521501863_item	3730988	et	0	main
kaubamajjas	doc_491521501863_item	3730989	et	0	main
esimesel	doc_491521501863_item	3730990	et	0	main
korrusel	doc_491521501863_item	3730991	et	0	main
on	doc_491521501863_item	3730992	et	0	main
vestluses	doc_491521501863_item	3730993	et	0	main
mordvalastega	doc_491521501863_item	3730994	et	0	main
võis	doc_491521501863_item	3730995	et	0	main
tähele	doc_491521501863_item	3730996	et	0	main
panna	doc_491521501863_item	3730997	et	0	main
et	doc_491521501863_item	3730998	et	0	main
nende	doc_491521501863_item	3730999	et	0	main
eesti	doc_491521501863_item	3731000	et	0	main
keele	doc_491521501863_item	3731001	et	0	main
hääldust	doc_491521501863_item	3731002	et	0	main
on	doc_491521501863_item	3731003	et	0	main
mõjutanud	doc_491521501863_item	3731004	et	0	main
ersa	doc_491521501863_item	3731005	et	0	main
keel	doc_491521501863_item	3731006	et	0	main
mis	doc_491521501863_item	3731007	et	0	main
eestlasele	doc_491521501863_item	3731008	et	0	main
tundub	doc_491521501863_item	3731009	et	0	main
lihtsalt	doc_491521501863_item	3731010	et	0	main
vene	doc_491521501863_item	3731011	et	0	main
keele	doc_491521501863_item	3731012	et	0	main
aktsendina	doc_491521501863_item	3731013	et	0	main
kaashäälikuid	doc_491521501863_item	3731014	et	0	main
hääldatakse	doc_491521501863_item	3731015	et	0	main
suhteliselt	doc_491521501863_item	3731016	et	0	main
tugevalt	doc_491521501863_item	3731017	et	0	main
ja	doc_491521501863_item	3731018	et	0	main
kogu	doc_491521501863_item	3731019	et	0	main
kõne	doc_491521501863_item	3731020	et	0	main
on	doc_491521501863_item	3731021	et	0	main
sujuvam	doc_491521501863_item	3731022	et	0	main
ja	doc_491521501863_item	3731023	et	0	main
pehmem	doc_491521501863_item	3731024	et	0	main
kui	doc_491521501863_item	3731025	et	0	main
eestlasel	doc_491521501863_item	3731026	et	0	main
astmevaheldus	doc_491521501863_item	3731027	et	0	main
astmevahelduse	doc_491521501863_item	3731028	et	0	main
vigu	doc_491521501863_item	3731029	et	0	main
oli	doc_491521501863_item	3731030	et	0	main
üllatavalt	doc_491521501863_item	3731031	et	0	main
vähe	doc_491521501863_item	3731032	et	0	main
ilmselt	doc_491521501863_item	3731033	et	0	main
on	doc_491521501863_item	3731034	et	0	main
siin	doc_491521501863_item	3731035	et	0	main
oluliseks	doc_491521501863_item	3731036	et	0	main
teguriks	doc_491521501863_item	3731037	et	0	main
see	doc_491521501863_item	3731038	et	0	main
et	doc_491521501863_item	3731039	et	0	main
õppurite	doc_491521501863_item	3731040	et	0	main
sõnavara	doc_491521501863_item	3731041	et	0	main
on	doc_491521501863_item	3731042	et	0	main
veel	doc_491521501863_item	3731043	et	0	main
suhteliselt	doc_491521501863_item	3731044	et	0	main
väike	doc_491521501863_item	3731045	et	0	main
teine	doc_491521501863_item	3731046	et	0	main
võimalus	doc_491521501863_item	3731047	et	0	main
on	doc_491521501863_item	3731048	et	0	main
see	doc_491521501863_item	3731049	et	0	main
et	doc_491521501863_item	3731050	et	0	main
astmevaheldus	doc_491521501863_item	3731051	et	0	main
on	doc_491521501863_item	3731052	et	0	main
hästi	doc_491521501863_item	3731053	et	0	main
ära	doc_491521501863_item	3731054	et	0	main
õpitud	doc_491521501863_item	3731055	et	0	main
ainukesed	doc_491521501863_item	3731056	et	0	main
leitud	doc_491521501863_item	3731057	et	0	main
vead	doc_491521501863_item	3731058	et	0	main
olid	doc_491521501863_item	3731059	et	0	main
tehtud	doc_491521501863_item	3731060	et	0	main
verbides	doc_491521501863_item	3731061	et	0	main
nt	doc_491521501863_item	3731062	et	0	main
õpisin	doc_491521501863_item	3731063	et	0	main
keskkoolis	doc_491521501863_item	3731064	et	0	main
selle	doc_491521501863_item	3731065	et	0	main
verbiga	doc_491521501863_item	3731066	et	0	main
oli	doc_491521501863_item	3731067	et	0	main
vigu	doc_491521501863_item	3731068	et	0	main
tehtud	doc_491521501863_item	3731069	et	0	main
enamgi	doc_491521501863_item	3731070	et	0	main
nimisonades	doc_491521501863_item	3731071	et	0	main
astmevahelduse	doc_491521501863_item	3731072	et	0	main
vigu	doc_491521501863_item	3731073	et	0	main
ei	doc_491521501863_item	3731074	et	0	main
tehtud	doc_491521501863_item	3731075	et	0	main
vähemalt	doc_491521501863_item	3731076	et	0	main
ei	doc_491521501863_item	3731077	et	0	main
olnud	doc_491521501863_item	3731078	et	0	main
neid	doc_491521501863_item	3731079	et	0	main
uuritud	doc_491521501863_item	3731080	et	0	main
töödes	doc_491521501863_item	3731081	et	0	main
objektivead	doc_491521501863_item	3731082	et	0	main
vorm	doc_491521501863_item	3731083	et	0	main
ja	doc_491521501863_item	3731084	et	0	main
käändevalik	doc_491521501863_item	3731085	et	0	main
käändevigu	doc_491521501863_item	3731086	et	0	main
oli	doc_491521501863_item	3731087	et	0	main
töödes	doc_491521501863_item	3731088	et	0	main
erinevaid	doc_491521501863_item	3731089	et	0	main
ja	doc_491521501863_item	3731090	et	0	main
neid	doc_491521501863_item	3731091	et	0	main
esines	doc_491521501863_item	3731092	et	0	main
suhteliselt	doc_491521501863_item	3731093	et	0	main
palju	doc_491521501863_item	3731094	et	0	main
siinkohal	doc_491521501863_item	3731095	et	0	main
võib	doc_491521501863_item	3731096	et	0	main
ka	doc_491521501863_item	3731097	et	0	main
ära	doc_491521501863_item	3731098	et	0	main
märkida	doc_491521501863_item	3731099	et	0	main
et	doc_491521501863_item	3731100	et	0	main
ersa	doc_491521501863_item	3731101	et	0	main
keeles	doc_491521501863_item	3731102	et	0	main
on	doc_491521501863_item	3731103	et	0	main
käändeid	doc_491521501863_item	3731104	et	0	main
vähem	doc_491521501863_item	3731105	et	0	main
kui	doc_491521501863_item	3731106	et	0	main
eesti	doc_491521501863_item	3731107	et	0	main
keeles	doc_491521501863_item	3731108	et	0	main
vead	doc_491521501863_item	3731109	et	0	main
mille	doc_491521501863_item	3731110	et	0	main
puhul	doc_491521501863_item	3731111	et	0	main
oli	doc_491521501863_item	3731112	et	0	main
kääne	doc_491521501863_item	3731113	et	0	main
valesti	doc_491521501863_item	3731114	et	0	main
moodustatud	doc_491521501863_item	3731115	et	0	main
siia	doc_491521501863_item	3731116	et	0	main
alla	doc_491521501863_item	3731117	et	0	main
käib	doc_491521501863_item	3731118	et	0	main
ennekõike	doc_491521501863_item	3731119	et	0	main
osastava	doc_491521501863_item	3731120	et	0	main
käände	doc_491521501863_item	3731121	et	0	main
moodustamine	doc_491521501863_item	3731122	et	0	main
vaatasid	doc_491521501863_item	3731123	et	0	main
häid	doc_491521501863_item	3731124	et	0	main
etenduseid	doc_491521501863_item	3731125	et	0	main
samas	doc_491521501863_item	3731126	et	0	main
võis	doc_491521501863_item	3731127	et	0	main
ka	doc_491521501863_item	3731128	et	0	main
tähele	doc_491521501863_item	3731129	et	0	main
panna	doc_491521501863_item	3731130	et	0	main
et	doc_491521501863_item	3731131	et	0	main
mitmuse	doc_491521501863_item	3731132	et	0	main
osastava	doc_491521501863_item	3731133	et	0	main
kasutamist	doc_491521501863_item	3731134	et	0	main
on	doc_491521501863_item	3731135	et	0	main
püütud	doc_491521501863_item	3731136	et	0	main
pigem	doc_491521501863_item	3731137	et	0	main
vältida	doc_491521501863_item	3731138	et	0	main
peale	doc_491521501863_item	3731139	et	0	main
selle	doc_491521501863_item	3731140	et	0	main
oli	doc_491521501863_item	3731141	et	0	main
mitmes	doc_491521501863_item	3731142	et	0	main
kohas	doc_491521501863_item	3731143	et	0	main
valesti	doc_491521501863_item	3731144	et	0	main
moodustatud	doc_491521501863_item	3731145	et	0	main
omastav	doc_491521501863_item	3731146	et	0	main
kääne	doc_491521501863_item	3731147	et	0	main
eriti	doc_491521501863_item	3731148	et	0	main
sõnades	doc_491521501863_item	3731149	et	0	main
kus	doc_491521501863_item	3731150	et	0	main
sõnalopuline	doc_491521501863_item	3731151	et	0	main
ne	doc_491521501863_item	3731152	et	0	main
muutub	doc_491521501863_item	3731153	et	0	main
omastavas	doc_491521501863_item	3731154	et	0	main
se	doc_491521501863_item	3731155	et	0	main
nt	doc_491521501863_item	3731156	et	0	main
naine	doc_491521501863_item	3731157	et	0	main
nimi	doc_491521501863_item	3731158	et	0	main
on	doc_491521501863_item	3731159	et	0	main
jelena	doc_491521501863_item	3731160	et	0	main
nainevanemad	doc_491521501863_item	3731161	et	0	main
on	doc_491521501863_item	3731162	et	0	main
pensionärid	doc_491521501863_item	3731163	et	0	main
tütar	doc_491521501863_item	3731164	et	0	main
nimi	doc_491521501863_item	3731165	et	0	main
on	doc_491521501863_item	3731166	et	0	main
jelena	doc_491521501863_item	3731167	et	0	main
minu	doc_491521501863_item	3731168	et	0	main
noorem	doc_491521501863_item	3731169	et	0	main
õde	doc_491521501863_item	3731170	et	0	main
nimi	doc_491521501863_item	3731171	et	0	main
on	doc_491521501863_item	3731172	et	0	main
irina	doc_491521501863_item	3731173	et	0	main
omastava	doc_491521501863_item	3731174	et	0	main
käändelõpu	doc_491521501863_item	3731175	et	0	main
vokaali	doc_491521501863_item	3731176	et	0	main
valimine	doc_491521501863_item	3731177	et	0	main
valmistab	doc_491521501863_item	3731178	et	0	main
ka	doc_491521501863_item	3731179	et	0	main
tihti	doc_491521501863_item	3731180	et	0	main
eesti	doc_491521501863_item	3731181	et	0	main
keele	doc_491521501863_item	3731182	et	0	main
õppijatele	doc_491521501863_item	3731183	et	0	main
raskusi	doc_491521501863_item	3731184	et	0	main
nii	doc_491521501863_item	3731185	et	0	main
näiteks	doc_491521501863_item	3731186	et	0	main
olid	doc_491521501863_item	3731187	et	0	main
tehtud	doc_491521501863_item	3731188	et	0	main
vigade	doc_491521501863_item	3731189	et	0	main
seas	doc_491521501863_item	3731190	et	0	main
järgmised	doc_491521501863_item	3731191	et	0	main
ostsid	doc_491521501863_item	3731192	et	0	main
endale	doc_491521501863_item	3731193	et	0	main
roosikimbi	doc_491521501863_item	3731194	et	0	main
sõi	doc_491521501863_item	3731195	et	0	main
kreemukooki	doc_491521501863_item	3731196	et	0	main
peale	doc_491521501863_item	3731197	et	0	main
selle	doc_491521501863_item	3731198	et	0	main
oli	doc_491521501863_item	3731199	et	0	main
mitmes	doc_491521501863_item	3731200	et	0	main
kohas	doc_491521501863_item	3731201	et	0	main
käändeid	doc_491521501863_item	3731202	et	0	main
valesti	doc_491521501863_item	3731203	et	0	main
kasutatud	doc_491521501863_item	3731204	et	0	main
põhjusteks	doc_491521501863_item	3731205	et	0	main
võivad	doc_491521501863_item	3731206	et	0	main
siin	doc_491521501863_item	3731207	et	0	main
olla	doc_491521501863_item	3731208	et	0	main
taas	doc_491521501863_item	3731209	et	0	main
mõjutused	doc_491521501863_item	3731210	et	0	main
vene	doc_491521501863_item	3731211	et	0	main
keelest	doc_491521501863_item	3731212	et	0	main
nt	doc_491521501863_item	3731213	et	0	main
ta	doc_491521501863_item	3731214	et	0	main
mängib	doc_491521501863_item	3731215	et	0	main
klaveriga	doc_491521501863_item	3731216	et	0	main
ta	doc_491521501863_item	3731217	et	0	main
on	doc_491521501863_item	3731218	et	0	main
autojuhina	doc_491521501863_item	3731219	et	0	main
oli	doc_491521501863_item	3731220	et	0	main
ka	doc_491521501863_item	3731221	et	0	main
sõnu	doc_491521501863_item	3731222	et	0	main
kus	doc_491521501863_item	3731223	et	0	main
näiteks	doc_491521501863_item	3731224	et	0	main
sisekohakääne	doc_491521501863_item	3731225	et	0	main
oli	doc_491521501863_item	3731226	et	0	main
valesti	doc_491521501863_item	3731227	et	0	main
moodustatud	doc_491521501863_item	3731228	et	0	main
nt	doc_491521501863_item	3731229	et	0	main
õhtul	doc_491521501863_item	3731230	et	0	main
pere	doc_491521501863_item	3731231	et	0	main
koguneb	doc_491521501863_item	3731232	et	0	main
peretubas	doc_491521501863_item	3731233	et	0	main
kohakäänete	doc_491521501863_item	3731234	et	0	main
vead	doc_491521501863_item	3731235	et	0	main
kohakäänete	doc_491521501863_item	3731236	et	0	main
vead	doc_491521501863_item	3731237	et	0	main
olid	doc_491521501863_item	3731238	et	0	main
suuremalt	doc_491521501863_item	3731239	et	0	main
jaolt	doc_491521501863_item	3731240	et	0	main
seotud	doc_491521501863_item	3731241	et	0	main
just	doc_491521501863_item	3731242	et	0	main
sellega	doc_491521501863_item	3731243	et	0	main
et	doc_491521501863_item	3731244	et	0	main
neid	doc_491521501863_item	3731245	et	0	main
oli	doc_491521501863_item	3731246	et	0	main
vales	doc_491521501863_item	3731247	et	0	main
kohas	doc_491521501863_item	3731248	et	0	main
kasutatud	doc_491521501863_item	3731249	et	0	main
kindlasti	doc_491521501863_item	3731250	et	0	main
võib	doc_491521501863_item	3731251	et	0	main
põhjusi	doc_491521501863_item	3731252	et	0	main
otsida	doc_491521501863_item	3731253	et	0	main
jälle	doc_491521501863_item	3731254	et	0	main
mordvalaste	doc_491521501863_item	3731255	et	0	main
emakeelest	doc_491521501863_item	3731256	et	0	main
ja	doc_491521501863_item	3731257	et	0	main
ka	doc_491521501863_item	3731258	et	0	main
vene	doc_491521501863_item	3731259	et	0	main
keelest	doc_491521501863_item	3731260	et	0	main
käändelõpp	doc_491521501863_item	3731261	et	0	main
oli	doc_491521501863_item	3731262	et	0	main
sõnale	doc_491521501863_item	3731263	et	0	main
õigesti	doc_491521501863_item	3731264	et	0	main
lisatud	doc_491521501863_item	3731265	et	0	main
aga	doc_491521501863_item	3731266	et	0	main
kasutuskoht	doc_491521501863_item	3731267	et	0	main
oli	doc_491521501863_item	3731268	et	0	main
valesti	doc_491521501863_item	3731269	et	0	main
valitud	doc_491521501863_item	3731270	et	0	main
sisekohakäänete	doc_491521501863_item	3731271	et	0	main
vead	doc_491521501863_item	3731272	et	0	main
nt	doc_491521501863_item	3731273	et	0	main
naudivad	doc_491521501863_item	3731274	et	0	main
selles	doc_491521501863_item	3731275	et	0	main
atmosfääris	doc_491521501863_item	3731276	et	0	main
käivad	doc_491521501863_item	3731277	et	0	main
restoranisse	doc_491521501863_item	3731278	et	0	main
panen	doc_491521501863_item	3731279	et	0	main
kartulid	doc_491521501863_item	3731280	et	0	main
panis	doc_491521501863_item	3731281	et	0	main
kohakääne	doc_491521501863_item	3731282	et	0	main
ortograafia	doc_491521501863_item	3731283	et	0	main
vanemad	doc_491521501863_item	3731284	et	0	main
elavad	doc_491521501863_item	3731285	et	0	main
saksamaas	doc_491521501863_item	3731286	et	0	main
väliskohakäänete	doc_491521501863_item	3731287	et	0	main
vead	doc_491521501863_item	3731288	et	0	main
nt	doc_491521501863_item	3731289	et	0	main
sõidan	doc_491521501863_item	3731290	et	0	main
turul	doc_491521501863_item	3731291	et	0	main
sõidan	doc_491521501863_item	3731292	et	0	main
turul	doc_491521501863_item	3731293	et	0	main
nendel	doc_491521501863_item	3731294	et	0	main
väga	doc_491521501863_item	3731295	et	0	main
meeldib	doc_491521501863_item	3731296	et	0	main
kohakäänete	doc_491521501863_item	3731297	et	0	main
kasutamise	doc_491521501863_item	3731298	et	0	main
puhul	doc_491521501863_item	3731299	et	0	main
tekkis	doc_491521501863_item	3731300	et	0	main
küsimus	doc_491521501863_item	3731301	et	0	main
et	doc_491521501863_item	3731302	et	0	main
kas	doc_491521501863_item	3731303	et	0	main
tehtud	doc_491521501863_item	3731304	et	0	main
vead	doc_491521501863_item	3731305	et	0	main
ei	doc_491521501863_item	3731306	et	0	main
sobiks	doc_491521501863_item	3731307	et	0	main
teisalt	doc_491521501863_item	3731308	et	0	main
ka	doc_491521501863_item	3731309	et	0	main
rektsioonivigade	doc_491521501863_item	3731310	et	0	main
alla	doc_491521501863_item	3731311	et	0	main
sest	doc_491521501863_item	3731312	et	0	main
põhjale	doc_491521501863_item	3731313	et	0	main
oli	doc_491521501863_item	3731314	et	0	main
valitud	doc_491521501863_item	3731315	et	0	main
vale	doc_491521501863_item	3731316	et	0	main
kääne	doc_491521501863_item	3731317	et	0	main
eelnevate	doc_491521501863_item	3731318	et	0	main
näidete	doc_491521501863_item	3731319	et	0	main
puhul	doc_491521501863_item	3731320	et	0	main
nautima	doc_491521501863_item	3731321	et	0	main
mida	doc_491521501863_item	3731322	et	0	main
käima	doc_491521501863_item	3731323	et	0	main
kus	doc_491521501863_item	3731324	et	0	main
sõitma	doc_491521501863_item	3731325	et	0	main
kuhu	doc_491521501863_item	3731326	et	0	main
ühildumisvead	doc_491521501863_item	3731327	et	0	main
ühildumisvigu	doc_491521501863_item	3731328	et	0	main
oli	doc_491521501863_item	3731329	et	0	main
töödes	doc_491521501863_item	3731330	et	0	main
võrdlemisi	doc_491521501863_item	3731331	et	0	main
palju	doc_491521501863_item	3731332	et	0	main
ei	doc_491521501863_item	3731333	et	0	main
oska	doc_491521501863_item	3731334	et	0	main
öelda	doc_491521501863_item	3731335	et	0	main
kas	doc_491521501863_item	3731336	et	0	main
neid	doc_491521501863_item	3731337	et	0	main
vigu	doc_491521501863_item	3731338	et	0	main
on	doc_491521501863_item	3731339	et	0	main
mõjutanud	doc_491521501863_item	3731340	et	0	main
teised	doc_491521501863_item	3731341	et	0	main
keeled	doc_491521501863_item	3731342	et	0	main
sest	doc_491521501863_item	3731343	et	0	main
ühildumine	doc_491521501863_item	3731344	et	0	main
on	doc_491521501863_item	3731345	et	0	main
eesti	doc_491521501863_item	3731346	et	0	main
keele	doc_491521501863_item	3731347	et	0	main
õppijatele	doc_491521501863_item	3731348	et	0	main
alati	doc_491521501863_item	3731349	et	0	main
raskusi	doc_491521501863_item	3731350	et	0	main
valmistanud	doc_491521501863_item	3731351	et	0	main
emakeelest	doc_491521501863_item	3731352	et	0	main
hoolimata	doc_491521501863_item	3731353	et	0	main
tihti	doc_491521501863_item	3731354	et	0	main
unustatakse	doc_491521501863_item	3731355	et	0	main
lihtsalt	doc_491521501863_item	3731356	et	0	main
ära	doc_491521501863_item	3731357	et	0	main
et	doc_491521501863_item	3731358	et	0	main
nimisõna	doc_491521501863_item	3731359	et	0	main
laiendav	doc_491521501863_item	3731360	et	0	main
omadussõna	doc_491521501863_item	3731361	et	0	main
on	doc_491521501863_item	3731362	et	0	main
nimisõnaga	doc_491521501863_item	3731363	et	0	main
samas	doc_491521501863_item	3731364	et	0	main
käändes	doc_491521501863_item	3731365	et	0	main
ja	doc_491521501863_item	3731366	et	0	main
arvus	doc_491521501863_item	3731367	et	0	main
see	doc_491521501863_item	3731368	et	0	main
on	doc_491521501863_item	3731369	et	0	main
keele	doc_491521501863_item	3731370	et	0	main
õppimisel	doc_491521501863_item	3731371	et	0	main
tehtav	doc_491521501863_item	3731372	et	0	main
täiesti	doc_491521501863_item	3731373	et	0	main
tavaline	doc_491521501863_item	3731374	et	0	main
viga	doc_491521501863_item	3731375	et	0	main
samamoodi	doc_491521501863_item	3731376	et	0	main
tehakse	doc_491521501863_item	3731377	et	0	main
vigu	doc_491521501863_item	3731378	et	0	main
vastupidi	doc_491521501863_item	3731379	et	0	main
so	doc_491521501863_item	3731380	et	0	main
ühildatakse	doc_491521501863_item	3731381	et	0	main
nö	doc_491521501863_item	3731382	et	0	main
ninataga	doc_491521501863_item	3731383	et	0	main
käänded	doc_491521501863_item	3731384	et	0	main
mis	doc_491521501863_item	3731385	et	0	main
tegelikult	doc_491521501863_item	3731386	et	0	main
ei	doc_491521501863_item	3731387	et	0	main
ühildu	doc_491521501863_item	3731388	et	0	main
näited	doc_491521501863_item	3731389	et	0	main
ühildumisvigade	doc_491521501863_item	3731390	et	0	main
kohta	doc_491521501863_item	3731391	et	0	main
mulle	doc_491521501863_item	3731392	et	0	main
ka	doc_491521501863_item	3731393	et	0	main
väga	doc_491521501863_item	3731394	et	0	main
meeldib	doc_491521501863_item	3731395	et	0	main
teatreid	doc_491521501863_item	3731396	et	0	main
on	doc_491521501863_item	3731397	et	0	main
palju	doc_491521501863_item	3731398	et	0	main
lauad	doc_491521501863_item	3731399	et	0	main
ja	doc_491521501863_item	3731400	et	0	main
toolid	doc_491521501863_item	3731401	et	0	main
elavad	doc_491521501863_item	3731402	et	0	main
mordvas	doc_491521501863_item	3731403	et	0	main
väike	doc_491521501863_item	3731404	et	0	main
külas	doc_491521501863_item	3731405	et	0	main
asub	doc_491521501863_item	3731406	et	0	main
ilusa	doc_491521501863_item	3731407	et	0	main
kohas	doc_491521501863_item	3731408	et	0	main
nad	doc_491521501863_item	3731409	et	0	main
on	doc_491521501863_item	3731410	et	0	main
15	doc_491521501863_item	3731411	et	0	main
aastat	doc_491521501863_item	3731412	et	0	main
vana	doc_491521501863_item	3731413	et	0	main
mulle	doc_491521501863_item	3731414	et	0	main
meeldivad	doc_491521501863_item	3731415	et	0	main
palju	doc_491521501863_item	3731416	et	0	main
lauljad	doc_491521501863_item	3731417	et	0	main
mul	doc_491521501863_item	3731418	et	0	main
ja	doc_491521501863_item	3731419	et	0	main
iga	doc_491521501863_item	3731420	et	0	main
inimesel	doc_491521501863_item	3731421	et	0	main
on	doc_491521501863_item	3731422	et	0	main
oma	doc_491521501863_item	3731423	et	0	main
elutee	doc_491521501863_item	3731424	et	0	main
selle	doc_491521501863_item	3731425	et	0	main
ajal	doc_491521501863_item	3731426	et	0	main
huvitasin	doc_491521501863_item	3731427	et	0	main
ka	doc_491521501863_item	3731428	et	0	main
kirjandusest	doc_491521501863_item	3731429	et	0	main
sai	doc_491521501863_item	3731430	et	0	main
kaheteistkümneks	doc_491521501863_item	3731431	et	0	main
aastaseks	doc_491521501863_item	3731432	et	0	main
tehtud	doc_491521501863_item	3731433	et	0	main
vead	doc_491521501863_item	3731434	et	0	main
on	doc_491521501863_item	3731435	et	0	main
väga	doc_491521501863_item	3731436	et	0	main
tüüpilised	doc_491521501863_item	3731437	et	0	main
ja	doc_491521501863_item	3731438	et	0	main
nende	doc_491521501863_item	3731439	et	0	main
vältimiseks	doc_491521501863_item	3731440	et	0	main
oleks	doc_491521501863_item	3731441	et	0	main
vaja	doc_491521501863_item	3731442	et	0	main
oma	doc_491521501863_item	3731443	et	0	main
keelekasutust	doc_491521501863_item	3731444	et	0	main
väga	doc_491521501863_item	3731445	et	0	main
hoolikalt	doc_491521501863_item	3731446	et	0	main
jälgida	doc_491521501863_item	3731447	et	0	main
ja	doc_491521501863_item	3731448	et	0	main
tähele	doc_491521501863_item	3731449	et	0	main
panna	doc_491521501863_item	3731450	et	0	main
et	doc_491521501863_item	3731451	et	0	main
ühildumist	doc_491521501863_item	3731452	et	0	main
kasutataks	doc_491521501863_item	3731453	et	0	main
rektsioonivead	doc_491521501863_item	3731454	et	0	main
rektsioonivead	doc_491521501863_item	3731455	et	0	main
moodustasid	doc_491521501863_item	3731456	et	0	main
suurema	doc_491521501863_item	3731457	et	0	main
osa	doc_491521501863_item	3731458	et	0	main
leitud	doc_491521501863_item	3731459	et	0	main
vigadest	doc_491521501863_item	3731460	et	0	main
rektsiooni	doc_491521501863_item	3731461	et	0	main
puhul	doc_491521501863_item	3731462	et	0	main
oleneb	doc_491521501863_item	3731463	et	0	main
käändsõna	doc_491521501863_item	3731464	et	0	main
kääne	doc_491521501863_item	3731465	et	0	main
sõna	doc_491521501863_item	3731466	et	0	main
leksikaalsest	doc_491521501863_item	3731467	et	0	main
tähendusest	doc_491521501863_item	3731468	et	0	main
nt	doc_491521501863_item	3731469	et	0	main
heitma	doc_491521501863_item	3731470	et	0	main
kuhu	doc_491521501863_item	3731471	et	0	main
osalema	doc_491521501863_item	3731472	et	0	main
kus	doc_491521501863_item	3731473	et	0	main
pole	doc_491521501863_item	3731474	et	0	main
üllatus	doc_491521501863_item	3731475	et	0	main
et	doc_491521501863_item	3731476	et	0	main
siin	doc_491521501863_item	3731477	et	0	main
vigu	doc_491521501863_item	3731478	et	0	main
tehakse	doc_491521501863_item	3731479	et	0	main
sest	doc_491521501863_item	3731480	et	0	main
rektsioon	doc_491521501863_item	3731481	et	0	main
on	doc_491521501863_item	3731482	et	0	main
sageli	doc_491521501863_item	3731483	et	0	main
komistuskiviks	doc_491521501863_item	3731484	et	0	main
ka	doc_491521501863_item	3731485	et	0	main
emakeelekõnelejatele	doc_491521501863_item	3731486	et	0	main
näited	doc_491521501863_item	3731487	et	0	main
leitud	doc_491521501863_item	3731488	et	0	main
vigadest	doc_491521501863_item	3731489	et	0	main
kuulavad	doc_491521501863_item	3731490	et	0	main
ilusad	doc_491521501863_item	3731491	et	0	main
laulud	doc_491521501863_item	3731492	et	0	main
kuulama	doc_491521501863_item	3731493	et	0	main
mida	doc_491521501863_item	3731494	et	0	main
käivad	doc_491521501863_item	3731495	et	0	main
restoranisse	doc_491521501863_item	3731496	et	0	main
käima	doc_491521501863_item	3731497	et	0	main
kus	doc_491521501863_item	3731498	et	0	main
tellib	doc_491521501863_item	3731499	et	0	main
toit	doc_491521501863_item	3731500	et	0	main
tellima	doc_491521501863_item	3731501	et	0	main
mida	doc_491521501863_item	3731502	et	0	main
ettekandja	doc_491521501863_item	3731503	et	0	main
kannab	doc_491521501863_item	3731504	et	0	main
toit	doc_491521501863_item	3731505	et	0	main
kandma	doc_491521501863_item	3731506	et	0	main
mida	doc_491521501863_item	3731507	et	0	main
ema	doc_491521501863_item	3731508	et	0	main
toidab	doc_491521501863_item	3731509	et	0	main
oma	doc_491521501863_item	3731510	et	0	main
tütar	doc_491521501863_item	3731511	et	0	main
toitma	doc_491521501863_item	3731512	et	0	main
keda	doc_491521501863_item	3731513	et	0	main
pere	doc_491521501863_item	3731514	et	0	main
joob	doc_491521501863_item	3731515	et	0	main
tee	doc_491521501863_item	3731516	et	0	main
jooma	doc_491521501863_item	3731517	et	0	main
mida	doc_491521501863_item	3731518	et	0	main
kuulavad	doc_491521501863_item	3731519	et	0	main
muusika	doc_491521501863_item	3731520	et	0	main
kuulama	doc_491521501863_item	3731521	et	0	main
mida	doc_491521501863_item	3731522	et	0	main
sõidan	doc_491521501863_item	3731523	et	0	main
turul	doc_491521501863_item	3731524	et	0	main
sõitma	doc_491521501863_item	3731525	et	0	main
kuhu	doc_491521501863_item	3731526	et	0	main
ma	doc_491521501863_item	3731527	et	0	main
tean	doc_491521501863_item	3731528	et	0	main
tema	doc_491521501863_item	3731529	et	0	main
juba	doc_491521501863_item	3731530	et	0	main
seitse	doc_491521501863_item	3731531	et	0	main
aastat	doc_491521501863_item	3731532	et	0	main
teadma	doc_491521501863_item	3731533	et	0	main
keda	doc_491521501863_item	3731534	et	0	main
mida	doc_491521501863_item	3731535	et	0	main
ma	doc_491521501863_item	3731536	et	0	main
meelsasti	doc_491521501863_item	3731537	et	0	main
kuulan	doc_491521501863_item	3731538	et	0	main
estraadimuusika	doc_491521501863_item	3731539	et	0	main
klassikaline	doc_491521501863_item	3731540	et	0	main
muusika	doc_491521501863_item	3731541	et	0	main
ja	doc_491521501863_item	3731542	et	0	main
rahvalik	doc_491521501863_item	3731543	et	0	main
muusika	doc_491521501863_item	3731544	et	0	main
kuulama	doc_491521501863_item	3731545	et	0	main
mida	doc_491521501863_item	3731546	et	0	main
ei	doc_491521501863_item	3731547	et	0	main
armasta	doc_491521501863_item	3731548	et	0	main
rokk	doc_491521501863_item	3731549	et	0	main
mulisika	doc_491521501863_item	3731550	et	0	main
armastama	doc_491521501863_item	3731551	et	0	main
keda	doc_491521501863_item	3731552	et	0	main
mida	doc_491521501863_item	3731553	et	0	main
müüdi	doc_491521501863_item	3731554	et	0	main
erinevad	doc_491521501863_item	3731555	et	0	main
lilled	doc_491521501863_item	3731556	et	0	main
müüma	doc_491521501863_item	3731557	et	0	main
mida	doc_491521501863_item	3731558	et	0	main
müüdi	doc_491521501863_item	3731559	et	0	main
kommid	doc_491521501863_item	3731560	et	0	main
müüma	doc_491521501863_item	3731561	et	0	main
mida	doc_491521501863_item	3731562	et	0	main
korjasid	doc_491521501863_item	3731563	et	0	main
erinevad	doc_491521501863_item	3731564	et	0	main
marjad	doc_491521501863_item	3731565	et	0	main
seened-korjama	doc_491521501863_item	3731566	et	0	main
mida	doc_491521501863_item	3731567	et	0	main
metsale	doc_491521501863_item	3731568	et	0	main
viiv	doc_491521501863_item	3731569	et	0	main
tee	doc_491521501863_item	3731570	et	0	main
oli	doc_491521501863_item	3731571	et	0	main
kuiv	doc_491521501863_item	3731572	et	0	main
ja	doc_491521501863_item	3731573	et	0	main
lai	doc_491521501863_item	3731574	et	0	main
viima	doc_491521501863_item	3731575	et	0	main
kuhu	doc_491521501863_item	3731576	et	0	main
verbivormide	doc_491521501863_item	3731577	et	0	main
valiku	doc_491521501863_item	3731578	et	0	main
vead	doc_491521501863_item	3731579	et	0	main
verbivormi	doc_491521501863_item	3731580	et	0	main
kasutamisel	doc_491521501863_item	3731581	et	0	main
tehti	doc_491521501863_item	3731582	et	0	main
vigu	doc_491521501863_item	3731583	et	0	main
väga	doc_491521501863_item	3731584	et	0	main
vähe	doc_491521501863_item	3731585	et	0	main
ilmselt	doc_491521501863_item	3731586	et	0	main
on	doc_491521501863_item	3731587	et	0	main
see	doc_491521501863_item	3731588	et	0	main
üks	doc_491521501863_item	3731589	et	0	main
lihtsamini	doc_491521501863_item	3731590	et	0	main
õpitavaid	doc_491521501863_item	3731591	et	0	main
asju	doc_491521501863_item	3731592	et	0	main
grammatikas	doc_491521501863_item	3731593	et	0	main
töödest	doc_491521501863_item	3731594	et	0	main
leidsin	doc_491521501863_item	3731595	et	0	main
kaks	doc_491521501863_item	3731596	et	0	main
viga	doc_491521501863_item	3731597	et	0	main
lapsepõlves	doc_491521501863_item	3731598	et	0	main
tahaksin	doc_491521501863_item	3731599	et	0	main
olla	doc_491521501863_item	3731600	et	0	main
sõjavaelaseks	doc_491521501863_item	3731601	et	0	main
ma	doc_491521501863_item	3731602	et	0	main
olin	doc_491521501863_item	3731603	et	0	main
sündinud	doc_491521501863_item	3731604	et	0	main
esimesel	doc_491521501863_item	3731605	et	0	main
juhul	doc_491521501863_item	3731606	et	0	main
oli	doc_491521501863_item	3731607	et	0	main
ilmselt	doc_491521501863_item	3731608	et	0	main
tahetud	doc_491521501863_item	3731609	et	0	main
kasutada	doc_491521501863_item	3731610	et	0	main
lihtminevikku	doc_491521501863_item	3731611	et	0	main
kuid	doc_491521501863_item	3731612	et	0	main
ekslikult	doc_491521501863_item	3731613	et	0	main
on	doc_491521501863_item	3731614	et	0	main
kasutatus	doc_491521501863_item	3731615	et	0	main
tingivat	doc_491521501863_item	3731616	et	0	main
kõneviisi	doc_491521501863_item	3731617	et	0	main
sellise	doc_491521501863_item	3731618	et	0	main
järelduse	doc_491521501863_item	3731619	et	0	main
võis	doc_491521501863_item	3731620	et	0	main
teha	doc_491521501863_item	3731621	et	0	main
lugedes	doc_491521501863_item	3731622	et	0	main
konkreetset	doc_491521501863_item	3731623	et	0	main
kirjandit	doc_491521501863_item	3731624	et	0	main
kus	doc_491521501863_item	3731625	et	0	main
see	doc_491521501863_item	3731626	et	0	main
kontekstist	doc_491521501863_item	3731627	et	0	main
välja	doc_491521501863_item	3731628	et	0	main
tuli	doc_491521501863_item	3731629	et	0	main
teisel	doc_491521501863_item	3731630	et	0	main
juhul	doc_491521501863_item	3731631	et	0	main
on	doc_491521501863_item	3731632	et	0	main
täismineviku	doc_491521501863_item	3731633	et	0	main
asemel	doc_491521501863_item	3731634	et	0	main
kasutatud	doc_491521501863_item	3731635	et	0	main
enneminevikku	doc_491521501863_item	3731636	et	0	main
kuid	doc_491521501863_item	3731637	et	0	main
eesti	doc_491521501863_item	3731638	et	0	main
keeles	doc_491521501863_item	3731639	et	0	main
öeldakse	doc_491521501863_item	3731640	et	0	main
ma	doc_491521501863_item	3731641	et	0	main
olen	doc_491521501863_item	3731642	et	0	main
sündinud	doc_491521501863_item	3731643	et	0	main
sõnatasandi	doc_491521501863_item	3731644	et	0	main
vead	doc_491521501863_item	3731645	et	0	main
sõnatasandil	doc_491521501863_item	3731646	et	0	main
tehti	doc_491521501863_item	3731647	et	0	main
ka	doc_491521501863_item	3731648	et	0	main
suhteliselt	doc_491521501863_item	3731649	et	0	main
palju	doc_491521501863_item	3731650	et	0	main
vigu	doc_491521501863_item	3731651	et	0	main
vead	doc_491521501863_item	3731652	et	0	main
siin	doc_491521501863_item	3731653	et	0	main
olid	doc_491521501863_item	3731654	et	0	main
erinevad	doc_491521501863_item	3731655	et	0	main
kõige	doc_491521501863_item	3731656	et	0	main
suuremaks	doc_491521501863_item	3731657	et	0	main
probleemiks	doc_491521501863_item	3731658	et	0	main
tundub	doc_491521501863_item	3731659	et	0	main
olevat	doc_491521501863_item	3731660	et	0	main
sõnajärg	doc_491521501863_item	3731661	et	0	main
sageli	doc_491521501863_item	3731662	et	0	main
oli	doc_491521501863_item	3731663	et	0	main
lause	doc_491521501863_item	3731664	et	0	main
sisu	doc_491521501863_item	3731665	et	0	main
selle	doc_491521501863_item	3731666	et	0	main
tõttu	doc_491521501863_item	3731667	et	0	main
peaaegu	doc_491521501863_item	3731668	et	0	main
arusaamatu	doc_491521501863_item	3731669	et	0	main
samuti	doc_491521501863_item	3731670	et	0	main
oli	doc_491521501863_item	3731671	et	0	main
mingit	doc_491521501863_item	3731672	et	0	main
sõna	doc_491521501863_item	3731673	et	0	main
kasutatud	doc_491521501863_item	3731674	et	0	main
vales	doc_491521501863_item	3731675	et	0	main
kontekstis	doc_491521501863_item	3731676	et	0	main
vt	doc_491521501863_item	3731677	et	0	main
näide	doc_491521501863_item	3731678	et	0	main
ainult	doc_491521501863_item	3731679	et	0	main
alles	doc_491521501863_item	3731680	et	0	main
ka	doc_491521501863_item	3731681	et	0	main
ainukese	doc_491521501863_item	3731682	et	0	main
asesõnavea	doc_491521501863_item	3731683	et	0	main
paigutasin	doc_491521501863_item	3731684	et	0	main
siia	doc_491521501863_item	3731685	et	0	main
gruppi	doc_491521501863_item	3731686	et	0	main
sest	doc_491521501863_item	3731687	et	0	main
see	doc_491521501863_item	3731688	et	0	main
ei	doc_491521501863_item	3731689	et	0	main
olnud	doc_491521501863_item	3731690	et	0	main
jätkuv	doc_491521501863_item	3731691	et	0	main
sõna	doc_491521501863_item	3731692	et	0	main
vale	doc_491521501863_item	3731693	et	0	main
kasutamine	doc_491521501863_item	3731694	et	0	main
mida	doc_491521501863_item	3731695	et	0	main
pikemad	doc_491521501863_item	3731696	et	0	main
olid	doc_491521501863_item	3731697	et	0	main
laused	doc_491521501863_item	3731698	et	0	main
seda	doc_491521501863_item	3731699	et	0	main
rohkem	doc_491521501863_item	3731700	et	0	main
oli	doc_491521501863_item	3731701	et	0	main
erinevaid	doc_491521501863_item	3731702	et	0	main
vigu	doc_491521501863_item	3731703	et	0	main
tehtud	doc_491521501863_item	3731704	et	0	main
näited	doc_491521501863_item	3731705	et	0	main
võib	doc_491521501863_item	3731706	et	0	main
huvitada	doc_491521501863_item	3731707	et	0	main
kui	doc_491521501863_item	3731708	et	0	main
täiskasvanuid	doc_491521501863_item	3731709	et	0	main
nii	doc_491521501863_item	3731710	et	0	main
lapsi	doc_491521501863_item	3731711	et	0	main
vaatavad	doc_491521501863_item	3731712	et	0	main
kuidas	doc_491521501863_item	3731713	et	0	main
mängivad	doc_491521501863_item	3731714	et	0	main
tantsivad	doc_491521501863_item	3731715	et	0	main
näitlejad	doc_491521501863_item	3731716	et	0	main
meie	doc_491521501863_item	3731717	et	0	main
jaoks	doc_491521501863_item	3731718	et	0	main
kõik	doc_491521501863_item	3731719	et	0	main
etendused	doc_491521501863_item	3731720	et	0	main
on	doc_491521501863_item	3731721	et	0	main
huvitavad	doc_491521501863_item	3731722	et	0	main
ilusad	doc_491521501863_item	3731723	et	0	main
ja	doc_491521501863_item	3731724	et	0	main
me	doc_491521501863_item	3731725	et	0	main
avame	doc_491521501863_item	3731726	et	0	main
midagi	doc_491521501863_item	3731727	et	0	main
uut	doc_491521501863_item	3731728	et	0	main
enda	doc_491521501863_item	3731729	et	0	main
jaoks	doc_491521501863_item	3731730	et	0	main
õde	doc_491521501863_item	3731731	et	0	main
on	doc_491521501863_item	3731732	et	0	main
kaunitar	doc_491521501863_item	3731733	et	0	main
ainult	doc_491521501863_item	3731734	et	0	main
pärast	doc_491521501863_item	3731735	et	0	main
ostan	doc_491521501863_item	3731736	et	0	main
kingid	doc_491521501863_item	3731737	et	0	main
siin	doc_491521501863_item	3731738	et	0	main
väga	doc_491521501863_item	3731739	et	0	main
hea	doc_491521501863_item	3731740	et	0	main
on	doc_491521501863_item	3731741	et	0	main
näha	doc_491521501863_item	3731742	et	0	main
kui	doc_491521501863_item	3731743	et	0	main
suurenes	doc_491521501863_item	3731744	et	0	main
elanikuarv	doc_491521501863_item	3731745	et	0	main
minu	doc_491521501863_item	3731746	et	0	main
jaoks	doc_491521501863_item	3731747	et	0	main
oma	doc_491521501863_item	3731748	et	0	main
elutee	doc_491521501863_item	3731749	et	0	main
on	doc_491521501863_item	3731750	et	0	main
esimesel	doc_491521501863_item	3731751	et	0	main
juhul	doc_491521501863_item	3731752	et	0	main
on	doc_491521501863_item	3731753	et	0	main
sõnade	doc_491521501863_item	3731754	et	0	main
järjekord	doc_491521501863_item	3731755	et	0	main
segamini	doc_491521501863_item	3731756	et	0	main
aetud	doc_491521501863_item	3731757	et	0	main
õige	doc_491521501863_item	3731758	et	0	main
on	doc_491521501863_item	3731759	et	0	main
öelda	doc_491521501863_item	3731760	et	0	main
võib	doc_491521501863_item	3731761	et	0	main
huvitada	doc_491521501863_item	3731762	et	0	main
nii	doc_491521501863_item	3731763	et	0	main
täiskasvanuid	doc_491521501863_item	3731764	et	0	main
kui	doc_491521501863_item	3731765	et	0	main
ka	doc_491521501863_item	3731766	et	0	main
lapsi	doc_491521501863_item	3731767	et	0	main
teisel	doc_491521501863_item	3731768	et	0	main
juhul	doc_491521501863_item	3731769	et	0	main
on	doc_491521501863_item	3731770	et	0	main
vale	doc_491521501863_item	3731771	et	0	main
sõnajärg	doc_491521501863_item	3731772	et	0	main
kolmandal	doc_491521501863_item	3731773	et	0	main
juhul	doc_491521501863_item	3731774	et	0	main
on	doc_491521501863_item	3731775	et	0	main
sõna	doc_491521501863_item	3731776	et	0	main
avastame	doc_491521501863_item	3731777	et	0	main
asemel	doc_491521501863_item	3731778	et	0	main
kasutatud	doc_491521501863_item	3731779	et	0	main
avame	doc_491521501863_item	3731780	et	0	main
põhjuseks	doc_491521501863_item	3731781	et	0	main
ilmselt	doc_491521501863_item	3731782	et	0	main
sõnade	doc_491521501863_item	3731783	et	0	main
ortograafiline	doc_491521501863_item	3731784	et	0	main
sarnasus	doc_491521501863_item	3731785	et	0	main
ja	doc_491521501863_item	3731786	et	0	main
ka	doc_491521501863_item	3731787	et	0	main
hääldus	doc_491521501863_item	3731788	et	0	main
õde	doc_491521501863_item	3731789	et	0	main
on	doc_491521501863_item	3731790	et	0	main
kaunitar	doc_491521501863_item	3731791	et	0	main
on	doc_491521501863_item	3731792	et	0	main
ilmne	doc_491521501863_item	3731793	et	0	main
mõju	doc_491521501863_item	3731794	et	0	main
vene	doc_491521501863_item	3731795	et	0	main
keelest	doc_491521501863_item	3731796	et	0	main
olen	doc_491521501863_item	3731797	et	0	main
kuulnud	doc_491521501863_item	3731798	et	0	main
venelasi	doc_491521501863_item	3731799	et	0	main
seda	doc_491521501863_item	3731800	et	0	main
kasutavat	doc_491521501863_item	3731801	et	0	main
ja	doc_491521501863_item	3731802	et	0	main
nende	doc_491521501863_item	3731803	et	0	main
jaoks	doc_491521501863_item	3731804	et	0	main
on	doc_491521501863_item	3731805	et	0	main
täiesti	doc_491521501863_item	3731806	et	0	main
tavaline	doc_491521501863_item	3731807	et	0	main
nii	doc_491521501863_item	3731808	et	0	main
öelda	doc_491521501863_item	3731809	et	0	main
eestlane	doc_491521501863_item	3731810	et	0	main
ütleks	doc_491521501863_item	3731811	et	0	main
pigem	doc_491521501863_item	3731812	et	0	main
õde	doc_491521501863_item	3731813	et	0	main
on	doc_491521501863_item	3731814	et	0	main
ilus	doc_491521501863_item	3731815	et	0	main
teatud	doc_491521501863_item	3731816	et	0	main
olukorras	doc_491521501863_item	3731817	et	0	main
võib	doc_491521501863_item	3731818	et	0	main
kaunitar	doc_491521501863_item	3731819	et	0	main
olla	doc_491521501863_item	3731820	et	0	main
isegi	doc_491521501863_item	3731821	et	0	main
negatiivse	doc_491521501863_item	3731822	et	0	main
varjundiga	doc_491521501863_item	3731823	et	0	main
järgmine	doc_491521501863_item	3731824	et	0	main
näide	doc_491521501863_item	3731825	et	0	main
on	doc_491521501863_item	3731826	et	0	main
taas	doc_491521501863_item	3731827	et	0	main
tüüpiline	doc_491521501863_item	3731828	et	0	main
viga	doc_491521501863_item	3731829	et	0	main
mis	doc_491521501863_item	3731830	et	0	main
tuleneb	doc_491521501863_item	3731831	et	0	main
vene	doc_491521501863_item	3731832	et	0	main
keelest	doc_491521501863_item	3731833	et	0	main
sest	doc_491521501863_item	3731834	et	0	main
vene	doc_491521501863_item	3731835	et	0	main
keeles	doc_491521501863_item	3731836	et	0	main
on	doc_491521501863_item	3731837	et	0	main
sõnade	doc_491521501863_item	3731838	et	0	main
ainult	doc_491521501863_item	3731839	et	0	main
ja	doc_491521501863_item	3731840	et	0	main
alles	doc_491521501863_item	3731841	et	0	main
vasteks	doc_491521501863_item	3731842	et	0	main
üks	doc_491521501863_item	3731843	et	0	main
sõna	doc_491521501863_item	3731844	et	0	main
järgmise	doc_491521501863_item	3731845	et	0	main
näite	doc_491521501863_item	3731846	et	0	main
ütleks	doc_491521501863_item	3731847	et	0	main
eestlane	doc_491521501863_item	3731848	et	0	main
ilmselt	doc_491521501863_item	3731849	et	0	main
järgmiselt	doc_491521501863_item	3731850	et	0	main
siin	doc_491521501863_item	3731851	et	0	main
on	doc_491521501863_item	3731852	et	0	main
väga	doc_491521501863_item	3731853	et	0	main
hea	doc_491521501863_item	3731854	et	0	main
näha	doc_491521501863_item	3731855	et	0	main
kuidas	doc_491521501863_item	3731856	et	0	main
suurenes	doc_491521501863_item	3731857	et	0	main
elanike	doc_491521501863_item	3731858	et	0	main
arv	doc_491521501863_item	3731859	et	0	main
vea	doc_491521501863_item	3731860	et	0	main
tegemise	doc_491521501863_item	3731861	et	0	main
põhjust	doc_491521501863_item	3731862	et	0	main
võib	doc_491521501863_item	3731863	et	0	main
taas	doc_491521501863_item	3731864	et	0	main
otsida	doc_491521501863_item	3731865	et	0	main
vene	doc_491521501863_item	3731866	et	0	main
keelest	doc_491521501863_item	3731867	et	0	main
viimasel	doc_491521501863_item	3731868	et	0	main
juhul	doc_491521501863_item	3731869	et	0	main
on	doc_491521501863_item	3731870	et	0	main
minu	doc_491521501863_item	3731871	et	0	main
asemel	doc_491521501863_item	3731872	et	0	main
kasutatud	doc_491521501863_item	3731873	et	0	main
oma	doc_491521501863_item	3731874	et	0	main
pronoomenite	doc_491521501863_item	3731875	et	0	main
kasutamine	doc_491521501863_item	3731876	et	0	main
on	doc_491521501863_item	3731877	et	0	main
samuti	doc_491521501863_item	3731878	et	0	main
sageli	doc_491521501863_item	3731879	et	0	main
komistuskiviks	doc_491521501863_item	3731880	et	0	main
olnud	doc_491521501863_item	3731881	et	0	main
kokkuvõte	doc_491521501863_item	3731882	et	0	main
lühidalt	doc_491521501863_item	3731883	et	0	main
võib	doc_491521501863_item	3731884	et	0	main
öelda	doc_491521501863_item	3731885	et	0	main
et	doc_491521501863_item	3731886	et	0	main
uuritud	doc_491521501863_item	3731887	et	0	main
töödes	doc_491521501863_item	3731888	et	0	main
oli	doc_491521501863_item	3731889	et	0	main
vigu	doc_491521501863_item	3731890	et	0	main
oodatud	doc_491521501863_item	3731891	et	0	main
määral	doc_491521501863_item	3731892	et	0	main
vigade	doc_491521501863_item	3731893	et	0	main
tegemine	doc_491521501863_item	3731894	et	0	main
sõltub	doc_491521501863_item	3731895	et	0	main
paljuski	doc_491521501863_item	3731896	et	0	main
emakeelemõjutustest	doc_491521501863_item	3731897	et	0	main
kuid	doc_491521501863_item	3731898	et	0	main
samuti	doc_491521501863_item	3731899	et	0	main
on	doc_491521501863_item	3731900	et	0	main
oluline	doc_491521501863_item	3731901	et	0	main
iga	doc_491521501863_item	3731902	et	0	main
inimene	doc_491521501863_item	3731903	et	0	main
eraldi	doc_491521501863_item	3731904	et	0	main
mõnele	doc_491521501863_item	3731905	et	0	main
valmistab	doc_491521501863_item	3731906	et	0	main
raskusi	doc_491521501863_item	3731907	et	0	main
sõnajärg	doc_491521501863_item	3731908	et	0	main
teisele	doc_491521501863_item	3731909	et	0	main
on	doc_491521501863_item	3731910	et	0	main
probleemne	doc_491521501863_item	3731911	et	0	main
käänete	doc_491521501863_item	3731912	et	0	main
moodustamine	doc_491521501863_item	3731913	et	0	main
põhjapanevaid	doc_491521501863_item	3731914	et	0	main
järeldusi	doc_491521501863_item	3731915	et	0	main
antud	doc_491521501863_item	3731916	et	0	main
väikese	doc_491521501863_item	3731917	et	0	main
uurimuse	doc_491521501863_item	3731918	et	0	main
põhjal	doc_491521501863_item	3731919	et	0	main
teha	doc_491521501863_item	3731920	et	0	main
ei	doc_491521501863_item	3731921	et	0	main
saa	doc_491521501863_item	3731922	et	0	main
kuid	doc_491521501863_item	3731923	et	0	main
alati	doc_491521501863_item	3731924	et	0	main
on	doc_491521501863_item	3731925	et	0	main
võimalik	doc_491521501863_item	3731926	et	0	main
midagi	doc_491521501863_item	3731927	et	0	main
prognoosida	doc_491521501863_item	3731928	et	0	main
analüüs	doc_491521501782_item	3731929	et	0	main
veaanlüüs	doc_491521501782_item	3731930	et	0	main
antud	doc_491521501782_item	3731931	et	0	main
tööks	doc_491521501782_item	3731932	et	0	main
kogusin	doc_491521501782_item	3731933	et	0	main
eesti	doc_491521501782_item	3731934	et	0	main
kirjakeelest	doc_491521501782_item	3731935	et	0	main
hälbiva	doc_491521501782_item	3731936	et	0	main
keelekasutuse	doc_491521501782_item	3731937	et	0	main
näiteid	doc_491521501782_item	3731938	et	0	main
mitteeestlaste	doc_491521501782_item	3731939	et	0	main
kirjalikest	doc_491521501782_item	3731940	et	0	main
tekstidest	doc_491521501782_item	3731941	et	0	main
analüüsivateks	doc_491521501782_item	3731942	et	0	main
materjalideks	doc_491521501782_item	3731943	et	0	main
olid	doc_491521501782_item	3731944	et	0	main
maardu	doc_491521501782_item	3731945	et	0	main
gümnaasiumi	doc_491521501782_item	3731946	et	0	main
kaheteistkümnendate	doc_491521501782_item	3731947	et	0	main
klasside	doc_491521501782_item	3731948	et	0	main
õpilaste	doc_491521501782_item	3731949	et	0	main
lühikjandid	doc_491521501782_item	3731950	et	0	main
arutluseks	doc_491521501782_item	3731951	et	0	main
oli	doc_491521501782_item	3731952	et	0	main
pakutud	doc_491521501782_item	3731953	et	0	main
teema	doc_491521501782_item	3731954	et	0	main
kas	doc_491521501782_item	3731955	et	0	main
inimene	doc_491521501782_item	3731956	et	0	main
peab	doc_491521501782_item	3731957	et	0	main
mäletama	doc_491521501782_item	3731958	et	0	main
oma	doc_491521501782_item	3731959	et	0	main
minevikku	doc_491521501782_item	3731960	et	0	main
õpilaste	doc_491521501782_item	3731961	et	0	main
keeleoskust	doc_491521501782_item	3731962	et	0	main
analüüsides	doc_491521501782_item	3731963	et	0	main
peab	doc_491521501782_item	3731964	et	0	main
arvestama	doc_491521501782_item	3731965	et	0	main
asjaoluga	doc_491521501782_item	3731966	et	0	main
et	doc_491521501782_item	3731967	et	0	main
neil	doc_491521501782_item	3731968	et	0	main
peaaegu	doc_491521501782_item	3731969	et	0	main
puudub	doc_491521501782_item	3731970	et	0	main
eesti	doc_491521501782_item	3731971	et	0	main
keele	doc_491521501782_item	3731972	et	0	main
praktiseerimise	doc_491521501782_item	3731973	et	0	main
võimalus	doc_491521501782_item	3731974	et	0	main
kuna	doc_491521501782_item	3731975	et	0	main
eestlasi	doc_491521501782_item	3731976	et	0	main
on	doc_491521501782_item	3731977	et	0	main
kogu	doc_491521501782_item	3731978	et	0	main
maardu	doc_491521501782_item	3731979	et	0	main
linna	doc_491521501782_item	3731980	et	0	main
elanikkonna	doc_491521501782_item	3731981	et	0	main
seast	doc_491521501782_item	3731982	et	0	main
ainult	doc_491521501782_item	3731983	et	0	main
viis	doc_491521501782_item	3731984	et	0	main
protsenti	doc_491521501782_item	3731985	et	0	main
läbiviidud	doc_491521501782_item	3731986	et	0	main
küsitluse	doc_491521501782_item	3731987	et	0	main
käigus	doc_491521501782_item	3731988	et	0	main
selgus	doc_491521501782_item	3731989	et	0	main
et	doc_491521501782_item	3731990	et	0	main
ainult	doc_491521501782_item	3731991	et	0	main
neli	doc_491521501782_item	3731992	et	0	main
õpilast	doc_491521501782_item	3731993	et	0	main
neljakümnest	doc_491521501782_item	3731994	et	0	main
täiendavad	doc_491521501782_item	3731995	et	0	main
oma	doc_491521501782_item	3731996	et	0	main
eesti	doc_491521501782_item	3731997	et	0	main
keele	doc_491521501782_item	3731998	et	0	main
oskusi	doc_491521501782_item	3731999	et	0	main
keelekursustel	doc_491521501782_item	3732000	et	0	main
järelikult	doc_491521501782_item	3732001	et	0	main
enamus	doc_491521501782_item	3732002	et	0	main
õpilasi	doc_491521501782_item	3732003	et	0	main
piirdub	doc_491521501782_item	3732004	et	0	main
koolis	doc_491521501782_item	3732005	et	0	main
saadud	doc_491521501782_item	3732006	et	0	main
teadmistega	doc_491521501782_item	3732007	et	0	main
mida	doc_491521501782_item	3732008	et	0	main
nad	doc_491521501782_item	3732009	et	0	main
ei	doc_491521501782_item	3732010	et	0	main
kinnita	doc_491521501782_item	3732011	et	0	main
praktikal	doc_491521501782_item	3732012	et	0	main
seega	doc_491521501782_item	3732013	et	0	main
võib	doc_491521501782_item	3732014	et	0	main
hinnata	doc_491521501782_item	3732015	et	0	main
nende	doc_491521501782_item	3732016	et	0	main
keeleoskust	doc_491521501782_item	3732017	et	0	main
hindega	doc_491521501782_item	3732018	et	0	main
kasin	doc_491521501782_item	3732019	et	0	main
õpilaste	doc_491521501782_item	3732020	et	0	main
kirjatöödes	doc_491521501782_item	3732021	et	0	main
esineb	doc_491521501782_item	3732022	et	0	main
palju	doc_491521501782_item	3732023	et	0	main
vigu	doc_491521501782_item	3732024	et	0	main
mille	doc_491521501782_item	3732025	et	0	main
iseloom	doc_491521501782_item	3732026	et	0	main
on	doc_491521501782_item	3732027	et	0	main
väga	doc_491521501782_item	3732028	et	0	main
erinev	doc_491521501782_item	3732029	et	0	main
mõned	doc_491521501782_item	3732030	et	0	main
õpilased	doc_491521501782_item	3732031	et	0	main
lubavad	doc_491521501782_item	3732032	et	0	main
endale	doc_491521501782_item	3732033	et	0	main
teha	doc_491521501782_item	3732034	et	0	main
eksimusi	doc_491521501782_item	3732035	et	0	main
mis	doc_491521501782_item	3732036	et	0	main
ei	doc_491521501782_item	3732037	et	0	main
tohiks	doc_491521501782_item	3732038	et	0	main
juba	doc_491521501782_item	3732039	et	0	main
esineda	doc_491521501782_item	3732040	et	0	main
kaheteistkümnenda	doc_491521501782_item	3732041	et	0	main
klassi	doc_491521501782_item	3732042	et	0	main
õpilase	doc_491521501782_item	3732043	et	0	main
töös	doc_491521501782_item	3732044	et	0	main
näiteks	doc_491521501782_item	3732045	et	0	main
mõnes	doc_491521501782_item	3732046	et	0	main
kirjandis	doc_491521501782_item	3732047	et	0	main
tulevad	doc_491521501782_item	3732048	et	0	main
ette	doc_491521501782_item	3732049	et	0	main
verbivormide	doc_491521501782_item	3732050	et	0	main
moodustusvead	doc_491521501782_item	3732051	et	0	main
minevik	doc_491521501782_item	3732052	et	0	main
see	doc_491521501782_item	3732053	et	0	main
on	doc_491521501782_item	3732054	et	0	main
asi	doc_491521501782_item	3732055	et	0	main
mis	doc_491521501782_item	3732056	et	0	main
oleb	doc_491521501782_item	3732057	et	0	main
igal	doc_491521501782_item	3732058	et	0	main
inimesel	doc_491521501782_item	3732059	et	0	main
paljud	doc_491521501782_item	3732060	et	0	main
inimesed	doc_491521501782_item	3732061	et	0	main
ei	doc_491521501782_item	3732062	et	0	main
tahavad	doc_491521501782_item	3732063	et	0	main
mäletada	doc_491521501782_item	3732064	et	0	main
oma	doc_491521501782_item	3732065	et	0	main
minevikku	doc_491521501782_item	3732066	et	0	main
ja	doc_491521501782_item	3732067	et	0	main
tahavad	doc_491521501782_item	3732068	et	0	main
elada	doc_491521501782_item	3732069	et	0	main
ainult	doc_491521501782_item	3732070	et	0	main
tänases	doc_491521501782_item	3732071	et	0	main
päevas	doc_491521501782_item	3732072	et	0	main
palju	doc_491521501782_item	3732073	et	0	main
vigu	doc_491521501782_item	3732074	et	0	main
me	doc_491521501782_item	3732075	et	0	main
ei	doc_491521501782_item	3732076	et	0	main
teeksime	doc_491521501782_item	3732077	et	0	main
kui	doc_491521501782_item	3732078	et	0	main
mäletaksime	doc_491521501782_item	3732079	et	0	main
minevikku	doc_491521501782_item	3732080	et	0	main
inimesd	doc_491521501782_item	3732081	et	0	main
vigadest	doc_491521501782_item	3732082	et	0	main
õppima	doc_491521501782_item	3732083	et	0	main
mõnede	doc_491521501782_item	3732084	et	0	main
õpilaste	doc_491521501782_item	3732085	et	0	main
töödes	doc_491521501782_item	3732086	et	0	main
esinesid	doc_491521501782_item	3732087	et	0	main
vead	doc_491521501782_item	3732088	et	0	main
mida	doc_491521501782_item	3732089	et	0	main
on	doc_491521501782_item	3732090	et	0	main
raske	doc_491521501782_item	3732091	et	0	main
nii	doc_491521501782_item	3732092	et	0	main
liigitada	doc_491521501782_item	3732093	et	0	main
kui	doc_491521501782_item	3732094	et	0	main
ka	doc_491521501782_item	3732095	et	0	main
nende	doc_491521501782_item	3732096	et	0	main
põhjust	doc_491521501782_item	3732097	et	0	main
välja	doc_491521501782_item	3732098	et	0	main
selgitada	doc_491521501782_item	3732099	et	0	main
nii	doc_491521501782_item	3732100	et	0	main
rääkis	doc_491521501782_item	3732101	et	0	main
ühe	doc_491521501782_item	3732102	et	0	main
kirjandi	doc_491521501782_item	3732103	et	0	main
autor	doc_491521501782_item	3732104	et	0	main
oma	doc_491521501782_item	3732105	et	0	main
lapsepõlvest	doc_491521501782_item	3732106	et	0	main
kasutades	doc_491521501782_item	3732107	et	0	main
ainult	doc_491521501782_item	3732108	et	0	main
täisminevikulisi	doc_491521501782_item	3732109	et	0	main
lauseid	doc_491521501782_item	3732110	et	0	main
me	doc_491521501782_item	3732111	et	0	main
oleme	doc_491521501782_item	3732112	et	0	main
armastanud	doc_491521501782_item	3732113	et	0	main
mängida	doc_491521501782_item	3732114	et	0	main
oma	doc_491521501782_item	3732115	et	0	main
hoovis	doc_491521501782_item	3732116	et	0	main
me	doc_491521501782_item	3732117	et	0	main
oleme	doc_491521501782_item	3732118	et	0	main
jooksnud	doc_491521501782_item	3732119	et	0	main
kabeli	doc_491521501782_item	3732120	et	0	main
ümber	doc_491521501782_item	3732121	et	0	main
ja	doc_491521501782_item	3732122	et	0	main
mänginud	doc_491521501782_item	3732123	et	0	main
kulli	doc_491521501782_item	3732124	et	0	main
vaatamata	doc_491521501782_item	3732125	et	0	main
sellele	doc_491521501782_item	3732126	et	0	main
et	doc_491521501782_item	3732127	et	0	main
vigade	doc_491521501782_item	3732128	et	0	main
iseloom	doc_491521501782_item	3732129	et	0	main
oli	doc_491521501782_item	3732130	et	0	main
väga	doc_491521501782_item	3732131	et	0	main
erinev	doc_491521501782_item	3732132	et	0	main
ei	doc_491521501782_item	3732133	et	0	main
tekkinud	doc_491521501782_item	3732134	et	0	main
raskusi	doc_491521501782_item	3732135	et	0	main
nende	doc_491521501782_item	3732136	et	0	main
liigitamisega	doc_491521501782_item	3732137	et	0	main
kõige	doc_491521501782_item	3732138	et	0	main
levinumad	doc_491521501782_item	3732139	et	0	main
olid	doc_491521501782_item	3732140	et	0	main
verbi	doc_491521501782_item	3732141	et	0	main
rektsiooni	doc_491521501782_item	3732142	et	0	main
vead	doc_491521501782_item	3732143	et	0	main
kolmekümneüheksa	doc_491521501782_item	3732144	et	0	main
kirjandi	doc_491521501782_item	3732145	et	0	main
seast	doc_491521501782_item	3732146	et	0	main
ei	doc_491521501782_item	3732147	et	0	main
olnud	doc_491521501782_item	3732148	et	0	main
ühtegi	doc_491521501782_item	3732149	et	0	main
tööd	doc_491521501782_item	3732150	et	0	main
kus	doc_491521501782_item	3732151	et	0	main
see	doc_491521501782_item	3732152	et	0	main
viga	doc_491521501782_item	3732153	et	0	main
ei	doc_491521501782_item	3732154	et	0	main
oleks	doc_491521501782_item	3732155	et	0	main
esinenud	doc_491521501782_item	3732156	et	0	main
peaaegu	doc_491521501782_item	3732157	et	0	main
igas	doc_491521501782_item	3732158	et	0	main
teises	doc_491521501782_item	3732159	et	0	main
kirjandis	doc_491521501782_item	3732160	et	0	main
kasutati	doc_491521501782_item	3732161	et	0	main
väljendit	doc_491521501782_item	3732162	et	0	main
me	doc_491521501782_item	3732163	et	0	main
õpime	doc_491521501782_item	3732164	et	0	main
oma	doc_491521501782_item	3732165	et	0	main
vigadest	doc_491521501782_item	3732166	et	0	main
selle	doc_491521501782_item	3732167	et	0	main
lause	doc_491521501782_item	3732168	et	0	main
erivariandid	doc_491521501782_item	3732169	et	0	main
on	doc_491521501782_item	3732170	et	0	main
järgmised	doc_491521501782_item	3732171	et	0	main
me	doc_491521501782_item	3732172	et	0	main
võime	doc_491521501782_item	3732173	et	0	main
õppida	doc_491521501782_item	3732174	et	0	main
oma	doc_491521501782_item	3732175	et	0	main
vigadel	doc_491521501782_item	3732176	et	0	main
vrd	doc_491521501782_item	3732177	et	0	main
venekeelsega	doc_491521501782_item	3732178	et	0	main
учимся	doc_491521501782_item	3732179	et	0	main
на	doc_491521501782_item	3732180	et	0	main
свойх	doc_491521501782_item	3732181	et	0	main
ошибках	doc_491521501782_item	3732182	et	0	main
kuna	doc_491521501782_item	3732183	et	0	main
õpilastel	doc_491521501782_item	3732184	et	0	main
puudus	doc_491521501782_item	3732185	et	0	main
pidev	doc_491521501782_item	3732186	et	0	main
keelepraktika	doc_491521501782_item	3732187	et	0	main
siis	doc_491521501782_item	3732188	et	0	main
nad	doc_491521501782_item	3732189	et	0	main
kandsid	doc_491521501782_item	3732190	et	0	main
venekeelseid	doc_491521501782_item	3732191	et	0	main
grammatika	doc_491521501782_item	3732192	et	0	main
reegleid	doc_491521501782_item	3732193	et	0	main
üle	doc_491521501782_item	3732194	et	0	main
eestikeelsetesse	doc_491521501782_item	3732195	et	0	main
analoogia	doc_491521501782_item	3732196	et	0	main
abil	doc_491521501782_item	3732197	et	0	main
tegid	doc_491521501782_item	3732198	et	0	main
otsetõlget	doc_491521501782_item	3732199	et	0	main
me	doc_491521501782_item	3732200	et	0	main
kõik	doc_491521501782_item	3732201	et	0	main
õpime	doc_491521501782_item	3732202	et	0	main
oma	doc_491521501782_item	3732203	et	0	main
vigadel	doc_491521501782_item	3732204	et	0	main
me	doc_491521501782_item	3732205	et	0	main
õpime	doc_491521501782_item	3732206	et	0	main
oma	doc_491521501782_item	3732207	et	0	main
vigade	doc_491521501782_item	3732208	et	0	main
peal	doc_491521501782_item	3732209	et	0	main
ainult	doc_491521501782_item	3732210	et	0	main
ühes	doc_491521501782_item	3732211	et	0	main
lühikirjandis	doc_491521501782_item	3732212	et	0	main
oli	doc_491521501782_item	3732213	et	0	main
see	doc_491521501782_item	3732214	et	0	main
lause	doc_491521501782_item	3732215	et	0	main
teistsuguses	doc_491521501782_item	3732216	et	0	main
variandis	doc_491521501782_item	3732217	et	0	main
oma	doc_491521501782_item	3732218	et	0	main
vigades	doc_491521501782_item	3732219	et	0	main
inimesed	doc_491521501782_item	3732220	et	0	main
õpivad	doc_491521501782_item	3732221	et	0	main
leidus	doc_491521501782_item	3732222	et	0	main
ka	doc_491521501782_item	3732223	et	0	main
üks	doc_491521501782_item	3732224	et	0	main
õige	doc_491521501782_item	3732225	et	0	main
variant	doc_491521501782_item	3732226	et	0	main
samas	doc_491521501782_item	3732227	et	0	main
aga	doc_491521501782_item	3732228	et	0	main
ei	doc_491521501782_item	3732229	et	0	main
olnud	doc_491521501782_item	3732230	et	0	main
see	doc_491521501782_item	3732231	et	0	main
lause	doc_491521501782_item	3732232	et	0	main
korrektne	doc_491521501782_item	3732233	et	0	main
inimesed	doc_491521501782_item	3732234	et	0	main
vigadest	doc_491521501782_item	3732235	et	0	main
õppima	doc_491521501782_item	3732236	et	0	main
järgmised	doc_491521501782_item	3732237	et	0	main
rektsioonid	doc_491521501782_item	3732238	et	0	main
milles	doc_491521501782_item	3732239	et	0	main
vene	doc_491521501782_item	3732240	et	0	main
õpilased	doc_491521501782_item	3732241	et	0	main
eksisid	doc_491521501782_item	3732242	et	0	main
kas	doc_491521501782_item	3732243	et	0	main
sa	doc_491521501782_item	3732244	et	0	main
käid	doc_491521501782_item	3732245	et	0	main
külas	doc_491521501782_item	3732246	et	0	main
sõprade	doc_491521501782_item	3732247	et	0	main
juurde	doc_491521501782_item	3732248	et	0	main
vrd	doc_491521501782_item	3732249	et	0	main
venekeelsega	doc_491521501782_item	3732250	et	0	main
ходить	doc_491521501782_item	3732251	et	0	main
куда	doc_491521501782_item	3732252	et	0	main
kuhu	doc_491521501782_item	3732253	et	0	main
в	doc_491521501782_item	3732254	et	0	main
гости	doc_491521501782_item	3732255	et	0	main
sellepärast	doc_491521501782_item	3732256	et	0	main
sõna	doc_491521501782_item	3732257	et	0	main
külas	doc_491521501782_item	3732258	et	0	main
on	doc_491521501782_item	3732259	et	0	main
õiges	doc_491521501782_item	3732260	et	0	main
vormis	doc_491521501782_item	3732261	et	0	main
aga	doc_491521501782_item	3732262	et	0	main
samas	doc_491521501782_item	3732263	et	0	main
к	doc_491521501782_item	3732264	et	0	main
кому	doc_491521501782_item	3732265	et	0	main
kelle	doc_491521501782_item	3732266	et	0	main
juurde	doc_491521501782_item	3732267	et	0	main
see	doc_491521501782_item	3732268	et	0	main
viib	doc_491521501782_item	3732269	et	0	main
depresioonisse	doc_491521501782_item	3732270	et	0	main
vrd	doc_491521501782_item	3732271	et	0	main
venekeelsega	doc_491521501782_item	3732272	et	0	main
вводщить	doc_491521501782_item	3732273	et	0	main
в	doc_491521501782_item	3732274	et	0	main
депрессию	doc_491521501782_item	3732275	et	0	main
ta	doc_491521501782_item	3732276	et	0	main
unustab	doc_491521501782_item	3732277	et	0	main
oma	doc_491521501782_item	3732278	et	0	main
probleemidest	doc_491521501782_item	3732279	et	0	main
vrd	doc_491521501782_item	3732280	et	0	main
venekeelsega	doc_491521501782_item	3732281	et	0	main
забывает	doc_491521501782_item	3732282	et	0	main
о	doc_491521501782_item	3732283	et	0	main
своих	doc_491521501782_item	3732284	et	0	main
проблемах	doc_491521501782_item	3732285	et	0	main
aga	doc_491521501782_item	3732286	et	0	main
saame	doc_491521501782_item	3732287	et	0	main
arvutada	doc_491521501782_item	3732288	et	0	main
kokku	doc_491521501782_item	3732289	et	0	main
kui	doc_491521501782_item	3732290	et	0	main
palju	doc_491521501782_item	3732291	et	0	main
vigu	doc_491521501782_item	3732292	et	0	main
me	doc_491521501782_item	3732293	et	0	main
ei	doc_491521501782_item	3732294	et	0	main
teeks	doc_491521501782_item	3732295	et	0	main
kui	doc_491521501782_item	3732296	et	0	main
mäletaksime	doc_491521501782_item	3732297	et	0	main
minevikust	doc_491521501782_item	3732298	et	0	main
vrd	doc_491521501782_item	3732299	et	0	main
venekeelsega	doc_491521501782_item	3732300	et	0	main
помнили	doc_491521501782_item	3732301	et	0	main
бы	doc_491521501782_item	3732302	et	0	main
о	doc_491521501782_item	3732303	et	0	main
прошлом	doc_491521501782_item	3732304	et	0	main
nad	doc_491521501782_item	3732305	et	0	main
ei	doc_491521501782_item	3732306	et	0	main
saa	doc_491521501782_item	3732307	et	0	main
ühe	doc_491521501782_item	3732308	et	0	main
arvamuse	doc_491521501782_item	3732309	et	0	main
juurde	doc_491521501782_item	3732310	et	0	main
tulla	doc_491521501782_item	3732311	et	0	main
vrd	doc_491521501782_item	3732312	et	0	main
venekeelsega	doc_491521501782_item	3732313	et	0	main
прийти	doc_491521501782_item	3732314	et	0	main
к	doc_491521501782_item	3732315	et	0	main
одному	doc_491521501782_item	3732316	et	0	main
мнению	doc_491521501782_item	3732317	et	0	main
kas	doc_491521501782_item	3732318	et	0	main
see	doc_491521501782_item	3732319	et	0	main
aeg	doc_491521501782_item	3732320	et	0	main
võib	doc_491521501782_item	3732321	et	0	main
unustada	doc_491521501782_item	3732322	et	0	main
teiseks	doc_491521501782_item	3732323	et	0	main
kõige	doc_491521501782_item	3732324	et	0	main
suuremaks	doc_491521501782_item	3732325	et	0	main
vigade	doc_491521501782_item	3732326	et	0	main
rühmaks	doc_491521501782_item	3732327	et	0	main
võib	doc_491521501782_item	3732328	et	0	main
nimetada	doc_491521501782_item	3732329	et	0	main
ma	doc_491521501782_item	3732330	et	0	main
ja	doc_491521501782_item	3732331	et	0	main
da	doc_491521501782_item	3732332	et	0	main
infinitiivide	doc_491521501782_item	3732333	et	0	main
vaheldumist	doc_491521501782_item	3732334	et	0	main
ta	doc_491521501782_item	3732335	et	0	main
uuesti	doc_491521501782_item	3732336	et	0	main
õpib	doc_491521501782_item	3732337	et	0	main
elada	doc_491521501782_item	3732338	et	0	main
ja	doc_491521501782_item	3732339	et	0	main
armastada	doc_491521501782_item	3732340	et	0	main
ma	doc_491521501782_item	3732341	et	0	main
olen	doc_491521501782_item	3732342	et	0	main
nõus	doc_491521501782_item	3732343	et	0	main
väitega	doc_491521501782_item	3732344	et	0	main
et	doc_491521501782_item	3732345	et	0	main
inimesed	doc_491521501782_item	3732346	et	0	main
peavad	doc_491521501782_item	3732347	et	0	main
mäletada	doc_491521501782_item	3732348	et	0	main
oma	doc_491521501782_item	3732349	et	0	main
minevikku	doc_491521501782_item	3732350	et	0	main
kas	doc_491521501782_item	3732351	et	0	main
me	doc_491521501782_item	3732352	et	0	main
oskaks	doc_491521501782_item	3732353	et	0	main
töötama	doc_491521501782_item	3732354	et	0	main
kui	doc_491521501782_item	3732355	et	0	main
me	doc_491521501782_item	3732356	et	0	main
ei	doc_491521501782_item	3732357	et	0	main
oleks	doc_491521501782_item	3732358	et	0	main
õppinud	doc_491521501782_item	3732359	et	0	main
meil	doc_491521501782_item	3732360	et	0	main
on	doc_491521501782_item	3732361	et	0	main
ainult	doc_491521501782_item	3732362	et	0	main
üks	doc_491521501782_item	3732363	et	0	main
elu	doc_491521501782_item	3732364	et	0	main
ja	doc_491521501782_item	3732365	et	0	main
me	doc_491521501782_item	3732366	et	0	main
oleme	doc_491521501782_item	3732367	et	0	main
kohustatud	doc_491521501782_item	3732368	et	0	main
mäletada	doc_491521501782_item	3732369	et	0	main
kõike	doc_491521501782_item	3732370	et	0	main
mis	doc_491521501782_item	3732371	et	0	main
juhtus	doc_491521501782_item	3732372	et	0	main
meie	doc_491521501782_item	3732373	et	0	main
elus	doc_491521501782_item	3732374	et	0	main
kolmandasse	doc_491521501782_item	3732375	et	0	main
vigade	doc_491521501782_item	3732376	et	0	main
rühma	doc_491521501782_item	3732377	et	0	main
kuuluvad	doc_491521501782_item	3732378	et	0	main
käändelised	doc_491521501782_item	3732379	et	0	main
vead	doc_491521501782_item	3732380	et	0	main
ilma	doc_491521501782_item	3732381	et	0	main
mineviku	doc_491521501782_item	3732382	et	0	main
meil	doc_491521501782_item	3732383	et	0	main
ei	doc_491521501782_item	3732384	et	0	main
või	doc_491521501782_item	3732385	et	0	main
olla	doc_491521501782_item	3732386	et	0	main
tulevikku	doc_491521501782_item	3732387	et	0	main
vrd	doc_491521501782_item	3732388	et	0	main
venekeelsega	doc_491521501782_item	3732389	et	0	main
без	doc_491521501782_item	3732390	et	0	main
прошлого	doc_491521501782_item	3732391	et	0	main
õpilane	doc_491521501782_item	3732392	et	0	main
piirdus	doc_491521501782_item	3732393	et	0	main
ainult	doc_491521501782_item	3732394	et	0	main
eitava	doc_491521501782_item	3732395	et	0	main
eessõna	doc_491521501782_item	3732396	et	0	main
ilma	doc_491521501782_item	3732397	et	0	main
kasutamisega	doc_491521501782_item	3732398	et	0	main
toetudes	doc_491521501782_item	3732399	et	0	main
venekeelsele	doc_491521501782_item	3732400	et	0	main
grammatuikale	doc_491521501782_item	3732401	et	0	main
mälestused	doc_491521501782_item	3732402	et	0	main
sõltuvad	doc_491521501782_item	3732403	et	0	main
sellest	doc_491521501782_item	3732404	et	0	main
kus	doc_491521501782_item	3732405	et	0	main
me	doc_491521501782_item	3732406	et	0	main
elame	doc_491521501782_item	3732407	et	0	main
ja	doc_491521501782_item	3732408	et	0	main
millises	doc_491521501782_item	3732409	et	0	main
ajas	doc_491521501782_item	3732410	et	0	main
vrd	doc_491521501782_item	3732411	et	0	main
venekeelse	doc_491521501782_item	3732412	et	0	main
tõlkega	doc_491521501782_item	3732413	et	0	main
в	doc_491521501782_item	3732414	et	0	main
какое	doc_491521501782_item	3732415	et	0	main
время	doc_491521501782_item	3732416	et	0	main
mulle	doc_491521501782_item	3732417	et	0	main
meeldib	doc_491521501782_item	3732418	et	0	main
meenutada	doc_491521501782_item	3732419	et	0	main
lapsepõlve	doc_491521501782_item	3732420	et	0	main
momendid	doc_491521501782_item	3732421	et	0	main
vrd	doc_491521501782_item	3732422	et	0	main
venekeelsega	doc_491521501782_item	3732423	et	0	main
вспоминать	doc_491521501782_item	3732424	et	0	main
момент	doc_491521501782_item	3732425	et	0	main
ы	doc_491521501782_item	3732426	et	0	main
mitmuses	doc_491521501782_item	3732427	et	0	main
mulle	doc_491521501782_item	3732428	et	0	main
meeldib	doc_491521501782_item	3732429	et	0	main
võrrelda	doc_491521501782_item	3732430	et	0	main
vanemate	doc_491521501782_item	3732431	et	0	main
aeg	doc_491521501782_item	3732432	et	0	main
meie	doc_491521501782_item	3732433	et	0	main
omaga	doc_491521501782_item	3732434	et	0	main
täna	doc_491521501782_item	3732435	et	0	main
ma	doc_491521501782_item	3732436	et	0	main
vaatame	doc_491521501782_item	3732437	et	0	main
telerist	doc_491521501782_item	3732438	et	0	main
kuulame	doc_491521501782_item	3732439	et	0	main
raadiost	doc_491521501782_item	3732440	et	0	main
või	doc_491521501782_item	3732441	et	0	main
omadest	doc_491521501782_item	3732442	et	0	main
vanematest	doc_491521501782_item	3732443	et	0	main
ja	doc_491521501782_item	3732444	et	0	main
vanavanematest	doc_491521501782_item	3732445	et	0	main
jutustusi	doc_491521501782_item	3732446	et	0	main
mis	doc_491521501782_item	3732447	et	0	main
räägivad	doc_491521501782_item	3732448	et	0	main
minevikust	doc_491521501782_item	3732449	et	0	main
lühikirjandites	doc_491521501782_item	3732450	et	0	main
leidus	doc_491521501782_item	3732451	et	0	main
väga	doc_491521501782_item	3732452	et	0	main
palju	doc_491521501782_item	3732453	et	0	main
vigu	doc_491521501782_item	3732454	et	0	main
mis	doc_491521501782_item	3732455	et	0	main
olid	doc_491521501782_item	3732456	et	0	main
seotud	doc_491521501782_item	3732457	et	0	main
õige	doc_491521501782_item	3732458	et	0	main
tõlkesõna	doc_491521501782_item	3732459	et	0	main
valikuga	doc_491521501782_item	3732460	et	0	main
õpilastel	doc_491521501782_item	3732461	et	0	main
oli	doc_491521501782_item	3732462	et	0	main
raske	doc_491521501782_item	3732463	et	0	main
tabada	doc_491521501782_item	3732464	et	0	main
õiget	doc_491521501782_item	3732465	et	0	main
tähendust	doc_491521501782_item	3732466	et	0	main
järgmistel	doc_491521501782_item	3732467	et	0	main
sõnadel	doc_491521501782_item	3732468	et	0	main
nagu	doc_491521501782_item	3732469	et	0	main
kui	doc_491521501782_item	3732470	et	0	main
mineviku	doc_491521501782_item	3732471	et	0	main
mäletamisest	doc_491521501782_item	3732472	et	0	main
kirjutasid	doc_491521501782_item	3732473	et	0	main
sellised	doc_491521501782_item	3732474	et	0	main
eesti	doc_491521501782_item	3732475	et	0	main
luuletajad	doc_491521501782_item	3732476	et	0	main
kui	doc_491521501782_item	3732477	et	0	main
anna	doc_491521501782_item	3732478	et	0	main
haava	doc_491521501782_item	3732479	et	0	main
juhan	doc_491521501782_item	3732480	et	0	main
liiv	doc_491521501782_item	3732481	et	0	main
nagu	doc_491521501782_item	3732482	et	0	main
kuidas	doc_491521501782_item	3732483	et	0	main
kuidas	doc_491521501782_item	3732484	et	0	main
a	doc_491521501782_item	3732485	et	0	main
haava	doc_491521501782_item	3732486	et	0	main
luuletuse	doc_491521501782_item	3732487	et	0	main
siin	doc_491521501782_item	3732488	et	0	main
kirjutatakse	doc_491521501782_item	3732489	et	0	main
orjusest	doc_491521501782_item	3732490	et	0	main
milles	doc_491521501782_item	3732491	et	0	main
olid	doc_491521501782_item	3732492	et	0	main
eestlased	doc_491521501782_item	3732493	et	0	main
mitte	doc_491521501782_item	3732494	et	0	main
ei	doc_491521501782_item	3732495	et	0	main
pole	doc_491521501782_item	3732496	et	0	main
ilmaaegu	doc_491521501782_item	3732497	et	0	main
räägitakse	doc_491521501782_item	3732498	et	0	main
et	doc_491521501782_item	3732499	et	0	main
pole	doc_491521501782_item	3732500	et	0	main
tulevikku	doc_491521501782_item	3732501	et	0	main
minevikuta	doc_491521501782_item	3732502	et	0	main
tuleb	doc_491521501782_item	3732503	et	0	main
välja	doc_491521501782_item	3732504	et	0	main
et	doc_491521501782_item	3732505	et	0	main
minevik	doc_491521501782_item	3732506	et	0	main
mitte	doc_491521501782_item	3732507	et	0	main
ainult	doc_491521501782_item	3732508	et	0	main
mälestused	doc_491521501782_item	3732509	et	0	main
aga	doc_491521501782_item	3732510	et	0	main
see	doc_491521501782_item	3732511	et	0	main
on	doc_491521501782_item	3732512	et	0	main
suur	doc_491521501782_item	3732513	et	0	main
saladus	doc_491521501782_item	3732514	et	0	main
inimeste	doc_491521501782_item	3732515	et	0	main
jaoks	doc_491521501782_item	3732516	et	0	main
inimene	doc_491521501782_item	3732517	et	0	main
peab	doc_491521501782_item	3732518	et	0	main
mäletama	doc_491521501782_item	3732519	et	0	main
ka	doc_491521501782_item	3732520	et	0	main
oma	doc_491521501782_item	3732521	et	0	main
halba	doc_491521501782_item	3732522	et	0	main
minevikku	doc_491521501782_item	3732523	et	0	main
et	doc_491521501782_item	3732524	et	0	main
näha	doc_491521501782_item	3732525	et	0	main
oma	doc_491521501782_item	3732526	et	0	main
vigu	doc_491521501782_item	3732527	et	0	main
ja	doc_491521501782_item	3732528	et	0	main
püüda	doc_491521501782_item	3732529	et	0	main
ei	doc_491521501782_item	3732530	et	0	main
korrata	doc_491521501782_item	3732531	et	0	main
neid	doc_491521501782_item	3732532	et	0	main
tulevikus	doc_491521501782_item	3732533	et	0	main
ligi	doc_491521501782_item	3732534	et	0	main
peaaegu	doc_491521501782_item	3732535	et	0	main
me	doc_491521501782_item	3732536	et	0	main
pöördume	doc_491521501782_item	3732537	et	0	main
minevikku	doc_491521501782_item	3732538	et	0	main
ligi	doc_491521501782_item	3732539	et	0	main
igapäev	doc_491521501782_item	3732540	et	0	main
muu	doc_491521501782_item	3732541	et	0	main
erinev	doc_491521501782_item	3732542	et	0	main
ma	doc_491521501782_item	3732543	et	0	main
mõistan	doc_491521501782_item	3732544	et	0	main
et	doc_491521501782_item	3732545	et	0	main
nende	doc_491521501782_item	3732546	et	0	main
aeg	doc_491521501782_item	3732547	et	0	main
oli	doc_491521501782_item	3732548	et	0	main
muu	doc_491521501782_item	3732549	et	0	main
lause	doc_491521501782_item	3732550	et	0	main
sõnajärg	doc_491521501782_item	3732551	et	0	main
mis	doc_491521501782_item	3732552	et	0	main
see	doc_491521501782_item	3732553	et	0	main
on	doc_491521501782_item	3732554	et	0	main
minevik	doc_491521501782_item	3732555	et	0	main
küsimus	doc_491521501782_item	3732556	et	0	main
on	doc_491521501782_item	3732557	et	0	main
esitatud	doc_491521501782_item	3732558	et	0	main
toetudes	doc_491521501782_item	3732559	et	0	main
eelkõige	doc_491521501782_item	3732560	et	0	main
intonatsioonile	doc_491521501782_item	3732561	et	0	main
esitades	doc_491521501782_item	3732562	et	0	main
retoorilist	doc_491521501782_item	3732563	et	0	main
küsimust	doc_491521501782_item	3732564	et	0	main
vene	doc_491521501782_item	3732565	et	0	main
keeles	doc_491521501782_item	3732566	et	0	main
ei	doc_491521501782_item	3732567	et	0	main
ole	doc_491521501782_item	3732568	et	0	main
sõnade	doc_491521501782_item	3732569	et	0	main
järjekord	doc_491521501782_item	3732570	et	0	main
lauses	doc_491521501782_item	3732571	et	0	main
nii	doc_491521501782_item	3732572	et	0	main
oluline	doc_491521501782_item	3732573	et	0	main
nagu	doc_491521501782_item	3732574	et	0	main
eesti	doc_491521501782_item	3732575	et	0	main
keeles	doc_491521501782_item	3732576	et	0	main
räägitakse	doc_491521501782_item	3732577	et	0	main
et	doc_491521501782_item	3732578	et	0	main
targad	doc_491521501782_item	3732579	et	0	main
inimesed	doc_491521501782_item	3732580	et	0	main
on	doc_491521501782_item	3732581	et	0	main
sellepärast	doc_491521501782_item	3732582	et	0	main
targad	doc_491521501782_item	3732583	et	0	main
et	doc_491521501782_item	3732584	et	0	main
kõik	doc_491521501782_item	3732585	et	0	main
oma	doc_491521501782_item	3732586	et	0	main
vigu	doc_491521501782_item	3732587	et	0	main
mäletavad	doc_491521501782_item	3732588	et	0	main
kirjavahemärgid	doc_491521501782_item	3732589	et	0	main
vene	doc_491521501782_item	3732590	et	0	main
koolidest	doc_491521501782_item	3732591	et	0	main
õpilased	doc_491521501782_item	3732592	et	0	main
kasutavad	doc_491521501782_item	3732593	et	0	main
kirjavahemärke	doc_491521501782_item	3732594	et	0	main
venekeele	doc_491521501782_item	3732595	et	0	main
grammatika	doc_491521501782_item	3732596	et	0	main
kohaselt	doc_491521501782_item	3732597	et	0	main
paljud	doc_491521501782_item	3732598	et	0	main
inimesed	doc_491521501782_item	3732599	et	0	main
arvavad	doc_491521501782_item	3732600	et	0	main
et	doc_491521501782_item	3732601	et	0	main
see	doc_491521501782_item	3732602	et	0	main
on	doc_491521501782_item	3732603	et	0	main
nii	doc_491521501782_item	3732604	et	0	main
vrd	doc_491521501782_item	3732605	et	0	main
venekeelsega	doc_491521501782_item	3732606	et	0	main
многие	doc_491521501782_item	3732607	et	0	main
люди	doc_491521501782_item	3732608	et	0	main
считают	doc_491521501782_item	3732609	et	0	main
что	doc_491521501782_item	3732610	et	0	main
это	doc_491521501782_item	3732611	et	0	main
так	doc_491521501782_item	3732612	et	0	main
и	doc_491521501782_item	3732613	et	0	main
есть	doc_491521501782_item	3732614	et	0	main
ahaava	doc_491521501782_item	3732615	et	0	main
oma	doc_491521501782_item	3732616	et	0	main
luuletustes	doc_491521501782_item	3732617	et	0	main
kirjutas	doc_491521501782_item	3732618	et	0	main
et	doc_491521501782_item	3732619	et	0	main
eesti	doc_491521501782_item	3732620	et	0	main
rahvus	doc_491521501782_item	3732621	et	0	main
oli	doc_491521501782_item	3732622	et	0	main
orjuses	doc_491521501782_item	3732623	et	0	main
rohkem	doc_491521501782_item	3732624	et	0	main
kui	doc_491521501782_item	3732625	et	0	main
kuussada	doc_491521501782_item	3732626	et	0	main
aastat	doc_491521501782_item	3732627	et	0	main
intransitiivsed	doc_491521501782_item	3732628	et	0	main
ja	doc_491521501782_item	3732629	et	0	main
transitiivsed	doc_491521501782_item	3732630	et	0	main
verbid	doc_491521501782_item	3732631	et	0	main
eduard	doc_491521501782_item	3732632	et	0	main
bornhöhe	doc_491521501782_item	3732633	et	0	main
romaanist	doc_491521501782_item	3732634	et	0	main
tasuja	doc_491521501782_item	3732635	et	0	main
saame	doc_491521501782_item	3732636	et	0	main
teada	doc_491521501782_item	3732637	et	0	main
jüriöö	doc_491521501782_item	3732638	et	0	main
ülestõusust	doc_491521501782_item	3732639	et	0	main
kuidas	doc_491521501782_item	3732640	et	0	main
see	doc_491521501782_item	3732641	et	0	main
juhtus	doc_491521501782_item	3732642	et	0	main
miks	doc_491521501782_item	3732643	et	0	main
algas	doc_491521501782_item	3732644	et	0	main
ja	doc_491521501782_item	3732645	et	0	main
kuidas	doc_491521501782_item	3732646	et	0	main
lõpetas	doc_491521501782_item	3732647	et	0	main
taolised	doc_491521501782_item	3732648	et	0	main
verbid	doc_491521501782_item	3732649	et	0	main
pakuvad	doc_491521501782_item	3732650	et	0	main
raskusi	doc_491521501782_item	3732651	et	0	main
nii	doc_491521501782_item	3732652	et	0	main
vene	doc_491521501782_item	3732653	et	0	main
kui	doc_491521501782_item	3732654	et	0	main
ka	doc_491521501782_item	3732655	et	0	main
eesti	doc_491521501782_item	3732656	et	0	main
kooli	doc_491521501782_item	3732657	et	0	main
õpilastele	doc_491521501782_item	3732658	et	0	main
vigade	doc_491521501782_item	3732659	et	0	main
vältimiseks	doc_491521501782_item	3732660	et	0	main
on	doc_491521501782_item	3732661	et	0	main
vaja	doc_491521501782_item	3732662	et	0	main
neid	doc_491521501782_item	3732663	et	0	main
ainult	doc_491521501782_item	3732664	et	0	main
pähe	doc_491521501782_item	3732665	et	0	main
õppida	doc_491521501782_item	3732666	et	0	main
kvantorsõna	doc_491521501782_item	3732667	et	0	main
rektsiooni	doc_491521501782_item	3732668	et	0	main
vead	doc_491521501782_item	3732669	et	0	main
majas	doc_491521501782_item	3732670	et	0	main
elas	doc_491521501782_item	3732671	et	0	main
palju	doc_491521501782_item	3732672	et	0	main
last	doc_491521501782_item	3732673	et	0	main
ma	doc_491521501782_item	3732674	et	0	main
usun	doc_491521501782_item	3732675	et	0	main
seda	doc_491521501782_item	3732676	et	0	main
et	doc_491521501782_item	3732677	et	0	main
inimesel	doc_491521501782_item	3732678	et	0	main
on	doc_491521501782_item	3732679	et	0	main
mitu	doc_491521501782_item	3732680	et	0	main
elusid	doc_491521501782_item	3732681	et	0	main
ühildumisvead	doc_491521501782_item	3732682	et	0	main
vanaema	doc_491521501782_item	3732683	et	0	main
jutustas	doc_491521501782_item	3732684	et	0	main
mulle	doc_491521501782_item	3732685	et	0	main
väga	doc_491521501782_item	3732686	et	0	main
huvitavaid	doc_491521501782_item	3732687	et	0	main
asju	doc_491521501782_item	3732688	et	0	main
temast	doc_491521501782_item	3732689	et	0	main
elust	doc_491521501782_item	3732690	et	0	main
vrd	doc_491521501782_item	3732691	et	0	main
venekeelsega	doc_491521501782_item	3732692	et	0	main
о	doc_491521501782_item	3732693	et	0	main
ее	doc_491521501782_item	3732694	et	0	main
жизни	doc_491521501782_item	3732695	et	0	main
ta	doc_491521501782_item	3732696	et	0	main
jutustas	doc_491521501782_item	3732697	et	0	main
sellest	doc_491521501782_item	3732698	et	0	main
kuidas	doc_491521501782_item	3732699	et	0	main
nad	doc_491521501782_item	3732700	et	0	main
elasid	doc_491521501782_item	3732701	et	0	main
kui	doc_491521501782_item	3732702	et	0	main
nendes	doc_491521501782_item	3732703	et	0	main
majas	doc_491521501782_item	3732704	et	0	main
elasid	doc_491521501782_item	3732705	et	0	main
sakslased	doc_491521501782_item	3732706	et	0	main
vrd	doc_491521501782_item	3732707	et	0	main
venekeelse	doc_491521501782_item	3732708	et	0	main
tõlkega	doc_491521501782_item	3732709	et	0	main
в	doc_491521501782_item	3732710	et	0	main
их	doc_491521501782_item	3732711	et	0	main
доме	doc_491521501782_item	3732712	et	0	main
kokkuvõtteks	doc_491521501782_item	3732713	et	0	main
saan	doc_491521501782_item	3732714	et	0	main
öelda	doc_491521501782_item	3732715	et	0	main
et	doc_491521501782_item	3732716	et	0	main
vigade	doc_491521501782_item	3732717	et	0	main
rohkus	doc_491521501782_item	3732718	et	0	main
oli	doc_491521501782_item	3732719	et	0	main
tingitud	doc_491521501782_item	3732720	et	0	main
eelkõige	doc_491521501782_item	3732721	et	0	main
vene	doc_491521501782_item	3732722	et	0	main
keele	doc_491521501782_item	3732723	et	0	main
grammatika	doc_491521501782_item	3732724	et	0	main
reeglite	doc_491521501782_item	3732725	et	0	main
ülekandmisest	doc_491521501782_item	3732726	et	0	main
eesti	doc_491521501782_item	3732727	et	0	main
keele	doc_491521501782_item	3732728	et	0	main
grammatikasse	doc_491521501782_item	3732729	et	0	main
kuna	doc_491521501782_item	3732730	et	0	main
tegemist	doc_491521501782_item	3732731	et	0	main
oli	doc_491521501782_item	3732732	et	0	main
kirjandiga	doc_491521501782_item	3732733	et	0	main
siis	doc_491521501782_item	3732734	et	0	main
kohtus	doc_491521501782_item	3732735	et	0	main
ka	doc_491521501782_item	3732736	et	0	main
väga	doc_491521501782_item	3732737	et	0	main
palju	doc_491521501782_item	3732738	et	0	main
lohakusvigu	doc_491521501782_item	3732739	et	0	main
sest	doc_491521501782_item	3732740	et	0	main
kirjutamise	doc_491521501782_item	3732741	et	0	main
momendil	doc_491521501782_item	3732742	et	0	main
õpilased	doc_491521501782_item	3732743	et	0	main
pöörasid	doc_491521501782_item	3732744	et	0	main
rohkem	doc_491521501782_item	3732745	et	0	main
tähelepanu	doc_491521501782_item	3732746	et	0	main
sisule	doc_491521501782_item	3732747	et	0	main
kui	doc_491521501782_item	3732748	et	0	main
grammatilistele	doc_491521501782_item	3732749	et	0	main
reeglitele	doc_491521501782_item	3732750	et	0	main
analüüs	doc_491521501871_item	3732751	et	0	main
eesti	doc_491521501871_item	3732752	et	0	main
keele	doc_491521501871_item	3732753	et	0	main
kui	doc_491521501871_item	3732754	et	0	main
võõrkeele	doc_491521501871_item	3732755	et	0	main
õppetool	doc_491521501871_item	3732756	et	0	main
kontrastiivlingvistika	doc_491521501871_item	3732757	et	0	main
veaanalüüs	doc_491521501871_item	3732758	et	0	main
koostata	doc_491521501871_item	3732759	et	0	main
eesnimi	doc_491521501871_item	3732760	et	0	main
perekonnanimi	doc_491521501871_item	3732761	et	0	main
õppejõud	doc_491521501871_item	3732762	et	0	main
professor	doc_491521501871_item	3732763	et	0	main
e	doc_491521501871_item	3732764	et	0	main
perekonnanimi	doc_491521501871_item	3732765	et	0	main
kohakäänete	doc_491521501871_item	3732766	et	0	main
vead	doc_491521501871_item	3732767	et	0	main
12	doc_491521501871_item	3732768	et	0	main
kl	doc_491521501871_item	3732769	et	0	main
õpilase	doc_491521501871_item	3732770	et	0	main
vead	doc_491521501871_item	3732771	et	0	main
kohakäänete	doc_491521501871_item	3732772	et	0	main
valikul	doc_491521501871_item	3732773	et	0	main
on	doc_491521501871_item	3732774	et	0	main
saaeli	doc_491521501871_item	3732775	et	0	main
vea	doc_491521501871_item	3732776	et	0	main
põhiuseks	doc_491521501871_item	3732777	et	0	main
sise-	doc_491521501871_item	3732778	et	0	main
ia	doc_491521501871_item	3732779	et	0	main
väliskohakäänete	doc_491521501871_item	3732780	et	0	main
kasutamise	doc_491521501871_item	3732781	et	0	main
ebaõiasus	doc_491521501871_item	3732782	et	0	main
eriti	doc_491521501871_item	3732783	et	0	main
gümnaasiumiõpilasel	doc_491521501871_item	3732784	et	0	main
samuti	doc_491521501871_item	3732785	et	0	main
põhiustab	doc_491521501871_item	3732786	et	0	main
vigu	doc_491521501871_item	3732787	et	0	main
verbi	doc_491521501871_item	3732788	et	0	main
rektsiooni	doc_491521501871_item	3732789	et	0	main
erinevus	doc_491521501871_item	3732790	et	0	main
vene	doc_491521501871_item	3732791	et	0	main
keeles	doc_491521501871_item	3732792	et	0	main
nt	doc_491521501871_item	3732793	et	0	main
vene	doc_491521501871_item	3732794	et	0	main
keeles	doc_491521501871_item	3732795	et	0	main
käima	doc_491521501871_item	3732796	et	0	main
kuhu	doc_491521501871_item	3732797	et	0	main
eesti	doc_491521501871_item	3732798	et	0	main
keeles	doc_491521501871_item	3732799	et	0	main
käima	doc_491521501871_item	3732800	et	0	main
kus	doc_491521501871_item	3732801	et	0	main
obiekti	doc_491521501871_item	3732802	et	0	main
käände	doc_491521501871_item	3732803	et	0	main
valiku	doc_491521501871_item	3732804	et	0	main
vead	doc_491521501871_item	3732805	et	0	main
12	doc_491521501871_item	3732806	et	0	main
kl	doc_491521501871_item	3732807	et	0	main
probleemne	doc_491521501871_item	3732808	et	0	main
on	doc_491521501871_item	3732809	et	0	main
sihilise	doc_491521501871_item	3732810	et	0	main
verbi	doc_491521501871_item	3732811	et	0	main
ühildumisel	doc_491521501871_item	3732812	et	0	main
õige	doc_491521501871_item	3732813	et	0	main
vormi	doc_491521501871_item	3732814	et	0	main
valik	doc_491521501871_item	3732815	et	0	main
esimese	doc_491521501871_item	3732816	et	0	main
kolme	doc_491521501871_item	3732817	et	0	main
käände	doc_491521501871_item	3732818	et	0	main
vahel	doc_491521501871_item	3732819	et	0	main
saaeli	doc_491521501871_item	3732820	et	0	main
kasutatakse	doc_491521501871_item	3732821	et	0	main
nimetavat	doc_491521501871_item	3732822	et	0	main
kui	doc_491521501871_item	3732823	et	0	main
täelikult	doc_491521501871_item	3732824	et	0	main
on	doc_491521501871_item	3732825	et	0	main
omastav	doc_491521501871_item	3732826	et	0	main
või	doc_491521501871_item	3732827	et	0	main
osastav	doc_491521501871_item	3732828	et	0	main
seega	doc_491521501871_item	3732829	et	0	main
sihitist	doc_491521501871_item	3732830	et	0	main
puudutavas	doc_491521501871_item	3732831	et	0	main
osas	doc_491521501871_item	3732832	et	0	main
an	doc_491521501871_item	3732833	et	0	main
teadmised	doc_491521501871_item	3732834	et	0	main
kesised	doc_491521501871_item	3732835	et	0	main
paliu	doc_491521501871_item	3732836	et	0	main
probleeme	doc_491521501871_item	3732837	et	0	main
tekitab	doc_491521501871_item	3732838	et	0	main
mitmuse	doc_491521501871_item	3732839	et	0	main
osastava	doc_491521501871_item	3732840	et	0	main
moodustamine	doc_491521501871_item	3732841	et	0	main
mis	doc_491521501871_item	3732842	et	0	main
on	doc_491521501871_item	3732843	et	0	main
mõneti	doc_491521501871_item	3732844	et	0	main
arusaadav	doc_491521501871_item	3732845	et	0	main
sest	doc_491521501871_item	3732846	et	0	main
nimetatud	doc_491521501871_item	3732847	et	0	main
vorm	doc_491521501871_item	3732848	et	0	main
on	doc_491521501871_item	3732849	et	0	main
raske	doc_491521501871_item	3732850	et	0	main
ia	doc_491521501871_item	3732851	et	0	main
erinevate	doc_491521501871_item	3732852	et	0	main
variatsioonidega	doc_491521501871_item	3732853	et	0	main
ka	doc_491521501871_item	3732854	et	0	main
tekitab	doc_491521501871_item	3732855	et	0	main
probleeme	doc_491521501871_item	3732856	et	0	main
eituse	doc_491521501871_item	3732857	et	0	main
moodustamine	doc_491521501871_item	3732858	et	0	main
saamaoskamavõima	doc_491521501871_item	3732859	et	0	main
sõnade	doc_491521501871_item	3732860	et	0	main
ebaõige	doc_491521501871_item	3732861	et	0	main
kasutamine	doc_491521501871_item	3732862	et	0	main
on	doc_491521501871_item	3732863	et	0	main
ka	doc_491521501871_item	3732864	et	0	main
venelaste	doc_491521501871_item	3732865	et	0	main
vuhul	doc_491521501871_item	3732866	et	0	main
sagedane	doc_491521501871_item	3732867	et	0	main
mis	doc_491521501871_item	3732868	et	0	main
võib	doc_491521501871_item	3732869	et	0	main
olla	doc_491521501871_item	3732870	et	0	main
tingntud	doc_491521501871_item	3732871	et	0	main
vene	doc_491521501871_item	3732872	et	0	main
keele	doc_491521501871_item	3732873	et	0	main
mõiust	doc_491521501871_item	3732874	et	0	main
osa	doc_491521501871_item	3732875	et	0	main
vormimoodustusvigu	doc_491521501871_item	3732876	et	0	main
on	doc_491521501871_item	3732877	et	0	main
tingitud	doc_491521501871_item	3732878	et	0	main
astmevaheldusreeglite	doc_491521501871_item	3732879	et	0	main
mittetundmisest	doc_491521501871_item	3732880	et	0	main
need	doc_491521501871_item	3732881	et	0	main
vead	doc_491521501871_item	3732882	et	0	main
on	doc_491521501871_item	3732883	et	0	main
tingitud	doc_491521501871_item	3732884	et	0	main
astmevahelduse	doc_491521501871_item	3732885	et	0	main
mitte-tundmisest	doc_491521501871_item	3732886	et	0	main
ning	doc_491521501871_item	3732887	et	0	main
kokku-lahku	doc_491521501871_item	3732888	et	0	main
kiriutamise	doc_491521501871_item	3732889	et	0	main
teadmiste	doc_491521501871_item	3732890	et	0	main
vähesusest	doc_491521501871_item	3732891	et	0	main
vead	doc_491521501871_item	3732892	et	0	main
on	doc_491521501871_item	3732893	et	0	main
kogutud	doc_491521501871_item	3732894	et	0	main
12	doc_491521501871_item	3732895	et	0	main
klassis	doc_491521501871_item	3732896	et	0	main
õppiva	doc_491521501871_item	3732897	et	0	main
eratunde	doc_491521501871_item	3732898	et	0	main
võtva	doc_491521501871_item	3732899	et	0	main
õpilase	doc_491521501871_item	3732900	et	0	main
kirialikest	doc_491521501871_item	3732901	et	0	main
töödest	doc_491521501871_item	3732902	et	0	main
ning	doc_491521501871_item	3732903	et	0	main
samuti	doc_491521501871_item	3732904	et	0	main
laste	doc_491521501871_item	3732905	et	0	main
suvises	doc_491521501871_item	3732906	et	0	main
keelelaagris	doc_491521501871_item	3732907	et	0	main
kiriutatud	doc_491521501871_item	3732908	et	0	main
töödest	doc_491521501871_item	3732909	et	0	main
abituriendi	doc_491521501871_item	3732910	et	0	main
keeletaset	doc_491521501871_item	3732911	et	0	main
iseloomustades	doc_491521501871_item	3732912	et	0	main
ütleksin	doc_491521501871_item	3732913	et	0	main
et	doc_491521501871_item	3732914	et	0	main
ta	doc_491521501871_item	3732915	et	0	main
saab	doc_491521501871_item	3732916	et	0	main
suhtlemisega	doc_491521501871_item	3732917	et	0	main
hästi	doc_491521501871_item	3732918	et	0	main
hakkama	doc_491521501871_item	3732919	et	0	main
st	doc_491521501871_item	3732920	et	0	main
sõnavara	doc_491521501871_item	3732921	et	0	main
on	doc_491521501871_item	3732922	et	0	main
piisavalt	doc_491521501871_item	3732923	et	0	main
lai	doc_491521501871_item	3732924	et	0	main
ning	doc_491521501871_item	3732925	et	0	main
ka	doc_491521501871_item	3732926	et	0	main
suhtlemisiulgus	doc_491521501871_item	3732927	et	0	main
on	doc_491521501871_item	3732928	et	0	main
saavutatud	doc_491521501871_item	3732929	et	0	main
kuid	doc_491521501871_item	3732930	et	0	main
grammatika	doc_491521501871_item	3732931	et	0	main
osas	doc_491521501871_item	3732932	et	0	main
teeb	doc_491521501871_item	3732933	et	0	main
ta	doc_491521501871_item	3732934	et	0	main
siiski	doc_491521501871_item	3732935	et	0	main
veel	doc_491521501871_item	3732936	et	0	main
paliu	doc_491521501871_item	3732937	et	0	main
vigu	doc_491521501871_item	3732938	et	0	main
kuid	doc_491521501871_item	3732939	et	0	main
vestluse	doc_491521501871_item	3732940	et	0	main
käigus	doc_491521501871_item	3732941	et	0	main
kui	doc_491521501871_item	3732942	et	0	main
annan	doc_491521501871_item	3732943	et	0	main
talle	doc_491521501871_item	3732944	et	0	main
märku	doc_491521501871_item	3732945	et	0	main
vigase	doc_491521501871_item	3732946	et	0	main
keelekasutuse	doc_491521501871_item	3732947	et	0	main
kohta	doc_491521501871_item	3732948	et	0	main
on	doc_491521501871_item	3732949	et	0	main
ta	doc_491521501871_item	3732950	et	0	main
sageli	doc_491521501871_item	3732951	et	0	main
iuba	doc_491521501871_item	3732952	et	0	main
ise	doc_491521501871_item	3732953	et	0	main
võimeline	doc_491521501871_item	3732954	et	0	main
seda	doc_491521501871_item	3732955	et	0	main
parandama	doc_491521501871_item	3732956	et	0	main
keelelaagris	doc_491521501871_item	3732957	et	0	main
viibinud	doc_491521501871_item	3732958	et	0	main
laste	doc_491521501871_item	3732959	et	0	main
kohta	doc_491521501871_item	3732960	et	0	main
on	doc_491521501871_item	3732961	et	0	main
raske	doc_491521501871_item	3732962	et	0	main
üldistust	doc_491521501871_item	3732963	et	0	main
teha	doc_491521501871_item	3732964	et	0	main
sest	doc_491521501871_item	3732965	et	0	main
nende	doc_491521501871_item	3732966	et	0	main
vanus	doc_491521501871_item	3732967	et	0	main
ning	doc_491521501871_item	3732968	et	0	main
keeleline	doc_491521501871_item	3732969	et	0	main
tase	doc_491521501871_item	3732970	et	0	main
olid	doc_491521501871_item	3732971	et	0	main
väga	doc_491521501871_item	3732972	et	0	main
erinevad	doc_491521501871_item	3732973	et	0	main
lapsed	doc_491521501871_item	3732974	et	0	main
olid	doc_491521501871_item	3732975	et	0	main
kokku	doc_491521501871_item	3732976	et	0	main
tulnud	doc_491521501871_item	3732977	et	0	main
erinevatest	doc_491521501871_item	3732978	et	0	main
koolidest	doc_491521501871_item	3732979	et	0	main
ia	doc_491521501871_item	3732980	et	0	main
ka	doc_491521501871_item	3732981	et	0	main
eelnev	doc_491521501871_item	3732982	et	0	main
loomulik	doc_491521501871_item	3732983	et	0	main
keelekeskkond	doc_491521501871_item	3732984	et	0	main
oli	doc_491521501871_item	3732985	et	0	main
olnud	doc_491521501871_item	3732986	et	0	main
erinev	doc_491521501871_item	3732987	et	0	main
laager	doc_491521501871_item	3732988	et	0	main
kestis	doc_491521501871_item	3732989	et	0	main
12	doc_491521501871_item	3732990	et	0	main
päeva	doc_491521501871_item	3732991	et	0	main
selle	doc_491521501871_item	3732992	et	0	main
lõpuks	doc_491521501871_item	3732993	et	0	main
saavutasid	doc_491521501871_item	3732994	et	0	main
lapsed	doc_491521501871_item	3732995	et	0	main
suurema	doc_491521501871_item	3732996	et	0	main
suhtlemisiulguse	doc_491521501871_item	3732997	et	0	main
ia	doc_491521501871_item	3732998	et	0	main
nad	doc_491521501871_item	3732999	et	0	main
ise	doc_491521501871_item	3733000	et	0	main
kiriutasid	doc_491521501871_item	3733001	et	0	main
ka	doc_491521501871_item	3733002	et	0	main
sõnavara	doc_491521501871_item	3733003	et	0	main
laienes	doc_491521501871_item	3733004	et	0	main
analüüs	doc_491521501860_item	3733005	et	0	main
kontrastiivne	doc_491521501860_item	3733006	et	0	main
lingvistika	doc_491521501860_item	3733007	et	0	main
veaanalüüs	doc_491521501860_item	3733008	et	0	main
vead	doc_491521501860_item	3733009	et	0	main
on	doc_491521501860_item	3733010	et	0	main
võetud	doc_491521501860_item	3733011	et	0	main
x	doc_491521501860_item	3733012	et	0	main
klassi	doc_491521501860_item	3733013	et	0	main
õpilaste	doc_491521501860_item	3733014	et	0	main
töödest	doc_491521501860_item	3733015	et	0	main
kontrolltööd	doc_491521501860_item	3733016	et	0	main
ja	doc_491521501860_item	3733017	et	0	main
essee	doc_491521501860_item	3733018	et	0	main
eesti	doc_491521501860_item	3733019	et	0	main
keelt	doc_491521501860_item	3733020	et	0	main
õpivad	doc_491521501860_item	3733021	et	0	main
nad	doc_491521501860_item	3733022	et	0	main
juba	doc_491521501860_item	3733023	et	0	main
8	doc_491521501860_item	3733024	et	0	main
aastat	doc_491521501860_item	3733025	et	0	main
kõik	doc_491521501860_item	3733026	et	0	main
on	doc_491521501860_item	3733027	et	0	main
vene	doc_491521501860_item	3733028	et	0	main
keelt	doc_491521501860_item	3733029	et	0	main
emakeelena	doc_491521501860_item	3733030	et	0	main
kõnelevad	doc_491521501860_item	3733031	et	0	main
lapsed	doc_491521501860_item	3733032	et	0	main
mõned	doc_491521501860_item	3733033	et	0	main
on	doc_491521501860_item	3733034	et	0	main
tugevad	doc_491521501860_item	3733035	et	0	main
ja	doc_491521501860_item	3733036	et	0	main
väga	doc_491521501860_item	3733037	et	0	main
tublid	doc_491521501860_item	3733038	et	0	main
nähtub	doc_491521501860_item	3733039	et	0	main
et	doc_491521501860_item	3733040	et	0	main
nad	doc_491521501860_item	3733041	et	0	main
tajuvad	doc_491521501860_item	3733042	et	0	main
juba	doc_491521501860_item	3733043	et	0	main
natukene	doc_491521501860_item	3733044	et	0	main
eesti	doc_491521501860_item	3733045	et	0	main
keelt	doc_491521501860_item	3733046	et	0	main
selle	doc_491521501860_item	3733047	et	0	main
reegleid	doc_491521501860_item	3733048	et	0	main
ja	doc_491521501860_item	3733049	et	0	main
struktuuri	doc_491521501860_item	3733050	et	0	main
mis	doc_491521501860_item	3733051	et	0	main
puudutab	doc_491521501860_item	3733052	et	0	main
teisi	doc_491521501860_item	3733053	et	0	main
tekib	doc_491521501860_item	3733054	et	0	main
selline	doc_491521501860_item	3733055	et	0	main
tunne	doc_491521501860_item	3733056	et	0	main
et	doc_491521501860_item	3733057	et	0	main
neil	doc_491521501860_item	3733058	et	0	main
on	doc_491521501860_item	3733059	et	0	main
vilets	doc_491521501860_item	3733060	et	0	main
sõnavara	doc_491521501860_item	3733061	et	0	main
ning	doc_491521501860_item	3733062	et	0	main
puuduvad	doc_491521501860_item	3733063	et	0	main
elementaarsed	doc_491521501860_item	3733064	et	0	main
grammatika	doc_491521501860_item	3733065	et	0	main
reeglid	doc_491521501860_item	3733066	et	0	main
1	doc_491521501860_item	3733067	et	0	main
hääldus	doc_491521501860_item	3733068	et	0	main
ja	doc_491521501860_item	3733069	et	0	main
õigekiri	doc_491521501860_item	3733070	et	0	main
pedagook	doc_491521501860_item	3733071	et	0	main
inimene	doc_491521501860_item	3733072	et	0	main
hääldatakse	doc_491521501860_item	3733073	et	0	main
tihti	doc_491521501860_item	3733074	et	0	main
inemene	doc_491521501860_item	3733075	et	0	main
kontrolltöö	doc_491521501860_item	3733076	et	0	main
õpilased	doc_491521501860_item	3733077	et	0	main
hääldavad	doc_491521501860_item	3733078	et	0	main
vahel	doc_491521501860_item	3733079	et	0	main
kantrolltöö	doc_491521501860_item	3733080	et	0	main
emakeele	doc_491521501860_item	3733081	et	0	main
mõju	doc_491521501860_item	3733082	et	0	main
afrika	doc_491521501860_item	3733083	et	0	main
emakeele	doc_491521501860_item	3733084	et	0	main
mõju	doc_491521501860_item	3733085	et	0	main
üks	doc_491521501860_item	3733086	et	0	main
vahel	doc_491521501860_item	3733087	et	0	main
hääldatakse	doc_491521501860_item	3733088	et	0	main
nii	doc_491521501860_item	3733089	et	0	main
nagu	doc_491521501860_item	3733090	et	0	main
u	doc_491521501860_item	3733091	et	0	main
ees	doc_491521501860_item	3733092	et	0	main
oleks	doc_491521501860_item	3733093	et	0	main
j	doc_491521501860_item	3733094	et	0	main
eesti	doc_491521501860_item	3733095	et	0	main
u	doc_491521501860_item	3733096	et	0	main
sarnaneb	doc_491521501860_item	3733097	et	0	main
vene	doc_491521501860_item	3733098	et	0	main
ю-ga	doc_491521501860_item	3733099	et	0	main
kirjavahemärgid	doc_491521501860_item	3733100	et	0	main
liitlauses	doc_491521501860_item	3733101	et	0	main
unustatakse	doc_491521501860_item	3733102	et	0	main
koma	doc_491521501860_item	3733103	et	0	main
panna	doc_491521501860_item	3733104	et	0	main
alistussidendite	doc_491521501860_item	3733105	et	0	main
et	doc_491521501860_item	3733106	et	0	main
siis	doc_491521501860_item	3733107	et	0	main
sest	doc_491521501860_item	3733108	et	0	main
mis	doc_491521501860_item	3733109	et	0	main
jne	doc_491521501860_item	3733110	et	0	main
ette	doc_491521501860_item	3733111	et	0	main
põhjuseks	doc_491521501860_item	3733112	et	0	main
võib	doc_491521501860_item	3733113	et	0	main
olla	doc_491521501860_item	3733114	et	0	main
ainult	doc_491521501860_item	3733115	et	0	main
reeglite	doc_491521501860_item	3733116	et	0	main
mittetundmine	doc_491521501860_item	3733117	et	0	main
2	doc_491521501860_item	3733118	et	0	main
astmevaheldus	doc_491521501860_item	3733119	et	0	main
sõbradel	doc_491521501860_item	3733120	et	0	main
vormi	doc_491521501860_item	3733121	et	0	main
moodustamist	doc_491521501860_item	3733122	et	0	main
on	doc_491521501860_item	3733123	et	0	main
mõjutanud	doc_491521501860_item	3733124	et	0	main
mitmuse	doc_491521501860_item	3733125	et	0	main
nimetav	doc_491521501860_item	3733126	et	0	main
sõbrad	doc_491521501860_item	3733127	et	0	main
sõbrade	doc_491521501860_item	3733128	et	0	main
l	doc_491521501860_item	3733129	et	0	main
sõbradel	doc_491521501860_item	3733130	et	0	main
õmbletakse	doc_491521501860_item	3733131	et	0	main
tegelikult	doc_491521501860_item	3733132	et	0	main
on	doc_491521501860_item	3733133	et	0	main
vorm	doc_491521501860_item	3733134	et	0	main
moodustatud	doc_491521501860_item	3733135	et	0	main
reeglite	doc_491521501860_item	3733136	et	0	main
järgi	doc_491521501860_item	3733137	et	0	main
kuid	doc_491521501860_item	3733138	et	0	main
av	doc_491521501860_item	3733139	et	0	main
ei	doc_491521501860_item	3733140	et	0	main
ole	doc_491521501860_item	3733141	et	0	main
arvestatud	doc_491521501860_item	3733142	et	0	main
tubad	doc_491521501860_item	3733143	et	0	main
pidud	doc_491521501860_item	3733144	et	0	main
sääraseid	doc_491521501860_item	3733145	et	0	main
vigu	doc_491521501860_item	3733146	et	0	main
on	doc_491521501860_item	3733147	et	0	main
väga	doc_491521501860_item	3733148	et	0	main
palju	doc_491521501860_item	3733149	et	0	main
neid	doc_491521501860_item	3733150	et	0	main
võib	doc_491521501860_item	3733151	et	0	main
ka	doc_491521501860_item	3733152	et	0	main
vormimoodustusveaks	doc_491521501860_item	3733153	et	0	main
pidada	doc_491521501860_item	3733154	et	0	main
hammasid	doc_491521501860_item	3733155	et	0	main
vead	doc_491521501860_item	3733156	et	0	main
on	doc_491521501860_item	3733157	et	0	main
nii	doc_491521501860_item	3733158	et	0	main
vormimoodustuses	doc_491521501860_item	3733159	et	0	main
kui	doc_491521501860_item	3733160	et	0	main
ka	doc_491521501860_item	3733161	et	0	main
astmevahelduses	doc_491521501860_item	3733162	et	0	main
reeglina	doc_491521501860_item	3733163	et	0	main
on	doc_491521501860_item	3733164	et	0	main
mosastav	doc_491521501860_item	3733165	et	0	main
tugevas	doc_491521501860_item	3733166	et	0	main
astmes	doc_491521501860_item	3733167	et	0	main
nim	doc_491521501860_item	3733168	et	0	main
hammas	doc_491521501860_item	3733169	et	0	main
om	doc_491521501860_item	3733170	et	0	main
hamba	doc_491521501860_item	3733171	et	0	main
m	doc_491521501860_item	3733172	et	0	main
os	doc_491521501860_item	3733173	et	0	main
hambaid	doc_491521501860_item	3733174	et	0	main
tavaliselt	doc_491521501860_item	3733175	et	0	main
eriti	doc_491521501860_item	3733176	et	0	main
algperiooldil	doc_491521501860_item	3733177	et	0	main
ei	doc_491521501860_item	3733178	et	0	main
tehta	doc_491521501860_item	3733179	et	0	main
vahet	doc_491521501860_item	3733180	et	0	main
ka	doc_491521501860_item	3733181	et	0	main
ii	doc_491521501860_item	3733182	et	0	main
ja	doc_491521501860_item	3733183	et	0	main
iii	doc_491521501860_item	3733184	et	0	main
välte	doc_491521501860_item	3733185	et	0	main
hääldamisel	doc_491521501860_item	3733186	et	0	main
nt	doc_491521501860_item	3733187	et	0	main
kirjutan	doc_491521501860_item	3733188	et	0	main
praegu	doc_491521501860_item	3733189	et	0	main
kirja	doc_491521501860_item	3733190	et	0	main
iii	doc_491521501860_item	3733191	et	0	main
välde	doc_491521501860_item	3733192	et	0	main
ja	doc_491521501860_item	3733193	et	0	main
kirjutan	doc_491521501860_item	3733194	et	0	main
kirja	doc_491521501860_item	3733195	et	0	main
ja	doc_491521501860_item	3733196	et	0	main
lähen	doc_491521501860_item	3733197	et	0	main
postkontorisse	doc_491521501860_item	3733198	et	0	main
ii	doc_491521501860_item	3733199	et	0	main
välde	doc_491521501860_item	3733200	et	0	main
söön	doc_491521501860_item	3733201	et	0	main
õunavõi	doc_491521501860_item	3733202	et	0	main
söön	doc_491521501860_item	3733203	et	0	main
õuna	doc_491521501860_item	3733204	et	0	main
ära	doc_491521501860_item	3733205	et	0	main
ja	doc_491521501860_item	3733206	et	0	main
lähen	doc_491521501860_item	3733207	et	0	main
õue	doc_491521501860_item	3733208	et	0	main
õpilased	doc_491521501860_item	3733209	et	0	main
hääldavad	doc_491521501860_item	3733210	et	0	main
ühtemoodi	doc_491521501860_item	3733211	et	0	main
3	doc_491521501860_item	3733212	et	0	main
objektivead	doc_491521501860_item	3733213	et	0	main
vorm	doc_491521501860_item	3733214	et	0	main
ja	doc_491521501860_item	3733215	et	0	main
käändevalik	doc_491521501860_item	3733216	et	0	main
isa	doc_491521501860_item	3733217	et	0	main
luges	doc_491521501860_item	3733218	et	0	main
raamatut	doc_491521501860_item	3733219	et	0	main
läbi	doc_491521501860_item	3733220	et	0	main
lõpetatud	doc_491521501860_item	3733221	et	0	main
tegevus	doc_491521501860_item	3733222	et	0	main
antud	doc_491521501860_item	3733223	et	0	main
juhul	doc_491521501860_item	3733224	et	0	main
peab	doc_491521501860_item	3733225	et	0	main
kasutama	doc_491521501860_item	3733226	et	0	main
omastavat	doc_491521501860_item	3733227	et	0	main
käänet	doc_491521501860_item	3733228	et	0	main
õpilased	doc_491521501860_item	3733229	et	0	main
on	doc_491521501860_item	3733230	et	0	main
aga	doc_491521501860_item	3733231	et	0	main
harjunud	doc_491521501860_item	3733232	et	0	main
kasutama	doc_491521501860_item	3733233	et	0	main
lugema	doc_491521501860_item	3733234	et	0	main
tegusõna	doc_491521501860_item	3733235	et	0	main
juures	doc_491521501860_item	3733236	et	0	main
osastavat	doc_491521501860_item	3733237	et	0	main
käänet	doc_491521501860_item	3733238	et	0	main
ma	doc_491521501860_item	3733239	et	0	main
loen	doc_491521501860_item	3733240	et	0	main
raamatut	doc_491521501860_item	3733241	et	0	main
ega	doc_491521501860_item	3733242	et	0	main
pane	doc_491521501860_item	3733243	et	0	main
tähele	doc_491521501860_item	3733244	et	0	main
on	doc_491521501860_item	3733245	et	0	main
seal	doc_491521501860_item	3733246	et	0	main
perfektiivsusadverb	doc_491521501860_item	3733247	et	0	main
nt	doc_491521501860_item	3733248	et	0	main
läbi	doc_491521501860_item	3733249	et	0	main
ära	doc_491521501860_item	3733250	et	0	main
valmis	doc_491521501860_item	3733251	et	0	main
jne	doc_491521501860_item	3733252	et	0	main
või	doc_491521501860_item	3733253	et	0	main
mitte	doc_491521501860_item	3733254	et	0	main
söön	doc_491521501860_item	3733255	et	0	main
putru	doc_491521501860_item	3733256	et	0	main
voi	doc_491521501860_item	3733257	et	0	main
söön	doc_491521501860_item	3733258	et	0	main
putru	doc_491521501860_item	3733259	et	0	main
ära	doc_491521501860_item	3733260	et	0	main
teises	doc_491521501860_item	3733261	et	0	main
lauses	doc_491521501860_item	3733262	et	0	main
on	doc_491521501860_item	3733263	et	0	main
tegemist	doc_491521501860_item	3733264	et	0	main
tulemusliku	doc_491521501860_item	3733265	et	0	main
tegevusega	doc_491521501860_item	3733266	et	0	main
õige	doc_491521501860_item	3733267	et	0	main
oleks	doc_491521501860_item	3733268	et	0	main
söön	doc_491521501860_item	3733269	et	0	main
pudru	doc_491521501860_item	3733270	et	0	main
ära	doc_491521501860_item	3733271	et	0	main
4	doc_491521501860_item	3733272	et	0	main
kohakäänete	doc_491521501860_item	3733273	et	0	main
vead	doc_491521501860_item	3733274	et	0	main
lasnamäes	doc_491521501860_item	3733275	et	0	main
interferentne	doc_491521501860_item	3733276	et	0	main
viga	doc_491521501860_item	3733277	et	0	main
mina	doc_491521501860_item	3733278	et	0	main
ootasin	doc_491521501860_item	3733279	et	0	main
peatusel	doc_491521501860_item	3733280	et	0	main
emakeele	doc_491521501860_item	3733281	et	0	main
mõju	doc_491521501860_item	3733282	et	0	main
mina	doc_491521501860_item	3733283	et	0	main
lähen	doc_491521501860_item	3733284	et	0	main
kinosse	doc_491521501860_item	3733285	et	0	main
kohvikusse	doc_491521501860_item	3733286	et	0	main
maasse	doc_491521501860_item	3733287	et	0	main
naitusesse	doc_491521501860_item	3733288	et	0	main
õpilastel	doc_491521501860_item	3733289	et	0	main
on	doc_491521501860_item	3733290	et	0	main
raske	doc_491521501860_item	3733291	et	0	main
aru	doc_491521501860_item	3733292	et	0	main
saada	doc_491521501860_item	3733293	et	0	main
miks	doc_491521501860_item	3733294	et	0	main
vene	doc_491521501860_item	3733295	et	0	main
keeles	doc_491521501860_item	3733296	et	0	main
kasutatakse	doc_491521501860_item	3733297	et	0	main
väliskoha-	doc_491521501860_item	3733298	et	0	main
ja	doc_491521501860_item	3733299	et	0	main
eesti	doc_491521501860_item	3733300	et	0	main
keeles	doc_491521501860_item	3733301	et	0	main
sisekohakäänet	doc_491521501860_item	3733302	et	0	main
ja	doc_491521501860_item	3733303	et	0	main
vastupidi	doc_491521501860_item	3733304	et	0	main
seda	doc_491521501860_item	3733305	et	0	main
peab	doc_491521501860_item	3733306	et	0	main
meelde	doc_491521501860_item	3733307	et	0	main
jätma	doc_491521501860_item	3733308	et	0	main
5	doc_491521501860_item	3733309	et	0	main
muud	doc_491521501860_item	3733310	et	0	main
käändevead	doc_491521501860_item	3733311	et	0	main
a	doc_491521501860_item	3733312	et	0	main
vormimoodustus	doc_491521501860_item	3733313	et	0	main
poolakas	doc_491521501860_item	3733314	et	0	main
poolakased	doc_491521501860_item	3733315	et	0	main
poolakas	doc_491521501860_item	3733316	et	0	main
poolakase	doc_491521501860_item	3733317	et	0	main
poolakased	doc_491521501860_item	3733318	et	0	main
võib	doc_491521501860_item	3733319	et	0	main
arvata	doc_491521501860_item	3733320	et	0	main
et	doc_491521501860_item	3733321	et	0	main
seda	doc_491521501860_item	3733322	et	0	main
mõjutas	doc_491521501860_item	3733323	et	0	main
nt	doc_491521501860_item	3733324	et	0	main
küsimus	doc_491521501860_item	3733325	et	0	main
küsimuse	doc_491521501860_item	3733326	et	0	main
küsimused	doc_491521501860_item	3733327	et	0	main
vormi	doc_491521501860_item	3733328	et	0	main
moodustamine	doc_491521501860_item	3733329	et	0	main
maale	doc_491521501860_item	3733330	et	0	main
sõidame	doc_491521501860_item	3733331	et	0	main
jalgratasega	doc_491521501860_item	3733332	et	0	main
jalgratas	doc_491521501860_item	3733333	et	0	main
jalgratase	doc_491521501860_item	3733334	et	0	main
ga	doc_491521501860_item	3733335	et	0	main
jalgratasega	doc_491521501860_item	3733336	et	0	main
kaunis	doc_491521501860_item	3733337	et	0	main
kaunisel	doc_491521501860_item	3733338	et	0	main
kaunis	doc_491521501860_item	3733339	et	0	main
kaunise	doc_491521501860_item	3733340	et	0	main
t	doc_491521501860_item	3733341	et	0	main
nb	doc_491521501860_item	3733342	et	0	main
tegelikult	doc_491521501860_item	3733343	et	0	main
on	doc_491521501860_item	3733344	et	0	main
need	doc_491521501860_item	3733345	et	0	main
vormid	doc_491521501860_item	3733346	et	0	main
moodustatud	doc_491521501860_item	3733347	et	0	main
reeglite	doc_491521501860_item	3733348	et	0	main
järgi	doc_491521501860_item	3733349	et	0	main
kaartid	doc_491521501860_item	3733350	et	0	main
kaart	doc_491521501860_item	3733351	et	0	main
kaarti	doc_491521501860_item	3733352	et	0	main
d	doc_491521501860_item	3733353	et	0	main
tegutsetakse	doc_491521501860_item	3733354	et	0	main
pähe	doc_491521501860_item	3733355	et	0	main
õpitud	doc_491521501860_item	3733356	et	0	main
reegli	doc_491521501860_item	3733357	et	0	main
järgi	doc_491521501860_item	3733358	et	0	main
kohalikud	doc_491521501860_item	3733359	et	0	main
gruppid	doc_491521501860_item	3733360	et	0	main
grupp	doc_491521501860_item	3733361	et	0	main
gruppi	doc_491521501860_item	3733362	et	0	main
d	doc_491521501860_item	3733363	et	0	main
gruppid	doc_491521501860_item	3733364	et	0	main
ei	doc_491521501860_item	3733365	et	0	main
tajuta	doc_491521501860_item	3733366	et	0	main
avst	doc_491521501860_item	3733367	et	0	main
õpilane	doc_491521501860_item	3733368	et	0	main
m	doc_491521501860_item	3733369	et	0	main
os	doc_491521501860_item	3733370	et	0	main
õpilanesid	doc_491521501860_item	3733371	et	0	main
uks	doc_491521501860_item	3733372	et	0	main
m	doc_491521501860_item	3733373	et	0	main
os	doc_491521501860_item	3733374	et	0	main
lõppe	doc_491521501860_item	3733375	et	0	main
on	doc_491521501860_item	3733376	et	0	main
sid	doc_491521501860_item	3733377	et	0	main
nt	doc_491521501860_item	3733378	et	0	main
pesa	doc_491521501860_item	3733379	et	0	main
sid	doc_491521501860_item	3733380	et	0	main
õpilane	doc_491521501860_item	3733381	et	0	main
sid	doc_491521501860_item	3733382	et	0	main
tunne	doc_491521501860_item	3733383	et	0	main
tunned	doc_491521501860_item	3733384	et	0	main
tunne	doc_491521501860_item	3733385	et	0	main
tunne	doc_491521501860_item	3733386	et	0	main
d	doc_491521501860_item	3733387	et	0	main
rääkisin	doc_491521501860_item	3733388	et	0	main
sellest	doc_491521501860_item	3733389	et	0	main
armastust	doc_491521501860_item	3733390	et	0	main
seda	doc_491521501860_item	3733391	et	0	main
võiks	doc_491521501860_item	3733392	et	0	main
ka	doc_491521501860_item	3733393	et	0	main
ühildumisveaks	doc_491521501860_item	3733394	et	0	main
pidada	doc_491521501860_item	3733395	et	0	main
kuid	doc_491521501860_item	3733396	et	0	main
see	doc_491521501860_item	3733397	et	0	main
kuulub	doc_491521501860_item	3733398	et	0	main
pigem	doc_491521501860_item	3733399	et	0	main
vormimoodustusvigade	doc_491521501860_item	3733400	et	0	main
hulka	doc_491521501860_item	3733401	et	0	main
nimetav	doc_491521501860_item	3733402	et	0	main
mõjutas	doc_491521501860_item	3733403	et	0	main
seestütleva	doc_491521501860_item	3733404	et	0	main
käände	doc_491521501860_item	3733405	et	0	main
moodustamist	doc_491521501860_item	3733406	et	0	main
armastus	doc_491521501860_item	3733407	et	0	main
lõpeb	doc_491521501860_item	3733408	et	0	main
s-ga	doc_491521501860_item	3733409	et	0	main
ja	doc_491521501860_item	3733410	et	0	main
seestütlev	doc_491521501860_item	3733411	et	0	main
st-ga	doc_491521501860_item	3733412	et	0	main
ning	doc_491521501860_item	3733413	et	0	main
armastust	doc_491521501860_item	3733414	et	0	main
on	doc_491521501860_item	3733415	et	0	main
segi	doc_491521501860_item	3733416	et	0	main
aetud	doc_491521501860_item	3733417	et	0	main
armastusest-ga	doc_491521501860_item	3733418	et	0	main
b	doc_491521501860_item	3733419	et	0	main
vormikasutus	doc_491521501860_item	3733420	et	0	main
linna	doc_491521501860_item	3733421	et	0	main
sõidame	doc_491521501860_item	3733422	et	0	main
trammil	doc_491521501860_item	3733423	et	0	main
ja	doc_491521501860_item	3733424	et	0	main
jalgrattal	doc_491521501860_item	3733425	et	0	main
vene	doc_491521501860_item	3733426	et	0	main
keele	doc_491521501860_item	3733427	et	0	main
mõju	doc_491521501860_item	3733428	et	0	main
tegelikult	doc_491521501860_item	3733429	et	0	main
peaks	doc_491521501860_item	3733430	et	0	main
olema	doc_491521501860_item	3733431	et	0	main
sõitma	doc_491521501860_item	3733432	et	0	main
millega	doc_491521501860_item	3733433	et	0	main
trammiga	doc_491521501860_item	3733434	et	0	main
jalgrattaga	doc_491521501860_item	3733435	et	0	main
jne	doc_491521501860_item	3733436	et	0	main
mööda	doc_491521501860_item	3733437	et	0	main
tänava-	doc_491521501860_item	3733438	et	0	main
eesti	doc_491521501860_item	3733439	et	0	main
keeles	doc_491521501860_item	3733440	et	0	main
mööda	doc_491521501860_item	3733441	et	0	main
mida	doc_491521501860_item	3733442	et	0	main
õpilastel	doc_491521501860_item	3733443	et	0	main
on	doc_491521501860_item	3733444	et	0	main
raske	doc_491521501860_item	3733445	et	0	main
seost	doc_491521501860_item	3733446	et	0	main
leida	doc_491521501860_item	3733447	et	0	main
6	doc_491521501860_item	3733448	et	0	main
pronoomenivead	doc_491521501860_item	3733449	et	0	main
teda	doc_491521501860_item	3733450	et	0	main
auto	doc_491521501860_item	3733451	et	0	main
omastava	doc_491521501860_item	3733452	et	0	main
asemel	doc_491521501860_item	3733453	et	0	main
on	doc_491521501860_item	3733454	et	0	main
osastav	doc_491521501860_item	3733455	et	0	main
õpitav	doc_491521501860_item	3733456	et	0	main
reegel	doc_491521501860_item	3733457	et	0	main
7	doc_491521501860_item	3733458	et	0	main
arvsõna	doc_491521501860_item	3733459	et	0	main
käänamine	doc_491521501860_item	3733460	et	0	main
ja	doc_491521501860_item	3733461	et	0	main
kasutamine	doc_491521501860_item	3733462	et	0	main
kakssada	doc_491521501860_item	3733463	et	0	main
inimesi	doc_491521501860_item	3733464	et	0	main
emakeele	doc_491521501860_item	3733465	et	0	main
mõju	doc_491521501860_item	3733466	et	0	main
seal	doc_491521501860_item	3733467	et	0	main
oli	doc_491521501860_item	3733468	et	0	main
mitu	doc_491521501860_item	3733469	et	0	main
väikesed	doc_491521501860_item	3733470	et	0	main
lapsi	doc_491521501860_item	3733471	et	0	main
emakeele	doc_491521501860_item	3733472	et	0	main
mõju	doc_491521501860_item	3733473	et	0	main
ühildumisviga	doc_491521501860_item	3733474	et	0	main
väikesed	doc_491521501860_item	3733475	et	0	main
m	doc_491521501860_item	3733476	et	0	main
nim	doc_491521501860_item	3733477	et	0	main
lapsi	doc_491521501860_item	3733478	et	0	main
m	doc_491521501860_item	3733479	et	0	main
os	doc_491521501860_item	3733480	et	0	main
küünlapäev	doc_491521501860_item	3733481	et	0	main
on	doc_491521501860_item	3733482	et	0	main
teisendal	doc_491521501860_item	3733483	et	0	main
veebruaril	doc_491521501860_item	3733484	et	0	main
keelesisene	doc_491521501860_item	3733485	et	0	main
interferents	doc_491521501860_item	3733486	et	0	main
enamik	doc_491521501860_item	3733487	et	0	main
järgarvsõnu	doc_491521501860_item	3733488	et	0	main
käändub	doc_491521501860_item	3733489	et	0	main
mitmes	doc_491521501860_item	3733490	et	0	main
mitmenda	doc_491521501860_item	3733491	et	0	main
mitmendat	doc_491521501860_item	3733492	et	0	main
nt	doc_491521501860_item	3733493	et	0	main
kolmas	doc_491521501860_item	3733494	et	0	main
kolmanda	doc_491521501860_item	3733495	et	0	main
kolmandal	doc_491521501860_item	3733496	et	0	main
veebruaril	doc_491521501860_item	3733497	et	0	main
sama	doc_491521501860_item	3733498	et	0	main
skeemi	doc_491521501860_item	3733499	et	0	main
järgi	doc_491521501860_item	3733500	et	0	main
on	doc_491521501860_item	3733501	et	0	main
tehtud	doc_491521501860_item	3733502	et	0	main
ka	doc_491521501860_item	3733503	et	0	main
teine	doc_491521501860_item	3733504	et	0	main
teisenda	doc_491521501860_item	3733505	et	0	main
l	doc_491521501860_item	3733506	et	0	main
7-l	doc_491521501860_item	3733507	et	0	main
juunil	doc_491521501860_item	3733508	et	0	main
vene	doc_491521501860_item	3733509	et	0	main
keeles	doc_491521501860_item	3733510	et	0	main
on	doc_491521501860_item	3733511	et	0	main
lubatud	doc_491521501860_item	3733512	et	0	main
kirjutada	doc_491521501860_item	3733513	et	0	main
kirjas	doc_491521501860_item	3733514	et	0	main
ei	doc_491521501860_item	3733515	et	0	main
eristata	doc_491521501860_item	3733516	et	0	main
tavaliselt	doc_491521501860_item	3733517	et	0	main
põhi-	doc_491521501860_item	3733518	et	0	main
järgarvsõna	doc_491521501860_item	3733519	et	0	main
ega	doc_491521501860_item	3733520	et	0	main
panda	doc_491521501860_item	3733521	et	0	main
punkti	doc_491521501860_item	3733522	et	0	main
nt	doc_491521501860_item	3733523	et	0	main
4	doc_491521501860_item	3733524	et	0	main
lehel	doc_491521501860_item	3733525	et	0	main
siit	doc_491521501860_item	3733526	et	0	main
ei	doc_491521501860_item	3733527	et	0	main
saada	doc_491521501860_item	3733528	et	0	main
aru	doc_491521501860_item	3733529	et	0	main
mida	doc_491521501860_item	3733530	et	0	main
on	doc_491521501860_item	3733531	et	0	main
tahetud	doc_491521501860_item	3733532	et	0	main
öelda	doc_491521501860_item	3733533	et	0	main
4	doc_491521501860_item	3733534	et	0	main
lehel	doc_491521501860_item	3733535	et	0	main
neljal	doc_491521501860_item	3733536	et	0	main
lehel	doc_491521501860_item	3733537	et	0	main
voi	doc_491521501860_item	3733538	et	0	main
4	doc_491521501860_item	3733539	et	0	main
lehel	doc_491521501860_item	3733540	et	0	main
neljandal	doc_491521501860_item	3733541	et	0	main
lehel	doc_491521501860_item	3733542	et	0	main
enamus	doc_491521501860_item	3733543	et	0	main
lausu	doc_491521501860_item	3733544	et	0	main
on	doc_491521501860_item	3733545	et	0	main
pühendatud	doc_491521501860_item	3733546	et	0	main
valesti	doc_491521501860_item	3733547	et	0	main
kasutatud	doc_491521501860_item	3733548	et	0	main
hulgasõna	doc_491521501860_item	3733549	et	0	main
mitte	doc_491521501860_item	3733550	et	0	main
enamus	doc_491521501860_item	3733551	et	0	main
klassi	doc_491521501860_item	3733552	et	0	main
vaid	doc_491521501860_item	3733553	et	0	main
klassi	doc_491521501860_item	3733554	et	0	main
enamus	doc_491521501860_item	3733555	et	0	main
teiseks	doc_491521501860_item	3733556	et	0	main
on	doc_491521501860_item	3733557	et	0	main
tahetud	doc_491521501860_item	3733558	et	0	main
arvatavasti	doc_491521501860_item	3733559	et	0	main
kasutada	doc_491521501860_item	3733560	et	0	main
mitmuse	doc_491521501860_item	3733561	et	0	main
osastavat	doc_491521501860_item	3733562	et	0	main
õige	doc_491521501860_item	3733563	et	0	main
vorm	doc_491521501860_item	3733564	et	0	main
lauseid	doc_491521501860_item	3733565	et	0	main
8	doc_491521501860_item	3733566	et	0	main
ühildumisvead	doc_491521501860_item	3733567	et	0	main
vaatasin	doc_491521501860_item	3733568	et	0	main
uue	doc_491521501860_item	3733569	et	0	main
ajalehti	doc_491521501860_item	3733570	et	0	main
nimisõnafraasi	doc_491521501860_item	3733571	et	0	main
täiendi	doc_491521501860_item	3733572	et	0	main
ja	doc_491521501860_item	3733573	et	0	main
põhisõna	doc_491521501860_item	3733574	et	0	main
ühildumine	doc_491521501860_item	3733575	et	0	main
uue	doc_491521501860_item	3733576	et	0	main
a	doc_491521501860_item	3733577	et	0	main
omastavas	doc_491521501860_item	3733578	et	0	main
ja	doc_491521501860_item	3733579	et	0	main
ajalehti	doc_491521501860_item	3733580	et	0	main
m	doc_491521501860_item	3733581	et	0	main
osastavas	doc_491521501860_item	3733582	et	0	main
käändes	doc_491521501860_item	3733583	et	0	main
näeb	doc_491521501860_item	3733584	et	0	main
kuri	doc_491521501860_item	3733585	et	0	main
koerat	doc_491521501860_item	3733586	et	0	main
täiend	doc_491521501860_item	3733587	et	0	main
on	doc_491521501860_item	3733588	et	0	main
nimetavas	doc_491521501860_item	3733589	et	0	main
käändes	doc_491521501860_item	3733590	et	0	main
põhisõna	doc_491521501860_item	3733591	et	0	main
koerat	doc_491521501860_item	3733592	et	0	main
osastavas	doc_491521501860_item	3733593	et	0	main
käändes	doc_491521501860_item	3733594	et	0	main
õige	doc_491521501860_item	3733595	et	0	main
koera	doc_491521501860_item	3733596	et	0	main
pärast	doc_491521501860_item	3733597	et	0	main
ma	doc_491521501860_item	3733598	et	0	main
tulid	doc_491521501860_item	3733599	et	0	main
koju	doc_491521501860_item	3733600	et	0	main
predikatsioon	doc_491521501860_item	3733601	et	0	main
ma	doc_491521501860_item	3733602	et	0	main
elas	doc_491521501860_item	3733603	et	0	main
lasnamäel	doc_491521501860_item	3733604	et	0	main
nägin	doc_491521501860_item	3733605	et	0	main
ühe	doc_491521501860_item	3733606	et	0	main
imeliku	doc_491521501860_item	3733607	et	0	main
tüdrukut	doc_491521501860_item	3733608	et	0	main
nägin	doc_491521501860_item	3733609	et	0	main
tüdrukut	doc_491521501860_item	3733610	et	0	main
nägin	doc_491521501860_item	3733611	et	0	main
keda	doc_491521501860_item	3733612	et	0	main
rektsioon	doc_491521501860_item	3733613	et	0	main
kasutatud	doc_491521501860_item	3733614	et	0	main
õigesti	doc_491521501860_item	3733615	et	0	main
kuid	doc_491521501860_item	3733616	et	0	main
põhisõna	doc_491521501860_item	3733617	et	0	main
osastavas	doc_491521501860_item	3733618	et	0	main
käändes	doc_491521501860_item	3733619	et	0	main
ja	doc_491521501860_item	3733620	et	0	main
täiendid	doc_491521501860_item	3733621	et	0	main
omastavas	doc_491521501860_item	3733622	et	0	main
käändes	doc_491521501860_item	3733623	et	0	main
ei	doc_491521501860_item	3733624	et	0	main
ühildu	doc_491521501860_item	3733625	et	0	main
kõik	doc_491521501860_item	3733626	et	0	main
oli	doc_491521501860_item	3733627	et	0	main
terved	doc_491521501860_item	3733628	et	0	main
predikatsioon	doc_491521501860_item	3733629	et	0	main
9	doc_491521501860_item	3733630	et	0	main
omadussõna	doc_491521501860_item	3733631	et	0	main
võrdlusastmed	doc_491521501860_item	3733632	et	0	main
kõige	doc_491521501860_item	3733633	et	0	main
õnnelikuim	doc_491521501860_item	3733634	et	0	main
päev	doc_491521501860_item	3733635	et	0	main
ilusam	doc_491521501860_item	3733636	et	0	main
ja	doc_491521501860_item	3733637	et	0	main
pidulikam	doc_491521501860_item	3733638	et	0	main
eelneva	doc_491521501860_item	3733639	et	0	main
sõna	doc_491521501860_item	3733640	et	0	main
vormi	doc_491521501860_item	3733641	et	0	main
mõju	doc_491521501860_item	3733642	et	0	main
ilus	doc_491521501860_item	3733643	et	0	main
ilusa	doc_491521501860_item	3733644	et	0	main
m	doc_491521501860_item	3733645	et	0	main
ilusam	doc_491521501860_item	3733646	et	0	main
pidulik	doc_491521501860_item	3733647	et	0	main
pidulika	doc_491521501860_item	3733648	et	0	main
m	doc_491521501860_item	3733649	et	0	main
pidulikam	doc_491521501860_item	3733650	et	0	main
10	doc_491521501860_item	3733651	et	0	main
verbivormide	doc_491521501860_item	3733652	et	0	main
moodustusvead	doc_491521501860_item	3733653	et	0	main
mari	doc_491521501860_item	3733654	et	0	main
oleb	doc_491521501860_item	3733655	et	0	main
oma	doc_491521501860_item	3733656	et	0	main
tööga	doc_491521501860_item	3733657	et	0	main
rahul	doc_491521501860_item	3733658	et	0	main
teiste	doc_491521501860_item	3733659	et	0	main
vormide	doc_491521501860_item	3733660	et	0	main
mõju	doc_491521501860_item	3733661	et	0	main
keelesisene	doc_491521501860_item	3733662	et	0	main
interferents	doc_491521501860_item	3733663	et	0	main
olen	doc_491521501860_item	3733664	et	0	main
oled	doc_491521501860_item	3733665	et	0	main
oleb	doc_491521501860_item	3733666	et	0	main
oleme	doc_491521501860_item	3733667	et	0	main
jne	doc_491521501860_item	3733668	et	0	main
õpitav	doc_491521501860_item	3733669	et	0	main
reegel	doc_491521501860_item	3733670	et	0	main
vanaema	doc_491521501860_item	3733671	et	0	main
nägeb	doc_491521501860_item	3733672	et	0	main
kuri	doc_491521501860_item	3733673	et	0	main
koerat	doc_491521501860_item	3733674	et	0	main
eile	doc_491521501860_item	3733675	et	0	main
sõnavormi	doc_491521501860_item	3733676	et	0	main
kasutus-	doc_491521501860_item	3733677	et	0	main
ja	doc_491521501860_item	3733678	et	0	main
modustusvead	doc_491521501860_item	3733679	et	0	main
nägema	doc_491521501860_item	3733680	et	0	main
keda	doc_491521501860_item	3733681	et	0	main
mida	doc_491521501860_item	3733682	et	0	main
kuri	doc_491521501860_item	3733683	et	0	main
kurja	doc_491521501860_item	3733684	et	0	main
kurja	doc_491521501860_item	3733685	et	0	main
koer	doc_491521501860_item	3733686	et	0	main
koera	doc_491521501860_item	3733687	et	0	main
koera	doc_491521501860_item	3733688	et	0	main
os	doc_491521501860_item	3733689	et	0	main
kääne	doc_491521501860_item	3733690	et	0	main
sõnajärje	doc_491521501860_item	3733691	et	0	main
vead	doc_491521501860_item	3733692	et	0	main
õpilased	doc_491521501860_item	3733693	et	0	main
peavad	doc_491521501860_item	3733694	et	0	main
kardama	doc_491521501860_item	3733695	et	0	main
õpetaja	doc_491521501860_item	3733696	et	0	main
ma-inf	doc_491521501860_item	3733697	et	0	main
on	doc_491521501860_item	3733698	et	0	main
moodustatud	doc_491521501860_item	3733699	et	0	main
kardan	doc_491521501860_item	3733700	et	0	main
ma	doc_491521501860_item	3733701	et	0	main
kardama	doc_491521501860_item	3733702	et	0	main
rektsiooniviga	doc_491521501860_item	3733703	et	0	main
kartma	doc_491521501860_item	3733704	et	0	main
kedamida	doc_491521501860_item	3733705	et	0	main
kuigi	doc_491521501860_item	3733706	et	0	main
võib	doc_491521501860_item	3733707	et	0	main
oletada	doc_491521501860_item	3733708	et	0	main
et	doc_491521501860_item	3733709	et	0	main
nimisõna	doc_491521501860_item	3733710	et	0	main
vorm	doc_491521501860_item	3733711	et	0	main
on	doc_491521501860_item	3733712	et	0	main
kasutatud	doc_491521501860_item	3733713	et	0	main
õigesti	doc_491521501860_item	3733714	et	0	main
siin	doc_491521501860_item	3733715	et	0	main
on	doc_491521501860_item	3733716	et	0	main
aga	doc_491521501860_item	3733717	et	0	main
vormimoodustusviga	doc_491521501860_item	3733718	et	0	main
st	doc_491521501860_item	3733719	et	0	main
valesti	doc_491521501860_item	3733720	et	0	main
moodustatud	doc_491521501860_item	3733721	et	0	main
osastav	doc_491521501860_item	3733722	et	0	main
kääne	doc_491521501860_item	3733723	et	0	main
õpetaja	doc_491521501860_item	3733724	et	0	main
alguses	doc_491521501860_item	3733725	et	0	main
laulasid	doc_491521501860_item	3733726	et	0	main
reeglina	doc_491521501860_item	3733727	et	0	main
moodustub	doc_491521501860_item	3733728	et	0	main
lihtminevik	doc_491521501860_item	3733729	et	0	main
jaatav	doc_491521501860_item	3733730	et	0	main
kõne	doc_491521501860_item	3733731	et	0	main
ma-infinitiivist	doc_491521501860_item	3733732	et	0	main
laulma	doc_491521501860_item	3733733	et	0	main
si-	doc_491521501860_item	3733734	et	0	main
d	doc_491521501860_item	3733735	et	0	main
laulsid	doc_491521501860_item	3733736	et	0	main
siin	doc_491521501860_item	3733737	et	0	main
aga	doc_491521501860_item	3733738	et	0	main
laulavad	doc_491521501860_item	3733739	et	0	main
si-	doc_491521501860_item	3733740	et	0	main
d	doc_491521501860_item	3733741	et	0	main
laulasid	doc_491521501860_item	3733742	et	0	main
sõidasin	doc_491521501860_item	3733743	et	0	main
vorm	doc_491521501860_item	3733744	et	0	main
moodustatud	doc_491521501860_item	3733745	et	0	main
sõidan	doc_491521501860_item	3733746	et	0	main
si-	doc_491521501860_item	3733747	et	0	main
lihtmineviku	doc_491521501860_item	3733748	et	0	main
tunnus	doc_491521501860_item	3733749	et	0	main
n	doc_491521501860_item	3733750	et	0	main
minu	doc_491521501860_item	3733751	et	0	main
õde	doc_491521501860_item	3733752	et	0	main
tegeb	doc_491521501860_item	3733753	et	0	main
süüa	doc_491521501860_item	3733754	et	0	main
tegema	doc_491521501860_item	3733755	et	0	main
3	doc_491521501860_item	3733756	et	0	main
isiku	doc_491521501860_item	3733757	et	0	main
pöördelõpp	doc_491521501860_item	3733758	et	0	main
b	doc_491521501860_item	3733759	et	0	main
tegeb	doc_491521501860_item	3733760	et	0	main
ta	doc_491521501860_item	3733761	et	0	main
nägis	doc_491521501860_item	3733762	et	0	main
mõned	doc_491521501860_item	3733763	et	0	main
on	doc_491521501860_item	3733764	et	0	main
selgeks	doc_491521501860_item	3733765	et	0	main
õppinud	doc_491521501860_item	3733766	et	0	main
et	doc_491521501860_item	3733767	et	0	main
lihtminevikus	doc_491521501860_item	3733768	et	0	main
lm	doc_491521501860_item	3733769	et	0	main
on	doc_491521501860_item	3733770	et	0	main
3	doc_491521501860_item	3733771	et	0	main
isiku	doc_491521501860_item	3733772	et	0	main
tunnus	doc_491521501860_item	3733773	et	0	main
s	doc_491521501860_item	3733774	et	0	main
ja	doc_491521501860_item	3733775	et	0	main
kasutavad	doc_491521501860_item	3733776	et	0	main
seda	doc_491521501860_item	3733777	et	0	main
pöördelõpuna	doc_491521501860_item	3733778	et	0	main
igat	doc_491521501860_item	3733779	et	0	main
vormi	doc_491521501860_item	3733780	et	0	main
moodustades	doc_491521501860_item	3733781	et	0	main
ma	doc_491521501860_item	3733782	et	0	main
nägin	doc_491521501860_item	3733783	et	0	main
sa	doc_491521501860_item	3733784	et	0	main
nägid	doc_491521501860_item	3733785	et	0	main
ta	doc_491521501860_item	3733786	et	0	main
nägis	doc_491521501860_item	3733787	et	0	main
jne	doc_491521501860_item	3733788	et	0	main
isa	doc_491521501860_item	3733789	et	0	main
teas	doc_491521501860_item	3733790	et	0	main
tean	doc_491521501860_item	3733791	et	0	main
lm	doc_491521501860_item	3733792	et	0	main
tunnus	doc_491521501860_item	3733793	et	0	main
s	doc_491521501860_item	3733794	et	0	main
teas	doc_491521501860_item	3733795	et	0	main
lähema	doc_491521501860_item	3733796	et	0	main
vormi	doc_491521501860_item	3733797	et	0	main
moodustamist	doc_491521501860_item	3733798	et	0	main
mõjutas	doc_491521501860_item	3733799	et	0	main
oleviku	doc_491521501860_item	3733800	et	0	main
l	doc_491521501860_item	3733801	et	0	main
pöörde	doc_491521501860_item	3733802	et	0	main
vorm	doc_491521501860_item	3733803	et	0	main
lähen	doc_491521501860_item	3733804	et	0	main
algperioodil	doc_491521501860_item	3733805	et	0	main
juhtub	doc_491521501860_item	3733806	et	0	main
see	doc_491521501860_item	3733807	et	0	main
väga	doc_491521501860_item	3733808	et	0	main
tihti	doc_491521501860_item	3733809	et	0	main
11	doc_491521501860_item	3733810	et	0	main
verbivormide	doc_491521501860_item	3733811	et	0	main
valiku	doc_491521501860_item	3733812	et	0	main
vead	doc_491521501860_item	3733813	et	0	main
kalevipoeg	doc_491521501860_item	3733814	et	0	main
hakkas	doc_491521501860_item	3733815	et	0	main
sõitab	doc_491521501860_item	3733816	et	0	main
maailma	doc_491521501860_item	3733817	et	0	main
lõppu	doc_491521501860_item	3733818	et	0	main
sõitab	doc_491521501860_item	3733819	et	0	main
mõjutas	doc_491521501860_item	3733820	et	0	main
eelmine	doc_491521501860_item	3733821	et	0	main
sõnavorm	doc_491521501860_item	3733822	et	0	main
õige	doc_491521501860_item	3733823	et	0	main
hakkama	doc_491521501860_item	3733824	et	0	main
ma-inf	doc_491521501860_item	3733825	et	0	main
küünlapäeval	doc_491521501860_item	3733826	et	0	main
tegid	doc_491521501860_item	3733827	et	0	main
küünlad	doc_491521501860_item	3733828	et	0	main
interferentne	doc_491521501860_item	3733829	et	0	main
viga-	doc_491521501860_item	3733830	et	0	main
vene	doc_491521501860_item	3733831	et	0	main
keeles	doc_491521501860_item	3733832	et	0	main
ei	doc_491521501860_item	3733833	et	0	main
ole	doc_491521501860_item	3733834	et	0	main
vahet	doc_491521501860_item	3733835	et	0	main
kas	doc_491521501860_item	3733836	et	0	main
lause	doc_491521501860_item	3733837	et	0	main
on	doc_491521501860_item	3733838	et	0	main
isikuline	doc_491521501860_item	3733839	et	0	main
või	doc_491521501860_item	3733840	et	0	main
umbisikuline	doc_491521501860_item	3733841	et	0	main
kasutatakse	doc_491521501860_item	3733842	et	0	main
ühte	doc_491521501860_item	3733843	et	0	main
ja	doc_491521501860_item	3733844	et	0	main
sama	doc_491521501860_item	3733845	et	0	main
vormi	doc_491521501860_item	3733846	et	0	main
sellel	doc_491521501860_item	3733847	et	0	main
päeval	doc_491521501860_item	3733848	et	0	main
on	doc_491521501860_item	3733849	et	0	main
ka	doc_491521501860_item	3733850	et	0	main
tegelevad	doc_491521501860_item	3733851	et	0	main
juuste	doc_491521501860_item	3733852	et	0	main
hoolitsemisega	doc_491521501860_item	3733853	et	0	main
infinitiivi	doc_491521501860_item	3733854	et	0	main
kasutamine	doc_491521501860_item	3733855	et	0	main
a	doc_491521501860_item	3733856	et	0	main
temal	doc_491521501860_item	3733857	et	0	main
tuli	doc_491521501860_item	3733858	et	0	main
tagasi	doc_491521501860_item	3733859	et	0	main
minema	doc_491521501860_item	3733860	et	0	main
kui	doc_491521501860_item	3733861	et	0	main
õpilane	doc_491521501860_item	3733862	et	0	main
ei	doc_491521501860_item	3733863	et	0	main
saa	doc_491521501860_item	3733864	et	0	main
lausest	doc_491521501860_item	3733865	et	0	main
aru	doc_491521501860_item	3733866	et	0	main
ega	doc_491521501860_item	3733867	et	0	main
tea	doc_491521501860_item	3733868	et	0	main
selle	doc_491521501860_item	3733869	et	0	main
tegusõna	doc_491521501860_item	3733870	et	0	main
kasutamise	doc_491521501860_item	3733871	et	0	main
võimalusi	doc_491521501860_item	3733872	et	0	main
teeb	doc_491521501860_item	3733873	et	0	main
ta	doc_491521501860_item	3733874	et	0	main
automaatselt	doc_491521501860_item	3733875	et	0	main
tulema	doc_491521501860_item	3733876	et	0	main
ma-infinitiiv	doc_491521501860_item	3733877	et	0	main
b	doc_491521501860_item	3733878	et	0	main
virgutab	doc_491521501860_item	3733879	et	0	main
elada	doc_491521501860_item	3733880	et	0	main
virgutab	doc_491521501860_item	3733881	et	0	main
ma-inf	doc_491521501860_item	3733882	et	0	main
c	doc_491521501860_item	3733883	et	0	main
nii	doc_491521501860_item	3733884	et	0	main
ei	doc_491521501860_item	3733885	et	0	main
saa	doc_491521501860_item	3733886	et	0	main
elama	doc_491521501860_item	3733887	et	0	main
saama	doc_491521501860_item	3733888	et	0	main
da-inf	doc_491521501860_item	3733889	et	0	main
aga	doc_491521501860_item	3733890	et	0	main
hakkama	doc_491521501860_item	3733891	et	0	main
saama	doc_491521501860_item	3733892	et	0	main
d	doc_491521501860_item	3733893	et	0	main
ei	doc_491521501860_item	3733894	et	0	main
ole	doc_491521501860_item	3733895	et	0	main
nõus	doc_491521501860_item	3733896	et	0	main
pesu	doc_491521501860_item	3733897	et	0	main
pesta	doc_491521501860_item	3733898	et	0	main
õpilased	doc_491521501860_item	3733899	et	0	main
on	doc_491521501860_item	3733900	et	0	main
harjunud	doc_491521501860_item	3733901	et	0	main
on	doc_491521501860_item	3733902	et	0	main
raske	doc_491521501860_item	3733903	et	0	main
on	doc_491521501860_item	3733904	et	0	main
keeruline	doc_491521501860_item	3733905	et	0	main
on	doc_491521501860_item	3733906	et	0	main
vaja	doc_491521501860_item	3733907	et	0	main
jne	doc_491521501860_item	3733908	et	0	main
tegusõnade	doc_491521501860_item	3733909	et	0	main
juures	doc_491521501860_item	3733910	et	0	main
da-inf	doc_491521501860_item	3733911	et	0	main
kasutama	doc_491521501860_item	3733912	et	0	main
12	doc_491521501860_item	3733913	et	0	main
sõnatasandi	doc_491521501860_item	3733914	et	0	main
vead	doc_491521501860_item	3733915	et	0	main
a	doc_491521501860_item	3733916	et	0	main
tuletised	doc_491521501860_item	3733917	et	0	main
too	doc_491521501860_item	3733918	et	0	main
tooma	doc_491521501860_item	3733919	et	0	main
odav	doc_491521501860_item	3733920	et	0	main
odavasti	doc_491521501860_item	3733921	et	0	main
rõõmus	doc_491521501860_item	3733922	et	0	main
rõõmusti	doc_491521501860_item	3733923	et	0	main
roheline	doc_491521501860_item	3733924	et	0	main
rohelisekas	doc_491521501860_item	3733925	et	0	main
vorm	doc_491521501860_item	3733926	et	0	main
moodustatud	doc_491521501860_item	3733927	et	0	main
selle	doc_491521501860_item	3733928	et	0	main
skeemi	doc_491521501860_item	3733929	et	0	main
jargi	doc_491521501860_item	3733930	et	0	main
roheline	doc_491521501860_item	3733931	et	0	main
rohelise	doc_491521501860_item	3733932	et	0	main
om	doc_491521501860_item	3733933	et	0	main
kas-liide	doc_491521501860_item	3733934	et	0	main
rohelisekas	doc_491521501860_item	3733935	et	0	main
püha	doc_491521501860_item	3733936	et	0	main
pühama	doc_491521501860_item	3733937	et	0	main
po	doc_491521501860_item	3733938	et	0	main
pühitsema	doc_491521501860_item	3733939	et	0	main
b	doc_491521501860_item	3733940	et	0	main
liitsõna	doc_491521501860_item	3733941	et	0	main
ja	doc_491521501860_item	3733942	et	0	main
sõnaühend	doc_491521501860_item	3733943	et	0	main
suvilinn	doc_491521501860_item	3733944	et	0	main
olime	doc_491521501860_item	3733945	et	0	main
toas	doc_491521501860_item	3733946	et	0	main
hirmu	doc_491521501860_item	3733947	et	0	main
ja	doc_491521501860_item	3733948	et	0	main
restoranis	doc_491521501860_item	3733949	et	0	main
interferentne	doc_491521501860_item	3733950	et	0	main
viga	doc_491521501860_item	3733951	et	0	main
xomxama	doc_491521501860_item	3733952	et	0	main
cmpaxa	doc_491521501860_item	3733953	et	0	main
a	doc_491521501860_item	3733954	et	0	main
xomname	doc_491521501860_item	3733955	et	0	main
ue2o	doc_491521501860_item	3733956	et	0	main
pod	doc_491521501860_item	3733957	et	0	main
n	doc_491521501860_item	3733958	et	0	main
cmpaxa	doc_491521501860_item	3733959	et	0	main
kus	doc_491521501860_item	3733960	et	0	main
toas	doc_491521501860_item	3733961	et	0	main
mille	doc_491521501860_item	3733962	et	0	main
om	doc_491521501860_item	3733963	et	0	main
kadne	doc_491521501860_item	3733964	et	0	main
hirmu-	doc_491521501860_item	3733965	et	0	main
otsene	doc_491521501860_item	3733966	et	0	main
tõlge	doc_491521501860_item	3733967	et	0	main
vene	doc_491521501860_item	3733968	et	0	main
keelest	doc_491521501860_item	3733969	et	0	main
c	doc_491521501860_item	3733970	et	0	main
uusmoodustised	doc_491521501860_item	3733971	et	0	main
keki	doc_491521501860_item	3733972	et	0	main
viskas	doc_491521501860_item	3733973	et	0	main
kassi	doc_491521501860_item	3733974	et	0	main
välja	doc_491521501860_item	3733975	et	0	main
keegi	doc_491521501860_item	3733976	et	0	main
elab	doc_491521501860_item	3733977	et	0	main
meeiga	doc_491521501860_item	3733978	et	0	main
meiega	doc_491521501860_item	3733979	et	0	main
võtsime	doc_491521501860_item	3733980	et	0	main
kasse	doc_491521501860_item	3733981	et	0	main
kaasa	doc_491521501860_item	3733982	et	0	main
d	doc_491521501860_item	3733983	et	0	main
enesekohased	doc_491521501860_item	3733984	et	0	main
tegusõnad	doc_491521501860_item	3733985	et	0	main
alustab	doc_491521501860_item	3733986	et	0	main
konflikt	doc_491521501860_item	3733987	et	0	main
kättemaksuga	doc_491521501860_item	3733988	et	0	main
tegusõna	doc_491521501860_item	3733989	et	0	main
valik	doc_491521501860_item	3733990	et	0	main
sõltub	doc_491521501860_item	3733991	et	0	main
kontekstist	doc_491521501860_item	3733992	et	0	main
mida	doc_491521501860_item	3733993	et	0	main
on	doc_491521501860_item	3733994	et	0	main
tahetud	doc_491521501860_item	3733995	et	0	main
öelda	doc_491521501860_item	3733996	et	0	main
lause	doc_491521501860_item	3733997	et	0	main
on	doc_491521501860_item	3733998	et	0	main
võetud	doc_491521501860_item	3733999	et	0	main
essees	doc_491521501860_item	3734000	et	0	main
kust	doc_491521501860_item	3734001	et	0	main
selgub	doc_491521501860_item	3734002	et	0	main
et	doc_491521501860_item	3734003	et	0	main
see	doc_491521501860_item	3734004	et	0	main
pidi	doc_491521501860_item	3734005	et	0	main
olema	doc_491521501860_item	3734006	et	0	main
algab	doc_491521501860_item	3734007	et	0	main
konflikt	doc_491521501860_item	3734008	et	0	main
kättemaksuga	doc_491521501860_item	3734009	et	0	main
mis	doc_491521501860_item	3734010	et	0	main
algab	doc_491521501860_item	3734011	et	0	main
aga	doc_491521501860_item	3734012	et	0	main
alustama	doc_491521501860_item	3734013	et	0	main
nõuab	doc_491521501860_item	3734014	et	0	main
objekti	doc_491521501860_item	3734015	et	0	main
mida	doc_491521501860_item	3734016	et	0	main
pidu	doc_491521501860_item	3734017	et	0	main
lõppetas	doc_491521501860_item	3734018	et	0	main
tulestikuga	doc_491521501860_item	3734019	et	0	main
samuti	doc_491521501860_item	3734020	et	0	main
lõppema	doc_491521501860_item	3734021	et	0	main
miski	doc_491521501860_item	3734022	et	0	main
lõpeb	doc_491521501860_item	3734023	et	0	main
ja	doc_491521501860_item	3734024	et	0	main
lõpetama	doc_491521501860_item	3734025	et	0	main
keegi	doc_491521501860_item	3734026	et	0	main
lõpetab	doc_491521501860_item	3734027	et	0	main
midagi	doc_491521501860_item	3734028	et	0	main
veel	doc_491521501860_item	3734029	et	0	main
üks	doc_491521501860_item	3734030	et	0	main
viga	doc_491521501860_item	3734031	et	0	main
lõppetama	doc_491521501860_item	3734032	et	0	main
võib	doc_491521501860_item	3734033	et	0	main
oletada	doc_491521501860_item	3734034	et	0	main
et	doc_491521501860_item	3734035	et	0	main
sellele	doc_491521501860_item	3734036	et	0	main
mõjus	doc_491521501860_item	3734037	et	0	main
tegusõna	doc_491521501860_item	3734038	et	0	main
lõppema	doc_491521501860_item	3734039	et	0	main
selliseid	doc_491521501860_item	3734040	et	0	main
tegusõnu	doc_491521501860_item	3734041	et	0	main
on	doc_491521501860_item	3734042	et	0	main
väga	doc_491521501860_item	3734043	et	0	main
palju	doc_491521501860_item	3734044	et	0	main
13	doc_491521501860_item	3734045	et	0	main
rektsioonivead	doc_491521501860_item	3734046	et	0	main
aita	doc_491521501860_item	3734047	et	0	main
mulle	doc_491521501860_item	3734048	et	0	main
ja	doc_491521501860_item	3734049	et	0	main
kas	doc_491521501860_item	3734050	et	0	main
sa	doc_491521501860_item	3734051	et	0	main
tahad	doc_491521501860_item	3734052	et	0	main
mulle	doc_491521501860_item	3734053	et	0	main
aidata	doc_491521501860_item	3734054	et	0	main
aitama	doc_491521501860_item	3734055	et	0	main
verb	doc_491521501860_item	3734056	et	0	main
nõuab	doc_491521501860_item	3734057	et	0	main
osastavat	doc_491521501860_item	3734058	et	0	main
käänet	doc_491521501860_item	3734059	et	0	main
aitama	doc_491521501860_item	3734060	et	0	main
keda	doc_491521501860_item	3734061	et	0	main
aita	doc_491521501860_item	3734062	et	0	main
mind	doc_491521501860_item	3734063	et	0	main
käisin	doc_491521501860_item	3734064	et	0	main
kooli	doc_491521501860_item	3734065	et	0	main
lähevad	doc_491521501860_item	3734066	et	0	main
kodus	doc_491521501860_item	3734067	et	0	main
käima	doc_491521501860_item	3734068	et	0	main
kus	doc_491521501860_item	3734069	et	0	main
minema	doc_491521501860_item	3734070	et	0	main
kuhu	doc_491521501860_item	3734071	et	0	main
õpilased	doc_491521501860_item	3734072	et	0	main
ajavad	doc_491521501860_item	3734073	et	0	main
tihti	doc_491521501860_item	3734074	et	0	main
segi	doc_491521501860_item	3734075	et	0	main
minema	doc_491521501860_item	3734076	et	0	main
käima	doc_491521501860_item	3734077	et	0	main
tulema	doc_491521501860_item	3734078	et	0	main
tegusõnad	doc_491521501860_item	3734079	et	0	main
ja	doc_491521501860_item	3734080	et	0	main
nende	doc_491521501860_item	3734081	et	0	main
rektsioonid	doc_491521501860_item	3734082	et	0	main
mulle	doc_491521501860_item	3734083	et	0	main
ei	doc_491521501860_item	3734084	et	0	main
vaja	doc_491521501860_item	3734085	et	0	main
vene	doc_491521501860_item	3734086	et	0	main
keele	doc_491521501860_item	3734087	et	0	main
mõju	doc_491521501860_item	3734088	et	0	main
hue	doc_491521501860_item	3734089	et	0	main
ne	doc_491521501860_item	3734090	et	0	main
nado	doc_491521501860_item	3734091	et	0	main
konzy	doc_491521501860_item	3734092	et	0	main
naue	doc_491521501860_item	3734093	et	0	main
kellele	doc_491521501860_item	3734094	et	0	main
mulle	doc_491521501860_item	3734095	et	0	main
otsetõlge	doc_491521501860_item	3734096	et	0	main
vene	doc_491521501860_item	3734097	et	0	main
keelest	doc_491521501860_item	3734098	et	0	main
minu	doc_491521501860_item	3734099	et	0	main
vend	doc_491521501860_item	3734100	et	0	main
jääb	doc_491521501860_item	3734101	et	0	main
kodu	doc_491521501860_item	3734102	et	0	main
sest	doc_491521501860_item	3734103	et	0	main
ta	doc_491521501860_item	3734104	et	0	main
on	doc_491521501860_item	3734105	et	0	main
haige	doc_491521501860_item	3734106	et	0	main
jääma	doc_491521501860_item	3734107	et	0	main
kuhu	doc_491521501860_item	3734108	et	0	main
inimene	doc_491521501860_item	3734109	et	0	main
rõõmustab	doc_491521501860_item	3734110	et	0	main
elu	doc_491521501860_item	3734111	et	0	main
rõõmustama	doc_491521501860_item	3734112	et	0	main
mille	doc_491521501860_item	3734113	et	0	main
üle	doc_491521501860_item	3734114	et	0	main
inimene	doc_491521501860_item	3734115	et	0	main
sai	doc_491521501860_item	3734116	et	0	main
aru	doc_491521501860_item	3734117	et	0	main
kõik	doc_491521501860_item	3734118	et	0	main
aru	doc_491521501860_item	3734119	et	0	main
saama	doc_491521501860_item	3734120	et	0	main
kellestmillest	doc_491521501860_item	3734121	et	0	main
verbirektsioone	doc_491521501860_item	3734122	et	0	main
peab	doc_491521501860_item	3734123	et	0	main
õppima	doc_491521501860_item	3734124	et	0	main
isa	doc_491521501860_item	3734125	et	0	main
keelab	doc_491521501860_item	3734126	et	0	main
mulle	doc_491521501860_item	3734127	et	0	main
jalutada	doc_491521501860_item	3734128	et	0	main
kaua	doc_491521501860_item	3734129	et	0	main
keelab	doc_491521501860_item	3734130	et	0	main
kellel	doc_491521501860_item	3734131	et	0	main
da-inf	doc_491521501860_item	3734132	et	0	main
õpilase	doc_491521501860_item	3734133	et	0	main
jaoks	doc_491521501860_item	3734134	et	0	main
on	doc_491521501860_item	3734135	et	0	main
keerulised	doc_491521501860_item	3734136	et	0	main
tegusõnad	doc_491521501860_item	3734137	et	0	main
mis	doc_491521501860_item	3734138	et	0	main
esinevad	doc_491521501860_item	3734139	et	0	main
selles	doc_491521501860_item	3734140	et	0	main
konstruktsioonis	doc_491521501860_item	3734141	et	0	main
nt	doc_491521501860_item	3734142	et	0	main
keelama	doc_491521501860_item	3734143	et	0	main
lubama	doc_491521501860_item	3734144	et	0	main
soovitama	doc_491521501860_item	3734145	et	0	main
käskima	doc_491521501860_item	3734146	et	0	main
paluma	doc_491521501860_item	3734147	et	0	main
jt	doc_491521501860_item	3734148	et	0	main
14	doc_491521501860_item	3734149	et	0	main
sõnajärjevead	doc_491521501860_item	3734150	et	0	main
võib	doc_491521501860_item	3734151	et	0	main
jälgida	doc_491521501860_item	3734152	et	0	main
eriti	doc_491521501860_item	3734153	et	0	main
tugevat	doc_491521501860_item	3734154	et	0	main
interferentsiooni	doc_491521501860_item	3734155	et	0	main
see	doc_491521501860_item	3734156	et	0	main
väga	doc_491521501860_item	3734157	et	0	main
meeldis	doc_491521501860_item	3734158	et	0	main
mulle	doc_491521501860_item	3734159	et	0	main
armastus	doc_491521501860_item	3734160	et	0	main
kahtlemata	doc_491521501860_item	3734161	et	0	main
võib	doc_491521501860_item	3734162	et	0	main
imet	doc_491521501860_item	3734163	et	0	main
tegema	doc_491521501860_item	3734164	et	0	main
hommikul	doc_491521501860_item	3734165	et	0	main
ma	doc_491521501860_item	3734166	et	0	main
lähen	doc_491521501860_item	3734167	et	0	main
kooli	doc_491521501860_item	3734168	et	0	main
seda	doc_491521501860_item	3734169	et	0	main
veatüüpi	doc_491521501860_item	3734170	et	0	main
võib	doc_491521501860_item	3734171	et	0	main
peaaegu	doc_491521501860_item	3734172	et	0	main
igast	doc_491521501860_item	3734173	et	0	main
lausest	doc_491521501860_item	3734174	et	0	main
leida	doc_491521501860_item	3734175	et	0	main
kusjuures	doc_491521501860_item	3734176	et	0	main
on	doc_491521501860_item	3734177	et	0	main
siin	doc_491521501860_item	3734178	et	0	main
väga	doc_491521501860_item	3734179	et	0	main
hästi	doc_491521501860_item	3734180	et	0	main
jälgitav	doc_491521501860_item	3734181	et	0	main
vene	doc_491521501860_item	3734182	et	0	main
keele	doc_491521501860_item	3734183	et	0	main
mõju	doc_491521501860_item	3734184	et	0	main
eesti	doc_491521501860_item	3734185	et	0	main
keeles	doc_491521501860_item	3734186	et	0	main
on	doc_491521501860_item	3734187	et	0	main
tavaline	doc_491521501860_item	3734188	et	0	main
v2	doc_491521501860_item	3734189	et	0	main
reegel	doc_491521501860_item	3734190	et	0	main
vene	doc_491521501860_item	3734191	et	0	main
keeles	doc_491521501860_item	3734192	et	0	main
on	doc_491521501860_item	3734193	et	0	main
palju	doc_491521501860_item	3734194	et	0	main
vabam	doc_491521501860_item	3734195	et	0	main
sõnajarg	doc_491521501860_item	3734196	et	0	main
ega	doc_491521501860_item	3734197	et	0	main
ole	doc_491521501860_item	3734198	et	0	main
nii	doc_491521501860_item	3734199	et	0	main
rangeid	doc_491521501860_item	3734200	et	0	main
reegleid	doc_491521501860_item	3734201	et	0	main
seetõttu	doc_491521501860_item	3734202	et	0	main
on	doc_491521501860_item	3734203	et	0	main
vene	doc_491521501860_item	3734204	et	0	main
keelt	doc_491521501860_item	3734205	et	0	main
emakeelena	doc_491521501860_item	3734206	et	0	main
kõnelevatel	doc_491521501860_item	3734207	et	0	main
inimestel	doc_491521501860_item	3734208	et	0	main
raske	doc_491521501860_item	3734209	et	0	main
seda	doc_491521501860_item	3734210	et	0	main
jälgida	doc_491521501860_item	3734211	et	0	main
15	doc_491521501860_item	3734212	et	0	main
muud	doc_491521501860_item	3734213	et	0	main
huvitavad	doc_491521501860_item	3734214	et	0	main
lausedsõnaühendid	doc_491521501860_item	3734215	et	0	main
kus	doc_491521501860_item	3734216	et	0	main
leidub	doc_491521501860_item	3734217	et	0	main
väga	doc_491521501860_item	3734218	et	0	main
palju	doc_491521501860_item	3734219	et	0	main
erinevaid	doc_491521501860_item	3734220	et	0	main
vigu	doc_491521501860_item	3734221	et	0	main
mulle	doc_491521501860_item	3734222	et	0	main
oli	doc_491521501860_item	3734223	et	0	main
väga	doc_491521501860_item	3734224	et	0	main
huvitavalt	doc_491521501860_item	3734225	et	0	main
seda	doc_491521501860_item	3734226	et	0	main
lugeda	doc_491521501860_item	3734227	et	0	main
emakeele	doc_491521501860_item	3734228	et	0	main
mõju	doc_491521501860_item	3734229	et	0	main
venekeelse	doc_491521501860_item	3734230	et	0	main
lause	doc_491521501860_item	3734231	et	0	main
mile	doc_491521501860_item	3734232	et	0	main
6bl70	doc_491521501860_item	3734233	et	0	main
ouercb	doc_491521501860_item	3734234	et	0	main
uxmepecuo	doc_491521501860_item	3734235	et	0	main
3mo	doc_491521501860_item	3734236	et	0	main
uumamb	doc_491521501860_item	3734237	et	0	main
otsene	doc_491521501860_item	3734238	et	0	main
tõlge	doc_491521501860_item	3734239	et	0	main
mke	doc_491521501860_item	3734240	et	0	main
kellele	doc_491521501860_item	3734241	et	0	main
mulle	doc_491521501860_item	3734242	et	0	main
6bano	doc_491521501860_item	3734243	et	0	main
ouenb	doc_491521501860_item	3734244	et	0	main
uhmepecxo	doc_491521501860_item	3734245	et	0	main
määrsona	doc_491521501860_item	3734246	et	0	main
kuidas	doc_491521501860_item	3734247	et	0	main
huvitavalt	doc_491521501860_item	3734248	et	0	main
smo	doc_491521501860_item	3734249	et	0	main
uumamb	doc_491521501860_item	3734250	et	0	main
üks	doc_491521501860_item	3734251	et	0	main
kord	doc_491521501860_item	3734252	et	0	main
mina	doc_491521501860_item	3734253	et	0	main
ja	doc_491521501860_item	3734254	et	0	main
minu	doc_491521501860_item	3734255	et	0	main
sõbraga	doc_491521501860_item	3734256	et	0	main
jalutada	doc_491521501860_item	3734257	et	0	main
õues	doc_491521501860_item	3734258	et	0	main
ja	doc_491521501860_item	3734259	et	0	main
vaata	doc_491521501860_item	3734260	et	0	main
autoga	doc_491521501860_item	3734261	et	0	main
hommes	doc_491521501860_item	3734262	et	0	main
päeval	doc_491521501860_item	3734263	et	0	main
ma	doc_491521501860_item	3734264	et	0	main
käin	doc_491521501860_item	3734265	et	0	main
õue	doc_491521501860_item	3734266	et	0	main
ema	doc_491521501860_item	3734267	et	0	main
ja	doc_491521501860_item	3734268	et	0	main
isa	doc_491521501860_item	3734269	et	0	main
käivad	doc_491521501860_item	3734270	et	0	main
tööle	doc_491521501860_item	3734271	et	0	main
ma	doc_491521501860_item	3734272	et	0	main
algan	doc_491521501860_item	3734273	et	0	main
tegin	doc_491521501860_item	3734274	et	0	main
kord	doc_491521501860_item	3734275	et	0	main
pärast	doc_491521501860_item	3734276	et	0	main
ma	doc_491521501860_item	3734277	et	0	main
tulid	doc_491521501860_item	3734278	et	0	main
koju	doc_491521501860_item	3734279	et	0	main
riietun	doc_491521501860_item	3734280	et	0	main
ja	doc_491521501860_item	3734281	et	0	main
käisin	doc_491521501860_item	3734282	et	0	main
kooli	doc_491521501860_item	3734283	et	0	main
hästi	doc_491521501860_item	3734284	et	0	main
et	doc_491521501860_item	3734285	et	0	main
meres	doc_491521501860_item	3734286	et	0	main
oli	doc_491521501860_item	3734287	et	0	main
mees	doc_491521501860_item	3734288	et	0	main
maardust	doc_491521501860_item	3734289	et	0	main
raadio	doc_491521501860_item	3734290	et	0	main
tihedus	doc_491521501860_item	3734291	et	0	main
emakeelest	doc_491521501860_item	3734292	et	0	main
põhjustatud	doc_491521501860_item	3734293	et	0	main
viga	doc_491521501860_item	3734294	et	0	main
vene	doc_491521501860_item	3734295	et	0	main
keeles	doc_491521501860_item	3734296	et	0	main
võib	doc_491521501860_item	3734297	et	0	main
ka	doc_491521501860_item	3734298	et	0	main
raadio	doc_491521501860_item	3734299	et	0	main
kohta	doc_491521501860_item	3734300	et	0	main
öelda	doc_491521501860_item	3734301	et	0	main
uacmoma	doc_491521501860_item	3734302	et	0	main
paduo	doc_491521501860_item	3734303	et	0	main
uacmoma	doc_491521501860_item	3734304	et	0	main
deuotcexuu	doc_491521501860_item	3734305	et	0	main
eesti	doc_491521501860_item	3734306	et	0	main
keeles	doc_491521501860_item	3734307	et	0	main
öeldakse	doc_491521501860_item	3734308	et	0	main
raado	doc_491521501860_item	3734309	et	0	main
kohta	doc_491521501860_item	3734310	et	0	main
laine	doc_491521501860_item	3734311	et	0	main
liigutuste	doc_491521501860_item	3734312	et	0	main
kohta	doc_491521501860_item	3734313	et	0	main
aga	doc_491521501860_item	3734314	et	0	main
ei	doc_491521501860_item	3734315	et	0	main
saa	doc_491521501860_item	3734316	et	0	main
seda	doc_491521501860_item	3734317	et	0	main
sõna	doc_491521501860_item	3734318	et	0	main
kasutada	doc_491521501860_item	3734319	et	0	main
mõtleja	doc_491521501860_item	3734320	et	0	main
mõtleb	doc_491521501860_item	3734321	et	0	main
et	doc_491521501860_item	3734322	et	0	main
ta	doc_491521501860_item	3734323	et	0	main
on	doc_491521501860_item	3734324	et	0	main
töötab	doc_491521501860_item	3734325	et	0	main
väga	doc_491521501860_item	3734326	et	0	main
hea	doc_491521501860_item	3734327	et	0	main
sõber	doc_491521501860_item	3734328	et	0	main
homme	doc_491521501860_item	3734329	et	0	main
ostis	doc_491521501860_item	3734330	et	0	main
uue	doc_491521501860_item	3734331	et	0	main
ajalehte	doc_491521501860_item	3734332	et	0	main
ja	doc_491521501860_item	3734333	et	0	main
nüüd	doc_491521501860_item	3734334	et	0	main
vaatab	doc_491521501860_item	3734335	et	0	main
teda	doc_491521501860_item	3734336	et	0	main
valesti	doc_491521501860_item	3734337	et	0	main
kasutatud	doc_491521501860_item	3734338	et	0	main
määrus	doc_491521501860_item	3734339	et	0	main
ja	doc_491521501860_item	3734340	et	0	main
tegusõna	doc_491521501860_item	3734341	et	0	main
ajavorm	doc_491521501860_item	3734342	et	0	main
teiseks	doc_491521501860_item	3734343	et	0	main
on	doc_491521501860_item	3734344	et	0	main
siin	doc_491521501860_item	3734345	et	0	main
ka	doc_491521501860_item	3734346	et	0	main
ühildumisviga	doc_491521501860_item	3734347	et	0	main
uue	doc_491521501860_item	3734348	et	0	main
ajalehte	doc_491521501860_item	3734349	et	0	main
ja	doc_491521501860_item	3734350	et	0	main
pronoomenivigaõige	doc_491521501860_item	3734351	et	0	main
vaatab	doc_491521501860_item	3734352	et	0	main
seda	doc_491521501860_item	3734353	et	0	main
kolmandaks	doc_491521501860_item	3734354	et	0	main
on	doc_491521501860_item	3734355	et	0	main
sõnajärjeviga	doc_491521501860_item	3734356	et	0	main
suured	doc_491521501860_item	3734357	et	0	main
järjekorrad	doc_491521501860_item	3734358	et	0	main
vene	doc_491521501860_item	3734359	et	0	main
keeles	doc_491521501860_item	3734360	et	0	main
võib	doc_491521501860_item	3734361	et	0	main
öelda	doc_491521501860_item	3734362	et	0	main
nii	doc_491521501860_item	3734363	et	0	main
6onbucue	doc_491521501860_item	3734364	et	0	main
kui	doc_491521501860_item	3734365	et	0	main
ka	doc_491521501860_item	3734366	et	0	main
dnuxxaae	doc_491521501860_item	3734367	et	0	main
ouepedu	doc_491521501860_item	3734368	et	0	main
eesti	doc_491521501860_item	3734369	et	0	main
keeles	doc_491521501860_item	3734370	et	0	main
on	doc_491521501860_item	3734371	et	0	main
pigem	doc_491521501860_item	3734372	et	0	main
pikad	doc_491521501860_item	3734373	et	0	main
järjekorrad	doc_491521501860_item	3734374	et	0	main
tüdrukud	doc_491521501860_item	3734375	et	0	main
andsid	doc_491521501860_item	3734376	et	0	main
koerale	doc_491521501860_item	3734377	et	0	main
kondid	doc_491521501860_item	3734378	et	0	main
sellest	doc_491521501860_item	3734379	et	0	main
et	doc_491521501860_item	3734380	et	0	main
kelle	doc_491521501860_item	3734381	et	0	main
kond	doc_491521501860_item	3734382	et	0	main
koer	doc_491521501860_item	3734383	et	0	main
võtab	doc_491521501860_item	3734384	et	0	main
see	doc_491521501860_item	3734385	et	0	main
tüdruk	doc_491521501860_item	3734386	et	0	main
oli	doc_491521501860_item	3734387	et	0	main
esimene	doc_491521501860_item	3734388	et	0	main
kes	doc_491521501860_item	3734389	et	0	main
valib	doc_491521501860_item	3734390	et	0	main
oma	doc_491521501860_item	3734391	et	0	main
mehi	doc_491521501860_item	3734392	et	0	main
armastus	doc_491521501860_item	3734393	et	0	main
alati	doc_491521501860_item	3734394	et	0	main
elab	doc_491521501860_item	3734395	et	0	main
teda	doc_491521501860_item	3734396	et	0	main
südas	doc_491521501860_item	3734397	et	0	main
sõnajärje-	doc_491521501860_item	3734398	et	0	main
vormimoodustus-	doc_491521501860_item	3734399	et	0	main
ja	doc_491521501860_item	3734400	et	0	main
pronoomeniviga	doc_491521501860_item	3734401	et	0	main
tekkis	doc_491521501860_item	3734402	et	0	main
vahel	doc_491521501860_item	3734403	et	0	main
naist	doc_491521501860_item	3734404	et	0	main
ja	doc_491521501860_item	3734405	et	0	main
meest	doc_491521501860_item	3734406	et	0	main
otsene	doc_491521501860_item	3734407	et	0	main
tõlge	doc_491521501860_item	3734408	et	0	main
vene	doc_491521501860_item	3734409	et	0	main
keelest	doc_491521501860_item	3734410	et	0	main
aosxuxno	doc_491521501860_item	3734411	et	0	main
ntencdy	doc_491521501860_item	3734412	et	0	main
xcexutuxou	doc_491521501860_item	3734413	et	0	main
u	doc_491521501860_item	3734414	et	0	main
nayjlcuuxou	doc_491521501860_item	3734415	et	0	main
peaks	doc_491521501860_item	3734416	et	0	main
olema	doc_491521501860_item	3734417	et	0	main
tekkis	doc_491521501860_item	3734418	et	0	main
naise	doc_491521501860_item	3734419	et	0	main
ja	doc_491521501860_item	3734420	et	0	main
mehe	doc_491521501860_item	3734421	et	0	main
vahel	doc_491521501860_item	3734422	et	0	main
16	doc_491521501860_item	3734423	et	0	main
teised	doc_491521501860_item	3734424	et	0	main
märkusedtähelepanekud	doc_491521501860_item	3734425	et	0	main
suulises	doc_491521501860_item	3734426	et	0	main
kõnes	doc_491521501860_item	3734427	et	0	main
teevad	doc_491521501860_item	3734428	et	0	main
õpilased	doc_491521501860_item	3734429	et	0	main
palju	doc_491521501860_item	3734430	et	0	main
rohkem	doc_491521501860_item	3734431	et	0	main
vigu	doc_491521501860_item	3734432	et	0	main
seda	doc_491521501860_item	3734433	et	0	main
võiks	doc_491521501860_item	3734434	et	0	main
seletada	doc_491521501860_item	3734435	et	0	main
nii	doc_491521501860_item	3734436	et	0	main
et	doc_491521501860_item	3734437	et	0	main
kui	doc_491521501860_item	3734438	et	0	main
rühmas	doc_491521501860_item	3734439	et	0	main
on	doc_491521501860_item	3734440	et	0	main
20	doc_491521501860_item	3734441	et	0	main
õpilast	doc_491521501860_item	3734442	et	0	main
ei	doc_491521501860_item	3734443	et	0	main
jõutagi	doc_491521501860_item	3734444	et	0	main
kõiki	doc_491521501860_item	3734445	et	0	main
küsida	doc_491521501860_item	3734446	et	0	main
õpilastel	doc_491521501860_item	3734447	et	0	main
on	doc_491521501860_item	3734448	et	0	main
raske	doc_491521501860_item	3734449	et	0	main
jälgida	doc_491521501860_item	3734450	et	0	main
aegaajavorme	doc_491521501860_item	3734451	et	0	main
st	doc_491521501860_item	3734452	et	0	main
et	doc_491521501860_item	3734453	et	0	main
nad	doc_491521501860_item	3734454	et	0	main
alustavad	doc_491521501860_item	3734455	et	0	main
näiteks	doc_491521501860_item	3734456	et	0	main
jutustada	doc_491521501860_item	3734457	et	0	main
minevikus	doc_491521501860_item	3734458	et	0	main
siis	doc_491521501860_item	3734459	et	0	main
paar-kolm	doc_491521501860_item	3734460	et	0	main
lauset	doc_491521501860_item	3734461	et	0	main
olevikus	doc_491521501860_item	3734462	et	0	main
pärast	doc_491521501860_item	3734463	et	0	main
jälle	doc_491521501860_item	3734464	et	0	main
minevikus	doc_491521501860_item	3734465	et	0	main
jne	doc_491521501860_item	3734466	et	0	main
kõige	doc_491521501860_item	3734467	et	0	main
rohkem	doc_491521501860_item	3734468	et	0	main
vigu	doc_491521501860_item	3734469	et	0	main
on	doc_491521501860_item	3734470	et	0	main
tingitud	doc_491521501860_item	3734471	et	0	main
emakeele	doc_491521501860_item	3734472	et	0	main
mõjust	doc_491521501860_item	3734473	et	0	main
nii	doc_491521501860_item	3734474	et	0	main
foneetikasfonoloogias	doc_491521501860_item	3734475	et	0	main
morfoloogias	doc_491521501860_item	3734476	et	0	main
süntaksis	doc_491521501860_item	3734477	et	0	main
kui	doc_491521501860_item	3734478	et	0	main
ka	doc_491521501860_item	3734479	et	0	main
semantikas	doc_491521501860_item	3734480	et	0	main
jt	doc_491521501860_item	3734481	et	0	main
kui	doc_491521501860_item	3734482	et	0	main
õpilased	doc_491521501860_item	3734483	et	0	main
hakkavad	doc_491521501860_item	3734484	et	0	main
oma	doc_491521501860_item	3734485	et	0	main
vigukõnet	doc_491521501860_item	3734486	et	0	main
jälgima	doc_491521501860_item	3734487	et	0	main
kaob	doc_491521501860_item	3734488	et	0	main
mõte	doc_491521501860_item	3734489	et	0	main
või	doc_491521501860_item	3734490	et	0	main
vigu	doc_491521501860_item	3734491	et	0	main
tehakse	doc_491521501860_item	3734492	et	0	main
veelgi	doc_491521501860_item	3734493	et	0	main
rohkem	doc_491521501860_item	3734494	et	0	main
analüüs	doc_491521501750_item	3734495	et	0	main
tallinna	doc_491521501750_item	3734496	et	0	main
pedagoogikaülikool	doc_491521501750_item	3734497	et	0	main
filoloogiateaduskond	doc_491521501750_item	3734498	et	0	main
eesti	doc_491521501750_item	3734499	et	0	main
keele	doc_491521501750_item	3734500	et	0	main
kui	doc_491521501750_item	3734501	et	0	main
võõrkeele	doc_491521501750_item	3734502	et	0	main
õppetool	doc_491521501750_item	3734503	et	0	main
eesnimi	doc_491521501750_item	3734504	et	0	main
perekonnanimi	doc_491521501750_item	3734505	et	0	main
kontrastiivlingvistika	doc_491521501750_item	3734506	et	0	main
veaanalüüsi	doc_491521501750_item	3734507	et	0	main
kodutöö	doc_491521501750_item	3734508	et	0	main
juhendaja	doc_491521501750_item	3734509	et	0	main
e	doc_491521501750_item	3734510	et	0	main
perekonnanimi	doc_491521501750_item	3734511	et	0	main
tallinn	doc_491521501750_item	3734512	et	0	main
2001	doc_491521501750_item	3734513	et	0	main
käesolev	doc_491521501750_item	3734514	et	0	main
töö	doc_491521501750_item	3734515	et	0	main
põhineb	doc_491521501750_item	3734516	et	0	main
kolmel	doc_491521501750_item	3734517	et	0	main
e-posti	doc_491521501750_item	3734518	et	0	main
teel	doc_491521501750_item	3734519	et	0	main
saadetud	doc_491521501750_item	3734520	et	0	main
kirjal	doc_491521501750_item	3734521	et	0	main
need	doc_491521501750_item	3734522	et	0	main
kirjad	doc_491521501750_item	3734523	et	0	main
on	doc_491521501750_item	3734524	et	0	main
kirjutanud	doc_491521501750_item	3734525	et	0	main
27-aastane	doc_491521501750_item	3734526	et	0	main
soomlane	doc_491521501750_item	3734527	et	0	main
milma	doc_491521501750_item	3734528	et	0	main
kes	doc_491521501750_item	3734529	et	0	main
õppeaastal	doc_491521501750_item	3734530	et	0	main
199697	doc_491521501750_item	3734531	et	0	main
oli	doc_491521501750_item	3734532	et	0	main
vahetusüliõpilasena	doc_491521501750_item	3734533	et	0	main
eesti	doc_491521501750_item	3734534	et	0	main
kunstiakadeemia	doc_491521501750_item	3734535	et	0	main
tudengiks	doc_491521501750_item	3734536	et	0	main
eesti	doc_491521501750_item	3734537	et	0	main
keele	doc_491521501750_item	3734538	et	0	main
omandas	doc_491521501750_item	3734539	et	0	main
ta	doc_491521501750_item	3734540	et	0	main
suheldes	doc_491521501750_item	3734541	et	0	main
kaasüliõpilastega	doc_491521501750_item	3734542	et	0	main
seega	doc_491521501750_item	3734543	et	0	main
on	doc_491521501750_item	3734544	et	0	main
see	doc_491521501750_item	3734545	et	0	main
loomulikus	doc_491521501750_item	3734546	et	0	main
keelekeskkonnas	doc_491521501750_item	3734547	et	0	main
õpitud	doc_491521501750_item	3734548	et	0	main
eesti	doc_491521501750_item	3734549	et	0	main
keel	doc_491521501750_item	3734550	et	0	main
need	doc_491521501750_item	3734551	et	0	main
kirjad	doc_491521501750_item	3734552	et	0	main
on	doc_491521501750_item	3734553	et	0	main
suhteliselt	doc_491521501750_item	3734554	et	0	main
kõnekeelsed	doc_491521501750_item	3734555	et	0	main
kuid	doc_491521501750_item	3734556	et	0	main
see	doc_491521501750_item	3734557	et	0	main
ei	doc_491521501750_item	3734558	et	0	main
pruugi	doc_491521501750_item	3734559	et	0	main
olla	doc_491521501750_item	3734560	et	0	main
tingitud	doc_491521501750_item	3734561	et	0	main
ainult	doc_491521501750_item	3734562	et	0	main
milma	doc_491521501750_item	3734563	et	0	main
keeleoskusest	doc_491521501750_item	3734564	et	0	main
esiteks	doc_491521501750_item	3734565	et	0	main
on	doc_491521501750_item	3734566	et	0	main
ta	doc_491521501750_item	3734567	et	0	main
kirjutanud	doc_491521501750_item	3734568	et	0	main
need	doc_491521501750_item	3734569	et	0	main
oma	doc_491521501750_item	3734570	et	0	main
heale	doc_491521501750_item	3734571	et	0	main
tuttavale	doc_491521501750_item	3734572	et	0	main
ja	doc_491521501750_item	3734573	et	0	main
teiseks	doc_491521501750_item	3734574	et	0	main
tegemist	doc_491521501750_item	3734575	et	0	main
on	doc_491521501750_item	3734576	et	0	main
siiski	doc_491521501750_item	3734577	et	0	main
e-kirjadega	doc_491521501750_item	3734578	et	0	main
kus	doc_491521501750_item	3734579	et	0	main
informaalse	doc_491521501750_item	3734580	et	0	main
suhtlemise	doc_491521501750_item	3734581	et	0	main
puhul	doc_491521501750_item	3734582	et	0	main
kasutatav	doc_491521501750_item	3734583	et	0	main
keel	doc_491521501750_item	3734584	et	0	main
lähenebki	doc_491521501750_item	3734585	et	0	main
kõnekeelele	doc_491521501750_item	3734586	et	0	main
kõik	doc_491521501750_item	3734587	et	0	main
kolm	doc_491521501750_item	3734588	et	0	main
kirja	doc_491521501750_item	3734589	et	0	main
on	doc_491521501750_item	3734590	et	0	main
ära	doc_491521501750_item	3734591	et	0	main
toodud	doc_491521501750_item	3734592	et	0	main
töö	doc_491521501750_item	3734593	et	0	main
lõpus	doc_491521501750_item	3734594	et	0	main
1	doc_491521501750_item	3734595	et	0	main
hääldus	doc_491521501750_item	3734596	et	0	main
ja	doc_491521501750_item	3734597	et	0	main
õigekiri	doc_491521501750_item	3734598	et	0	main
õ-kasutamine	doc_491521501750_item	3734599	et	0	main
kuigi	doc_491521501750_item	3734600	et	0	main
kirjades	doc_491521501750_item	3734601	et	0	main
1	doc_491521501750_item	3734602	et	0	main
ja	doc_491521501750_item	3734603	et	0	main
3	doc_491521501750_item	3734604	et	0	main
puuduvad	doc_491521501750_item	3734605	et	0	main
grafeemid	doc_491521501750_item	3734606	et	0	main
õ	doc_491521501750_item	3734607	et	0	main
ei	doc_491521501750_item	3734608	et	0	main
saa	doc_491521501750_item	3734609	et	0	main
öelda	doc_491521501750_item	3734610	et	0	main
et	doc_491521501750_item	3734611	et	0	main
milma	doc_491521501750_item	3734612	et	0	main
neid	doc_491521501750_item	3734613	et	0	main
kasutada	doc_491521501750_item	3734614	et	0	main
ei	doc_491521501750_item	3734615	et	0	main
oska	doc_491521501750_item	3734616	et	0	main
arvatavasti	doc_491521501750_item	3734617	et	0	main
oli	doc_491521501750_item	3734618	et	0	main
probleemiks	doc_491521501750_item	3734619	et	0	main
see	doc_491521501750_item	3734620	et	0	main
et	doc_491521501750_item	3734621	et	0	main
arvuti	doc_491521501750_item	3734622	et	0	main
millega	doc_491521501750_item	3734623	et	0	main
ta	doc_491521501750_item	3734624	et	0	main
need	doc_491521501750_item	3734625	et	0	main
kirjad	doc_491521501750_item	3734626	et	0	main
kirjutas	doc_491521501750_item	3734627	et	0	main
ei	doc_491521501750_item	3734628	et	0	main
võimaldanud	doc_491521501750_item	3734629	et	0	main
õ	doc_491521501750_item	3734630	et	0	main
kasutamist	doc_491521501750_item	3734631	et	0	main
seda	doc_491521501750_item	3734632	et	0	main
kinnitab	doc_491521501750_item	3734633	et	0	main
kiri	doc_491521501750_item	3734634	et	0	main
2	doc_491521501750_item	3734635	et	0	main
seal	doc_491521501750_item	3734636	et	0	main
on	doc_491521501750_item	3734637	et	0	main
õ-d	doc_491521501750_item	3734638	et	0	main
kasutatud	doc_491521501750_item	3734639	et	0	main
ja	doc_491521501750_item	3734640	et	0	main
seda	doc_491521501750_item	3734641	et	0	main
täiesti	doc_491521501750_item	3734642	et	0	main
veatult	doc_491521501750_item	3734643	et	0	main
kirjavahemärgid	doc_491521501750_item	3734644	et	0	main
milmal	doc_491521501750_item	3734645	et	0	main
on	doc_491521501750_item	3734646	et	0	main
küll	doc_491521501750_item	3734647	et	0	main
kirjades	doc_491521501750_item	3734648	et	0	main
hulganisti	doc_491521501750_item	3734649	et	0	main
komasid	doc_491521501750_item	3734650	et	0	main
puudu	doc_491521501750_item	3734651	et	0	main
kuid	doc_491521501750_item	3734652	et	0	main
ma	doc_491521501750_item	3734653	et	0	main
ei	doc_491521501750_item	3734654	et	0	main
hakkaks	doc_491521501750_item	3734655	et	0	main
nende	doc_491521501750_item	3734656	et	0	main
puudumist	doc_491521501750_item	3734657	et	0	main
siin	doc_491521501750_item	3734658	et	0	main
pikemalt	doc_491521501750_item	3734659	et	0	main
analüüsima	doc_491521501750_item	3734660	et	0	main
kuna	doc_491521501750_item	3734661	et	0	main
tegemist	doc_491521501750_item	3734662	et	0	main
on	doc_491521501750_item	3734663	et	0	main
mitteametlike	doc_491521501750_item	3734664	et	0	main
e-kirjadega	doc_491521501750_item	3734665	et	0	main
klusiilide	doc_491521501750_item	3734666	et	0	main
õigekiri	doc_491521501750_item	3734667	et	0	main
arvan	doc_491521501750_item	3734668	et	0	main
et	doc_491521501750_item	3734669	et	0	main
enamusele	doc_491521501750_item	3734670	et	0	main
soomlastest	doc_491521501750_item	3734671	et	0	main
on	doc_491521501750_item	3734672	et	0	main
see	doc_491521501750_item	3734673	et	0	main
teema	doc_491521501750_item	3734674	et	0	main
raske	doc_491521501750_item	3734675	et	0	main
ja	doc_491521501750_item	3734676	et	0	main
ka	doc_491521501750_item	3734677	et	0	main
milma	doc_491521501750_item	3734678	et	0	main
pole	doc_491521501750_item	3734679	et	0	main
mingi	doc_491521501750_item	3734680	et	0	main
erand	doc_491521501750_item	3734681	et	0	main
nende	doc_491521501750_item	3734682	et	0	main
vigade	doc_491521501750_item	3734683	et	0	main
puhul	doc_491521501750_item	3734684	et	0	main
on	doc_491521501750_item	3734685	et	0	main
siiski	doc_491521501750_item	3734686	et	0	main
raske	doc_491521501750_item	3734687	et	0	main
otsustada	doc_491521501750_item	3734688	et	0	main
kas	doc_491521501750_item	3734689	et	0	main
tegemist	doc_491521501750_item	3734690	et	0	main
on	doc_491521501750_item	3734691	et	0	main
lohakuse	doc_491521501750_item	3734692	et	0	main
emakeele	doc_491521501750_item	3734693	et	0	main
mõju	doc_491521501750_item	3734694	et	0	main
või	doc_491521501750_item	3734695	et	0	main
vigase	doc_491521501750_item	3734696	et	0	main
vormimoodustusega	doc_491521501750_item	3734697	et	0	main
näiteks	doc_491521501750_item	3734698	et	0	main
verbist	doc_491521501750_item	3734699	et	0	main
pildistama	doc_491521501750_item	3734700	et	0	main
on	doc_491521501750_item	3734701	et	0	main
kirjas	doc_491521501750_item	3734702	et	0	main
1	doc_491521501750_item	3734703	et	0	main
mitu	doc_491521501750_item	3734704	et	0	main
varianti	doc_491521501750_item	3734705	et	0	main
piltistan	doc_491521501750_item	3734706	et	0	main
pildistamisele	doc_491521501750_item	3734707	et	0	main
pildisdama	doc_491521501750_item	3734708	et	0	main
ja	doc_491521501750_item	3734709	et	0	main
pildisdamiseks	doc_491521501750_item	3734710	et	0	main
kuigi	doc_491521501750_item	3734711	et	0	main
on	doc_491521501750_item	3734712	et	0	main
tehtud	doc_491521501750_item	3734713	et	0	main
mitu	doc_491521501750_item	3734714	et	0	main
viga	doc_491521501750_item	3734715	et	0	main
jääb	doc_491521501750_item	3734716	et	0	main
kirju	doc_491521501750_item	3734717	et	0	main
2	doc_491521501750_item	3734718	et	0	main
ja	doc_491521501750_item	3734719	et	0	main
3	doc_491521501750_item	3734720	et	0	main
lugedes	doc_491521501750_item	3734721	et	0	main
mulje	doc_491521501750_item	3734722	et	0	main
et	doc_491521501750_item	3734723	et	0	main
milma	doc_491521501750_item	3734724	et	0	main
teab	doc_491521501750_item	3734725	et	0	main
kuidas	doc_491521501750_item	3734726	et	0	main
seda	doc_491521501750_item	3734727	et	0	main
verbi	doc_491521501750_item	3734728	et	0	main
kasutatakse	doc_491521501750_item	3734729	et	0	main
nii	doc_491521501750_item	3734730	et	0	main
loeksin	doc_491521501750_item	3734731	et	0	main
need	doc_491521501750_item	3734732	et	0	main
vead	doc_491521501750_item	3734733	et	0	main
hooletusest	doc_491521501750_item	3734734	et	0	main
põhjustatuteks	doc_491521501750_item	3734735	et	0	main
raskusi	doc_491521501750_item	3734736	et	0	main
on	doc_491521501750_item	3734737	et	0	main
milmal	doc_491521501750_item	3734738	et	0	main
ka	doc_491521501750_item	3734739	et	0	main
sõna	doc_491521501750_item	3734740	et	0	main
keskel	doc_491521501750_item	3734741	et	0	main
asuvate	doc_491521501750_item	3734742	et	0	main
klusiilidega	doc_491521501750_item	3734743	et	0	main
nt	doc_491521501750_item	3734744	et	0	main
loppuni	doc_491521501750_item	3734745	et	0	main
tutavatele	doc_491521501750_item	3734746	et	0	main
ilmuttamisele	doc_491521501750_item	3734747	et	0	main
printtimisele	doc_491521501750_item	3734748	et	0	main
kiri	doc_491521501750_item	3734749	et	0	main
1	doc_491521501750_item	3734750	et	0	main
jättaks	doc_491521501750_item	3734751	et	0	main
jättan	doc_491521501750_item	3734752	et	0	main
kusgilt	doc_491521501750_item	3734753	et	0	main
kiri	doc_491521501750_item	3734754	et	0	main
2	doc_491521501750_item	3734755	et	0	main
kindlasti	doc_491521501750_item	3734756	et	0	main
on	doc_491521501750_item	3734757	et	0	main
siin	doc_491521501750_item	3734758	et	0	main
oma	doc_491521501750_item	3734759	et	0	main
roll	doc_491521501750_item	3734760	et	0	main
emakeele	doc_491521501750_item	3734761	et	0	main
mõjust	doc_491521501750_item	3734762	et	0	main
tingitud	doc_491521501750_item	3734763	et	0	main
ebakindlusel	doc_491521501750_item	3734764	et	0	main
kuid	doc_491521501750_item	3734765	et	0	main
mõnede	doc_491521501750_item	3734766	et	0	main
vigade	doc_491521501750_item	3734767	et	0	main
puhul	doc_491521501750_item	3734768	et	0	main
julgen	doc_491521501750_item	3734769	et	0	main
kahtlustada	doc_491521501750_item	3734770	et	0	main
ka	doc_491521501750_item	3734771	et	0	main
muid	doc_491521501750_item	3734772	et	0	main
põhjusi	doc_491521501750_item	3734773	et	0	main
näiteks	doc_491521501750_item	3734774	et	0	main
loppuni	doc_491521501750_item	3734775	et	0	main
siin	doc_491521501750_item	3734776	et	0	main
võib	doc_491521501750_item	3734777	et	0	main
olla	doc_491521501750_item	3734778	et	0	main
põhjuseks	doc_491521501750_item	3734779	et	0	main
emakeel	doc_491521501750_item	3734780	et	0	main
sm	doc_491521501750_item	3734781	et	0	main
loppuun	doc_491521501750_item	3734782	et	0	main
asti	doc_491521501750_item	3734783	et	0	main
või	doc_491521501750_item	3734784	et	0	main
hoopis	doc_491521501750_item	3734785	et	0	main
vigane	doc_491521501750_item	3734786	et	0	main
vormimoodustus	doc_491521501750_item	3734787	et	0	main
lõpp	doc_491521501750_item	3734788	et	0	main
lõppu	doc_491521501750_item	3734789	et	0	main
kuhu	doc_491521501750_item	3734790	et	0	main
lõppuni	doc_491521501750_item	3734791	et	0	main
kuhu	doc_491521501750_item	3734792	et	0	main
maani	doc_491521501750_item	3734793	et	0	main
päris	doc_491521501750_item	3734794	et	0	main
kahtlane	doc_491521501750_item	3734795	et	0	main
on	doc_491521501750_item	3734796	et	0	main
soome	doc_491521501750_item	3734797	et	0	main
keele	doc_491521501750_item	3734798	et	0	main
mõju	doc_491521501750_item	3734799	et	0	main
sõna	doc_491521501750_item	3734800	et	0	main
printtimisele	doc_491521501750_item	3734801	et	0	main
puhul	doc_491521501750_item	3734802	et	0	main
teades	doc_491521501750_item	3734803	et	0	main
kuidas	doc_491521501750_item	3734804	et	0	main
see	doc_491521501750_item	3734805	et	0	main
eesti	doc_491521501750_item	3734806	et	0	main
keeles	doc_491521501750_item	3734807	et	0	main
hääldub	doc_491521501750_item	3734808	et	0	main
on	doc_491521501750_item	3734809	et	0	main
sellist	doc_491521501750_item	3734810	et	0	main
kirjapilti	doc_491521501750_item	3734811	et	0	main
välismaalasele	doc_491521501750_item	3734812	et	0	main
raske	doc_491521501750_item	3734813	et	0	main
pahaks	doc_491521501750_item	3734814	et	0	main
panna	doc_491521501750_item	3734815	et	0	main
võib	doc_491521501750_item	3734816	et	0	main
arvata	doc_491521501750_item	3734817	et	0	main
et	doc_491521501750_item	3734818	et	0	main
siin	doc_491521501750_item	3734819	et	0	main
teeks	doc_491521501750_item	3734820	et	0	main
vea	doc_491521501750_item	3734821	et	0	main
ka	doc_491521501750_item	3734822	et	0	main
nii	doc_491521501750_item	3734823	et	0	main
mõnigi	doc_491521501750_item	3734824	et	0	main
eestlane	doc_491521501750_item	3734825	et	0	main
segaseks	doc_491521501750_item	3734826	et	0	main
jääb	doc_491521501750_item	3734827	et	0	main
vea	doc_491521501750_item	3734828	et	0	main
põhjus	doc_491521501750_item	3734829	et	0	main
veel	doc_491521501750_item	3734830	et	0	main
määrsõna	doc_491521501750_item	3734831	et	0	main
kusgilt	doc_491521501750_item	3734832	et	0	main
juures	doc_491521501750_item	3734833	et	0	main
kas	doc_491521501750_item	3734834	et	0	main
milma	doc_491521501750_item	3734835	et	0	main
on	doc_491521501750_item	3734836	et	0	main
tahtnud	doc_491521501750_item	3734837	et	0	main
kirjutada	doc_491521501750_item	3734838	et	0	main
kusagilt	doc_491521501750_item	3734839	et	0	main
ja	doc_491521501750_item	3734840	et	0	main
tegemist	doc_491521501750_item	3734841	et	0	main
on	doc_491521501750_item	3734842	et	0	main
hooletusveaga	doc_491521501750_item	3734843	et	0	main
või	doc_491521501750_item	3734844	et	0	main
on	doc_491521501750_item	3734845	et	0	main
ta	doc_491521501750_item	3734846	et	0	main
siiski	doc_491521501750_item	3734847	et	0	main
mõelnud	doc_491521501750_item	3734848	et	0	main
sõna	doc_491521501750_item	3734849	et	0	main
kuskilt	doc_491521501750_item	3734850	et	0	main
ja	doc_491521501750_item	3734851	et	0	main
märkinud	doc_491521501750_item	3734852	et	0	main
klusiili	doc_491521501750_item	3734853	et	0	main
valesti	doc_491521501750_item	3734854	et	0	main
ka	doc_491521501750_item	3734855	et	0	main
sõnalõpuliste	doc_491521501750_item	3734856	et	0	main
klusiilidega	doc_491521501750_item	3734857	et	0	main
on	doc_491521501750_item	3734858	et	0	main
milma	doc_491521501750_item	3734859	et	0	main
eksinud	doc_491521501750_item	3734860	et	0	main
nt	doc_491521501750_item	3734861	et	0	main
printi	doc_491521501750_item	3734862	et	0	main
mille	doc_491521501750_item	3734863	et	0	main
kiri	doc_491521501750_item	3734864	et	0	main
1	doc_491521501750_item	3734865	et	0	main
vaib	doc_491521501750_item	3734866	et	0	main
ainuld	doc_491521501750_item	3734867	et	0	main
kiri	doc_491521501750_item	3734868	et	0	main
2	doc_491521501750_item	3734869	et	0	main
ja	doc_491521501750_item	3734870	et	0	main
kort	doc_491521501750_item	3734871	et	0	main
kiri	doc_491521501750_item	3734872	et	0	main
3	doc_491521501750_item	3734873	et	0	main
nendest	doc_491521501750_item	3734874	et	0	main
vigadest	doc_491521501750_item	3734875	et	0	main
vaib	doc_491521501750_item	3734876	et	0	main
ja	doc_491521501750_item	3734877	et	0	main
kort	doc_491521501750_item	3734878	et	0	main
tunduvad	doc_491521501750_item	3734879	et	0	main
olevat	doc_491521501750_item	3734880	et	0	main
juhuslikku	doc_491521501750_item	3734881	et	0	main
laadi	doc_491521501750_item	3734882	et	0	main
sest	doc_491521501750_item	3734883	et	0	main
mõlemat	doc_491521501750_item	3734884	et	0	main
sõna	doc_491521501750_item	3734885	et	0	main
on	doc_491521501750_item	3734886	et	0	main
ka	doc_491521501750_item	3734887	et	0	main
õigesti	doc_491521501750_item	3734888	et	0	main
kasutatud	doc_491521501750_item	3734889	et	0	main
vaibad	doc_491521501750_item	3734890	et	0	main
vaipade	doc_491521501750_item	3734891	et	0	main
kiri	doc_491521501750_item	3734892	et	0	main
2	doc_491521501750_item	3734893	et	0	main
ja	doc_491521501750_item	3734894	et	0	main
kord	doc_491521501750_item	3734895	et	0	main
kiri	doc_491521501750_item	3734896	et	0	main
2	doc_491521501750_item	3734897	et	0	main
kokkuvõtvalt	doc_491521501750_item	3734898	et	0	main
arvan	doc_491521501750_item	3734899	et	0	main
et	doc_491521501750_item	3734900	et	0	main
klusiilide	doc_491521501750_item	3734901	et	0	main
õigekiri	doc_491521501750_item	3734902	et	0	main
tekitab	doc_491521501750_item	3734903	et	0	main
ebakindlust	doc_491521501750_item	3734904	et	0	main
enamuses	doc_491521501750_item	3734905	et	0	main
ka	doc_491521501750_item	3734906	et	0	main
eesti	doc_491521501750_item	3734907	et	0	main
keele	doc_491521501750_item	3734908	et	0	main
grammatikat	doc_491521501750_item	3734909	et	0	main
õppinud	doc_491521501750_item	3734910	et	0	main
soomlastes	doc_491521501750_item	3734911	et	0	main
ja	doc_491521501750_item	3734912	et	0	main
sellised	doc_491521501750_item	3734913	et	0	main
vead	doc_491521501750_item	3734914	et	0	main
võivad	doc_491521501750_item	3734915	et	0	main
sisse	doc_491521501750_item	3734916	et	0	main
lipsata	doc_491521501750_item	3734917	et	0	main
ka	doc_491521501750_item	3734918	et	0	main
õigeid	doc_491521501750_item	3734919	et	0	main
vorme	doc_491521501750_item	3734920	et	0	main
teades	doc_491521501750_item	3734921	et	0	main
kokku-	doc_491521501750_item	3734922	et	0	main
ja	doc_491521501750_item	3734923	et	0	main
lahkukirjutamine	doc_491521501750_item	3734924	et	0	main
selliseid	doc_491521501750_item	3734925	et	0	main
vigu	doc_491521501750_item	3734926	et	0	main
leidsin	doc_491521501750_item	3734927	et	0	main
milmal	doc_491521501750_item	3734928	et	0	main
ainult	doc_491521501750_item	3734929	et	0	main
kaks	doc_491521501750_item	3734930	et	0	main
nagu	doc_491521501750_item	3734931	et	0	main
nii	doc_491521501750_item	3734932	et	0	main
pole	doc_491521501750_item	3734933	et	0	main
piisavalt	doc_491521501750_item	3734934	et	0	main
kiri	doc_491521501750_item	3734935	et	0	main
1	doc_491521501750_item	3734936	et	0	main
ja	doc_491521501750_item	3734937	et	0	main
klaasi	doc_491521501750_item	3734938	et	0	main
näitus	doc_491521501750_item	3734939	et	0	main
kiri	doc_491521501750_item	3734940	et	0	main
3	doc_491521501750_item	3734941	et	0	main
kuna	doc_491521501750_item	3734942	et	0	main
milma	doc_491521501750_item	3734943	et	0	main
on	doc_491521501750_item	3734944	et	0	main
õppinud	doc_491521501750_item	3734945	et	0	main
eesti	doc_491521501750_item	3734946	et	0	main
keele	doc_491521501750_item	3734947	et	0	main
ära	doc_491521501750_item	3734948	et	0	main
eestlastega	doc_491521501750_item	3734949	et	0	main
suheldes	doc_491521501750_item	3734950	et	0	main
on	doc_491521501750_item	3734951	et	0	main
täiesti	doc_491521501750_item	3734952	et	0	main
mõistetav	doc_491521501750_item	3734953	et	0	main
et	doc_491521501750_item	3734954	et	0	main
selliseid	doc_491521501750_item	3734955	et	0	main
vigu	doc_491521501750_item	3734956	et	0	main
tuleb	doc_491521501750_item	3734957	et	0	main
ette	doc_491521501750_item	3734958	et	0	main
muud	doc_491521501750_item	3734959	et	0	main
õigekirjavead	doc_491521501750_item	3734960	et	0	main
mõnede	doc_491521501750_item	3734961	et	0	main
vigade	doc_491521501750_item	3734962	et	0	main
puhul	doc_491521501750_item	3734963	et	0	main
olen	doc_491521501750_item	3734964	et	0	main
üpris	doc_491521501750_item	3734965	et	0	main
kindel	doc_491521501750_item	3734966	et	0	main
et	doc_491521501750_item	3734967	et	0	main
tegemist	doc_491521501750_item	3734968	et	0	main
on	doc_491521501750_item	3734969	et	0	main
hooletusvigadega	doc_491521501750_item	3734970	et	0	main
nt	doc_491521501750_item	3734971	et	0	main
algust	doc_491521501750_item	3734972	et	0	main
loppuni	doc_491521501750_item	3734973	et	0	main
käsitse	doc_491521501750_item	3734974	et	0	main
kiri	doc_491521501750_item	3734975	et	0	main
1	doc_491521501750_item	3734976	et	0	main
ja	doc_491521501750_item	3734977	et	0	main
kaas	doc_491521501750_item	3734978	et	0	main
võtma	doc_491521501750_item	3734979	et	0	main
kiri	doc_491521501750_item	3734980	et	0	main
2	doc_491521501750_item	3734981	et	0	main
2	doc_491521501750_item	3734982	et	0	main
süntaks	doc_491521501750_item	3734983	et	0	main
ja	doc_491521501750_item	3734984	et	0	main
morfoloogia	doc_491521501750_item	3734985	et	0	main
sõnajärg	doc_491521501750_item	3734986	et	0	main
sõnajärjega	doc_491521501750_item	3734987	et	0	main
milmal	doc_491521501750_item	3734988	et	0	main
suuremaid	doc_491521501750_item	3734989	et	0	main
probleeme	doc_491521501750_item	3734990	et	0	main
ei	doc_491521501750_item	3734991	et	0	main
ole	doc_491521501750_item	3734992	et	0	main
kuid	doc_491521501750_item	3734993	et	0	main
mõned	doc_491521501750_item	3734994	et	0	main
vead	doc_491521501750_item	3734995	et	0	main
peaksin	doc_491521501750_item	3734996	et	0	main
siiski	doc_491521501750_item	3734997	et	0	main
ära	doc_491521501750_item	3734998	et	0	main
märkima	doc_491521501750_item	3734999	et	0	main
kiri	doc_491521501750_item	3735000	et	0	main
1	doc_491521501750_item	3735001	et	0	main
vaipade	doc_491521501750_item	3735002	et	0	main
pildisdamiseks	doc_491521501750_item	3735003	et	0	main
päevavalgus	doc_491521501750_item	3735004	et	0	main
oleks	doc_491521501750_item	3735005	et	0	main
hea	doc_491521501750_item	3735006	et	0	main
siin	doc_491521501750_item	3735007	et	0	main
on	doc_491521501750_item	3735008	et	0	main
kirjutajat	doc_491521501750_item	3735009	et	0	main
arvatavasti	doc_491521501750_item	3735010	et	0	main
mõjutanud	doc_491521501750_item	3735011	et	0	main
emakeel	doc_491521501750_item	3735012	et	0	main
selliste	doc_491521501750_item	3735013	et	0	main
vigade	doc_491521501750_item	3735014	et	0	main
nagu	doc_491521501750_item	3735015	et	0	main
nii	doc_491521501750_item	3735016	et	0	main
et	doc_491521501750_item	3735017	et	0	main
umbes	doc_491521501750_item	3735018	et	0	main
20ndal	doc_491521501750_item	3735019	et	0	main
tulen	doc_491521501750_item	3735020	et	0	main
kiri	doc_491521501750_item	3735021	et	0	main
3	doc_491521501750_item	3735022	et	0	main
ja	doc_491521501750_item	3735023	et	0	main
vaatan	doc_491521501750_item	3735024	et	0	main
meile	doc_491521501750_item	3735025	et	0	main
veel	doc_491521501750_item	3735026	et	0	main
täna	doc_491521501750_item	3735027	et	0	main
õhtul	doc_491521501750_item	3735028	et	0	main
kindlasti	doc_491521501750_item	3735029	et	0	main
kiri	doc_491521501750_item	3735030	et	0	main
2	doc_491521501750_item	3735031	et	0	main
juures	doc_491521501750_item	3735032	et	0	main
ei	doc_491521501750_item	3735033	et	0	main
oska	doc_491521501750_item	3735034	et	0	main
kahjuks	doc_491521501750_item	3735035	et	0	main
muud	doc_491521501750_item	3735036	et	0	main
põhjust	doc_491521501750_item	3735037	et	0	main
leida	doc_491521501750_item	3735038	et	0	main
kui	doc_491521501750_item	3735039	et	0	main
ainult	doc_491521501750_item	3735040	et	0	main
kõnekeele	doc_491521501750_item	3735041	et	0	main
mõju	doc_491521501750_item	3735042	et	0	main
objektivead	doc_491521501750_item	3735043	et	0	main
kuna	doc_491521501750_item	3735044	et	0	main
pean	doc_491521501750_item	3735045	et	0	main
koige	doc_491521501750_item	3735046	et	0	main
käsitse	doc_491521501750_item	3735047	et	0	main
tegema	doc_491521501750_item	3735048	et	0	main
kiri	doc_491521501750_item	3735049	et	0	main
1	doc_491521501750_item	3735050	et	0	main
kui	doc_491521501750_item	3735051	et	0	main
milma	doc_491521501750_item	3735052	et	0	main
ei	doc_491521501750_item	3735053	et	0	main
ole	doc_491521501750_item	3735054	et	0	main
siin	doc_491521501750_item	3735055	et	0	main
teinud	doc_491521501750_item	3735056	et	0	main
õigekirjaviga	doc_491521501750_item	3735057	et	0	main
vormis	doc_491521501750_item	3735058	et	0	main
kõike	doc_491521501750_item	3735059	et	0	main
mida	doc_491521501750_item	3735060	et	0	main
on	doc_491521501750_item	3735061	et	0	main
ta	doc_491521501750_item	3735062	et	0	main
eksinud	doc_491521501750_item	3735063	et	0	main
käändevalikuga	doc_491521501750_item	3735064	et	0	main
iseenesest	doc_491521501750_item	3735065	et	0	main
on	doc_491521501750_item	3735066	et	0	main
ju	doc_491521501750_item	3735067	et	0	main
ka	doc_491521501750_item	3735068	et	0	main
omastav	doc_491521501750_item	3735069	et	0	main
õige	doc_491521501750_item	3735070	et	0	main
pean	doc_491521501750_item	3735071	et	0	main
mille	doc_491521501750_item	3735072	et	0	main
käsitsi	doc_491521501750_item	3735073	et	0	main
tegema	doc_491521501750_item	3735074	et	0	main
kuid	doc_491521501750_item	3735075	et	0	main
sõna	doc_491521501750_item	3735076	et	0	main
kõik	doc_491521501750_item	3735077	et	0	main
puhul	doc_491521501750_item	3735078	et	0	main
see	doc_491521501750_item	3735079	et	0	main
ei	doc_491521501750_item	3735080	et	0	main
sobi	doc_491521501750_item	3735081	et	0	main
veel	doc_491521501750_item	3735082	et	0	main
on	doc_491521501750_item	3735083	et	0	main
milmal	doc_491521501750_item	3735084	et	0	main
probleeme	doc_491521501750_item	3735085	et	0	main
abimäärsõnade	doc_491521501750_item	3735086	et	0	main
kasutamisega	doc_491521501750_item	3735087	et	0	main
ostsin	doc_491521501750_item	3735088	et	0	main
nüüd	doc_491521501750_item	3735089	et	0	main
igal	doc_491521501750_item	3735090	et	0	main
juhul	doc_491521501750_item	3735091	et	0	main
filmi	doc_491521501750_item	3735092	et	0	main
ja	doc_491521501750_item	3735093	et	0	main
panin	doc_491521501750_item	3735094	et	0	main
kiri	doc_491521501750_item	3735095	et	0	main
2	doc_491521501750_item	3735096	et	0	main
ja	doc_491521501750_item	3735097	et	0	main
pildistan	doc_491521501750_item	3735098	et	0	main
ainuld	doc_491521501750_item	3735099	et	0	main
need	doc_491521501750_item	3735100	et	0	main
sinu	doc_491521501750_item	3735101	et	0	main
vaibad	doc_491521501750_item	3735102	et	0	main
kiri	doc_491521501750_item	3735103	et	0	main
2	doc_491521501750_item	3735104	et	0	main
siin	doc_491521501750_item	3735105	et	0	main
on	doc_491521501750_item	3735106	et	0	main
tunda	doc_491521501750_item	3735107	et	0	main
soome	doc_491521501750_item	3735108	et	0	main
keele	doc_491521501750_item	3735109	et	0	main
mõju	doc_491521501750_item	3735110	et	0	main
eesti	doc_491521501750_item	3735111	et	0	main
keeles	doc_491521501750_item	3735112	et	0	main
selline	doc_491521501750_item	3735113	et	0	main
vorm	doc_491521501750_item	3735114	et	0	main
nõuab	doc_491521501750_item	3735115	et	0	main
abimäärsõna	doc_491521501750_item	3735116	et	0	main
ära	doc_491521501750_item	3735117	et	0	main
rektsioonivead	doc_491521501750_item	3735118	et	0	main
teaksin	doc_491521501750_item	3735119	et	0	main
mis	doc_491521501750_item	3735120	et	0	main
pean	doc_491521501750_item	3735121	et	0	main
kaas	doc_491521501750_item	3735122	et	0	main
võtma	doc_491521501750_item	3735123	et	0	main
kiri	doc_491521501750_item	3735124	et	0	main
2	doc_491521501750_item	3735125	et	0	main
siin	doc_491521501750_item	3735126	et	0	main
on	doc_491521501750_item	3735127	et	0	main
milmat	doc_491521501750_item	3735128	et	0	main
arvatavasti	doc_491521501750_item	3735129	et	0	main
jällegi	doc_491521501750_item	3735130	et	0	main
mõjutanud	doc_491521501750_item	3735131	et	0	main
kõnekeel	doc_491521501750_item	3735132	et	0	main
ühendverb	doc_491521501750_item	3735133	et	0	main
kaasa	doc_491521501750_item	3735134	et	0	main
võtma	doc_491521501750_item	3735135	et	0	main
eeldab	doc_491521501750_item	3735136	et	0	main
küsimusi	doc_491521501750_item	3735137	et	0	main
mille	doc_491521501750_item	3735138	et	0	main
või	doc_491521501750_item	3735139	et	0	main
mida	doc_491521501750_item	3735140	et	0	main
käändevead	doc_491521501750_item	3735141	et	0	main
töö	doc_491521501750_item	3735142	et	0	main
tööst	doc_491521501750_item	3735143	et	0	main
diil	doc_491521501750_item	3735144	et	0	main
kiri	doc_491521501750_item	3735145	et	0	main
1	doc_491521501750_item	3735146	et	0	main
tegemist	doc_491521501750_item	3735147	et	0	main
on	doc_491521501750_item	3735148	et	0	main
arvatavasti	doc_491521501750_item	3735149	et	0	main
emakeele	doc_491521501750_item	3735150	et	0	main
mõjuga	doc_491521501750_item	3735151	et	0	main
sm	doc_491521501750_item	3735152	et	0	main
työ	doc_491521501750_item	3735153	et	0	main
työstä	doc_491521501750_item	3735154	et	0	main
soome	doc_491521501750_item	3735155	et	0	main
keeles	doc_491521501750_item	3735156	et	0	main
on	doc_491521501750_item	3735157	et	0	main
sellistel	doc_491521501750_item	3735158	et	0	main
puhkudel	doc_491521501750_item	3735159	et	0	main
seestütlev	doc_491521501750_item	3735160	et	0	main
eesti	doc_491521501750_item	3735161	et	0	main
keeles	doc_491521501750_item	3735162	et	0	main
aga	doc_491521501750_item	3735163	et	0	main
omastav	doc_491521501750_item	3735164	et	0	main
kaassõna	doc_491521501750_item	3735165	et	0	main
eest	doc_491521501750_item	3735166	et	0	main
mille	doc_491521501750_item	3735167	et	0	main
eest	doc_491521501750_item	3735168	et	0	main
vea	doc_491521501750_item	3735169	et	0	main
juhuslikkuse	doc_491521501750_item	3735170	et	0	main
välistab	doc_491521501750_item	3735171	et	0	main
selle	doc_491521501750_item	3735172	et	0	main
kordumine	doc_491521501750_item	3735173	et	0	main
kirjas	doc_491521501750_item	3735174	et	0	main
2	doc_491521501750_item	3735175	et	0	main
kui	doc_491521501750_item	3735176	et	0	main
sulle	doc_491521501750_item	3735177	et	0	main
tundub	doc_491521501750_item	3735178	et	0	main
et	doc_491521501750_item	3735179	et	0	main
vaib	doc_491521501750_item	3735180	et	0	main
on	doc_491521501750_item	3735181	et	0	main
sellest	doc_491521501750_item	3735182	et	0	main
palju	doc_491521501750_item	3735183	et	0	main
vastu	doc_491521501750_item	3735184	et	0	main
anda	doc_491521501750_item	3735185	et	0	main
ühildumisvead	doc_491521501750_item	3735186	et	0	main
leidsin	doc_491521501750_item	3735187	et	0	main
kaks	doc_491521501750_item	3735188	et	0	main
näidet	doc_491521501750_item	3735189	et	0	main
kus	doc_491521501750_item	3735190	et	0	main
on	doc_491521501750_item	3735191	et	0	main
eksitud	doc_491521501750_item	3735192	et	0	main
igas	doc_491521501750_item	3735193	et	0	main
vaibast	doc_491521501750_item	3735194	et	0	main
ja	doc_491521501750_item	3735195	et	0	main
kulud	doc_491521501750_item	3735196	et	0	main
oleks	doc_491521501750_item	3735197	et	0	main
mõlemad	doc_491521501750_item	3735198	et	0	main
kiri	doc_491521501750_item	3735199	et	0	main
1	doc_491521501750_item	3735200	et	0	main
suure	doc_491521501750_item	3735201	et	0	main
tõenäosusega	doc_491521501750_item	3735202	et	0	main
on	doc_491521501750_item	3735203	et	0	main
tegemist	doc_491521501750_item	3735204	et	0	main
hooletusvigadega	doc_491521501750_item	3735205	et	0	main
teise	doc_491521501750_item	3735206	et	0	main
näite	doc_491521501750_item	3735207	et	0	main
puhul	doc_491521501750_item	3735208	et	0	main
võib	doc_491521501750_item	3735209	et	0	main
muidugi	doc_491521501750_item	3735210	et	0	main
olla	doc_491521501750_item	3735211	et	0	main
tegemist	doc_491521501750_item	3735212	et	0	main
ka	doc_491521501750_item	3735213	et	0	main
kõnekeele	doc_491521501750_item	3735214	et	0	main
mõjuga	doc_491521501750_item	3735215	et	0	main
3	doc_491521501750_item	3735216	et	0	main
sõnatasand	doc_491521501750_item	3735217	et	0	main
stiilivead	doc_491521501750_item	3735218	et	0	main
kuigi	doc_491521501750_item	3735219	et	0	main
e-kirjades	doc_491521501750_item	3735220	et	0	main
kasutatakse	doc_491521501750_item	3735221	et	0	main
palju	doc_491521501750_item	3735222	et	0	main
kõnekeelt	doc_491521501750_item	3735223	et	0	main
leidsin	doc_491521501750_item	3735224	et	0	main
siiski	doc_491521501750_item	3735225	et	0	main
ühe	doc_491521501750_item	3735226	et	0	main
näite	doc_491521501750_item	3735227	et	0	main
mille	doc_491521501750_item	3735228	et	0	main
puhul	doc_491521501750_item	3735229	et	0	main
kahtlen	doc_491521501750_item	3735230	et	0	main
et	doc_491521501750_item	3735231	et	0	main
kas	doc_491521501750_item	3735232	et	0	main
mõni	doc_491521501750_item	3735233	et	0	main
eestlane	doc_491521501750_item	3735234	et	0	main
oleks	doc_491521501750_item	3735235	et	0	main
niimoodi	doc_491521501750_item	3735236	et	0	main
kirjutanud	doc_491521501750_item	3735237	et	0	main
materiaali	doc_491521501750_item	3735238	et	0	main
kulud	doc_491521501750_item	3735239	et	0	main
oleks	doc_491521501750_item	3735240	et	0	main
mulle	doc_491521501750_item	3735241	et	0	main
endale	doc_491521501750_item	3735242	et	0	main
kiri	doc_491521501750_item	3735243	et	0	main
1	doc_491521501750_item	3735244	et	0	main
siin	doc_491521501750_item	3735245	et	0	main
on	doc_491521501750_item	3735246	et	0	main
milma	doc_491521501750_item	3735247	et	0	main
arvatavasti	doc_491521501750_item	3735248	et	0	main
moodustanud	doc_491521501750_item	3735249	et	0	main
üle	doc_491521501750_item	3735250	et	0	main
jõu	doc_491521501750_item	3735251	et	0	main
käiva	doc_491521501750_item	3735252	et	0	main
konstruktsiooniga	doc_491521501750_item	3735253	et	0	main
lause	doc_491521501750_item	3735254	et	0	main
veel	doc_491521501750_item	3735255	et	0	main
mõned	doc_491521501750_item	3735256	et	0	main
näited	doc_491521501750_item	3735257	et	0	main
kõnekeelest	doc_491521501750_item	3735258	et	0	main
interjööris	doc_491521501750_item	3735259	et	0	main
kindlasti	doc_491521501750_item	3735260	et	0	main
nagu	doc_491521501750_item	3735261	et	0	main
nii	doc_491521501750_item	3735262	et	0	main
pole	doc_491521501750_item	3735263	et	0	main
piisavalt	doc_491521501750_item	3735264	et	0	main
ja	doc_491521501750_item	3735265	et	0	main
olen	doc_491521501750_item	3735266	et	0	main
järgmine	doc_491521501750_item	3735267	et	0	main
kord	doc_491521501750_item	3735268	et	0	main
see	doc_491521501750_item	3735269	et	0	main
nädalavahetus	doc_491521501750_item	3735270	et	0	main
eestis	doc_491521501750_item	3735271	et	0	main
mõlemad	doc_491521501750_item	3735272	et	0	main
kiri	doc_491521501750_item	3735273	et	0	main
1	doc_491521501750_item	3735274	et	0	main
need	doc_491521501750_item	3735275	et	0	main
on	doc_491521501750_item	3735276	et	0	main
juba	doc_491521501750_item	3735277	et	0	main
tavalised	doc_491521501750_item	3735278	et	0	main
ka	doc_491521501750_item	3735279	et	0	main
eestlaste	doc_491521501750_item	3735280	et	0	main
poolt	doc_491521501750_item	3735281	et	0	main
kasutatavad	doc_491521501750_item	3735282	et	0	main
kõnekeele	doc_491521501750_item	3735283	et	0	main
näited	doc_491521501750_item	3735284	et	0	main
leidsin	doc_491521501750_item	3735285	et	0	main
ka	doc_491521501750_item	3735286	et	0	main
ühe	doc_491521501750_item	3735287	et	0	main
näite	doc_491521501750_item	3735288	et	0	main
võimalikust	doc_491521501750_item	3735289	et	0	main
soome	doc_491521501750_item	3735290	et	0	main
kõnekeele	doc_491521501750_item	3735291	et	0	main
mõjust	doc_491521501750_item	3735292	et	0	main
päevavalgus	doc_491521501750_item	3735293	et	0	main
oleks	doc_491521501750_item	3735294	et	0	main
hea	doc_491521501750_item	3735295	et	0	main
kui	doc_491521501750_item	3735296	et	0	main
voimatu	doc_491521501750_item	3735297	et	0	main
siis	doc_491521501750_item	3735298	et	0	main
saab	doc_491521501750_item	3735299	et	0	main
ilma	doc_491521501750_item	3735300	et	0	main
ka	doc_491521501750_item	3735301	et	0	main
hakkama	doc_491521501750_item	3735302	et	0	main
kiri	doc_491521501750_item	3735303	et	0	main
1	doc_491521501750_item	3735304	et	0	main
arvan	doc_491521501750_item	3735305	et	0	main
et	doc_491521501750_item	3735306	et	0	main
isegi	doc_491521501750_item	3735307	et	0	main
eesti	doc_491521501750_item	3735308	et	0	main
kõnekeeles	doc_491521501750_item	3735309	et	0	main
nii	doc_491521501750_item	3735310	et	0	main
lühikest	doc_491521501750_item	3735311	et	0	main
varianti	doc_491521501750_item	3735312	et	0	main
ei	doc_491521501750_item	3735313	et	0	main
kasutata	doc_491521501750_item	3735314	et	0	main
pigem	doc_491521501750_item	3735315	et	0	main
ikkagi	doc_491521501750_item	3735316	et	0	main
kui	doc_491521501750_item	3735317	et	0	main
see	doc_491521501750_item	3735318	et	0	main
on	doc_491521501750_item	3735319	et	0	main
võimatu	doc_491521501750_item	3735320	et	0	main
või	doc_491521501750_item	3735321	et	0	main
kui	doc_491521501750_item	3735322	et	0	main
pole	doc_491521501750_item	3735323	et	0	main
võimalik	doc_491521501750_item	3735324	et	0	main
sõnavead	doc_491521501750_item	3735325	et	0	main
leidsin	doc_491521501750_item	3735326	et	0	main
kaks	doc_491521501750_item	3735327	et	0	main
viga	doc_491521501750_item	3735328	et	0	main
mis	doc_491521501750_item	3735329	et	0	main
arvatavasti	doc_491521501750_item	3735330	et	0	main
on	doc_491521501750_item	3735331	et	0	main
mõjutatud	doc_491521501750_item	3735332	et	0	main
soome	doc_491521501750_item	3735333	et	0	main
keelest	doc_491521501750_item	3735334	et	0	main
muidu	doc_491521501750_item	3735335	et	0	main
kui	doc_491521501750_item	3735336	et	0	main
sulle	doc_491521501750_item	3735337	et	0	main
tundub	doc_491521501750_item	3735338	et	0	main
et	doc_491521501750_item	3735339	et	0	main
kiri	doc_491521501750_item	3735340	et	0	main
2	doc_491521501750_item	3735341	et	0	main
vea	doc_491521501750_item	3735342	et	0	main
on	doc_491521501750_item	3735343	et	0	main
põhjustanud	doc_491521501750_item	3735344	et	0	main
soomekeelne	doc_491521501750_item	3735345	et	0	main
muuten	doc_491521501750_item	3735346	et	0	main
jos	doc_491521501750_item	3735347	et	0	main
eesti	doc_491521501750_item	3735348	et	0	main
keeles	doc_491521501750_item	3735349	et	0	main
sobiks	doc_491521501750_item	3735350	et	0	main
siia	doc_491521501750_item	3735351	et	0	main
muide	doc_491521501750_item	3735352	et	0	main
või	doc_491521501750_item	3735353	et	0	main
muidugi	doc_491521501750_item	3735354	et	0	main
loomulikult	doc_491521501750_item	3735355	et	0	main
ei	doc_491521501750_item	3735356	et	0	main
saa	doc_491521501750_item	3735357	et	0	main
täielikult	doc_491521501750_item	3735358	et	0	main
välistada	doc_491521501750_item	3735359	et	0	main
et	doc_491521501750_item	3735360	et	0	main
milma	doc_491521501750_item	3735361	et	0	main
on	doc_491521501750_item	3735362	et	0	main
ikkagi	doc_491521501750_item	3735363	et	0	main
mõelnud	doc_491521501750_item	3735364	et	0	main
kasutada	doc_491521501750_item	3735365	et	0	main
ühte	doc_491521501750_item	3735366	et	0	main
neist	doc_491521501750_item	3735367	et	0	main
aga	doc_491521501750_item	3735368	et	0	main
on	doc_491521501750_item	3735369	et	0	main
teinud	doc_491521501750_item	3735370	et	0	main
lihtsalt	doc_491521501750_item	3735371	et	0	main
hooletusvea	doc_491521501750_item	3735372	et	0	main
viga	doc_491521501750_item	3735373	et	0	main
sõnas	doc_491521501750_item	3735374	et	0	main
materiaali	doc_491521501750_item	3735375	et	0	main
kiri	doc_491521501750_item	3735376	et	0	main
1	doc_491521501750_item	3735377	et	0	main
oli	doc_491521501750_item	3735378	et	0	main
natuke	doc_491521501750_item	3735379	et	0	main
üllatav	doc_491521501750_item	3735380	et	0	main
sest	doc_491521501750_item	3735381	et	0	main
sõna	doc_491521501750_item	3735382	et	0	main
interjöör	doc_491521501750_item	3735383	et	0	main
mis	doc_491521501750_item	3735384	et	0	main
on	doc_491521501750_item	3735385	et	0	main
samuti	doc_491521501750_item	3735386	et	0	main
sarnane	doc_491521501750_item	3735387	et	0	main
oma	doc_491521501750_item	3735388	et	0	main
soomekeelsele	doc_491521501750_item	3735389	et	0	main
vastele	doc_491521501750_item	3735390	et	0	main
on	doc_491521501750_item	3735391	et	0	main
milmal	doc_491521501750_item	3735392	et	0	main
korrektselt	doc_491521501750_item	3735393	et	0	main
kirjutatud	doc_491521501750_item	3735394	et	0	main
kiri	doc_491521501750_item	3735395	et	0	main
1	doc_491521501750_item	3735396	et	0	main
kuule	doc_491521501750_item	3735397	et	0	main
kuidas	doc_491521501750_item	3735398	et	0	main
oleks	doc_491521501750_item	3735399	et	0	main
töö	doc_491521501750_item	3735400	et	0	main
tööst	doc_491521501750_item	3735401	et	0	main
diil	doc_491521501750_item	3735402	et	0	main
ma	doc_491521501750_item	3735403	et	0	main
motlen	doc_491521501750_item	3735404	et	0	main
et	doc_491521501750_item	3735405	et	0	main
kui	doc_491521501750_item	3735406	et	0	main
ma	doc_491521501750_item	3735407	et	0	main
piltistan	doc_491521501750_item	3735408	et	0	main
teie	doc_491521501750_item	3735409	et	0	main
asjad	doc_491521501750_item	3735410	et	0	main
ära	doc_491521501750_item	3735411	et	0	main
ytleme	doc_491521501750_item	3735412	et	0	main
et	doc_491521501750_item	3735413	et	0	main
algust	doc_491521501750_item	3735414	et	0	main
loppuni	doc_491521501750_item	3735415	et	0	main
ja	doc_491521501750_item	3735416	et	0	main
annan	doc_491521501750_item	3735417	et	0	main
sulle	doc_491521501750_item	3735418	et	0	main
yhe	doc_491521501750_item	3735419	et	0	main
printi	doc_491521501750_item	3735420	et	0	main
igas	doc_491521501750_item	3735421	et	0	main
vaibast	doc_491521501750_item	3735422	et	0	main
ja	doc_491521501750_item	3735423	et	0	main
tutavatele	doc_491521501750_item	3735424	et	0	main
näiteks	doc_491521501750_item	3735425	et	0	main
viis	doc_491521501750_item	3735426	et	0	main
pilti	doc_491521501750_item	3735427	et	0	main
interjöörist	doc_491521501750_item	3735428	et	0	main
siis	doc_491521501750_item	3735429	et	0	main
selle	doc_491521501750_item	3735430	et	0	main
eest	doc_491521501750_item	3735431	et	0	main
saan	doc_491521501750_item	3735432	et	0	main
sinu	doc_491521501750_item	3735433	et	0	main
käest	doc_491521501750_item	3735434	et	0	main
vaiba	doc_491521501750_item	3735435	et	0	main
ma	doc_491521501750_item	3735436	et	0	main
arvan	doc_491521501750_item	3735437	et	0	main
et	doc_491521501750_item	3735438	et	0	main
sellise	doc_491521501750_item	3735439	et	0	main
töö	doc_491521501750_item	3735440	et	0	main
materiaali	doc_491521501750_item	3735441	et	0	main
kulud	doc_491521501750_item	3735442	et	0	main
oleks	doc_491521501750_item	3735443	et	0	main
mulle	doc_491521501750_item	3735444	et	0	main
endale	doc_491521501750_item	3735445	et	0	main
umbes	doc_491521501750_item	3735446	et	0	main
300	doc_491521501750_item	3735447	et	0	main
fimi	doc_491521501750_item	3735448	et	0	main
ja	doc_491521501750_item	3735449	et	0	main
aega	doc_491521501750_item	3735450	et	0	main
läheks	doc_491521501750_item	3735451	et	0	main
pildistamisele	doc_491521501750_item	3735452	et	0	main
ytleme	doc_491521501750_item	3735453	et	0	main
yks	doc_491521501750_item	3735454	et	0	main
päev	doc_491521501750_item	3735455	et	0	main
ja	doc_491521501750_item	3735456	et	0	main
ilmuttamisele	doc_491521501750_item	3735457	et	0	main
ja	doc_491521501750_item	3735458	et	0	main
printtimisele	doc_491521501750_item	3735459	et	0	main
3-4	doc_491521501750_item	3735460	et	0	main
päeva	doc_491521501750_item	3735461	et	0	main
kuna	doc_491521501750_item	3735462	et	0	main
pean	doc_491521501750_item	3735463	et	0	main
koige	doc_491521501750_item	3735464	et	0	main
käsitse	doc_491521501750_item	3735465	et	0	main
tegema	doc_491521501750_item	3735466	et	0	main
ytle	doc_491521501750_item	3735467	et	0	main
mis	doc_491521501750_item	3735468	et	0	main
arvad	doc_491521501750_item	3735469	et	0	main
ja	doc_491521501750_item	3735470	et	0	main
kus	doc_491521501750_item	3735471	et	0	main
see	doc_491521501750_item	3735472	et	0	main
koht	doc_491521501750_item	3735473	et	0	main
asub	doc_491521501750_item	3735474	et	0	main
kus	doc_491521501750_item	3735475	et	0	main
peaks	doc_491521501750_item	3735476	et	0	main
pildisdama	doc_491521501750_item	3735477	et	0	main
ma	doc_491521501750_item	3735478	et	0	main
arvan	doc_491521501750_item	3735479	et	0	main
et	doc_491521501750_item	3735480	et	0	main
olen	doc_491521501750_item	3735481	et	0	main
järgmine	doc_491521501750_item	3735482	et	0	main
kord	doc_491521501750_item	3735483	et	0	main
see	doc_491521501750_item	3735484	et	0	main
nädalavahetus	doc_491521501750_item	3735485	et	0	main
eestis	doc_491521501750_item	3735486	et	0	main
ja	doc_491521501750_item	3735487	et	0	main
voiks	doc_491521501750_item	3735488	et	0	main
siis	doc_491521501750_item	3735489	et	0	main
äkki	doc_491521501750_item	3735490	et	0	main
kohe	doc_491521501750_item	3735491	et	0	main
ära	doc_491521501750_item	3735492	et	0	main
teha	doc_491521501750_item	3735493	et	0	main
vaipade	doc_491521501750_item	3735494	et	0	main
pildisdamiseks	doc_491521501750_item	3735495	et	0	main
päevavalgus	doc_491521501750_item	3735496	et	0	main
oleks	doc_491521501750_item	3735497	et	0	main
hea	doc_491521501750_item	3735498	et	0	main
kui	doc_491521501750_item	3735499	et	0	main
voimatu	doc_491521501750_item	3735500	et	0	main
siis	doc_491521501750_item	3735501	et	0	main
saab	doc_491521501750_item	3735502	et	0	main
ilma	doc_491521501750_item	3735503	et	0	main
ka	doc_491521501750_item	3735504	et	0	main
hakkama	doc_491521501750_item	3735505	et	0	main
interjööris	doc_491521501750_item	3735506	et	0	main
kindlasti	doc_491521501750_item	3735507	et	0	main
nagu	doc_491521501750_item	3735508	et	0	main
nii	doc_491521501750_item	3735509	et	0	main
pole	doc_491521501750_item	3735510	et	0	main
piisavalt	doc_491521501750_item	3735511	et	0	main
päevavalgust	doc_491521501750_item	3735512	et	0	main
ja	doc_491521501750_item	3735513	et	0	main
peab	doc_491521501750_item	3735514	et	0	main
miksima	doc_491521501750_item	3735515	et	0	main
välguga	doc_491521501750_item	3735516	et	0	main
aga	doc_491521501750_item	3735517	et	0	main
teata	doc_491521501750_item	3735518	et	0	main
mis	doc_491521501750_item	3735519	et	0	main
arvad	doc_491521501750_item	3735520	et	0	main
milma	doc_491521501750_item	3735521	et	0	main
kiri	doc_491521501750_item	3735522	et	0	main
2	doc_491521501750_item	3735523	et	0	main
kuule	doc_491521501750_item	3735524	et	0	main
ostsin	doc_491521501750_item	3735525	et	0	main
nüüd	doc_491521501750_item	3735526	et	0	main
igal	doc_491521501750_item	3735527	et	0	main
juhul	doc_491521501750_item	3735528	et	0	main
filmi	doc_491521501750_item	3735529	et	0	main
ja	doc_491521501750_item	3735530	et	0	main
panin	doc_491521501750_item	3735531	et	0	main
koolist	doc_491521501750_item	3735532	et	0	main
kaamera	doc_491521501750_item	3735533	et	0	main
kinni	doc_491521501750_item	3735534	et	0	main
kuna	doc_491521501750_item	3735535	et	0	main
homme	doc_491521501750_item	3735536	et	0	main
vist	doc_491521501750_item	3735537	et	0	main
enam	doc_491521501750_item	3735538	et	0	main
ei	doc_491521501750_item	3735539	et	0	main
jõua	doc_491521501750_item	3735540	et	0	main
seda	doc_491521501750_item	3735541	et	0	main
teha	doc_491521501750_item	3735542	et	0	main
aga	doc_491521501750_item	3735543	et	0	main
kui	doc_491521501750_item	3735544	et	0	main
jõuad	doc_491521501750_item	3735545	et	0	main
oleks	doc_491521501750_item	3735546	et	0	main
ikkagi	doc_491521501750_item	3735547	et	0	main
hea	doc_491521501750_item	3735548	et	0	main
kui	doc_491521501750_item	3735549	et	0	main
ütled	doc_491521501750_item	3735550	et	0	main
kuidas	doc_491521501750_item	3735551	et	0	main
on	doc_491521501750_item	3735552	et	0	main
teaksin	doc_491521501750_item	3735553	et	0	main
mis	doc_491521501750_item	3735554	et	0	main
pean	doc_491521501750_item	3735555	et	0	main
kaas	doc_491521501750_item	3735556	et	0	main
võtma	doc_491521501750_item	3735557	et	0	main
vaatan	doc_491521501750_item	3735558	et	0	main
meile	doc_491521501750_item	3735559	et	0	main
veel	doc_491521501750_item	3735560	et	0	main
täna	doc_491521501750_item	3735561	et	0	main
õhtul	doc_491521501750_item	3735562	et	0	main
kindlasti	doc_491521501750_item	3735563	et	0	main
ja	doc_491521501750_item	3735564	et	0	main
loodan	doc_491521501750_item	3735565	et	0	main
et	doc_491521501750_item	3735566	et	0	main
homme	doc_491521501750_item	3735567	et	0	main
ka	doc_491521501750_item	3735568	et	0	main
veel	doc_491521501750_item	3735569	et	0	main
enne	doc_491521501750_item	3735570	et	0	main
kahtteist	doc_491521501750_item	3735571	et	0	main
muidu	doc_491521501750_item	3735572	et	0	main
kui	doc_491521501750_item	3735573	et	0	main
sulle	doc_491521501750_item	3735574	et	0	main
tundub	doc_491521501750_item	3735575	et	0	main
et	doc_491521501750_item	3735576	et	0	main
vaib	doc_491521501750_item	3735577	et	0	main
on	doc_491521501750_item	3735578	et	0	main
sellest	doc_491521501750_item	3735579	et	0	main
palju	doc_491521501750_item	3735580	et	0	main
vastu	doc_491521501750_item	3735581	et	0	main
anda	doc_491521501750_item	3735582	et	0	main
siis	doc_491521501750_item	3735583	et	0	main
võib	doc_491521501750_item	3735584	et	0	main
nii	doc_491521501750_item	3735585	et	0	main
ka	doc_491521501750_item	3735586	et	0	main
teha	doc_491521501750_item	3735587	et	0	main
et	doc_491521501750_item	3735588	et	0	main
pildistan	doc_491521501750_item	3735589	et	0	main
ainuld	doc_491521501750_item	3735590	et	0	main
need	doc_491521501750_item	3735591	et	0	main
sinu	doc_491521501750_item	3735592	et	0	main
vaibad	doc_491521501750_item	3735593	et	0	main
seal	doc_491521501750_item	3735594	et	0	main
kus	doc_491521501750_item	3735595	et	0	main
nad	doc_491521501750_item	3735596	et	0	main
nüüd	doc_491521501750_item	3735597	et	0	main
olid	doc_491521501750_item	3735598	et	0	main
aga	doc_491521501750_item	3735599	et	0	main
jättaks	doc_491521501750_item	3735600	et	0	main
siis	doc_491521501750_item	3735601	et	0	main
selle	doc_491521501750_item	3735602	et	0	main
interjööri	doc_491521501750_item	3735603	et	0	main
ära	doc_491521501750_item	3735604	et	0	main
jättan	doc_491521501750_item	3735605	et	0	main
siis	doc_491521501750_item	3735606	et	0	main
filmi	doc_491521501750_item	3735607	et	0	main
sinu	doc_491521501750_item	3735608	et	0	main
kätte	doc_491521501750_item	3735609	et	0	main
ja	doc_491521501750_item	3735610	et	0	main
sa	doc_491521501750_item	3735611	et	0	main
saad	doc_491521501750_item	3735612	et	0	main
ise	doc_491521501750_item	3735613	et	0	main
need	doc_491521501750_item	3735614	et	0	main
pildid	doc_491521501750_item	3735615	et	0	main
kusgilt	doc_491521501750_item	3735616	et	0	main
näiteks	doc_491521501750_item	3735617	et	0	main
morganist	doc_491521501750_item	3735618	et	0	main
tellida	doc_491521501750_item	3735619	et	0	main
onju	doc_491521501750_item	3735620	et	0	main
arvan	doc_491521501750_item	3735621	et	0	main
et	doc_491521501750_item	3735622	et	0	main
see	doc_491521501750_item	3735623	et	0	main
vaipade	doc_491521501750_item	3735624	et	0	main
pildistamine	doc_491521501750_item	3735625	et	0	main
on	doc_491521501750_item	3735626	et	0	main
lihtne	doc_491521501750_item	3735627	et	0	main
ja	doc_491521501750_item	3735628	et	0	main
seda	doc_491521501750_item	3735629	et	0	main
saab	doc_491521501750_item	3735630	et	0	main
igal	doc_491521501750_item	3735631	et	0	main
juhul	doc_491521501750_item	3735632	et	0	main
teha	doc_491521501750_item	3735633	et	0	main
noh	doc_491521501750_item	3735634	et	0	main
aga	doc_491521501750_item	3735635	et	0	main
teata	doc_491521501750_item	3735636	et	0	main
siis	doc_491521501750_item	3735637	et	0	main
onju	doc_491521501750_item	3735638	et	0	main
milma	doc_491521501750_item	3735639	et	0	main
kiri	doc_491521501750_item	3735640	et	0	main
3	doc_491521501750_item	3735641	et	0	main
ma	doc_491521501750_item	3735642	et	0	main
tulen	doc_491521501750_item	3735643	et	0	main
järgmine	doc_491521501750_item	3735644	et	0	main
kort	doc_491521501750_item	3735645	et	0	main
ilmselt	doc_491521501750_item	3735646	et	0	main
kahe	doc_491521501750_item	3735647	et	0	main
nädala	doc_491521501750_item	3735648	et	0	main
pärast	doc_491521501750_item	3735649	et	0	main
siis	doc_491521501750_item	3735650	et	0	main
kui	doc_491521501750_item	3735651	et	0	main
see	doc_491521501750_item	3735652	et	0	main
kätlini	doc_491521501750_item	3735653	et	0	main
klaasi	doc_491521501750_item	3735654	et	0	main
näitus	doc_491521501750_item	3735655	et	0	main
avatakse	doc_491521501750_item	3735656	et	0	main
aga	doc_491521501750_item	3735657	et	0	main
see	doc_491521501750_item	3735658	et	0	main
on	doc_491521501750_item	3735659	et	0	main
vist	doc_491521501750_item	3735660	et	0	main
umbes	doc_491521501750_item	3735661	et	0	main
just	doc_491521501750_item	3735662	et	0	main
20	doc_491521501750_item	3735663	et	0	main
nii	doc_491521501750_item	3735664	et	0	main
et	doc_491521501750_item	3735665	et	0	main
voib	doc_491521501750_item	3735666	et	0	main
olla	doc_491521501750_item	3735667	et	0	main
siis	doc_491521501750_item	3735668	et	0	main
ka	doc_491521501750_item	3735669	et	0	main
ei	doc_491521501750_item	3735670	et	0	main
joua	doc_491521501750_item	3735671	et	0	main
pildistada	doc_491521501750_item	3735672	et	0	main
aga	doc_491521501750_item	3735673	et	0	main
kui	doc_491521501750_item	3735674	et	0	main
vähemalt	doc_491521501750_item	3735675	et	0	main
kokku	doc_491521501750_item	3735676	et	0	main
saaks	doc_491521501750_item	3735677	et	0	main
siis	doc_491521501750_item	3735678	et	0	main
saaks	doc_491521501750_item	3735679	et	0	main
asja	doc_491521501750_item	3735680	et	0	main
arutada	doc_491521501750_item	3735681	et	0	main
onju	doc_491521501750_item	3735682	et	0	main
nii	doc_491521501750_item	3735683	et	0	main
et	doc_491521501750_item	3735684	et	0	main
umbes	doc_491521501750_item	3735685	et	0	main
20ndal	doc_491521501750_item	3735686	et	0	main
tulen	doc_491521501750_item	3735687	et	0	main
voi	doc_491521501750_item	3735688	et	0	main
siis	doc_491521501750_item	3735689	et	0	main
päeva	doc_491521501750_item	3735690	et	0	main
enne	doc_491521501750_item	3735691	et	0	main
näiteks	doc_491521501750_item	3735692	et	0	main
kui	doc_491521501750_item	3735693	et	0	main
vaja	doc_491521501750_item	3735694	et	0	main
milma	doc_491521501750_item	3735695	et	0	main
kustutada	doc_491521501744_item	3739118	et	0	main
tekst	doc_491521501744_item	3739119	et	0	main
kustutada	doc_491521501744_item	3739120	et	0	main
samasugune	doc_491521501744_item	3739121	et	0	main
tekst	doc_491521501744_item	3739122	et	0	main
siin	doc_491521501744_item	3739123	et	0	main
httpevkktlueedocumentsdoc491521501867item	doc_491521501744_item	3739124	et	0	main
tallinna	doc_491521501744_item	3739125	et	0	main
pedagoogikaülikool	doc_491521501744_item	3739126	et	0	main
eesti	doc_491521501744_item	3739127	et	0	main
filoloogia	doc_491521501744_item	3739128	et	0	main
teaduskond	doc_491521501744_item	3739129	et	0	main
eesti	doc_491521501744_item	3739130	et	0	main
keele	doc_491521501744_item	3739131	et	0	main
õppetool	doc_491521501744_item	3739132	et	0	main
vigade	doc_491521501744_item	3739133	et	0	main
analüüs	doc_491521501744_item	3739134	et	0	main
uurimistöö	doc_491521501744_item	3739135	et	0	main
tallinn	doc_491521501744_item	3739136	et	0	main
2001	doc_491521501744_item	3739137	et	0	main
sisukord	doc_491521501744_item	3739138	et	0	main
sissejuhatus	doc_491521501744_item	3739139	et	0	main
vigade	doc_491521501744_item	3739140	et	0	main
registreerimine	doc_491521501744_item	3739141	et	0	main
vigade	doc_491521501744_item	3739142	et	0	main
rühmitamine	doc_491521501744_item	3739143	et	0	main
ja	doc_491521501744_item	3739144	et	0	main
põhjuste	doc_491521501744_item	3739145	et	0	main
seletamine	doc_491521501744_item	3739146	et	0	main
kokkuvõte	doc_491521501744_item	3739147	et	0	main
kasutatud	doc_491521501744_item	3739148	et	0	main
kirjandus	doc_491521501744_item	3739149	et	0	main
sissejuhatus	doc_491521501744_item	3739150	et	0	main
keeleoskust	doc_491521501744_item	3739151	et	0	main
hinnatakse	doc_491521501744_item	3739152	et	0	main
vastavalt	doc_491521501744_item	3739153	et	0	main
sellele	doc_491521501744_item	3739154	et	0	main
kui	doc_491521501744_item	3739155	et	0	main
mitmes	doc_491521501744_item	3739156	et	0	main
valdkonnas	doc_491521501744_item	3739157	et	0	main
inimene	doc_491521501744_item	3739158	et	0	main
on	doc_491521501744_item	3739159	et	0	main
võimeline	doc_491521501744_item	3739160	et	0	main
kaasa	doc_491521501744_item	3739161	et	0	main
rääkima	doc_491521501744_item	3739162	et	0	main
kui	doc_491521501744_item	3739163	et	0	main
õigesti	doc_491521501744_item	3739164	et	0	main
ta	doc_491521501744_item	3739165	et	0	main
seda	doc_491521501744_item	3739166	et	0	main
teeb	doc_491521501744_item	3739167	et	0	main
viga	doc_491521501744_item	3739168	et	0	main
on	doc_491521501744_item	3739169	et	0	main
kõrvalekalle	doc_491521501744_item	3739170	et	0	main
kehtivast	doc_491521501744_item	3739171	et	0	main
normist	doc_491521501744_item	3739172	et	0	main
keeleviga	doc_491521501744_item	3739173	et	0	main
võib	doc_491521501744_item	3739174	et	0	main
olla	doc_491521501744_item	3739175	et	0	main
vääratus	doc_491521501744_item	3739176	et	0	main
või	doc_491521501744_item	3739177	et	0	main
eksitus	doc_491521501744_item	3739178	et	0	main
mis	doc_491521501744_item	3739179	et	0	main
põhjustab	doc_491521501744_item	3739180	et	0	main
arusaamatuse	doc_491521501744_item	3739181	et	0	main
ja	doc_491521501744_item	3739182	et	0	main
valestimõistmist	doc_491521501744_item	3739183	et	0	main
mai	doc_491521501744_item	3739184	et	0	main
loog	doc_491521501744_item	3739185	et	0	main
ja	doc_491521501744_item	3739186	et	0	main
krista	doc_491521501744_item	3739187	et	0	main
kerge	doc_491521501744_item	3739188	et	0	main
1999	doc_491521501744_item	3739189	et	0	main
on	doc_491521501744_item	3739190	et	0	main
defineerinud	doc_491521501744_item	3739191	et	0	main
viga	doc_491521501744_item	3739192	et	0	main
kui	doc_491521501744_item	3739193	et	0	main
süstemaatilist	doc_491521501744_item	3739194	et	0	main
eksimist	doc_491521501744_item	3739195	et	0	main
mis	doc_491521501744_item	3739196	et	0	main
viitab	doc_491521501744_item	3739197	et	0	main
kindla	doc_491521501744_item	3739198	et	0	main
oskuse	doc_491521501744_item	3739199	et	0	main
puudumisele	doc_491521501744_item	3739200	et	0	main
vigu	doc_491521501744_item	3739201	et	0	main
tehakse	doc_491521501744_item	3739202	et	0	main
kui	doc_491521501744_item	3739203	et	0	main
ei	doc_491521501744_item	3739204	et	0	main
tea	doc_491521501744_item	3739205	et	0	main
reegleid	doc_491521501744_item	3739206	et	0	main
kuidas	doc_491521501744_item	3739207	et	0	main
toimida	doc_491521501744_item	3739208	et	0	main
õigesti	doc_491521501744_item	3739209	et	0	main
või	doc_491521501744_item	3739210	et	0	main
kui	doc_491521501744_item	3739211	et	0	main
sellised	doc_491521501744_item	3739212	et	0	main
hoopis	doc_491521501744_item	3739213	et	0	main
puuduvad	doc_491521501744_item	3739214	et	0	main
viga	doc_491521501744_item	3739215	et	0	main
võib	doc_491521501744_item	3739216	et	0	main
olla	doc_491521501744_item	3739217	et	0	main
kerge	doc_491521501744_item	3739218	et	0	main
eksimus	doc_491521501744_item	3739219	et	0	main
ja	doc_491521501744_item	3739220	et	0	main
hõlpsasti	doc_491521501744_item	3739221	et	0	main
kõrvaldatav	doc_491521501744_item	3739222	et	0	main
kui	doc_491521501744_item	3739223	et	0	main
sellele	doc_491521501744_item	3739224	et	0	main
tähelepanu	doc_491521501744_item	3739225	et	0	main
juhtida	doc_491521501744_item	3739226	et	0	main
õpilasele	doc_491521501744_item	3739227	et	0	main
hinnet	doc_491521501744_item	3739228	et	0	main
pannes	doc_491521501744_item	3739229	et	0	main
võtab	doc_491521501744_item	3739230	et	0	main
õpetaja	doc_491521501744_item	3739231	et	0	main
arvesse	doc_491521501744_item	3739232	et	0	main
tehtud	doc_491521501744_item	3739233	et	0	main
vigade	doc_491521501744_item	3739234	et	0	main
hulka	doc_491521501744_item	3739235	et	0	main
ning	doc_491521501744_item	3739236	et	0	main
enamasti	doc_491521501744_item	3739237	et	0	main
ka	doc_491521501744_item	3739238	et	0	main
nende	doc_491521501744_item	3739239	et	0	main
raskusastet	doc_491521501744_item	3739240	et	0	main
võiks	doc_491521501744_item	3739241	et	0	main
arvata	doc_491521501744_item	3739242	et	0	main
et	doc_491521501744_item	3739243	et	0	main
kuulata	doc_491521501744_item	3739244	et	0	main
on	doc_491521501744_item	3739245	et	0	main
kergem	doc_491521501744_item	3739246	et	0	main
kui	doc_491521501744_item	3739247	et	0	main
rääkida	doc_491521501744_item	3739248	et	0	main
või	doc_491521501744_item	3739249	et	0	main
et	doc_491521501744_item	3739250	et	0	main
õigekirjavead	doc_491521501744_item	3739251	et	0	main
on	doc_491521501744_item	3739252	et	0	main
lihtsamad	doc_491521501744_item	3739253	et	0	main
kui	doc_491521501744_item	3739254	et	0	main
vormimoodustusvead	doc_491521501744_item	3739255	et	0	main
ning	doc_491521501744_item	3739256	et	0	main
hindamisel	doc_491521501744_item	3739257	et	0	main
tuleb	doc_491521501744_item	3739258	et	0	main
seda	doc_491521501744_item	3739259	et	0	main
arvestada	doc_491521501744_item	3739260	et	0	main
eesti	doc_491521501744_item	3739261	et	0	main
keele	doc_491521501744_item	3739262	et	0	main
õpetaja	doc_491521501744_item	3739263	et	0	main
peab	doc_491521501744_item	3739264	et	0	main
meeles	doc_491521501744_item	3739265	et	0	main
pidama	doc_491521501744_item	3739266	et	0	main
et	doc_491521501744_item	3739267	et	0	main
emakeeles	doc_491521501744_item	3739268	et	0	main
esinevad	doc_491521501744_item	3739269	et	0	main
vead	doc_491521501744_item	3739270	et	0	main
ei	doc_491521501744_item	3739271	et	0	main
ole	doc_491521501744_item	3739272	et	0	main
olulised	doc_491521501744_item	3739273	et	0	main
sama	doc_491521501744_item	3739274	et	0	main
keele	doc_491521501744_item	3739275	et	0	main
võõrkeelena	doc_491521501744_item	3739276	et	0	main
kõnelemisel	doc_491521501744_item	3739277	et	0	main
käesolev	doc_491521501744_item	3739278	et	0	main
vigade	doc_491521501744_item	3739279	et	0	main
analüüs	doc_491521501744_item	3739280	et	0	main
on	doc_491521501744_item	3739281	et	0	main
pühendatud	doc_491521501744_item	3739282	et	0	main
õpilaste	doc_491521501744_item	3739283	et	0	main
hälbiva	doc_491521501744_item	3739284	et	0	main
eesti	doc_491521501744_item	3739285	et	0	main
keele	doc_491521501744_item	3739286	et	0	main
kasutamisele	doc_491521501744_item	3739287	et	0	main
uurimus	doc_491521501744_item	3739288	et	0	main
on	doc_491521501744_item	3739289	et	0	main
tehtud	doc_491521501744_item	3739290	et	0	main
10	doc_491521501744_item	3739291	et	0	main
klassi	doc_491521501744_item	3739292	et	0	main
õpilaste	doc_491521501744_item	3739293	et	0	main
kirjandite	doc_491521501744_item	3739294	et	0	main
kodutööde	doc_491521501744_item	3739295	et	0	main
ja	doc_491521501744_item	3739296	et	0	main
kontrolltööde	doc_491521501744_item	3739297	et	0	main
alusel	doc_491521501744_item	3739298	et	0	main
tegemist	doc_491521501744_item	3739299	et	0	main
on	doc_491521501744_item	3739300	et	0	main
peamiselt	doc_491521501744_item	3739301	et	0	main
kesktasemega	doc_491521501744_item	3739302	et	0	main
mõnedel	doc_491521501744_item	3739303	et	0	main
on	doc_491521501744_item	3739304	et	0	main
isegi	doc_491521501744_item	3739305	et	0	main
algtase	doc_491521501744_item	3739306	et	0	main
nende	doc_491521501744_item	3739307	et	0	main
tööde	doc_491521501744_item	3739308	et	0	main
alusel	doc_491521501744_item	3739309	et	0	main
püüdsingi	doc_491521501744_item	3739310	et	0	main
analüüsida	doc_491521501744_item	3739311	et	0	main
vigu	doc_491521501744_item	3739312	et	0	main
ja	doc_491521501744_item	3739313	et	0	main
nende	doc_491521501744_item	3739314	et	0	main
põhjusi	doc_491521501744_item	3739315	et	0	main
tahaksin	doc_491521501744_item	3739316	et	0	main
tänada	doc_491521501744_item	3739317	et	0	main
oma	doc_491521501744_item	3739318	et	0	main
koolipoolset	doc_491521501744_item	3739319	et	0	main
juhendajat	doc_491521501744_item	3739320	et	0	main
kes	doc_491521501744_item	3739321	et	0	main
aitas	doc_491521501744_item	3739322	et	0	main
mind	doc_491521501744_item	3739323	et	0	main
uurimismaterjali	doc_491521501744_item	3739324	et	0	main
otsida	doc_491521501744_item	3739325	et	0	main
vigade	doc_491521501744_item	3739326	et	0	main
registreerimine	doc_491521501744_item	3739327	et	0	main
algaja	doc_491521501744_item	3739328	et	0	main
õpetaja	doc_491521501744_item	3739329	et	0	main
ei	doc_491521501744_item	3739330	et	0	main
märka	doc_491521501744_item	3739331	et	0	main
kõiki	doc_491521501744_item	3739332	et	0	main
vigu	doc_491521501744_item	3739333	et	0	main
sest	doc_491521501744_item	3739334	et	0	main
paljud	doc_491521501744_item	3739335	et	0	main
neist	doc_491521501744_item	3739336	et	0	main
on	doc_491521501744_item	3739337	et	0	main
ootamatud	doc_491521501744_item	3739338	et	0	main
ebaloogilised	doc_491521501744_item	3739339	et	0	main
ja	doc_491521501744_item	3739340	et	0	main
neid	doc_491521501744_item	3739341	et	0	main
tehakse	doc_491521501744_item	3739342	et	0	main
arusaamatutel	doc_491521501744_item	3739343	et	0	main
põhjustel	doc_491521501744_item	3739344	et	0	main
isegi	doc_491521501744_item	3739345	et	0	main
kui	doc_491521501744_item	3739346	et	0	main
ta	doc_491521501744_item	3739347	et	0	main
märkab	doc_491521501744_item	3739348	et	0	main
vigu	doc_491521501744_item	3739349	et	0	main
ei	doc_491521501744_item	3739350	et	0	main
oska	doc_491521501744_item	3739351	et	0	main
ta	doc_491521501744_item	3739352	et	0	main
neid	doc_491521501744_item	3739353	et	0	main
käsitleda	doc_491521501744_item	3739354	et	0	main
juhtub	doc_491521501744_item	3739355	et	0	main
ju	doc_491521501744_item	3739356	et	0	main
nii	doc_491521501744_item	3739357	et	0	main
et	doc_491521501744_item	3739358	et	0	main
mida	doc_491521501744_item	3739359	et	0	main
rohkem	doc_491521501744_item	3739360	et	0	main
parandada	doc_491521501744_item	3739361	et	0	main
seda	doc_491521501744_item	3739362	et	0	main
hullemaks	doc_491521501744_item	3739363	et	0	main
läheb	doc_491521501744_item	3739364	et	0	main
kirjalik	doc_491521501744_item	3739365	et	0	main
tekst	doc_491521501744_item	3739366	et	0	main
muutub	doc_491521501744_item	3739367	et	0	main
arusaamatuks	doc_491521501744_item	3739368	et	0	main
kõnelev	doc_491521501744_item	3739369	et	0	main
õppija	doc_491521501744_item	3739370	et	0	main
kaotab	doc_491521501744_item	3739371	et	0	main
järje	doc_491521501744_item	3739372	et	0	main
ja	doc_491521501744_item	3739373	et	0	main
jääb	doc_491521501744_item	3739374	et	0	main
sõnatuks	doc_491521501744_item	3739375	et	0	main
vigu	doc_491521501744_item	3739376	et	0	main
on	doc_491521501744_item	3739377	et	0	main
kerge	doc_491521501744_item	3739378	et	0	main
leida	doc_491521501744_item	3739379	et	0	main
kirjakeelest	doc_491521501744_item	3739380	et	0	main
mis	doc_491521501744_item	3739381	et	0	main
on	doc_491521501744_item	3739382	et	0	main
õpetajale	doc_491521501744_item	3739383	et	0	main
nähtav	doc_491521501744_item	3739384	et	0	main
või	doc_491521501744_item	3739385	et	0	main
kuuldav	doc_491521501744_item	3739386	et	0	main
arvan	doc_491521501744_item	3739387	et	0	main
et	doc_491521501744_item	3739388	et	0	main
kirjavigu	doc_491521501744_item	3739389	et	0	main
on	doc_491521501744_item	3739390	et	0	main
suhteliselt	doc_491521501744_item	3739391	et	0	main
mugav	doc_491521501744_item	3739392	et	0	main
parandada	doc_491521501744_item	3739393	et	0	main
sest	doc_491521501744_item	3739394	et	0	main
kirjalikul	doc_491521501744_item	3739395	et	0	main
tekstil	doc_491521501744_item	3739396	et	0	main
on	doc_491521501744_item	3739397	et	0	main
omadus	doc_491521501744_item	3739398	et	0	main
vead	doc_491521501744_item	3739399	et	0	main
silmatorkavaks	doc_491521501744_item	3739400	et	0	main
teha	doc_491521501744_item	3739401	et	0	main
kui	doc_491521501744_item	3739402	et	0	main
õppija	doc_491521501744_item	3739403	et	0	main
saab	doc_491521501744_item	3739404	et	0	main
suulise	doc_491521501744_item	3739405	et	0	main
vastuse	doc_491521501744_item	3739406	et	0	main
viie	doc_491521501744_item	3739407	et	0	main
võib	doc_491521501744_item	3739408	et	0	main
sama	doc_491521501744_item	3739409	et	0	main
tekst	doc_491521501744_item	3739410	et	0	main
kirjalikul	doc_491521501744_item	3739411	et	0	main
kujul	doc_491521501744_item	3739412	et	0	main
ainult	doc_491521501744_item	3739413	et	0	main
nelja-kolme	doc_491521501744_item	3739414	et	0	main
välja	doc_491521501744_item	3739415	et	0	main
teenida	doc_491521501744_item	3739416	et	0	main
samas	doc_491521501744_item	3739417	et	0	main
on	doc_491521501744_item	3739418	et	0	main
kirjalikku	doc_491521501744_item	3739419	et	0	main
tööd	doc_491521501744_item	3739420	et	0	main
parandades	doc_491521501744_item	3739421	et	0	main
õpetajal	doc_491521501744_item	3739422	et	0	main
rohkem	doc_491521501744_item	3739423	et	0	main
aega	doc_491521501744_item	3739424	et	0	main
mõelda	doc_491521501744_item	3739425	et	0	main
kas	doc_491521501744_item	3739426	et	0	main
viga	doc_491521501744_item	3739427	et	0	main
on	doc_491521501744_item	3739428	et	0	main
juhuslik	doc_491521501744_item	3739429	et	0	main
eksitus	doc_491521501744_item	3739430	et	0	main
või	doc_491521501744_item	3739431	et	0	main
tõsine	doc_491521501744_item	3739432	et	0	main
viga	doc_491521501744_item	3739433	et	0	main
mis	doc_491521501744_item	3739434	et	0	main
põhjustatud	doc_491521501744_item	3739435	et	0	main
sellest	doc_491521501744_item	3739436	et	0	main
et	doc_491521501744_item	3739437	et	0	main
reegel	doc_491521501744_item	3739438	et	0	main
ei	doc_491521501744_item	3739439	et	0	main
ole	doc_491521501744_item	3739440	et	0	main
selgeks	doc_491521501744_item	3739441	et	0	main
õpitud	doc_491521501744_item	3739442	et	0	main
vigade	doc_491521501744_item	3739443	et	0	main
rühmitamine	doc_491521501744_item	3739444	et	0	main
ja	doc_491521501744_item	3739445	et	0	main
põhjuste	doc_491521501744_item	3739446	et	0	main
seletamine	doc_491521501744_item	3739447	et	0	main
nii	doc_491521501744_item	3739448	et	0	main
õ	doc_491521501744_item	3739449	et	0	main
petajad	doc_491521501744_item	3739450	et	0	main
kui	doc_491521501744_item	3739451	et	0	main
õpilased	doc_491521501744_item	3739452	et	0	main
oskavad	doc_491521501744_item	3739453	et	0	main
öelda	doc_491521501744_item	3739454	et	0	main
mis	doc_491521501744_item	3739455	et	0	main
on	doc_491521501744_item	3739456	et	0	main
eesti	doc_491521501744_item	3739457	et	0	main
keeles	doc_491521501744_item	3739458	et	0	main
kõige	doc_491521501744_item	3739459	et	0	main
raskem	doc_491521501744_item	3739460	et	0	main
siin	doc_491521501744_item	3739461	et	0	main
on	doc_491521501744_item	3739462	et	0	main
toodud	doc_491521501744_item	3739463	et	0	main
keeletasandid	doc_491521501744_item	3739464	et	0	main
kus	doc_491521501744_item	3739465	et	0	main
10	doc_491521501744_item	3739466	et	0	main
klassi	doc_491521501744_item	3739467	et	0	main
õpilased	doc_491521501744_item	3739468	et	0	main
teevad	doc_491521501744_item	3739469	et	0	main
vigu	doc_491521501744_item	3739470	et	0	main
sõnavara	doc_491521501744_item	3739471	et	0	main
õppija	doc_491521501744_item	3739472	et	0	main
kasutab	doc_491521501744_item	3739473	et	0	main
vale	doc_491521501744_item	3739474	et	0	main
sõna	doc_491521501744_item	3739475	et	0	main
mille	doc_491521501744_item	3739476	et	0	main
tõttu	doc_491521501744_item	3739477	et	0	main
ei	doc_491521501744_item	3739478	et	0	main
ole	doc_491521501744_item	3739479	et	0	main
võimalik	doc_491521501744_item	3739480	et	0	main
lausest	doc_491521501744_item	3739481	et	0	main
aru	doc_491521501744_item	3739482	et	0	main
saada	doc_491521501744_item	3739483	et	0	main
nt	doc_491521501744_item	3739484	et	0	main
kui	doc_491521501744_item	3739485	et	0	main
kõik	doc_491521501744_item	3739486	et	0	main
on	doc_491521501744_item	3739487	et	0	main
juba	doc_491521501744_item	3739488	et	0	main
ära	doc_491521501744_item	3739489	et	0	main
tehtud	doc_491521501744_item	3739490	et	0	main
kindlasti	doc_491521501744_item	3739491	et	0	main
ja	doc_491521501744_item	3739492	et	0	main
mina	doc_491521501744_item	3739493	et	0	main
puhkan	doc_491521501744_item	3739494	et	0	main
kõigidest	doc_491521501744_item	3739495	et	0	main
lause	doc_491521501744_item	3739496	et	0	main
sõnastus	doc_491521501744_item	3739497	et	0	main
on	doc_491521501744_item	3739498	et	0	main
ebaselge	doc_491521501744_item	3739499	et	0	main
seetõttu	doc_491521501744_item	3739500	et	0	main
ei	doc_491521501744_item	3739501	et	0	main
ole	doc_491521501744_item	3739502	et	0	main
võimalik	doc_491521501744_item	3739503	et	0	main
lausest	doc_491521501744_item	3739504	et	0	main
aru	doc_491521501744_item	3739505	et	0	main
saada	doc_491521501744_item	3739506	et	0	main
nt	doc_491521501744_item	3739507	et	0	main
mulle	doc_491521501744_item	3739508	et	0	main
üldse	doc_491521501744_item	3739509	et	0	main
ei	doc_491521501744_item	3739510	et	0	main
meeldi	doc_491521501744_item	3739511	et	0	main
vanamuusika	doc_491521501744_item	3739512	et	0	main
ansamblid	doc_491521501744_item	3739513	et	0	main
ja	doc_491521501744_item	3739514	et	0	main
põllumajandussaated	doc_491521501744_item	3739515	et	0	main
vanamuusika	doc_491521501744_item	3739516	et	0	main
ansablid	doc_491521501744_item	3739517	et	0	main
on	doc_491521501744_item	3739518	et	0	main
kasutatud	doc_491521501744_item	3739519	et	0	main
valesti	doc_491521501744_item	3739520	et	0	main
oleks	doc_491521501744_item	3739521	et	0	main
parem-mulle	doc_491521501744_item	3739522	et	0	main
üldse	doc_491521501744_item	3739523	et	0	main
ei	doc_491521501744_item	3739524	et	0	main
meeldi	doc_491521501744_item	3739525	et	0	main
ansamblid	doc_491521501744_item	3739526	et	0	main
mis	doc_491521501744_item	3739527	et	0	main
mängivad	doc_491521501744_item	3739528	et	0	main
vana	doc_491521501744_item	3739529	et	0	main
muusikat	doc_491521501744_item	3739530	et	0	main
ja	doc_491521501744_item	3739531	et	0	main
põllumajandussaated	doc_491521501744_item	3739532	et	0	main
morfoloogia	doc_491521501744_item	3739533	et	0	main
õppija	doc_491521501744_item	3739534	et	0	main
moodustab	doc_491521501744_item	3739535	et	0	main
vigaseid	doc_491521501744_item	3739536	et	0	main
grammatilisi	doc_491521501744_item	3739537	et	0	main
vorme	doc_491521501744_item	3739538	et	0	main
üks	doc_491521501744_item	3739539	et	0	main
sagedasem	doc_491521501744_item	3739540	et	0	main
põhjus	doc_491521501744_item	3739541	et	0	main
on	doc_491521501744_item	3739542	et	0	main
emakeele	doc_491521501744_item	3739543	et	0	main
mõju	doc_491521501744_item	3739544	et	0	main
liit-	doc_491521501744_item	3739545	et	0	main
ja	doc_491521501744_item	3739546	et	0	main
ühendtegusõnade	doc_491521501744_item	3739547	et	0	main
moodustusvead	doc_491521501744_item	3739548	et	0	main
vead	doc_491521501744_item	3739549	et	0	main
kohtuvad	doc_491521501744_item	3739550	et	0	main
sel	doc_491521501744_item	3739551	et	0	main
juhul	doc_491521501744_item	3739552	et	0	main
et	doc_491521501744_item	3739553	et	0	main
õpilased	doc_491521501744_item	3739554	et	0	main
ei	doc_491521501744_item	3739555	et	0	main
tea	doc_491521501744_item	3739556	et	0	main
mis	doc_491521501744_item	3739557	et	0	main
laadi	doc_491521501744_item	3739558	et	0	main
tegusõnaga	doc_491521501744_item	3739559	et	0	main
on	doc_491521501744_item	3739560	et	0	main
tegemist	doc_491521501744_item	3739561	et	0	main
lauses	doc_491521501744_item	3739562	et	0	main
kas	doc_491521501744_item	3739563	et	0	main
liit-	doc_491521501744_item	3739564	et	0	main
või	doc_491521501744_item	3739565	et	0	main
ühendverbiga	doc_491521501744_item	3739566	et	0	main
eesti	doc_491521501744_item	3739567	et	0	main
keeles	doc_491521501744_item	3739568	et	0	main
liittegusõnad	doc_491521501744_item	3739569	et	0	main
koosnevad	doc_491521501744_item	3739570	et	0	main
kahest	doc_491521501744_item	3739571	et	0	main
erinevast	doc_491521501744_item	3739572	et	0	main
tüvest	doc_491521501744_item	3739573	et	0	main
mis	doc_491521501744_item	3739574	et	0	main
moodustavad	doc_491521501744_item	3739575	et	0	main
liitsõna	doc_491521501744_item	3739576	et	0	main
ja	doc_491521501744_item	3739577	et	0	main
ühendtegusõnad	doc_491521501744_item	3739578	et	0	main
koosnevad	doc_491521501744_item	3739579	et	0	main
tegelikult	doc_491521501744_item	3739580	et	0	main
kahest	doc_491521501744_item	3739581	et	0	main
sõnast	doc_491521501744_item	3739582	et	0	main
tegusõnast	doc_491521501744_item	3739583	et	0	main
ja	doc_491521501744_item	3739584	et	0	main
selle	doc_491521501744_item	3739585	et	0	main
tähendust	doc_491521501744_item	3739586	et	0	main
muutvast	doc_491521501744_item	3739587	et	0	main
abimäärsõnast	doc_491521501744_item	3739588	et	0	main
nt	doc_491521501744_item	3739589	et	0	main
alakoormama	doc_491521501744_item	3739590	et	0	main
mitte	doc_491521501744_item	3739591	et	0	main
ala	doc_491521501744_item	3739592	et	0	main
koormama	doc_491521501744_item	3739593	et	0	main
siirdistutama	doc_491521501744_item	3739594	et	0	main
mitte	doc_491521501744_item	3739595	et	0	main
siird	doc_491521501744_item	3739596	et	0	main
istutama	doc_491521501744_item	3739597	et	0	main
ristküsitlema	doc_491521501744_item	3739598	et	0	main
mitte	doc_491521501744_item	3739599	et	0	main
rist	doc_491521501744_item	3739600	et	0	main
küsitlema	doc_491521501744_item	3739601	et	0	main
nt	doc_491521501744_item	3739602	et	0	main
alla	doc_491521501744_item	3739603	et	0	main
andma	doc_491521501744_item	3739604	et	0	main
mitte	doc_491521501744_item	3739605	et	0	main
allaandma	doc_491521501744_item	3739606	et	0	main
maha	doc_491521501744_item	3739607	et	0	main
magama	doc_491521501744_item	3739608	et	0	main
mitte	doc_491521501744_item	3739609	et	0	main
mahamagama	doc_491521501744_item	3739610	et	0	main
üle	doc_491521501744_item	3739611	et	0	main
elama	doc_491521501744_item	3739612	et	0	main
mitte	doc_491521501744_item	3739613	et	0	main
üleelama	doc_491521501744_item	3739614	et	0	main
õpilastel	doc_491521501744_item	3739615	et	0	main
on	doc_491521501744_item	3739616	et	0	main
raske	doc_491521501744_item	3739617	et	0	main
vahet	doc_491521501744_item	3739618	et	0	main
teha	doc_491521501744_item	3739619	et	0	main
enesekohaste	doc_491521501744_item	3739620	et	0	main
ja	doc_491521501744_item	3739621	et	0	main
sihiliste	doc_491521501744_item	3739622	et	0	main
verbide	doc_491521501744_item	3739623	et	0	main
vahel	doc_491521501744_item	3739624	et	0	main
nt	doc_491521501744_item	3739625	et	0	main
täna	doc_491521501744_item	3739626	et	0	main
jätan	doc_491521501744_item	3739627	et	0	main
mitte	doc_491521501744_item	3739628	et	0	main
jään	doc_491521501744_item	3739629	et	0	main
ma	doc_491521501744_item	3739630	et	0	main
töö	doc_491521501744_item	3739631	et	0	main
tegemata	doc_491521501744_item	3739632	et	0	main
ma	doc_491521501744_item	3739633	et	0	main
liigutan	doc_491521501744_item	3739634	et	0	main
mitte	doc_491521501744_item	3739635	et	0	main
liigun	doc_491521501744_item	3739636	et	0	main
aeglaselt	doc_491521501744_item	3739637	et	0	main
ma	doc_491521501744_item	3739638	et	0	main
pean	doc_491521501744_item	3739639	et	0	main
söötma	doc_491521501744_item	3739640	et	0	main
mitte	doc_491521501744_item	3739641	et	0	main
sööma	doc_491521501744_item	3739642	et	0	main
loomi	doc_491521501744_item	3739643	et	0	main
õpilased	doc_491521501744_item	3739644	et	0	main
ei	doc_491521501744_item	3739645	et	0	main
tee	doc_491521501744_item	3739646	et	0	main
vahet	doc_491521501744_item	3739647	et	0	main
ainsus-	doc_491521501744_item	3739648	et	0	main
ja	doc_491521501744_item	3739649	et	0	main
mitmussõnade	doc_491521501744_item	3739650	et	0	main
vahel	doc_491521501744_item	3739651	et	0	main
sest	doc_491521501744_item	3739652	et	0	main
eesti	doc_491521501744_item	3739653	et	0	main
keeles	doc_491521501744_item	3739654	et	0	main
on	doc_491521501744_item	3739655	et	0	main
nimisõnu	doc_491521501744_item	3739656	et	0	main
mis	doc_491521501744_item	3739657	et	0	main
esinevad	doc_491521501744_item	3739658	et	0	main
tavaliselt	doc_491521501744_item	3739659	et	0	main
ainsuse	doc_491521501744_item	3739660	et	0	main
vormis	doc_491521501744_item	3739661	et	0	main
kurjus	doc_491521501744_item	3739662	et	0	main
headus	doc_491521501744_item	3739663	et	0	main
nohu	doc_491521501744_item	3739664	et	0	main
ja	doc_491521501744_item	3739665	et	0	main
nimisõnu	doc_491521501744_item	3739666	et	0	main
mis	doc_491521501744_item	3739667	et	0	main
esinevad	doc_491521501744_item	3739668	et	0	main
mitmuse	doc_491521501744_item	3739669	et	0	main
vormis	doc_491521501744_item	3739670	et	0	main
mis	doc_491521501744_item	3739671	et	0	main
vene	doc_491521501744_item	3739672	et	0	main
keeles	doc_491521501744_item	3739673	et	0	main
on	doc_491521501744_item	3739674	et	0	main
ainsuses	doc_491521501744_item	3739675	et	0	main
jõulud-	doc_491521501744_item	3739676	et	0	main
рождество	doc_491521501744_item	3739677	et	0	main
rõugud	doc_491521501744_item	3739678	et	0	main
оспа	doc_491521501744_item	3739679	et	0	main
tangud	doc_491521501744_item	3739680	et	0	main
крупа	doc_491521501744_item	3739681	et	0	main
aetakse	doc_491521501744_item	3739682	et	0	main
segi	doc_491521501744_item	3739683	et	0	main
omaduss	doc_491521501744_item	3739684	et	0	main
õ	doc_491521501744_item	3739685	et	0	main
na	doc_491521501744_item	3739686	et	0	main
ja	doc_491521501744_item	3739687	et	0	main
määrsõna	doc_491521501744_item	3739688	et	0	main
sest	doc_491521501744_item	3739689	et	0	main
eesti	doc_491521501744_item	3739690	et	0	main
keeles	doc_491521501744_item	3739691	et	0	main
omadussõnadel	doc_491521501744_item	3739692	et	0	main
kui	doc_491521501744_item	3739693	et	0	main
sõnaliigil	doc_491521501744_item	3739694	et	0	main
on	doc_491521501744_item	3739695	et	0	main
ühisosad	doc_491521501744_item	3739696	et	0	main
määrsõnade	doc_491521501744_item	3739697	et	0	main
tegusõnade	doc_491521501744_item	3739698	et	0	main
arvsõnade	doc_491521501744_item	3739699	et	0	main
ja	doc_491521501744_item	3739700	et	0	main
nimisõnadega	doc_491521501744_item	3739701	et	0	main
mis	doc_491521501744_item	3739702	et	0	main
ei	doc_491521501744_item	3739703	et	0	main
ole	doc_491521501744_item	3739704	et	0	main
vene	doc_491521501744_item	3739705	et	0	main
keeles	doc_491521501744_item	3739706	et	0	main
nt	doc_491521501744_item	3739707	et	0	main
ma	doc_491521501744_item	3739708	et	0	main
väga	doc_491521501744_item	3739709	et	0	main
hästi	doc_491521501744_item	3739710	et	0	main
mitte	doc_491521501744_item	3739711	et	0	main
hea	doc_491521501744_item	3739712	et	0	main
jooksen	doc_491521501744_item	3739713	et	0	main
meie	doc_491521501744_item	3739714	et	0	main
tundides	doc_491521501744_item	3739715	et	0	main
on	doc_491521501744_item	3739716	et	0	main
alati	doc_491521501744_item	3739717	et	0	main
huvitav	doc_491521501744_item	3739718	et	0	main
mitte	doc_491521501744_item	3739719	et	0	main
huvitavalt	doc_491521501744_item	3739720	et	0	main
mul	doc_491521501744_item	3739721	et	0	main
läheb	doc_491521501744_item	3739722	et	0	main
kord	doc_491521501744_item	3739723	et	0	main
halvemini	doc_491521501744_item	3739724	et	0	main
mitte	doc_491521501744_item	3739725	et	0	main
halvem	doc_491521501744_item	3739726	et	0	main
kord	doc_491521501744_item	3739727	et	0	main
paremini	doc_491521501744_item	3739728	et	0	main
mitte	doc_491521501744_item	3739729	et	0	main
parem	doc_491521501744_item	3739730	et	0	main
ärge	doc_491521501744_item	3739731	et	0	main
sisenege-ohtlik	doc_491521501744_item	3739732	et	0	main
mitte	doc_491521501744_item	3739733	et	0	main
ohtlikult	doc_491521501744_item	3739734	et	0	main
omaduss	doc_491521501744_item	3739735	et	0	main
õ	doc_491521501744_item	3739736	et	0	main
nade	doc_491521501744_item	3739737	et	0	main
võrdlusastmete	doc_491521501744_item	3739738	et	0	main
moodustamine	doc_491521501744_item	3739739	et	0	main
on	doc_491521501744_item	3739740	et	0	main
eriti	doc_491521501744_item	3739741	et	0	main
raske	doc_491521501744_item	3739742	et	0	main
õpilased	doc_491521501744_item	3739743	et	0	main
peavad	doc_491521501744_item	3739744	et	0	main
meeles	doc_491521501744_item	3739745	et	0	main
pidama	doc_491521501744_item	3739746	et	0	main
et	doc_491521501744_item	3739747	et	0	main
keskvõrde	doc_491521501744_item	3739748	et	0	main
tunnuseks	doc_491521501744_item	3739749	et	0	main
on	doc_491521501744_item	3739750	et	0	main
alati	doc_491521501744_item	3739751	et	0	main
m	doc_491521501744_item	3739752	et	0	main
mis	doc_491521501744_item	3739753	et	0	main
liitub	doc_491521501744_item	3739754	et	0	main
tavaliselt	doc_491521501744_item	3739755	et	0	main
algvõrde	doc_491521501744_item	3739756	et	0	main
omastava	doc_491521501744_item	3739757	et	0	main
käände	doc_491521501744_item	3739758	et	0	main
tüvele	doc_491521501744_item	3739759	et	0	main
nt	doc_491521501744_item	3739760	et	0	main
suur	doc_491521501744_item	3739761	et	0	main
suure	doc_491521501744_item	3739762	et	0	main
suurem	doc_491521501744_item	3739763	et	0	main
mitte	doc_491521501744_item	3739764	et	0	main
suurtem	doc_491521501744_item	3739765	et	0	main
kaunis	doc_491521501744_item	3739766	et	0	main
kauni	doc_491521501744_item	3739767	et	0	main
kaunim	doc_491521501744_item	3739768	et	0	main
mitte	doc_491521501744_item	3739769	et	0	main
kauunisam	doc_491521501744_item	3739770	et	0	main
korralik	doc_491521501744_item	3739771	et	0	main
korraliku	doc_491521501744_item	3739772	et	0	main
korralikum	doc_491521501744_item	3739773	et	0	main
mitte	doc_491521501744_item	3739774	et	0	main
korralikem	doc_491521501744_item	3739775	et	0	main
ligi	doc_491521501744_item	3739776	et	0	main
70	doc_491521501744_item	3739777	et	0	main
omadussõna	doc_491521501744_item	3739778	et	0	main
korral	doc_491521501744_item	3739779	et	0	main
mille	doc_491521501744_item	3739780	et	0	main
algvõrde	doc_491521501744_item	3739781	et	0	main
omastav	doc_491521501744_item	3739782	et	0	main
kääne	doc_491521501744_item	3739783	et	0	main
lõpeb	doc_491521501744_item	3739784	et	0	main
a	doc_491521501744_item	3739785	et	0	main
ga	doc_491521501744_item	3739786	et	0	main
või	doc_491521501744_item	3739787	et	0	main
u	doc_491521501744_item	3739788	et	0	main
ga	doc_491521501744_item	3739789	et	0	main
toimub	doc_491521501744_item	3739790	et	0	main
tunnuse	doc_491521501744_item	3739791	et	0	main
ees	doc_491521501744_item	3739792	et	0	main
vokaaliteisendus	doc_491521501744_item	3739793	et	0	main
a	doc_491521501744_item	3739794	et	0	main
u	doc_491521501744_item	3739795	et	0	main
muutub	doc_491521501744_item	3739796	et	0	main
e	doc_491521501744_item	3739797	et	0	main
ks	doc_491521501744_item	3739798	et	0	main
nt	doc_491521501744_item	3739799	et	0	main
pikk	doc_491521501744_item	3739800	et	0	main
pika	doc_491521501744_item	3739801	et	0	main
pikem	doc_491521501744_item	3739802	et	0	main
mitte	doc_491521501744_item	3739803	et	0	main
pikam	doc_491521501744_item	3739804	et	0	main
paks	doc_491521501744_item	3739805	et	0	main
paksu	doc_491521501744_item	3739806	et	0	main
paksem	doc_491521501744_item	3739807	et	0	main
mitte	doc_491521501744_item	3739808	et	0	main
paksum	doc_491521501744_item	3739809	et	0	main
kuri	doc_491521501744_item	3739810	et	0	main
kurja	doc_491521501744_item	3739811	et	0	main
kurjem	doc_491521501744_item	3739812	et	0	main
mitte	doc_491521501744_item	3739813	et	0	main
kurjam	doc_491521501744_item	3739814	et	0	main
i-ülivõrre	doc_491521501744_item	3739815	et	0	main
on	doc_491521501744_item	3739816	et	0	main
ebaselge	doc_491521501744_item	3739817	et	0	main
kui	doc_491521501744_item	3739818	et	0	main
tüvi	doc_491521501744_item	3739819	et	0	main
lõpeb	doc_491521501744_item	3739820	et	0	main
i	doc_491521501744_item	3739821	et	0	main
ga	doc_491521501744_item	3739822	et	0	main
toimub	doc_491521501744_item	3739823	et	0	main
ülivõrde	doc_491521501744_item	3739824	et	0	main
tunnuse	doc_491521501744_item	3739825	et	0	main
ees	doc_491521501744_item	3739826	et	0	main
vokaaliteisendus	doc_491521501744_item	3739827	et	0	main
i	doc_491521501744_item	3739828	et	0	main
muutub	doc_491521501744_item	3739829	et	0	main
e	doc_491521501744_item	3739830	et	0	main
ks	doc_491521501744_item	3739831	et	0	main
nt	doc_491521501744_item	3739832	et	0	main
kallis	doc_491521501744_item	3739833	et	0	main
kalliim	doc_491521501744_item	3739834	et	0	main
kalleim	doc_491521501744_item	3739835	et	0	main
mitte	doc_491521501744_item	3739836	et	0	main
kalliim	doc_491521501744_item	3739837	et	0	main
truu	doc_491521501744_item	3739838	et	0	main
truuim	doc_491521501744_item	3739839	et	0	main
truim	doc_491521501744_item	3739840	et	0	main
mitte	doc_491521501744_item	3739841	et	0	main
truuim	doc_491521501744_item	3739842	et	0	main
arvsõnad	doc_491521501744_item	3739843	et	0	main
käivad	doc_491521501744_item	3739844	et	0	main
väga	doc_491521501744_item	3739845	et	0	main
paljudele	doc_491521501744_item	3739846	et	0	main
õpilastele	doc_491521501744_item	3739847	et	0	main
üle	doc_491521501744_item	3739848	et	0	main
jõu	doc_491521501744_item	3739849	et	0	main
näiteks	doc_491521501744_item	3739850	et	0	main
kuupäevi	doc_491521501744_item	3739851	et	0	main
ja	doc_491521501744_item	3739852	et	0	main
aastaarve	doc_491521501744_item	3739853	et	0	main
vastamisel	doc_491521501744_item	3739854	et	0	main
ja	doc_491521501744_item	3739855	et	0	main
kirjutamisel	doc_491521501744_item	3739856	et	0	main
väidetakse	doc_491521501744_item	3739857	et	0	main
et	doc_491521501744_item	3739858	et	0	main
arvud	doc_491521501744_item	3739859	et	0	main
ei	doc_491521501744_item	3739860	et	0	main
jää	doc_491521501744_item	3739861	et	0	main
pähe	doc_491521501744_item	3739862	et	0	main
emakeeleski	doc_491521501744_item	3739863	et	0	main
sellepärast	doc_491521501744_item	3739864	et	0	main
on	doc_491521501744_item	3739865	et	0	main
neid	doc_491521501744_item	3739866	et	0	main
nii	doc_491521501744_item	3739867	et	0	main
raske	doc_491521501744_item	3739868	et	0	main
välja	doc_491521501744_item	3739869	et	0	main
öelda	doc_491521501744_item	3739870	et	0	main
võõrkeeles	doc_491521501744_item	3739871	et	0	main
sagedasti	doc_491521501744_item	3739872	et	0	main
aetakse	doc_491521501744_item	3739873	et	0	main
segi	doc_491521501744_item	3739874	et	0	main
kaks	doc_491521501744_item	3739875	et	0	main
ja	doc_491521501744_item	3739876	et	0	main
kaheksa	doc_491521501744_item	3739877	et	0	main
sisaldavad	doc_491521501744_item	3739878	et	0	main
arvsõnad	doc_491521501744_item	3739879	et	0	main
üksikjuhtudel	doc_491521501744_item	3739880	et	0	main
tekkivad	doc_491521501744_item	3739881	et	0	main
kahtlused	doc_491521501744_item	3739882	et	0	main
kas	doc_491521501744_item	3739883	et	0	main
tegemist	doc_491521501744_item	3739884	et	0	main
on	doc_491521501744_item	3739885	et	0	main
nimisõna	doc_491521501744_item	3739886	et	0	main
käändevormiga	doc_491521501744_item	3739887	et	0	main
või	doc_491521501744_item	3739888	et	0	main
määrsõnaga	doc_491521501744_item	3739889	et	0	main
nt	doc_491521501744_item	3739890	et	0	main
pärast	doc_491521501744_item	3739891	et	0	main
rikkaliku	doc_491521501744_item	3739892	et	0	main
söömaega	doc_491521501744_item	3739893	et	0	main
oli	doc_491521501744_item	3739894	et	0	main
ta	doc_491521501744_item	3739895	et	0	main
kõht	doc_491521501744_item	3739896	et	0	main
lõhkemiseni	doc_491521501744_item	3739897	et	0	main
määramäärsõna	doc_491521501744_item	3739898	et	0	main
pungil	doc_491521501744_item	3739899	et	0	main
kuni	doc_491521501744_item	3739900	et	0	main
torude	doc_491521501744_item	3739901	et	0	main
lõhkemiseni	doc_491521501744_item	3739902	et	0	main
nimisõna	doc_491521501744_item	3739903	et	0	main
rajava	doc_491521501744_item	3739904	et	0	main
käände	doc_491521501744_item	3739905	et	0	main
vorm	doc_491521501744_item	3739906	et	0	main
oli	doc_491521501744_item	3739907	et	0	main
ta	doc_491521501744_item	3739908	et	0	main
elanud	doc_491521501744_item	3739909	et	0	main
oma	doc_491521501744_item	3739910	et	0	main
köögipugerikus	doc_491521501744_item	3739911	et	0	main
nimisõna	doc_491521501744_item	3739912	et	0	main
seesütleva	doc_491521501744_item	3739913	et	0	main
käändega	doc_491521501744_item	3739914	et	0	main
sarnanevad	doc_491521501744_item	3739915	et	0	main
määrsõnavormid	doc_491521501744_item	3739916	et	0	main
erinevad	doc_491521501744_item	3739917	et	0	main
paradigmaatiliselt	doc_491521501744_item	3739918	et	0	main
käändevormist	doc_491521501744_item	3739919	et	0	main
sageli	doc_491521501744_item	3739920	et	0	main
ka	doc_491521501744_item	3739921	et	0	main
tüve	doc_491521501744_item	3739922	et	0	main
tugeva	doc_491521501744_item	3739923	et	0	main
astme	doc_491521501744_item	3739924	et	0	main
poolest	doc_491521501744_item	3739925	et	0	main
nt	doc_491521501744_item	3739926	et	0	main
poisil	doc_491521501744_item	3739927	et	0	main
olid	doc_491521501744_item	3739928	et	0	main
kõrvad	doc_491521501744_item	3739929	et	0	main
lukkus	doc_491521501744_item	3739930	et	0	main
mitte	doc_491521501744_item	3739931	et	0	main
lukus	doc_491521501744_item	3739932	et	0	main
selles	doc_491521501744_item	3739933	et	0	main
tohutus	doc_491521501744_item	3739934	et	0	main
ja	doc_491521501744_item	3739935	et	0	main
keerulises	doc_491521501744_item	3739936	et	0	main
lukus	doc_491521501744_item	3739937	et	0	main
mitte	doc_491521501744_item	3739938	et	0	main
lukkus	doc_491521501744_item	3739939	et	0	main
oli	doc_491521501744_item	3739940	et	0	main
midagi	doc_491521501744_item	3739941	et	0	main
pahaendelist	doc_491521501744_item	3739942	et	0	main
asesõnade	doc_491521501744_item	3739943	et	0	main
kasutamisel	doc_491521501744_item	3739944	et	0	main
tekkivad	doc_491521501744_item	3739945	et	0	main
ka	doc_491521501744_item	3739946	et	0	main
mõned	doc_491521501744_item	3739947	et	0	main
vead	doc_491521501744_item	3739948	et	0	main
pronoomeni	doc_491521501744_item	3739949	et	0	main
oma	doc_491521501744_item	3739950	et	0	main
põhifunktsioon	doc_491521501744_item	3739951	et	0	main
on	doc_491521501744_item	3739952	et	0	main
omastav	doc_491521501744_item	3739953	et	0	main
ja	doc_491521501744_item	3739954	et	0	main
enesekohases	doc_491521501744_item	3739955	et	0	main
tähenduses	doc_491521501744_item	3739956	et	0	main
esineb	doc_491521501744_item	3739957	et	0	main
ta	doc_491521501744_item	3739958	et	0	main
harva	doc_491521501744_item	3739959	et	0	main
pronoomeni	doc_491521501744_item	3739960	et	0	main
enese-enda	doc_491521501744_item	3739961	et	0	main
asendamine	doc_491521501744_item	3739962	et	0	main
pronoomeniga	doc_491521501744_item	3739963	et	0	main
oma	doc_491521501744_item	3739964	et	0	main
on	doc_491521501744_item	3739965	et	0	main
võimalik	doc_491521501744_item	3739966	et	0	main
peamiselt	doc_491521501744_item	3739967	et	0	main
omastavas	doc_491521501744_item	3739968	et	0	main
käändes	doc_491521501744_item	3739969	et	0	main
või	doc_491521501744_item	3739970	et	0	main
väliskohakäänetes	doc_491521501744_item	3739971	et	0	main
kui	doc_491521501744_item	3739972	et	0	main
enesekohasustähendusele	doc_491521501744_item	3739973	et	0	main
lisandub	doc_491521501744_item	3739974	et	0	main
omamistähendus	doc_491521501744_item	3739975	et	0	main
nt	doc_491521501744_item	3739976	et	0	main
vanemad	doc_491521501744_item	3739977	et	0	main
said	doc_491521501744_item	3739978	et	0	main
omale	doc_491521501744_item	3739979	et	0	main
mitte	doc_491521501744_item	3739980	et	0	main
endale	doc_491521501744_item	3739981	et	0	main
hea	doc_491521501744_item	3739982	et	0	main
palka	doc_491521501744_item	3739983	et	0	main
artur	doc_491521501744_item	3739984	et	0	main
laskis	doc_491521501744_item	3739985	et	0	main
omal	doc_491521501744_item	3739986	et	0	main
mitte	doc_491521501744_item	3739987	et	0	main
enesel	doc_491521501744_item	3739988	et	0	main
pea	doc_491521501744_item	3739989	et	0	main
paljaks	doc_491521501744_item	3739990	et	0	main
ajada	doc_491521501744_item	3739991	et	0	main
lõunaeestilist	doc_491521501744_item	3739992	et	0	main
päritolu	doc_491521501744_item	3739993	et	0	main
asesõna	doc_491521501744_item	3739994	et	0	main
too	doc_491521501744_item	3739995	et	0	main
ei	doc_491521501744_item	3739996	et	0	main
ole	doc_491521501744_item	3739997	et	0	main
eesti	doc_491521501744_item	3739998	et	0	main
ühiskeeles	doc_491521501744_item	3739999	et	0	main
veel	doc_491521501744_item	3740000	et	0	main
päris	doc_491521501744_item	3740001	et	0	main
kadunud	doc_491521501744_item	3740002	et	0	main
õpilased	doc_491521501744_item	3740003	et	0	main
ei	doc_491521501744_item	3740004	et	0	main
oska	doc_491521501744_item	3740005	et	0	main
seda	doc_491521501744_item	3740006	et	0	main
kasutada	doc_491521501744_item	3740007	et	0	main
õiges	doc_491521501744_item	3740008	et	0	main
ajas	doc_491521501744_item	3740009	et	0	main
nt	doc_491521501744_item	3740010	et	0	main
too	doc_491521501744_item	3740011	et	0	main
seal	doc_491521501744_item	3740012	et	0	main
on	doc_491521501744_item	3740013	et	0	main
minu	doc_491521501744_item	3740014	et	0	main
auto	doc_491521501744_item	3740015	et	0	main
mitte	doc_491521501744_item	3740016	et	0	main
too	doc_491521501744_item	3740017	et	0	main
siin	doc_491521501744_item	3740018	et	0	main
on	doc_491521501744_item	3740019	et	0	main
minu	doc_491521501744_item	3740020	et	0	main
auto	doc_491521501744_item	3740021	et	0	main
tol	doc_491521501744_item	3740022	et	0	main
aastal	doc_491521501744_item	3740023	et	0	main
oli	doc_491521501744_item	3740024	et	0	main
kevad	doc_491521501744_item	3740025	et	0	main
maria	doc_491521501744_item	3740026	et	0	main
väga	doc_491521501744_item	3740027	et	0	main
paks	doc_491521501744_item	3740028	et	0	main
mitte	doc_491521501744_item	3740029	et	0	main
tol	doc_491521501744_item	3740030	et	0	main
aastal	doc_491521501744_item	3740031	et	0	main
on	doc_491521501744_item	3740032	et	0	main
maria	doc_491521501744_item	3740033	et	0	main
väga	doc_491521501744_item	3740034	et	0	main
paks	doc_491521501744_item	3740035	et	0	main
kuivõrd	doc_491521501744_item	3740036	et	0	main
kaassõnad	doc_491521501744_item	3740037	et	0	main
on	doc_491521501744_item	3740038	et	0	main
mittetäistähenduslikud	doc_491521501744_item	3740039	et	0	main
ilmneb	doc_491521501744_item	3740040	et	0	main
nende	doc_491521501744_item	3740041	et	0	main
tähendus	doc_491521501744_item	3740042	et	0	main
sageli	doc_491521501744_item	3740043	et	0	main
ainult	doc_491521501744_item	3740044	et	0	main
seoses	doc_491521501744_item	3740045	et	0	main
konkreetse	doc_491521501744_item	3740046	et	0	main
nimisõnaga	doc_491521501744_item	3740047	et	0	main
konkreetses	doc_491521501744_item	3740048	et	0	main
kontekstis	doc_491521501744_item	3740049	et	0	main
sealjuures	doc_491521501744_item	3740050	et	0	main
tekkivad	doc_491521501744_item	3740051	et	0	main
arusaamatused	doc_491521501744_item	3740052	et	0	main
et	doc_491521501744_item	3740053	et	0	main
üks	doc_491521501744_item	3740054	et	0	main
ja	doc_491521501744_item	3740055	et	0	main
seesama	doc_491521501744_item	3740056	et	0	main
kaassõna	doc_491521501744_item	3740057	et	0	main
võib	doc_491521501744_item	3740058	et	0	main
eri	doc_491521501744_item	3740059	et	0	main
kontekstides	doc_491521501744_item	3740060	et	0	main
üsna	doc_491521501744_item	3740061	et	0	main
erinevaid	doc_491521501744_item	3740062	et	0	main
tähendusi	doc_491521501744_item	3740063	et	0	main
kanda	doc_491521501744_item	3740064	et	0	main
nt	doc_491521501744_item	3740065	et	0	main
pärast	doc_491521501744_item	3740066	et	0	main
tööd	doc_491521501744_item	3740067	et	0	main
läksid	doc_491521501744_item	3740068	et	0	main
nad	doc_491521501744_item	3740069	et	0	main
etendusele	doc_491521501744_item	3740070	et	0	main
tunni	doc_491521501744_item	3740071	et	0	main
aja	doc_491521501744_item	3740072	et	0	main
pärast	doc_491521501744_item	3740073	et	0	main
on	doc_491521501744_item	3740074	et	0	main
direktori	doc_491521501744_item	3740075	et	0	main
vastuvõtt	doc_491521501744_item	3740076	et	0	main
ärge	doc_491521501744_item	3740077	et	0	main
selle	doc_491521501744_item	3740078	et	0	main
pärast	doc_491521501744_item	3740079	et	0	main
muretsege	doc_491521501744_item	3740080	et	0	main
sidesõna	doc_491521501744_item	3740081	et	0	main
vahetatakse	doc_491521501744_item	3740082	et	0	main
ära	doc_491521501744_item	3740083	et	0	main
küsisõnaga	doc_491521501744_item	3740084	et	0	main
nt	doc_491521501744_item	3740085	et	0	main
jõudsin	doc_491521501744_item	3740086	et	0	main
koju	doc_491521501744_item	3740087	et	0	main
kui	doc_491521501744_item	3740088	et	0	main
mitte	doc_491521501744_item	3740089	et	0	main
millal	doc_491521501744_item	3740090	et	0	main
vanemad	doc_491521501744_item	3740091	et	0	main
olid	doc_491521501744_item	3740092	et	0	main
kodus	doc_491521501744_item	3740093	et	0	main
noortesaadetes	doc_491521501744_item	3740094	et	0	main
on	doc_491521501744_item	3740095	et	0	main
huvitavaid	doc_491521501744_item	3740096	et	0	main
asju	doc_491521501744_item	3740097	et	0	main
kui	doc_491521501744_item	3740098	et	0	main
mitte	doc_491521501744_item	3740099	et	0	main
millal	doc_491521501744_item	3740100	et	0	main
noored	doc_491521501744_item	3740101	et	0	main
räägivad	doc_491521501744_item	3740102	et	0	main
oma	doc_491521501744_item	3740103	et	0	main
probleemidest	doc_491521501744_item	3740104	et	0	main
lühike	doc_491521501744_item	3740105	et	0	main
sisseütlev	doc_491521501744_item	3740106	et	0	main
jääb	doc_491521501744_item	3740107	et	0	main
halvasti	doc_491521501744_item	3740108	et	0	main
meelde	doc_491521501744_item	3740109	et	0	main
õpilastele	doc_491521501744_item	3740110	et	0	main
on	doc_491521501744_item	3740111	et	0	main
kergem	doc_491521501744_item	3740112	et	0	main
öelda	doc_491521501744_item	3740113	et	0	main
nt	doc_491521501744_item	3740114	et	0	main
toasse	doc_491521501744_item	3740115	et	0	main
õige	doc_491521501744_item	3740116	et	0	main
tuppa	doc_491521501744_item	3740117	et	0	main
metsasse	doc_491521501744_item	3740118	et	0	main
õige	doc_491521501744_item	3740119	et	0	main
metsa	doc_491521501744_item	3740120	et	0	main
köögisse	doc_491521501744_item	3740121	et	0	main
õige	doc_491521501744_item	3740122	et	0	main
kööki	doc_491521501744_item	3740123	et	0	main
suusse	doc_491521501744_item	3740124	et	0	main
õige	doc_491521501744_item	3740125	et	0	main
suhu	doc_491521501744_item	3740126	et	0	main
pesasse	doc_491521501744_item	3740127	et	0	main
õige	doc_491521501744_item	3740128	et	0	main
pessa	doc_491521501744_item	3740129	et	0	main
aetakse	doc_491521501744_item	3740130	et	0	main
segi	doc_491521501744_item	3740131	et	0	main
omastav	doc_491521501744_item	3740132	et	0	main
ja	doc_491521501744_item	3740133	et	0	main
osastav	doc_491521501744_item	3740134	et	0	main
kääne	doc_491521501744_item	3740135	et	0	main
lõpetatud	doc_491521501744_item	3740136	et	0	main
ja	doc_491521501744_item	3740137	et	0	main
lõpetamata	doc_491521501744_item	3740138	et	0	main
tegevus	doc_491521501744_item	3740139	et	0	main
nt	doc_491521501744_item	3740140	et	0	main
kõik	doc_491521501744_item	3740141	et	0	main
kuulsid	doc_491521501744_item	3740142	et	0	main
raadiot	doc_491521501744_item	3740143	et	0	main
mitte	doc_491521501744_item	3740144	et	0	main
kõik	doc_491521501744_item	3740145	et	0	main
kuulsid	doc_491521501744_item	3740146	et	0	main
raadio	doc_491521501744_item	3740147	et	0	main
mart	doc_491521501744_item	3740148	et	0	main
luges	doc_491521501744_item	3740149	et	0	main
raamatut	doc_491521501744_item	3740150	et	0	main
mitte	doc_491521501744_item	3740151	et	0	main
mart	doc_491521501744_item	3740152	et	0	main
luges	doc_491521501744_item	3740153	et	0	main
raamatu	doc_491521501744_item	3740154	et	0	main
kui	doc_491521501744_item	3740155	et	0	main
on	doc_491521501744_item	3740156	et	0	main
osasihitis	doc_491521501744_item	3740157	et	0	main
õpetaja	doc_491521501744_item	3740158	et	0	main
luges	doc_491521501744_item	3740159	et	0	main
raamatu	doc_491521501744_item	3740160	et	0	main
mitte	doc_491521501744_item	3740161	et	0	main
õpetaja	doc_491521501744_item	3740162	et	0	main
luges	doc_491521501744_item	3740163	et	0	main
raamatut	doc_491521501744_item	3740164	et	0	main
kui	doc_491521501744_item	3740165	et	0	main
lõpetatud	doc_491521501744_item	3740166	et	0	main
tegevus	doc_491521501744_item	3740167	et	0	main
mulle	doc_491521501744_item	3740168	et	0	main
meeldib	doc_491521501744_item	3740169	et	0	main
kuulata	doc_491521501744_item	3740170	et	0	main
head	doc_491521501744_item	3740171	et	0	main
muusikat	doc_491521501744_item	3740172	et	0	main
mitte	doc_491521501744_item	3740173	et	0	main
mulle	doc_491521501744_item	3740174	et	0	main
meeldib	doc_491521501744_item	3740175	et	0	main
kuulata	doc_491521501744_item	3740176	et	0	main
hea	doc_491521501744_item	3740177	et	0	main
muusika	doc_491521501744_item	3740178	et	0	main
ainsuse	doc_491521501744_item	3740179	et	0	main
osastava	doc_491521501744_item	3740180	et	0	main
moodustamine	doc_491521501744_item	3740181	et	0	main
on	doc_491521501744_item	3740182	et	0	main
raske	doc_491521501744_item	3740183	et	0	main
sest	doc_491521501744_item	3740184	et	0	main
osastava	doc_491521501744_item	3740185	et	0	main
käände	doc_491521501744_item	3740186	et	0	main
tunnused	doc_491521501744_item	3740187	et	0	main
on	doc_491521501744_item	3740188	et	0	main
neli	doc_491521501744_item	3740189	et	0	main
morfeemvarianti	doc_491521501744_item	3740190	et	0	main
t	doc_491521501744_item	3740191	et	0	main
d	doc_491521501744_item	3740192	et	0	main
ja	doc_491521501744_item	3740193	et	0	main
da	doc_491521501744_item	3740194	et	0	main
kusjuures	doc_491521501744_item	3740195	et	0	main
valik	doc_491521501744_item	3740196	et	0	main
sõltub	doc_491521501744_item	3740197	et	0	main
sõnatüübist	doc_491521501744_item	3740198	et	0	main
nt	doc_491521501744_item	3740199	et	0	main
kollane	doc_491521501744_item	3740200	et	0	main
kollase	doc_491521501744_item	3740201	et	0	main
kollast	doc_491521501744_item	3740202	et	0	main
mitte	doc_491521501744_item	3740203	et	0	main
kollaset	doc_491521501744_item	3740204	et	0	main
suur	doc_491521501744_item	3740205	et	0	main
suure	doc_491521501744_item	3740206	et	0	main
suurt	doc_491521501744_item	3740207	et	0	main
mitte	doc_491521501744_item	3740208	et	0	main
suuret	doc_491521501744_item	3740209	et	0	main
küünal	doc_491521501744_item	3740210	et	0	main
küünla	doc_491521501744_item	3740211	et	0	main
küünalt	doc_491521501744_item	3740212	et	0	main
mitte	doc_491521501744_item	3740213	et	0	main
küünlat	doc_491521501744_item	3740214	et	0	main
ema	doc_491521501744_item	3740215	et	0	main
ema	doc_491521501744_item	3740216	et	0	main
ema	doc_491521501744_item	3740217	et	0	main
mitte	doc_491521501744_item	3740218	et	0	main
emat	doc_491521501744_item	3740219	et	0	main
kaks	doc_491521501744_item	3740220	et	0	main
kahe	doc_491521501744_item	3740221	et	0	main
kaht	doc_491521501744_item	3740222	et	0	main
mitte	doc_491521501744_item	3740223	et	0	main
kahet	doc_491521501744_item	3740224	et	0	main
mitmuse	doc_491521501744_item	3740225	et	0	main
osastava	doc_491521501744_item	3740226	et	0	main
moodustamine	doc_491521501744_item	3740227	et	0	main
on	doc_491521501744_item	3740228	et	0	main
eriti	doc_491521501744_item	3740229	et	0	main
raske	doc_491521501744_item	3740230	et	0	main
kus	doc_491521501744_item	3740231	et	0	main
õpilased	doc_491521501744_item	3740232	et	0	main
teevad	doc_491521501744_item	3740233	et	0	main
palju	doc_491521501744_item	3740234	et	0	main
vigu	doc_491521501744_item	3740235	et	0	main
nendel	doc_491521501744_item	3740236	et	0	main
on	doc_491521501744_item	3740237	et	0	main
raske	doc_491521501744_item	3740238	et	0	main
vahet	doc_491521501744_item	3740239	et	0	main
teha	doc_491521501744_item	3740240	et	0	main
i	doc_491521501744_item	3740241	et	0	main
ja	doc_491521501744_item	3740242	et	0	main
sid	doc_491521501744_item	3740243	et	0	main
lõpude	doc_491521501744_item	3740244	et	0	main
vahel	doc_491521501744_item	3740245	et	0	main
nt	doc_491521501744_item	3740246	et	0	main
mõtteid	doc_491521501744_item	3740247	et	0	main
mitte	doc_491521501744_item	3740248	et	0	main
mõttesid	doc_491521501744_item	3740249	et	0	main
siile	doc_491521501744_item	3740250	et	0	main
mitte	doc_491521501744_item	3740251	et	0	main
siileid	doc_491521501744_item	3740252	et	0	main
sõprusid	doc_491521501744_item	3740253	et	0	main
mitte	doc_491521501744_item	3740254	et	0	main
sõpraid	doc_491521501744_item	3740255	et	0	main
koerasid	doc_491521501744_item	3740256	et	0	main
mitte	doc_491521501744_item	3740257	et	0	main
koeraid	doc_491521501744_item	3740258	et	0	main
lihtminevikku	doc_491521501744_item	3740259	et	0	main
on	doc_491521501744_item	3740260	et	0	main
raskem	doc_491521501744_item	3740261	et	0	main
moodustada	doc_491521501744_item	3740262	et	0	main
kui	doc_491521501744_item	3740263	et	0	main
täisminevikku	doc_491521501744_item	3740264	et	0	main
nt	doc_491521501744_item	3740265	et	0	main
loodan	doc_491521501744_item	3740266	et	0	main
et	doc_491521501744_item	3740267	et	0	main
pühapäeva	doc_491521501744_item	3740268	et	0	main
õhtuks	doc_491521501744_item	3740269	et	0	main
oled	doc_491521501744_item	3740270	et	0	main
sa	doc_491521501744_item	3740271	et	0	main
selle	doc_491521501744_item	3740272	et	0	main
töö	doc_491521501744_item	3740273	et	0	main
lõpetanud	doc_491521501744_item	3740274	et	0	main
mitte	doc_491521501744_item	3740275	et	0	main
loodan	doc_491521501744_item	3740276	et	0	main
et	doc_491521501744_item	3740277	et	0	main
pühapäeva	doc_491521501744_item	3740278	et	0	main
õhtuks	doc_491521501744_item	3740279	et	0	main
sa	doc_491521501744_item	3740280	et	0	main
selle	doc_491521501744_item	3740281	et	0	main
töö	doc_491521501744_item	3740282	et	0	main
lõpetanud	doc_491521501744_item	3740283	et	0	main
mari	doc_491521501744_item	3740284	et	0	main
oli	doc_491521501744_item	3740285	et	0	main
kõvasti	doc_491521501744_item	3740286	et	0	main
tööd	doc_491521501744_item	3740287	et	0	main
teinud	doc_491521501744_item	3740288	et	0	main
mitte	doc_491521501744_item	3740289	et	0	main
mari	doc_491521501744_item	3740290	et	0	main
kõvasti	doc_491521501744_item	3740291	et	0	main
tööd	doc_491521501744_item	3740292	et	0	main
teinud	doc_491521501744_item	3740293	et	0	main
mul	doc_491521501744_item	3740294	et	0	main
ei	doc_491521501744_item	3740295	et	0	main
olnud	doc_491521501744_item	3740296	et	0	main
vaba	doc_491521501744_item	3740297	et	0	main
aega	doc_491521501744_item	3740298	et	0	main
mitte	doc_491521501744_item	3740299	et	0	main
mul	doc_491521501744_item	3740300	et	0	main
ei	doc_491521501744_item	3740301	et	0	main
oli	doc_491521501744_item	3740302	et	0	main
vaba	doc_491521501744_item	3740303	et	0	main
aega	doc_491521501744_item	3740304	et	0	main
tingiv	doc_491521501744_item	3740305	et	0	main
kõneviis	doc_491521501744_item	3740306	et	0	main
on	doc_491521501744_item	3740307	et	0	main
õpilastele	doc_491521501744_item	3740308	et	0	main
tavaliselt	doc_491521501744_item	3740309	et	0	main
selge	doc_491521501744_item	3740310	et	0	main
kui	doc_491521501744_item	3740311	et	0	main
moodustamise	doc_491521501744_item	3740312	et	0	main
teeb	doc_491521501744_item	3740313	et	0	main
raskeks	doc_491521501744_item	3740314	et	0	main
laadivaheldus	doc_491521501744_item	3740315	et	0	main
nt	doc_491521501744_item	3740316	et	0	main
teeksime	doc_491521501744_item	3740317	et	0	main
mitte	doc_491521501744_item	3740318	et	0	main
tegiksime	doc_491521501744_item	3740319	et	0	main
peseksin	doc_491521501744_item	3740320	et	0	main
mitte	doc_491521501744_item	3740321	et	0	main
pestaksin	doc_491521501744_item	3740322	et	0	main
puhkaksime	doc_491521501744_item	3740323	et	0	main
mitte	doc_491521501744_item	3740324	et	0	main
puhaksime	doc_491521501744_item	3740325	et	0	main
õmbleksin	doc_491521501744_item	3740326	et	0	main
mitte	doc_491521501744_item	3740327	et	0	main
õmmeldaksin	doc_491521501744_item	3740328	et	0	main
umbisikuline	doc_491521501744_item	3740329	et	0	main
tegumood	doc_491521501744_item	3740330	et	0	main
on	doc_491521501744_item	3740331	et	0	main
raske	doc_491521501744_item	3740332	et	0	main
eriti	doc_491521501744_item	3740333	et	0	main
täisminevikus	doc_491521501744_item	3740334	et	0	main
nt	doc_491521501744_item	3740335	et	0	main
pildil	doc_491521501744_item	3740336	et	0	main
on	doc_491521501744_item	3740337	et	0	main
kujutatud	doc_491521501744_item	3740338	et	0	main
mitte	doc_491521501744_item	3740339	et	0	main
pildil	doc_491521501744_item	3740340	et	0	main
on	doc_491521501744_item	3740341	et	0	main
kujutanud	doc_491521501744_item	3740342	et	0	main
õunad	doc_491521501744_item	3740343	et	0	main
ja	doc_491521501744_item	3740344	et	0	main
pirnid	doc_491521501744_item	3740345	et	0	main
kui	doc_491521501744_item	3740346	et	0	main
töö	doc_491521501744_item	3740347	et	0	main
on	doc_491521501744_item	3740348	et	0	main
tehtud	doc_491521501744_item	3740349	et	0	main
mitte	doc_491521501744_item	3740350	et	0	main
kui	doc_491521501744_item	3740351	et	0	main
on	doc_491521501744_item	3740352	et	0	main
tehnud	doc_491521501744_item	3740353	et	0	main
võib	doc_491521501744_item	3740354	et	0	main
minna	doc_491521501744_item	3740355	et	0	main
koju	doc_491521501744_item	3740356	et	0	main
umbisikulise	doc_491521501744_item	3740357	et	0	main
tegumoe	doc_491521501744_item	3740358	et	0	main
olevikus	doc_491521501744_item	3740359	et	0	main
tekitab	doc_491521501744_item	3740360	et	0	main
segadust	doc_491521501744_item	3740361	et	0	main
silpide	doc_491521501744_item	3740362	et	0	main
kordus	doc_491521501744_item	3740363	et	0	main
nt	doc_491521501744_item	3740364	et	0	main
veetakse	doc_491521501744_item	3740365	et	0	main
mitte	doc_491521501744_item	3740366	et	0	main
vedakse	doc_491521501744_item	3740367	et	0	main
ostetakse	doc_491521501744_item	3740368	et	0	main
mitte	doc_491521501744_item	3740369	et	0	main
ostakse	doc_491521501744_item	3740370	et	0	main
tahetakse	doc_491521501744_item	3740371	et	0	main
mitte	doc_491521501744_item	3740372	et	0	main
tahakse	doc_491521501744_item	3740373	et	0	main
murtakse	doc_491521501744_item	3740374	et	0	main
mitte	doc_491521501744_item	3740375	et	0	main
murdatakse	doc_491521501744_item	3740376	et	0	main
eriti	doc_491521501744_item	3740377	et	0	main
ebaselge	doc_491521501744_item	3740378	et	0	main
on	doc_491521501744_item	3740379	et	0	main
1	doc_491521501744_item	3740380	et	0	main
pöördkonna	doc_491521501744_item	3740381	et	0	main
jooma-tüübis	doc_491521501744_item	3740382	et	0	main
toimuv	doc_491521501744_item	3740383	et	0	main
formatiivi	doc_491521501744_item	3740384	et	0	main
akse	doc_491521501744_item	3740385	et	0	main
ees	doc_491521501744_item	3740386	et	0	main
vokaaliteisendus	doc_491521501744_item	3740387	et	0	main
oo-uu	doc_491521501744_item	3740388	et	0	main
voi	doc_491521501744_item	3740389	et	0	main
öö-üü	doc_491521501744_item	3740390	et	0	main
nt	doc_491521501744_item	3740391	et	0	main
jooma	doc_491521501744_item	3740392	et	0	main
juuakse	doc_491521501744_item	3740393	et	0	main
mitte	doc_491521501744_item	3740394	et	0	main
joodakse	doc_491521501744_item	3740395	et	0	main
sööma	doc_491521501744_item	3740396	et	0	main
süüakse	doc_491521501744_item	3740397	et	0	main
mitte	doc_491521501744_item	3740398	et	0	main
söödakse	doc_491521501744_item	3740399	et	0	main
lööma	doc_491521501744_item	3740400	et	0	main
lüüakse	doc_491521501744_item	3740401	et	0	main
mitte	doc_491521501744_item	3740402	et	0	main
löödakse	doc_491521501744_item	3740403	et	0	main
tooma	doc_491521501744_item	3740404	et	0	main
tuuakse	doc_491521501744_item	3740405	et	0	main
mitte	doc_491521501744_item	3740406	et	0	main
toodakse	doc_491521501744_item	3740407	et	0	main
ma-ja	doc_491521501744_item	3740408	et	0	main
da-	doc_491521501744_item	3740409	et	0	main
tegevusnime	doc_491521501744_item	3740410	et	0	main
kasutamine	doc_491521501744_item	3740411	et	0	main
on	doc_491521501744_item	3740412	et	0	main
üks	doc_491521501744_item	3740413	et	0	main
raskematest	doc_491521501744_item	3740414	et	0	main
ülesannetest	doc_491521501744_item	3740415	et	0	main
nt	doc_491521501744_item	3740416	et	0	main
oskab	doc_491521501744_item	3740417	et	0	main
arvestada	doc_491521501744_item	3740418	et	0	main
mitte	doc_491521501744_item	3740419	et	0	main
arvestama	doc_491521501744_item	3740420	et	0	main
meeldib	doc_491521501744_item	3740421	et	0	main
kuulata	doc_491521501744_item	3740422	et	0	main
mitte	doc_491521501744_item	3740423	et	0	main
kuulama	doc_491521501744_item	3740424	et	0	main
on	doc_491521501744_item	3740425	et	0	main
vaja	doc_491521501744_item	3740426	et	0	main
teha	doc_491521501744_item	3740427	et	0	main
mitte	doc_491521501744_item	3740428	et	0	main
tegema	doc_491521501744_item	3740429	et	0	main
tuleb	doc_491521501744_item	3740430	et	0	main
tarvitseda	doc_491521501744_item	3740431	et	0	main
mitte	doc_491521501744_item	3740432	et	0	main
tarvitsema	doc_491521501744_item	3740433	et	0	main
olen	doc_491521501744_item	3740434	et	0	main
nõus	doc_491521501744_item	3740435	et	0	main
tantsima	doc_491521501744_item	3740436	et	0	main
mitte	doc_491521501744_item	3740437	et	0	main
tantsida	doc_491521501744_item	3740438	et	0	main
valmis	doc_491521501744_item	3740439	et	0	main
minema	doc_491521501744_item	3740440	et	0	main
mitte	doc_491521501744_item	3740441	et	0	main
minna	doc_491521501744_item	3740442	et	0	main
võib	doc_491521501744_item	3740443	et	0	main
kirjutada	doc_491521501744_item	3740444	et	0	main
mitte	doc_491521501744_item	3740445	et	0	main
kirjutama	doc_491521501744_item	3740446	et	0	main
alustan	doc_491521501744_item	3740447	et	0	main
puhkama	doc_491521501744_item	3740448	et	0	main
mitte	doc_491521501744_item	3740449	et	0	main
puhata	doc_491521501744_item	3740450	et	0	main
pani	doc_491521501744_item	3740451	et	0	main
meid	doc_491521501744_item	3740452	et	0	main
kirja	doc_491521501744_item	3740453	et	0	main
kirjutama	doc_491521501744_item	3740454	et	0	main
mitte	doc_491521501744_item	3740455	et	0	main
kirjutada	doc_491521501744_item	3740456	et	0	main
ta	doc_491521501744_item	3740457	et	0	main
hakkas	doc_491521501744_item	3740458	et	0	main
laulma	doc_491521501744_item	3740459	et	0	main
mitte	doc_491521501744_item	3740460	et	0	main
laulda	doc_491521501744_item	3740461	et	0	main
läksime	doc_491521501744_item	3740462	et	0	main
sööma	doc_491521501744_item	3740463	et	0	main
mitte	doc_491521501744_item	3740464	et	0	main
süüa	doc_491521501744_item	3740465	et	0	main
armastan	doc_491521501744_item	3740466	et	0	main
töötada	doc_491521501744_item	3740467	et	0	main
mitte	doc_491521501744_item	3740468	et	0	main
töötama	doc_491521501744_item	3740469	et	0	main
rektsioone	doc_491521501744_item	3740470	et	0	main
milles	doc_491521501744_item	3740471	et	0	main
sageli	doc_491521501744_item	3740472	et	0	main
eksitakse	doc_491521501744_item	3740473	et	0	main
ühildumine	doc_491521501744_item	3740474	et	0	main
ei	doc_491521501744_item	3740475	et	0	main
vasta	doc_491521501744_item	3740476	et	0	main
eesti	doc_491521501744_item	3740477	et	0	main
keele	doc_491521501744_item	3740478	et	0	main
reeglitele	doc_491521501744_item	3740479	et	0	main
nt	doc_491521501744_item	3740480	et	0	main
huvi	doc_491521501744_item	3740481	et	0	main
tundma	doc_491521501744_item	3740482	et	0	main
mille	doc_491521501744_item	3740483	et	0	main
vastu	doc_491521501744_item	3740484	et	0	main
mitte	doc_491521501744_item	3740485	et	0	main
mille	doc_491521501744_item	3740486	et	0	main
pärast	doc_491521501744_item	3740487	et	0	main
kaasnema	doc_491521501744_item	3740488	et	0	main
millega	doc_491521501744_item	3740489	et	0	main
mitte	doc_491521501744_item	3740490	et	0	main
millele	doc_491521501744_item	3740491	et	0	main
käima	doc_491521501744_item	3740492	et	0	main
kus	doc_491521501744_item	3740493	et	0	main
mitte	doc_491521501744_item	3740494	et	0	main
kuhu	doc_491521501744_item	3740495	et	0	main
ostma	doc_491521501744_item	3740496	et	0	main
kust	doc_491521501744_item	3740497	et	0	main
mitte	doc_491521501744_item	3740498	et	0	main
kus	doc_491521501744_item	3740499	et	0	main
kuulatama	doc_491521501744_item	3740500	et	0	main
kellele	doc_491521501744_item	3740501	et	0	main
millele	doc_491521501744_item	3740502	et	0	main
mitte	doc_491521501744_item	3740503	et	0	main
keda	doc_491521501744_item	3740504	et	0	main
mida	doc_491521501744_item	3740505	et	0	main
jätma	doc_491521501744_item	3740506	et	0	main
kuhu	doc_491521501744_item	3740507	et	0	main
mitte	doc_491521501744_item	3740508	et	0	main
kus	doc_491521501744_item	3740509	et	0	main
aitama	doc_491521501744_item	3740510	et	0	main
keda	doc_491521501744_item	3740511	et	0	main
mida	doc_491521501744_item	3740512	et	0	main
mitte	doc_491521501744_item	3740513	et	0	main
kellele	doc_491521501744_item	3740514	et	0	main
millele	doc_491521501744_item	3740515	et	0	main
häirima	doc_491521501744_item	3740516	et	0	main
keda	doc_491521501744_item	3740517	et	0	main
mida	doc_491521501744_item	3740518	et	0	main
mitte	doc_491521501744_item	3740519	et	0	main
kellele	doc_491521501744_item	3740520	et	0	main
millele	doc_491521501744_item	3740521	et	0	main
kahetsema	doc_491521501744_item	3740522	et	0	main
keda	doc_491521501744_item	3740523	et	0	main
mida	doc_491521501744_item	3740524	et	0	main
mitte	doc_491521501744_item	3740525	et	0	main
kelles	doc_491521501744_item	3740526	et	0	main
milles	doc_491521501744_item	3740527	et	0	main
põhinema	doc_491521501744_item	3740528	et	0	main
millel	doc_491521501744_item	3740529	et	0	main
mitte	doc_491521501744_item	3740530	et	0	main
millele	doc_491521501744_item	3740531	et	0	main
sarnanema	doc_491521501744_item	3740532	et	0	main
millega	doc_491521501744_item	3740533	et	0	main
mitte	doc_491521501744_item	3740534	et	0	main
millele	doc_491521501744_item	3740535	et	0	main
muganema	doc_491521501744_item	3740536	et	0	main
millega	doc_491521501744_item	3740537	et	0	main
mitte	doc_491521501744_item	3740538	et	0	main
millele	doc_491521501744_item	3740539	et	0	main
kohanema	doc_491521501744_item	3740540	et	0	main
millega	doc_491521501744_item	3740541	et	0	main
mitte	doc_491521501744_item	3740542	et	0	main
millele	doc_491521501744_item	3740543	et	0	main
harjuma	doc_491521501744_item	3740544	et	0	main
millega	doc_491521501744_item	3740545	et	0	main
mitte	doc_491521501744_item	3740546	et	0	main
millele	doc_491521501744_item	3740547	et	0	main
baseeruma	doc_491521501744_item	3740548	et	0	main
millel	doc_491521501744_item	3740549	et	0	main
mitte	doc_491521501744_item	3740550	et	0	main
millele	doc_491521501744_item	3740551	et	0	main
tuginema	doc_491521501744_item	3740552	et	0	main
millele	doc_491521501744_item	3740553	et	0	main
mitte	doc_491521501744_item	3740554	et	0	main
millel	doc_491521501744_item	3740555	et	0	main
ortograafia	doc_491521501744_item	3740556	et	0	main
vead	doc_491521501744_item	3740557	et	0	main
õigekirjas	doc_491521501744_item	3740558	et	0	main
ja	doc_491521501744_item	3740559	et	0	main
interpunktsioonis	doc_491521501744_item	3740560	et	0	main
nimisõnade	doc_491521501744_item	3740561	et	0	main
kokku-	doc_491521501744_item	3740562	et	0	main
ja	doc_491521501744_item	3740563	et	0	main
lahkukirjutamine	doc_491521501744_item	3740564	et	0	main
on	doc_491521501744_item	3740565	et	0	main
segane	doc_491521501744_item	3740566	et	0	main
õpilased	doc_491521501744_item	3740567	et	0	main
ei	doc_491521501744_item	3740568	et	0	main
erista	doc_491521501744_item	3740569	et	0	main
kas	doc_491521501744_item	3740570	et	0	main
on	doc_491521501744_item	3740571	et	0	main
tegemist	doc_491521501744_item	3740572	et	0	main
konkreetse	doc_491521501744_item	3740573	et	0	main
üksikjuhtimiga	doc_491521501744_item	3740574	et	0	main
siis	doc_491521501744_item	3740575	et	0	main
lahku	doc_491521501744_item	3740576	et	0	main
voi	doc_491521501744_item	3740577	et	0	main
tegevusalaga	doc_491521501744_item	3740578	et	0	main
siis	doc_491521501744_item	3740579	et	0	main
kokku	doc_491521501744_item	3740580	et	0	main
nt	doc_491521501744_item	3740581	et	0	main
kingsepatöökoda	doc_491521501744_item	3740582	et	0	main
mitte	doc_491521501744_item	3740583	et	0	main
kingsepa	doc_491521501744_item	3740584	et	0	main
töökoda	doc_491521501744_item	3740585	et	0	main
olümpiapurjespordikeskus	doc_491521501744_item	3740586	et	0	main
mitte	doc_491521501744_item	3740587	et	0	main
olümpia	doc_491521501744_item	3740588	et	0	main
purjespordikeskus	doc_491521501744_item	3740589	et	0	main
põrandavärvimine	doc_491521501744_item	3740590	et	0	main
kui	doc_491521501744_item	3740591	et	0	main
tegevusala	doc_491521501744_item	3740592	et	0	main
vaibapuhastus	doc_491521501744_item	3740593	et	0	main
kui	doc_491521501744_item	3740594	et	0	main
tegevusala	doc_491521501744_item	3740595	et	0	main
kingaparandus	doc_491521501744_item	3740596	et	0	main
kui	doc_491521501744_item	3740597	et	0	main
tegevusala	doc_491521501744_item	3740598	et	0	main
arvsõnade	doc_491521501744_item	3740599	et	0	main
kokku-	doc_491521501744_item	3740600	et	0	main
ja	doc_491521501744_item	3740601	et	0	main
lahkukirjutamine	doc_491521501744_item	3740602	et	0	main
on	doc_491521501744_item	3740603	et	0	main
samuti	doc_491521501744_item	3740604	et	0	main
raske	doc_491521501744_item	3740605	et	0	main
nt	doc_491521501744_item	3740606	et	0	main
üheksasada	doc_491521501744_item	3740607	et	0	main
mitte	doc_491521501744_item	3740608	et	0	main
üheksa	doc_491521501744_item	3740609	et	0	main
sada	doc_491521501744_item	3740610	et	0	main
viis	doc_491521501744_item	3740611	et	0	main
tuhat	doc_491521501744_item	3740612	et	0	main
mitte	doc_491521501744_item	3740613	et	0	main
viistuhat	doc_491521501744_item	3740614	et	0	main
nelikümmend	doc_491521501744_item	3740615	et	0	main
kolm	doc_491521501744_item	3740616	et	0	main
mitte	doc_491521501744_item	3740617	et	0	main
neli	doc_491521501744_item	3740618	et	0	main
kümmend	doc_491521501744_item	3740619	et	0	main
kolm	doc_491521501744_item	3740620	et	0	main
kahetuhandes	doc_491521501744_item	3740621	et	0	main
mitte	doc_491521501744_item	3740622	et	0	main
kahe	doc_491521501744_item	3740623	et	0	main
tuhandes	doc_491521501744_item	3740624	et	0	main
kolm	doc_491521501744_item	3740625	et	0	main
miljonit	doc_491521501744_item	3740626	et	0	main
mitte	doc_491521501744_item	3740627	et	0	main
kolmmiljonit	doc_491521501744_item	3740628	et	0	main
kolmemiljoniline	doc_491521501744_item	3740629	et	0	main
mitte	doc_491521501744_item	3740630	et	0	main
kolme	doc_491521501744_item	3740631	et	0	main
miljoniline	doc_491521501744_item	3740632	et	0	main
pool	doc_491521501744_item	3740633	et	0	main
miljardit	doc_491521501744_item	3740634	et	0	main
mitte	doc_491521501744_item	3740635	et	0	main
poolmiljardit	doc_491521501744_item	3740636	et	0	main
poolemiljardik	doc_491521501744_item	3740637	et	0	main
mitte	doc_491521501744_item	3740638	et	0	main
poole	doc_491521501744_item	3740639	et	0	main
miljardik	doc_491521501744_item	3740640	et	0	main
süntaks	doc_491521501744_item	3740641	et	0	main
sõnajärg	doc_491521501744_item	3740642	et	0	main
ja	doc_491521501744_item	3740643	et	0	main
lauseehitus	doc_491521501744_item	3740644	et	0	main
on	doc_491521501744_item	3740645	et	0	main
vale	doc_491521501744_item	3740646	et	0	main
lauseehitus	doc_491521501744_item	3740647	et	0	main
on	doc_491521501744_item	3740648	et	0	main
eesti	doc_491521501744_item	3740649	et	0	main
keeles	doc_491521501744_item	3740650	et	0	main
suhteliselt	doc_491521501744_item	3740651	et	0	main
vaba	doc_491521501744_item	3740652	et	0	main
kuid	doc_491521501744_item	3740653	et	0	main
vale	doc_491521501744_item	3740654	et	0	main
sõnajärg	doc_491521501744_item	3740655	et	0	main
võib	doc_491521501744_item	3740656	et	0	main
omakorda	doc_491521501744_item	3740657	et	0	main
põhjustada	doc_491521501744_item	3740658	et	0	main
vigu	doc_491521501744_item	3740659	et	0	main
nt	doc_491521501744_item	3740660	et	0	main
kiiresti	doc_491521501744_item	3740661	et	0	main
lahkusid	doc_491521501744_item	3740662	et	0	main
õpilased	doc_491521501744_item	3740663	et	0	main
koolimajast	doc_491521501744_item	3740664	et	0	main
mitte	doc_491521501744_item	3740665	et	0	main
õpilased	doc_491521501744_item	3740666	et	0	main
lahkusid	doc_491521501744_item	3740667	et	0	main
koolimajast	doc_491521501744_item	3740668	et	0	main
kiiresti	doc_491521501744_item	3740669	et	0	main
kui	doc_491521501744_item	3740670	et	0	main
lause	doc_491521501744_item	3740671	et	0	main
algul	doc_491521501744_item	3740672	et	0	main
olevaks	doc_491521501744_item	3740673	et	0	main
verbilaiendiks	doc_491521501744_item	3740674	et	0	main
on	doc_491521501744_item	3740675	et	0	main
verbiga	doc_491521501744_item	3740676	et	0	main
tihedalt	doc_491521501744_item	3740677	et	0	main
seotud	doc_491521501744_item	3740678	et	0	main
viisimäärus	doc_491521501744_item	3740679	et	0	main
raamat	doc_491521501744_item	3740680	et	0	main
on	doc_491521501744_item	3740681	et	0	main
läbi	doc_491521501744_item	3740682	et	0	main
loetud	doc_491521501744_item	3740683	et	0	main
mitte	doc_491521501744_item	3740684	et	0	main
raamat	doc_491521501744_item	3740685	et	0	main
on	doc_491521501744_item	3740686	et	0	main
lugenud	doc_491521501744_item	3740687	et	0	main
läbi	doc_491521501744_item	3740688	et	0	main
infiniitverbi	doc_491521501744_item	3740689	et	0	main
laiendeil	doc_491521501744_item	3740690	et	0	main
on	doc_491521501744_item	3740691	et	0	main
asukoht	doc_491521501744_item	3740692	et	0	main
paikneda	doc_491521501744_item	3740693	et	0	main
tema	doc_491521501744_item	3740694	et	0	main
ees	doc_491521501744_item	3740695	et	0	main
raadiot	doc_491521501744_item	3740696	et	0	main
võib	doc_491521501744_item	3740697	et	0	main
kaasa	doc_491521501744_item	3740698	et	0	main
võtta	doc_491521501744_item	3740699	et	0	main
mitte	doc_491521501744_item	3740700	et	0	main
raadiot	doc_491521501744_item	3740701	et	0	main
kaasa	doc_491521501744_item	3740702	et	0	main
võib	doc_491521501744_item	3740703	et	0	main
võtta	doc_491521501744_item	3740704	et	0	main
ühildumise	doc_491521501744_item	3740705	et	0	main
vead	doc_491521501744_item	3740706	et	0	main
öeldistäite	doc_491521501744_item	3740707	et	0	main
ühildumine	doc_491521501744_item	3740708	et	0	main
alusega	doc_491521501744_item	3740709	et	0	main
õpilased	doc_491521501744_item	3740710	et	0	main
ei	doc_491521501744_item	3740711	et	0	main
tee	doc_491521501744_item	3740712	et	0	main
vahet	doc_491521501744_item	3740713	et	0	main
kas	doc_491521501744_item	3740714	et	0	main
alus	doc_491521501744_item	3740715	et	0	main
tähistab	doc_491521501744_item	3740716	et	0	main
ühte	doc_491521501744_item	3740717	et	0	main
siis	doc_491521501744_item	3740718	et	0	main
öeldistäide	doc_491521501744_item	3740719	et	0	main
ainsuses	doc_491521501744_item	3740720	et	0	main
või	doc_491521501744_item	3740721	et	0	main
alus	doc_491521501744_item	3740722	et	0	main
tähistab	doc_491521501744_item	3740723	et	0	main
mitut	doc_491521501744_item	3740724	et	0	main
siis	doc_491521501744_item	3740725	et	0	main
öeldistäide	doc_491521501744_item	3740726	et	0	main
mitmuses	doc_491521501744_item	3740727	et	0	main
nt	doc_491521501744_item	3740728	et	0	main
tangid	doc_491521501744_item	3740729	et	0	main
on	doc_491521501744_item	3740730	et	0	main
tööriist	doc_491521501744_item	3740731	et	0	main
mitte	doc_491521501744_item	3740732	et	0	main
tööriistad	doc_491521501744_item	3740733	et	0	main
pulmad	doc_491521501744_item	3740734	et	0	main
on	doc_491521501744_item	3740735	et	0	main
meeldejääv	doc_491521501744_item	3740736	et	0	main
sündmus	doc_491521501744_item	3740737	et	0	main
mitte	doc_491521501744_item	3740738	et	0	main
meeldejäävad	doc_491521501744_item	3740739	et	0	main
sündmused	doc_491521501744_item	3740740	et	0	main
elina	doc_491521501744_item	3740741	et	0	main
ja	doc_491521501744_item	3740742	et	0	main
karina	doc_491521501744_item	3740743	et	0	main
on	doc_491521501744_item	3740744	et	0	main
üliõpilased	doc_491521501744_item	3740745	et	0	main
mitte	doc_491521501744_item	3740746	et	0	main
üliõpilane	doc_491521501744_item	3740747	et	0	main
kokkuvõte	doc_491521501744_item	3740748	et	0	main
ei	doc_491521501744_item	3740749	et	0	main
saa	doc_491521501744_item	3740750	et	0	main
anda	doc_491521501744_item	3740751	et	0	main
ühtki	doc_491521501744_item	3740752	et	0	main
üldkehtivat	doc_491521501744_item	3740753	et	0	main
reeglit	doc_491521501744_item	3740754	et	0	main
kuidas	doc_491521501744_item	3740755	et	0	main
õpilaste	doc_491521501744_item	3740756	et	0	main
keelevigu	doc_491521501744_item	3740757	et	0	main
parandada	doc_491521501744_item	3740758	et	0	main
nagu	doc_491521501744_item	3740759	et	0	main
ei	doc_491521501744_item	3740760	et	0	main
ole	doc_491521501744_item	3740761	et	0	main
võimalik	doc_491521501744_item	3740762	et	0	main
anda	doc_491521501744_item	3740763	et	0	main
selgeid	doc_491521501744_item	3740764	et	0	main
reegleid	doc_491521501744_item	3740765	et	0	main
kuidas	doc_491521501744_item	3740766	et	0	main
õpetada	doc_491521501744_item	3740767	et	0	main
ja	doc_491521501744_item	3740768	et	0	main
õppida	doc_491521501744_item	3740769	et	0	main
iga	doc_491521501744_item	3740770	et	0	main
õpetaja	doc_491521501744_item	3740771	et	0	main
tahab	doc_491521501744_item	3740772	et	0	main
et	doc_491521501744_item	3740773	et	0	main
tema	doc_491521501744_item	3740774	et	0	main
õppijad	doc_491521501744_item	3740775	et	0	main
õpiksid	doc_491521501744_item	3740776	et	0	main
suhtlema	doc_491521501744_item	3740777	et	0	main
ja	doc_491521501744_item	3740778	et	0	main
tundma	doc_491521501744_item	3740779	et	0	main
end	doc_491521501744_item	3740780	et	0	main
vilunud	doc_491521501744_item	3740781	et	0	main
vestlejatena	doc_491521501744_item	3740782	et	0	main
õpetamine	doc_491521501744_item	3740783	et	0	main
peaks	doc_491521501744_item	3740784	et	0	main
olema	doc_491521501744_item	3740785	et	0	main
paindlik	doc_491521501744_item	3740786	et	0	main
et	doc_491521501744_item	3740787	et	0	main
sellest	doc_491521501744_item	3740788	et	0	main
oleks	doc_491521501744_item	3740789	et	0	main
abi	doc_491521501744_item	3740790	et	0	main
õppijatele	doc_491521501744_item	3740791	et	0	main
kes	doc_491521501744_item	3740792	et	0	main
ihkavad	doc_491521501744_item	3740793	et	0	main
vabalt	doc_491521501744_item	3740794	et	0	main
eksperimenteerida	doc_491521501744_item	3740795	et	0	main
kuid	doc_491521501744_item	3740796	et	0	main
ka	doc_491521501744_item	3740797	et	0	main
neile	doc_491521501744_item	3740798	et	0	main
kes	doc_491521501744_item	3740799	et	0	main
soovivad	doc_491521501744_item	3740800	et	0	main
turvalist	doc_491521501744_item	3740801	et	0	main
teadmist	doc_491521501744_item	3740802	et	0	main
mis	doc_491521501744_item	3740803	et	0	main
on	doc_491521501744_item	3740804	et	0	main
õige	doc_491521501744_item	3740805	et	0	main
ja	doc_491521501744_item	3740806	et	0	main
mis	doc_491521501744_item	3740807	et	0	main
vale	doc_491521501744_item	3740808	et	0	main
loodan	doc_491521501744_item	3740809	et	0	main
et	doc_491521501744_item	3740810	et	0	main
käesolev	doc_491521501744_item	3740811	et	0	main
vigade	doc_491521501744_item	3740812	et	0	main
analüüs	doc_491521501744_item	3740813	et	0	main
pakub	doc_491521501744_item	3740814	et	0	main
õpetajatele	doc_491521501744_item	3740815	et	0	main
huvi	doc_491521501744_item	3740816	et	0	main
ja	doc_491521501744_item	3740817	et	0	main
teda	doc_491521501744_item	3740818	et	0	main
saab	doc_491521501744_item	3740819	et	0	main
praktikas	doc_491521501744_item	3740820	et	0	main
kasutada	doc_491521501744_item	3740821	et	0	main
kasutatud	doc_491521501744_item	3740822	et	0	main
kirjandus	doc_491521501744_item	3740823	et	0	main
1	doc_491521501744_item	3740824	et	0	main
kerge	doc_491521501744_item	3740825	et	0	main
krista	doc_491521501744_item	3740826	et	0	main
1996funktsionaalse	doc_491521501744_item	3740827	et	0	main
keeleoskuse	doc_491521501744_item	3740828	et	0	main
taseme	doc_491521501744_item	3740829	et	0	main
määratleminetallinn	doc_491521501744_item	3740830	et	0	main
kustutada	doc_491521501756_item	3742659	et	0	main
tekst	doc_491521501756_item	3742660	et	0	main
kustutada	doc_491521501756_item	3742661	et	0	main
samasugune	doc_491521501756_item	3742662	et	0	main
tekst	doc_491521501756_item	3742663	et	0	main
siin	doc_491521501756_item	3742664	et	0	main
httpevkktlueedocumentsdoc491521501867item	doc_491521501756_item	3742665	et	0	main
tallinna	doc_491521501756_item	3742666	et	0	main
pedagoogikaülikool	doc_491521501756_item	3742667	et	0	main
eesti	doc_491521501756_item	3742668	et	0	main
filoloogia	doc_491521501756_item	3742669	et	0	main
teaduskond	doc_491521501756_item	3742670	et	0	main
eesti	doc_491521501756_item	3742671	et	0	main
keele	doc_491521501756_item	3742672	et	0	main
õppetool	doc_491521501756_item	3742673	et	0	main
eesnimi	doc_491521501756_item	3742674	et	0	main
perekonnanimi	doc_491521501756_item	3742675	et	0	main
vigade	doc_491521501756_item	3742676	et	0	main
analüüs	doc_491521501756_item	3742677	et	0	main
uurimistöö	doc_491521501756_item	3742678	et	0	main
juhendaja	doc_491521501756_item	3742679	et	0	main
eperekonnanimi	doc_491521501756_item	3742680	et	0	main
sisukord	doc_491521501756_item	3742681	et	0	main
sissejuhatus	doc_491521501756_item	3742682	et	0	main
vigade	doc_491521501756_item	3742683	et	0	main
registreerimine	doc_491521501756_item	3742684	et	0	main
vigade	doc_491521501756_item	3742685	et	0	main
rühmitamine	doc_491521501756_item	3742686	et	0	main
ja	doc_491521501756_item	3742687	et	0	main
põhjuste	doc_491521501756_item	3742688	et	0	main
seletamine	doc_491521501756_item	3742689	et	0	main
kokkuvõte	doc_491521501756_item	3742690	et	0	main
kasutatud	doc_491521501756_item	3742691	et	0	main
kirjandus	doc_491521501756_item	3742692	et	0	main
sissejuhatus	doc_491521501756_item	3742693	et	0	main
keeleoskust	doc_491521501756_item	3742694	et	0	main
hinnatakse	doc_491521501756_item	3742695	et	0	main
vastavalt	doc_491521501756_item	3742696	et	0	main
sellele	doc_491521501756_item	3742697	et	0	main
kui	doc_491521501756_item	3742698	et	0	main
mitmes	doc_491521501756_item	3742699	et	0	main
valdkonnas	doc_491521501756_item	3742700	et	0	main
inimene	doc_491521501756_item	3742701	et	0	main
on	doc_491521501756_item	3742702	et	0	main
võimeline	doc_491521501756_item	3742703	et	0	main
kaasa	doc_491521501756_item	3742704	et	0	main
rääkima	doc_491521501756_item	3742705	et	0	main
kui	doc_491521501756_item	3742706	et	0	main
õi	doc_491521501756_item	3742707	et	0	main
gesti	doc_491521501756_item	3742708	et	0	main
ta	doc_491521501756_item	3742709	et	0	main
seda	doc_491521501756_item	3742710	et	0	main
teeb	doc_491521501756_item	3742711	et	0	main
viga	doc_491521501756_item	3742712	et	0	main
on	doc_491521501756_item	3742713	et	0	main
kõrvalekalle	doc_491521501756_item	3742714	et	0	main
kehtivast	doc_491521501756_item	3742715	et	0	main
normist	doc_491521501756_item	3742716	et	0	main
keeleviga	doc_491521501756_item	3742717	et	0	main
võib	doc_491521501756_item	3742718	et	0	main
olla	doc_491521501756_item	3742719	et	0	main
vääratus	doc_491521501756_item	3742720	et	0	main
või	doc_491521501756_item	3742721	et	0	main
eksitus	doc_491521501756_item	3742722	et	0	main
mis	doc_491521501756_item	3742723	et	0	main
põhjustab	doc_491521501756_item	3742724	et	0	main
arusaamatuse	doc_491521501756_item	3742725	et	0	main
ja	doc_491521501756_item	3742726	et	0	main
valestimõistmist	doc_491521501756_item	3742727	et	0	main
mai	doc_491521501756_item	3742728	et	0	main
loog	doc_491521501756_item	3742729	et	0	main
ja	doc_491521501756_item	3742730	et	0	main
krista	doc_491521501756_item	3742731	et	0	main
kerge	doc_491521501756_item	3742732	et	0	main
1999	doc_491521501756_item	3742733	et	0	main
on	doc_491521501756_item	3742734	et	0	main
defineerinud	doc_491521501756_item	3742735	et	0	main
viga	doc_491521501756_item	3742736	et	0	main
kui	doc_491521501756_item	3742737	et	0	main
süstemaatilist	doc_491521501756_item	3742738	et	0	main
eksimist	doc_491521501756_item	3742739	et	0	main
mis	doc_491521501756_item	3742740	et	0	main
viitab	doc_491521501756_item	3742741	et	0	main
kindla	doc_491521501756_item	3742742	et	0	main
oskuse	doc_491521501756_item	3742743	et	0	main
puudumisele	doc_491521501756_item	3742744	et	0	main
vigu	doc_491521501756_item	3742745	et	0	main
tehakse	doc_491521501756_item	3742746	et	0	main
kui	doc_491521501756_item	3742747	et	0	main
ei	doc_491521501756_item	3742748	et	0	main
tea	doc_491521501756_item	3742749	et	0	main
reegleid	doc_491521501756_item	3742750	et	0	main
kuidas	doc_491521501756_item	3742751	et	0	main
toimida	doc_491521501756_item	3742752	et	0	main
õigesti	doc_491521501756_item	3742753	et	0	main
või	doc_491521501756_item	3742754	et	0	main
kui	doc_491521501756_item	3742755	et	0	main
sellised	doc_491521501756_item	3742756	et	0	main
hoopis	doc_491521501756_item	3742757	et	0	main
puuduvad	doc_491521501756_item	3742758	et	0	main
viga	doc_491521501756_item	3742759	et	0	main
võib	doc_491521501756_item	3742760	et	0	main
olla	doc_491521501756_item	3742761	et	0	main
kerge	doc_491521501756_item	3742762	et	0	main
eksimus	doc_491521501756_item	3742763	et	0	main
ja	doc_491521501756_item	3742764	et	0	main
hõlpsasti	doc_491521501756_item	3742765	et	0	main
kõrvaldatav	doc_491521501756_item	3742766	et	0	main
kui	doc_491521501756_item	3742767	et	0	main
sellele	doc_491521501756_item	3742768	et	0	main
tähelepanu	doc_491521501756_item	3742769	et	0	main
juhtida	doc_491521501756_item	3742770	et	0	main
õpilasele	doc_491521501756_item	3742771	et	0	main
hinnet	doc_491521501756_item	3742772	et	0	main
pannes	doc_491521501756_item	3742773	et	0	main
võtab	doc_491521501756_item	3742774	et	0	main
õpetaja	doc_491521501756_item	3742775	et	0	main
arvesse	doc_491521501756_item	3742776	et	0	main
tehtud	doc_491521501756_item	3742777	et	0	main
vigade	doc_491521501756_item	3742778	et	0	main
hulka	doc_491521501756_item	3742779	et	0	main
ning	doc_491521501756_item	3742780	et	0	main
enamasti	doc_491521501756_item	3742781	et	0	main
ka	doc_491521501756_item	3742782	et	0	main
nende	doc_491521501756_item	3742783	et	0	main
raskusastet	doc_491521501756_item	3742784	et	0	main
võiks	doc_491521501756_item	3742785	et	0	main
arvata	doc_491521501756_item	3742786	et	0	main
et	doc_491521501756_item	3742787	et	0	main
kuulata	doc_491521501756_item	3742788	et	0	main
on	doc_491521501756_item	3742789	et	0	main
kergem	doc_491521501756_item	3742790	et	0	main
kui	doc_491521501756_item	3742791	et	0	main
rääkida	doc_491521501756_item	3742792	et	0	main
või	doc_491521501756_item	3742793	et	0	main
et	doc_491521501756_item	3742794	et	0	main
õigekirjavead	doc_491521501756_item	3742795	et	0	main
on	doc_491521501756_item	3742796	et	0	main
lihtsamad	doc_491521501756_item	3742797	et	0	main
kui	doc_491521501756_item	3742798	et	0	main
vormimoodustusvead	doc_491521501756_item	3742799	et	0	main
ning	doc_491521501756_item	3742800	et	0	main
hindamisel	doc_491521501756_item	3742801	et	0	main
tuleb	doc_491521501756_item	3742802	et	0	main
seda	doc_491521501756_item	3742803	et	0	main
arvestada	doc_491521501756_item	3742804	et	0	main
eesti	doc_491521501756_item	3742805	et	0	main
keele	doc_491521501756_item	3742806	et	0	main
õpetaja	doc_491521501756_item	3742807	et	0	main
peab	doc_491521501756_item	3742808	et	0	main
meeles	doc_491521501756_item	3742809	et	0	main
pidama	doc_491521501756_item	3742810	et	0	main
et	doc_491521501756_item	3742811	et	0	main
emakeeles	doc_491521501756_item	3742812	et	0	main
esinevad	doc_491521501756_item	3742813	et	0	main
vead	doc_491521501756_item	3742814	et	0	main
ei	doc_491521501756_item	3742815	et	0	main
ole	doc_491521501756_item	3742816	et	0	main
olulised	doc_491521501756_item	3742817	et	0	main
sama	doc_491521501756_item	3742818	et	0	main
keele	doc_491521501756_item	3742819	et	0	main
võõrkeelena	doc_491521501756_item	3742820	et	0	main
kõnelemisel	doc_491521501756_item	3742821	et	0	main
käesolev	doc_491521501756_item	3742822	et	0	main
uurimistöö	doc_491521501756_item	3742823	et	0	main
on	doc_491521501756_item	3742824	et	0	main
pühendatud	doc_491521501756_item	3742825	et	0	main
õpilaste	doc_491521501756_item	3742826	et	0	main
vigade	doc_491521501756_item	3742827	et	0	main
analüüsimisele	doc_491521501756_item	3742828	et	0	main
uurimus	doc_491521501756_item	3742829	et	0	main
on	doc_491521501756_item	3742830	et	0	main
tehtud	doc_491521501756_item	3742831	et	0	main
10	doc_491521501756_item	3742832	et	0	main
klassi	doc_491521501756_item	3742833	et	0	main
õpilaste	doc_491521501756_item	3742834	et	0	main
kirjandite	doc_491521501756_item	3742835	et	0	main
kodutööde	doc_491521501756_item	3742836	et	0	main
ja	doc_491521501756_item	3742837	et	0	main
kontrolltööde	doc_491521501756_item	3742838	et	0	main
alusel	doc_491521501756_item	3742839	et	0	main
nende	doc_491521501756_item	3742840	et	0	main
eesti	doc_491521501756_item	3742841	et	0	main
keele	doc_491521501756_item	3742842	et	0	main
õpetaja	doc_491521501756_item	3742843	et	0	main
arvates	doc_491521501756_item	3742844	et	0	main
tegemist	doc_491521501756_item	3742845	et	0	main
on	doc_491521501756_item	3742846	et	0	main
peamiselt	doc_491521501756_item	3742847	et	0	main
kesktasemega	doc_491521501756_item	3742848	et	0	main
mõnedel	doc_491521501756_item	3742849	et	0	main
on	doc_491521501756_item	3742850	et	0	main
isegi	doc_491521501756_item	3742851	et	0	main
algtase	doc_491521501756_item	3742852	et	0	main
nende	doc_491521501756_item	3742853	et	0	main
tööde	doc_491521501756_item	3742854	et	0	main
alusel	doc_491521501756_item	3742855	et	0	main
püüdsingi	doc_491521501756_item	3742856	et	0	main
analüüsida	doc_491521501756_item	3742857	et	0	main
vigu	doc_491521501756_item	3742858	et	0	main
ja	doc_491521501756_item	3742859	et	0	main
nende	doc_491521501756_item	3742860	et	0	main
põhjusi	doc_491521501756_item	3742861	et	0	main
tahaksin	doc_491521501756_item	3742862	et	0	main
tänada	doc_491521501756_item	3742863	et	0	main
oma	doc_491521501756_item	3742864	et	0	main
koolipoolset	doc_491521501756_item	3742865	et	0	main
juhendajat	doc_491521501756_item	3742866	et	0	main
kes	doc_491521501756_item	3742867	et	0	main
aitas	doc_491521501756_item	3742868	et	0	main
mind	doc_491521501756_item	3742869	et	0	main
uurimismaterjali	doc_491521501756_item	3742870	et	0	main
otsida	doc_491521501756_item	3742871	et	0	main
vigade	doc_491521501756_item	3742872	et	0	main
registreerimine	doc_491521501756_item	3742873	et	0	main
algaja	doc_491521501756_item	3742874	et	0	main
õpetaja	doc_491521501756_item	3742875	et	0	main
ei	doc_491521501756_item	3742876	et	0	main
märka	doc_491521501756_item	3742877	et	0	main
kõiki	doc_491521501756_item	3742878	et	0	main
vigu	doc_491521501756_item	3742879	et	0	main
sest	doc_491521501756_item	3742880	et	0	main
paljud	doc_491521501756_item	3742881	et	0	main
neist	doc_491521501756_item	3742882	et	0	main
on	doc_491521501756_item	3742883	et	0	main
ootamatud	doc_491521501756_item	3742884	et	0	main
ebaloogilised	doc_491521501756_item	3742885	et	0	main
ja	doc_491521501756_item	3742886	et	0	main
neid	doc_491521501756_item	3742887	et	0	main
tehakse	doc_491521501756_item	3742888	et	0	main
arusaamatutel	doc_491521501756_item	3742889	et	0	main
põhjustel	doc_491521501756_item	3742890	et	0	main
isegi	doc_491521501756_item	3742891	et	0	main
kui	doc_491521501756_item	3742892	et	0	main
ta	doc_491521501756_item	3742893	et	0	main
märkab	doc_491521501756_item	3742894	et	0	main
vigu	doc_491521501756_item	3742895	et	0	main
ei	doc_491521501756_item	3742896	et	0	main
oska	doc_491521501756_item	3742897	et	0	main
ta	doc_491521501756_item	3742898	et	0	main
neid	doc_491521501756_item	3742899	et	0	main
käsitleda	doc_491521501756_item	3742900	et	0	main
juhtub	doc_491521501756_item	3742901	et	0	main
ju	doc_491521501756_item	3742902	et	0	main
nii	doc_491521501756_item	3742903	et	0	main
et	doc_491521501756_item	3742904	et	0	main
mida	doc_491521501756_item	3742905	et	0	main
rohkem	doc_491521501756_item	3742906	et	0	main
parandada	doc_491521501756_item	3742907	et	0	main
seda	doc_491521501756_item	3742908	et	0	main
hullemaks	doc_491521501756_item	3742909	et	0	main
läheb	doc_491521501756_item	3742910	et	0	main
kirjalik	doc_491521501756_item	3742911	et	0	main
tekst	doc_491521501756_item	3742912	et	0	main
muutub	doc_491521501756_item	3742913	et	0	main
arusaamatuks	doc_491521501756_item	3742914	et	0	main
kõnelev	doc_491521501756_item	3742915	et	0	main
õppija	doc_491521501756_item	3742916	et	0	main
kaotab	doc_491521501756_item	3742917	et	0	main
järje	doc_491521501756_item	3742918	et	0	main
ja	doc_491521501756_item	3742919	et	0	main
jääb	doc_491521501756_item	3742920	et	0	main
sõnatuks	doc_491521501756_item	3742921	et	0	main
vigu	doc_491521501756_item	3742922	et	0	main
on	doc_491521501756_item	3742923	et	0	main
kerge	doc_491521501756_item	3742924	et	0	main
leida	doc_491521501756_item	3742925	et	0	main
kirjakeelest	doc_491521501756_item	3742926	et	0	main
mis	doc_491521501756_item	3742927	et	0	main
on	doc_491521501756_item	3742928	et	0	main
õpetajale	doc_491521501756_item	3742929	et	0	main
nähtav	doc_491521501756_item	3742930	et	0	main
või	doc_491521501756_item	3742931	et	0	main
kuuldav	doc_491521501756_item	3742932	et	0	main
arvan	doc_491521501756_item	3742933	et	0	main
et	doc_491521501756_item	3742934	et	0	main
kirjavigu	doc_491521501756_item	3742935	et	0	main
on	doc_491521501756_item	3742936	et	0	main
suhteliselt	doc_491521501756_item	3742937	et	0	main
mugav	doc_491521501756_item	3742938	et	0	main
parandada	doc_491521501756_item	3742939	et	0	main
sest	doc_491521501756_item	3742940	et	0	main
kirjalikul	doc_491521501756_item	3742941	et	0	main
tekstil	doc_491521501756_item	3742942	et	0	main
on	doc_491521501756_item	3742943	et	0	main
omadus	doc_491521501756_item	3742944	et	0	main
vead	doc_491521501756_item	3742945	et	0	main
silmatorkavaks	doc_491521501756_item	3742946	et	0	main
teha	doc_491521501756_item	3742947	et	0	main
kui	doc_491521501756_item	3742948	et	0	main
õppija	doc_491521501756_item	3742949	et	0	main
saab	doc_491521501756_item	3742950	et	0	main
suulise	doc_491521501756_item	3742951	et	0	main
vastuse	doc_491521501756_item	3742952	et	0	main
viie	doc_491521501756_item	3742953	et	0	main
võib	doc_491521501756_item	3742954	et	0	main
sama	doc_491521501756_item	3742955	et	0	main
tekst	doc_491521501756_item	3742956	et	0	main
kirjalikul	doc_491521501756_item	3742957	et	0	main
kujul	doc_491521501756_item	3742958	et	0	main
ainult	doc_491521501756_item	3742959	et	0	main
nelja-kolme	doc_491521501756_item	3742960	et	0	main
välja	doc_491521501756_item	3742961	et	0	main
teenida	doc_491521501756_item	3742962	et	0	main
samas	doc_491521501756_item	3742963	et	0	main
on	doc_491521501756_item	3742964	et	0	main
kirjalikku	doc_491521501756_item	3742965	et	0	main
tööd	doc_491521501756_item	3742966	et	0	main
parandades	doc_491521501756_item	3742967	et	0	main
õpetajal	doc_491521501756_item	3742968	et	0	main
rohkem	doc_491521501756_item	3742969	et	0	main
aega	doc_491521501756_item	3742970	et	0	main
mõelda	doc_491521501756_item	3742971	et	0	main
kas	doc_491521501756_item	3742972	et	0	main
viga	doc_491521501756_item	3742973	et	0	main
on	doc_491521501756_item	3742974	et	0	main
juhuslik	doc_491521501756_item	3742975	et	0	main
eksitus	doc_491521501756_item	3742976	et	0	main
või	doc_491521501756_item	3742977	et	0	main
tõsine	doc_491521501756_item	3742978	et	0	main
viga	doc_491521501756_item	3742979	et	0	main
mis	doc_491521501756_item	3742980	et	0	main
põhjustatud	doc_491521501756_item	3742981	et	0	main
sellest	doc_491521501756_item	3742982	et	0	main
et	doc_491521501756_item	3742983	et	0	main
reegel	doc_491521501756_item	3742984	et	0	main
ei	doc_491521501756_item	3742985	et	0	main
ole	doc_491521501756_item	3742986	et	0	main
selgeks	doc_491521501756_item	3742987	et	0	main
õpitud	doc_491521501756_item	3742988	et	0	main
vigade	doc_491521501756_item	3742989	et	0	main
rühmitamine	doc_491521501756_item	3742990	et	0	main
ja	doc_491521501756_item	3742991	et	0	main
põhjuste	doc_491521501756_item	3742992	et	0	main
seletamine	doc_491521501756_item	3742993	et	0	main
nii	doc_491521501756_item	3742994	et	0	main
õpetajad	doc_491521501756_item	3742995	et	0	main
kui	doc_491521501756_item	3742996	et	0	main
õpilased	doc_491521501756_item	3742997	et	0	main
oskavad	doc_491521501756_item	3742998	et	0	main
öelda	doc_491521501756_item	3742999	et	0	main
mis	doc_491521501756_item	3743000	et	0	main
on	doc_491521501756_item	3743001	et	0	main
eesti	doc_491521501756_item	3743002	et	0	main
keeles	doc_491521501756_item	3743003	et	0	main
kõige	doc_491521501756_item	3743004	et	0	main
raskem	doc_491521501756_item	3743005	et	0	main
siin	doc_491521501756_item	3743006	et	0	main
on	doc_491521501756_item	3743007	et	0	main
toodud	doc_491521501756_item	3743008	et	0	main
keeletasandid	doc_491521501756_item	3743009	et	0	main
kus	doc_491521501756_item	3743010	et	0	main
10	doc_491521501756_item	3743011	et	0	main
klassi	doc_491521501756_item	3743012	et	0	main
õpilased	doc_491521501756_item	3743013	et	0	main
teevad	doc_491521501756_item	3743014	et	0	main
vigu	doc_491521501756_item	3743015	et	0	main
sõnavara	doc_491521501756_item	3743016	et	0	main
õppija	doc_491521501756_item	3743017	et	0	main
kasutab	doc_491521501756_item	3743018	et	0	main
vale	doc_491521501756_item	3743019	et	0	main
sõna	doc_491521501756_item	3743020	et	0	main
mille	doc_491521501756_item	3743021	et	0	main
tõttu	doc_491521501756_item	3743022	et	0	main
ei	doc_491521501756_item	3743023	et	0	main
ole	doc_491521501756_item	3743024	et	0	main
võimalik	doc_491521501756_item	3743025	et	0	main
lausest	doc_491521501756_item	3743026	et	0	main
aru	doc_491521501756_item	3743027	et	0	main
saada	doc_491521501756_item	3743028	et	0	main
nt	doc_491521501756_item	3743029	et	0	main
kui	doc_491521501756_item	3743030	et	0	main
kõik	doc_491521501756_item	3743031	et	0	main
on	doc_491521501756_item	3743032	et	0	main
juba	doc_491521501756_item	3743033	et	0	main
ära	doc_491521501756_item	3743034	et	0	main
tehtud	doc_491521501756_item	3743035	et	0	main
kindlasti	doc_491521501756_item	3743036	et	0	main
ja	doc_491521501756_item	3743037	et	0	main
mina	doc_491521501756_item	3743038	et	0	main
puhkan	doc_491521501756_item	3743039	et	0	main
kõigidest	doc_491521501756_item	3743040	et	0	main
lause	doc_491521501756_item	3743041	et	0	main
sõnastus	doc_491521501756_item	3743042	et	0	main
on	doc_491521501756_item	3743043	et	0	main
ebaselge	doc_491521501756_item	3743044	et	0	main
seetõttu	doc_491521501756_item	3743045	et	0	main
ei	doc_491521501756_item	3743046	et	0	main
ole	doc_491521501756_item	3743047	et	0	main
võimalik	doc_491521501756_item	3743048	et	0	main
lausest	doc_491521501756_item	3743049	et	0	main
aru	doc_491521501756_item	3743050	et	0	main
saada	doc_491521501756_item	3743051	et	0	main
nt	doc_491521501756_item	3743052	et	0	main
mulle	doc_491521501756_item	3743053	et	0	main
üldse	doc_491521501756_item	3743054	et	0	main
ei	doc_491521501756_item	3743055	et	0	main
meeldi	doc_491521501756_item	3743056	et	0	main
vanamuusika	doc_491521501756_item	3743057	et	0	main
ansamblid	doc_491521501756_item	3743058	et	0	main
ja	doc_491521501756_item	3743059	et	0	main
põllumajandussaated	doc_491521501756_item	3743060	et	0	main
vanamuusika	doc_491521501756_item	3743061	et	0	main
ansamblid	doc_491521501756_item	3743062	et	0	main
on	doc_491521501756_item	3743063	et	0	main
kasutatud	doc_491521501756_item	3743064	et	0	main
valesti	doc_491521501756_item	3743065	et	0	main
oleks	doc_491521501756_item	3743066	et	0	main
parem-mulle	doc_491521501756_item	3743067	et	0	main
üldse	doc_491521501756_item	3743068	et	0	main
ei	doc_491521501756_item	3743069	et	0	main
meeldi	doc_491521501756_item	3743070	et	0	main
ansamblid	doc_491521501756_item	3743071	et	0	main
mis	doc_491521501756_item	3743072	et	0	main
mängivad	doc_491521501756_item	3743073	et	0	main
vana	doc_491521501756_item	3743074	et	0	main
muusikat	doc_491521501756_item	3743075	et	0	main
ja	doc_491521501756_item	3743076	et	0	main
põllumajandussaated	doc_491521501756_item	3743077	et	0	main
morfoloogia	doc_491521501756_item	3743078	et	0	main
õppija	doc_491521501756_item	3743079	et	0	main
moodustab	doc_491521501756_item	3743080	et	0	main
vigaseid	doc_491521501756_item	3743081	et	0	main
grammatilisi	doc_491521501756_item	3743082	et	0	main
vorme	doc_491521501756_item	3743083	et	0	main
üks	doc_491521501756_item	3743084	et	0	main
sagedasem	doc_491521501756_item	3743085	et	0	main
põhjus	doc_491521501756_item	3743086	et	0	main
on	doc_491521501756_item	3743087	et	0	main
emakeele	doc_491521501756_item	3743088	et	0	main
mõju	doc_491521501756_item	3743089	et	0	main
liit-	doc_491521501756_item	3743090	et	0	main
ja	doc_491521501756_item	3743091	et	0	main
ühendtegusõnade	doc_491521501756_item	3743092	et	0	main
moodustusvead	doc_491521501756_item	3743093	et	0	main
kui	doc_491521501756_item	3743094	et	0	main
kontekst	doc_491521501756_item	3743095	et	0	main
ei	doc_491521501756_item	3743096	et	0	main
ole	doc_491521501756_item	3743097	et	0	main
arusaadav	doc_491521501756_item	3743098	et	0	main
õpilased	doc_491521501756_item	3743099	et	0	main
ei	doc_491521501756_item	3743100	et	0	main
tea	doc_491521501756_item	3743101	et	0	main
mis	doc_491521501756_item	3743102	et	0	main
laadi	doc_491521501756_item	3743103	et	0	main
tegusõnaga	doc_491521501756_item	3743104	et	0	main
on	doc_491521501756_item	3743105	et	0	main
tegemist	doc_491521501756_item	3743106	et	0	main
lauses	doc_491521501756_item	3743107	et	0	main
kas	doc_491521501756_item	3743108	et	0	main
liit-	doc_491521501756_item	3743109	et	0	main
või	doc_491521501756_item	3743110	et	0	main
ühendverbiga	doc_491521501756_item	3743111	et	0	main
eesti	doc_491521501756_item	3743112	et	0	main
keeles	doc_491521501756_item	3743113	et	0	main
liittegusõnad	doc_491521501756_item	3743114	et	0	main
koosnevad	doc_491521501756_item	3743115	et	0	main
kahest	doc_491521501756_item	3743116	et	0	main
erinevast	doc_491521501756_item	3743117	et	0	main
tüvest	doc_491521501756_item	3743118	et	0	main
mis	doc_491521501756_item	3743119	et	0	main
moodustavad	doc_491521501756_item	3743120	et	0	main
liitsõna	doc_491521501756_item	3743121	et	0	main
ja	doc_491521501756_item	3743122	et	0	main
ühendtegusõnad	doc_491521501756_item	3743123	et	0	main
koosnevad	doc_491521501756_item	3743124	et	0	main
tegelikult	doc_491521501756_item	3743125	et	0	main
kahest	doc_491521501756_item	3743126	et	0	main
sõnast	doc_491521501756_item	3743127	et	0	main
tegusõnast	doc_491521501756_item	3743128	et	0	main
ja	doc_491521501756_item	3743129	et	0	main
selle	doc_491521501756_item	3743130	et	0	main
tähendust	doc_491521501756_item	3743131	et	0	main
muutvast	doc_491521501756_item	3743132	et	0	main
abimäärsõnast	doc_491521501756_item	3743133	et	0	main
nt	doc_491521501756_item	3743134	et	0	main
alakoormama	doc_491521501756_item	3743135	et	0	main
mitte	doc_491521501756_item	3743136	et	0	main
ala	doc_491521501756_item	3743137	et	0	main
koormama	doc_491521501756_item	3743138	et	0	main
siirdistutama	doc_491521501756_item	3743139	et	0	main
mitte	doc_491521501756_item	3743140	et	0	main
siird	doc_491521501756_item	3743141	et	0	main
istutama	doc_491521501756_item	3743142	et	0	main
ristküsitlema	doc_491521501756_item	3743143	et	0	main
mitte	doc_491521501756_item	3743144	et	0	main
rist	doc_491521501756_item	3743145	et	0	main
küsitlema	doc_491521501756_item	3743146	et	0	main
nt	doc_491521501756_item	3743147	et	0	main
alla	doc_491521501756_item	3743148	et	0	main
andma	doc_491521501756_item	3743149	et	0	main
mitte	doc_491521501756_item	3743150	et	0	main
allaandma	doc_491521501756_item	3743151	et	0	main
maha	doc_491521501756_item	3743152	et	0	main
magama	doc_491521501756_item	3743153	et	0	main
mitte	doc_491521501756_item	3743154	et	0	main
mahamagama	doc_491521501756_item	3743155	et	0	main
üle	doc_491521501756_item	3743156	et	0	main
elama	doc_491521501756_item	3743157	et	0	main
mitte	doc_491521501756_item	3743158	et	0	main
üleelama	doc_491521501756_item	3743159	et	0	main
õpilastel	doc_491521501756_item	3743160	et	0	main
on	doc_491521501756_item	3743161	et	0	main
raske	doc_491521501756_item	3743162	et	0	main
vahet	doc_491521501756_item	3743163	et	0	main
teha	doc_491521501756_item	3743164	et	0	main
enesekohaste	doc_491521501756_item	3743165	et	0	main
ja	doc_491521501756_item	3743166	et	0	main
sihiliste	doc_491521501756_item	3743167	et	0	main
verbide	doc_491521501756_item	3743168	et	0	main
vahel	doc_491521501756_item	3743169	et	0	main
sest	doc_491521501756_item	3743170	et	0	main
enesekohased	doc_491521501756_item	3743171	et	0	main
tegusõnad	doc_491521501756_item	3743172	et	0	main
väljendavad	doc_491521501756_item	3743173	et	0	main
seda	doc_491521501756_item	3743174	et	0	main
et	doc_491521501756_item	3743175	et	0	main
tegevus	doc_491521501756_item	3743176	et	0	main
on	doc_491521501756_item	3743177	et	0	main
suunatud	doc_491521501756_item	3743178	et	0	main
tegijale	doc_491521501756_item	3743179	et	0	main
endale	doc_491521501756_item	3743180	et	0	main
või	doc_491521501756_item	3743181	et	0	main
toimub	doc_491521501756_item	3743182	et	0	main
tegija	doc_491521501756_item	3743183	et	0	main
endaga	doc_491521501756_item	3743184	et	0	main
aga	doc_491521501756_item	3743185	et	0	main
sihilised	doc_491521501756_item	3743186	et	0	main
verbid	doc_491521501756_item	3743187	et	0	main
väljendavad	doc_491521501756_item	3743188	et	0	main
tegevuse	doc_491521501756_item	3743189	et	0	main
põhjustamist	doc_491521501756_item	3743190	et	0	main
või	doc_491521501756_item	3743191	et	0	main
esile	doc_491521501756_item	3743192	et	0	main
kutsumist	doc_491521501756_item	3743193	et	0	main
nt	doc_491521501756_item	3743194	et	0	main
täna	doc_491521501756_item	3743195	et	0	main
jätan	doc_491521501756_item	3743196	et	0	main
mitte	doc_491521501756_item	3743197	et	0	main
jään	doc_491521501756_item	3743198	et	0	main
ma	doc_491521501756_item	3743199	et	0	main
töö	doc_491521501756_item	3743200	et	0	main
tegemata	doc_491521501756_item	3743201	et	0	main
ma	doc_491521501756_item	3743202	et	0	main
liigutan	doc_491521501756_item	3743203	et	0	main
mitte	doc_491521501756_item	3743204	et	0	main
liigun	doc_491521501756_item	3743205	et	0	main
ennast	doc_491521501756_item	3743206	et	0	main
ma	doc_491521501756_item	3743207	et	0	main
pean	doc_491521501756_item	3743208	et	0	main
söötma	doc_491521501756_item	3743209	et	0	main
mitte	doc_491521501756_item	3743210	et	0	main
sööma	doc_491521501756_item	3743211	et	0	main
loomi	doc_491521501756_item	3743212	et	0	main
õpilased	doc_491521501756_item	3743213	et	0	main
ei	doc_491521501756_item	3743214	et	0	main
tee	doc_491521501756_item	3743215	et	0	main
vahet	doc_491521501756_item	3743216	et	0	main
ainsus-	doc_491521501756_item	3743217	et	0	main
ja	doc_491521501756_item	3743218	et	0	main
mitmussõnade	doc_491521501756_item	3743219	et	0	main
vahel	doc_491521501756_item	3743220	et	0	main
sest	doc_491521501756_item	3743221	et	0	main
eesti	doc_491521501756_item	3743222	et	0	main
keeles	doc_491521501756_item	3743223	et	0	main
on	doc_491521501756_item	3743224	et	0	main
nimisõnu	doc_491521501756_item	3743225	et	0	main
mis	doc_491521501756_item	3743226	et	0	main
esinevad	doc_491521501756_item	3743227	et	0	main
tavaliselt	doc_491521501756_item	3743228	et	0	main
ainsuse	doc_491521501756_item	3743229	et	0	main
vormis	doc_491521501756_item	3743230	et	0	main
kurjus	doc_491521501756_item	3743231	et	0	main
headus	doc_491521501756_item	3743232	et	0	main
nohu	doc_491521501756_item	3743233	et	0	main
ja	doc_491521501756_item	3743234	et	0	main
nimisõnu	doc_491521501756_item	3743235	et	0	main
mis	doc_491521501756_item	3743236	et	0	main
esinevad	doc_491521501756_item	3743237	et	0	main
mitmuse	doc_491521501756_item	3743238	et	0	main
vormis	doc_491521501756_item	3743239	et	0	main
mis	doc_491521501756_item	3743240	et	0	main
vene	doc_491521501756_item	3743241	et	0	main
keeles	doc_491521501756_item	3743242	et	0	main
on	doc_491521501756_item	3743243	et	0	main
ainsuses	doc_491521501756_item	3743244	et	0	main
jõulud-	doc_491521501756_item	3743245	et	0	main
рождество	doc_491521501756_item	3743246	et	0	main
rõuged-	doc_491521501756_item	3743247	et	0	main
оспа	doc_491521501756_item	3743248	et	0	main
tangud-	doc_491521501756_item	3743249	et	0	main
крупа	doc_491521501756_item	3743250	et	0	main
lihavõtted-	doc_491521501756_item	3743251	et	0	main
пасха	doc_491521501756_item	3743252	et	0	main
jt	doc_491521501756_item	3743253	et	0	main
nt	doc_491521501756_item	3743254	et	0	main
jõulud	doc_491521501756_item	3743255	et	0	main
olid	doc_491521501756_item	3743256	et	0	main
sel	doc_491521501756_item	3743257	et	0	main
aastal	doc_491521501756_item	3743258	et	0	main
ilma	doc_491521501756_item	3743259	et	0	main
lumeta	doc_491521501756_item	3743260	et	0	main
mitte	doc_491521501756_item	3743261	et	0	main
jõulu	doc_491521501756_item	3743262	et	0	main
oli	doc_491521501756_item	3743263	et	0	main
sel	doc_491521501756_item	3743264	et	0	main
aastal	doc_491521501756_item	3743265	et	0	main
ilma	doc_491521501756_item	3743266	et	0	main
lumeta	doc_491521501756_item	3743267	et	0	main
täpne	doc_491521501756_item	3743268	et	0	main
kaal	doc_491521501756_item	3743269	et	0	main
точные	doc_491521501756_item	3743270	et	0	main
весы	doc_491521501756_item	3743271	et	0	main
vanaaegne	doc_491521501756_item	3743272	et	0	main
kell	doc_491521501756_item	3743273	et	0	main
старинные	doc_491521501756_item	3743274	et	0	main
часы	doc_491521501756_item	3743275	et	0	main
kallid	doc_491521501756_item	3743276	et	0	main
pärlid	doc_491521501756_item	3743277	et	0	main
дорогой	doc_491521501756_item	3743278	et	0	main
жемчуг	doc_491521501756_item	3743279	et	0	main
kapsas	doc_491521501756_item	3743280	et	0	main
kapsad	doc_491521501756_item	3743281	et	0	main
капуста	doc_491521501756_item	3743282	et	0	main
maasikas	doc_491521501756_item	3743283	et	0	main
maasikad	doc_491521501756_item	3743284	et	0	main
земляника	doc_491521501756_item	3743285	et	0	main
aetakse	doc_491521501756_item	3743286	et	0	main
segi	doc_491521501756_item	3743287	et	0	main
omadussõna	doc_491521501756_item	3743288	et	0	main
ja	doc_491521501756_item	3743289	et	0	main
määrsõna	doc_491521501756_item	3743290	et	0	main
sest	doc_491521501756_item	3743291	et	0	main
eesti	doc_491521501756_item	3743292	et	0	main
keeles	doc_491521501756_item	3743293	et	0	main
omadussõnadel	doc_491521501756_item	3743294	et	0	main
kui	doc_491521501756_item	3743295	et	0	main
sõnaliigil	doc_491521501756_item	3743296	et	0	main
on	doc_491521501756_item	3743297	et	0	main
ühisosad	doc_491521501756_item	3743298	et	0	main
määrsõnade	doc_491521501756_item	3743299	et	0	main
tegusõnade	doc_491521501756_item	3743300	et	0	main
arvsõnade	doc_491521501756_item	3743301	et	0	main
ja	doc_491521501756_item	3743302	et	0	main
nimisõnadega	doc_491521501756_item	3743303	et	0	main
nt	doc_491521501756_item	3743304	et	0	main
ma	doc_491521501756_item	3743305	et	0	main
väga	doc_491521501756_item	3743306	et	0	main
hästi	doc_491521501756_item	3743307	et	0	main
mitte	doc_491521501756_item	3743308	et	0	main
hea	doc_491521501756_item	3743309	et	0	main
jooksen	doc_491521501756_item	3743310	et	0	main
meie	doc_491521501756_item	3743311	et	0	main
tundides	doc_491521501756_item	3743312	et	0	main
on	doc_491521501756_item	3743313	et	0	main
alati	doc_491521501756_item	3743314	et	0	main
huvitav	doc_491521501756_item	3743315	et	0	main
mitte	doc_491521501756_item	3743316	et	0	main
huvitavalt	doc_491521501756_item	3743317	et	0	main
mul	doc_491521501756_item	3743318	et	0	main
läheb	doc_491521501756_item	3743319	et	0	main
kord	doc_491521501756_item	3743320	et	0	main
halvemini	doc_491521501756_item	3743321	et	0	main
mitte	doc_491521501756_item	3743322	et	0	main
halvem	doc_491521501756_item	3743323	et	0	main
kord	doc_491521501756_item	3743324	et	0	main
paremini	doc_491521501756_item	3743325	et	0	main
mitte	doc_491521501756_item	3743326	et	0	main
parem	doc_491521501756_item	3743327	et	0	main
ärge	doc_491521501756_item	3743328	et	0	main
sisenege-	doc_491521501756_item	3743329	et	0	main
ohtlik	doc_491521501756_item	3743330	et	0	main
mitte	doc_491521501756_item	3743331	et	0	main
ohtlikult	doc_491521501756_item	3743332	et	0	main
omadussõnade	doc_491521501756_item	3743333	et	0	main
võrdlusastmete	doc_491521501756_item	3743334	et	0	main
moodustamine	doc_491521501756_item	3743335	et	0	main
on	doc_491521501756_item	3743336	et	0	main
eriti	doc_491521501756_item	3743337	et	0	main
raske	doc_491521501756_item	3743338	et	0	main
õpilased	doc_491521501756_item	3743339	et	0	main
peavad	doc_491521501756_item	3743340	et	0	main
meeles	doc_491521501756_item	3743341	et	0	main
pidama	doc_491521501756_item	3743342	et	0	main
et	doc_491521501756_item	3743343	et	0	main
keskvõrde	doc_491521501756_item	3743344	et	0	main
tunnuseks	doc_491521501756_item	3743345	et	0	main
on	doc_491521501756_item	3743346	et	0	main
alati	doc_491521501756_item	3743347	et	0	main
m	doc_491521501756_item	3743348	et	0	main
mis	doc_491521501756_item	3743349	et	0	main
liitub	doc_491521501756_item	3743350	et	0	main
tavaliselt	doc_491521501756_item	3743351	et	0	main
algvõrde	doc_491521501756_item	3743352	et	0	main
omastava	doc_491521501756_item	3743353	et	0	main
käände	doc_491521501756_item	3743354	et	0	main
tüvele	doc_491521501756_item	3743355	et	0	main
nt	doc_491521501756_item	3743356	et	0	main
suur	doc_491521501756_item	3743357	et	0	main
suure	doc_491521501756_item	3743358	et	0	main
suurem	doc_491521501756_item	3743359	et	0	main
mitte	doc_491521501756_item	3743360	et	0	main
suurtem	doc_491521501756_item	3743361	et	0	main
kaunis	doc_491521501756_item	3743362	et	0	main
kauni	doc_491521501756_item	3743363	et	0	main
kaunim	doc_491521501756_item	3743364	et	0	main
mitte	doc_491521501756_item	3743365	et	0	main
kaunisam	doc_491521501756_item	3743366	et	0	main
korralik	doc_491521501756_item	3743367	et	0	main
korraliku	doc_491521501756_item	3743368	et	0	main
korralikum	doc_491521501756_item	3743369	et	0	main
mitte	doc_491521501756_item	3743370	et	0	main
korralikem	doc_491521501756_item	3743371	et	0	main
ligi	doc_491521501756_item	3743372	et	0	main
70	doc_491521501756_item	3743373	et	0	main
omadussõna	doc_491521501756_item	3743374	et	0	main
korral	doc_491521501756_item	3743375	et	0	main
mille	doc_491521501756_item	3743376	et	0	main
algvõrde	doc_491521501756_item	3743377	et	0	main
omastav	doc_491521501756_item	3743378	et	0	main
kääne	doc_491521501756_item	3743379	et	0	main
lõpeb	doc_491521501756_item	3743380	et	0	main
a	doc_491521501756_item	3743381	et	0	main
ga	doc_491521501756_item	3743382	et	0	main
voi	doc_491521501756_item	3743383	et	0	main
u	doc_491521501756_item	3743384	et	0	main
ga	doc_491521501756_item	3743385	et	0	main
toimub	doc_491521501756_item	3743386	et	0	main
tunnuse	doc_491521501756_item	3743387	et	0	main
ees	doc_491521501756_item	3743388	et	0	main
vokaaliteisendus	doc_491521501756_item	3743389	et	0	main
a	doc_491521501756_item	3743390	et	0	main
u	doc_491521501756_item	3743391	et	0	main
muutub	doc_491521501756_item	3743392	et	0	main
e	doc_491521501756_item	3743393	et	0	main
ks	doc_491521501756_item	3743394	et	0	main
nt	doc_491521501756_item	3743395	et	0	main
pikk	doc_491521501756_item	3743396	et	0	main
pika	doc_491521501756_item	3743397	et	0	main
pikem	doc_491521501756_item	3743398	et	0	main
mitte	doc_491521501756_item	3743399	et	0	main
pikam	doc_491521501756_item	3743400	et	0	main
paks	doc_491521501756_item	3743401	et	0	main
paksu	doc_491521501756_item	3743402	et	0	main
paksem	doc_491521501756_item	3743403	et	0	main
mitte	doc_491521501756_item	3743404	et	0	main
paksum	doc_491521501756_item	3743405	et	0	main
kuri	doc_491521501756_item	3743406	et	0	main
kurja	doc_491521501756_item	3743407	et	0	main
kurjem	doc_491521501756_item	3743408	et	0	main
mitte	doc_491521501756_item	3743409	et	0	main
kurjam	doc_491521501756_item	3743410	et	0	main
i-ülivõrre	doc_491521501756_item	3743411	et	0	main
on	doc_491521501756_item	3743412	et	0	main
ebaselge	doc_491521501756_item	3743413	et	0	main
kui	doc_491521501756_item	3743414	et	0	main
tüvi	doc_491521501756_item	3743415	et	0	main
lõpeb	doc_491521501756_item	3743416	et	0	main
i-ga	doc_491521501756_item	3743417	et	0	main
toimub	doc_491521501756_item	3743418	et	0	main
ülivõrde	doc_491521501756_item	3743419	et	0	main
tunnuse	doc_491521501756_item	3743420	et	0	main
ees	doc_491521501756_item	3743421	et	0	main
vokaaliteisendus	doc_491521501756_item	3743422	et	0	main
i	doc_491521501756_item	3743423	et	0	main
muutub	doc_491521501756_item	3743424	et	0	main
e	doc_491521501756_item	3743425	et	0	main
ks	doc_491521501756_item	3743426	et	0	main
nt	doc_491521501756_item	3743427	et	0	main
kallis	doc_491521501756_item	3743428	et	0	main
kalliim	doc_491521501756_item	3743429	et	0	main
kalleim	doc_491521501756_item	3743430	et	0	main
mitte	doc_491521501756_item	3743431	et	0	main
kalliim	doc_491521501756_item	3743432	et	0	main
truu	doc_491521501756_item	3743433	et	0	main
truuim	doc_491521501756_item	3743434	et	0	main
truim	doc_491521501756_item	3743435	et	0	main
mitte	doc_491521501756_item	3743436	et	0	main
truuim	doc_491521501756_item	3743437	et	0	main
arvsõnad	doc_491521501756_item	3743438	et	0	main
käivad	doc_491521501756_item	3743439	et	0	main
väga	doc_491521501756_item	3743440	et	0	main
paljudele	doc_491521501756_item	3743441	et	0	main
õpilastele	doc_491521501756_item	3743442	et	0	main
üle	doc_491521501756_item	3743443	et	0	main
jõu	doc_491521501756_item	3743444	et	0	main
näiteks	doc_491521501756_item	3743445	et	0	main
kuupäevi	doc_491521501756_item	3743446	et	0	main
ja	doc_491521501756_item	3743447	et	0	main
aastaarve	doc_491521501756_item	3743448	et	0	main
vastamisel	doc_491521501756_item	3743449	et	0	main
ja	doc_491521501756_item	3743450	et	0	main
kirjutamisel	doc_491521501756_item	3743451	et	0	main
väidetakse	doc_491521501756_item	3743452	et	0	main
et	doc_491521501756_item	3743453	et	0	main
arvud	doc_491521501756_item	3743454	et	0	main
ei	doc_491521501756_item	3743455	et	0	main
jää	doc_491521501756_item	3743456	et	0	main
pähe	doc_491521501756_item	3743457	et	0	main
emakeeleski	doc_491521501756_item	3743458	et	0	main
sellepärast	doc_491521501756_item	3743459	et	0	main
on	doc_491521501756_item	3743460	et	0	main
neid	doc_491521501756_item	3743461	et	0	main
nii	doc_491521501756_item	3743462	et	0	main
raske	doc_491521501756_item	3743463	et	0	main
välja	doc_491521501756_item	3743464	et	0	main
öelda	doc_491521501756_item	3743465	et	0	main
võõrkeeles	doc_491521501756_item	3743466	et	0	main
sagedasti	doc_491521501756_item	3743467	et	0	main
aetakse	doc_491521501756_item	3743468	et	0	main
segi	doc_491521501756_item	3743469	et	0	main
kaks	doc_491521501756_item	3743470	et	0	main
ja	doc_491521501756_item	3743471	et	0	main
kaheksa	doc_491521501756_item	3743472	et	0	main
sisaldavad	doc_491521501756_item	3743473	et	0	main
arvsõnad	doc_491521501756_item	3743474	et	0	main
nt	doc_491521501756_item	3743475	et	0	main
ma	doc_491521501756_item	3743476	et	0	main
olen	doc_491521501756_item	3743477	et	0	main
sündinud	doc_491521501756_item	3743478	et	0	main
tuhande	doc_491521501756_item	3743479	et	0	main
üheksasada	doc_491521501756_item	3743480	et	0	main
kaheksakümne	doc_491521501756_item	3743481	et	0	main
kaheksandal	doc_491521501756_item	3743482	et	0	main
aastal	doc_491521501756_item	3743483	et	0	main
mitte	doc_491521501756_item	3743484	et	0	main
ma	doc_491521501756_item	3743485	et	0	main
olen	doc_491521501756_item	3743486	et	0	main
sündinud	doc_491521501756_item	3743487	et	0	main
tuhande	doc_491521501756_item	3743488	et	0	main
üheksasada	doc_491521501756_item	3743489	et	0	main
kahekümne	doc_491521501756_item	3743490	et	0	main
kahendal	doc_491521501756_item	3743491	et	0	main
aastal	doc_491521501756_item	3743492	et	0	main
minu	doc_491521501756_item	3743493	et	0	main
vanemad	doc_491521501756_item	3743494	et	0	main
on	doc_491521501756_item	3743495	et	0	main
sündinud	doc_491521501756_item	3743496	et	0	main
tuhande	doc_491521501756_item	3743497	et	0	main
üheksasada	doc_491521501756_item	3743498	et	0	main
kahekümne	doc_491521501756_item	3743499	et	0	main
teisel	doc_491521501756_item	3743500	et	0	main
aastal	doc_491521501756_item	3743501	et	0	main
mitte	doc_491521501756_item	3743502	et	0	main
minu	doc_491521501756_item	3743503	et	0	main
vanemad	doc_491521501756_item	3743504	et	0	main
on	doc_491521501756_item	3743505	et	0	main
sündinud	doc_491521501756_item	3743506	et	0	main
tuhande	doc_491521501756_item	3743507	et	0	main
üheksasada	doc_491521501756_item	3743508	et	0	main
kahekümne	doc_491521501756_item	3743509	et	0	main
kahendal	doc_491521501756_item	3743510	et	0	main
aastal	doc_491521501756_item	3743511	et	0	main
üksikjuhtudel	doc_491521501756_item	3743512	et	0	main
tekkivad	doc_491521501756_item	3743513	et	0	main
kahtlused	doc_491521501756_item	3743514	et	0	main
kas	doc_491521501756_item	3743515	et	0	main
tegemist	doc_491521501756_item	3743516	et	0	main
on	doc_491521501756_item	3743517	et	0	main
nimisõna	doc_491521501756_item	3743518	et	0	main
käändevormiga	doc_491521501756_item	3743519	et	0	main
või	doc_491521501756_item	3743520	et	0	main
määrsõnaga	doc_491521501756_item	3743521	et	0	main
õpilased	doc_491521501756_item	3743522	et	0	main
ei	doc_491521501756_item	3743523	et	0	main
tee	doc_491521501756_item	3743524	et	0	main
vahet	doc_491521501756_item	3743525	et	0	main
nimisõna	doc_491521501756_item	3743526	et	0	main
käändevormi	doc_491521501756_item	3743527	et	0	main
ja	doc_491521501756_item	3743528	et	0	main
määrsõna	doc_491521501756_item	3743529	et	0	main
vahel	doc_491521501756_item	3743530	et	0	main
sest	doc_491521501756_item	3743531	et	0	main
nimisõna	doc_491521501756_item	3743532	et	0	main
seesütleva	doc_491521501756_item	3743533	et	0	main
käändega	doc_491521501756_item	3743534	et	0	main
sarnanevad	doc_491521501756_item	3743535	et	0	main
määrsõnavormid	doc_491521501756_item	3743536	et	0	main
erinevad	doc_491521501756_item	3743537	et	0	main
paradigmaatiliselt	doc_491521501756_item	3743538	et	0	main
käändevormist	doc_491521501756_item	3743539	et	0	main
sageli	doc_491521501756_item	3743540	et	0	main
ka	doc_491521501756_item	3743541	et	0	main
tüve	doc_491521501756_item	3743542	et	0	main
tugeva	doc_491521501756_item	3743543	et	0	main
astme	doc_491521501756_item	3743544	et	0	main
poolest	doc_491521501756_item	3743545	et	0	main
nt	doc_491521501756_item	3743546	et	0	main
poisil	doc_491521501756_item	3743547	et	0	main
olid	doc_491521501756_item	3743548	et	0	main
kõrvad	doc_491521501756_item	3743549	et	0	main
lukkus	doc_491521501756_item	3743550	et	0	main
mitte	doc_491521501756_item	3743551	et	0	main
lukus	doc_491521501756_item	3743552	et	0	main
selles	doc_491521501756_item	3743553	et	0	main
tohutus	doc_491521501756_item	3743554	et	0	main
ja	doc_491521501756_item	3743555	et	0	main
keerulises	doc_491521501756_item	3743556	et	0	main
lukus	doc_491521501756_item	3743557	et	0	main
mitte	doc_491521501756_item	3743558	et	0	main
lukkus	doc_491521501756_item	3743559	et	0	main
oli	doc_491521501756_item	3743560	et	0	main
midagi	doc_491521501756_item	3743561	et	0	main
pahaendelist	doc_491521501756_item	3743562	et	0	main
asesõnade	doc_491521501756_item	3743563	et	0	main
kasutamisel	doc_491521501756_item	3743564	et	0	main
tekkivad	doc_491521501756_item	3743565	et	0	main
ka	doc_491521501756_item	3743566	et	0	main
mõned	doc_491521501756_item	3743567	et	0	main
vead	doc_491521501756_item	3743568	et	0	main
pronoomeni	doc_491521501756_item	3743569	et	0	main
oma	doc_491521501756_item	3743570	et	0	main
põhifunktsioon	doc_491521501756_item	3743571	et	0	main
on	doc_491521501756_item	3743572	et	0	main
omastav	doc_491521501756_item	3743573	et	0	main
ja	doc_491521501756_item	3743574	et	0	main
enesekohases	doc_491521501756_item	3743575	et	0	main
tähenduses	doc_491521501756_item	3743576	et	0	main
esineb	doc_491521501756_item	3743577	et	0	main
ta	doc_491521501756_item	3743578	et	0	main
harva	doc_491521501756_item	3743579	et	0	main
pronoomeni	doc_491521501756_item	3743580	et	0	main
enese	doc_491521501756_item	3743581	et	0	main
enda	doc_491521501756_item	3743582	et	0	main
asendamine	doc_491521501756_item	3743583	et	0	main
pronoomeniga	doc_491521501756_item	3743584	et	0	main
oma	doc_491521501756_item	3743585	et	0	main
on	doc_491521501756_item	3743586	et	0	main
võimalik	doc_491521501756_item	3743587	et	0	main
peamiselt	doc_491521501756_item	3743588	et	0	main
omastavas	doc_491521501756_item	3743589	et	0	main
käändes	doc_491521501756_item	3743590	et	0	main
või	doc_491521501756_item	3743591	et	0	main
väliskohakäänetes	doc_491521501756_item	3743592	et	0	main
kui	doc_491521501756_item	3743593	et	0	main
enesekohase	doc_491521501756_item	3743594	et	0	main
tähendusele	doc_491521501756_item	3743595	et	0	main
lisandub	doc_491521501756_item	3743596	et	0	main
omamistähendus	doc_491521501756_item	3743597	et	0	main
nt	doc_491521501756_item	3743598	et	0	main
vanemad	doc_491521501756_item	3743599	et	0	main
said	doc_491521501756_item	3743600	et	0	main
omale	doc_491521501756_item	3743601	et	0	main
mitte	doc_491521501756_item	3743602	et	0	main
endale	doc_491521501756_item	3743603	et	0	main
hea	doc_491521501756_item	3743604	et	0	main
sõbra	doc_491521501756_item	3743605	et	0	main
artur	doc_491521501756_item	3743606	et	0	main
laskis	doc_491521501756_item	3743607	et	0	main
omal	doc_491521501756_item	3743608	et	0	main
mitte	doc_491521501756_item	3743609	et	0	main
enesel	doc_491521501756_item	3743610	et	0	main
pea	doc_491521501756_item	3743611	et	0	main
paljaks	doc_491521501756_item	3743612	et	0	main
ajada	doc_491521501756_item	3743613	et	0	main
lõunaeestilist	doc_491521501756_item	3743614	et	0	main
päritolu	doc_491521501756_item	3743615	et	0	main
asesõna	doc_491521501756_item	3743616	et	0	main
too	doc_491521501756_item	3743617	et	0	main
ei	doc_491521501756_item	3743618	et	0	main
ole	doc_491521501756_item	3743619	et	0	main
tuttav	doc_491521501756_item	3743620	et	0	main
õpilased	doc_491521501756_item	3743621	et	0	main
ei	doc_491521501756_item	3743622	et	0	main
oska	doc_491521501756_item	3743623	et	0	main
seda	doc_491521501756_item	3743624	et	0	main
kirjutada	doc_491521501756_item	3743625	et	0	main
sest	doc_491521501756_item	3743626	et	0	main
asesõna	doc_491521501756_item	3743627	et	0	main
too	doc_491521501756_item	3743628	et	0	main
kasutatakse	doc_491521501756_item	3743629	et	0	main
viitamaks	doc_491521501756_item	3743630	et	0	main
kõnelejast	doc_491521501756_item	3743631	et	0	main
ruumis	doc_491521501756_item	3743632	et	0	main
ja	doc_491521501756_item	3743633	et	0	main
ajas	doc_491521501756_item	3743634	et	0	main
kaugemal	doc_491521501756_item	3743635	et	0	main
paiknevale	doc_491521501756_item	3743636	et	0	main
nt	doc_491521501756_item	3743637	et	0	main
too	doc_491521501756_item	3743638	et	0	main
seal	doc_491521501756_item	3743639	et	0	main
on	doc_491521501756_item	3743640	et	0	main
minu	doc_491521501756_item	3743641	et	0	main
auto	doc_491521501756_item	3743642	et	0	main
mitte	doc_491521501756_item	3743643	et	0	main
too	doc_491521501756_item	3743644	et	0	main
siin	doc_491521501756_item	3743645	et	0	main
on	doc_491521501756_item	3743646	et	0	main
minu	doc_491521501756_item	3743647	et	0	main
auto	doc_491521501756_item	3743648	et	0	main
tol	doc_491521501756_item	3743649	et	0	main
aastal	doc_491521501756_item	3743650	et	0	main
oli	doc_491521501756_item	3743651	et	0	main
maria	doc_491521501756_item	3743652	et	0	main
väga	doc_491521501756_item	3743653	et	0	main
paks	doc_491521501756_item	3743654	et	0	main
mitte	doc_491521501756_item	3743655	et	0	main
tol	doc_491521501756_item	3743656	et	0	main
aastal	doc_491521501756_item	3743657	et	0	main
on	doc_491521501756_item	3743658	et	0	main
maria	doc_491521501756_item	3743659	et	0	main
väga	doc_491521501756_item	3743660	et	0	main
paks	doc_491521501756_item	3743661	et	0	main
sidesõna	doc_491521501756_item	3743662	et	0	main
vahetatakse	doc_491521501756_item	3743663	et	0	main
ara	doc_491521501756_item	3743664	et	0	main
küsisõnaga	doc_491521501756_item	3743665	et	0	main
nt	doc_491521501756_item	3743666	et	0	main
jõudsin	doc_491521501756_item	3743667	et	0	main
koju	doc_491521501756_item	3743668	et	0	main
kui	doc_491521501756_item	3743669	et	0	main
mitte	doc_491521501756_item	3743670	et	0	main
millal	doc_491521501756_item	3743671	et	0	main
vanemad	doc_491521501756_item	3743672	et	0	main
olid	doc_491521501756_item	3743673	et	0	main
kodus	doc_491521501756_item	3743674	et	0	main
noortesaadetes	doc_491521501756_item	3743675	et	0	main
on	doc_491521501756_item	3743676	et	0	main
huvitavaid	doc_491521501756_item	3743677	et	0	main
asju	doc_491521501756_item	3743678	et	0	main
kui	doc_491521501756_item	3743679	et	0	main
mitte	doc_491521501756_item	3743680	et	0	main
millal	doc_491521501756_item	3743681	et	0	main
noored	doc_491521501756_item	3743682	et	0	main
räägivad	doc_491521501756_item	3743683	et	0	main
oma	doc_491521501756_item	3743684	et	0	main
probleemidest	doc_491521501756_item	3743685	et	0	main
lühike	doc_491521501756_item	3743686	et	0	main
sisseütlev	doc_491521501756_item	3743687	et	0	main
jääb	doc_491521501756_item	3743688	et	0	main
halvasti	doc_491521501756_item	3743689	et	0	main
meelde	doc_491521501756_item	3743690	et	0	main
õpilastele	doc_491521501756_item	3743691	et	0	main
on	doc_491521501756_item	3743692	et	0	main
kergem	doc_491521501756_item	3743693	et	0	main
öelda	doc_491521501756_item	3743694	et	0	main
nt	doc_491521501756_item	3743695	et	0	main
toasse	doc_491521501756_item	3743696	et	0	main
õige	doc_491521501756_item	3743697	et	0	main
tuppa	doc_491521501756_item	3743698	et	0	main
metsasse	doc_491521501756_item	3743699	et	0	main
õige	doc_491521501756_item	3743700	et	0	main
metsa	doc_491521501756_item	3743701	et	0	main
köögisse	doc_491521501756_item	3743702	et	0	main
õige	doc_491521501756_item	3743703	et	0	main
kööki	doc_491521501756_item	3743704	et	0	main
suusse	doc_491521501756_item	3743705	et	0	main
õige	doc_491521501756_item	3743706	et	0	main
suhu	doc_491521501756_item	3743707	et	0	main
pesasse	doc_491521501756_item	3743708	et	0	main
õige	doc_491521501756_item	3743709	et	0	main
pessa	doc_491521501756_item	3743710	et	0	main
aetakse	doc_491521501756_item	3743711	et	0	main
segi	doc_491521501756_item	3743712	et	0	main
omastav	doc_491521501756_item	3743713	et	0	main
ja	doc_491521501756_item	3743714	et	0	main
osastav	doc_491521501756_item	3743715	et	0	main
kääne	doc_491521501756_item	3743716	et	0	main
lõpetatud	doc_491521501756_item	3743717	et	0	main
ja	doc_491521501756_item	3743718	et	0	main
lõpetamata	doc_491521501756_item	3743719	et	0	main
tegevus	doc_491521501756_item	3743720	et	0	main
nt	doc_491521501756_item	3743721	et	0	main
kõik	doc_491521501756_item	3743722	et	0	main
kuulsid	doc_491521501756_item	3743723	et	0	main
raadiot	doc_491521501756_item	3743724	et	0	main
mitte	doc_491521501756_item	3743725	et	0	main
kõik	doc_491521501756_item	3743726	et	0	main
kuulsid	doc_491521501756_item	3743727	et	0	main
raadio	doc_491521501756_item	3743728	et	0	main
mart	doc_491521501756_item	3743729	et	0	main
luges	doc_491521501756_item	3743730	et	0	main
raamatut	doc_491521501756_item	3743731	et	0	main
mitte	doc_491521501756_item	3743732	et	0	main
mart	doc_491521501756_item	3743733	et	0	main
luges	doc_491521501756_item	3743734	et	0	main
raamatu	doc_491521501756_item	3743735	et	0	main
kui	doc_491521501756_item	3743736	et	0	main
on	doc_491521501756_item	3743737	et	0	main
osasihitis	doc_491521501756_item	3743738	et	0	main
õ	doc_491521501756_item	3743739	et	0	main
petaja	doc_491521501756_item	3743740	et	0	main
luges	doc_491521501756_item	3743741	et	0	main
raamatu	doc_491521501756_item	3743742	et	0	main
mitte	doc_491521501756_item	3743743	et	0	main
õpetaja	doc_491521501756_item	3743744	et	0	main
luges	doc_491521501756_item	3743745	et	0	main
raamatut	doc_491521501756_item	3743746	et	0	main
kui	doc_491521501756_item	3743747	et	0	main
lõpetatud	doc_491521501756_item	3743748	et	0	main
tegevus	doc_491521501756_item	3743749	et	0	main
mulle	doc_491521501756_item	3743750	et	0	main
meeldib	doc_491521501756_item	3743751	et	0	main
kuulata	doc_491521501756_item	3743752	et	0	main
head	doc_491521501756_item	3743753	et	0	main
muusikat	doc_491521501756_item	3743754	et	0	main
mitte	doc_491521501756_item	3743755	et	0	main
mulle	doc_491521501756_item	3743756	et	0	main
meeldib	doc_491521501756_item	3743757	et	0	main
kuulata	doc_491521501756_item	3743758	et	0	main
hea	doc_491521501756_item	3743759	et	0	main
muusika	doc_491521501756_item	3743760	et	0	main
ainsuse	doc_491521501756_item	3743761	et	0	main
osastava	doc_491521501756_item	3743762	et	0	main
moodustamine	doc_491521501756_item	3743763	et	0	main
on	doc_491521501756_item	3743764	et	0	main
raske	doc_491521501756_item	3743765	et	0	main
sest	doc_491521501756_item	3743766	et	0	main
osastava	doc_491521501756_item	3743767	et	0	main
käände	doc_491521501756_item	3743768	et	0	main
tunnused	doc_491521501756_item	3743769	et	0	main
on	doc_491521501756_item	3743770	et	0	main
neli	doc_491521501756_item	3743771	et	0	main
morfeemvarianti	doc_491521501756_item	3743772	et	0	main
t	doc_491521501756_item	3743773	et	0	main
d	doc_491521501756_item	3743774	et	0	main
ja	doc_491521501756_item	3743775	et	0	main
da	doc_491521501756_item	3743776	et	0	main
kusjuures	doc_491521501756_item	3743777	et	0	main
valik	doc_491521501756_item	3743778	et	0	main
sõltub	doc_491521501756_item	3743779	et	0	main
sõnatüübist	doc_491521501756_item	3743780	et	0	main
nt	doc_491521501756_item	3743781	et	0	main
kollane	doc_491521501756_item	3743782	et	0	main
kollase	doc_491521501756_item	3743783	et	0	main
kollast	doc_491521501756_item	3743784	et	0	main
mitte	doc_491521501756_item	3743785	et	0	main
kollaset	doc_491521501756_item	3743786	et	0	main
suur	doc_491521501756_item	3743787	et	0	main
suure	doc_491521501756_item	3743788	et	0	main
suurt	doc_491521501756_item	3743789	et	0	main
mitte	doc_491521501756_item	3743790	et	0	main
suuret	doc_491521501756_item	3743791	et	0	main
küünal	doc_491521501756_item	3743792	et	0	main
küünla	doc_491521501756_item	3743793	et	0	main
küünalt	doc_491521501756_item	3743794	et	0	main
mitte	doc_491521501756_item	3743795	et	0	main
küünlat	doc_491521501756_item	3743796	et	0	main
ema	doc_491521501756_item	3743797	et	0	main
ema	doc_491521501756_item	3743798	et	0	main
ema	doc_491521501756_item	3743799	et	0	main
mitte	doc_491521501756_item	3743800	et	0	main
emat	doc_491521501756_item	3743801	et	0	main
kaks	doc_491521501756_item	3743802	et	0	main
kahe	doc_491521501756_item	3743803	et	0	main
kaht	doc_491521501756_item	3743804	et	0	main
mitte	doc_491521501756_item	3743805	et	0	main
kahet	doc_491521501756_item	3743806	et	0	main
mitmuse	doc_491521501756_item	3743807	et	0	main
osastava	doc_491521501756_item	3743808	et	0	main
moodustamine	doc_491521501756_item	3743809	et	0	main
on	doc_491521501756_item	3743810	et	0	main
eriti	doc_491521501756_item	3743811	et	0	main
raske	doc_491521501756_item	3743812	et	0	main
kus	doc_491521501756_item	3743813	et	0	main
õpilased	doc_491521501756_item	3743814	et	0	main
teevad	doc_491521501756_item	3743815	et	0	main
palju	doc_491521501756_item	3743816	et	0	main
vigu	doc_491521501756_item	3743817	et	0	main
nendel	doc_491521501756_item	3743818	et	0	main
on	doc_491521501756_item	3743819	et	0	main
raske	doc_491521501756_item	3743820	et	0	main
vahet	doc_491521501756_item	3743821	et	0	main
teha	doc_491521501756_item	3743822	et	0	main
i	doc_491521501756_item	3743823	et	0	main
ja	doc_491521501756_item	3743824	et	0	main
sid	doc_491521501756_item	3743825	et	0	main
lõpude	doc_491521501756_item	3743826	et	0	main
vahel	doc_491521501756_item	3743827	et	0	main
nt	doc_491521501756_item	3743828	et	0	main
mõtteid	doc_491521501756_item	3743829	et	0	main
mitte	doc_491521501756_item	3743830	et	0	main
mõttesid	doc_491521501756_item	3743831	et	0	main
siile	doc_491521501756_item	3743832	et	0	main
mitte	doc_491521501756_item	3743833	et	0	main
siileid	doc_491521501756_item	3743834	et	0	main
sõprusid	doc_491521501756_item	3743835	et	0	main
mittesõpraid	doc_491521501756_item	3743836	et	0	main
koerasid	doc_491521501756_item	3743837	et	0	main
mitte	doc_491521501756_item	3743838	et	0	main
koeraid	doc_491521501756_item	3743839	et	0	main
lihtminevikku	doc_491521501756_item	3743840	et	0	main
on	doc_491521501756_item	3743841	et	0	main
raskem	doc_491521501756_item	3743842	et	0	main
moodustada	doc_491521501756_item	3743843	et	0	main
kui	doc_491521501756_item	3743844	et	0	main
täisminevikku	doc_491521501756_item	3743845	et	0	main
nt	doc_491521501756_item	3743846	et	0	main
loodan	doc_491521501756_item	3743847	et	0	main
et	doc_491521501756_item	3743848	et	0	main
pühapäeva	doc_491521501756_item	3743849	et	0	main
õhtuks	doc_491521501756_item	3743850	et	0	main
oled	doc_491521501756_item	3743851	et	0	main
sa	doc_491521501756_item	3743852	et	0	main
selle	doc_491521501756_item	3743853	et	0	main
töö	doc_491521501756_item	3743854	et	0	main
lõpetanud	doc_491521501756_item	3743855	et	0	main
mitte	doc_491521501756_item	3743856	et	0	main
loodan	doc_491521501756_item	3743857	et	0	main
et	doc_491521501756_item	3743858	et	0	main
pühapäeva	doc_491521501756_item	3743859	et	0	main
õhtuks	doc_491521501756_item	3743860	et	0	main
sa	doc_491521501756_item	3743861	et	0	main
selle	doc_491521501756_item	3743862	et	0	main
töö	doc_491521501756_item	3743863	et	0	main
lõpetanud	doc_491521501756_item	3743864	et	0	main
mari	doc_491521501756_item	3743865	et	0	main
oli	doc_491521501756_item	3743866	et	0	main
kõvasti	doc_491521501756_item	3743867	et	0	main
tööd	doc_491521501756_item	3743868	et	0	main
teinud	doc_491521501756_item	3743869	et	0	main
mitte	doc_491521501756_item	3743870	et	0	main
mari	doc_491521501756_item	3743871	et	0	main
kõvasti	doc_491521501756_item	3743872	et	0	main
tööd	doc_491521501756_item	3743873	et	0	main
teinud	doc_491521501756_item	3743874	et	0	main
mul	doc_491521501756_item	3743875	et	0	main
ei	doc_491521501756_item	3743876	et	0	main
olnud	doc_491521501756_item	3743877	et	0	main
vaba	doc_491521501756_item	3743878	et	0	main
aega	doc_491521501756_item	3743879	et	0	main
mitte	doc_491521501756_item	3743880	et	0	main
mul	doc_491521501756_item	3743881	et	0	main
ei	doc_491521501756_item	3743882	et	0	main
oli	doc_491521501756_item	3743883	et	0	main
vaba	doc_491521501756_item	3743884	et	0	main
aega	doc_491521501756_item	3743885	et	0	main
tingiv	doc_491521501756_item	3743886	et	0	main
kõneviis	doc_491521501756_item	3743887	et	0	main
on	doc_491521501756_item	3743888	et	0	main
õpilastele	doc_491521501756_item	3743889	et	0	main
tavaliselt	doc_491521501756_item	3743890	et	0	main
selge	doc_491521501756_item	3743891	et	0	main
kui	doc_491521501756_item	3743892	et	0	main
moodustamise	doc_491521501756_item	3743893	et	0	main
teeb	doc_491521501756_item	3743894	et	0	main
raskeks	doc_491521501756_item	3743895	et	0	main
laadivaheldus	doc_491521501756_item	3743896	et	0	main
tingiva	doc_491521501756_item	3743897	et	0	main
kõneviisi	doc_491521501756_item	3743898	et	0	main
tunnusel	doc_491521501756_item	3743899	et	0	main
on	doc_491521501756_item	3743900	et	0	main
kaks	doc_491521501756_item	3743901	et	0	main
kuju	doc_491521501756_item	3743902	et	0	main
ksi	doc_491521501756_item	3743903	et	0	main
kui	doc_491521501756_item	3743904	et	0	main
järgneb	doc_491521501756_item	3743905	et	0	main
pöördetunnus	doc_491521501756_item	3743906	et	0	main
nt	doc_491521501756_item	3743907	et	0	main
tahaksin	doc_491521501756_item	3743908	et	0	main
ja	doc_491521501756_item	3743909	et	0	main
ks	doc_491521501756_item	3743910	et	0	main
sõna	doc_491521501756_item	3743911	et	0	main
lõpus	doc_491521501756_item	3743912	et	0	main
nt	doc_491521501756_item	3743913	et	0	main
elaks	doc_491521501756_item	3743914	et	0	main
nt	doc_491521501756_item	3743915	et	0	main
teeksime	doc_491521501756_item	3743916	et	0	main
mitte	doc_491521501756_item	3743917	et	0	main
tegiksime	doc_491521501756_item	3743918	et	0	main
peseksin	doc_491521501756_item	3743919	et	0	main
mitte	doc_491521501756_item	3743920	et	0	main
pestaksin	doc_491521501756_item	3743921	et	0	main
puhkaksime	doc_491521501756_item	3743922	et	0	main
mitte	doc_491521501756_item	3743923	et	0	main
puhaksime	doc_491521501756_item	3743924	et	0	main
õ	doc_491521501756_item	3743925	et	0	main
mbleksin	doc_491521501756_item	3743926	et	0	main
mitte	doc_491521501756_item	3743927	et	0	main
õmmeldaksin	doc_491521501756_item	3743928	et	0	main
umbisikuline	doc_491521501756_item	3743929	et	0	main
tegumood	doc_491521501756_item	3743930	et	0	main
on	doc_491521501756_item	3743931	et	0	main
raske	doc_491521501756_item	3743932	et	0	main
eriti	doc_491521501756_item	3743933	et	0	main
t	doc_491521501756_item	3743934	et	0	main
ä	doc_491521501756_item	3743935	et	0	main
isminevikus	doc_491521501756_item	3743936	et	0	main
nt	doc_491521501756_item	3743937	et	0	main
pildil	doc_491521501756_item	3743938	et	0	main
on	doc_491521501756_item	3743939	et	0	main
kujutatud	doc_491521501756_item	3743940	et	0	main
mitte	doc_491521501756_item	3743941	et	0	main
pildil	doc_491521501756_item	3743942	et	0	main
on	doc_491521501756_item	3743943	et	0	main
kujutanud	doc_491521501756_item	3743944	et	0	main
õunad	doc_491521501756_item	3743945	et	0	main
ja	doc_491521501756_item	3743946	et	0	main
pirnid	doc_491521501756_item	3743947	et	0	main
kui	doc_491521501756_item	3743948	et	0	main
töö	doc_491521501756_item	3743949	et	0	main
on	doc_491521501756_item	3743950	et	0	main
tehtud	doc_491521501756_item	3743951	et	0	main
mitte	doc_491521501756_item	3743952	et	0	main
kui	doc_491521501756_item	3743953	et	0	main
töö	doc_491521501756_item	3743954	et	0	main
on	doc_491521501756_item	3743955	et	0	main
tehnud	doc_491521501756_item	3743956	et	0	main
võib	doc_491521501756_item	3743957	et	0	main
minna	doc_491521501756_item	3743958	et	0	main
koju	doc_491521501756_item	3743959	et	0	main
umbisikulise	doc_491521501756_item	3743960	et	0	main
tegumoe	doc_491521501756_item	3743961	et	0	main
olevikus	doc_491521501756_item	3743962	et	0	main
tekitab	doc_491521501756_item	3743963	et	0	main
segadust	doc_491521501756_item	3743964	et	0	main
silpide	doc_491521501756_item	3743965	et	0	main
kordus	doc_491521501756_item	3743966	et	0	main
nt	doc_491521501756_item	3743967	et	0	main
veetakse	doc_491521501756_item	3743968	et	0	main
mitte	doc_491521501756_item	3743969	et	0	main
vedakse	doc_491521501756_item	3743970	et	0	main
ostetakse	doc_491521501756_item	3743971	et	0	main
mitte	doc_491521501756_item	3743972	et	0	main
ostakse	doc_491521501756_item	3743973	et	0	main
tahetakse	doc_491521501756_item	3743974	et	0	main
mitte	doc_491521501756_item	3743975	et	0	main
tahakse	doc_491521501756_item	3743976	et	0	main
murtakse	doc_491521501756_item	3743977	et	0	main
mitte	doc_491521501756_item	3743978	et	0	main
murdatakse	doc_491521501756_item	3743979	et	0	main
eriti	doc_491521501756_item	3743980	et	0	main
ebaselge	doc_491521501756_item	3743981	et	0	main
on	doc_491521501756_item	3743982	et	0	main
1	doc_491521501756_item	3743983	et	0	main
pöördkonna	doc_491521501756_item	3743984	et	0	main
jooma-tüübis	doc_491521501756_item	3743985	et	0	main
toimuv	doc_491521501756_item	3743986	et	0	main
formatiivi	doc_491521501756_item	3743987	et	0	main
akse	doc_491521501756_item	3743988	et	0	main
ees	doc_491521501756_item	3743989	et	0	main
vokaaliteisendus	doc_491521501756_item	3743990	et	0	main
oo-uu	doc_491521501756_item	3743991	et	0	main
või	doc_491521501756_item	3743992	et	0	main
öö-üü	doc_491521501756_item	3743993	et	0	main
nt	doc_491521501756_item	3743994	et	0	main
jooma	doc_491521501756_item	3743995	et	0	main
juuakse	doc_491521501756_item	3743996	et	0	main
mitte	doc_491521501756_item	3743997	et	0	main
joodakse	doc_491521501756_item	3743998	et	0	main
sööma	doc_491521501756_item	3743999	et	0	main
süüakse	doc_491521501756_item	3744000	et	0	main
mitte	doc_491521501756_item	3744001	et	0	main
söödakse	doc_491521501756_item	3744002	et	0	main
lööma	doc_491521501756_item	3744003	et	0	main
lüüakse	doc_491521501756_item	3744004	et	0	main
mitte	doc_491521501756_item	3744005	et	0	main
löödakse	doc_491521501756_item	3744006	et	0	main
tooma	doc_491521501756_item	3744007	et	0	main
tuuakse	doc_491521501756_item	3744008	et	0	main
mitte	doc_491521501756_item	3744009	et	0	main
toodakse	doc_491521501756_item	3744010	et	0	main
ma-	doc_491521501756_item	3744011	et	0	main
ja	doc_491521501756_item	3744012	et	0	main
da-	doc_491521501756_item	3744013	et	0	main
tegevusnime	doc_491521501756_item	3744014	et	0	main
kasutamine	doc_491521501756_item	3744015	et	0	main
on	doc_491521501756_item	3744016	et	0	main
üks	doc_491521501756_item	3744017	et	0	main
raskematest	doc_491521501756_item	3744018	et	0	main
ülesannetest	doc_491521501756_item	3744019	et	0	main
sest	doc_491521501756_item	3744020	et	0	main
ma	doc_491521501756_item	3744021	et	0	main
infinitiivi	doc_491521501756_item	3744022	et	0	main
tegusõna	doc_491521501756_item	3744023	et	0	main
lõpus	doc_491521501756_item	3744024	et	0	main
ma	doc_491521501756_item	3744025	et	0	main
kasutame	doc_491521501756_item	3744026	et	0	main
koos	doc_491521501756_item	3744027	et	0	main
sõnadega	doc_491521501756_item	3744028	et	0	main
употребляем	doc_491521501756_item	3744029	et	0	main
с	doc_491521501756_item	3744030	et	0	main
глаголами	doc_491521501756_item	3744031	et	0	main
движения	doc_491521501756_item	3744032	et	0	main
начала	doc_491521501756_item	3744033	et	0	main
действия	doc_491521501756_item	3744034	et	0	main
необходимости	doc_491521501756_item	3744035	et	0	main
действия	doc_491521501756_item	3744036	et	0	main
aga	doc_491521501756_item	3744037	et	0	main
da	doc_491521501756_item	3744038	et	0	main
infinitiivi	doc_491521501756_item	3744039	et	0	main
tegusõna	doc_491521501756_item	3744040	et	0	main
lõpus	doc_491521501756_item	3744041	et	0	main
da	doc_491521501756_item	3744042	et	0	main
ta	doc_491521501756_item	3744043	et	0	main
a	doc_491521501756_item	3744044	et	0	main
kasutame	doc_491521501756_item	3744045	et	0	main
koos	doc_491521501756_item	3744046	et	0	main
sõnadega	doc_491521501756_item	3744047	et	0	main
употребляем	doc_491521501756_item	3744048	et	0	main
с	doc_491521501756_item	3744049	et	0	main
глаголами	doc_491521501756_item	3744050	et	0	main
выражающими	doc_491521501756_item	3744051	et	0	main
чувства	doc_491521501756_item	3744052	et	0	main
отношение	doc_491521501756_item	3744053	et	0	main
к	doc_491521501756_item	3744054	et	0	main
действию	doc_491521501756_item	3744055	et	0	main
в	doc_491521501756_item	3744056	et	0	main
конструкциях	doc_491521501756_item	3744057	et	0	main
с	doc_491521501756_item	3744058	et	0	main
on	doc_491521501756_item	3744059	et	0	main
nt	doc_491521501756_item	3744060	et	0	main
oskab	doc_491521501756_item	3744061	et	0	main
arvestada	doc_491521501756_item	3744062	et	0	main
mitte	doc_491521501756_item	3744063	et	0	main
arvestama	doc_491521501756_item	3744064	et	0	main
meeldib	doc_491521501756_item	3744065	et	0	main
kuulata	doc_491521501756_item	3744066	et	0	main
mitte	doc_491521501756_item	3744067	et	0	main
kuulama	doc_491521501756_item	3744068	et	0	main
on	doc_491521501756_item	3744069	et	0	main
vaja	doc_491521501756_item	3744070	et	0	main
teha	doc_491521501756_item	3744071	et	0	main
mitte	doc_491521501756_item	3744072	et	0	main
tegema	doc_491521501756_item	3744073	et	0	main
tuleb	doc_491521501756_item	3744074	et	0	main
tarvitseda	doc_491521501756_item	3744075	et	0	main
mitte	doc_491521501756_item	3744076	et	0	main
tarvitsema	doc_491521501756_item	3744077	et	0	main
olen	doc_491521501756_item	3744078	et	0	main
nõus	doc_491521501756_item	3744079	et	0	main
tantsima	doc_491521501756_item	3744080	et	0	main
mitte	doc_491521501756_item	3744081	et	0	main
tantsida	doc_491521501756_item	3744082	et	0	main
valmis	doc_491521501756_item	3744083	et	0	main
minema	doc_491521501756_item	3744084	et	0	main
mitte	doc_491521501756_item	3744085	et	0	main
minna	doc_491521501756_item	3744086	et	0	main
võib	doc_491521501756_item	3744087	et	0	main
kirjutada	doc_491521501756_item	3744088	et	0	main
mitte	doc_491521501756_item	3744089	et	0	main
kirjutama	doc_491521501756_item	3744090	et	0	main
alustan	doc_491521501756_item	3744091	et	0	main
puhkama	doc_491521501756_item	3744092	et	0	main
mitte	doc_491521501756_item	3744093	et	0	main
puhata	doc_491521501756_item	3744094	et	0	main
pani	doc_491521501756_item	3744095	et	0	main
meid	doc_491521501756_item	3744096	et	0	main
kirja	doc_491521501756_item	3744097	et	0	main
kirjutama	doc_491521501756_item	3744098	et	0	main
mitte	doc_491521501756_item	3744099	et	0	main
kirjutada	doc_491521501756_item	3744100	et	0	main
ta	doc_491521501756_item	3744101	et	0	main
hakkas	doc_491521501756_item	3744102	et	0	main
laulma	doc_491521501756_item	3744103	et	0	main
mitte	doc_491521501756_item	3744104	et	0	main
laulda	doc_491521501756_item	3744105	et	0	main
läksime	doc_491521501756_item	3744106	et	0	main
sööma	doc_491521501756_item	3744107	et	0	main
mitte	doc_491521501756_item	3744108	et	0	main
süüa	doc_491521501756_item	3744109	et	0	main
armastan	doc_491521501756_item	3744110	et	0	main
töötada	doc_491521501756_item	3744111	et	0	main
mitte	doc_491521501756_item	3744112	et	0	main
töötama	doc_491521501756_item	3744113	et	0	main
rektsioone	doc_491521501756_item	3744114	et	0	main
milles	doc_491521501756_item	3744115	et	0	main
sageli	doc_491521501756_item	3744116	et	0	main
eksitakse	doc_491521501756_item	3744117	et	0	main
ühildumine	doc_491521501756_item	3744118	et	0	main
ei	doc_491521501756_item	3744119	et	0	main
vasta	doc_491521501756_item	3744120	et	0	main
eesti	doc_491521501756_item	3744121	et	0	main
keele	doc_491521501756_item	3744122	et	0	main
reeglitele	doc_491521501756_item	3744123	et	0	main
nt	doc_491521501756_item	3744124	et	0	main
huvi	doc_491521501756_item	3744125	et	0	main
tundma	doc_491521501756_item	3744126	et	0	main
mille	doc_491521501756_item	3744127	et	0	main
vastu	doc_491521501756_item	3744128	et	0	main
mitte	doc_491521501756_item	3744129	et	0	main
mille	doc_491521501756_item	3744130	et	0	main
pärast	doc_491521501756_item	3744131	et	0	main
kaasnema	doc_491521501756_item	3744132	et	0	main
millega	doc_491521501756_item	3744133	et	0	main
mitte	doc_491521501756_item	3744134	et	0	main
millele	doc_491521501756_item	3744135	et	0	main
käima	doc_491521501756_item	3744136	et	0	main
kus	doc_491521501756_item	3744137	et	0	main
mitte	doc_491521501756_item	3744138	et	0	main
kuhu	doc_491521501756_item	3744139	et	0	main
ostma	doc_491521501756_item	3744140	et	0	main
kust	doc_491521501756_item	3744141	et	0	main
mitte	doc_491521501756_item	3744142	et	0	main
kus	doc_491521501756_item	3744143	et	0	main
kuulatama	doc_491521501756_item	3744144	et	0	main
kellele	doc_491521501756_item	3744145	et	0	main
millele	doc_491521501756_item	3744146	et	0	main
mitte	doc_491521501756_item	3744147	et	0	main
keda	doc_491521501756_item	3744148	et	0	main
mida	doc_491521501756_item	3744149	et	0	main
jätma	doc_491521501756_item	3744150	et	0	main
kuhu	doc_491521501756_item	3744151	et	0	main
mitte	doc_491521501756_item	3744152	et	0	main
kus	doc_491521501756_item	3744153	et	0	main
aitama	doc_491521501756_item	3744154	et	0	main
keda	doc_491521501756_item	3744155	et	0	main
mida	doc_491521501756_item	3744156	et	0	main
mitte	doc_491521501756_item	3744157	et	0	main
kellele	doc_491521501756_item	3744158	et	0	main
millele	doc_491521501756_item	3744159	et	0	main
häirima	doc_491521501756_item	3744160	et	0	main
keda	doc_491521501756_item	3744161	et	0	main
mida	doc_491521501756_item	3744162	et	0	main
mitte	doc_491521501756_item	3744163	et	0	main
kellele	doc_491521501756_item	3744164	et	0	main
millele	doc_491521501756_item	3744165	et	0	main
kahetsema	doc_491521501756_item	3744166	et	0	main
keda	doc_491521501756_item	3744167	et	0	main
mida	doc_491521501756_item	3744168	et	0	main
mitte	doc_491521501756_item	3744169	et	0	main
kelles	doc_491521501756_item	3744170	et	0	main
milles	doc_491521501756_item	3744171	et	0	main
põhinema	doc_491521501756_item	3744172	et	0	main
millel	doc_491521501756_item	3744173	et	0	main
mitte	doc_491521501756_item	3744174	et	0	main
millele	doc_491521501756_item	3744175	et	0	main
sarnanema	doc_491521501756_item	3744176	et	0	main
millega	doc_491521501756_item	3744177	et	0	main
mitte	doc_491521501756_item	3744178	et	0	main
millele	doc_491521501756_item	3744179	et	0	main
muganema	doc_491521501756_item	3744180	et	0	main
millega	doc_491521501756_item	3744181	et	0	main
mitte	doc_491521501756_item	3744182	et	0	main
millele	doc_491521501756_item	3744183	et	0	main
kohanema	doc_491521501756_item	3744184	et	0	main
millega	doc_491521501756_item	3744185	et	0	main
mitte	doc_491521501756_item	3744186	et	0	main
millele	doc_491521501756_item	3744187	et	0	main
harjuma	doc_491521501756_item	3744188	et	0	main
millega	doc_491521501756_item	3744189	et	0	main
mitte	doc_491521501756_item	3744190	et	0	main
millele	doc_491521501756_item	3744191	et	0	main
baseeruma	doc_491521501756_item	3744192	et	0	main
millel	doc_491521501756_item	3744193	et	0	main
mitte	doc_491521501756_item	3744194	et	0	main
millele	doc_491521501756_item	3744195	et	0	main
tuginema	doc_491521501756_item	3744196	et	0	main
millele	doc_491521501756_item	3744197	et	0	main
mitte	doc_491521501756_item	3744198	et	0	main
millel	doc_491521501756_item	3744199	et	0	main
ortograafia	doc_491521501756_item	3744200	et	0	main
vead	doc_491521501756_item	3744201	et	0	main
õigekirjas	doc_491521501756_item	3744202	et	0	main
ja	doc_491521501756_item	3744203	et	0	main
interpunktsioonis	doc_491521501756_item	3744204	et	0	main
nimisõnade	doc_491521501756_item	3744205	et	0	main
kokku-	doc_491521501756_item	3744206	et	0	main
ja	doc_491521501756_item	3744207	et	0	main
lahkukirjutamine	doc_491521501756_item	3744208	et	0	main
on	doc_491521501756_item	3744209	et	0	main
segane	doc_491521501756_item	3744210	et	0	main
õpilased	doc_491521501756_item	3744211	et	0	main
ei	doc_491521501756_item	3744212	et	0	main
erista	doc_491521501756_item	3744213	et	0	main
kas	doc_491521501756_item	3744214	et	0	main
on	doc_491521501756_item	3744215	et	0	main
tegemist	doc_491521501756_item	3744216	et	0	main
konkreetse	doc_491521501756_item	3744217	et	0	main
üksikjuhtumiga	doc_491521501756_item	3744218	et	0	main
siis	doc_491521501756_item	3744219	et	0	main
lahku	doc_491521501756_item	3744220	et	0	main
või	doc_491521501756_item	3744221	et	0	main
tegevusalaga	doc_491521501756_item	3744222	et	0	main
siis	doc_491521501756_item	3744223	et	0	main
kokku	doc_491521501756_item	3744224	et	0	main
nt	doc_491521501756_item	3744225	et	0	main
kingsepatöökoda	doc_491521501756_item	3744226	et	0	main
mitte	doc_491521501756_item	3744227	et	0	main
kingsepa	doc_491521501756_item	3744228	et	0	main
töökoda	doc_491521501756_item	3744229	et	0	main
olümpiapurjespordikeskus	doc_491521501756_item	3744230	et	0	main
mitte	doc_491521501756_item	3744231	et	0	main
olümpia	doc_491521501756_item	3744232	et	0	main
purjespordikeskus	doc_491521501756_item	3744233	et	0	main
põrandavärvimine	doc_491521501756_item	3744234	et	0	main
kui	doc_491521501756_item	3744235	et	0	main
tegevusala	doc_491521501756_item	3744236	et	0	main
vaibapuhastus	doc_491521501756_item	3744237	et	0	main
kui	doc_491521501756_item	3744238	et	0	main
tegevusala	doc_491521501756_item	3744239	et	0	main
kingaparandus	doc_491521501756_item	3744240	et	0	main
kui	doc_491521501756_item	3744241	et	0	main
tegevusala	doc_491521501756_item	3744242	et	0	main
arvsõnade	doc_491521501756_item	3744243	et	0	main
kokku-	doc_491521501756_item	3744244	et	0	main
ja	doc_491521501756_item	3744245	et	0	main
lahkukirjutamine	doc_491521501756_item	3744246	et	0	main
on	doc_491521501756_item	3744247	et	0	main
samuti	doc_491521501756_item	3744248	et	0	main
raske	doc_491521501756_item	3744249	et	0	main
nt	doc_491521501756_item	3744250	et	0	main
üheksasada	doc_491521501756_item	3744251	et	0	main
mitte	doc_491521501756_item	3744252	et	0	main
üheksa	doc_491521501756_item	3744253	et	0	main
sada	doc_491521501756_item	3744254	et	0	main
viis	doc_491521501756_item	3744255	et	0	main
tuhat	doc_491521501756_item	3744256	et	0	main
mitte	doc_491521501756_item	3744257	et	0	main
viistuhat	doc_491521501756_item	3744258	et	0	main
nelikümmend	doc_491521501756_item	3744259	et	0	main
kolm	doc_491521501756_item	3744260	et	0	main
mitte	doc_491521501756_item	3744261	et	0	main
neli	doc_491521501756_item	3744262	et	0	main
kümmend	doc_491521501756_item	3744263	et	0	main
kolm	doc_491521501756_item	3744264	et	0	main
kahetuhandes	doc_491521501756_item	3744265	et	0	main
mitte	doc_491521501756_item	3744266	et	0	main
kahe	doc_491521501756_item	3744267	et	0	main
tuhandes	doc_491521501756_item	3744268	et	0	main
kolm	doc_491521501756_item	3744269	et	0	main
miljonit	doc_491521501756_item	3744270	et	0	main
mitte	doc_491521501756_item	3744271	et	0	main
kolmmiljonit	doc_491521501756_item	3744272	et	0	main
kolmemiljoniline	doc_491521501756_item	3744273	et	0	main
mitte	doc_491521501756_item	3744274	et	0	main
kolme	doc_491521501756_item	3744275	et	0	main
miljoniline	doc_491521501756_item	3744276	et	0	main
pool	doc_491521501756_item	3744277	et	0	main
miljardit	doc_491521501756_item	3744278	et	0	main
mitte	doc_491521501756_item	3744279	et	0	main
poolmiljardit	doc_491521501756_item	3744280	et	0	main
poolemiljardik	doc_491521501756_item	3744281	et	0	main
mitte	doc_491521501756_item	3744282	et	0	main
poole	doc_491521501756_item	3744283	et	0	main
miljardik	doc_491521501756_item	3744284	et	0	main
süntaks	doc_491521501756_item	3744285	et	0	main
sõnajärg	doc_491521501756_item	3744286	et	0	main
ja	doc_491521501756_item	3744287	et	0	main
lauseehitus	doc_491521501756_item	3744288	et	0	main
on	doc_491521501756_item	3744289	et	0	main
vale	doc_491521501756_item	3744290	et	0	main
lauseehitus	doc_491521501756_item	3744291	et	0	main
on	doc_491521501756_item	3744292	et	0	main
eesti	doc_491521501756_item	3744293	et	0	main
keeles	doc_491521501756_item	3744294	et	0	main
suhteliselt	doc_491521501756_item	3744295	et	0	main
vaba	doc_491521501756_item	3744296	et	0	main
kuid	doc_491521501756_item	3744297	et	0	main
vale	doc_491521501756_item	3744298	et	0	main
sõnajärg	doc_491521501756_item	3744299	et	0	main
võib	doc_491521501756_item	3744300	et	0	main
omakorda	doc_491521501756_item	3744301	et	0	main
põhjustada	doc_491521501756_item	3744302	et	0	main
vigu	doc_491521501756_item	3744303	et	0	main
nt	doc_491521501756_item	3744304	et	0	main
kiiresti	doc_491521501756_item	3744305	et	0	main
lahkusid	doc_491521501756_item	3744306	et	0	main
õpilased	doc_491521501756_item	3744307	et	0	main
koolimajast	doc_491521501756_item	3744308	et	0	main
mitte	doc_491521501756_item	3744309	et	0	main
õpilased	doc_491521501756_item	3744310	et	0	main
kiiresti	doc_491521501756_item	3744311	et	0	main
lahkusid	doc_491521501756_item	3744312	et	0	main
koolimajast	doc_491521501756_item	3744313	et	0	main
kui	doc_491521501756_item	3744314	et	0	main
lause	doc_491521501756_item	3744315	et	0	main
algul	doc_491521501756_item	3744316	et	0	main
olevaks	doc_491521501756_item	3744317	et	0	main
verbilaiendiks	doc_491521501756_item	3744318	et	0	main
on	doc_491521501756_item	3744319	et	0	main
verbiga	doc_491521501756_item	3744320	et	0	main
tihedalt	doc_491521501756_item	3744321	et	0	main
seotud	doc_491521501756_item	3744322	et	0	main
viisimäärus	doc_491521501756_item	3744323	et	0	main
raamat	doc_491521501756_item	3744324	et	0	main
on	doc_491521501756_item	3744325	et	0	main
läbi	doc_491521501756_item	3744326	et	0	main
loetud	doc_491521501756_item	3744327	et	0	main
mitte	doc_491521501756_item	3744328	et	0	main
raamat	doc_491521501756_item	3744329	et	0	main
on	doc_491521501756_item	3744330	et	0	main
lugenud	doc_491521501756_item	3744331	et	0	main
läbi	doc_491521501756_item	3744332	et	0	main
infiniitverbi	doc_491521501756_item	3744333	et	0	main
laiendeil	doc_491521501756_item	3744334	et	0	main
on	doc_491521501756_item	3744335	et	0	main
asukoht	doc_491521501756_item	3744336	et	0	main
paikneda	doc_491521501756_item	3744337	et	0	main
tema	doc_491521501756_item	3744338	et	0	main
ees	doc_491521501756_item	3744339	et	0	main
raadiot	doc_491521501756_item	3744340	et	0	main
võib	doc_491521501756_item	3744341	et	0	main
kaasa	doc_491521501756_item	3744342	et	0	main
võtta	doc_491521501756_item	3744343	et	0	main
mitte	doc_491521501756_item	3744344	et	0	main
raadiot	doc_491521501756_item	3744345	et	0	main
kaasa	doc_491521501756_item	3744346	et	0	main
võib	doc_491521501756_item	3744347	et	0	main
võtta	doc_491521501756_item	3744348	et	0	main
ühildumise	doc_491521501756_item	3744349	et	0	main
vead	doc_491521501756_item	3744350	et	0	main
öeldistäite	doc_491521501756_item	3744351	et	0	main
ühildumine	doc_491521501756_item	3744352	et	0	main
alusega	doc_491521501756_item	3744353	et	0	main
õpilased	doc_491521501756_item	3744354	et	0	main
ei	doc_491521501756_item	3744355	et	0	main
tee	doc_491521501756_item	3744356	et	0	main
vahet	doc_491521501756_item	3744357	et	0	main
kas	doc_491521501756_item	3744358	et	0	main
alus	doc_491521501756_item	3744359	et	0	main
tähistab	doc_491521501756_item	3744360	et	0	main
ühte	doc_491521501756_item	3744361	et	0	main
siis	doc_491521501756_item	3744362	et	0	main
öeldistäide	doc_491521501756_item	3744363	et	0	main
ainsuses	doc_491521501756_item	3744364	et	0	main
või	doc_491521501756_item	3744365	et	0	main
alus	doc_491521501756_item	3744366	et	0	main
tähistab	doc_491521501756_item	3744367	et	0	main
mitut	doc_491521501756_item	3744368	et	0	main
siis	doc_491521501756_item	3744369	et	0	main
öeldistäide	doc_491521501756_item	3744370	et	0	main
mitmuses	doc_491521501756_item	3744371	et	0	main
nt	doc_491521501756_item	3744372	et	0	main
tangid	doc_491521501756_item	3744373	et	0	main
on	doc_491521501756_item	3744374	et	0	main
tööriist	doc_491521501756_item	3744375	et	0	main
mitte	doc_491521501756_item	3744376	et	0	main
tööriistad	doc_491521501756_item	3744377	et	0	main
pulmad	doc_491521501756_item	3744378	et	0	main
on	doc_491521501756_item	3744379	et	0	main
meeldejääv	doc_491521501756_item	3744380	et	0	main
sündmus	doc_491521501756_item	3744381	et	0	main
mitte	doc_491521501756_item	3744382	et	0	main
meeldejäävad	doc_491521501756_item	3744383	et	0	main
sündmused	doc_491521501756_item	3744384	et	0	main
elina	doc_491521501756_item	3744385	et	0	main
ja	doc_491521501756_item	3744386	et	0	main
karina	doc_491521501756_item	3744387	et	0	main
on	doc_491521501756_item	3744388	et	0	main
üliõpilased	doc_491521501756_item	3744389	et	0	main
mitte	doc_491521501756_item	3744390	et	0	main
üliõpilane	doc_491521501756_item	3744391	et	0	main
kokkuvõte	doc_491521501756_item	3744392	et	0	main
ei	doc_491521501756_item	3744393	et	0	main
saa	doc_491521501756_item	3744394	et	0	main
anda	doc_491521501756_item	3744395	et	0	main
ühtki	doc_491521501756_item	3744396	et	0	main
üldkehtivat	doc_491521501756_item	3744397	et	0	main
reeglit	doc_491521501756_item	3744398	et	0	main
kuidas	doc_491521501756_item	3744399	et	0	main
õpilaste	doc_491521501756_item	3744400	et	0	main
keelevigu	doc_491521501756_item	3744401	et	0	main
parandada	doc_491521501756_item	3744402	et	0	main
nagu	doc_491521501756_item	3744403	et	0	main
ei	doc_491521501756_item	3744404	et	0	main
ole	doc_491521501756_item	3744405	et	0	main
võimalik	doc_491521501756_item	3744406	et	0	main
anda	doc_491521501756_item	3744407	et	0	main
selgeid	doc_491521501756_item	3744408	et	0	main
reegleid	doc_491521501756_item	3744409	et	0	main
kuidas	doc_491521501756_item	3744410	et	0	main
õpetada	doc_491521501756_item	3744411	et	0	main
ja	doc_491521501756_item	3744412	et	0	main
õppida	doc_491521501756_item	3744413	et	0	main
iga	doc_491521501756_item	3744414	et	0	main
õpetaja	doc_491521501756_item	3744415	et	0	main
tahab	doc_491521501756_item	3744416	et	0	main
et	doc_491521501756_item	3744417	et	0	main
tema	doc_491521501756_item	3744418	et	0	main
õppijad	doc_491521501756_item	3744419	et	0	main
õpiksid	doc_491521501756_item	3744420	et	0	main
suhtlema	doc_491521501756_item	3744421	et	0	main
ja	doc_491521501756_item	3744422	et	0	main
tundma	doc_491521501756_item	3744423	et	0	main
end	doc_491521501756_item	3744424	et	0	main
vilunud	doc_491521501756_item	3744425	et	0	main
vestlejatena	doc_491521501756_item	3744426	et	0	main
õpetamine	doc_491521501756_item	3744427	et	0	main
peaks	doc_491521501756_item	3744428	et	0	main
olema	doc_491521501756_item	3744429	et	0	main
paindlik	doc_491521501756_item	3744430	et	0	main
et	doc_491521501756_item	3744431	et	0	main
sellest	doc_491521501756_item	3744432	et	0	main
oleks	doc_491521501756_item	3744433	et	0	main
abi	doc_491521501756_item	3744434	et	0	main
õppijatele	doc_491521501756_item	3744435	et	0	main
kes	doc_491521501756_item	3744436	et	0	main
ihkavad	doc_491521501756_item	3744437	et	0	main
vabalt	doc_491521501756_item	3744438	et	0	main
eksperimenteerida	doc_491521501756_item	3744439	et	0	main
kuid	doc_491521501756_item	3744440	et	0	main
ka	doc_491521501756_item	3744441	et	0	main
neile	doc_491521501756_item	3744442	et	0	main
kes	doc_491521501756_item	3744443	et	0	main
soovivad	doc_491521501756_item	3744444	et	0	main
turvalist	doc_491521501756_item	3744445	et	0	main
teadmist	doc_491521501756_item	3744446	et	0	main
mis	doc_491521501756_item	3744447	et	0	main
on	doc_491521501756_item	3744448	et	0	main
õige	doc_491521501756_item	3744449	et	0	main
ja	doc_491521501756_item	3744450	et	0	main
mis	doc_491521501756_item	3744451	et	0	main
vale	doc_491521501756_item	3744452	et	0	main
loodan	doc_491521501756_item	3744453	et	0	main
et	doc_491521501756_item	3744454	et	0	main
käesolev	doc_491521501756_item	3744455	et	0	main
vigade	doc_491521501756_item	3744456	et	0	main
analuüüs	doc_491521501756_item	3744457	et	0	main
pakub	doc_491521501756_item	3744458	et	0	main
õpetajatele	doc_491521501756_item	3744459	et	0	main
huvi	doc_491521501756_item	3744460	et	0	main
ja	doc_491521501756_item	3744461	et	0	main
teda	doc_491521501756_item	3744462	et	0	main
saab	doc_491521501756_item	3744463	et	0	main
praktikas	doc_491521501756_item	3744464	et	0	main
kasutada	doc_491521501756_item	3744465	et	0	main
kasutatud	doc_491521501756_item	3744466	et	0	main
kirjandus	doc_491521501756_item	3744467	et	0	main
1	doc_491521501756_item	3744468	et	0	main
kerge	doc_491521501756_item	3744469	et	0	main
krista	doc_491521501756_item	3744470	et	0	main
1996funktsionaalse	doc_491521501756_item	3744471	et	0	main
keeleoskuse	doc_491521501756_item	3744472	et	0	main
taseme	doc_491521501756_item	3744473	et	0	main
määratlemine	doc_491521501756_item	3744474	et	0	main
2kerge	doc_491521501756_item	3744475	et	0	main
krista	doc_491521501756_item	3744476	et	0	main
loog	doc_491521501756_item	3744477	et	0	main
mai	doc_491521501756_item	3744478	et	0	main
1999	doc_491521501756_item	3744479	et	0	main
tuul	doc_491521501756_item	3744480	et	0	main
tibades	doc_491521501756_item	3744481	et	0	main
tallinn	doc_491521501756_item	3744482	et	0	main
riiklik	doc_491521501756_item	3744483	et	0	main
eksami-	doc_491521501756_item	3744484	et	0	main
ja	doc_491521501756_item	3744485	et	0	main
kvalifikatsioonikeskus	doc_491521501756_item	3744486	et	0	main
analüüs	doc_491521501801_item	3744487	et	0	main
kontrastiivlingvistika	doc_491521501801_item	3744488	et	0	main
veaanalüüsi	doc_491521501801_item	3744489	et	0	main
kodutöö	doc_491521501801_item	3744490	et	0	main
antud	doc_491521501801_item	3744491	et	0	main
töö	doc_491521501801_item	3744492	et	0	main
vigade	doc_491521501801_item	3744493	et	0	main
analüüsist	doc_491521501801_item	3744494	et	0	main
on	doc_491521501801_item	3744495	et	0	main
pühendatud	doc_491521501801_item	3744496	et	0	main
õpilaste	doc_491521501801_item	3744497	et	0	main
hälbiva	doc_491521501801_item	3744498	et	0	main
eesti	doc_491521501801_item	3744499	et	0	main
keele	doc_491521501801_item	3744500	et	0	main
kasutamisele	doc_491521501801_item	3744501	et	0	main
analüüs	doc_491521501801_item	3744502	et	0	main
on	doc_491521501801_item	3744503	et	0	main
tehtud	doc_491521501801_item	3744504	et	0	main
õpilaste	doc_491521501801_item	3744505	et	0	main
antud	doc_491521501801_item	3744506	et	0	main
talvesemestri	doc_491521501801_item	3744507	et	0	main
kirjalikke	doc_491521501801_item	3744508	et	0	main
tööde	doc_491521501801_item	3744509	et	0	main
kirjandite	doc_491521501801_item	3744510	et	0	main
harjutuste	doc_491521501801_item	3744511	et	0	main
kontrolltööde	doc_491521501801_item	3744512	et	0	main
jt	doc_491521501801_item	3744513	et	0	main
põhjal	doc_491521501801_item	3744514	et	0	main
tegemist	doc_491521501801_item	3744515	et	0	main
on	doc_491521501801_item	3744516	et	0	main
9	doc_491521501801_item	3744517	et	0	main
klassi	doc_491521501801_item	3744518	et	0	main
õpilastega	doc_491521501801_item	3744519	et	0	main
selle	doc_491521501801_item	3744520	et	0	main
klassi	doc_491521501801_item	3744521	et	0	main
eesti	doc_491521501801_item	3744522	et	0	main
keele	doc_491521501801_item	3744523	et	0	main
õpetaja	doc_491521501801_item	3744524	et	0	main
sõnul	doc_491521501801_item	3744525	et	0	main
see	doc_491521501801_item	3744526	et	0	main
on	doc_491521501801_item	3744527	et	0	main
väga	doc_491521501801_item	3744528	et	0	main
nõrk	doc_491521501801_item	3744529	et	0	main
klass	doc_491521501801_item	3744530	et	0	main
klassis	doc_491521501801_item	3744531	et	0	main
on	doc_491521501801_item	3744532	et	0	main
ainult	doc_491521501801_item	3744533	et	0	main
kaks	doc_491521501801_item	3744534	et	0	main
viit	doc_491521501801_item	3744535	et	0	main
kolm-neli	doc_491521501801_item	3744536	et	0	main
nelja	doc_491521501801_item	3744537	et	0	main
ülejäänud	doc_491521501801_item	3744538	et	0	main
ainult	doc_491521501801_item	3744539	et	0	main
kolmed	doc_491521501801_item	3744540	et	0	main
ja	doc_491521501801_item	3744541	et	0	main
isegi	doc_491521501801_item	3744542	et	0	main
kahed	doc_491521501801_item	3744543	et	0	main
nagu	doc_491521501801_item	3744544	et	0	main
õpilaste	doc_491521501801_item	3744545	et	0	main
töödest	doc_491521501801_item	3744546	et	0	main
selgus	doc_491521501801_item	3744547	et	0	main
kõige	doc_491521501801_item	3744548	et	0	main
rohkem	doc_491521501801_item	3744549	et	0	main
raskusi	doc_491521501801_item	3744550	et	0	main
on	doc_491521501801_item	3744551	et	0	main
nendel	doc_491521501801_item	3744552	et	0	main
verbide	doc_491521501801_item	3744553	et	0	main
rektsiooniga	doc_491521501801_item	3744554	et	0	main
sisekohakäänetega	doc_491521501801_item	3744555	et	0	main
objekti	doc_491521501801_item	3744556	et	0	main
kasutamisega	doc_491521501801_item	3744557	et	0	main
ning	doc_491521501801_item	3744558	et	0	main
verbivormide	doc_491521501801_item	3744559	et	0	main
moodustamisega	doc_491521501801_item	3744560	et	0	main
võib	doc_491521501801_item	3744561	et	0	main
öelda	doc_491521501801_item	3744562	et	0	main
et	doc_491521501801_item	3744563	et	0	main
kõige	doc_491521501801_item	3744564	et	0	main
sagedasemate	doc_491521501801_item	3744565	et	0	main
vigade	doc_491521501801_item	3744566	et	0	main
põhjuseks	doc_491521501801_item	3744567	et	0	main
on	doc_491521501801_item	3744568	et	0	main
silmapaistvad	doc_491521501801_item	3744569	et	0	main
erinevused	doc_491521501801_item	3744570	et	0	main
kahe	doc_491521501801_item	3744571	et	0	main
keele	doc_491521501801_item	3744572	et	0	main
vahel	doc_491521501801_item	3744573	et	0	main
märkus	doc_491521501801_item	3744574	et	0	main
mõnede	doc_491521501801_item	3744575	et	0	main
näidete	doc_491521501801_item	3744576	et	0	main
puhul	doc_491521501801_item	3744577	et	0	main
juhul	doc_491521501801_item	3744578	et	0	main
kui	doc_491521501801_item	3744579	et	0	main
tegemist	doc_491521501801_item	3744580	et	0	main
oli	doc_491521501801_item	3744581	et	0	main
kogu	doc_491521501801_item	3744582	et	0	main
klassile	doc_491521501801_item	3744583	et	0	main
esitatud	doc_491521501801_item	3744584	et	0	main
kontrolltööga	doc_491521501801_item	3744585	et	0	main
voi	doc_491521501801_item	3744586	et	0	main
harjutustega	doc_491521501801_item	3744587	et	0	main
on	doc_491521501801_item	3744588	et	0	main
sulgudes	doc_491521501801_item	3744589	et	0	main
esitatud	doc_491521501801_item	3744590	et	0	main
ka	doc_491521501801_item	3744591	et	0	main
protsendid	doc_491521501801_item	3744592	et	0	main
mis	doc_491521501801_item	3744593	et	0	main
näitavad	doc_491521501801_item	3744594	et	0	main
hälbivate	doc_491521501801_item	3744595	et	0	main
vastuste	doc_491521501801_item	3744596	et	0	main
arvu	doc_491521501801_item	3744597	et	0	main
klassis	doc_491521501801_item	3744598	et	0	main
õigekiri	doc_491521501801_item	3744599	et	0	main
õpilaste	doc_491521501801_item	3744600	et	0	main
töödes	doc_491521501801_item	3744601	et	0	main
esinenud	doc_491521501801_item	3744602	et	0	main
vormid	doc_491521501801_item	3744603	et	0	main
õiged	doc_491521501801_item	3744604	et	0	main
vormid	doc_491521501801_item	3744605	et	0	main
pelgulinna	doc_491521501801_item	3744606	et	0	main
pelgulinna	doc_491521501801_item	3744607	et	0	main
raioonis	doc_491521501801_item	3744608	et	0	main
rajoonis	doc_491521501801_item	3744609	et	0	main
võib	doc_491521501801_item	3744610	et	0	main
olla	doc_491521501801_item	3744611	et	0	main
on	doc_491521501801_item	3744612	et	0	main
põhjustatud	doc_491521501801_item	3744613	et	0	main
sellest	doc_491521501801_item	3744614	et	0	main
et	doc_491521501801_item	3744615	et	0	main
hääldamise	doc_491521501801_item	3744616	et	0	main
puhul	doc_491521501801_item	3744617	et	0	main
võib	doc_491521501801_item	3744618	et	0	main
tunda	doc_491521501801_item	3744619	et	0	main
et	doc_491521501801_item	3744620	et	0	main
me	doc_491521501801_item	3744621	et	0	main
kasutame	doc_491521501801_item	3744622	et	0	main
i	doc_491521501801_item	3744623	et	0	main
j	doc_491521501801_item	3744624	et	0	main
asemel	doc_491521501801_item	3744625	et	0	main
karpis	doc_491521501801_item	3744626	et	0	main
karbis	doc_491521501801_item	3744627	et	0	main
võib	doc_491521501801_item	3744628	et	0	main
olla	doc_491521501801_item	3744629	et	0	main
on	doc_491521501801_item	3744630	et	0	main
põhjustatud	doc_491521501801_item	3744631	et	0	main
sellest	doc_491521501801_item	3744632	et	0	main
et	doc_491521501801_item	3744633	et	0	main
hääldamise	doc_491521501801_item	3744634	et	0	main
puhul	doc_491521501801_item	3744635	et	0	main
võib	doc_491521501801_item	3744636	et	0	main
tunda	doc_491521501801_item	3744637	et	0	main
et	doc_491521501801_item	3744638	et	0	main
me	doc_491521501801_item	3744639	et	0	main
kasutame	doc_491521501801_item	3744640	et	0	main
p	doc_491521501801_item	3744641	et	0	main
b	doc_491521501801_item	3744642	et	0	main
asemel	doc_491521501801_item	3744643	et	0	main
kuid	doc_491521501801_item	3744644	et	0	main
võib	doc_491521501801_item	3744645	et	0	main
olla	doc_491521501801_item	3744646	et	0	main
põhjuseks	doc_491521501801_item	3744647	et	0	main
on	doc_491521501801_item	3744648	et	0	main
hoopis	doc_491521501801_item	3744649	et	0	main
av	doc_491521501801_item	3744650	et	0	main
lasnamääl	doc_491521501801_item	3744651	et	0	main
lasnamäel	doc_491521501801_item	3744652	et	0	main
võib	doc_491521501801_item	3744653	et	0	main
olla	doc_491521501801_item	3744654	et	0	main
on	doc_491521501801_item	3744655	et	0	main
põhjus-	doc_491521501801_item	3744656	et	0	main
tatud	doc_491521501801_item	3744657	et	0	main
sellest	doc_491521501801_item	3744658	et	0	main
et	doc_491521501801_item	3744659	et	0	main
hääldamise	doc_491521501801_item	3744660	et	0	main
puhul	doc_491521501801_item	3744661	et	0	main
võib	doc_491521501801_item	3744662	et	0	main
tunda	doc_491521501801_item	3744663	et	0	main
et	doc_491521501801_item	3744664	et	0	main
me	doc_491521501801_item	3744665	et	0	main
kasutame	doc_491521501801_item	3744666	et	0	main
ää	doc_491521501801_item	3744667	et	0	main
äe	doc_491521501801_item	3744668	et	0	main
asemel	doc_491521501801_item	3744669	et	0	main
vanituba	doc_491521501801_item	3744670	et	0	main
vanituba	doc_491521501801_item	3744671	et	0	main
perekonna	doc_491521501801_item	3744672	et	0	main
nimi	doc_491521501801_item	3744673	et	0	main
perekonnanimi	doc_491521501801_item	3744674	et	0	main
sa	doc_491521501801_item	3744675	et	0	main
sa	doc_491521501801_item	3744676	et	0	main
kesküte	doc_491521501801_item	3744677	et	0	main
keskküte	doc_491521501801_item	3744678	et	0	main
nurgadivan	doc_491521501801_item	3744679	et	0	main
divaneid	doc_491521501801_item	3744680	et	0	main
nurgadiivan	doc_491521501801_item	3744681	et	0	main
diivaneid	doc_491521501801_item	3744682	et	0	main
võib	doc_491521501801_item	3744683	et	0	main
olla	doc_491521501801_item	3744684	et	0	main
siin	doc_491521501801_item	3744685	et	0	main
toimus	doc_491521501801_item	3744686	et	0	main
hoopis	doc_491521501801_item	3744687	et	0	main
vene	doc_491521501801_item	3744688	et	0	main
keele	doc_491521501801_item	3744689	et	0	main
mõju	doc_491521501801_item	3744690	et	0	main
vene	doc_491521501801_item	3744691	et	0	main
k-s	doc_491521501801_item	3744692	et	0	main
sõnas	doc_491521501801_item	3744693	et	0	main
диван	doc_491521501801_item	3744694	et	0	main
on	doc_491521501801_item	3744695	et	0	main
üks	doc_491521501801_item	3744696	et	0	main
i	doc_491521501801_item	3744697	et	0	main
astmevaheldus	doc_491521501801_item	3744698	et	0	main
av	doc_491521501801_item	3744699	et	0	main
on	doc_491521501801_item	3744700	et	0	main
üleüldse	doc_491521501801_item	3744701	et	0	main
eesti	doc_491521501801_item	3744702	et	0	main
keele	doc_491521501801_item	3744703	et	0	main
üks	doc_491521501801_item	3744704	et	0	main
raskemaid	doc_491521501801_item	3744705	et	0	main
teemasid	doc_491521501801_item	3744706	et	0	main
õpilaste	doc_491521501801_item	3744707	et	0	main
töödes	doc_491521501801_item	3744708	et	0	main
esinenud	doc_491521501801_item	3744709	et	0	main
vormid	doc_491521501801_item	3744710	et	0	main
õiged	doc_491521501801_item	3744711	et	0	main
vormid	doc_491521501801_item	3744712	et	0	main
hakkada	doc_491521501801_item	3744713	et	0	main
hakata	doc_491521501801_item	3744714	et	0	main
karpis	doc_491521501801_item	3744715	et	0	main
karbis	doc_491521501801_item	3744716	et	0	main
suhtleda	doc_491521501801_item	3744717	et	0	main
suhelda	doc_491521501801_item	3744718	et	0	main
kolmekorruselines	doc_491521501801_item	3744719	et	0	main
majas	doc_491521501801_item	3744720	et	0	main
kolmekorruselises	doc_491521501801_item	3744721	et	0	main
majas	doc_491521501801_item	3744722	et	0	main
tütrast	doc_491521501801_item	3744723	et	0	main
tütrest	doc_491521501801_item	3744724	et	0	main
kuldast	doc_491521501801_item	3744725	et	0	main
kullast	doc_491521501801_item	3744726	et	0	main
objektivead	doc_491521501801_item	3744727	et	0	main
objekt	doc_491521501801_item	3744728	et	0	main
e	doc_491521501801_item	3744729	et	0	main
sihitis	doc_491521501801_item	3744730	et	0	main
eesti	doc_491521501801_item	3744731	et	0	main
keeles	doc_491521501801_item	3744732	et	0	main
võib	doc_491521501801_item	3744733	et	0	main
olla	doc_491521501801_item	3744734	et	0	main
esitatud	doc_491521501801_item	3744735	et	0	main
lauses	doc_491521501801_item	3744736	et	0	main
kas	doc_491521501801_item	3744737	et	0	main
nimetavas	doc_491521501801_item	3744738	et	0	main
omastavas	doc_491521501801_item	3744739	et	0	main
või	doc_491521501801_item	3744740	et	0	main
osastavas	doc_491521501801_item	3744741	et	0	main
käändes	doc_491521501801_item	3744742	et	0	main
eesti	doc_491521501801_item	3744743	et	0	main
keeles	doc_491521501801_item	3744744	et	0	main
jaguneb	doc_491521501801_item	3744745	et	0	main
sihitis	doc_491521501801_item	3744746	et	0	main
täissihitiseks	doc_491521501801_item	3744747	et	0	main
ja	doc_491521501801_item	3744748	et	0	main
osasihitiseks	doc_491521501801_item	3744749	et	0	main
samuti	doc_491521501801_item	3744750	et	0	main
vene	doc_491521501801_item	3744751	et	0	main
keeleski	doc_491521501801_item	3744752	et	0	main
kuid	doc_491521501801_item	3744753	et	0	main
nende	doc_491521501801_item	3744754	et	0	main
kasutuspiirid	doc_491521501801_item	3744755	et	0	main
ei	doc_491521501801_item	3744756	et	0	main
lange	doc_491521501801_item	3744757	et	0	main
kokku	doc_491521501801_item	3744758	et	0	main
õpilaste	doc_491521501801_item	3744759	et	0	main
töödes	doc_491521501801_item	3744760	et	0	main
esinenud	doc_491521501801_item	3744761	et	0	main
vormid	doc_491521501801_item	3744762	et	0	main
õiged	doc_491521501801_item	3744763	et	0	main
vormid	doc_491521501801_item	3744764	et	0	main
mul	doc_491521501801_item	3744765	et	0	main
on	doc_491521501801_item	3744766	et	0	main
vaja	doc_491521501801_item	3744767	et	0	main
uus	doc_491521501801_item	3744768	et	0	main
mööbel	doc_491521501801_item	3744769	et	0	main
uut	doc_491521501801_item	3744770	et	0	main
mööblit	doc_491521501801_item	3744771	et	0	main
os	doc_491521501801_item	3744772	et	0	main
vene	doc_491521501801_item	3744773	et	0	main
k-s	doc_491521501801_item	3744774	et	0	main
именит	doc_491521501801_item	3744775	et	0	main
ma	doc_491521501801_item	3744776	et	0	main
ostsin	doc_491521501801_item	3744777	et	0	main
uus	doc_491521501801_item	3744778	et	0	main
kirjutuslaud	doc_491521501801_item	3744779	et	0	main
uue	doc_491521501801_item	3744780	et	0	main
kirjutuslaua	doc_491521501801_item	3744781	et	0	main
omvene	doc_491521501801_item	3744782	et	0	main
k-s	doc_491521501801_item	3744783	et	0	main
винит	doc_491521501801_item	3744784	et	0	main
tahab	doc_491521501801_item	3744785	et	0	main
osta	doc_491521501801_item	3744786	et	0	main
uus	doc_491521501801_item	3744787	et	0	main
maja	doc_491521501801_item	3744788	et	0	main
uut	doc_491521501801_item	3744789	et	0	main
maja	doc_491521501801_item	3744790	et	0	main
os	doc_491521501801_item	3744791	et	0	main
vene	doc_491521501801_item	3744792	et	0	main
k-s	doc_491521501801_item	3744793	et	0	main
винит	doc_491521501801_item	3744794	et	0	main
ma	doc_491521501801_item	3744795	et	0	main
ostsin	doc_491521501801_item	3744796	et	0	main
uus	doc_491521501801_item	3744797	et	0	main
korter	doc_491521501801_item	3744798	et	0	main
uue	doc_491521501801_item	3744799	et	0	main
korteri	doc_491521501801_item	3744800	et	0	main
0m	doc_491521501801_item	3744801	et	0	main
vene	doc_491521501801_item	3744802	et	0	main
k-s	doc_491521501801_item	3744803	et	0	main
винит	doc_491521501801_item	3744804	et	0	main
meil	doc_491521501801_item	3744805	et	0	main
on	doc_491521501801_item	3744806	et	0	main
kaks	doc_491521501801_item	3744807	et	0	main
vannitoa	doc_491521501801_item	3744808	et	0	main
vannitubaos	doc_491521501801_item	3744809	et	0	main
vene	doc_491521501801_item	3744810	et	0	main
k-s	doc_491521501801_item	3744811	et	0	main
родит	doc_491521501801_item	3744812	et	0	main
seal	doc_491521501801_item	3744813	et	0	main
on	doc_491521501801_item	3744814	et	0	main
palju	doc_491521501801_item	3744815	et	0	main
mugavused	doc_491521501801_item	3744816	et	0	main
mugavusi	doc_491521501801_item	3744817	et	0	main
mosvene	doc_491521501801_item	3744818	et	0	main
k-s	doc_491521501801_item	3744819	et	0	main
родит	doc_491521501801_item	3744820	et	0	main
panime	doc_491521501801_item	3744821	et	0	main
uued	doc_491521501801_item	3744822	et	0	main
tapeet	doc_491521501801_item	3744823	et	0	main
uued	doc_491521501801_item	3744824	et	0	main
tapeedid	doc_491521501801_item	3744825	et	0	main
mnimvene	doc_491521501801_item	3744826	et	0	main
k-s	doc_491521501801_item	3744827	et	0	main
винит	doc_491521501801_item	3744828	et	0	main
kohakäänete	doc_491521501801_item	3744829	et	0	main
vead	doc_491521501801_item	3744830	et	0	main
eesti	doc_491521501801_item	3744831	et	0	main
sisekohakäänete	doc_491521501801_item	3744832	et	0	main
peamine	doc_491521501801_item	3744833	et	0	main
funktsioon	doc_491521501801_item	3744834	et	0	main
on	doc_491521501801_item	3744835	et	0	main
väljendada	doc_491521501801_item	3744836	et	0	main
ruumilisi	doc_491521501801_item	3744837	et	0	main
suhteid	doc_491521501801_item	3744838	et	0	main
eesti	doc_491521501801_item	3744839	et	0	main
käänded	doc_491521501801_item	3744840	et	0	main
jagunevad	doc_491521501801_item	3744841	et	0	main
sisekohakääneteks	doc_491521501801_item	3744842	et	0	main
kuhu	doc_491521501801_item	3744843	et	0	main
kuuluvad	doc_491521501801_item	3744844	et	0	main
illatiiv	doc_491521501801_item	3744845	et	0	main
e	doc_491521501801_item	3744846	et	0	main
sisseütlev	doc_491521501801_item	3744847	et	0	main
innessiiv	doc_491521501801_item	3744848	et	0	main
e	doc_491521501801_item	3744849	et	0	main
seesütlev	doc_491521501801_item	3744850	et	0	main
elatiiv	doc_491521501801_item	3744851	et	0	main
e	doc_491521501801_item	3744852	et	0	main
seestütlev	doc_491521501801_item	3744853	et	0	main
ja	doc_491521501801_item	3744854	et	0	main
väliskohakääneteks	doc_491521501801_item	3744855	et	0	main
kuhu	doc_491521501801_item	3744856	et	0	main
kuuluvad	doc_491521501801_item	3744857	et	0	main
alatiiv	doc_491521501801_item	3744858	et	0	main
e	doc_491521501801_item	3744859	et	0	main
alaleütlev	doc_491521501801_item	3744860	et	0	main
adessiiv	doc_491521501801_item	3744861	et	0	main
e	doc_491521501801_item	3744862	et	0	main
alalütlev	doc_491521501801_item	3744863	et	0	main
ja	doc_491521501801_item	3744864	et	0	main
ablatiiv	doc_491521501801_item	3744865	et	0	main
e	doc_491521501801_item	3744866	et	0	main
alaltütlev	doc_491521501801_item	3744867	et	0	main
vene	doc_491521501801_item	3744868	et	0	main
keeles	doc_491521501801_item	3744869	et	0	main
ruumiliste	doc_491521501801_item	3744870	et	0	main
suhete	doc_491521501801_item	3744871	et	0	main
valjendamiseks	doc_491521501801_item	3744872	et	0	main
kasutatakse	doc_491521501801_item	3744873	et	0	main
kas	doc_491521501801_item	3744874	et	0	main
родительный	doc_491521501801_item	3744875	et	0	main
винительный	doc_491521501801_item	3744876	et	0	main
või	doc_491521501801_item	3744877	et	0	main
предложный	doc_491521501801_item	3744878	et	0	main
käänded	doc_491521501801_item	3744879	et	0	main
vastavate	doc_491521501801_item	3744880	et	0	main
eessõnadega	doc_491521501801_item	3744881	et	0	main
в	doc_491521501801_item	3744882	et	0	main
из	doc_491521501801_item	3744883	et	0	main
нас	doc_491521501801_item	3744884	et	0	main
nagu	doc_491521501801_item	3744885	et	0	main
õpilaste	doc_491521501801_item	3744886	et	0	main
töödest	doc_491521501801_item	3744887	et	0	main
toodud	doc_491521501801_item	3744888	et	0	main
näidetest	doc_491521501801_item	3744889	et	0	main
on	doc_491521501801_item	3744890	et	0	main
näha	doc_491521501801_item	3744891	et	0	main
eksitakse	doc_491521501801_item	3744892	et	0	main
kõige	doc_491521501801_item	3744893	et	0	main
rohkem	doc_491521501801_item	3744894	et	0	main
lühikese	doc_491521501801_item	3744895	et	0	main
illatiivi	doc_491521501801_item	3744896	et	0	main
puhul	doc_491521501801_item	3744897	et	0	main
nii	doc_491521501801_item	3744898	et	0	main
kõige	doc_491521501801_item	3744899	et	0	main
raskemateks	doc_491521501801_item	3744900	et	0	main
osutasid	doc_491521501801_item	3744901	et	0	main
sellised	doc_491521501801_item	3744902	et	0	main
sõnad	doc_491521501801_item	3744903	et	0	main
nagu	doc_491521501801_item	3744904	et	0	main
uttu	doc_491521501801_item	3744905	et	0	main
parki	doc_491521501801_item	3744906	et	0	main
pessa	doc_491521501801_item	3744907	et	0	main
keelde	doc_491521501801_item	3744908	et	0	main
kinno	doc_491521501801_item	3744909	et	0	main
vette	doc_491521501801_item	3744910	et	0	main
merre	doc_491521501801_item	3744911	et	0	main
nii	doc_491521501801_item	3744912	et	0	main
rohkearvuliste	doc_491521501801_item	3744913	et	0	main
vigade	doc_491521501801_item	3744914	et	0	main
põhjuseks	doc_491521501801_item	3744915	et	0	main
võivad	doc_491521501801_item	3744916	et	0	main
olla	doc_491521501801_item	3744917	et	0	main
erinevused	doc_491521501801_item	3744918	et	0	main
eesti	doc_491521501801_item	3744919	et	0	main
ja	doc_491521501801_item	3744920	et	0	main
vene	doc_491521501801_item	3744921	et	0	main
keele	doc_491521501801_item	3744922	et	0	main
vahel	doc_491521501801_item	3744923	et	0	main
ruumiliste	doc_491521501801_item	3744924	et	0	main
suhete	doc_491521501801_item	3744925	et	0	main
väljendamises	doc_491521501801_item	3744926	et	0	main
nii	doc_491521501801_item	3744927	et	0	main
eesti	doc_491521501801_item	3744928	et	0	main
keeles	doc_491521501801_item	3744929	et	0	main
ei	doc_491521501801_item	3744930	et	0	main
saa	doc_491521501801_item	3744931	et	0	main
piirduda	doc_491521501801_item	3744932	et	0	main
illatiivi	doc_491521501801_item	3744933	et	0	main
moodustamisel	doc_491521501801_item	3744934	et	0	main
ainult	doc_491521501801_item	3744935	et	0	main
sse	doc_491521501801_item	3744936	et	0	main
lõpu	doc_491521501801_item	3744937	et	0	main
lisamisega	doc_491521501801_item	3744938	et	0	main
sõna	doc_491521501801_item	3744939	et	0	main
juurde	doc_491521501801_item	3744940	et	0	main
nii	doc_491521501801_item	3744941	et	0	main
et	doc_491521501801_item	3744942	et	0	main
väga	doc_491521501801_item	3744943	et	0	main
palju	doc_491521501801_item	3744944	et	0	main
vorme	doc_491521501801_item	3744945	et	0	main
tuleb	doc_491521501801_item	3744946	et	0	main
lihtsalt	doc_491521501801_item	3744947	et	0	main
meelde	doc_491521501801_item	3744948	et	0	main
jätta	doc_491521501801_item	3744949	et	0	main
innessiivi	doc_491521501801_item	3744950	et	0	main
ja	doc_491521501801_item	3744951	et	0	main
elatiivi	doc_491521501801_item	3744952	et	0	main
puhul	doc_491521501801_item	3744953	et	0	main
oli	doc_491521501801_item	3744954	et	0	main
vigu	doc_491521501801_item	3744955	et	0	main
palju	doc_491521501801_item	3744956	et	0	main
vähem	doc_491521501801_item	3744957	et	0	main
tegelikult	doc_491521501801_item	3744958	et	0	main
nad	doc_491521501801_item	3744959	et	0	main
võiksid	doc_491521501801_item	3744960	et	0	main
kuuluda	doc_491521501801_item	3744961	et	0	main
av	doc_491521501801_item	3744962	et	0	main
ja	doc_491521501801_item	3744963	et	0	main
ühildumisvigade	doc_491521501801_item	3744964	et	0	main
hulka	doc_491521501801_item	3744965	et	0	main
õpilaste	doc_491521501801_item	3744966	et	0	main
töödes	doc_491521501801_item	3744967	et	0	main
esinenud	doc_491521501801_item	3744968	et	0	main
vormid	doc_491521501801_item	3744969	et	0	main
sisseütlev	doc_491521501801_item	3744970	et	0	main
udu	doc_491521501801_item	3744971	et	0	main
udusse	doc_491521501801_item	3744972	et	0	main
90	doc_491521501801_item	3744973	et	0	main
uttu	doc_491521501801_item	3744974	et	0	main
koju	doc_491521501801_item	3744975	et	0	main
2	doc_491521501801_item	3744976	et	0	main
kojju	doc_491521501801_item	3744977	et	0	main
õhu	doc_491521501801_item	3744978	et	0	main
3	doc_491521501801_item	3744979	et	0	main
õhku	doc_491521501801_item	3744980	et	0	main
poesse	doc_491521501801_item	3744981	et	0	main
10	doc_491521501801_item	3744982	et	0	main
poodi	doc_491521501801_item	3744983	et	0	main
randasse	doc_491521501801_item	3744984	et	0	main
20	doc_491521501801_item	3744985	et	0	main
randa	doc_491521501801_item	3744986	et	0	main
tundisse	doc_491521501801_item	3744987	et	0	main
tunni	doc_491521501801_item	3744988	et	0	main
10	doc_491521501801_item	3744989	et	0	main
tundi	doc_491521501801_item	3744990	et	0	main
lõkkesse	doc_491521501801_item	3744991	et	0	main
30	doc_491521501801_item	3744992	et	0	main
lõkke	doc_491521501801_item	3744993	et	0	main
õudesse	doc_491521501801_item	3744994	et	0	main
10	doc_491521501801_item	3744995	et	0	main
õue	doc_491521501801_item	3744996	et	0	main
märkmiku	doc_491521501801_item	3744997	et	0	main
20	doc_491521501801_item	3744998	et	0	main
märkmikku	doc_491521501801_item	3744999	et	0	main
toasse	doc_491521501801_item	3745000	et	0	main
10	doc_491521501801_item	3745001	et	0	main
tuppa	doc_491521501801_item	3745002	et	0	main
jaami	doc_491521501801_item	3745003	et	0	main
jaamasse	doc_491521501801_item	3745004	et	0	main
40	doc_491521501801_item	3745005	et	0	main
jaama	doc_491521501801_item	3745006	et	0	main
loomaaja	doc_491521501801_item	3745007	et	0	main
40	doc_491521501801_item	3745008	et	0	main
loomaaeda	doc_491521501801_item	3745009	et	0	main
raekoda	doc_491521501801_item	3745010	et	0	main
70	doc_491521501801_item	3745011	et	0	main
raekotta	doc_491521501801_item	3745012	et	0	main
lasteaja	doc_491521501801_item	3745013	et	0	main
50	doc_491521501801_item	3745014	et	0	main
lasteaeda	doc_491521501801_item	3745015	et	0	main
mäge	doc_491521501801_item	3745016	et	0	main
mäe	doc_491521501801_item	3745017	et	0	main
40	doc_491521501801_item	3745018	et	0	main
mäkke	doc_491521501801_item	3745019	et	0	main
kinosse	doc_491521501801_item	3745020	et	0	main
80	doc_491521501801_item	3745021	et	0	main
kinno	doc_491521501801_item	3745022	et	0	main
talu	doc_491521501801_item	3745023	et	0	main
20	doc_491521501801_item	3745024	et	0	main
tallu	doc_491521501801_item	3745025	et	0	main
keele	doc_491521501801_item	3745026	et	0	main
60	doc_491521501801_item	3745027	et	0	main
keelde	doc_491521501801_item	3745028	et	0	main
veete	doc_491521501801_item	3745029	et	0	main
vesisse	doc_491521501801_item	3745030	et	0	main
40	doc_491521501801_item	3745031	et	0	main
vette	doc_491521501801_item	3745032	et	0	main
pestesa	doc_491521501801_item	3745033	et	0	main
pesesse60	doc_491521501801_item	3745034	et	0	main
pessa	doc_491521501801_item	3745035	et	0	main
kinnasse	doc_491521501801_item	3745036	et	0	main
20	doc_491521501801_item	3745037	et	0	main
kinda	doc_491521501801_item	3745038	et	0	main
mere	doc_491521501801_item	3745039	et	0	main
40	doc_491521501801_item	3745040	et	0	main
merre	doc_491521501801_item	3745041	et	0	main
seesütlev	doc_491521501801_item	3745042	et	0	main
haiglases	doc_491521501801_item	3745043	et	0	main
10	doc_491521501801_item	3745044	et	0	main
haiglas	doc_491521501801_item	3745045	et	0	main
selgis	doc_491521501801_item	3745046	et	0	main
30	doc_491521501801_item	3745047	et	0	main
seljas	doc_491521501801_item	3745048	et	0	main
parkis	doc_491521501801_item	3745049	et	0	main
20	doc_491521501801_item	3745050	et	0	main
pargis	doc_491521501801_item	3745051	et	0	main
pirukases	doc_491521501801_item	3745052	et	0	main
20	doc_491521501801_item	3745053	et	0	main
pirukas	doc_491521501801_item	3745054	et	0	main
seestütlev	doc_491521501801_item	3745055	et	0	main
tütrast	doc_491521501801_item	3745056	et	0	main
tütrest	doc_491521501801_item	3745057	et	0	main
tehast	doc_491521501801_item	3745058	et	0	main
tehasest	doc_491521501801_item	3745059	et	0	main
kinnost	doc_491521501801_item	3745060	et	0	main
kinost	doc_491521501801_item	3745061	et	0	main
muud	doc_491521501801_item	3745062	et	0	main
käändevead	doc_491521501801_item	3745063	et	0	main
eesti	doc_491521501801_item	3745064	et	0	main
ja	doc_491521501801_item	3745065	et	0	main
vene	doc_491521501801_item	3745066	et	0	main
käänetetähendused	doc_491521501801_item	3745067	et	0	main
ja	doc_491521501801_item	3745068	et	0	main
kasutamisreeglid	doc_491521501801_item	3745069	et	0	main
ei	doc_491521501801_item	3745070	et	0	main
lange	doc_491521501801_item	3745071	et	0	main
peaaegu	doc_491521501801_item	3745072	et	0	main
kunagi	doc_491521501801_item	3745073	et	0	main
kokku	doc_491521501801_item	3745074	et	0	main
va	doc_491521501801_item	3745075	et	0	main
terminatiivi	doc_491521501801_item	3745076	et	0	main
ja	doc_491521501801_item	3745077	et	0	main
abessiivi	doc_491521501801_item	3745078	et	0	main
puhul	doc_491521501801_item	3745079	et	0	main
nt	doc_491521501801_item	3745080	et	0	main
tartuni	doc_491521501801_item	3745081	et	0	main
дo	doc_491521501801_item	3745082	et	0	main
tapтy	doc_491521501801_item	3745083	et	0	main
lõunata	doc_491521501801_item	3745084	et	0	main
без	doc_491521501801_item	3745085	et	0	main
обеда	doc_491521501801_item	3745086	et	0	main
õpilaste	doc_491521501801_item	3745087	et	0	main
töödes	doc_491521501801_item	3745088	et	0	main
esinenud	doc_491521501801_item	3745089	et	0	main
vormid	doc_491521501801_item	3745090	et	0	main
õiged	doc_491521501801_item	3745091	et	0	main
vormid	doc_491521501801_item	3745092	et	0	main
kakskümment	doc_491521501801_item	3745093	et	0	main
minutit	doc_491521501801_item	3745094	et	0	main
kakskümmend	doc_491521501801_item	3745095	et	0	main
mnim	doc_491521501801_item	3745096	et	0	main
vene	doc_491521501801_item	3745097	et	0	main
k-s	doc_491521501801_item	3745098	et	0	main
им	doc_491521501801_item	3745099	et	0	main
alias	doc_491521501801_item	3745100	et	0	main
on	doc_491521501801_item	3745101	et	0	main
ka	doc_491521501801_item	3745102	et	0	main
lillepeenarid	doc_491521501801_item	3745103	et	0	main
lillepeenrad	doc_491521501801_item	3745104	et	0	main
mnim	doc_491521501801_item	3745105	et	0	main
vene	doc_491521501801_item	3745106	et	0	main
k-s	doc_491521501801_item	3745107	et	0	main
имен	doc_491521501801_item	3745108	et	0	main
seal	doc_491521501801_item	3745109	et	0	main
on	doc_491521501801_item	3745110	et	0	main
palju	doc_491521501801_item	3745111	et	0	main
mugavused	doc_491521501801_item	3745112	et	0	main
mugavusi	doc_491521501801_item	3745113	et	0	main
mos	doc_491521501801_item	3745114	et	0	main
vene	doc_491521501801_item	3745115	et	0	main
k-s	doc_491521501801_item	3745116	et	0	main
родит	doc_491521501801_item	3745117	et	0	main
kui	doc_491521501801_item	3745118	et	0	main
palju	doc_491521501801_item	3745119	et	0	main
1ampi	doc_491521501801_item	3745120	et	0	main
seal	doc_491521501801_item	3745121	et	0	main
on	doc_491521501801_item	3745122	et	0	main
lampe	doc_491521501801_item	3745123	et	0	main
mos	doc_491521501801_item	3745124	et	0	main
vene	doc_491521501801_item	3745125	et	0	main
k-s	doc_491521501801_item	3745126	et	0	main
родит	doc_491521501801_item	3745127	et	0	main
esimesel	doc_491521501801_item	3745128	et	0	main
korrusel	doc_491521501801_item	3745129	et	0	main
on	doc_491521501801_item	3745130	et	0	main
palju	doc_491521501801_item	3745131	et	0	main
lauaid	doc_491521501801_item	3745132	et	0	main
laudu	doc_491521501801_item	3745133	et	0	main
mos	doc_491521501801_item	3745134	et	0	main
vene	doc_491521501801_item	3745135	et	0	main
k-s	doc_491521501801_item	3745136	et	0	main
родит	doc_491521501801_item	3745137	et	0	main
läksin	doc_491521501801_item	3745138	et	0	main
sõbradega	doc_491521501801_item	3745139	et	0	main
sõpradega	doc_491521501801_item	3745140	et	0	main
mkaasaütl	doc_491521501801_item	3745141	et	0	main
vene	doc_491521501801_item	3745142	et	0	main
k-s	doc_491521501801_item	3745143	et	0	main
тв	doc_491521501801_item	3745144	et	0	main
pronoomenivead	doc_491521501801_item	3745145	et	0	main
pronoomenivigu	doc_491521501801_item	3745146	et	0	main
peaaegu	doc_491521501801_item	3745147	et	0	main
ei	doc_491521501801_item	3745148	et	0	main
esinenud	doc_491521501801_item	3745149	et	0	main
üldse	doc_491521501801_item	3745150	et	0	main
kõige	doc_491521501801_item	3745151	et	0	main
sagedasemad	doc_491521501801_item	3745152	et	0	main
esinevatest	doc_491521501801_item	3745153	et	0	main
oli	doc_491521501801_item	3745154	et	0	main
enesekohase	doc_491521501801_item	3745155	et	0	main
asesõna	doc_491521501801_item	3745156	et	0	main
sinu	doc_491521501801_item	3745157	et	0	main
oma	doc_491521501801_item	3745158	et	0	main
asemel	doc_491521501801_item	3745159	et	0	main
võib	doc_491521501801_item	3745160	et	0	main
olla	doc_491521501801_item	3745161	et	0	main
see	doc_491521501801_item	3745162	et	0	main
oli	doc_491521501801_item	3745163	et	0	main
tingitud	doc_491521501801_item	3745164	et	0	main
vene	doc_491521501801_item	3745165	et	0	main
keele	doc_491521501801_item	3745166	et	0	main
mõjust	doc_491521501801_item	3745167	et	0	main
eesti	doc_491521501801_item	3745168	et	0	main
keeles	doc_491521501801_item	3745169	et	0	main
on	doc_491521501801_item	3745170	et	0	main
olemas	doc_491521501801_item	3745171	et	0	main
ainult	doc_491521501801_item	3745172	et	0	main
üks	doc_491521501801_item	3745173	et	0	main
enesekohane	doc_491521501801_item	3745174	et	0	main
asesõna-	doc_491521501801_item	3745175	et	0	main
so	doc_491521501801_item	3745176	et	0	main
oma	doc_491521501801_item	3745177	et	0	main
vene	doc_491521501801_item	3745178	et	0	main
keeles	doc_491521501801_item	3745179	et	0	main
neid	doc_491521501801_item	3745180	et	0	main
on	doc_491521501801_item	3745181	et	0	main
mitu	doc_491521501801_item	3745182	et	0	main
мой	doc_491521501801_item	3745183	et	0	main
твой	doc_491521501801_item	3745184	et	0	main
наш	doc_491521501801_item	3745185	et	0	main
ваш	doc_491521501801_item	3745186	et	0	main
свой	doc_491521501801_item	3745187	et	0	main
ütle	doc_491521501801_item	3745188	et	0	main
oma	doc_491521501801_item	3745189	et	0	main
isikukood	doc_491521501801_item	3745190	et	0	main
asemel	doc_491521501801_item	3745191	et	0	main
kirjutati	doc_491521501801_item	3745192	et	0	main
ütle	doc_491521501801_item	3745193	et	0	main
sinu	doc_491521501801_item	3745194	et	0	main
isikukood	doc_491521501801_item	3745195	et	0	main
kuigi	doc_491521501801_item	3745196	et	0	main
ülesandeks	doc_491521501801_item	3745197	et	0	main
oli	doc_491521501801_item	3745198	et	0	main
tõlkida	doc_491521501801_item	3745199	et	0	main
vene	doc_491521501801_item	3745200	et	0	main
keelest	doc_491521501801_item	3745201	et	0	main
eesti	doc_491521501801_item	3745202	et	0	main
keeldeскажи	doc_491521501801_item	3745203	et	0	main
свой	doc_491521501801_item	3745204	et	0	main
личный	doc_491521501801_item	3745205	et	0	main
код	doc_491521501801_item	3745206	et	0	main
arvsõna	doc_491521501801_item	3745207	et	0	main
käänamine	doc_491521501801_item	3745208	et	0	main
õpilaste	doc_491521501801_item	3745209	et	0	main
töödes	doc_491521501801_item	3745210	et	0	main
esinenud	doc_491521501801_item	3745211	et	0	main
vormid	doc_491521501801_item	3745212	et	0	main
õiged	doc_491521501801_item	3745213	et	0	main
vormid	doc_491521501801_item	3745214	et	0	main
kolmeksi	doc_491521501801_item	3745215	et	0	main
kolmekesi	doc_491521501801_item	3745216	et	0	main
kahekesti	doc_491521501801_item	3745217	et	0	main
kahekesi	doc_491521501801_item	3745218	et	0	main
kolmele	doc_491521501801_item	3745219	et	0	main
korruselile	doc_491521501801_item	3745220	et	0	main
kolmandale	doc_491521501801_item	3745221	et	0	main
korrusele	doc_491521501801_item	3745222	et	0	main
ühildumisvead	doc_491521501801_item	3745223	et	0	main
arvan	doc_491521501801_item	3745224	et	0	main
et	doc_491521501801_item	3745225	et	0	main
nende	doc_491521501801_item	3745226	et	0	main
veade	doc_491521501801_item	3745227	et	0	main
põhjus	doc_491521501801_item	3745228	et	0	main
oli	doc_491521501801_item	3745229	et	0	main
õpilaste	doc_491521501801_item	3745230	et	0	main
hajameelsus	doc_491521501801_item	3745231	et	0	main
õpilaste	doc_491521501801_item	3745232	et	0	main
töödes	doc_491521501801_item	3745233	et	0	main
esinenud	doc_491521501801_item	3745234	et	0	main
vormid	doc_491521501801_item	3745235	et	0	main
õiged	doc_491521501801_item	3745236	et	0	main
vormid	doc_491521501801_item	3745237	et	0	main
teisel	doc_491521501801_item	3745238	et	0	main
korrusel	doc_491521501801_item	3745239	et	0	main
oli	doc_491521501801_item	3745240	et	0	main
kapid	doc_491521501801_item	3745241	et	0	main
teisel	doc_491521501801_item	3745242	et	0	main
korrusel	doc_491521501801_item	3745243	et	0	main
olid	doc_491521501801_item	3745244	et	0	main
kapid	doc_491521501801_item	3745245	et	0	main
me	doc_491521501801_item	3745246	et	0	main
ei	doc_491521501801_item	3745247	et	0	main
kohtusime	doc_491521501801_item	3745248	et	0	main
me	doc_491521501801_item	3745249	et	0	main
ei	doc_491521501801_item	3745250	et	0	main
kohtunud	doc_491521501801_item	3745251	et	0	main
kuidas	doc_491521501801_item	3745252	et	0	main
sa	doc_491521501801_item	3745253	et	0	main
kooli	doc_491521501801_item	3745254	et	0	main
lähete	doc_491521501801_item	3745255	et	0	main
kuidas	doc_491521501801_item	3745256	et	0	main
sa	doc_491521501801_item	3745257	et	0	main
kooli	doc_491521501801_item	3745258	et	0	main
lähedte	doc_491521501801_item	3745259	et	0	main
lähete	doc_491521501801_item	3745260	et	0	main
öelge	doc_491521501801_item	3745261	et	0	main
kuidas	doc_491521501801_item	3745262	et	0	main
sa	doc_491521501801_item	3745263	et	0	main
elate	doc_491521501801_item	3745264	et	0	main
kuidas	doc_491521501801_item	3745265	et	0	main
te	doc_491521501801_item	3745266	et	0	main
elate	doc_491521501801_item	3745267	et	0	main
sa	doc_491521501801_item	3745268	et	0	main
elad	doc_491521501801_item	3745269	et	0	main
verbivormide	doc_491521501801_item	3745270	et	0	main
moodustusvead	doc_491521501801_item	3745271	et	0	main
esinesid	doc_491521501801_item	3745272	et	0	main
umbisikulise	doc_491521501801_item	3745273	et	0	main
tegumoe	doc_491521501801_item	3745274	et	0	main
ja	doc_491521501801_item	3745275	et	0	main
da-infinitiivi	doc_491521501801_item	3745276	et	0	main
kasutamisel	doc_491521501801_item	3745277	et	0	main
õpilaste	doc_491521501801_item	3745278	et	0	main
töödes	doc_491521501801_item	3745279	et	0	main
esinenud	doc_491521501801_item	3745280	et	0	main
vormid	doc_491521501801_item	3745281	et	0	main
õiged	doc_491521501801_item	3745282	et	0	main
vormid	doc_491521501801_item	3745283	et	0	main
perekonnanimi	doc_491521501801_item	3745284	et	0	main
kirjutakse	doc_491521501801_item	3745285	et	0	main
kirjutatakse	doc_491521501801_item	3745286	et	0	main
ma	doc_491521501801_item	3745287	et	0	main
pean	doc_491521501801_item	3745288	et	0	main
emaga	doc_491521501801_item	3745289	et	0	main
lähme	doc_491521501801_item	3745290	et	0	main
minema	doc_491521501801_item	3745291	et	0	main
et	doc_491521501801_item	3745292	et	0	main
ma	doc_491521501801_item	3745293	et	0	main
ei	doc_491521501801_item	3745294	et	0	main
tuli	doc_491521501801_item	3745295	et	0	main
sinu	doc_491521501801_item	3745296	et	0	main
sünnipäevale	doc_491521501801_item	3745297	et	0	main
ei	doc_491521501801_item	3745298	et	0	main
tulnud	doc_491521501801_item	3745299	et	0	main
ei	doc_491521501801_item	3745300	et	0	main
tule	doc_491521501801_item	3745301	et	0	main
ma	doc_491521501801_item	3745302	et	0	main
ei	doc_491521501801_item	3745303	et	0	main
mäelda	doc_491521501801_item	3745304	et	0	main
ei	doc_491521501801_item	3745305	et	0	main
mäleta	doc_491521501801_item	3745306	et	0	main
remontime	doc_491521501801_item	3745307	et	0	main
maja	doc_491521501801_item	3745308	et	0	main
remondime	doc_491521501801_item	3745309	et	0	main
tahan	doc_491521501801_item	3745310	et	0	main
täna	doc_491521501801_item	3745311	et	0	main
õnnidelda	doc_491521501801_item	3745312	et	0	main
õnnitleda	doc_491521501801_item	3745313	et	0	main
ise	doc_491521501801_item	3745314	et	0	main
ma	doc_491521501801_item	3745315	et	0	main
neid	doc_491521501801_item	3745316	et	0	main
välja	doc_491521501801_item	3745317	et	0	main
mõtleda	doc_491521501801_item	3745318	et	0	main
mõelda	doc_491521501801_item	3745319	et	0	main
kaasa	doc_491521501801_item	3745320	et	0	main
võtada	doc_491521501801_item	3745321	et	0	main
võtta	doc_491521501801_item	3745322	et	0	main
tuleb	doc_491521501801_item	3745323	et	0	main
sinna	doc_491521501801_item	3745324	et	0	main
sõida	doc_491521501801_item	3745325	et	0	main
sõita	doc_491521501801_item	3745326	et	0	main
armastab	doc_491521501801_item	3745327	et	0	main
kimpudesse	doc_491521501801_item	3745328	et	0	main
seatada	doc_491521501801_item	3745329	et	0	main
seada	doc_491521501801_item	3745330	et	0	main
seata	doc_491521501801_item	3745331	et	0	main
verbivormide	doc_491521501801_item	3745332	et	0	main
valiku	doc_491521501801_item	3745333	et	0	main
vead	doc_491521501801_item	3745334	et	0	main
kuna	doc_491521501801_item	3745335	et	0	main
eesti	doc_491521501801_item	3745336	et	0	main
keeles	doc_491521501801_item	3745337	et	0	main
on	doc_491521501801_item	3745338	et	0	main
2	doc_491521501801_item	3745339	et	0	main
infinitiivivormi	doc_491521501801_item	3745340	et	0	main
ja	doc_491521501801_item	3745341	et	0	main
vene	doc_491521501801_item	3745342	et	0	main
keeles	doc_491521501801_item	3745343	et	0	main
ainult	doc_491521501801_item	3745344	et	0	main
üks	doc_491521501801_item	3745345	et	0	main
kutsub	doc_491521501801_item	3745346	et	0	main
see	doc_491521501801_item	3745347	et	0	main
esile	doc_491521501801_item	3745348	et	0	main
väga	doc_491521501801_item	3745349	et	0	main
palju	doc_491521501801_item	3745350	et	0	main
probleeme	doc_491521501801_item	3745351	et	0	main
eesti	doc_491521501801_item	3745352	et	0	main
keelt	doc_491521501801_item	3745353	et	0	main
mitte	doc_491521501801_item	3745354	et	0	main
emakeelena	doc_491521501801_item	3745355	et	0	main
rääkivatel	doc_491521501801_item	3745356	et	0	main
inimestel	doc_491521501801_item	3745357	et	0	main
nii	doc_491521501801_item	3745358	et	0	main
tõlkimise	doc_491521501801_item	3745359	et	0	main
puhul	doc_491521501801_item	3745360	et	0	main
eriti	doc_491521501801_item	3745361	et	0	main
vene	doc_491521501801_item	3745362	et	0	main
keelest	doc_491521501801_item	3745363	et	0	main
eesti	doc_491521501801_item	3745364	et	0	main
keelde	doc_491521501801_item	3745365	et	0	main
kui	doc_491521501801_item	3745366	et	0	main
ka	doc_491521501801_item	3745367	et	0	main
suhtlemisel	doc_491521501801_item	3745368	et	0	main
õpilaste	doc_491521501801_item	3745369	et	0	main
töödes	doc_491521501801_item	3745370	et	0	main
esinevad	doc_491521501801_item	3745371	et	0	main
vead	doc_491521501801_item	3745372	et	0	main
on	doc_491521501801_item	3745373	et	0	main
tingitud	doc_491521501801_item	3745374	et	0	main
minu	doc_491521501801_item	3745375	et	0	main
arvates	doc_491521501801_item	3745376	et	0	main
sellest	doc_491521501801_item	3745377	et	0	main
et	doc_491521501801_item	3745378	et	0	main
nad	doc_491521501801_item	3745379	et	0	main
pole	doc_491521501801_item	3745380	et	0	main
vajalikus	doc_491521501801_item	3745381	et	0	main
ulatuses	doc_491521501801_item	3745382	et	0	main
omandanud	doc_491521501801_item	3745383	et	0	main
vastava	doc_491521501801_item	3745384	et	0	main
infinitiivi	doc_491521501801_item	3745385	et	0	main
kasutamisreegleid	doc_491521501801_item	3745386	et	0	main
kuid	doc_491521501801_item	3745387	et	0	main
mitte	doc_491521501801_item	3745388	et	0	main
alati	doc_491521501801_item	3745389	et	0	main
esineb	doc_491521501801_item	3745390	et	0	main
suhteliselt	doc_491521501801_item	3745391	et	0	main
palju	doc_491521501801_item	3745392	et	0	main
juhtumeid	doc_491521501801_item	3745393	et	0	main
mil	doc_491521501801_item	3745394	et	0	main
infinitiivi	doc_491521501801_item	3745395	et	0	main
valik	doc_491521501801_item	3745396	et	0	main
on	doc_491521501801_item	3745397	et	0	main
tehtud	doc_491521501801_item	3745398	et	0	main
õieti	doc_491521501801_item	3745399	et	0	main
viga	doc_491521501801_item	3745400	et	0	main
seisneb	doc_491521501801_item	3745401	et	0	main
vaid	doc_491521501801_item	3745402	et	0	main
vormimoodustuses	doc_491521501801_item	3745403	et	0	main
nt	doc_491521501801_item	3745404	et	0	main
ise	doc_491521501801_item	3745405	et	0	main
ma	doc_491521501801_item	3745406	et	0	main
neid	doc_491521501801_item	3745407	et	0	main
äalja	doc_491521501801_item	3745408	et	0	main
mõtelda	doc_491521501801_item	3745409	et	0	main
ei	doc_491521501801_item	3745410	et	0	main
suuda	doc_491521501801_item	3745411	et	0	main
tuleb	doc_491521501801_item	3745412	et	0	main
lilled	doc_491521501801_item	3745413	et	0	main
kaasa	doc_491521501801_item	3745414	et	0	main
võtada	doc_491521501801_item	3745415	et	0	main
tahan	doc_491521501801_item	3745416	et	0	main
täna	doc_491521501801_item	3745417	et	0	main
õnnidelda	doc_491521501801_item	3745418	et	0	main
jt	doc_491521501801_item	3745419	et	0	main
õpilaste	doc_491521501801_item	3745420	et	0	main
töödes	doc_491521501801_item	3745421	et	0	main
esinenud	doc_491521501801_item	3745422	et	0	main
vormid	doc_491521501801_item	3745423	et	0	main
õiged	doc_491521501801_item	3745424	et	0	main
vormid	doc_491521501801_item	3745425	et	0	main
on	doc_491521501801_item	3745426	et	0	main
meeldiv	doc_491521501801_item	3745427	et	0	main
viibita	doc_491521501801_item	3745428	et	0	main
65	doc_491521501801_item	3745429	et	0	main
viibida	doc_491521501801_item	3745430	et	0	main
jään	doc_491521501801_item	3745431	et	0	main
kaldale	doc_491521501801_item	3745432	et	0	main
päevitada	doc_491521501801_item	3745433	et	0	main
65	doc_491521501801_item	3745434	et	0	main
päevitama	doc_491521501801_item	3745435	et	0	main
saaks	doc_491521501801_item	3745436	et	0	main
talvel	doc_491521501801_item	3745437	et	0	main
suve	doc_491521501801_item	3745438	et	0	main
meenutama	doc_491521501801_item	3745439	et	0	main
65	doc_491521501801_item	3745440	et	0	main
meenutada	doc_491521501801_item	3745441	et	0	main
võib	doc_491521501801_item	3745442	et	0	main
ta	doc_491521501801_item	3745443	et	0	main
muretsema	doc_491521501801_item	3745444	et	0	main
hakkada	doc_491521501801_item	3745445	et	0	main
l3	doc_491521501801_item	3745446	et	0	main
hakata	doc_491521501801_item	3745447	et	0	main
ma	doc_491521501801_item	3745448	et	0	main
võin	doc_491521501801_item	3745449	et	0	main
ka	doc_491521501801_item	3745450	et	0	main
sind	doc_491521501801_item	3745451	et	0	main
ujuda	doc_491521501801_item	3745452	et	0	main
õpetada	doc_491521501801_item	3745453	et	0	main
65	doc_491521501801_item	3745454	et	0	main
ujuma	doc_491521501801_item	3745455	et	0	main
armastab	doc_491521501801_item	3745456	et	0	main
marju	doc_491521501801_item	3745457	et	0	main
korjada	doc_491521501801_item	3745458	et	0	main
20	doc_491521501801_item	3745459	et	0	main
korjama	doc_491521501801_item	3745460	et	0	main
on	doc_491521501801_item	3745461	et	0	main
vaja	doc_491521501801_item	3745462	et	0	main
pesu	doc_491521501801_item	3745463	et	0	main
pesema	doc_491521501801_item	3745464	et	0	main
26	doc_491521501801_item	3745465	et	0	main
pesta	doc_491521501801_item	3745466	et	0	main
tuleks	doc_491521501801_item	3745467	et	0	main
rohkem	doc_491521501801_item	3745468	et	0	main
suhtlema	doc_491521501801_item	3745469	et	0	main
20	doc_491521501801_item	3745470	et	0	main
suhelda	doc_491521501801_item	3745471	et	0	main
ei	doc_491521501801_item	3745472	et	0	main
taha	doc_491521501801_item	3745473	et	0	main
läbi	doc_491521501801_item	3745474	et	0	main
kukkuma	doc_491521501801_item	3745475	et	0	main
13	doc_491521501801_item	3745476	et	0	main
kukkuda	doc_491521501801_item	3745477	et	0	main
võiks	doc_491521501801_item	3745478	et	0	main
talle	doc_491521501801_item	3745479	et	0	main
sobita	doc_491521501801_item	3745480	et	0	main
65	doc_491521501801_item	3745481	et	0	main
sobida	doc_491521501801_item	3745482	et	0	main
ma	doc_491521501801_item	3745483	et	0	main
õpetan	doc_491521501801_item	3745484	et	0	main
teda	doc_491521501801_item	3745485	et	0	main
käske	doc_491521501801_item	3745486	et	0	main
täita	doc_491521501801_item	3745487	et	0	main
13	doc_491521501801_item	3745488	et	0	main
täitma	doc_491521501801_item	3745489	et	0	main
võiksid	doc_491521501801_item	3745490	et	0	main
ka	doc_491521501801_item	3745491	et	0	main
tordi	doc_491521501801_item	3745492	et	0	main
viida	doc_491521501801_item	3745493	et	0	main
viima	doc_491521501801_item	3745494	et	0	main
13	doc_491521501801_item	3745495	et	0	main
viia	doc_491521501801_item	3745496	et	0	main
armastab	doc_491521501801_item	3745497	et	0	main
korjama	doc_491521501801_item	3745498	et	0	main
ja	doc_491521501801_item	3745499	et	0	main
kimpudesse	doc_491521501801_item	3745500	et	0	main
seatada	doc_491521501801_item	3745501	et	0	main
seata	doc_491521501801_item	3745502	et	0	main
33	doc_491521501801_item	3745503	et	0	main
seata	doc_491521501801_item	3745504	et	0	main
võiksin	doc_491521501801_item	3745505	et	0	main
võtma	doc_491521501801_item	3745506	et	0	main
13	doc_491521501801_item	3745507	et	0	main
võtta	doc_491521501801_item	3745508	et	0	main
tuleks	doc_491521501801_item	3745509	et	0	main
suhtlema	doc_491521501801_item	3745510	et	0	main
13	doc_491521501801_item	3745511	et	0	main
suhelda	doc_491521501801_item	3745512	et	0	main
kui	doc_491521501801_item	3745513	et	0	main
raske	doc_491521501801_item	3745514	et	0	main
luuletus	doc_491521501801_item	3745515	et	0	main
on	doc_491521501801_item	3745516	et	0	main
antud	doc_491521501801_item	3745517	et	0	main
pähe	doc_491521501801_item	3745518	et	0	main
õppima	doc_491521501801_item	3745519	et	0	main
26	doc_491521501801_item	3745520	et	0	main
õppida	doc_491521501801_item	3745521	et	0	main
kas	doc_491521501801_item	3745522	et	0	main
saadata	doc_491521501801_item	3745523	et	0	main
saada	doc_491521501801_item	3745524	et	0	main
telegramm	doc_491521501801_item	3745525	et	0	main
või	doc_491521501801_item	3745526	et	0	main
minna	doc_491521501801_item	3745527	et	0	main
ise	doc_491521501801_item	3745528	et	0	main
60	doc_491521501801_item	3745529	et	0	main
saata	doc_491521501801_item	3745530	et	0	main
võime	doc_491521501801_item	3745531	et	0	main
neid	doc_491521501801_item	3745532	et	0	main
kaardilt	doc_491521501801_item	3745533	et	0	main
vaatama	doc_491521501801_item	3745534	et	0	main
13	doc_491521501801_item	3745535	et	0	main
vaadata	doc_491521501801_item	3745536	et	0	main
tuleb	doc_491521501801_item	3745537	et	0	main
lilled	doc_491521501801_item	3745538	et	0	main
kaasa	doc_491521501801_item	3745539	et	0	main
võtada	doc_491521501801_item	3745540	et	0	main
võtma	doc_491521501801_item	3745541	et	0	main
ja	doc_491521501801_item	3745542	et	0	main
sinna	doc_491521501801_item	3745543	et	0	main
sõidata	doc_491521501801_item	3745544	et	0	main
13	doc_491521501801_item	3745545	et	0	main
võtta	doc_491521501801_item	3745546	et	0	main
sõita	doc_491521501801_item	3745547	et	0	main
ise	doc_491521501801_item	3745548	et	0	main
ma	doc_491521501801_item	3745549	et	0	main
neid	doc_491521501801_item	3745550	et	0	main
välja	doc_491521501801_item	3745551	et	0	main
mõtleda	doc_491521501801_item	3745552	et	0	main
ei	doc_491521501801_item	3745553	et	0	main
suuda	doc_491521501801_item	3745554	et	0	main
40	doc_491521501801_item	3745555	et	0	main
mõelda	doc_491521501801_item	3745556	et	0	main
tulge	doc_491521501801_item	3745557	et	0	main
minuga	doc_491521501801_item	3745558	et	0	main
kohvi	doc_491521501801_item	3745559	et	0	main
juua	doc_491521501801_item	3745560	et	0	main
26	doc_491521501801_item	3745561	et	0	main
jooma	doc_491521501801_item	3745562	et	0	main
mul	doc_491521501801_item	3745563	et	0	main
ei	doc_491521501801_item	3745564	et	0	main
ole	doc_491521501801_item	3745565	et	0	main
aega	doc_491521501801_item	3745566	et	0	main
ootama	doc_491521501801_item	3745567	et	0	main
65	doc_491521501801_item	3745568	et	0	main
oodata	doc_491521501801_item	3745569	et	0	main
millal	doc_491521501801_item	3745570	et	0	main
te	doc_491521501801_item	3745571	et	0	main
lähete	doc_491521501801_item	3745572	et	0	main
supelda	doc_491521501801_item	3745573	et	0	main
26	doc_491521501801_item	3745574	et	0	main
suplema	doc_491521501801_item	3745575	et	0	main
kas	doc_491521501801_item	3745576	et	0	main
ma	doc_491521501801_item	3745577	et	0	main
võin	doc_491521501801_item	3745578	et	0	main
teid	doc_491521501801_item	3745579	et	0	main
aitama	doc_491521501801_item	3745580	et	0	main
65	doc_491521501801_item	3745581	et	0	main
aidata	doc_491521501801_item	3745582	et	0	main
ma	doc_491521501801_item	3745583	et	0	main
tahan	doc_491521501801_item	3745584	et	0	main
sööma	doc_491521501801_item	3745585	et	0	main
l3	doc_491521501801_item	3745586	et	0	main
süüa	doc_491521501801_item	3745587	et	0	main
kas	doc_491521501801_item	3745588	et	0	main
kartuleid	doc_491521501801_item	3745589	et	0	main
on	doc_491521501801_item	3745590	et	0	main
vaja	doc_491521501801_item	3745591	et	0	main
tooma	doc_491521501801_item	3745592	et	0	main
20	doc_491521501801_item	3745593	et	0	main
tuua	doc_491521501801_item	3745594	et	0	main
kuhu	doc_491521501801_item	3745595	et	0	main
te	doc_491521501801_item	3745596	et	0	main
sõidate	doc_491521501801_item	3745597	et	0	main
puhata	doc_491521501801_item	3745598	et	0	main
466	doc_491521501801_item	3745599	et	0	main
puhkama	doc_491521501801_item	3745600	et	0	main
võiksin	doc_491521501801_item	3745601	et	0	main
talle	doc_491521501801_item	3745602	et	0	main
ka	doc_491521501801_item	3745603	et	0	main
tordi	doc_491521501801_item	3745604	et	0	main
viida	doc_491521501801_item	3745605	et	0	main
26	doc_491521501801_item	3745606	et	0	main
viia	doc_491521501801_item	3745607	et	0	main
peame	doc_491521501801_item	3745608	et	0	main
rääkida	doc_491521501801_item	3745609	et	0	main
65	doc_491521501801_item	3745610	et	0	main
rääkima	doc_491521501801_item	3745611	et	0	main
pole	doc_491521501801_item	3745612	et	0	main
kerge	doc_491521501801_item	3745613	et	0	main
riigikeelt	doc_491521501801_item	3745614	et	0	main
selgeks	doc_491521501801_item	3745615	et	0	main
saama	doc_491521501801_item	3745616	et	0	main
333	doc_491521501801_item	3745617	et	0	main
saada	doc_491521501801_item	3745618	et	0	main
sügisel	doc_491521501801_item	3745619	et	0	main
asusime	doc_491521501801_item	3745620	et	0	main
õppida	doc_491521501801_item	3745621	et	0	main
40	doc_491521501801_item	3745622	et	0	main
õppima	doc_491521501801_item	3745623	et	0	main
jään	doc_491521501801_item	3745624	et	0	main
maale	doc_491521501801_item	3745625	et	0	main
elada	doc_491521501801_item	3745626	et	0	main
26	doc_491521501801_item	3745627	et	0	main
elama	doc_491521501801_item	3745628	et	0	main
lapsed	doc_491521501801_item	3745629	et	0	main
hakkavad	doc_491521501801_item	3745630	et	0	main
lauda	doc_491521501801_item	3745631	et	0	main
katta	doc_491521501801_item	3745632	et	0	main
13	doc_491521501801_item	3745633	et	0	main
katma	doc_491521501801_item	3745634	et	0	main
tahan	doc_491521501801_item	3745635	et	0	main
täna	doc_491521501801_item	3745636	et	0	main
õnnidelda	doc_491521501801_item	3745637	et	0	main
13	doc_491521501801_item	3745638	et	0	main
õnnitleda	doc_491521501801_item	3745639	et	0	main
meeldiv	doc_491521501801_item	3745640	et	0	main
oleks	doc_491521501801_item	3745641	et	0	main
teda	doc_491521501801_item	3745642	et	0	main
ennast	doc_491521501801_item	3745643	et	0	main
näeta	doc_491521501801_item	3745644	et	0	main
65	doc_491521501801_item	3745645	et	0	main
näha	doc_491521501801_item	3745646	et	0	main
sõnatasandi	doc_491521501801_item	3745647	et	0	main
vead	doc_491521501801_item	3745648	et	0	main
siia	doc_491521501801_item	3745649	et	0	main
kuuluvad	doc_491521501801_item	3745650	et	0	main
tõlkelaenud	doc_491521501801_item	3745651	et	0	main
õpilaste	doc_491521501801_item	3745652	et	0	main
töödes	doc_491521501801_item	3745653	et	0	main
esinenud	doc_491521501801_item	3745654	et	0	main
vormid	doc_491521501801_item	3745655	et	0	main
õiged	doc_491521501801_item	3745656	et	0	main
vormid	doc_491521501801_item	3745657	et	0	main
hakkame	doc_491521501801_item	3745658	et	0	main
sisse	doc_491521501801_item	3745659	et	0	main
sõitma	doc_491521501801_item	3745660	et	0	main
sisse	doc_491521501801_item	3745661	et	0	main
kolima	doc_491521501801_item	3745662	et	0	main
vene	doc_491521501801_item	3745663	et	0	main
k-s	doc_491521501801_item	3745664	et	0	main
вьезжать	doc_491521501801_item	3745665	et	0	main
seal	doc_491521501801_item	3745666	et	0	main
on	doc_491521501801_item	3745667	et	0	main
sauna	doc_491521501801_item	3745668	et	0	main
ja	doc_491521501801_item	3745669	et	0	main
saun	doc_491521501801_item	3745670	et	0	main
vene	doc_491521501801_item	3745671	et	0	main
k-s	doc_491521501801_item	3745672	et	0	main
сауна	doc_491521501801_item	3745673	et	0	main
mul	doc_491521501801_item	3745674	et	0	main
on	doc_491521501801_item	3745675	et	0	main
oma	doc_491521501801_item	3745676	et	0	main
tuba	doc_491521501801_item	3745677	et	0	main
ja	doc_491521501801_item	3745678	et	0	main
ma	doc_491521501801_item	3745679	et	0	main
olen	doc_491521501801_item	3745680	et	0	main
väga	doc_491521501801_item	3745681	et	0	main
rõõmus	doc_491521501801_item	3745682	et	0	main
sellepärast	doc_491521501801_item	3745683	et	0	main
selle	doc_491521501801_item	3745684	et	0	main
üle	doc_491521501801_item	3745685	et	0	main
vene	doc_491521501801_item	3745686	et	0	main
k-s	doc_491521501801_item	3745687	et	0	main
поэтому	doc_491521501801_item	3745688	et	0	main
parimate	doc_491521501801_item	3745689	et	0	main
tervitustega	doc_491521501801_item	3745690	et	0	main
sinust	doc_491521501801_item	3745691	et	0	main
sõbrast	doc_491521501801_item	3745692	et	0	main
sinu	doc_491521501801_item	3745693	et	0	main
sõber	doc_491521501801_item	3745694	et	0	main
jüri	doc_491521501801_item	3745695	et	0	main
vene	doc_491521501801_item	3745696	et	0	main
k-s	doc_491521501801_item	3745697	et	0	main
от	doc_491521501801_item	3745698	et	0	main
твоего	doc_491521501801_item	3745699	et	0	main
друга	doc_491521501801_item	3745700	et	0	main
юры	doc_491521501801_item	3745701	et	0	main
jürist	doc_491521501801_item	3745702	et	0	main
kabeltelevisioon	doc_491521501801_item	3745703	et	0	main
kaabeltelevisioon	doc_491521501801_item	3745704	et	0	main
vene	doc_491521501801_item	3745705	et	0	main
k-s	doc_491521501801_item	3745706	et	0	main
кабельное	doc_491521501801_item	3745707	et	0	main
телевидение	doc_491521501801_item	3745708	et	0	main
vanni	doc_491521501801_item	3745709	et	0	main
toas	doc_491521501801_item	3745710	et	0	main
vannitoas	doc_491521501801_item	3745711	et	0	main
vene	doc_491521501801_item	3745712	et	0	main
k-s	doc_491521501801_item	3745713	et	0	main
в	doc_491521501801_item	3745714	et	0	main
ванной	doc_491521501801_item	3745715	et	0	main
комнате	doc_491521501801_item	3745716	et	0	main
minu	doc_491521501801_item	3745717	et	0	main
kutsunimi	doc_491521501801_item	3745718	et	0	main
on	doc_491521501801_item	3745719	et	0	main
hüüdnimi	doc_491521501801_item	3745720	et	0	main
vene	doc_491521501801_item	3745721	et	0	main
k-s	doc_491521501801_item	3745722	et	0	main
прозвище	doc_491521501801_item	3745723	et	0	main
rektsioon	doc_491521501801_item	3745724	et	0	main
rektsioon	doc_491521501801_item	3745725	et	0	main
on	doc_491521501801_item	3745726	et	0	main
üks	doc_491521501801_item	3745727	et	0	main
raskemaid	doc_491521501801_item	3745728	et	0	main
ja	doc_491521501801_item	3745729	et	0	main
olulisemaid	doc_491521501801_item	3745730	et	0	main
teemasid	doc_491521501801_item	3745731	et	0	main
eesti	doc_491521501801_item	3745732	et	0	main
keeles	doc_491521501801_item	3745733	et	0	main
rektsioon	doc_491521501801_item	3745734	et	0	main
on	doc_491521501801_item	3745735	et	0	main
selline	doc_491521501801_item	3745736	et	0	main
olukord	doc_491521501801_item	3745737	et	0	main
mil	doc_491521501801_item	3745738	et	0	main
verb	doc_491521501801_item	3745739	et	0	main
määrab	doc_491521501801_item	3745740	et	0	main
temaga	doc_491521501801_item	3745741	et	0	main
seotud	doc_491521501801_item	3745742	et	0	main
sõnade	doc_491521501801_item	3745743	et	0	main
vormi	doc_491521501801_item	3745744	et	0	main
paljude	doc_491521501801_item	3745745	et	0	main
sõnade	doc_491521501801_item	3745746	et	0	main
juures	doc_491521501801_item	3745747	et	0	main
peab	doc_491521501801_item	3745748	et	0	main
rektsioon	doc_491521501801_item	3745749	et	0	main
lihtsalt	doc_491521501801_item	3745750	et	0	main
meelde	doc_491521501801_item	3745751	et	0	main
jätma	doc_491521501801_item	3745752	et	0	main
õpilaste	doc_491521501801_item	3745753	et	0	main
töödes	doc_491521501801_item	3745754	et	0	main
esinenud	doc_491521501801_item	3745755	et	0	main
vormid	doc_491521501801_item	3745756	et	0	main
õiged	doc_491521501801_item	3745757	et	0	main
vormid	doc_491521501801_item	3745758	et	0	main
mul	doc_491521501801_item	3745759	et	0	main
on	doc_491521501801_item	3745760	et	0	main
oma	doc_491521501801_item	3745761	et	0	main
tuba	doc_491521501801_item	3745762	et	0	main
ja	doc_491521501801_item	3745763	et	0	main
ma	doc_491521501801_item	3745764	et	0	main
olen	doc_491521501801_item	3745765	et	0	main
väga	doc_491521501801_item	3745766	et	0	main
rõõmus	doc_491521501801_item	3745767	et	0	main
sellepärast	doc_491521501801_item	3745768	et	0	main
selle	doc_491521501801_item	3745769	et	0	main
üle	doc_491521501801_item	3745770	et	0	main
mille	doc_491521501801_item	3745771	et	0	main
üle	doc_491521501801_item	3745772	et	0	main
ostsime	doc_491521501801_item	3745773	et	0	main
uue	doc_491521501801_item	3745774	et	0	main
riiuli	doc_491521501801_item	3745775	et	0	main
esikule	doc_491521501801_item	3745776	et	0	main
esikusse	doc_491521501801_item	3745777	et	0	main
kuhu	doc_491521501801_item	3745778	et	0	main
ma	doc_491521501801_item	3745779	et	0	main
käin	doc_491521501801_item	3745780	et	0	main
oma	doc_491521501801_item	3745781	et	0	main
emaga	doc_491521501801_item	3745782	et	0	main
uude	doc_491521501801_item	3745783	et	0	main
mööblikauplusesse	doc_491521501801_item	3745784	et	0	main
uues	doc_491521501801_item	3745785	et	0	main
mööblikaupluses	doc_491521501801_item	3745786	et	0	main
kus	doc_491521501801_item	3745787	et	0	main
me	doc_491521501801_item	3745788	et	0	main
ostsime	doc_491521501801_item	3745789	et	0	main
seal	doc_491521501801_item	3745790	et	0	main
sealt	doc_491521501801_item	3745791	et	0	main
kust	doc_491521501801_item	3745792	et	0	main
sellelt	doc_491521501801_item	3745793	et	0	main
peatuselt	doc_491521501801_item	3745794	et	0	main
ma	doc_491521501801_item	3745795	et	0	main
sõidan	doc_491521501801_item	3745796	et	0	main
kooli	doc_491521501801_item	3745797	et	0	main
sellest	doc_491521501801_item	3745798	et	0	main
peatusest	doc_491521501801_item	3745799	et	0	main
kust	doc_491521501801_item	3745800	et	0	main
käisin	doc_491521501801_item	3745801	et	0	main
haapsalu	doc_491521501801_item	3745802	et	0	main
haapsalus	doc_491521501801_item	3745803	et	0	main
kus	doc_491521501801_item	3745804	et	0	main
süntaks	doc_491521501801_item	3745805	et	0	main
kõige	doc_491521501801_item	3745806	et	0	main
rohkem	doc_491521501801_item	3745807	et	0	main
vigu	doc_491521501801_item	3745808	et	0	main
ca	doc_491521501801_item	3745809	et	0	main
70	doc_491521501801_item	3745810	et	0	main
unustati	doc_491521501801_item	3745811	et	0	main
koma	doc_491521501801_item	3745812	et	0	main
õpilaste	doc_491521501801_item	3745813	et	0	main
töödes	doc_491521501801_item	3745814	et	0	main
esinenud	doc_491521501801_item	3745815	et	0	main
vormid	doc_491521501801_item	3745816	et	0	main
õiged	doc_491521501801_item	3745817	et	0	main
vormid	doc_491521501801_item	3745818	et	0	main
tere	doc_491521501801_item	3745819	et	0	main
kallis	doc_491521501801_item	3745820	et	0	main
sõber	doc_491521501801_item	3745821	et	0	main
tere	doc_491521501801_item	3745822	et	0	main
kallis	doc_491521501801_item	3745823	et	0	main
sõber	doc_491521501801_item	3745824	et	0	main
tere	doc_491521501801_item	3745825	et	0	main
anne	doc_491521501801_item	3745826	et	0	main
tere	doc_491521501801_item	3745827	et	0	main
anne	doc_491521501801_item	3745828	et	0	main
koma	doc_491521501801_item	3745829	et	0	main
ei	doc_491521501801_item	3745830	et	0	main
ole	doc_491521501801_item	3745831	et	0	main
pandud	doc_491521501801_item	3745832	et	0	main
järgmistel	doc_491521501801_item	3745833	et	0	main
juhtudel	doc_491521501801_item	3745834	et	0	main
loodan	doc_491521501801_item	3745835	et	0	main
et	doc_491521501801_item	3745836	et	0	main
tuled	doc_491521501801_item	3745837	et	0	main
minu	doc_491521501801_item	3745838	et	0	main
juurde	doc_491521501801_item	3745839	et	0	main
loodan	doc_491521501801_item	3745840	et	0	main
et	doc_491521501801_item	3745841	et	0	main
sulle	doc_491521501801_item	3745842	et	0	main
sellepärast	doc_491521501801_item	3745843	et	0	main
et	doc_491521501801_item	3745844	et	0	main
sellepärast	doc_491521501801_item	3745845	et	0	main
et	doc_491521501801_item	3745846	et	0	main
loodan	doc_491521501801_item	3745847	et	0	main
et	doc_491521501801_item	3745848	et	0	main
talle	doc_491521501801_item	3745849	et	0	main
meeldib	doc_491521501801_item	3745850	et	0	main
loodan	doc_491521501801_item	3745851	et	0	main
et	doc_491521501801_item	3745852	et	0	main
talle	doc_491521501801_item	3745853	et	0	main
meeldib	doc_491521501801_item	3745854	et	0	main
kiri	doc_491521502053_item	3745855	et	0	main
lugege	doc_491521502053_item	3745856	et	0	main
läbi	doc_491521502053_item	3745857	et	0	main
kuulutus	doc_491521502053_item	3745858	et	0	main
ja	doc_491521502053_item	3745859	et	0	main
vastake	doc_491521502053_item	3745860	et	0	main
sellele	doc_491521502053_item	3745861	et	0	main
kirjas	doc_491521502053_item	3745862	et	0	main
peab	doc_491521502053_item	3745863	et	0	main
olema	doc_491521502053_item	3745864	et	0	main
umbes	doc_491521502053_item	3745865	et	0	main
60	doc_491521502053_item	3745866	et	0	main
sõna	doc_491521502053_item	3745867	et	0	main
tutvustage	doc_491521502053_item	3745868	et	0	main
ennast	doc_491521502053_item	3745869	et	0	main
perekonnaseis	doc_491521502053_item	3745870	et	0	main
haridus	doc_491521502053_item	3745871	et	0	main
töökogemused	doc_491521502053_item	3745872	et	0	main
keelteoskus	doc_491521502053_item	3745873	et	0	main
arvutioskus	doc_491521502053_item	3745874	et	0	main
autojuhiload	doc_491521502053_item	3745875	et	0	main
hobid	doc_491521502053_item	3745876	et	0	main
ja	doc_491521502053_item	3745877	et	0	main
kirjutage	doc_491521502053_item	3745878	et	0	main
oma	doc_491521502053_item	3745879	et	0	main
soovidest	doc_491521502053_item	3745880	et	0	main
millist	doc_491521502053_item	3745881	et	0	main
tööd	doc_491521502053_item	3745882	et	0	main
soovite	doc_491521502053_item	3745883	et	0	main
kui	doc_491521502053_item	3745884	et	0	main
suurt	doc_491521502053_item	3745885	et	0	main
töötasu	doc_491521502053_item	3745886	et	0	main
soovite	doc_491521502053_item	3745887	et	0	main
milline	doc_491521502053_item	3745888	et	0	main
töögraafik	doc_491521502053_item	3745889	et	0	main
sobib	doc_491521502053_item	3745890	et	0	main
kahe	doc_491521502053_item	3745891	et	0	main
kuu	doc_491521502053_item	3745892	et	0	main
pärast	doc_491521502053_item	3745893	et	0	main
avatakse	doc_491521502053_item	3745894	et	0	main
uus	doc_491521502053_item	3745895	et	0	main
toidukauplus	doc_491521502053_item	3745896	et	0	main
kauplusse	doc_491521502053_item	3745897	et	0	main
vajatakse	doc_491521502053_item	3745898	et	0	main
müüjat	doc_491521502053_item	3745899	et	0	main
kassapidajat	doc_491521502053_item	3745900	et	0	main
turvamehi	doc_491521502053_item	3745901	et	0	main
koristajaid	doc_491521502053_item	3745902	et	0	main
pakkijaid	doc_491521502053_item	3745903	et	0	main
kanditaatidelt	doc_491521502053_item	3745904	et	0	main
ootame	doc_491521502053_item	3745905	et	0	main
eesti	doc_491521502053_item	3745906	et	0	main
ja	doc_491521502053_item	3745907	et	0	main
vene	doc_491521502053_item	3745908	et	0	main
keele	doc_491521502053_item	3745909	et	0	main
oskust	doc_491521502053_item	3745910	et	0	main
head	doc_491521502053_item	3745911	et	0	main
suhtlemisoskust	doc_491521502053_item	3745912	et	0	main
soovitav	doc_491521502053_item	3745913	et	0	main
on	doc_491521502053_item	3745914	et	0	main
ka	doc_491521502053_item	3745915	et	0	main
arvutikasutusoskus	doc_491521502053_item	3745916	et	0	main
pakume	doc_491521502053_item	3745917	et	0	main
mugavaid	doc_491521502053_item	3745918	et	0	main
töötingimusi	doc_491521502053_item	3745919	et	0	main
teile	doc_491521502053_item	3745920	et	0	main
sobivat	doc_491521502053_item	3745921	et	0	main
töögraafikut	doc_491521502053_item	3745922	et	0	main
kindlat	doc_491521502053_item	3745923	et	0	main
palka	doc_491521502053_item	3745924	et	0	main
lisainfo	doc_491521502053_item	3745925	et	0	main
as	doc_491521502053_item	3745926	et	0	main
kakuke	doc_491521502053_item	3745927	et	0	main
juhuslik	doc_491521502053_item	3745928	et	0	main
mnt	doc_491521502053_item	3745929	et	0	main
3	doc_491521502053_item	3745930	et	0	main
tallinn	doc_491521502053_item	3745931	et	0	main
as	doc_491521502053_item	3745932	et	0	main
kakuke	doc_491521502053_item	3745933	et	0	main
direktorile	doc_491521502053_item	3745934	et	0	main
tallinn	doc_491521502053_item	3745935	et	0	main
tartu	doc_491521502053_item	3745936	et	0	main
mnt	doc_491521502053_item	3745937	et	0	main
3	doc_491521502053_item	3745938	et	0	main
eesnimi	doc_491521502053_item	3745939	et	0	main
perekonnanimi	doc_491521502053_item	3745940	et	0	main
elukoht	doc_491521502053_item	3745941	et	0	main
tallinn	doc_491521502053_item	3745942	et	0	main
juhuslik	doc_491521502053_item	3745943	et	0	main
pst	doc_491521502053_item	3745944	et	0	main
55	doc_491521502053_item	3745945	et	0	main
kor	doc_491521502053_item	3745946	et	0	main
5	doc_491521502053_item	3745947	et	0	main
kont	doc_491521502053_item	3745948	et	0	main
tel	doc_491521502053_item	3745949	et	0	main
5555555	doc_491521502053_item	3745950	et	0	main
isikukood	doc_491521502053_item	3745951	et	0	main
5555555	doc_491521502053_item	3745952	et	0	main
avaldus	doc_491521502053_item	3745953	et	0	main
palun	doc_491521502053_item	3745954	et	0	main
võtke	doc_491521502053_item	3745955	et	0	main
mind	doc_491521502053_item	3745956	et	0	main
tööle	doc_491521502053_item	3745957	et	0	main
ma	doc_491521502053_item	3745958	et	0	main
tahan	doc_491521502053_item	3745959	et	0	main
töötama	doc_491521502053_item	3745960	et	0	main
müüjana	doc_491521502053_item	3745961	et	0	main
või	doc_491521502053_item	3745962	et	0	main
kassapidajana	doc_491521502053_item	3745963	et	0	main
mulle	doc_491521502053_item	3745964	et	0	main
on	doc_491521502053_item	3745965	et	0	main
25	doc_491521502053_item	3745966	et	0	main
aastad	doc_491521502053_item	3745967	et	0	main
mul	doc_491521502053_item	3745968	et	0	main
on	doc_491521502053_item	3745969	et	0	main
hea	doc_491521502053_item	3745970	et	0	main
rahulik	doc_491521502053_item	3745971	et	0	main
iseloom	doc_491521502053_item	3745972	et	0	main
ma	doc_491521502053_item	3745973	et	0	main
lõpetasin	doc_491521502053_item	3745974	et	0	main
tallina	doc_491521502053_item	3745975	et	0	main
kaubakool	doc_491521502053_item	3745976	et	0	main
1997	doc_491521502053_item	3745977	et	0	main
aastal	doc_491521502053_item	3745978	et	0	main
pärast	doc_491521502053_item	3745979	et	0	main
ma	doc_491521502053_item	3745980	et	0	main
töötasin	doc_491521502053_item	3745981	et	0	main
müüjana	doc_491521502053_item	3745982	et	0	main
tallina	doc_491521502053_item	3745983	et	0	main
kaubamajja	doc_491521502053_item	3745984	et	0	main
minu	doc_491521502053_item	3745985	et	0	main
viimane	doc_491521502053_item	3745986	et	0	main
töökoht	doc_491521502053_item	3745987	et	0	main
on	doc_491521502053_item	3745988	et	0	main
kauplus	doc_491521502053_item	3745989	et	0	main
edu	doc_491521502053_item	3745990	et	0	main
kus	doc_491521502053_item	3745991	et	0	main
ma	doc_491521502053_item	3745992	et	0	main
töötasin	doc_491521502053_item	3745993	et	0	main
kassapidajana	doc_491521502053_item	3745994	et	0	main
ma	doc_491521502053_item	3745995	et	0	main
valdan	doc_491521502053_item	3745996	et	0	main
eesti	doc_491521502053_item	3745997	et	0	main
ja	doc_491521502053_item	3745998	et	0	main
vene	doc_491521502053_item	3745999	et	0	main
keelda	doc_491521502053_item	3746000	et	0	main
mul	doc_491521502053_item	3746001	et	0	main
on	doc_491521502053_item	3746002	et	0	main
hea	doc_491521502053_item	3746003	et	0	main
suhtlemisoskust	doc_491521502053_item	3746004	et	0	main
mulle	doc_491521502053_item	3746005	et	0	main
mugava	doc_491521502053_item	3746006	et	0	main
töötama	doc_491521502053_item	3746007	et	0	main
terve	doc_491521502053_item	3746008	et	0	main
nadala	doc_491521502053_item	3746009	et	0	main
kella	doc_491521502053_item	3746010	et	0	main
6	doc_491521502053_item	3746011	et	0	main
õhtuni	doc_491521502053_item	3746012	et	0	main
laupäeval	doc_491521502053_item	3746013	et	0	main
3	doc_491521502053_item	3746014	et	0	main
päevani	doc_491521502053_item	3746015	et	0	main
pühapäeval	doc_491521502053_item	3746016	et	0	main
on	doc_491521502053_item	3746017	et	0	main
puhkepäev	doc_491521502053_item	3746018	et	0	main
ma	doc_491521502053_item	3746019	et	0	main
tahan	doc_491521502053_item	3746020	et	0	main
saada	doc_491521502053_item	3746021	et	0	main
2	doc_491521502053_item	3746022	et	0	main
500	doc_491521502053_item	3746023	et	0	main
eek	doc_491521502053_item	3746024	et	0	main
eesnimi	doc_491521502053_item	3746025	et	0	main
perekonnanimi	doc_491521502053_item	3746026	et	0	main
kiri	doc_491521502059_item	3746410	et	0	main
lugege	doc_491521502059_item	3746411	et	0	main
läbi	doc_491521502059_item	3746412	et	0	main
kuulutus	doc_491521502059_item	3746413	et	0	main
ja	doc_491521502059_item	3746414	et	0	main
vastake	doc_491521502059_item	3746415	et	0	main
sellele	doc_491521502059_item	3746416	et	0	main
kirjas	doc_491521502059_item	3746417	et	0	main
peab	doc_491521502059_item	3746418	et	0	main
olema	doc_491521502059_item	3746419	et	0	main
umbes	doc_491521502059_item	3746420	et	0	main
60	doc_491521502059_item	3746421	et	0	main
sõna	doc_491521502059_item	3746422	et	0	main
tutvustage	doc_491521502059_item	3746423	et	0	main
ennast	doc_491521502059_item	3746424	et	0	main
perekonnaseis	doc_491521502059_item	3746425	et	0	main
haridus	doc_491521502059_item	3746426	et	0	main
töökogemused	doc_491521502059_item	3746427	et	0	main
keelteoskus	doc_491521502059_item	3746428	et	0	main
arvutioskus	doc_491521502059_item	3746429	et	0	main
autojuhiload	doc_491521502059_item	3746430	et	0	main
hobid	doc_491521502059_item	3746431	et	0	main
ja	doc_491521502059_item	3746432	et	0	main
kirjutage	doc_491521502059_item	3746433	et	0	main
oma	doc_491521502059_item	3746434	et	0	main
soovidest	doc_491521502059_item	3746435	et	0	main
millist	doc_491521502059_item	3746436	et	0	main
tööd	doc_491521502059_item	3746437	et	0	main
soovite	doc_491521502059_item	3746438	et	0	main
kui	doc_491521502059_item	3746439	et	0	main
suurt	doc_491521502059_item	3746440	et	0	main
töötasu	doc_491521502059_item	3746441	et	0	main
soovite	doc_491521502059_item	3746442	et	0	main
milline	doc_491521502059_item	3746443	et	0	main
töögraafik	doc_491521502059_item	3746444	et	0	main
sobib	doc_491521502059_item	3746445	et	0	main
kahe	doc_491521502059_item	3746446	et	0	main
kuu	doc_491521502059_item	3746447	et	0	main
pärast	doc_491521502059_item	3746448	et	0	main
avatakse	doc_491521502059_item	3746449	et	0	main
uus	doc_491521502059_item	3746450	et	0	main
toidukauplus	doc_491521502059_item	3746451	et	0	main
kauplusse	doc_491521502059_item	3746452	et	0	main
vajatakse	doc_491521502059_item	3746453	et	0	main
müüjat	doc_491521502059_item	3746454	et	0	main
kassapidajat	doc_491521502059_item	3746455	et	0	main
turvamehi	doc_491521502059_item	3746456	et	0	main
koristajaid	doc_491521502059_item	3746457	et	0	main
pakkijaid	doc_491521502059_item	3746458	et	0	main
kanditaatidelt	doc_491521502059_item	3746459	et	0	main
ootame	doc_491521502059_item	3746460	et	0	main
eesti	doc_491521502059_item	3746461	et	0	main
ja	doc_491521502059_item	3746462	et	0	main
vene	doc_491521502059_item	3746463	et	0	main
keele	doc_491521502059_item	3746464	et	0	main
oskust	doc_491521502059_item	3746465	et	0	main
head	doc_491521502059_item	3746466	et	0	main
suhtlemisoskust	doc_491521502059_item	3746467	et	0	main
soovitav	doc_491521502059_item	3746468	et	0	main
on	doc_491521502059_item	3746469	et	0	main
ka	doc_491521502059_item	3746470	et	0	main
arvutikasutusoskus	doc_491521502059_item	3746471	et	0	main
pakume	doc_491521502059_item	3746472	et	0	main
mugavaid	doc_491521502059_item	3746473	et	0	main
töötingimusi	doc_491521502059_item	3746474	et	0	main
teile	doc_491521502059_item	3746475	et	0	main
sobivat	doc_491521502059_item	3746476	et	0	main
töögraafikut	doc_491521502059_item	3746477	et	0	main
kindlat	doc_491521502059_item	3746478	et	0	main
palka	doc_491521502059_item	3746479	et	0	main
lisainfo	doc_491521502059_item	3746480	et	0	main
as	doc_491521502059_item	3746481	et	0	main
kakuke	doc_491521502059_item	3746482	et	0	main
tartu	doc_491521502059_item	3746483	et	0	main
mnt	doc_491521502059_item	3746484	et	0	main
3	doc_491521502059_item	3746485	et	0	main
tallinn	doc_491521502059_item	3746486	et	0	main
as	doc_491521502059_item	3746487	et	0	main
kakuke	doc_491521502059_item	3746488	et	0	main
eesnimi	doc_491521502059_item	3746489	et	0	main
perekonnanimi	doc_491521502059_item	3746490	et	0	main
sünd	doc_491521502059_item	3746491	et	0	main
15051966	doc_491521502059_item	3746492	et	0	main
a	doc_491521502059_item	3746493	et	0	main
eluk	doc_491521502059_item	3746494	et	0	main
k-jarve	doc_491521502059_item	3746495	et	0	main
juhuslik	doc_491521502059_item	3746496	et	0	main
1	doc_491521502059_item	3746497	et	0	main
11	doc_491521502059_item	3746498	et	0	main
t	doc_491521502059_item	3746499	et	0	main
66-666	doc_491521502059_item	3746500	et	0	main
lugupeetud	doc_491521502059_item	3746501	et	0	main
aktsiaseltsi	doc_491521502059_item	3746502	et	0	main
kakuke	doc_491521502059_item	3746503	et	0	main
direktor	doc_491521502059_item	3746504	et	0	main
ma	doc_491521502059_item	3746505	et	0	main
lugesin	doc_491521502059_item	3746506	et	0	main
läbi	doc_491521502059_item	3746507	et	0	main
teie	doc_491521502059_item	3746508	et	0	main
kuulutuse	doc_491521502059_item	3746509	et	0	main
postimehes	doc_491521502059_item	3746510	et	0	main
kus	doc_491521502059_item	3746511	et	0	main
on	doc_491521502059_item	3746512	et	0	main
kirjutanud	doc_491521502059_item	3746513	et	0	main
et	doc_491521502059_item	3746514	et	0	main
teie	doc_491521502059_item	3746515	et	0	main
toidukauplus	doc_491521502059_item	3746516	et	0	main
vajatakse	doc_491521502059_item	3746517	et	0	main
kassapidajaid	doc_491521502059_item	3746518	et	0	main
ma	doc_491521502059_item	3746519	et	0	main
töötasin	doc_491521502059_item	3746520	et	0	main
toidukaupluses	doc_491521502059_item	3746521	et	0	main
raja	doc_491521502059_item	3746522	et	0	main
ja	doc_491521502059_item	3746523	et	0	main
tean	doc_491521502059_item	3746524	et	0	main
kuidas	doc_491521502059_item	3746525	et	0	main
on	doc_491521502059_item	3746526	et	0	main
vaja	doc_491521502059_item	3746527	et	0	main
töötada	doc_491521502059_item	3746528	et	0	main
ma	doc_491521502059_item	3746529	et	0	main
valdan	doc_491521502059_item	3746530	et	0	main
vabalt	doc_491521502059_item	3746531	et	0	main
eesti	doc_491521502059_item	3746532	et	0	main
vene	doc_491521502059_item	3746533	et	0	main
ja	doc_491521502059_item	3746534	et	0	main
saksa	doc_491521502059_item	3746535	et	0	main
keelt	doc_491521502059_item	3746536	et	0	main
natuke	doc_491521502059_item	3746537	et	0	main
võin	doc_491521502059_item	3746538	et	0	main
rääkida	doc_491521502059_item	3746539	et	0	main
ka	doc_491521502059_item	3746540	et	0	main
soome	doc_491521502059_item	3746541	et	0	main
keeles	doc_491521502059_item	3746542	et	0	main
präegu	doc_491521502059_item	3746543	et	0	main
ma	doc_491521502059_item	3746544	et	0	main
käin	doc_491521502059_item	3746545	et	0	main
soome	doc_491521502059_item	3746546	et	0	main
keele	doc_491521502059_item	3746547	et	0	main
kursustel	doc_491521502059_item	3746548	et	0	main
viimasel	doc_491521502059_item	3746549	et	0	main
töökohal	doc_491521502059_item	3746550	et	0	main
töötasin	doc_491521502059_item	3746551	et	0	main
ma	doc_491521502059_item	3746552	et	0	main
väga	doc_491521502059_item	3746553	et	0	main
palju	doc_491521502059_item	3746554	et	0	main
ka	doc_491521502059_item	3746555	et	0	main
arvutiga	doc_491521502059_item	3746556	et	0	main
mulle	doc_491521502059_item	3746557	et	0	main
meeldib	doc_491521502059_item	3746558	et	0	main
teie	doc_491521502059_item	3746559	et	0	main
töögrafikut	doc_491521502059_item	3746560	et	0	main
ma	doc_491521502059_item	3746561	et	0	main
sooviksin	doc_491521502059_item	3746562	et	0	main
et	doc_491521502059_item	3746563	et	0	main
minu	doc_491521502059_item	3746564	et	0	main
palk	doc_491521502059_item	3746565	et	0	main
oleks	doc_491521502059_item	3746566	et	0	main
umbes	doc_491521502059_item	3746567	et	0	main
8000	doc_491521502059_item	3746568	et	0	main
eek	doc_491521502059_item	3746569	et	0	main
ma	doc_491521502059_item	3746570	et	0	main
ei	doc_491521502059_item	3746571	et	0	main
suitseta	doc_491521502059_item	3746572	et	0	main
ei	doc_491521502059_item	3746573	et	0	main
joo	doc_491521502059_item	3746574	et	0	main
ma	doc_491521502059_item	3746575	et	0	main
olen	doc_491521502059_item	3746576	et	0	main
abielus	doc_491521502059_item	3746577	et	0	main
mul	doc_491521502059_item	3746578	et	0	main
on	doc_491521502059_item	3746579	et	0	main
keskharidus	doc_491521502059_item	3746580	et	0	main
mul	doc_491521502059_item	3746581	et	0	main
on	doc_491521502059_item	3746582	et	0	main
autojuhiload	doc_491521502059_item	3746583	et	0	main
arvan	doc_491521502059_item	3746584	et	0	main
et	doc_491521502059_item	3746585	et	0	main
mul	doc_491521502059_item	3746586	et	0	main
on	doc_491521502059_item	3746587	et	0	main
õigus	doc_491521502059_item	3746588	et	0	main
looda	doc_491521502059_item	3746589	et	0	main
et	doc_491521502059_item	3746590	et	0	main
ma	doc_491521502059_item	3746591	et	0	main
saan	doc_491521502059_item	3746592	et	0	main
töö	doc_491521502059_item	3746593	et	0	main
teie	doc_491521502059_item	3746594	et	0	main
firmas	doc_491521502059_item	3746595	et	0	main
as	doc_491521502059_item	3746596	et	0	main
kakuke	doc_491521502059_item	3746597	et	0	main
29	doc_491521502059_item	3746598	et	0	main
sept	doc_491521502059_item	3746599	et	0	main
01	doc_491521502059_item	3746600	et	0	main
allkiri	doc_491521502059_item	3746601	et	0	main
kiri	doc_491521501952_item	3746602	et	0	main
lugege	doc_491521501952_item	3746603	et	0	main
läbi	doc_491521501952_item	3746604	et	0	main
kuulutus	doc_491521501952_item	3746605	et	0	main
ja	doc_491521501952_item	3746606	et	0	main
vastake	doc_491521501952_item	3746607	et	0	main
sellele	doc_491521501952_item	3746608	et	0	main
kirjas	doc_491521501952_item	3746609	et	0	main
peab	doc_491521501952_item	3746610	et	0	main
olema	doc_491521501952_item	3746611	et	0	main
umbes	doc_491521501952_item	3746612	et	0	main
60	doc_491521501952_item	3746613	et	0	main
sõna	doc_491521501952_item	3746614	et	0	main
tutvustage	doc_491521501952_item	3746615	et	0	main
ennast	doc_491521501952_item	3746616	et	0	main
perekonnaseis	doc_491521501952_item	3746617	et	0	main
haridus	doc_491521501952_item	3746618	et	0	main
töökogemused	doc_491521501952_item	3746619	et	0	main
keelteoskus	doc_491521501952_item	3746620	et	0	main
arvutioskus	doc_491521501952_item	3746621	et	0	main
autojuhiload	doc_491521501952_item	3746622	et	0	main
hobid	doc_491521501952_item	3746623	et	0	main
ja	doc_491521501952_item	3746624	et	0	main
kirjutage	doc_491521501952_item	3746625	et	0	main
oma	doc_491521501952_item	3746626	et	0	main
soovidest	doc_491521501952_item	3746627	et	0	main
millist	doc_491521501952_item	3746628	et	0	main
tööd	doc_491521501952_item	3746629	et	0	main
soovite	doc_491521501952_item	3746630	et	0	main
kui	doc_491521501952_item	3746631	et	0	main
suurt	doc_491521501952_item	3746632	et	0	main
töötasu	doc_491521501952_item	3746633	et	0	main
soovite	doc_491521501952_item	3746634	et	0	main
milline	doc_491521501952_item	3746635	et	0	main
töögraafik	doc_491521501952_item	3746636	et	0	main
sobib	doc_491521501952_item	3746637	et	0	main
kahe	doc_491521501952_item	3746638	et	0	main
kuu	doc_491521501952_item	3746639	et	0	main
pärast	doc_491521501952_item	3746640	et	0	main
avatakse	doc_491521501952_item	3746641	et	0	main
uus	doc_491521501952_item	3746642	et	0	main
toidukauplus	doc_491521501952_item	3746643	et	0	main
kauplusse	doc_491521501952_item	3746644	et	0	main
vajatakse	doc_491521501952_item	3746645	et	0	main
müüjat	doc_491521501952_item	3746646	et	0	main
kassapidajat	doc_491521501952_item	3746647	et	0	main
turvamehi	doc_491521501952_item	3746648	et	0	main
koristajaid	doc_491521501952_item	3746649	et	0	main
pakkijaid	doc_491521501952_item	3746650	et	0	main
kanditaatidelt	doc_491521501952_item	3746651	et	0	main
ootame	doc_491521501952_item	3746652	et	0	main
eesti	doc_491521501952_item	3746653	et	0	main
ja	doc_491521501952_item	3746654	et	0	main
vene	doc_491521501952_item	3746655	et	0	main
keele	doc_491521501952_item	3746656	et	0	main
oskust	doc_491521501952_item	3746657	et	0	main
head	doc_491521501952_item	3746658	et	0	main
suhtlemisoskust	doc_491521501952_item	3746659	et	0	main
soovitav	doc_491521501952_item	3746660	et	0	main
on	doc_491521501952_item	3746661	et	0	main
ka	doc_491521501952_item	3746662	et	0	main
arvutikasutusoskus	doc_491521501952_item	3746663	et	0	main
pakume	doc_491521501952_item	3746664	et	0	main
mugavaid	doc_491521501952_item	3746665	et	0	main
töötingimusi	doc_491521501952_item	3746666	et	0	main
teile	doc_491521501952_item	3746667	et	0	main
sobivat	doc_491521501952_item	3746668	et	0	main
töögraafikut	doc_491521501952_item	3746669	et	0	main
kindlat	doc_491521501952_item	3746670	et	0	main
palka	doc_491521501952_item	3746671	et	0	main
lisainfo	doc_491521501952_item	3746672	et	0	main
as	doc_491521501952_item	3746673	et	0	main
kakuke	doc_491521501952_item	3746674	et	0	main
tartu	doc_491521501952_item	3746675	et	0	main
mnt3	doc_491521501952_item	3746676	et	0	main
tallinn	doc_491521501952_item	3746677	et	0	main
lugupeetud	doc_491521501952_item	3746678	et	0	main
firmajuht	doc_491521501952_item	3746679	et	0	main
ma	doc_491521501952_item	3746680	et	0	main
teatsin	doc_491521501952_item	3746681	et	0	main
et	doc_491521501952_item	3746682	et	0	main
teie	doc_491521501952_item	3746683	et	0	main
kauplusesse	doc_491521501952_item	3746684	et	0	main
vajatakse	doc_491521501952_item	3746685	et	0	main
müüjat	doc_491521501952_item	3746686	et	0	main
sellel	doc_491521501952_item	3746687	et	0	main
aastal	doc_491521501952_item	3746688	et	0	main
ma	doc_491521501952_item	3746689	et	0	main
lõppetasin	doc_491521501952_item	3746690	et	0	main
müüjakursuste	doc_491521501952_item	3746691	et	0	main
kus	doc_491521501952_item	3746692	et	0	main
ma	doc_491521501952_item	3746693	et	0	main
õppisin	doc_491521501952_item	3746694	et	0	main
ka	doc_491521501952_item	3746695	et	0	main
töötama	doc_491521501952_item	3746696	et	0	main
arvutil	doc_491521501952_item	3746697	et	0	main
ja	doc_491521501952_item	3746698	et	0	main
kassal	doc_491521501952_item	3746699	et	0	main
kolm	doc_491521501952_item	3746700	et	0	main
aastat	doc_491521501952_item	3746701	et	0	main
õpin	doc_491521501952_item	3746702	et	0	main
eesti	doc_491521501952_item	3746703	et	0	main
keelt	doc_491521501952_item	3746704	et	0	main
üks	doc_491521501952_item	3746705	et	0	main
kuu	doc_491521501952_item	3746706	et	0	main
oli	doc_491521501952_item	3746707	et	0	main
praktikal	doc_491521501952_item	3746708	et	0	main
ja	doc_491521501952_item	3746709	et	0	main
selle	doc_491521501952_item	3746710	et	0	main
eest	doc_491521501952_item	3746711	et	0	main
sai	doc_491521501952_item	3746712	et	0	main
viie	doc_491521501952_item	3746713	et	0	main
mina	doc_491521501952_item	3746714	et	0	main
elan	doc_491521501952_item	3746715	et	0	main
oma	doc_491521501952_item	3746716	et	0	main
ema	doc_491521501952_item	3746717	et	0	main
ja	doc_491521501952_item	3746718	et	0	main
tütrega	doc_491521501952_item	3746719	et	0	main
mul	doc_491521501952_item	3746720	et	0	main
on	doc_491521501952_item	3746721	et	0	main
keskeriharidus	doc_491521501952_item	3746722	et	0	main
ma	doc_491521501952_item	3746723	et	0	main
õppisin	doc_491521501952_item	3746724	et	0	main
algklassideõpetajaks	doc_491521501952_item	3746725	et	0	main
ja	doc_491521501952_item	3746726	et	0	main
töötasin	doc_491521501952_item	3746727	et	0	main
koolis	doc_491521501952_item	3746728	et	0	main
15	doc_491521501952_item	3746729	et	0	main
aastat	doc_491521501952_item	3746730	et	0	main
praegu	doc_491521501952_item	3746731	et	0	main
ma	doc_491521501952_item	3746732	et	0	main
ei	doc_491521501952_item	3746733	et	0	main
tööta	doc_491521501952_item	3746734	et	0	main
ma	doc_491521501952_item	3746735	et	0	main
arvan	doc_491521501952_item	3746736	et	0	main
et	doc_491521501952_item	3746737	et	0	main
töö	doc_491521501952_item	3746738	et	0	main
lastega	doc_491521501952_item	3746739	et	0	main
andis	doc_491521501952_item	3746740	et	0	main
mulle	doc_491521501952_item	3746741	et	0	main
suhtlemisoskust	doc_491521501952_item	3746742	et	0	main
ma	doc_491521501952_item	3746743	et	0	main
palju	doc_491521501952_item	3746744	et	0	main
reisisin	doc_491521501952_item	3746745	et	0	main
ja	doc_491521501952_item	3746746	et	0	main
matkasin	doc_491521501952_item	3746747	et	0	main
ja	doc_491521501952_item	3746748	et	0	main
kerge	doc_491521501952_item	3746749	et	0	main
tunnen	doc_491521501952_item	3746750	et	0	main
inimesi	doc_491521501952_item	3746751	et	0	main
ma	doc_491521501952_item	3746752	et	0	main
tahaksin	doc_491521501952_item	3746753	et	0	main
saada	doc_491521501952_item	3746754	et	0	main
teil	doc_491521501952_item	3746755	et	0	main
tööd	doc_491521501952_item	3746756	et	0	main
mulle	doc_491521501952_item	3746757	et	0	main
sobib	doc_491521501952_item	3746758	et	0	main
selline	doc_491521501952_item	3746759	et	0	main
töögraafik	doc_491521501952_item	3746760	et	0	main
kui	doc_491521501952_item	3746761	et	0	main
te	doc_491521501952_item	3746762	et	0	main
töötate	doc_491521501952_item	3746763	et	0	main
iga	doc_491521501952_item	3746764	et	0	main
päev	doc_491521501952_item	3746765	et	0	main
siis	doc_491521501952_item	3746766	et	0	main
tahaksin	doc_491521501952_item	3746767	et	0	main
üks	doc_491521501952_item	3746768	et	0	main
puhkepäev	doc_491521501952_item	3746769	et	0	main
on	doc_491521501952_item	3746770	et	0	main
pühapäeval	doc_491521501952_item	3746771	et	0	main
ja	doc_491521501952_item	3746772	et	0	main
teine	doc_491521501952_item	3746773	et	0	main
tööpäeval	doc_491521501952_item	3746774	et	0	main
töötasu	doc_491521501952_item	3746775	et	0	main
soovin	doc_491521501952_item	3746776	et	0	main
3000-4000	doc_491521501952_item	3746777	et	0	main
krooni	doc_491521501952_item	3746778	et	0	main
ja	doc_491521501952_item	3746779	et	0	main
puhkus	doc_491521501952_item	3746780	et	0	main
parem	doc_491521501952_item	3746781	et	0	main
suvel	doc_491521501952_item	3746782	et	0	main
sest	doc_491521501952_item	3746783	et	0	main
minu	doc_491521501952_item	3746784	et	0	main
tütar	doc_491521501952_item	3746785	et	0	main
õpib	doc_491521501952_item	3746786	et	0	main
koolis	doc_491521501952_item	3746787	et	0	main
ja	doc_491521501952_item	3746788	et	0	main
tal	doc_491521501952_item	3746789	et	0	main
on	doc_491521501952_item	3746790	et	0	main
sellel	doc_491521501952_item	3746791	et	0	main
ajal	doc_491521501952_item	3746792	et	0	main
koolivaheaeg	doc_491521501952_item	3746793	et	0	main
kõik	doc_491521501952_item	3746794	et	0	main
tööd	doc_491521501952_item	3746795	et	0	main
ma	doc_491521501952_item	3746796	et	0	main
püüan	doc_491521501952_item	3746797	et	0	main
teha	doc_491521501952_item	3746798	et	0	main
hästi	doc_491521501952_item	3746799	et	0	main
ootan	doc_491521501952_item	3746800	et	0	main
vastust	doc_491521501952_item	3746801	et	0	main
ametlik	doc_634572338216_item	3746802	et	0	main
kiri	doc_634572338216_item	3746803	et	0	main
arvamuse	doc_634572338216_item	3746804	et	0	main
eesti	doc_634572338216_item	3746805	et	0	main
ekspressitoimetaja	doc_634572338216_item	3746806	et	0	main
tiina	doc_634572338216_item	3746807	et	0	main
kaalepi	doc_634572338216_item	3746808	et	0	main
artikli	doc_634572338216_item	3746809	et	0	main
kohta	doc_634572338216_item	3746810	et	0	main
arikkel	doc_634572338216_item	3746811	et	0	main
vt	doc_634572338216_item	3746812	et	0	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338216_item	3746813	et	0	main
kiri	doc_634572338216_item	3746814	et	0	main
tiina	doc_634572338216_item	3746815	et	0	main
kaalepile	doc_634572338216_item	3746816	et	0	main
lp	doc_634572338216_item	3746817	et	0	main
tiina	doc_634572338216_item	3746818	et	0	main
kaalep	doc_634572338216_item	3746819	et	0	main
minu	doc_634572338216_item	3746820	et	0	main
nimi	doc_634572338216_item	3746821	et	0	main
on	doc_634572338216_item	3746822	et	0	main
eesnimi	doc_634572338216_item	3746823	et	0	main
kirjutan	doc_634572338216_item	3746824	et	0	main
teile	doc_634572338216_item	3746825	et	0	main
sellepärast	doc_634572338216_item	3746826	et	0	main
et	doc_634572338216_item	3746827	et	0	main
olen	doc_634572338216_item	3746828	et	0	main
teie	doc_634572338216_item	3746829	et	0	main
juhtkiri	doc_634572338216_item	3746830	et	0	main
lugenud	doc_634572338216_item	3746831	et	0	main
ma	doc_634572338216_item	3746832	et	0	main
õpin	doc_634572338216_item	3746833	et	0	main
tallinna	doc_634572338216_item	3746834	et	0	main
tehnikaülikoolis	doc_634572338216_item	3746835	et	0	main
esimesel	doc_634572338216_item	3746836	et	0	main
kursusel	doc_634572338216_item	3746837	et	0	main
elektriajamite	doc_634572338216_item	3746838	et	0	main
ja	doc_634572338216_item	3746839	et	0	main
jõuelektronika	doc_634572338216_item	3746840	et	0	main
erialalas	doc_634572338216_item	3746841	et	0	main
ma	doc_634572338216_item	3746842	et	0	main
olen	doc_634572338216_item	3746843	et	0	main
üheksateist	doc_634572338216_item	3746844	et	0	main
aastat	doc_634572338216_item	3746845	et	0	main
vana	doc_634572338216_item	3746846	et	0	main
ma	doc_634572338216_item	3746847	et	0	main
kirjutan	doc_634572338216_item	3746848	et	0	main
teile	doc_634572338216_item	3746849	et	0	main
sellepärast	doc_634572338216_item	3746850	et	0	main
et	doc_634572338216_item	3746851	et	0	main
olen	doc_634572338216_item	3746852	et	0	main
teie	doc_634572338216_item	3746853	et	0	main
juhtkiri	doc_634572338216_item	3746854	et	0	main
lugenud	doc_634572338216_item	3746855	et	0	main
arvan	doc_634572338216_item	3746856	et	0	main
et	doc_634572338216_item	3746857	et	0	main
see	doc_634572338216_item	3746858	et	0	main
on	doc_634572338216_item	3746859	et	0	main
väga	doc_634572338216_item	3746860	et	0	main
põnev	doc_634572338216_item	3746861	et	0	main
ja	doc_634572338216_item	3746862	et	0	main
kasulik	doc_634572338216_item	3746863	et	0	main
tekst	doc_634572338216_item	3746864	et	0	main
ma	doc_634572338216_item	3746865	et	0	main
olen	doc_634572338216_item	3746866	et	0	main
teiega	doc_634572338216_item	3746867	et	0	main
nõus	doc_634572338216_item	3746868	et	0	main
et	doc_634572338216_item	3746869	et	0	main
on	doc_634572338216_item	3746870	et	0	main
rühmad	doc_634572338216_item	3746871	et	0	main
rahvast	doc_634572338216_item	3746872	et	0	main
esimesed	doc_634572338216_item	3746873	et	0	main
täesti	doc_634572338216_item	3746874	et	0	main
teavad	doc_634572338216_item	3746875	et	0	main
millega	doc_634572338216_item	3746876	et	0	main
nad	doc_634572338216_item	3746877	et	0	main
tulevikus	doc_634572338216_item	3746878	et	0	main
tegelevad	doc_634572338216_item	3746879	et	0	main
nendel	doc_634572338216_item	3746880	et	0	main
on	doc_634572338216_item	3746881	et	0	main
eesmärk	doc_634572338216_item	3746882	et	0	main
kuhu	doc_634572338216_item	3746883	et	0	main
nad	doc_634572338216_item	3746884	et	0	main
lähevad	doc_634572338216_item	3746885	et	0	main
kui	doc_634572338216_item	3746886	et	0	main
eesmärk	doc_634572338216_item	3746887	et	0	main
on	doc_634572338216_item	3746888	et	0	main
läbi	doc_634572338216_item	3746889	et	0	main
käinud	doc_634572338216_item	3746890	et	0	main
siis	doc_634572338216_item	3746891	et	0	main
nad	doc_634572338216_item	3746892	et	0	main
võtavad	doc_634572338216_item	3746893	et	0	main
endale	doc_634572338216_item	3746894	et	0	main
uus	doc_634572338216_item	3746895	et	0	main
töö	doc_634572338216_item	3746896	et	0	main
nendel	doc_634572338216_item	3746897	et	0	main
kõik	doc_634572338216_item	3746898	et	0	main
on	doc_634572338216_item	3746899	et	0	main
korras	doc_634572338216_item	3746900	et	0	main
aga	doc_634572338216_item	3746901	et	0	main
veel	doc_634572338216_item	3746902	et	0	main
on	doc_634572338216_item	3746903	et	0	main
teised	doc_634572338216_item	3746904	et	0	main
rühmad	doc_634572338216_item	3746905	et	0	main
järgmises	doc_634572338216_item	3746906	et	0	main
rühmas	doc_634572338216_item	3746907	et	0	main
inimesed	doc_634572338216_item	3746908	et	0	main
ei	doc_634572338216_item	3746909	et	0	main
teavad	doc_634572338216_item	3746910	et	0	main
mida	doc_634572338216_item	3746911	et	0	main
nad	doc_634572338216_item	3746912	et	0	main
homme	doc_634572338216_item	3746913	et	0	main
olevad	doc_634572338216_item	3746914	et	0	main
tegema	doc_634572338216_item	3746915	et	0	main
nad	doc_634572338216_item	3746916	et	0	main
ei	doc_634572338216_item	3746917	et	0	main
tea	doc_634572338216_item	3746918	et	0	main
mis	doc_634572338216_item	3746919	et	0	main
neist	doc_634572338216_item	3746920	et	0	main
saab	doc_634572338216_item	3746921	et	0	main
nad	doc_634572338216_item	3746922	et	0	main
tuulevad	doc_634572338216_item	3746923	et	0	main
õppima	doc_634572338216_item	3746924	et	0	main
riigieksamite	doc_634572338216_item	3746925	et	0	main
tulemuse	doc_634572338216_item	3746926	et	0	main
looteriga	doc_634572338216_item	3746927	et	0	main
see	doc_634572338216_item	3746928	et	0	main
on	doc_634572338216_item	3746929	et	0	main
väga	doc_634572338216_item	3746930	et	0	main
halvasti	doc_634572338216_item	3746931	et	0	main
inimesele	doc_634572338216_item	3746932	et	0	main
kes	doc_634572338216_item	3746933	et	0	main
looteri	doc_634572338216_item	3746934	et	0	main
pärast	doc_634572338216_item	3746935	et	0	main
on	doc_634572338216_item	3746936	et	0	main
ülikoolis	doc_634572338216_item	3746937	et	0	main
ja	doc_634572338216_item	3746938	et	0	main
põlvkonnadele	doc_634572338216_item	3746939	et	0	main
üldselt	doc_634572338216_item	3746940	et	0	main
inemesed	doc_634572338216_item	3746941	et	0	main
sellest	doc_634572338216_item	3746942	et	0	main
rühmast	doc_634572338216_item	3746943	et	0	main
ei	doc_634572338216_item	3746944	et	0	main
mõtlevad	doc_634572338216_item	3746945	et	0	main
kuidas	doc_634572338216_item	3746946	et	0	main
tulevikus	doc_634572338216_item	3746947	et	0	main
elama	doc_634572338216_item	3746948	et	0	main
nendele	doc_634572338216_item	3746949	et	0	main
on	doc_634572338216_item	3746950	et	0	main
tähtsam	doc_634572338216_item	3746951	et	0	main
tänane	doc_634572338216_item	3746952	et	0	main
päev	doc_634572338216_item	3746953	et	0	main
kui	doc_634572338216_item	3746954	et	0	main
tulevik	doc_634572338216_item	3746955	et	0	main
hea	doc_634572338216_item	3746956	et	0	main
palk	doc_634572338216_item	3746957	et	0	main
pere	doc_634572338216_item	3746958	et	0	main
ja	doc_634572338216_item	3746959	et	0	main
kodu	doc_634572338216_item	3746960	et	0	main
te	doc_634572338216_item	3746961	et	0	main
kirjutasite	doc_634572338216_item	3746962	et	0	main
et	doc_634572338216_item	3746963	et	0	main
hoopis	doc_634572338216_item	3746964	et	0	main
inimesed	doc_634572338216_item	3746965	et	0	main
on	doc_634572338216_item	3746966	et	0	main
väga	doc_634572338216_item	3746967	et	0	main
realistlikud	doc_634572338216_item	3746968	et	0	main
ma	doc_634572338216_item	3746969	et	0	main
olen	doc_634572338216_item	3746970	et	0	main
sellega	doc_634572338216_item	3746971	et	0	main
ka	doc_634572338216_item	3746972	et	0	main
nõus	doc_634572338216_item	3746973	et	0	main
kõik	doc_634572338216_item	3746974	et	0	main
inemesed	doc_634572338216_item	3746975	et	0	main
teavad	doc_634572338216_item	3746976	et	0	main
et	doc_634572338216_item	3746977	et	0	main
on	doc_634572338216_item	3746978	et	0	main
vaja	doc_634572338216_item	3746979	et	0	main
õppima	doc_634572338216_item	3746980	et	0	main
ja	doc_634572338216_item	3746981	et	0	main
töötama	doc_634572338216_item	3746982	et	0	main
ennast	doc_634572338216_item	3746983	et	0	main
aga	doc_634572338216_item	3746984	et	0	main
teha	doc_634572338216_item	3746985	et	0	main
see	doc_634572338216_item	3746986	et	0	main
nendele	doc_634572338216_item	3746987	et	0	main
on	doc_634572338216_item	3746988	et	0	main
väga	doc_634572338216_item	3746989	et	0	main
raske	doc_634572338216_item	3746990	et	0	main
tihti	doc_634572338216_item	3746991	et	0	main
inimesed	doc_634572338216_item	3746992	et	0	main
ei	doc_634572338216_item	3746993	et	0	main
õppe	doc_634572338216_item	3746994	et	0	main
ei	doc_634572338216_item	3746995	et	0	main
tööta	doc_634572338216_item	3746996	et	0	main
selleparast	doc_634572338216_item	3746997	et	0	main
et	doc_634572338216_item	3746998	et	0	main
nad	doc_634572338216_item	3746999	et	0	main
mõtlevad	doc_634572338216_item	3747000	et	0	main
oma	doc_634572338216_item	3747001	et	0	main
halbadest	doc_634572338216_item	3747002	et	0	main
võimalusest	doc_634572338216_item	3747003	et	0	main
aga	doc_634572338216_item	3747004	et	0	main
on	doc_634572338216_item	3747005	et	0	main
vaja	doc_634572338216_item	3747006	et	0	main
tehe	doc_634572338216_item	3747007	et	0	main
teistmodi	doc_634572338216_item	3747008	et	0	main
usuma	doc_634572338216_item	3747009	et	0	main
ennasele	doc_634572338216_item	3747010	et	0	main
mulle	doc_634572338216_item	3747011	et	0	main
teie	doc_634572338216_item	3747012	et	0	main
juhtkiri	doc_634572338216_item	3747013	et	0	main
väga	doc_634572338216_item	3747014	et	0	main
meldis	doc_634572338216_item	3747015	et	0	main
kirjutage	doc_634572338216_item	3747016	et	0	main
palun	doc_634572338216_item	3747017	et	0	main
edasi	doc_634572338216_item	3747018	et	0	main
niisugused	doc_634572338216_item	3747019	et	0	main
asjad	doc_634572338216_item	3747020	et	0	main
arvan	doc_634572338216_item	3747021	et	0	main
et	doc_634572338216_item	3747022	et	0	main
palju	doc_634572338216_item	3747023	et	0	main
inemisi	doc_634572338216_item	3747024	et	0	main
tahavad	doc_634572338216_item	3747025	et	0	main
veel	doc_634572338216_item	3747026	et	0	main
lugema	doc_634572338216_item	3747027	et	0	main
teie	doc_634572338216_item	3747028	et	0	main
tööid	doc_634572338216_item	3747029	et	0	main
sellega	doc_634572338216_item	3747030	et	0	main
ma	doc_634572338216_item	3747031	et	0	main
lõpetasin	doc_634572338216_item	3747032	et	0	main
oma	doc_634572338216_item	3747033	et	0	main
kiri	doc_634572338216_item	3747034	et	0	main
lugupidamisega	doc_634572338216_item	3747035	et	0	main
eesnimi	doc_634572338216_item	3747036	et	0	main
ametlik	doc_634572338214_item	3747037	et	0	main
kiri	doc_634572338214_item	3747038	et	0	main
arvamuse	doc_634572338214_item	3747039	et	0	main
eesti	doc_634572338214_item	3747040	et	0	main
ekspressi	doc_634572338214_item	3747041	et	0	main
toimetaja	doc_634572338214_item	3747042	et	0	main
tiina	doc_634572338214_item	3747043	et	0	main
kaalepi	doc_634572338214_item	3747044	et	0	main
artikli	doc_634572338214_item	3747045	et	0	main
kohta	doc_634572338214_item	3747046	et	0	main
arikkel	doc_634572338214_item	3747047	et	0	main
vt	doc_634572338214_item	3747048	et	0	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338214_item	3747049	et	0	main
kiri	doc_634572338214_item	3747050	et	0	main
tiina	doc_634572338214_item	3747051	et	0	main
kaalepile	doc_634572338214_item	3747052	et	0	main
tere	doc_634572338214_item	3747053	et	0	main
lugupeetud	doc_634572338214_item	3747054	et	0	main
tiina	doc_634572338214_item	3747055	et	0	main
kaalep	doc_634572338214_item	3747056	et	0	main
hiljuti	doc_634572338214_item	3747057	et	0	main
ma	doc_634572338214_item	3747058	et	0	main
lugesin	doc_634572338214_item	3747059	et	0	main
teie	doc_634572338214_item	3747060	et	0	main
artiiklit	doc_634572338214_item	3747061	et	0	main
ajalehest	doc_634572338214_item	3747062	et	0	main
ja	doc_634572338214_item	3747063	et	0	main
otsustasin	doc_634572338214_item	3747064	et	0	main
kirjutada	doc_634572338214_item	3747065	et	0	main
oma	doc_634572338214_item	3747066	et	0	main
arvamust	doc_634572338214_item	3747067	et	0	main
probleemi	doc_634572338214_item	3747068	et	0	main
kohta	doc_634572338214_item	3747069	et	0	main
ühest	doc_634572338214_item	3747070	et	0	main
küljest	doc_634572338214_item	3747071	et	0	main
ma	doc_634572338214_item	3747072	et	0	main
olen	doc_634572338214_item	3747073	et	0	main
nõus	doc_634572338214_item	3747074	et	0	main
teiega	doc_634572338214_item	3747075	et	0	main
et	doc_634572338214_item	3747076	et	0	main
abituriendid	doc_634572338214_item	3747077	et	0	main
tahavad	doc_634572338214_item	3747078	et	0	main
õppida	doc_634572338214_item	3747079	et	0	main
ülikoolis	doc_634572338214_item	3747080	et	0	main
ja	doc_634572338214_item	3747081	et	0	main
tahavad	doc_634572338214_item	3747082	et	0	main
tulevikus	doc_634572338214_item	3747083	et	0	main
teenida	doc_634572338214_item	3747084	et	0	main
raha	doc_634572338214_item	3747085	et	0	main
alguselt	doc_634572338214_item	3747086	et	0	main
nad	doc_634572338214_item	3747087	et	0	main
ei	doc_634572338214_item	3747088	et	0	main
tea	doc_634572338214_item	3747089	et	0	main
täpselt	doc_634572338214_item	3747090	et	0	main
kuhu	doc_634572338214_item	3747091	et	0	main
lähevad	doc_634572338214_item	3747092	et	0	main
edasi	doc_634572338214_item	3747093	et	0	main
õppima	doc_634572338214_item	3747094	et	0	main
sest	doc_634572338214_item	3747095	et	0	main
eksamid	doc_634572338214_item	3747096	et	0	main
on	doc_634572338214_item	3747097	et	0	main
loterii	doc_634572338214_item	3747098	et	0	main
ja	doc_634572338214_item	3747099	et	0	main
kunagi	doc_634572338214_item	3747100	et	0	main
ei	doc_634572338214_item	3747101	et	0	main
tea	doc_634572338214_item	3747102	et	0	main
palju	doc_634572338214_item	3747103	et	0	main
eksamipunkte	doc_634572338214_item	3747104	et	0	main
saad	doc_634572338214_item	3747105	et	0	main
ainult	doc_634572338214_item	3747106	et	0	main
pärast	doc_634572338214_item	3747107	et	0	main
seda	doc_634572338214_item	3747108	et	0	main
kui	doc_634572338214_item	3747109	et	0	main
tulemused	doc_634572338214_item	3747110	et	0	main
on	doc_634572338214_item	3747111	et	0	main
käes	doc_634572338214_item	3747112	et	0	main
õpilased	doc_634572338214_item	3747113	et	0	main
otsustavad	doc_634572338214_item	3747114	et	0	main
ja	doc_634572338214_item	3747115	et	0	main
proovivad	doc_634572338214_item	3747116	et	0	main
oma	doc_634572338214_item	3747117	et	0	main
jõudu	doc_634572338214_item	3747118	et	0	main
erinevates	doc_634572338214_item	3747119	et	0	main
ülikoolides	doc_634572338214_item	3747120	et	0	main
see	doc_634572338214_item	3747121	et	0	main
on	doc_634572338214_item	3747122	et	0	main
väga	doc_634572338214_item	3747123	et	0	main
tähtis	doc_634572338214_item	3747124	et	0	main
otsus	doc_634572338214_item	3747125	et	0	main
mis	doc_634572338214_item	3747126	et	0	main
määrab	doc_634572338214_item	3747127	et	0	main
nende	doc_634572338214_item	3747128	et	0	main
elu	doc_634572338214_item	3747129	et	0	main
tulevikus	doc_634572338214_item	3747130	et	0	main
teisest	doc_634572338214_item	3747131	et	0	main
küljest	doc_634572338214_item	3747132	et	0	main
ma	doc_634572338214_item	3747133	et	0	main
arvan	doc_634572338214_item	3747134	et	0	main
teistsmoodi	doc_634572338214_item	3747135	et	0	main
mitte	doc_634572338214_item	3747136	et	0	main
kõik	doc_634572338214_item	3747137	et	0	main
inimesed	doc_634572338214_item	3747138	et	0	main
ei	doc_634572338214_item	3747139	et	0	main
tea	doc_634572338214_item	3747140	et	0	main
mida	doc_634572338214_item	3747141	et	0	main
nad	doc_634572338214_item	3747142	et	0	main
tahavad	doc_634572338214_item	3747143	et	0	main
on	doc_634572338214_item	3747144	et	0	main
selliseid	doc_634572338214_item	3747145	et	0	main
kellel	doc_634572338214_item	3747146	et	0	main
on	doc_634572338214_item	3747147	et	0	main
kindel	doc_634572338214_item	3747148	et	0	main
elu	doc_634572338214_item	3747149	et	0	main
eesmärk	doc_634572338214_item	3747150	et	0	main
näiteks	doc_634572338214_item	3747151	et	0	main
mina	doc_634572338214_item	3747152	et	0	main
juba	doc_634572338214_item	3747153	et	0	main
üksendast	doc_634572338214_item	3747154	et	0	main
klassist	doc_634572338214_item	3747155	et	0	main
otsustasin	doc_634572338214_item	3747156	et	0	main
et	doc_634572338214_item	3747157	et	0	main
ma	doc_634572338214_item	3747158	et	0	main
tahan	doc_634572338214_item	3747159	et	0	main
õppida	doc_634572338214_item	3747160	et	0	main
majandust	doc_634572338214_item	3747161	et	0	main
ja	doc_634572338214_item	3747162	et	0	main
kolm	doc_634572338214_item	3747163	et	0	main
aastat	doc_634572338214_item	3747164	et	0	main
ma	doc_634572338214_item	3747165	et	0	main
liikusin	doc_634572338214_item	3747166	et	0	main
oma	doc_634572338214_item	3747167	et	0	main
sihele	doc_634572338214_item	3747168	et	0	main
minu	doc_634572338214_item	3747169	et	0	main
arvates	doc_634572338214_item	3747170	et	0	main
kõik	doc_634572338214_item	3747171	et	0	main
sõltub	doc_634572338214_item	3747172	et	0	main
abiturientidest	doc_634572338214_item	3747173	et	0	main
iga	doc_634572338214_item	3747174	et	0	main
inimene	doc_634572338214_item	3747175	et	0	main
on	doc_634572338214_item	3747176	et	0	main
oma	doc_634572338214_item	3747177	et	0	main
õnne	doc_634572338214_item	3747178	et	0	main
looja	doc_634572338214_item	3747179	et	0	main
olen	doc_634572338214_item	3747180	et	0	main
veendunud	doc_634572338214_item	3747181	et	0	main
et	doc_634572338214_item	3747182	et	0	main
kui	doc_634572338214_item	3747183	et	0	main
midagi	doc_634572338214_item	3747184	et	0	main
väga	doc_634572338214_item	3747185	et	0	main
tahad	doc_634572338214_item	3747186	et	0	main
siis	doc_634572338214_item	3747187	et	0	main
pead	doc_634572338214_item	3747188	et	0	main
ise	doc_634572338214_item	3747189	et	0	main
kõvasti	doc_634572338214_item	3747190	et	0	main
tööd	doc_634572338214_item	3747191	et	0	main
tegema	doc_634572338214_item	3747192	et	0	main
sest	doc_634572338214_item	3747193	et	0	main
mitte	doc_634572338214_item	3747194	et	0	main
keegi	doc_634572338214_item	3747195	et	0	main
sinu	doc_634572338214_item	3747196	et	0	main
eest	doc_634572338214_item	3747197	et	0	main
seda	doc_634572338214_item	3747198	et	0	main
ei	doc_634572338214_item	3747199	et	0	main
tee	doc_634572338214_item	3747200	et	0	main
ametlik	doc_634572338210_item	3747201	et	0	main
kiri	doc_634572338210_item	3747202	et	0	main
arvamuse	doc_634572338210_item	3747203	et	0	main
eesti	doc_634572338210_item	3747204	et	0	main
ekspressi	doc_634572338210_item	3747205	et	0	main
toimetaja	doc_634572338210_item	3747206	et	0	main
tiina	doc_634572338210_item	3747207	et	0	main
kaalepi	doc_634572338210_item	3747208	et	0	main
artikli	doc_634572338210_item	3747209	et	0	main
kohta	doc_634572338210_item	3747210	et	0	main
arikkel	doc_634572338210_item	3747211	et	0	main
vt	doc_634572338210_item	3747212	et	0	main
httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	doc_634572338210_item	3747213	et	0	main
lugupeetud	doc_634572338210_item	3747214	et	0	main
tiina	doc_634572338210_item	3747215	et	0	main
kaalep	doc_634572338210_item	3747216	et	0	main
mina	doc_634572338210_item	3747217	et	0	main
lugesin	doc_634572338210_item	3747218	et	0	main
teie	doc_634572338210_item	3747219	et	0	main
artiklit	doc_634572338210_item	3747220	et	0	main
vähenõudlike	doc_634572338210_item	3747221	et	0	main
põlvkond	doc_634572338210_item	3747222	et	0	main
ja	doc_634572338210_item	3747223	et	0	main
tahan	doc_634572338210_item	3747224	et	0	main
kirjutada	doc_634572338210_item	3747225	et	0	main
teile	doc_634572338210_item	3747226	et	0	main
oma	doc_634572338210_item	3747227	et	0	main
arvamusest	doc_634572338210_item	3747228	et	0	main
olen	doc_634572338210_item	3747229	et	0	main
teiega	doc_634572338210_item	3747230	et	0	main
absoluutselt	doc_634572338210_item	3747231	et	0	main
nõus	doc_634572338210_item	3747232	et	0	main
et	doc_634572338210_item	3747233	et	0	main
kõik	doc_634572338210_item	3747234	et	0	main
tahavad	doc_634572338210_item	3747235	et	0	main
palju	doc_634572338210_item	3747236	et	0	main
pappi	doc_634572338210_item	3747237	et	0	main
ja	doc_634572338210_item	3747238	et	0	main
kohe	doc_634572338210_item	3747239	et	0	main
keegi	doc_634572338210_item	3747240	et	0	main
eriti	doc_634572338210_item	3747241	et	0	main
ei	doc_634572338210_item	3747242	et	0	main
hooli	doc_634572338210_item	3747243	et	0	main
keskkonnast	doc_634572338210_item	3747244	et	0	main
teistest	doc_634572338210_item	3747245	et	0	main
inimestest	doc_634572338210_item	3747246	et	0	main
kajuks	doc_634572338210_item	3747247	et	0	main
olen	doc_634572338210_item	3747248	et	0	main
ma	doc_634572338210_item	3747249	et	0	main
võib	doc_634572338210_item	3747250	et	0	main
olla	doc_634572338210_item	3747251	et	0	main
ka	doc_634572338210_item	3747252	et	0	main
selline	doc_634572338210_item	3747253	et	0	main
aga	doc_634572338210_item	3747254	et	0	main
tahaks	doc_634572338210_item	3747255	et	0	main
märkida	doc_634572338210_item	3747256	et	0	main
et	doc_634572338210_item	3747257	et	0	main
ma	doc_634572338210_item	3747258	et	0	main
ikkagi	doc_634572338210_item	3747259	et	0	main
hoolitsen	doc_634572338210_item	3747260	et	0	main
teistest	doc_634572338210_item	3747261	et	0	main
inimestest	doc_634572338210_item	3747262	et	0	main
nagu	doc_634572338210_item	3747263	et	0	main
te	doc_634572338210_item	3747264	et	0	main
kirjutasite	doc_634572338210_item	3747265	et	0	main
vaba	doc_634572338210_item	3747266	et	0	main
aeg	doc_634572338210_item	3747267	et	0	main
on	doc_634572338210_item	3747268	et	0	main
täiesti	doc_634572338210_item	3747269	et	0	main
väärtus	doc_634572338210_item	3747270	et	0	main
ja	doc_634572338210_item	3747271	et	0	main
mina	doc_634572338210_item	3747272	et	0	main
valeks	doc_634572338210_item	3747273	et	0	main
endale	doc_634572338210_item	3747274	et	0	main
tuleviku	doc_634572338210_item	3747275	et	0	main
kus	doc_634572338210_item	3747276	et	0	main
ma	doc_634572338210_item	3747277	et	0	main
ei	doc_634572338210_item	3747278	et	0	main
pea	doc_634572338210_item	3747279	et	0	main
tööle	doc_634572338210_item	3747280	et	0	main
palju	doc_634572338210_item	3747281	et	0	main
käima	doc_634572338210_item	3747282	et	0	main
tahaks	doc_634572338210_item	3747283	et	0	main
materiaalse	doc_634572338210_item	3747284	et	0	main
kindlustust	doc_634572338210_item	3747285	et	0	main
sotsiaaltagatiseid	doc_634572338210_item	3747286	et	0	main
jne	doc_634572338210_item	3747287	et	0	main
see	doc_634572338210_item	3747288	et	0	main
on	doc_634572338210_item	3747289	et	0	main
meie	doc_634572338210_item	3747290	et	0	main
suur	doc_634572338210_item	3747291	et	0	main
probleem	doc_634572338210_item	3747292	et	0	main
et	doc_634572338210_item	3747293	et	0	main
tahame	doc_634572338210_item	3747294	et	0	main
elada	doc_634572338210_item	3747295	et	0	main
nagu	doc_634572338210_item	3747296	et	0	main
neljakümnesed	doc_634572338210_item	3747297	et	0	main
selline	doc_634572338210_item	3747298	et	0	main
on	doc_634572338210_item	3747299	et	0	main
meie	doc_634572338210_item	3747300	et	0	main
põlvkond	doc_634572338210_item	3747301	et	0	main
ma	doc_634572338210_item	3747302	et	0	main
arvan	doc_634572338210_item	3747303	et	0	main
et	doc_634572338210_item	3747304	et	0	main
kindlasti	doc_634572338210_item	3747305	et	0	main
on	doc_634572338210_item	3747306	et	0	main
midagi	doc_634572338210_item	3747307	et	0	main
vale	doc_634572338210_item	3747308	et	0	main
riigieksamitega	doc_634572338210_item	3747309	et	0	main
kas	doc_634572338210_item	3747310	et	0	main
veedab	doc_634572338210_item	3747311	et	0	main
või	doc_634572338210_item	3747312	et	0	main
mitte	doc_634572338210_item	3747313	et	0	main
juhtub	doc_634572338210_item	3747314	et	0	main
ka	doc_634572338210_item	3747315	et	0	main
nii	doc_634572338210_item	3747316	et	0	main
et	doc_634572338210_item	3747317	et	0	main
need	doc_634572338210_item	3747318	et	0	main
kes	doc_634572338210_item	3747319	et	0	main
teavad	doc_634572338210_item	3747320	et	0	main
saavad	doc_634572338210_item	3747321	et	0	main
väga	doc_634572338210_item	3747322	et	0	main
vähe	doc_634572338210_item	3747323	et	0	main
palki	doc_634572338210_item	3747324	et	0	main
sellest	doc_634572338210_item	3747325	et	0	main
ju	doc_634572338210_item	3747326	et	0	main
sõltub	doc_634572338210_item	3747327	et	0	main
kus	doc_634572338210_item	3747328	et	0	main
kohas	doc_634572338210_item	3747329	et	0	main
nad	doc_634572338210_item	3747330	et	0	main
hakkavad	doc_634572338210_item	3747331	et	0	main
õppima	doc_634572338210_item	3747332	et	0	main
nende	doc_634572338210_item	3747333	et	0	main
tulevik	doc_634572338210_item	3747334	et	0	main
pärast	doc_634572338210_item	3747335	et	0	main
lõpetamist	doc_634572338210_item	3747336	et	0	main
nad	doc_634572338210_item	3747337	et	0	main
kandideerivad	doc_634572338210_item	3747338	et	0	main
suvalistele	doc_634572338210_item	3747339	et	0	main
töökohtadile	doc_634572338210_item	3747340	et	0	main
ei	doc_634572338210_item	3747341	et	0	main
naudi	doc_634572338210_item	3747342	et	0	main
oma	doc_634572338210_item	3747343	et	0	main
ametist	doc_634572338210_item	3747344	et	0	main
lõpuks	doc_634572338210_item	3747345	et	0	main
ma	doc_634572338210_item	3747346	et	0	main
ütlen	doc_634572338210_item	3747347	et	0	main
et	doc_634572338210_item	3747348	et	0	main
on	doc_634572338210_item	3747349	et	0	main
vaja	doc_634572338210_item	3747350	et	0	main
rääkida	doc_634572338210_item	3747351	et	0	main
tulevikust	doc_634572338210_item	3747352	et	0	main
juba	doc_634572338210_item	3747353	et	0	main
koolis	doc_634572338210_item	3747354	et	0	main
nii	doc_634572338210_item	3747355	et	0	main
et	doc_634572338210_item	3747356	et	0	main
kõik	doc_634572338210_item	3747357	et	0	main
teaksid	doc_634572338210_item	3747358	et	0	main
kus	doc_634572338210_item	3747359	et	0	main
nad	doc_634572338210_item	3747360	et	0	main
tahavad	doc_634572338210_item	3747361	et	0	main
õpida	doc_634572338210_item	3747362	et	0	main
ja	doc_634572338210_item	3747363	et	0	main
mida	doc_634572338210_item	3747364	et	0	main
tahavad	doc_634572338210_item	3747365	et	0	main
teha	doc_634572338210_item	3747366	et	0	main
ja	doc_634572338210_item	3747367	et	0	main
keegi	doc_634572338210_item	3747368	et	0	main
ei	doc_634572338210_item	3747369	et	0	main
ütle	doc_634572338210_item	3747370	et	0	main
et	doc_634572338210_item	3747371	et	0	main
oleme	doc_634572338210_item	3747372	et	0	main
vähenõudlik	doc_634572338210_item	3747373	et	0	main
põlvkond	doc_634572338210_item	3747374	et	0	main
suur	doc_634572338210_item	3747375	et	0	main
täna	doc_634572338210_item	3747376	et	0	main
teile	doc_634572338210_item	3747377	et	0	main
ilusa	doc_634572338210_item	3747378	et	0	main
artikli	doc_634572338210_item	3747379	et	0	main
eest	doc_634572338210_item	3747380	et	0	main
see	doc_634572338210_item	3747381	et	0	main
oli	doc_634572338210_item	3747382	et	0	main
väga	doc_634572338210_item	3747383	et	0	main
teaduslik	doc_634572338210_item	3747384	et	0	main
lugupidamisega	doc_634572338210_item	3747385	et	0	main
eesnimi	doc_634572338210_item	3747386	et	0	main
avaldus	doc_491521501894_item	3747387	et	0	main
as	doc_491521501894_item	3747388	et	0	main
cwb	doc_491521501894_item	3747389	et	0	main
direktorile	doc_491521501894_item	3747390	et	0	main
sünd	doc_491521501894_item	3747391	et	0	main
1041972	doc_491521501894_item	3747392	et	0	main
eesnimi	doc_491521501894_item	3747393	et	0	main
perekonnanimi	doc_491521501894_item	3747394	et	0	main
juhuslik	doc_491521501894_item	3747395	et	0	main
6-1	doc_491521501894_item	3747396	et	0	main
tel	doc_491521501894_item	3747397	et	0	main
image	doc_491521501894_item	3747398	et	0	main
chromeskypefftoolbarwincontentcbtransparentlgif	doc_491521501894_item	3747399	et	0	main
image	doc_491521501894_item	3747400	et	0	main
chromeskypefftoolbarwincontentfamfamfameegif	doc_491521501894_item	3747401	et	0	main
image	doc_491521501894_item	3747402	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501894_item	3747403	et	0	main
image	doc_491521501894_item	3747404	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501894_item	3747405	et	0	main
image	doc_491521501894_item	3747406	et	0	main
chromeskypefftoolbarwincontentarrowgif	doc_491521501894_item	3747407	et	0	main
image	doc_491521501894_item	3747408	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501894_item	3747409	et	0	main
image	doc_491521501894_item	3747410	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501894_item	3747411	et	0	main
image	doc_491521501894_item	3747412	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501894_item	3747413	et	0	main
image	doc_491521501894_item	3747414	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501894_item	3747415	et	0	main
image	doc_491521501894_item	3747416	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501894_item	3747417	et	0	main
image	doc_491521501894_item	3747418	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501894_item	3747419	et	0	main
image	doc_491521501894_item	3747420	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501894_item	3747421	et	0	main
55	doc_491521501894_item	3747422	et	0	main
555	doc_491521501894_item	3747423	et	0	main
55	doc_491521501894_item	3747424	et	0	main
image	doc_491521501894_item	3747425	et	0	main
chromeskypefftoolbarwincontentcbtransparentrgif	doc_491521501894_item	3747426	et	0	main
sooviavaldus	doc_491521501894_item	3747427	et	0	main
palun	doc_491521501894_item	3747428	et	0	main
mind	doc_491521501894_item	3747429	et	0	main
tööle	doc_491521501894_item	3747430	et	0	main
võtta	doc_491521501894_item	3747431	et	0	main
teie	doc_491521501894_item	3747432	et	0	main
firma	doc_491521501894_item	3747433	et	0	main
müügiesindajaks	doc_491521501894_item	3747434	et	0	main
olen	doc_491521501894_item	3747435	et	0	main
lõpetanud	doc_491521501894_item	3747436	et	0	main
tallinna	doc_491521501894_item	3747437	et	0	main
tehnikaülikooli	doc_491521501894_item	3747438	et	0	main
1994	doc_491521501894_item	3747439	et	0	main
majandusteaduskonna	doc_491521501894_item	3747440	et	0	main
finantsijuhi	doc_491521501894_item	3747441	et	0	main
eriala	doc_491521501894_item	3747442	et	0	main
peale	doc_491521501894_item	3747443	et	0	main
lõpetamist	doc_491521501894_item	3747444	et	0	main
olen	doc_491521501894_item	3747445	et	0	main
töötanud	doc_491521501894_item	3747446	et	0	main
2	doc_491521501894_item	3747447	et	0	main
aastat	doc_491521501894_item	3747448	et	0	main
as	doc_491521501894_item	3747449	et	0	main
normen	doc_491521501894_item	3747450	et	0	main
müüjana	doc_491521501894_item	3747451	et	0	main
2	doc_491521501894_item	3747452	et	0	main
aastat	doc_491521501894_item	3747453	et	0	main
pearaamatupidajana	doc_491521501894_item	3747454	et	0	main
alates	doc_491521501894_item	3747455	et	0	main
1998	doc_491521501894_item	3747456	et	0	main
aastast	doc_491521501894_item	3747457	et	0	main
töötasin	doc_491521501894_item	3747458	et	0	main
kosmetika	doc_491521501894_item	3747459	et	0	main
firmas	doc_491521501894_item	3747460	et	0	main
eeva	doc_491521501894_item	3747461	et	0	main
müügiesindajana	doc_491521501894_item	3747462	et	0	main
valdan	doc_491521501894_item	3747463	et	0	main
esti	doc_491521501894_item	3747464	et	0	main
vene	doc_491521501894_item	3747465	et	0	main
ja	doc_491521501894_item	3747466	et	0	main
inglise	doc_491521501894_item	3747467	et	0	main
keelt	doc_491521501894_item	3747468	et	0	main
oskan	doc_491521501894_item	3747469	et	0	main
töötada	doc_491521501894_item	3747470	et	0	main
arvutiga	doc_491521501894_item	3747471	et	0	main
kõigis	doc_491521501894_item	3747472	et	0	main
enamlevinud	doc_491521501894_item	3747473	et	0	main
süsteemides	doc_491521501894_item	3747474	et	0	main
mul	doc_491521501894_item	3747475	et	0	main
on	doc_491521501894_item	3747476	et	0	main
autojuhiloa	doc_491521501894_item	3747477	et	0	main
b-kategoria	doc_491521501894_item	3747478	et	0	main
ma	doc_491521501894_item	3747479	et	0	main
olen	doc_491521501894_item	3747480	et	0	main
väga	doc_491521501894_item	3747481	et	0	main
seltsiv	doc_491521501894_item	3747482	et	0	main
lõbus	doc_491521501894_item	3747483	et	0	main
ja	doc_491521501894_item	3747484	et	0	main
vastutav	doc_491521501894_item	3747485	et	0	main
inimene	doc_491521501894_item	3747486	et	0	main
mul	doc_491521501894_item	3747487	et	0	main
on	doc_491521501894_item	3747488	et	0	main
tahtmine	doc_491521501894_item	3747489	et	0	main
ja	doc_491521501894_item	3747490	et	0	main
võimalus	doc_491521501894_item	3747491	et	0	main
reisida	doc_491521501894_item	3747492	et	0	main
eestis	doc_491521501894_item	3747493	et	0	main
palka	doc_491521501894_item	3747494	et	0	main
sooviksin	doc_491521501894_item	3747495	et	0	main
saada	doc_491521501894_item	3747496	et	0	main
vähemalt	doc_491521501894_item	3747497	et	0	main
4000	doc_491521501894_item	3747498	et	0	main
krooni	doc_491521501894_item	3747499	et	0	main
kuus	doc_491521501894_item	3747500	et	0	main
jään	doc_491521501894_item	3747501	et	0	main
ootama	doc_491521501894_item	3747502	et	0	main
positiivset	doc_491521501894_item	3747503	et	0	main
vastust	doc_491521501894_item	3747504	et	0	main
lugupidamisega	doc_491521501894_item	3747505	et	0	main
14032002	doc_491521501894_item	3747506	et	0	main
tõlge	doc_399014257219_item	3747507	et	0	main
kunstnike	doc_399014257219_item	3747508	et	0	main
liidud	doc_399014257219_item	3747509	et	0	main
vaatavad	doc_399014257219_item	3747510	et	0	main
viltu	doc_399014257219_item	3747511	et	0	main
tallinna	doc_399014257219_item	3747512	et	0	main
lahele	doc_399014257219_item	3747513	et	0	main
planeeritud	doc_399014257219_item	3747514	et	0	main
suurele	doc_399014257219_item	3747515	et	0	main
kalevipoja	doc_399014257219_item	3747516	et	0	main
kujule	doc_399014257219_item	3747517	et	0	main
tallinna	doc_399014257219_item	3747518	et	0	main
linn	doc_399014257219_item	3747519	et	0	main
sai	doc_399014257219_item	3747520	et	0	main
kolm	doc_399014257219_item	3747521	et	0	main
võistlustööd	doc_399014257219_item	3747522	et	0	main
eesti	doc_399014257219_item	3747523	et	0	main
kunstnikud	doc_399014257219_item	3747524	et	0	main
vaatavad	doc_399014257219_item	3747525	et	0	main
viltu	doc_399014257219_item	3747526	et	0	main
tallinna	doc_399014257219_item	3747527	et	0	main
linna	doc_399014257219_item	3747528	et	0	main
plaanile	doc_399014257219_item	3747529	et	0	main
püstitada	doc_399014257219_item	3747530	et	0	main
tallinna	doc_399014257219_item	3747531	et	0	main
lahele	doc_399014257219_item	3747532	et	0	main
korrusmaja	doc_399014257219_item	3747533	et	0	main
kõrgune	doc_399014257219_item	3747534	et	0	main
21meetrine	doc_399014257219_item	3747535	et	0	main
kalevipoeg	doc_399014257219_item	3747536	et	0	main
eesti	doc_399014257219_item	3747537	et	0	main
samanimelise	doc_399014257219_item	3747538	et	0	main
rahvuseepose	doc_399014257219_item	3747539	et	0	main
kangelase	doc_399014257219_item	3747540	et	0	main
järgi	doc_399014257219_item	3747541	et	0	main
linna	doc_399014257219_item	3747542	et	0	main
poolt	doc_399014257219_item	3747543	et	0	main
organiseeritud	doc_399014257219_item	3747544	et	0	main
konkursile	doc_399014257219_item	3747545	et	0	main
oli	doc_399014257219_item	3747546	et	0	main
tähtajaks	doc_399014257219_item	3747547	et	0	main
esmaspäevaks	doc_399014257219_item	3747548	et	0	main
jäetud	doc_399014257219_item	3747549	et	0	main
ainult	doc_399014257219_item	3747550	et	0	main
kolm	doc_399014257219_item	3747551	et	0	main
võistlustööd	doc_399014257219_item	3747552	et	0	main
eesmärk	doc_399014257219_item	3747553	et	0	main
on	doc_399014257219_item	3747554	et	0	main
kalevipoeg	doc_399014257219_item	3747555	et	0	main
püstitada	doc_399014257219_item	3747556	et	0	main
merre	doc_399014257219_item	3747557	et	0	main
saja	doc_399014257219_item	3747558	et	0	main
meetri	doc_399014257219_item	3747559	et	0	main
kaugusele	doc_399014257219_item	3747560	et	0	main
tallinna	doc_399014257219_item	3747561	et	0	main
pirita	doc_399014257219_item	3747562	et	0	main
rannatee	doc_399014257219_item	3747563	et	0	main
äärde	doc_399014257219_item	3747564	et	0	main
samas	doc_399014257219_item	3747565	et	0	main
kohas	doc_399014257219_item	3747566	et	0	main
on	doc_399014257219_item	3747567	et	0	main
ka	doc_399014257219_item	3747568	et	0	main
nõukogudeaegne	doc_399014257219_item	3747569	et	0	main
teise	doc_399014257219_item	3747570	et	0	main
maailmasõja	doc_399014257219_item	3747571	et	0	main
kangelastele	doc_399014257219_item	3747572	et	0	main
püstitatud	doc_399014257219_item	3747573	et	0	main
mälestusmärk	doc_399014257219_item	3747574	et	0	main
millest	doc_399014257219_item	3747575	et	0	main
merele	doc_399014257219_item	3747576	et	0	main
paistab	doc_399014257219_item	3747577	et	0	main
kõrge	doc_399014257219_item	3747578	et	0	main
skulptuur	doc_399014257219_item	3747579	et	0	main
ja	doc_399014257219_item	3747580	et	0	main
ka	doc_399014257219_item	3747581	et	0	main
trepp	doc_399014257219_item	3747582	et	0	main
linna	doc_399014257219_item	3747583	et	0	main
ja	doc_399014257219_item	3747584	et	0	main
skulptorite	doc_399014257219_item	3747585	et	0	main
liidu	doc_399014257219_item	3747586	et	0	main
lahkhelid	doc_399014257219_item	3747587	et	0	main
hakkavad	doc_399014257219_item	3747588	et	0	main
pihta	doc_399014257219_item	3747589	et	0	main
juba	doc_399014257219_item	3747590	et	0	main
kuju	doc_399014257219_item	3747591	et	0	main
suurusest	doc_399014257219_item	3747592	et	0	main
ja	doc_399014257219_item	3747593	et	0	main
asukohast	doc_399014257219_item	3747594	et	0	main
meres	doc_399014257219_item	3747595	et	0	main
eesti	doc_399014257219_item	3747596	et	0	main
skulptorite	doc_399014257219_item	3747597	et	0	main
liidu	doc_399014257219_item	3747598	et	0	main
idee	doc_399014257219_item	3747599	et	0	main
iseenesest	doc_399014257219_item	3747600	et	0	main
on	doc_399014257219_item	3747601	et	0	main
vananenud	doc_399014257219_item	3747602	et	0	main
ega	doc_399014257219_item	3747603	et	0	main
rahvuseepose	doc_399014257219_item	3747604	et	0	main
kangelane	doc_399014257219_item	3747605	et	0	main
sobi	doc_399014257219_item	3747606	et	0	main
kokku	doc_399014257219_item	3747607	et	0	main
nõukogudeaegse	doc_399014257219_item	3747608	et	0	main
mälestuskompleksiga	doc_399014257219_item	3747609	et	0	main
juba	doc_399014257219_item	3747610	et	0	main
sügisel	doc_399014257219_item	3747611	et	0	main
nii	doc_399014257219_item	3747612	et	0	main
skulptorite-	doc_399014257219_item	3747613	et	0	main
kui	doc_399014257219_item	3747614	et	0	main
ka	doc_399014257219_item	3747615	et	0	main
arhitektide	doc_399014257219_item	3747616	et	0	main
liidud	doc_399014257219_item	3747617	et	0	main
kutsusid	doc_399014257219_item	3747618	et	0	main
tagasi	doc_399014257219_item	3747619	et	0	main
oma	doc_399014257219_item	3747620	et	0	main
esindaja	doc_399014257219_item	3747621	et	0	main
kohtunike	doc_399014257219_item	3747622	et	0	main
esindusest	doc_399014257219_item	3747623	et	0	main
protestimaks	doc_399014257219_item	3747624	et	0	main
ametivõimu	doc_399014257219_item	3747625	et	0	main
vastu	doc_399014257219_item	3747626	et	0	main
linnapea	doc_399014257219_item	3747627	et	0	main
jüri	doc_399014257219_item	3747628	et	0	main
ratase	doc_399014257219_item	3747629	et	0	main
32	doc_399014257219_item	3747630	et	0	main
juhtimisel	doc_399014257219_item	3747631	et	0	main
kohtunikkogu	doc_399014257219_item	3747632	et	0	main
ainuke	doc_399014257219_item	3747633	et	0	main
sõltumatu	doc_399014257219_item	3747634	et	0	main
kunstnikust	doc_399014257219_item	3747635	et	0	main
liige	doc_399014257219_item	3747636	et	0	main
on	doc_399014257219_item	3747637	et	0	main
maastikuarhitekt	doc_399014257219_item	3747638	et	0	main
kes	doc_399014257219_item	3747639	et	0	main
on	doc_399014257219_item	3747640	et	0	main
projekteerinud	doc_399014257219_item	3747641	et	0	main
linna	doc_399014257219_item	3747642	et	0	main
parke	doc_399014257219_item	3747643	et	0	main
algupärase	doc_399014257219_item	3747644	et	0	main
idee	doc_399014257219_item	3747645	et	0	main
isa	doc_399014257219_item	3747646	et	0	main
on	doc_399014257219_item	3747647	et	0	main
hoopis	doc_399014257219_item	3747648	et	0	main
kunstnik	doc_399014257219_item	3747649	et	0	main
kõmutekitanud	doc_399014257219_item	3747650	et	0	main
vaidlusalune	doc_399014257219_item	3747651	et	0	main
skulptor	doc_399014257219_item	3747652	et	0	main
tauno	doc_399014257219_item	3747653	et	0	main
kangro	doc_399014257219_item	3747654	et	0	main
40	doc_399014257219_item	3747655	et	0	main
kes	doc_399014257219_item	3747656	et	0	main
hakkas	doc_399014257219_item	3747657	et	0	main
reklaamima	doc_399014257219_item	3747658	et	0	main
kalevipoja	doc_399014257219_item	3747659	et	0	main
ideed	doc_399014257219_item	3747660	et	0	main
juba	doc_399014257219_item	3747661	et	0	main
1990	doc_399014257219_item	3747662	et	0	main
aastate	doc_399014257219_item	3747663	et	0	main
lõpus	doc_399014257219_item	3747664	et	0	main
oli	doc_399014257219_item	3747665	et	0	main
mõte	doc_399014257219_item	3747666	et	0	main
luua	doc_399014257219_item	3747667	et	0	main
tallinnale	doc_399014257219_item	3747668	et	0	main
kopenhaageni	doc_399014257219_item	3747669	et	0	main
merineitsi	doc_399014257219_item	3747670	et	0	main
taoline	doc_399014257219_item	3747671	et	0	main
sümbol	doc_399014257219_item	3747672	et	0	main
esimeste	doc_399014257219_item	3747673	et	0	main
plaanide	doc_399014257219_item	3747674	et	0	main
järgi	doc_399014257219_item	3747675	et	0	main
tallinna	doc_399014257219_item	3747676	et	0	main
väike	doc_399014257219_item	3747677	et	0	main
merineitsi	doc_399014257219_item	3747678	et	0	main
oli	doc_399014257219_item	3747679	et	0	main
ainult	doc_399014257219_item	3747680	et	0	main
14	doc_399014257219_item	3747681	et	0	main
meetri	doc_399014257219_item	3747682	et	0	main
kõrgune	doc_399014257219_item	3747683	et	0	main
aga	doc_399014257219_item	3747684	et	0	main
linna	doc_399014257219_item	3747685	et	0	main
ettepanekul	doc_399014257219_item	3747686	et	0	main
kõrgust	doc_399014257219_item	3747687	et	0	main
lisati	doc_399014257219_item	3747688	et	0	main
21	doc_399014257219_item	3747689	et	0	main
meetrini	doc_399014257219_item	3747690	et	0	main
vaatasime	doc_399014257219_item	3747691	et	0	main
kuidas	doc_399014257219_item	3747692	et	0	main
kuju	doc_399014257219_item	3747693	et	0	main
sobiks	doc_399014257219_item	3747694	et	0	main
maarjamäe	doc_399014257219_item	3747695	et	0	main
mälestusmärkide	doc_399014257219_item	3747696	et	0	main
kompleksiga	doc_399014257219_item	3747697	et	0	main
ühte	doc_399014257219_item	3747698	et	0	main
arvutasime	doc_399014257219_item	3747699	et	0	main
ja	doc_399014257219_item	3747700	et	0	main
visualiseerisime	doc_399014257219_item	3747701	et	0	main
selle	doc_399014257219_item	3747702	et	0	main
tulemuseks	doc_399014257219_item	3747703	et	0	main
oli	doc_399014257219_item	3747704	et	0	main
21	doc_399014257219_item	3747705	et	0	main
meetrit	doc_399014257219_item	3747706	et	0	main
see	doc_399014257219_item	3747707	et	0	main
paistaks	doc_399014257219_item	3747708	et	0	main
silma	doc_399014257219_item	3747709	et	0	main
põhjendab	doc_399014257219_item	3747710	et	0	main
aselinnapea	doc_399014257219_item	3747711	et	0	main
olga	doc_399014257219_item	3747712	et	0	main
sõtnik	doc_399014257219_item	3747713	et	0	main
sõtniku	doc_399014257219_item	3747714	et	0	main
sõnul	doc_399014257219_item	3747715	et	0	main
koht	doc_399014257219_item	3747716	et	0	main
on	doc_399014257219_item	3747717	et	0	main
ka	doc_399014257219_item	3747718	et	0	main
parim	doc_399014257219_item	3747719	et	0	main
võimalik	doc_399014257219_item	3747720	et	0	main
kuna	doc_399014257219_item	3747721	et	0	main
see	doc_399014257219_item	3747722	et	0	main
jääb	doc_399014257219_item	3747723	et	0	main
turistide	doc_399014257219_item	3747724	et	0	main
teele	doc_399014257219_item	3747725	et	0	main
pirita	doc_399014257219_item	3747726	et	0	main
spasse	doc_399014257219_item	3747727	et	0	main
ja	doc_399014257219_item	3747728	et	0	main
tallinna	doc_399014257219_item	3747729	et	0	main
botaanika	doc_399014257219_item	3747730	et	0	main
aeda	doc_399014257219_item	3747731	et	0	main
minnes	doc_399014257219_item	3747732	et	0	main
siis	doc_399014257219_item	3747733	et	0	main
see	doc_399014257219_item	3747734	et	0	main
ei	doc_399014257219_item	3747735	et	0	main
varja	doc_399014257219_item	3747736	et	0	main
ka	doc_399014257219_item	3747737	et	0	main
vanalinna	doc_399014257219_item	3747738	et	0	main
siluetti	doc_399014257219_item	3747739	et	0	main
tauno	doc_399014257219_item	3747740	et	0	main
kangro	doc_399014257219_item	3747741	et	0	main
galeriis	doc_399014257219_item	3747742	et	0	main
vanalinnas	doc_399014257219_item	3747743	et	0	main
valitses	doc_399014257219_item	3747744	et	0	main
veel	doc_399014257219_item	3747745	et	0	main
esmaspäevalgi	doc_399014257219_item	3747746	et	0	main
ärev	doc_399014257219_item	3747747	et	0	main
meeleolu	doc_399014257219_item	3747748	et	0	main
kunstnik	doc_399014257219_item	3747749	et	0	main
ise	doc_399014257219_item	3747750	et	0	main
ei	doc_399014257219_item	3747751	et	0	main
olnud	doc_399014257219_item	3747752	et	0	main
linnas	doc_399014257219_item	3747753	et	0	main
aga	doc_399014257219_item	3747754	et	0	main
galerii	doc_399014257219_item	3747755	et	0	main
omanik	doc_399014257219_item	3747756	et	0	main
pille	doc_399014257219_item	3747757	et	0	main
mägila	doc_399014257219_item	3747758	et	0	main
esitles	doc_399014257219_item	3747759	et	0	main
innukalt	doc_399014257219_item	3747760	et	0	main
pronkskuju	doc_399014257219_item	3747761	et	0	main
kus	doc_399014257219_item	3747762	et	0	main
suurekämblaline	doc_399014257219_item	3747763	et	0	main
kalevipoeg	doc_399014257219_item	3747764	et	0	main
kannab	doc_399014257219_item	3747765	et	0	main
laeva	doc_399014257219_item	3747766	et	0	main
kuju	doc_399014257219_item	3747767	et	0	main
sümboliseerib	doc_399014257219_item	3747768	et	0	main
kangelase	doc_399014257219_item	3747769	et	0	main
naasmist	doc_399014257219_item	3747770	et	0	main
ümbermaailma	doc_399014257219_item	3747771	et	0	main
reisilt	doc_399014257219_item	3747772	et	0	main
kangelase	doc_399014257219_item	3747773	et	0	main
käes	doc_399014257219_item	3747774	et	0	main
on	doc_399014257219_item	3747775	et	0	main
kuntniku	doc_399014257219_item	3747776	et	0	main
nägemusest	doc_399014257219_item	3747777	et	0	main
veel	doc_399014257219_item	3747778	et	0	main
laev	doc_399014257219_item	3747779	et	0	main
ja	doc_399014257219_item	3747780	et	0	main
mõned	doc_399014257219_item	3747781	et	0	main
inimkujud	doc_399014257219_item	3747782	et	0	main
kes	doc_399014257219_item	3747783	et	0	main
sümboliseerivad	doc_399014257219_item	3747784	et	0	main
eestlaste	doc_399014257219_item	3747785	et	0	main
kojujõudmist	doc_399014257219_item	3747786	et	0	main
lisaks	doc_399014257219_item	3747787	et	0	main
skulptorite	doc_399014257219_item	3747788	et	0	main
liidule	doc_399014257219_item	3747789	et	0	main
boikoteerib	doc_399014257219_item	3747790	et	0	main
kuju	doc_399014257219_item	3747791	et	0	main
hanget	doc_399014257219_item	3747792	et	0	main
veel	doc_399014257219_item	3747793	et	0	main
mõjuvõimas	doc_399014257219_item	3747794	et	0	main
arhitektide	doc_399014257219_item	3747795	et	0	main
liit	doc_399014257219_item	3747796	et	0	main
kes	doc_399014257219_item	3747797	et	0	main
on	doc_399014257219_item	3747798	et	0	main
linnaga	doc_399014257219_item	3747799	et	0	main
tülis	doc_399014257219_item	3747800	et	0	main
muuhulgas	doc_399014257219_item	3747801	et	0	main
ka	doc_399014257219_item	3747802	et	0	main
uue	doc_399014257219_item	3747803	et	0	main
linnavalitsuse	doc_399014257219_item	3747804	et	0	main
asukoha	doc_399014257219_item	3747805	et	0	main
pärast	doc_399014257219_item	3747806	et	0	main
tallinnas	doc_399014257219_item	3747807	et	0	main
on	doc_399014257219_item	3747808	et	0	main
ainsana	doc_399014257219_item	3747809	et	0	main
parteina	doc_399014257219_item	3747810	et	0	main
võimul	doc_399014257219_item	3747811	et	0	main
keskerakond	doc_399014257219_item	3747812	et	0	main
kes	doc_399014257219_item	3747813	et	0	main
on	doc_399014257219_item	3747814	et	0	main
varemgi	doc_399014257219_item	3747815	et	0	main
avaldanud	doc_399014257219_item	3747816	et	0	main
poolehoidu	doc_399014257219_item	3747817	et	0	main
kõrgetele	doc_399014257219_item	3747818	et	0	main
ehitistele	doc_399014257219_item	3747819	et	0	main
teiste	doc_399014257219_item	3747820	et	0	main
kunstnike	doc_399014257219_item	3747821	et	0	main
kriitika	doc_399014257219_item	3747822	et	0	main
kujuhanke	doc_399014257219_item	3747823	et	0	main
kohta	doc_399014257219_item	3747824	et	0	main
kasvas	doc_399014257219_item	3747825	et	0	main
pärast	doc_399014257219_item	3747826	et	0	main
seda	doc_399014257219_item	3747827	et	0	main
kui	doc_399014257219_item	3747828	et	0	main
ideed	doc_399014257219_item	3747829	et	0	main
kaua	doc_399014257219_item	3747830	et	0	main
reklaaminud	doc_399014257219_item	3747831	et	0	main
kangro	doc_399014257219_item	3747832	et	0	main
astus	doc_399014257219_item	3747833	et	0	main
suvel	doc_399014257219_item	3747834	et	0	main
keskerakonda	doc_399014257219_item	3747835	et	0	main
kriitikat	doc_399014257219_item	3747836	et	0	main
on	doc_399014257219_item	3747837	et	0	main
saanud	doc_399014257219_item	3747838	et	0	main
ka	doc_399014257219_item	3747839	et	0	main
kalevipoeg	doc_399014257219_item	3747840	et	0	main
ise	doc_399014257219_item	3747841	et	0	main
kes	doc_399014257219_item	3747842	et	0	main
muistendi	doc_399014257219_item	3747843	et	0	main
järgi	doc_399014257219_item	3747844	et	0	main
pildus	doc_399014257219_item	3747845	et	0	main
vaenlasi	doc_399014257219_item	3747846	et	0	main
suurte	doc_399014257219_item	3747847	et	0	main
kividega	doc_399014257219_item	3747848	et	0	main
aga	doc_399014257219_item	3747849	et	0	main
ka	doc_399014257219_item	3747850	et	0	main
oli	doc_399014257219_item	3747851	et	0	main
süüdi	doc_399014257219_item	3747852	et	0	main
noore	doc_399014257219_item	3747853	et	0	main
neiu	doc_399014257219_item	3747854	et	0	main
vägistamises	doc_399014257219_item	3747855	et	0	main
merel	doc_399014257219_item	3747856	et	0	main
on	doc_399014257219_item	3747857	et	0	main
küsitud	doc_399014257219_item	3747858	et	0	main
kas	doc_399014257219_item	3747859	et	0	main
selline	doc_399014257219_item	3747860	et	0	main
tegelane	doc_399014257219_item	3747861	et	0	main
on	doc_399014257219_item	3747862	et	0	main
sobiv	doc_399014257219_item	3747863	et	0	main
sümbol	doc_399014257219_item	3747864	et	0	main
merele	doc_399014257219_item	3747865	et	0	main
kalevipoeg-konkursi	doc_399014257219_item	3747866	et	0	main
tulemused	doc_399014257219_item	3747867	et	0	main
avalikustatakse	doc_399014257219_item	3747868	et	0	main
jaanuari	doc_399014257219_item	3747869	et	0	main
lõpus	doc_399014257219_item	3747870	et	0	main
pärast	doc_399014257219_item	3747871	et	0	main
mida	doc_399014257219_item	3747872	et	0	main
konkursitööd	doc_399014257219_item	3747873	et	0	main
lähevad	doc_399014257219_item	3747874	et	0	main
näitusele	doc_399014257219_item	3747875	et	0	main
abilinnapea	doc_399014257219_item	3747876	et	0	main
soõtniku	doc_399014257219_item	3747877	et	0	main
sõnul	doc_399014257219_item	3747878	et	0	main
kuju	doc_399014257219_item	3747879	et	0	main
peaks	doc_399014257219_item	3747880	et	0	main
püstitatama	doc_399014257219_item	3747881	et	0	main
järmise	doc_399014257219_item	3747882	et	0	main
ja	doc_399014257219_item	3747883	et	0	main
ülejärgmise	doc_399014257219_item	3747884	et	0	main
aasta	doc_399014257219_item	3747885	et	0	main
jooksul	doc_399014257219_item	3747886	et	0	main
käskkirjad	doc_491521501739_item	3747887	et	0	main
1	doc_491521501739_item	3747888	et	0	main
põhjuseta	doc_491521501739_item	3747889	et	0	main
tunnides	doc_491521501739_item	3747890	et	0	main
puudumise	doc_491521501739_item	3747891	et	0	main
ja	doc_491521501739_item	3747892	et	0	main
distsipliini	doc_491521501739_item	3747893	et	0	main
rikkumise	doc_491521501739_item	3747894	et	0	main
eest	doc_491521501739_item	3747895	et	0	main
avaldada	doc_491521501739_item	3747896	et	0	main
noomitus	doc_491521501739_item	3747897	et	0	main
13	doc_491521501739_item	3747898	et	0	main
õpperühma	doc_491521501739_item	3747899	et	0	main
õpilastele	doc_491521501739_item	3747900	et	0	main
2	doc_491521501739_item	3747901	et	0	main
põhjuseta	doc_491521501739_item	3747902	et	0	main
omavolilise	doc_491521501739_item	3747903	et	0	main
tunnist	doc_491521501739_item	3747904	et	0	main
puudumise	doc_491521501739_item	3747905	et	0	main
eest	doc_491521501739_item	3747906	et	0	main
avaldada	doc_491521501739_item	3747907	et	0	main
noomitus	doc_491521501739_item	3747908	et	0	main
järgmistel	doc_491521501739_item	3747909	et	0	main
12	doc_491521501739_item	3747910	et	0	main
õpperühma	doc_491521501739_item	3747911	et	0	main
õpilastel	doc_491521501739_item	3747912	et	0	main
3	doc_491521501739_item	3747913	et	0	main
põhjuseta	doc_491521501739_item	3747914	et	0	main
puudumise	doc_491521501739_item	3747915	et	0	main
ja	doc_491521501739_item	3747916	et	0	main
distsipliini	doc_491521501739_item	3747917	et	0	main
rikkumise	doc_491521501739_item	3747918	et	0	main
eest	doc_491521501739_item	3747919	et	0	main
avaldada	doc_491521501739_item	3747920	et	0	main
range	doc_491521501739_item	3747921	et	0	main
noomitus	doc_491521501739_item	3747922	et	0	main
13	doc_491521501739_item	3747923	et	0	main
õpperühma	doc_491521501739_item	3747924	et	0	main
õpilasele	doc_491521501739_item	3747925	et	0	main
4	doc_491521501739_item	3747926	et	0	main
seoses	doc_491521501739_item	3747927	et	0	main
osavõtuga	doc_491521501739_item	3747928	et	0	main
eesti	doc_491521501739_item	3747929	et	0	main
kutseõppeasutuste	doc_491521501739_item	3747930	et	0	main
2002а	doc_491521501739_item	3747931	et	0	main
meistrivõistlustes	doc_491521501739_item	3747932	et	0	main
kreeka-rooma	doc_491521501739_item	3747933	et	0	main
maadluses	doc_491521501739_item	3747934	et	0	main
vabastada	doc_491521501739_item	3747935	et	0	main
õppetööst	doc_491521501739_item	3747936	et	0	main
14032002а	doc_491521501739_item	3747937	et	0	main
järgmised	doc_491521501739_item	3747938	et	0	main
kooli	doc_491521501739_item	3747939	et	0	main
õpilased	doc_491521501739_item	3747940	et	0	main
määrata	doc_491521501739_item	3747941	et	0	main
võistkonna	doc_491521501739_item	3747942	et	0	main
juhatajaks	doc_491521501739_item	3747943	et	0	main
maša	doc_491521501739_item	3747944	et	0	main
vorotinstkaja	doc_491521501739_item	3747945	et	0	main
kehalise	doc_491521501739_item	3747946	et	0	main
kasvatuse	doc_491521501739_item	3747947	et	0	main
õpetaja	doc_491521501739_item	3747948	et	0	main
5	doc_491521501739_item	3747949	et	0	main
põhjuseta	doc_491521501739_item	3747950	et	0	main
tunnides	doc_491521501739_item	3747951	et	0	main
puudumise	doc_491521501739_item	3747952	et	0	main
eest	doc_491521501739_item	3747953	et	0	main
ja	doc_491521501739_item	3747954	et	0	main
mitterahuldava	doc_491521501739_item	3747955	et	0	main
õppeedukuse	doc_491521501739_item	3747956	et	0	main
alusel	doc_491521501739_item	3747957	et	0	main
avaldada	doc_491521501739_item	3747958	et	0	main
range	doc_491521501739_item	3747959	et	0	main
noomitus	doc_491521501739_item	3747960	et	0	main
30	doc_491521501739_item	3747961	et	0	main
õpperühma	doc_491521501739_item	3747962	et	0	main
õpilastele	doc_491521501739_item	3747963	et	0	main
6	doc_491521501739_item	3747964	et	0	main
seoses	doc_491521501739_item	3747965	et	0	main
raske	doc_491521501739_item	3747966	et	0	main
materiaalse	doc_491521501739_item	3747967	et	0	main
olukorraga	doc_491521501739_item	3747968	et	0	main
võimaldada	doc_491521501739_item	3747969	et	0	main
mattoetus	doc_491521501739_item	3747970	et	0	main
43	doc_491521501739_item	3747971	et	0	main
õpperühma	doc_491521501739_item	3747972	et	0	main
õpilasele	doc_491521501739_item	3747973	et	0	main
aljona	doc_491521501739_item	3747974	et	0	main
karpovale	doc_491521501739_item	3747975	et	0	main
materiaalne	doc_491521501739_item	3747976	et	0	main
toetus	doc_491521501739_item	3747977	et	0	main
välja	doc_491521501739_item	3747978	et	0	main
maksta	doc_491521501739_item	3747979	et	0	main
stipendiumi	doc_491521501739_item	3747980	et	0	main
fondist	doc_491521501739_item	3747981	et	0	main
7	doc_491521501739_item	3747982	et	0	main
abielutunnistuse	doc_491521501739_item	3747983	et	0	main
alusel	doc_491521501739_item	3747984	et	0	main
muuta	doc_491521501739_item	3747985	et	0	main
perekonnaimi	doc_491521501739_item	3747986	et	0	main
marina	doc_491521501739_item	3747987	et	0	main
polovna	doc_491521501739_item	3747988	et	0	main
21	doc_491521501739_item	3747989	et	0	main
õppegrupp	doc_491521501739_item	3747990	et	0	main
perekonnanimele	doc_491521501739_item	3747991	et	0	main
marina	doc_491521501739_item	3747992	et	0	main
solovjeva	doc_491521501739_item	3747993	et	0	main
asedirektorile	doc_491521501739_item	3747994	et	0	main
sisse	doc_491521501739_item	3747995	et	0	main
viia	doc_491521501739_item	3747996	et	0	main
muudatus	doc_491521501739_item	3747997	et	0	main
õpilaste	doc_491521501739_item	3747998	et	0	main
registri	doc_491521501739_item	3747999	et	0	main
8saavutatud	doc_491521501739_item	3748000	et	0	main
i	doc_491521501739_item	3748001	et	0	main
koha	doc_491521501739_item	3748002	et	0	main
eest	doc_491521501739_item	3748003	et	0	main
eesti	doc_491521501739_item	3748004	et	0	main
kutseõppeasutuste	doc_491521501739_item	3748005	et	0	main
2002а	doc_491521501739_item	3748006	et	0	main
meistrivõistlustes	doc_491521501739_item	3748007	et	0	main
premeerida	doc_491521501739_item	3748008	et	0	main
järgmised	doc_491521501739_item	3748009	et	0	main
kutsekooli	doc_491521501739_item	3748010	et	0	main
õpilased	doc_491521501739_item	3748011	et	0	main
preemia	doc_491521501739_item	3748012	et	0	main
välja	doc_491521501739_item	3748013	et	0	main
maksta	doc_491521501739_item	3748014	et	0	main
õрре-stipendiumi	doc_491521501739_item	3748015	et	0	main
fondist	doc_491521501739_item	3748016	et	0	main
9	doc_491521501739_item	3748017	et	0	main
seoses	doc_491521501739_item	3748018	et	0	main
ekskursiooni	doc_491521501739_item	3748019	et	0	main
korraldamisega	doc_491521501739_item	3748020	et	0	main
narva	doc_491521501739_item	3748021	et	0	main
linna	doc_491521501739_item	3748022	et	0	main
komandeerida	doc_491521501739_item	3748023	et	0	main
1903	doc_491521501739_item	3748024	et	0	main
2002а	doc_491521501739_item	3748025	et	0	main
järgmised	doc_491521501739_item	3748026	et	0	main
kutsekooli	doc_491521501739_item	3748027	et	0	main
õpilased	doc_491521501739_item	3748028	et	0	main
määrata	doc_491521501739_item	3748029	et	0	main
rühma	doc_491521501739_item	3748030	et	0	main
juhiks	doc_491521501739_item	3748031	et	0	main
ja	doc_491521501739_item	3748032	et	0	main
vastutava	doc_491521501739_item	3748033	et	0	main
õpetaja	doc_491521501739_item	3748034	et	0	main
nadja	doc_491521501739_item	3748035	et	0	main
gurjeva	doc_491521501739_item	3748036	et	0	main
10	doc_491521501739_item	3748037	et	0	main
materialne	doc_491521501739_item	3748038	et	0	main
toetus	doc_491521501739_item	3748039	et	0	main
seoses	doc_491521501739_item	3748040	et	0	main
raske	doc_491521501739_item	3748041	et	0	main
materialse	doc_491521501739_item	3748042	et	0	main
olukorraga	doc_491521501739_item	3748043	et	0	main
eraldada	doc_491521501739_item	3748044	et	0	main
mattoetus	doc_491521501739_item	3748045	et	0	main
46	doc_491521501739_item	3748046	et	0	main
õpperühma	doc_491521501739_item	3748047	et	0	main
õpilasele	doc_491521501739_item	3748048	et	0	main
nataša	doc_491521501739_item	3748049	et	0	main
vorotinskile	doc_491521501739_item	3748050	et	0	main
mat	doc_491521501739_item	3748051	et	0	main
toetus	doc_491521501739_item	3748052	et	0	main
välja	doc_491521501739_item	3748053	et	0	main
maksta	doc_491521501739_item	3748054	et	0	main
stipendiumi	doc_491521501739_item	3748055	et	0	main
fondi	doc_491521501739_item	3748056	et	0	main
arvelt	doc_491521501739_item	3748057	et	0	main
11	doc_491521501739_item	3748058	et	0	main
lubada	doc_491521501739_item	3748059	et	0	main
palgata	doc_491521501739_item	3748060	et	0	main
puhkus	doc_491521501739_item	3748061	et	0	main
ajavahemikul	doc_491521501739_item	3748062	et	0	main
1418032002а	doc_491521501739_item	3748063	et	0	main
köögi	doc_491521501739_item	3748064	et	0	main
töötajal	doc_491521501739_item	3748065	et	0	main
nadja	doc_491521501739_item	3748066	et	0	main
polovnal	doc_491521501739_item	3748067	et	0	main
raske	doc_491521501739_item	3748068	et	0	main
materialse	doc_491521501739_item	3748069	et	0	main
olukorra	doc_491521501739_item	3748070	et	0	main
tõttu	doc_491521501739_item	3748071	et	0	main
välja	doc_491521501739_item	3748072	et	0	main
maksta	doc_491521501739_item	3748073	et	0	main
mat	doc_491521501739_item	3748074	et	0	main
toetust	doc_491521501739_item	3748075	et	0	main
12	doc_491521501739_item	3748076	et	0	main
välja	doc_491521501739_item	3748077	et	0	main
vahetamine	doc_491521501739_item	3748078	et	0	main
old	doc_491521501739_item	3748079	et	0	main
töötaja	doc_491521501739_item	3748080	et	0	main
vladimir	doc_491521501739_item	3748081	et	0	main
barani	doc_491521501739_item	3748082	et	0	main
haiguslehel	doc_491521501739_item	3748083	et	0	main
viibimise	doc_491521501739_item	3748084	et	0	main
ajaks	doc_491521501739_item	3748085	et	0	main
lubada	doc_491521501739_item	3748086	et	0	main
töötada	doc_491521501739_item	3748087	et	0	main
töökoja	doc_491521501739_item	3748088	et	0	main
valvurina	doc_491521501739_item	3748089	et	0	main
alates	doc_491521501739_item	3748090	et	0	main
27022002	doc_491521501739_item	3748091	et	0	main
kuni	doc_491521501739_item	3748092	et	0	main
1303	doc_491521501739_item	3748093	et	0	main
2002а	doc_491521501739_item	3748094	et	0	main
maali	doc_491521501739_item	3748095	et	0	main
tarul	doc_491521501739_item	3748096	et	0	main
13	doc_491521501739_item	3748097	et	0	main
lubada	doc_491521501739_item	3748098	et	0	main
üks	doc_491521501739_item	3748099	et	0	main
päev	doc_491521501739_item	3748100	et	0	main
06032002	doc_491521501739_item	3748101	et	0	main
palgata	doc_491521501739_item	3748102	et	0	main
laborandile	doc_491521501739_item	3748103	et	0	main
marita	doc_491521501739_item	3748104	et	0	main
kuusele	doc_491521501739_item	3748105	et	0	main
14	doc_491521501739_item	3748106	et	0	main
lähetada	doc_491521501739_item	3748107	et	0	main
direktor	doc_491521501739_item	3748108	et	0	main
martin	doc_491521501739_item	3748109	et	0	main
malakov	doc_491521501739_item	3748110	et	0	main
pühajärve	doc_491521501739_item	3748111	et	0	main
määrata	doc_491521501739_item	3748112	et	0	main
asetäitja	doc_491521501739_item	3748113	et	0	main
kohale	doc_491521501739_item	3748114	et	0	main
aleksandr	doc_491521501739_item	3748115	et	0	main
barani	doc_491521501739_item	3748116	et	0	main
asedirektori	doc_491521501739_item	3748117	et	0	main
15	doc_491521501739_item	3748118	et	0	main
lubada	doc_491521501739_item	3748119	et	0	main
kolm	doc_491521501739_item	3748120	et	0	main
palgata	doc_491521501739_item	3748121	et	0	main
päeva	doc_491521501739_item	3748122	et	0	main
2728detsember	doc_491521501739_item	3748123	et	0	main
2001	doc_491521501739_item	3748124	et	0	main
ja	doc_491521501739_item	3748125	et	0	main
02jaanuar	doc_491521501739_item	3748126	et	0	main
2002а	doc_491521501739_item	3748127	et	0	main
kokkale	doc_491521501739_item	3748128	et	0	main
valentina	doc_491521501739_item	3748129	et	0	main
lurinale	doc_491521501739_item	3748130	et	0	main
16	doc_491521501739_item	3748131	et	0	main
kuulutan	doc_491521501739_item	3748132	et	0	main
tänulikkust	doc_491521501739_item	3748133	et	0	main
järgmistel	doc_491521501739_item	3748134	et	0	main
kutsekooli	doc_491521501739_item	3748135	et	0	main
õpilastel	doc_491521501739_item	3748136	et	0	main
kontrolltöö	doc_491521502078_item	3748137	et	0	main
i	doc_491521502078_item	3748138	et	0	main
tõlkige	doc_491521502078_item	3748139	et	0	main
taipama	doc_491521502078_item	3748140	et	0	main
hallitama	doc_491521502078_item	3748141	et	0	main
плесневеть	doc_491521502078_item	3748142	et	0	main
umbusklik	doc_491521502078_item	3748143	et	0	main
недоверчивый	doc_491521502078_item	3748144	et	0	main
jäätmed	doc_491521502078_item	3748145	et	0	main
отходы	doc_491521502078_item	3748146	et	0	main
pihustama	doc_491521502078_item	3748147	et	0	main
jõukohane	doc_491521502078_item	3748148	et	0	main
посильный	doc_491521502078_item	3748149	et	0	main
lakkama	doc_491521502078_item	3748150	et	0	main
прекращать	doc_491521502078_item	3748151	et	0	main
tõhus	doc_491521502078_item	3748152	et	0	main
причина	doc_491521502078_item	3748153	et	0	main
ära	doc_491521502078_item	3748154	et	0	main
kuluma	doc_491521502078_item	3748155	et	0	main
изнашиваться	doc_491521502078_item	3748156	et	0	main
toime	doc_491521502078_item	3748157	et	0	main
tulema	doc_491521502078_item	3748158	et	0	main
справляться	doc_491521502078_item	3748159	et	0	main
ii	doc_491521502078_item	3748160	et	0	main
kirjutage	doc_491521502078_item	3748161	et	0	main
ühesõnalised	doc_491521502078_item	3748162	et	0	main
sünonüümid	doc_491521502078_item	3748163	et	0	main
ära	doc_491521502078_item	3748164	et	0	main
minema	doc_491521502078_item	3748165	et	0	main
lahkuma	doc_491521502078_item	3748166	et	0	main
haigeks	doc_491521502078_item	3748167	et	0	main
jääma	doc_491521502078_item	3748168	et	0	main
haigestuma	doc_491521502078_item	3748169	et	0	main
terveks	doc_491521502078_item	3748170	et	0	main
saama	doc_491521502078_item	3748171	et	0	main
maha	doc_491521502078_item	3748172	et	0	main
jätma	doc_491521502078_item	3748173	et	0	main
kinni	doc_491521502078_item	3748174	et	0	main
püüdma	doc_491521502078_item	3748175	et	0	main
iii	doc_491521502078_item	3748176	et	0	main
mida	doc_491521502078_item	3748177	et	0	main
tehti	doc_491521502078_item	3748178	et	0	main
nõudma	doc_491521502078_item	3748179	et	0	main
nõuti	doc_491521502078_item	3748180	et	0	main
ütlema	doc_491521502078_item	3748181	et	0	main
öeldi	doc_491521502078_item	3748182	et	0	main
andma	doc_491521502078_item	3748183	et	0	main
anti	doc_491521502078_item	3748184	et	0	main
pakkuma	doc_491521502078_item	3748185	et	0	main
pakkuti	doc_491521502078_item	3748186	et	0	main
lubama	doc_491521502078_item	3748187	et	0	main
lubati	doc_491521502078_item	3748188	et	0	main
tegema	doc_491521502078_item	3748189	et	0	main
tehti	doc_491521502078_item	3748190	et	0	main
laskma	doc_491521502078_item	3748191	et	0	main
lasti	doc_491521502078_item	3748192	et	0	main
saatma	doc_491521502078_item	3748193	et	0	main
saadeti	doc_491521502078_item	3748194	et	0	main
rääkima	doc_491521502078_item	3748195	et	0	main
räägiti	doc_491521502078_item	3748196	et	0	main
teatama	doc_491521502078_item	3748197	et	0	main
teatati	doc_491521502078_item	3748198	et	0	main
iv	doc_491521502078_item	3748199	et	0	main
kasutage	doc_491521502078_item	3748200	et	0	main
v-kesksõna	doc_491521502078_item	3748201	et	0	main
prügi	doc_491521502078_item	3748202	et	0	main
mis	doc_491521502078_item	3748203	et	0	main
tekib	doc_491521502078_item	3748204	et	0	main
kodus	doc_491521502078_item	3748205	et	0	main
kodus	doc_491521502078_item	3748206	et	0	main
tekiv	doc_491521502078_item	3748207	et	0	main
prügi	doc_491521502078_item	3748208	et	0	main
vahenditeta	doc_491521502078_item	3748209	et	0	main
mis	doc_491521502078_item	3748210	et	0	main
värskendavad	doc_491521502078_item	3748211	et	0	main
õhku	doc_491521502078_item	3748212	et	0	main
õhku	doc_491521502078_item	3748213	et	0	main
värskendava	doc_491521502078_item	3748214	et	0	main
vahenditeta	doc_491521502078_item	3748215	et	0	main
inimest	doc_491521502078_item	3748216	et	0	main
kes	doc_491521502078_item	3748217	et	0	main
müüb	doc_491521502078_item	3748218	et	0	main
kosmeetikavahendeid	doc_491521502078_item	3748219	et	0	main
kosmetikavahendeid	doc_491521502078_item	3748220	et	0	main
müüvat	doc_491521502078_item	3748221	et	0	main
inimest	doc_491521502078_item	3748222	et	0	main
kreemiga	doc_491521502078_item	3748223	et	0	main
mis	doc_491521502078_item	3748224	et	0	main
niisutab	doc_491521502078_item	3748225	et	0	main
niisutava	doc_491521502078_item	3748226	et	0	main
kreemiga	doc_491521502078_item	3748227	et	0	main
šampoone	doc_491521502078_item	3748228	et	0	main
mis	doc_491521502078_item	3748229	et	0	main
ravivad	doc_491521502078_item	3748230	et	0	main
juukseid	doc_491521502078_item	3748231	et	0	main
juukseid	doc_491521502078_item	3748232	et	0	main
ravivad	doc_491521502078_item	3748233	et	0	main
šampoone	doc_491521502078_item	3748234	et	0	main
v	doc_491521502078_item	3748235	et	0	main
kasutage	doc_491521502078_item	3748236	et	0	main
tav-kesksõna	doc_491521502078_item	3748237	et	0	main
kreemidele	doc_491521502078_item	3748238	et	0	main
mis	doc_491521502078_item	3748239	et	0	main
toodetakse	doc_491521502078_item	3748240	et	0	main
välismaal	doc_491521502078_item	3748241	et	0	main
välismaal	doc_491521502078_item	3748242	et	0	main
toodetavale	doc_491521502078_item	3748243	et	0	main
kreemidele	doc_491521502078_item	3748244	et	0	main
pesu	doc_491521502078_item	3748245	et	0	main
mida	doc_491521502078_item	3748246	et	0	main
pestakse	doc_491521502078_item	3748247	et	0	main
käsitsi	doc_491521502078_item	3748248	et	0	main
käsitsi	doc_491521502078_item	3748249	et	0	main
pestav	doc_491521502078_item	3748250	et	0	main
pesu	doc_491521502078_item	3748251	et	0	main
toidust	doc_491521502078_item	3748252	et	0	main
mida	doc_491521502078_item	3748253	et	0	main
süüakse	doc_491521502078_item	3748254	et	0	main
söödavat	doc_491521502078_item	3748255	et	0	main
toidust	doc_491521502078_item	3748256	et	0	main
kaupu	doc_491521502078_item	3748257	et	0	main
mida	doc_491521502078_item	3748258	et	0	main
ostetakse	doc_491521502078_item	3748259	et	0	main
harva	doc_491521502078_item	3748260	et	0	main
harva	doc_491521502078_item	3748261	et	0	main
ostetavaid	doc_491521502078_item	3748262	et	0	main
kaupu	doc_491521502078_item	3748263	et	0	main
kaanega	doc_491521502078_item	3748264	et	0	main
mida	doc_491521502078_item	3748265	et	0	main
saab	doc_491521502078_item	3748266	et	0	main
kergesti	doc_491521502078_item	3748267	et	0	main
avada	doc_491521502078_item	3748268	et	0	main
kergesti	doc_491521502078_item	3748269	et	0	main
saadeva	doc_491521502078_item	3748270	et	0	main
avada	doc_491521502078_item	3748271	et	0	main
kaanega	doc_491521502078_item	3748272	et	0	main
vi	doc_491521502078_item	3748273	et	0	main
tõmmake	doc_491521502078_item	3748274	et	0	main
maha	doc_491521502078_item	3748275	et	0	main
alla	doc_491521502078_item	3748276	et	0	main
valed	doc_491521502078_item	3748277	et	0	main
sõnad	doc_491521502078_item	3748278	et	0	main
suurt	doc_491521502078_item	3748279	et	0	main
koera	doc_491521502078_item	3748280	et	0	main
peab	doc_491521502078_item	3748281	et	0	main
kordamööda	doc_491521502078_item	3748282	et	0	main
ilmtingimata	doc_491521502078_item	3748283	et	0	main
omapead	doc_491521502078_item	3748284	et	0	main
õpetama	doc_491521502078_item	3748285	et	0	main
selle	doc_491521502078_item	3748286	et	0	main
pintsaku	doc_491521502078_item	3748287	et	0	main
õmblused	doc_491521502078_item	3748288	et	0	main
käsitsevad	doc_491521502078_item	3748289	et	0	main
kisuvad	doc_491521502078_item	3748290	et	0	main
luituvad	doc_491521502078_item	3748291	et	0	main
artiklid	doc_491521502078_item	3748292	et	0	main
kahjustasid	doc_491521502078_item	3748293	et	0	main
firma	doc_491521502078_item	3748294	et	0	main
olemust	doc_491521502078_item	3748295	et	0	main
mainet	doc_491521502078_item	3748296	et	0	main
puänti	doc_491521502078_item	3748297	et	0	main
seda	doc_491521502078_item	3748298	et	0	main
plaani	doc_491521502078_item	3748299	et	0	main
on	doc_491521502078_item	3748300	et	0	main
raske	doc_491521502078_item	3748301	et	0	main
liigitada	doc_491521502078_item	3748302	et	0	main
sisaldada	doc_491521502078_item	3748303	et	0	main
teostada	doc_491521502078_item	3748304	et	0	main
inimesed	doc_491521502078_item	3748305	et	0	main
peaksid	doc_491521502078_item	3748306	et	0	main
endale	doc_491521502078_item	3748307	et	0	main
rohkem	doc_491521502078_item	3748308	et	0	main
teadvustama	doc_491521502078_item	3748309	et	0	main
keskkonna	doc_491521502078_item	3748310	et	0	main
reostamise	doc_491521502078_item	3748311	et	0	main
järeldusi	doc_491521502078_item	3748312	et	0	main
tagajärgi	doc_491521502078_item	3748313	et	0	main
tulemusi	doc_491521502078_item	3748314	et	0	main
vii	doc_491521502078_item	3748315	et	0	main
tõlkige	doc_491521502078_item	3748316	et	0	main
система	doc_491521502078_item	3748317	et	0	main
переработки	doc_491521502078_item	3748318	et	0	main
мусора	doc_491521502078_item	3748319	et	0	main
не	doc_491521502078_item	3748320	et	0	main
разработана	doc_491521502078_item	3748321	et	0	main
заказывая	doc_491521502078_item	3748322	et	0	main
по	doc_491521502078_item	3748323	et	0	main
каталогу	doc_491521502078_item	3748324	et	0	main
вы	doc_491521502078_item	3748325	et	0	main
экономите	doc_491521502078_item	3748326	et	0	main
время	doc_491521502078_item	3748327	et	0	main
tellides	doc_491521502078_item	3748328	et	0	main
kataloogist	doc_491521502078_item	3748329	et	0	main
te	doc_491521502078_item	3748330	et	0	main
säästate	doc_491521502078_item	3748331	et	0	main
aega	doc_491521502078_item	3748332	et	0	main
фирма	doc_491521502078_item	3748333	et	0	main
привлекает	doc_491521502078_item	3748334	et	0	main
клиентов	doc_491521502078_item	3748335	et	0	main
подарками	doc_491521502078_item	3748336	et	0	main
firma	doc_491521502078_item	3748337	et	0	main
meelitab	doc_491521502078_item	3748338	et	0	main
kliente	doc_491521502078_item	3748339	et	0	main
kingitustega	doc_491521502078_item	3748340	et	0	main
это	doc_491521502078_item	3748341	et	0	main
нарушает	doc_491521502078_item	3748342	et	0	main
принципы	doc_491521502078_item	3748343	et	0	main
торговли	doc_491521502078_item	3748344	et	0	main
свободного	doc_491521502078_item	3748345	et	0	main
рынка	doc_491521502078_item	3748346	et	0	main
see	doc_491521502078_item	3748347	et	0	main
häirib	doc_491521502078_item	3748348	et	0	main
kaubanduse	doc_491521502078_item	3748349	et	0	main
printsiipe	doc_491521502078_item	3748350	et	0	main
vaba	doc_491521502078_item	3748351	et	0	main
turu	doc_491521502078_item	3748352	et	0	main
у	doc_491521502078_item	3748353	et	0	main
вас	doc_491521502078_item	3748354	et	0	main
есть	doc_491521502078_item	3748355	et	0	main
возможность	doc_491521502078_item	3748356	et	0	main
дома	doc_491521502078_item	3748357	et	0	main
спокойно	doc_491521502078_item	3748358	et	0	main
изучить	doc_491521502078_item	3748359	et	0	main
каталог	doc_491521502078_item	3748360	et	0	main
kodus	doc_491521502078_item	3748361	et	0	main
teil	doc_491521502078_item	3748362	et	0	main
on	doc_491521502078_item	3748363	et	0	main
võimalus	doc_491521502078_item	3748364	et	0	main
rahulikult	doc_491521502078_item	3748365	et	0	main
kataloogi	doc_491521502078_item	3748366	et	0	main
uurida	doc_491521502078_item	3748367	et	0	main
viii	doc_491521502078_item	3748368	et	0	main
pange	doc_491521502078_item	3748369	et	0	main
sulgudes	doc_491521502078_item	3748370	et	0	main
olevad	doc_491521502078_item	3748371	et	0	main
sõnad	doc_491521502078_item	3748372	et	0	main
õigesse	doc_491521502078_item	3748373	et	0	main
vormi	doc_491521502078_item	3748374	et	0	main
see	doc_491521502078_item	3748375	et	0	main
näeb	doc_491521502078_item	3748376	et	0	main
jube	doc_491521502078_item	3748377	et	0	main
jubedalt	doc_491521502078_item	3748378	et	0	main
välja	doc_491521502078_item	3748379	et	0	main
on	doc_491521502078_item	3748380	et	0	main
väga	doc_491521502078_item	3748381	et	0	main
piinlik	doc_491521502078_item	3748382	et	0	main
piinlik	doc_491521502078_item	3748383	et	0	main
kui	doc_491521502078_item	3748384	et	0	main
inimesed	doc_491521502078_item	3748385	et	0	main
ei	doc_491521502078_item	3748386	et	0	main
korista	doc_491521502078_item	3748387	et	0	main
enda	doc_491521502078_item	3748388	et	0	main
järelt	doc_491521502078_item	3748389	et	0	main
vihma	doc_491521502078_item	3748390	et	0	main
sajab	doc_491521502078_item	3748391	et	0	main
lakkamatu	doc_491521502078_item	3748392	et	0	main
lakkamatult	doc_491521502078_item	3748393	et	0	main
kassis	doc_491521502078_item	3748394	et	0	main
ajavad	doc_491521502078_item	3748395	et	0	main
hirmus	doc_491521502078_item	3748396	et	0	main
hirmsasti	doc_491521502078_item	3748397	et	0	main
karva	doc_491521502078_item	3748398	et	0	main
mul	doc_491521502078_item	3748399	et	0	main
on	doc_491521502078_item	3748400	et	0	main
ebameeldiv	doc_491521502078_item	3748401	et	0	main
ebameeldiv	doc_491521502078_item	3748402	et	0	main
seda	doc_491521502078_item	3748403	et	0	main
vaadata	doc_491521502078_item	3748404	et	0	main
diplomitöö	doc_491521501746_item	3748405	et	0	main
sissejuhatus	doc_491521501746_item	3748406	et	0	main
diplomitöö	doc_491521501746_item	3748407	et	0	main
teemaks	doc_491521501746_item	3748408	et	0	main
on	doc_491521501746_item	3748409	et	0	main
nissi	doc_491521501746_item	3748410	et	0	main
kihelkonna	doc_491521501746_item	3748411	et	0	main
aja-	doc_491521501746_item	3748412	et	0	main
ja	doc_491521501746_item	3748413	et	0	main
kohapärimused	doc_491521501746_item	3748414	et	0	main
teema	doc_491521501746_item	3748415	et	0	main
valikulut	doc_491521501746_item	3748416	et	0	main
saab	doc_491521501746_item	3748417	et	0	main
põhjendada	doc_491521501746_item	3748418	et	0	main
mitmel	doc_491521501746_item	3748419	et	0	main
moel	doc_491521501746_item	3748420	et	0	main
kihelkonnas	doc_491521501746_item	3748421	et	0	main
paikneb	doc_491521501746_item	3748422	et	0	main
14	doc_491521501746_item	3748423	et	0	main
mõisat	doc_491521501746_item	3748424	et	0	main
neist	doc_491521501746_item	3748425	et	0	main
1	doc_491521501746_item	3748426	et	0	main
kirikumõis	doc_491521501746_item	3748427	et	0	main
9	doc_491521501746_item	3748428	et	0	main
rüütlimõisast	doc_491521501746_item	3748429	et	0	main
peamõisat	doc_491521501746_item	3748430	et	0	main
koos	doc_491521501746_item	3748431	et	0	main
2	doc_491521501746_item	3748432	et	0	main
kõrvalmõisaga	doc_491521501746_item	3748433	et	0	main
ning	doc_491521501746_item	3748434	et	0	main
2	doc_491521501746_item	3748435	et	0	main
poolmõisat	doc_491521501746_item	3748436	et	0	main
sellele	doc_491521501746_item	3748437	et	0	main
lisandub	doc_491521501746_item	3748438	et	0	main
2	doc_491521501746_item	3748439	et	0	main
karjamõisat	doc_491521501746_item	3748440	et	0	main
jaanika	doc_491521501746_item	3748441	et	0	main
janiko	doc_491521501746_item	3748442	et	0	main
munalaskme	doc_491521501746_item	3748443	et	0	main
kõrvalmõis	doc_491521501746_item	3748444	et	0	main
laitse	doc_491521501746_item	3748445	et	0	main
laitz	doc_491521501746_item	3748446	et	0	main
rüütlimõis	doc_491521501746_item	3748447	et	0	main
lehetu	doc_491521501746_item	3748448	et	0	main
lehhet	doc_491521501746_item	3748449	et	0	main
rüütlimõis	doc_491521501746_item	3748450	et	0	main
munalaskme	doc_491521501746_item	3748451	et	0	main
munnalas	doc_491521501746_item	3748452	et	0	main
rüütlimõis	doc_491521501746_item	3748453	et	0	main
nurme	doc_491521501746_item	3748454	et	0	main
nurms	doc_491521501746_item	3748455	et	0	main
rüütlimõis	doc_491521501746_item	3748456	et	0	main
pajaka	doc_491521501746_item	3748457	et	0	main
pajak	doc_491521501746_item	3748458	et	0	main
rüütlimõis	doc_491521501746_item	3748459	et	0	main
põlli	doc_491521501746_item	3748460	et	0	main
poll	doc_491521501746_item	3748461	et	0	main
rüütlimõis	doc_491521501746_item	3748462	et	0	main
pärnamaa	doc_491521501746_item	3748463	et	0	main
pernama	doc_491521501746_item	3748464	et	0	main
poolmõis	doc_491521501746_item	3748465	et	0	main
riisipere	doc_491521501746_item	3748466	et	0	main
riesenberg	doc_491521501746_item	3748467	et	0	main
neu-riesenberg	doc_491521501746_item	3748468	et	0	main
rüütlimõis	doc_491521501746_item	3748469	et	0	main
russalu	doc_491521501746_item	3748470	et	0	main
russal	doc_491521501746_item	3748471	et	0	main
rüütlimõis	doc_491521501746_item	3748472	et	0	main
vana-riisipere	doc_491521501746_item	3748473	et	0	main
alt-riesenberg	doc_491521501746_item	3748474	et	0	main
riisipere	doc_491521501746_item	3748475	et	0	main
kõrvalmõis	doc_491521501746_item	3748476	et	0	main
üle	doc_491521501746_item	3748477	et	0	main
kolmveerandi	doc_491521501746_item	3748478	et	0	main
ajaloolisse	doc_491521501746_item	3748479	et	0	main
harjumaale	doc_491521501746_item	3748480	et	0	main
harrien	doc_491521501746_item	3748481	et	0	main
kuuluva	doc_491521501746_item	3748482	et	0	main
kihelkonna	doc_491521501746_item	3748483	et	0	main
aladest	doc_491521501746_item	3748484	et	0	main
jääb	doc_491521501746_item	3748485	et	0	main
kaasaegsele	doc_491521501746_item	3748486	et	0	main
harjumaale	doc_491521501746_item	3748487	et	0	main
umbes	doc_491521501746_item	3748488	et	0	main
veerand	doc_491521501746_item	3748489	et	0	main
raplamaale	doc_491521501746_item	3748490	et	0	main
kaasaegsele	doc_491521501746_item	3748491	et	0	main
harjumaale	doc_491521501746_item	3748492	et	0	main
jääv	doc_491521501746_item	3748493	et	0	main
kihelkonna	doc_491521501746_item	3748494	et	0	main
ala	doc_491521501746_item	3748495	et	0	main
kattub	doc_491521501746_item	3748496	et	0	main
suuremalt	doc_491521501746_item	3748497	et	0	main
jaolt	doc_491521501746_item	3748498	et	0	main
nissi	doc_491521501746_item	3748499	et	0	main
vallaga	doc_491521501746_item	3748500	et	0	main
kihelkonna	doc_491521501746_item	3748501	et	0	main
kirdeosa	doc_491521501746_item	3748502	et	0	main
laitse	doc_491521501746_item	3748503	et	0	main
ümbruses	doc_491521501746_item	3748504	et	0	main
kuulub	doc_491521501746_item	3748505	et	0	main
kernu	doc_491521501746_item	3748506	et	0	main
valda	doc_491521501746_item	3748507	et	0	main
kihelkonna	doc_491521501746_item	3748508	et	0	main
kaguosa	doc_491521501746_item	3748509	et	0	main
mitmete	doc_491521501746_item	3748510	et	0	main
mõisatega	doc_491521501746_item	3748511	et	0	main
vardi	doc_491521501746_item	3748512	et	0	main
lähikonnas	doc_491521501746_item	3748513	et	0	main
kuulub	doc_491521501746_item	3748514	et	0	main
märjamaa	doc_491521501746_item	3748515	et	0	main
valda	doc_491521501746_item	3748516	et	0	main
kaasaegsel	doc_491521501746_item	3748517	et	0	main
raplamaal	doc_491521501746_item	3748518	et	0	main
1	doc_491521501746_item	3748519	et	0	main
peatükk	doc_491521501746_item	3748520	et	0	main
11	doc_491521501746_item	3748521	et	0	main
rahvaluule	doc_491521501746_item	3748522	et	0	main
üldist	doc_491521501746_item	3748523	et	0	main
rahvaluule	doc_491521501746_item	3748524	et	0	main
on	doc_491521501746_item	3748525	et	0	main
inimkonna	doc_491521501746_item	3748526	et	0	main
vaimse	doc_491521501746_item	3748527	et	0	main
kultuuri	doc_491521501746_item	3748528	et	0	main
osa	doc_491521501746_item	3748529	et	0	main
mida	doc_491521501746_item	3748530	et	0	main
säilitatakse	doc_491521501746_item	3748531	et	0	main
teadlikult	doc_491521501746_item	3748532	et	0	main
või	doc_491521501746_item	3748533	et	0	main
ebateadlikult	doc_491521501746_item	3748534	et	0	main
usundilistes	doc_491521501746_item	3748535	et	0	main
kujutelmades	doc_491521501746_item	3748536	et	0	main
mille	doc_491521501746_item	3748537	et	0	main
allikaks	doc_491521501746_item	3748538	et	0	main
om	doc_491521501746_item	3748539	et	0	main
inimese	doc_491521501746_item	3748540	et	0	main
kogemused	doc_491521501746_item	3748541	et	0	main
ja	doc_491521501746_item	3748542	et	0	main
elunähtused	doc_491521501746_item	3748543	et	0	main
rahvaluule	doc_491521501746_item	3748544	et	0	main
tekkimiseks	doc_491521501746_item	3748545	et	0	main
pole	doc_491521501746_item	3748546	et	0	main
kindlat	doc_491521501746_item	3748547	et	0	main
aega	doc_491521501746_item	3748548	et	0	main
kohta	doc_491521501746_item	3748549	et	0	main
või	doc_491521501746_item	3748550	et	0	main
isikut	doc_491521501746_item	3748551	et	0	main
see	doc_491521501746_item	3748552	et	0	main
võib	doc_491521501746_item	3748553	et	0	main
tekkida	doc_491521501746_item	3748554	et	0	main
kõikjal	doc_491521501746_item	3748555	et	0	main
seda	doc_491521501746_item	3748556	et	0	main
võib	doc_491521501746_item	3748557	et	0	main
luua	doc_491521501746_item	3748558	et	0	main
ükskõik	doc_491521501746_item	3748559	et	0	main
mis	doc_491521501746_item	3748560	et	0	main
isik	doc_491521501746_item	3748561	et	0	main
või	doc_491521501746_item	3748562	et	0	main
grupp	doc_491521501746_item	3748563	et	0	main
rahvaluule	doc_491521501746_item	3748564	et	0	main
on	doc_491521501746_item	3748565	et	0	main
omasugune	doc_491521501746_item	3748566	et	0	main
informatsioon	doc_491521501746_item	3748567	et	0	main
või	doc_491521501746_item	3748568	et	0	main
kogemuste	doc_491521501746_item	3748569	et	0	main
kokkuvõte	doc_491521501746_item	3748570	et	0	main
rahvaluule	doc_491521501746_item	3748571	et	0	main
ringleb	doc_491521501746_item	3748572	et	0	main
kõigis	doc_491521501746_item	3748573	et	0	main
inimgruppides	doc_491521501746_item	3748574	et	0	main
tal	doc_491521501746_item	3748575	et	0	main
on	doc_491521501746_item	3748576	et	0	main
oma	doc_491521501746_item	3748577	et	0	main
andja	doc_491521501746_item	3748578	et	0	main
ja	doc_491521501746_item	3748579	et	0	main
vastuvõtja	doc_491521501746_item	3748580	et	0	main
teda	doc_491521501746_item	3748581	et	0	main
kasutatakse	doc_491521501746_item	3748582	et	0	main
ja	doc_491521501746_item	3748583	et	0	main
muudetakse	doc_491521501746_item	3748584	et	0	main
varieeritakse	doc_491521501746_item	3748585	et	0	main
ja	doc_491521501746_item	3748586	et	0	main
kohandakse	doc_491521501746_item	3748587	et	0	main
ta	doc_491521501746_item	3748588	et	0	main
tekib	doc_491521501746_item	3748589	et	0	main
ja	doc_491521501746_item	3748590	et	0	main
elab	doc_491521501746_item	3748591	et	0	main
areneb	doc_491521501746_item	3748592	et	0	main
kaob	doc_491521501746_item	3748593	et	0	main
tal	doc_491521501746_item	3748594	et	0	main
on	doc_491521501746_item	3748595	et	0	main
omad	doc_491521501746_item	3748596	et	0	main
arenemisfaasid	doc_491521501746_item	3748597	et	0	main
rahvaluule	doc_491521501746_item	3748598	et	0	main
on	doc_491521501746_item	3748599	et	0	main
seotud	doc_491521501746_item	3748600	et	0	main
keskkonnaga	doc_491521501746_item	3748601	et	0	main
selle	doc_491521501746_item	3748602	et	0	main
majanduse	doc_491521501746_item	3748603	et	0	main
ja	doc_491521501746_item	3748604	et	0	main
kultuuri	doc_491521501746_item	3748605	et	0	main
arenemise	doc_491521501746_item	3748606	et	0	main
ja	doc_491521501746_item	3748607	et	0	main
muutumisega	doc_491521501746_item	3748608	et	0	main
rahvaluule	doc_491521501746_item	3748609	et	0	main
on	doc_491521501746_item	3748610	et	0	main
töötava	doc_491521501746_item	3748611	et	0	main
rahva	doc_491521501746_item	3748612	et	0	main
kollektiivne	doc_491521501746_item	3748613	et	0	main
traditsiooniline	doc_491521501746_item	3748614	et	0	main
vaimne	doc_491521501746_item	3748615	et	0	main
kunstilooming	doc_491521501746_item	3748616	et	0	main
mis	doc_491521501746_item	3748617	et	0	main
on	doc_491521501746_item	3748618	et	0	main
tekkinud	doc_491521501746_item	3748619	et	0	main
ja	doc_491521501746_item	3748620	et	0	main
levinud	doc_491521501746_item	3748621	et	0	main
suuliselt	doc_491521501746_item	3748622	et	0	main
peegeldab	doc_491521501746_item	3748623	et	0	main
oma	doc_491521501746_item	3748624	et	0	main
tekkimise	doc_491521501746_item	3748625	et	0	main
ja	doc_491521501746_item	3748626	et	0	main
levimise	doc_491521501746_item	3748627	et	0	main
keskkonda	doc_491521501746_item	3748628	et	0	main
rahvaluulet	doc_491521501746_item	3748629	et	0	main
uurib	doc_491521501746_item	3748630	et	0	main
rahvaluuleteadus	doc_491521501746_item	3748631	et	0	main
e	doc_491521501746_item	3748632	et	0	main
folkloristika	doc_491521501746_item	3748633	et	0	main
eesti	doc_491521501746_item	3748634	et	0	main
rahvaluuleteaduse	doc_491521501746_item	3748635	et	0	main
aineks	doc_491521501746_item	3748636	et	0	main
on	doc_491521501746_item	3748637	et	0	main
traditsiooniline	doc_491521501746_item	3748638	et	0	main
suuline	doc_491521501746_item	3748639	et	0	main
looming	doc_491521501746_item	3748640	et	0	main
so	doc_491521501746_item	3748641	et	0	main
laulid	doc_491521501746_item	3748642	et	0	main
regivärsilised	doc_491521501746_item	3748643	et	0	main
riimilised	doc_491521501746_item	3748644	et	0	main
jutud	doc_491521501746_item	3748645	et	0	main
muinasjutud	doc_491521501746_item	3748646	et	0	main
naljandid	doc_491521501746_item	3748647	et	0	main
muistendid	doc_491521501746_item	3748648	et	0	main
pajatused	doc_491521501746_item	3748649	et	0	main
vanasõnad	doc_491521501746_item	3748650	et	0	main
kõnekäänud	doc_491521501746_item	3748651	et	0	main
mõistatused	doc_491521501746_item	3748652	et	0	main
kogu	doc_491521501746_item	3748653	et	0	main
rahvalooming	doc_491521501746_item	3748654	et	0	main
seostub	doc_491521501746_item	3748655	et	0	main
kommete	doc_491521501746_item	3748656	et	0	main
uskumuste	doc_491521501746_item	3748657	et	0	main
mängude	doc_491521501746_item	3748658	et	0	main
muusika	doc_491521501746_item	3748659	et	0	main
ja	doc_491521501746_item	3748660	et	0	main
tantsudega	doc_491521501746_item	3748661	et	0	main
mõnevõrra	doc_491521501746_item	3748662	et	0	main
rahvapillidega	doc_491521501746_item	3748663	et	0	main
folkliristika	doc_491521501746_item	3748664	et	0	main
aineks	doc_491521501746_item	3748665	et	0	main
on	doc_491521501746_item	3748666	et	0	main
ka	doc_491521501746_item	3748667	et	0	main
rahvaluule	doc_491521501746_item	3748668	et	0	main
kogumise	doc_491521501746_item	3748669	et	0	main
ja	doc_491521501746_item	3748670	et	0	main
uurimise	doc_491521501746_item	3748671	et	0	main
ajalugu	doc_491521501746_item	3748672	et	0	main
laugaste	doc_491521501746_item	3748673	et	0	main
1986	doc_491521501746_item	3748674	et	0	main
74	doc_491521501746_item	3748675	et	0	main
12	doc_491521501746_item	3748676	et	0	main
rahvaluule	doc_491521501746_item	3748677	et	0	main
kogumise	doc_491521501746_item	3748678	et	0	main
ajaloost	doc_491521501746_item	3748679	et	0	main
rahva	doc_491521501746_item	3748680	et	0	main
elu	doc_491521501746_item	3748681	et	0	main
vastu	doc_491521501746_item	3748682	et	0	main
hakati	doc_491521501746_item	3748683	et	0	main
eestis	doc_491521501746_item	3748684	et	0	main
teadlikku	doc_491521501746_item	3748685	et	0	main
huvi	doc_491521501746_item	3748686	et	0	main
tundma	doc_491521501746_item	3748687	et	0	main
1980-ndatel	doc_491521501746_item	3748688	et	0	main
selle	doc_491521501746_item	3748689	et	0	main
ajal	doc_491521501746_item	3748690	et	0	main
töötasid	doc_491521501746_item	3748691	et	0	main
tartus	doc_491521501746_item	3748692	et	0	main
ülikooli	doc_491521501746_item	3748693	et	0	main
nooremate	doc_491521501746_item	3748694	et	0	main
õppejõudude	doc_491521501746_item	3748695	et	0	main
ja	doc_491521501746_item	3748696	et	0	main
linna	doc_491521501746_item	3748697	et	0	main
intelligentsi	doc_491521501746_item	3748698	et	0	main
huvitatumate	doc_491521501746_item	3748699	et	0	main
liikmete	doc_491521501746_item	3748700	et	0	main
hulgast	doc_491521501746_item	3748701	et	0	main
koondunud	doc_491521501746_item	3748702	et	0	main
teaduslikud	doc_491521501746_item	3748703	et	0	main
vestlusringid	doc_491521501746_item	3748704	et	0	main
millest	doc_491521501746_item	3748705	et	0	main
ühesse	doc_491521501746_item	3748706	et	0	main
kuulusid	doc_491521501746_item	3748707	et	0	main
isikud	doc_491521501746_item	3748708	et	0	main
kes	doc_491521501746_item	3748709	et	0	main
olid	doc_491521501746_item	3748710	et	0	main
huvitatud	doc_491521501746_item	3748711	et	0	main
eesti	doc_491521501746_item	3748712	et	0	main
keelest	doc_491521501746_item	3748713	et	0	main
kirjandusest	doc_491521501746_item	3748714	et	0	main
ajaloostja	doc_491521501746_item	3748715	et	0	main
eestlaste	doc_491521501746_item	3748716	et	0	main
poolt	doc_491521501746_item	3748717	et	0	main
austatud	doc_491521501746_item	3748718	et	0	main
maast	doc_491521501746_item	3748719	et	0	main
sinna	doc_491521501746_item	3748720	et	0	main
kuulusid	doc_491521501746_item	3748721	et	0	main
ka	doc_491521501746_item	3748722	et	0	main
mõned	doc_491521501746_item	3748723	et	0	main
eestlased	doc_491521501746_item	3748724	et	0	main
nt	doc_491521501746_item	3748725	et	0	main
fr	doc_491521501746_item	3748726	et	0	main
r	doc_491521501746_item	3748727	et	0	main
faehlmann	doc_491521501746_item	3748728	et	0	main
tartu	doc_491521501746_item	3748729	et	0	main
seminari	doc_491521501746_item	3748730	et	0	main
inspektor	doc_491521501746_item	3748731	et	0	main
d	doc_491521501746_item	3748732	et	0	main
h	doc_491521501746_item	3748733	et	0	main
jürgenson	doc_491521501746_item	3748734	et	0	main
pika	doc_491521501746_item	3748735	et	0	main
ettevalmistava	doc_491521501746_item	3748736	et	0	main
töö	doc_491521501746_item	3748737	et	0	main
järel	doc_491521501746_item	3748738	et	0	main
rajati	doc_491521501746_item	3748739	et	0	main
tartus	doc_491521501746_item	3748740	et	0	main
õpetatud	doc_491521501746_item	3748741	et	0	main
eesti	doc_491521501746_item	3748742	et	0	main
selts	doc_491521501746_item	3748743	et	0	main
1838	doc_491521501746_item	3748744	et	0	main
1939	doc_491521501746_item	3748745	et	0	main
a	doc_491521501746_item	3748746	et	0	main
liitus	doc_491521501746_item	3748747	et	0	main
seltsiga	doc_491521501746_item	3748748	et	0	main
ka	doc_491521501746_item	3748749	et	0	main
f	doc_491521501746_item	3748750	et	0	main
r	doc_491521501746_item	3748751	et	0	main
kreutzwald	doc_491521501746_item	3748752	et	0	main
1842	doc_491521501746_item	3748753	et	0	main
a	doc_491521501746_item	3748754	et	0	main
rajati	doc_491521501746_item	3748755	et	0	main
tallinnas	doc_491521501746_item	3748756	et	0	main
eestimaa	doc_491521501746_item	3748757	et	0	main
kirjanduslik	doc_491521501746_item	3748758	et	0	main
ühing	doc_491521501746_item	3748759	et	0	main
mõlema	doc_491521501746_item	3748760	et	0	main
eesmärkide	doc_491521501746_item	3748761	et	0	main
hulka	doc_491521501746_item	3748762	et	0	main
kuulus	doc_491521501746_item	3748763	et	0	main
rahvaluule	doc_491521501746_item	3748764	et	0	main
kogumine	doc_491521501746_item	3748765	et	0	main
rahvaluule	doc_491521501746_item	3748766	et	0	main
tähtsuse	doc_491521501746_item	3748767	et	0	main
mõistmine	doc_491521501746_item	3748768	et	0	main
avardus	doc_491521501746_item	3748769	et	0	main
19	doc_491521501746_item	3748770	et	0	main
s	doc_491521501746_item	3748771	et	0	main
viimasel	doc_491521501746_item	3748772	et	0	main
veerandil	doc_491521501746_item	3748773	et	0	main
ja	doc_491521501746_item	3748774	et	0	main
jõudis	doc_491521501746_item	3748775	et	0	main
nüüd	doc_491521501746_item	3748776	et	0	main
ka	doc_491521501746_item	3748777	et	0	main
talurahvani	doc_491521501746_item	3748778	et	0	main
tippu	doc_491521501746_item	3748779	et	0	main
aga	doc_491521501746_item	3748780	et	0	main
jõudis	doc_491521501746_item	3748781	et	0	main
see	doc_491521501746_item	3748782	et	0	main
pastor	doc_491521501746_item	3748783	et	0	main
jakob	doc_491521501746_item	3748784	et	0	main
hurda	doc_491521501746_item	3748785	et	0	main
1839-1907	doc_491521501746_item	3748786	et	0	main
juhitud	doc_491521501746_item	3748787	et	0	main
ülemaalise	doc_491521501746_item	3748788	et	0	main
rahvaluulekogumisega	doc_491521501746_item	3748789	et	0	main
milles	doc_491521501746_item	3748790	et	0	main
osales	doc_491521501746_item	3748791	et	0	main
sadu	doc_491521501746_item	3748792	et	0	main
inimesi	doc_491521501746_item	3748793	et	0	main
rahvaluulekogumisega	doc_491521501746_item	3748794	et	0	main
alustas	doc_491521501746_item	3748795	et	0	main
hurt	doc_491521501746_item	3748796	et	0	main
juba	doc_491521501746_item	3748797	et	0	main
1860	doc_491521501746_item	3748798	et	0	main
a	doc_491521501746_item	3748799	et	0	main
kodukihelkonnas	doc_491521501746_item	3748800	et	0	main
tõmmates	doc_491521501746_item	3748801	et	0	main
selleks	doc_491521501746_item	3748802	et	0	main
kaasa	doc_491521501746_item	3748803	et	0	main
oma	doc_491521501746_item	3748804	et	0	main
sugulasi	doc_491521501746_item	3748805	et	0	main
ja	doc_491521501746_item	3748806	et	0	main
ligidadi	doc_491521501746_item	3748807	et	0	main
tuttavaid	doc_491521501746_item	3748808	et	0	main
hurda	doc_491521501746_item	3748809	et	0	main
kodu-uurimuslik	doc_491521501746_item	3748810	et	0	main
tagavus	doc_491521501746_item	3748811	et	0	main
hoogustus	doc_491521501746_item	3748812	et	0	main
1871	doc_491521501746_item	3748813	et	0	main
a	doc_491521501746_item	3748814	et	0	main
kui	doc_491521501746_item	3748815	et	0	main
ta	doc_491521501746_item	3748816	et	0	main
oli	doc_491521501746_item	3748817	et	0	main
eesti	doc_491521501746_item	3748818	et	0	main
postimehe	doc_491521501746_item	3748819	et	0	main
lisalehe	doc_491521501746_item	3748820	et	0	main
toimetaja	doc_491521501746_item	3748821	et	0	main
selles	doc_491521501746_item	3748822	et	0	main
väljaandes	doc_491521501746_item	3748823	et	0	main
ilmusidki	doc_491521501746_item	3748824	et	0	main
tema	doc_491521501746_item	3748825	et	0	main
esimesed	doc_491521501746_item	3748826	et	0	main
ulatuslikud	doc_491521501746_item	3748827	et	0	main
kodu-uurimuslikud	doc_491521501746_item	3748828	et	0	main
üleskutsed	doc_491521501746_item	3748829	et	0	main
ja	doc_491521501746_item	3748830	et	0	main
selgitused	doc_491521501746_item	3748831	et	0	main
järv	doc_491521501746_item	3748832	et	0	main
1977	doc_491521501746_item	3748833	et	0	main
62	doc_491521501746_item	3748834	et	0	main
neis	doc_491521501746_item	3748835	et	0	main
üleskutsetes	doc_491521501746_item	3748836	et	0	main
ja	doc_491521501746_item	3748837	et	0	main
artiklites	doc_491521501746_item	3748838	et	0	main
fikseerib	doc_491521501746_item	3748839	et	0	main
ta	doc_491521501746_item	3748840	et	0	main
ka	doc_491521501746_item	3748841	et	0	main
rahvaluuleliigid	doc_491521501746_item	3748842	et	0	main
ja	doc_491521501746_item	3748843	et	0	main
žanrid	doc_491521501746_item	3748844	et	0	main
kogumistöö	doc_491521501746_item	3748845	et	0	main
korgaeg	doc_491521501746_item	3748846	et	0	main
algas	doc_491521501746_item	3748847	et	0	main
tal	doc_491521501746_item	3748848	et	0	main
1888	doc_491521501746_item	3748849	et	0	main
aastast	doc_491521501746_item	3748850	et	0	main
millal	doc_491521501746_item	3748851	et	0	main
ilmus	doc_491521501746_item	3748852	et	0	main
põhjalik	doc_491521501746_item	3748853	et	0	main
ja	doc_491521501746_item	3748854	et	0	main
metoodiliselt	doc_491521501746_item	3748855	et	0	main
läbitöötatud	doc_491521501746_item	3748856	et	0	main
üleskutse	doc_491521501746_item	3748857	et	0	main
paar	doc_491521501746_item	3748858	et	0	main
palvid	doc_491521501746_item	3748859	et	0	main
eesti	doc_491521501746_item	3748860	et	0	main
ärksamaile	doc_491521501746_item	3748861	et	0	main
poegadele	doc_491521501746_item	3748862	et	0	main
ja	doc_491521501746_item	3748863	et	0	main
tütardele	doc_491521501746_item	3748864	et	0	main
1875	doc_491521501746_item	3748865	et	0	main
aastal	doc_491521501746_item	3748866	et	0	main
esitas	doc_491521501746_item	3748867	et	0	main
hurt	doc_491521501746_item	3748868	et	0	main
eesti	doc_491521501746_item	3748869	et	0	main
kirjameeste	doc_491521501746_item	3748870	et	0	main
seltsile	doc_491521501746_item	3748871	et	0	main
editeerimisele	doc_491521501746_item	3748872	et	0	main
plaani	doc_491521501746_item	3748873	et	0	main
ta	doc_491521501746_item	3748874	et	0	main
kavatses	doc_491521501746_item	3748875	et	0	main
väljaanded	doc_491521501746_item	3748876	et	0	main
organiseerida	doc_491521501746_item	3748877	et	0	main
järgmiselt	doc_491521501746_item	3748878	et	0	main
1	doc_491521501746_item	3748879	et	0	main
laulud	doc_491521501746_item	3748880	et	0	main
2	doc_491521501746_item	3748881	et	0	main
vanasõnad	doc_491521501746_item	3748882	et	0	main
3	doc_491521501746_item	3748883	et	0	main
uskumused	doc_491521501746_item	3748884	et	0	main
4	doc_491521501746_item	3748885	et	0	main
rahvajutud	doc_491521501746_item	3748886	et	0	main
5	doc_491521501746_item	3748887	et	0	main
kombed	doc_491521501746_item	3748888	et	0	main
6	doc_491521501746_item	3748889	et	0	main
rahvaviisid	doc_491521501746_item	3748890	et	0	main
tegelikult	doc_491521501746_item	3748891	et	0	main
aga	doc_491521501746_item	3748892	et	0	main
avaldas	doc_491521501746_item	3748893	et	0	main
ta	doc_491521501746_item	3748894	et	0	main
trükise	doc_491521501746_item	3748895	et	0	main
topograafilise-tüpoloogilise	doc_491521501746_item	3748896	et	0	main
printsiibi	doc_491521501746_item	3748897	et	0	main
järgi	doc_491521501746_item	3748898	et	0	main
laugaste	doc_491521501746_item	3748899	et	0	main
1986	doc_491521501746_item	3748900	et	0	main
112	doc_491521501746_item	3748901	et	0	main
hurdaga	doc_491521501746_item	3748902	et	0	main
paralleelselt	doc_491521501746_item	3748903	et	0	main
asus	doc_491521501746_item	3748904	et	0	main
rahvaluulet	doc_491521501746_item	3748905	et	0	main
eelkõige	doc_491521501746_item	3748906	et	0	main
rahvajutte	doc_491521501746_item	3748907	et	0	main
koguma	doc_491521501746_item	3748908	et	0	main
ka	doc_491521501746_item	3748909	et	0	main
teine	doc_491521501746_item	3748910	et	0	main
pastor	doc_491521501746_item	3748911	et	0	main
matthias	doc_491521501746_item	3748912	et	0	main
johann	doc_491521501746_item	3748913	et	0	main
eisen	doc_491521501746_item	3748914	et	0	main
1857-1934	doc_491521501746_item	3748915	et	0	main
kes	doc_491521501746_item	3748916	et	0	main
neid	doc_491521501746_item	3748917	et	0	main
ka	doc_491521501746_item	3748918	et	0	main
kohe	doc_491521501746_item	3748919	et	0	main
publitseeris	doc_491521501746_item	3748920	et	0	main
rohkearvulistes	doc_491521501746_item	3748921	et	0	main
odavates	doc_491521501746_item	3748922	et	0	main
raamatutes	doc_491521501746_item	3748923	et	0	main
1885	doc_491521501746_item	3748924	et	0	main
aastal	doc_491521501746_item	3748925	et	0	main
käis	doc_491521501746_item	3748926	et	0	main
eestis	doc_491521501746_item	3748927	et	0	main
ehitisi	doc_491521501746_item	3748928	et	0	main
uurima	doc_491521501746_item	3748929	et	0	main
soome	doc_491521501746_item	3748930	et	0	main
rahvateaduse	doc_491521501746_item	3748931	et	0	main
teerajaja	doc_491521501746_item	3748932	et	0	main
axel	doc_491521501746_item	3748933	et	0	main
olai	doc_491521501746_item	3748934	et	0	main
heikel	doc_491521501746_item	3748935	et	0	main
1851-1924	doc_491521501746_item	3748936	et	0	main
tema	doc_491521501746_item	3748937	et	0	main
teosed	doc_491521501746_item	3748938	et	0	main
olid	doc_491521501746_item	3748939	et	0	main
esimesed	doc_491521501746_item	3748940	et	0	main
eestlaste	doc_491521501746_item	3748941	et	0	main
ainelist	doc_491521501746_item	3748942	et	0	main
kultuuri	doc_491521501746_item	3748943	et	0	main
käsitlevad	doc_491521501746_item	3748944	et	0	main
tõsiteaduslikud	doc_491521501746_item	3748945	et	0	main
uurimused	doc_491521501746_item	3748946	et	0	main
viires	doc_491521501746_item	3748947	et	0	main
tedre	doc_491521501746_item	3748948	et	0	main
1998	doc_491521501746_item	3748949	et	0	main
16	doc_491521501746_item	3748950	et	0	main
esimeseks	doc_491521501746_item	3748951	et	0	main
eriettevalmistusega	doc_491521501746_item	3748952	et	0	main
eesti	doc_491521501746_item	3748953	et	0	main
rahvaluuleteadlaseks	doc_491521501746_item	3748954	et	0	main
oli	doc_491521501746_item	3748955	et	0	main
oskar	doc_491521501746_item	3748956	et	0	main
kallas	doc_491521501746_item	3748957	et	0	main
1868-1946	doc_491521501746_item	3748958	et	0	main
tema	doc_491521501746_item	3748959	et	0	main
oli	doc_491521501746_item	3748960	et	0	main
ka	doc_491521501746_item	3748961	et	0	main
rajatud	doc_491521501746_item	3748962	et	0	main
1904	doc_491521501746_item	3748963	et	0	main
aastal	doc_491521501746_item	3748964	et	0	main
eesti	doc_491521501746_item	3748965	et	0	main
muuseumi	doc_491521501746_item	3748966	et	0	main
esimene	doc_491521501746_item	3748967	et	0	main
juhataja	doc_491521501746_item	3748968	et	0	main
tänu	doc_491521501746_item	3748969	et	0	main
eesti	doc_491521501746_item	3748970	et	0	main
iseseisvumisele	doc_491521501746_item	3748971	et	0	main
sai	doc_491521501746_item	3748972	et	0	main
ka	doc_491521501746_item	3748973	et	0	main
rahvaluuleteadus	doc_491521501746_item	3748974	et	0	main
institutsioonilised	doc_491521501746_item	3748975	et	0	main
alused	doc_491521501746_item	3748976	et	0	main
omariikluse	doc_491521501746_item	3748977	et	0	main
aega	doc_491521501746_item	3748978	et	0	main
võib	doc_491521501746_item	3748979	et	0	main
jagada	doc_491521501746_item	3748980	et	0	main
kaheks	doc_491521501746_item	3748981	et	0	main
esimesel	doc_491521501746_item	3748982	et	0	main
perioodil	doc_491521501746_item	3748983	et	0	main
oli	doc_491521501746_item	3748984	et	0	main
folkloristika	doc_491521501746_item	3748985	et	0	main
tartu	doc_491521501746_item	3748986	et	0	main
ülikooli	doc_491521501746_item	3748987	et	0	main
ja	doc_491521501746_item	3748988	et	0	main
teadusseltside	doc_491521501746_item	3748989	et	0	main
õlgadel	doc_491521501746_item	3748990	et	0	main
teisel	doc_491521501746_item	3748991	et	0	main
perioodil	doc_491521501746_item	3748992	et	0	main
juba	doc_491521501746_item	3748993	et	0	main
suuremas	doc_491521501746_item	3748994	et	0	main
osas	doc_491521501746_item	3748995	et	0	main
eesti	doc_491521501746_item	3748996	et	0	main
rahvaluule	doc_491521501746_item	3748997	et	0	main
arhiivil	doc_491521501746_item	3748998	et	0	main
kanda	doc_491521501746_item	3748999	et	0	main
13	doc_491521501746_item	3749000	et	0	main
eesti	doc_491521501746_item	3749001	et	0	main
rahvaluule	doc_491521501746_item	3749002	et	0	main
arhiivi	doc_491521501746_item	3749003	et	0	main
kogumistööst	doc_491521501746_item	3749004	et	0	main
avardus	doc_491521501746_item	3749005	et	0	main
ka	doc_491521501746_item	3749006	et	0	main
kodumistöö	doc_491521501746_item	3749007	et	0	main
eisen	doc_491521501746_item	3749008	et	0	main
jätkas	doc_491521501746_item	3749009	et	0	main
seda	doc_491521501746_item	3749010	et	0	main
korrespondentide	doc_491521501746_item	3749011	et	0	main
vahendusel	doc_491521501746_item	3749012	et	0	main
lisaks	doc_491521501746_item	3749013	et	0	main
hankis	doc_491521501746_item	3749014	et	0	main
ta	doc_491521501746_item	3749015	et	0	main
harudusministeeriumilt	doc_491521501746_item	3749016	et	0	main
toetust	doc_491521501746_item	3749017	et	0	main
ja	doc_491521501746_item	3749018	et	0	main
organiseeris	doc_491521501746_item	3749019	et	0	main
aastail	doc_491521501746_item	3749020	et	0	main
1921-27	doc_491521501746_item	3749021	et	0	main
rahvaluule	doc_491521501746_item	3749022	et	0	main
kogumist	doc_491521501746_item	3749023	et	0	main
stipendiaatide	doc_491521501746_item	3749024	et	0	main
abiga	doc_491521501746_item	3749025	et	0	main
1927	doc_491521501746_item	3749026	et	0	main
aastal	doc_491521501746_item	3749027	et	0	main
loodi	doc_491521501746_item	3749028	et	0	main
eesti	doc_491521501746_item	3749029	et	0	main
rahva	doc_491521501746_item	3749030	et	0	main
muuseumi	doc_491521501746_item	3749031	et	0	main
juurde	doc_491521501746_item	3749032	et	0	main
eesri	doc_491521501746_item	3749033	et	0	main
rahvaluule	doc_491521501746_item	3749034	et	0	main
arhiiv	doc_491521501746_item	3749035	et	0	main
era	doc_491521501746_item	3749036	et	0	main
sinna	doc_491521501746_item	3749037	et	0	main
koondati	doc_491521501746_item	3749038	et	0	main
kõik	doc_491521501746_item	3749039	et	0	main
aegade	doc_491521501746_item	3749040	et	0	main
jooksul	doc_491521501746_item	3749041	et	0	main
teaduslikkudesse	doc_491521501746_item	3749042	et	0	main
asutustesse	doc_491521501746_item	3749043	et	0	main
või	doc_491521501746_item	3749044	et	0	main
eravaldusse	doc_491521501746_item	3749045	et	0	main
koondunud	doc_491521501746_item	3749046	et	0	main
kogud	doc_491521501746_item	3749047	et	0	main
õpetatud	doc_491521501746_item	3749048	et	0	main
eestiseltsi	doc_491521501746_item	3749049	et	0	main
ja	doc_491521501746_item	3749050	et	0	main
eestimaa	doc_491521501746_item	3749051	et	0	main
kirjanduse	doc_491521501746_item	3749052	et	0	main
seltsi	doc_491521501746_item	3749053	et	0	main
kogud	doc_491521501746_item	3749054	et	0	main
eesti	doc_491521501746_item	3749055	et	0	main
üliõpilaste	doc_491521501746_item	3749056	et	0	main
seltsi	doc_491521501746_item	3749057	et	0	main
viisikogu	doc_491521501746_item	3749058	et	0	main
aga	doc_491521501746_item	3749059	et	0	main
ka	doc_491521501746_item	3749060	et	0	main
suurim	doc_491521501746_item	3749061	et	0	main
neist	doc_491521501746_item	3749062	et	0	main
hurda	doc_491521501746_item	3749063	et	0	main
kogu	doc_491521501746_item	3749064	et	0	main
koos	doc_491521501746_item	3749065	et	0	main
eesti	doc_491521501746_item	3749066	et	0	main
kirjameeste	doc_491521501746_item	3749067	et	0	main
seltsi	doc_491521501746_item	3749068	et	0	main
omaga	doc_491521501746_item	3749069	et	0	main
mille	doc_491521501746_item	3749070	et	0	main
hurda	doc_491521501746_item	3749071	et	0	main
surma	doc_491521501746_item	3749072	et	0	main
järel	doc_491521501746_item	3749073	et	0	main
1907	doc_491521501746_item	3749074	et	0	main
aastal	doc_491521501746_item	3749075	et	0	main
viis	doc_491521501746_item	3749076	et	0	main
kkrohn	doc_491521501746_item	3749077	et	0	main
helsingisse	doc_491521501746_item	3749078	et	0	main
sest	doc_491521501746_item	3749079	et	0	main
kusagil	doc_491521501746_item	3749080	et	0	main
mujal	doc_491521501746_item	3749081	et	0	main
ei	doc_491521501746_item	3749082	et	0	main
olnud	doc_491521501746_item	3749083	et	0	main
võimalust	doc_491521501746_item	3749084	et	0	main
selle	doc_491521501746_item	3749085	et	0	main
unikaalse	doc_491521501746_item	3749086	et	0	main
vaimuvara	doc_491521501746_item	3749087	et	0	main
säilitamiseks	doc_491521501746_item	3749088	et	0	main
soomes	doc_491521501746_item	3749089	et	0	main
kopeeriti	doc_491521501746_item	3749090	et	0	main
ja	doc_491521501746_item	3749091	et	0	main
katalogiseeriti	doc_491521501746_item	3749092	et	0	main
neid	doc_491521501746_item	3749093	et	0	main
materjale	doc_491521501746_item	3749094	et	0	main
nii	doc_491521501746_item	3749095	et	0	main
et	doc_491521501746_item	3749096	et	0	main
nad	doc_491521501746_item	3749097	et	0	main
seal	doc_491521501746_item	3749098	et	0	main
olid	doc_491521501746_item	3749099	et	0	main
kasutatavad	doc_491521501746_item	3749100	et	0	main
kuni	doc_491521501746_item	3749101	et	0	main
äratoomiseni	doc_491521501746_item	3749102	et	0	main
1927	doc_491521501746_item	3749103	et	0	main
aastal	doc_491521501746_item	3749104	et	0	main
m	doc_491521501746_item	3749105	et	0	main
j	doc_491521501746_item	3749106	et	0	main
eiseni	doc_491521501746_item	3749107	et	0	main
kogu	doc_491521501746_item	3749108	et	0	main
saabus	doc_491521501746_item	3749109	et	0	main
arhiivi	doc_491521501746_item	3749110	et	0	main
tartu	doc_491521501746_item	3749111	et	0	main
ülikooli	doc_491521501746_item	3749112	et	0	main
omandina	doc_491521501746_item	3749113	et	0	main
kusjuures	doc_491521501746_item	3749114	et	0	main
koguje	doc_491521501746_item	3749115	et	0	main
seda	doc_491521501746_item	3749116	et	0	main
kuni	doc_491521501746_item	3749117	et	0	main
surmani	doc_491521501746_item	3749118	et	0	main
1934	doc_491521501746_item	3749119	et	0	main
aastal	doc_491521501746_item	3749120	et	0	main
pidevalt	doc_491521501746_item	3749121	et	0	main
täiendas	doc_491521501746_item	3749122	et	0	main
arhiiv	doc_491521501746_item	3749123	et	0	main
alustas	doc_491521501746_item	3749124	et	0	main
1928	doc_491521501746_item	3749125	et	0	main
aastal	doc_491521501746_item	3749126	et	0	main
uut	doc_491521501746_item	3749127	et	0	main
omanimelist	doc_491521501746_item	3749128	et	0	main
kogu	doc_491521501746_item	3749129	et	0	main
laugaste	doc_491521501746_item	3749130	et	0	main
1986	doc_491521501746_item	3749131	et	0	main
118	doc_491521501746_item	3749132	et	0	main
era	doc_491521501746_item	3749133	et	0	main
juhatajaks	doc_491521501746_item	3749134	et	0	main
sai	doc_491521501746_item	3749135	et	0	main
oskar	doc_491521501746_item	3749136	et	0	main
loorits	doc_491521501746_item	3749137	et	0	main
1900-1961	doc_491521501746_item	3749138	et	0	main
ta	doc_491521501746_item	3749139	et	0	main
pani	doc_491521501746_item	3749140	et	0	main
tugeva	doc_491521501746_item	3749141	et	0	main
aluse	doc_491521501746_item	3749142	et	0	main
materjali	doc_491521501746_item	3749143	et	0	main
korrastamisele	doc_491521501746_item	3749144	et	0	main
ja	doc_491521501746_item	3749145	et	0	main
sihipärasele	doc_491521501746_item	3749146	et	0	main
järelkogumisele	doc_491521501746_item	3749147	et	0	main
järelkorjandusel	doc_491521501746_item	3749148	et	0	main
keskenduti	doc_491521501746_item	3749149	et	0	main
neile	doc_491521501746_item	3749150	et	0	main
kihelkondadele	doc_491521501746_item	3749151	et	0	main
ka	doc_491521501746_item	3749152	et	0	main
nissi	doc_491521501746_item	3749153	et	0	main
kihelkonda	doc_491521501746_item	3749154	et	0	main
oli	doc_491521501746_item	3749155	et	0	main
uuritud	doc_491521501746_item	3749156	et	0	main
sellel	doc_491521501746_item	3749157	et	0	main
ajal	doc_491521501746_item	3749158	et	0	main
kust	doc_491521501746_item	3749159	et	0	main
oli	doc_491521501746_item	3749160	et	0	main
seni	doc_491521501746_item	3749161	et	0	main
vähe	doc_491521501746_item	3749162	et	0	main
kirjapanekuid	doc_491521501746_item	3749163	et	0	main
ja	doc_491521501746_item	3749164	et	0	main
küsimustele	doc_491521501746_item	3749165	et	0	main
mille	doc_491521501746_item	3749166	et	0	main
kohta	doc_491521501746_item	3749167	et	0	main
nappis	doc_491521501746_item	3749168	et	0	main
andmeid	doc_491521501746_item	3749169	et	0	main
kujunesid	doc_491521501746_item	3749170	et	0	main
omad	doc_491521501746_item	3749171	et	0	main
kaastöölised	doc_491521501746_item	3749172	et	0	main
kaastöölistega	doc_491521501746_item	3749173	et	0	main
suhtlemiseks	doc_491521501746_item	3749174	et	0	main
hakati	doc_491521501746_item	3749175	et	0	main
1936	doc_491521501746_item	3749176	et	0	main
aastal	doc_491521501746_item	3749177	et	0	main
avaldama	doc_491521501746_item	3749178	et	0	main
infobülletääni	doc_491521501746_item	3749179	et	0	main
rahvapärimuste	doc_491521501746_item	3749180	et	0	main
selgitaja	doc_491521501746_item	3749181	et	0	main
mis	doc_491521501746_item	3749182	et	0	main
sisaldas	doc_491521501746_item	3749183	et	0	main
küsitluskavu	doc_491521501746_item	3749184	et	0	main
ülevaateid	doc_491521501746_item	3749185	et	0	main
era	doc_491521501746_item	3749186	et	0	main
tööst	doc_491521501746_item	3749187	et	0	main
kogujate	doc_491521501746_item	3749188	et	0	main
juubeli-	doc_491521501746_item	3749189	et	0	main
ja	doc_491521501746_item	3749190	et	0	main
mälestuskirjutisi	doc_491521501746_item	3749191	et	0	main
jm	doc_491521501746_item	3749192	et	0	main
era	doc_491521501746_item	3749193	et	0	main
töötajatest	doc_491521501746_item	3749194	et	0	main
said	doc_491521501746_item	3749195	et	0	main
tuntuks	doc_491521501746_item	3749196	et	0	main
richard	doc_491521501746_item	3749197	et	0	main
viidalepp	doc_491521501746_item	3749198	et	0	main
1904-1986	doc_491521501746_item	3749199	et	0	main
kelle	doc_491521501746_item	3749200	et	0	main
õlul	doc_491521501746_item	3749201	et	0	main
oli	doc_491521501746_item	3749202	et	0	main
peamiselt	doc_491521501746_item	3749203	et	0	main
kogumine	doc_491521501746_item	3749204	et	0	main
tedre	doc_491521501746_item	3749205	et	0	main
viires	doc_491521501746_item	3749206	et	0	main
1998	doc_491521501746_item	3749207	et	0	main
25	doc_491521501746_item	3749208	et	0	main
era	doc_491521501746_item	3749209	et	0	main
alguspäevil	doc_491521501746_item	3749210	et	0	main
suhtuti	doc_491521501746_item	3749211	et	0	main
koolidesse	doc_491521501746_item	3749212	et	0	main
kui	doc_491521501746_item	3749213	et	0	main
võimalikesse	doc_491521501746_item	3749214	et	0	main
rahvaluule	doc_491521501746_item	3749215	et	0	main
kogumiskanalitesse	doc_491521501746_item	3749216	et	0	main
kaunis	doc_491521501746_item	3749217	et	0	main
ettevaatlikult	doc_491521501746_item	3749218	et	0	main
mõne	doc_491521501746_item	3749219	et	0	main
aasta	doc_491521501746_item	3749220	et	0	main
pärast	doc_491521501746_item	3749221	et	0	main
aga	doc_491521501746_item	3749222	et	0	main
jõuti	doc_491521501746_item	3749223	et	0	main
veedumuseni	doc_491521501746_item	3749224	et	0	main
et	doc_491521501746_item	3749225	et	0	main
koolide	doc_491521501746_item	3749226	et	0	main
abi	doc_491521501746_item	3749227	et	0	main
on	doc_491521501746_item	3749228	et	0	main
vajalik	doc_491521501746_item	3749229	et	0	main
esialgu	doc_491521501746_item	3749230	et	0	main
küll	doc_491521501746_item	3749231	et	0	main
laste	doc_491521501746_item	3749232	et	0	main
repertuaari	doc_491521501746_item	3749233	et	0	main
osas	doc_491521501746_item	3749234	et	0	main
olevate	doc_491521501746_item	3749235	et	0	main
tühimike	doc_491521501746_item	3749236	et	0	main
täitmisel	doc_491521501746_item	3749237	et	0	main
esimeheks	doc_491521501746_item	3749238	et	0	main
proovikiviks	doc_491521501746_item	3749239	et	0	main
koolidele	doc_491521501746_item	3749240	et	0	main
sai	doc_491521501746_item	3749241	et	0	main
19311932	doc_491521501746_item	3749242	et	0	main
õppeaastal	doc_491521501746_item	3749243	et	0	main
etnograafidega	doc_491521501746_item	3749244	et	0	main
kahasse	doc_491521501746_item	3749245	et	0	main
korraldatud	doc_491521501746_item	3749246	et	0	main
ringküsitlus	doc_491521501746_item	3749247	et	0	main
korrespondentidele	doc_491521501746_item	3749248	et	0	main
ja	doc_491521501746_item	3749249	et	0	main
maa-algkoolidele	doc_491521501746_item	3749250	et	0	main
teemaks	doc_491521501746_item	3749251	et	0	main
lastehirmutised	doc_491521501746_item	3749252	et	0	main
era	doc_491521501746_item	3749253	et	0	main
kõige	doc_491521501746_item	3749254	et	0	main
suuremaks	doc_491521501746_item	3749255	et	0	main
aktsiooniks	doc_491521501746_item	3749256	et	0	main
kujunes	doc_491521501746_item	3749257	et	0	main
aga	doc_491521501746_item	3749258	et	0	main
19381939	doc_491521501746_item	3749259	et	0	main
õppeaastal	doc_491521501746_item	3749260	et	0	main
kooliõpilaste	doc_491521501746_item	3749261	et	0	main
seas	doc_491521501746_item	3749262	et	0	main
läbi	doc_491521501746_item	3749263	et	0	main
viidud	doc_491521501746_item	3749264	et	0	main
kohamuistendite	doc_491521501746_item	3749265	et	0	main
võistluskogumine	doc_491521501746_item	3749266	et	0	main
mille	doc_491521501746_item	3749267	et	0	main
tulemusei	doc_491521501746_item	3749268	et	0	main
saadi	doc_491521501746_item	3749269	et	0	main
37	doc_491521501746_item	3749270	et	0	main
köidet	doc_491521501746_item	3749271	et	0	main
rahvapärimust	doc_491521501746_item	3749272	et	0	main
kogumisvõistluse	doc_491521501746_item	3749273	et	0	main
pedagoogiliseks	doc_491521501746_item	3749274	et	0	main
eesmärgiks	doc_491521501746_item	3749275	et	0	main
oli	doc_491521501746_item	3749276	et	0	main
suunata	doc_491521501746_item	3749277	et	0	main
ja	doc_491521501746_item	3749278	et	0	main
ergutada	doc_491521501746_item	3749279	et	0	main
oma	doc_491521501746_item	3749280	et	0	main
kodukohta	doc_491521501746_item	3749281	et	0	main
ja	doc_491521501746_item	3749282	et	0	main
selle	doc_491521501746_item	3749283	et	0	main
ajaloo	doc_491521501746_item	3749284	et	0	main
tundmaõppimisel	doc_491521501746_item	3749285	et	0	main
ning	doc_491521501746_item	3749286	et	0	main
arendada	doc_491521501746_item	3749287	et	0	main
samas	doc_491521501746_item	3749288	et	0	main
õpilaste	doc_491521501746_item	3749289	et	0	main
jälgimisvõimet	doc_491521501746_item	3749290	et	0	main
ja	doc_491521501746_item	3749291	et	0	main
väljendamisoskust	doc_491521501746_item	3749292	et	0	main
üles	doc_491521501746_item	3749293	et	0	main
tuli	doc_491521501746_item	3749294	et	0	main
kirjutada	doc_491521501746_item	3749295	et	0	main
rahvapärimusi	doc_491521501746_item	3749296	et	0	main
ja	doc_491521501746_item	3749297	et	0	main
mälestusi	doc_491521501746_item	3749298	et	0	main
ühenduses	doc_491521501746_item	3749299	et	0	main
ümbruskonna	doc_491521501746_item	3749300	et	0	main
kohtadega	doc_491521501746_item	3749301	et	0	main
rahvapärimused	doc_491521501746_item	3749302	et	0	main
võivad	doc_491521501746_item	3749303	et	0	main
olla	doc_491521501746_item	3749304	et	0	main
nii	doc_491521501746_item	3749305	et	0	main
rahvaluuleliselt	doc_491521501746_item	3749306	et	0	main
kui	doc_491521501746_item	3749307	et	0	main
ka	doc_491521501746_item	3749308	et	0	main
ajaloolist	doc_491521501746_item	3749309	et	0	main
laadi	doc_491521501746_item	3749310	et	0	main
kindel	doc_491521501746_item	3749311	et	0	main
2002	doc_491521501746_item	3749312	et	0	main
100-101	doc_491521501746_item	3749313	et	0	main
rviidalepp	doc_491521501746_item	3749314	et	0	main
arvas	doc_491521501746_item	3749315	et	0	main
et	doc_491521501746_item	3749316	et	0	main
kohamuistendite	doc_491521501746_item	3749317	et	0	main
korjamine	doc_491521501746_item	3749318	et	0	main
peaks	doc_491521501746_item	3749319	et	0	main
igaühele	doc_491521501746_item	3749320	et	0	main
jõukohane	doc_491521501746_item	3749321	et	0	main
olema	doc_491521501746_item	3749322	et	0	main
võrreldes	doc_491521501746_item	3749323	et	0	main
mõne	doc_491521501746_item	3749324	et	0	main
muu	doc_491521501746_item	3749325	et	0	main
rahvaluuleliigiga	doc_491521501746_item	3749326	et	0	main
on	doc_491521501746_item	3749327	et	0	main
sellel	doc_491521501746_item	3749328	et	0	main
teemal	doc_491521501746_item	3749329	et	0	main
hoopis	doc_491521501746_item	3749330	et	0	main
lihtsam	doc_491521501746_item	3749331	et	0	main
jutustajaid	doc_491521501746_item	3749332	et	0	main
rääkima	doc_491521501746_item	3749333	et	0	main
panna	doc_491521501746_item	3749334	et	0	main
lugude	doc_491521501746_item	3749335	et	0	main
ülesmärkimine	doc_491521501746_item	3749336	et	0	main
pole	doc_491521501746_item	3749337	et	0	main
ka	doc_491521501746_item	3749338	et	0	main
kuigi	doc_491521501746_item	3749339	et	0	main
keeruline	doc_491521501746_item	3749340	et	0	main
sest	doc_491521501746_item	3749341	et	0	main
kohtadest	doc_491521501746_item	3749342	et	0	main
kõnelevad	doc_491521501746_item	3749343	et	0	main
jutud	doc_491521501746_item	3749344	et	0	main
on	doc_491521501746_item	3749345	et	0	main
sageli	doc_491521501746_item	3749346	et	0	main
lühikesed	doc_491521501746_item	3749347	et	0	main
ning	doc_491521501746_item	3749348	et	0	main
lihtsa	doc_491521501746_item	3749349	et	0	main
sündmustikuga	doc_491521501746_item	3749350	et	0	main
viidalepp	doc_491521501746_item	3749351	et	0	main
1938	doc_491521501746_item	3749352	et	0	main
437-440	doc_491521501746_item	3749353	et	0	main
hiljem	doc_491521501746_item	3749354	et	0	main
1940	doc_491521501746_item	3749355	et	0	main
aastal	doc_491521501746_item	3749356	et	0	main
ilmunud	doc_491521501746_item	3749357	et	0	main
raamatus	doc_491521501746_item	3749358	et	0	main
tööjuhiseid	doc_491521501746_item	3749359	et	0	main
rahvaluulekogujaile	doc_491521501746_item	3749360	et	0	main
seletab	doc_491521501746_item	3749361	et	0	main
viidalepp	doc_491521501746_item	3749362	et	0	main
väga	doc_491521501746_item	3749363	et	0	main
põhjalikult	doc_491521501746_item	3749364	et	0	main
kuidas	doc_491521501746_item	3749365	et	0	main
tuleb	doc_491521501746_item	3749366	et	0	main
rahvajutte	doc_491521501746_item	3749367	et	0	main
üles	doc_491521501746_item	3749368	et	0	main
kirjutama	doc_491521501746_item	3749369	et	0	main
erilist	doc_491521501746_item	3749370	et	0	main
tähelepanu	doc_491521501746_item	3749371	et	0	main
pöörab	doc_491521501746_item	3749372	et	0	main
ta	doc_491521501746_item	3749373	et	0	main
keelelisele	doc_491521501746_item	3749374	et	0	main
küljele	doc_491521501746_item	3749375	et	0	main
sest	doc_491521501746_item	3749376	et	0	main
rahvaluule-tekstide	doc_491521501746_item	3749377	et	0	main
murdekeel	doc_491521501746_item	3749378	et	0	main
peab	doc_491521501746_item	3749379	et	0	main
olema	doc_491521501746_item	3749380	et	0	main
loomulik	doc_491521501746_item	3749381	et	0	main
nagu	doc_491521501746_item	3749382	et	0	main
ta	doc_491521501746_item	3749383	et	0	main
tegelikult	doc_491521501746_item	3749384	et	0	main
esineb	doc_491521501746_item	3749385	et	0	main
vahel	doc_491521501746_item	3749386	et	0	main
täis	doc_491521501746_item	3749387	et	0	main
ebajärjekindlusi	doc_491521501746_item	3749388	et	0	main
mõjustatud	doc_491521501746_item	3749389	et	0	main
ühis-	doc_491521501746_item	3749390	et	0	main
ja	doc_491521501746_item	3749391	et	0	main
kirjakeelest	doc_491521501746_item	3749392	et	0	main
jne	doc_491521501746_item	3749393	et	0	main
korjaja	doc_491521501746_item	3749394	et	0	main
ei	doc_491521501746_item	3749395	et	0	main
tohi	doc_491521501746_item	3749396	et	0	main
jutustaja	doc_491521501746_item	3749397	et	0	main
keelt	doc_491521501746_item	3749398	et	0	main
parandama	doc_491521501746_item	3749399	et	0	main
ega	doc_491521501746_item	3749400	et	0	main
ümber	doc_491521501746_item	3749401	et	0	main
tegema	doc_491521501746_item	3749402	et	0	main
samas	doc_491521501746_item	3749403	et	0	main
jutustaja	doc_491521501746_item	3749404	et	0	main
keelt	doc_491521501746_item	3749405	et	0	main
ei	doc_491521501746_item	3749406	et	0	main
tule	doc_491521501746_item	3749407	et	0	main
üleskirjutistes	doc_491521501746_item	3749408	et	0	main
sihilikult	doc_491521501746_item	3749409	et	0	main
teha	doc_491521501746_item	3749410	et	0	main
murdelisemaks	doc_491521501746_item	3749411	et	0	main
kui	doc_491521501746_item	3749412	et	0	main
ta	doc_491521501746_item	3749413	et	0	main
tõesti	doc_491521501746_item	3749414	et	0	main
esineb	doc_491521501746_item	3749415	et	0	main
kindlasti	doc_491521501746_item	3749416	et	0	main
tuleb	doc_491521501746_item	3749417	et	0	main
meeles	doc_491521501746_item	3749418	et	0	main
pidada	doc_491521501746_item	3749419	et	0	main
ka	doc_491521501746_item	3749420	et	0	main
seda	doc_491521501746_item	3749421	et	0	main
et	doc_491521501746_item	3749422	et	0	main
materjalis	doc_491521501746_item	3749423	et	0	main
esinevad	doc_491521501746_item	3749424	et	0	main
nimetused	doc_491521501746_item	3749425	et	0	main
terminoloogia	doc_491521501746_item	3749426	et	0	main
esitatakse	doc_491521501746_item	3749427	et	0	main
tingimata	doc_491521501746_item	3749428	et	0	main
nii	doc_491521501746_item	3749429	et	0	main
nagu	doc_491521501746_item	3749430	et	0	main
nad	doc_491521501746_item	3749431	et	0	main
kõlavad	doc_491521501746_item	3749432	et	0	main
kohapealsete	doc_491521501746_item	3749433	et	0	main
vanemate	doc_491521501746_item	3749434	et	0	main
inimeste	doc_491521501746_item	3749435	et	0	main
keeles	doc_491521501746_item	3749436	et	0	main
mitmesuguseid	doc_491521501746_item	3749437	et	0	main
kohalugusid	doc_491521501746_item	3749438	et	0	main
mis	doc_491521501746_item	3749439	et	0	main
võivad	doc_491521501746_item	3749440	et	0	main
jutustajale	doc_491521501746_item	3749441	et	0	main
või	doc_491521501746_item	3749442	et	0	main
kirjapanijale	doc_491521501746_item	3749443	et	0	main
olla	doc_491521501746_item	3749444	et	0	main
hästi	doc_491521501746_item	3749445	et	0	main
tuttavad	doc_491521501746_item	3749446	et	0	main
leidub	doc_491521501746_item	3749447	et	0	main
senises	doc_491521501746_item	3749448	et	0	main
üleskirjutistest	doc_491521501746_item	3749449	et	0	main
väga	doc_491521501746_item	3749450	et	0	main
lühidas	doc_491521501746_item	3749451	et	0	main
sõnastuses	doc_491521501746_item	3749452	et	0	main
enamasti	doc_491521501746_item	3749453	et	0	main
öeldakse	doc_491521501746_item	3749454	et	0	main
ühe	doc_491521501746_item	3749455	et	0	main
lausega	doc_491521501746_item	3749456	et	0	main
et	doc_491521501746_item	3749457	et	0	main
seal	doc_491521501746_item	3749458	et	0	main
või	doc_491521501746_item	3749459	et	0	main
teal	doc_491521501746_item	3749460	et	0	main
olevat	doc_491521501746_item	3749461	et	0	main
näit	doc_491521501746_item	3749462	et	0	main
vana	doc_491521501746_item	3749463	et	0	main
sõjatee	doc_491521501746_item	3749464	et	0	main
lahingukoht	doc_491521501746_item	3749465	et	0	main
ohvrikivi	doc_491521501746_item	3749466	et	0	main
matmispaik	doc_491521501746_item	3749467	et	0	main
või	doc_491521501746_item	3749468	et	0	main
muud	doc_491521501746_item	3749469	et	0	main
oluliseks	doc_491521501746_item	3749470	et	0	main
tuleb	doc_491521501746_item	3749471	et	0	main
pidada	doc_491521501746_item	3749472	et	0	main
märget	doc_491521501746_item	3749473	et	0	main
soovitusega	doc_491521501746_item	3749474	et	0	main
üles	doc_491521501746_item	3749475	et	0	main
kirjutada	doc_491521501746_item	3749476	et	0	main
loos	doc_491521501746_item	3749477	et	0	main
esineva	doc_491521501746_item	3749478	et	0	main
koha	doc_491521501746_item	3749479	et	0	main
andmed	doc_491521501746_item	3749480	et	0	main
võimalikult	doc_491521501746_item	3749481	et	0	main
täpselt	doc_491521501746_item	3749482	et	0	main
et	doc_491521501746_item	3749483	et	0	main
oleks	doc_491521501746_item	3749484	et	0	main
selge	doc_491521501746_item	3749485	et	0	main
kus	doc_491521501746_item	3749486	et	0	main
konkreetne	doc_491521501746_item	3749487	et	0	main
koht	doc_491521501746_item	3749488	et	0	main
asub	doc_491521501746_item	3749489	et	0	main
kohamuistenditele	doc_491521501746_item	3749490	et	0	main
on	doc_491521501746_item	3749491	et	0	main
väga	doc_491521501746_item	3749492	et	0	main
soovitav	doc_491521501746_item	3749493	et	0	main
lisada	doc_491521501746_item	3749494	et	0	main
väike	doc_491521501746_item	3749495	et	0	main
omajoonistatud	doc_491521501746_item	3749496	et	0	main
kaart	doc_491521501746_item	3749497	et	0	main
viidalepp	doc_491521501746_item	3749498	et	0	main
1940	doc_491521501746_item	3749499	et	0	main
7-8	doc_491521501746_item	3749500	et	0	main
59	doc_491521501746_item	3749501	et	0	main
ka	doc_491521501746_item	3749502	et	0	main
era	doc_491521501746_item	3749503	et	0	main
poolt	doc_491521501746_item	3749504	et	0	main
trükiti	doc_491521501746_item	3749505	et	0	main
kogumisaktsioonideks	doc_491521501746_item	3749506	et	0	main
kahesugused	doc_491521501746_item	3749507	et	0	main
juhendid	doc_491521501746_item	3749508	et	0	main
küsitluslehed	doc_491521501746_item	3749509	et	0	main
õpilastele	doc_491521501746_item	3749510	et	0	main
ning	doc_491521501746_item	3749511	et	0	main
kaaskirjad-juhendid	doc_491521501746_item	3749512	et	0	main
õpetajatele	doc_491521501746_item	3749513	et	0	main
küsitlusleht	doc_491521501746_item	3749514	et	0	main
ise	doc_491521501746_item	3749515	et	0	main
on	doc_491521501746_item	3749516	et	0	main
selge	doc_491521501746_item	3749517	et	0	main
ja	doc_491521501746_item	3749518	et	0	main
konkreetne	doc_491521501746_item	3749519	et	0	main
koostatud	doc_491521501746_item	3749520	et	0	main
pigem	doc_491521501746_item	3749521	et	0	main
temaatilisena	doc_491521501746_item	3749522	et	0	main
ja	doc_491521501746_item	3749523	et	0	main
objektikesksena	doc_491521501746_item	3749524	et	0	main
mitte	doc_491521501746_item	3749525	et	0	main
tüübikesksest	doc_491521501746_item	3749526	et	0	main
rahvajuttudest	doc_491521501746_item	3749527	et	0	main
lähtuvalt	doc_491521501746_item	3749528	et	0	main
eraldi	doc_491521501746_item	3749529	et	0	main
teemadena	doc_491521501746_item	3749530	et	0	main
on	doc_491521501746_item	3749531	et	0	main
väla	doc_491521501746_item	3749532	et	0	main
toodud	doc_491521501746_item	3749533	et	0	main
looduslikiu	doc_491521501746_item	3749534	et	0	main
objektid	doc_491521501746_item	3749535	et	0	main
ja	doc_491521501746_item	3749536	et	0	main
paigad	doc_491521501746_item	3749537	et	0	main
nagu	doc_491521501746_item	3749538	et	0	main
kivid	doc_491521501746_item	3749539	et	0	main
mäed	doc_491521501746_item	3749540	et	0	main
ja	doc_491521501746_item	3749541	et	0	main
orud	doc_491521501746_item	3749542	et	0	main
ning	doc_491521501746_item	3749543	et	0	main
veekogud	doc_491521501746_item	3749544	et	0	main
puud	doc_491521501746_item	3749545	et	0	main
ja	doc_491521501746_item	3749546	et	0	main
metsad	doc_491521501746_item	3749547	et	0	main
küsitud	doc_491521501746_item	3749548	et	0	main
on	doc_491521501746_item	3749549	et	0	main
ka	doc_491521501746_item	3749550	et	0	main
ajaloolise	doc_491521501746_item	3749551	et	0	main
pärimuse	doc_491521501746_item	3749552	et	0	main
asustusajaloo	doc_491521501746_item	3749553	et	0	main
sõdade	doc_491521501746_item	3749554	et	0	main
nälja	doc_491521501746_item	3749555	et	0	main
ning	doc_491521501746_item	3749556	et	0	main
katku	doc_491521501746_item	3749557	et	0	main
kohta	doc_491521501746_item	3749558	et	0	main
kindel	doc_491521501746_item	3749559	et	0	main
2002	doc_491521501746_item	3749560	et	0	main
103	doc_491521501746_item	3749561	et	0	main
laekunud	doc_491521501746_item	3749562	et	0	main
materjali	doc_491521501746_item	3749563	et	0	main
põhjal	doc_491521501746_item	3749564	et	0	main
koostati	doc_491521501746_item	3749565	et	0	main
ja	doc_491521501746_item	3749566	et	0	main
trükiti	doc_491521501746_item	3749567	et	0	main
veel	doc_491521501746_item	3749568	et	0	main
samal	doc_491521501746_item	3749569	et	0	main
aastal	doc_491521501746_item	3749570	et	0	main
õhuke	doc_491521501746_item	3749571	et	0	main
muistendivalimik	doc_491521501746_item	3749572	et	0	main
mõeldud	doc_491521501746_item	3749573	et	0	main
eeskätt	doc_491521501746_item	3749574	et	0	main
tänutäheks	doc_491521501746_item	3749575	et	0	main
kogujaile	doc_491521501746_item	3749576	et	0	main
raamatukeses	doc_491521501746_item	3749577	et	0	main
on	doc_491521501746_item	3749578	et	0	main
püütud	doc_491521501746_item	3749579	et	0	main
tuua	doc_491521501746_item	3749580	et	0	main
paljudest	doc_491521501746_item	3749581	et	0	main
kihelkondadest	doc_491521501746_item	3749582	et	0	main
näiteid	doc_491521501746_item	3749583	et	0	main
mitmesugustest	doc_491521501746_item	3749584	et	0	main
jutudest	doc_491521501746_item	3749585	et	0	main
võistluse	doc_491521501746_item	3749586	et	0	main
aruandes	doc_491521501746_item	3749587	et	0	main
nendib	doc_491521501746_item	3749588	et	0	main
viidalepp	doc_491521501746_item	3749589	et	0	main
et	doc_491521501746_item	3749590	et	0	main
see	doc_491521501746_item	3749591	et	0	main
kogumisaktsioon	doc_491521501746_item	3749592	et	0	main
pole	doc_491521501746_item	3749593	et	0	main
mitte	doc_491521501746_item	3749594	et	0	main
oma	doc_491521501746_item	3749595	et	0	main
mahu	doc_491521501746_item	3749596	et	0	main
poolest	doc_491521501746_item	3749597	et	0	main
täiendanud	doc_491521501746_item	3749598	et	0	main
era	doc_491521501746_item	3749599	et	0	main
kogusid	doc_491521501746_item	3749600	et	0	main
vaid	doc_491521501746_item	3749601	et	0	main
neis	doc_491521501746_item	3749602	et	0	main
võistlustöödes	doc_491521501746_item	3749603	et	0	main
leidub	doc_491521501746_item	3749604	et	0	main
ka	doc_491521501746_item	3749605	et	0	main
palju	doc_491521501746_item	3749606	et	0	main
uusi	doc_491521501746_item	3749607	et	0	main
andmeid	doc_491521501746_item	3749608	et	0	main
ja	doc_491521501746_item	3749609	et	0	main
kirjeldusi	doc_491521501746_item	3749610	et	0	main
eestimaa	doc_491521501746_item	3749611	et	0	main
mitmesugustest	doc_491521501746_item	3749612	et	0	main
paikadest	doc_491521501746_item	3749613	et	0	main
vanadest	doc_491521501746_item	3749614	et	0	main
ohvrikohtadest	doc_491521501746_item	3749615	et	0	main
kalmetest	doc_491521501746_item	3749616	et	0	main
jne	doc_491521501746_item	3749617	et	0	main
kindel	doc_491521501746_item	3749618	et	0	main
2002	doc_491521501746_item	3749619	et	0	main
108	doc_491521501746_item	3749620	et	0	main
tuntuks	doc_491521501746_item	3749621	et	0	main
era	doc_491521501746_item	3749622	et	0	main
töötajaks	doc_491521501746_item	3749623	et	0	main
oli	doc_491521501746_item	3749624	et	0	main
ka	doc_491521501746_item	3749625	et	0	main
rudolf	doc_491521501746_item	3749626	et	0	main
põldmäe	doc_491521501746_item	3749627	et	0	main
1908-1988	doc_491521501746_item	3749628	et	0	main
osales	doc_491521501746_item	3749629	et	0	main
ekspeditsioonis	doc_491521501746_item	3749630	et	0	main
mille	doc_491521501746_item	3749631	et	0	main
käigus	doc_491521501746_item	3749632	et	0	main
sai	doc_491521501746_item	3749633	et	0	main
korjatud	doc_491521501746_item	3749634	et	0	main
ka	doc_491521501746_item	3749635	et	0	main
suurem	doc_491521501746_item	3749636	et	0	main
osa	doc_491521501746_item	3749637	et	0	main
nissi	doc_491521501746_item	3749638	et	0	main
kihelkonna	doc_491521501746_item	3749639	et	0	main
kohapärimustest	doc_491521501746_item	3749640	et	0	main
2	doc_491521501746_item	3749641	et	0	main
peatükk	doc_491521501746_item	3749642	et	0	main
muistend	doc_491521501746_item	3749643	et	0	main
muistend	doc_491521501746_item	3749644	et	0	main
moodustab	doc_491521501746_item	3749645	et	0	main
olulise	doc_491521501746_item	3749646	et	0	main
rahvajutuliigi	doc_491521501746_item	3749647	et	0	main
muistend	doc_491521501746_item	3749648	et	0	main
omab	doc_491521501746_item	3749649	et	0	main
mitmeid	doc_491521501746_item	3749650	et	0	main
tunnuseid	doc_491521501746_item	3749651	et	0	main
mille	doc_491521501746_item	3749652	et	0	main
poolest	doc_491521501746_item	3749653	et	0	main
erineb	doc_491521501746_item	3749654	et	0	main
ta	doc_491521501746_item	3749655	et	0	main
muinasjutust	doc_491521501746_item	3749656	et	0	main
muinasjutt	doc_491521501746_item	3749657	et	0	main
on	doc_491521501746_item	3749658	et	0	main
rahvuvahelile	doc_491521501746_item	3749659	et	0	main
muistendis	doc_491521501746_item	3749660	et	0	main
on	doc_491521501746_item	3749661	et	0	main
suur	doc_491521501746_item	3749662	et	0	main
osa	doc_491521501746_item	3749663	et	0	main
aineid	doc_491521501746_item	3749664	et	0	main
kohalikku	doc_491521501746_item	3749665	et	0	main
rahvuslikku	doc_491521501746_item	3749666	et	0	main
algupära	doc_491521501746_item	3749667	et	0	main
ta	doc_491521501746_item	3749668	et	0	main
on	doc_491521501746_item	3749669	et	0	main
tavaliselt	doc_491521501746_item	3749670	et	0	main
seotud	doc_491521501746_item	3749671	et	0	main
kas	doc_491521501746_item	3749672	et	0	main
koha	doc_491521501746_item	3749673	et	0	main
aja	doc_491521501746_item	3749674	et	0	main
eseme	doc_491521501746_item	3749675	et	0	main
või	doc_491521501746_item	3749676	et	0	main
isikuga	doc_491521501746_item	3749677	et	0	main
muistend	doc_491521501746_item	3749678	et	0	main
on	doc_491521501746_item	3749679	et	0	main
primitiivse	doc_491521501746_item	3749680	et	0	main
rahva	doc_491521501746_item	3749681	et	0	main
teadus	doc_491521501746_item	3749682	et	0	main
katk	doc_491521501746_item	3749683	et	0	main
võid	doc_491521501746_item	3749684	et	0	main
liikuda	doc_491521501746_item	3749685	et	0	main
mingi	doc_491521501746_item	3749686	et	0	main
olendi	doc_491521501746_item	3749687	et	0	main
või	doc_491521501746_item	3749688	et	0	main
eseme	doc_491521501746_item	3749689	et	0	main
kujul	doc_491521501746_item	3749690	et	0	main
hiid	doc_491521501746_item	3749691	et	0	main
püstitas	doc_491521501746_item	3749692	et	0	main
mingi	doc_491521501746_item	3749693	et	0	main
suure	doc_491521501746_item	3749694	et	0	main
praegu	doc_491521501746_item	3749695	et	0	main
veel	doc_491521501746_item	3749696	et	0	main
olemasoleva	doc_491521501746_item	3749697	et	0	main
ehitise	doc_491521501746_item	3749698	et	0	main
suured	doc_491521501746_item	3749699	et	0	main
rändrahnud	doc_491521501746_item	3749700	et	0	main
on	doc_491521501746_item	3749701	et	0	main
hiidude	doc_491521501746_item	3749702	et	0	main
viskamise	doc_491521501746_item	3749703	et	0	main
tulemusena	doc_491521501746_item	3749704	et	0	main
sattunud	doc_491521501746_item	3749705	et	0	main
näidatud	doc_491521501746_item	3749706	et	0	main
paika	doc_491521501746_item	3749707	et	0	main
jne	doc_491521501746_item	3749708	et	0	main
rahvajutt	doc_491521501746_item	3749709	et	0	main
on	doc_491521501746_item	3749710	et	0	main
ainult	doc_491521501746_item	3749711	et	0	main
nende	doc_491521501746_item	3749712	et	0	main
olemise	doc_491521501746_item	3749713	et	0	main
või	doc_491521501746_item	3749714	et	0	main
asukoha	doc_491521501746_item	3749715	et	0	main
saamise	doc_491521501746_item	3749716	et	0	main
seletuseks	doc_491521501746_item	3749717	et	0	main
laugaste	doc_491521501746_item	3749718	et	0	main
1986	doc_491521501746_item	3749719	et	0	main
268	doc_491521501746_item	3749720	et	0	main
muistendi	doc_491521501746_item	3749721	et	0	main
sündmustik	doc_491521501746_item	3749722	et	0	main
on	doc_491521501746_item	3749723	et	0	main
muinasjutu	doc_491521501746_item	3749724	et	0	main
omast	doc_491521501746_item	3749725	et	0	main
lühem	doc_491521501746_item	3749726	et	0	main
staatilisem	doc_491521501746_item	3749727	et	0	main
lihtsam	doc_491521501746_item	3749728	et	0	main
aga	doc_491521501746_item	3749729	et	0	main
ka	doc_491521501746_item	3749730	et	0	main
asjalikum	doc_491521501746_item	3749731	et	0	main
ühe	doc_491521501746_item	3749732	et	0	main
tegelasega	doc_491521501746_item	3749733	et	0	main
võib	doc_491521501746_item	3749734	et	0	main
vahel	doc_491521501746_item	3749735	et	0	main
seotud	doc_491521501746_item	3749736	et	0	main
olla	doc_491521501746_item	3749737	et	0	main
mitu	doc_491521501746_item	3749738	et	0	main
muistendit	doc_491521501746_item	3749739	et	0	main
koguni	doc_491521501746_item	3749740	et	0	main
terve	doc_491521501746_item	3749741	et	0	main
tsükkel	doc_491521501746_item	3749742	et	0	main
nagu	doc_491521501746_item	3749743	et	0	main
vastavalt	doc_491521501746_item	3749744	et	0	main
oma	doc_491521501746_item	3749745	et	0	main
iseloomule	doc_491521501746_item	3749746	et	0	main
on	doc_491521501746_item	3749747	et	0	main
muistend	doc_491521501746_item	3749748	et	0	main
enamasti	doc_491521501746_item	3749749	et	0	main
lühike	doc_491521501746_item	3749750	et	0	main
mingit	doc_491521501746_item	3749751	et	0	main
fakti	doc_491521501746_item	3749752	et	0	main
konstanteeruv	doc_491521501746_item	3749753	et	0	main
ühtainust	doc_491521501746_item	3749754	et	0	main
eesmärki	doc_491521501746_item	3749755	et	0	main
silmas	doc_491521501746_item	3749756	et	0	main
pidav	doc_491521501746_item	3749757	et	0	main
on	doc_491521501746_item	3749758	et	0	main
ka	doc_491521501746_item	3749759	et	0	main
selle	doc_491521501746_item	3749760	et	0	main
stiil	doc_491521501746_item	3749761	et	0	main
lapidaarne	doc_491521501746_item	3749762	et	0	main
kokkusurutud	doc_491521501746_item	3749763	et	0	main
tihti	doc_491521501746_item	3749764	et	0	main
rohkem	doc_491521501746_item	3749765	et	0	main
kirjeldav	doc_491521501746_item	3749766	et	0	main
kui	doc_491521501746_item	3749767	et	0	main
jutustav	doc_491521501746_item	3749768	et	0	main
muistend	doc_491521501746_item	3749769	et	0	main
algab	doc_491521501746_item	3749770	et	0	main
tavaliselt	doc_491521501746_item	3749771	et	0	main
koha	doc_491521501746_item	3749772	et	0	main
või	doc_491521501746_item	3749773	et	0	main
aja	doc_491521501746_item	3749774	et	0	main
täpse	doc_491521501746_item	3749775	et	0	main
märkimisega	doc_491521501746_item	3749776	et	0	main
kus	doc_491521501746_item	3749777	et	0	main
sündmus	doc_491521501746_item	3749778	et	0	main
toimus	doc_491521501746_item	3749779	et	0	main
siis	doc_491521501746_item	3749780	et	0	main
tuleb	doc_491521501746_item	3749781	et	0	main
tegelane	doc_491521501746_item	3749782	et	0	main
kellega	doc_491521501746_item	3749783	et	0	main
konkreetselt	doc_491521501746_item	3749784	et	0	main
näidatav	doc_491521501746_item	3749785	et	0	main
või	doc_491521501746_item	3749786	et	0	main
tõeks	doc_491521501746_item	3749787	et	0	main
tunnistatud	doc_491521501746_item	3749788	et	0	main
lugu	doc_491521501746_item	3749789	et	0	main
juhtus	doc_491521501746_item	3749790	et	0	main
muistendi	doc_491521501746_item	3749791	et	0	main
pikkus	doc_491521501746_item	3749792	et	0	main
kõigub	doc_491521501746_item	3749793	et	0	main
ühe	doc_491521501746_item	3749794	et	0	main
või	doc_491521501746_item	3749795	et	0	main
paari	doc_491521501746_item	3749796	et	0	main
lause	doc_491521501746_item	3749797	et	0	main
ja	doc_491521501746_item	3749798	et	0	main
küllalt	doc_491521501746_item	3749799	et	0	main
pika	doc_491521501746_item	3749800	et	0	main
eepilise	doc_491521501746_item	3749801	et	0	main
jutustuse	doc_491521501746_item	3749802	et	0	main
vahel	doc_491521501746_item	3749803	et	0	main
kuid	doc_491521501746_item	3749804	et	0	main
viimane	doc_491521501746_item	3749805	et	0	main
on	doc_491521501746_item	3749806	et	0	main
siiski	doc_491521501746_item	3749807	et	0	main
erand	doc_491521501746_item	3749808	et	0	main
muistend	doc_491521501746_item	3749809	et	0	main
harulikut	doc_491521501746_item	3749810	et	0	main
ei	doc_491521501746_item	3749811	et	0	main
arenda	doc_491521501746_item	3749812	et	0	main
üksikpilte	doc_491521501746_item	3749813	et	0	main
nagu	doc_491521501746_item	3749814	et	0	main
teeb	doc_491521501746_item	3749815	et	0	main
seda	doc_491521501746_item	3749816	et	0	main
muinasjutt	doc_491521501746_item	3749817	et	0	main
muistend	doc_491521501746_item	3749818	et	0	main
jääb	doc_491521501746_item	3749819	et	0	main
ikka	doc_491521501746_item	3749820	et	0	main
seletavaks	doc_491521501746_item	3749821	et	0	main
seetõttu	doc_491521501746_item	3749822	et	0	main
on	doc_491521501746_item	3749823	et	0	main
ka	doc_491521501746_item	3749824	et	0	main
stiil	doc_491521501746_item	3749825	et	0	main
värvivaesem	doc_491521501746_item	3749826	et	0	main
tavaliselt	doc_491521501746_item	3749827	et	0	main
antakse	doc_491521501746_item	3749828	et	0	main
jutustus	doc_491521501746_item	3749829	et	0	main
edasi	doc_491521501746_item	3749830	et	0	main
kolmandas	doc_491521501746_item	3749831	et	0	main
isikus	doc_491521501746_item	3749832	et	0	main
kui	doc_491521501746_item	3749833	et	0	main
traditsiooniline	doc_491521501746_item	3749834	et	0	main
lugu	doc_491521501746_item	3749835	et	0	main
või	doc_491521501746_item	3749836	et	0	main
kui	doc_491521501746_item	3749837	et	0	main
mittekaheldav	doc_491521501746_item	3749838	et	0	main
tõsiasi	doc_491521501746_item	3749839	et	0	main
mis	doc_491521501746_item	3749840	et	0	main
on	doc_491521501746_item	3749841	et	0	main
juhtunud	doc_491521501746_item	3749842	et	0	main
jutustaja	doc_491521501746_item	3749843	et	0	main
tuttava	doc_491521501746_item	3749844	et	0	main
isikuga	doc_491521501746_item	3749845	et	0	main
harva	doc_491521501746_item	3749846	et	0	main
tutvustab	doc_491521501746_item	3749847	et	0	main
jutustaja	doc_491521501746_item	3749848	et	0	main
end	doc_491521501746_item	3749849	et	0	main
isikliki	doc_491521501746_item	3749850	et	0	main
pealtvaatajana	doc_491521501746_item	3749851	et	0	main
jutustuse	doc_491521501746_item	3749852	et	0	main
usaldatavuse	doc_491521501746_item	3749853	et	0	main
toetuseks	doc_491521501746_item	3749854	et	0	main
tuuakse	doc_491521501746_item	3749855	et	0	main
mitmes	doc_491521501746_item	3749856	et	0	main
muistendrühmas	doc_491521501746_item	3749857	et	0	main
silmnähtav	doc_491521501746_item	3749858	et	0	main
fakt	doc_491521501746_item	3749859	et	0	main
kivi	doc_491521501746_item	3749860	et	0	main
mägi	doc_491521501746_item	3749861	et	0	main
soo	doc_491521501746_item	3749862	et	0	main
järv	doc_491521501746_item	3749863	et	0	main
allikas	doc_491521501746_item	3749864	et	0	main
jne	doc_491521501746_item	3749865	et	0	main
just	doc_491521501746_item	3749866	et	0	main
sellise	doc_491521501746_item	3749867	et	0	main
konkreetsuse	doc_491521501746_item	3749868	et	0	main
kaudu	doc_491521501746_item	3749869	et	0	main
saabki	doc_491521501746_item	3749870	et	0	main
muistendi	doc_491521501746_item	3749871	et	0	main
jutustaja	doc_491521501746_item	3749872	et	0	main
kuulajat	doc_491521501746_item	3749873	et	0	main
veenda	doc_491521501746_item	3749874	et	0	main
uskuma	doc_491521501746_item	3749875	et	0	main
jutustatut	doc_491521501746_item	3749876	et	0	main
kui	doc_491521501746_item	3749877	et	0	main
tõde	doc_491521501746_item	3749878	et	0	main
muistend	doc_491521501746_item	3749879	et	0	main
on	doc_491521501746_item	3749880	et	0	main
loodud	doc_491521501746_item	3749881	et	0	main
mütoloogia	doc_491521501746_item	3749882	et	0	main
alusel	doc_491521501746_item	3749883	et	0	main
ja	doc_491521501746_item	3749884	et	0	main
mütoloogia	doc_491521501746_item	3749885	et	0	main
seos	doc_491521501746_item	3749886	et	0	main
võib	doc_491521501746_item	3749887	et	0	main
olla	doc_491521501746_item	3749888	et	0	main
vähem	doc_491521501746_item	3749889	et	0	main
või	doc_491521501746_item	3749890	et	0	main
rohkem	doc_491521501746_item	3749891	et	0	main
ilmne	doc_491521501746_item	3749892	et	0	main
aga	doc_491521501746_item	3749893	et	0	main
ei	doc_491521501746_item	3749894	et	0	main
puudu	doc_491521501746_item	3749895	et	0	main
kunagi	doc_491521501746_item	3749896	et	0	main
muistendid	doc_491521501746_item	3749897	et	0	main
on	doc_491521501746_item	3749898	et	0	main
jaotatud	doc_491521501746_item	3749899	et	0	main
viite	doc_491521501746_item	3749900	et	0	main
rühma	doc_491521501746_item	3749901	et	0	main
1	doc_491521501746_item	3749902	et	0	main
tekke-	doc_491521501746_item	3749903	et	0	main
ja	doc_491521501746_item	3749904	et	0	main
seletusmuistendid	doc_491521501746_item	3749905	et	0	main
2	doc_491521501746_item	3749906	et	0	main
usundilised	doc_491521501746_item	3749907	et	0	main
muistendid	doc_491521501746_item	3749908	et	0	main
3	doc_491521501746_item	3749909	et	0	main
hiiu-	doc_491521501746_item	3749910	et	0	main
ja	doc_491521501746_item	3749911	et	0	main
vägilasmuistendid	doc_491521501746_item	3749912	et	0	main
4	doc_491521501746_item	3749913	et	0	main
kohamuistendid	doc_491521501746_item	3749914	et	0	main
e	doc_491521501746_item	3749915	et	0	main
kohapärimused	doc_491521501746_item	3749916	et	0	main
5	doc_491521501746_item	3749917	et	0	main
ajaloolised	doc_491521501746_item	3749918	et	0	main
muistendid	doc_491521501746_item	3749919	et	0	main
laugaste	doc_491521501746_item	3749920	et	0	main
1986	doc_491521501746_item	3749921	et	0	main
270	doc_491521501746_item	3749922	et	0	main
liikide	doc_491521501746_item	3749923	et	0	main
piirid	doc_491521501746_item	3749924	et	0	main
ei	doc_491521501746_item	3749925	et	0	main
ole	doc_491521501746_item	3749926	et	0	main
päris	doc_491521501746_item	3749927	et	0	main
kindlad	doc_491521501746_item	3749928	et	0	main
üht	doc_491521501746_item	3749929	et	0	main
ja	doc_491521501746_item	3749930	et	0	main
sama	doc_491521501746_item	3749931	et	0	main
muistendit	doc_491521501746_item	3749932	et	0	main
saab	doc_491521501746_item	3749933	et	0	main
paigutada	doc_491521501746_item	3749934	et	0	main
eri	doc_491521501746_item	3749935	et	0	main
rühmadesse	doc_491521501746_item	3749936	et	0	main
nt	doc_491521501746_item	3749937	et	0	main
katkumuistendid	doc_491521501746_item	3749938	et	0	main
võivad	doc_491521501746_item	3749939	et	0	main
olla	doc_491521501746_item	3749940	et	0	main
nii	doc_491521501746_item	3749941	et	0	main
ajaloolised	doc_491521501746_item	3749942	et	0	main
muistendid	doc_491521501746_item	3749943	et	0	main
kui	doc_491521501746_item	3749944	et	0	main
ka	doc_491521501746_item	3749945	et	0	main
kohapärimused	doc_491521501746_item	3749946	et	0	main
21	doc_491521501746_item	3749947	et	0	main
kohamuistendid	doc_491521501746_item	3749948	et	0	main
e	doc_491521501746_item	3749949	et	0	main
kohapärimused	doc_491521501746_item	3749950	et	0	main
kohamuisendite	doc_491521501746_item	3749951	et	0	main
hulgas	doc_491521501746_item	3749952	et	0	main
on	doc_491521501746_item	3749953	et	0	main
palju	doc_491521501746_item	3749954	et	0	main
niisuguseid	doc_491521501746_item	3749955	et	0	main
mis	doc_491521501746_item	3749956	et	0	main
püüävad	doc_491521501746_item	3749957	et	0	main
seletada	doc_491521501746_item	3749958	et	0	main
kohtade	doc_491521501746_item	3749959	et	0	main
moodustumist	doc_491521501746_item	3749960	et	0	main
kujunemist	doc_491521501746_item	3749961	et	0	main
nime	doc_491521501746_item	3749962	et	0	main
saamist	doc_491521501746_item	3749963	et	0	main
või	doc_491521501746_item	3749964	et	0	main
sündmusi	doc_491521501746_item	3749965	et	0	main
mis	doc_491521501746_item	3749966	et	0	main
kunagi	doc_491521501746_item	3749967	et	0	main
antud	doc_491521501746_item	3749968	et	0	main
paigas	doc_491521501746_item	3749969	et	0	main
on	doc_491521501746_item	3749970	et	0	main
toimunud	doc_491521501746_item	3749971	et	0	main
paljud	doc_491521501746_item	3749972	et	0	main
kohapärimused	doc_491521501746_item	3749973	et	0	main
on	doc_491521501746_item	3749974	et	0	main
seotud	doc_491521501746_item	3749975	et	0	main
suurte	doc_491521501746_item	3749976	et	0	main
rändrahnude	doc_491521501746_item	3749977	et	0	main
puude	doc_491521501746_item	3749978	et	0	main
järvede	doc_491521501746_item	3749979	et	0	main
allikate	doc_491521501746_item	3749980	et	0	main
ehitistega	doc_491521501746_item	3749981	et	0	main
nissi	doc_491521501746_item	3749982	et	0	main
kihelkonna	doc_491521501746_item	3749983	et	0	main
pärimuste	doc_491521501746_item	3749984	et	0	main
kohta	doc_491521501746_item	3749985	et	0	main
kogutud	doc_491521501746_item	3749986	et	0	main
materjal	doc_491521501746_item	3749987	et	0	main
on	doc_491521501746_item	3749988	et	0	main
eesti	doc_491521501746_item	3749989	et	0	main
rahvaluule	doc_491521501746_item	3749990	et	0	main
arhiivis	doc_491521501746_item	3749991	et	0	main
kus	doc_491521501746_item	3749992	et	0	main
saigi	doc_491521501746_item	3749993	et	0	main
seda	doc_491521501746_item	3749994	et	0	main
uurida	doc_491521501746_item	3749995	et	0	main
suurem	doc_491521501746_item	3749996	et	0	main
osa	doc_491521501746_item	3749997	et	0	main
materjalist	doc_491521501746_item	3749998	et	0	main
on	doc_491521501746_item	3749999	et	0	main
kogutud	doc_491521501746_item	3750000	et	0	main
rkm	doc_491521501746_item	3750001	et	0	main
ekspeditsioonis	doc_491521501746_item	3750002	et	0	main
mis	doc_491521501746_item	3750003	et	0	main
oli	doc_491521501746_item	3750004	et	0	main
toimunud	doc_491521501746_item	3750005	et	0	main
1990	doc_491521501746_item	3750006	et	0	main
aastal	doc_491521501746_item	3750007	et	0	main
ja	doc_491521501746_item	3750008	et	0	main
mille	doc_491521501746_item	3750009	et	0	main
üheks	doc_491521501746_item	3750010	et	0	main
eesmärgiks	doc_491521501746_item	3750011	et	0	main
oli	doc_491521501746_item	3750012	et	0	main
rahvapärimuse	doc_491521501746_item	3750013	et	0	main
kogumine	doc_491521501746_item	3750014	et	0	main
nissi	doc_491521501746_item	3750015	et	0	main
kihelkonnast	doc_491521501746_item	3750016	et	0	main
suurem	doc_491521501746_item	3750017	et	0	main
osa	doc_491521501746_item	3750018	et	0	main
sellest	doc_491521501746_item	3750019	et	0	main
moodustavad	doc_491521501746_item	3750020	et	0	main
rahvajutud	doc_491521501746_item	3750021	et	0	main
mis	doc_491521501746_item	3750022	et	0	main
seletavad	doc_491521501746_item	3750023	et	0	main
kohanimede	doc_491521501746_item	3750024	et	0	main
teket	doc_491521501746_item	3750025	et	0	main
siin	doc_491521501746_item	3750026	et	0	main
võib	doc_491521501746_item	3750027	et	0	main
eraldi	doc_491521501746_item	3750028	et	0	main
vaadelda	doc_491521501746_item	3750029	et	0	main
muistendeid	doc_491521501746_item	3750030	et	0	main
mis	doc_491521501746_item	3750031	et	0	main
räägivad	doc_491521501746_item	3750032	et	0	main
maastiku	doc_491521501746_item	3750033	et	0	main
vormide	doc_491521501746_item	3750034	et	0	main
nimede	doc_491521501746_item	3750035	et	0	main
tekkimisest	doc_491521501746_item	3750036	et	0	main
ja	doc_491521501746_item	3750037	et	0	main
talude	doc_491521501746_item	3750038	et	0	main
nimede	doc_491521501746_item	3750039	et	0	main
seletavaid	doc_491521501746_item	3750040	et	0	main
jutte	doc_491521501746_item	3750041	et	0	main
kohalikus	doc_491521501746_item	3750042	et	0	main
vanavaras	doc_491521501746_item	3750043	et	0	main
on	doc_491521501746_item	3750044	et	0	main
ka	doc_491521501746_item	3750045	et	0	main
kohamuistendeid	doc_491521501746_item	3750046	et	0	main
muinaslinnadest	doc_491521501746_item	3750047	et	0	main
varbolast	doc_491521501746_item	3750048	et	0	main
rohumäest	doc_491521501746_item	3750049	et	0	main
maa-alustest	doc_491521501746_item	3750050	et	0	main
teedest	doc_491521501746_item	3750051	et	0	main
eraldi	doc_491521501746_item	3750052	et	0	main
rühmana	doc_491521501746_item	3750053	et	0	main
julgen	doc_491521501746_item	3750054	et	0	main
välja	doc_491521501746_item	3750055	et	0	main
tuua	doc_491521501746_item	3750056	et	0	main
ka	doc_491521501746_item	3750057	et	0	main
pärimusi	doc_491521501746_item	3750058	et	0	main
mis	doc_491521501746_item	3750059	et	0	main
on	doc_491521501746_item	3750060	et	0	main
seotud	doc_491521501746_item	3750061	et	0	main
matmispaikadega	doc_491521501746_item	3750062	et	0	main
e	doc_491521501746_item	3750063	et	0	main
kalmetega	doc_491521501746_item	3750064	et	0	main
211	doc_491521501746_item	3750065	et	0	main
talud	doc_491521501746_item	3750066	et	0	main
külad	doc_491521501746_item	3750067	et	0	main
asulad	doc_491521501746_item	3750068	et	0	main
turba	doc_491521501746_item	3750069	et	0	main
elektrijaam	doc_491521501746_item	3750070	et	0	main
turba	doc_491521501746_item	3750071	et	0	main
asula	doc_491521501746_item	3750072	et	0	main
ajaloost	doc_491521501746_item	3750073	et	0	main
siin	doc_491521501746_item	3750074	et	0	main
oli	doc_491521501746_item	3750075	et	0	main
ainult	doc_491521501746_item	3750076	et	0	main
paar	doc_491521501746_item	3750077	et	0	main
talu	doc_491521501746_item	3750078	et	0	main
jaamaülema	doc_491521501746_item	3750079	et	0	main
maja	doc_491521501746_item	3750080	et	0	main
ehitati	doc_491521501746_item	3750081	et	0	main
esimesena	doc_491521501746_item	3750082	et	0	main
see	doc_491521501746_item	3750083	et	0	main
on	doc_491521501746_item	3750084	et	0	main
siin	doc_491521501746_item	3750085	et	0	main
valge	doc_491521501746_item	3750086	et	0	main
jaam	doc_491521501746_item	3750087	et	0	main
ja	doc_491521501746_item	3750088	et	0	main
pärast	doc_491521501746_item	3750089	et	0	main
sooniste	doc_491521501746_item	3750090	et	0	main
jaam	doc_491521501746_item	3750091	et	0	main
risti	doc_491521501746_item	3750092	et	0	main
ja	doc_491521501746_item	3750093	et	0	main
palivere	doc_491521501746_item	3750094	et	0	main
jaagna	doc_491521501746_item	3750095	et	0	main
kõverikus	doc_491521501746_item	3750096	et	0	main
on	doc_491521501746_item	3750097	et	0	main
raudtee	doc_491521501746_item	3750098	et	0	main
kõrval	doc_491521501746_item	3750099	et	0	main
vanad	doc_491521501746_item	3750100	et	0	main
teemulde	doc_491521501746_item	3750101	et	0	main
kraavid	doc_491521501746_item	3750102	et	0	main
olla	doc_491521501746_item	3750103	et	0	main
algul	doc_491521501746_item	3750104	et	0	main
raudtee	doc_491521501746_item	3750105	et	0	main
planeeritud	doc_491521501746_item	3750106	et	0	main
aga	doc_491521501746_item	3750107	et	0	main
pole	doc_491521501746_item	3750108	et	0	main
tehtud	doc_491521501746_item	3750109	et	0	main
turba	doc_491521501746_item	3750110	et	0	main
elamaa	doc_491521501746_item	3750111	et	0	main
vahel	doc_491521501746_item	3750112	et	0	main
on	doc_491521501746_item	3750113	et	0	main
raudtee	doc_491521501746_item	3750114	et	0	main
ehitatud	doc_491521501746_item	3750115	et	0	main
vangide	doc_491521501746_item	3750116	et	0	main
tööga	doc_491521501746_item	3750117	et	0	main
töö	doc_491521501746_item	3750118	et	0	main
oli	doc_491521501746_item	3750119	et	0	main
raske	doc_491521501746_item	3750120	et	0	main
rabas	doc_491521501746_item	3750121	et	0	main
suri	doc_491521501746_item	3750122	et	0	main
palju	doc_491521501746_item	3750123	et	0	main
vange	doc_491521501746_item	3750124	et	0	main
turbasse	doc_491521501746_item	3750125	et	0	main
tehti	doc_491521501746_item	3750126	et	0	main
elektrijaam	doc_491521501746_item	3750127	et	0	main
turvas	doc_491521501746_item	3750128	et	0	main
veeti	doc_491521501746_item	3750129	et	0	main
ellamaale	doc_491521501746_item	3750130	et	0	main
välja	doc_491521501746_item	3750131	et	0	main
eesti	doc_491521501746_item	3750132	et	0	main
ajal	doc_491521501746_item	3750133	et	0	main
käis	doc_491521501746_item	3750134	et	0	main
turba	doc_491521501746_item	3750135	et	0	main
tootmine	doc_491521501746_item	3750136	et	0	main
käsitsi	doc_491521501746_item	3750137	et	0	main
algil	doc_491521501746_item	3750138	et	0	main
tehti	doc_491521501746_item	3750139	et	0	main
pätse	doc_491521501746_item	3750140	et	0	main
praegu	doc_491521501746_item	3750141	et	0	main
tehakse	doc_491521501746_item	3750142	et	0	main
freesiturvast	doc_491521501746_item	3750143	et	0	main
müüakse	doc_491521501746_item	3750144	et	0	main
välismaale	doc_491521501746_item	3750145	et	0	main
hea	doc_491521501746_item	3750146	et	0	main
valuuta	doc_491521501746_item	3750147	et	0	main
allikas	doc_491521501746_item	3750148	et	0	main
rkm	doc_491521501746_item	3750149	et	0	main
ii	doc_491521501746_item	3750150	et	0	main
435	doc_491521501746_item	3750151	et	0	main
221222	doc_491521501746_item	3750152	et	0	main
4	doc_491521501746_item	3750153	et	0	main
nissi	doc_491521501746_item	3750154	et	0	main
turba	doc_491521501746_item	3750155	et	0	main
al	doc_491521501746_item	3750156	et	0	main
kullamaa	doc_491521501746_item	3750157	et	0	main
maidla	doc_491521501746_item	3750158	et	0	main
k	doc_491521501746_item	3750159	et	0	main
kadi	doc_491521501746_item	3750160	et	0	main
sarv	doc_491521501746_item	3750161	et	0	main
johannes	doc_491521501746_item	3750162	et	0	main
paulmann	doc_491521501746_item	3750163	et	0	main
s	doc_491521501746_item	3750164	et	0	main
1922	doc_491521501746_item	3750165	et	0	main
a	doc_491521501746_item	3750166	et	0	main
1990	doc_491521501746_item	3750167	et	0	main
hiie	doc_491521501746_item	3750168	et	0	main
ja	doc_491521501746_item	3750169	et	0	main
matsu	doc_491521501746_item	3750170	et	0	main
talu	doc_491521501746_item	3750171	et	0	main
on	doc_491521501746_item	3750172	et	0	main
viruküla	doc_491521501746_item	3750173	et	0	main
vanimad	doc_491521501746_item	3750174	et	0	main
asustatud	doc_491521501746_item	3750175	et	0	main
kohad	doc_491521501746_item	3750176	et	0	main
rkm	doc_491521501746_item	3750177	et	0	main
ii	doc_491521501746_item	3750178	et	0	main
435	doc_491521501746_item	3750179	et	0	main
264	doc_491521501746_item	3750180	et	0	main
4	doc_491521501746_item	3750181	et	0	main
nissi	doc_491521501746_item	3750182	et	0	main
turba	doc_491521501746_item	3750183	et	0	main
al	doc_491521501746_item	3750184	et	0	main
põltsamaa	doc_491521501746_item	3750185	et	0	main
khk	doc_491521501746_item	3750186	et	0	main
kadi	doc_491521501746_item	3750187	et	0	main
sarv	doc_491521501746_item	3750188	et	0	main
agnes	doc_491521501746_item	3750189	et	0	main
saliste	doc_491521501746_item	3750190	et	0	main
s	doc_491521501746_item	3750191	et	0	main
1923	doc_491521501746_item	3750192	et	0	main
a	doc_491521501746_item	3750193	et	0	main
1990	doc_491521501746_item	3750194	et	0	main
meil	doc_491521501746_item	3750195	et	0	main
on	doc_491521501746_item	3750196	et	0	main
linnapa	doc_491521501746_item	3750197	et	0	main
talu	doc_491521501746_item	3750198	et	0	main
aga	doc_491521501746_item	3750199	et	0	main
räägiti	doc_491521501746_item	3750200	et	0	main
et	doc_491521501746_item	3750201	et	0	main
vanasti	doc_491521501746_item	3750202	et	0	main
oli	doc_491521501746_item	3750203	et	0	main
varbola	doc_491521501746_item	3750204	et	0	main
maalinnuse	doc_491521501746_item	3750205	et	0	main
pea	doc_491521501746_item	3750206	et	0	main
seal	doc_491521501746_item	3750207	et	0	main
elanud	doc_491521501746_item	3750208	et	0	main
et	doc_491521501746_item	3750209	et	0	main
sellest	doc_491521501746_item	3750210	et	0	main
tuli	doc_491521501746_item	3750211	et	0	main
linnapea	doc_491521501746_item	3750212	et	0	main
talu	doc_491521501746_item	3750213	et	0	main
manivald	doc_491521501746_item	3750214	et	0	main
oli	doc_491521501746_item	3750215	et	0	main
vist	doc_491521501746_item	3750216	et	0	main
selles	doc_491521501746_item	3750217	et	0	main
küsimuses	doc_491521501746_item	3750218	et	0	main
see	doc_491521501746_item	3750219	et	0	main
peamees	doc_491521501746_item	3750220	et	0	main
meil	doc_491521501746_item	3750221	et	0	main
oli	doc_491521501746_item	3750222	et	0	main
niisugune	doc_491521501746_item	3750223	et	0	main
soine	doc_491521501746_item	3750224	et	0	main
koht	doc_491521501746_item	3750225	et	0	main
siis	doc_491521501746_item	3750226	et	0	main
otse	doc_491521501746_item	3750227	et	0	main
ei	doc_491521501746_item	3750228	et	0	main
saanud	doc_491521501746_item	3750229	et	0	main
sinna	doc_491521501746_item	3750230	et	0	main
linmese	doc_491521501746_item	3750231	et	0	main
juurde	doc_491521501746_item	3750232	et	0	main
aga	doc_491521501746_item	3750233	et	0	main
siis	doc_491521501746_item	3750234	et	0	main
kostis	doc_491521501746_item	3750235	et	0	main
laul	doc_491521501746_item	3750236	et	0	main
ja	doc_491521501746_item	3750237	et	0	main
pillimäng	doc_491521501746_item	3750238	et	0	main
sealt	doc_491521501746_item	3750239	et	0	main
ära	doc_491521501746_item	3750240	et	0	main
poisid	doc_491521501746_item	3750241	et	0	main
olid	doc_491521501746_item	3750242	et	0	main
ehitanud	doc_491521501746_item	3750243	et	0	main
selle	doc_491521501746_item	3750244	et	0	main
kiige	doc_491521501746_item	3750245	et	0	main
sinna	doc_491521501746_item	3750246	et	0	main
mina	doc_491521501746_item	3750247	et	0	main
ei	doc_491521501746_item	3750248	et	0	main
ole	doc_491521501746_item	3750249	et	0	main
seal	doc_491521501746_item	3750250	et	0	main
käinud	doc_491521501746_item	3750251	et	0	main
tantsimas	doc_491521501746_item	3750252	et	0	main
aga	doc_491521501746_item	3750253	et	0	main
noored	doc_491521501746_item	3750254	et	0	main
käisid	doc_491521501746_item	3750255	et	0	main
seal	doc_491521501746_item	3750256	et	0	main
rkm	doc_491521501746_item	3750257	et	0	main
ii	doc_491521501746_item	3750258	et	0	main
434	doc_491521501746_item	3750259	et	0	main
745	doc_491521501746_item	3750260	et	0	main
2	doc_491521501746_item	3750261	et	0	main
nissi	doc_491521501746_item	3750262	et	0	main
lehetu	doc_491521501746_item	3750263	et	0	main
k	doc_491521501746_item	3750264	et	0	main
pajaka	doc_491521501746_item	3750265	et	0	main
k	doc_491521501746_item	3750266	et	0	main
varbola	doc_491521501746_item	3750267	et	0	main
v	doc_491521501746_item	3750268	et	0	main
ja	doc_491521501746_item	3750269	et	0	main
k	doc_491521501746_item	3750270	et	0	main
mall	doc_491521501746_item	3750271	et	0	main
hiiemäe	doc_491521501746_item	3750272	et	0	main
hilda	doc_491521501746_item	3750273	et	0	main
nurmbek	doc_491521501746_item	3750274	et	0	main
s	doc_491521501746_item	3750275	et	0	main
1907	doc_491521501746_item	3750276	et	0	main
a	doc_491521501746_item	3750277	et	0	main
1990	doc_491521501746_item	3750278	et	0	main
saapa	doc_491521501746_item	3750279	et	0	main
talu	doc_491521501746_item	3750280	et	0	main
maa	doc_491521501746_item	3750281	et	0	main
aga	doc_491521501746_item	3750282	et	0	main
päris	doc_491521501746_item	3750283	et	0	main
saapa	doc_491521501746_item	3750284	et	0	main
kujuga	doc_491521501746_item	3750285	et	0	main
rkm	doc_491521501746_item	3750286	et	0	main
ii	doc_491521501746_item	3750287	et	0	main
433	doc_491521501746_item	3750288	et	0	main
435	doc_491521501746_item	3750289	et	0	main
39	doc_491521501746_item	3750290	et	0	main
nissi	doc_491521501746_item	3750291	et	0	main
khk	doc_491521501746_item	3750292	et	0	main
sooniste	doc_491521501746_item	3750293	et	0	main
v	doc_491521501746_item	3750294	et	0	main
ellamaa	doc_491521501746_item	3750295	et	0	main
k	doc_491521501746_item	3750296	et	0	main
piirsalu	doc_491521501746_item	3750297	et	0	main
v	doc_491521501746_item	3750298	et	0	main
turvaste	doc_491521501746_item	3750299	et	0	main
k	doc_491521501746_item	3750300	et	0	main
anu	doc_491521501746_item	3750301	et	0	main
korb	doc_491521501746_item	3750302	et	0	main
hilda	doc_491521501746_item	3750303	et	0	main
tanner	doc_491521501746_item	3750304	et	0	main
s	doc_491521501746_item	3750305	et	0	main
1908	doc_491521501746_item	3750306	et	0	main
a	doc_491521501746_item	3750307	et	0	main
1990	doc_491521501746_item	3750308	et	0	main
luuri	doc_491521501746_item	3750309	et	0	main
loss	doc_491521501746_item	3750310	et	0	main
oli	doc_491521501746_item	3750311	et	0	main
väike	doc_491521501746_item	3750312	et	0	main
osmik	doc_491521501746_item	3750313	et	0	main
urgeta	doc_491521501746_item	3750314	et	0	main
talu	doc_491521501746_item	3750315	et	0	main
põllu	doc_491521501746_item	3750316	et	0	main
peal	doc_491521501746_item	3750317	et	0	main
seal	doc_491521501746_item	3750318	et	0	main
elas	doc_491521501746_item	3750319	et	0	main
talumees	doc_491521501746_item	3750320	et	0	main
kellel	doc_491521501746_item	3750321	et	0	main
oli	doc_491521501746_item	3750322	et	0	main
palju	doc_491521501746_item	3750323	et	0	main
tütreid	doc_491521501746_item	3750324	et	0	main
mõnele	doc_491521501746_item	3750325	et	0	main
mehele	doc_491521501746_item	3750326	et	0	main
oli	doc_491521501746_item	3750327	et	0	main
sellepärast	doc_491521501746_item	3750328	et	0	main
vast	doc_491521501746_item	3750329	et	0	main
loss	doc_491521501746_item	3750330	et	0	main
siis	doc_491521501746_item	3750331	et	0	main
luuri	doc_491521501746_item	3750332	et	0	main
lossi	doc_491521501746_item	3750333	et	0	main
seosest	doc_491521501746_item	3750334	et	0	main
lurichiga	doc_491521501746_item	3750335	et	0	main
ei	doc_491521501746_item	3750336	et	0	main
tea	doc_491521501746_item	3750337	et	0	main
midagi	doc_491521501746_item	3750338	et	0	main
rkm	doc_491521501746_item	3750339	et	0	main
ii	doc_491521501746_item	3750340	et	0	main
435	doc_491521501746_item	3750341	et	0	main
227	doc_491521501746_item	3750342	et	0	main
3	doc_491521501746_item	3750343	et	0	main
nissi	doc_491521501746_item	3750344	et	0	main
turba	doc_491521501746_item	3750345	et	0	main
al	doc_491521501746_item	3750346	et	0	main
ellamaa	doc_491521501746_item	3750347	et	0	main
k	doc_491521501746_item	3750348	et	0	main
kadi	doc_491521501746_item	3750349	et	0	main
sarv	doc_491521501746_item	3750350	et	0	main
feliks	doc_491521501746_item	3750351	et	0	main
päärson	doc_491521501746_item	3750352	et	0	main
s	doc_491521501746_item	3750353	et	0	main
1910	doc_491521501746_item	3750354	et	0	main
a	doc_491521501746_item	3750355	et	0	main
1990	doc_491521501746_item	3750356	et	0	main
turvaste	doc_491521501746_item	3750357	et	0	main
külas	doc_491521501746_item	3750358	et	0	main
on	doc_491521501746_item	3750359	et	0	main
põldotsa	doc_491521501746_item	3750360	et	0	main
talu	doc_491521501746_item	3750361	et	0	main
põld	doc_491521501746_item	3750362	et	0	main
lõppes	doc_491521501746_item	3750363	et	0	main
sinna	doc_491521501746_item	3750364	et	0	main
ära	doc_491521501746_item	3750365	et	0	main
rkm	doc_491521501746_item	3750366	et	0	main
ii	doc_491521501746_item	3750367	et	0	main
433	doc_491521501746_item	3750368	et	0	main
435	doc_491521501746_item	3750369	et	0	main
38	doc_491521501746_item	3750370	et	0	main
nissi	doc_491521501746_item	3750371	et	0	main
khk	doc_491521501746_item	3750372	et	0	main
sooniste	doc_491521501746_item	3750373	et	0	main
v	doc_491521501746_item	3750374	et	0	main
ellamaa	doc_491521501746_item	3750375	et	0	main
k	doc_491521501746_item	3750376	et	0	main
piirsalu	doc_491521501746_item	3750377	et	0	main
v	doc_491521501746_item	3750378	et	0	main
turvaste	doc_491521501746_item	3750379	et	0	main
k	doc_491521501746_item	3750380	et	0	main
anu	doc_491521501746_item	3750381	et	0	main
korb	doc_491521501746_item	3750382	et	0	main
hilda	doc_491521501746_item	3750383	et	0	main
tanner	doc_491521501746_item	3750384	et	0	main
s	doc_491521501746_item	3750385	et	0	main
1908	doc_491521501746_item	3750386	et	0	main
a	doc_491521501746_item	3750387	et	0	main
1990	doc_491521501746_item	3750388	et	0	main
terjatu	doc_491521501746_item	3750389	et	0	main
on	doc_491521501746_item	3750390	et	0	main
niisugune	doc_491521501746_item	3750391	et	0	main
koht	doc_491521501746_item	3750392	et	0	main
et	doc_491521501746_item	3750393	et	0	main
sealt	doc_491521501746_item	3750394	et	0	main
käis	doc_491521501746_item	3750395	et	0	main
igavene	doc_491521501746_item	3750396	et	0	main
kehv	doc_491521501746_item	3750397	et	0	main
tee	doc_491521501746_item	3750398	et	0	main
välja	doc_491521501746_item	3750399	et	0	main
sellepärast	doc_491521501746_item	3750400	et	0	main
pandigi	doc_491521501746_item	3750401	et	0	main
nimi	doc_491521501746_item	3750402	et	0	main
teerajatu	doc_491521501746_item	3750403	et	0	main
kolm	doc_491521501746_item	3750404	et	0	main
talu	doc_491521501746_item	3750405	et	0	main
on	doc_491521501746_item	3750406	et	0	main
seal	doc_491521501746_item	3750407	et	0	main
soo	doc_491521501746_item	3750408	et	0	main
sees	doc_491521501746_item	3750409	et	0	main
rkm	doc_491521501746_item	3750410	et	0	main
ii	doc_491521501746_item	3750411	et	0	main
434	doc_491521501746_item	3750412	et	0	main
98	doc_491521501746_item	3750413	et	0	main
1	doc_491521501746_item	3750414	et	0	main
nissi	doc_491521501746_item	3750415	et	0	main
khk	doc_491521501746_item	3750416	et	0	main
riisipere	doc_491521501746_item	3750417	et	0	main
v	doc_491521501746_item	3750418	et	0	main
terjatu	doc_491521501746_item	3750419	et	0	main
k	doc_491521501746_item	3750420	et	0	main
lehetu	doc_491521501746_item	3750421	et	0	main
k	doc_491521501746_item	3750422	et	0	main
mall	doc_491521501746_item	3750423	et	0	main
hiiemäe	doc_491521501746_item	3750424	et	0	main
linda	doc_491521501746_item	3750425	et	0	main
linroos	doc_491521501746_item	3750426	et	0	main
s	doc_491521501746_item	3750427	et	0	main
1924	doc_491521501746_item	3750428	et	0	main
a	doc_491521501746_item	3750429	et	0	main
1990	doc_491521501746_item	3750430	et	0	main
kabli	doc_491521501746_item	3750431	et	0	main
talu	doc_491521501746_item	3750432	et	0	main
juures	doc_491521501746_item	3750433	et	0	main
on	doc_491521501746_item	3750434	et	0	main
olnud	doc_491521501746_item	3750435	et	0	main
üks	doc_491521501746_item	3750436	et	0	main
kiiboja	doc_491521501746_item	3750437	et	0	main
mõis	doc_491521501746_item	3750438	et	0	main
kabli	doc_491521501746_item	3750439	et	0	main
talu	doc_491521501746_item	3750440	et	0	main
juures	doc_491521501746_item	3750441	et	0	main
on	doc_491521501746_item	3750442	et	0	main
põld	doc_491521501746_item	3750443	et	0	main
ja	doc_491521501746_item	3750444	et	0	main
seal	doc_491521501746_item	3750445	et	0	main
olla	doc_491521501746_item	3750446	et	0	main
palju	doc_491521501746_item	3750447	et	0	main
kive	doc_491521501746_item	3750448	et	0	main
olnd	doc_491521501746_item	3750449	et	0	main
see	doc_491521501746_item	3750450	et	0	main
oli	doc_491521501746_item	3750451	et	0	main
mõisaase	doc_491521501746_item	3750452	et	0	main
kablil	doc_491521501746_item	3750453	et	0	main
oli	doc_491521501746_item	3750454	et	0	main
hobuseid	doc_491521501746_item	3750455	et	0	main
rautatud	doc_491521501746_item	3750456	et	0	main
ja	doc_491521501746_item	3750457	et	0	main
nuudilt	doc_491521501746_item	3750458	et	0	main
talu	doc_491521501746_item	3750459	et	0	main
oli	doc_491521501746_item	3750460	et	0	main
peksa	doc_491521501746_item	3750461	et	0	main
antud	doc_491521501746_item	3750462	et	0	main
jaagu	doc_491521501746_item	3750463	et	0	main
jüri	doc_491521501746_item	3750464	et	0	main
sellest	doc_491521501746_item	3750465	et	0	main
on	doc_491521501746_item	3750466	et	0	main
tulnud	doc_491521501746_item	3750467	et	0	main
jaagujüri	doc_491521501746_item	3750468	et	0	main
see	doc_491521501746_item	3750469	et	0	main
nukk	doc_491521501746_item	3750470	et	0	main
siin	doc_491521501746_item	3750471	et	0	main
küla	doc_491521501746_item	3750472	et	0	main
vahel	doc_491521501746_item	3750473	et	0	main
kus	doc_491521501746_item	3750474	et	0	main
sovhoosi	doc_491521501746_item	3750475	et	0	main
aeg	doc_491521501746_item	3750476	et	0	main
kive	doc_491521501746_item	3750477	et	0	main
kokku	doc_491521501746_item	3750478	et	0	main
aeti	doc_491521501746_item	3750479	et	0	main
nimetati	doc_491521501746_item	3750480	et	0	main
kiigealune	doc_491521501746_item	3750481	et	0	main
seal	doc_491521501746_item	3750482	et	0	main
oli	doc_491521501746_item	3750483	et	0	main
enne	doc_491521501746_item	3750484	et	0	main
kiige	doc_491521501746_item	3750485	et	0	main
rkm	doc_491521501746_item	3750486	et	0	main
ii	doc_491521501746_item	3750487	et	0	main
435	doc_491521501746_item	3750488	et	0	main
468	doc_491521501746_item	3750489	et	0	main
1	doc_491521501746_item	3750490	et	0	main
nissi	doc_491521501746_item	3750491	et	0	main
kibuna	doc_491521501746_item	3750492	et	0	main
k	doc_491521501746_item	3750493	et	0	main
jaaguri	doc_491521501746_item	3750494	et	0	main
t	doc_491521501746_item	3750495	et	0	main
jaanika	doc_491521501746_item	3750496	et	0	main
oras	doc_491521501746_item	3750497	et	0	main
helene	doc_491521501746_item	3750498	et	0	main
kuller	doc_491521501746_item	3750499	et	0	main
s	doc_491521501746_item	3750500	et	0	main
1917	doc_491521501746_item	3750501	et	0	main
a	doc_491521501746_item	3750502	et	0	main
1990	doc_491521501746_item	3750503	et	0	main
enne	doc_491521501746_item	3750504	et	0	main
kibuna	doc_491521501746_item	3750505	et	0	main
küla	doc_491521501746_item	3750506	et	0	main
ei	doc_491521501746_item	3750507	et	0	main
olnudki	doc_491521501746_item	3750508	et	0	main
oli	doc_491521501746_item	3750509	et	0	main
kolm	doc_491521501746_item	3750510	et	0	main
karjamõisa	doc_491521501746_item	3750511	et	0	main
omanikud	doc_491521501746_item	3750512	et	0	main
olid	doc_491521501746_item	3750513	et	0	main
eestlane	doc_491521501746_item	3750514	et	0	main
keskpaigas	doc_491521501746_item	3750515	et	0	main
oli	doc_491521501746_item	3750516	et	0	main
venelane	doc_491521501746_item	3750517	et	0	main
kolmas	doc_491521501746_item	3750518	et	0	main
oli	doc_491521501746_item	3750519	et	0	main
sakslane	doc_491521501746_item	3750520	et	0	main
need	doc_491521501746_item	3750521	et	0	main
läksid	doc_491521501746_item	3750522	et	0	main
tülisse	doc_491521501746_item	3750523	et	0	main
ja	doc_491521501746_item	3750524	et	0	main
venelane	doc_491521501746_item	3750525	et	0	main
oli	doc_491521501746_item	3750526	et	0	main
öelnud	doc_491521501746_item	3750527	et	0	main
kibuna	doc_491521501746_item	3750528	et	0	main
materi	doc_491521501746_item	3750529	et	0	main
teisel	doc_491521501746_item	3750530	et	0	main
korral	doc_491521501746_item	3750531	et	0	main
ütleb	doc_491521501746_item	3750532	et	0	main
justkui	doc_491521501746_item	3750533	et	0	main
kivrjuna	doc_491521501746_item	3750534	et	0	main
materi	doc_491521501746_item	3750535	et	0	main
sellest	doc_491521501746_item	3750536	et	0	main
tuligi	doc_491521501746_item	3750537	et	0	main
küla	doc_491521501746_item	3750538	et	0	main
nimi	doc_491521501746_item	3750539	et	0	main
minu	doc_491521501746_item	3750540	et	0	main
vanaisa	doc_491521501746_item	3750541	et	0	main
rääkis	doc_491521501746_item	3750542	et	0	main
ja	doc_491521501746_item	3750543	et	0	main
ploompuu	doc_491521501746_item	3750544	et	0	main
kustas	doc_491521501746_item	3750545	et	0	main
ka	doc_491521501746_item	3750546	et	0	main
rkm	doc_491521501746_item	3750547	et	0	main
ii	doc_491521501746_item	3750548	et	0	main
435	doc_491521501746_item	3750549	et	0	main
492	doc_491521501746_item	3750550	et	0	main
1	doc_491521501746_item	3750551	et	0	main
nissi	doc_491521501746_item	3750552	et	0	main
kibuna	doc_491521501746_item	3750553	et	0	main
k	doc_491521501746_item	3750554	et	0	main
otsari	doc_491521501746_item	3750555	et	0	main
t	doc_491521501746_item	3750556	et	0	main
jaanika	doc_491521501746_item	3750557	et	0	main
oras	doc_491521501746_item	3750558	et	0	main
ants	doc_491521501746_item	3750559	et	0	main
järvlepp	doc_491521501746_item	3750560	et	0	main
s	doc_491521501746_item	3750561	et	0	main
28	doc_491521501746_item	3750562	et	0	main
dets	doc_491521501746_item	3750563	et	0	main
1904	doc_491521501746_item	3750564	et	0	main
a	doc_491521501746_item	3750565	et	0	main
1990	doc_491521501746_item	3750566	et	0	main
kohe	doc_491521501746_item	3750567	et	0	main
seal	doc_491521501746_item	3750568	et	0	main
võdlemisi	doc_491521501746_item	3750569	et	0	main
lähedal	doc_491521501746_item	3750570	et	0	main
on	doc_491521501746_item	3750571	et	0	main
nuudi	doc_491521501746_item	3750572	et	0	main
seal	doc_491521501746_item	3750573	et	0	main
oli	doc_491521501746_item	3750574	et	0	main
siis	doc_491521501746_item	3750575	et	0	main
orjaaeg	doc_491521501746_item	3750576	et	0	main
rahvale	doc_491521501746_item	3750577	et	0	main
antud	doc_491521501746_item	3750578	et	0	main
peksa	doc_491521501746_item	3750579	et	0	main
kas	doc_491521501746_item	3750580	et	0	main
olid	doc_491521501746_item	3750581	et	0	main
siis	doc_491521501746_item	3750582	et	0	main
vaod	doc_491521501746_item	3750583	et	0	main
kõvarad	doc_491521501746_item	3750584	et	0	main
või	doc_491521501746_item	3750585	et	0	main
hakkasid	doc_491521501746_item	3750586	et	0	main
vastu	doc_491521501746_item	3750587	et	0	main
kupjale	doc_491521501746_item	3750588	et	0	main
siis	doc_491521501746_item	3750589	et	0	main
anti	doc_491521501746_item	3750590	et	0	main
ju	doc_491521501746_item	3750591	et	0	main
nuuti	doc_491521501746_item	3750592	et	0	main
rkm	doc_491521501746_item	3750593	et	0	main
ii	doc_491521501746_item	3750594	et	0	main
435	doc_491521501746_item	3750595	et	0	main
481	doc_491521501746_item	3750596	et	0	main
2	doc_491521501746_item	3750597	et	0	main
nissi	doc_491521501746_item	3750598	et	0	main
laitse	doc_491521501746_item	3750599	et	0	main
v	doc_491521501746_item	3750600	et	0	main
kibuna	doc_491521501746_item	3750601	et	0	main
k	doc_491521501746_item	3750602	et	0	main
vainu	doc_491521501746_item	3750603	et	0	main
talu	doc_491521501746_item	3750604	et	0	main
jaanika	doc_491521501746_item	3750605	et	0	main
oras	doc_491521501746_item	3750606	et	0	main
linda	doc_491521501746_item	3750607	et	0	main
vainu	doc_491521501746_item	3750608	et	0	main
s	doc_491521501746_item	3750609	et	0	main
29	doc_491521501746_item	3750610	et	0	main
dets	doc_491521501746_item	3750611	et	0	main
1926	doc_491521501746_item	3750612	et	0	main
a	doc_491521501746_item	3750613	et	0	main
1990	doc_491521501746_item	3750614	et	0	main
aga	doc_491521501746_item	3750615	et	0	main
kabli	doc_491521501746_item	3750616	et	0	main
talu	doc_491521501746_item	3750617	et	0	main
seal	doc_491521501746_item	3750618	et	0	main
on	doc_491521501746_item	3750619	et	0	main
mõisaaegas	doc_491521501746_item	3750620	et	0	main
jälle	doc_491521501746_item	3750621	et	0	main
hobuseid	doc_491521501746_item	3750622	et	0	main
rautatud	doc_491521501746_item	3750623	et	0	main
sellest	doc_491521501746_item	3750624	et	0	main
see	doc_491521501746_item	3750625	et	0	main
nimi	doc_491521501746_item	3750626	et	0	main
on	doc_491521501746_item	3750627	et	0	main
tulnud	doc_491521501746_item	3750628	et	0	main
rkm	doc_491521501746_item	3750629	et	0	main
ii	doc_491521501746_item	3750630	et	0	main
435	doc_491521501746_item	3750631	et	0	main
481	doc_491521501746_item	3750632	et	0	main
3	doc_491521501746_item	3750633	et	0	main
nissi	doc_491521501746_item	3750634	et	0	main
laitse	doc_491521501746_item	3750635	et	0	main
v	doc_491521501746_item	3750636	et	0	main
kibuna	doc_491521501746_item	3750637	et	0	main
k	doc_491521501746_item	3750638	et	0	main
vainu	doc_491521501746_item	3750639	et	0	main
talu	doc_491521501746_item	3750640	et	0	main
jaanika	doc_491521501746_item	3750641	et	0	main
oras	doc_491521501746_item	3750642	et	0	main
linda	doc_491521501746_item	3750643	et	0	main
vainu	doc_491521501746_item	3750644	et	0	main
s	doc_491521501746_item	3750645	et	0	main
29	doc_491521501746_item	3750646	et	0	main
dets	doc_491521501746_item	3750647	et	0	main
1926	doc_491521501746_item	3750648	et	0	main
a	doc_491521501746_item	3750649	et	0	main
1990	doc_491521501746_item	3750650	et	0	main
m	doc_491521501746_item	3750651	et	0	main
väljataguse	doc_491521501746_item	3750652	et	0	main
talu	doc_491521501746_item	3750653	et	0	main
väljaotsa	doc_491521501746_item	3750654	et	0	main
maja	doc_491521501746_item	3750655	et	0	main
akkas	doc_491521501746_item	3750656	et	0	main
ehitama	doc_491521501746_item	3750657	et	0	main
korstna	doc_491521501746_item	3750658	et	0	main
vundamendi	doc_491521501746_item	3750659	et	0	main
tegi	doc_491521501746_item	3750660	et	0	main
lauda	doc_491521501746_item	3750661	et	0	main
alt	doc_491521501746_item	3750662	et	0	main
oli	doc_491521501746_item	3750663	et	0	main
tulnd	doc_491521501746_item	3750664	et	0	main
kirstu	doc_491521501746_item	3750665	et	0	main
moodi	doc_491521501746_item	3750666	et	0	main
välja	doc_491521501746_item	3750667	et	0	main
inimese	doc_491521501746_item	3750668	et	0	main
luud	doc_491521501746_item	3750669	et	0	main
olid	doc_491521501746_item	3750670	et	0	main
seal	doc_491521501746_item	3750671	et	0	main
villem	doc_491521501746_item	3750672	et	0	main
ja	doc_491521501746_item	3750673	et	0	main
johannes	doc_491521501746_item	3750674	et	0	main
ehitasid	doc_491521501746_item	3750675	et	0	main
siis	doc_491521501746_item	3750676	et	0	main
seda	doc_491521501746_item	3750677	et	0	main
et	doc_491521501746_item	3750678	et	0	main
kas	doc_491521501746_item	3750679	et	0	main
oli	doc_491521501746_item	3750680	et	0	main
mõni	doc_491521501746_item	3750681	et	0	main
tähtsam	doc_491521501746_item	3750682	et	0	main
mees	doc_491521501746_item	3750683	et	0	main
või	doc_491521501746_item	3750684	et	0	main
põhjasõda	doc_491521501746_item	3750685	et	0	main
ajal	doc_491521501746_item	3750686	et	0	main
sääl	doc_491521501746_item	3750687	et	0	main
ääres	doc_491521501746_item	3750688	et	0	main
võis	doc_491521501746_item	3750689	et	0	main
kulda	doc_491521501746_item	3750690	et	0	main
ka	doc_491521501746_item	3750691	et	0	main
olla	doc_491521501746_item	3750692	et	0	main
mõni	doc_491521501746_item	3750693	et	0	main
rootsi	doc_491521501746_item	3750694	et	0	main
väepealik	doc_491521501746_item	3750695	et	0	main
vast	doc_491521501746_item	3750696	et	0	main
oli	doc_491521501746_item	3750697	et	0	main
tammepuudest	doc_491521501746_item	3750698	et	0	main
olevat	doc_491521501746_item	3750699	et	0	main
kirst	doc_491521501746_item	3750700	et	0	main
olnud	doc_491521501746_item	3750701	et	0	main
seal	doc_491521501746_item	3750702	et	0	main
võib	doc_491521501746_item	3750703	et	0	main
kulda	doc_491521501746_item	3750704	et	0	main
ka	doc_491521501746_item	3750705	et	0	main
veel	doc_491521501746_item	3750706	et	0	main
olla	doc_491521501746_item	3750707	et	0	main
aga	doc_491521501746_item	3750708	et	0	main
seal	doc_491521501746_item	3750709	et	0	main
majas	doc_491521501746_item	3750710	et	0	main
kogu	doc_491521501746_item	3750711	et	0	main
aeg	doc_491521501746_item	3750712	et	0	main
olid	doc_491521501746_item	3750713	et	0	main
õnnetused	doc_491521501746_item	3750714	et	0	main
tütretütat	doc_491521501746_item	3750715	et	0	main
oli	doc_491521501746_item	3750716	et	0	main
pime	doc_491521501746_item	3750717	et	0	main
juta	doc_491521501746_item	3750718	et	0	main
noorperenaine	doc_491521501746_item	3750719	et	0	main
sai	doc_491521501746_item	3750720	et	0	main
surma	doc_491521501746_item	3750721	et	0	main
viina	doc_491521501746_item	3750722	et	0	main
läbi	doc_491521501746_item	3750723	et	0	main
teine	doc_491521501746_item	3750724	et	0	main
perenaine	doc_491521501746_item	3750725	et	0	main
läks	doc_491521501746_item	3750726	et	0	main
abordi	doc_491521501746_item	3750727	et	0	main
tagajärjel	doc_491521501746_item	3750728	et	0	main
vanaema	doc_491521501746_item	3750729	et	0	main
matis	doc_491521501746_item	3750730	et	0	main
kõik	doc_491521501746_item	3750731	et	0	main
lapsed	doc_491521501746_item	3750732	et	0	main
maha	doc_491521501746_item	3750733	et	0	main
ja	doc_491521501746_item	3750734	et	0	main
jäi	doc_491521501746_item	3750735	et	0	main
rongi	doc_491521501746_item	3750736	et	0	main
alla	doc_491521501746_item	3750737	et	0	main
üks	doc_491521501746_item	3750738	et	0	main
mees	doc_491521501746_item	3750739	et	0	main
sõjaväes	doc_491521501746_item	3750740	et	0	main
uppus	doc_491521501746_item	3750741	et	0	main
juhani	doc_491521501746_item	3750742	et	0	main
õde	doc_491521501746_item	3750743	et	0	main
oli	doc_491521501746_item	3750744	et	0	main
tuba	doc_491521501746_item	3750745	et	0	main
pühkind	doc_491521501746_item	3750746	et	0	main
ja	doc_491521501746_item	3750747	et	0	main
mismoodi	doc_491521501746_item	3750748	et	0	main
see	doc_491521501746_item	3750749	et	0	main
püss	doc_491521501746_item	3750750	et	0	main
oli	doc_491521501746_item	3750751	et	0	main
lahti	doc_491521501746_item	3750752	et	0	main
läinud	doc_491521501746_item	3750753	et	0	main
ja	doc_491521501746_item	3750754	et	0	main
sai	doc_491521501746_item	3750755	et	0	main
surma	doc_491521501746_item	3750756	et	0	main
viimati	doc_491521501746_item	3750757	et	0	main
põles	doc_491521501746_item	3750758	et	0	main
talu	doc_491521501746_item	3750759	et	0	main
maha	doc_491521501746_item	3750760	et	0	main
70	doc_491521501746_item	3750761	et	0	main
aastatel	doc_491521501746_item	3750762	et	0	main
ainult	doc_491521501746_item	3750763	et	0	main
üks	doc_491521501746_item	3750764	et	0	main
õnnetuste	doc_491521501746_item	3750765	et	0	main
rida	doc_491521501746_item	3750766	et	0	main
üks	doc_491521501746_item	3750767	et	0	main
tütardest	doc_491521501746_item	3750768	et	0	main
tahab	doc_491521501746_item	3750769	et	0	main
seda	doc_491521501746_item	3750770	et	0	main
kohta	doc_491521501746_item	3750771	et	0	main
ülesehitada	doc_491521501746_item	3750772	et	0	main
vahel	doc_491521501746_item	3750773	et	0	main
on	doc_491521501746_item	3750774	et	0	main
nisuke	doc_491521501746_item	3750775	et	0	main
tunne	doc_491521501746_item	3750776	et	0	main
et	doc_491521501746_item	3750777	et	0	main
tahaks	doc_491521501746_item	3750778	et	0	main
midagi	doc_491521501746_item	3750779	et	0	main
õelda	doc_491521501746_item	3750780	et	0	main
selle	doc_491521501746_item	3750781	et	0	main
kohta	doc_491521501746_item	3750782	et	0	main
talle	doc_491521501746_item	3750783	et	0	main
aga	doc_491521501746_item	3750784	et	0	main
ei	doc_491521501746_item	3750785	et	0	main
tea	doc_491521501746_item	3750786	et	0	main
ka	doc_491521501746_item	3750787	et	0	main
seostati	doc_491521501746_item	3750788	et	0	main
sellega	doc_491521501746_item	3750789	et	0	main
et	doc_491521501746_item	3750790	et	0	main
võib-olla	doc_491521501746_item	3750791	et	0	main
oleks	doc_491521501746_item	3750792	et	0	main
pidanud	doc_491521501746_item	3750793	et	0	main
selle	doc_491521501746_item	3750794	et	0	main
kirstu	doc_491521501746_item	3750795	et	0	main
sinna	doc_491521501746_item	3750796	et	0	main
tagasi	doc_491521501746_item	3750797	et	0	main
panema	doc_491521501746_item	3750798	et	0	main
kui	doc_491521501746_item	3750799	et	0	main
ehitas	doc_491521501746_item	3750800	et	0	main
või	doc_491521501746_item	3750801	et	0	main
võib-olla	doc_491521501746_item	3750802	et	0	main
võttis	doc_491521501746_item	3750803	et	0	main
sealt	doc_491521501746_item	3750804	et	0	main
midagi	doc_491521501746_item	3750805	et	0	main
ka	doc_491521501746_item	3750806	et	0	main
veel	doc_491521501746_item	3750807	et	0	main
vanarahvas	doc_491521501746_item	3750808	et	0	main
ütles	doc_491521501746_item	3750809	et	0	main
niimoodi	doc_491521501746_item	3750810	et	0	main
rkm	doc_491521501746_item	3750811	et	0	main
ii	doc_491521501746_item	3750812	et	0	main
435	doc_491521501746_item	3750813	et	0	main
152153	doc_491521501746_item	3750814	et	0	main
7	doc_491521501746_item	3750815	et	0	main
nissi	doc_491521501746_item	3750816	et	0	main
v	doc_491521501746_item	3750817	et	0	main
odolemma	doc_491521501746_item	3750818	et	0	main
k	doc_491521501746_item	3750819	et	0	main
jaanijüri	doc_491521501746_item	3750820	et	0	main
t	doc_491521501746_item	3750821	et	0	main
kernu	doc_491521501746_item	3750822	et	0	main
v	doc_491521501746_item	3750823	et	0	main
miilima	doc_491521501746_item	3750824	et	0	main
k	doc_491521501746_item	3750825	et	0	main
mare	doc_491521501746_item	3750826	et	0	main
janneste	doc_491521501746_item	3750827	et	0	main
aliide	doc_491521501746_item	3750828	et	0	main
niinemaa	doc_491521501746_item	3750829	et	0	main
s	doc_491521501746_item	3750830	et	0	main
magnus	doc_491521501746_item	3750831	et	0	main
s	doc_491521501746_item	3750832	et	0	main
1919	doc_491521501746_item	3750833	et	0	main
a	doc_491521501746_item	3750834	et	0	main
august	doc_491521501746_item	3750835	et	0	main
niinemaa	doc_491521501746_item	3750836	et	0	main
s	doc_491521501746_item	3750837	et	0	main
1912	doc_491521501746_item	3750838	et	0	main
a	doc_491521501746_item	3750839	et	0	main
liidia	doc_491521501746_item	3750840	et	0	main
metsjõe	doc_491521501746_item	3750841	et	0	main
s	doc_491521501746_item	3750842	et	0	main
1942	doc_491521501746_item	3750843	et	0	main
a	doc_491521501746_item	3750844	et	0	main
eelmiste	doc_491521501746_item	3750845	et	0	main
tütar	doc_491521501746_item	3750846	et	0	main
1990	doc_491521501746_item	3750847	et	0	main
212	doc_491521501746_item	3750848	et	0	main
teed	doc_491521501746_item	3750849	et	0	main
sest	doc_491521501746_item	3750850	et	0	main
on	doc_491521501746_item	3750851	et	0	main
nüüd	doc_491521501746_item	3750852	et	0	main
kaua	doc_491521501746_item	3750853	et	0	main
aega	doc_491521501746_item	3750854	et	0	main
mööda	doc_491521501746_item	3750855	et	0	main
kui	doc_491521501746_item	3750856	et	0	main
ma	doc_491521501746_item	3750857	et	0	main
seal	doc_491521501746_item	3750858	et	0	main
varbola	doc_491521501746_item	3750859	et	0	main
linnuse	doc_491521501746_item	3750860	et	0	main
juures	doc_491521501746_item	3750861	et	0	main
käisin	doc_491521501746_item	3750862	et	0	main
seal	doc_491521501746_item	3750863	et	0	main
on	doc_491521501746_item	3750864	et	0	main
maa-alune	doc_491521501746_item	3750865	et	0	main
tee	doc_491521501746_item	3750866	et	0	main
olnud	doc_491521501746_item	3750867	et	0	main
varbola	doc_491521501746_item	3750868	et	0	main
maalinnast	doc_491521501746_item	3750869	et	0	main
algas	doc_491521501746_item	3750870	et	0	main
ja	doc_491521501746_item	3750871	et	0	main
tunda	doc_491521501746_item	3750872	et	0	main
oli	doc_491521501746_item	3750873	et	0	main
kõrgem	doc_491521501746_item	3750874	et	0	main
koht	doc_491521501746_item	3750875	et	0	main
oli	doc_491521501746_item	3750876	et	0	main
ta	doc_491521501746_item	3750877	et	0	main
läks	doc_491521501746_item	3750878	et	0	main
otse	doc_491521501746_item	3750879	et	0	main
ja	doc_491521501746_item	3750880	et	0	main
kui	doc_491521501746_item	3750881	et	0	main
ta	doc_491521501746_item	3750882	et	0	main
pidi	doc_491521501746_item	3750883	et	0	main
minema	doc_491521501746_item	3750884	et	0	main
sinna	doc_491521501746_item	3750885	et	0	main
hageri	doc_491521501746_item	3750886	et	0	main
taha	doc_491521501746_item	3750887	et	0	main
ta	doc_491521501746_item	3750888	et	0	main
ei	doc_491521501746_item	3750889	et	0	main
läind	doc_491521501746_item	3750890	et	0	main
kaugele	doc_491521501746_item	3750891	et	0	main
see	doc_491521501746_item	3750892	et	0	main
kõrgem	doc_491521501746_item	3750893	et	0	main
koht	doc_491521501746_item	3750894	et	0	main
aga	doc_491521501746_item	3750895	et	0	main
kristjani	doc_491521501746_item	3750896	et	0	main
heinamaa	doc_491521501746_item	3750897	et	0	main
kohal	doc_491521501746_item	3750898	et	0	main
oli	doc_491521501746_item	3750899	et	0	main
küll	doc_491521501746_item	3750900	et	0	main
näha	doc_491521501746_item	3750901	et	0	main
arvati	doc_491521501746_item	3750902	et	0	main
et	doc_491521501746_item	3750903	et	0	main
vanade	doc_491521501746_item	3750904	et	0	main
eestalaste	doc_491521501746_item	3750905	et	0	main
ehitatud	doc_491521501746_item	3750906	et	0	main
räägiti	doc_491521501746_item	3750907	et	0	main
et	doc_491521501746_item	3750908	et	0	main
seal	doc_491521501746_item	3750909	et	0	main
on	doc_491521501746_item	3750910	et	0	main
kalmukoht	doc_491521501746_item	3750911	et	0	main
ka	doc_491521501746_item	3750912	et	0	main
aga	doc_491521501746_item	3750913	et	0	main
ei	doc_491521501746_item	3750914	et	0	main
teatud	doc_491521501746_item	3750915	et	0	main
kus	doc_491521501746_item	3750916	et	0	main
aga	doc_491521501746_item	3750917	et	0	main
tartust	doc_491521501746_item	3750918	et	0	main
käidi	doc_491521501746_item	3750919	et	0	main
kaevamas	doc_491521501746_item	3750920	et	0	main
üks	doc_491521501746_item	3750921	et	0	main
magister	doc_491521501746_item	3750922	et	0	main
laid	doc_491521501746_item	3750923	et	0	main
siis	doc_491521501746_item	3750924	et	0	main
tuli	doc_491521501746_item	3750925	et	0	main
ehteid	doc_491521501746_item	3750926	et	0	main
ja	doc_491521501746_item	3750927	et	0	main
luid	doc_491521501746_item	3750928	et	0	main
ja	doc_491521501746_item	3750929	et	0	main
riidetükikesi	doc_491521501746_item	3750930	et	0	main
välja	doc_491521501746_item	3750931	et	0	main
kaev	doc_491521501746_item	3750932	et	0	main
oli	doc_491521501746_item	3750933	et	0	main
ka	doc_491521501746_item	3750934	et	0	main
seal	doc_491521501746_item	3750935	et	0	main
seda	doc_491521501746_item	3750936	et	0	main
peaks	doc_491521501746_item	3750937	et	0	main
kohe	doc_491521501746_item	3750938	et	0	main
vaatama	doc_491521501746_item	3750939	et	0	main
minema	doc_491521501746_item	3750940	et	0	main
sinna	doc_491521501746_item	3750941	et	0	main
rkm	doc_491521501746_item	3750942	et	0	main
ii	doc_491521501746_item	3750943	et	0	main
434	doc_491521501746_item	3750944	et	0	main
745	doc_491521501746_item	3750945	et	0	main
1	doc_491521501746_item	3750946	et	0	main
nissi	doc_491521501746_item	3750947	et	0	main
lehetu	doc_491521501746_item	3750948	et	0	main
k	doc_491521501746_item	3750949	et	0	main
pajaka	doc_491521501746_item	3750950	et	0	main
k	doc_491521501746_item	3750951	et	0	main
varbola	doc_491521501746_item	3750952	et	0	main
v	doc_491521501746_item	3750953	et	0	main
ja	doc_491521501746_item	3750954	et	0	main
k	doc_491521501746_item	3750955	et	0	main
mall	doc_491521501746_item	3750956	et	0	main
hiiemäe	doc_491521501746_item	3750957	et	0	main
hilda	doc_491521501746_item	3750958	et	0	main
nurmbek	doc_491521501746_item	3750959	et	0	main
s	doc_491521501746_item	3750960	et	0	main
1907	doc_491521501746_item	3750961	et	0	main
a	doc_491521501746_item	3750962	et	0	main
1990	doc_491521501746_item	3750963	et	0	main
maa-alune	doc_491521501746_item	3750964	et	0	main
käik	doc_491521501746_item	3750965	et	0	main
noh	doc_491521501746_item	3750966	et	0	main
siin	doc_491521501746_item	3750967	et	0	main
oli	doc_491521501746_item	3750968	et	0	main
kõmises	doc_491521501746_item	3750969	et	0	main
kus	doc_491521501746_item	3750970	et	0	main
see	doc_491521501746_item	3750971	et	0	main
park	doc_491521501746_item	3750972	et	0	main
oli	doc_491521501746_item	3750973	et	0	main
tee	doc_491521501746_item	3750974	et	0	main
käis	doc_491521501746_item	3750975	et	0	main
sealt	doc_491521501746_item	3750976	et	0	main
juurest	doc_491521501746_item	3750977	et	0	main
seal	doc_491521501746_item	3750978	et	0	main
olid	doc_491521501746_item	3750979	et	0	main
mingid	doc_491521501746_item	3750980	et	0	main
müürid	doc_491521501746_item	3750981	et	0	main
st	doc_491521501746_item	3750982	et	0	main
munalaskme	doc_491521501746_item	3750983	et	0	main
mõisa	doc_491521501746_item	3750984	et	0	main
pargis	doc_491521501746_item	3750985	et	0	main
jalaga	doc_491521501746_item	3750986	et	0	main
põrutasid	doc_491521501746_item	3750987	et	0	main
siis	doc_491521501746_item	3750988	et	0	main
kõmises	doc_491521501746_item	3750989	et	0	main
mingisugune	doc_491521501746_item	3750990	et	0	main
käik	doc_491521501746_item	3750991	et	0	main
oli	doc_491521501746_item	3750992	et	0	main
kes	doc_491521501746_item	3750993	et	0	main
seda	doc_491521501746_item	3750994	et	0	main
teab	doc_491521501746_item	3750995	et	0	main
enne	doc_491521501746_item	3750996	et	0	main
ta	doc_491521501746_item	3750997	et	0	main
oli	doc_491521501746_item	3750998	et	0	main
ilus	doc_491521501746_item	3750999	et	0	main
küll	doc_491521501746_item	3751000	et	0	main
st	doc_491521501746_item	3751001	et	0	main
mõisakoht	doc_491521501746_item	3751002	et	0	main
arvasid	doc_491521501746_item	3751003	et	0	main
et	doc_491521501746_item	3751004	et	0	main
ikka	doc_491521501746_item	3751005	et	0	main
seal	doc_491521501746_item	3751006	et	0	main
on	doc_491521501746_item	3751007	et	0	main
midagi	doc_491521501746_item	3751008	et	0	main
sisse	doc_491521501746_item	3751009	et	0	main
ta	doc_491521501746_item	3751010	et	0	main
varisend	doc_491521501746_item	3751011	et	0	main
ka	doc_491521501746_item	3751012	et	0	main
ei	doc_491521501746_item	3751013	et	0	main
ole	doc_491521501746_item	3751014	et	0	main
rkm	doc_491521501746_item	3751015	et	0	main
ii	doc_491521501746_item	3751016	et	0	main
435	doc_491521501746_item	3751017	et	0	main
100101	doc_491521501746_item	3751018	et	0	main
7	doc_491521501746_item	3751019	et	0	main
nissi	doc_491521501746_item	3751020	et	0	main
munalaskme	doc_491521501746_item	3751021	et	0	main
k	doc_491521501746_item	3751022	et	0	main
mare	doc_491521501746_item	3751023	et	0	main
janneste	doc_491521501746_item	3751024	et	0	main
alfred	doc_491521501746_item	3751025	et	0	main
vanatoa	doc_491521501746_item	3751026	et	0	main
s	doc_491521501746_item	3751027	et	0	main
1918	doc_491521501746_item	3751028	et	0	main
a	doc_491521501746_item	3751029	et	0	main
1990	doc_491521501746_item	3751030	et	0	main
maa-alust	doc_491521501746_item	3751031	et	0	main
käiku	doc_491521501746_item	3751032	et	0	main
ma	doc_491521501746_item	3751033	et	0	main
muud	doc_491521501746_item	3751034	et	0	main
pole	doc_491521501746_item	3751035	et	0	main
kuulnud	doc_491521501746_item	3751036	et	0	main
kui	doc_491521501746_item	3751037	et	0	main
kollu	doc_491521501746_item	3751038	et	0	main
kuristik	doc_491521501746_item	3751039	et	0	main
seal	doc_491521501746_item	3751040	et	0	main
on	doc_491521501746_item	3751041	et	0	main
mingi	doc_491521501746_item	3751042	et	0	main
kollu	doc_491521501746_item	3751043	et	0	main
talu	doc_491521501746_item	3751044	et	0	main
olnud	doc_491521501746_item	3751045	et	0	main
läks	doc_491521501746_item	3751046	et	0	main
kollust	doc_491521501746_item	3751047	et	0	main
maa	doc_491521501746_item	3751048	et	0	main
alla	doc_491521501746_item	3751049	et	0	main
ja	doc_491521501746_item	3751050	et	0	main
veetõusmest	doc_491521501746_item	3751051	et	0	main
tuli	doc_491521501746_item	3751052	et	0	main
maa	doc_491521501746_item	3751053	et	0	main
peale	doc_491521501746_item	3751054	et	0	main
ja	doc_491521501746_item	3751055	et	0	main
kiriku	doc_491521501746_item	3751056	et	0	main
alt	doc_491521501746_item	3751057	et	0	main
käis	doc_491521501746_item	3751058	et	0	main
läbi	doc_491521501746_item	3751059	et	0	main
kui	doc_491521501746_item	3751060	et	0	main
oli	doc_491521501746_item	3751061	et	0	main
hästi	doc_491521501746_item	3751062	et	0	main
kuuland	doc_491521501746_item	3751063	et	0	main
kõrva	doc_491521501746_item	3751064	et	0	main
vastu	doc_491521501746_item	3751065	et	0	main
maad	doc_491521501746_item	3751066	et	0	main
pand	doc_491521501746_item	3751067	et	0	main
kiriku	doc_491521501746_item	3751068	et	0	main
ukse	doc_491521501746_item	3751069	et	0	main
aall	doc_491521501746_item	3751070	et	0	main
siis	doc_491521501746_item	3751071	et	0	main
oli	doc_491521501746_item	3751072	et	0	main
kolinat	doc_491521501746_item	3751073	et	0	main
kuulnud	doc_491521501746_item	3751074	et	0	main
ega	doc_491521501746_item	3751075	et	0	main
ta	doc_491521501746_item	3751076	et	0	main
pikk	doc_491521501746_item	3751077	et	0	main
maa	doc_491521501746_item	3751078	et	0	main
ei	doc_491521501746_item	3751079	et	0	main
ole	doc_491521501746_item	3751080	et	0	main
neli-viis	doc_491521501746_item	3751081	et	0	main
kilomeetrit	doc_491521501746_item	3751082	et	0	main
kõige	doc_491521501746_item	3751083	et	0	main
rohkem	doc_491521501746_item	3751084	et	0	main
see	doc_491521501746_item	3751085	et	0	main
vist	doc_491521501746_item	3751086	et	0	main
tehtud	doc_491521501746_item	3751087	et	0	main
ei	doc_491521501746_item	3751088	et	0	main
ole	doc_491521501746_item	3751089	et	0	main
see	doc_491521501746_item	3751090	et	0	main
on	doc_491521501746_item	3751091	et	0	main
loodud	doc_491521501746_item	3751092	et	0	main
veesoon	doc_491521501746_item	3751093	et	0	main
aga	doc_491521501746_item	3751094	et	0	main
kellegi	doc_491521501746_item	3751095	et	0	main
härg	doc_491521501746_item	3751096	et	0	main
oli	doc_491521501746_item	3751097	et	0	main
küll	doc_491521501746_item	3751098	et	0	main
jäänud	doc_491521501746_item	3751099	et	0	main
sinna	doc_491521501746_item	3751100	et	0	main
ja	doc_491521501746_item	3751101	et	0	main
pealuu	doc_491521501746_item	3751102	et	0	main
koos	doc_491521501746_item	3751103	et	0	main
iketega	doc_491521501746_item	3751104	et	0	main
välja	doc_491521501746_item	3751105	et	0	main
tulnud	doc_491521501746_item	3751106	et	0	main
aali	doc_491521501746_item	3751107	et	0	main
oli	doc_491521501746_item	3751108	et	0	main
läind	doc_491521501746_item	3751109	et	0	main
sinna	doc_491521501746_item	3751110	et	0	main
ujuma	doc_491521501746_item	3751111	et	0	main
siis	doc_491521501746_item	3751112	et	0	main
old	doc_491521501746_item	3751113	et	0	main
tal	doc_491521501746_item	3751114	et	0	main
hirm	doc_491521501746_item	3751115	et	0	main
nahas	doc_491521501746_item	3751116	et	0	main
et	doc_491521501746_item	3751117	et	0	main
vool	doc_491521501746_item	3751118	et	0	main
viib	doc_491521501746_item	3751119	et	0	main
alla	doc_491521501746_item	3751120	et	0	main
ja	doc_491521501746_item	3751121	et	0	main
haned	doc_491521501746_item	3751122	et	0	main
olid	doc_491521501746_item	3751123	et	0	main
sealt	doc_491521501746_item	3751124	et	0	main
alla	doc_491521501746_item	3751125	et	0	main
läind	doc_491521501746_item	3751126	et	0	main
aga	doc_491521501746_item	3751127	et	0	main
kas	doc_491521501746_item	3751128	et	0	main
nad	doc_491521501746_item	3751129	et	0	main
välja	doc_491521501746_item	3751130	et	0	main
tulid	doc_491521501746_item	3751131	et	0	main
selle	doc_491521501746_item	3751132	et	0	main
kohta	doc_491521501746_item	3751133	et	0	main
ei	doc_491521501746_item	3751134	et	0	main
ole	doc_491521501746_item	3751135	et	0	main
andmeid	doc_491521501746_item	3751136	et	0	main
hiiemäe	doc_491521501746_item	3751137	et	0	main
rkm	doc_491521501746_item	3751138	et	0	main
ii	doc_491521501746_item	3751139	et	0	main
434	doc_491521501746_item	3751140	et	0	main
118119	doc_491521501746_item	3751141	et	0	main
2	doc_491521501746_item	3751142	et	0	main
riisipere	doc_491521501746_item	3751143	et	0	main
v	doc_491521501746_item	3751144	et	0	main
nurme	doc_491521501746_item	3751145	et	0	main
k	doc_491521501746_item	3751146	et	0	main
nissi	doc_491521501746_item	3751147	et	0	main
khk	doc_491521501746_item	3751148	et	0	main
lehetu	doc_491521501746_item	3751149	et	0	main
k	doc_491521501746_item	3751150	et	0	main
mall	doc_491521501746_item	3751151	et	0	main
hiiemäe	doc_491521501746_item	3751152	et	0	main
august	doc_491521501746_item	3751153	et	0	main
lehtme	doc_491521501746_item	3751154	et	0	main
s	doc_491521501746_item	3751155	et	0	main
1919	doc_491521501746_item	3751156	et	0	main
a	doc_491521501746_item	3751157	et	0	main
1990	doc_491521501746_item	3751158	et	0	main
kolovere	doc_491521501746_item	3751159	et	0	main
lossist	doc_491521501746_item	3751160	et	0	main
kullamaa	doc_491521501746_item	3751161	et	0	main
rohumäele	doc_491521501746_item	3751162	et	0	main
viib	doc_491521501746_item	3751163	et	0	main
maa-alune	doc_491521501746_item	3751164	et	0	main
tee	doc_491521501746_item	3751165	et	0	main
rkm	doc_491521501746_item	3751166	et	0	main
ii	doc_491521501746_item	3751167	et	0	main
435	doc_491521501746_item	3751168	et	0	main
220	doc_491521501746_item	3751169	et	0	main
1	doc_491521501746_item	3751170	et	0	main
nissi	doc_491521501746_item	3751171	et	0	main
turba	doc_491521501746_item	3751172	et	0	main
al	doc_491521501746_item	3751173	et	0	main
kullamaa	doc_491521501746_item	3751174	et	0	main
maidla	doc_491521501746_item	3751175	et	0	main
k	doc_491521501746_item	3751176	et	0	main
kadi	doc_491521501746_item	3751177	et	0	main
sarv	doc_491521501746_item	3751178	et	0	main
johannes	doc_491521501746_item	3751179	et	0	main
paulmann	doc_491521501746_item	3751180	et	0	main
s	doc_491521501746_item	3751181	et	0	main
1922	doc_491521501746_item	3751182	et	0	main
a	doc_491521501746_item	3751183	et	0	main
1990	doc_491521501746_item	3751184	et	0	main
seda	doc_491521501746_item	3751185	et	0	main
ka	doc_491521501746_item	3751186	et	0	main
olete	doc_491521501746_item	3751187	et	0	main
kuulnud	doc_491521501746_item	3751188	et	0	main
et	doc_491521501746_item	3751189	et	0	main
riisipere	doc_491521501746_item	3751190	et	0	main
mõisast	doc_491521501746_item	3751191	et	0	main
tuleb	doc_491521501746_item	3751192	et	0	main
salatee	doc_491521501746_item	3751193	et	0	main
nissi	doc_491521501746_item	3751194	et	0	main
eks	doc_491521501746_item	3751195	et	0	main
ikka	doc_491521501746_item	3751196	et	0	main
parunid	doc_491521501746_item	3751197	et	0	main
tegid	doc_491521501746_item	3751198	et	0	main
seda	doc_491521501746_item	3751199	et	0	main
rkm	doc_491521501746_item	3751200	et	0	main
ii	doc_491521501746_item	3751201	et	0	main
434	doc_491521501746_item	3751202	et	0	main
141	doc_491521501746_item	3751203	et	0	main
11	doc_491521501746_item	3751204	et	0	main
niisi	doc_491521501746_item	3751205	et	0	main
khk	doc_491521501746_item	3751206	et	0	main
riisipere	doc_491521501746_item	3751207	et	0	main
v	doc_491521501746_item	3751208	et	0	main
nurme	doc_491521501746_item	3751209	et	0	main
k	doc_491521501746_item	3751210	et	0	main
mall	doc_491521501746_item	3751211	et	0	main
hiiemäe	doc_491521501746_item	3751212	et	0	main
marta	doc_491521501746_item	3751213	et	0	main
ehrpais	doc_491521501746_item	3751214	et	0	main
82	doc_491521501746_item	3751215	et	0	main
a	doc_491521501746_item	3751216	et	0	main
1990	doc_491521501746_item	3751217	et	0	main
varbolas	doc_491521501746_item	3751218	et	0	main
on	doc_491521501746_item	3751219	et	0	main
jaanilinn	doc_491521501746_item	3751220	et	0	main
enne	doc_491521501746_item	3751221	et	0	main
olid	doc_491521501746_item	3751222	et	0	main
põllud	doc_491521501746_item	3751223	et	0	main
sees	doc_491521501746_item	3751224	et	0	main
suur	doc_491521501746_item	3751225	et	0	main
kaevuauk	doc_491521501746_item	3751226	et	0	main
on	doc_491521501746_item	3751227	et	0	main
see	doc_491521501746_item	3751228	et	0	main
üks	doc_491521501746_item	3751229	et	0	main
vana	doc_491521501746_item	3751230	et	0	main
kants	doc_491521501746_item	3751231	et	0	main
old	doc_491521501746_item	3751232	et	0	main
inimesed	doc_491521501746_item	3751233	et	0	main
käinud	doc_491521501746_item	3751234	et	0	main
röövimas	doc_491521501746_item	3751235	et	0	main
siis	doc_491521501746_item	3751236	et	0	main
andsid	doc_491521501746_item	3751237	et	0	main
kantsi	doc_491521501746_item	3751238	et	0	main
pealt	doc_491521501746_item	3751239	et	0	main
vaenlasele	doc_491521501746_item	3751240	et	0	main
valu	doc_491521501746_item	3751241	et	0	main
maaalused	doc_491521501746_item	3751242	et	0	main
teed	doc_491521501746_item	3751243	et	0	main
pidid	doc_491521501746_item	3751244	et	0	main
olema	doc_491521501746_item	3751245	et	0	main
pidi	doc_491521501746_item	3751246	et	0	main
märjamaa	doc_491521501746_item	3751247	et	0	main
juure	doc_491521501746_item	3751248	et	0	main
kõrgema	doc_491521501746_item	3751249	et	0	main
kõrsi	doc_491521501746_item	3751250	et	0	main
juure	doc_491521501746_item	3751251	et	0	main
välja	doc_491521501746_item	3751252	et	0	main
minema	doc_491521501746_item	3751253	et	0	main
teine	doc_491521501746_item	3751254	et	0	main
pidi	doc_491521501746_item	3751255	et	0	main
ohukotsa	doc_491521501746_item	3751256	et	0	main
mõisa	doc_491521501746_item	3751257	et	0	main
minema	doc_491521501746_item	3751258	et	0	main
seal	doc_491521501746_item	3751259	et	0	main
ots	doc_491521501746_item	3751260	et	0	main
ää	doc_491521501746_item	3751261	et	0	main
umistand	doc_491521501746_item	3751262	et	0	main
on	doc_491521501746_item	3751263	et	0	main
otsa	doc_491521501746_item	3751264	et	0	main
jääkelder	doc_491521501746_item	3751265	et	0	main
tehtud	doc_491521501746_item	3751266	et	0	main
era	doc_491521501746_item	3751267	et	0	main
ii	doc_491521501746_item	3751268	et	0	main
77	doc_491521501746_item	3751269	et	0	main
336337	doc_491521501746_item	3751270	et	0	main
2	doc_491521501746_item	3751271	et	0	main
hageri	doc_491521501746_item	3751272	et	0	main
v	doc_491521501746_item	3751273	et	0	main
hageri	doc_491521501746_item	3751274	et	0	main
vndk	doc_491521501746_item	3751275	et	0	main
põlli	doc_491521501746_item	3751276	et	0	main
k	doc_491521501746_item	3751277	et	0	main
varbola	doc_491521501746_item	3751278	et	0	main
v	doc_491521501746_item	3751279	et	0	main
nissi	doc_491521501746_item	3751280	et	0	main
rpõldmäe	doc_491521501746_item	3751281	et	0	main
jaagup	doc_491521501746_item	3751282	et	0	main
jäämann	doc_491521501746_item	3751283	et	0	main
70	doc_491521501746_item	3751284	et	0	main
a	doc_491521501746_item	3751285	et	0	main
1934	doc_491521501746_item	3751286	et	0	main
213	doc_491521501746_item	3751287	et	0	main
kalmed	doc_491521501746_item	3751288	et	0	main
suur	doc_491521501746_item	3751289	et	0	main
kalmekoht	doc_491521501746_item	3751290	et	0	main
on	doc_491521501746_item	3751291	et	0	main
siinsamas	doc_491521501746_item	3751292	et	0	main
lehetu	doc_491521501746_item	3751293	et	0	main
külas	doc_491521501746_item	3751294	et	0	main
siin	doc_491521501746_item	3751295	et	0	main
on	doc_491521501746_item	3751296	et	0	main
suur	doc_491521501746_item	3751297	et	0	main
matus	doc_491521501746_item	3751298	et	0	main
olnud	doc_491521501746_item	3751299	et	0	main
rkm	doc_491521501746_item	3751300	et	0	main
ii	doc_491521501746_item	3751301	et	0	main
434	doc_491521501746_item	3751302	et	0	main
734	doc_491521501746_item	3751303	et	0	main
3	doc_491521501746_item	3751304	et	0	main
nissi	doc_491521501746_item	3751305	et	0	main
khk	doc_491521501746_item	3751306	et	0	main
lehetu	doc_491521501746_item	3751307	et	0	main
k	doc_491521501746_item	3751308	et	0	main
mall	doc_491521501746_item	3751309	et	0	main
hiiemäe	doc_491521501746_item	3751310	et	0	main
leida	doc_491521501746_item	3751311	et	0	main
kivisäkk	doc_491521501746_item	3751312	et	0	main
s	doc_491521501746_item	3751313	et	0	main
1916	doc_491521501746_item	3751314	et	0	main
a	doc_491521501746_item	3751315	et	0	main
1990	doc_491521501746_item	3751316	et	0	main
paremat	doc_491521501746_item	3751317	et	0	main
kätt	doc_491521501746_item	3751318	et	0	main
enne	doc_491521501746_item	3751319	et	0	main
nurme	doc_491521501746_item	3751320	et	0	main
jõudmist	doc_491521501746_item	3751321	et	0	main
kus	doc_491521501746_item	3751322	et	0	main
on	doc_491521501746_item	3751323	et	0	main
see	doc_491521501746_item	3751324	et	0	main
väga	doc_491521501746_item	3751325	et	0	main
pikk	doc_491521501746_item	3751326	et	0	main
allee	doc_491521501746_item	3751327	et	0	main
seal	doc_491521501746_item	3751328	et	0	main
oli	doc_491521501746_item	3751329	et	0	main
vanasti	doc_491521501746_item	3751330	et	0	main
kivikangur	doc_491521501746_item	3751331	et	0	main
ja	doc_491521501746_item	3751332	et	0	main
mõisarehi	doc_491521501746_item	3751333	et	0	main
eesti	doc_491521501746_item	3751334	et	0	main
ajal	doc_491521501746_item	3751335	et	0	main
see	doc_491521501746_item	3751336	et	0	main
oli	doc_491521501746_item	3751337	et	0	main
muinsuskaitse	doc_491521501746_item	3751338	et	0	main
all	doc_491521501746_item	3751339	et	0	main
seal	doc_491521501746_item	3751340	et	0	main
on	doc_491521501746_item	3751341	et	0	main
suured	doc_491521501746_item	3751342	et	0	main
tugevad	doc_491521501746_item	3751343	et	0	main
kivid	doc_491521501746_item	3751344	et	0	main
matuse	doc_491521501746_item	3751345	et	0	main
paik	doc_491521501746_item	3751346	et	0	main
on	doc_491521501746_item	3751347	et	0	main
see	doc_491521501746_item	3751348	et	0	main
aga	doc_491521501746_item	3751349	et	0	main
muud	doc_491521501746_item	3751350	et	0	main
juttu	doc_491521501746_item	3751351	et	0	main
ei	doc_491521501746_item	3751352	et	0	main
tea	doc_491521501746_item	3751353	et	0	main
rkm	doc_491521501746_item	3751354	et	0	main
ii	doc_491521501746_item	3751355	et	0	main
434	doc_491521501746_item	3751356	et	0	main
155156	doc_491521501746_item	3751357	et	0	main
36	doc_491521501746_item	3751358	et	0	main
nissi	doc_491521501746_item	3751359	et	0	main
khk	doc_491521501746_item	3751360	et	0	main
riisipere	doc_491521501746_item	3751361	et	0	main
v	doc_491521501746_item	3751362	et	0	main
nurme	doc_491521501746_item	3751363	et	0	main
k	doc_491521501746_item	3751364	et	0	main
mall	doc_491521501746_item	3751365	et	0	main
hiiemäe	doc_491521501746_item	3751366	et	0	main
marta	doc_491521501746_item	3751367	et	0	main
ehrpais	doc_491521501746_item	3751368	et	0	main
82	doc_491521501746_item	3751369	et	0	main
a	doc_491521501746_item	3751370	et	0	main
19909	doc_491521501746_item	3751371	et	0	main
nurme	doc_491521501746_item	3751372	et	0	main
allee	doc_491521501746_item	3751373	et	0	main
nurme	doc_491521501746_item	3751374	et	0	main
külas	doc_491521501746_item	3751375	et	0	main
põllu	doc_491521501746_item	3751376	et	0	main
sees	doc_491521501746_item	3751377	et	0	main
mõisarehe	doc_491521501746_item	3751378	et	0	main
lähedal	doc_491521501746_item	3751379	et	0	main
vana-vana	doc_491521501746_item	3751380	et	0	main
maja	doc_491521501746_item	3751381	et	0	main
ja	doc_491521501746_item	3751382	et	0	main
üks	doc_491521501746_item	3751383	et	0	main
väike	doc_491521501746_item	3751384	et	0	main
maja	doc_491521501746_item	3751385	et	0	main
seal	doc_491521501746_item	3751386	et	0	main
külje	doc_491521501746_item	3751387	et	0	main
all	doc_491521501746_item	3751388	et	0	main
seal	doc_491521501746_item	3751389	et	0	main
olevatki	doc_491521501746_item	3751390	et	0	main
vana	doc_491521501746_item	3751391	et	0	main
kalmekoht	doc_491521501746_item	3751392	et	0	main
seal	doc_491521501746_item	3751393	et	0	main
on	doc_491521501746_item	3751394	et	0	main
luid	doc_491521501746_item	3751395	et	0	main
ka	doc_491521501746_item	3751396	et	0	main
leitud	doc_491521501746_item	3751397	et	0	main
rkm	doc_491521501746_item	3751398	et	0	main
ii	doc_491521501746_item	3751399	et	0	main
434	doc_491521501746_item	3751400	et	0	main
113114	doc_491521501746_item	3751401	et	0	main
64	doc_491521501746_item	3751402	et	0	main
nissi	doc_491521501746_item	3751403	et	0	main
khk	doc_491521501746_item	3751404	et	0	main
riisipere	doc_491521501746_item	3751405	et	0	main
v	doc_491521501746_item	3751406	et	0	main
terjatu	doc_491521501746_item	3751407	et	0	main
k	doc_491521501746_item	3751408	et	0	main
mall	doc_491521501746_item	3751409	et	0	main
hiiemäe	doc_491521501746_item	3751410	et	0	main
linda	doc_491521501746_item	3751411	et	0	main
linroos	doc_491521501746_item	3751412	et	0	main
s	doc_491521501746_item	3751413	et	0	main
1924	doc_491521501746_item	3751414	et	0	main
a	doc_491521501746_item	3751415	et	0	main
1990	doc_491521501746_item	3751416	et	0	main
saida	doc_491521501746_item	3751417	et	0	main
kõrtsu	doc_491521501746_item	3751418	et	0	main
ligidalt	doc_491521501746_item	3751419	et	0	main
leiti	doc_491521501746_item	3751420	et	0	main
vanu	doc_491521501746_item	3751421	et	0	main
surnukonta	doc_491521501746_item	3751422	et	0	main
seal	doc_491521501746_item	3751423	et	0	main
ligidal	doc_491521501746_item	3751424	et	0	main
on	doc_491521501746_item	3751425	et	0	main
kolju	doc_491521501746_item	3751426	et	0	main
pere	doc_491521501746_item	3751427	et	0	main
ja	doc_491521501746_item	3751428	et	0	main
koolja	doc_491521501746_item	3751429	et	0	main
mets	doc_491521501746_item	3751430	et	0	main
tea	doc_491521501746_item	3751431	et	0	main
kas	doc_491521501746_item	3751432	et	0	main
ta	doc_491521501746_item	3751433	et	0	main
on	doc_491521501746_item	3751434	et	0	main
siis	doc_491521501746_item	3751435	et	0	main
kooljast	doc_491521501746_item	3751436	et	0	main
või	doc_491521501746_item	3751437	et	0	main
kooljas	doc_491521501746_item	3751438	et	0	main
tähendab	doc_491521501746_item	3751439	et	0	main
siin	doc_491521501746_item	3751440	et	0	main
surnut	doc_491521501746_item	3751441	et	0	main
niisugune	doc_491521501746_item	3751442	et	0	main
surnu	doc_491521501746_item	3751443	et	0	main
kes	doc_491521501746_item	3751444	et	0	main
rahulikult	doc_491521501746_item	3751445	et	0	main
surnud	doc_491521501746_item	3751446	et	0	main
ei	doc_491521501746_item	3751447	et	0	main
ole	doc_491521501746_item	3751448	et	0	main
era	doc_491521501746_item	3751449	et	0	main
ii	doc_491521501746_item	3751450	et	0	main
27	doc_491521501746_item	3751451	et	0	main
266	doc_491521501746_item	3751452	et	0	main
51	doc_491521501746_item	3751453	et	0	main
nissi	doc_491521501746_item	3751454	et	0	main
khk	doc_491521501746_item	3751455	et	0	main
laitse	doc_491521501746_item	3751456	et	0	main
vld	doc_491521501746_item	3751457	et	0	main
kubuna	doc_491521501746_item	3751458	et	0	main
kl	doc_491521501746_item	3751459	et	0	main
kaasiku	doc_491521501746_item	3751460	et	0	main
talu	doc_491521501746_item	3751461	et	0	main
riisipere	doc_491521501746_item	3751462	et	0	main
v	doc_491521501746_item	3751463	et	0	main
nurme	doc_491521501746_item	3751464	et	0	main
k	doc_491521501746_item	3751465	et	0	main
rpõldmäe	doc_491521501746_item	3751466	et	0	main
tõnu	doc_491521501746_item	3751467	et	0	main
evald	doc_491521501746_item	3751468	et	0	main
66	doc_491521501746_item	3751469	et	0	main
a	doc_491521501746_item	3751470	et	0	main
1930	doc_491521501746_item	3751471	et	0	main
siin	doc_491521501746_item	3751472	et	0	main
lehetus	doc_491521501746_item	3751473	et	0	main
lehtmetsa	doc_491521501746_item	3751474	et	0	main
põllu	doc_491521501746_item	3751475	et	0	main
mägi	doc_491521501746_item	3751476	et	0	main
seal	doc_491521501746_item	3751477	et	0	main
tuli	doc_491521501746_item	3751478	et	0	main
küll	doc_491521501746_item	3751479	et	0	main
luid	doc_491521501746_item	3751480	et	0	main
välja	doc_491521501746_item	3751481	et	0	main
mida	doc_491521501746_item	3751482	et	0	main
rohkem	doc_491521501746_item	3751483	et	0	main
sinna	doc_491521501746_item	3751484	et	0	main
mäe	doc_491521501746_item	3751485	et	0	main
poole	doc_491521501746_item	3751486	et	0	main
mindi	doc_491521501746_item	3751487	et	0	main
seda	doc_491521501746_item	3751488	et	0	main
rohkem	doc_491521501746_item	3751489	et	0	main
surnuluid	doc_491521501746_item	3751490	et	0	main
sealt	doc_491521501746_item	3751491	et	0	main
välja	doc_491521501746_item	3751492	et	0	main
tuli	doc_491521501746_item	3751493	et	0	main
ja	doc_491521501746_item	3751494	et	0	main
odaotsi	doc_491521501746_item	3751495	et	0	main
ja	doc_491521501746_item	3751496	et	0	main
kõiki	doc_491521501746_item	3751497	et	0	main
seda	doc_491521501746_item	3751498	et	0	main
jüri	doc_491521501746_item	3751499	et	0	main
ütles	doc_491521501746_item	3751500	et	0	main
et	doc_491521501746_item	3751501	et	0	main
kui	doc_491521501746_item	3751502	et	0	main
ta	doc_491521501746_item	3751503	et	0	main
püsti	doc_491521501746_item	3751504	et	0	main
tõstis	doc_491521501746_item	3751505	et	0	main
siis	doc_491521501746_item	3751506	et	0	main
tema	doc_491521501746_item	3751507	et	0	main
oli	doc_491521501746_item	3751508	et	0	main
luukerele	doc_491521501746_item	3751509	et	0	main
püksivärvlist	doc_491521501746_item	3751510	et	0	main
saadik	doc_491521501746_item	3751511	et	0	main
no	doc_491521501746_item	3751512	et	0	main
ta	doc_491521501746_item	3751513	et	0	main
oli	doc_491521501746_item	3751514	et	0	main
küll	doc_491521501746_item	3751515	et	0	main
lühike	doc_491521501746_item	3751516	et	0	main
mees	doc_491521501746_item	3751517	et	0	main
eesti	doc_491521501746_item	3751518	et	0	main
ajal	doc_491521501746_item	3751519	et	0	main
oli	doc_491521501746_item	3751520	et	0	main
keelatud	doc_491521501746_item	3751521	et	0	main
seal	doc_491521501746_item	3751522	et	0	main
igasugune	doc_491521501746_item	3751523	et	0	main
kaevamine	doc_491521501746_item	3751524	et	0	main
aga	doc_491521501746_item	3751525	et	0	main
nüüd	doc_491521501746_item	3751526	et	0	main
ei	doc_491521501746_item	3751527	et	0	main
ole	doc_491521501746_item	3751528	et	0	main
hoolitud	doc_491521501746_item	3751529	et	0	main
rahvas	doc_491521501746_item	3751530	et	0	main
arvas	doc_491521501746_item	3751531	et	0	main
et	doc_491521501746_item	3751532	et	0	main
ikka	doc_491521501746_item	3751533	et	0	main
põhjasõja	doc_491521501746_item	3751534	et	0	main
aegne	doc_491521501746_item	3751535	et	0	main
oli	doc_491521501746_item	3751536	et	0	main
see	doc_491521501746_item	3751537	et	0	main
rkm	doc_491521501746_item	3751538	et	0	main
ii	doc_491521501746_item	3751539	et	0	main
434	doc_491521501746_item	3751540	et	0	main
124	doc_491521501746_item	3751541	et	0	main
14	doc_491521501746_item	3751542	et	0	main
riisipere	doc_491521501746_item	3751543	et	0	main
v	doc_491521501746_item	3751544	et	0	main
nurme	doc_491521501746_item	3751545	et	0	main
k	doc_491521501746_item	3751546	et	0	main
nissi	doc_491521501746_item	3751547	et	0	main
khk	doc_491521501746_item	3751548	et	0	main
lehetu	doc_491521501746_item	3751549	et	0	main
k	doc_491521501746_item	3751550	et	0	main
mall	doc_491521501746_item	3751551	et	0	main
hiiemäe	doc_491521501746_item	3751552	et	0	main
august	doc_491521501746_item	3751553	et	0	main
lehtme	doc_491521501746_item	3751554	et	0	main
s	doc_491521501746_item	3751555	et	0	main
1919	doc_491521501746_item	3751556	et	0	main
a	doc_491521501746_item	3751557	et	0	main
1990	doc_491521501746_item	3751558	et	0	main
22	doc_491521501746_item	3751559	et	0	main
ajaloolised	doc_491521501746_item	3751560	et	0	main
muistendid	doc_491521501746_item	3751561	et	0	main
ajaloolised	doc_491521501746_item	3751562	et	0	main
muistendid	doc_491521501746_item	3751563	et	0	main
sisaldavad	doc_491521501746_item	3751564	et	0	main
tekste	doc_491521501746_item	3751565	et	0	main
ajaloolise	doc_491521501746_item	3751566	et	0	main
sündmuste	doc_491521501746_item	3751567	et	0	main
või	doc_491521501746_item	3751568	et	0	main
isikutega	doc_491521501746_item	3751569	et	0	main
ajaloolistest	doc_491521501746_item	3751570	et	0	main
muistenditest	doc_491521501746_item	3751571	et	0	main
mahukamaid	doc_491521501746_item	3751572	et	0	main
rühmi	doc_491521501746_item	3751573	et	0	main
moodustavad	doc_491521501746_item	3751574	et	0	main
katkumuistendid	doc_491521501746_item	3751575	et	0	main
ja	doc_491521501746_item	3751576	et	0	main
muistendid	doc_491521501746_item	3751577	et	0	main
sõjaröövlitest	doc_491521501746_item	3751578	et	0	main
katku	doc_491521501746_item	3751579	et	0	main
tekitajaks	doc_491521501746_item	3751580	et	0	main
pidas	doc_491521501746_item	3751581	et	0	main
rahvas	doc_491521501746_item	3751582	et	0	main
katkuhaldjat	doc_491521501746_item	3751583	et	0	main
deemonit	doc_491521501746_item	3751584	et	0	main
katku	doc_491521501746_item	3751585	et	0	main
on	doc_491521501746_item	3751586	et	0	main
eestlaste	doc_491521501746_item	3751587	et	0	main
alal	doc_491521501746_item	3751588	et	0	main
esinenud	doc_491521501746_item	3751589	et	0	main
palju	doc_491521501746_item	3751590	et	0	main
katkihaldjas	doc_491521501746_item	3751591	et	0	main
võis	doc_491521501746_item	3751592	et	0	main
rahva	doc_491521501746_item	3751593	et	0	main
kujutelmades	doc_491521501746_item	3751594	et	0	main
ilmuda	doc_491521501746_item	3751595	et	0	main
mitmel	doc_491521501746_item	3751596	et	0	main
kujul	doc_491521501746_item	3751597	et	0	main
kõige	doc_491521501746_item	3751598	et	0	main
sagedamini	doc_491521501746_item	3751599	et	0	main
inimesena	doc_491521501746_item	3751600	et	0	main
väikse	doc_491521501746_item	3751601	et	0	main
poisina	doc_491521501746_item	3751602	et	0	main
või	doc_491521501746_item	3751603	et	0	main
habemiku	doc_491521501746_item	3751604	et	0	main
vanamehena	doc_491521501746_item	3751605	et	0	main
kes	doc_491521501746_item	3751606	et	0	main
torkab	doc_491521501746_item	3751607	et	0	main
oma	doc_491521501746_item	3751608	et	0	main
kepiga	doc_491521501746_item	3751609	et	0	main
magajaid	doc_491521501746_item	3751610	et	0	main
kes	doc_491521501746_item	3751611	et	0	main
sellest	doc_491521501746_item	3751612	et	0	main
surevad	doc_491521501746_item	3751613	et	0	main
vahel	doc_491521501746_item	3751614	et	0	main
sureb	doc_491521501746_item	3751615	et	0	main
inimene	doc_491521501746_item	3751616	et	0	main
ainult	doc_491521501746_item	3751617	et	0	main
musta	doc_491521501746_item	3751618	et	0	main
mehe	doc_491521501746_item	3751619	et	0	main
nägemisest	doc_491521501746_item	3751620	et	0	main
musta	doc_491521501746_item	3751621	et	0	main
mehe	doc_491521501746_item	3751622	et	0	main
kuju	doc_491521501746_item	3751623	et	0	main
järgi	doc_491521501746_item	3751624	et	0	main
on	doc_491521501746_item	3751625	et	0	main
katk	doc_491521501746_item	3751626	et	0	main
saanud	doc_491521501746_item	3751627	et	0	main
ka	doc_491521501746_item	3751628	et	0	main
nimetuse	doc_491521501746_item	3751629	et	0	main
must	doc_491521501746_item	3751630	et	0	main
surm	doc_491521501746_item	3751631	et	0	main
katku	doc_491521501746_item	3751632	et	0	main
ohvriks	doc_491521501746_item	3751633	et	0	main
langevad	doc_491521501746_item	3751634	et	0	main
magajad	doc_491521501746_item	3751635	et	0	main
ärkvel	doc_491521501746_item	3751636	et	0	main
olijad	doc_491521501746_item	3751637	et	0	main
jäävad	doc_491521501746_item	3751638	et	0	main
ellu	doc_491521501746_item	3751639	et	0	main
katkuhaldjas	doc_491521501746_item	3751640	et	0	main
võib	doc_491521501746_item	3751641	et	0	main
ilmuda	doc_491521501746_item	3751642	et	0	main
looma	doc_491521501746_item	3751643	et	0	main
või	doc_491521501746_item	3751644	et	0	main
linnu	doc_491521501746_item	3751645	et	0	main
kujul	doc_491521501746_item	3751646	et	0	main
katkuhaldja	doc_491521501746_item	3751647	et	0	main
käest	doc_491521501746_item	3751648	et	0	main
pääseb	doc_491521501746_item	3751649	et	0	main
siirdumisega	doc_491521501746_item	3751650	et	0	main
eraldatud	doc_491521501746_item	3751651	et	0	main
kohta	doc_491521501746_item	3751652	et	0	main
metsa	doc_491521501746_item	3751653	et	0	main
vete	doc_491521501746_item	3751654	et	0	main
taha	doc_491521501746_item	3751655	et	0	main
toomingapõõsasse	doc_491521501746_item	3751656	et	0	main
või	doc_491521501746_item	3751657	et	0	main
selle	doc_491521501746_item	3751658	et	0	main
ligidusse	doc_491521501746_item	3751659	et	0	main
nakust	doc_491521501746_item	3751660	et	0	main
takistab	doc_491521501746_item	3751661	et	0	main
ka	doc_491521501746_item	3751662	et	0	main
elukoha	doc_491521501746_item	3751663	et	0	main
vahetamine	doc_491521501746_item	3751664	et	0	main
tõrjeks	doc_491521501746_item	3751665	et	0	main
aitab	doc_491521501746_item	3751666	et	0	main
vahel	doc_491521501746_item	3751667	et	0	main
ka	doc_491521501746_item	3751668	et	0	main
sõnamaagia	doc_491521501746_item	3751669	et	0	main
nagu	doc_491521501746_item	3751670	et	0	main
seegi	doc_491521501746_item	3751671	et	0	main
kui	doc_491521501746_item	3751672	et	0	main
tema	doc_491521501746_item	3751673	et	0	main
tulekul	doc_491521501746_item	3751674	et	0	main
inimesed	doc_491521501746_item	3751675	et	0	main
söövad	doc_491521501746_item	3751676	et	0	main
rõõska	doc_491521501746_item	3751677	et	0	main
piima	doc_491521501746_item	3751678	et	0	main
või	doc_491521501746_item	3751679	et	0	main
liha	doc_491521501746_item	3751680	et	0	main
soolavett	doc_491521501746_item	3751681	et	0	main
katkupärimus	doc_491521501746_item	3751682	et	0	main
on	doc_491521501746_item	3751683	et	0	main
tihti	doc_491521501746_item	3751684	et	0	main
seotud	doc_491521501746_item	3751685	et	0	main
rahva	doc_491521501746_item	3751686	et	0	main
mõisnikevastase	doc_491521501746_item	3751687	et	0	main
hoiakuga	doc_491521501746_item	3751688	et	0	main
mis	doc_491521501746_item	3751689	et	0	main
ilmneb	doc_491521501746_item	3751690	et	0	main
ka	doc_491521501746_item	3751691	et	0	main
rahvalauludes	doc_491521501746_item	3751692	et	0	main
või	doc_491521501746_item	3751693	et	0	main
naljandites	doc_491521501746_item	3751694	et	0	main
mõisnike	doc_491521501746_item	3751695	et	0	main
isegi	doc_491521501746_item	3751696	et	0	main
kahtlustati	doc_491521501746_item	3751697	et	0	main
katku	doc_491521501746_item	3751698	et	0	main
saatmises	doc_491521501746_item	3751699	et	0	main
talurahvale	doc_491521501746_item	3751700	et	0	main
mõisnike	doc_491521501746_item	3751701	et	0	main
käsilased	doc_491521501746_item	3751702	et	0	main
liikuvat	doc_491521501746_item	3751703	et	0	main
maal	doc_491521501746_item	3751704	et	0	main
kihvtiandjatena	doc_491521501746_item	3751705	et	0	main
kes	doc_491521501746_item	3751706	et	0	main
olevat	doc_491521501746_item	3751707	et	0	main
puistanud	doc_491521501746_item	3751708	et	0	main
katku	doc_491521501746_item	3751709	et	0	main
tekitevat	doc_491521501746_item	3751710	et	0	main
pulbrit	doc_491521501746_item	3751711	et	0	main
et	doc_491521501746_item	3751712	et	0	main
talupoegade	doc_491521501746_item	3751713	et	0	main
hävitamisega	doc_491521501746_item	3751714	et	0	main
nende	doc_491521501746_item	3751715	et	0	main
varandust	doc_491521501746_item	3751716	et	0	main
endale	doc_491521501746_item	3751717	et	0	main
saada	doc_491521501746_item	3751718	et	0	main
mõisnikke	doc_491521501746_item	3751719	et	0	main
peeti	doc_491521501746_item	3751720	et	0	main
ka	doc_491521501746_item	3751721	et	0	main
koolerakülvajaiks	doc_491521501746_item	3751722	et	0	main
nissi	doc_491521501746_item	3751723	et	0	main
kihelkonnas	doc_491521501746_item	3751724	et	0	main
on	doc_491521501746_item	3751725	et	0	main
katkuga	doc_491521501746_item	3751726	et	0	main
seotuid	doc_491521501746_item	3751727	et	0	main
muistendeid	doc_491521501746_item	3751728	et	0	main
päris	doc_491521501746_item	3751729	et	0	main
palju	doc_491521501746_item	3751730	et	0	main
selles	doc_491521501746_item	3751731	et	0	main
töös	doc_491521501746_item	3751732	et	0	main
nad	doc_491521501746_item	3751733	et	0	main
on	doc_491521501746_item	3751734	et	0	main
esitatud	doc_491521501746_item	3751735	et	0	main
selle	doc_491521501746_item	3751736	et	0	main
põhimõte	doc_491521501746_item	3751737	et	0	main
järgi	doc_491521501746_item	3751738	et	0	main
mis	doc_491521501746_item	3751739	et	0	main
on	doc_491521501746_item	3751740	et	0	main
kasutusel	doc_491521501746_item	3751741	et	0	main
olnud	doc_491521501746_item	3751742	et	0	main
mall	doc_491521501746_item	3751743	et	0	main
hiiemäe	doc_491521501746_item	3751744	et	0	main
raamatus	doc_491521501746_item	3751745	et	0	main
eesti	doc_491521501746_item	3751746	et	0	main
katkupärimus	doc_491521501746_item	3751747	et	0	main
221	doc_491521501746_item	3751748	et	0	main
katk	doc_491521501746_item	3751749	et	0	main
kui	doc_491521501746_item	3751750	et	0	main
haigus	doc_491521501746_item	3751751	et	0	main
rahvapärased	doc_491521501746_item	3751752	et	0	main
ravimid	doc_491521501746_item	3751753	et	0	main
katku	doc_491521501746_item	3751754	et	0	main
oli	doc_491521501746_item	3751755	et	0	main
olnud	doc_491521501746_item	3751756	et	0	main
alati	doc_491521501746_item	3751757	et	0	main
inimesed	doc_491521501746_item	3751758	et	0	main
surnud	doc_491521501746_item	3751759	et	0	main
veri	doc_491521501746_item	3751760	et	0	main
käis	doc_491521501746_item	3751761	et	0	main
läbi	doc_491521501746_item	3751762	et	0	main
kõhutõbe	doc_491521501746_item	3751763	et	0	main
moodi	doc_491521501746_item	3751764	et	0	main
oli	doc_491521501746_item	3751765	et	0	main
see	doc_491521501746_item	3751766	et	0	main
on	doc_491521501746_item	3751767	et	0	main
nagu	doc_491521501746_item	3751768	et	0	main
koleera	doc_491521501746_item	3751769	et	0	main
ütlesid	doc_491521501746_item	3751770	et	0	main
ikka	doc_491521501746_item	3751771	et	0	main
nagu	doc_491521501746_item	3751772	et	0	main
katkuaegas	doc_491521501746_item	3751773	et	0	main
soolast	doc_491521501746_item	3751774	et	0	main
ei	doc_491521501746_item	3751775	et	0	main
kästud	doc_491521501746_item	3751776	et	0	main
süia	doc_491521501746_item	3751777	et	0	main
aga	doc_491521501746_item	3751778	et	0	main
mõni	doc_491521501746_item	3751779	et	0	main
söönd	doc_491521501746_item	3751780	et	0	main
lihasoolvett	doc_491521501746_item	3751781	et	0	main
see	doc_491521501746_item	3751782	et	0	main
oli	doc_491521501746_item	3751783	et	0	main
aidanud	doc_491521501746_item	3751784	et	0	main
küll	doc_491521501746_item	3751785	et	0	main
aga	doc_491521501746_item	3751786	et	0	main
seda	doc_491521501746_item	3751787	et	0	main
ei	doc_491521501746_item	3751788	et	0	main
kästud	doc_491521501746_item	3751789	et	0	main
võtta	doc_491521501746_item	3751790	et	0	main
era	doc_491521501746_item	3751791	et	0	main
ii	doc_491521501746_item	3751792	et	0	main
192	doc_491521501746_item	3751793	et	0	main
531	doc_491521501746_item	3751794	et	0	main
103	doc_491521501746_item	3751795	et	0	main
nissi	doc_491521501746_item	3751796	et	0	main
khk	doc_491521501746_item	3751797	et	0	main
riisipere	doc_491521501746_item	3751798	et	0	main
v	doc_491521501746_item	3751799	et	0	main
vndk	doc_491521501746_item	3751800	et	0	main
r	doc_491521501746_item	3751801	et	0	main
põldmäe	doc_491521501746_item	3751802	et	0	main
ann	doc_491521501746_item	3751803	et	0	main
umberg	doc_491521501746_item	3751804	et	0	main
83	doc_491521501746_item	3751805	et	0	main
a	doc_491521501746_item	3751806	et	0	main
1938	doc_491521501746_item	3751807	et	0	main
lk	doc_491521501746_item	3751808	et	0	main
96	doc_491521501746_item	3751809	et	0	main
katkukülvaja	doc_491521501746_item	3751810	et	0	main
katkutoovat	doc_491521501746_item	3751811	et	0	main
ainet	doc_491521501746_item	3751812	et	0	main
kihvti	doc_491521501746_item	3751813	et	0	main
külvatakse	doc_491521501746_item	3751814	et	0	main
mõni	doc_491521501746_item	3751815	et	0	main
arbas	doc_491521501746_item	3751816	et	0	main
ikka	doc_491521501746_item	3751817	et	0	main
et	doc_491521501746_item	3751818	et	0	main
pidi	doc_491521501746_item	3751819	et	0	main
tehtud	doc_491521501746_item	3751820	et	0	main
luht	doc_491521501746_item	3751821	et	0	main
olema	doc_491521501746_item	3751822	et	0	main
pidi	doc_491521501746_item	3751823	et	0	main
välla	doc_491521501746_item	3751824	et	0	main
viskama	doc_491521501746_item	3751825	et	0	main
kihti	doc_491521501746_item	3751826	et	0	main
siis	doc_491521501746_item	3751827	et	0	main
pidi	doc_491521501746_item	3751828	et	0	main
loomakatku	doc_491521501746_item	3751829	et	0	main
olema	doc_491521501746_item	3751830	et	0	main
lk	doc_491521501746_item	3751831	et	0	main
109	doc_491521501746_item	3751832	et	0	main
era	doc_491521501746_item	3751833	et	0	main
ii	doc_491521501746_item	3751834	et	0	main
27	doc_491521501746_item	3751835	et	0	main
220	doc_491521501746_item	3751836	et	0	main
10	doc_491521501746_item	3751837	et	0	main
nissi	doc_491521501746_item	3751838	et	0	main
khk	doc_491521501746_item	3751839	et	0	main
kibuna	doc_491521501746_item	3751840	et	0	main
k	doc_491521501746_item	3751841	et	0	main
r	doc_491521501746_item	3751842	et	0	main
põldmäe	doc_491521501746_item	3751843	et	0	main
jaagup	doc_491521501746_item	3751844	et	0	main
einberg	doc_491521501746_item	3751845	et	0	main
79	doc_491521501746_item	3751846	et	0	main
a	doc_491521501746_item	3751847	et	0	main
1930	doc_491521501746_item	3751848	et	0	main
mõisnikud	doc_491521501746_item	3751849	et	0	main
külvavad	doc_491521501746_item	3751850	et	0	main
katku	doc_491521501746_item	3751851	et	0	main
usti	doc_491521501746_item	3751852	et	0	main
et	doc_491521501746_item	3751853	et	0	main
kihvtitegijad	doc_491521501746_item	3751854	et	0	main
pidid	doc_491521501746_item	3751855	et	0	main
olema	doc_491521501746_item	3751856	et	0	main
mõisnikud	doc_491521501746_item	3751857	et	0	main
pidid	doc_491521501746_item	3751858	et	0	main
olema	doc_491521501746_item	3751859	et	0	main
koleerat	doc_491521501746_item	3751860	et	0	main
ja	doc_491521501746_item	3751861	et	0	main
katku	doc_491521501746_item	3751862	et	0	main
peeti	doc_491521501746_item	3751863	et	0	main
inimeste	doc_491521501746_item	3751864	et	0	main
tegemiseks	doc_491521501746_item	3751865	et	0	main
era	doc_491521501746_item	3751866	et	0	main
ii	doc_491521501746_item	3751867	et	0	main
27	doc_491521501746_item	3751868	et	0	main
261242	doc_491521501746_item	3751869	et	0	main
nissi	doc_491521501746_item	3751870	et	0	main
khk	doc_491521501746_item	3751871	et	0	main
laitse	doc_491521501746_item	3751872	et	0	main
v	doc_491521501746_item	3751873	et	0	main
kibuna	doc_491521501746_item	3751874	et	0	main
k	doc_491521501746_item	3751875	et	0	main
r	doc_491521501746_item	3751876	et	0	main
põldmäe	doc_491521501746_item	3751877	et	0	main
tõnu	doc_491521501746_item	3751878	et	0	main
evald	doc_491521501746_item	3751879	et	0	main
66	doc_491521501746_item	3751880	et	0	main
a	doc_491521501746_item	3751881	et	0	main
1930	doc_491521501746_item	3751882	et	0	main
lk	doc_491521501746_item	3751883	et	0	main
114	doc_491521501746_item	3751884	et	0	main
4	doc_491521501746_item	3751885	et	0	main
muud	doc_491521501746_item	3751886	et	0	main
katkulevitajad	doc_491521501746_item	3751887	et	0	main
24	doc_491521501746_item	3751888	et	0	main
a	doc_491521501746_item	3751889	et	0	main
sirgu	doc_491521501746_item	3751890	et	0	main
vanamees	doc_491521501746_item	3751891	et	0	main
teeb	doc_491521501746_item	3751892	et	0	main
katku	doc_491521501746_item	3751893	et	0	main
põlli	doc_491521501746_item	3751894	et	0	main
sirgu	doc_491521501746_item	3751895	et	0	main
vanamees	doc_491521501746_item	3751896	et	0	main
teind	doc_491521501746_item	3751897	et	0	main
vanaste	doc_491521501746_item	3751898	et	0	main
katku	doc_491521501746_item	3751899	et	0	main
old	doc_491521501746_item	3751900	et	0	main
kihiandja	doc_491521501746_item	3751901	et	0	main
kui	doc_491521501746_item	3751902	et	0	main
suured	doc_491521501746_item	3751903	et	0	main
haigused	doc_491521501746_item	3751904	et	0	main
olid	doc_491521501746_item	3751905	et	0	main
siis	doc_491521501746_item	3751906	et	0	main
käind	doc_491521501746_item	3751907	et	0	main
ikka	doc_491521501746_item	3751908	et	0	main
kihiandjad	doc_491521501746_item	3751909	et	0	main
sirgu	doc_491521501746_item	3751910	et	0	main
vanamees	doc_491521501746_item	3751911	et	0	main
teind	doc_491521501746_item	3751912	et	0	main
kõhutõbe	doc_491521501746_item	3751913	et	0	main
toond	doc_491521501746_item	3751914	et	0	main
sakste	doc_491521501746_item	3751915	et	0	main
käest	doc_491521501746_item	3751916	et	0	main
kihti	doc_491521501746_item	3751917	et	0	main
era	doc_491521501746_item	3751918	et	0	main
ii	doc_491521501746_item	3751919	et	0	main
27	doc_491521501746_item	3751920	et	0	main
4812	doc_491521501746_item	3751921	et	0	main
25	doc_491521501746_item	3751922	et	0	main
nissi	doc_491521501746_item	3751923	et	0	main
khk	doc_491521501746_item	3751924	et	0	main
riisipere	doc_491521501746_item	3751925	et	0	main
v	doc_491521501746_item	3751926	et	0	main
odolemma	doc_491521501746_item	3751927	et	0	main
k	doc_491521501746_item	3751928	et	0	main
r	doc_491521501746_item	3751929	et	0	main
põldmäe	doc_491521501746_item	3751930	et	0	main
juhan	doc_491521501746_item	3751931	et	0	main
petoffer	doc_491521501746_item	3751932	et	0	main
71	doc_491521501746_item	3751933	et	0	main
a	doc_491521501746_item	3751934	et	0	main
1930	doc_491521501746_item	3751935	et	0	main
lk	doc_491521501746_item	3751936	et	0	main
117	doc_491521501746_item	3751937	et	0	main
3	doc_491521501746_item	3751938	et	0	main
katku	doc_491521501746_item	3751939	et	0	main
nägemisele	doc_491521501746_item	3751940	et	0	main
järgneb	doc_491521501746_item	3751941	et	0	main
surm	doc_491521501746_item	3751942	et	0	main
60	doc_491521501746_item	3751943	et	0	main
e	doc_491521501746_item	3751944	et	0	main
suure-jaagu	doc_491521501746_item	3751945	et	0	main
talu	doc_491521501746_item	3751946	et	0	main
lähedal	doc_491521501746_item	3751947	et	0	main
asub	doc_491521501746_item	3751948	et	0	main
mägi	doc_491521501746_item	3751949	et	0	main
mida	doc_491521501746_item	3751950	et	0	main
nimetatakse	doc_491521501746_item	3751951	et	0	main
surnumäeks	doc_491521501746_item	3751952	et	0	main
enne	doc_491521501746_item	3751953	et	0	main
kui	doc_491521501746_item	3751954	et	0	main
veel	doc_491521501746_item	3751955	et	0	main
seda	doc_491521501746_item	3751956	et	0	main
talu	doc_491521501746_item	3751957	et	0	main
ei	doc_491521501746_item	3751958	et	0	main
olnud	doc_491521501746_item	3751959	et	0	main
oli	doc_491521501746_item	3751960	et	0	main
sääl	doc_491521501746_item	3751961	et	0	main
üks	doc_491521501746_item	3751962	et	0	main
teine	doc_491521501746_item	3751963	et	0	main
talu	doc_491521501746_item	3751964	et	0	main
talu	doc_491521501746_item	3751965	et	0	main
inimesed	doc_491521501746_item	3751966	et	0	main
läinud	doc_491521501746_item	3751967	et	0	main
kaevule	doc_491521501746_item	3751968	et	0	main
vett	doc_491521501746_item	3751969	et	0	main
tooma	doc_491521501746_item	3751970	et	0	main
ja	doc_491521501746_item	3751971	et	0	main
näinud	doc_491521501746_item	3751972	et	0	main
alasti	doc_491521501746_item	3751973	et	0	main
last	doc_491521501746_item	3751974	et	0	main
kaevu	doc_491521501746_item	3751975	et	0	main
juures	doc_491521501746_item	3751976	et	0	main
istumas	doc_491521501746_item	3751977	et	0	main
inimesed	doc_491521501746_item	3751978	et	0	main
läinud	doc_491521501746_item	3751979	et	0	main
vaatama	doc_491521501746_item	3751980	et	0	main
kuid	doc_491521501746_item	3751981	et	0	main
ligi	doc_491521501746_item	3751982	et	0	main
jõudes	doc_491521501746_item	3751983	et	0	main
kukkunud	doc_491521501746_item	3751984	et	0	main
muist	doc_491521501746_item	3751985	et	0	main
surnult	doc_491521501746_item	3751986	et	0	main
maha	doc_491521501746_item	3751987	et	0	main
teised	doc_491521501746_item	3751988	et	0	main
hüüdnud	doc_491521501746_item	3751989	et	0	main
vaadake	doc_491521501746_item	3751990	et	0	main
katku	doc_491521501746_item	3751991	et	0	main
poiss	doc_491521501746_item	3751992	et	0	main
pannud	doc_491521501746_item	3751993	et	0	main
jooksma	doc_491521501746_item	3751994	et	0	main
ja	doc_491521501746_item	3751995	et	0	main
teised	doc_491521501746_item	3751996	et	0	main
näinud	doc_491521501746_item	3751997	et	0	main
et	doc_491521501746_item	3751998	et	0	main
jalapöiad	doc_491521501746_item	3751999	et	0	main
olnud	doc_491521501746_item	3752000	et	0	main
tagurpidi	doc_491521501746_item	3752001	et	0	main
katk	doc_491521501746_item	3752002	et	0	main
hävitanud	doc_491521501746_item	3752003	et	0	main
kogu	doc_491521501746_item	3752004	et	0	main
küla	doc_491521501746_item	3752005	et	0	main
surnud	doc_491521501746_item	3752006	et	0	main
viidud	doc_491521501746_item	3752007	et	0	main
sinna	doc_491521501746_item	3752008	et	0	main
mäele	doc_491521501746_item	3752009	et	0	main
nii	doc_491521501746_item	3752010	et	0	main
et	doc_491521501746_item	3752011	et	0	main
valged	doc_491521501746_item	3752012	et	0	main
juuksed	doc_491521501746_item	3752013	et	0	main
lehvinud	doc_491521501746_item	3752014	et	0	main
tuules	doc_491521501746_item	3752015	et	0	main
sest	doc_491521501746_item	3752016	et	0	main
ajast	doc_491521501746_item	3752017	et	0	main
on	doc_491521501746_item	3752018	et	0	main
selle	doc_491521501746_item	3752019	et	0	main
mäe	doc_491521501746_item	3752020	et	0	main
nimi	doc_491521501746_item	3752021	et	0	main
surnumägi	doc_491521501746_item	3752022	et	0	main
era	doc_491521501746_item	3752023	et	0	main
ii	doc_491521501746_item	3752024	et	0	main
226	doc_491521501746_item	3752025	et	0	main
2145	doc_491521501746_item	3752026	et	0	main
9	doc_491521501746_item	3752027	et	0	main
nissi	doc_491521501746_item	3752028	et	0	main
khk	doc_491521501746_item	3752029	et	0	main
riisipere	doc_491521501746_item	3752030	et	0	main
v	doc_491521501746_item	3752031	et	0	main
mustu	doc_491521501746_item	3752032	et	0	main
k	doc_491521501746_item	3752033	et	0	main
e	doc_491521501746_item	3752034	et	0	main
niinepuu	doc_491521501746_item	3752035	et	0	main
emalt	doc_491521501746_item	3752036	et	0	main
s	doc_491521501746_item	3752037	et	0	main
1926	doc_491521501746_item	3752038	et	0	main
1939	doc_491521501746_item	3752039	et	0	main
lk	doc_491521501746_item	3752040	et	0	main
147	doc_491521501746_item	3752041	et	0	main
4	doc_491521501746_item	3752042	et	0	main
katku	doc_491521501746_item	3752043	et	0	main
kuulmisele	doc_491521501746_item	3752044	et	0	main
järgneb	doc_491521501746_item	3752045	et	0	main
surm	doc_491521501746_item	3752046	et	0	main
katku	doc_491521501746_item	3752047	et	0	main
hääle	doc_491521501746_item	3752048	et	0	main
kuulmisele	doc_491521501746_item	3752049	et	0	main
järgneb	doc_491521501746_item	3752050	et	0	main
surm	doc_491521501746_item	3752051	et	0	main
vanasti	doc_491521501746_item	3752052	et	0	main
kui	doc_491521501746_item	3752053	et	0	main
suured	doc_491521501746_item	3752054	et	0	main
katkud	doc_491521501746_item	3752055	et	0	main
ringi	doc_491521501746_item	3752056	et	0	main
käinud	doc_491521501746_item	3752057	et	0	main
kolanud	doc_491521501746_item	3752058	et	0	main
ümber	doc_491521501746_item	3752059	et	0	main
isesugused	doc_491521501746_item	3752060	et	0	main
hallid	doc_491521501746_item	3752061	et	0	main
linnud	doc_491521501746_item	3752062	et	0	main
nad	doc_491521501746_item	3752063	et	0	main
lennanud	doc_491521501746_item	3752064	et	0	main
puult	doc_491521501746_item	3752065	et	0	main
puule	doc_491521501746_item	3752066	et	0	main
ja	doc_491521501746_item	3752067	et	0	main
teinud	doc_491521501746_item	3752068	et	0	main
isesugust	doc_491521501746_item	3752069	et	0	main
võigast	doc_491521501746_item	3752070	et	0	main
häält	doc_491521501746_item	3752071	et	0	main
kuhu	doc_491521501746_item	3752072	et	0	main
need	doc_491521501746_item	3752073	et	0	main
linnud	doc_491521501746_item	3752074	et	0	main
ilmunud	doc_491521501746_item	3752075	et	0	main
sial	doc_491521501746_item	3752076	et	0	main
pääsenud	doc_491521501746_item	3752077	et	0	main
kohe	doc_491521501746_item	3752078	et	0	main
laastav	doc_491521501746_item	3752079	et	0	main
katk	doc_491521501746_item	3752080	et	0	main
lahti	doc_491521501746_item	3752081	et	0	main
rahvasuu	doc_491521501746_item	3752082	et	0	main
räägib	doc_491521501746_item	3752083	et	0	main
et	doc_491521501746_item	3752084	et	0	main
need	doc_491521501746_item	3752085	et	0	main
olnud	doc_491521501746_item	3752086	et	0	main
katku	doc_491521501746_item	3752087	et	0	main
käskjalad	doc_491521501746_item	3752088	et	0	main
katk	doc_491521501746_item	3752089	et	0	main
ise	doc_491521501746_item	3752090	et	0	main
olnud	doc_491521501746_item	3752091	et	0	main
ka	doc_491521501746_item	3752092	et	0	main
samasugune	doc_491521501746_item	3752093	et	0	main
aga	doc_491521501746_item	3752094	et	0	main
suurem	doc_491521501746_item	3752095	et	0	main
ja	doc_491521501746_item	3752096	et	0	main
ta	doc_491521501746_item	3752097	et	0	main
nokk	doc_491521501746_item	3752098	et	0	main
olnud	doc_491521501746_item	3752099	et	0	main
tulipunane	doc_491521501746_item	3752100	et	0	main
sel	doc_491521501746_item	3752101	et	0	main
suurel	doc_491521501746_item	3752102	et	0	main
katku	doc_491521501746_item	3752103	et	0	main
ajal	doc_491521501746_item	3752104	et	0	main
olevat	doc_491521501746_item	3752105	et	0	main
siin	doc_491521501746_item	3752106	et	0	main
ümbruses	doc_491521501746_item	3752107	et	0	main
maa	doc_491521501746_item	3752108	et	0	main
nii	doc_491521501746_item	3752109	et	0	main
inimestest	doc_491521501746_item	3752110	et	0	main
lage	doc_491521501746_item	3752111	et	0	main
olnud	doc_491521501746_item	3752112	et	0	main
et	doc_491521501746_item	3752113	et	0	main
üks	doc_491521501746_item	3752114	et	0	main
inimene	doc_491521501746_item	3752115	et	0	main
olnud	doc_491521501746_item	3752116	et	0	main
keila	doc_491521501746_item	3752117	et	0	main
teine	doc_491521501746_item	3752118	et	0	main
nissi	doc_491521501746_item	3752119	et	0	main
kiriku	doc_491521501746_item	3752120	et	0	main
tornis	doc_491521501746_item	3752121	et	0	main
era	doc_491521501746_item	3752122	et	0	main
ii	doc_491521501746_item	3752123	et	0	main
226	doc_491521501746_item	3752124	et	0	main
191	doc_491521501746_item	3752125	et	0	main
14	doc_491521501746_item	3752126	et	0	main
nissi	doc_491521501746_item	3752127	et	0	main
khk	doc_491521501746_item	3752128	et	0	main
laitse	doc_491521501746_item	3752129	et	0	main
v	doc_491521501746_item	3752130	et	0	main
õpil	doc_491521501746_item	3752131	et	0	main
h	doc_491521501746_item	3752132	et	0	main
tillemann	doc_491521501746_item	3752133	et	0	main
kaarel	doc_491521501746_item	3752134	et	0	main
tui	doc_491521501746_item	3752135	et	0	main
73	doc_491521501746_item	3752136	et	0	main
a	doc_491521501746_item	3752137	et	0	main
1939	doc_491521501746_item	3752138	et	0	main
lk	doc_491521501746_item	3752139	et	0	main
151	doc_491521501746_item	3752140	et	0	main
füüsiline	doc_491521501746_item	3752141	et	0	main
kontakt	doc_491521501746_item	3752142	et	0	main
katkuga	doc_491521501746_item	3752143	et	0	main
inimene	doc_491521501746_item	3752144	et	0	main
haigestub	doc_491521501746_item	3752145	et	0	main
katku	doc_491521501746_item	3752146	et	0	main
puudutusest	doc_491521501746_item	3752147	et	0	main
inimene	doc_491521501746_item	3752148	et	0	main
puudutab	doc_491521501746_item	3752149	et	0	main
katkueset	doc_491521501746_item	3752150	et	0	main
katk	doc_491521501746_item	3752151	et	0	main
üks	doc_491521501746_item	3752152	et	0	main
eit	doc_491521501746_item	3752153	et	0	main
old	doc_491521501746_item	3752154	et	0	main
õues	doc_491521501746_item	3752155	et	0	main
oma	doc_491521501746_item	3752156	et	0	main
asjal	doc_491521501746_item	3752157	et	0	main
kaks	doc_491521501746_item	3752158	et	0	main
tükki	doc_491521501746_item	3752159	et	0	main
tuld	doc_491521501746_item	3752160	et	0	main
jälle	doc_491521501746_item	3752161	et	0	main
old	doc_491521501746_item	3752162	et	0	main
poisikesed	doc_491521501746_item	3752163	et	0	main
rääkind	doc_491521501746_item	3752164	et	0	main
et	doc_491521501746_item	3752165	et	0	main
kudas	doc_491521501746_item	3752166	et	0	main
nende	doc_491521501746_item	3752167	et	0	main
suu	doc_491521501746_item	3752168	et	0	main
külgi	doc_491521501746_item	3752169	et	0	main
saaks	doc_491521501746_item	3752170	et	0	main
puutuda	doc_491521501746_item	3752171	et	0	main
teine	doc_491521501746_item	3752172	et	0	main
üteld	doc_491521501746_item	3752173	et	0	main
neil	doc_491521501746_item	3752174	et	0	main
on	doc_491521501746_item	3752175	et	0	main
leivad	doc_491521501746_item	3752176	et	0	main
astjas	doc_491521501746_item	3752177	et	0	main
ma	doc_491521501746_item	3752178	et	0	main
teen	doc_491521501746_item	3752179	et	0	main
enese	doc_491521501746_item	3752180	et	0	main
einakõrreks	doc_491521501746_item	3752181	et	0	main
lähen	doc_491521501746_item	3752182	et	0	main
leiva	doc_491521501746_item	3752183	et	0	main
sisse	doc_491521501746_item	3752184	et	0	main
ta	doc_491521501746_item	3752185	et	0	main
võtab	doc_491521501746_item	3752186	et	0	main
suuga	doc_491521501746_item	3752187	et	0	main
selle	doc_491521501746_item	3752188	et	0	main
ära	doc_491521501746_item	3752189	et	0	main
sealt	doc_491521501746_item	3752190	et	0	main
ja	doc_491521501746_item	3752191	et	0	main
ma	doc_491521501746_item	3752192	et	0	main
saan	doc_491521501746_item	3752193	et	0	main
suhu	doc_491521501746_item	3752194	et	0	main
minna	doc_491521501746_item	3752195	et	0	main
teine	doc_491521501746_item	3752196	et	0	main
üteld	doc_491521501746_item	3752197	et	0	main
kui	doc_491521501746_item	3752198	et	0	main
ta	doc_491521501746_item	3752199	et	0	main
sõtkub	doc_491521501746_item	3752200	et	0	main
aab	doc_491521501746_item	3752201	et	0	main
tüki	doc_491521501746_item	3752202	et	0	main
tainast	doc_491521501746_item	3752203	et	0	main
koa	doc_491521501746_item	3752204	et	0	main
maha	doc_491521501746_item	3752205	et	0	main
ma	doc_491521501746_item	3752206	et	0	main
soan	doc_491521501746_item	3752207	et	0	main
sedamoodi	doc_491521501746_item	3752208	et	0	main
ta	doc_491521501746_item	3752209	et	0	main
suhu	doc_491521501746_item	3752210	et	0	main
siis	doc_491521501746_item	3752211	et	0	main
on	doc_491521501746_item	3752212	et	0	main
kaks	doc_491521501746_item	3752213	et	0	main
tükki	doc_491521501746_item	3752214	et	0	main
ma	doc_491521501746_item	3752215	et	0	main
käes	doc_491521501746_item	3752216	et	0	main
siis	doc_491521501746_item	3752217	et	0	main
teised	doc_491521501746_item	3752218	et	0	main
jäävad	doc_491521501746_item	3752219	et	0	main
juba	doc_491521501746_item	3752220	et	0	main
isegi	doc_491521501746_item	3752221	et	0	main
ei	doc_491521501746_item	3752222	et	0	main
nad	doc_491521501746_item	3752223	et	0	main
me	doc_491521501746_item	3752224	et	0	main
käest	doc_491521501746_item	3752225	et	0	main
pääse	doc_491521501746_item	3752226	et	0	main
eit	doc_491521501746_item	3752227	et	0	main
kuuland	doc_491521501746_item	3752228	et	0	main
ja	doc_491521501746_item	3752229	et	0	main
põle	doc_491521501746_item	3752230	et	0	main
rääkind	doc_491521501746_item	3752231	et	0	main
kui	doc_491521501746_item	3752232	et	0	main
teised	doc_491521501746_item	3752233	et	0	main
juba	doc_491521501746_item	3752234	et	0	main
aiged-suremas	doc_491521501746_item	3752235	et	0	main
old	doc_491521501746_item	3752236	et	0	main
era	doc_491521501746_item	3752237	et	0	main
ii	doc_491521501746_item	3752238	et	0	main
77	doc_491521501746_item	3752239	et	0	main
3456	doc_491521501746_item	3752240	et	0	main
12	doc_491521501746_item	3752241	et	0	main
hageri	doc_491521501746_item	3752242	et	0	main
khk	doc_491521501746_item	3752243	et	0	main
v	doc_491521501746_item	3752244	et	0	main
ja	doc_491521501746_item	3752245	et	0	main
vndk	doc_491521501746_item	3752246	et	0	main
nissi	doc_491521501746_item	3752247	et	0	main
khk	doc_491521501746_item	3752248	et	0	main
varbola	doc_491521501746_item	3752249	et	0	main
v	doc_491521501746_item	3752250	et	0	main
põlli	doc_491521501746_item	3752251	et	0	main
k	doc_491521501746_item	3752252	et	0	main
r	doc_491521501746_item	3752253	et	0	main
põldmäe	doc_491521501746_item	3752254	et	0	main
jaagup	doc_491521501746_item	3752255	et	0	main
jäämann	doc_491521501746_item	3752256	et	0	main
70	doc_491521501746_item	3752257	et	0	main
a	doc_491521501746_item	3752258	et	0	main
1934	doc_491521501746_item	3752259	et	0	main
lk	doc_491521501746_item	3752260	et	0	main
169	doc_491521501746_item	3752261	et	0	main
katk	doc_491521501746_item	3752262	et	0	main
puudutab	doc_491521501746_item	3752263	et	0	main
inimest	doc_491521501746_item	3752264	et	0	main
katk	doc_491521501746_item	3752265	et	0	main
minu	doc_491521501746_item	3752266	et	0	main
emaema	doc_491521501746_item	3752267	et	0	main
rääkis	doc_491521501746_item	3752268	et	0	main
et	doc_491521501746_item	3752269	et	0	main
nemad	doc_491521501746_item	3752270	et	0	main
näind	doc_491521501746_item	3752271	et	0	main
kui	doc_491521501746_item	3752272	et	0	main
katk	doc_491521501746_item	3752273	et	0	main
oli	doc_491521501746_item	3752274	et	0	main
inimesi	doc_491521501746_item	3752275	et	0	main
surmand	doc_491521501746_item	3752276	et	0	main
nagu	doc_491521501746_item	3752277	et	0	main
hall	doc_491521501746_item	3752278	et	0	main
vaim	doc_491521501746_item	3752279	et	0	main
tulnd	doc_491521501746_item	3752280	et	0	main
keda	doc_491521501746_item	3752281	et	0	main
käega	doc_491521501746_item	3752282	et	0	main
katsund	doc_491521501746_item	3752283	et	0	main
see	doc_491521501746_item	3752284	et	0	main
jäänud	doc_491521501746_item	3752285	et	0	main
nagu	doc_491521501746_item	3752286	et	0	main
loog	doc_491521501746_item	3752287	et	0	main
maha	doc_491521501746_item	3752288	et	0	main
kes	doc_491521501746_item	3752289	et	0	main
üleval	doc_491521501746_item	3752290	et	0	main
oli	doc_491521501746_item	3752291	et	0	main
need	doc_491521501746_item	3752292	et	0	main
jäänd	doc_491521501746_item	3752293	et	0	main
kõik	doc_491521501746_item	3752294	et	0	main
elama	doc_491521501746_item	3752295	et	0	main
aga	doc_491521501746_item	3752296	et	0	main
kes	doc_491521501746_item	3752297	et	0	main
magas	doc_491521501746_item	3752298	et	0	main
sel	doc_491521501746_item	3752299	et	0	main
aal	doc_491521501746_item	3752300	et	0	main
see	doc_491521501746_item	3752301	et	0	main
jäi	doc_491521501746_item	3752302	et	0	main
maha	doc_491521501746_item	3752303	et	0	main
era	doc_491521501746_item	3752304	et	0	main
ii	doc_491521501746_item	3752305	et	0	main
27	doc_491521501746_item	3752306	et	0	main
3256	doc_491521501746_item	3752307	et	0	main
17	doc_491521501746_item	3752308	et	0	main
nissi	doc_491521501746_item	3752309	et	0	main
khk	doc_491521501746_item	3752310	et	0	main
laitse	doc_491521501746_item	3752311	et	0	main
v	doc_491521501746_item	3752312	et	0	main
r	doc_491521501746_item	3752313	et	0	main
põldmäe	doc_491521501746_item	3752314	et	0	main
ann	doc_491521501746_item	3752315	et	0	main
vihman	doc_491521501746_item	3752316	et	0	main
1939	doc_491521501746_item	3752317	et	0	main
lk	doc_491521501746_item	3752318	et	0	main
174	doc_491521501746_item	3752319	et	0	main
katk	doc_491521501746_item	3752320	et	0	main
torkab	doc_491521501746_item	3752321	et	0	main
ainult	doc_491521501746_item	3752322	et	0	main
magajaid	doc_491521501746_item	3752323	et	0	main
katk	doc_491521501746_item	3752324	et	0	main
katk	doc_491521501746_item	3752325	et	0	main
käind	doc_491521501746_item	3752326	et	0	main
inimese	doc_491521501746_item	3752327	et	0	main
näol	doc_491521501746_item	3752328	et	0	main
ringi	doc_491521501746_item	3752329	et	0	main
must	doc_491521501746_item	3752330	et	0	main
mees	doc_491521501746_item	3752331	et	0	main
olnud	doc_491521501746_item	3752332	et	0	main
kui	doc_491521501746_item	3752333	et	0	main
inimesed	doc_491521501746_item	3752334	et	0	main
magand	doc_491521501746_item	3752335	et	0	main
siis	doc_491521501746_item	3752336	et	0	main
katk	doc_491521501746_item	3752337	et	0	main
surmand	doc_491521501746_item	3752338	et	0	main
neid	doc_491521501746_item	3752339	et	0	main
kolm	doc_491521501746_item	3752340	et	0	main
ööd	doc_491521501746_item	3752341	et	0	main
ja	doc_491521501746_item	3752342	et	0	main
päeva	doc_491521501746_item	3752343	et	0	main
käind	doc_491521501746_item	3752344	et	0	main
inimesed	doc_491521501746_item	3752345	et	0	main
olnud	doc_491521501746_item	3752346	et	0	main
valvel	doc_491521501746_item	3752347	et	0	main
ei	doc_491521501746_item	3752348	et	0	main
ole	doc_491521501746_item	3752349	et	0	main
saand	doc_491521501746_item	3752350	et	0	main
kedagi	doc_491521501746_item	3752351	et	0	main
surmata	doc_491521501746_item	3752352	et	0	main
üks	doc_491521501746_item	3752353	et	0	main
inime	doc_491521501746_item	3752354	et	0	main
visand	doc_491521501746_item	3752355	et	0	main
aina	doc_491521501746_item	3752356	et	0	main
kedervarre	doc_491521501746_item	3752357	et	0	main
ja	doc_491521501746_item	3752358	et	0	main
lõngakera	doc_491521501746_item	3752359	et	0	main
uksest	doc_491521501746_item	3752360	et	0	main
välla	doc_491521501746_item	3752361	et	0	main
siis	doc_491521501746_item	3752362	et	0	main
kordamööda	doc_491521501746_item	3752363	et	0	main
lapsed	doc_491521501746_item	3752364	et	0	main
toonud	doc_491521501746_item	3752365	et	0	main
sisse	doc_491521501746_item	3752366	et	0	main
olnd	doc_491521501746_item	3752367	et	0	main
üleval	doc_491521501746_item	3752368	et	0	main
sedasiöö	doc_491521501746_item	3752369	et	0	main
lävi	doc_491521501746_item	3752370	et	0	main
peasend	doc_491521501746_item	3752371	et	0	main
surmast	doc_491521501746_item	3752372	et	0	main
keda	doc_491521501746_item	3752373	et	0	main
katk	doc_491521501746_item	3752374	et	0	main
kepiga	doc_491521501746_item	3752375	et	0	main
turgand	doc_491521501746_item	3752376	et	0	main
see	doc_491521501746_item	3752377	et	0	main
surnud	doc_491521501746_item	3752378	et	0	main
era	doc_491521501746_item	3752379	et	0	main
ii	doc_491521501746_item	3752380	et	0	main
27	doc_491521501746_item	3752381	et	0	main
57475	doc_491521501746_item	3752382	et	0	main
90	doc_491521501746_item	3752383	et	0	main
nissi	doc_491521501746_item	3752384	et	0	main
khk	doc_491521501746_item	3752385	et	0	main
varbola	doc_491521501746_item	3752386	et	0	main
v	doc_491521501746_item	3752387	et	0	main
rahula	doc_491521501746_item	3752388	et	0	main
k	doc_491521501746_item	3752389	et	0	main
harju-madise	doc_491521501746_item	3752390	et	0	main
khk	doc_491521501746_item	3752391	et	0	main
r	doc_491521501746_item	3752392	et	0	main
põldmäe	doc_491521501746_item	3752393	et	0	main
liisa	doc_491521501746_item	3752394	et	0	main
tropp	doc_491521501746_item	3752395	et	0	main
61	doc_491521501746_item	3752396	et	0	main
a	doc_491521501746_item	3752397	et	0	main
1930	doc_491521501746_item	3752398	et	0	main
lk	doc_491521501746_item	3752399	et	0	main
188	doc_491521501746_item	3752400	et	0	main
see	doc_491521501746_item	3752401	et	0	main
elama	doc_491521501746_item	3752402	et	0	main
see	doc_491521501746_item	3752403	et	0	main
surema	doc_491521501746_item	3752404	et	0	main
katk	doc_491521501746_item	3752405	et	0	main
old	doc_491521501746_item	3752406	et	0	main
üks	doc_491521501746_item	3752407	et	0	main
pisike	doc_491521501746_item	3752408	et	0	main
poiss	doc_491521501746_item	3752409	et	0	main
käind	doc_491521501746_item	3752410	et	0	main
omiku	doc_491521501746_item	3752411	et	0	main
vara	doc_491521501746_item	3752412	et	0	main
kui	doc_491521501746_item	3752413	et	0	main
inimesed	doc_491521501746_item	3752414	et	0	main
magand	doc_491521501746_item	3752415	et	0	main
igas	doc_491521501746_item	3752416	et	0	main
toas	doc_491521501746_item	3752417	et	0	main
inimeste	doc_491521501746_item	3752418	et	0	main
juures	doc_491521501746_item	3752419	et	0	main
turkind	doc_491521501746_item	3752420	et	0	main
kepiga	doc_491521501746_item	3752421	et	0	main
igaühe	doc_491521501746_item	3752422	et	0	main
külgi	doc_491521501746_item	3752423	et	0	main
see	doc_491521501746_item	3752424	et	0	main
peab	doc_491521501746_item	3752425	et	0	main
surema	doc_491521501746_item	3752426	et	0	main
ja	doc_491521501746_item	3752427	et	0	main
see	doc_491521501746_item	3752428	et	0	main
peab	doc_491521501746_item	3752429	et	0	main
surema	doc_491521501746_item	3752430	et	0	main
need	doc_491521501746_item	3752431	et	0	main
keda	doc_491521501746_item	3752432	et	0	main
turgand	doc_491521501746_item	3752433	et	0	main
need	doc_491521501746_item	3752434	et	0	main
jäänd	doc_491521501746_item	3752435	et	0	main
katkuhaigeks	doc_491521501746_item	3752436	et	0	main
ja	doc_491521501746_item	3752437	et	0	main
surd	doc_491521501746_item	3752438	et	0	main
pärast	doc_491521501746_item	3752439	et	0	main
nad	doc_491521501746_item	3752440	et	0	main
põle	doc_491521501746_item	3752441	et	0	main
julgend	doc_491521501746_item	3752442	et	0	main
magama	doc_491521501746_item	3752443	et	0	main
jääda	doc_491521501746_item	3752444	et	0	main
võtt	doc_491521501746_item	3752445	et	0	main
ühe	doc_491521501746_item	3752446	et	0	main
teise	doc_491521501746_item	3752447	et	0	main
nõu	doc_491521501746_item	3752448	et	0	main
era	doc_491521501746_item	3752449	et	0	main
ii	doc_491521501746_item	3752450	et	0	main
77	doc_491521501746_item	3752451	et	0	main
3445	doc_491521501746_item	3752452	et	0	main
11	doc_491521501746_item	3752453	et	0	main
hageri	doc_491521501746_item	3752454	et	0	main
khk	doc_491521501746_item	3752455	et	0	main
v	doc_491521501746_item	3752456	et	0	main
ja	doc_491521501746_item	3752457	et	0	main
vndk	doc_491521501746_item	3752458	et	0	main
nissi	doc_491521501746_item	3752459	et	0	main
khk	doc_491521501746_item	3752460	et	0	main
varbola	doc_491521501746_item	3752461	et	0	main
v	doc_491521501746_item	3752462	et	0	main
põlli	doc_491521501746_item	3752463	et	0	main
k	doc_491521501746_item	3752464	et	0	main
r	doc_491521501746_item	3752465	et	0	main
põldmäe	doc_491521501746_item	3752466	et	0	main
jaagup	doc_491521501746_item	3752467	et	0	main
jäämann	doc_491521501746_item	3752468	et	0	main
70	doc_491521501746_item	3752469	et	0	main
a	doc_491521501746_item	3752470	et	0	main
1934	doc_491521501746_item	3752471	et	0	main
lk	doc_491521501746_item	3752472	et	0	main
196	doc_491521501746_item	3752473	et	0	main
katk	doc_491521501746_item	3752474	et	0	main
lööb	doc_491521501746_item	3752475	et	0	main
ainult	doc_491521501746_item	3752476	et	0	main
magajaid	doc_491521501746_item	3752477	et	0	main
kui	doc_491521501746_item	3752478	et	0	main
eestis	doc_491521501746_item	3752479	et	0	main
nn	doc_491521501746_item	3752480	et	0	main
must	doc_491521501746_item	3752481	et	0	main
katk	doc_491521501746_item	3752482	et	0	main
koledasti	doc_491521501746_item	3752483	et	0	main
möllanud	doc_491521501746_item	3752484	et	0	main
siis	doc_491521501746_item	3752485	et	0	main
olid	doc_491521501746_item	3752486	et	0	main
inimesed	doc_491521501746_item	3752487	et	0	main
teda	doc_491521501746_item	3752488	et	0	main
mitmet	doc_491521501746_item	3752489	et	0	main
moodi	doc_491521501746_item	3752490	et	0	main
näinud	doc_491521501746_item	3752491	et	0	main
kord	doc_491521501746_item	3752492	et	0	main
kirju	doc_491521501746_item	3752493	et	0	main
kanana	doc_491521501746_item	3752494	et	0	main
kes	doc_491521501746_item	3752495	et	0	main
siblinud	doc_491521501746_item	3752496	et	0	main
õues	doc_491521501746_item	3752497	et	0	main
siis	doc_491521501746_item	3752498	et	0	main
surnud	doc_491521501746_item	3752499	et	0	main
kohe	doc_491521501746_item	3752500	et	0	main
keegi	doc_491521501746_item	3752501	et	0	main
katku	doc_491521501746_item	3752502	et	0	main
ära	doc_491521501746_item	3752503	et	0	main
vahest	doc_491521501746_item	3752504	et	0	main
kujutanud	doc_491521501746_item	3752505	et	0	main
ta	doc_491521501746_item	3752506	et	0	main
musta	doc_491521501746_item	3752507	et	0	main
koera	doc_491521501746_item	3752508	et	0	main
kuhu	doc_491521501746_item	3752509	et	0	main
see	doc_491521501746_item	3752510	et	0	main
ilmub	doc_491521501746_item	3752511	et	0	main
sääl	doc_491521501746_item	3752512	et	0	main
olnud	doc_491521501746_item	3752513	et	0	main
ka	doc_491521501746_item	3752514	et	0	main
kohe	doc_491521501746_item	3752515	et	0	main
surm	doc_491521501746_item	3752516	et	0	main
külaliseks	doc_491521501746_item	3752517	et	0	main
kõige	doc_491521501746_item	3752518	et	0	main
rohkem	doc_491521501746_item	3752519	et	0	main
nähtud	doc_491521501746_item	3752520	et	0	main
teda	doc_491521501746_item	3752521	et	0	main
väikese	doc_491521501746_item	3752522	et	0	main
poisina	doc_491521501746_item	3752523	et	0	main
kellel	doc_491521501746_item	3752524	et	0	main
ikka	doc_491521501746_item	3752525	et	0	main
piits	doc_491521501746_item	3752526	et	0	main
käes	doc_491521501746_item	3752527	et	0	main
olnud	doc_491521501746_item	3752528	et	0	main
keda	doc_491521501746_item	3752529	et	0	main
ta	doc_491521501746_item	3752530	et	0	main
piitsaga	doc_491521501746_item	3752531	et	0	main
ähvardanud	doc_491521501746_item	3752532	et	0	main
ehk	doc_491521501746_item	3752533	et	0	main
löönud	doc_491521501746_item	3752534	et	0	main
ja	doc_491521501746_item	3752535	et	0	main
kes	doc_491521501746_item	3752536	et	0	main
siis	doc_491521501746_item	3752537	et	0	main
karjatanud	doc_491521501746_item	3752538	et	0	main
see	doc_491521501746_item	3752539	et	0	main
surnud	doc_491521501746_item	3752540	et	0	main
katku	doc_491521501746_item	3752541	et	0	main
samuti	doc_491521501746_item	3752542	et	0	main
magajad	doc_491521501746_item	3752543	et	0	main
surnud	doc_491521501746_item	3752544	et	0	main
ära	doc_491521501746_item	3752545	et	0	main
inimesed	doc_491521501746_item	3752546	et	0	main
pole	doc_491521501746_item	3752547	et	0	main
julgenud	doc_491521501746_item	3752548	et	0	main
enam	doc_491521501746_item	3752549	et	0	main
magada	doc_491521501746_item	3752550	et	0	main
vaid	doc_491521501746_item	3752551	et	0	main
valvanud	doc_491521501746_item	3752552	et	0	main
ööd	doc_491521501746_item	3752553	et	0	main
kui	doc_491521501746_item	3752554	et	0	main
päevad	doc_491521501746_item	3752555	et	0	main
nii	doc_491521501746_item	3752556	et	0	main
et	doc_491521501746_item	3752557	et	0	main
nad	doc_491521501746_item	3752558	et	0	main
juba	doc_491521501746_item	3752559	et	0	main
uimaseks	doc_491521501746_item	3752560	et	0	main
jäänud	doc_491521501746_item	3752561	et	0	main
südaöösel	doc_491521501746_item	3752562	et	0	main
aga	doc_491521501746_item	3752563	et	0	main
ulnus	doc_491521501746_item	3752564	et	0	main
poisikene	doc_491521501746_item	3752565	et	0	main
uksest	doc_491521501746_item	3752566	et	0	main
sisse	doc_491521501746_item	3752567	et	0	main
ja	doc_491521501746_item	3752568	et	0	main
plaksutanud	doc_491521501746_item	3752569	et	0	main
piitsa	doc_491521501746_item	3752570	et	0	main
kes	doc_491521501746_item	3752571	et	0	main
siis	doc_491521501746_item	3752572	et	0	main
maganud	doc_491521501746_item	3752573	et	0	main
või	doc_491521501746_item	3752574	et	0	main
kiljatanud	doc_491521501746_item	3752575	et	0	main
olnud	doc_491521501746_item	3752576	et	0	main
hommikuks	doc_491521501746_item	3752577	et	0	main
surnud	doc_491521501746_item	3752578	et	0	main
kõik	doc_491521501746_item	3752579	et	0	main
kohad	doc_491521501746_item	3752580	et	0	main
olnud	doc_491521501746_item	3752581	et	0	main
viimaks	doc_491521501746_item	3752582	et	0	main
inimestest	doc_491521501746_item	3752583	et	0	main
tühjad	doc_491521501746_item	3752584	et	0	main
pole	doc_491521501746_item	3752585	et	0	main
olnud	doc_491521501746_item	3752586	et	0	main
enam	doc_491521501746_item	3752587	et	0	main
puusärgitegijäid	doc_491521501746_item	3752588	et	0	main
ega	doc_491521501746_item	3752589	et	0	main
matjaid	doc_491521501746_item	3752590	et	0	main
lehmad	doc_491521501746_item	3752591	et	0	main
olnud	doc_491521501746_item	3752592	et	0	main
söömata	doc_491521501746_item	3752593	et	0	main
ja	doc_491521501746_item	3752594	et	0	main
lüpsmata	doc_491521501746_item	3752595	et	0	main
ammudes	doc_491521501746_item	3752596	et	0	main
käinud	doc_491521501746_item	3752597	et	0	main
nad	doc_491521501746_item	3752598	et	0	main
mööda	doc_491521501746_item	3752599	et	0	main
küla	doc_491521501746_item	3752600	et	0	main
tänavaid	doc_491521501746_item	3752601	et	0	main
külla	doc_491521501746_item	3752602	et	0	main
jäänud	doc_491521501746_item	3752603	et	0	main
ainult	doc_491521501746_item	3752604	et	0	main
kaks	doc_491521501746_item	3752605	et	0	main
peremeest	doc_491521501746_item	3752606	et	0	main
üks	doc_491521501746_item	3752607	et	0	main
olnud	doc_491521501746_item	3752608	et	0	main
reinu	doc_491521501746_item	3752609	et	0	main
jüri	doc_491521501746_item	3752610	et	0	main
ja	doc_491521501746_item	3752611	et	0	main
teine	doc_491521501746_item	3752612	et	0	main
otsa	doc_491521501746_item	3752613	et	0	main
jaan	doc_491521501746_item	3752614	et	0	main
pärast	doc_491521501746_item	3752615	et	0	main
katku	doc_491521501746_item	3752616	et	0	main
toonud	doc_491521501746_item	3752617	et	0	main
mõisaomanik	doc_491521501746_item	3752618	et	0	main
kindral	doc_491521501746_item	3752619	et	0	main
meiendorf	doc_491521501746_item	3752620	et	0	main
taru	doc_491521501746_item	3752621	et	0	main
linnast	doc_491521501746_item	3752622	et	0	main
ja	doc_491521501746_item	3752623	et	0	main
selle	doc_491521501746_item	3752624	et	0	main
ümbrusest	doc_491521501746_item	3752625	et	0	main
uusi	doc_491521501746_item	3752626	et	0	main
elanikke	doc_491521501746_item	3752627	et	0	main
külla	doc_491521501746_item	3752628	et	0	main
era	doc_491521501746_item	3752629	et	0	main
ii	doc_491521501746_item	3752630	et	0	main
219	doc_491521501746_item	3752631	et	0	main
3212	doc_491521501746_item	3752632	et	0	main
26	doc_491521501746_item	3752633	et	0	main
ambla	doc_491521501746_item	3752634	et	0	main
khk	doc_491521501746_item	3752635	et	0	main
tapa	doc_491521501746_item	3752636	et	0	main
as	doc_491521501746_item	3752637	et	0	main
nissi	doc_491521501746_item	3752638	et	0	main
khk	doc_491521501746_item	3752639	et	0	main
nurme	doc_491521501746_item	3752640	et	0	main
trahter	doc_491521501746_item	3752641	et	0	main
õpil	doc_491521501746_item	3752642	et	0	main
h	doc_491521501746_item	3752643	et	0	main
reemets	doc_491521501746_item	3752644	et	0	main
joh	doc_491521501746_item	3752645	et	0	main
reemets	doc_491521501746_item	3752646	et	0	main
60	doc_491521501746_item	3752647	et	0	main
a	doc_491521501746_item	3752648	et	0	main
1939	doc_491521501746_item	3752649	et	0	main
lk	doc_491521501746_item	3752650	et	0	main
200	doc_491521501746_item	3752651	et	0	main
katkukalmed	doc_491521501746_item	3752652	et	0	main
katkumägi	doc_491521501746_item	3752653	et	0	main
on	doc_491521501746_item	3752654	et	0	main
siit	doc_491521501746_item	3752655	et	0	main
4	doc_491521501746_item	3752656	et	0	main
km	doc_491521501746_item	3752657	et	0	main
nissi	doc_491521501746_item	3752658	et	0	main
poole	doc_491521501746_item	3752659	et	0	main
sõitu	doc_491521501746_item	3752660	et	0	main
sinna	doc_491521501746_item	3752661	et	0	main
olevat	doc_491521501746_item	3752662	et	0	main
maetud	doc_491521501746_item	3752663	et	0	main
katkuhaiged	doc_491521501746_item	3752664	et	0	main
rkm	doc_491521501746_item	3752665	et	0	main
ii	doc_491521501746_item	3752666	et	0	main
433	doc_491521501746_item	3752667	et	0	main
342	doc_491521501746_item	3752668	et	0	main
32	doc_491521501746_item	3752669	et	0	main
nissi	doc_491521501746_item	3752670	et	0	main
khk	doc_491521501746_item	3752671	et	0	main
turba	doc_491521501746_item	3752672	et	0	main
as	doc_491521501746_item	3752673	et	0	main
a	doc_491521501746_item	3752674	et	0	main
korb	doc_491521501746_item	3752675	et	0	main
helju	doc_491521501746_item	3752676	et	0	main
samlas	doc_491521501746_item	3752677	et	0	main
sünd	doc_491521501746_item	3752678	et	0	main
1926	doc_491521501746_item	3752679	et	0	main
1990	doc_491521501746_item	3752680	et	0	main
katkumägi	doc_491521501746_item	3752681	et	0	main
oli	doc_491521501746_item	3752682	et	0	main
sündinud	doc_491521501746_item	3752683	et	0	main
sellest	doc_491521501746_item	3752684	et	0	main
et	doc_491521501746_item	3752685	et	0	main
vanast	doc_491521501746_item	3752686	et	0	main
olid	doc_491521501746_item	3752687	et	0	main
loomad	doc_491521501746_item	3752688	et	0	main
ära	doc_491521501746_item	3752689	et	0	main
surnud	doc_491521501746_item	3752690	et	0	main
katku	doc_491521501746_item	3752691	et	0	main
ja	doc_491521501746_item	3752692	et	0	main
siis	doc_491521501746_item	3752693	et	0	main
viidud	doc_491521501746_item	3752694	et	0	main
sinna	doc_491521501746_item	3752695	et	0	main
ema	doc_491521501746_item	3752696	et	0	main
rääkis	doc_491521501746_item	3752697	et	0	main
seda	doc_491521501746_item	3752698	et	0	main
nii	doc_491521501746_item	3752699	et	0	main
see	doc_491521501746_item	3752700	et	0	main
oli	doc_491521501746_item	3752701	et	0	main
niisugune	doc_491521501746_item	3752702	et	0	main
kõrge	doc_491521501746_item	3752703	et	0	main
koht	doc_491521501746_item	3752704	et	0	main
seal	doc_491521501746_item	3752705	et	0	main
üle	doc_491521501746_item	3752706	et	0	main
raudtee	doc_491521501746_item	3752707	et	0	main
rkm	doc_491521501746_item	3752708	et	0	main
ii	doc_491521501746_item	3752709	et	0	main
434	doc_491521501746_item	3752710	et	0	main
313	doc_491521501746_item	3752711	et	0	main
12	doc_491521501746_item	3752712	et	0	main
nissi	doc_491521501746_item	3752713	et	0	main
khk	doc_491521501746_item	3752714	et	0	main
riisipere	doc_491521501746_item	3752715	et	0	main
v	doc_491521501746_item	3752716	et	0	main
madila	doc_491521501746_item	3752717	et	0	main
k	doc_491521501746_item	3752718	et	0	main
m	doc_491521501746_item	3752719	et	0	main
hiiemäe	doc_491521501746_item	3752720	et	0	main
leida	doc_491521501746_item	3752721	et	0	main
leheroo	doc_491521501746_item	3752722	et	0	main
71	doc_491521501746_item	3752723	et	0	main
a	doc_491521501746_item	3752724	et	0	main
1990	doc_491521501746_item	3752725	et	0	main
lk	doc_491521501746_item	3752726	et	0	main
228	doc_491521501746_item	3752727	et	0	main
31	doc_491521501746_item	3752728	et	0	main
katkukalmetega	doc_491521501746_item	3752729	et	0	main
seotud	doc_491521501746_item	3752730	et	0	main
üleloomulikud	doc_491521501746_item	3752731	et	0	main
ilmingud	doc_491521501746_item	3752732	et	0	main
meie	doc_491521501746_item	3752733	et	0	main
ligidal	doc_491521501746_item	3752734	et	0	main
vasalemmas	doc_491521501746_item	3752735	et	0	main
olid	doc_491521501746_item	3752736	et	0	main
liivaaugud	doc_491521501746_item	3752737	et	0	main
sinna	doc_491521501746_item	3752738	et	0	main
oli	doc_491521501746_item	3752739	et	0	main
vanasti	doc_491521501746_item	3752740	et	0	main
katkuaeg	doc_491521501746_item	3752741	et	0	main
inimesi	doc_491521501746_item	3752742	et	0	main
maetud	doc_491521501746_item	3752743	et	0	main
seal	doc_491521501746_item	3752744	et	0	main
oli	doc_491521501746_item	3752745	et	0	main
ikka	doc_491521501746_item	3752746	et	0	main
vaimusi	doc_491521501746_item	3752747	et	0	main
nähtud	doc_491521501746_item	3752748	et	0	main
kes	doc_491521501746_item	3752749	et	0	main
on	doc_491521501746_item	3752750	et	0	main
purjus	doc_491521501746_item	3752751	et	0	main
mehed	doc_491521501746_item	3752752	et	0	main
nied	doc_491521501746_item	3752753	et	0	main
ikke	doc_491521501746_item	3752754	et	0	main
näevad	doc_491521501746_item	3752755	et	0	main
rohkem	doc_491521501746_item	3752756	et	0	main
minu	doc_491521501746_item	3752757	et	0	main
oma	doc_491521501746_item	3752758	et	0	main
onu	doc_491521501746_item	3752759	et	0	main
oli	doc_491521501746_item	3752760	et	0	main
ühekorra	doc_491521501746_item	3752761	et	0	main
näind	doc_491521501746_item	3752762	et	0	main
madise	doc_491521501746_item	3752763	et	0	main
kiriku	doc_491521501746_item	3752764	et	0	main
juurdes	doc_491521501746_item	3752765	et	0	main
oli	doc_491521501746_item	3752766	et	0	main
üks	doc_491521501746_item	3752767	et	0	main
akanud	doc_491521501746_item	3752768	et	0	main
obuse	doc_491521501746_item	3752769	et	0	main
kõrvas	doc_491521501746_item	3752770	et	0	main
jooksma	doc_491521501746_item	3752771	et	0	main
akanud	doc_491521501746_item	3752772	et	0	main
viel	doc_491521501746_item	3752773	et	0	main
obuse	doc_491521501746_item	3752774	et	0	main
aisadest	doc_491521501746_item	3752775	et	0	main
kinni	doc_491521501746_item	3752776	et	0	main
vana	doc_491521501746_item	3752777	et	0	main
surnuaia	doc_491521501746_item	3752778	et	0	main
juures	doc_491521501746_item	3752779	et	0	main
siis	doc_491521501746_item	3752780	et	0	main
onu	doc_491521501746_item	3752781	et	0	main
oli	doc_491521501746_item	3752782	et	0	main
ütelnud	doc_491521501746_item	3752783	et	0	main
et	doc_491521501746_item	3752784	et	0	main
kui	doc_491521501746_item	3752785	et	0	main
sa	doc_491521501746_item	3752786	et	0	main
nüüd	doc_491521501746_item	3752787	et	0	main
ia	doc_491521501746_item	3752788	et	0	main
vaim	doc_491521501746_item	3752789	et	0	main
oled	doc_491521501746_item	3752790	et	0	main
tule	doc_491521501746_item	3752791	et	0	main
istu	doc_491521501746_item	3752792	et	0	main
peale	doc_491521501746_item	3752793	et	0	main
ja	doc_491521501746_item	3752794	et	0	main
kui	doc_491521501746_item	3752795	et	0	main
sa	doc_491521501746_item	3752796	et	0	main
paha	doc_491521501746_item	3752797	et	0	main
vaim	doc_491521501746_item	3752798	et	0	main
oled	doc_491521501746_item	3752799	et	0	main
jookse	doc_491521501746_item	3752800	et	0	main
edasi	doc_491521501746_item	3752801	et	0	main
kui	doc_491521501746_item	3752802	et	0	main
oli	doc_491521501746_item	3752803	et	0	main
kodu	doc_491521501746_item	3752804	et	0	main
poole	doc_491521501746_item	3752805	et	0	main
ära	doc_491521501746_item	3752806	et	0	main
keeranud	doc_491521501746_item	3752807	et	0	main
siis	doc_491521501746_item	3752808	et	0	main
kadus	doc_491521501746_item	3752809	et	0	main
sie	doc_491521501746_item	3752810	et	0	main
vaim	doc_491521501746_item	3752811	et	0	main
ära	doc_491521501746_item	3752812	et	0	main
läind	doc_491521501746_item	3752813	et	0	main
siis	doc_491521501746_item	3752814	et	0	main
koju	doc_491521501746_item	3752815	et	0	main
sisse	doc_491521501746_item	3752816	et	0	main
ja	doc_491521501746_item	3752817	et	0	main
akand	doc_491521501746_item	3752818	et	0	main
rääkima	doc_491521501746_item	3752819	et	0	main
ise	doc_491521501746_item	3752820	et	0	main
kole	doc_491521501746_item	3752821	et	0	main
hirmu	doc_491521501746_item	3752822	et	0	main
täis	doc_491521501746_item	3752823	et	0	main
ta	doc_491521501746_item	3752824	et	0	main
oma	doc_491521501746_item	3752825	et	0	main
poeg	doc_491521501746_item	3752826	et	0	main
oli	doc_491521501746_item	3752827	et	0	main
kuuland	doc_491521501746_item	3752828	et	0	main
seda	doc_491521501746_item	3752829	et	0	main
juttu	doc_491521501746_item	3752830	et	0	main
ja	doc_491521501746_item	3752831	et	0	main
just	doc_491521501746_item	3752832	et	0	main
üks	doc_491521501746_item	3752833	et	0	main
kass	doc_491521501746_item	3752834	et	0	main
oli	doc_491521501746_item	3752835	et	0	main
akna	doc_491521501746_item	3752836	et	0	main
taga	doc_491521501746_item	3752837	et	0	main
krabistanud	doc_491521501746_item	3752838	et	0	main
pole	doc_491521501746_item	3752839	et	0	main
öelnud	doc_491521501746_item	3752840	et	0	main
et	doc_491521501746_item	3752841	et	0	main
näe	doc_491521501746_item	3752842	et	0	main
tuligi	doc_491521501746_item	3752843	et	0	main
suule	doc_491521501746_item	3752844	et	0	main
järele	doc_491521501746_item	3752845	et	0	main
onu	doc_491521501746_item	3752846	et	0	main
läind	doc_491521501746_item	3752847	et	0	main
kohe	doc_491521501746_item	3752848	et	0	main
näost	doc_491521501746_item	3752849	et	0	main
valgeks	doc_491521501746_item	3752850	et	0	main
eks	doc_491521501746_item	3752851	et	0	main
ta	doc_491521501746_item	3752852	et	0	main
olnd	doc_491521501746_item	3752853	et	0	main
vindine	doc_491521501746_item	3752854	et	0	main
ka	doc_491521501746_item	3752855	et	0	main
nied	doc_491521501746_item	3752856	et	0	main
vindised	doc_491521501746_item	3752857	et	0	main
mehed	doc_491521501746_item	3752858	et	0	main
ikka	doc_491521501746_item	3752859	et	0	main
näevad	doc_491521501746_item	3752860	et	0	main
rohkem	doc_491521501746_item	3752861	et	0	main
rkm	doc_491521501746_item	3752862	et	0	main
ii	doc_491521501746_item	3752863	et	0	main
435	doc_491521501746_item	3752864	et	0	main
462	doc_491521501746_item	3752865	et	0	main
3	doc_491521501746_item	3752866	et	0	main
nissi	doc_491521501746_item	3752867	et	0	main
khk	doc_491521501746_item	3752868	et	0	main
laitse	doc_491521501746_item	3752869	et	0	main
v	doc_491521501746_item	3752870	et	0	main
kibuna	doc_491521501746_item	3752871	et	0	main
k	doc_491521501746_item	3752872	et	0	main
harju-madise	doc_491521501746_item	3752873	et	0	main
khk	doc_491521501746_item	3752874	et	0	main
vasalemma	doc_491521501746_item	3752875	et	0	main
as	doc_491521501746_item	3752876	et	0	main
j	doc_491521501746_item	3752877	et	0	main
oras	doc_491521501746_item	3752878	et	0	main
salme	doc_491521501746_item	3752879	et	0	main
vilhelmine	doc_491521501746_item	3752880	et	0	main
saatla	doc_491521501746_item	3752881	et	0	main
sünd	doc_491521501746_item	3752882	et	0	main
1910	doc_491521501746_item	3752883	et	0	main
1990	doc_491521501746_item	3752884	et	0	main
lk	doc_491521501746_item	3752885	et	0	main
245	doc_491521501746_item	3752886	et	0	main
katkust	doc_491521501746_item	3752887	et	0	main
pääsemine	doc_491521501746_item	3752888	et	0	main
mitu	doc_491521501746_item	3752889	et	0	main
katku-	doc_491521501746_item	3752890	et	0	main
sõjajuttu	doc_491521501746_item	3752891	et	0	main
üks	doc_491521501746_item	3752892	et	0	main
vana	doc_491521501746_item	3752893	et	0	main
laul	doc_491521501746_item	3752894	et	0	main
oli	doc_491521501746_item	3752895	et	0	main
kuda	doc_491521501746_item	3752896	et	0	main
katk	doc_491521501746_item	3752897	et	0	main
istund	doc_491521501746_item	3752898	et	0	main
lee	doc_491521501746_item	3752899	et	0	main
ääres	doc_491521501746_item	3752900	et	0	main
söönd	doc_491521501746_item	3752901	et	0	main
läätseleent	doc_491521501746_item	3752902	et	0	main
tüdruk	doc_491521501746_item	3752903	et	0	main
vahtind	doc_491521501746_item	3752904	et	0	main
lõsna	doc_491521501746_item	3752905	et	0	main
pealt	doc_491521501746_item	3752906	et	0	main
mitu	doc_491521501746_item	3752907	et	0	main
katku-	doc_491521501746_item	3752908	et	0	main
sõjajuttu	doc_491521501746_item	3752909	et	0	main
kuulsin	doc_491521501746_item	3752910	et	0	main
isa-ema	doc_491521501746_item	3752911	et	0	main
kottu	doc_491521501746_item	3752912	et	0	main
surnuid	doc_491521501746_item	3752913	et	0	main
veeti	doc_491521501746_item	3752914	et	0	main
selja	doc_491521501746_item	3752915	et	0	main
mäele	doc_491521501746_item	3752916	et	0	main
maeti	doc_491521501746_item	3752917	et	0	main
üheteise	doc_491521501746_item	3752918	et	0	main
peale	doc_491521501746_item	3752919	et	0	main
surnuid	doc_491521501746_item	3752920	et	0	main
aina	doc_491521501746_item	3752921	et	0	main
maetud	doc_491521501746_item	3752922	et	0	main
seal	doc_491521501746_item	3752923	et	0	main
kus	doc_491521501746_item	3752924	et	0	main
see	doc_491521501746_item	3752925	et	0	main
katk	doc_491521501746_item	3752926	et	0	main
kui	doc_491521501746_item	3752927	et	0	main
varas	doc_491521501746_item	3752928	et	0	main
koland	doc_491521501746_item	3752929	et	0	main
kõik	doc_491521501746_item	3752930	et	0	main
olnud	doc_491521501746_item	3752931	et	0	main
surnud	doc_491521501746_item	3752932	et	0	main
muudkui	doc_491521501746_item	3752933	et	0	main
üks	doc_491521501746_item	3752934	et	0	main
tüdruk	doc_491521501746_item	3752935	et	0	main
vahtind	doc_491521501746_item	3752936	et	0	main
lõsna	doc_491521501746_item	3752937	et	0	main
pealt	doc_491521501746_item	3752938	et	0	main
kuda	doc_491521501746_item	3752939	et	0	main
katk	doc_491521501746_item	3752940	et	0	main
söönd	doc_491521501746_item	3752941	et	0	main
läätseleent	doc_491521501746_item	3752942	et	0	main
kuid	doc_491521501746_item	3752943	et	0	main
et	doc_491521501746_item	3752944	et	0	main
katk	doc_491521501746_item	3752945	et	0	main
ei	doc_491521501746_item	3752946	et	0	main
teda	doc_491521501746_item	3752947	et	0	main
näinud	doc_491521501746_item	3752948	et	0	main
sellest	doc_491521501746_item	3752949	et	0	main
tüdruk	doc_491521501746_item	3752950	et	0	main
hinge	doc_491521501746_item	3752951	et	0	main
jäänud	doc_491521501746_item	3752952	et	0	main
era	doc_491521501746_item	3752953	et	0	main
ii	doc_491521501746_item	3752954	et	0	main
27	doc_491521501746_item	3752955	et	0	main
49950	doc_491521501746_item	3752956	et	0	main
13	doc_491521501746_item	3752957	et	0	main
nissi	doc_491521501746_item	3752958	et	0	main
khk	doc_491521501746_item	3752959	et	0	main
riisipere	doc_491521501746_item	3752960	et	0	main
v	doc_491521501746_item	3752961	et	0	main
odolemma	doc_491521501746_item	3752962	et	0	main
k	doc_491521501746_item	3752963	et	0	main
r	doc_491521501746_item	3752964	et	0	main
põldmäe	doc_491521501746_item	3752965	et	0	main
tiina	doc_491521501746_item	3752966	et	0	main
petoffer	doc_491521501746_item	3752967	et	0	main
68	doc_491521501746_item	3752968	et	0	main
a	doc_491521501746_item	3752969	et	0	main
1930	doc_491521501746_item	3752970	et	0	main
lk	doc_491521501746_item	3752971	et	0	main
258	doc_491521501746_item	3752972	et	0	main
14	doc_491521501746_item	3752973	et	0	main
eriline	doc_491521501746_item	3752974	et	0	main
magamisviis	doc_491521501746_item	3752975	et	0	main
käsi	doc_491521501746_item	3752976	et	0	main
üle	doc_491521501746_item	3752977	et	0	main
magajate	doc_491521501746_item	3752978	et	0	main
ühel	doc_491521501746_item	3752979	et	0	main
naisel	doc_491521501746_item	3752980	et	0	main
kaksikud	doc_491521501746_item	3752981	et	0	main
lapsed	doc_491521501746_item	3752982	et	0	main
magand	doc_491521501746_item	3752983	et	0	main
must	doc_491521501746_item	3752984	et	0	main
inime	doc_491521501746_item	3752985	et	0	main
tulnd	doc_491521501746_item	3752986	et	0	main
uksest	doc_491521501746_item	3752987	et	0	main
sisse	doc_491521501746_item	3752988	et	0	main
ema	doc_491521501746_item	3752989	et	0	main
pand	doc_491521501746_item	3752990	et	0	main
käed	doc_491521501746_item	3752991	et	0	main
laste	doc_491521501746_item	3752992	et	0	main
peale	doc_491521501746_item	3752993	et	0	main
et	doc_491521501746_item	3752994	et	0	main
need	doc_491521501746_item	3752995	et	0	main
on	doc_491521501746_item	3752996	et	0	main
minu	doc_491521501746_item	3752997	et	0	main
lapsed	doc_491521501746_item	3752998	et	0	main
jäänd	doc_491521501746_item	3752999	et	0	main
järele	doc_491521501746_item	3753000	et	0	main
emaga	doc_491521501746_item	3753001	et	0	main
tükkis	doc_491521501746_item	3753002	et	0	main
aga	doc_491521501746_item	3753003	et	0	main
teised	doc_491521501746_item	3753004	et	0	main
surnd	doc_491521501746_item	3753005	et	0	main
kõik	doc_491521501746_item	3753006	et	0	main
katku	doc_491521501746_item	3753007	et	0	main
need	doc_491521501746_item	3753008	et	0	main
magand	doc_491521501746_item	3753009	et	0	main
era	doc_491521501746_item	3753010	et	0	main
ii	doc_491521501746_item	3753011	et	0	main
27	doc_491521501746_item	3753012	et	0	main
575	doc_491521501746_item	3753013	et	0	main
90a	doc_491521501746_item	3753014	et	0	main
nissi	doc_491521501746_item	3753015	et	0	main
khk	doc_491521501746_item	3753016	et	0	main
varbola	doc_491521501746_item	3753017	et	0	main
v	doc_491521501746_item	3753018	et	0	main
rahula	doc_491521501746_item	3753019	et	0	main
k	doc_491521501746_item	3753020	et	0	main
harju-madise	doc_491521501746_item	3753021	et	0	main
khk	doc_491521501746_item	3753022	et	0	main
r	doc_491521501746_item	3753023	et	0	main
põldmäe	doc_491521501746_item	3753024	et	0	main
liisa	doc_491521501746_item	3753025	et	0	main
tropp	doc_491521501746_item	3753026	et	0	main
61	doc_491521501746_item	3753027	et	0	main
a	doc_491521501746_item	3753028	et	0	main
1930	doc_491521501746_item	3753029	et	0	main
lk	doc_491521501746_item	3753030	et	0	main
310	doc_491521501746_item	3753031	et	0	main
5	doc_491521501746_item	3753032	et	0	main
katku	doc_491521501746_item	3753033	et	0	main
vanker	doc_491521501746_item	3753034	et	0	main
katki	doc_491521501746_item	3753035	et	0	main
kivikalme	doc_491521501746_item	3753036	et	0	main
nissi	doc_491521501746_item	3753037	et	0	main
kiriku	doc_491521501746_item	3753038	et	0	main
ligidal	doc_491521501746_item	3753039	et	0	main
riisipere	doc_491521501746_item	3753040	et	0	main
mõisa	doc_491521501746_item	3753041	et	0	main
maa	doc_491521501746_item	3753042	et	0	main
sees	doc_491521501746_item	3753043	et	0	main
seal	doc_491521501746_item	3753044	et	0	main
mäe	doc_491521501746_item	3753045	et	0	main
sees	doc_491521501746_item	3753046	et	0	main
olla	doc_491521501746_item	3753047	et	0	main
ka	doc_491521501746_item	3753048	et	0	main
vanu	doc_491521501746_item	3753049	et	0	main
katkuhaudu	doc_491521501746_item	3753050	et	0	main
kus	doc_491521501746_item	3753051	et	0	main
inimeste	doc_491521501746_item	3753052	et	0	main
luid	doc_491521501746_item	3753053	et	0	main
kraavi	doc_491521501746_item	3753054	et	0	main
viisi	doc_491521501746_item	3753055	et	0	main
maetud	doc_491521501746_item	3753056	et	0	main
vanajutt	doc_491521501746_item	3753057	et	0	main
räägib	doc_491521501746_item	3753058	et	0	main
sellest	doc_491521501746_item	3753059	et	0	main
mäest	doc_491521501746_item	3753060	et	0	main
et	doc_491521501746_item	3753061	et	0	main
katk	doc_491521501746_item	3753062	et	0	main
seal	doc_491521501746_item	3753063	et	0	main
musta	doc_491521501746_item	3753064	et	0	main
tõllaga	doc_491521501746_item	3753065	et	0	main
ümber	doc_491521501746_item	3753066	et	0	main
sõitnud	doc_491521501746_item	3753067	et	0	main
ja	doc_491521501746_item	3753068	et	0	main
kust	doc_491521501746_item	3753069	et	0	main
ta	doc_491521501746_item	3753070	et	0	main
iial	doc_491521501746_item	3753071	et	0	main
läbi	doc_491521501746_item	3753072	et	0	main
käinud	doc_491521501746_item	3753073	et	0	main
seal	doc_491521501746_item	3753074	et	0	main
surnud	doc_491521501746_item	3753075	et	0	main
inimesi	doc_491521501746_item	3753076	et	0	main
tuhandete	doc_491521501746_item	3753077	et	0	main
kaupa	doc_491521501746_item	3753078	et	0	main
inimesed	doc_491521501746_item	3753079	et	0	main
jäänud	doc_491521501746_item	3753080	et	0	main
nii	doc_491521501746_item	3753081	et	0	main
harvaks	doc_491521501746_item	3753082	et	0	main
et	doc_491521501746_item	3753083	et	0	main
kui	doc_491521501746_item	3753084	et	0	main
keegi	doc_491521501746_item	3753085	et	0	main
teise	doc_491521501746_item	3753086	et	0	main
inimese	doc_491521501746_item	3753087	et	0	main
jalajälgi	doc_491521501746_item	3753088	et	0	main
näinud	doc_491521501746_item	3753089	et	0	main
siis	doc_491521501746_item	3753090	et	0	main
selle	doc_491521501746_item	3753091	et	0	main
rõõmu	doc_491521501746_item	3753092	et	0	main
pärast	doc_491521501746_item	3753093	et	0	main
suud	doc_491521501746_item	3753094	et	0	main
annud	doc_491521501746_item	3753095	et	0	main
olnud	doc_491521501746_item	3753096	et	0	main
katk	doc_491521501746_item	3753097	et	0	main
kõik	doc_491521501746_item	3753098	et	0	main
kohad	doc_491521501746_item	3753099	et	0	main
läbi	doc_491521501746_item	3753100	et	0	main
lasknud	doc_491521501746_item	3753101	et	0	main
siis	doc_491521501746_item	3753102	et	0	main
tahtnud	doc_491521501746_item	3753103	et	0	main
ta	doc_491521501746_item	3753104	et	0	main
siit	doc_491521501746_item	3753105	et	0	main
kohast	doc_491521501746_item	3753106	et	0	main
jälle	doc_491521501746_item	3753107	et	0	main
läbi	doc_491521501746_item	3753108	et	0	main
minna	doc_491521501746_item	3753109	et	0	main
aga	doc_491521501746_item	3753110	et	0	main
taara	doc_491521501746_item	3753111	et	0	main
ei	doc_491521501746_item	3753112	et	0	main
olla	doc_491521501746_item	3753113	et	0	main
teda	doc_491521501746_item	3753114	et	0	main
enam	doc_491521501746_item	3753115	et	0	main
lasknud	doc_491521501746_item	3753116	et	0	main
vaid	doc_491521501746_item	3753117	et	0	main
saatnud	doc_491521501746_item	3753118	et	0	main
suurt	doc_491521501746_item	3753119	et	0	main
tuult	doc_491521501746_item	3753120	et	0	main
ja	doc_491521501746_item	3753121	et	0	main
tormi	doc_491521501746_item	3753122	et	0	main
et	doc_491521501746_item	3753123	et	0	main
katku	doc_491521501746_item	3753124	et	0	main
tõld	doc_491521501746_item	3753125	et	0	main
sinna	doc_491521501746_item	3753126	et	0	main
paika	doc_491521501746_item	3753127	et	0	main
ära	doc_491521501746_item	3753128	et	0	main
lagunenud	doc_491521501746_item	3753129	et	0	main
ja	doc_491521501746_item	3753130	et	0	main
nõnda	doc_491521501746_item	3753131	et	0	main
olla	doc_491521501746_item	3753132	et	0	main
see	doc_491521501746_item	3753133	et	0	main
mägi	doc_491521501746_item	3753134	et	0	main
sinna	doc_491521501746_item	3753135	et	0	main
saanud	doc_491521501746_item	3753136	et	0	main
keda	doc_491521501746_item	3753137	et	0	main
rahvas	doc_491521501746_item	3753138	et	0	main
katkumäeks	doc_491521501746_item	3753139	et	0	main
kutsunud	doc_491521501746_item	3753140	et	0	main
trükitud	doc_491521501746_item	3753141	et	0	main
j	doc_491521501746_item	3753142	et	0	main
jung	doc_491521501746_item	3753143	et	0	main
muinasaja	doc_491521501746_item	3753144	et	0	main
teadus	doc_491521501746_item	3753145	et	0	main
eestlste	doc_491521501746_item	3753146	et	0	main
maalt	doc_491521501746_item	3753147	et	0	main
iii	doc_491521501746_item	3753148	et	0	main
1910	doc_491521501746_item	3753149	et	0	main
lk	doc_491521501746_item	3753150	et	0	main
98	doc_491521501746_item	3753151	et	0	main
nr	doc_491521501746_item	3753152	et	0	main
5	doc_491521501746_item	3753153	et	0	main
saatja	doc_491521501746_item	3753154	et	0	main
a	doc_491521501746_item	3753155	et	0	main
johanni	doc_491521501746_item	3753156	et	0	main
c	doc_491521501746_item	3753157	et	0	main
stern	doc_491521501746_item	3753158	et	0	main
estnische	doc_491521501746_item	3753159	et	0	main
volkssagen	doc_491521501746_item	3753160	et	0	main
1935	doc_491521501746_item	3753161	et	0	main
lk	doc_491521501746_item	3753162	et	0	main
209	doc_491521501746_item	3753163	et	0	main
nr	doc_491521501746_item	3753164	et	0	main
281	doc_491521501746_item	3753165	et	0	main
viidatud	doc_491521501746_item	3753166	et	0	main
jungile	doc_491521501746_item	3753167	et	0	main
1910	doc_491521501746_item	3753168	et	0	main
lk	doc_491521501746_item	3753169	et	0	main
373	doc_491521501746_item	3753170	et	0	main
3	doc_491521501746_item	3753171	et	0	main
ellujäänute	doc_491521501746_item	3753172	et	0	main
mainimine	doc_491521501746_item	3753173	et	0	main
kõik	doc_491521501746_item	3753174	et	0	main
kibuna	doc_491521501746_item	3753175	et	0	main
küla	doc_491521501746_item	3753176	et	0	main
rahvas	doc_491521501746_item	3753177	et	0	main
pidi	doc_491521501746_item	3753178	et	0	main
omavahel	doc_491521501746_item	3753179	et	0	main
kaugelt	doc_491521501746_item	3753180	et	0	main
sugulased	doc_491521501746_item	3753181	et	0	main
olema	doc_491521501746_item	3753182	et	0	main
et	doc_491521501746_item	3753183	et	0	main
siin	doc_491521501746_item	3753184	et	0	main
üks	doc_491521501746_item	3753185	et	0	main
suur	doc_491521501746_item	3753186	et	0	main
koht	doc_491521501746_item	3753187	et	0	main
kaasiku	doc_491521501746_item	3753188	et	0	main
et	doc_491521501746_item	3753189	et	0	main
seal	doc_491521501746_item	3753190	et	0	main
on	doc_491521501746_item	3753191	et	0	main
kõik	doc_491521501746_item	3753192	et	0	main
külarahvas	doc_491521501746_item	3753193	et	0	main
välja	doc_491521501746_item	3753194	et	0	main
kasvanud	doc_491521501746_item	3753195	et	0	main
aga	doc_491521501746_item	3753196	et	0	main
üks	doc_491521501746_item	3753197	et	0	main
asi	doc_491521501746_item	3753198	et	0	main
et	doc_491521501746_item	3753199	et	0	main
siin	doc_491521501746_item	3753200	et	0	main
on	doc_491521501746_item	3753201	et	0	main
väga	doc_491521501746_item	3753202	et	0	main
suur	doc_491521501746_item	3753203	et	0	main
katk	doc_491521501746_item	3753204	et	0	main
olnd	doc_491521501746_item	3753205	et	0	main
viel	doc_491521501746_item	3753206	et	0	main
pärast	doc_491521501746_item	3753207	et	0	main
põhjasõda	doc_491521501746_item	3753208	et	0	main
külas	doc_491521501746_item	3753209	et	0	main
on	doc_491521501746_item	3753210	et	0	main
kohe	doc_491521501746_item	3753211	et	0	main
suurem	doc_491521501746_item	3753212	et	0	main
osa	doc_491521501746_item	3753213	et	0	main
rahvast	doc_491521501746_item	3753214	et	0	main
ära	doc_491521501746_item	3753215	et	0	main
surnud	doc_491521501746_item	3753216	et	0	main
ja	doc_491521501746_item	3753217	et	0	main
peale	doc_491521501746_item	3753218	et	0	main
seda	doc_491521501746_item	3753219	et	0	main
katku	doc_491521501746_item	3753220	et	0	main
on	doc_491521501746_item	3753221	et	0	main
minu	doc_491521501746_item	3753222	et	0	main
isaisad	doc_491521501746_item	3753223	et	0	main
siia	doc_491521501746_item	3753224	et	0	main
tulnudki	doc_491521501746_item	3753225	et	0	main
nemad	doc_491521501746_item	3753226	et	0	main
on	doc_491521501746_item	3753227	et	0	main
enne	doc_491521501746_item	3753228	et	0	main
elanud	doc_491521501746_item	3753229	et	0	main
ruilas	doc_491521501746_item	3753230	et	0	main
rkm	doc_491521501746_item	3753231	et	0	main
ii	doc_491521501746_item	3753232	et	0	main
435	doc_491521501746_item	3753233	et	0	main
482	doc_491521501746_item	3753234	et	0	main
6	doc_491521501746_item	3753235	et	0	main
nissi	doc_491521501746_item	3753236	et	0	main
khk	doc_491521501746_item	3753237	et	0	main
kibuna	doc_491521501746_item	3753238	et	0	main
k	doc_491521501746_item	3753239	et	0	main
joras	doc_491521501746_item	3753240	et	0	main
linda	doc_491521501746_item	3753241	et	0	main
vainu	doc_491521501746_item	3753242	et	0	main
sünd	doc_491521501746_item	3753243	et	0	main
1926	doc_491521501746_item	3753244	et	0	main
1990	doc_491521501746_item	3753245	et	0	main
lk406	doc_491521501746_item	3753246	et	0	main
4	doc_491521501746_item	3753247	et	0	main
ellujäänute	doc_491521501746_item	3753248	et	0	main
edasine	doc_491521501746_item	3753249	et	0	main
elukäik	doc_491521501746_item	3753250	et	0	main
katkujärgsed	doc_491521501746_item	3753251	et	0	main
ümberasumised	doc_491521501746_item	3753252	et	0	main
munalaskmes	doc_491521501746_item	3753253	et	0	main
kobru	doc_491521501746_item	3753254	et	0	main
külas	doc_491521501746_item	3753255	et	0	main
surnud	doc_491521501746_item	3753256	et	0	main
katku	doc_491521501746_item	3753257	et	0	main
kõik	doc_491521501746_item	3753258	et	0	main
inimesed	doc_491521501746_item	3753259	et	0	main
küla	doc_491521501746_item	3753260	et	0	main
jäänud	doc_491521501746_item	3753261	et	0	main
täiesti	doc_491521501746_item	3753262	et	0	main
tühjaks	doc_491521501746_item	3753263	et	0	main
siis	doc_491521501746_item	3753264	et	0	main
toodud	doc_491521501746_item	3753265	et	0	main
soomest	doc_491521501746_item	3753266	et	0	main
üks	doc_491521501746_item	3753267	et	0	main
suurekasvuline	doc_491521501746_item	3753268	et	0	main
mees	doc_491521501746_item	3753269	et	0	main
ühes	doc_491521501746_item	3753270	et	0	main
naisega	doc_491521501746_item	3753271	et	0	main
mehe	doc_491521501746_item	3753272	et	0	main
nimi	doc_491521501746_item	3753273	et	0	main
olnud	doc_491521501746_item	3753274	et	0	main
suur-jaak	doc_491521501746_item	3753275	et	0	main
selle	doc_491521501746_item	3753276	et	0	main
mehe	doc_491521501746_item	3753277	et	0	main
järeltulijaist	doc_491521501746_item	3753278	et	0	main
tekkinud	doc_491521501746_item	3753279	et	0	main
jälle	doc_491521501746_item	3753280	et	0	main
uus	doc_491521501746_item	3753281	et	0	main
küla	doc_491521501746_item	3753282	et	0	main
see	doc_491521501746_item	3753283	et	0	main
talu	doc_491521501746_item	3753284	et	0	main
kuhu	doc_491521501746_item	3753285	et	0	main
see	doc_491521501746_item	3753286	et	0	main
mees	doc_491521501746_item	3753287	et	0	main
elama	doc_491521501746_item	3753288	et	0	main
asus	doc_491521501746_item	3753289	et	0	main
nimetati	doc_491521501746_item	3753290	et	0	main
suure-jaagu	doc_491521501746_item	3753291	et	0	main
taluks	doc_491521501746_item	3753292	et	0	main
ja	doc_491521501746_item	3753293	et	0	main
seda	doc_491521501746_item	3753294	et	0	main
nime	doc_491521501746_item	3753295	et	0	main
kannab	doc_491521501746_item	3753296	et	0	main
ta	doc_491521501746_item	3753297	et	0	main
tänapäevani	doc_491521501746_item	3753298	et	0	main
era	doc_491521501746_item	3753299	et	0	main
ii	doc_491521501746_item	3753300	et	0	main
226	doc_491521501746_item	3753301	et	0	main
20910	doc_491521501746_item	3753302	et	0	main
2	doc_491521501746_item	3753303	et	0	main
nissi	doc_491521501746_item	3753304	et	0	main
khk	doc_491521501746_item	3753305	et	0	main
riisipere	doc_491521501746_item	3753306	et	0	main
v	doc_491521501746_item	3753307	et	0	main
mustu	doc_491521501746_item	3753308	et	0	main
k	doc_491521501746_item	3753309	et	0	main
munalaskme	doc_491521501746_item	3753310	et	0	main
k	doc_491521501746_item	3753311	et	0	main
õpil	doc_491521501746_item	3753312	et	0	main
e	doc_491521501746_item	3753313	et	0	main
niinepuu	doc_491521501746_item	3753314	et	0	main
anette	doc_491521501746_item	3753315	et	0	main
niinepuu	doc_491521501746_item	3753316	et	0	main
1939	doc_491521501746_item	3753317	et	0	main
lk423	doc_491521501746_item	3753318	et	0	main
222	doc_491521501746_item	3753319	et	0	main
sõjaröövlimuistendid	doc_491521501746_item	3753320	et	0	main
sajandite	doc_491521501746_item	3753321	et	0	main
jooksul	doc_491521501746_item	3753322	et	0	main
toimunud	doc_491521501746_item	3753323	et	0	main
sõjad	doc_491521501746_item	3753324	et	0	main
oma	doc_491521501746_item	3753325	et	0	main
koledustega	doc_491521501746_item	3753326	et	0	main
on	doc_491521501746_item	3753327	et	0	main
jäänud	doc_491521501746_item	3753328	et	0	main
tugevasti	doc_491521501746_item	3753329	et	0	main
inimeste	doc_491521501746_item	3753330	et	0	main
meeltesse	doc_491521501746_item	3753331	et	0	main
nii	doc_491521501746_item	3753332	et	0	main
on	doc_491521501746_item	3753333	et	0	main
kohutavaid	doc_491521501746_item	3753334	et	0	main
muljeid	doc_491521501746_item	3753335	et	0	main
jätnud	doc_491521501746_item	3753336	et	0	main
ka	doc_491521501746_item	3753337	et	0	main
sõja	doc_491521501746_item	3753338	et	0	main
ajal	doc_491521501746_item	3753339	et	0	main
või	doc_491521501746_item	3753340	et	0	main
järel	doc_491521501746_item	3753341	et	0	main
käivad	doc_491521501746_item	3753342	et	0	main
sõjaröövlid	doc_491521501746_item	3753343	et	0	main
nende	doc_491521501746_item	3753344	et	0	main
võimalik	doc_491521501746_item	3753345	et	0	main
tegevus	doc_491521501746_item	3753346	et	0	main
varade	doc_491521501746_item	3753347	et	0	main
riisumise	doc_491521501746_item	3753348	et	0	main
tapmise	doc_491521501746_item	3753349	et	0	main
näol	doc_491521501746_item	3753350	et	0	main
on	doc_491521501746_item	3753351	et	0	main
saanud	doc_491521501746_item	3753352	et	0	main
muistendilise	doc_491521501746_item	3753353	et	0	main
sisu	doc_491521501746_item	3753354	et	0	main
mida	doc_491521501746_item	3753355	et	0	main
anti	doc_491521501746_item	3753356	et	0	main
edasi	doc_491521501746_item	3753357	et	0	main
põlvest	doc_491521501746_item	3753358	et	0	main
põlve	doc_491521501746_item	3753359	et	0	main
muistendid	doc_491521501746_item	3753360	et	0	main
sissidest	doc_491521501746_item	3753361	et	0	main
pardiajajaist	doc_491521501746_item	3753362	et	0	main
koerakoonlasestest	doc_491521501746_item	3753363	et	0	main
või	doc_491521501746_item	3753364	et	0	main
peninukkidest	doc_491521501746_item	3753365	et	0	main
on	doc_491521501746_item	3753366	et	0	main
levinud	doc_491521501746_item	3753367	et	0	main
väga	doc_491521501746_item	3753368	et	0	main
laialt	doc_491521501746_item	3753369	et	0	main
on	doc_491521501746_item	3753370	et	0	main
muidugi	doc_491521501746_item	3753371	et	0	main
vaieldav	doc_491521501746_item	3753372	et	0	main
kas	doc_491521501746_item	3753373	et	0	main
koerkoonlaste	doc_491521501746_item	3753374	et	0	main
e	doc_491521501746_item	3753375	et	0	main
peninukkide	doc_491521501746_item	3753376	et	0	main
antiikaja	doc_491521501746_item	3753377	et	0	main
künokefaalid	doc_491521501746_item	3753378	et	0	main
lugusid	doc_491521501746_item	3753379	et	0	main
pidada	doc_491521501746_item	3753380	et	0	main
rahvausundilisteks	doc_491521501746_item	3753381	et	0	main
või	doc_491521501746_item	3753382	et	0	main
ajaloomuistenditeks	doc_491521501746_item	3753383	et	0	main
viimase	doc_491521501746_item	3753384	et	0	main
kasuks	doc_491521501746_item	3753385	et	0	main
räägib	doc_491521501746_item	3753386	et	0	main
see	doc_491521501746_item	3753387	et	0	main
et	doc_491521501746_item	3753388	et	0	main
sageli	doc_491521501746_item	3753389	et	0	main
on	doc_491521501746_item	3753390	et	0	main
nad	doc_491521501746_item	3753391	et	0	main
segunenud	doc_491521501746_item	3753392	et	0	main
lugudega	doc_491521501746_item	3753393	et	0	main
sissidest	doc_491521501746_item	3753394	et	0	main
või	doc_491521501746_item	3753395	et	0	main
nn	doc_491521501746_item	3753396	et	0	main
pardiajajatest	doc_491521501746_item	3753397	et	0	main
rahvaetümoloogiline	doc_491521501746_item	3753398	et	0	main
tuletis	doc_491521501746_item	3753399	et	0	main
saksa	doc_491521501746_item	3753400	et	0	main
sõnast	doc_491521501746_item	3753401	et	0	main
parteigänger	doc_491521501746_item	3753402	et	0	main
need	doc_491521501746_item	3753403	et	0	main
lood	doc_491521501746_item	3753404	et	0	main
võivad	doc_491521501746_item	3753405	et	0	main
olla	doc_491521501746_item	3753406	et	0	main
liivi	doc_491521501746_item	3753407	et	0	main
või	doc_491521501746_item	3753408	et	0	main
ka	doc_491521501746_item	3753409	et	0	main
põhjasõja	doc_491521501746_item	3753410	et	0	main
kajastused	doc_491521501746_item	3753411	et	0	main
kokkuvõteks	doc_491521501746_item	3753412	et	0	main
võib	doc_491521501746_item	3753413	et	0	main
märkida	doc_491521501746_item	3753414	et	0	main
et	doc_491521501746_item	3753415	et	0	main
muistendid	doc_491521501746_item	3753416	et	0	main
on	doc_491521501746_item	3753417	et	0	main
meie	doc_491521501746_item	3753418	et	0	main
proosapärimuse	doc_491521501746_item	3753419	et	0	main
olulisim	doc_491521501746_item	3753420	et	0	main
ja	doc_491521501746_item	3753421	et	0	main
kindlasti	doc_491521501746_item	3753422	et	0	main
ka	doc_491521501746_item	3753423	et	0	main
algupärasem	doc_491521501746_item	3753424	et	0	main
liik	doc_491521501746_item	3753425	et	0	main
nad	doc_491521501746_item	3753426	et	0	main
on	doc_491521501746_item	3753427	et	0	main
vahetus	doc_491521501746_item	3753428	et	0	main
seoses	doc_491521501746_item	3753429	et	0	main
meie	doc_491521501746_item	3753430	et	0	main
looduse	doc_491521501746_item	3753431	et	0	main
ja	doc_491521501746_item	3753432	et	0	main
olustikuga	doc_491521501746_item	3753433	et	0	main
tedre	doc_491521501746_item	3753434	et	0	main
1998	doc_491521501746_item	3753435	et	0	main
574-575	doc_491521501746_item	3753436	et	0	main
nissi	doc_491521501746_item	3753437	et	0	main
kihelkonna	doc_491521501746_item	3753438	et	0	main
kogutud	doc_491521501746_item	3753439	et	0	main
rahvapärimustes	doc_491521501746_item	3753440	et	0	main
õnnestus	doc_491521501746_item	3753441	et	0	main
leida	doc_491521501746_item	3753442	et	0	main
ainult	doc_491521501746_item	3753443	et	0	main
ühte	doc_491521501746_item	3753444	et	0	main
muistendi	doc_491521501746_item	3753445	et	0	main
kus	doc_491521501746_item	3753446	et	0	main
oli	doc_491521501746_item	3753447	et	0	main
räägitud	doc_491521501746_item	3753448	et	0	main
röövlitest	doc_491521501746_item	3753449	et	0	main
aga	doc_491521501746_item	3753450	et	0	main
see	doc_491521501746_item	3753451	et	0	main
ei	doc_491521501746_item	3753452	et	0	main
tähenda	doc_491521501746_item	3753453	et	0	main
et	doc_491521501746_item	3753454	et	0	main
neid	doc_491521501746_item	3753455	et	0	main
ei	doc_491521501746_item	3753456	et	0	main
ole	doc_491521501746_item	3753457	et	0	main
lihtsalt	doc_491521501746_item	3753458	et	0	main
see	doc_491521501746_item	3753459	et	0	main
materjal	doc_491521501746_item	3753460	et	0	main
on	doc_491521501746_item	3753461	et	0	main
vähe	doc_491521501746_item	3753462	et	0	main
uuritud	doc_491521501746_item	3753463	et	0	main
senini	doc_491521501746_item	3753464	et	0	main
ja	doc_491521501746_item	3753465	et	0	main
see	doc_491521501746_item	3753466	et	0	main
pärimus	doc_491521501746_item	3753467	et	0	main
on	doc_491521501746_item	3753468	et	0	main
ka	doc_491521501746_item	3753469	et	0	main
pigem	doc_491521501746_item	3753470	et	0	main
seotud	doc_491521501746_item	3753471	et	0	main
kohanimetusega	doc_491521501746_item	3753472	et	0	main
kui	doc_491521501746_item	3753473	et	0	main
röövlitega	doc_491521501746_item	3753474	et	0	main
kääbaste	doc_491521501746_item	3753475	et	0	main
mäed	doc_491521501746_item	3753476	et	0	main
olid	doc_491521501746_item	3753477	et	0	main
seal	doc_491521501746_item	3753478	et	0	main
olid	doc_491521501746_item	3753479	et	0	main
laadaröövlid	doc_491521501746_item	3753480	et	0	main
olnud	doc_491521501746_item	3753481	et	0	main
varastatud	doc_491521501746_item	3753482	et	0	main
ja	doc_491521501746_item	3753483	et	0	main
võetud	doc_491521501746_item	3753484	et	0	main
inimesi	doc_491521501746_item	3753485	et	0	main
kinni	doc_491521501746_item	3753486	et	0	main
seal	doc_491521501746_item	3753487	et	0	main
vahetanud	doc_491521501746_item	3753488	et	0	main
hobuseid	doc_491521501746_item	3753489	et	0	main
ära	doc_491521501746_item	3753490	et	0	main
vankri	doc_491521501746_item	3753491	et	0	main
eest	doc_491521501746_item	3753492	et	0	main
üks	doc_491521501746_item	3753493	et	0	main
röövel	doc_491521501746_item	3753494	et	0	main
norinud	doc_491521501746_item	3753495	et	0	main
peremehega	doc_491521501746_item	3753496	et	0	main
tüli	doc_491521501746_item	3753497	et	0	main
teine	doc_491521501746_item	3753498	et	0	main
vahetas	doc_491521501746_item	3753499	et	0	main
sel	doc_491521501746_item	3753500	et	0	main
ajal	doc_491521501746_item	3753501	et	0	main
hobuse	doc_491521501746_item	3753502	et	0	main
rkm	doc_491521501746_item	3753503	et	0	main
ii	doc_491521501746_item	3753504	et	0	main
435	doc_491521501746_item	3753505	et	0	main
234	doc_491521501746_item	3753506	et	0	main
8	doc_491521501746_item	3753507	et	0	main
nissi	doc_491521501746_item	3753508	et	0	main
turba	doc_491521501746_item	3753509	et	0	main
al	doc_491521501746_item	3753510	et	0	main
ellamaa	doc_491521501746_item	3753511	et	0	main
k	doc_491521501746_item	3753512	et	0	main
kullamaa	doc_491521501746_item	3753513	et	0	main
v	doc_491521501746_item	3753514	et	0	main
päri	doc_491521501746_item	3753515	et	0	main
as	doc_491521501746_item	3753516	et	0	main
kadi	doc_491521501746_item	3753517	et	0	main
sarv	doc_491521501746_item	3753518	et	0	main
salme	doc_491521501746_item	3753519	et	0	main
villenthal	doc_491521501746_item	3753520	et	0	main
s	doc_491521501746_item	3753521	et	0	main
1923	doc_491521501746_item	3753522	et	0	main
a	doc_491521501746_item	3753523	et	0	main
1990	doc_491521501746_item	3753524	et	0	main
nissi	doc_491521501746_item	3753525	et	0	main
kihelkonnas	doc_491521501746_item	3753526	et	0	main
on	doc_491521501746_item	3753527	et	0	main
säilinud	doc_491521501746_item	3753528	et	0	main
ka	doc_491521501746_item	3753529	et	0	main
ajaloolisi	doc_491521501746_item	3753530	et	0	main
pärimusi	doc_491521501746_item	3753531	et	0	main
mis	doc_491521501746_item	3753532	et	0	main
räägivad	doc_491521501746_item	3753533	et	0	main
kogu	doc_491521501746_item	3753534	et	0	main
kihelkonna	doc_491521501746_item	3753535	et	0	main
peale	doc_491521501746_item	3753536	et	0	main
ühest	doc_491521501746_item	3753537	et	0	main
ellujäänust	doc_491521501746_item	3753538	et	0	main
tihtipeale	doc_491521501746_item	3753539	et	0	main
need	doc_491521501746_item	3753540	et	0	main
seostuvad	doc_491521501746_item	3753541	et	0	main
põhjasõjaga	doc_491521501746_item	3753542	et	0	main
põhjasõja	doc_491521501746_item	3753543	et	0	main
ajal	doc_491521501746_item	3753544	et	0	main
oli	doc_491521501746_item	3753545	et	0	main
ellamaa	doc_491521501746_item	3753546	et	0	main
küla	doc_491521501746_item	3753547	et	0	main
põlenud	doc_491521501746_item	3753548	et	0	main
enne	doc_491521501746_item	3753549	et	0	main
asus	doc_491521501746_item	3753550	et	0	main
ühel	doc_491521501746_item	3753551	et	0	main
pool	doc_491521501746_item	3753552	et	0	main
pärast	doc_491521501746_item	3753553	et	0	main
teisel	doc_491521501746_item	3753554	et	0	main
pool	doc_491521501746_item	3753555	et	0	main
maanteed	doc_491521501746_item	3753556	et	0	main
karjavärav	doc_491521501746_item	3753557	et	0	main
läks	doc_491521501746_item	3753558	et	0	main
alla	doc_491521501746_item	3753559	et	0	main
põllu	doc_491521501746_item	3753560	et	0	main
seest	doc_491521501746_item	3753561	et	0	main
tuli	doc_491521501746_item	3753562	et	0	main
välja	doc_491521501746_item	3753563	et	0	main
inimeste	doc_491521501746_item	3753564	et	0	main
luud	doc_491521501746_item	3753565	et	0	main
rkm	doc_491521501746_item	3753566	et	0	main
ii	doc_491521501746_item	3753567	et	0	main
435	doc_491521501746_item	3753568	et	0	main
232	doc_491521501746_item	3753569	et	0	main
2	doc_491521501746_item	3753570	et	0	main
nissi	doc_491521501746_item	3753571	et	0	main
turba	doc_491521501746_item	3753572	et	0	main
al	doc_491521501746_item	3753573	et	0	main
ellamaa	doc_491521501746_item	3753574	et	0	main
k	doc_491521501746_item	3753575	et	0	main
kullamaa	doc_491521501746_item	3753576	et	0	main
v	doc_491521501746_item	3753577	et	0	main
päri	doc_491521501746_item	3753578	et	0	main
as	doc_491521501746_item	3753579	et	0	main
kadi	doc_491521501746_item	3753580	et	0	main
sarv	doc_491521501746_item	3753581	et	0	main
salme	doc_491521501746_item	3753582	et	0	main
villenthal	doc_491521501746_item	3753583	et	0	main
s	doc_491521501746_item	3753584	et	0	main
1923	doc_491521501746_item	3753585	et	0	main
a	doc_491521501746_item	3753586	et	0	main
1990	doc_491521501746_item	3753587	et	0	main
põhjasõja	doc_491521501746_item	3753588	et	0	main
ajal	doc_491521501746_item	3753589	et	0	main
ajanud	doc_491521501746_item	3753590	et	0	main
venelased	doc_491521501746_item	3753591	et	0	main
rootsi	doc_491521501746_item	3753592	et	0	main
sõjavägede	doc_491521501746_item	3753593	et	0	main
päris	doc_491521501746_item	3753594	et	0	main
juhti	doc_491521501746_item	3753595	et	0	main
taga	doc_491521501746_item	3753596	et	0	main
see	doc_491521501746_item	3753597	et	0	main
põgenes	doc_491521501746_item	3753598	et	0	main
ja	doc_491521501746_item	3753599	et	0	main
peitis	doc_491521501746_item	3753600	et	0	main
ennast	doc_491521501746_item	3753601	et	0	main
saapa	doc_491521501746_item	3753602	et	0	main
tallu	doc_491521501746_item	3753603	et	0	main
puges	doc_491521501746_item	3753604	et	0	main
leivakünasse	doc_491521501746_item	3753605	et	0	main
vanaema	doc_491521501746_item	3753606	et	0	main
pani	doc_491521501746_item	3753607	et	0	main
ka	doc_491521501746_item	3753608	et	0	main
jahu	doc_491521501746_item	3753609	et	0	main
peale	doc_491521501746_item	3753610	et	0	main
vaenlased	doc_491521501746_item	3753611	et	0	main
ei	doc_491521501746_item	3753612	et	0	main
leidnud	doc_491521501746_item	3753613	et	0	main
teda	doc_491521501746_item	3753614	et	0	main
üles	doc_491521501746_item	3753615	et	0	main
sõjavägede	doc_491521501746_item	3753616	et	0	main
juht	doc_491521501746_item	3753617	et	0	main
kaotanud	doc_491521501746_item	3753618	et	0	main
talu	doc_491521501746_item	3753619	et	0	main
hoovis	doc_491521501746_item	3753620	et	0	main
hobuse	doc_491521501746_item	3753621	et	0	main
seljast	doc_491521501746_item	3753622	et	0	main
maha	doc_491521501746_item	3753623	et	0	main
hüpates	doc_491521501746_item	3753624	et	0	main
oma	doc_491521501746_item	3753625	et	0	main
saapa	doc_491521501746_item	3753626	et	0	main
sellest	doc_491521501746_item	3753627	et	0	main
sai	doc_491521501746_item	3753628	et	0	main
saapa	doc_491521501746_item	3753629	et	0	main
talu	doc_491521501746_item	3753630	et	0	main
oma	doc_491521501746_item	3753631	et	0	main
nime	doc_491521501746_item	3753632	et	0	main
rkm	doc_491521501746_item	3753633	et	0	main
ii	doc_491521501746_item	3753634	et	0	main
435	doc_491521501746_item	3753635	et	0	main
232233	doc_491521501746_item	3753636	et	0	main
4	doc_491521501746_item	3753637	et	0	main
nissi	doc_491521501746_item	3753638	et	0	main
turba	doc_491521501746_item	3753639	et	0	main
al	doc_491521501746_item	3753640	et	0	main
ellamaa	doc_491521501746_item	3753641	et	0	main
k	doc_491521501746_item	3753642	et	0	main
kullamaa	doc_491521501746_item	3753643	et	0	main
v	doc_491521501746_item	3753644	et	0	main
päri	doc_491521501746_item	3753645	et	0	main
as	doc_491521501746_item	3753646	et	0	main
kadi	doc_491521501746_item	3753647	et	0	main
sarv	doc_491521501746_item	3753648	et	0	main
salme	doc_491521501746_item	3753649	et	0	main
villenthal	doc_491521501746_item	3753650	et	0	main
s	doc_491521501746_item	3753651	et	0	main
1923	doc_491521501746_item	3753652	et	0	main
a	doc_491521501746_item	3753653	et	0	main
1990	doc_491521501746_item	3753654	et	0	main
ellamaa	doc_491521501746_item	3753655	et	0	main
mäe	doc_491521501746_item	3753656	et	0	main
peal	doc_491521501746_item	3753657	et	0	main
on	doc_491521501746_item	3753658	et	0	main
suur	doc_491521501746_item	3753659	et	0	main
kivi	doc_491521501746_item	3753660	et	0	main
nagu	doc_491521501746_item	3753661	et	0	main
pool	doc_491521501746_item	3753662	et	0	main
tuba	doc_491521501746_item	3753663	et	0	main
põhjasõja	doc_491521501746_item	3753664	et	0	main
ajal	doc_491521501746_item	3753665	et	0	main
oli	doc_491521501746_item	3753666	et	0	main
osa	doc_491521501746_item	3753667	et	0	main
kivist	doc_491521501746_item	3753668	et	0	main
nagu	doc_491521501746_item	3753669	et	0	main
laeva	doc_491521501746_item	3753670	et	0	main
nina	doc_491521501746_item	3753671	et	0	main
maast	doc_491521501746_item	3753672	et	0	main
lahti	doc_491521501746_item	3753673	et	0	main
üks	doc_491521501746_item	3753674	et	0	main
naine	doc_491521501746_item	3753675	et	0	main
varjanud	doc_491521501746_item	3753676	et	0	main
end	doc_491521501746_item	3753677	et	0	main
selle	doc_491521501746_item	3753678	et	0	main
kivi	doc_491521501746_item	3753679	et	0	main
all	doc_491521501746_item	3753680	et	0	main
ja	doc_491521501746_item	3753681	et	0	main
sünnitanud	doc_491521501746_item	3753682	et	0	main
seal	doc_491521501746_item	3753683	et	0	main
lapse	doc_491521501746_item	3753684	et	0	main
mõlemad	doc_491521501746_item	3753685	et	0	main
jäid	doc_491521501746_item	3753686	et	0	main
ellu	doc_491521501746_item	3753687	et	0	main
rkm	doc_491521501746_item	3753688	et	0	main
ii	doc_491521501746_item	3753689	et	0	main
435	doc_491521501746_item	3753690	et	0	main
233	doc_491521501746_item	3753691	et	0	main
5	doc_491521501746_item	3753692	et	0	main
nissi	doc_491521501746_item	3753693	et	0	main
turba	doc_491521501746_item	3753694	et	0	main
al	doc_491521501746_item	3753695	et	0	main
ellamaa	doc_491521501746_item	3753696	et	0	main
k	doc_491521501746_item	3753697	et	0	main
kullamaa	doc_491521501746_item	3753698	et	0	main
v	doc_491521501746_item	3753699	et	0	main
päri	doc_491521501746_item	3753700	et	0	main
as	doc_491521501746_item	3753701	et	0	main
kadi	doc_491521501746_item	3753702	et	0	main
sarv	doc_491521501746_item	3753703	et	0	main
salme	doc_491521501746_item	3753704	et	0	main
villenthal	doc_491521501746_item	3753705	et	0	main
s	doc_491521501746_item	3753706	et	0	main
1923	doc_491521501746_item	3753707	et	0	main
a	doc_491521501746_item	3753708	et	0	main
1990	doc_491521501746_item	3753709	et	0	main
põhjasja	doc_491521501746_item	3753710	et	0	main
aeg	doc_491521501746_item	3753711	et	0	main
olnud	doc_491521501746_item	3753712	et	0	main
niimoodi	doc_491521501746_item	3753713	et	0	main
et	doc_491521501746_item	3753714	et	0	main
üks	doc_491521501746_item	3753715	et	0	main
ainukene	doc_491521501746_item	3753716	et	0	main
inimene	doc_491521501746_item	3753717	et	0	main
jäänud	doc_491521501746_item	3753718	et	0	main
järele	doc_491521501746_item	3753719	et	0	main
jaagu	doc_491521501746_item	3753720	et	0	main
talusse	doc_491521501746_item	3753721	et	0	main
üks	doc_491521501746_item	3753722	et	0	main
vana	doc_491521501746_item	3753723	et	0	main
neti	doc_491521501746_item	3753724	et	0	main
jäänud	doc_491521501746_item	3753725	et	0	main
järele	doc_491521501746_item	3753726	et	0	main
lauda	doc_491521501746_item	3753727	et	0	main
ukse	doc_491521501746_item	3753728	et	0	main
olid	doc_491521501746_item	3753729	et	0	main
vene	doc_491521501746_item	3753730	et	0	main
soldatid	doc_491521501746_item	3753731	et	0	main
tõmmanud	doc_491521501746_item	3753732	et	0	main
lahti	doc_491521501746_item	3753733	et	0	main
ja	doc_491521501746_item	3753734	et	0	main
õeld	doc_491521501746_item	3753735	et	0	main
netu	doc_491521501746_item	3753736	et	0	main
aga	doc_491521501746_item	3753737	et	0	main
tema	doc_491521501746_item	3753738	et	0	main
oli	doc_491521501746_item	3753739	et	0	main
seal	doc_491521501746_item	3753740	et	0	main
peidus	doc_491521501746_item	3753741	et	0	main
olnud	doc_491521501746_item	3753742	et	0	main
ja	doc_491521501746_item	3753743	et	0	main
öeld	doc_491521501746_item	3753744	et	0	main
ma	doc_491521501746_item	3753745	et	0	main
olen	doc_491521501746_item	3753746	et	0	main
siin	doc_491521501746_item	3753747	et	0	main
oli	doc_491521501746_item	3753748	et	0	main
arvand	doc_491521501746_item	3753749	et	0	main
et	doc_491521501746_item	3753750	et	0	main
teda	doc_491521501746_item	3753751	et	0	main
kutsutakse	doc_491521501746_item	3753752	et	0	main
hiiemäe	doc_491521501746_item	3753753	et	0	main
rkm	doc_491521501746_item	3753754	et	0	main
ii	doc_491521501746_item	3753755	et	0	main
434	doc_491521501746_item	3753756	et	0	main
120	doc_491521501746_item	3753757	et	0	main
3	doc_491521501746_item	3753758	et	0	main
riisipere	doc_491521501746_item	3753759	et	0	main
v	doc_491521501746_item	3753760	et	0	main
nurme	doc_491521501746_item	3753761	et	0	main
k	doc_491521501746_item	3753762	et	0	main
nissi	doc_491521501746_item	3753763	et	0	main
khk	doc_491521501746_item	3753764	et	0	main
lehetu	doc_491521501746_item	3753765	et	0	main
k	doc_491521501746_item	3753766	et	0	main
mall	doc_491521501746_item	3753767	et	0	main
hiiemäe	doc_491521501746_item	3753768	et	0	main
august	doc_491521501746_item	3753769	et	0	main
lehtme	doc_491521501746_item	3753770	et	0	main
s	doc_491521501746_item	3753771	et	0	main
1919	doc_491521501746_item	3753772	et	0	main
a	doc_491521501746_item	3753773	et	0	main
1990	doc_491521501746_item	3753774	et	0	main
siin	doc_491521501746_item	3753775	et	0	main
lehetus	doc_491521501746_item	3753776	et	0	main
kus	doc_491521501746_item	3753777	et	0	main
see	doc_491521501746_item	3753778	et	0	main
suur	doc_491521501746_item	3753779	et	0	main
tamm	doc_491521501746_item	3753780	et	0	main
on	doc_491521501746_item	3753781	et	0	main
siin	doc_491521501746_item	3753782	et	0	main
on	doc_491521501746_item	3753783	et	0	main
see	doc_491521501746_item	3753784	et	0	main
kuur	doc_491521501746_item	3753785	et	0	main
kas	doc_491521501746_item	3753786	et	0	main
oli	doc_491521501746_item	3753787	et	0	main
see	doc_491521501746_item	3753788	et	0	main
põhjasõja	doc_491521501746_item	3753789	et	0	main
ajal	doc_491521501746_item	3753790	et	0	main
olnud	doc_491521501746_item	3753791	et	0	main
üks	doc_491521501746_item	3753792	et	0	main
küün	doc_491521501746_item	3753793	et	0	main
ja	doc_491521501746_item	3753794	et	0	main
inimesed	doc_491521501746_item	3753795	et	0	main
olid	doc_491521501746_item	3753796	et	0	main
sinna	doc_491521501746_item	3753797	et	0	main
peitu	doc_491521501746_item	3753798	et	0	main
läinud	doc_491521501746_item	3753799	et	0	main
ja	doc_491521501746_item	3753800	et	0	main
olid	doc_491521501746_item	3753801	et	0	main
sõjamehed	doc_491521501746_item	3753802	et	0	main
tulnud	doc_491521501746_item	3753803	et	0	main
tõmmanud	doc_491521501746_item	3753804	et	0	main
selle	doc_491521501746_item	3753805	et	0	main
küüne	doc_491521501746_item	3753806	et	0	main
ukse	doc_491521501746_item	3753807	et	0	main
lahti	doc_491521501746_item	3753808	et	0	main
ja	doc_491521501746_item	3753809	et	0	main
ütlend	doc_491521501746_item	3753810	et	0	main
otsind	doc_491521501746_item	3753811	et	0	main
inimesi	doc_491521501746_item	3753812	et	0	main
kedagi	doc_491521501746_item	3753813	et	0	main
pole	doc_491521501746_item	3753814	et	0	main
olnud	doc_491521501746_item	3753815	et	0	main
ütlend	doc_491521501746_item	3753816	et	0	main
netu	doc_491521501746_item	3753817	et	0	main
üks	doc_491521501746_item	3753818	et	0	main
olnud	doc_491521501746_item	3753819	et	0	main
seal	doc_491521501746_item	3753820	et	0	main
hulgas	doc_491521501746_item	3753821	et	0	main
see	doc_491521501746_item	3753822	et	0	main
tulnd	doc_491521501746_item	3753823	et	0	main
välja	doc_491521501746_item	3753824	et	0	main
ja	doc_491521501746_item	3753825	et	0	main
ütlend	doc_491521501746_item	3753826	et	0	main
imestusega	doc_491521501746_item	3753827	et	0	main
kus	doc_491521501746_item	3753828	et	0	main
te	doc_491521501746_item	3753829	et	0	main
teate	doc_491521501746_item	3753830	et	0	main
et	doc_491521501746_item	3753831	et	0	main
mu	doc_491521501746_item	3753832	et	0	main
nimi	doc_491521501746_item	3753833	et	0	main
neti	doc_491521501746_item	3753834	et	0	main
on	doc_491521501746_item	3753835	et	0	main
nii	doc_491521501746_item	3753836	et	0	main
leitud	doc_491521501746_item	3753837	et	0	main
kõik	doc_491521501746_item	3753838	et	0	main
üles	doc_491521501746_item	3753839	et	0	main
kes	doc_491521501746_item	3753840	et	0	main
seal	doc_491521501746_item	3753841	et	0	main
peidus	doc_491521501746_item	3753842	et	0	main
olid	doc_491521501746_item	3753843	et	0	main
see	doc_491521501746_item	3753844	et	0	main
tamm	doc_491521501746_item	3753845	et	0	main
on	doc_491521501746_item	3753846	et	0	main
praegu	doc_491521501746_item	3753847	et	0	main
alles	doc_491521501746_item	3753848	et	0	main
kus	doc_491521501746_item	3753849	et	0	main
see	doc_491521501746_item	3753850	et	0	main
küün	doc_491521501746_item	3753851	et	0	main
oli	doc_491521501746_item	3753852	et	0	main
nende	doc_491521501746_item	3753853	et	0	main
peidusolijatega	doc_491521501746_item	3753854	et	0	main
see	doc_491521501746_item	3753855	et	0	main
on	doc_491521501746_item	3753856	et	0	main
alles	doc_491521501746_item	3753857	et	0	main
seal	doc_491521501746_item	3753858	et	0	main
see	doc_491521501746_item	3753859	et	0	main
tamm	doc_491521501746_item	3753860	et	0	main
näed	doc_491521501746_item	3753861	et	0	main
inimesi	doc_491521501746_item	3753862	et	0	main
olnd	doc_491521501746_item	3753863	et	0	main
nii	doc_491521501746_item	3753864	et	0	main
vähe	doc_491521501746_item	3753865	et	0	main
et	doc_491521501746_item	3753866	et	0	main
mahtunud	doc_491521501746_item	3753867	et	0	main
kõik	doc_491521501746_item	3753868	et	0	main
ühte	doc_491521501746_item	3753869	et	0	main
küüni	doc_491521501746_item	3753870	et	0	main
ära	doc_491521501746_item	3753871	et	0	main
ja	doc_491521501746_item	3753872	et	0	main
sellest	doc_491521501746_item	3753873	et	0	main
sugustki	doc_491521501746_item	3753874	et	0	main
pole	doc_491521501746_item	3753875	et	0	main
enam	doc_491521501746_item	3753876	et	0	main
kedagi	doc_491521501746_item	3753877	et	0	main
olemas	doc_491521501746_item	3753878	et	0	main
rkm	doc_491521501746_item	3753879	et	0	main
ii	doc_491521501746_item	3753880	et	0	main
image	doc_491521501746_item	3753881	et	0	main
chromeskypefftoolbarwincontentcbtransparentlgif	doc_491521501746_item	3753882	et	0	main
image	doc_491521501746_item	3753883	et	0	main
chromeskypefftoolbarwincontentfamfamfameegif	doc_491521501746_item	3753884	et	0	main
image	doc_491521501746_item	3753885	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3753886	et	0	main
image	doc_491521501746_item	3753887	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3753888	et	0	main
image	doc_491521501746_item	3753889	et	0	main
chromeskypefftoolbarwincontentarrowgif	doc_491521501746_item	3753890	et	0	main
image	doc_491521501746_item	3753891	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3753892	et	0	main
image	doc_491521501746_item	3753893	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3753894	et	0	main
image	doc_491521501746_item	3753895	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3753896	et	0	main
image	doc_491521501746_item	3753897	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3753898	et	0	main
image	doc_491521501746_item	3753899	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3753900	et	0	main
image	doc_491521501746_item	3753901	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3753902	et	0	main
image	doc_491521501746_item	3753903	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3753904	et	0	main
434	doc_491521501746_item	3753905	et	0	main
8990	doc_491521501746_item	3753906	et	0	main
image	doc_491521501746_item	3753907	et	0	main
chromeskypefftoolbarwincontentcbtransparentrgif	doc_491521501746_item	3753908	et	0	main
3	doc_491521501746_item	3753909	et	0	main
nissi	doc_491521501746_item	3753910	et	0	main
khk	doc_491521501746_item	3753911	et	0	main
lehetu	doc_491521501746_item	3753912	et	0	main
k	doc_491521501746_item	3753913	et	0	main
keldrimäe	doc_491521501746_item	3753914	et	0	main
talu	doc_491521501746_item	3753915	et	0	main
mall	doc_491521501746_item	3753916	et	0	main
hiiemäe	doc_491521501746_item	3753917	et	0	main
liisi	doc_491521501746_item	3753918	et	0	main
laitamm	doc_491521501746_item	3753919	et	0	main
81	doc_491521501746_item	3753920	et	0	main
a	doc_491521501746_item	3753921	et	0	main
1990	doc_491521501746_item	3753922	et	0	main
eesti	doc_491521501746_item	3753923	et	0	main
rahvapärimuses	doc_491521501746_item	3753924	et	0	main
tegelike	doc_491521501746_item	3753925	et	0	main
isikutega	doc_491521501746_item	3753926	et	0	main
seostuvaib	doc_491521501746_item	3753927	et	0	main
muistendeid	doc_491521501746_item	3753928	et	0	main
on	doc_491521501746_item	3753929	et	0	main
vähe	doc_491521501746_item	3753930	et	0	main
nissi	doc_491521501746_item	3753931	et	0	main
kihelkonnas	doc_491521501746_item	3753932	et	0	main
on	doc_491521501746_item	3753933	et	0	main
säilinud	doc_491521501746_item	3753934	et	0	main
mõni	doc_491521501746_item	3753935	et	0	main
lugu	doc_491521501746_item	3753936	et	0	main
rootsi	doc_491521501746_item	3753937	et	0	main
kuningast	doc_491521501746_item	3753938	et	0	main
karl	doc_491521501746_item	3753939	et	0	main
xii	doc_491521501746_item	3753940	et	0	main
ta	doc_491521501746_item	3753941	et	0	main
on	doc_491521501746_item	3753942	et	0	main
eestis	doc_491521501746_item	3753943	et	0	main
käinud	doc_491521501746_item	3753944	et	0	main
sellest	doc_491521501746_item	3753945	et	0	main
ka	doc_491521501746_item	3753946	et	0	main
pärimus	doc_491521501746_item	3753947	et	0	main
siin	doc_491521501746_item	3753948	et	0	main
oli	doc_491521501746_item	3753949	et	0	main
kaarel	doc_491521501746_item	3753950	et	0	main
kaheteistkümnes	doc_491521501746_item	3753951	et	0	main
ta	doc_491521501746_item	3753952	et	0	main
sõitis	doc_491521501746_item	3753953	et	0	main
nii	doc_491521501746_item	3753954	et	0	main
et	doc_491521501746_item	3753955	et	0	main
kus	doc_491521501746_item	3753956	et	0	main
kõige	doc_491521501746_item	3753957	et	0	main
kangem	doc_491521501746_item	3753958	et	0	main
lahing	doc_491521501746_item	3753959	et	0	main
old	doc_491521501746_item	3753960	et	0	main
siis	doc_491521501746_item	3753961	et	0	main
ta	doc_491521501746_item	3753962	et	0	main
sinna	doc_491521501746_item	3753963	et	0	main
läks	doc_491521501746_item	3753964	et	0	main
kas	doc_491521501746_item	3753965	et	0	main
nüüd	doc_491521501746_item	3753966	et	0	main
koa	doc_491521501746_item	3753967	et	0	main
kuningas	doc_491521501746_item	3753968	et	0	main
ise	doc_491521501746_item	3753969	et	0	main
sõtta	doc_491521501746_item	3753970	et	0	main
lähvad	doc_491521501746_item	3753971	et	0	main
era	doc_491521501746_item	3753972	et	0	main
ii	doc_491521501746_item	3753973	et	0	main
77	doc_491521501746_item	3753974	et	0	main
543544	doc_491521501746_item	3753975	et	0	main
37	doc_491521501746_item	3753976	et	0	main
põlli	doc_491521501746_item	3753977	et	0	main
k	doc_491521501746_item	3753978	et	0	main
varbola	doc_491521501746_item	3753979	et	0	main
v	doc_491521501746_item	3753980	et	0	main
nissi	doc_491521501746_item	3753981	et	0	main
haiba	doc_491521501746_item	3753982	et	0	main
kernu	doc_491521501746_item	3753983	et	0	main
hageri	doc_491521501746_item	3753984	et	0	main
rpõldmäe	doc_491521501746_item	3753985	et	0	main
ants	doc_491521501746_item	3753986	et	0	main
toomberg	doc_491521501746_item	3753987	et	0	main
84	doc_491521501746_item	3753988	et	0	main
a	doc_491521501746_item	3753989	et	0	main
1934	doc_491521501746_item	3753990	et	0	main
kernu	doc_491521501746_item	3753991	et	0	main
kadakas	doc_491521501746_item	3753992	et	0	main
on	doc_491521501746_item	3753993	et	0	main
pärnu	doc_491521501746_item	3753994	et	0	main
tee	doc_491521501746_item	3753995	et	0	main
ääres	doc_491521501746_item	3753996	et	0	main
karl	doc_491521501746_item	3753997	et	0	main
xii	doc_491521501746_item	3753998	et	0	main
sõitis	doc_491521501746_item	3753999	et	0	main
läbi	doc_491521501746_item	3754000	et	0	main
ja	doc_491521501746_item	3754001	et	0	main
istutas	doc_491521501746_item	3754002	et	0	main
selle	doc_491521501746_item	3754003	et	0	main
kernu	doc_491521501746_item	3754004	et	0	main
kool	doc_491521501746_item	3754005	et	0	main
hooldas	doc_491521501746_item	3754006	et	0	main
teda	doc_491521501746_item	3754007	et	0	main
rkm	doc_491521501746_item	3754008	et	0	main
ii	doc_491521501746_item	3754009	et	0	main
435	doc_491521501746_item	3754010	et	0	main
130	doc_491521501746_item	3754011	et	0	main
3	doc_491521501746_item	3754012	et	0	main
nissi	doc_491521501746_item	3754013	et	0	main
harku	doc_491521501746_item	3754014	et	0	main
k	doc_491521501746_item	3754015	et	0	main
vahemetsa	doc_491521501746_item	3754016	et	0	main
talukoht	doc_491521501746_item	3754017	et	0	main
mare	doc_491521501746_item	3754018	et	0	main
janneste	doc_491521501746_item	3754019	et	0	main
anne	doc_491521501746_item	3754020	et	0	main
karotamm	doc_491521501746_item	3754021	et	0	main
s	doc_491521501746_item	3754022	et	0	main
1939	doc_491521501746_item	3754023	et	0	main
a	doc_491521501746_item	3754024	et	0	main
töötanud	doc_491521501746_item	3754025	et	0	main
algklasside	doc_491521501746_item	3754026	et	0	main
õpetajana	doc_491521501746_item	3754027	et	0	main
tallinnas	doc_491521501746_item	3754028	et	0	main
1990	doc_491521501746_item	3754029	et	0	main
munalaskme	doc_491521501746_item	3754030	et	0	main
tee	doc_491521501746_item	3754031	et	0	main
ääres	doc_491521501746_item	3754032	et	0	main
on	doc_491521501746_item	3754033	et	0	main
üks	doc_491521501746_item	3754034	et	0	main
mänd	doc_491521501746_item	3754035	et	0	main
et	doc_491521501746_item	3754036	et	0	main
rootsi	doc_491521501746_item	3754037	et	0	main
kuningas	doc_491521501746_item	3754038	et	0	main
olla	doc_491521501746_item	3754039	et	0	main
selle	doc_491521501746_item	3754040	et	0	main
istutand	doc_491521501746_item	3754041	et	0	main
et	doc_491521501746_item	3754042	et	0	main
kui	doc_491521501746_item	3754043	et	0	main
hakkab	doc_491521501746_item	3754044	et	0	main
kasvama	doc_491521501746_item	3754045	et	0	main
siis	doc_491521501746_item	3754046	et	0	main
pidi	doc_491521501746_item	3754047	et	0	main
tagasi	doc_491521501746_item	3754048	et	0	main
tulema	doc_491521501746_item	3754049	et	0	main
ega	doc_491521501746_item	3754050	et	0	main
ta	doc_491521501746_item	3754051	et	0	main
praegu	doc_491521501746_item	3754052	et	0	main
veel	doc_491521501746_item	3754053	et	0	main
kuivanud	doc_491521501746_item	3754054	et	0	main
ei	doc_491521501746_item	3754055	et	0	main
ole	doc_491521501746_item	3754056	et	0	main
pool	doc_491521501746_item	3754057	et	0	main
kasvab	doc_491521501746_item	3754058	et	0	main
võib	doc_491521501746_item	3754059	et	0	main
olla	doc_491521501746_item	3754060	et	0	main
tulebki	doc_491521501746_item	3754061	et	0	main
tagasi	doc_491521501746_item	3754062	et	0	main
ma	doc_491521501746_item	3754063	et	0	main
sõitsin	doc_491521501746_item	3754064	et	0	main
just	doc_491521501746_item	3754065	et	0	main
bussiga	doc_491521501746_item	3754066	et	0	main
mööda	doc_491521501746_item	3754067	et	0	main
siis	doc_491521501746_item	3754068	et	0	main
vaaatasin	doc_491521501746_item	3754069	et	0	main
rkm	doc_491521501746_item	3754070	et	0	main
ii	doc_491521501746_item	3754071	et	0	main
image	doc_491521501746_item	3754072	et	0	main
chromeskypefftoolbarwincontentcbtransparentlgif	doc_491521501746_item	3754073	et	0	main
image	doc_491521501746_item	3754074	et	0	main
chromeskypefftoolbarwincontentfamfamfameegif	doc_491521501746_item	3754075	et	0	main
image	doc_491521501746_item	3754076	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3754077	et	0	main
image	doc_491521501746_item	3754078	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3754079	et	0	main
image	doc_491521501746_item	3754080	et	0	main
chromeskypefftoolbarwincontentarrowgif	doc_491521501746_item	3754081	et	0	main
image	doc_491521501746_item	3754082	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3754083	et	0	main
image	doc_491521501746_item	3754084	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3754085	et	0	main
image	doc_491521501746_item	3754086	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3754087	et	0	main
image	doc_491521501746_item	3754088	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3754089	et	0	main
image	doc_491521501746_item	3754090	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3754091	et	0	main
image	doc_491521501746_item	3754092	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3754093	et	0	main
image	doc_491521501746_item	3754094	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3754095	et	0	main
434	doc_491521501746_item	3754096	et	0	main
9899	doc_491521501746_item	3754097	et	0	main
image	doc_491521501746_item	3754098	et	0	main
chromeskypefftoolbarwincontentcbtransparentrgif	doc_491521501746_item	3754099	et	0	main
2	doc_491521501746_item	3754100	et	0	main
nissi	doc_491521501746_item	3754101	et	0	main
khk	doc_491521501746_item	3754102	et	0	main
riisipere	doc_491521501746_item	3754103	et	0	main
v	doc_491521501746_item	3754104	et	0	main
terjatu	doc_491521501746_item	3754105	et	0	main
k	doc_491521501746_item	3754106	et	0	main
lehetu	doc_491521501746_item	3754107	et	0	main
k	doc_491521501746_item	3754108	et	0	main
mall	doc_491521501746_item	3754109	et	0	main
hiiemäe	doc_491521501746_item	3754110	et	0	main
linda	doc_491521501746_item	3754111	et	0	main
linroos	doc_491521501746_item	3754112	et	0	main
s	doc_491521501746_item	3754113	et	0	main
1924	doc_491521501746_item	3754114	et	0	main
a	doc_491521501746_item	3754115	et	0	main
1990	doc_491521501746_item	3754116	et	0	main
mingil	doc_491521501746_item	3754117	et	0	main
määral	doc_491521501746_item	3754118	et	0	main
on	doc_491521501746_item	3754119	et	0	main
muistendipärimust	doc_491521501746_item	3754120	et	0	main
mõjutanud	doc_491521501746_item	3754121	et	0	main
ka	doc_491521501746_item	3754122	et	0	main
lähiminevik	doc_491521501746_item	3754123	et	0	main
näiteks	doc_491521501746_item	3754124	et	0	main
lood	doc_491521501746_item	3754125	et	0	main
metsavendadest	doc_491521501746_item	3754126	et	0	main
vigalas	doc_491521501746_item	3754127	et	0	main
olevat	doc_491521501746_item	3754128	et	0	main
üks	doc_491521501746_item	3754129	et	0	main
talu	doc_491521501746_item	3754130	et	0	main
ja	doc_491521501746_item	3754131	et	0	main
öösel	doc_491521501746_item	3754132	et	0	main
seal	doc_491521501746_item	3754133	et	0	main
kummitab	doc_491521501746_item	3754134	et	0	main
suur	doc_491521501746_item	3754135	et	0	main
laud	doc_491521501746_item	3754136	et	0	main
on	doc_491521501746_item	3754137	et	0	main
ja	doc_491521501746_item	3754138	et	0	main
laua	doc_491521501746_item	3754139	et	0	main
ääres	doc_491521501746_item	3754140	et	0	main
on	doc_491521501746_item	3754141	et	0	main
mehed	doc_491521501746_item	3754142	et	0	main
ja	doc_491521501746_item	3754143	et	0	main
räägivad	doc_491521501746_item	3754144	et	0	main
rääkimisest	doc_491521501746_item	3754145	et	0	main
aru	doc_491521501746_item	3754146	et	0	main
ei	doc_491521501746_item	3754147	et	0	main
saa	doc_491521501746_item	3754148	et	0	main
arvatakse	doc_491521501746_item	3754149	et	0	main
et	doc_491521501746_item	3754150	et	0	main
need	doc_491521501746_item	3754151	et	0	main
on	doc_491521501746_item	3754152	et	0	main
need	doc_491521501746_item	3754153	et	0	main
metsavennad	doc_491521501746_item	3754154	et	0	main
kes	doc_491521501746_item	3754155	et	0	main
seal	doc_491521501746_item	3754156	et	0	main
talus	doc_491521501746_item	3754157	et	0	main
ära	doc_491521501746_item	3754158	et	0	main
tapeti	doc_491521501746_item	3754159	et	0	main
on	doc_491521501746_item	3754160	et	0	main
unrehti	doc_491521501746_item	3754161	et	0	main
tapetud	doc_491521501746_item	3754162	et	0	main
rkm	doc_491521501746_item	3754163	et	0	main
ii	doc_491521501746_item	3754164	et	0	main
433	doc_491521501746_item	3754165	et	0	main
31	doc_491521501746_item	3754166	et	0	main
5	doc_491521501746_item	3754167	et	0	main
nissi	doc_491521501746_item	3754168	et	0	main
khk	doc_491521501746_item	3754169	et	0	main
viruküla	doc_491521501746_item	3754170	et	0	main
sissi	doc_491521501746_item	3754171	et	0	main
talu	doc_491521501746_item	3754172	et	0	main
sirle	doc_491521501746_item	3754173	et	0	main
pent	doc_491521501746_item	3754174	et	0	main
rudolf	doc_491521501746_item	3754175	et	0	main
juhani	doc_491521501746_item	3754176	et	0	main
78	doc_491521501746_item	3754177	et	0	main
a	doc_491521501746_item	3754178	et	0	main
1990	doc_491521501746_item	3754179	et	0	main
3	doc_491521501746_item	3754180	et	0	main
peatükk	doc_491521501746_item	3754181	et	0	main
muistendi	doc_491521501746_item	3754182	et	0	main
seos	doc_491521501746_item	3754183	et	0	main
eesti	doc_491521501746_item	3754184	et	0	main
rahvausundiga	doc_491521501746_item	3754185	et	0	main
31	doc_491521501746_item	3754186	et	0	main
loodusobjektid	doc_491521501746_item	3754187	et	0	main
mõned	doc_491521501746_item	3754188	et	0	main
rahvapärimuse	doc_491521501746_item	3754189	et	0	main
liigid	doc_491521501746_item	3754190	et	0	main
kajastavad	doc_491521501746_item	3754191	et	0	main
rahvausundit	doc_491521501746_item	3754192	et	0	main
üsna	doc_491521501746_item	3754193	et	0	main
vahetult	doc_491521501746_item	3754194	et	0	main
teised	doc_491521501746_item	3754195	et	0	main
aga	doc_491521501746_item	3754196	et	0	main
kaudselt	doc_491521501746_item	3754197	et	0	main
eesti	doc_491521501746_item	3754198	et	0	main
rahvausundi	doc_491521501746_item	3754199	et	0	main
üheks	doc_491521501746_item	3754200	et	0	main
tunnusjooneks	doc_491521501746_item	3754201	et	0	main
on	doc_491521501746_item	3754202	et	0	main
animistlik	doc_491521501746_item	3754203	et	0	main
elava	doc_491521501746_item	3754204	et	0	main
looduse	doc_491521501746_item	3754205	et	0	main
usk	doc_491521501746_item	3754206	et	0	main
kui	doc_491521501746_item	3754207	et	0	main
rooma	doc_491521501746_item	3754208	et	0	main
paavst	doc_491521501746_item	3754209	et	0	main
innocentius	doc_491521501746_item	3754210	et	0	main
iii	doc_491521501746_item	3754211	et	0	main
oma	doc_491521501746_item	3754212	et	0	main
1119	doc_491521501746_item	3754213	et	0	main
aasta	doc_491521501746_item	3754214	et	0	main
bullas	doc_491521501746_item	3754215	et	0	main
kristlasi	doc_491521501746_item	3754216	et	0	main
liivimaalaste	doc_491521501746_item	3754217	et	0	main
vastu	doc_491521501746_item	3754218	et	0	main
ristisõtta	doc_491521501746_item	3754219	et	0	main
kutsus	doc_491521501746_item	3754220	et	0	main
süüdistas	doc_491521501746_item	3754221	et	0	main
ta	doc_491521501746_item	3754222	et	0	main
viimaseid	doc_491521501746_item	3754223	et	0	main
selles	doc_491521501746_item	3754224	et	0	main
et	doc_491521501746_item	3754225	et	0	main
nad	doc_491521501746_item	3754226	et	0	main
jumalale	doc_491521501746_item	3754227	et	0	main
kuuluvat	doc_491521501746_item	3754228	et	0	main
austust	doc_491521501746_item	3754229	et	0	main
osutavad	doc_491521501746_item	3754230	et	0	main
mõistuseta	doc_491521501746_item	3754231	et	0	main
loomadele	doc_491521501746_item	3754232	et	0	main
lehtpuudele	doc_491521501746_item	3754233	et	0	main
selgetele	doc_491521501746_item	3754234	et	0	main
vetele	doc_491521501746_item	3754235	et	0	main
haljendavatele	doc_491521501746_item	3754236	et	0	main
taimedele	doc_491521501746_item	3754237	et	0	main
ja	doc_491521501746_item	3754238	et	0	main
ebapuhastele	doc_491521501746_item	3754239	et	0	main
vaimudele	doc_491521501746_item	3754240	et	0	main
sellega	doc_491521501746_item	3754241	et	0	main
iseloomustab	doc_491521501746_item	3754242	et	0	main
paavst	doc_491521501746_item	3754243	et	0	main
üllatavalt	doc_491521501746_item	3754244	et	0	main
täpselt	doc_491521501746_item	3754245	et	0	main
siinse	doc_491521501746_item	3754246	et	0	main
usundi	doc_491521501746_item	3754247	et	0	main
panteistlikke	doc_491521501746_item	3754248	et	0	main
jooni	doc_491521501746_item	3754249	et	0	main
kunagine	doc_491521501746_item	3754250	et	0	main
eestlane	doc_491521501746_item	3754251	et	0	main
tajus	doc_491521501746_item	3754252	et	0	main
looduse	doc_491521501746_item	3754253	et	0	main
pühadust	doc_491521501746_item	3754254	et	0	main
pühad	doc_491521501746_item	3754255	et	0	main
võisid	doc_491521501746_item	3754256	et	0	main
olla	doc_491521501746_item	3754257	et	0	main
kohad	doc_491521501746_item	3754258	et	0	main
objektid	doc_491521501746_item	3754259	et	0	main
loomad	doc_491521501746_item	3754260	et	0	main
ajaperioodid	doc_491521501746_item	3754261	et	0	main
mitmesugused	doc_491521501746_item	3754262	et	0	main
nähtused	doc_491521501746_item	3754263	et	0	main
olukorrad	doc_491521501746_item	3754264	et	0	main
pühapaigad	doc_491521501746_item	3754265	et	0	main
olid	doc_491521501746_item	3754266	et	0	main
ka	doc_491521501746_item	3754267	et	0	main
ohvrikivid	doc_491521501746_item	3754268	et	0	main
allikad	doc_491521501746_item	3754269	et	0	main
ja	doc_491521501746_item	3754270	et	0	main
teised	doc_491521501746_item	3754271	et	0	main
veekogud	doc_491521501746_item	3754272	et	0	main
talu	doc_491521501746_item	3754273	et	0	main
piirides	doc_491521501746_item	3754274	et	0	main
asunud	doc_491521501746_item	3754275	et	0	main
ohvriajad	doc_491521501746_item	3754276	et	0	main
ning	doc_491521501746_item	3754277	et	0	main
väga	doc_491521501746_item	3754278	et	0	main
sageli	doc_491521501746_item	3754279	et	0	main
hiiepuud	doc_491521501746_item	3754280	et	0	main
põhja-	doc_491521501746_item	3754281	et	0	main
ja	doc_491521501746_item	3754282	et	0	main
lääne-eestis	doc_491521501746_item	3754283	et	0	main
oli	doc_491521501746_item	3754284	et	0	main
enamasti	doc_491521501746_item	3754285	et	0	main
tegemist	doc_491521501746_item	3754286	et	0	main
hiiemetsaga	doc_491521501746_item	3754287	et	0	main
maa	doc_491521501746_item	3754288	et	0	main
lõunaosas	doc_491521501746_item	3754289	et	0	main
austati	doc_491521501746_item	3754290	et	0	main
paljudes	doc_491521501746_item	3754291	et	0	main
kohtades	doc_491521501746_item	3754292	et	0	main
üksikuid	doc_491521501746_item	3754293	et	0	main
puid	doc_491521501746_item	3754294	et	0	main
enamasti	doc_491521501746_item	3754295	et	0	main
tammi	doc_491521501746_item	3754296	et	0	main
või	doc_491521501746_item	3754297	et	0	main
pärni	doc_491521501746_item	3754298	et	0	main
harvemini	doc_491521501746_item	3754299	et	0	main
mände	doc_491521501746_item	3754300	et	0	main
kaski	doc_491521501746_item	3754301	et	0	main
leppi	doc_491521501746_item	3754302	et	0	main
või	doc_491521501746_item	3754303	et	0	main
kuuski	doc_491521501746_item	3754304	et	0	main
hiiepuu	doc_491521501746_item	3754305	et	0	main
rajujat	doc_491521501746_item	3754306	et	0	main
ähvardas	doc_491521501746_item	3754307	et	0	main
surmaoht	doc_491521501746_item	3754308	et	0	main
ja	doc_491521501746_item	3754309	et	0	main
puu	doc_491521501746_item	3754310	et	0	main
ümbruses	doc_491521501746_item	3754311	et	0	main
kehtisid	doc_491521501746_item	3754312	et	0	main
mitmed	doc_491521501746_item	3754313	et	0	main
tabud	doc_491521501746_item	3754314	et	0	main
seal	doc_491521501746_item	3754315	et	0	main
ei	doc_491521501746_item	3754316	et	0	main
niidetud	doc_491521501746_item	3754317	et	0	main
heina	doc_491521501746_item	3754318	et	0	main
ei	doc_491521501746_item	3754319	et	0	main
nopitud	doc_491521501746_item	3754320	et	0	main
marju	doc_491521501746_item	3754321	et	0	main
ega	doc_491521501746_item	3754322	et	0	main
karjatanud	doc_491521501746_item	3754323	et	0	main
loomi	doc_491521501746_item	3754324	et	0	main
et	doc_491521501746_item	3754325	et	0	main
vältida	doc_491521501746_item	3754326	et	0	main
üleloomulikku	doc_491521501746_item	3754327	et	0	main
karistust	doc_491521501746_item	3754328	et	0	main
valk	doc_491521501746_item	3754329	et	0	main
1998	doc_491521501746_item	3754330	et	0	main
489-492	doc_491521501746_item	3754331	et	0	main
sõna	doc_491521501746_item	3754332	et	0	main
hiis	doc_491521501746_item	3754333	et	0	main
on	doc_491521501746_item	3754334	et	0	main
väga	doc_491521501746_item	3754335	et	0	main
huvitav	doc_491521501746_item	3754336	et	0	main
ka	doc_491521501746_item	3754337	et	0	main
selles	doc_491521501746_item	3754338	et	0	main
mõttes	doc_491521501746_item	3754339	et	0	main
et	doc_491521501746_item	3754340	et	0	main
ta	doc_491521501746_item	3754341	et	0	main
tähendab	doc_491521501746_item	3754342	et	0	main
niihästi	doc_491521501746_item	3754343	et	0	main
metsa	doc_491521501746_item	3754344	et	0	main
kui	doc_491521501746_item	3754345	et	0	main
ka	doc_491521501746_item	3754346	et	0	main
selle	doc_491521501746_item	3754347	et	0	main
asukat	doc_491521501746_item	3754348	et	0	main
kas	doc_491521501746_item	3754349	et	0	main
metsanurga	doc_491521501746_item	3754350	et	0	main
inimest	doc_491521501746_item	3754351	et	0	main
vrd	doc_491521501746_item	3754352	et	0	main
hiidlane	doc_491521501746_item	3754353	et	0	main
või	doc_491521501746_item	3754354	et	0	main
hoopis	doc_491521501746_item	3754355	et	0	main
metsas	doc_491521501746_item	3754356	et	0	main
asuvat	doc_491521501746_item	3754357	et	0	main
vaimu	doc_491521501746_item	3754358	et	0	main
vrd	doc_491521501746_item	3754359	et	0	main
hiiglane	doc_491521501746_item	3754360	et	0	main
hiid	doc_491521501746_item	3754361	et	0	main
hiius	doc_491521501746_item	3754362	et	0	main
huvitav	doc_491521501746_item	3754363	et	0	main
on	doc_491521501746_item	3754364	et	0	main
a	doc_491521501746_item	3754365	et	0	main
oleariuse	doc_491521501746_item	3754366	et	0	main
teade	doc_491521501746_item	3754367	et	0	main
sellest	doc_491521501746_item	3754368	et	0	main
et	doc_491521501746_item	3754369	et	0	main
eestlased	doc_491521501746_item	3754370	et	0	main
valivad	doc_491521501746_item	3754371	et	0	main
teatud	doc_491521501746_item	3754372	et	0	main
puud	doc_491521501746_item	3754373	et	0	main
eriti	doc_491521501746_item	3754374	et	0	main
mäekinkudel	doc_491521501746_item	3754375	et	0	main
karsivad	doc_491521501746_item	3754376	et	0	main
need	doc_491521501746_item	3754377	et	0	main
kuni	doc_491521501746_item	3754378	et	0	main
ladvani	doc_491521501746_item	3754379	et	0	main
paljaks	doc_491521501746_item	3754380	et	0	main
seovad	doc_491521501746_item	3754381	et	0	main
neile	doc_491521501746_item	3754382	et	0	main
punaseid	doc_491521501746_item	3754383	et	0	main
paelu	doc_491521501746_item	3754384	et	0	main
ja	doc_491521501746_item	3754385	et	0	main
esitavad	doc_491521501746_item	3754386	et	0	main
nende	doc_491521501746_item	3754387	et	0	main
all	doc_491521501746_item	3754388	et	0	main
oma	doc_491521501746_item	3754389	et	0	main
palveid	doc_491521501746_item	3754390	et	0	main
ja	doc_491521501746_item	3754391	et	0	main
soove	doc_491521501746_item	3754392	et	0	main
hiie	doc_491521501746_item	3754393	et	0	main
puu	doc_491521501746_item	3754394	et	0	main
kivid	doc_491521501746_item	3754395	et	0	main
ja	doc_491521501746_item	3754396	et	0	main
allikad	doc_491521501746_item	3754397	et	0	main
on	doc_491521501746_item	3754398	et	0	main
suureks	doc_491521501746_item	3754399	et	0	main
jõukeskuseks	doc_491521501746_item	3754400	et	0	main
kuhu	doc_491521501746_item	3754401	et	0	main
tuuakse	doc_491521501746_item	3754402	et	0	main
ohvreid	doc_491521501746_item	3754403	et	0	main
ja	doc_491521501746_item	3754404	et	0	main
kus	doc_491521501746_item	3754405	et	0	main
käiakse	doc_491521501746_item	3754406	et	0	main
haigusi	doc_491521501746_item	3754407	et	0	main
arstimas	doc_491521501746_item	3754408	et	0	main
loorits	doc_491521501746_item	3754409	et	0	main
1990	doc_491521501746_item	3754410	et	0	main
67	doc_491521501746_item	3754411	et	0	main
32	doc_491521501746_item	3754412	et	0	main
puud	doc_491521501746_item	3754413	et	0	main
madila	doc_491521501746_item	3754414	et	0	main
meeste	doc_491521501746_item	3754415	et	0	main
heinamaad	doc_491521501746_item	3754416	et	0	main
on	doc_491521501746_item	3754417	et	0	main
seal	doc_491521501746_item	3754418	et	0	main
kus	doc_491521501746_item	3754419	et	0	main
on	doc_491521501746_item	3754420	et	0	main
soosalu	doc_491521501746_item	3754421	et	0	main
mägi	doc_491521501746_item	3754422	et	0	main
seal	doc_491521501746_item	3754423	et	0	main
kasvab	doc_491521501746_item	3754424	et	0	main
kuldking	doc_491521501746_item	3754425	et	0	main
ja	doc_491521501746_item	3754426	et	0	main
tuhandeid	doc_491521501746_item	3754427	et	0	main
kummalisi	doc_491521501746_item	3754428	et	0	main
taime	doc_491521501746_item	3754429	et	0	main
mida	doc_491521501746_item	3754430	et	0	main
vanemad	doc_491521501746_item	3754431	et	0	main
inimesedki	doc_491521501746_item	3754432	et	0	main
ei	doc_491521501746_item	3754433	et	0	main
tunnud	doc_491521501746_item	3754434	et	0	main
seal	doc_491521501746_item	3754435	et	0	main
tehti	doc_491521501746_item	3754436	et	0	main
heina	doc_491521501746_item	3754437	et	0	main
ja	doc_491521501746_item	3754438	et	0	main
see	doc_491521501746_item	3754439	et	0	main
on	doc_491521501746_item	3754440	et	0	main
puisniit	doc_491521501746_item	3754441	et	0	main
see	doc_491521501746_item	3754442	et	0	main
võis	doc_491521501746_item	3754443	et	0	main
olla	doc_491521501746_item	3754444	et	0	main
mingi	doc_491521501746_item	3754445	et	0	main
hiietammastik	doc_491521501746_item	3754446	et	0	main
ka	doc_491521501746_item	3754447	et	0	main
sest	doc_491521501746_item	3754448	et	0	main
ta	doc_491521501746_item	3754449	et	0	main
on	doc_491521501746_item	3754450	et	0	main
rabast	doc_491521501746_item	3754451	et	0	main
kõrgem	doc_491521501746_item	3754452	et	0	main
koht	doc_491521501746_item	3754453	et	0	main
seal	doc_491521501746_item	3754454	et	0	main
on	doc_491521501746_item	3754455	et	0	main
vanad	doc_491521501746_item	3754456	et	0	main
vundamendikohad	doc_491521501746_item	3754457	et	0	main
tunda	doc_491521501746_item	3754458	et	0	main
vanad	doc_491521501746_item	3754459	et	0	main
mehed	doc_491521501746_item	3754460	et	0	main
ütlesid	doc_491521501746_item	3754461	et	0	main
seda	doc_491521501746_item	3754462	et	0	main
ja	doc_491521501746_item	3754463	et	0	main
et	doc_491521501746_item	3754464	et	0	main
see	doc_491521501746_item	3754465	et	0	main
on	doc_491521501746_item	3754466	et	0	main
olnud	doc_491521501746_item	3754467	et	0	main
hiietammestik	doc_491521501746_item	3754468	et	0	main
seal	doc_491521501746_item	3754469	et	0	main
kuldkingaa	doc_491521501746_item	3754470	et	0	main
kasvas	doc_491521501746_item	3754471	et	0	main
siin	doc_491521501746_item	3754472	et	0	main
ükskord	doc_491521501746_item	3754473	et	0	main
läksid	doc_491521501746_item	3754474	et	0	main
vaatama	doc_491521501746_item	3754475	et	0	main
eelmine	doc_491521501746_item	3754476	et	0	main
õhtu	doc_491521501746_item	3754477	et	0	main
oli	doc_491521501746_item	3754478	et	0	main
kõik	doc_491521501746_item	3754479	et	0	main
täis	doc_491521501746_item	3754480	et	0	main
ja	doc_491521501746_item	3754481	et	0	main
järgmine	doc_491521501746_item	3754482	et	0	main
päev	doc_491521501746_item	3754483	et	0	main
läksid	doc_491521501746_item	3754484	et	0	main
vaatama	doc_491521501746_item	3754485	et	0	main
siis	doc_491521501746_item	3754486	et	0	main
oli	doc_491521501746_item	3754487	et	0	main
kõik	doc_491521501746_item	3754488	et	0	main
ära	doc_491521501746_item	3754489	et	0	main
korjatud	doc_491521501746_item	3754490	et	0	main
ja	doc_491521501746_item	3754491	et	0	main
jänesekäppa	doc_491521501746_item	3754492	et	0	main
kasvab	doc_491521501746_item	3754493	et	0	main
ka	doc_491521501746_item	3754494	et	0	main
seal	doc_491521501746_item	3754495	et	0	main
rkm	doc_491521501746_item	3754496	et	0	main
ii	doc_491521501746_item	3754497	et	0	main
434	doc_491521501746_item	3754498	et	0	main
306	doc_491521501746_item	3754499	et	0	main
5	doc_491521501746_item	3754500	et	0	main
nissi	doc_491521501746_item	3754501	et	0	main
khk	doc_491521501746_item	3754502	et	0	main
riisipere	doc_491521501746_item	3754503	et	0	main
v	doc_491521501746_item	3754504	et	0	main
madila	doc_491521501746_item	3754505	et	0	main
k	doc_491521501746_item	3754506	et	0	main
mall	doc_491521501746_item	3754507	et	0	main
hiiemäe	doc_491521501746_item	3754508	et	0	main
rein	doc_491521501746_item	3754509	et	0	main
leheroo	doc_491521501746_item	3754510	et	0	main
s	doc_491521501746_item	3754511	et	0	main
1949	doc_491521501746_item	3754512	et	0	main
a	doc_491521501746_item	3754513	et	0	main
1990	doc_491521501746_item	3754514	et	0	main
varbola	doc_491521501746_item	3754515	et	0	main
maalinna	doc_491521501746_item	3754516	et	0	main
vallil	doc_491521501746_item	3754517	et	0	main
kahed	doc_491521501746_item	3754518	et	0	main
väravad	doc_491521501746_item	3754519	et	0	main
ees	doc_491521501746_item	3754520	et	0	main
olnud	doc_491521501746_item	3754521	et	0	main
aga	doc_491521501746_item	3754522	et	0	main
pärast	doc_491521501746_item	3754523	et	0	main
olid	doc_491521501746_item	3754524	et	0	main
kohad	doc_491521501746_item	3754525	et	0	main
ainult	doc_491521501746_item	3754526	et	0	main
ja	doc_491521501746_item	3754527	et	0	main
ma	doc_491521501746_item	3754528	et	0	main
ei	doc_491521501746_item	3754529	et	0	main
tea	doc_491521501746_item	3754530	et	0	main
kus	doc_491521501746_item	3754531	et	0	main
kilomeeter	doc_491521501746_item	3754532	et	0	main
ole	doc_491521501746_item	3754533	et	0	main
see	doc_491521501746_item	3754534	et	0	main
valli	doc_491521501746_item	3754535	et	0	main
ring	doc_491521501746_item	3754536	et	0	main
ohvritammed	doc_491521501746_item	3754537	et	0	main
olid	doc_491521501746_item	3754538	et	0	main
valli	doc_491521501746_item	3754539	et	0	main
kõrval	doc_491521501746_item	3754540	et	0	main
mitte	doc_491521501746_item	3754541	et	0	main
sees	doc_491521501746_item	3754542	et	0	main
ei	doc_491521501746_item	3754543	et	0	main
olnud	doc_491521501746_item	3754544	et	0	main
rkm	doc_491521501746_item	3754545	et	0	main
ii	doc_491521501746_item	3754546	et	0	main
434	doc_491521501746_item	3754547	et	0	main
745	doc_491521501746_item	3754548	et	0	main
3	doc_491521501746_item	3754549	et	0	main
nissi	doc_491521501746_item	3754550	et	0	main
lehetu	doc_491521501746_item	3754551	et	0	main
k	doc_491521501746_item	3754552	et	0	main
pajaka	doc_491521501746_item	3754553	et	0	main
k	doc_491521501746_item	3754554	et	0	main
varbola	doc_491521501746_item	3754555	et	0	main
v	doc_491521501746_item	3754556	et	0	main
ja	doc_491521501746_item	3754557	et	0	main
k	doc_491521501746_item	3754558	et	0	main
mall	doc_491521501746_item	3754559	et	0	main
hiiemäe	doc_491521501746_item	3754560	et	0	main
hilda	doc_491521501746_item	3754561	et	0	main
nurmbek	doc_491521501746_item	3754562	et	0	main
s	doc_491521501746_item	3754563	et	0	main
1907	doc_491521501746_item	3754564	et	0	main
a	doc_491521501746_item	3754565	et	0	main
1990	doc_491521501746_item	3754566	et	0	main
33	doc_491521501746_item	3754567	et	0	main
veekogud	doc_491521501746_item	3754568	et	0	main
allikad	doc_491521501746_item	3754569	et	0	main
järved	doc_491521501746_item	3754570	et	0	main
jõed	doc_491521501746_item	3754571	et	0	main
kultuslikest	doc_491521501746_item	3754572	et	0	main
veekogudest	doc_491521501746_item	3754573	et	0	main
moodustavad	doc_491521501746_item	3754574	et	0	main
allikad	doc_491521501746_item	3754575	et	0	main
kõige	doc_491521501746_item	3754576	et	0	main
arvukama	doc_491521501746_item	3754577	et	0	main
rühma	doc_491521501746_item	3754578	et	0	main
rahvapärimustes	doc_491521501746_item	3754579	et	0	main
allikatele	doc_491521501746_item	3754580	et	0	main
omistatud	doc_491521501746_item	3754581	et	0	main
funktsioonide	doc_491521501746_item	3754582	et	0	main
järgi	doc_491521501746_item	3754583	et	0	main
võiks	doc_491521501746_item	3754584	et	0	main
neid	doc_491521501746_item	3754585	et	0	main
jaotada	doc_491521501746_item	3754586	et	0	main
rühmadesse	doc_491521501746_item	3754587	et	0	main
pühad	doc_491521501746_item	3754588	et	0	main
hiie-	doc_491521501746_item	3754589	et	0	main
ravi-	doc_491521501746_item	3754590	et	0	main
ehk	doc_491521501746_item	3754591	et	0	main
tervise-	doc_491521501746_item	3754592	et	0	main
silma-	doc_491521501746_item	3754593	et	0	main
elu-	doc_491521501746_item	3754594	et	0	main
jne	doc_491521501746_item	3754595	et	0	main
allikad	doc_491521501746_item	3754596	et	0	main
selline	doc_491521501746_item	3754597	et	0	main
jaotus	doc_491521501746_item	3754598	et	0	main
on	doc_491521501746_item	3754599	et	0	main
siiski	doc_491521501746_item	3754600	et	0	main
mõnevõrra	doc_491521501746_item	3754601	et	0	main
tinglik	doc_491521501746_item	3754602	et	0	main
sest	doc_491521501746_item	3754603	et	0	main
ühel	doc_491521501746_item	3754604	et	0	main
ja	doc_491521501746_item	3754605	et	0	main
samal	doc_491521501746_item	3754606	et	0	main
allikal	doc_491521501746_item	3754607	et	0	main
teatakse	doc_491521501746_item	3754608	et	0	main
sageli	doc_491521501746_item	3754609	et	0	main
mitut	doc_491521501746_item	3754610	et	0	main
eri	doc_491521501746_item	3754611	et	0	main
funktsiooni	doc_491521501746_item	3754612	et	0	main
tamla	doc_491521501746_item	3754613	et	0	main
1985	doc_491521501746_item	3754614	et	0	main
123-125	doc_491521501746_item	3754615	et	0	main
eriti	doc_491521501746_item	3754616	et	0	main
palju	doc_491521501746_item	3754617	et	0	main
on	doc_491521501746_item	3754618	et	0	main
raviallikaid	doc_491521501746_item	3754619	et	0	main
mille	doc_491521501746_item	3754620	et	0	main
veest	doc_491521501746_item	3754621	et	0	main
on	doc_491521501746_item	3754622	et	0	main
püütud	doc_491521501746_item	3754623	et	0	main
haiguste	doc_491521501746_item	3754624	et	0	main
vastu	doc_491521501746_item	3754625	et	0	main
abi	doc_491521501746_item	3754626	et	0	main
saada	doc_491521501746_item	3754627	et	0	main
allikatesse	doc_491521501746_item	3754628	et	0	main
on	doc_491521501746_item	3754629	et	0	main
ohverdatud	doc_491521501746_item	3754630	et	0	main
münte	doc_491521501746_item	3754631	et	0	main
hõbevalget	doc_491521501746_item	3754632	et	0	main
kraabitud	doc_491521501746_item	3754633	et	0	main
hõbedapuru	doc_491521501746_item	3754634	et	0	main
viljateri	doc_491521501746_item	3754635	et	0	main
toiduaineid	doc_491521501746_item	3754636	et	0	main
ehteasju	doc_491521501746_item	3754637	et	0	main
nissi	doc_491521501746_item	3754638	et	0	main
kiriku	doc_491521501746_item	3754639	et	0	main
juurest	doc_491521501746_item	3754640	et	0	main
alla	doc_491521501746_item	3754641	et	0	main
oli	doc_491521501746_item	3754642	et	0	main
puhas	doc_491521501746_item	3754643	et	0	main
allikas	doc_491521501746_item	3754644	et	0	main
rahvas	doc_491521501746_item	3754645	et	0	main
käis	doc_491521501746_item	3754646	et	0	main
pudeliga	doc_491521501746_item	3754647	et	0	main
vett	doc_491521501746_item	3754648	et	0	main
võtmas	doc_491521501746_item	3754649	et	0	main
silmade	doc_491521501746_item	3754650	et	0	main
raviks	doc_491521501746_item	3754651	et	0	main
see	doc_491521501746_item	3754652	et	0	main
pidi	doc_491521501746_item	3754653	et	0	main
silma	doc_491521501746_item	3754654	et	0	main
ravima	doc_491521501746_item	3754655	et	0	main
rkm	doc_491521501746_item	3754656	et	0	main
ii	doc_491521501746_item	3754657	et	0	main
434	doc_491521501746_item	3754658	et	0	main
423	doc_491521501746_item	3754659	et	0	main
2	doc_491521501746_item	3754660	et	0	main
nissi	doc_491521501746_item	3754661	et	0	main
khk	doc_491521501746_item	3754662	et	0	main
riisipere	doc_491521501746_item	3754663	et	0	main
as	doc_491521501746_item	3754664	et	0	main
erna	doc_491521501746_item	3754665	et	0	main
tampere	doc_491521501746_item	3754666	et	0	main
alvine	doc_491521501746_item	3754667	et	0	main
saks	doc_491521501746_item	3754668	et	0	main
83	doc_491521501746_item	3754669	et	0	main
a	doc_491521501746_item	3754670	et	0	main
1990	doc_491521501746_item	3754671	et	0	main
raudtee	doc_491521501746_item	3754672	et	0	main
alt	doc_491521501746_item	3754673	et	0	main
tuleb	doc_491521501746_item	3754674	et	0	main
allikas	doc_491521501746_item	3754675	et	0	main
läbi	doc_491521501746_item	3754676	et	0	main
seda	doc_491521501746_item	3754677	et	0	main
öeldi	doc_491521501746_item	3754678	et	0	main
jõetõusme	doc_491521501746_item	3754679	et	0	main
ja	doc_491521501746_item	3754680	et	0	main
siin	doc_491521501746_item	3754681	et	0	main
metsa	doc_491521501746_item	3754682	et	0	main
sees	doc_491521501746_item	3754683	et	0	main
on	doc_491521501746_item	3754684	et	0	main
kevadel	doc_491521501746_item	3754685	et	0	main
ja	doc_491521501746_item	3754686	et	0	main
sügisel	doc_491521501746_item	3754687	et	0	main
niisugune	doc_491521501746_item	3754688	et	0	main
maa-alune	doc_491521501746_item	3754689	et	0	main
allikas	doc_491521501746_item	3754690	et	0	main
niisugune	doc_491521501746_item	3754691	et	0	main
jutt	doc_491521501746_item	3754692	et	0	main
et	doc_491521501746_item	3754693	et	0	main
seal	doc_491521501746_item	3754694	et	0	main
jõetõusmes	doc_491521501746_item	3754695	et	0	main
oli	doc_491521501746_item	3754696	et	0	main
lehm	doc_491521501746_item	3754697	et	0	main
ära	doc_491521501746_item	3754698	et	0	main
uppund	doc_491521501746_item	3754699	et	0	main
ja	doc_491521501746_item	3754700	et	0	main
kell	doc_491521501746_item	3754701	et	0	main
tulnud	doc_491521501746_item	3754702	et	0	main
siit	doc_491521501746_item	3754703	et	0	main
välja	doc_491521501746_item	3754704	et	0	main
siin	doc_491521501746_item	3754705	et	0	main
on	doc_491521501746_item	3754706	et	0	main
jaa	doc_491521501746_item	3754707	et	0	main
kevade	doc_491521501746_item	3754708	et	0	main
suur	doc_491521501746_item	3754709	et	0	main
vesi	doc_491521501746_item	3754710	et	0	main
rkm	doc_491521501746_item	3754711	et	0	main
ii	doc_491521501746_item	3754712	et	0	main
434	doc_491521501746_item	3754713	et	0	main
156	doc_491521501746_item	3754714	et	0	main
37	doc_491521501746_item	3754715	et	0	main
nissi	doc_491521501746_item	3754716	et	0	main
khk	doc_491521501746_item	3754717	et	0	main
riisipere	doc_491521501746_item	3754718	et	0	main
v	doc_491521501746_item	3754719	et	0	main
nurme	doc_491521501746_item	3754720	et	0	main
k	doc_491521501746_item	3754721	et	0	main
mall	doc_491521501746_item	3754722	et	0	main
hiiemäe	doc_491521501746_item	3754723	et	0	main
marta	doc_491521501746_item	3754724	et	0	main
ehrpais	doc_491521501746_item	3754725	et	0	main
82	doc_491521501746_item	3754726	et	0	main
a	doc_491521501746_item	3754727	et	0	main
1990	doc_491521501746_item	3754728	et	0	main
nurme	doc_491521501746_item	3754729	et	0	main
külas	doc_491521501746_item	3754730	et	0	main
oli	doc_491521501746_item	3754731	et	0	main
allikas	doc_491521501746_item	3754732	et	0	main
sealt	doc_491521501746_item	3754733	et	0	main
sai	doc_491521501746_item	3754734	et	0	main
ikka	doc_491521501746_item	3754735	et	0	main
vett	doc_491521501746_item	3754736	et	0	main
toodud	doc_491521501746_item	3754737	et	0	main
kui	doc_491521501746_item	3754738	et	0	main
suvel	doc_491521501746_item	3754739	et	0	main
mujal	doc_491521501746_item	3754740	et	0	main
ei	doc_491521501746_item	3754741	et	0	main
olnud	doc_491521501746_item	3754742	et	0	main
midagi	doc_491521501746_item	3754743	et	0	main
nad	doc_491521501746_item	3754744	et	0	main
seal	doc_491521501746_item	3754745	et	0	main
sonisid	doc_491521501746_item	3754746	et	0	main
et	doc_491521501746_item	3754747	et	0	main
on	doc_491521501746_item	3754748	et	0	main
raha	doc_491521501746_item	3754749	et	0	main
poisid	doc_491521501746_item	3754750	et	0	main
ma	doc_491521501746_item	3754751	et	0	main
tean	doc_491521501746_item	3754752	et	0	main
et	doc_491521501746_item	3754753	et	0	main
tirisid	doc_491521501746_item	3754754	et	0	main
seal	doc_491521501746_item	3754755	et	0	main
tünnilauad	doc_491521501746_item	3754756	et	0	main
välja	doc_491521501746_item	3754757	et	0	main
et	doc_491521501746_item	3754758	et	0	main
saavad	doc_491521501746_item	3754759	et	0	main
kätte	doc_491521501746_item	3754760	et	0	main
seal	doc_491521501746_item	3754761	et	0	main
nad	doc_491521501746_item	3754762	et	0	main
sonisid	doc_491521501746_item	3754763	et	0	main
et	doc_491521501746_item	3754764	et	0	main
raha	doc_491521501746_item	3754765	et	0	main
on	doc_491521501746_item	3754766	et	0	main
pandud	doc_491521501746_item	3754767	et	0	main
aga	doc_491521501746_item	3754768	et	0	main
seal	doc_491521501746_item	3754769	et	0	main
ei	doc_491521501746_item	3754770	et	0	main
ole	doc_491521501746_item	3754771	et	0	main
muudkui	doc_491521501746_item	3754772	et	0	main
see	doc_491521501746_item	3754773	et	0	main
et	doc_491521501746_item	3754774	et	0	main
tünn	doc_491521501746_item	3754775	et	0	main
on	doc_491521501746_item	3754776	et	0	main
pandud	doc_491521501746_item	3754777	et	0	main
allika	doc_491521501746_item	3754778	et	0	main
kaitseks	doc_491521501746_item	3754779	et	0	main
et	doc_491521501746_item	3754780	et	0	main
ei	doc_491521501746_item	3754781	et	0	main
lähe	doc_491521501746_item	3754782	et	0	main
sodiseks	doc_491521501746_item	3754783	et	0	main
rkm	doc_491521501746_item	3754784	et	0	main
ii	doc_491521501746_item	3754785	et	0	main
434	doc_491521501746_item	3754786	et	0	main
122	doc_491521501746_item	3754787	et	0	main
8	doc_491521501746_item	3754788	et	0	main
riisipere	doc_491521501746_item	3754789	et	0	main
v	doc_491521501746_item	3754790	et	0	main
nurme	doc_491521501746_item	3754791	et	0	main
k	doc_491521501746_item	3754792	et	0	main
nissi	doc_491521501746_item	3754793	et	0	main
khk	doc_491521501746_item	3754794	et	0	main
lehetu	doc_491521501746_item	3754795	et	0	main
k	doc_491521501746_item	3754796	et	0	main
mall	doc_491521501746_item	3754797	et	0	main
hiiemäe	doc_491521501746_item	3754798	et	0	main
august	doc_491521501746_item	3754799	et	0	main
lehtme	doc_491521501746_item	3754800	et	0	main
s	doc_491521501746_item	3754801	et	0	main
1919	doc_491521501746_item	3754802	et	0	main
a	doc_491521501746_item	3754803	et	0	main
1990	doc_491521501746_item	3754804	et	0	main
koerakingumägi	doc_491521501746_item	3754805	et	0	main
on	doc_491521501746_item	3754806	et	0	main
küll	doc_491521501746_item	3754807	et	0	main
ja	doc_491521501746_item	3754808	et	0	main
seal	doc_491521501746_item	3754809	et	0	main
on	doc_491521501746_item	3754810	et	0	main
allikas	doc_491521501746_item	3754811	et	0	main
ka	doc_491521501746_item	3754812	et	0	main
mingisugune	doc_491521501746_item	3754813	et	0	main
sooserv	doc_491521501746_item	3754814	et	0	main
on	doc_491521501746_item	3754815	et	0	main
ees	doc_491521501746_item	3754816	et	0	main
ja	doc_491521501746_item	3754817	et	0	main
siis	doc_491521501746_item	3754818	et	0	main
on	doc_491521501746_item	3754819	et	0	main
metsa	doc_491521501746_item	3754820	et	0	main
sees	doc_491521501746_item	3754821	et	0	main
pajaka	doc_491521501746_item	3754822	et	0	main
maantee	doc_491521501746_item	3754823	et	0	main
ääres	doc_491521501746_item	3754824	et	0	main
küngas	doc_491521501746_item	3754825	et	0	main
seal	doc_491521501746_item	3754826	et	0	main
pidi	doc_491521501746_item	3754827	et	0	main
varandus	doc_491521501746_item	3754828	et	0	main
olema	doc_491521501746_item	3754829	et	0	main
kuskil	doc_491521501746_item	3754830	et	0	main
rkm	doc_491521501746_item	3754831	et	0	main
ii	doc_491521501746_item	3754832	et	0	main
434	doc_491521501746_item	3754833	et	0	main
159	doc_491521501746_item	3754834	et	0	main
1	doc_491521501746_item	3754835	et	0	main
riisipere	doc_491521501746_item	3754836	et	0	main
v	doc_491521501746_item	3754837	et	0	main
nurme	doc_491521501746_item	3754838	et	0	main
k	doc_491521501746_item	3754839	et	0	main
lehtla	doc_491521501746_item	3754840	et	0	main
talu	doc_491521501746_item	3754841	et	0	main
mall	doc_491521501746_item	3754842	et	0	main
hiiemäe	doc_491521501746_item	3754843	et	0	main
oskar	doc_491521501746_item	3754844	et	0	main
lehtme	doc_491521501746_item	3754845	et	0	main
76	doc_491521501746_item	3754846	et	0	main
a	doc_491521501746_item	3754847	et	0	main
1990	doc_491521501746_item	3754848	et	0	main
allikaveega	doc_491521501746_item	3754849	et	0	main
soovitati	doc_491521501746_item	3754850	et	0	main
ikka	doc_491521501746_item	3754851	et	0	main
silmi	doc_491521501746_item	3754852	et	0	main
pesta	doc_491521501746_item	3754853	et	0	main
küll	doc_491521501746_item	3754854	et	0	main
mõned	doc_491521501746_item	3754855	et	0	main
käisid	doc_491521501746_item	3754856	et	0	main
allikavett	doc_491521501746_item	3754857	et	0	main
toomas	doc_491521501746_item	3754858	et	0	main
silmapesemise	doc_491521501746_item	3754859	et	0	main
jaoks	doc_491521501746_item	3754860	et	0	main
rkm	doc_491521501746_item	3754861	et	0	main
ii	doc_491521501746_item	3754862	et	0	main
433	doc_491521501746_item	3754863	et	0	main
528	doc_491521501746_item	3754864	et	0	main
35	doc_491521501746_item	3754865	et	0	main
nissi	doc_491521501746_item	3754866	et	0	main
khk	doc_491521501746_item	3754867	et	0	main
sooniste	doc_491521501746_item	3754868	et	0	main
v	doc_491521501746_item	3754869	et	0	main
ellamaa	doc_491521501746_item	3754870	et	0	main
k	doc_491521501746_item	3754871	et	0	main
riisipere	doc_491521501746_item	3754872	et	0	main
v	doc_491521501746_item	3754873	et	0	main
tabara	doc_491521501746_item	3754874	et	0	main
k	doc_491521501746_item	3754875	et	0	main
anu	doc_491521501746_item	3754876	et	0	main
korb	doc_491521501746_item	3754877	et	0	main
alma	doc_491521501746_item	3754878	et	0	main
põldma	doc_491521501746_item	3754879	et	0	main
s	doc_491521501746_item	3754880	et	0	main
1915	doc_491521501746_item	3754881	et	0	main
a	doc_491521501746_item	3754882	et	0	main
1990	doc_491521501746_item	3754883	et	0	main
järvatse	doc_491521501746_item	3754884	et	0	main
järves	doc_491521501746_item	3754885	et	0	main
käidi	doc_491521501746_item	3754886	et	0	main
haigeid	doc_491521501746_item	3754887	et	0	main
silmi	doc_491521501746_item	3754888	et	0	main
pesemas	doc_491521501746_item	3754889	et	0	main
seal	doc_491521501746_item	3754890	et	0	main
kus	doc_491521501746_item	3754891	et	0	main
allikad	doc_491521501746_item	3754892	et	0	main
välja	doc_491521501746_item	3754893	et	0	main
jooksid	doc_491521501746_item	3754894	et	0	main
rkm	doc_491521501746_item	3754895	et	0	main
ii	doc_491521501746_item	3754896	et	0	main
435	doc_491521501746_item	3754897	et	0	main
245	doc_491521501746_item	3754898	et	0	main
29	doc_491521501746_item	3754899	et	0	main
nissi	doc_491521501746_item	3754900	et	0	main
turba	doc_491521501746_item	3754901	et	0	main
al	doc_491521501746_item	3754902	et	0	main
ellamaa	doc_491521501746_item	3754903	et	0	main
k	doc_491521501746_item	3754904	et	0	main
kullamaa	doc_491521501746_item	3754905	et	0	main
päri	doc_491521501746_item	3754906	et	0	main
as	doc_491521501746_item	3754907	et	0	main
kadi	doc_491521501746_item	3754908	et	0	main
sarv	doc_491521501746_item	3754909	et	0	main
salme	doc_491521501746_item	3754910	et	0	main
villenthal	doc_491521501746_item	3754911	et	0	main
s	doc_491521501746_item	3754912	et	0	main
1923	doc_491521501746_item	3754913	et	0	main
a	doc_491521501746_item	3754914	et	0	main
1990	doc_491521501746_item	3754915	et	0	main
meil	doc_491521501746_item	3754916	et	0	main
allika	doc_491521501746_item	3754917	et	0	main
talus	doc_491521501746_item	3754918	et	0	main
oli	doc_491521501746_item	3754919	et	0	main
ka	doc_491521501746_item	3754920	et	0	main
allikas	doc_491521501746_item	3754921	et	0	main
1937aastal	doc_491521501746_item	3754922	et	0	main
oli	doc_491521501746_item	3754923	et	0	main
suur	doc_491521501746_item	3754924	et	0	main
põud	doc_491521501746_item	3754925	et	0	main
kõik	doc_491521501746_item	3754926	et	0	main
käisid	doc_491521501746_item	3754927	et	0	main
meie	doc_491521501746_item	3754928	et	0	main
allikast	doc_491521501746_item	3754929	et	0	main
vett	doc_491521501746_item	3754930	et	0	main
vsdamas	doc_491521501746_item	3754931	et	0	main
vett	doc_491521501746_item	3754932	et	0	main
jäi	doc_491521501746_item	3754933	et	0	main
väheks	doc_491521501746_item	3754934	et	0	main
ja	doc_491521501746_item	3754935	et	0	main
minu	doc_491521501746_item	3754936	et	0	main
isa	doc_491521501746_item	3754937	et	0	main
läks	doc_491521501746_item	3754938	et	0	main
allikat	doc_491521501746_item	3754939	et	0	main
puhastama	doc_491521501746_item	3754940	et	0	main
andis	doc_491521501746_item	3754941	et	0	main
leiva	doc_491521501746_item	3754942	et	0	main
välja	doc_491521501746_item	3754943	et	0	main
kui	doc_491521501746_item	3754944	et	0	main
siis	doc_491521501746_item	3754945	et	0	main
vesi	doc_491521501746_item	3754946	et	0	main
hakkas	doc_491521501746_item	3754947	et	0	main
tulema	doc_491521501746_item	3754948	et	0	main
nii	doc_491521501746_item	3754949	et	0	main
et	doc_491521501746_item	3754950	et	0	main
vahutas	doc_491521501746_item	3754951	et	0	main
isa	doc_491521501746_item	3754952	et	0	main
vaatas	doc_491521501746_item	3754953	et	0	main
et	doc_491521501746_item	3754954	et	0	main
sai	doc_491521501746_item	3754955	et	0	main
välja	doc_491521501746_item	3754956	et	0	main
ühel	doc_491521501746_item	3754957	et	0	main
mehel	doc_491521501746_item	3754958	et	0	main
olid	doc_491521501746_item	3754959	et	0	main
silmad	doc_491521501746_item	3754960	et	0	main
haiged	doc_491521501746_item	3754961	et	0	main
ta	doc_491521501746_item	3754962	et	0	main
käis	doc_491521501746_item	3754963	et	0	main
hommikul	doc_491521501746_item	3754964	et	0	main
vara	doc_491521501746_item	3754965	et	0	main
enne	doc_491521501746_item	3754966	et	0	main
kui	doc_491521501746_item	3754967	et	0	main
keegi	doc_491521501746_item	3754968	et	0	main
polnud	doc_491521501746_item	3754969	et	0	main
veel	doc_491521501746_item	3754970	et	0	main
allikast	doc_491521501746_item	3754971	et	0	main
vett	doc_491521501746_item	3754972	et	0	main
võtnud	doc_491521501746_item	3754973	et	0	main
et	doc_491521501746_item	3754974	et	0	main
siis	doc_491521501746_item	3754975	et	0	main
on	doc_491521501746_item	3754976	et	0	main
veel	doc_491521501746_item	3754977	et	0	main
ravimõju	doc_491521501746_item	3754978	et	0	main
ja	doc_491521501746_item	3754979	et	0	main
viis	doc_491521501746_item	3754980	et	0	main
endale	doc_491521501746_item	3754981	et	0	main
koju	doc_491521501746_item	3754982	et	0	main
silmade	doc_491521501746_item	3754983	et	0	main
pesemiseks	doc_491521501746_item	3754984	et	0	main
mõjus	doc_491521501746_item	3754985	et	0	main
hästi	doc_491521501746_item	3754986	et	0	main
rkm	doc_491521501746_item	3754987	et	0	main
ii	doc_491521501746_item	3754988	et	0	main
435	doc_491521501746_item	3754989	et	0	main
245	doc_491521501746_item	3754990	et	0	main
30	doc_491521501746_item	3754991	et	0	main
nissi	doc_491521501746_item	3754992	et	0	main
turba	doc_491521501746_item	3754993	et	0	main
al	doc_491521501746_item	3754994	et	0	main
ellamaa	doc_491521501746_item	3754995	et	0	main
k	doc_491521501746_item	3754996	et	0	main
kullamaa	doc_491521501746_item	3754997	et	0	main
päri	doc_491521501746_item	3754998	et	0	main
as	doc_491521501746_item	3754999	et	0	main
kadi	doc_491521501746_item	3755000	et	0	main
sarv	doc_491521501746_item	3755001	et	0	main
salme	doc_491521501746_item	3755002	et	0	main
villenthal	doc_491521501746_item	3755003	et	0	main
s	doc_491521501746_item	3755004	et	0	main
1923	doc_491521501746_item	3755005	et	0	main
a	doc_491521501746_item	3755006	et	0	main
1990	doc_491521501746_item	3755007	et	0	main
virukülas	doc_491521501746_item	3755008	et	0	main
võidu	doc_491521501746_item	3755009	et	0	main
talu	doc_491521501746_item	3755010	et	0	main
juures	doc_491521501746_item	3755011	et	0	main
on	doc_491521501746_item	3755012	et	0	main
aupa	doc_491521501746_item	3755013	et	0	main
allikas	doc_491521501746_item	3755014	et	0	main
aupa	doc_491521501746_item	3755015	et	0	main
talu	doc_491521501746_item	3755016	et	0	main
on	doc_491521501746_item	3755017	et	0	main
seal	doc_491521501746_item	3755018	et	0	main
lähedal	doc_491521501746_item	3755019	et	0	main
see	doc_491521501746_item	3755020	et	0	main
on	doc_491521501746_item	3755021	et	0	main
silmaallikas	doc_491521501746_item	3755022	et	0	main
vanemad	doc_491521501746_item	3755023	et	0	main
inimesed	doc_491521501746_item	3755024	et	0	main
käivad	doc_491521501746_item	3755025	et	0	main
veel	doc_491521501746_item	3755026	et	0	main
praedugi	doc_491521501746_item	3755027	et	0	main
seal	doc_491521501746_item	3755028	et	0	main
silmi	doc_491521501746_item	3755029	et	0	main
pesemas	doc_491521501746_item	3755030	et	0	main
nad	doc_491521501746_item	3755031	et	0	main
viivad	doc_491521501746_item	3755032	et	0	main
saelt	doc_491521501746_item	3755033	et	0	main
ka	doc_491521501746_item	3755034	et	0	main
vett	doc_491521501746_item	3755035	et	0	main
kaasa	doc_491521501746_item	3755036	et	0	main
rkm	doc_491521501746_item	3755037	et	0	main
ii	doc_491521501746_item	3755038	et	0	main
435	doc_491521501746_item	3755039	et	0	main
264	doc_491521501746_item	3755040	et	0	main
2	doc_491521501746_item	3755041	et	0	main
nissi	doc_491521501746_item	3755042	et	0	main
turba	doc_491521501746_item	3755043	et	0	main
al	doc_491521501746_item	3755044	et	0	main
põltsamaa	doc_491521501746_item	3755045	et	0	main
khk	doc_491521501746_item	3755046	et	0	main
kadi	doc_491521501746_item	3755047	et	0	main
sarv	doc_491521501746_item	3755048	et	0	main
agnes	doc_491521501746_item	3755049	et	0	main
saliste	doc_491521501746_item	3755050	et	0	main
s	doc_491521501746_item	3755051	et	0	main
1923	doc_491521501746_item	3755052	et	0	main
a	doc_491521501746_item	3755053	et	0	main
1990	doc_491521501746_item	3755054	et	0	main
pajaka	doc_491521501746_item	3755055	et	0	main
külas	doc_491521501746_item	3755056	et	0	main
läheb	doc_491521501746_item	3755057	et	0	main
jõgi	doc_491521501746_item	3755058	et	0	main
maa	doc_491521501746_item	3755059	et	0	main
alt	doc_491521501746_item	3755060	et	0	main
läbi	doc_491521501746_item	3755061	et	0	main
nissi	doc_491521501746_item	3755062	et	0	main
kuristikust	doc_491521501746_item	3755063	et	0	main
tuleb	doc_491521501746_item	3755064	et	0	main
välja	doc_491521501746_item	3755065	et	0	main
kiriku	doc_491521501746_item	3755066	et	0	main
nurga	doc_491521501746_item	3755067	et	0	main
alt	doc_491521501746_item	3755068	et	0	main
pidi	doc_491521501746_item	3755069	et	0	main
veetõusmesse	doc_491521501746_item	3755070	et	0	main
jõgi	doc_491521501746_item	3755071	et	0	main
minema	doc_491521501746_item	3755072	et	0	main
välja	doc_491521501746_item	3755073	et	0	main
rkm	doc_491521501746_item	3755074	et	0	main
ii	doc_491521501746_item	3755075	et	0	main
434	doc_491521501746_item	3755076	et	0	main
174	doc_491521501746_item	3755077	et	0	main
14	doc_491521501746_item	3755078	et	0	main
nissi	doc_491521501746_item	3755079	et	0	main
khk	doc_491521501746_item	3755080	et	0	main
varbola	doc_491521501746_item	3755081	et	0	main
v	doc_491521501746_item	3755082	et	0	main
jutapere	doc_491521501746_item	3755083	et	0	main
e	doc_491521501746_item	3755084	et	0	main
pajaka	doc_491521501746_item	3755085	et	0	main
k	doc_491521501746_item	3755086	et	0	main
nurme	doc_491521501746_item	3755087	et	0	main
k	doc_491521501746_item	3755088	et	0	main
hilda	doc_491521501746_item	3755089	et	0	main
leismann	doc_491521501746_item	3755090	et	0	main
s	doc_491521501746_item	3755091	et	0	main
ehrpais	doc_491521501746_item	3755092	et	0	main
81	doc_491521501746_item	3755093	et	0	main
a	doc_491521501746_item	3755094	et	0	main
1990	doc_491521501746_item	3755095	et	0	main
valgejärve	doc_491521501746_item	3755096	et	0	main
nimi	doc_491521501746_item	3755097	et	0	main
on	doc_491521501746_item	3755098	et	0	main
sellest	doc_491521501746_item	3755099	et	0	main
see	doc_491521501746_item	3755100	et	0	main
on	doc_491521501746_item	3755101	et	0	main
siin	doc_491521501746_item	3755102	et	0	main
lähedal	doc_491521501746_item	3755103	et	0	main
et	doc_491521501746_item	3755104	et	0	main
sealt	doc_491521501746_item	3755105	et	0	main
toodi	doc_491521501746_item	3755106	et	0	main
valget	doc_491521501746_item	3755107	et	0	main
muda	doc_491521501746_item	3755108	et	0	main
see	doc_491521501746_item	3755109	et	0	main
on	doc_491521501746_item	3755110	et	0	main
nüüd	doc_491521501746_item	3755111	et	0	main
kinni	doc_491521501746_item	3755112	et	0	main
kasvanud	doc_491521501746_item	3755113	et	0	main
see	doc_491521501746_item	3755114	et	0	main
järv	doc_491521501746_item	3755115	et	0	main
on	doc_491521501746_item	3755116	et	0	main
kuskil	doc_491521501746_item	3755117	et	0	main
ellamaal	doc_491521501746_item	3755118	et	0	main
taga	doc_491521501746_item	3755119	et	0	main
raba	doc_491521501746_item	3755120	et	0	main
sees	doc_491521501746_item	3755121	et	0	main
üks	doc_491521501746_item	3755122	et	0	main
mees	doc_491521501746_item	3755123	et	0	main
näitas	doc_491521501746_item	3755124	et	0	main
tünni	doc_491521501746_item	3755125	et	0	main
sees	doc_491521501746_item	3755126	et	0	main
seda	doc_491521501746_item	3755127	et	0	main
muda	doc_491521501746_item	3755128	et	0	main
lubjati	doc_491521501746_item	3755129	et	0	main
seinu	doc_491521501746_item	3755130	et	0	main
siis	doc_491521501746_item	3755131	et	0	main
pandi	doc_491521501746_item	3755132	et	0	main
värviks	doc_491521501746_item	3755133	et	0	main
hulka	doc_491521501746_item	3755134	et	0	main
rkm	doc_491521501746_item	3755135	et	0	main
ii	doc_491521501746_item	3755136	et	0	main
434	doc_491521501746_item	3755137	et	0	main
307	doc_491521501746_item	3755138	et	0	main
6	doc_491521501746_item	3755139	et	0	main
nissi	doc_491521501746_item	3755140	et	0	main
khk	doc_491521501746_item	3755141	et	0	main
riisipere	doc_491521501746_item	3755142	et	0	main
v	doc_491521501746_item	3755143	et	0	main
madila	doc_491521501746_item	3755144	et	0	main
k	doc_491521501746_item	3755145	et	0	main
mall	doc_491521501746_item	3755146	et	0	main
hiiemäe	doc_491521501746_item	3755147	et	0	main
rein	doc_491521501746_item	3755148	et	0	main
leheroo	doc_491521501746_item	3755149	et	0	main
s	doc_491521501746_item	3755150	et	0	main
1949	doc_491521501746_item	3755151	et	0	main
a	doc_491521501746_item	3755152	et	0	main
1990	doc_491521501746_item	3755153	et	0	main
sillasoo	doc_491521501746_item	3755154	et	0	main
ja	doc_491521501746_item	3755155	et	0	main
jaagu	doc_491521501746_item	3755156	et	0	main
järved	doc_491521501746_item	3755157	et	0	main
on	doc_491521501746_item	3755158	et	0	main
nüüd	doc_491521501746_item	3755159	et	0	main
kuivanud	doc_491521501746_item	3755160	et	0	main
järveotsa	doc_491521501746_item	3755161	et	0	main
järv	doc_491521501746_item	3755162	et	0	main
on	doc_491521501746_item	3755163	et	0	main
alles	doc_491521501746_item	3755164	et	0	main
aga	doc_491521501746_item	3755165	et	0	main
mingit	doc_491521501746_item	3755166	et	0	main
jutte	doc_491521501746_item	3755167	et	0	main
tema	doc_491521501746_item	3755168	et	0	main
kohta	doc_491521501746_item	3755169	et	0	main
ei	doc_491521501746_item	3755170	et	0	main
tea	doc_491521501746_item	3755171	et	0	main
rkm	doc_491521501746_item	3755172	et	0	main
ii	doc_491521501746_item	3755173	et	0	main
435	doc_491521501746_item	3755174	et	0	main
227	doc_491521501746_item	3755175	et	0	main
4	doc_491521501746_item	3755176	et	0	main
nissi	doc_491521501746_item	3755177	et	0	main
turba	doc_491521501746_item	3755178	et	0	main
al	doc_491521501746_item	3755179	et	0	main
ellamaa	doc_491521501746_item	3755180	et	0	main
k	doc_491521501746_item	3755181	et	0	main
kadi	doc_491521501746_item	3755182	et	0	main
sarv	doc_491521501746_item	3755183	et	0	main
feliks	doc_491521501746_item	3755184	et	0	main
päärson	doc_491521501746_item	3755185	et	0	main
s	doc_491521501746_item	3755186	et	0	main
1910	doc_491521501746_item	3755187	et	0	main
a	doc_491521501746_item	3755188	et	0	main
1990	doc_491521501746_item	3755189	et	0	main
järveotsa	doc_491521501746_item	3755190	et	0	main
järv	doc_491521501746_item	3755191	et	0	main
on	doc_491521501746_item	3755192	et	0	main
nagu	doc_491521501746_item	3755193	et	0	main
maa	doc_491521501746_item	3755194	et	0	main
alla	doc_491521501746_item	3755195	et	0	main
vajunud	doc_491521501746_item	3755196	et	0	main
puu	doc_491521501746_item	3755197	et	0	main
juured	doc_491521501746_item	3755198	et	0	main
on	doc_491521501746_item	3755199	et	0	main
põhjas	doc_491521501746_item	3755200	et	0	main
ta	doc_491521501746_item	3755201	et	0	main
on	doc_491521501746_item	3755202	et	0	main
umbjärv	doc_491521501746_item	3755203	et	0	main
rkm	doc_491521501746_item	3755204	et	0	main
ii	doc_491521501746_item	3755205	et	0	main
435	doc_491521501746_item	3755206	et	0	main
264	doc_491521501746_item	3755207	et	0	main
3	doc_491521501746_item	3755208	et	0	main
nissi	doc_491521501746_item	3755209	et	0	main
turba	doc_491521501746_item	3755210	et	0	main
al	doc_491521501746_item	3755211	et	0	main
põltsamaa	doc_491521501746_item	3755212	et	0	main
khk	doc_491521501746_item	3755213	et	0	main
kadi	doc_491521501746_item	3755214	et	0	main
sarv	doc_491521501746_item	3755215	et	0	main
agnes	doc_491521501746_item	3755216	et	0	main
saliste	doc_491521501746_item	3755217	et	0	main
s	doc_491521501746_item	3755218	et	0	main
1923	doc_491521501746_item	3755219	et	0	main
a	doc_491521501746_item	3755220	et	0	main
1990	doc_491521501746_item	3755221	et	0	main
järveotsa	doc_491521501746_item	3755222	et	0	main
järv	doc_491521501746_item	3755223	et	0	main
tussu	doc_491521501746_item	3755224	et	0	main
raba	doc_491521501746_item	3755225	et	0	main
sealt	doc_491521501746_item	3755226	et	0	main
jooksevad	doc_491521501746_item	3755227	et	0	main
välja	doc_491521501746_item	3755228	et	0	main
paljud	doc_491521501746_item	3755229	et	0	main
allikad	doc_491521501746_item	3755230	et	0	main
nagu	doc_491521501746_item	3755231	et	0	main
tussud	doc_491521501746_item	3755232	et	0	main
tulevad	doc_491521501746_item	3755233	et	0	main
seal	doc_491521501746_item	3755234	et	0	main
on	doc_491521501746_item	3755235	et	0	main
10	doc_491521501746_item	3755236	et	0	main
allikat	doc_491521501746_item	3755237	et	0	main
rkm	doc_491521501746_item	3755238	et	0	main
ii	doc_491521501746_item	3755239	et	0	main
435	doc_491521501746_item	3755240	et	0	main
263264	doc_491521501746_item	3755241	et	0	main
1	doc_491521501746_item	3755242	et	0	main
nissi	doc_491521501746_item	3755243	et	0	main
turba	doc_491521501746_item	3755244	et	0	main
al	doc_491521501746_item	3755245	et	0	main
põltsamaa	doc_491521501746_item	3755246	et	0	main
khk	doc_491521501746_item	3755247	et	0	main
kadi	doc_491521501746_item	3755248	et	0	main
sarv	doc_491521501746_item	3755249	et	0	main
agnes	doc_491521501746_item	3755250	et	0	main
saliste	doc_491521501746_item	3755251	et	0	main
s	doc_491521501746_item	3755252	et	0	main
1923	doc_491521501746_item	3755253	et	0	main
a	doc_491521501746_item	3755254	et	0	main
1990	doc_491521501746_item	3755255	et	0	main
kolju	doc_491521501746_item	3755256	et	0	main
kuristikus	doc_491521501746_item	3755257	et	0	main
oli	doc_491521501746_item	3755258	et	0	main
nii	doc_491521501746_item	3755259	et	0	main
suur	doc_491521501746_item	3755260	et	0	main
veetõmme	doc_491521501746_item	3755261	et	0	main
et	doc_491521501746_item	3755262	et	0	main
kolju	doc_491521501746_item	3755263	et	0	main
lehm	doc_491521501746_item	3755264	et	0	main
oli	doc_491521501746_item	3755265	et	0	main
sealt	doc_491521501746_item	3755266	et	0	main
alla	doc_491521501746_item	3755267	et	0	main
läinud	doc_491521501746_item	3755268	et	0	main
luud	doc_491521501746_item	3755269	et	0	main
leiti	doc_491521501746_item	3755270	et	0	main
jõetõusmel	doc_491521501746_item	3755271	et	0	main
tuli	doc_491521501746_item	3755272	et	0	main
välja	doc_491521501746_item	3755273	et	0	main
paljas	doc_491521501746_item	3755274	et	0	main
selgroog	doc_491521501746_item	3755275	et	0	main
oli	doc_491521501746_item	3755276	et	0	main
ütlevad	doc_491521501746_item	3755277	et	0	main
et	doc_491521501746_item	3755278	et	0	main
kell	doc_491521501746_item	3755279	et	0	main
oli	doc_491521501746_item	3755280	et	0	main
veel	doc_491521501746_item	3755281	et	0	main
luukere	doc_491521501746_item	3755282	et	0	main
kaelas	doc_491521501746_item	3755283	et	0	main
üks	doc_491521501746_item	3755284	et	0	main
vallasant	doc_491521501746_item	3755285	et	0	main
läind	doc_491521501746_item	3755286	et	0	main
sinna	doc_491521501746_item	3755287	et	0	main
ja	doc_491521501746_item	3755288	et	0	main
tõmband	doc_491521501746_item	3755289	et	0	main
ka	doc_491521501746_item	3755290	et	0	main
alla	doc_491521501746_item	3755291	et	0	main
pärast	doc_491521501746_item	3755292	et	0	main
veeti	doc_491521501746_item	3755293	et	0	main
kiva	doc_491521501746_item	3755294	et	0	main
täis	doc_491521501746_item	3755295	et	0	main
aga	doc_491521501746_item	3755296	et	0	main
tugev	doc_491521501746_item	3755297	et	0	main
neelukoht	doc_491521501746_item	3755298	et	0	main
oli	doc_491521501746_item	3755299	et	0	main
rkm	doc_491521501746_item	3755300	et	0	main
ii	doc_491521501746_item	3755301	et	0	main
435	doc_491521501746_item	3755302	et	0	main
151	doc_491521501746_item	3755303	et	0	main
3	doc_491521501746_item	3755304	et	0	main
nissi	doc_491521501746_item	3755305	et	0	main
v	doc_491521501746_item	3755306	et	0	main
odolemma	doc_491521501746_item	3755307	et	0	main
k	doc_491521501746_item	3755308	et	0	main
jaanijüri	doc_491521501746_item	3755309	et	0	main
t	doc_491521501746_item	3755310	et	0	main
kernu	doc_491521501746_item	3755311	et	0	main
v	doc_491521501746_item	3755312	et	0	main
miilima	doc_491521501746_item	3755313	et	0	main
k	doc_491521501746_item	3755314	et	0	main
mare	doc_491521501746_item	3755315	et	0	main
janneste	doc_491521501746_item	3755316	et	0	main
aliide	doc_491521501746_item	3755317	et	0	main
niinemaa	doc_491521501746_item	3755318	et	0	main
smagnus	doc_491521501746_item	3755319	et	0	main
s	doc_491521501746_item	3755320	et	0	main
1919	doc_491521501746_item	3755321	et	0	main
a	doc_491521501746_item	3755322	et	0	main
august	doc_491521501746_item	3755323	et	0	main
niinemaa	doc_491521501746_item	3755324	et	0	main
s	doc_491521501746_item	3755325	et	0	main
1912	doc_491521501746_item	3755326	et	0	main
a	doc_491521501746_item	3755327	et	0	main
liidia	doc_491521501746_item	3755328	et	0	main
metsjõe	doc_491521501746_item	3755329	et	0	main
s	doc_491521501746_item	3755330	et	0	main
1942	doc_491521501746_item	3755331	et	0	main
a	doc_491521501746_item	3755332	et	0	main
eelmiste	doc_491521501746_item	3755333	et	0	main
tütar	doc_491521501746_item	3755334	et	0	main
1990	doc_491521501746_item	3755335	et	0	main
viidiauk	doc_491521501746_item	3755336	et	0	main
oli	doc_491521501746_item	3755337	et	0	main
ühenduses	doc_491521501746_item	3755338	et	0	main
kolju	doc_491521501746_item	3755339	et	0	main
kuristikuga	doc_491521501746_item	3755340	et	0	main
maa-aluse	doc_491521501746_item	3755341	et	0	main
jõega	doc_491521501746_item	3755342	et	0	main
ilmus	doc_491521501746_item	3755343	et	0	main
korra	doc_491521501746_item	3755344	et	0	main
maa	doc_491521501746_item	3755345	et	0	main
peale	doc_491521501746_item	3755346	et	0	main
ja	doc_491521501746_item	3755347	et	0	main
raba	doc_491521501746_item	3755348	et	0	main
äärest	doc_491521501746_item	3755349	et	0	main
läks	doc_491521501746_item	3755350	et	0	main
minema	doc_491521501746_item	3755351	et	0	main
rkm	doc_491521501746_item	3755352	et	0	main
ii	doc_491521501746_item	3755353	et	0	main
435	doc_491521501746_item	3755354	et	0	main
151	doc_491521501746_item	3755355	et	0	main
4	doc_491521501746_item	3755356	et	0	main
nissi	doc_491521501746_item	3755357	et	0	main
v	doc_491521501746_item	3755358	et	0	main
odolemma	doc_491521501746_item	3755359	et	0	main
k	doc_491521501746_item	3755360	et	0	main
jaanijüri	doc_491521501746_item	3755361	et	0	main
t	doc_491521501746_item	3755362	et	0	main
kernu	doc_491521501746_item	3755363	et	0	main
v	doc_491521501746_item	3755364	et	0	main
miilima	doc_491521501746_item	3755365	et	0	main
k	doc_491521501746_item	3755366	et	0	main
mare	doc_491521501746_item	3755367	et	0	main
janneste	doc_491521501746_item	3755368	et	0	main
aliide	doc_491521501746_item	3755369	et	0	main
niinemaa	doc_491521501746_item	3755370	et	0	main
s	doc_491521501746_item	3755371	et	0	main
magnus	doc_491521501746_item	3755372	et	0	main
s	doc_491521501746_item	3755373	et	0	main
1919	doc_491521501746_item	3755374	et	0	main
a	doc_491521501746_item	3755375	et	0	main
august	doc_491521501746_item	3755376	et	0	main
niinemaa	doc_491521501746_item	3755377	et	0	main
s	doc_491521501746_item	3755378	et	0	main
1912	doc_491521501746_item	3755379	et	0	main
a	doc_491521501746_item	3755380	et	0	main
liidia	doc_491521501746_item	3755381	et	0	main
metsjõe	doc_491521501746_item	3755382	et	0	main
s	doc_491521501746_item	3755383	et	0	main
1942	doc_491521501746_item	3755384	et	0	main
a	doc_491521501746_item	3755385	et	0	main
eelmiste	doc_491521501746_item	3755386	et	0	main
tütar	doc_491521501746_item	3755387	et	0	main
1990	doc_491521501746_item	3755388	et	0	main
siinkandis	doc_491521501746_item	3755389	et	0	main
on	doc_491521501746_item	3755390	et	0	main
üks	doc_491521501746_item	3755391	et	0	main
kolju	doc_491521501746_item	3755392	et	0	main
kuristik	doc_491521501746_item	3755393	et	0	main
sealt	doc_491521501746_item	3755394	et	0	main
läheb	doc_491521501746_item	3755395	et	0	main
läbi	doc_491521501746_item	3755396	et	0	main
üks	doc_491521501746_item	3755397	et	0	main
salajõgi	doc_491521501746_item	3755398	et	0	main
kiriku	doc_491521501746_item	3755399	et	0	main
alt	doc_491521501746_item	3755400	et	0	main
läheb	doc_491521501746_item	3755401	et	0	main
ja	doc_491521501746_item	3755402	et	0	main
vee	doc_491521501746_item	3755403	et	0	main
kohinat	doc_491521501746_item	3755404	et	0	main
on	doc_491521501746_item	3755405	et	0	main
kuulda	doc_491521501746_item	3755406	et	0	main
ja	doc_491521501746_item	3755407	et	0	main
veetõusmest	doc_491521501746_item	3755408	et	0	main
tuleb	doc_491521501746_item	3755409	et	0	main
välja	doc_491521501746_item	3755410	et	0	main
see	doc_491521501746_item	3755411	et	0	main
on	doc_491521501746_item	3755412	et	0	main
seal	doc_491521501746_item	3755413	et	0	main
kirikust	doc_491521501746_item	3755414	et	0	main
allapoole	doc_491521501746_item	3755415	et	0	main
seal	doc_491521501746_item	3755416	et	0	main
nissi	doc_491521501746_item	3755417	et	0	main
kirikus	doc_491521501746_item	3755418	et	0	main
on	doc_491521501746_item	3755419	et	0	main
rahvas	doc_491521501746_item	3755420	et	0	main
jutluse	doc_491521501746_item	3755421	et	0	main
ajal	doc_491521501746_item	3755422	et	0	main
hanekaginat	doc_491521501746_item	3755423	et	0	main
kuulnud	doc_491521501746_item	3755424	et	0	main
ja	doc_491521501746_item	3755425	et	0	main
vahest	doc_491521501746_item	3755426	et	0	main
on	doc_491521501746_item	3755427	et	0	main
kuulda	doc_491521501746_item	3755428	et	0	main
kohinat	doc_491521501746_item	3755429	et	0	main
ja	doc_491521501746_item	3755430	et	0	main
lehm	doc_491521501746_item	3755431	et	0	main
oli	doc_491521501746_item	3755432	et	0	main
ka	doc_491521501746_item	3755433	et	0	main
selle	doc_491521501746_item	3755434	et	0	main
alla	doc_491521501746_item	3755435	et	0	main
vajunud	doc_491521501746_item	3755436	et	0	main
sealt	doc_491521501746_item	3755437	et	0	main
kolju	doc_491521501746_item	3755438	et	0	main
kuristikust	doc_491521501746_item	3755439	et	0	main
ja	doc_491521501746_item	3755440	et	0	main
teisest	doc_491521501746_item	3755441	et	0	main
otsast	doc_491521501746_item	3755442	et	0	main
oli	doc_491521501746_item	3755443	et	0	main
lehmakell	doc_491521501746_item	3755444	et	0	main
välja	doc_491521501746_item	3755445	et	0	main
tulnud	doc_491521501746_item	3755446	et	0	main
rkm	doc_491521501746_item	3755447	et	0	main
ii	doc_491521501746_item	3755448	et	0	main
434	doc_491521501746_item	3755449	et	0	main
305	doc_491521501746_item	3755450	et	0	main
2	doc_491521501746_item	3755451	et	0	main
nissi	doc_491521501746_item	3755452	et	0	main
khk	doc_491521501746_item	3755453	et	0	main
riisipere	doc_491521501746_item	3755454	et	0	main
v	doc_491521501746_item	3755455	et	0	main
madila	doc_491521501746_item	3755456	et	0	main
k	doc_491521501746_item	3755457	et	0	main
mall	doc_491521501746_item	3755458	et	0	main
hiiemäe	doc_491521501746_item	3755459	et	0	main
rein	doc_491521501746_item	3755460	et	0	main
leheroo	doc_491521501746_item	3755461	et	0	main
s	doc_491521501746_item	3755462	et	0	main
1949	doc_491521501746_item	3755463	et	0	main
a	doc_491521501746_item	3755464	et	0	main
1990	doc_491521501746_item	3755465	et	0	main
viidiauk	doc_491521501746_item	3755466	et	0	main
oli	doc_491521501746_item	3755467	et	0	main
keset	doc_491521501746_item	3755468	et	0	main
põldusid	doc_491521501746_item	3755469	et	0	main
oli	doc_491521501746_item	3755470	et	0	main
veel	doc_491521501746_item	3755471	et	0	main
noorte	doc_491521501746_item	3755472	et	0	main
kogunemiskoht	doc_491521501746_item	3755473	et	0	main
seal	doc_491521501746_item	3755474	et	0	main
oli	doc_491521501746_item	3755475	et	0	main
kevaditi	doc_491521501746_item	3755476	et	0	main
vesi	doc_491521501746_item	3755477	et	0	main
sees	doc_491521501746_item	3755478	et	0	main
väljatse	doc_491521501746_item	3755479	et	0	main
talu	doc_491521501746_item	3755480	et	0	main
maa	doc_491521501746_item	3755481	et	0	main
peale	doc_491521501746_item	3755482	et	0	main
jäi	doc_491521501746_item	3755483	et	0	main
rkm	doc_491521501746_item	3755484	et	0	main
ii	doc_491521501746_item	3755485	et	0	main
435	doc_491521501746_item	3755486	et	0	main
130	doc_491521501746_item	3755487	et	0	main
2	doc_491521501746_item	3755488	et	0	main
nissi	doc_491521501746_item	3755489	et	0	main
harku	doc_491521501746_item	3755490	et	0	main
k	doc_491521501746_item	3755491	et	0	main
vahemetsa	doc_491521501746_item	3755492	et	0	main
talukoht	doc_491521501746_item	3755493	et	0	main
mare	doc_491521501746_item	3755494	et	0	main
janneste	doc_491521501746_item	3755495	et	0	main
anne	doc_491521501746_item	3755496	et	0	main
karotamm	doc_491521501746_item	3755497	et	0	main
s	doc_491521501746_item	3755498	et	0	main
1939	doc_491521501746_item	3755499	et	0	main
a	doc_491521501746_item	3755500	et	0	main
töötanud	doc_491521501746_item	3755501	et	0	main
algklasside	doc_491521501746_item	3755502	et	0	main
õpetajana	doc_491521501746_item	3755503	et	0	main
tallinnas	doc_491521501746_item	3755504	et	0	main
1990	doc_491521501746_item	3755505	et	0	main
34	doc_491521501746_item	3755506	et	0	main
kivid	doc_491521501746_item	3755507	et	0	main
eestis	doc_491521501746_item	3755508	et	0	main
on	doc_491521501746_item	3755509	et	0	main
pühaks	doc_491521501746_item	3755510	et	0	main
peetud	doc_491521501746_item	3755511	et	0	main
ka	doc_491521501746_item	3755512	et	0	main
kive	doc_491521501746_item	3755513	et	0	main
millele	doc_491521501746_item	3755514	et	0	main
on	doc_491521501746_item	3755515	et	0	main
toodud	doc_491521501746_item	3755516	et	0	main
ohvriande	doc_491521501746_item	3755517	et	0	main
enamasti	doc_491521501746_item	3755518	et	0	main
on	doc_491521501746_item	3755519	et	0	main
need	doc_491521501746_item	3755520	et	0	main
tavalised	doc_491521501746_item	3755521	et	0	main
rändrahnud	doc_491521501746_item	3755522	et	0	main
kusjuures	doc_491521501746_item	3755523	et	0	main
suurus	doc_491521501746_item	3755524	et	0	main
ei	doc_491521501746_item	3755525	et	0	main
ole	doc_491521501746_item	3755526	et	0	main
pühakspidamiseks	doc_491521501746_item	3755527	et	0	main
tähtis	doc_491521501746_item	3755528	et	0	main
austatud	doc_491521501746_item	3755529	et	0	main
on	doc_491521501746_item	3755530	et	0	main
vähem	doc_491521501746_item	3755531	et	0	main
kui	doc_491521501746_item	3755532	et	0	main
meetrise	doc_491521501746_item	3755533	et	0	main
läbimõõduga	doc_491521501746_item	3755534	et	0	main
kive	doc_491521501746_item	3755535	et	0	main
ning	doc_491521501746_item	3755536	et	0	main
selliseid	doc_491521501746_item	3755537	et	0	main
millest	doc_491521501746_item	3755538	et	0	main
valdav	doc_491521501746_item	3755539	et	0	main
osa	doc_491521501746_item	3755540	et	0	main
on	doc_491521501746_item	3755541	et	0	main
maa	doc_491521501746_item	3755542	et	0	main
sees	doc_491521501746_item	3755543	et	0	main
kuju	doc_491521501746_item	3755544	et	0	main
poolest	doc_491521501746_item	3755545	et	0	main
nad	doc_491521501746_item	3755546	et	0	main
on	doc_491521501746_item	3755547	et	0	main
enamasti	doc_491521501746_item	3755548	et	0	main
lamedad	doc_491521501746_item	3755549	et	0	main
paljud	doc_491521501746_item	3755550	et	0	main
looduslike	doc_491521501746_item	3755551	et	0	main
ja	doc_491521501746_item	3755552	et	0	main
mõned	doc_491521501746_item	3755553	et	0	main
kunstlike	doc_491521501746_item	3755554	et	0	main
süvenditega	doc_491521501746_item	3755555	et	0	main
millesse	doc_491521501746_item	3755556	et	0	main
kogunenud	doc_491521501746_item	3755557	et	0	main
vihmaveega	doc_491521501746_item	3755558	et	0	main
on	doc_491521501746_item	3755559	et	0	main
haigusi	doc_491521501746_item	3755560	et	0	main
ravitud	doc_491521501746_item	3755561	et	0	main
ohvrikivid	doc_491521501746_item	3755562	et	0	main
asuvad	doc_491521501746_item	3755563	et	0	main
peamiselt	doc_491521501746_item	3755564	et	0	main
küla	doc_491521501746_item	3755565	et	0	main
lähedal	doc_491521501746_item	3755566	et	0	main
kultuurmaastikus	doc_491521501746_item	3755567	et	0	main
põllul	doc_491521501746_item	3755568	et	0	main
karja-	doc_491521501746_item	3755569	et	0	main
või	doc_491521501746_item	3755570	et	0	main
heinamaal	doc_491521501746_item	3755571	et	0	main
harvemini	doc_491521501746_item	3755572	et	0	main
metsas	doc_491521501746_item	3755573	et	0	main
rahvapäraselt	doc_491521501746_item	3755574	et	0	main
on	doc_491521501746_item	3755575	et	0	main
neid	doc_491521501746_item	3755576	et	0	main
mitmel	doc_491521501746_item	3755577	et	0	main
pool	doc_491521501746_item	3755578	et	0	main
eestis	doc_491521501746_item	3755579	et	0	main
nimetatud	doc_491521501746_item	3755580	et	0	main
hiiekivideks	doc_491521501746_item	3755581	et	0	main
viruküla	doc_491521501746_item	3755582	et	0	main
hiie	doc_491521501746_item	3755583	et	0	main
talu	doc_491521501746_item	3755584	et	0	main
metsas	doc_491521501746_item	3755585	et	0	main
on	doc_491521501746_item	3755586	et	0	main
olnud	doc_491521501746_item	3755587	et	0	main
vanasti	doc_491521501746_item	3755588	et	0	main
püha	doc_491521501746_item	3755589	et	0	main
hiis	doc_491521501746_item	3755590	et	0	main
seal	doc_491521501746_item	3755591	et	0	main
on	doc_491521501746_item	3755592	et	0	main
ka	doc_491521501746_item	3755593	et	0	main
suur	doc_491521501746_item	3755594	et	0	main
kivi	doc_491521501746_item	3755595	et	0	main
mõned	doc_491521501746_item	3755596	et	0	main
teavad	doc_491521501746_item	3755597	et	0	main
rääkida	doc_491521501746_item	3755598	et	0	main
et	doc_491521501746_item	3755599	et	0	main
see	doc_491521501746_item	3755600	et	0	main
on	doc_491521501746_item	3755601	et	0	main
vana	doc_491521501746_item	3755602	et	0	main
ohvri	doc_491521501746_item	3755603	et	0	main
kivi	doc_491521501746_item	3755604	et	0	main
ja	doc_491521501746_item	3755605	et	0	main
seal	doc_491521501746_item	3755606	et	0	main
on	doc_491521501746_item	3755607	et	0	main
käinud	doc_491521501746_item	3755608	et	0	main
vanad	doc_491521501746_item	3755609	et	0	main
nõu	doc_491521501746_item	3755610	et	0	main
pidamas	doc_491521501746_item	3755611	et	0	main
ja	doc_491521501746_item	3755612	et	0	main
ohverdamas	doc_491521501746_item	3755613	et	0	main
era	doc_491521501746_item	3755614	et	0	main
ii	doc_491521501746_item	3755615	et	0	main
226	doc_491521501746_item	3755616	et	0	main
249	doc_491521501746_item	3755617	et	0	main
9	doc_491521501746_item	3755618	et	0	main
nissi	doc_491521501746_item	3755619	et	0	main
riisipere	doc_491521501746_item	3755620	et	0	main
v	doc_491521501746_item	3755621	et	0	main
tabara	doc_491521501746_item	3755622	et	0	main
k	doc_491521501746_item	3755623	et	0	main
a	doc_491521501746_item	3755624	et	0	main
kitsik	doc_491521501746_item	3755625	et	0	main
1939	doc_491521501746_item	3755626	et	0	main
varbola	doc_491521501746_item	3755627	et	0	main
maalinnuse	doc_491521501746_item	3755628	et	0	main
lähedal	doc_491521501746_item	3755629	et	0	main
oli	doc_491521501746_item	3755630	et	0	main
hästi	doc_491521501746_item	3755631	et	0	main
suur	doc_491521501746_item	3755632	et	0	main
kivi	doc_491521501746_item	3755633	et	0	main
see	doc_491521501746_item	3755634	et	0	main
oli	doc_491521501746_item	3755635	et	0	main
küll	doc_491521501746_item	3755636	et	0	main
ohvrikivi	doc_491521501746_item	3755637	et	0	main
olnud	doc_491521501746_item	3755638	et	0	main
ma	doc_491521501746_item	3755639	et	0	main
olen	doc_491521501746_item	3755640	et	0	main
isegi	doc_491521501746_item	3755641	et	0	main
seal	doc_491521501746_item	3755642	et	0	main
kivi	doc_491521501746_item	3755643	et	0	main
peal	doc_491521501746_item	3755644	et	0	main
käinud	doc_491521501746_item	3755645	et	0	main
andis	doc_491521501746_item	3755646	et	0	main
ronida	doc_491521501746_item	3755647	et	0	main
kohe	doc_491521501746_item	3755648	et	0	main
otsa	doc_491521501746_item	3755649	et	0	main
eks	doc_491521501746_item	3755650	et	0	main
ta	doc_491521501746_item	3755651	et	0	main
ole	doc_491521501746_item	3755652	et	0	main
praegu	doc_491521501746_item	3755653	et	0	main
alles	doc_491521501746_item	3755654	et	0	main
rapla	doc_491521501746_item	3755655	et	0	main
maantee	doc_491521501746_item	3755656	et	0	main
käis	doc_491521501746_item	3755657	et	0	main
sealt	doc_491521501746_item	3755658	et	0	main
linnuse	doc_491521501746_item	3755659	et	0	main
lähedalt	doc_491521501746_item	3755660	et	0	main
läbi	doc_491521501746_item	3755661	et	0	main
ta	doc_491521501746_item	3755662	et	0	main
oli	doc_491521501746_item	3755663	et	0	main
seal	doc_491521501746_item	3755664	et	0	main
ääres	doc_491521501746_item	3755665	et	0	main
aga	doc_491521501746_item	3755666	et	0	main
eks	doc_491521501746_item	3755667	et	0	main
nüüd	doc_491521501746_item	3755668	et	0	main
ole	doc_491521501746_item	3755669	et	0	main
tehtud	doc_491521501746_item	3755670	et	0	main
uued	doc_491521501746_item	3755671	et	0	main
teed	doc_491521501746_item	3755672	et	0	main
kõik	doc_491521501746_item	3755673	et	0	main
rkm	doc_491521501746_item	3755674	et	0	main
ii	doc_491521501746_item	3755675	et	0	main
434	doc_491521501746_item	3755676	et	0	main
745	doc_491521501746_item	3755677	et	0	main
4	doc_491521501746_item	3755678	et	0	main
nissi	doc_491521501746_item	3755679	et	0	main
lehetu	doc_491521501746_item	3755680	et	0	main
k	doc_491521501746_item	3755681	et	0	main
pajaka	doc_491521501746_item	3755682	et	0	main
k	doc_491521501746_item	3755683	et	0	main
varbola	doc_491521501746_item	3755684	et	0	main
v	doc_491521501746_item	3755685	et	0	main
ja	doc_491521501746_item	3755686	et	0	main
k	doc_491521501746_item	3755687	et	0	main
mall	doc_491521501746_item	3755688	et	0	main
hiiemäe	doc_491521501746_item	3755689	et	0	main
hilda	doc_491521501746_item	3755690	et	0	main
nurmbek	doc_491521501746_item	3755691	et	0	main
s	doc_491521501746_item	3755692	et	0	main
1908	doc_491521501746_item	3755693	et	0	main
a	doc_491521501746_item	3755694	et	0	main
1990	doc_491521501746_item	3755695	et	0	main
aadul	doc_491521501746_item	3755696	et	0	main
oli	doc_491521501746_item	3755697	et	0	main
aadu	doc_491521501746_item	3755698	et	0	main
niis	doc_491521501746_item	3755699	et	0	main
ja	doc_491521501746_item	3755700	et	0	main
ohvrikivi	doc_491521501746_item	3755701	et	0	main
oli	doc_491521501746_item	3755702	et	0	main
seal	doc_491521501746_item	3755703	et	0	main
see	doc_491521501746_item	3755704	et	0	main
hiiemets	doc_491521501746_item	3755705	et	0	main
on	doc_491521501746_item	3755706	et	0	main
maha	doc_491521501746_item	3755707	et	0	main
kõik	doc_491521501746_item	3755708	et	0	main
võetud	doc_491521501746_item	3755709	et	0	main
aga	doc_491521501746_item	3755710	et	0	main
kus	doc_491521501746_item	3755711	et	0	main
see	doc_491521501746_item	3755712	et	0	main
kivi	doc_491521501746_item	3755713	et	0	main
on	doc_491521501746_item	3755714	et	0	main
ei	doc_491521501746_item	3755715	et	0	main
tea	doc_491521501746_item	3755716	et	0	main
talu	doc_491521501746_item	3755717	et	0	main
lähedal	doc_491521501746_item	3755718	et	0	main
oli	doc_491521501746_item	3755719	et	0	main
põld	doc_491521501746_item	3755720	et	0	main
oli	doc_491521501746_item	3755721	et	0	main
vahel	doc_491521501746_item	3755722	et	0	main
suur	doc_491521501746_item	3755723	et	0	main
kivi	doc_491521501746_item	3755724	et	0	main
rohkem	doc_491521501746_item	3755725	et	0	main
maa	doc_491521501746_item	3755726	et	0	main
sees	doc_491521501746_item	3755727	et	0	main
nii	doc_491521501746_item	3755728	et	0	main
kõrge	doc_491521501746_item	3755729	et	0	main
näitab	doc_491521501746_item	3755730	et	0	main
u	doc_491521501746_item	3755731	et	0	main
pool	doc_491521501746_item	3755732	et	0	main
m	doc_491521501746_item	3755733	et	0	main
aga	doc_491521501746_item	3755734	et	0	main
lai	doc_491521501746_item	3755735	et	0	main
nii	doc_491521501746_item	3755736	et	0	main
lai	doc_491521501746_item	3755737	et	0	main
nagu	doc_491521501746_item	3755738	et	0	main
see	doc_491521501746_item	3755739	et	0	main
pool	doc_491521501746_item	3755740	et	0	main
tuba	doc_491521501746_item	3755741	et	0	main
seda	doc_491521501746_item	3755742	et	0	main
öeldi	doc_491521501746_item	3755743	et	0	main
ohvrikivi	doc_491521501746_item	3755744	et	0	main
me	doc_491521501746_item	3755745	et	0	main
käisime	doc_491521501746_item	3755746	et	0	main
sealt	doc_491521501746_item	3755747	et	0	main
kuldraha	doc_491521501746_item	3755748	et	0	main
nokkima	doc_491521501746_item	3755749	et	0	main
et	doc_491521501746_item	3755750	et	0	main
vast	doc_491521501746_item	3755751	et	0	main
on	doc_491521501746_item	3755752	et	0	main
rkm	doc_491521501746_item	3755753	et	0	main
ii	doc_491521501746_item	3755754	et	0	main
434	doc_491521501746_item	3755755	et	0	main
115	doc_491521501746_item	3755756	et	0	main
3	doc_491521501746_item	3755757	et	0	main
nissi	doc_491521501746_item	3755758	et	0	main
khk	doc_491521501746_item	3755759	et	0	main
riisipere	doc_491521501746_item	3755760	et	0	main
v	doc_491521501746_item	3755761	et	0	main
terjatu	doc_491521501746_item	3755762	et	0	main
k	doc_491521501746_item	3755763	et	0	main
lehetu	doc_491521501746_item	3755764	et	0	main
k	doc_491521501746_item	3755765	et	0	main
mall	doc_491521501746_item	3755766	et	0	main
hiiemäe	doc_491521501746_item	3755767	et	0	main
paul	doc_491521501746_item	3755768	et	0	main
linroos	doc_491521501746_item	3755769	et	0	main
s	doc_491521501746_item	3755770	et	0	main
1919	doc_491521501746_item	3755771	et	0	main
a	doc_491521501746_item	3755772	et	0	main
1990	doc_491521501746_item	3755773	et	0	main
russalu	doc_491521501746_item	3755774	et	0	main
kandis	doc_491521501746_item	3755775	et	0	main
on	doc_491521501746_item	3755776	et	0	main
õige	doc_491521501746_item	3755777	et	0	main
suur	doc_491521501746_item	3755778	et	0	main
kivi	doc_491521501746_item	3755779	et	0	main
metsa	doc_491521501746_item	3755780	et	0	main
sees	doc_491521501746_item	3755781	et	0	main
see	doc_491521501746_item	3755782	et	0	main
on	doc_491521501746_item	3755783	et	0	main
ohvrikivi	doc_491521501746_item	3755784	et	0	main
sest	doc_491521501746_item	3755785	et	0	main
ohverdamisest	doc_491521501746_item	3755786	et	0	main
ma	doc_491521501746_item	3755787	et	0	main
ei	doc_491521501746_item	3755788	et	0	main
tea	doc_491521501746_item	3755789	et	0	main
aga	doc_491521501746_item	3755790	et	0	main
seal	doc_491521501746_item	3755791	et	0	main
pidi	doc_491521501746_item	3755792	et	0	main
hästi	doc_491521501746_item	3755793	et	0	main
palju	doc_491521501746_item	3755794	et	0	main
kulda	doc_491521501746_item	3755795	et	0	main
all	doc_491521501746_item	3755796	et	0	main
olema	doc_491521501746_item	3755797	et	0	main
vanasti	doc_491521501746_item	3755798	et	0	main
kui	doc_491521501746_item	3755799	et	0	main
ma	doc_491521501746_item	3755800	et	0	main
laps	doc_491521501746_item	3755801	et	0	main
olin	doc_491521501746_item	3755802	et	0	main
siis	doc_491521501746_item	3755803	et	0	main
ikka	doc_491521501746_item	3755804	et	0	main
vanad	doc_491521501746_item	3755805	et	0	main
inimesed	doc_491521501746_item	3755806	et	0	main
ütlesid	doc_491521501746_item	3755807	et	0	main
et	doc_491521501746_item	3755808	et	0	main
sinn	doc_491521501746_item	3755809	et	0	main
kivi	doc_491521501746_item	3755810	et	0	main
juurde	doc_491521501746_item	3755811	et	0	main
ei	doc_491521501746_item	3755812	et	0	main
tohi	doc_491521501746_item	3755813	et	0	main
minna	doc_491521501746_item	3755814	et	0	main
seal	doc_491521501746_item	3755815	et	0	main
on	doc_491521501746_item	3755816	et	0	main
ussid	doc_491521501746_item	3755817	et	0	main
väljas	doc_491521501746_item	3755818	et	0	main
aga	doc_491521501746_item	3755819	et	0	main
seal	doc_491521501746_item	3755820	et	0	main
on	doc_491521501746_item	3755821	et	0	main
niisugune	doc_491521501746_item	3755822	et	0	main
risune	doc_491521501746_item	3755823	et	0	main
võib-olla	doc_491521501746_item	3755824	et	0	main
et	doc_491521501746_item	3755825	et	0	main
seal	doc_491521501746_item	3755826	et	0	main
oligi	doc_491521501746_item	3755827	et	0	main
neid	doc_491521501746_item	3755828	et	0	main
rohkem	doc_491521501746_item	3755829	et	0	main
rkm	doc_491521501746_item	3755830	et	0	main
ii	doc_491521501746_item	3755831	et	0	main
434	doc_491521501746_item	3755832	et	0	main
305306	doc_491521501746_item	3755833	et	0	main
3	doc_491521501746_item	3755834	et	0	main
nissi	doc_491521501746_item	3755835	et	0	main
khk	doc_491521501746_item	3755836	et	0	main
riisipere	doc_491521501746_item	3755837	et	0	main
v	doc_491521501746_item	3755838	et	0	main
madila	doc_491521501746_item	3755839	et	0	main
k	doc_491521501746_item	3755840	et	0	main
mall	doc_491521501746_item	3755841	et	0	main
hiiemäe	doc_491521501746_item	3755842	et	0	main
rein	doc_491521501746_item	3755843	et	0	main
leheroo	doc_491521501746_item	3755844	et	0	main
s	doc_491521501746_item	3755845	et	0	main
1949	doc_491521501746_item	3755846	et	0	main
a	doc_491521501746_item	3755847	et	0	main
1990	doc_491521501746_item	3755848	et	0	main
kividega	doc_491521501746_item	3755849	et	0	main
seoses	doc_491521501746_item	3755850	et	0	main
on	doc_491521501746_item	3755851	et	0	main
tihti	doc_491521501746_item	3755852	et	0	main
räägitud	doc_491521501746_item	3755853	et	0	main
ka	doc_491521501746_item	3755854	et	0	main
üleloomulikest	doc_491521501746_item	3755855	et	0	main
olenditest	doc_491521501746_item	3755856	et	0	main
või	doc_491521501746_item	3755857	et	0	main
vaimudest	doc_491521501746_item	3755858	et	0	main
keda	doc_491521501746_item	3755859	et	0	main
on	doc_491521501746_item	3755860	et	0	main
nähtud	doc_491521501746_item	3755861	et	0	main
kivi	doc_491521501746_item	3755862	et	0	main
peal	doc_491521501746_item	3755863	et	0	main
istumas	doc_491521501746_item	3755864	et	0	main
nagu	doc_491521501746_item	3755865	et	0	main
alltoodud	doc_491521501746_item	3755866	et	0	main
pärimuses	doc_491521501746_item	3755867	et	0	main
august	doc_491521501746_item	3755868	et	0	main
n	doc_491521501746_item	3755869	et	0	main
mustu	doc_491521501746_item	3755870	et	0	main
nõmme	doc_491521501746_item	3755871	et	0	main
ääres	doc_491521501746_item	3755872	et	0	main
anna	doc_491521501746_item	3755873	et	0	main
sauna	doc_491521501746_item	3755874	et	0	main
juures	doc_491521501746_item	3755875	et	0	main
mätliku	doc_491521501746_item	3755876	et	0	main
talu	doc_491521501746_item	3755877	et	0	main
on	doc_491521501746_item	3755878	et	0	main
ligemal	doc_491521501746_item	3755879	et	0	main
seal	doc_491521501746_item	3755880	et	0	main
seal	doc_491521501746_item	3755881	et	0	main
on	doc_491521501746_item	3755882	et	0	main
suur	doc_491521501746_item	3755883	et	0	main
kivi	doc_491521501746_item	3755884	et	0	main
sääl	doc_491521501746_item	3755885	et	0	main
otsas	doc_491521501746_item	3755886	et	0	main
oli	doc_491521501746_item	3755887	et	0	main
käind	doc_491521501746_item	3755888	et	0	main
ka	doc_491521501746_item	3755889	et	0	main
mõni	doc_491521501746_item	3755890	et	0	main
vaim	doc_491521501746_item	3755891	et	0	main
istumas	doc_491521501746_item	3755892	et	0	main
ööse	doc_491521501746_item	3755893	et	0	main
igaüks	doc_491521501746_item	3755894	et	0	main
pole	doc_491521501746_item	3755895	et	0	main
teda	doc_491521501746_item	3755896	et	0	main
näind	doc_491521501746_item	3755897	et	0	main
vahest	doc_491521501746_item	3755898	et	0	main
olnd	doc_491521501746_item	3755899	et	0	main
kotka	doc_491521501746_item	3755900	et	0	main
moodi	doc_491521501746_item	3755901	et	0	main
sääreluud	doc_491521501746_item	3755902	et	0	main
olnd	doc_491521501746_item	3755903	et	0	main
seal	doc_491521501746_item	3755904	et	0	main
maas	doc_491521501746_item	3755905	et	0	main
ajand	doc_491521501746_item	3755906	et	0	main
vahtu	doc_491521501746_item	3755907	et	0	main
välja	doc_491521501746_item	3755908	et	0	main
ja	doc_491521501746_item	3755909	et	0	main
karjund	doc_491521501746_item	3755910	et	0	main
umbluu	doc_491521501746_item	3755911	et	0	main
umbluu	doc_491521501746_item	3755912	et	0	main
mõni	doc_491521501746_item	3755913	et	0	main
kes	doc_491521501746_item	3755914	et	0	main
siis	doc_491521501746_item	3755915	et	0	main
aram	doc_491521501746_item	3755916	et	0	main
oli	doc_491521501746_item	3755917	et	0	main
arama	doc_491521501746_item	3755918	et	0	main
verega	doc_491521501746_item	3755919	et	0	main
oli	doc_491521501746_item	3755920	et	0	main
jooksu	doc_491521501746_item	3755921	et	0	main
pannud	doc_491521501746_item	3755922	et	0	main
teatud	doc_491521501746_item	3755923	et	0	main
nädalapäevadel	doc_491521501746_item	3755924	et	0	main
11-12	doc_491521501746_item	3755925	et	0	main
vahel	doc_491521501746_item	3755926	et	0	main
oli	doc_491521501746_item	3755927	et	0	main
kõige	doc_491521501746_item	3755928	et	0	main
rohkem	doc_491521501746_item	3755929	et	0	main
näinud	doc_491521501746_item	3755930	et	0	main
rkm	doc_491521501746_item	3755931	et	0	main
ii	doc_491521501746_item	3755932	et	0	main
435	doc_491521501746_item	3755933	et	0	main
151152	doc_491521501746_item	3755934	et	0	main
6	doc_491521501746_item	3755935	et	0	main
nissi	doc_491521501746_item	3755936	et	0	main
v	doc_491521501746_item	3755937	et	0	main
odolemma	doc_491521501746_item	3755938	et	0	main
k	doc_491521501746_item	3755939	et	0	main
jaanijüri	doc_491521501746_item	3755940	et	0	main
t	doc_491521501746_item	3755941	et	0	main
kernu	doc_491521501746_item	3755942	et	0	main
v	doc_491521501746_item	3755943	et	0	main
miilima	doc_491521501746_item	3755944	et	0	main
k	doc_491521501746_item	3755945	et	0	main
mare	doc_491521501746_item	3755946	et	0	main
janneste	doc_491521501746_item	3755947	et	0	main
aliide	doc_491521501746_item	3755948	et	0	main
niinemaa	doc_491521501746_item	3755949	et	0	main
s	doc_491521501746_item	3755950	et	0	main
magnus	doc_491521501746_item	3755951	et	0	main
s	doc_491521501746_item	3755952	et	0	main
1919	doc_491521501746_item	3755953	et	0	main
a	doc_491521501746_item	3755954	et	0	main
august	doc_491521501746_item	3755955	et	0	main
niinemaa	doc_491521501746_item	3755956	et	0	main
s	doc_491521501746_item	3755957	et	0	main
1912	doc_491521501746_item	3755958	et	0	main
a	doc_491521501746_item	3755959	et	0	main
liidia	doc_491521501746_item	3755960	et	0	main
metsjõe	doc_491521501746_item	3755961	et	0	main
s	doc_491521501746_item	3755962	et	0	main
1942	doc_491521501746_item	3755963	et	0	main
a	doc_491521501746_item	3755964	et	0	main
eelmiste	doc_491521501746_item	3755965	et	0	main
tütar	doc_491521501746_item	3755966	et	0	main
1990	doc_491521501746_item	3755967	et	0	main
mõned	doc_491521501746_item	3755968	et	0	main
pärimused	doc_491521501746_item	3755969	et	0	main
kividest	doc_491521501746_item	3755970	et	0	main
katuvad	doc_491521501746_item	3755971	et	0	main
rahvausundiliste	doc_491521501746_item	3755972	et	0	main
juttudega	doc_491521501746_item	3755973	et	0	main
peidetud	doc_491521501746_item	3755974	et	0	main
varandusest	doc_491521501746_item	3755975	et	0	main
kivi	doc_491521501746_item	3755976	et	0	main
esineb	doc_491521501746_item	3755977	et	0	main
mingi	doc_491521501746_item	3755978	et	0	main
märgina	doc_491521501746_item	3755979	et	0	main
mille	doc_491521501746_item	3755980	et	0	main
järgi	doc_491521501746_item	3755981	et	0	main
varandust	doc_491521501746_item	3755982	et	0	main
on	doc_491521501746_item	3755983	et	0	main
võimalik	doc_491521501746_item	3755984	et	0	main
leida	doc_491521501746_item	3755985	et	0	main
ühes	doc_491521501746_item	3755986	et	0	main
kohas	doc_491521501746_item	3755987	et	0	main
oli	doc_491521501746_item	3755988	et	0	main
kivi	doc_491521501746_item	3755989	et	0	main
õeldi	doc_491521501746_item	3755990	et	0	main
et	doc_491521501746_item	3755991	et	0	main
seal	doc_491521501746_item	3755992	et	0	main
all	doc_491521501746_item	3755993	et	0	main
on	doc_491521501746_item	3755994	et	0	main
ju	doc_491521501746_item	3755995	et	0	main
varandust	doc_491521501746_item	3755996	et	0	main
ja	doc_491521501746_item	3755997	et	0	main
meil	doc_491521501746_item	3755998	et	0	main
keegi	doc_491521501746_item	3755999	et	0	main
ei	doc_491521501746_item	3756000	et	0	main
uskunud	doc_491521501746_item	3756001	et	0	main
ja	doc_491521501746_item	3756002	et	0	main
meile	doc_491521501746_item	3756003	et	0	main
öeldi	doc_491521501746_item	3756004	et	0	main
et	doc_491521501746_item	3756005	et	0	main
kui	doc_491521501746_item	3756006	et	0	main
sa	doc_491521501746_item	3756007	et	0	main
ei	doc_491521501746_item	3756008	et	0	main
usu	doc_491521501746_item	3756009	et	0	main
siis	doc_491521501746_item	3756010	et	0	main
ei	doc_491521501746_item	3756011	et	0	main
leia	doc_491521501746_item	3756012	et	0	main
ka	doc_491521501746_item	3756013	et	0	main
rääkisid	doc_491521501746_item	3756014	et	0	main
küll	doc_491521501746_item	3756015	et	0	main
et	doc_491521501746_item	3756016	et	0	main
on	doc_491521501746_item	3756017	et	0	main
leitud	doc_491521501746_item	3756018	et	0	main
vanatoa	doc_491521501746_item	3756019	et	0	main
ees	doc_491521501746_item	3756020	et	0	main
pidi	doc_491521501746_item	3756021	et	0	main
olema	doc_491521501746_item	3756022	et	0	main
vana	doc_491521501746_item	3756023	et	0	main
rehetuba	doc_491521501746_item	3756024	et	0	main
oli	doc_491521501746_item	3756025	et	0	main
aga	doc_491521501746_item	3756026	et	0	main
onu	doc_491521501746_item	3756027	et	0	main
ei	doc_491521501746_item	3756028	et	0	main
lubanud	doc_491521501746_item	3756029	et	0	main
meile	doc_491521501746_item	3756030	et	0	main
kaevata	doc_491521501746_item	3756031	et	0	main
ka	doc_491521501746_item	3756032	et	0	main
rkm	doc_491521501746_item	3756033	et	0	main
ii	doc_491521501746_item	3756034	et	0	main
433	doc_491521501746_item	3756035	et	0	main
443	doc_491521501746_item	3756036	et	0	main
13	doc_491521501746_item	3756037	et	0	main
nissi	doc_491521501746_item	3756038	et	0	main
khk	doc_491521501746_item	3756039	et	0	main
ellamaa	doc_491521501746_item	3756040	et	0	main
k	doc_491521501746_item	3756041	et	0	main
anu	doc_491521501746_item	3756042	et	0	main
korb	doc_491521501746_item	3756043	et	0	main
natalja	doc_491521501746_item	3756044	et	0	main
rass	doc_491521501746_item	3756045	et	0	main
s	doc_491521501746_item	3756046	et	0	main
1893	doc_491521501746_item	3756047	et	0	main
a	doc_491521501746_item	3756048	et	0	main
1990	doc_491521501746_item	3756049	et	0	main
sooniste	doc_491521501746_item	3756050	et	0	main
kivikangur	doc_491521501746_item	3756051	et	0	main
kivivare	doc_491521501746_item	3756052	et	0	main
on	doc_491521501746_item	3756053	et	0	main
kas	doc_491521501746_item	3756054	et	0	main
üks	doc_491521501746_item	3756055	et	0	main
vana	doc_491521501746_item	3756056	et	0	main
lossi	doc_491521501746_item	3756057	et	0	main
või	doc_491521501746_item	3756058	et	0	main
mõisahoone	doc_491521501746_item	3756059	et	0	main
vana	doc_491521501746_item	3756060	et	0	main
metstukk	doc_491521501746_item	3756061	et	0	main
räägitakse	doc_491521501746_item	3756062	et	0	main
et	doc_491521501746_item	3756063	et	0	main
see	doc_491521501746_item	3756064	et	0	main
on	doc_491521501746_item	3756065	et	0	main
tasuja-aegne	doc_491521501746_item	3756066	et	0	main
ehitis	doc_491521501746_item	3756067	et	0	main
olnud	doc_491521501746_item	3756068	et	0	main
mõis	doc_491521501746_item	3756069	et	0	main
on	doc_491521501746_item	3756070	et	0	main
ikka	doc_491521501746_item	3756071	et	0	main
saanud	doc_491521501746_item	3756072	et	0	main
rkm	doc_491521501746_item	3756073	et	0	main
ii	doc_491521501746_item	3756074	et	0	main
435	doc_491521501746_item	3756075	et	0	main
54	doc_491521501746_item	3756076	et	0	main
1	doc_491521501746_item	3756077	et	0	main
nissi	doc_491521501746_item	3756078	et	0	main
turba	doc_491521501746_item	3756079	et	0	main
al	doc_491521501746_item	3756080	et	0	main
kullamaa	doc_491521501746_item	3756081	et	0	main
sooniste	doc_491521501746_item	3756082	et	0	main
v	doc_491521501746_item	3756083	et	0	main
karusmaa	doc_491521501746_item	3756084	et	0	main
k	doc_491521501746_item	3756085	et	0	main
vanaküla	doc_491521501746_item	3756086	et	0	main
talu	doc_491521501746_item	3756087	et	0	main
mare	doc_491521501746_item	3756088	et	0	main
janneste	doc_491521501746_item	3756089	et	0	main
ivo	doc_491521501746_item	3756090	et	0	main
koppelmaa	doc_491521501746_item	3756091	et	0	main
s	doc_491521501746_item	3756092	et	0	main
1933	doc_491521501746_item	3756093	et	0	main
a	doc_491521501746_item	3756094	et	0	main
mare	doc_491521501746_item	3756095	et	0	main
janneste	doc_491521501746_item	3756096	et	0	main
35	doc_491521501746_item	3756097	et	0	main
mäed	doc_491521501746_item	3756098	et	0	main
karupuhkamisemägi	doc_491521501746_item	3756099	et	0	main
on	doc_491521501746_item	3756100	et	0	main
siinsamas	doc_491521501746_item	3756101	et	0	main
ju	doc_491521501746_item	3756102	et	0	main
siis	doc_491521501746_item	3756103	et	0	main
siin	doc_491521501746_item	3756104	et	0	main
karud	doc_491521501746_item	3756105	et	0	main
käisid	doc_491521501746_item	3756106	et	0	main
puhkamas	doc_491521501746_item	3756107	et	0	main
soo	doc_491521501746_item	3756108	et	0	main
ümberringi	doc_491521501746_item	3756109	et	0	main
kus	doc_491521501746_item	3756110	et	0	main
need	doc_491521501746_item	3756111	et	0	main
karud	doc_491521501746_item	3756112	et	0	main
ikka	doc_491521501746_item	3756113	et	0	main
puhata	doc_491521501746_item	3756114	et	0	main
said	doc_491521501746_item	3756115	et	0	main
siis	doc_491521501746_item	3756116	et	0	main
kogusid	doc_491521501746_item	3756117	et	0	main
kokku	doc_491521501746_item	3756118	et	0	main
ega	doc_491521501746_item	3756119	et	0	main
ta	doc_491521501746_item	3756120	et	0	main
mägi	doc_491521501746_item	3756121	et	0	main
ei	doc_491521501746_item	3756122	et	0	main
ole	doc_491521501746_item	3756123	et	0	main
ega	doc_491521501746_item	3756124	et	0	main
midagi	doc_491521501746_item	3756125	et	0	main
niisama	doc_491521501746_item	3756126	et	0	main
vähe	doc_491521501746_item	3756127	et	0	main
kõrgem	doc_491521501746_item	3756128	et	0	main
küngas	doc_491521501746_item	3756129	et	0	main
praegu	doc_491521501746_item	3756130	et	0	main
ei	doc_491521501746_item	3756131	et	0	main
saa	doc_491521501746_item	3756132	et	0	main
arugi	doc_491521501746_item	3756133	et	0	main
rkm	doc_491521501746_item	3756134	et	0	main
ii	doc_491521501746_item	3756135	et	0	main
434	doc_491521501746_item	3756136	et	0	main
99	doc_491521501746_item	3756137	et	0	main
3	doc_491521501746_item	3756138	et	0	main
nissi	doc_491521501746_item	3756139	et	0	main
khk	doc_491521501746_item	3756140	et	0	main
riisipere	doc_491521501746_item	3756141	et	0	main
v	doc_491521501746_item	3756142	et	0	main
terjatu	doc_491521501746_item	3756143	et	0	main
k	doc_491521501746_item	3756144	et	0	main
lehetu	doc_491521501746_item	3756145	et	0	main
k	doc_491521501746_item	3756146	et	0	main
mall	doc_491521501746_item	3756147	et	0	main
hiiemäe	doc_491521501746_item	3756148	et	0	main
linda	doc_491521501746_item	3756149	et	0	main
linroos	doc_491521501746_item	3756150	et	0	main
s	doc_491521501746_item	3756151	et	0	main
1924	doc_491521501746_item	3756152	et	0	main
a	doc_491521501746_item	3756153	et	0	main
1990	doc_491521501746_item	3756154	et	0	main
siin	doc_491521501746_item	3756155	et	0	main
on	doc_491521501746_item	3756156	et	0	main
ühe	doc_491521501746_item	3756157	et	0	main
koha	doc_491521501746_item	3756158	et	0	main
nimi	doc_491521501746_item	3756159	et	0	main
isegi	doc_491521501746_item	3756160	et	0	main
ussimägi	doc_491521501746_item	3756161	et	0	main
ma	doc_491521501746_item	3756162	et	0	main
kui	doc_491521501746_item	3756163	et	0	main
laps	doc_491521501746_item	3756164	et	0	main
olin	doc_491521501746_item	3756165	et	0	main
siis	doc_491521501746_item	3756166	et	0	main
seal	doc_491521501746_item	3756167	et	0	main
oli	doc_491521501746_item	3756168	et	0	main
niisugune	doc_491521501746_item	3756169	et	0	main
auk	doc_491521501746_item	3756170	et	0	main
või	doc_491521501746_item	3756171	et	0	main
siis	doc_491521501746_item	3756172	et	0	main
kui	doc_491521501746_item	3756173	et	0	main
sügis	doc_491521501746_item	3756174	et	0	main
oli	doc_491521501746_item	3756175	et	0	main
siis	doc_491521501746_item	3756176	et	0	main
ussid	doc_491521501746_item	3756177	et	0	main
kogusid	doc_491521501746_item	3756178	et	0	main
kõik	doc_491521501746_item	3756179	et	0	main
sinna	doc_491521501746_item	3756180	et	0	main
magama	doc_491521501746_item	3756181	et	0	main
siis	doc_491521501746_item	3756182	et	0	main
poisid	doc_491521501746_item	3756183	et	0	main
ajasid	doc_491521501746_item	3756184	et	0	main
pudelise	doc_491521501746_item	3756185	et	0	main
neid	doc_491521501746_item	3756186	et	0	main
rkm	doc_491521501746_item	3756187	et	0	main
ii	doc_491521501746_item	3756188	et	0	main
434	doc_491521501746_item	3756189	et	0	main
110	doc_491521501746_item	3756190	et	0	main
45	doc_491521501746_item	3756191	et	0	main
nissi	doc_491521501746_item	3756192	et	0	main
khk	doc_491521501746_item	3756193	et	0	main
riisipere	doc_491521501746_item	3756194	et	0	main
v	doc_491521501746_item	3756195	et	0	main
terjatu	doc_491521501746_item	3756196	et	0	main
k	doc_491521501746_item	3756197	et	0	main
lehetu	doc_491521501746_item	3756198	et	0	main
k	doc_491521501746_item	3756199	et	0	main
mall	doc_491521501746_item	3756200	et	0	main
hiiemäe	doc_491521501746_item	3756201	et	0	main
linda	doc_491521501746_item	3756202	et	0	main
linroos	doc_491521501746_item	3756203	et	0	main
s	doc_491521501746_item	3756204	et	0	main
1924	doc_491521501746_item	3756205	et	0	main
a	doc_491521501746_item	3756206	et	0	main
1990	doc_491521501746_item	3756207	et	0	main
ellamaa	doc_491521501746_item	3756208	et	0	main
kõrtsumägi	doc_491521501746_item	3756209	et	0	main
on	doc_491521501746_item	3756210	et	0	main
saanud	doc_491521501746_item	3756211	et	0	main
oma	doc_491521501746_item	3756212	et	0	main
nime	doc_491521501746_item	3756213	et	0	main
seal	doc_491521501746_item	3756214	et	0	main
asunud	doc_491521501746_item	3756215	et	0	main
ellamaa	doc_491521501746_item	3756216	et	0	main
kõrtsi	doc_491521501746_item	3756217	et	0	main
järgi	doc_491521501746_item	3756218	et	0	main
rkm	doc_491521501746_item	3756219	et	0	main
ii	doc_491521501746_item	3756220	et	0	main
435	doc_491521501746_item	3756221	et	0	main
226	doc_491521501746_item	3756222	et	0	main
2	doc_491521501746_item	3756223	et	0	main
nissi	doc_491521501746_item	3756224	et	0	main
turba	doc_491521501746_item	3756225	et	0	main
al	doc_491521501746_item	3756226	et	0	main
ellamaa	doc_491521501746_item	3756227	et	0	main
k	doc_491521501746_item	3756228	et	0	main
kadi	doc_491521501746_item	3756229	et	0	main
sarv	doc_491521501746_item	3756230	et	0	main
feliks	doc_491521501746_item	3756231	et	0	main
päärson	doc_491521501746_item	3756232	et	0	main
s	doc_491521501746_item	3756233	et	0	main
1910	doc_491521501746_item	3756234	et	0	main
a	doc_491521501746_item	3756235	et	0	main
1990	doc_491521501746_item	3756236	et	0	main
siin	doc_491521501746_item	3756237	et	0	main
külas	doc_491521501746_item	3756238	et	0	main
on	doc_491521501746_item	3756239	et	0	main
üks	doc_491521501746_item	3756240	et	0	main
rahnimägi	doc_491521501746_item	3756241	et	0	main
selle	doc_491521501746_item	3756242	et	0	main
mäe	doc_491521501746_item	3756243	et	0	main
peal	doc_491521501746_item	3756244	et	0	main
kasvavad	doc_491521501746_item	3756245	et	0	main
pärnad	doc_491521501746_item	3756246	et	0	main
seal	doc_491521501746_item	3756247	et	0	main
olla	doc_491521501746_item	3756248	et	0	main
olnud	doc_491521501746_item	3756249	et	0	main
talukohad	doc_491521501746_item	3756250	et	0	main
veskimägi	doc_491521501746_item	3756251	et	0	main
on	doc_491521501746_item	3756252	et	0	main
saida	doc_491521501746_item	3756253	et	0	main
tee	doc_491521501746_item	3756254	et	0	main
ääres	doc_491521501746_item	3756255	et	0	main
seal	doc_491521501746_item	3756256	et	0	main
oli	doc_491521501746_item	3756257	et	0	main
veski	doc_491521501746_item	3756258	et	0	main
ka	doc_491521501746_item	3756259	et	0	main
rkm	doc_491521501746_item	3756260	et	0	main
ii	doc_491521501746_item	3756261	et	0	main
435	doc_491521501746_item	3756262	et	0	main
432433	doc_491521501746_item	3756263	et	0	main
3	doc_491521501746_item	3756264	et	0	main
nissi	doc_491521501746_item	3756265	et	0	main
pohla	doc_491521501746_item	3756266	et	0	main
k	doc_491521501746_item	3756267	et	0	main
männiku	doc_491521501746_item	3756268	et	0	main
t	doc_491521501746_item	3756269	et	0	main
hageri	doc_491521501746_item	3756270	et	0	main
khk	doc_491521501746_item	3756271	et	0	main
mõnuste	doc_491521501746_item	3756272	et	0	main
k	doc_491521501746_item	3756273	et	0	main
pikassalu	doc_491521501746_item	3756274	et	0	main
t	doc_491521501746_item	3756275	et	0	main
jaanika	doc_491521501746_item	3756276	et	0	main
oras	doc_491521501746_item	3756277	et	0	main
pauliine	doc_491521501746_item	3756278	et	0	main
müürisepp	doc_491521501746_item	3756279	et	0	main
s	doc_491521501746_item	3756280	et	0	main
1916	doc_491521501746_item	3756281	et	0	main
a	doc_491521501746_item	3756282	et	0	main
1990	doc_491521501746_item	3756283	et	0	main
kääpa	doc_491521501746_item	3756284	et	0	main
nimesid	doc_491521501746_item	3756285	et	0	main
on	doc_491521501746_item	3756286	et	0	main
siin	doc_491521501746_item	3756287	et	0	main
siin	doc_491521501746_item	3756288	et	0	main
üks	doc_491521501746_item	3756289	et	0	main
keabaste	doc_491521501746_item	3756290	et	0	main
mägi	doc_491521501746_item	3756291	et	0	main
seal	doc_491521501746_item	3756292	et	0	main
on	doc_491521501746_item	3756293	et	0	main
vist	doc_491521501746_item	3756294	et	0	main
vanad	doc_491521501746_item	3756295	et	0	main
matmispaigad	doc_491521501746_item	3756296	et	0	main
era	doc_491521501746_item	3756297	et	0	main
ii	doc_491521501746_item	3756298	et	0	main
27	doc_491521501746_item	3756299	et	0	main
266	doc_491521501746_item	3756300	et	0	main
52	doc_491521501746_item	3756301	et	0	main
nissi	doc_491521501746_item	3756302	et	0	main
khk	doc_491521501746_item	3756303	et	0	main
laitse	doc_491521501746_item	3756304	et	0	main
vld	doc_491521501746_item	3756305	et	0	main
kibuna	doc_491521501746_item	3756306	et	0	main
kl	doc_491521501746_item	3756307	et	0	main
kaasiku	doc_491521501746_item	3756308	et	0	main
talu	doc_491521501746_item	3756309	et	0	main
sündinud	doc_491521501746_item	3756310	et	0	main
riisipere	doc_491521501746_item	3756311	et	0	main
vallas	doc_491521501746_item	3756312	et	0	main
nurme	doc_491521501746_item	3756313	et	0	main
külas	doc_491521501746_item	3756314	et	0	main
r	doc_491521501746_item	3756315	et	0	main
põldmäe	doc_491521501746_item	3756316	et	0	main
tõnu	doc_491521501746_item	3756317	et	0	main
evald	doc_491521501746_item	3756318	et	0	main
66	doc_491521501746_item	3756319	et	0	main
a	doc_491521501746_item	3756320	et	0	main
1930	doc_491521501746_item	3756321	et	0	main
terjatu	doc_491521501746_item	3756322	et	0	main
külas	doc_491521501746_item	3756323	et	0	main
on	doc_491521501746_item	3756324	et	0	main
kääpamägi	doc_491521501746_item	3756325	et	0	main
tea	doc_491521501746_item	3756326	et	0	main
kas	doc_491521501746_item	3756327	et	0	main
seal	doc_491521501746_item	3756328	et	0	main
matust	doc_491521501746_item	3756329	et	0	main
on	doc_491521501746_item	3756330	et	0	main
olnud	doc_491521501746_item	3756331	et	0	main
aga	doc_491521501746_item	3756332	et	0	main
nimi	doc_491521501746_item	3756333	et	0	main
on	doc_491521501746_item	3756334	et	0	main
niisugune	doc_491521501746_item	3756335	et	0	main
soo	doc_491521501746_item	3756336	et	0	main
sees	doc_491521501746_item	3756337	et	0	main
oli	doc_491521501746_item	3756338	et	0	main
ja	doc_491521501746_item	3756339	et	0	main
männid	doc_491521501746_item	3756340	et	0	main
olnd	doc_491521501746_item	3756341	et	0	main
peal	doc_491521501746_item	3756342	et	0	main
rkm	doc_491521501746_item	3756343	et	0	main
ii	doc_491521501746_item	3756344	et	0	main
434	doc_491521501746_item	3756345	et	0	main
99	doc_491521501746_item	3756346	et	0	main
4	doc_491521501746_item	3756347	et	0	main
nissi	doc_491521501746_item	3756348	et	0	main
khk	doc_491521501746_item	3756349	et	0	main
riisipere	doc_491521501746_item	3756350	et	0	main
v	doc_491521501746_item	3756351	et	0	main
terjatu	doc_491521501746_item	3756352	et	0	main
k	doc_491521501746_item	3756353	et	0	main
lehetu	doc_491521501746_item	3756354	et	0	main
k	doc_491521501746_item	3756355	et	0	main
mall	doc_491521501746_item	3756356	et	0	main
hiiemäe	doc_491521501746_item	3756357	et	0	main
linda	doc_491521501746_item	3756358	et	0	main
linroos	doc_491521501746_item	3756359	et	0	main
s	doc_491521501746_item	3756360	et	0	main
1924	doc_491521501746_item	3756361	et	0	main
a	doc_491521501746_item	3756362	et	0	main
1990	doc_491521501746_item	3756363	et	0	main
meil	doc_491521501746_item	3756364	et	0	main
kroosu	doc_491521501746_item	3756365	et	0	main
rääkis	doc_491521501746_item	3756366	et	0	main
niisugust	doc_491521501746_item	3756367	et	0	main
juttu	doc_491521501746_item	3756368	et	0	main
siit	doc_491521501746_item	3756369	et	0	main
edasi	doc_491521501746_item	3756370	et	0	main
lähete	doc_491521501746_item	3756371	et	0	main
siis	doc_491521501746_item	3756372	et	0	main
on	doc_491521501746_item	3756373	et	0	main
ka	doc_491521501746_item	3756374	et	0	main
kaks	doc_491521501746_item	3756375	et	0	main
teeharu	doc_491521501746_item	3756376	et	0	main
parem	doc_491521501746_item	3756377	et	0	main
lähed	doc_491521501746_item	3756378	et	0	main
nurme	doc_491521501746_item	3756379	et	0	main
kus	doc_491521501746_item	3756380	et	0	main
te	doc_491521501746_item	3756381	et	0	main
tahate	doc_491521501746_item	3756382	et	0	main
minna	doc_491521501746_item	3756383	et	0	main
kus	doc_491521501746_item	3756384	et	0	main
on	doc_491521501746_item	3756385	et	0	main
inimesi	doc_491521501746_item	3756386	et	0	main
aga	doc_491521501746_item	3756387	et	0	main
teine	doc_491521501746_item	3756388	et	0	main
tee	doc_491521501746_item	3756389	et	0	main
läheb	doc_491521501746_item	3756390	et	0	main
pärnu	doc_491521501746_item	3756391	et	0	main
maantee	doc_491521501746_item	3756392	et	0	main
peale	doc_491521501746_item	3756393	et	0	main
välja	doc_491521501746_item	3756394	et	0	main
seal	doc_491521501746_item	3756395	et	0	main
on	doc_491521501746_item	3756396	et	0	main
pajaka	doc_491521501746_item	3756397	et	0	main
küla	doc_491521501746_item	3756398	et	0	main
siis	doc_491521501746_item	3756399	et	0	main
seal	doc_491521501746_item	3756400	et	0	main
tee	doc_491521501746_item	3756401	et	0	main
ääres	doc_491521501746_item	3756402	et	0	main
on	doc_491521501746_item	3756403	et	0	main
koerakingumägi	doc_491521501746_item	3756404	et	0	main
metsa	doc_491521501746_item	3756405	et	0	main
all	doc_491521501746_item	3756406	et	0	main
on	doc_491521501746_item	3756407	et	0	main
meie	doc_491521501746_item	3756408	et	0	main
vahtkonnas	doc_491521501746_item	3756409	et	0	main
see	doc_491521501746_item	3756410	et	0	main
seal	doc_491521501746_item	3756411	et	0	main
pidi	doc_491521501746_item	3756412	et	0	main
olema	doc_491521501746_item	3756413	et	0	main
kuskil	doc_491521501746_item	3756414	et	0	main
rahaauk	doc_491521501746_item	3756415	et	0	main
ja	doc_491521501746_item	3756416	et	0	main
iga	doc_491521501746_item	3756417	et	0	main
neljapäeva	doc_491521501746_item	3756418	et	0	main
öösel	doc_491521501746_item	3756419	et	0	main
pidi	doc_491521501746_item	3756420	et	0	main
seal	doc_491521501746_item	3756421	et	0	main
koer	doc_491521501746_item	3756422	et	0	main
uluma	doc_491521501746_item	3756423	et	0	main
rkm	doc_491521501746_item	3756424	et	0	main
ii	doc_491521501746_item	3756425	et	0	main
434	doc_491521501746_item	3756426	et	0	main
147148	doc_491521501746_item	3756427	et	0	main
27	doc_491521501746_item	3756428	et	0	main
nissi	doc_491521501746_item	3756429	et	0	main
khk	doc_491521501746_item	3756430	et	0	main
riisipere	doc_491521501746_item	3756431	et	0	main
v	doc_491521501746_item	3756432	et	0	main
nurme	doc_491521501746_item	3756433	et	0	main
k	doc_491521501746_item	3756434	et	0	main
mall	doc_491521501746_item	3756435	et	0	main
hiiemäe	doc_491521501746_item	3756436	et	0	main
marta	doc_491521501746_item	3756437	et	0	main
ehrpais	doc_491521501746_item	3756438	et	0	main
82	doc_491521501746_item	3756439	et	0	main
a	doc_491521501746_item	3756440	et	0	main
1990	doc_491521501746_item	3756441	et	0	main
härgemäe	doc_491521501746_item	3756442	et	0	main
nimi	doc_491521501746_item	3756443	et	0	main
tuleb	doc_491521501746_item	3756444	et	0	main
sellest	doc_491521501746_item	3756445	et	0	main
et	doc_491521501746_item	3756446	et	0	main
maalinna	doc_491521501746_item	3756447	et	0	main
ajal	doc_491521501746_item	3756448	et	0	main
karjatatud	doc_491521501746_item	3756449	et	0	main
seal	doc_491521501746_item	3756450	et	0	main
härgasid	doc_491521501746_item	3756451	et	0	main
rkm	doc_491521501746_item	3756452	et	0	main
ii	doc_491521501746_item	3756453	et	0	main
435	doc_491521501746_item	3756454	et	0	main
228	doc_491521501746_item	3756455	et	0	main
11	doc_491521501746_item	3756456	et	0	main
nissi	doc_491521501746_item	3756457	et	0	main
turba	doc_491521501746_item	3756458	et	0	main
al	doc_491521501746_item	3756459	et	0	main
ellamaa	doc_491521501746_item	3756460	et	0	main
k	doc_491521501746_item	3756461	et	0	main
kadi	doc_491521501746_item	3756462	et	0	main
sarv	doc_491521501746_item	3756463	et	0	main
feliks	doc_491521501746_item	3756464	et	0	main
päärson	doc_491521501746_item	3756465	et	0	main
s	doc_491521501746_item	3756466	et	0	main
1910	doc_491521501746_item	3756467	et	0	main
a	doc_491521501746_item	3756468	et	0	main
1990	doc_491521501746_item	3756469	et	0	main
kondimägi	doc_491521501746_item	3756470	et	0	main
sie	doc_491521501746_item	3756471	et	0	main
on	doc_491521501746_item	3756472	et	0	main
siit	doc_491521501746_item	3756473	et	0	main
munalaskme	doc_491521501746_item	3756474	et	0	main
tied	doc_491521501746_item	3756475	et	0	main
mööda	doc_491521501746_item	3756476	et	0	main
kuni	doc_491521501746_item	3756477	et	0	main
mets	doc_491521501746_item	3756478	et	0	main
hakkab	doc_491521501746_item	3756479	et	0	main
seal	doc_491521501746_item	3756480	et	0	main
on	doc_491521501746_item	3756481	et	0	main
männitukk	doc_491521501746_item	3756482	et	0	main
ja	doc_491521501746_item	3756483	et	0	main
liivaauk	doc_491521501746_item	3756484	et	0	main
liivamäe	doc_491521501746_item	3756485	et	0	main
talu	doc_491521501746_item	3756486	et	0	main
ja	doc_491521501746_item	3756487	et	0	main
kibuna	doc_491521501746_item	3756488	et	0	main
küla	doc_491521501746_item	3756489	et	0	main
vahel	doc_491521501746_item	3756490	et	0	main
ja	doc_491521501746_item	3756491	et	0	main
surnukonte	doc_491521501746_item	3756492	et	0	main
tuli	doc_491521501746_item	3756493	et	0	main
välja	doc_491521501746_item	3756494	et	0	main
kui	doc_491521501746_item	3756495	et	0	main
sealt	doc_491521501746_item	3756496	et	0	main
liiva	doc_491521501746_item	3756497	et	0	main
toodi	doc_491521501746_item	3756498	et	0	main
rkm	doc_491521501746_item	3756499	et	0	main
ii	doc_491521501746_item	3756500	et	0	main
435	doc_491521501746_item	3756501	et	0	main
497	doc_491521501746_item	3756502	et	0	main
7	doc_491521501746_item	3756503	et	0	main
nissi	doc_491521501746_item	3756504	et	0	main
kibuna	doc_491521501746_item	3756505	et	0	main
k	doc_491521501746_item	3756506	et	0	main
otsari	doc_491521501746_item	3756507	et	0	main
t	doc_491521501746_item	3756508	et	0	main
jaanika	doc_491521501746_item	3756509	et	0	main
oras	doc_491521501746_item	3756510	et	0	main
ants	doc_491521501746_item	3756511	et	0	main
järvlepp	doc_491521501746_item	3756512	et	0	main
s	doc_491521501746_item	3756513	et	0	main
28	doc_491521501746_item	3756514	et	0	main
dets	doc_491521501746_item	3756515	et	0	main
1904	doc_491521501746_item	3756516	et	0	main
a	doc_491521501746_item	3756517	et	0	main
1990	doc_491521501746_item	3756518	et	0	main
üks	doc_491521501746_item	3756519	et	0	main
linnamägi	doc_491521501746_item	3756520	et	0	main
pidi	doc_491521501746_item	3756521	et	0	main
siin	doc_491521501746_item	3756522	et	0	main
olema	doc_491521501746_item	3756523	et	0	main
lehetu	doc_491521501746_item	3756524	et	0	main
küla	doc_491521501746_item	3756525	et	0	main
jõe	doc_491521501746_item	3756526	et	0	main
ääres	doc_491521501746_item	3756527	et	0	main
ja	doc_491521501746_item	3756528	et	0	main
mina	doc_491521501746_item	3756529	et	0	main
kui	doc_491521501746_item	3756530	et	0	main
noorem	doc_491521501746_item	3756531	et	0	main
olin	doc_491521501746_item	3756532	et	0	main
siis	doc_491521501746_item	3756533	et	0	main
käisin	doc_491521501746_item	3756534	et	0	main
seal	doc_491521501746_item	3756535	et	0	main
linnamäele	doc_491521501746_item	3756536	et	0	main
pidi	doc_491521501746_item	3756537	et	0	main
varandust	doc_491521501746_item	3756538	et	0	main
olema	doc_491521501746_item	3756539	et	0	main
maetud	doc_491521501746_item	3756540	et	0	main
või	doc_491521501746_item	3756541	et	0	main
peidetud	doc_491521501746_item	3756542	et	0	main
rkm	doc_491521501746_item	3756543	et	0	main
ii	doc_491521501746_item	3756544	et	0	main
434	doc_491521501746_item	3756545	et	0	main
99100	doc_491521501746_item	3756546	et	0	main
5	doc_491521501746_item	3756547	et	0	main
nissi	doc_491521501746_item	3756548	et	0	main
khk	doc_491521501746_item	3756549	et	0	main
riisipere	doc_491521501746_item	3756550	et	0	main
v	doc_491521501746_item	3756551	et	0	main
terjatu	doc_491521501746_item	3756552	et	0	main
k	doc_491521501746_item	3756553	et	0	main
lehetu	doc_491521501746_item	3756554	et	0	main
k	doc_491521501746_item	3756555	et	0	main
mall	doc_491521501746_item	3756556	et	0	main
hiiemäe	doc_491521501746_item	3756557	et	0	main
linda	doc_491521501746_item	3756558	et	0	main
linroos	doc_491521501746_item	3756559	et	0	main
s	doc_491521501746_item	3756560	et	0	main
1924	doc_491521501746_item	3756561	et	0	main
a	doc_491521501746_item	3756562	et	0	main
1990	doc_491521501746_item	3756563	et	0	main
koerakingumägi	doc_491521501746_item	3756564	et	0	main
on	doc_491521501746_item	3756565	et	0	main
küll	doc_491521501746_item	3756566	et	0	main
ja	doc_491521501746_item	3756567	et	0	main
seal	doc_491521501746_item	3756568	et	0	main
on	doc_491521501746_item	3756569	et	0	main
allikas	doc_491521501746_item	3756570	et	0	main
ka	doc_491521501746_item	3756571	et	0	main
mingisugune	doc_491521501746_item	3756572	et	0	main
sooserv	doc_491521501746_item	3756573	et	0	main
on	doc_491521501746_item	3756574	et	0	main
ees	doc_491521501746_item	3756575	et	0	main
ja	doc_491521501746_item	3756576	et	0	main
siis	doc_491521501746_item	3756577	et	0	main
on	doc_491521501746_item	3756578	et	0	main
metsa	doc_491521501746_item	3756579	et	0	main
sees	doc_491521501746_item	3756580	et	0	main
pajaka	doc_491521501746_item	3756581	et	0	main
maantee	doc_491521501746_item	3756582	et	0	main
ääres	doc_491521501746_item	3756583	et	0	main
küngas	doc_491521501746_item	3756584	et	0	main
seal	doc_491521501746_item	3756585	et	0	main
pidi	doc_491521501746_item	3756586	et	0	main
varandus	doc_491521501746_item	3756587	et	0	main
olema	doc_491521501746_item	3756588	et	0	main
kuskil	doc_491521501746_item	3756589	et	0	main
rkm	doc_491521501746_item	3756590	et	0	main
ii	doc_491521501746_item	3756591	et	0	main
434	doc_491521501746_item	3756592	et	0	main
159	doc_491521501746_item	3756593	et	0	main
1	doc_491521501746_item	3756594	et	0	main
riisipere	doc_491521501746_item	3756595	et	0	main
v	doc_491521501746_item	3756596	et	0	main
nurme	doc_491521501746_item	3756597	et	0	main
k	doc_491521501746_item	3756598	et	0	main
lehtla	doc_491521501746_item	3756599	et	0	main
t	doc_491521501746_item	3756600	et	0	main
mall	doc_491521501746_item	3756601	et	0	main
hiiemäe	doc_491521501746_item	3756602	et	0	main
oskar	doc_491521501746_item	3756603	et	0	main
lehtme	doc_491521501746_item	3756604	et	0	main
76	doc_491521501746_item	3756605	et	0	main
a	doc_491521501746_item	3756606	et	0	main
1990	doc_491521501746_item	3756607	et	0	main
lubjaaugu	doc_491521501746_item	3756608	et	0	main
mägi	doc_491521501746_item	3756609	et	0	main
seal	doc_491521501746_item	3756610	et	0	main
põletati	doc_491521501746_item	3756611	et	0	main
vanasti	doc_491521501746_item	3756612	et	0	main
lupja	doc_491521501746_item	3756613	et	0	main
seal	doc_491521501746_item	3756614	et	0	main
olid	doc_491521501746_item	3756615	et	0	main
lubjaahjud	doc_491521501746_item	3756616	et	0	main
rkm	doc_491521501746_item	3756617	et	0	main
ii	doc_491521501746_item	3756618	et	0	main
435	doc_491521501746_item	3756619	et	0	main
336	doc_491521501746_item	3756620	et	0	main
4	doc_491521501746_item	3756621	et	0	main
nissi	doc_491521501746_item	3756622	et	0	main
turba	doc_491521501746_item	3756623	et	0	main
al	doc_491521501746_item	3756624	et	0	main
riisipere	doc_491521501746_item	3756625	et	0	main
mõis	doc_491521501746_item	3756626	et	0	main
kadi	doc_491521501746_item	3756627	et	0	main
sarv	doc_491521501746_item	3756628	et	0	main
mart	doc_491521501746_item	3756629	et	0	main
sinivee	doc_491521501746_item	3756630	et	0	main
s	doc_491521501746_item	3756631	et	0	main
1915	doc_491521501746_item	3756632	et	0	main
a	doc_491521501746_item	3756633	et	0	main
1990	doc_491521501746_item	3756634	et	0	main
neid	doc_491521501746_item	3756635	et	0	main
mägesid	doc_491521501746_item	3756636	et	0	main
on	doc_491521501746_item	3756637	et	0	main
old	doc_491521501746_item	3756638	et	0	main
igal	doc_491521501746_item	3756639	et	0	main
ühel	doc_491521501746_item	3756640	et	0	main
on	doc_491521501746_item	3756641	et	0	main
omad	doc_491521501746_item	3756642	et	0	main
nimed	doc_491521501746_item	3756643	et	0	main
siin	doc_491521501746_item	3756644	et	0	main
mägedemetsas	doc_491521501746_item	3756645	et	0	main
on	doc_491521501746_item	3756646	et	0	main
kerstu	doc_491521501746_item	3756647	et	0	main
mägi	doc_491521501746_item	3756648	et	0	main
miiu	doc_491521501746_item	3756649	et	0	main
mägi	doc_491521501746_item	3756650	et	0	main
ruuna	doc_491521501746_item	3756651	et	0	main
mägi	doc_491521501746_item	3756652	et	0	main
seal	doc_491521501746_item	3756653	et	0	main
oli	doc_491521501746_item	3756654	et	0	main
suur	doc_491521501746_item	3756655	et	0	main
männimets	doc_491521501746_item	3756656	et	0	main
lao	doc_491521501746_item	3756657	et	0	main
raba	doc_491521501746_item	3756658	et	0	main
suured	doc_491521501746_item	3756659	et	0	main
lau-augud	doc_491521501746_item	3756660	et	0	main
peavad	doc_491521501746_item	3756661	et	0	main
olema	doc_491521501746_item	3756662	et	0	main
põhja	doc_491521501746_item	3756663	et	0	main
ei	doc_491521501746_item	3756664	et	0	main
pea	doc_491521501746_item	3756665	et	0	main
all	doc_491521501746_item	3756666	et	0	main
olema	doc_491521501746_item	3756667	et	0	main
sel	doc_491521501746_item	3756668	et	0	main
peavad	doc_491521501746_item	3756669	et	0	main
kolme	doc_491521501746_item	3756670	et	0	main
saksa	doc_491521501746_item	3756671	et	0	main
moad	doc_491521501746_item	3756672	et	0	main
olema	doc_491521501746_item	3756673	et	0	main
kodila	doc_491521501746_item	3756674	et	0	main
ja	doc_491521501746_item	3756675	et	0	main
põlli	doc_491521501746_item	3756676	et	0	main
ja	doc_491521501746_item	3756677	et	0	main
alu	doc_491521501746_item	3756678	et	0	main
era	doc_491521501746_item	3756679	et	0	main
ii	doc_491521501746_item	3756680	et	0	main
77	doc_491521501746_item	3756681	et	0	main
544	doc_491521501746_item	3756682	et	0	main
39	doc_491521501746_item	3756683	et	0	main
nissi	doc_491521501746_item	3756684	et	0	main
khk	doc_491521501746_item	3756685	et	0	main
varbola	doc_491521501746_item	3756686	et	0	main
v	doc_491521501746_item	3756687	et	0	main
põlli	doc_491521501746_item	3756688	et	0	main
k	doc_491521501746_item	3756689	et	0	main
hageri	doc_491521501746_item	3756690	et	0	main
kernu	doc_491521501746_item	3756691	et	0	main
haiba	doc_491521501746_item	3756692	et	0	main
r	doc_491521501746_item	3756693	et	0	main
põldmäe	doc_491521501746_item	3756694	et	0	main
ants	doc_491521501746_item	3756695	et	0	main
toomberg	doc_491521501746_item	3756696	et	0	main
84	doc_491521501746_item	3756697	et	0	main
a	doc_491521501746_item	3756698	et	0	main
1934	doc_491521501746_item	3756699	et	0	main
4	doc_491521501746_item	3756700	et	0	main
peatükk	doc_491521501746_item	3756701	et	0	main
kultuurilised	doc_491521501746_item	3756702	et	0	main
objektid	doc_491521501746_item	3756703	et	0	main
41	doc_491521501746_item	3756704	et	0	main
nissi	doc_491521501746_item	3756705	et	0	main
kirik	doc_491521501746_item	3756706	et	0	main
nissi	doc_491521501746_item	3756707	et	0	main
kihelkonnas	doc_491521501746_item	3756708	et	0	main
on	doc_491521501746_item	3756709	et	0	main
kaks	doc_491521501746_item	3756710	et	0	main
objekti	doc_491521501746_item	3756711	et	0	main
mis	doc_491521501746_item	3756712	et	0	main
on	doc_491521501746_item	3756713	et	0	main
kõige	doc_491521501746_item	3756714	et	0	main
sagedamini	doc_491521501746_item	3756715	et	0	main
olnud	doc_491521501746_item	3756716	et	0	main
pärimuste	doc_491521501746_item	3756717	et	0	main
aineks	doc_491521501746_item	3756718	et	0	main
see	doc_491521501746_item	3756719	et	0	main
on	doc_491521501746_item	3756720	et	0	main
nissi	doc_491521501746_item	3756721	et	0	main
kirik	doc_491521501746_item	3756722	et	0	main
ja	doc_491521501746_item	3756723	et	0	main
riisipere	doc_491521501746_item	3756724	et	0	main
mõis	doc_491521501746_item	3756725	et	0	main
nissi	doc_491521501746_item	3756726	et	0	main
kirikust	doc_491521501746_item	3756727	et	0	main
on	doc_491521501746_item	3756728	et	0	main
räägitud	doc_491521501746_item	3756729	et	0	main
nii	doc_491521501746_item	3756730	et	0	main
ehitamislugusid	doc_491521501746_item	3756731	et	0	main
kui	doc_491521501746_item	3756732	et	0	main
ka	doc_491521501746_item	3756733	et	0	main
jutte	doc_491521501746_item	3756734	et	0	main
mis	doc_491521501746_item	3756735	et	0	main
on	doc_491521501746_item	3756736	et	0	main
seotud	doc_491521501746_item	3756737	et	0	main
nt	doc_491521501746_item	3756738	et	0	main
ebaloomulike	doc_491521501746_item	3756739	et	0	main
nähtuste	doc_491521501746_item	3756740	et	0	main
või	doc_491521501746_item	3756741	et	0	main
olenditega	doc_491521501746_item	3756742	et	0	main
minu	doc_491521501746_item	3756743	et	0	main
vanaema	doc_491521501746_item	3756744	et	0	main
oli	doc_491521501746_item	3756745	et	0	main
nissi	doc_491521501746_item	3756746	et	0	main
kirikule	doc_491521501746_item	3756747	et	0	main
neid	doc_491521501746_item	3756748	et	0	main
kiva	doc_491521501746_item	3756749	et	0	main
vedand	doc_491521501746_item	3756750	et	0	main
enne	doc_491521501746_item	3756751	et	0	main
oli	doc_491521501746_item	3756752	et	0	main
seal	doc_491521501746_item	3756753	et	0	main
puukirik	doc_491521501746_item	3756754	et	0	main
kernult	doc_491521501746_item	3756755	et	0	main
või	doc_491521501746_item	3756756	et	0	main
kus	doc_491521501746_item	3756757	et	0	main
pagan	doc_491521501746_item	3756758	et	0	main
nad	doc_491521501746_item	3756759	et	0	main
neid	doc_491521501746_item	3756760	et	0	main
kiva	doc_491521501746_item	3756761	et	0	main
vedasid	doc_491521501746_item	3756762	et	0	main
sinna	doc_491521501746_item	3756763	et	0	main
ligemalt	doc_491521501746_item	3756764	et	0	main
paemurdu	doc_491521501746_item	3756765	et	0	main
ei	doc_491521501746_item	3756766	et	0	main
old	doc_491521501746_item	3756767	et	0	main
käijad	doc_491521501746_item	3756768	et	0	main
olid	doc_491521501746_item	3756769	et	0	main
magama	doc_491521501746_item	3756770	et	0	main
jäänd	doc_491521501746_item	3756771	et	0	main
sinna	doc_491521501746_item	3756772	et	0	main
ja	doc_491521501746_item	3756773	et	0	main
sellega	doc_491521501746_item	3756774	et	0	main
siis	doc_491521501746_item	3756775	et	0	main
oli	doc_491521501746_item	3756776	et	0	main
kiriku	doc_491521501746_item	3756777	et	0	main
koht	doc_491521501746_item	3756778	et	0	main
ära	doc_491521501746_item	3756779	et	0	main
määratud	doc_491521501746_item	3756780	et	0	main
senna	doc_491521501746_item	3756781	et	0	main
küll	doc_491521501746_item	3756782	et	0	main
see	doc_491521501746_item	3756783	et	0	main
kirik	doc_491521501746_item	3756784	et	0	main
ikka	doc_491521501746_item	3756785	et	0	main
vanem	doc_491521501746_item	3756786	et	0	main
on	doc_491521501746_item	3756787	et	0	main
aga	doc_491521501746_item	3756788	et	0	main
ei	doc_491521501746_item	3756789	et	0	main
tea	doc_491521501746_item	3756790	et	0	main
midagi	doc_491521501746_item	3756791	et	0	main
ema	doc_491521501746_item	3756792	et	0	main
oleks	doc_491521501746_item	3756793	et	0	main
ka	doc_491521501746_item	3756794	et	0	main
juba	doc_491521501746_item	3756795	et	0	main
üle	doc_491521501746_item	3756796	et	0	main
saja	doc_491521501746_item	3756797	et	0	main
aasta	doc_491521501746_item	3756798	et	0	main
juba	doc_491521501746_item	3756799	et	0	main
ja	doc_491521501746_item	3756800	et	0	main
emaema	doc_491521501746_item	3756801	et	0	main
old	doc_491521501746_item	3756802	et	0	main
ikka	doc_491521501746_item	3756803	et	0	main
neiu	doc_491521501746_item	3756804	et	0	main
veel	doc_491521501746_item	3756805	et	0	main
kiu	doc_491521501746_item	3756806	et	0	main
neid	doc_491521501746_item	3756807	et	0	main
kive	doc_491521501746_item	3756808	et	0	main
vedand	doc_491521501746_item	3756809	et	0	main
rkm	doc_491521501746_item	3756810	et	0	main
ii	doc_491521501746_item	3756811	et	0	main
434	doc_491521501746_item	3756812	et	0	main
118	doc_491521501746_item	3756813	et	0	main
1	doc_491521501746_item	3756814	et	0	main
nissi	doc_491521501746_item	3756815	et	0	main
khk	doc_491521501746_item	3756816	et	0	main
riisipere	doc_491521501746_item	3756817	et	0	main
v	doc_491521501746_item	3756818	et	0	main
nurme	doc_491521501746_item	3756819	et	0	main
k	doc_491521501746_item	3756820	et	0	main
lehetu	doc_491521501746_item	3756821	et	0	main
k	doc_491521501746_item	3756822	et	0	main
mall	doc_491521501746_item	3756823	et	0	main
hiiemäe	doc_491521501746_item	3756824	et	0	main
august	doc_491521501746_item	3756825	et	0	main
lehtme	doc_491521501746_item	3756826	et	0	main
s	doc_491521501746_item	3756827	et	0	main
1919	doc_491521501746_item	3756828	et	0	main
a	doc_491521501746_item	3756829	et	0	main
1990	doc_491521501746_item	3756830	et	0	main
nissis	doc_491521501746_item	3756831	et	0	main
old	doc_491521501746_item	3756832	et	0	main
enne	doc_491521501746_item	3756833	et	0	main
puukabel	doc_491521501746_item	3756834	et	0	main
üks	doc_491521501746_item	3756835	et	0	main
inime	doc_491521501746_item	3756836	et	0	main
old	doc_491521501746_item	3756837	et	0	main
enne	doc_491521501746_item	3756838	et	0	main
raskeste	doc_491521501746_item	3756839	et	0	main
pattu	doc_491521501746_item	3756840	et	0	main
teind	doc_491521501746_item	3756841	et	0	main
old	doc_491521501746_item	3756842	et	0	main
vangi	doc_491521501746_item	3756843	et	0	main
mõistetud	doc_491521501746_item	3756844	et	0	main
see	doc_491521501746_item	3756845	et	0	main
old	doc_491521501746_item	3756846	et	0	main
riisipere	doc_491521501746_item	3756847	et	0	main
ärra	doc_491521501746_item	3756848	et	0	main
poeg	doc_491521501746_item	3756849	et	0	main
ta	doc_491521501746_item	3756850	et	0	main
on	doc_491521501746_item	3756851	et	0	main
seal	doc_491521501746_item	3756852	et	0	main
kloostres	doc_491521501746_item	3756853	et	0	main
käind	doc_491521501746_item	3756854	et	0	main
palund	doc_491521501746_item	3756855	et	0	main
jumalat	doc_491521501746_item	3756856	et	0	main
et	doc_491521501746_item	3756857	et	0	main
peaks	doc_491521501746_item	3756858	et	0	main
ta	doc_491521501746_item	3756859	et	0	main
lahti	doc_491521501746_item	3756860	et	0	main
jaama	doc_491521501746_item	3756861	et	0	main
ehitaks	doc_491521501746_item	3756862	et	0	main
ühe	doc_491521501746_item	3756863	et	0	main
kiriku	doc_491521501746_item	3756864	et	0	main
ta	doc_491521501746_item	3756865	et	0	main
ongi	doc_491521501746_item	3756866	et	0	main
lahti	doc_491521501746_item	3756867	et	0	main
pääsend	doc_491521501746_item	3756868	et	0	main
ükskord	doc_491521501746_item	3756869	et	0	main
ja	doc_491521501746_item	3756870	et	0	main
ehitand	doc_491521501746_item	3756871	et	0	main
senna	doc_491521501746_item	3756872	et	0	main
ühe	doc_491521501746_item	3756873	et	0	main
puukabeli	doc_491521501746_item	3756874	et	0	main
edaspidi	doc_491521501746_item	3756875	et	0	main
ta	doc_491521501746_item	3756876	et	0	main
old	doc_491521501746_item	3756877	et	0	main
vana	doc_491521501746_item	3756878	et	0	main
mees	doc_491521501746_item	3756879	et	0	main
taht	doc_491521501746_item	3756880	et	0	main
terve	doc_491521501746_item	3756881	et	0	main
kihelkonna	doc_491521501746_item	3756882	et	0	main
asutada	doc_491521501746_item	3756883	et	0	main
siis	doc_491521501746_item	3756884	et	0	main
on	doc_491521501746_item	3756885	et	0	main
võetud	doc_491521501746_item	3756886	et	0	main
teistest	doc_491521501746_item	3756887	et	0	main
kihelkondadest	doc_491521501746_item	3756888	et	0	main
igalt	doc_491521501746_item	3756889	et	0	main
ühelt	doc_491521501746_item	3756890	et	0	main
natuke	doc_491521501746_item	3756891	et	0	main
akatud	doc_491521501746_item	3756892	et	0	main
uut	doc_491521501746_item	3756893	et	0	main
kirikud	doc_491521501746_item	3756894	et	0	main
tegema	doc_491521501746_item	3756895	et	0	main
minu	doc_491521501746_item	3756896	et	0	main
ajal	doc_491521501746_item	3756897	et	0	main
tehti	doc_491521501746_item	3756898	et	0	main
jälle	doc_491521501746_item	3756899	et	0	main
uut	doc_491521501746_item	3756900	et	0	main
kirikud	doc_491521501746_item	3756901	et	0	main
nüid	doc_491521501746_item	3756902	et	0	main
on	doc_491521501746_item	3756903	et	0	main
kuuskümmend	doc_491521501746_item	3756904	et	0	main
aastat	doc_491521501746_item	3756905	et	0	main
vana	doc_491521501746_item	3756906	et	0	main
era	doc_491521501746_item	3756907	et	0	main
ii	doc_491521501746_item	3756908	et	0	main
77	doc_491521501746_item	3756909	et	0	main
461462	doc_491521501746_item	3756910	et	0	main
102	doc_491521501746_item	3756911	et	0	main
hageri	doc_491521501746_item	3756912	et	0	main
khk	doc_491521501746_item	3756913	et	0	main
v	doc_491521501746_item	3756914	et	0	main
ja	doc_491521501746_item	3756915	et	0	main
vndk	doc_491521501746_item	3756916	et	0	main
nissi	doc_491521501746_item	3756917	et	0	main
khk	doc_491521501746_item	3756918	et	0	main
varbola	doc_491521501746_item	3756919	et	0	main
v	doc_491521501746_item	3756920	et	0	main
põlli	doc_491521501746_item	3756921	et	0	main
k	doc_491521501746_item	3756922	et	0	main
r	doc_491521501746_item	3756923	et	0	main
põldmäe	doc_491521501746_item	3756924	et	0	main
jaagup	doc_491521501746_item	3756925	et	0	main
jäämann	doc_491521501746_item	3756926	et	0	main
70	doc_491521501746_item	3756927	et	0	main
a	doc_491521501746_item	3756928	et	0	main
1934	doc_491521501746_item	3756929	et	0	main
kui	doc_491521501746_item	3756930	et	0	main
uut	doc_491521501746_item	3756931	et	0	main
kirikut	doc_491521501746_item	3756932	et	0	main
tehti	doc_491521501746_item	3756933	et	0	main
see	doc_491521501746_item	3756934	et	0	main
on	doc_491521501746_item	3756935	et	0	main
üle	doc_491521501746_item	3756936	et	0	main
saja	doc_491521501746_item	3756937	et	0	main
aasta	doc_491521501746_item	3756938	et	0	main
nüüd	doc_491521501746_item	3756939	et	0	main
vana	doc_491521501746_item	3756940	et	0	main
siis	doc_491521501746_item	3756941	et	0	main
minu	doc_491521501746_item	3756942	et	0	main
vanaisa	doc_491521501746_item	3756943	et	0	main
oli	doc_491521501746_item	3756944	et	0	main
ka	doc_491521501746_item	3756945	et	0	main
teed	doc_491521501746_item	3756946	et	0	main
tegemas	doc_491521501746_item	3756947	et	0	main
ja	doc_491521501746_item	3756948	et	0	main
siis	doc_491521501746_item	3756949	et	0	main
vanemad	doc_491521501746_item	3756950	et	0	main
mehed	doc_491521501746_item	3756951	et	0	main
olid	doc_491521501746_item	3756952	et	0	main
rääkinud	doc_491521501746_item	3756953	et	0	main
et	doc_491521501746_item	3756954	et	0	main
need	doc_491521501746_item	3756955	et	0	main
kondid	doc_491521501746_item	3756956	et	0	main
olid	doc_491521501746_item	3756957	et	0	main
koledat	doc_491521501746_item	3756958	et	0	main
häält	doc_491521501746_item	3756959	et	0	main
teinud	doc_491521501746_item	3756960	et	0	main
mis	doc_491521501746_item	3756961	et	0	main
seal	doc_491521501746_item	3756962	et	0	main
kiriku	doc_491521501746_item	3756963	et	0	main
ehitamisega	doc_491521501746_item	3756964	et	0	main
välja	doc_491521501746_item	3756965	et	0	main
tulid	doc_491521501746_item	3756966	et	0	main
rkm	doc_491521501746_item	3756967	et	0	main
ii	doc_491521501746_item	3756968	et	0	main
434	doc_491521501746_item	3756969	et	0	main
304305	doc_491521501746_item	3756970	et	0	main
1	doc_491521501746_item	3756971	et	0	main
nissi	doc_491521501746_item	3756972	et	0	main
khk	doc_491521501746_item	3756973	et	0	main
riisipere	doc_491521501746_item	3756974	et	0	main
v	doc_491521501746_item	3756975	et	0	main
maidla	doc_491521501746_item	3756976	et	0	main
k	doc_491521501746_item	3756977	et	0	main
mall	doc_491521501746_item	3756978	et	0	main
hiiemäe	doc_491521501746_item	3756979	et	0	main
rein	doc_491521501746_item	3756980	et	0	main
leheroo	doc_491521501746_item	3756981	et	0	main
s	doc_491521501746_item	3756982	et	0	main
1949	doc_491521501746_item	3756983	et	0	main
a	doc_491521501746_item	3756984	et	0	main
1990	doc_491521501746_item	3756985	et	0	main
nissi	doc_491521501746_item	3756986	et	0	main
kirik	doc_491521501746_item	3756987	et	0	main
on	doc_491521501746_item	3756988	et	0	main
mõni	doc_491521501746_item	3756989	et	0	main
räägib	doc_491521501746_item	3756990	et	0	main
niimoodi	doc_491521501746_item	3756991	et	0	main
et	doc_491521501746_item	3756992	et	0	main
seal	doc_491521501746_item	3756993	et	0	main
on	doc_491521501746_item	3756994	et	0	main
kasvanud	doc_491521501746_item	3756995	et	0	main
palkimets	doc_491521501746_item	3756996	et	0	main
saksa	doc_491521501746_item	3756997	et	0	main
keeles	doc_491521501746_item	3756998	et	0	main
nüssen	doc_491521501746_item	3756999	et	0	main
rkm	doc_491521501746_item	3757000	et	0	main
ii	doc_491521501746_item	3757001	et	0	main
434	doc_491521501746_item	3757002	et	0	main
141	doc_491521501746_item	3757003	et	0	main
10	doc_491521501746_item	3757004	et	0	main
nissi	doc_491521501746_item	3757005	et	0	main
khk	doc_491521501746_item	3757006	et	0	main
riisipere	doc_491521501746_item	3757007	et	0	main
v	doc_491521501746_item	3757008	et	0	main
nurme	doc_491521501746_item	3757009	et	0	main
k	doc_491521501746_item	3757010	et	0	main
mall	doc_491521501746_item	3757011	et	0	main
hiiemäe	doc_491521501746_item	3757012	et	0	main
marta	doc_491521501746_item	3757013	et	0	main
ehrpais	doc_491521501746_item	3757014	et	0	main
82	doc_491521501746_item	3757015	et	0	main
a	doc_491521501746_item	3757016	et	0	main
1990	doc_491521501746_item	3757017	et	0	main
nissi	doc_491521501746_item	3757018	et	0	main
kiriku	doc_491521501746_item	3757019	et	0	main
alune	doc_491521501746_item	3757020	et	0	main
oli	doc_491521501746_item	3757021	et	0	main
kõik	doc_491521501746_item	3757022	et	0	main
surnuluid	doc_491521501746_item	3757023	et	0	main
täis	doc_491521501746_item	3757024	et	0	main
olnud	doc_491521501746_item	3757025	et	0	main
ja	doc_491521501746_item	3757026	et	0	main
need	doc_491521501746_item	3757027	et	0	main
olid	doc_491521501746_item	3757028	et	0	main
siis	doc_491521501746_item	3757029	et	0	main
välja	doc_491521501746_item	3757030	et	0	main
võetud	doc_491521501746_item	3757031	et	0	main
ja	doc_491521501746_item	3757032	et	0	main
kiriku	doc_491521501746_item	3757033	et	0	main
ette	doc_491521501746_item	3757034	et	0	main
maha	doc_491521501746_item	3757035	et	0	main
maetud	doc_491521501746_item	3757036	et	0	main
kabelis	doc_491521501746_item	3757037	et	0	main
olid	doc_491521501746_item	3757038	et	0	main
balsameerutud	doc_491521501746_item	3757039	et	0	main
surnud	doc_491521501746_item	3757040	et	0	main
seal	doc_491521501746_item	3757041	et	0	main
siis	doc_491521501746_item	3757042	et	0	main
oli	doc_491521501746_item	3757043	et	0	main
neid	doc_491521501746_item	3757044	et	0	main
vanaaegseid	doc_491521501746_item	3757045	et	0	main
pärgasi	doc_491521501746_item	3757046	et	0	main
kõik	doc_491521501746_item	3757047	et	0	main
seinad	doc_491521501746_item	3757048	et	0	main
täis	doc_491521501746_item	3757049	et	0	main
ja	doc_491521501746_item	3757050	et	0	main
naised	doc_491521501746_item	3757051	et	0	main
olid	doc_491521501746_item	3757052	et	0	main
sealt	doc_491521501746_item	3757053	et	0	main
küljest	doc_491521501746_item	3757054	et	0	main
käind	doc_491521501746_item	3757055	et	0	main
siidilintisid	doc_491521501746_item	3757056	et	0	main
võtmas	doc_491521501746_item	3757057	et	0	main
oma	doc_491521501746_item	3757058	et	0	main
tütardele	doc_491521501746_item	3757059	et	0	main
pähe	doc_491521501746_item	3757060	et	0	main
rkm	doc_491521501746_item	3757061	et	0	main
ii	doc_491521501746_item	3757062	et	0	main
434	doc_491521501746_item	3757063	et	0	main
179	doc_491521501746_item	3757064	et	0	main
29	doc_491521501746_item	3757065	et	0	main
nissi	doc_491521501746_item	3757066	et	0	main
khk	doc_491521501746_item	3757067	et	0	main
varbola	doc_491521501746_item	3757068	et	0	main
v	doc_491521501746_item	3757069	et	0	main
jutapere	doc_491521501746_item	3757070	et	0	main
e	doc_491521501746_item	3757071	et	0	main
pajaka	doc_491521501746_item	3757072	et	0	main
k	doc_491521501746_item	3757073	et	0	main
nurme	doc_491521501746_item	3757074	et	0	main
k	doc_491521501746_item	3757075	et	0	main
mall	doc_491521501746_item	3757076	et	0	main
hiiemäe	doc_491521501746_item	3757077	et	0	main
hilda	doc_491521501746_item	3757078	et	0	main
leismann	doc_491521501746_item	3757079	et	0	main
s	doc_491521501746_item	3757080	et	0	main
ehrpais	doc_491521501746_item	3757081	et	0	main
81	doc_491521501746_item	3757082	et	0	main
a	doc_491521501746_item	3757083	et	0	main
1990	doc_491521501746_item	3757084	et	0	main
kui	doc_491521501746_item	3757085	et	0	main
nissi	doc_491521501746_item	3757086	et	0	main
kirikud	doc_491521501746_item	3757087	et	0	main
oli	doc_491521501746_item	3757088	et	0	main
laadatud	doc_491521501746_item	3757089	et	0	main
ää	doc_491521501746_item	3757090	et	0	main
siis	doc_491521501746_item	3757091	et	0	main
olid	doc_491521501746_item	3757092	et	0	main
vanad	doc_491521501746_item	3757093	et	0	main
kirjad	doc_491521501746_item	3757094	et	0	main
müüride	doc_491521501746_item	3757095	et	0	main
sees	doc_491521501746_item	3757096	et	0	main
üks	doc_491521501746_item	3757097	et	0	main
lollakas	doc_491521501746_item	3757098	et	0	main
russvere	doc_491521501746_item	3757099	et	0	main
mees	doc_491521501746_item	3757100	et	0	main
leind	doc_491521501746_item	3757101	et	0	main
selle	doc_491521501746_item	3757102	et	0	main
kasti	doc_491521501746_item	3757103	et	0	main
ta	doc_491521501746_item	3757104	et	0	main
leidis	doc_491521501746_item	3757105	et	0	main
kirikuärra	doc_491521501746_item	3757106	et	0	main
oli	doc_491521501746_item	3757107	et	0	main
ää	doc_491521501746_item	3757108	et	0	main
viind	doc_491521501746_item	3757109	et	0	main
era	doc_491521501746_item	3757110	et	0	main
ii	doc_491521501746_item	3757111	et	0	main
77	doc_491521501746_item	3757112	et	0	main
525	doc_491521501746_item	3757113	et	0	main
5	doc_491521501746_item	3757114	et	0	main
nissi	doc_491521501746_item	3757115	et	0	main
khk	doc_491521501746_item	3757116	et	0	main
varbola	doc_491521501746_item	3757117	et	0	main
v	doc_491521501746_item	3757118	et	0	main
põlli	doc_491521501746_item	3757119	et	0	main
k	doc_491521501746_item	3757120	et	0	main
hageri	doc_491521501746_item	3757121	et	0	main
kernu	doc_491521501746_item	3757122	et	0	main
haiba	doc_491521501746_item	3757123	et	0	main
r	doc_491521501746_item	3757124	et	0	main
põldmäe	doc_491521501746_item	3757125	et	0	main
ants	doc_491521501746_item	3757126	et	0	main
toomberg	doc_491521501746_item	3757127	et	0	main
84	doc_491521501746_item	3757128	et	0	main
a	doc_491521501746_item	3757129	et	0	main
1934	doc_491521501746_item	3757130	et	0	main
meid	doc_491521501746_item	3757131	et	0	main
oli	doc_491521501746_item	3757132	et	0	main
seitse	doc_491521501746_item	3757133	et	0	main
venda	doc_491521501746_item	3757134	et	0	main
ja	doc_491521501746_item	3757135	et	0	main
mina	doc_491521501746_item	3757136	et	0	main
olin	doc_491521501746_item	3757137	et	0	main
kaheksas	doc_491521501746_item	3757138	et	0	main
läksime	doc_491521501746_item	3757139	et	0	main
nissi	doc_491521501746_item	3757140	et	0	main
kirikusse	doc_491521501746_item	3757141	et	0	main
üks	doc_491521501746_item	3757142	et	0	main
vend	doc_491521501746_item	3757143	et	0	main
puudus	doc_491521501746_item	3757144	et	0	main
öeldi	doc_491521501746_item	3757145	et	0	main
et	doc_491521501746_item	3757146	et	0	main
kui	doc_491521501746_item	3757147	et	0	main
seitse	doc_491521501746_item	3757148	et	0	main
venda	doc_491521501746_item	3757149	et	0	main
länevad	doc_491521501746_item	3757150	et	0	main
kirikusse	doc_491521501746_item	3757151	et	0	main
koos	doc_491521501746_item	3757152	et	0	main
siis	doc_491521501746_item	3757153	et	0	main
kiriku	doc_491521501746_item	3757154	et	0	main
lagi	doc_491521501746_item	3757155	et	0	main
kukub	doc_491521501746_item	3757156	et	0	main
sisse	doc_491521501746_item	3757157	et	0	main
rkm	doc_491521501746_item	3757158	et	0	main
ii	doc_491521501746_item	3757159	et	0	main
433	doc_491521501746_item	3757160	et	0	main
291	doc_491521501746_item	3757161	et	0	main
2	doc_491521501746_item	3757162	et	0	main
urgete	doc_491521501746_item	3757163	et	0	main
k	doc_491521501746_item	3757164	et	0	main
kloostri	doc_491521501746_item	3757165	et	0	main
v	doc_491521501746_item	3757166	et	0	main
harju-madise	doc_491521501746_item	3757167	et	0	main
põlli	doc_491521501746_item	3757168	et	0	main
mõis	doc_491521501746_item	3757169	et	0	main
varbola	doc_491521501746_item	3757170	et	0	main
v	doc_491521501746_item	3757171	et	0	main
nissi	doc_491521501746_item	3757172	et	0	main
anu	doc_491521501746_item	3757173	et	0	main
korb	doc_491521501746_item	3757174	et	0	main
selma	doc_491521501746_item	3757175	et	0	main
palmse	doc_491521501746_item	3757176	et	0	main
s	doc_491521501746_item	3757177	et	0	main
1921	doc_491521501746_item	3757178	et	0	main
a	doc_491521501746_item	3757179	et	0	main
oskar	doc_491521501746_item	3757180	et	0	main
palmse	doc_491521501746_item	3757181	et	0	main
s	doc_491521501746_item	3757182	et	0	main
1910	doc_491521501746_item	3757183	et	0	main
a	doc_491521501746_item	3757184	et	0	main
padise	doc_491521501746_item	3757185	et	0	main
külas	doc_491521501746_item	3757186	et	0	main
1990	doc_491521501746_item	3757187	et	0	main
siinkandis	doc_491521501746_item	3757188	et	0	main
on	doc_491521501746_item	3757189	et	0	main
üks	doc_491521501746_item	3757190	et	0	main
kolju	doc_491521501746_item	3757191	et	0	main
kuristik	doc_491521501746_item	3757192	et	0	main
sealt	doc_491521501746_item	3757193	et	0	main
läheb	doc_491521501746_item	3757194	et	0	main
läbi	doc_491521501746_item	3757195	et	0	main
üks	doc_491521501746_item	3757196	et	0	main
salajõgi	doc_491521501746_item	3757197	et	0	main
kiriku	doc_491521501746_item	3757198	et	0	main
alt	doc_491521501746_item	3757199	et	0	main
läheb	doc_491521501746_item	3757200	et	0	main
ja	doc_491521501746_item	3757201	et	0	main
vee	doc_491521501746_item	3757202	et	0	main
kohinat	doc_491521501746_item	3757203	et	0	main
on	doc_491521501746_item	3757204	et	0	main
kuulda	doc_491521501746_item	3757205	et	0	main
ja	doc_491521501746_item	3757206	et	0	main
veetõusmest	doc_491521501746_item	3757207	et	0	main
tuleb	doc_491521501746_item	3757208	et	0	main
välja	doc_491521501746_item	3757209	et	0	main
see	doc_491521501746_item	3757210	et	0	main
on	doc_491521501746_item	3757211	et	0	main
seal	doc_491521501746_item	3757212	et	0	main
kirikust	doc_491521501746_item	3757213	et	0	main
allapoole	doc_491521501746_item	3757214	et	0	main
seal	doc_491521501746_item	3757215	et	0	main
nissi	doc_491521501746_item	3757216	et	0	main
kirikus	doc_491521501746_item	3757217	et	0	main
on	doc_491521501746_item	3757218	et	0	main
rahvas	doc_491521501746_item	3757219	et	0	main
jutluse	doc_491521501746_item	3757220	et	0	main
ajal	doc_491521501746_item	3757221	et	0	main
hanekaginat	doc_491521501746_item	3757222	et	0	main
kuulnud	doc_491521501746_item	3757223	et	0	main
ja	doc_491521501746_item	3757224	et	0	main
vahest	doc_491521501746_item	3757225	et	0	main
on	doc_491521501746_item	3757226	et	0	main
kuulda	doc_491521501746_item	3757227	et	0	main
kohinat	doc_491521501746_item	3757228	et	0	main
ja	doc_491521501746_item	3757229	et	0	main
lehm	doc_491521501746_item	3757230	et	0	main
oli	doc_491521501746_item	3757231	et	0	main
ka	doc_491521501746_item	3757232	et	0	main
selle	doc_491521501746_item	3757233	et	0	main
alla	doc_491521501746_item	3757234	et	0	main
vajunud	doc_491521501746_item	3757235	et	0	main
sealt	doc_491521501746_item	3757236	et	0	main
kolju	doc_491521501746_item	3757237	et	0	main
kuristikust	doc_491521501746_item	3757238	et	0	main
ja	doc_491521501746_item	3757239	et	0	main
teisest	doc_491521501746_item	3757240	et	0	main
otsast	doc_491521501746_item	3757241	et	0	main
oli	doc_491521501746_item	3757242	et	0	main
lehmakell	doc_491521501746_item	3757243	et	0	main
välja	doc_491521501746_item	3757244	et	0	main
tulnud	doc_491521501746_item	3757245	et	0	main
rkm	doc_491521501746_item	3757246	et	0	main
ii	doc_491521501746_item	3757247	et	0	main
434	doc_491521501746_item	3757248	et	0	main
305	doc_491521501746_item	3757249	et	0	main
2	doc_491521501746_item	3757250	et	0	main
nissi	doc_491521501746_item	3757251	et	0	main
khk	doc_491521501746_item	3757252	et	0	main
riisipere	doc_491521501746_item	3757253	et	0	main
v	doc_491521501746_item	3757254	et	0	main
maidla	doc_491521501746_item	3757255	et	0	main
k	doc_491521501746_item	3757256	et	0	main
mall	doc_491521501746_item	3757257	et	0	main
hiiemäe	doc_491521501746_item	3757258	et	0	main
rein	doc_491521501746_item	3757259	et	0	main
leheroo	doc_491521501746_item	3757260	et	0	main
s	doc_491521501746_item	3757261	et	0	main
1949	doc_491521501746_item	3757262	et	0	main
a	doc_491521501746_item	3757263	et	0	main
1990	doc_491521501746_item	3757264	et	0	main
nissi	doc_491521501746_item	3757265	et	0	main
kirik	doc_491521501746_item	3757266	et	0	main
42	doc_491521501746_item	3757267	et	0	main
nissi	doc_491521501746_item	3757268	et	0	main
surnuaia	doc_491521501746_item	3757269	et	0	main
kabel	doc_491521501746_item	3757270	et	0	main
räägivad	doc_491521501746_item	3757271	et	0	main
vaimusid	doc_491521501746_item	3757272	et	0	main
ka	doc_491521501746_item	3757273	et	0	main
üks	doc_491521501746_item	3757274	et	0	main
on	doc_491521501746_item	3757275	et	0	main
igatahes	doc_491521501746_item	3757276	et	0	main
surnud	doc_491521501746_item	3757277	et	0	main
kes	doc_491521501746_item	3757278	et	0	main
rääkis	doc_491521501746_item	3757279	et	0	main
oli	doc_491521501746_item	3757280	et	0	main
miller	doc_491521501746_item	3757281	et	0	main
juhan	doc_491521501746_item	3757282	et	0	main
mustu	doc_491521501746_item	3757283	et	0	main
külast	doc_491521501746_item	3757284	et	0	main
ja	doc_491521501746_item	3757285	et	0	main
teine	doc_491521501746_item	3757286	et	0	main
oli	doc_491521501746_item	3757287	et	0	main
tohvri	doc_491521501746_item	3757288	et	0	main
johannes	doc_491521501746_item	3757289	et	0	main
russalu	doc_491521501746_item	3757290	et	0	main
külast	doc_491521501746_item	3757291	et	0	main
nemad	doc_491521501746_item	3757292	et	0	main
olid	doc_491521501746_item	3757293	et	0	main
kahekesi	doc_491521501746_item	3757294	et	0	main
hobustega	doc_491521501746_item	3757295	et	0	main
linnast	doc_491521501746_item	3757296	et	0	main
tulnud	doc_491521501746_item	3757297	et	0	main
ja	doc_491521501746_item	3757298	et	0	main
äkki	doc_491521501746_item	3757299	et	0	main
olnud	doc_491521501746_item	3757300	et	0	main
üks	doc_491521501746_item	3757301	et	0	main
naisterahvas	doc_491521501746_item	3757302	et	0	main
surnuaia	doc_491521501746_item	3757303	et	0	main
peal	doc_491521501746_item	3757304	et	0	main
lauluraamat	doc_491521501746_item	3757305	et	0	main
käes	doc_491521501746_item	3757306	et	0	main
ja	doc_491521501746_item	3757307	et	0	main
heleda	doc_491521501746_item	3757308	et	0	main
häälega	doc_491521501746_item	3757309	et	0	main
laulnud	doc_491521501746_item	3757310	et	0	main
seal	doc_491521501746_item	3757311	et	0	main
tohver	doc_491521501746_item	3757312	et	0	main
oli	doc_491521501746_item	3757313	et	0	main
julge	doc_491521501746_item	3757314	et	0	main
poiss	doc_491521501746_item	3757315	et	0	main
ta	doc_491521501746_item	3757316	et	0	main
oli	doc_491521501746_item	3757317	et	0	main
noorem	doc_491521501746_item	3757318	et	0	main
mees	doc_491521501746_item	3757319	et	0	main
miller	doc_491521501746_item	3757320	et	0	main
oli	doc_491521501746_item	3757321	et	0	main
juba	doc_491521501746_item	3757322	et	0	main
vanem	doc_491521501746_item	3757323	et	0	main
ta	doc_491521501746_item	3757324	et	0	main
oli	doc_491521501746_item	3757325	et	0	main
võtnud	doc_491521501746_item	3757326	et	0	main
piitsa	doc_491521501746_item	3757327	et	0	main
ja	doc_491521501746_item	3757328	et	0	main
läinud	doc_491521501746_item	3757329	et	0	main
surnuaiale	doc_491521501746_item	3757330	et	0	main
see	doc_491521501746_item	3757331	et	0	main
oli	doc_491521501746_item	3757332	et	0	main
siis	doc_491521501746_item	3757333	et	0	main
kabeli	doc_491521501746_item	3757334	et	0	main
taha	doc_491521501746_item	3757335	et	0	main
ära	doc_491521501746_item	3757336	et	0	main
vajunud	doc_491521501746_item	3757337	et	0	main
nissi	doc_491521501746_item	3757338	et	0	main
surnuaia	doc_491521501746_item	3757339	et	0	main
keskmise	doc_491521501746_item	3757340	et	0	main
värava	doc_491521501746_item	3757341	et	0	main
juures	doc_491521501746_item	3757342	et	0	main
oli	doc_491521501746_item	3757343	et	0	main
see	doc_491521501746_item	3757344	et	0	main
rkm	doc_491521501746_item	3757345	et	0	main
ii	doc_491521501746_item	3757346	et	0	main
434	doc_491521501746_item	3757347	et	0	main
129	doc_491521501746_item	3757348	et	0	main
21	doc_491521501746_item	3757349	et	0	main
nissi	doc_491521501746_item	3757350	et	0	main
khk	doc_491521501746_item	3757351	et	0	main
riisipere	doc_491521501746_item	3757352	et	0	main
v	doc_491521501746_item	3757353	et	0	main
nurme	doc_491521501746_item	3757354	et	0	main
k	doc_491521501746_item	3757355	et	0	main
lehetu	doc_491521501746_item	3757356	et	0	main
k	doc_491521501746_item	3757357	et	0	main
mall	doc_491521501746_item	3757358	et	0	main
hiiemäe	doc_491521501746_item	3757359	et	0	main
august	doc_491521501746_item	3757360	et	0	main
lehtme	doc_491521501746_item	3757361	et	0	main
s	doc_491521501746_item	3757362	et	0	main
1919	doc_491521501746_item	3757363	et	0	main
a	doc_491521501746_item	3757364	et	0	main
1990	doc_491521501746_item	3757365	et	0	main
43	doc_491521501746_item	3757366	et	0	main
riisipere	doc_491521501746_item	3757367	et	0	main
mõis	doc_491521501746_item	3757368	et	0	main
kivitammi	doc_491521501746_item	3757369	et	0	main
külla	doc_491521501746_item	3757370	et	0	main
rajati	doc_491521501746_item	3757371	et	0	main
vana	doc_491521501746_item	3757372	et	0	main
riisipere	doc_491521501746_item	3757373	et	0	main
mõis	doc_491521501746_item	3757374	et	0	main
alt-riiesenberg	doc_491521501746_item	3757375	et	0	main
juba	doc_491521501746_item	3757376	et	0	main
13	doc_491521501746_item	3757377	et	0	main
saj	doc_491521501746_item	3757378	et	0	main
hiljem	doc_491521501746_item	3757379	et	0	main
jäi	doc_491521501746_item	3757380	et	0	main
see	doc_491521501746_item	3757381	et	0	main
karjamõisaks	doc_491521501746_item	3757382	et	0	main
vilumäele	doc_491521501746_item	3757383	et	0	main
ehitati	doc_491521501746_item	3757384	et	0	main
1821	doc_491521501746_item	3757385	et	0	main
a	doc_491521501746_item	3757386	et	0	main
üks	doc_491521501746_item	3757387	et	0	main
eesti	doc_491521501746_item	3757388	et	0	main
suuremaid	doc_491521501746_item	3757389	et	0	main
ja	doc_491521501746_item	3757390	et	0	main
huvitavamaid	doc_491521501746_item	3757391	et	0	main
klassitsistlik	doc_491521501746_item	3757392	et	0	main
uue-riisipere	doc_491521501746_item	3757393	et	0	main
härrastemaja	doc_491521501746_item	3757394	et	0	main
vana	doc_491521501746_item	3757395	et	0	main
riisipere	doc_491521501746_item	3757396	et	0	main
mõis	doc_491521501746_item	3757397	et	0	main
põles	doc_491521501746_item	3757398	et	0	main
ära	doc_491521501746_item	3757399	et	0	main
see	doc_491521501746_item	3757400	et	0	main
sündmus	doc_491521501746_item	3757401	et	0	main
on	doc_491521501746_item	3757402	et	0	main
kohapärimusre	doc_491521501746_item	3757403	et	0	main
jutuaineks	doc_491521501746_item	3757404	et	0	main
olnud	doc_491521501746_item	3757405	et	0	main
mitmeid	doc_491521501746_item	3757406	et	0	main
aastakümneid	doc_491521501746_item	3757407	et	0	main
riisipere	doc_491521501746_item	3757408	et	0	main
riesenberg	doc_491521501746_item	3757409	et	0	main
mõisahoone	doc_491521501746_item	3757410	et	0	main
kuulub	doc_491521501746_item	3757411	et	0	main
koos	doc_491521501746_item	3757412	et	0	main
kolga	doc_491521501746_item	3757413	et	0	main
mõisahoonega	doc_491521501746_item	3757414	et	0	main
klassitsitliku	doc_491521501746_item	3757415	et	0	main
ehitusstiili	doc_491521501746_item	3757416	et	0	main
parimate	doc_491521501746_item	3757417	et	0	main
näidiste	doc_491521501746_item	3757418	et	0	main
hulka	doc_491521501746_item	3757419	et	0	main
riisipere	doc_491521501746_item	3757420	et	0	main
mõisaansambel	doc_491521501746_item	3757421	et	0	main
oli	doc_491521501746_item	3757422	et	0	main
xix	doc_491521501746_item	3757423	et	0	main
sajandil	doc_491521501746_item	3757424	et	0	main
võitnud	doc_491521501746_item	3757425	et	0	main
laialdase	doc_491521501746_item	3757426	et	0	main
kuulsuse	doc_491521501746_item	3757427	et	0	main
temast	doc_491521501746_item	3757428	et	0	main
kõnelesid	doc_491521501746_item	3757429	et	0	main
paljud	doc_491521501746_item	3757430	et	0	main
reisikirjeldused	doc_491521501746_item	3757431	et	0	main
suurejooneline	doc_491521501746_item	3757432	et	0	main
sammasportikus	doc_491521501746_item	3757433	et	0	main
kuue	doc_491521501746_item	3757434	et	0	main
joonia	doc_491521501746_item	3757435	et	0	main
stiilis	doc_491521501746_item	3757436	et	0	main
sambaga	doc_491521501746_item	3757437	et	0	main
kaunistab	doc_491521501746_item	3757438	et	0	main
hoone	doc_491521501746_item	3757439	et	0	main
peafassaadi	doc_491521501746_item	3757440	et	0	main
keskosa	doc_491521501746_item	3757441	et	0	main
rotundikujulisest	doc_491521501746_item	3757442	et	0	main
keskvestibüülist	doc_491521501746_item	3757443	et	0	main
mille	doc_491521501746_item	3757444	et	0	main
seintes	doc_491521501746_item	3757445	et	0	main
on	doc_491521501746_item	3757446	et	0	main
kaarnišid	doc_491521501746_item	3757447	et	0	main
skulptuuride	doc_491521501746_item	3757448	et	0	main
tarvis	doc_491521501746_item	3757449	et	0	main
viib	doc_491521501746_item	3757450	et	0	main
trepp	doc_491521501746_item	3757451	et	0	main
teisele	doc_491521501746_item	3757452	et	0	main
korrusele	doc_491521501746_item	3757453	et	0	main
vestibüüli	doc_491521501746_item	3757454	et	0	main
peal	doc_491521501746_item	3757455	et	0	main
on	doc_491521501746_item	3757456	et	0	main
kuppelsaal	doc_491521501746_item	3757457	et	0	main
nn	doc_491521501746_item	3757458	et	0	main
esivanemate	doc_491521501746_item	3757459	et	0	main
galerii	doc_491521501746_item	3757460	et	0	main
kus	doc_491521501746_item	3757461	et	0	main
asetsesid	doc_491521501746_item	3757462	et	0	main
perekonnaportreed	doc_491521501746_item	3757463	et	0	main
suur	doc_491521501746_item	3757464	et	0	main
peosaal	doc_491521501746_item	3757465	et	0	main
asetses	doc_491521501746_item	3757466	et	0	main
hoone	doc_491521501746_item	3757467	et	0	main
ühes	doc_491521501746_item	3757468	et	0	main
otsas	doc_491521501746_item	3757469	et	0	main
saali	doc_491521501746_item	3757470	et	0	main
lagi	doc_491521501746_item	3757471	et	0	main
lae-	doc_491521501746_item	3757472	et	0	main
ja	doc_491521501746_item	3757473	et	0	main
uksekarniisid	doc_491521501746_item	3757474	et	0	main
on	doc_491521501746_item	3757475	et	0	main
nii	doc_491521501746_item	3757476	et	0	main
motiividelt	doc_491521501746_item	3757477	et	0	main
kui	doc_491521501746_item	3757478	et	0	main
ka	doc_491521501746_item	3757479	et	0	main
töötluselt	doc_491521501746_item	3757480	et	0	main
parimad	doc_491521501746_item	3757481	et	0	main
meil	doc_491521501746_item	3757482	et	0	main
leiduvad	doc_491521501746_item	3757483	et	0	main
klassitsistlikud	doc_491521501746_item	3757484	et	0	main
dekoratiivdetailid	doc_491521501746_item	3757485	et	0	main
mõisahoonetes	doc_491521501746_item	3757486	et	0	main
asus	doc_491521501746_item	3757487	et	0	main
pikka	doc_491521501746_item	3757488	et	0	main
aega	doc_491521501746_item	3757489	et	0	main
riisipere	doc_491521501746_item	3757490	et	0	main
lastekodu	doc_491521501746_item	3757491	et	0	main
ja	doc_491521501746_item	3757492	et	0	main
põhikool	doc_491521501746_item	3757493	et	0	main
praegu	doc_491521501746_item	3757494	et	0	main
ootab	doc_491521501746_item	3757495	et	0	main
kaunis	doc_491521501746_item	3757496	et	0	main
kuppel-	doc_491521501746_item	3757497	et	0	main
ja	doc_491521501746_item	3757498	et	0	main
sammassaali	doc_491521501746_item	3757499	et	0	main
jt	doc_491521501746_item	3757500	et	0	main
kunstiväärtustega	doc_491521501746_item	3757501	et	0	main
loss	doc_491521501746_item	3757502	et	0	main
taastamist	doc_491521501746_item	3757503	et	0	main
riisipere	doc_491521501746_item	3757504	et	0	main
mõisa	doc_491521501746_item	3757505	et	0	main
pärimused	doc_491521501746_item	3757506	et	0	main
esiteks	doc_491521501746_item	3757507	et	0	main
võib	doc_491521501746_item	3757508	et	0	main
nimetada	doc_491521501746_item	3757509	et	0	main
kohapärimusteks	doc_491521501746_item	3757510	et	0	main
kuna	doc_491521501746_item	3757511	et	0	main
nad	doc_491521501746_item	3757512	et	0	main
on	doc_491521501746_item	3757513	et	0	main
seotud	doc_491521501746_item	3757514	et	0	main
konkreetse	doc_491521501746_item	3757515	et	0	main
ehitisega	doc_491521501746_item	3757516	et	0	main
teisalt	doc_491521501746_item	3757517	et	0	main
me	doc_491521501746_item	3757518	et	0	main
võime	doc_491521501746_item	3757519	et	0	main
kasitleda	doc_491521501746_item	3757520	et	0	main
neid	doc_491521501746_item	3757521	et	0	main
memoraatidena	doc_491521501746_item	3757522	et	0	main
kuna	doc_491521501746_item	3757523	et	0	main
tegemist	doc_491521501746_item	3757524	et	0	main
on	doc_491521501746_item	3757525	et	0	main
lugudega	doc_491521501746_item	3757526	et	0	main
mis	doc_491521501746_item	3757527	et	0	main
kajastavad	doc_491521501746_item	3757528	et	0	main
isikulist	doc_491521501746_item	3757529	et	0	main
elamust	doc_491521501746_item	3757530	et	0	main
minu	doc_491521501746_item	3757531	et	0	main
ema	doc_491521501746_item	3757532	et	0	main
rääkis	doc_491521501746_item	3757533	et	0	main
küll	doc_491521501746_item	3757534	et	0	main
väga	doc_491521501746_item	3757535	et	0	main
imelikku	doc_491521501746_item	3757536	et	0	main
lugu	doc_491521501746_item	3757537	et	0	main
ütles	doc_491521501746_item	3757538	et	0	main
veel	doc_491521501746_item	3757539	et	0	main
et	doc_491521501746_item	3757540	et	0	main
ma	doc_491521501746_item	3757541	et	0	main
olen	doc_491521501746_item	3757542	et	0	main
ise	doc_491521501746_item	3757543	et	0	main
seda	doc_491521501746_item	3757544	et	0	main
näinud	doc_491521501746_item	3757545	et	0	main
neljateiskümne	doc_491521501746_item	3757546	et	0	main
aastaselt	doc_491521501746_item	3757547	et	0	main
läinud	doc_491521501746_item	3757548	et	0	main
riisipere	doc_491521501746_item	3757549	et	0	main
mõisasse	doc_491521501746_item	3757550	et	0	main
alguses	doc_491521501746_item	3757551	et	0	main
oli	doc_491521501746_item	3757552	et	0	main
olnud	doc_491521501746_item	3757553	et	0	main
aedniku	doc_491521501746_item	3757554	et	0	main
abiks	doc_491521501746_item	3757555	et	0	main
ja	doc_491521501746_item	3757556	et	0	main
siis	doc_491521501746_item	3757557	et	0	main
toatüdrukuks	doc_491521501746_item	3757558	et	0	main
stakelbergid	doc_491521501746_item	3757559	et	0	main
olid	doc_491521501746_item	3757560	et	0	main
väga	doc_491521501746_item	3757561	et	0	main
ead	doc_491521501746_item	3757562	et	0	main
inimesed	doc_491521501746_item	3757563	et	0	main
olnud	doc_491521501746_item	3757564	et	0	main
seal	doc_491521501746_item	3757565	et	0	main
tema	doc_491521501746_item	3757566	et	0	main
akand	doc_491521501746_item	3757567	et	0	main
lõunalauda	doc_491521501746_item	3757568	et	0	main
katma	doc_491521501746_item	3757569	et	0	main
siis	doc_491521501746_item	3757570	et	0	main
olla	doc_491521501746_item	3757571	et	0	main
tulnud	doc_491521501746_item	3757572	et	0	main
temale	doc_491521501746_item	3757573	et	0	main
vastu	doc_491521501746_item	3757574	et	0	main
üks	doc_491521501746_item	3757575	et	0	main
niisugune	doc_491521501746_item	3757576	et	0	main
kena	doc_491521501746_item	3757577	et	0	main
noor	doc_491521501746_item	3757578	et	0	main
tütarlaps	doc_491521501746_item	3757579	et	0	main
madrusekleidis	doc_491521501746_item	3757580	et	0	main
ema	doc_491521501746_item	3757581	et	0	main
läind	doc_491521501746_item	3757582	et	0	main
siis	doc_491521501746_item	3757583	et	0	main
veel	doc_491521501746_item	3757584	et	0	main
proua	doc_491521501746_item	3757585	et	0	main
käest	doc_491521501746_item	3757586	et	0	main
küsima	doc_491521501746_item	3757587	et	0	main
et	doc_491521501746_item	3757588	et	0	main
mitmele	doc_491521501746_item	3757589	et	0	main
ma	doc_491521501746_item	3757590	et	0	main
lauda	doc_491521501746_item	3757591	et	0	main
katan	doc_491521501746_item	3757592	et	0	main
proua	doc_491521501746_item	3757593	et	0	main
oli	doc_491521501746_item	3757594	et	0	main
päris	doc_491521501746_item	3757595	et	0	main
imestunud	doc_491521501746_item	3757596	et	0	main
äälega	doc_491521501746_item	3757597	et	0	main
küsinud	doc_491521501746_item	3757598	et	0	main
et	doc_491521501746_item	3757599	et	0	main
kulla	doc_491521501746_item	3757600	et	0	main
laps	doc_491521501746_item	3757601	et	0	main
miks	doc_491521501746_item	3757602	et	0	main
sa	doc_491521501746_item	3757603	et	0	main
seda	doc_491521501746_item	3757604	et	0	main
küsid	doc_491521501746_item	3757605	et	0	main
eks	doc_491521501746_item	3757606	et	0	main
sa	doc_491521501746_item	3757607	et	0	main
kata	doc_491521501746_item	3757608	et	0	main
nii	doc_491521501746_item	3757609	et	0	main
nagu	doc_491521501746_item	3757610	et	0	main
alati	doc_491521501746_item	3757611	et	0	main
ema	doc_491521501746_item	3757612	et	0	main
oli	doc_491521501746_item	3757613	et	0	main
vastanud	doc_491521501746_item	3757614	et	0	main
et	doc_491521501746_item	3757615	et	0	main
ma	doc_491521501746_item	3757616	et	0	main
mõtlesin	doc_491521501746_item	3757617	et	0	main
et	doc_491521501746_item	3757618	et	0	main
külalised	doc_491521501746_item	3757619	et	0	main
üks	doc_491521501746_item	3757620	et	0	main
võõras	doc_491521501746_item	3757621	et	0	main
preoli	doc_491521501746_item	3757622	et	0	main
oli	doc_491521501746_item	3757623	et	0	main
veel	doc_491521501746_item	3757624	et	0	main
tulnud	doc_491521501746_item	3757625	et	0	main
proua	doc_491521501746_item	3757626	et	0	main
läks	doc_491521501746_item	3757627	et	0	main
nagu	doc_491521501746_item	3757628	et	0	main
tõsiseks	doc_491521501746_item	3757629	et	0	main
kas	doc_491521501746_item	3757630	et	0	main
sa	doc_491521501746_item	3757631	et	0	main
nägid	doc_491521501746_item	3757632	et	0	main
ära	doc_491521501746_item	3757633	et	0	main
seda	doc_491521501746_item	3757634	et	0	main
mitte	doc_491521501746_item	3757635	et	0	main
kellegile	doc_491521501746_item	3757636	et	0	main
räägi	doc_491521501746_item	3757637	et	0	main
et	doc_491521501746_item	3757638	et	0	main
sa	doc_491521501746_item	3757639	et	0	main
nägid	doc_491521501746_item	3757640	et	0	main
teda	doc_491521501746_item	3757641	et	0	main
aga	doc_491521501746_item	3757642	et	0	main
ema	doc_491521501746_item	3757643	et	0	main
oli	doc_491521501746_item	3757644	et	0	main
kolm	doc_491521501746_item	3757645	et	0	main
korda	doc_491521501746_item	3757646	et	0	main
näinud	doc_491521501746_item	3757647	et	0	main
isegi	doc_491521501746_item	3757648	et	0	main
oli	doc_491521501746_item	3757649	et	0	main
üks	doc_491521501746_item	3757650	et	0	main
ruum	doc_491521501746_item	3757651	et	0	main
ka	doc_491521501746_item	3757652	et	0	main
kus	doc_491521501746_item	3757653	et	0	main
see	doc_491521501746_item	3757654	et	0	main
vastu	doc_491521501746_item	3757655	et	0	main
tuli	doc_491521501746_item	3757656	et	0	main
millest	doc_491521501746_item	3757657	et	0	main
see	doc_491521501746_item	3757658	et	0	main
siis	doc_491521501746_item	3757659	et	0	main
oli	doc_491521501746_item	3757660	et	0	main
tema	doc_491521501746_item	3757661	et	0	main
kohe	doc_491521501746_item	3757662	et	0	main
teab	doc_491521501746_item	3757663	et	0	main
nii	doc_491521501746_item	3757664	et	0	main
selgesti	doc_491521501746_item	3757665	et	0	main
nägi	doc_491521501746_item	3757666	et	0	main
üks	doc_491521501746_item	3757667	et	0	main
vanem	doc_491521501746_item	3757668	et	0	main
naine	doc_491521501746_item	3757669	et	0	main
oli	doc_491521501746_item	3757670	et	0	main
köögis	doc_491521501746_item	3757671	et	0	main
tema	doc_491521501746_item	3757672	et	0	main
oli	doc_491521501746_item	3757673	et	0	main
see	doc_491521501746_item	3757674	et	0	main
oli	doc_491521501746_item	3757675	et	0	main
ka	doc_491521501746_item	3757676	et	0	main
midagi	doc_491521501746_item	3757677	et	0	main
teadnud	doc_491521501746_item	3757678	et	0	main
rkm	doc_491521501746_item	3757679	et	0	main
ii	doc_491521501746_item	3757680	et	0	main
image	doc_491521501746_item	3757681	et	0	main
chromeskypefftoolbarwincontentcbtransparentlgif	doc_491521501746_item	3757682	et	0	main
image	doc_491521501746_item	3757683	et	0	main
chromeskypefftoolbarwincontentfamfamfameegif	doc_491521501746_item	3757684	et	0	main
image	doc_491521501746_item	3757685	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757686	et	0	main
image	doc_491521501746_item	3757687	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757688	et	0	main
image	doc_491521501746_item	3757689	et	0	main
chromeskypefftoolbarwincontentarrowgif	doc_491521501746_item	3757690	et	0	main
image	doc_491521501746_item	3757691	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757692	et	0	main
image	doc_491521501746_item	3757693	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757694	et	0	main
image	doc_491521501746_item	3757695	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757696	et	0	main
image	doc_491521501746_item	3757697	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757698	et	0	main
image	doc_491521501746_item	3757699	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757700	et	0	main
image	doc_491521501746_item	3757701	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757702	et	0	main
image	doc_491521501746_item	3757703	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757704	et	0	main
435	doc_491521501746_item	3757705	et	0	main
7576	doc_491521501746_item	3757706	et	0	main
image	doc_491521501746_item	3757707	et	0	main
chromeskypefftoolbarwincontentcbtransparentrgif	doc_491521501746_item	3757708	et	0	main
9	doc_491521501746_item	3757709	et	0	main
nissi	doc_491521501746_item	3757710	et	0	main
turba	doc_491521501746_item	3757711	et	0	main
al	doc_491521501746_item	3757712	et	0	main
riisipere	doc_491521501746_item	3757713	et	0	main
mare	doc_491521501746_item	3757714	et	0	main
janneste	doc_491521501746_item	3757715	et	0	main
asta	doc_491521501746_item	3757716	et	0	main
kraut	doc_491521501746_item	3757717	et	0	main
s	doc_491521501746_item	3757718	et	0	main
1921	doc_491521501746_item	3757719	et	0	main
a	doc_491521501746_item	3757720	et	0	main
1990	doc_491521501746_item	3757721	et	0	main
riisipere	doc_491521501746_item	3757722	et	0	main
mõisas	doc_491521501746_item	3757723	et	0	main
ikka	doc_491521501746_item	3757724	et	0	main
räägitud	doc_491521501746_item	3757725	et	0	main
et	doc_491521501746_item	3757726	et	0	main
peretoas	doc_491521501746_item	3757727	et	0	main
kus	doc_491521501746_item	3757728	et	0	main
tüdrukud	doc_491521501746_item	3757729	et	0	main
maganud	doc_491521501746_item	3757730	et	0	main
käinud	doc_491521501746_item	3757731	et	0	main
kodukäija	doc_491521501746_item	3757732	et	0	main
tüdrukuid	doc_491521501746_item	3757733	et	0	main
piinamas	doc_491521501746_item	3757734	et	0	main
räägiti	doc_491521501746_item	3757735	et	0	main
et	doc_491521501746_item	3757736	et	0	main
mehe	doc_491521501746_item	3757737	et	0	main
kuju	doc_491521501746_item	3757738	et	0	main
on	doc_491521501746_item	3757739	et	0	main
ütleb	doc_491521501746_item	3757740	et	0	main
veel	doc_491521501746_item	3757741	et	0	main
tere	doc_491521501746_item	3757742	et	0	main
õhtust	doc_491521501746_item	3757743	et	0	main
ja	doc_491521501746_item	3757744	et	0	main
siis	doc_491521501746_item	3757745	et	0	main
tuleb	doc_491521501746_item	3757746	et	0	main
kellegi	doc_491521501746_item	3757747	et	0	main
peale	doc_491521501746_item	3757748	et	0	main
ja	doc_491521501746_item	3757749	et	0	main
rõhub	doc_491521501746_item	3757750	et	0	main
minu	doc_491521501746_item	3757751	et	0	main
ema	doc_491521501746_item	3757752	et	0	main
tulnud	doc_491521501746_item	3757753	et	0	main
mõisa	doc_491521501746_item	3757754	et	0	main
pesutüdrukuks	doc_491521501746_item	3757755	et	0	main
maganud	doc_491521501746_item	3757756	et	0	main
ka	doc_491521501746_item	3757757	et	0	main
seal	doc_491521501746_item	3757758	et	0	main
peretoas	doc_491521501746_item	3757759	et	0	main
ja	doc_491521501746_item	3757760	et	0	main
mõelnud	doc_491521501746_item	3757761	et	0	main
et	doc_491521501746_item	3757762	et	0	main
kui	doc_491521501746_item	3757763	et	0	main
see	doc_491521501746_item	3757764	et	0	main
kodukäija	doc_491521501746_item	3757765	et	0	main
tuleb	doc_491521501746_item	3757766	et	0	main
ma	doc_491521501746_item	3757767	et	0	main
kohe	doc_491521501746_item	3757768	et	0	main
ukse	doc_491521501746_item	3757769	et	0	main
all	doc_491521501746_item	3757770	et	0	main
äkki	doc_491521501746_item	3757771	et	0	main
tuleb	doc_491521501746_item	3757772	et	0	main
mind	doc_491521501746_item	3757773	et	0	main
rõhuma	doc_491521501746_item	3757774	et	0	main
võtnud	doc_491521501746_item	3757775	et	0	main
suure	doc_491521501746_item	3757776	et	0	main
koera	doc_491521501746_item	3757777	et	0	main
enda	doc_491521501746_item	3757778	et	0	main
jälgade	doc_491521501746_item	3757779	et	0	main
peale	doc_491521501746_item	3757780	et	0	main
rkm	doc_491521501746_item	3757781	et	0	main
ii	doc_491521501746_item	3757782	et	0	main
image	doc_491521501746_item	3757783	et	0	main
chromeskypefftoolbarwincontentcbtransparentlgif	doc_491521501746_item	3757784	et	0	main
image	doc_491521501746_item	3757785	et	0	main
chromeskypefftoolbarwincontentfamfamfameegif	doc_491521501746_item	3757786	et	0	main
image	doc_491521501746_item	3757787	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757788	et	0	main
image	doc_491521501746_item	3757789	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757790	et	0	main
image	doc_491521501746_item	3757791	et	0	main
chromeskypefftoolbarwincontentarrowgif	doc_491521501746_item	3757792	et	0	main
image	doc_491521501746_item	3757793	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757794	et	0	main
image	doc_491521501746_item	3757795	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757796	et	0	main
image	doc_491521501746_item	3757797	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757798	et	0	main
image	doc_491521501746_item	3757799	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757800	et	0	main
image	doc_491521501746_item	3757801	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757802	et	0	main
image	doc_491521501746_item	3757803	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757804	et	0	main
image	doc_491521501746_item	3757805	et	0	main
chromeskypefftoolbarwincontentspacegif	doc_491521501746_item	3757806	et	0	main
433	doc_491521501746_item	3757807	et	0	main
image	doc_491521501746_item	3757808	et	0	main
chromeskypefftoolbarwincontentcbtransparentrgif	doc_491521501746_item	3757809	et	0	main
25	doc_491521501746_item	3757810	et	0	main
nissi	doc_491521501746_item	3757811	et	0	main
khk	doc_491521501746_item	3757812	et	0	main
riisipere	doc_491521501746_item	3757813	et	0	main
mõis	doc_491521501746_item	3757814	et	0	main
anu	doc_491521501746_item	3757815	et	0	main
korb	doc_491521501746_item	3757816	et	0	main
õilme	doc_491521501746_item	3757817	et	0	main
sepp	doc_491521501746_item	3757818	et	0	main
64	doc_491521501746_item	3757819	et	0	main
a	doc_491521501746_item	3757820	et	0	main
1990	doc_491521501746_item	3757821	et	0	main
riisipere	doc_491521501746_item	3757822	et	0	main
vana	doc_491521501746_item	3757823	et	0	main
mõis	doc_491521501746_item	3757824	et	0	main
mis	doc_491521501746_item	3757825	et	0	main
seal	doc_491521501746_item	3757826	et	0	main
kivitamme	doc_491521501746_item	3757827	et	0	main
pool	doc_491521501746_item	3757828	et	0	main
on	doc_491521501746_item	3757829	et	0	main
mis	doc_491521501746_item	3757830	et	0	main
ära	doc_491521501746_item	3757831	et	0	main
põles	doc_491521501746_item	3757832	et	0	main
1936	doc_491521501746_item	3757833	et	0	main
või	doc_491521501746_item	3757834	et	0	main
37	doc_491521501746_item	3757835	et	0	main
pikne	doc_491521501746_item	3757836	et	0	main
löönd	doc_491521501746_item	3757837	et	0	main
kase	doc_491521501746_item	3757838	et	0	main
sisse	doc_491521501746_item	3757839	et	0	main
peale	doc_491521501746_item	3757840	et	0	main
seda	doc_491521501746_item	3757841	et	0	main
traktorist	doc_491521501746_item	3757842	et	0	main
tuli	doc_491521501746_item	3757843	et	0	main
küla	doc_491521501746_item	3757844	et	0	main
pealt	doc_491521501746_item	3757845	et	0	main
pimedal	doc_491521501746_item	3757846	et	0	main
ajal	doc_491521501746_item	3757847	et	0	main
näeb	doc_491521501746_item	3757848	et	0	main
üks	doc_491521501746_item	3757849	et	0	main
naisterahvas	doc_491521501746_item	3757850	et	0	main
seisab	doc_491521501746_item	3757851	et	0	main
seal	doc_491521501746_item	3757852	et	0	main
trepi	doc_491521501746_item	3757853	et	0	main
peal	doc_491521501746_item	3757854	et	0	main
vihma	doc_491521501746_item	3757855	et	0	main
sadand	doc_491521501746_item	3757856	et	0	main
ta	doc_491521501746_item	3757857	et	0	main
mõtelnd	doc_491521501746_item	3757858	et	0	main
ma	doc_491521501746_item	3757859	et	0	main
kutsun	doc_491521501746_item	3757860	et	0	main
ta	doc_491521501746_item	3757861	et	0	main
siis	doc_491521501746_item	3757862	et	0	main
ära	doc_491521501746_item	3757863	et	0	main
läind	doc_491521501746_item	3757864	et	0	main
ligemale	doc_491521501746_item	3757865	et	0	main
see	doc_491521501746_item	3757866	et	0	main
kadund	doc_491521501746_item	3757867	et	0	main
ära	doc_491521501746_item	3757868	et	0	main
aga	doc_491521501746_item	3757869	et	0	main
nii	doc_491521501746_item	3757870	et	0	main
on	doc_491521501746_item	3757871	et	0	main
et	doc_491521501746_item	3757872	et	0	main
kui	doc_491521501746_item	3757873	et	0	main
maja	doc_491521501746_item	3757874	et	0	main
ilma	doc_491521501746_item	3757875	et	0	main
katuseta	doc_491521501746_item	3757876	et	0	main
jääb	doc_491521501746_item	3757877	et	0	main
pidid	doc_491521501746_item	3757878	et	0	main
ilmuma	doc_491521501746_item	3757879	et	0	main
nende	doc_491521501746_item	3757880	et	0	main
vaimud	doc_491521501746_item	3757881	et	0	main
kes	doc_491521501746_item	3757882	et	0	main
nemad	doc_491521501746_item	3757883	et	0	main
ehitanud	doc_491521501746_item	3757884	et	0	main
on	doc_491521501746_item	3757885	et	0	main
rkm	doc_491521501746_item	3757886	et	0	main
ii	doc_491521501746_item	3757887	et	0	main
435	doc_491521501746_item	3757888	et	0	main
155	doc_491521501746_item	3757889	et	0	main
11	doc_491521501746_item	3757890	et	0	main
nissi	doc_491521501746_item	3757891	et	0	main
v	doc_491521501746_item	3757892	et	0	main
odolemma	doc_491521501746_item	3757893	et	0	main
k	doc_491521501746_item	3757894	et	0	main
jaanijüri	doc_491521501746_item	3757895	et	0	main
t	doc_491521501746_item	3757896	et	0	main
kernu	doc_491521501746_item	3757897	et	0	main
v	doc_491521501746_item	3757898	et	0	main
miilima	doc_491521501746_item	3757899	et	0	main
k	doc_491521501746_item	3757900	et	0	main
mare	doc_491521501746_item	3757901	et	0	main
janneste	doc_491521501746_item	3757902	et	0	main
aliide	doc_491521501746_item	3757903	et	0	main
niinemaa	doc_491521501746_item	3757904	et	0	main
s	doc_491521501746_item	3757905	et	0	main
magnus	doc_491521501746_item	3757906	et	0	main
s	doc_491521501746_item	3757907	et	0	main
1919	doc_491521501746_item	3757908	et	0	main
a	doc_491521501746_item	3757909	et	0	main
august	doc_491521501746_item	3757910	et	0	main
niinemaa	doc_491521501746_item	3757911	et	0	main
s	doc_491521501746_item	3757912	et	0	main
1912	doc_491521501746_item	3757913	et	0	main
a	doc_491521501746_item	3757914	et	0	main
liidia	doc_491521501746_item	3757915	et	0	main
metsjõe	doc_491521501746_item	3757916	et	0	main
s	doc_491521501746_item	3757917	et	0	main
1942	doc_491521501746_item	3757918	et	0	main
a	doc_491521501746_item	3757919	et	0	main
eelmiste	doc_491521501746_item	3757920	et	0	main
tütar	doc_491521501746_item	3757921	et	0	main
1990	doc_491521501746_item	3757922	et	0	main
riisipere	doc_491521501746_item	3757923	et	0	main
vana	doc_491521501746_item	3757924	et	0	main
mõisa	doc_491521501746_item	3757925	et	0	main
õue	doc_491521501746_item	3757926	et	0	main
pealt	doc_491521501746_item	3757927	et	0	main
läks	doc_491521501746_item	3757928	et	0	main
salatee	doc_491521501746_item	3757929	et	0	main
uue	doc_491521501746_item	3757930	et	0	main
mõisa	doc_491521501746_item	3757931	et	0	main
juurde	doc_491521501746_item	3757932	et	0	main
seal	doc_491521501746_item	3757933	et	0	main
oli	doc_491521501746_item	3757934	et	0	main
sada	doc_491521501746_item	3757935	et	0	main
tuba	doc_491521501746_item	3757936	et	0	main
olnud	doc_491521501746_item	3757937	et	0	main
mõisa	doc_491521501746_item	3757938	et	0	main
ees	doc_491521501746_item	3757939	et	0	main
olid	doc_491521501746_item	3757940	et	0	main
suured	doc_491521501746_item	3757941	et	0	main
vaasid	doc_491521501746_item	3757942	et	0	main
kivist	doc_491521501746_item	3757943	et	0	main
lilled	doc_491521501746_item	3757944	et	0	main
kasvasid	doc_491521501746_item	3757945	et	0	main
kui	doc_491521501746_item	3757946	et	0	main
lastekodu	doc_491521501746_item	3757947	et	0	main
tehti	doc_491521501746_item	3757948	et	0	main
müüriti	doc_491521501746_item	3757949	et	0	main
aknad	doc_491521501746_item	3757950	et	0	main
kinni	doc_491521501746_item	3757951	et	0	main
see	doc_491521501746_item	3757952	et	0	main
on	doc_491521501746_item	3757953	et	0	main
riisipere	doc_491521501746_item	3757954	et	0	main
uus	doc_491521501746_item	3757955	et	0	main
mõis	doc_491521501746_item	3757956	et	0	main
vana	doc_491521501746_item	3757957	et	0	main
mõis	doc_491521501746_item	3757958	et	0	main
oli	doc_491521501746_item	3757959	et	0	main
kivitammi	doc_491521501746_item	3757960	et	0	main
peatuse	doc_491521501746_item	3757961	et	0	main
juures	doc_491521501746_item	3757962	et	0	main
rkm	doc_491521501746_item	3757963	et	0	main
ii	doc_491521501746_item	3757964	et	0	main
435	doc_491521501746_item	3757965	et	0	main
274	doc_491521501746_item	3757966	et	0	main
33	doc_491521501746_item	3757967	et	0	main
nissi	doc_491521501746_item	3757968	et	0	main
turba	doc_491521501746_item	3757969	et	0	main
al	doc_491521501746_item	3757970	et	0	main
põltsamaa	doc_491521501746_item	3757971	et	0	main
khk	doc_491521501746_item	3757972	et	0	main
kadi	doc_491521501746_item	3757973	et	0	main
sarv	doc_491521501746_item	3757974	et	0	main
agnes	doc_491521501746_item	3757975	et	0	main
saliste	doc_491521501746_item	3757976	et	0	main
s	doc_491521501746_item	3757977	et	0	main
1923	doc_491521501746_item	3757978	et	0	main
a	doc_491521501746_item	3757979	et	0	main
1990	doc_491521501746_item	3757980	et	0	main
ja	doc_491521501746_item	3757981	et	0	main
üpris	doc_491521501746_item	3757982	et	0	main
vähe	doc_491521501746_item	3757983	et	0	main
on	doc_491521501746_item	3757984	et	0	main
leitud	doc_491521501746_item	3757985	et	0	main
ajaloolisi	doc_491521501746_item	3757986	et	0	main
pärimusi	doc_491521501746_item	3757987	et	0	main
mis	doc_491521501746_item	3757988	et	0	main
oleks	doc_491521501746_item	3757989	et	0	main
jutustanud	doc_491521501746_item	3757990	et	0	main
mõisa	doc_491521501746_item	3757991	et	0	main
ajaloost	doc_491521501746_item	3757992	et	0	main
või	doc_491521501746_item	3757993	et	0	main
mõisnikest	doc_491521501746_item	3757994	et	0	main
nissis	doc_491521501746_item	3757995	et	0	main
oli	doc_491521501746_item	3757996	et	0	main
parun	doc_491521501746_item	3757997	et	0	main
riisenberk	doc_491521501746_item	3757998	et	0	main
selle	doc_491521501746_item	3757999	et	0	main
järgi	doc_491521501746_item	3758000	et	0	main
riisipere	doc_491521501746_item	3758001	et	0	main
tähendavat	doc_491521501746_item	3758002	et	0	main
hiigla	doc_491521501746_item	3758003	et	0	main
mägi	doc_491521501746_item	3758004	et	0	main
tõlkes	doc_491521501746_item	3758005	et	0	main
rkm	doc_491521501746_item	3758006	et	0	main
ii	doc_491521501746_item	3758007	et	0	main
433	doc_491521501746_item	3758008	et	0	main
218	doc_491521501746_item	3758009	et	0	main
1	doc_491521501746_item	3758010	et	0	main
nissi	doc_491521501746_item	3758011	et	0	main
turba	doc_491521501746_item	3758012	et	0	main
al	doc_491521501746_item	3758013	et	0	main
tuuli	doc_491521501746_item	3758014	et	0	main
otsus	doc_491521501746_item	3758015	et	0	main
helmi	doc_491521501746_item	3758016	et	0	main
veeroja	doc_491521501746_item	3758017	et	0	main
s	doc_491521501746_item	3758018	et	0	main
1921	doc_491521501746_item	3758019	et	0	main
a	doc_491521501746_item	3758020	et	0	main
endor	doc_491521501746_item	3758021	et	0	main
veeroja	doc_491521501746_item	3758022	et	0	main
s	doc_491521501746_item	3758023	et	0	main
1914	doc_491521501746_item	3758024	et	0	main
a	doc_491521501746_item	3758025	et	0	main
1990	doc_491521501746_item	3758026	et	0	main
5	doc_491521501746_item	3758027	et	0	main
peatükk	doc_491521501746_item	3758028	et	0	main
kokkuvõte	doc_491521501746_item	3758029	et	0	main
päevik	doc_534729444684_item	3758030	et	0	main
180806	doc_534729444684_item	3758031	et	0	main
täna	doc_534729444684_item	3758032	et	0	main
mul	doc_534729444684_item	3758033	et	0	main
oli	doc_534729444684_item	3758034	et	0	main
veel	doc_534729444684_item	3758035	et	0	main
kord	doc_534729444684_item	3758036	et	0	main
üks	doc_534729444684_item	3758037	et	0	main
eksam	doc_534729444684_item	3758038	et	0	main
kell	doc_534729444684_item	3758039	et	0	main
kaheksa	doc_534729444684_item	3758040	et	0	main
ma	doc_534729444684_item	3758041	et	0	main
tõusin	doc_534729444684_item	3758042	et	0	main
üles	doc_534729444684_item	3758043	et	0	main
ja	doc_534729444684_item	3758044	et	0	main
keetsin	doc_534729444684_item	3758045	et	0	main
kohvi	doc_534729444684_item	3758046	et	0	main
siis	doc_534729444684_item	3758047	et	0	main
ma	doc_534729444684_item	3758048	et	0	main
lugesin	doc_534729444684_item	3758049	et	0	main
omas	doc_534729444684_item	3758050	et	0	main
märkustes	doc_534729444684_item	3758051	et	0	main
kell	doc_534729444684_item	3758052	et	0	main
pool	doc_534729444684_item	3758053	et	0	main
kümme	doc_534729444684_item	3758054	et	0	main
ma	doc_534729444684_item	3758055	et	0	main
käin	doc_534729444684_item	3758056	et	0	main
duši	doc_534729444684_item	3758057	et	0	main
all	doc_534729444684_item	3758058	et	0	main
ja	doc_534729444684_item	3758059	et	0	main
pärast	doc_534729444684_item	3758060	et	0	main
ma	doc_534729444684_item	3758061	et	0	main
läksin	doc_534729444684_item	3758062	et	0	main
marega	doc_534729444684_item	3758063	et	0	main
läbi	doc_534729444684_item	3758064	et	0	main
pargi	doc_534729444684_item	3758065	et	0	main
siis	doc_534729444684_item	3758066	et	0	main
ma	doc_534729444684_item	3758067	et	0	main
ostsin	doc_534729444684_item	3758068	et	0	main
üks	doc_534729444684_item	3758069	et	0	main
kohvi	doc_534729444684_item	3758070	et	0	main
ja	doc_534729444684_item	3758071	et	0	main
käin	doc_534729444684_item	3758072	et	0	main
instituudisse	doc_534729444684_item	3758073	et	0	main
eksam	doc_534729444684_item	3758074	et	0	main
hakkasin	doc_534729444684_item	3758075	et	0	main
umbes	doc_534729444684_item	3758076	et	0	main
kell	doc_534729444684_item	3758077	et	0	main
üksteist	doc_534729444684_item	3758078	et	0	main
ja	doc_534729444684_item	3758079	et	0	main
kestis	doc_534729444684_item	3758080	et	0	main
kuni	doc_534729444684_item	3758081	et	0	main
kella	doc_534729444684_item	3758082	et	0	main
poole	doc_534729444684_item	3758083	et	0	main
kaheteistkümneni	doc_534729444684_item	3758084	et	0	main
ma	doc_534729444684_item	3758085	et	0	main
sain	doc_534729444684_item	3758086	et	0	main
üks	doc_534729444684_item	3758087	et	0	main
a	doc_534729444684_item	3758088	et	0	main
siis	doc_534729444684_item	3758089	et	0	main
ma	doc_534729444684_item	3758090	et	0	main
sain	doc_534729444684_item	3758091	et	0	main
kokku	doc_534729444684_item	3758092	et	0	main
oma	doc_534729444684_item	3758093	et	0	main
parima	doc_534729444684_item	3758094	et	0	main
sõpraga	doc_534729444684_item	3758095	et	0	main
ja	doc_534729444684_item	3758096	et	0	main
me	doc_534729444684_item	3758097	et	0	main
läksime	doc_534729444684_item	3758098	et	0	main
jooma	doc_534729444684_item	3758099	et	0	main
kohvi	doc_534729444684_item	3758100	et	0	main
moskvasse	doc_534729444684_item	3758101	et	0	main
pärast	doc_534729444684_item	3758102	et	0	main
ma	doc_534729444684_item	3758103	et	0	main
tahtsin	doc_534729444684_item	3758104	et	0	main
tegema	doc_534729444684_item	3758105	et	0	main
lõunauinakut	doc_534729444684_item	3758106	et	0	main
aga	doc_534729444684_item	3758107	et	0	main
ma	doc_534729444684_item	3758108	et	0	main
jõin	doc_534729444684_item	3758109	et	0	main
liiga	doc_534729444684_item	3758110	et	0	main
palju	doc_534729444684_item	3758111	et	0	main
kohvi	doc_534729444684_item	3758112	et	0	main
selle	doc_534729444684_item	3758113	et	0	main
pärast	doc_534729444684_item	3758114	et	0	main
ma	doc_534729444684_item	3758115	et	0	main
koristasin	doc_534729444684_item	3758116	et	0	main
oma	doc_534729444684_item	3758117	et	0	main
toa	doc_534729444684_item	3758118	et	0	main
pärastlõunnal	doc_534729444684_item	3758119	et	0	main
kell	doc_534729444684_item	3758120	et	0	main
viis	doc_534729444684_item	3758121	et	0	main
ma	doc_534729444684_item	3758122	et	0	main
jooksin	doc_534729444684_item	3758123	et	0	main
pool	doc_534729444684_item	3758124	et	0	main
tundi	doc_534729444684_item	3758125	et	0	main
umbes	doc_534729444684_item	3758126	et	0	main
kell	doc_534729444684_item	3758127	et	0	main
kuus	doc_534729444684_item	3758128	et	0	main
ma	doc_534729444684_item	3758129	et	0	main
jalutasin	doc_534729444684_item	3758130	et	0	main
marega	doc_534729444684_item	3758131	et	0	main
metsas	doc_534729444684_item	3758132	et	0	main
me	doc_534729444684_item	3758133	et	0	main
tegime	doc_534729444684_item	3758134	et	0	main
kauget	doc_534729444684_item	3758135	et	0	main
jalutuskäiku	doc_534729444684_item	3758136	et	0	main
see	doc_534729444684_item	3758137	et	0	main
kests	doc_534729444684_item	3758138	et	0	main
pea	doc_534729444684_item	3758139	et	0	main
kaks	doc_534729444684_item	3758140	et	0	main
tundi	doc_534729444684_item	3758141	et	0	main
õhtul	doc_534729444684_item	3758142	et	0	main
mare	doc_534729444684_item	3758143	et	0	main
ja	doc_534729444684_item	3758144	et	0	main
mina	doc_534729444684_item	3758145	et	0	main
läksime	doc_534729444684_item	3758146	et	0	main
sööma	doc_534729444684_item	3758147	et	0	main
india	doc_534729444684_item	3758148	et	0	main
restoranis	doc_534729444684_item	3758149	et	0	main
pärast	doc_534729444684_item	3758150	et	0	main
me	doc_534729444684_item	3758151	et	0	main
vahtisime	doc_534729444684_item	3758152	et	0	main
filmi	doc_534729444684_item	3758153	et	0	main
pärast	doc_534729444684_item	3758154	et	0	main
filmi	doc_534729444684_item	3758155	et	0	main
ma	doc_534729444684_item	3758156	et	0	main
olin	doc_534729444684_item	3758157	et	0	main
väga	doc_534729444684_item	3758158	et	0	main
väsinud	doc_534729444684_item	3758159	et	0	main
ja	doc_534729444684_item	3758160	et	0	main
magasin	doc_534729444684_item	3758161	et	0	main
jääma	doc_534729444684_item	3758162	et	0	main
vastus	doc_284706151130_item	3758163	et	0	main
küsimusele	doc_284706151130_item	3758164	et	0	main
1	doc_284706151130_item	3758165	et	0	main
1	doc_284706151130_item	3758166	et	0	main
töökohas	doc_284706151130_item	3758167	et	0	main
peab	doc_284706151130_item	3758168	et	0	main
rohkem	doc_284706151130_item	3758169	et	0	main
kasutama	doc_284706151130_item	3758170	et	0	main
päevavalgust	doc_284706151130_item	3758171	et	0	main
2	doc_284706151130_item	3758172	et	0	main
parem	doc_284706151130_item	3758173	et	0	main
kui	doc_284706151130_item	3758174	et	0	main
seinad	doc_284706151130_item	3758175	et	0	main
ja	doc_284706151130_item	3758176	et	0	main
laed	doc_284706151130_item	3758177	et	0	main
on	doc_284706151130_item	3758178	et	0	main
heledates	doc_284706151130_item	3758179	et	0	main
värvitoonides	doc_284706151130_item	3758180	et	0	main
3	doc_284706151130_item	3758181	et	0	main
vältida	doc_284706151130_item	3758182	et	0	main
nägemisväljas	doc_284706151130_item	3758183	et	0	main
suuri	doc_284706151130_item	3758184	et	0	main
erinevusi	doc_284706151130_item	3758185	et	0	main
töökoha	doc_284706151130_item	3758186	et	0	main
valgustamisel	doc_284706151130_item	3758187	et	0	main
4	doc_284706151130_item	3758188	et	0	main
on	doc_284706151130_item	3758189	et	0	main
vaja	doc_284706151130_item	3758190	et	0	main
valgustada	doc_284706151130_item	3758191	et	0	main
kõik	doc_284706151130_item	3758192	et	0	main
kohad	doc_284706151130_item	3758193	et	0	main
kus	doc_284706151130_item	3758194	et	0	main
võivad	doc_284706151130_item	3758195	et	0	main
viibida	doc_284706151130_item	3758196	et	0	main
inimesed	doc_284706151130_item	3758197	et	0	main
5	doc_284706151130_item	3758198	et	0	main
täpsust	doc_284706151130_item	3758199	et	0	main
nõudvak	doc_284706151130_item	3758200	et	0	main
tööks	doc_284706151130_item	3758201	et	0	main
parem	doc_284706151130_item	3758202	et	0	main
sobib	doc_284706151130_item	3758203	et	0	main
kohtvalgustus	doc_284706151130_item	3758204	et	0	main
6	doc_284706151130_item	3758205	et	0	main
paigutada	doc_284706151130_item	3758206	et	0	main
valgusallikad	doc_284706151130_item	3758207	et	0	main
ümber	doc_284706151130_item	3758208	et	0	main
või	doc_284706151130_item	3758209	et	0	main
panna	doc_284706151130_item	3758210	et	0	main
nendele	doc_284706151130_item	3758211	et	0	main
katted	doc_284706151130_item	3758212	et	0	main
et	doc_284706151130_item	3758213	et	0	main
eemaldada	doc_284706151130_item	3758214	et	0	main
pimestavat	doc_284706151130_item	3758215	et	0	main
valgust	doc_284706151130_item	3758216	et	0	main
2	doc_284706151130_item	3758217	et	0	main
1	doc_284706151130_item	3758218	et	0	main
kindlustada	doc_284706151130_item	3758219	et	0	main
sobiva	doc_284706151130_item	3758220	et	0	main
istekoha	doc_284706151130_item	3758221	et	0	main
kõrguse	doc_284706151130_item	3758222	et	0	main
2	doc_284706151130_item	3758223	et	0	main
kasutada	doc_284706151130_item	3758224	et	0	main
sellist	doc_284706151130_item	3758225	et	0	main
arvutitöökohta	doc_284706151130_item	3758226	et	0	main
mida	doc_284706151130_item	3758227	et	0	main
töötajad	doc_284706151130_item	3758228	et	0	main
saavad	doc_284706151130_item	3758229	et	0	main
enda	doc_284706151130_item	3758230	et	0	main
järgi	doc_284706151130_item	3758231	et	0	main
kohandada	doc_284706151130_item	3758232	et	0	main
3	doc_284706151130_item	3758233	et	0	main
ramatu	doc_284706151130_item	3758234	et	0	main
nimi	doc_284706151130_item	3758235	et	0	main
ergonoomilised	doc_284706151130_item	3758236	et	0	main
soovitused	doc_284706151130_item	3758237	et	0	main
lühitutvustus	doc_284706151130_item	3758238	et	0	main
selle	doc_284706151130_item	3758239	et	0	main
128	doc_284706151130_item	3758240	et	0	main
ergonoomilisest	doc_284706151130_item	3758241	et	0	main
soovitusest	doc_284706151130_item	3758242	et	0	main
koosneva	doc_284706151130_item	3758243	et	0	main
väljaande	doc_284706151130_item	3758244	et	0	main
eesmärgiks	doc_284706151130_item	3758245	et	0	main
on	doc_284706151130_item	3758246	et	0	main
anda	doc_284706151130_item	3758247	et	0	main
abi	doc_284706151130_item	3758248	et	0	main
ohutuse	doc_284706151130_item	3758249	et	0	main
tervise	doc_284706151130_item	3758250	et	0	main
ja	doc_284706151130_item	3758251	et	0	main
töötingimuste	doc_284706151130_item	3758252	et	0	main
parandamiseks	doc_284706151130_item	3758253	et	0	main
seen	doc_284706151130_item	3758254	et	0	main
on	doc_284706151130_item	3758255	et	0	main
lihtsaid	doc_284706151130_item	3758256	et	0	main
ja	doc_284706151130_item	3758257	et	0	main
odavaid	doc_284706151130_item	3758258	et	0	main
lahendusi	doc_284706151130_item	3758259	et	0	main
4	doc_284706151130_item	3758260	et	0	main
1	doc_284706151130_item	3758261	et	0	main
väike	doc_284706151130_item	3758262	et	0	main
teejuht	doc_284706151130_item	3758263	et	0	main
ergonoomika-	doc_284706151130_item	3758264	et	0	main
ja	doc_284706151130_item	3758265	et	0	main
ohutusalase	doc_284706151130_item	3758266	et	0	main
teabe	doc_284706151130_item	3758267	et	0	main
otsimiseks	doc_284706151130_item	3758268	et	0	main
internetis	doc_284706151130_item	3758269	et	0	main
virve	doc_284706151130_item	3758270	et	0	main
siirak	doc_284706151130_item	3758271	et	0	main
wwwtturaamatee	doc_284706151130_item	3758272	et	0	main
leidsin	doc_284706151130_item	3758273	et	0	main
wwwnetiee	doc_284706151130_item	3758274	et	0	main
2	doc_284706151130_item	3758275	et	0	main
töökoha	doc_284706151130_item	3758276	et	0	main
ergonoomika	doc_284706151130_item	3758277	et	0	main
eva-maria	doc_284706151130_item	3758278	et	0	main
reimers	doc_284706151130_item	3758279	et	0	main
wwwsekretaree160102prd	doc_284706151130_item	3758280	et	0	main
wwwnetiee	doc_284706151130_item	3758281	et	0	main
3	doc_284706151130_item	3758282	et	0	main
kaasaegse	doc_284706151130_item	3758283	et	0	main
ergonoomika	doc_284706151130_item	3758284	et	0	main
alused	doc_284706151130_item	3758285	et	0	main
ülo	doc_284706151130_item	3758286	et	0	main
kristjuhan	doc_284706151130_item	3758287	et	0	main
wwwparnueeraulpageergo	doc_284706151130_item	3758288	et	0	main
wwwnetiee	doc_284706151130_item	3758289	et	0	main
5	doc_284706151130_item	3758290	et	0	main
1	doc_284706151130_item	3758291	et	0	main
silmade	doc_284706151130_item	3758292	et	0	main
väsimist	doc_284706151130_item	3758293	et	0	main
2	doc_284706151130_item	3758294	et	0	main
väsitab	doc_284706151130_item	3758295	et	0	main
lihaseid	doc_284706151130_item	3758296	et	0	main
selja	doc_284706151130_item	3758297	et	0	main
ja	doc_284706151130_item	3758298	et	0	main
turja	doc_284706151130_item	3758299	et	0	main
värvivalikul	doc_284706151130_item	3758300	et	0	main
tuleb	doc_284706151130_item	3758301	et	0	main
arvestada	doc_284706151130_item	3758302	et	0	main
töötajate	doc_284706151130_item	3758303	et	0	main
vanuse	doc_284706151130_item	3758304	et	0	main
ja	doc_284706151130_item	3758305	et	0	main
sooga	doc_284706151130_item	3758306	et	0	main
meestele	doc_284706151130_item	3758307	et	0	main
üldiselt	doc_284706151130_item	3758308	et	0	main
ei	doc_284706151130_item	3758309	et	0	main
meeldi	doc_284706151130_item	3758310	et	0	main
roosad	doc_284706151130_item	3758311	et	0	main
toad	doc_284706151130_item	3758312	et	0	main
samas	doc_284706151130_item	3758313	et	0	main
taluvad	doc_284706151130_item	3758314	et	0	main
nad	doc_284706151130_item	3758315	et	0	main
kinnist	doc_284706151130_item	3758316	et	0	main
ruumi	doc_284706151130_item	3758317	et	0	main
paremini	doc_284706151130_item	3758318	et	0	main
kui	doc_284706151130_item	3758319	et	0	main
naised	doc_284706151130_item	3758320	et	0	main
igasugune	doc_284706151130_item	3758321	et	0	main
liialdus	doc_284706151130_item	3758322	et	0	main
on	doc_284706151130_item	3758323	et	0	main
halb	doc_284706151130_item	3758324	et	0	main
oranž	doc_284706151130_item	3758325	et	0	main
punane	doc_284706151130_item	3758326	et	0	main
kollane	doc_284706151130_item	3758327	et	0	main
erklilla	doc_284706151130_item	3758328	et	0	main
loovad	doc_284706151130_item	3758329	et	0	main
küll	doc_284706151130_item	3758330	et	0	main
lõbusat	doc_284706151130_item	3758331	et	0	main
meeleolu	doc_284706151130_item	3758332	et	0	main
ja	doc_284706151130_item	3758333	et	0	main
meeldivad	doc_284706151130_item	3758334	et	0	main
noortele	doc_284706151130_item	3758335	et	0	main
aga	doc_284706151130_item	3758336	et	0	main
häirivad	doc_284706151130_item	3758337	et	0	main
pikaajalist	doc_284706151130_item	3758338	et	0	main
keskendumist	doc_284706151130_item	3758339	et	0	main
noorte	doc_284706151130_item	3758340	et	0	main
värvieelistused	doc_284706151130_item	3758341	et	0	main
on	doc_284706151130_item	3758342	et	0	main
alati	doc_284706151130_item	3758343	et	0	main
särtsakamad	doc_284706151130_item	3758344	et	0	main
ja	doc_284706151130_item	3758345	et	0	main
tugevamad	doc_284706151130_item	3758346	et	0	main
ning	doc_284706151130_item	3758347	et	0	main
võivad	doc_284706151130_item	3758348	et	0	main
nii	doc_284706151130_item	3758349	et	0	main
mõnegi	doc_284706151130_item	3758350	et	0	main
eakama	doc_284706151130_item	3758351	et	0	main
hüsteeriasse	doc_284706151130_item	3758352	et	0	main
ajada	doc_284706151130_item	3758353	et	0	main
6	doc_284706151130_item	3758354	et	0	main
52	doc_284706151130_item	3758355	et	0	main
punkti	doc_284706151130_item	3758356	et	0	main
7	doc_284706151130_item	3758357	et	0	main
minu	doc_284706151130_item	3758358	et	0	main
stressisoodumus	doc_284706151130_item	3758359	et	0	main
üsna	doc_284706151130_item	3758360	et	0	main
suur	doc_284706151130_item	3758361	et	0	main
võtke	doc_284706151130_item	3758362	et	0	main
kohe	doc_284706151130_item	3758363	et	0	main
kasutusele	doc_284706151130_item	3758364	et	0	main
psüühilise	doc_284706151130_item	3758365	et	0	main
eneseregulatsiooni	doc_284706151130_item	3758366	et	0	main
võtted	doc_284706151130_item	3758367	et	0	main
alustades	doc_284706151130_item	3758368	et	0	main
autogeensest	doc_284706151130_item	3758369	et	0	main
treeningust	doc_284706151130_item	3758370	et	0	main
unustada	doc_284706151130_item	3758371	et	0	main
ei	doc_284706151130_item	3758372	et	0	main
maksa	doc_284706151130_item	3758373	et	0	main
ka	doc_284706151130_item	3758374	et	0	main
füüsise	doc_284706151130_item	3758375	et	0	main
tugevdamist	doc_284706151130_item	3758376	et	0	main
8	doc_284706151130_item	3758377	et	0	main
praktiline	doc_284706151130_item	3758378	et	0	main
arvutikasutaja	doc_284706151130_item	3758379	et	0	main
arvutimaailm	doc_284706151130_item	3758380	et	0	main
kiri	doc_600559928986_item	3758381	et	0	main
kirjuta	doc_600559928986_item	3758382	et	0	main
oma	doc_600559928986_item	3758383	et	0	main
eestlasest	doc_600559928986_item	3758384	et	0	main
sõbrale	doc_600559928986_item	3758385	et	0	main
et	doc_600559928986_item	3758386	et	0	main
käid	doc_600559928986_item	3758387	et	0	main
praegu	doc_600559928986_item	3758388	et	0	main
kursustel	doc_600559928986_item	3758389	et	0	main
kirjuta	doc_600559928986_item	3758390	et	0	main
mida	doc_600559928986_item	3758391	et	0	main
sa	doc_600559928986_item	3758392	et	0	main
kursustel	doc_600559928986_item	3758393	et	0	main
õpid	doc_600559928986_item	3758394	et	0	main
ja	doc_600559928986_item	3758395	et	0	main
et	doc_600559928986_item	3758396	et	0	main
varsti	doc_600559928986_item	3758397	et	0	main
lähete	doc_600559928986_item	3758398	et	0	main
praktikale	doc_600559928986_item	3758399	et	0	main
kirjuta	doc_600559928986_item	3758400	et	0	main
kuhu	doc_600559928986_item	3758401	et	0	main
sa	doc_600559928986_item	3758402	et	0	main
praktikale	doc_600559928986_item	3758403	et	0	main
lähed	doc_600559928986_item	3758404	et	0	main
mis	doc_600559928986_item	3758405	et	0	main
firma	doc_600559928986_item	3758406	et	0	main
see	doc_600559928986_item	3758407	et	0	main
on	doc_600559928986_item	3758408	et	0	main
mida	doc_600559928986_item	3758409	et	0	main
sa	doc_600559928986_item	3758410	et	0	main
seal	doc_600559928986_item	3758411	et	0	main
tegema	doc_600559928986_item	3758412	et	0	main
hakkad	doc_600559928986_item	3758413	et	0	main
tere	doc_600559928986_item	3758414	et	0	main
kallis	doc_600559928986_item	3758415	et	0	main
erika	doc_600559928986_item	3758416	et	0	main
kaks	doc_600559928986_item	3758417	et	0	main
nädalat	doc_600559928986_item	3758418	et	0	main
tagasi	doc_600559928986_item	3758419	et	0	main
ma	doc_600559928986_item	3758420	et	0	main
sain	doc_600559928986_item	3758421	et	0	main
sinu	doc_600559928986_item	3758422	et	0	main
kirja	doc_600559928986_item	3758423	et	0	main
tänan	doc_600559928986_item	3758424	et	0	main
sulle	doc_600559928986_item	3758425	et	0	main
vabanda	doc_600559928986_item	3758426	et	0	main
et	doc_600559928986_item	3758427	et	0	main
ma	doc_600559928986_item	3758428	et	0	main
ei	doc_600559928986_item	3758429	et	0	main
vastanud	doc_600559928986_item	3758430	et	0	main
varem	doc_600559928986_item	3758431	et	0	main
mul	doc_600559928986_item	3758432	et	0	main
ei	doc_600559928986_item	3758433	et	0	main
olnud	doc_600559928986_item	3758434	et	0	main
aega	doc_600559928986_item	3758435	et	0	main
ma	doc_600559928986_item	3758436	et	0	main
käin	doc_600559928986_item	3758437	et	0	main
praegu	doc_600559928986_item	3758438	et	0	main
kursusel	doc_600559928986_item	3758439	et	0	main
klienditeenindaja	doc_600559928986_item	3758440	et	0	main
me	doc_600559928986_item	3758441	et	0	main
õpime	doc_600559928986_item	3758442	et	0	main
siin	doc_600559928986_item	3758443	et	0	main
palju	doc_600559928986_item	3758444	et	0	main
huvitavaid	doc_600559928986_item	3758445	et	0	main
õppeained	doc_600559928986_item	3758446	et	0	main
see	doc_600559928986_item	3758447	et	0	main
on	doc_600559928986_item	3758448	et	0	main
arvutiõpetus	doc_600559928986_item	3758449	et	0	main
psühholoogia	doc_600559928986_item	3758450	et	0	main
asjaajamine	doc_600559928986_item	3758451	et	0	main
stiiliõpetus	doc_600559928986_item	3758452	et	0	main
ettevõtluse	doc_600559928986_item	3758453	et	0	main
alused	doc_600559928986_item	3758454	et	0	main
turunduse	doc_600559928986_item	3758455	et	0	main
ja	doc_600559928986_item	3758456	et	0	main
reklaami	doc_600559928986_item	3758457	et	0	main
alused	doc_600559928986_item	3758458	et	0	main
tööseadusandluse	doc_600559928986_item	3758459	et	0	main
alused	doc_600559928986_item	3758460	et	0	main
etikett	doc_600559928986_item	3758461	et	0	main
eesti	doc_600559928986_item	3758462	et	0	main
keel	doc_600559928986_item	3758463	et	0	main
varsti	doc_600559928986_item	3758464	et	0	main
ma	doc_600559928986_item	3758465	et	0	main
lõpetasin	doc_600559928986_item	3758466	et	0	main
teoreetilise	doc_600559928986_item	3758467	et	0	main
kurs	doc_600559928986_item	3758468	et	0	main
ja	doc_600559928986_item	3758469	et	0	main
lähen	doc_600559928986_item	3758470	et	0	main
praktikale	doc_600559928986_item	3758471	et	0	main
ma	doc_600559928986_item	3758472	et	0	main
lähen	doc_600559928986_item	3758473	et	0	main
linnaraamatukogusse	doc_600559928986_item	3758474	et	0	main
ja	doc_600559928986_item	3758475	et	0	main
hakkan	doc_600559928986_item	3758476	et	0	main
raamatukoguhoidjana	doc_600559928986_item	3758477	et	0	main
töötama	doc_600559928986_item	3758478	et	0	main
arvan	doc_600559928986_item	3758479	et	0	main
et	doc_600559928986_item	3758480	et	0	main
see	doc_600559928986_item	3758481	et	0	main
on	doc_600559928986_item	3758482	et	0	main
huvitav	doc_600559928986_item	3758483	et	0	main
töö	doc_600559928986_item	3758484	et	0	main
ma	doc_600559928986_item	3758485	et	0	main
kirjutan	doc_600559928986_item	3758486	et	0	main
sulle	doc_600559928986_item	3758487	et	0	main
natuke	doc_600559928986_item	3758488	et	0	main
hiljem	doc_600559928986_item	3758489	et	0	main
kuidas	doc_600559928986_item	3758490	et	0	main
minul	doc_600559928986_item	3758491	et	0	main
läheb	doc_600559928986_item	3758492	et	0	main
kirjuta	doc_600559928986_item	3758493	et	0	main
mulle	doc_600559928986_item	3758494	et	0	main
ka	doc_600559928986_item	3758495	et	0	main
kuidas	doc_600559928986_item	3758496	et	0	main
sa	doc_600559928986_item	3758497	et	0	main
elad	doc_600559928986_item	3758498	et	0	main
mis	doc_600559928986_item	3758499	et	0	main
uudist	doc_600559928986_item	3758500	et	0	main
sul	doc_600559928986_item	3758501	et	0	main
ma	doc_600559928986_item	3758502	et	0	main
loodan	doc_600559928986_item	3758503	et	0	main
et	doc_600559928986_item	3758504	et	0	main
sina	doc_600559928986_item	3758505	et	0	main
tuled	doc_600559928986_item	3758506	et	0	main
meie	doc_600559928986_item	3758507	et	0	main
juurde	doc_600559928986_item	3758508	et	0	main
jaanuaris	doc_600559928986_item	3758509	et	0	main
nägemiseni	doc_600559928986_item	3758510	et	0	main
eesnimi	doc_600559928986_item	3758511	et	0	main
kokkuvõte	doc_541159270917_item	3758850	et	0	cKUAfXynZ
lt	doc_541159270917_item	3758851	et	0	cKUAfXynZ
font	doc_541159270917_item	3758852	et	0	cKUAfXynZ
definitions	doc_541159270917_item	3758853	et	0	cKUAfXynZ
font-face	doc_541159270917_item	3758854	et	0	cKUAfXynZ
font-familycambria	doc_541159270917_item	3758855	et	0	cKUAfXynZ
math	doc_541159270917_item	3758856	et	0	cKUAfXynZ
panose-12	doc_541159270917_item	3758857	et	0	cKUAfXynZ
4	doc_541159270917_item	3758858	et	0	cKUAfXynZ
5	doc_541159270917_item	3758859	et	0	cKUAfXynZ
3	doc_541159270917_item	3758860	et	0	cKUAfXynZ
5	doc_541159270917_item	3758861	et	0	cKUAfXynZ
4	doc_541159270917_item	3758862	et	0	cKUAfXynZ
6	doc_541159270917_item	3758863	et	0	cKUAfXynZ
3	doc_541159270917_item	3758864	et	0	cKUAfXynZ
2	doc_541159270917_item	3758865	et	0	cKUAfXynZ
4	doc_541159270917_item	3758866	et	0	cKUAfXynZ
mso-font-charset0	doc_541159270917_item	3758867	et	0	cKUAfXynZ
mso-generic-font-familyroman	doc_541159270917_item	3758868	et	0	cKUAfXynZ
mso-font-pitchvariable	doc_541159270917_item	3758869	et	0	cKUAfXynZ
mso-font-signature1610611985	doc_541159270917_item	3758870	et	0	cKUAfXynZ
1107304683	doc_541159270917_item	3758871	et	0	cKUAfXynZ
0	doc_541159270917_item	3758872	et	0	cKUAfXynZ
0	doc_541159270917_item	3758873	et	0	cKUAfXynZ
159	doc_541159270917_item	3758874	et	0	cKUAfXynZ
0	doc_541159270917_item	3758875	et	0	cKUAfXynZ
style	doc_541159270917_item	3758876	et	0	cKUAfXynZ
definitions	doc_541159270917_item	3758877	et	0	cKUAfXynZ
pmsonormal	doc_541159270917_item	3758878	et	0	cKUAfXynZ
limsonormal	doc_541159270917_item	3758879	et	0	cKUAfXynZ
divmsonormal	doc_541159270917_item	3758880	et	0	cKUAfXynZ
mso-style-unhideno	doc_541159270917_item	3758881	et	0	cKUAfXynZ
mso-style-qformatyes	doc_541159270917_item	3758882	et	0	cKUAfXynZ
mso-style-parent	doc_541159270917_item	3758883	et	0	cKUAfXynZ
margin0cm	doc_541159270917_item	3758884	et	0	cKUAfXynZ
margin-bottom0001pt	doc_541159270917_item	3758885	et	0	cKUAfXynZ
mso-paginationwidow-orphan	doc_541159270917_item	3758886	et	0	cKUAfXynZ
font-size120pt	doc_541159270917_item	3758887	et	0	cKUAfXynZ
font-familytimes	doc_541159270917_item	3758888	et	0	cKUAfXynZ
new	doc_541159270917_item	3758889	et	0	cKUAfXynZ
romanserif	doc_541159270917_item	3758890	et	0	cKUAfXynZ
mso-fareast-font-familytimes	doc_541159270917_item	3758891	et	0	cKUAfXynZ
new	doc_541159270917_item	3758892	et	0	cKUAfXynZ
roman	doc_541159270917_item	3758893	et	0	cKUAfXynZ
mso-ansi-languageet	doc_541159270917_item	3758894	et	0	cKUAfXynZ
mso-fareast-languageet	doc_541159270917_item	3758895	et	0	cKUAfXynZ
msochpdefault	doc_541159270917_item	3758896	et	0	cKUAfXynZ
mso-style-typeexport-only	doc_541159270917_item	3758897	et	0	cKUAfXynZ
mso-default-propsyes	doc_541159270917_item	3758898	et	0	cKUAfXynZ
font-size100pt	doc_541159270917_item	3758899	et	0	cKUAfXynZ
mso-ansi-font-size100pt	doc_541159270917_item	3758900	et	0	cKUAfXynZ
mso-bidi-font-size100pt	doc_541159270917_item	3758901	et	0	cKUAfXynZ
page	doc_541159270917_item	3758902	et	0	cKUAfXynZ
section1	doc_541159270917_item	3758903	et	0	cKUAfXynZ
size5953pt	doc_541159270917_item	3758904	et	0	cKUAfXynZ
8419pt	doc_541159270917_item	3758905	et	0	cKUAfXynZ
margin7085pt	doc_541159270917_item	3758906	et	0	cKUAfXynZ
7085pt	doc_541159270917_item	3758907	et	0	cKUAfXynZ
7085pt	doc_541159270917_item	3758908	et	0	cKUAfXynZ
7085pt	doc_541159270917_item	3758909	et	0	cKUAfXynZ
mso-header-margin360pt	doc_541159270917_item	3758910	et	0	cKUAfXynZ
mso-footer-margin360pt	doc_541159270917_item	3758911	et	0	cKUAfXynZ
mso-paper-source0	doc_541159270917_item	3758912	et	0	cKUAfXynZ
divsection1	doc_541159270917_item	3758913	et	0	cKUAfXynZ
pagesection1	doc_541159270917_item	3758914	et	0	cKUAfXynZ
gt	doc_541159270917_item	3758915	et	0	cKUAfXynZ
maarika	doc_541159270917_item	3758916	et	0	cKUAfXynZ
terali	doc_541159270917_item	3758917	et	0	cKUAfXynZ
magistritöös	doc_541159270917_item	3758918	et	0	cKUAfXynZ
kirjutatakse	doc_541159270917_item	3758919	et	0	cKUAfXynZ
taani	doc_541159270917_item	3758920	et	0	cKUAfXynZ
eestlase	doc_541159270917_item	3758921	et	0	cKUAfXynZ
keelelst	doc_541159270917_item	3758922	et	0	cKUAfXynZ
töös	doc_541159270917_item	3758923	et	0	cKUAfXynZ
keskendutakse	doc_541159270917_item	3758924	et	0	cKUAfXynZ
teise	doc_541159270917_item	3758925	et	0	cKUAfXynZ
maailmasõja	doc_541159270917_item	3758926	et	0	cKUAfXynZ
järel	doc_541159270917_item	3758927	et	0	cKUAfXynZ
taani	doc_541159270917_item	3758928	et	0	cKUAfXynZ
ümberasunud	doc_541159270917_item	3758929	et	0	cKUAfXynZ
eestlaste	doc_541159270917_item	3758930	et	0	cKUAfXynZ
keelele	doc_541159270917_item	3758931	et	0	cKUAfXynZ
autor	doc_541159270917_item	3758932	et	0	cKUAfXynZ
tänab	doc_541159270917_item	3758933	et	0	cKUAfXynZ
kopoenhaaginise	doc_541159270917_item	3758934	et	0	cKUAfXynZ
koondunud	doc_541159270917_item	3758935	et	0	cKUAfXynZ
eestlaskonda	doc_541159270917_item	3758936	et	0	cKUAfXynZ
kes	doc_541159270917_item	3758937	et	0	cKUAfXynZ
oli	doc_541159270917_item	3758938	et	0	cKUAfXynZ
väga	doc_541159270917_item	3758939	et	0	cKUAfXynZ
koostööaldis	doc_541159270917_item	3758940	et	0	cKUAfXynZ
käesolevas	doc_541159270917_item	3758941	et	0	cKUAfXynZ
töös	doc_541159270917_item	3758942	et	0	cKUAfXynZ
sisaldatakse	doc_541159270917_item	3758943	et	0	cKUAfXynZ
eluloo	doc_541159270917_item	3758944	et	0	cKUAfXynZ
mälestusi	doc_541159270917_item	3758945	et	0	cKUAfXynZ
vestlusivadeldakse	doc_541159270917_item	3758946	et	0	cKUAfXynZ
leksikaalseid	doc_541159270917_item	3758947	et	0	cKUAfXynZ
ja	doc_541159270917_item	3758948	et	0	cKUAfXynZ
süntaksilisi	doc_541159270917_item	3758949	et	0	cKUAfXynZ
interfererentsi	doc_541159270917_item	3758950	et	0	cKUAfXynZ
eesti	doc_541159270917_item	3758951	et	0	cKUAfXynZ
keeles	doc_541159270917_item	3758952	et	0	cKUAfXynZ
töös	doc_541159270917_item	3758953	et	0	cKUAfXynZ
antakse	doc_541159270917_item	3758954	et	0	cKUAfXynZ
ülevaade	doc_541159270917_item	3758955	et	0	cKUAfXynZ
kakskeelsuse	doc_541159270917_item	3758956	et	0	cKUAfXynZ
ja	doc_541159270917_item	3758957	et	0	cKUAfXynZ
keelekontaktidele	doc_541159270917_item	3758958	et	0	cKUAfXynZ
räägitakse	doc_541159270917_item	3758959	et	0	cKUAfXynZ
eestlastest	doc_541159270917_item	3758960	et	0	cKUAfXynZ
maailma	doc_541159270917_item	3758961	et	0	cKUAfXynZ
eri	doc_541159270917_item	3758962	et	0	cKUAfXynZ
paigus	doc_541159270917_item	3758963	et	0	cKUAfXynZ
kasutatakse	doc_541159270917_item	3758964	et	0	cKUAfXynZ
demograafiliseid	doc_541159270917_item	3758965	et	0	cKUAfXynZ
tegureid	doc_541159270917_item	3758966	et	0	cKUAfXynZ
autori	doc_541159270917_item	3758967	et	0	cKUAfXynZ
sõnul	doc_541159270917_item	3758968	et	0	cKUAfXynZ
integraantidel	doc_541159270917_item	3758969	et	0	cKUAfXynZ
on	doc_541159270917_item	3758970	et	0	cKUAfXynZ
raske	doc_541159270917_item	3758971	et	0	cKUAfXynZ
otsustada	doc_541159270917_item	3758972	et	0	cKUAfXynZ
mis	doc_541159270917_item	3758973	et	0	cKUAfXynZ
on	doc_541159270917_item	3758974	et	0	cKUAfXynZ
emakeel	doc_541159270917_item	3758975	et	0	cKUAfXynZ
nende	doc_541159270917_item	3758976	et	0	cKUAfXynZ
jaoks	doc_541159270917_item	3758977	et	0	cKUAfXynZ
magistritöös	doc_541159270917_item	3758978	et	0	cKUAfXynZ
tsiteeritakse	doc_541159270917_item	3758979	et	0	cKUAfXynZ
skutnabb	doc_541159270917_item	3758980	et	0	cKUAfXynZ
kangast	doc_541159270917_item	3758981	et	0	cKUAfXynZ
kes	doc_541159270917_item	3758982	et	0	cKUAfXynZ
oli	doc_541159270917_item	3758983	et	0	cKUAfXynZ
esitanud	doc_541159270917_item	3758984	et	0	cKUAfXynZ
emakeelemääratlused	doc_541159270917_item	3758985	et	0	cKUAfXynZ
tema	doc_541159270917_item	3758986	et	0	cKUAfXynZ
järgi	doc_541159270917_item	3758987	et	0	cKUAfXynZ
emakeel	doc_541159270917_item	3758988	et	0	cKUAfXynZ
on	doc_541159270917_item	3758989	et	0	cKUAfXynZ
selline	doc_541159270917_item	3758990	et	0	cKUAfXynZ
keel	doc_541159270917_item	3758991	et	0	cKUAfXynZ
milles	doc_541159270917_item	3758992	et	0	cKUAfXynZ
mõeldakse	doc_541159270917_item	3758993	et	0	cKUAfXynZ
nähakse	doc_541159270917_item	3758994	et	0	cKUAfXynZ
unenägusid	doc_541159270917_item	3758995	et	0	cKUAfXynZ
ja	doc_541159270917_item	3758996	et	0	cKUAfXynZ
loendatakse	doc_541159270917_item	3758997	et	0	cKUAfXynZ
kangase	doc_541159270917_item	3758998	et	0	cKUAfXynZ
seisukohast	doc_541159270917_item	3758999	et	0	cKUAfXynZ
emakeelt	doc_541159270917_item	3759000	et	0	cKUAfXynZ
võib	doc_541159270917_item	3759001	et	0	cKUAfXynZ
määratleda	doc_541159270917_item	3759002	et	0	cKUAfXynZ
ka	doc_541159270917_item	3759003	et	0	cKUAfXynZ
päritolu	doc_541159270917_item	3759004	et	0	cKUAfXynZ
järgi	doc_541159270917_item	3759005	et	0	cKUAfXynZ
selle	doc_541159270917_item	3759006	et	0	cKUAfXynZ
kriteeriumi	doc_541159270917_item	3759007	et	0	cKUAfXynZ
järgi	doc_541159270917_item	3759008	et	0	cKUAfXynZ
emakeel	doc_541159270917_item	3759009	et	0	cKUAfXynZ
on	doc_541159270917_item	3759010	et	0	cKUAfXynZ
esimene	doc_541159270917_item	3759011	et	0	cKUAfXynZ
õpitud	doc_541159270917_item	3759012	et	0	cKUAfXynZ
keel	doc_541159270917_item	3759013	et	0	cKUAfXynZ
emakeele	doc_541159270917_item	3759014	et	0	cKUAfXynZ
määratlemisaspektist	doc_541159270917_item	3759015	et	0	cKUAfXynZ
määrab	doc_541159270917_item	3759016	et	0	cKUAfXynZ
emakeelt	doc_541159270917_item	3759017	et	0	cKUAfXynZ
ka	doc_541159270917_item	3759018	et	0	cKUAfXynZ
keeleoskus	doc_541159270917_item	3759019	et	0	cKUAfXynZ
kasutamissagedus	doc_541159270917_item	3759020	et	0	cKUAfXynZ
eneseidentifitseerimine	doc_541159270917_item	3759021	et	0	cKUAfXynZ
ja	doc_541159270917_item	3759022	et	0	cKUAfXynZ
hoiakud	doc_541159270917_item	3759023	et	0	cKUAfXynZ
sellese	doc_541159270917_item	3759024	et	0	cKUAfXynZ
keelde	doc_541159270917_item	3759025	et	0	cKUAfXynZ
marika	doc_541159270917_item	3759026	et	0	cKUAfXynZ
terali	doc_541159270917_item	3759027	et	0	cKUAfXynZ
sõnul	doc_541159270917_item	3759028	et	0	cKUAfXynZ
on	doc_541159270917_item	3759029	et	0	cKUAfXynZ
kakseelsus	doc_541159270917_item	3759030	et	0	cKUAfXynZ
keruline	doc_541159270917_item	3759031	et	0	cKUAfXynZ
nähtus	doc_541159270917_item	3759032	et	0	cKUAfXynZ
kakskeelsuse	doc_541159270917_item	3759033	et	0	cKUAfXynZ
uurimisega	doc_541159270917_item	3759034	et	0	cKUAfXynZ
tegelevad	doc_541159270917_item	3759035	et	0	cKUAfXynZ
kontaktlingvistiga	doc_541159270917_item	3759036	et	0	cKUAfXynZ
keele	doc_541159270917_item	3759037	et	0	cKUAfXynZ
ja	doc_541159270917_item	3759038	et	0	cKUAfXynZ
identiteedi	doc_541159270917_item	3759039	et	0	cKUAfXynZ
uurimine	doc_541159270917_item	3759040	et	0	cKUAfXynZ
ja	doc_541159270917_item	3759041	et	0	cKUAfXynZ
kakskeelses	doc_541159270917_item	3759042	et	0	cKUAfXynZ
ühiskonnas	doc_541159270917_item	3759043	et	0	cKUAfXynZ
toimuvate	doc_541159270917_item	3759044	et	0	cKUAfXynZ
protsesside	doc_541159270917_item	3759045	et	0	cKUAfXynZ
uurimine	doc_541159270917_item	3759046	et	0	cKUAfXynZ
magistritöös	doc_541159270917_item	3759047	et	0	cKUAfXynZ
pöörakse	doc_541159270917_item	3759048	et	0	cKUAfXynZ
tähelepanu	doc_541159270917_item	3759049	et	0	cKUAfXynZ
sellele	doc_541159270917_item	3759050	et	0	cKUAfXynZ
et	doc_541159270917_item	3759051	et	0	cKUAfXynZ
on	doc_541159270917_item	3759052	et	0	cKUAfXynZ
olemas	doc_541159270917_item	3759053	et	0	cKUAfXynZ
individuaalne	doc_541159270917_item	3759054	et	0	cKUAfXynZ
ja	doc_541159270917_item	3759055	et	0	cKUAfXynZ
ühiskondlik	doc_541159270917_item	3759056	et	0	cKUAfXynZ
kakskeelsus	doc_541159270917_item	3759057	et	0	cKUAfXynZ
esimene	doc_541159270917_item	3759058	et	0	cKUAfXynZ
on	doc_541159270917_item	3759059	et	0	cKUAfXynZ
bilingvaalsus	doc_541159270917_item	3759060	et	0	cKUAfXynZ
aga	doc_541159270917_item	3759061	et	0	cKUAfXynZ
teine	doc_541159270917_item	3759062	et	0	cKUAfXynZ
bilingualism	doc_541159270917_item	3759063	et	0	cKUAfXynZ
käesolevas	doc_541159270917_item	3759064	et	0	cKUAfXynZ
töös	doc_541159270917_item	3759065	et	0	cKUAfXynZ
uurimisobkjektiks	doc_541159270917_item	3759066	et	0	cKUAfXynZ
on	doc_541159270917_item	3759067	et	0	cKUAfXynZ
diglossia	doc_541159270917_item	3759068	et	0	cKUAfXynZ
diglossiaks	doc_541159270917_item	3759069	et	0	cKUAfXynZ
nimetetakse	doc_541159270917_item	3759070	et	0	cKUAfXynZ
keele	doc_541159270917_item	3759071	et	0	cKUAfXynZ
funktsionaalset	doc_541159270917_item	3759072	et	0	cKUAfXynZ
jaotust	doc_541159270917_item	3759073	et	0	cKUAfXynZ
töös	doc_541159270917_item	3759074	et	0	cKUAfXynZ
räägitakse	doc_541159270917_item	3759075	et	0	cKUAfXynZ
ka	doc_541159270917_item	3759076	et	0	cKUAfXynZ
sellest	doc_541159270917_item	3759077	et	0	cKUAfXynZ
et	doc_541159270917_item	3759078	et	0	cKUAfXynZ
keelekontaktide	doc_541159270917_item	3759079	et	0	cKUAfXynZ
tõttu	doc_541159270917_item	3759080	et	0	cKUAfXynZ
võivad	doc_541159270917_item	3759081	et	0	cKUAfXynZ
tekkida	doc_541159270917_item	3759082	et	0	cKUAfXynZ
pidzinid	doc_541159270917_item	3759083	et	0	cKUAfXynZ
kreoolid	doc_541159270917_item	3759084	et	0	cKUAfXynZ
ja	doc_541159270917_item	3759085	et	0	cKUAfXynZ
segakeeled	doc_541159270917_item	3759086	et	0	cKUAfXynZ
keelemuutuste	doc_541159270917_item	3759087	et	0	cKUAfXynZ
tõttu	doc_541159270917_item	3759088	et	0	cKUAfXynZ
võivad	doc_541159270917_item	3759089	et	0	cKUAfXynZ
tekkida	doc_541159270917_item	3759090	et	0	cKUAfXynZ
koodivahetusm	doc_541159270917_item	3759091	et	0	cKUAfXynZ
interferents	doc_541159270917_item	3759092	et	0	cKUAfXynZ
ja	doc_541159270917_item	3759093	et	0	cKUAfXynZ
laenamine	doc_541159270917_item	3759094	et	0	cKUAfXynZ
laenamise	doc_541159270917_item	3759095	et	0	cKUAfXynZ
all	doc_541159270917_item	3759096	et	0	cKUAfXynZ
mõeldakse	doc_541159270917_item	3759097	et	0	cKUAfXynZ
sõnavara	doc_541159270917_item	3759098	et	0	cKUAfXynZ
laenamist	doc_541159270917_item	3759099	et	0	cKUAfXynZ
ja	doc_541159270917_item	3759100	et	0	cKUAfXynZ
keele	doc_541159270917_item	3759101	et	0	cKUAfXynZ
struktuuri	doc_541159270917_item	3759102	et	0	cKUAfXynZ
laenamist	doc_541159270917_item	3759103	et	0	cKUAfXynZ
koodivahetus	doc_541159270917_item	3759104	et	0	cKUAfXynZ
on	doc_541159270917_item	3759105	et	0	cKUAfXynZ
teadlik	doc_541159270917_item	3759106	et	0	cKUAfXynZ
keelte	doc_541159270917_item	3759107	et	0	cKUAfXynZ
ja	doc_541159270917_item	3759108	et	0	cKUAfXynZ
eesmärgite	doc_541159270917_item	3759109	et	0	cKUAfXynZ
kindel	doc_541159270917_item	3759110	et	0	cKUAfXynZ
vahetus	doc_541159270917_item	3759111	et	0	cKUAfXynZ
interferents	doc_541159270917_item	3759112	et	0	cKUAfXynZ
on	doc_541159270917_item	3759113	et	0	cKUAfXynZ
ühe	doc_541159270917_item	3759114	et	0	cKUAfXynZ
keele	doc_541159270917_item	3759115	et	0	cKUAfXynZ
mõju	doc_541159270917_item	3759116	et	0	cKUAfXynZ
teistele	doc_541159270917_item	3759117	et	0	cKUAfXynZ
autoriga	doc_541159270917_item	3759118	et	0	cKUAfXynZ
rõhutaske	doc_541159270917_item	3759119	et	0	cKUAfXynZ
et	doc_541159270917_item	3759120	et	0	cKUAfXynZ
lapsed	doc_541159270917_item	3759121	et	0	cKUAfXynZ
ja	doc_541159270917_item	3759122	et	0	cKUAfXynZ
täiskasvanud	doc_541159270917_item	3759123	et	0	cKUAfXynZ
inimesed	doc_541159270917_item	3759124	et	0	cKUAfXynZ
omandavad	doc_541159270917_item	3759125	et	0	cKUAfXynZ
keelt	doc_541159270917_item	3759126	et	0	cKUAfXynZ
erinevalt	doc_541159270917_item	3759127	et	0	cKUAfXynZ
autor	doc_541159270917_item	3759128	et	0	cKUAfXynZ
tsiteerib	doc_541159270917_item	3759129	et	0	cKUAfXynZ
scottoni	doc_541159270917_item	3759130	et	0	cKUAfXynZ
kes	doc_541159270917_item	3759131	et	0	cKUAfXynZ
väidab	doc_541159270917_item	3759132	et	0	cKUAfXynZ
et	doc_541159270917_item	3759133	et	0	cKUAfXynZ
lapsed	doc_541159270917_item	3759134	et	0	cKUAfXynZ
omandavad	doc_541159270917_item	3759135	et	0	cKUAfXynZ
keelt	doc_541159270917_item	3759136	et	0	cKUAfXynZ
spontaanselt	doc_541159270917_item	3759137	et	0	cKUAfXynZ
ja	doc_541159270917_item	3759138	et	0	cKUAfXynZ
nendele	doc_541159270917_item	3759139	et	0	cKUAfXynZ
õigesti	doc_541159270917_item	3759140	et	0	cKUAfXynZ
kuulda	doc_541159270917_item	3759141	et	0	cKUAfXynZ
on	doc_541159270917_item	3759142	et	0	cKUAfXynZ
raskem	doc_541159270917_item	3759143	et	0	cKUAfXynZ
kui	doc_541159270917_item	3759144	et	0	cKUAfXynZ
täiskasvanutele	doc_541159270917_item	3759145	et	0	cKUAfXynZ
töös	doc_541159270917_item	3759146	et	0	cKUAfXynZ
pööratakse	doc_541159270917_item	3759147	et	0	cKUAfXynZ
tähelepanu	doc_541159270917_item	3759148	et	0	cKUAfXynZ
ka	doc_541159270917_item	3759149	et	0	cKUAfXynZ
keele	doc_541159270917_item	3759150	et	0	cKUAfXynZ
hääbumisele	doc_541159270917_item	3759151	et	0	cKUAfXynZ
siin	doc_541159270917_item	3759152	et	0	cKUAfXynZ
autor	doc_541159270917_item	3759153	et	0	cKUAfXynZ
tsiteerib	doc_541159270917_item	3759154	et	0	cKUAfXynZ
riionheimot	doc_541159270917_item	3759155	et	0	cKUAfXynZ
kes	doc_541159270917_item	3759156	et	0	cKUAfXynZ
väidab	doc_541159270917_item	3759157	et	0	cKUAfXynZ
et	doc_541159270917_item	3759158	et	0	cKUAfXynZ
esimese	doc_541159270917_item	3759159	et	0	cKUAfXynZ
keele	doc_541159270917_item	3759160	et	0	cKUAfXynZ
hääbumine	doc_541159270917_item	3759161	et	0	cKUAfXynZ
ei	doc_541159270917_item	3759162	et	0	cKUAfXynZ
toimu	doc_541159270917_item	3759163	et	0	cKUAfXynZ
kunagi	doc_541159270917_item	3759164	et	0	cKUAfXynZ
iseenesest	doc_541159270917_item	3759165	et	0	cKUAfXynZ
esimese	doc_541159270917_item	3759166	et	0	cKUAfXynZ
keele	doc_541159270917_item	3759167	et	0	cKUAfXynZ
hääbutamine	doc_541159270917_item	3759168	et	0	cKUAfXynZ
toimub	doc_541159270917_item	3759169	et	0	cKUAfXynZ
selle	doc_541159270917_item	3759170	et	0	cKUAfXynZ
keele	doc_541159270917_item	3759171	et	0	cKUAfXynZ
vähenemisest	doc_541159270917_item	3759172	et	0	cKUAfXynZ
keelehääbumisega	doc_541159270917_item	3759173	et	0	cKUAfXynZ
on	doc_541159270917_item	3759174	et	0	cKUAfXynZ
seotud	doc_541159270917_item	3759175	et	0	cKUAfXynZ
niisugused	doc_541159270917_item	3759176	et	0	cKUAfXynZ
lingvistimuutused	doc_541159270917_item	3759177	et	0	cKUAfXynZ
nagu	doc_541159270917_item	3759178	et	0	cKUAfXynZ
keele	doc_541159270917_item	3759179	et	0	cKUAfXynZ
lihtsustumine	doc_541159270917_item	3759180	et	0	cKUAfXynZ
käesolevas	doc_541159270917_item	3759181	et	0	cKUAfXynZ
magistritöös	doc_541159270917_item	3759182	et	0	cKUAfXynZ
tsiteeritakse	doc_541159270917_item	3759183	et	0	cKUAfXynZ
ka	doc_541159270917_item	3759184	et	0	cKUAfXynZ
arnbergi	doc_541159270917_item	3759185	et	0	cKUAfXynZ
grosejani	doc_541159270917_item	3759186	et	0	cKUAfXynZ
m	doc_541159270917_item	3759187	et	0	cKUAfXynZ
kokko	doc_541159270917_item	3759188	et	0	cKUAfXynZ
jt	doc_541159270917_item	3759189	et	0	cKUAfXynZ
\.


--
-- Data for Name: documents; Type: TABLE DATA; Schema: public; Owner: evkk
--

COPY documents ("DocumentID", title, corpus, "language") FROM stdin;
doc_100636852915_item	 Arvamus	main	et
doc_100636852916_item	 Arvamus	main	et
doc_100636852917_item	 Arvamus	main	et
doc_1010138197_item	Eksamitöö	main	et
doc_1010138198_item	Test 	main	et
doc_1010138199_item	Eksamitöö	main	et
doc_1010138200_item	Eksamitöö	main	et
doc_109979842709_item	 kontrolltöö	main	et
doc_120968879137_item	Essee	main	et
doc_120968879138_item	Essee	main	et
doc_120968879139_item	Essee	main	et
doc_120968879140_item	Essee	main	et
doc_120968879141_item	Essee	main	et
doc_120968879142_item	Essee	main	et
doc_120968879143_item	Essee	main	et
doc_120968879144_item	Essee	main	et
doc_120968879145_item	Essee	main	et
doc_120968879147_item	Essee	main	et
doc_120968879148_item	Essee	main	et
doc_120968879149_item	Essee	main	et
doc_120968879151_item	Essee	main	et
doc_120968879153_item	Essee	main	et
doc_120968879155_item	Essee	main	et
doc_122714475542_item	Asjad, ilma milleta ei saa elada	main	et
doc_122714475543_item	Asjad, ilma milleta inimesed ei saaks elada	main	et
doc_122714475544_item	Asjad, ilma milleta inimesed ei saaks elada	main	et
doc_122714475545_item	Asjad, ilma milleta inimsed ei saaks elada	main	et
doc_122714475546_item	Ilma milleta ei saaks inimesed elada	main	et
doc_124643816973_item	Kontrolltöö Eesti kultuuriloost	main	et
doc_124643816974_item	Eesti kultuuriloo kontrolltöö	main	et
doc_12501346824_item	 Vastus küsimusele	main	et
doc_125394962863_item	kontrolltöö	main	et
doc_125394962864_item	kontrolltöö	main	et
doc_125394962865_item	kontrolltöö	main	et
doc_13389385120_item	Referaat	main	et
doc_134822946562_item	vastus küsimusele	main	et
doc_142308885626_item	kontrolltöö	main	et
doc_142308885627_item	kontrolltöö	main	et
doc_15203423346_item	 Arvamus	main	et
doc_15203423347_item	 Kirjeldus	main	et
doc_15203423348_item	 Kirjeldus  	main	et
doc_15203423351_item	 Arvamus	main	et
doc_15203423352_item	Kirjeldus	main	et
doc_153483594920_item	Väited kuritegevuse kohta	main	et
doc_153483594921_item	Direktori kõne	main	et
doc_153483594922_item	Kaebus	main	et
doc_153483594923_item	Seletuskiri	main	et
doc_153483594924_item	Kas lapsed peavad suvel töötama?	main	et
doc_153483594925_item	Millest sõltub eluiga?	main	et
doc_153483594926_item	Kontrolltöö	main	et
doc_153483594927_item	Ilma milleta ei saaks inimesed elada?	main	et
doc_154182424413_item	Vastus küsimusele	main	et
doc_154182424414_item	Vastus küsimusele	main	et
doc_154182424415_item	 Vastus küsimusele	main	et
doc_154182424416_item	 Vastus küsimusele	main	et
doc_154182424417_item	 Vastus küsimusele	main	et
doc_158183956827_item	kontrolltöö	main	et
doc_158183956828_item	kontrolltöö	main	et
doc_158183956829_item	kontrolltöö	main	et
doc_167143726882_item	Vastus küsimusele	main	et
doc_170347281009_item	Eksamitöö	main	et
doc_170347281010_item	Eksamitöö	main	et
doc_170347281011_item	Eksamitöö	main	et
doc_170347281012_item	Eksamitöö	main	et
doc_170347281013_item	Eksamitöö	main	et
doc_171929905767_item	Ametlik kiri	main	et
doc_171929905768_item	Kontrolltöö eesti kultuuriloost	main	et
doc_177993561423_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_177993561424_item	Ilma milleta ei saa tänapäeval inimene elada.	main	et
doc_177993561425_item	Ilma milleta ei saa tänapäeval elada	main	et
doc_177993561426_item	ILma milleta ei saa tänapäeval elada	main	et
doc_177993561427_item	Ilma milleta ei saa tänapäeval elada.	main	et
doc_177993561428_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_177993561429_item	Ilma milleta ei saa tänapäeval elada	main	et
doc_177993561430_item	Ilma milleta ei saa tänapäeval elada	main	et
doc_177993561431_item	Ilma milleta ei saa tänapäeval elada	main	et
doc_177993561432_item	Ilma milleta ei saa tänapäeval elada	main	et
doc_177993561433_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_177993561434_item	Ametite kirjeldus	main	et
doc_177993561435_item	Ametite kirjeldus	main	et
doc_177993561436_item	Ametite kirjeldus	main	et
doc_177993561437_item	Ametite kirjeldus	main	et
doc_177993561438_item	Ametite kirjeldus	main	et
doc_177993561439_item	Ametite kirjeldus	main	et
doc_177993561440_item	Ametite kirjeldus	main	et
doc_177993561441_item	Ametite kirjeldus	main	et
doc_177993561442_item	Ametite kirjeldus	main	et
doc_177993561443_item	Ametite kirjeldus	main	et
doc_177993561444_item	Ametite kirjeldus	main	et
doc_177993561445_item	Ametite kirjeldus	main	et
doc_177993561446_item	Ametite kirjeldus	main	et
doc_177993561447_item	Ametite kirjeldus	main	et
doc_187964557897_item	Essee	main	et
doc_187964557898_item	Essee	main	et
doc_187964557899_item	Essee	main	et
doc_187964557900_item	Essee	main	et
doc_187964557901_item	Essee	main	et
doc_187964557903_item	Essee	main	et
doc_187964557904_item	Essee	main	et
doc_187964557906_item	Essee	main	et
doc_187964557908_item	Essee	main	et
doc_187964557910_item	Essee	main	et
doc_187964557911_item	Essee	main	et
doc_193540241566_item	Eksam	main	et
doc_193540241567_item	Essee	main	et
doc_193540241568_item	Eksam	main	et
doc_193540241570_item	Analüüs	main	et
doc_196962140767_item	kontrolltöö	main	et
doc_200257165102_item	kontrolltöö	main	et
doc_200257165103_item	kontrolltöö	main	et
doc_213943984903_item	Päevik	main	et
doc_213943984905_item	Essee	main	et
doc_213943984906_item	Essee	main	et
doc_213943984907_item	Essee	main	et
doc_213943984908_item	Essee	main	et
doc_213943984909_item	Essee	main	et
doc_213943984910_item	Essee	main	et
doc_213943984912_item	Tõlge	main	et
doc_213943984913_item	Tõlge	main	et
doc_213943984915_item	Tõlge	main	et
doc_213943984916_item	Tõlge	main	et
doc_213943984917_item	Tõlge	main	et
doc_213943984918_item	Tõlge	main	et
doc_213943984919_item	Tõlge	main	et
doc_213943984920_item	Tõlge	main	et
doc_213943984921_item	Tõlge	main	et
doc_213943984922_item	Tõlge	main	et
doc_213943984924_item	Tõlge	main	et
doc_213943984925_item	Tõlge	main	et
doc_213943984926_item	Tõlge	main	et
doc_213943984927_item	Essee	main	et
doc_213943984928_item	Essee	main	et
doc_213943984929_item	Essee	main	et
doc_213943984930_item	Essee	main	et
doc_213943984931_item	Essee	main	et
doc_213943984932_item	Essee	main	et
doc_213943984933_item	Essee	main	et
doc_213943984934_item	Essee	main	et
doc_213943984935_item	Essee	main	et
doc_213943984936_item	Essee	main	et
doc_213943984937_item	Essee	main	et
doc_213943984938_item	Essee	main	et
doc_213943984940_item	Essee	main	et
doc_213943984941_item	Essee	main	et
doc_213943984942_item	Essee	main	et
doc_213943984943_item	Essee	main	et
doc_213943984944_item	Essee	main	et
doc_213943984945_item	Essee	main	et
doc_213943984946_item	Essee	main	et
doc_213943984947_item	Essee	main	et
doc_213943984948_item	Essee	main	et
doc_213943984949_item	Essee	main	et
doc_213943984950_item	Essee	main	et
doc_213943984951_item	Essee	main	et
doc_213943984952_item	Essee	main	et
doc_213943984953_item	Essee	main	et
doc_213943984954_item	Essee	main	et
doc_213943984956_item	Essee	main	et
doc_213943984958_item	Essee	main	et
doc_213943984959_item	Essee	main	et
doc_213943984960_item	Essee	main	et
doc_213943984961_item	Essee	main	et
doc_213943984962_item	Essee	main	et
doc_213943984966_item	Essee	main	et
doc_213943984967_item	Essee	main	et
doc_213943984968_item	Essee	main	et
doc_213943984969_item	Essee	main	et
doc_213943984970_item	Essee	main	et
doc_213943984971_item	Essee	main	et
doc_213943984972_item	Essee	main	et
doc_213943984973_item	Essee	main	et
doc_213943984974_item	Essee	main	et
doc_213943984975_item	Essee	main	et
doc_213943984976_item	Essee	main	et
doc_213943984977_item	Essee	main	et
doc_213943984979_item	Essee	main	et
doc_213943984981_item	 Referaat	main	et
doc_213943984982_item	Essee	main	et
doc_213943984983_item	Essee	main	et
doc_213943984984_item	Essee	main	et
doc_213943984985_item	Essee	main	et
doc_213943984987_item	Essee	main	et
doc_213943984989_item	Essee	main	et
doc_213943984990_item	Essee	main	et
doc_213943984991_item	Essee	main	et
doc_213943984992_item	Essee	main	et
doc_213943984993_item	Essee	main	et
doc_213943984994_item	Essee	main	et
doc_213943984995_item	Essee	main	et
doc_213943984996_item	Essee	main	et
doc_213943984997_item	Essee	main	et
doc_213943984998_item	Essee	main	et
doc_213943984999_item	Essee	main	et
doc_213943985000_item	Essee	main	et
doc_213943985002_item	Essee	main	et
doc_213943985003_item	Essee	main	et
doc_213943985004_item	Essee	main	et
doc_213943985005_item	Essee	main	et
doc_213943985006_item	Essee	main	et
doc_213943985007_item	Essee	main	et
doc_213943985009_item	Essee	main	et
doc_213943985011_item	Essee	main	et
doc_213943985013_item	Essee	main	et
doc_213943985016_item	Essee	main	et
doc_213943985019_item	Essee	main	et
doc_213943985020_item	Essee	main	et
doc_213943985022_item	Essee	main	et
doc_213943985023_item	Essee	main	et
doc_213943985024_item	Essee	main	et
doc_213943985025_item	Essee	main	et
doc_213943985026_item	Essee	main	et
doc_213943985031_item	Essee	main	et
doc_213943985032_item	Essee	main	et
doc_213943985034_item	Essee	main	et
doc_213943985037_item	Essee	main	et
doc_213943985038_item	Essee	main	et
doc_213943985041_item	Essee	main	et
doc_213943985042_item	Essee	main	et
doc_213943985043_item	Essee	main	et
doc_213943985044_item	Essee	main	et
doc_213943985045_item	Essee	main	et
doc_213943985046_item	Essee	main	et
doc_213943985047_item	Essee	main	et
doc_213943985049_item	Essee	main	et
doc_213943985050_item	Essee	main	et
doc_213943985051_item	Essee	main	et
doc_213943985052_item	Essee	main	et
doc_213943985057_item	Harjutus	main	et
doc_213943985059_item	Harjutus	main	et
doc_213943985060_item	Harjutus	main	et
doc_213943985061_item	Harjutus	main	et
doc_213943985062_item	Harjutus	main	et
doc_213943985063_item	Harjutus	main	et
doc_213943985064_item	Essee	main	et
doc_213943985065_item	Essee	main	et
doc_213943985066_item	Essee	main	et
doc_213943985067_item	Essee	main	et
doc_213943985068_item	Harjutus	main	et
doc_213943985069_item	Harjutus	main	et
doc_213943985070_item	Essee	main	et
doc_213943985072_item	Harjutus	main	et
doc_213943985073_item	Essee	main	et
doc_213943985074_item	Essee	main	et
doc_213943985076_item	Ümberjutustus	main	et
doc_213943985077_item	Harjutus	main	et
doc_213943985078_item	Harjutus	main	et
doc_213943985079_item	Essee	main	et
doc_213943985080_item	Harjutus	main	et
doc_213943985081_item	Harjutus	main	et
doc_213943985082_item	Harjutus	main	et
doc_213943985083_item	Harjutus	main	et
doc_213943985084_item	Harjutus	main	et
doc_213943985085_item	Harjutus	main	et
doc_214589672701_item	Milleta tänapäeval elada ei saa	main	et
doc_214589672703_item	Inimest ümbritseva maailma ohud ja võlud (laused)	main	et
doc_214589672704_item	Milleta tänapäevainimene elada ei saaks (eestlaste laused)	main	et
doc_214589672705_item	Milleta tänapäeva inimene elada ei saaks (eestlaste laused)	main	et
doc_214589672706_item	katastroofid panevad mõtlema (eestlaste laused)	main	et
doc_214589672707_item	Milleta tänapäeval elada ei saaks (eestlaste laused)	main	et
doc_214589672708_item	Inimest ümbritseva maailma võlud ja ohud (eestlaste laused)	main	et
doc_224629419611_item	kontrolltöö	main	et
doc_224629419612_item	kontrolltöö	main	et
doc_252287432501_item	Kultuurilugu	main	et
doc_255175075422_item	Vastus küsimusele	main	et
doc_263021865803_item	 Essee	main	et
doc_263021865804_item	kontrolltöö	main	et
doc_263021865805_item	 Essee	main	et
doc_264166611934_item	kontrolltöö	main	et
doc_264166611935_item	kontrolltöö	main	et
doc_268694804105_item	kontrolltöö	main	et
doc_27046690325_item	kontrolltöö	main	et
doc_278690626899_item	Essee	main	et
doc_278690626904_item	Essee	main	et
doc_278690626905_item	Essee	main	et
doc_278690626907_item	Essee	main	et
doc_278690626908_item	Essee	main	et
doc_278690626909_item	Essee	main	et
doc_278690626910_item	Essee	main	et
doc_278690626912_item	Essee	main	et
doc_278690626916_item	Essee	main	et
doc_278690626918_item	Essee	main	et
doc_278690626920_item	Essee	main	et
doc_278690626921_item	Essee	main	et
doc_278690626922_item	Essee	main	et
doc_278690626930_item	Essee	main	et
doc_278690626931_item	Essee	main	et
doc_278690626940_item	Essee	main	et
doc_278690626945_item	Essee	main	et
doc_278690626947_item	Essee	main	et
doc_278690626948_item	Essee	main	et
doc_278690626954_item	Essee	main	et
doc_278690626959_item	Essee	main	et
doc_284706151123_item	Ülevaade	main	et
doc_284706151124_item	Ülevaade	main	et
doc_284706151125_item	Ülevaade	main	et
doc_284706151126_item	Ülevaade	main	et
doc_284706151127_item	Ülevaade	main	et
doc_284706151128_item	Essee	main	et
doc_284706151129_item	Essee	main	et
doc_284706151132_item	Juhend	main	et
doc_284706151134_item	essee	main	et
doc_284706151135_item	essee	main	et
doc_284706151136_item	essee	main	et
doc_284706151137_item	essee	main	et
doc_284706151138_item	essee	main	et
doc_284706151139_item	essee	main	et
doc_284706151140_item	essee	main	et
doc_284706151141_item	essee	main	et
doc_284706151142_item	essee	main	et
doc_284706151143_item	essee	main	et
doc_284706151144_item	essee	main	et
doc_284706151145_item	essee	main	et
doc_284706151146_item	Uus dokument	main	et
doc_284706151147_item	essee	main	et
doc_284706151148_item	essee	main	et
doc_284706151149_item	essee	main	et
doc_286998102756_item	Essee	main	et
doc_286998102757_item	Essee	main	et
doc_292273046169_item	seminaritöö	main	et
doc_292273046170_item	seminaritöö	main	et
doc_292273046171_item	seminaritöö	main	et
doc_292273046172_item	seminaritöö	main	et
doc_292273046173_item	seminaritöö	main	et
doc_292273046174_item	kiri	main	et
doc_292273046175_item	 kiri	main	et
doc_292273046176_item	 kontrolltöö	main	et
doc_301901115683_item	 kontrolltöö	main	et
doc_301901115684_item	kontrolltöö	main	et
doc_301901115685_item	kontrolltöö	main	et
doc_323408915250_item	kontrolltöö	main	et
doc_323408915251_item	kontrolltöö	main	et
doc_326260187481_item	kontrolltöö	main	et
doc_326260187482_item	kontrolltöö	main	et
doc_326260187483_item	kontrolltöö	main	et
doc_326260187484_item	kontrolltöö	main	et
doc_333816885024_item	Essee	main	et
doc_333816885026_item	Essee	main	et
doc_333816885027_item	Essee	main	et
doc_333816885028_item	Essee	main	et
doc_333816885029_item	Essee	main	et
doc_333816885030_item	Essee	main	et
doc_333816885031_item	Essee	main	et
doc_333816885032_item	Essee	main	et
doc_333816885033_item	Essee	main	et
doc_333816885034_item	Essee	main	et
doc_344825459481_item	 Vastus küsimusele	main	et
doc_345282884525_item	Pildi kirjeldus	main	et
doc_346862720676_item	kontrolltöö	main	et
doc_346862720677_item	kontrolltöö	main	et
doc_346862720678_item	kontrolltöö	main	et
doc_366216787875_item	Essee	main	et
doc_366216787879_item	Essee	main	et
doc_366216787880_item	Essee	main	et
doc_366216787881_item	Essee	main	et
doc_366216787883_item	Essee	main	et
doc_366216787885_item	Essee	main	et
doc_366216787887_item	Essee	main	et
doc_366216787888_item	Essee	main	et
doc_366216787890_item	Essee	main	et
doc_366216787893_item	Essee	main	et
doc_366216787895_item	Essee	main	et
doc_366216787897_item	Essee	main	et
doc_366216787898_item	Essee	main	et
doc_366216787900_item	Essee	main	et
doc_366216787904_item	Essee	main	et
doc_368487548147_item	kontrolltöö	main	et
doc_384045275263_item	Annotatsioon	main	et
doc_384045275264_item	Tõlge	main	et
doc_384045275265_item	Tõlge	main	et
doc_384045275267_item	 Tõlkeanalüüs	main	et
doc_384045275268_item	Referaat	main	et
doc_384045275271_item	Referaat	main	et
doc_384045275272_item	Essee	main	et
doc_384045275273_item	 Essee	main	et
doc_384045275275_item	Essee	main	et
doc_384045275276_item	Essee	main	et
doc_384045275277_item	 Essee	main	et
doc_384045275278_item	Essee	main	et
doc_384045275279_item	Referaadi sissejuhatus	main	et
doc_384045275280_item	Retsensioon	main	et
doc_384045275281_item	Retsensioon	main	et
doc_384045275282_item	Referaat	main	et
doc_384045275283_item	 Essee	main	et
doc_384045275284_item	 Essee	main	et
doc_392411160212_item	Harjutus	main	et
doc_392411160213_item	Essee	main	et
doc_392411160214_item	Essee	main	et
doc_392411160216_item	Harjutus	main	et
doc_392411160217_item	Harjutus	main	et
doc_392411160218_item	Essee	main	et
doc_392411160221_item	Essee	main	et
doc_392411160222_item	Essee	main	et
doc_392411160224_item	Essee	main	et
doc_392411160225_item	Essee	main	et
doc_392411160226_item	Essee	main	et
doc_392411160227_item	Essee	main	et
doc_392411160228_item	Essee	main	et
doc_392411160229_item	Essee	main	et
doc_397823701987_item	Essee	main	et
doc_397823701989_item	Essee	main	et
doc_397823701990_item	Ametlik kiri	main	et
doc_397823701991_item	Essee	main	et
doc_397823701993_item	Essee	main	et
doc_397823701994_item	Ametlik kiri	main	et
doc_397823701995_item	Essee	main	et
doc_397823701996_item	Ametlik kiri	main	et
doc_397823701997_item	Essee	main	et
doc_397823702012_item	Kiri	main	et
doc_397823702015_item	Kiri	main	et
doc_397823702016_item	Kiri	main	et
doc_397823702017_item	Kiri	main	et
doc_397823702018_item	Kiri	main	et
doc_398228895326_item	Essee	main	et
doc_398961616083_item	Tarbi, inimene, tarbi!	main	et
doc_399014257165_item	Essee	main	et
doc_399014257166_item	Essee	main	et
doc_399014257169_item	Essee	main	et
doc_399014257182_item	Essee	main	et
doc_399014257187_item	Essee	main	et
doc_399014257196_item	Harjutus	main	et
doc_399014257197_item	Harjutus	main	et
doc_399014257199_item	Kiri	main	et
doc_399014257208_item	Harjutus	main	et
doc_399014257214_item	Essee	main	et
doc_399014257216_item	Essee	main	et
doc_399014257220_item	Tõlge	main	et
doc_399014257222_item	Tõlge	main	et
doc_399014257223_item	Tõlge	main	et
doc_399014257227_item	Tõlge	main	et
doc_399014257228_item	Tõlge	main	et
doc_399014257230_item	Tõlge	main	et
doc_399014257231_item	Tõlge	main	et
doc_399014257235_item	Tõlge	main	et
doc_399014257236_item	Tõlge	main	et
doc_399014257237_item	Tõlge	main	et
doc_399014257241_item	Tõlge	main	et
doc_399014257242_item	Tõlge	main	et
doc_399014257243_item	Tõlge	main	et
doc_399014257245_item	Tõlge	main	et
doc_401436695441_item	 kontrolltöö	main	et
doc_403280563851_item	Essee	main	et
doc_40918597572_item	Essee	main	et
doc_40918597574_item	Tõlge	main	et
doc_40918597575_item	Harjutus	main	et
doc_40918597576_item	Tõlge	main	et
doc_40918597577_item	Essee	main	et
doc_40918597578_item	Harjutus	main	et
doc_40918597579_item	Tõlge	main	et
doc_40918597580_item	Essee	main	et
doc_41618862214_item	Ametite kirjeldus	main	et
doc_41618862215_item	Ametite kirjeldus	main	et
doc_41618862216_item	Kontrolltöö	main	et
doc_41618862217_item	Kontrolltöö	main	et
doc_41618862218_item	Kontrolltöö	main	et
doc_41618862219_item	Kontrolltöö	main	et
doc_41618862220_item	Kontrolltöö	main	et
doc_41618862221_item	Kontrolltöö	main	et
doc_41618862222_item	Kontrolltöö	main	et
doc_41618862223_item	Kontrolltöö	main	et
doc_41618862224_item	Kontrolltöö	main	et
doc_41618862225_item	Kontrolltöö	main	et
doc_418750402001_item	 Pildi kirjeldus	main	et
doc_418750402002_item	 Arvamus	main	et
doc_418750402003_item	 Arvamus	main	et
doc_418750402004_item	 Arvamus	main	et
doc_418750402005_item	 Arvamus	main	et
doc_418750402006_item	 Ametlik teade	main	et
doc_418750402007_item	 vastus küsimusele 	main	et
doc_418750402008_item	 Arvamus	main	et
doc_418750402009_item	 Harjutus	main	et
doc_418750402010_item	 Harjutus	main	et
doc_418750402011_item	 Arvamus	main	et
doc_418750402012_item	 Kirjand	main	et
doc_42187174247_item	kontrolltöö	main	et
doc_42187174248_item	kontrolltöö	main	et
doc_42187174249_item	kontrolltöö	main	et
doc_427657030946_item	proov	main	et
doc_429435411727_item	kontrolltöö	main	et
doc_43125203602_item	Vastus küsimusele	main	et
doc_43125203603_item	kontrolltöö	main	et
doc_432051777896_item	Uus dokument	main	et
doc_432051777897_item	Uus dokument	main	et
doc_432051777898_item	Uus dokument	main	et
doc_432051777899_item	Uus dokument	main	et
doc_432051777901_item	Uus dokument	main	et
doc_432051777902_item	Uus dokument	main	et
doc_432051777903_item	Uus dokument	main	et
doc_432051777905_item	Uus dokument	main	et
doc_432051777906_item	Uus dokument	main	et
doc_432051777907_item	Uus dokument	main	et
doc_432051777908_item	Uus dokument	main	et
doc_432051777909_item	Uus dokument	main	et
doc_432051777910_item	Uus dokument	main	et
doc_432051777911_item	Uus dokument	main	et
doc_432051777914_item	Uus dokument	main	et
doc_432051777915_item	Uus dokument	main	et
doc_432051777916_item	Uus dokument	main	et
doc_432051777917_item	Uus dokument	main	et
doc_432051777918_item	Uus dokument	main	et
doc_432051777920_item	Uus dokument	main	et
doc_432051777922_item	Juhend	main	et
doc_432051777923_item	Uus dokument	main	et
doc_432051777924_item	Uus dokument	main	et
doc_432051777925_item	Uus dokument	main	et
doc_432051777926_item	Uus dokument	main	et
doc_437545024342_item	kontrolltöö	main	et
doc_438857714625_item	Essee	main	et
doc_438857714626_item	Essee	main	et
doc_438857714627_item	Essee	main	et
doc_438857714628_item	Essee	main	et
doc_438857714629_item	Essee	main	et
doc_438857714630_item	Essee	main	et
doc_438857714631_item	Essee	main	et
doc_438857714632_item	Essee	main	et
doc_439979801331_item	 Essee	main	et
doc_441430986980_item	Eksamitöö	main	et
doc_441430986981_item	Eksamitöö	main	et
doc_441430986982_item	Eksamitöö	main	et
doc_441779960551_item	Essee	main	et
doc_441779960552_item	Essee	main	et
doc_442386364033_item	Vastus küsimusele	main	et
doc_442386364034_item	Vastus küsimusele	main	et
doc_446076497168_item	Analüüs	main	et
doc_446076497169_item	Essee	main	et
doc_446076497170_item	 Essee	main	et
doc_446470622100_item	Pildi kirjeldamine	main	et
doc_446717232815_item	Essee	main	et
doc_446717232816_item	kontrolltöö	main	et
doc_446717232817_item	Essee	main	et
doc_446717232818_item	 kontrolltöö	main	et
doc_45035221884_item	Vastus küsimusele	main	et
doc_45035221885_item	Vastus küsimusele	main	et
doc_450956289271_item	kontrolltöö	main	et
doc_45265275512_item	Dialoog	main	et
doc_45265275513_item	Dialoog	main	et
doc_45265275514_item	Dialoog	main	et
doc_453262085738_item	Analüüs	main	et
doc_45618460770_item	Katastroofid panevad mõtlema (eestlaste laused)	main	et
doc_45618460771_item	Kui vene kool õpiks eesti keeles (eestlaste laused)	main	et
doc_45618460772_item	Katastroofid panevad mõtlema (eestlaste laused)	main	et
doc_45618460773_item	Milleta tänapäeva inimene elada ei saaks (eestlaste laused)	main	et
doc_45618460774_item	Katastroofid panevad mõtlema (eestlaste laused)	main	et
doc_45618460775_item	Eestlaste laused	main	et
doc_45618460776_item	Eestlaste laused	main	et
doc_45618460777_item	Eestlaste laused	main	et
doc_45618460778_item	Eestlaste laused	main	et
doc_45618460779_item	Eestlaste laused	main	et
doc_45618460780_item	Ametite kirjeldus	main	et
doc_45618460781_item	Ametite kirjeldus	main	et
doc_45618460782_item	Ametite kirjeldus	main	et
doc_45618460783_item	Ametite kirjeldus	main	et
doc_460280307193_item	 Essee	main	et
doc_460280307194_item	 Analüüs	main	et
doc_460280307195_item	 Analüüs	main	et
doc_460280307199_item	 Essee	main	et
doc_460280307201_item	 Arvamus 	main	et
doc_460280307202_item	 Essee	main	et
doc_460280307203_item	 Arvamus	main	et
doc_460280307204_item	 Essee	main	et
doc_460280307205_item	 Arvamus	main	et
doc_460280307206_item	 Arvamus	main	et
doc_460280307207_item	Essee	main	et
doc_462410643036_item	kontrolltöö	main	et
doc_462410643037_item	kontrolltöö	main	et
doc_462410643038_item	kontrolltöö	main	et
doc_464301607715_item	Harjutus	main	et
doc_464301607716_item	Harjutus	main	et
doc_464301607720_item	Essee	main	et
doc_464301607721_item	Essee	main	et
doc_464301607722_item	Essee	main	et
doc_464301607723_item	Essee	main	et
doc_464301607724_item	Essee	main	et
doc_464301607725_item	Essee	main	et
doc_464301607726_item	Essee	main	et
doc_464301607727_item	Essee	main	et
doc_464301607728_item	Kiri	main	et
doc_464301607729_item	Essee	main	et
doc_464301607730_item	Essee	main	et
doc_464301607731_item	Essee	main	et
doc_464301607733_item	Essee	main	et
doc_464301607734_item	Essee	main	et
doc_464301607735_item	Essee	main	et
doc_464301607736_item	Essee	main	et
doc_464301607737_item	Essee	main	et
doc_464301607738_item	Essee	main	et
doc_464301607741_item	Essee	main	et
doc_464301607743_item	Essee	main	et
doc_4683472066_item	 kontrolltöö	main	et
doc_4683472067_item	 kontrolltöö	main	et
doc_482578971776_item	 Arvustus	main	et
doc_482578971777_item	 Kiri	main	et
doc_485437783973_item	Vastus küsimusele	main	et
doc_485437783975_item	 Vastus küsimusele	main	et
doc_485839256081_item	 Essee	main	et
doc_485839256082_item	 Essee	main	et
doc_485839256083_item	 Essee	main	et
doc_485839256084_item	Essee	main	et
doc_485839256085_item	 Uurimustöö	main	et
doc_489002948347_item	kontrolltöö	main	et
doc_489002948348_item	kontrolltöö	main	et
doc_491521501645_item	Uus dokument	main	et
doc_491521501646_item	 Eksamitöö	main	et
doc_491521501647_item	 Referaat	main	et
doc_491521501648_item	 Referaat	main	et
doc_491521501649_item	 Kavaleht	main	et
doc_491521501650_item	 Eksamitöö	main	et
doc_491521501653_item	Kontrolltöö	main	et
doc_491521501654_item	Kontrolltöö	main	et
doc_491521501655_item	Kontrolltöö	main	et
doc_491521501656_item	Kontrolltöö 	main	et
doc_491521501658_item	Kontrolltöö	main	et
doc_491521501659_item	Kontrolltöö	main	et
doc_491521501660_item	KONTROLLTÖÖ  	main	et
doc_491521501661_item	Kontrolltöö	main	et
doc_491521501662_item	KONTROLLTÖÖ  	main	et
doc_491521501663_item	katse	main	et
doc_491521501664_item	Kiri	main	et
doc_491521501665_item	Kiri	main	et
doc_491521501666_item	Kiri	main	et
doc_491521501667_item	Kiri	main	et
doc_491521501671_item	Kontrolltöö	main	et
doc_491521501672_item	Kiri	main	et
doc_491521501673_item	Kiri	main	et
doc_491521501674_item	Kiri	main	et
doc_491521501676_item	Kiri	main	et
doc_491521501677_item	Kiri	main	et
doc_491521501678_item	Kiri	main	et
doc_491521501679_item	Kiri	main	et
doc_491521501681_item	ülesanne 1	main	et
doc_491521501682_item	ülesanne 1	main	et
doc_491521501683_item	ülesanne 1	main	et
doc_491521501684_item	ülesanne 1	main	et
doc_491521501685_item	ülesanne 1	main	et
doc_491521501686_item	ülesanne 1	main	et
doc_491521501687_item	ülesanne 1	main	et
doc_491521501688_item	ülesanne 1	main	et
doc_491521501689_item	ülesanne 1	main	et
doc_491521501690_item	ülesanne 1	main	et
doc_491521501691_item	ülesanne 1	main	et
doc_491521501692_item	ülesanne 1	main	et
doc_491521501693_item	ülesanne 1	main	et
doc_491521501694_item	ülesanne 1	main	et
doc_491521501695_item	Ankeet	main	et
doc_491521501696_item	ülesanne 1	main	et
doc_491521501697_item	ülesanne 1	main	et
doc_491521501698_item	ülesanne 1	main	et
doc_491521501699_item	ülesanne 1	main	et
doc_491521501700_item	ülesanne 1	main	et
doc_491521501701_item	kiri	main	et
doc_491521501705_item	kiri	main	et
doc_491521501707_item	kiri	main	et
doc_491521501708_item	kiri	main	et
doc_491521501710_item	kiri	main	et
doc_491521501715_item	kiri	main	et
doc_491521501717_item	kiri	main	et
doc_491521501719_item	kiri	main	et
doc_491521501721_item	kiri	main	et
doc_491521501724_item	Kiri	main	et
doc_491521501725_item	Vastus küsimusele	main	et
doc_491521501726_item		main	et
doc_491521501727_item	kirjadIV	main	et
doc_491521501728_item	kirjadIV	main	et
doc_491521501732_item	Essee	main	et
doc_491521501740_item	VENELASTE VEAD EESTI INFINITIIVI VALIKUL	main	et
doc_491521501741_item	Veaanalüüs	main	et
doc_491521501742_item	ajalehe analüüs	main	et
doc_491521501743_item	Vead mordvalaste keelekasutuses	main	et
doc_491521501745_item	arvamus artikli kohta	main	et
doc_491521501747_item	Eksamitöö	main	et
doc_491521501749_item	Analüüs	main	et
doc_491521501751_item	Essee	main	et
doc_491521501752_item	Eesti rahvakultuur muutuvas ajas	main	et
doc_491521501754_item	Analüüs	main	et
doc_491521501758_item	Essee	main	et
doc_491521501759_item	Essee	main	et
doc_491521501760_item	Vastus küsimusele	main	et
doc_491521501761_item	Essee	main	et
doc_491521501762_item	Essee	main	et
doc_491521501763_item	Essee	main	et
doc_491521501764_item	Essee	main	et
doc_491521501765_item	EKSAMITÖÖ  	main	et
doc_491521501766_item	Avaldus	main	et
doc_491521501768_item	Esse  	main	et
doc_491521501769_item	Essee	main	et
doc_491521501771_item	Essee	main	et
doc_491521501772_item	Essee	main	et
doc_491521501773_item	Essee	main	et
doc_491521501774_item	Essee	main	et
doc_491521501776_item	Analüüs	main	et
doc_491521501777_item	KONTRASTIIVNE LINGVISTIKA	main	et
doc_491521501778_item	Analüüs	main	et
doc_491521501779_item	Analüüs	main	et
doc_491521501780_item	Analüüs	main	et
doc_491521501784_item	Avaldus	main	et
doc_491521501787_item	Seminaritöö	main	et
doc_491521501788_item	Seminaritöö	main	et
doc_491521501790_item	Analüüs	main	et
doc_491521501791_item	„Vägivald sünnitab vägivalda“	main	et
doc_491521501792_item	Essee	main	et
doc_491521501793_item	Essee	main	et
doc_491521501794_item	Essee 	main	et
doc_491521501795_item	Essee	main	et
doc_491521501799_item	Essee	main	et
doc_491521501800_item	Essee	main	et
doc_491521501802_item	Pildi kirjeldus	main	et
doc_491521501803_item	Ümberjutustus	main	et
doc_491521501808_item	Pildi kirjeldus	main	et
doc_491521501809_item	Analüüs	main	et
doc_491521501810_item	EKSAMITÖÖ	main	et
doc_491521501811_item	EKSAMITÖÖ  	main	et
doc_491521501812_item	Eksamitöö	main	et
doc_491521501813_item	EKSAMITÖÖ  	main	et
doc_491521501815_item	EKSAMITÖÖ  	main	et
doc_491521501818_item	EKSAMITÖÖ	main	et
doc_491521501819_item	EKSAMITÖÖ  	main	et
doc_491521501820_item	EKSAMITÖÖ  	main	et
doc_491521501821_item	EKSAMITÖÖ  	main	et
doc_491521501822_item	EKSAMITÖÖ  	main	et
doc_491521501823_item	EKSAMITÖÖ  	main	et
doc_491521501824_item	EKSAMITÖÖ  	main	et
doc_491521501825_item	EKSAMITÖÖ 	main	et
doc_491521501826_item	EKSAMITÖÖ  	main	et
doc_491521501827_item	EKSAMITÖÖ  	main	et
doc_491521501828_item	EKSAMITÖÖ  	main	et
doc_491521501830_item	EKSAMITÖÖ  	main	et
doc_491521501831_item	EKSAMITÖÖ  	main	et
doc_491521501832_item	EKSAMITÖÖ  	main	et
doc_491521501833_item	EKSAMITÖÖ  	main	et
doc_491521501834_item	Ümberjutustus	main	et
doc_491521501839_item	CURRICULUM VITAE	main	et
doc_491521501840_item	Pildi kirjeldus	main	et
doc_491521501841_item	„Nimed marmortahvlil“	main	et
doc_491521501842_item	Essee	main	et
doc_491521501843_item	Essee	main	et
doc_491521501844_item	Essee	main	et
doc_491521501845_item	Essee	main	et
doc_491521501846_item	Essee	main	et
doc_491521501847_item	Essee	main	et
doc_491521501848_item	Essee	main	et
doc_491521501850_item	Essee	main	et
doc_491521501851_item	Essee	main	et
doc_491521501852_item	Essee	main	et
doc_491521501853_item	Nimed marmortahvlil	main	et
doc_491521501854_item	Nimed marmortahvlil	main	et
doc_491521501856_item	Veaanaliiiisi kodutoo	main	et
doc_491521501857_item	Analüüs	main	et
doc_491521501858_item	Analüüs	main	et
doc_491521501859_item	Nlketuubid	main	et
doc_491521501861_item	Analüüs	main	et
doc_491521501862_item	Vigade analuus	main	et
doc_491521501864_item	Uhildumisvead	main	et
doc_491521501865_item	VEAANALiTIJS	main	et
doc_491521501866_item	VEAANALUUS	main	et
doc_491521501870_item	Analüüs	main	et
doc_491521501872_item	veaanaliiusi kodutoo	main	et
doc_491521501873_item	Essee	main	et
doc_491521501876_item	Eksamitöö	main	et
doc_491521501877_item	Eksamitöö	main	et
doc_491521501879_item	Eksamitöö	main	et
doc_491521501881_item	Eksamitöö	main	et
doc_491521501888_item	 Analüüs	main	et
doc_491521501890_item	Veaanalüüs	main	et
doc_491521501892_item	 Analüüs	main	et
doc_491521501893_item	Kontrastiivlingvistika veaanalüüs	main	et
doc_491521501895_item	 Essee	main	et
doc_491521501896_item	 Essee	main	et
doc_491521501897_item	 Essee	main	et
doc_491521501898_item	 Essee	main	et
doc_491521501899_item	 Kiri 	main	et
doc_491521501900_item	 Etteütlus	main	et
doc_491521501901_item	 Etteütlus	main	et
doc_491521501902_item	 Etteütlus	main	et
doc_491521501905_item	Ümberjutustus	main	et
doc_491521501907_item	 Essee	main	et
doc_491521501908_item	 Eksamitöö	main	et
doc_491521501909_item	 Eksamitöö	main	et
doc_491521501910_item	 Eksamitöö	main	et
doc_491521501912_item	 Eksamitöö	main	et
doc_491521501913_item	 Eksamitöö	main	et
doc_491521501914_item	Harjutus	main	et
doc_491521501915_item	Harjutus	main	et
doc_491521501916_item	Essee	main	et
doc_491521501919_item	Harjutus	main	et
doc_491521501921_item	Kiri	main	et
doc_491521501922_item	Kiri	main	et
doc_491521501924_item	Kiri	main	et
doc_491521501928_item	Kiri	main	et
doc_491521501931_item	Kiri	main	et
doc_491521501932_item	Kiri	main	et
doc_491521501933_item	Kiri	main	et
doc_491521501935_item	Essee	main	et
doc_491521501936_item	Essee	main	et
doc_491521501937_item	Essee	main	et
doc_491521501938_item	Eksamitöö	main	et
doc_491521501941_item	 Kiri	main	et
doc_491521501942_item	Kiri	main	et
doc_491521501943_item	Etteütlus	main	et
doc_491521501944_item	Etteütlus	main	et
doc_491521501945_item	Etteütlus	main	et
doc_491521501946_item	Minevik 	main	et
doc_491521501947_item	Essee	main	et
doc_491521501948_item	Essee	main	et
doc_491521501953_item	13 küsimust	main	et
doc_491521501954_item	13 küsimust	main	et
doc_491521501955_item	13 küsimust	main	et
doc_491521501956_item	13 küsimust	main	et
doc_491521501957_item	13 küsimust	main	et
doc_491521501958_item	13 küsimust	main	et
doc_491521501959_item	13 küsimust	main	et
doc_491521501960_item	13 küsimust	main	et
doc_491521501961_item	13 küsimust	main	et
doc_491521501962_item	13 küsimust	main	et
doc_491521501963_item	13 küsimust	main	et
doc_491521501964_item	13 küsimust	main	et
doc_491521501965_item	13 küsimust	main	et
doc_491521501966_item	13 küsimust	main	et
doc_491521501967_item	13 küsimust	main	et
doc_491521501968_item	13 küsimust	main	et
doc_491521501969_item	13 küsimust	main	et
doc_491521501970_item	13 küsimust	main	et
doc_491521501971_item	13 küsimust	main	et
doc_491521501972_item	13 küsimust	main	et
doc_491521501973_item	13 küsimust	main	et
doc_491521501974_item	13 küsimust	main	et
doc_491521501975_item	13 küsimust	main	et
doc_491521501976_item	tere	main	et
doc_491521501978_item	 Kiri	main	et
doc_491521501980_item	 Kiri	main	et
doc_491521501981_item	 Kiri	main	et
doc_491521501982_item	 Kiri	main	et
doc_491521501983_item	 Kiri	main	et
doc_491521501984_item	 Kiri	main	et
doc_491521501986_item	Essee	main	et
doc_491521501987_item	 Kiri	main	et
doc_491521501988_item	 Kiri	main	et
doc_491521501989_item	 Kiri	main	et
doc_491521501992_item	 Essee	main	et
doc_491521501994_item	 Essee	main	et
doc_491521501995_item	 Essee	main	et
doc_491521501996_item	 Essee	main	et
doc_491521501998_item	 Essee	main	et
doc_491521501999_item	 Essee	main	et
doc_491521502000_item	eesti	main	et
doc_491521502001_item	Eksamitöö	main	et
doc_491521502002_item	neljas osa	main	et
doc_491521502003_item	Essee	main	et
doc_491521502004_item	neljas osa	main	et
doc_491521502005_item	neljas osa	main	et
doc_491521502006_item	neljas osa	main	et
doc_491521502007_item	Eksamitöö	main	et
doc_491521502008_item	test	main	et
doc_491521502009_item	kiri	main	et
doc_491521502010_item	test	main	et
doc_491521502011_item	Eksamitöö	main	et
doc_491521502012_item	Eksamitöö 	main	et
doc_491521502013_item	neljas osa	main	et
doc_491521502014_item	neljas osa	main	et
doc_491521502015_item	Essee	main	et
doc_491521502016_item	neljas osa	main	et
doc_491521502017_item	neljas osa	main	et
doc_491521502018_item	neljas osa	main	et
doc_491521502019_item	neljas osa	main	et
doc_491521502020_item	neljas osa	main	et
doc_491521502021_item	neljas osa	main	et
doc_491521502022_item	neljas osa	main	et
doc_491521502023_item	neljas osa	main	et
doc_491521502024_item	neljas osa	main	et
doc_491521502025_item	Eksamitöö	main	et
doc_491521502026_item	kiri	main	et
doc_491521502027_item	kiri	main	et
doc_491521502028_item	Eksamitöö 	main	et
doc_491521502029_item	Eksamitöö	main	et
doc_491521502030_item	Eksamitöö	main	et
doc_491521502031_item	Kiri	main	et
doc_491521502033_item	Kiri	main	et
doc_491521502034_item	Kiri	main	et
doc_491521502036_item	Kiri	main	et
doc_491521502037_item	Kiri	main	et
doc_491521502038_item	Kiri	main	et
doc_491521502039_item	Kiri	main	et
doc_491521502040_item	Kiri	main	et
doc_491521502041_item	Kiri	main	et
doc_491521502043_item	Kiri	main	et
doc_491521502044_item	Kiri	main	et
doc_491521502046_item	Kiri	main	et
doc_491521502047_item	Eksamitöö	main	et
doc_491521502049_item	Kiri	main	et
doc_491521502052_item	Kiri	main	et
doc_491521502056_item	Kiri	main	et
doc_491521502062_item	Kiri	main	et
doc_491521502063_item	Kiri	main	et
doc_491521502064_item	Kiri	main	et
doc_491521502065_item	Kiri	main	et
doc_491521502067_item	Kiri	main	et
doc_491521502068_item	Kontrolltöö	main	et
doc_491521502082_item	Kontrolltöö	main	et
doc_491521502083_item	Kontrolltöö	main	et
doc_491521502084_item	Kontrolltöö	main	et
doc_491521502085_item	Kontrolltöö	main	et
doc_491521502086_item	Kontrolltöö 	main	et
doc_491521502087_item	Kontrolltöö	main	et
doc_491521502088_item	Kontrolltöö	main	et
doc_491521502089_item	Kontrolltöö	main	et
doc_491521502090_item	Kontrolltöö	main	et
doc_491521502091_item	Kontrolltöö	main	et
doc_491521502092_item	Kontrolltöö	main	et
doc_491521502093_item	Kontrolltöö	main	et
doc_491521502094_item	Kontrolltöö	main	et
doc_491521502095_item	Kontrolltöö	main	et
doc_491521502096_item	Kontrolltöö	main	et
doc_491521502097_item	KOntrolltöö	main	et
doc_491521502098_item	Kontrolltöö	main	et
doc_491521502099_item	Kontrolltöö	main	et
doc_491521502100_item	Kontrolltöö	main	et
doc_491521502101_item	Kontrolltöö	main	et
doc_491521502102_item	Kontrolltöö	main	et
doc_491521502103_item	Kontrolltöö	main	et
doc_491521502104_item	Kontrolltöö	main	et
doc_491521502105_item	Essee	main	et
doc_491521502106_item	Essee	main	et
doc_491521502107_item	Essee	main	et
doc_491521502108_item	lenin	main	et
doc_491521502112_item	Eksamitöö  	main	et
doc_491521502113_item	Eksamitöö  	main	et
doc_491521502114_item	Eksamitöö  	main	et
doc_491521502115_item	Eksamitöö	main	et
doc_491521502116_item	Eksamitöö  	main	et
doc_491521502122_item	Eksamitöö  	main	et
doc_491521502125_item	Eksamitöö 	main	et
doc_491521502126_item	Eksamitöö  	main	et
doc_491521502127_item	Eksamitöö  	main	et
doc_491521502128_item	Eksamitöö  	main	et
doc_491521502129_item	Eksamitöö  	main	et
doc_491521502131_item	Eksamitöö  	main	et
doc_491521502133_item	Eksamitöö  	main	et
doc_491521502134_item	EKSAMITÖÖ	main	et
doc_491521502135_item	EKSAMITÖÖ	main	et
doc_491521502136_item	EKSAMITÖÖ	main	et
doc_491521502137_item	EKSAMITÖÖ	main	et
doc_491521502138_item	EKSAMITÖÖ	main	et
doc_491521502139_item	EKSAMITÖÖ	main	et
doc_491521502140_item	EKSAMITÖÖ	main	et
doc_491521502141_item	EKSAMITÖÖ	main	et
doc_491521502142_item	Essee	main	et
doc_491521502143_item	Essee	main	et
doc_491521502144_item	Essee	main	et
doc_491521502145_item	Essee	main	et
doc_491521502146_item	Essee	main	et
doc_491521502147_item	Essee	main	et
doc_491521502148_item	Essee	main	et
doc_491521502151_item	Essee 	main	et
doc_491521502152_item	Essee	main	et
doc_491521502153_item	Minu Leninid	main	et
doc_491521502154_item	Essee	main	et
doc_491521502156_item	Minu Leninid	main	et
doc_491521502157_item	Minu Leeninid	main	et
doc_491521502158_item	EESTI KEELE TEST	main	et
doc_491521502159_item	EESTI KEELE TEST	main	et
doc_491521502160_item	EESTI KEELE TEST	main	et
doc_491521502161_item	EESTI KEELE TEST	main	et
doc_491521502162_item	EESTI KEELE TEST	main	et
doc_491521502163_item	EESTI KEELE TEST	main	et
doc_491521502164_item	EESTI KEELE TEST	main	et
doc_491521502165_item	EESTI KEELE TEST	main	et
doc_491521502166_item	EESTI KEELE TEST	main	et
doc_491521502167_item	EESTI KEELE TEST	main	et
doc_491521502168_item	EESTI KEELE TEST	main	et
doc_491521502169_item	EESTI KEELE TEST	main	et
doc_491521502170_item	EESTI KEELE TEST	main	et
doc_491521502171_item	EESTI KEELE TEST	main	et
doc_491521502172_item	EESTI KEELE TEST	main	et
doc_491521502173_item	EESTI KEELE TEST	main	et
doc_491521502174_item	EESTI KEELE TEST	main	et
doc_491521502175_item	EESTI KEELE TEST	main	et
doc_491521502176_item	EESTI KEELE TEST	main	et
doc_491521502177_item	EESTI KEELE TEST	main	et
doc_491521502178_item	EESTI KEELE TEST	main	et
doc_491521502179_item	EESTI KEELE TEST	main	et
doc_491521502180_item	EESTI KEELE TEST	main	et
doc_491521502182_item	KONTROLLTÖÖ 	main	et
doc_491521502191_item	KONTROLLTÖÖ  	main	et
doc_491521502195_item	KONTROLLTÖÖ  	main	et
doc_491521502197_item	KONTROLLTÖÖ  	main	et
doc_491521502199_item	KONTROLLTÖÖ  	main	et
doc_491521502200_item	KONTROLLTÖÖ  	main	et
doc_491521502202_item	KONTROLLTÖÖ  	main	et
doc_491521502203_item	KONTROLLTÖÖ  	main	et
doc_491521502205_item	KONTROLLTÖÖ  	main	et
doc_491521502209_item	KONTROLLTÖÖ  	main	et
doc_491521502210_item	KONTROLLTÖÖ  	main	et
doc_491521502213_item	KONTROLLTÖÖ  	main	et
doc_491521502214_item	KONTROLLTÖÖ  	main	et
doc_491521502219_item	KONTROLLTÖÖ  	main	et
doc_491521502220_item	KONTROLLTÖÖ 	main	et
doc_491521502221_item	KONTROLLTÖÖ  	main	et
doc_491521502224_item	KONTROLLTÖÖ  	main	et
doc_491521502225_item	KONTROLLTÖÖ  	main	et
doc_491521502226_item	KONTROLLTÖÖ  	main	et
doc_491521502227_item	KONTROLLTÖÖ  	main	et
doc_491521502228_item	KONTROLLTÖÖ  	main	et
doc_491521502230_item	KONTROLLTÖÖ  	main	et
doc_491521502232_item	KONTROLLTÖÖ  	main	et
doc_491521502233_item	KONTROLLTÖÖ  	main	et
doc_491521502235_item	KONTROLLTÖÖ  	main	et
doc_491521502236_item	KONTROLLTÖÖ  	main	et
doc_491521502238_item	KONTROLLTÖÖ  	main	et
doc_491521502239_item	KONTROLLTÖÖ  	main	et
doc_491521502241_item	KONTROLLTÖÖ  	main	et
doc_491521502242_item	KONTROLLTÖÖ  	main	et
doc_491521502243_item	KONTROLLTÖÖ EESTI KULTUURILOOST II D	main	et
doc_491521502251_item	KONTROLLTÖÖ  	main	et
doc_491521502253_item	KONTROLLTÖÖ  	main	et
doc_491521502254_item	KONTROLLTÖÖ  	main	et
doc_491521502255_item	KONTROLLTÖÖ  	main	et
doc_491521502257_item	KONTROLLTÖÖ  	main	et
doc_491521502258_item	KONTROLLTÖÖ 	main	et
doc_491521502259_item	KONTROLLTÖÖ  	main	et
doc_491521502262_item	KONTROLLTÖÖ  	main	et
doc_491521502264_item	KONTROLLTÖÖ  	main	et
doc_491521502266_item	KONTROLLTÖÖ  	main	et
doc_491521502269_item	KONTROLLTÖÖ  	main	et
doc_491521502270_item	KONTROLLTÖÖ  	main	et
doc_491521502272_item	KONTROLLTÖÖ  	main	et
doc_491521502274_item	KONTROLLTÖÖ  	main	et
doc_491521502275_item	KONTROLLTÖÖ  	main	et
doc_491521502276_item	KONTROLLTÖÖ  	main	et
doc_491521502277_item	KONTROLLTÖÖ 	main	et
doc_491521502280_item	KONTROLLTÖÖ  	main	et
doc_491521502281_item	KONTROLLTÖÖ  	main	et
doc_491521502282_item	KONTROLLTÖÖ  	main	et
doc_491521502284_item	KONTROLLTÖÖ  	main	et
doc_491521502286_item	KONTROLLTÖÖ  	main	et
doc_491521502288_item	KONTROLLTÖÖ  	main	et
doc_491521502289_item	KONTROLLTÖÖ  	main	et
doc_491521502290_item	KONTROLLTÖÖ  	main	et
doc_491521502291_item	KONTROLLTÖÖ 	main	et
doc_491521502292_item	KONTROLLTÖÖ  	main	et
doc_491521502293_item	KONTROLLTÖÖ  	main	et
doc_491521502294_item	KONTROLLTÖÖ 	main	et
doc_491521502295_item	KONTROLLTÖÖ  	main	et
doc_491521502296_item	KONTROLLTÖÖ  	main	et
doc_491521502297_item	KONTROLLTÖÖ  	main	et
doc_491521502298_item	KONTROLLTÖÖ  	main	et
doc_491521502299_item	KONTROLLTÖÖ  	main	et
doc_491521502300_item	KONTROLLTÖÖ  	main	et
doc_491521502301_item	KONTROLLTÖÖ  	main	et
doc_491521502302_item	KONTROLLTÖÖ  	main	et
doc_491521502303_item	KONTROLLTÖÖ  	main	et
doc_491521502304_item	KONTROLLTÖÖ  	main	et
doc_491521502305_item	KONTROLLTÖÖ  	main	et
doc_491521502306_item	KONTROLLTÖÖ  	main	et
doc_491521502308_item	KONTROLLTÖÖ  	main	et
doc_491521502309_item	KONTROLLTÖÖ  	main	et
doc_491521502310_item	KONTROLLTÖÖ  	main	et
doc_491521502311_item	KONTROLLTÖÖ  	main	et
doc_491521502313_item	KONTROLLTÖÖ  	main	et
doc_491521502315_item	KONTROLLTÖÖ  	main	et
doc_491521502316_item	KONTROLLTÖÖ  	main	et
doc_491521502317_item	KONTROLLTÖÖ  	main	et
doc_491521502319_item	Analüüs	main	et
doc_491521502320_item	test doc	main	et
doc_49256336380_item	Kontrolltöö	main	et
doc_49256336381_item	Kontrolltöö	main	et
doc_49256336382_item	Kontrolltöö	main	et
doc_503739895319_item	kontrolltöö	main	et
doc_503739895320_item	kontrolltöö	main	et
doc_503739895321_item	kontrolltöö	main	et
doc_516622545497_item	Seletuskiri politseile	main	et
doc_516622545498_item	Poolt- ja vastuargumendid	main	et
doc_516622545499_item	Seletuskiri	main	et
doc_516622545500_item	Kontrolltöö	main	et
doc_516622545501_item	Kontrolltöö	main	et
doc_516622545502_item	Milline peab olema hea juht	main	et
doc_516622545503_item	Artikli kokkuvõte	main	et
doc_516622545504_item	Minu eriala	main	et
doc_516622545505_item	Väidete kommenteerimine	main	et
doc_516622545506_item	Minu töö	main	et
doc_516622545507_item	Minu elukoht	main	et
doc_51880851196_item	Seletuskiri	main	et
doc_51880851197_item	Kaebus	main	et
doc_51880851198_item	Kontrolltöö	main	et
doc_51880851199_item	Kontrolltöö	main	et
doc_51880851202_item	Liiklusõnnetuse pealtnägija kirjeldus	main	et
doc_51880851203_item	Pangateenus	main	et
doc_51880851204_item	Euroliit on väikefirmadele uus väljakutse	main	et
doc_524344278300_item	Tekstianalüüs	main	et
doc_524344278301_item	 Tekstianalüüs	main	et
doc_527420171752_item	Essee	main	et
doc_527420171753_item	Essee	main	et
doc_52744525860_item	 Analüüs	main	et
doc_52744525861_item	 Kirjeldus  	main	et
doc_52744525862_item	Kirjeldus	main	et
doc_532115409053_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409054_item	Essee	main	et
doc_532115409055_item	Leiutis, ilma milleta ma ei saa elada	main	et
doc_532115409056_item	Leiutis, ilma milleta ma ei saaks elada	main	et
doc_532115409057_item	Leiutis, ilma milleta ma ei saaks elada	main	et
doc_532115409058_item	Leiutis, ilma milleta ma ei saaks elada	main	et
doc_532115409059_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409060_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409061_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409062_item	Mida ma tahaksin õppida eesti keele tundides	main	et
doc_532115409063_item	Mida ma tahaksin õppida eesti keele tundides	main	et
doc_532115409064_item	Mida ma tahan õppida eesti keele tundides	main	et
doc_532115409065_item	Mida ma tahaksin õppida eesti keele tundides	main	et
doc_532115409066_item	Mida ma tahaksin õppida eesti keele tundides	main	et
doc_532115409067_item	Mida ma tahaksin õppida eesti keele tundides	main	et
doc_532115409068_item	Mida ma tahaksin õppida eesti keele tundides	main	et
doc_532115409069_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409070_item	Mida ma tahaksin õppida eesti keele tundides	main	et
doc_532115409071_item	Mida ma tahaksin õppida eesti keele tundides	main	et
doc_532115409072_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409073_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409074_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409075_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409076_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409077_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409078_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409079_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409080_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409081_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409082_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409083_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409084_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409085_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409086_item	Leiutised, ilma milleta ma ei saaks elada	main	et
doc_532115409087_item	Ilma milliste leiutisteta ma ei saaks elada	main	et
doc_532115409088_item	Minu elukoht	main	et
doc_532115409089_item	Missugused autod mulle meeldivad	main	et
doc_532115409090_item	Seletuskiri	main	et
doc_532115409091_item	Inimese tervis sõltub elustiilist	main	et
doc_532115409092_item	Minu elukoht	main	et
doc_532115409093_item	Laste kasvatamisest ja kooliharidusest sõltub see, kas nad lähevad kuritegelikule teele või mitte	main	et
doc_532115409094_item	Keemiatooted teevad meie elu lihtsamaks ja turvalisemaks	main	et
doc_532115409096_item	Minu kannapöörded	main	et
doc_532115409097_item	Asjad, ilma milleta inimesed ei saa elada	main	et
doc_532115409098_item	Vene kool eesti keeles	main	et
doc_532115409099_item	Vene kool eesti keeles?	main	et
doc_532115409100_item	Vene kool eesti keeles?	main	et
doc_532115409101_item	Vene kool eesti keeles?	main	et
doc_532115409102_item	Vene kool eesti keeles?	main	et
doc_532115409104_item	Vene kool eesti keeles?	main	et
doc_532115409105_item	Vene kool eesti keeles?	main	et
doc_532115409106_item	Vene kool eesti keeles?	main	et
doc_532115409107_item	Vene kool eesti keeles?	main	et
doc_532115409108_item	Vene kool eesti keeles?	main	et
doc_534729444675_item	Päevik	main	et
doc_534729444678_item	Päevik	main	et
doc_534729444679_item	Päevik	main	et
doc_534729444686_item	Päevik	main	et
doc_534729444688_item	Päevik	main	et
doc_534729444689_item	Päevik	main	et
doc_534729444696_item	Päevik	main	et
doc_534729444697_item	Päevik	main	et
doc_534729444700_item	Päevik	main	et
doc_534729444701_item	Päevik	main	et
doc_534729444702_item	Päevik	main	et
doc_534729444703_item	Päevik	main	et
doc_534729444704_item	Päevik	main	et
doc_534729444705_item	Päevik	main	et
doc_534729444706_item	Essee	main	et
doc_534729444707_item	Essee	main	et
doc_534729444711_item	Essee	main	et
doc_534729444716_item	Essee	main	et
doc_534729444717_item	Essee	main	et
doc_534729444719_item	Essee	main	et
doc_534729444722_item	Essee	main	et
doc_534729444724_item	Essee	main	et
doc_534729444725_item	Essee	main	et
doc_534729444726_item	Essee	main	et
doc_534729444729_item	Essee	main	et
doc_534729444730_item	Essee	main	et
doc_534729444732_item	Essee	main	et
doc_534729444733_item	Essee	main	et
doc_534729444734_item	Essee	main	et
doc_534729444736_item	Essee	main	et
doc_534729444737_item	Essee	main	et
doc_534729444739_item	Essee	main	et
doc_534729444740_item	Essee	main	et
doc_534729444741_item	Essee	main	et
doc_534729444742_item	Essee	main	et
doc_535144239974_item	 kontrolltöö	main	et
doc_535144239975_item	kontrolltöö	main	et
doc_535144239976_item	 kontrolltöö	main	et
doc_535144239977_item	 kontrolltöö	main	et
doc_535144239978_item	 kontrolltöö	main	et
doc_535144239979_item	 kontrolltöö	main	et
doc_53629148792_item	kontrolltöö	main	et
doc_536541856858_item	Essee	main	et
doc_536541856859_item	Essee	main	et
doc_536541856860_item	Essee	main	et
doc_536541856861_item	Essee	main	et
doc_536541856862_item	Essee	main	et
doc_536541856863_item	Essee	main	et
doc_536541856864_item	Essee	main	et
doc_536541856865_item	Essee	main	et
doc_536541856868_item	Essee	main	et
doc_536541856869_item	Essee	main	et
doc_536541856870_item	Essee	main	et
doc_536541856875_item	Essee	main	et
doc_536541856876_item	Essee	main	et
doc_536541856877_item	Essee	main	et
doc_536541856883_item	Essee	main	et
doc_536541856887_item	Essee	main	et
doc_536541856888_item	Essee	main	et
doc_536541856889_item	Essee	main	et
doc_536541856890_item	Essee	main	et
doc_536541856891_item	Essee	main	et
doc_536541856893_item	Essee	main	et
doc_536541856896_item	Essee	main	et
doc_536541856898_item	Essee	main	et
doc_536541856900_item	Essee	main	et
doc_536541856901_item	Essee	main	et
doc_536541856903_item	Essee	main	et
doc_536541856904_item	Essee	main	et
doc_536541856907_item	Essee	main	et
doc_536541856908_item	Essee	main	et
doc_536541856909_item	Essee	main	et
doc_536541856912_item	Essee	main	et
doc_538656299206_item	 kontrolltöö	main	et
doc_541512374224_item	Eksamitöö	main	et
doc_542009824736_item	Vastus küsimusele	main	et
doc_542009824737_item	Vastus küsimusele	main	et
doc_542009824738_item	Vastus küsimusele	main	et
doc_542009824739_item	Vastus küsimusele	main	et
doc_542009824740_item	Vastus küsimusele	main	et
doc_542009824742_item	Vastus küsimusele	main	et
doc_542009824744_item	Vastus küsimusele	main	et
doc_542009824746_item	Vastus küsimusele	main	et
doc_542009824747_item	Vastus küsimusele	main	et
doc_542009824748_item	Vastus küsimusele	main	et
doc_542009824750_item	Essee	main	et
doc_542009824751_item	essee	main	et
doc_542009824752_item	essee	main	et
doc_542009824753_item	essee	main	et
doc_542009824754_item	essee	main	et
doc_542009824755_item	essee	main	et
doc_542009824756_item	essee	main	et
doc_542009824757_item	essee	main	et
doc_542009824758_item	essee	main	et
doc_542009824759_item	essee	main	et
doc_542009824760_item	essee	main	et
doc_542009824761_item	essee	main	et
doc_542009824762_item	essee	main	et
doc_542009824763_item	Harjutus	main	et
doc_542009824764_item	Tõlge	main	et
doc_542009824765_item	Harjutus	main	et
doc_542009824766_item	Harjutus	main	et
doc_542009824767_item	Harjutus	main	et
doc_542009824768_item	Harjutus	main	et
doc_542009824772_item	Vastus küsimusele	main	et
doc_542009824773_item	Harjutus	main	et
doc_542009824774_item	essee	main	et
doc_542009824775_item	essee	main	et
doc_542009824776_item	essee	main	et
doc_542009824777_item	essee	main	et
doc_542009824778_item	essee	main	et
doc_542009824779_item	essee	main	et
doc_542009824780_item	essee	main	et
doc_542009824781_item	essee	main	et
doc_542009824782_item	essee	main	et
doc_542009824783_item	essee	main	et
doc_542009824784_item	essee	main	et
doc_542009824785_item	essee	main	et
doc_542009824786_item	essee	main	et
doc_542009824787_item	essee	main	et
doc_542009824788_item	Harjutus	main	et
doc_542009824789_item	essee	main	et
doc_542009824790_item	essee	main	et
doc_542009824791_item	essee	main	et
doc_542009824792_item	essee	main	et
doc_542009824794_item	essee	main	et
doc_542009824795_item	essee	main	et
doc_542009824796_item	essee	main	et
doc_542009824797_item	essee	main	et
doc_542009824798_item	ametlik kiri	main	et
doc_542009824802_item	ametlik kiri	main	et
doc_542009824803_item	essee	main	et
doc_542009824804_item	essee	main	et
doc_542009824805_item	essee	main	et
doc_542009824808_item	Uus dokument	main	et
doc_542009824809_item	Juhend	main	et
doc_542009824811_item	Harjutus	main	et
doc_542009824812_item	Harjutus	main	et
doc_542009824813_item	Harjutus	main	et
doc_542009824815_item	Harjutus	main	et
doc_542576733648_item	Kiri	main	et
doc_542576733649_item	Kiri	main	et
doc_542576733650_item	Kiri	main	et
doc_542576733651_item	Kiri	main	et
doc_542576733652_item	Kiri	main	et
doc_542576733653_item	Kiri	main	et
doc_542576733654_item	Kiri	main	et
doc_542576733655_item	Kiri	main	et
doc_542576733656_item	Kiri	main	et
doc_542576733657_item	Kiri	main	et
doc_553383122816_item	Eksamitöö	main	et
doc_560938275462_item	 Ametlik kiri	main	et
doc_568696801174_item	kontrolltöö	main	et
doc_568696801175_item	kontrolltöö	main	et
doc_568696801176_item	kontrolltöö	main	et
doc_56989259334_item	Essee	main	et
doc_572002200596_item	Kontrolltöö	main	et
doc_572002200597_item	Kontrolltöö	main	et
doc_572002200598_item	Kaebus	main	et
doc_572002200599_item	Kaebus	main	et
doc_572002200600_item	Kontrolltöö	main	et
doc_572002200601_item	Kontrolltöö	main	et
doc_572002200602_item	Kontrolltöö	main	et
doc_573958253416_item	Kiri	main	et
doc_573958253418_item	Uus dokument	main	et
doc_574559240055_item	Arvamus	main	et
doc_574559240056_item	Arvamus	main	et
doc_574559240057_item	Arvamus	main	et
doc_576966344269_item	Eesti kultuuriloo kontrolltöö	main	et
doc_57773893368_item	kontrolltöö	main	et
doc_57773893369_item	kontrolltöö	main	et
doc_582053207518_item	test	main	et
doc_582053207519_item	Uus dokument	main	et
doc_582053207520_item	Kiri	main	et
doc_582053207521_item	Kiri	main	et
doc_582053207522_item	Referaat	main	et
doc_582053207523_item	Seminaritöö	main	et
doc_582053207524_item	Referaat	main	et
doc_582053207525_item	Milleta ei saa inimene elada?	main	et
doc_582053207526_item	Vene kool eesti keeles	main	et
doc_582053207527_item	Milleta ei saa inimene elada?	main	et
doc_582053207528_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207529_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207530_item	Ilma milleta ei saa inimene elada	main	et
doc_582053207531_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207532_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207533_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207534_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207535_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207536_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207537_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207538_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207539_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207540_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207541_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207542_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207543_item	Ilma milelta ei saa inimene tänapäeval elada	main	et
doc_582053207544_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_582053207545_item	Ilma milleta ei saa tänapäeval elada	main	et
doc_582053207546_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_584615399807_item	 Kiri 	main	et
doc_584615399808_item	 Ametlik kiri	main	et
doc_584615399809_item	 Essee	main	et
doc_584615399811_item	Vastus küsimusele	main	et
doc_596017998605_item	vastus küsimusele	main	et
doc_596017998606_item	vastus küsimusele	main	et
doc_596182270457_item	Analüüs	main	et
doc_59711134399_item	Kiri	main	et
doc_59711134402_item	Kiri	main	et
doc_59711134403_item	Kiri	main	et
doc_59711134404_item	Kiri	main	et
doc_59711134410_item	Essee	main	et
doc_59711134415_item	Kiri	main	et
doc_59711134418_item	Essee	main	et
doc_59711134419_item	Ametlik kiri	main	et
doc_598824800290_item	Kaebus	main	et
doc_598824800291_item	Koolidirektori kõne	main	et
doc_600365859531_item	 Vastus küsimusele	main	et
doc_600559928975_item	 Kiri 	main	et
doc_600559928976_item	 Kiri 	main	et
doc_600559928977_item	 Kiri 	main	et
doc_600559928981_item	 Kiri 	main	et
doc_600559928982_item	 Kiri 	main	et
doc_600559928990_item	 Kiri 	main	et
doc_600559928995_item	 Kiri 	main	et
doc_600559928996_item	 Kiri 	main	et
doc_600559928997_item	 Kiri 	main	et
doc_600559929001_item	 Kiri 	main	et
doc_600559929002_item	Kiri	main	et
doc_600559929005_item	Uus dokument	main	et
doc_609075653171_item	 Arvamus 	main	et
doc_609075653172_item	 Kirjeldus	main	et
doc_609075653173_item	 Arvamus	main	et
doc_609075653174_item	 Kirjeldus  	main	et
doc_609075653175_item	kontrolltöö	main	et
doc_609075653176_item	 Kirjeldus	main	et
doc_609075653177_item	 kontrolltöö	main	et
doc_609075653178_item	 Kirjeldus  	main	et
doc_609075653179_item	 Kirjeldus	main	et
doc_609075653180_item	vastus küsimusele	main	et
doc_609075653181_item	 vastus küsimusele 	main	et
doc_609075653182_item	 vastus küsimusele 	main	et
doc_609075653184_item	 vastus küsimusele 	main	et
doc_609075653187_item	 vastus küsimusele 	main	et
doc_609075653188_item	vastus küsimusele	main	et
doc_617668397741_item	Kontrolltöö	main	et
doc_617668397742_item	Kontrolltöö	main	et
doc_617668397743_item	Kontrolltöö	main	et
doc_617668397744_item	Kontrolltöö	main	et
doc_617668397747_item	Kontrolltöö	main	et
doc_617668397748_item	Kontrolltöö	main	et
doc_617668397749_item	Kontrolltöö	main	et
doc_617668397750_item	Kontrolltöö	main	et
doc_617668397751_item	Kontrolltöö	main	et
doc_617668397753_item	Kontrolltöö	main	et
doc_617668397754_item	Kontrolltöö	main	et
doc_617668397755_item	Kontrolltöö	main	et
doc_617668397756_item	Kontrolltöö	main	et
doc_617668397757_item	Kontrolltöö	main	et
doc_617668397758_item	Kontrolltöö	main	et
doc_617668397760_item	Kontrolltöö	main	et
doc_617668397761_item	essee	main	et
doc_617668397763_item	essee	main	et
doc_617668397764_item	essee	main	et
doc_617668397766_item	essee	main	et
doc_617668397767_item	essee	main	et
doc_617668397768_item	essee	main	et
doc_634572338199_item	Essee	main	et
doc_634572338200_item	Essee	main	et
doc_634572338202_item	Vastus küsimusele	main	et
doc_634572338203_item	Essee	main	et
doc_634572338204_item	Seletuskiri	main	et
doc_634572338206_item	Essee	main	et
doc_634572338208_item	Arvamus	main	et
doc_634572338209_item	Arvamus	main	et
doc_634572338212_item	Arvamus	main	et
doc_634572338213_item	Arvamus	main	et
doc_634572338218_item	Arvamus 	main	et
doc_634572338219_item	Arvamus	main	et
doc_634572338220_item	Arvamus	main	et
doc_634572338222_item	Harjutus	main	et
doc_634572338223_item	Tõlge	main	et
doc_634572338224_item	essee	main	et
doc_634572338225_item	essee	main	et
doc_634572338227_item	Harjutus	main	et
doc_634572338228_item	Harjutus	main	et
doc_634572338229_item	Kontrolltöö	main	et
doc_634572338230_item	essee	main	et
doc_634572338231_item	essee	main	et
doc_634572338232_item	essee	main	et
doc_634572338234_item	essee	main	et
doc_634572338235_item	ametlik kiri	main	et
doc_634572338238_item	ametlik kiri	main	et
doc_634572338239_item	Ametlik kiri	main	et
doc_634572338240_item	Ametlik kiri	main	et
doc_634572338241_item	Vastus küsimusele	main	et
doc_634572338242_item	Vastus küsimusele	main	et
doc_634572338243_item	Vastus küsimusele	main	et
doc_634572338245_item	Harjutus	main	et
doc_634572338246_item	Vastus küsimusele	main	et
doc_634572338247_item	Vastus küsimusele	main	et
doc_634572338248_item	Vastus küsimusele	main	et
doc_634572338249_item	Vastus küsimusele	main	et
doc_640286507873_item	kontrolltöö	main	et
doc_640286507874_item	kontrolltöö	main	et
doc_640286507876_item	 kontrolltöö	main	et
doc_640286507877_item	kontrolltöö	main	et
doc_643650824484_item	Vastlapäeva lõke	main	et
doc_662339917498_item	 kontrolltöö	main	et
doc_670731433410_item	Essee	main	et
doc_670731433412_item	Essee	main	et
doc_670731433416_item	Essee	main	et
doc_670731433418_item	Essee	main	et
doc_670731433419_item	Essee	main	et
doc_670731433420_item	Essee	main	et
doc_670731433422_item	Essee	main	et
doc_670731433423_item	Essee	main	et
doc_670731433425_item	Essee	main	et
doc_670731433426_item	Essee	main	et
doc_670731433427_item	Essee	main	et
doc_670731433428_item	Essee	main	et
doc_670731433429_item	Essee	main	et
doc_670731433430_item	Essee	main	et
doc_670731433431_item	Essee	main	et
doc_670731433432_item	Essee	main	et
doc_670731433433_item	Essee	main	et
doc_670731433434_item	Essee	main	et
doc_670731433435_item	Essee	main	et
doc_670731433436_item	Essee	main	et
doc_670731433437_item	Essee	main	et
doc_670731433438_item	Essee	main	et
doc_670731433439_item	Seletuskiri	main	et
doc_670731433440_item	Harjutus	main	et
doc_670731433441_item	Harjutus	main	et
doc_670731433442_item	Harjutus	main	et
doc_670731433443_item	Harjutus	main	et
doc_670731433444_item	Harjutus	main	et
doc_670731433445_item	Harjutus	main	et
doc_670731433446_item	Harjutus	main	et
doc_670731433447_item	Harjutus	main	et
doc_670731433448_item	Harjutus	main	et
doc_670731433449_item	Harjutus	main	et
doc_670731433450_item	Harjutus	main	et
doc_670731433451_item	Harjutus	main	et
doc_670731433452_item	Harjutus	main	et
doc_670731433453_item	Harjutus	main	et
doc_670731433454_item	Harjutus	main	et
doc_670731433455_item	Harjutus	main	et
doc_670731433456_item	Harjutus	main	et
doc_670731433457_item	Harjutus	main	et
doc_670731433458_item	Harjutus	main	et
doc_670731433459_item	Harjutus	main	et
doc_670731433460_item	Harjutus	main	et
doc_670731433461_item	Harjutus	main	et
doc_670731433462_item	Harjutus	main	et
doc_670731433463_item	Harjutus	main	et
doc_670731433464_item	Harjutus	main	et
doc_670731433465_item	Harjutus	main	et
doc_670731433466_item	Harjutus	main	et
doc_670731433467_item	Harjutus	main	et
doc_670731433468_item	Harjutus	main	et
doc_670731433469_item	Harjutus	main	et
doc_670731433470_item	Harjutus	main	et
doc_670731433471_item	Harjutus	main	et
doc_670731433472_item	Harjutus	main	et
doc_670731433473_item	Harjutus	main	et
doc_670731433474_item	Harjutus	main	et
doc_670731433475_item	Harjutus	main	et
doc_670731433476_item	Harjutus	main	et
doc_670731433477_item	Harjutus	main	et
doc_670731433478_item	Harjutus	main	et
doc_670731433479_item	Harjutus	main	et
doc_670731433480_item	Harjutus	main	et
doc_676618345565_item	 kontrolltöö	main	et
doc_680929863179_item	Essee	main	et
doc_680929863182_item	Essee	main	et
doc_680929863183_item	Essee	main	et
doc_680929863184_item	Ametlik kiri	main	et
doc_680929863186_item	Essee	main	et
doc_680929863187_item	Essee	main	et
doc_681992022005_item	Ümberjutustus	main	et
doc_681992022006_item	Ümberjutustus	main	et
doc_681992022007_item	Ümberjutustus	main	et
doc_681992022008_item	Ümberjutustus	main	et
doc_681992022009_item	Ümberjutustus	main	et
doc_681992022010_item	Ümberjutustus	main	et
doc_681992022011_item	Ümberjutustus	main	et
doc_681992022013_item	Pildi kirjeldus	main	et
doc_681992022014_item	Ümberjutustus	main	et
doc_681992022015_item	Ümberjutustus	main	et
doc_681992022016_item	Ümberjutustus	main	et
doc_681992022017_item	Vastus küsimusele	main	et
doc_681992022018_item	essee	main	et
doc_681992022019_item	essee	main	et
doc_681992022020_item	essee	main	et
doc_681992022021_item	essee	main	et
doc_681992022022_item	essee	main	et
doc_681992022023_item	essee	main	et
doc_681992022024_item	essee	main	et
doc_681992022025_item	essee	main	et
doc_681992022026_item	essee	main	et
doc_681992022027_item	essee	main	et
doc_681992022028_item	essee	main	et
doc_681992022029_item	essee	main	et
doc_681992022030_item	essee	main	et
doc_681992022031_item	essee	main	et
doc_681992022032_item	essee	main	et
doc_681992022033_item	essee	main	et
doc_681992022034_item	essee	main	et
doc_681992022035_item	essee	main	et
doc_685122975254_item	Seminaritöö	main	et
doc_685122975266_item	Kiri	main	et
doc_685122975268_item	Kiri	main	et
doc_685122975270_item	Kiri	main	et
doc_685122975271_item	Kiri	main	et
doc_685122975272_item	Kiri	main	et
doc_685122975273_item	Kiri	main	et
doc_685122975274_item	Kiri	main	et
doc_685122975275_item	Kiri	main	et
doc_685122975276_item	Kiri	main	et
doc_685122975277_item	Kiri	main	et
doc_685122975278_item	Kiri	main	et
doc_685122975279_item	Kiri	main	et
doc_685122975280_item	Kiri	main	et
doc_685122975281_item	Kiri	main	et
doc_685122975282_item	Kiri	main	et
doc_685122975283_item	Kiri	main	et
doc_685122975284_item	Kiri	main	et
doc_685122975285_item	Kiri	main	et
doc_685122975286_item	Kiri	main	et
doc_685122975287_item	Kiri	main	et
doc_685122975288_item	Kiri	main	et
doc_685122975289_item	Kiri	main	et
doc_685122975290_item	Kiri	main	et
doc_685122975291_item	Kiri	main	et
doc_685122975292_item	Kiri	main	et
doc_685122975293_item	Kiri	main	et
doc_685122975294_item	Essee	main	et
doc_685122975295_item	Essee	main	et
doc_685122975296_item	Essee	main	et
doc_685122975297_item	Essee	main	et
doc_685122975298_item	Essee	main	et
doc_685122975299_item	Essee	main	et
doc_685122975300_item	Essee	main	et
doc_685122975301_item	Essee	main	et
doc_685122975302_item	Essee	main	et
doc_685122975303_item	Essee	main	et
doc_685122975304_item	Essee	main	et
doc_685122975305_item	Essee	main	et
doc_685122975306_item	Essee	main	et
doc_685122975307_item	Essee	main	et
doc_685122975308_item	Essee	main	et
doc_685122975309_item	Essee	main	et
doc_685122975310_item	Essee	main	et
doc_685122975311_item	Essee	main	et
doc_685122975312_item	Essee	main	et
doc_685122975313_item	Essee	main	et
doc_688103945038_item	Eksamitöö	main	et
doc_689641833088_item	 kontrolltöö	main	et
doc_689641833089_item	 kontrolltöö	main	et
doc_689641833090_item	 kontrolltöö	main	et
doc_689641833091_item	 Kiri	main	et
doc_689641833092_item	 kontrolltöö	main	et
doc_696163377508_item	kontrolltöö	main	et
doc_696163377509_item	kontrolltöö	main	et
doc_697936465046_item	Uus dokument	main	et
doc_6982649480_item	Essee	main	et
doc_701263568939_item	kontrolltöö	main	et
doc_701263568940_item	kontrolltöö	main	et
doc_705833728516_item	 Eksamitöö	main	et
doc_705833728517_item	 Eksamitöö	main	et
doc_705833728518_item	 Eksamitöö	main	et
doc_713316236902_item	kontrolltöö	main	et
doc_713316236903_item	kontrolltöö	main	et
doc_713316236904_item	kontrolltöö	main	et
doc_713316236905_item	 kontrolltöö	main	et
doc_713316236906_item	kontrolltöö	main	et
doc_713316236907_item	kontrolltöö	main	et
doc_713316236908_item	kontrolltöö	main	et
doc_714827497072_item	kontrolltöö	main	et
doc_714827497073_item	kontrolltöö	main	et
doc_723935141568_item	 Vastus küsimusele	main	et
doc_723935141570_item	 Vastus küsimusele	main	et
doc_724355862913_item	Essee	main	et
doc_724355862914_item	Essee	main	et
doc_724355862915_item	Essee	main	et
doc_724355862917_item	Essee	main	et
doc_724355862918_item	Essee	main	et
doc_724355862919_item	Essee	main	et
doc_724355862922_item	Essee	main	et
doc_725976921216_item	kontrolltöö	main	et
doc_725976921217_item	kontrolltöö	main	et
doc_737963622253_item	Elsamitöö	main	et
doc_737963622254_item	Eksamitöö	main	et
doc_737963622255_item	Eksamitöö	main	et
doc_740091150997_item	Essee	main	et
doc_740091150999_item	Essee	main	et
doc_740091151002_item	Essee	main	et
doc_740091151003_item	Essee	main	et
doc_740091151004_item	Essee	main	et
doc_740091151006_item	Essee	main	et
doc_740091151012_item	Essee	main	et
doc_740091151014_item	Essee	main	et
doc_740091151017_item	Essee	main	et
doc_744799184082_item	kontrolltöö	main	et
doc_744962874519_item	Uus dokument	main	et
doc_744962874522_item	Essee	main	et
doc_744962874524_item	Uus dokument	main	et
doc_744962874525_item	Essee	main	et
doc_744962874526_item	Essee	main	et
doc_744962874527_item	Uus dokument	main	et
doc_744962874529_item	Uus dokument	main	et
doc_744962874530_item	Essee	main	et
doc_744962874531_item	Essee	main	et
doc_744962874532_item	Uus dokument	main	et
doc_744962874533_item	Uus dokument	main	et
doc_744962874534_item	Uus dokument	main	et
doc_744962874535_item	Uus dokument	main	et
doc_744962874536_item	Uus dokument	main	et
doc_744962874537_item	Uus dokument	main	et
doc_744962874538_item	Essee	main	et
doc_744962874539_item	Uus dokument	main	et
doc_744962874540_item	Uus dokument	main	et
doc_744962874541_item	Essee	main	et
doc_744962874542_item	 Juhend	main	et
doc_744962874543_item	Juhend	main	et
doc_744962874544_item	Uus dokument	main	et
doc_744962874545_item	Uus dokument	main	et
doc_744962874546_item	Essee	main	et
doc_75394297594_item	ametlik kiri-kutse	main	et
doc_758697966141_item	 Analüüs	main	et
doc_758697966142_item	Analüüs	main	et
doc_761051790173_item	Uus dokument	main	et
doc_767882159205_item	Essee	main	et
doc_767882159208_item	Essee	main	et
doc_767882159213_item	Essee	main	et
doc_767882159220_item	Essee	main	et
doc_767882159221_item	Essee	main	et
doc_767882159222_item	Essee	main	et
doc_767882159224_item	Essee	main	et
doc_767882159227_item	Essee	main	et
doc_767882159228_item	Essee	main	et
doc_767882159230_item	Essee	main	et
doc_767882159231_item	Essee	main	et
doc_767882159232_item	Essee	main	et
doc_767882159233_item	Essee	main	et
doc_767882159235_item	Essee	main	et
doc_767882159236_item	Essee	main	et
doc_767882159238_item	Essee	main	et
doc_767882159242_item	Essee	main	et
doc_767882159244_item	Essee	main	et
doc_767882159245_item	Essee	main	et
doc_767882159249_item	Essee	main	et
doc_767882159252_item	Essee	main	et
doc_767882159254_item	Essee	main	et
doc_767882159257_item	Essee	main	et
doc_767882159258_item	Essee	main	et
doc_767882159264_item	Essee	main	et
doc_767882159266_item	Essee	main	et
doc_767882159269_item	Essee	main	et
doc_769634019905_item	Ametlik kiri	main	et
doc_769634019906_item	Ametlik kiri 	main	et
doc_769634019907_item	Analüüs	main	et
doc_769634019908_item	Ametlik kiri	main	et
doc_769634019909_item	Ametlik kiri	main	et
doc_769634019912_item	Essee	main	et
doc_771173210946_item	Eksamitöö	main	et
doc_771173210947_item	Eksamitöö	main	et
doc_771173210948_item	Eksamitöö	main	et
doc_771173210949_item	Ei ole midagi hirmsamat ...	main	et
doc_771173210950_item	Essee	main	et
doc_782723477918_item	 vastus küsimusele 	main	et
doc_785467701573_item	Vastus küsimusele	main	et
doc_786864950071_item	Uus dokument	main	et
doc_78691914849_item	Kontrolltöö	main	et
doc_78691914850_item	Kontrolltöö	main	et
doc_78691914851_item	Uus dokument	main	et
doc_78691914852_item	Leiutised	main	et
doc_78691914853_item	Kontrolltöö	main	et
doc_78691914854_item	Millest sõltub tervis	main	et
doc_788097534636_item	 kontrolltöö	main	et
doc_792821541744_item	 Kiri 	main	et
doc_792821541746_item	 Arvamus	main	et
doc_798444340112_item	vastus küsimusele	main	et
doc_801781988527_item	essee	main	et
doc_801781988528_item	essee	main	et
doc_801781988529_item	Essee	main	et
doc_801781988530_item	essee	main	et
doc_801781988531_item	essee	main	et
doc_801781988532_item	essee	main	et
doc_801781988533_item	Essee	main	et
doc_801781988534_item	essee	main	et
doc_801781988535_item	essee	main	et
doc_802069853715_item	essee	main	et
doc_802069853716_item	essee	main	et
doc_802069853717_item	essee	main	et
doc_802069853718_item	essee	main	et
doc_802069853719_item	essee	main	et
doc_802069853720_item	essee	main	et
doc_802069853721_item	essee	main	et
doc_802069853722_item	essee	main	et
doc_802069853723_item	essee	main	et
doc_802069853724_item	essee	main	et
doc_802069853727_item	essee	main	et
doc_802069853728_item	essee	main	et
doc_802069853729_item	essee	main	et
doc_802069853730_item	essee	main	et
doc_802069853731_item	essee	main	et
doc_802069853732_item	essee	main	et
doc_802069853734_item	essee	main	et
doc_802069853735_item	essee	main	et
doc_802069853736_item	essee	main	et
doc_802069853737_item	essee	main	et
doc_802069853738_item	essee	main	et
doc_802069853739_item	essee	main	et
doc_802069853740_item	essee	main	et
doc_802069853741_item	essee	main	et
doc_802069853742_item	essee	main	et
doc_802069853743_item	Harjutus	main	et
doc_802069853744_item	Harjutus	main	et
doc_802069853745_item	Harjutus	main	et
doc_802069853746_item	Harjutus	main	et
doc_802069853747_item	Harjutus	main	et
doc_802069853748_item	Harjutus	main	et
doc_802069853749_item	Harjutus	main	et
doc_802069853750_item	Harjutus	main	et
doc_802069853751_item	Harjutus	main	et
doc_802069853752_item	Harjutus	main	et
doc_802069853753_item	Harjutus	main	et
doc_802069853754_item	Harjutus	main	et
doc_802069853755_item	Harjutus	main	et
doc_802069853756_item	Harjutus	main	et
doc_802069853757_item	Harjutus	main	et
doc_802069853758_item	Harjutus	main	et
doc_802069853759_item	Harjutus	main	et
doc_802069853760_item	Harjutus	main	et
doc_802069853761_item	Harjutus	main	et
doc_802069853762_item	Harjutus	main	et
doc_802069853763_item	Harjutus	main	et
doc_802069853764_item	Harjutus	main	et
doc_802069853765_item	Harjutus	main	et
doc_802069853766_item	Harjutus	main	et
doc_802069853767_item	Harjutus	main	et
doc_802069853768_item	Harjutus	main	et
doc_802069853769_item	Harjutus	main	et
doc_802069853770_item	Harjutus	main	et
doc_802069853771_item	Harjutus	main	et
doc_802069853772_item	Harjutus	main	et
doc_802069853773_item	Harjutus	main	et
doc_802069853774_item	Harjutus	main	et
doc_802069853775_item	Harjutus	main	et
doc_802069853776_item	Harjutus	main	et
doc_802069853777_item	Harjutus	main	et
doc_802069853778_item	Harjutus	main	et
doc_802069853779_item	Harjutus	main	et
doc_802069853780_item	Harjutus	main	et
doc_802069853782_item	Essee	main	et
doc_802069853783_item	Essee	main	et
doc_802069853784_item	Essee	main	et
doc_802069853787_item	Essee	main	et
doc_802069853788_item	Essee	main	et
doc_802069853789_item	Essee	main	et
doc_802069853790_item	Essee	main	et
doc_802069853791_item	Essee	main	et
doc_802069853792_item	Essee	main	et
doc_802069853794_item	Essee	main	et
doc_802069853796_item	Essee	main	et
doc_802069853797_item	Essee	main	et
doc_802069853798_item	Essee	main	et
doc_802069853799_item	Essee	main	et
doc_802069853800_item	Essee	main	et
doc_802069853802_item	Essee	main	et
doc_802069853803_item	Essee	main	et
doc_802069853805_item	Essee	main	et
doc_802069853806_item	Essee	main	et
doc_802069853807_item	Essee	main	et
doc_802069853808_item	Essee	main	et
doc_802069853809_item	Essee	main	et
doc_802069853810_item	Essee	main	et
doc_802069853811_item	Essee	main	et
doc_804074096014_item	kontrolltöö	main	et
doc_819690035128_item	kontrolltöö	main	et
doc_819690035129_item	kontrolltöö	main	et
doc_820667236802_item	 Essee	main	et
doc_820667236803_item	 kontrolltöö	main	et
doc_826196946514_item	 kontrolltöö	main	et
doc_833156154878_item	kontrolltöö	main	et
doc_833156154879_item	kontrolltöö	main	et
doc_836620486402_item	Tänapäeva noored hoolivad oma tervisest rohkem kui keskealised	main	et
doc_836620486403_item	Kontrolltöö	main	et
doc_836620486404_item	Mida kõrgem on elatustase, seda vähem on kuritegusid	main	et
doc_836620486405_item	Koolidirektori kõne	main	et
doc_836620486406_item	Direktori kõne	main	et
doc_836620486407_item	Liiklusõnnetuse kirjeldus	main	et
doc_836620486408_item	Kaebus	main	et
doc_836620486409_item	Kontrolltöö	main	et
doc_836620486410_item	Millest sõltub eluiga?	main	et
doc_836620486411_item	Mis mõjutab eluiga?	main	et
doc_836620486412_item	Kaebus	main	et
doc_836620486413_item	Vastus töökonkursil osalenule	main	et
doc_836620486414_item	Seletuskiri	main	et
doc_836620486415_item	Inimese tervis sõltub elustiilist	main	et
doc_842434202394_item	Vastus küsimusele	main	et
doc_842434202398_item	Harjutus	main	et
doc_842434202399_item	Harjutus	main	et
doc_842434202400_item	Harjutus	main	et
doc_842434202403_item	essee	main	et
doc_842434202404_item	essee	main	et
doc_854846908872_item	kontrolltöö	main	et
doc_854846908873_item	kontrolltöö	main	et
doc_855437674538_item	kontrolltöö	main	et
doc_860756017853_item	 kontrolltöö	main	et
doc_860756017854_item	 kontrolltöö	main	et
doc_860756017855_item	 kontrolltöö	main	et
doc_860756017857_item	kontrolltöö	main	et
doc_862226128015_item	kontrolltöö	main	et
doc_862226128016_item	kontrolltöö	main	et
doc_862226128017_item	kontrolltöö	main	et
doc_862226128018_item	kontrolltöö	main	et
doc_862226128019_item	kontrolltöö	main	et
doc_866101568973_item	kontrolltöö	main	et
doc_86991684127_item	 Vastus küsimusele	main	et
doc_872470917318_item	kontrolltöö	main	et
doc_872470917320_item	kontrolltöö	main	et
doc_872470917321_item	kontrolltöö	main	et
doc_873901597503_item	Essee	main	et
doc_873901597504_item	Essee	main	et
doc_873901597505_item	Essee	main	et
doc_873901597506_item	Essee	main	et
doc_873901597507_item	Essee	main	et
doc_873901597508_item	Essee	main	et
doc_873901597509_item	Essee	main	et
doc_873901597510_item	Essee	main	et
doc_873901597511_item	Essee	main	et
doc_873901597512_item	Essee	main	et
doc_873901597513_item	Essee	main	et
doc_873901597514_item	Essee	main	et
doc_873901597515_item	Essee	main	et
doc_873901597516_item	Essee	main	et
doc_873901597517_item	Essee	main	et
doc_873901597518_item	Essee	main	et
doc_873901597519_item	Essee	main	et
doc_873901597520_item	Essee	main	et
doc_873901597521_item	Essee	main	et
doc_873901597522_item	Essee	main	et
doc_873901597523_item	Essee	main	et
doc_873901597524_item	Essee	main	et
doc_873901597525_item	Essee	main	et
doc_873901597526_item	Essee	main	et
doc_873901597527_item	Essee	main	et
doc_873901597528_item	Ametlik kiri	main	et
doc_873901597531_item	Essee	main	et
doc_873901597532_item	Essee	main	et
doc_873901597538_item	Essee	main	et
doc_873901597539_item	Essee	main	et
doc_873901597542_item	Essee	main	et
doc_873901597543_item	Essee	main	et
doc_873901597546_item	Essee	main	et
doc_873901597548_item	Essee	main	et
doc_873901597549_item	Essee	main	et
doc_873901597550_item	Essee	main	et
doc_873901597552_item	Essee	main	et
doc_873901597554_item	Essee	main	et
doc_873901597555_item	Essee	main	et
doc_873901597556_item	Essee	main	et
doc_873901597557_item	Essee	main	et
doc_873901597558_item	Essee	main	et
doc_873901597559_item	Essee	main	et
doc_873901597560_item	Essee	main	et
doc_873901597561_item	Essee	main	et
doc_873901597562_item	Essee	main	et
doc_873901597563_item	Essee	main	et
doc_873901597565_item	Essee	main	et
doc_873901597566_item	Essee	main	et
doc_873901597567_item	Essee	main	et
doc_873901597568_item	Essee	main	et
doc_873901597569_item	Essee	main	et
doc_881412446069_item	Essee	main	et
doc_881412446073_item	Essee	main	et
doc_881412446074_item	Essee	main	et
doc_881412446075_item	Essee	main	et
doc_881412446076_item	Essee	main	et
doc_881412446077_item	Essee	main	et
doc_887959124398_item	kontrolltöö	main	et
doc_897182025870_item	 vastus küsimusele 	main	et
doc_897182025871_item	 vastus küsimusele 	main	et
doc_897182025872_item	 vastus küsimusele 	main	et
doc_897182025873_item	 vastus küsimusele 	main	et
doc_899326610084_item	Vastus küsimusele	main	et
doc_899326610085_item	 Vastus küsimusele	main	et
doc_901133458138_item	Uus dokument	main	et
doc_901133458140_item	Harjutus	main	et
doc_901133458141_item	Uus dokument	main	et
doc_901133458143_item	Uus dokument	main	et
doc_901133458145_item	Harjutus	main	et
doc_901133458146_item	Uus dokument	main	et
doc_901133458147_item	Uus dokument	main	et
doc_901133458148_item	Uus dokument	main	et
doc_901133458149_item	Uus dokument	main	et
doc_901133458150_item	Essee	main	et
doc_901133458151_item	Uus dokument	main	et
doc_901133458152_item	Uus dokument	main	et
doc_901133458153_item	Uus dokument	main	et
doc_901133458154_item	Uus dokument	main	et
doc_901133458155_item	Uus dokument	main	et
doc_901133458157_item	Uus dokument	main	et
doc_901133458158_item	Uus dokument	main	et
doc_901133458160_item	Uus dokument	main	et
doc_901133458161_item	Uus dokument	main	et
doc_901133458162_item	Uus dokument	main	et
doc_901133458168_item	Uus dokument	main	et
doc_901133458169_item	Uus dokument	main	et
doc_901133458170_item	Uus dokument	main	et
doc_901133458171_item	Uus dokument	main	et
doc_901133458172_item	Uus dokument	main	et
doc_901133458175_item	Uus dokument	main	et
doc_901133458177_item	Uus dokument	main	et
doc_901133458178_item	Uus dokument	main	et
doc_901133458179_item	Uus dokument	main	et
doc_901133458180_item	Uus dokument	main	et
doc_901133458181_item	Uus dokument	main	et
doc_901133458182_item	Uus dokument	main	et
doc_901133458183_item	Uus dokument	main	et
doc_901133458184_item	Vastus küsimusele	main	et
doc_901133458185_item	Vastus küsimusele	main	et
doc_901133458186_item	Uus dokument	main	et
doc_901133458187_item	Uus dokument	main	et
doc_901133458189_item	Uus dokument	main	et
doc_901133458190_item	Uus dokument	main	et
doc_901133458192_item	Kiri	main	et
doc_910290104792_item	kontrolltöö	main	et
doc_910290104793_item	kontrolltöö	main	et
doc_919500587377_item	Referaat	main	et
doc_919500587378_item	Referaat	main	et
doc_919500587379_item	Referaat	main	et
doc_919500587380_item	Referaat	main	et
doc_919500587381_item	Essee	main	et
doc_919500587382_item	Essee	main	et
doc_919500587384_item	Essee	main	et
doc_919500587386_item	Essee	main	et
doc_919500587387_item	Essee	main	et
doc_929981265996_item	 Essee	main	et
doc_940752626606_item	kontrolltöö	main	et
doc_947478791302_item	Vastus küsimusele	main	et
doc_947478791303_item	Vastus küsimusele	main	et
doc_947478791304_item	Vastus küsimusele	main	et
doc_961923037877_item	kontrolltöö	main	et
doc_961923037878_item	kontrolltöö	main	et
doc_961938048511_item	 Vastus küsimusele	main	et
doc_968228746309_item	 Essee	main	et
doc_968228746310_item	 Essee	main	et
doc_96992327343_item	 Essee	main	et
doc_96992327344_item	 Essee	main	et
doc_973441205323_item	 vastus küsimusele 	main	et
doc_973441205324_item	 vastus küsimusele 	main	et
doc_973441205325_item	 vastus küsimusele 	main	et
doc_973441205326_item	 Telefonivestlus	main	et
doc_973441205327_item	Essee	main	et
doc_973441205328_item	Essee	main	et
doc_973441205329_item	vastus küsimusele	main	et
doc_973441205331_item	vastus küsimusele	main	et
doc_973441205332_item	vastus küsimusele	main	et
doc_973441205334_item	Essee	main	et
doc_973441205336_item	Essee	main	et
doc_973441205337_item	vastus küsimusele	main	et
doc_973441205339_item	Essee	main	et
doc_973441205352_item	Essee	main	et
doc_973441205353_item	Essee	main	et
doc_973441205354_item	Essee	main	et
doc_973441205355_item	Essee	main	et
doc_973441205357_item	vastus küsimusele	main	et
doc_973441205358_item	Ümberjutustus	main	et
doc_973441205359_item	Ümberjutustus	main	et
doc_973441205360_item	Ümberjutustus	main	et
doc_973441205361_item	Ümberjutustus	main	et
doc_973441205362_item	Ümberjutustus	main	et
doc_973441205363_item	Ümberjutustus	main	et
doc_973441205364_item	Ümberjutustus	main	et
doc_973441205365_item	Ümberjutustus	main	et
doc_973441205366_item	Ümberjutustus	main	et
doc_973441205367_item	Ümberjutustus	main	et
doc_973441205368_item	Ümberjutustus	main	et
doc_973441205369_item	Ümberjutustus	main	et
doc_973441205370_item	Ümberjutustus	main	et
doc_973441205371_item	Ümberjutustus	main	et
doc_973441205372_item	Ümberjutustus	main	et
doc_973441205373_item	Ümberjutustus	main	et
doc_973441205374_item	Essee	main	et
doc_973441205375_item	Essee	main	et
doc_973441205376_item	Essee	main	et
doc_973441205377_item	Essee	main	et
doc_973441205378_item	Essee	main	et
doc_973441205379_item	referaat	main	et
doc_974724932290_item	Essee	main	et
doc_975151536916_item	kontrolltöö	main	et
doc_975151536917_item	kontrolltöö	main	et
doc_975151536918_item	kontrolltöö	main	et
doc_975151536920_item	kontrolltöö	main	et
doc_980560860245_item	Dialoog	main	et
doc_980560860248_item	Harjutus	main	et
doc_980560860249_item	Harjutus	main	et
doc_980560860250_item	Harjutus	main	et
doc_980560860251_item	Essee	main	et
doc_980560860260_item	Essee	main	et
doc_980560860261_item	Pildi kirjeldus	main	et
doc_980560860263_item	Essee	main	et
doc_980560860265_item	Kontrolltöö	main	et
doc_980560860266_item	Kontrolltöö	main	et
doc_980560860267_item	Kontrolltöö	main	et
doc_980560860269_item	Kontrolltöö	main	et
doc_980560860270_item	Kontrolltöö	main	et
doc_980560860271_item	Kontrolltöö	main	et
doc_980560860276_item	Tõlge	main	et
doc_980560860277_item	Tõlge	main	et
doc_986203247096_item	 Arvamus	main	et
doc_986203247098_item	Uus dokument	main	et
doc_986203247101_item	 Arvamus	main	et
doc_986203247103_item	 Arvamus	main	et
doc_986203247105_item	 Arvamus	main	et
doc_986203247112_item	Kirjeldus	main	et
doc_986203247113_item	  Analüüs	main	et
doc_986203247115_item	 Kiri	main	et
doc_988291579395_item	Essee	main	et
doc_988291579396_item	Essee	main	et
doc_988291579397_item	 Essee	main	et
doc_988291579398_item	Ametlik kiri	main	et
doc_988291579399_item	Ametlik kiri	main	et
doc_995572625433_item	Ilma milleta ei saa tänapäeval elada	main	et
doc_995572625434_item	Ilma milleta ei saa tänapäeval elada	main	et
doc_995572625435_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_995572625436_item	Ilma milleta ei saa inimene tänapäeval elada	main	et
doc_995572625437_item	Ilma milleta ei saa tänapäeval elada	main	et
doc_995572625438_item	Ilma milleta ei saa inimene elada	main	et
doc_995572625439_item	Kliima mõjutab inimese elu	main	et
doc_995572625440_item	Milleta ei saa inimene elada	main	et
doc_995572625441_item	Milleta ei saa inimene elada	main	et
doc_995572625442_item	Ilma milleta ei saa inimene elada	main	et
doc_995572625443_item	Vene kool eesti keeles?	main	et
doc_995572625444_item	Naised on paremad autojuhid kui mehed	main	et
doc_995572625445_item	Millisena näen tuleviku kodu	main	et
doc_995572625446_item	Inimeste toitumisharjumuis mõjutab kõige rohkem reklaam	main	et
doc_553383122817_item	Eesti kultuuriloo referaat	main	et
doc_101672866015_item	Eesti kultuuriloo referaat	main	et
doc_237983010020_item		\N	x
doc_491521501775_item	Analüüs	main	et
doc_491521501781_item	Veaanalüüs	main	et
doc_491521501891_item	Veaanalüüsi kodutöö	main	et
doc_491521501867_item	Analüüs	main	et
doc_491521501757_item	Analüüs	main	et
doc_491521501783_item	Analüüs	main	et
doc_491521501675_item	Kiri	main	et
doc_285078626585_item	Kiri	main	et
doc_491521501702_item	Kiri	main	et
doc_491521501680_item	Kiri	main	et
doc_491521502042_item	Kiri	main	et
doc_491521501736_item	Kiri	main	et
doc_491521501737_item	Kiri	main	et
doc_491521501738_item	Kiri	main	et
doc_491521501977_item	Kiri	main	et
doc_491521501798_item	Kiri	main	et
doc_285078626586_item	Kirjavahetus	main	et
doc_842434202405_item	Kiri	main	et
doc_491521501940_item	Kiri	main	et
doc_441430986979_item	Harjutus	main	et
doc_491521501652_item	Kontrolltöö	main	et
doc_491521501651_item	Kontrolltöö	main	et
doc_491521501657_item	Kontrolltöö	main	et
doc_491521501911_item	Eksamitöö	main	et
doc_491521502069_item	Kontrolltöö	main	et
doc_491521502070_item	Kontrolltöö	main	et
doc_491521502074_item	Kontrolltöö	main	et
doc_491521502075_item	Kontrolltöö	main	et
doc_491521502076_item	Kontrolltöö	main	et
doc_491521502077_item	Kontrolltöö	main	et
doc_542009824806_item	Juhend	main	et
doc_491521502071_item	Kontrolltöö	main	et
doc_491521502072_item	Kontrolltöö	main	et
doc_491521502073_item	Kontrolltöö	main	et
doc_491521502079_item	Kontrolltöö	main	et
doc_491521502080_item	Kontrolltöö	main	et
doc_491521502081_item	Kontrolltöö	main	et
doc_491521501855_item	Veaanalüüs (kontrastiivlingvistika)	main	et
doc_491521501729_item	Kiri	main	et
doc_193540241569_item	Eksam	main	et
doc_617668397745_item	Kontrolltöö	main	et
doc_617668397746_item	Kontrolltöö	main	et
doc_617668397752_item	Kontrolltöö	main	et
doc_213943984904_item	 Päevik	main	et
doc_792821541745_item	 Arvamus	main	et
doc_171929905769_item	Kontrolltöö eesti kultuuriloost	main	et
doc_901133458156_item	Juhend	main	et
doc_901133458159_item	Juhend	main	et
doc_214589672702_item	Meid ümbritseva maailma ohud ja võlud (laused)	main	et
doc_491521501804_item	Pildi kirjeldus	main	et
doc_491521501805_item	Pildi kirjeldus	main	et
doc_491521501806_item	Pildi kirjeldus	main	et
doc_491521501807_item	Pildi kirjeldus	main	et
doc_491521501835_item	Ümberjutustus	main	et
doc_491521501836_item	Ümberjutustus	main	et
doc_491521501837_item	Pildi kirjeldus	main	et
doc_491521501838_item	Pildi kirjeldus	main	et
doc_491521501882_item	Eksamitöö	main	et
doc_491521501883_item	Eksamitöö	main	et
doc_491521501884_item	 Eksamitöö	main	et
doc_491521501885_item	Eksamitöö	main	et
doc_491521501886_item	Eksamitöö	main	et
doc_491521501887_item	Eksamitöö	main	et
doc_491521501939_item	Eksamitöö	main	et
doc_491521502058_item	Eksamitöö	main	et
doc_973441205340_item	Pildi kirjeldus	main	et
doc_485437783974_item	Vastus küsimusele	main	et
doc_344825459480_item	Vastus küsimusele	main	et
doc_681992022012_item	Pildi kirjeldus	main	et
doc_873901597530_item	Pildi kirjeldus	main	et
doc_842434202406_item	Suulise keele näited	main	et
doc_542009824807_item	Juhend	main	et
doc_40918597559_item	Leping	main	et
doc_40918597560_item	Leping	main	et
doc_40918597562_item	Leping	main	et
doc_40918597563_item	Leping	main	et
doc_40918597564_item	Leping	main	et
doc_40918597566_item	Leping	main	et
doc_40918597568_item	Leping	main	et
doc_40918597569_item	Leping	main	et
doc_40918597570_item	Leping	main	et
doc_40918597571_item	Leping	main	et
doc_464301607717_item	Pildi kirjeldus	main	et
doc_534729444676_item	Päevik	main	et
doc_534729444677_item	Päevik	main	et
doc_534729444680_item	Päevik	main	et
doc_534729444681_item	Päevik	main	et
doc_534729444682_item	Päevik	main	et
doc_534729444683_item	Päevik	main	et
doc_534729444685_item	Päevik	main	et
doc_534729444687_item	Päevik	main	et
doc_534729444690_item	Päevik	main	et
doc_534729444691_item	Päevik	main	et
doc_534729444692_item	Päevik	main	et
doc_534729444694_item	Päevik	main	et
doc_534729444695_item	Päevik	main	et
doc_534729444699_item	Päevik	main	et
doc_284706151131_item	Vastus küsimusele	main	et
doc_284706151133_item	Vastus küsimusele	main	et
doc_40918597561_item	Leping	main	et
doc_40918597567_item	Leping	main	et
doc_617668397759_item	Kontrolltöö	main	et
doc_980560860268_item	Kontrolltöö	main	et
doc_491521501878_item	Eksamitöö	main	et
doc_491521501880_item	Eksamitöö	main	et
doc_491521501786_item	Seminaritöö	main	et
doc_491521501785_item	Seminaritöö	main	et
doc_491521501748_item	Vigase keelekasutuse näited	main	et
doc_45618460769_item	Milleta tänapäevainimene elada ei saaks	main	et
doc_40918597565_item	Leping	main	et
doc_534729444698_item	Päevik	main	et
doc_491521501753_item	Seminaritöö	main	et
doc_534729444693_item	Päevik	main	et
doc_399014257218_item	Tõlge	main	et
doc_399014257225_item	Tõlge	main	et
doc_399014257226_item	Tõlge	main	et
doc_399014257229_item	Tõlge	main	et
doc_399014257232_item	Tõlge	main	et
doc_399014257233_item	Tõlge	main	et
doc_399014257234_item	Tõlge	main	et
doc_399014257238_item	Tõlge	main	et
doc_399014257239_item	Tõlge	main	et
doc_399014257240_item	Tõlge	main	et
doc_213943984923_item	Tõlge	main	et
doc_399014257250_item	Tõlge	main	et
doc_399014257249_item	Tõlge	main	et
doc_399014257248_item	Tõlge	main	et
doc_237632014900_item	Tõlge	main	et
doc_237632014901_item	Tõlge	main	et
doc_237632014902_item	Tõlge	main	et
doc_40918597573_item	Tõlge	main	et
doc_980560860278_item	Tõlge	main	et
doc_980560860279_item	Tõlge	main	et
doc_213943984914_item	Tõlge	main	et
doc_384045275266_item	Tõlge	main	et
doc_399014257247_item	Tõlge	main	et
doc_399014257246_item	Tõlge	main	et
doc_399014257244_item	Tõlge	main	et
doc_399014257224_item	Tõlge	main	et
doc_399014257221_item	Tõlge	main	et
doc_59711134398_item	Ametlik kiri	main	et
doc_59711134400_item	Ametlik kiri	main	et
doc_59711134401_item	Ametlik kiri	main	et
doc_59711134405_item	Ametlik kiri	main	et
doc_59711134407_item	Ametlik kiri	main	et
doc_59711134408_item	Ametlik kiri	main	et
doc_59711134413_item	Kiri	main	et
doc_59711134414_item	Kiri	main	et
doc_59711134416_item	Kiri	main	et
doc_399014257175_item	Kiri	main	et
doc_213943985012_item	Kiri	main	et
doc_491521501669_item	Kiri	main	et
doc_491521501703_item	Kiri	main	et
doc_491521501704_item	Kiri	main	et
doc_491521501706_item	Kiri	main	et
doc_491521501709_item	Kiri	main	et
doc_491521501712_item	Kiri	main	et
doc_491521501713_item	Kiri	main	et
doc_491521501714_item	Kiri	main	et
doc_491521501716_item	Kiri	main	et
doc_491521501718_item	Kiri	main	et
doc_744962874521_item	Kiri	main	et
doc_901133458139_item	Kiri	main	et
doc_901133458142_item	Kiri	main	et
doc_901133458191_item	Kiri	main	et
doc_491521502048_item	Kiri	main	et
doc_491521502050_item	Kiri	main	et
doc_491521502066_item	Kiri	main	et
doc_491521501668_item	Kiri	main	et
doc_491521501711_item	Kiri	main	et
doc_491521501731_item	Kiri	main	et
doc_491521501920_item	Kiri	main	et
doc_491521501923_item	Kiri	main	et
doc_491521501926_item	Kiri	main	et
doc_491521501927_item	Kiri	main	et
doc_491521501929_item	Kiri	main	et
doc_491521501930_item	Essee	main	et
doc_491521501934_item	Essee	main	et
doc_491521501979_item	 Kiri	main	et
doc_491521501985_item	Kiri	main	et
doc_491521501990_item	Kiri	main	et
doc_744962874523_item	Kiri 	main	et
doc_761051790172_item	Kiri	main	et
doc_584615399785_item	Kiri	main	et
doc_584615399786_item	Kiri	main	et
doc_584615399787_item	Kiri	main	et
doc_584615399788_item	Kiri	main	et
doc_584615399789_item	Kiri	main	et
doc_584615399790_item	Kiri	main	et
doc_584615399791_item	Kiri	main	et
doc_584615399792_item	 Kiri 	main	et
doc_584615399793_item	 Kiri	main	et
doc_584615399794_item	Kiri 	main	et
doc_584615399795_item	 Kiri 	main	et
doc_584615399796_item	 Kiri 	main	et
doc_584615399797_item	 Kiri 	main	et
doc_584615399798_item	 Kiri 	main	et
doc_584615399799_item	Kiri 	main	et
doc_584615399800_item	Kiri 	main	et
doc_584615399801_item	Kiri 	main	et
doc_584615399802_item	Kiri 	main	et
doc_584615399803_item	Kiri 	main	et
doc_584615399804_item	Kiri	main	et
doc_584615399805_item	Kiri 	main	et
doc_584615399806_item	Kiri 	main	et
doc_397823702000_item	Kiri	main	et
doc_397823702001_item	Kiri	main	et
doc_397823702002_item	Kiri	main	et
doc_397823702003_item	Kiri	main	et
doc_397823702004_item	Kiri	main	et
doc_397823702005_item	Kiri	main	et
doc_397823702006_item	Kiri	main	et
doc_397823702007_item	Kiri	main	et
doc_397823702008_item	Kiri	main	et
doc_397823702009_item	Kiri	main	et
doc_397823702010_item	Kiri	main	et
doc_397823702011_item	Kiri	main	et
doc_397823702013_item	Kiri	main	et
doc_397823702014_item	Kiri	main	et
doc_986203247114_item	Kiri	main	et
doc_600559928978_item	 Kiri 	main	et
doc_600559928979_item	Kiri 	main	et
doc_600559928980_item	Kiri 	main	et
doc_600559928983_item	 Kiri 	main	et
doc_600559928984_item	 Kiri 	main	et
doc_600559928985_item	Kiri 	main	et
doc_600559928987_item	 Kiri 	main	et
doc_600559928988_item	Kiri 	main	et
doc_600559928989_item	Kiri 	main	et
doc_600559928991_item	Kiri 	main	et
doc_600559928992_item	Kiri 	main	et
doc_600559928993_item	Kiri 	main	et
doc_600559928994_item	Kiri 	main	et
doc_600559928998_item	Kiri 	main	et
doc_600559928999_item	Kiri 	main	et
doc_600559929000_item	Kiri 	main	et
doc_600559929003_item	Kiri 	main	et
doc_873901597529_item	Isiklik kiri	main	et
doc_464301607718_item	Kiri	main	et
doc_491521501949_item	Kiri	main	et
doc_491521502032_item	Kiri	main	et
doc_600559929004_item	Kiri	main	et
doc_901133458188_item	Kiri	main	et
doc_685122975262_item	Ametlik kiri	main	et
doc_685122975256_item	Ametlik kiri	main	et
doc_685122975255_item	Ametlik kiri	main	et
doc_491521501797_item	Kiri	main	et
doc_491521501722_item	Kiri	main	et
doc_491521501720_item	Kiri	main	et
doc_685122975257_item	Ametlik kiri	main	et
doc_685122975258_item	Ametlik kiri	main	et
doc_685122975259_item	Ametlik kiri	main	et
doc_685122975260_item	Ametlik kiri	main	et
doc_685122975261_item	Ametlik kiri	main	et
doc_685122975263_item	Ametlik kiri	main	et
doc_685122975265_item	Ametlik kiri	main	et
doc_685122975267_item	Ametlik kiri	main	et
doc_573958253415_item	Ametlik kiri	main	et
doc_491521502035_item	Kiri	main	et
doc_573958253417_item	Ametlik kiri	main	et
doc_685122975269_item	Ametlik kiri	main	et
doc_432051777927_item	Ametlik kiri	main	et
doc_432051777928_item	Ametlik kiri	main	et
doc_51880851200_item	Ametlik kiri	main	et
doc_491521502051_item	Kiri	main	et
doc_491521502054_item	Kiri	main	et
doc_491521501670_item	Kiri	main	et
doc_491521501903_item	Ametlik kiri	main	et
doc_491521501904_item	Ametlik kiri	main	et
doc_744962874520_item	Kiri	main	et
doc_973441205342_item	Ametlik kiri	main	et
doc_973441205343_item	Ametlik kiri	main	et
doc_973441205348_item	Ametlik kiri	main	et
doc_986203247095_item	Kiri 	main	et
doc_986203247097_item	Kiri 	main	et
doc_986203247100_item	Kiri 	main	et
doc_986203247102_item	Kiri 	main	et
doc_986203247104_item	Kiri 	main	et
doc_986203247106_item	Kiri 	main	et
doc_986203247108_item	Kiri 	main	et
doc_432051777900_item	Ametlik kiri	main	et
doc_51880851201_item	Vastus järelepärimiskirjale	main	et
doc_542009824799_item	Ametlik kiri	main	et
doc_384045275262_item	Avaldus	main	et
doc_986203247110_item	Kiri 	main	et
doc_491521502055_item	Kiri	main	et
doc_491521502057_item	Kiri	main	et
doc_491521502060_item	Kiri	main	et
doc_491521502061_item	Kiri	main	et
doc_491521501950_item	Kiri	main	et
doc_491521501951_item	Kiri	main	et
doc_584615399810_item	Ametlik kiri	main	et
doc_397823701992_item	Ametlik kiri	main	et
doc_397823701998_item	Ametlik kiri	main	et
doc_491521501734_item	Kiri	main	et
doc_491521501767_item	Avaldus	main	et
doc_491521501733_item	Kiri	main	et
doc_491521501730_item	Kiri	main	et
doc_634572338221_item	Ametlik kiri	main	et
doc_634572338217_item	Ametlik kiri	main	et
doc_634572338215_item	Ametlik kiri	main	et
doc_634572338211_item	Ametlik kiri	main	et
doc_634572338207_item	Ametlik kiri	main	et
doc_432051777921_item	Kiri	main	et
doc_317833399028_item	Kiri	main	et
doc_317833399027_item	Kiri	main	et
doc_40918597557_item	Avaldus	main	et
doc_40918597556_item	Avaldus	main	et
doc_634572338237_item	Seletuskiri	main	et
doc_542009824800_item	Kuulutus	main	et
doc_397823701988_item	Ametlik kiri	main	et
doc_15203423349_item	Järelpärimine	main	et
doc_973441205341_item	Aruanne	main	et
doc_973441205351_item	Järelpärimine	main	et
doc_460280307200_item	Ettepanek	main	et
doc_52744525863_item	Järelpärimine	main	et
doc_285078626584_item	Taotlus	main	et
doc_40918597555_item	Avaldus	main	et
doc_40918597554_item	Avaldus	main	et
doc_40918597553_item	Avaldus	main	et
doc_40918597552_item	Avaldus	main	et
doc_542009824801_item	Avaldus	main	et
doc_842434202402_item	Taotlus	main	et
doc_842434202396_item	Seletuskiri	main	et
doc_973441205350_item	Järelpärimine	main	et
doc_973441205347_item	Aruanne	main	et
doc_973441205346_item	Aruanne	main	et
doc_973441205345_item	Aruanne	main	et
doc_973441205344_item	Aruanne	main	et
doc_973441205338_item	Järelpärimine	main	et
doc_973441205356_item	Järelpärimine	main	et
doc_634572338236_item	Seletuskiri	main	et
doc_432051777919_item	Kiri	main	et
doc_491521501723_item	Kiri	main	et
doc_59711134412_item	Essee	main	et
doc_193540241556_item	Essee	main	et
doc_193540241557_item	Essee	main	et
doc_193540241558_item	Essee	main	et
doc_193540241559_item	Essee	main	et
doc_193540241560_item	Essee	main	et
doc_193540241561_item	Essee	main	et
doc_193540241562_item	Essee	main	et
doc_193540241563_item	Essee	main	et
doc_193540241564_item	Essee	main	et
doc_193540241565_item	Essee	main	et
doc_399014257167_item	Essee	main	et
doc_399014257168_item	Essee	main	et
doc_399014257170_item	Essee	main	et
doc_399014257172_item	Essee	main	et
doc_399014257173_item	Essee	main	et
doc_399014257174_item	Essee	main	et
doc_399014257176_item	Essee	main	et
doc_399014257177_item	Essee	main	et
doc_399014257178_item	Essee	main	et
doc_399014257179_item	Essee	main	et
doc_399014257180_item	Essee	main	et
doc_399014257181_item	Essee	main	et
doc_399014257183_item	Essee	main	et
doc_399014257184_item	Essee	main	et
doc_399014257185_item	Essee	main	et
doc_399014257186_item	Essee	main	et
doc_399014257188_item	Essee	main	et
doc_399014257189_item	Essee	main	et
doc_399014257190_item	Essee	main	et
doc_399014257191_item	Essee	main	et
doc_399014257192_item	Essee	main	et
doc_399014257193_item	Essee	main	et
doc_399014257194_item	Essee	main	et
doc_399014257195_item	Essee	main	et
doc_399014257198_item	Essee	main	et
doc_399014257200_item	Essee	main	et
doc_399014257201_item	Essee	main	et
doc_399014257203_item	Essee	main	et
doc_399014257204_item	Essee	main	et
doc_399014257205_item	Essee	main	et
doc_399014257210_item	Essee	main	et
doc_399014257211_item	Essee	main	et
doc_120968879146_item	Essee	main	et
doc_187964557905_item	Essee	main	et
doc_187964557909_item	Essee	main	et
doc_213943984911_item	Essee	main	et
doc_213943984939_item	Essee	main	et
doc_213943984955_item	Essee	main	et
doc_213943984957_item	Essee	main	et
doc_213943984963_item	Essee	main	et
doc_213943984988_item	Essee	main	et
doc_213943985014_item	Essee	main	et
doc_213943985018_item	Essee	main	et
doc_213943985029_item	Essee	main	et
doc_213943985048_item	Essee	main	et
doc_213943985071_item	Essee	main	et
doc_213943985075_item	Essee	main	et
doc_333816885025_item	Essee	main	et
doc_392411160215_item	Essee	main	et
doc_392411160219_item	Essee	main	et
doc_392411160220_item	Essee	main	et
doc_392411160223_item	Essee	main	et
doc_397823701999_item	Essee	main	et
doc_532115409095_item	Essee	main	et
doc_446717232819_item	Essee	main	et
doc_491521501770_item	Essee	main	et
doc_491521501789_item	Essee	main	et
doc_491521501796_item	Essee	main	et
doc_491521501917_item	Essee	main	et
doc_491521501991_item	Essee	main	et
doc_491521501993_item	Essee	main	et
doc_491521502149_item	Essee 	main	et
doc_491521502150_item	Essee	main	et
doc_491521502155_item	Essee	main	et
doc_527420171751_item	Essee	main	et
doc_542009824793_item	Essee	main	et
doc_567528375368_item	Essee	main	et
doc_567528375369_item	Essee	main	et
doc_617668397762_item	Essee	main	et
doc_617668397765_item	Essee	main	et
doc_634572338226_item	Essee	main	et
doc_634572338233_item	Essee	main	et
doc_634572338244_item	Essee	main	et
doc_724355862916_item	Essee	main	et
doc_724355862920_item	Essee	main	et
doc_724355862923_item	Essee	main	et
doc_802069853714_item	Essee	main	et
doc_802069853725_item	Essee	main	et
doc_802069853726_item	Essee	main	et
doc_802069853733_item	Essee	main	et
doc_802069853781_item	Essee	main	et
doc_802069853785_item	Essee	main	et
doc_802069853786_item	Essee	main	et
doc_802069853795_item	Essee	main	et
doc_802069853801_item	Essee	main	et
doc_802069853804_item	Essee	main	et
doc_873901597537_item	Essee	main	et
doc_873901597544_item	Essee	main	et
doc_873901597547_item	Essee	main	et
doc_873901597551_item	Essee	main	et
doc_873901597553_item	Essee	main	et
doc_873901597564_item	Essee	main	et
doc_919500587383_item	Essee	main	et
doc_919500587385_item	Essee	main	et
doc_919500587388_item	Essee	main	et
doc_986203247107_item	Arvamus	main	et
doc_986203247109_item	Arvamus	main	et
doc_881412446071_item	Essee	main	et
doc_767882159207_item	Essee	main	et
doc_767882159206_item	Essee	main	et
doc_767882159209_item	Essee	main	et
doc_767882159210_item	Essee	main	et
doc_767882159211_item	Essee	main	et
doc_767882159214_item	Essee	main	et
doc_767882159215_item	Essee	main	et
doc_767882159216_item	Essee	main	et
doc_767882159217_item	Essee	main	et
doc_767882159218_item	Essee	main	et
doc_767882159219_item	Essee	main	et
doc_767882159223_item	Essee	main	et
doc_767882159225_item	Essee	main	et
doc_767882159226_item	Essee	main	et
doc_767882159229_item	Essee	main	et
doc_767882159234_item	Essee	main	et
doc_767882159239_item	Essee	main	et
doc_767882159240_item	Essee	main	et
doc_767882159241_item	Essee	main	et
doc_767882159243_item	Essee	main	et
doc_767882159246_item	Essee	main	et
doc_767882159247_item	Essee	main	et
doc_767882159248_item	Essee	main	et
doc_767882159250_item	Essee	main	et
doc_767882159251_item	Essee	main	et
doc_767882159253_item	Essee	main	et
doc_767882159255_item	Essee	main	et
doc_767882159256_item	Essee	main	et
doc_767882159259_item	Essee	main	et
doc_767882159260_item	Essee	main	et
doc_767882159261_item	Essee	main	et
doc_767882159262_item	Essee	main	et
doc_767882159263_item	Essee	main	et
doc_767882159265_item	Essee	main	et
doc_767882159267_item	Essee	main	et
doc_767882159268_item	Essee	main	et
doc_767882159270_item	Essee	main	et
doc_767882159271_item	Essee	main	et
doc_399014257202_item	Harjutus	main	et
doc_213943985053_item	Harjutus	main	et
doc_213943985054_item	Harjutus	main	et
doc_213943985055_item	Harjutus	main	et
doc_213943985056_item	Harjutus	main	et
doc_213943985058_item	Harjutus	main	et
doc_432051777912_item	Harjutus	main	et
doc_399014257217_item	Dialoog	main	et
doc_399014257209_item	Dialoog	main	et
doc_491521501918_item	Harjutus	main	et
doc_842434202397_item	Harjutus	main	et
doc_542009824771_item	Harjutus	main	et
doc_542009824810_item	Harjutus	main	et
doc_286998102737_item	Pildi kirjeldus	main	et
doc_286998102739_item	Pildi kirjeldus	main	et
doc_286998102743_item	Pildi kirjeldus	main	et
doc_286998102745_item	Pildi kirjeldus	main	et
doc_286998102746_item	Pildi kirjeldus	main	et
doc_286998102748_item	Pildi kirjeldus	main	et
doc_286998102749_item	Pildi kirjeldus	main	et
doc_286998102750_item	Pildi kirjeldus	main	et
doc_286998102751_item	Pildi kirjeldus	main	et
doc_286998102753_item	Pildi kirjeldus	main	et
doc_286998102754_item	Pildi kirjeldus	main	et
doc_286998102755_item	Pildi kirjeldus	main	et
doc_286998102758_item	Pildi kirjeldus	main	et
doc_286998102759_item	Harjutus	main	et
doc_464301607713_item	Harjutus	main	et
doc_980560860246_item	Dialoog	main	et
doc_980560860252_item	Dialoog	main	et
doc_980560860256_item	Harjutus	main	et
doc_980560860257_item	Dialoog	main	et
doc_574559240059_item	Harjutus	main	et
doc_35015649953_item	Päevik	main	et
doc_35015649954_item	Päevik	main	et
doc_786864950072_item	Pildi kirjeldus	main	et
doc_786864950073_item	Pildi kirjeldus	main	et
doc_786864950074_item	Pildi kirjeldus	main	et
doc_786864950075_item	Pildi kirjeldus	main	et
doc_786864950076_item	Pildi kirjeldus	main	et
doc_786864950077_item	Pildi kirjeldus	main	et
doc_786864950078_item	Pildi kirjeldus	main	et
doc_786864950079_item	Harjutus	main	et
doc_786864950080_item	Harjutus	main	et
doc_786864950081_item	Harjutus	main	et
doc_786864950082_item	Harjutus	main	et
doc_786864950083_item	Harjutus	main	et
doc_786864950084_item	Harjutus	main	et
doc_786864950085_item	Harjutus	main	et
doc_399014257213_item	Dialoog	main	et
doc_542009824769_item	Menüü	main	et
doc_542009824770_item	Menüü	main	et
doc_542009824814_item	Harjutus	main	et
doc_685122975264_item	Kiri	main	et
doc_491521502045_item	Kiri	main	et
doc_491521501735_item	Ametlik kiri	main	et
doc_491521501906_item	Ametlik kiri	main	et
doc_973441205349_item	Järelpärimine	main	et
doc_432051777904_item	Kiri	main	et
doc_432051777913_item	Kiri	main	et
doc_40918597558_item	Avaldus	main	et
doc_384045275269_item	Referaat	main	et
doc_384045275270_item	Referaat	main	et
doc_366216787874_item	Essee	main	et
doc_366216787876_item	Essee	main	et
doc_366216787877_item	Essee	main	et
doc_366216787878_item	Essee	main	et
doc_366216787882_item	Essee	main	et
doc_366216787884_item	Essee	main	et
doc_366216787886_item	Essee	main	et
doc_366216787889_item	Essee	main	et
doc_366216787892_item	Essee	main	et
doc_366216787894_item	Essee	main	et
doc_366216787896_item	Essee	main	et
doc_366216787899_item	Essee	main	et
doc_366216787901_item	Essee	main	et
doc_366216787902_item	Essee	main	et
doc_366216787903_item	Essee	main	et
doc_366216787905_item	Essee	main	et
doc_366216787907_item	Essee	main	et
doc_366216787908_item	Essee	main	et
doc_366216787909_item	Essee	main	et
doc_366216787910_item	Essee	main	et
doc_213943984965_item	Essee	main	et
doc_213943984978_item	Essee	main	et
doc_213943984980_item	Essee	main	et
doc_213943984986_item	Essee	main	et
doc_213943985001_item	Essee	main	et
doc_213943985008_item	Essee	main	et
doc_213943985010_item	Essee	main	et
doc_213943985015_item	Essee	main	et
doc_213943985017_item	Essee	main	et
doc_213943985021_item	Essee	main	et
doc_213943985027_item	Essee	main	et
doc_213943985028_item	Essee	main	et
doc_213943985030_item	Essee	main	et
doc_213943985033_item	Essee	main	et
doc_213943985035_item	Essee	main	et
doc_213943985036_item	Essee	main	et
doc_213943985039_item	Essee	main	et
doc_213943985040_item	Essee	main	et
doc_724355862921_item	Essee	main	et
doc_187964557896_item	Essee	main	et
doc_187964557907_item	Essee	main	et
doc_670731433409_item	Essee	main	et
doc_670731433411_item	Essee	main	et
doc_670731433413_item	Essee	main	et
doc_670731433414_item	Essee	main	et
doc_670731433415_item	Essee	main	et
doc_670731433417_item	Essee	main	et
doc_670731433421_item	Essee	main	et
doc_670731433424_item	Essee	main	et
doc_532115409103_item	Essee	main	et
doc_802069853793_item	Essee	main	et
doc_120968879150_item	Essee	main	et
doc_120968879152_item	Essee	main	et
doc_873901597533_item	Essee	main	et
doc_873901597534_item	Essee	main	et
doc_873901597535_item	Essee	main	et
doc_873901597536_item	Essee	main	et
doc_873901597540_item	Essee	main	et
doc_873901597541_item	Essee	main	et
doc_873901597545_item	Essee	main	et
doc_286998102732_item	Essee	main	et
doc_286998102733_item	Essee	main	et
doc_286998102734_item	Essee	main	et
doc_286998102735_item	Essee	main	et
doc_286998102736_item	Essee	main	et
doc_286998102738_item	Essee	main	et
doc_286998102740_item	Essee	main	et
doc_286998102741_item	Pildi kirjeldus	main	et
doc_286998102742_item	Essee	main	et
doc_286998102744_item	Essee	main	et
doc_286998102747_item	Essee	main	et
doc_286998102752_item	Essee	main	et
doc_286998102760_item	Essee	main	et
doc_286998102761_item	Essee	main	et
doc_286998102762_item	Essee	main	et
doc_286998102763_item	Essee	main	et
doc_286998102764_item	Essee	main	et
doc_286998102765_item	Essee	main	et
doc_536541856856_item	Essee	main	et
doc_536541856857_item	Essee	main	et
doc_536541856866_item	Essee	main	et
doc_536541856867_item	Essee	main	et
doc_536541856871_item	Essee	main	et
doc_536541856872_item	Essee	main	et
doc_536541856873_item	Essee	main	et
doc_536541856874_item	Essee	main	et
doc_536541856878_item	Essee	main	et
doc_536541856879_item	Essee	main	et
doc_536541856880_item	Essee	main	et
doc_536541856881_item	Essee	main	et
doc_536541856882_item	Essee	main	et
doc_536541856884_item	Essee	main	et
doc_536541856885_item	Essee	main	et
doc_536541856886_item	Essee	main	et
doc_536541856892_item	Essee	main	et
doc_536541856894_item	Essee	main	et
doc_536541856895_item	Essee	main	et
doc_536541856897_item	Essee	main	et
doc_536541856899_item	Essee	main	et
doc_536541856902_item	Essee	main	et
doc_536541856905_item	Essee	main	et
doc_536541856906_item	Essee	main	et
doc_536541856910_item	Essee	main	et
doc_536541856911_item	Essee	main	et
doc_852214925993_item	Essee	main	et
doc_464301607714_item	Essee	main	et
doc_464301607719_item	Essee	main	et
doc_464301607739_item	Essee	main	et
doc_464301607740_item	Essee	main	et
doc_980560860247_item	Essee	main	et
doc_980560860253_item	Essee	main	et
doc_980560860254_item	Essee	main	et
doc_980560860255_item	Essee	main	et
doc_980560860258_item	Essee	main	et
doc_980560860259_item	Essee	main	et
doc_980560860262_item	Essee	main	et
doc_980560860264_item	Essee	main	et
doc_128876189872_item	 Arvamus	main	et
doc_534729444708_item	Essee	main	et
doc_534729444709_item	Essee	main	et
doc_534729444710_item	Essee	main	et
doc_534729444712_item	Essee	main	et
doc_534729444713_item	Essee	main	et
doc_534729444714_item	Essee	main	et
doc_534729444715_item	Essee	main	et
doc_534729444718_item	Essee	main	et
doc_534729444720_item	Essee	main	et
doc_534729444721_item	Essee	main	et
doc_534729444723_item	Essee	main	et
doc_534729444727_item	Essee	main	et
doc_534729444728_item	Essee	main	et
doc_534729444731_item	Essee	main	et
doc_534729444735_item	Essee	main	et
doc_534729444738_item	Essee	main	et
doc_534729444743_item	Essee	main	et
doc_35015649955_item	Essee	main	et
doc_35015649956_item	Essee	main	et
doc_35015649958_item	Essee	main	et
doc_35015649959_item	Essee	main	et
doc_35015649960_item	Essee	main	et
doc_786864950086_item	Essee	main	et
doc_786864950087_item	Essee	main	et
doc_278690626900_item	Essee	main	et
doc_278690626901_item	Essee	main	et
doc_278690626902_item	Essee	main	et
doc_278690626903_item	Essee	main	et
doc_278690626906_item	Essee	main	et
doc_278690626911_item	Essee	main	et
doc_278690626913_item	Essee	main	et
doc_278690626914_item	Essee	main	et
doc_278690626915_item	Essee	main	et
doc_278690626917_item	Essee	main	et
doc_278690626919_item	Essee	main	et
doc_278690626923_item	Essee	main	et
doc_278690626924_item	Essee	main	et
doc_278690626925_item	Essee	main	et
doc_278690626926_item	Essee	main	et
doc_278690626927_item	Essee	main	et
doc_278690626928_item	Essee	main	et
doc_278690626929_item	Essee	main	et
doc_278690626932_item	Essee	main	et
doc_278690626933_item	Essee	main	et
doc_278690626934_item	Essee	main	et
doc_278690626935_item	Essee	main	et
doc_278690626936_item	Essee	main	et
doc_278690626937_item	Essee	main	et
doc_278690626938_item	Essee	main	et
doc_278690626939_item	Essee	main	et
doc_278690626942_item	Essee	main	et
doc_278690626943_item	Essee	main	et
doc_278690626944_item	Essee	main	et
doc_278690626946_item	Essee	main	et
doc_278690626949_item	Essee	main	et
doc_278690626950_item	Essee	main	et
doc_278690626951_item	Essee	main	et
doc_278690626952_item	Essee	main	et
doc_278690626953_item	Essee	main	et
doc_278690626955_item	Essee	main	et
doc_278690626956_item	Essee	main	et
doc_278690626957_item	Essee	main	et
doc_278690626958_item	Essee	main	et
doc_278690626960_item	Essee	main	et
doc_278690626962_item	Essee	main	et
doc_278690626963_item	Essee	main	et
doc_740091150996_item	Essee	main	et
doc_740091150998_item	Essee	main	et
doc_740091151000_item	Essee	main	et
doc_740091151001_item	Essee	main	et
doc_740091151005_item	Essee	main	et
doc_740091151007_item	Essee	main	et
doc_740091151008_item	Essee	main	et
doc_740091151009_item	Essee	main	et
doc_740091151010_item	Essee	main	et
doc_740091151011_item	Essee	main	et
doc_740091151013_item	Essee	main	et
doc_740091151015_item	Essee	main	et
doc_740091151016_item	Essee	main	et
doc_366216787891_item	Essee	main	et
doc_399014257171_item	Essee	main	et
doc_464301607732_item	Essee	main	et
doc_744962874528_item	Essee  	main	et
doc_767882159212_item	Essee	main	et
doc_767882159237_item	Essee	main	et
doc_901133458144_item	Essee	main	et
doc_986203247099_item	Arvamus	main	et
doc_986203247111_item	Arvamus	main	et
doc_574559240058_item	Arvamus	main	et
doc_609075653183_item	Vastus küsimusele 	main	et
doc_862226128014_item	Kontrolltöö	main	et
doc_640286507875_item	Kontrolltöö	main	et
doc_826196946513_item	Kontrolltöö	main	et
doc_48663839466_item	Kontrolltöö	main	et
doc_901133458163_item	Vastus küsimusele	main	et
doc_901133458164_item	Vastus küsimusele	main	et
doc_901133458165_item	Vastus küsimusele	main	et
doc_901133458166_item	Vastus küsimusele	main	et
doc_901133458167_item	Vastus küsimusele	main	et
doc_901133458173_item	Vastus küsimusele	main	et
doc_901133458174_item	Vastus küsimusele	main	et
doc_901133458176_item	Vastus küsimusele	main	et
doc_491521502110_item	Eksamitöö  	main	et
doc_491521502118_item	Eksamitöö 	main	et
doc_491521502119_item	Eksamitöö  	main	et
doc_491521502120_item	Eksamitöö  	main	et
doc_491521502123_item	Eksamitöö  	main	et
doc_491521502124_item	Eksamitöö  	main	et
doc_491521502130_item	Eksamitöö  	main	et
doc_491521502132_item	Eksamitöö  	main	et
doc_491521502183_item	Kontrolltöö	main	et
doc_491521502186_item	Kontrolltöö	main	et
doc_491521502189_item	Kontrolltöö	main	et
doc_491521502192_item	Kontrolltöö	main	et
doc_491521502193_item	Kontrolltöö 	main	et
doc_491521502196_item	Kontrolltöö	main	et
doc_491521502198_item	Kontrolltöö 	main	et
doc_491521502201_item	Kontrolltöö	main	et
doc_491521502204_item	Kontrolltöö 	main	et
doc_491521502207_item	Kontrolltöö	main	et
doc_491521502208_item	Kontrolltöö 	main	et
doc_491521502211_item	Kontrolltöö	main	et
doc_491521502212_item	Kontrolltöö	main	et
doc_491521502215_item	Kontrolltöö	main	et
doc_491521502216_item	Kontrolltöö 	main	et
doc_491521502218_item	Kontrolltöö	main	et
doc_491521502222_item	Kontrolltöö	main	et
doc_491521502223_item	Kontrolltöö	main	et
doc_491521502229_item	Kontrolltöö	main	et
doc_491521502237_item	Kontrolltöö	main	et
doc_491521502231_item	Kontrolltöö	main	et
doc_491521502244_item	Kontrolltöö	main	et
doc_491521502245_item	Kontrolltöö	main	et
doc_491521502246_item	Kontrolltöö	main	et
doc_491521502248_item	Kontrolltöö	main	et
doc_491521502249_item	Kontrolltöö	main	et
doc_491521502250_item	Kontrolltöö  	main	et
doc_491521502256_item	Kontrolltöö	main	et
doc_491521502260_item	Kontrolltöö	main	et
doc_491521502261_item	Kontrolltöö	main	et
doc_491521502265_item	Kontrolltöö	main	et
doc_491521502267_item	Kontrolltöö 	main	et
doc_491521502271_item	Kontrolltöö	main	et
doc_491521502273_item	Kontrolltöö	main	et
doc_491521502278_item	Kontrolltöö	main	et
doc_491521502279_item	Kontrolltöö 	main	et
doc_491521502283_item	Kontrolltöö 	main	et
doc_491521502285_item	Kontrolltöö	main	et
doc_491521502287_item	Kontrolltöö	main	et
doc_491521502307_item	Kontrolltöö	main	et
doc_491521502312_item	Kontrolltöö	main	et
doc_491521502314_item	Kontrolltöö	main	et
doc_491521502318_item	Kontrolltöö	main	et
doc_491521501874_item	Vastus küsimusele	main	et
doc_491521501875_item	Vastus küsimusele	main	et
doc_980560860272_item	Vastus küsimusele	main	et
doc_491521502234_item	Kontrolltöö	main	et
doc_491521502217_item	Kontrolltöö 	main	et
doc_491521502206_item	Kontrolltöö	main	et
doc_491521502194_item	Kontrolltöö	main	et
doc_491521502190_item	Kontrolltöö	main	et
doc_491521502188_item	Kontrolltöö	main	et
doc_491521502184_item	Kontrolltöö	main	et
doc_491521502181_item	Kontrolltöö	main	et
doc_491521502121_item	Eksamitöö	main	et
doc_980560860275_item	Vastus küsimusele	main	et
doc_980560860274_item	Vastus küsimusele	main	et
doc_980560860273_item	Vastus küsimusele	main	et
doc_542009824749_item	Vastus küsimusele	main	et
doc_542009824745_item	Vastus küsimusele	main	et
doc_542009824743_item	Vastus küsimusele	main	et
doc_542009824741_item	Vastus küsimusele	main	et
doc_842434202395_item	Vastus küsimusele	main	et
doc_723935141569_item	Vastus küsimusele	main	et
doc_516622545496_item	Kontrolltöö	main	et
doc_601001696377_item	Kontrolltöö	main	et
doc_601001696376_item	Kontrolltöö	main	et
doc_872470917319_item	Kontrolltöö	main	et
doc_854846908871_item	Kontrolltöö	main	et
doc_860756017856_item	Kontrolltöö	main	et
doc_866101568972_item	Kontrolltöö	main	et
doc_513103214317_item	Kontrolltöö	main	et
doc_973441205335_item	Vastus küsimusele	main	et
doc_973441205330_item	Vastus küsimusele	main	et
doc_460280307198_item	Arvamus	main	et
doc_460280307197_item	Arvamus 	main	et
doc_460280307196_item	Arvamus	main	et
doc_15203423350_item	Vastus küsimusele	main	et
doc_491521501925_item	Vastus küsimusele	main	et
doc_634572338201_item	Vastus küsimusele	main	et
doc_491521502185_item	Kontrolltöö	main	et
doc_609075653186_item	Vastus küsimusele 	main	et
doc_609075653185_item	Vastus küsimusele 	main	et
doc_975151536919_item	Kontrolltöö	main	et
doc_820667236801_item	Kontrolltöö	main	et
doc_640286507878_item	Kontrolltöö	main	et
doc_57773893367_item	Kontrolltöö	main	et
doc_323697784328_item	Kontrolltöö	main	et
doc_491521501817_item	Eksamitöö	main	et
doc_491521501816_item	Eksamitöö	main	et
doc_491521501829_item	Eksamitöö	main	et
doc_491521501814_item	Eksamitöö	main	et
doc_278690626961_item	Essee	main	et
doc_187964557902_item	Essee	main	et
doc_873901597502_item	Essee	main	et
doc_193540241555_item	Essee	main	et
doc_59711134417_item	Essee	main	et
doc_59711134411_item	Essee	main	et
doc_343606542360_item	Arvamus	main	et
doc_399014257207_item	Essee	main	et
doc_399014257206_item	Essee	main	et
doc_213943984964_item	Essee	main	et
doc_491521501997_item	Essee	main	et
doc_634572338205_item	Essee	main	et
doc_842434202401_item	Essee	main	et
doc_881412446067_item	Essee	main	et
doc_881412446068_item	Essee	main	et
doc_881412446070_item	Essee	main	et
doc_769634019911_item	Essee	main	et
doc_769634019910_item	Essee	main	et
doc_680929863178_item	Essee	main	et
doc_464301607742_item	Essee	main	et
doc_680929863180_item	Essee	main	et
doc_680929863181_item	Essee	main	et
doc_680929863185_item	Essee	main	et
doc_35015649957_item	Essee	main	et
doc_384045275274_item	Essee	main	et
doc_237983010021_item		\N	et
doc_59711134406_item	Ametlik kiri	main	et
doc_59711134409_item	Ametlik kiri	main	et
doc_831529852294_item		\N	et
doc_541159270915_item		\N	et
doc_541159270916_item		\N	et
doc_708250025260_item	Es	\N	et
doc_399014257215_item	Essee	main	et
doc_120968879154_item	Essee	main	et
doc_120968879156_item	Essee	main	et
doc_399014257212_item	Essee	main	et
doc_491521501849_item	Essee	main	et
doc_973441205333_item	Essee	main	et
doc_769634019913_item	Essee	main	et
doc_278690626941_item	Essee	main	et
doc_366216787906_item	Essee	main	et
doc_27046690324_item	Kontrolltöö	main	et
doc_527420171754_item	Kontrolltöö	main	et
doc_491521502109_item	Eksamitöö  	main	et
doc_491521502111_item	Eksamitöö  	main	et
doc_491521502117_item	Eksamitöö  	main	et
doc_491521502240_item	Kontrolltöö	main	et
doc_491521502247_item	Kontrolltöö 	main	et
doc_491521502252_item	Kontrolltöö	main	et
doc_491521502263_item	Kontrolltöö	main	et
doc_491521502268_item	Kontrolltöö  	main	et
doc_491521502187_item	Kontrolltöö	main	et
doc_301901115686_item	Kontrolltöö	main	et
doc_881665289253_item	Referaat	cKUAfXynZ	et
doc_831529852295_item	Referaat	cKUAfXynZ	et
doc_881412446072_item	Essee	main	et
doc_491521501755_item	Analüüs	main	et
doc_491521501889_item	Analüüs	main	et
doc_491521501869_item	Analüüs	main	et
doc_491521501868_item	Veaanalüüs	main	et
doc_491521501863_item	Analüüs	main	et
doc_491521501782_item	Analüüs	main	et
doc_491521501871_item	Analüüs	main	et
doc_491521501860_item	Analüüs	main	et
doc_491521501750_item	Analüüs	main	et
doc_491521501744_item	KUSTUTADA	main	et
doc_491521501756_item	KUSTUTADA	main	et
doc_491521501801_item	Analüüs	main	et
doc_491521502053_item	Kiri	main	et
doc_491521502059_item	Kiri	main	et
doc_491521501952_item	Kiri	main	et
doc_634572338216_item	Ametlik kiri	main	et
doc_634572338214_item	Ametlik kiri	main	et
doc_634572338210_item	Ametlik kiri	main	et
doc_491521501894_item	Avaldus	main	et
doc_399014257219_item	Tõlge	main	et
doc_491521501739_item	Käskkirjad	main	et
doc_491521502078_item	Kontrolltöö	main	et
doc_491521501746_item	Diplomitöö	main	et
doc_534729444684_item	Päevik	main	et
doc_284706151130_item	Vastus küsimusele	main	et
doc_600559928986_item	Kiri 	main	et
doc_541159270917_item	Kokkuvõte	cKUAfXynZ	et
doc_881665289254_item		csonzdTft	et
doc_541159270918_item		\N	et
\.


--
-- Data for Name: undecided; Type: TABLE DATA; Schema: public; Owner: evkk
--

COPY undecided ("ID", word, "option", "language", processed, tick) FROM stdin;
108071	läbi	läbi =läbi  (ID  >läbi !41_DK	et	f	\N
108072	läbi	läbi =läbi  (IndPrPs_  >läbima !27_V	et	f	\N
108073	läbi	läbi =läbi  (ImpPrSg2  >läbima !27_V	et	f	\N
108074	huvitav	huvitav =huvita  (PtsPrPs  >huvitama !27_V	et	f	\N
108075	huvitav	huvitav =huvitav  (SgN  >huvitav !02_A	et	f	\N
108076	huvitav	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
108077	ühest	ühest =ühe  (SgEl  >üks !22_NP	et	f	\N
108078	ühest	ühest =ühes  (SgP  >ühene !10_AS	et	f	\N
108079	ühest	"ühene %ühe  )NE_aA  <üks ;22_NP	et	f	\N
108080	koolist	koolist =kooli  (SgEl  >kool !22_S	et	f	\N
108081	ühest	ühest =ühest  (ID  >ühest !41_D	et	f	\N
108082	koolist	koolist =kooli  (PlEl  >kool !22_S	et	f	\N
108083	koolist	koolist =koolis  (SgP  >kooline !10_A	et	f	\N
108084	väikesest	väikesest =väikese  (SgEl  >väike !12?10_A	et	f	\N
108085	koolist	"kooline %koo  )LINE_aA  <kubu ;18_S	et	f	\N
108086	väikesest	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
108087	koolist	"kooline %kooli  )NE_aA  <kool ;22_S	et	f	\N
108088	väikesest	väikesest =väikese  (SgEl  >väikene !12?10_A	et	f	\N
108089	väikesest	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
108090	alevikust	alevikust =aleviku  (SgEl  >alevik !25_S	et	f	\N
108091	võru	võru =võru  (SgN  >võru !17_S	et	f	\N
108092	võru	võru =võru  (SgG  >võru !17_S	et	f	\N
108093	alevikust	alevikust =kus  (SgP  >alevi+kusi !20_S	et	f	\N
108094	võru	võru =võru  (SgP  >võru !17_S	et	f	\N
108095	alevikust	alevikust =viku  (SgEl  >ale+vikk !22_S	et	f	\N
108096	sõmerpalust	sõmerpalust =palu  (SgEl  >sõmer+palu !17_S	et	f	\N
108097	juures	juures =juure  (SgIn  >juur !13_S	et	f	\N
108098	sõmerpalust	sõmerpalust =palu  (PlEl  >sõmer+pala !17_S	et	f	\N
108099	juures	juures =juures  (ID  >juures !41_DK	et	f	\N
108100	selles	selles =selle  (SgIn  >see !00_P	et	f	\N
108101	selles	selles =selle  (PlIn  >sell !22_S	et	f	\N
108102	koolis	koolis =kool  (IndIpfSg3  >koolma !33_V	et	f	\N
108103	koolis	koolis =kooli  (SgIn  >kool !22_S	et	f	\N
108104	koolis	koolis =kooli  (PlIn  >kool !22_S	et	f	\N
108105	on	on =on  (IndPrSg3  >olema !36_V	et	f	\N
108106	on	on =on  (IndPrPl3  >olema !36_V	et	f	\N
108107	tähelepanelik	tähelepanelik =nelik  (SgN  >tähe+lepa+nelik !02_S	et	f	\N
108108	viis	viis =vii  (IndIpfSg3  >viima !38_V	et	f	\N
108109	viis	viis =viis  (SgN  >viis !14_N	et	f	\N
108110	viis	viis =viis  (SgN  >viis !22_S	et	f	\N
108111	tähelepanelik	tähelepanelik =panelik  (SgN  >tähele+panelik !25_A	et	f	\N
108112	koos	koos =koo  (SgIn  >kubu !18_S	et	f	\N
108113	koos	koos =koos  (ID  >koos !41_DK	et	f	\N
108114	koos	koos =koos  (SgN  >koos !22_S	et	f	\N
108115	õpetajad	õpetajad =õpetaja  (PlN  >õpetaja !01_S	et	f	\N
108116	tegid	tegid =teg  (IndIpfSg2  >tegema !28_V	et	f	\N
108117	õpetajad	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
108118	väikeses	väikeses =väikese  (SgIn  >väike !12?10_A	et	f	\N
108119	väikeses	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
108120	väikeses	väikeses =väikese  (SgIn  >väikene !12?10_A	et	f	\N
108121	väikeses	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
108122	tegid	tegid =teg  (IndIpfPl3  >tegema !28_V	et	f	\N
108123	koolikeskuses	koolikeskuses =use  (PlIn  >kooli+kesk+usk !22_S	et	f	\N
108124	koolikeskuses	koolikeskuses =keskuse  (SgIn  >kooli+keskus !11~09_S	et	f	\N
108125	talveaeda	talveaeda =aeda  (SgP  >talve+aed !22_S	et	f	\N
108126	talveaeda	talveaeda =aeda  (SgAdt  >talve+aed !22_S	et	f	\N
108127	raske	raske =raske  (SgN  >raske !01_A	et	f	\N
108128	raske	raske =raske  (SgG  >raske !01_A	et	f	\N
108129	töö	töö =töö  (SgN  >töö !26_S	et	f	\N
108130	raske	raske =raske  (PlP  >rask !22_S	et	f	\N
108131	töö	töö =töö  (SgG  >töö !26_S	et	f	\N
108132	sest	sest =se  (SgEl  >see !00_P	et	f	\N
108133	sest	sest =sest  (ID  >sest !41_J	et	f	\N
108134	ise	ise =ise  (SgN  >ise !00_P	et	f	\N
108135	ise	ise =ise  (PlN  >ise !00_P	et	f	\N
108136	ise	ise =ise  (ID  >ise !41_DA	et	f	\N
108137	pidid	pidid =pid  (IndIpfSg2  >pida !40_V	et	f	\N
108138	pidid	pidid =pid  (IndIpfPl3  >pida !40_V	et	f	\N
108139	toru	toru =toru  (SgN  >toru !17_S	et	f	\N
108140	kuuma	kuuma =kuuma  (SgG  >kuum !22_AS	et	f	\N
108141	kuuma	kuuma =kuuma  (SgP  >kuum !22_AS	et	f	\N
108142	kuuma	kuuma =kuuma  (SgAdt  >kuum !22_AS	et	f	\N
108143	toru	toru =toru  (SgG  >toru !17_S	et	f	\N
108144	kuuma	kuuma =kuuma  (IndPrPs_  >kuumama !29_V	et	f	\N
108145	toru	toru =toru  (SgP  >toru !17_S	et	f	\N
108146	kuuma	kuuma =kuuma  (ImpPrSg2  >kuumama !29_V	et	f	\N
108147	ruumis	ruumis =ruumi  (SgIn  >ruum !22_S	et	f	\N
108148	ruumis	ruumis =ruumi  (IndIpfSg3  >ruumima !28_V	et	f	\N
108149	soe	soe =soe  (SgN  >soe !24_AS	et	f	\N
108150	soe	soe =soe  (SgG  >susi !15_S	et	f	\N
108151	soe	soe =soe  (IndPrPs_  >sugema !28_V	et	f	\N
108152	soe	soe =soe  (ImpPrSg2  >sugema !28_V	et	f	\N
108153	oliks	?oliks =oli  (SgTr  >oli !17_S	et	f	\N
108175	seima	seima =seima  (SgG  >seim !22_S	et	f	\N
108154	oliks	?oliks =oli  (KndPrPs  >olima !27_V	et	f	\N
108159	nüüd	nüüd =nüü  (PlN  >nüü !26_S	et	f	\N
108160	nüüd	nüüd =nüü  (SgP  >nüü !26_S	et	f	\N
108161	nüüd	nüüd =nüüd  (ID  >nüüd !41_D	et	f	\N
108162	ilus	ilus =ilu  (SgIn  >ilu !17_S	et	f	\N
108163	ilus	ilus =ilus  (SgN  >ilus !02_A	et	f	\N
108185	elavad	elavad =ela  (IndPrPl3  >elama !27_V	et	f	\N
108188	elavad	elavad =elava  (PlN  >elav !02_A	et	f	\N
108189	elavad	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
108208	päevat	?päevat =päevat  (SgN  >päevat !02_S	et	f	\N
108216	sojendama	?sojendama =sojenda  (Sup  >sojendama !27_V	et	f	\N
108218	sojendama	?sojendama =sojendama  (SgG  >sojendam !02_A	et	f	\N
108226	pere	pere =pere  (SgN  >pere !16_S	et	f	\N
108228	pere	pere =pere  (SgG  >pere !16_S	et	f	\N
108234	elu	elu =elu  (SgN  >elu !17_S	et	f	\N
108235	elu	elu =elu  (SgG  >elu !17_S	et	f	\N
108236	elu	elu =elu  (SgP  >elu !17_S	et	f	\N
108249	nende	nende =nen  (PlG  >see !00_P	et	f	\N
108251	nende	nende =nen  (PlG  >ta !00_P	et	f	\N
108253	nende	nende =nen  (PlG  >tema !00_P	et	f	\N
108266	sveta	?sveta =sveta  (SgN  >sveta !16_S	et	f	\N
108269	sveta	?sveta =sveta  (SgG  >sveta !16_S	et	f	\N
108271	sveta	?sveta =sveta  (IndPrPs_  >svetama !27_V	et	f	\N
108273	sveta	?sveta =sveta  (ImpPrSg2  >svetama !27_V	et	f	\N
108275	misha	?misha =misha  (SgN  >misha !16_S	et	f	\N
108276	misha	?misha =misha  (SgG  >misha !16_S	et	f	\N
108277	misha	?misha =misha  (IndPrPs_  >mishama !29_V	et	f	\N
108278	misha	?misha =misha  (ImpPrSg2  >mishama !29_V	et	f	\N
108279	neid	neid =ne  (PlP  >see !00_P	et	f	\N
108280	neid	neid =ne  (PlP  >ta !00_P	et	f	\N
108281	neid	neid =ne  (PlP  >tema !00_P	et	f	\N
108282	neid	neid =neid  (SgN  >neid !22_S	et	f	\N
108283	me	me =me  (PlG  >ma !00_P	et	f	\N
108284	me	me =me  (PlN  >ma !00_P	et	f	\N
108287	reis	reis =reis  (SgN  >reis !14_S	et	f	\N
108289	reis	reis =reis  (SgN  >reis !22_S	et	f	\N
108292	romantika	romantika =romantika  (SgN  >romantika !01_S	et	f	\N
108293	romantika	romantika =romantika  (SgG  >romantika !01_S	et	f	\N
108296	igaühe	igaühe =ühe  (SgN  >iga+ühe !06_S	et	f	\N
108298	igaühe	igaühe =ühe  (SgG  >iga+üks !22_P	et	f	\N
108301	nägu	nägu =nägu  (SgN  >nägu !18_S	et	f	\N
108303	nägu	nägu =nägu  (SgP  >nägu !18_S	et	f	\N
108308	arvavad	arvavad =arva  (IndPrPl3  >arvama !29_V	et	f	\N
108309	arvavad	arvavad =arvava  (PlN  >arvav !02_A	et	f	\N
108310	arvavad	"arvav %arva  )V_vA  <arvama ;29_V	et	f	\N
108311	arvavad	arvavad =ava  (PlN  >arv+ava !17_S	et	f	\N
108317	võid	võid =või  (PlN  >või !26_S	et	f	\N
108318	võid	võid =või  (SgP  >või !26_S	et	f	\N
108319	võid	võid =või  (IndPrSg2  >võima !37_V	et	f	\N
108340	vaadata	vaadata =vaada  (Inf  >vaatama !29_V	et	f	\N
108342	vaadata	vaadata =vaada  (IndPrIps_  >vaatama !29_V	et	f	\N
108356	reisi	reisi =reis  (PlP  >reis !14_S	et	f	\N
108357	reisi	reisi =reisi  (ID  >reisi !41_D	et	f	\N
108358	reisi	reisi =reisi  (SgG  >reis !22_S	et	f	\N
108359	reisi	reisi =reisi  (SgP  >reis !22_S	et	f	\N
108360	reisi	reisi =reisi  (SgAdt  >reis !22_S	et	f	\N
108361	reisi	reisi =reisi  (IndPrPs_  >reisima !28_V	et	f	\N
108362	reisi	reisi =reisi  (ImpPrSg2  >reisima !28_V	et	f	\N
108363	ühe	ühe =ühe  (SgN  >ühe !06_S	et	f	\N
108364	ühe	ühe =ühe  (SgG  >üks !22_NP	et	f	\N
108365	reklaamiga	reklaamiga =reklaami  (SgKom  >reklaam !22_S	et	f	\N
108366	reklaamiga	reklaamiga =iga  (SgN  >reklaam+iga !18_S	et	f	\N
108367	reklaamiga	reklaamiga =iga  (SgP  >reklaam+iga !18_S	et	f	\N
108368	kujutatud	kujutatud =kujuta  (PtsPtIps  >kujutama !27_V	et	f	\N
108369	kujutatud	kujutatud =kujutatu  (PlN  >kujutatu !01_S	et	f	\N
108370	kujutatud	"kujutatu %kujuta  )TU1_vS  <kujutama ;27_V	et	f	\N
108371	kujutatud	kujutatud =kujutatud  (ID  >kujutatud !41_A	et	f	\N
108372	kujutatud	"kujutatud %kujuta  )TUD_vA  <kujutama ;27_V	et	f	\N
108376	arvutiga	arvutiga =arvuti  (SgKom  >arvuti !01_S	et	f	\N
108377	arvutiga	arvutiga =uti  (SgKom  >arv+utt !22_S	et	f	\N
108388	jõulu	jõulu =jõulu  (SgG  >jõul !22_S	et	f	\N
108389	jõulu	jõulu =jõulu  (SgP  >jõul !22_S	et	f	\N
108390	jõulu	jõulu =jõulu  (SgAdt  >jõul !22_S	et	f	\N
108407	kaheks	kaheks =kahe  (SgTr  >kaks !22_N	et	f	\N
108408	kaheks	kaheks =kahe  (PlTr  >kahk !22_S	et	f	\N
108418	35-60-245	### 35-60-245	et	f	\N
108433	tähavad	?tähavad =täha  (IndPrPl3  >tähama !27_V	et	f	\N
108434	tähavad	?tähavad =tähava  (PlN  >tähava !01_S	et	f	\N
108435	tähavad	?tähavad =tähava  (PlN  >tähav !02_A	et	f	\N
108441	kellel	kellel =kelle  (SgAd  >kes !00_P	et	f	\N
108442	kellel	kellel =kelle  (PlAd  >kell !22_S	et	f	\N
108458	vormi	vormi =vormi  (SgG  >vorm !22_S	et	f	\N
108460	vormi	vormi =vormi  (SgP  >vorm !22_S	et	f	\N
108461	vormi	vormi =vormi  (SgAdt  >vorm !22_S	et	f	\N
108463	vormi	vormi =vormi  (IndPrPs_  >vormima !28_V	et	f	\N
108155	valgus	valgus =valgu  (SgIn  >valk !22_S	et	f	\N
108156	valgus	valgus =valgu  (IndIpfSg3  >valguma !27_V	et	f	\N
108157	valgus	valgus =valgus  (SgN  >valgus !11~09_S	et	f	\N
108158	valgus	"valgus %valge  )US_aS  <valge ;01_AS	et	f	\N
108164	kasvavad	kasvavad =kasva  (IndPrPl3  >kasvama !28_V	et	f	\N
108165	kasvavad	kasvavad =kasvava  (PlN  >kasvav !02_A	et	f	\N
108167	kasvavad	"kasvav %kasva  )V_vA  <kasvama ;28_V	et	f	\N
108186	papagoid	papagoid =papagoi  (PlN  >papagoi !26_S	et	f	\N
108187	papagoid	papagoid =papagoi  (SgP  >papagoi !26_S	et	f	\N
108190	veel	veel =vee  (SgAd  >vesi !15_S	et	f	\N
108191	veel	veel =veel  (ID  >veel !41_D	et	f	\N
108192	seal	seal =sea  (SgAd  >siga !18_SA	et	f	\N
108193	seal	seal =seal  (ID  >seal !41_D	et	f	\N
108196	kord	kord =kord  (ID  >kord !41_D	et	f	\N
108197	kord	kord =kord  (SgN  >kord !22_S	et	f	\N
108212	kodust	kodust =kodu  (SgEl  >kodu !17_S	et	f	\N
108214	kodust	kodust =kodus  (SgP  >kodune !10_A	et	f	\N
108215	kodust	"kodune %kodu  )NE_aA  <kodu ;17_S	et	f	\N
108222	vastuvad	?vastuvad =vastu  (IndPrPl3  >vastuma !27_V	et	f	\N
108223	vastuvad	?vastuvad =vastuva  (PlN  >vastuva !01_S	et	f	\N
108224	vastuvad	?vastuvad =vastuva  (PlN  >vastuv !02_A	et	f	\N
108225	vastuvad	?vastuvad =uva  (PlN  >vast+uva !17_S	et	f	\N
108231	atikkel	?atikkel =atikkel  (SgN  >atikkel !02_S	et	f	\N
108255	natukene	natukene =natukene  (ID  >natukene !41_D	et	f	\N
108257	natukene	natukene =natukene  (SgN  >natukene !12_S	et	f	\N
108299	oma	oma =oma  (ID  >oma !41_D	et	f	\N
108300	oma	oma =oma  (ID  >oma !41_P	et	f	\N
108302	oma	oma =oma  (SgN  >oma !17_A	et	f	\N
108304	oma	oma =oma  (SgG  >oma !17_A	et	f	\N
108305	oma	oma =oma  (SgP  >oma !17_A	et	f	\N
108306	oma	oma =oma  (IndPrPs_  >omama !27_V	et	f	\N
108307	oma	oma =oma  (ImpPrSg2  >omama !27_V	et	f	\N
108312	reisid	reisid =reisi  (PlN  >reis !22_S	et	f	\N
108313	reisid	reisid =reisi  (IndPrSg2  >reisima !28_V	et	f	\N
108320	lossi	lossi =lossi  (ID  >lossi !41_D	et	f	\N
108321	lossi	lossi =lossi  (SgG  >loss !22_S	et	f	\N
108323	lossi	lossi =lossi  (SgP  >loss !22_S	et	f	\N
108325	lossi	lossi =lossi  (SgAdt  >loss !22_S	et	f	\N
108327	lossi	lossi =lossi  (IndPrPs_  >lossima !28_V	et	f	\N
108329	lossi	lossi =lossi  (ImpPrSg2  >lossima !28_V	et	f	\N
108347	niisuguned	### niisuguned	et	f	\N
108378	sellest	sellest =selle  (SgEl  >see !00_P	et	f	\N
108379	sellest	sellest =selle  (PlEl  >sell !22_S	et	f	\N
108383	arvutikeskuses	arvutikeskuses =use  (PlIn  >arvuti+kesk+usk !22_S	et	f	\N
108384	arvutikeskuses	arvutikeskuses =keskuse  (SgIn  >arvuti+keskus !11~09_S	et	f	\N
108391	kingitusi	kingitusi =kingitusi  (PlP  >kingitus !11_S	et	f	\N
108392	kingitusi	"kingitus %kingi  )TUS1_aS  <kinkima ;28_V	et	f	\N
108393	kingitusi	"kingitus %kingi  )TUS2_aS  <kink ;22_S	et	f	\N
108400	võiimalus	võiimalus =imalus  (SgN  >või+imalus !11_S	et	f	\N
108401	võiimalus	"või+imalus %imala  )US_aS  <või+imal ;02_A	et	f	\N
108411	pood	pood =poo  (IndPrSg2  >pooma !38_V	et	f	\N
108412	pood	pood =pood  (SgN  >pood !22_S	et	f	\N
108419	huvitatud	huvitatud =huvita  (PtsPtIps  >huvitama !27_V	et	f	\N
108420	huvitatud	huvitatud =huvitatu  (PlN  >huvitatu !01_S	et	f	\N
108421	huvitatud	"huvitatu %huvita  )TU1_vS  <huvitama ;27_V	et	f	\N
108422	huvitatud	huvitatud =huvitatud  (ID  >huvitatud !41_A	et	f	\N
108423	huvitatud	"huvitatud %huvita  )TUD_vA  <huvitama ;27_V	et	f	\N
108436	jõulukingitust	jõulukingitust =tust  (SgN  >jõulu+kingi+tust !22_S	et	f	\N
108437	jõulukingitust	jõulukingitust =kingitu  (SgEl  >jõulu+kingitu !01_AS	et	f	\N
108438	jõulukingitust	"jõulu+kingitu %kingi  )TU2_kA  <jõulu+kink ;22_S	et	f	\N
108439	jõulukingitust	jõulukingitust =kingitus  (SgP  >jõulu+kingitus !11_S	et	f	\N
108440	jõulukingitust	"jõulu+kingitus %kingi  )TUS2_aS  <jõulu+kink ;22_S	et	f	\N
108447	i	### i	et	f	\N
108457	sõnad	sõnad =sõna  (PlN  >sõna !17_S	et	f	\N
108459	sõnad	sõnad =sõna  (IndPrSg2  >sõnama !27_V	et	f	\N
108465	toomet	?toomet =toome  (SgP  >toome !06_S	et	f	\N
108476	siberisse	?siberisse =siberi  (SgIll  >siberi !01_S	et	f	\N
108480	siberisse	?siberisse =siberi  (SgIll  >siber !02_S	et	f	\N
108484	siberisse	?siberisse =siberis  (SgAdt  >siberis !11_S	et	f	\N
108486	siberisse	?siberisse =siberisse  (SgG  >siberisne !02_A	et	f	\N
108488	siberisse	?siberisse =siberisse  (PlP  >siberiss !22_S	et	f	\N
108490	küla	küla =küla  (SgN  >küla !17_S	et	f	\N
108491	küla	küla =küla  (SgG  >küla !17_S	et	f	\N
108492	küla	küla =küla  (SgP  >küla !17_S	et	f	\N
108499	õpetajat	õpetajat =õpetaja  (SgP  >õpetaja !01_S	et	f	\N
108500	õpetajat	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
108512	emakeelt	emakeelt =kee  (SgAbl  >ema+kesi !15_S	et	f	\N
108513	emakeelt	emakeelt =kee  (SgAbl  >ema+kee !26_S	et	f	\N
108514	emakeelt	emakeelt =keel  (SgP  >ema+keel !13_S	et	f	\N
108527	üllatunud	üllatunud =üllatu  (PtsPtPs  >üllatuma !27_V	et	f	\N
108528	üllatunud	üllatunud =üllatunu  (PlN  >üllatunu !01_S	et	f	\N
108166	erinevad	erinevad =erine  (IndPrPl3  >erinema !27_V	et	f	\N
108168	erinevad	erinevad =erineva  (PlN  >erinev !02_A	et	f	\N
108169	erinevad	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
108170	õitsevad	õitsevad =õitse  (IndPrPl3  >õitsema !28_V	et	f	\N
108171	õitsevad	õitsevad =õitse  (IndPrPl3  >õitsma !32_V	et	f	\N
108172	õitsevad	õitsevad =õitseva  (PlN  >õitsev !02_A	et	f	\N
108173	õitsevad	"õitsev %õits  )V_vA  <õitsma ;32_V	et	f	\N
108174	õitsevad	"õitsev %õitse  )V_vA  <õitsema ;28_V	et	f	\N
108203	ei	ei =ei  (Neg  >ei !--_V	et	f	\N
108204	ei	ei =ei  (ID  >ei !41_D	et	f	\N
108205	sooja	sooja =sooja  (SgG  >soe !24_AS	et	f	\N
108206	sooja	sooja =sooja  (SgP  >soe !24_AS	et	f	\N
108207	sooja	sooja =sooja  (SgAdt  >soe !24_AS	et	f	\N
108227	mulle	mulle =mu  (SgAll  >ma !00_P	et	f	\N
108229	mulle	mulle =mulle  (SgN  >mulle !06_S	et	f	\N
108230	mulle	mulle =mulle  (PlP  >mull !22_S	et	f	\N
108242	midagi	midagi =mi  (SgP  >miski !00_P	et	f	\N
108243	midagi	midagi =mi  (SgP^  >mis !00_P	et	f	\N
108244	midagi	midagi =mi  (PlP^  >mis !00_P	et	f	\N
108252	jaoks	jaoks =jao  (SgTr  >jagu !18_S	et	f	\N
108254	jaoks	jaoks =jaoks  (ID  >jaoks !41_DK	et	f	\N
108259	meie	meie =meie  (PlG  >mina !00_P	et	f	\N
108260	meie	meie =meie  (PlN  >mina !00_P	et	f	\N
108261	meie	meie =meie  (SgN  >meie !16_S	et	f	\N
108262	meie	meie =meie  (SgG  >meie !16_S	et	f	\N
108265	elja	?elja =elja  (SgN  >elja !16_S	et	f	\N
108267	elja	?elja =elja  (SgG  >eljas !02_A	et	f	\N
108270	elja	?elja =elja  (SgG  >elja !16_S	et	f	\N
108272	elja	?elja =elja  (IndPrPs_  >eljama !29_V	et	f	\N
108274	elja	?elja =elja  (ImpPrSg2  >eljama !29_V	et	f	\N
108285	iga	iga =iga  (SgN  >iga !17_P	et	f	\N
108286	iga	iga =iga  (SgN  >iga !18_S	et	f	\N
108288	iga	iga =iga  (SgG  >iga !17_P	et	f	\N
108290	iga	iga =iga  (SgP  >iga !17_P	et	f	\N
108291	iga	iga =iga  (SgP  >iga !18_S	et	f	\N
108314	rigisse	?rigisse =rigi  (SgIll  >rigi !17_S	et	f	\N
108315	rigisse	?rigisse =rigisse  (SgG  >rigisne !02_A	et	f	\N
108316	rigisse	?rigisse =rigisse  (PlP  >rigiss !22_S	et	f	\N
108338	armastatud	armastatud =armasta  (PtsPtIps  >armastama !27_V	et	f	\N
108339	armastatud	armastatud =armastatu  (PlN  >armastatu !01_S	et	f	\N
108341	armastatud	"armastatu %armasta  )TU1_vS  <armastama ;27_V	et	f	\N
108343	armastatud	armastatud =armastatud  (ID  >armastatud !41_A	et	f	\N
108344	armastatud	"armastatud %armasta  )TUD_vA  <armastama ;27_V	et	f	\N
108373	arvuti	arvuti =arvuti  (SgN  >arvuti !01_S	et	f	\N
108374	arvuti	arvuti =arvuti  (SgG  >arvuti !01_S	et	f	\N
108375	arvuti	arvuti =uti  (SgG  >arv+utt !22_S	et	f	\N
108394	kes	kes =kes  (SgN  >kes !00_P	et	f	\N
108395	kes	kes =kes  (PlN  >kes !00_P	et	f	\N
108396	õpetajale	õpetajale =õpetaja  (SgAll  >õpetaja !01_S	et	f	\N
108397	õpetajale	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
108409	aastaks	aastaks =aasta  (SgTr  >aasta !01_S	et	f	\N
108410	aastaks	aastaks =taks  (SgN  >aas+taks !22_S	et	f	\N
108413	narvas	?narvas =narva  (SgIn  >narva !16_S	et	f	\N
108414	narvas	?narvas =narva  (IndIpfSg3  >narvama !29_V	et	f	\N
108415	narvas	?narvas =narvas  (SgN  >narvas !07_S	et	f	\N
108427	netis	?netis =neti  (SgIn  >neti !16_S	et	f	\N
108429	netis	?netis =neti  (SgIn  >nett !22_AS	et	f	\N
108431	netis	?netis =neti  (IndIpfSg3  >netima !27_V	et	f	\N
108432	netis	?netis =netis  (SgN  >netis !09_S	et	f	\N
108455	olevad	olevad =oleva  (PlN  >olev !02_A	et	f	\N
108456	olevad	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
108467	kuulutuse	kuulutuse =kuulutuse  (SgG  >kuulutus !11_S	et	f	\N
108469	kuulutuse	"kuulutus %kuuluta  )US_vS  <kuulutama ;27_V	et	f	\N
108472	kuulutuse	"kuulutus %kuulu  )TUS1_aS  <kuuluma ;27_V	et	f	\N
108473	kuulutuse	"kuulutus %kuulu  )TUS2_aS  <kuuld ;22_S	et	f	\N
108494	keele	keele =kee  (SgAll  >kesi !15_S	et	f	\N
108496	keele	keele =kee  (SgAll  >kee !26_S	et	f	\N
108498	keele	keele =keele  (SgG  >keel !13_S	et	f	\N
108506	eestlastele	eestlastele =eestlas  (PlAll  >eestlane !12?10_S	et	f	\N
108509	eestlastele	eestlastele =las  (PlAll  >eest+laps !14_S	et	f	\N
108511	eestlastele	eestlastele =laste  (PlAll  >eest+last !22_S	et	f	\N
108520	kinnitusel	kinnitusel =kinnituse  (SgAd  >kinnitus !11_S	et	f	\N
108521	kinnitusel	"kinnitus %kinnita  )US_vS  <kinnitama ;27_V	et	f	\N
108522	oodatud	oodatud =ooda  (PtsPtIps  >ootama !29_V	et	f	\N
108523	oodatud	oodatud =oodatu  (PlN  >oodatu !01_S	et	f	\N
108524	oodatud	"oodatu %ooda  )TU1_vS  <ootama ;29_V	et	f	\N
108525	oodatud	oodatud =oodatud  (ID  >oodatud !41_A	et	f	\N
108526	oodatud	"oodatud %ooda  )TUD_vA  <ootama ;29_V	et	f	\N
108536	siber	?siber =siber  (SgN  >siber !02_S	et	f	\N
108559	õppeaasta	õppeaasta =aasta  (SgN  >õppe+aasta !01_S	et	f	\N
108562	õppeaasta	õppeaasta =aasta  (SgG  >õppe+aasta !01_S	et	f	\N
108566	kohale	kohale =koha  (SgAll  >koha !17_S	et	f	\N
108567	kohale	kohale =koha  (SgAll  >koht !22_S	et	f	\N
108176	seima	seima =seima  (SgP  >seim !22_S	et	f	\N
108177	seima	seima =seima  (SgAdt  >seim !22_S	et	f	\N
108183	puurid	puurid =puuri  (PlN  >puur !22_S	et	f	\N
108184	puurid	puurid =puuri  (IndPrSg2  >puurima !28_V	et	f	\N
108198	talvel	talvel =talve  (SgAd  >talv !22_S	et	f	\N
108199	talvel	talvel =talve  (SgAd  >tali !24_S	et	f	\N
108200	talvel	talvel =talve  (PlAd  >talv !22_S	et	f	\N
108209	kooli	kooli =kooli  (SgG  >kool !22_S	et	f	\N
108210	kooli	kooli =kooli  (SgP  >kool !22_S	et	f	\N
108211	kooli	kooli =kooli  (SgAdt  >kool !22_S	et	f	\N
108213	kooli	kooli =kooli  (PlP  >kool !22_S	et	f	\N
108217	nendega	nendega =nen  (PlKom  >see !00_P	et	f	\N
108219	nendega	nendega =nen  (PlKom  >tema !00_P	et	f	\N
108220	ta	ta =ta  (SgG  >ta !00_P	et	f	\N
108221	ta	ta =ta  (SgN  >ta !00_P	et	f	\N
108232	linnas	linnas =linna  (SgIn  >linn !22_S	et	f	\N
108233	linnas	linnas =linnas  (SgN  >linnas !09_S	et	f	\N
108237	katsuvad	katsuvad =katsu  (IndPrPl3  >katsuma !28_V	et	f	\N
108238	katsuvad	katsuvad =katsuva  (PlN  >katsuv !02_A	et	f	\N
108240	katsuvad	"katsuv %katsu  )V_vA  <katsuma ;28_V	et	f	\N
108245	meeldiv	meeldiv =meeldi  (PtsPrPs  >meeldima !27_V	et	f	\N
108246	meeldiv	meeldiv =meeldiv  (SgN  >meeldiv !02_A	et	f	\N
108247	meeldiv	"meeldiv %meeldi  )V_vA  <meeldima ;27_V	et	f	\N
108256	rõmsaks	?rõmsaks =rõmsa  (SgTr  >rõmsa !16_S	et	f	\N
108258	rõmsaks	?rõmsaks =rõmsa  (KndPrPs  >rõmsama !29_V	et	f	\N
108263	poissi	poissi =poissi  (SgP  >poiss !23?22_S	et	f	\N
108264	poissi	poissi =poissi  (SgAdt  >poiss !23?22_S	et	f	\N
108268	anton	?anton =anton  (SgN  >anton !02_S	et	f	\N
108331	linna	linna =linna  (SgG  >linn !22_S	et	f	\N
108333	linna	linna =linna  (SgP  >linn !22_S	et	f	\N
108335	linna	linna =linna  (SgAdt  >linn !22_S	et	f	\N
108348	võiks	võiks =või  (SgTr  >või !26_S	et	f	\N
108349	võiks	võiks =või  (KndPrPs  >võima !37_V	et	f	\N
108352	võivad	võivad =või  (IndPrPl3  >võima !37_V	et	f	\N
108353	võivad	võivad =võiva  (PlN  >võiv !02_A	et	f	\N
108354	võivad	"võiv %või  )V_vA  <võima ;37_V	et	f	\N
108398	soodustused	soodustused =soodustuse  (PlN  >soodustus !11_S	et	f	\N
108399	soodustused	"soodustus %soodusta  )US_vS  <soodustama ;27_V	et	f	\N
108402	osta	osta =ost  (Inf  >ostma !34_V	et	f	\N
108403	osta	osta =osta  (IndPrPs_  >ostma !34_V	et	f	\N
108404	osta	osta =osta  (ImpPrSg2  >ostma !34_V	et	f	\N
108405	krediiti	krediiti =krediiti  (SgP  >krediit !22_S	et	f	\N
108406	krediiti	krediiti =krediiti  (SgAdt  >krediit !22_S	et	f	\N
108428	wwwmikromaailmee	?wwwmikromaailmee =wwwmikromaailmee  (SgN  >wwwmikromaailmee !26_S	et	f	\N
108430	wwwmikromaailmee	?wwwmikromaailmee =wwwmikromaailmee  (SgG  >wwwmikromaailmee !26_S	et	f	\N
108443	kallist	kallist =kalli  (SgEl  >kallis !05~07_A	et	f	\N
108444	kallist	kallist =kallis  (SgP  >kallis !05~07_A	et	f	\N
108448	pange	pange =pan  (ImpPrPl2  >panema !36_V	et	f	\N
108449	pange	pange =pange  (SgG  >pang !22_S	et	f	\N
108450	pange	pange =pange  (SgP  >pang !22_S	et	f	\N
108451	pange	pange =pange  (SgAdt  >pang !22_S	et	f	\N
108454	pange	pange =pange  (PlP  >pang !22_S	et	f	\N
108479	ülem-suetuki	?ülem-suetuki =suetuki  (SgN  >ülem-suetuki !01_S	et	f	\N
108481	ülem-suetuki	?ülem-suetuki =suetuki  (SgG  >ülem-suetuki !01_S	et	f	\N
108483	ülem-suetuki	?ülem-suetuki =suetuki  (SgG  >ülem-suetuk !02_S	et	f	\N
108485	ülem-suetuki	?ülem-suetuki =suetuki  (SgG  >ülem-suetukk !22_S	et	f	\N
108487	ülem-suetuki	?ülem-suetuki =suetuki  (IndPrPs_  >ülem-suetukkima !28_V	et	f	\N
108489	ülem-suetuki	?ülem-suetuki =suetuki  (ImpPrSg2  >ülem-suetukkima !28_V	et	f	\N
108501	konkurssi	konkurssi =konkurssi  (SgP  >konkurss !22_S	et	f	\N
108502	konkurssi	konkurssi =konkurssi  (SgAdt  >konkurss !22_S	et	f	\N
108515	pireti	?pireti =pire  (IndIpfIps  >pirema !27_V	et	f	\N
108516	pireti	?pireti =pireti  (ID  >pireti !41_D	et	f	\N
108517	pireti	?pireti =pireti  (SgG  >pirett !22_S	et	f	\N
108518	pireti	?pireti =pireti  (IndPrPs_  >pirettima !28_V	et	f	\N
108519	pireti	?pireti =pireti  (ImpPrSg2  >pirettima !28_V	et	f	\N
108532	tulema	tulema =tule  (Sup  >tulema !36_V	et	f	\N
108534	tulema	tulema =tulema  (SgG  >tulem !02_S	et	f	\N
108537	siberi	?siberi =siberi  (SgN  >siberi !01_S	et	f	\N
108539	siberi	?siberi =siberi  (SgG  >siberi !01_S	et	f	\N
108541	siberi	?siberi =siberi  (SgG  >siber !02_S	et	f	\N
108544	kasva	kasva =kasva  (IndPrPs_  >kasvama !28_V	et	f	\N
108545	kasva	kasva =kasva  (ImpPrSg2  >kasvama !28_V	et	f	\N
108551	tahtmise	tahtmise =tahtmise  (SgG  >tahtmine !12?10_S	et	f	\N
108552	tahtmise	"tahtmine %taht  )MINE_vS  <tahtma ;34_V	et	f	\N
108561	algust	algust =algu  (SgEl  >alg !22_S	et	f	\N
108564	algust	algust =algus  (SgP  >algus !11~09_S	et	f	\N
108565	algust	algust =us  (SgP  >alg+uks !14_S	et	f	\N
108569	kool	kool =koo  (SgAd  >kubu !18_S	et	f	\N
108570	kool	kool =kool  (SgN  >kool !22_S	et	f	\N
108586	tähtis	tähtis =tähti  (IndIpfSg3  >tähtima !28_V	et	f	\N
108589	tähtis	tähtis =tähtis  (SgN  >tähtis !02_A	et	f	\N
108178	piki	piki =piki  (ID  >piki !41_K	et	f	\N
108179	piki	piki =piki  (SgG  >pikk !22_S	et	f	\N
108180	piki	piki =piki  (SgG  >pikk !22_AS	et	f	\N
108181	piki	piki =piki  (IndPrPs_  >pikkima !28_V	et	f	\N
108182	piki	piki =piki  (ImpPrSg2  >pikkima !28_V	et	f	\N
108194	madu	madu =madu  (SgN  >madu !18_S	et	f	\N
108195	madu	madu =madu  (SgP  >madu !18_S	et	f	\N
108201	sõmerpalus	sõmerpalus =palu  (SgIn  >sõmer+palu !17_S	et	f	\N
108202	sõmerpalus	sõmerpalus =palu  (PlIn  >sõmer+pala !17_S	et	f	\N
108239	luua	luua =luu  (Inf  >looma !38_V	et	f	\N
108241	luua	luua =luua  (SgG  >luud !22_S	et	f	\N
108248	hea	hea =hea  (SgN  >hea !26_AS	et	f	\N
108250	hea	hea =hea  (SgG  >hea !26_AS	et	f	\N
108294	romaantika	?romaantika =romaantika  (SgN  >romaantika !01_S	et	f	\N
108295	romaantika	?romaantika =romaantika  (SgG  >romaantika !01_S	et	f	\N
108297	romaantika	?romaantika =romaantika  (SgG  >romaantikas !02_A	et	f	\N
108322	või	või =või  (ID  >või !41_JD	et	f	\N
108324	või	või =või  (SgN  >või !26_S	et	f	\N
108326	või	või =või  (SgG  >või !26_S	et	f	\N
108328	või	või =või  (IndPrPs_  >võima !37_V	et	f	\N
108330	või	või =või  (ImpPrSg2  >võima !37_V	et	f	\N
108332	varemetes	varemetes =vareme  (PlIn  >vare !04_S	et	f	\N
108334	varemetes	varemetes =e  (PlIn  >varem+esi !15_S	et	f	\N
108336	teisel	teisel =teise  (SgAd  >teine !12_OP	et	f	\N
108337	teisel	teisel =teise  (SgAd  >teise !12_P	et	f	\N
108345	päikese	päikese =päikese  (SgG  >päike !12?10_S	et	f	\N
108346	päikese	päikese =päikese  (SgG  >päikene !12?10_S	et	f	\N
108350	öelda	öelda =öel  (Inf  >ütlema !30_V	et	f	\N
108351	öelda	öelda =öel  (IndPrIps_  >ütlema !30_V	et	f	\N
108355	pakuda	?pakuda =paku  (Inf  >pakuma !27_V	et	f	\N
108380	reklaamist	reklaamist =reklaami  (SgEl  >reklaam !22_S	et	f	\N
108381	reklaamist	reklaamist =reklaamis  (SgP  >reklaamine !10_A	et	f	\N
108382	reklaamist	"reklaamine %reklaami  )NE_aA  <reklaam ;22_S	et	f	\N
108385	palju	palju =palju  (ID  >palju !41_D	et	f	\N
108386	palju	palju =palju  (SgN  >palju !16_P	et	f	\N
108387	palju	palju =palju  (SgG  >palju !16_P	et	f	\N
108416	energia	energia =energia  (SgN  >energia !01_S	et	f	\N
108417	energia	energia =energia  (SgG  >energia !01_S	et	f	\N
108424	rohkem	rohkem =rohkem  (ID  >rohkem !41_D	et	f	\N
108425	rohkem	"rohkem %rohke  )M_cA  <rohke ;01_A	et	f	\N
108426	rohkem	rohkem =rohkem  (SgN  >rohkem !02_A	et	f	\N
108445	eksamitöö	eksamitöö =töö  (SgN  >eksami+töö !26_S	et	f	\N
108446	eksamitöö	eksamitöö =töö  (SgG  >eksami+töö !26_S	et	f	\N
108452	sulgudes	sulgudes =sulgu  (PlIn  >sulg !22_S	et	f	\N
108453	sulgudes	sulgudes =sulgu  (Ger  >sulguma !27_V	et	f	\N
108462	piret	### piret	et	f	\N
108466	kuulutus	kuulutus =kuulutu  (SgIn  >kuulutu !01_AS	et	f	\N
108468	kuulutus	"kuulutu %kuulu  )TU1_vS  <kuuluma ;27_V	et	f	\N
108470	kuulutus	"kuulutu %kuulu  )TU2_kA  <kuuld ;22_S	et	f	\N
108471	kuulutus	kuulutus =kuulutus  (SgN  >kuulutus !11_S	et	f	\N
108474	kuulutus	"kuulutus %kuuluta  )US_vS  <kuulutama ;27_V	et	f	\N
108475	kuulutus	"kuulutus %kuulu  )TUS1_aS  <kuuluma ;27_V	et	f	\N
108477	kuulutus	"kuulutus %kuulu  )TUS2_aS  <kuuld ;22_S	et	f	\N
108478	kuulutus	kuulutus =lutu  (SgIn  >kuu+lutu !16_S	et	f	\N
108482	kuulutus	kuulutus =lutu  (SgIn  >kuu+lutt !22_S	et	f	\N
108503	väikestele	väikestele =väikes  (PlAll  >väike !12?10_A	et	f	\N
108504	väikestele	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
108505	väikestele	väikestele =väikes  (PlAll  >väikene !12?10_A	et	f	\N
108507	väikestele	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
108508	väikestele	väikestele =keste  (SgAll  >väi+keste !06_S	et	f	\N
108510	väikestele	väikestele =keste  (PlAll  >väi+kest !22_S	et	f	\N
108538	selline	selline =selline  (SgN  >selline !10_P	et	f	\N
108540	selline	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
108542	lenda	lenda =lenda  (IndPrPs_  >lendama !29_V	et	f	\N
108543	lenda	lenda =lenda  (ImpPrSg2  >lendama !29_V	et	f	\N
108549	tahtmine	tahtmine =tahtmine  (SgN  >tahtmine !12?10_S	et	f	\N
108550	tahtmine	"tahtmine %taht  )MINE_vS  <tahtma ;34_V	et	f	\N
108582	siin	siin =siin  (ID  >siin !41_D	et	f	\N
108583	siin	siin =siin  (SgN  >siin !22_S	et	f	\N
108590	tänaseks	tänaseks =tänase  (SgTr  >tänane !10_A	et	f	\N
108591	tänaseks	tänaseks =tänaseks  (ID  >tänaseks !41_D	et	f	\N
108592	tänaseks	tänaseks =seks  (SgN  >täna+seks !22_S	et	f	\N
108593	õppimine	õppimine =õppimine  (SgN  >õppimine !12_S	et	f	\N
108594	õppimine	"õppimine %õppi  )MINE_vS  <õppima ;28_V	et	f	\N
108609	mõnet	?mõnet =mõne  (SgP  >mõne !16_S	et	f	\N
108616	ülejäänud	ülejäänud =jää  (PtsPtPs  >üle+_jääma !37_V	et	f	\N
108618	ülejäänud	ülejäänud =jäänu  (PlN  >üle+jäänu !01_S	et	f	\N
108620	ülejäänud	ülejäänud =jäänu  (PlN  >üle+jäänu !06_S	et	f	\N
108640	poolpõlenud	poolpõlenud =põlenu  (PlN  >pool+põlenu !01_S	et	f	\N
108641	poolpõlenud	poolpõlenud =põlenud  (ID  >pool+põlenud !41_A	et	f	\N
108655	karda	karda =karda  (SgP  >kard !22_S	et	f	\N
108464	vormi	vormi =vormi  (ImpPrSg2  >vormima !28_V	et	f	\N
108493	eesti	eesti =eesti  (ID  >eesti !41_G	et	f	\N
108495	eesti	eesti =eesti  (SgN  >eesti !16_H	et	f	\N
108497	eesti	eesti =eesti  (SgG  >eesti !16_H	et	f	\N
108533	tuli	tuli =tul  (IndIpfSg3  >tulema !36_V	et	f	\N
108535	tuli	tuli =tuli  (SgN  >tuli !20_S	et	f	\N
108557	pärast	pärast =pära  (SgEl  >pära !17_S	et	f	\N
108558	pärast	pärast =päras  (SgP  >pärane !10_A	et	f	\N
108560	pärast	"pärane %pära  )NE_aA  <pära ;17_S	et	f	\N
108563	pärast	pärast =pärast  (ID  >pärast !41_DK	et	f	\N
108571	kogu	kogu =kogu  (ID  >kogu !41_P	et	f	\N
108573	kogu	kogu =kogu  (SgN  >kogu !17_S	et	f	\N
108575	kogu	kogu =kogu  (SgG  >kogu !17_S	et	f	\N
108577	kogu	kogu =kogu  (SgP  >kogu !17_S	et	f	\N
108579	kogu	kogu =kogu  (IndPrPs_  >koguma !27_V	et	f	\N
108581	kogu	kogu =kogu  (ImpPrSg2  >koguma !27_V	et	f	\N
108587	tähtsam	tähtsam =tähtsam  (SgN  >tähtsam !02_A	et	f	\N
108588	tähtsam	"tähtsam %tähtsa  )M_cA  <tähtis ;02_A	et	f	\N
108599	mõnusalt	mõnusalt =mõnusa  (SgAbl  >mõnus !02_A	et	f	\N
108600	mõnusalt	mõnusalt =mõnusalt  (ID  >mõnusalt !41_D	et	f	\N
108601	mõnusalt	"mõnusalt %mõnusa  )LT_mD  <mõnus ;02_A	et	f	\N
108608	aktsentiga	?aktsentiga =aktsenti  (SgKom  >aktsenti !01_S	et	f	\N
108610	murret	murret =murre  (SgP  >murre !05_S	et	f	\N
108611	murret	murret =murre  (SgP  >murre !06_S	et	f	\N
108612	siiski	siiski =siiski  (ID  >siiski !41_D	et	f	\N
108614	siiski	siiski =siis  (ID^  >siis !41_D	et	f	\N
108622	keeles	keeles =keele  (SgIn  >keel !13_S	et	f	\N
108623	keeles	keeles =keele  (PlIn  >keeld !22_S	et	f	\N
108644	saatatakse	?saatatakse =saata  (IndPrIps  >saatama !27_V	et	f	\N
108645	saatatakse	?saatatakse =saatatakse  (SgG  >saatatakne !02_A	et	f	\N
108646	saatatakse	?saatatakse =saatatakse  (PlP  >saatataks !22_S	et	f	\N
108647	saatatakse	?saatatakse =atakse  (SgG  >saat+atakne !02_A	et	f	\N
108666	kuid	kuid =ku  (PlP  >kuu !26_S	et	f	\N
108668	kuid	kuid =kuid  (ID  >kuid !41_J	et	f	\N
108670	ahju	ahju =ahju  (SgG  >ahi !24_S	et	f	\N
108671	ahju	ahju =ahju  (SgP  >ahi !24_S	et	f	\N
108674	ahju	ahju =ahju  (SgAdt  >ahi !24_S	et	f	\N
108677	vaja	vaja =vaja  (ID  >vaja !41_D	et	f	\N
108678	vaja	vaja =vaja  (SgN  >vaja !17_S	et	f	\N
108679	vaja	vaja =vaja  (SgG  >vaja !17_S	et	f	\N
108680	vaja	vaja =vaja  (SgP  >vaja !17_S	et	f	\N
108681	vaja	vaja =vaja  (IndPrPs_  >vajama !27_V	et	f	\N
108682	vaja	vaja =vaja  (ImpPrSg2  >vajama !27_V	et	f	\N
108721	naiselikum	naiselikum =naiselikum  (SgN  >naiselikum !02_A	et	f	\N
108722	naiselikum	"naiselikum %naiseliku  )M_cA  <naiselik ;25_A	et	f	\N
108732	soovimatu	soovimatu =soovimatu  (SgN  >soovimatu !01_A	et	f	\N
108733	soovimatu	"soovimatu %soovi  )MATU_vA  <soovima ;28_V	et	f	\N
108734	soovimatu	soovimatu =soovimatu  (SgG  >soovimatu !01_A	et	f	\N
108735	soovimatu	soovimatu =imatu  (SgN  >soov+imatu !01_A	et	f	\N
108736	soovimatu	"soov+imatu %ima  )TU2_kA  <soov+ima ;17_S	et	f	\N
108737	soovimatu	soovimatu =imatu  (SgG  >soov+imatu !01_A	et	f	\N
108744	tagajärgi	tagajärgi =järgi  (SgG  >taga+järk !22_S	et	f	\N
108746	tagajärgi	tagajärgi =järgi  (SgP  >taga+järg !22_S	et	f	\N
108748	tagajärgi	tagajärgi =järgi  (SgAdt  >taga+järg !22_S	et	f	\N
108750	tagajärgi	tagajärgi =järgi  (PlP  >taga+järg !22_S	et	f	\N
108775	lausa	lausa =lausa  (ID  >lausa !41_D	et	f	\N
108776	lausa	lausa =lausa  (SgG  >lausk !22_A	et	f	\N
108789	söömine	söömine =söömine  (SgN  >söömine !12?10_S	et	f	\N
108790	söömine	"söömine %söö  )MINE_vS  <sööma ;38_V	et	f	\N
108791	söömine	"söömine %söömi  )NE_aA  <sööm ;22_S	et	f	\N
108792	telesaade	telesaade =saade  (SgN  >tele+saade !06_S	et	f	\N
108794	telesaade	telesaade =saade  (PlP  >tele+saad !22_S	et	f	\N
108801	valmistamist	valmistamist =valmistamis  (SgP  >valmistamine !12_S	et	f	\N
108802	valmistamist	"valmistamine %valmista  )MINE_vS  <valmistama ;27_V	et	f	\N
108817	iv	### iv	et	f	\N
108823	vanemad	vanemad =vanema  (PlN  >vanem !02_AS	et	f	\N
108824	vanemad	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
108838	huvi	huvi =huvi  (SgN  >huvi !17_S	et	f	\N
108840	huvi	huvi =huvi  (SgG  >huvi !17_S	et	f	\N
108843	huvi	huvi =huvi  (SgP  >huvi !17_S	et	f	\N
108859	väikesed	väikesed =väikese  (PlN  >väike !12?10_A	et	f	\N
108860	väikesed	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
108861	väikesed	väikesed =väikese  (PlN  >väikene !12?10_A	et	f	\N
108862	väikesed	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
108881	külmetamisest	külmetamisest =külmetamise  (SgEl  >külmetamine !12_S	et	f	\N
108883	külmetamisest	"külmetamine %külmeta  )MINE_vS  <külmetama ;27_V	et	f	\N
108894	v	### v	et	f	\N
108897	kolmekäigulise	kolmekäigulise =käigulise  (SgG  >kolme+käiguline !12_A	et	f	\N
108899	kolmekäigulise	"kolme+käiguline %käigu  )LINE_aA  <kolme+käik ;22_S	et	f	\N
108906	kohal	kohal =koha  (SgAd  >koha !17_S	et	f	\N
108907	kohal	kohal =koha  (SgAd  >koht !22_S	et	f	\N
108909	kohal	kohal =kohal  (ID  >kohal !41_DK	et	f	\N
108529	üllatunud	"üllatunu %üllatu  )NU_vS  <üllatuma ;27_V	et	f	\N
108530	üllatunud	üllatunud =üllatunud  (ID  >üllatunud !41_A	et	f	\N
108531	üllatunud	"üllatunud %üllatu  )NUD_vA  <üllatuma ;27_V	et	f	\N
108546	rohi	rohi =rohi  (SgN  >rohi !24_S	et	f	\N
108547	rohi	rohi =rohi  (IndPrPs_  >rohima !27_V	et	f	\N
108548	rohi	rohi =rohi  (ImpPrSg2  >rohima !27_V	et	f	\N
108553	täis	täis =täi  (SgIn  >täi !26_S	et	f	\N
108554	täis	täis =täi  (IndIpfSg3  >täima !27_V	et	f	\N
108555	täis	täis =täis  (ID  >täis !41_DA	et	f	\N
108556	täis	täis =täis  (SgN  >täis !14_AS	et	f	\N
108584	kõige	kõige =kõige  (SgG  >kõik !00_P	et	f	\N
108585	kõige	kõige =kõige  (ID  >kõige !41_D	et	f	\N
108595	mõnus	mõnus =mõnu  (SgIn  >mõnu !17_S	et	f	\N
108596	mõnus	mõnus =mõnus  (SgN  >mõnus !02_A	et	f	\N
108648	talve	talve =talve  (SgG  >talv !22_S	et	f	\N
108649	talve	talve =talve  (SgG  >tali !24_S	et	f	\N
108650	talve	talve =talve  (SgP  >talv !22_S	et	f	\N
108651	talve	talve =talve  (SgP  >tali !24_S	et	f	\N
108652	talve	talve =talve  (SgAdt  >talv !22_S	et	f	\N
108653	talve	talve =talve  (SgAdt  >tali !24_S	et	f	\N
108654	talve	talve =talve  (PlP  >talv !22_S	et	f	\N
108661	tooti	tooti =tooti  (SgP  >toot !22_S	et	f	\N
108662	tooti	tooti =tooti  (SgAdt  >toot !22_S	et	f	\N
108684	vildid	vildid =vildi  (PlN  >vilt !22_S	et	f	\N
108685	vildid	vildid =vildi  (IndPrSg2  >viltima !28_V	et	f	\N
108697	vapralt	vapralt =vapra  (SgAbl  >vapper !02_A	et	f	\N
108699	vapralt	vapralt =vapralt  (ID  >vapralt !41_D	et	f	\N
108701	vapralt	"vapralt %vapra  )LT_mD  <vapper ;02_A	et	f	\N
108711	iii	?iii =iii  (SgN  >iii !26_S	et	f	\N
108712	iii	?iii =iii  (SgG  >iii !26_S	et	f	\N
108728	kogus	kogus =kogu  (SgIn  >kogu !17_S	et	f	\N
108729	kogus	kogus =kogu  (IndIpfSg3  >koguma !27_V	et	f	\N
108730	kogus	kogus =kogus  (SgN  >kogus !02_A	et	f	\N
108731	kogus	kogus =kogus  (SgN  >kogus !09_S	et	f	\N
108738	tegutsemata	tegutsemata =tegutse  (SupAb  >tegutsema !27_V	et	f	\N
108740	tegutsemata	tegutsemata =tegutsemata  (ID  >tegutsemata !41_A	et	f	\N
108742	tegutsemata	"tegutsemata %tegutse  )MATA_vA  <tegutsema ;27_V	et	f	\N
108758	sportima	sportima =sporti  (Sup  >sportima !28_V	et	f	\N
108759	sportima	sportima =ima  (SgN  >sport+ima !17_S	et	f	\N
108760	sportima	sportima =ima  (SgG  >sport+ima !17_S	et	f	\N
108761	sportima	sportima =ima  (SgP  >sport+ima !17_S	et	f	\N
108762	tohi	tohi =tohi  (IndPrPs_  >tohtima !28_V	et	f	\N
108763	tohi	tohi =tohi  (ImpPrSg2  >tohtima !28_V	et	f	\N
108768	olema	olema =ole  (Sup  >olema !36_V	et	f	\N
108769	olema	olema =olema  (SgG  >olem !02_S	et	f	\N
108783	hingata	hingata =hinga  (Inf  >hingama !29_V	et	f	\N
108784	hingata	hingata =hinga  (IndPrIps_  >hingama !29_V	et	f	\N
108785	hingata	hingata =hingata  (IndPrPs_  >hingatama !27_V	et	f	\N
108786	hingata	hingata =hingata  (ImpPrSg2  >hingatama !27_V	et	f	\N
108807	huvitava	huvitava =huvitava  (SgG  >huvitav !02_A	et	f	\N
108809	huvitava	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
108810	huvitava	huvitava =tava  (SgN  >huvi+tava !17_S	et	f	\N
108811	huvitava	huvitava =tava  (SgG  >huvi+tava !17_S	et	f	\N
108812	huvitava	huvitava =tava  (SgP  >huvi+tava !17_S	et	f	\N
108813	aega	aega =aega  (ID  >aega !41_K	et	f	\N
108815	aega	aega =aega  (SgP  >aeg !22_S	et	f	\N
108818	aega	aega =aega  (SgAdt  >aeg !22_S	et	f	\N
108830	usaldavad	usaldavad =usalda  (IndPrPl3  >usaldama !27_V	et	f	\N
108831	usaldavad	usaldavad =usaldava  (PlN  >usaldav !02_A	et	f	\N
108832	usaldavad	"usaldav %usalda  )V_vA  <usaldama ;27_V	et	f	\N
108839	ainult	ainult =ainu  (SgAbl  >ainus !07_AS	et	f	\N
108841	ainult	ainult =ainu  (SgAbl  >ainu !16_S	et	f	\N
108842	ainult	ainult =ainu  (PlAbl  >ain !22_S	et	f	\N
108844	ainult	ainult =ainult  (ID  >ainult !41_D	et	f	\N
108845	ainult	"ainult %ainu  )LT_mD  <ainus ;07_AS	et	f	\N
108849	ilusadele	### ilusadele	et	f	\N
108873	valdkonnale	valdkonnale =valdkonna  (SgAll  >valdkond !22_S	et	f	\N
108875	valdkonnale	valdkonnale =konna  (SgAll  >vald+konn !22_S	et	f	\N
108891	päikeseks	päikeseks =päikese  (SgTr  >päike !12?10_S	et	f	\N
108893	päikeseks	päikeseks =päikese  (SgTr  >päikene !12?10_S	et	f	\N
108908	olid	olid =ol  (IndIpfSg2  >olema !36_V	et	f	\N
108910	olid	olid =ol  (IndIpfPl3  >olema !36_V	et	f	\N
108927	keegi	keegi =kee  (SgN  >keegi !00_P	et	f	\N
108928	keegi	keegi =kee  (SgN^  >kee !26_S	et	f	\N
108929	keegi	keegi =kee  (SgG^  >kesi !15_S	et	f	\N
108930	keegi	keegi =kee  (SgG^  >kee !26_S	et	f	\N
108931	keegi	keegi =kee  (IndPrPs_^  >keema !37_V	et	f	\N
108932	keegi	keegi =kee  (ImpPrSg2^  >keema !37_V	et	f	\N
108940	tule	tule =tule  (SgG  >tuli !20_S	et	f	\N
108941	tule	tule =tule  (IndPrPs_  >tulema !36_V	et	f	\N
108942	tule	tule =tule  (ImpPrSg2  >tulema !36_V	et	f	\N
108948	alkoholi	alkoholi =alkoholi  (SgG  >alkohol !19_S	et	f	\N
108949	alkoholi	alkoholi =alkoholi  (SgP  >alkohol !19_S	et	f	\N
108568	kohale	kohale =kohale  (ID  >kohale !41_DK	et	f	\N
108572	alganud	?alganud =alga  (PtsPtPs  >alkama !29_V	et	f	\N
108574	alganud	?alganud =alganu  (PlN  >alganu !01_S	et	f	\N
108576	alganud	?alganud =alganu  (IndPrSg2  >alganuma !27_V	et	f	\N
108578	alganud	?alganud =alganud  (ID  >alganud !41_A	et	f	\N
108580	alganud	?alganud =anu  (PlN  >alg+anu !17_S	et	f	\N
108604	vene	vene =vene  (ID  >vene !41_G	et	f	\N
108606	vene	vene =vene  (SgN  >vene !16_S	et	f	\N
108607	vene	vene =vene  (SgG  >vene !16_S	et	f	\N
108613	venemaa	venemaa =maa  (SgN  >vene+maa !26_S	et	f	\N
108615	venemaa	venemaa =maa  (SgG  >vene+maa !26_S	et	f	\N
108617	aine	aine =aine  (SgN  >aine !06_S	et	f	\N
108619	aine	aine =aine  (SgG  >aine !06_S	et	f	\N
108621	aine	aine =aine  (PlP  >ain !22_S	et	f	\N
108625	kolmesaja	?kolmesaja =kolmesaja  (SgN  >kolmesaja !01_S	et	f	\N
108626	kolmesaja	?kolmesaja =kolmesaja  (SgG  >kolmesaja !01_S	et	f	\N
108627	kolmesaja	?kolmesaja =kolmesaja  (SgG  >kolmesajas !02_A	et	f	\N
108628	kolmesaja	?kolmesaja =saja  (SgN  >kolme+saja !17_S	et	f	\N
108629	kolmesaja	?kolmesaja =saja  (SgG  >kolme+saja !17_S	et	f	\N
108630	kolmesaja	?kolmesaja =saja  (SgP  >kolme+saja !17_S	et	f	\N
108631	kolmesaja	?kolmesaja =esaja  (SgN  >kolm+esaja !01_S	et	f	\N
108632	kolmesaja	?kolmesaja =esaja  (SgG  >kolm+esaja !01_S	et	f	\N
108634	kolmesaja	?kolmesaja =esaja  (SgG  >kolm+esajas !02_A	et	f	\N
108637	kõike	kõike =kõike  (SgAdt  >kõik !00_P	et	f	\N
108638	kõike	kõike =kõike  (SgP  >kõik !00_P	et	f	\N
108639	kõike	kõike =kõike  (PlP  >kõik !22_S	et	f	\N
108642	raamatud	raamatud =raamatu  (PlN  >raamat !02_S	et	f	\N
108643	raamatud	raamatud =atu  (PlN  >raam+att !22_S	et	f	\N
108672	kütmine	kütmine =kütmine  (SgN  >kütmine !12?10_S	et	f	\N
108673	kütmine	"kütmine %küt  )MINE_vS  <kütma ;35_V	et	f	\N
108688	muud	muud =muu  (PlN  >muu !26_S	et	f	\N
108689	muud	muud =muu  (PlN  >muu !26_P	et	f	\N
108690	muud	muud =muu  (SgP  >muu !26_S	et	f	\N
108691	muud	muud =muu  (SgP  >muu !26_P	et	f	\N
108692	muud	muud =muu  (IndPrSg2  >muuma !27_V	et	f	\N
108702	lühendatud	lühendatud =lühenda  (PtsPtIps  >lühendama !27_V	et	f	\N
108703	lühendatud	lühendatud =lühendatu  (PlN  >lühendatu !01_S	et	f	\N
108704	lühendatud	"lühendatu %lühenda  )TU1_vS  <lühendama ;27_V	et	f	\N
108706	lühendatud	lühendatud =lühendatud  (ID  >lühendatud !41_A	et	f	\N
108708	lühendatud	"lühendatud %lühenda  )TUD_vA  <lühendama ;27_V	et	f	\N
108725	kaunim	kaunim =kaunim  (SgN  >kaunim !02_A	et	f	\N
108726	kaunim	"kaunim %kauni  )M_cA  <kaunis ;05_A	et	f	\N
108727	kaunim	"kaunim %kauni  )M_cA  <kaunis ;07_A	et	f	\N
108739	meid	meid =me  (PlP  >ma !00_P	et	f	\N
108741	meid	meid =me  (PlP  >mina !00_P	et	f	\N
108743	soovimatut	soovimatut =soovimatu  (SgP  >soovimatu !01_A	et	f	\N
108745	soovimatut	"soovimatu %soovi  )MATU_vA  <soovima ;28_V	et	f	\N
108747	soovimatut	soovimatut =imatu  (SgP  >soov+imatu !01_A	et	f	\N
108749	soovimatut	"soov+imatu %ima  )TU2_kA  <soov+ima ;17_S	et	f	\N
108770	maagiline	maagiline =maagiline  (SgN  >maagiline !12_A	et	f	\N
108771	maagiline	"maagiline %maagi  )LINE_aA  <maag ;22_S	et	f	\N
108772	maagiline	"maagiline %maagi  )LINE_aA  <maak ;22_S	et	f	\N
108781	selle	selle =selle  (SgG  >see !00_P	et	f	\N
108782	selle	selle =selle  (PlP  >sell !22_S	et	f	\N
108803	söömist	söömist =söömi  (SgEl  >sööm !22_S	et	f	\N
108804	söömist	söömist =söömi  (PlEl  >sööm !22_S	et	f	\N
108805	söömist	söömist =söömis  (SgP  >söömine !12?10_S	et	f	\N
108806	söömist	"söömine %söö  )MINE_vS  <sööma ;38_V	et	f	\N
108808	söömist	"söömine %söömi  )NE_aA  <sööm ;22_S	et	f	\N
108846	kiired	kiired =kiire  (PlN  >kiire !01_A	et	f	\N
108847	kiired	kiired =kiire  (PlN  >kiire !06_S	et	f	\N
108848	kiired	kiired =kiire  (PlN  >kiire !06_AS	et	f	\N
108850	kiired	kiired =kiire  (PlN  >kiir !13_S	et	f	\N
108853	töökoha	töökoha =koha  (SgN  >töö+koha !17_S	et	f	\N
108854	töökoha	töökoha =koha  (SgG  >töö+koha !17_S	et	f	\N
108855	töökoha	töökoha =koha  (SgG  >töö+koht !22_S	et	f	\N
108856	töökoha	töökoha =koha  (SgP  >töö+koha !17_S	et	f	\N
108857	küsimuses	küsimuses =küsimuse  (SgIn  >küsimus !11_S	et	f	\N
108858	küsimuses	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
108872	teisele	teisele =teise  (SgAll  >teine !12_OP	et	f	\N
108874	teisele	teisele =teise  (SgAll  >teise !12_P	et	f	\N
108876	peab	peab =pea  (IndPrSg3  >pida !40_V	et	f	\N
108878	peab	peab =pea  (IndPrSg3  >pidama !28_V	et	f	\N
108889	suviseks	suviseks =suvise  (SgTr  >suvine !10_A	et	f	\N
108890	suviseks	"suvine %suvi  )NE_aA  <suvi ;20_S	et	f	\N
108892	suviseks	suviseks =seks  (SgN  >suvi+seks !22_S	et	f	\N
108911	lapsel	lapsel =lapse  (SgAd  >laps !14_S	et	f	\N
108912	lapsel	lapsel =lapse  (PlAd  >laps !22_S	et	f	\N
108923	naeru	naeru =naeru  (SgG  >naer !22_S	et	f	\N
108925	naeru	naeru =naeru  (SgP  >naer !22_S	et	f	\N
108926	naeru	naeru =naeru  (SgAdt  >naer !22_S	et	f	\N
108953	küll	küll =küll  (ID  >küll !41_D	et	f	\N
108597	mahlakas	mahlakas =mahlaka  (SgIn  >mahlakas !02_A	et	f	\N
108598	mahlakas	mahlakas =mahlakas  (SgN  >mahlakas !02_A	et	f	\N
108602	mahlakalt	mahlakalt =mahlaka  (SgAbl  >mahlakas !02_A	et	f	\N
108603	mahlakalt	mahlakalt =mahlakalt  (ID  >mahlakalt !41_D	et	f	\N
108605	mahlakalt	"mahlakalt %mahlaka  )LT_mD  <mahlakas ;02_A	et	f	\N
108624	kolmsada	### kolmsada	et	f	\N
108633	kõik	kõik =kõik  (SgN  >kõik !00_P	et	f	\N
108635	kõik	kõik =kõik  (PlN  >kõik !00_P	et	f	\N
108636	kõik	kõik =kõik  (SgN  >kõik !22_S	et	f	\N
108667	ööd	ööd =öö  (PlN  >öö !26_S	et	f	\N
108669	ööd	ööd =öö  (SgP  >öö !26_S	et	f	\N
108675	kütmisele	kütmisele =kütmise  (SgAll  >kütmine !12?10_S	et	f	\N
108676	kütmisele	"kütmine %küt  )MINE_vS  <kütma ;35_V	et	f	\N
108683	külapoest	külapoest =poe  (SgEl  >küla+pood !22_S	et	f	\N
108686	külapoest	külapoest =poes  (SgP  >küla+poene !10_A	et	f	\N
108687	külapoest	"küla+poene %poe  )NE_aA  <küla+pood ;22_S	et	f	\N
108693	talveks	talveks =talve  (SgTr  >talv !22_S	et	f	\N
108694	talveks	talveks =talve  (SgTr  >tali !24_S	et	f	\N
108695	talveks	talveks =talve  (PlTr  >talv !22_S	et	f	\N
108696	valmistuv	valmistuv =valmistu  (PtsPrPs  >valmistuma !27_V	et	f	\N
108698	valmistuv	valmistuv =valmistuv  (SgN  >valmistuv !02_A	et	f	\N
108700	valmistuv	"valmistuv %valmistu  )V_vA  <valmistuma ;27_V	et	f	\N
108710	slõhtuleht	?slõhtuleht =slõhtuleht  (SgN  >slõhtuleht !22_S	et	f	\N
108713	etteantud	etteantud =an  (PtsPtIps  >ette+_andma !34_V	et	f	\N
108714	etteantud	etteantud =antu  (PlN  >ette+antu !01_S	et	f	\N
108717	kirjavahemärke	kirjavahemärke =märke  (SgG  >kirja+vahe+märge !06_S	et	f	\N
108718	kirjavahemärke	kirjavahemärke =märke  (PlP  >kirja+vahe+märk !22_S	et	f	\N
108751	pinge	pinge =pinge  (SgN  >pinge !06_S	et	f	\N
108752	pinge	pinge =pinge  (SgG  >pinge !06_S	et	f	\N
108753	pinge	pinge =pinge  (PlP  >ping !22_S	et	f	\N
108765	ülekoormust	ülekoormust =must  (SgN  >üle+koor+must !22_AS	et	f	\N
108767	ülekoormust	ülekoormust =koormus  (SgP  >üle+koormus !11~09_S	et	f	\N
108773	abil	abil =abi  (SgAd  >abi !17_S	et	f	\N
108774	abil	abil =abil  (ID  >abil !41_K	et	f	\N
108793	vaatamine	vaatamine =vaatamine  (SgN  >vaatamine !12_S	et	f	\N
108795	vaatamine	"vaatamine %vaata  )MINE_vS  <vaatama ;29_V	et	f	\N
108799	und	und =un  (SgP  >uni !20_S	et	f	\N
108800	und	und =und  (SgN  >und !22_S	et	f	\N
108814	vaatamise	vaatamise =vaatamise  (SgG  >vaatamine !12_S	et	f	\N
108816	vaatamise	"vaatamine %vaata  )MINE_vS  <vaatama ;29_V	et	f	\N
108819	pean	pean =pea  (IndPrSg1  >pida !40_V	et	f	\N
108820	pean	pean =pea  (IndPrSg1  >pidama !28_V	et	f	\N
108827	aitavad	aitavad =aita  (IndPrPl3  >aitama !29_V	et	f	\N
108828	aitavad	aitavad =aitava  (PlN  >aitav !02_A	et	f	\N
108829	aitavad	"aitav %aita  )V_vA  <aitama ;29_V	et	f	\N
108870	küsimus	küsimus =küsimus  (SgN  >küsimus !11_S	et	f	\N
108871	küsimus	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
108877	ajal	ajal =aja  (SgAd  >aeg !22_S	et	f	\N
108879	ajal	ajal =ajal  (ID  >ajal !41_K	et	f	\N
108885	suvine	suvine =suvine  (SgN  >suvine !10_A	et	f	\N
108887	suvine	"suvine %suvi  )NE_aA  <suvi ;20_S	et	f	\N
108900	lõuna	lõuna =lõuna  (SgN  >lõuna !06_S	et	f	\N
108903	lõuna	lõuna =lõuna  (SgG  >lõuna !06_S	et	f	\N
108913	oodata	oodata =ooda  (Inf  >ootama !29_V	et	f	\N
108914	oodata	oodata =ooda  (IndPrIps_  >ootama !29_V	et	f	\N
108915	tulevad	tulevad =tule  (IndPrPl3  >tulema !36_V	et	f	\N
108916	tulevad	tulevad =tuleva  (PlN  >tulev !02_A	et	f	\N
108917	tulevad	"tulev %tule  )V_vA  <tulema ;36_V	et	f	\N
108933	anekdooti	anekdooti =anekdooti  (SgP  >anekdoot !22_S	et	f	\N
108934	anekdooti	anekdooti =anekdooti  (SgAdt  >anekdoot !22_S	et	f	\N
108946	lähete	lähete =lähe  (IndPrPl2  >minema !36_V	et	f	\N
108947	lähete	lähete =lähe  (PlG  >lähe !06_S	et	f	\N
108968	jääd	jääd =jää  (PlN  >jää !26_S	et	f	\N
108969	jääd	jääd =jää  (SgP  >jää !26_S	et	f	\N
108970	jääd	jääd =jää  (IndPrSg2  >jääma !37_V	et	f	\N
108989	hooguga	?hooguga =hoogu  (SgKom  >hoogu !16_S	et	f	\N
108990	hooguga	?hooguga =guga  (SgN  >hoo+guga !17_S	et	f	\N
108991	hooguga	?hooguga =guga  (SgG  >hoo+guga !17_S	et	f	\N
108992	hooguga	?hooguga =guga  (SgP  >hoo+guga !17_S	et	f	\N
108993	mõnusam	mõnusam =mõnusam  (SgN  >mõnusam !02_A	et	f	\N
108994	mõnusam	"mõnusam %mõnusa  )M_cA  <mõnus ;02_A	et	f	\N
108999	saadavad	saadavad =saada  (IndPrPl3  >saatma !34_V	et	f	\N
109000	saadavad	saadavad =saadava  (PlN  >saadav !02_A	et	f	\N
109001	saadavad	"saadav %saa  )TAV_vAS  <saama ;37_V	et	f	\N
109002	toodi	toodi =too  (IndIpfIps  >tooma !38_V	et	f	\N
109003	toodi	toodi =toodi  (SgG  >toot !22_S	et	f	\N
109043	kiirde	kiirde =kiir  (SgAdt  >kiir !13_S	et	f	\N
109044	kiirde	kiirde =kiirde  (PlP  >kiird !22_S	et	f	\N
109077	konkurssist	?konkurssist =konkurssi  (SgEl  >konkurssi !01_S	et	f	\N
109078	konkurssist	?konkurssist =konkurssis  (SgP  >konkurssis !11_S	et	f	\N
109079	konkurssist	?konkurssist =konkurssist  (SgN  >konkurssist !22_S	et	f	\N
108656	karda	karda =karda  (SgAdt  >kard !22_S	et	f	\N
108657	karda	karda =karda  (IndPrPs_  >kardama !29_V	et	f	\N
108658	karda	karda =karda  (IndPrPs_  >kartma !34_V	et	f	\N
108659	karda	karda =karda  (ImpPrSg2  >kardama !29_V	et	f	\N
108660	karda	karda =karda  (ImpPrSg2  >kartma !34_V	et	f	\N
108663	talvepuud	talvepuud =puu  (PlN  >talve+puu !26_S	et	f	\N
108664	talvepuud	talvepuud =puu  (SgP  >talve+puu !26_S	et	f	\N
108665	talvepuud	talvepuud =puud  (SgN  >talve+puud !22_S	et	f	\N
108705	ajalehest	ajalehest =lehe  (SgEl  >aja+leht !22_S	et	f	\N
108707	ajalehest	ajalehest =lehes  (SgP  >aja+lehene !10_A	et	f	\N
108709	ajalehest	"aja+lehene %lehe  )NE_aA  <aja+leht ;22_S	et	f	\N
108715	pannes	pannes =pann  (Ger  >panema !36_V	et	f	\N
108716	pannes	pannes =panne  (PlIn  >pann !22_S	et	f	\N
108719	naeratus	naeratus =naeratus  (SgN  >naeratus !11_S	et	f	\N
108720	naeratus	"naeratus %naerata  )US_vS  <naeratama ;27_V	et	f	\N
108723	mehelikum	mehelikum =mehelikum  (SgN  >mehelikum !02_A	et	f	\N
108724	mehelikum	"mehelikum %meheliku  )M_cA  <mehelik ;25_A	et	f	\N
108754	saama	saama =saa  (Sup  >saama !37_V	et	f	\N
108755	saama	saama =saama  (SgG  >saam !22_S	et	f	\N
108756	saama	saama =saama  (SgP  >saam !22_S	et	f	\N
108757	saama	saama =saama  (SgAdt  >saam !22_S	et	f	\N
108764	lasta	lasta =las  (Inf  >laskma !34_V	et	f	\N
108766	lasta	lasta =las  (IndPrIps_  >laskma !34_V	et	f	\N
108777	tänapaeval	?tänapaeval =tänapaeva  (SgAd  >tänapaeva !16_S	et	f	\N
108778	tänapaeval	?tänapaeval =tänapaeval  (SgN  >tänapaeval !02_S	et	f	\N
108779	tänapaeval	?tänapaeval =paeva  (SgAd  >täna+paeva !16_S	et	f	\N
108780	tänapaeval	?tänapaeval =paeval  (SgN  >täna+paeval !02_S	et	f	\N
108787	valmistamine	valmistamine =valmistamine  (SgN  >valmistamine !12_S	et	f	\N
108788	valmistamine	"valmistamine %valmista  )MINE_vS  <valmistama ;27_V	et	f	\N
108796	pühapäeva	pühapäeva =päeva  (SgG  >püha+päev !22_S	et	f	\N
108797	pühapäeva	pühapäeva =päeva  (SgP  >püha+päev !22_S	et	f	\N
108798	pühapäeva	pühapäeva =päeva  (SgAdt  >püha+päev !22_S	et	f	\N
108821	lugu	lugu =lugu  (SgN  >lugu !18_S	et	f	\N
108822	lugu	lugu =lugu  (SgP  >lugu !18_S	et	f	\N
108825	vanemaid	vanemaid =vanema  (PlP  >vanem !02_AS	et	f	\N
108826	vanemaid	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
108833	huvitud	huvitud =huvitu  (PlN  >huvitu !01_A	et	f	\N
108834	huvitud	"huvitu %huvi  )TU2_kA  <huvi ;17_S	et	f	\N
108835	huvitud	huvitud =huvitu  (IndPrSg2  >huvituma !27_V	et	f	\N
108836	sportiga	sportiga =iga  (SgN  >sport+iga !18_S	et	f	\N
108837	sportiga	sportiga =iga  (SgP  >sport+iga !18_S	et	f	\N
108851	difteeria	difteeria =difteeria  (SgN  >difteeria !01_S	et	f	\N
108852	difteeria	difteeria =difteeria  (SgG  >difteeria !01_S	et	f	\N
108863	väikeste	väikeste =väikes  (PlG  >väike !12?10_A	et	f	\N
108864	väikeste	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
108865	väikeste	väikeste =väikes  (PlG  >väikene !12?10_A	et	f	\N
108866	väikeste	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
108867	väikeste	väikeste =keste  (SgN  >väi+keste !06_S	et	f	\N
108868	väikeste	väikeste =keste  (SgG  >väi+keste !06_S	et	f	\N
108869	väikeste	väikeste =keste  (PlP  >väi+kest !22_S	et	f	\N
108880	külmetamine	külmetamine =külmetamine  (SgN  >külmetamine !12_S	et	f	\N
108882	külmetamine	"külmetamine %külmeta  )MINE_vS  <külmetama ;27_V	et	f	\N
108884	rõõmu	rõõmu =rõõmu  (SgG  >rõõm !22_S	et	f	\N
108886	rõõmu	rõõmu =rõõmu  (SgP  >rõõm !22_S	et	f	\N
108888	rõõmu	rõõmu =rõõmu  (SgAdt  >rõõm !22_S	et	f	\N
108895	sobivate	sobivate =sobiva  (PlG  >sobiv !02_A	et	f	\N
108896	sobivate	"sobiv %sobi  )V_vA  <sobima ;27_V	et	f	\N
108898	tellisime	tellisime =telli  (IndIpfPl1  >tellima !28_V	et	f	\N
108901	tellisime	tellisime =ime  (SgN  >tellis+ime !16_S	et	f	\N
108902	tellisime	tellisime =ime  (SgG  >tellis+ime !16_S	et	f	\N
108904	maksis	maksis =maks  (IndIpfSg3  >maksma !32_V	et	f	\N
108905	maksis	maksis =maksi  (SgIn  >maks !22_S	et	f	\N
108918	kõrvallauast	kõrvallauast =ast  (SgN  >kõrval+lau+ast !22_S	et	f	\N
108920	kõrvallauast	kõrvallauast =laua  (SgEl  >kõrval+laud !22_S	et	f	\N
108922	kõrvallauast	kõrvallauast =lauas  (SgP  >kõrval+lauane !10_A	et	f	\N
108924	kõrvallauast	"kõrval+lauane %laua  )NE_aA  <kõrval+laud ;22_S	et	f	\N
108935	rääkinud	rääkinud =rääki  (PtsPtPs  >rääkima !28_V	et	f	\N
108936	rääkinud	rääkinud =rääkinu  (PlN  >rääkinu !01_S	et	f	\N
108937	rääkinud	"rääkinu %rääki  )NU_vS  <rääkima ;28_V	et	f	\N
108938	rääkinud	rääkinud =rääkinud  (ID  >rääkinud !41_A	et	f	\N
108939	rääkinud	"rääkinud %rääki  )NUD_vA  <rääkima ;28_V	et	f	\N
108955	pingsalt	pingsalt =pingsa  (SgAbl  >pingne !02_A	et	f	\N
108956	pingsalt	pingsalt =pingsalt  (ID  >pingsalt !41_D	et	f	\N
108957	pingsalt	"pingsalt %pingsa  )LT_mD  <pingne ;02_A	et	f	\N
108985	siberist	?siberist =siberi  (SgEl  >siberi !01_S	et	f	\N
108986	siberist	?siberist =siberi  (SgEl  >siber !02_S	et	f	\N
108987	siberist	?siberist =siberis  (SgP  >siberis !11_S	et	f	\N
108988	siberist	?siberist =siberist  (SgN  >siberist !22_S	et	f	\N
108919	kostis	kostis =kost  (IndIpfSg3  >kostma !34_V	et	f	\N
108921	kostis	kostis =kosti  (SgIn  >kost !22_S	et	f	\N
108943	trenni	trenni =trenni  (SgG  >trenn !22_S	et	f	\N
108944	trenni	trenni =trenni  (SgP  >trenn !22_S	et	f	\N
108945	trenni	trenni =trenni  (SgAdt  >trenn !22_S	et	f	\N
108951	töötasid	töötasid =tööta  (IndIpfSg2  >töötama !27_V	et	f	\N
108952	töötasid	töötasid =tööta  (IndIpfPl3  >töötama !27_V	et	f	\N
108958	tulemust	tulemust =tulemus  (SgP  >tulemus !11_S	et	f	\N
108959	tulemust	tulemust =must  (SgN  >tule+must !22_AS	et	f	\N
108997	inimese	inimese =inimese  (SgG  >inimene !12_S	et	f	\N
108998	inimese	inimese =ese  (SgN  >inim+ese !04_S	et	f	\N
109022	tagajarje	?tagajarje =jarje  (SgN  >taga+jarje !06_S	et	f	\N
109023	tagajarje	?tagajarje =jarje  (SgG  >taga+jarje !06_S	et	f	\N
109025	varahommikku	?varahommikku =varahommikku  (IndPrPs_  >varahommikkuma !27_V	et	f	\N
109026	varahommikku	?varahommikku =varahommikku  (ImpPrSg2  >varahommikkuma !27_V	et	f	\N
109027	varahommikku	?varahommikku =hommikku  (SgN  >vara+hommikku !01_S	et	f	\N
109028	varahommikku	?varahommikku =hommikku  (SgG  >vara+hommikku !01_S	et	f	\N
109045	kohta	kohta =kohta  (ID  >kohta !41_DK	et	f	\N
109046	kohta	kohta =kohta  (SgP  >koht !22_S	et	f	\N
109047	kohta	kohta =kohta  (SgAdt  >koht !22_S	et	f	\N
109048	kohta	kohta =kohta  (IndPrPs_  >kohtama !29_V	et	f	\N
109049	kohta	kohta =kohta  (ImpPrSg2  >kohtama !29_V	et	f	\N
109050	uest	?uest =ue  (SgEl  >ue !26_S	et	f	\N
109052	uest	?uest =ues  (SgP  >ues !09_S	et	f	\N
109054	uest	?uest =ues  (SgP  >uene !10_A	et	f	\N
109056	uest	?uest =uest  (SgN  >uest !22_S	et	f	\N
109064	valdkonda	valdkonda =valdkonda  (SgP  >valdkond !22_S	et	f	\N
109066	valdkonda	valdkonda =valdkonda  (SgAdt  >valdkond !22_S	et	f	\N
109067	külmetamist	külmetamist =külmetamis  (SgP  >külmetamine !12_S	et	f	\N
109068	külmetamist	"külmetamine %külmeta  )MINE_vS  <külmetama ;27_V	et	f	\N
109071	päikesest	päikesest =päikese  (SgEl  >päike !12?10_S	et	f	\N
109072	päikesest	päikesest =päikese  (SgEl  >päikene !12?10_S	et	f	\N
109073	te	te =te  (PlG  >sa !00_P	et	f	\N
109074	te	te =te  (PlN  >sa !00_P	et	f	\N
109085	tähtmist	?tähtmist =tähtmi  (SgEl  >tähtmi !01_S	et	f	\N
109086	tähtmist	?tähtmist =tähtmi  (SgEl  >tähtm !22_S	et	f	\N
109087	tähtmist	?tähtmist =tähtmis  (SgP  >tähtmis !09_S	et	f	\N
109088	tähtmist	?tähtmist =tähtmis  (SgP  >tähtmine !12?10_A	et	f	\N
109089	tähtmist	?tähtmist =tähtmist  (SgN  >tähtmist !22_S	et	f	\N
109138	ilusaks	ilusaks =ilusa  (SgTr  >ilus !02_A	et	f	\N
109139	ilusaks	ilusaks =saks  (SgN  >ilu+saks !23?22_S	et	f	\N
109150	teises	teises =teise  (SgIn  >teine !12_OP	et	f	\N
109151	teises	teises =teise  (SgIn  >teise !12_P	et	f	\N
109192	seminaritöö	?seminaritöö =seminaritöö  (SgN  >seminaritöö !26_S	et	f	\N
109193	seminaritöö	?seminaritöö =seminaritöö  (SgG  >seminaritöö !26_S	et	f	\N
109194	seminaritöö	?seminaritöö =itöö  (SgN  >seminar+itöö !26_S	et	f	\N
109195	seminaritöö	?seminaritöö =itöö  (SgG  >seminar+itöö !26_S	et	f	\N
109200	kultuuriline	kultuuriline =kultuuriline  (SgN  >kultuuriline !12_A	et	f	\N
109201	kultuuriline	"kultuuriline %kultuuri  )LINE_aA  <kultuur ;22_S	et	f	\N
109202	päris	päris =päri  (PlIn  >pärg !22_S	et	f	\N
109203	päris	päris =päri  (IndIpfSg3  >pärima !27_V	et	f	\N
109205	päris	päris =päris  (ID  >päris !41_DA	et	f	\N
109226	huvitavad	huvitavad =huvita  (IndPrPl3  >huvitama !27_V	et	f	\N
109227	huvitavad	huvitavad =huvitava  (PlN  >huvitav !02_A	et	f	\N
109228	huvitavad	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
109229	huvitavad	huvitavad =tava  (PlN  >huvi+tava !17_S	et	f	\N
109254	elanud	elanud =ela  (PtsPtPs  >elama !27_V	et	f	\N
109257	elanud	elanud =elanu  (PlN  >elanu !01_S	et	f	\N
109258	elanud	"elanu %ela  )NU_vS  <elama ;27_V	et	f	\N
109259	elanud	elanud =elanud  (ID  >elanud !41_A	et	f	\N
109260	elanud	"elanud %ela  )NUD_vA  <elama ;27_V	et	f	\N
109277	kodukohale	kodukohale =koha  (SgAll  >kodu+koha !17_S	et	f	\N
109280	kodukohale	kodukohale =koha  (SgAll  >kodu+koht !22_S	et	f	\N
109289	tallinna	?tallinna =tallinna  (SgN  >tallinna !16_S	et	f	\N
109290	tallinna	?tallinna =tallinna  (SgG  >tallinna !16_S	et	f	\N
109291	tallinna	?tallinna =tallinna  (SgP  >tallinn !22_H	et	f	\N
109292	tallinna	?tallinna =tallinna  (SgAdt  >tallinn !22_H	et	f	\N
109314	hõlmavad	hõlmavad =hõlma  (IndPrPl3  >hõlmama !29_V	et	f	\N
109316	hõlmavad	hõlmavad =hõlmava  (PlN  >hõlmav !02_A	et	f	\N
109318	hõlmavad	"hõlmav %hõlma  )V_vA  <hõlmama ;29_V	et	f	\N
109326	enda	enda =enda  (SgG  >enda !00_P	et	f	\N
109327	enda	enda =enda  (SgG  >ise !00_P	et	f	\N
109364	harkujärve	?harkujärve =harkujärve  (PlP  >harkujärv !22_S	et	f	\N
109365	harkujärve	?harkujärve =ujärve  (PlP  >hark+ujärv !22_S	et	f	\N
109377	liikva	liikva =liikva  (SgN  >liikva !01_S	et	f	\N
109378	liikva	liikva =liikva  (SgG  >liikva !01_S	et	f	\N
109404	jõesuu	jõesuu =suu  (SgN  >jõe+suu !26_S	et	f	\N
109405	jõesuu	jõesuu =suu  (SgG  >jõe+suu !26_S	et	f	\N
108950	alkoholi	alkoholi =alkoholi  (SgAdt  >alkohol !19_S	et	f	\N
108966	maale	maale =maa  (SgAll  >maa !26_S	et	f	\N
108967	maale	maale =maale  (PlP  >maal !22_S	et	f	\N
108971	koputust	koputust =koputus  (SgP  >koputus !11_S	et	f	\N
108972	koputust	"koputus %koputa  )US_vS  <koputama ;27_V	et	f	\N
108995	mahlakasem	?mahlakasem =mahlakasem  (SgN  >mahlakasem !02_A	et	f	\N
108996	mahlakasem	?mahlakasem =kasem  (SgN  >mahla+kasem !02_A	et	f	\N
109017	soovimatuid	soovimatuid =soovimatu  (PlP  >soovimatu !01_A	et	f	\N
109019	soovimatuid	"soovimatu %soovi  )MATU_vA  <soovima ;28_V	et	f	\N
109020	soovimatuid	soovimatuid =imatu  (PlP  >soov+imatu !01_A	et	f	\N
109021	soovimatuid	"soov+imatu %ima  )TU2_kA  <soov+ima ;17_S	et	f	\N
109029	lõunasööki	lõunasööki =sööki  (SgP  >lõuna+söök !22_S	et	f	\N
109030	lõunasööki	lõunasööki =sööki  (SgAdt  >lõuna+söök !22_S	et	f	\N
109036	vanematest	vanematest =vanema  (PlEl  >vanem !02_AS	et	f	\N
109037	vanematest	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
109038	vanematest	vanematest =test  (SgN  >vanema+test !22_S	et	f	\N
109039	vanematest	vanematest =ate  (PlEl  >vanem+att !22_S	et	f	\N
109040	igaühte	igaühte =ühte  (SgG  >iga+ühe !06_S	et	f	\N
109041	igaühte	igaühte =ühte  (SgP  >iga+üks !22_P	et	f	\N
109042	igaühte	igaühte =ühte  (SgAdt  >iga+üks !22_P	et	f	\N
109061	teise	teise =teise  (SgAdt  >teine !12_OP	et	f	\N
109062	teise	teise =teise  (SgAdt  >teise !12_P	et	f	\N
109063	teise	teise =teise  (SgG  >teine !12_OP	et	f	\N
109065	teise	teise =teise  (SgG  >teise !12_P	et	f	\N
109095	tähtsaim	tähtsaim =tähtsaim  (SgN  >tähtsaim !02_A	et	f	\N
109096	tähtsaim	"tähtsaim %tähtsa  )IM_sA  <tähtis ;02_A	et	f	\N
109099	mõnusamalt	mõnusamalt =mõnusama  (SgAbl  >mõnusam !02_A	et	f	\N
109100	mõnusamalt	"mõnusam %mõnusa  )M_cA  <mõnus ;02_A	et	f	\N
109101	mõnusamalt	mõnusamalt =mõnusamalt  (ID  >mõnusamalt !41_D	et	f	\N
109102	mõnusamalt	"mõnusamalt %mõnusa  )MALT_mD  <mõnus ;02_A	et	f	\N
109105	valmistutud	valmistutud =valmistu  (PtsPtIps  >valmistuma !27_V	et	f	\N
109106	valmistutud	valmistutud =valmistutu  (PlN  >valmistutu !01_A	et	f	\N
109107	valmistutud	"valmistutu %valmistu  )TU1_vS  <valmistuma ;27_V	et	f	\N
109108	valmistutud	valmistutud =valmistutud  (ID  >valmistutud !41_A	et	f	\N
109109	valmistutud	"valmistutud %valmistu  )TUD_vA  <valmistuma ;27_V	et	f	\N
109113	sportida	sportida =sporti  (Inf  >sportima !28_V	et	f	\N
109114	sportida	sportida =ida  (SgN  >sport+ida !17_S	et	f	\N
109115	sportida	sportida =ida  (SgG  >sport+ida !17_S	et	f	\N
109116	sportida	sportida =ida  (SgP  >sport+ida !17_S	et	f	\N
109119	vanematele	vanematele =vanema  (PlAll  >vanem !02_AS	et	f	\N
109120	vanematele	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
109121	vanematele	vanematele =ate  (PlAll  >vanem+att !22_S	et	f	\N
109122	nõudetele	?nõudetele =nõude  (PlAll  >nõude !06_S	et	f	\N
109123	nõudetele	?nõudetele =nõudete  (PlAll  >nõudett !22_S	et	f	\N
109124	nõudetele	?nõudetele =nõudetele  (IndPrPs_  >nõudetelema !36_V	et	f	\N
109125	nõudetele	?nõudetele =nõudetele  (ImpPrSg2  >nõudetelema !36_V	et	f	\N
109126	nõudetele	?nõudetele =dete  (PlAll  >nõu+dett !22_S	et	f	\N
109129	kiireid	kiireid =kiire  (PlP  >kiire !01_A	et	f	\N
109130	kiireid	kiireid =kiire  (PlP  >kiire !06_S	et	f	\N
109131	kiireid	kiireid =kiire  (PlP  >kiire !06_AS	et	f	\N
109140	kiireks	kiireks =kiire  (SgTr  >kiire !01_A	et	f	\N
109141	kiireks	kiireks =kiire  (SgTr  >kiire !06_S	et	f	\N
109142	kiireks	kiireks =kiire  (SgTr  >kiire !06_AS	et	f	\N
109143	kiireks	kiireks =kiire  (SgTr  >kiir !13_S	et	f	\N
109144	kiireks	kiireks =kiire  (PlTr  >kiird !22_S	et	f	\N
109145	kiireks	kiireks =kiire  (PlTr  >kiir !22_S	et	f	\N
109152	valdkonnas	valdkonnas =valdkonna  (SgIn  >valdkond !22_S	et	f	\N
109153	valdkonnas	valdkonnas =konna  (SgIn  >vald+konn !22_S	et	f	\N
109176	televisioon	televisioon =televisioon  (SgN  >televisioon !22_S	et	f	\N
109177	televisioon	televisioon =visioon  (SgN  >tele+visioon !22_S	et	f	\N
109182	käi	käi =käi  (SgN  >käi !22_S	et	f	\N
109183	käi	käi =käi  (IndPrPs_  >käima !38_V	et	f	\N
109184	käi	käi =käi  (ImpPrSg2  >käima !38_V	et	f	\N
109187	elades	elades =ela  (Ger  >elama !27_V	et	f	\N
109188	elades	elades =elades  (ID  >elades !41_D	et	f	\N
109197	valla	valla =valla  (ID  >valla !41_D	et	f	\N
109199	valla	valla =valla  (SgG  >vald !22_S	et	f	\N
109208	poolest	poolest =poole  (SgEl  >pool !13_NS	et	f	\N
109209	poolest	poolest =poole  (PlEl  >pool !22_S	et	f	\N
109210	poolest	poolest =pooles  (SgP  >poolene !10_A	et	f	\N
109211	poolest	"poolene %poole  )NE_aA  <pool ;13_NS	et	f	\N
109212	poolest	poolest =poolest  (ID  >poolest !41_DK	et	f	\N
109244	võibolla	?võibolla =võibolla  (SgN  >võibolla !16_S	et	f	\N
109246	võibolla	?võibolla =võibolla  (SgG  >võibolla !16_S	et	f	\N
109249	võibolla	?võibolla =olla  (SgN  >võib+olla !16_S	et	f	\N
109251	võibolla	?võibolla =olla  (SgG  >võib+olla !16_S	et	f	\N
109253	võibolla	?võibolla =bolla  (SgN  >või+bolla !16_S	et	f	\N
109256	võibolla	?võibolla =bolla  (SgG  >või+bolla !16_S	et	f	\N
108954	küll	küll =küll  (SgN  >küll !22_S	et	f	\N
108960	olnud	olnud =ol  (PtsPtPs  >olema !36_V	et	f	\N
108961	olnud	olnud =olnu  (PlN  >olnu !01_S	et	f	\N
108962	olnud	"olnu %ol  )NU_vS  <olema ;36_V	et	f	\N
108963	olnud	olnud =olnu  (PlN  >olnu !06_S	et	f	\N
108964	olnud	olnud =olnud  (ID  >olnud !41_A	et	f	\N
108965	olnud	"olnud %ol  )NUD_vA  <olema ;36_V	et	f	\N
108973	kuulutust	kuulutust =kuulutu  (SgEl  >kuulutu !01_AS	et	f	\N
108974	kuulutust	"kuulutu %kuulu  )TU1_vS  <kuuluma ;27_V	et	f	\N
108975	kuulutust	"kuulutu %kuulu  )TU2_kA  <kuuld ;22_S	et	f	\N
108976	kuulutust	kuulutust =kuulutus  (SgP  >kuulutus !11_S	et	f	\N
108977	kuulutust	"kuulutus %kuuluta  )US_vS  <kuulutama ;27_V	et	f	\N
108978	kuulutust	"kuulutus %kuulu  )TUS1_aS  <kuuluma ;27_V	et	f	\N
108979	kuulutust	"kuulutus %kuulu  )TUS2_aS  <kuuld ;22_S	et	f	\N
108980	kuulutust	kuulutust =tust  (SgN  >kuulu+tust !22_S	et	f	\N
108981	kuulutust	kuulutust =lutu  (SgEl  >kuu+lutu !16_S	et	f	\N
108982	kuulutust	kuulutust =lutu  (SgEl  >kuu+lutt !22_S	et	f	\N
108983	jõudmisel	jõudmisel =jõudmise  (SgAd  >jõudmine !12?10_S	et	f	\N
108984	jõudmisel	"jõudmine %jõud  )MINE_vS  <jõudma ;34_V	et	f	\N
109004	kütmist	kütmist =kütmis  (SgP  >kütmine !12?10_S	et	f	\N
109005	kütmist	"kütmine %küt  )MINE_vS  <kütma ;35_V	et	f	\N
109006	valmistunud	valmistunud =valmistu  (PtsPtPs  >valmistuma !27_V	et	f	\N
109007	valmistunud	valmistunud =valmistunu  (PlN  >valmistunu !01_S	et	f	\N
109008	valmistunud	"valmistunu %valmistu  )NU_vS  <valmistuma ;27_V	et	f	\N
109009	valmistunud	valmistunud =valmistunud  (ID  >valmistunud !41_A	et	f	\N
109010	valmistunud	"valmistunud %valmistu  )NUD_vA  <valmistuma ;27_V	et	f	\N
109011	kaunis	kaunis =kauni  (SgIn  >kaunis !05~07_A	et	f	\N
109012	kaunis	kaunis =kauni  (SgIn  >kaun !22_S	et	f	\N
109013	kaunis	kaunis =kauni  (PlIn  >kaun !22_S	et	f	\N
109014	kaunis	kaunis =kaunis  (ID  >kaunis !41_D	et	f	\N
109015	kaunis	kaunis =kaunis  (SgN  >kaunis !05~07_A	et	f	\N
109033	söömisel	söömisel =söömise  (SgAd  >söömine !12?10_S	et	f	\N
109034	söömisel	"söömine %söö  )MINE_vS  <sööma ;38_V	et	f	\N
109035	söömisel	"söömine %söömi  )NE_aA  <sööm ;22_S	et	f	\N
109051	töökohast	töökohast =koha  (SgEl  >töö+koha !17_S	et	f	\N
109053	töökohast	töökohast =koha  (SgEl  >töö+koht !22_S	et	f	\N
109055	töökohast	töökohast =kohas  (SgP  >töö+kohane !10_A	et	f	\N
109057	töökohast	"töö+kohane %koha  )NE_aA  <töö+koha ;17_S	et	f	\N
109058	töökohast	"töö+kohane %koha  )NE_aA  <töö+koht ;22_S	et	f	\N
109059	vaikesi	vaikesi =esi  (SgN  >vaik+esi !15_S	et	f	\N
109060	vaikesi	vaikesi =esi  (PlP  >vaik+esi !15_S	et	f	\N
109069	suvisest	suvisest =suvise  (SgEl  >suvine !10_A	et	f	\N
109070	suvisest	"suvine %suvi  )NE_aA  <suvi ;20_S	et	f	\N
109080	õpetanud	õpetanud =õpeta  (PtsPtPs  >õpetama !27_V	et	f	\N
109081	õpetanud	õpetanud =õpetanu  (PlN  >õpetanu !01_S	et	f	\N
109082	õpetanud	"õpetanu %õpeta  )NU_vS  <õpetama ;27_V	et	f	\N
109083	õpetanud	õpetanud =õpetanud  (ID  >õpetanud !41_A	et	f	\N
109084	õpetanud	"õpetanud %õpeta  )NUD_vA  <õpetama ;27_V	et	f	\N
109097	salves	salves =salve  (SgIn  >salv !22_S	et	f	\N
109098	salves	salves =salve  (PlIn  >salv !22_S	et	f	\N
109117	puhata	puhata =puha  (Inf  >puhkama !29_V	et	f	\N
109118	puhata	puhata =puha  (IndPrIps_  >puhkama !29_V	et	f	\N
109146	väikesi	väikesi =väikesi  (PlP  >väike !12_A	et	f	\N
109147	väikesi	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
109148	väikesi	väikesi =väikesi  (PlP  >väikene !12_A	et	f	\N
109149	väikesi	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
109154	kahjuks	kahjuks =kahju  (SgTr  >kahju !16~17_S	et	f	\N
109155	kahjuks	kahjuks =kahju  (SgTr  >kahi !24_S	et	f	\N
109156	kahjuks	kahjuks =kahju  (PlTr  >kahi !24_S	et	f	\N
109157	kahjuks	kahjuks =kahjuks  (ID  >kahjuks !41_D	et	f	\N
109162	teemaks	teemaks =teema  (SgTr  >teema !16_S	et	f	\N
109163	teemaks	teemaks =maks  (SgN  >tee+maks !22_S	et	f	\N
109164	sõnu	sõnu =sõnu  (PlP  >sõna !17_S	et	f	\N
109165	sõnu	sõnu =sõnu  (IndPrPs_  >sõnuma !27_V	et	f	\N
109166	sõnu	sõnu =sõnu  (ImpPrSg2  >sõnuma !27_V	et	f	\N
109170	pilgust	pilgust =pilgu  (SgEl  >pilk !22_S	et	f	\N
109171	pilgust	pilgust =pilgu  (PlEl  >pilk !22_S	et	f	\N
109175	internet	### internet	et	f	\N
109196	harku	harku =harku  (IndPrPs_  >harkuma !27_V	et	f	\N
109198	harku	harku =harku  (ImpPrSg2  >harkuma !27_V	et	f	\N
109215	ühekaupa	ühekaupa =kaupa  (ID  >ühe+kaupa !41_D	et	f	\N
109217	ühekaupa	ühekaupa =kaupa  (SgP  >ühe+kaup !22_S	et	f	\N
109218	ühekaupa	ühekaupa =kaupa  (SgAdt  >ühe+kaup !22_S	et	f	\N
109230	näiteks	näiteks =näite  (SgTr  >näide !06_S	et	f	\N
109231	näiteks	näiteks =näiteks  (ID  >näiteks !41_D	et	f	\N
109273	tegelesid	tegelesid =tegele  (IndIpfSg2  >tegelema !31~27_V	et	f	\N
109274	tegelesid	tegelesid =tegele  (IndIpfPl3  >tegelema !31~27_V	et	f	\N
109275	kultuurilisi	kultuurilisi =kultuurilisi  (PlP  >kultuuriline !12_A	et	f	\N
109276	kultuurilisi	"kultuuriline %kultuuri  )LINE_aA  <kultuur ;22_S	et	f	\N
109016	tua	?tua =tua  (SgN  >tua !26_S	et	f	\N
109018	tua	?tua =tua  (SgG  >tua !26_S	et	f	\N
109024	aparat	?aparat =apara  (SgP  >apara !01_S	et	f	\N
109031	valmistamisel	valmistamisel =valmistamise  (SgAd  >valmistamine !12_S	et	f	\N
109032	valmistamisel	"valmistamine %valmista  )MINE_vS  <valmistama ;27_V	et	f	\N
109075	voi	?voi =voi  (SgN  >voi !26_S	et	f	\N
109076	voi	?voi =voi  (SgG  >voi !26_S	et	f	\N
109127	sporti	sporti =sporti  (SgP  >sport !22_S	et	f	\N
109128	sporti	sporti =sporti  (SgAdt  >sport !22_S	et	f	\N
109136	kütmisega	kütmisega =kütmise  (SgKom  >kütmine !12?10_S	et	f	\N
109137	kütmisega	"kütmine %küt  )MINE_vS  <kütma ;35_V	et	f	\N
109158	sissejuhatus	sissejuhatus =juhatu  (SgIn  >sisse+juhatu !01_AS	et	f	\N
109159	sissejuhatus	"sisse+juhatu %juha  )TU2_kA  <sisse+juha ;17_S	et	f	\N
109160	sissejuhatus	sissejuhatus =juhatus  (SgN  >sisse+juhatus !11_S	et	f	\N
109161	sissejuhatus	"sisse+juhatus %juha  )TUS2_aS  <sisse+juha ;17_S	et	f	\N
109167	mis	mis =mis  (SgN  >mis !00_P	et	f	\N
109168	mis	mis =mis  (PlN  >mis !00_P	et	f	\N
109169	mis	mis =mi  (SgIn  >mi !26_S	et	f	\N
109185	ühes	ühes =ühe  (SgIn  >üks !22_NP	et	f	\N
109186	ühes	ühes =ühes  (ID  >ühes !41_DK	et	f	\N
109204	rikkas	?rikkas =rikka  (SgIn  >rikas !07_A	et	f	\N
109206	rikkas	?rikkas =rikka  (IndIpfSg3  >rikkama !29_V	et	f	\N
109207	rikkas	?rikkas =rikkas  (SgN  >rikkas !07_S	et	f	\N
109213	kohti	kohti =kohti  (SgP  >koht !22_S	et	f	\N
109214	kohti	kohti =kohti  (SgAdt  >koht !22_S	et	f	\N
109216	kohti	kohti =kohti  (PlP  >koht !22_S	et	f	\N
109219	tuntud	tuntud =tun  (PtsPtIps  >tundma !34_V	et	f	\N
109220	tuntud	tuntud =tuntu  (PlN  >tuntu !01_S	et	f	\N
109221	tuntud	"tuntu %tun  )TU1_vS  <tundma ;34_V	et	f	\N
109222	tuntud	tuntud =tuntud  (ID  >tuntud !41_A	et	f	\N
109223	tuntud	"tuntud %tun  )TUD_vA  <tundma ;34_V	et	f	\N
109224	nendel	nendel =nen  (PlAd  >see !00_P	et	f	\N
109225	nendel	nendel =nen  (PlAd  >tema !00_P	et	f	\N
109232	rahvajuttude	rahvajuttude =ude  (SgN  >rahva+jutt+ude !04_S	et	f	\N
109233	rahvajuttude	rahvajuttude =juttu  (PlG  >rahva+jutt !22_S	et	f	\N
109238	esinenud	esinenud =esine  (PtsPtPs  >esinema !27_V	et	f	\N
109239	esinenud	esinenud =esinenu  (PlN  >esinenu !01_S	et	f	\N
109240	esinenud	"esinenu %esine  )NU_vS  <esinema ;27_V	et	f	\N
109241	esinenud	esinenud =esinenud  (ID  >esinenud !41_A	et	f	\N
109242	esinenud	"esinenud %esine  )NUD_vA  <esinema ;27_V	et	f	\N
109261	inimesi	inimesi =inimesi  (PlP  >inimene !12_S	et	f	\N
109262	inimesi	inimesi =esi  (SgN  >inim+esi !15_S	et	f	\N
109263	inimesi	inimesi =esi  (PlP  >inim+esi !15_S	et	f	\N
109269	selliseid	selliseid =sellise  (PlP  >selline !10_P	et	f	\N
109270	selliseid	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
109283	nendest	nendest =nen  (PlEl  >see !00_P	et	f	\N
109284	nendest	nendest =nen  (PlEl  >tema !00_P	et	f	\N
109308	kuulusid	kuulusid =kuulu  (IndIpfSg2  >kuuluma !27_V	et	f	\N
109309	kuulusid	kuulusid =kuulu  (IndIpfPl3  >kuuluma !27_V	et	f	\N
109310	kuulusid	kuulusid =kuulusi  (PlN  >kuulus !02_A	et	f	\N
109319	veerandi	veerandi =veerandi  (SgG  >veerand !02_NS	et	f	\N
109320	veerandi	veerandi =andi  (SgP  >veer+and !22_S	et	f	\N
109321	veerandi	veerandi =andi  (SgAdt  >veer+and !22_S	et	f	\N
109332	tallinnale	tallinnale =ale  (SgN  >tallinn+ale !16_S	et	f	\N
109335	tallinnale	tallinnale =ale  (SgG  >tallinn+ale !16_S	et	f	\N
109343	tiskre	?tiskre =tiskre  (SgN  >tiskre !06_S	et	f	\N
109345	tiskre	?tiskre =tiskre  (SgG  >tiskre !06_S	et	f	\N
109347	tiskre	?tiskre =tiskre  (IndPrPs_  >tiskrema !27_V	et	f	\N
109348	tiskre	?tiskre =tiskre  (ImpPrSg2  >tiskrema !27_V	et	f	\N
109371	sõrve	?sõrve =sõrve  (SgN  >sõrve !06_S	et	f	\N
109372	sõrve	?sõrve =sõrve  (SgG  >sõrve !06_S	et	f	\N
109373	sõrve	?sõrve =sõrve  (PlP  >sõrv !22_S	et	f	\N
109374	sõrve	?sõrve =sõrve  (IndPrPs_  >sõrvema !27_V	et	f	\N
109375	sõrve	?sõrve =sõrve  (ImpPrSg2  >sõrvema !27_V	et	f	\N
109376	vaila	?vaila =vaila  (SgN  >vaila !16_S	et	f	\N
109379	vaila	?vaila =vaila  (SgG  >vaila !16_S	et	f	\N
109380	vaila	?vaila =vaila  (IndPrPs_  >vailama !29_V	et	f	\N
109382	vaila	?vaila =vaila  (ImpPrSg2  >vailama !29_V	et	f	\N
109389	kumna	?kumna =kumna  (SgN  >kumna !16_S	et	f	\N
109390	kumna	?kumna =kumna  (SgG  >kumna !16_S	et	f	\N
109391	kumna	?kumna =kumna  (IndPrPs_  >kumnama !29_V	et	f	\N
109392	kumna	?kumna =kumna  (ImpPrSg2  >kumnama !29_V	et	f	\N
109406	viti	?viti =viti  (SgN  >viti !16_S	et	f	\N
109407	viti	?viti =viti  (SgG  >viti !16_S	et	f	\N
109409	viti	?viti =viti  (SgG  >vitt !22_S	et	f	\N
109412	viti	?viti =viti  (IndPrPs_  >vitima !27_V	et	f	\N
109414	viti	?viti =viti  (IndPrPs_  >vittima !28_V	et	f	\N
109415	viti	?viti =viti  (ImpPrSg2  >vitima !27_V	et	f	\N
109418	viti	?viti =viti  (ImpPrSg2  >vittima !28_V	et	f	\N
109433	tegi	tegi =teg  (IndIpfSg3  >tegema !28_V	et	f	\N
109435	tegi	tegi =te  (PlG^  >sa !00_P	et	f	\N
109437	tegi	tegi =te  (PlN^  >sa !00_P	et	f	\N
109451	kevades	kevades =kevade  (SgIn  >kevade !01_S	et	f	\N
109090	alanud	alanud =ala  (PtsPtPs  >algama !29_V	et	f	\N
109091	alanud	alanud =alanu  (PlN  >alanu !01_S	et	f	\N
109092	alanud	"alanu %ala  )NU_vS  <algama ;29_V	et	f	\N
109093	alanud	alanud =alanud  (ID  >alanud !41_A	et	f	\N
109094	alanud	"alanud %ala  )NUD_vA  <algama ;29_V	et	f	\N
109103	jahedamad	jahedamad =jahedama  (PlN  >jahedam !02_A	et	f	\N
109104	jahedamad	"jahedam %jaheda  )M_cA  <jahe ;02_AS	et	f	\N
109110	tekkitav	tekkitav =tekki  (PtsPrIps  >tekkima !27_V	et	f	\N
109111	tekkitav	tekkitav =tekkitav  (SgN  >tekkitav !02_A	et	f	\N
109112	tekkitav	"tekkitav %tekki  )TAV_vAS  <tekkima ;27_V	et	f	\N
109132	peale	peale =pea  (SgAll  >pea !26_S	et	f	\N
109133	peale	peale =peale  (ID  >peale !41_DK	et	f	\N
109134	päikest	päikest =päikes  (SgP  >päike !12?10_S	et	f	\N
109135	päikest	päikest =päikes  (SgP  >päikene !12?10_S	et	f	\N
109172	tänapäevaelus	tänapäevaelus =elu  (SgIn  >täna+päeva+elu !17_S	et	f	\N
109173	tänapäevaelus	tänapäevaelus =elus  (SgN  >täna+päeva+elus !02_A	et	f	\N
109174	tänapäevaelus	tänapäevaelus =aelus  (SgN  >täna+päev+aelus !11~09_S	et	f	\N
109178	loe	loe =loe  (SgN  >loe !06_S	et	f	\N
109179	loe	loe =loe  (SgG  >lood !22_S	et	f	\N
109180	loe	loe =loe  (IndPrPs_  >lugema !28_V	et	f	\N
109181	loe	loe =loe  (ImpPrSg2  >lugema !28_V	et	f	\N
109189	tunne	tunne =tunne  (SgN  >tunne !06_S	et	f	\N
109190	tunne	tunne =tunne  (IndPrPs_  >tundma !34_V	et	f	\N
109191	tunne	tunne =tunne  (ImpPrSg2  >tundma !34_V	et	f	\N
109234	mingite	mingite =mingi  (PlG  >mingi !01_P	et	f	\N
109235	mingite	mingite =mingi  (IndPrPl2  >minkima !28_V	et	f	\N
109236	elukommete	elukommete =me  (PlG  >elu+kom+mesi !15_S	et	f	\N
109237	elukommete	elukommete =komme  (PlG  >elu+komme !06_S	et	f	\N
109243	järgi	järgi =järgi  (ID  >järgi !41_DK	et	f	\N
109245	järgi	järgi =järgi  (SgG  >järk !22_S	et	f	\N
109247	järgi	järgi =järgi  (SgP  >järg !22_S	et	f	\N
109248	järgi	järgi =järgi  (SgAdt  >järg !22_S	et	f	\N
109250	järgi	järgi =järgi  (PlP  >järg !22_S	et	f	\N
109252	järgi	järgi =järgi  (IndPrPs_  >järgima !27_V	et	f	\N
109255	järgi	järgi =järgi  (ImpPrSg2  >järgima !27_V	et	f	\N
109264	unustatud	unustatud =unusta  (PtsPtIps  >unustama !27_V	et	f	\N
109265	unustatud	unustatud =unustatu  (PlN  >unustatu !01_S	et	f	\N
109266	unustatud	"unustatu %unusta  )TU1_vS  <unustama ;27_V	et	f	\N
109267	unustatud	unustatud =unustatud  (ID  >unustatud !41_A	et	f	\N
109268	unustatud	"unustatud %unusta  )TUD_vA  <unustama ;27_V	et	f	\N
109271	elasid	elasid =ela  (IndIpfSg2  >elama !27_V	et	f	\N
109272	elasid	elasid =ela  (IndIpfPl3  >elama !27_V	et	f	\N
109278	tõid	tõid =tõ  (IndIpfSg2  >tooma !38_V	et	f	\N
109279	tõid	tõid =tõ  (IndIpfPl3  >tooma !38_V	et	f	\N
109281	mida	mida =mi  (SgP  >mis !00_P	et	f	\N
109282	mida	mida =mi  (PlP  >mis !00_P	et	f	\N
109298	kuulus	kuulus =kuulu  (SgIn  >kuuld !22_S	et	f	\N
109301	kuulus	kuulus =kuulu  (IndIpfSg3  >kuuluma !27_V	et	f	\N
109302	kuulus	kuulus =kuulus  (SgN  >kuulus !02_A	et	f	\N
109304	kihelkonda	kihelkonda =kihelkonda  (SgP  >kihelkond !22_S	et	f	\N
109305	kihelkonda	kihelkonda =kihelkonda  (SgAdt  >kihelkond !22_S	et	f	\N
109322	maadest	maadest =maa  (PlEl  >maa !26_S	et	f	\N
109323	maadest	maadest =maade  (PlEl  >maat !22_S	et	f	\N
109324	haaras	haaras =haara  (SgIn  >haar !22_S	et	f	\N
109325	haaras	haaras =haara  (IndIpfSg3  >haarama !29_V	et	f	\N
109328	ala	ala =ala  (SgN  >ala !17_S	et	f	\N
109329	ala	ala =ala  (SgG  >ala !17_S	et	f	\N
109330	ala	ala =ala  (SgP  >ala !17_S	et	f	\N
109354	taastati	taastati =taasta  (IndIpfIps  >taastama !27_V	et	f	\N
109355	taastati	taastati =tati  (SgG  >taas+tatt !22_S	et	f	\N
109357	kuuluvad	kuuluvad =kuulu  (IndPrPl3  >kuuluma !27_V	et	f	\N
109359	kuuluvad	kuuluvad =kuuluva  (PlN  >kuuluv !02_A	et	f	\N
109361	kuuluvad	"kuuluv %kuulu  )V_vA  <kuuluma ;27_V	et	f	\N
109381	vääna	vääna =vääna  (IndPrPs_  >väänama !29_V	et	f	\N
109383	vääna	vääna =vääna  (ImpPrSg2  >väänama !29_V	et	f	\N
109387	tutermaa	?tutermaa =tutermaa  (SgN  >tutermaa !26_S	et	f	\N
109388	tutermaa	?tutermaa =tutermaa  (SgG  >tutermaa !26_S	et	f	\N
109402	vääna-	vääna- =vääna  (IndPrPs_  >väänama !29_V	et	f	\N
109403	vääna-	vääna- =vääna  (ImpPrSg2  >väänama !29_V	et	f	\N
109419	ilmandu	?ilmandu =ilmandu  (SgN  >ilmandu !01_S	et	f	\N
109421	ilmandu	?ilmandu =ilmandu  (SgG  >ilmandu !01_S	et	f	\N
109422	ilmandu	?ilmandu =ilmandu  (IndPrPs_  >ilmanduma !27_V	et	f	\N
109424	ilmandu	?ilmandu =ilmandu  (ImpPrSg2  >ilmanduma !27_V	et	f	\N
109448	puhkepaiga	puhkepaiga =pai  (SgKom  >puhke+pai !26_AS	et	f	\N
109450	puhkepaiga	puhkepaiga =paiga  (SgG  >puhke+paik !22_S	et	f	\N
109470	paiknevad	paiknevad =paikne  (IndPrPl3  >paiknema !27_V	et	f	\N
109471	paiknevad	paiknevad =paikneva  (PlN  >paiknev !02_A	et	f	\N
109472	paiknevad	"paiknev %paikne  )V_vA  <paiknema ;27_V	et	f	\N
109475	vana-	vana- =vana  (SgN  >vana !17_AS	et	f	\N
109476	vana-	vana- =vana  (SgG  >vana !17_AS	et	f	\N
109478	vana-	vana- =vana  (SgP  >vana !17_AS	et	f	\N
109285	lääne-	lääne- =lääne  (SgG  >lääs !14_S	et	f	\N
109287	lääne-	lääne- =lääne  (PlP  >lään !22_S	et	f	\N
109293	keila	?keila =keila  (SgN  >keila !16_S	et	f	\N
109295	keila	?keila =keila  (SgG  >keila !16_S	et	f	\N
109296	keila	?keila =keila  (IndPrPs_  >keilama !29_V	et	f	\N
109300	keila	?keila =keila  (ImpPrSg2  >keilama !29_V	et	f	\N
109306	teda	teda =te  (SgP  >ta !00_P	et	f	\N
109307	teda	teda =te  (SgP  >tema !00_P	et	f	\N
109336	antud	antud =an  (PtsPtIps  >andma !34_V	et	f	\N
109339	antud	antud =antu  (PlN  >antu !01_S	et	f	\N
109342	antud	"antu %an  )TU1_vS  <andma ;34_V	et	f	\N
109344	antud	antud =antud  (ID  >antud !41_A	et	f	\N
109346	antud	"antud %an  )TUD_vA  <andma ;34_V	et	f	\N
109356	tabasalu	tabasalu =salu  (SgN  >taba+salu !17_S	et	f	\N
109358	tabasalu	tabasalu =salu  (SgG  >taba+salu !17_S	et	f	\N
109360	tabasalu	tabasalu =salu  (SgP  >taba+salu !17_S	et	f	\N
109366	tiske	?tiske =tiske  (SgN  >tiske !01_A	et	f	\N
109367	tiske	?tiske =tiske  (SgG  >tiske !01_A	et	f	\N
109368	tiske	?tiske =tiske  (PlP  >tisk !22_S	et	f	\N
109369	tiske	?tiske =tiske  (IndPrPs_  >tiskema !27_V	et	f	\N
109370	tiske	?tiske =tiske  (ImpPrSg2  >tiskema !27_V	et	f	\N
109384	vahi	vahi =vahi  (SgG  >vaht !22_S	et	f	\N
109385	vahi	vahi =vahi  (IndPrPs_  >vahtima !28_V	et	f	\N
109386	vahi	vahi =vahi  (ImpPrSg2  >vahtima !28_V	et	f	\N
109397	naage	?naage =naage  (SgN  >naage !06_S	et	f	\N
109399	naage	?naage =naage  (PlP  >naag !22_S	et	f	\N
109400	naage	?naage =naage  (IndPrPs_  >naagema !27_V	et	f	\N
109401	naage	?naage =naage  (ImpPrSg2  >naagema !27_V	et	f	\N
109410	suurupi	?suurupi =suurupi  (SgN  >suurupi !01_S	et	f	\N
109413	suurupi	?suurupi =suurupi  (SgG  >suurupi !01_S	et	f	\N
109416	suurupi	?suurupi =suurupi  (SgG  >suurup !02_S	et	f	\N
109417	suurupi	?suurupi =suurupi  (SgG  >suurupp !22_S	et	f	\N
109420	suurupi	?suurupi =suurupi  (IndPrPs_  >suuruppima !28_V	et	f	\N
109423	suurupi	?suurupi =suurupi  (ImpPrSg2  >suuruppima !28_V	et	f	\N
109425	suurupi	?suurupi =upi  (SgN  >suur+upi !16_S	et	f	\N
109426	suurupi	?suurupi =upi  (SgG  >suur+upi !16_S	et	f	\N
109427	suurupi	?suurupi =upi  (SgG  >suur+upp !22_S	et	f	\N
109428	suurupi	?suurupi =rupi  (SgN  >suu+rupi !16_S	et	f	\N
109429	suurupi	?suurupi =rupi  (SgG  >suu+rupi !16_S	et	f	\N
109430	suurupi	?suurupi =rupi  (SgG  >suu+rupp !22_S	et	f	\N
109458	pea	pea =pea  (IndPrPs_  >pida !40_V	et	f	\N
109460	pea	pea =pea  (ID  >pea !41_D	et	f	\N
109461	pea	pea =pea  (SgN  >pea !26_S	et	f	\N
109462	pea	pea =pea  (SgG  >pea !26_S	et	f	\N
109463	pea	pea =pea  (IndPrPs_  >pidama !28_V	et	f	\N
109464	pea	pea =pea  (ImpPrSg2  >pidama !28_V	et	f	\N
109468	esinduslikumad	esinduslikumad =esinduslikuma  (PlN  >esinduslikum !02_A	et	f	\N
109469	esinduslikumad	"esinduslikum %esindusliku  )M_cA  <esinduslik ;25_A	et	f	\N
109491	laiem	laiem =laiem  (SgN  >laiem !02_A	et	f	\N
109492	laiem	"laiem %laie  )M_cA  <lai ;22_A	et	f	\N
109501	pärinevad	pärinevad =pärine  (IndPrPl3  >pärinema !27_V	et	f	\N
109502	pärinevad	pärinevad =pärineva  (PlN  >pärinev !02_A	et	f	\N
109503	pärinevad	"pärinev %pärine  )V_vA  <pärinema ;27_V	et	f	\N
109525	tile	?tile =tile  (SgN  >tile !16_S	et	f	\N
109526	tile	?tile =tile  (SgG  >tile !16_S	et	f	\N
109527	tile	?tile =tile  (IndPrPs_  >tilema !27_V	et	f	\N
109529	tile	?tile =tile  (ImpPrSg2  >tilema !27_V	et	f	\N
109531	kuningalt	kuningalt =kuninga  (SgAbl  >kuningas !02_S	et	f	\N
109533	kuningalt	kuningalt =alt  (SgN  >kuning+alt !22_S	et	f	\N
109546	kuuluski	kuuluski =uski  (SgG  >kuul+usk !22_S	et	f	\N
109548	kuuluski	kuuluski =uski  (SgP  >kuul+usk !22_S	et	f	\N
109551	kuuluski	kuuluski =uski  (SgAdt  >kuul+usk !22_S	et	f	\N
109552	kuuluski	kuuluski =kuulu  (SgIn^  >kuuld !22_S	et	f	\N
109554	kuuluski	kuuluski =kuulu  (IndIpfSg3^  >kuuluma !27_V	et	f	\N
109556	kuuluski	kuuluski =kuulus  (SgN^  >kuulus !02_A	et	f	\N
109569	teel	teel =tee  (SgAd  >tee !26_S	et	f	\N
109570	teel	teel =teel  (ID  >teel !41_DK	et	f	\N
109573	taubed	?taubed =taube  (IndPrSg2  >taubema !27_V	et	f	\N
109581	sealt	sealt =sea  (SgAbl  >siga !18_SA	et	f	\N
109582	sealt	sealt =sealt  (ID  >sealt !41_D	et	f	\N
109598	pikas	pikas =pika  (SgIn  >pikk !22_S	et	f	\N
109600	pikas	pikas =pika  (SgIn  >pikk !22_AS	et	f	\N
109610	rahvusvaheliselt	rahvusvaheliselt =vahelise  (SgAbl  >rahvus+vaheline !12_A	et	f	\N
109611	rahvusvaheliselt	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
109612	rahvusvaheliselt	"rahvus+vaheliselt %vahe  )LISELT_mD  <rahvus+vahe ;16_S	et	f	\N
109613	rahvusvaheliselt	"rahvus+vaheliselt %vahelise  )LT_mD  <rahvus+vaheline ;12_A	et	f	\N
109619	mitme	mitme =mitme  (SgG  >mitu !05_P	et	f	\N
109621	mitme	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
109646	arendamiseks	arendamiseks =arendamise  (SgTr  >arendamine !12_S	et	f	\N
109648	arendamiseks	"arendamine %arenda  )MINE_vS  <arendama ;27_V	et	f	\N
109653	talle	talle =ta  (SgAll  >ta !00_P	et	f	\N
109655	talle	talle =talle  (SgN  >talle !06_S	et	f	\N
109286	harjumaal	harjumaal =maa  (SgAd  >harju+maa !26_S	et	f	\N
109288	harjumaal	harjumaal =maal  (SgN  >harju+maal !22_S	et	f	\N
109294	vahel	vahel =vahe  (SgAd  >vahe !16_S	et	f	\N
109297	vahel	vahel =vahe  (PlAd  >vahk !22_S	et	f	\N
109299	vahel	vahel =vahe  (PlAd  >vaht !22_S	et	f	\N
109303	vahel	vahel =vahel  (ID  >vahel !41_DK	et	f	\N
109311	saue	saue =saue  (SgG  >sau !22_S	et	f	\N
109312	saue	saue =saue  (SgP  >sau !22_S	et	f	\N
109313	saue	saue =saue  (SgAdt  >sau !22_S	et	f	\N
109315	umbes	umbes =umbe  (SgIn  >umme !06_S	et	f	\N
109317	umbes	umbes =umbes  (ID  >umbes !41_DA	et	f	\N
109331	osa	osa =osa  (SgN  >osa !17_S	et	f	\N
109333	osa	osa =osa  (SgG  >osa !17_S	et	f	\N
109334	osa	osa =osa  (SgP  >osa !17_S	et	f	\N
109337	territooriumist	territooriumist =territooriumi  (SgEl  >territoorium !19~02_S	et	f	\N
109338	territooriumist	territooriumist =territooriumis  (SgP  >territooriumine !10_A	et	f	\N
109340	territooriumist	"territooriumine %territooriumi  )NE_aA  <territoorium ;02_S	et	f	\N
109341	territooriumist	"territooriumine %territooriumi  )NE_aA  <territoorium ;19_S	et	f	\N
109349	pikaliiva	pikaliiva =liiva  (SgG  >pika+liiv !22_S	et	f	\N
109350	pikaliiva	pikaliiva =liiva  (SgP  >pika+liiv !22_S	et	f	\N
109351	pikaliiva	pikaliiva =liiva  (SgAdt  >pika+liiv !22_S	et	f	\N
109352	õigused	õigused =õiguse  (PlN  >õigus !11~09_S	et	f	\N
109353	õigused	"õigus %õige  )US_aS  <õige ;01_A	et	f	\N
109362	alevikud	alevikud =aleviku  (PlN  >alevik !25_S	et	f	\N
109363	alevikud	alevikud =viku  (PlN  >ale+vikk !22_S	et	f	\N
109393	kütke	kütke =küt  (ImpPrPl2  >kütma !35_V	et	f	\N
109394	kütke	kütke =kütke  (SgN  >kütke !06_S	et	f	\N
109395	kütke	kütke =kütke  (SgG  >kütke !06_S	et	f	\N
109396	türisalu	?türisalu =türisalu  (IndPrPs_  >türisaluma !27_V	et	f	\N
109398	türisalu	?türisalu =türisalu  (ImpPrSg2  >türisaluma !27_V	et	f	\N
109431	loodus	loodus =loodu  (SgIn  >loodu !01_S	et	f	\N
109432	loodus	"loodu %loo  )TU1_vS  <looma ;38_V	et	f	\N
109434	loodus	loodus =loodus  (SgN  >loodus !11~09_S	et	f	\N
109436	loodus	"loodus %loo  )TUS1_aS  <looma ;38_V	et	f	\N
109440	elu-	elu- =elu  (SgN  >elu !17_S	et	f	\N
109442	elu-	elu- =elu  (SgG  >elu !17_S	et	f	\N
109444	elu-	elu- =elu  (SgP  >elu !17_S	et	f	\N
109465	rikas	?rikas =rika  (SgIn  >rika !16_S	et	f	\N
109466	rikas	?rikas =rika  (IndIpfSg3  >rikama !27_V	et	f	\N
109467	rikas	?rikas =rikas  (SgN  >rikas !07_A	et	f	\N
109477	pääla	?pääla =pääla  (SgN  >pääla !16_S	et	f	\N
109479	pääla	?pääla =pääla  (SgG  >pääla !16_S	et	f	\N
109480	pääla	?pääla =pääla  (IndPrPs_  >päälama !29_V	et	f	\N
109481	pääla	?pääla =pääla  (ImpPrSg2  >päälama !29_V	et	f	\N
109483	tulevikku	tulevikku =tulevikku  (SgP  >tulevik !25_S	et	f	\N
109485	tulevikku	tulevikku =tulevikku  (SgAdt  >tulevik !25_S	et	f	\N
109486	tulevikku	tulevikku =vikku  (SgP  >tule+vikk !22_S	et	f	\N
109487	tulevikku	tulevikku =vikku  (SgAdt  >tule+vikk !22_S	et	f	\N
109497	audentsed	?audentsed =audentse  (PlN  >audentne !02_A	et	f	\N
109498	audentsed	?audentsed =audentse  (IndPrSg2  >audentsema !27_V	et	f	\N
109499	audentsed	?audentsed =dentse  (PlN  >au+dentne !02_A	et	f	\N
109500	audentsed	?audentsed =dentse  (PlN  >au+dentse !06_S	et	f	\N
109523	bremen	?bremen =breme  (IndPrSg1  >bremema !27_V	et	f	\N
109524	bremen	?bremen =bremen  (SgN  >bremen !02_S	et	f	\N
109532	taani	?taani =taa  (SgTer  >taa !26_S	et	f	\N
109534	taani	?taani =taani  (SgN  >taani !16_S	et	f	\N
109535	taani	?taani =taani  (SgG  >taani !16_S	et	f	\N
109536	taani	?taani =taani  (SgG  >taan !22_S	et	f	\N
109537	taani	?taani =taani  (SgP  >taan !22_S	et	f	\N
109539	taani	?taani =taani  (SgAdt  >taan !22_S	et	f	\N
109541	taani	?taani =taani  (IndPrPs_  >taanima !28_V	et	f	\N
109542	taani	?taani =taani  (ImpPrSg2  >taanima !28_V	et	f	\N
109543	vööne	?vööne =vööne  (SgN  >vööne !06_S	et	f	\N
109544	vööne	?vööne =vööne  (SgG  >vööne !06_S	et	f	\N
109545	vööne	?vööne =vööne  (PlP  >vöön !22_S	et	f	\N
109547	vööne	?vööne =vööne  (IndPrPs_  >vöönema !27_V	et	f	\N
109550	vööne	?vööne =vööne  (ImpPrSg2  >vöönema !27_V	et	f	\N
109565	müümiste	müümiste =müümis  (PlG  >müümine !12?10_S	et	f	\N
109568	müümiste	"müümine %müü  )MINE_vS  <müüma ;38_V	et	f	\N
109572	tiesenhausenid	?tiesenhausenid =tiesenhauseni  (PlN  >tiesenhausen !02_S	et	f	\N
109579	dückerid	?dückerid =dückeri  (PlN  >dückeri !01_S	et	f	\N
109580	dückerid	?dückerid =dückeri  (PlN  >dücker !02_S	et	f	\N
109583	stackelbergide	?stackelbergide =stackelbergi  (PlG  >stackelberg !22_S	et	f	\N
109606	magnus	?magnus =magnu  (SgIn  >magnu !01_S	et	f	\N
109607	magnus	?magnus =magnu  (IndIpfSg3  >magnuma !27_V	et	f	\N
109608	magnus	?magnus =magnus  (SgN  >magnus !11~09_S	et	f	\N
109615	uurija	uurija =uurija  (SgN  >uurija !01_S	et	f	\N
109616	uurija	"uurija %uuri  )JA_vS  <uurima ;28_V	et	f	\N
109617	uurija	uurija =uurija  (SgG  >uurija !01_S	et	f	\N
109651	ema	ema =ema  (SgN  >ema !17_S	et	f	\N
109652	ema	ema =ema  (SgG  >ema !17_S	et	f	\N
109408	muraste	?muraste =muras  (PlG  >muras !09_S	et	f	\N
109411	muraste	?muraste =muras  (PlG  >murane !10_A	et	f	\N
109438	soositud	soositud =soosi  (PtsPtIps  >soosima !28_V	et	f	\N
109439	soositud	soositud =soositu  (PlN  >soositu !01_AS	et	f	\N
109441	soositud	"soositu %soosi  )TU1_vS  <soosima ;28_V	et	f	\N
109443	soositud	"soositu %soosi  )TU2_kA  <soos ;22_S	et	f	\N
109445	soositud	soositud =soositud  (ID  >soositud !41_A	et	f	\N
109446	soositud	"soositud %soosi  )TUD_vA  <soosima ;28_V	et	f	\N
109447	soositud	soositud =situ  (PlN  >soo+situ !16_S	et	f	\N
109449	soositud	"soo+situ %si  )TU2_kA  <soo+si ;26_S	et	f	\N
109455	suvitajatele	suvitajatele =suvitaja  (PlAll  >suvitaja !01_S	et	f	\N
109459	suvitajatele	"suvitaja %suvita  )JA_vS  <suvitama ;27_V	et	f	\N
109482	kultuurikeskuseks	kultuurikeskuseks =use  (PlTr  >kultuuri+kesk+usk !22_S	et	f	\N
109484	kultuurikeskuseks	kultuurikeskuseks =keskuse  (SgTr  >kultuuri+keskus !11~09_S	et	f	\N
109488	kohaks	kohaks =koha  (SgTr  >koha !17_S	et	f	\N
109489	kohaks	kohaks =koha  (SgTr  >koht !22_S	et	f	\N
109490	kohaks	kohaks =koha  (KndPrPs  >kohama !27_V	et	f	\N
109493	tähendus	tähendus =tähendus  (SgN  >tähendus !11_S	et	f	\N
109494	tähendus	"tähendus %tähenda  )US_vS  <tähendama ;27_V	et	f	\N
109504	väänast	?väänast =vääna  (SgEl  >vääna !16_S	et	f	\N
109507	väänast	?väänast =väänas  (SgP  >väänas !07_S	et	f	\N
109509	väänast	?väänast =väänas  (SgP  >väänane !10_A	et	f	\N
109522	hermann	?hermann =hermann  (SgN  >hermann !22_S	et	f	\N
109528	rotkeriga	?rotkeriga =rotkeri  (SgKom  >rotkeri !01_S	et	f	\N
109530	rotkeriga	?rotkeriga =rotkeri  (SgKom  >rotker !02_S	et	f	\N
109553	perekonnale	perekonnale =perekonna  (SgAll  >perekond !22_S	et	f	\N
109555	perekonnale	perekonnale =konna  (SgAll  >pere+konn !22_S	et	f	\N
109561	ostmiste-	ostmiste- =ostmis  (PlG  >ostmine !12?10_S	et	f	\N
109563	ostmiste-	"ostmine %ost  )MINE_vS  <ostma ;34_V	et	f	\N
109584	kätte	kätte =kä  (SgAdt  >käsi !15_S	et	f	\N
109585	kätte	kätte =kätte  (ID  >kätte !41_DK	et	f	\N
109593	strackelberg	?strackelberg =strackelberg  (SgN  >strackelberg !22_S	et	f	\N
109597	stackenbergide	?stackenbergide =stackenbergi  (PlG  >stackenberg !22_S	et	f	\N
109609	stackenberg	?stackenberg =stackenberg  (SgN  >stackenberg !22_S	et	f	\N
109625	liige	liige =liige  (SgN  >liige !05_S	et	f	\N
109626	liige	liige =liige  (PlP  >liig !22_S	et	f	\N
109640	poja	poja =poja  (SgN  >poja !17_S	et	f	\N
109641	poja	poja =poja  (SgG  >poja !17_S	et	f	\N
109642	poja	poja =poja  (SgG  >poeg !22_S	et	f	\N
109643	poja	poja =poja  (SgP  >poja !17_S	et	f	\N
109662	p	### p	et	f	\N
109680	pidi	pidi =pid  (IndIpfSg3  >pida !40_V	et	f	\N
109681	pidi	pidi =pidi  (ID  >pidi !41_K	et	f	\N
109682	pidi	pidi =pidi  (ID  >pidi !41_D	et	f	\N
109686	halle	halle =halle  (SgN  >halle !06_S	et	f	\N
109688	halle	halle =halle  (PlP  >hall !22_S	et	f	\N
109689	halle	halle =halle  (PlP  >hall !22_AS	et	f	\N
109712	itaalias	?itaalias =itaalia  (SgIn  >itaalia !01_S	et	f	\N
109716	itaalias	?itaalias =itaalias  (SgN  >itaalias !11_S	et	f	\N
109720	aasias	?aasias =aasia  (SgIn  >aasia !01_S	et	f	\N
109721	aasias	?aasias =aasias  (SgN  >aasias !11_S	et	f	\N
109722	aja	aja =aja  (SgG  >aeg !22_S	et	f	\N
109723	aja	aja =aja  (IndPrPs_  >ajama !27_V	et	f	\N
109724	aja	aja =aja  (ImpPrSg2  >ajama !27_V	et	f	\N
109746	dückeri	?dückeri =dückeri  (SgN  >dückeri !01_S	et	f	\N
109747	dückeri	?dückeri =dückeri  (SgG  >dückeri !01_S	et	f	\N
109748	dückeri	?dückeri =dückeri  (SgG  >dücker !02_S	et	f	\N
109768	huvitasid	huvitasid =huvita  (IndIpfSg2  >huvitama !27_V	et	f	\N
109770	huvitasid	huvitasid =huvita  (IndIpfPl3  >huvitama !27_V	et	f	\N
109771	maastikumaal	maastikumaal =maa  (SgAd  >maas+tiku+maa !26_S	et	f	\N
109772	maastikumaal	maastikumaal =maal  (SgN  >maas+tiku+maal !22_S	et	f	\N
109776	archeolgico	?archeolgico =archeolgico  (SgN  >archeolgico !16_S	et	f	\N
109777	archeolgico	?archeolgico =archeolgico  (SgG  >archeolgico !16_S	et	f	\N
109792	tähtsamad	tähtsamad =tähtsama  (PlN  >tähtsam !02_A	et	f	\N
109794	tähtsamad	"tähtsam %tähtsa  )M_cA  <tähtis ;02_A	et	f	\N
109798	gebräuche	?gebräuche =gebräuche  (PlP  >gebräuch !22_S	et	f	\N
109807	grece	?grece =grece  (SgN  >grece !06_S	et	f	\N
109808	grece	?grece =grece  (SgG  >grece !06_S	et	f	\N
109811	topographiques	?topographiques =topographique  (SgIn  >topographique !01_S	et	f	\N
109813	topographiques	?topographiques =topographiques  (SgN  >topographiques !22_S	et	f	\N
109832	sees	sees =sees  (ID  >sees !41_DK	et	f	\N
109833	sees	sees =sees  (SgN  >sees !22_S	et	f	\N
109854	de	### de	et	f	\N
109884	ole	ole =ole  (IndPrPs_  >olema !36_V	et	f	\N
109886	ole	ole =ole  (ImpPrSg2  >olema !36_V	et	f	\N
109894	neile	neile =ne  (PlAll  >see !00_P	et	f	\N
109895	neile	neile =ne  (PlAll  >ta !00_P	et	f	\N
109905	lugemata	lugemata =luge  (SupAb  >lugema !28_V	et	f	\N
109907	lugemata	lugemata =lugema  (SgAb  >lugem !02_S	et	f	\N
109909	lugemata	lugemata =lugemata  (ID  >lugemata !41_A	et	f	\N
109452	kevades	kevades =kevade  (SgIn  >kevad !02_S	et	f	\N
109453	tänu	tänu =tänu  (ID  >tänu !41_K	et	f	\N
109454	tänu	tänu =tänu  (SgN  >tänu !17_S	et	f	\N
109456	tänu	tänu =tänu  (SgG  >tänu !17_S	et	f	\N
109457	tänu	tänu =tänu  (SgP  >tänu !17_S	et	f	\N
109473	lucca	?lucca =lucca  (SgN  >lucca !16_S	et	f	\N
109474	lucca	?lucca =lucca  (SgG  >lucca !16_S	et	f	\N
109505	aastast	aastast =aasta  (SgEl  >aasta !01_S	et	f	\N
109506	aastast	aastast =aastas  (SgP  >aastane !12~10_A	et	f	\N
109508	aastast	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
109510	padise	padise =padise  (IndPrPs_  >padisema !27_V	et	f	\N
109511	padise	padise =padise  (ImpPrSg2  >padisema !27_V	et	f	\N
109512	asustatud	asustatud =asusta  (PtsPtIps  >asustama !27_V	et	f	\N
109513	asustatud	asustatud =asustatu  (PlN  >asustatu !01_S	et	f	\N
109514	asustatud	"asustatu %asusta  )TU1_vS  <asustama ;27_V	et	f	\N
109515	asustatud	asustatud =asustatud  (ID  >asustatud !41_A	et	f	\N
109516	asustatud	"asustatud %asusta  )TUD_vA  <asustama ;27_V	et	f	\N
109520	sai	sai =sa  (IndIpfSg3  >saama !37_V	et	f	\N
109521	sai	sai =sai  (SgN  >sai !22_S	et	f	\N
109557	abielumiste	?abielumiste =abielumis  (PlG  >abielumis !09_S	et	f	\N
109558	abielumiste	?abielumiste =abielumis  (PlG  >abielumine !12_S	et	f	\N
109559	abielumiste	?abielumiste =abielumiste  (PlP  >abielumist !22_S	et	f	\N
109560	abielumiste	?abielumiste =elumis  (PlG  >abi+elumis !11_S	et	f	\N
109562	abielumiste	?abielumiste =elumis  (PlG  >abi+elumine !12_S	et	f	\N
109564	abielumiste	?abielumiste =elumiste  (PlP  >abi+elumist !22_S	et	f	\N
109576	maydellid	?maydellid =maydelli  (PlN  >maydelli !01_S	et	f	\N
109577	maydellid	?maydellid =maydelli  (PlN  >maydell !22_S	et	f	\N
109578	maydellid	?maydellid =maydelli  (IndPrSg2  >maydellima !28_V	et	f	\N
109591	otto	?otto =otto  (SgN  >otto !16_S	et	f	\N
109592	otto	?otto =otto  (SgG  >otto !16_S	et	f	\N
109594	kuulasamaid	?kuulasamaid =kuulasama  (PlP  >kuulasam !02_A	et	f	\N
109595	kuulasamaid	?kuulasamaid =kuulasamai  (PlN  >kuulasamai !26_S	et	f	\N
109596	kuulasamaid	?kuulasamaid =kuulasamai  (SgP  >kuulasamai !26_S	et	f	\N
109599	kuulasamaid	?kuulasamaid =asama  (PlP  >kuul+asam !02_A	et	f	\N
109601	kuulasamaid	?kuulasamaid =asamai  (PlN  >kuul+asamai !26_S	et	f	\N
109602	kuulasamaid	?kuulasamaid =asamai  (SgP  >kuul+asamai !26_S	et	f	\N
109603	kuulasamaid	?kuulasamaid =lasama  (PlP  >kuu+lasam !02_A	et	f	\N
109604	kuulasamaid	?kuulasamaid =lasamai  (PlN  >kuu+lasamai !26_S	et	f	\N
109605	kuulasamaid	?kuulasamaid =lasamai  (SgP  >kuu+lasamai !26_S	et	f	\N
109614	antiikajaloo	antiikajaloo =loo  (SgG  >antiik+aja+lugu !18_S	et	f	\N
109618	antiikajaloo	antiikajaloo =loo  (SgG  >antiik+aja+loog !22_S	et	f	\N
109620	antiikajaloo	antiikajaloo =loo  (SgG  >antiik+aja+lood !22_S	et	f	\N
109630	varakult	varakult =varakult  (ID  >varakult !41_D	et	f	\N
109632	varakult	varakult =kult  (SgN  >vara+kult !22_S	et	f	\N
109638	muusika	muusika =muusika  (SgN  >muusika !01_S	et	f	\N
109639	muusika	muusika =muusika  (SgG  >muusika !01_S	et	f	\N
109649	kutsus	kutsus =kutsu  (SgIn  >kutsu !16_S	et	f	\N
109650	kutsus	kutsus =kutsu  (IndIpfSg3  >kutsuma !28_V	et	f	\N
109668	suguvõsa	suguvõsa =võsa  (SgN  >sugu+võsa !17_S	et	f	\N
109670	suguvõsa	suguvõsa =võsa  (SgG  >sugu+võsa !17_S	et	f	\N
109673	suguvõsa	suguvõsa =võsa  (SgP  >sugu+võsa !17_S	et	f	\N
109683	magnusest	?magnusest =magnuse  (SgEl  >magnus !11~09_S	et	f	\N
109684	magnusest	?magnusest =magnuses  (SgP  >magnusene !12_A	et	f	\N
109697	moskva	?moskva =moskva  (ID  >moskva !41_G	et	f	\N
109698	moskva	?moskva =moskva  (IndPrPs_  >moskvama !29_V	et	f	\N
109699	moskva	?moskva =moskva  (ImpPrSg2  >moskvama !29_V	et	f	\N
109715	väike-	väike- =väike  (SgN  >väike !12?10_A	et	f	\N
109719	väike-	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
109725	antiikkunsti	antiikkunsti =kunsti  (SgG  >antiik+kunst !22_S	et	f	\N
109726	antiikkunsti	antiikkunsti =kunsti  (SgP  >antiik+kunst !22_S	et	f	\N
109727	antiikkunsti	antiikkunsti =kunsti  (SgAdt  >antiik+kunst !22_S	et	f	\N
109735	jooksul	jooksul =jooksu  (SgAd  >jooks !22_S	et	f	\N
109736	jooksul	jooksul =jooksul  (ID  >jooksul !41_K	et	f	\N
109745	peter	?peter =peter  (SgN  >peter !02_S	et	f	\N
109759	tema	tema =tema  (SgG  >tema !00_P	et	f	\N
109760	tema	tema =tema  (SgN  >tema !00_P	et	f	\N
109766	kirikuaeda	kirikuaeda =aeda  (SgP  >kiriku+aed !22_S	et	f	\N
109767	kirikuaeda	kirikuaeda =aeda  (SgAdt  >kiriku+aed !22_S	et	f	\N
109775	instutio	?instutio =instutio  (SgN  >instutio !01_S	et	f	\N
109778	instutio	?instutio =instutio  (SgG  >instutio !01_S	et	f	\N
109789	akadeemia	akadeemia =akadeemia  (SgN  >akadeemia !01_S	et	f	\N
109790	akadeemia	akadeemia =akadeemia  (SgG  >akadeemia !01_S	et	f	\N
109801	apollptempel	?apollptempel =apollptempel  (SgN  >apollptempel !02_S	et	f	\N
109802	zu	### zu	et	f	\N
109812	die	?die =die  (SgN  >die !26_S	et	f	\N
109814	die	?die =die  (SgG  >die !26_S	et	f	\N
109819	tragöödia	tragöödia =tragöödia  (SgN  >tragöödia !01_S	et	f	\N
109820	tragöödia	tragöödia =tragöödia  (SgG  >tragöödia !01_S	et	f	\N
109828	isegi	isegi =isegi  (ID  >isegi !41_D	et	f	\N
109495	suurem	suurem =suurem  (SgN  >suurem !02_A	et	f	\N
109496	suurem	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
109517	kloostrimõisast	kloostrimõisast =mõisa  (SgEl  >kloostri+mõis !02_S	et	f	\N
109518	kloostrimõisast	kloostrimõisast =mõisas  (SgP  >kloostri+mõisane !10_A	et	f	\N
109519	kloostrimõisast	"kloostri+mõisane %mõisa  )NE_aA  <kloostri+mõis ;02_S	et	f	\N
109538	kuus	kuus =kuu  (SgIn  >kuu !26_S	et	f	\N
109540	kuus	kuus =kuus  (SgN  >kuus !14_N	et	f	\N
109549	breminite	?breminite =bremini  (PlG  >bremin !02_S	et	f	\N
109566	pärimiste	pärimiste =pärimis  (PlG  >pärimine !12_S	et	f	\N
109567	pärimiste	"pärimine %päri  )MINE_vS  <pärima ;27_V	et	f	\N
109571	von	### von	et	f	\N
109574	frommholdid	?frommholdid =frommholdi  (PlN  >frommholdi !01_S	et	f	\N
109575	frommholdid	?frommholdid =frommholdi  (IndPrSg2  >frommholtima !28_V	et	f	\N
109586	perekonna	perekonna =perekonna  (SgG  >perekond !22_S	et	f	\N
109587	perekonna	perekonna =konna  (SgG  >pere+konn !22_S	et	f	\N
109588	perekonna	perekonna =konna  (SgP  >pere+konn !22_S	et	f	\N
109589	perekonna	perekonna =konna  (SgAdt  >pere+konn !22_S	et	f	\N
109590	strackbergide	### strackbergide	et	f	\N
109622	teadusorganisatsiooni	teadusorganisatsiooni =organisatsiooni  (SgG  >teadus+organisatsioon !22_S	et	f	\N
109623	teadusorganisatsiooni	teadusorganisatsiooni =organisatsiooni  (SgP  >teadus+organisatsioon !22_S	et	f	\N
109624	teadusorganisatsiooni	teadusorganisatsiooni =organisatsiooni  (SgAdt  >teadus+organisatsioon !22_S	et	f	\N
109627	lapsepõlvest	lapsepõlvest =põlve  (SgEl  >lapse+põlv !22_S	et	f	\N
109628	lapsepõlvest	lapsepõlvest =põlve  (SgEl  >lapse+põli !24_S	et	f	\N
109629	lapsepõlvest	lapsepõlvest =põlve  (PlEl  >lapse+põlv !22_S	et	f	\N
109631	lapsepõlvest	lapsepõlvest =põlves  (SgP  >lapse+põlvene !10_A	et	f	\N
109633	lapsepõlvest	"lapse+põlvene %põlve  )NE_aA  <lapse+põlv ;22_S	et	f	\N
109634	lapsepõlvest	"lapse+põlvene %põlve  )NE_aA  <lapse+põli ;24_S	et	f	\N
109635	kunsti	kunsti =kunsti  (SgG  >kunst !22_S	et	f	\N
109636	kunsti	kunsti =kunsti  (SgP  >kunst !22_S	et	f	\N
109637	kunsti	kunsti =kunsti  (SgAdt  >kunst !22_S	et	f	\N
109644	joonistushuvi	joonistushuvi =huvi  (SgN  >joonistus+huvi !17_S	et	f	\N
109645	joonistushuvi	joonistushuvi =huvi  (SgG  >joonistus+huvi !17_S	et	f	\N
109647	joonistushuvi	joonistushuvi =huvi  (SgP  >joonistus+huvi !17_S	et	f	\N
109677	sõjaväelaste	sõjaväelaste =las  (PlG  >sõja+väe+laps !14_S	et	f	\N
109678	sõjaväelaste	sõjaväelaste =laste  (PlP  >sõja+väe+last !22_S	et	f	\N
109679	sõjaväelaste	sõjaväelaste =väelas  (PlG  >sõja+väelane !12?10_S	et	f	\N
109692	göttingeni	?göttingeni =göttingeni  (SgG  >göttingen !19_S	et	f	\N
109694	göttingeni	?göttingeni =göttingeni  (SgP  >göttingen !19_S	et	f	\N
109696	göttingeni	?göttingeni =göttingeni  (SgAdt  >göttingen !19_S	et	f	\N
109700	ülikooli	ülikooli =kooli  (SgG  >üli+kool !22_S	et	f	\N
109701	ülikooli	ülikooli =kooli  (SgP  >üli+kool !22_S	et	f	\N
109702	ülikooli	ülikooli =kooli  (SgAdt  >üli+kool !22_S	et	f	\N
109703	ülikooli	ülikooli =kooli  (PlP  >üli+kool !22_S	et	f	\N
109705	töö-	töö- =töö  (SgN  >töö !26_S	et	f	\N
109707	töö-	töö- =töö  (SgG  >töö !26_S	et	f	\N
109709	konstantinoopolis	?konstantinoopolis =konstantinoopoli  (SgIn  >konstantinoopol !02_S	et	f	\N
109711	konstantinoopolis	?konstantinoopolis =konstantinoopolis  (SgN  >konstantinoopolis !09_S	et	f	\N
109714	konstantinoopolis	?konstantinoopolis =oopoli  (SgIn  >konstantin+oopol !02_S	et	f	\N
109718	konstantinoopolis	?konstantinoopolis =oopolis  (SgN  >konstantin+oopolis !11_S	et	f	\N
109733	alu	alu =alu  (SgG  >alg !22_S	et	f	\N
109734	alu	alu =alu  (PlP  >ala !17_S	et	f	\N
109737	oluliselt	oluliselt =olulise  (SgAbl  >oluline !12_A	et	f	\N
109738	oluliselt	"oluline %olu  )LINE_aA  <olu ;17_S	et	f	\N
109739	oluliselt	oluliselt =oluliselt  (ID  >oluliselt !41_D	et	f	\N
109740	oluliselt	"oluliselt %olu  )LISELT_mD  <olu ;17_S	et	f	\N
109741	oluliselt	"oluliselt %olulise  )LT_mD  <oluline ;12_A	et	f	\N
109749	asutatud	asutatud =asuta  (PtsPtIps  >asutama !27_V	et	f	\N
109750	asutatud	asutatud =asutatu  (PlN  >asutatu !01_S	et	f	\N
109751	asutatud	"asutatu %asuta  )TU1_vS  <asutama ;27_V	et	f	\N
109752	asutatud	asutatud =asutatud  (ID  >asutatud !41_A	et	f	\N
109754	asutatud	"asutatud %asuta  )TUD_vA  <asutama ;27_V	et	f	\N
109761	joonistuste	joonistuste =joonistus  (PlG  >joonistus !11_S	et	f	\N
109762	joonistuste	"joonistus %joonista  )US_vS  <joonistama ;27_V	et	f	\N
109763	joonistuste	joonistuste =tuste  (PlP  >joonis+tust !22_S	et	f	\N
109769	magnuse	?magnuse =magnuse  (SgG  >magnus !11~09_S	et	f	\N
109773	mitmete	mitmete =mitme  (PlG  >mitu !05_P	et	f	\N
109774	mitmete	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
109779	kaasasutaja	kaasasutaja =asutaja  (SgN  >kaas+asutaja !01_S	et	f	\N
109780	kaasasutaja	kaasasutaja =asutaja  (SgG  >kaas+asutaja !01_S	et	f	\N
109815	gräben	?gräben =gräbe  (IndPrSg1  >gräbema !27_V	et	f	\N
109816	gräben	?gräben =gräben  (SgN  >gräben !02_S	et	f	\N
109834	looga	looga =loo  (SgKom  >lugu !18_S	et	f	\N
109835	looga	looga =loo  (SgKom  >loog !22_S	et	f	\N
109836	looga	looga =loo  (SgKom  >lood !22_S	et	f	\N
109837	looga	looga =looga  (SgG  >look !22_S	et	f	\N
109654	ema	ema =ema  (SgP  >ema !17_S	et	f	\N
109660	õpetajaks	õpetajaks =õpetaja  (SgTr  >õpetaja !01_S	et	f	\N
109661	õpetajaks	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
109664	neusi	?neusi =neusi  (SgN  >neusi !16_S	et	f	\N
109665	neusi	?neusi =neusi  (SgG  >neusi !16_S	et	f	\N
109666	neusi	?neusi =neusi  (SgG  >neus !22_S	et	f	\N
109669	neusi	?neusi =neusi  (SgP  >neus !22_S	et	f	\N
109671	neusi	?neusi =neusi  (SgAdt  >neus !22_S	et	f	\N
109672	neusi	?neusi =neusi  (PlP  >neus !22_S	et	f	\N
109674	neusi	?neusi =neusi  (IndPrPs_  >neusima !28_V	et	f	\N
109676	neusi	?neusi =neusi  (ImpPrSg2  >neusima !28_V	et	f	\N
109691	pedagoogiumi	pedagoogiumi =pedagoogiumi  (SgG  >pedagoogium !19~02_S	et	f	\N
109693	pedagoogiumi	pedagoogiumi =pedagoogiumi  (SgP  >pedagoogium !19_S	et	f	\N
109695	pedagoogiumi	pedagoogiumi =pedagoogiumi  (SgAdt  >pedagoogium !19_S	et	f	\N
109708	kreekas	?kreekas =kreeka  (SgIn  >kreekas !02_A	et	f	\N
109710	kreekas	?kreekas =kreeka  (SgIn  >kreeka !16_S	et	f	\N
109713	kreekas	?kreekas =kreeka  (IndIpfSg3  >kreekama !29_V	et	f	\N
109717	kreekas	?kreekas =kreekas  (SgN  >kreekas !02_A	et	f	\N
109791	muinasteduste	?muinasteduste =muinastedus  (PlG  >muinastedus !11?09_S	et	f	\N
109796	trachten	?trachten =trachte  (IndPrSg1  >trachtema !27_V	et	f	\N
109797	trachten	?trachten =trachten  (SgN  >trachten !02_S	et	f	\N
109800	neugriechen	?neugriechen =neugriechen  (SgN  >neugriechen !02_S	et	f	\N
109843	mõjutasid	mõjutasid =mõjuta  (IndIpfSg2  >mõjutama !27_V	et	f	\N
109844	mõjutasid	mõjutasid =mõjuta  (IndIpfPl3  >mõjutama !27_V	et	f	\N
109860	ludwig	### ludwig	et	f	\N
109868	kirjad	kirjad =kirja  (PlN  >kiri !24_S	et	f	\N
109869	kirjad	kirjad =kirja  (IndPrSg2  >kirjama !29_V	et	f	\N
109872	armastajad	armastajad =armastaja  (PlN  >armastaja !01_S	et	f	\N
109873	armastajad	"armastaja %armasta  )JA_vS  <armastama ;27_V	et	f	\N
109882	keelesse	keelesse =keele  (SgIll  >keel !13_S	et	f	\N
109883	keelesse	keelesse =keele  (PlIll  >keeld !22_S	et	f	\N
109899	vastata	vastata =vasta  (Inf  >vastama !29_V	et	f	\N
109900	vastata	vastata =vasta  (IndPrIps_  >vastama !29_V	et	f	\N
109932	henrich	?henrich =henrich  (SgN  >henrich !22_S	et	f	\N
109937	viini	viini =viini  (SgG  >viin !22_S	et	f	\N
109938	viini	viini =viini  (SgP  >viin !22_S	et	f	\N
109939	viini	viini =viini  (SgAdt  >viin !22_S	et	f	\N
109952	seas	seas =sea  (SgIn  >siga !18_SA	et	f	\N
109954	seas	seas =seas  (ID  >seas !41_DK	et	f	\N
109960	unsterbliche	?unsterbliche =unsterbliche  (PlP  >unsterblich !22_S	et	f	\N
109964	surematu	surematu =surematu  (SgN  >surematu !01_A	et	f	\N
109965	surematu	"surematu %sure  )MATU_vA  <surema ;36_V	et	f	\N
109966	surematu	surematu =surematu  (SgG  >surematu !01_A	et	f	\N
109971	armastusest	armastusest =armastuse  (SgEl  >armastus !11_S	et	f	\N
109972	armastusest	"armastus %armasta  )US_vS  <armastama ;27_V	et	f	\N
109973	armastusest	armastusest =armastuses  (SgP  >armastusene !12_A	et	f	\N
109974	armastusest	"armastusene %armastuse  )NE_aA  <armastus ;11_S	et	f	\N
109975	surma	surma =surma  (SgG  >surm !22_S	et	f	\N
109976	surma	surma =surma  (SgP  >surm !22_S	et	f	\N
109977	surma	surma =surma  (SgAdt  >surm !22_S	et	f	\N
109978	surma	surma =surma  (IndPrPs_  >surmama !29_V	et	f	\N
109979	surma	surma =surma  (ImpPrSg2  >surmama !29_V	et	f	\N
109990	mõtisklesid	mõtisklesid =mõtiskle  (IndIpfSg2  >mõtisklema !27_V	et	f	\N
109991	mõtisklesid	mõtisklesid =mõtiskle  (IndIpfPl3  >mõtisklema !27_V	et	f	\N
109998	saa	saa =saa  (IndPrPs_  >saama !37_V	et	f	\N
109999	saa	saa =saa  (ImpPrSg2  >saama !37_V	et	f	\N
110003	armastus	armastus =armastus  (SgN  >armastus !11_S	et	f	\N
110004	armastus	"armastus %armasta  )US_vS  <armastama ;27_V	et	f	\N
110023	ich	?ich =ich  (SgN  >ich !22_S	et	f	\N
110027	armastatu	armastatu =armastatu  (SgN  >armastatu !01_S	et	f	\N
110028	armastatu	"armastatu %armasta  )TU1_vS  <armastama ;27_V	et	f	\N
110029	armastatu	armastatu =armastatu  (SgG  >armastatu !01_S	et	f	\N
110034	geliebten	?geliebten =geliebten  (SgN  >geliebten !02_S	et	f	\N
110038	ewing	?ewing =ewing  (SgN  >ewing !02_S	et	f	\N
110045	mais	mais =ma  (PlIn  >maa !26_S	et	f	\N
110046	mais	mais =mai  (SgIn  >mai !26_S	et	f	\N
110047	mais	mais =mais  (SgN  >mais !22_S	et	f	\N
110049	brunswick	?brunswick =brunswick  (SgN  >brunswick !22_S	et	f	\N
110057	neiud	neiud =neiu  (PlN  >neiu !16_S	et	f	\N
110058	neiud	neiud =neiu  (PlN  >neid !22_S	et	f	\N
110085	variationen	?variationen =variationen  (SgN  >variationen !02_S	et	f	\N
110086	variationen	?variationen =ationen  (SgN  >vari+ationen !02_S	et	f	\N
110103	omaaegseks	omaaegseks =seks  (SgN  >oma+aeg+seks !22_S	et	f	\N
110105	omaaegseks	omaaegseks =aegse  (SgTr  >oma+aegne !02_A	et	f	\N
110132	tausta	tausta =tausta  (SgG  >taust !22_S	et	f	\N
110134	tausta	tausta =tausta  (SgP  >taust !22_S	et	f	\N
110136	tausta	tausta =tausta  (SgAdt  >taust !22_S	et	f	\N
110159	endiselt	endiselt =endise  (SgAbl  >endine !10~12_A	et	f	\N
110161	endiselt	endiselt =endiselt  (ID  >endiselt !41_D	et	f	\N
110164	endiselt	"endiselt %endise  )LT_mD  <endine ;10_A	et	f	\N
109656	talle	talle =talle  (SgG  >tall !22_S	et	f	\N
109657	talle	talle =talle  (SgP  >tall !22_S	et	f	\N
109658	talle	talle =talle  (SgAdt  >tall !22_S	et	f	\N
109659	talle	talle =talle  (PlP  >tall !22_S	et	f	\N
109663	j	### j	et	f	\N
109667	nimekate	nimekate =nimeka  (PlG  >nimekas !02_A	et	f	\N
109675	nimekate	nimekate =kate  (SgN  >nime+kate !06_S	et	f	\N
109685	viisid	viisid =vii  (IndIpfSg2  >viima !38_V	et	f	\N
109687	viisid	viisid =vii  (IndIpfPl3  >viima !38_V	et	f	\N
109690	viisid	viisid =viisi  (PlN  >viis !22_S	et	f	\N
109704	pikkadel	pikkadel =pikka  (PlAd  >pikk !22_S	et	f	\N
109706	pikkadel	pikkadel =pikka  (PlAd  >pikk !22_AS	et	f	\N
109728	illustreeritud	illustreeritud =illustreeri  (PtsPtIps  >illustreerima !28_V	et	f	\N
109729	illustreeritud	illustreeritud =illustreeritu  (PlN  >illustreeritu !01_S	et	f	\N
109730	illustreeritud	"illustreeritu %illustreeri  )TU1_vS  <illustreerima ;28_V	et	f	\N
109731	illustreeritud	illustreeritud =illustreeritud  (ID  >illustreeritud !41_A	et	f	\N
109732	illustreeritud	"illustreeritud %illustreeri  )TUD_vA  <illustreerima ;28_V	et	f	\N
109742	onu	onu =onu  (SgN  >onu !17_S	et	f	\N
109743	onu	onu =onu  (SgG  >onu !17_S	et	f	\N
109744	onu	onu =onu  (SgP  >onu !17_S	et	f	\N
109753	kunstikogusid	kunstikogusid =kogu  (PlP  >kunsti+kogu !17_S	et	f	\N
109755	kunstikogusid	kunstikogusid =kogusi  (PlN  >kunsti+kogus !02_A	et	f	\N
109756	raamatukogu	raamatukogu =kogu  (SgN  >raamatu+kogu !17_S	et	f	\N
109757	raamatukogu	raamatukogu =kogu  (SgG  >raamatu+kogu !17_S	et	f	\N
109758	raamatukogu	raamatukogu =kogu  (SgP  >raamatu+kogu !17_S	et	f	\N
109764	kirikuaeda	kirikuaeda =aeda  (SgP  >kiriku+aed !22_S	et	f	\N
109765	kirikuaeda	kirikuaeda =aeda  (SgAdt  >kiriku+aed !22_S	et	f	\N
109781	berliini	?berliini =berlii  (SgTer  >berlii !26_S	et	f	\N
109782	berliini	?berliini =berliini  (SgN  >berliini !16_S	et	f	\N
109783	berliini	?berliini =berliini  (SgG  >berliini !16_S	et	f	\N
109784	berliini	?berliini =berliini  (SgG  >berliin !22_S	et	f	\N
109785	berliini	?berliini =berliini  (SgP  >berliin !22_S	et	f	\N
109786	berliini	?berliini =berliini  (SgAdt  >berliin !22_S	et	f	\N
109787	berliini	?berliini =berliini  (IndPrPs_  >berliinima !28_V	et	f	\N
109788	berliini	?berliini =berliini  (ImpPrSg2  >berliinima !28_V	et	f	\N
109793	tööd	tööd =töö  (PlN  >töö !26_S	et	f	\N
109795	tööd	tööd =töö  (SgP  >töö !26_S	et	f	\N
109799	der	### der	et	f	\N
109803	bassa	?bassa =bassa  (SgN  >bassa !16_S	et	f	\N
109804	bassa	?bassa =bassa  (SgG  >bassa !16_S	et	f	\N
109805	bassa	?bassa =bassa  (IndPrPs_  >bassama !29_V	et	f	\N
109806	bassa	?bassa =bassa  (ImpPrSg2  >bassama !29_V	et	f	\N
109809	pittoresques	?pittoresques =pittoresque  (SgIn  >pittoresque !01_S	et	f	\N
109810	pittoresques	?pittoresques =pittoresques  (SgN  >pittoresques !22_S	et	f	\N
109817	hellenen	?hellenen =hellene  (IndPrSg1  >hellenema !27_V	et	f	\N
109818	hellenen	?hellenen =hellenen  (SgN  >hellenen !19_S	et	f	\N
109821	seotud	seotud =seo  (PtsPtIps  >siduma !28_V	et	f	\N
109822	seotud	seotud =seotu  (PlN  >seotu !01_A	et	f	\N
109823	seotud	"seotu %seo  )TU1_vS  <siduma ;28_V	et	f	\N
109824	seotud	seotud =seotud  (ID  >seotud !41_A	et	f	\N
109825	seotud	"seotud %seo  )TUD_vA  <siduma ;28_V	et	f	\N
109826	armastuslugu	armastuslugu =lugu  (SgN  >armastus+lugu !18_S	et	f	\N
109827	armastuslugu	armastuslugu =lugu  (SgP  >armastus+lugu !18_S	et	f	\N
109838	käinud	käinud =käi  (PtsPtPs  >käima !38_V	et	f	\N
109839	käinud	käinud =käinu  (PlN  >käinu !01_S	et	f	\N
109840	käinud	"käinu %käi  )NU_vS  <käima ;38_V	et	f	\N
109841	käinud	käinud =käinu  (PlN  >käinu !06_S	et	f	\N
109842	käinud	käinud =käinud  (ID  >käinud !41_A	et	f	\N
109845	käinud	"käinud %käi  )NUD_vA  <käima ;38_V	et	f	\N
109846	elavaid	elavaid =elava  (PlP  >elav !02_A	et	f	\N
109847	elavaid	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
109848	christoph	?christoph =christoph  (SgN  >christoph !22_S	et	f	\N
109850	stackelberg	?stackelberg =stackelberg  (SgN  >stackelberg !22_S	et	f	\N
109853	brunswik	?brunswik =brunswik  (SgN  >brunswik !02_S	et	f	\N
109858	franz	### franz	et	f	\N
109861	van	### van	et	f	\N
109885	tõlgitud	tõlgitud =tõlgi  (PtsPtIps  >tõlkima !28_V	et	f	\N
109887	tõlgitud	tõlgitud =tõlgitu  (PlN  >tõlgitu !01_AS	et	f	\N
109888	tõlgitud	"tõlgitu %tõlgi  )TU1_vS  <tõlkima ;28_V	et	f	\N
109890	tõlgitud	"tõlgitu %tõlgi  )TU2_kA  <tõlk ;22_S	et	f	\N
109892	tõlgitud	tõlgitud =tõlgitud  (ID  >tõlgitud !41_A	et	f	\N
109893	tõlgitud	"tõlgitud %tõlgi  )TUD_vA  <tõlkima ;28_V	et	f	\N
109903	ilma	ilma =ilma  (ID  >ilma !41_DK	et	f	\N
109904	ilma	ilma =ilma  (SgG  >ilm !22_S	et	f	\N
109906	ilma	ilma =ilma  (SgP  >ilm !22_S	et	f	\N
109908	ilma	ilma =ilma  (SgAdt  >ilm !22_S	et	f	\N
109921	kurbust	kurbust =kurbus  (SgP  >kurbus !11~09_S	et	f	\N
109922	kurbust	"kurbus %kurb  )US_aS  <kurb ;22_A	et	f	\N
109923	kurbust	kurbust =us  (SgP  >kurb+uks !14_S	et	f	\N
109995	sellise	sellise =sellise  (SgG  >selline !10_P	et	f	\N
109997	sellise	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
109829	isegi	isegi =ise  (SgN^  >ise !00_P	et	f	\N
109830	isegi	isegi =ise  (PlN^  >ise !00_P	et	f	\N
109831	isegi	isegi =ise  (ID^  >ise !41_DA	et	f	\N
109855	korompa	?korompa =korompa  (SgN  >korompa !01_S	et	f	\N
109856	korompa	?korompa =korompa  (SgG  >korompa !01_S	et	f	\N
109863	loo	loo =loo  (SgG  >lugu !18_S	et	f	\N
109864	loo	loo =loo  (SgG  >loog !22_S	et	f	\N
109865	loo	loo =loo  (SgG  >lood !22_S	et	f	\N
109866	loo	loo =loo  (IndPrPs_  >looma !38_V	et	f	\N
109867	loo	loo =loo  (ImpPrSg2  >looma !38_V	et	f	\N
109874	kirjutatud	kirjutatud =kirjuta  (PtsPtIps  >kirjutama !27_V	et	f	\N
109875	kirjutatud	kirjutatud =kirjutatu  (PlN  >kirjutatu !01_S	et	f	\N
109876	kirjutatud	"kirjutatu %kirjuta  )TU1_vS  <kirjutama ;27_V	et	f	\N
109877	kirjutatud	kirjutatud =kirjutatud  (ID  >kirjutatud !41_A	et	f	\N
109879	kirjutatud	"kirjutatud %kirjuta  )TUD_vA  <kirjutama ;27_V	et	f	\N
109896	küsimustele	küsimustele =küsimus  (PlAll  >küsimus !11_S	et	f	\N
109897	küsimustele	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
109898	küsimustele	küsimustele =muste  (PlAll  >küsi+must !22_AS	et	f	\N
109915	sügavust	sügavust =sügavus  (SgP  >sügavus !11_S	et	f	\N
109917	sügavust	"sügavus %süga  )VUS_aS  <sügama ;27_V	et	f	\N
109918	sügavust	"sügavus %sügava  )US_aS  <sügav ;02_A	et	f	\N
109919	sügavust	sügavust =sügavus  (SgP  >sügavune !12_A	et	f	\N
109920	sügavust	sügavust =us  (SgP  >sügav+uks !14_S	et	f	\N
109924	salapärane	salapärane =pärane  (SgN  >sala+pärane !10_A	et	f	\N
109925	salapärane	"sala+pärane %pära  )NE_aA  <sala+pära ;17_S	et	f	\N
109926	krahvinna	krahvinna =krahvinna  (SgN  >krahvinna !16_S	et	f	\N
109927	krahvinna	krahvinna =krahvinna  (SgG  >krahvinna !16_S	et	f	\N
109934	löwen	?löwen =löwen  (SgN  >löwen !02_S	et	f	\N
109935	müncheni	?müncheni =münche  (SgTer  >münche !06_S	et	f	\N
109936	müncheni	?müncheni =müncheni  (SgG  >münchen !02_S	et	f	\N
109940	beethoveni	?beethoveni =beethoveni  (SgG  >beethoven !19_S	et	f	\N
109941	beethoveni	?beethoveni =beethoveni  (SgP  >beethoven !19_S	et	f	\N
109942	beethoveni	?beethoveni =beethoveni  (SgAdt  >beethoven !19_S	et	f	\N
109943	peetud	peetud =pee  (PtsPtIps  >pidama !28_V	et	f	\N
109944	peetud	peetud =peetu  (PlN  >peetu !01_SA	et	f	\N
109945	peetud	"peetu %pee  )TU1_vS  <pidama ;28_V	et	f	\N
109946	peetud	peetud =peetu  (IndPrSg2  >peetuma !27_V	et	f	\N
109947	peetud	peetud =peetud  (ID  >peetud !41_A	et	f	\N
109949	peetud	"peetud %pee  )TUD_vA  <pidama ;28_V	et	f	\N
109953	bethooveni	?bethooveni =bethoove  (SgTer  >bethoove !16_S	et	f	\N
109955	bethooveni	?bethooveni =bethooveni  (SgG  >bethooven !02_S	et	f	\N
109961	geliebte	?geliebte =geliebte  (PlP  >geliebt !22_S	et	f	\N
109982	ajast	ajast =aja  (SgEl  >aeg !22_S	et	f	\N
109984	ajast	ajast =ajas  (SgP  >ajane !10_A	et	f	\N
109986	ajast	"ajane %aja  )NE_aA  <aeg ;22_S	et	f	\N
110005	kirju	kirju =kirju  (SgN  >kirju !01_A	et	f	\N
110006	kirju	kirju =kirju  (SgN  >kirju !16_A	et	f	\N
110007	kirju	kirju =kirju  (SgG  >kirju !01_A	et	f	\N
110008	kirju	kirju =kirju  (SgG  >kirju !16_A	et	f	\N
110009	kirju	kirju =kirju  (PlP  >kiri !24_S	et	f	\N
110010	tõenäolisena	tõenäolisena =näolise  (SgEs  >tõe+näoline !12?10_A	et	f	\N
110011	tõenäolisena	"tõe+näoline %näo  )LINE_aA  <tõe+nägu ;18_S	et	f	\N
110016	mina	mina =mina  (SgN  >mina !00_P	et	f	\N
110017	mina	mina =mi  (SgEs  >mi !26_S	et	f	\N
110019	mina	mina =mina  (SgN  >mina !17_S	et	f	\N
110021	mina	mina =mina  (SgG  >mina !17_S	et	f	\N
110022	mina	mina =mina  (SgP  >mina !17_S	et	f	\N
110024	lõppes	lõppes =lõpp  (Ger  >lõpma !35_V	et	f	\N
110025	lõppes	lõppes =lõppe  (SgIn  >lõpe !06_S	et	f	\N
110026	lõppes	lõppes =lõppe  (IndIpfSg3  >lõppema !27~28_V	et	f	\N
110033	igavesti	igavesti =igavesti  (ID  >igavesti !41_D	et	f	\N
110035	igavesti	igavesti =vesti  (SgG  >iga+vest !22_S	et	f	\N
110036	igavesti	igavesti =vesti  (SgP  >iga+vest !22_S	et	f	\N
110037	igavesti	igavesti =vesti  (SgAdt  >iga+vest !22_S	et	f	\N
110060	toolajal	?toolajal =toolaja  (SgAd  >toolaja !01_S	et	f	\N
110062	toolajal	?toolajal =toolaja  (SgAd  >toolajas !02_A	et	f	\N
110064	toolajal	?toolajal =toolajal  (SgN  >toolajal !19_S	et	f	\N
110066	toolajal	?toolajal =laja  (SgAd  >too+laja !17_S	et	f	\N
110067	toolajal	?toolajal =lajal  (SgN  >too+lajal !02_S	et	f	\N
110074	deymi	?deymi =deymi  (SgN  >deymi !16_S	et	f	\N
110075	deymi	?deymi =deymi  (SgG  >deymi !16_S	et	f	\N
110076	deymi	?deymi =deymi  (SgG  >deym !22_S	et	f	\N
110077	deymi	?deymi =deymi  (SgP  >deym !22_S	et	f	\N
110078	deymi	?deymi =deymi  (SgAdt  >deym !22_S	et	f	\N
110079	deymi	?deymi =deymi  (IndPrPs_  >deymima !28_V	et	f	\N
110080	deymi	?deymi =deymi  (ImpPrSg2  >deymima !28_V	et	f	\N
110081	deymile	?deymile =deymi  (SgAll  >deymi !16_S	et	f	\N
110082	deymile	?deymile =deymi  (SgAll  >deym !22_S	et	f	\N
110083	deymile	?deymile =deymile  (IndPrPs_  >deymilema !27_V	et	f	\N
110084	deymile	?deymile =deymile  (ImpPrSg2  >deymilema !27_V	et	f	\N
110100	mees	mees =mee  (SgIn  >mesi !15_S	et	f	\N
109849	adam	?adam =adam  (SgN  >adam !02_A	et	f	\N
109851	josephine	?josephine =josephine  (SgN  >josephine !12_A	et	f	\N
109852	josephine	?josephine =josephine  (PlP  >josephin !19_S	et	f	\N
109857	helilooja	helilooja =looja  (SgN  >heli+looja !01_S	et	f	\N
109859	helilooja	helilooja =looja  (SgG  >heli+looja !01_S	et	f	\N
109862	beethoven	?beethoven =beethoven  (SgN  >beethoven !19_S	et	f	\N
109870	kirjutasid	kirjutasid =kirjuta  (IndIpfSg2  >kirjutama !27_V	et	f	\N
109871	kirjutasid	kirjutasid =kirjuta  (IndIpfPl3  >kirjutama !27_V	et	f	\N
109878	inglise-	inglise- =inglise  (ID  >inglise !41_G	et	f	\N
109880	inglise-	inglise- =inglise  (SgG  >ingline !12~10_A	et	f	\N
109881	inglise-	"ingline %ingli  )NE_aA  <ingel ;02_S	et	f	\N
109889	kust	kust =kus  (SgP  >kusi !20_S	et	f	\N
109891	kust	kust =kust  (ID  >kust !41_D	et	f	\N
109901	toon	toon =too  (IndPrSg1  >tooma !38_V	et	f	\N
109902	toon	toon =toon  (SgN  >toon !22_S	et	f	\N
109911	loomu	loomu =loomu  (SgG  >loom !22_S	et	f	\N
109912	loomu	loomu =loomu  (SgP  >loom !22_S	et	f	\N
109913	loomu	loomu =loomu  (SgAdt  >loom !22_S	et	f	\N
109928	aadlisoost	aadlisoost =soo  (SgEl  >aadli+sugu !18_S	et	f	\N
109929	aadlisoost	aadlisoost =soo  (SgEl  >aadli+soo !26_S	et	f	\N
109948	teiste	teiste =teis  (PlG  >teine !12_OP	et	f	\N
109950	teiste	teiste =teis  (PlG  >teise !12_P	et	f	\N
109951	teiste	teiste =teiste  (PlP  >teist !22_S	et	f	\N
109956	surematuks	surematuks =surematu  (SgTr  >surematu !01_A	et	f	\N
109957	surematuks	"surematu %sure  )MATU_vA  <surema ;36_V	et	f	\N
109962	biograafide	biograafide =biograafi  (PlG  >biograaf !22_S	et	f	\N
109963	biograafide	biograafide =graafi  (PlG  >bio+graaf !22_S	et	f	\N
109987	uurisid	uurisid =uuri  (PlP  >uur !22_S	et	f	\N
109988	uurisid	uurisid =uuri  (IndIpfSg2  >uurima !28_V	et	f	\N
109989	uurisid	uurisid =uuri  (IndIpfPl3  >uurima !28_V	et	f	\N
110018	engel	?engel =enge  (PlAd  >enk !22_S	et	f	\N
110020	engel	?engel =engel  (SgN  >engel !02_S	et	f	\N
110043	aasta	aasta =aasta  (SgN  >aasta !01_S	et	f	\N
110044	aasta	aasta =aasta  (SgG  >aasta !01_S	et	f	\N
110053	ungarist	?ungarist =ungari  (SgEl  >ungari !01_S	et	f	\N
110054	ungarist	?ungarist =ungari  (SgEl  >ungar !02_S	et	f	\N
110055	ungarist	?ungarist =ungaris  (SgP  >ungaris !11_S	et	f	\N
110056	ungarist	?ungarist =ungarist  (SgN  >ungarist !22_S	et	f	\N
110068	klaveritunde	klaveritunde =tunde  (SgG  >klaveri+tunne !06_S	et	f	\N
110069	klaveritunde	klaveritunde =tunde  (PlP  >klaveri+tund !22_S	et	f	\N
110073	joseph	?joseph =joseph  (SgN  >joseph !22_S	et	f	\N
110087	über	?über =über  (SgN  >über !02_S	et	f	\N
110117	riietuses	riietuses =riietuse  (SgIn  >riietus !11_S	et	f	\N
110119	riietuses	"riietus %riieta  )US_vS  <riietama ;27_V	et	f	\N
110130	isikute	isikute =isiku  (PlG  >isik !02_S	et	f	\N
110131	isikute	isikute =ute  (SgG  >isik+utt !22_S	et	f	\N
110133	muusikalist	muusikalist =muusikali  (SgEl  >muusikal !19_S	et	f	\N
110135	muusikalist	muusikalist =muusikalis  (SgP  >muusikaline !12_A	et	f	\N
110137	muusikalist	"muusikaline %muusika  )LINE_aA  <muusika ;01_S	et	f	\N
110138	muusikalist	"muusikaline %muusikali  )NE_aA  <muusikal ;19_S	et	f	\N
110168	theresele	?theresele =therese  (SgAll  >therene !10_A	et	f	\N
110169	theresele	?theresele =theresele  (PlP  >theresel !19_S	et	f	\N
110175	charming	?charming =charming  (SgN  >charming !02_S	et	f	\N
110178	elus	elus =elu  (SgIn  >elu !17_S	et	f	\N
110179	elus	elus =elus  (SgN  >elus !02_A	et	f	\N
110184	nimelt	nimelt =nime  (SgAbl  >nimi !20_S	et	f	\N
110185	nimelt	nimelt =nimelt  (ID  >nimelt !41_D	et	f	\N
110191	lootnud	lootnud =loot  (PtsPtPs  >lootma !34_V	et	f	\N
110192	lootnud	lootnud =lootnu  (PlN  >lootnu !01_S	et	f	\N
110193	lootnud	"lootnu %loot  )NU_vS  <lootma ;34_V	et	f	\N
110194	lootnud	lootnud =lootnud  (ID  >lootnud !41_A	et	f	\N
110195	lootnud	"lootnud %loot  )NUD_vA  <lootma ;34_V	et	f	\N
110203	perekonnalt	perekonnalt =perekonna  (SgAbl  >perekond !22_S	et	f	\N
110204	perekonnalt	perekonnalt =konna  (SgAbl  >pere+konn !22_S	et	f	\N
110230	jättes	jättes =jätt  (Ger  >jätma !35_V	et	f	\N
110231	jättes	jättes =jätte  (SgIn  >jäte !06_S	et	f	\N
110280	lessons	?lessons =lessons  (SgN  >lessons !02_S	et	f	\N
110291	some	?some =some  (SgN  >some !16_S	et	f	\N
110292	some	?some =some  (SgG  >some !16_S	et	f	\N
110294	some	?some =some  (IndPrPs_  >somema !27_V	et	f	\N
110296	some	?some =some  (ImpPrSg2  >somema !27_V	et	f	\N
110311	brunswikile	?brunswikile =brunswiki  (SgAll  >brunswiki !01_S	et	f	\N
110312	brunswikile	?brunswikile =brunswiki  (SgAll  >brunswik !02_S	et	f	\N
110313	brunswikile	?brunswikile =brunswikile  (ID  >brunswikile !41_D	et	f	\N
110332	frequently	### frequently	et	f	\N
110337	bit	### bit	et	f	\N
110340	confess	?confess =confess  (SgN  >confess !22_S	et	f	\N
110370	märganud	märganud =märga  (PtsPtPs  >märkama !29_V	et	f	\N
110371	märganud	märganud =märganu  (PlN  >märganu !01_S	et	f	\N
110372	märganud	"märganu %märga  )NU_vS  <märkama ;29_V	et	f	\N
110373	märganud	märganud =märganud  (ID  >märganud !41_A	et	f	\N
109910	lugemata	"lugemata %luge  )MATA_vA  <lugema ;28_V	et	f	\N
109914	armastuse	armastuse =armastuse  (SgG  >armastus !11_S	et	f	\N
109916	armastuse	"armastus %armasta  )US_vS  <armastama ;27_V	et	f	\N
109930	esivanemaks	esivanemaks =vanema  (SgTr  >esi+vanem !02_AS	et	f	\N
109931	esivanemaks	"esi+vanem %vane  )M_cA  <esi+vana ;17_AS	et	f	\N
109933	des	### des	et	f	\N
109958	armastuseks	armastuseks =armastuse  (SgTr  >armastus !11_S	et	f	\N
109959	armastuseks	"armastus %armasta  )US_vS  <armastama ;27_V	et	f	\N
109967	järjest	järjest =järje  (SgEl  >järg !22_S	et	f	\N
109968	järjest	järjest =järjes  (SgP  >järjene !10_A	et	f	\N
109969	järjest	"järjene %järje  )NE_aA  <järg ;22_S	et	f	\N
109970	järjest	järjest =järjest  (ID  >järjest !41_D	et	f	\N
109980	salalaekast	salalaekast =kast  (SgN  >sala+lae+kast !22_S	et	f	\N
109981	salalaekast	salalaekast =laeka  (SgEl  >sala+laegas !07_S	et	f	\N
109983	salalaekast	salalaekast =laekas  (SgP  >sala+laekane !12~10_A	et	f	\N
109985	salalaekast	"sala+laekane %laeka  )NE_aA  <sala+laegas ;07_S	et	f	\N
109992	kellele	kellele =kelle  (SgAll  >kes !00_P	et	f	\N
109993	kellele	kellele =kelle  (PlAll  >kell !22_S	et	f	\N
109994	armastusega	armastusega =armastuse  (SgKom  >armastus !11_S	et	f	\N
109996	armastusega	"armastus %armasta  )US_vS  <armastama ;27_V	et	f	\N
110000	täpselt	täpselt =täpse  (SgAbl  >täpne !02_A	et	f	\N
110001	täpselt	täpselt =täpselt  (ID  >täpselt !41_D	et	f	\N
110002	täpselt	"täpselt %täpse  )LT_mD  <täpne ;02_A	et	f	\N
110030	deines	?deines =deine  (PlIn  >dein !22_S	et	f	\N
110031	deines	?deines =deine  (IndIpfSg3  >deinema !27_V	et	f	\N
110032	deines	?deines =deines  (SgN  >deines !09_S	et	f	\N
110040	unss	?unss =unss  (SgN  >unss !22_S	et	f	\N
110041	tutvustus	tutvustus =tutvustus  (SgN  >tutvustus !11_S	et	f	\N
110042	tutvustus	"tutvustus %tutvusta  )US_vS  <tutvustama ;27_V	et	f	\N
110059	hakkavad	hakkavad =hakka  (IndPrPl3  >hakkama !29_V	et	f	\N
110061	hakkavad	hakkavad =hakkava  (PlN  >hakkav !02_A	et	f	\N
110063	hakkavad	"hakkav %hakka  )V_vA  <hakkama ;29_V	et	f	\N
110065	hakkavad	hakkavad =ava  (PlN  >hakk+ava !17_S	et	f	\N
110070	josephinale	?josephinale =josephinale  (PlP  >josephinal !19_S	et	f	\N
110088	denke	?denke =denke  (SgN  >denke !06_S	et	f	\N
110089	denke	?denke =denke  (SgG  >denge !06_S	et	f	\N
110090	denke	?denke =denke  (PlP  >denk !22_S	et	f	\N
110091	denke	?denke =denke  (IndPrPs_  >denkema !27_V	et	f	\N
110092	denke	?denke =denke  (ImpPrSg2  >denkema !27_V	et	f	\N
110093	muusikapalu	muusikapalu =palu  (SgN  >muusika+palu !17_S	et	f	\N
110094	muusikapalu	muusikapalu =palu  (SgG  >muusika+palu !17_S	et	f	\N
110095	muusikapalu	muusikapalu =palu  (SgP  >muusika+palu !17_S	et	f	\N
110096	muusikapalu	muusikapalu =palu  (PlP  >muusika+pala !17_S	et	f	\N
110097	õrnu	õrnu =õrnu  (PlP  >õrn !22_A	et	f	\N
110098	õrnu	õrnu =õrnu  (IndPrPs_  >õrnuma !27_V	et	f	\N
110099	õrnu	õrnu =õrnu  (ImpPrSg2  >õrnuma !27_V	et	f	\N
110108	laulev	laulev =laul  (PtsPrPs  >laulma !33_V	et	f	\N
110109	laulev	laulev =laulev  (SgN  >laulev !02_A	et	f	\N
110110	laulev	"laulev %laul  )V_vA  <laulma ;33_V	et	f	\N
110115	hispaania	?hispaania =hispaania  (SgN  >hispaania !01_S	et	f	\N
110118	hispaania	?hispaania =hispaania  (SgG  >hispaania !01_S	et	f	\N
110125	ees	ees =ee  (SgIn  >esi !15_S	et	f	\N
110126	ees	ees =ees  (ID  >ees !41_DK	et	f	\N
110139	muusikaautomaadid	muusikaautomaadid =maadi  (PlN  >muusika+auto+maat !22_S	et	f	\N
110140	muusikaautomaadid	muusikaautomaadid =automaadi  (PlN  >muusika+automaat !22_S	et	f	\N
110143	mozarti	?mozarti =mozarti  (SgN  >mozarti !01_S	et	f	\N
110144	mozarti	?mozarti =mozarti  (SgG  >mozarti !01_S	et	f	\N
110145	mozarti	?mozarti =mozarti  (SgP  >mozart !22_S	et	f	\N
110147	mozarti	?mozarti =mozarti  (SgAdt  >mozart !22_S	et	f	\N
110154	läbisaamine	läbisaamine =saamine  (SgN  >läbi+saamine !12?10_S	et	f	\N
110155	läbisaamine	"läbi+saamine %saami  )NE_aA  <läbi+saam ;22_S	et	f	\N
110156	beethovenist	?beethovenist =beethoveni  (SgEl  >beethoven !19_S	et	f	\N
110157	beethovenist	?beethovenist =beethovenis  (SgP  >beethovenis !09_S	et	f	\N
110158	beethovenist	?beethovenist =beethovenist  (SgN  >beethovenist !22_S	et	f	\N
110160	vaimustatud	vaimustatud =vaimusta  (PtsPtIps  >vaimustama !27_V	et	f	\N
110162	vaimustatud	vaimustatud =vaimustatu  (PlN  >vaimustatu !01_S	et	f	\N
110163	vaimustatud	"vaimustatu %vaimusta  )TU1_vS  <vaimustama ;27_V	et	f	\N
110165	vaimustatud	vaimustatud =vaimustatud  (ID  >vaimustatud !41_A	et	f	\N
110167	vaimustatud	"vaimustatud %vaimusta  )TUD_vA  <vaimustama ;27_V	et	f	\N
110216	nõustu	nõustu =nõustu  (IndPrPs_  >nõustuma !27_V	et	f	\N
110217	nõustu	nõustu =nõustu  (ImpPrSg2  >nõustuma !27_V	et	f	\N
110221	deyemi	?deyemi =deyemi  (SgN  >deyemi !01_S	et	f	\N
110223	deyemi	?deyemi =deyemi  (SgG  >deyemi !01_S	et	f	\N
110224	deyemi	?deyemi =deyemi  (SgG  >deyem !02_S	et	f	\N
110225	deyemi	?deyemi =deyemi  (IndPrPs_  >deyemima !28_V	et	f	\N
110226	deyemi	?deyemi =deyemi  (ImpPrSg2  >deyemima !28_V	et	f	\N
110248	rahalised	rahalised =rahalise  (PlN  >rahaline !12_A	et	f	\N
110249	rahalised	"rahaline %raha  )LINE_aA  <raha ;17_S	et	f	\N
110012	olemasolu	olemasolu =olu  (SgN  >olemas+olu !17_S	et	f	\N
110013	olemasolu	olemasolu =olu  (SgG  >olemas+olu !17_S	et	f	\N
110014	olemasolu	olemasolu =olu  (SgP  >olemas+olu !17_S	et	f	\N
110015	mein	?mein =mein  (SgN  >mein !22_S	et	f	\N
110039	dein	?dein =dein  (SgN  >dein !22_S	et	f	\N
110048	anna	anna =anna  (SgN  >anna !16_S	et	f	\N
110050	anna	anna =anna  (SgG  >anna !16_S	et	f	\N
110051	anna	anna =anna  (IndPrPs_  >andma !34_V	et	f	\N
110052	anna	anna =anna  (ImpPrSg2  >andma !34_V	et	f	\N
110071	sobilikku	sobilikku =sobilikku  (SgP  >sobilik !25_A	et	f	\N
110072	sobilikku	sobilikku =sobilikku  (SgAdt  >sobilik !25_A	et	f	\N
110106	keskuses	keskuses =keskuse  (SgIn  >keskus !11~09_S	et	f	\N
110107	keskuses	keskuses =use  (PlIn  >kesk+usk !22_S	et	f	\N
110112	mängivat	mängivat =mängi  (KvtPrPs  >mängima !28_V	et	f	\N
110114	mängivat	mängivat =mängiva  (SgP  >mängiv !02_A	et	f	\N
110116	mängivat	"mängiv %mängi  )V_vA  <mängima ;28_V	et	f	\N
110120	elusuuruses	elusuuruses =use  (PlIn  >elu+suur+usk !22_S	et	f	\N
110121	elusuuruses	elusuuruses =ruse  (PlIn  >elu+suu+rusk !22_S	et	f	\N
110122	elusuuruses	elusuuruses =suuruse  (SgIn  >elu+suurus !11~09_S	et	f	\N
110123	elusuuruses	"elu+suurus %suur  )US_aS  <elu+suur ;13_A	et	f	\N
110124	elusuuruses	elusuuruses =suuruse  (SgIn  >elu+suurune !10~12_A	et	f	\N
110127	istuv	istuv =istu  (PtsPrPs  >istuma !28_V	et	f	\N
110128	istuv	istuv =istuv  (SgN  >istuv !02_A	et	f	\N
110129	istuv	"istuv %istu  )V_vA  <istuma ;28_V	et	f	\N
110141	mängivad	mängivad =mängi  (IndPrPl3  >mängima !28_V	et	f	\N
110142	mängivad	mängivad =mängiva  (PlN  >mängiv !02_A	et	f	\N
110146	mängivad	"mängiv %mängi  )V_vA  <mängima ;28_V	et	f	\N
110148	deyem	?deyem =deyem  (SgN  >deyem !02_S	et	f	\N
110176	vaimustuses	vaimustuses =vaimustuse  (SgIn  >vaimustus !11_S	et	f	\N
110177	vaimustuses	"vaimustus %vaimusta  )US_vS  <vaimustama ;27_V	et	f	\N
110189	põhjas	põhjas =põhja  (SgIn  >põhi !24_S	et	f	\N
110190	põhjas	põhjas =põhja  (IndIpfSg3  >põhjama !29_V	et	f	\N
110197	brunswikide	### brunswikide	et	f	\N
110207	välja	välja =välja  (ID  >välja !41_D	et	f	\N
110209	välja	välja =välja  (SgG  >väli !24_S	et	f	\N
110210	välja	välja =välja  (SgP  >väli !24_S	et	f	\N
110211	välja	välja =välja  (SgAdt  >väli !24_S	et	f	\N
110212	välja	välja =välja  (IndPrPs_  >väljama !29_V	et	f	\N
110213	välja	välja =välja  (ImpPrSg2  >väljama !29_V	et	f	\N
110214	ennast	ennast =ennas  (SgP  >enese !00_P	et	f	\N
110215	ennast	ennast =ennas  (SgP  >ise !00_P	et	f	\N
110227	lohutaja	lohutaja =lohutaja  (SgN  >lohutaja !01_S	et	f	\N
110228	lohutaja	"lohutaja %lohuta  )JA_vS  <lohutama ;27_V	et	f	\N
110229	lohutaja	lohutaja =lohutaja  (SgG  >lohutaja !01_S	et	f	\N
110251	kodus	kodus =kodu  (SgIn  >kodu !17_S	et	f	\N
110252	kodus	kodus =kodus  (ID  >kodus !41_D	et	f	\N
110256	õde	õde =õde  (SgN  >õde !18_S	et	f	\N
110257	õde	õde =õde  (SgP  >õde !18_S	et	f	\N
110260	he	### he	et	f	\N
110262	comes	?comes =come  (SgIn  >come !16_S	et	f	\N
110263	comes	?comes =come  (IndIpfSg3  >comema !27_V	et	f	\N
110265	comes	?comes =comes  (SgN  >comes !09_S	et	f	\N
110268	second	?second =second  (SgN  >second !22_S	et	f	\N
110270	gives	?gives =give  (SgIn  >give !16_S	et	f	\N
110272	gives	?gives =give  (IndIpfSg3  >givema !27_V	et	f	\N
110274	gives	?gives =gives  (SgN  >gives !09_S	et	f	\N
110297	it	### it	et	f	\N
110302	aina	aina =aina  (ID  >aina !41_D	et	f	\N
110303	aina	aina =aina  (SgG  >ain !22_S	et	f	\N
110304	aina	aina =aina  (SgP  >ain !22_S	et	f	\N
110305	aina	aina =aina  (SgAdt  >ain !22_S	et	f	\N
110320	umbest	umbest =umbe  (SgEl  >umme !06_S	et	f	\N
110321	umbest	umbest =umbes  (SgP  >umbene !12~10_A	et	f	\N
110322	umbest	"umbene %umbe  )NE_aA  <umme ;06_S	et	f	\N
110329	quite	?quite =quite  (SgN  >quite !06_S	et	f	\N
110330	quite	?quite =quite  (SgG  >quide !06_S	et	f	\N
110331	quite	?quite =quite  (PlP  >quit !22_S	et	f	\N
110333	quite	?quite =quite  (IndPrPs_  >quitema !27_V	et	f	\N
110334	quite	?quite =quite  (ImpPrSg2  >quitema !27_V	et	f	\N
110336	a	### 230888a	et	f	\N
110358	haste	?haste =haste  (SgN  >haste !06_S	et	f	\N
110359	haste	?haste =haste  (SgG  >haste !06_S	et	f	\N
110360	haste	?haste =haste  (PlP  >hast !22_S	et	f	\N
110361	haste	?haste =haste  (IndPrPs_  >hastema !27_V	et	f	\N
110362	haste	?haste =haste  (ImpPrSg2  >hastema !27_V	et	f	\N
110364	varsi	varsi =vars  (PlP  >vars !14_S	et	f	\N
110365	varsi	varsi =varsi  (SgG  >varss !22_S	et	f	\N
110366	märgavad	märgavad =märga  (IndPrPl3  >märgama !29_V	et	f	\N
110367	märgavad	märgavad =märgava  (PlN  >märgav !02_A	et	f	\N
110368	märgavad	"märgav %märga  )V_vA  <märgama ;29_V	et	f	\N
110383	helolooja	?helolooja =helolooja  (SgN  >helolooja !16_S	et	f	\N
110384	helolooja	?helolooja =helolooja  (SgG  >heloloojas !02_A	et	f	\N
110386	helolooja	?helolooja =helolooja  (SgG  >helolooja !16_S	et	f	\N
110101	mees	mees =mees  (SgN  >mees !13_S	et	f	\N
110102	multimeediakeskuseks	multimeediakeskuseks =use  (PlTr  >multi+meedia+kesk+usk !22_S	et	f	\N
110104	multimeediakeskuseks	multimeediakeskuseks =keskuse  (SgTr  >multi+meedia+keskus !11~09_S	et	f	\N
110111	flööti	flööti =flööti  (SgP  >flööt !22_S	et	f	\N
110113	flööti	flööti =flööti  (SgAdt  >flööt !22_S	et	f	\N
110149	isiklikult	isiklikult =isikliku  (SgAbl  >isiklik !25_A	et	f	\N
110150	isiklikult	isiklikult =isiklikult  (ID  >isiklikult !41_D	et	f	\N
110151	isiklikult	"isiklikult %isikliku  )LT_mD  <isiklik ;25_A	et	f	\N
110152	järel	järel =järe  (PlAd  >järg !22_S	et	f	\N
110153	järel	järel =järel  (ID  >järel !41_DK	et	f	\N
110205	kaasvara	kaasvara =vara  (SgN  >kaas+vara !17_S	et	f	\N
110206	kaasvara	kaasvara =vara  (SgG  >kaas+vara !17_S	et	f	\N
110208	kaasvara	kaasvara =vara  (SgP  >kaas+vara !17_S	et	f	\N
110218	sellel	sellel =selle  (SgAd  >see !00_P	et	f	\N
110219	sellel	sellel =selle  (PlAd  >sell !22_S	et	f	\N
110220	truu	truu =truu  (SgN  >truu !26_A	et	f	\N
110222	truu	truu =truu  (SgG  >truu !26_A	et	f	\N
110232	kolme	kolme =kolme  (SgG  >kolm !22_N	et	f	\N
110235	kolme	kolme =kolme  (SgP  >kolm !22_N	et	f	\N
110236	kolme	kolme =kolme  (SgAdt  >kolm !22_N	et	f	\N
110237	kolme	kolme =kolme  (PlP  >kolm !22_N	et	f	\N
110239	üksi	üksi =üksi  (ID  >üksi !41_D	et	f	\N
110241	üksi	üksi =üksi  (SgG  >üks !22_NP	et	f	\N
110242	üksi	üksi =üksi  (SgP  >üks !22_NP	et	f	\N
110244	üksi	üksi =üksi  (SgAdt  >üks !22_NP	et	f	\N
110246	üksi	üksi =üksi  (PlP  >üks !22_NP	et	f	\N
110258	charlotte	?charlotte =charlotte  (PlP  >charlott !22_S	et	f	\N
110259	brunwick	?brunwick =brunwick  (SgN  >brunwick !22_S	et	f	\N
110264	almost	?almost =almo  (SgEl  >almo !16_S	et	f	\N
110266	almost	?almost =almos  (SgP  >almos !11~09_S	et	f	\N
110271	pepi	?pepi =pepi  (SgN  >pepi !16_S	et	f	\N
110273	pepi	?pepi =pepi  (SgG  >pepi !16_S	et	f	\N
110275	pepi	?pepi =pepi  (SgG  >pepp !22_S	et	f	\N
110276	pepi	?pepi =pepi  (IndPrPs_  >pepima !27_V	et	f	\N
110277	pepi	?pepi =pepi  (IndPrPs_  >peppima !28_V	et	f	\N
110278	pepi	?pepi =pepi  (ImpPrSg2  >pepima !27_V	et	f	\N
110279	pepi	?pepi =pepi  (ImpPrSg2  >peppima !28_V	et	f	\N
110284	you	### you	et	f	\N
110285	composing	?composing =composing  (SgN  >composing !02_S	et	f	\N
110290	us	### us	et	f	\N
110310	nr	### nr	et	f	\N
110323	traagilisus	?traagilisus =traagilisu  (IndIpfSg3  >traagilisuma !27_V	et	f	\N
110324	traagilisus	?traagilisus =traagilisus  (SgN  >traagilisus !11?09_S	et	f	\N
110338	dangerous	?dangerous =dangerou  (SgIn  >dangerou !26_S	et	f	\N
110339	dangerous	?dangerous =dangerous  (SgN  >dangerous !22_S	et	f	\N
110343	pööranud	pööranud =pööra  (PtsPtPs  >pöörama !29_V	et	f	\N
110344	pööranud	pööranud =pööranu  (PlN  >pööranu !01_S	et	f	\N
110345	pööranud	"pööranu %pööra  )NU_vS  <pöörama ;29_V	et	f	\N
110346	pööranud	pööranud =pööranud  (ID  >pööranud !41_A	et	f	\N
110348	pööranud	"pööranud %pööra  )NUD_vA  <pöörama ;29_V	et	f	\N
110357	in	### in	et	f	\N
110375	heaks	heaks =hea  (SgTr  >hea !26_AS	et	f	\N
110376	heaks	heaks =heaks  (ID  >heaks !41_K	et	f	\N
110394	hoffnung	?hoffnung =hoffnung  (SgN  >hoffnung !02_S	et	f	\N
110395	lootuseks	lootuseks =lootuse  (SgTr  >lootus !11~09_S	et	f	\N
110397	lootuseks	"lootus %loo  )TUS2_aS  <lugu ;18_S	et	f	\N
110398	lootuseks	"lootus %loo  )TUS2_aS  <loog ;22_S	et	f	\N
110399	lootuseks	"lootus %loo  )TUS2_aS  <lood ;22_S	et	f	\N
110406	why	### why	et	f	\N
110412	which	?which =which  (SgN  >which !22_S	et	f	\N
110414	express	?express =express  (SgN  >express !22_S	et	f	\N
110420	hapiness	?hapiness =hapiness  (SgN  >hapiness !22_S	et	f	\N
110421	for	### for	et	f	\N
110429	love	love =love  (SgG  >lovi !20_S	et	f	\N
110430	love	love =love  (SgP  >lovi !20_S	et	f	\N
110434	together	?together =together  (SgN  >together !02_S	et	f	\N
110442	to	### to	et	f	\N
110458	many	### many	et	f	\N
110470	weak	?weak =weak  (SgN  >weak !22_S	et	f	\N
110477	lessen	?lessen =lesse  (IndPrSg1  >lessema !27_V	et	f	\N
110478	lessen	?lessen =lessen  (SgN  >lessen !02_S	et	f	\N
110480	heighten	?heighten =heighte  (IndPrSg1  >heightema !27_V	et	f	\N
110481	heighten	?heighten =heighten  (SgN  >heighten !02_S	et	f	\N
110485	felt	?felt =felt  (SgN  >felt !22_S	et	f	\N
110488	iknow	### iknow	et	f	\N
110500	kestab	kestab =kesta  (IndPrSg3  >kestama !29_V	et	f	\N
110502	kestab	kestab =kesta  (IndPrSg3  >kestma !34_V	et	f	\N
110527	süüdistavad	süüdistavad =süüdista  (IndPrPl3  >süüdistama !27_V	et	f	\N
110528	süüdistavad	süüdistavad =süüdistava  (PlN  >süüdistav !02_A	et	f	\N
110530	süüdistavad	"süüdistav %süüdista  )V_vA  <süüdistama ;27_V	et	f	\N
110535	heart	?heart =heart  (SgN  >heart !22_S	et	f	\N
110544	know	### know	et	f	\N
110552	have	?have =have  (SgN  >have !16_S	et	f	\N
110554	have	?have =have  (SgG  >have !16_S	et	f	\N
110166	endiselt	"endiselt %endise  )LT_mD  <endine ;12_A	et	f	\N
110170	kirja	kirja =kirja  (SgG  >kiri !24_S	et	f	\N
110171	kirja	kirja =kirja  (SgP  >kiri !24_S	et	f	\N
110172	kirja	kirja =kirja  (SgAdt  >kiri !24_S	et	f	\N
110173	kirja	kirja =kirja  (IndPrPs_  >kirjama !29_V	et	f	\N
110174	kirja	kirja =kirja  (ImpPrSg2  >kirjama !29_V	et	f	\N
110180	algavad	algavad =alga  (IndPrPl3  >algama !29_V	et	f	\N
110181	algavad	algavad =algava  (PlN  >algav !02_A	et	f	\N
110182	algavad	"algav %alga  )V_vA  <algama ;29_V	et	f	\N
110183	algavad	algavad =ava  (PlN  >alg+ava !17_S	et	f	\N
110186	majanduslikult	majanduslikult =majandusliku  (SgAbl  >majanduslik !25_A	et	f	\N
110187	majanduslikult	majanduslikult =majanduslikult  (ID  >majanduslikult !41_D	et	f	\N
110188	majanduslikult	"majanduslikult %majandusliku  )LT_mD  <majanduslik ;25_A	et	f	\N
110196	saanud	saanud =saa  (PtsPtPs  >saama !37_V	et	f	\N
110198	saanud	saanud =saanu  (PlN  >saanu !01_S	et	f	\N
110199	saanud	"saanu %saa  )NU_vS  <saama ;37_V	et	f	\N
110200	saanud	saanud =saanu  (PlN  >saanu !06_S	et	f	\N
110201	saanud	saanud =saanud  (ID  >saanud !41_A	et	f	\N
110202	saanud	"saanud %saa  )NUD_vA  <saama ;37_V	et	f	\N
110233	lapse	lapse =lapse  (SgG  >laps !14_S	et	f	\N
110234	lapse	lapse =lapse  (PlP  >laps !22_S	et	f	\N
110238	masendatud	masendatud =masenda  (PtsPtIps  >masendama !27_V	et	f	\N
110240	masendatud	masendatud =masendatu  (PlN  >masendatu !01_S	et	f	\N
110243	masendatud	"masendatu %masenda  )TU1_vS  <masendama ;27_V	et	f	\N
110245	masendatud	masendatud =masendatud  (ID  >masendatud !41_A	et	f	\N
110247	masendatud	"masendatud %masenda  )TUD_vA  <masendama ;27_V	et	f	\N
110253	muusikalisi	muusikalisi =muusikalisi  (PlP  >muusikaline !12_A	et	f	\N
110254	muusikalisi	"muusikaline %muusika  )LINE_aA  <muusika ;01_S	et	f	\N
110255	muusikalisi	"muusikaline %muusikali  )NE_aA  <muusikal ;19_S	et	f	\N
110267	every	### every	et	f	\N
110281	always	?always =always  (SgN  >always !22_S	et	f	\N
110283	after	?after =after  (SgN  >after !02_S	et	f	\N
110287	opera	?opera =opera  (SgN  >opera !01_S	et	f	\N
110288	opera	?opera =opera  (SgG  >opera !01_S	et	f	\N
110293	from	### from	et	f	\N
110314	ilmunud	ilmunud =ilmu  (PtsPtPs  >ilmuma !27_V	et	f	\N
110315	ilmunud	ilmunud =ilmunu  (PlN  >ilmunu !01_S	et	f	\N
110316	ilmunud	"ilmunu %ilmu  )NU_vS  <ilmuma ;27_V	et	f	\N
110317	ilmunud	ilmunud =ilmunud  (ID  >ilmunud !41_A	et	f	\N
110318	ilmunud	"ilmunud %ilmu  )NUD_vA  <ilmuma ;27_V	et	f	\N
110335	giving	?giving =giving  (SgN  >giving !02_S	et	f	\N
110341	must	must =mu  (SgEl  >ma !00_P	et	f	\N
110342	must	must =must  (SgN  >must !22_AS	et	f	\N
110347	piisavalt	piisavalt =piisava  (SgAbl  >piisav !02_A	et	f	\N
110349	piisavalt	"piisav %piisa  )V_vA  <piisama ;29_V	et	f	\N
110350	piisavalt	piisavalt =piisavalt  (ID  >piisavalt !41_D	et	f	\N
110352	piisavalt	"piisavalt %piisa  )VALT_mD  <piisama ;29_V	et	f	\N
110354	piisavalt	"piisavalt %piisava  )LT_mD  <piisav ;02_A	et	f	\N
110369	lichnowsky	### lichnowsky	et	f	\N
110379	mõjutavad	mõjutavad =mõjuta  (IndPrPl3  >mõjutama !27_V	et	f	\N
110381	mõjutavad	mõjutavad =mõjutava  (PlN  >mõjutav !02_A	et	f	\N
110382	mõjutavad	"mõjutav %mõju  )TAV_vAS  <mõjuma ;27_V	et	f	\N
110385	mõjutavad	"mõjutav %mõjuta  )V_vA  <mõjutama ;27_V	et	f	\N
110387	mõjutavad	mõjutavad =tava  (PlN  >mõju+tava !17_S	et	f	\N
110390	beethovenile	?beethovenile =beethoveni  (SgAll  >beethoven !19_S	et	f	\N
110415	what	### what	et	f	\N
110417	far	### far	et	f	\N
110418	regard---you	### regard---you	et	f	\N
110428	of	### of	et	f	\N
110432	as	### as	et	f	\N
110435	again	?again =again  (SgN  >again !22_S	et	f	\N
110437	one	?one =one  (SgN  >one !16_S	et	f	\N
110438	one	?one =one  (SgG  >one !16_S	et	f	\N
110439	one	?one =one  (IndPrPs_  >onema !27_V	et	f	\N
110440	one	?one =one  (ImpPrSg2  >onema !27_V	et	f	\N
110454	death	?death =death  (SgN  >death !22_S	et	f	\N
110457	so	### so	et	f	\N
110459	more	?more =more  (SgN  >more !16_S	et	f	\N
110461	more	?more =more  (SgG  >more !16_S	et	f	\N
110462	more	?more =more  (IndPrPs_  >morema !27_V	et	f	\N
110463	more	?more =more  (ImpPrSg2  >morema !27_V	et	f	\N
110467	much	?much =much  (SgN  >much !22_S	et	f	\N
110486	enthusiasm	?enthusiasm =enthusiasm  (SgN  >enthusiasm !22_S	et	f	\N
110487	before	### before	et	f	\N
110494	tundeline	tundeline =tundeline  (SgN  >tundeline !12_A	et	f	\N
110495	tundeline	"tundeline %tunde  )LINE_aA  <tunne ;06_S	et	f	\N
110496	tundeline	"tundeline %tundeli  )NE_aA  <tundel ;02_S	et	f	\N
110503	mitu	mitu =mitu  (SgN  >mitu !05_P	et	f	\N
110504	mitu	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
110509	kohtuvad	kohtuvad =kohtu  (IndPrPl3  >kohtuma !27_V	et	f	\N
110510	kohtuvad	kohtuvad =kohtuva  (PlN  >kohtuv !02_A	et	f	\N
110511	kohtuvad	"kohtuv %kohtu  )V_vA  <kohtuma ;27_V	et	f	\N
110541	certain	?certain =certain  (SgN  >certain !22_S	et	f	\N
110542	do	do =do  (SgN  >do !26_S	et	f	\N
110250	rahalised	"rahaline %raha  )LINE_aA  <rahk ;22_S	et	f	\N
110261	is	### is	et	f	\N
110269	day	### day	et	f	\N
110282	inquires	?inquires =inquire  (PlIn  >inquir !22_S	et	f	\N
110286	an	### an	et	f	\N
110289	played	?played =played  (SgN  >played !02_S	et	f	\N
110295	selections	?selections =selections  (SgN  >selections !22_S	et	f	\N
110298	side	side =si  (PlG  >si !26_S	et	f	\N
110299	side	side =side  (SgN  >side !04_S	et	f	\N
110300	side	side =side  (SgN  >side !16_S	et	f	\N
110301	side	side =side  (SgG  >side !16_S	et	f	\N
110306	klaversonaati	?klaversonaati =klaversonaati  (SgN  >klaversonaati !16_S	et	f	\N
110307	klaversonaati	?klaversonaati =klaversonaati  (SgG  >klaversonaati !16_S	et	f	\N
110308	klaversonaati	?klaversonaati =klaversonaati  (SgP  >klaversonaat !22_S	et	f	\N
110309	klaversonaati	?klaversonaati =klaversonaati  (SgAdt  >klaversonaat !22_S	et	f	\N
110319	therese	?therese =therese  (SgG  >therene !10_A	et	f	\N
110325	tõestuseks	tõestuseks =tõestuse  (SgTr  >tõestus !11~09_S	et	f	\N
110326	tõestuseks	"tõestus %tõesta  )US_vS  <tõestama ;27_V	et	f	\N
110327	theresiale	?theresiale =theresia  (SgAll  >theresia !01_S	et	f	\N
110328	theresiale	?theresiale =theresiale  (PlP  >theresial !19_S	et	f	\N
110351	tähelepanu	tähelepanu =panu  (SgN  >tähele+panu !17_S	et	f	\N
110353	tähelepanu	tähelepanu =panu  (SgG  >tähele+panu !17_S	et	f	\N
110355	tähelepanu	tähelepanu =panu  (SgP  >tähele+panu !17_S	et	f	\N
110356	beethoveniks	?beethoveniks =beethoveni  (SgTr  >beethoven !19_S	et	f	\N
110363	your	?your =your  (SgN  >your !02_S	et	f	\N
110400	aurora	?aurora =aurora  (SgN  >aurora !01_S	et	f	\N
110401	aurora	?aurora =aurora  (SgG  >aurora !01_S	et	f	\N
110403	aurora	?aurora =rora  (SgN  >au+rora !17_S	et	f	\N
110404	aurora	?aurora =rora  (SgG  >au+rora !17_S	et	f	\N
110405	aurora	?aurora =rora  (SgP  >au+rora !17_S	et	f	\N
110411	language	?language =language  (PlP  >languag !22_S	et	f	\N
110413	can	### can	et	f	\N
110427	feeling	?feeling =feeling  (SgN  >feeling !02_S	et	f	\N
110441	disturb	?disturb =disturb  (SgN  >disturb !02_S	et	f	\N
110448	struggle	?struggle =struggle  (SgN  >struggle !06_S	et	f	\N
110449	struggle	?struggle =struggle  (SgG  >struggle !06_S	et	f	\N
110451	struggle	?struggle =struggle  (PlP  >struggl !22_S	et	f	\N
110452	struggle	?struggle =struggle  (IndPrPs_  >strugglema !30_V	et	f	\N
110453	struggle	?struggle =struggle  (ImpPrSg2  >strugglema !30_V	et	f	\N
110456	god	### god	et	f	\N
110460	things	?things =things  (SgN  >things !22_S	et	f	\N
110466	how	### how	et	f	\N
110468	think	?think =think  (SgN  >think !22_S	et	f	\N
110472	words	?words =words  (SgN  >words !22_S	et	f	\N
110479	or	### or	et	f	\N
110483	soul	?soul =sou  (SgAd  >sou !26_S	et	f	\N
110484	soul	?soul =soul  (SgN  >soul !22_S	et	f	\N
110505	aastaid	aastaid =aasta  (PlP  >aasta !01_S	et	f	\N
110506	aastaid	aastaid =tai  (PlN  >aas+tai !26_S	et	f	\N
110507	aastaid	aastaid =tai  (SgP  >aas+tai !26_S	et	f	\N
110508	aastaid	aastaid =taid  (SgN  >aas+taid !22_S	et	f	\N
110515	järsult	järsult =järsu  (SgAbl  >järsk !22_A	et	f	\N
110516	järsult	järsult =järsult  (ID  >järsult !41_D	et	f	\N
110517	järsult	"järsult %järsu  )LT_mD  <järsk ;22_A	et	f	\N
110518	mingi	mingi =mingi  (SgN  >mingi !01_P	et	f	\N
110521	mingi	mingi =mingi  (SgG  >mingi !01_P	et	f	\N
110522	mingi	mingi =mingi  (SgG  >mink !22_S	et	f	\N
110525	mingi	mingi =mingi  (IndPrPs_  >minkima !28_V	et	f	\N
110526	mingi	mingi =mingi  (ImpPrSg2  >minkima !28_V	et	f	\N
110549	moral	?moral =mora  (SgAd  >mora !17_S	et	f	\N
110551	moral	?moral =moral  (SgN  >moral !02_S	et	f	\N
110558	dear	?dear =dear  (SgN  >dear !22_S	et	f	\N
110560	children	?children =childre  (IndPrSg1  >childrema !27_V	et	f	\N
110561	children	?children =children  (SgN  >children !02_S	et	f	\N
110564	will	?will =will  (SgN  >will !22_S	et	f	\N
110566	live	?live =live  (SgN  >live !16_S	et	f	\N
110567	live	?live =live  (SgG  >live !16_S	et	f	\N
110568	live	?live =live  (IndPrPs_  >livema !27_V	et	f	\N
110569	live	?live =live  (ImpPrSg2  >livema !27_V	et	f	\N
110593	disloyality	### disloyality	et	f	\N
110598	pettumus	pettumus =pettumus  (SgN  >pettumus !11_S	et	f	\N
110599	pettumus	"pettumus %pettu  )MUS_vS  <pettuma ;27_V	et	f	\N
110608	only	### only	et	f	\N
110614	pleasure	### pleasure	et	f	\N
110626	had	### had	et	f	\N
110627	be	### be	et	f	\N
110629	yours	?yours =yours  (SgN  >yours !02_S	et	f	\N
110639	letter	?letter =letter  (SgN  >letter !02_S	et	f	\N
110643	third	?third =third  (SgN  >third !22_S	et	f	\N
110654	eest	eest =ee  (SgEl  >esi !15_S	et	f	\N
110655	eest	eest =ees  (SgP  >eene !10_A	et	f	\N
110656	eest	"eene %ee  )NE_aA  <esi ;15_S	et	f	\N
110658	eest	eest =eest  (ID  >eest !41_DK	et	f	\N
110662	beg	### beg	et	f	\N
110664	tõenäoliselt	tõenäoliselt =näolise  (SgAbl  >tõe+näoline !12?10_A	et	f	\N
110374	märganud	"märganud %märga  )NUD_vA  <märkama ;29_V	et	f	\N
110377	positiivselt	positiivselt =positiivse  (SgAbl  >positiivne !02_A	et	f	\N
110378	positiivselt	positiivselt =positiivselt  (ID  >positiivselt !41_D	et	f	\N
110380	positiivselt	"positiivselt %positiivse  )LT_mD  <positiivne ;02_A	et	f	\N
110407	there	?there =there  (SgN  >there !16_S	et	f	\N
110408	there	?there =there  (SgG  >there !16_S	et	f	\N
110409	there	?there =there  (IndPrPs_  >therema !27_V	et	f	\N
110410	there	?there =there  (ImpPrSg2  >therema !27_V	et	f	\N
110416	above	### above	et	f	\N
110419	my	### my	et	f	\N
110443	shall	?shall =shall  (SgN  >shall !22_S	et	f	\N
110445	about	?about =about  (SgN  >about !22_S	et	f	\N
110446	sorrows	?sorrows =sorrows  (SgN  >sorrows !22_S	et	f	\N
110447	myself	?myself =myself  (SgN  >myself !22_S	et	f	\N
110465	tell	?tell =tell  (SgN  >tell !22_S	et	f	\N
110482	feelings	?feelings =feelings  (SgN  >feelings !22_S	et	f	\N
110489	personally	### personally	et	f	\N
110490	lies	?lies =lie  (SgIn  >lie !26_S	et	f	\N
110491	lies	?lies =lies  (SgN  >lies !09_S	et	f	\N
110497	kirjavahetus	kirjavahetus =vahetu  (SgIn  >kirja+vahetu !01_A	et	f	\N
110498	kirjavahetus	"kirja+vahetu %vahe  )TU2_kA  <kirja+vahe ;16_S	et	f	\N
110499	kirjavahetus	kirjavahetus =vahetus  (SgN  >kirja+vahetus !11_S	et	f	\N
110501	kirjavahetus	"kirja+vahetus %vahe  )TUS2_aS  <kirja+vahe ;16_S	et	f	\N
110513	miks	miks =mi  (SgTr  >mi !26_S	et	f	\N
110514	miks	miks =miks  (ID  >miks !41_D	et	f	\N
110519	arusaamatus	arusaamatus =saamatu  (SgIn  >aru+saamatu !01_A	et	f	\N
110520	arusaamatus	"aru+saamatu %saama  )TU2_kA  <aru+saam ;22_S	et	f	\N
110523	arusaamatus	arusaamatus =saamatus  (SgN  >aru+saamatus !11_S	et	f	\N
110524	arusaamatus	"aru+saamatus %saama  )TUS2_aS  <aru+saam ;22_S	et	f	\N
110529	teineteist	teineteist =teis  (SgP  >teine+teise !12_P	et	f	\N
110531	teineteist	teineteist =te  (PlEl  >teine+tee !26_S	et	f	\N
110532	teineteist	teineteist =teist  (SgN  >teine+teist !22_S	et	f	\N
110533	kirjas	kirjas =kirja  (SgIn  >kiri !24_S	et	f	\N
110534	kirjas	kirjas =kirja  (IndIpfSg3  >kirjama !29_V	et	f	\N
110538	not	### not	et	f	\N
110540	accuse	?accuse =accuse  (SgG  >accus !11~09_S	et	f	\N
110545	treat	?treat =treat  (SgN  >treat !22_S	et	f	\N
110557	that	### that	et	f	\N
110562	never	?never =never  (SgN  >never !02_S	et	f	\N
110577	contribute	?contribute =contribu  (PlG  >contribu !01_S	et	f	\N
110578	contribute	?contribute =contribu  (IndPrPl2  >contribuma !27_V	et	f	\N
110590	over	?over =over  (SgN  >over !02_S	et	f	\N
110594	kokkusaamatus	kokkusaamatus =saamatu  (SgIn  >kokku+saamatu !01_A	et	f	\N
110595	kokkusaamatus	"kokku+saamatu %saama  )TU2_kA  <kokku+saam ;22_S	et	f	\N
110596	kokkusaamatus	kokkusaamatus =saamatus  (SgN  >kokku+saamatus !11_S	et	f	\N
110597	kokkusaamatus	"kokku+saamatus %saama  )TUS2_aS  <kokku+saam ;22_S	et	f	\N
110607	few	### few	et	f	\N
110611	given	?given =give  (IndPrSg1  >givema !27_V	et	f	\N
110612	given	?given =given  (SgN  >given !02_S	et	f	\N
110613	great	?great =great  (SgN  >great !22_S	et	f	\N
110615	tomorrow	### tomorrow	et	f	\N
110616	may	### may	et	f	\N
110622	spend	?spend =spend  (SgN  >spend !22_S	et	f	\N
110631	coming	?coming =coming  (SgN  >coming !02_S	et	f	\N
110663	pardon	?pardon =pardon  (SgN  >pardon !02_S	et	f	\N
110671	suaree	suaree =suaree  (SgN  >suaree !26_S	et	f	\N
110672	suaree	suaree =suaree  (SgG  >suaree !26_S	et	f	\N
110678	such	?such =such  (SgN  >such !22_S	et	f	\N
110681	conventional	?conventional =conventional  (SgN  >conventional !02_S	et	f	\N
110685	transgress	?transgress =transgress  (SgN  >transgress !22_S	et	f	\N
110686	transgress	?transgress =gress  (SgN  >trans+gress !22_S	et	f	\N
110688	deem	?deem =deem  (SgN  >deem !22_S	et	f	\N
110714	malady	### malady	et	f	\N
110731	mind	mind =min  (SgP  >ma !00_P	et	f	\N
110732	mind	mind =min  (SgP  >mina !00_P	et	f	\N
110740	läksid	läksid =läk  (IndIpfSg2  >minema !36_V	et	f	\N
110741	läksid	läksid =läk  (IndIpfPl3  >minema !36_V	et	f	\N
110748	õpetaja	õpetaja =õpetaja  (SgN  >õpetaja !01_S	et	f	\N
110749	õpetaja	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
110750	õpetaja	õpetaja =õpetaja  (SgG  >õpetaja !01_S	et	f	\N
110751	seisis	seisis =seis  (IndIpfSg3  >seisma !32_V	et	f	\N
110752	seisis	seisis =seisi  (SgIn  >seis !22_S	et	f	\N
110762	vana	vana =vana  (SgN  >vana !17_AS	et	f	\N
110763	vana	vana =vana  (SgG  >vana !17_AS	et	f	\N
110764	vana	vana =vana  (SgP  >vana !17_AS	et	f	\N
110767	kaotaks	kaotaks =kao  (KndPrIps  >kaduma !28_V	et	f	\N
110768	kaotaks	kaotaks =kaota  (KndPrPs  >kaotama !27_V	et	f	\N
110772	ühiskonnas	ühiskonnas =ühiskonna  (SgIn  >ühiskond !22_S	et	f	\N
110773	ühiskonnas	ühiskonnas =konna  (SgIn  >ühis+konn !22_S	et	f	\N
110782	elus-	elus- =elu  (SgIn  >elu !17_S	et	f	\N
110783	elus-	elus- =elus  (SgN  >elus !02_A	et	f	\N
110786	lastele	lastele =las  (PlAll  >laps !14_S	et	f	\N
110787	lastele	lastele =laste  (PlAll  >last !22_S	et	f	\N
110388	muusa	muusa =muusa  (SgN  >muusa !16_S	et	f	\N
110389	muusa	muusa =muusa  (SgG  >muusa !16_S	et	f	\N
110391	laulu	laulu =laulu  (SgG  >laul !22_S	et	f	\N
110392	laulu	laulu =laulu  (SgP  >laul !22_S	et	f	\N
110393	laulu	laulu =laulu  (SgAdt  >laul !22_S	et	f	\N
110396	op	### op	et	f	\N
110402	op53	### op53	et	f	\N
110422	time	?time =time  (SgN  >time !16_S	et	f	\N
110423	time	?time =time  (SgG  >time !16_S	et	f	\N
110424	time	?time =time  (IndPrPs_  >timema !27_V	et	f	\N
110425	time	?time =time  (ImpPrSg2  >timema !27_V	et	f	\N
110426	the	### the	et	f	\N
110431	adored	### adored	et	f	\N
110433	we	### we	et	f	\N
110436	with	?with =with  (SgN  >with !22_S	et	f	\N
110444	hear	?hear =hear  (SgN  >hear !22_S	et	f	\N
110450	between	?between =between  (SgN  >between !22_S	et	f	\N
110455	life	?life =life  (SgN  >life !06_S	et	f	\N
110464	should	?should =should  (SgN  >should !22_S	et	f	\N
110469	but	### but	et	f	\N
110471	those	?those =those  (SgN  >those !16_S	et	f	\N
110473	those	?those =those  (SgG  >those !16_S	et	f	\N
110474	those	?those =those  (IndPrPs_  >thosema !27_V	et	f	\N
110475	those	?those =those  (ImpPrSg2  >thosema !27_V	et	f	\N
110476	who	### who	et	f	\N
110492	deep	?deep =deep  (SgN  >deep !22_S	et	f	\N
110493	ineffable	?ineffable =ineffable  (PlP  >ineffabl !22_S	et	f	\N
110512	josephinele	?josephinele =josephine  (PlAll  >josephin !19_S	et	f	\N
110536	does	?does =doe  (SgIn  >doe !26_S	et	f	\N
110537	does	?does =does  (SgN  >does !09_S	et	f	\N
110539	when	### when	et	f	\N
110546	wrongly	### wrongly	et	f	\N
110547	value	?value =value  (SgN  >value !01_S	et	f	\N
110548	value	?value =value  (SgG  >value !01_S	et	f	\N
110563	forget	?forget =forge  (SgP  >forge !06_S	et	f	\N
110579	happiness	?happiness =happiness  (SgN  >happiness !22_S	et	f	\N
110600	juhtunud	juhtunud =juhtu  (PtsPtPs  >juhtuma !27_V	et	f	\N
110601	juhtunud	juhtunud =juhtunu  (PlN  >juhtunu !01_S	et	f	\N
110602	juhtunud	"juhtunu %juhtu  )NU_vS  <juhtuma ;27_V	et	f	\N
110603	juhtunud	juhtunud =juhtunud  (ID  >juhtunud !41_A	et	f	\N
110604	juhtunud	"juhtunud %juhtu  )NUD_vA  <juhtuma ;27_V	et	f	\N
110617	heaven	?heaven =heave  (IndPrSg1  >heavema !27_V	et	f	\N
110618	heaven	?heaven =heaven  (SgN  >heaven !02_S	et	f	\N
110621	hour	?hour =hour  (SgN  >hour !22_S	et	f	\N
110634	town	?town =town  (SgN  >town !22_S	et	f	\N
110635	today	### today	et	f	\N
110638	this	### this	et	f	\N
110641	suspect	?suspect =suspect  (SgN  >suspect !22_S	et	f	\N
110657	vabandust	vabandust =vabandus  (SgP  >vabandus !11_S	et	f	\N
110659	vabandust	"vabandus %vabanda  )US_vS  <vabandama ;27_V	et	f	\N
110660	vabandust	vabandust =vabandust  (ID  >vabandust !41_I	et	f	\N
110667	jargmisel	?jargmisel =jargmise  (SgAd  >jargmine !12?10_A	et	f	\N
110669	jargmisel	?jargmisel =jargmisel  (SgN  >jargmisel !19_S	et	f	\N
110680	aware	### aware	et	f	\N
110689	little	?little =little  (SgN  >little !06_S	et	f	\N
110690	little	?little =little  (SgG  >little !06_S	et	f	\N
110691	little	?little =little  (PlP  >littl !22_S	et	f	\N
110692	little	?little =little  (IndPrPs_  >littlema !30_V	et	f	\N
110693	little	?little =little  (ImpPrSg2  >littlema !30_V	et	f	\N
110701	understand	?understand =understand  (SgN  >understand !22_S	et	f	\N
110703	where	?where =where  (SgN  >where !16_S	et	f	\N
110705	where	?where =where  (SgG  >where !16_S	et	f	\N
110706	where	?where =where  (IndPrPs_  >wherema !27_V	et	f	\N
110707	where	?where =where  (ImpPrSg2  >wherema !27_V	et	f	\N
110728	peace	?peace =peace  (SgN  >peace !06_S	et	f	\N
110729	peace	?peace =peace  (SgG  >peace !06_S	et	f	\N
110730	peace	?peace =peace  (PlP  >peac !22_S	et	f	\N
110733	offended	### offended	et	f	\N
110734	viimast	viimast =vii  (SupEl  >viima !38_V	et	f	\N
110735	viimast	viimast =viimas  (SgP  >viimane !10_A	et	f	\N
110736	hüvastijattudeks	### hüvastijattudeks	et	f	\N
110738	lahku	lahku =lahku  (ID  >lahku !41_D	et	f	\N
110739	lahku	lahku =lahku  (SgP  >lahk !22_S	et	f	\N
110742	lahku	lahku =lahku  (SgAdt  >lahk !22_S	et	f	\N
110743	lahku	lahku =lahku  (IndPrPs_  >lahkuma !27_V	et	f	\N
110744	lahku	lahku =lahku  (ImpPrSg2  >lahkuma !27_V	et	f	\N
110758	võimatu	võimatu =võimatu  (SgN  >võimatu !01_A	et	f	\N
110759	võimatu	"võimatu %või  )MATU_vA  <võima ;37_V	et	f	\N
110760	võimatu	võimatu =võimatu  (SgG  >võimatu !01_A	et	f	\N
110778	kingituse	kingituse =kingituse  (SgG  >kingitus !11_S	et	f	\N
110780	kingituse	"kingitus %kingi  )TUS1_aS  <kinkima ;28_V	et	f	\N
110781	kingituse	"kingitus %kingi  )TUS2_aS  <kink ;22_S	et	f	\N
110800	pikka	pikka =pikka  (ID  >pikka !41_D	et	f	\N
110801	pikka	pikka =pikka  (SgP  >pikk !22_S	et	f	\N
110802	pikka	pikka =pikka  (SgP  >pikk !22_AS	et	f	\N
110804	pikka	pikka =pikka  (SgAdt  >pikk !22_S	et	f	\N
110806	pikka	pikka =pikka  (SgAdt  >pikk !22_AS	et	f	\N
110543	do	do =do  (SgG  >do !26_S	et	f	\N
110550	character	?character =character  (SgN  >character !02_S	et	f	\N
110553	demonstrated	### demonstrated	et	f	\N
110570	take	?take =take  (SgN  >take !06_S	et	f	\N
110571	take	?take =take  (IndPrPs_  >takema !27_V	et	f	\N
110572	take	?take =take  (ImpPrSg2  >takema !27_V	et	f	\N
110574	fate	?fate =fate  (SgN  >fate !06_S	et	f	\N
110575	fate	?fate =fate  (IndPrPs_  >fatema !27_V	et	f	\N
110576	fate	?fate =fate  (ImpPrSg2  >fatema !27_V	et	f	\N
110580	amiss	?amiss =amiss  (SgN  >amiss !22_S	et	f	\N
110623	once	?once =once  (SgN  >once !06_S	et	f	\N
110624	once	?once =once  (SgG  >once !06_S	et	f	\N
110625	once	?once =once  (PlP  >onc !22_S	et	f	\N
110628	united	### united	et	f	\N
110637	deliver	?deliver =deliver  (SgN  >deliver !19_S	et	f	\N
110640	did	### did	et	f	\N
110642	might	?might =might  (SgN  >might !22_S	et	f	\N
110644	ilmselt	ilmselt =ilmse  (SgAbl  >ilmne !02_A	et	f	\N
110645	ilmselt	ilmselt =ilmselt  (ID  >ilmselt !41_D	et	f	\N
110646	ilmselt	"ilmselt %ilmse  )LT_mD  <ilmne ;02_A	et	f	\N
110674	b	### b	et	f	\N
110698	yourpardon	?yourpardon =yourpardon  (SgN  >yourpardon !02_S	et	f	\N
110702	very	### very	et	f	\N
110715	usually	### usually	et	f	\N
110718	souls	?souls =souls  (SgN  >souls !22_S	et	f	\N
110756	lihtsalt	lihtsalt =lihtsa  (SgAbl  >lihtne !02_A	et	f	\N
110757	lihtsalt	lihtsalt =lihtsalt  (ID  >lihtsalt !41_D	et	f	\N
110761	lihtsalt	"lihtsalt %lihtsa  )LT_mD  <lihtne ;02_A	et	f	\N
110803	ringreisi	ringreisi =reis  (PlP  >ring+reis !14_S	et	f	\N
110805	ringreisi	ringreisi =reisi  (SgG  >ring+reis !22_S	et	f	\N
110807	ringreisi	ringreisi =reisi  (SgP  >ring+reis !22_S	et	f	\N
110808	ringreisi	ringreisi =reisi  (SgAdt  >ring+reis !22_S	et	f	\N
110813	gümnaasiumi	gümnaasiumi =gümnaasiumi  (SgG  >gümnaasium !19~02_S	et	f	\N
110814	gümnaasiumi	gümnaasiumi =gümnaasiumi  (SgP  >gümnaasium !19_S	et	f	\N
110815	gümnaasiumi	gümnaasiumi =gümnaasiumi  (SgAdt  >gümnaasium !19_S	et	f	\N
110843	seminari	seminari =seminari  (SgG  >seminar !19_S	et	f	\N
110844	seminari	seminari =seminari  (SgP  >seminar !19_S	et	f	\N
110845	seminari	seminari =seminari  (SgAdt  >seminar !19_S	et	f	\N
110859	päeva	päeva =päeva  (SgG  >päev !22_S	et	f	\N
110860	päeva	päeva =päeva  (SgP  >päev !22_S	et	f	\N
110861	päeva	päeva =päeva  (SgAdt  >päev !22_S	et	f	\N
110884	koorilaulu	koorilaulu =laulu  (SgG  >koori+laul !22_S	et	f	\N
110885	koorilaulu	koorilaulu =laulu  (SgP  >koori+laul !22_S	et	f	\N
110886	koorilaulu	koorilaulu =laulu  (SgAdt  >koori+laul !22_S	et	f	\N
110891	ühistegevuse	ühistegevuse =tegevuse  (SgG  >ühis+tegevus !11_S	et	f	\N
110893	ühistegevuse	"ühis+tegevus %tegeva  )US_aS  <ühis+tegev ;02_A	et	f	\N
110914	hingeline	hingeline =hingeline  (SgN  >hingeline !12_SA	et	f	\N
110915	hingeline	"hingeline %hinge  )LINE_aA  <hing ;22_S	et	f	\N
110918	nõudmine	nõudmine =nõudmine  (SgN  >nõudmine !12?10_S	et	f	\N
110919	nõudmine	"nõudmine %nõud  )MINE_vS  <nõudma ;34_V	et	f	\N
110921	liikumise	liikumise =liikumise  (SgG  >liikumine !12_S	et	f	\N
110922	liikumise	"liikumine %liiku  )MINE_vS  <liikuma ;28_V	et	f	\N
110925	sellised	sellised =sellise  (PlN  >selline !10_P	et	f	\N
110927	sellised	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
110931	võiksid	võiksid =või  (KndPrSg2  >võima !37_V	et	f	\N
110932	võiksid	võiksid =või  (KndPrPl3  >võima !37_V	et	f	\N
111001	kuu	kuu =kuu  (SgN  >kuu !26_S	et	f	\N
111002	kuu	kuu =kuu  (SgG  >kuu !26_S	et	f	\N
111030	sündi	sündi =sündi  (SgP  >sünd !22_S	et	f	\N
111031	sündi	sündi =sündi  (SgAdt  >sünd !22_S	et	f	\N
111051	abielulahutuse	abielulahutuse =lahutuse  (SgG  >abi+elu+lahutus !11_S	et	f	\N
111052	abielulahutuse	"abi+elu+lahutus %lahu  )TUS2_aS  <abi+elu+lahk ;22_S	et	f	\N
111067	teresia	?teresia =teresia  (SgN  >teresia !01_S	et	f	\N
111068	teresia	?teresia =teresia  (SgG  >teresia !01_S	et	f	\N
111070	teresia	?teresia =sia  (SgN  >tere+sia !26_S	et	f	\N
111072	teresia	?teresia =sia  (SgG  >tere+sia !26_S	et	f	\N
111086	like	?like =like  (SgN  >like !06_S	et	f	\N
111087	like	?like =like  (IndPrPs_  >likema !27_V	et	f	\N
111088	like	?like =like  (ImpPrSg2  >likema !27_V	et	f	\N
111092	intimate	?intimate =intima  (PlG  >intim !02_A	et	f	\N
111102	sister	?sister =sister  (SgN  >sister !02_S	et	f	\N
111103	widow	### widow	et	f	\N
111107	her	### her	et	f	\N
111110	would	?would =would  (SgN  >would !22_S	et	f	\N
111111	been	?been =been  (SgN  >been !22_S	et	f	\N
111120	happinessbeethoven	?happinessbeethoven =happinessbeethoven  (SgN  >happinessbeethoven !19_S	et	f	\N
111130	each	?each =each  (SgN  >each !22_S	et	f	\N
111136	pani	pani =pan  (IndIpfSg3  >panema !36_V	et	f	\N
111137	pani	pani =pani  (SgN  >pani !16_S	et	f	\N
111138	pani	pani =pani  (SgG  >pani !16_S	et	f	\N
111139	pani	pani =pani  (SgG  >pan !19_S	et	f	\N
111140	pani	pani =pani  (SgP  >pan !19_S	et	f	\N
111141	pani	pani =pani  (SgAdt  >pan !19_S	et	f	\N
111142	ongi	ongi =on  (IndPrSg3^  >olema !36_V	et	f	\N
110555	have	?have =have  (IndPrPs_  >havema !27_V	et	f	\N
110556	have	?have =have  (ImpPrSg2  >havema !27_V	et	f	\N
110559	kind	?kind =kind  (SgN  >kind !22_S	et	f	\N
110565	long	?long =long  (SgN  >long !22_S	et	f	\N
110573	interest	?interest =interes  (SgP  >interene !12_A	et	f	\N
110581	if	### if	et	f	\N
110582	ungarisse	?ungarisse =ungari  (SgIll  >ungari !01_S	et	f	\N
110583	ungarisse	?ungarisse =ungari  (SgIll  >ungar !02_S	et	f	\N
110584	ungarisse	?ungarisse =ungaris  (SgAdt  >ungaris !11_S	et	f	\N
110585	ungarisse	?ungarisse =ungarisse  (SgG  >ungarisne !02_A	et	f	\N
110586	ungarisse	?ungarisse =ungarisse  (PlP  >ungariss !22_S	et	f	\N
110587	truudusetuse	truudusetuse =truudusetuse  (SgG  >truudusetus !11?09_S	et	f	\N
110588	truudusetuse	"truudusetus %truuduse  )TUS2_aS  <truudus ;09_S	et	f	\N
110589	truudusetuse	"truudusetus %truuduse  )TUS2_aS  <truudus ;11_S	et	f	\N
110591	lydias	?lydias =lydia  (SgIn  >lydia !01_S	et	f	\N
110592	lydias	?lydias =lydias  (SgN  >lydias !11_S	et	f	\N
110605	even	?even =eve  (IndPrSg1  >evema !27_V	et	f	\N
110606	even	?even =even  (SgN  >even !02_S	et	f	\N
110609	lines	?lines =line  (IndIpfSg3  >linema !27_V	et	f	\N
110610	lines	?lines =lines  (SgN  >lines !09_S	et	f	\N
110619	grant	?grant =grant  (SgN  >grant !22_S	et	f	\N
110620	undisturbed	### undisturbed	et	f	\N
110630	am	### am	et	f	\N
110632	into	?into =into  (SgN  >into !16_S	et	f	\N
110633	into	?into =into  (SgG  >into !16_S	et	f	\N
110636	could	?could =could  (SgN  >could !22_S	et	f	\N
110647	solvanud	solvanud =solva  (PtsPtPs  >solvama !29_V	et	f	\N
110648	solvanud	solvanud =solvanu  (PlN  >solvanu !01_S	et	f	\N
110649	solvanud	"solvanu %solva  )NU_vS  <solvama ;29_V	et	f	\N
110650	solvanud	solvanud =solvanud  (ID  >solvanud !41_A	et	f	\N
110651	solvanud	"solvanud %solva  )NUD_vA  <solvama ;29_V	et	f	\N
110652	millegi	millegi =mille  (SgG  >miski !00_P	et	f	\N
110653	millegi	millegi =mille  (SgG^  >mis !00_P	et	f	\N
110661	turn	?turn =turn  (SgN  >turn !22_S	et	f	\N
110679	well	?well =well  (SgN  >well !22_S	et	f	\N
110699	cannot	?cannot =canno  (SgP  >canno !16_S	et	f	\N
110700	cannot	?cannot =cannot  (SgN  >cannot !02_S	et	f	\N
110708	true	?true =true  (SgN  >true !26_S	et	f	\N
110710	true	?true =true  (SgG  >true !26_S	et	f	\N
110713	exists	?exists =exists  (SgN  >exists !02_S	et	f	\N
110716	suspected	### suspected	et	f	\N
110717	weaker	?weaker =weaker  (SgN  >weaker !02_S	et	f	\N
110721	sorry	### sorry	et	f	\N
110727	better	?better =better  (SgN  >better !02_S	et	f	\N
110753	abielu	abielu =elu  (SgN  >abi+elu !17_S	et	f	\N
110754	abielu	abielu =elu  (SgG  >abi+elu !17_S	et	f	\N
110755	abielu	abielu =elu  (SgP  >abi+elu !17_S	et	f	\N
110793	armastasid	armastasid =armasta  (IndIpfSg2  >armastama !27_V	et	f	\N
110794	armastasid	armastasid =armasta  (IndIpfPl3  >armastama !27_V	et	f	\N
110797	lahkus	lahkus =lahku  (IndIpfSg3  >lahkuma !27_V	et	f	\N
110798	lahkus	lahkus =lahkus  (SgN  >lahkus !11~09_S	et	f	\N
110799	lahkus	"lahkus %lahke  )US_aS  <lahke ;01_A	et	f	\N
110809	saatjaks	saatjaks =saatja  (SgTr  >saatja !01_S	et	f	\N
110810	saatjaks	"saatja %saat  )JA_vS  <saatma ;34_V	et	f	\N
110811	saatjaks	saatjaks =jaks  (SgN  >saat+jaks !22_S	et	f	\N
110818	meditsiini	meditsiini =meditsiini  (SgG  >meditsiin !22_S	et	f	\N
110819	meditsiini	meditsiini =meditsiini  (SgP  >meditsiin !22_S	et	f	\N
110821	meditsiini	meditsiini =meditsiini  (SgAdt  >meditsiin !22_S	et	f	\N
110827	eestimaa	eestimaa =maa  (SgN  >eesti+maa !26_S	et	f	\N
110828	eestimaa	eestimaa =maa  (SgG  >eesti+maa !26_S	et	f	\N
110837	pühapäeva-	pühapäeva- =päeva  (SgG  >püha+päev !22_S	et	f	\N
110838	pühapäeva-	pühapäeva- =päeva  (SgP  >püha+päev !22_S	et	f	\N
110839	pühapäeva-	pühapäeva- =päeva  (SgAdt  >püha+päev !22_S	et	f	\N
110846	reisis	reisis =reisi  (SgIn  >reis !22_S	et	f	\N
110847	reisis	reisis =reisi  (IndIpfSg3  >reisima !28_V	et	f	\N
110850	ungaris	?ungaris =ungari  (SgIn  >ungari !01_S	et	f	\N
110851	ungaris	?ungaris =ungari  (SgIn  >ungar !02_S	et	f	\N
110852	ungaris	?ungaris =ungaris  (SgN  >ungaris !11_S	et	f	\N
110854	christop	?christop =christop  (SgN  >christop !02_S	et	f	\N
110871	kirjakultuuri	kirjakultuuri =kultuuri  (SgG  >kirja+kultuur !22_S	et	f	\N
110872	kirjakultuuri	kirjakultuuri =kultuuri  (SgP  >kirja+kultuur !22_S	et	f	\N
110873	kirjakultuuri	kirjakultuuri =kultuuri  (SgAdt  >kirja+kultuur !22_S	et	f	\N
110920	henhuutluse	?henhuutluse =henhuutluse  (SgG  >henhuutlus !11~09_S	et	f	\N
110941	tulevikus	tulevikus =tuleviku  (SgIn  >tulevik !25_S	et	f	\N
110943	tulevikus	tulevikus =viku  (SgIn  >tule+vikk !22_S	et	f	\N
110945	algusest	algusest =alguse  (SgEl  >algus !11~09_S	et	f	\N
110946	algusest	algusest =alguses  (SgP  >algusene !12_A	et	f	\N
110947	algusest	"algusene %alguse  )NE_aA  <algus ;09_S	et	f	\N
110948	algusest	"algusene %alguse  )NE_aA  <algus ;11_S	et	f	\N
110949	algusest	algusest =use  (PlEl  >alg+usk !22_S	et	f	\N
110952	last	last =la  (SgEl  >la !26_S	et	f	\N
110953	last	last =las  (SgP  >laps !14_S	et	f	\N
110665	tõenäoliselt	"tõe+näoline %näo  )LINE_aA  <tõe+nägu ;18_S	et	f	\N
110666	tõenäoliselt	"tõe+näoliselt %näo  )LISELT_mD  <tõe+nägu ;18_S	et	f	\N
110668	tõenäoliselt	"tõe+näoliselt %näolise  )LT_mD  <tõe+näoline ;10_A	et	f	\N
110670	tõenäoliselt	"tõe+näoliselt %näolise  )LT_mD  <tõe+näoline ;12_A	et	f	\N
110673	mean	?mean =mean  (SgN  >mean !22_S	et	f	\N
110675	since	?since =since  (SgN  >since !06_S	et	f	\N
110676	since	?since =since  (SgG  >since !06_S	et	f	\N
110677	since	?since =since  (PlP  >sinc !22_S	et	f	\N
110682	code	?code =code  (SgN  >code !16_S	et	f	\N
110683	code	?code =code  (SgG  >code !16_S	et	f	\N
110684	code	?code =code  (IndPrPs_  >codema !27_V	et	f	\N
110687	code	?code =code  (ImpPrSg2  >codema !27_V	et	f	\N
110694	importance	?importance =importance  (PlP  >importanc !22_S	et	f	\N
110695	importance	?importance =ance  (SgN  >import+ance !06_S	et	f	\N
110696	importance	?importance =ance  (SgG  >import+ance !06_S	et	f	\N
110697	importance	?importance =ance  (PlP  >import+anc !22_S	et	f	\N
110704	touchiness	?touchiness =touchiness  (SgN  >touchiness !22_S	et	f	\N
110709	mutual	?mutual =mutua  (SgAd  >mutua !01_S	et	f	\N
110711	mutual	?mutual =mutual  (SgN  >mutual !19_S	et	f	\N
110712	esteem	?esteem =esteem  (SgN  >esteem !22_S	et	f	\N
110719	kohe	kohe =kohe  (ID  >kohe !41_D	et	f	\N
110720	kohe	kohe =kohe  (SgN  >kohe !02_A	et	f	\N
110722	able	?able =able  (SgN  >able !16_S	et	f	\N
110723	able	?able =able  (SgG  >able !16_S	et	f	\N
110724	able	?able =able  (PlP  >abl !22_S	et	f	\N
110725	able	?able =able  (IndPrPs_  >ablema !30_V	et	f	\N
110726	able	?able =able  (ImpPrSg2  >ablema !30_V	et	f	\N
110737	m	### m	et	f	\N
110745	tüli	tüli =tüli  (SgN  >tüli !17_S	et	f	\N
110746	tüli	tüli =tüli  (SgG  >tüli !17_S	et	f	\N
110747	tüli	tüli =tüli  (SgP  >tüli !17_S	et	f	\N
110765	soost	soost =soo  (SgEl  >sugu !18_S	et	f	\N
110766	soost	soost =soo  (SgEl  >soo !26_S	et	f	\N
110769	positsiooni	positsiooni =positsiooni  (SgG  >positsioon !22_S	et	f	\N
110770	positsiooni	positsiooni =positsiooni  (SgP  >positsioon !22_S	et	f	\N
110771	positsiooni	positsiooni =positsiooni  (SgAdt  >positsioon !22_S	et	f	\N
110774	suurema	suurema =suurema  (SgG  >suurem !02_A	et	f	\N
110775	suurema	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
110776	suurema	suurema =ema  (SgN  >suur+ema !17_S	et	f	\N
110777	suurema	suurema =ema  (SgG  >suur+ema !17_S	et	f	\N
110779	suurema	suurema =ema  (SgP  >suur+ema !17_S	et	f	\N
110784	õiguse	õiguse =õiguse  (SgG  >õigus !11~09_S	et	f	\N
110785	õiguse	"õigus %õige  )US_aS  <õige ;01_A	et	f	\N
110816	saksamaal	saksamaal =maa  (SgAd  >saksa+maa !26_S	et	f	\N
110817	saksamaal	saksamaal =maal  (SgN  >saksa+maal !22_S	et	f	\N
110820	õigusteadust	õigusteadust =dust  (SgN  >õigust+ea+dust !22_S	et	f	\N
110822	õigusteadust	õigusteadust =teadu  (SgEl  >õigus+tead !22_S	et	f	\N
110823	õigusteadust	õigusteadust =teadus  (SgP  >õigus+teadus !11~09_S	et	f	\N
110824	kubermangugümnaasiumi	kubermangugümnaasiumi =gümnaasiumi  (SgG  >kubermangu+gümnaasium !19~02_S	et	f	\N
110825	kubermangugümnaasiumi	kubermangugümnaasiumi =gümnaasiumi  (SgP  >kubermangu+gümnaasium !19_S	et	f	\N
110826	kubermangugümnaasiumi	kubermangugümnaasiumi =gümnaasiumi  (SgAdt  >kubermangu+gümnaasium !19_S	et	f	\N
110833	alalise	alalise =alalise  (SgG  >alaline !12_A	et	f	\N
110834	alalise	"alaline %ala  )LINE_aA  <ala ;17_S	et	f	\N
110840	vaeslastekoole	vaeslastekoole =koo  (SgAll  >vaes+laste+kubu !18_S	et	f	\N
110841	vaeslastekoole	vaeslastekoole =koole  (SgN  >vaes+laste+koole !05_S	et	f	\N
110842	vaeslastekoole	vaeslastekoole =koole  (PlP  >vaes+laste+kool !22_S	et	f	\N
110848	tutvuski	tutvuski =tutvu  (IndIpfSg3^  >tutvuma !27_V	et	f	\N
110849	tutvuski	tutvuski =tutvus  (SgN^  >tutvus !11~09_S	et	f	\N
110855	hernhuutlusega	hernhuutlusega =hernhuutluse  (SgKom  >hernhuutlus !11~09_S	et	f	\N
110856	hernhuutlusega	"hernhuutlus %hernhuutlase  )US_aS  <hernhuutlane ;12_S	et	f	\N
110864	1730-ndatel	?-ndatel =ndate  (PlAd  >-ndatt !22_S	et	f	\N
110865	1730-ndatel	?-ndatel =ndatel  (SgN  >-ndatel !02_S	et	f	\N
110881	enesearendamisvõimalusi	?enesearendamisvõimalusi =enesearendamisvõimalusi  (PlP  >enesearendamisvõimalus !11_S	et	f	\N
110883	enesearendamisvõimalusi	?enesearendamisvõimalusi =arendamisvõimalusi  (PlP  >enese+arendamisvõimalus !11_S	et	f	\N
110905	teatud	teatud =tea  (PtsPtIps  >teadma !34_V	et	f	\N
110906	teatud	teatud =teatu  (PlN  >teatu !01_S	et	f	\N
110907	teatud	"teatu %tea  )TU1_vS  <teadma ;34_V	et	f	\N
110908	teatud	teatud =teatud  (ID  >teatud !41_A	et	f	\N
110909	teatud	"teatud %tea  )TUD_vA  <teadma ;34_V	et	f	\N
110916	võrdsete	võrdsete =võrdse  (PlG  >võrdne !02_A	et	f	\N
110917	võrdsete	võrdsete =sete  (SgN  >võrd+sete !06_S	et	f	\N
110923	valgustajana	valgustajana =valgustaja  (SgEs  >valgustaja !01_S	et	f	\N
110924	valgustajana	"valgustaja %valgusta  )JA_vS  <valgustama ;27_V	et	f	\N
110926	valgustajana	valgustajana =aja  (SgEs  >valgust+aeg !22_S	et	f	\N
110936	konflikti	konflikti =konflikti  (SgG  >konflikt !22_S	et	f	\N
110938	konflikti	konflikti =konflikti  (SgP  >konflikt !22_S	et	f	\N
110788	mõelnud	mõelnud =mõel  (PtsPtPs  >mõtlema !30_V	et	f	\N
110789	mõelnud	mõelnud =mõelnu  (PlN  >mõelnu !01_S	et	f	\N
110790	mõelnud	"mõelnu %mõel  )NU_vS  <mõtlema ;30_V	et	f	\N
110791	mõelnud	mõelnud =mõelnud  (ID  >mõelnud !41_A	et	f	\N
110792	mõelnud	"mõelnud %mõel  )NUD_vA  <mõtlema ;30_V	et	f	\N
110795	reaalsusega	reaalsusega =reaalsuse  (SgKom  >reaalsus !11~09_S	et	f	\N
110796	reaalsusega	"reaalsus %reaalse  )US_aS  <reaalne ;02_A	et	f	\N
110812	tallinnas	?tallinnas =tallinna  (SgIn  >tallinna !16_S	et	f	\N
110835	komitee	komitee =komitee  (SgN  >komitee !26_S	et	f	\N
110836	komitee	komitee =komitee  (SgG  >komitee !26_S	et	f	\N
110853	korompaga	?korompaga =korompa  (SgKom  >korompa !01_S	et	f	\N
110857	liikumisega	liikumisega =liikumise  (SgKom  >liikumine !12_S	et	f	\N
110858	liikumisega	"liikumine %liiku  )MINE_vS  <liikuma ;28_V	et	f	\N
110866	liikumine	liikumine =liikumine  (SgN  >liikumine !12_S	et	f	\N
110867	liikumine	"liikumine %liiku  )MINE_vS  <liikuma ;28_V	et	f	\N
110876	eneseväärtustunde	eneseväärtustunde =tunde  (SgG  >enese+väärtus+tunne !06_S	et	f	\N
110877	eneseväärtustunde	eneseväärtustunde =tunde  (PlP  >enese+väärtus+tund !22_S	et	f	\N
110887	traditsiooni	traditsiooni =traditsiooni  (SgG  >traditsioon !22_S	et	f	\N
110888	traditsiooni	traditsiooni =traditsiooni  (SgP  >traditsioon !22_S	et	f	\N
110889	traditsiooni	traditsiooni =traditsiooni  (SgAdt  >traditsioon !22_S	et	f	\N
110890	kunstialaste	kunstialaste =alas  (PlG  >kunsti+alane !10_AS	et	f	\N
110892	kunstialaste	"kunsti+alane %ala  )NE_aA  <kunsti+ala ;17_S	et	f	\N
110896	distsiplineeritud	distsiplineeritud =distsiplineeri  (PtsPtIps  >distsiplineerima !28_V	et	f	\N
110897	distsiplineeritud	distsiplineeritud =distsiplineeritu  (PlN  >distsiplineeritu !01_S	et	f	\N
110898	distsiplineeritud	"distsiplineeritu %distsiplineeri  )TU1_vS  <distsiplineerima ;28_V	et	f	\N
110899	distsiplineeritud	distsiplineeritud =distsiplineeritud  (ID  >distsiplineeritud !41_A	et	f	\N
110900	distsiplineeritud	"distsiplineeritud %distsiplineeri  )TUD_vA  <distsiplineerima ;28_V	et	f	\N
110910	vastuseis	vastuseis =vastuse  (PlIn  >vastus !09_S	et	f	\N
110912	vastuseis	vastuseis =seis  (SgN  >vastu+seis !22_S	et	f	\N
110928	kalduvused	kalduvused =kalduvuse  (PlN  >kalduvus !11_S	et	f	\N
110929	kalduvused	"kalduvus %kaldu  )VUS_aS  <kalduma ;27_V	et	f	\N
110930	kalduvused	"kalduvus %kalduva  )US_aS  <kalduv ;02_A	et	f	\N
110933	adami	?adami =adami  (SgN  >adami !01_S	et	f	\N
110935	adami	?adami =adami  (SgG  >adami !01_S	et	f	\N
110939	adami	?adami =adami  (SgG  >adam !02_A	et	f	\N
110950	neil	neil =ne  (PlAd  >see !00_P	et	f	\N
110951	neil	neil =ne  (PlAd  >ta !00_P	et	f	\N
110954	teophile	?teophile =teophi  (SgAll  >teoph !22_S	et	f	\N
110956	teophile	?teophile =teophile  (IndPrPs_  >teophilema !27_V	et	f	\N
110957	teophile	?teophile =teophile  (ImpPrSg2  >teophilema !27_V	et	f	\N
110958	maria	?maria =maria  (SgN  >maria !01_S	et	f	\N
110962	maria	?maria =maria  (SgG  >maria !01_S	et	f	\N
110973	päikesesse	päikesesse =päikese  (SgIll  >päike !12?10_S	et	f	\N
110974	päikesesse	päikesesse =päikese  (SgIll  >päikene !12?10_S	et	f	\N
110995	perekonnal	perekonnal =perekonna  (SgAd  >perekond !22_S	et	f	\N
110996	perekonnal	perekonnal =konna  (SgAd  >pere+konn !22_S	et	f	\N
110997	juurest	juurest =juure  (SgEl  >juur !13_S	et	f	\N
110998	juurest	juurest =juures  (SgP  >juurene !10_A	et	f	\N
110999	juurest	"juurene %juure  )NE_aA  <juur ;13_S	et	f	\N
111000	juurest	juurest =juurest  (ID  >juurest !41_K	et	f	\N
111008	laps	laps =laps  (SgN  >laps !14_S	et	f	\N
111009	laps	laps =laps  (SgN  >laps !22_S	et	f	\N
111026	silmapaistev	silmapaistev =paist  (PtsPrPs  >silma+_paistma !34_V	et	f	\N
111027	silmapaistev	silmapaistev =paistev  (SgN  >silma+paistev !02_A	et	f	\N
111028	kuud	kuud =kuu  (PlN  >kuu !26_S	et	f	\N
111029	kuud	kuud =kuu  (SgP  >kuu !26_S	et	f	\N
111042	mehest	mehest =mehe  (SgEl  >mees !13_S	et	f	\N
111043	mehest	mehest =mehes  (SgP  >mehene !10_A	et	f	\N
111045	mehest	"mehene %mehe  )NE_aA  <mees ;13_S	et	f	\N
111053	ajaks	ajaks =aja  (SgTr  >aeg !22_S	et	f	\N
111054	ajaks	ajaks =aja  (KndPrPs  >ajama !27_V	et	f	\N
111069	nelja	nelja =nelja  (SgG  >neljas !02_O	et	f	\N
111071	nelja	nelja =nelja  (SgG  >neli !24_N	et	f	\N
111073	nelja	nelja =nelja  (SgP  >neli !24_N	et	f	\N
111074	nelja	nelja =nelja  (SgAdt  >neli !24_N	et	f	\N
111085	seems	?seems =seems  (SgN  >seems !22_S	et	f	\N
111091	friend	?friend =friend  (SgN  >friend !02_S	et	f	\N
111093	our	?our =our  (SgN  >our !22_S	et	f	\N
111095	stupendous	?stupendous =stupendou  (SgIn  >stupendou !26_S	et	f	\N
111097	stupendous	?stupendous =stupendous  (SgN  >stupendous !22_S	et	f	\N
111106	him	### him	et	f	\N
111115	caused	?caused =cause  (PlN  >cause !06_S	et	f	\N
111116	caused	?caused =cause  (IndPrSg2  >causema !28_V	et	f	\N
111117	forgo	?forgo =forgo  (SgN  >forgo !16_S	et	f	\N
111119	forgo	?forgo =forgo  (SgG  >forgo !16_S	et	f	\N
111122	friendin	?friendin =friendi  (IndPrSg1  >frientima !28_V	et	f	\N
111123	friendin	?friendin =friendin  (SgN  >friendin !02_S	et	f	\N
111133	now	### now	et	f	\N
110829	kubermangukooli	kubermangukooli =kooli  (SgG  >kubermangu+kool !22_S	et	f	\N
110830	kubermangukooli	kubermangukooli =kooli  (SgP  >kubermangu+kool !22_S	et	f	\N
110831	kubermangukooli	kubermangukooli =kooli  (SgAdt  >kubermangu+kool !22_S	et	f	\N
110832	kubermangukooli	kubermangukooli =kooli  (PlP  >kubermangu+kool !22_S	et	f	\N
110862	palve	palve =palve  (SgN  >palve !06_S	et	f	\N
110863	palve	palve =palve  (SgG  >palve !06_S	et	f	\N
110868	henhuutlus	?henhuutlus =henhuutlu  (SgIn  >henhuutlu !01_S	et	f	\N
110869	henhuutlus	?henhuutlus =henhuutlu  (IndIpfSg3  >henhuutluma !27_V	et	f	\N
110870	henhuutlus	?henhuutlus =henhuutlus  (SgN  >henhuutlus !11~09_S	et	f	\N
110874	pärisoristele	pärisoristele =oris  (PlAll  >päris+orine !10_A	et	f	\N
110875	pärisoristele	"päris+orine %ori  )NE_aA  <päris+ori ;24_S	et	f	\N
110878	tegutsemis-	?tegutsemis- =tegutsemi  (SgIn  >tegutsem !02_A	et	f	\N
110879	tegutsemis-	?tegutsemis- =tegutsemis  (SgN  >tegutsemis !09_S	et	f	\N
110880	tegutsemis-	?tegutsemis- =tsemi  (SgIn  >tegu+tsemi !17_S	et	f	\N
110882	tegutsemis-	?tegutsemis- =tsemis  (SgN  >tegu+tsemis !09_S	et	f	\N
110894	õpetasid	õpetasid =õpeta  (IndIpfSg2  >õpetama !27_V	et	f	\N
110895	õpetasid	õpetasid =õpeta  (IndIpfPl3  >õpetama !27_V	et	f	\N
110901	eluviisi	eluviisi =viisi  (ID  >elu+viisi !41_D	et	f	\N
110902	eluviisi	eluviisi =viisi  (SgG  >elu+viis !22_S	et	f	\N
110903	eluviisi	eluviisi =viisi  (SgP  >elu+viis !22_S	et	f	\N
110904	eluviisi	eluviisi =viisi  (SgAdt  >elu+viis !22_S	et	f	\N
110911	luterlikule	?luterlikule =luterliku  (SgAll  >luterlik !25_A	et	f	\N
110913	luterlikule	?luterlikule =luterlikule  (PlP  >luterlikul !19_S	et	f	\N
110934	vahelise	vahelise =vahelise  (SgG  >vaheline !12_A	et	f	\N
110937	vahelise	"vaheline %vahe  )LINE_aA  <vahe ;16_S	et	f	\N
110942	abiellusid	abiellusid =ellu  (IndIpfSg2  >abi+elluma !27_V	et	f	\N
110944	abiellusid	abiellusid =ellu  (IndIpfPl3  >abi+elluma !27_V	et	f	\N
110964	pilti	pilti =pilti  (SgP  >pilt !22_S	et	f	\N
110965	pilti	pilti =pilti  (SgAdt  >pilt !22_S	et	f	\N
110975	vaatav	vaatav =vaata  (PtsPrPs  >vaatama !29_V	et	f	\N
110976	vaatav	vaatav =vaatav  (SgN  >vaatav !02_A	et	f	\N
110977	vaatav	"vaatav %vaata  )V_vA  <vaatama ;29_V	et	f	\N
110978	õnne	õnne =õnne  (SgG  >õnn !22_S	et	f	\N
110979	õnne	õnne =õnne  (SgP  >õnn !22_S	et	f	\N
110980	õnne	õnne =õnne  (SgAdt  >õnn !22_S	et	f	\N
110981	õnne	õnne =õnne  (PlP  >õnn !22_S	et	f	\N
110983	sellele	sellele =selle  (SgAll  >see !00_P	et	f	\N
110986	sellele	sellele =selle  (PlAll  >sell !22_S	et	f	\N
110987	vaielda	vaielda =vaiel  (Inf  >vaidlema !30_V	et	f	\N
110988	vaielda	vaielda =vaiel  (IndPrIps_  >vaidlema !30_V	et	f	\N
110989	külastanud	külastanud =külasta  (PtsPtPs  >külastama !27_V	et	f	\N
110990	külastanud	külastanud =külastanu  (PlN  >külastanu !01_S	et	f	\N
110991	külastanud	"külastanu %külasta  )NU_vS  <külastama ;27_V	et	f	\N
110992	külastanud	külastanud =külastanud  (ID  >külastanud !41_A	et	f	\N
110993	külastanud	"külastanud %külasta  )NUD_vA  <külastama ;27_V	et	f	\N
110994	külastanud	külastanud =tanu  (PlN  >külas+tanu !17_S	et	f	\N
111013	uurijad	uurijad =uurija  (PlN  >uurija !01_S	et	f	\N
111014	uurijad	"uurija %uuri  )JA_vS  <uurima ;28_V	et	f	\N
111021	väliselt	väliselt =välise  (SgAbl  >väline !10_A	et	f	\N
111022	väliselt	"väline %väli  )NE_aA  <väli ;24_S	et	f	\N
111023	väliselt	väliselt =väliselt  (ID  >väliselt !41_D	et	f	\N
111024	väliselt	"väliselt %välise  )LT_mD  <väline ;10_A	et	f	\N
111025	minonast	?minonast =minonas  (SgP  >minonane !12_A	et	f	\N
111036	lühikesteks	lühikesteks =lühikes  (PlTr  >lühike !12_A	et	f	\N
111037	lühikesteks	"lühike %lühi  )KE_dS  <lüht ;22_S	et	f	\N
111038	lühikesteks	lühikesteks =lühikes  (PlTr  >lühikene !12_S	et	f	\N
111039	lühikesteks	"lühikene %lühi  )KENE_dS  <lüht ;22_S	et	f	\N
111040	lühikesteks	lühikesteks =keste  (SgTr  >lühi+keste !06_S	et	f	\N
111041	lühikesteks	lühikesteks =keste  (PlTr  >lühi+kest !22_S	et	f	\N
111057	kurnatud	kurnatud =kurna  (PtsPtIps  >kurnama !29_V	et	f	\N
111058	kurnatud	kurnatud =kurnatu  (PlN  >kurnatu !01_AS	et	f	\N
111059	kurnatud	"kurnatu %kurna  )TU1_vS  <kurnama ;29_V	et	f	\N
111060	kurnatud	"kurnatu %kurna  )TU2_kA  <kurn ;22_S	et	f	\N
111061	kurnatud	kurnatud =kurnatud  (ID  >kurnatud !41_A	et	f	\N
111063	kurnatud	"kurnatud %kurna  )TUD_vA  <kurnama ;29_V	et	f	\N
111105	accept	?accept =accept  (SgN  >accept !22_S	et	f	\N
111112	happier	?happier =happier  (SgN  >happier !19_S	et	f	\N
111114	maternal	?maternal =materna  (SgAd  >materna !01_S	et	f	\N
111118	own	?own =own  (SgN  >own !22_S	et	f	\N
111125	they	### they	et	f	\N
111184	eksisteerivad	eksisteerivad =eksisteeri  (IndPrPl3  >eksisteerima !28_V	et	f	\N
111185	eksisteerivad	eksisteerivad =eksisteeriva  (PlN  >eksisteeriv !02_A	et	f	\N
111186	eksisteerivad	"eksisteeriv %eksisteeri  )V_vA  <eksisteerima ;28_V	et	f	\N
111191	päevikuid	päevikuid =päeviku  (PlP  >päevik !02_S	et	f	\N
111192	päevikuid	päevikuid =ku  (PlP  >päevi+kuu !26_S	et	f	\N
111198	erapooletu	erapooletu =erapooletu  (SgN  >erapooletu !01_A	et	f	\N
111199	erapooletu	erapooletu =erapooletu  (SgG  >erapooletu !01_A	et	f	\N
110940	konflikti	konflikti =konflikti  (SgAdt  >konflikt !22_S	et	f	\N
110982	hinges	hinges =hinge  (SgIn  >hing !22_S	et	f	\N
110984	hinges	hinges =hinge  (PlIn  >hink !22_S	et	f	\N
110985	hinges	hinges =hinges  (ID  >hinges !41_DA	et	f	\N
111006	seitsmes	seitsmes =seitsme  (SgIn  >seitse !05_N	et	f	\N
111007	seitsmes	seitsmes =seitsmes  (SgN  >seitsmes !02_O	et	f	\N
111011	keda	keda =ke  (SgP  >kes !00_P	et	f	\N
111012	keda	keda =ke  (PlP  >kes !00_P	et	f	\N
111017	lapseks	lapseks =lapse  (SgTr  >laps !14_S	et	f	\N
111020	lapseks	lapseks =lapse  (PlTr  >laps !22_S	et	f	\N
111044	eemaldamist	eemaldamist =eemaldamis  (SgP  >eemaldamine !12_S	et	f	\N
111046	eemaldamist	"eemaldamine %eemalda  )MINE_vS  <eemaldama ;27_V	et	f	\N
111055	haige	haige =haige  (SgN  >haige !01_AS	et	f	\N
111056	haige	haige =haige  (SgG  >haige !01_AS	et	f	\N
111062	nõus	nõus =nõu  (SgIn  >nõu !26_S	et	f	\N
111064	nõus	nõus =nõus  (ID  >nõus !41_D	et	f	\N
111065	õe	õe =õe  (ID  >õe !41_I	et	f	\N
111066	õe	õe =õe  (SgG  >õde !18_S	et	f	\N
111077	surnud	surnud =sur  (PtsPtPs  >surema !36_V	et	f	\N
111078	surnud	surnud =surnu  (PlN  >surnu !01_S	et	f	\N
111079	surnud	"surnu %sur  )NU_vS  <surema ;36_V	et	f	\N
111080	surnud	surnud =surnu  (PlN  >surnu !06_S	et	f	\N
111081	surnud	surnud =surnud  (ID  >surnud !41_A	et	f	\N
111082	surnud	"surnud %sur  )NUD_vA  <surema ;36_V	et	f	\N
111083	päevikusse	päevikusse =päeviku  (SgIll  >päevik !02_S	et	f	\N
111084	päevikusse	päevikusse =kusse  (SgAdt  >päevi+kusi !20_S	et	f	\N
111090	was	### was	et	f	\N
111100	spirit	?spirit =spirit  (SgN  >spirit !02_S	et	f	\N
111108	husband	?husband =husband  (SgN  >husband !02_S	et	f	\N
111113	than	### than	et	f	\N
111124	were	?were =were  (SgN  >were !16_S	et	f	\N
111126	were	?were =were  (SgG  >were !16_S	et	f	\N
111127	were	?were =were  (IndPrPs_  >werema !27_V	et	f	\N
111128	were	?were =were  (ImpPrSg2  >werema !27_V	et	f	\N
111132	living	?living =living  (SgN  >living !02_S	et	f	\N
111144	kõikidele	kõikidele =kõiki  (PlAll  >kõik !00_P	et	f	\N
111145	kõikidele	kõikidele =kõiki  (PlAll  >kõik !22_S	et	f	\N
111151	tähtsus	tähtsus =tähtsus  (SgN  >tähtsus !11~09_S	et	f	\N
111153	tähtsus	"tähtsus %tähtsa  )US_aS  <tähtis ;02_A	et	f	\N
111157	lavastus	lavastus =lavastu  (IndIpfSg3  >lavastuma !27_V	et	f	\N
111158	lavastus	lavastus =lavastus  (SgN  >lavastus !11_S	et	f	\N
111159	lavastus	"lavastus %lavasta  )US_vS  <lavastama ;27_V	et	f	\N
111160	peamistest	peamistest =peamis  (PlEl  >peamine !12?10_A	et	f	\N
111162	peamistest	peamistest =test  (SgN  >pea+mis+test !22_S	et	f	\N
111167	lavastuse	lavastuse =lavastuse  (SgG  >lavastus !11_S	et	f	\N
111168	lavastuse	"lavastus %lavasta  )US_vS  <lavastama ;27_V	et	f	\N
111189	theresa	?theresa =theresa  (SgN  >theresa !01_S	et	f	\N
111190	theresa	?theresa =theresa  (SgG  >theresa !01_S	et	f	\N
111193	pealt	pealt =pea  (SgAbl  >pea !26_S	et	f	\N
111194	pealt	pealt =pealt  (ID  >pealt !41_DK	et	f	\N
111210	kommenteerija	kommenteerija =kommenteerija  (SgN  >kommenteerija !01_S	et	f	\N
111211	kommenteerija	"kommenteerija %kommenteeri  )JA_vS  <kommenteerima ;28_V	et	f	\N
111212	kommenteerija	kommenteerija =kommenteerija  (SgG  >kommenteerija !01_S	et	f	\N
111217	seega	seega =seega  (ID  >seega !41_D	et	f	\N
111218	seega	seega =seega  (IndPrPs_  >seegama !27_V	et	f	\N
111219	seega	seega =seega  (ImpPrSg2  >seegama !27_V	et	f	\N
111227	tunnistajateks	tunnistajateks =tunnistaja  (PlTr  >tunnistaja !01_S	et	f	\N
111228	tunnistajateks	"tunnistaja %tunnista  )JA_vS  <tunnistama ;27_V	et	f	\N
111241	puhkemaja	puhkemaja =maja  (SgN  >puhke+maja !17_S	et	f	\N
111242	puhkemaja	puhkemaja =maja  (SgG  >puhke+maja !17_S	et	f	\N
111244	puhkemaja	puhkemaja =maja  (SgP  >puhke+maja !17_S	et	f	\N
111248	otsisid	otsisid =otsi  (PlP  >ots !22_S	et	f	\N
111249	otsisid	otsisid =otsi  (IndIpfSg2  >otsima !28_V	et	f	\N
111250	otsisid	otsisid =otsi  (IndIpfPl3  >otsima !28_V	et	f	\N
111256	tulu	tulu =tulu  (SgN  >tulu !17_S	et	f	\N
111257	tulu	tulu =tulu  (SgG  >tulu !17_S	et	f	\N
111258	tulu	tulu =tulu  (SgP  >tulu !17_S	et	f	\N
111262	vaatamisväärsusi	vaatamisväärsusi =susi  (SgN  >vaatamis+väär+susi !15_S	et	f	\N
111263	vaatamisväärsusi	vaatamisväärsusi =susi  (PlP  >vaatamis+väär+susi !15_S	et	f	\N
111265	vaatamisväärsusi	vaatamisväärsusi =väärsusi  (PlP  >vaatamis+väärsus !11_S	et	f	\N
111267	vaatamisväärsusi	"vaatamis+väärsus %väärse  )US_aS  <vaatamis+väärne ;02_A	et	f	\N
111281	sõnast	sõnast =sõna  (SgEl  >sõna !17_S	et	f	\N
111282	sõnast	sõnast =sõnas  (SgP  >sõnane !10_A	et	f	\N
111284	sõnast	"sõnane %sõna  )NE_aA  <sõna ;17_S	et	f	\N
111289	ühis	?ühis =ühi  (SgIn  >ühi !17_S	et	f	\N
111290	ühis	?ühis =ühi  (IndIpfSg3  >ühima !27_V	et	f	\N
111292	ühis	?ühis =ühis  (SgN  >ühis !09_S	et	f	\N
111300	eisen	?eisen =eise  (IndPrSg1  >eisema !28_V	et	f	\N
111301	eisen	?eisen =eisen  (SgN  >eisen !02_S	et	f	\N
111302	daani	?daani =daa  (SgTer  >daa !26_S	et	f	\N
111304	daani	?daani =daani  (SgN  >daani !16_S	et	f	\N
110955	last	last =last  (SgN  >last !22_S	et	f	\N
110959	laura	?laura =laura  (SgN  >laura !16_S	et	f	\N
110960	laura	?laura =laura  (SgG  >laura !16_S	et	f	\N
110961	laura	?laura =laura  (IndPrPs_  >laurama !29_V	et	f	\N
110963	laura	?laura =laura  (ImpPrSg2  >laurama !29_V	et	f	\N
110966	kotkas	kotkas =kotka  (SgIn  >kotkas !07_S	et	f	\N
110967	kotkas	kotkas =kotkas  (SgN  >kotkas !07_S	et	f	\N
110968	oluline	oluline =oluline  (SgN  >oluline !12_A	et	f	\N
110969	oluline	"oluline %olu  )LINE_aA  <olu ;17_S	et	f	\N
110970	taha	taha =taha  (ID  >taha !41_DK	et	f	\N
110971	taha	taha =taha  (IndPrPs_  >tahtma !34_V	et	f	\N
110972	taha	taha =taha  (ImpPrSg2  >tahtma !34_V	et	f	\N
111003	prahas	?prahas =praha  (SgIn  >praha !17_S	et	f	\N
111004	prahas	?prahas =praha  (IndIpfSg3  >prahama !27_V	et	f	\N
111005	prahas	?prahas =prahas  (SgN  >prahas !09_S	et	f	\N
111010	minona	?minona =mino  (SgEs  >mino !17~16_S	et	f	\N
111015	pidanud	pidanud =pida  (PtsPtPs  >pida !40_V	et	f	\N
111016	pidanud	pidanud =pida  (PtsPtPs  >pidama !28_V	et	f	\N
111018	pidanud	"pidanu %pida  )NU_vS  <pida ;40_V	et	f	\N
111019	pidanud	"pidanud %pida  )NUD_vA  <pida ;40_V	et	f	\N
111032	harva	harva =harva  (ID  >harva !41_D	et	f	\N
111033	harva	harva =harva  (SgG  >harv !22_A	et	f	\N
111034	harva	harva =harva  (SgP  >harv !22_A	et	f	\N
111035	harva	harva =harva  (SgAdt  >harv !22_A	et	f	\N
111047	lauast	lauast =laua  (SgEl  >laud !22_S	et	f	\N
111048	lauast	lauast =lauas  (SgP  >lauane !10_A	et	f	\N
111049	lauast	"lauane %laua  )NE_aA  <laud ;22_S	et	f	\N
111050	lauast	lauast =ast  (SgN  >lau+ast !22_S	et	f	\N
111075	aastasena	aastasena =aastase  (SgEs  >aastane !12~10_A	et	f	\N
111076	aastasena	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
111089	dream	?dream =dream  (SgN  >dream !22_S	et	f	\N
111094	house	?house =house  (SgN  >house !06_S	et	f	\N
111096	house	?house =house  (SgG  >house !06_S	et	f	\N
111098	house	?house =house  (PlP  >hous !22_S	et	f	\N
111099	house	?house =house  (IndPrPs_  >housema !28_V	et	f	\N
111101	house	?house =house  (ImpPrSg2  >housema !28_V	et	f	\N
111104	deym	?deym =deym  (SgN  >deym !22_S	et	f	\N
111109	she	### she	et	f	\N
111121	josephines	?josephines =josephine  (PlIn  >josephin !19_S	et	f	\N
111129	born	?born =born  (SgN  >born !22_S	et	f	\N
111131	other	?other =other  (SgN  >other !02_S	et	f	\N
111134	forgot	?forgot =forgo  (SgP  >forgo !16_S	et	f	\N
111135	forgot	?forgot =forgot  (SgN  >forgot !02_S	et	f	\N
111146	vastuseks	vastuseks =vastuse  (SgTr  >vastus !09_S	et	f	\N
111147	vastuseks	vastuseks =seks  (SgN  >vastu+seks !22_S	et	f	\N
111148	vastuseks	vastuseks =use  (PlTr  >vast+usk !22_S	et	f	\N
111161	pärildest	?pärildest =pärildes  (SgP  >pärildene !12_A	et	f	\N
111169	näidata	näidata =näida  (Inf  >näitama !29_V	et	f	\N
111170	näidata	näidata =näida  (IndPrIps_  >näitama !29_V	et	f	\N
111173	loeksid	loeksid =loe  (KndPrSg2  >lugema !28_V	et	f	\N
111174	loeksid	loeksid =loe  (KndPrPl3  >lugema !28_V	et	f	\N
111202	loole	loole =loo  (SgAll  >lugu !18_S	et	f	\N
111203	loole	loole =loo  (SgAll  >loog !22_S	et	f	\N
111204	loole	loole =loo  (SgAll  >lood !22_S	et	f	\N
111220	loota	loota =loo  (SgAb  >lugu !18_S	et	f	\N
111221	loota	loota =loo  (SgAb  >loog !22_S	et	f	\N
111222	loota	loota =loo  (SgAb  >lood !22_S	et	f	\N
111223	loota	loota =loot  (Inf  >lootma !34_V	et	f	\N
111253	teised	teised =teise  (PlN  >teine !12_OP	et	f	\N
111255	teised	teised =teise  (PlN  >teise !12_P	et	f	\N
111273	kandja	kandja =kandja  (SgN  >kandja !01_S	et	f	\N
111274	kandja	"kandja %kand  )JA_vS  <kandma ;34_V	et	f	\N
111275	kandja	kandja =kandja  (SgG  >kandja !01_S	et	f	\N
111283	harkko	?harkko =harkko  (SgN  >harkko !16_S	et	f	\N
111285	harkko	?harkko =harkko  (SgG  >harkko !16_S	et	f	\N
111334	toeta	toeta =toe  (SgAb  >tugi !21_S	et	f	\N
111335	toeta	toeta =toeta  (IndPrPs_  >toetama !27_V	et	f	\N
111336	toeta	toeta =toeta  (ImpPrSg2  >toetama !27_V	et	f	\N
111342	harkua	?harkua =harkua  (SgN  >harkua !01_S	et	f	\N
111343	harkua	?harkua =harkua  (SgG  >harkua !01_S	et	f	\N
111346	harkut	?harkut =harku  (SgP  >harku !16_S	et	f	\N
111347	harkut	?harkut =harkut  (SgN  >harkut !02_S	et	f	\N
111350	seoses	seoses =seose  (SgIn  >seos !09_S	et	f	\N
111351	seoses	seoses =seoses  (ID  >seoses !41_K	et	f	\N
111372	frederik	?frederik =frederik  (SgN  >frederik !25_S	et	f	\N
111383	theodoricus	?theodoricus =theodoricus  (SgN  >theodoricus !11?09_S	et	f	\N
111385	rida	rida =rida  (SgN  >rida !18_S	et	f	\N
111386	rida	rida =rida  (SgP  >rida !18_S	et	f	\N
111393	kandjaid	kandjaid =kandja  (PlP  >kandja !01_S	et	f	\N
111394	kandjaid	"kandja %kand  )JA_vS  <kandma ;34_V	et	f	\N
111400	liignimi	?liignimi =liignimi  (SgN  >liignimi !01_S	et	f	\N
111402	liignimi	?liignimi =liignimi  (SgG  >liignimi !01_S	et	f	\N
111404	liignimi	?liignimi =liignimi  (SgG  >liignim !02_A	et	f	\N
111406	pärineval	pärineval =pärineva  (SgAd  >pärinev !02_A	et	f	\N
111143	ongi	ongi =on  (IndPrPl3^  >olema !36_V	et	f	\N
111149	tänapäeva	tänapäeva =päeva  (SgG  >täna+päev !22_S	et	f	\N
111150	tänapäeva	tänapäeva =päeva  (SgP  >täna+päev !22_S	et	f	\N
111152	tänapäeva	tänapäeva =päeva  (SgAdt  >täna+päev !22_S	et	f	\N
111175	monolooge	monolooge =monolooge  (PlP  >monoloog !22_S	et	f	\N
111176	monolooge	monolooge =looge  (SgN  >mono+looge !06_S	et	f	\N
111177	monolooge	monolooge =looge  (PlP  >mono+loog !22_S	et	f	\N
111178	mängiksid	mängiksid =mängi  (KndPrSg2  >mängima !28_V	et	f	\N
111179	mängiksid	mängiksid =mängi  (KndPrPl3  >mängima !28_V	et	f	\N
111180	lühikesi	lühikesi =lühikesi  (PlP  >lühike !12_A	et	f	\N
111181	lühikesi	"lühike %lühi  )KE_dS  <lüht ;22_S	et	f	\N
111182	lühikesi	lühikesi =lühikesi  (PlP  >lühikene !12_S	et	f	\N
111183	lühikesi	"lühikene %lühi  )KENE_dS  <lüht ;22_S	et	f	\N
111187	plaanid	plaanid =plaani  (PlN  >plaan !22_S	et	f	\N
111188	plaanid	plaanid =plaani  (IndPrSg2  >plaanima !28_V	et	f	\N
111195	nägija	nägija =nägija  (SgN  >nägija !01_S	et	f	\N
111196	nägija	"nägija %nägi  )JA_vS  <nägema ;28_V	et	f	\N
111197	nägija	nägija =nägija  (SgG  >nägija !01_S	et	f	\N
111207	jutustaja	jutustaja =jutustaja  (SgN  >jutustaja !01_S	et	f	\N
111208	jutustaja	"jutustaja %jutusta  )JA_vS  <jutustama ;27_V	et	f	\N
111209	jutustaja	jutustaja =jutustaja  (SgG  >jutustaja !01_S	et	f	\N
111215	olemas	olemas =ole  (SupIn  >olema !36_V	et	f	\N
111216	olemas	olemas =olema  (SgIn  >olem !02_S	et	f	\N
111233	ajalooga	ajalooga =loo  (SgKom  >aja+lugu !18_S	et	f	\N
111234	ajalooga	ajalooga =loo  (SgKom  >aja+loog !22_S	et	f	\N
111236	ajalooga	ajalooga =loo  (SgKom  >aja+lood !22_S	et	f	\N
111238	ajalooga	ajalooga =looga  (SgG  >aja+look !22_S	et	f	\N
111243	vangla	vangla =vangla  (SgN  >vangla !01_S	et	f	\N
111245	vangla	vangla =vangla  (SgG  >vangla !01_S	et	f	\N
111251	lõbu	lõbu =lõbu  (SgN  >lõbu !17_S	et	f	\N
111252	lõbu	lõbu =lõbu  (SgG  >lõbu !17_S	et	f	\N
111254	lõbu	lõbu =lõbu  (SgP  >lõbu !17_S	et	f	\N
111270	nimetuse	nimetuse =nimetuse  (SgG  >nimetus !11_S	et	f	\N
111271	nimetuse	"nimetus %nimeta  )US_vS  <nimetama ;27_V	et	f	\N
111272	nimetuse	"nimetus %nime  )TUS2_aS  <nimi ;20_S	et	f	\N
111295	enne	enne =enne  (ID  >enne !41_DK	et	f	\N
111296	enne	enne =enne  (SgN  >enne !06_S	et	f	\N
111314	veetammi	veetammi =tammi  (SgG  >vee+tamm !22_S	et	f	\N
111315	veetammi	veetammi =tammi  (SgP  >vee+tamm !22_S	et	f	\N
111316	veetammi	veetammi =tammi  (SgAdt  >vee+tamm !22_S	et	f	\N
111317	veetammi	veetammi =tammi  (PlP  >vee+tamm !22_S	et	f	\N
111352	ristimisega	ristimisega =ristimise  (SgKom  >ristimine !12_S	et	f	\N
111353	ristimisega	"ristimine %risti  )MINE_vS  <ristima ;28_V	et	f	\N
111380	pojale	pojale =poja  (SgAll  >poja !17_S	et	f	\N
111381	pojale	pojale =poja  (SgAll  >poeg !22_S	et	f	\N
111408	talupojad	talupojad =poja  (PlN  >talu+poja !17_S	et	f	\N
111409	talupojad	talupojad =poja  (PlN  >talu+poeg !22_S	et	f	\N
111414	katku	katku =kat  (ImpPrPs  >katma !35_V	et	f	\N
111415	katku	katku =katku  (SgG  >katk !22_S	et	f	\N
111416	katku	katku =katku  (SgP  >katk !22_S	et	f	\N
111417	katku	katku =katku  (SgAdt  >katk !22_S	et	f	\N
111418	katku	katku =katku  (IndPrPs_  >katkuma !28_V	et	f	\N
111420	katku	katku =katku  (ImpPrSg2  >katkuma !28_V	et	f	\N
111425	liivi	liivi =liivi  (SgG  >liiv !22_S	et	f	\N
111426	liivi	liivi =liivi  (SgP  >liiv !22_S	et	f	\N
111428	liivi	liivi =liivi  (SgAdt  >liiv !22_S	et	f	\N
111429	komtuurile	komtuurile =komtuuri  (SgAll  >komtuur !22_S	et	f	\N
111430	komtuurile	komtuurile =tuuri  (SgAll  >kom+tuur !22_S	et	f	\N
111432	komtuurile	komtuurile =tuuri  (PlAll  >kom+tuur !22_S	et	f	\N
111446	müüs	müüs =müü  (IndIpfSg3  >müüma !38_V	et	f	\N
111447	müüs	müüs =müü  (SgIn  >müü !26_S	et	f	\N
111454	piirkonnas	piirkonnas =piirkonna  (SgIn  >piirkond !22_S	et	f	\N
111456	piirkonnas	piirkonnas =konna  (SgIn  >piir+konn !22_S	et	f	\N
111459	liitmistele	liitmistele =liitmis  (PlAll  >liitmine !12?10_S	et	f	\N
111460	liitmistele	"liitmine %liit  )MINE_vS  <liitma ;34_V	et	f	\N
111487	tühjaksjäänud	tühjaksjäänud =jäänu  (PlN  >tühjaks+jäänu !01_S	et	f	\N
111488	tühjaksjäänud	tühjaksjäänud =jäänu  (PlN  >tühjaks+jäänu !06_S	et	f	\N
111497	scheiding	?scheiding =scheiding  (SgN  >scheiding !02_S	et	f	\N
111508	omanikuks	omanikuks =omaniku  (SgTr  >omanik !25_S	et	f	\N
111509	omanikuks	omanikuks =uks  (SgN  >omanik+uks !14_S	et	f	\N
111518	baueri	?baueri =baueri  (SgN  >baueri !01_S	et	f	\N
111519	baueri	?baueri =baueri  (SgG  >baueri !01_S	et	f	\N
111520	baueri	?baueri =baueri  (SgG  >bauer !02_S	et	f	\N
111521	baueri	?baueri =baueri  (IndPrPs_  >bauerima !28_V	et	f	\N
111522	baueri	?baueri =baueri  (ImpPrSg2  >bauerima !28_V	et	f	\N
111535	alistusid	alistusid =alistu  (IndIpfSg2  >alistuma !27_V	et	f	\N
111537	alistusid	alistusid =alistu  (IndIpfPl3  >alistuma !27_V	et	f	\N
111544	eestimaal	eestimaal =maa  (SgAd  >eesti+maa !26_S	et	f	\N
111545	eestimaal	eestimaal =maal  (SgN  >eesti+maal !22_S	et	f	\N
111154	muuseumi	muuseumi =muuseumi  (SgG  >muuseum !19~02_S	et	f	\N
111155	muuseumi	muuseumi =muuseumi  (SgP  >muuseum !19_S	et	f	\N
111156	muuseumi	muuseumi =muuseumi  (SgAdt  >muuseum !19_S	et	f	\N
111163	põhjal	põhjal =põhja  (SgAd  >põhi !24_S	et	f	\N
111164	põhjal	põhjal =põhjal  (ID  >põhjal !41_K	et	f	\N
111165	tahetakse	tahetakse =tahe  (IndPrIps  >tahtma !34_V	et	f	\N
111166	tahetakse	tahetakse =takse  (PlP  >tahe+taks !22_S	et	f	\N
111171	seonduvaid	seonduvaid =seonduva  (PlP  >seonduv !02_A	et	f	\N
111172	seonduvaid	"seonduv %seondu  )V_vA  <seonduma ;27_V	et	f	\N
111213	keelde	keelde =keel  (SgAdt  >keel !13_S	et	f	\N
111214	keelde	keelde =keelde  (PlP  >keeld !22_S	et	f	\N
111224	saavad	saavad =saa  (IndPrPl3  >saama !37_V	et	f	\N
111225	saavad	saavad =saava  (PlN  >saav !02_A	et	f	\N
111226	saavad	"saav %saa  )V_vA  <saama ;37_V	et	f	\N
111229	saladustele	saladustele =saladus  (PlAll  >saladus !11_S	et	f	\N
111230	saladustele	saladustele =duste  (PlAll  >sala+dust !22_S	et	f	\N
111235	hoone	hoone =hoone  (SgN  >hoone !06_S	et	f	\N
111237	hoone	"hoone %hoo  )NE_aA  <hoog ;22_S	et	f	\N
111239	hoone	hoone =hoone  (SgG  >hoone !06_S	et	f	\N
111240	hoone	hoone =hoone  (PlP  >hoon !22_A	et	f	\N
111246	müüdi	müüdi =müü  (IndIpfIps  >müüma !38_V	et	f	\N
111247	müüdi	müüdi =müüdi  (SgG  >müüt !22_S	et	f	\N
111259	vaidlemata	vaidlemata =vaidle  (SupAb  >vaidlema !30_V	et	f	\N
111260	vaidlemata	vaidlemata =vaidlemata  (ID  >vaidlemata !41_A	et	f	\N
111261	vaidlemata	"vaidlemata %vaidle  )MATA_vA  <vaidlema ;30_V	et	f	\N
111264	kuulsamaid	kuulsamaid =kuulsama  (PlP  >kuulsam !02_A	et	f	\N
111266	kuulsamaid	"kuulsam %kuulsa  )M_cA  <kuulus ;02_A	et	f	\N
111276	nimetus	nimetus =nimetu  (SgIn  >nimetu !01_A	et	f	\N
111277	nimetus	"nimetu %nime  )TU2_kA  <nimi ;20_S	et	f	\N
111278	nimetus	nimetus =nimetus  (SgN  >nimetus !11_S	et	f	\N
111279	nimetus	"nimetus %nimeta  )US_vS  <nimetama ;27_V	et	f	\N
111280	nimetus	"nimetus %nime  )TUS2_aS  <nimi ;20_S	et	f	\N
111286	arvata	arvata =arva  (Inf  >arvama !29_V	et	f	\N
111287	arvata	arvata =arva  (IndPrIps_  >arvama !29_V	et	f	\N
111288	arvata	arvata =arvata  (ID  >arvata !41_D	et	f	\N
111291	ajastust	ajastust =ajastu  (SgEl  >ajastu !01_S	et	f	\N
111293	ajastust	ajastust =ajastus  (SgP  >ajastus !11_S	et	f	\N
111294	ajastust	"ajastus %ajasta  )US_vS  <ajastama ;27_V	et	f	\N
111297	mathias	?mathias =mathia  (SgIn  >mathia !01_S	et	f	\N
111298	mathias	?mathias =mathias  (SgN  >mathias !11_S	et	f	\N
111303	hindamise	hindamise =hindamise  (SgG  >hindamine !12_S	et	f	\N
111305	hindamise	"hindamine %hinda  )MINE_vS  <hindama ;29_V	et	f	\N
111324	öeldut	öeldut =öeldu  (SgP  >öeldu !01_S	et	f	\N
111325	öeldut	"öeldu %öel  )TU1_vS  <ütlema ;30_V	et	f	\N
111337	nimetatud	nimetatud =nimeta  (PtsPtIps  >nimetama !27_V	et	f	\N
111338	nimetatud	nimetatud =nimetatu  (PlN  >nimetatu !01_S	et	f	\N
111339	nimetatud	"nimetatu %nimeta  )TU1_vS  <nimetama ;27_V	et	f	\N
111340	nimetatud	nimetatud =nimetatud  (ID  >nimetatud !41_A	et	f	\N
111341	nimetatud	"nimetatud %nimeta  )TUD_vA  <nimetama ;27_V	et	f	\N
111344	esmakordselt	esmakordselt =kordse  (SgAbl  >esma+kordne !02_AS	et	f	\N
111345	esmakordselt	"esma+kordselt %kordse  )LT_mD  <esma+kordne ;02_AS	et	f	\N
111354	korraldatud	korraldatud =korralda  (PtsPtIps  >korraldama !27_V	et	f	\N
111356	korraldatud	korraldatud =korraldatu  (PlN  >korraldatu !01_S	et	f	\N
111358	korraldatud	"korraldatu %korralda  )TU1_vS  <korraldama ;27_V	et	f	\N
111359	korraldatud	korraldatud =korraldatud  (ID  >korraldatud !41_A	et	f	\N
111360	korraldatud	"korraldatud %korralda  )TUD_vA  <korraldama ;27_V	et	f	\N
111368	ilmusid	ilmusid =ilmu  (IndIpfSg2  >ilmuma !27_V	et	f	\N
111369	ilmusid	ilmusid =ilmu  (IndIpfPl3  >ilmuma !27_V	et	f	\N
111376	harkele	?harkele =harke  (SgAll  >harge !06_S	et	f	\N
111377	harkele	?harkele =harkele  (IndPrPs_  >harkelema !27_V	et	f	\N
111378	harkele	?harkele =harkele  (ImpPrSg2  >harkelema !27_V	et	f	\N
111379	tilo	?tilo =tilo  (SgN  >tilo !17~16_S	et	f	\N
111382	tilo	?tilo =tilo  (SgG  >tilo !17~16_S	et	f	\N
111384	tilo	?tilo =tilo  (SgP  >tilo !17_S	et	f	\N
111387	terve	terve =terve  (SgN  >terve !01_AS	et	f	\N
111388	terve	terve =terve  (SgN  >terve !06_AS	et	f	\N
111389	terve	terve =terve  (SgG  >terve !01_AS	et	f	\N
111390	terve	terve =terve  (SgG  >terve !06_AS	et	f	\N
111448	toddeven	?toddeven =toddeven  (SgN  >toddeven !19_S	et	f	\N
111453	lääne	lääne =lääne  (SgG  >lääs !14_S	et	f	\N
111458	lääne	lääne =lääne  (PlP  >lään !22_S	et	f	\N
111461	lähedal	lähedal =läheda  (SgAd  >läheda !02_A	et	f	\N
111462	lähedal	lähedal =lähedal  (ID  >lähedal !41_DK	et	f	\N
111463	kotipere	kotipere =pere  (SgN  >koti+pere !16_S	et	f	\N
111464	kotipere	kotipere =pere  (SgG  >koti+pere !16_S	et	f	\N
111467	teatavat	teatavat =tea  (KvtPrIps  >teadma !34_V	et	f	\N
111469	teatavat	teatavat =teata  (KvtPrPs  >teatama !27_V	et	f	\N
111471	teatavat	teatavat =teatava  (SgP  >teatav !02_A	et	f	\N
111472	teatavat	"teatav %tea  )TAV_vAS  <teadma ;34_V	et	f	\N
111200	erapooletu	erapooletu =pooletu  (SgN  >era+pooletu !01_A	et	f	\N
111201	erapooletu	erapooletu =pooletu  (SgG  >era+pooletu !01_A	et	f	\N
111205	pealtnägija	pealtnägija =nägija  (SgN  >pealt+nägija !01_S	et	f	\N
111206	pealtnägija	pealtnägija =nägija  (SgG  >pealt+nägija !01_S	et	f	\N
111231	ajalugu	ajalugu =lugu  (SgN  >aja+lugu !18_S	et	f	\N
111232	ajalugu	ajalugu =lugu  (SgP  >aja+lugu !18_S	et	f	\N
111268	sellepoolest	sellepoolest =poole  (PlEl  >selle+pool !22_S	et	f	\N
111269	sellepoolest	sellepoolest =pooles  (SgP  >selle+poolene !10_A	et	f	\N
111299	johann	?johann =johann  (SgN  >johann !22_S	et	f	\N
111326	sõna	sõna =sõna  (SgN  >sõna !17_S	et	f	\N
111327	sõna	sõna =sõna  (SgG  >sõna !17_S	et	f	\N
111328	sõna	sõna =sõna  (SgP  >sõna !17_S	et	f	\N
111329	sõna	sõna =sõna  (IndPrPs_  >sõnama !27_V	et	f	\N
111330	sõna	sõna =sõna  (ImpPrSg2  >sõnama !27_V	et	f	\N
111355	poolt	poolt =pool  (SgP  >pool !13_NS	et	f	\N
111357	poolt	poolt =poolt  (ID  >poolt !41_DK	et	f	\N
111361	juuni-	juuni- =juuni  (SgN  >juuni !16_S	et	f	\N
111362	juuni-	juuni- =juuni  (SgG  >juuni !16_S	et	f	\N
111363	rahno	?rahno =rahno  (SgN  >rahno !16_S	et	f	\N
111364	rahno	?rahno =rahno  (SgG  >rahno !16_S	et	f	\N
111370	ficke	?ficke =ficke  (SgN  >ficke !06_S	et	f	\N
111371	ficke	?ficke =ficke  (SgG  >ficke !06_S	et	f	\N
111373	ficke	?ficke =ficke  (PlP  >fick !22_S	et	f	\N
111374	ficke	?ficke =ficke  (IndPrPs_  >fickema !27_V	et	f	\N
111375	ficke	?ficke =ficke  (ImpPrSg2  >fickema !27_V	et	f	\N
111395	enam	enam =enam  (ID  >enam !41_D	et	f	\N
111396	enam	enam =enam  (SgN  >enam !02_A	et	f	\N
111419	claves	?claves =clave  (SgIn  >clave !16_S	et	f	\N
111421	claves	?claves =clave  (IndIpfSg3  >clavema !27_V	et	f	\N
111422	claves	?claves =claves  (SgN  >claves !09_S	et	f	\N
111431	alluv	alluv =allu  (PtsPrPs  >alluma !27_V	et	f	\N
111433	alluv	alluv =alluv  (SgN  >alluv !02_AS	et	f	\N
111434	alluv	"alluv %allu  )V_vA  <alluma ;27_V	et	f	\N
111435	märgitakse	märgitakse =märgi  (IndPrIps  >märkima !28_V	et	f	\N
111436	märgitakse	märgitakse =takse  (PlP  >märgi+taks !22_S	et	f	\N
111478	adolf	?adolf =adolf  (SgN  >adolf !22_S	et	f	\N
111485	kroonikates	kroonikates =kroonika  (PlIn  >kroonika !01_S	et	f	\N
111486	kroonikates	kroonikates =kate  (PlIn  >krooni+katt !22_S	et	f	\N
111491	levinud	levinud =levi  (PtsPtPs  >levima !27_V	et	f	\N
111492	levinud	levinud =levinu  (PlN  >levinu !01_S	et	f	\N
111493	levinud	"levinu %levi  )NU_vS  <levima ;27_V	et	f	\N
111494	levinud	levinud =levinud  (ID  >levinud !41_A	et	f	\N
111495	levinud	"levinud %levi  )NUD_vA  <levima ;27_V	et	f	\N
111501	seisva	seisva =seisva  (SgG  >seisev !02_A	et	f	\N
111502	seisva	"seisev %seis  )V_vA  <seisma ;32_V	et	f	\N
111510	mõisahoones	mõisahoones =hoone  (SgIn  >mõisa+hoone !06_S	et	f	\N
111511	mõisahoones	"mõisa+hoone %hoo  )NE_aA  <mõisa+hoog ;22_S	et	f	\N
111512	mõisahoones	mõisahoones =hoone  (PlIn  >mõisa+hoon !22_A	et	f	\N
111533	rüütelkond	?rüütelkond =rüütelkond  (SgN  >rüütelkond !22_S	et	f	\N
111534	rüütelkond	?rüütelkond =ond  (SgN  >rüü+telk+ond !22_S	et	f	\N
111536	rüütelkond	?rüütelkond =telkond  (SgN  >rüü+telkond !22_S	et	f	\N
111553	constantin	?constantin =constantin  (SgN  >constantin !19_S	et	f	\N
111555	sternberg	?sternberg =sternberg  (SgN  >sternberg !02_S	et	f	\N
111576	xix	### xix	et	f	\N
111584	ette	ette =e  (SgAdt  >esi !15_S	et	f	\N
111585	ette	ette =ette  (ID  >ette !41_DK	et	f	\N
111619	levis	levis =levi  (SgIn  >levi !17_S	et	f	\N
111620	levis	levis =levi  (IndIpfSg3  >levima !27_V	et	f	\N
111621	segatud	segatud =sega  (PtsPtIps  >segama !27_V	et	f	\N
111622	segatud	segatud =segatu  (PlN  >segatu !01_AS	et	f	\N
111623	segatud	"segatu %sega  )TU1_vS  <segama ;27_V	et	f	\N
111624	segatud	segatud =segatud  (ID  >segatud !41_A	et	f	\N
111625	segatud	"segatud %sega  )TUD_vA  <segama ;27_V	et	f	\N
111645	sisse	sisse =si  (SgIll  >si !26_S	et	f	\N
111646	sisse	sisse =sisse  (ID  >sisse !41_DK	et	f	\N
111647	sisse	sisse =sisse  (PlP  >siss !22_S	et	f	\N
111652	põldroos	põldroos =roo  (SgIn  >põld+rood !22_S	et	f	\N
111653	põldroos	põldroos =roo  (SgIn  >põld+roog !22_S	et	f	\N
111654	põldroos	põldroos =roo  (SgIn  >põld+roo !26_S	et	f	\N
111655	põldroos	põldroos =roos  (SgN  >põld+roos !22_S	et	f	\N
111656	otsima	otsima =otsi  (Sup  >otsima !28_V	et	f	\N
111657	otsima	otsima =ima  (SgN  >ots+ima !17_S	et	f	\N
111658	otsima	otsima =ima  (SgG  >ots+ima !17_S	et	f	\N
111659	otsima	otsima =ima  (SgP  >ots+ima !17_S	et	f	\N
111673	puuduvad	puuduvad =puudu  (IndPrPl3  >puuduma !27_V	et	f	\N
111674	puuduvad	puuduvad =puuduva  (PlN  >puuduv !02_A	et	f	\N
111675	puuduvad	"puuduv %puudu  )V_vA  <puuduma ;27_V	et	f	\N
111686	looma	looma =loo  (Sup  >looma !38_V	et	f	\N
111688	looma	looma =looma  (SgG  >loom !22_S	et	f	\N
111690	looma	looma =looma  (SgP  >loom !22_S	et	f	\N
111691	looma	looma =looma  (SgAdt  >loom !22_S	et	f	\N
111715	paiku	paiku =paiku  (ID  >paiku !41_K	et	f	\N
111306	daani	?daani =daani  (SgG  >daani !16_S	et	f	\N
111307	daani	?daani =daani  (SgG  >daan !22_S	et	f	\N
111308	daani	?daani =daani  (SgP  >daan !22_S	et	f	\N
111309	daani	?daani =daani  (SgAdt  >daan !22_S	et	f	\N
111310	daani	?daani =daani  (IndPrPs_  >daanima !28_V	et	f	\N
111311	daani	?daani =daani  (ImpPrSg2  >daanima !28_V	et	f	\N
111312	agu	agu =agu  (SgN  >agu !18_S	et	f	\N
111313	agu	agu =agu  (SgP  >agu !18_S	et	f	\N
111318	raamatus	raamatus =raamatu  (SgIn  >raamat !02_S	et	f	\N
111319	raamatus	raamatus =atu  (SgIn  >raam+att !22_S	et	f	\N
111320	keila-	?keila- =keila  (SgN  >keila !16_S	et	f	\N
111321	keila-	?keila- =keila  (SgG  >keila !16_S	et	f	\N
111322	keila-	?keila- =keila  (IndPrPs_  >keilama !29_V	et	f	\N
111323	keila-	?keila- =keila  (ImpPrSg2  >keilama !29_V	et	f	\N
111331	metalli-	metalli- =metalli  (SgG  >metall !22_S	et	f	\N
111332	metalli-	metalli- =metalli  (SgP  >metall !22_S	et	f	\N
111333	metalli-	metalli- =metalli  (SgAdt  >metall !22_S	et	f	\N
111348	hindamisraamatus	hindamisraamatus =atu  (SgIn  >hinda+mis+raam+att !22_S	et	f	\N
111349	hindamisraamatus	hindamisraamatus =raamatu  (SgIn  >hinda+mis+raamat !02_S	et	f	\N
111365	ajaloost	ajaloost =loo  (SgEl  >aja+lugu !18_S	et	f	\N
111366	ajaloost	ajaloost =loo  (SgEl  >aja+loog !22_S	et	f	\N
111367	ajaloost	ajaloost =loo  (SgEl  >aja+lood !22_S	et	f	\N
111391	nime	nime =nime  (SgG  >nimi !20_S	et	f	\N
111392	nime	nime =nime  (SgP  >nimi !20_S	et	f	\N
111397	märgitud	märgitud =märgi  (PtsPtIps  >märkima !28_V	et	f	\N
111398	märgitud	märgitud =märgitu  (PlN  >märgitu !01_AS	et	f	\N
111399	märgitud	"märgitu %märgi  )TU1_vS  <märkima ;28_V	et	f	\N
111401	märgitud	"märgitu %märgi  )TU2_kA  <märk ;22_S	et	f	\N
111403	märgitud	märgitud =märgitud  (ID  >märgitud !41_A	et	f	\N
111405	märgitud	"märgitud %märgi  )TUD_vA  <märkima ;28_V	et	f	\N
111437	brieflades	### brieflades	et	f	\N
111438	koha	koha =koha  (SgN  >koha !17_S	et	f	\N
111439	koha	koha =koha  (SgG  >koha !17_S	et	f	\N
111440	koha	koha =koha  (SgG  >koht !22_S	et	f	\N
111441	koha	koha =koha  (SgP  >koha !17_S	et	f	\N
111442	koha	koha =koha  (IndPrPs_  >kohama !27_V	et	f	\N
111443	koha	koha =koha  (ImpPrSg2  >kohama !27_V	et	f	\N
111451	mekesele	?mekesele =mekese  (SgAll  >mekene !10_A	et	f	\N
111452	mekesele	?mekesele =mekesele  (PlP  >mekesel !19_S	et	f	\N
111455	toimuvate	toimuvate =toimuva  (PlG  >toimuv !02_A	et	f	\N
111457	toimuvate	"toimuv %toimu  )V_vA  <toimuma ;27_V	et	f	\N
111479	vatsla	?vatsla =vatsla  (SgN  >vatsla !01_S	et	f	\N
111480	vatsla	?vatsla =vatsla  (SgG  >vatsla !01_S	et	f	\N
111481	vatsla	?vatsla =vatsla  (IndPrPs_  >vatslama !29_V	et	f	\N
111482	vatsla	?vatsla =vatsla  (ImpPrSg2  >vatslama !29_V	et	f	\N
111496	philipp	?philipp =philipp  (SgN  >philipp !22_S	et	f	\N
111498	tühjalt	tühjalt =tühja  (SgAbl  >tühi !24_A	et	f	\N
111499	tühjalt	tühjalt =tühjalt  (ID  >tühjalt !41_D	et	f	\N
111500	tühjalt	"tühjalt %tühja  )LT_mD  <tühi ;24_A	et	f	\N
111517	felix	### felix	et	f	\N
111523	kirjutakse	?kirjutakse =kirju  (IndPrIps  >kirjuma !27_V	et	f	\N
111524	kirjutakse	?kirjutakse =kirjutakse  (SgG  >kirjutakne !02_A	et	f	\N
111525	kirjutakse	?kirjutakse =kirjutakse  (PlP  >kirjutaks !22_S	et	f	\N
111527	rootsi	rootsi =rootsi  (ID  >rootsi !41_G	et	f	\N
111528	rootsi	rootsi =rootsi  (SgG  >roots !22_S	et	f	\N
111530	rootsi	rootsi =rootsi  (SgP  >roots !22_S	et	f	\N
111531	rootsi	rootsi =rootsi  (SgAdt  >roots !22_S	et	f	\N
111554	ungern	?ungern =ungern  (SgN  >ungern !22_S	et	f	\N
111631	välismaale	välismaale =maa  (SgAll  >välis+maa !26_S	et	f	\N
111632	välismaale	välismaale =maale  (PlP  >välis+maal !22_S	et	f	\N
111650	julius	?julius =juliu  (SgIn  >juliu !01_S	et	f	\N
111651	julius	?julius =julius  (SgN  >julius !11_S	et	f	\N
111666	1895-	### 1895-	et	f	\N
111669	vilhelm	?vilhelm =vilhelm  (SgN  >vilhelm !22_S	et	f	\N
111672	arhiivandmed	### arhiivandmed	et	f	\N
111676	huvitavaid	huvitavaid =huvitava  (PlP  >huvitav !02_A	et	f	\N
111677	huvitavaid	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
111680	ratsahobune	ratsahobune =hobune  (SgN  >ratsa+hobune !10_S	et	f	\N
111681	ratsahobune	"ratsa+hobune %hobu  )NE_aA  <ratsa+hobu ;17_S	et	f	\N
111692	püstitati	püstitati =püstita  (IndIpfIps  >püstitama !27_V	et	f	\N
111693	püstitati	püstitati =tati  (SgG  >püsti+tatt !22_S	et	f	\N
111694	püha	püha =püha  (SgN  >püha !17_SA	et	f	\N
111695	püha	püha =püha  (SgG  >püha !17_SA	et	f	\N
111696	püha	püha =püha  (SgP  >püha !17_SA	et	f	\N
111697	kivitükki	kivitükki =tükki  (SgP  >kivi+tükk !22_S	et	f	\N
111698	kivitükki	kivitükki =tükki  (SgAdt  >kivi+tükk !22_S	et	f	\N
111699	tasuja	tasuja =tasuja  (SgN  >tasuja !01_S	et	f	\N
111700	tasuja	"tasuja %tasu  )JA_vS  <tasuma ;27_V	et	f	\N
111701	tasuja	tasuja =tasuja  (SgG  >tasuja !01_S	et	f	\N
111709	hobune	hobune =hobune  (SgN  >hobune !10_S	et	f	\N
111710	hobune	"hobune %hobu  )NE_aA  <hobu ;17_S	et	f	\N
111714	1907-	### 1907-	et	f	\N
111407	pärineval	"pärinev %pärine  )V_vA  <pärinema ;27_V	et	f	\N
111410	henne	?henne =henne  (SgN  >henne !06_S	et	f	\N
111411	henne	?henne =henne  (PlP  >henn !22_S	et	f	\N
111412	henne	?henne =henne  (IndPrPs_  >hennema !27_V	et	f	\N
111413	henne	?henne =henne  (ImpPrSg2  >hennema !27_V	et	f	\N
111423	kronoloogia	kronoloogia =kronoloogia  (SgN  >kronoloogia !01_S	et	f	\N
111424	kronoloogia	kronoloogia =kronoloogia  (SgG  >kronoloogia !01_S	et	f	\N
111427	xvi	### xvi	et	f	\N
111444	johan	?johan =joha  (IndPrSg1  >johama !27_V	et	f	\N
111445	johan	?johan =johan  (SgN  >johan !02_S	et	f	\N
111449	claus	?claus =clau  (SgIn  >clau !26_S	et	f	\N
111450	claus	?claus =claus  (SgN  >claus !22_S	et	f	\N
111465	ajaloos	ajaloos =loo  (SgIn  >aja+lugu !18_S	et	f	\N
111466	ajaloos	ajaloos =loo  (SgIn  >aja+loog !22_S	et	f	\N
111468	ajaloos	ajaloos =loo  (SgIn  >aja+lood !22_S	et	f	\N
111470	ajaloos	ajaloos =loos  (SgN  >aja+loos !22_S	et	f	\N
111475	kuningas	kuningas =kuninga  (SgIn  >kuningas !02_S	et	f	\N
111477	kuningas	kuningas =kuningas  (SgN  >kuningas !02_S	et	f	\N
111483	schrapfferile	?schrapfferile =schrapfferi  (SgAll  >schrapfferi !01_S	et	f	\N
111484	schrapfferile	?schrapfferile =schrapfferi  (SgAll  >schrapffer !02_S	et	f	\N
111489	põhjus	põhjus =põhju  (PlIn  >põhi !24_S	et	f	\N
111490	põhjus	põhjus =põhjus  (SgN  >põhjus !11~09_S	et	f	\N
111516	rudolf	?rudolf =rudolf  (SgN  >rudolf !22_S	et	f	\N
111542	põhjasõda	põhjasõda =sõda  (SgN  >põhja+sõda !18_S	et	f	\N
111543	põhjasõda	põhjasõda =sõda  (SgP  >põhja+sõda !18_S	et	f	\N
111546	röövelparuni	?röövelparuni =röövelparuni  (SgG  >röövelparun !19_S	et	f	\N
111547	röövelparuni	?röövelparuni =röövelparuni  (SgP  >röövelparun !19_S	et	f	\N
111548	röövelparuni	?röövelparuni =röövelparuni  (SgAdt  >röövelparun !19_S	et	f	\N
111549	röövelparuni	?röövelparuni =elparu  (SgTer  >rööv+elparu !01_S	et	f	\N
111550	röövelparuni	?röövelparuni =elparuni  (SgG  >rööv+elparun !19_S	et	f	\N
111551	röövelparuni	?röövelparuni =elparuni  (SgP  >rööv+elparun !19_S	et	f	\N
111552	röövelparuni	?röövelparuni =elparuni  (SgAdt  >rööv+elparun !19_S	et	f	\N
111566	viina	viina =viina  (SgG  >viin !22_S	et	f	\N
111567	viina	viina =viina  (SgP  >viin !22_S	et	f	\N
111569	viina	viina =viina  (SgAdt  >viin !22_S	et	f	\N
111570	baltimaadel	baltimaadel =maa  (PlAd  >balti+maa !26_S	et	f	\N
111571	baltimaadel	baltimaadel =maade  (PlAd  >balti+maat !22_S	et	f	\N
111574	pankrotti	pankrotti =pankrotti  (SgP  >pankrot !22_S	et	f	\N
111575	pankrotti	pankrotti =pankrotti  (SgAdt  >pankrot !22_S	et	f	\N
111577	kuuekümne	?kuuekümne =kuuekümne  (SgN  >kuuekümne !02_A	et	f	\N
111578	kuuekümne	?kuuekümne =kuuekümne  (PlP  >kuuekümn !22_S	et	f	\N
111579	kuuekümne	?kuuekümne =kümne  (SgN  >kuue+kümne !02_A	et	f	\N
111580	kuuekümne	?kuuekümne =kümne  (PlP  >kuue+kümn !22_S	et	f	\N
111581	kuuekümne	?kuuekümne =ekümne  (SgN  >kuu+ekümne !02_A	et	f	\N
111582	kuuekümne	?kuuekümne =ekümne  (PlP  >kuu+ekümn !22_S	et	f	\N
111586	ehitus-	ehitus- =ehitu  (SgIn  >ehitu !01_AS	et	f	\N
111587	ehitus-	"ehitu %ehi  )TU1_vS  <ehtima ;28_V	et	f	\N
111588	ehitus-	ehitus- =ehitu  (IndIpfSg3  >ehituma !27_V	et	f	\N
111589	ehitus-	ehitus- =ehitus  (SgN  >ehitus !11_S	et	f	\N
111590	ehitus-	"ehitus %ehita  )US_vS  <ehitama ;27_V	et	f	\N
111591	ehitus-	"ehitus %ehi  )TUS1_aS  <ehtima ;28_V	et	f	\N
111594	laiendatakse	laiendatakse =laienda  (IndPrIps  >laiendama !27_V	et	f	\N
111595	laiendatakse	laiendatakse =takse  (PlP  >lai+enda+taks !22_S	et	f	\N
111605	piimakarja	piimakarja =karja  (SgG  >piima+kari !24_S	et	f	\N
111606	piimakarja	piimakarja =karja  (SgP  >piima+kari !24_S	et	f	\N
111607	piimakarja	piimakarja =karja  (SgAdt  >piima+kari !24_S	et	f	\N
111618	robert	?robert =robert  (SgN  >robert !22_S	et	f	\N
111634	kaevanud	kaevanud =kaeva  (PtsPtPs  >kaebama !29_V	et	f	\N
111636	kaevanud	kaevanud =kaeva  (PtsPtPs  >kaevama !29_V	et	f	\N
111637	kaevanud	kaevanud =kaevanu  (PlN  >kaevanu !01_S	et	f	\N
111638	kaevanud	"kaevanu %kaeva  )NU_vS  <kaebama ;29_V	et	f	\N
111639	kaevanud	"kaevanu %kaeva  )NU_vS  <kaevama ;29_V	et	f	\N
111640	kaevanud	kaevanud =kaevanud  (ID  >kaevanud !41_A	et	f	\N
111641	kaevanud	"kaevanud %kaeva  )NUD_vA  <kaebama ;29_V	et	f	\N
111644	kaevanud	"kaevanud %kaeva  )NUD_vA  <kaevama ;29_V	et	f	\N
111678	mälestusi	mälestusi =mälestusi  (PlP  >mälestus !11_S	et	f	\N
111679	mälestusi	"mälestus %mälesta  )US_vS  <mälestama ;27_V	et	f	\N
111682	otsa	otsa =otsa  (ID  >otsa !41_DK	et	f	\N
111683	otsa	otsa =otsa  (SgG  >ots !23?22_S	et	f	\N
111684	otsa	otsa =otsa  (SgP  >ots !23?22_S	et	f	\N
111685	otsa	otsa =otsa  (SgAdt  >ots !23?22_S	et	f	\N
111687	otsa	otsa =otsa  (IndPrPs_  >otsama !29_V	et	f	\N
111689	otsa	otsa =otsa  (ImpPrSg2  >otsama !29_V	et	f	\N
111728	puhkepaika	puhkepaika =paika  (SgP  >puhke+paik !22_S	et	f	\N
111730	puhkepaika	puhkepaika =paika  (SgAdt  >puhke+paik !22_S	et	f	\N
111732	lõbutsemist	lõbutsemist =lõbutsemis  (SgP  >lõbutsemine !12_S	et	f	\N
111733	lõbutsemist	"lõbutsemine %lõbutse  )MINE_vS  <lõbutsema ;27_V	et	f	\N
111473	teatavat	"teatav %teata  )V_vA  <teatama ;27_V	et	f	\N
111474	gustav	?gustav =gusta  (PtsPrPs  >gustama !29_V	et	f	\N
111476	gustav	?gustav =gustav  (SgN  >gustav !02_A	et	f	\N
111503	sõjakomissari	sõjakomissari =komissari  (SgG  >sõja+komissar !19_S	et	f	\N
111504	sõjakomissari	sõjakomissari =komissari  (SgP  >sõja+komissar !19_S	et	f	\N
111505	sõjakomissari	sõjakomissari =komissari  (SgAdt  >sõja+komissar !19_S	et	f	\N
111506	end	end =end  (SgP  >enda !00_P	et	f	\N
111507	end	end =end  (SgP  >ise !00_P	et	f	\N
111513	juhataja	juhataja =juhataja  (SgN  >juhataja !01_S	et	f	\N
111514	juhataja	"juhataja %juhata  )JA_vS  <juhatama ;27_V	et	f	\N
111515	juhataja	juhataja =juhataja  (SgG  >juhataja !01_S	et	f	\N
111526	rahu	rahu =rahu  (SgN  >rahu !17_S	et	f	\N
111529	rahu	rahu =rahu  (SgG  >rahu !17_S	et	f	\N
111532	rahu	rahu =rahu  (SgP  >rahu !17_S	et	f	\N
111538	põhimõtteliselt	põhimõtteliselt =mõttelise  (SgAbl  >põhi+mõtteline !12_A	et	f	\N
111539	põhimõtteliselt	"põhi+mõtteline %mõtte  )LINE_aA  <põhi+mõte ;06_S	et	f	\N
111540	põhimõtteliselt	"põhi+mõtteliselt %mõtte  )LISELT_mD  <põhi+mõte ;06_S	et	f	\N
111541	põhimõtteliselt	"põhi+mõtteliselt %mõttelise  )LT_mD  <põhi+mõtteline ;12_A	et	f	\N
111558	laevaga	laevaga =laeva  (SgKom  >laev !22_S	et	f	\N
111559	laevaga	laevaga =vaga  (SgN  >lae+vaga !17_A	et	f	\N
111560	laevaga	laevaga =vaga  (SgG  >lae+vaga !17_A	et	f	\N
111561	laevaga	laevaga =vaga  (SgP  >lae+vaga !17_A	et	f	\N
111565	vedades	vedades =veda  (PlIn  >veda !17_S	et	f	\N
111568	vedades	vedades =veda  (Ger  >vedama !28_V	et	f	\N
111592	parki	parki =parki  (SgP  >park !22_S	et	f	\N
111593	parki	parki =parki  (SgAdt  >park !22_S	et	f	\N
111601	puuliike	puuliike =liike  (SgN  >puu+liike !12?10_S	et	f	\N
111602	puuliike	"puu+liike %lii  )KE_dS  <puu+lii ;26_S	et	f	\N
111603	puuliike	puuliike =liike  (PlP  >puu+liik !22_S	et	f	\N
111604	reliktjärveke	?reliktjärveke =reliktjärveke  (SgN  >reliktjärveke !12_S	et	f	\N
111610	meriino	meriino =meriino  (SgN  >meriino !16_S	et	f	\N
111611	meriino	meriino =meriino  (SgG  >meriino !16_S	et	f	\N
111633	kulla	kulla =kulla  (ID  >kulla !41_A	et	f	\N
111635	kulla	kulla =kulla  (SgG  >kuld !22_S	et	f	\N
111670	weymarnile	?weymarnile =weymarni  (SgAll  >weymarni !01_S	et	f	\N
111671	weymarnile	?weymarnile =weymarni  (SgAll  >weymarn !22_S	et	f	\N
111702	väites	väites =väit  (Ger  >väitma !34_V	et	f	\N
111703	väites	väites =väite  (SgIn  >väide !06_S	et	f	\N
111720	ela	ela =ela  (IndPrPs_  >elama !27_V	et	f	\N
111721	ela	ela =ela  (ImpPrSg2  >elama !27_V	et	f	\N
111755	raskused	raskused =raskuse  (PlN  >raskus !11~09_S	et	f	\N
111756	raskused	"raskus %raske  )US_aS  <raske ;01_A	et	f	\N
111757	raskused	raskused =raskuse  (PlN  >raskune !12~10_A	et	f	\N
111763	aiast	aiast =aia  (SgEl  >aed !22_S	et	f	\N
111765	aiast	aiast =aia  (SgEl  >ai !22_S	et	f	\N
111767	aiast	aiast =aias  (SgP  >aiane !10_A	et	f	\N
111768	aiast	"aiane %aia  )NE_aA  <aed ;22_S	et	f	\N
111769	aiast	"aiane %aia  )NE_aA  <ai ;22_S	et	f	\N
111781	endale	endale =enda  (SgAll  >enda !00_P	et	f	\N
111783	endale	endale =enda  (SgAll  >ise !00_P	et	f	\N
111785	andnud	andnud =and  (PtsPtPs  >andma !34_V	et	f	\N
111786	andnud	andnud =andnu  (PlN  >andnu !01_S	et	f	\N
111787	andnud	"andnu %and  )NU_vS  <andma ;34_V	et	f	\N
111788	andnud	andnud =andnud  (ID  >andnud !41_A	et	f	\N
111789	andnud	"andnud %and  )NUD_vA  <andma ;34_V	et	f	\N
111805	otsija	otsija =otsija  (SgN  >otsija !01_S	et	f	\N
111806	otsija	"otsija %otsi  )JA_vS  <otsima ;28_V	et	f	\N
111807	otsija	otsija =otsija  (SgG  >otsija !01_S	et	f	\N
111828	rangelt	rangelt =range  (SgAbl  >range !01_A	et	f	\N
111830	rangelt	rangelt =range  (PlAbl  >rang !22_S	et	f	\N
111832	rangelt	rangelt =rangelt  (ID  >rangelt !41_D	et	f	\N
111834	rangelt	"rangelt %range  )LT_mD  <range ;01_A	et	f	\N
111852	peksnud	peksnud =peks  (PtsPtPs  >peksma !32_V	et	f	\N
111853	peksnud	peksnud =peksnu  (PlN  >peksnu !01_S	et	f	\N
111854	peksnud	"peksnu %peks  )NU_vS  <peksma ;32_V	et	f	\N
111855	peksnud	peksnud =peksnud  (ID  >peksnud !41_A	et	f	\N
111856	peksnud	"peksnud %peks  )NUD_vA  <peksma ;32_V	et	f	\N
111874	käis	käis =käi  (IndIpfSg3  >käima !38_V	et	f	\N
111875	käis	käis =käis  (SgN  >käis !09_S	et	f	\N
111883	seppa	seppa =seppa  (SgP  >sepp !22_S	et	f	\N
111884	seppa	seppa =seppa  (SgAdt  >sepp !22_S	et	f	\N
111890	nr9	### nr9	et	f	\N
111902	käisarvatava	?käisarvatava =käisarvatava  (SgN  >käisarvatava !16_S	et	f	\N
111903	käisarvatava	?käisarvatava =käisarvatava  (SgG  >käisarvatav !02_A	et	f	\N
111904	käisarvatava	?käisarvatava =käisarvatava  (SgG  >käisarvatava !16_S	et	f	\N
111926	nendes	nendes =nen  (PlIn  >see !00_P	et	f	\N
111928	nendes	nendes =nen  (PlIn  >tema !00_P	et	f	\N
111942	valmimisel	valmimisel =valmimise  (SgAd  >valmimine !12_S	et	f	\N
111943	valmimisel	"valmimine %valmi  )MINE_vS  <valmima ;27_V	et	f	\N
111952	tüssata	tüssata =tüssa  (Inf  >tüssama !29_V	et	f	\N
111953	tüssata	tüssata =tüssa  (IndPrIps_  >tüssama !29_V	et	f	\N
111556	hiiumaa	hiiumaa =maa  (SgN  >hiiu+maa !26_S	et	f	\N
111557	hiiumaa	hiiumaa =maa  (SgG  >hiiu+maa !26_S	et	f	\N
111562	vilja	vilja =vilja  (SgG  >vili !24_S	et	f	\N
111563	vilja	vilja =vilja  (SgP  >vili !24_S	et	f	\N
111564	vilja	vilja =vilja  (SgAdt  >vili !24_S	et	f	\N
111572	jäid	jäid =jä  (IndIpfSg2  >jääma !37_V	et	f	\N
111573	jäid	jäid =jä  (IndIpfPl3  >jääma !37_V	et	f	\N
111583	sternbergidele	### sternbergidele	et	f	\N
111596	tunduvalt	tunduvalt =tunduva  (SgAbl  >tunduv !02_A	et	f	\N
111597	tunduvalt	"tunduv %tundu  )V_vA  <tunduma ;27_V	et	f	\N
111598	tunduvalt	tunduvalt =tunduvalt  (ID  >tunduvalt !41_D	et	f	\N
111599	tunduvalt	"tunduvalt %tundu  )VALT_mD  <tunduma ;27_V	et	f	\N
111600	tunduvalt	"tunduvalt %tunduva  )LT_mD  <tunduv ;02_A	et	f	\N
111608	pidamisega	pidamisega =pidamise  (SgKom  >pidamine !12_S	et	f	\N
111609	pidamisega	"pidamine %pida  )MINE_vS  <pidama ;28_V	et	f	\N
111612	kasvatusega	kasvatusega =kasvatuse  (SgKom  >kasvatus !11_S	et	f	\N
111613	kasvatusega	"kasvatus %kasvata  )US_vS  <kasvatama ;27_V	et	f	\N
111614	kasvatusega	"kasvatus %kasva  )TUS1_aS  <kasvama ;28_V	et	f	\N
111615	suguvõsast	suguvõsast =võsa  (SgEl  >sugu+võsa !17_S	et	f	\N
111616	suguvõsast	suguvõsast =võsas  (SgP  >sugu+võsane !10_A	et	f	\N
111617	suguvõsast	"sugu+võsane %võsa  )NE_aA  <sugu+võsa ;17_S	et	f	\N
111626	põgenenud	põgenenud =põgene  (PtsPtPs  >põgenema !27_V	et	f	\N
111627	põgenenud	põgenenud =põgenenu  (PlN  >põgenenu !01_S	et	f	\N
111628	põgenenud	"põgenenu %põgene  )NU_vS  <põgenema ;27_V	et	f	\N
111629	põgenenud	põgenenud =põgenenud  (ID  >põgenenud !41_A	et	f	\N
111630	põgenenud	"põgenenud %põgene  )NUD_vA  <põgenema ;27_V	et	f	\N
111642	maa	maa =maa  (SgN  >maa !26_S	et	f	\N
111643	maa	maa =maa  (SgG  >maa !26_S	et	f	\N
111648	juttu	juttu =juttu  (SgP  >jutt !22_S	et	f	\N
111649	juttu	juttu =juttu  (SgAdt  >jutt !22_S	et	f	\N
111660	näidatud	näidatud =näida  (PtsPtIps  >näitama !29_V	et	f	\N
111661	näidatud	näidatud =näidatu  (PlN  >näidatu !01_S	et	f	\N
111662	näidatud	"näidatu %näida  )TU1_vS  <näitama ;29_V	et	f	\N
111663	näidatud	näidatud =näidatud  (ID  >näidatud !41_A	et	f	\N
111664	näidatud	"näidatud %näida  )TUD_vA  <näitama ;29_V	et	f	\N
111665	kindraliproua	kindraliproua =proua  (SgN  >kindrali+proua !16_S	et	f	\N
111667	kindraliproua	kindraliproua =proua  (SgG  >kindrali+proua !16_S	et	f	\N
111668	friederih	?friederih =friederih  (ID  >friederih !41_I	et	f	\N
111704	maetud	maetud =mae  (PtsPtIps  >matma !35_V	et	f	\N
111705	maetud	maetud =maetu  (PlN  >maetu !01_S	et	f	\N
111706	maetud	"maetu %mae  )TU1_vS  <matma ;35_V	et	f	\N
111707	maetud	maetud =maetud  (ID  >maetud !41_A	et	f	\N
111708	maetud	"maetud %mae  )TUD_vA  <matma ;35_V	et	f	\N
111711	peterburist	?peterburist =peterburi  (SgEl  >peterbur !19_S	et	f	\N
111712	peterburist	?peterburist =peterburis  (SgP  >peterburis !09_S	et	f	\N
111713	peterburist	?peterburist =peterburist  (SgN  >peterburist !22_S	et	f	\N
111718	knorringile	?knorringile =knorringi  (SgAll  >knorring !02_S	et	f	\N
111719	knorringile	?knorringile =knorringi  (SgAll  >knorrink !22_S	et	f	\N
111751	tekkisid	tekkisid =tekki  (PlP  >tekk !22_S	et	f	\N
111753	tekkisid	tekkisid =tekki  (IndIpfSg2  >tekkima !27~28_V	et	f	\N
111754	tekkisid	tekkisid =tekki  (IndIpfPl3  >tekkima !27~28_V	et	f	\N
111758	sissetulekuid	sissetulekuid =ku  (PlP  >sisse+tule+kuu !26_S	et	f	\N
111759	sissetulekuid	sissetulekuid =tuleku  (PlP  >sisse+tulek !02_S	et	f	\N
111808	siia	siia =siia  (ID  >siia !41_D	et	f	\N
111809	siia	siia =siia  (SgG  >siig !22_S	et	f	\N
111810	tulutoovamaks	tulutoovamaks =toovama  (SgTr  >tulu+toovam !02_A	et	f	\N
111811	tulutoovamaks	"tulu+toovam %toova  )M_cA  <tulu+toov ;02_A	et	f	\N
111824	alati	alati =ala  (IndIpfIps  >algama !29_V	et	f	\N
111827	alati	alati =alati  (ID  >alati !41_D	et	f	\N
111829	keelatud	keelatud =keela  (PtsPtIps  >keelama !29_V	et	f	\N
111831	keelatud	keelatud =keelatu  (PlN  >keelatu !01_S	et	f	\N
111833	keelatud	"keelatu %keela  )TU1_vS  <keelama ;29_V	et	f	\N
111835	keelatud	keelatud =keelatud  (ID  >keelatud !41_A	et	f	\N
111836	keelatud	"keelatud %keela  )TUD_vA  <keelama ;29_V	et	f	\N
111837	keelatud	keelatud =atu  (PlN  >keel+att !22_S	et	f	\N
111838	vahele	vahele =vahe  (SgAll  >vahe !16_S	et	f	\N
111839	vahele	vahele =vahe  (PlAll  >vahk !22_S	et	f	\N
111840	vahele	vahele =vahe  (PlAll  >vaht !22_S	et	f	\N
111841	vahele	vahele =vahele  (ID  >vahele !41_DK	et	f	\N
111850	proua	proua =proua  (SgN  >proua !16_S	et	f	\N
111851	proua	proua =proua  (SgG  >proua !16_S	et	f	\N
111897	öeldud	öeldud =öel  (PtsPtIps  >ütlema !30_V	et	f	\N
111898	öeldud	öeldud =öeldu  (PlN  >öeldu !01_S	et	f	\N
111899	öeldud	"öeldu %öel  )TU1_vS  <ütlema ;30_V	et	f	\N
111900	öeldud	öeldud =öeldud  (ID  >öeldud !41_A	et	f	\N
111901	öeldud	"öeldud %öel  )TUD_vA  <ütlema ;30_V	et	f	\N
111907	talu	talu =talu  (SgN  >talu !17_S	et	f	\N
111909	talu	talu =talu  (SgG  >talu !17_S	et	f	\N
111911	talu	talu =talu  (SgP  >talu !17_S	et	f	\N
111716	paiku	paiku =paiku  (PlP  >paik !22_S	et	f	\N
111717	weymarn	?weymarn =weymarn  (SgN  >weymarn !22_S	et	f	\N
111745	aurujahuveski	aurujahuveski =veski  (SgN  >auru+jahu+veski !01_S	et	f	\N
111746	aurujahuveski	aurujahuveski =veski  (SgG  >auru+jahu+veski !01_S	et	f	\N
111764	tooteid	tooteid =toote  (PlP  >toode !06_S	et	f	\N
111766	tooteid	tooteid =te  (PlP  >too+tee !26_S	et	f	\N
111770	aednikupoisid	?aednikupoisid =aednikupoi  (PlP  >aednikupoi !26_S	et	f	\N
111771	aednikupoisid	?aednikupoisid =aednikupoisi  (PlN  >aednikupoisi !16_S	et	f	\N
111772	aednikupoisid	?aednikupoisid =aednikupoisi  (PlN  >aednikupois !22_S	et	f	\N
111773	aednikupoisid	?aednikupoisid =aednikupoisi  (IndPrSg2  >aednikupoisima !28_V	et	f	\N
111774	aednikupoisid	?aednikupoisid =nikupoi  (PlP  >aed+nikupoi !26_S	et	f	\N
111776	aednikupoisid	?aednikupoisid =nikupoisi  (PlN  >aed+nikupoisi !16_S	et	f	\N
111778	aednikupoisid	?aednikupoisid =nikupoisi  (PlN  >aed+nikupois !22_S	et	f	\N
111790	ära	ära =ära  (ImpPrSg2N  >ära !--_V	et	f	\N
111791	ära	ära =ära  (ID  >ära !41_D	et	f	\N
111797	herman	?herman =herma  (IndPrSg1  >hermama !29_V	et	f	\N
111798	herman	?herman =herman  (SgN  >herman !02_S	et	f	\N
111812	korras	korras =korra  (SgIn  >kord !22_S	et	f	\N
111813	korras	korras =korras  (ID  >korras !41_DA	et	f	\N
111815	korras	korras =korras  (ID  >korras !41_K	et	f	\N
111821	hoitud	hoitud =hoi  (PtsPtIps  >hoidma !34_V	et	f	\N
111822	hoitud	hoitud =hoitu  (PlN  >hoitu !01_S	et	f	\N
111823	hoitud	"hoitu %hoi  )TU1_vS  <hoidma ;34_V	et	f	\N
111825	hoitud	hoitud =hoitud  (ID  >hoitud !41_A	et	f	\N
111826	hoitud	"hoitud %hoi  )TUD_vA  <hoidma ;34_V	et	f	\N
111844	karistuse	karistuse =karistuse  (SgG  >karistus !11_S	et	f	\N
111845	karistuse	"karistus %karista  )US_vS  <karistama ;27_V	et	f	\N
111847	valvas	valvas =valva  (IndIpfSg3  >valvama !29_V	et	f	\N
111849	valvas	valvas =valvas  (SgN  >valvas !03~05_A	et	f	\N
111881	otsimas	otsimas =otsi  (SupIn  >otsima !28_V	et	f	\N
111882	otsimas	otsimas =ima  (SgIn  >ots+ima !17_S	et	f	\N
111905	tambeti	?tambeti =tambe  (IndIpfIps  >tambema !27_V	et	f	\N
111906	tambeti	?tambeti =tambeti  (ID  >tambeti !41_D	et	f	\N
111908	tambeti	?tambeti =tambeti  (SgG  >tambett !22_S	et	f	\N
111910	tambeti	?tambeti =tambeti  (IndPrPs_  >tambettima !28_V	et	f	\N
111912	tambeti	?tambeti =tambeti  (ImpPrSg2  >tambettima !28_V	et	f	\N
111933	mõisahoone	mõisahoone =hoone  (SgN  >mõisa+hoone !06_S	et	f	\N
111934	mõisahoone	"mõisa+hoone %hoo  )NE_aA  <mõisa+hoog ;22_S	et	f	\N
111935	mõisahoone	mõisahoone =hoone  (SgG  >mõisa+hoone !06_S	et	f	\N
111936	mõisahoone	mõisahoone =hoone  (PlP  >mõisa+hoon !22_A	et	f	\N
111939	kohalekutsutud	kohalekutsutud =kutsu  (PtsPtIps  >kohale+_kutsuma !28_V	et	f	\N
111940	kohalekutsutud	kohalekutsutud =kutsutu  (PlN  >kohale+kutsutu !01_S	et	f	\N
111941	kohalekutsutud	"kohale+kutsutu %kutsu  )TU2_kA  <kohale+kutsu ;16_S	et	f	\N
111954	õige	õige =õige  (ID  >õige !41_D	et	f	\N
111955	õige	õige =õige  (SgN  >õige !01_A	et	f	\N
111957	õige	õige =õige  (SgG  >õige !01_A	et	f	\N
111976	kella	kella =kella  (SgG  >kell !22_S	et	f	\N
111978	kella	kella =kella  (SgP  >kell !22_S	et	f	\N
111980	kella	kella =kella  (SgAdt  >kell !22_S	et	f	\N
111982	kella	kella =kella  (IndPrPs_  >kellama !29_V	et	f	\N
111983	kella	kella =kella  (ImpPrSg2  >kellama !29_V	et	f	\N
112000	käima	käima =käi  (Sup  >käima !38_V	et	f	\N
112001	käima	käima =käima  (SgG  >käim !22_S	et	f	\N
112003	käima	käima =käima  (SgP  >käim !22_S	et	f	\N
112004	käima	käima =käima  (SgAdt  >käim !22_S	et	f	\N
112017	algul	algul =algu  (SgAd  >alg !22_S	et	f	\N
112018	algul	algul =algul  (ID  >algul !41_DK	et	f	\N
112021	valu	valu =valu  (SgN  >valu !17_S	et	f	\N
112022	valu	valu =valu  (SgG  >valu !17_S	et	f	\N
112023	valu	valu =valu  (SgP  >valu !17_S	et	f	\N
112024	valu	valu =valu  (IndPrPs_  >valuma !27_V	et	f	\N
112025	valu	valu =valu  (ImpPrSg2  >valuma !27_V	et	f	\N
112032	laitse	?laitse =laitse  (SgN  >laitse !06_S	et	f	\N
112033	laitse	?laitse =laitse  (SgG  >laitne !02_A	et	f	\N
112034	laitse	?laitse =laitse  (SgG  >laitse !06_S	et	f	\N
112035	laitse	?laitse =laitse  (PlP  >laits !22_S	et	f	\N
112036	laitse	?laitse =laitse  (IndPrPs_  >laitsema !28_V	et	f	\N
112037	laitse	?laitse =laitse  (ImpPrSg2  >laitsema !28_V	et	f	\N
112056	tee	tee =tee  (SgN  >tee !26_S	et	f	\N
112059	tee	tee =tee  (SgG  >tee !26_S	et	f	\N
112060	tee	tee =tee  (IndPrPs_  >tegema !28_V	et	f	\N
112061	tee	tee =tee  (ImpPrSg2  >tegema !28_V	et	f	\N
112064	matmispaigas	matmispaigas =paiga  (SgIn  >matmis+paik !22_S	et	f	\N
112065	matmispaigas	matmispaigas =paigas  (SgN  >matmis+paigas !09_S	et	f	\N
112069	matmise	matmise =matmise  (SgG  >matmine !12?10_S	et	f	\N
112070	matmise	"matmine %mat  )MINE_vS  <matma ;35_V	et	f	\N
112079	tasaseks	tasaseks =tasase  (SgTr  >tasane !10_A	et	f	\N
112080	tasaseks	tasaseks =seks  (SgN  >tasa+seks !22_S	et	f	\N
112085	abi	abi =abi  (SgN  >abi !17_S	et	f	\N
112086	abi	abi =abi  (SgG  >abi !17_S	et	f	\N
112087	abi	abi =abi  (SgP  >abi !17_S	et	f	\N
111722	peterburis	?peterburis =peterburi  (SgIn  >peterbur !19_S	et	f	\N
111723	peterburis	?peterburis =peterburis  (SgN  >peterburis !09_S	et	f	\N
111724	otsi	otsi =otsi  (SgG  >ots !22_S	et	f	\N
111725	otsi	otsi =otsi  (SgP  >ots !22_S	et	f	\N
111726	otsi	otsi =otsi  (SgAdt  >ots !22_S	et	f	\N
111727	otsi	otsi =otsi  (PlP  >ots !23?22_S	et	f	\N
111729	otsi	otsi =otsi  (IndPrPs_  >otsima !28_V	et	f	\N
111731	otsi	otsi =otsi  (ImpPrSg2  >otsima !28_V	et	f	\N
111734	võimalikult	võimalikult =võimaliku  (SgAbl  >võimalik !25_A	et	f	\N
111735	võimalikult	võimalikult =võimalikult  (ID  >võimalikult !41_D	et	f	\N
111736	võimalikult	"võimalikult %võimaliku  )LT_mD  <võimalik ;25_A	et	f	\N
111737	ennem	ennem =ennem  (ID  >ennem !41_D	et	f	\N
111738	ennem	ennem =ennem  (SgN  >ennem !02_A	et	f	\N
111739	peamiselt	peamiselt =peamise  (SgAbl  >peamine !12?10_A	et	f	\N
111740	peamiselt	peamiselt =peamiselt  (ID  >peamiselt !41_D	et	f	\N
111741	peamiselt	"peamiselt %peamise  )LT_mD  <peamine ;10_A	et	f	\N
111742	peamiselt	"peamiselt %peamise  )LT_mD  <peamine ;12_A	et	f	\N
111743	kasvatamisega	kasvatamisega =kasvatamise  (SgKom  >kasvatamine !12_S	et	f	\N
111744	kasvatamisega	"kasvatamine %kasvata  )MINE_vS  <kasvatama ;27_V	et	f	\N
111760	saadi	saadi =saa  (IndIpfIps  >saama !37_V	et	f	\N
111761	saadi	saadi =saadi  (SgP  >saad !22_S	et	f	\N
111762	saadi	saadi =saadi  (SgAdt  >saad !22_S	et	f	\N
111779	raha	raha =raha  (SgN  >raha !17_S	et	f	\N
111780	raha	raha =raha  (SgG  >raha !17_S	et	f	\N
111782	raha	raha =raha  (SgG  >rahk !22_S	et	f	\N
111784	raha	raha =raha  (SgP  >raha !17_S	et	f	\N
111792	ostnud	ostnud =ost  (PtsPtPs  >ostma !34_V	et	f	\N
111793	ostnud	ostnud =ostnu  (PlN  >ostnu !01_S	et	f	\N
111794	ostnud	"ostnu %ost  )NU_vS  <ostma ;34_V	et	f	\N
111795	ostnud	ostnud =ostnud  (ID  >ostnud !41_A	et	f	\N
111796	ostnud	"ostnud %ost  )NUD_vA  <ostma ;34_V	et	f	\N
111799	richard	?richard =richard  (SgN  >richard !02_S	et	f	\N
111800	harpe	?harpe =harpe  (SgN  >harpe !06_S	et	f	\N
111801	harpe	?harpe =harpe  (SgG  >harbe !06_S	et	f	\N
111802	harpe	?harpe =harpe  (PlP  >harp !22_S	et	f	\N
111803	harpe	?harpe =harpe  (IndPrPs_  >harpema !27_V	et	f	\N
111804	harpe	?harpe =harpe  (ImpPrSg2  >harpema !27_V	et	f	\N
111817	pargi	pargi =pargi  (SgG  >park !22_S	et	f	\N
111819	pargi	pargi =pargi  (IndPrPs_  >parkima !28_V	et	f	\N
111820	pargi	pargi =pargi  (ImpPrSg2  >parkima !28_V	et	f	\N
111870	muid	muid =mu  (PlP  >muu !26_S	et	f	\N
111871	muid	muid =mu  (PlP  >muu !26_P	et	f	\N
111872	rikastumiseks	rikastumiseks =rikastumise  (SgTr  >rikastumine !12_S	et	f	\N
111873	rikastumiseks	"rikastumine %rikastu  )MINE_vS  <rikastuma ;27_V	et	f	\N
111888	kodu	kodu =kodu  (ID  >kodu !41_D	et	f	\N
111889	kodu	kodu =kodu  (SgN  >kodu !17_S	et	f	\N
111892	kodu	kodu =kodu  (SgG  >kodu !17_S	et	f	\N
111893	kodu	kodu =kodu  (SgP  >kodu !17_S	et	f	\N
111915	kaevamas	kaevamas =kaeva  (SupIn  >kaevama !29_V	et	f	\N
111916	kaevamas	kaevamas =kaevama  (SgIn  >kaevam !02_A	et	f	\N
111917	kaevamas	"kaevam %kae  )VAM_cA  <kaema ;27_V	et	f	\N
111925	jälgi	jälgi =jälgi  (SgG  >jälk !22_A	et	f	\N
111927	jälgi	jälgi =jälgi  (SgP  >jälg !22_S	et	f	\N
111929	jälgi	jälgi =jälgi  (SgAdt  >jälg !22_S	et	f	\N
111930	jälgi	jälgi =jälgi  (PlP  >jälg !22_S	et	f	\N
111931	jälgi	jälgi =jälgi  (IndPrPs_  >jälgima !27_V	et	f	\N
111932	jälgi	jälgi =jälgi  (ImpPrSg2  >jälgima !27_V	et	f	\N
111937	kõrval	kõrval =kõrva  (SgAd  >kõrv !22_S	et	f	\N
111938	kõrval	kõrval =kõrval  (ID  >kõrval !41_DK	et	f	\N
111946	tahtnud	tahtnud =taht  (PtsPtPs  >tahtma !34_V	et	f	\N
111948	tahtnud	tahtnud =tahtnu  (PlN  >tahtnu !01_S	et	f	\N
111949	tahtnud	"tahtnu %taht  )NU_vS  <tahtma ;34_V	et	f	\N
111950	tahtnud	tahtnud =tahtnud  (ID  >tahtnud !41_A	et	f	\N
111951	tahtnud	"tahtnud %taht  )NUD_vA  <tahtma ;34_V	et	f	\N
111962	valeraha	valeraha =raha  (SgN  >vale+raha !17_S	et	f	\N
111963	valeraha	valeraha =raha  (SgG  >vale+raha !17_S	et	f	\N
111965	valeraha	valeraha =raha  (SgG  >vale+rahk !22_S	et	f	\N
111966	valeraha	valeraha =raha  (SgP  >vale+raha !17_S	et	f	\N
111967	teinud	teinud =tei  (PtsPtPs  >tegema !28_V	et	f	\N
111968	teinud	teinud =teinu  (PlN  >teinu !01_S	et	f	\N
111969	teinud	"teinu %tei  )NU_vS  <tegema ;28_V	et	f	\N
111970	teinud	teinud =teinu  (PlN  >teinu !06_S	et	f	\N
111972	teinud	"teinud %tei  )NUD_vA  <tegema ;28_V	et	f	\N
111989	maailmast	maailmast =ast  (SgN  >maa+ilm+ast !22_S	et	f	\N
111990	maailmast	maailmast =ilma  (SgEl  >maa+ilm !22_S	et	f	\N
111991	maailmast	maailmast =ilmas  (SgP  >maa+ilmane !10_A	et	f	\N
111992	maailmast	"maa+ilmane %ilma  )NE_aA  <maa+ilm ;22_S	et	f	\N
111995	osanud	osanud =osa  (PtsPtPs  >oskama !29_V	et	f	\N
111996	osanud	osanud =osanu  (PlN  >osanu !01_S	et	f	\N
111997	osanud	"osanu %osa  )NU_vS  <oskama ;29_V	et	f	\N
111998	osanud	osanud =osanud  (ID  >osanud !41_A	et	f	\N
111999	osanud	"osanud %osa  )NUD_vA  <oskama ;29_V	et	f	\N
111747	tegelenud	tegelenud =tegele  (PtsPtPs  >tegelema !27_V	et	f	\N
111748	tegelenud	tegelenud =tegelenu  (PlN  >tegelenu !01_S	et	f	\N
111749	tegelenud	"tegelenu %tegele  )NU_vS  <tegelema ;27_V	et	f	\N
111750	tegelenud	tegelenud =tegelenud  (ID  >tegelenud !41_A	et	f	\N
111752	tegelenud	"tegelenud %tegele  )NUD_vA  <tegelema ;27_V	et	f	\N
111775	jätsid	jätsid =jät  (IndIpfSg2  >jätma !35_V	et	f	\N
111777	jätsid	jätsid =jät  (IndIpfPl3  >jätma !35_V	et	f	\N
111814	teed	teed =tee  (PlN  >tee !26_S	et	f	\N
111816	teed	teed =tee  (SgP  >tee !26_S	et	f	\N
111818	teed	teed =tee  (IndPrSg2  >tegema !28_V	et	f	\N
111842	said	said =sa  (IndIpfSg2  >saama !37_V	et	f	\N
111843	said	said =sa  (IndIpfPl3  >saama !37_V	et	f	\N
111846	järele	järele =järe  (PlAll  >järg !22_S	et	f	\N
111848	järele	järele =järele  (ID  >järele !41_DK	et	f	\N
111857	kohanud	kohanud =koha  (PtsPtPs  >kohama !27_V	et	f	\N
111858	kohanud	kohanud =koha  (PtsPtPs  >kohtama !29_V	et	f	\N
111859	kohanud	kohanud =kohanu  (PlN  >kohanu !01_S	et	f	\N
111860	kohanud	"kohanu %koha  )NU_vS  <kohama ;27_V	et	f	\N
111861	kohanud	"kohanu %koha  )NU_vS  <kohtama ;29_V	et	f	\N
111862	kohanud	kohanud =kohanud  (ID  >kohanud !41_A	et	f	\N
111863	kohanud	"kohanud %koha  )NUD_vA  <kohama ;27_V	et	f	\N
111864	kohanud	"kohanud %koha  )NUD_vA  <kohtama ;29_V	et	f	\N
111865	otsinud	otsinud =otsi  (PtsPtPs  >otsima !28_V	et	f	\N
111866	otsinud	otsinud =otsinu  (PlN  >otsinu !01_S	et	f	\N
111867	otsinud	"otsinu %otsi  )NU_vS  <otsima ;28_V	et	f	\N
111868	otsinud	otsinud =otsinud  (ID  >otsinud !41_A	et	f	\N
111869	otsinud	"otsinud %otsi  )NUD_vA  <otsima ;28_V	et	f	\N
111876	sternbergi	?sternbergi =sternbergi  (SgG  >sternberg !02_S	et	f	\N
111877	sternbergi	?sternbergi =sternbergi  (SgG  >sternberk !22_S	et	f	\N
111878	sternbergi	?sternbergi =sternbergi  (IndPrPs_  >sternberkima !28_V	et	f	\N
111879	sternbergi	?sternbergi =sternbergi  (ImpPrSg2  >sternberkima !28_V	et	f	\N
111880	sternbergi	?sternbergi =sternber  (SgN^  >sternber !02_S	et	f	\N
111885	kaitse	kaitse =kaitse  (SgN  >kaitse !05_S	et	f	\N
111886	kaitse	kaitse =kaitse  (SgN  >kaitse !06_S	et	f	\N
111887	kaitse	kaitse =kaitse  (SgG  >kaitse !06_S	et	f	\N
111891	kaitse	kaitse =kaitse  (IndPrPs_  >kaitsema !28_V	et	f	\N
111894	kaitse	kaitse =kaitse  (IndPrPs_  >kaitsma !32_V	et	f	\N
111895	kaitse	kaitse =kaitse  (ImpPrSg2  >kaitsema !28_V	et	f	\N
111896	kaitse	kaitse =kaitse  (ImpPrSg2  >kaitsma !32_V	et	f	\N
111918	tassinud	tassinud =tassi  (PtsPtPs  >tassima !28_V	et	f	\N
111919	tassinud	tassinud =tassinu  (PlN  >tassinu !01_S	et	f	\N
111921	tassinud	"tassinu %tassi  )NU_vS  <tassima ;28_V	et	f	\N
111922	tassinud	tassinud =tassinud  (ID  >tassinud !41_A	et	f	\N
111924	tassinud	"tassinud %tassi  )NUD_vA  <tassima ;28_V	et	f	\N
111961	asemel	asemel =aseme  (SgAd  >ase !04_S	et	f	\N
111964	asemel	asemel =asemel  (ID  >asemel !41_K	et	f	\N
111971	palus	palus =palu  (SgIn  >palu !17_S	et	f	\N
111973	palus	palus =palu  (PlIn  >pala !17_S	et	f	\N
111974	palus	palus =palu  (IndIpfSg3  >paluma !27_V	et	f	\N
111984	kutsunud	kutsunud =kutsu  (PtsPtPs  >kutsuma !28_V	et	f	\N
111985	kutsunud	kutsunud =kutsunu  (PlN  >kutsunu !01_S	et	f	\N
111986	kutsunud	"kutsunu %kutsu  )NU_vS  <kutsuma ;28_V	et	f	\N
111987	kutsunud	kutsunud =kutsunud  (ID  >kutsunud !41_A	et	f	\N
111988	kutsunud	"kutsunud %kutsu  )NUD_vA  <kutsuma ;28_V	et	f	\N
112010	kodanluse	kodanluse =kodanluse  (SgG  >kodanlus !11_S	et	f	\N
112012	kodanluse	"kodanlus %kodanlase  )US_aS  <kodanlane ;12_S	et	f	\N
112019	maha	maha =ma  (SgAdt  >maa !26_S	et	f	\N
112020	maha	maha =maha  (ID  >maha !41_D	et	f	\N
112026	alaealiste	alaealiste =ealis  (PlG  >ala+ealine !12?10_A	et	f	\N
112027	alaealiste	"ala+ealine %ea  )LINE_aA  <ala+iga ;18_S	et	f	\N
112041	keskvangla	keskvangla =vangla  (SgN  >kesk+vangla !01_S	et	f	\N
112042	keskvangla	keskvangla =vangla  (SgG  >kesk+vangla !01_S	et	f	\N
112050	poole	poole =poole  (ID  >poole !41_DK	et	f	\N
112052	poole	poole =poole  (SgN  >poole !05_S	et	f	\N
112055	poole	poole =poole  (SgG  >pool !13_NS	et	f	\N
112057	poole	poole =poole  (PlP  >pool !22_S	et	f	\N
112071	lükati	lükati =lüka  (IndIpfIps  >lükkama !29_V	et	f	\N
112072	lükati	lükati =lükati  (SgN  >lükati !01_S	et	f	\N
112073	lükati	lükati =lükati  (SgG  >lükati !01_S	et	f	\N
112088	viibinud	viibinud =viibi  (PtsPtPs  >viibima !27_V	et	f	\N
112089	viibinud	viibinud =viibinu  (PlN  >viibinu !01_S	et	f	\N
112090	viibinud	"viibinu %viibi  )NU_vS  <viibima ;27_V	et	f	\N
112092	viibinud	viibinud =viibinud  (ID  >viibinud !41_A	et	f	\N
112093	viibinud	"viibinud %viibi  )NUD_vA  <viibima ;27_V	et	f	\N
112100	e	### e	et	f	\N
112107	bornhöhe	### bornhöhe	et	f	\N
112118	kandis	kandis =kand  (IndIpfSg3  >kandma !34_V	et	f	\N
112119	kandis	kandis =kandi  (SgIn  >kant !22_S	et	f	\N
112120	kandis	kandis =kandis  (ID  >kandis !41_DK	et	f	\N
112140	tulnud	tulnud =tul  (PtsPtPs  >tulema !36_V	et	f	\N
112141	tulnud	tulnud =tulnu  (PlN  >tulnu !01_S	et	f	\N
112142	tulnud	"tulnu %tul  )NU_vS  <tulema ;36_V	et	f	\N
111913	talu	talu =talu  (IndPrPs_  >taluma !27_V	et	f	\N
111914	talu	talu =talu  (ImpPrSg2  >taluma !27_V	et	f	\N
111920	kaevamise	kaevamise =kaevamise  (SgG  >kaevamine !12_S	et	f	\N
111923	kaevamise	"kaevamine %kaeva  )MINE_vS  <kaevama ;29_V	et	f	\N
111944	olevat	olevat =ole  (KvtPrPs  >olema !36_V	et	f	\N
111945	olevat	olevat =oleva  (SgP  >olev !02_A	et	f	\N
111947	olevat	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
112014	valitsuse	valitsuse =valitsuse  (SgG  >valitsus !11_S	et	f	\N
112016	valitsuse	"valitsus %valitse  )US_vS  <valitsema ;27_V	et	f	\N
112028	koloonia	koloonia =koloonia  (SgN  >koloonia !01_S	et	f	\N
112029	koloonia	koloonia =koloonia  (SgG  >koloonia !01_S	et	f	\N
112048	nõmme	nõmme =nõmme  (SgG  >nõmm !22_S	et	f	\N
112049	nõmme	nõmme =nõmme  (SgP  >nõmm !22_S	et	f	\N
112053	nõmme	nõmme =nõmme  (SgAdt  >nõmm !22_S	et	f	\N
112058	nõmme	nõmme =nõmme  (PlP  >nõmm !22_S	et	f	\N
112098	rahvapärimuste	rahvapärimuste =muste  (PlP  >rahva+päri+must !22_AS	et	f	\N
112099	rahvapärimuste	rahvapärimuste =pärimus  (PlG  >rahva+pärimus !11_S	et	f	\N
112101	vilde	?vilde =vilde  (SgN  >vilde !06_S	et	f	\N
112102	vilde	?vilde =vilde  (SgG  >ville !06_S	et	f	\N
112104	vilde	?vilde =vilde  (PlP  >vild !22_S	et	f	\N
112106	vilde	?vilde =vilde  (IndPrPs_  >vildema !27_V	et	f	\N
112108	vilde	?vilde =vilde  (ImpPrSg2  >vildema !27_V	et	f	\N
112110	tasujas	tasujas =tasuja  (SgIn  >tasuja !01_S	et	f	\N
112111	tasujas	"tasuja %tasu  )JA_vS  <tasuma ;27_V	et	f	\N
112146	järve	järve =järve  (SgG  >järv !22_S	et	f	\N
112147	järve	järve =järve  (SgP  >järv !22_S	et	f	\N
112148	järve	järve =järve  (SgAdt  >järv !22_S	et	f	\N
112149	järve	järve =järve  (PlP  >järv !22_S	et	f	\N
112173	lodijärve	?lodijärve =lodijärve  (PlP  >lodijärv !22_S	et	f	\N
112204	matnud	matnud =mat  (PtsPtPs  >matma !35_V	et	f	\N
112206	matnud	matnud =matnu  (PlN  >matnu !01_S	et	f	\N
112207	matnud	"matnu %mat  )NU_vS  <matma ;35_V	et	f	\N
112208	matnud	matnud =matnud  (ID  >matnud !41_A	et	f	\N
112209	matnud	"matnud %mat  )NUD_vA  <matma ;35_V	et	f	\N
112221	ajaloomuuseumi	ajaloomuuseumi =muuseumi  (SgG  >aja+loo+muuseum !19~02_S	et	f	\N
112223	ajaloomuuseumi	ajaloomuuseumi =muuseumi  (SgP  >aja+loo+muuseum !19_S	et	f	\N
112225	ajaloomuuseumi	ajaloomuuseumi =muuseumi  (SgAdt  >aja+loo+muuseum !19_S	et	f	\N
112235	kõdunenud	kõdunenud =kõdune  (PtsPtPs  >kõdunema !27_V	et	f	\N
112236	kõdunenud	kõdunenud =kõdunenu  (PlN  >kõdunenu !01_S	et	f	\N
112238	kõdunenud	"kõdunenu %kõdune  )NU_vS  <kõdunema ;27_V	et	f	\N
112239	kõdunenud	kõdunenud =kõdunenud  (ID  >kõdunenud !41_A	et	f	\N
112241	kõdunenud	"kõdunenud %kõdune  )NUD_vA  <kõdunema ;27_V	et	f	\N
112242	puude	puude =puu  (PlG  >puu !26_S	et	f	\N
112244	puude	puude =puude  (SgN  >puude !06_S	et	f	\N
112246	puude	puude =puude  (SgG  >puue !06_S	et	f	\N
112247	puude	puude =puude  (PlP  >puud !22_S	et	f	\N
112248	trüki	trüki =trüki  (SgG  >trükk !22_S	et	f	\N
112249	trüki	trüki =trüki  (IndPrPs_  >trükkima !28_V	et	f	\N
112250	trüki	trüki =trüki  (ImpPrSg2  >trükkima !28_V	et	f	\N
112296	kuulda	kuulda =kuul  (Inf  >kuulma !33_V	et	f	\N
112297	kuulda	kuulda =kuul  (IndPrIps_  >kuulma !33_V	et	f	\N
112298	riias	?riias =riia  (SgIn  >riia !16_S	et	f	\N
112299	riias	?riias =riia  (IndIpfSg3  >riiama !29_V	et	f	\N
112300	riias	?riias =riias  (SgN  >riias !02_S	et	f	\N
112304	baltische	?baltische =baltische  (PlP  >baltisch !22_S	et	f	\N
112307	baltische	?baltische =ische  (SgN  >balt+ische !06_S	et	f	\N
112309	baltische	?baltische =ische  (SgG  >balt+ische !06_S	et	f	\N
112312	baltische	?baltische =ische  (PlP  >balt+isch !22_S	et	f	\N
112317	nimetatavate	nimetatavate =nimetatava  (PlG  >nimetatav !02_A	et	f	\N
112318	nimetatavate	"nimetatav %nimeta  )TAV_vAS  <nimetama ;27_V	et	f	\N
112326	estenführer	?estenführer =estenführer  (SgN  >estenführer !02_S	et	f	\N
112374	ajastu	ajastu =ajastu  (SgN  >ajastu !01_S	et	f	\N
112375	ajastu	ajastu =ajastu  (SgG  >ajastu !01_S	et	f	\N
112383	põlistele	põlistele =põlis  (PlAll  >põline !10_A	et	f	\N
112384	põlistele	"põline %põli  )NE_aA  <põli ;24_S	et	f	\N
112445	carl	?carl =carl  (SgN  >carl !22_S	et	f	\N
112463	ütlesid	ütlesid =ütle  (IndIpfSg2  >ütlema !30_V	et	f	\N
112464	ütlesid	ütlesid =ütle  (IndIpfPl3  >ütlema !30_V	et	f	\N
112467	õigeusku	õigeusku =usku  (SgP  >õige+usk !22_S	et	f	\N
112469	õigeusku	õigeusku =usku  (SgAdt  >õige+usk !22_S	et	f	\N
112474	meyendoffid	### meyendoffid	et	f	\N
112506	sellist	sellist =selli  (SgEl  >sell !22_S	et	f	\N
112507	sellist	sellist =sellis  (SgP  >selline !10_P	et	f	\N
112508	sellist	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
112537	tulemiseks	tulemiseks =tulemise  (SgTr  >tulemine !12_S	et	f	\N
112538	tulemiseks	"tulemine %tule  )MINE_vS  <tulema ;36_V	et	f	\N
112539	tulemiseks	"tulemine %tulemi  )NE_aA  <tulem ;02_S	et	f	\N
112542	suuruse	suuruse =suuruse  (SgG  >suurus !11~09_S	et	f	\N
112543	suuruse	"suurus %suur  )US_aS  <suur ;13_A	et	f	\N
112544	suuruse	suuruse =suuruse  (SgG  >suurune !10~12_A	et	f	\N
111956	kuldraha	kuldraha =raha  (SgN  >kuld+raha !17_S	et	f	\N
111958	kuldraha	kuldraha =raha  (SgG  >kuld+raha !17_S	et	f	\N
111959	kuldraha	kuldraha =raha  (SgG  >kuld+rahk !22_S	et	f	\N
111960	kuldraha	kuldraha =raha  (SgP  >kuld+raha !17_S	et	f	\N
111975	luba	luba =luba  (SgN  >luba !18_S	et	f	\N
111977	luba	luba =luba  (SgP  >luba !18_S	et	f	\N
111979	luba	luba =luba  (IndPrPs_  >lubama !27_V	et	f	\N
111981	luba	luba =luba  (ImpPrSg2  >lubama !27_V	et	f	\N
111993	parimaid	parimaid =parima  (PlP  >parim !02_A	et	f	\N
111994	parimaid	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
112002	panna	panna =pann  (Inf  >panema !36_V	et	f	\N
112005	panna	panna =panna  (SgN  >panna !16_S	et	f	\N
112006	panna	panna =panna  (SgG  >panna !16_S	et	f	\N
112007	panna	panna =panna  (SgG  >pand !22_S	et	f	\N
112030	viidi	viidi =vii  (IndIpfIps  >viima !38_V	et	f	\N
112031	viidi	viidi =viidi  (SgG  >viit !22_S	et	f	\N
112038	asus	asus =asu  (SgIn  >asu !17_S	et	f	\N
112039	asus	asus =asu  (PlIn  >ask !22_S	et	f	\N
112040	asus	asus =asu  (IndIpfSg3  >asuma !27_V	et	f	\N
112043	rabas	rabas =raba  (SgIn  >raba !17_S	et	f	\N
112044	rabas	rabas =raba  (IndIpfSg3  >rabama !27_V	et	f	\N
112051	viiva	viiva =viiva  (SgG  >viiv !02_A	et	f	\N
112054	viiva	"viiv %vii  )V_vA  <viima ;38_V	et	f	\N
112062	äärde	äärde =äär  (SgAdt  >äär !13_S	et	f	\N
112063	äärde	äärde =äärde  (ID  >äärde !41_K	et	f	\N
112066	kalmu	kalmu =kalmu  (SgG  >kalm !22_S	et	f	\N
112067	kalmu	kalmu =kalmu  (SgP  >kalm !22_S	et	f	\N
112068	kalmu	kalmu =kalmu  (SgAdt  >kalm !22_S	et	f	\N
112091	poliitvangide	### poliitvangide	et	f	\N
112114	lodijarve	?lodijarve =lodijarve  (PlP  >lodijarv !22_S	et	f	\N
112121	kuuldud	kuuldud =kuul  (PtsPtIps  >kuulma !33_V	et	f	\N
112122	kuuldud	kuuldud =kuuldu  (PlN  >kuuldu !01_S	et	f	\N
112123	kuuldud	"kuuldu %kuul  )TU1_vS  <kuulma ;33_V	et	f	\N
112124	kuuldud	kuuldud =kuuldu  (IndPrSg2  >kuulduma !27_V	et	f	\N
112125	kuuldud	kuuldud =kuuldud  (ID  >kuuldud !41_A	et	f	\N
112126	kuuldud	"kuuldud %kuul  )TUD_vA  <kuulma ;33_V	et	f	\N
112127	seostavad	seostavad =seosta  (IndPrPl3  >seostama !27_V	et	f	\N
112128	seostavad	seostavad =seostava  (PlN  >seostav !02_A	et	f	\N
112129	seostavad	"seostav %seosta  )V_vA  <seostama ;27_V	et	f	\N
112150	peavad	peavad =pea  (IndPrPl3  >pida !40_V	et	f	\N
112151	peavad	peavad =pea  (IndPrPl3  >pidama !28_V	et	f	\N
112155	laenatud	laenatud =laena  (PtsPtIps  >laenama !29_V	et	f	\N
112157	laenatud	laenatud =laenatu  (PlN  >laenatu !01_AS	et	f	\N
112159	laenatud	"laenatu %laena  )TU1_vS  <laenama ;29_V	et	f	\N
112160	laenatud	laenatud =laenatud  (ID  >laenatud !41_A	et	f	\N
112162	laenatud	"laenatud %laena  )TUD_vA  <laenama ;29_V	et	f	\N
112165	lodensee	?lodensee =lodensee  (SgN  >lodensee !26_S	et	f	\N
112166	lodensee	?lodensee =lodensee  (SgG  >lodensee !26_S	et	f	\N
112168	valmis	valmis =valmi  (SgIn  >valmis !02_A	et	f	\N
112169	valmis	valmis =valmi  (SgIn  >valm !22_S	et	f	\N
112170	valmis	valmis =valmi  (IndIpfSg3  >valmima !27_V	et	f	\N
112171	valmis	valmis =valmis  (ID  >valmis !41_DA	et	f	\N
112172	valmis	valmis =valmis  (SgN  >valmis !02_A	et	f	\N
112174	varemeid	varemeid =vareme  (PlP  >varem !02_A	et	f	\N
112175	varemeid	varemeid =vareme  (PlP  >vare !04_S	et	f	\N
112176	asukohta	asukohta =kohta  (SgP  >asu+koht !22_S	et	f	\N
112177	asukohta	asukohta =kohta  (SgAdt  >asu+koht !22_S	et	f	\N
112195	tamme	tamme =tamme  (SgG  >tamm !22_S	et	f	\N
112198	tamme	tamme =tamme  (SgP  >tamm !22_S	et	f	\N
112200	tamme	tamme =tamme  (SgAdt  >tamm !22_S	et	f	\N
112201	tamme	tamme =tamme  (PlP  >tamm !22_S	et	f	\N
112210	laiematki	laiematki =laiema  (SgP^  >laiem !02_A	et	f	\N
112211	laiematki	"laiem %laie  )M_cA^  <lai ;22_A	et	f	\N
112226	ammu	ammu =ammu  (ID  >ammu !41_D	et	f	\N
112227	ammu	ammu =ammu  (SgG  >amb !22_S	et	f	\N
112228	ammu	ammu =ammu  (IndPrPs_  >ammuma !28_V	et	f	\N
112229	ammu	ammu =ammu  (IndPrPs_  >ambuma !28_V	et	f	\N
112230	ammu	ammu =ammu  (ImpPrSg2  >ammuma !28_V	et	f	\N
112231	ammu	ammu =ammu  (ImpPrSg2  >ambuma !28_V	et	f	\N
112253	esitati	esitati =esita  (IndIpfIps  >esitama !27_V	et	f	\N
112254	esitati	esitati =tati  (SgG  >esi+tatt !22_S	et	f	\N
112263	tuginev	tuginev =tugine  (PtsPrPs  >tuginema !27_V	et	f	\N
112264	tuginev	tuginev =tuginev  (SgN  >tuginev !02_A	et	f	\N
112265	tuginev	"tuginev %tugine  )V_vA  <tuginema ;27_V	et	f	\N
112276	sarnane	sarnane =sarnane  (SgN  >sarnane !10_A	et	f	\N
112277	sarnane	"sarnane %sarna  )NE_aA  <sarn ;22_S	et	f	\N
112278	sarnane	sarnane =sarnane  (IndPrPs_  >sarnanema !27_V	et	f	\N
112279	sarnane	sarnane =sarnane  (ImpPrSg2  >sarnanema !27_V	et	f	\N
112301	ilmus	ilmus =ilmu  (PlIn  >ilm !22_S	et	f	\N
112302	ilmus	ilmus =ilmu  (IndIpfSg3  >ilmuma !27_V	et	f	\N
112315	band	?band =band  (SgN  >band !22_S	et	f	\N
112322	juhti	juhti =juhti  (SgP  >juht !22_S	et	f	\N
112324	juhti	juhti =juhti  (SgAdt  >juht !22_S	et	f	\N
112333	tõelise	tõelise =tõelise  (SgG  >tõeline !12?10_A	et	f	\N
112008	võetud	võetud =võe  (PtsPtIps  >võtma !35_V	et	f	\N
112009	võetud	võetud =võetu  (PlN  >võetu !01_S	et	f	\N
112011	võetud	"võetu %võe  )TU1_vS  <võtma ;35_V	et	f	\N
112013	võetud	võetud =võetud  (ID  >võetud !41_A	et	f	\N
112015	võetud	"võetud %võe  )TUD_vA  <võtma ;35_V	et	f	\N
112045	surnuid	surnuid =surnu  (PlP  >surnu !01_S	et	f	\N
112046	surnuid	"surnu %sur  )NU_vS  <surema ;36_V	et	f	\N
112047	surnuid	surnuid =surnu  (PlP  >surnu !06_S	et	f	\N
112074	vähemalt	vähemalt =vähema  (SgAbl  >vähem !02_A	et	f	\N
112075	vähemalt	"vähem %vähe  )M_cA  <väike ;10_A	et	f	\N
112076	vähemalt	vähemalt =vähemalt  (ID  >vähemalt !41_D	et	f	\N
112077	vähemalt	"vähemalt %vähema  )LT_mD  <vähem ;02_A	et	f	\N
112078	vähemalt	vähemalt =alt  (SgN  >vähem+alt !22_S	et	f	\N
112081	uurimistööid	?uurimistööid =uurimistööi  (PlN  >uurimistööi !26_S	et	f	\N
112082	uurimistööid	?uurimistööid =uurimistööi  (SgP  >uurimistööi !26_S	et	f	\N
112083	uurimistööid	?uurimistööid =uurimistööid  (SgN  >uurimistööid !22_S	et	f	\N
112084	uurimistööid	?uurimistööid =tööid  (SgN  >uurimis+tööid !02_S	et	f	\N
112094	matmispaiga	matmispaiga =pai  (SgKom  >matmis+pai !26_AS	et	f	\N
112095	matmispaiga	matmispaiga =paiga  (SgG  >matmis+paik !22_S	et	f	\N
112096	eksperimentaalbioloogia	eksperimentaalbioloogia =bioloogia  (SgN  >eksperimentaal+bioloogia !01_S	et	f	\N
112097	eksperimentaalbioloogia	eksperimentaalbioloogia =bioloogia  (SgG  >eksperimentaal+bioloogia !01_S	et	f	\N
112103	eduard	?eduard =eduard  (SgN  >eduard !22_S	et	f	\N
112105	eduard	?eduard =ard  (SgN  >edu+ard !22_S	et	f	\N
112133	mõjul	mõjul =mõju  (SgAd  >mõju !17_S	et	f	\N
112135	mõjul	mõjul =mõjul  (ID  >mõjul !41_K	et	f	\N
112139	lodijärv	?lodijärv =lodijärv  (SgN  >lodijärv !22_S	et	f	\N
112156	klooga	?klooga =kloo  (SgKom  >kloo !26_S	et	f	\N
112158	klooga	?klooga =klooga  (SgN  >klooga !16_S	et	f	\N
112161	klooga	?klooga =klooga  (SgG  >klooga !16_S	et	f	\N
112163	klooga	?klooga =klooga  (IndPrPs_  >kloogama !29_V	et	f	\N
112164	klooga	?klooga =klooga  (ImpPrSg2  >kloogama !29_V	et	f	\N
112218	säilinud	säilinud =säili  (PtsPtPs  >säilima !28_V	et	f	\N
112219	säilinud	säilinud =säilinu  (PlN  >säilinu !01_S	et	f	\N
112220	säilinud	"säilinu %säili  )NU_vS  <säilima ;28_V	et	f	\N
112222	säilinud	säilinud =säilinud  (ID  >säilinud !41_A	et	f	\N
112224	säilinud	"säilinud %säili  )NUD_vA  <säilima ;28_V	et	f	\N
112251	ilmumise	ilmumise =ilmumise  (SgG  >ilmumine !12_S	et	f	\N
112252	ilmumise	"ilmumine %ilmu  )MINE_vS  <ilmuma ;27_V	et	f	\N
112260	legendi	legendi =legendi  (SgG  >legend !22_S	et	f	\N
112261	legendi	legendi =legendi  (SgP  >legend !22_S	et	f	\N
112262	legendi	legendi =legendi  (SgAdt  >legend !22_S	et	f	\N
112270	eksisteerisid	eksisteerisid =eksisteeri  (IndIpfSg2  >eksisteerima !28_V	et	f	\N
112271	eksisteerisid	eksisteerisid =eksisteeri  (IndIpfPl3  >eksisteerima !28_V	et	f	\N
112272	eksisteerisid	eksisteerisid =eri  (PlP  >eks+iste+eri !17_S	et	f	\N
112273	eksisteerisid	eksisteerisid =steeri  (PlP  >eksi+steer !22_S	et	f	\N
112280	bornhöhele	?bornhöhele =bornhöhele  (PlP  >bornhöhel !19_S	et	f	\N
112283	nähtud	nähtud =näh  (PtsPtIps  >nägema !28_V	et	f	\N
112284	nähtud	nähtud =nähtu  (PlN  >nähtu !01_S	et	f	\N
112285	nähtud	"nähtu %näh  )TU1_vS  <nägema ;28_V	et	f	\N
112287	nähtud	nähtud =nähtu  (IndPrSg2  >nähtuma !27_V	et	f	\N
112289	nähtud	"nähtud %näh  )TUD_vA  <nägema ;28_V	et	f	\N
112294	kirjutamist	kirjutamist =kirjutamis  (SgP  >kirjutamine !12_S	et	f	\N
112295	kirjutamist	"kirjutamine %kirjuta  )MINE_vS  <kirjutama ;27_V	et	f	\N
112303	richtersi	?richtersi =richtersi  (SgN  >richtersi !01_S	et	f	\N
112305	richtersi	?richtersi =richtersi  (SgG  >richtersi !01_S	et	f	\N
112308	richtersi	?richtersi =richtersi  (SgG  >richters !02_S	et	f	\N
112310	richtersi	?richtersi =richtersi  (SgG  >richterss !22_S	et	f	\N
112311	richtersi	?richtersi =richtersi  (IndPrPs_  >richterssima !28_V	et	f	\N
112313	richtersi	?richtersi =richtersi  (ImpPrSg2  >richterssima !28_V	et	f	\N
112319	vanuse	vanuse =vanuse  (SgG  >vanus !09_S	et	f	\N
112320	vanuse	vanuse =vanuse  (SgG  >vanune !10_A	et	f	\N
112337	esinemiseaja	?esinemiseaja =esinemiseaja  (SgN  >esinemiseaja !01_S	et	f	\N
112339	esinemiseaja	?esinemiseaja =esinemiseaja  (SgG  >esinemiseaja !01_S	et	f	\N
112341	esinemiseaja	?esinemiseaja =esinemiseaja  (SgG  >esinemiseajas !02_A	et	f	\N
112342	esinemiseaja	?esinemiseaja =eaja  (SgN  >esinemis+eaja !01_S	et	f	\N
112344	esinemiseaja	?esinemiseaja =eaja  (SgG  >esinemis+eaja !01_S	et	f	\N
112346	esinemiseaja	?esinemiseaja =nemiseaja  (SgN  >esi+nemiseaja !01_S	et	f	\N
112347	esinemiseaja	?esinemiseaja =nemiseaja  (SgG  >esi+nemiseaja !01_S	et	f	\N
112348	esinemiseaja	?esinemiseaja =nemiseaja  (SgG  >esi+nemiseajas !02_A	et	f	\N
112349	kaevamisi	kaevamisi =kaevamisi  (PlP  >kaevamine !12_S	et	f	\N
112350	kaevamisi	"kaevamine %kaeva  )MINE_vS  <kaevama ;29_V	et	f	\N
112360	rajatud	rajatud =raja  (PtsPtIps  >rajama !27_V	et	f	\N
112362	rajatud	rajatud =rajatu  (PlN  >rajatu !01_AS	et	f	\N
112364	rajatud	"rajatu %raja  )TU1_vS  <rajama ;27_V	et	f	\N
112366	rajatud	"rajatu %raja  )TU2_kA  <raja ;17_S	et	f	\N
112109	1862-	### 1862-	et	f	\N
112112	kirjeldatud	kirjeldatud =kirjelda  (PtsPtIps  >kirjeldama !27_V	et	f	\N
112113	kirjeldatud	kirjeldatud =kirjeldatu  (PlN  >kirjeldatu !01_S	et	f	\N
112115	kirjeldatud	"kirjeldatu %kirjelda  )TU1_vS  <kirjeldama ;27_V	et	f	\N
112116	kirjeldatud	kirjeldatud =kirjeldatud  (ID  >kirjeldatud !41_A	et	f	\N
112117	kirjeldatud	"kirjeldatud %kirjelda  )TUD_vA  <kirjeldama ;27_V	et	f	\N
112130	tekkinud	tekkinud =tekki  (PtsPtPs  >tekkima !27~28_V	et	f	\N
112131	tekkinud	tekkinud =tekkinu  (PlN  >tekkinu !01_S	et	f	\N
112132	tekkinud	"tekkinu %tekki  )NU_vS  <tekkima ;27_V	et	f	\N
112134	tekkinud	"tekkinu %tekki  )NU_vS  <tekkima ;28_V	et	f	\N
112136	tekkinud	tekkinud =tekkinud  (ID  >tekkinud !41_A	et	f	\N
112137	tekkinud	"tekkinud %tekki  )NUD_vA  <tekkima ;27_V	et	f	\N
112138	tekkinud	"tekkinud %tekki  )NUD_vA  <tekkima ;28_V	et	f	\N
112152	õigemaks	õigemaks =õigema  (SgTr  >õigem !02_A	et	f	\N
112153	õigemaks	"õigem %õige  )M_cA  <õige ;01_A	et	f	\N
112154	õigemaks	õigemaks =maks  (SgN  >õige+maks !22_S	et	f	\N
112167	paarkümmend	?paarkümmend =paarkümmend  (SgN  >paarkümmend !22_S	et	f	\N
112178	metsatalu	metsatalu =talu  (SgN  >metsa+talu !17_S	et	f	\N
112179	metsatalu	metsatalu =talu  (SgG  >metsa+talu !17_S	et	f	\N
112180	metsatalu	metsatalu =talu  (SgP  >metsa+talu !17_S	et	f	\N
112181	tambetit	### tambetit	et	f	\N
112182	raudrõngastki	raudrõngastki =rõnga  (SgEl^  >raud+rõngas !07_S	et	f	\N
112183	raudrõngastki	raudrõngastki =rõngas  (SgP^  >raud+rõngas !07_S	et	f	\N
112184	raudrõngastki	raudrõngastki =rõngas  (SgP^  >raud+rõngane !10_A	et	f	\N
112185	raudrõngastki	"raud+rõngane %rõnga  )NE_aA^  <raud+rõngas ;07_S	et	f	\N
112194	kahte	kahte =kahte  (SgP  >kaks !22_N	et	f	\N
112196	kahte	kahte =kahte  (SgAdt  >kaks !22_N	et	f	\N
112202	isa	isa =isa  (SgN  >isa !17_S	et	f	\N
112203	isa	isa =isa  (SgG  >isa !17_S	et	f	\N
112205	isa	isa =isa  (SgP  >isa !17_S	et	f	\N
112212	neist	neist =ne  (PlEl  >see !00_P	et	f	\N
112213	neist	neist =ne  (PlEl  >ta !00_P	et	f	\N
112214	tammedest	tammedest =tamme  (PlEl  >tamm !22_S	et	f	\N
112215	tammedest	tammedest =ede  (SgEl  >tamm+ede !16_S	et	f	\N
112216	tammedest	tammedest =edes  (SgP  >tamm+edene !10_A	et	f	\N
112217	tammedest	"tamm+edene %ede  )NE_aA  <tamm+ede ;16_S	et	f	\N
112232	murdunud	murdunud =murdu  (PtsPtPs  >murduma !27_V	et	f	\N
112233	murdunud	murdunud =murdunu  (PlN  >murdunu !01_S	et	f	\N
112234	murdunud	"murdunu %murdu  )NU_vS  <murduma ;27_V	et	f	\N
112237	murdunud	murdunud =murdunud  (ID  >murdunud !41_A	et	f	\N
112240	murdunud	"murdunud %murdu  )NUD_vA  <murduma ;27_V	et	f	\N
112243	seast	seast =sea  (SgEl  >siga !18_SA	et	f	\N
112245	seast	seast =seast  (ID  >seast !41_K	et	f	\N
112255	ajalooliste	ajalooliste =loolis  (PlG  >aja+looline !12?10_A	et	f	\N
112256	ajalooliste	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
112257	ajalooliste	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
112258	ajalooliste	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
112259	ajalooliste	ajalooliste =loolis  (PlG  >aja+looline !12?10_S	et	f	\N
112306	verkhrs-	?verkhrs- =verkhrs  (SgN  >verkhrs !22_S	et	f	\N
112314	adressebücher	?adressebücher =adressebücher  (SgN  >adressebücher !02_S	et	f	\N
112316	estland	?estland =estland  (SgN  >estland !02_S	et	f	\N
112321	eestlaste	eestlaste =eestlas  (PlG  >eestlane !12?10_S	et	f	\N
112323	eestlaste	eestlaste =las  (PlG  >eest+laps !14_S	et	f	\N
112325	eestlaste	eestlaste =laste  (PlP  >eest+last !22_S	et	f	\N
112327	esinesid	esinesid =esine  (IndIpfSg2  >esinema !27_V	et	f	\N
112328	esinesid	esinesid =esine  (IndIpfPl3  >esinema !27_V	et	f	\N
112343	selgitamiseks	selgitamiseks =selgitamise  (SgTr  >selgitamine !12_S	et	f	\N
112345	selgitamiseks	"selgitamine %selgita  )MINE_vS  <selgitama ;27_V	et	f	\N
112353	mainitud	mainitud =maini  (PtsPtIps  >mainima !28_V	et	f	\N
112354	mainitud	mainitud =mainitu  (PlN  >mainitu !01_S	et	f	\N
112355	mainitud	"mainitu %maini  )TU1_vS  <mainima ;28_V	et	f	\N
112356	mainitud	mainitud =mainitud  (ID  >mainitud !41_A	et	f	\N
112357	mainitud	"mainitud %maini  )TUD_vA  <mainima ;28_V	et	f	\N
112358	väike	väike =väike  (SgN  >väike !12?10_A	et	f	\N
112359	väike	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
112363	aastatel	aastatel =aasta  (PlAd  >aasta !01_S	et	f	\N
112365	aastatel	aastatel =tate  (PlAd  >aas+tatt !22_S	et	f	\N
112370	knopius	?knopius =knopiu  (SgIn  >knopiu !01_S	et	f	\N
112371	knopius	?knopius =knopius  (SgN  >knopius !11_S	et	f	\N
112372	saigi	saigi =sa  (IndIpfSg3^  >saama !37_V	et	f	\N
112373	saigi	saigi =sai  (SgN^  >sai !22_S	et	f	\N
112415	kahekorruseline	kahekorruseline =korruseline  (SgN  >kahe+korruseline !12_A	et	f	\N
112416	kahekorruseline	"kahe+korruseline %korruse  )LINE_aA  <kahe+korrus ;09_S	et	f	\N
112422	puust	puust =puu  (SgEl  >puu !26_S	et	f	\N
112423	puust	puust =puus  (SgP  >puune !10_A	et	f	\N
112447	laia	laia =laia  (SgG  >laid !22_S	et	f	\N
112448	laia	laia =laia  (SgG  >lai !22_A	et	f	\N
112450	laia	laia =laia  (SgP  >lai !22_A	et	f	\N
112451	laia	laia =laia  (SgAdt  >lai !22_A	et	f	\N
112143	tulnud	tulnud =tulnu  (PlN  >tulnu !06_S	et	f	\N
112144	tulnud	tulnud =tulnud  (ID  >tulnud !41_A	et	f	\N
112145	tulnud	"tulnud %tul  )NUD_vA  <tulema ;36_V	et	f	\N
112186	külge	külge =külge  (ID  >külge !41_DK	et	f	\N
112187	külge	külge =külge  (SgP  >külg !22_S	et	f	\N
112188	külge	külge =külge  (SgAdt  >külg !22_S	et	f	\N
112189	külge	külge =külge  (PlP  >külg !22_S	et	f	\N
112190	needitud	needitud =needi  (PtsPtIps  >neetima !28_V	et	f	\N
112191	needitud	needitud =needitu  (PlN  >needitu !01_AS	et	f	\N
112192	needitud	"needitu %needi  )TU1_vS  <neetima ;28_V	et	f	\N
112193	needitud	"needitu %needi  )TU2_kA  <neet ;22_S	et	f	\N
112197	needitud	needitud =needitud  (ID  >needitud !41_A	et	f	\N
112199	needitud	"needitud %needi  )TUD_vA  <neetima ;28_V	et	f	\N
112266	ajalookronoloogia	ajalookronoloogia =kronoloogia  (SgN  >aja+loo+kronoloogia !01_S	et	f	\N
112267	ajalookronoloogia	ajalookronoloogia =kronoloogia  (SgG  >aja+loo+kronoloogia !01_S	et	f	\N
112268	osas	osas =osa  (SgIn  >osa !17_S	et	f	\N
112269	osas	osas =osas  (ID  >osas !41_K	et	f	\N
112274	kelle	kelle =kelle  (SgG  >kes !00_P	et	f	\N
112275	kelle	kelle =kelle  (PlP  >kell !22_S	et	f	\N
112281	võõras	võõras =võõra  (SgIn  >võõras !07_AS	et	f	\N
112282	võõras	võõras =võõras  (SgN  >võõras !07_AS	et	f	\N
112286	ringi	ringi =ringi  (ID  >ringi !41_DK	et	f	\N
112288	ringi	ringi =ringi  (SgG  >ring !22_S	et	f	\N
112290	ringi	ringi =ringi  (SgP  >ring !22_S	et	f	\N
112291	ringi	ringi =ringi  (SgAdt  >ring !22_S	et	f	\N
112292	ringi	ringi =ringi  (IndPrPs_  >ringima !28_V	et	f	\N
112293	ringi	ringi =ringi  (ImpPrSg2  >ringima !28_V	et	f	\N
112329	ilmumist	ilmumist =ilmumis  (SgP  >ilmumine !12_S	et	f	\N
112330	ilmumist	"ilmumine %ilmu  )MINE_vS  <ilmuma ;27_V	et	f	\N
112331	kõigi	kõigi =kõigi  (PlG  >kõik !00_P	et	f	\N
112332	kõigi	kõigi =kõigi  (SgG  >kõik !22_S	et	f	\N
112335	tekkimise	tekkimise =tekkimise  (SgG  >tekkimine !12_S	et	f	\N
112338	tekkimise	"tekkimine %tekki  )MINE_vS  <tekkima ;27_V	et	f	\N
112340	tekkimise	"tekkimine %tekki  )MINE_vS  <tekkima ;28_V	et	f	\N
112361	1620tel	### 1620tel	et	f	\N
112377	aadliperekonna	aadliperekonna =konna  (SgG  >aadli+pere+konn !22_S	et	f	\N
112378	aadliperekonna	aadliperekonna =konna  (SgP  >aadli+pere+konn !22_S	et	f	\N
112379	aadliperekonna	aadliperekonna =konna  (SgAdt  >aadli+pere+konn !22_S	et	f	\N
112380	aadliperekonna	aadliperekonna =perekonna  (SgG  >aadli+perekond !22_S	et	f	\N
112381	valduses	valduses =valduse  (SgIn  >valdus !11~09_S	et	f	\N
112382	valduses	valduses =use  (PlIn  >vald+usk !22_S	et	f	\N
112400	peahoone	peahoone =hoone  (SgN  >pea+hoone !06_S	et	f	\N
112401	peahoone	"pea+hoone %hoo  )NE_aA  <pea+hoog ;22_S	et	f	\N
112402	peahoone	peahoone =hoone  (SgG  >pea+hoone !06_S	et	f	\N
112403	peahoone	peahoone =hoone  (PlP  >pea+hoon !22_A	et	f	\N
112404	kaunistused	kaunistused =kaunistuse  (PlN  >kaunistus !11_S	et	f	\N
112405	kaunistused	"kaunistus %kaunista  )US_vS  <kaunistama ;27_V	et	f	\N
112424	kasutusel	kasutusel =kasutuse  (SgAd  >kasutus !11_S	et	f	\N
112425	kasutusel	"kasutus %kasuta  )US_vS  <kasutama ;27_V	et	f	\N
112426	kasutusel	"kasutus %kasu  )TUS2_aS  <kasu ;17_S	et	f	\N
112431	põlises	põlises =põlise  (SgIn  >põline !10_A	et	f	\N
112432	põlises	"põline %põli  )NE_aA  <põli ;24_S	et	f	\N
112433	kahes	kahes =kahe  (SgIn  >kaks !22_N	et	f	\N
112434	kahes	kahes =kahe  (PlIn  >kahk !22_S	et	f	\N
112444	meyendoffe	?meyendoffe =meyendoffe  (PlP  >meyendoff !22_S	et	f	\N
112446	mothander	?mothander =mothander  (SgN  >mothander !02_S	et	f	\N
112456	meyendorff	### meyendorff	et	f	\N
112465	pöördusid	pöördusid =pöördu  (IndIpfSg2  >pöörduma !27_V	et	f	\N
112466	pöördusid	pöördusid =pöördu  (IndIpfPl3  >pöörduma !27_V	et	f	\N
112481	suguluses	suguluses =suguluse  (SgIn  >sugulus !11_S	et	f	\N
112482	suguluses	"sugulus %sugulase  )US_aS  <sugulane ;12_S	et	f	\N
112489	eestisse	eestisse =eesti  (SgIll  >eesti !16_H	et	f	\N
112490	eestisse	eestisse =tisse  (PlP  >ees+tiss !22_S	et	f	\N
112494	paremaid	paremaid =parema  (PlP  >parem !02_A	et	f	\N
112495	paremaid	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
112502	kodupaigast	kodupaigast =paiga  (SgEl  >kodu+paik !22_S	et	f	\N
112503	kodupaigast	kodupaigast =paigas  (SgP  >kodu+paigas !09_S	et	f	\N
112504	kodupaigast	kodupaigast =paigas  (SgP  >kodu+paigane !10_A	et	f	\N
112505	kodupaigast	"kodu+paigane %paiga  )NE_aA  <kodu+paik ;22_S	et	f	\N
112519	asutava	asutava =asutava  (SgG  >asutav !02_A	et	f	\N
112520	asutava	"asutav %asu  )TAV_vAS  <asuma ;27_V	et	f	\N
112521	asutava	"asutav %asuta  )V_vA  <asutama ;27_V	et	f	\N
112522	asutava	asutava =tava  (SgN  >asu+tava !17_S	et	f	\N
112523	asutava	asutava =tava  (SgG  >asu+tava !17_S	et	f	\N
112524	asutava	asutava =tava  (SgP  >asu+tava !17_S	et	f	\N
112529	valdusse	valdusse =valdus  (SgAdt  >valdus !11_S	et	f	\N
112530	valdusse	valdusse =usse  (PlP  >vald+uss !22_S	et	f	\N
112531	toime	toime =toime  (SgN  >toime !06_S	et	f	\N
112532	toime	toime =toime  (SgG  >toime !06_S	et	f	\N
112533	toime	toime =toime  (SgG  >toim !22_S	et	f	\N
112334	tõelise	"tõeline %tõe  )LINE_aA  <tõsi ;15_S	et	f	\N
112336	tõelise	"tõeline %tõe  )LINE_aA  <tõde ;18_S	et	f	\N
112351	juhendamisel	juhendamisel =juhendamise  (SgAd  >juhendamine !12_S	et	f	\N
112352	juhendamisel	"juhendamine %juhenda  )MINE_vS  <juhendama ;27_V	et	f	\N
112376	meyendolffide	### meyendolffide	et	f	\N
112385	baltlastele	baltlastele =baltlas  (PlAll  >baltlane !12?10_S	et	f	\N
112386	baltlastele	baltlastele =las  (PlAll  >balt+laps !14_S	et	f	\N
112387	baltlastele	baltlastele =laste  (PlAll  >balt+last !22_S	et	f	\N
112406	1910tel	### 1910tel	et	f	\N
112407	põhjapoole	põhjapoole =poole  (SgN  >põhja+poole !05_S	et	f	\N
112409	põhjapoole	põhjapoole =poole  (SgG  >põhja+pool !13_NS	et	f	\N
112411	põhjapoole	põhjapoole =poole  (PlP  >põhja+pool !22_S	et	f	\N
112429	venepärane	venepärane =pärane  (SgN  >vene+pärane !10_A	et	f	\N
112430	venepärane	"vene+pärane %pära  )NE_aA  <vene+pära ;17_S	et	f	\N
112449	maailma	maailma =maailma  (ID  >maa+ilma !41_D	et	f	\N
112452	maailma	maailma =ilma  (SgG  >maa+ilm !22_S	et	f	\N
112453	maailma	maailma =ilma  (SgP  >maa+ilm !22_S	et	f	\N
112454	maailma	maailma =ilma  (SgAdt  >maa+ilm !22_S	et	f	\N
112476	tsaari	tsaari =tsaari  (SgG  >tsaar !22_S	et	f	\N
112477	tsaari	tsaari =tsaari  (SgP  >tsaar !22_S	et	f	\N
112478	tsaari	tsaari =tsaari  (SgAdt  >tsaar !22_S	et	f	\N
112491	kumnasse	?kumnasse =kumna  (SgIll  >kumna !16_S	et	f	\N
112492	kumnasse	?kumnasse =kumnasse  (SgG  >kumnasne !02_A	et	f	\N
112493	kumnasse	?kumnasse =kumnasse  (PlP  >kumnass !22_S	et	f	\N
112500	moodustasid	moodustasid =moodusta  (IndIpfSg2  >moodustama !27_V	et	f	\N
112501	moodustasid	moodustasid =moodusta  (IndIpfPl3  >moodustama !27_V	et	f	\N
112512	kaugemaid	kaugemaid =kaugema  (PlP  >kaugem !02_A	et	f	\N
112513	kaugemaid	"kaugem %kauge  )M_cA  <kauge ;01_A	et	f	\N
112514	kaugemaid	kaugemaid =ma  (PlP  >kauge+maa !26_S	et	f	\N
112515	kaugemaid	kaugemaid =mai  (PlN  >kauge+mai !26_S	et	f	\N
112516	kaugemaid	kaugemaid =mai  (SgP  >kauge+mai !26_S	et	f	\N
112525	maareformi	maareformi =reformi  (SgG  >maa+reform !22_S	et	f	\N
112526	maareformi	maareformi =reformi  (SgP  >maa+reform !22_S	et	f	\N
112527	maareformi	maareformi =reformi  (SgAdt  >maa+reform !22_S	et	f	\N
112559	jooma	jooma =joo  (Sup  >jooma !38_V	et	f	\N
112560	jooma	jooma =jooma  (SgG  >joom !22_S	et	f	\N
112561	jooma	jooma =jooma  (SgP  >joom !22_S	et	f	\N
112562	jooma	jooma =jooma  (SgAdt  >joom !22_S	et	f	\N
112575	vabameelselt	vabameelselt =meelse  (SgAbl  >vaba+meelne !02_A	et	f	\N
112576	vabameelselt	"vaba+meelselt %meelse  )LT_mD  <vaba+meelne ;02_A	et	f	\N
112582	hoonete	hoonete =hoone  (PlG  >hoone !06_S	et	f	\N
112583	hoonete	"hoone %hoo  )NE_aA  <hoog ;22_S	et	f	\N
112615	varjatud	varjatud =varja  (PtsPtIps  >varjama !29_V	et	f	\N
112616	varjatud	varjatud =varjatu  (PlN  >varjatu !01_AS	et	f	\N
112617	varjatud	"varjatu %varja  )TU1_vS  <varjama ;29_V	et	f	\N
112618	varjatud	"varjatu %varja  )TU2_kA  <vari ;24_S	et	f	\N
112619	varjatud	varjatud =varjatud  (ID  >varjatud !41_A	et	f	\N
112620	varjatud	"varjatud %varja  )TUD_vA  <varjama ;29_V	et	f	\N
112642	külalisi	külalisi =külalisi  (PlP  >külaline !12_S	et	f	\N
112643	külalisi	"külaline %küla  )LINE_aA  <küla ;17_S	et	f	\N
112652	lõbustus	lõbustus =lõbustu  (IndIpfSg3  >lõbustuma !27_V	et	f	\N
112653	lõbustus	lõbustus =lõbustus  (SgN  >lõbustus !11_S	et	f	\N
112654	lõbustus	"lõbustus %lõbusta  )US_vS  <lõbustama ;27_V	et	f	\N
112670	teistest	teistest =teis  (PlEl  >teine !12_OP	et	f	\N
112671	teistest	teistest =teis  (PlEl  >teise !12_P	et	f	\N
112672	teistest	teistest =teiste  (PlEl  >teist !22_S	et	f	\N
112673	teistest	teistest =test  (SgN  >teis+test !22_S	et	f	\N
112698	vabastav	vabastav =vabasta  (PtsPrPs  >vabastama !27_V	et	f	\N
112699	vabastav	vabastav =vabastav  (SgN  >vabastav !02_A	et	f	\N
112700	vabastav	"vabastav %vabasta  )V_vA  <vabastama ;27_V	et	f	\N
112703	vabadus	vabadus =vabadus  (SgN  >vabadus !11_S	et	f	\N
112705	vabadus	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
112707	sellisena	sellisena =sellise  (SgEs  >selline !10_P	et	f	\N
112708	sellisena	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
112709	ajalukku	ajalukku =lukku  (SgP  >aja+lukk !22_S	et	f	\N
112711	ajalukku	ajalukku =lukku  (SgAdt  >aja+lugu !18_S	et	f	\N
112713	ajalukku	ajalukku =lukku  (SgAdt  >aja+lukk !22_S	et	f	\N
112715	leppesgute	?leppesgute =leppesgu  (PlG  >leppesgu !01_S	et	f	\N
112716	leppesgute	?leppesgute =leppesgu  (IndPrPl2  >leppesguma !27_V	et	f	\N
112719	budbergide	### budbergide	et	f	\N
112745	läheduses	läheduses =läheduse  (SgIn  >lähedus !11_S	et	f	\N
112746	läheduses	"lähedus %läheda  )US_aS  <läheda ;02_A	et	f	\N
112749	hoogustus	hoogustus =hoogustu  (IndIpfSg3  >hoogustuma !27_V	et	f	\N
112753	hoogustus	hoogustus =hoogustus  (SgN  >hoogustus !11_S	et	f	\N
112754	hoogustus	"hoogustus %hoogusta  )US_vS  <hoogustama ;27_V	et	f	\N
112760	invaliididekodu	?invaliididekodu =invaliididekodu  (IndPrPs_  >invaliididekoduma !27_V	et	f	\N
112761	invaliididekodu	?invaliididekodu =invaliididekodu  (ImpPrSg2  >invaliididekoduma !27_V	et	f	\N
112762	invaliididekodu	?invaliididekodu =dekodu  (SgN  >invaliidi+dekodu !01_S	et	f	\N
112367	rajatud	"rajatu %raja  )TU2_kA  <rada ;18_S	et	f	\N
112368	rajatud	rajatud =rajatud  (ID  >rajatud !41_A	et	f	\N
112369	rajatud	"rajatud %raja  )TUD_vA  <rajama ;27_V	et	f	\N
112388	põlve	põlve =põlve  (SgG  >põlv !22_S	et	f	\N
112389	põlve	põlve =põlve  (SgG  >põli !24_S	et	f	\N
112390	põlve	põlve =põlve  (SgP  >põlv !22_S	et	f	\N
112391	põlve	põlve =põlve  (SgP  >põli !24_S	et	f	\N
112392	põlve	põlve =põlve  (SgAdt  >põlv !22_S	et	f	\N
112393	põlve	põlve =põlve  (SgAdt  >põli !24_S	et	f	\N
112394	põlve	põlve =põlve  (PlP  >põlv !22_S	et	f	\N
112395	venestunud	venestunud =venestu  (PtsPtPs  >venestuma !27_V	et	f	\N
112396	venestunud	venestunud =venestunu  (PlN  >venestunu !01_S	et	f	\N
112397	venestunud	"venestunu %venestu  )NU_vS  <venestuma ;27_V	et	f	\N
112398	venestunud	venestunud =venestunud  (ID  >venestunud !41_A	et	f	\N
112399	venestunud	"venestunud %venestu  )NUD_vA  <venestuma ;27_V	et	f	\N
112408	peahoonest	peahoonest =hoone  (SgEl  >pea+hoone !06_S	et	f	\N
112410	peahoonest	"pea+hoone %hoo  )NE_aA  <pea+hoog ;22_S	et	f	\N
112412	peahoonest	peahoonest =hoone  (PlEl  >pea+hoon !22_A	et	f	\N
112413	peahoonest	peahoonest =hoones  (SgP  >pea+hoonene !10_A	et	f	\N
112414	peahoonest	"pea+hoonene %hoone  )NE_aA  <pea+hoone ;06_S	et	f	\N
112417	perekonda	perekonda =perekonda  (SgP  >perekond !22_S	et	f	\N
112418	perekonda	perekonda =perekonda  (SgAdt  >perekond !22_S	et	f	\N
112419	sovhoosi	sovhoosi =sovhoosi  (SgG  >sovhoos !22_S	et	f	\N
112420	sovhoosi	sovhoosi =sovhoosi  (SgP  >sovhoos !22_S	et	f	\N
112421	sovhoosi	sovhoosi =sovhoosi  (SgAdt  >sovhoos !22_S	et	f	\N
112427	uuem	uuem =uuem  (SgN  >uuem !02_A	et	f	\N
112428	uuem	"uuem %uue  )M_cA  <uus ;14_A	et	f	\N
112435	ehitatud	ehitatud =ehita  (PtsPtIps  >ehitama !27_V	et	f	\N
112436	ehitatud	ehitatud =ehitatu  (PlN  >ehitatu !01_S	et	f	\N
112437	ehitatud	"ehitatu %ehita  )TU1_vS  <ehitama ;27_V	et	f	\N
112438	ehitatud	ehitatud =ehitatud  (ID  >ehitatud !41_A	et	f	\N
112439	ehitatud	"ehitatud %ehita  )TUD_vA  <ehitama ;27_V	et	f	\N
112440	villas	villas =villa  (SgIn  >villa !16_S	et	f	\N
112441	villas	villas =villa  (SgIn  >vill !22_S	et	f	\N
112442	põlvkonda	põlvkonda =põlvkonda  (SgP  >põlvkond !22_S	et	f	\N
112443	põlvkonda	põlvkonda =põlvkonda  (SgAdt  >põlvkond !22_S	et	f	\N
112457	pojad	pojad =poja  (PlN  >poja !17_S	et	f	\N
112458	pojad	pojad =poja  (PlN  >poeg !22_S	et	f	\N
112479	kõrgetele	kõrgetele =kõrge  (PlAll  >kõrge !01_A	et	f	\N
112480	kõrgetele	kõrgetele =e  (PlAll  >kõrg+esi !15_S	et	f	\N
112487	põgenesid	põgenesid =põgene  (IndIpfSg2  >põgenema !27_V	et	f	\N
112488	põgenesid	põgenesid =põgene  (IndIpfPl3  >põgenema !27_V	et	f	\N
112496	aegu	aegu =aegu  (ID  >aegu !41_DK	et	f	\N
112497	aegu	aegu =aegu  (PlP  >aeg !22_S	et	f	\N
112498	aegu	aegu =aegu  (IndPrPs_  >aeguma !27_V	et	f	\N
112499	aegu	aegu =aegu  (ImpPrSg2  >aeguma !27_V	et	f	\N
112609	pingutusi	pingutusi =pingutusi  (PlP  >pingutus !11_S	et	f	\N
112611	pingutusi	"pingutus %pinguta  )US_vS  <pingutama ;27_V	et	f	\N
112613	pingutusi	"pingutus %pingu  )TUS2_aS  <ping ;22_S	et	f	\N
112621	avatud	avatud =ava  (PtsPtIps  >avama !27_V	et	f	\N
112623	avatud	avatud =avatu  (PlN  >avatu !01_AS	et	f	\N
112625	avatud	"avatu %ava  )TU1_vS  <avama ;27_V	et	f	\N
112627	avatud	"avatu %ava  )TU2_kA  <ava ;17_S	et	f	\N
112628	avatud	avatud =avatud  (ID  >avatud !41_A	et	f	\N
112629	avatud	"avatud %ava  )TUD_vA  <avama ;27_V	et	f	\N
112634	mitmelt	mitmelt =mitme  (SgAbl  >mitu !05_P	et	f	\N
112635	mitmelt	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
112637	päri	päri =päri  (ID  >päri !41_D	et	f	\N
112638	päri	päri =päri  (IndPrPs_  >pärima !27_V	et	f	\N
112639	päri	päri =päri  (ImpPrSg2  >pärima !27_V	et	f	\N
112644	tosin	?tosin =tosi  (IndPrSg1  >tosima !27_V	et	f	\N
112645	tosin	?tosin =tosin  (SgN  >tosin !02_NS	et	f	\N
112648	külaline	külaline =külaline  (SgN  >külaline !12_S	et	f	\N
112649	külaline	"külaline %küla  )LINE_aA  <küla ;17_S	et	f	\N
112655	külalised	külalised =külalise  (PlN  >külaline !12_S	et	f	\N
112656	külalised	"külaline %küla  )LINE_aA  <küla ;17_S	et	f	\N
112663	kumnat	?kumnat =kumna  (SgP  >kumna !16_S	et	f	\N
112664	kumnat	?kumnat =kumnat  (SgN  >kumnat !02_S	et	f	\N
112665	selliseks	selliseks =sellise  (SgTr  >selline !10_P	et	f	\N
112666	selliseks	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
112694	kilkamise	kilkamise =kilkamise  (SgG  >kilkamine !12_S	et	f	\N
112695	kilkamise	"kilkamine %kilka  )MINE_vS  <kilkama ;29_V	et	f	\N
112696	imetabane	imetabane =tabane  (SgN  >ime+tabane !10_A	et	f	\N
112697	imetabane	"ime+tabane %taba  )NE_aA  <ime+taba ;17_S	et	f	\N
112717	linnusele	linnusele =linnuse  (SgAll  >linnus !09_S	et	f	\N
112718	linnusele	linnusele =use  (PlAll  >linn+usk !22_S	et	f	\N
112740	eestimaale	eestimaale =maa  (SgAll  >eesti+maa !26_S	et	f	\N
112741	eestimaale	eestimaale =maale  (PlP  >eesti+maal !22_S	et	f	\N
112764	olulisi	olulisi =olulisi  (PlP  >oluline !12_A	et	f	\N
112765	olulisi	"oluline %olu  )LINE_aA  <olu ;17_S	et	f	\N
112455	georg	?georg =georg  (SgN  >georg !02_S	et	f	\N
112459	lahti	lahti =lahti  (ID  >lahti !41_D	et	f	\N
112460	lahti	lahti =lahti  (SgP  >laht !22_S	et	f	\N
112461	lahti	lahti =lahti  (SgAdt  >laht !22_S	et	f	\N
112462	lahti	lahti =lahti  (PlP  >laht !22_S	et	f	\N
112468	astusid	astusid =astu  (IndIpfSg2  >astuma !28_V	et	f	\N
112470	astusid	astusid =astu  (IndIpfPl3  >astuma !28_V	et	f	\N
112471	tõusid	tõusid =tõu  (PlP  >tõu !26_S	et	f	\N
112472	tõusid	tõusid =tõus  (IndIpfSg2  >tõusma !32_V	et	f	\N
112473	tõusid	tõusid =tõus  (IndIpfPl3  >tõusma !32_V	et	f	\N
112475	tõusid	tõusid =tõusi  (PlN  >tõus !22_S	et	f	\N
112483	romanovite	?romanovite =romanovi  (PlG  >romanov !02_A	et	f	\N
112484	revolutsiooni	revolutsiooni =revolutsiooni  (SgG  >revolutsioon !22_S	et	f	\N
112485	revolutsiooni	revolutsiooni =revolutsiooni  (SgP  >revolutsioon !22_S	et	f	\N
112486	revolutsiooni	revolutsiooni =revolutsiooni  (SgAdt  >revolutsioon !22_S	et	f	\N
112509	lahkelt	lahkelt =lahke  (SgAbl  >lahke !01_A	et	f	\N
112510	lahkelt	lahkelt =lahkelt  (ID  >lahkelt !41_D	et	f	\N
112511	lahkelt	"lahkelt %lahke  )LT_mD  <lahke ;01_A	et	f	\N
112517	lähemaid	lähemaid =lähema  (PlP  >lähem !02_A	et	f	\N
112518	lähemaid	"lähem %lähe  )M_cA  <lähike ;12_A	et	f	\N
112528	meyendorfide	?meyendorfide =meyendorfi  (PlG  >meyendorf !22_S	et	f	\N
112540	külalistel	külalistel =külalis  (PlAd  >külaline !12_S	et	f	\N
112541	külalistel	"külaline %küla  )LINE_aA  <küla ;17_S	et	f	\N
112546	viisaja	viisaja =viisaja  (SgN  >viisaja !01_S	et	f	\N
112547	viisaja	"viisaja %viisa  )JA_vS  <viisama ;29_V	et	f	\N
112548	viisaja	viisaja =viisaja  (SgG  >viisaja !01_S	et	f	\N
112549	viisaja	viisaja =aja  (SgG  >viis+aeg !22_S	et	f	\N
112550	kandsid	kandsid =kand  (IndIpfSg2  >kandma !34_V	et	f	\N
112551	kandsid	kandsid =kand  (IndIpfPl3  >kandma !34_V	et	f	\N
112554	esiema	esiema =ema  (SgN  >esi+ema !17_S	et	f	\N
112556	esiema	esiema =ema  (SgG  >esi+ema !17_S	et	f	\N
112558	esiema	esiema =ema  (SgP  >esi+ema !17_S	et	f	\N
112564	valdkonna	valdkonna =valdkonna  (SgG  >valdkond !22_S	et	f	\N
112565	valdkonna	valdkonna =konna  (SgG  >vald+konn !22_S	et	f	\N
112568	valdkonna	valdkonna =konna  (SgP  >vald+konn !22_S	et	f	\N
112569	valdkonna	valdkonna =konna  (SgAdt  >vald+konn !22_S	et	f	\N
112578	kunstnikulohakus	kunstnikulohakus =lohakus  (SgN  >kunstniku+lohakus !11_S	et	f	\N
112579	kunstnikulohakus	"kunstniku+lohakus %lohaka  )US_aS  <kunstniku+lohakas ;02_A	et	f	\N
112581	meyendoffide	?meyendoffide =meyendoffi  (PlG  >meyendoff !22_S	et	f	\N
112591	pudipadist	?pudipadist =pudipadis  (SgP  >pudipadis !09_S	et	f	\N
112592	pudipadist	?pudipadist =pudipadist  (SgN  >pudipadist !22_S	et	f	\N
112593	pudipadist	?pudipadist =padis  (SgP  >pudi+padis !09_S	et	f	\N
112594	pudipadist	?pudipadist =padist  (SgN  >pudi+padist !22_S	et	f	\N
112599	odavamate	odavamate =odavama  (PlG  >odavam !02_A	et	f	\N
112600	odavamate	"odavam %odava  )M_cA  <odav ;02_A	et	f	\N
112601	odavamate	odavamate =mate  (SgN  >odava+mate !16_S	et	f	\N
112602	odavamate	odavamate =mate  (SgG  >odava+mate !16_S	et	f	\N
112605	tehtud	tehtud =teh  (PtsPtIps  >tegema !28_V	et	f	\N
112607	tehtud	tehtud =tehtu  (PlN  >tehtu !01_S	et	f	\N
112610	tehtud	"tehtu %teh  )TU1_vS  <tegema ;28_V	et	f	\N
112612	tehtud	tehtud =tehtud  (ID  >tehtud !41_A	et	f	\N
112614	tehtud	"tehtud %teh  )TUD_vA  <tegema ;28_V	et	f	\N
112622	kumnas	?kumnas =kumna  (SgIn  >kumna !16_S	et	f	\N
112624	kumnas	?kumnas =kumna  (IndIpfSg3  >kumnama !29_V	et	f	\N
112626	kumnas	?kumnas =kumnas  (SgN  >kumnas !07_S	et	f	\N
112650	voodi	voodi =voodi  (SgN  >voodi !01_S	et	f	\N
112651	voodi	voodi =voodi  (SgG  >voodi !01_S	et	f	\N
112657	käia	käia =käi  (Inf  >käima !38_V	et	f	\N
112658	käia	käia =käia  (SgG  >käi !22_S	et	f	\N
112659	käia	käia =käia  (SgP  >käi !22_S	et	f	\N
112660	käia	käia =käia  (SgAdt  >käi !22_S	et	f	\N
112661	käia	käia =käia  (IndPrPs_  >käiama !29_V	et	f	\N
112662	käia	käia =käia  (ImpPrSg2  >käiama !29_V	et	f	\N
112674	ajaloosse	ajaloosse =loo  (SgIll  >aja+lugu !18_S	et	f	\N
112675	ajaloosse	ajaloosse =loo  (SgIll  >aja+loog !22_S	et	f	\N
112676	ajaloosse	ajaloosse =loo  (SgIll  >aja+lood !22_S	et	f	\N
112679	kavalerid	kavalerid =kavaleri  (PlN  >kavaler !19_S	et	f	\N
112680	kavalerid	kavalerid =eri  (PlN  >kaval+eri !17_S	et	f	\N
112683	ime	ime =ime  (SgN  >ime !16_S	et	f	\N
112684	ime	ime =ime  (SgG  >ime !16_S	et	f	\N
112685	ime	ime =ime  (IndPrPs_  >imema !27_V	et	f	\N
112688	ime	ime =ime  (ImpPrSg2  >imema !27_V	et	f	\N
112720	puhkekohana	puhkekohana =koha  (SgEs  >puhke+koha !17_S	et	f	\N
112721	puhkekohana	puhkekohana =koha  (SgEs  >puhke+koht !22_S	et	f	\N
112729	srajas	?srajas =sraja  (SgIn  >sraja !17_S	et	f	\N
112731	srajas	?srajas =sraja  (IndIpfSg3  >srajama !27_V	et	f	\N
112732	srajas	?srajas =srajas  (SgN  >srajas !09_S	et	f	\N
112737	itaalia	?itaalia =itaalia  (SgN  >itaalia !01_S	et	f	\N
112738	itaalia	?itaalia =itaalia  (SgG  >itaalia !01_S	et	f	\N
112777	neogooti	neogooti =gooti  (SgP  >neo+goot !22_S	et	f	\N
112534	toime	toime =toime  (SgP  >toim !22_S	et	f	\N
112535	toime	toime =toime  (SgAdt  >toim !22_S	et	f	\N
112536	toime	toime =toime  (PlP  >toim !22_S	et	f	\N
112555	juurde	juurde =juur  (SgAdt  >juur !13_S	et	f	\N
112557	juurde	juurde =juurde  (ID  >juurde !41_DK	et	f	\N
112563	aru	aru =aru  (SgN  >aru !17_S	et	f	\N
112566	aru	aru =aru  (SgG  >aru !17_S	et	f	\N
112567	aru	aru =aru  (SgP  >aru !17_S	et	f	\N
112574	riietusid	riietusid =riietu  (IndIpfSg2  >riietuma !27_V	et	f	\N
112577	riietusid	riietusid =riietu  (IndIpfPl3  >riietuma !27_V	et	f	\N
112580	mothanderi	?mothanderi =mothanderi  (SgG  >mothander !02_S	et	f	\N
112584	luksusest	luksusest =luksuse  (SgEl  >luksus !11~09_S	et	f	\N
112585	luksusest	luksusest =luksuses  (SgP  >luksusene !12_A	et	f	\N
112586	luksusest	"luksusene %luksuse  )NE_aA  <luksus ;09_S	et	f	\N
112587	luksusest	"luksusene %luksuse  )NE_aA  <luksus ;11_S	et	f	\N
112588	luksusest	luksusest =use  (PlEl  >luks+usk !22_S	et	f	\N
112603	imeliseks	imeliseks =imelise  (SgTr  >imeline !12_A	et	f	\N
112604	imeliseks	"imeline %ime  )LINE_aA  <ime ;16_S	et	f	\N
112630	peeti	peeti =pee  (IndIpfIps  >pidama !28_V	et	f	\N
112631	peeti	peeti =peeti  (SgP  >peet !22_S	et	f	\N
112632	peeti	peeti =peeti  (SgAdt  >peet !22_S	et	f	\N
112646	parimas	parimas =parima  (SgIn  >parim !02_A	et	f	\N
112647	parimas	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
112667	loomulikult	loomulikult =loomuliku  (SgAbl  >loomulik !25_A	et	f	\N
112668	loomulikult	loomulikult =loomulikult  (ID  >loomulikult !41_D	et	f	\N
112669	loomulikult	"loomulikult %loomuliku  )LT_mD  <loomulik ;25_A	et	f	\N
112677	paiga	paiga =pai  (SgKom  >pai !26_AS	et	f	\N
112678	paiga	paiga =paiga  (SgG  >paik !22_S	et	f	\N
112681	masurka	masurka =masurka  (SgN  >masurka !16_S	et	f	\N
112682	masurka	masurka =masurka  (SgG  >masurka !16_S	et	f	\N
112689	kära	kära =kära  (SgN  >kära !17_S	et	f	\N
112690	kära	kära =kära  (SgG  >kära !17_S	et	f	\N
112691	kära	kära =kära  (SgP  >kära !17_S	et	f	\N
112692	kära	kära =kära  (IndPrPs_  >kärama !27_V	et	f	\N
112693	kära	kära =kära  (ImpPrSg2  >kärama !27_V	et	f	\N
112701	minnalaskmisemeeleolu	?minnalaskmisemeeleolu =minnalaskmisemeeleolu  (IndPrPs_  >minnalaskmisemeeleoluma !27_V	et	f	\N
112702	minnalaskmisemeeleolu	?minnalaskmisemeeleolu =minnalaskmisemeeleolu  (ImpPrSg2  >minnalaskmisemeeleoluma !27_V	et	f	\N
112714	pansionaatena	?pansionaatena =pansionaate  (SgEs  >pansionaate !16_S	et	f	\N
112722	tuntuks	tuntuks =tun  (KndPtIps  >tundma !34_V	et	f	\N
112723	tuntuks	tuntuks =tuntu  (SgTr  >tuntu !01_S	et	f	\N
112724	tuntuks	"tuntu %tun  )TU1_vS  <tundma ;34_V	et	f	\N
112734	jalamile	jalamile =jalami  (SgAll  >jalam !02_S	et	f	\N
112736	jalamile	jalamile =mi  (SgAll  >jala+mi !26_S	et	f	\N
112739	hoogu	hoogu =hoogu  (SgP  >hoog !22_S	et	f	\N
112742	hoogu	hoogu =hoogu  (SgAdt  >hoog !22_S	et	f	\N
112750	aastakümneid	?aastakümneid =aastakümnei  (PlN  >aastakümnei !26_S	et	f	\N
112751	aastakümneid	?aastakümneid =aastakümnei  (SgP  >aastakümnei !26_S	et	f	\N
112752	aastakümneid	?aastakümneid =kümnei  (PlN  >aasta+kümnei !26_S	et	f	\N
112755	aastakümneid	?aastakümneid =kümnei  (SgP  >aasta+kümnei !26_S	et	f	\N
112756	aastakümneid	?aastakümneid =kümneid  (SgN  >aasta+kümneid !22_S	et	f	\N
112757	aastakümneid	?aastakümneid =takümne  (PlP  >aas+takümni !01_S	et	f	\N
112758	aastakümneid	?aastakümneid =takümnei  (PlN  >aas+takümnei !26_S	et	f	\N
112759	aastakümneid	?aastakümneid =takümnei  (SgP  >aas+takümnei !26_S	et	f	\N
112770	mõisast	mõisast =mõisa  (SgEl  >mõis !02_S	et	f	\N
112771	mõisast	mõisast =mõisas  (SgP  >mõisane !10_A	et	f	\N
112772	mõisast	"mõisane %mõisa  )NE_aA  <mõis ;02_S	et	f	\N
112783	alustati	alustati =alusta  (IndIpfIps  >alustama !27_V	et	f	\N
112784	alustati	alustati =tati  (SgG  >alus+tatt !22_S	et	f	\N
112791	teadmata	teadmata =tead  (SupAb  >teadma !34_V	et	f	\N
112792	teadmata	teadmata =teadmata  (ID  >teadmata !41_A	et	f	\N
112793	teadmata	"teadmata %tead  )MATA_vA  <teadma ;34_V	et	f	\N
112801	karl	?karl =karl  (SgN  >karl !22_S	et	f	\N
112804	volmer	?volmer =volmer  (SgN  >volmer !02_S	et	f	\N
112812	maikuust	maikuust =kuu  (SgEl  >mai+kuu !26_S	et	f	\N
112813	maikuust	maikuust =kuus  (SgP  >mai+kuune !10_A	et	f	\N
112814	maikuust	"mai+kuune %kuu  )NE_aA  <mai+kuu ;26_S	et	f	\N
112816	kanadasse	?kanadasse =kanadas  (SgAdt  >kanadane !12_A	et	f	\N
112817	kanadasse	?kanadasse =kanadasse  (SgG  >kanadasne !02_A	et	f	\N
112818	kanadasse	?kanadasse =kanadasse  (PlP  >kanadass !22_S	et	f	\N
112819	kanadasse	?kanadasse =dasse  (SgN  >kana+dasse !06_S	et	f	\N
112820	kanadasse	?kanadasse =dasse  (SgG  >kana+dasne !02_A	et	f	\N
112821	kanadasse	?kanadasse =dasse  (SgG  >kana+dasse !06_S	et	f	\N
112822	kanadasse	?kanadasse =dasse  (PlP  >kana+dass !22_S	et	f	\N
112834	ajakirja	ajakirja =kirja  (SgG  >aja+kiri !24_S	et	f	\N
112835	ajakirja	ajakirja =kirja  (SgP  >aja+kiri !24_S	et	f	\N
112836	ajakirja	ajakirja =kirja  (SgAdt  >aja+kiri !24_S	et	f	\N
112844	kultuurivara	kultuurivara =vara  (SgN  >kultuuri+vara !17_S	et	f	\N
112845	kultuurivara	kultuurivara =vara  (SgG  >kultuuri+vara !17_S	et	f	\N
112545	suuruse	suuruse =ruse  (SgN  >suu+ruse !05_S	et	f	\N
112552	hoolt	hoolt =hoo  (SgAbl  >hoog !22_S	et	f	\N
112553	hoolt	hoolt =hool  (SgP  >hool !13_S	et	f	\N
112570	lasid	lasid =las  (IndIpfSg2  >laskma !34_V	et	f	\N
112571	lasid	lasid =las  (IndIpfPl3  >laskma !34_V	et	f	\N
112572	lasid	lasid =la  (PlP  >la !26_S	et	f	\N
112573	lasid	lasid =lasi  (PlN  >lasi !17_S	et	f	\N
112589	odavast	odavast =odava  (SgEl  >odav !02_A	et	f	\N
112590	odavast	odavast =ast  (SgN  >odav+ast !22_S	et	f	\N
112595	vaimustav	vaimustav =vaimusta  (PtsPrPs  >vaimustama !27_V	et	f	\N
112596	vaimustav	vaimustav =vaimustav  (SgN  >vaimustav !02_A	et	f	\N
112597	vaimustav	"vaimustav %vaimusta  )V_vA  <vaimustama ;27_V	et	f	\N
112598	vaimustav	vaimustav =ustav  (SgN  >vaim+ustav !02_A	et	f	\N
112606	erilisi	erilisi =erilisi  (PlP  >eriline !12_A	et	f	\N
112608	erilisi	"eriline %eri  )LINE_aA  <eri ;17_S	et	f	\N
112633	pansionaati	pansionaati =pansionaati  (SgP  >pansionaat !22_S	et	f	\N
112636	pansionaati	pansionaati =pansionaati  (SgAdt  >pansionaat !22_S	et	f	\N
112640	tosinale	tosinale =ale  (SgN  >tosin+ale !16_S	et	f	\N
112641	tosinale	tosinale =ale  (SgG  >tosin+ale !16_S	et	f	\N
112686	välismaa	välismaa =maa  (SgN  >välis+maa !26_S	et	f	\N
112687	välismaa	välismaa =maa  (SgG  >välis+maa !26_S	et	f	\N
112704	kõikidest	kõikidest =kõiki  (PlEl  >kõik !00_P	et	f	\N
112706	kõikidest	kõikidest =kõiki  (PlEl  >kõik !22_S	et	f	\N
112710	imelise	imelise =imelise  (SgG  >imeline !12_A	et	f	\N
112712	imelise	"imeline %ime  )LINE_aA  <ime ;16_S	et	f	\N
112725	kaupmees	kaupmees =mee  (SgIn  >kaup+mesi !15_S	et	f	\N
112726	kaupmees	kaupmees =mees  (SgN  >kaup+mees !13_S	et	f	\N
112727	girard	?girard =girard  (SgN  >girard !02_S	et	f	\N
112728	tiskresse	?tiskresse =tiskre  (SgIll  >tiskre !06_S	et	f	\N
112730	tiskresse	?tiskresse =tiskres  (SgAdt  >tiskrene !12_A	et	f	\N
112733	tiskresse	?tiskresse =tiskresse  (SgG  >tiskresne !02_A	et	f	\N
112735	tiskresse	?tiskresse =tiskresse  (PlP  >tiskress !22_S	et	f	\N
112743	1950ndatel	?ndatel =ndate  (PlAd  >ndatt !22_S	et	f	\N
112744	1950ndatel	?ndatel =ndatel  (SgN  >ndatel !02_S	et	f	\N
112747	ehitamise	ehitamise =ehitamise  (SgG  >ehitamine !12_S	et	f	\N
112748	ehitamise	"ehitamine %ehita  )MINE_vS  <ehitama ;27_V	et	f	\N
112766	suurbritannia	?suurbritannia =suurbritannia  (SgN  >suurbritannia !01_S	et	f	\N
112767	suurbritannia	?suurbritannia =suurbritannia  (SgG  >suurbritannia !01_S	et	f	\N
112768	suurbritannia	?suurbritannia =britannia  (SgN  >suur+britannia !01_S	et	f	\N
112769	suurbritannia	?suurbritannia =britannia  (SgG  >suur+britannia !01_S	et	f	\N
112774	pidama	pidama =pida  (Sup  >pida !40_V	et	f	\N
112775	pidama	pidama =pida  (Sup  >pidama !28_V	et	f	\N
112779	stiilis	stiilis =stiili  (SgIn  >stiil !22_S	et	f	\N
112780	stiilis	stiilis =stiili  (IndIpfSg3  >stiilima !28_V	et	f	\N
112797	iseseisvakskoguduseks	?iseseisvakskoguduseks =iseseisvakskoguduse  (SgTr  >iseseisvakskogudus !11?09_S	et	f	\N
112798	iseseisvakskoguduseks	?iseseisvakskoguduseks =seisvakskoguduse  (SgTr  >ise+seisvakskogudus !11?09_S	et	f	\N
112802	dunkel	?dunkel =dunke  (SgAd  >dunge !06_S	et	f	\N
112803	dunkel	?dunkel =dunkel  (SgN  >dunkel !02_S	et	f	\N
112807	t	### t	et	f	\N
112829	kanada	?kanada =kana  (Inf  >kanama !27_V	et	f	\N
112847	vanu	vanu =vanu  (PlP  >vana !17_AS	et	f	\N
112848	vanu	vanu =vanu  (IndPrPs_  >vanuma !27_V	et	f	\N
112849	vanu	vanu =vanu  (ImpPrSg2  >vanuma !27_V	et	f	\N
112862	kohalikust	kohalikust =kohaliku  (SgEl  >kohalik !25_AS	et	f	\N
112864	kohalikust	kohalikust =kohalikus  (SgP  >kohalikus !11?09_S	et	f	\N
112866	kohalikust	"kohalikus %kohaliku  )US_aS  <kohalik ;25_AS	et	f	\N
112874	pühapäeviti	?pühapäeviti =pühapäevi  (IndIpfIps  >pühapäevima !28_V	et	f	\N
112875	pühapäeviti	?pühapäeviti =pühapäeviti  (ID  >pühapäeviti !41_D	et	f	\N
112876	pühapäeviti	?pühapäeviti =pühapäeviti  (SgG  >pühapäevitt !22_S	et	f	\N
112878	pühapäeviti	?pühapäeviti =pühapäeviti  (IndPrPs_  >pühapäevittima !28_V	et	f	\N
112879	pühapäeviti	?pühapäeviti =pühapäeviti  (ImpPrSg2  >pühapäevittima !28_V	et	f	\N
112881	pühapäeviti	?pühapäeviti =iti  (SgN  >püha+päev+iti !16_S	et	f	\N
112883	pühapäeviti	?pühapäeviti =iti  (SgG  >püha+päev+iti !16_S	et	f	\N
112884	pühapäeviti	?pühapäeviti =iti  (SgG  >püha+päev+itt !22_S	et	f	\N
112886	pühapäeviti	?pühapäeviti =päeviti  (SgG  >püha+päevit !02_S	et	f	\N
112888	pühapäeviti	?pühapäeviti =päeviti  (SgG  >püha+päevitt !22_S	et	f	\N
112897	korraldakse	?korraldakse =korraldakse  (SgG  >korraldakne !02_A	et	f	\N
112921	ostis	ostis =ost  (IndIpfSg3  >ostma !34_V	et	f	\N
112923	ostis	ostis =osti  (SgIn  >ost !22_S	et	f	\N
112957	risti	risti =risti  (ID  >risti !41_D	et	f	\N
112958	risti	risti =risti  (SgN  >risti !16_S	et	f	\N
112959	risti	risti =risti  (SgG  >risti !16_S	et	f	\N
112960	risti	risti =risti  (SgG  >rist !22_S	et	f	\N
112961	risti	risti =risti  (SgP  >rist !22_S	et	f	\N
112962	risti	risti =risti  (SgAdt  >rist !22_S	et	f	\N
112964	risti	risti =risti  (IndPrPs_  >ristima !28_V	et	f	\N
112966	risti	risti =risti  (ImpPrSg2  >ristima !28_V	et	f	\N
112763	invaliididekodu	?invaliididekodu =dekodu  (SgG  >invaliidi+dekodu !01_S	et	f	\N
112785	daniel	?daniel =danie  (SgAd  >danie !01_S	et	f	\N
112786	daniel	?daniel =daniel  (SgN  >daniel !19_S	et	f	\N
112839	õnnistati	õnnistati =õnnista  (IndIpfIps  >õnnistama !27_V	et	f	\N
112840	õnnistati	õnnistati =tati  (SgG  >õnnis+tatt !22_S	et	f	\N
112872	laiendamine	laiendamine =laiendamine  (SgN  >laiendamine !12_S	et	f	\N
112873	laiendamine	"laiendamine %laienda  )MINE_vS  <laiendama ;27_V	et	f	\N
112877	toimuvad	toimuvad =toimu  (IndPrPl3  >toimuma !27_V	et	f	\N
112880	toimuvad	toimuvad =toimuva  (PlN  >toimuv !02_A	et	f	\N
112882	toimuvad	"toimuv %toimu  )V_vA  <toimuma ;27_V	et	f	\N
112893	üüritus	üüritus =üüritu  (SgIn  >üüritu !01_AS	et	f	\N
112894	üüritus	"üüritu %üüri  )TU1_vS  <üürima ;28_V	et	f	\N
112895	üüritus	"üüritu %üüri  )TU2_kA  <üür ;22_S	et	f	\N
112896	üüritus	üüritus =üüritus  (SgN  >üüritus !11_S	et	f	\N
112898	üüritus	"üüritus %üüri  )TUS1_aS  <üürima ;28_V	et	f	\N
112899	üüritus	"üüritus %üüri  )TUS2_aS  <üür ;22_S	et	f	\N
112900	moodustus	moodustus =moodustu  (IndIpfSg3  >moodustuma !27_V	et	f	\N
112901	moodustus	moodustus =moodustus  (SgN  >moodustus !11_S	et	f	\N
112902	moodustus	"moodustus %moodusta  )US_vS  <moodustama ;27_V	et	f	\N
112905	merekülast	merekülast =küla  (SgEl  >mere+küla !17_S	et	f	\N
112906	merekülast	merekülast =külas  (SgP  >mere+külane !10_A	et	f	\N
112907	merekülast	"mere+külane %küla  )NE_aA  <mere+küla ;17_S	et	f	\N
112908	saj	### saj	et	f	\N
112933	mõisahooneks	mõisahooneks =hoone  (SgTr  >mõisa+hoone !06_S	et	f	\N
112934	mõisahooneks	"mõisa+hoone %hoo  )NE_aA  <mõisa+hoog ;22_S	et	f	\N
112935	mõisahooneks	mõisahooneks =hoone  (PlTr  >mõisa+hoon !22_A	et	f	\N
112939	mõisahoonet	mõisahoonet =hoone  (SgP  >mõisa+hoone !06_S	et	f	\N
112940	mõisahoonet	"mõisa+hoone %hoo  )NE_aA  <mõisa+hoog ;22_S	et	f	\N
112942	põhiliselt	põhiliselt =põhilise  (SgAbl  >põhiline !12_A	et	f	\N
112943	põhiliselt	põhiliselt =põhiliselt  (ID  >põhiliselt !41_D	et	f	\N
112944	põhiliselt	"põhiliselt %põhilise  )LT_mD  <põhiline ;12_A	et	f	\N
112963	lastekodu	lastekodu =kodu  (SgN  >laste+kodu !17_S	et	f	\N
112965	lastekodu	lastekodu =kodu  (SgG  >laste+kodu !17_S	et	f	\N
112967	lastekodu	lastekodu =kodu  (SgP  >laste+kodu !17_S	et	f	\N
112980	jäänud	jäänud =jää  (PtsPtPs  >jääma !37_V	et	f	\N
112982	jäänud	jäänud =jäänu  (PlN  >jäänu !01_S	et	f	\N
112983	jäänud	"jäänu %jää  )NU_vS  <jääma ;37_V	et	f	\N
112984	jäänud	jäänud =jäänu  (PlN  >jäänu !06_S	et	f	\N
112985	jäänud	jäänud =jäänud  (ID  >jäänud !41_A	et	f	\N
112986	jäänud	"jäänud %jää  )NUD_vA  <jääma ;37_V	et	f	\N
113012	mõisamaja	mõisamaja =maja  (SgN  >mõisa+maja !17_S	et	f	\N
113013	mõisamaja	mõisamaja =maja  (SgG  >mõisa+maja !17_S	et	f	\N
113016	mõisamaja	mõisamaja =maja  (SgP  >mõisa+maja !17_S	et	f	\N
113034	kuulsaks	kuulsaks =kuulsa  (SgTr  >kuulus !02_A	et	f	\N
113036	kuulsaks	kuulsaks =saks  (SgN  >kuul+saks !23?22_S	et	f	\N
113048	pedro	?pedro =pedro  (SgN  >pedro !16_S	et	f	\N
113049	pedro	?pedro =pedro  (SgG  >pedro !16_S	et	f	\N
113084	ateljeekoolis	ateljeekoolis =kooli  (SgIn  >ateljee+kool !22_S	et	f	\N
113086	ateljeekoolis	ateljeekoolis =kooli  (PlIn  >ateljee+kool !22_S	et	f	\N
113123	parimaks	parimaks =parima  (SgTr  >parim !02_A	et	f	\N
113124	parimaks	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
113125	loonud	loonud =loo  (PtsPtPs  >looma !38_V	et	f	\N
113126	loonud	loonud =loonu  (PlN  >loonu !01_S	et	f	\N
113127	loonud	"loonu %loo  )NU_vS  <looma ;38_V	et	f	\N
113128	loonud	loonud =loonu  (PlN  >loonu !06_S	et	f	\N
113129	loonud	loonud =loonud  (ID  >loonud !41_A	et	f	\N
113130	loonud	"loonud %loo  )NUD_vA  <looma ;38_V	et	f	\N
113131	karikaturis	?karikaturis =karikaturi  (SgIn  >karikatur !19_S	et	f	\N
113132	karikaturis	?karikaturis =karikaturis  (SgN  >karikaturis !09_S	et	f	\N
113133	karikaturis	?karikaturis =turis  (SgN  >karika+turis !09_S	et	f	\N
113134	karikaturis	?karikaturis =katuri  (SgIn  >kari+katuri !01_S	et	f	\N
113135	karikaturis	?karikaturis =katuri  (SgIn  >kari+katur !02_S	et	f	\N
113136	karikaturis	?karikaturis =katuris  (SgN  >kari+katuris !11_S	et	f	\N
113139	täna	täna =täna  (ID  >täna !41_D	et	f	\N
113140	täna	täna =täna  (IndPrPs_  >tänama !27_V	et	f	\N
113141	täna	täna =täna  (ImpPrSg2  >tänama !27_V	et	f	\N
113172	lõpetamist	lõpetamist =lõpetamis  (SgP  >lõpetamine !12_S	et	f	\N
113173	lõpetamist	"lõpetamine %lõpeta  )MINE_vS  <lõpetama ;27_V	et	f	\N
113184	ametlikult	ametlikult =ametliku  (SgAbl  >ametlik !25_A	et	f	\N
113185	ametlikult	ametlikult =ametlikult  (ID  >ametlikult !41_D	et	f	\N
113186	ametlikult	"ametlikult %ametliku  )LT_mD  <ametlik ;25_A	et	f	\N
113188	elukohaks	elukohaks =koha  (SgTr  >elu+koha !17_S	et	f	\N
113190	elukohaks	elukohaks =koha  (SgTr  >elu+koht !22_S	et	f	\N
113192	washington	?washington =washington  (SgN  >washington !02_S	et	f	\N
113214	salgamata	salgamata =salga  (SupAb  >salgama !29_V	et	f	\N
113216	salgamata	salgamata =salgamata  (ID  >salgamata !41_A	et	f	\N
112773	pidusid	pidusid =pidu  (PlP  >pidu !17_S	et	f	\N
112776	pidusid	pidusid =pidu  (PlP  >pidu !18_S	et	f	\N
112787	burchard	?burchard =burchard  (SgN  >burchard !02_S	et	f	\N
112788	altarimaali	altarimaali =maali  (SgG  >altari+maal !22_S	et	f	\N
112789	altarimaali	altarimaali =maali  (SgP  >altari+maal !22_S	et	f	\N
112790	altarimaali	altarimaali =maali  (SgAdt  >altari+maal !22_S	et	f	\N
112794	kabel	kabel =kabe  (SgAd  >kabe !16_S	et	f	\N
112795	kabel	kabel =kabel  (SgN  >kabel !02_S	et	f	\N
112796	kabel	kabel =kabel  (SgN  >kabel !24_S	et	f	\N
112806	lipsthal	?lipsthal =lipstha  (SgAd  >lipstha !01_S	et	f	\N
112808	lipsthal	?lipsthal =lipsthal  (SgN  >lipsthal !02_S	et	f	\N
112823	pikki	pikki =pikki  (SgP  >pikk !22_S	et	f	\N
112824	pikki	pikki =pikki  (SgP  >pikk !22_AS	et	f	\N
112825	pikki	pikki =pikki  (SgAdt  >pikk !22_S	et	f	\N
112826	pikki	pikki =pikki  (SgAdt  >pikk !22_AS	et	f	\N
112827	pikki	pikki =pikki  (PlP  >pikk !22_S	et	f	\N
112828	pikki	pikki =pikki  (PlP  >pikk !22_AS	et	f	\N
112830	luterlikku	?luterlikku =luterlikku  (SgP  >luterlik !25_A	et	f	\N
112831	luterlikku	?luterlikku =luterlikku  (SgAdt  >luterlik !25_A	et	f	\N
112832	luterlikku	?luterlikku =luterlikku  (IndPrPs_  >luterlikkuma !27_V	et	f	\N
112833	luterlikku	?luterlikku =luterlikku  (ImpPrSg2  >luterlikkuma !27_V	et	f	\N
112850	irdriste	irdriste =riste  (SgN  >ird+riste !05_S	et	f	\N
112852	irdriste	irdriste =riste  (PlP  >ird+rist !22_S	et	f	\N
112857	kasutusele	kasutusele =kasutuse  (SgAll  >kasutus !11_S	et	f	\N
112858	kasutusele	"kasutus %kasuta  )US_vS  <kasutama ;27_V	et	f	\N
112859	kasutusele	"kasutus %kasu  )TUS2_aS  <kasu ;17_S	et	f	\N
112870	hetkel	hetkel =hetke  (SgAd  >hetk !22_S	et	f	\N
112871	hetkel	hetkel =hetke  (PlAd  >hetk !22_S	et	f	\N
112912	grassile	?grassile =grassi  (SgAll  >grassi !16_S	et	f	\N
112913	grassile	?grassile =grassi  (SgAll  >grass !22_S	et	f	\N
112914	grassile	?grassile =grassile  (IndPrPs_  >grassilema !27_V	et	f	\N
112915	grassile	?grassile =grassile  (ImpPrSg2  >grassilema !27_V	et	f	\N
112941	härrarahvas	?härrarahvas =härrarahva  (SgIn  >härrarahva !16_S	et	f	\N
112952	punaste	punaste =punas  (PlG  >punane !10_AS	et	f	\N
112955	punaste	"punane %puna  )NE_aA  <puna ;17_S	et	f	\N
112976	maailmasõda	maailmasõda =sõda  (SgN  >maa+ilma+sõda !18_S	et	f	\N
112977	maailmasõda	maailmasõda =sõda  (SgP  >maa+ilma+sõda !18_S	et	f	\N
113010	13-	### 13-	et	f	\N
113056	hooldamine	hooldamine =hooldamine  (SgN  >hooldamine !12_S	et	f	\N
113057	hooldamine	"hooldamine %hoolda  )MINE_vS  <hooldama ;27_V	et	f	\N
113072	peegelduvad	peegelduvad =peegeldu  (IndPrPl3  >peegelduma !27_V	et	f	\N
113073	peegelduvad	peegelduvad =peegelduva  (PlN  >peegelduv !02_A	et	f	\N
113074	peegelduvad	"peegelduv %peegeldu  )V_vA  <peegelduma ;27_V	et	f	\N
113076	autobiograafilises	autobiograafilises =graafilise  (SgIn  >auto+bio+graafiline !12_A	et	f	\N
113078	autobiograafilises	"auto+bio+graafiline %graafi  )LINE_aA  <auto+bio+graaf ;22_S	et	f	\N
113079	autobiograafilises	autobiograafilises =biograafilise  (SgIn  >auto+biograafiline !12_A	et	f	\N
113080	autobiograafilises	"auto+biograafiline %biograafi  )LINE_aA  <auto+biograaf ;22_S	et	f	\N
113085	laikmaa	laikmaa =maa  (SgN  >laik+maa !26_S	et	f	\N
113087	laikmaa	laikmaa =maa  (SgG  >laik+maa !26_S	et	f	\N
113090	seltsi	seltsi =seltsi  (ID  >seltsi !41_A	et	f	\N
113091	seltsi	seltsi =seltsi  (ID  >seltsi !41_DK	et	f	\N
113093	seltsi	seltsi =seltsi  (SgG  >selts !22_S	et	f	\N
113095	seltsi	seltsi =seltsi  (SgP  >selts !22_S	et	f	\N
113096	seltsi	seltsi =seltsi  (SgAdt  >selts !22_S	et	f	\N
113097	seltsi	seltsi =seltsi  (IndPrPs_  >seltsima !28_V	et	f	\N
113098	seltsi	seltsi =seltsi  (ImpPrSg2  >seltsima !28_V	et	f	\N
113103	satiirkirjadele	?satiirkirjadele =satiirkirja  (PlAll  >satiirkirja !16_S	et	f	\N
113104	ösituled	### ösituled	et	f	\N
113105	gulbranssoni	?gulbranssoni =gulbransso  (SgTer  >gulbransso !01_S	et	f	\N
113107	gulbranssoni	?gulbranssoni =gulbranssoni  (SgG  >gulbransson !02_S	et	f	\N
113110	tabavalt	tabavalt =tabava  (SgAbl  >tabav !02_A	et	f	\N
113111	tabavalt	"tabav %taba  )V_vA  <tabama ;27_V	et	f	\N
113112	tabavalt	tabavalt =tabavalt  (ID  >tabavalt !41_D	et	f	\N
113113	tabavalt	"tabavalt %taba  )VALT_mD  <tabama ;27_V	et	f	\N
113114	tabavalt	"tabavalt %tabava  )LT_mD  <tabav ;02_A	et	f	\N
113137	vaesed	vaesed =vaese  (PlN  >vaene !10_AS	et	f	\N
113138	vaesed	"vaene %vae  )NE_aA  <vaag ;22_S	et	f	\N
113144	sarkastilisemate	sarkastilisemate =sarkastilisema  (PlG  >sarkastilisem !02_A	et	f	\N
113145	sarkastilisemate	"sarkastilisem %sarkastilise  )M_cA  <sarkastiline ;12_A	et	f	\N
113147	ajendasid	ajendasid =ajenda  (IndIpfSg2  >ajendama !27_V	et	f	\N
113148	ajendasid	ajendasid =ajenda  (IndIpfPl3  >ajendama !27_V	et	f	\N
113162	vaeste	vaeste =vaes  (PlG  >vaene !10_AS	et	f	\N
113163	vaeste	"vaene %vae  )NE_aA  <vaag ;22_S	et	f	\N
113164	murastes	?murastes =muras  (PlIn  >muras !09_S	et	f	\N
113165	murastes	?murastes =muras  (PlIn  >murane !10_A	et	f	\N
113181	saksamaale	saksamaale =maa  (SgAll  >saksa+maa !26_S	et	f	\N
113182	saksamaale	saksamaale =maale  (PlP  >saksa+maal !22_S	et	f	\N
113187	püsivaks	püsivaks =püsiva  (SgTr  >püsiv !02_A	et	f	\N
112778	neogooti	neogooti =gooti  (SgAdt  >neo+goot !22_S	et	f	\N
112781	ehitamist	ehitamist =ehitamis  (SgP  >ehitamine !12_S	et	f	\N
112782	ehitamist	"ehitamine %ehita  )MINE_vS  <ehitama ;27_V	et	f	\N
112799	organist	organist =organi  (SgEl  >organ !02_S	et	f	\N
112800	organist	organist =organist  (SgN  >organist !22_S	et	f	\N
112805	r	### r	et	f	\N
112809	oja	oja =oja  (SgN  >oja !17_S	et	f	\N
112810	oja	oja =oja  (SgG  >oja !17_S	et	f	\N
112811	oja	oja =oja  (SgP  >oja !17_S	et	f	\N
112815	oskar	?oskar =oskar  (SgN  >oskar !02_S	et	f	\N
112837	kalmistu	kalmistu =kalmistu  (SgN  >kalmistu !01_S	et	f	\N
112838	kalmistu	kalmistu =kalmistu  (SgG  >kalmistu !01_S	et	f	\N
112841	kunsti-	kunsti- =kunsti  (SgG  >kunst !22_S	et	f	\N
112842	kunsti-	kunsti- =kunsti  (SgP  >kunst !22_S	et	f	\N
112843	kunsti-	kunsti- =kunsti  (SgAdt  >kunst !22_S	et	f	\N
112851	hauatähiseid	hauatähiseid =tähise  (PlP  >haua+tähis !09_S	et	f	\N
112853	hauatähiseid	hauatähiseid =tähise  (PlP  >haua+tähine !10_A	et	f	\N
112854	hauatähiseid	"haua+tähine %tähi  )NE_aA  <haua+täht ;22_S	et	f	\N
112863	kultuuriloost	kultuuriloost =loo  (SgEl  >kultuuri+lugu !18_S	et	f	\N
112865	kultuuriloost	kultuuriloost =loo  (SgEl  >kultuuri+loog !22_S	et	f	\N
112867	kultuuriloost	kultuuriloost =loo  (SgEl  >kultuuri+lood !22_S	et	f	\N
112903	kurba	kurba =kurba  (SgP  >kurb !22_A	et	f	\N
112904	kurba	kurba =kurba  (SgAdt  >kurb !22_A	et	f	\N
112911	henning	?henning =henning  (SgN  >henning !02_S	et	f	\N
112916	panditi	panditi =pandi  (IndIpfIps  >pantima !28_V	et	f	\N
112917	panditi	panditi =panditi  (SgG  >pandit !02_S	et	f	\N
112918	korduvalt	korduvalt =korduva  (SgAbl  >korduv !02_A	et	f	\N
112919	korduvalt	"korduv %kordu  )V_vA  <korduma ;27_V	et	f	\N
112920	korduvalt	korduvalt =korduvalt  (ID  >korduvalt !41_D	et	f	\N
112922	korduvalt	"korduvalt %kordu  )VALT_mD  <korduma ;27_V	et	f	\N
112924	korduvalt	"korduvalt %korduva  )LT_mD  <korduv ;02_A	et	f	\N
112925	korduvalt	korduvalt =alt  (SgN  >korduv+alt !22_S	et	f	\N
112927	suurejoonelise	suurejoonelise =joonelise  (SgG  >suure+jooneline !12_A	et	f	\N
112928	suurejoonelise	"suure+jooneline %joone  )LINE_aA  <suure+joon ;13_S	et	f	\N
112929	suurejoonelise	"suure+jooneline %jooneli  )NE_aA  <suure+joonel ;02_S	et	f	\N
112930	varasemaks	varasemaks =varasema  (SgTr  >varasem !02_A	et	f	\N
112931	varasemaks	"varasem %vara  )SEM_cA  <vara ;17_S	et	f	\N
112932	varasemaks	"varasem %varase  )M_cA  <varane ;10_A	et	f	\N
112945	võõrandamist	võõrandamist =võõrandamis  (SgP  >võõrandamine !12_S	et	f	\N
112946	võõrandamist	"võõrandamine %võõranda  )MINE_vS  <võõrandama ;27_V	et	f	\N
112947	võõrandamist	võõrandamist =andami  (SgEl  >võõr+andam !02_S	et	f	\N
112948	võõrandamist	võõrandamist =andamis  (SgP  >võõr+andamine !12_S	et	f	\N
112949	võõrandamist	"võõr+andamine %andami  )NE_aA  <võõr+andam ;02_S	et	f	\N
112950	mõisahoonest	mõisahoonest =hoone  (SgEl  >mõisa+hoone !06_S	et	f	\N
112951	mõisahoonest	"mõisa+hoone %hoo  )NE_aA  <mõisa+hoog ;22_S	et	f	\N
112953	mõisahoonest	mõisahoonest =hoone  (PlEl  >mõisa+hoon !22_A	et	f	\N
112954	mõisahoonest	mõisahoonest =hoones  (SgP  >mõisa+hoonene !10_A	et	f	\N
112956	mõisahoonest	"mõisa+hoonene %hoone  )NE_aA  <mõisa+hoone ;06_S	et	f	\N
112968	teist	teist =te  (PlEl  >sa !00_P	et	f	\N
112969	teist	teist =teist  (SgG  >teist !05_N	et	f	\N
112970	teist	teist =teis  (SgP  >teist !05_N	et	f	\N
112971	teist	teist =teis  (SgP  >teine !12_OP	et	f	\N
112972	teist	teist =teis  (SgP  >teise !12_P	et	f	\N
112973	teist	teist =te  (PlEl  >tee !26_S	et	f	\N
112974	teist	teist =teist  (SgN  >teist !05_N	et	f	\N
112975	teist	teist =teist  (SgN  >teist !22_S	et	f	\N
113008	kohalikku	kohalikku =kohalikku  (SgP  >kohalik !25_AS	et	f	\N
113011	kohalikku	kohalikku =kohalikku  (SgAdt  >kohalik !25_AS	et	f	\N
113030	vanem	vanem =vanem  (SgN  >vanem !02_AS	et	f	\N
113031	vanem	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
113065	piltid	### piltid	et	f	\N
113146	hulka	hulka =hulka  (ID  >hulka !41_K	et	f	\N
113149	hulka	hulka =hulka  (SgP  >hulk !22_S	et	f	\N
113150	hulka	hulka =hulka  (SgAdt  >hulk !22_S	et	f	\N
113154	moodi	moodi =moodi  (SgP  >mood !22_S	et	f	\N
113155	moodi	moodi =moodi  (SgAdt  >mood !22_S	et	f	\N
113156	läinud	läinud =läi  (PtsPtPs  >minema !36_V	et	f	\N
113157	läinud	läinud =läinu  (PlN  >läinu !01_S	et	f	\N
113158	läinud	"läinu %läi  )NU_vS  <minema ;36_V	et	f	\N
113159	läinud	läinud =läinu  (PlN  >läinu !06_S	et	f	\N
113160	läinud	läinud =läinud  (ID  >läinud !41_A	et	f	\N
113161	läinud	"läinud %läi  )NUD_vA  <minema ;36_V	et	f	\N
113178	vaba	vaba =vaba  (SgN  >vaba !17_A	et	f	\N
113179	vaba	vaba =vaba  (SgG  >vaba !17_A	et	f	\N
113180	vaba	vaba =vaba  (SgP  >vaba !17_A	et	f	\N
113196	toimetus	toimetus =toimetu  (SgIn  >toimetu !01_A	et	f	\N
113197	toimetus	"toimetu %toime  )TU2_kA  <toime ;06_S	et	f	\N
113198	toimetus	"toimetu %toime  )TU2_kA  <toim ;22_S	et	f	\N
113199	toimetus	toimetus =toimetus  (SgN  >toimetus !11_S	et	f	\N
112846	kultuurivara	kultuurivara =vara  (SgP  >kultuuri+vara !17_S	et	f	\N
112855	raidkivitööd	raidkivitööd =töö  (PlN  >raid+kivi+töö !26_S	et	f	\N
112856	raidkivitööd	raidkivitööd =töö  (SgP  >raid+kivi+töö !26_S	et	f	\N
112860	piirkonnale	piirkonnale =piirkonna  (SgAll  >piirkond !22_S	et	f	\N
112861	piirkonnale	piirkonnale =konna  (SgAll  >piir+konn !22_S	et	f	\N
112868	hauplaste	?hauplaste =hauplas  (PlG  >hauplas !07_S	et	f	\N
112869	hauplaste	?hauplaste =hauplas  (PlG  >hauplane !12?10_S	et	f	\N
112885	komapäeva	?komapäeva =komapäeva  (SgN  >komapäeva !16_S	et	f	\N
112887	komapäeva	?komapäeva =komapäeva  (SgG  >komapäeva !16_S	et	f	\N
112889	komapäeva	?komapäeva =apäeva  (SgN  >kom+apäeva !01_S	et	f	\N
112890	komapäeva	?komapäeva =apäeva  (SgG  >kom+apäeva !01_S	et	f	\N
112891	pühapäevakool	pühapäevakool =koo  (SgAd  >püha+päeva+kubu !18_S	et	f	\N
112892	pühapäevakool	pühapäevakool =kool  (SgN  >püha+päeva+kool !22_S	et	f	\N
112909	poolel	poolel =poole  (SgAd  >pool !13_NS	et	f	\N
112910	poolel	poolel =poole  (PlAd  >pool !22_S	et	f	\N
112926	krusenstiern	?krusenstiern =krusenstiern  (SgN  >krusenstiern !22_S	et	f	\N
112936	lossiliku	?lossiliku =lossiliku  (SgG  >lossilik !25_A	et	f	\N
112937	lossiliku	?lossiliku =lossiliku  (IndPrPs_  >lossilikuma !27_V	et	f	\N
112938	lossiliku	?lossiliku =lossiliku  (ImpPrSg2  >lossilikuma !27_V	et	f	\N
112987	härrastemaja	?härrastemaja =härrastemaja  (SgN  >härrastemaja !01_S	et	f	\N
112988	härrastemaja	?härrastemaja =härrastemaja  (SgG  >härrastemaja !01_S	et	f	\N
112990	härrastemaja	?härrastemaja =härrastemaja  (SgG  >härrastemajas !02_A	et	f	\N
112992	härrastemaja	?härrastemaja =temaja  (SgN  >härras+temaja !01_S	et	f	\N
112994	härrastemaja	?härrastemaja =temaja  (SgG  >härras+temaja !01_S	et	f	\N
112996	härrastemaja	?härrastemaja =temaja  (SgG  >härras+temajas !02_A	et	f	\N
112999	paldiski	?paldiski =paldiski  (SgG  >paldisk !02_S	et	f	\N
113000	paldiski	?paldiski =paldiski  (IndPrPs_  >paldiskima !28_V	et	f	\N
113001	paldiski	?paldiski =paldiski  (ImpPrSg2  >paldiskima !28_V	et	f	\N
113002	paldiski	?paldiski =paldi  (SgIn^  >palt !22_S	et	f	\N
113003	paldiski	?paldiski =paldi  (IndIpfSg3^  >paldima !28_V	et	f	\N
113004	paldiski	?paldiski =paldis  (SgN^  >paldis !09_S	et	f	\N
113014	põlema	põlema =põle  (Sup  >põlema !27_V	et	f	\N
113015	põlema	põlema =põlema  (SgG  >põlem !02_S	et	f	\N
113017	vare	vare =vare  (SgN  >vare !04_S	et	f	\N
113018	vare	vare =vare  (SgN  >vare !16_S	et	f	\N
113019	vare	vare =vare  (SgG  >vare !16_S	et	f	\N
113023	sündisid	sündisid =sündi  (PlP  >sünd !22_S	et	f	\N
113024	sündisid	sündisid =sündi  (IndIpfSg2  >sündima !28_V	et	f	\N
113025	sündisid	sündisid =sündi  (IndIpfPl3  >sündima !28_V	et	f	\N
113026	krusteni	?krusteni =kruste  (SgTer  >kruste !06_S	et	f	\N
113027	krusteni	?krusteni =krusteni  (SgG  >krusten !02_S	et	f	\N
113035	karikaturistiks	karikaturistiks =karikaturisti  (SgTr  >karikaturist !22_S	et	f	\N
113037	karikaturistiks	karikaturistiks =turisti  (SgTr  >karika+turist !22_S	et	f	\N
113039	erni	?erni =erni  (SgN  >erni !16_S	et	f	\N
113042	erni	?erni =erni  (SgG  >erni !16_S	et	f	\N
113043	erni	?erni =erni  (SgG  >ern !22_S	et	f	\N
113044	erni	?erni =erni  (SgP  >ern !22_S	et	f	\N
113045	erni	?erni =erni  (SgAdt  >ern !22_S	et	f	\N
113046	erni	?erni =erni  (IndPrPs_  >ernima !28_V	et	f	\N
113047	erni	?erni =erni  (ImpPrSg2  >ernima !28_V	et	f	\N
113050	ülesandeks	ülesandeks =ande  (SgTr  >üles+anne !06_S	et	f	\N
113051	ülesandeks	ülesandeks =sande  (PlTr  >üle+sand !22_S	et	f	\N
113052	ülesandeks	ülesandeks =sande  (PlTr  >üle+sant !22_SA	et	f	\N
113088	edendamise	edendamise =edendamise  (SgG  >edendamine !12_S	et	f	\N
113089	edendamise	"edendamine %edenda  )MINE_vS  <edendama ;27_V	et	f	\N
113092	kunstikoolis	kunstikoolis =kooli  (SgIn  >kunsti+kool !22_S	et	f	\N
113094	kunstikoolis	kunstikoolis =kooli  (PlIn  >kunsti+kool !22_S	et	f	\N
113101	ajalehtedele	ajalehtedele =ede  (SgAll  >aja+leht+ede !16_S	et	f	\N
113102	ajalehtedele	ajalehtedele =lehte  (PlAll  >aja+leht !22_S	et	f	\N
113106	o	### o	et	f	\N
113108	isikupärase	isikupärase =pärase  (SgG  >isiku+pärane !10_A	et	f	\N
113109	isikupärase	"isiku+pärane %pära  )NE_aA  <isiku+pära ;17_S	et	f	\N
113118	kultuuri-	kultuuri- =kultuuri  (SgG  >kultuur !22_S	et	f	\N
113119	kultuuri-	kultuuri- =kultuuri  (SgP  >kultuur !22_S	et	f	\N
113120	kultuuri-	kultuuri- =kultuuri  (SgAdt  >kultuur !22_S	et	f	\N
113121	alal	alal =ala  (SgAd  >ala !17_S	et	f	\N
113122	alal	alal =alal  (ID  >alal !41_D	et	f	\N
113151	kahekümnendate	?kahekümnendate =kahekümnenda  (IndPrPl2  >kahekümnendama !27_V	et	f	\N
113152	kahekümnendate	?kahekümnendate =ate  (SgN  >kahe+kümnend+ate !06_S	et	f	\N
113153	kahekümnendate	?kahekümnendate =kümnenda  (PlG  >kahe+kümnenda !01_S	et	f	\N
113174	keskpaigast	keskpaigast =paiga  (SgEl  >kesk+paik !22_S	et	f	\N
113175	keskpaigast	keskpaigast =paigas  (SgP  >kesk+paigas !09_S	et	f	\N
113176	keskpaigast	keskpaigast =paigas  (SgP  >kesk+paigane !10_A	et	f	\N
113177	keskpaigast	"kesk+paigane %paiga  )NE_aA  <kesk+paik ;22_S	et	f	\N
113203	enamasti	enamasti =enamasti  (ID  >enamasti !41_D	et	f	\N
112978	tõttu	tõttu =tõttu  (ID  >tõttu !41_DK	et	f	\N
112979	tõttu	tõttu =tõttu  (SgP  >tõtt !22_S	et	f	\N
112981	tõttu	tõttu =tõttu  (SgAdt  >tõtt !22_S	et	f	\N
112989	valdaja	valdaja =valdaja  (SgN  >valdaja !01_S	et	f	\N
112991	valdaja	"valdaja %valda  )JA_vS  <valdama ;29_V	et	f	\N
112993	valdaja	valdaja =valdaja  (SgG  >valdaja !01_S	et	f	\N
112995	valdaja	valdaja =aja  (SgG  >vald+aeg !22_S	et	f	\N
112997	punane	punane =punane  (SgN  >punane !10_AS	et	f	\N
112998	punane	"punane %puna  )NE_aA  <puna ;17_S	et	f	\N
113005	panid	panid =pan  (IndIpfSg2  >panema !36_V	et	f	\N
113006	panid	panid =pan  (IndIpfPl3  >panema !36_V	et	f	\N
113007	panid	panid =pani  (PlN  >pani !16_S	et	f	\N
113009	panid	panid =pani  (PlN  >pan !19_S	et	f	\N
113020	kasvasid	kasvasid =kasva  (IndIpfSg2  >kasvama !28_V	et	f	\N
113021	kasvasid	kasvasid =kasva  (IndIpfPl3  >kasvama !28_V	et	f	\N
113022	krustenid	?krustenid =krusteni  (PlN  >krusten !02_S	et	f	\N
113028	perekonnas	perekonnas =perekonna  (SgIn  >perekond !22_S	et	f	\N
113029	perekonnas	perekonnas =konna  (SgIn  >pere+konn !22_S	et	f	\N
113032	krusten	?krusten =kruste  (IndPrSg1  >krustema !27_V	et	f	\N
113033	krusten	?krusten =krusten  (SgN  >krusten !02_S	et	f	\N
113038	nooremad	nooremad =noorema  (PlN  >noorem !02_A	et	f	\N
113040	nooremad	"noorem %noore  )M_cA  <noor ;13_AS	et	f	\N
113041	nooremad	nooremad =ema  (PlN  >noor+ema !17_S	et	f	\N
113053	triiphoone	triiphoone =hoone  (SgN  >triip+hoone !06_S	et	f	\N
113054	triiphoone	"triip+hoone %hoo  )NE_aA  <triip+hoog ;22_S	et	f	\N
113055	triiphoone	triiphoone =hoone  (SgG  >triip+hoone !06_S	et	f	\N
113058	triiphoone	triiphoone =hoone  (PlP  >triip+hoon !22_A	et	f	\N
113059	vaeselt	vaeselt =vaese  (SgAbl  >vaene !10_AS	et	f	\N
113060	vaeselt	"vaene %vae  )NE_aA  <vaag ;22_S	et	f	\N
113061	vaeselt	vaeselt =vaeselt  (ID  >vaeselt !41_D	et	f	\N
113062	vaeselt	"vaeselt %vae  )SELT_mD  <vaag ;22_S	et	f	\N
113063	vaeselt	"vaeselt %vaese  )LT_mD  <vaene ;10_AS	et	f	\N
113064	lapsepõlve	lapsepõlve =põlve  (SgG  >lapse+põlv !22_S	et	f	\N
113066	lapsepõlve	lapsepõlve =põlve  (SgG  >lapse+põli !24_S	et	f	\N
113067	lapsepõlve	lapsepõlve =põlve  (SgP  >lapse+põlv !22_S	et	f	\N
113068	lapsepõlve	lapsepõlve =põlve  (SgP  >lapse+põli !24_S	et	f	\N
113069	lapsepõlve	lapsepõlve =põlve  (SgAdt  >lapse+põlv !22_S	et	f	\N
113070	lapsepõlve	lapsepõlve =põlve  (SgAdt  >lapse+põli !24_S	et	f	\N
113071	lapsepõlve	lapsepõlve =põlve  (PlP  >lapse+põlv !22_S	et	f	\N
113075	mõisaolustikku	mõisaolustikku =olustikku  (SgP  >mõisa+olustik !25_S	et	f	\N
113077	mõisaolustikku	mõisaolustikku =olustikku  (SgAdt  >mõisa+olustik !25_S	et	f	\N
113081	metsa	metsa =metsa  (SgG  >mets !22_S	et	f	\N
113082	metsa	metsa =metsa  (SgP  >mets !22_S	et	f	\N
113083	metsa	metsa =metsa  (SgAdt  >mets !22_S	et	f	\N
113099	karikatuure	karikatuure =karikatuure  (PlP  >karikatuur !22_S	et	f	\N
113100	karikatuure	karikatuure =tuure  (PlP  >karika+tuur !22_S	et	f	\N
113115	iseloomustavaid	iseloomustavaid =ustava  (PlP  >ise+loom+ustav !02_A	et	f	\N
113116	iseloomustavaid	iseloomustavaid =mustava  (PlP  >ise+loo+mustav !02_A	et	f	\N
113117	iseloomustavaid	iseloomustavaid =loomustava  (PlP  >ise+loomustav !02_A	et	f	\N
113142	teile	teile =te  (PlAll  >sa !00_P	et	f	\N
113143	teile	teile =te  (PlAll  >tee !26_S	et	f	\N
113166	pojana	pojana =poja  (SgEs  >poja !17_S	et	f	\N
113167	pojana	pojana =poja  (SgEs  >poeg !22_S	et	f	\N
113168	progümnaasiumis	?progümnaasiumis =progümnaasiumi  (SgIn  >progümnaasium !19~02_S	et	f	\N
113169	progümnaasiumis	?progümnaasiumis =progümnaasiumi  (SgIn  >progümnaasiumi !16_S	et	f	\N
113170	progümnaasiumis	?progümnaasiumis =progümnaasiumi  (IndIpfSg3  >progümnaasiumima !28_V	et	f	\N
113171	progümnaasiumis	?progümnaasiumis =progümnaasiumis  (SgN  >progümnaasiumis !09_S	et	f	\N
113183	1950a	### 1950a	et	f	\N
113208	silma	silma =silma  (SgG  >silm !22_S	et	f	\N
113210	silma	silma =silma  (SgP  >silm !22_S	et	f	\N
113212	silma	silma =silma  (SgAdt  >silm !22_S	et	f	\N
113213	silma	silma =silma  (IndPrPs_  >silmama !29_V	et	f	\N
113215	silma	silma =silma  (ImpPrSg2  >silmama !29_V	et	f	\N
113232	loomusest	loomusest =loomuse  (SgEl  >loomus !11~09_S	et	f	\N
113234	loomusest	loomusest =loomuses  (SgP  >loomusene !12_A	et	f	\N
113236	loomusest	"loomusene %loomuse  )NE_aA  <loomus ;09_S	et	f	\N
113237	loomusest	"loomusene %loomuse  )NE_aA  <loomus ;11_S	et	f	\N
113238	loomusest	loomusest =use  (PlEl  >loom+usk !22_S	et	f	\N
113242	huvita	huvita =huvi  (SgAb  >huvi !17_S	et	f	\N
113243	huvita	huvita =huvita  (IndPrPs_  >huvitama !27_V	et	f	\N
113244	huvita	huvita =huvita  (ImpPrSg2  >huvitama !27_V	et	f	\N
113259	pannud	pannud =pan  (PtsPtPs  >panema !36_V	et	f	\N
113260	pannud	pannud =pannu  (PlN  >pannu !16_S	et	f	\N
113261	pannud	"pannu %pan  )NU_vS  <panema ;36_V	et	f	\N
113262	pannud	pannud =pannud  (ID  >pannud !41_A	et	f	\N
113263	pannud	"pannud %pan  )NUD_vA  <panema ;36_V	et	f	\N
113271	nähtused	nähtused =nähtuse  (PlN  >nähtus !11~09_S	et	f	\N
113272	nähtused	"nähtus %näh  )TUS1_aS  <nägema ;28_V	et	f	\N
113189	püsivaks	"püsiv %püsi  )V_vA  <püsima ;27_V	et	f	\N
113191	püsivaks	püsivaks =vaks  (SgN  >püsi+vaks !22_S	et	f	\N
113193	raadiojaama	raadiojaama =jaama  (SgG  >raadio+jaam !22_S	et	f	\N
113194	raadiojaama	raadiojaama =jaama  (SgP  >raadio+jaam !22_S	et	f	\N
113195	raadiojaama	raadiojaama =jaama  (SgAdt  >raadio+jaam !22_S	et	f	\N
113217	isikupära	isikupära =pära  (SgN  >isiku+pära !17_S	et	f	\N
113219	isikupära	isikupära =pära  (SgG  >isiku+pära !17_S	et	f	\N
113220	isikupära	isikupära =pära  (SgP  >isiku+pära !17_S	et	f	\N
113264	kodumaa	kodumaa =maa  (SgN  >kodu+maa !26_S	et	f	\N
113265	kodumaa	kodumaa =maa  (SgG  >kodu+maa !26_S	et	f	\N
113266	teatava	teatava =teatava  (SgG  >teatav !02_A	et	f	\N
113268	teatava	"teatav %tea  )TAV_vAS  <teadma ;34_V	et	f	\N
113270	teatava	"teatav %teata  )V_vA  <teatama ;27_V	et	f	\N
113276	psühholoogiliseks	psühholoogiliseks =psühholoogilise  (SgTr  >psühholoogiline !12_A	et	f	\N
113277	psühholoogiliseks	"psühholoogiline %psühholoogi  )LINE_aA  <psühholoog ;22_S	et	f	\N
113278	psühholoogiliseks	psühholoogiliseks =loogilise  (SgTr  >psühho+loogiline !12_A	et	f	\N
113279	psühholoogiliseks	"psühho+loogiline %loogi  )LINE_aA  <psühho+loog ;22_S	et	f	\N
113282	alateadvuse	alateadvuse =teadvuse  (SgG  >ala+teadvus !11~09_S	et	f	\N
113283	alateadvuse	"ala+teadvus %teadva  )US_aS  <ala+teadev ;02_A	et	f	\N
113289	tõe	tõe =tõe  (SgG  >tõsi !15_S	et	f	\N
113290	tõe	tõe =tõe  (SgG  >tõde !18_S	et	f	\N
113300	tõde	tõde =tõde  (SgN  >tõde !18_S	et	f	\N
113302	tõde	tõde =tõde  (SgP  >tõde !18_S	et	f	\N
113304	tõde	tõde =tõde  (IndPrPs_  >tõdema !27_V	et	f	\N
113305	tõde	tõde =tõde  (ImpPrSg2  >tõdema !27_V	et	f	\N
113311	juhust	juhust =juhu  (SgEl  >juht !22_S	et	f	\N
113312	juhust	juhust =juhus  (SgP  >juhus !09_S	et	f	\N
113314	sellesse	sellesse =selle  (SgIll  >see !00_P	et	f	\N
113316	sellesse	sellesse =selle  (PlIll  >sell !22_S	et	f	\N
113319	voorus	voorus =vooru  (SgIn  >voor !22_S	et	f	\N
113320	voorus	voorus =voorus  (SgN  >voorus !11~09_S	et	f	\N
113336	triloogia	triloogia =triloogia  (SgN  >triloogia !01_S	et	f	\N
113337	triloogia	triloogia =triloogia  (SgG  >triloogia !01_S	et	f	\N
113352	koostajaks	koostajaks =koostaja  (SgTr  >koostaja !01_S	et	f	\N
113353	koostajaks	"koostaja %koosta  )JA_vS  <koostama ;27_V	et	f	\N
113354	tundmatu	tundmatu =tundmatu  (SgN  >tundmatu !01_AS	et	f	\N
113355	tundmatu	"tundmatu %tund  )MATU_vA  <tundma ;34_V	et	f	\N
113356	tundmatu	tundmatu =tundmatu  (SgG  >tundmatu !01_AS	et	f	\N
113362	1959-	### 1959-	et	f	\N
113368	kõrgel	kõrgel =kõrge  (SgAd  >kõrge !01_A	et	f	\N
113369	kõrgel	kõrgel =kõrge  (PlAd  >kõrk !22_A	et	f	\N
113370	kõrgel	kõrgel =kõrgel  (ID  >kõrgel !41_D	et	f	\N
113421	ihaldatud	ihaldatud =ihalda  (PtsPtIps  >ihaldama !27_V	et	f	\N
113422	ihaldatud	ihaldatud =ihaldatu  (PlN  >ihaldatu !01_S	et	f	\N
113423	ihaldatud	"ihaldatu %ihalda  )TU1_vS  <ihaldama ;27_V	et	f	\N
113424	ihaldatud	ihaldatud =ihaldatud  (ID  >ihaldatud !41_A	et	f	\N
113425	ihaldatud	"ihaldatud %ihalda  )TUD_vA  <ihaldama ;27_V	et	f	\N
113430	põgenemise	põgenemise =põgenemise  (SgG  >põgenemine !12_S	et	f	\N
113431	põgenemise	"põgenemine %põgene  )MINE_vS  <põgenema ;27_V	et	f	\N
113440	teod	teod =teo  (PlN  >tegu !18_S	et	f	\N
113441	teod	teod =teo  (PlN  >tigu !18_S	et	f	\N
113442	kroonika	kroonika =kroonika  (SgN  >kroonika !01_S	et	f	\N
113443	kroonika	kroonika =kroonika  (SgG  >kroonika !01_S	et	f	\N
113452	tõele	tõele =tõe  (SgAll  >tõsi !15_S	et	f	\N
113453	tõele	tõele =tõe  (SgAll  >tõde !18_S	et	f	\N
113465	inimsõbralikkus	inimsõbralikkus =sõbralikkus  (SgN  >inim+sõbralikkus !11~09_S	et	f	\N
113466	inimsõbralikkus	"inim+sõbralikkus %sõbralikku  )US_aS  <inim+sõbralik ;25_A	et	f	\N
113467	muutumatu	muutumatu =muutumatu  (SgN  >muutumatu !01_A	et	f	\N
113468	muutumatu	"muutumatu %muutu  )MATU_vA  <muutuma ;27_V	et	f	\N
113469	muutumatu	muutumatu =muutumatu  (SgG  >muutumatu !01_A	et	f	\N
113472	avastamine	avastamine =avastamine  (SgN  >avastamine !12_S	et	f	\N
113473	avastamine	"avastamine %avasta  )MINE_vS  <avastama ;27_V	et	f	\N
113474	ideed	ideed =idee  (PlN  >idee !26_S	et	f	\N
113475	ideed	ideed =idee  (SgP  >idee !26_S	et	f	\N
113486	valdamisest	valdamisest =valdamise  (SgEl  >valdamine !12_S	et	f	\N
113487	valdamisest	"valdamine %valda  )MINE_vS  <valdama ;29_V	et	f	\N
113489	mõtelda	mõtelda =mõtel  (Inf  >mõtlema !30_V	et	f	\N
113490	mõtelda	mõtelda =mõtel  (IndPrIps_  >mõtlema !30_V	et	f	\N
113496	tulevikuprespektiivid	?tulevikuprespektiivid =tulevikuprespektiivi  (PlN  >tulevikuprespektiivi !16_S	et	f	\N
113497	tulevikuprespektiivid	?tulevikuprespektiivid =tulevikuprespektiivi  (PlN  >tulevikuprespektiiv !22_S	et	f	\N
113498	tulevikuprespektiivid	?tulevikuprespektiivid =tulevikuprespektiivi  (IndPrSg2  >tulevikuprespektiivima !28_V	et	f	\N
113499	tulevikuprespektiivid	?tulevikuprespektiivid =spektiivi  (PlN  >tuleviku+pre+spektiivi !16_S	et	f	\N
113500	tulevikuprespektiivid	?tulevikuprespektiivid =spektiivi  (PlN  >tuleviku+pre+spektiiv !22_S	et	f	\N
113501	tulevikuprespektiivid	?tulevikuprespektiivid =prespektiivi  (PlN  >tuleviku+prespektiivi !16_S	et	f	\N
113200	toimetus	"toimetus %toimeta  )US_vS  <toimetama ;27_V	et	f	\N
113201	toimetus	"toimetus %toime  )TUS2_aS  <toime ;06_S	et	f	\N
113202	toimetus	"toimetus %toime  )TUS2_aS  <toim ;22_S	et	f	\N
113207	tugev	tugev =tuge  (PtsPrPs  >tugema !27_V	et	f	\N
113209	tugev	tugev =tugev  (SgN  >tugev !02_A	et	f	\N
113211	tugev	"tugev %tuge  )V_vA  <tugema ;27_V	et	f	\N
113221	seotus	seotus =seotu  (SgIn  >seotu !01_A	et	f	\N
113222	seotus	"seotu %seo  )TU1_vS  <siduma ;28_V	et	f	\N
113223	seotus	seotus =seotus  (SgN  >seotus !11~09_S	et	f	\N
113226	seotus	"seotus %seo  )TUS1_aS  <siduma ;28_V	et	f	\N
113249	lugejad	lugejad =lugeja  (PlN  >lugeja !01_S	et	f	\N
113250	lugejad	"lugeja %luge  )JA_vS  <lugema ;28_V	et	f	\N
113251	kriitika	kriitika =kriitika  (SgN  >kriitika !01_S	et	f	\N
113252	kriitika	kriitika =kriitika  (SgG  >kriitika !01_S	et	f	\N
113267	rahvas	rahvas =rahva  (SgIn  >rahvas !07_S	et	f	\N
113269	rahvas	rahvas =rahvas  (SgN  >rahvas !07_S	et	f	\N
113299	tõeline	tõeline =tõeline  (SgN  >tõeline !12?10_A	et	f	\N
113301	tõeline	"tõeline %tõe  )LINE_aA  <tõsi ;15_S	et	f	\N
113303	tõeline	"tõeline %tõe  )LINE_aA  <tõde ;18_S	et	f	\N
113306	kujuteldav	kujuteldav =kujutel  (PtsPrIps  >kujutelema !36_V	et	f	\N
113307	kujuteldav	kujuteldav =kujuteldav  (SgN  >kujuteldav !02_A	et	f	\N
113308	kujuteldav	"kujuteldav %kujutel  )TAV_vAS  <kujutelema ;36_V	et	f	\N
113322	kättemaks	kättemaks =maks  (SgN  >kätte+maks !22_S	et	f	\N
113325	kättemaks	kättemaks =ema  (SgTr  >kätt+ema !17_S	et	f	\N
113346	olnudki	olnudki =ol  (PtsPtPs^  >olema !36_V	et	f	\N
113347	olnudki	olnudki =olnu  (PlN^  >olnu !01_S	et	f	\N
113348	olnudki	"olnu %ol  )NU_vS^  <olema ;36_V	et	f	\N
113349	olnudki	olnudki =olnu  (PlN^  >olnu !06_S	et	f	\N
113350	olnudki	olnudki =olnud  (ID^  >olnud !41_A	et	f	\N
113351	olnudki	"olnud %ol  )NUD_vA^  <olema ;36_V	et	f	\N
113379	kujunemist	kujunemist =kujunemis  (SgP  >kujunemine !12_S	et	f	\N
113380	kujunemist	"kujunemine %kujune  )MINE_vS  <kujunema ;27_V	et	f	\N
113394	mälestuslikeks	?mälestuslikeks =mälestuslike  (PlTr  >mälestuslik !25_A	et	f	\N
113395	mõisaednik	?mõisaednik =mõisaednik  (SgN  >mõisaednik !25_S	et	f	\N
113396	mõisaednik	?mõisaednik =ednik  (SgN  >mõisa+ednik !02_S	et	f	\N
113406	kajastuvad	kajastuvad =kajastu  (IndPrPl3  >kajastuma !27_V	et	f	\N
113407	kajastuvad	kajastuvad =kajastuva  (PlN  >kajastuv !02_A	et	f	\N
113408	kajastuvad	"kajastuv %kajastu  )V_vA  <kajastuma ;27_V	et	f	\N
113409	pöördelised	pöördelised =pöördelise  (PlN  >pöördeline !12_A	et	f	\N
113410	pöördelised	"pöördeline %pöörde  )LINE_aA  <pööre ;06_S	et	f	\N
113428	kaugelviibija	kaugelviibija =viibija  (SgN  >kaugel+viibija !01_S	et	f	\N
113429	kaugelviibija	kaugelviibija =viibija  (SgG  >kaugel+viibija !01_S	et	f	\N
113456	paisatud	paisatud =paisa  (PtsPtIps  >paiskama !29_V	et	f	\N
113458	paisatud	paisatud =paisatu  (PlN  >paisatu !01_AS	et	f	\N
113459	paisatud	"paisatu %paisa  )TU1_vS  <paiskama ;29_V	et	f	\N
113460	paisatud	paisatud =paisatud  (ID  >paisatud !41_A	et	f	\N
113461	paisatud	"paisatud %paisa  )TUD_vA  <paiskama ;29_V	et	f	\N
113462	pohmelsuses	?pohmelsuses =pohmelsuse  (SgIn  >pohmelsus !11~09_S	et	f	\N
113481	proosa	proosa =proosa  (SgN  >proosa !16_S	et	f	\N
113483	proosa	proosa =proosa  (SgG  >proosa !16_S	et	f	\N
113484	paremast	paremast =parema  (SgEl  >parem !02_A	et	f	\N
113485	paremast	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
113488	paremast	paremast =ast  (SgN  >parem+ast !22_S	et	f	\N
113494	2004vääna	vääna =vääna  (IndPrPs_  >väänama !29_V	et	f	\N
113495	2004vääna	vääna =vääna  (ImpPrSg2  >väänama !29_V	et	f	\N
113514	rahnop1976	?rahnop =rahnop  (SgN  >rahnop !02_S	et	f	\N
113517	p1976	### p1976	et	f	\N
113522	httpwwwharkueefiles84pdf	### httpwwwharkueefiles84pdf	et	f	\N
113524	tartu	tartu =tartu  (SgN  >tartu !01_H	et	f	\N
113525	tartu	tartu =tartu  (SgG  >tartu !01_H	et	f	\N
113529	kontrolltöö	kontrolltöö =töö  (SgN  >kont+roll+töö !26_S	et	f	\N
113530	kontrolltöö	kontrolltöö =töö  (SgG  >kont+roll+töö !26_S	et	f	\N
113537	kultuurielu	kultuurielu =elu  (SgN  >kultuuri+elu !17_S	et	f	\N
113538	kultuurielu	kultuurielu =elu  (SgG  >kultuuri+elu !17_S	et	f	\N
113539	kultuurielu	kultuurielu =elu  (SgP  >kultuuri+elu !17_S	et	f	\N
113570	üleviima	?üleviima =üleviima  (SgN  >üleviima !16_S	et	f	\N
113572	üleviima	?üleviima =üleviima  (SgG  >üleviima !16_S	et	f	\N
113583	nafta	nafta =nafta  (SgN  >nafta !16_S	et	f	\N
113584	nafta	nafta =nafta  (SgG  >nafta !16_S	et	f	\N
113621	laulupeod	laulupeod =peo  (PlN  >laulu+pidu !18_S	et	f	\N
113622	laulupeod	laulupeod =peo  (PlN  >laulu+peo !26_S	et	f	\N
113624	laulupeod	laulupeod =peo  (SgP  >laulu+peo !26_S	et	f	\N
113634	võime	võime =või  (IndPrPl1  >võima !37_V	et	f	\N
113635	võime	võime =võime  (SgN  >võime !06_S	et	f	\N
113636	võime	võime =võime  (SgG  >võime !06_S	et	f	\N
113637	võime	võime =võime  (PlP  >võim !22_S	et	f	\N
113638	toimusid	toimusid =toimu  (IndIpfSg2  >toimuma !27_V	et	f	\N
113639	toimusid	toimusid =toimu  (IndIpfPl3  >toimuma !27_V	et	f	\N
113648	laule	laule =lau  (SgAll  >laug !22_SA	et	f	\N
113204	enamasti	enamasti =asti  (SgG  >enam+ast !22_S	et	f	\N
113205	enamasti	enamasti =asti  (SgP  >enam+ast !22_S	et	f	\N
113206	enamasti	enamasti =asti  (SgAdt  >enam+ast !22_S	et	f	\N
113224	sügavalt	sügavalt =sügava  (SgAbl  >sügav !02_A	et	f	\N
113227	sügavalt	"sügav %süga  )V_vA  <sügama ;27_V	et	f	\N
113229	sügavalt	sügavalt =sügavalt  (ID  >sügavalt !41_D	et	f	\N
113231	sügavalt	"sügavalt %süga  )VALT_mD  <sügama ;27_V	et	f	\N
113233	sügavalt	"sügavalt %sügava  )LT_mD  <sügav ;02_A	et	f	\N
113235	sügavalt	sügavalt =alt  (SgN  >sügav+alt !22_S	et	f	\N
113245	kodumaal	kodumaal =maa  (SgAd  >kodu+maa !26_S	et	f	\N
113246	kodumaal	kodumaal =maal  (SgN  >kodu+maal !22_S	et	f	\N
113247	washingtonis	?washingtonis =washingtoni  (SgIn  >washington !02_S	et	f	\N
113248	washingtonis	?washingtonis =washingtonis  (SgN  >washingtonis !09_S	et	f	\N
113253	tunnustanud	tunnustanud =tunnusta  (PtsPtPs  >tunnustama !27_V	et	f	\N
113254	tunnustanud	tunnustanud =tunnustanu  (PlN  >tunnustanu !01_S	et	f	\N
113255	tunnustanud	"tunnustanu %tunnusta  )NU_vS  <tunnustama ;27_V	et	f	\N
113256	tunnustanud	tunnustanud =tunnustanud  (ID  >tunnustanud !41_A	et	f	\N
113257	tunnustanud	"tunnustanud %tunnusta  )NUD_vA  <tunnustama ;27_V	et	f	\N
113258	tunnustanud	tunnustanud =tanu  (PlN  >tunnus+tanu !17_S	et	f	\N
113292	süü	süü =süü  (SgN  >süü !26_S	et	f	\N
113294	süü	süü =süü  (SgG  >süü !26_S	et	f	\N
113309	õhuke	õhuke =õhuke  (SgN  >õhuke !12_A	et	f	\N
113310	õhuke	"õhuke %õhu  )KE_dS  <õhk ;22_S	et	f	\N
113317	gruppi	gruppi =gruppi  (SgP  >grupp !22_S	et	f	\N
113318	gruppi	gruppi =gruppi  (SgAdt  >grupp !22_S	et	f	\N
113321	jaanuse	?jaanuse =jaanuse  (SgG  >jaanus !11~09_S	et	f	\N
113323	jaanuse	?jaanuse =use  (SgN  >jaan+use !16_S	et	f	\N
113324	jaanuse	?jaanuse =use  (SgG  >jaan+use !16_S	et	f	\N
113326	varasema	varasema =varasema  (SgG  >varasem !02_A	et	f	\N
113327	varasema	"varasem %vara  )SEM_cA  <vara ;17_S	et	f	\N
113328	varasema	"varasem %varase  )M_cA  <varane ;10_A	et	f	\N
113338	taga	taga =ta  (SgKom  >ta !00_P	et	f	\N
113339	taga	taga =taga  (ID  >taga !41_DK	et	f	\N
113340	taga	taga =taga  (IndPrPs_  >tagama !27_V	et	f	\N
113341	taga	taga =taga  (ImpPrSg2  >tagama !27_V	et	f	\N
113342	ülo	?ülo =ülo  (SgN  >ülo !17~16_S	et	f	\N
113343	ülo	?ülo =ülo  (SgG  >ülo !17~16_S	et	f	\N
113344	ülo	?ülo =ülo  (SgP  >ülo !17_S	et	f	\N
113366	laul	laul =lau  (SgAd  >laug !22_SA	et	f	\N
113367	laul	laul =laul  (SgN  >laul !22_S	et	f	\N
113384	võrsuv	võrsuv =võrsu  (PtsPrPs  >võrsuma !27_V	et	f	\N
113385	võrsuv	võrsuv =võrsuv  (SgN  >võrsuv !02_A	et	f	\N
113386	võrsuv	"võrsuv %võrsu  )V_vA  <võrsuma ;27_V	et	f	\N
113387	täienduseks	täienduseks =täienduse  (SgTr  >täiendus !11_S	et	f	\N
113388	täienduseks	"täiendus %täienda  )US_vS  <täiendama ;27_V	et	f	\N
113389	täienduseks	täienduseks =use  (PlTr  >täiend+usk !22_S	et	f	\N
113397	kaldametsa	kaldametsa =metsa  (SgG  >kalda+mets !22_S	et	f	\N
113398	kaldametsa	kaldametsa =metsa  (SgP  >kalda+mets !22_S	et	f	\N
113399	kaldametsa	kaldametsa =metsa  (SgAdt  >kalda+mets !22_S	et	f	\N
113411	läbinähtud	läbinähtud =näh  (PtsPtIps  >läbi+_nägema !28_V	et	f	\N
113412	läbinähtud	läbinähtud =nähtu  (PlN  >läbi+nähtu !01_S	et	f	\N
113434	ümberasumisest	ümberasumisest =asumise  (SgEl  >ümber+asumine !12_S	et	f	\N
113435	ümberasumisest	"ümber+asumine %asumi  )NE_aA  <ümber+asum ;02_S	et	f	\N
113438	oleksid	oleksid =ole  (KndPrSg2  >olema !36_V	et	f	\N
113439	oleksid	oleksid =ole  (KndPrPl3  >olema !36_V	et	f	\N
113444	pagulaselu	pagulaselu =elu  (SgN  >pagulas+elu !17_S	et	f	\N
113445	pagulaselu	pagulaselu =elu  (SgG  >pagulas+elu !17_S	et	f	\N
113446	pagulaselu	pagulaselu =elu  (SgP  >pagulas+elu !17_S	et	f	\N
113447	tontsu	?tontsu =tontsu  (ID  >tontsu !41_D	et	f	\N
113448	tontsu	?tontsu =tontsu  (IndPrPs_  >tontsuma !28_V	et	f	\N
113449	tontsu	?tontsu =tontsu  (ImpPrSg2  >tontsuma !28_V	et	f	\N
113450	vasta	vasta =vasta  (IndPrPs_  >vastama !29_V	et	f	\N
113451	vasta	vasta =vasta  (ImpPrSg2  >vastama !29_V	et	f	\N
113478	psühholoogiline	psühholoogiline =psühholoogiline  (SgN  >psühholoogiline !12_A	et	f	\N
113479	psühholoogiline	"psühholoogiline %psühholoogi  )LINE_aA  <psühholoog ;22_S	et	f	\N
113480	psühholoogiline	psühholoogiline =loogiline  (SgN  >psühho+loogiline !12_A	et	f	\N
113482	psühholoogiline	"psühho+loogiline %loogi  )LINE_aA  <psühho+loog ;22_S	et	f	\N
113491	httpwwwharkueeindexphp	### httpwwwharkueeindexphp	et	f	\N
113502	polüfunktsionaalse	?polüfunktsionaalse =polüfunktsionaalse  (SgG  >polüfunktsionaalne !02_A	et	f	\N
113504	polüfunktsionaalse	?polüfunktsionaalse =polüfunktsionaalse  (PlP  >polüfunktsionaals !22_S	et	f	\N
113513	57-	### 57-	et	f	\N
113527	httpwwweestigiideescat10catid1itemid7890	?httpwwweestigiideescatcatiditemid =httpwwweestigiideescatcatiditemi  (PlN  >httpwwweestigiideescatcatiditem !02_A	et	f	\N
113540	nn	### nn	et	f	\N
113547	laulva	laulva =laulva  (SgG  >laulev !02_A	et	f	\N
113548	laulva	"laulev %laul  )V_vA  <laulma ;33_V	et	f	\N
113575	kiirendasid	kiirendasid =kiirenda  (IndIpfSg2  >kiirendama !27_V	et	f	\N
113576	kiirendasid	kiirendasid =kiirenda  (IndIpfPl3  >kiirendama !27_V	et	f	\N
113218	salgamata	"salgamata %salga  )MATA_vA  <salgama ;29_V	et	f	\N
113225	kirjutaja	kirjutaja =kirjutaja  (SgN  >kirjutaja !01_S	et	f	\N
113228	kirjutaja	"kirjutaja %kirjuta  )JA_vS  <kirjutama ;27_V	et	f	\N
113230	kirjutaja	kirjutaja =kirjutaja  (SgG  >kirjutaja !01_S	et	f	\N
113239	lähtuv	lähtuv =lähtu  (PtsPrPs  >lähtuma !27_V	et	f	\N
113240	lähtuv	lähtuv =lähtuv  (SgN  >lähtuv !02_A	et	f	\N
113241	lähtuv	"lähtuv %lähtu  )V_vA  <lähtuma ;27_V	et	f	\N
113280	suundu	suundu =suundu  (IndPrPs_  >suunduma !27_V	et	f	\N
113281	suundu	suundu =suundu  (ImpPrSg2  >suunduma !27_V	et	f	\N
113284	väid	väid =väi  (PlN  >väi !26_S	et	f	\N
113285	väid	väid =väi  (SgP  >väi !26_S	et	f	\N
113291	vale	vale =vale  (SgN  >vale !16_SA	et	f	\N
113293	vale	vale =vale  (SgG  >vale !16_SA	et	f	\N
113295	puhtuse	puhtuse =puhtuse  (SgG  >puhtus !11~09_S	et	f	\N
113296	puhtuse	"puhtus %puhta  )US_aS  <puhas ;07_A	et	f	\N
113297	lunastuse	lunastuse =lunastuse  (SgG  >lunastus !11_S	et	f	\N
113298	lunastuse	"lunastus %lunasta  )US_vS  <lunastama ;27_V	et	f	\N
113329	kirjuta	kirjuta =kirju  (SgAb  >kirju !01_A	et	f	\N
113330	kirjuta	kirjuta =kirju  (SgAb  >kirju !16_A	et	f	\N
113331	kirjuta	kirjuta =kirjuta  (IndPrPs_  >kirjutama !27_V	et	f	\N
113332	kirjuta	kirjuta =kirjuta  (ImpPrSg2  >kirjutama !27_V	et	f	\N
113333	kaldametsa-	kaldametsa- =metsa  (SgG  >kalda+mets !22_S	et	f	\N
113334	kaldametsa-	kaldametsa- =metsa  (SgP  >kalda+mets !22_S	et	f	\N
113335	kaldametsa-	kaldametsa- =metsa  (SgAdt  >kalda+mets !22_S	et	f	\N
113357	kadunud	kadunud =kadu  (PtsPtPs  >kaduma !28_V	et	f	\N
113358	kadunud	kadunud =kadunu  (PlN  >kadunu !01_S	et	f	\N
113359	kadunud	"kadunu %kadu  )NU_vS  <kaduma ;28_V	et	f	\N
113360	kadunud	kadunud =kadunud  (ID  >kadunud !41_A	et	f	\N
113361	kadunud	"kadunud %kadu  )NUD_vA  <kaduma ;28_V	et	f	\N
113371	neiuke	neiuke =neiuke  (SgN  >neiuke !12_S	et	f	\N
113372	neiuke	"neiuke %neiu  )KE_dS  <neiu ;16_S	et	f	\N
113373	neiuke	"neiuke %neiu  )KE_dS  <neid ;22_S	et	f	\N
113376	maaintelligentsi	maaintelligentsi =intelligentsi  (SgG  >maa+intelligents !22_S	et	f	\N
113377	maaintelligentsi	maaintelligentsi =intelligentsi  (SgP  >maa+intelligents !22_S	et	f	\N
113378	maaintelligentsi	maaintelligentsi =intelligentsi  (SgAdt  >maa+intelligents !22_S	et	f	\N
113381	külast	külast =küla  (SgEl  >küla !17_S	et	f	\N
113382	külast	külast =külas  (SgP  >külane !10_A	et	f	\N
113383	külast	"külane %küla  )NE_aA  <küla ;17_S	et	f	\N
113390	autobiograafilisteks	autobiograafilisteks =graafilis  (PlTr  >auto+bio+graafiline !12_A	et	f	\N
113391	autobiograafilisteks	"auto+bio+graafiline %graafi  )LINE_aA  <auto+bio+graaf ;22_S	et	f	\N
113392	autobiograafilisteks	autobiograafilisteks =biograafilis  (PlTr  >auto+biograafiline !12_A	et	f	\N
113393	autobiograafilisteks	"auto+biograafiline %biograafi  )LINE_aA  <auto+biograaf ;22_S	et	f	\N
113403	kultuuri	kultuuri =kultuuri  (SgG  >kultuur !22_S	et	f	\N
113404	kultuuri	kultuuri =kultuuri  (SgP  >kultuur !22_S	et	f	\N
113405	kultuuri	kultuuri =kultuuri  (SgAdt  >kultuur !22_S	et	f	\N
113426	inimesehoidja	inimesehoidja =hoidja  (SgN  >inimese+hoidja !01_S	et	f	\N
113427	inimesehoidja	inimesehoidja =hoidja  (SgG  >inimese+hoidja !01_S	et	f	\N
113432	diipii-	?diipii- =diipii  (SgN  >diipii !26_S	et	f	\N
113433	diipii-	?diipii- =diipii  (SgG  >diipii !26_S	et	f	\N
113454	võõrsile	võõrsile =võõrsile  (ID  >võõrsile !41_D	et	f	\N
113455	võõrsile	võõrsile =si  (SgAll  >võõr+si !26_S	et	f	\N
113457	võõrsile	võõrsile =sile  (SgN  >võõr+sile !02_A	et	f	\N
113463	iseloomustab	?iseloomustab =iseloomusta  (IndPrSg3  >iseloomustama !27_V	et	f	\N
113464	iseloomustab	?iseloomustab =loomusta  (IndPrSg3  >ise+loomustama !27_V	et	f	\N
113492	ülevainor2001	?ülevainor =ülevainor  (SgN  >ülevainor !02_S	et	f	\N
113493	ülevainor2001	?ülevainor =vainor  (SgN  >üle+vainor !02_S	et	f	\N
113516	rahnop1965	?rahnop =rahnop  (SgN  >rahnop !02_S	et	f	\N
113528	httpwwweestigiideepersonnimipyearaastaitemid214	?httpwwweestigiideepersonnimipyearaastaitemid =httpwwweestigiideepersonnimipyearaastaitemi  (PlN  >httpwwweestigiideepersonnimipyearaastaitem !02_A	et	f	\N
113541	öölaulupidudeja	?öölaulupidudeja =öölaulupidudeja  (SgN  >öölaulupidudeja !01_S	et	f	\N
113542	öölaulupidudeja	?öölaulupidudeja =öölaulupidudeja  (SgG  >öölaulupidudeja !01_S	et	f	\N
113543	öölaulupidudeja	?öölaulupidudeja =öölaulupidudeja  (SgG  >öölaulupidudejas !02_A	et	f	\N
113544	öölaulupidudeja	?öölaulupidudeja =deja  (SgN  >öö+laulu+pidu+deja !17_S	et	f	\N
113545	öölaulupidudeja	?öölaulupidudeja =deja  (SgG  >öö+laulu+pidu+deja !17_S	et	f	\N
113546	öölaulupidudeja	?öölaulupidudeja =deja  (SgP  >öö+laulu+pidu+deja !17_S	et	f	\N
113549	öölaulupidudeja	?öölaulupidudeja =pidudeja  (SgN  >öö+laulu+pidudeja !01_S	et	f	\N
113550	öölaulupidudeja	?öölaulupidudeja =pidudeja  (SgG  >öö+laulu+pidudeja !01_S	et	f	\N
113551	öölaulupidudeja	?öölaulupidudeja =pidudeja  (SgG  >öö+laulu+pidudejas !02_A	et	f	\N
113552	öölaulupidudeja	?öölaulupidudeja =lupidudeja  (SgN  >öö+lau+lupidudeja !01_S	et	f	\N
113553	öölaulupidudeja	?öölaulupidudeja =lupidudeja  (SgG  >öö+lau+lupidudeja !01_S	et	f	\N
113554	öölaulupidudeja	?öölaulupidudeja =lupidudeja  (SgG  >öö+lau+lupidudejas !02_A	et	f	\N
113555	öölaulupidudeja	?öölaulupidudeja =laulupidudeja  (SgN  >öö+laulupidudeja !01_S	et	f	\N
113273	loolaadi	loolaadi =laadi  (SgG  >loo+laad !22_S	et	f	\N
113274	loolaadi	loolaadi =laadi  (SgP  >loo+laad !22_S	et	f	\N
113275	loolaadi	loolaadi =laadi  (SgAdt  >loo+laad !22_S	et	f	\N
113286	kerkivad	kerkivad =kerki  (IndPrPl3  >kerkima !27_V	et	f	\N
113287	kerkivad	kerkivad =kerkiva  (PlN  >kerkiv !02_A	et	f	\N
113288	kerkivad	"kerkiv %kerki  )V_vA  <kerkima ;27_V	et	f	\N
113313	ekslemist	ekslemist =ekslemis  (SgP  >ekslemine !12_S	et	f	\N
113315	ekslemist	"ekslemine %eksle  )MINE_vS  <ekslema ;30_V	et	f	\N
113345	tonts	?tonts =tonts  (SgN  >tonts !22_S	et	f	\N
113363	kuuluvates	kuuluvates =kuuluva  (PlIn  >kuuluv !02_A	et	f	\N
113364	kuuluvates	"kuuluv %kuulu  )V_vA  <kuuluma ;27_V	et	f	\N
113365	kuuluvates	kuuluvates =vate  (PlIn  >kuulu+vatt !22_S	et	f	\N
113374	roosiaeda	roosiaeda =aeda  (SgP  >roosi+aed !22_S	et	f	\N
113375	roosiaeda	roosiaeda =aeda  (SgAdt  >roosi+aed !22_S	et	f	\N
113400	lapsepõlvekodu	lapsepõlvekodu =kodu  (SgN  >lapse+põlve+kodu !17_S	et	f	\N
113401	lapsepõlvekodu	lapsepõlvekodu =kodu  (SgG  >lapse+põlve+kodu !17_S	et	f	\N
113402	lapsepõlvekodu	lapsepõlvekodu =kodu  (SgP  >lapse+põlve+kodu !17_S	et	f	\N
113413	tõlgendatud	tõlgendatud =tõlgenda  (PtsPtIps  >tõlgendama !27_V	et	f	\N
113414	tõlgendatud	tõlgendatud =tõlgendatu  (PlN  >tõlgendatu !01_S	et	f	\N
113415	tõlgendatud	"tõlgendatu %tõlgenda  )TU1_vS  <tõlgendama ;27_V	et	f	\N
113416	tõlgendatud	tõlgendatud =tõlgendatud  (ID  >tõlgendatud !41_A	et	f	\N
113417	tõlgendatud	"tõlgendatud %tõlgenda  )TUD_vA  <tõlgendama ;27_V	et	f	\N
113418	üleparda	üleparda =parda  (SgG  >üle+parras !07_S	et	f	\N
113419	üleparda	üleparda =parda  (SgP  >üle+pard !22_S	et	f	\N
113420	üleparda	üleparda =parda  (SgAdt  >üle+pard !22_S	et	f	\N
113436	väidsid	?väidsid =väidsi  (PlN  >väids !22_S	et	f	\N
113437	väidsid	?väidsid =väidsi  (IndPrSg2  >väidsima !28_V	et	f	\N
113470	vaatlemine	vaatlemine =vaatlemine  (SgN  >vaatlemine !12_S	et	f	\N
113471	vaatlemine	"vaatlemine %vaatle  )MINE_vS  <vaatlema ;30_V	et	f	\N
113476	ikka	ikka =ikka  (ID  >ikka !41_D	et	f	\N
113477	ikka	ikka =ikka  (SgAdt  >iga !18_S	et	f	\N
113515	tallinn	?tallinn =tallinn  (SgN  >tallinn !22_H	et	f	\N
113519	httpwwweestigiideescat15catid0itemid130	?httpwwweestigiideescatcatiditemid =httpwwweestigiideescatcatiditemi  (PlN  >httpwwweestigiideescatcatiditem !02_A	et	f	\N
113520	sakki2002	sakki =sakki  (SgP  >sakk !22_S	et	f	\N
113521	sakki2002	sakki =sakki  (SgAdt  >sakk !22_S	et	f	\N
113523	monthanderc1997	?monthanderc =monthanderc  (SgN  >monthanderc !22_S	et	f	\N
113526	httpwwweestigiideecatid89itemid325	?httpwwweestigiideecatiditemid =httpwwweestigiideecatiditemi  (PlN  >httpwwweestigiideecatiditem !02_A	et	f	\N
113531	iseloomustage	?iseloomustage =iseloomusta  (ImpPrPl2  >iseloomustama !27_V	et	f	\N
113532	iseloomustage	?iseloomustage =age  (SgN  >ise+loo+must+age !16_S	et	f	\N
113533	iseloomustage	?iseloomustage =age  (SgG  >ise+loo+must+age !16_S	et	f	\N
113534	iseloomustage	?iseloomustage =stage  (SgN  >ise+loomu+stage !16_S	et	f	\N
113535	iseloomustage	?iseloomustage =stage  (SgG  >ise+loomu+stage !16_S	et	f	\N
113536	iseloomustage	?iseloomustage =loomusta  (ImpPrPl2  >ise+loomustama !27_V	et	f	\N
113562	sisu	sisu =sisu  (SgN  >sisu !17_S	et	f	\N
113563	sisu	sisu =sisu  (SgG  >sisu !17_S	et	f	\N
113564	sisu	sisu =sisu  (SgP  >sisu !17_S	et	f	\N
113581	vähendasid	vähendasid =vähenda  (IndIpfSg2  >vähendama !27_V	et	f	\N
113582	vähendasid	vähendasid =vähenda  (IndIpfPl3  >vähendama !27_V	et	f	\N
113591	säilitamine	säilitamine =säilitamine  (SgN  >säilitamine !12_S	et	f	\N
113593	säilitamine	"säilitamine %säilita  )MINE_vS  <säilitama ;27_V	et	f	\N
113614	kriisi	kriisi =kriisi  (SgG  >kriis !22_S	et	f	\N
113615	kriisi	kriisi =kriisi  (SgP  >kriis !22_S	et	f	\N
113617	kriisi	kriisi =kriisi  (SgAdt  >kriis !22_S	et	f	\N
113619	stalinismikuriteod	?stalinismikuriteod =stalinismikuriteo  (PlN  >stalinismikuriteo !01_S	et	f	\N
113620	stalinismikuriteod	?stalinismikuriteod =stalinismikuriteod  (SgN  >stalinismikuriteod !22_S	et	f	\N
113629	vaimu	vaimu =vaimu  (SgG  >vaim !22_S	et	f	\N
113630	vaimu	vaimu =vaimu  (SgP  >vaim !22_S	et	f	\N
113632	vaimu	vaimu =vaimu  (SgAdt  >vaim !22_S	et	f	\N
113633	vaimu	vaimu =vaimu  (PlP  >vaim !22_S	et	f	\N
113677	ajaloole	ajaloole =loo  (SgAll  >aja+lugu !18_S	et	f	\N
113679	ajaloole	ajaloole =loo  (SgAll  >aja+loog !22_S	et	f	\N
113680	ajaloole	ajaloole =loo  (SgAll  >aja+lood !22_S	et	f	\N
113686	valmistati	valmistati =valmista  (IndIpfIps  >valmistama !27_V	et	f	\N
113687	valmistati	valmistati =tati  (SgG  >valmis+tatt !22_S	et	f	\N
113712	trükkiste	?trükkiste =trükkiste  (PlP  >trükkist !22_S	et	f	\N
113720	rummo	?rummo =rummo  (SgN  >rummo !16_S	et	f	\N
113721	rummo	?rummo =rummo  (SgG  >rummo !16_S	et	f	\N
113729	loodusteadus	loodusteadus =teadu  (SgIn  >loodus+tead !22_S	et	f	\N
113730	loodusteadus	loodusteadus =teadus  (SgN  >loodus+teadus !11~09_S	et	f	\N
113756	vbeekman	?vbeekman =vbeekma  (IndPrSg1  >vbeekmama !29_V	et	f	\N
113757	vbeekman	?vbeekman =vbeekman  (SgN  >vbeekman !02_S	et	f	\N
113779	venemaal	venemaal =maa  (SgAd  >vene+maa !26_S	et	f	\N
113780	venemaal	venemaal =maal  (SgN  >vene+maal !22_S	et	f	\N
113804	pildikogu	pildikogu =kogu  (SgN  >pildi+kogu !17_S	et	f	\N
113503	tulevikuprespektiivid	?tulevikuprespektiivid =prespektiivi  (PlN  >tuleviku+prespektiiv !22_S	et	f	\N
113505	tulevikuprespektiivid	?tulevikuprespektiivid =ikuprespektiivi  (PlN  >tulev+ikuprespektiivi !16_S	et	f	\N
113506	tulevikuprespektiivid	?tulevikuprespektiivid =ikuprespektiivi  (PlN  >tulev+ikuprespektiiv !22_S	et	f	\N
113507	tulevikuprespektiivid	?tulevikuprespektiivid =vikuprespektiivi  (PlN  >tule+vikuprespektiivi !16_S	et	f	\N
113508	tulevikuprespektiivid	?tulevikuprespektiivid =vikuprespektiivi  (PlN  >tule+vikuprespektiiv !22_S	et	f	\N
113509	sihtasutus	sihtasutus =asutu  (SgIn  >siht+asutu !01_AS	et	f	\N
113510	sihtasutus	"siht+asutu %asu  )TU2_kA  <siht+asu ;17_S	et	f	\N
113511	sihtasutus	sihtasutus =asutus  (SgN  >siht+asutus !11_S	et	f	\N
113512	sihtasutus	"siht+asutus %asu  )TUS2_aS  <siht+asu ;17_S	et	f	\N
113518	httpwwwharkueefiles103pdf	### httpwwwharkueefiles103pdf	et	f	\N
113573	inglismaa	inglismaa =maa  (SgN  >inglis+maa !26_S	et	f	\N
113574	inglismaa	inglismaa =maa  (SgG  >inglis+maa !26_S	et	f	\N
113587	nsv	### nsv	et	f	\N
113588	gorbatshovi	?gorbatshovi =gorbatshovi  (ID  >gorbatshovi !41_D	et	f	\N
113589	gorbatshovi	?gorbatshovi =gorbatshovi  (SgG  >gorbatshov !02_A	et	f	\N
113601	ühiskonna	ühiskonna =ühiskonna  (SgG  >ühiskond !22_S	et	f	\N
113602	ühiskonna	ühiskonna =konna  (SgG  >ühis+konn !22_S	et	f	\N
113603	ühiskonna	ühiskonna =konna  (SgP  >ühis+konn !22_S	et	f	\N
113604	ühiskonna	ühiskonna =konna  (SgAdt  >ühis+konn !22_S	et	f	\N
113626	põlvkonna	põlvkonna =põlvkonna  (SgG  >põlvkond !22_S	et	f	\N
113627	põlvkonna	põlvkonna =konna  (SgG  >põlv+konn !22_S	et	f	\N
113628	põlvkonna	põlvkonna =konna  (SgP  >põlv+konn !22_S	et	f	\N
113631	põlvkonna	põlvkonna =konna  (SgAdt  >põlv+konn !22_S	et	f	\N
113645	rahvamärke	rahvamärke =märke  (SgG  >rahva+märge !06_S	et	f	\N
113647	rahvamärke	rahvamärke =märke  (PlP  >rahva+märk !22_S	et	f	\N
113659	suurenes	suurenes =suurene  (IndIpfSg3  >suurenema !27_V	et	f	\N
113660	suurenes	suurenes =rene  (SgIn  >suu+rene !16_S	et	f	\N
113661	suurenes	"suu+rene %re  )NE_aA  <suu+re ;26_S	et	f	\N
113689	silmaringi	silmaringi =ringi  (SgG  >silma+ring !22_S	et	f	\N
113690	silmaringi	silmaringi =ringi  (SgP  >silma+ring !22_S	et	f	\N
113692	silmaringi	silmaringi =ringi  (SgAdt  >silma+ring !22_S	et	f	\N
113698	profiliga	profiliga =liga  (SgN  >profi+liga !17_S	et	f	\N
113699	profiliga	profiliga =liga  (SgG  >profi+liga !17_S	et	f	\N
113700	profiliga	profiliga =liga  (SgP  >profi+liga !17_S	et	f	\N
113743	filmid	filmid =filmi  (PlN  >film !22_S	et	f	\N
113744	filmid	filmid =filmi  (IndPrSg2  >filmima !28_V	et	f	\N
113754	kosmeetika	kosmeetika =kosmeetika  (SgN  >kosmeetika !01_S	et	f	\N
113755	kosmeetika	kosmeetika =kosmeetika  (SgG  >kosmeetika !01_S	et	f	\N
113758	vluik	?vluik =vluik  (SgN  >vluik !22_S	et	f	\N
113763	dkareva	?dkareva =dkareva  (SgN  >dkareva !01_S	et	f	\N
113765	dkareva	?dkareva =dkareva  (SgG  >dkareva !01_S	et	f	\N
113767	dkareva	?dkareva =dkareva  (SgG  >dkarev !02_A	et	f	\N
113770	prammiga	?prammiga =prammi  (SgKom  >prammi !16_S	et	f	\N
113771	prammiga	?prammiga =prammi  (SgKom  >pramm !22_S	et	f	\N
113777	vanematega	vanematega =vanema  (PlKom  >vanem !02_AS	et	f	\N
113778	vanematega	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
113799	esitatud	esitatud =esita  (PtsPtIps  >esitama !27_V	et	f	\N
113800	esitatud	esitatud =esitatu  (PlN  >esitatu !01_S	et	f	\N
113801	esitatud	"esitatu %esita  )TU1_vS  <esitama ;27_V	et	f	\N
113802	esitatud	esitatud =esitatud  (ID  >esitatud !41_A	et	f	\N
113803	esitatud	"esitatud %esita  )TUD_vA  <esitama ;27_V	et	f	\N
113807	erinevaid	erinevaid =erineva  (PlP  >erinev !02_A	et	f	\N
113808	erinevaid	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
113861	maastikust	maastikust =maastiku  (SgEl  >maastik !25_S	et	f	\N
113863	maastikust	maastikust =maastikus  (SgP  >maastikune !10?12_A	et	f	\N
113866	maastikust	"maastikune %maastiku  )NE_aA  <maastik ;25_S	et	f	\N
113868	maastikust	maastikust =tiku  (SgEl  >maas+tikk !22_S	et	f	\N
113869	maastikust	maastikust =tiku  (PlEl  >maas+tikk !22_S	et	f	\N
113871	lõpuks	lõpuks =lõpu  (SgTr  >lõpp !22_SA	et	f	\N
113872	lõpuks	lõpuks =lõpuks  (ID  >lõpuks !41_D	et	f	\N
113877	laendab	?laendab =laenda  (IndPrSg3  >laendama !27_V	et	f	\N
113885	paremad	paremad =parema  (PlN  >parem !02_A	et	f	\N
113886	paremad	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
113888	kuldsad	?kuldsad =kuldsa  (PlN  >kuldsa !01_S	et	f	\N
113890	kuldsad	?kuldsad =kuldsa  (IndPrSg2  >kuldsama !29_V	et	f	\N
113894	barokko	?barokko =barokko  (SgN  >barokko !16_S	et	f	\N
113895	barokko	?barokko =barokko  (SgG  >barokko !16_S	et	f	\N
113919	jalutasid	jalutasid =jaluta  (IndIpfSg2  >jalutama !27_V	et	f	\N
113920	jalutasid	jalutasid =jaluta  (IndIpfPl3  >jalutama !27_V	et	f	\N
113926	asi	asi =asi  (SgN  >asi !24_S	et	f	\N
113928	asi	asi =asi  (IndPrPs_  >asima !27_V	et	f	\N
113930	asi	asi =asi  (ImpPrSg2  >asima !27_V	et	f	\N
113945	küllaltki	küllaltki =külla  (SgAbl^  >küll !22_S	et	f	\N
113946	küllaltki	küllaltki =küllalt  (ID^  >küllalt !41_D	et	f	\N
113953	kohas	kohas =koha  (SgIn  >koha !17_S	et	f	\N
113954	kohas	kohas =koha  (SgIn  >koht !22_S	et	f	\N
113556	öölaulupidudeja	?öölaulupidudeja =laulupidudeja  (SgG  >öö+laulupidudeja !01_S	et	f	\N
113557	öölaulupidudeja	?öölaulupidudeja =laulupidudeja  (SgG  >öö+laulupidudejas !02_A	et	f	\N
113558	perestroika	?perestroika =perestroika  (SgN  >perestroika !16_S	et	f	\N
113559	perestroika	?perestroika =perestroika  (SgG  >perestroikas !02_A	et	f	\N
113560	perestroika	?perestroika =perestroika  (SgG  >perestroika !16_S	et	f	\N
113561	glasnostj	### glasnostj	et	f	\N
113565	sunnitud	sunnitud =sunni  (PtsPtIps  >sundima !28_V	et	f	\N
113566	sunnitud	sunnitud =sunnitu  (PlN  >sunnitu !01_AS	et	f	\N
113567	sunnitud	"sunnitu %sunni  )TU1_vS  <sundima ;28_V	et	f	\N
113568	sunnitud	"sunnitu %sunni  )TU2_kA  <sund ;22_S	et	f	\N
113569	sunnitud	sunnitud =sunnitud  (ID  >sunnitud !41_A	et	f	\N
113571	sunnitud	"sunnitud %sunni  )TUD_vA  <sundima ;28_V	et	f	\N
113577	toetasid	toetasid =toeta  (IndIpfSg2  >toetama !27_V	et	f	\N
113578	toetasid	toetasid =toeta  (IndIpfPl3  >toetama !27_V	et	f	\N
113590	süsteemi	süsteemi =süsteemi  (SgG  >süsteem !22_S	et	f	\N
113592	süsteemi	süsteemi =süsteemi  (SgP  >süsteem !22_S	et	f	\N
113594	süsteemi	süsteemi =süsteemi  (SgAdt  >süsteem !22_S	et	f	\N
113595	algasid	algasid =alga  (IndIpfSg2  >algama !29_V	et	f	\N
113596	algasid	algasid =alga  (IndIpfPl3  >algama !29_V	et	f	\N
113597	glasnost	?glasnost =glasno  (SgEl  >glasno !16_S	et	f	\N
113598	glasnost	?glasnost =glasnos  (SgP  >glasnos !11~09_S	et	f	\N
113605	osaliselt	osaliselt =osalise  (SgAbl  >osaline !12_SA	et	f	\N
113606	osaliselt	"osaline %osa  )LINE_aA  <osa ;17_S	et	f	\N
113607	osaliselt	osaliselt =osaliselt  (ID  >osaliselt !41_D	et	f	\N
113608	osaliselt	"osaliselt %osa  )LISELT_mD  <osa ;17_S	et	f	\N
113623	ärkasid	ärkasid =ärka  (IndIpfSg2  >ärkama !29_V	et	f	\N
113625	ärkasid	ärkasid =ärka  (IndIpfPl3  >ärkama !29_V	et	f	\N
113644	teisi	teisi =teisi  (PlP  >teine !12_OP	et	f	\N
113646	teisi	teisi =teisi  (PlP  >teise !12_P	et	f	\N
113650	vaimustasid	vaimustasid =vaimusta  (IndIpfSg2  >vaimustama !27_V	et	f	\N
113651	vaimustasid	vaimustasid =vaimusta  (IndIpfPl3  >vaimustama !27_V	et	f	\N
113657	administreerimine	administreerimine =administreerimine  (SgN  >administreerimine !12_S	et	f	\N
113658	administreerimine	"administreerimine %administreeri  )MINE_vS  <administreerima ;28_V	et	f	\N
113676	keelele	keelele =keele  (SgAll  >keel !13_S	et	f	\N
113678	keelele	keelele =keele  (PlAll  >keeld !22_S	et	f	\N
113683	üldine	üldine =üldine  (SgN  >üldine !10~12_A	et	f	\N
113684	üldine	üldine =ine  (SgN  >üld+ine !16_S	et	f	\N
113685	üldine	üldine =ine  (SgG  >üld+ine !16_S	et	f	\N
113701	masendus	masendus =masendu  (IndIpfSg3  >masenduma !27_V	et	f	\N
113702	masendus	masendus =masendus  (SgN  >masendus !11_S	et	f	\N
113703	masendus	"masendus %masenda  )US_vS  <masendama ;27_V	et	f	\N
113713	sõpruskonnad	sõpruskonnad =sõpruskonna  (PlN  >sõpruskond !22_S	et	f	\N
113714	sõpruskonnad	sõpruskonnad =konna  (PlN  >sõprus+konn !22_S	et	f	\N
113740	olikättesaadav	?olikättesaadav =olikättesaadav  (SgN  >olikättesaadav !02_A	et	f	\N
113748	välismaaid	?välismaaid =välismaai  (PlN  >välismaai !26_S	et	f	\N
113749	välismaaid	?välismaaid =välismaai  (SgP  >välismaai !26_S	et	f	\N
113750	välismaaid	?välismaaid =maaid  (SgN  >välis+maaid !02_S	et	f	\N
113751	välismaaid	?välismaaid =smaaid  (SgN  >väli+smaaid !02_S	et	f	\N
113759	perummo	?perummo =perummo  (SgN  >perummo !16_S	et	f	\N
113761	perummo	?perummo =perummo  (SgG  >perummo !16_S	et	f	\N
113772	rongiga	rongiga =rongi  (SgKom  >rong !22_S	et	f	\N
113773	rongiga	rongiga =iga  (SgN  >rong+iga !18_S	et	f	\N
113774	rongiga	rongiga =iga  (SgP  >rong+iga !18_S	et	f	\N
113784	ääres	ääres =ääre  (SgIn  >äär !13_S	et	f	\N
113786	ääres	ääres =ääres  (ID  >ääres !41_K	et	f	\N
113789	aluses	aluses =aluse  (SgIn  >alus !09_S	et	f	\N
113790	aluses	aluses =aluse  (SgIn  >alune !10_AS	et	f	\N
113791	aluses	"alune %alu  )NE_aA  <alg ;22_S	et	f	\N
113792	sõidasime	?sõidasime =sõida  (IndIpfPl1  >sõidama !29_V	et	f	\N
113809	kunstist	kunstist =kunsti  (SgEl  >kunst !22_S	et	f	\N
113810	kunstist	kunstist =ist  (SgN  >kunst+ist !22_S	et	f	\N
113814	novotserkask	?novotserkask =novotserkask  (SgN  >novotserkask !22_S	et	f	\N
113815	novotserkask	?novotserkask =tserkask  (SgN  >novo+tserkask !02_S	et	f	\N
113830	unustumata	?unustumata =unustu  (SupAb  >unustuma !27_V	et	f	\N
113831	unustumata	?unustumata =unustuma  (SgAb  >unustum !02_A	et	f	\N
113832	unustumata	?unustumata =unustumata  (ID  >unustumata !41_A	et	f	\N
113833	unustumata	?unustumata =unustumata  (IndPrPs_  >unustumatama !27_V	et	f	\N
113834	unustumata	?unustumata =unustumata  (ImpPrSg2  >unustumatama !27_V	et	f	\N
113835	palav	palav =pala  (PtsPrPs  >palama !27_V	et	f	\N
113836	palav	palav =palav  (SgN  >palav !02_A	et	f	\N
113839	palav	"palav %pala  )V_vA  <palama ;27_V	et	f	\N
113847	arvutu	arvutu =arvutu  (SgN  >arvutu !01_A	et	f	\N
113848	arvutu	"arvutu %arvu  )TU2_kA  <arv ;22_S	et	f	\N
113849	arvutu	arvutu =arvutu  (SgG  >arvutu !01_A	et	f	\N
113852	läbipäistev	?läbipäistev =läbipäistev  (SgN  >läbipäistev !02_A	et	f	\N
113853	läbipäistev	?läbipäistev =päist  (PtsPrPs  >läbi+_päistma !34_V	et	f	\N
113579	liikumisi	liikumisi =liikumisi  (PlP  >liikumine !12_S	et	f	\N
113580	liikumisi	"liikumine %liiku  )MINE_vS  <liikuma ;28_V	et	f	\N
113585	alandamise	alandamise =alandamise  (SgG  >alandamine !12_S	et	f	\N
113586	alandamise	"alandamine %alanda  )MINE_vS  <alandama ;27_V	et	f	\N
113599	avalikustamine	avalikustamine =avalikustamine  (SgN  >avalikustamine !12_S	et	f	\N
113600	avalikustamine	"avalikustamine %avalikusta  )MINE_vS  <avalikustama ;27_V	et	f	\N
113609	kaasa	kaasa =kaasa  (ID  >kaasa !41_D	et	f	\N
113610	kaasa	kaasa =kaasa  (SgN  >kaasa !16_S	et	f	\N
113611	kaasa	kaasa =kaasa  (SgG  >kaasa !16_S	et	f	\N
113612	kaasa	kaasa =kaasa  (IndPrPs_  >kaasama !29_V	et	f	\N
113613	kaasa	kaasa =kaasa  (ImpPrSg2  >kaasama !29_V	et	f	\N
113616	seisukohad	seisukohad =koha  (PlN  >seisu+koha !17_S	et	f	\N
113618	seisukohad	seisukohad =koha  (PlN  >seisu+koht !22_S	et	f	\N
113640	rahvast	rahvast =rahva  (SgEl  >rahvas !07_S	et	f	\N
113641	rahvast	rahvast =rahvas  (SgP  >rahvas !07_S	et	f	\N
113642	rahvast	rahvast =rahvas  (SgP  >rahvane !10_A	et	f	\N
113643	rahvast	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
113652	ususid	?ususid =usu  (PlP  >usu !17_S	et	f	\N
113653	ususid	?ususid =usu  (IndIpfSg2  >usuma !27_V	et	f	\N
113654	ususid	?ususid =usu  (IndIpfPl3  >usuma !27_V	et	f	\N
113664	kontrolli	kontrolli =kontrolli  (SgG  >kontroll !22_S	et	f	\N
113666	kontrolli	kontrolli =kontrolli  (SgP  >kontroll !22_S	et	f	\N
113667	kontrolli	kontrolli =kontrolli  (SgAdt  >kontroll !22_S	et	f	\N
113668	kontrolli	kontrolli =kontrolli  (IndPrPs_  >kontrollima !28_V	et	f	\N
113669	kontrolli	kontrolli =kontrolli  (ImpPrSg2  >kontrollima !28_V	et	f	\N
113681	pionerid	?pionerid =pioneri  (PlN  >pioneri !01_S	et	f	\N
113682	pionerid	?pionerid =pioneri  (PlN  >pioner !02_S	et	f	\N
113688	piiratud	piiratud =piira  (PtsPtIps  >piirama !29_V	et	f	\N
113691	piiratud	piiratud =piiratu  (PlN  >piiratu !01_AS	et	f	\N
113693	piiratud	"piiratu %piira  )TU1_vS  <piirama ;29_V	et	f	\N
113694	piiratud	"piiratu %piira  )TU2_kA  <piird ;22_S	et	f	\N
113695	piiratud	piiratud =piiratud  (ID  >piiratud !41_A	et	f	\N
113696	piiratud	"piiratud %piira  )TUD_vA  <piirama ;29_V	et	f	\N
113697	piiratud	piiratud =atu  (PlN  >piir+att !22_S	et	f	\N
113704	pessimismi	pessimismi =pessimismi  (SgG  >pessimism !22_S	et	f	\N
113705	pessimismi	pessimismi =pessimismi  (SgP  >pessimism !22_S	et	f	\N
113706	pessimismi	pessimismi =pessimismi  (SgAdt  >pessimism !22_S	et	f	\N
113717	kasutasid	kasutasid =kasuta  (IndIpfSg2  >kasutama !27_V	et	f	\N
113718	kasutasid	kasutasid =kasuta  (IndIpfPl3  >kasutama !27_V	et	f	\N
113722	klassikalisest	klassikalisest =klassikalise  (SgEl  >klassikaline !12_A	et	f	\N
113723	klassikalisest	"klassikaline %klassika  )LINE_aA  <klassika ;01_S	et	f	\N
113724	klassikalisest	klassikalisest =kalise  (SgEl  >klassi+kaline !10_A	et	f	\N
113725	klassikalisest	"klassi+kaline %kali  )NE_aA  <klassi+kali ;17_S	et	f	\N
113726	dzhässfestivale	?dzhässfestivale =dzhässfestiva  (SgAll  >dzhässfestiv !02_A	et	f	\N
113727	dzhässfestivale	?dzhässfestivale =dzhässfestiva  (SgAll  >dzhässfestiva !16_S	et	f	\N
113728	dzhässfestivale	?dzhässfestivale =dzhässfestivale  (PlP  >dzhässfestival !19_S	et	f	\N
113737	keelt	keelt =kee  (SgAbl  >kesi !15_S	et	f	\N
113738	keelt	keelt =kee  (SgAbl  >kee !26_S	et	f	\N
113739	keelt	keelt =keel  (SgP  >keel !13_S	et	f	\N
113752	teksad	?teksad =teksa  (PlN  >teksa !16_S	et	f	\N
113753	teksad	?teksad =teksa  (IndPrSg2  >teksama !29_V	et	f	\N
113760	jkaplinski	?jkaplinski =jkaplinski  (SgG  >jkaplinsk !02_S	et	f	\N
113762	jkaplinski	?jkaplinski =jkaplinski  (IndPrPs_  >jkaplinskima !28_V	et	f	\N
113764	jkaplinski	?jkaplinski =jkaplinski  (ImpPrSg2  >jkaplinskima !28_V	et	f	\N
113766	jkaplinski	?jkaplinski =jkaplins  (SgN^  >jkaplins !02_S	et	f	\N
113775	sõidasin	?sõidasin =sõida  (IndIpfSg1  >sõidama !29_V	et	f	\N
113776	sõidasin	?sõidasin =sõidasin  (SgN  >sõidasin !19_S	et	f	\N
113781	musta	musta =musta  (SgG  >must !22_AS	et	f	\N
113782	musta	musta =musta  (SgP  >must !22_AS	et	f	\N
113783	musta	musta =musta  (SgAdt  >must !22_AS	et	f	\N
113785	musta	musta =musta  (IndPrPs_  >mustama !29_V	et	f	\N
113787	musta	musta =musta  (ImpPrSg2  >mustama !29_V	et	f	\N
113793	moskvas	?moskvas =moskva  (IndIpfSg3  >moskvama !29_V	et	f	\N
113794	moskvas	?moskvas =moskvas  (SgN  >moskvas !07_S	et	f	\N
113797	galerii	galerii =galerii  (SgN  >galerii !26_S	et	f	\N
113798	galerii	galerii =galerii  (SgG  >galerii !26_S	et	f	\N
113811	ümbritsev	ümbritsev =ümbritse  (PtsPrPs  >ümbritsema !27_V	et	f	\N
113812	ümbritsev	ümbritsev =ümbritsev  (SgN  >ümbritsev !02_A	et	f	\N
113813	ümbritsev	"ümbritsev %ümbritse  )V_vA  <ümbritsema ;27_V	et	f	\N
113816	peakirikust	peakirikust =us  (SgP  >pea+kirik+uks !14_S	et	f	\N
113817	peakirikust	peakirikust =kus  (SgP  >pea+kiri+kusi !20_S	et	f	\N
113818	peakirikust	peakirikust =kiriku  (SgEl  >pea+kirik !02_S	et	f	\N
113819	ebatavaliselt	ebatavaliselt =tavalise  (SgAbl  >eba+tavaline !12_A	et	f	\N
113820	ebatavaliselt	"eba+tavaline %tava  )LINE_aA  <eba+tava ;17_S	et	f	\N
113821	ebatavaliselt	ebatavaliselt =tavaliselt  (ID  >eba+tavaliselt !41_D	et	f	\N
113649	laule	laule =laule  (PlP  >laul !22_S	et	f	\N
113655	püüdsid	püüdsid =püüd  (IndIpfSg2  >püüdma !34_V	et	f	\N
113656	püüdsid	püüdsid =püüd  (IndIpfPl3  >püüdma !34_V	et	f	\N
113662	hariduselu	hariduselu =elu  (SgN  >haridus+elu !17_S	et	f	\N
113663	hariduselu	hariduselu =elu  (SgG  >haridus+elu !17_S	et	f	\N
113665	hariduselu	hariduselu =elu  (SgP  >haridus+elu !17_S	et	f	\N
113670	pandi	pandi =pan  (IndIpfIps  >panema !36_V	et	f	\N
113671	pandi	pandi =pandi  (SgG  >pant !22_S	et	f	\N
113672	pandi	pandi =pandi  (SgP  >pand !22_S	et	f	\N
113673	pandi	pandi =pandi  (SgAdt  >pand !22_S	et	f	\N
113674	pandi	pandi =pandi  (IndPrPs_  >pantima !28_V	et	f	\N
113675	pandi	pandi =pandi  (ImpPrSg2  >pantima !28_V	et	f	\N
113707	uskunud	uskunud =usku  (PtsPtPs  >uskuma !28_V	et	f	\N
113708	uskunud	uskunud =uskunu  (PlN  >uskunu !01_S	et	f	\N
113709	uskunud	"uskunu %usku  )NU_vS  <uskuma ;28_V	et	f	\N
113710	uskunud	uskunud =uskunud  (ID  >uskunud !41_A	et	f	\N
113711	uskunud	"uskunud %usku  )NUD_vA  <uskuma ;28_V	et	f	\N
113715	luules	luules =luule  (SgIn  >luule !06_S	et	f	\N
113716	luules	luules =luule  (PlIn  >luul !22_S	et	f	\N
113719	pe	### pe	et	f	\N
113731	venekeelepropaganda	venekeelepropaganda =propaganda  (SgN  >vene+keele+propaganda !16_S	et	f	\N
113732	venekeelepropaganda	venekeelepropaganda =propaganda  (SgG  >vene+keele+propaganda !16_S	et	f	\N
113733	muulastel	muulastel =muulas  (PlAd  >muulane !12?10_S	et	f	\N
113734	muulastel	"muulane %muula  )NE_aA  <muul ;22_S	et	f	\N
113735	muulastel	muulastel =las  (PlAd  >muu+laps !14_S	et	f	\N
113736	muulastel	muulastel =laste  (PlAd  >muu+last !22_S	et	f	\N
113741	arenesilmusid	?arenesilmusid =arenesilmu  (IndIpfSg2  >arenesilmuma !27_V	et	f	\N
113742	arenesilmusid	?arenesilmusid =arenesilmu  (IndIpfPl3  >arenesilmuma !27_V	et	f	\N
113745	kuulati	kuulati =kuula  (IndIpfIps  >kuulama !29_V	et	f	\N
113746	kuulati	kuulati =ati  (SgG  >kuul+att !22_S	et	f	\N
113747	kuulati	kuulati =lati  (SgG  >kuu+latt !22_S	et	f	\N
113768	essee	essee =essee  (SgN  >essee !26_S	et	f	\N
113769	essee	essee =essee  (SgG  >essee !26_S	et	f	\N
113788	mitmedes	?mitmedes =mitme  (Ger  >mitmema !27_V	et	f	\N
113795	tretjakovi	?tretjakovi =tretjakovi  (ID  >tretjakovi !41_D	et	f	\N
113796	tretjakovi	?tretjakovi =tretjakovi  (SgG  >tretjakov !02_A	et	f	\N
113827	sirasid	sirasid =sira  (PlP  >sira !17_S	et	f	\N
113828	sirasid	sirasid =sira  (IndIpfSg2  >sirama !27_V	et	f	\N
113829	sirasid	sirasid =sira  (IndIpfPl3  >sirama !27_V	et	f	\N
113859	loodust	loodust =loodu  (SgEl  >loodu !01_S	et	f	\N
113862	loodust	"loodu %loo  )TU1_vS  <looma ;38_V	et	f	\N
113864	loodust	loodust =loodus  (SgP  >loodus !11~09_S	et	f	\N
113867	loodust	"loodus %loo  )TUS1_aS  <looma ;38_V	et	f	\N
113870	loodust	loodust =dust  (SgN  >loo+dust !22_S	et	f	\N
113896	hooned	hooned =hoone  (PlN  >hoone !06_S	et	f	\N
113898	hooned	"hoone %hoo  )NE_aA  <hoog ;22_S	et	f	\N
113903	muidugi	muidugi =muidugi  (ID  >muidugi !41_D	et	f	\N
113904	muidugi	muidugi =muidu  (ID^  >muidu !41_D	et	f	\N
113913	sugulastele	sugulastele =sugulas  (PlAll  >sugulane !12_S	et	f	\N
113914	sugulastele	sugulastele =las  (PlAll  >sugu+laps !14_S	et	f	\N
113915	sugulastele	sugulastele =laste  (PlAll  >sugu+last !22_S	et	f	\N
113916	tekkitas	?tekkitas =tekkita  (IndIpfSg3  >tekkitama !27_V	et	f	\N
113936	kaevast	?kaevast =kaeva  (SgEl  >kaeva !16_S	et	f	\N
113937	kaevast	?kaevast =kaevas  (SgP  >kaevas !07_S	et	f	\N
113938	kaevast	?kaevast =kaevas  (SgP  >kaevane !10_A	et	f	\N
113961	soovi	soovi =soovi  (SgG  >soov !22_S	et	f	\N
113962	soovi	soovi =soovi  (SgP  >soov !22_S	et	f	\N
113963	soovi	soovi =soovi  (SgAdt  >soov !22_S	et	f	\N
113964	soovi	soovi =soovi  (IndPrPs_  >soovima !28_V	et	f	\N
113965	soovi	soovi =soovi  (ImpPrSg2  >soovima !28_V	et	f	\N
113978	tutvudud	?tutvudud =tutvudu  (PlN  >tutvudu !01_S	et	f	\N
113979	tutvudud	?tutvudud =tutvudu  (IndPrSg2  >tutvuduma !27_V	et	f	\N
113980	tutvudud	?tutvudud =tutvudud  (ID  >tutvudud !41_A	et	f	\N
113999	mõelda	mõelda =mõel  (Inf  >mõtlema !30_V	et	f	\N
114000	mõelda	mõelda =mõel  (IndPrIps_  >mõtlema !30_V	et	f	\N
114045	vaatavad	vaatavad =vaata  (IndPrPl3  >vaatama !29_V	et	f	\N
114046	vaatavad	vaatavad =vaatava  (PlN  >vaatav !02_A	et	f	\N
114047	vaatavad	"vaatav %vaata  )V_vA  <vaatama ;29_V	et	f	\N
114086	vist	vist =vist  (ID  >vist !41_D	et	f	\N
114087	vist	vist =vist  (SgN  >vist !22_S	et	f	\N
114125	pool	pool =pool  (ID  >pool !41_DK	et	f	\N
114127	pool	pool =pool  (SgN  >pool !13_NS	et	f	\N
114128	pool	pool =pool  (SgN  >pool !22_S	et	f	\N
114129	joosse	?joosse =joo  (SgIll  >joo !26_S	et	f	\N
114130	joosse	?joosse =joosse  (SgG  >joosne !02_A	et	f	\N
114131	joosse	?joosse =joosse  (SgG  >joose !06_S	et	f	\N
114132	joosse	?joosse =joosse  (PlP  >jooss !22_S	et	f	\N
114133	joosse	?joosse =joosse  (IndPrPs_  >joossema !27_V	et	f	\N
114134	joosse	?joosse =joosse  (ImpPrSg2  >joossema !27_V	et	f	\N
114136	tasuta	tasuta =tasu  (SgAb  >tasu !17_S	et	f	\N
114138	tasuta	tasuta =tasu  (IndPrIps_  >tasuma !27_V	et	f	\N
113805	pildikogu	pildikogu =kogu  (SgG  >pildi+kogu !17_S	et	f	\N
113806	pildikogu	pildikogu =kogu  (SgP  >pildi+kogu !17_S	et	f	\N
113824	sinised	?sinised =sinise  (PlN  >sinis !09_S	et	f	\N
113825	sinised	?sinised =sinise  (PlN  >sinine !10_AS	et	f	\N
113826	sinised	?sinised =sinise  (IndPrSg2  >sinisema !27_V	et	f	\N
113837	kohtasid	kohtasid =kohta  (PlP  >koht !22_S	et	f	\N
113838	kohtasid	kohtasid =kohta  (IndIpfSg2  >kohtama !29_V	et	f	\N
113840	kohtasid	kohtasid =kohta  (IndIpfPl3  >kohtama !29_V	et	f	\N
113850	vesi	vesi =vesi  (SgN  >vesi !15_S	et	f	\N
113851	vesi	vesi =vesi  (PlP  >vesi !15_S	et	f	\N
113854	lisaks	lisaks =lisa  (SgTr  >lisa !17_S	et	f	\N
113856	lisaks	lisaks =lisa  (KndPrPs  >lisama !27_V	et	f	\N
113858	vaatamisväärsustest	vaatamisväärsustest =test  (SgN  >vaatamis+väärsus+test !22_S	et	f	\N
113860	vaatamisväärsustest	vaatamisväärsustest =väärsus  (PlEl  >vaatamis+väärsus !11~09_S	et	f	\N
113865	vaatamisväärsustest	"vaatamis+väärsus %väärse  )US_aS  <vaatamis+väärne ;02_A	et	f	\N
113879	näinud	näinud =näi  (PtsPtPs  >nägema !28_V	et	f	\N
113880	näinud	näinud =näi  (PtsPtPs  >näima !37_V	et	f	\N
113881	näinud	näinud =näinu  (PlN  >näinu !01_S	et	f	\N
113882	näinud	"näinu %näi  )NU_vS  <nägema ;28_V	et	f	\N
113883	näinud	näinud =näinu  (PlN  >näinu !06_S	et	f	\N
113884	näinud	"näinud %näi  )NUD_vA  <nägema ;28_V	et	f	\N
113891	turgis	?turgis =turgi  (SgIn  >turk !22_S	et	f	\N
113892	turgis	?turgis =turgi  (IndIpfSg3  >turgima !28_V	et	f	\N
113893	turgis	?turgis =turgis  (SgN  >turgis !09_S	et	f	\N
113897	vanemaal	?vanemaal =vanemaa  (SgAd  >vanemaa !26_S	et	f	\N
113899	vanemaal	?vanemaal =vanemaal  (SgN  >vanemaal !22_S	et	f	\N
113900	vanemaal	?vanemaal =aal  (SgN  >vanem+aal !22_S	et	f	\N
113905	parem	parem =parem  (ID  >parem !41_D	et	f	\N
113906	parem	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
113907	parem	parem =parem  (SgN  >parem !02_A	et	f	\N
113921	televisorist	?televisorist =televisori  (SgEl  >televisor !02_S	et	f	\N
113922	televisorist	?televisorist =televisoris  (SgP  >televisoris !09_S	et	f	\N
113923	televisorist	?televisorist =televisorist  (SgN  >televisorist !22_S	et	f	\N
113924	televisorist	?televisorist =visori  (SgEl  >tele+visori !01_S	et	f	\N
113925	televisorist	?televisorist =visori  (SgEl  >tele+visor !02_S	et	f	\N
113927	televisorist	?televisorist =visoris  (SgP  >tele+visoris !11_S	et	f	\N
113929	televisorist	?televisorist =visorist  (SgN  >tele+visorist !22_S	et	f	\N
113934	mugavuse	mugavuse =mugavuse  (SgG  >mugavus !11_S	et	f	\N
113935	mugavuse	"mugavus %mugava  )US_aS  <mugav ;02_A	et	f	\N
113941	kohanematu	kohanematu =kohanematu  (SgN  >kohanematu !01_A	et	f	\N
113942	kohanematu	"kohanematu %kohane  )MATU_vA  <kohanema ;27_V	et	f	\N
113943	kohanematu	kohanematu =kohanematu  (SgG  >kohanematu !01_A	et	f	\N
113949	hall	hall =hall  (SgN  >hall !22_S	et	f	\N
113950	hall	hall =hall  (SgN  >hall !22_AS	et	f	\N
113983	peatuseni	peatuseni =peatuse  (SgTer  >peatus !11~09_S	et	f	\N
113984	peatuseni	"peatus %peata  )US_vS  <peatama ;27_V	et	f	\N
113985	peatuseni	"peatus %pea  )TUS2_aS  <pea ;26_S	et	f	\N
114031	eneergiline	?eneergiline =eneergiline  (SgN  >eneergiline !12_A	et	f	\N
114032	eneergiline	?eneergiline =eneergiline  (PlP  >eneergilin !19_S	et	f	\N
114041	baari	baari =baari  (SgG  >baar !22_S	et	f	\N
114042	baari	baari =baari  (SgP  >baar !22_S	et	f	\N
114043	baari	baari =baari  (SgAdt  >baar !22_S	et	f	\N
114053	ilusaim	ilusaim =ilusaim  (SgN  >ilusaim !02_A	et	f	\N
114054	ilusaim	"ilusaim %ilusa  )IM_sA  <ilus ;02_A	et	f	\N
114055	korjanud	korjanud =korja  (PtsPtPs  >korjama !29_V	et	f	\N
114056	korjanud	korjanud =korjanu  (PlN  >korjanu !01_S	et	f	\N
114057	korjanud	"korjanu %korja  )NU_vS  <korjama ;29_V	et	f	\N
114058	korjanud	korjanud =korjanud  (ID  >korjanud !41_A	et	f	\N
114059	korjanud	"korjanud %korja  )NUD_vA  <korjama ;29_V	et	f	\N
114060	imestanud	imestanud =imesta  (PtsPtPs  >imestama !27_V	et	f	\N
114061	imestanud	imestanud =imestanu  (PlN  >imestanu !01_S	et	f	\N
114062	imestanud	"imestanu %imesta  )NU_vS  <imestama ;27_V	et	f	\N
114063	imestanud	imestanud =imestanud  (ID  >imestanud !41_A	et	f	\N
114064	imestanud	"imestanud %imesta  )NUD_vA  <imestama ;27_V	et	f	\N
114077	venemaad	venemaad =maa  (PlN  >vene+maa !26_S	et	f	\N
114078	venemaad	venemaad =maa  (SgP  >vene+maa !26_S	et	f	\N
114082	venemaale	venemaale =maa  (SgAll  >vene+maa !26_S	et	f	\N
114084	venemaale	venemaale =maale  (PlP  >vene+maal !22_S	et	f	\N
114088	homikul	?homikul =homiku  (SgAd  >homiku !01_S	et	f	\N
114091	homikul	?homikul =homiku  (SgAd  >homik !02_S	et	f	\N
114093	homikul	?homikul =homikul  (SgN  >homikul !19_S	et	f	\N
114108	vähem	vähem =vähem  (ID  >vähem !41_D	et	f	\N
114109	vähem	"vähem %vähe  )M_cA  <väike ;10_A	et	f	\N
114110	vähem	vähem =vähem  (SgN  >vähem !02_A	et	f	\N
114119	mootoreline	?mootoreline =mootoreline  (SgN  >mootoreline !12_A	et	f	\N
114120	mootoreline	?mootoreline =mootoreline  (PlP  >mootorelin !19_S	et	f	\N
114121	mootoreline	?mootoreline =eline  (SgN  >mootor+eline !10_A	et	f	\N
114122	natuke	natuke =natuke  (ID  >natuke !41_D	et	f	\N
113822	ebatavaliselt	"eba+tavaliselt %tava  )LISELT_mD  <eba+tava ;17_S	et	f	\N
113823	ebatavaliselt	"eba+tavaliselt %tavalise  )LT_mD  <eba+tavaline ;12_A	et	f	\N
113841	üllatanud	üllatanud =üllata  (PtsPtPs  >üllatama !27_V	et	f	\N
113842	üllatanud	üllatanud =üllatanu  (PlN  >üllatanu !01_S	et	f	\N
113843	üllatanud	"üllatanu %üllata  )NU_vS  <üllatama ;27_V	et	f	\N
113844	üllatanud	üllatanud =üllatanud  (ID  >üllatanud !41_A	et	f	\N
113845	üllatanud	"üllatanud %üllata  )NUD_vA  <üllatama ;27_V	et	f	\N
113846	üllatanud	üllatanud =tanu  (PlN  >ülla+tanu !17_S	et	f	\N
113873	unustamatu	unustamatu =unustamatu  (SgN  >unustamatu !01_A	et	f	\N
113874	unustamatu	"unustamatu %unusta  )MATU_vA  <unustama ;27_V	et	f	\N
113875	unustamatu	unustamatu =unustamatu  (SgG  >unustamatu !01_A	et	f	\N
113876	reisimine	reisimine =reisimine  (SgN  >reisimine !12_S	et	f	\N
113878	reisimine	"reisimine %reisi  )MINE_vS  <reisima ;28_V	et	f	\N
113908	ebab	?ebab =eba  (IndPrSg3  >ebama !27_V	et	f	\N
113909	mälestuses	mälestuses =mälestuse  (SgIn  >mälestus !11_S	et	f	\N
113910	mälestuses	"mälestus %mälesta  )US_vS  <mälestama ;27_V	et	f	\N
113911	omapärane	omapärane =pärane  (SgN  >oma+pärane !10_A	et	f	\N
113912	omapärane	"oma+pärane %pära  )NE_aA  <oma+pära ;17_S	et	f	\N
113917	õues	õues =õue  (SgIn  >õu !22_S	et	f	\N
113918	õues	õues =õues  (ID  >õues !41_D	et	f	\N
113939	ebamugavused	ebamugavused =mugavuse  (PlN  >eba+mugavus !11_S	et	f	\N
113940	ebamugavused	"eba+mugavus %mugava  )US_aS  <eba+mugav ;02_A	et	f	\N
113944	tutvunud	tutvunud =tutvu  (PtsPtPs  >tutvuma !27_V	et	f	\N
113947	tutvunud	tutvunud =tutvunu  (PlN  >tutvunu !01_S	et	f	\N
113948	tutvunud	"tutvunu %tutvu  )NU_vS  <tutvuma ;27_V	et	f	\N
113951	tutvunud	tutvunud =tutvunud  (ID  >tutvunud !41_A	et	f	\N
113952	tutvunud	"tutvunud %tutvu  )NUD_vA  <tutvuma ;27_V	et	f	\N
113956	kogenenud	kogenenud =kogene  (PtsPtPs  >kogenema !27_V	et	f	\N
113957	kogenenud	kogenenud =kogenenu  (PlN  >kogenenu !01_S	et	f	\N
113958	kogenenud	"kogenenu %kogene  )NU_vS  <kogenema ;27_V	et	f	\N
113959	kogenenud	kogenenud =kogenenud  (ID  >kogenenud !41_A	et	f	\N
113960	kogenenud	"kogenenud %kogene  )NUD_vA  <kogenema ;27_V	et	f	\N
113967	sõida	sõida =sõida  (IndPrPs_  >sõitma !34_V	et	f	\N
113969	sõida	sõida =sõida  (ImpPrSg2  >sõitma !34_V	et	f	\N
113976	rongis	rongis =rongi  (SgIn  >rong !22_S	et	f	\N
113977	rongis	rongis =rongi  (PlIn  >ronk !22_S	et	f	\N
113986	huvitavat	huvitavat =huvita  (KvtPrPs  >huvitama !27_V	et	f	\N
113987	huvitavat	huvitavat =huvitava  (SgP  >huvitav !02_A	et	f	\N
113988	huvitavat	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
113996	kai	kai =kai  (SgN  >kai !22_S	et	f	\N
113997	kai	kai =kai  (SgN  >kai !26_S	et	f	\N
113998	kai	kai =kai  (SgG  >kai !26_S	et	f	\N
114001	omast	omast =oma  (SgEl  >oma !17_A	et	f	\N
114002	omast	omast =omas  (SgP  >omas !09_S	et	f	\N
114003	omast	omast =omas  (SgP  >omane !10_A	et	f	\N
114009	korda	korda =korda  (ID  >korda !41_D	et	f	\N
114010	korda	korda =korda  (SgP  >kord !22_S	et	f	\N
114011	korda	korda =korda  (SgAdt  >kord !22_S	et	f	\N
114012	korda	korda =korda  (IndPrPs_  >kordama !29_V	et	f	\N
114013	korda	korda =korda  (ImpPrSg2  >kordama !29_V	et	f	\N
114018	mugavam	mugavam =mugavam  (SgN  >mugavam !02_A	et	f	\N
114019	mugavam	"mugavam %mugava  )M_cA  <mugav ;02_A	et	f	\N
114027	kluubist	?kluubist =kluubi  (SgEl  >kluubi !16_S	et	f	\N
114028	kluubist	?kluubist =kluubi  (SgEl  >kluup !22_S	et	f	\N
114029	kluubist	?kluubist =kluubis  (SgP  >kluubis !09_S	et	f	\N
114030	kluubist	?kluubist =kluubist  (SgN  >kluubist !22_S	et	f	\N
114033	väsinud	väsinud =väsi  (PtsPtPs  >väsima !27_V	et	f	\N
114034	väsinud	väsinud =väsinu  (PlN  >väsinu !01_S	et	f	\N
114035	väsinud	"väsinu %väsi  )NU_vS  <väsima ;27_V	et	f	\N
114036	väsinud	väsinud =väsinud  (ID  >väsinud !41_A	et	f	\N
114037	väsinud	"väsinud %väsi  )NUD_vA  <väsima ;27_V	et	f	\N
114044	tihem	?tihem =tihem  (SgN  >tihem !02_A	et	f	\N
114068	punase	punase =punase  (SgG  >punane !10_AS	et	f	\N
114069	punase	"punane %puna  )NE_aA  <puna ;17_S	et	f	\N
114079	reisseid	?reisseid =reisse  (PlP  >reisne !02_A	et	f	\N
114080	reisseid	?reisseid =reisse  (PlP  >reise !06_S	et	f	\N
114081	reisseid	?reisseid =reissei  (PlN  >reissei !26_S	et	f	\N
114083	reisseid	?reisseid =reissei  (SgP  >reissei !26_S	et	f	\N
114085	reisseid	?reisseid =reisseid  (SgN  >reisseid !22_S	et	f	\N
114094	helistanud	helistanud =helista  (PtsPtPs  >helistama !27_V	et	f	\N
114095	helistanud	helistanud =helistanu  (PlN  >helistanu !01_S	et	f	\N
114096	helistanud	"helistanu %helista  )NU_vS  <helistama ;27_V	et	f	\N
114097	helistanud	helistanud =helistanud  (ID  >helistanud !41_A	et	f	\N
114098	helistanud	"helistanud %helista  )NUD_vA  <helistama ;27_V	et	f	\N
114104	keilasse	?keilasse =keila  (SgIll  >keila !16_S	et	f	\N
114105	keilasse	?keilasse =keilas  (SgAdt  >keilane !12_S	et	f	\N
114106	keilasse	?keilasse =keilasse  (SgG  >keilasne !02_A	et	f	\N
114107	keilasse	?keilasse =keilasse  (PlP  >keilass !22_S	et	f	\N
114111	odavam	odavam =odavam  (SgN  >odavam !02_A	et	f	\N
113855	läbipäistev	?läbipäistev =päiste  (PtsPrPs  >läbi+_päistema !27_V	et	f	\N
113857	läbipäistev	?läbipäistev =päistev  (SgN  >läbi+päistev !02_A	et	f	\N
113887	mälestused	mälestused =mälestuse  (PlN  >mälestus !11_S	et	f	\N
113889	mälestused	"mälestus %mälesta  )US_vS  <mälestama ;27_V	et	f	\N
113901	elusuhtumine	elusuhtumine =uhtumine  (SgN  >elus+uhtumine !12_S	et	f	\N
113902	elusuhtumine	elusuhtumine =suhtumine  (SgN  >elu+suhtumine !12_S	et	f	\N
113931	hirmitas	?hirmitas =hirmita  (IndIpfSg3  >hirmitama !27_V	et	f	\N
113932	hirmitas	?hirmitas =ita  (SgIn  >hirm+ita !16_S	et	f	\N
113933	hirmitas	?hirmitas =itas  (SgN  >hirm+itas !07_S	et	f	\N
113989	kluubid	?kluubid =kluubi  (PlN  >kluubi !16_S	et	f	\N
113990	kluubid	?kluubid =kluubi  (PlN  >kluup !22_S	et	f	\N
113991	kluubid	?kluubid =kluubi  (IndPrSg2  >kluubima !27_V	et	f	\N
113992	kluubid	?kluubid =kluubi  (IndPrSg2  >kluupima !28_V	et	f	\N
113993	kai	kai =kai  (SgN  >kai !22_S	et	f	\N
113994	kai	kai =kai  (SgN  >kai !26_S	et	f	\N
113995	kai	kai =kai  (SgG  >kai !26_S	et	f	\N
114004	laiste	?laiste =laiste  (SgN  >laiste !06_S	et	f	\N
114005	laiste	?laiste =laiste  (SgG  >laiste !06_S	et	f	\N
114006	laiste	?laiste =laiste  (PlP  >laist !22_S	et	f	\N
114007	laiste	?laiste =laiste  (IndPrPs_  >laistema !27_V	et	f	\N
114008	laiste	?laiste =laiste  (ImpPrSg2  >laistema !27_V	et	f	\N
114014	ööelda	?ööelda =ööelda  (IndPrPs_  >ööeldama !27_V	et	f	\N
114015	ööelda	?ööelda =ööelda  (ImpPrSg2  >ööeldama !27_V	et	f	\N
114016	ööelda	?ööelda =elda  (SgN  >öö+elda !16_S	et	f	\N
114017	ööelda	?ööelda =elda  (SgG  >öö+elda !16_S	et	f	\N
114020	meil	meil =me  (PlAd  >ma !00_P	et	f	\N
114021	meil	meil =meil  (SgN  >meil !22_S	et	f	\N
114022	ühendanud	ühendanud =ühenda  (PtsPtPs  >ühendama !27_V	et	f	\N
114023	ühendanud	ühendanud =ühendanu  (PlN  >ühendanu !01_S	et	f	\N
114024	ühendanud	"ühendanu %ühenda  )NU_vS  <ühendama ;27_V	et	f	\N
114025	ühendanud	ühendanud =ühendanud  (ID  >ühendanud !41_A	et	f	\N
114026	ühendanud	"ühendanud %ühenda  )NUD_vA  <ühendama ;27_V	et	f	\N
114038	kino	kino =kino  (SgN  >kino !17_S	et	f	\N
114039	kino	kino =kino  (SgG  >kino !17_S	et	f	\N
114040	kino	kino =kino  (SgP  >kino !17_S	et	f	\N
114065	muinasjuttuds	?muinasjuttuds =muinasjuttuds  (SgN  >muinasjuttuds !22_S	et	f	\N
114066	muinasjuttuds	?muinasjuttuds =uds  (SgN  >muinas+jutt+uds !22_S	et	f	\N
114067	muinasjuttuds	?muinasjuttuds =juttuds  (SgN  >muinas+juttuds !22_S	et	f	\N
114070	peal	peal =pea  (SgAd  >pea !26_S	et	f	\N
114071	peal	peal =peal  (ID  >peal !41_DK	et	f	\N
114072	täppid	### täppid	et	f	\N
114089	sajas	sajas =saja  (SgIn  >sajas !02_O	et	f	\N
114090	sajas	sajas =saja  (SgIn  >sada !18_N	et	f	\N
114092	sajas	sajas =sajas  (SgN  >sajas !02_O	et	f	\N
114103	sõidsime	?sõidsime =sõidsi  (IndPrPl1  >sõidsima !28_V	et	f	\N
114124	tundi	tundi =tundi  (SgP  >tund !22_S	et	f	\N
114126	tundi	tundi =tundi  (SgAdt  >tund !22_S	et	f	\N
114135	auto	auto =auto  (SgN  >auto !16_S	et	f	\N
114137	auto	auto =auto  (SgG  >auto !16_S	et	f	\N
114143	suvilasse	suvilasse =suvila  (SgIll  >suvila !01_S	et	f	\N
114144	suvilasse	suvilasse =suvilas  (SgAdt  >suvilane !12_S	et	f	\N
114145	suvilasse	"suvilane %suvila  )NE_aA  <suvila ;01_S	et	f	\N
114146	suvilasse	suvilasse =la  (SgIll  >suvi+la !26_S	et	f	\N
114147	suvilasse	suvilasse =lasse  (PlP  >suvi+lass !22_S	et	f	\N
114159	peterburisse	?peterburisse =peterburi  (SgIll  >peterbur !19_S	et	f	\N
114160	peterburisse	?peterburisse =peterburisse  (SgG  >peterburisne !02_A	et	f	\N
114161	peterburisse	?peterburisse =peterburisse  (PlP  >peterburiss !22_S	et	f	\N
114182	varamusel	?varamusel =varamuse  (SgAd  >varamus !11_S	et	f	\N
114183	varamusel	?varamusel =muse  (SgAd  >vara+muse !16_S	et	f	\N
114184	varamusel	?varamusel =musel  (SgN  >vara+musel !02_S	et	f	\N
114191	hirmsalt	hirmsalt =hirmsa  (SgAbl  >hirmus !02_A	et	f	\N
114192	hirmsalt	hirmsalt =hirmsalt  (ID  >hirmsalt !41_D	et	f	\N
114193	hirmsalt	"hirmsalt %hirmsa  )LT_mD  <hirmus ;02_A	et	f	\N
114207	puudel	puudel =puu  (PlAd  >puu !26_S	et	f	\N
114208	puudel	puudel =puude  (SgAd  >puue !06_S	et	f	\N
114209	puudel	puudel =puudel  (SgN  >puudel !02_S	et	f	\N
114214	sättisid	sättisid =sätti  (IndIpfSg2  >sättima !28_V	et	f	\N
114215	sättisid	sättisid =sätti  (IndIpfPl3  >sättima !28_V	et	f	\N
114222	maja	maja =maja  (SgN  >maja !17_S	et	f	\N
114223	maja	maja =maja  (SgG  >maja !17_S	et	f	\N
114224	maja	maja =maja  (SgP  >maja !17_S	et	f	\N
114227	proektid	?proektid =proekti  (PlN  >proekt !22_S	et	f	\N
114228	proektid	?proektid =proekti  (IndPrSg2  >proektima !28_V	et	f	\N
114233	romaantiline	?romaantiline =romaantiline  (SgN  >romaantiline !12_A	et	f	\N
114234	romaantiline	?romaantiline =romaantiline  (PlP  >romaantilin !19_S	et	f	\N
114247	londonis	?londonis =londoni  (SgIn  >london !02_S	et	f	\N
114249	londonis	?londonis =londonis  (SgN  >londonis !11_S	et	f	\N
114250	londonisse	?londonisse =londoni  (SgIll  >london !02_S	et	f	\N
114251	londonisse	?londonisse =londonis  (SgAdt  >londonis !11_S	et	f	\N
113955	kohas	kohas =koha  (IndIpfSg3  >kohama !27_V	et	f	\N
113966	kiireneni	?kiireneni =kiireneni  (SgG  >kiirenen !19_S	et	f	\N
113968	kiireneni	?kiireneni =kiireneni  (SgP  >kiirenen !19_S	et	f	\N
113970	kiireneni	?kiireneni =kiireneni  (SgAdt  >kiirenen !19_S	et	f	\N
113971	kiireneni	?kiireneni =neni  (SgN  >kiire+neni !17_S	et	f	\N
113972	kiireneni	?kiireneni =neni  (SgG  >kiire+neni !17_S	et	f	\N
113973	kiireneni	?kiireneni =neni  (SgP  >kiire+neni !17_S	et	f	\N
113974	kiireneni	?kiireneni =ene  (SgTer  >kiir+ene !16_S	et	f	\N
113975	kiireneni	?kiireneni =eneni  (SgG  >kiir+enen !02_S	et	f	\N
113981	lobinesin	?lobinesin =lobine  (IndIpfSg1  >lobinema !27_V	et	f	\N
113982	lobinesin	?lobinesin =lobinesin  (SgN  >lobinesin !19_S	et	f	\N
114048	filmi	filmi =filmi  (SgG  >film !22_S	et	f	\N
114049	filmi	filmi =filmi  (SgP  >film !22_S	et	f	\N
114050	filmi	filmi =filmi  (SgAdt  >film !22_S	et	f	\N
114051	filmi	filmi =filmi  (IndPrPs_  >filmima !28_V	et	f	\N
114052	filmi	filmi =filmi  (ImpPrSg2  >filmima !28_V	et	f	\N
114073	kojju	?kojju =kojju  (SgN  >kojju !16_S	et	f	\N
114074	kojju	?kojju =kojju  (SgG  >kojju !16_S	et	f	\N
114075	kojju	?kojju =kojju  (IndPrPs_  >kojjuma !27_V	et	f	\N
114076	kojju	?kojju =kojju  (ImpPrSg2  >kojjuma !27_V	et	f	\N
114099	keilasse	?keilasse =keila  (SgIll  >keila !16_S	et	f	\N
114100	keilasse	?keilasse =keilas  (SgAdt  >keilane !12_S	et	f	\N
114101	keilasse	?keilasse =keilasse  (SgG  >keilasne !02_A	et	f	\N
114102	keilasse	?keilasse =keilasse  (PlP  >keilass !22_S	et	f	\N
114113	huvitavam	huvitavam =huvitavam  (SgN  >huvitavam !02_A	et	f	\N
114114	huvitavam	"huvitavam %huvita  )VAM_cA  <huvitama ;27_V	et	f	\N
114115	huvitavam	"huvitavam %huvitava  )M_cA  <huvitav ;02_A	et	f	\N
114153	16i	### 16i	et	f	\N
114175	püramiidi	püramiidi =püramiidi  (SgG  >püramiid !22_S	et	f	\N
114176	püramiidi	püramiidi =püramiidi  (SgP  >püramiid !22_S	et	f	\N
114177	püramiidi	püramiidi =püramiidi  (SgAdt  >püramiid !22_S	et	f	\N
114179	egiptus	?egiptus =egiptu  (SgIn  >egiptu !01_S	et	f	\N
114180	egiptus	?egiptus =egiptu  (IndIpfSg3  >egiptuma !27_V	et	f	\N
114181	egiptus	?egiptus =egiptus  (SgN  >egiptus !11_S	et	f	\N
114188	õudselt	õudselt =õudse  (SgAbl  >õudne !02_A	et	f	\N
114189	õudselt	õudselt =õudselt  (ID  >õudselt !41_D	et	f	\N
114190	õudselt	"õudselt %õudse  )LT_mD  <õudne ;02_A	et	f	\N
114194	maal	maal =maa  (SgAd  >maa !26_S	et	f	\N
114195	maal	maal =maal  (SgN  >maal !22_S	et	f	\N
114218	meel	meel =mee  (SgAd  >mesi !15_S	et	f	\N
114219	meel	meel =meel  (SgN  >meel !13_S	et	f	\N
114220	veekogust	veekogust =kogu  (SgEl  >vee+kogu !17_S	et	f	\N
114221	veekogust	veekogust =kogus  (SgP  >vee+kogus !09_S	et	f	\N
114235	unistusest	unistusest =unistuse  (SgEl  >unistus !11_S	et	f	\N
114236	unistusest	"unistus %unista  )US_vS  <unistama ;27_V	et	f	\N
114237	unistusest	unistusest =unistuses  (SgP  >unistusene !12_A	et	f	\N
114238	unistusest	"unistusene %unistuse  )NE_aA  <unistus ;11_S	et	f	\N
114241	seisundisest	?seisundisest =seisundise  (SgEl  >seisundis !11_S	et	f	\N
114242	seisundisest	?seisundisest =seisundises  (SgP  >seisundisene !12_A	et	f	\N
114245	torem	?torem =torem  (SgN  >torem !02_A	et	f	\N
114246	inglismaal	inglismaal =maa  (SgAd  >inglis+maa !26_S	et	f	\N
114248	inglismaal	inglismaal =maal  (SgN  >inglis+maal !22_S	et	f	\N
114256	londoni	?londoni =londo  (SgTer  >londo !16_S	et	f	\N
114257	londoni	?londoni =londoni  (SgG  >london !02_S	et	f	\N
114260	rääkimis	?rääkimis =rääkimi  (SgIn  >rääkimi !01_S	et	f	\N
114261	rääkimis	?rääkimis =rääkimi  (SgIn  >rääkim !02_A	et	f	\N
114262	rääkimis	?rääkimis =rääkimis  (SgN  >rääkimis !11_S	et	f	\N
114272	erine	erine =erine  (SgN  >erine !10_A	et	f	\N
114273	erine	"erine %eri  )NE_aA  <eri ;17_S	et	f	\N
114276	erine	erine =erine  (IndPrPs_  >erinema !27_V	et	f	\N
114277	erine	erine =erine  (ImpPrSg2  >erinema !27_V	et	f	\N
114321	renoveritud	?renoveritud =renoveritu  (PlN  >renoveritu !01_A	et	f	\N
114322	renoveritud	?renoveritud =renoveritu  (IndPrSg2  >renoverituma !27_V	et	f	\N
114323	renoveritud	?renoveritud =renoveritud  (ID  >renoveritud !41_A	et	f	\N
114334	venelastest	venelastest =venelas  (PlEl  >venelane !12_S	et	f	\N
114335	venelastest	venelastest =las  (PlEl  >vene+laps !14_S	et	f	\N
114336	venelastest	venelastest =laste  (PlEl  >vene+last !22_S	et	f	\N
114360	ööbimine	ööbimine =ööbimine  (SgN  >ööbimine !12_S	et	f	\N
114361	ööbimine	"ööbimine %ööbi  )MINE_vS  <ööbima ;27_V	et	f	\N
114388	vaatamisvärsused	?vaatamisvärsused =vaatamisvärsuse  (PlN  >vaatamisvärsus !11~09_S	et	f	\N
114389	vaatamisvärsused	?vaatamisvärsused =värsuse  (PlN  >vaatamis+värsus !11~09_S	et	f	\N
114391	atlanteline	?atlanteline =atlanteline  (SgN  >atlanteline !12_A	et	f	\N
114392	atlanteline	?atlanteline =atlanteline  (PlP  >atlantelin !19_S	et	f	\N
114401	sündinud	sündinud =sündi  (PtsPtPs  >sündima !28_V	et	f	\N
114402	sündinud	sündinud =sündinu  (PlN  >sündinu !01_S	et	f	\N
114403	sündinud	"sündinu %sündi  )NU_vS  <sündima ;28_V	et	f	\N
114404	sündinud	sündinud =sündinud  (ID  >sündinud !41_A	et	f	\N
114112	odavam	"odavam %odava  )M_cA  <odav ;02_A	et	f	\N
114116	keilast	?keilast =keila  (SgEl  >keila !16_S	et	f	\N
114117	keilast	?keilast =keilas  (SgP  >keilas !07_S	et	f	\N
114118	keilast	?keilast =keilas  (SgP  >keilane !12?10_S	et	f	\N
114139	parkida	parkida =parki  (Inf  >parkima !28_V	et	f	\N
114140	parkida	parkida =ida  (SgN  >park+ida !17_S	et	f	\N
114141	parkida	parkida =ida  (SgG  >park+ida !17_S	et	f	\N
114142	parkida	parkida =ida  (SgP  >park+ida !17_S	et	f	\N
114156	sankt	?sankt =sankt  (SgN  >sankt !22_S	et	f	\N
114170	picasso	?picasso =picasso  (SgN  >picasso !16_S	et	f	\N
114171	picasso	?picasso =picasso  (SgG  >picasso !16_S	et	f	\N
114172	vahva	vahva =vahva  (SgN  >vahva !01_A	et	f	\N
114173	vahva	vahva =vahva  (SgG  >vahva !01_A	et	f	\N
114174	egiptuse	?egiptuse =egiptuse  (SgG  >egiptus !11_S	et	f	\N
114178	tundakse	?tundakse =tundakse  (SgG  >tundakne !02_A	et	f	\N
114185	ausalt	ausalt =ausa  (SgAbl  >aus !02_A	et	f	\N
114186	ausalt	ausalt =ausalt  (ID  >ausalt !41_D	et	f	\N
114187	ausalt	"ausalt %ausa  )LT_mD  <aus ;02_A	et	f	\N
114199	keha	keha =keha  (SgN  >keha !17_S	et	f	\N
114200	keha	keha =keha  (SgG  >keha !17_S	et	f	\N
114201	keha	keha =keha  (SgP  >keha !17_S	et	f	\N
114210	kollased	kollased =kollase  (PlN  >kollane !10_A	et	f	\N
114211	kollased	"kollane %kolla  )NE_aA  <kold ;22_S	et	f	\N
114231	veekogusel	veekogusel =koguse  (SgAd  >vee+kogus !09_S	et	f	\N
114232	veekogusel	veekogusel =koguse  (SgAd  >vee+kogus !02_A	et	f	\N
114239	soovist	soovist =soovi  (SgEl  >soov !22_S	et	f	\N
114240	soovist	soovist =vist  (SgN  >soo+vist !22_S	et	f	\N
114269	elekantne	?elekantne =elekantne  (SgN  >elekantne !02_A	et	f	\N
114284	sarnased	sarnased =sarnase  (PlN  >sarnane !10_A	et	f	\N
114285	sarnased	"sarnane %sarna  )NE_aA  <sarn ;22_S	et	f	\N
114303	otavad	?otavad =ota  (IndPrPl3  >otama !27_V	et	f	\N
114304	otavad	?otavad =otava  (PlN  >otava !01_S	et	f	\N
114305	otavad	?otavad =otava  (PlN  >otav !02_A	et	f	\N
114348	jutustavad	jutustavad =jutusta  (IndPrPl3  >jutustama !27_V	et	f	\N
114349	jutustavad	jutustavad =jutustava  (PlN  >jutustav !02_A	et	f	\N
114350	jutustavad	"jutustav %jutusta  )V_vA  <jutustama ;27_V	et	f	\N
114362	jaos	jaos =jao  (SgIn  >jagu !18_S	et	f	\N
114363	jaos	jaos =jaos  (SgN  >jaos !09_S	et	f	\N
114377	transiga	transiga =transi  (SgKom  >transs !22_S	et	f	\N
114379	transiga	transiga =iga  (SgN  >trans+iga !18_S	et	f	\N
114381	transiga	transiga =iga  (SgP  >trans+iga !18_S	et	f	\N
114384	turnir	?turnir =turnir  (SgN  >turnir !02_S	et	f	\N
114390	dover	?dover =dover  (SgN  >dover !02_S	et	f	\N
114428	luuletusi	luuletusi =luuletusi  (PlP  >luuletus !11_S	et	f	\N
114429	luuletusi	"luuletus %luuleta  )US_vS  <luuletama ;27_V	et	f	\N
114430	luuletusi	"luuletus %luule  )TUS2_aS  <luule ;06_S	et	f	\N
114452	bandi	?bandi =bandi  (SgN  >bandi !16_S	et	f	\N
114454	bandi	?bandi =bandi  (SgG  >bandi !16_S	et	f	\N
114455	bandi	?bandi =bandi  (SgG  >bant !22_S	et	f	\N
114456	bandi	?bandi =bandi  (SgP  >band !22_S	et	f	\N
114457	bandi	?bandi =bandi  (SgAdt  >band !22_S	et	f	\N
114458	bandi	?bandi =bandi  (IndPrPs_  >bantima !28_V	et	f	\N
114459	bandi	?bandi =bandi  (ImpPrSg2  >bantima !28_V	et	f	\N
114467	heli	heli =heli  (SgN  >heli !17_S	et	f	\N
114468	heli	heli =heli  (SgG  >heli !17_S	et	f	\N
114469	heli	heli =heli  (SgP  >heli !17_S	et	f	\N
114474	vestlisime	?vestlisime =vestli  (IndIpfPl1  >vestlima !28_V	et	f	\N
114488	kontrollida	kontrollida =kontrolli  (Inf  >kontrollima !28_V	et	f	\N
114489	kontrollida	kontrollida =ida  (SgN  >kont+roll+ida !17_S	et	f	\N
114491	kontrollida	kontrollida =ida  (SgG  >kont+roll+ida !17_S	et	f	\N
114493	kontrollida	kontrollida =ida  (SgP  >kont+roll+ida !17_S	et	f	\N
114520	lehte	lehte =lehte  (ID  >lehte !41_D	et	f	\N
114521	lehte	lehte =lehte  (SgP  >leht !22_S	et	f	\N
114522	lehte	lehte =lehte  (SgAdt  >leht !22_S	et	f	\N
114523	lehte	lehte =lehte  (PlP  >leht !22_S	et	f	\N
114530	füüsika	füüsika =füüsika  (SgN  >füüsika !01_S	et	f	\N
114531	füüsika	füüsika =füüsika  (SgG  >füüsika !01_S	et	f	\N
114602	mätle	?mätle =mätle  (SgN  >mätle !06_S	et	f	\N
114603	mätle	?mätle =mätle  (IndPrPs_  >mätlema !30_V	et	f	\N
114604	mätle	?mätle =mätle  (ImpPrSg2  >mätlema !30_V	et	f	\N
114616	venemal	?venemal =venema  (SgAd  >venem !02_A	et	f	\N
114617	venemal	?venemal =venemal  (ID  >venemal !41_D	et	f	\N
114623	mäleta	mäleta =mäleta  (IndPrPs_  >mäletama !27_V	et	f	\N
114624	mäleta	mäleta =mäleta  (ImpPrSg2  >mäletama !27_V	et	f	\N
114625	õpima	?õpima =õpi  (Sup  >õpima !27_V	et	f	\N
114626	õpima	?õpima =õpima  (SgG  >õpim !02_A	et	f	\N
114629	estlased	?estlased =estlase  (PlN  >estlane !12?10_S	et	f	\N
114633	viga	viga =viga  (SgN  >viga !18_S	et	f	\N
114634	viga	viga =viga  (SgP  >viga !18_S	et	f	\N
114663	õpetajaga	õpetajaga =õpetaja  (SgKom  >õpetaja !01_S	et	f	\N
114664	õpetajaga	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
114674	reeglidest	?reeglidest =reeglides  (SgP  >reeglidene !12_A	et	f	\N
114123	natuke	natuke =natuke  (SgN  >natuke !12_S	et	f	\N
114148	sõitnud	sõitnud =sõit  (PtsPtPs  >sõitma !34_V	et	f	\N
114149	sõitnud	sõitnud =sõitnu  (PlN  >sõitnu !01_S	et	f	\N
114150	sõitnud	"sõitnu %sõit  )NU_vS  <sõitma ;34_V	et	f	\N
114151	sõitnud	sõitnud =sõitnud  (ID  >sõitnud !41_A	et	f	\N
114152	sõitnud	"sõitnud %sõit  )NUD_vA  <sõitma ;34_V	et	f	\N
114154	täpsemalt	täpsemalt =täpsema  (SgAbl  >täpsem !02_A	et	f	\N
114155	täpsemalt	"täpsem %täpse  )M_cA  <täpne ;02_A	et	f	\N
114157	täpsemalt	täpsemalt =täpsemalt  (ID  >täpsemalt !41_D	et	f	\N
114158	täpsemalt	"täpsemalt %täpse  )MALT_mD  <täpne ;02_A	et	f	\N
114162	sugulastel	sugulastel =sugulas  (PlAd  >sugulane !12_S	et	f	\N
114163	sugulastel	sugulastel =las  (PlAd  >sugu+laps !14_S	et	f	\N
114164	sugulastel	sugulastel =laste  (PlAd  >sugu+last !22_S	et	f	\N
114196	sauna	sauna =sauna  (SgG  >saun !22_S	et	f	\N
114197	sauna	sauna =sauna  (SgP  >saun !22_S	et	f	\N
114198	sauna	sauna =sauna  (SgAdt  >saun !22_S	et	f	\N
114202	kombeid	kombeid =kombe  (PlP  >komme !06_S	et	f	\N
114203	kombeid	kombeid =bei  (PlN  >kom+bei !26_S	et	f	\N
114204	kombeid	kombeid =bei  (SgP  >kom+bei !26_S	et	f	\N
114205	puhus	puhus =puhu  (SgIn  >puhk !22_S	et	f	\N
114206	puhus	puhus =puhu  (IndIpfSg3  >puhuma !27_V	et	f	\N
114229	sellisel	sellisel =sellise  (SgAd  >selline !10_P	et	f	\N
114230	sellisel	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
114270	elustiil	elustiil =elusti  (PlAd  >elusti !01_S	et	f	\N
114271	elustiil	elustiil =stiil  (SgN  >elu+stiil !22_S	et	f	\N
114280	tunde	tunde =tunde  (SgG  >tunne !06_S	et	f	\N
114281	tunde	tunde =tunde  (PlP  >tund !22_S	et	f	\N
114286	üldselt	?üldselt =üldse  (SgAbl  >üldne !02_A	et	f	\N
114287	üldselt	?üldselt =üldse  (PlAbl  >ülds !22_S	et	f	\N
114288	üldselt	?üldselt =üldselt  (ID  >üldselt !41_D	et	f	\N
114289	jaanuari	jaanuari =jaanuari  (SgG  >jaanuar !19_S	et	f	\N
114290	jaanuari	jaanuari =jaanuari  (SgP  >jaanuar !19_S	et	f	\N
114291	jaanuari	jaanuari =jaanuari  (SgAdt  >jaanuar !19_S	et	f	\N
114316	stokholm	?stokholm =stokholm  (SgN  >stokholm !22_S	et	f	\N
114328	kauplustes	kauplustes =kauplus  (PlIn  >kauplus !11~09_S	et	f	\N
114329	kauplustes	kauplustes =luste  (SgIn  >kaup+luste !06_S	et	f	\N
114330	kauplustes	kauplustes =luste  (PlIn  >kaup+lust !22_S	et	f	\N
114337	huvilise	huvilise =huvilise  (SgG  >huviline !12_SA	et	f	\N
114338	huvilise	"huviline %huvi  )LINE_aA  <huvi ;17_S	et	f	\N
114339	panevaid	panevaid =paneva  (PlP  >panev !02_A	et	f	\N
114340	panevaid	"panev %pane  )V_vA  <panema ;36_V	et	f	\N
114355	alguses	alguses =alguse  (SgIn  >algus !11~09_S	et	f	\N
114356	alguses	alguses =use  (PlIn  >alg+usk !22_S	et	f	\N
114359	sbk	### sbk	et	f	\N
114367	näe	näe =näe  (IndPrPs_  >nägema !28_V	et	f	\N
114368	näe	näe =näe  (ImpPrSg2  >nägema !28_V	et	f	\N
114373	meeskonnaga	meeskonnaga =meeskonna  (SgKom  >meeskond !22_S	et	f	\N
114375	meeskonnaga	meeskonnaga =konna  (SgKom  >mees+konn !22_S	et	f	\N
114385	kurortis	?kurortis =kurorti  (SgIn  >kurorti !01_S	et	f	\N
114386	kurortis	?kurortis =kurorti  (IndIpfSg3  >kurortima !28_V	et	f	\N
114387	kurortis	?kurortis =kurortis  (SgN  >kurortis !11_S	et	f	\N
114420	algusel	algusel =alguse  (SgAd  >algus !11~09_S	et	f	\N
114421	algusel	algusel =use  (PlAd  >alg+usk !22_S	et	f	\N
114431	lugema	lugema =luge  (Sup  >lugema !28_V	et	f	\N
114432	lugema	lugema =lugema  (SgG  >lugem !02_S	et	f	\N
114442	avangardi	avangardi =avangardi  (SgG  >avangard !22_S	et	f	\N
114443	avangardi	avangardi =avangardi  (SgP  >avangard !22_S	et	f	\N
114444	avangardi	avangardi =avangardi  (SgAdt  >avangard !22_S	et	f	\N
114445	lõpetaks	lõpetaks =lõpe  (KndPrIps  >lõppema !28_V	et	f	\N
114446	lõpetaks	lõpetaks =lõpe  (KndPrIps  >lõpma !35_V	et	f	\N
114447	lõpetaks	lõpetaks =lõpeta  (KndPrPs  >lõpetama !27_V	et	f	\N
114460	vaat	vaat =vaat  (ID  >vaat !41_I	et	f	\N
114461	vaat	vaat =vaat  (SgN  >vaat !22_S	et	f	\N
114464	vaatamata	vaatamata =vaata  (SupAb  >vaatama !29_V	et	f	\N
114465	vaatamata	vaatamata =vaatamata  (ID  >vaatamata !41_K	et	f	\N
114466	vaatamata	"vaatamata %vaata  )MATA_vA  <vaatama ;29_V	et	f	\N
114477	suurepärane	suurepärane =pärane  (SgN  >suure+pärane !10_A	et	f	\N
114478	suurepärane	"suure+pärane %pära  )NE_aA  <suure+pära ;17_S	et	f	\N
114498	maganud	maganud =maga  (PtsPtPs  >magama !27_V	et	f	\N
114499	maganud	maganud =maganu  (PlN  >maganu !01_S	et	f	\N
114500	maganud	"maganu %maga  )NU_vS  <magama ;27_V	et	f	\N
114501	maganud	maganud =maganud  (ID  >maganud !41_A	et	f	\N
114502	maganud	"maganud %maga  )NUD_vA  <magama ;27_V	et	f	\N
114535	pead	pead =pea  (IndPrSg2  >pida !40_V	et	f	\N
114536	pead	pead =pea  (PlN  >pea !26_S	et	f	\N
114537	pead	pead =pea  (SgP  >pea !26_S	et	f	\N
114538	pead	pead =pea  (IndPrSg2  >pidama !28_V	et	f	\N
114541	niimodi	?niimodi =niimodi  (SgN  >niimodi !01_S	et	f	\N
114542	niimodi	?niimodi =niimodi  (SgG  >niimodi !01_S	et	f	\N
114543	niimodi	?niimodi =niimodi  (SgG  >niimod !02_S	et	f	\N
114544	niimodi	?niimodi =modi  (SgN  >nii+modi !17_S	et	f	\N
114165	südalinnas	südalinnas =linna  (SgIn  >süda+linn !22_S	et	f	\N
114166	südalinnas	südalinnas =linnas  (SgN  >süda+linnas !09_S	et	f	\N
114167	aivasovski	?aivasovski =aivasovski  (IndPrPs_  >aivasovskima !28_V	et	f	\N
114168	aivasovski	?aivasovski =aivasovski  (ImpPrSg2  >aivasovskima !28_V	et	f	\N
114169	aivasovski	?aivasovski =aivasovs  (SgN^  >aivasovs !22_S	et	f	\N
114212	punased	punased =punase  (PlN  >punane !10_AS	et	f	\N
114213	punased	"punane %puna  )NE_aA  <puna ;17_S	et	f	\N
114216	kaugele	kaugele =kauge  (SgAll  >kauge !01_A	et	f	\N
114217	kaugele	kaugele =kaugele  (ID  >kaugele !41_D	et	f	\N
114225	rigikogus	?rigikogus =rigikogu  (IndIpfSg3  >rigikoguma !27_V	et	f	\N
114226	rigikogus	?rigikogus =rigikogus  (SgN  >rigikogus !11?09_S	et	f	\N
114243	kartasin	?kartasin =karta  (IndIpfSg1  >kartama !29_V	et	f	\N
114244	kartasin	?kartasin =kartasin  (SgN  >kartasin !19_S	et	f	\N
114252	kohtumiseks	kohtumiseks =kohtumise  (SgTr  >kohtumine !12_S	et	f	\N
114253	kohtumiseks	"kohtumine %kohtu  )MINE_vS  <kohtuma ;27_V	et	f	\N
114263	bigbeni	?bigbeni =bigbe  (SgTer  >bigbe !06_S	et	f	\N
114264	bigbeni	?bigbeni =bigbeni  (SgG  >bigben !02_S	et	f	\N
114265	võrrelda	võrrelda =võrrel  (Inf  >võrdlema !30_V	et	f	\N
114266	võrrelda	võrrelda =võrrel  (IndPrIps_  >võrdlema !30_V	et	f	\N
114267	oleviste	?oleviste =olevis  (PlG  >olevis !11_S	et	f	\N
114268	oleviste	?oleviste =oleviste  (PlP  >olevist !22_S	et	f	\N
114292	selleks	selleks =selle  (SgTr  >see !00_P	et	f	\N
114293	selleks	selleks =selle  (PlTr  >sell !22_S	et	f	\N
114294	stokholmi	?stokholmi =stokholmi  (SgN  >stokholmi !01_S	et	f	\N
114295	stokholmi	?stokholmi =stokholmi  (SgG  >stokholmi !01_S	et	f	\N
114296	stokholmi	?stokholmi =stokholmi  (SgG  >stokholm !22_S	et	f	\N
114297	stokholmi	?stokholmi =stokholmi  (SgP  >stokholm !22_S	et	f	\N
114298	stokholmi	?stokholmi =stokholmi  (SgAdt  >stokholm !22_S	et	f	\N
114299	stokholmi	?stokholmi =stokholmi  (IndPrPs_  >stokholmima !28_V	et	f	\N
114300	stokholmi	?stokholmi =stokholmi  (ImpPrSg2  >stokholmima !28_V	et	f	\N
114306	tavaliselt	tavaliselt =tavalise  (SgAbl  >tavaline !12_A	et	f	\N
114307	tavaliselt	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
114308	tavaliselt	tavaliselt =tavaliselt  (ID  >tavaliselt !41_D	et	f	\N
114309	tavaliselt	"tavaliselt %tava  )LISELT_mD  <tava ;17_S	et	f	\N
114310	tavaliselt	"tavaliselt %tavalise  )LT_mD  <tavaline ;12_A	et	f	\N
114314	surepärane	?surepärane =surepärane  (SgN  >surepärane !12_A	et	f	\N
114315	surepärane	?surepärane =surepärane  (PlP  >surepäran !19_S	et	f	\N
114343	varastanud	varastanud =varasta  (PtsPtPs  >varastama !27_V	et	f	\N
114344	varastanud	varastanud =varastanu  (PlN  >varastanu !01_S	et	f	\N
114345	varastanud	"varastanu %varasta  )NU_vS  <varastama ;27_V	et	f	\N
114346	varastanud	varastanud =varastanud  (ID  >varastanud !41_A	et	f	\N
114347	varastanud	"varastanud %varasta  )NUD_vA  <varastama ;27_V	et	f	\N
114357	kergem	kergem =kergem  (SgN  >kergem !02_A	et	f	\N
114358	kergem	"kergem %kerge  )M_cA  <kerge ;01_A	et	f	\N
114371	telki	telki =telki  (SgP  >telk !22_S	et	f	\N
114372	telki	telki =telki  (SgAdt  >telk !22_S	et	f	\N
114382	inglismaale	inglismaale =maa  (SgAll  >inglis+maa !26_S	et	f	\N
114383	inglismaale	inglismaale =maale  (PlP  >inglis+maal !22_S	et	f	\N
114415	asustaja	asustaja =asustaja  (SgN  >asustaja !01_S	et	f	\N
114416	asustaja	"asustaja %asusta  )JA_vS  <asustama ;27_V	et	f	\N
114417	asustaja	asustaja =asustaja  (SgG  >asustaja !01_S	et	f	\N
114422	kõk	### kõk	et	f	\N
114436	süngused	süngused =sünguse  (PlN  >süngus !11~09_S	et	f	\N
114437	süngused	"süngus %sünge  )US_aS  <sünge ;01_A	et	f	\N
114483	mitmekesisus	?mitmekesisus =mitmekesisu  (IndIpfSg3  >mitmekesisuma !27_V	et	f	\N
114484	mitmekesisus	?mitmekesisus =mitmekesisus  (SgN  >mitmekesisus !11?09_S	et	f	\N
114485	poodi	poodi =poo  (IndIpfIps  >pooma !38_V	et	f	\N
114486	poodi	poodi =poodi  (SgP  >pood !22_S	et	f	\N
114487	poodi	poodi =poodi  (SgAdt  >pood !22_S	et	f	\N
114506	kehalinekasvatus	?kehalinekasvatus =kehalinekasvatu  (SgIn  >kehalinekasvatu !01_A	et	f	\N
114507	kehalinekasvatus	?kehalinekasvatus =kehalinekasvatu  (IndIpfSg3  >kehalinekasvatuma !27_V	et	f	\N
114508	kehalinekasvatus	?kehalinekasvatus =kehalinekasvatus  (SgN  >kehalinekasvatus !11?09_S	et	f	\N
114509	kehalinekasvatus	?kehalinekasvatus =linekasvatu  (SgIn  >keha+linekasvatu !01_A	et	f	\N
114510	kehalinekasvatus	?kehalinekasvatus =linekasvatus  (SgN  >keha+linekasvatus !11?09_S	et	f	\N
114511	teadnud	teadnud =tead  (PtsPtPs  >teadma !34_V	et	f	\N
114512	teadnud	teadnud =teadnu  (PlN  >teadnu !01_S	et	f	\N
114513	teadnud	"teadnu %tead  )NU_vS  <teadma ;34_V	et	f	\N
114514	teadnud	teadnud =teadnud  (ID  >teadnud !41_A	et	f	\N
114515	teadnud	"teadnud %tead  )NUD_vA  <teadma ;34_V	et	f	\N
114518	unustasid	unustasid =unusta  (IndIpfSg2  >unustama !27_V	et	f	\N
114519	unustasid	unustasid =unusta  (IndIpfPl3  >unustama !27_V	et	f	\N
114524	lektsionidele	?lektsionidele =lektsioni  (PlAll  >lektsioni !16_S	et	f	\N
114525	lektsionidele	?lektsionidele =lektsioni  (PlAll  >lektsion !19_S	et	f	\N
114526	lektsionid	?lektsionid =lektsioni  (PlN  >lektsion !19~02_S	et	f	\N
114527	lektsionid	?lektsionid =lektsioni  (PlN  >lektsioni !16_S	et	f	\N
114254	londonisse	?londonisse =londonisse  (SgG  >londonisne !02_A	et	f	\N
114255	londonisse	?londonisse =londonisse  (PlP  >londoniss !22_S	et	f	\N
114258	külastamiseks	külastamiseks =külastamise  (SgTr  >külastamine !12_S	et	f	\N
114259	külastamiseks	"külastamine %külasta  )MINE_vS  <külastama ;27_V	et	f	\N
114274	meiest	meiest =meie  (SgEl  >meie !16_S	et	f	\N
114275	meiest	meiest =meie  (PlEl  >meig !22_S	et	f	\N
114278	meiest	meiest =meies  (SgP  >meiene !10_A	et	f	\N
114279	meiest	"meiene %meie  )NE_aA  <meie ;16_S	et	f	\N
114282	pilvine	pilvine =pilvine  (SgN  >pilvine !10_A	et	f	\N
114283	pilvine	"pilvine %pilvi  )NE_aA  <pilv ;22_S	et	f	\N
114301	kümne	kümne =kümne  (SgG  >kümmend !05_N	et	f	\N
114302	kümne	kümne =kümne  (SgG  >kümme !05_N	et	f	\N
114311	jalutavad	jalutavad =jaluta  (IndPrPl3  >jalutama !27_V	et	f	\N
114312	jalutavad	jalutavad =jalutava  (PlN  >jalutav !02_A	et	f	\N
114313	jalutavad	"jalutav %jaluta  )V_vA  <jalutama ;27_V	et	f	\N
114317	stokholmis	?stokholmis =stokholmi  (SgIn  >stokholmi !01_S	et	f	\N
114318	stokholmis	?stokholmis =stokholmi  (SgIn  >stokholm !22_S	et	f	\N
114319	stokholmis	?stokholmis =stokholmi  (IndIpfSg3  >stokholmima !28_V	et	f	\N
114320	stokholmis	?stokholmis =stokholmis  (SgN  >stokholmis !11_S	et	f	\N
114324	tänavad	tänavad =täna  (IndPrPl3  >tänama !27_V	et	f	\N
114325	tänavad	tänavad =tänava  (PlN  >tänav !02_A	et	f	\N
114326	tänavad	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
114327	tänavad	tänavad =tänava  (PlN  >tänav !02_S	et	f	\N
114331	eestlastest	eestlastest =eestlas  (PlEl  >eestlane !12?10_S	et	f	\N
114332	eestlastest	eestlastest =las  (PlEl  >eest+laps !14_S	et	f	\N
114333	eestlastest	eestlastest =laste  (PlEl  >eest+last !22_S	et	f	\N
114341	otse	otse =otse  (ID  >otse !41_D	et	f	\N
114342	otse	otse =otse  (PlP  >ots !22_S	et	f	\N
114351	määleta	?määleta =määle  (SgAb  >määle !06_S	et	f	\N
114352	määleta	?määleta =määle  (IndPrIps_  >määlema !27_V	et	f	\N
114353	määleta	?määleta =määleta  (IndPrPs_  >määletama !27_V	et	f	\N
114354	määleta	?määleta =määleta  (ImpPrSg2  >määletama !27_V	et	f	\N
114364	ahi	ahi =ahi  (SgN  >ahi !24_S	et	f	\N
114365	ahi	ahi =ahi  (IndPrPs_  >ahkima !28_V	et	f	\N
114366	ahi	ahi =ahi  (ImpPrSg2  >ahkima !28_V	et	f	\N
114369	tea	tea =tea  (IndPrPs_  >teadma !34_V	et	f	\N
114370	tea	tea =tea  (ImpPrSg2  >teadma !34_V	et	f	\N
114374	narva	?narva =narva  (SgN  >narva !16_S	et	f	\N
114376	narva	?narva =narva  (SgG  >narva !16_S	et	f	\N
114378	narva	?narva =narva  (IndPrPs_  >narvama !29_V	et	f	\N
114380	narva	?narva =narva  (ImpPrSg2  >narvama !29_V	et	f	\N
114393	okeani	?okeani =okea  (SgTer  >okea !26_S	et	f	\N
114394	okeani	?okeani =okeani  (SgN  >okeani !16_S	et	f	\N
114395	okeani	?okeani =okeani  (SgG  >okeani !16_S	et	f	\N
114396	okeani	?okeani =okeani  (SgG  >okean !19_S	et	f	\N
114397	okeani	?okeani =okeani  (SgP  >okean !19_S	et	f	\N
114398	okeani	?okeani =okeani  (SgAdt  >okean !19_S	et	f	\N
114399	okeani	?okeani =okeani  (IndPrPs_  >okeanima !28_V	et	f	\N
114400	okeani	?okeani =okeani  (ImpPrSg2  >okeanima !28_V	et	f	\N
114407	avamise	avamise =avamise  (SgG  >avamine !12_S	et	f	\N
114408	avamise	"avamine %ava  )MINE_vS  <avama ;27_V	et	f	\N
114411	nimitus	?nimitus =nimitu  (SgIn  >nimitu !01_AS	et	f	\N
114412	nimitus	?nimitus =nimitu  (IndIpfSg3  >nimituma !27_V	et	f	\N
114413	nimitus	?nimitus =nimitus  (SgN  >nimitus !11_S	et	f	\N
114418	sõbranna	sõbranna =sõbranna  (SgN  >sõbranna !16_S	et	f	\N
114419	sõbranna	sõbranna =sõbranna  (SgG  >sõbranna !16_S	et	f	\N
114423	esimine	?esimine =esimine  (SgN  >esimine !12_S	et	f	\N
114424	esimine	?esimine =esimine  (PlP  >esimin !19_S	et	f	\N
114433	luuletused	luuletused =luuletuse  (PlN  >luuletus !11_S	et	f	\N
114434	luuletused	"luuletus %luuleta  )US_vS  <luuletama ;27_V	et	f	\N
114435	luuletused	"luuletus %luule  )TUS2_aS  <luule ;06_S	et	f	\N
114438	lugejaste	lugejaste =lugejas  (PlG  >lugejane !12_A	et	f	\N
114439	lugejaste	"lugejane %lugeja  )NE_aA  <lugeja ;01_S	et	f	\N
114440	lugesid	lugesid =luge  (IndIpfSg2  >lugema !28_V	et	f	\N
114441	lugesid	lugesid =luge  (IndIpfPl3  >lugema !28_V	et	f	\N
114451	viimaks	viimaks =vii  (SupTr  >viima !38_V	et	f	\N
114453	viimaks	viimaks =viimaks  (ID  >viimaks !41_D	et	f	\N
114472	jalle	?jalle =jalle  (SgN  >jalle !06_S	et	f	\N
114473	jalle	?jalle =jalle  (PlP  >jall !22_S	et	f	\N
114475	jalle	?jalle =jalle  (IndPrPs_  >jallema !30_V	et	f	\N
114476	jalle	?jalle =jalle  (ImpPrSg2  >jallema !30_V	et	f	\N
114479	õhku	õhku =õhku  (SgP  >õhk !22_S	et	f	\N
114480	õhku	õhku =õhku  (SgAdt  >õhk !22_S	et	f	\N
114481	õhku	õhku =õhku  (IndPrPs_  >õhkuma !27_V	et	f	\N
114482	õhku	õhku =õhku  (ImpPrSg2  >õhkuma !27_V	et	f	\N
114494	nalja	nalja =nalja  (SgG  >nali !24_S	et	f	\N
114495	nalja	nalja =nalja  (SgP  >nali !24_S	et	f	\N
114496	nalja	nalja =nalja  (SgAdt  >nali !24_S	et	f	\N
114497	lektsion	?lektsion =lektsion  (SgN  >lektsion !19~02_S	et	f	\N
114503	ärkanud	?ärkanud =ärkanu  (PlN  >ärkanu !01_S	et	f	\N
114405	sündinud	"sündinud %sündi  )NUD_vA  <sündima ;28_V	et	f	\N
114406	xxx	### xxx	et	f	\N
114409	ürituse	ürituse =ürituse  (SgG  >üritus !11_S	et	f	\N
114410	ürituse	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
114414	eperekonnanimi	?eperekonnanimi =eperekonnanimi  (SgG  >eperekonnanim !02_A	et	f	\N
114425	tutvusime	tutvusime =tutvu  (IndIpfPl1  >tutvuma !27_V	et	f	\N
114426	tutvusime	tutvusime =ime  (SgN  >tutvus+ime !16_S	et	f	\N
114427	tutvusime	tutvusime =ime  (SgG  >tutvus+ime !16_S	et	f	\N
114448	proosast	proosast =proosa  (SgEl  >proosa !16_S	et	f	\N
114449	proosast	proosast =proosas  (SgP  >proosane !10_A	et	f	\N
114450	proosast	"proosane %proosa  )NE_aA  <proosa ;16_S	et	f	\N
114462	esinemine	esinemine =esinemine  (SgN  >esinemine !12_S	et	f	\N
114463	esinemine	"esinemine %esine  )MINE_vS  <esinema ;27_V	et	f	\N
114470	esinemiseks	esinemiseks =esinemise  (SgTr  >esinemine !12_S	et	f	\N
114471	esinemiseks	"esinemine %esine  )MINE_vS  <esinema ;27_V	et	f	\N
114490	teadmised	teadmised =teadmise  (PlN  >teadmine !12?10_S	et	f	\N
114492	teadmised	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
114516	tahaksid	tahaksid =taha  (KndPrSg2  >tahtma !34_V	et	f	\N
114517	tahaksid	tahaksid =taha  (KndPrPl3  >tahtma !34_V	et	f	\N
114532	lektsionil	?lektsionil =lektsioni  (SgAd  >lektsion !19~02_S	et	f	\N
114533	lektsionil	?lektsionil =lektsioni  (SgAd  >lektsioni !16_S	et	f	\N
114534	lektsionil	?lektsionil =lektsionil  (SgN  >lektsionil !02_S	et	f	\N
114539	lühike	lühike =lühike  (SgN  >lühike !12_A	et	f	\N
114540	lühike	"lühike %lühi  )KE_dS  <lüht ;22_S	et	f	\N
114553	õppejõud	õppejõud =jõu  (PlN  >õppe+jõud !22_S	et	f	\N
114554	õppejõud	õppejõud =jõud  (SgN  >õppe+jõud !22_S	et	f	\N
114569	puhkusel	puhkusel =puhkuse  (SgAd  >puhkus !11~09_S	et	f	\N
114570	puhkusel	puhkusel =use  (PlAd  >puhk+usk !22_S	et	f	\N
114571	korratusega	korratusega =korratuse  (SgKom  >korratus !11_S	et	f	\N
114572	korratusega	"korratus %korra  )TUS1_aS  <kordama ;29_V	et	f	\N
114573	korratusega	"korratus %korra  )TUS2_aS  <kord ;22_S	et	f	\N
114576	vaatanud	?vaatanud =vaatanu  (PlN  >vaatanu !01_S	et	f	\N
114577	vaatanud	?vaatanud =vaatanu  (IndPrSg2  >vaatanuma !27_V	et	f	\N
114578	vaatanud	?vaatanud =vaatanud  (ID  >vaatanud !41_A	et	f	\N
114583	internetis	?internetis =internetis  (SgN  >internetis !09_S	et	f	\N
114585	internetis	?internetis =neti  (SgIn  >inter+neti !16_S	et	f	\N
114586	internetis	?internetis =neti  (SgIn  >inter+nett !22_AS	et	f	\N
114587	internetis	?internetis =netis  (SgN  >inter+netis !09_S	et	f	\N
114597	teiele	?teiele =teie  (SgAll  >teie !06_S	et	f	\N
114598	teiele	?teiele =teiele  (IndPrPs_  >teielema !27_V	et	f	\N
114599	teiele	?teiele =teiele  (ImpPrSg2  >teielema !27_V	et	f	\N
114650	õpetajaid	õpetajaid =õpetaja  (PlP  >õpetaja !01_S	et	f	\N
114651	õpetajaid	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
114657	meeleolu	meeleolu =olu  (SgN  >meele+olu !17_S	et	f	\N
114658	meeleolu	meeleolu =olu  (SgG  >meele+olu !17_S	et	f	\N
114659	meeleolu	meeleolu =olu  (SgP  >meele+olu !17_S	et	f	\N
114660	tegelisin	?tegelisin =tegelisin  (SgN  >tegelisin !19_S	et	f	\N
114672	seadusest	seadusest =seaduse  (SgEl  >seadus !11~09_S	et	f	\N
114673	seadusest	seadusest =seaduses  (SgP  >seadusene !12_A	et	f	\N
114675	seadusest	"seadusene %seaduse  )NE_aA  <seadus ;09_S	et	f	\N
114678	seadusest	"seadusene %seaduse  )NE_aA  <seadus ;11_S	et	f	\N
114682	jutustus	jutustus =jutustus  (SgN  >jutustus !11_S	et	f	\N
114683	jutustus	"jutustus %jutusta  )US_vS  <jutustama ;27_V	et	f	\N
114694	aulas	aulas =aula  (SgIn  >aula !01_S	et	f	\N
114695	aulas	aulas =aula  (SgIn  >aula !16_S	et	f	\N
114699	kehaline	kehaline =kehaline  (SgN  >kehaline !12_A	et	f	\N
114701	kehaline	"kehaline %keha  )LINE_aA  <keha ;17_S	et	f	\N
114704	ühindasin	?ühindasin =ühinda  (IndIpfSg1  >ühindama !27_V	et	f	\N
114705	ühindasin	?ühindasin =ühindasin  (SgN  >ühindasin !19_S	et	f	\N
114729	keskajane	keskajane =ajane  (SgN  >kesk+ajane !10_A	et	f	\N
114730	keskajane	"kesk+ajane %aja  )NE_aA  <kesk+aeg ;22_S	et	f	\N
114731	käisid	käisid =käi  (IndIpfSg2  >käima !38_V	et	f	\N
114732	käisid	käisid =käi  (IndIpfPl3  >käima !38_V	et	f	\N
114750	hiid	hiid =hii  (PlN  >hii !26_S	et	f	\N
114751	hiid	hiid =hii  (SgP  >hii !26_S	et	f	\N
114752	hiid	hiid =hiid  (SgN  >hiid !22_S	et	f	\N
114753	piisike	?piisike =piisike  (SgN  >piisike !12_S	et	f	\N
114760	loodusega	loodusega =looduse  (SgKom  >loodus !11~09_S	et	f	\N
114761	loodusega	"loodus %loo  )TUS1_aS  <looma ;38_V	et	f	\N
114763	disco	?disco =disco  (SgN  >disco !16_S	et	f	\N
114765	disco	?disco =disco  (SgG  >disco !16_S	et	f	\N
114771	loomi	loomi =loomi  (SgG  >loom !22_S	et	f	\N
114772	loomi	loomi =loomi  (SgP  >loom !22_S	et	f	\N
114773	loomi	loomi =loomi  (SgAdt  >loom !22_S	et	f	\N
114774	loomi	loomi =loomi  (PlP  >loom !22_S	et	f	\N
114789	ukrainas	### ukrainas	et	f	\N
114844	liga	liga =liga  (SgN  >liga !17_S	et	f	\N
114845	liga	liga =liga  (SgG  >liga !17_S	et	f	\N
114846	liga	liga =liga  (SgP  >liga !17_S	et	f	\N
114504	ärkanud	?ärkanud =ärkanu  (IndPrSg2  >ärkanuma !27_V	et	f	\N
114505	ärkanud	?ärkanud =ärkanud  (ID  >ärkanud !41_A	et	f	\N
114551	gruppis	?gruppis =gruppi  (IndIpfSg3  >gruppima !28_V	et	f	\N
114552	gruppis	?gruppis =gruppis  (ID  >gruppis !41_DA	et	f	\N
114555	lubanud	lubanud =luba  (PtsPtPs  >lubama !27_V	et	f	\N
114556	lubanud	lubanud =lubanu  (PlN  >lubanu !01_S	et	f	\N
114557	lubanud	"lubanu %luba  )NU_vS  <lubama ;27_V	et	f	\N
114558	lubanud	lubanud =lubanud  (ID  >lubanud !41_A	et	f	\N
114559	lubanud	"lubanud %luba  )NUD_vA  <lubama ;27_V	et	f	\N
114560	informatikas	?informatikas =informatika  (SgIn  >informatika !01_S	et	f	\N
114561	informatikas	?informatikas =informatika  (SgIn  >informatikas !02_A	et	f	\N
114562	informatikas	?informatikas =informatikas  (SgN  >informatikas !02_A	et	f	\N
114611	ida	ida =ida  (SgN  >ida !17_S	et	f	\N
114612	ida	ida =ida  (SgG  >ida !17_S	et	f	\N
114613	ida	ida =ida  (SgP  >ida !17_S	et	f	\N
114621	paides	paides =pai  (PlIn  >pai !26_AS	et	f	\N
114622	paides	paides =paide  (SgIn  >paide !01_H	et	f	\N
114627	ttüs	### ttüs	et	f	\N
114661	õpilastega	õpilastega =õpilas  (PlKom  >õpilane !12_S	et	f	\N
114662	õpilastega	õpilastega =las  (PlKom  >õpi+laps !14_S	et	f	\N
114665	jutustasid	jutustasid =jutusta  (IndIpfSg2  >jutustama !27_V	et	f	\N
114666	jutustasid	jutustasid =jutusta  (IndIpfPl3  >jutustama !27_V	et	f	\N
114669	õppekavast	õppekavast =kava  (SgEl  >õppe+kava !17_S	et	f	\N
114670	õppekavast	õppekavast =kavas  (SgP  >õppe+kavane !10_A	et	f	\N
114671	õppekavast	"õppe+kavane %kava  )NE_aA  <õppe+kava ;17_S	et	f	\N
114680	nendele	nendele =nen  (PlAll  >see !00_P	et	f	\N
114681	nendele	nendele =nen  (PlAll  >tema !00_P	et	f	\N
114697	magasin	magasin =maga  (IndIpfSg1  >magama !27_V	et	f	\N
114698	magasin	magasin =magasin  (SgN  >magasin !19_S	et	f	\N
114715	edinburgis	?edinburgis =edinburgi  (SgIn  >edinburk !22_S	et	f	\N
114716	edinburgis	?edinburgis =edinburgi  (IndIpfSg3  >edinburgima !28_V	et	f	\N
114717	edinburgis	?edinburgis =edinburgis  (SgN  >edinburgis !09_S	et	f	\N
114720	nõrkal	?nõrkal =nõrka  (SgAd  >nõrka !16_S	et	f	\N
114721	nõrkal	?nõrkal =nõrkal  (SgN  >nõrkal !02_S	et	f	\N
114733	inemesi	?inemesi =inemesi  (PlP  >inemene !12_A	et	f	\N
114734	riietusi	riietusi =riietusi  (PlP  >riietus !11_S	et	f	\N
114736	riietusi	"riietus %riieta  )US_vS  <riietama ;27_V	et	f	\N
114786	pubs	?pubs =pubs  (SgN  >pubs !22_S	et	f	\N
114814	lilleid	?lilleid =lillei  (PlN  >lillei !26_S	et	f	\N
114815	lilleid	?lilleid =lillei  (SgP  >lillei !26_S	et	f	\N
114816	lilleid	?lilleid =lilleid  (SgN  >lilleid !22_S	et	f	\N
114817	lilleid	?lilleid =eid  (SgN  >lill+eid !22_S	et	f	\N
114822	ukraina	?ukraina =ukrai  (SgEs  >ukrai !26_S	et	f	\N
114826	melelahutusikohti	?melelahutusikohti =melelahutusikohti  (ID  >melelahutusikohti !41_D	et	f	\N
114827	melelahutusikohti	?melelahutusikohti =melelahutusikohti  (SgP  >melelahutusikoht !22_S	et	f	\N
114828	melelahutusikohti	?melelahutusikohti =melelahutusikohti  (SgAdt  >melelahutusikoht !22_S	et	f	\N
114837	peol	peol =peo  (SgAd  >pidu !18_S	et	f	\N
114840	peol	peol =peo  (SgAd  >peo !26_S	et	f	\N
114873	ekskursiooni	ekskursiooni =ekskursiooni  (SgG  >ekskursioon !22_S	et	f	\N
114874	ekskursiooni	ekskursiooni =ekskursiooni  (SgP  >ekskursioon !22_S	et	f	\N
114875	ekskursiooni	ekskursiooni =ekskursiooni  (SgAdt  >ekskursioon !22_S	et	f	\N
114876	juhi	juhi =juhi  (SgG  >juht !22_S	et	f	\N
114877	juhi	juhi =juhi  (IndPrPs_  >juhtima !28_V	et	f	\N
114879	juhi	juhi =juhi  (ImpPrSg2  >juhtima !28_V	et	f	\N
114891	jalgratad	?jalgratad =jalgrata  (IndPrSg2  >jalgratama !27_V	et	f	\N
114892	jalgratad	?jalgratad =rata  (PlN  >jalg+rata !16_S	et	f	\N
114957	teegisid	?teegisid =teegi  (PlP  >teegi !16_S	et	f	\N
114958	teegisid	?teegisid =teegi  (PlP  >teeg !22_S	et	f	\N
114959	teegisid	?teegisid =teegi  (IndIpfSg2  >teegima !28_V	et	f	\N
114960	teegisid	?teegisid =teegi  (IndIpfPl3  >teegima !28_V	et	f	\N
114961	teegisid	?teegisid =gisi  (PlN  >tee+gisi !17_S	et	f	\N
114975	suvenirid	?suvenirid =suveniri  (PlN  >suvenir !19_S	et	f	\N
114977	suvenirid	?suvenirid =niri  (PlN  >suve+niri !17_S	et	f	\N
114988	kaheksa	kaheksa =kaheksa  (SgN  >kaheksa !01_N	et	f	\N
114989	kaheksa	kaheksa =kaheksa  (SgG  >kaheksa !01_N	et	f	\N
114993	närviline	närviline =närviline  (SgN  >närviline !12_A	et	f	\N
114994	närviline	"närviline %närvi  )LINE_aA  <närv ;22_S	et	f	\N
114998	jope	jope =jope  (SgN  >jope !16_S	et	f	\N
114999	jope	jope =jope  (SgG  >jope !16_S	et	f	\N
115006	teisipäeviti	?teisipäeviti =teisipäevi  (IndIpfIps  >teisipäevima !28_V	et	f	\N
115007	teisipäeviti	?teisipäeviti =teisipäeviti  (ID  >teisipäeviti !41_D	et	f	\N
115008	teisipäeviti	?teisipäeviti =teisipäeviti  (SgG  >teisipäevitt !22_S	et	f	\N
115009	teisipäeviti	?teisipäeviti =teisipäeviti  (IndPrPs_  >teisipäevittima !28_V	et	f	\N
115010	teisipäeviti	?teisipäeviti =teisipäeviti  (ImpPrSg2  >teisipäevittima !28_V	et	f	\N
115011	teisipäeviti	?teisipäeviti =iti  (SgN  >teisi+päev+iti !16_S	et	f	\N
115012	teisipäeviti	?teisipäeviti =iti  (SgG  >teisi+päev+iti !16_S	et	f	\N
115013	teisipäeviti	?teisipäeviti =iti  (SgG  >teisi+päev+itt !22_S	et	f	\N
114528	lektsionid	?lektsionid =lektsioni  (IndPrSg2  >lektsionima !28_V	et	f	\N
114529	matanalüs	### matanalüs	et	f	\N
114547	vara	vara =vara  (ID  >vara !41_D	et	f	\N
114548	vara	vara =vara  (SgN  >vara !17_S	et	f	\N
114549	vara	vara =vara  (SgG  >vara !17_S	et	f	\N
114550	vara	vara =vara  (SgP  >vara !17_S	et	f	\N
114563	oska	oska =oska  (IndPrPs_  >oskama !29_V	et	f	\N
114564	oska	oska =oska  (ImpPrSg2  >oskama !29_V	et	f	\N
114565	saada	saada =saa  (Inf  >saama !37_V	et	f	\N
114566	saada	saada =saa  (IndPrIps_  >saama !37_V	et	f	\N
114567	saada	saada =saada  (IndPrPs_  >saatma !34_V	et	f	\N
114568	saada	saada =saada  (ImpPrSg2  >saatma !34_V	et	f	\N
114574	kuhugi	kuhugi =kuhugi  (ID  >kuhugi !41_D	et	f	\N
114575	kuhugi	kuhugi =kuhu  (ID^  >kuhu !41_D	et	f	\N
114588	harjutanud	harjutanud =harjuta  (PtsPtPs  >harjutama !27_V	et	f	\N
114589	harjutanud	harjutanud =harjutanu  (PlN  >harjutanu !01_S	et	f	\N
114590	harjutanud	"harjutanu %harjuta  )NU_vS  <harjutama ;27_V	et	f	\N
114591	harjutanud	harjutanud =harjutanud  (ID  >harjutanud !41_A	et	f	\N
114592	harjutanud	"harjutanud %harjuta  )NUD_vA  <harjutama ;27_V	et	f	\N
114593	harjutanud	harjutanud =tanu  (PlN  >harju+tanu !17_S	et	f	\N
114594	diskole	?diskole =disko  (SgAll  >disko !16_S	et	f	\N
114595	diskole	?diskole =diskole  (IndPrPs_  >diskolema !27_V	et	f	\N
114596	diskole	?diskole =diskole  (ImpPrSg2  >diskolema !27_V	et	f	\N
114618	veedasin	?veedasin =veeda  (IndIpfSg1  >veedama !29_V	et	f	\N
114619	veedasin	?veedasin =veedasin  (SgN  >veedasin !19_S	et	f	\N
114620	veedasin	?veedasin =dasin  (SgN  >vee+dasin !02_S	et	f	\N
114630	armastavad	armastavad =armasta  (IndPrPl3  >armastama !27_V	et	f	\N
114631	armastavad	armastavad =armastava  (PlN  >armastav !02_A	et	f	\N
114632	armastavad	"armastav %armasta  )V_vA  <armastama ;27_V	et	f	\N
114648	ülikoolis	ülikoolis =kooli  (SgIn  >üli+kool !22_S	et	f	\N
114649	ülikoolis	ülikoolis =kooli  (PlIn  >üli+kool !22_S	et	f	\N
114652	ruumeid	?ruumeid =ruume  (PlP  >ruume !06_S	et	f	\N
114653	ruumeid	?ruumeid =ruumei  (PlN  >ruumei !26_S	et	f	\N
114654	ruumeid	?ruumeid =ruumei  (SgP  >ruumei !26_S	et	f	\N
114655	ruumeid	?ruumeid =ruumeid  (SgN  >ruumeid !22_S	et	f	\N
114656	ruumeid	?ruumeid =eid  (SgN  >ruum+eid !22_S	et	f	\N
114691	missugu	missugu =sugu  (SgN  >mis+sugu !18_S	et	f	\N
114692	missugu	missugu =sugu  (SgP  >mis+sugu !18_S	et	f	\N
114706	kaugelt	kaugelt =kauge  (SgAbl  >kauge !01_A	et	f	\N
114707	kaugelt	kaugelt =kaugelt  (ID  >kaugelt !41_D	et	f	\N
114709	kaugelt	"kaugelt %kauge  )LT_mD  <kauge ;01_A	et	f	\N
114712	kultuuriga	kultuuriga =kultuuri  (SgKom  >kultuur !22_S	et	f	\N
114713	kultuuriga	kultuuriga =iga  (SgN  >kultuur+iga !18_S	et	f	\N
114714	kultuuriga	kultuuriga =iga  (SgP  >kultuur+iga !18_S	et	f	\N
114758	teema	teema =teema  (SgN  >teema !16_S	et	f	\N
114759	teema	teema =teema  (SgG  >teema !16_S	et	f	\N
114762	country	### country	et	f	\N
114764	puhkavad	puhkavad =puhka  (IndPrPl3  >puhkama !29_V	et	f	\N
114766	puhkavad	puhkavad =puhkava  (PlN  >puhkav !02_A	et	f	\N
114767	puhkavad	"puhkav %puhka  )V_vA  <puhkama ;29_V	et	f	\N
114768	puhkavad	puhkavad =ava  (PlN  >puhk+ava !17_S	et	f	\N
114780	lõvi	lõvi =lõvi  (SgN  >lõvi !17_S	et	f	\N
114781	lõvi	lõvi =lõvi  (SgN  >lõvi !20_S	et	f	\N
114782	lõvi	lõvi =lõvi  (SgG  >lõvi !17_S	et	f	\N
114783	lõvi	lõvi =lõvi  (SgP  >lõvi !17_S	et	f	\N
114787	elmisel	?elmisel =elmise  (SgAd  >elmine !10_A	et	f	\N
114788	elmisel	?elmisel =elmisel  (SgN  >elmisel !19_S	et	f	\N
114834	harkovi	?harkovi =harkovi  (ID  >harkovi !41_D	et	f	\N
114836	harkovi	?harkovi =harkovi  (SgG  >harkov !02_A	et	f	\N
114838	harkovi	?harkovi =ovi  (SgN  >hark+ovi !17_S	et	f	\N
114841	harkovi	?harkovi =ovi  (SgG  >hark+ovi !17_S	et	f	\N
114843	harkovi	?harkovi =ovi  (SgP  >hark+ovi !17_S	et	f	\N
114862	leidnud	leidnud =leid  (PtsPtPs  >leidma !34_V	et	f	\N
114863	leidnud	leidnud =leidnu  (PlN  >leidnu !01_S	et	f	\N
114864	leidnud	"leidnu %leid  )NU_vS  <leidma ;34_V	et	f	\N
114865	leidnud	leidnud =leidnud  (ID  >leidnud !41_A	et	f	\N
114866	leidnud	"leidnud %leid  )NUD_vA  <leidma ;34_V	et	f	\N
114878	kuulata	kuulata =kuula  (Inf  >kuulama !29_V	et	f	\N
114880	kuulata	kuulata =kuula  (IndPrIps_  >kuulama !29_V	et	f	\N
114883	kuulata	kuulata =kuulata  (IndPrPs_  >kuulatama !27_V	et	f	\N
114885	kuulata	kuulata =kuulata  (ImpPrSg2  >kuulatama !27_V	et	f	\N
114887	kuulata	kuulata =la  (SgAb  >kuu+la !26_S	et	f	\N
114890	inimised	?inimised =inimise  (PlN  >inimine !12_S	et	f	\N
114921	mõõdunud	?mõõdunud =mõõdu  (PtsPtPs  >mõõduma !27_V	et	f	\N
114924	mõõdunud	?mõõdunud =mõõdunu  (PlN  >mõõdunu !01_S	et	f	\N
114928	mõõdunud	?mõõdunud =mõõdunu  (IndPrSg2  >mõõdunuma !27_V	et	f	\N
114929	mõõdunud	?mõõdunud =mõõdunud  (ID  >mõõdunud !41_A	et	f	\N
114965	remondiks	remondiks =remondi  (SgTr  >remont !22_S	et	f	\N
114966	remondiks	remondiks =remondi  (KndPrPs  >remontima !28_V	et	f	\N
114979	vodka	vodka =vodka  (SgN  >vodka !16_S	et	f	\N
114980	vodka	vodka =vodka  (SgG  >vodka !16_S	et	f	\N
114545	niimodi	?niimodi =modi  (SgG  >nii+modi !17_S	et	f	\N
114546	niimodi	?niimodi =modi  (SgP  >nii+modi !17_S	et	f	\N
114579	lugenud	lugenud =luge  (PtsPtPs  >lugema !28_V	et	f	\N
114580	lugenud	lugenud =lugenu  (PlN  >lugenu !01_S	et	f	\N
114581	lugenud	"lugenu %luge  )NU_vS  <lugema ;28_V	et	f	\N
114582	lugenud	lugenud =lugenud  (ID  >lugenud !41_A	et	f	\N
114584	lugenud	"lugenud %luge  )NUD_vA  <lugema ;28_V	et	f	\N
114600	meeldi	meeldi =meeldi  (IndPrPs_  >meeldima !27_V	et	f	\N
114601	meeldi	meeldi =meeldi  (ImpPrSg2  >meeldima !27_V	et	f	\N
114605	paremini	paremini =paremi  (SgTer  >parem !02_A	et	f	\N
114606	paremini	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
114607	paremini	paremini =paremini  (ID  >paremini !41_D	et	f	\N
114608	paremini	paremini =ini  (SgN  >parem+ini !17_S	et	f	\N
114609	paremini	paremini =ini  (SgG  >parem+ini !17_S	et	f	\N
114610	paremini	paremini =ini  (SgP  >parem+ini !17_S	et	f	\N
114614	virumaal	virumaal =maa  (SgAd  >viru+maa !26_S	et	f	\N
114615	virumaal	virumaal =maal  (SgN  >viru+maal !22_S	et	f	\N
114628	kultur	?kultur =kultur  (SgN  >kultur !02_S	et	f	\N
114635	meelega	meelega =meele  (SgKom  >meel !13_S	et	f	\N
114636	meelega	meelega =meelega  (ID  >meelega !41_D	et	f	\N
114637	peod	peod =peo  (PlN  >pidu !18_S	et	f	\N
114638	peod	peod =peo  (PlN  >peo !26_S	et	f	\N
114639	peod	peod =peo  (SgP  >peo !26_S	et	f	\N
114640	ööklubi	ööklubi =klubi  (SgN  >öö+klubi !17_S	et	f	\N
114641	ööklubi	ööklubi =klubi  (SgG  >öö+klubi !17_S	et	f	\N
114642	ööklubi	ööklubi =klubi  (SgP  >öö+klubi !17_S	et	f	\N
114643	lõpetuteks	lõpetuteks =lõpetu  (PlTr  >lõpetu !01_A	et	f	\N
114644	lõpetuteks	"lõpetu %lõpe  )TU1_vS  <lõppema ;28_V	et	f	\N
114645	lõpetuteks	"lõpetu %lõpe  )TU1_vS  <lõpma ;35_V	et	f	\N
114646	varem	varem =varem  (ID  >varem !41_D	et	f	\N
114647	varem	varem =varem  (SgN  >varem !02_A	et	f	\N
114667	rõõmus	rõõmus =rõõmu  (SgIn  >rõõm !22_S	et	f	\N
114668	rõõmus	rõõmus =rõõmus  (SgN  >rõõmus !02_A	et	f	\N
114684	suhtlemine	suhtlemine =suhtlemine  (SgN  >suhtlemine !12_S	et	f	\N
114685	suhtlemine	"suhtlemine %suhtle  )MINE_vS  <suhtlema ;30_V	et	f	\N
114693	esindus	esindus =esindus  (SgN  >esindus !11_S	et	f	\N
114696	esindus	"esindus %esinda  )US_vS  <esindama ;27_V	et	f	\N
114700	kasvatuse	kasvatuse =kasvatuse  (SgG  >kasvatus !11_S	et	f	\N
114702	kasvatuse	"kasvatus %kasvata  )US_vS  <kasvatama ;27_V	et	f	\N
114703	kasvatuse	"kasvatus %kasva  )TUS1_aS  <kasvama ;28_V	et	f	\N
114722	tänavatel	tänavatel =tänava  (PlAd  >tänav !02_A	et	f	\N
114723	tänavatel	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
114724	tänavatel	tänavatel =tänava  (PlAd  >tänav !02_S	et	f	\N
114725	tänavatel	tänavatel =ate  (PlAd  >tänav+att !22_S	et	f	\N
114726	tänavatel	tänavatel =vate  (PlAd  >täna+vatt !22_S	et	f	\N
114735	keskajase	keskajase =ajase  (SgG  >kesk+ajane !10_A	et	f	\N
114737	keskajase	"kesk+ajane %aja  )NE_aA  <kesk+aeg ;22_S	et	f	\N
114744	padsed	?padsed =padse  (PlN  >padne !02_A	et	f	\N
114745	padsed	?padsed =padse  (PlN  >padse !06_S	et	f	\N
114746	padsed	?padsed =padse  (IndPrSg2  >padsema !27_V	et	f	\N
114747	seina	seina =seina  (SgG  >sein !23?22_S	et	f	\N
114748	seina	seina =seina  (SgP  >sein !23?22_S	et	f	\N
114749	seina	seina =seina  (SgAdt  >sein !23?22_S	et	f	\N
114769	loomaaias	loomaaias =aia  (SgIn  >looma+aed !22_S	et	f	\N
114770	loomaaias	loomaaias =aia  (SgIn  >looma+ai !22_S	et	f	\N
114784	puhkusse	puhkusse =puhkus  (SgAdt  >puhkus !11_S	et	f	\N
114785	puhkusse	puhkusse =usse  (PlP  >puhk+uss !22_S	et	f	\N
114790	mälestussammaid	?mälestussammaid =mälestussammai  (PlN  >mälestussammai !26_S	et	f	\N
114791	mälestussammaid	?mälestussammaid =mälestussammai  (SgP  >mälestussammai !26_S	et	f	\N
114792	mälestussammaid	?mälestussammaid =sammai  (PlN  >mälestus+sammai !26_S	et	f	\N
114793	mälestussammaid	?mälestussammaid =sammai  (SgP  >mälestus+sammai !26_S	et	f	\N
114794	mälestussammaid	?mälestussammaid =sammaid  (SgN  >mälestus+sammaid !22_S	et	f	\N
114804	erinev	erinev =erine  (PtsPrPs  >erinema !27_V	et	f	\N
114805	erinev	erinev =erinev  (SgN  >erinev !02_A	et	f	\N
114806	erinev	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
114823	harkov	?harkov =harkov  (SgN  >harkov !02_A	et	f	\N
114824	avatakse	avatakse =ava  (IndPrIps  >avama !27_V	et	f	\N
114825	avatakse	avatakse =takse  (PlP  >ava+taks !22_S	et	f	\N
114829	maitsev	maitsev =maits  (PtsPrPs  >maitsma !32_V	et	f	\N
114830	maitsev	maitsev =maitse  (PtsPrPs  >maitsema !28_V	et	f	\N
114831	maitsev	maitsev =maitsev  (SgN  >maitsev !02_A	et	f	\N
114832	maitsev	"maitsev %maits  )V_vA  <maitsma ;32_V	et	f	\N
114833	maitsev	"maitsev %maitse  )V_vA  <maitsema ;28_V	et	f	\N
114858	kaaslastega	kaaslastega =kaaslas  (PlKom  >kaaslane !12?10_S	et	f	\N
114859	kaaslastega	kaaslastega =las  (PlKom  >kaas+laps !14_S	et	f	\N
114867	liiga	liiga =lii  (SgKom  >lii !26_S	et	f	\N
114868	liiga	liiga =liiga  (ID  >liiga !41_D	et	f	\N
114869	liiga	liiga =liiga  (SgN  >liiga !16_S	et	f	\N
114870	liiga	liiga =liiga  (SgG  >liiga !16_S	et	f	\N
114676	reeglidest	?reeglidest =glide  (SgEl  >ree+glide !16_S	et	f	\N
114677	reeglidest	?reeglidest =glides  (SgP  >ree+glides !09_S	et	f	\N
114679	reeglidest	?reeglidest =glides  (SgP  >ree+glidene !10_A	et	f	\N
114686	matemaatika	matemaatika =matemaatika  (SgN  >matemaatika !01_S	et	f	\N
114687	matemaatika	matemaatika =matemaatika  (SgG  >matemaatika !01_S	et	f	\N
114688	õpilastes	õpilastes =õpilas  (PlIn  >õpilane !12_S	et	f	\N
114689	õpilastes	õpilastes =las  (PlIn  >õpi+laps !14_S	et	f	\N
114690	õpilastes	õpilastes =laste  (PlIn  >õpi+last !22_S	et	f	\N
114708	kojust	?kojust =kojus  (SgP  >kojus !09_S	et	f	\N
114710	tutvustamine	tutvustamine =tutvustamine  (SgN  >tutvustamine !12_S	et	f	\N
114711	tutvustamine	"tutvustamine %tutvusta  )MINE_vS  <tutvustama ;27_V	et	f	\N
114718	vaatamisvärsusi	?vaatamisvärsusi =vaatamisvärsusi  (PlP  >vaatamisvärsus !11_S	et	f	\N
114719	vaatamisvärsusi	?vaatamisvärsusi =värsusi  (PlP  >vaatamis+värsus !11_S	et	f	\N
114727	tuntsin	?tuntsin =tuntsi  (IndPrSg1  >tuntsima !28_V	et	f	\N
114728	tuntsin	?tuntsin =tuntsin  (SgN  >tuntsin !02_S	et	f	\N
114738	ümbretsesid	?ümbretsesid =ümbretse  (IndIpfSg2  >ümbretsema !27_V	et	f	\N
114739	ümbretsesid	?ümbretsesid =ümbretse  (IndIpfPl3  >ümbretsema !27_V	et	f	\N
114740	kesklinnas	kesklinnas =linna  (SgIn  >kesk+linn !22_S	et	f	\N
114741	kesklinnas	kesklinnas =linnas  (SgN  >kesk+linnas !09_S	et	f	\N
114742	keskajaline	keskajaline =ajaline  (SgN  >kesk+ajaline !12_A	et	f	\N
114743	keskajaline	"kesk+ajaline %aja  )LINE_aA  <kesk+aeg ;22_S	et	f	\N
114754	unustamutu	?unustamutu =unustamutu  (SgN  >unustamutu !01_A	et	f	\N
114755	unustamutu	?unustamutu =unustamutu  (SgG  >unustamutu !01_A	et	f	\N
114756	unustamutu	?unustamutu =unustamutu  (IndPrPs_  >unustamutuma !27_V	et	f	\N
114757	unustamutu	?unustamutu =unustamutu  (ImpPrSg2  >unustamutuma !27_V	et	f	\N
114775	ahvi	ahvi =ahvi  (SgG  >ahv !22_S	et	f	\N
114776	ahvi	ahvi =ahvi  (SgP  >ahv !22_S	et	f	\N
114777	ahvi	ahvi =ahvi  (SgAdt  >ahv !22_S	et	f	\N
114778	ahvi	ahvi =ahvi  (IndPrPs_  >ahvima !28_V	et	f	\N
114779	ahvi	ahvi =ahvi  (ImpPrSg2  >ahvima !28_V	et	f	\N
114795	head	head =hea  (PlN  >hea !26_AS	et	f	\N
114796	head	head =hea  (SgP  >hea !26_AS	et	f	\N
114797	ekskursionil	?ekskursionil =ekskursioni  (SgAd  >ekskursion !19~02_S	et	f	\N
114798	ekskursionil	?ekskursionil =ekskursioni  (SgAd  >ekskursioni !16_S	et	f	\N
114799	ekskursionil	?ekskursionil =ekskursionil  (SgN  >ekskursionil !02_S	et	f	\N
114800	ekskursionil	?ekskursionil =oni  (SgAd  >eks+kursi+oni !17_S	et	f	\N
114801	ekskursionil	?ekskursionil =kursioni  (SgAd  >eks+kursion !19~02_S	et	f	\N
114802	ekskursionil	?ekskursionil =kursioni  (SgAd  >eks+kursioni !16_S	et	f	\N
114803	ekskursionil	?ekskursionil =kursionil  (SgN  >eks+kursionil !02_S	et	f	\N
114807	värskeid	?värskeid =värske  (PlP  >värske !01_AS	et	f	\N
114808	värskeid	?värskeid =värskei  (PlN  >värskei !26_S	et	f	\N
114809	värskeid	?värskeid =värskei  (SgP  >värskei !26_S	et	f	\N
114810	värskeid	?värskeid =värskeid  (SgN  >värskeid !22_S	et	f	\N
114811	kasvatal	?kasvatal =kasvatal  (SgN  >kasvatal !19_S	et	f	\N
114812	kasvatal	?kasvatal =vata  (SgAd  >kas+vata !16_S	et	f	\N
114813	kasvatal	?kasvatal =vatal  (SgN  >kas+vatal !02_S	et	f	\N
114818	harkovis	?harkovis =harkovi  (SgIn  >harkov !02_A	et	f	\N
114819	harkovis	?harkovis =harkovis  (SgN  >harkovis !11_S	et	f	\N
114820	harkovis	?harkovis =ovi  (SgIn  >hark+ovi !17_S	et	f	\N
114821	harkovis	?harkovis =ovis  (SgN  >hark+ovis !09_S	et	f	\N
114835	sünnipäeva	sünnipäeva =päeva  (SgG  >sünni+päev !22_S	et	f	\N
114839	sünnipäeva	sünnipäeva =päeva  (SgP  >sünni+päev !22_S	et	f	\N
114842	sünnipäeva	sünnipäeva =päeva  (SgAdt  >sünni+päev !22_S	et	f	\N
114850	jurde	?jurde =jurde  (SgN  >jurde !06_S	et	f	\N
114851	jurde	?jurde =jurde  (SgG  >jurre !06_S	et	f	\N
114852	jurde	?jurde =jurde  (PlP  >jurd !22_S	et	f	\N
114853	jurde	?jurde =jurde  (IndPrPs_  >jurdema !27_V	et	f	\N
114854	jurde	?jurde =jurde  (ImpPrSg2  >jurdema !27_V	et	f	\N
114881	ümbes	?ümbes =ümbe  (SgIn  >ümme !06_S	et	f	\N
114882	ümbes	?ümbes =ümbe  (PlIn  >ümp !22_S	et	f	\N
114884	ümbes	?ümbes =ümbe  (IndIpfSg3  >ümbema !27_V	et	f	\N
114886	ümbes	?ümbes =ümbes  (SgN  >ümbes !09_S	et	f	\N
114888	välismaal	välismaal =maa  (SgAd  >välis+maa !26_S	et	f	\N
114889	välismaal	välismaal =maal  (SgN  >välis+maal !22_S	et	f	\N
114908	olulisemad	olulisemad =olulisema  (PlN  >olulisem !02_A	et	f	\N
114909	olulisemad	"olulisem %olu  )LISEM_cA  <olu ;17_S	et	f	\N
114910	olulisemad	"olulisem %olulise  )M_cA  <oluline ;12_A	et	f	\N
114938	kinnosid	?kinnosid =kinno  (PlP  >kinno !16_S	et	f	\N
114939	laevad	laevad =lae  (IndPrPl3  >laadima !28_V	et	f	\N
114940	laevad	laevad =laeva  (PlN  >laev !22_S	et	f	\N
114943	delfinariesil	?delfinariesil =delfinariesi  (SgAd  >delfinariesi !16_S	et	f	\N
114944	delfinariesil	?delfinariesil =delfinariesil  (SgN  >delfinariesil !02_S	et	f	\N
114952	dashka	?dashka =dashka  (SgN  >dashka !01_S	et	f	\N
114954	dashka	?dashka =dashka  (SgG  >dashka !01_S	et	f	\N
114955	dashka	?dashka =dashka  (IndPrPs_  >dashkama !29_V	et	f	\N
114956	dashka	?dashka =dashka  (ImpPrSg2  >dashkama !29_V	et	f	\N
114847	sugulaste	sugulaste =sugulas  (PlG  >sugulane !12_S	et	f	\N
114848	sugulaste	sugulaste =las  (PlG  >sugu+laps !14_S	et	f	\N
114849	sugulaste	sugulaste =laste  (PlP  >sugu+last !22_S	et	f	\N
114855	klassi	klassi =klassi  (SgG  >klass !22_S	et	f	\N
114856	klassi	klassi =klassi  (SgP  >klass !22_S	et	f	\N
114857	klassi	klassi =klassi  (SgAdt  >klass !22_S	et	f	\N
114860	saaaremaal	?saaaremaal =saaaremaa  (SgAd  >saaaremaa !26_S	et	f	\N
114861	saaaremaal	?saaaremaal =saaaremaal  (SgN  >saaaremaal !22_S	et	f	\N
114902	reisimiseks	reisimiseks =reisimise  (SgTr  >reisimine !12_S	et	f	\N
114903	reisimiseks	"reisimine %reisi  )MINE_vS  <reisima ;28_V	et	f	\N
114907	reisik	?reisik =reisik  (SgN  >reisik !02_S	et	f	\N
114915	maksta	maksta =maks  (Inf  >maksma !32_V	et	f	\N
114916	maksta	maksta =maks  (IndPrIps_  >maksma !32_V	et	f	\N
114919	nainud	nainud =nai  (PtsPtPs  >naima !37_V	et	f	\N
114920	nainud	nainud =nainu  (PlN  >nainu !01_S	et	f	\N
114922	nainud	"nainu %nai  )NU_vS  <naima ;37_V	et	f	\N
114925	nainud	nainud =nainud  (ID  >nainud !41_A	et	f	\N
114927	nainud	"nainud %nai  )NUD_vA  <naima ;37_V	et	f	\N
114932	lasteaia	lasteaia =aia  (SgG  >laste+aed !22_S	et	f	\N
114933	lasteaia	lasteaia =aia  (SgG  >laste+ai !22_S	et	f	\N
114934	lasteaia	lasteaia =aia  (SgP  >laste+ai !22_S	et	f	\N
114935	lasteaia	lasteaia =aia  (SgAdt  >laste+ai !22_S	et	f	\N
114936	rajoonis	rajoonis =rajooni  (SgIn  >rajoon !22_S	et	f	\N
114937	rajoonis	rajoonis =rajooni  (IndIpfSg3  >rajoonima !28_V	et	f	\N
114946	mashka	?mashka =mashka  (SgN  >mashka !01_S	et	f	\N
114949	mashka	?mashka =mashka  (SgG  >mashka !01_S	et	f	\N
114951	mashka	?mashka =mashka  (IndPrPs_  >mashkama !29_V	et	f	\N
114953	mashka	?mashka =mashka  (ImpPrSg2  >mashkama !29_V	et	f	\N
114962	fontaanid	?fontaanid =fontaani  (PlN  >fontaani !16_S	et	f	\N
114963	fontaanid	?fontaanid =fontaani  (PlN  >fontaan !22_S	et	f	\N
114964	fontaanid	?fontaanid =fontaani  (IndPrSg2  >fontaanima !28_V	et	f	\N
114974	mängija	mängija =mängija  (SgN  >mängija !01_S	et	f	\N
114976	mängija	"mängija %mängi  )JA_vS  <mängima ;28_V	et	f	\N
114978	mängija	mängija =mängija  (SgG  >mängija !01_S	et	f	\N
114981	moskvasse	?moskvasse =moskvas  (SgAdt  >moskvane !12_A	et	f	\N
114982	moskvasse	?moskvasse =moskvasse  (SgG  >moskvasne !02_A	et	f	\N
114983	moskvasse	?moskvasse =moskvasse  (PlP  >moskvass !22_S	et	f	\N
114995	bussi	bussi =bussi  (SgG  >buss !22_S	et	f	\N
114996	bussi	bussi =bussi  (SgP  >buss !22_S	et	f	\N
114997	bussi	bussi =bussi  (SgAdt  >buss !22_S	et	f	\N
115002	jamind	?jamind =jamind  (SgN  >jamind !02_S	et	f	\N
115035	bussipeatusesse	bussipeatusesse =peatuse  (SgIll  >bussi+peatus !11~09_S	et	f	\N
115036	bussipeatusesse	"bussi+peatus %pea  )TUS2_aS  <bussi+pea ;26_S	et	f	\N
115037	bussipeatusesse	bussipeatusesse =peatuses  (SgAdt  >bussi+peatusene !12_A	et	f	\N
115038	bussipeatusesse	"bussi+peatusene %peatuse  )NE_aA  <bussi+peatus ;09_S	et	f	\N
115039	bussipeatusesse	"bussi+peatusene %peatuse  )NE_aA  <bussi+peatus ;11_S	et	f	\N
115062	külastajaid	külastajaid =külastaja  (PlP  >külastaja !01_S	et	f	\N
115063	külastajaid	"külastaja %külasta  )JA_vS  <külastama ;27_V	et	f	\N
115067	täiskasvanud	täiskasvanud =kasva  (PtsPtPs  >täis+_kasvama !28_V	et	f	\N
115068	täiskasvanud	täiskasvanud =kasvanu  (PlN  >täis+kasvanu !01_S	et	f	\N
115093	kassi	kassi =kassi  (SgG  >kass !22_S	et	f	\N
115094	kassi	kassi =kassi  (SgP  >kass !22_S	et	f	\N
115095	kassi	kassi =kassi  (SgAdt  >kass !22_S	et	f	\N
115113	hambapasta	hambapasta =pasta  (SgN  >hamba+pasta !16_S	et	f	\N
115114	hambapasta	hambapasta =pasta  (SgG  >hamba+pasta !16_S	et	f	\N
115120	asjadbr	?asjadbr =asjadbr  (SgN  >asjadbr !22_S	et	f	\N
115139	pardel	pardel =parde  (PlAd  >part !22_S	et	f	\N
115140	pardel	pardel =pardel  (SgN  >pardel !02_S	et	f	\N
115144	naiteks	?naiteks =naite  (SgTr  >naide !06_S	et	f	\N
115145	naiteks	?naiteks =naite  (KndPrPs  >naitema !27_V	et	f	\N
115176	arvutist	arvutist =arvuti  (SgEl  >arvuti !01_S	et	f	\N
115177	arvutist	arvutist =arvutis  (SgP  >arvutis !11_S	et	f	\N
115178	arvutist	arvutist =uti  (SgEl  >arv+utt !22_S	et	f	\N
115180	arvutist	arvutist =uti  (PlEl  >arv+utt !22_S	et	f	\N
115182	sõprale	?sõprale =sõprale  (IndPrPs_  >sõpralema !27_V	et	f	\N
115184	sõprale	?sõprale =sõprale  (ImpPrSg2  >sõpralema !27_V	et	f	\N
115191	inimsed	?inimsed =inimse  (PlN  >inimne !02_A	et	f	\N
115214	teiseks	teiseks =teise  (SgTr  >teine !12_OP	et	f	\N
115215	teiseks	teiseks =teise  (SgTr  >teise !12_P	et	f	\N
115216	teiseks	teiseks =teiseks  (ID  >teiseks !41_D	et	f	\N
115235	võidu	võidu =võidu  (ID  >võidu !41_DK	et	f	\N
115236	võidu	"võidu %või  )TU1_vS  <võima ;37_V	et	f	\N
115237	võidu	võidu =võidu  (SgN  >võidu !01_S	et	f	\N
115238	võidu	võidu =võidu  (SgG  >võidu !01_S	et	f	\N
115239	võidu	võidu =võidu  (SgG  >võit !22_S	et	f	\N
115240	võidu	võidu =võidu  (IndPrPs_  >võiduma !27_V	et	f	\N
115241	võidu	võidu =võidu  (ImpPrSg2  >võiduma !27_V	et	f	\N
115243	teaduselubr	?teaduselubr =teaduselubr  (SgN  >teaduselubr !22_S	et	f	\N
115244	teaduselubr	?teaduselubr =lubr  (SgN  >teaduse+lubr !22_S	et	f	\N
114871	liiga	liiga =liiga  (SgP  >liig !22_S	et	f	\N
114872	liiga	liiga =liiga  (SgAdt  >liig !22_S	et	f	\N
114893	museumi	?museumi =museumi  (SgN  >museumi !01_S	et	f	\N
114894	museumi	?museumi =museumi  (SgG  >museumi !01_S	et	f	\N
114895	museumi	?museumi =museumi  (SgG  >museum !22_S	et	f	\N
114896	museumi	?museumi =museumi  (SgP  >museum !22_S	et	f	\N
114897	museumi	?museumi =museumi  (SgAdt  >museum !22_S	et	f	\N
114898	museumi	?museumi =museumi  (IndPrPs_  >museumima !28_V	et	f	\N
114899	museumi	?museumi =museumi  (ImpPrSg2  >museumima !28_V	et	f	\N
114900	arvates	arvates =arva  (Ger  >arvama !29_V	et	f	\N
114901	arvates	arvates =ate  (PlIn  >arv+att !22_S	et	f	\N
114904	sobivad	sobivad =sobi  (IndPrPl3  >sobima !27_V	et	f	\N
114905	sobivad	sobivad =sobiva  (PlN  >sobiv !02_A	et	f	\N
114906	sobivad	"sobiv %sobi  )V_vA  <sobima ;27_V	et	f	\N
114911	tööta	tööta =töö  (SgAb  >töö !26_S	et	f	\N
114912	tööta	tööta =tööta  (IndPrPs_  >töötama !27_V	et	f	\N
114913	tööta	tööta =tööta  (ImpPrSg2  >töötama !27_V	et	f	\N
114914	reisimese	?reisimese =reisimese  (SgG  >reisimene !12_A	et	f	\N
114917	reisimese	?reisimese =mese  (SgN  >reisi+mese !16_S	et	f	\N
114918	reisimese	?reisimese =mese  (SgG  >reisi+mese !16_S	et	f	\N
114923	suve	suve =suve  (SgG  >suvi !20_S	et	f	\N
114926	suve	suve =suve  (SgP  >suvi !20_S	et	f	\N
114930	kohtusin	kohtusin =kohtu  (IndIpfSg1  >kohtuma !27_V	et	f	\N
114931	kohtusin	kohtusin =usin  (SgN  >koht+usin !02_A	et	f	\N
114941	pikk	pikk =pikk  (SgN  >pikk !22_S	et	f	\N
114942	pikk	pikk =pikk  (SgN  >pikk !22_AS	et	f	\N
114945	pashka	?pashka =pashka  (SgN  >pashka !01_S	et	f	\N
114947	pashka	?pashka =pashka  (SgG  >pashka !01_S	et	f	\N
114948	pashka	?pashka =pashka  (IndPrPs_  >pashkama !29_V	et	f	\N
114950	pashka	?pashka =pashka  (ImpPrSg2  >pashkama !29_V	et	f	\N
114984	naad	?naad =naad  (SgN  >naad !22_S	et	f	\N
115000	loengusse	loengusse =loengu  (SgIll  >loeng !02_S	et	f	\N
115001	loengusse	loengusse =usse  (PlP  >loeng+uss !22_S	et	f	\N
115017	puhkemist	puhkemist =puhkemis  (SgP  >puhkemine !12_S	et	f	\N
115018	puhkemist	"puhkemine %puhke  )MINE_vS  <puhkema ;27_V	et	f	\N
115020	puhkemist	puhkemist =emis  (SgP  >puhk+emis !09_S	et	f	\N
115032	bussiaedega	?bussiaedega =bussiae  (PlKom  >bussiae !26_S	et	f	\N
115055	kolmekümnendal	?kolmekümnendal =kolmekümnenda  (SgAd  >kolmekümnenda !16_S	et	f	\N
115056	kolmekümnendal	?kolmekümnendal =kolmekümnendal  (SgN  >kolmekümnendal !02_S	et	f	\N
115057	kolmekümnendal	?kolmekümnendal =kümnenda  (SgAd  >kolme+kümnenda !01_S	et	f	\N
115058	kolmekümnendal	?kolmekümnendal =ekümnenda  (SgAd  >kolm+ekümnenda !16_S	et	f	\N
115059	kolmekümnendal	?kolmekümnendal =ekümnendal  (SgN  >kolm+ekümnendal !02_S	et	f	\N
115071	esindanud	esindanud =esinda  (PtsPtPs  >esindama !27_V	et	f	\N
115072	esindanud	esindanud =esindanu  (PlN  >esindanu !01_S	et	f	\N
115073	esindanud	"esindanu %esinda  )NU_vS  <esindama ;27_V	et	f	\N
115074	esindanud	esindanud =esindanud  (ID  >esindanud !41_A	et	f	\N
115075	esindanud	"esindanud %esinda  )NUD_vA  <esindama ;27_V	et	f	\N
115101	sinise	?sinise =sinise  (SgG  >sinis !09_S	et	f	\N
115102	sinise	?sinise =sinise  (SgG  >sinine !10_AS	et	f	\N
115103	sinise	?sinise =sinise  (IndPrPs_  >sinisema !27_V	et	f	\N
115104	sinise	?sinise =sinise  (ImpPrSg2  >sinisema !27_V	et	f	\N
115111	alisa	?alisa =alisa  (SgN  >alisa !01_S	et	f	\N
115112	alisa	?alisa =alisa  (SgG  >alisa !01_S	et	f	\N
115115	seeta	?seeta =seet  (Inf  >seetma !34_V	et	f	\N
115116	seeta	?seeta =seeta  (SgN  >seeta !16_S	et	f	\N
115117	seeta	?seeta =seeta  (SgG  >seeta !16_S	et	f	\N
115118	seeta	?seeta =seeta  (IndPrPs_  >seetama !27_V	et	f	\N
115119	seeta	?seeta =seeta  (ImpPrSg2  >seetama !27_V	et	f	\N
115141	kasuta	kasuta =kasu  (SgAb  >kasu !17_S	et	f	\N
115142	kasuta	kasuta =kasuta  (IndPrPs_  >kasutama !27_V	et	f	\N
115143	kasuta	kasuta =kasuta  (ImpPrSg2  >kasutama !27_V	et	f	\N
115157	milleseid	?milleseid =millese  (PlP  >millene !10_A	et	f	\N
115158	milleseid	?milleseid =millesei  (PlN  >millesei !26_S	et	f	\N
115159	milleseid	?milleseid =millesei  (SgP  >millesei !26_S	et	f	\N
115160	milleseid	?milleseid =sei  (PlN  >mille+sei !26_S	et	f	\N
115161	milleseid	?milleseid =sei  (SgP  >mille+sei !26_S	et	f	\N
115162	milleseid	?milleseid =seid  (SgN  >mille+seid !22_S	et	f	\N
115163	compuuterita	?compuuterita =compuuteri  (SgAb  >compuuter !02_S	et	f	\N
115165	compuuterita	?compuuterita =compuuterita  (IndPrPs_  >compuuteritama !27_V	et	f	\N
115166	compuuterita	?compuuterita =compuuterita  (ImpPrSg2  >compuuteritama !27_V	et	f	\N
115183	kokkuleppime	### kokkuleppime	et	f	\N
115185	transporti	transporti =transporti  (SgP  >transport !22_S	et	f	\N
115186	transporti	transporti =transporti  (SgAdt  >transport !22_S	et	f	\N
115199	magavad	magavad =maga  (IndPrPl3  >magama !27_V	et	f	\N
115200	magavad	magavad =magava  (PlN  >magav !02_A	et	f	\N
115201	magavad	"magav %maga  )V_vA  <magama ;27_V	et	f	\N
115210	sõitmine	sõitmine =sõitmine  (SgN  >sõitmine !12?10_S	et	f	\N
115211	sõitmine	"sõitmine %sõit  )MINE_vS  <sõitma ;34_V	et	f	\N
114967	peeterburis	?peeterburis =peeterburi  (SgIn  >peeterbur !19_S	et	f	\N
114968	peeterburis	?peeterburis =peeterburis  (SgN  >peeterburis !09_S	et	f	\N
114969	peeterburis	?peeterburis =erburi  (SgIn  >peet+erburi !01_S	et	f	\N
114970	peeterburis	?peeterburis =erburi  (SgIn  >peet+erbur !02_S	et	f	\N
114971	peeterburis	?peeterburis =erburis  (SgN  >peet+erburis !11_S	et	f	\N
114972	dvd	### dvd	et	f	\N
114973	mp3	### mp3	et	f	\N
114985	ottavad	?ottavad =otta  (IndPrPl3  >ottama !29_V	et	f	\N
114986	ottavad	?ottavad =ottava  (PlN  >ottava !01_S	et	f	\N
114987	ottavad	?ottavad =ottava  (PlN  >ottav !02_A	et	f	\N
115019	ttüsse	?ttüsse =ttüsse  (SgN  >ttüsse !06_S	et	f	\N
115021	ttüsse	?ttüsse =ttüsse  (SgG  >ttüsne !02_A	et	f	\N
115022	ttüsse	?ttüsse =ttüsse  (SgG  >ttüsse !06_S	et	f	\N
115023	ttüsse	?ttüsse =ttüsse  (PlP  >ttüss !22_S	et	f	\N
115024	ttüsse	?ttüsse =ttüsse  (IndPrPs_  >ttüssema !27_V	et	f	\N
115025	ttüsse	?ttüsse =ttüsse  (ImpPrSg2  >ttüssema !27_V	et	f	\N
115026	eestikeel	eestikeel =kee  (SgAd  >eesti+kesi !15_S	et	f	\N
115027	eestikeel	eestikeel =kee  (SgAd  >eesti+kee !26_S	et	f	\N
115028	eestikeel	eestikeel =keel  (SgN  >eesti+keel !13_S	et	f	\N
115029	harjutusi	harjutusi =harjutusi  (PlP  >harjutus !11_S	et	f	\N
115030	harjutusi	"harjutus %harjuta  )US_vS  <harjutama ;27_V	et	f	\N
115031	harjutusi	"harjutus %harju  )TUS1_aS  <harjuma ;27_V	et	f	\N
115091	unised	unised =unise  (PlN  >unine !10_A	et	f	\N
115092	unised	"unine %uni  )NE_aA  <uni ;20_S	et	f	\N
115121	nuga	nuga =nuga  (SgN  >nuga !18_S	et	f	\N
115122	nuga	nuga =nuga  (SgP  >nuga !18_S	et	f	\N
115134	inemene	?inemene =inemene  (SgN  >inemene !12_A	et	f	\N
115135	inemene	?inemene =inemene  (PlP  >inemen !19_S	et	f	\N
115136	teisega	teisega =teise  (SgKom  >teine !12_OP	et	f	\N
115137	teisega	teisega =teise  (SgKom  >teise !12_P	et	f	\N
115138	saabbr	?saabbr =saabbr  (SgN  >saabbr !22_S	et	f	\N
115147	peasu	?peasu =peasu  (SgN  >peasu !16_S	et	f	\N
115148	peasu	?peasu =peasu  (SgG  >peasu !16_S	et	f	\N
115149	peasu	?peasu =peasu  (IndPrPs_  >peasuma !27_V	et	f	\N
115150	peasu	?peasu =peasu  (ImpPrSg2  >peasuma !27_V	et	f	\N
115151	lülitakse	lülitakse =lüli  (IndPrIps  >lülima !27_V	et	f	\N
115152	lülitakse	lülitakse =takse  (PlP  >lüli+taks !22_S	et	f	\N
115153	raadio	raadio =raadio  (SgN  >raadio !01_S	et	f	\N
115154	raadio	raadio =raadio  (SgG  >raadio !01_S	et	f	\N
115164	telefoonita	telefoonita =telefooni  (IndPrIps_  >telefoonima !28_V	et	f	\N
115167	telefoonita	telefoonita =fooni  (SgAb  >tele+foon !22_S	et	f	\N
115168	transportita	?transportita =transporti  (SgAb  >transporti !01_S	et	f	\N
115169	transportita	?transportita =transportita  (IndPrPs_  >transportitama !27_V	et	f	\N
115170	transportita	?transportita =transportita  (ImpPrSg2  >transportitama !27_V	et	f	\N
115171	transportita	?transportita =ita  (SgN  >trans+port+ita !16_S	et	f	\N
115172	transportita	?transportita =ita  (SgG  >trans+port+ita !16_S	et	f	\N
115173	informatsiooni	informatsiooni =informatsiooni  (SgG  >informatsioon !22_S	et	f	\N
115174	informatsiooni	informatsiooni =informatsiooni  (SgP  >informatsioon !22_S	et	f	\N
115175	informatsiooni	informatsiooni =informatsiooni  (SgAdt  >informatsioon !22_S	et	f	\N
115179	telerist	telerist =teleri  (SgEl  >teler !02_S	et	f	\N
115181	telerist	telerist =rist  (SgN  >tele+rist !22_S	et	f	\N
115192	sööma	sööma =söö  (Sup  >sööma !38_V	et	f	\N
115193	sööma	sööma =sööma  (SgG  >sööm !22_S	et	f	\N
115194	sööma	sööma =sööma  (SgP  >sööm !22_S	et	f	\N
115195	sööma	sööma =sööma  (SgAdt  >sööm !22_S	et	f	\N
115202	milleks	milleks =mille  (SgTr  >mis !00_P	et	f	\N
115203	milleks	milleks =milleks  (ID  >milleks !41_D	et	f	\N
115205	esimiseks	?esimiseks =esimise  (SgTr  >esimine !12_S	et	f	\N
115217	elektronika	?elektronika =elektronika  (SgN  >elektronika !01_S	et	f	\N
115219	elektronika	?elektronika =elektronika  (SgG  >elektronika !01_S	et	f	\N
115221	elektronika	?elektronika =elektronika  (SgG  >elektronikas !02_A	et	f	\N
115222	elektronika	?elektronika =ika  (SgN  >elektron+ika !16_S	et	f	\N
115223	elektronika	?elektronika =ika  (SgG  >elektron+ika !16_S	et	f	\N
115224	elektronika	?elektronika =nika  (SgN  >elektro+nika !16_S	et	f	\N
115225	elektronika	?elektronika =nika  (SgG  >elektro+nika !16_S	et	f	\N
115232	majanduslikku	majanduslikku =majanduslikku  (SgP  >majanduslik !25_A	et	f	\N
115233	majanduslikku	majanduslikku =majanduslikku  (SgAdt  >majanduslik !25_A	et	f	\N
115234	süsteemibr	?süsteemibr =süsteemibr  (SgN  >süsteemibr !22_S	et	f	\N
115255	küsimusi	küsimusi =küsimusi  (PlP  >küsimus !11_S	et	f	\N
115256	küsimusi	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
115258	küsimusi	küsimusi =musi  (SgN  >küsi+musi !17_S	et	f	\N
115259	küsimusi	küsimusi =musi  (SgG  >küsi+musi !17_S	et	f	\N
115262	küsimusi	küsimusi =musi  (SgP  >küsi+musi !17_S	et	f	\N
115272	küsimused	küsimused =küsimuse  (PlN  >küsimus !11_S	et	f	\N
115273	küsimused	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
115286	maad	maad =maa  (PlN  >maa !26_S	et	f	\N
115287	maad	maad =maa  (SgP  >maa !26_S	et	f	\N
115292	karju	karju =karju  (PlP  >kari !24_S	et	f	\N
114990	bussipeatuses	bussipeatuses =peatuse  (SgIn  >bussi+peatus !11~09_S	et	f	\N
114991	bussipeatuses	"bussi+peatus %pea  )TUS2_aS  <bussi+pea ;26_S	et	f	\N
114992	kakskümmend	?kakskümmend =kakskümmend  (SgN  >kakskümmend !22_S	et	f	\N
115003	tükkis	tükkis =tükki  (IndIpfSg3  >tükkima !28_V	et	f	\N
115004	tükkis	tükkis =tükkis  (ID  >tükkis !41_A	et	f	\N
115005	tükkis	tükkis =tükkis  (ID  >tükkis !41_DK	et	f	\N
115033	jooksis	jooksis =jooks  (IndIpfSg3  >jooksma !32_V	et	f	\N
115034	jooksis	jooksis =jooksi  (SgIn  >jooks !22_S	et	f	\N
115045	vaevu	vaevu =vaevu  (ID  >vaevu !41_D	et	f	\N
115046	vaevu	vaevu =vaevu  (PlP  >vaev !22_S	et	f	\N
115047	vaevu	vaevu =vaevu  (IndPrPs_  >vaevuma !27_V	et	f	\N
115048	vaevu	vaevu =vaevu  (ImpPrSg2  >vaevuma !27_V	et	f	\N
115049	jõud	jõud =jõu  (PlN  >jõud !22_S	et	f	\N
115050	jõud	jõud =jõud  (SgN  >jõud !22_S	et	f	\N
115060	üritust	üritust =üritus  (SgP  >üritus !11_S	et	f	\N
115061	üritust	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
115064	meeldivad	meeldivad =meeldi  (IndPrPl3  >meeldima !27_V	et	f	\N
115065	meeldivad	meeldivad =meeldiva  (PlN  >meeldiv !02_A	et	f	\N
115066	meeldivad	"meeldiv %meeldi  )V_vA  <meeldima ;27_V	et	f	\N
115069	näituses	näituses =näituse  (SgIn  >näitus !11~09_S	et	f	\N
115070	näituses	näituses =use  (PlIn  >näit+usk !22_S	et	f	\N
115088	mänglevad	mänglevad =mängle  (IndPrPl3  >mänglema !30_V	et	f	\N
115089	mänglevad	mänglevad =mängleva  (PlN  >mänglev !02_A	et	f	\N
115090	mänglevad	"mänglev %mängle  )V_vA  <mänglema ;30_V	et	f	\N
115096	kassipoega	kassipoega =poe  (SgKom  >kassi+pood !22_S	et	f	\N
115097	kassipoega	kassipoega =poega  (SgP  >kassi+poeg !22_S	et	f	\N
115098	kassipoega	kassipoega =poega  (SgAdt  >kassi+poeg !22_S	et	f	\N
115099	valge	valge =valge  (SgN  >valge !01_AS	et	f	\N
115100	valge	valge =valge  (SgG  >valge !01_AS	et	f	\N
115105	nevskaja	?nevskaja =nevskaja  (SgN  >nevskaja !01_S	et	f	\N
115106	nevskaja	?nevskaja =nevskaja  (SgG  >nevskaja !01_S	et	f	\N
115107	nevskaja	?nevskaja =nevskaja  (SgG  >nevskajas !02_A	et	f	\N
115125	süüja	?süüja =süüja  (SgN  >süüja !01_S	et	f	\N
115126	süüja	?süüja =süüja  (SgG  >süüja !01_S	et	f	\N
115127	süüja	?süüja =süüja  (IndPrPs_  >süüjama !29_V	et	f	\N
115128	süüja	?süüja =süüja  (ImpPrSg2  >süüjama !29_V	et	f	\N
115155	kodunetelefon	?kodunetelefon =kodunetelefon  (SgN  >kodunetelefon !19_S	et	f	\N
115156	kodunetelefon	?kodunetelefon =netelefon  (SgN  >kodu+netelefon !19_S	et	f	\N
115187	kinnosse	?kinnosse =kinno  (SgIll  >kinno !16_S	et	f	\N
115188	kinnosse	?kinnosse =kinnos  (SgAdt  >kinnos !11_S	et	f	\N
115189	kinnosse	?kinnosse =kinnosse  (SgG  >kinnosne !02_A	et	f	\N
115190	kinnosse	?kinnosse =kinnosse  (PlP  >kinnoss !22_S	et	f	\N
115196	käivad	käivad =käi  (IndPrPl3  >käima !38_V	et	f	\N
115197	käivad	käivad =käiva  (PlN  >käiv !02_A	et	f	\N
115198	käivad	"käiv %käi  )V_vA  <käima ;38_V	et	f	\N
115204	räägita	räägita =räägi  (SgAb  >rääk !22_S	et	f	\N
115206	räägita	räägita =räägi  (IndPrIps_  >rääkima !28_V	et	f	\N
115218	arvutid	arvutid =arvuti  (PlN  >arvuti !01_S	et	f	\N
115220	arvutid	arvutid =uti  (PlN  >arv+utt !22_S	et	f	\N
115242	ew	### ew	et	f	\N
115245	br	### br	et	f	\N
115248	olulisem	olulisem =olulisem  (SgN  >olulisem !02_A	et	f	\N
115249	olulisem	"olulisem %olu  )LISEM_cA  <olu ;17_S	et	f	\N
115250	olulisem	"olulisem %olulise  )M_cA  <oluline ;12_A	et	f	\N
115251	partei	partei =partei  (SgN  >partei !26_S	et	f	\N
115252	partei	partei =partei  (SgG  >partei !26_S	et	f	\N
115257	stalini	?stalini =stali  (SgTer  >stali !17_S	et	f	\N
115260	stalini	?stalini =stalini  (SgG  >stalin !02_S	et	f	\N
115264	valitseja	valitseja =valitseja  (SgN  >valitseja !01_S	et	f	\N
115265	valitseja	"valitseja %valitse  )JA_vS  <valitsema ;27_V	et	f	\N
115266	valitseja	valitseja =valitseja  (SgG  >valitseja !01_S	et	f	\N
115274	käes	käes =käe  (SgIn  >käsi !15_S	et	f	\N
115275	käes	käes =käes  (ID  >käes !41_DK	et	f	\N
115303	ebaõnnestunud	ebaõnnestunud =õnnestu  (PtsPtPs  >eba+õnnestuma !27_V	et	f	\N
115304	ebaõnnestunud	ebaõnnestunud =õnnestunu  (PlN  >eba+õnnestunu !01_S	et	f	\N
115305	ebaõnnestunud	ebaõnnestunud =õnnestunud  (ID  >eba+õnnestunud !41_A	et	f	\N
115306	tähtsamaid	tähtsamaid =tähtsama  (PlP  >tähtsam !02_A	et	f	\N
115307	tähtsamaid	"tähtsam %tähtsa  )M_cA  <tähtis ;02_A	et	f	\N
115310	vaemistatud	?vaemistatud =vaemista  (PtsPtIps  >vaemistama !27_V	et	f	\N
115311	vaemistatud	?vaemistatud =vaemistatu  (PlN  >vaemistatu !01_S	et	f	\N
115312	vaemistatud	?vaemistatud =vaemistatu  (IndPrSg2  >vaemistatuma !27_V	et	f	\N
115316	vaemistatud	?vaemistatud =vaemistatud  (ID  >vaemistatud !41_A	et	f	\N
115318	vaemistatud	?vaemistatud =tatu  (PlN  >vae+mis+tatu !16_S	et	f	\N
115319	vaemistatud	?vaemistatud =mistatu  (PlN  >vae+mistatu !01_S	et	f	\N
115322	võimu	võimu =võimu  (SgG  >võim !22_S	et	f	\N
115323	võimu	võimu =võimu  (SgP  >võim !22_S	et	f	\N
115324	võimu	võimu =võimu  (SgAdt  >võim !22_S	et	f	\N
115336	kultuuriloo	kultuuriloo =loo  (SgG  >kultuuri+lugu !18_S	et	f	\N
115014	teisipäeviti	?teisipäeviti =päeviti  (SgG  >teisi+päevit !02_S	et	f	\N
115015	teisipäeviti	?teisipäeviti =päeviti  (SgG  >teisi+päevitt !22_S	et	f	\N
115016	teisipäeviti	?teisipäeviti =ipäeviti  (SgG  >teis+ipäevitt !22_S	et	f	\N
115040	jõudnud	jõudnud =jõud  (PtsPtPs  >jõudma !34_V	et	f	\N
115041	jõudnud	jõudnud =jõudnu  (PlN  >jõudnu !01_S	et	f	\N
115042	jõudnud	"jõudnu %jõud  )NU_vS  <jõudma ;34_V	et	f	\N
115043	jõudnud	jõudnud =jõudnud  (ID  >jõudnud !41_A	et	f	\N
115044	jõudnud	"jõudnud %jõud  )NUD_vA  <jõudma ;34_V	et	f	\N
115051	tegevusetus	tegevusetus =tegevusetu  (SgIn  >tegevusetu !01_A	et	f	\N
115052	tegevusetus	"tegevusetu %tegevuse  )TU2_kA  <tegevus ;11_S	et	f	\N
115053	tegevusetus	tegevusetus =tegevusetus  (SgN  >tegevusetus !11?09_S	et	f	\N
115054	tegevusetus	"tegevusetus %tegevuse  )TUS2_aS  <tegevus ;11_S	et	f	\N
115076	kassitõuguid	?kassitõuguid =kassitõugui  (PlN  >kassitõugui !26_S	et	f	\N
115077	kassitõuguid	?kassitõuguid =kassitõugui  (SgP  >kassitõugui !26_S	et	f	\N
115078	kassitõuguid	?kassitõuguid =gui  (PlN  >kassi+tõu+gui !26_S	et	f	\N
115079	kassitõuguid	?kassitõuguid =gui  (SgP  >kassi+tõu+gui !26_S	et	f	\N
115080	kassitõuguid	?kassitõuguid =guid  (SgN  >kassi+tõu+guid !22_S	et	f	\N
115081	kassitõuguid	?kassitõuguid =tõugui  (PlN  >kassi+tõugui !26_S	et	f	\N
115082	kassitõuguid	?kassitõuguid =tõugui  (SgP  >kassi+tõugui !26_S	et	f	\N
115083	kassitõuguid	?kassitõuguid =tõuguid  (SgN  >kassi+tõuguid !22_S	et	f	\N
115084	kassitõuguid	?kassitõuguid =sitõugui  (PlN  >kas+sitõugui !26_S	et	f	\N
115085	kassitõuguid	?kassitõuguid =sitõugui  (SgP  >kas+sitõugui !26_S	et	f	\N
115086	paljapeased	paljapeased =pease  (PlN  >palja+peane !10_S	et	f	\N
115087	paljapeased	"palja+peane %pea  )NE_aA  <palja+pea ;26_S	et	f	\N
115108	maskaradnaja	?maskaradnaja =maskaradnaja  (SgN  >maskaradnaja !01_S	et	f	\N
115109	maskaradnaja	?maskaradnaja =maskaradnaja  (SgG  >maskaradnaja !01_S	et	f	\N
115110	maskaradnaja	?maskaradnaja =maskaradnaja  (SgG  >maskaradnajas !02_A	et	f	\N
115123	lusikas	lusikas =lusika  (SgIn  >lusikas !02_S	et	f	\N
115124	lusikas	lusikas =lusikas  (SgN  >lusikas !02_S	et	f	\N
115129	töötavad	töötavad =tööta  (IndPrPl3  >töötama !27_V	et	f	\N
115130	töötavad	töötavad =töötava  (PlN  >töötav !02_A	et	f	\N
115131	töötavad	"töötav %tööta  )V_vA  <töötama ;27_V	et	f	\N
115132	töötavad	töötavad =tava  (PlN  >töö+tava !17_S	et	f	\N
115133	päevbr	?päevbr =päevbr  (SgN  >päevbr !22_S	et	f	\N
115146	problem	?problem =problem  (SgN  >problem !02_A	et	f	\N
115207	saad	saad =saa  (IndPrSg2  >saama !37_V	et	f	\N
115208	saad	saad =saad  (SgN  >saad !22_S	et	f	\N
115209	informatsion	?informatsion =informatsion  (SgN  >informatsion !19~02_S	et	f	\N
115226	huvitavalt	huvitavalt =huvitava  (SgAbl  >huvitav !02_A	et	f	\N
115227	huvitavalt	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
115228	huvitavalt	huvitavalt =huvitavalt  (ID  >huvitavalt !41_D	et	f	\N
115229	huvitavalt	"huvitavalt %huvita  )VALT_mD  <huvitama ;27_V	et	f	\N
115230	huvitavalt	"huvitavalt %huvitava  )LT_mD  <huvitav ;02_A	et	f	\N
115231	huvitavalt	huvitavalt =tava  (SgAbl  >huvi+tava !17_S	et	f	\N
115261	ideoloogia	ideoloogia =ideoloogia  (SgN  >ideoloogia !01_S	et	f	\N
115263	ideoloogia	ideoloogia =ideoloogia  (SgG  >ideoloogia !01_S	et	f	\N
115276	majanduses	majanduses =majanduse  (SgIn  >majandus !11_S	et	f	\N
115277	majanduses	"majandus %majanda  )US_vS  <majandama ;27_V	et	f	\N
115300	vaevad	vaevad =vae  (IndPrPl3  >vaagima !28_V	et	f	\N
115301	vaevad	vaevad =vaeva  (PlN  >vaev !22_S	et	f	\N
115302	vaevad	vaevad =vaeva  (IndPrSg2  >vaevama !29_V	et	f	\N
115325	pooltbr	?pooltbr =pooltbr  (SgN  >pooltbr !22_S	et	f	\N
115326	tü	### tü	et	f	\N
115335	body	### body	et	f	\N
115351	eestlasteks	eestlasteks =eestlas  (PlTr  >eestlane !12?10_S	et	f	\N
115352	eestlasteks	eestlasteks =las  (PlTr  >eest+laps !14_S	et	f	\N
115353	eestlasteks	eestlasteks =laste  (PlTr  >eest+last !22_S	et	f	\N
115356	intelligentsi	intelligentsi =intelligentsi  (SgG  >intelligents !22_S	et	f	\N
115359	intelligentsi	intelligentsi =intelligentsi  (SgP  >intelligents !22_S	et	f	\N
115360	intelligentsi	intelligentsi =intelligentsi  (SgAdt  >intelligents !22_S	et	f	\N
115387	unistus	unistus =unistus  (SgN  >unistus !11_S	et	f	\N
115388	unistus	"unistus %unista  )US_vS  <unistama ;27_V	et	f	\N
115393	iseseisvusele	iseseisvusele =seisvuse  (SgAll  >ise+seisvus !11~09_S	et	f	\N
115395	iseseisvusele	"ise+seisvus %seisva  )US_aS  <ise+seisev ;02_A	et	f	\N
115426	puudusid	puudusid =puudu  (IndIpfSg2  >puuduma !27_V	et	f	\N
115427	puudusid	puudusid =puudu  (IndIpfPl3  >puuduma !27_V	et	f	\N
115428	inimõigused	inimõigused =õiguse  (PlN  >inim+õigus !11~09_S	et	f	\N
115429	inimõigused	"inim+õigus %õige  )US_aS  <inim+õige ;01_A	et	f	\N
115443	mõju	mõju =mõju  (SgN  >mõju !17_S	et	f	\N
115444	mõju	mõju =mõju  (SgG  >mõju !17_S	et	f	\N
115445	mõju	mõju =mõju  (SgP  >mõju !17_S	et	f	\N
115446	mõju	mõju =mõju  (IndPrPs_  >mõjuma !27_V	et	f	\N
115447	mõju	mõju =mõju  (ImpPrSg2  >mõjuma !27_V	et	f	\N
115468	faktoridest	?faktoridest =faktorides  (SgP  >faktoridene !12_A	et	f	\N
115471	wabariigis	?wabariigis =wabariigi  (SgIn  >wabariigi !16_S	et	f	\N
115212	meile	meile =me  (PlAll  >ma !00_P	et	f	\N
115213	meile	meile =meile  (PlP  >meil !22_S	et	f	\N
115278	kollektivisatsiooni	?kollektivisatsiooni =kollektivisatsioo  (SgTer  >kollektivisatsioo !26_S	et	f	\N
115279	kollektivisatsiooni	?kollektivisatsiooni =kollektivisatsiooni  (SgN  >kollektivisatsiooni !16_S	et	f	\N
115280	kollektivisatsiooni	?kollektivisatsiooni =kollektivisatsiooni  (SgG  >kollektivisatsiooni !16_S	et	f	\N
115281	kollektivisatsiooni	?kollektivisatsiooni =kollektivisatsiooni  (SgG  >kollektivisatsioon !22_S	et	f	\N
115282	kollektivisatsiooni	?kollektivisatsiooni =kollektivisatsiooni  (SgP  >kollektivisatsioon !22_S	et	f	\N
115283	kollektivisatsiooni	?kollektivisatsiooni =kollektivisatsiooni  (SgAdt  >kollektivisatsioon !22_S	et	f	\N
115284	kollektivisatsiooni	?kollektivisatsiooni =kollektivisatsiooni  (IndPrPs_  >kollektivisatsioonima !28_V	et	f	\N
115285	kollektivisatsiooni	?kollektivisatsiooni =kollektivisatsiooni  (ImpPrSg2  >kollektivisatsioonima !28_V	et	f	\N
115290	loome	loome =loo  (IndPrPl1  >looma !38_V	et	f	\N
115291	loome	loome =loome  (SgN  >loome !06_S	et	f	\N
115294	loome	loome =loome  (SgG  >loome !06_S	et	f	\N
115295	loome	loome =loome  (PlP  >loom !22_S	et	f	\N
115313	tekstiilist	tekstiilist =tekstiili  (SgEl  >tekstiil !22_S	et	f	\N
115314	tekstiilist	tekstiilist =tekstiilis  (SgP  >tekstiiline !12?10_A	et	f	\N
115315	tekstiilist	"tekstiiline %tekstiili  )NE_aA  <tekstiil ;22_S	et	f	\N
115327	arenenud	arenenud =arene  (PtsPtPs  >arenema !27_V	et	f	\N
115328	arenenud	arenenud =arenenu  (PlN  >arenenu !01_S	et	f	\N
115329	arenenud	"arenenu %arene  )NU_vS  <arenema ;27_V	et	f	\N
115330	arenenud	arenenud =arenenud  (ID  >arenenud !41_A	et	f	\N
115331	arenenud	"arenenud %arene  )NUD_vA  <arenema ;27_V	et	f	\N
115346	seaduspärasus	seaduspärasus =pärasus  (SgN  >seadus+pärasus !11_S	et	f	\N
115347	seaduspärasus	"seadus+pärasus %pära  )SUS_aS  <seadus+pära ;17_S	et	f	\N
115354	haritud	haritud =hari  (PtsPtIps  >harima !27_V	et	f	\N
115355	haritud	haritud =haritu  (PlN  >haritu !01_AS	et	f	\N
115357	haritud	"haritu %hari  )TU1_vS  <harima ;27_V	et	f	\N
115358	haritud	haritud =haritud  (ID  >haritud !41_A	et	f	\N
115361	haritud	"haritud %hari  )TUD_vA  <harima ;27_V	et	f	\N
115368	arenemiseks	arenemiseks =arenemise  (SgTr  >arenemine !12_S	et	f	\N
115369	arenemiseks	"arenemine %arene  )MINE_vS  <arenema ;27_V	et	f	\N
115374	euroopa	euroopa =euroopa  (ID  >euroopa !41_G	et	f	\N
115375	euroopa	euroopa =euroopa  (SgN  >euroopa !01_H	et	f	\N
115376	euroopa	euroopa =euroopa  (SgG  >euroopa !01_H	et	f	\N
115381	väiksel	väiksel =väikse  (SgAd  >väike !10_A	et	f	\N
115382	väiksel	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
115390	tormi	tormi =tormi  (SgG  >torm !22_SA	et	f	\N
115391	tormi	tormi =tormi  (SgP  >torm !22_SA	et	f	\N
115392	tormi	tormi =tormi  (SgAdt  >torm !22_SA	et	f	\N
115401	tohutut	tohutut =tohutu  (SgP  >tohutu !01_A	et	f	\N
115403	tohutut	"tohutu %tohu  )TU2_kA  <tohu ;17_S	et	f	\N
115405	tohutut	"tohutu %tohu  )TU2_kA  <toht ;22_S	et	f	\N
115411	mõjusid	mõjusid =mõju  (PlP  >mõju !17_S	et	f	\N
115412	mõjusid	mõjusid =mõju  (IndIpfSg2  >mõjuma !27_V	et	f	\N
115413	mõjusid	mõjusid =mõju  (IndIpfPl3  >mõjuma !27_V	et	f	\N
115414	mõjusid	mõjusid =mõjusi  (PlN  >mõjus !02_A	et	f	\N
115481	arenesid	arenesid =arene  (IndIpfSg2  >arenema !27_V	et	f	\N
115484	arenesid	arenesid =arene  (IndIpfPl3  >arenema !27_V	et	f	\N
115492	ew-kirjanduselus	ew-kirjanduselus =elu  (SgIn  >ew-kirjandus+elu !17_S	et	f	\N
115494	ew-kirjanduselus	ew-kirjanduselus =elus  (SgN  >ew-kirjandus+elus !02_A	et	f	\N
115497	tõlkija	tõlkija =tõlkija  (SgN  >tõlkija !01_S	et	f	\N
115498	tõlkija	"tõlkija %tõlki  )JA_vS  <tõlkima ;28_V	et	f	\N
115499	tõlkija	tõlkija =tõlkija  (SgG  >tõlkija !01_S	et	f	\N
115521	loomingubr	?loomingubr =loomingubr  (SgN  >loomingubr !22_S	et	f	\N
115522	loomingubr	?loomingubr =ingubr  (SgN  >loom+ingubr !22_S	et	f	\N
115523	loomingubr	?loomingubr =mingubr  (SgN  >loo+mingubr !22_S	et	f	\N
115530	rahvaomapärasusega	rahvaomapärasusega =pärasuse  (SgKom  >rahva+oma+pärasus !11_S	et	f	\N
115531	rahvaomapärasusega	"rahva+oma+pärasus %pära  )SUS_aS  <rahva+oma+pära ;17_S	et	f	\N
115534	intelligentsusest	intelligentsusest =intelligentsuse  (SgEl  >intelligentsus !11~09_S	et	f	\N
115535	intelligentsusest	"intelligentsus %intelligentse  )US_aS  <intelligentne ;02_A	et	f	\N
115555	lilli	lilli =lilli  (SgG  >lill !22_S	et	f	\N
115557	lilli	lilli =lilli  (SgP  >lill !22_S	et	f	\N
115558	lilli	lilli =lilli  (SgAdt  >lill !22_S	et	f	\N
115559	lilli	lilli =lilli  (PlP  >lill !22_S	et	f	\N
115565	kestnud	kestnud =kest  (PtsPtPs  >kestma !34_V	et	f	\N
115566	kestnud	kestnud =kestnu  (PlN  >kestnu !01_S	et	f	\N
115567	kestnud	"kestnu %kest  )NU_vS  <kestma ;34_V	et	f	\N
115568	kestnud	kestnud =kestnud  (ID  >kestnud !41_A	et	f	\N
115569	kestnud	"kestnud %kest  )NUD_vA  <kestma ;34_V	et	f	\N
115608	sõltus	sõltus =sõltu  (IndIpfSg3  >sõltuma !27_V	et	f	\N
115609	sõltus	sõltus =sõltus  (SgN  >sõltus !11~09_S	et	f	\N
115617	maadele	maadele =maa  (PlAll  >maa !26_S	et	f	\N
115618	maadele	maadele =maade  (PlAll  >maat !22_S	et	f	\N
115626	põhiseadus	põhiseadus =seadu  (SgIn  >põhi+sead !22_S	et	f	\N
115627	põhiseadus	põhiseadus =seadus  (SgN  >põhi+seadus !11~09_S	et	f	\N
115246	teaduselubr	?teaduselubr =elubr  (SgN  >teadus+elubr !22_S	et	f	\N
115247	teaduselubr	?teaduselubr =selubr  (SgN  >teadu+selubr !22_S	et	f	\N
115253	partei	partei =partei  (SgN  >partei !26_S	et	f	\N
115254	partei	partei =partei  (SgG  >partei !26_S	et	f	\N
115267	pidati	?pidati =pidati  (ID  >pidati !41_D	et	f	\N
115268	pidati	?pidati =pidati  (SgG  >pidat !02_S	et	f	\N
115269	pidati	?pidati =pidati  (SgG  >pidatt !22_S	et	f	\N
115270	pidati	?pidati =pidati  (IndPrPs_  >pidattima !28_V	et	f	\N
115271	pidati	?pidati =pidati  (ImpPrSg2  >pidattima !28_V	et	f	\N
115288	talud	talud =talu  (PlN  >talu !17_S	et	f	\N
115289	talud	talud =talu  (IndPrSg2  >taluma !27_V	et	f	\N
115332	opetsialiste	?opetsialiste =opetsialis  (PlG  >opetsialis !09_S	et	f	\N
115333	opetsialiste	?opetsialiste =opetsialis  (PlG  >opetsialine !12_A	et	f	\N
115334	opetsialiste	?opetsialiste =opetsialiste  (PlP  >opetsialist !22_S	et	f	\N
115343	juhus	juhus =juhu  (SgIn  >juht !22_S	et	f	\N
115344	juhus	juhus =juhus  (SgN  >juhus !09_S	et	f	\N
115362	heatasemeline	heatasemeline =tasemeline  (SgN  >hea+tasemeline !12_A	et	f	\N
115365	heatasemeline	"hea+tasemeline %taseme  )LINE_aA  <hea+tase ;04_S	et	f	\N
115366	enese	enese =enese  (SgG  >enese !00_P	et	f	\N
115367	enese	enese =enese  (SgG  >ise !00_P	et	f	\N
115370	avaldamiseks	avaldamiseks =avaldamise  (SgTr  >avaldamine !12_S	et	f	\N
115371	avaldamiseks	"avaldamine %avalda  )MINE_vS  <avaldama ;27_V	et	f	\N
115377	muutused	muutused =muutuse  (PlN  >muutus !11~09_S	et	f	\N
115378	muutused	"muutus %muu  )TUS2_aS  <muu ;26_S	et	f	\N
115379	poliitiilistes	poliitiilistes =iilis  (PlIn  >poliit+iiline !10_A	et	f	\N
115380	poliitiilistes	"poliit+iiline %iili  )NE_aA  <poliit+iil ;22_S	et	f	\N
115398	protsessebr	?protsessebr =protsessebr  (SgN  >protsessebr !22_S	et	f	\N
115399	sõda	sõda =sõda  (SgN  >sõda !18_S	et	f	\N
115400	sõda	sõda =sõda  (SgP  >sõda !18_S	et	f	\N
115424	parandamist	parandamist =parandamis  (SgP  >parandamine !12_S	et	f	\N
115425	parandamist	"parandamine %paranda  )MINE_vS  <parandama ;27_V	et	f	\N
115441	tahtsid	tahtsid =taht  (IndIpfSg2  >tahtma !34_V	et	f	\N
115442	tahtsid	tahtsid =taht  (IndIpfPl3  >tahtma !34_V	et	f	\N
115448	identiteedi	?identiteedi =identiteedi  (SgN  >identiteedi !16_S	et	f	\N
115449	identiteedi	?identiteedi =identiteedi  (SgG  >identiteedi !16_S	et	f	\N
115450	identiteedi	?identiteedi =identiteedi  (SgG  >identiteet !22_S	et	f	\N
115451	identiteedi	?identiteedi =identiteedi  (SgP  >identiteed !22_S	et	f	\N
115452	identiteedi	?identiteedi =identiteedi  (SgAdt  >identiteed !22_S	et	f	\N
115453	identiteedi	?identiteedi =identiteedi  (IndPrPs_  >identiteetima !28_V	et	f	\N
115454	identiteedi	?identiteedi =identiteedi  (ImpPrSg2  >identiteetima !28_V	et	f	\N
115455	võõrast	võõrast =võõra  (SgEl  >võõras !07_AS	et	f	\N
115456	võõrast	võõrast =võõras  (SgP  >võõras !07_AS	et	f	\N
115457	võõrast	võõrast =ast  (SgN  >võõr+ast !22_S	et	f	\N
115479	ajas	ajas =aja  (SgIn  >aeg !22_S	et	f	\N
115480	ajas	ajas =aja  (IndIpfSg3  >ajama !27_V	et	f	\N
115488	tähtsaks	tähtsaks =tähtsa  (SgTr  >tähtis !02_A	et	f	\N
115489	tähtsaks	tähtsaks =saks  (SgN  >täht+saks !23?22_S	et	f	\N
115502	köiteline	köiteline =köiteline  (SgN  >köiteline !12_A	et	f	\N
115503	köiteline	"köiteline %köite  )LINE_aA  <köide ;06_S	et	f	\N
115504	presidentist	?presidentist =presidentis  (SgP  >presidentis !09_S	et	f	\N
115505	presidentist	?presidentist =presidentist  (SgN  >presidentist !22_S	et	f	\N
115506	presidentist	?presidentist =sidenti  (SgEl  >pre+sidenti !01_S	et	f	\N
115507	presidentist	?presidentist =sidentis  (SgP  >pre+sidentis !11_S	et	f	\N
115508	presidentist	?presidentist =sidentist  (SgN  >pre+sidentist !22_S	et	f	\N
115516	juttusi	?juttusi =juttusi  (ID  >juttusi !41_D	et	f	\N
115517	juttusi	?juttusi =juttusi  (PlP  >juttus !11_S	et	f	\N
115518	juttusi	?juttusi =usi  (SgN  >jutt+usi !17_S	et	f	\N
115519	juttusi	?juttusi =usi  (SgG  >jutt+usi !17_S	et	f	\N
115520	juttusi	?juttusi =usi  (SgP  >jutt+usi !17_S	et	f	\N
115524	küsimusele	küsimusele =küsimuse  (SgAll  >küsimus !11_S	et	f	\N
115525	küsimusele	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
115556	promet	?promet =prome  (SgP  >prome !16_S	et	f	\N
115571	nliidust	?nliidust =nliidu  (SgEl  >nliidu !16_S	et	f	\N
115573	nliidust	?nliidust =nliidus  (SgP  >nliidus !11~09_S	et	f	\N
115585	valimised	valimised =valimise  (PlN  >valimine !12_S	et	f	\N
115587	valimised	"valimine %vali  )MINE_vS  <valima ;27_V	et	f	\N
115590	juhtima	juhtima =juhti  (Sup  >juhtima !28_V	et	f	\N
115591	juhtima	juhtima =ima  (SgN  >juht+ima !17_S	et	f	\N
115592	juhtima	juhtima =ima  (SgG  >juht+ima !17_S	et	f	\N
115593	juhtima	juhtima =ima  (SgP  >juht+ima !17_S	et	f	\N
115594	nliit	?nliit =nliit  (SgN  >nliit !22_S	et	f	\N
115597	ellu	ellu =ellu  (SgAdt  >elu !17_S	et	f	\N
115598	ellu	ellu =ellu  (IndPrPs_  >elluma !27_V	et	f	\N
115599	ellu	ellu =ellu  (ImpPrSg2  >elluma !27_V	et	f	\N
115602	kasu	kasu =kasu  (SgN  >kasu !17_S	et	f	\N
115603	kasu	kasu =kasu  (SgG  >kasu !17_S	et	f	\N
115604	kasu	kasu =kasu  (SgP  >kasu !17_S	et	f	\N
115615	kaubavahetuse	kaubavahetuse =vahetuse  (SgG  >kauba+vahetus !11_S	et	f	\N
115293	karju	karju =karju  (IndPrPs_  >karjuma !28_V	et	f	\N
115296	karju	karju =karju  (ImpPrSg2  >karjuma !28_V	et	f	\N
115297	vilju	vilju =vilju  (PlP  >vili !24_S	et	f	\N
115298	vilju	vilju =vilju  (IndPrPs_  >viljuma !27_V	et	f	\N
115299	vilju	vilju =vilju  (ImpPrSg2  >viljuma !27_V	et	f	\N
115308	riigidel	?riigidel =riigi  (PlAd  >riigi !16_S	et	f	\N
115309	riigidel	?riigidel =riigi  (PlAd  >riig !22_S	et	f	\N
115317	raudemasi	?raudemasi =raudemasi  (PlP  >raudemane !12_A	et	f	\N
115320	tahtejõudu	tahtejõudu =jõudu  (SgP  >tahte+jõud !22_S	et	f	\N
115321	tahtejõudu	tahtejõudu =jõudu  (SgAdt  >tahte+jõud !22_S	et	f	\N
115341	kreedo	kreedo =kreedo  (SgN  >kreedo !16_S	et	f	\N
115342	kreedo	kreedo =kreedo  (SgG  >kreedo !16_S	et	f	\N
115345	põhjendabr	?põhjendabr =põhjendabr  (SgN  >põhjendabr !22_S	et	f	\N
115348	ahtammsaare	?ahtammsaare =ahtammsaare  (SgN  >ahtammsaare !16_S	et	f	\N
115349	ahtammsaare	?ahtammsaare =ahtammsaare  (SgG  >ahtammsaare !16_S	et	f	\N
115350	ahtammsaare	?ahtammsaare =ahtammsaare  (PlP  >ahtammsaar !22_S	et	f	\N
115394	eelnevad	eelnevad =eelne  (IndPrPl3  >eelnema !27_V	et	f	\N
115396	eelnevad	eelnevad =eelneva  (PlN  >eelnev !02_A	et	f	\N
115397	eelnevad	"eelnev %eelne  )V_vA  <eelnema ;27_V	et	f	\N
115417	arusaamisele	arusaamisele =saamise  (SgAll  >aru+saamine !12?10_S	et	f	\N
115418	arusaamisele	"aru+saamine %saami  )NE_aA  <aru+saam ;22_S	et	f	\N
115433	vabrikutööliste	vabrikutööliste =iste  (SgN  >vabriku+tööl+iste !05_S	et	f	\N
115434	vabrikutööliste	vabrikutööliste =iste  (SgN  >vabriku+tööl+iste !06_S	et	f	\N
115435	vabrikutööliste	vabrikutööliste =iste  (SgG  >vabriku+tööl+iste !06_S	et	f	\N
115436	vabrikutööliste	vabrikutööliste =iste  (PlP  >vabriku+tööl+ist !22_S	et	f	\N
115437	vabrikutööliste	vabrikutööliste =töölis  (PlG  >vabriku+tööline !12?10_S	et	f	\N
115463	mitteainult	mitteainult =ainu  (SgAbl  >mitte+ainus !07_AS	et	f	\N
115464	mitteainult	mitteainult =ainu  (SgAbl  >mitte+ainu !16_S	et	f	\N
115465	mitteainult	mitteainult =ainu  (PlAbl  >mitte+ain !22_S	et	f	\N
115466	mitteainult	mitteainult =ainult  (ID  >mitte+ainult !41_D	et	f	\N
115467	mitteainult	"mitte+ainult %ainu  )LT_mD  <mitte+ainus ;07_AS	et	f	\N
115472	õitse	õitse =õitse  (IndPrPs_  >õitsema !28_V	et	f	\N
115473	õitse	õitse =õitse  (IndPrPs_  >õitsma !32_V	et	f	\N
115474	õitse	õitse =õitse  (ImpPrSg2  >õitsema !28_V	et	f	\N
115476	õitse	õitse =õitse  (ImpPrSg2  >õitsma !32_V	et	f	\N
115490	figuriiks	?figuriiks =figuri  (PlTr  >figuri !01_S	et	f	\N
115491	figuriiks	?figuriiks =figuri  (PlTr  >figur !02_S	et	f	\N
115493	figuriiks	?figuriiks =figurii  (SgTr  >figurii !26_S	et	f	\N
115509	köite	köite =köi  (PlG  >köis !14_S	et	f	\N
115510	köite	köite =köite  (SgG  >köide !06_S	et	f	\N
115526	kuulete	kuulete =kuule  (PlG  >kuule !06_S	et	f	\N
115527	kuulete	kuulete =kuule  (IndPrPl2  >kuulma !33_V	et	f	\N
115528	kuulete	kuulete =e  (PlG  >kuul+esi !15_S	et	f	\N
115529	inemeste	?inemeste =inemes  (PlG  >inemene !12_A	et	f	\N
115532	kultuursetest	kultuursetest =kultuurse  (PlEl  >kultuurne !02_A	et	f	\N
115533	kultuursetest	kultuursetest =sete  (PlEl  >kultuur+sett !22_S	et	f	\N
115536	etikeedist	?etikeedist =etikeedi  (SgEl  >etikeedi !16_S	et	f	\N
115537	etikeedist	?etikeedist =etikeedi  (SgEl  >etikeet !22_S	et	f	\N
115538	etikeedist	?etikeedist =etikeedis  (SgP  >etikeedis !09_S	et	f	\N
115613	tuleks	tuleks =tule  (SgTr  >tuli !20_S	et	f	\N
115614	tuleks	tuleks =tule  (KndPrPs  >tulema !36_V	et	f	\N
115625	l	### l	et	f	\N
115651	maadel	maadel =maa  (PlAd  >maa !26_S	et	f	\N
115652	maadel	maadel =maade  (PlAd  >maat !22_S	et	f	\N
115669	tegevus	tegevus =tegevus  (SgN  >tegevus !11_S	et	f	\N
115670	tegevus	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
115671	tegevus	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
115684	keskpaiku	keskpaiku =keskpaiku  (ID  >kesk+paiku !41_D	et	f	\N
115685	keskpaiku	keskpaiku =paiku  (PlP  >kesk+paik !22_S	et	f	\N
115698	vajasid	vajasid =vaja  (PlP  >vaja !17_S	et	f	\N
115699	vajasid	vajasid =vaja  (IndIpfSg2  >vajama !27_V	et	f	\N
115700	vajasid	vajasid =vaja  (IndIpfPl3  >vajama !27_V	et	f	\N
115704	lunastust	lunastust =lunastus  (SgP  >lunastus !11_S	et	f	\N
115705	lunastust	"lunastus %lunasta  )US_vS  <lunastama ;27_V	et	f	\N
115713	ristiusku	ristiusku =usku  (SgP  >risti+usk !22_S	et	f	\N
115714	ristiusku	ristiusku =usku  (SgAdt  >risti+usk !22_S	et	f	\N
115721	alistamine	alistamine =alistamine  (SgN  >alistamine !12_S	et	f	\N
115722	alistamine	"alistamine %alista  )MINE_vS  <alistama ;27_V	et	f	\N
115744	kreeka-rooma	kreeka-rooma =rooma  (ID  >kreeka-rooma !41_G	et	f	\N
115745	kreeka-rooma	kreeka-rooma =rooma  (SgG  >kreeka-room !22_S	et	f	\N
115746	kreeka-rooma	kreeka-rooma =rooma  (SgP  >kreeka-room !22_S	et	f	\N
115747	kreeka-rooma	kreeka-rooma =rooma  (SgAdt  >kreeka-room !22_S	et	f	\N
115748	kreeka-rooma	kreeka-rooma =rooma  (IndPrPs_  >kreeka-roomama !29_V	et	f	\N
115749	kreeka-rooma	kreeka-rooma =rooma  (ImpPrSg2  >kreeka-roomama !29_V	et	f	\N
115753	killustatus	killustatus =killustatu  (SgIn  >killustatu !01_S	et	f	\N
115754	killustatus	"killustatu %killusta  )TU1_vS  <killustama ;27_V	et	f	\N
115337	kultuuriloo	kultuuriloo =loo  (SgG  >kultuuri+loog !22_S	et	f	\N
115338	kultuuriloo	kultuuriloo =loo  (SgG  >kultuuri+lood !22_S	et	f	\N
115339	loominguline	loominguline =loominguline  (SgN  >loominguline !12_A	et	f	\N
115340	loominguline	"loominguline %loomingu  )LINE_aA  <looming ;02_S	et	f	\N
115363	teadus	teadus =teadu  (SgIn  >tead !22_S	et	f	\N
115364	teadus	teadus =teadus  (SgN  >teadus !11~09_S	et	f	\N
115372	mozeditorbogusnodetrue	?mozeditorbogusnodetrue =mozeditorbogusnodetrue  (SgN  >mozeditorbogusnodetrue !01_S	et	f	\N
115373	mozeditorbogusnodetrue	?mozeditorbogusnodetrue =mozeditorbogusnodetrue  (SgG  >mozeditorbogusnodetrue !01_S	et	f	\N
115383	õigus	õigus =õigus  (SgN  >õigus !11~09_S	et	f	\N
115384	õigus	"õigus %õige  )US_aS  <õige ;01_A	et	f	\N
115385	tsiviliseerimisse	tsiviliseerimisse =tsiviliseerimis  (SgAdt  >tsiviliseerimine !12_S	et	f	\N
115386	tsiviliseerimisse	"tsiviliseerimine %tsiviliseeri  )MINE_vS  <tsiviliseerima ;28_V	et	f	\N
115389	wabariik	?wabariik =wabariik  (SgN  >wabariik !22_S	et	f	\N
115402	kahju	kahju =kahju  (SgN  >kahju !16~17_S	et	f	\N
115404	kahju	kahju =kahju  (SgG  >kahju !16~17_S	et	f	\N
115406	kahju	kahju =kahju  (SgG  >kahi !24_S	et	f	\N
115407	kahju	kahju =kahju  (SgP  >kahju !17_S	et	f	\N
115408	kahju	kahju =kahju  (SgP  >kahi !24_S	et	f	\N
115409	kahju	kahju =kahju  (SgAdt  >kahi !24_S	et	f	\N
115410	kahju	kahju =kahju  (PlP  >kahi !24_S	et	f	\N
115415	enesekindlusele	enesekindlusele =kindluse  (SgAll  >enese+kindlus !11~09_S	et	f	\N
115416	enesekindlusele	"enese+kindlus %kindla  )US_aS  <enese+kindel ;02_A	et	f	\N
115419	muuta	muuta =muu  (SgAb  >muu !26_S	et	f	\N
115420	muuta	muuta =muu  (SgAb  >muu !26_P	et	f	\N
115421	muuta	muuta =muut  (Inf  >muutma !34_V	et	f	\N
115422	majanduse	majanduse =majanduse  (SgG  >majandus !11_S	et	f	\N
115423	majanduse	"majandus %majanda  )US_vS  <majandama ;27_V	et	f	\N
115430	erinevused	erinevused =erinevuse  (PlN  >erinevus !11?09_S	et	f	\N
115431	erinevused	"erinevus %erine  )VUS_aS  <erinema ;27_V	et	f	\N
115432	erinevused	"erinevus %erineva  )US_aS  <erinev ;02_A	et	f	\N
115438	tugevad	tugevad =tuge  (IndPrPl3  >tugema !27_V	et	f	\N
115439	tugevad	tugevad =tugeva  (PlN  >tugev !02_A	et	f	\N
115440	tugevad	"tugev %tuge  )V_vA  <tugema ;27_V	et	f	\N
115458	jõudu	jõudu =jõudu  (ID  >jõudu !41_I	et	f	\N
115459	jõudu	jõudu =jõudu  (SgP  >jõud !22_S	et	f	\N
115460	jõudu	jõudu =jõudu  (SgAdt  >jõud !22_S	et	f	\N
115461	jõudu	jõudu =jõudu  (IndPrPs_  >jõuduma !27_V	et	f	\N
115462	jõudu	jõudu =jõudu  (ImpPrSg2  >jõuduma !27_V	et	f	\N
115469	iseseisvuminebr	?iseseisvuminebr =iseseisvuminebr  (SgN  >iseseisvuminebr !22_S	et	f	\N
115470	iseseisvuminebr	?iseseisvuminebr =seisvuminebr  (SgN  >ise+seisvuminebr !22_S	et	f	\N
115539	uhke	uhke =uhke  (SgN  >uhke !01_A	et	f	\N
115540	uhke	uhke =uhke  (SgG  >uhke !01_A	et	f	\N
115541	uhke	uhke =uhke  (SgG  >uhe !06_S	et	f	\N
115542	uhke	uhke =uhke  (PlP  >uhk !22_S	et	f	\N
115546	laulufestivaalidest	?laulufestivaalidest =laulufestivaali  (PlEl  >laulufestivaali !16_S	et	f	\N
115547	laulufestivaalidest	?laulufestivaalidest =laulufestivaali  (PlEl  >laulufestivaal !22_S	et	f	\N
115548	laulufestivaalidest	?laulufestivaalidest =laulufestivaalides  (SgP  >laulufestivaalidene !12_A	et	f	\N
115549	laulufestivaalidest	?laulufestivaalidest =festivaali  (PlEl  >laulu+festivaali !16_S	et	f	\N
115550	laulufestivaalidest	?laulufestivaalidest =festivaali  (PlEl  >laulu+festivaal !22_S	et	f	\N
115551	laulufestivaalidest	?laulufestivaalidest =festivaalides  (SgP  >laulu+festivaalidene !12_A	et	f	\N
115552	laulufestivaalidest	?laulufestivaalidest =lufestivaali  (PlEl  >lau+lufestivaali !16_S	et	f	\N
115553	laulufestivaalidest	?laulufestivaalidest =lufestivaali  (PlEl  >lau+lufestivaal !22_S	et	f	\N
115554	laulufestivaalidest	?laulufestivaalidest =lufestivaalides  (SgP  >lau+lufestivaalidene !12_A	et	f	\N
115562	tihedalt	tihedalt =tiheda  (SgAbl  >tihe !02_A	et	f	\N
115563	tihedalt	tihedalt =tihedalt  (ID  >tihedalt !41_D	et	f	\N
115564	tihedalt	"tihedalt %tiheda  )LT_mD  <tihe ;02_A	et	f	\N
115577	peaks	peaks =pea  (KndPrPs  >pida !40_V	et	f	\N
115578	peaks	peaks =pea  (SgTr  >pea !26_S	et	f	\N
115579	peaks	peaks =pea  (KndPrPs  >pidama !28_V	et	f	\N
115583	ülemnõukogu	ülemnõukogu =kogu  (SgN  >ülem+nõu+kogu !17_S	et	f	\N
115584	ülemnõukogu	ülemnõukogu =kogu  (SgG  >ülem+nõu+kogu !17_S	et	f	\N
115586	ülemnõukogu	ülemnõukogu =kogu  (SgP  >ülem+nõu+kogu !17_S	et	f	\N
115588	valitsust	valitsust =valitsus  (SgP  >valitsus !11_S	et	f	\N
115589	valitsust	"valitsus %valitse  )US_vS  <valitsema ;27_V	et	f	\N
115595	iseseisvust	iseseisvust =seisvus  (SgP  >ise+seisvus !11~09_S	et	f	\N
115596	iseseisvust	"ise+seisvus %seisva  )US_aS  <ise+seisev ;02_A	et	f	\N
115605	majandusele	majandusele =majanduse  (SgAll  >majandus !11_S	et	f	\N
115606	majandusele	"majandus %majanda  )US_vS  <majandama ;27_V	et	f	\N
115607	majandus	majandus =majandus  (SgN  >majandus !11_S	et	f	\N
115610	majandus	"majandus %majanda  )US_vS  <majandama ;27_V	et	f	\N
115646	valitsus	valitsus =valitsus  (SgN  >valitsus !11_S	et	f	\N
115647	valitsus	"valitsus %valitse  )US_vS  <valitsema ;27_V	et	f	\N
115648	sedaprotsessi	sedaprotsessi =protsessi  (SgG  >seda+protsess !22_S	et	f	\N
115475	wabariigis	?wabariigis =wabariigi  (SgIn  >wabariik !22_S	et	f	\N
115477	wabariigis	?wabariigis =wabariigi  (IndIpfSg3  >wabariigima !28_V	et	f	\N
115478	wabariigis	?wabariigis =wabariigis  (SgN  >wabariigis !09_S	et	f	\N
115482	keel	keel =kee  (SgAd  >kesi !15_S	et	f	\N
115483	keel	keel =kee  (SgAd  >kee !26_S	et	f	\N
115485	keel	keel =keel  (SgN  >keel !13_S	et	f	\N
115486	hannsen	?hannsen =hannse  (IndPrSg1  >hannsema !27_V	et	f	\N
115487	hannsen	?hannsen =hannsen  (SgN  >hannsen !02_S	et	f	\N
115495	kultuurielus	kultuurielus =elu  (SgIn  >kultuuri+elu !17_S	et	f	\N
115496	kultuurielus	kultuurielus =elus  (SgN  >kultuuri+elus !02_A	et	f	\N
115500	3-me	-me =me  (PlG  >-ma !00_P	et	f	\N
115501	3-me	-me =me  (PlN  >-ma !00_P	et	f	\N
115511	muinasjuttusi	?muinasjuttusi =muinasjuttusi  (PlP  >muinasjuttus !11_S	et	f	\N
115512	muinasjuttusi	?muinasjuttusi =usi  (SgN  >muinas+jutt+usi !17_S	et	f	\N
115513	muinasjuttusi	?muinasjuttusi =usi  (SgG  >muinas+jutt+usi !17_S	et	f	\N
115514	muinasjuttusi	?muinasjuttusi =usi  (SgP  >muinas+jutt+usi !17_S	et	f	\N
115515	muinasjuttusi	?muinasjuttusi =juttusi  (PlP  >muinas+juttus !11_S	et	f	\N
115543	tantsu	tantsu =tantsu  (SgG  >tants !22_S	et	f	\N
115544	tantsu	tantsu =tantsu  (SgP  >tants !22_S	et	f	\N
115545	tantsu	tantsu =tantsu  (SgAdt  >tants !22_S	et	f	\N
115560	taasiseseisvunud	taasiseseisvunud =seisvu  (PtsPtPs  >taas+ise+seisvuma !27_V	et	f	\N
115561	taasiseseisvunud	taasiseseisvunud =seisvunu  (PlN  >taas+ise+seisvunu !01_S	et	f	\N
115570	sõltunud	sõltunud =sõltu  (PtsPtPs  >sõltuma !27_V	et	f	\N
115572	sõltunud	sõltunud =sõltunu  (PlN  >sõltunu !01_S	et	f	\N
115574	sõltunud	"sõltunu %sõltu  )NU_vS  <sõltuma ;27_V	et	f	\N
115575	sõltunud	sõltunud =sõltunud  (ID  >sõltunud !41_A	et	f	\N
115576	sõltunud	"sõltunud %sõltu  )NUD_vA  <sõltuma ;27_V	et	f	\N
115580	kongressi	kongressi =kongressi  (SgG  >kongress !22_S	et	f	\N
115581	kongressi	kongressi =kongressi  (SgP  >kongress !22_S	et	f	\N
115582	kongressi	kongressi =kongressi  (SgAdt  >kongress !22_S	et	f	\N
115600	idee	idee =idee  (SgN  >idee !26_S	et	f	\N
115601	idee	idee =idee  (SgG  >idee !26_S	et	f	\N
115611	liidust	liidust =liidu  (SgEl  >liit !22_S	et	f	\N
115612	liidust	liidust =liidus  (SgP  >liidus !09_S	et	f	\N
115619	seisukohast	seisukohast =koha  (SgEl  >seisu+koha !17_S	et	f	\N
115620	seisukohast	seisukohast =koha  (SgEl  >seisu+koht !22_S	et	f	\N
115621	seisukohast	seisukohast =kohas  (SgP  >seisu+kohane !10_A	et	f	\N
115622	seisukohast	"seisu+kohane %koha  )NE_aA  <seisu+koha ;17_S	et	f	\N
115624	seisukohast	"seisu+kohane %koha  )NE_aA  <seisu+koht ;22_S	et	f	\N
115628	saksa	saksa =saksa  (ID  >saksa !41_G	et	f	\N
115629	saksa	saksa =saksa  (SgG  >saks !23?22_S	et	f	\N
115630	saksa	saksa =saksa  (SgP  >saks !23?22_S	et	f	\N
115631	saksa	saksa =saksa  (SgAdt  >saks !23?22_S	et	f	\N
115644	vabanemisega	vabanemisega =vabanemise  (SgKom  >vabanemine !12_S	et	f	\N
115645	vabanemisega	"vabanemine %vabane  )MINE_vS  <vabanema ;27_V	et	f	\N
115653	hakkasid	hakkasid =hakka  (IndIpfSg2  >hakkama !29_V	et	f	\N
115654	hakkasid	hakkasid =hakka  (IndIpfPl3  >hakkama !29_V	et	f	\N
115657	iseseisvuse	iseseisvuse =seisvuse  (SgG  >ise+seisvus !11~09_S	et	f	\N
115658	iseseisvuse	"ise+seisvus %seisva  )US_aS  <ise+seisev ;02_A	et	f	\N
115659	laulis	laulis =laul  (IndIpfSg3  >laulma !33_V	et	f	\N
115660	laulis	laulis =lauli  (SgIn  >laul !22_S	et	f	\N
115661	tundsid	tundsid =tund  (IndIpfSg2  >tundma !34_V	et	f	\N
115662	tundsid	tundsid =tund  (IndIpfPl3  >tundma !34_V	et	f	\N
115672	selgelt	selgelt =selge  (SgAbl  >selge !01_A	et	f	\N
115673	selgelt	selgelt =selgelt  (ID  >selgelt !41_D	et	f	\N
115674	selgelt	"selgelt %selge  )LT_mD  <selge ;01_A	et	f	\N
115679	sõdimine	sõdimine =sõdimine  (SgN  >sõdimine !12_S	et	f	\N
115680	sõdimine	"sõdimine %sõdi  )MINE_vS  <sõdima ;27_V	et	f	\N
115716	linna-	linna- =linna  (SgG  >linn !22_S	et	f	\N
115717	linna-	linna- =linna  (SgP  >linn !22_S	et	f	\N
115718	linna-	linna- =linna  (SgAdt  >linn !22_S	et	f	\N
115723	saarlastega	saarlastega =saarlas  (PlKom  >saarlane !12?10_S	et	f	\N
115724	saarlastega	saarlastega =las  (PlKom  >saar+laps !14_S	et	f	\N
115733	elusalt	elusalt =elusa  (SgAbl  >elus !02_A	et	f	\N
115735	elusalt	elusalt =elusalt  (ID  >elusalt !41_D	et	f	\N
115736	elusalt	"elusalt %elusa  )LT_mD  <elus ;02_A	et	f	\N
115737	elusalt	elusalt =alt  (SgN  >elus+alt !22_S	et	f	\N
115743	peipsil	?peipsil =peipsi  (SgAd  >peips !22_S	et	f	\N
115750	alast	alast =ala  (SgEl  >ala !17_S	et	f	\N
115751	alast	alast =alas  (SgP  >alane !10_AS	et	f	\N
115752	alast	"alane %ala  )NE_aA  <ala ;17_S	et	f	\N
115759	feodaalriigid	?feodaalriigid =feodaalriigi  (PlN  >feodaalriigi !16_S	et	f	\N
115760	feodaalriigid	?feodaalriigid =feodaalriigi  (PlN  >feodaalriik !22_S	et	f	\N
115761	feodaalriigid	?feodaalriigid =feodaalriigi  (IndPrSg2  >feodaalriikima !28_V	et	f	\N
115765	taanile	?taanile =taani  (SgAll  >taani !16_S	et	f	\N
115766	taanile	?taanile =taani  (SgAll  >taan !22_S	et	f	\N
115767	taanile	?taanile =taanile  (IndPrPs_  >taanilema !27_V	et	f	\N
115768	taanile	?taanile =taanile  (ImpPrSg2  >taanilema !27_V	et	f	\N
115616	kaubavahetuse	"kauba+vahetus %vahe  )TUS2_aS  <kauba+vahe ;16_S	et	f	\N
115623	presidentiks	?presidentiks =sidenti  (SgTr  >pre+sidenti !01_S	et	f	\N
115632	tõeliseks	tõeliseks =tõelise  (SgTr  >tõeline !12?10_A	et	f	\N
115633	tõeliseks	"tõeline %tõe  )LINE_aA  <tõsi ;15_S	et	f	\N
115634	tõeliseks	"tõeline %tõe  )LINE_aA  <tõde ;18_S	et	f	\N
115638	käigus	käigus =käigu  (SgIn  >käik !22_S	et	f	\N
115640	käigus	käigus =käigus  (ID  >käigus !41_K	et	f	\N
115686	kohaselt	kohaselt =kohase  (SgAbl  >kohane !10_A	et	f	\N
115687	kohaselt	"kohane %koha  )NE_aA  <koha ;17_S	et	f	\N
115688	kohaselt	"kohane %koha  )NE_aA  <koht ;22_S	et	f	\N
115689	kohaselt	kohaselt =kohaselt  (ID  >kohaselt !41_D	et	f	\N
115690	kohaselt	"kohaselt %koha  )SELT_mD  <koha ;17_S	et	f	\N
115691	kohaselt	"kohaselt %koha  )SELT_mD  <koht ;22_S	et	f	\N
115692	kohaselt	"kohaselt %kohase  )LT_mD  <kohane ;10_A	et	f	\N
115701	pääsemiseks	pääsemiseks =pääsemise  (SgTr  >pääsemine !12_S	et	f	\N
115702	pääsemiseks	"pääsemine %pääse  )MINE_vS  <pääsema ;28_V	et	f	\N
115703	pääsemiseks	pääsemiseks =emise  (SgTr  >pääs+emis !09_S	et	f	\N
115711	rüüstades	?rüüstades =stade  (SgIn  >rüü+stade !16_S	et	f	\N
115712	rüüstades	?rüüstades =stades  (SgN  >rüü+stades !09_S	et	f	\N
115719	saaremaa	saaremaa =maa  (SgN  >saare+maa !26_S	et	f	\N
115720	saaremaa	saaremaa =maa  (SgG  >saare+maa !26_S	et	f	\N
115757	piirkonnaks	piirkonnaks =piirkonna  (SgTr  >piirkond !22_S	et	f	\N
115758	piirkonnaks	piirkonnaks =konna  (SgTr  >piir+konn !22_S	et	f	\N
115774	jäävad	jäävad =jää  (IndPrPl3  >jääma !37_V	et	f	\N
115775	jäävad	jäävad =jääva  (PlN  >jääv !02_A	et	f	\N
115776	jäävad	"jääv %jää  )V_vA  <jääma ;37_V	et	f	\N
115819	pakkusid	pakkusid =pakku  (PlP  >pakk !22_S	et	f	\N
115821	pakkusid	pakkusid =pakku  (IndIpfSg2  >pakkuma !28_V	et	f	\N
115822	pakkusid	pakkusid =pakku  (IndIpfPl3  >pakkuma !28_V	et	f	\N
115828	materjaalne	?materjaalne =materjaalne  (SgN  >materjaalne !02_A	et	f	\N
115829	materjaalne	?materjaalne =materjaalne  (PlP  >materjaaln !22_S	et	f	\N
115834	makse	makse =makse  (SgN  >makse !06_S	et	f	\N
115835	makse	makse =makse  (SgG  >makse !06_S	et	f	\N
115836	makse	makse =makse  (PlP  >maks !22_S	et	f	\N
115854	kett	kett =ke  (SgP  >kesi !15_S	et	f	\N
115855	kett	kett =kett  (SgN  >kett !22_S	et	f	\N
115868	maailmale	maailmale =ale  (SgN  >maa+ilm+ale !16_S	et	f	\N
115869	maailmale	maailmale =ale  (SgG  >maa+ilm+ale !16_S	et	f	\N
115870	maailmale	maailmale =ilma  (SgAll  >maa+ilm !22_S	et	f	\N
115873	nimetused	nimetused =nimetuse  (PlN  >nimetus !11_S	et	f	\N
115874	nimetused	"nimetus %nimeta  )US_vS  <nimetama ;27_V	et	f	\N
115875	nimetused	"nimetus %nime  )TUS2_aS  <nimi ;20_S	et	f	\N
115881	keskkooli	keskkooli =kooli  (SgG  >kesk+kool !22_S	et	f	\N
115882	keskkooli	keskkooli =kooli  (SgP  >kesk+kool !22_S	et	f	\N
115883	keskkooli	keskkooli =kooli  (SgAdt  >kesk+kool !22_S	et	f	\N
115884	keskkooli	keskkooli =kooli  (PlP  >kesk+kool !22_S	et	f	\N
115890	usuteadus	usuteadus =teadu  (SgIn  >usu+tead !22_S	et	f	\N
115891	usuteadus	usuteadus =teadus  (SgN  >usu+teadus !11~09_S	et	f	\N
115892	süsteemist	süsteemist =süsteemi  (SgEl  >süsteem !22_S	et	f	\N
115893	süsteemist	süsteemist =süsteemis  (SgP  >süsteemine !10_A	et	f	\N
115894	süsteemist	"süsteemine %süsteemi  )NE_aA  <süsteem ;22_S	et	f	\N
115932	regionaalkeelt	regionaalkeelt =kee  (SgAbl  >regionaal+kesi !15_S	et	f	\N
115933	regionaalkeelt	regionaalkeelt =kee  (SgAbl  >regionaal+kee !26_S	et	f	\N
115934	regionaalkeelt	regionaalkeelt =keel  (SgP  >regionaal+keel !13_S	et	f	\N
115948	setu	setu =setu  (ID  >setu !41_G	et	f	\N
115949	setu	setu =setu  (SgN  >setu !05_P	et	f	\N
115950	setu	setu =setu  (SgN  >setu !16_S	et	f	\N
115951	setu	setu =setu  (SgG  >setu !16_S	et	f	\N
115958	arvo	?arvo =arvo  (SgN  >arvo !16_S	et	f	\N
115959	arvo	?arvo =arvo  (SgG  >arvo !16_S	et	f	\N
115972	kirjaniketele	?kirjaniketele =kirjanikete  (PlAll  >kirjanikett !22_S	et	f	\N
115973	kirjaniketele	?kirjaniketele =kirjaniketele  (IndPrPs_  >kirjaniketelema !36_V	et	f	\N
115974	kirjaniketele	?kirjaniketele =kirjaniketele  (ImpPrSg2  >kirjaniketelema !36_V	et	f	\N
115975	kirjaniketele	?kirjaniketele =nike  (PlAll  >kirja+nike !06_S	et	f	\N
115976	kirjaniketele	?kirjaniketele =nikete  (PlAll  >kirja+nikett !22_S	et	f	\N
115982	igalpool	igalpool =pool  (ID  >igal+pool !41_DK	et	f	\N
115984	igalpool	igalpool =pool  (SgN  >igal+pool !13_NS	et	f	\N
115986	igalpool	igalpool =pool  (SgN  >igal+pool !22_S	et	f	\N
115996	arvutite	arvutite =arvuti  (PlG  >arvuti !01_S	et	f	\N
115998	arvutite	arvutite =tite  (SgG  >arvu+titt !22_S	et	f	\N
116016	el	### el	et	f	\N
116017	suureks	suureks =suure  (SgTr  >suur !13_A	et	f	\N
116018	suureks	suureks =re  (SgTr  >suu+re !26_S	et	f	\N
116055	ketti	ketti =ketti  (SgP  >kett !22_S	et	f	\N
116057	ketti	ketti =ketti  (SgAdt  >kett !22_S	et	f	\N
116070	lähemalt	lähemalt =lähema  (SgAbl  >lähem !02_A	et	f	\N
116071	lähemalt	"lähem %lähe  )M_cA  <lähike ;12_A	et	f	\N
116072	lähemalt	lähemalt =lähemalt  (ID  >lähemalt !41_D	et	f	\N
115635	kaotasid	kaotasid =kaota  (IndIpfSg2  >kaotama !27_V	et	f	\N
115636	kaotasid	kaotasid =kaota  (IndIpfPl3  >kaotama !27_V	et	f	\N
115637	reformi	reformi =reformi  (SgG  >reform !22_S	et	f	\N
115639	reformi	reformi =reformi  (SgP  >reform !22_S	et	f	\N
115641	reformi	reformi =reformi  (SgAdt  >reform !22_S	et	f	\N
115642	reformi	reformi =reformi  (IndPrPs_  >reformima !28_V	et	f	\N
115643	reformi	reformi =reformi  (ImpPrSg2  >reformima !28_V	et	f	\N
115663	tugevam	tugevam =tugevam  (SgN  >tugevam !02_A	et	f	\N
115664	tugevam	"tugevam %tuge  )VAM_cA  <tugema ;27_V	et	f	\N
115665	tugevam	"tugevam %tugeva  )M_cA  <tugev ;02_A	et	f	\N
115675	eesmärke	eesmärke =märke  (SgG  >ees+märge !06_S	et	f	\N
115676	eesmärke	eesmärke =märke  (PlP  >ees+märk !22_S	et	f	\N
115681	katolik	?katolik =katolik  (SgN  >katolik !25_A	et	f	\N
115682	reeglitest	reeglitest =reegli  (PlEl  >reegel !02_S	et	f	\N
115683	reeglitest	reeglitest =test  (SgN  >reegli+test !22_S	et	f	\N
115696	vägivaldselt	vägivaldselt =valdse  (SgAbl  >vägi+valdne !02_A	et	f	\N
115697	vägivaldselt	"vägi+valdselt %valdse  )LT_mD  <vägi+valdne ;02_A	et	f	\N
115708	liivlaste	liivlaste =liivlas  (PlG  >liivlane !12?10_S	et	f	\N
115709	liivlaste	liivlaste =las  (PlG  >liiv+laps !14_S	et	f	\N
115710	liivlaste	liivlaste =laste  (PlP  >liiv+last !22_S	et	f	\N
115726	vabatahtlikult	vabatahtlikult =tahtliku  (SgAbl  >vaba+tahtlik !25_A	et	f	\N
115729	vabatahtlikult	"vaba+tahtlikult %tahtliku  )LT_mD  <vaba+tahtlik ;25_A	et	f	\N
115740	venelaste	venelaste =venelas  (PlG  >venelane !12_S	et	f	\N
115741	venelaste	venelaste =las  (PlG  >vene+laps !14_S	et	f	\N
115742	venelaste	venelaste =laste  (PlP  >vene+last !22_S	et	f	\N
115777	saare-lääne	saare-lääne =lääne  (SgG  >saare-lääs !14_S	et	f	\N
115778	saare-lääne	saare-lääne =lääne  (PlP  >saare-lään !22_S	et	f	\N
115786	kabeleid	kabeleid =kabele  (PlP  >kabel !02_S	et	f	\N
115787	kabeleid	kabeleid =lei  (PlN  >kabe+lei !26_S	et	f	\N
115788	kabeleid	kabeleid =lei  (SgP  >kabe+lei !26_S	et	f	\N
115789	kabeleid	kabeleid =leid  (SgN  >kabe+leid !22_S	et	f	\N
115791	ristima	ristima =risti  (Sup  >ristima !28_V	et	f	\N
115793	ristima	ristima =ima  (SgN  >rist+ima !17_S	et	f	\N
115794	ristima	ristima =ima  (SgG  >rist+ima !17_S	et	f	\N
115795	ristima	ristima =ima  (SgP  >rist+ima !17_S	et	f	\N
115797	mulda	mulda =mulda  (SgP  >muld !22_S	et	f	\N
115799	mulda	mulda =mulda  (SgAdt  >muld !22_S	et	f	\N
115801	mulda	mulda =mulda  (IndPrPs_  >muldama !29_V	et	f	\N
115803	mulda	mulda =mulda  (ImpPrSg2  >muldama !29_V	et	f	\N
115830	rikastumine	rikastumine =rikastumine  (SgN  >rikastumine !12_S	et	f	\N
115831	rikastumine	"rikastumine %rikastu  )MINE_vS  <rikastuma ;27_V	et	f	\N
115838	olukorda	olukorda =korda  (SgP  >olu+kord !22_S	et	f	\N
115839	olukorda	olukorda =korda  (SgAdt  >olu+kord !22_S	et	f	\N
115840	liivimaal	liivimaal =maa  (SgAd  >liivi+maa !26_S	et	f	\N
115841	liivimaal	liivimaal =maal  (SgN  >liivi+maal !22_S	et	f	\N
115842	kirikuvara	kirikuvara =vara  (SgN  >kiriku+vara !17_S	et	f	\N
115843	kirikuvara	kirikuvara =vara  (SgG  >kiriku+vara !17_S	et	f	\N
115844	kirikuvara	kirikuvara =vara  (SgP  >kiriku+vara !17_S	et	f	\N
115848	reformatsiooni	reformatsiooni =reformatsiooni  (SgG  >reformatsioon !22_S	et	f	\N
115849	reformatsiooni	reformatsiooni =reformatsiooni  (SgP  >reformatsioon !22_S	et	f	\N
115851	reformatsiooni	reformatsiooni =reformatsiooni  (SgAdt  >reformatsioon !22_S	et	f	\N
115856	baltikumi	?baltikumi =baltikumi  (SgG  >baltikum !19_S	et	f	\N
115857	baltikumi	?baltikumi =baltikumi  (SgP  >baltikum !19_S	et	f	\N
115858	baltikumi	?baltikumi =baltikumi  (SgAdt  >baltikum !19_S	et	f	\N
115859	baltikumi	?baltikumi =kumi  (SgN  >balti+kumi !17_S	et	f	\N
115861	baltikumi	?baltikumi =kumi  (SgG  >balti+kumi !17_S	et	f	\N
115862	baltikumi	?baltikumi =kumi  (SgP  >balti+kumi !17_S	et	f	\N
115864	baltikumi	?baltikumi =ikumi  (SgN  >balt+ikumi !01_S	et	f	\N
115866	baltikumi	?baltikumi =ikumi  (SgG  >balt+ikumi !01_S	et	f	\N
115867	baltikumi	?baltikumi =ikumi  (SgG  >balt+ikum !02_S	et	f	\N
115871	taasiseseisvuse	taasiseseisvuse =seisvuse  (SgG  >taas+ise+seisvus !11~09_S	et	f	\N
115872	taasiseseisvuse	"taas+ise+seisvus %seisva  )US_aS  <taas+ise+seisev ;02_A	et	f	\N
115876	nt	### nt	et	f	\N
115885	põhikooliks	põhikooliks =iks  (SgN  >põhi+kool+iks !22_S	et	f	\N
115886	põhikooliks	põhikooliks =kooli  (SgTr  >põhi+kool !22_S	et	f	\N
115887	põhikooliks	põhikooliks =kooli  (PlTr  >põhi+kool !22_S	et	f	\N
115895	õpitakse	õpitakse =õpi  (IndPrIps  >õppima !28_V	et	f	\N
115896	õpitakse	õpitakse =takse  (PlP  >õpi+taks !22_S	et	f	\N
115897	hakab	?hakab =haka  (IndPrSg3  >hakama !27_V	et	f	\N
115907	korporatsiooni	korporatsiooni =korporatsiooni  (SgG  >korporatsioon !22_S	et	f	\N
115908	korporatsiooni	korporatsiooni =korporatsiooni  (SgP  >korporatsioon !22_S	et	f	\N
115909	korporatsiooni	korporatsiooni =korporatsiooni  (SgAdt  >korporatsioon !22_S	et	f	\N
115910	eüs	?eüs =eüs  (SgN  >eüs !22_S	et	f	\N
115911	veljesto	?veljesto =veljesto  (SgN  >veljesto !16_S	et	f	\N
115912	veljesto	?veljesto =veljesto  (SgG  >veljesto !16_S	et	f	\N
115918	naiss	?naiss =naiss  (SgN  >naiss !22_S	et	f	\N
115649	sedaprotsessi	sedaprotsessi =protsessi  (SgP  >seda+protsess !22_S	et	f	\N
115650	sedaprotsessi	sedaprotsessi =protsessi  (SgAdt  >seda+protsess !22_S	et	f	\N
115655	poliitika	poliitika =poliitika  (SgN  >poliitika !01_S	et	f	\N
115656	poliitika	poliitika =poliitika  (SgG  >poliitika !01_S	et	f	\N
115666	tegutsevad	tegutsevad =tegutse  (IndPrPl3  >tegutsema !27_V	et	f	\N
115667	tegutsevad	tegutsevad =tegutseva  (PlN  >tegutsev !02_A	et	f	\N
115668	tegutsevad	"tegutsev %tegutse  )V_vA  <tegutsema ;27_V	et	f	\N
115677	mõjud	mõjud =mõju  (PlN  >mõju !17_S	et	f	\N
115678	mõjud	mõjud =mõju  (IndPrSg2  >mõjuma !27_V	et	f	\N
115693	kedagi	kedagi =ke  (SgP  >keegi !00_P	et	f	\N
115694	kedagi	kedagi =ke  (SgP^  >kes !00_P	et	f	\N
115695	kedagi	kedagi =ke  (PlP^  >kes !00_P	et	f	\N
115706	ordu	ordu =ordu  (SgN  >ordu !16_S	et	f	\N
115707	ordu	ordu =ordu  (SgG  >ordu !16_S	et	f	\N
115715	feodaalkord	?feodaalkord =feodaalkord  (SgN  >feodaalkord !22_S	et	f	\N
115725	pöörduvad	pöörduvad =pöördu  (IndPrPl3  >pöörduma !27_V	et	f	\N
115727	pöörduvad	pöörduvad =pöörduva  (PlN  >pöörduv !02_A	et	f	\N
115728	pöörduvad	"pöörduv %pöördu  )V_vA  <pöörduma ;27_V	et	f	\N
115730	tabatu	tabatu =tabatu  (SgN  >tabatu !01_S	et	f	\N
115731	tabatu	"tabatu %taba  )TU1_vS  <tabama ;27_V	et	f	\N
115732	tabatu	"tabatu %taba  )TU2_kA  <taba ;17_S	et	f	\N
115734	tabatu	tabatu =tabatu  (SgG  >tabatu !01_S	et	f	\N
115738	erinesid	erinesid =erine  (IndIpfSg2  >erinema !27_V	et	f	\N
115739	erinesid	erinesid =erine  (IndIpfPl3  >erinema !27_V	et	f	\N
115762	lõuna-eesti	lõuna-eesti =eesti  (ID  >lõuna-eesti !41_G	et	f	\N
115763	lõuna-eesti	lõuna-eesti =eesti  (SgN  >lõuna-eesti !16_H	et	f	\N
115764	lõuna-eesti	lõuna-eesti =eesti  (SgG  >lõuna-eesti !16_H	et	f	\N
115805	talurahvas	talurahvas =rahva  (SgIn  >talu+rahvas !07_S	et	f	\N
115806	talurahvas	talurahvas =rahvas  (SgN  >talu+rahvas !07_S	et	f	\N
115825	arstiabi	arstiabi =abi  (SgN  >arsti+abi !17_S	et	f	\N
115826	arstiabi	arstiabi =abi  (SgG  >arsti+abi !17_S	et	f	\N
115827	arstiabi	arstiabi =abi  (SgP  >arsti+abi !17_S	et	f	\N
115837	luther	?luther =luther  (SgN  >luther !02_S	et	f	\N
115878	mõiste	mõiste =mõiste  (SgN  >mõiste !06_S	et	f	\N
115879	mõiste	mõiste =mõiste  (SgG  >mõiste !06_S	et	f	\N
115880	mõiste	mõiste =mõiste  (PlP  >mõist !22_S	et	f	\N
115888	teaduskonnad	teaduskonnad =teaduskonna  (PlN  >teaduskond !22_S	et	f	\N
115889	teaduskonnad	teaduskonnad =konna  (PlN  >teadus+konn !22_S	et	f	\N
115924	ars	?ars =ars  (SgN  >ars !22_S	et	f	\N
115960	part	part =par  (SgP  >pars !14_S	et	f	\N
115962	part	part =part  (SgN  >part !22_S	et	f	\N
115977	nimeline	nimeline =nimeline  (SgN  >nimeline !12_A	et	f	\N
115978	nimeline	"nimeline %nime  )LINE_aA  <nimi ;20_S	et	f	\N
115981	tehtikaareng	?tehtikaareng =tehtikaareng  (SgN  >tehtikaareng !02_S	et	f	\N
116000	salvesta	salvesta =salvesta  (IndPrPs_  >salvestama !27_V	et	f	\N
116001	salvesta	salvesta =salvesta  (ImpPrSg2  >salvestama !27_V	et	f	\N
116002	sama	sama =sama  (ID  >sama !41_D	et	f	\N
116003	sama	sama =sama  (SgN  >sama !17_P	et	f	\N
116004	sama	sama =sama  (SgG  >sama !17_P	et	f	\N
116005	sama	sama =sama  (SgP  >sama !17_P	et	f	\N
116009	läti	?läti =läti  (SgN  >läti !16_S	et	f	\N
116010	läti	?läti =läti  (SgG  >läti !16_S	et	f	\N
116011	läti	?läti =läti  (SgG  >lätt !22_S	et	f	\N
116012	läti	?läti =läti  (IndPrPs_  >lätima !27_V	et	f	\N
116013	läti	?läti =läti  (IndPrPs_  >lättima !28_V	et	f	\N
116014	läti	?läti =läti  (ImpPrSg2  >lätima !27_V	et	f	\N
116015	läti	?läti =läti  (ImpPrSg2  >lättima !28_V	et	f	\N
116019	probleemiks	probleemiks =probleemi  (SgTr  >probleem !22_S	et	f	\N
116020	probleemiks	probleemiks =iks  (SgN  >probleem+iks !22_S	et	f	\N
116021	muulasi	muulasi =muulasi  (PlP  >muulane !12_S	et	f	\N
116022	muulasi	"muulane %muula  )NE_aA  <muul ;22_S	et	f	\N
116031	kommed	?kommed =komme  (IndPrSg2  >kommema !27_V	et	f	\N
116032	narkomaania	narkomaania =maania  (SgN  >narko+maania !01_S	et	f	\N
116033	narkomaania	narkomaania =maania  (SgG  >narko+maania !01_S	et	f	\N
116038	millioni	?millioni =millio  (SgTer  >millio !01_S	et	f	\N
116039	millioni	?millioni =millioni  (SgN  >millioni !16_S	et	f	\N
116040	millioni	?millioni =millioni  (SgG  >million !19~02_S	et	f	\N
116041	millioni	?millioni =millioni  (SgG  >millioni !16_S	et	f	\N
116042	millioni	?millioni =millioni  (SgP  >million !19_S	et	f	\N
116043	millioni	?millioni =millioni  (SgAdt  >million !19_S	et	f	\N
116044	millioni	?millioni =millioni  (IndPrPs_  >millionima !28_V	et	f	\N
116045	millioni	?millioni =millioni  (ImpPrSg2  >millionima !28_V	et	f	\N
116046	millioni	?millioni =oni  (SgN  >milli+oni !17_S	et	f	\N
116047	millioni	?millioni =oni  (SgG  >milli+oni !17_S	et	f	\N
116048	millioni	?millioni =oni  (SgP  >milli+oni !17_S	et	f	\N
116074	ükskõigne	?ükskõigne =ükskõigne  (SgN  >ükskõigne !02_A	et	f	\N
116075	ükskõigne	?ükskõigne =ükskõigne  (PlP  >ükskõign !22_S	et	f	\N
116076	ükskõigne	?ükskõigne =kõigne  (SgN  >üks+kõigne !02_A	et	f	\N
116077	ükskõigne	?ükskõigne =kõigne  (PlP  >üks+kõign !22_S	et	f	\N
115755	killustatus	killustatus =killustatus  (SgN  >killustatus !11?09_S	et	f	\N
115756	killustatus	"killustatus %killusta  )TUS1_aS  <killustama ;27_V	et	f	\N
115769	rannikueesti	?rannikueesti =rannikueesti  (ID  >rannikueesti !41_D	et	f	\N
115770	rannikueesti	?rannikueesti =rannikueesti  (IndPrPs_  >rannikueestima !28_V	et	f	\N
115772	rannikueesti	?rannikueesti =rannikueesti  (ImpPrSg2  >rannikueestima !28_V	et	f	\N
115779	maarahvas	maarahvas =rahva  (SgIn  >maa+rahvas !07_S	et	f	\N
115780	maarahvas	maarahvas =rahvas  (SgN  >maa+rahvas !07_S	et	f	\N
115781	ümberorienteeruma	?ümberorienteeruma =ümberorienteeru  (Sup  >ümberorienteeruma !27_V	et	f	\N
115784	ehitama	ehitama =ehi  (SupIps  >ehtima !28_V	et	f	\N
115785	ehitama	ehitama =ehita  (Sup  >ehitama !27_V	et	f	\N
115790	sündides	sündides =sündi  (PlIn  >sünd !22_S	et	f	\N
115792	sündides	sündides =sündi  (Ger  >sündima !28_V	et	f	\N
115796	pühitsetudõnnistatud	?pühitsetudõnnistatud =pühitsetudõnnista  (PtsPtIps  >pühitsetudõnnistama !27_V	et	f	\N
115798	pühitsetudõnnistatud	?pühitsetudõnnistatud =pühitsetudõnnistatu  (PlN  >pühitsetudõnnistatu !01_S	et	f	\N
115800	pühitsetudõnnistatud	?pühitsetudõnnistatud =pühitsetudõnnistatu  (IndPrSg2  >pühitsetudõnnistatuma !27_V	et	f	\N
115802	pühitsetudõnnistatud	?pühitsetudõnnistatud =pühitsetudõnnistatud  (ID  >pühitsetudõnnistatud !41_A	et	f	\N
115804	pühitsetudõnnistatud	?pühitsetudõnnistatud =tsetudõnnistatu  (PlN  >pühi+tsetudõnnistatu !01_S	et	f	\N
115807	ülemkihti	ülemkihti =kihti  (SgP  >ülem+kiht !22_S	et	f	\N
115808	ülemkihti	ülemkihti =kihti  (SgAdt  >ülem+kiht !22_S	et	f	\N
115811	adminastriinse	?adminastriinse =adminastriinse  (SgG  >adminastriinne !02_A	et	f	\N
115812	adminastriinse	?adminastriinse =adminastriinse  (PlP  >adminastriins !22_S	et	f	\N
115816	valdavalt	valdavalt =valdava  (SgAbl  >valdav !02_A	et	f	\N
115817	valdavalt	"valdav %valda  )V_vA  <valdama ;29_V	et	f	\N
115818	valdavalt	valdavalt =valdavalt  (ID  >valdavalt !41_D	et	f	\N
115820	valdavalt	"valdavalt %valda  )VALT_mD  <valdama ;29_V	et	f	\N
115823	valdavalt	"valdavalt %valdava  )LT_mD  <valdav ;02_A	et	f	\N
115824	valdavalt	valdavalt =ava  (SgAbl  >vald+ava !17_S	et	f	\N
115852	nõudeks	nõudeks =nõu  (PlTr  >nõu !26_S	et	f	\N
115853	nõudeks	nõudeks =nõude  (SgTr  >nõue !06_S	et	f	\N
115877	tr	### tr	et	f	\N
115898	programmi	programmi =programmi  (SgG  >programm !22_S	et	f	\N
115899	programmi	programmi =programmi  (SgP  >programm !22_S	et	f	\N
115900	programmi	programmi =programmi  (SgAdt  >programm !22_S	et	f	\N
115901	programmi	programmi =programmi  (IndPrPs_  >programmima !28_V	et	f	\N
115902	programmi	programmi =programmi  (ImpPrSg2  >programmima !28_V	et	f	\N
115903	välisvahetus	välisvahetus =vahetu  (SgIn  >välis+vahetu !01_A	et	f	\N
115904	välisvahetus	"välis+vahetu %vahe  )TU2_kA  <välis+vahe ;16_S	et	f	\N
115905	välisvahetus	välisvahetus =vahetus  (SgN  >välis+vahetus !11_S	et	f	\N
115906	välisvahetus	"välis+vahetus %vahe  )TUS2_aS  <välis+vahe ;16_S	et	f	\N
115913	ainuke	ainuke =ainuke  (SgN  >ainuke !12_AS	et	f	\N
115914	ainuke	"ainuke %ainu  )KE_dS  <ainu ;16_S	et	f	\N
115915	ainuke	"ainuke %ainu  )KE_dA  <ainus ;07_AS	et	f	\N
115919	koolivormi	koolivormi =vormi  (SgG  >kooli+vorm !22_S	et	f	\N
115920	koolivormi	koolivormi =vormi  (SgP  >kooli+vorm !22_S	et	f	\N
115921	koolivormi	koolivormi =vormi  (SgAdt  >kooli+vorm !22_S	et	f	\N
115922	ões	ões =õe  (SgIn  >õde !18_S	et	f	\N
115923	ões	ões =ões  (SgN  >ões !09_S	et	f	\N
115927	ajakirju	ajakirju =kirju  (SgN  >aja+kirju !01_A	et	f	\N
115928	ajakirju	ajakirju =kirju  (SgN  >aja+kirju !16_A	et	f	\N
115929	ajakirju	ajakirju =kirju  (SgG  >aja+kirju !01_A	et	f	\N
115930	ajakirju	ajakirju =kirju  (SgG  >aja+kirju !16_A	et	f	\N
115931	ajakirju	ajakirju =kirju  (PlP  >aja+kiri !24_S	et	f	\N
115940	murreid	?murreid =murrei  (PlN  >murrei !26_S	et	f	\N
115941	murreid	?murreid =murrei  (SgP  >murrei !26_S	et	f	\N
115942	murreid	?murreid =murreid  (SgN  >murreid !22_S	et	f	\N
115946	pidada	pidada =pida  (Inf  >pida !40_V	et	f	\N
115947	pidada	pidada =pida  (Inf  >pidama !28_V	et	f	\N
115952	kodumaale	kodumaale =maa  (SgAll  >kodu+maa !26_S	et	f	\N
115953	kodumaale	kodumaale =maale  (PlP  >kodu+maal !22_S	et	f	\N
115966	järvi	järvi =järvi  (SgG  >järv !22_S	et	f	\N
115967	järvi	järvi =järvi  (SgP  >järv !22_S	et	f	\N
115968	järvi	järvi =järvi  (SgAdt  >järv !22_S	et	f	\N
115969	järvi	järvi =järvi  (PlP  >järv !22_S	et	f	\N
115979	preemia	preemia =preemia  (SgN  >preemia !01_S	et	f	\N
115980	preemia	preemia =preemia  (SgG  >preemia !01_S	et	f	\N
115993	telefoni	telefoni =telefoni  (SgG  >telefon !19_S	et	f	\N
115994	telefoni	telefoni =telefoni  (SgP  >telefon !19_S	et	f	\N
115995	telefoni	telefoni =telefoni  (SgAdt  >telefon !19_S	et	f	\N
115997	kasutamine	kasutamine =kasutamine  (SgN  >kasutamine !12_S	et	f	\N
115999	kasutamine	"kasutamine %kasuta  )MINE_vS  <kasutama ;27_V	et	f	\N
116025	keskealised	keskealised =ealise  (PlN  >kesk+ealine !12?10_A	et	f	\N
116026	keskealised	"kesk+ealine %ea  )LINE_aA  <kesk+iga ;18_S	et	f	\N
116029	tagapoole	tagapoole =poole  (SgN  >taga+poole !05_S	et	f	\N
116030	tagapoole	tagapoole =poole  (PlP  >taga+pool !22_S	et	f	\N
115771	läänemaa	läänemaa =maa  (SgN  >lääne+maa !26_S	et	f	\N
115773	läänemaa	läänemaa =maa  (SgG  >lääne+maa !26_S	et	f	\N
115782	võimuks	võimuks =võimu  (SgTr  >võim !22_S	et	f	\N
115783	võimuks	võimuks =muks  (SgN  >või+muks !22_S	et	f	\N
115809	käsitöö	käsitöö =töö  (SgN  >käsi+töö !26_S	et	f	\N
115810	käsitöö	käsitöö =töö  (SgG  >käsi+töö !26_S	et	f	\N
115813	jaotuse	jaotuse =jaotuse  (SgG  >jaotus !11~09_S	et	f	\N
115814	jaotuse	"jaotus %jaota  )US_vS  <jaotama ;27_V	et	f	\N
115815	jaotuse	"jaotus %jao  )TUS2_aS  <jagu ;18_S	et	f	\N
115832	kõigilt	kõigilt =kõigi  (PlAbl  >kõik !00_P	et	f	\N
115833	kõigilt	kõigilt =kõigi  (SgAbl  >kõik !22_S	et	f	\N
115845	nõudsid	nõudsid =nõud  (IndIpfSg2  >nõudma !34_V	et	f	\N
115846	nõudsid	nõudsid =nõud  (IndIpfPl3  >nõudma !34_V	et	f	\N
115847	õppimist	õppimist =õppimis  (SgP  >õppimine !12_S	et	f	\N
115850	õppimist	"õppimine %õppi  )MINE_vS  <õppima ;28_V	et	f	\N
115860	rahavstele	?rahavstele =rahavste  (PlAll  >rahavst !22_S	et	f	\N
115863	rahavstele	?rahavstele =rahavstele  (IndPrPs_  >rahavstelema !36_V	et	f	\N
115865	rahavstele	?rahavstele =rahavstele  (ImpPrSg2  >rahavstelema !36_V	et	f	\N
115916	mees-	mees- =mee  (SgIn  >mesi !15_S	et	f	\N
115917	mees-	mees- =mees  (SgN  >mees !13_S	et	f	\N
115925	andsid	andsid =and  (IndIpfSg2  >andma !34_V	et	f	\N
115926	andsid	andsid =and  (IndIpfPl3  >andma !34_V	et	f	\N
115935	tohtinud	tohtinud =tohti  (PtsPtPs  >tohtima !28_V	et	f	\N
115936	tohtinud	tohtinud =tohtinu  (PlN  >tohtinu !01_S	et	f	\N
115937	tohtinud	"tohtinu %tohti  )NU_vS  <tohtima ;28_V	et	f	\N
115938	tohtinud	tohtinud =tohtinud  (ID  >tohtinud !41_A	et	f	\N
115939	tohtinud	"tohtinud %tohti  )NUD_vA  <tohtima ;28_V	et	f	\N
115954	tutvustavad	tutvustavad =tutvusta  (IndPrPl3  >tutvustama !27_V	et	f	\N
115955	tutvustavad	tutvustavad =tutvustava  (PlN  >tutvustav !02_A	et	f	\N
115956	tutvustavad	"tutvustav %tutvusta  )V_vA  <tutvustama ;27_V	et	f	\N
115957	tutvustavad	tutvustavad =tava  (PlN  >tutvus+tava !17_S	et	f	\N
115983	kiire	kiire =kiire  (SgN  >kiire !01_A	et	f	\N
115985	kiire	kiire =kiire  (SgN  >kiire !06_S	et	f	\N
115987	kiire	kiire =kiire  (SgN  >kiire !06_AS	et	f	\N
115988	kiire	kiire =kiire  (SgG  >kiire !01_A	et	f	\N
115989	kiire	kiire =kiire  (SgG  >kiire !06_S	et	f	\N
115990	kiire	kiire =kiire  (SgG  >kiire !06_AS	et	f	\N
115991	kiire	kiire =kiire  (SgG  >kiir !13_S	et	f	\N
115992	kiire	kiire =kiire  (PlP  >kiir !22_S	et	f	\N
116006	integratsiooni	integratsiooni =integratsiooni  (SgG  >integratsioon !22_S	et	f	\N
116007	integratsiooni	integratsiooni =integratsiooni  (SgP  >integratsioon !22_S	et	f	\N
116008	integratsiooni	integratsiooni =integratsiooni  (SgAdt  >integratsioon !22_S	et	f	\N
116027	vaatasid	vaatasid =vaata  (IndIpfSg2  >vaatama !29_V	et	f	\N
116028	vaatasid	vaatasid =vaata  (IndIpfPl3  >vaatama !29_V	et	f	\N
116052	elanikku	elanikku =elanikku  (SgP  >elanik !25_S	et	f	\N
116053	elanikku	elanikku =elanikku  (SgAdt  >elanik !25_S	et	f	\N
116065	pööras	pööras =pööra  (SgIn  >pöör !22_S	et	f	\N
116066	pööras	pööras =pööra  (IndIpfSg3  >pöörama !29_V	et	f	\N
116067	televiisorist	televiisorist =televiisori  (SgEl  >televiisor !02_S	et	f	\N
116068	televiisorist	televiisorist =oris  (SgP  >tele+viis+orine !10_A	et	f	\N
116069	televiisorist	"tele+viis+orine %ori  )NE_aA  <tele+viis+ori ;24_S	et	f	\N
116081	kerget	kerget =kerge  (SgP  >kerge !01_A	et	f	\N
116082	kerget	kerget =kerge  (SgP  >kerge !06_S	et	f	\N
116086	liialt	liialt =liia  (SgAbl  >liig !22_S	et	f	\N
116087	liialt	liialt =liialt  (ID  >liialt !41_D	et	f	\N
116092	leitud	leitud =lei  (PtsPtIps  >leidma !34_V	et	f	\N
116093	leitud	leitud =leitu  (PlN  >leitu !01_S	et	f	\N
116094	leitud	"leitu %lei  )TU1_vS  <leidma ;34_V	et	f	\N
116095	leitud	"leitu %lei  )TU2_kA  <lei ;26_S	et	f	\N
116096	leitud	leitud =leitud  (ID  >leitud !41_A	et	f	\N
116097	leitud	"leitud %lei  )TUD_vA  <leidma ;34_V	et	f	\N
116109	tegijate	tegijate =tegija  (PlG  >tegija !01_S	et	f	\N
116111	tegijate	"tegija %tegi  )JA_vS  <tegema ;28_V	et	f	\N
116115	reklaami	reklaami =reklaami  (SgG  >reklaam !22_S	et	f	\N
116118	reklaami	reklaami =reklaami  (SgP  >reklaam !22_S	et	f	\N
116119	reklaami	reklaami =reklaami  (SgAdt  >reklaam !22_S	et	f	\N
116120	reklaami	reklaami =reklaami  (IndPrPs_  >reklaamima !28_V	et	f	\N
116121	reklaami	reklaami =reklaami  (ImpPrSg2  >reklaamima !28_V	et	f	\N
116129	lk2	### lk2	et	f	\N
116144	kooliõppekava	kooliõppekava =kava  (SgN  >kooli+õppe+kava !17_S	et	f	\N
116145	kooliõppekava	kooliõppekava =kava  (SgG  >kooli+õppe+kava !17_S	et	f	\N
116147	kooliõppekava	kooliõppekava =kava  (SgP  >kooli+õppe+kava !17_S	et	f	\N
116150	lk	### lk	et	f	\N
116153	kasutatud	kasutatud =kasuta  (PtsPtIps  >kasutama !27_V	et	f	\N
116154	kasutatud	kasutatud =kasutatu  (PlN  >kasutatu !01_S	et	f	\N
116155	kasutatud	"kasutatu %kasuta  )TU1_vS  <kasutama ;27_V	et	f	\N
116156	kasutatud	kasutatud =kasutatud  (ID  >kasutatud !41_A	et	f	\N
116158	kasutatud	"kasutatud %kasuta  )TUD_vA  <kasutama ;27_V	et	f	\N
116167	koolisma	?koolisma =koolisma  (SgN  >koolisma !01_S	et	f	\N
115943	eraldi	eraldi =eraldi  (ID  >eraldi !41_DA	et	f	\N
115944	eraldi	eraldi =eraldi  (SgN  >eraldi !01_S	et	f	\N
115945	eraldi	eraldi =eraldi  (SgG  >eraldi !01_S	et	f	\N
115961	neeme	neeme =neeme  (SgG  >neem !22_S	et	f	\N
115963	neeme	neeme =neeme  (SgP  >neem !22_S	et	f	\N
115964	neeme	neeme =neeme  (SgAdt  >neem !22_S	et	f	\N
115965	neeme	neeme =neeme  (PlP  >neem !22_S	et	f	\N
115970	kangro	?kangro =kangro  (SgN  >kangro !01_S	et	f	\N
115971	kangro	?kangro =kangro  (SgG  >kangro !01_S	et	f	\N
116023	kurssi	kurssi =kurssi  (SgP  >kurss !22_S	et	f	\N
116024	kurssi	kurssi =kurssi  (SgAdt  >kurss !22_S	et	f	\N
116034	tegelevad	tegelevad =tegele  (IndPrPl3  >tegelema !31~27_V	et	f	\N
116035	tegelevad	tegelevad =tegeleva  (PlN  >tegelev !02_A	et	f	\N
116036	tegelevad	"tegelev %tegele  )V_vA  <tegelema ;27_V	et	f	\N
116037	tegelevad	"tegelev %tegele  )V_vA  <tegelema ;31_V	et	f	\N
116049	leedu	leedu =leedu  (SgN  >leedu !16_S	et	f	\N
116050	leedu	"leedu %lee  )TU1_vS  <leema ;37_V	et	f	\N
116051	leedu	leedu =leedu  (SgG  >leedu !16_S	et	f	\N
116054	võetes	?võetes =võet  (Ger  >võetma !34_V	et	f	\N
116056	võetes	?võetes =võete  (SgIn  >võede !06_S	et	f	\N
116058	võetes	?võetes =võete  (IndIpfSg3  >võetema !27_V	et	f	\N
116059	võetes	?võetes =võetes  (SgN  >võetes !09_S	et	f	\N
116063	vabadusele	vabadusele =vabaduse  (SgAll  >vabadus !11_S	et	f	\N
116064	vabadusele	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
116088	meest	meest =mee  (SgEl  >mesi !15_S	et	f	\N
116089	meest	meest =mees  (SgP  >meene !10_A	et	f	\N
116090	meest	"meene %mee  )NE_aA  <mesi ;15_S	et	f	\N
116091	meest	meest =mees  (SgP  >mees !13_S	et	f	\N
116098	nõksu	nõksu =nõksu  (SgG  >nõks !22_S	et	f	\N
116099	nõksu	nõksu =nõksu  (SgP  >nõks !22_S	et	f	\N
116100	nõksu	nõksu =nõksu  (SgAdt  >nõks !22_S	et	f	\N
116101	nõksu	nõksu =nõksu  (IndPrPs_  >nõksuma !28_V	et	f	\N
116102	nõksu	nõksu =nõksu  (ImpPrSg2  >nõksuma !28_V	et	f	\N
116131	lk4	### lk4	et	f	\N
116133	11eesti	eesti =eesti  (ID  >eesti !41_G	et	f	\N
116134	11eesti	eesti =eesti  (SgN  >eesti !16_H	et	f	\N
116135	11eesti	eesti =eesti  (SgG  >eesti !16_H	et	f	\N
116146	lk15	### lk15	et	f	\N
116160	seminaritööteemaks	?seminaritööteemaks =seminaritööteema  (SgTr  >seminaritööteema !16_S	et	f	\N
116161	seminaritööteemaks	?seminaritööteemaks =itööteema  (SgTr  >seminar+itööteema !16_S	et	f	\N
116162	valinud	valinud =vali  (PtsPtPs  >valima !27_V	et	f	\N
116163	valinud	valinud =valinu  (PlN  >valinu !01_S	et	f	\N
116164	valinud	"valinu %vali  )NU_vS  <valima ;27_V	et	f	\N
116165	valinud	valinud =valinud  (ID  >valinud !41_A	et	f	\N
116166	valinud	"valinud %vali  )NUD_vA  <valima ;27_V	et	f	\N
116186	õppimiseks	õppimiseks =õppimise  (SgTr  >õppimine !12_S	et	f	\N
116188	õppimiseks	"õppimine %õppi  )MINE_vS  <õppima ;28_V	et	f	\N
116222	õpetajatega	õpetajatega =õpetaja  (PlKom  >õpetaja !01_S	et	f	\N
116223	õpetajatega	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
116229	interneti-	?interneti- =interneti  (IndPrPs_  >internettima !28_V	et	f	\N
116230	interneti-	?interneti- =interneti  (ImpPrSg2  >internettima !28_V	et	f	\N
116232	interneti-	?interneti- =neti  (SgN  >inter+neti !16_S	et	f	\N
116233	interneti-	?interneti- =neti  (SgG  >inter+neti !16_S	et	f	\N
116234	interneti-	?interneti- =neti  (SgG  >inter+nett !22_AS	et	f	\N
116255	tervikpilti	tervikpilti =pilti  (SgP  >tervik+pilt !22_S	et	f	\N
116257	tervikpilti	tervikpilti =pilti  (SgAdt  >tervik+pilt !22_S	et	f	\N
116267	alamast	alamast =alama  (SgEl  >alam !02_AS	et	f	\N
116268	alamast	alamast =ast  (SgN  >alam+ast !22_S	et	f	\N
116269	alamast	alamast =mast  (SgN  >ala+mast !22_S	et	f	\N
116272	erakordselt	erakordselt =kordse  (SgAbl  >era+kordne !02_AS	et	f	\N
116275	erakordselt	"era+kordselt %kordse  )LT_mD  <era+kordne ;02_AS	et	f	\N
116279	olemise	olemise =olemise  (SgG  >olemine !12_S	et	f	\N
116281	olemise	"olemine %ole  )MINE_vS  <olema ;36_V	et	f	\N
116282	olemise	"olemine %olemi  )NE_aA  <olem ;02_S	et	f	\N
116283	vastuoluline	vastuoluline =oluline  (SgN  >vastu+oluline !12_A	et	f	\N
116284	vastuoluline	"vastu+oluline %olu  )LINE_aA  <vastu+olu ;17_S	et	f	\N
116295	lõuna-eestiks	lõuna-eestiks =eesti  (SgTr  >lõuna-eesti !16_H	et	f	\N
116296	lõuna-eestiks	lõuna-eestiks =iks  (SgN  >lõuna-eest+iks !22_S	et	f	\N
116297	lõuna-eestiks	lõuna-eestiks =tiks  (SgN  >lõuna-ees+tiks !22_S	et	f	\N
116317	pärnuni	pärnuni =pärnu  (SgTer  >pärnu !01_H	et	f	\N
116319	pärnuni	pärnuni =uni  (SgN  >pärn+uni !20_S	et	f	\N
116328	samasuunaliste	samasuunaliste =suunalis  (PlG  >sama+suunaline !12_A	et	f	\N
116329	samasuunaliste	"sama+suunaline %suuna  )LINE_aA  <sama+suund ;22_S	et	f	\N
116356	ulatunud	ulatunud =ulatu  (PtsPtPs  >ulatuma !27_V	et	f	\N
116357	ulatunud	ulatunud =ulatunu  (PlN  >ulatunu !01_S	et	f	\N
116358	ulatunud	"ulatunu %ulatu  )NU_vS  <ulatuma ;27_V	et	f	\N
116359	ulatunud	ulatunud =ulatunud  (ID  >ulatunud !41_A	et	f	\N
116360	ulatunud	"ulatunud %ulatu  )NUD_vA  <ulatuma ;27_V	et	f	\N
116398	liitsid	liitsid =liit  (IndIpfSg2  >liitma !34_V	et	f	\N
116060	kättest	?kättest =kätte  (SgEl  >käte !06_S	et	f	\N
116061	kättest	?kättest =kättes  (SgP  >kättes !09_S	et	f	\N
116062	kättest	?kättest =kättes  (SgP  >kättene !12~10_A	et	f	\N
116079	tegijatel	tegijatel =tegija  (PlAd  >tegija !01_S	et	f	\N
116080	tegijatel	"tegija %tegi  )JA_vS  <tegema ;28_V	et	f	\N
116103	loodetakse	loodetakse =loode  (IndPrIps  >lootma !34_V	et	f	\N
116104	loodetakse	loodetakse =takse  (PlP  >loode+taks !22_S	et	f	\N
116105	vaesekeste	vaesekeste =vaesekes  (PlG  >vaeseke !12_AS	et	f	\N
116106	vaesekeste	"vaeseke %vaese  )KE_dA  <vaene ;10_AS	et	f	\N
116107	vaesekeste	vaesekeste =vaesekes  (PlG  >vaesekene !12_AS	et	f	\N
116108	vaesekeste	"vaesekene %vaese  )KENE_dA  <vaene ;10_AS	et	f	\N
116110	vaesekeste	vaesekeste =keste  (SgN  >vaese+keste !06_S	et	f	\N
116112	vaesekeste	vaesekeste =keste  (SgG  >vaese+keste !06_S	et	f	\N
116113	vaesekeste	vaesekeste =keste  (PlP  >vaese+kest !22_S	et	f	\N
116126	võõrkelena	?võõrkelena =kele  (SgEs  >võõr+kele !16_S	et	f	\N
116127	õpetamine	õpetamine =õpetamine  (SgN  >õpetamine !12_S	et	f	\N
116128	õpetamine	"õpetamine %õpeta  )MINE_vS  <õpetama ;27_V	et	f	\N
116130	lk3	### lk3	et	f	\N
116148	2õppimine	õppimine =õppimine  (SgN  >õppimine !12_S	et	f	\N
116149	2õppimine	"õppimine %õppi  )MINE_vS  <õppima ;28_V	et	f	\N
116157	lisad	lisad =lisa  (PlN  >lisa !17_S	et	f	\N
116159	lisad	lisad =lisa  (IndPrSg2  >lisama !27_V	et	f	\N
116173	valdkonnassee	?valdkonnassee =valdkonnassee  (SgN  >valdkonnassee !26_S	et	f	\N
116174	valdkonnassee	?valdkonnassee =valdkonnassee  (SgG  >valdkonnassee !26_S	et	f	\N
116175	valdkonnassee	?valdkonnassee =konnassee  (SgN  >vald+konnassee !26_S	et	f	\N
116176	valdkonnassee	?valdkonnassee =konnassee  (SgG  >vald+konnassee !26_S	et	f	\N
116184	pööratud	pööratud =pööra  (PtsPtIps  >pöörama !29_V	et	f	\N
116185	pööratud	pööratud =pööratu  (PlN  >pööratu !01_AS	et	f	\N
116187	pööratud	"pööratu %pööra  )TU1_vS  <pöörama ;29_V	et	f	\N
116189	pööratud	"pööratu %pööra  )TU2_kA  <pöör ;22_S	et	f	\N
116190	pööratud	pööratud =pööratud  (ID  >pööratud !41_A	et	f	\N
116191	pööratud	"pööratud %pööra  )TUD_vA  <pöörama ;29_V	et	f	\N
116192	sooviksid	sooviksid =soovi  (KndPrSg2  >soovima !28_V	et	f	\N
116193	sooviksid	sooviksid =soovi  (KndPrPl3  >soovima !28_V	et	f	\N
116194	sooviksid	sooviksid =iksi  (PlN  >soov+iks !22_S	et	f	\N
116195	sooviksid	sooviksid =viksi  (PlN  >soo+viks !22_AS	et	f	\N
116214	õppeedukust	õppeedukust =kus  (SgP  >õppe+edu+kusi !20_S	et	f	\N
116215	õppeedukust	õppeedukust =edukus  (SgP  >õppe+edukus !11_S	et	f	\N
116216	õppeedukust	"õppe+edukus %eduka  )US_aS  <õppe+edukas ;02_A	et	f	\N
116224	paremaks	paremaks =parema  (SgTr  >parem !02_A	et	f	\N
116225	paremaks	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
116249	ril	### ril	et	f	\N
116285	seisukohalt	seisukohalt =koha  (SgAbl  >seisu+koha !17_S	et	f	\N
116286	seisukohalt	seisukohalt =koha  (SgAbl  >seisu+koht !22_S	et	f	\N
116298	tuumikuks	tuumikuks =tuumiku  (SgTr  >tuumik !02_S	et	f	\N
116299	tuumikuks	tuumikuks =uks  (SgN  >tuumik+uks !14_S	et	f	\N
116300	murde	murde =murde  (SgG  >murre !06_S	et	f	\N
116301	murde	murde =murde  (PlP  >murd !22_S	et	f	\N
116311	madal-eesti	madal-eesti =eesti  (ID  >madal-eesti !41_G	et	f	\N
116312	madal-eesti	madal-eesti =eesti  (SgN  >madal-eesti !16_H	et	f	\N
116313	madal-eesti	madal-eesti =eesti  (SgG  >madal-eesti !16_H	et	f	\N
116338	rannikuala	rannikuala =ala  (SgN  >ranniku+ala !17_S	et	f	\N
116339	rannikuala	rannikuala =ala  (SgG  >ranniku+ala !17_S	et	f	\N
116340	rannikuala	rannikuala =ala  (SgP  >ranniku+ala !17_S	et	f	\N
116350	kaugemale	kaugemale =kaugema  (SgAll  >kaugem !02_A	et	f	\N
116351	kaugemale	"kaugem %kauge  )M_cA  <kauge ;01_A	et	f	\N
116352	kaugemale	kaugemale =kaugemale  (ID  >kaugemale !41_D	et	f	\N
116353	kaugemale	kaugemale =male  (SgN  >kauge+male !16_S	et	f	\N
116354	kaugemale	kaugemale =male  (SgG  >kauge+male !16_S	et	f	\N
116355	kaugemale	kaugemale =ema  (SgAll  >kaug+ema !17_S	et	f	\N
116370	peterburi	?peterburi =peterburi  (SgG  >peterbur !19_S	et	f	\N
116372	peterburi	?peterburi =peterburi  (SgP  >peterbur !19_S	et	f	\N
116373	peterburi	?peterburi =peterburi  (SgAdt  >peterbur !19_S	et	f	\N
116376	riia	?riia =riia  (SgN  >riia !16_S	et	f	\N
116377	riia	?riia =riia  (SgG  >riia !16_S	et	f	\N
116378	riia	?riia =riia  (IndPrPs_  >riiama !29_V	et	f	\N
116379	riia	?riia =riia  (ImpPrSg2  >riiama !29_V	et	f	\N
116381	liivimaa	liivimaa =maa  (SgN  >liivi+maa !26_S	et	f	\N
116382	liivimaa	liivimaa =maa  (SgG  >liivi+maa !26_S	et	f	\N
116384	kubermangu	kubermangu =kubermangu  (SgG  >kubermang !22_S	et	f	\N
116385	kubermangu	kubermangu =kubermangu  (SgP  >kubermang !22_S	et	f	\N
116386	kubermangu	kubermangu =kubermangu  (SgAdt  >kubermang !22_S	et	f	\N
116402	rahvalaulu	rahvalaulu =laulu  (SgG  >rahva+laul !22_S	et	f	\N
116403	rahvalaulu	rahvalaulu =laulu  (SgP  >rahva+laul !22_S	et	f	\N
116404	rahvalaulu	rahvalaulu =laulu  (SgAdt  >rahva+laul !22_S	et	f	\N
116453	aluse	aluse =aluse  (SgG  >alus !09_S	et	f	\N
116454	aluse	aluse =aluse  (SgG  >alune !10_AS	et	f	\N
116073	lähemalt	"lähemalt %lähema  )LT_mD  <lähem ;02_A	et	f	\N
116078	tuntub	?tuntub =tuntu  (IndPrSg3  >tuntuma !27_V	et	f	\N
116083	ajamiseks	ajamiseks =ajamise  (SgTr  >ajamine !12_S	et	f	\N
116084	ajamiseks	"ajamine %aja  )MINE_vS  <ajama ;27_V	et	f	\N
116085	ajamiseks	"ajamine %ajami  )NE_aA  <ajam ;02_S	et	f	\N
116114	mõteta	?mõteta =mõte  (IndPrIps_  >mõtema !27_V	et	f	\N
116116	mõteta	?mõteta =mõteta  (IndPrPs_  >mõtetama !27_V	et	f	\N
116117	mõteta	?mõteta =mõteta  (ImpPrSg2  >mõtetama !27_V	et	f	\N
116122	ülikool	ülikool =koo  (SgAd  >üli+kubu !18_S	et	f	\N
116123	ülikool	ülikool =kool  (SgN  >üli+kool !22_S	et	f	\N
116132	lk4	### lk4	et	f	\N
116136	lk6	### lk6	et	f	\N
116140	lk8	### lk8	et	f	\N
116152	lk21	### lk21	et	f	\N
116180	tööhüpoteesiks	tööhüpoteesiks =iks  (SgN  >töö+hüpo+tees+iks !22_S	et	f	\N
116181	tööhüpoteesiks	tööhüpoteesiks =si  (SgTr  >töö+hüpo+tee+si !26_S	et	f	\N
116182	tööhüpoteesiks	tööhüpoteesiks =teesi  (SgTr  >töö+hüpo+tees !22_S	et	f	\N
116183	tööhüpoteesiks	tööhüpoteesiks =hüpoteesi  (SgTr  >töö+hüpotees !22_S	et	f	\N
116199	tööhüpoteesi	tööhüpoteesi =teesi  (SgG  >töö+hüpo+tees !22_S	et	f	\N
116200	tööhüpoteesi	tööhüpoteesi =teesi  (SgP  >töö+hüpo+tees !22_S	et	f	\N
116201	tööhüpoteesi	tööhüpoteesi =teesi  (SgAdt  >töö+hüpo+tees !22_S	et	f	\N
116202	tööhüpoteesi	tööhüpoteesi =hüpoteesi  (SgG  >töö+hüpotees !22_S	et	f	\N
116203	tööhüpoteesi	tööhüpoteesi =hüpoteesi  (SgP  >töö+hüpotees !22_S	et	f	\N
116204	tööhüpoteesi	tööhüpoteesi =hüpoteesi  (SgAdt  >töö+hüpotees !22_S	et	f	\N
116208	õpilaste	õpilaste =õpilas  (PlG  >õpilane !12_S	et	f	\N
116210	õpilaste	õpilaste =las  (PlG  >õpi+laps !14_S	et	f	\N
116212	õpilaste	õpilaste =laste  (PlP  >õpi+last !22_S	et	f	\N
116217	hüpoteesi	hüpoteesi =hüpoteesi  (SgG  >hüpotees !22_S	et	f	\N
116218	hüpoteesi	hüpoteesi =hüpoteesi  (SgP  >hüpotees !22_S	et	f	\N
116219	hüpoteesi	hüpoteesi =hüpoteesi  (SgAdt  >hüpotees !22_S	et	f	\N
116226	arusaamiseks	arusaamiseks =saamise  (SgTr  >aru+saamine !12?10_S	et	f	\N
116227	arusaamiseks	"aru+saamine %saami  )NE_aA  <aru+saam ;22_S	et	f	\N
116235	seisnud	seisnud =seis  (PtsPtPs  >seisma !32_V	et	f	\N
116236	seisnud	seisnud =seisnu  (PlN  >seisnu !01_S	et	f	\N
116237	seisnud	"seisnu %seis  )NU_vS  <seisma ;32_V	et	f	\N
116238	seisnud	seisnud =seisnud  (ID  >seisnud !41_A	et	f	\N
116239	seisnud	"seisnud %seis  )NUD_vA  <seisma ;32_V	et	f	\N
116246	pii	pii =pii  (SgN  >pii !26_S	et	f	\N
116248	pii	pii =pii  (SgG  >pii !26_S	et	f	\N
116250	määranud	määranud =määra  (PtsPtPs  >määrama !29_V	et	f	\N
116251	määranud	määranud =määranu  (PlN  >määranu !01_S	et	f	\N
116252	määranud	"määranu %määra  )NU_vS  <määrama ;29_V	et	f	\N
116253	määranud	määranud =määranud  (ID  >määranud !41_A	et	f	\N
116254	määranud	"määranud %määra  )NUD_vA  <määrama ;29_V	et	f	\N
116261	mõistmiseks	mõistmiseks =mõistmise  (SgTr  >mõistmine !12?10_S	et	f	\N
116262	mõistmiseks	"mõistmine %mõist  )MINE_vS  <mõistma ;34_V	et	f	\N
116276	keeruline	keeruline =keeruline  (SgN  >keeruline !12_A	et	f	\N
116277	keeruline	"keeruline %keeru  )LINE_aA  <keerd ;22_SA	et	f	\N
116287	kõrg-eesti	kõrg-eesti =eesti  (ID  >kõrg-eesti !41_G	et	f	\N
116288	kõrg-eesti	kõrg-eesti =eesti  (SgN  >kõrg-eesti !16_H	et	f	\N
116289	kõrg-eesti	kõrg-eesti =eesti  (SgG  >kõrg-eesti !16_H	et	f	\N
116302	erinevus	erinevus =erinevus  (SgN  >erinevus !11?09_S	et	f	\N
116303	erinevus	"erinevus %erine  )VUS_aS  <erinema ;27_V	et	f	\N
116305	erinevus	"erinevus %erineva  )US_aS  <erinev ;02_A	et	f	\N
116314	üleminekuala	üleminekuala =ala  (SgN  >üle+mineku+ala !17_S	et	f	\N
116315	üleminekuala	üleminekuala =ala  (SgG  >üle+mineku+ala !17_S	et	f	\N
116316	üleminekuala	üleminekuala =ala  (SgP  >üle+mineku+ala !17_S	et	f	\N
116318	geograafiliselt	geograafiliselt =geograafilise  (SgAbl  >geograafiline !12_A	et	f	\N
116320	geograafiliselt	"geograafiline %geograafi  )LINE_aA  <geograaf ;22_S	et	f	\N
116321	geograafiliselt	geograafiliselt =geograafiliselt  (ID  >geograafiliselt !41_D	et	f	\N
116322	geograafiliselt	"geograafiliselt %geograafi  )LISELT_mD  <geograaf ;22_S	et	f	\N
116323	geograafiliselt	"geograafiliselt %geograafilise  )LT_mD  <geograafiline ;12_A	et	f	\N
116324	geograafiliselt	geograafiliselt =graafilise  (SgAbl  >geo+graafiline !12_A	et	f	\N
116325	geograafiliselt	"geo+graafiline %graafi  )LINE_aA  <geo+graaf ;22_S	et	f	\N
116326	geograafiliselt	"geo+graafiliselt %graafi  )LISELT_mD  <geo+graaf ;22_S	et	f	\N
116327	geograafiliselt	"geo+graafiliselt %graafilise  )LT_mD  <geo+graafiline ;12_A	et	f	\N
116333	puhul	puhul =puhu  (SgAd  >puhk !22_S	et	f	\N
116334	puhul	puhul =puhul  (ID  >puhul !41_DK	et	f	\N
116341	mitmetele	mitmetele =mitme  (PlAll  >mitu !05_P	et	f	\N
116342	mitmetele	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
116345	mõjutustele	mõjutustele =mõjutus  (PlAll  >mõjutus !11_S	et	f	\N
116346	mõjutustele	"mõjutus %mõjuta  )US_vS  <mõjutama ;27_V	et	f	\N
116347	mõjutustele	"mõjutus %mõju  )TUS1_aS  <mõjuma ;27_V	et	f	\N
116348	mõjutustele	"mõjutus %mõju  )TUS2_aS  <mõju ;17_S	et	f	\N
116349	mõjutustele	mõjutustele =tuste  (PlAll  >mõju+tust !22_S	et	f	\N
116124	filoloogia	filoloogia =filoloogia  (SgN  >filoloogia !01_S	et	f	\N
116125	filoloogia	filoloogia =filoloogia  (SgG  >filoloogia !01_S	et	f	\N
116137	riigiõppekava	riigiõppekava =kava  (SgN  >riigi+õppe+kava !17_S	et	f	\N
116138	riigiõppekava	riigiõppekava =kava  (SgG  >riigi+õppe+kava !17_S	et	f	\N
116139	riigiõppekava	riigiõppekava =kava  (SgP  >riigi+õppe+kava !17_S	et	f	\N
116141	lütseumi	lütseumi =lütseumi  (SgG  >lütseum !19~02_S	et	f	\N
116142	lütseumi	lütseumi =lütseumi  (SgP  >lütseum !19_S	et	f	\N
116143	lütseumi	lütseumi =lütseumi  (SgAdt  >lütseum !19_S	et	f	\N
116151	lk20	### lk20	et	f	\N
116196	raskusi	raskusi =raskusi  (PlP  >raskus !11_S	et	f	\N
116197	raskusi	"raskus %raske  )US_aS  <raske ;01_A	et	f	\N
116198	raskusi	raskusi =raskusi  (PlP  >raskune !12_A	et	f	\N
116205	kaitsta	kaitsta =kaits  (Inf  >kaitsma !32_V	et	f	\N
116206	kaitsta	kaitsta =kaits  (IndPrIps_  >kaitsma !32_V	et	f	\N
116207	näitavad	näitavad =näita  (IndPrPl3  >näitama !29_V	et	f	\N
116209	näitavad	näitavad =näitava  (PlN  >näitav !02_A	et	f	\N
116211	näitavad	"näitav %näita  )V_vA  <näitama ;29_V	et	f	\N
116213	näitavad	näitavad =ava  (PlN  >näit+ava !17_S	et	f	\N
116228	mõnda	mõnda =mõn  (SgAdt  >mõni !20_P	et	f	\N
116231	mõnda	mõnda =mõn  (SgP  >mõni !20_P	et	f	\N
116256	iseloomustavad	iseloomustavad =ava  (PlN  >ise+loo+must+ava !17_S	et	f	\N
116258	iseloomustavad	iseloomustavad =ustava  (PlN  >ise+loom+ustav !02_A	et	f	\N
116259	iseloomustavad	iseloomustavad =mustava  (PlN  >ise+loo+mustav !02_A	et	f	\N
116260	iseloomustavad	iseloomustavad =loomustava  (PlN  >ise+loomustav !02_A	et	f	\N
116309	kõrg-	?kõrg- =kõrg  (SgN  >kõrg !22_S	et	f	\N
116361	põhja-eesti	põhja-eesti =eesti  (ID  >põhja-eesti !41_G	et	f	\N
116362	põhja-eesti	põhja-eesti =eesti  (SgN  >põhja-eesti !16_H	et	f	\N
116363	põhja-eesti	põhja-eesti =eesti  (SgG  >põhja-eesti !16_H	et	f	\N
116364	uuendustele	uuendustele =uuendus  (PlAll  >uuendus !11_S	et	f	\N
116365	uuendustele	"uuendus %uuenda  )US_vS  <uuendama ;27_V	et	f	\N
116400	tunnuslikumaks	tunnuslikumaks =tunnuslikuma  (SgTr  >tunnuslikum !02_A	et	f	\N
116401	tunnuslikumaks	"tunnuslikum %tunnusliku  )M_cA  <tunnuslik ;25_A	et	f	\N
116406	regivärsilist	regivärsilist =värsilis  (SgP  >regi+värsiline !12_A	et	f	\N
116407	regivärsilist	"regi+värsiline %värsi  )LINE_aA  <regi+värss ;22_S	et	f	\N
116408	hapendatud	hapendatud =hapenda  (PtsPtIps  >hapendama !27_V	et	f	\N
116409	hapendatud	hapendatud =hapendatu  (PlN  >hapendatu !01_S	et	f	\N
116410	hapendatud	"hapendatu %hapenda  )TU1_vS  <hapendama ;27_V	et	f	\N
116411	hapendatud	hapendatud =hapendatud  (ID  >hapendatud !41_A	et	f	\N
116415	hapendatud	"hapendatud %hapenda  )TUD_vA  <hapendama ;27_V	et	f	\N
116428	ajaloolisest	ajaloolisest =loolise  (SgEl  >aja+looline !12?10_A	et	f	\N
116431	ajaloolisest	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
116432	ajaloolisest	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
116433	ajaloolisest	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
116434	ajaloolisest	ajaloolisest =loolise  (SgEl  >aja+looline !12?10_S	et	f	\N
116442	usu	usu =usu  (SgG  >usk !22_S	et	f	\N
116443	usu	usu =usu  (IndPrPs_  >uskuma !28_V	et	f	\N
116444	usu	usu =usu  (ImpPrSg2  >uskuma !28_V	et	f	\N
116450	trükisõna	trükisõna =sõna  (SgN  >trüki+sõna !17_S	et	f	\N
116451	trükisõna	trükisõna =sõna  (SgG  >trüki+sõna !17_S	et	f	\N
116452	trükisõna	trükisõna =sõna  (SgP  >trüki+sõna !17_S	et	f	\N
116461	pärimuse	pärimuse =pärimuse  (SgG  >pärimus !11_S	et	f	\N
116463	pärimuse	"pärimus %päri  )MUS_vS  <pärima ;27_V	et	f	\N
116492	vahendajateks	vahendajateks =vahendaja  (PlTr  >vahendaja !01_S	et	f	\N
116493	vahendajateks	"vahendaja %vahenda  )JA_vS  <vahendama ;27_V	et	f	\N
116510	12riigiõppekava	riigiõppekava =kava  (SgN  >riigi+õppe+kava !17_S	et	f	\N
116511	12riigiõppekava	riigiõppekava =kava  (SgG  >riigi+õppe+kava !17_S	et	f	\N
116512	12riigiõppekava	riigiõppekava =kava  (SgP  >riigi+õppe+kava !17_S	et	f	\N
116515	rahvapärimust	rahvapärimust =must  (SgN  >rahva+päri+must !22_AS	et	f	\N
116516	rahvapärimust	rahvapärimust =pärimus  (SgP  >rahva+pärimus !11_S	et	f	\N
116519	valitud	valitud =vali  (PtsPtIps  >valima !27_V	et	f	\N
116520	valitud	valitud =valitu  (PlN  >valitu !01_S	et	f	\N
116521	valitud	"valitu %vali  )TU1_vS  <valima ;27_V	et	f	\N
116523	valitud	valitud =valitud  (ID  >valitud !41_A	et	f	\N
116525	valitud	"valitud %vali  )TUD_vA  <valima ;27_V	et	f	\N
116534	vabalt	vabalt =vaba  (SgAbl  >vaba !17_A	et	f	\N
116536	vabalt	vabalt =vabalt  (ID  >vabalt !41_D	et	f	\N
116537	vabalt	"vabalt %vaba  )LT_mD  <vaba ;17_A	et	f	\N
116607	ainekava	ainekava =kava  (SgN  >aine+kava !17_S	et	f	\N
116608	ainekava	ainekava =kava  (SgG  >aine+kava !17_S	et	f	\N
116609	ainekava	ainekava =kava  (SgP  >aine+kava !17_S	et	f	\N
116618	kodukoha	kodukoha =koha  (SgN  >kodu+koha !17_S	et	f	\N
116619	kodukoha	kodukoha =koha  (SgG  >kodu+koha !17_S	et	f	\N
116620	kodukoha	kodukoha =koha  (SgG  >kodu+koht !22_S	et	f	\N
116622	kodukoha	kodukoha =koha  (SgP  >kodu+koha !17_S	et	f	\N
116625	laienevad	laienevad =laiene  (IndPrPl3  >laienema !27_V	et	f	\N
116168	koolisma	?koolisma =koolisma  (SgG  >koolisma !01_S	et	f	\N
116169	koolisma	?koolisma =isma  (SgN  >kool+isma !16_S	et	f	\N
116170	koolisma	?koolisma =isma  (SgG  >kool+isma !16_S	et	f	\N
116171	samas	samas =sama  (SgIn  >sama !17_P	et	f	\N
116172	samas	samas =samas  (ID  >samas !41_D	et	f	\N
116177	seonduvad	seonduvad =seondu  (IndPrPl3  >seonduma !27_V	et	f	\N
116178	seonduvad	seonduvad =seonduva  (PlN  >seonduv !02_A	et	f	\N
116179	seonduvad	"seonduv %seondu  )V_vA  <seonduma ;27_V	et	f	\N
116220	õpetamist	õpetamist =õpetamis  (SgP  >õpetamine !12_S	et	f	\N
116221	õpetamist	"õpetamine %õpeta  )MINE_vS  <õpetama ;27_V	et	f	\N
116240	aastatuhandeid	?aastatuhandeid =aastatuhandei  (PlN  >aastatuhandei !26_S	et	f	\N
116241	aastatuhandeid	?aastatuhandeid =aastatuhandei  (SgP  >aastatuhandei !26_S	et	f	\N
116242	aastatuhandeid	?aastatuhandeid =tuhande  (PlP  >aasta+tuhandi !01_S	et	f	\N
116243	aastatuhandeid	?aastatuhandeid =tuhandei  (PlN  >aasta+tuhandei !26_S	et	f	\N
116244	aastatuhandeid	?aastatuhandeid =tuhandei  (SgP  >aasta+tuhandei !26_S	et	f	\N
116245	aastatuhandeid	?aastatuhandeid =tatuhandei  (PlN  >aas+tatuhandei !26_S	et	f	\N
116247	aastatuhandeid	?aastatuhandeid =tatuhandei  (SgP  >aas+tatuhandei !26_S	et	f	\N
116263	väikese	väikese =väikese  (SgG  >väike !12?10_A	et	f	\N
116264	väikese	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
116265	väikese	väikese =väikese  (SgG  >väikene !12?10_A	et	f	\N
116266	väikese	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
116270	seisusest	seisusest =seisuse  (SgEl  >seisus !11~09_S	et	f	\N
116271	seisusest	seisusest =seisuses  (SgP  >seisusene !12_A	et	f	\N
116273	seisusest	"seisusene %seisuse  )NE_aA  <seisus ;09_S	et	f	\N
116274	seisusest	"seisusene %seisuse  )NE_aA  <seisus ;11_S	et	f	\N
116278	mitmekihiline	mitmekihiline =kihiline  (SgN  >mitme+kihiline !12_A	et	f	\N
116280	mitmekihiline	"mitme+kihiline %kihi  )LINE_aA  <mitme+kiht ;22_S	et	f	\N
116290	põhja-	põhja- =põhja  (SgG  >põhi !24_S	et	f	\N
116291	põhja-	põhja- =põhja  (SgP  >põhi !24_S	et	f	\N
116292	põhja-	põhja- =põhja  (SgAdt  >põhi !24_S	et	f	\N
116293	põhja-	põhja- =põhja  (IndPrPs_  >põhjama !29_V	et	f	\N
116294	põhja-	põhja- =põhja  (ImpPrSg2  >põhjama !29_V	et	f	\N
116304	esiajaloolisest	esiajaloolisest =loolise  (SgEl  >esi+aja+looline !12?10_A	et	f	\N
116306	esiajaloolisest	"esi+aja+looline %loo  )LINE_aA  <esi+aja+lugu ;18_S	et	f	\N
116307	esiajaloolisest	"esi+aja+looline %loo  )LINE_aA  <esi+aja+loog ;22_S	et	f	\N
116308	esiajaloolisest	"esi+aja+looline %loo  )LINE_aA  <esi+aja+lood ;22_S	et	f	\N
116310	esiajaloolisest	esiajaloolisest =loolise  (SgEl  >esi+aja+looline !12?10_S	et	f	\N
116330	sünni	sünni =sünni  (SgG  >sünd !22_S	et	f	\N
116331	sünni	sünni =sünni  (IndPrPs_  >sündima !28_V	et	f	\N
116332	sünni	sünni =sünni  (ImpPrSg2  >sündima !28_V	et	f	\N
116335	eeldustest	eeldustest =eeldus  (PlEl  >eeldus !11~09_S	et	f	\N
116336	eeldustest	"eeldus %eelda  )US_vS  <eeldama ;27_V	et	f	\N
116337	eeldustest	eeldustest =duste  (PlEl  >eel+dust !22_S	et	f	\N
116343	skandinaavia	?skandinaavia =skandinaavia  (SgN  >skandinaavia !01_S	et	f	\N
116344	skandinaavia	?skandinaavia =skandinaavia  (SgG  >skandinaavia !01_S	et	f	\N
116366	keskendus	keskendus =keskendu  (IndIpfSg3  >keskenduma !27_V	et	f	\N
116367	keskendus	keskendus =keskendus  (SgN  >keskendus !11_S	et	f	\N
116368	keskendus	"keskendus %keskenda  )US_vS  <keskendama ;27_V	et	f	\N
116369	areneva	areneva =areneva  (SgG  >arenev !02_A	et	f	\N
116371	areneva	"arenev %arene  )V_vA  <arenema ;27_V	et	f	\N
116387	teisekeelseks	teisekeelseks =seks  (SgN  >teise+keel+seks !22_S	et	f	\N
116388	teisekeelseks	teisekeelseks =keelse  (SgTr  >teise+keelne !02_A	et	f	\N
116389	erinevustest	erinevustest =erinevus  (PlEl  >erinevus !11?09_S	et	f	\N
116390	erinevustest	"erinevus %erine  )VUS_aS  <erinema ;27_V	et	f	\N
116392	erinevustest	"erinevus %erineva  )US_aS  <erinev ;02_A	et	f	\N
116422	lugemine	lugemine =lugemine  (SgN  >lugemine !12_S	et	f	\N
116423	lugemine	"lugemine %luge  )MINE_vS  <lugema ;28_V	et	f	\N
116425	lugemine	"lugemine %lugemi  )NE_aA  <lugem ;02_S	et	f	\N
116435	eristatavad	eristatavad =eristatava  (PlN  >eristatav !02_A	et	f	\N
116436	eristatavad	"eristatav %erista  )TAV_vAS  <eristama ;27_V	et	f	\N
116448	lõi	lõi =lõ  (IndIpfSg3  >looma !38_V	et	f	\N
116449	lõi	lõi =lõ  (IndIpfSg3  >lööma !38_V	et	f	\N
116464	murenemises	murenemises =murenemise  (SgIn  >murenemine !12_S	et	f	\N
116466	murenemises	"murenemine %murene  )MINE_vS  <murenema ;27_V	et	f	\N
116496	õnnestus	õnnestus =õnnestu  (IndIpfSg3  >õnnestuma !27_V	et	f	\N
116497	õnnestus	õnnestus =õnnestus  (SgN  >õnnestus !11_S	et	f	\N
116499	õnnestus	"õnnestus %õnnesta  )US_vS  <õnnestama ;27_V	et	f	\N
116500	ühte	ühte =ühte  (ID  >ühte !41_D	et	f	\N
116501	ühte	ühte =ühte  (SgG  >ühe !06_S	et	f	\N
116502	ühte	ühte =ühte  (SgP  >üks !22_NP	et	f	\N
116503	ühte	ühte =ühte  (SgAdt  >üks !22_NP	et	f	\N
116513	rahvapärimust	rahvapärimust =must  (SgN  >rahva+päri+must !22_AS	et	f	\N
116514	rahvapärimust	rahvapärimust =pärimus  (SgP  >rahva+pärimus !11_S	et	f	\N
116539	rahvapärimusest	rahvapärimusest =pärimuse  (SgEl  >rahva+pärimus !11_S	et	f	\N
116374	lähedus	lähedus =lähedus  (SgN  >lähedus !11_S	et	f	\N
116375	lähedus	"lähedus %läheda  )US_aS  <läheda ;02_A	et	f	\N
116380	suhtes	suhtes =suhte  (SgIn  >suhe !06_S	et	f	\N
116383	suhtes	suhtes =suhtes  (ID  >suhtes !41_K	et	f	\N
116391	hoolimata	hoolimata =hooli  (SupAb  >hoolima !28_V	et	f	\N
116393	hoolimata	hoolimata =hoolimata  (ID  >hoolimata !41_K	et	f	\N
116394	hoolimata	"hoolimata %hooli  )MATA_vA  <hoolima ;28_V	et	f	\N
116395	hoolimata	hoolimata =lima  (SgAb  >hoo+lima !17_S	et	f	\N
116396	tervikuks	tervikuks =terviku  (SgTr  >tervik !02_S	et	f	\N
116397	tervikuks	tervikuks =uks  (SgN  >tervik+uks !14_S	et	f	\N
116413	ühine	ühine =ühine  (SgN  >ühine !10_A	et	f	\N
116416	ühine	ühine =ühine  (IndPrPs_  >ühinema !27_V	et	f	\N
116417	ühine	ühine =ühine  (ImpPrSg2  >ühinema !27_V	et	f	\N
116418	pulma-	pulma- =pulma  (SgG  >pulm !22_S	et	f	\N
116419	pulma-	pulma- =pulma  (SgP  >pulm !22_S	et	f	\N
116420	pulma-	pulma- =pulma  (SgAdt  >pulm !22_S	et	f	\N
116421	jõulukombestikust	jõulukombestikust =kombestiku  (SgEl  >jõulu+kombestik !25_S	et	f	\N
116424	jõulukombestikust	jõulukombestikust =kombestikus  (SgP  >jõulu+kombestikune !10?12_A	et	f	\N
116426	jõulukombestikust	"jõulu+kombestikune %kombestiku  )NE_aA  <jõulu+kombestik ;25_S	et	f	\N
116458	suulise	suulise =suulise  (SgG  >suuline !12?10_AS	et	f	\N
116459	suulise	"suuline %suu  )LINE_aA  <suu ;26_S	et	f	\N
116472	pööre	pööre =pööre  (SgN  >pööre !05_S	et	f	\N
116474	pööre	pööre =pööre  (SgN  >pööre !06_S	et	f	\N
116476	pööre	pööre =pööre  (PlP  >pöör !22_S	et	f	\N
116485	vastastikuseid	vastastikuseid =vastastikuse  (PlP  >vastastikune !10_A	et	f	\N
116487	vastastikuseid	vastastikuseid =astikuse  (PlP  >vast+astikune !10_A	et	f	\N
116489	vastastikuseid	"vast+astikune %astiku  )NE_aA  <vast+astik ;02_S	et	f	\N
116494	eestlastel	eestlastel =eestlas  (PlAd  >eestlane !12?10_S	et	f	\N
116495	eestlastel	eestlastel =las  (PlAd  >eest+laps !14_S	et	f	\N
116498	eestlastel	eestlastel =laste  (PlAd  >eest+last !22_S	et	f	\N
116504	saabunud	saabunud =saabu  (PtsPtPs  >saabuma !27_V	et	f	\N
116505	saabunud	saabunud =saabunu  (PlN  >saabunu !01_S	et	f	\N
116506	saabunud	"saabunu %saabu  )NU_vS  <saabuma ;27_V	et	f	\N
116507	saabunud	saabunud =saabunud  (ID  >saabunud !41_A	et	f	\N
116508	saabunud	"saabunud %saabu  )NUD_vA  <saabuma ;27_V	et	f	\N
116544	määratletud	määratletud =määratle  (PtsPtIps  >määratlema !27_V	et	f	\N
116545	määratletud	määratletud =määratletu  (PlN  >määratletu !01_S	et	f	\N
116546	määratletud	"määratletu %määratle  )TU1_vS  <määratlema ;27_V	et	f	\N
116547	määratletud	määratletud =määratletud  (ID  >määratletud !41_A	et	f	\N
116548	määratletud	"määratletud %määratle  )TUD_vA  <määratlema ;27_V	et	f	\N
116585	kasvatustegevuse	kasvatustegevuse =tegevuse  (SgG  >kasvatus+tegevus !11_S	et	f	\N
116586	kasvatustegevuse	"kasvatus+tegevus %tegeva  )US_aS  <kasvatus+tegev ;02_A	et	f	\N
116587	omandatavad	omandatavad =omandatava  (PlN  >omandatav !02_A	et	f	\N
116589	omandatavad	"omandatav %omanda  )TAV_vAS  <omandama ;27_V	et	f	\N
116594	tunnijaotusplaani	tunnijaotusplaani =plaani  (SgG  >tunni+jaotus+plaan !22_S	et	f	\N
116595	tunnijaotusplaani	tunnijaotusplaani =plaani  (SgP  >tunni+jaotus+plaan !22_S	et	f	\N
116596	tunnijaotusplaani	tunnijaotusplaani =plaani  (SgAdt  >tunni+jaotus+plaan !22_S	et	f	\N
116616	kadri-	kadri- =kadri  (SgN  >kadri !16_S	et	f	\N
116617	kadri-	kadri- =kadri  (SgG  >kadri !16_S	et	f	\N
116621	eripära	eripära =pära  (SgN  >eri+pära !17_S	et	f	\N
116623	eripära	eripära =pära  (SgG  >eri+pära !17_S	et	f	\N
116624	eripära	eripära =pära  (SgP  >eri+pära !17_S	et	f	\N
116628	vaatamisväärsused	vaatamisväärsused =väärsuse  (PlN  >vaatamis+väärsus !11~09_S	et	f	\N
116629	vaatamisväärsused	"vaatamis+väärsus %väärse  )US_aS  <vaatamis+väärne ;02_A	et	f	\N
116647	6klassi	klassi =klassi  (SgG  >klass !22_S	et	f	\N
116649	6klassi	klassi =klassi  (SgP  >klass !22_S	et	f	\N
116650	6klassi	klassi =klassi  (SgAdt  >klass !22_S	et	f	\N
116674	katked	katked =katke  (PlN  >katke !06_S	et	f	\N
116676	katked	katked =katke  (IndPrSg2  >katkema !27_V	et	f	\N
116712	õpetamiseks	õpetamiseks =õpetamise  (SgTr  >õpetamine !12_S	et	f	\N
116713	õpetamiseks	"õpetamine %õpeta  )MINE_vS  <õpetama ;27_V	et	f	\N
116714	kavandatud	kavandatud =kavanda  (PtsPtIps  >kavandama !27_V	et	f	\N
116715	kavandatud	kavandatud =kavandatu  (PlN  >kavandatu !01_S	et	f	\N
116716	kavandatud	"kavandatu %kavanda  )TU1_vS  <kavandama ;27_V	et	f	\N
116717	kavandatud	kavandatud =kavandatud  (ID  >kavandatud !41_A	et	f	\N
116718	kavandatud	"kavandatud %kavanda  )TUD_vA  <kavandama ;27_V	et	f	\N
116729	kirjandusest	kirjandusest =kirjanduse  (SgEl  >kirjandus !11_S	et	f	\N
116731	kirjandusest	kirjandusest =kirjanduses  (SgP  >kirjandusene !12_A	et	f	\N
116735	kirjandusest	"kirjandusene %kirjanduse  )NE_aA  <kirjandus ;11_S	et	f	\N
116742	ii	?ii =ii  (SgN  >ii !26_S	et	f	\N
116743	ii	?ii =ii  (SgG  >ii !26_S	et	f	\N
116762	kirjakeele	kirjakeele =kee  (SgAll  >kirja+kesi !15_S	et	f	\N
116765	kirjakeele	kirjakeele =kee  (SgAll  >kirja+kee !26_S	et	f	\N
116766	kirjakeele	kirjakeele =keele  (SgG  >kirja+keel !13_S	et	f	\N
116399	liitsid	liitsid =liit  (IndIpfPl3  >liitma !34_V	et	f	\N
116405	rehielamut	### rehielamut	et	f	\N
116412	rukkileiba	rukkileiba =leiba  (SgP  >rukki+leib !22_S	et	f	\N
116414	rukkileiba	rukkileiba =leiba  (SgAdt  >rukki+leib !22_S	et	f	\N
116427	vaatevinklist	vaatevinklist =vinkli  (SgEl  >vaate+vinkel !02_S	et	f	\N
116429	vaatevinklist	vaatevinklist =vinklis  (SgP  >vaate+vinkline !12~10_A	et	f	\N
116430	vaatevinklist	"vaate+vinkline %vinkli  )NE_aA  <vaate+vinkel ;02_S	et	f	\N
116437	murranguperioodi	murranguperioodi =perioodi  (SgG  >murrangu+periood !22_S	et	f	\N
116438	murranguperioodi	murranguperioodi =perioodi  (SgP  >murrangu+periood !22_S	et	f	\N
116439	murranguperioodi	murranguperioodi =perioodi  (SgAdt  >murrangu+periood !22_S	et	f	\N
116440	vallutustega	vallutustega =vallutus  (PlKom  >vallutus !11_S	et	f	\N
116441	vallutustega	"vallutus %valluta  )US_vS  <vallutama ;27_V	et	f	\N
116445	linnakultuuri	linnakultuuri =kultuuri  (SgG  >linna+kultuur !22_S	et	f	\N
116446	linnakultuuri	linnakultuuri =kultuuri  (SgP  >linna+kultuur !22_S	et	f	\N
116447	linnakultuuri	linnakultuuri =kultuuri  (SgAdt  >linna+kultuur !22_S	et	f	\N
116456	olulist	olulist =olulis  (SgP  >oluline !12_A	et	f	\N
116457	olulist	"oluline %olu  )LINE_aA  <olu ;17_S	et	f	\N
116480	leidis	leidis =leid  (IndIpfSg3  >leidma !34_V	et	f	\N
116481	leidis	leidis =leidis  (SgN  >leidis !09_S	et	f	\N
116482	rahvakultuuri	rahvakultuuri =kultuuri  (SgG  >rahva+kultuur !22_S	et	f	\N
116483	rahvakultuuri	rahvakultuuri =kultuuri  (SgP  >rahva+kultuur !22_S	et	f	\N
116484	rahvakultuuri	rahvakultuuri =kultuuri  (SgAdt  >rahva+kultuur !22_S	et	f	\N
116486	mõjutusi	mõjutusi =mõjutusi  (PlP  >mõjutus !11_S	et	f	\N
116488	mõjutusi	"mõjutus %mõjuta  )US_vS  <mõjutama ;27_V	et	f	\N
116490	mõjutusi	"mõjutus %mõju  )TUS1_aS  <mõjuma ;27_V	et	f	\N
116491	mõjutusi	"mõjutus %mõju  )TUS2_aS  <mõju ;17_S	et	f	\N
116517	õpetatava	õpetatava =õpetatava  (SgG  >õpetatav !02_A	et	f	\N
116518	õpetatava	"õpetatav %õpeta  )TAV_vAS  <õpetama ;27_V	et	f	\N
116542	selliste	selliste =sellis  (PlG  >selline !10_P	et	f	\N
116543	selliste	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
116549	piisav	piisav =piisa  (PtsPrPs  >piisama !29_V	et	f	\N
116550	piisav	piisav =piisav  (SgN  >piisav !02_A	et	f	\N
116551	piisav	"piisav %piisa  )V_vA  <piisama ;29_V	et	f	\N
116552	lootagi	lootagi =tagi  (SgN  >loo+tagi !17_S	et	f	\N
116553	lootagi	lootagi =tagi  (SgG  >loo+tagi !17_S	et	f	\N
116554	lootagi	lootagi =tagi  (SgP  >loo+tagi !17_S	et	f	\N
116555	lootagi	lootagi =loo  (SgAb^  >lugu !18_S	et	f	\N
116556	lootagi	lootagi =loo  (SgAb^  >loog !22_S	et	f	\N
116559	lootagi	lootagi =loo  (SgAb^  >lood !22_S	et	f	\N
116561	lootagi	lootagi =loot  (Inf^  >lootma !34_V	et	f	\N
116563	punktiks	punktiks =punkti  (SgTr  >punkt !22_S	et	f	\N
116565	punktiks	punktiks =punkti  (KndPrPs  >punktima !28_V	et	f	\N
116566	punktiks	punktiks =iks  (SgN  >punkt+iks !22_S	et	f	\N
116567	punktiks	punktiks =tiks  (SgN  >punk+tiks !22_S	et	f	\N
116583	õppe-	õppe- =õppe  (SgG  >õpe !06_S	et	f	\N
116584	õppe-	õppe- =õppe  (PlP  >õpp !22_S	et	f	\N
116588	pädevused	pädevused =pädevuse  (PlN  >pädevus !11_S	et	f	\N
116590	pädevused	"pädevus %pädeva  )US_aS  <pädev ;02_A	et	f	\N
116610	üldandmedrahvussümbolikarahvuslindlillpuu	?üldandmedrahvussümbolikarahvuslindlillpuu =üldandmedrahvussümbolikarahvuslindlillpuu  (SgN  >üldandmedrahvussümbolikarahvuslindlillpuu !26_S	et	f	\N
116611	üldandmedrahvussümbolikarahvuslindlillpuu	?üldandmedrahvussümbolikarahvuslindlillpuu =üldandmedrahvussümbolikarahvuslindlillpuu  (SgG  >üldandmedrahvussümbolikarahvuslindlillpuu !26_S	et	f	\N
116612	üldandmedrahvussümbolikarahvuslindlillpuu	?üldandmedrahvussümbolikarahvuslindlillpuu =drahvussümbolikarahvuslindlillpuu  (SgN  >üld+andme+drahvussümbolikarahvuslindlillpuu !26_S	et	f	\N
116613	üldandmedrahvussümbolikarahvuslindlillpuu	?üldandmedrahvussümbolikarahvuslindlillpuu =drahvussümbolikarahvuslindlillpuu  (SgG  >üld+andme+drahvussümbolikarahvuslindlillpuu !26_S	et	f	\N
116614	üldandmedrahvussümbolikarahvuslindlillpuu	?üldandmedrahvussümbolikarahvuslindlillpuu =andmedrahvussümbolikarahvuslindlillpuu  (SgN  >üld+andmedrahvussümbolikarahvuslindlillpuu !26_S	et	f	\N
116615	üldandmedrahvussümbolikarahvuslindlillpuu	?üldandmedrahvussümbolikarahvuslindlillpuu =andmedrahvussümbolikarahvuslindlillpuu  (SgG  >üld+andmedrahvussümbolikarahvuslindlillpuu !26_S	et	f	\N
116641	lippvapphümneesti	?lippvapphümneesti =lippvapphümneesti  (ID  >lippvapphümneesti !41_D	et	f	\N
116642	lippvapphümneesti	?lippvapphümneesti =lippvapphümneesti  (IndPrPs_  >lippvapphümneestima !28_V	et	f	\N
116644	lippvapphümneesti	?lippvapphümneesti =lippvapphümneesti  (ImpPrSg2  >lippvapphümneestima !28_V	et	f	\N
116651	lõpetaja	lõpetaja =lõpetaja  (SgN  >lõpetaja !01_S	et	f	\N
116652	lõpetaja	"lõpetaja %lõpeta  )JA_vS  <lõpetama ;27_V	et	f	\N
116653	lõpetaja	lõpetaja =lõpetaja  (SgG  >lõpetaja !01_S	et	f	\N
116662	üritusi	üritusi =üritusi  (PlP  >üritus !11_S	et	f	\N
116663	üritusi	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
116675	noorsookirjandusest	noorsookirjandusest =kirjanduse  (SgEl  >noor+soo+kirjandus !11_S	et	f	\N
116677	noorsookirjandusest	noorsookirjandusest =kirjanduses  (SgP  >noor+soo+kirjandusene !12_A	et	f	\N
116678	noorsookirjandusest	"noor+soo+kirjandusene %kirjanduse  )NE_aA  <noor+soo+kirjandus ;11_S	et	f	\N
116688	jõukohast	jõukohast =koha  (SgEl  >jõu+koha !17_S	et	f	\N
116690	jõukohast	jõukohast =koha  (SgEl  >jõu+koht !22_S	et	f	\N
116455	aluse	"alune %alu  )NE_aA  <alg ;22_S	et	f	\N
116460	muusikalise	muusikalise =muusikalise  (SgG  >muusikaline !12_A	et	f	\N
116462	muusikalise	"muusikaline %muusika  )LINE_aA  <muusika ;01_S	et	f	\N
116465	muusikalise	"muusikaline %muusikali  )NE_aA  <muusikal ;19_S	et	f	\N
116467	kujunemises	kujunemises =kujunemise  (SgIn  >kujunemine !12_S	et	f	\N
116468	kujunemises	"kujunemine %kujune  )MINE_vS  <kujunema ;27_V	et	f	\N
116469	tõeliselt	tõeliselt =tõelise  (SgAbl  >tõeline !12?10_A	et	f	\N
116470	tõeliselt	"tõeline %tõe  )LINE_aA  <tõsi ;15_S	et	f	\N
116471	tõeliselt	"tõeline %tõe  )LINE_aA  <tõde ;18_S	et	f	\N
116473	tõeliselt	tõeliselt =tõeliselt  (ID  >tõeliselt !41_D	et	f	\N
116475	tõeliselt	"tõeliselt %tõe  )LISELT_mD  <tõsi ;15_S	et	f	\N
116477	tõeliselt	"tõeliselt %tõe  )LISELT_mD  <tõde ;18_S	et	f	\N
116478	tõeliselt	"tõeliselt %tõelise  )LT_mD  <tõeline ;10_A	et	f	\N
116479	tõeliselt	"tõeliselt %tõelise  )LT_mD  <tõeline ;12_A	et	f	\N
116509	httpwwwestonicaorgestluguhtmlmenyyid175kateg5alam19leht1	?httpwwwestonicaorgestluguhtmlmenyyidkategalamleht =httpwwwestonicaorgestluguhtmlmenyyidkategalamleht  (SgN  >httpwwwestonicaorgestluguhtmlmenyyidkategalamleht !22_S	et	f	\N
116522	elamiseks	elamiseks =elamise  (SgTr  >elamine !12_S	et	f	\N
116524	elamiseks	"elamine %ela  )MINE_vS  <elama ;27_V	et	f	\N
116526	õppekava	õppekava =kava  (SgN  >õppe+kava !17_S	et	f	\N
116527	õppekava	õppekava =kava  (SgG  >õppe+kava !17_S	et	f	\N
116528	õppekava	õppekava =kava  (SgP  >õppe+kava !17_S	et	f	\N
116529	oluliseks	oluliseks =olulise  (SgTr  >oluline !12_A	et	f	\N
116530	oluliseks	"oluline %olu  )LINE_aA  <olu ;17_S	et	f	\N
116531	valdamine	valdamine =valdamine  (SgN  >valdamine !12_S	et	f	\N
116532	valdamine	"valdamine %valda  )MINE_vS  <valdama ;29_V	et	f	\N
116533	valdav	valdav =valda  (PtsPrPs  >valdama !29_V	et	f	\N
116535	valdav	valdav =valdav  (SgN  >valdav !02_A	et	f	\N
116538	valdav	"valdav %valda  )V_vA  <valdama ;29_V	et	f	\N
116568	koostatud	koostatud =koosta  (PtsPtIps  >koostama !27_V	et	f	\N
116569	koostatud	koostatud =koostatu  (PlN  >koostatu !01_S	et	f	\N
116570	koostatud	"koostatu %koosta  )TU1_vS  <koostama ;27_V	et	f	\N
116571	koostatud	"koostatu %koosta  )TU2_kA  <koost ;22_S	et	f	\N
116572	koostatud	koostatud =koostatud  (ID  >koostatud !41_A	et	f	\N
116573	koostatud	"koostatud %koosta  )TUD_vA  <koostama ;27_V	et	f	\N
116579	põhikooli	põhikooli =kooli  (SgG  >põhi+kool !22_S	et	f	\N
116580	põhikooli	põhikooli =kooli  (SgP  >põhi+kool !22_S	et	f	\N
116581	põhikooli	põhikooli =kooli  (SgAdt  >põhi+kool !22_S	et	f	\N
116582	põhikooli	põhikooli =kooli  (PlP  >põhi+kool !22_S	et	f	\N
116591	alused	alused =aluse  (PlN  >alus !09_S	et	f	\N
116592	alused	alused =aluse  (PlN  >alune !10_AS	et	f	\N
116593	alused	"alune %alu  )NE_aA  <alg ;22_S	et	f	\N
116599	koostamise	koostamise =koostamise  (SgG  >koostamine !12_S	et	f	\N
116600	koostamise	"koostamine %koosta  )MINE_vS  <koostama ;27_V	et	f	\N
116604	õiguslikust	õiguslikust =õigusliku  (SgEl  >õiguslik !25_A	et	f	\N
116605	õiguslikust	õiguslikust =õiguslikus  (SgP  >õiguslikus !11?09_S	et	f	\N
116606	õiguslikust	"õiguslikus %õigusliku  )US_aS  <õiguslik ;25_A	et	f	\N
116630	kultuuritegelasedraamatukogujutte	?kultuuritegelasedraamatukogujutte =kultuuritegelasedraamatukogujutte  (PlP  >kultuuritegelasedraamatukogujutt !22_S	et	f	\N
116631	kultuuritegelasedraamatukogujutte	?kultuuritegelasedraamatukogujutte =edraamatukogujutte  (PlP  >kultuuri+tegelas+edraamatukogujutt !22_S	et	f	\N
116632	kultuuritegelasedraamatukogujutte	?kultuuritegelasedraamatukogujutte =tegelasedraamatukogujutte  (PlP  >kultuuri+tegelasedraamatukogujutt !22_S	et	f	\N
116633	kultuuritegelasedraamatukogujutte	?kultuuritegelasedraamatukogujutte =itegelasedraamatukogujutte  (PlP  >kultuur+itegelasedraamatukogujutt !22_S	et	f	\N
116634	lastekirjandusestnäited	### lastekirjandusestnäited	et	f	\N
116635	mõistatusest	mõistatusest =mõistatuse  (SgEl  >mõistatus !11_S	et	f	\N
116636	mõistatusest	"mõistatus %mõistata  )US_vS  <mõistatama ;27_V	et	f	\N
116637	mõistatusest	mõistatusest =mõistatuses  (SgP  >mõistatusene !12_A	et	f	\N
116638	mõistatusest	"mõistatusene %mõistatuse  )NE_aA  <mõistatus ;11_S	et	f	\N
116654	eripäraleloodus	eripäraleloodus =loodu  (SgIn  >eri+pärale+loodu !01_S	et	f	\N
116656	eripäraleloodus	eripäraleloodus =loodus  (SgN  >eri+pärale+loodus !11~09_S	et	f	\N
116709	järjestus	järjestus =järjestu  (IndIpfSg3  >järjestuma !27_V	et	f	\N
116710	järjestus	järjestus =järjestus  (SgN  >järjestus !11_S	et	f	\N
116711	järjestus	"järjestus %järjesta  )US_vS  <järjestama ;27_V	et	f	\N
116721	kultuurilugu	kultuurilugu =lugu  (SgN  >kultuuri+lugu !18_S	et	f	\N
116722	kultuurilugu	kultuurilugu =lugu  (SgP  >kultuuri+lugu !18_S	et	f	\N
116734	muusikast	muusikast =muusika  (SgEl  >muusika !01_S	et	f	\N
116736	muusikast	muusikast =muusikas  (SgP  >muusikane !12_A	et	f	\N
116737	muusikast	"muusikane %muusika  )NE_aA  <muusika ;01_S	et	f	\N
116752	soomeugri	?soomeugri =soomeugri  (SgN  >soomeugri !01_S	et	f	\N
116753	soomeugri	?soomeugri =soomeugri  (SgG  >soomeugri !01_S	et	f	\N
116754	soomeugri	?soomeugri =soomeugri  (SgG  >soomeuger !02_S	et	f	\N
116756	soomeugri	?soomeugri =soomeugri  (IndPrPs_  >soomeugrima !28_V	et	f	\N
116758	soomeugri	?soomeugri =soomeugri  (ImpPrSg2  >soomeugrima !28_V	et	f	\N
116540	rahvapärimusest	rahvapärimusest =pärimuses  (SgP  >rahva+pärimusene !12_A	et	f	\N
116541	rahvapärimusest	"rahva+pärimusene %pärimuse  )NE_aA  <rahva+pärimus ;11_S	et	f	\N
116557	maksa	maksa =maksa  (SgG  >maks !22_S	et	f	\N
116558	maksa	maksa =maksa  (SgP  >maks !22_S	et	f	\N
116560	maksa	maksa =maksa  (SgAdt  >maks !22_S	et	f	\N
116562	maksa	maksa =maksa  (IndPrPs_  >maksma !32_V	et	f	\N
116564	maksa	maksa =maksa  (ImpPrSg2  >maksma !32_V	et	f	\N
116574	puudutavad	puudutavad =puuduta  (IndPrPl3  >puudutama !27_V	et	f	\N
116575	puudutavad	puudutavad =puudutava  (PlN  >puudutav !02_A	et	f	\N
116576	puudutavad	"puudutav %puudu  )TAV_vAS  <puuduma ;27_V	et	f	\N
116577	puudutavad	"puudutav %puuduta  )V_vA  <puudutama ;27_V	et	f	\N
116578	puudutavad	puudutavad =tava  (PlN  >puudu+tava !17_S	et	f	\N
116597	lõpetamiseks	lõpetamiseks =lõpetamise  (SgTr  >lõpetamine !12_S	et	f	\N
116598	lõpetamiseks	"lõpetamine %lõpeta  )MINE_vS  <lõpetama ;27_V	et	f	\N
116601	olenemata	olenemata =olene  (SupAb  >olenema !27_V	et	f	\N
116602	olenemata	olenemata =olenemata  (ID  >olenemata !41_A	et	f	\N
116603	olenemata	"olenemata %olene  )MATA_vA  <olenema ;27_V	et	f	\N
116639	tähtpäevadeesti	?tähtpäevadeesti =tähtpäevadeesti  (ID  >tähtpäevadeesti !41_D	et	f	\N
116640	tähtpäevadeesti	?tähtpäevadeesti =tähtpäevadeesti  (IndPrPs_  >tähtpäevadeestima !28_V	et	f	\N
116643	tähtpäevadeesti	?tähtpäevadeesti =tähtpäevadeesti  (ImpPrSg2  >tähtpäevadeestima !28_V	et	f	\N
116645	tähtpäevadeesti	?tähtpäevadeesti =deesti  (SgG  >täht+päeva+deest !22_S	et	f	\N
116646	tähtpäevadeesti	?tähtpäevadeesti =deesti  (SgP  >täht+päeva+deest !22_S	et	f	\N
116648	tähtpäevadeesti	?tähtpäevadeesti =deesti  (SgAdt  >täht+päeva+deest !22_S	et	f	\N
116658	osavõttu	osavõttu =võttu  (SgP  >osa+võtt !22_S	et	f	\N
116659	osavõttu	osavõttu =võttu  (SgAdt  >osa+võtt !22_S	et	f	\N
116667	kontserditel	?kontserditel =kontserdi  (PlAd  >kontserdi !01_S	et	f	\N
116668	kontserditel	?kontserditel =kontserdi  (PlAd  >kontserd !02_S	et	f	\N
116669	kontserditel	?kontserditel =kontserdite  (PlAd  >kontserditt !22_S	et	f	\N
116670	kontserditel	?kontserditel =serdite  (PlAd  >kont+serditt !22_S	et	f	\N
116672	olulised	olulised =olulise  (PlN  >oluline !12_A	et	f	\N
116673	olulised	"oluline %olu  )LINE_aA  <olu ;17_S	et	f	\N
116681	eakohast	eakohast =koha  (SgEl  >ea+koha !17_S	et	f	\N
116682	eakohast	eakohast =koha  (SgEl  >ea+koht !22_S	et	f	\N
116683	eakohast	eakohast =kohas  (SgP  >ea+kohane !10_A	et	f	\N
116684	eakohast	"ea+kohane %koha  )NE_aA  <ea+koha ;17_S	et	f	\N
116685	eakohast	"ea+kohane %koha  )NE_aA  <ea+koht ;22_S	et	f	\N
116693	proosateksti	proosateksti =teksti  (SgG  >proosa+tekst !22_S	et	f	\N
116695	proosateksti	proosateksti =teksti  (SgP  >proosa+tekst !22_S	et	f	\N
116697	proosateksti	proosateksti =teksti  (SgAdt  >proosa+tekst !22_S	et	f	\N
116703	kohustusliks	?kohustusliks =kohustusli  (SgTr  >kohustusl !22_S	et	f	\N
116704	kohustusliks	?kohustusliks =kohustusli  (KndPrPs  >kohustuslima !28_V	et	f	\N
116705	kohustusliks	?kohustusliks =stusli  (SgTr  >kohu+stusli !16_S	et	f	\N
116706	kohustusliks	?kohustusliks =stusli  (SgTr  >kohu+stusl !22_S	et	f	\N
116723	kutselise	kutselise =kutselise  (SgG  >kutseline !12_A	et	f	\N
116724	kutselise	"kutseline %kutse  )LINE_aA  <kutse ;06_S	et	f	\N
116749	arutelu	arutelu =arutelu  (SgN  >arutelu !17_S	et	f	\N
116750	arutelu	arutelu =arutelu  (SgG  >arutelu !17_S	et	f	\N
116751	arutelu	arutelu =arutelu  (SgP  >arutelu !17_S	et	f	\N
116767	tegevuse	tegevuse =tegevuse  (SgG  >tegevus !11_S	et	f	\N
116768	tegevuse	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
116769	tegevuse	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
116772	vahelised	vahelised =vahelise  (PlN  >vaheline !12_A	et	f	\N
116773	vahelised	"vaheline %vahe  )LINE_aA  <vahe ;16_S	et	f	\N
116786	rahvussümboolikastlindlillpuu	?rahvussümboolikastlindlillpuu =rahvussümboolikastlindlillpuu  (SgN  >rahvussümboolikastlindlillpuu !26_S	et	f	\N
116787	rahvussümboolikastlindlillpuu	?rahvussümboolikastlindlillpuu =rahvussümboolikastlindlillpuu  (SgG  >rahvussümboolikastlindlillpuu !26_S	et	f	\N
116788	rahvussümboolikastlindlillpuu	?rahvussümboolikastlindlillpuu =sümboolikastlindlillpuu  (SgN  >rahvus+sümboolikastlindlillpuu !26_S	et	f	\N
116789	rahvussümboolikastlindlillpuu	?rahvussümboolikastlindlillpuu =sümboolikastlindlillpuu  (SgG  >rahvus+sümboolikastlindlillpuu !26_S	et	f	\N
116792	tähendust	tähendust =tähendus  (SgP  >tähendus !11_S	et	f	\N
116793	tähendust	"tähendus %tähenda  )US_vS  <tähendama ;27_V	et	f	\N
116801	jõule	jõule =jõu  (SgAll  >jõud !22_S	et	f	\N
116802	jõule	jõule =jõule  (PlP  >jõul !22_S	et	f	\N
116803	lange	lange =lange  (SgN  >lange !06_S	et	f	\N
116804	lange	lange =lange  (SgG  >lange !06_S	et	f	\N
116805	lange	lange =lange  (PlP  >lang !22_S	et	f	\N
116806	lange	lange =lange  (IndPrPs_  >langema !27_V	et	f	\N
116807	lange	lange =lange  (ImpPrSg2  >langema !27_V	et	f	\N
116808	mõistetavamad	mõistetavamad =mõistetavama  (PlN  >mõistetavam !02_A	et	f	\N
116809	mõistetavamad	"mõistetavam %mõiste  )TAVAM_cA  <mõistma ;34_V	et	f	\N
116810	mõistetavamad	"mõistetavam %mõistetava  )M_cA  <mõistetav ;02_A	et	f	\N
116814	oskavad	oskavad =oska  (IndPrPl3  >oskama !29_V	et	f	\N
116815	oskavad	oskavad =oskava  (PlN  >oskav !02_A	et	f	\N
116626	laienevad	laienevad =laieneva  (PlN  >laienev !02_A	et	f	\N
116627	laienevad	"laienev %laiene  )V_vA  <laienema ;27_V	et	f	\N
116655	kliima	kliima =kliima  (SgN  >kliima !16_S	et	f	\N
116657	kliima	kliima =kliima  (SgG  >kliima !16_S	et	f	\N
116660	klassiväliseid	klassiväliseid =välise  (PlP  >klassi+väline !10_A	et	f	\N
116661	klassiväliseid	"klassi+väline %väli  )NE_aA  <klassi+väli ;24_S	et	f	\N
116664	tetris	?tetris =tetri  (SgIn  >tetter !02_S	et	f	\N
116665	tetris	?tetris =tetri  (IndIpfSg3  >tetrima !28_V	et	f	\N
116666	tetris	?tetris =tetris  (SgN  >tetris !09_S	et	f	\N
116671	jm	### jm	et	f	\N
116679	noorsookirjanikku	noorsookirjanikku =kirjanikku  (SgP  >noor+soo+kirjanik !25_S	et	f	\N
116680	noorsookirjanikku	noorsookirjanikku =kirjanikku  (SgAdt  >noor+soo+kirjanik !25_S	et	f	\N
116686	keeleliselt	keeleliselt =keelelise  (SgAbl  >keeleline !12_A	et	f	\N
116687	keeleliselt	"keeleline %keele  )LINE_aA  <keel ;13_S	et	f	\N
116689	keeleliselt	keeleliselt =keeleliselt  (ID  >keeleliselt !41_D	et	f	\N
116691	keeleliselt	"keeleliselt %keele  )LISELT_mD  <keel ;13_S	et	f	\N
116694	keeleliselt	"keeleliselt %keelelise  )LT_mD  <keeleline ;12_A	et	f	\N
116707	õppetundi	õppetundi =tundi  (SgP  >õppe+tund !22_S	et	f	\N
116708	õppetundi	õppetundi =tundi  (SgAdt  >õppe+tund !22_S	et	f	\N
116727	algus	algus =algu  (SgIn  >alg !22_S	et	f	\N
116728	algus	algus =algus  (SgN  >algus !11~09_S	et	f	\N
116738	teadusest	teadusest =teaduse  (SgEl  >teadus !11~09_S	et	f	\N
116739	teadusest	teadusest =teaduses  (SgP  >teadusene !12_A	et	f	\N
116740	teadusest	"teadusene %teaduse  )NE_aA  <teadus ;09_S	et	f	\N
116741	teadusest	"teadusene %teaduse  )NE_aA  <teadus ;11_S	et	f	\N
116755	struktuurilised	struktuurilised =struktuurilise  (PlN  >struktuuriline !12_A	et	f	\N
116757	struktuurilised	"struktuuriline %struktuuri  )LINE_aA  <struktuur ;22_S	et	f	\N
116770	õigekeelsussõnaraamatu	õigekeelsussõnaraamatu =atu  (SgG  >õige+keelsus+sõna+raam+att !22_S	et	f	\N
116771	õigekeelsussõnaraamatu	õigekeelsussõnaraamatu =raamatu  (SgG  >õige+keelsus+sõna+raamat !02_S	et	f	\N
116811	õpilastele	õpilastele =õpilas  (PlAll  >õpilane !12_S	et	f	\N
116812	õpilastele	õpilastele =las  (PlAll  >õpi+laps !14_S	et	f	\N
116813	õpilastele	õpilastele =laste  (PlAll  >õpi+last !22_S	et	f	\N
116836	vastamine	vastamine =vastamine  (SgN  >vastamine !12_S	et	f	\N
116837	vastamine	"vastamine %vasta  )MINE_vS  <vastama ;29_V	et	f	\N
116851	ainetevahelised	ainetevahelised =vahelise  (PlN  >ainete+vaheline !12_A	et	f	\N
116852	ainetevahelised	"ainete+vaheline %vahe  )LINE_aA  <ainete+vahe ;16_S	et	f	\N
116862	klassidevaheline	?klassidevaheline =klassidevaheline  (SgN  >klassidevaheline !12_A	et	f	\N
116864	klassidevaheline	?klassidevaheline =klassidevaheline  (PlP  >klassidevahelin !19_S	et	f	\N
116867	klassidevaheline	?klassidevaheline =devaheline  (SgN  >klassi+devaheline !12_A	et	f	\N
116868	klassidevaheline	?klassidevaheline =devaheline  (PlP  >klassi+devahelin !19_S	et	f	\N
116876	julupühade	?julupühade =julupüha  (PlG  >julupüha !16_S	et	f	\N
116877	emadepäeva	emadepäeva =päeva  (SgG  >emade+päev !22_S	et	f	\N
116878	emadepäeva	emadepäeva =päeva  (SgP  >emade+päev !22_S	et	f	\N
116879	emadepäeva	emadepäeva =päeva  (SgAdt  >emade+päev !22_S	et	f	\N
116882	mõistatusi	mõistatusi =mõistatusi  (PlP  >mõistatus !11_S	et	f	\N
116883	mõistatusi	"mõistatus %mõistata  )US_vS  <mõistatama ;27_V	et	f	\N
116893	ande	ande =ande  (SgG  >anne !06_S	et	f	\N
116894	ande	ande =ande  (PlP  >and !22_S	et	f	\N
116895	tegelikult	tegelikult =tegeliku  (SgAbl  >tegelik !25_A	et	f	\N
116896	tegelikult	tegelikult =tegelikult  (ID  >tegelikult !41_D	et	f	\N
116897	tegelikult	"tegelikult %tegeliku  )LT_mD  <tegelik ;25_A	et	f	\N
116917	jällegi	jällegi =jällegi  (ID  >jällegi !41_D	et	f	\N
116918	jällegi	jällegi =jälle  (ID^  >jälle !41_D	et	f	\N
116954	endast	endast =enda  (SgEl  >enda !00_P	et	f	\N
116955	endast	endast =enda  (SgEl  >ise !00_P	et	f	\N
116964	mardisanti	mardisanti =santi  (SgP  >mardi+sant !22_SA	et	f	\N
116965	mardisanti	mardisanti =santi  (SgAdt  >mardi+sant !22_SA	et	f	\N
116978	üritustel	üritustel =üritus  (PlAd  >üritus !11_S	et	f	\N
116979	üritustel	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
116987	kultuuritegelasiselleks	?kultuuritegelasiselleks =kultuuritegelasiselle  (PlTr  >kultuuritegelasisell !22_S	et	f	\N
116988	kultuuritegelasiselleks	?kultuuritegelasiselleks =iselle  (PlTr  >kultuuri+tegelas+isell !22_S	et	f	\N
116989	kultuuritegelasiselleks	?kultuuritegelasiselleks =tegelasiselle  (PlTr  >kultuuri+tegelasisell !22_S	et	f	\N
116990	kultuuritegelasiselleks	?kultuuritegelasiselleks =itegelasiselle  (PlTr  >kultuur+itegelasisell !22_S	et	f	\N
117012	materjali	materjali =materjali  (SgG  >materjal !19_S	et	f	\N
117013	materjali	materjali =materjali  (SgP  >materjal !19_S	et	f	\N
117014	materjali	materjali =materjali  (SgAdt  >materjal !19_S	et	f	\N
117025	tutvuvad	tutvuvad =tutvu  (IndPrPl3  >tutvuma !27_V	et	f	\N
117026	tutvuvad	tutvuvad =tutvuva  (PlN  >tutvuv !02_A	et	f	\N
117027	tutvuvad	"tutvuv %tutvu  )V_vA  <tutvuma ;27_V	et	f	\N
117035	tutvus	tutvus =tutvu  (IndIpfSg3  >tutvuma !27_V	et	f	\N
117036	tutvus	tutvus =tutvus  (SgN  >tutvus !11~09_S	et	f	\N
117047	henno	?henno =henno  (SgN  >henno !16_S	et	f	\N
116692	jõukohast	jõukohast =kohas  (SgP  >jõu+kohane !10_A	et	f	\N
116696	jõukohast	"jõu+kohane %koha  )NE_aA  <jõu+koha ;17_S	et	f	\N
116698	jõukohast	"jõu+kohane %koha  )NE_aA  <jõu+koht ;22_S	et	f	\N
116699	kultuuritegelastjutustab	?kultuuritegelastjutustab =kultuuritegelastjutusta  (IndPrSg3  >kultuuritegelastjutustama !27_V	et	f	\N
116700	huviväärsustest	huviväärsustest =test  (SgN  >huvi+väärsus+test !22_S	et	f	\N
116701	huviväärsustest	huviväärsustest =väärsus  (PlEl  >huvi+väärsus !11~09_S	et	f	\N
116702	huviväärsustest	"huvi+väärsus %väärse  )US_aS  <huvi+väärne ;02_A	et	f	\N
116719	35-tunnise	-tunnise =tunnise  (SgG  >-tunnine !10_A	et	f	\N
116720	35-tunnise	"-tunnine %tunni  )NE_aA  <-tund ;22_S	et	f	\N
116725	laulupidude	laulupidude =pidu  (PlG  >laulu+pidu !17_S	et	f	\N
116726	laulupidude	laulupidude =pidu  (PlG  >laulu+pidu !18_S	et	f	\N
116730	ajakirjandusest	ajakirjandusest =kirjanduse  (SgEl  >aja+kirjandus !11_S	et	f	\N
116732	ajakirjandusest	ajakirjandusest =kirjanduses  (SgP  >aja+kirjandusene !12_A	et	f	\N
116733	ajakirjandusest	"aja+kirjandusene %kirjanduse  )NE_aA  <aja+kirjandus ;11_S	et	f	\N
116744	luulest	luulest =luule  (SgEl  >luule !06_S	et	f	\N
116745	luulest	luulest =luule  (PlEl  >luul !22_S	et	f	\N
116746	luulest	luulest =luules  (SgP  >luulene !10_A	et	f	\N
116747	luulest	"luulene %luule  )NE_aA  <luule ;06_S	et	f	\N
116748	luulest	luulest =lest  (SgN  >luu+lest !22_S	et	f	\N
116763	kujunemine	kujunemine =kujunemine  (SgN  >kujunemine !12_S	et	f	\N
116764	kujunemine	"kujunemine %kujune  )MINE_vS  <kujunema ;27_V	et	f	\N
116790	tähtpäevadestjõulud	?tähtpäevadestjõulud =tähtpäevadestjõulu  (IndPrSg2  >tähtpäevadestjõuluma !27_V	et	f	\N
116791	tähtpäevadestjõulud	?tähtpäevadestjõulud =destjõulu  (PlN  >täht+päeva+destjõulu !01_S	et	f	\N
116794	koduloo	koduloo =loo  (SgG  >kodu+lugu !18_S	et	f	\N
116795	koduloo	koduloo =loo  (SgG  >kodu+loog !22_S	et	f	\N
116796	koduloo	koduloo =loo  (SgG  >kodu+lood !22_S	et	f	\N
116825	tegevust	tegevust =tegevus  (SgP  >tegevus !11_S	et	f	\N
116826	tegevust	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
116828	tegevust	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
116830	tegevust	tegevust =us  (SgP  >tegev+uks !14_S	et	f	\N
116844	eestistüldandmed	### eestistüldandmed	et	f	\N
116857	pikaajalised	pikaajalised =ajalise  (PlN  >pika+ajaline !12_A	et	f	\N
116858	pikaajalised	"pika+ajaline %aja  )LINE_aA  <pika+aeg ;22_S	et	f	\N
116872	tähistamine	tähistamine =tähistamine  (SgN  >tähistamine !12_S	et	f	\N
116873	tähistamine	"tähistamine %tähista  )MINE_vS  <tähistama ;27_V	et	f	\N
116884	1992laulukogumikkeeesti	?laulukogumikkeeesti =laulukogumikkeeesti  (ID  >laulukogumikkeeesti !41_D	et	f	\N
116885	1992laulukogumikkeeesti	?laulukogumikkeeesti =laulukogumikkeeesti  (IndPrPs_  >laulukogumikkeeestima !28_V	et	f	\N
116886	1992laulukogumikkeeesti	?laulukogumikkeeesti =laulukogumikkeeesti  (ImpPrSg2  >laulukogumikkeeestima !28_V	et	f	\N
116909	õpilastel	õpilastel =õpilas  (PlAd  >õpilane !12_S	et	f	\N
116910	õpilastel	õpilastel =las  (PlAd  >õpi+laps !14_S	et	f	\N
116911	õpilastel	õpilastel =laste  (PlAd  >õpi+last !22_S	et	f	\N
116922	kultuuriruumigata	?kultuuriruumigata =kultuuriruumigata  (IndPrPs_  >kultuuriruumigatama !27_V	et	f	\N
116923	kultuuriruumigata	?kultuuriruumigata =kultuuriruumigata  (ImpPrSg2  >kultuuriruumigatama !27_V	et	f	\N
116924	kultuuriruumigata	?kultuuriruumigata =gata  (SgN  >kultuuri+ruumi+gata !16_S	et	f	\N
116925	kultuuriruumigata	?kultuuriruumigata =gata  (SgG  >kultuuri+ruumi+gata !16_S	et	f	\N
116927	üldandmetest	üldandmetest =test  (SgN  >üld+andme+test !22_S	et	f	\N
116930	üldandmetest	üldandmetest =andme  (PlEl  >üld+anne !05_S	et	f	\N
116950	reaalselt	reaalselt =reaalse  (SgAbl  >reaalne !02_A	et	f	\N
116951	reaalselt	reaalselt =reaalselt  (ID  >reaalselt !41_D	et	f	\N
116952	reaalselt	"reaalselt %reaalse  )LT_mD  <reaalne ;02_A	et	f	\N
116953	reaalselt	reaalselt =alse  (PlAbl  >rea+alss !22_S	et	f	\N
116975	osalevad	osalevad =osale  (IndPrPl3  >osalema !27_V	et	f	\N
116976	osalevad	osalevad =osaleva  (PlN  >osalev !02_A	et	f	\N
116977	osalevad	"osalev %osale  )V_vA  <osalema ;27_V	et	f	\N
116994	mõistatustest	mõistatustest =mõistatus  (PlEl  >mõistatus !11_S	et	f	\N
116995	mõistatustest	"mõistatus %mõistata  )US_vS  <mõistatama ;27_V	et	f	\N
116996	mõistatustest	mõistatustest =tuste  (PlEl  >mõista+tust !22_S	et	f	\N
117005	presidentselleks	?presidentselleks =presidentselle  (PlTr  >presidentsell !22_S	et	f	\N
117006	presidentselleks	?presidentselleks =sidentselle  (PlTr  >pre+sidentsell !22_S	et	f	\N
117007	jne	### jne	et	f	\N
117031	külastavad	külastavad =külasta  (IndPrPl3  >külastama !27_V	et	f	\N
117032	külastavad	külastavad =külastava  (PlN  >külastav !02_A	et	f	\N
117033	külastavad	"külastav %külasta  )V_vA  <külastama ;27_V	et	f	\N
117034	külastavad	külastavad =tava  (PlN  >külas+tava !17_S	et	f	\N
117060	jneekskursioonidüldkoolilised	?jneekskursioonidüldkoolilised =jneekskursioonidüldkoolilise  (PlN  >jneekskursioonidüldkooliline !12_A	et	f	\N
117079	ajaloo	ajaloo =loo  (SgG  >aja+lugu !18_S	et	f	\N
117080	ajaloo	ajaloo =loo  (SgG  >aja+loog !22_S	et	f	\N
117081	ajaloo	ajaloo =loo  (SgG  >aja+lood !22_S	et	f	\N
117082	raames	raames =raame  (PlIn  >raam !22_S	et	f	\N
117083	raames	raames =raames  (ID  >raames !41_K	et	f	\N
116759	soomeugri	?soomeugri =ugri  (SgP  >soome+ugr !22_S	et	f	\N
116760	soomeugri	?soomeugri =ugri  (SgAdt  >soome+ugr !22_S	et	f	\N
116761	soomeugri	?soomeugri =meugri  (SgG  >soo+meuger !02_S	et	f	\N
116774	httpswwwriigiteatajaeeertactjspid802290	?httpswwwriigiteatajaeeertactjspid =httpswwwriigiteatajaeeertactjspi  (IndPrSg2  >httpswwwriigiteatajaeeertactjspima !28_V	et	f	\N
116779	lihtsamaid	lihtsamaid =lihtsama  (PlP  >lihtsam !02_A	et	f	\N
116780	lihtsamaid	"lihtsam %lihtsa  )M_cA  <lihtne ;02_A	et	f	\N
116782	lihtsamaid	lihtsamaid =ma  (PlP  >lihtsa+maa !26_S	et	f	\N
116783	lihtsamaid	lihtsamaid =mai  (PlN  >lihtsa+mai !26_S	et	f	\N
116785	lihtsamaid	lihtsamaid =mai  (SgP  >lihtsa+mai !26_S	et	f	\N
116827	mängu	mängu =mängu  (SgG  >mäng !22_S	et	f	\N
116829	mängu	mängu =mängu  (SgP  >mäng !22_S	et	f	\N
116831	mängu	mängu =mängu  (SgAdt  >mäng !22_S	et	f	\N
116832	loetu	loetu =loetu  (SgN  >loetu !01_S	et	f	\N
116833	loetu	"loetu %loe  )TU1_vS  <lugema ;28_V	et	f	\N
116834	loetu	"loetu %loe  )TU2_kA  <lood ;22_S	et	f	\N
116835	loetu	loetu =loetu  (SgG  >loetu !01_S	et	f	\N
116838	vestlemine	vestlemine =vestlemine  (SgN  >vestlemine !12_S	et	f	\N
116839	vestlemine	"vestlemine %vestle  )MINE_vS  <vestlema ;30_V	et	f	\N
116874	tähistamine	tähistamine =tähistamine  (SgN  >tähistamine !12_S	et	f	\N
116875	tähistamine	"tähistamine %tähista  )MINE_vS  <tähistama ;27_V	et	f	\N
116891	kadrisandid	kadrisandid =sandi  (PlN  >kadri+sand !22_S	et	f	\N
116892	kadrisandid	kadrisandid =sandi  (PlN  >kadri+sant !22_SA	et	f	\N
116898	mõistatuseks	mõistatuseks =mõistatuse  (SgTr  >mõistatus !11_S	et	f	\N
116899	mõistatuseks	"mõistatus %mõistata  )US_vS  <mõistatama ;27_V	et	f	\N
116915	rahvussümboolika	rahvussümboolika =sümboolika  (SgN  >rahvus+sümboolika !01_S	et	f	\N
116916	rahvussümboolika	rahvussümboolika =sümboolika  (SgG  >rahvus+sümboolika !01_S	et	f	\N
116919	mõistetav	mõistetav =mõiste  (PtsPrIps  >mõistma !34_V	et	f	\N
116920	mõistetav	mõistetav =mõistetav  (SgN  >mõistetav !02_A	et	f	\N
116921	mõistetav	"mõistetav %mõiste  )TAV_vAS  <mõistma ;34_V	et	f	\N
116941	jaanipäevet	?jaanipäevet =päeve  (SgP  >jaani+päeve !06_S	et	f	\N
116968	jõulukombeid	jõulukombeid =bei  (PlN  >jõulu+kom+bei !26_S	et	f	\N
116969	jõulukombeid	jõulukombeid =bei  (SgP  >jõulu+kom+bei !26_S	et	f	\N
116970	jõulukombeid	jõulukombeid =kombe  (PlP  >jõulu+komme !06_S	et	f	\N
116980	toetavad	toetavad =toeta  (IndPrPl3  >toetama !27_V	et	f	\N
116981	toetavad	toetavad =toetava  (PlN  >toetav !02_A	et	f	\N
116982	toetavad	"toetav %toeta  )V_vA  <toetama ;27_V	et	f	\N
116983	toetavad	toetavad =tava  (PlN  >toe+tava !17_S	et	f	\N
116984	õppeeeasmärgiks	?õppeeeasmärgiks =õppeeeasmärgi  (SgTr  >õppeeeasmärk !22_S	et	f	\N
116985	õppeeeasmärgiks	?õppeeeasmärgiks =õppeeeasmärgi  (KndPrPs  >õppeeeasmärkima !28_V	et	f	\N
116986	õppeeeasmärgiks	?õppeeeasmärgiks =eeasmärgi  (SgTr  >õppe+eeasmärk !22_S	et	f	\N
117008	eestimaad	eestimaad =maa  (PlN  >eesti+maa !26_S	et	f	\N
117009	eestimaad	eestimaad =maa  (SgP  >eesti+maa !26_S	et	f	\N
117015	omandanud	omandanud =omanda  (PtsPtPs  >omandama !27_V	et	f	\N
117016	omandanud	omandanud =omandanu  (PlN  >omandanu !01_S	et	f	\N
117017	omandanud	"omandanu %omanda  )NU_vS  <omandama ;27_V	et	f	\N
117018	omandanud	omandanud =omandanud  (ID  >omandanud !41_A	et	f	\N
117019	omandanud	"omandanud %omanda  )NUD_vA  <omandama ;27_V	et	f	\N
117020	plaani	plaani =plaani  (SgG  >plaan !22_S	et	f	\N
117021	plaani	plaani =plaani  (SgP  >plaan !22_S	et	f	\N
117022	plaani	plaani =plaani  (SgAdt  >plaan !22_S	et	f	\N
117023	plaani	plaani =plaani  (IndPrPs_  >plaanima !28_V	et	f	\N
117024	plaani	plaani =plaani  (ImpPrSg2  >plaanima !28_V	et	f	\N
117039	mahu	mahu =mahu  (SgG  >maht !22_S	et	f	\N
117040	mahu	mahu =mahu  (IndPrPs_  >mahtuma !28_V	et	f	\N
117041	mahu	mahu =mahu  (ImpPrSg2  >mahtuma !28_V	et	f	\N
117061	tv-	### tv-	et	f	\N
117062	grammatika	grammatika =grammatika  (SgN  >grammatika !01_S	et	f	\N
117063	grammatika	grammatika =grammatika  (SgG  >grammatika !01_S	et	f	\N
117097	omapära	omapära =pära  (SgN  >oma+pära !17_S	et	f	\N
117098	omapära	omapära =pära  (SgG  >oma+pära !17_S	et	f	\N
117099	omapära	omapära =pära  (SgP  >oma+pära !17_S	et	f	\N
117124	ikkagi	ikkagi =ikkagi  (ID  >ikkagi !41_D	et	f	\N
117125	ikkagi	ikkagi =ikka  (ID^  >ikka !41_D	et	f	\N
117126	ikkagi	ikkagi =ikka  (SgAdt^  >iga !18_S	et	f	\N
117140	raisata	raisata =raisa  (SgAb  >raisk !22_S	et	f	\N
117141	raisata	raisata =raisa  (Inf  >raiskama !29_V	et	f	\N
117142	raisata	raisata =raisa  (IndPrIps_  >raiskama !29_V	et	f	\N
117158	ühiskondlikust	ühiskondlikust =ühiskondliku  (SgEl  >ühiskondlik !25_A	et	f	\N
117159	ühiskondlikust	ühiskondlikust =ühiskondlikus  (SgP  >ühiskondlikus !11?09_S	et	f	\N
117160	ühiskondlikust	"ühiskondlikus %ühiskondliku  )US_aS  <ühiskondlik ;25_A	et	f	\N
117175	olulisematest	olulisematest =olulisema  (PlEl  >olulisem !02_A	et	f	\N
117176	olulisematest	"olulisem %olu  )LISEM_cA  <olu ;17_S	et	f	\N
117177	olulisematest	"olulisem %olulise  )M_cA  <oluline ;12_A	et	f	\N
117186	aastapäevale	aastapäevale =ale  (SgN  >aasta+päev+ale !16_S	et	f	\N
116775	13tallinna	?tallinna =tallinna  (SgN  >tallinna !16_S	et	f	\N
116776	13tallinna	?tallinna =tallinna  (SgG  >tallinna !16_S	et	f	\N
116777	13tallinna	?tallinna =tallinna  (SgP  >tallinn !22_H	et	f	\N
116778	13tallinna	?tallinna =tallinna  (SgAdt  >tallinn !22_H	et	f	\N
116781	tähtpäevakaarte	tähtpäevakaarte =kaar  (PlG  >täht+päeva+kaar !13_S	et	f	\N
116784	tähtpäevakaarte	tähtpäevakaarte =kaarte  (PlP  >täht+päeva+kaart !22_S	et	f	\N
116797	tähistavad	tähistavad =tähista  (IndPrPl3  >tähistama !27_V	et	f	\N
116798	tähistavad	tähistavad =tähistava  (PlN  >tähistav !02_A	et	f	\N
116799	tähistavad	"tähistav %tähista  )V_vA  <tähistama ;27_V	et	f	\N
116800	tähistavad	tähistavad =tava  (PlN  >tähis+tava !17_S	et	f	\N
116817	mõista	mõista =mõist  (Inf  >mõistma !34_V	et	f	\N
116818	mõista	mõista =mõista  (IndPrPs_  >mõistma !34_V	et	f	\N
116819	mõista	mõista =mõista  (ImpPrSg2  >mõistma !34_V	et	f	\N
116820	tähendusi	tähendusi =tähendusi  (PlP  >tähendus !11_S	et	f	\N
116821	tähendusi	"tähendus %tähenda  )US_vS  <tähendama ;27_V	et	f	\N
116822	kultuuriruumiga	kultuuriruumiga =iga  (SgN  >kultuuri+ruum+iga !18_S	et	f	\N
116823	kultuuriruumiga	kultuuriruumiga =iga  (SgP  >kultuuri+ruum+iga !18_S	et	f	\N
116824	kultuuriruumiga	kultuuriruumiga =ruumi  (SgKom  >kultuuri+ruum !22_S	et	f	\N
116840	jutustamine	jutustamine =jutustamine  (SgN  >jutustamine !12_S	et	f	\N
116841	jutustamine	"jutustamine %jutusta  )MINE_vS  <jutustama ;27_V	et	f	\N
116842	teadmisi	teadmisi =teadmisi  (PlP  >teadmine !12_S	et	f	\N
116843	teadmisi	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
116850	käivel	?käivel =käivel  (SgN  >käivel !02_S	et	f	\N
116853	klassidevahelised	?klassidevahelised =klassidevahelise  (PlN  >klassidevaheline !12_A	et	f	\N
116854	klassidevahelised	?klassidevahelised =devahelise  (PlN  >klassi+devaheline !12_A	et	f	\N
116859	koolidevahelised	?koolidevahelised =koolidevahelise  (PlN  >koolidevaheline !12_A	et	f	\N
116860	koolidevahelised	?koolidevahelised =devahelise  (PlN  >kooli+devaheline !12_A	et	f	\N
116861	koolidevahelised	?koolidevahelised =idevahelise  (PlN  >kool+idevaheline !12_A	et	f	\N
116880	laste	laste =las  (PlG  >laps !14_S	et	f	\N
116881	laste	laste =laste  (PlP  >last !22_S	et	f	\N
116900	toovad	toovad =too  (IndPrPl3  >tooma !38_V	et	f	\N
116901	toovad	toovad =toova  (PlN  >toov !02_A	et	f	\N
116902	toovad	"toov %too  )V_vA  <tooma ;38_V	et	f	\N
116903	karjaõnne	karjaõnne =õnne  (SgG  >karja+õnn !22_S	et	f	\N
116904	karjaõnne	karjaõnne =õnne  (SgP  >karja+õnn !22_S	et	f	\N
116905	karjaõnne	karjaõnne =õnne  (SgAdt  >karja+õnn !22_S	et	f	\N
116906	karjaõnne	karjaõnne =õnne  (PlP  >karja+õnn !22_S	et	f	\N
116907	enamus	enamus =enamus  (SgN  >enamus !11_S	et	f	\N
116908	enamus	"enamus %enama  )US_aS  <enam ;02_A	et	f	\N
116961	jooksevad	jooksevad =jookse  (IndPrPl3  >jooksma !32_V	et	f	\N
116962	jooksevad	jooksevad =jookseva  (PlN  >jooksev !02_A	et	f	\N
116963	jooksevad	"jooksev %jooks  )V_vA  <jooksma ;32_V	et	f	\N
116966	kadrisanti	kadrisanti =santi  (SgP  >kadri+sant !22_SA	et	f	\N
116967	kadrisanti	kadrisanti =santi  (SgAdt  >kadri+sant !22_SA	et	f	\N
116971	tähtpäevast	tähtpäevast =ast  (SgN  >täht+päev+ast !22_S	et	f	\N
116972	tähtpäevast	tähtpäevast =päeva  (SgEl  >täht+päev !22_S	et	f	\N
116973	tähtpäevast	tähtpäevast =päevas  (SgP  >täht+päevane !10_A	et	f	\N
116974	tähtpäevast	"täht+päevane %päeva  )NE_aA  <täht+päev ;22_S	et	f	\N
116991	lastekirjandusest	lastekirjandusest =kirjanduse  (SgEl  >laste+kirjandus !11_S	et	f	\N
116992	lastekirjandusest	lastekirjandusest =kirjanduses  (SgP  >laste+kirjandusene !12_A	et	f	\N
116993	lastekirjandusest	"laste+kirjandusene %kirjanduse  )NE_aA  <laste+kirjandus ;11_S	et	f	\N
117000	rahvussümbolitest	rahvussümbolitest =test  (SgN  >rahvus+sümboli+test !22_S	et	f	\N
117001	rahvussümbolitest	rahvussümbolitest =sümboli  (PlEl  >rahvus+sümbol !02_S	et	f	\N
117028	jõukohaste	jõukohaste =kohas  (PlG  >jõu+kohane !10_A	et	f	\N
117029	jõukohaste	"jõu+kohane %koha  )NE_aA  <jõu+koha ;17_S	et	f	\N
117030	jõukohaste	"jõu+kohane %koha  )NE_aA  <jõu+koht ;22_S	et	f	\N
117042	leelo	leelo =leelo  (SgN  >leelo !16_S	et	f	\N
117043	leelo	leelo =leelo  (SgG  >leelo !16_S	et	f	\N
117044	tungal	tungal =tunga  (SgAd  >tung !22_S	et	f	\N
117045	tungal	tungal =tungal  (SgN  >tungal !08_S	et	f	\N
117046	rannap	?rannap =rannap  (SgN  >rannap !02_S	et	f	\N
117052	lastekirjandusestnäiteid	?lastekirjandusestnäiteid =lastekirjandusestnäitei  (PlN  >lastekirjandusestnäitei !26_S	et	f	\N
117053	lastekirjandusestnäiteid	?lastekirjandusestnäiteid =lastekirjandusestnäitei  (SgP  >lastekirjandusestnäitei !26_S	et	f	\N
117054	lastekirjandusestnäiteid	?lastekirjandusestnäiteid =estnäitei  (PlN  >laste+kirjandus+estnäitei !26_S	et	f	\N
117055	lastekirjandusestnäiteid	?lastekirjandusestnäiteid =estnäitei  (SgP  >laste+kirjandus+estnäitei !26_S	et	f	\N
117056	lastekirjandusestnäiteid	?lastekirjandusestnäiteid =kirjandusestnäitei  (PlN  >laste+kirjandusestnäitei !26_S	et	f	\N
117057	lastekirjandusestnäiteid	?lastekirjandusestnäiteid =kirjandusestnäitei  (SgP  >laste+kirjandusestnäitei !26_S	et	f	\N
117066	süsteemitu	süsteemitu =süsteemitu  (SgN  >süsteemitu !01_A	et	f	\N
117067	süsteemitu	"süsteemitu %süsteemi  )TU2_kA  <süsteem ;22_S	et	f	\N
117068	süsteemitu	süsteemitu =süsteemitu  (SgG  >süsteemitu !01_A	et	f	\N
116816	oskavad	"oskav %oska  )V_vA  <oskama ;29_V	et	f	\N
116845	rahvussümboolikast	rahvussümboolikast =sümboolika  (SgEl  >rahvus+sümboolika !01_S	et	f	\N
116846	rahvussümboolikast	rahvussümboolikast =sümboolikas  (SgP  >rahvus+sümboolikane !12_A	et	f	\N
116847	rahvussümboolikast	"rahvus+sümboolikane %sümboolika  )NE_aA  <rahvus+sümboolika ;01_S	et	f	\N
116848	puu	puu =puu  (SgN  >puu !26_S	et	f	\N
116849	puu	puu =puu  (SgG  >puu !26_S	et	f	\N
116855	ülekoolilised	ülekoolilised =koolilise  (PlN  >üle+kooliline !12_A	et	f	\N
116856	ülekoolilised	"üle+kooliline %kooli  )LINE_aA  <üle+kool ;22_S	et	f	\N
116863	mardipäeva	mardipäeva =päeva  (SgG  >mardi+päev !22_S	et	f	\N
116865	mardipäeva	mardipäeva =päeva  (SgP  >mardi+päev !22_S	et	f	\N
116866	mardipäeva	mardipäeva =päeva  (SgAdt  >mardi+päev !22_S	et	f	\N
116869	kadripäeva	kadripäeva =päeva  (SgG  >kadri+päev !22_S	et	f	\N
116870	kadripäeva	kadripäeva =päeva  (SgP  >kadri+päev !22_S	et	f	\N
116871	kadripäeva	kadripäeva =päeva  (SgAdt  >kadri+päev !22_S	et	f	\N
116887	õpetajate	õpetajate =õpetaja  (PlG  >õpetaja !01_S	et	f	\N
116888	õpetajate	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
116889	mardisandid	mardisandid =sandi  (PlN  >mardi+sand !22_S	et	f	\N
116890	mardisandid	mardisandid =sandi  (PlN  >mardi+sant !22_SA	et	f	\N
116912	selge	selge =selge  (SgN  >selge !01_A	et	f	\N
116913	selge	selge =selge  (SgG  >selge !01_A	et	f	\N
116914	selge	selge =selge  (PlP  >selg !22_S	et	f	\N
116926	rääkidaeesti	?rääkidaeesti =rääkidaeesti  (ID  >rääkidaeesti !41_D	et	f	\N
116928	rääkidaeesti	?rääkidaeesti =rääkidaeesti  (IndPrPs_  >rääkidaeestima !28_V	et	f	\N
116929	rääkidaeesti	?rääkidaeesti =rääkidaeesti  (ImpPrSg2  >rääkidaeestima !28_V	et	f	\N
116931	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =rahvuskalendritähtpäevadestkadri  (SgP  >rahvuskalendritähtpäevadestkadr !22_S	et	f	\N
116932	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =rahvuskalendritähtpäevadestkadri  (SgAdt  >rahvuskalendritähtpäevadestkadr !22_S	et	f	\N
116933	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =rahvuskalendritähtpäevadestkadri  (IndPrPs_  >rahvuskalendritähtpäevadestkatrima !28_V	et	f	\N
116934	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =rahvuskalendritähtpäevadestkadri  (ImpPrSg2  >rahvuskalendritähtpäevadestkatrima !28_V	et	f	\N
116935	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =destkadri  (SgN  >rahvus+kalendri+täht+päeva+destkadri !01_S	et	f	\N
116936	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =destkadri  (SgG  >rahvus+kalendri+täht+päeva+destkadri !01_S	et	f	\N
116937	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =destkadri  (SgP  >rahvus+kalendri+täht+päeva+destkadr !22_S	et	f	\N
116938	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =destkadri  (SgAdt  >rahvus+kalendri+täht+päeva+destkadr !22_S	et	f	\N
116939	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =adestkadri  (SgP  >rahvus+kalendri+täht+päev+adestkadr !22_S	et	f	\N
116940	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =adestkadri  (SgAdt  >rahvus+kalendri+täht+päev+adestkadr !22_S	et	f	\N
116942	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =päevadestkadri  (SgP  >rahvus+kalendri+täht+päevadestkadr !22_S	et	f	\N
116943	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =päevadestkadri  (SgAdt  >rahvus+kalendri+täht+päevadestkadr !22_S	et	f	\N
116944	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =tähtpäevadestkadri  (SgP  >rahvus+kalendri+tähtpäevadestkadr !22_S	et	f	\N
116945	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =tähtpäevadestkadri  (SgAdt  >rahvus+kalendri+tähtpäevadestkadr !22_S	et	f	\N
116946	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =kalendritähtpäevadestkadri  (SgP  >rahvus+kalendritähtpäevadestkadr !22_S	et	f	\N
116947	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =kalendritähtpäevadestkadri  (SgAdt  >rahvus+kalendritähtpäevadestkadr !22_S	et	f	\N
116948	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =skalendritähtpäevadestkadri  (SgP  >rahvu+skalendritähtpäevadestkadr !22_S	et	f	\N
116949	rahvuskalendritähtpäevadestkadri-	?rahvuskalendritähtpäevadestkadri- =skalendritähtpäevadestkadri  (SgAdt  >rahvu+skalendritähtpäevadestkadr !22_S	et	f	\N
116956	kujutlevad	kujutlevad =kujutle  (IndPrPl3  >kujutlema !27_V	et	f	\N
116957	kujutlevad	kujutlevad =kujutleva  (PlN  >kujutlev !02_A	et	f	\N
116958	kujutlevad	"kujutlev %kujutle  )V_vA  <kujutlema ;27_V	et	f	\N
116959	üritused	üritused =ürituse  (PlN  >üritus !11_S	et	f	\N
116960	üritused	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
116997	tähtpäevadesteesti	?tähtpäevadesteesti =tähtpäevadesteesti  (ID  >tähtpäevadesteesti !41_D	et	f	\N
116998	tähtpäevadesteesti	?tähtpäevadesteesti =tähtpäevadesteesti  (IndPrPs_  >tähtpäevadesteestima !28_V	et	f	\N
116999	tähtpäevadesteesti	?tähtpäevadesteesti =tähtpäevadesteesti  (ImpPrSg2  >tähtpäevadesteestima !28_V	et	f	\N
117002	hümneesti	?hümneesti =hümneesti  (ID  >hümneesti !41_D	et	f	\N
117003	hümneesti	?hümneesti =hümneesti  (IndPrPs_  >hümneestima !28_V	et	f	\N
117004	hümneesti	?hümneesti =hümneesti  (ImpPrSg2  >hümneestima !28_V	et	f	\N
117010	üldkoolilised	üldkoolilised =koolilise  (PlN  >üld+kooliline !12_A	et	f	\N
117011	üldkoolilised	"üld+kooliline %kooli  )LINE_aA  <üld+kool ;22_S	et	f	\N
117037	ülevaate	ülevaate =vaate  (SgG  >üle+vaade !06_S	et	f	\N
117038	ülevaate	ülevaate =vaate  (PlP  >üle+vaat !22_S	et	f	\N
117048	henno	?henno =henno  (SgG  >henno !16_S	et	f	\N
117049	esmärgiks	?esmärgiks =esmärgi  (SgTr  >esmärg !02_S	et	f	\N
117050	esmärgiks	?esmärgiks =esmärgi  (SgTr  >esmärk !22_S	et	f	\N
117051	esmärgiks	?esmärgiks =esmärgi  (KndPrPs  >esmärkima !28_V	et	f	\N
117069	koostööd	koostööd =töö  (PlN  >koos+töö !26_S	et	f	\N
117070	koostööd	koostööd =töö  (SgP  >koos+töö !26_S	et	f	\N
117071	tutvutud	tutvutud =tutvu  (PtsPtIps  >tutvuma !27_V	et	f	\N
117072	tutvutud	tutvutud =tutvutu  (PlN  >tutvutu !01_AS	et	f	\N
117073	tutvutud	"tutvutu %tutvu  )TU1_vS  <tutvuma ;27_V	et	f	\N
117074	tutvutud	tutvutud =tutvutud  (ID  >tutvutud !41_A	et	f	\N
117075	tutvutud	"tutvutud %tutvu  )TUD_vA  <tutvuma ;27_V	et	f	\N
117107	konkurssid	?konkurssid =konkurssi  (PlN  >konkurssi !01_S	et	f	\N
117135	sümboolika	sümboolika =sümboolika  (SgN  >sümboolika !01_S	et	f	\N
117136	sümboolika	sümboolika =sümboolika  (SgG  >sümboolika !01_S	et	f	\N
117153	õpetus	õpetus =õpetus  (SgN  >õpetus !11_S	et	f	\N
117154	õpetus	"õpetus %õpeta  )US_vS  <õpetama ;27_V	et	f	\N
117161	tundemaailma	tundemaailma =ilma  (SgG  >tunde+maa+ilm !22_S	et	f	\N
117162	tundemaailma	tundemaailma =ilma  (SgP  >tunde+maa+ilm !22_S	et	f	\N
117163	tundemaailma	tundemaailma =ilma  (SgAdt  >tunde+maa+ilm !22_S	et	f	\N
117164	muuseumidesõpilane	?muuseumidesõpilane =muuseumidesõpilane  (SgN  >muuseumidesõpilane !12_S	et	f	\N
117165	muuseumidesõpilane	?muuseumidesõpilane =muuseumidesõpilane  (PlP  >muuseumidesõpilan !19_S	et	f	\N
117166	muuseumidesõpilane	?muuseumidesõpilane =desõpilane  (SgN  >muuseumi+desõpilane !12_S	et	f	\N
117167	muuseumidesõpilane	?muuseumidesõpilane =desõpilane  (PlP  >muuseumi+desõpilan !19_S	et	f	\N
117168	muuseumidesõpilane	?muuseumidesõpilane =seumidesõpilane  (SgN  >muu+seumidesõpilane !12_S	et	f	\N
117169	muuseumidesõpilane	?muuseumidesõpilane =seumidesõpilane  (PlP  >muu+seumidesõpilan !19_S	et	f	\N
117171	sündmustest	sündmustest =sündmus  (PlEl  >sündmus !11~09_S	et	f	\N
117173	sündmustest	sündmustest =test  (SgN  >sündmus+test !22_S	et	f	\N
117189	paikonna	paikonna =konna  (SgG  >pai+konn !22_S	et	f	\N
117190	paikonna	paikonna =konna  (SgP  >pai+konn !22_S	et	f	\N
117191	paikonna	paikonna =konna  (SgAdt  >pai+konn !22_S	et	f	\N
117207	õppisid	õppisid =õppi  (PlP  >õpp !22_S	et	f	\N
117208	õppisid	õppisid =õppi  (IndIpfSg2  >õppima !28_V	et	f	\N
117209	õppisid	õppisid =õppi  (IndIpfPl3  >õppima !28_V	et	f	\N
117215	külasta	külasta =külasta  (IndPrPs_  >külastama !27_V	et	f	\N
117216	külasta	külasta =külasta  (ImpPrSg2  >külastama !27_V	et	f	\N
117229	kontrollita	kontrollita =kontrolli  (SgAb  >kontroll !22_S	et	f	\N
117230	kontrollita	kontrollita =kontrolli  (IndPrIps_  >kontrollima !28_V	et	f	\N
117231	rõhku	rõhku =rõhku  (SgP  >rõhk !22_S	et	f	\N
117233	rõhku	rõhku =rõhku  (SgAdt  >rõhk !22_S	et	f	\N
117239	võimeline	võimeline =võimeline  (SgN  >võimeline !12_A	et	f	\N
117240	võimeline	"võimeline %võime  )LINE_aA  <võime ;06_S	et	f	\N
117241	kultuurielustloeb	?kultuurielustloeb =kultuurielustloeb  (SgN  >kultuurielustloeb !22_S	et	f	\N
117242	kultuurielustloeb	?kultuurielustloeb =elustloeb  (SgN  >kultuuri+elustloeb !22_S	et	f	\N
117246	audeerimismaterjalid	?audeerimismaterjalid =audeerimismaterjali  (PlN  >audeerimismaterjal !02_S	et	f	\N
117247	audeerimismaterjalid	?audeerimismaterjalid =deerimismaterjali  (PlN  >au+deerimismaterjal !02_S	et	f	\N
117270	õpetusega	õpetusega =õpetuse  (SgKom  >õpetus !11_S	et	f	\N
117271	õpetusega	"õpetus %õpeta  )US_vS  <õpetama ;27_V	et	f	\N
117275	sotsiallsfääris	?sotsiallsfääris =sotsiallsfääri  (SgIn  >sotsiallsfääri !16_S	et	f	\N
117276	sotsiallsfääris	?sotsiallsfääris =sotsiallsfääri  (SgIn  >sotsiallsfäär !22_S	et	f	\N
117277	sotsiallsfääris	?sotsiallsfääris =sotsiallsfääri  (IndIpfSg3  >sotsiallsfäärima !28_V	et	f	\N
117278	sotsiallsfääris	?sotsiallsfääris =sotsiallsfääris  (SgN  >sotsiallsfääris !09_S	et	f	\N
117281	käitumis-	?käitumis- =käitumi  (SgIn  >käitumi !01_S	et	f	\N
117282	käitumis-	?käitumis- =käitumi  (SgIn  >käitum !02_A	et	f	\N
117283	käitumis-	?käitumis- =käitumis  (SgN  >käitumis !11_S	et	f	\N
117284	kultuurilukku	kultuurilukku =lukku  (SgP  >kultuuri+lukk !22_S	et	f	\N
117285	kultuurilukku	kultuurilukku =lukku  (SgAdt  >kultuuri+lugu !18_S	et	f	\N
117286	kultuurilukku	kultuurilukku =lukku  (SgAdt  >kultuuri+lukk !22_S	et	f	\N
117298	arusaama	arusaama =saama  (SgG  >aru+saam !22_S	et	f	\N
117299	arusaama	arusaama =saama  (SgP  >aru+saam !22_S	et	f	\N
117300	arusaama	arusaama =saama  (SgAdt  >aru+saam !22_S	et	f	\N
117315	kultuuriruumi	kultuuriruumi =ruumi  (SgG  >kultuuri+ruum !22_S	et	f	\N
117316	kultuuriruumi	kultuuriruumi =ruumi  (SgP  >kultuuri+ruum !22_S	et	f	\N
117317	kultuuriruumi	kultuuriruumi =ruumi  (SgAdt  >kultuuri+ruum !22_S	et	f	\N
117320	piirdu	piirdu =piirdu  (PlP  >piird !22_S	et	f	\N
117321	piirdu	piirdu =piirdu  (IndPrPs_  >piirduma !27_V	et	f	\N
117322	piirdu	piirdu =piirdu  (ImpPrSg2  >piirduma !27_V	et	f	\N
117329	stilistikast	stilistikast =stilistika  (SgEl  >stilistika !01_S	et	f	\N
117331	stilistikast	stilistikast =stilistikas  (SgP  >stilistikane !12_A	et	f	\N
117332	stilistikast	"stilistikane %stilistika  )NE_aA  <stilistika ;01_S	et	f	\N
117353	kreutzwald	?kreutzwald =kreutzwald  (SgN  >kreutzwald !02_S	et	f	\N
117356	koidula	?koidula =koidula  (SgN  >koidula !01_S	et	f	\N
117058	presidentsamas	?presidentsamas =presidentsama  (SgIn  >presidentsam !02_A	et	f	\N
117059	presidentsamas	?presidentsamas =sidentsama  (SgIn  >pre+sidentsam !02_A	et	f	\N
117064	õppimisele	õppimisele =õppimise  (SgAll  >õppimine !12_S	et	f	\N
117065	õppimisele	"õppimine %õppi  )MINE_vS  <õppima ;28_V	et	f	\N
117092	jagatud	jagatud =jaga  (PtsPtIps  >jagama !27_V	et	f	\N
117093	jagatud	jagatud =jagatu  (PlN  >jagatu !01_AS	et	f	\N
117094	jagatud	"jagatu %jaga  )TU1_vS  <jagama ;27_V	et	f	\N
117095	jagatud	jagatud =jagatud  (ID  >jagatud !41_A	et	f	\N
117096	jagatud	"jagatud %jaga  )TUD_vA  <jagama ;27_V	et	f	\N
117105	tähistamineülekoolilised	?tähistamineülekoolilised =tähistamineülekoolilise  (PlN  >tähistamineülekooliline !12_A	et	f	\N
117106	tähistamineülekoolilised	?tähistamineülekoolilised =tamineülekoolilise  (PlN  >tähis+tamineülekooliline !12_A	et	f	\N
117122	kõnekäände	kõnekäände =käände  (SgG  >kõne+kääne !06_S	et	f	\N
117123	kõnekäände	kõnekäände =käände  (PlP  >kõne+käänd !22_S	et	f	\N
117137	rahvuskultuuri	rahvuskultuuri =kultuuri  (SgG  >rahvus+kultuur !22_S	et	f	\N
117138	rahvuskultuuri	rahvuskultuuri =kultuuri  (SgP  >rahvus+kultuur !22_S	et	f	\N
117139	rahvuskultuuri	rahvuskultuuri =kultuuri  (SgAdt  >rahvus+kultuur !22_S	et	f	\N
117143	mööda	mööda =mööda  (ID  >mööda !41_A	et	f	\N
117144	mööda	mööda =mööda  (ID  >mööda !41_DK	et	f	\N
117155	olulisemaid	olulisemaid =olulisema  (PlP  >olulisem !02_A	et	f	\N
117156	olulisemaid	"olulisem %olu  )LISEM_cA  <olu ;17_S	et	f	\N
117157	olulisemaid	"olulisem %olulise  )M_cA  <oluline ;12_A	et	f	\N
117170	tähtsamatest	tähtsamatest =tähtsama  (PlEl  >tähtsam !02_A	et	f	\N
117172	tähtsamatest	"tähtsam %tähtsa  )M_cA  <tähtis ;02_A	et	f	\N
117174	tähtsamatest	tähtsamatest =test  (SgN  >täht+sama+test !22_S	et	f	\N
117180	legendidesttoimub	?legendidesttoimub =legendidesttoimu  (IndPrSg3  >legendidesttoimuma !27_V	et	f	\N
117194	kasutavad	kasutavad =kasuta  (IndPrPl3  >kasutama !27_V	et	f	\N
117195	kasutavad	kasutavad =kasutava  (PlN  >kasutav !02_A	et	f	\N
117196	kasutavad	"kasutav %kasuta  )V_vA  <kasutama ;27_V	et	f	\N
117197	kasutavad	kasutavad =tava  (PlN  >kasu+tava !17_S	et	f	\N
117210	teadsid	teadsid =tead  (IndIpfSg2  >teadma !34_V	et	f	\N
117211	teadsid	teadsid =tead  (IndIpfPl3  >teadma !34_V	et	f	\N
117217	üleliigseteks	üleliigseteks =sete  (PlTr  >üle+liig+sett !22_S	et	f	\N
117218	üleliigseteks	üleliigseteks =liigse  (PlTr  >üle+liigne !02_A	et	f	\N
117219	jmõpilane	?jmõpilane =jmõpilane  (SgN  >jmõpilane !12_S	et	f	\N
117220	jmõpilane	?jmõpilane =jmõpilane  (PlP  >jmõpilan !19_S	et	f	\N
117243	õpetamismeetodid	### õpetamismeetodid	et	f	\N
117253	õpetajal	õpetajal =õpetaja  (SgAd  >õpetaja !01_S	et	f	\N
117254	õpetajal	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
117264	puudutavatele	puudutavatele =puudutava  (PlAll  >puudutav !02_A	et	f	\N
117265	puudutavatele	"puudutav %puudu  )TAV_vAS  <puuduma ;27_V	et	f	\N
117266	puudutavatele	"puudutav %puuduta  )V_vA  <puudutama ;27_V	et	f	\N
117291	integreeritud	integreeritud =integreeri  (PtsPtIps  >integreerima !28_V	et	f	\N
117292	integreeritud	integreeritud =integreeritu  (PlN  >integreeritu !01_S	et	f	\N
117294	integreeritud	"integreeritu %integreeri  )TU1_vS  <integreerima ;28_V	et	f	\N
117296	integreeritud	integreeritud =integreeritud  (ID  >integreeritud !41_A	et	f	\N
117297	integreeritud	"integreeritud %integreeri  )TUD_vA  <integreerima ;28_V	et	f	\N
117330	ilukirjandusteksti	ilukirjandusteksti =teksti  (SgG  >ilu+kirjandus+tekst !22_S	et	f	\N
117333	ilukirjandusteksti	ilukirjandusteksti =teksti  (SgP  >ilu+kirjandus+tekst !22_S	et	f	\N
117334	ilukirjandusteksti	ilukirjandusteksti =teksti  (SgAdt  >ilu+kirjandus+tekst !22_S	et	f	\N
117347	õppesisu	õppesisu =sisu  (SgN  >õppe+sisu !17_S	et	f	\N
117348	õppesisu	õppesisu =sisu  (SgG  >õppe+sisu !17_S	et	f	\N
117349	õppesisu	õppesisu =sisu  (SgP  >õppe+sisu !17_S	et	f	\N
117361	haava	haava =haava  (SgG  >haab !22_S	et	f	\N
117362	haava	haava =haava  (SgG  >haav !22_S	et	f	\N
117363	haava	haava =haava  (SgP  >haav !22_S	et	f	\N
117364	haava	haava =haava  (SgAdt  >haav !22_S	et	f	\N
117365	haava	haava =haava  (IndPrPs_  >haavama !29_V	et	f	\N
117366	haava	haava =haava  (ImpPrSg2  >haavama !29_V	et	f	\N
117391	kirjanduslugu	kirjanduslugu =lugu  (SgN  >kirjandus+lugu !18_S	et	f	\N
117392	kirjanduslugu	kirjanduslugu =lugu  (SgP  >kirjandus+lugu !18_S	et	f	\N
117393	virgela	?virgela =virgela  (SgN  >virgela !01_S	et	f	\N
117394	virgela	?virgela =virgela  (SgG  >virgela !01_S	et	f	\N
117398	fraseoloogia	fraseoloogia =fraseoloogia  (SgN  >fraseoloogia !01_S	et	f	\N
117399	fraseoloogia	fraseoloogia =fraseoloogia  (SgG  >fraseoloogia !01_S	et	f	\N
117428	tunneks	tunneks =tunne  (PlTr  >tund !22_S	et	f	\N
117429	tunneks	tunneks =tunne  (KndPrPs  >tundma !34_V	et	f	\N
117430	geograafia	geograafia =geograafia  (SgN  >geograafia !01_S	et	f	\N
117431	geograafia	geograafia =geograafia  (SgG  >geograafia !01_S	et	f	\N
117434	seis	seis =seis  (ID  >seis !41_I	et	f	\N
117435	seis	seis =seis  (SgN  >seis !22_S	et	f	\N
117436	kiita	kiita =kii  (SgAb  >kii !26_S	et	f	\N
117437	kiita	kiita =kiit  (Inf  >kiitma !34_V	et	f	\N
117438	töötavatest	töötavatest =töötava  (PlEl  >töötav !02_A	et	f	\N
117076	emakeele	emakeele =kee  (SgAll  >ema+kesi !15_S	et	f	\N
117077	emakeele	emakeele =kee  (SgAll  >ema+kee !26_S	et	f	\N
117078	emakeele	emakeele =keele  (SgG  >ema+keel !13_S	et	f	\N
117086	tulemusi	tulemusi =tulemusi  (PlP  >tulemus !11_S	et	f	\N
117087	tulemusi	tulemusi =musi  (SgN  >tule+musi !17_S	et	f	\N
117088	tulemusi	tulemusi =musi  (SgG  >tule+musi !17_S	et	f	\N
117089	tulemusi	tulemusi =musi  (SgP  >tule+musi !17_S	et	f	\N
117102	emakeelepäeva	emakeelepäeva =päeva  (SgG  >ema+keele+päev !22_S	et	f	\N
117103	emakeelepäeva	emakeelepäeva =päeva  (SgP  >ema+keele+päev !22_S	et	f	\N
117104	emakeelepäeva	emakeelepäeva =päeva  (SgAdt  >ema+keele+päev !22_S	et	f	\N
117108	teabeesti	?teabeesti =teabeesti  (ID  >teabeesti !41_D	et	f	\N
117109	teabeesti	?teabeesti =teabeesti  (IndPrPs_  >teabeestima !28_V	et	f	\N
117110	teabeesti	?teabeesti =teabeesti  (ImpPrSg2  >teabeestima !28_V	et	f	\N
117111	teabeesti	?teabeesti =esti  (SgN  >teabe+esti !16_S	et	f	\N
117112	teabeesti	?teabeesti =esti  (SgG  >teabe+esti !16_S	et	f	\N
117113	teabeesti	?teabeesti =esti  (SgG  >teabe+est !22_S	et	f	\N
117114	teabeesti	?teabeesti =esti  (SgP  >teabe+est !22_S	et	f	\N
117115	teabeesti	?teabeesti =esti  (SgAdt  >teabe+est !22_S	et	f	\N
117116	kasutatavad	kasutatavad =kasutatava  (PlN  >kasutatav !02_A	et	f	\N
117117	kasutatavad	"kasutatav %kasuta  )TAV_vAS  <kasutama ;27_V	et	f	\N
117132	läbivatele	läbivatele =läbiva  (PlAll  >läbiv !02_A	et	f	\N
117133	läbivatele	"läbiv %läbi  )V_vA  <läbima ;27_V	et	f	\N
117134	läbivatele	läbivatele =vate  (PlAll  >läbi+vatt !22_S	et	f	\N
117145	teagi	teagi =tea  (IndPrPs_^  >teadma !34_V	et	f	\N
117146	teagi	teagi =tea  (ImpPrSg2^  >teadma !34_V	et	f	\N
117150	7klassi	klassi =klassi  (SgG  >klass !22_S	et	f	\N
117151	7klassi	klassi =klassi  (SgP  >klass !22_S	et	f	\N
117152	7klassi	klassi =klassi  (SgAdt  >klass !22_S	et	f	\N
117178	kultuuritegelastest	kultuuritegelastest =test  (SgN  >kultuuri+tegelas+test !22_S	et	f	\N
117179	kultuuritegelastest	kultuuritegelastest =tegelas  (PlEl  >kultuuri+tegelane !12_S	et	f	\N
117202	hümni	hümni =hümni  (SgG  >hümn !22_S	et	f	\N
117203	hümni	hümni =hümni  (SgP  >hümn !22_S	et	f	\N
117204	hümni	hümni =hümni  (SgAdt  >hümn !22_S	et	f	\N
117212	absoluutselt	absoluutselt =absoluutse  (SgAbl  >absoluutne !02_A	et	f	\N
117213	absoluutselt	absoluutselt =absoluutselt  (ID  >absoluutselt !41_D	et	f	\N
117214	absoluutselt	"absoluutselt %absoluutse  )LT_mD  <absoluutne ;02_A	et	f	\N
117226	alaseid	alaseid =alase  (PlP  >alasi !01_S	et	f	\N
117227	alaseid	alaseid =alase  (PlP  >alane !10_AS	et	f	\N
117228	alaseid	"alane %ala  )NE_aA  <ala ;17_S	et	f	\N
117244	video-	video- =video  (SgN  >video !01_S	et	f	\N
117245	video-	video- =video  (SgG  >video !01_S	et	f	\N
117267	10klassi	klassi =klassi  (SgG  >klass !22_S	et	f	\N
117268	10klassi	klassi =klassi  (SgP  >klass !22_S	et	f	\N
117269	10klassi	klassi =klassi  (SgAdt  >klass !22_S	et	f	\N
117287	lugupidavalt	lugupidavalt =pidava  (SgAbl  >lugu+pidav !02_A	et	f	\N
117288	lugupidavalt	"lugu+pidavalt %pidava  )LT_mD  <lugu+pidav ;02_A	et	f	\N
117289	tähtsaima	tähtsaima =tähtsaima  (SgG  >tähtsaim !02_A	et	f	\N
117290	tähtsaima	"tähtsaim %tähtsa  )IM_sA  <tähtis ;02_A	et	f	\N
117318	tunnetamine	tunnetamine =tunnetamine  (SgN  >tunnetamine !12_S	et	f	\N
117319	tunnetamine	"tunnetamine %tunneta  )MINE_vS  <tunnetama ;27_V	et	f	\N
117338	soodustavad	soodustavad =soodusta  (IndPrPl3  >soodustama !27_V	et	f	\N
117340	soodustavad	soodustavad =soodustava  (PlN  >soodustav !02_A	et	f	\N
117342	soodustavad	"soodustav %soodusta  )V_vA  <soodustama ;27_V	et	f	\N
117343	soodustavad	soodustavad =tava  (PlN  >soodus+tava !17_S	et	f	\N
117351	reinhold	?reinhold =reinhold  (SgN  >reinhold !22_S	et	f	\N
117352	reinhold	?reinhold =hold  (SgN  >rein+hold !22_S	et	f	\N
117371	luule	luule =luu  (SgAll  >luu !26_S	et	f	\N
117372	luule	luule =luule  (SgN  >luule !06_S	et	f	\N
117373	luule	luule =luule  (SgG  >luule !06_S	et	f	\N
117374	luule	luule =luule  (PlP  >luul !22_S	et	f	\N
117380	mati	mati =mati  (SgN  >mati !16_S	et	f	\N
117381	mati	mati =mati  (SgG  >mati !16_S	et	f	\N
117383	mati	mati =mati  (SgG  >matt !22_SA	et	f	\N
117385	kasutatav	kasutatav =kasuta  (PtsPrIps  >kasutama !27_V	et	f	\N
117386	kasutatav	kasutatav =kasutatav  (SgN  >kasutatav !02_A	et	f	\N
117387	kasutatav	"kasutatav %kasuta  )TAV_vAS  <kasutama ;27_V	et	f	\N
117397	õim	?õim =õim  (SgN  >õim !22_S	et	f	\N
117417	rahatähtedel	rahatähtedel =ede  (SgAd  >raha+täht+ede !16_S	et	f	\N
117418	rahatähtedel	rahatähtedel =edel  (SgN  >raha+täht+edel !02_S	et	f	\N
117419	rahatähtedel	rahatähtedel =tähte  (PlAd  >raha+täht !22_S	et	f	\N
117457	riiklikus	riiklikus =riikliku  (SgIn  >riiklik !25_A	et	f	\N
117458	riiklikus	riiklikus =riiklikus  (SgN  >riiklikus !11_S	et	f	\N
117459	riiklikus	"riiklikus %riikliku  )US_aS  <riiklik ;25_A	et	f	\N
117460	ruumi	ruumi =ruumi  (SgG  >ruum !22_S	et	f	\N
117461	ruumi	ruumi =ruumi  (SgP  >ruum !22_S	et	f	\N
117462	ruumi	ruumi =ruumi  (SgAdt  >ruum !22_S	et	f	\N
117463	ruumi	ruumi =ruumi  (IndPrPs_  >ruumima !28_V	et	f	\N
117084	saaksid	saaksid =saa  (KndPrSg2  >saama !37_V	et	f	\N
117085	saaksid	saaksid =saa  (KndPrPl3  >saama !37_V	et	f	\N
117090	rühmaks	rühmaks =rühma  (SgTr  >rühm !22_S	et	f	\N
117091	rühmaks	rühmaks =rühma  (KndPrPs  >rühmama !29_V	et	f	\N
117100	ülekooliline	ülekooliline =kooliline  (SgN  >üle+kooliline !12_A	et	f	\N
117101	ülekooliline	"üle+kooliline %kooli  )LINE_aA  <üle+kool ;22_S	et	f	\N
117118	meedia	meedia =meedia  (SgN  >meedia !01_S	et	f	\N
117119	meedia	meedia =meedia  (SgG  >meedia !01_S	et	f	\N
117120	meedia	meedia =dia  (SgN  >mee+dia !26_S	et	f	\N
117121	meedia	meedia =dia  (SgG  >mee+dia !26_S	et	f	\N
117127	pandud	pandud =pan  (PtsPtIps  >panema !36_V	et	f	\N
117128	pandud	pandud =pandu  (PlN  >pandu !01_S	et	f	\N
117129	pandud	"pandu %pan  )TU1_vS  <panema ;36_V	et	f	\N
117130	pandud	pandud =pandud  (ID  >pandud !41_A	et	f	\N
117131	pandud	"pandud %pan  )TUD_vA  <panema ;36_V	et	f	\N
117147	eestiga	eestiga =eesti  (SgKom  >eesti !16_H	et	f	\N
117148	eestiga	eestiga =iga  (SgN  >eest+iga !18_S	et	f	\N
117149	eestiga	eestiga =iga  (SgP  >eest+iga !18_S	et	f	\N
117181	pühendatud	pühendatud =pühenda  (PtsPtIps  >pühendama !27_V	et	f	\N
117182	pühendatud	pühendatud =pühendatu  (PlN  >pühendatu !01_S	et	f	\N
117183	pühendatud	"pühendatu %pühenda  )TU1_vS  <pühendama ;27_V	et	f	\N
117184	pühendatud	pühendatud =pühendatud  (ID  >pühendatud !41_A	et	f	\N
117185	pühendatud	"pühendatud %pühenda  )TUD_vA  <pühendama ;27_V	et	f	\N
117198	peaksid	peaksid =pea  (KndPrSg2  >pida !40_V	et	f	\N
117199	peaksid	peaksid =pea  (KndPrPl3  >pida !40_V	et	f	\N
117200	peaksid	peaksid =pea  (KndPrSg2  >pidama !28_V	et	f	\N
117201	peaksid	peaksid =pea  (KndPrPl3  >pidama !28_V	et	f	\N
117205	praktika	praktika =praktika  (SgN  >praktika !01_S	et	f	\N
117206	praktika	praktika =praktika  (SgG  >praktika !01_S	et	f	\N
117223	lutsu	lutsu =lutsu  (SgG  >luts !22_S	et	f	\N
117224	lutsu	lutsu =lutsu  (SgP  >luts !22_S	et	f	\N
117225	lutsu	lutsu =lutsu  (SgAdt  >luts !22_S	et	f	\N
117232	pane	pane =pane  (PlP  >pan !19_S	et	f	\N
117234	pane	pane =pane  (IndPrPs_  >panema !36_V	et	f	\N
117235	pane	pane =pane  (ImpPrSg2  >panema !36_V	et	f	\N
117248	põhikoolilõpetaja	põhikoolilõpetaja =lõpetaja  (SgN  >põhi+kooli+lõpetaja !01_S	et	f	\N
117249	põhikoolilõpetaja	põhikoolilõpetaja =lõpetaja  (SgG  >põhi+kooli+lõpetaja !01_S	et	f	\N
117255	puudu	puudu =puudu  (ID  >puudu !41_D	et	f	\N
117256	puudu	puudu =puudu  (IndPrPs_  >puuduma !27_V	et	f	\N
117257	puudu	puudu =puudu  (ImpPrSg2  >puuduma !27_V	et	f	\N
117261	igapäeva	igapäeva =päeva  (SgG  >iga+päev !22_S	et	f	\N
117262	igapäeva	igapäeva =päeva  (SgP  >iga+päev !22_S	et	f	\N
117263	igapäeva	igapäeva =päeva  (SgAdt  >iga+päev !22_S	et	f	\N
117272	proosateost	proosateost =teo  (SgEl  >proosa+tegu !18_S	et	f	\N
117273	proosateost	proosateost =teo  (SgEl  >proosa+tigu !18_S	et	f	\N
117274	proosateost	proosateost =teos  (SgP  >proosa+teos !09_S	et	f	\N
117301	vahekorrast	vahekorrast =korra  (SgEl  >vahe+kord !22_S	et	f	\N
117302	vahekorrast	vahekorrast =korras  (SgP  >vahe+korrane !10_A	et	f	\N
117303	vahekorrast	"vahe+korrane %korra  )NE_aA  <vahe+kord ;22_S	et	f	\N
117304	vaimsete	vaimsete =vaimse  (PlG  >vaimne !02_A	et	f	\N
117305	vaimsete	vaimsete =sete  (SgN  >vaim+sete !06_S	et	f	\N
117307	loomingulisi	loomingulisi =loomingulisi  (PlP  >loominguline !12_A	et	f	\N
117309	loomingulisi	"loominguline %loomingu  )LINE_aA  <looming ;02_S	et	f	\N
117311	arenemise	arenemise =arenemise  (SgG  >arenemine !12_S	et	f	\N
117312	arenemise	"arenemine %arene  )MINE_vS  <arenema ;27_V	et	f	\N
117313	õppetegevus	õppetegevus =tegevus  (SgN  >õppe+tegevus !11_S	et	f	\N
117314	õppetegevus	"õppe+tegevus %tegeva  )US_aS  <õppe+tegev ;02_A	et	f	\N
117327	ajaloolis-kultuuriliste	ajaloolis-kultuuriliste =kultuurilis  (PlG  >ajaloolis-kultuuriline !12_A	et	f	\N
117328	ajaloolis-kultuuriliste	"ajaloolis-kultuuriline %kultuuri  )LINE_aA  <ajaloolis-kultuur ;22_S	et	f	\N
117335	semiootikast	semiootikast =semiootika  (SgEl  >semiootika !01_S	et	f	\N
117336	semiootikast	semiootikast =semiootikas  (SgP  >semiootikane !12_A	et	f	\N
117337	semiootikast	"semiootikane %semiootika  )NE_aA  <semiootika ;01_S	et	f	\N
117345	raamatu	raamatu =raamatu  (SgG  >raamat !02_S	et	f	\N
117346	raamatu	raamatu =atu  (SgG  >raam+att !22_S	et	f	\N
117350	friedrich	?friedrich =friedrich  (SgN  >friedrich !22_S	et	f	\N
117367	friedebert	?friedebert =friedebert  (SgN  >friedebert !22_S	et	f	\N
117375	paul-eerik	?paul-eerik =eerik  (SgN  >paul-eerik !02_S	et	f	\N
117377	runnel	?runnel =runne  (PlAd  >runn !22_S	et	f	\N
117379	runnel	?runnel =runnel  (SgN  >runnel !02_S	et	f	\N
117400	eta	?eta =eta  (SgN  >eta !16_S	et	f	\N
117401	eta	?eta =eta  (SgG  >eta !16_S	et	f	\N
117403	eta	?eta =eta  (IndPrPs_  >etama !27_V	et	f	\N
117404	eta	?eta =eta  (ImpPrSg2  >etama !27_V	et	f	\N
117405	h	### h	et	f	\N
117415	suuda	suuda =suuda  (IndPrPs_  >suutma !34_V	et	f	\N
117416	suuda	suuda =suuda  (ImpPrSg2  >suutma !34_V	et	f	\N
117420	ununenud	ununenud =unune  (PtsPtPs  >ununema !27_V	et	f	\N
117421	ununenud	ununenud =ununenu  (PlN  >ununenu !01_S	et	f	\N
117187	aastapäevale	aastapäevale =ale  (SgG  >aasta+päev+ale !16_S	et	f	\N
117188	aastapäevale	aastapäevale =päeva  (SgAll  >aasta+päev !22_S	et	f	\N
117192	õpikuid	õpikuid =õpiku  (PlP  >õpik !02_S	et	f	\N
117193	õpikuid	õpikuid =ku  (PlP  >õpi+kuu !26_S	et	f	\N
117221	muinasjuttud	?muinasjuttud =muinasjuttu  (IndPrSg2  >muinasjuttuma !27_V	et	f	\N
117222	muinasjuttud	?muinasjuttud =juttud  (ID  >muinas+juttud !41_A	et	f	\N
117236	9klassi	klassi =klassi  (SgG  >klass !22_S	et	f	\N
117237	9klassi	klassi =klassi  (SgP  >klass !22_S	et	f	\N
117238	9klassi	klassi =klassi  (SgAdt  >klass !22_S	et	f	\N
117250	kanda	kanda =kand  (Inf  >kandma !34_V	et	f	\N
117251	kanda	kanda =kanda  (SgP  >kand !22_S	et	f	\N
117252	kanda	kanda =kanda  (SgAdt  >kand !22_S	et	f	\N
117258	grammtikale	?grammtikale =grammtika  (SgAll  >grammtika !01_S	et	f	\N
117259	grammtikale	?grammtikale =grammtika  (SgAll  >grammtikas !02_S	et	f	\N
117260	grammtikale	?grammtikale =grammtikale  (PlP  >grammtikal !19_S	et	f	\N
117279	ühiskonnale	ühiskonnale =ühiskonna  (SgAll  >ühiskond !22_S	et	f	\N
117280	ühiskonnale	ühiskonnale =konna  (SgAll  >ühis+konn !22_S	et	f	\N
117293	õpetuse	õpetuse =õpetuse  (SgG  >õpetus !11_S	et	f	\N
117295	õpetuse	"õpetus %õpeta  )US_vS  <õpetama ;27_V	et	f	\N
117306	lugejakultuuri	lugejakultuuri =kultuuri  (SgG  >lugeja+kultuur !22_S	et	f	\N
117308	lugejakultuuri	lugejakultuuri =kultuuri  (SgP  >lugeja+kultuur !22_S	et	f	\N
117310	lugejakultuuri	lugejakultuuri =kultuuri  (SgAdt  >lugeja+kultuur !22_S	et	f	\N
117323	biograafiliste	biograafiliste =biograafilis  (PlG  >biograafiline !12_A	et	f	\N
117324	biograafiliste	"biograafiline %biograafi  )LINE_aA  <biograaf ;22_S	et	f	\N
117325	biograafiliste	biograafiliste =graafilis  (PlG  >bio+graafiline !12_A	et	f	\N
117326	biograafiliste	"bio+graafiline %graafi  )LINE_aA  <bio+graaf ;22_S	et	f	\N
117339	initsiatiivi	initsiatiivi =initsiatiivi  (SgG  >initsiatiiv !22_S	et	f	\N
117341	initsiatiivi	initsiatiivi =initsiatiivi  (SgP  >initsiatiiv !22_S	et	f	\N
117344	initsiatiivi	initsiatiivi =initsiatiivi  (SgAdt  >initsiatiiv !22_S	et	f	\N
117354	lydia	?lydia =lydia  (SgN  >lydia !01_S	et	f	\N
117355	lydia	?lydia =lydia  (SgG  >lydia !01_S	et	f	\N
117368	tuglas	?tuglas =tugla  (SgIn  >tugla !16_S	et	f	\N
117369	tuglas	?tuglas =tugla  (IndIpfSg3  >tuglama !27_V	et	f	\N
117370	tuglas	?tuglas =tuglas  (SgN  >tuglas !07_S	et	f	\N
117376	hando	?hando =hando  (SgN  >hando !16_S	et	f	\N
117378	hando	?hando =hando  (SgG  >hando !16_S	et	f	\N
117382	unt	?unt =unt  (SgN  >unt !22_S	et	f	\N
117384	viiding	?viiding =viiding  (SgN  >viiding !02_S	et	f	\N
117389	koolibri	koolibri =koolibri  (SgN  >koolibri !01_S	et	f	\N
117390	koolibri	koolibri =koolibri  (SgG  >koolibri !01_S	et	f	\N
117395	lias	?lias =lia  (SgIn  >lia !26_S	et	f	\N
117396	lias	?lias =lias  (SgN  >lias !22_S	et	f	\N
117412	ulatuses	ulatuses =ulatuse  (SgIn  >ulatus !11_S	et	f	\N
117413	ulatuses	"ulatus %ulata  )US_vS  <ulatama ;27_V	et	f	\N
117414	ulatuses	"ulatus %ula  )TUS1_aS  <ulama ;27_V	et	f	\N
117442	õpetajatest	õpetajatest =õpetaja  (PlEl  >õpetaja !01_S	et	f	\N
117443	õpetajatest	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
117444	õpetajatest	õpetajatest =test  (SgN  >õpetaja+test !22_S	et	f	\N
117445	kiiksuga	kiiksuga =kiiksu  (SgKom  >kiiks !22_S	et	f	\N
117446	kiiksuga	kiiksuga =suga  (SgN  >kiik+suga !18_S	et	f	\N
117447	kiiksuga	kiiksuga =suga  (SgP  >kiik+suga !18_S	et	f	\N
117469	testidtest	?testidtest =testidte  (PlEl  >testidt !22_S	et	f	\N
117470	testidtest	?testidtest =testidtes  (SgP  >testidtene !12_A	et	f	\N
117471	testidtest	?testidtest =idte  (SgEl  >test+idte !06_S	et	f	\N
117472	testidtest	?testidtest =idte  (PlEl  >test+idt !22_S	et	f	\N
117473	testidtest	?testidtest =idtes  (SgP  >test+idtes !09_S	et	f	\N
117474	testidtest	?testidtest =idtes  (SgP  >test+idtene !12~10_A	et	f	\N
117480	harjutus	harjutus =harjutu  (SgIn  >harjutu !01_AS	et	f	\N
117481	harjutus	"harjutu %harju  )TU1_vS  <harjuma ;27_V	et	f	\N
117482	harjutus	harjutus =harjutus  (SgN  >harjutus !11_S	et	f	\N
117483	harjutus	"harjutus %harjuta  )US_vS  <harjutama ;27_V	et	f	\N
117484	harjutus	"harjutus %harju  )TUS1_aS  <harjuma ;27_V	et	f	\N
117487	küsimustest	küsimustest =küsimus  (PlEl  >küsimus !11_S	et	f	\N
117488	küsimustest	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
117489	küsimustest	küsimustest =muste  (PlEl  >küsi+must !22_AS	et	f	\N
117513	vastust	vastust =vastus  (SgP  >vastus !09_S	et	f	\N
117514	vastust	vastust =us  (SgP  >vast+uks !14_S	et	f	\N
117515	hakkkasid	?hakkkasid =hakkka  (IndIpfSg2  >hakkkama !29_V	et	f	\N
117516	hakkkasid	?hakkkasid =hakkka  (IndIpfPl3  >hakkkama !29_V	et	f	\N
117517	hakkkasid	?hakkkasid =kasi  (PlN  >hakk+kasi !17_S	et	f	\N
117523	küsimuseks	küsimuseks =küsimuse  (SgTr  >küsimus !11_S	et	f	\N
117524	küsimuseks	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
117541	õpilaneselline	?õpilaneselline =õpilaneselline  (SgN  >õpilaneselline !12_A	et	f	\N
117542	õpilaneselline	?õpilaneselline =laneselline  (SgN  >õpi+laneselline !12_A	et	f	\N
117557	puudutasid	puudutasid =puuduta  (IndIpfSg2  >puudutama !27_V	et	f	\N
117558	puudutasid	puudutasid =puuduta  (IndIpfPl3  >puudutama !27_V	et	f	\N
117357	koidula	?koidula =koidula  (SgG  >koidula !01_S	et	f	\N
117358	koidula	?koidula =dula  (SgN  >koi+dula !17_S	et	f	\N
117359	koidula	?koidula =dula  (SgG  >koi+dula !17_S	et	f	\N
117360	koidula	?koidula =dula  (SgP  >koi+dula !17_S	et	f	\N
117388	hennoste	?hennoste =hennos  (PlG  >hennos !11~09_S	et	f	\N
117402	kki	### kki	et	f	\N
117406	joonuks	joonuks =joo  (KndPtPs  >jooma !38_V	et	f	\N
117407	joonuks	joonuks =joonu  (SgTr  >joonu !01_S	et	f	\N
117408	joonuks	"joonu %joo  )NU_vS  <jooma ;38_V	et	f	\N
117409	joonuks	joonuks =joonu  (SgTr  >joonu !06_S	et	f	\N
117410	tunnise	tunnise =tunnise  (SgG  >tunnine !10_A	et	f	\N
117411	tunnise	"tunnine %tunni  )NE_aA  <tund ;22_S	et	f	\N
117425	teata	teata =tea  (IndPrIps_  >teadma !34_V	et	f	\N
117426	teata	teata =teata  (IndPrPs_  >teatama !27_V	et	f	\N
117427	teata	teata =teata  (ImpPrSg2  >teatama !27_V	et	f	\N
117432	muukeelses	muukeelses =eelse  (SgIn  >muuk+eelne !02_A	et	f	\N
117433	muukeelses	muukeelses =keelse  (SgIn  >muu+keelne !02_A	et	f	\N
117495	õpilast	õpilast =õpilas  (SgP  >õpilane !12_S	et	f	\N
117496	õpilast	õpilast =la  (SgEl  >õpi+la !26_S	et	f	\N
117497	õpilast	õpilast =las  (SgP  >õpi+laps !14_S	et	f	\N
117498	õpilast	õpilast =last  (SgN  >õpi+last !22_S	et	f	\N
117499	küsimiseks	küsimiseks =küsimise  (SgTr  >küsimine !12_S	et	f	\N
117500	küsimiseks	"küsimine %küsi  )MINE_vS  <küsima ;27_V	et	f	\N
117533	voldemar	?voldemar =voldemar  (SgN  >voldemar !19_S	et	f	\N
117537	pacius	?pacius =paciu  (SgIn  >paciu !01_S	et	f	\N
117538	pacius	?pacius =pacius  (SgN  >pacius !11_S	et	f	\N
117548	koidulat	?koidulat =koidula  (SgP  >koidula !01_S	et	f	\N
117549	koidulat	?koidulat =dulat  (SgN  >koi+dulat !02_S	et	f	\N
117552	jannseni	?jannseni =jannse  (SgTer  >jannne !02_A	et	f	\N
117554	jannseni	?jannseni =jannse  (SgTer  >jannse !06_S	et	f	\N
117556	jannseni	?jannseni =jannseni  (SgG  >jannsen !02_S	et	f	\N
117590	laulupeost	laulupeost =peo  (SgEl  >laulu+pidu !18_S	et	f	\N
117591	laulupeost	laulupeost =peo  (SgEl  >laulu+peo !26_S	et	f	\N
117598	pakutud	pakutud =paku  (PtsPtIps  >pakkuma !28_V	et	f	\N
117599	pakutud	pakutud =pakutu  (PlN  >pakutu !01_S	et	f	\N
117600	pakutud	"pakutu %paku  )TU1_vS  <pakkuma ;28_V	et	f	\N
117601	pakutud	"pakutu %paku  )TU2_kA  <pakk ;22_S	et	f	\N
117602	pakutud	pakutud =pakutud  (ID  >pakutud !41_A	et	f	\N
117603	pakutud	"pakutud %paku  )TUD_vA  <pakkuma ;28_V	et	f	\N
117627	jannsenpaljud	?jannsenpaljud =jannsenpalju  (IndPrSg2  >jannsenpaljuma !27_V	et	f	\N
117651	rääkidantminna	?rääkidantminna =rääkidantminna  (SgN  >rääkidantminna !16_S	et	f	\N
117652	rääkidantminna	?rääkidantminna =rääkidantminna  (SgG  >rääkidantminna !16_S	et	f	\N
117673	vastust16	vastust =vastus  (SgP  >vastus !09_S	et	f	\N
117674	vastust16	vastust =us  (SgP  >vast+uks !14_S	et	f	\N
117675	detsembermiks	?detsembermiks =detsembermi  (SgTr  >detsemberm !22_S	et	f	\N
117676	detsembermiks	?detsembermiks =detsembermi  (KndPrPs  >detsembermima !28_V	et	f	\N
117692	puudumist	puudumist =puudumis  (SgP  >puudumine !12_S	et	f	\N
117693	puudumist	"puudumine %puudu  )MINE_vS  <puuduma ;27_V	et	f	\N
117701	küsitlenust	küsitlenust =küsitlenu  (SgEl  >küsitlenu !01_S	et	f	\N
117702	küsitlenust	"küsitlenu %küsitle  )NU_vS  <küsitlema ;27_V	et	f	\N
117708	pakusid	?pakusid =paku  (PlP  >paku !16_S	et	f	\N
117709	pakusid	?pakusid =paku  (IndIpfSg2  >pakuma !27_V	et	f	\N
117710	pakusid	?pakusid =paku  (IndIpfPl3  >pakuma !27_V	et	f	\N
117727	sõnavara	sõnavara =vara  (SgN  >sõna+vara !17_S	et	f	\N
117728	sõnavara	sõnavara =vara  (SgG  >sõna+vara !17_S	et	f	\N
117729	sõnavara	sõnavara =vara  (SgP  >sõna+vara !17_S	et	f	\N
117732	ajasid	ajasid =aja  (IndIpfSg2  >ajama !27_V	et	f	\N
117733	ajasid	ajasid =aja  (IndIpfPl3  >ajama !27_V	et	f	\N
117741	vastanud	vastanud =vasta  (PtsPtPs  >vastama !29_V	et	f	\N
117742	vastanud	vastanud =vastanu  (PlN  >vastanu !01_S	et	f	\N
117743	vastanud	"vastanu %vasta  )NU_vS  <vastama ;29_V	et	f	\N
117744	vastanud	vastanud =vastanud  (ID  >vastanud !41_A	et	f	\N
117745	vastanud	"vastanud %vasta  )NUD_vA  <vastama ;29_V	et	f	\N
117772	teadmine	teadmine =teadmine  (SgN  >teadmine !12?10_S	et	f	\N
117773	teadmine	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
117782	rahvakalendristnimelt	?rahvakalendristnimelt =rahvakalendristnimelt  (ID  >rahvakalendristnimelt !41_D	et	f	\N
117793	rahvuspidusid	rahvuspidusid =pidu  (PlP  >rahvus+pidu !17_S	et	f	\N
117794	rahvuspidusid	rahvuspidusid =pidu  (PlP  >rahvus+pidu !18_S	et	f	\N
117830	mainisid	mainisid =maini  (IndIpfSg2  >mainima !28_V	et	f	\N
117831	mainisid	mainisid =maini  (IndIpfPl3  >mainima !28_V	et	f	\N
117832	tammsaarevilde	?tammsaarevilde =tammsaarevilde  (PlP  >tammsaarevild !22_S	et	f	\N
117833	tammsaarevilde	?tammsaarevilde =vilde  (SgN  >tamm+saare+vilde !06_S	et	f	\N
117834	tammsaarevilde	?tammsaarevilde =vilde  (SgG  >tamm+saare+ville !06_S	et	f	\N
117835	tammsaarevilde	?tammsaarevilde =vilde  (PlP  >tamm+saare+vild !22_S	et	f	\N
117836	tammsaarevilde	?tammsaarevilde =saarevilde  (PlP  >tamm+saarevild !22_S	et	f	\N
117871	olevaid	olevaid =oleva  (PlP  >olev !02_A	et	f	\N
117872	olevaid	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
117422	ununenud	"ununenu %unune  )NU_vS  <ununema ;27_V	et	f	\N
117423	ununenud	ununenud =ununenud  (ID  >ununenud !41_A	et	f	\N
117424	ununenud	"ununenud %unune  )NUD_vA  <ununema ;27_V	et	f	\N
117448	lootustki	lootustki =lootu  (SgEl^  >lootu !01_A	et	f	\N
117449	lootustki	"lootu %loo  )TU2_kA^  <lugu ;18_S	et	f	\N
117450	lootustki	"lootu %loo  )TU2_kA^  <loog ;22_S	et	f	\N
117451	lootustki	"lootu %loo  )TU2_kA^  <lood ;22_S	et	f	\N
117452	lootustki	lootustki =lootus  (SgP^  >lootus !11~09_S	et	f	\N
117453	lootustki	"lootus %loo  )TUS2_aS^  <lugu ;18_S	et	f	\N
117454	lootustki	"lootus %loo  )TUS2_aS^  <loog ;22_S	et	f	\N
117455	lootustki	"lootus %loo  )TUS2_aS^  <lood ;22_S	et	f	\N
117456	lootustki	lootustki =tust  (SgN^  >loo+tust !22_S	et	f	\N
117467	tõestamiseks	tõestamiseks =tõestamise  (SgTr  >tõestamine !12_S	et	f	\N
117468	tõestamiseks	"tõestamine %tõesta  )MINE_vS  <tõestama ;27_V	et	f	\N
117475	tühja	tühja =tühja  (SgG  >tühi !24_A	et	f	\N
117476	tühja	tühja =tühja  (SgP  >tühi !24_A	et	f	\N
117477	tühja	tühja =tühja  (SgAdt  >tühi !24_A	et	f	\N
117485	testivarianti	testivarianti =varianti  (SgP  >testi+variant !22_S	et	f	\N
117486	testivarianti	testivarianti =varianti  (SgAdt  >testi+variant !22_S	et	f	\N
117490	küsitud	küsitud =küsi  (PtsPtIps  >küsima !27_V	et	f	\N
117491	küsitud	küsitud =küsitu  (PlN  >küsitu !01_AS	et	f	\N
117492	küsitud	"küsitu %küsi  )TU1_vS  <küsima ;27_V	et	f	\N
117493	küsitud	küsitud =küsitud  (ID  >küsitud !41_A	et	f	\N
117494	küsitud	"küsitud %küsi  )TUD_vA  <küsima ;27_V	et	f	\N
117501	vastusteks	vastusteks =vastus  (PlTr  >vastus !09_S	et	f	\N
117502	vastusteks	vastusteks =us  (PlTr  >vast+uks !14_S	et	f	\N
117503	lippuhümni	?lippuhümni =lippuhümni  (SgG  >lippuhümn !22_S	et	f	\N
117504	lippuhümni	?lippuhümni =lippuhümni  (SgP  >lippuhümn !22_S	et	f	\N
117505	lippuhümni	?lippuhümni =lippuhümni  (SgAdt  >lippuhümn !22_S	et	f	\N
117506	lippuhümni	?lippuhümni =lippuhümni  (IndPrPs_  >lippuhümnima !28_V	et	f	\N
117507	lippuhümni	?lippuhümni =lippuhümni  (ImpPrSg2  >lippuhümnima !28_V	et	f	\N
117508	lippuhümni	?lippuhümni =uhümni  (SgN  >lipp+uhümni !01_S	et	f	\N
117509	lippuhümni	?lippuhümni =uhümni  (SgG  >lipp+uhümni !01_S	et	f	\N
117510	lippuhümni	?lippuhümni =uhümni  (SgG  >lipp+uhümn !22_S	et	f	\N
117511	lippuhümni	?lippuhümni =uhümni  (SgP  >lipp+uhümn !22_S	et	f	\N
117512	lippuhümni	?lippuhümni =uhümni  (SgAdt  >lipp+uhümn !22_S	et	f	\N
117518	rahvuslindlillkivi	rahvuslindlillkivi =kivi  (SgN  >rahvus+lind+lill+kivi !17_S	et	f	\N
117519	rahvuslindlillkivi	rahvuslindlillkivi =kivi  (SgG  >rahvus+lind+lill+kivi !17_S	et	f	\N
117520	rahvuslindlillkivi	rahvuslindlillkivi =kivi  (SgP  >rahvus+lind+lill+kivi !17_S	et	f	\N
117521	küsimusedteiseks	?küsimusedteiseks =küsimusedteise  (PlTr  >küsimusedteis !22_S	et	f	\N
117522	küsimusedteiseks	?küsimusedteiseks =musedteise  (PlTr  >küsi+musedteis !22_S	et	f	\N
117525	jakob	?jakob =jakob  (SgN  >jakob !02_S	et	f	\N
117536	arvasidet	### arvasidet	et	f	\N
117539	vastust-lydia	?vastust-lydia =lydia  (SgN  >vastust-lydia !01_S	et	f	\N
117540	vastust-lydia	?vastust-lydia =lydia  (SgG  >vastust-lydia !01_S	et	f	\N
117562	kõikidel	kõikidel =kõiki  (PlAd  >kõik !00_P	et	f	\N
117563	kõikidel	kõikidel =kõiki  (PlAd  >kõik !22_S	et	f	\N
117569	rahvuspuu	rahvuspuu =puu  (SgN  >rahvus+puu !26_S	et	f	\N
117570	rahvuspuu	rahvuspuu =puu  (SgG  >rahvus+puu !26_S	et	f	\N
117585	oodanud	oodanud =ooda  (PtsPtPs  >ootama !29_V	et	f	\N
117586	oodanud	oodanud =oodanu  (PlN  >oodanu !01_S	et	f	\N
117587	oodanud	"oodanu %ooda  )NU_vS  <ootama ;29_V	et	f	\N
117588	oodanud	oodanud =oodanud  (ID  >oodanud !41_A	et	f	\N
117589	oodanud	"oodanud %ooda  )NUD_vA  <ootama ;29_V	et	f	\N
117604	vastuseidseal	?vastuseidseal =vastuseidsea  (SgAd  >vastuseidsea !26_S	et	f	\N
117605	vastuseidseal	?vastuseidseal =vastuseidseal  (SgN  >vastuseidseal !19_S	et	f	\N
117606	vastuseidseal	?vastuseidseal =dsea  (SgAd  >vastus+ei+dsea !26_S	et	f	\N
117607	vastuseidseal	?vastuseidseal =dseal  (SgN  >vastus+ei+dseal !22_S	et	f	\N
117608	vastuseidseal	?vastuseidseal =eidsea  (SgAd  >vastus+eidsea !26_S	et	f	\N
117609	vastuseidseal	?vastuseidseal =eidseal  (SgN  >vastus+eidseal !19_S	et	f	\N
117611	vastuseidseal	?vastuseidseal =seidsea  (SgAd  >vastu+seidsea !26_S	et	f	\N
117612	vastuseidseal	?vastuseidseal =seidseal  (SgN  >vastu+seidseal !19_S	et	f	\N
117614	vastuseidseal	?vastuseidseal =useidsea  (SgAd  >vast+useidsea !26_S	et	f	\N
117617	vastuseidseal	?vastuseidseal =useidseal  (SgN  >vast+useidseal !19_S	et	f	\N
117711	vastuseidselle	?vastuseidselle =vastuseidselle  (PlP  >vastuseidsell !22_S	et	f	\N
117712	vastuseidselle	?vastuseidselle =dselle  (SgN  >vastus+ei+dselle !06_S	et	f	\N
117714	vastuseidselle	?vastuseidselle =dselle  (PlP  >vastus+ei+dsell !22_S	et	f	\N
117716	vastuseidselle	?vastuseidselle =eidselle  (PlP  >vastus+eidsell !22_S	et	f	\N
117718	vastuseidselle	?vastuseidselle =seidselle  (PlP  >vastu+seidsell !22_S	et	f	\N
117719	vastuseidselle	?vastuseidselle =useidselle  (PlP  >vast+useidsell !22_S	et	f	\N
117720	sellekset	?sellekset =sellekse  (SgP  >sellekne !02_A	et	f	\N
117755	õppeteksti	õppeteksti =teksti  (SgG  >õppe+tekst !22_S	et	f	\N
117756	õppeteksti	õppeteksti =teksti  (SgP  >õppe+tekst !22_S	et	f	\N
117439	töötavatest	"töötav %tööta  )V_vA  <töötama ;27_V	et	f	\N
117440	töötavatest	töötavatest =test  (SgN  >töö+tava+test !22_S	et	f	\N
117441	töötavatest	töötavatest =vate  (PlEl  >tööta+vatt !22_S	et	f	\N
117478	hindeline	hindeline =hindeline  (SgN  >hindeline !12_A	et	f	\N
117479	hindeline	"hindeline %hinde  )LINE_aA  <hinne ;06_S	et	f	\N
117527	voldemarperekonnanimi	?voldemarperekonnanimi =voldemarperekonnanimi  (SgG  >voldemarperekonnanim !02_A	et	f	\N
117534	jansen	?jansen =janse  (IndPrSg1  >jansema !27_V	et	f	\N
117535	jansen	?jansen =jansen  (SgN  >jansen !02_S	et	f	\N
117553	juhendamise	juhendamise =juhendamise  (SgG  >juhendamine !12_S	et	f	\N
117555	juhendamise	"juhendamine %juhenda  )MINE_vS  <juhendama ;27_V	et	f	\N
117571	korratakse	korratakse =korra  (IndPrIps  >kordama !29_V	et	f	\N
117572	korratakse	korratakse =takse  (PlP  >korra+taks !22_S	et	f	\N
117583	presidendist	presidendist =presidendi  (SgEl  >president !22_S	et	f	\N
117584	presidendist	presidendist =sidendi  (SgEl  >pre+sidend !02_S	et	f	\N
117610	laulavad	laulavad =laula  (IndPrPl3  >laulma !33_V	et	f	\N
117613	laulavad	laulavad =lava  (PlN  >lau+lava !17_S	et	f	\N
117624	esimeneoli	?esimeneoli =esimeneoli  (SgN  >esimeneoli !16_S	et	f	\N
117625	esimeneoli	?esimeneoli =esimeneoli  (SgG  >esimeneoli !16_S	et	f	\N
117626	esimeneoli	?esimeneoli =esimeneoli  (SgG  >esimeneol !19_S	et	f	\N
117628	esimeneoli	?esimeneoli =esimeneoli  (SgP  >esimeneol !19_S	et	f	\N
117629	esimeneoli	?esimeneoli =esimeneoli  (SgAdt  >esimeneol !19_S	et	f	\N
117630	esimeneoli	?esimeneoli =esimeneoli  (IndPrPs_  >esimeneolima !28_V	et	f	\N
117631	esimeneoli	?esimeneoli =esimeneoli  (ImpPrSg2  >esimeneolima !28_V	et	f	\N
117632	esimeneoli	?esimeneoli =meneoli  (SgN  >esi+meneoli !16_S	et	f	\N
117633	esimeneoli	?esimeneoli =meneoli  (SgG  >esi+meneoli !16_S	et	f	\N
117634	esimeneoli	?esimeneoli =meneoli  (SgG  >esi+meneol !19_S	et	f	\N
117635	esimeneoli	?esimeneoli =meneoli  (SgP  >esi+meneol !19_S	et	f	\N
117636	esimeneoli	?esimeneoli =meneoli  (SgAdt  >esi+meneol !19_S	et	f	\N
117653	iseseisvuspäeva	iseseisvuspäeva =päeva  (SgG  >ise+seisvus+päev !22_S	et	f	\N
117654	iseseisvuspäeva	iseseisvuspäeva =päeva  (SgP  >ise+seisvus+päev !22_S	et	f	\N
117656	iseseisvuspäeva	iseseisvuspäeva =päeva  (SgAdt  >ise+seisvus+päev !22_S	et	f	\N
117678	nimet	?nimet =nime  (SgP  >nime !16_S	et	f	\N
117679	vastustoli	?vastustoli =toli  (SgN  >vastus+toli !17_S	et	f	\N
117680	vastustoli	?vastustoli =toli  (SgG  >vastus+toli !17_S	et	f	\N
117681	vastustoli	?vastustoli =toli  (SgP  >vastus+toli !17_S	et	f	\N
117682	vastustoli	?vastustoli =stoli  (SgN  >vastu+stoli !17_S	et	f	\N
117683	vastustoli	?vastustoli =stoli  (SgG  >vastu+stoli !17_S	et	f	\N
117684	vastustoli	?vastustoli =stoli  (SgP  >vastu+stoli !17_S	et	f	\N
117685	vastustoli	?vastustoli =ustoli  (SgG  >vast+ustol !02_S	et	f	\N
117686	vastatakalevipoja	?vastatakalevipoja =vastatakalevipoja  (SgN  >vastatakalevipoja !01_S	et	f	\N
117687	vastatakalevipoja	?vastatakalevipoja =vastatakalevipoja  (SgG  >vastatakalevipoja !01_S	et	f	\N
117688	vastatakalevipoja	?vastatakalevipoja =vastatakalevipoja  (SgG  >vastatakalevipojas !02_A	et	f	\N
117689	vastatakalevipoja	?vastatakalevipoja =atakalevipoja  (SgN  >vast+atakalevipoja !01_S	et	f	\N
117690	vastatakalevipoja	?vastatakalevipoja =atakalevipoja  (SgG  >vast+atakalevipoja !01_S	et	f	\N
117691	vastatakalevipoja	?vastatakalevipoja =atakalevipoja  (SgG  >vast+atakalevipojas !02_A	et	f	\N
117699	rahvuslaule	rahvuslaule =lau  (SgAll  >rahvus+laug !22_SA	et	f	\N
117700	rahvuslaule	rahvuslaule =laule  (PlP  >rahvus+laul !22_S	et	f	\N
117703	rahvuslauluks	rahvuslauluks =luks  (SgN  >rahvus+lau+luks !22_S	et	f	\N
117704	rahvuslauluks	rahvuslauluks =luks  (SgN  >rahvus+lau+luks !22_SA	et	f	\N
117705	rahvuslauluks	rahvuslauluks =laulu  (SgTr  >rahvus+laul !22_S	et	f	\N
117713	alusel	alusel =aluse  (SgAd  >alus !09_S	et	f	\N
117715	alusel	alusel =aluse  (SgAd  >alune !10_AS	et	f	\N
117717	alusel	"alune %alu  )NE_aA  <alg ;22_S	et	f	\N
117721	rahvuslaul	rahvuslaul =lau  (SgAd  >rahvus+laug !22_SA	et	f	\N
117722	rahvuslaul	rahvuslaul =laul  (SgN  >rahvus+laul !22_S	et	f	\N
117734	segamini	segamini =segamini  (ID  >segamini !41_DA	et	f	\N
117735	segamini	segamini =mi  (SgTer  >sega+mi !26_S	et	f	\N
117736	segamini	segamini =mini  (SgN  >sega+mini !17~16_S	et	f	\N
117737	segamini	segamini =mini  (SgG  >sega+mini !17~16_S	et	f	\N
117738	segamini	segamini =mini  (SgP  >sega+mini !17_S	et	f	\N
117758	teksti	teksti =teksti  (SgG  >tekst !22_S	et	f	\N
117759	teksti	teksti =teksti  (SgP  >tekst !22_S	et	f	\N
117760	teksti	teksti =teksti  (SgAdt  >tekst !22_S	et	f	\N
117768	küsimusega	küsimusega =küsimuse  (SgKom  >küsimus !11_S	et	f	\N
117769	küsimusega	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
117774	tasemeltestis	?tasemeltestis =tasemeltesti  (IndIpfSg3  >tasemeltestima !28_V	et	f	\N
117775	tasemeltestis	?tasemeltestis =tasemeltestis  (SgN  >tasemeltestis !09_S	et	f	\N
117776	muisete	?muisete =muise  (PlG  >muise !06_S	et	f	\N
117777	muisete	?muisete =muise  (IndPrPl2  >muisema !28_V	et	f	\N
117791	kõlas	kõlas =kõla  (SgIn  >kõla !17_S	et	f	\N
117792	kõlas	kõlas =kõla  (IndIpfSg3  >kõlama !27_V	et	f	\N
117837	smuul	?smuul =smuu  (SgAd  >smuu !26_S	et	f	\N
117464	ruumi	ruumi =ruumi  (ImpPrSg2  >ruumima !28_V	et	f	\N
117465	testid	testid =testi  (PlN  >test !22_S	et	f	\N
117466	testid	testid =testi  (IndPrSg2  >testima !28_V	et	f	\N
117526	jakobson	?jakobson =jakobson  (SgN  >jakobson !19_S	et	f	\N
117528	kirjutanud	kirjutanud =kirjuta  (PtsPtPs  >kirjutama !27_V	et	f	\N
117529	kirjutanud	kirjutanud =kirjutanu  (PlN  >kirjutanu !01_S	et	f	\N
117530	kirjutanud	"kirjutanu %kirjuta  )NU_vS  <kirjutama ;27_V	et	f	\N
117531	kirjutanud	kirjutanud =kirjutanud  (ID  >kirjutanud !41_A	et	f	\N
117532	kirjutanud	"kirjutanud %kirjuta  )NUD_vA  <kirjutama ;27_V	et	f	\N
117543	põhjustatud	põhjustatud =põhjusta  (PtsPtIps  >põhjustama !27_V	et	f	\N
117544	põhjustatud	põhjustatud =põhjustatu  (PlN  >põhjustatu !01_S	et	f	\N
117545	põhjustatud	"põhjustatu %põhjusta  )TU1_vS  <põhjustama ;27_V	et	f	\N
117546	põhjustatud	põhjustatud =põhjustatud  (ID  >põhjustatud !41_A	et	f	\N
117547	põhjustatud	"põhjustatud %põhjusta  )TUD_vA  <põhjustama ;27_V	et	f	\N
117550	arvati	arvati =arva  (IndIpfIps  >arvama !29_V	et	f	\N
117551	arvati	arvati =ati  (SgG  >arv+att !22_S	et	f	\N
117637	laulupidu10	laulupidu =pidu  (SgN  >laulu+pidu !17_S	et	f	\N
117638	laulupidu10	laulupidu =pidu  (SgN  >laulu+pidu !18_S	et	f	\N
117639	laulupidu10	laulupidu =pidu  (SgG  >laulu+pidu !17_S	et	f	\N
117640	laulupidu10	laulupidu =pidu  (SgP  >laulu+pidu !17_S	et	f	\N
117641	laulupidu10	laulupidu =pidu  (SgP  >laulu+pidu !18_S	et	f	\N
117642	maininud	maininud =maini  (PtsPtPs  >mainima !28_V	et	f	\N
117643	maininud	maininud =maininu  (PlN  >maininu !01_S	et	f	\N
117644	maininud	"maininu %maini  )NU_vS  <mainima ;28_V	et	f	\N
117645	maininud	maininud =maininud  (ID  >maininud !41_A	et	f	\N
117646	maininud	"maininud %maini  )NUD_vA  <mainima ;28_V	et	f	\N
117647	lähimalt	lähimalt =lähima  (SgAbl  >lähim !02_A	et	f	\N
117648	lähimalt	"lähim %lähi  )IM_sA  <lähike ;12_A	et	f	\N
117649	lähimalt	lähimalt =lähimalt  (ID  >lähimalt !41_D	et	f	\N
117650	lähimalt	"lähimalt %lähima  )LT_mD  <lähim ;02_A	et	f	\N
117677	sellisedseda	### sellisedseda	et	f	\N
117739	ükski	ükski =üks  (SgN  >ükski !00_P	et	f	\N
117740	ükski	ükski =üks  (SgN^  >üks !22_NP	et	f	\N
117751	kasutamise	kasutamise =kasutamise  (SgG  >kasutamine !12_S	et	f	\N
117752	kasutamise	"kasutamine %kasuta  )MINE_vS  <kasutama ;27_V	et	f	\N
117753	kõnema	?kõnema =kõne  (Sup  >kõnema !27_V	et	f	\N
117754	kõnema	?kõnema =kõnema  (SgG  >kõnem !02_A	et	f	\N
117787	teavadkõige	?teavadkõige =teavadkõige  (PlP  >teavadkõig !22_S	et	f	\N
117807	nimetati	nimetati =nimeta  (IndIpfIps  >nimetama !27_V	et	f	\N
117808	nimetati	nimetati =tati  (SgG  >nime+tatt !22_S	et	f	\N
117809	eno	?eno =eno  (SgN  >eno !17~16_S	et	f	\N
117810	eno	?eno =eno  (SgG  >eno !17~16_S	et	f	\N
117811	eno	?eno =eno  (SgP  >eno !17_S	et	f	\N
117826	ellen	?ellen =elle  (IndPrSg1  >ellema !30_V	et	f	\N
117827	ellen	?ellen =ellen  (SgN  >ellen !02_S	et	f	\N
117841	sattunud	sattunud =sattu  (PtsPtPs  >sattuma !27~28_V	et	f	\N
117842	sattunud	sattunud =sattunu  (PlN  >sattunu !01_S	et	f	\N
117843	sattunud	"sattunu %sattu  )NU_vS  <sattuma ;27_V	et	f	\N
117844	sattunud	"sattunu %sattu  )NU_vS  <sattuma ;28_V	et	f	\N
117845	sattunud	sattunud =sattunud  (ID  >sattunud !41_A	et	f	\N
117847	sattunud	"sattunud %sattu  )NUD_vA  <sattuma ;27_V	et	f	\N
117849	sattunud	"sattunud %sattu  )NUD_vA  <sattuma ;28_V	et	f	\N
117850	rudolph	?rudolph =rudolph  (SgN  >rudolph !22_S	et	f	\N
117857	küsimustega	küsimustega =küsimus  (PlKom  >küsimus !11_S	et	f	\N
117858	küsimustega	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
117866	lavastusedpaljud	?lavastusedpaljud =lavastusedpalju  (IndPrSg2  >lavastusedpaljuma !27_V	et	f	\N
117868	lavastusedpaljud	?lavastusedpaljud =edpalju  (PlN  >lavastus+edpalju !01_S	et	f	\N
117892	teadis	teadis =tead  (IndIpfSg3  >teadma !34_V	et	f	\N
117893	teadis	teadis =teadis  (SgN  >teadis !09_S	et	f	\N
117929	onteater	?onteater =onteater  (SgN  >onteater !02_S	et	f	\N
117954	tetritest	?tetritest =tetri  (PlEl  >tetter !02_S	et	f	\N
117955	tetritest	?tetritest =tetrite  (PlEl  >tetritt !22_S	et	f	\N
117956	tetritest	?tetritest =tetrites  (SgP  >tetritene !12_A	et	f	\N
117969	õpetamisele	õpetamisele =õpetamise  (SgAll  >õpetamine !12_S	et	f	\N
117970	õpetamisele	"õpetamine %õpeta  )MINE_vS  <õpetama ;27_V	et	f	\N
117971	korraldatav	korraldatav =korralda  (PtsPrIps  >korraldama !27_V	et	f	\N
117972	korraldatav	korraldatav =korraldatav  (SgN  >korraldatav !02_A	et	f	\N
117973	korraldatav	"korraldatav %korralda  )TAV_vAS  <korraldama ;27_V	et	f	\N
117997	õigestiseega	?õigestiseega =õigestisee  (SgKom  >õigestisee !26_S	et	f	\N
117998	õigestiseega	?õigestiseega =õigestiseega  (SgN  >õigestiseega !16_S	et	f	\N
117999	õigestiseega	?õigestiseega =õigestiseega  (SgG  >õigestiseega !16_S	et	f	\N
118000	õigestiseega	?õigestiseega =stisee  (SgKom  >õige+stisee !26_S	et	f	\N
118001	õigestiseega	?õigestiseega =stiseega  (SgN  >õige+stiseega !16_S	et	f	\N
118002	õigestiseega	?õigestiseega =stiseega  (SgG  >õige+stiseega !16_S	et	f	\N
118005	hümniõpilastel	hümniõpilastel =las  (PlAd  >hümni+õpi+laps !14_S	et	f	\N
118006	hümniõpilastel	hümniõpilastel =laste  (PlAd  >hümni+õpi+last !22_S	et	f	\N
117559	rahvuslidu	rahvuslidu =lidu  (SgN  >rahvus+lidu !17_S	et	f	\N
117560	rahvuslidu	rahvuslidu =lidu  (SgG  >rahvus+lidu !17_S	et	f	\N
117561	rahvuslidu	rahvuslidu =lidu  (SgP  >rahvus+lidu !17_S	et	f	\N
117564	suutnud	suutnud =suut  (PtsPtPs  >suutma !34_V	et	f	\N
117565	suutnud	suutnud =suutnu  (PlN  >suutnu !01_S	et	f	\N
117566	suutnud	"suutnu %suut  )NU_vS  <suutma ;34_V	et	f	\N
117567	suutnud	suutnud =suutnud  (ID  >suutnud !41_A	et	f	\N
117568	suutnud	"suutnud %suut  )NUD_vA  <suutma ;34_V	et	f	\N
117573	esikaaneteloli	?esikaaneteloli =esikaaneteloli  (SgG  >esikaanetelol !19_S	et	f	\N
117574	esikaaneteloli	?esikaaneteloli =esikaaneteloli  (SgP  >esikaanetelol !19_S	et	f	\N
117575	esikaaneteloli	?esikaaneteloli =esikaaneteloli  (SgAdt  >esikaanetelol !19_S	et	f	\N
117576	esikaaneteloli	?esikaaneteloli =teloli  (SgG  >esi+kaane+telol !02_S	et	f	\N
117577	esikaaneteloli	?esikaaneteloli =aaneteloli  (SgG  >esik+aanetelol !19_S	et	f	\N
117578	esikaaneteloli	?esikaaneteloli =aaneteloli  (SgP  >esik+aanetelol !19_S	et	f	\N
117579	esikaaneteloli	?esikaaneteloli =aaneteloli  (SgAdt  >esik+aanetelol !19_S	et	f	\N
117580	esikaaneteloli	?esikaaneteloli =kaaneteloli  (SgG  >esi+kaanetelol !19_S	et	f	\N
117581	esikaaneteloli	?esikaaneteloli =kaaneteloli  (SgP  >esi+kaanetelol !19_S	et	f	\N
117582	esikaaneteloli	?esikaaneteloli =kaaneteloli  (SgAdt  >esi+kaanetelol !19_S	et	f	\N
117592	probleemeõpilastel	?probleemeõpilastel =probleemeõpilas  (PlAd  >probleemeõpilane !12_S	et	f	\N
117593	laulupidu	laulupidu =pidu  (SgN  >laulu+pidu !17_S	et	f	\N
117594	laulupidu	laulupidu =pidu  (SgN  >laulu+pidu !18_S	et	f	\N
117595	laulupidu	laulupidu =pidu  (SgG  >laulu+pidu !17_S	et	f	\N
117596	laulupidu	laulupidu =pidu  (SgP  >laulu+pidu !17_S	et	f	\N
117597	laulupidu	laulupidu =pidu  (SgP  >laulu+pidu !18_S	et	f	\N
117615	rahvuslaulelaua	?rahvuslaulelaua =rahvuslaulelaua  (SgN  >rahvuslaulelaua !01_S	et	f	\N
117616	rahvuslaulelaua	?rahvuslaulelaua =rahvuslaulelaua  (SgG  >rahvuslaulelaua !01_S	et	f	\N
117618	rahvuslaulelaua	?rahvuslaulelaua =lelaua  (SgN  >rahvus+lau+lelaua !01_S	et	f	\N
117619	rahvuslaulelaua	?rahvuslaulelaua =lelaua  (SgG  >rahvus+lau+lelaua !01_S	et	f	\N
117620	rahvuslaulelaua	?rahvuslaulelaua =laulelaua  (SgN  >rahvus+laulelaua !01_S	et	f	\N
117621	rahvuslaulelaua	?rahvuslaulelaua =laulelaua  (SgG  >rahvus+laulelaua !01_S	et	f	\N
117622	rahvuslaulelaua	?rahvuslaulelaua =slaulelaua  (SgN  >rahvu+slaulelaua !01_S	et	f	\N
117623	rahvuslaulelaua	?rahvuslaulelaua =slaulelaua  (SgG  >rahvu+slaulelaua !01_S	et	f	\N
117655	laulupeolesee	?laulupeolesee =laulupeolesee  (SgN  >laulupeolesee !26_S	et	f	\N
117657	laulupeolesee	?laulupeolesee =laulupeolesee  (SgG  >laulupeolesee !26_S	et	f	\N
117658	laulupeolesee	?laulupeolesee =lesee  (SgN  >laulu+peo+lesee !26_S	et	f	\N
117659	laulupeolesee	?laulupeolesee =lesee  (SgG  >laulu+peo+lesee !26_S	et	f	\N
117660	laulupeolesee	?laulupeolesee =peolesee  (SgN  >laulu+peolesee !26_S	et	f	\N
117661	laulupeolesee	?laulupeolesee =peolesee  (SgG  >laulu+peolesee !26_S	et	f	\N
117662	laulupeolesee	?laulupeolesee =lupeolesee  (SgN  >lau+lupeolesee !26_S	et	f	\N
117663	laulupeolesee	?laulupeolesee =lupeolesee  (SgG  >lau+lupeolesee !26_S	et	f	\N
117664	vastustseega	?vastustseega =vastustsee  (SgKom  >vastustsee !26_S	et	f	\N
117665	vastustseega	?vastustseega =vastustseega  (SgN  >vastustseega !16_S	et	f	\N
117666	vastustseega	?vastustseega =vastustseega  (SgG  >vastustseega !16_S	et	f	\N
117667	vastustseega	?vastustseega =tsee  (SgKom  >vastus+tsee !26_S	et	f	\N
117668	vastustseega	?vastustseega =tseega  (SgN  >vastus+tseega !16_S	et	f	\N
117669	vastustseega	?vastustseega =tseega  (SgG  >vastus+tseega !16_S	et	f	\N
117670	vastustseega	?vastustseega =ustsee  (SgKom  >vast+ustsee !26_S	et	f	\N
117671	vastustseega	?vastustseega =ustseega  (SgN  >vast+ustseega !16_S	et	f	\N
117672	vastustseega	?vastustseega =ustseega  (SgG  >vast+ustseega !16_S	et	f	\N
117694	selgitadasamas	?selgitadasamas =selgitadasama  (SgIn  >selgitadasam !02_A	et	f	\N
117695	selgitadasamas	?selgitadasamas =itadasama  (SgIn  >selg+itadasam !02_A	et	f	\N
117696	küsimisepalusin	?küsimisepalusin =küsimisepalu  (IndIpfSg1  >küsimisepaluma !27_V	et	f	\N
117697	küsimisepalusin	?küsimisepalusin =küsimisepalusin  (SgN  >küsimisepalusin !19_S	et	f	\N
117698	küsimisepalusin	?küsimisepalusin =epalusin  (SgN  >küsi+mis+epalusin !19_S	et	f	\N
117706	niigi	niigi =niigi  (ID  >niigi !41_D	et	f	\N
117707	niigi	niigi =nii  (ID^  >nii !41_D	et	f	\N
117723	lapsi	lapsi =laps  (PlP  >laps !14_S	et	f	\N
117724	lapsi	lapsi =lapsi  (SgG  >laps !22_S	et	f	\N
117725	lapsi	lapsi =lapsi  (SgP  >laps !22_S	et	f	\N
117726	lapsi	lapsi =lapsi  (SgAdt  >laps !22_S	et	f	\N
117730	saasama	?saasama =saasa  (Sup  >saasama !29_V	et	f	\N
117731	saasama	?saasama =saasama  (SgG  >saasam !02_A	et	f	\N
117746	igapäevases	igapäevases =päevase  (SgIn  >iga+päevane !10_A	et	f	\N
117747	igapäevases	"iga+päevane %päeva  )NE_aA  <iga+päev ;22_S	et	f	\N
117748	vanasõna	vanasõna =sõna  (SgN  >vana+sõna !17_S	et	f	\N
117749	vanasõna	vanasõna =sõna  (SgG  >vana+sõna !17_S	et	f	\N
117750	vanasõna	vanasõna =sõna  (SgP  >vana+sõna !17_S	et	f	\N
117761	sobiksid	sobiksid =sobi  (KndPrSg2  >sobima !27_V	et	f	\N
117762	sobiksid	sobiksid =sobi  (KndPrPl3  >sobima !27_V	et	f	\N
117763	mõistatustele	mõistatustele =mõistatus  (PlAll  >mõistatus !11_S	et	f	\N
117757	õppeteksti	õppeteksti =teksti  (SgAdt  >õppe+tekst !22_S	et	f	\N
117778	kalevipoegjeesuslydiajärgmised	?kalevipoegjeesuslydiajärgmised =kalevipoegjeesuslydiajärgmise  (PlN  >kalevipoegjeesuslydiajärgmine !12_A	et	f	\N
117779	kalevipoegjeesuslydiajärgmised	?kalevipoegjeesuslydiajärgmised =jeesuslydiajärgmise  (PlN  >kalevi+poeg+jeesuslydiajärgmine !12_A	et	f	\N
117780	kalevipoegjeesuslydiajärgmised	?kalevipoegjeesuslydiajärgmised =gjeesuslydiajärgmise  (PlN  >kalevi+poe+gjeesuslydiajärgmine !12_A	et	f	\N
117781	kalevipoegjeesuslydiajärgmised	?kalevipoegjeesuslydiajärgmised =poegjeesuslydiajärgmise  (PlN  >kalevi+poegjeesuslydiajärgmine !12_A	et	f	\N
117788	jaanipäeva	jaanipäeva =päeva  (SgG  >jaani+päev !22_S	et	f	\N
117789	jaanipäeva	jaanipäeva =päeva  (SgP  >jaani+päev !22_S	et	f	\N
117790	jaanipäeva	jaanipäeva =päeva  (SgAdt  >jaani+päev !22_S	et	f	\N
117812	rauda	rauda =rauda  (SgP  >raud !22_S	et	f	\N
117813	rauda	rauda =rauda  (SgAdt  >raud !22_S	et	f	\N
117828	niit	niit =nii  (SgP  >niis !14_S	et	f	\N
117829	niit	niit =niit  (SgN  >niit !22_S	et	f	\N
117859	vastajaid	vastajaid =vastaja  (PlP  >vastaja !01_S	et	f	\N
117860	vastajaid	"vastaja %vasta  )JA_vS  <vastama ;29_V	et	f	\N
117873	tuntumaidteater	?tuntumaidteater =tuntumaidteater  (SgN  >tuntumaidteater !02_S	et	f	\N
117896	kirjutanudneed	?kirjutanudneed =kirjutanudnee  (PlN  >kirjutanudnee !26_S	et	f	\N
117897	kirjutanudneed	?kirjutanudneed =kirjutanudnee  (SgP  >kirjutanudnee !26_S	et	f	\N
117898	kirjutanudneed	?kirjutanudneed =kirjutanudneed  (SgN  >kirjutanudneed !22_S	et	f	\N
117899	lahendamata	lahendamata =lahenda  (SupAb  >lahendama !27_V	et	f	\N
117900	lahendamata	lahendamata =lahendamata  (ID  >lahendamata !41_A	et	f	\N
117903	lahendamata	"lahendamata %lahenda  )MATA_vA  <lahendama ;27_V	et	f	\N
117909	küsitletust	küsitletust =küsitletu  (SgEl  >küsitletu !01_S	et	f	\N
117910	küsitletust	"küsitletu %küsitle  )TU1_vS  <küsitlema ;27_V	et	f	\N
117911	küsitletust	küsitletust =küsitletus  (SgP  >küsitletus !11?09_S	et	f	\N
117912	küsitletust	"küsitletus %küsitle  )TUS1_aS  <küsitlema ;27_V	et	f	\N
117913	vastuskalevipoegsellist	vastuskalevipoegsellist =selli  (SgEl  >vastus+kalevi+poeg+sell !22_S	et	f	\N
117914	vastuskalevipoegsellist	"vastus+kalevi+poeg+selline %selli  )NE_aA  <vastus+kalevi+poeg+sell ;22_S	et	f	\N
117920	analüüsides	analüüsides =analüüsi  (PlIn  >analüüs !22_S	et	f	\N
117921	analüüsides	analüüsides =analüüsi  (Ger  >analüüsima !28_V	et	f	\N
117939	tarkused	tarkused =tarkuse  (PlN  >tarkus !11~09_S	et	f	\N
117941	tarkused	"tarkus %tark  )US_aS  <tark ;22_AS	et	f	\N
117944	tarkused	tarkused =tarkuse  (PlN  >tarkune !12~10_A	et	f	\N
117951	selgus	selgus =selgu  (IndIpfSg3  >selguma !27_V	et	f	\N
117952	selgus	selgus =selgus  (SgN  >selgus !11~09_S	et	f	\N
117953	selgus	"selgus %selge  )US_aS  <selge ;01_A	et	f	\N
117959	pakkunud	pakkunud =pakku  (PtsPtPs  >pakkuma !28_V	et	f	\N
117960	pakkunud	pakkunud =pakkunu  (PlN  >pakkunu !01_S	et	f	\N
117961	pakkunud	"pakkunu %pakku  )NU_vS  <pakkuma ;28_V	et	f	\N
117962	pakkunud	pakkunud =pakkunud  (ID  >pakkunud !41_A	et	f	\N
117963	pakkunud	"pakkunud %pakku  )NUD_vA  <pakkuma ;28_V	et	f	\N
117974	anonüümnetestis	?anonüümnetestis =anonüümnetesti  (IndIpfSg3  >anonüümnetestima !28_V	et	f	\N
117976	anonüümnetestis	?anonüümnetestis =anonüümnetestis  (SgN  >anonüümnetestis !09_S	et	f	\N
117978	anonüümnetestis	?anonüümnetestis =netestis  (SgN  >anonüüm+netestis !11_S	et	f	\N
118012	vastajate	vastajate =vastaja  (PlG  >vastaja !01_S	et	f	\N
118013	vastajate	"vastaja %vasta  )JA_vS  <vastama ;29_V	et	f	\N
118027	oskajate	oskajate =oskaja  (PlG  >oskaja !01_S	et	f	\N
118029	oskajate	"oskaja %oska  )JA_vS  <oskama ;29_V	et	f	\N
118067	õigestirahvuslauludega	### õigestirahvuslauludega	et	f	\N
118074	õpilast14	õpilast =õpilas  (SgP  >õpilane !12_S	et	f	\N
118075	õpilast14	õpilast =la  (SgEl  >õpi+la !26_S	et	f	\N
118076	õpilast14	õpilast =las  (SgP  >õpi+laps !14_S	et	f	\N
118077	õpilast14	õpilast =last  (SgN  >õpi+last !22_S	et	f	\N
118095	pappi	pappi =pappi  (SgP  >papp !22_S	et	f	\N
118096	pappi	pappi =pappi  (SgAdt  >papp !22_S	et	f	\N
118097	nimesidvalesti	?nimesidvalesti =nimesidvalesti  (ID  >nimesidvalesti !41_D	et	f	\N
118100	nimesidvalesti	?nimesidvalesti =nimesidvalesti  (IndPrPs_  >nimesidvalestima !28_V	et	f	\N
118101	nimesidvalesti	?nimesidvalesti =nimesidvalesti  (ImpPrSg2  >nimesidvalestima !28_V	et	f	\N
118105	varianteaga	?varianteaga =variantea  (SgKom  >variantea !26_S	et	f	\N
118106	varianteaga	?varianteaga =antea  (SgKom  >vari+antea !26_S	et	f	\N
118112	õpilast60	õpilast =õpilas  (SgP  >õpilane !12_S	et	f	\N
118113	õpilast60	õpilast =la  (SgEl  >õpi+la !26_S	et	f	\N
118114	õpilast60	õpilast =las  (SgP  >õpi+laps !14_S	et	f	\N
118115	õpilast60	õpilast =last  (SgN  >õpi+last !22_S	et	f	\N
118118	levinum	levinum =levinum  (SgN  >levinum !02_A	et	f	\N
118119	levinum	"levinum %levi  )NUM_cA  <levima ;27_V	et	f	\N
118122	meeskolmeteiskümnendas	?meeskolmeteiskümnendas =meeskolmeteiskümnenda  (SgIn  >meeskolmeteiskümnenda !16_S	et	f	\N
118123	meeskolmeteiskümnendas	?meeskolmeteiskümnendas =meeskolmeteiskümnenda  (IndIpfSg3  >meeskolmeteiskümnendama !27_V	et	f	\N
118124	meeskolmeteiskümnendas	?meeskolmeteiskümnendas =kümnenda  (SgIn  >mees+kolme+teis+kümnenda !01_S	et	f	\N
117764	mõistatustele	"mõistatus %mõistata  )US_vS  <mõistatama ;27_V	et	f	\N
117765	mõistatustele	mõistatustele =tuste  (PlAll  >mõista+tust !22_S	et	f	\N
117766	eelneva	eelneva =eelneva  (SgG  >eelnev !02_A	et	f	\N
117767	eelneva	"eelnev %eelne  )V_vA  <eelnema ;27_V	et	f	\N
117770	vastatarahvatarkuste	?vastatarahvatarkuste =vastatarahvatarkus  (PlG  >vastatarahvatarkus !11~09_S	et	f	\N
117771	vastatarahvatarkuste	?vastatarahvatarkuste =atarahvatarkus  (PlG  >vast+atarahvatarkus !11~09_S	et	f	\N
117783	rahvakalendripäevi	rahvakalendripäevi =päevi  (SgG  >rahva+kalendri+päev !22_S	et	f	\N
117784	rahvakalendripäevi	rahvakalendripäevi =päevi  (SgP  >rahva+kalendri+päev !22_S	et	f	\N
117785	rahvakalendripäevi	rahvakalendripäevi =päevi  (SgAdt  >rahva+kalendri+päev !22_S	et	f	\N
117786	rahvakalendripäevi	rahvakalendripäevi =päevi  (PlP  >rahva+kalendri+päev !22_S	et	f	\N
117795	olidjõulud	?olidjõulud =olidjõulu  (IndPrSg2  >olidjõuluma !27_V	et	f	\N
117796	tähistatkse	?tähistatkse =tähistatkse  (SgG  >tähistatkne !02_A	et	f	\N
117797	tähistatkse	?tähistatkse =tatkse  (SgN  >tähis+tatkse !06_S	et	f	\N
117798	tähistatkse	?tähistatkse =tatkse  (SgG  >tähis+tatkne !02_A	et	f	\N
117799	tähistatkse	?tähistatkse =tatkse  (SgG  >tähis+tatkse !06_S	et	f	\N
117800	tähistatkse	?tähistatkse =tatkse  (PlP  >tähis+tatks !22_S	et	f	\N
117801	kirjanikkevastuseid	?kirjanikkevastuseid =kirjanikkevastuse  (PlP  >kirjanikkevastus !09_S	et	f	\N
117802	kirjanikkevastuseid	?kirjanikkevastuseid =kirjanikkevastusei  (PlN  >kirjanikkevastusei !26_S	et	f	\N
117803	kirjanikkevastuseid	?kirjanikkevastuseid =kirjanikkevastusei  (SgP  >kirjanikkevastusei !26_S	et	f	\N
117804	kirjanikkevastuseid	?kirjanikkevastuseid =nikkevastuse  (PlP  >kirja+nikkevastus !09_S	et	f	\N
117805	kirjanikkevastuseid	?kirjanikkevastuseid =nikkevastusei  (PlN  >kirja+nikkevastusei !26_S	et	f	\N
117806	kirjanikkevastuseid	?kirjanikkevastuseid =nikkevastusei  (SgP  >kirja+nikkevastusei !26_S	et	f	\N
117814	lasteleoli	?lasteleoli =lasteleoli  (SgN  >lasteleoli !16_S	et	f	\N
117815	lasteleoli	?lasteleoli =lasteleoli  (SgG  >lasteleoli !16_S	et	f	\N
117816	lasteleoli	?lasteleoli =lasteleoli  (SgG  >lasteleol !19_S	et	f	\N
117817	lasteleoli	?lasteleoli =lasteleoli  (SgP  >lasteleol !19_S	et	f	\N
117818	lasteleoli	?lasteleoli =lasteleoli  (SgAdt  >lasteleol !19_S	et	f	\N
117819	lasteleoli	?lasteleoli =lasteleoli  (IndPrPs_  >lasteleolima !28_V	et	f	\N
117820	lasteleoli	?lasteleoli =lasteleoli  (ImpPrSg2  >lasteleolima !28_V	et	f	\N
117821	lasteleoli	?lasteleoli =leoli  (SgN  >laste+leoli !16_S	et	f	\N
117822	lasteleoli	?lasteleoli =leoli  (SgG  >laste+leoli !16_S	et	f	\N
117823	lasteleoli	?lasteleoli =leoli  (SgG  >laste+leol !22_S	et	f	\N
117824	lasteleoli	?lasteleoli =leoli  (SgP  >laste+leol !22_S	et	f	\N
117825	lasteleoli	?lasteleoli =leoli  (SgAdt  >laste+leol !22_S	et	f	\N
117839	mingil	mingil =mingi  (SgAd  >mingi !01_P	et	f	\N
117840	mingil	mingil =mingi  (SgAd  >mink !22_S	et	f	\N
117846	lingren	?lingren =lingre  (IndPrSg1  >lingrema !27_V	et	f	\N
117848	lingren	?lingren =lingren  (SgN  >lingren !02_S	et	f	\N
117863	tuntumad	tuntumad =tuntuma  (PlN  >tuntum !02_A	et	f	\N
117864	tuntumad	"tuntum %tun  )TUM1_cA  <tundma ;34_V	et	f	\N
117865	näitlejad	näitlejad =näitleja  (PlN  >näitleja !01_S	et	f	\N
117867	näitlejad	"näitleja %näitle  )JA_vS  <näitlema ;30_V	et	f	\N
117925	kohad	kohad =koha  (PlN  >koha !17_S	et	f	\N
117926	kohad	kohad =koha  (PlN  >koht !22_S	et	f	\N
117927	kohad	kohad =koha  (IndPrSg2  >kohama !27_V	et	f	\N
117928	lavastused	lavastused =lavastuse  (PlN  >lavastus !11_S	et	f	\N
117930	lavastused	"lavastus %lavasta  )US_vS  <lavastama ;27_V	et	f	\N
117957	sajandisee	?sajandisee =sajandisee  (SgN  >sajandisee !26_S	et	f	\N
117958	sajandisee	?sajandisee =sajandisee  (SgG  >sajandisee !26_S	et	f	\N
117983	paranenud	paranenud =parane  (PtsPtPs  >paranema !27_V	et	f	\N
117984	paranenud	paranenud =paranenu  (PlN  >paranenu !01_S	et	f	\N
117985	paranenud	"paranenu %parane  )NU_vS  <paranema ;27_V	et	f	\N
117986	paranenud	paranenud =paranenud  (ID  >paranenud !41_A	et	f	\N
117987	paranenud	"paranenud %parane  )NUD_vA  <paranema ;27_V	et	f	\N
117988	rahvuslindulilli-kivekokku	?rahvuslindulilli-kivekokku =kivekokku  (IndPrPs_  >rahvuslindulilli-kivekokkuma !27_V	et	f	\N
117989	rahvuslindulilli-kivekokku	?rahvuslindulilli-kivekokku =kivekokku  (ImpPrSg2  >rahvuslindulilli-kivekokkuma !27_V	et	f	\N
118014	suurenenudteine	?suurenenudteine =suurenenudteine  (SgN  >suurenenudteine !16_S	et	f	\N
118015	suurenenudteine	?suurenenudteine =suurenenudteine  (SgG  >suurenenudteine !16_S	et	f	\N
118016	suurenenudteine	?suurenenudteine =suurenenudteine  (PlP  >suurenenudtein !19_S	et	f	\N
118017	suurenenudteine	?suurenenudteine =nenudteine  (SgN  >suure+nenudteine !16_S	et	f	\N
118018	suurenenudteine	?suurenenudteine =nenudteine  (SgG  >suure+nenudteine !16_S	et	f	\N
118019	suurenenudteine	?suurenenudteine =nenudteine  (PlP  >suure+nenudtein !19_S	et	f	\N
118020	suurenenudteine	?suurenenudteine =enenudteine  (SgN  >suur+enenudteine !16_S	et	f	\N
118021	suurenenudteine	?suurenenudteine =enenudteine  (SgG  >suur+enenudteine !16_S	et	f	\N
118022	suurenenudteine	?suurenenudteine =enenudteine  (PlP  >suur+enenudtein !19_S	et	f	\N
118023	suurenenudteine	?suurenenudteine =renenudteine  (SgN  >suu+renenudteine !16_S	et	f	\N
118024	suurenenudteine	?suurenenudteine =renenudteine  (SgG  >suu+renenudteine !16_S	et	f	\N
117838	smuul	?smuul =smuul  (SgN  >smuul !22_S	et	f	\N
117851	tobiasoli	?tobiasoli =tobiasoli  (SgG  >tobiasol !02_S	et	f	\N
117852	olutsu	?olutsu =olutsu  (SgN  >olutsu !01_S	et	f	\N
117853	olutsu	?olutsu =olutsu  (SgG  >olutsu !01_S	et	f	\N
117854	olutsu	?olutsu =olutsu  (IndPrPs_  >olutsuma !27_V	et	f	\N
117855	olutsu	?olutsu =olutsu  (ImpPrSg2  >olutsuma !27_V	et	f	\N
117856	kirjandeidvõrreldes	### kirjandeidvõrreldes	et	f	\N
117861	leidus	leidus =leidu  (IndIpfSg3  >leiduma !27_V	et	f	\N
117862	leidus	leidus =leidus  (SgN  >leidus !11~09_S	et	f	\N
117869	nimetasid	nimetasid =nimeta  (IndIpfSg2  >nimetama !27_V	et	f	\N
117870	nimetasid	nimetasid =nimeta  (IndIpfPl3  >nimetama !27_V	et	f	\N
117885	plaza	?plaza =plaza  (SgN  >plaza !17_S	et	f	\N
117886	plaza	?plaza =plaza  (SgG  >plaza !17_S	et	f	\N
117888	plaza	?plaza =plaza  (SgP  >plaza !17_S	et	f	\N
117890	plaza	?plaza =plaza  (IndPrPs_  >plazama !27_V	et	f	\N
117891	plaza	?plaza =plaza  (ImpPrSg2  >plazama !27_V	et	f	\N
117904	jäätnud	?jäätnud =jäät  (PtsPtPs  >jäätma !34_V	et	f	\N
117905	jäätnud	?jäätnud =jäätnu  (PlN  >jäätnu !01_S	et	f	\N
117906	jäätnud	?jäätnud =jäätnu  (IndPrSg2  >jäätnuma !27_V	et	f	\N
117907	jäätnud	?jäätnud =jäätnud  (ID  >jäätnud !41_A	et	f	\N
117915	küsimust	küsimust =küsimus  (SgP  >küsimus !11_S	et	f	\N
117916	küsimust	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
117917	küsimust	küsimust =must  (SgN  >küsi+must !22_AS	et	f	\N
117918	saan	saan =saa  (IndPrSg1  >saama !37_V	et	f	\N
117919	saan	saan =saan  (SgN  >saan !22_S	et	f	\N
117924	tasemelnõrgad	?tasemelnõrgad =tasemelnõrga  (PlN  >tasemelnõrga !16_S	et	f	\N
117943	kõigile	kõigile =kõigi  (PlAll  >kõik !00_P	et	f	\N
117945	kõigile	kõigile =kõigi  (SgAll  >kõik !22_S	et	f	\N
117946	pöörata	pöörata =pööra  (SgAb  >pöör !22_S	et	f	\N
117947	pöörata	pöörata =pööra  (Inf  >pöörama !29_V	et	f	\N
117948	pöörata	pöörata =pööra  (IndPrIps_  >pöörama !29_V	et	f	\N
117964	raskelt	raskelt =raske  (SgAbl  >raske !01_A	et	f	\N
117965	raskelt	raskelt =raskelt  (ID  >raskelt !41_D	et	f	\N
117966	raskelt	"raskelt %raske  )LT_mD  <raske ;01_A	et	f	\N
117981	testis	testis =testi  (SgIn  >test !22_S	et	f	\N
117982	testis	testis =testi  (IndIpfSg3  >testima !28_V	et	f	\N
117990	16ainult	ainult =ainu  (SgAbl  >ainus !07_AS	et	f	\N
117991	16ainult	ainult =ainu  (SgAbl  >ainu !16_S	et	f	\N
117992	16ainult	ainult =ainu  (PlAbl  >ain !22_S	et	f	\N
117994	16ainult	ainult =ainult  (ID  >ainult !41_D	et	f	\N
117996	16ainult	"ainult %ainu  )LT_mD  <ainus ;07_AS	et	f	\N
118048	laulupeost7klassiga	?laulupeostklassiga =laulupeostklassi  (SgKom  >laulupeostklass !22_S	et	f	\N
118049	laulupeost7klassiga	?laulupeostklassiga =peostklassi  (SgKom  >laulu+peostklassi !01_S	et	f	\N
118050	laulupeost7klassiga	?laulupeostklassiga =peostklassi  (SgKom  >laulu+peostklass !22_S	et	f	\N
118051	laulupeost7klassiga	?laulupeostklassiga =lupeostklassi  (SgKom  >lau+lupeostklass !22_S	et	f	\N
118063	iseseisvuspäevast	iseseisvuspäevast =ast  (SgN  >ise+seisvus+päev+ast !22_S	et	f	\N
118064	iseseisvuspäevast	iseseisvuspäevast =päeva  (SgEl  >ise+seisvus+päev !22_S	et	f	\N
118065	iseseisvuspäevast	iseseisvuspäevast =päevas  (SgP  >ise+seisvus+päevane !10_A	et	f	\N
118066	iseseisvuspäevast	"ise+seisvus+päevane %päeva  )NE_aA  <ise+seisvus+päev ;22_S	et	f	\N
118098	vastanuid	vastanuid =vastanu  (PlP  >vastanu !01_S	et	f	\N
118099	vastanuid	"vastanu %vasta  )NU_vS  <vastama ;29_V	et	f	\N
118111	ülesannega	### ülesannega	et	f	\N
118218	näitlejäid	?näitlejäid =näitlejäi  (PlN  >näitlejäi !26_S	et	f	\N
118219	näitlejäid	?näitlejäid =näitlejäi  (SgP  >näitlejäi !26_S	et	f	\N
118220	näitlejäid	?näitlejäid =näitlejäid  (SgN  >näitlejäid !22_S	et	f	\N
118221	näitlejäid	?näitlejäid =lejäi  (PlN  >näit+lejäi !26_S	et	f	\N
118222	näitlejäid	?näitlejäid =lejäi  (SgP  >näit+lejäi !26_S	et	f	\N
118223	näitlejäid	?näitlejäid =lejäid  (SgN  >näit+lejäid !22_S	et	f	\N
118252	esimest	esimest =esimes  (SgP  >esimene !12_OP	et	f	\N
118253	esimest	esimest =mest  (SgN  >esi+mest !22_S	et	f	\N
118284	õpilast76	õpilast =õpilas  (SgP  >õpilane !12_S	et	f	\N
118285	õpilast76	õpilast =la  (SgEl  >õpi+la !26_S	et	f	\N
118286	õpilast76	õpilast =las  (SgP  >õpi+laps !14_S	et	f	\N
118287	õpilast76	õpilast =last  (SgN  >õpi+last !22_S	et	f	\N
118306	suunatud	suunatud =suuna  (PtsPtIps  >suunama !29_V	et	f	\N
118307	suunatud	suunatud =suunatu  (PlN  >suunatu !01_AS	et	f	\N
118308	suunatud	"suunatu %suuna  )TU1_vS  <suunama ;29_V	et	f	\N
118309	suunatud	"suunatu %suuna  )TU2_kA  <suund ;22_S	et	f	\N
118310	suunatud	suunatud =suunatud  (ID  >suunatud !41_A	et	f	\N
118311	suunatud	"suunatud %suuna  )TUD_vA  <suunama ;29_V	et	f	\N
118321	vastamineteadmised	?vastamineteadmised =vastamineteadmise  (PlN  >vastamineteadmine !12_A	et	f	\N
118323	vastamineteadmised	?vastamineteadmised =amineteadmise  (PlN  >vast+amineteadmine !12_A	et	f	\N
118331	järeldusele	järeldusele =järelduse  (SgAll  >järeldus !11_S	et	f	\N
118332	järeldusele	"järeldus %järelda  )US_vS  <järeldama ;27_V	et	f	\N
118342	põhjalikult	põhjalikult =põhjaliku  (SgAbl  >põhjalik !25_A	et	f	\N
117874	estonia	estonia =estonia  (SgN  >estonia !01_S	et	f	\N
117875	estonia	estonia =estonia  (SgG  >estonia !01_S	et	f	\N
117876	juttugi	juttugi =juttu  (SgP^  >jutt !22_S	et	f	\N
117877	juttugi	juttugi =juttu  (SgAdt^  >jutt !22_S	et	f	\N
117878	vanemuineteatri	?vanemuineteatri =vanemuineteatri  (SgG  >vanemuineteater !02_S	et	f	\N
117879	vanemuineteatri	?vanemuineteatri =vanemuineteatri  (IndPrPs_  >vanemuineteatrima !28_V	et	f	\N
117880	vanemuineteatri	?vanemuineteatri =vanemuineteatri  (ImpPrSg2  >vanemuineteatrima !28_V	et	f	\N
117881	vanemuineteatri	?vanemuineteatri =uineteatri  (SgG  >vanem+uineteater !02_S	et	f	\N
117882	coca-cola	?coca-cola =cola  (SgN  >coca-cola !17_S	et	f	\N
117883	coca-cola	?coca-cola =cola  (SgG  >coca-cola !17_S	et	f	\N
117884	coca-cola	?coca-cola =cola  (SgP  >coca-cola !17_S	et	f	\N
117887	coca-cola	?coca-cola =cola  (IndPrPs_  >coca-colama !27_V	et	f	\N
117889	coca-cola	?coca-cola =cola  (ImpPrSg2  >coca-colama !27_V	et	f	\N
117894	näitlejaid	näitlejaid =näitleja  (PlP  >näitleja !01_S	et	f	\N
117895	näitlejaid	"näitleja %näitle  )JA_vS  <näitlema ;30_V	et	f	\N
117901	osasee	?osasee =osasee  (SgN  >osasee !26_S	et	f	\N
117902	osasee	?osasee =osasee  (SgG  >osasee !26_S	et	f	\N
117908	niimillised	?niimillised =niimillise  (PlN  >niimilline !12_A	et	f	\N
117922	madalal	madalal =madala  (SgAd  >madal !02_AS	et	f	\N
117923	madalal	madalal =madalal  (ID  >madalal !41_D	et	f	\N
117931	kirjanduseesti	?kirjanduseesti =kirjanduseesti  (ID  >kirjanduseesti !41_D	et	f	\N
117932	kirjanduseesti	?kirjanduseesti =kirjanduseesti  (IndPrPs_  >kirjanduseestima !28_V	et	f	\N
117933	kirjanduseesti	?kirjanduseesti =kirjanduseesti  (ImpPrSg2  >kirjanduseestima !28_V	et	f	\N
117934	kirjanduseesti	?kirjanduseesti =esti  (SgN  >kirjanduse+esti !16_S	et	f	\N
117935	kirjanduseesti	?kirjanduseesti =esti  (SgG  >kirjanduse+esti !16_S	et	f	\N
117936	kirjanduseesti	?kirjanduseesti =esti  (SgG  >kirjanduse+est !22_S	et	f	\N
117937	kirjanduseesti	?kirjanduseesti =esti  (SgP  >kirjanduse+est !22_S	et	f	\N
117938	kirjanduseesti	?kirjanduseesti =esti  (SgAdt  >kirjanduse+est !22_S	et	f	\N
117940	rahvuslaulud-sellele	rahvuslaulud-sellele =selle  (SgAll  >rahvuslaulud-see !00_P	et	f	\N
117942	rahvuslaulud-sellele	rahvuslaulud-sellele =selle  (PlAll  >rahvuslaulud-sell !22_S	et	f	\N
117949	koostamiselõpilastega	?koostamiselõpilastega =koostamiselõpilas  (PlKom  >koostamiselõpilane !12_S	et	f	\N
117950	koostamiselõpilastega	?koostamiselõpilastega =tamiselõpilas  (PlKom  >koos+tamiselõpilane !12_S	et	f	\N
117967	arusaadav	arusaadav =saa  (PtsPrIps  >aru+_saama !37_V	et	f	\N
117968	arusaadav	arusaadav =saadav  (SgN  >aru+saadav !02_A	et	f	\N
117975	osalesid	osalesid =osale  (IndIpfSg2  >osalema !27_V	et	f	\N
117977	osalesid	osalesid =osale  (IndIpfPl3  >osalema !27_V	et	f	\N
117979	õpilastküsimusi	?õpilastküsimusi =õpilastküsimusi  (PlP  >õpilastküsimus !11_S	et	f	\N
117980	õpilastküsimusi	?õpilastküsimusi =lastküsimusi  (PlP  >õpi+lastküsimus !11_S	et	f	\N
117993	vastasid	vastasid =vasta  (IndIpfSg2  >vastama !29_V	et	f	\N
117995	vastasid	vastasid =vasta  (IndIpfPl3  >vastama !29_V	et	f	\N
118003	vapulippu	?vapulippu =vapulippu  (IndPrPs_  >vapulippuma !27_V	et	f	\N
118004	vapulippu	?vapulippu =vapulippu  (ImpPrSg2  >vapulippuma !27_V	et	f	\N
118008	selgemis	selgemis =selgemi  (SgIn  >selgem !02_A	et	f	\N
118009	selgemis	"selgem %selge  )M_cA  <selge ;01_A	et	f	\N
118010	selgemis	selgemis =mi  (SgIn  >selge+mi !26_S	et	f	\N
118011	selgemis	selgemis =emis  (SgN  >selg+emis !09_S	et	f	\N
118036	rahvuslillest	rahvuslillest =lille  (SgEl  >rahvus+lill !22_S	et	f	\N
118037	rahvuslillest	rahvuslillest =lille  (PlEl  >rahvus+lill !22_S	et	f	\N
118038	rahvuslillest	rahvuslillest =lilles  (SgP  >rahvus+lillene !10_A	et	f	\N
118039	rahvuslillest	"rahvus+lillene %lille  )NE_aA  <rahvus+lill ;22_S	et	f	\N
118040	rahuslilleks	?rahuslilleks =rahuslille  (PlTr  >rahuslill !22_S	et	f	\N
118041	rahuslilleks	?rahuslilleks =slille  (PlTr  >rahu+slill !22_S	et	f	\N
118044	presidenti	presidenti =presidenti  (SgP  >president !22_S	et	f	\N
118046	presidenti	presidenti =presidenti  (SgAdt  >president !22_S	et	f	\N
118057	vastanute	vastanute =vastanu  (PlG  >vastanu !01_S	et	f	\N
118058	vastanute	"vastanu %vasta  )NU_vS  <vastama ;29_V	et	f	\N
118090	laulme	?laulme =laulme  (SgN  >laulme !06_S	et	f	\N
118091	laulme	?laulme =laulme  (SgG  >laulme !06_S	et	f	\N
118092	laulme	?laulme =laulme  (PlP  >laulm !22_S	et	f	\N
118093	laulme	?laulme =laulme  (IndPrPs_  >laulmema !27_V	et	f	\N
118094	laulme	?laulme =laulme  (ImpPrSg2  >laulmema !27_V	et	f	\N
118102	klassst16	?klassst =klassst  (SgN  >klassst !22_S	et	f	\N
118103	õpilastnad	?õpilastnad =õpilastna  (PlN  >õpilastna !16_S	et	f	\N
118104	õpilastnad	?õpilastnad =lastna  (PlN  >õpi+lastna !01_S	et	f	\N
118107	vastas	vastas =vasta  (IndIpfSg3  >vastama !29_V	et	f	\N
118108	vastas	vastas =vastas  (ID  >vastas !41_DK	et	f	\N
118109	ülesanne	ülesanne =anne  (SgN  >üles+anne !05_S	et	f	\N
118110	ülesanne	ülesanne =anne  (SgN  >üles+anne !06_S	et	f	\N
118129	mõistatusele	mõistatusele =mõistatuse  (SgAll  >mõistatus !11_S	et	f	\N
118130	mõistatusele	"mõistatus %mõistata  )US_vS  <mõistatama ;27_V	et	f	\N
118136	mõistatustoli	?mõistatustoli =mõistatustoli  (SgG  >mõistatustol !02_S	et	f	\N
118007	hümniõpilastel	hümniõpilastel =õpilas  (PlAd  >hümni+õpilane !12_S	et	f	\N
118026	küsimuse	küsimuse =küsimuse  (SgG  >küsimus !11_S	et	f	\N
118028	küsimuse	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
118031	jannsenjärgmised	?jannsenjärgmised =jannsenjärgmise  (PlN  >jannsenjärgmine !12_A	et	f	\N
118032	rahvuslinnust	rahvuslinnust =us  (SgP  >rahvus+linn+uks !14_S	et	f	\N
118033	rahvuslinnust	rahvuslinnust =linnu  (SgEl  >rahvus+lind !22_S	et	f	\N
118034	rahvuslinnust	rahvuslinnust =linnu  (PlEl  >rahvus+linn !22_S	et	f	\N
118035	rahvuslinnust	rahvuslinnust =linnus  (SgP  >rahvus+linnus !09_S	et	f	\N
118042	sinililleeesti	?sinililleeesti =sinililleeesti  (ID  >sinililleeesti !41_D	et	f	\N
118043	sinililleeesti	?sinililleeesti =sinililleeesti  (IndPrPs_  >sinililleeestima !28_V	et	f	\N
118045	sinililleeesti	?sinililleeesti =sinililleeesti  (ImpPrSg2  >sinililleeestima !28_V	et	f	\N
118068	paranenudoli	?paranenudoli =paranenudoli  (SgG  >paranenudol !19_S	et	f	\N
118069	paranenudoli	?paranenudoli =paranenudoli  (SgP  >paranenudol !19_S	et	f	\N
118070	paranenudoli	?paranenudoli =paranenudoli  (SgAdt  >paranenudol !19_S	et	f	\N
118071	paranenudoli	?paranenudoli =nenudoli  (SgG  >para+nenudol !19_S	et	f	\N
118072	paranenudoli	?paranenudoli =nenudoli  (SgP  >para+nenudol !19_S	et	f	\N
118073	paranenudoli	?paranenudoli =nenudoli  (SgAdt  >para+nenudol !19_S	et	f	\N
118078	naljakaid	naljakaid =naljaka  (PlP  >naljakas !02_A	et	f	\N
118079	naljakaid	naljakaid =kai  (PlN  >nalja+kai !26_S	et	f	\N
118080	naljakaid	naljakaid =kai  (SgP  >nalja+kai !26_S	et	f	\N
118085	osutus	osutus =osutu  (IndIpfSg3  >osutuma !27_V	et	f	\N
118087	osutus	osutus =osutus  (SgN  >osutus !11_S	et	f	\N
118089	osutus	"osutus %osuta  )US_vS  <osutama ;27_V	et	f	\N
118116	õppinudkõike	?õppinudkõike =õppinudkõike  (SgN  >õppinudkõike !12?10_S	et	f	\N
118117	õppinudkõike	?õppinudkõike =õppinudkõike  (PlP  >õppinudkõik !22_S	et	f	\N
118131	vastuseidoli	?vastuseidoli =vastuseidoli  (SgG  >vastuseidol !02_S	et	f	\N
118132	vastuseidoli	?vastuseidoli =doli  (SgN  >vastus+ei+doli !17_S	et	f	\N
118133	vastuseidoli	?vastuseidoli =doli  (SgG  >vastus+ei+doli !17_S	et	f	\N
118134	vastuseidoli	?vastuseidoli =doli  (SgP  >vastus+ei+doli !17_S	et	f	\N
118135	vastuseidoli	?vastuseidoli =eidoli  (SgG  >vastus+eidol !02_S	et	f	\N
118137	vastuseidoli	?vastuseidoli =seidoli  (SgG  >vastu+seidol !02_S	et	f	\N
118142	kõigidele	?kõigidele =kõigi  (PlAll  >kõigi !16_S	et	f	\N
118143	kõigidele	?kõigidele =kõigi  (PlAll  >kõig !22_S	et	f	\N
118158	populaarsemad	populaarsemad =populaarsema  (PlN  >populaarsem !02_A	et	f	\N
118159	populaarsemad	"populaarsem %populaarse  )M_cA  <populaarne ;02_A	et	f	\N
118164	jõuludemadepäevmind	?jõuludemadepäevmind =jõuludemadepäevmind  (SgN  >jõuludemadepäevmind !22_S	et	f	\N
118165	jõuludemadepäevmind	?jõuludemadepäevmind =demadepäevmind  (SgN  >jõulu+demadepäevmind !22_S	et	f	\N
118166	jõuludemadepäevmind	?jõuludemadepäevmind =ludemadepäevmind  (SgN  >jõu+ludemadepäevmind !22_S	et	f	\N
118180	küsimusel	küsimusel =küsimuse  (SgAd  >küsimus !11_S	et	f	\N
118182	küsimusel	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
118188	kirjanikkeainult	?kirjanikkeainult =kirjanikkeainu  (SgAbl  >kirjanikkeainu !01_S	et	f	\N
118189	kirjanikkeainult	?kirjanikkeainult =kirjanikkeainult  (ID  >kirjanikkeainult !41_D	et	f	\N
118190	kirjanikkeainult	?kirjanikkeainult =nikkeainu  (SgAbl  >kirja+nikkeainu !01_S	et	f	\N
118193	vastusevariante	?vastusevariante =vastusevariante  (PlP  >vastusevariant !22_S	et	f	\N
118194	vastusevariante	?vastusevariante =evariante  (PlP  >vastus+evariant !22_S	et	f	\N
118195	vastusevariante	?vastusevariante =sevariante  (PlP  >vastu+sevariant !22_S	et	f	\N
118196	vastusevariante	?vastusevariante =usevariante  (PlP  >vast+usevariant !22_S	et	f	\N
118216	asuvaid	asuvaid =asuva  (PlP  >asuv !02_A	et	f	\N
118217	asuvaid	"asuv %asu  )V_vA  <asuma ;27_V	et	f	\N
118224	lavastusi	lavastusi =lavastusi  (PlP  >lavastus !11_S	et	f	\N
118225	lavastusi	"lavastus %lavasta  )US_vS  <lavastama ;27_V	et	f	\N
118226	paranenudveel	?paranenudveel =paranenudvee  (SgAd  >paranenudvee !26_S	et	f	\N
118227	paranenudveel	?paranenudveel =paranenudveel  (SgN  >paranenudveel !22_S	et	f	\N
118228	paranenudveel	?paranenudveel =nenudvee  (SgAd  >para+nenudvee !26_S	et	f	\N
118229	paranenudveel	?paranenudveel =nenudveel  (SgN  >para+nenudveel !22_S	et	f	\N
118237	eluaastaidlydia	?eluaastaidlydia =eluaastaidlydia  (SgN  >eluaastaidlydia !01_S	et	f	\N
118238	eluaastaidlydia	?eluaastaidlydia =eluaastaidlydia  (SgG  >eluaastaidlydia !01_S	et	f	\N
118240	eluaastaidlydia	?eluaastaidlydia =dlydia  (SgN  >elu+aas+tai+dlydia !01_S	et	f	\N
118242	eluaastaidlydia	?eluaastaidlydia =dlydia  (SgG  >elu+aas+tai+dlydia !01_S	et	f	\N
118244	eluaastaidlydia	?eluaastaidlydia =idlydia  (SgN  >elu+aasta+idlydia !01_S	et	f	\N
118245	eluaastaidlydia	?eluaastaidlydia =idlydia  (SgG  >elu+aasta+idlydia !01_S	et	f	\N
118246	eluaastaidlydia	?eluaastaidlydia =taidlydia  (SgN  >elu+aas+taidlydia !01_S	et	f	\N
118247	eluaastaidlydia	?eluaastaidlydia =taidlydia  (SgG  >elu+aas+taidlydia !01_S	et	f	\N
118248	eluaastaidlydia	?eluaastaidlydia =aastaidlydia  (SgN  >elu+aastaidlydia !01_S	et	f	\N
118249	eluaastaidlydia	?eluaastaidlydia =aastaidlydia  (SgG  >elu+aastaidlydia !01_S	et	f	\N
118262	koostajast	koostajast =koostaja  (SgEl  >koostaja !01_S	et	f	\N
118263	koostajast	"koostaja %koosta  )JA_vS  <koostama ;27_V	et	f	\N
118025	suurenenudteine	?suurenenudteine =renenudteine  (PlP  >suu+renenudtein !19_S	et	f	\N
118030	kindladet	### kindladet	et	f	\N
118047	kultuuristseitsmes	?kultuuristseitsmes =istseitsme  (PlIn  >kultuur+istseitsm !22_S	et	f	\N
118052	märgatavalt	märgatavalt =märgatava  (SgAbl  >märgatav !02_A	et	f	\N
118053	märgatavalt	"märgatav %märga  )TAV_vAS  <märkama ;29_V	et	f	\N
118054	märgatavalt	märgatavalt =märgatavalt  (ID  >märgatavalt !41_D	et	f	\N
118055	märgatavalt	"märgatavalt %märga  )TAVALT_mD  <märkama ;29_V	et	f	\N
118056	märgatavalt	"märgatavalt %märgatava  )LT_mD  <märgatav ;02_A	et	f	\N
118059	35-tunniline	-tunniline =tunniline  (SgN  >-tunniline !12_A	et	f	\N
118060	35-tunniline	"-tunniline %tunni  )LINE_aA  <-tund ;22_S	et	f	\N
118061	kultuuristjärgmisele	?kultuuristjärgmisele =kultuuristjärgmise  (SgAll  >kultuuristjärgmine !12_A	et	f	\N
118062	kultuuristjärgmisele	?kultuuristjärgmisele =istjärgmise  (SgAll  >kultuur+istjärgmine !12_A	et	f	\N
118081	nteesti	?nteesti =nteesti  (ID  >nteesti !41_D	et	f	\N
118082	nteesti	?nteesti =nteesti  (SgG  >nteest !22_S	et	f	\N
118083	nteesti	?nteesti =nteesti  (SgP  >nteest !22_S	et	f	\N
118084	nteesti	?nteesti =nteesti  (SgAdt  >nteest !22_S	et	f	\N
118086	nteesti	?nteesti =nteesti  (IndPrPs_  >nteestima !28_V	et	f	\N
118088	nteesti	?nteesti =nteesti  (ImpPrSg2  >nteestima !28_V	et	f	\N
118120	eessee	?eessee =eessee  (SgN  >eessee !26_S	et	f	\N
118121	eessee	?eessee =eessee  (SgG  >eessee !26_S	et	f	\N
118146	11klassi	klassi =klassi  (SgG  >klass !22_S	et	f	\N
118147	11klassi	klassi =klassi  (SgP  >klass !22_S	et	f	\N
118148	11klassi	klassi =klassi  (SgAdt  >klass !22_S	et	f	\N
118149	kõrgem	kõrgem =kõrgem  (SgN  >kõrgem !02_A	et	f	\N
118150	kõrgem	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
118156	tundmisest	tundmisest =tundmise  (SgEl  >tundmine !12?10_S	et	f	\N
118157	tundmisest	"tundmine %tund  )MINE_vS  <tundma ;34_V	et	f	\N
118160	päevi	päevi =päevi  (SgG  >päev !22_S	et	f	\N
118161	päevi	päevi =päevi  (SgP  >päev !22_S	et	f	\N
118162	päevi	päevi =päevi  (SgAdt  >päev !22_S	et	f	\N
118163	päevi	päevi =päevi  (PlP  >päev !22_S	et	f	\N
118191	vastanus	vastanus =vastanu  (SgIn  >vastanu !01_S	et	f	\N
118192	vastanus	"vastanu %vasta  )NU_vS  <vastama ;29_V	et	f	\N
118239	koidulast	koidulast =la  (SgEl  >koidu+la !26_S	et	f	\N
118241	koidulast	koidulast =las  (SgP  >koidu+laps !14_S	et	f	\N
118243	koidulast	koidulast =last  (SgN  >koidu+last !22_S	et	f	\N
118259	aabitsast	aabitsast =aabitsa  (SgEl  >aabits !02_S	et	f	\N
118260	aabitsast	aabitsast =aabitsas  (SgP  >aabitsane !12_A	et	f	\N
118261	aabitsast	"aabitsane %aabitsa  )NE_aA  <aabits ;02_S	et	f	\N
118264	nimetanudsamas	?nimetanudsamas =nimetanudsama  (SgIn  >nimetanudsam !02_A	et	f	\N
118265	nimetanudsamas	?nimetanudsamas =tanudsama  (SgIn  >nime+tanudsam !02_A	et	f	\N
118272	kasettpõlvkonnast	?kasettpõlvkonnast =kasettpõlvkonna  (SgEl  >kasettpõlvkonna !16_S	et	f	\N
118273	kasettpõlvkonnast	?kasettpõlvkonnast =kasettpõlvkonna  (SgEl  >kasettpõlvkond !22_S	et	f	\N
118274	kasettpõlvkonnast	?kasettpõlvkonnast =kasettpõlvkonnas  (SgP  >kasettpõlvkonnane !12_A	et	f	\N
118275	kasettpõlvkonnast	?kasettpõlvkonnast =ettpõlvkonna  (SgEl  >kas+ettpõlvkonna !16_S	et	f	\N
118276	kasettpõlvkonnast	?kasettpõlvkonnast =ettpõlvkonna  (SgEl  >kas+ettpõlvkond !22_S	et	f	\N
118277	kasettpõlvkonnast	?kasettpõlvkonnast =ettpõlvkonnas  (SgP  >kas+ettpõlvkonnane !12_A	et	f	\N
118278	ühtki	ühtki =üht  (SgP  >ükski !00_P	et	f	\N
118279	ühtki	ühtki =üht  (SgP^  >üks !22_NP	et	f	\N
118298	üldiselt	üldiselt =üldise  (SgAbl  >üldine !10~12_A	et	f	\N
118299	üldiselt	üldiselt =üldiselt  (ID  >üldiselt !41_D	et	f	\N
118300	üldiselt	"üldiselt %üldise  )LT_mD  <üldine ;10_A	et	f	\N
118301	üldiselt	"üldiselt %üldise  )LT_mD  <üldine ;12_A	et	f	\N
118305	tasandilkuna	### tasandilkuna	et	f	\N
118319	teadminemõistatustele	?teadminemõistatustele =teadminemõistatus  (PlAll  >teadminemõistatus !11?09_S	et	f	\N
118320	teadminemõistatustele	?teadminemõistatustele =teadminemõistatustele  (IndPrPs_  >teadminemõistatustelema !36_V	et	f	\N
118325	teadminemõistatustele	?teadminemõistatustele =teadminemõistatustele  (ImpPrSg2  >teadminemõistatustelema !36_V	et	f	\N
118327	analüüsimist	analüüsimist =analüüsimis  (SgP  >analüüsimine !12_S	et	f	\N
118328	analüüsimist	"analüüsimine %analüüsi  )MINE_vS  <analüüsima ;28_V	et	f	\N
118359	lastel	lastel =las  (PlAd  >laps !14_S	et	f	\N
118360	lastel	lastel =laste  (PlAd  >last !22_S	et	f	\N
118364	saame	saame =saa  (IndPrPl1  >saama !37_V	et	f	\N
118365	saame	saame =saame  (PlP  >saam !22_S	et	f	\N
118403	teatritesüldiselt	?teatritesüldiselt =teatritesüldise  (SgAbl  >teatritesüldis !09_S	et	f	\N
118404	teatritesüldiselt	?teatritesüldiselt =teatritesüldiselt  (ID  >teatritesüldiselt !41_D	et	f	\N
118405	teatritesüldiselt	?teatritesüldiselt =tesüldise  (SgAbl  >teatri+tesüldis !11_S	et	f	\N
118424	leidaõpilastega	?leidaõpilastega =leidaõpilas  (PlKom  >leidaõpilane !12_S	et	f	\N
118430	terminkasettpõlvkond	?terminkasettpõlvkond =terminkasettpõlvkond  (SgN  >terminkasettpõlvkond !22_S	et	f	\N
118435	järeldustega	järeldustega =järeldus  (PlKom  >järeldus !11_S	et	f	\N
118441	järeldustega	"järeldus %järelda  )US_vS  <järeldama ;27_V	et	f	\N
118125	meeskolmeteiskümnendas	?meeskolmeteiskümnendas =teiskümnenda  (SgIn  >mees+kolme+teiskümnenda !16_S	et	f	\N
118126	meeskolmeteiskümnendas	?meeskolmeteiskümnendas =eteiskümnenda  (SgIn  >mees+kolm+eteiskümnenda !16_S	et	f	\N
118127	meeskolmeteiskümnendas	?meeskolmeteiskümnendas =kolmeteiskümnenda  (SgIn  >mees+kolmeteiskümnenda !16_S	et	f	\N
118128	meeskolmeteiskümnendas	?meeskolmeteiskümnendas =skolmeteiskümnenda  (SgIn  >mee+skolmeteiskümnenda !16_S	et	f	\N
118155	klassiljärgmise	?klassiljärgmise =klassiljärgmise  (SgG  >klassiljärgmine !12_A	et	f	\N
118232	kreutzwaldi	?kreutzwaldi =kreutzwaldi  (SgN  >kreutzwaldi !01_S	et	f	\N
118233	kreutzwaldi	?kreutzwaldi =kreutzwaldi  (SgG  >kreutzwaldi !01_S	et	f	\N
118234	kreutzwaldi	?kreutzwaldi =kreutzwaldi  (SgG  >kreutzwald !02_S	et	f	\N
118235	kreutzwaldi	?kreutzwaldi =kreutzwaldi  (IndPrPs_  >kreutzwaltima !28_V	et	f	\N
118236	kreutzwaldi	?kreutzwaldi =kreutzwaldi  (ImpPrSg2  >kreutzwaltima !28_V	et	f	\N
118267	suhteliselt	suhteliselt =suhtelise  (SgAbl  >suhteline !12_A	et	f	\N
118268	suhteliselt	"suhteline %suhte  )LINE_aA  <suhe ;06_S	et	f	\N
118269	suhteliselt	suhteliselt =suhteliselt  (ID  >suhteliselt !41_D	et	f	\N
118270	suhteliselt	"suhteliselt %suhte  )LISELT_mD  <suhe ;06_S	et	f	\N
118271	suhteliselt	"suhteliselt %suhtelise  )LT_mD  <suhteline ;12_A	et	f	\N
118290	kirjutanud16	kirjutanud =kirjuta  (PtsPtPs  >kirjutama !27_V	et	f	\N
118291	kirjutanud16	kirjutanud =kirjutanu  (PlN  >kirjutanu !01_S	et	f	\N
118292	kirjutanud16	"kirjutanu %kirjuta  )NU_vS  <kirjutama ;27_V	et	f	\N
118293	kirjutanud16	kirjutanud =kirjutanud  (ID  >kirjutanud !41_A	et	f	\N
118294	kirjutanud16	"kirjutanud %kirjuta  )NUD_vA  <kirjutama ;27_V	et	f	\N
118295	kuupäeva	kuupäeva =päeva  (SgG  >kuu+päev !22_S	et	f	\N
118296	kuupäeva	kuupäeva =päeva  (SgP  >kuu+päev !22_S	et	f	\N
118297	kuupäeva	kuupäeva =päeva  (SgAdt  >kuu+päev !22_S	et	f	\N
118312	iseseisvuselebalti	### iseseisvuselebalti	et	f	\N
118313	kirjanduskasettpõlvkondtugevad	?kirjanduskasettpõlvkondtugevad =kirjanduskasettpõlvkondtugeva  (PlN  >kirjanduskasettpõlvkondtugev !02_A	et	f	\N
118314	kirjanduskasettpõlvkondtugevad	?kirjanduskasettpõlvkondtugevad =kirjanduskasettpõlvkondtugeva  (PlN  >kirjanduskasettpõlvkondtugeva !16_S	et	f	\N
118315	kirjanduskasettpõlvkondtugevad	?kirjanduskasettpõlvkondtugevad =ettpõlvkondtugeva  (PlN  >kirjandus+kas+ettpõlvkondtugev !02_A	et	f	\N
118316	kirjanduskasettpõlvkondtugevad	?kirjanduskasettpõlvkondtugevad =ettpõlvkondtugeva  (PlN  >kirjandus+kas+ettpõlvkondtugeva !16_S	et	f	\N
118317	kirjanduskasettpõlvkondtugevad	?kirjanduskasettpõlvkondtugevad =kasettpõlvkondtugeva  (PlN  >kirjandus+kasettpõlvkondtugev !02_A	et	f	\N
118318	kirjanduskasettpõlvkondtugevad	?kirjanduskasettpõlvkondtugevad =kasettpõlvkondtugeva  (PlN  >kirjandus+kasettpõlvkondtugeva !16_S	et	f	\N
118333	määratud	määratud =määra  (PtsPtIps  >määrama !29_V	et	f	\N
118334	määratud	määratud =määratu  (PlN  >määratu !01_AS	et	f	\N
118335	määratud	"määratu %määra  )TU1_vS  <määrama ;29_V	et	f	\N
118336	määratud	"määratu %määra  )TU2_kA  <määr ;22_S	et	f	\N
118337	määratud	määratud =määratud  (ID  >määratud !41_A	et	f	\N
118338	määratud	"määratud %määra  )TUD_vA  <määrama ;29_V	et	f	\N
118349	videomaterjali	videomaterjali =materjali  (SgG  >video+materjal !19_S	et	f	\N
118350	videomaterjali	videomaterjali =materjali  (SgP  >video+materjal !19_S	et	f	\N
118351	videomaterjali	videomaterjali =materjali  (SgAdt  >video+materjal !19_S	et	f	\N
118354	jäetud	jäetud =jäe  (PtsPtIps  >jätma !35_V	et	f	\N
118355	jäetud	jäetud =jäetu  (PlN  >jäetu !01_S	et	f	\N
118356	jäetud	"jäetu %jäe  )TU1_vS  <jätma ;35_V	et	f	\N
118357	jäetud	jäetud =jäetud  (ID  >jäetud !41_A	et	f	\N
118358	jäetud	"jäetud %jäe  )TUD_vA  <jätma ;35_V	et	f	\N
118386	raamatutest	raamatutest =raamatu  (PlEl  >raamat !02_S	et	f	\N
118387	raamatutest	raamatutest =test  (SgN  >raamatu+test !22_S	et	f	\N
118390	rahvapärimuseteadmisi	?rahvapärimuseteadmisi =rahvapärimuseteadmisi  (ID  >rahvapärimuseteadmisi !41_D	et	f	\N
118391	rahvapärimuseteadmisi	?rahvapärimuseteadmisi =rahvapärimuseteadmisi  (PlP  >rahvapärimuseteadmine !12_A	et	f	\N
118392	rahvapärimuseteadmisi	?rahvapärimuseteadmisi =museteadmisi  (PlP  >rahva+päri+museteadmine !12_A	et	f	\N
118393	rahvapärimuseteadmisi	?rahvapärimuseteadmisi =pärimuseteadmisi  (PlP  >rahva+pärimuseteadmine !12_A	et	f	\N
118398	kutsuvad	kutsuvad =kutsu  (IndPrPl3  >kutsuma !28_V	et	f	\N
118399	kutsuvad	kutsuvad =kutsuva  (PlN  >kutsuv !02_A	et	f	\N
118400	kutsuvad	"kutsuv %kutsu  )V_vA  <kutsuma ;28_V	et	f	\N
118401	näitustel	näitustel =näitus  (PlAd  >näitus !11~09_S	et	f	\N
118402	näitustel	näitustel =us  (PlAd  >näit+uks !14_S	et	f	\N
118412	kardavad	kardavad =karda  (IndPrPl3  >kardama !29_V	et	f	\N
118413	kardavad	kardavad =karda  (IndPrPl3  >kartma !34_V	et	f	\N
118414	kardavad	kardavad =kardava  (PlN  >kardav !02_A	et	f	\N
118415	kardavad	"kardav %karda  )V_vA  <kardama ;29_V	et	f	\N
118418	õppitakse	?õppitakse =õppitakse  (SgG  >õppitakne !02_A	et	f	\N
118421	õppitakse	?õppitakse =õppitakse  (PlP  >õppitaks !22_S	et	f	\N
118431	loodameet	?loodameet =loodameet  (SgN  >loodameet !22_S	et	f	\N
118432	loodameet	?loodameet =dameet  (SgN  >loo+dameet !22_S	et	f	\N
118436	testideanalüüsidega	?testideanalüüsidega =testideanalüüsi  (PlKom  >testideanalüüsi !16_S	et	f	\N
118437	testideanalüüsidega	?testideanalüüsidega =testideanalüüsi  (PlKom  >testideanalüüs !22_S	et	f	\N
118138	mõistatustoli	?mõistatustoli =tustoli  (SgG  >mõista+tustol !02_S	et	f	\N
118139	õpilastkes	?õpilastkes =lastke  (SgIn  >õpi+lastke !06_S	et	f	\N
118140	õpilastkes	?õpilastkes =lastke  (PlIn  >õpi+lastk !22_S	et	f	\N
118141	õpilastkes	?õpilastkes =lastkes  (SgN  >õpi+lastkes !09_S	et	f	\N
118144	kahele	kahele =kahe  (SgAll  >kaks !22_N	et	f	\N
118145	kahele	kahele =kahe  (PlAll  >kahk !22_S	et	f	\N
118151	teadmisteskaal	?teadmisteskaal =teadmisteskaa  (SgAd  >teadmisteskaa !26_S	et	f	\N
118152	teadmisteskaal	?teadmisteskaal =teadmisteskaal  (SgN  >teadmisteskaal !22_S	et	f	\N
118153	teadmisteskaal	?teadmisteskaal =teskaa  (SgAd  >teadmis+teskaa !26_S	et	f	\N
118154	teadmisteskaal	?teadmisteskaal =teskaal  (SgN  >teadmis+teskaal !22_S	et	f	\N
118167	sellisedesimene	?sellisedesimene =sellisedesimene  (SgN  >sellisedesimene !12_A	et	f	\N
118168	sellisedesimene	?sellisedesimene =sellisedesimene  (PlP  >sellisedesimen !19_S	et	f	\N
118169	jaanipäevsiis	?jaanipäevsiis =jaanipäevsii  (SgIn  >jaanipäevsii !26_S	et	f	\N
118170	jaanipäevsiis	?jaanipäevsiis =jaanipäevsiis  (SgN  >jaanipäevsiis !22_S	et	f	\N
118171	jaanipäevsiis	?jaanipäevsiis =sii  (SgIn  >jaani+päev+sii !26_S	et	f	\N
118172	jaanipäevsiis	?jaanipäevsiis =päevsii  (SgIn  >jaani+päevsii !26_S	et	f	\N
118173	jaanipäevsiis	?jaanipäevsiis =päevsiis  (SgN  >jaani+päevsiis !22_S	et	f	\N
118174	jaanipäevsiis	?jaanipäevsiis =ipäevsi  (PlIn  >jaan+ipäevsi !01_S	et	f	\N
118175	jaanipäevsiis	?jaanipäevsiis =ipäevsii  (SgIn  >jaan+ipäevsii !26_S	et	f	\N
118176	jaanipäevsiis	?jaanipäevsiis =ipäevsiis  (SgN  >jaan+ipäevsiis !22_S	et	f	\N
118177	kadripäevviieteistkümnendal	?kadripäevviieteistkümnendal =kadripäevviieteistkümnenda  (SgAd  >kadripäevviieteistkümnenda !16_S	et	f	\N
118178	kadripäevviieteistkümnendal	?kadripäevviieteistkümnendal =kadripäevviieteistkümnendal  (SgN  >kadripäevviieteistkümnendal !02_S	et	f	\N
118179	kadripäevviieteistkümnendal	?kadripäevviieteistkümnendal =kümnenda  (SgAd  >kadri+päev+viie+teist+kümnenda !01_S	et	f	\N
118181	kadripäevviieteistkümnendal	?kadripäevviieteistkümnendal =teistkümnenda  (SgAd  >kadri+päev+viie+teistkümnenda !16_S	et	f	\N
118183	kadripäevviieteistkümnendal	?kadripäevviieteistkümnendal =teistkümnendal  (SgN  >kadri+päev+viie+teistkümnendal !02_S	et	f	\N
118184	kadripäevviieteistkümnendal	?kadripäevviieteistkümnendal =viieteistkümnenda  (SgAd  >kadri+päev+viieteistkümnenda !16_S	et	f	\N
118185	kadripäevviieteistkümnendal	?kadripäevviieteistkümnendal =viieteistkümnendal  (SgN  >kadri+päev+viieteistkümnendal !02_S	et	f	\N
118186	kadripäevviieteistkümnendal	?kadripäevviieteistkümnendal =päevviieteistkümnenda  (SgAd  >kadri+päevviieteistkümnenda !16_S	et	f	\N
118187	kadripäevviieteistkümnendal	?kadripäevviieteistkümnendal =päevviieteistkümnendal  (SgN  >kadri+päevviieteistkümnendal !02_S	et	f	\N
118197	kirjanikkekuna	?kirjanikkekuna =nikkeku  (SgEs  >kirja+nikkeku !01_S	et	f	\N
118198	kirjanikkekuna	?kirjanikkekuna =nikkeku  (SgEs  >kirja+nikkek !02_S	et	f	\N
118199	lavastusioli	?lavastusioli =lavastusioli  (SgN  >lavastusioli !16_S	et	f	\N
118200	lavastusioli	?lavastusioli =lavastusioli  (SgG  >lavastusioli !16_S	et	f	\N
118201	lavastusioli	?lavastusioli =lavastusioli  (SgG  >lavastusiol !19_S	et	f	\N
118202	lavastusioli	?lavastusioli =lavastusioli  (SgP  >lavastusiol !19_S	et	f	\N
118203	lavastusioli	?lavastusioli =lavastusioli  (SgAdt  >lavastusiol !19_S	et	f	\N
118204	lavastusioli	?lavastusioli =lavastusioli  (IndPrPs_  >lavastusiolima !28_V	et	f	\N
118205	lavastusioli	?lavastusioli =lavastusioli  (ImpPrSg2  >lavastusiolima !28_V	et	f	\N
118206	lavastusioli	?lavastusioli =ioli  (SgN  >lavastus+ioli !16_S	et	f	\N
118207	lavastusioli	?lavastusioli =ioli  (SgG  >lavastus+ioli !16_S	et	f	\N
118208	lavastusioli	?lavastusioli =ioli  (SgG  >lavastus+iol !22_S	et	f	\N
118209	lavastusioli	?lavastusioli =ioli  (SgP  >lavastus+iol !22_S	et	f	\N
118210	lavastusioli	?lavastusioli =ioli  (SgAdt  >lavastus+iol !22_S	et	f	\N
118211	lavastusioli	?lavastusioli =stusioli  (SgN  >lava+stusioli !16_S	et	f	\N
118212	lavastusioli	?lavastusioli =stusioli  (SgG  >lava+stusioli !16_S	et	f	\N
118213	lavastusioli	?lavastusioli =stusioli  (SgG  >lava+stusiol !19_S	et	f	\N
118214	lavastusioli	?lavastusioli =stusioli  (SgP  >lava+stusiol !19_S	et	f	\N
118215	lavastusioli	?lavastusioli =stusioli  (SgAdt  >lava+stusiol !19_S	et	f	\N
118230	kirjutanudjärgnevas	?kirjutanudjärgnevas =kirjutanudjärgneva  (SgIn  >kirjutanudjärgnev !02_A	et	f	\N
118231	kirjutanudjärgnevas	?kirjutanudjärgnevas =kirjutanudjärgneva  (SgIn  >kirjutanudjärgneva !16_S	et	f	\N
118250	strahvatansu	?strahvatansu =strahvatansu  (IndPrPs_  >strahvatansuma !27_V	et	f	\N
118251	strahvatansu	?strahvatansu =strahvatansu  (ImpPrSg2  >strahvatansuma !27_V	et	f	\N
118254	rahvusärkamisaega	rahvusärkamisaega =aega  (SgP  >rahvus+ärkamis+aeg !22_S	et	f	\N
118255	rahvusärkamisaega	rahvusärkamisaega =aega  (SgAdt  >rahvus+ärkamis+aeg !22_S	et	f	\N
118256	küsinutest15	küsinutest =küsinu  (PlEl  >küsinu !01_S	et	f	\N
118257	küsinutest15	"küsinu %küsi  )NU_vS  <küsima ;27_V	et	f	\N
118258	küsinutest15	küsinutest =nute  (PlEl  >küsi+nutt !22_S	et	f	\N
118266	kirjutanudjärgmine	?kirjutanudjärgmine =kirjutanudjärgmine  (SgN  >kirjutanudjärgmine !12_A	et	f	\N
118280	olnudveel	?olnudveel =olnudvee  (SgAd  >olnudvee !26_S	et	f	\N
118281	olnudveel	?olnudveel =olnudveel  (SgN  >olnudveel !22_S	et	f	\N
118282	teadmisest	teadmisest =teadmise  (SgEl  >teadmine !12?10_S	et	f	\N
118283	teadmisest	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
118329	vestlemist	vestlemist =vestlemis  (SgP  >vestlemine !12_S	et	f	\N
118288	vastanudviimane	?vastanudviimane =vastanudviimane  (SgN  >vastanudviimane !10_A	et	f	\N
118289	vastanudviimane	?vastanudviimane =anudviimane  (SgN  >vast+anudviimane !10_A	et	f	\N
118302	madalamal	madalamal =madalama  (SgAd  >madalam !02_A	et	f	\N
118303	madalamal	"madalam %madala  )M_cA  <madal ;02_AS	et	f	\N
118304	madalamal	madalamal =madalamal  (ID  >madalamal !41_D	et	f	\N
118322	kultuuritegelastestkoidulakreutzwaldeesti	?kultuuritegelastestkoidulakreutzwaldeesti =kultuuritegelastestkoidulakreutzwaldeesti  (ID  >kultuuritegelastestkoidulakreutzwaldeesti !41_D	et	f	\N
118324	kultuuritegelastestkoidulakreutzwaldeesti	?kultuuritegelastestkoidulakreutzwaldeesti =kultuuritegelastestkoidulakreutzwaldeesti  (IndPrPs_  >kultuuritegelastestkoidulakreutzwaldeestima !28_V	et	f	\N
118326	kultuuritegelastestkoidulakreutzwaldeesti	?kultuuritegelastestkoidulakreutzwaldeesti =kultuuritegelastestkoidulakreutzwaldeesti  (ImpPrSg2  >kultuuritegelastestkoidulakreutzwaldeestima !28_V	et	f	\N
118339	piisa	piisa =piisa  (SgG  >piisk !22_S	et	f	\N
118340	piisa	piisa =piisa  (IndPrPs_  >piisama !29_V	et	f	\N
118341	piisa	piisa =piisa  (ImpPrSg2  >piisama !29_V	et	f	\N
118345	audio	?audio =audio  (SgN  >audio !01_S	et	f	\N
118346	audio	?audio =audio  (SgG  >audio !01_S	et	f	\N
118347	audio	?audio =dio  (SgN  >au+dio !26_S	et	f	\N
118348	audio	?audio =dio  (SgG  >au+dio !26_S	et	f	\N
118371	süstemmatiliselt	?süstemmatiliselt =süstemmatilise  (SgAbl  >süstemmatiline !12_A	et	f	\N
118372	süstemmatiliselt	?süstemmatiliselt =süstemmatiliselt  (ID  >süstemmatiliselt !41_D	et	f	\N
118373	unustavad	unustavad =unusta  (IndPrPl3  >unustama !27_V	et	f	\N
118374	unustavad	unustavad =unustava  (PlN  >unustav !02_A	et	f	\N
118375	unustavad	"unustav %unusta  )V_vA  <unustama ;27_V	et	f	\N
118378	kaudselt	kaudselt =kaudse  (SgAbl  >kaudne !02_A	et	f	\N
118379	kaudselt	kaudselt =kaudselt  (ID  >kaudselt !41_D	et	f	\N
118380	kaudselt	"kaudselt %kaudse  )LT_mD  <kaudne ;02_A	et	f	\N
118383	ainuld	?ainuld =ainuld  (SgN  >ainuld !02_S	et	f	\N
118409	loodavad	loodavad =looda  (IndPrPl3  >lootma !34_V	et	f	\N
118410	loodavad	loodavad =loodava  (PlN  >loodav !02_A	et	f	\N
118411	loodavad	"loodav %loo  )TAV_vAS  <looma ;38_V	et	f	\N
118416	vestelda	vestelda =vestel  (Inf  >vestlema !30_V	et	f	\N
118417	vestelda	vestelda =vestel  (IndPrIps_  >vestlema !30_V	et	f	\N
118419	kultuuriteadmistepuudulikkusele	?kultuuriteadmistepuudulikkusele =kultuuriteadmistepuudulikkuse  (SgAll  >kultuuriteadmistepuudulikkus !11~09_S	et	f	\N
118420	kultuuriteadmistepuudulikkusele	?kultuuriteadmistepuudulikkusele =tepuudulikkuse  (SgAll  >kultuuri+teadmis+tepuudulikkus !11~09_S	et	f	\N
118422	kultuuriteadmistepuudulikkusele	?kultuuriteadmistepuudulikkusele =teadmistepuudulikkuse  (SgAll  >kultuuri+teadmistepuudulikkus !11~09_S	et	f	\N
118423	kultuuriteadmistepuudulikkusele	?kultuuriteadmistepuudulikkusele =iteadmistepuudulikkuse  (SgAll  >kultuur+iteadmistepuudulikkus !11~09_S	et	f	\N
118425	mõistatused	mõistatused =mõistatuse  (PlN  >mõistatus !11_S	et	f	\N
118426	mõistatused	"mõistatus %mõistata  )US_vS  <mõistatama ;27_V	et	f	\N
118433	arusaadavaks	arusaadavaks =vaks  (SgN  >aru+saada+vaks !22_S	et	f	\N
118434	arusaadavaks	arusaadavaks =saadava  (SgTr  >aru+saadav !02_A	et	f	\N
118446	riigiõõpekavas	?riigiõõpekavas =riigiõõpekava  (SgIn  >riigiõõpekav !02_A	et	f	\N
118447	riigiõõpekavas	?riigiõõpekavas =riigiõõpekava  (SgIn  >riigiõõpekava !16_S	et	f	\N
118448	riigiõõpekavas	?riigiõõpekavas =õõpekava  (SgIn  >riigi+õõpekav !02_A	et	f	\N
118449	riigiõõpekavas	?riigiõõpekavas =õõpekava  (SgIn  >riigi+õõpekava !16_S	et	f	\N
118451	mytele2eeoldjyrimarijyrivalikuliselt	?myteleeeoldjyrimarijyrivalikuliselt =myteleeeoldjyrimarijyrivalikulise  (SgAbl  >myteleeeoldjyrimarijyrivalikuline !12_A	et	f	\N
118452	mytele2eeoldjyrimarijyrivalikuliselt	?myteleeeoldjyrimarijyrivalikuliselt =myteleeeoldjyrimarijyrivalikuliselt  (ID  >myteleeeoldjyrimarijyrivalikuliselt !41_D	et	f	\N
118456	andres	?andres =andre  (SgIn  >andre !06_S	et	f	\N
118457	andres	?andres =andre  (IndIpfSg3  >andrema !27_V	et	f	\N
118459	andres	?andres =andres  (SgN  >andres !09_S	et	f	\N
118462	valdmaa	valdmaa =maa  (SgN  >vald+maa !26_S	et	f	\N
118463	valdmaa	valdmaa =maa  (SgG  >vald+maa !26_S	et	f	\N
118464	httpwwwtovltlneduee	?httpwwwtovltlneduee =httpwwwtovltlneduee  (SgN  >httpwwwtovltlneduee !26_S	et	f	\N
118465	httpwwwtovltlneduee	?httpwwwtovltlneduee =httpwwwtovltlneduee  (SgG  >httpwwwtovltlneduee !26_S	et	f	\N
118485	soovid	soovid =soovi  (PlN  >soov !22_S	et	f	\N
118486	soovid	soovid =soovi  (IndPrSg2  >soovima !28_V	et	f	\N
118494	väärtustavad	väärtustavad =väärtusta  (IndPrPl3  >väärtustama !27_V	et	f	\N
118495	väärtustavad	väärtustavad =väärtustava  (PlN  >väärtustav !02_A	et	f	\N
118496	väärtustavad	"väärtustav %väärtusta  )V_vA  <väärtustama ;27_V	et	f	\N
118497	väärtustavad	väärtustavad =tava  (PlN  >väärtus+tava !17_S	et	f	\N
118498	väärtustavad	väärtustavad =ustava  (PlN  >väärt+ustav !02_A	et	f	\N
118561	rikkad	?rikkad =rikka  (PlN  >rikas !07_A	et	f	\N
118562	rikkad	?rikkad =rikka  (IndPrSg2  >rikkama !29_V	et	f	\N
118571	liikumi	?liikumi =liikumi  (SgN  >liikumi !01_S	et	f	\N
118572	liikumi	?liikumi =liikumi  (SgG  >liikumi !01_S	et	f	\N
118573	liikumi	?liikumi =liikumi  (SgG  >liikum !02_S	et	f	\N
118588	tähendanud	tähendanud =tähenda  (PtsPtPs  >tähendama !27_V	et	f	\N
118589	tähendanud	tähendanud =tähendanu  (PlN  >tähendanu !01_S	et	f	\N
118590	tähendanud	"tähendanu %tähenda  )NU_vS  <tähendama ;27_V	et	f	\N
118330	vestlemist	"vestlemine %vestle  )MINE_vS  <vestlema ;30_V	et	f	\N
118352	kuningassamas	?kuningassamas =kuningassama  (SgIn  >kuningassam !02_A	et	f	\N
118353	kuningassamas	?kuningassamas =assama  (SgIn  >kuning+assam !02_A	et	f	\N
118361	5klassi	klassi =klassi  (SgG  >klass !22_S	et	f	\N
118362	5klassi	klassi =klassi  (SgP  >klass !22_S	et	f	\N
118363	5klassi	klassi =klassi  (SgAdt  >klass !22_S	et	f	\N
118366	peetaksekoolid	?peetaksekoolid =peetaksekooli  (PlN  >peetaksekooli !16_S	et	f	\N
118367	peetaksekoolid	?peetaksekoolid =peetaksekooli  (PlN  >peetaksekool !22_S	et	f	\N
118368	peetaksekoolid	?peetaksekoolid =peetaksekooli  (IndPrSg2  >peetaksekoolima !28_V	et	f	\N
118369	peetaksekoolid	?peetaksekoolid =aksekooli  (PlN  >peet+aksekooli !16_S	et	f	\N
118370	peetaksekoolid	?peetaksekoolid =aksekooli  (PlN  >peet+aksekool !22_S	et	f	\N
118381	tunnisloetakse	?tunnisloetakse =tunnisloetakse  (SgG  >tunnisloetakne !02_A	et	f	\N
118382	tunnisloetakse	?tunnisloetakse =tunnisloetakse  (PlP  >tunnisloetaks !22_S	et	f	\N
118384	tunnisloetakse	?tunnisloetakse =loetakse  (SgG  >tunnis+loetakne !02_A	et	f	\N
118385	tunnisloetakse	?tunnisloetakse =sloetakse  (SgG  >tunni+sloetakne !02_A	et	f	\N
118388	kontrollitakse	kontrollitakse =kontrolli  (IndPrIps  >kontrollima !28_V	et	f	\N
118389	kontrollitakse	kontrollitakse =takse  (PlP  >kont+rolli+taks !22_S	et	f	\N
118396	vanasamas	?vanasamas =vanasama  (SgIn  >vanasam !02_A	et	f	\N
118406	rahul	rahul =rahu  (SgAd  >rahu !17_S	et	f	\N
118407	rahul	rahul =rahu  (PlAd  >rahk !22_S	et	f	\N
118408	rahul	rahul =rahul  (ID  >rahul !41_D	et	f	\N
118428	kõne	kõne =kõne  (SgN  >kõne !16_S	et	f	\N
118429	kõne	kõne =kõne  (SgG  >kõne !16_S	et	f	\N
118443	pandnud	?pandnud =pandnu  (PlN  >pandnu !01_S	et	f	\N
118444	pandnud	?pandnud =pandnu  (IndPrSg2  >pandnuma !27_V	et	f	\N
118445	pandnud	?pandnud =pandnud  (ID  >pandnud !41_A	et	f	\N
118450	httpwwwermeelangestnode201	### httpwwwermeelangestnode201	et	f	\N
118472	sundida	sundida =sundi  (Inf  >sundima !28_V	et	f	\N
118473	sundida	sundida =ida  (SgN  >sund+ida !17_S	et	f	\N
118474	sundida	sundida =ida  (SgG  >sund+ida !17_S	et	f	\N
118475	sundida	sundida =ida  (SgP  >sund+ida !17_S	et	f	\N
118476	tõsine	tõsine =tõsine  (SgN  >tõsine !10_A	et	f	\N
118477	tõsine	"tõsine %tõsi  )NE_aA  <tõsi ;15_S	et	f	\N
118478	tõsine	tõsine =tõsine  (IndPrPs_  >tõsinema !27_V	et	f	\N
118479	tõsine	tõsine =tõsine  (ImpPrSg2  >tõsinema !27_V	et	f	\N
118482	kõrgharidust	kõrgharidust =dust  (SgN  >kõrg+hari+dust !22_S	et	f	\N
118483	kõrgharidust	kõrgharidust =haridus  (SgP  >kõrg+haridus !11_S	et	f	\N
118484	ptus	### ptus	et	f	\N
118532	sõlmivad	sõlmivad =sõlmi  (IndPrPl3  >sõlmima !28_V	et	f	\N
118533	sõlmivad	sõlmivad =sõlmiva  (PlN  >sõlmiv !02_A	et	f	\N
118534	sõlmivad	"sõlmiv %sõlmi  )V_vA  <sõlmima ;28_V	et	f	\N
118535	sõlmivad	sõlmivad =iva  (PlN  >sõlm+iva !17_S	et	f	\N
118536	talupoegi	talupoegi =poegi  (SgP  >talu+poeg !22_S	et	f	\N
118537	talupoegi	talupoegi =poegi  (SgAdt  >talu+poeg !22_S	et	f	\N
118538	talupoegi	talupoegi =poegi  (PlP  >talu+poeg !22_S	et	f	\N
118539	talupoegi	talupoegi =poe  (SgG^  >talu+pood !22_S	et	f	\N
118569	säilis	säilis =säili  (IndIpfSg3  >säilima !28_V	et	f	\N
118570	säilis	säilis =säilis  (SgN  >säilis !09_S	et	f	\N
118584	renti	renti =renti  (SgP  >rent !22_S	et	f	\N
118585	renti	renti =renti  (SgAdt  >rent !22_S	et	f	\N
118586	kaotamine	kaotamine =kaotamine  (SgN  >kaotamine !12_S	et	f	\N
118587	kaotamine	"kaotamine %kaota  )MINE_vS  <kaotama ;27_V	et	f	\N
118603	muutus	muutus =muutu  (SgIn  >muutu !01_A	et	f	\N
118604	muutus	"muutu %muu  )TU2_kA  <muu ;26_S	et	f	\N
118605	muutus	muutus =muutu  (IndIpfSg3  >muutuma !27_V	et	f	\N
118606	muutus	muutus =muutus  (SgN  >muutus !11~09_S	et	f	\N
118607	muutus	"muutus %muu  )TUS2_aS  <muu ;26_S	et	f	\N
118633	erdell	?erdell =erdell  (SgN  >erdell !22_S	et	f	\N
118634	mõisaomanikuks	mõisaomanikuks =uks  (SgN  >mõisa+omanik+uks !14_S	et	f	\N
118635	mõisaomanikuks	mõisaomanikuks =omaniku  (SgTr  >mõisa+omanik !25_S	et	f	\N
118636	lootus	lootus =lootu  (SgIn  >lootu !01_A	et	f	\N
118637	lootus	"lootu %loo  )TU2_kA  <lugu ;18_S	et	f	\N
118638	lootus	"lootu %loo  )TU2_kA  <loog ;22_S	et	f	\N
118639	lootus	"lootu %loo  )TU2_kA  <lood ;22_S	et	f	\N
118640	lootus	lootus =lootus  (SgN  >lootus !11~09_S	et	f	\N
118641	lootus	"lootus %loo  )TUS2_aS  <lugu ;18_S	et	f	\N
118642	lootus	"lootus %loo  )TUS2_aS  <loog ;22_S	et	f	\N
118643	lootus	"lootus %loo  )TUS2_aS  <lood ;22_S	et	f	\N
118650	embrüoloogia	embrüoloogia =embrüoloogia  (SgN  >embrüoloogia !01_S	et	f	\N
118651	embrüoloogia	embrüoloogia =embrüoloogia  (SgG  >embrüoloogia !01_S	et	f	\N
118658	w	### w	et	f	\N
118659	struve	?struve =struve  (SgN  >struve !16_S	et	f	\N
118660	struve	?struve =struve  (SgG  >struve !16_S	et	f	\N
118661	struve	?struve =struve  (IndPrPs_  >struvema !27_V	et	f	\N
118662	struve	?struve =struve  (ImpPrSg2  >struvema !27_V	et	f	\N
118667	kodustel	kodustel =kodus  (PlAd  >kodune !10_A	et	f	\N
118668	kodustel	"kodune %kodu  )NE_aA  <kodu ;17_S	et	f	\N
118343	põhjalikult	põhjalikult =põhjalikult  (ID  >põhjalikult !41_D	et	f	\N
118344	põhjalikult	"põhjalikult %põhjaliku  )LT_mD  <põhjalik ;25_A	et	f	\N
118376	omandasid	omandasid =omanda  (IndIpfSg2  >omandama !27_V	et	f	\N
118377	omandasid	omandasid =omanda  (IndIpfPl3  >omandama !27_V	et	f	\N
118394	korrata	korrata =korra  (SgAb  >kord !22_S	et	f	\N
118395	korrata	korrata =korra  (Inf  >kordama !29_V	et	f	\N
118397	korrata	korrata =korra  (IndPrIps_  >kordama !29_V	et	f	\N
118427	sams	?sams =sams  (SgN  >sams !22_S	et	f	\N
118461	adamsonsulev	?adamsonsulev =adamsonsulev  (SgN  >adamsonsulev !02_A	et	f	\N
118471	lajsk	?lajsk =lajsk  (SgN  >lajsk !22_S	et	f	\N
118480	prooblem	?prooblem =prooblem  (SgN  >prooblem !02_A	et	f	\N
118499	taasavamise	taasavamise =avamise  (SgG  >taas+avamine !12_S	et	f	\N
118500	taasavamise	"taas+avamine %ava  )MINE_vS  <taas+avama ;27_V	et	f	\N
118505	sisuliselt	sisuliselt =sisulise  (SgAbl  >sisuline !12_A	et	f	\N
118506	sisuliselt	"sisuline %sisu  )LINE_aA  <sisu ;17_S	et	f	\N
118507	sisuliselt	sisuliselt =sisuliselt  (ID  >sisuliselt !41_D	et	f	\N
118508	sisuliselt	"sisuliselt %sisu  )LISELT_mD  <sisu ;17_S	et	f	\N
118509	sisuliselt	"sisuliselt %sisulise  )LT_mD  <sisuline ;12_A	et	f	\N
118516	võlgu	võlgu =võlgu  (ID  >võlgu !41_D	et	f	\N
118517	võlgu	võlgu =võlgu  (PlP  >võlg !22_S	et	f	\N
118518	loenguid	loenguid =loengu  (PlP  >loeng !02_S	et	f	\N
118519	loenguid	loenguid =ui  (PlN  >loeng+ui !26_S	et	f	\N
118520	loenguid	loenguid =ui  (SgP  >loeng+ui !26_S	et	f	\N
118521	loenguid	loenguid =uid  (SgN  >loeng+uid !22_S	et	f	\N
118525	ahrens	?ahrens =ahrens  (SgN  >ahrens !02_S	et	f	\N
118543	kodanikuõigusi	kodanikuõigusi =õigusi  (PlP  >kodaniku+õigus !11_S	et	f	\N
118544	kodanikuõigusi	"kodaniku+õigus %õige  )US_aS  <kodaniku+õige ;01_A	et	f	\N
118563	1819a	### 1819a	et	f	\N
118564	kaotatud	kaotatud =kaota  (PtsPtIps  >kaotama !27_V	et	f	\N
118565	kaotatud	kaotatud =kaotatu  (PlN  >kaotatu !01_S	et	f	\N
118566	kaotatud	"kaotatu %kaota  )TU1_vS  <kaotama ;27_V	et	f	\N
118567	kaotatud	kaotatud =kaotatud  (ID  >kaotatud !41_A	et	f	\N
118568	kaotatud	"kaotatud %kaota  )TUD_vA  <kaotama ;27_V	et	f	\N
118574	rendileppingu	?rendileppingu =rendileppingu  (SgG  >rendilepping !02_S	et	f	\N
118577	rendileppingu	?rendileppingu =rendileppingu  (IndPrPs_  >rendileppinguma !27_V	et	f	\N
118579	rendileppingu	?rendileppingu =rendileppingu  (ImpPrSg2  >rendileppinguma !27_V	et	f	\N
118580	rendileppingu	?rendileppingu =leppingu  (SgN  >rendi+leppingu !01_S	et	f	\N
118582	rendileppingu	?rendileppingu =leppingu  (SgG  >rendi+leppingu !01_S	et	f	\N
118583	rendileppingu	?rendileppingu =leppingu  (SgG  >rendi+lepping !02_S	et	f	\N
118619	psühholoogiliselt	psühholoogiliselt =psühholoogilise  (SgAbl  >psühholoogiline !12_A	et	f	\N
118620	psühholoogiliselt	"psühholoogiline %psühholoogi  )LINE_aA  <psühholoog ;22_S	et	f	\N
118621	psühholoogiliselt	psühholoogiliselt =psühholoogiliselt  (ID  >psühholoogiliselt !41_D	et	f	\N
118622	psühholoogiliselt	"psühholoogiliselt %psühholoogi  )LISELT_mD  <psühholoog ;22_S	et	f	\N
118623	psühholoogiliselt	"psühholoogiliselt %psühholoogilise  )LT_mD  <psühholoogiline ;12_A	et	f	\N
118624	psühholoogiliselt	psühholoogiliselt =loogilise  (SgAbl  >psühho+loogiline !12_A	et	f	\N
118625	psühholoogiliselt	"psühho+loogiline %loogi  )LINE_aA  <psühho+loog ;22_S	et	f	\N
118626	psühholoogiliselt	"psühho+loogiliselt %loogi  )LISELT_mD  <psühho+loog ;22_S	et	f	\N
118627	psühholoogiliselt	"psühho+loogiliselt %loogilise  )LT_mD  <psühho+loogiline ;12_A	et	f	\N
118644	parematele	parematele =parema  (PlAll  >parem !02_A	et	f	\N
118645	parematele	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
118646	parematele	parematele =ate  (PlAll  >parem+att !22_S	et	f	\N
118663	kättesaadavaks	kättesaadavaks =vaks  (SgN  >kätte+saada+vaks !22_S	et	f	\N
118664	kättesaadavaks	kättesaadavaks =saadava  (SgTr  >kätte+saadav !02_A	et	f	\N
118665	arenemisest	arenemisest =arenemise  (SgEl  >arenemine !12_S	et	f	\N
118666	arenemisest	"arenemine %arene  )MINE_vS  <arenema ;27_V	et	f	\N
118669	puudumine	puudumine =puudumine  (SgN  >puudumine !12_S	et	f	\N
118670	puudumine	"puudumine %puudu  )MINE_vS  <puuduma ;27_V	et	f	\N
118701	kõrge	kõrge =kõrge  (SgN  >kõrge !01_A	et	f	\N
118702	kõrge	kõrge =kõrge  (SgN  >kõrge !05_S	et	f	\N
118703	kõrge	kõrge =kõrge  (SgG  >kõrge !01_A	et	f	\N
118726	poppi	poppi =poppi  (SgP  >popp !22_AS	et	f	\N
118727	poppi	poppi =poppi  (SgAdt  >popp !22_AS	et	f	\N
118731	kirjeldus	kirjeldus =kirjeldus  (SgN  >kirjeldus !11_S	et	f	\N
118732	kirjeldus	"kirjeldus %kirjelda  )US_vS  <kirjeldama ;27_V	et	f	\N
118738	kuusteist	kuusteist =te  (PlEl  >kuus+tee !26_S	et	f	\N
118739	kuusteist	kuusteist =teist  (SgN  >kuus+teist !22_S	et	f	\N
118746	poliitikast	poliitikast =poliitika  (SgEl  >poliitika !01_S	et	f	\N
118747	poliitikast	poliitikast =poliitikas  (SgP  >poliitikane !12_A	et	f	\N
118748	poliitikast	"poliitikane %poliitika  )NE_aA  <poliitika ;01_S	et	f	\N
118770	lehekülgedel	lehekülgedel =ede  (SgAd  >lehe+külg+ede !16_S	et	f	\N
118771	lehekülgedel	lehekülgedel =edel  (SgN  >lehe+külg+edel !02_S	et	f	\N
118772	lehekülgedel	lehekülgedel =külge  (PlAd  >lehe+külg !22_S	et	f	\N
118793	lühikokkuvõtte	lühikokkuvõtte =võtte  (SgG  >lühi+kokku+võte !06_S	et	f	\N
118438	testideanalüüsidega	?testideanalüüsidega =deanalüüsi  (PlKom  >testi+deanalüüsi !16_S	et	f	\N
118439	testideanalüüsidega	?testideanalüüsidega =deanalüüsi  (PlKom  >testi+deanalüüs !22_S	et	f	\N
118440	testideanalüüsidega	?testideanalüüsidega =ideanalüüsi  (PlKom  >test+ideanalüüsi !16_S	et	f	\N
118442	testideanalüüsidega	?testideanalüüsidega =ideanalüüsi  (PlKom  >test+ideanalüüs !22_S	et	f	\N
118453	valikuliselt	valikuliselt =valikulise  (SgAbl  >valikuline !12_A	et	f	\N
118454	valikuliselt	"valikuline %valiku  )LINE_aA  <valik ;02_S	et	f	\N
118455	valikuliselt	valikuliselt =valikuliselt  (ID  >valikuliselt !41_D	et	f	\N
118458	valikuliselt	"valikuliselt %valiku  )LISELT_mD  <valik ;02_S	et	f	\N
118460	valikuliselt	"valikuliselt %valikulise  )LT_mD  <valikuline ;12_A	et	f	\N
118466	teenivad	teenivad =teeni  (IndPrPl3  >teenima !28_V	et	f	\N
118467	teenivad	teenivad =teeniva  (PlN  >teeniv !02_A	et	f	\N
118468	teenivad	"teeniv %teeni  )V_vA  <teenima ;28_V	et	f	\N
118491	sisendavad	sisendavad =sisenda  (IndPrPl3  >sisendama !27_V	et	f	\N
118492	sisendavad	sisendavad =sisendava  (PlN  >sisendav !02_A	et	f	\N
118493	sisendavad	"sisendav %sisenda  )V_vA  <sisendama ;27_V	et	f	\N
118512	vallasvara	vallasvara =vara  (SgN  >vallas+vara !17_S	et	f	\N
118513	vallasvara	vallasvara =vara  (SgG  >vallas+vara !17_S	et	f	\N
118514	vallasvara	vallasvara =vara  (SgP  >vallas+vara !17_S	et	f	\N
118515	müüapärandada	?müüapärandada =müüapäranda  (Inf  >müüapärandama !27_V	et	f	\N
118526	ahrensi	?ahrensi =ahrensi  (SgN  >ahrensi !01_S	et	f	\N
118527	ahrensi	?ahrensi =ahrensi  (SgG  >ahrensi !01_S	et	f	\N
118528	ahrensi	?ahrensi =ahrensi  (SgG  >ahrens !02_S	et	f	\N
118529	ahrensi	?ahrensi =ahrensi  (SgG  >ahrenss !22_S	et	f	\N
118530	ahrensi	?ahrensi =ahrensi  (IndPrPs_  >ahrenssima !28_V	et	f	\N
118531	ahrensi	?ahrensi =ahrensi  (ImpPrSg2  >ahrenssima !28_V	et	f	\N
118540	kinnisvara	kinnisvara =vara  (SgN  >kinnis+vara !17_S	et	f	\N
118541	kinnisvara	kinnisvara =vara  (SgG  >kinnis+vara !17_S	et	f	\N
118542	kinnisvara	kinnisvara =vara  (SgP  >kinnis+vara !17_S	et	f	\N
118545	perekonnanime	perekonnanime =nime  (SgG  >pere+konna+nimi !20_S	et	f	\N
118546	perekonnanime	perekonnanime =nime  (SgP  >pere+konna+nimi !20_S	et	f	\N
118551	nälgi	nälgi =nälgi  (SgP  >nälg !22_S	et	f	\N
118552	nälgi	nälgi =nälgi  (SgAdt  >nälg !22_S	et	f	\N
118553	nälgi	nälgi =nälgi  (PlP  >nälg !22_S	et	f	\N
118554	nälgi	nälgi =nälgi  (IndPrPs_  >nälgima !27_V	et	f	\N
118555	nälgi	nälgi =nälgi  (ImpPrSg2  >nälgima !27_V	et	f	\N
118558	seadus	seadus =seadu  (SgIn  >sead !22_S	et	f	\N
118559	seadus	seadus =seadu  (IndIpfSg3  >seaduma !27_V	et	f	\N
118560	seadus	seadus =seadus  (SgN  >seadus !11~09_S	et	f	\N
118575	sõlmima	sõlmima =sõlmi  (Sup  >sõlmima !28_V	et	f	\N
118576	sõlmima	sõlmima =ima  (SgN  >sõlm+ima !17_S	et	f	\N
118578	sõlmima	sõlmima =ima  (SgG  >sõlm+ima !17_S	et	f	\N
118581	sõlmima	sõlmima =ima  (SgP  >sõlm+ima !17_S	et	f	\N
118600	kohati	kohati =koha  (IndIpfIps  >kohama !27_V	et	f	\N
118601	kohati	kohati =koha  (IndIpfIps  >kohtama !29_V	et	f	\N
118602	kohati	kohati =kohati  (ID  >kohati !41_D	et	f	\N
118613	vabastamine	vabastamine =vabastamine  (SgN  >vabastamine !12_S	et	f	\N
118614	vabastamine	"vabastamine %vabasta  )MINE_vS  <vabastama ;27_V	et	f	\N
118690	ootamine	ootamine =ootamine  (SgN  >ootamine !12_S	et	f	\N
118691	ootamine	"ootamine %oota  )MINE_vS  <ootama ;29_V	et	f	\N
118696	köha	köha =köha  (SgN  >köha !17_S	et	f	\N
118699	köha	köha =köha  (SgG  >köha !17_S	et	f	\N
118700	köha	köha =köha  (SgP  >köha !17_S	et	f	\N
118714	kirjutavad	kirjutavad =kirjuta  (IndPrPl3  >kirjutama !27_V	et	f	\N
118716	kirjutavad	kirjutavad =kirjutava  (PlN  >kirjutav !02_A	et	f	\N
118718	kirjutavad	"kirjutav %kirjuta  )V_vA  <kirjutama ;27_V	et	f	\N
118752	värvilise	värvilise =värvilise  (SgG  >värviline !12_A	et	f	\N
118753	värvilise	"värviline %värvi  )LINE_aA  <värv ;22_S	et	f	\N
118757	võitjatele	võitjatele =võitja  (PlAll  >võitja !01_S	et	f	\N
118758	võitjatele	"võitja %võit  )JA_vS  <võitma ;34_V	et	f	\N
118761	viissada	### viissada	et	f	\N
118762	krooni	krooni =krooni  (SgG  >kroon !22_S	et	f	\N
118763	krooni	krooni =krooni  (SgP  >kroon !22_S	et	f	\N
118764	krooni	krooni =krooni  (SgAdt  >kroon !22_S	et	f	\N
118765	krooni	krooni =krooni  (IndPrPs_  >kroonima !28_V	et	f	\N
118766	krooni	krooni =krooni  (ImpPrSg2  >kroonima !28_V	et	f	\N
118768	sada	sada =sada  (SgN  >sada !18_N	et	f	\N
118769	sada	sada =sada  (SgP  >sada !18_N	et	f	\N
118779	kava	kava =kava  (SgN  >kava !17_S	et	f	\N
118780	kava	kava =kava  (SgG  >kava !17_S	et	f	\N
118781	kava	kava =kava  (SgP  >kava !17_S	et	f	\N
118789	kasteist	kasteist =kaste  (PlEl  >kaste !06_S	et	f	\N
118790	kasteist	kasteist =te  (PlEl  >kas+tee !26_S	et	f	\N
118791	kasteist	kasteist =teist  (SgN  >kas+teist !22_S	et	f	\N
118792	kahetuhande	?kahetuhande =kahetuhande  (PlP  >kahetuhand !22_S	et	f	\N
118795	artiklist	artiklist =artikli  (SgEl  >artikkel !02_S	et	f	\N
118796	artiklist	artiklist =artiklis  (SgP  >artikline !12_A	et	f	\N
118797	artiklist	"artikline %artikli  )NE_aA  <artikkel ;02_S	et	f	\N
118469	õpetöös	?õpetöös =õpetöö  (SgIn  >õpetöö !26_S	et	f	\N
118470	õpetöös	?õpetöös =õpetöös  (SgN  >õpetöös !22_S	et	f	\N
118481	võjmalik	?võjmalik =võjmalik  (SgN  >võjmalik !25_A	et	f	\N
118487	prestiizne	?prestiizne =prestiizne  (SgN  >prestiizne !02_A	et	f	\N
118488	prestiizne	?prestiizne =prestiizne  (PlP  >prestiizn !22_S	et	f	\N
118489	prestiizne	?prestiizne =stiizne  (SgN  >pre+stiizne !02_A	et	f	\N
118490	prestiizne	?prestiizne =stiizne  (PlP  >pre+stiizn !22_S	et	f	\N
118501	pärisorjusest	pärisorjusest =orjuse  (SgEl  >päris+orjus !11~09_S	et	f	\N
118502	pärisorjusest	pärisorjusest =orjuses  (SgP  >päris+orjusene !12_A	et	f	\N
118503	pärisorjusest	"päris+orjusene %orjuse  )NE_aA  <päris+orjus ;09_S	et	f	\N
118504	pärisorjusest	"päris+orjusene %orjuse  )NE_aA  <päris+orjus ;11_S	et	f	\N
118510	parrot	?parrot =parro  (SgP  >parro !16_S	et	f	\N
118511	parrot	?parrot =parrot  (SgN  >parrot !02_S	et	f	\N
118522	kirjaviis	kirjaviis =kirjavi  (PlIn  >kirjav !02_A	et	f	\N
118523	kirjaviis	"kirjav %kirja  )V_vA  <kirjama ;29_V	et	f	\N
118524	kirjaviis	kirjaviis =viis  (SgN  >kirja+viis !22_S	et	f	\N
118547	rännata	rännata =ränna  (Inf  >rändama !29_V	et	f	\N
118548	rännata	rännata =ränna  (IndPrIps_  >rändama !29_V	et	f	\N
118549	täpsustati	täpsustati =täpsusta  (IndIpfIps  >täpsustama !27_V	et	f	\N
118550	täpsustati	täpsustati =tati  (SgG  >täpsus+tatt !22_S	et	f	\N
118556	kaotamist	kaotamist =kaotamis  (SgP  >kaotamine !12_S	et	f	\N
118557	kaotamist	"kaotamine %kaota  )MINE_vS  <kaotama ;27_V	et	f	\N
118593	taluoja	taluoja =oja  (SgN  >talu+oja !17_S	et	f	\N
118594	taluoja	taluoja =oja  (SgG  >talu+oja !17_S	et	f	\N
118595	taluoja	taluoja =oja  (SgP  >talu+oja !17_S	et	f	\N
118631	talupojal	talupojal =poja  (SgAd  >talu+poja !17_S	et	f	\N
118632	talupojal	talupojal =poja  (SgAd  >talu+poeg !22_S	et	f	\N
118649	baer	?baer =baer  (SgN  >baer !22_S	et	f	\N
118652	rajaja	rajaja =rajaja  (SgN  >rajaja !01_S	et	f	\N
118653	rajaja	"rajaja %raja  )JA_vS  <rajama ;27_V	et	f	\N
118655	rajaja	rajaja =rajaja  (SgG  >rajaja !01_S	et	f	\N
118673	juhtuvad	juhtuvad =juhtu  (IndPrPl3  >juhtuma !27_V	et	f	\N
118674	juhtuvad	juhtuvad =juhtuva  (PlN  >juhtuv !02_A	et	f	\N
118675	juhtuvad	"juhtuv %juhtu  )V_vA  <juhtuma ;27_V	et	f	\N
118676	õnnetus	õnnetus =õnnetu  (SgIn  >õnnetu !01_A	et	f	\N
118677	õnnetus	"õnnetu %õnne  )TU2_kA  <õnn ;22_S	et	f	\N
118679	õnnetus	õnnetus =õnnetus  (SgN  >õnnetus !11_S	et	f	\N
118681	õnnetus	"õnnetus %õnne  )TUS2_aS  <õnn ;22_S	et	f	\N
118695	nohu	nohu =nohu  (SgN  >nohu !17_S	et	f	\N
118697	nohu	nohu =nohu  (SgG  >nohu !17_S	et	f	\N
118698	nohu	nohu =nohu  (SgP  >nohu !17_S	et	f	\N
118706	arsti	arsti =arsti  (SgG  >arst !22_S	et	f	\N
118707	arsti	arsti =arsti  (SgP  >arst !22_S	et	f	\N
118708	arsti	arsti =arsti  (SgAdt  >arst !22_S	et	f	\N
118709	arsti	arsti =arsti  (IndPrPs_  >arstima !28_V	et	f	\N
118710	arsti	arsti =arsti  (ImpPrSg2  >arstima !28_V	et	f	\N
118713	seletuskirju	seletuskirju =kirju  (SgN  >seletus+kirju !01_A	et	f	\N
118715	seletuskirju	seletuskirju =kirju  (SgN  >seletus+kirju !16_A	et	f	\N
118717	seletuskirju	seletuskirju =kirju  (SgG  >seletus+kirju !01_A	et	f	\N
118719	seletuskirju	seletuskirju =kirju  (SgG  >seletus+kirju !16_A	et	f	\N
118720	seletuskirju	seletuskirju =kirju  (PlP  >seletus+kiri !24_S	et	f	\N
118733	ajalehte	ajalehte =lehte  (SgP  >aja+leht !22_S	et	f	\N
118734	ajalehte	ajalehte =lehte  (SgAdt  >aja+leht !22_S	et	f	\N
118735	ajalehte	ajalehte =lehte  (PlP  >aja+leht !22_S	et	f	\N
118736	iganädalane	iganädalane =nädalane  (SgN  >iga+nädalane !12_A	et	f	\N
118737	iganädalane	"iga+nädalane %nädala  )NE_aA  <iga+nädal ;02_S	et	f	\N
118754	ristsõna	ristsõna =sõna  (SgN  >rist+sõna !17_S	et	f	\N
118755	ristsõna	ristsõna =sõna  (SgG  >rist+sõna !17_S	et	f	\N
118756	ristsõna	ristsõna =sõna  (SgP  >rist+sõna !17_S	et	f	\N
118759	kingitakse	kingitakse =kingi  (IndPrIps  >kinkima !28_V	et	f	\N
118760	kingitakse	kingitakse =takse  (PlP  >kingi+taks !22_S	et	f	\N
118767	kakssada	### kakssada	et	f	\N
118784	üksteist	üksteist =teis  (SgP  >üks+teise !12_P	et	f	\N
118785	üksteist	üksteist =te  (PlEl  >üks+tee !26_S	et	f	\N
118786	üksteist	üksteist =teist  (SgN  >üks+teist !22_S	et	f	\N
118802	piima	piima =piima  (SgG  >piim !22_S	et	f	\N
118803	piima	piima =piima  (SgP  >piim !22_S	et	f	\N
118804	piima	piima =piima  (SgAdt  >piim !22_S	et	f	\N
118805	nvinner	?nvinner =nvinner  (SgN  >nvinner !02_S	et	f	\N
118814	belka	?belka =belka  (SgN  >belka !16_S	et	f	\N
118815	belka	?belka =belka  (SgG  >belka !16_S	et	f	\N
118816	belka	?belka =belka  (IndPrPs_  >belkama !29_V	et	f	\N
118817	belka	?belka =belka  (ImpPrSg2  >belkama !29_V	et	f	\N
118831	ebatavaline	ebatavaline =tavaline  (SgN  >eba+tavaline !12_A	et	f	\N
118832	ebatavaline	"eba+tavaline %tava  )LINE_aA  <eba+tava ;17_S	et	f	\N
118833	raavib	?raavib =raavi  (IndPrSg3  >raavima !28_V	et	f	\N
118856	asutus	asutus =asutu  (SgIn  >asutu !01_AS	et	f	\N
118857	asutus	"asutu %asu  )TU1_vS  <asuma ;27_V	et	f	\N
118858	asutus	"asutu %asu  )TU2_kA  <asu ;17_S	et	f	\N
118591	tähendanud	tähendanud =tähendanud  (ID  >tähendanud !41_A	et	f	\N
118592	tähendanud	"tähendanud %tähenda  )NUD_vA  <tähendama ;27_V	et	f	\N
118596	kergemaks	kergemaks =kergema  (SgTr  >kergem !02_A	et	f	\N
118597	kergemaks	"kergem %kerge  )M_cA  <kerge ;01_A	et	f	\N
118598	kergemaks	kergemaks =maks  (SgN  >kerge+maks !22_S	et	f	\N
118599	kergemaks	kergemaks =ema  (SgTr  >kerg+ema !17_S	et	f	\N
118608	karmimaks	karmimaks =karmima  (SgTr  >karmim !02_A	et	f	\N
118609	karmimaks	"karmim %karmi  )M_cA  <karm ;22_A	et	f	\N
118610	karmimaks	karmimaks =maks  (SgN  >karmi+maks !22_S	et	f	\N
118611	parisorjusest	?parisorjusest =parisorjuse  (SgEl  >parisorjus !11~09_S	et	f	\N
118612	parisorjusest	?parisorjusest =parisorjuses  (SgP  >parisorjusene !12_A	et	f	\N
118615	talupoja	talupoja =poja  (SgN  >talu+poja !17_S	et	f	\N
118616	talupoja	talupoja =poja  (SgG  >talu+poja !17_S	et	f	\N
118617	talupoja	talupoja =poja  (SgG  >talu+poeg !22_S	et	f	\N
118618	talupoja	talupoja =poja  (SgP  >talu+poja !17_S	et	f	\N
118628	vabadust	vabadust =vabadus  (SgP  >vabadus !11_S	et	f	\N
118629	vabadust	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
118630	vabadust	vabadust =dust  (SgN  >vaba+dust !22_S	et	f	\N
118647	õppetöö	õppetöö =töö  (SgN  >õppe+töö !26_S	et	f	\N
118648	õppetöö	õppetöö =töö  (SgG  >õppe+töö !26_S	et	f	\N
118654	jakobi	?jakobi =jakobi  (SgN  >jakobi !01_S	et	f	\N
118656	jakobi	?jakobi =jakobi  (SgG  >jakobi !01_S	et	f	\N
118657	jakobi	?jakobi =jakobi  (SgG  >jakob !02_S	et	f	\N
118671	õnnetused	õnnetused =õnnetuse  (PlN  >õnnetus !11_S	et	f	\N
118672	õnnetused	"õnnetus %õnne  )TUS2_aS  <õnn ;22_S	et	f	\N
118678	lõpeb	lõpeb =lõpe  (IndPrSg3  >lõppema !28_V	et	f	\N
118680	lõpeb	lõpeb =lõpe  (IndPrSg3  >lõpma !35_V	et	f	\N
118692	kaaluvad	kaaluvad =kaalu  (IndPrPl3  >kaaluma !28_V	et	f	\N
118693	kaaluvad	kaaluvad =kaaluva  (PlN  >kaaluv !02_A	et	f	\N
118694	kaaluvad	"kaaluv %kaalu  )V_vA  <kaaluma ;28_V	et	f	\N
118721	kergekäeliselt	kergekäeliselt =käelise  (SgAbl  >kerge+käeline !12?10_A	et	f	\N
118722	kergekäeliselt	"kerge+käeline %käe  )LINE_aA  <kerge+käsi ;15_S	et	f	\N
118723	kergekäeliselt	"kerge+käeliselt %käe  )LISELT_mD  <kerge+käsi ;15_S	et	f	\N
118724	kergekäeliselt	"kerge+käeliselt %käelise  )LT_mD  <kerge+käeline ;10_A	et	f	\N
118725	kergekäeliselt	"kerge+käeliselt %käelise  )LT_mD  <kerge+käeline ;12_A	et	f	\N
118740	lehekülge	lehekülge =külge  (SgP  >lehe+külg !22_S	et	f	\N
118741	lehekülge	lehekülge =külge  (SgAdt  >lehe+külg !22_S	et	f	\N
118742	lehekülge	lehekülge =külge  (PlP  >lehe+külg !22_S	et	f	\N
118743	trükitud	trükitud =trüki  (PtsPtIps  >trükkima !28_V	et	f	\N
118744	trükitud	trükitud =trükitu  (PlN  >trükitu !01_AS	et	f	\N
118745	trükitud	"trükitu %trüki  )TU1_vS  <trükkima ;28_V	et	f	\N
118749	trükitud	"trükitu %trüki  )TU2_kA  <trükk ;22_S	et	f	\N
118750	trükitud	trükitud =trükitud  (ID  >trükitud !41_A	et	f	\N
118751	trükitud	"trükitud %trüki  )TUD_vA  <trükkima ;28_V	et	f	\N
118773	televisiooni	televisiooni =televisiooni  (SgG  >televisioon !22_S	et	f	\N
118774	televisiooni	televisiooni =televisiooni  (SgP  >televisioon !22_S	et	f	\N
118775	televisiooni	televisiooni =televisiooni  (SgAdt  >televisioon !22_S	et	f	\N
118776	televisiooni	televisiooni =visiooni  (SgG  >tele+visioon !22_S	et	f	\N
118777	televisiooni	televisiooni =visiooni  (SgP  >tele+visioon !22_S	et	f	\N
118778	televisiooni	televisiooni =visiooni  (SgAdt  >tele+visioon !22_S	et	f	\N
118787	kahel	kahel =kahe  (SgAd  >kaks !22_N	et	f	\N
118788	kahel	kahel =kahe  (PlAd  >kahk !22_S	et	f	\N
118798	sarve	sarve =sarve  (SgG  >sarv !22_S	et	f	\N
118799	sarve	sarve =sarve  (SgP  >sarv !22_S	et	f	\N
118800	sarve	sarve =sarve  (SgAdt  >sarv !22_S	et	f	\N
118801	sarve	sarve =sarve  (PlP  >sarv !22_S	et	f	\N
118806	mustvalge	### mustvalge	et	f	\N
118834	külmatust	külmatust =külmatu  (SgEl  >külmatu !01_A	et	f	\N
118835	külmatust	"külmatu %külma  )TU1_vS  <külmama ;29_V	et	f	\N
118836	külmatust	külmatust =külmatus  (SgP  >külmatus !11_S	et	f	\N
118837	külmatust	"külmatus %külma  )TUS1_aS  <külmama ;29_V	et	f	\N
118838	külmatust	külmatust =tust  (SgN  >külma+tust !22_S	et	f	\N
118839	külmatust	külmatust =atu  (SgEl  >külm+att !22_S	et	f	\N
118840	neljaastane	?neljaastane =neljaastane  (SgN  >neljaastane !12~10_A	et	f	\N
118841	neljaastane	?neljaastane =neljaastane  (PlP  >neljaastan !19_S	et	f	\N
118842	neljaastane	?neljaastane =astane  (SgN  >nelja+astane !12~10_A	et	f	\N
118846	tavaline	tavaline =tavaline  (SgN  >tavaline !12_A	et	f	\N
118847	tavaline	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
118863	erialaste	erialaste =alas  (PlG  >eri+alane !10_AS	et	f	\N
118864	erialaste	"eri+alane %ala  )NE_aA  <eri+ala ;17_S	et	f	\N
118866	põnevaim	põnevaim =põnevaim  (SgN  >põnevaim !02_A	et	f	\N
118867	põnevaim	"põnevaim %põneva  )IM_sA  <põnev ;02_A	et	f	\N
118894	vüitjatele	?vüitjatele =vüitja  (PlAll  >vüitja !01_S	et	f	\N
118895	vüitjatele	?vüitjatele =vüitja  (PlAll  >vüitjas !02_A	et	f	\N
118896	vüitjatele	?vüitjatele =vüitjate  (PlAll  >vüitjatt !22_S	et	f	\N
118897	vüitjatele	?vüitjatele =vüitjatele  (IndPrPs_  >vüitjatelema !36_V	et	f	\N
118682	õnnelikult	õnnelikult =õnneliku  (SgAbl  >õnnelik !25_A	et	f	\N
118683	õnnelikult	õnnelikult =õnnelikult  (ID  >õnnelikult !41_D	et	f	\N
118684	õnnelikult	"õnnelikult %õnneliku  )LT_mD  <õnnelik ;25_A	et	f	\N
118685	uputus	uputus =uputu  (SgIn  >uputu !01_AS	et	f	\N
118686	uputus	"uputu %upu  )TU1_vS  <uppuma ;28_V	et	f	\N
118687	uputus	uputus =uputus  (SgN  >uputus !11_S	et	f	\N
118688	uputus	"uputus %uputa  )US_vS  <uputama ;27_V	et	f	\N
118689	uputus	"uputus %upu  )TUS1_aS  <uppuma ;28_V	et	f	\N
118704	viitsi	viitsi =viitsi  (IndPrPs_  >viitsima !28_V	et	f	\N
118705	viitsi	viitsi =viitsi  (ImpPrSg2  >viitsima !28_V	et	f	\N
118711	kodusel	kodusel =koduse  (SgAd  >kodune !10_A	et	f	\N
118712	kodusel	"kodune %kodu  )NE_aA  <kodu ;17_S	et	f	\N
118728	öeldu	öeldu =öeldu  (SgN  >öeldu !01_S	et	f	\N
118729	öeldu	"öeldu %öel  )TU1_vS  <ütlema ;30_V	et	f	\N
118730	öeldu	öeldu =öeldu  (SgG  >öeldu !01_S	et	f	\N
118782	kolmteist	kolmteist =te  (PlEl  >kolm+tee !26_S	et	f	\N
118783	kolmteist	kolmteist =teist  (SgN  >kolm+teist !22_S	et	f	\N
118818	kitse	kitse =kitse  (SgG  >kits !22_S	et	f	\N
118819	kitse	kitse =kitse  (SgP  >kits !22_S	et	f	\N
118820	kitse	kitse =kitse  (SgAdt  >kits !22_S	et	f	\N
118821	kitse	kitse =kitse  (PlP  >kits !22_S	et	f	\N
118848	pr	### pr	et	f	\N
118851	ajakirjanduslevi	ajakirjanduslevi =levi  (SgN  >aja+kirjandus+levi !17_S	et	f	\N
118852	ajakirjanduslevi	ajakirjanduslevi =levi  (SgG  >aja+kirjandus+levi !17_S	et	f	\N
118853	ajakirjanduslevi	ajakirjanduslevi =levi  (SgP  >aja+kirjandus+levi !17_S	et	f	\N
118868	trükis	trükis =trüki  (SgIn  >trükk !22_S	et	f	\N
118869	trükis	trükis =trükis  (SgN  >trükis !09_S	et	f	\N
118870	reeklaamist	?reeklaamist =reeklaami  (SgEl  >reeklaami !16_S	et	f	\N
118871	reeklaamist	?reeklaamist =reeklaami  (SgEl  >reeklaam !22_S	et	f	\N
118872	reeklaamist	?reeklaamist =reeklaamis  (SgP  >reeklaamis !09_S	et	f	\N
118873	reeklaamist	?reeklaamist =reeklaamis  (SgP  >reeklaamine !10_A	et	f	\N
118874	reeklaamist	?reeklaamist =klaami  (SgEl  >ree+klaami !16_S	et	f	\N
118875	reeklaamist	?reeklaamist =klaami  (SgEl  >ree+klaam !22_S	et	f	\N
118876	reeklaamist	?reeklaamist =klaamis  (SgP  >ree+klaamis !09_S	et	f	\N
118877	reeklaamist	?reeklaamist =klaamis  (SgP  >ree+klaamine !10_A	et	f	\N
118878	reeklaamist	?reeklaamist =klaamist  (SgN  >ree+klaamist !22_S	et	f	\N
118889	värvilisi	värvilisi =värvilisi  (PlP  >värviline !12_A	et	f	\N
118890	värvilisi	"värviline %värvi  )LINE_aA  <värv ;22_S	et	f	\N
118892	osalemine	osalemine =osalemine  (SgN  >osalemine !12_S	et	f	\N
118893	osalemine	"osalemine %osale  )MINE_vS  <osalema ;27_V	et	f	\N
118905	ida-virumaa	ida-virumaa =maa  (SgN  >ida-viru+maa !26_S	et	f	\N
118908	ida-virumaa	ida-virumaa =maa  (SgG  >ida-viru+maa !26_S	et	f	\N
118911	austusega	austusega =austuse  (SgKom  >austus !11~09_S	et	f	\N
118914	austusega	"austus %austa  )US_vS  <austama ;27_V	et	f	\N
118935	kaasas	kaasas =kaasa  (SgIn  >kaasa !16_S	et	f	\N
118936	kaasas	kaasas =kaasa  (IndIpfSg3  >kaasama !29_V	et	f	\N
118937	kaasas	kaasas =kaasas  (ID  >kaasas !41_DK	et	f	\N
118939	joonistamise	joonistamise =joonistamise  (SgG  >joonistamine !12_S	et	f	\N
118940	joonistamise	"joonistamine %joonista  )MINE_vS  <joonistama ;27_V	et	f	\N
118949	näitlejaks	näitlejaks =näitleja  (SgTr  >näitleja !01_S	et	f	\N
118950	näitlejaks	"näitleja %näitle  )JA_vS  <näitlema ;30_V	et	f	\N
118958	mälu	mälu =mälu  (SgN  >mälu !17_S	et	f	\N
118959	mälu	mälu =mälu  (SgG  >mälu !17_S	et	f	\N
118960	mälu	mälu =mälu  (SgP  >mälu !17_S	et	f	\N
118961	mälu	mälu =mälu  (IndPrPs_  >mäluma !27_V	et	f	\N
118962	mälu	mälu =mälu  (ImpPrSg2  >mäluma !27_V	et	f	\N
118970	aljona	?aljona =aljo  (SgEs  >aljo !16_S	et	f	\N
118979	seesmiselt	seesmiselt =seesmise  (SgAbl  >seesmine !12?10_A	et	f	\N
118980	seesmiselt	seesmiselt =seesmiselt  (ID  >seesmiselt !41_D	et	f	\N
118981	seesmiselt	"seesmiselt %seesmise  )LT_mD  <seesmine ;10_A	et	f	\N
118982	seesmiselt	"seesmiselt %seesmise  )LT_mD  <seesmine ;12_A	et	f	\N
118985	töökas	töökas =tööka  (SgIn  >töökas !02_A	et	f	\N
118986	töökas	töökas =töökas  (SgN  >töökas !02_A	et	f	\N
118987	edu	edu =edu  (SgN  >edu !17_S	et	f	\N
118988	edu	edu =edu  (SgG  >edu !17_S	et	f	\N
118989	edu	edu =edu  (SgP  >edu !17_S	et	f	\N
118997	lager	?lager =lager  (SgN  >lager !02_S	et	f	\N
119004	rõõmsalt	rõõmsalt =rõõmsa  (SgAbl  >rõõmus !02_A	et	f	\N
119005	rõõmsalt	rõõmsalt =rõõmsalt  (ID  >rõõmsalt !41_D	et	f	\N
119006	rõõmsalt	"rõõmsalt %rõõmsa  )LT_mD  <rõõmus ;02_A	et	f	\N
119013	tõusmine	tõusmine =tõusmine  (SgN  >tõusmine !12?10_S	et	f	\N
119014	tõusmine	"tõusmine %tõus  )MINE_vS  <tõusma ;32_V	et	f	\N
119046	kõigidel	?kõigidel =kõigi  (PlAd  >kõigi !16_S	et	f	\N
119047	kõigidel	?kõigidel =kõigi  (PlAd  >kõig !22_S	et	f	\N
119051	kuritegijadel	### kuritegijadel	et	f	\N
119065	austatud	austatud =austa  (PtsPtIps  >austama !27_V	et	f	\N
119066	austatud	austatud =austatu  (PlN  >austatu !01_S	et	f	\N
119067	austatud	"austatu %austa  )TU1_vS  <austama ;27_V	et	f	\N
118794	lühikokkuvõtte	lühikokkuvõtte =võtte  (PlP  >lühi+kokku+võtt !22_S	et	f	\N
118807	foto	foto =foto  (SgN  >foto !16_S	et	f	\N
118808	foto	foto =foto  (SgG  >foto !16_S	et	f	\N
118809	trükitatud	?trükitatud =trükita  (PtsPtIps  >trükitama !27_V	et	f	\N
118810	trükitatud	?trükitatud =trükitatu  (PlN  >trükitatu !01_S	et	f	\N
118811	trükitatud	?trükitatud =trükitatu  (IndPrSg2  >trükitatuma !27_V	et	f	\N
118812	trükitatud	?trükitatud =trükitatud  (ID  >trükitatud !41_A	et	f	\N
118813	trükitatud	?trükitatud =tatu  (PlN  >trüki+tatu !16_S	et	f	\N
118829	belkal	?belkal =belka  (SgAd  >belka !16_S	et	f	\N
118830	belkal	?belkal =belkal  (SgN  >belkal !02_S	et	f	\N
118849	peatoimetaja	peatoimetaja =toimetaja  (SgN  >pea+toimetaja !01_S	et	f	\N
118850	peatoimetaja	peatoimetaja =toimetaja  (SgG  >pea+toimetaja !01_S	et	f	\N
118854	tuba	tuba =tuba  (SgN  >tuba !18_S	et	f	\N
118855	tuba	tuba =tuba  (SgP  >tuba !18_S	et	f	\N
118883	kodulehekülge	kodulehekülge =külge  (SgP  >kodu+lehe+külg !22_S	et	f	\N
118884	kodulehekülge	kodulehekülge =külge  (SgAdt  >kodu+lehe+külg !22_S	et	f	\N
118885	kodulehekülge	kodulehekülge =külge  (PlP  >kodu+lehe+külg !22_S	et	f	\N
118899	vastuste	vastuste =vastus  (PlG  >vastus !09_S	et	f	\N
118900	vastuste	vastuste =us  (PlG  >vast+uks !14_S	et	f	\N
118901	tänav	tänav =täna  (PtsPrPs  >tänama !27_V	et	f	\N
118902	tänav	tänav =tänav  (SgN  >tänav !02_A	et	f	\N
118903	tänav	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
118904	tänav	tänav =tänav  (SgN  >tänav !02_S	et	f	\N
118909	nimiaanamktee	?nimiaanamktee =nimiaanamktee  (SgN  >nimiaanamktee !26_S	et	f	\N
118910	nimiaanamktee	?nimiaanamktee =nimiaanamktee  (SgG  >nimiaanamktee !26_S	et	f	\N
118912	nimiaanamktee	?nimiaanamktee =aanamktee  (SgN  >nimi+aanamktee !26_S	et	f	\N
118913	nimiaanamktee	?nimiaanamktee =aanamktee  (SgG  >nimi+aanamktee !26_S	et	f	\N
118933	riiki	riiki =riiki  (SgP  >riik !22_S	et	f	\N
118934	riiki	riiki =riiki  (SgAdt  >riik !22_S	et	f	\N
118938	cdpleier	?cdpleier =cdpleier  (SgN  >cdpleier !02_S	et	f	\N
118983	suhelda	suhelda =suhel  (Inf  >suhtlema !30_V	et	f	\N
118984	suhelda	suhelda =suhel  (IndPrIps_  >suhtlema !30_V	et	f	\N
119019	tõusta	tõusta =tõus  (Inf  >tõusma !32_V	et	f	\N
119020	tõusta	tõusta =tõus  (IndPrIps_  >tõusma !32_V	et	f	\N
119024	tegevusi	tegevusi =tegevusi  (PlP  >tegevus !11_S	et	f	\N
119025	tegevusi	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
119026	tegevusi	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
119033	üheteistkümnendas	?üheteistkümnendas =üheteistkümnenda  (SgIn  >üheteistkümnenda !16_S	et	f	\N
119034	üheteistkümnendas	?üheteistkümnendas =üheteistkümnenda  (IndIpfSg3  >üheteistkümnendama !27_V	et	f	\N
119035	üheteistkümnendas	?üheteistkümnendas =kümnenda  (SgIn  >ühe+teist+kümnenda !01_S	et	f	\N
119036	üheteistkümnendas	?üheteistkümnendas =teistkümnenda  (SgIn  >ühe+teistkümnenda !16_S	et	f	\N
119037	suplemine	suplemine =suplemine  (SgN  >suplemine !12_S	et	f	\N
119038	suplemine	"suplemine %suple  )MINE_vS  <suplema ;30_V	et	f	\N
119039	toredam	toredam =toredam  (SgN  >toredam !02_A	et	f	\N
119040	toredam	"toredam %toreda  )M_cA  <tore ;02_A	et	f	\N
119055	vaata	vaata =vaata  (IndPrPs_  >vaatama !29_V	et	f	\N
119056	vaata	vaata =vaata  (ImpPrSg2  >vaatama !29_V	et	f	\N
119057	turvalisem	turvalisem =turvalisem  (SgN  >turvalisem !02_A	et	f	\N
119058	turvalisem	"turvalisem %turva  )LISEM_cA  <turb ;22_SA	et	f	\N
119059	turvalisem	"turvalisem %turva  )LISEM_cA  <turv ;22_S	et	f	\N
119060	turvalisem	"turvalisem %turvalise  )M_cA  <turvaline ;12_A	et	f	\N
119078	teate	teate =tea  (IndPrPl2  >teadma !34_V	et	f	\N
119079	teate	teate =teate  (SgG  >teade !06_S	et	f	\N
119103	ak	### ak	et	f	\N
119117	katki	katki =katki  (ID  >katki !41_D	et	f	\N
119118	katki	katki =katki  (SgG  >katk !22_S	et	f	\N
119119	katki	katki =katki  (SgP  >katk !22_S	et	f	\N
119120	katki	katki =katki  (SgAdt  >katk !22_S	et	f	\N
119129	distantsiooni	?distantsiooni =distantsioo  (SgTer  >distantsioo !26_S	et	f	\N
119130	distantsiooni	?distantsiooni =distantsiooni  (SgN  >distantsiooni !16_S	et	f	\N
119131	distantsiooni	?distantsiooni =distantsiooni  (SgG  >distantsiooni !16_S	et	f	\N
119132	distantsiooni	?distantsiooni =distantsiooni  (SgG  >distantsioon !22_S	et	f	\N
119133	distantsiooni	?distantsiooni =distantsiooni  (SgP  >distantsioon !22_S	et	f	\N
119134	distantsiooni	?distantsiooni =distantsiooni  (SgAdt  >distantsioon !22_S	et	f	\N
119135	distantsiooni	?distantsiooni =distantsiooni  (IndPrPs_  >distantsioonima !28_V	et	f	\N
119136	distantsiooni	?distantsiooni =distantsiooni  (ImpPrSg2  >distantsioonima !28_V	et	f	\N
119137	distantsiooni	?distantsiooni =ooni  (SgN  >distantsi+ooni !16_S	et	f	\N
119138	distantsiooni	?distantsiooni =ooni  (SgG  >distantsi+ooni !16_S	et	f	\N
119139	distantsiooni	?distantsiooni =ooni  (SgG  >distantsi+oon !22_S	et	f	\N
119140	distantsiooni	?distantsiooni =ooni  (SgP  >distantsi+oon !22_S	et	f	\N
119141	distantsiooni	?distantsiooni =ooni  (SgAdt  >distantsi+oon !22_S	et	f	\N
119156	veada	?veada =veada  (SgN  >veada !16_S	et	f	\N
119157	veada	?veada =veada  (SgG  >veada !16_S	et	f	\N
119158	veada	?veada =veada  (IndPrPs_  >veadama !29_V	et	f	\N
118822	seitsmekümneaastane	seitsmekümneaastane =aastane  (SgN  >seitsme+kümne+aastane !12~10_A	et	f	\N
118823	seitsmekümneaastane	"seitsme+kümne+aastane %aasta  )NE_aA  <seitsme+kümne+aasta ;01_S	et	f	\N
118824	zorina	?zorina =zori  (SgEs  >zori !17_S	et	f	\N
118825	zorina	?zorina =zorina  (SgG  >zorin !02_S	et	f	\N
118826	tappa	tappa =tapp  (Inf  >tapma !35_V	et	f	\N
118827	tappa	tappa =tappa  (SgP  >tapp !22_S	et	f	\N
118828	tappa	tappa =tappa  (SgAdt  >tapp !22_S	et	f	\N
118843	kerge	kerge =kerge  (SgN  >kerge !01_A	et	f	\N
118844	kerge	kerge =kerge  (SgN  >kerge !06_S	et	f	\N
118845	kerge	kerge =kerge  (SgG  >kerge !01_A	et	f	\N
118891	tuitvuda	?tuitvuda =tuitvu  (Inf  >tuitvuma !27_V	et	f	\N
118915	kontserditele	?kontserditele =kontserdi  (PlAll  >kontserdi !01_S	et	f	\N
118916	kontserditele	?kontserditele =kontserdi  (PlAll  >kontserd !02_S	et	f	\N
118917	kontserditele	?kontserditele =kontserdite  (PlAll  >kontserditt !22_S	et	f	\N
118918	kontserditele	?kontserditele =kontserditele  (IndPrPs_  >kontserditelema !36_V	et	f	\N
118919	kontserditele	?kontserditele =kontserditele  (ImpPrSg2  >kontserditelema !36_V	et	f	\N
118920	kontserditele	?kontserditele =serdite  (PlAll  >kont+serditt !22_S	et	f	\N
118923	täisealised	täisealised =ealise  (PlN  >täis+ealine !12?10_A	et	f	\N
118924	täisealised	"täis+ealine %ea  )LINE_aA  <täis+iga ;18_S	et	f	\N
118925	täisealised	täisealised =sealise  (PlN  >täi+sealine !12?10_A	et	f	\N
118926	täisealised	"täi+sealine %sea  )LINE_aA  <täi+siga ;18_SA	et	f	\N
118932	cd	### cd	et	f	\N
118945	dzhäss	?dzhäss =dzhäss  (SgN  >dzhäss !22_S	et	f	\N
118965	rolli	rolli =rolli  (SgG  >roll !22_S	et	f	\N
118966	rolli	rolli =rolli  (SgP  >roll !22_S	et	f	\N
118967	rolli	rolli =rolli  (SgAdt  >roll !22_S	et	f	\N
118990	paremusele	paremusele =paremuse  (SgAll  >paremus !11_S	et	f	\N
118991	paremusele	"paremus %parema  )US_aS  <parem ;02_A	et	f	\N
118992	paremusele	paremusele =use  (PlAll  >parem+usk !22_S	et	f	\N
118998	savist	savist =savi  (SgEl  >savi !17_S	et	f	\N
118999	savist	savist =savis  (SgP  >savine !10_A	et	f	\N
119000	savist	"savine %savi  )NE_aA  <savi ;17_S	et	f	\N
119009	hiline	hiline =hiline  (SgN  >hiline !10_A	et	f	\N
119011	hiline	hiline =hiline  (IndPrPs_  >hilinema !27_V	et	f	\N
119012	hiline	hiline =hiline  (ImpPrSg2  >hilinema !27_V	et	f	\N
119015	punkt	punkt =punkt  (ID  >punkt !41_D	et	f	\N
119016	punkt	punkt =punkt  (SgN  >punkt !22_S	et	f	\N
119041	kuritegevuse	kuritegevuse =tegevuse  (SgG  >kuri+tegevus !11_S	et	f	\N
119042	kuritegevuse	"kuri+tegevus %tegeva  )US_aS  <kuri+tegev ;02_A	et	f	\N
119061	aused	?aused =ause  (PlN  >ause !06_S	et	f	\N
119062	aused	?aused =ause  (IndPrSg2  >ausema !28_V	et	f	\N
119068	kuulajad	kuulajad =kuulaja  (PlN  >kuulaja !01_S	et	f	\N
119070	kuulajad	"kuulaja %kuula  )JA_vS  <kuulama ;29_V	et	f	\N
119071	kuulajad	kuulajad =aja  (PlN  >kuul+aeg !22_S	et	f	\N
119080	tel	### tel	et	f	\N
119081	vabaaega	vabaaega =aega  (SgP  >vaba+aeg !22_S	et	f	\N
119082	vabaaega	vabaaega =aega  (SgAdt  >vaba+aeg !22_S	et	f	\N
119088	kavandatavat	kavandatavat =kavanda  (KvtPrIps  >kavandama !27_V	et	f	\N
119089	kavandatavat	kavandatavat =kavandatava  (SgP  >kavandatav !02_A	et	f	\N
119090	kavandatavat	"kavandatav %kavanda  )TAV_vAS  <kavandama ;27_V	et	f	\N
119097	viidud	viidud =vii  (PtsPtIps  >viima !38_V	et	f	\N
119098	viidud	viidud =viidu  (PlN  >viidu !01_S	et	f	\N
119099	viidud	"viidu %vii  )TU1_vS  <viima ;38_V	et	f	\N
119100	viidud	viidud =viidud  (ID  >viidud !41_A	et	f	\N
119101	viidud	"viidud %vii  )TUD_vA  <viima ;38_V	et	f	\N
119125	c	### c	et	f	\N
119143	miklis	?miklis =mikli  (SgIn  >mikkel !02_S	et	f	\N
119144	miklis	?miklis =mikli  (IndIpfSg3  >miklima !28_V	et	f	\N
119145	miklis	?miklis =miklis  (SgN  >miklis !09_S	et	f	\N
119168	üheksa	üheksa =üheksa  (SgN  >üheksa !01_N	et	f	\N
119169	üheksa	üheksa =üheksa  (SgG  >üheksa !01_N	et	f	\N
119185	paha	paha =paha  (SgN  >paha !17_AS	et	f	\N
119186	paha	paha =paha  (SgG  >paha !17_AS	et	f	\N
119187	paha	paha =paha  (SgG  >pahk !22_S	et	f	\N
119188	paha	paha =paha  (SgP  >paha !17_AS	et	f	\N
119189	töödistsipliinit	?töödistsipliinit =töödistsipliini  (SgP  >töödistsipliini !16_S	et	f	\N
119190	töödistsipliinit	?töödistsipliinit =distsipliini  (SgP  >töö+distsipliini !16_S	et	f	\N
119202	kohutav	kohutav =kohu  (PtsPrIps  >kohuma !27_V	et	f	\N
119203	kohutav	kohutav =kohuta  (PtsPrPs  >kohutama !27_V	et	f	\N
119204	kohutav	kohutav =kohutav  (SgN  >kohutav !02_A	et	f	\N
119205	kohutav	"kohutav %kohu  )TAV_vAS  <kohuma ;27_V	et	f	\N
119206	kohutav	"kohutav %kohuta  )V_vA  <kohutama ;27_V	et	f	\N
119207	haiguse	haiguse =haiguse  (SgG  >haigus !11~09_S	et	f	\N
119208	haiguse	"haigus %haige  )US_aS  <haige ;01_AS	et	f	\N
119217	suitsetamist	suitsetamist =suitsetamis  (SgP  >suitsetamine !12_S	et	f	\N
119220	suitsetamist	"suitsetamine %suitseta  )MINE_vS  <suitsetama ;27_V	et	f	\N
119238	sobiv	sobiv =sobi  (PtsPrPs  >sobima !27_V	et	f	\N
119240	sobiv	sobiv =sobiv  (SgN  >sobiv !02_A	et	f	\N
119241	sobiv	"sobiv %sobi  )V_vA  <sobima ;27_V	et	f	\N
118859	asutus	asutus =asutus  (SgN  >asutus !11_S	et	f	\N
118860	asutus	"asutus %asuta  )US_vS  <asutama ;27_V	et	f	\N
118861	asutus	"asutus %asu  )TUS1_aS  <asuma ;27_V	et	f	\N
118862	asutus	"asutus %asu  )TUS2_aS  <asu ;17_S	et	f	\N
118865	konkurssil	?konkurssil =konkurssi  (SgAd  >konkurssi !01_S	et	f	\N
118879	osalemist	osalemist =osalemis  (SgP  >osalemine !12_S	et	f	\N
118880	osalemist	"osalemine %osale  )MINE_vS  <osalema ;27_V	et	f	\N
118881	teie	teie =teie  (PlG  >sina !00_P	et	f	\N
118882	teie	teie =teie  (PlN  >sina !00_P	et	f	\N
118886	soovime	soovime =soovi  (IndPrPl1  >soovima !28_V	et	f	\N
118887	soovime	soovime =ime  (SgN  >soov+ime !16_S	et	f	\N
118888	soovime	soovime =ime  (SgG  >soov+ime !16_S	et	f	\N
118906	e-mailil	?e-mailil =maili  (SgAd  >e-maili !16_S	et	f	\N
118907	e-mailil	?e-mailil =maili  (SgAd  >e-mail !22_S	et	f	\N
118921	piiramine	piiramine =piiramine  (SgN  >piiramine !12_S	et	f	\N
118922	piiramine	"piiramine %piira  )MINE_vS  <piirama ;29_V	et	f	\N
118946	näitleja	näitleja =näitleja  (SgN  >näitleja !01_S	et	f	\N
118947	näitleja	"näitleja %näitle  )JA_vS  <näitlema ;30_V	et	f	\N
118948	näitleja	näitleja =näitleja  (SgG  >näitleja !01_S	et	f	\N
118951	erineva	erineva =erineva  (SgG  >erinev !02_A	et	f	\N
118952	erineva	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
118953	iseloomu	iseloomu =loomu  (SgG  >ise+loom !22_S	et	f	\N
118954	iseloomu	iseloomu =loomu  (SgP  >ise+loom !22_S	et	f	\N
118955	iseloomu	iseloomu =loomu  (SgAdt  >ise+loom !22_S	et	f	\N
118975	teas	?teas =tea  (SgIn  >tea !26_S	et	f	\N
118976	teas	?teas =teas  (SgN  >teas !22_S	et	f	\N
119007	kasulikult	kasulikult =kasuliku  (SgAbl  >kasulik !25_A	et	f	\N
119008	kasulikult	kasulikult =kasulikult  (ID  >kasulikult !41_D	et	f	\N
119010	kasulikult	"kasulikult %kasuliku  )LT_mD  <kasulik ;25_A	et	f	\N
119021	praktiliselt	praktiliselt =praktilise  (SgAbl  >praktiline !12_A	et	f	\N
119022	praktiliselt	praktiliselt =praktiliselt  (ID  >praktiliselt !41_D	et	f	\N
119023	praktiliselt	"praktiliselt %praktilise  )LT_mD  <praktiline ;12_A	et	f	\N
119030	paksu	paksu =paksu  (SgG  >paks !22_AS	et	f	\N
119031	paksu	paksu =paksu  (SgP  >paks !22_AS	et	f	\N
119032	paksu	paksu =paksu  (SgAdt  >paks !22_AS	et	f	\N
119052	kooliharidusest	kooliharidusest =hariduse  (SgEl  >kooli+haridus !11_S	et	f	\N
119053	kooliharidusest	kooliharidusest =hariduses  (SgP  >kooli+haridusene !12_A	et	f	\N
119054	kooliharidusest	"kooli+haridusene %hariduse  )NE_aA  <kooli+haridus ;11_S	et	f	\N
119091	ollu	?ollu =ollu  (SgN  >ollu !16_S	et	f	\N
119092	ollu	?ollu =ollu  (SgG  >ollu !16_S	et	f	\N
119093	ollu	?ollu =ollu  (IndPrPs_  >olluma !27_V	et	f	\N
119095	ollu	?ollu =ollu  (ImpPrSg2  >olluma !27_V	et	f	\N
119102	lugupeetud	lugupeetud =pee  (PtsPtIps  >lugu+_pidama !28_V	et	f	\N
119104	lugupeetud	lugupeetud =peetu  (PlN  >lugu+peetu !01_SA	et	f	\N
119106	viru	viru =viru  (SgN  >viru !17_S	et	f	\N
119107	viru	viru =viru  (SgG  >viru !17_S	et	f	\N
119109	viru	viru =viru  (SgP  >viru !17_S	et	f	\N
119112	viru	viru =viru  (IndPrPs_  >viruma !27_V	et	f	\N
119113	viru	viru =viru  (ImpPrSg2  >viruma !27_V	et	f	\N
119121	77-88br	### 77-88br	et	f	\N
119126	hoidanud	?hoidanud =hoidanu  (PlN  >hoidanu !01_S	et	f	\N
119127	hoidanud	?hoidanud =hoidanu  (IndPrSg2  >hoidanuma !27_V	et	f	\N
119128	hoidanud	?hoidanud =hoidanud  (ID  >hoidanud !41_A	et	f	\N
119152	taskuraha	taskuraha =raha  (SgN  >tasku+raha !17_S	et	f	\N
119153	taskuraha	taskuraha =raha  (SgG  >tasku+raha !17_S	et	f	\N
119154	taskuraha	taskuraha =raha  (SgG  >tasku+rahk !22_S	et	f	\N
119155	taskuraha	taskuraha =raha  (SgP  >tasku+raha !17_S	et	f	\N
119164	kulutama	kulutama =kulu  (SupIps  >kuluma !27_V	et	f	\N
119165	kulutama	kulutama =kuluta  (Sup  >kulutama !27_V	et	f	\N
119166	iseseisvalt	iseseisvalt =seisva  (SgAbl  >ise+seisev !02_A	et	f	\N
119167	iseseisvalt	"ise+seisvalt %seisva  )LT_mD  <ise+seisev ;02_A	et	f	\N
119176	füüsiliselt	füüsiliselt =füüsilise  (SgAbl  >füüsiline !12_A	et	f	\N
119177	füüsiliselt	füüsiliselt =füüsiliselt  (ID  >füüsiliselt !41_D	et	f	\N
119178	füüsiliselt	"füüsiliselt %füüsilise  )LT_mD  <füüsiline ;12_A	et	f	\N
119182	huvitamatu	huvitamatu =huvitamatu  (SgN  >huvitamatu !01_A	et	f	\N
119183	huvitamatu	"huvitamatu %huvita  )MATU_vA  <huvitama ;27_V	et	f	\N
119184	huvitamatu	huvitamatu =huvitamatu  (SgG  >huvitamatu !01_A	et	f	\N
119229	cv	### cv	et	f	\N
119242	riietus	riietus =riietu  (IndIpfSg3  >riietuma !27_V	et	f	\N
119243	riietus	riietus =riietus  (SgN  >riietus !11_S	et	f	\N
119244	riietus	"riietus %riieta  )US_vS  <riietama ;27_V	et	f	\N
119247	tarbija	tarbija =tarbija  (SgN  >tarbija !01_S	et	f	\N
119248	tarbija	"tarbija %tarbi  )JA_vS  <tarbima ;27_V	et	f	\N
119249	tarbija	tarbija =tarbija  (SgG  >tarbija !01_S	et	f	\N
119278	kõrgkoolis	kõrgkoolis =kooli  (SgIn  >kõrg+kool !22_S	et	f	\N
119279	kõrgkoolis	kõrgkoolis =kooli  (PlIn  >kõrg+kool !22_S	et	f	\N
119285	sattumise	sattumise =sattumise  (SgG  >sattumine !12_S	et	f	\N
119287	sattumise	"sattumine %sattu  )MINE_vS  <sattuma ;27_V	et	f	\N
119289	sattumise	"sattumine %sattu  )MINE_vS  <sattuma ;28_V	et	f	\N
118898	vüitjatele	?vüitjatele =vüitjatele  (ImpPrSg2  >vüitjatelema !36_V	et	f	\N
118927	kõla	kõla =kõla  (SgN  >kõla !17_S	et	f	\N
118928	kõla	kõla =kõla  (SgG  >kõla !17_S	et	f	\N
118929	kõla	kõla =kõla  (SgP  >kõla !17_S	et	f	\N
118930	kõla	kõla =kõla  (IndPrPs_  >kõlama !27_V	et	f	\N
118931	kõla	kõla =kõla  (ImpPrSg2  >kõlama !27_V	et	f	\N
118941	klassikaline	klassikaline =klassikaline  (SgN  >klassikaline !12_A	et	f	\N
118942	klassikaline	"klassikaline %klassika  )LINE_aA  <klassika ;01_S	et	f	\N
118943	klassikaline	klassikaline =kaline  (SgN  >klassi+kaline !10_A	et	f	\N
118944	klassikaline	"klassi+kaline %kali  )NE_aA  <klassi+kali ;17_S	et	f	\N
118956	näitlejatel	näitlejatel =näitleja  (PlAd  >näitleja !01_S	et	f	\N
118957	näitlejatel	"näitleja %näitle  )JA_vS  <näitlema ;30_V	et	f	\N
118963	pähe	pähe =pä  (SgAdt  >pea !26_S	et	f	\N
118964	pähe	pähe =pähe  (ID  >pähe !41_DK	et	f	\N
118968	lemmiknäitleja	lemmiknäitleja =näitleja  (SgN  >lemmik+näitleja !01_S	et	f	\N
118969	lemmiknäitleja	lemmiknäitleja =näitleja  (SgG  >lemmik+näitleja !01_S	et	f	\N
118971	babonina	?babonina =baboni  (SgEs  >babon !02_S	et	f	\N
118972	babonina	?babonina =babonina  (SgG  >babonin !19_S	et	f	\N
118973	babonina	?babonina =babonina  (SgP  >babonin !19_S	et	f	\N
118974	babonina	?babonina =babonina  (SgAdt  >babonin !19_S	et	f	\N
118977	elurõõmus	elurõõmus =rõõmu  (SgIn  >elu+rõõm !22_S	et	f	\N
118978	elurõõmus	elurõõmus =rõõmus  (SgN  >elu+rõõmus !02_A	et	f	\N
118993	leedusse	leedusse =leedu  (SgIll  >leedu !16_S	et	f	\N
118994	leedusse	"leedu %lee  )TU1_vS  <leema ;37_V	et	f	\N
118995	leedusse	leedusse =leedus  (SgAdt  >leedus !11_S	et	f	\N
118996	leedusse	"leedus %lee  )TUS1_aS  <leema ;37_V	et	f	\N
119001	veeta	veeta =vee  (IndPrIps_  >vedama !28_V	et	f	\N
119002	veeta	veeta =vee  (SgAb  >vesi !15_S	et	f	\N
119003	veeta	veeta =veet  (Inf  >veetma !34_V	et	f	\N
119017	öösel	öösel =ööse  (PlAd  >öös !22_S	et	f	\N
119018	öösel	öösel =öösel  (ID  >öösel !41_D	et	f	\N
119027	loetelu	loetelu =loetelu  (SgN  >loetelu !17_S	et	f	\N
119028	loetelu	loetelu =loetelu  (SgG  >loetelu !17_S	et	f	\N
119029	loetelu	loetelu =loetelu  (SgP  >loetelu !17_S	et	f	\N
119043	signalisatsiooni	signalisatsiooni =signalisatsiooni  (SgG  >signalisatsioon !22_S	et	f	\N
119044	signalisatsiooni	signalisatsiooni =signalisatsiooni  (SgP  >signalisatsioon !22_S	et	f	\N
119045	signalisatsiooni	signalisatsiooni =signalisatsiooni  (SgAdt  >signalisatsioon !22_S	et	f	\N
119048	kuritegevusele	kuritegevusele =use  (PlAll  >kuri+tegev+usk !22_S	et	f	\N
119049	kuritegevusele	kuritegevusele =tegevuse  (SgAll  >kuri+tegevus !11_S	et	f	\N
119050	kuritegevusele	"kuri+tegevus %tegeva  )US_aS  <kuri+tegev ;02_A	et	f	\N
119063	politseinikud	politseinikud =politseiniku  (PlN  >politseinik !25_S	et	f	\N
119064	politseinikud	politseinikud =politseiniku  (PlN  >politseinik !02_S	et	f	\N
119086	xxxx	### xxxx	et	f	\N
119087	tegevused	tegevused =tegevuse  (PlN  >tegevus !11_S	et	f	\N
119094	tegevused	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
119096	tegevused	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
119114	tänavas	tänavas =tänava  (SgIn  >tänav !02_A	et	f	\N
119115	tänavas	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
119116	tänavas	tänavas =tänava  (SgIn  >tänav !02_S	et	f	\N
119222	haigused	haigused =haiguse  (PlN  >haigus !11~09_S	et	f	\N
119223	haigused	"haigus %haige  )US_aS  <haige ;01_AS	et	f	\N
119233	lühikesed	lühikesed =lühikese  (PlN  >lühike !12_A	et	f	\N
119234	lühikesed	"lühike %lühi  )KE_dS  <lüht ;22_S	et	f	\N
119235	lühikesed	lühikesed =lühikese  (PlN  >lühikene !12_S	et	f	\N
119236	lühikesed	"lühikene %lühi  )KENE_dS  <lüht ;22_S	et	f	\N
119237	enast	?enast =enas  (SgP  >enas !09_S	et	f	\N
119239	enast	?enast =enas  (SgP  >enane !10_A	et	f	\N
119254	tarbijal	tarbijal =tarbija  (SgAd  >tarbija !01_S	et	f	\N
119255	tarbijal	"tarbija %tarbi  )JA_vS  <tarbima ;27_V	et	f	\N
119257	teil	teil =te  (PlAd  >sa !00_P	et	f	\N
119258	teil	teil =te  (PlAd  >tee !26_S	et	f	\N
119266	nõu	nõu =nõu  (SgP  >nõu !26_S	et	f	\N
119267	nõu	nõu =nõu  (SgN  >nõu !26_S	et	f	\N
119268	nõu	nõu =nõu  (SgG  >nõu !26_S	et	f	\N
119269	viska	viska =viska  (IndPrPs_  >viskama !29_V	et	f	\N
119270	viska	viska =viska  (ImpPrSg2  >viskama !29_V	et	f	\N
119271	suuremad	suuremad =suurema  (PlN  >suurem !02_A	et	f	\N
119272	suuremad	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
119273	suuremad	suuremad =ema  (PlN  >suur+ema !17_S	et	f	\N
119277	õpida	?õpida =õpi  (Inf  >õpima !27_V	et	f	\N
119282	kuriteo	kuriteo =teo  (SgG  >kuri+tegu !18_S	et	f	\N
119283	kuriteo	kuriteo =teo  (SgG  >kuri+tigu !18_S	et	f	\N
119310	normal	?normal =norma  (SgAd  >norma !16_S	et	f	\N
119311	normal	?normal =normal  (SgN  >normal !02_S	et	f	\N
119327	ebatuntud	ebatuntud =tuntu  (PlN  >eba+tuntu !01_S	et	f	\N
119328	ebatuntud	ebatuntud =tuntud  (ID  >eba+tuntud !41_A	et	f	\N
119329	silmas	silmas =silma  (SgIn  >silm !22_S	et	f	\N
119330	silmas	silmas =silma  (IndIpfSg3  >silmama !29_V	et	f	\N
119357	henricus	?henricus =henricu  (SgIn  >henricu !01_S	et	f	\N
119069	austatud	austatud =austatud  (ID  >austatud !41_A	et	f	\N
119072	austatud	"austatud %austa  )TUD_vA  <austama ;27_V	et	f	\N
119073	kogunenud	kogunenud =kogune  (PtsPtPs  >kogunema !27_V	et	f	\N
119074	kogunenud	kogunenud =kogunenu  (PlN  >kogunenu !01_S	et	f	\N
119075	kogunenud	"kogunenu %kogune  )NU_vS  <kogunema ;27_V	et	f	\N
119076	kogunenud	kogunenud =kogunenud  (ID  >kogunenud !41_A	et	f	\N
119077	kogunenud	"kogunenud %kogune  )NUD_vA  <kogunema ;27_V	et	f	\N
119083	vastutavaks	vastutavaks =vastutava  (SgTr  >vastutav !02_A	et	f	\N
119084	vastutavaks	"vastutav %vastuta  )V_vA  <vastutama ;27_V	et	f	\N
119085	vastutavaks	vastutavaks =tava  (SgTr  >vastu+tava !17_S	et	f	\N
119105	kauplusest	kauplusest =kaupluse  (SgEl  >kauplus !11~09_S	et	f	\N
119108	kauplusest	kauplusest =kaupluses  (SgP  >kauplusene !12_A	et	f	\N
119110	kauplusest	"kauplusene %kaupluse  )NE_aA  <kauplus ;09_S	et	f	\N
119111	kauplusest	"kauplusene %kaupluse  )NE_aA  <kauplus ;11_S	et	f	\N
119122	taamsaare	?taamsaare =taamsaare  (SgN  >taamsaare !16_S	et	f	\N
119123	taamsaare	?taamsaare =taamsaare  (SgG  >taamsaare !16_S	et	f	\N
119124	taamsaare	?taamsaare =taamsaare  (PlP  >taamsaar !22_S	et	f	\N
119142	mobelega	### mobelega	et	f	\N
119146	jalgraturi	?jalgraturi =jalgraturi  (SgG  >jalgratur !19_S	et	f	\N
119147	jalgraturi	?jalgraturi =jalgraturi  (SgP  >jalgratur !19_S	et	f	\N
119148	jalgraturi	?jalgraturi =jalgraturi  (SgAdt  >jalgratur !19_S	et	f	\N
119149	jalgraturi	?jalgraturi =raturi  (SgN  >jalg+raturi !01_S	et	f	\N
119150	jalgraturi	?jalgraturi =raturi  (SgG  >jalg+raturi !01_S	et	f	\N
119151	jalgraturi	?jalgraturi =raturi  (SgG  >jalg+ratur !02_S	et	f	\N
119160	teenevad	?teenevad =teene  (IndPrPl3  >teenema !27_V	et	f	\N
119161	teenevad	?teenevad =teeneva  (PlN  >teeneva !01_S	et	f	\N
119162	teenevad	?teenevad =teeneva  (PlN  >teenev !02_A	et	f	\N
119163	teenevad	?teenevad =neva  (PlN  >tee+neva !17_S	et	f	\N
119173	moraalselt	moraalselt =moraalse  (SgAbl  >moraalne !02_A	et	f	\N
119174	moraalselt	moraalselt =moraalselt  (ID  >moraalselt !41_D	et	f	\N
119175	moraalselt	"moraalselt %moraalse  )LT_mD  <moraalne ;02_A	et	f	\N
119191	harjumusi	harjumusi =harjumusi  (PlP  >harjumus !11_S	et	f	\N
119192	harjumusi	"harjumus %harju  )MUS_vS  <harjuma ;27_V	et	f	\N
119193	harjumusi	harjumusi =musi  (SgN  >harju+musi !17_S	et	f	\N
119194	harjumusi	harjumusi =musi  (SgG  >harju+musi !17_S	et	f	\N
119195	harjumusi	harjumusi =musi  (SgP  >harju+musi !17_S	et	f	\N
119196	eluiga	eluiga =iga  (SgN  >elu+iga !18_S	et	f	\N
119197	eluiga	eluiga =iga  (SgP  >elu+iga !18_S	et	f	\N
119200	pärilikkust	pärilikkust =pärilikkus  (SgP  >pärilikkus !11~09_S	et	f	\N
119201	pärilikkust	"pärilikkus %pärilikku  )US_aS  <pärilik ;25_A	et	f	\N
119209	toitumine	toitumine =toitumine  (SgN  >toitumine !12_S	et	f	\N
119210	toitumine	"toitumine %toitu  )MINE_vS  <toituma ;27_V	et	f	\N
119224	peate	peate =pea  (IndPrPl2  >pida !40_V	et	f	\N
119225	peate	peate =pea  (IndPrPl2  >pidama !28_V	et	f	\N
119245	plusid	?plusid =plusi  (PlN  >plusi !17_S	et	f	\N
119246	plusid	?plusid =plusi  (IndPrSg2  >plusima !27_V	et	f	\N
119250	põhiõigused	põhiõigused =õiguse  (PlN  >põhi+õigus !11~09_S	et	f	\N
119251	põhiõigused	"põhi+õigus %õige  )US_aS  <põhi+õige ;01_A	et	f	\N
119294	stylefont-family	### stylefont-family	et	f	\N
119333	vooli	vooli =vooli  (SgG  >vool !22_S	et	f	\N
119334	vooli	vooli =vooli  (SgP  >vool !22_S	et	f	\N
119335	vooli	vooli =vooli  (SgAdt  >vool !22_S	et	f	\N
119336	vooli	vooli =vooli  (IndPrPs_  >voolima !28_V	et	f	\N
119337	vooli	vooli =vooli  (ImpPrSg2  >voolima !28_V	et	f	\N
119340	tüttar	?tüttar =tüttar  (SgN  >tüttar !02_S	et	f	\N
119346	nädalavahetusel	nädalavahetusel =use  (PlAd  >nädala+vahet+usk !22_S	et	f	\N
119347	nädalavahetusel	nädalavahetusel =vahetuse  (SgAd  >nädala+vahetus !11_S	et	f	\N
119348	nädalavahetusel	"nädala+vahetus %vahe  )TUS2_aS  <nädala+vahe ;16_S	et	f	\N
119351	keskajast	keskajast =aja  (SgEl  >kesk+aeg !22_S	et	f	\N
119352	keskajast	keskajast =ajas  (SgP  >kesk+ajane !10_A	et	f	\N
119353	keskajast	"kesk+ajane %aja  )NE_aA  <kesk+aeg ;22_S	et	f	\N
119384	puud	puud =puu  (PlN  >puu !26_S	et	f	\N
119385	puud	puud =puu  (SgP  >puu !26_S	et	f	\N
119386	puud	puud =puud  (SgN  >puud !22_S	et	f	\N
119398	thor	### thor	et	f	\N
119399	1740a	### 1740a	et	f	\N
119430	dialoogi	dialoogi =dialoogi  (SgG  >dialoog !22_S	et	f	\N
119431	dialoogi	dialoogi =dialoogi  (SgP  >dialoog !22_S	et	f	\N
119432	dialoogi	dialoogi =dialoogi  (SgAdt  >dialoog !22_S	et	f	\N
119463	aluseks	aluseks =aluse  (SgTr  >alus !09_S	et	f	\N
119464	aluseks	aluseks =aluse  (SgTr  >alune !10_AS	et	f	\N
119465	aluseks	"alune %alu  )NE_aA  <alg ;22_S	et	f	\N
119466	aluseks	aluseks =seks  (SgN  >alu+seks !22_S	et	f	\N
119471	kauplesid	kauplesid =kauple  (IndIpfSg2  >kauplema !30_V	et	f	\N
119472	kauplesid	kauplesid =kauple  (IndIpfPl3  >kauplema !30_V	et	f	\N
119473	eestlastega	eestlastega =eestlas  (PlKom  >eestlane !12?10_S	et	f	\N
119474	eestlastega	eestlastega =las  (PlKom  >eest+laps !14_S	et	f	\N
119529	koduloomade	koduloomade =made  (SgN  >kodu+loo+made !04_S	et	f	\N
119159	veada	?veada =veada  (ImpPrSg2  >veadama !29_V	et	f	\N
119170	väsivad	väsivad =väsi  (IndPrPl3  >väsima !27_V	et	f	\N
119171	väsivad	väsivad =väsiva  (PlN  >väsiv !02_A	et	f	\N
119172	väsivad	"väsiv %väsi  )V_vA  <väsima ;27_V	et	f	\N
119179	depressiooni	depressiooni =depressiooni  (SgG  >depressioon !22_S	et	f	\N
119180	depressiooni	depressiooni =depressiooni  (SgP  >depressioon !22_S	et	f	\N
119181	depressiooni	depressiooni =depressiooni  (SgAdt  >depressioon !22_S	et	f	\N
119198	eluiga	eluiga =iga  (SgN  >elu+iga !18_S	et	f	\N
119199	eluiga	eluiga =iga  (SgP  >elu+iga !18_S	et	f	\N
119211	narkotikumist	?narkotikumist =narkotikumi  (SgEl  >narkotikum !19_S	et	f	\N
119212	narkotikumist	?narkotikumist =narkotikumis  (SgP  >narkotikumis !09_S	et	f	\N
119213	narkotikumist	?narkotikumist =narkotikumis  (SgP  >narkotikumine !12_S	et	f	\N
119214	narkotikumist	?narkotikumist =narkotikumist  (SgN  >narkotikumist !22_S	et	f	\N
119215	narkotikumist	?narkotikumist =tikumi  (SgEl  >narko+tikumi !01_S	et	f	\N
119216	narkotikumist	?narkotikumist =tikumi  (SgEl  >narko+tikum !02_S	et	f	\N
119218	narkotikumist	?narkotikumist =tikumis  (SgP  >narko+tikumis !11_S	et	f	\N
119219	narkotikumist	?narkotikumist =tikumis  (SgP  >narko+tikumine !12_S	et	f	\N
119221	narkotikumist	?narkotikumist =tikumist  (SgN  >narko+tikumist !22_S	et	f	\N
119226	räägi	räägi =räägi  (SgG  >rääk !22_S	et	f	\N
119227	räägi	räägi =räägi  (IndPrPs_  >rääkima !28_V	et	f	\N
119228	räägi	räägi =räägi  (ImpPrSg2  >rääkima !28_V	et	f	\N
119230	avaldus	avaldus =avaldu  (IndIpfSg3  >avalduma !27_V	et	f	\N
119231	avaldus	avaldus =avaldus  (SgN  >avaldus !11_S	et	f	\N
119232	avaldus	"avaldus %avalda  )US_vS  <avaldama ;27_V	et	f	\N
119256	vaetab	?vaetab =vaeta  (IndPrSg3  >vaetama !27_V	et	f	\N
119260	vaetada	?vaetada =vaeta  (Inf  >vaetama !27_V	et	f	\N
119262	vaetada	?vaetada =tada  (SgN  >vae+tada !17_S	et	f	\N
119263	vaetada	?vaetada =tada  (SgG  >vae+tada !17_S	et	f	\N
119264	vaetada	?vaetada =tada  (SgP  >vae+tada !17_S	et	f	\N
119274	mõtlevad	mõtlevad =mõtle  (IndPrPl3  >mõtlema !30_V	et	f	\N
119275	mõtlevad	mõtlevad =mõtleva  (PlN  >mõtlev !02_A	et	f	\N
119276	mõtlevad	"mõtlev %mõtle  )V_vA  <mõtlema ;30_V	et	f	\N
119284	riski	riski =riski  (SgG  >risk !22_S	et	f	\N
119286	riski	riski =riski  (SgP  >risk !22_S	et	f	\N
119288	riski	riski =riski  (SgAdt  >risk !22_S	et	f	\N
119290	riski	riski =riski  (IndPrPs_  >riskima !28_V	et	f	\N
119291	riski	riski =riski  (ImpPrSg2  >riskima !28_V	et	f	\N
119298	roman	?roman =roma  (IndPrSg1  >romama !27_V	et	f	\N
119300	roman	?roman =roman  (SgN  >roman !02_S	et	f	\N
119305	normal	?normal =norma  (SgAd  >norma !16_S	et	f	\N
119306	normal	?normal =normal  (SgN  >normal !02_S	et	f	\N
119313	line-height	?line-height =height  (SgN  >line-height !22_S	et	f	\N
119319	font-stretch	?font-stretch =stretch  (SgN  >font-stretch !22_S	et	f	\N
119322	tähelepanelikuks	tähelepanelikuks =uks  (SgN  >tähe+lepa+nelik+uks !14_S	et	f	\N
119323	tähelepanelikuks	tähelepanelikuks =neliku  (SgTr  >tähe+lepa+nelik !02_S	et	f	\N
119324	tähelepanelikuks	tähelepanelikuks =paneliku  (SgTr  >tähele+panelik !25_A	et	f	\N
119331	töötamisel	töötamisel =töötamise  (SgAd  >töötamine !12_S	et	f	\N
119332	töötamisel	"töötamine %tööta  )MINE_vS  <töötama ;27_V	et	f	\N
119354	teos	teos =teo  (SgIn  >tegu !18_S	et	f	\N
119355	teos	teos =teo  (SgIn  >tigu !18_S	et	f	\N
119356	teos	teos =teos  (SgN  >teos !09_S	et	f	\N
119359	lettis	?lettis =letti  (IndIpfSg3  >lettima !28_V	et	f	\N
119360	lettis	?lettis =lettis  (ID  >lettis !41_DA	et	f	\N
119361	missionääriks	?missionääriks =missionääri  (SgTr  >missionääri !16_S	et	f	\N
119362	missionääriks	?missionääriks =missionääri  (SgTr  >missionäär !22_S	et	f	\N
119363	missionääriks	?missionääriks =missionääri  (KndPrPs  >missionäärima !28_V	et	f	\N
119364	missionääriks	?missionääriks =onääri  (SgTr  >missi+onääri !16_S	et	f	\N
119365	missionääriks	?missionääriks =onääri  (SgTr  >missi+onäär !22_S	et	f	\N
119366	missionääriks	?missionääriks =sionääri  (SgTr  >mis+sionääri !16_S	et	f	\N
119368	missionääriks	?missionääriks =sionääri  (SgTr  >mis+sionäär !22_S	et	f	\N
119372	ladina	ladina =ladina  (ID  >ladina !41_G	et	f	\N
119373	ladina	ladina =ladina  (SgG  >ladin !02_S	et	f	\N
119395	taara	taara =taara  (ID  >taara !41_G	et	f	\N
119396	taara	taara =taara  (SgN  >taara !16_S	et	f	\N
119397	taara	taara =taara  (SgG  >taara !16_S	et	f	\N
119410	lahingute	lahingute =lahingu  (PlG  >lahing !02_S	et	f	\N
119411	lahingute	lahingute =ute  (SgG  >lahing+utt !22_S	et	f	\N
119418	tatud	?tatud =tatu  (PlN  >tatu !16_S	et	f	\N
119419	tatud	?tatud =tatu  (IndPrSg2  >tatuma !27_V	et	f	\N
119436	niguliste	?niguliste =nigulis  (PlG  >nigulis !11_S	et	f	\N
119437	niguliste	?niguliste =nigulis  (PlG  >niguline !12_A	et	f	\N
119438	niguliste	?niguliste =niguliste  (PlP  >nigulist !22_S	et	f	\N
119443	hans	?hans =hans  (SgN  >hans !22_S	et	f	\N
119468	vikingid	?vikingid =vikingi  (PlN  >viking !02_S	et	f	\N
119469	vikingid	?vikingid =vikingi  (PlN  >vikink !22_S	et	f	\N
119252	põhiõigused	põhiõigused =õiguse  (PlN  >põhi+õigus !11~09_S	et	f	\N
119253	põhiõigused	"põhi+õigus %õige  )US_aS  <põhi+õige ;01_A	et	f	\N
119259	saate	saate =saa  (IndPrPl2  >saama !37_V	et	f	\N
119261	saate	saate =saate  (SgG  >saade !06_S	et	f	\N
119265	kaubadega	### kaubadega	et	f	\N
119280	õppimisest	õppimisest =õppimise  (SgEl  >õppimine !12_S	et	f	\N
119281	õppimisest	"õppimine %õppi  )MINE_vS  <õppima ;28_V	et	f	\N
119295	times	?times =time  (SgIn  >time !16_S	et	f	\N
119296	times	?times =time  (IndIpfSg3  >timema !27_V	et	f	\N
119297	times	?times =times  (SgN  >times !09_S	et	f	\N
119301	font-style	?font-style =style  (SgN  >font-style !16_S	et	f	\N
119302	font-style	?font-style =style  (SgG  >font-style !16_S	et	f	\N
119303	font-style	?font-style =style  (IndPrPs_  >font-stylema !27_V	et	f	\N
119304	font-style	?font-style =style  (ImpPrSg2  >font-stylema !27_V	et	f	\N
119307	font-weight	?font-weight =weight  (SgN  >font-weight !22_S	et	f	\N
119308	font-size	?font-size =size  (SgN  >font-size !16_S	et	f	\N
119309	font-size	?font-size =size  (SgG  >font-size !16_S	et	f	\N
119312	7pt	### 7pt	et	f	\N
119314	font-size-adjust	?font-size-adjust =adju  (SgEl  >font-size-adju !16_S	et	f	\N
119315	font-size-adjust	?font-size-adjust =adjus  (SgP  >font-size-adjus !11~09_S	et	f	\N
119325	span3span	?spanspan =spanspa  (IndPrSg1  >spanspama !29_V	et	f	\N
119326	span3span	?spanspan =spanspan  (SgN  >spanspan !02_S	et	f	\N
119341	pussiga	pussiga =pussi  (SgKom  >puss !22_S	et	f	\N
119342	pussiga	pussiga =iga  (SgN  >puss+iga !18_S	et	f	\N
119343	pussiga	pussiga =iga  (SgP  >puss+iga !18_S	et	f	\N
119349	hoijan	?hoijan =hoija  (IndPrSg1  >hoijama !29_V	et	f	\N
119350	hoijan	?hoijan =hoijan  (SgN  >hoijan !02_S	et	f	\N
119374	teost	teost =teo  (SgEl  >tegu !18_S	et	f	\N
119375	teost	teost =teo  (SgEl  >tigu !18_S	et	f	\N
119376	teost	teost =teos  (SgP  >teos !09_S	et	f	\N
119379	toodud	toodud =too  (PtsPtIps  >tooma !38_V	et	f	\N
119380	toodud	toodud =toodu  (PlN  >toodu !01_S	et	f	\N
119381	toodud	"toodu %too  )TU1_vS  <tooma ;38_V	et	f	\N
119382	toodud	toodud =toodud  (ID  >toodud !41_A	et	f	\N
119383	toodud	"toodud %too  )TUD_vA  <tooma ;38_V	et	f	\N
119389	tharapita	?tharapita =tharapi  (SgAb  >tharapi !01_S	et	f	\N
119390	tharapita	?tharapita =tharapi  (SgAb  >tharap !02_S	et	f	\N
119391	tharapita	?tharapita =tharapi  (SgAb  >tharapp !22_S	et	f	\N
119392	tharapita	?tharapita =tharapi  (IndPrIps_  >tharappima !28_V	et	f	\N
119393	tharapita	?tharapita =tharapita  (IndPrPs_  >tharapitama !27_V	et	f	\N
119394	tharapita	?tharapita =tharapita  (ImpPrSg2  >tharapitama !27_V	et	f	\N
119404	jungi	jungi =jungi  (SgP  >jung !22_S	et	f	\N
119405	jungi	jungi =jungi  (SgAdt  >jung !22_S	et	f	\N
119406	jungi	jungi =jungi  (PlP  >jung !22_S	et	f	\N
119412	kirikureformatsiooni	kirikureformatsiooni =formatsiooni  (SgG  >kiri+kure+formatsioon !22_S	et	f	\N
119413	kirikureformatsiooni	kirikureformatsiooni =formatsiooni  (SgP  >kiri+kure+formatsioon !22_S	et	f	\N
119414	kirikureformatsiooni	kirikureformatsiooni =formatsiooni  (SgAdt  >kiri+kure+formatsioon !22_S	et	f	\N
119415	kirikureformatsiooni	kirikureformatsiooni =reformatsiooni  (SgG  >kiriku+reformatsioon !22_S	et	f	\N
119416	kirikureformatsiooni	kirikureformatsiooni =reformatsiooni  (SgP  >kiriku+reformatsioon !22_S	et	f	\N
119417	kirikureformatsiooni	kirikureformatsiooni =reformatsiooni  (SgAdt  >kiriku+reformatsioon !22_S	et	f	\N
119427	1525a	### 1525a	et	f	\N
119455	1575a	### 1575a	et	f	\N
119467	pkr	### pkr	et	f	\N
119481	hõbega	### hõbega	et	f	\N
119485	sõjalisi	sõjalisi =sõjalisi  (PlP  >sõjaline !12_A	et	f	\N
119486	sõjalisi	"sõjaline %sõja  )LINE_aA  <sõda ;18_S	et	f	\N
119487	kontlikte	?kontlikte =kontlikte  (PlP  >kontlikt !22_S	et	f	\N
119500	jaroslav	?jaroslav =jaroslav  (SgN  >jaroslav !02_A	et	f	\N
119512	irboska	?irboska =irboska  (SgN  >irboska !01_S	et	f	\N
119513	irboska	?irboska =irboska  (SgG  >irboska !01_S	et	f	\N
119531	heina	heina =heina  (SgG  >hein !23?22_S	et	f	\N
119532	heina	heina =heina  (SgP  >hein !23?22_S	et	f	\N
119533	heina	heina =heina  (SgAdt  >hein !23?22_S	et	f	\N
119534	oskasid	oskasid =oska  (IndIpfSg2  >oskama !29_V	et	f	\N
119535	oskasid	oskasid =oska  (IndIpfPl3  >oskama !29_V	et	f	\N
119539	metalli	metalli =metalli  (SgG  >metall !22_S	et	f	\N
119540	metalli	metalli =metalli  (SgP  >metall !22_S	et	f	\N
119542	metalli	metalli =metalli  (SgAdt  >metall !22_S	et	f	\N
119547	kirves	kirves =kirve  (SgIn  >kirves !07_S	et	f	\N
119548	kirves	kirves =kirves  (SgN  >kirves !07_S	et	f	\N
119552	rikkamad	?rikkamad =rikkama  (PlN  >rikkam !02_A	et	f	\N
119556	tulekutrauaaja	?tulekutrauaaja =tulekutrauaaja  (SgN  >tulekutrauaaja !16_S	et	f	\N
119557	tulekutrauaaja	?tulekutrauaaja =tulekutrauaaja  (SgG  >tulekutrauaajas !02_A	et	f	\N
119558	tulekutrauaaja	?tulekutrauaaja =tulekutrauaaja  (SgG  >tulekutrauaaja !16_S	et	f	\N
119559	tulekutrauaaja	?tulekutrauaaja =trauaaja  (SgN  >tuleku+trauaaja !01_S	et	f	\N
119560	tulekutrauaaja	?tulekutrauaaja =trauaaja  (SgG  >tuleku+trauaaja !01_S	et	f	\N
119561	tulekutrauaaja	?tulekutrauaaja =kutrauaaja  (SgN  >tule+kutrauaaja !16_S	et	f	\N
119292	span2span	?spanspan =spanspa  (IndPrSg1  >spanspama !29_V	et	f	\N
119293	span2span	?spanspan =spanspan  (SgN  >spanspan !02_S	et	f	\N
119299	new	### new	et	f	\N
119316	none	?none =none  (SgN  >none !16_S	et	f	\N
119317	none	?none =none  (SgG  >none !16_S	et	f	\N
119318	none	?none =none  (IndPrPs_  >nonema !27_V	et	f	\N
119320	none	?none =none  (ImpPrSg2  >nonema !27_V	et	f	\N
119321	span	### span	et	f	\N
119338	transpordita	transpordita =transpordi  (SgAb  >transport !22_S	et	f	\N
119339	transpordita	transpordita =transpordi  (IndPrIps_  >transportima !28_V	et	f	\N
119344	hommikuti	hommikuti =hommikuti  (ID  >hommikuti !41_D	et	f	\N
119345	hommikuti	hommikuti =uti  (SgG  >hommik+utt !22_S	et	f	\N
119377	hilisemate	hilisemate =hilisema  (PlG  >hilisem !02_A	et	f	\N
119378	hilisemate	"hilisem %hilise  )M_cA  <hiline ;10_A	et	f	\N
119387	tähtsamaks	tähtsamaks =tähtsama  (SgTr  >tähtsam !02_A	et	f	\N
119388	tähtsamaks	"tähtsam %tähtsa  )M_cA  <tähtis ;02_A	et	f	\N
119401	jaani	jaani =jaani  (SgG  >jaan !22_S	et	f	\N
119402	jaani	jaani =jaani  (SgP  >jaan !22_S	et	f	\N
119403	jaani	jaani =jaani  (SgAdt  >jaan !22_S	et	f	\N
119407	inglise	inglise =inglise  (ID  >inglise !41_G	et	f	\N
119408	inglise	inglise =inglise  (SgG  >ingline !12~10_A	et	f	\N
119409	inglise	"ingline %ingli  )NE_aA  <ingel ;02_S	et	f	\N
119421	koelli	?koelli =koelli  (ID  >koelli !41_D	et	f	\N
119422	koelli	?koelli =koelli  (SgG  >koell !22_S	et	f	\N
119423	koelli	?koelli =koelli  (SgP  >koell !22_S	et	f	\N
119424	koelli	?koelli =koelli  (SgAdt  >koell !22_S	et	f	\N
119425	koelli	?koelli =koelli  (IndPrPs_  >koellima !28_V	et	f	\N
119426	koelli	?koelli =koelli  (ImpPrSg2  >koellima !28_V	et	f	\N
119439	linnakooli	linnakooli =kooli  (SgG  >linna+kool !22_S	et	f	\N
119440	linnakooli	linnakooli =kooli  (SgP  >linna+kool !22_S	et	f	\N
119441	linnakooli	linnakooli =kooli  (SgAdt  >linna+kool !22_S	et	f	\N
119442	linnakooli	linnakooli =kooli  (PlP  >linna+kool !22_S	et	f	\N
119444	susi	susi =susi  (SgN  >susi !15_S	et	f	\N
119445	susi	susi =susi  (PlP  >susi !15_S	et	f	\N
119446	susi	susi =susi  (IndPrPs_  >susima !27_V	et	f	\N
119447	susi	susi =susi  (IndPrPs_  >suskima !28_V	et	f	\N
119448	susi	susi =susi  (ImpPrSg2  >susima !27_V	et	f	\N
119449	susi	susi =susi  (ImpPrSg2  >suskima !28_V	et	f	\N
119452	käsikirja	käsikirja =kirja  (SgG  >käsi+kiri !24_S	et	f	\N
119453	käsikirja	käsikirja =kirja  (SgP  >käsi+kiri !24_S	et	f	\N
119454	käsikirja	käsikirja =kirja  (SgAdt  >käsi+kiri !24_S	et	f	\N
119456	maksule	maksule =maksu  (SgAll  >maks !22_S	et	f	\N
119457	maksule	maksule =maksu  (PlAll  >maks !22_S	et	f	\N
119461	kahekordselt	kahekordselt =kordse  (SgAbl  >kahe+kordne !02_AS	et	f	\N
119462	kahekordselt	"kahe+kordselt %kordse  )LT_mD  <kahe+kordne ;02_AS	et	f	\N
119477	orjed	?orjed =orje  (PlN  >orje !06_S	et	f	\N
119478	orjed	?orjed =orje  (IndPrSg2  >orjema !27_V	et	f	\N
119482	250-300gr	### 250-300gr	et	f	\N
119484	gr	### gr	et	f	\N
119491	ajaloosündusdest	?ajaloosündusdest =ajaloosündusde  (PlEl  >ajaloosündusd !22_S	et	f	\N
119494	ajaloosündusdest	?ajaloosündusdest =ajaloosündusdes  (SgP  >ajaloosündusdene !12_A	et	f	\N
119495	ajaloosündusdest	?ajaloosündusdest =sündusdes  (SgP  >aja+loo+sündusdene !12_A	et	f	\N
119496	ajaloosündusdest	?ajaloosündusdest =loosündusde  (PlEl  >aja+loosündusd !22_S	et	f	\N
119497	ajaloosündusdest	?ajaloosündusdest =loosündusdes  (SgP  >aja+loosündusdene !12_A	et	f	\N
119514	slavlasttel	?slavlasttel =slavlastte  (PlAd  >slavlastt !22_S	et	f	\N
119518	besmen	?besmen =besme  (IndPrSg1  >besmema !27_V	et	f	\N
119519	besmen	?besmen =besmen  (SgN  >besmen !02_S	et	f	\N
119544	suulata	suulata =suula  (SgAb  >suulas !07_A	et	f	\N
119545	suulata	suulata =suula  (SgAb  >suula !16_S	et	f	\N
119546	suulata	suulata =la  (SgAb  >suu+la !26_S	et	f	\N
119554	kristluse	kristluse =kristluse  (SgG  >kristlus !11~09_S	et	f	\N
119555	kristluse	"kristlus %kristlase  )US_aS  <kristlane ;12_S	et	f	\N
119580	asukate	asukate =asuka  (PlG  >asukas !02_S	et	f	\N
119581	asukate	asukate =kate  (SgN  >asu+kate !06_S	et	f	\N
119594	kivikirstkalmed	### kivikirstkalmed	et	f	\N
119610	noorem	noorem =noorem  (SgN  >noorem !02_A	et	f	\N
119611	noorem	"noorem %noore  )M_cA  <noor ;13_AS	et	f	\N
119619	avastatud	avastatud =avasta  (PtsPtIps  >avastama !27_V	et	f	\N
119620	avastatud	avastatud =avastatu  (PlN  >avastatu !01_S	et	f	\N
119621	avastatud	"avastatu %avasta  )TU1_vS  <avastama ;27_V	et	f	\N
119622	avastatud	avastatud =avastatud  (ID  >avastatud !41_A	et	f	\N
119623	avastatud	"avastatud %avasta  )TUD_vA  <avastama ;27_V	et	f	\N
119628	sõltuvad	sõltuvad =sõltu  (IndPrPl3  >sõltuma !27_V	et	f	\N
119629	sõltuvad	sõltuvad =sõltuva  (PlN  >sõltuv !02_A	et	f	\N
119630	sõltuvad	"sõltuv %sõltu  )V_vA  <sõltuma ;27_V	et	f	\N
119634	austamisest	austamisest =austamise  (SgEl  >austamine !12_S	et	f	\N
119635	austamisest	"austamine %austa  )MINE_vS  <austama ;27_V	et	f	\N
119668	rauaaega	rauaaega =aega  (SgP  >raua+aeg !22_S	et	f	\N
119669	rauaaega	rauaaega =aega  (SgAdt  >raua+aeg !22_S	et	f	\N
119358	henricus	?henricus =henricus  (SgN  >henricus !11_S	et	f	\N
119367	usku	usku =usku  (SgP  >usk !22_S	et	f	\N
119369	usku	usku =usku  (SgAdt  >usk !22_S	et	f	\N
119370	levitama	levitama =levi  (SupIps  >levima !27_V	et	f	\N
119371	levitama	levitama =levita  (Sup  >levitama !27_V	et	f	\N
119400	1881a	### 1881a	et	f	\N
119420	wandradt	?wandradt =wandradt  (SgN  >wandradt !22_S	et	f	\N
119428	lübeckis	?lübeckis =lübecki  (SgIn  >lübeck !22_S	et	f	\N
119429	lübeckis	?lübeckis =lübeckis  (SgN  >lübeckis !11_S	et	f	\N
119433	kujul	kujul =kuju  (SgAd  >kuju !17_S	et	f	\N
119434	kujul	kujul =kujul  (ID  >kujul !41_K	et	f	\N
119435	simon	?simon =simon  (SgN  >simon !02_S	et	f	\N
119450	koostas	koostas =koosta  (SgIn  >koost !22_S	et	f	\N
119451	koostas	koostas =koosta  (IndIpfSg3  >koostama !27_V	et	f	\N
119458	kohustus	kohustus =kohustu  (IndIpfSg3  >kohustuma !27_V	et	f	\N
119459	kohustus	kohustus =kohustus  (SgN  >kohustus !11_S	et	f	\N
119460	kohustus	"kohustus %kohusta  )US_vS  <kohustama ;27_V	et	f	\N
119483	gr	### gr	et	f	\N
119488	pikemad	pikemad =pikema  (PlN  >pikem !02_A	et	f	\N
119489	pikemad	"pikem %pike  )M_cA  <pikk ;22_AS	et	f	\N
119501	jurjev	?jurjev =jurje  (PtsPrPs  >jurjema !27_V	et	f	\N
119502	jurjev	?jurjev =jurjev  (SgN  >jurjev !02_A	et	f	\N
119506	peipsi	?peipsi =peipsi  (ID  >peipsi !41_D	et	f	\N
119507	peipsi	?peipsi =peipsi  (SgG  >peips !22_S	et	f	\N
119508	peipsi	?peipsi =peipsi  (SgP  >peips !22_S	et	f	\N
119509	peipsi	?peipsi =peipsi  (SgAdt  >peips !22_S	et	f	\N
119510	peipsi	?peipsi =peipsi  (IndPrPs_  >peipsima !28_V	et	f	\N
119511	peipsi	?peipsi =peipsi  (ImpPrSg2  >peipsima !28_V	et	f	\N
119515	territooriumi	territooriumi =territooriumi  (SgG  >territoorium !19~02_S	et	f	\N
119516	territooriumi	territooriumi =territooriumi  (SgP  >territoorium !19_S	et	f	\N
119517	territooriumi	territooriumi =territooriumi  (SgAdt  >territoorium !19_S	et	f	\N
119549	aitasid	aitasid =aita  (PlP  >ait !22_S	et	f	\N
119550	aitasid	aitasid =aita  (IndIpfSg2  >aitama !29_V	et	f	\N
119551	aitasid	aitasid =aita  (IndIpfPl3  >aitama !29_V	et	f	\N
119578	asula	asula =asula  (SgN  >asula !01_S	et	f	\N
119579	asula	asula =asula  (SgG  >asula !01_S	et	f	\N
119598	kivimetest	kivimetest =e  (PlEl  >kivim+esi !15_S	et	f	\N
119600	kivimetest	kivimetest =me  (PlEl  >kivi+mesi !15_S	et	f	\N
119603	kivimetest	kivimetest =mete  (PlEl  >kivi+mett !22_S	et	f	\N
119612	surnutele	surnutele =surnu  (PlAll  >surnu !01_S	et	f	\N
119613	surnutele	"surnu %sur  )NU_vS  <surema ;36_V	et	f	\N
119614	surnutele	surnutele =surnu  (PlAll  >surnu !06_S	et	f	\N
119646	maagilised	maagilised =maagilise  (PlN  >maagiline !12_A	et	f	\N
119647	maagilised	"maagiline %maagi  )LINE_aA  <maag ;22_S	et	f	\N
119648	maagilised	"maagiline %maagi  )LINE_aA  <maak ;22_S	et	f	\N
119661	kauem	kauem =kauem  (ID  >kauem !41_D	et	f	\N
119662	kauem	kauem =kauem  (SgN  >kauem !02_A	et	f	\N
119689	langes	langes =lange  (SgIn  >lange !06_S	et	f	\N
119690	langes	langes =lange  (PlIn  >lang !22_S	et	f	\N
119691	langes	langes =lange  (PlIn  >lank !22_S	et	f	\N
119692	langes	langes =lange  (IndIpfSg3  >langema !27_V	et	f	\N
119698	mõnekümne	?mõnekümne =mõnekümne  (SgN  >mõnekümne !02_A	et	f	\N
119699	mõnekümne	?mõnekümne =mõnekümne  (PlP  >mõnekümn !22_S	et	f	\N
119700	mõnekümne	?mõnekümne =kümne  (SgN  >mõne+kümne !02_A	et	f	\N
119701	mõnekümne	?mõnekümne =kümne  (PlP  >mõne+kümn !22_S	et	f	\N
119703	protsessi	protsessi =protsessi  (SgG  >protsess !22_S	et	f	\N
119704	protsessi	protsessi =protsessi  (SgP  >protsess !22_S	et	f	\N
119705	protsessi	protsessi =protsessi  (SgAdt  >protsess !22_S	et	f	\N
119706	protsessi	protsessi =protsessi  (IndPrPs_  >protsessima !28_V	et	f	\N
119707	protsessi	protsessi =protsessi  (ImpPrSg2  >protsessima !28_V	et	f	\N
119737	põletatult	põletatult =põletatu  (SgAbl  >põletatu !01_S	et	f	\N
119738	põletatult	"põletatu %põleta  )TU1_vS  <põletama ;27_V	et	f	\N
119739	põletatult	põletatult =põletatult  (ID  >põletatult !41_D	et	f	\N
119740	põletatult	"põletatult %põleta  )TULT1_mD  <põletama ;27_V	et	f	\N
119766	valvavad	valvavad =valva  (IndPrPl3  >valvama !29_V	et	f	\N
119767	valvavad	valvavad =valvava  (PlN  >valvav !02_A	et	f	\N
119769	valvavad	"valvav %valva  )V_vA  <valvama ;29_V	et	f	\N
119779	tugevamaks	tugevamaks =tugevama  (SgTr  >tugevam !02_A	et	f	\N
119780	tugevamaks	"tugevam %tuge  )VAM_cA  <tugema ;27_V	et	f	\N
119781	tugevamaks	"tugevam %tugeva  )M_cA  <tugev ;02_A	et	f	\N
119782	tugevamaks	tugevamaks =maks  (SgN  >tugeva+maks !22_S	et	f	\N
119791	ettekujutust	ettekujutust =tust  (SgN  >ette+kuju+tust !22_S	et	f	\N
119792	ettekujutust	ettekujutust =kujutu  (SgEl  >ette+kujutu !01_A	et	f	\N
119793	ettekujutust	"ette+kujutu %kuju  )TU2_kA  <ette+kuju ;17_S	et	f	\N
119794	ettekujutust	ettekujutust =kujutus  (SgP  >ette+kujutus !11_S	et	f	\N
119795	ettekujutust	"ette+kujutus %kuju  )TUS2_aS  <ette+kuju ;17_S	et	f	\N
119798	holitsema	?holitsema =holitse  (Sup  >holitsema !27_V	et	f	\N
119799	holitsema	?holitsema =holitsema  (SgG  >holitsem !02_A	et	f	\N
119470	vikingid	?vikingid =vikingi  (IndPrSg2  >vikinkima !28_V	et	f	\N
119475	mesi	mesi =mesi  (SgN  >mesi !15_S	et	f	\N
119476	mesi	mesi =mesi  (PlP  >mesi !15_S	et	f	\N
119479	väärtuslikum	väärtuslikum =väärtuslikum  (SgN  >väärtuslikum !02_A	et	f	\N
119480	väärtuslikum	"väärtuslikum %väärtusliku  )M_cA  <väärtuslik ;25_A	et	f	\N
119490	tähtsadest	?tähtsadest =tähtsades  (SgP  >tähtsadene !12_A	et	f	\N
119492	tähtsadest	?tähtsadest =sades  (SgP  >täht+sades !09_S	et	f	\N
119493	tähtsadest	?tähtsadest =sades  (SgP  >täht+sadene !10_A	et	f	\N
119498	sõjakontlikt	?sõjakontlikt =sõjakontlikt  (SgN  >sõjakontlikt !22_S	et	f	\N
119499	sõjakontlikt	?sõjakontlikt =kontlikt  (SgN  >sõja+kontlikt !22_S	et	f	\N
119503	tugipunktiks	tugipunktiks =iks  (SgN  >tugi+punkt+iks !22_S	et	f	\N
119504	tugipunktiks	tugipunktiks =tiks  (SgN  >tugi+punk+tiks !22_S	et	f	\N
119505	tugipunktiks	tugipunktiks =punkti  (SgTr  >tugi+punkt !22_S	et	f	\N
119520	sõjaliselt	sõjaliselt =sõjalise  (SgAbl  >sõjaline !12_A	et	f	\N
119521	sõjaliselt	"sõjaline %sõja  )LINE_aA  <sõda ;18_S	et	f	\N
119522	sõjaliselt	sõjaliselt =sõjaliselt  (ID  >sõjaliselt !41_D	et	f	\N
119523	sõjaliselt	"sõjaliselt %sõja  )LISELT_mD  <sõda ;18_S	et	f	\N
119524	sõjaliselt	"sõjaliselt %sõjalise  )LT_mD  <sõjaline ;12_A	et	f	\N
119525	araabia	?araabia =araabia  (SgN  >araabia !01_S	et	f	\N
119526	araabia	?araabia =araabia  (SgG  >araabia !01_S	et	f	\N
119527	araabia	?araabia =abia  (SgN  >ara+abia !01_S	et	f	\N
119528	araabia	?araabia =abia  (SgG  >ara+abia !01_S	et	f	\N
119582	kivi	kivi =kivi  (SgN  >kivi !17_S	et	f	\N
119583	kivi	kivi =kivi  (SgG  >kivi !17_S	et	f	\N
119586	kivi	kivi =kivi  (SgP  >kivi !17_S	et	f	\N
119595	valmistatud	valmistatud =valmista  (PtsPtIps  >valmistama !27_V	et	f	\N
119596	valmistatud	valmistatud =valmistatu  (PlN  >valmistatu !01_S	et	f	\N
119597	valmistatud	"valmistatu %valmista  )TU1_vS  <valmistama ;27_V	et	f	\N
119602	valmistatud	valmistatud =valmistatud  (ID  >valmistatud !41_A	et	f	\N
119604	valmistatud	"valmistatud %valmista  )TUD_vA  <valmistama ;27_V	et	f	\N
119615	relvi	relvi =relvi  (SgG  >relv !22_S	et	f	\N
119616	relvi	relvi =relvi  (SgP  >relv !22_S	et	f	\N
119617	relvi	relvi =relvi  (SgAdt  >relv !22_S	et	f	\N
119618	relvi	relvi =relvi  (PlP  >relv !22_S	et	f	\N
119624	okrit	?okrit =okri  (SgP  >okker !02_S	et	f	\N
119625	okrit	?okrit =okrit  (SgN  >okrit !02_S	et	f	\N
119636	rooma	rooma =rooma  (ID  >rooma !41_G	et	f	\N
119637	rooma	rooma =rooma  (SgG  >room !22_S	et	f	\N
119638	rooma	rooma =rooma  (SgP  >room !22_S	et	f	\N
119639	rooma	rooma =rooma  (SgAdt  >room !22_S	et	f	\N
119640	rooma	rooma =rooma  (IndPrPs_  >roomama !29_V	et	f	\N
119641	rooma	rooma =rooma  (ImpPrSg2  >roomama !29_V	et	f	\N
119644	tähtsuse	tähtsuse =tähtsuse  (SgG  >tähtsus !11~09_S	et	f	\N
119645	tähtsuse	"tähtsus %tähtsa  )US_aS  <tähtis ;02_A	et	f	\N
119663	jaanitule	jaanitule =jaanitu  (SgAll  >jaanitu !01_AS	et	f	\N
119665	jaanitule	"jaanitu %jaani  )TU2_kA  <jaan ;22_S	et	f	\N
119667	jaanitule	jaanitule =tule  (SgG  >jaani+tuli !20_S	et	f	\N
119670	uskumuslikuks	?uskumuslikuks =uskumusliku  (SgTr  >uskumuslik !25_A	et	f	\N
119671	uskumuslikuks	?uskumuslikuks =uskumusliku  (KndPrPs  >uskumuslikuma !27_V	et	f	\N
119672	uskumuslikuks	?uskumuslikuks =musliku  (SgTr  >usku+muslik !25_A	et	f	\N
119673	uskumuslikuks	?uskumuslikuks =musliku  (SgTr  >usku+musliku !01_S	et	f	\N
119676	saamiseks	saamiseks =saamise  (SgTr  >saamine !12?10_S	et	f	\N
119677	saamiseks	"saamine %saa  )MINE_vS  <saama ;37_V	et	f	\N
119678	saamiseks	"saamine %saami  )NE_aA  <saam ;22_S	et	f	\N
119683	viljakus	viljakus =viljaku  (SgIn  >viljak !02_S	et	f	\N
119685	viljakus	viljakus =viljakus  (SgN  >viljakus !11_S	et	f	\N
119687	viljakus	"viljakus %viljaka  )US_aS  <viljakas ;02_A	et	f	\N
119693	varasel	varasel =varase  (SgAd  >varane !10_A	et	f	\N
119694	varasel	"varane %vara  )NE_aA  <vara ;17_S	et	f	\N
119711	esivanemate	esivanemate =vanema  (PlG  >esi+vanem !02_AS	et	f	\N
119712	esivanemate	"esi+vanem %vane  )M_cA  <esi+vana ;17_AS	et	f	\N
119721	ohverdamine	ohverdamine =ohverdamine  (SgN  >ohverdamine !12_S	et	f	\N
119722	ohverdamine	"ohverdamine %ohverda  )MINE_vS  <ohverdama ;27_V	et	f	\N
119729	liha	liha =liha  (SgN  >liha !17_S	et	f	\N
119731	liha	liha =liha  (SgG  >liha !17_S	et	f	\N
119732	liha	liha =liha  (SgP  >liha !17_S	et	f	\N
119748	kokkukuuluvus	kokkukuuluvus =kuuluvus  (SgN  >kokku+kuuluvus !11_S	et	f	\N
119749	kokkukuuluvus	"kokku+kuuluvus %kuuluva  )US_aS  <kokku+kuuluv ;02_A	et	f	\N
119750	esivanematega	esivanematega =vanema  (PlKom  >esi+vanem !02_AS	et	f	\N
119751	esivanematega	"esi+vanem %vane  )M_cA  <esi+vana ;17_AS	et	f	\N
119787	loomakujukesed	loomakujukesed =kujukese  (PlN  >looma+kujuke !12_S	et	f	\N
119788	loomakujukesed	"looma+kujuke %kuju  )KE_dS  <looma+kuju ;17_S	et	f	\N
119789	loomakujukesed	loomakujukesed =kujukese  (PlN  >looma+kujukene !12_S	et	f	\N
119790	loomakujukesed	"looma+kujukene %kuju  )KENE_dS  <looma+kuju ;17_S	et	f	\N
119796	vanemal	vanemal =vanema  (SgAd  >vanem !02_AS	et	f	\N
119797	vanemal	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
119530	koduloomade	koduloomade =looma  (PlG  >kodu+loom !22_S	et	f	\N
119536	pronksi	pronksi =pronksi  (SgG  >pronks !22_S	et	f	\N
119537	pronksi	pronksi =pronksi  (SgP  >pronks !22_S	et	f	\N
119538	pronksi	pronksi =pronksi  (SgAdt  >pronks !22_S	et	f	\N
119541	töödelda	töödelda =töödel  (Inf  >töötlema !30_V	et	f	\N
119543	töödelda	töödelda =töödel  (IndPrIps_  >töötlema !30_V	et	f	\N
119553	varat	?varat =varat  (SgN  >varat !02_S	et	f	\N
119564	üldiseloomustus	üldiseloomustus =ustu  (SgIn  >üld+ise+loom+ustu !01_S	et	f	\N
119565	üldiseloomustus	üldiseloomustus =mustus  (SgN  >üld+ise+loo+mustus !11~09_S	et	f	\N
119566	üldiseloomustus	"üld+ise+loo+mustus %must  )US_aS  <üld+ise+loo+must ;22_AS	et	f	\N
119567	üldiseloomustus	üldiseloomustus =loomustus  (SgN  >üld+ise+loomustus !11_S	et	f	\N
119574	hingest	hingest =hinge  (SgEl  >hing !22_S	et	f	\N
119575	hingest	hingest =hinge  (PlEl  >hink !22_S	et	f	\N
119576	hingest	hingest =hinges  (SgP  >hingene !12~10_A	et	f	\N
119577	hingest	"hingene %hinge  )NE_aA  <hing ;22_S	et	f	\N
119584	nöörkeraamika	nöörkeraamika =keraamika  (SgN  >nöör+keraamika !01_S	et	f	\N
119585	nöörkeraamika	nöörkeraamika =keraamika  (SgG  >nöör+keraamika !01_S	et	f	\N
119590	jõudsid	jõudsid =jõud  (IndIpfSg2  >jõudma !34_V	et	f	\N
119591	jõudsid	jõudsid =jõud  (IndIpfPl3  >jõudma !34_V	et	f	\N
119649	ilmastiku	ilmastiku =ilmastiku  (SgG  >ilmastik !25_S	et	f	\N
119652	ilmastiku	ilmastiku =astiku  (SgG  >ilm+astik !02_S	et	f	\N
119653	ristida	ristida =risti  (Inf  >ristima !28_V	et	f	\N
119654	ristida	ristida =ida  (SgN  >rist+ida !17_S	et	f	\N
119655	ristida	ristida =ida  (SgG  >rist+ida !17_S	et	f	\N
119656	ristida	ristida =ida  (SgP  >rist+ida !17_S	et	f	\N
119658	püsis	püsis =püsi  (SgIn  >püsi !17_S	et	f	\N
119659	püsis	püsis =püsi  (IndIpfSg3  >püsima !27_V	et	f	\N
119684	mulla	mulla =mulla  (SgN  >mulla !16_S	et	f	\N
119686	mulla	mulla =mulla  (SgG  >mulla !16_S	et	f	\N
119688	mulla	mulla =mulla  (SgG  >muld !22_S	et	f	\N
119713	austamine	austamine =austamine  (SgN  >austamine !12_S	et	f	\N
119714	austamine	"austamine %austa  )MINE_vS  <austama ;27_V	et	f	\N
119741	toitu	toitu =toitu  (SgN  >toitu !01_A	et	f	\N
119742	toitu	"toitu %toi  )TU2_kA  <toi ;26_S	et	f	\N
119743	toitu	toitu =toitu  (SgG  >toitu !01_A	et	f	\N
119744	toitu	toitu =toitu  (SgP  >toit !22_S	et	f	\N
119745	toitu	toitu =toitu  (SgAdt  >toit !22_S	et	f	\N
119746	toitu	toitu =toitu  (IndPrPs_  >toituma !27_V	et	f	\N
119747	toitu	toitu =toitu  (ImpPrSg2  >toituma !27_V	et	f	\N
119763	joomine	joomine =joomine  (SgN  >joomine !12?10_S	et	f	\N
119764	joomine	"joomine %joo  )MINE_vS  <jooma ;38_V	et	f	\N
119765	joomine	"joomine %joomi  )NE_aA  <joom ;22_S	et	f	\N
119774	uskusid	uskusid =usku  (PlP  >usk !22_S	et	f	\N
119775	uskusid	uskusid =usku  (IndIpfSg2  >uskuma !28_V	et	f	\N
119776	uskusid	uskusid =usku  (IndIpfPl3  >uskuma !28_V	et	f	\N
119783	uskust	?uskust =usku  (SgEl  >usku !16_S	et	f	\N
119784	uskust	?uskust =uskus  (SgP  >uskus !11~09_S	et	f	\N
119830	surt	?surt =surt  (SgN  >surt !22_S	et	f	\N
119861	arust	arust =aru  (SgEl  >aru !17_S	et	f	\N
119862	arust	arust =aru  (PlEl  >arg !22_A	et	f	\N
119863	arust	arust =arus  (SgP  >arune !10_A	et	f	\N
119864	arust	"arune %aru  )NE_aA  <aru ;17_S	et	f	\N
119886	kaasnesid	kaasnesid =kaasne  (IndIpfSg2  >kaasnema !27_V	et	f	\N
119887	kaasnesid	kaasnesid =kaasne  (IndIpfPl3  >kaasnema !27_V	et	f	\N
119888	muutsid	muutsid =muut  (IndIpfSg2  >muutma !34_V	et	f	\N
119889	muutsid	muutsid =muut  (IndIpfPl3  >muutma !34_V	et	f	\N
119898	praeguga	?praeguga =guga  (SgN  >prae+guga !17_S	et	f	\N
119899	praeguga	?praeguga =guga  (SgG  >prae+guga !17_S	et	f	\N
119900	praeguga	?praeguga =guga  (SgP  >prae+guga !17_S	et	f	\N
119912	vaipa	vaipa =vaipa  (SgP  >vaip !22_S	et	f	\N
119913	vaipa	vaipa =vaipa  (SgAdt  >vaip !22_S	et	f	\N
119923	loa	loa =loa  (SgG  >luba !18_S	et	f	\N
119924	loa	loa =loa  (SgG  >luga !18_S	et	f	\N
119935	ne	### ne	et	f	\N
119946	arenevad	arenevad =arene  (IndPrPl3  >arenema !27_V	et	f	\N
119947	arenevad	arenevad =areneva  (PlN  >arenev !02_A	et	f	\N
119948	arenevad	"arenev %arene  )V_vA  <arenema ;27_V	et	f	\N
119958	edgar	?edgar =edgar  (SgN  >edgar !02_S	et	f	\N
119975	radikaalselt	radikaalselt =radikaalse  (SgAbl  >radikaalne !02_A	et	f	\N
119976	radikaalselt	radikaalselt =radikaalselt  (ID  >radikaalselt !41_D	et	f	\N
119977	radikaalselt	"radikaalselt %radikaalse  )LT_mD  <radikaalne ;02_A	et	f	\N
119990	isamaaliitu	isamaaliitu =liitu  (SgN  >isa+maa+liitu !01_A	et	f	\N
119991	isamaaliitu	"isa+maa+liitu %lii  )TU2_kA  <isa+maa+lii ;26_S	et	f	\N
119992	isamaaliitu	isamaaliitu =liitu  (SgG  >isa+maa+liitu !01_A	et	f	\N
119993	isamaaliitu	isamaaliitu =liitu  (SgP  >isa+maa+liit !22_S	et	f	\N
119994	isamaaliitu	isamaaliitu =liitu  (SgAdt  >isa+maa+liit !22_S	et	f	\N
120008	aktiivselt	aktiivselt =aktiivse  (SgAbl  >aktiivne !02_A	et	f	\N
120009	aktiivselt	aktiivselt =aktiivselt  (ID  >aktiivselt !41_D	et	f	\N
120010	aktiivselt	"aktiivselt %aktiivse  )LT_mD  <aktiivne ;02_A	et	f	\N
119562	tulekutrauaaja	?tulekutrauaaja =kutrauaaja  (SgG  >tule+kutrauaajas !02_A	et	f	\N
119563	tulekutrauaaja	?tulekutrauaaja =kutrauaaja  (SgG  >tule+kutrauaaja !16_S	et	f	\N
119568	uskumuste	uskumuste =uskumus  (PlG  >uskumus !11_S	et	f	\N
119569	uskumuste	uskumuste =muste  (PlP  >usku+must !22_AS	et	f	\N
119570	ettekujutus	ettekujutus =kujutu  (SgIn  >ette+kujutu !01_A	et	f	\N
119571	ettekujutus	"ette+kujutu %kuju  )TU2_kA  <ette+kuju ;17_S	et	f	\N
119572	ettekujutus	ettekujutus =kujutus  (SgN  >ette+kujutus !11_S	et	f	\N
119573	ettekujutus	"ette+kujutus %kuju  )TUS2_aS  <ette+kuju ;17_S	et	f	\N
119587	neoliitikumi	neoliitikumi =neoliitikumi  (SgG  >neoliitikum !19_S	et	f	\N
119588	neoliitikumi	neoliitikumi =neoliitikumi  (SgP  >neoliitikum !19_S	et	f	\N
119589	neoliitikumi	neoliitikumi =neoliitikumi  (SgAdt  >neoliitikum !19_S	et	f	\N
119592	ekr	?ekr =ekr  (SgN  >ekr !22_S	et	f	\N
119593	nö	### nö	et	f	\N
119599	suurematest	suurematest =suurema  (PlEl  >suurem !02_A	et	f	\N
119601	suurematest	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
119605	suurematest	suurematest =test  (SgN  >suur+ema+test !22_S	et	f	\N
119606	suurematest	suurematest =mate  (SgEl  >suure+mate !16_S	et	f	\N
119607	suurematest	suurematest =mate  (PlEl  >suure+matt !22_SA	et	f	\N
119608	suurematest	suurematest =mates  (SgP  >suure+matene !10_A	et	f	\N
119609	suurematest	"suure+matene %mate  )NE_aA  <suure+mate ;16_S	et	f	\N
119626	arvasid	arvasid =arva  (IndIpfSg2  >arvama !29_V	et	f	\N
119627	arvasid	arvasid =arva  (IndIpfPl3  >arvama !29_V	et	f	\N
119631	surnute	surnute =surnu  (PlG  >surnu !01_S	et	f	\N
119632	surnute	"surnu %sur  )NU_vS  <surema ;36_V	et	f	\N
119633	surnute	surnute =surnu  (PlG  >surnu !06_S	et	f	\N
119642	erilise	erilise =erilise  (SgG  >eriline !12_A	et	f	\N
119643	erilise	"eriline %eri  )LINE_aA  <eri ;17_S	et	f	\N
119650	mõjutamiseks	mõjutamiseks =mõjutamise  (SgTr  >mõjutamine !12_S	et	f	\N
119651	mõjutamiseks	"mõjutamine %mõjuta  )MINE_vS  <mõjutama ;27_V	et	f	\N
119657	baltimaa	baltimaa =maa  (SgN  >balti+maa !26_S	et	f	\N
119660	baltimaa	baltimaa =maa  (SgG  >balti+maa !26_S	et	f	\N
119664	komme	komme =komme  (SgN  >komme !06_S	et	f	\N
119666	komme	komme =komme  (PlP  >komm !22_S	et	f	\N
119674	põllumaa	põllumaa =maa  (SgN  >põllu+maa !26_S	et	f	\N
119675	põllumaa	põllumaa =maa  (SgG  >põllu+maa !26_S	et	f	\N
119681	vältel	vältel =välte  (SgAd  >välde !06_S	et	f	\N
119682	vältel	vältel =vältel  (ID  >vältel !41_K	et	f	\N
119715	hinge	hinge =hinge  (SgG  >hing !22_S	et	f	\N
119716	hinge	hinge =hinge  (SgP  >hing !22_S	et	f	\N
119717	hinge	hinge =hinge  (SgAdt  >hing !22_S	et	f	\N
119718	hinge	hinge =hinge  (PlP  >hing !22_S	et	f	\N
119725	leiba	leiba =leiba  (SgP  >leib !22_S	et	f	\N
119727	leiba	leiba =leiba  (SgAdt  >leib !22_S	et	f	\N
119733	ohverdamisega	ohverdamisega =ohverdamise  (SgKom  >ohverdamine !12_S	et	f	\N
119734	ohverdamisega	"ohverdamine %ohverda  )MINE_vS  <ohverdama ;27_V	et	f	\N
119754	paelu	paelu =paelu  (PlP  >pael !23?22_S	et	f	\N
119755	paelu	paelu =paelu  (IndPrPs_  >paeluma !27_V	et	f	\N
119756	paelu	paelu =paelu  (ImpPrSg2  >paeluma !27_V	et	f	\N
119768	kaitsevad	kaitsevad =kaitse  (IndPrPl3  >kaitsema !28_V	et	f	\N
119770	kaitsevad	kaitsevad =kaitse  (IndPrPl3  >kaitsma !32_V	et	f	\N
119771	kaitsevad	kaitsevad =kaitseva  (PlN  >kaitsev !02_A	et	f	\N
119772	kaitsevad	"kaitsev %kaits  )V_vA  <kaitsma ;32_V	et	f	\N
119773	kaitsevad	"kaitsev %kaitse  )V_vA  <kaitsema ;28_V	et	f	\N
119777	läbisaamisest	läbisaamisest =saamise  (SgEl  >läbi+saamine !12?10_S	et	f	\N
119778	läbisaamisest	"läbi+saamine %saami  )NE_aA  <läbi+saam ;22_S	et	f	\N
119807	halvenevad	halvenevad =halvene  (IndPrPl3  >halvenema !27_V	et	f	\N
119808	halvenevad	halvenevad =halveneva  (PlN  >halvenev !02_A	et	f	\N
119809	halvenevad	"halvenev %halvene  )V_vA  <halvenema ;27_V	et	f	\N
119813	taasiseseivumisprotsessis	?taasiseseivumisprotsessis =taasiseseivumisprotsessi  (SgIn  >taasiseseivumisprotsess !22_S	et	f	\N
119814	taasiseseivumisprotsessis	?taasiseseivumisprotsessis =taasiseseivumisprotsessi  (IndIpfSg3  >taasiseseivumisprotsessima !28_V	et	f	\N
119815	taasiseseivumisprotsessis	?taasiseseivumisprotsessis =taasiseseivumisprotsessis  (SgN  >taasiseseivumisprotsessis !09_S	et	f	\N
119816	taasiseseivumisprotsessis	?taasiseseivumisprotsessis =seivumisprotsessi  (SgIn  >taas+ise+seivumisprotsess !22_S	et	f	\N
119817	taasiseseivumisprotsessis	?taasiseseivumisprotsessis =seivumisprotsessis  (SgN  >taas+ise+seivumisprotsessis !09_S	et	f	\N
119818	taasiseseivumisprotsessis	?taasiseseivumisprotsessis =iseseivumisprotsessi  (SgIn  >taas+iseseivumisprotsess !22_S	et	f	\N
119819	taasiseseivumisprotsessis	?taasiseseivumisprotsessis =iseseivumisprotsessi  (IndIpfSg3  >taas+iseseivumisprotsessima !28_V	et	f	\N
119820	taasiseseivumisprotsessis	?taasiseseivumisprotsessis =iseseivumisprotsessis  (SgN  >taas+iseseivumisprotsessis !09_S	et	f	\N
119821	tähendavad	tähendavad =tähenda  (IndPrPl3  >tähendama !27_V	et	f	\N
119822	tähendavad	tähendavad =tähendava  (PlN  >tähendav !02_A	et	f	\N
119823	tähendavad	"tähendav %tähenda  )V_vA  <tähendama ;27_V	et	f	\N
119828	isesesvumisprotsessis	?isesesvumisprotsessis =isesesvumisprotsessi  (SgIn  >isesesvumisprotsess !22_S	et	f	\N
119829	isesesvumisprotsessis	?isesesvumisprotsessis =isesesvumisprotsessi  (IndIpfSg3  >isesesvumisprotsessima !28_V	et	f	\N
119679	kasutati	kasutati =kasuta  (IndIpfIps  >kasutama !27_V	et	f	\N
119680	kasutati	kasutati =tati  (SgG  >kasu+tatt !22_S	et	f	\N
119695	võsa	võsa =võsa  (SgN  >võsa !17_S	et	f	\N
119696	võsa	võsa =võsa  (SgG  >võsa !17_S	et	f	\N
119697	võsa	võsa =võsa  (SgP  >võsa !17_S	et	f	\N
119702	korrati	korrati =korra  (IndIpfIps  >kordama !29_V	et	f	\N
119708	korrati	korrati =korrati  (ID  >korrati !41_D	et	f	\N
119709	loodusel	loodusel =looduse  (SgAd  >loodus !11~09_S	et	f	\N
119710	loodusel	"loodus %loo  )TUS1_aS  <looma ;38_V	et	f	\N
119719	looduses	looduses =looduse  (SgIn  >loodus !11~09_S	et	f	\N
119720	looduses	"loodus %loo  )TUS1_aS  <looma ;38_V	et	f	\N
119723	villa	villa =villa  (SgN  >villa !16_S	et	f	\N
119724	villa	villa =villa  (SgG  >villa !16_S	et	f	\N
119726	villa	villa =villa  (SgG  >vill !22_S	et	f	\N
119728	villa	villa =villa  (SgP  >vill !22_S	et	f	\N
119730	villa	villa =villa  (SgAdt  >vill !22_S	et	f	\N
119735	maagia	maagia =maagia  (SgN  >maagia !01_S	et	f	\N
119736	maagia	maagia =maagia  (SgG  >maagia !01_S	et	f	\N
119752	puudele	puudele =puu  (PlAll  >puu !26_S	et	f	\N
119753	puudele	puudele =puude  (SgAll  >puue !06_S	et	f	\N
119757	ohvrijooki	ohvrijooki =jooki  (SgP  >ohvri+jook !22_S	et	f	\N
119758	ohvrijooki	ohvrijooki =jooki  (SgAdt  >ohvri+jook !22_S	et	f	\N
119759	hõberaha	hõberaha =raha  (SgN  >hõbe+raha !17_S	et	f	\N
119760	hõberaha	hõberaha =raha  (SgG  >hõbe+raha !17_S	et	f	\N
119761	hõberaha	hõberaha =raha  (SgG  >hõbe+rahk !22_S	et	f	\N
119762	hõberaha	hõberaha =raha  (SgP  >hõbe+raha !17_S	et	f	\N
119785	magavas	magavas =magava  (SgIn  >magav !02_A	et	f	\N
119786	magavas	"magav %maga  )V_vA  <magama ;27_V	et	f	\N
119845	pavad	?pavad =pava  (PlN  >pava !17_S	et	f	\N
119846	pavad	?pavad =pava  (IndPrSg2  >pavama !27_V	et	f	\N
119852	nsvsse	### nsvsse	et	f	\N
119865	leebemaks	leebemaks =leebema  (SgTr  >leebem !02_A	et	f	\N
119866	leebemaks	"leebem %leebe  )M_cA  <leebe ;01_A	et	f	\N
119867	gorbatsjovi	?gorbatsjovi =gorbatsjovi  (ID  >gorbatsjovi !41_D	et	f	\N
119868	gorbatsjovi	?gorbatsjovi =gorbatsjovi  (SgG  >gorbatsjov !02_A	et	f	\N
119881	laostus	laostus =laostu  (IndIpfSg3  >laostuma !27_V	et	f	\N
119883	laostus	laostus =laostus  (SgN  >laostus !11~09_S	et	f	\N
119885	laostus	"laostus %laosta  )US_vS  <laostama ;27_V	et	f	\N
119890	sotsallaabi	sotsallaabi =abi  (SgN  >sots+alla+abi !17_S	et	f	\N
119891	sotsallaabi	sotsallaabi =abi  (SgG  >sots+alla+abi !17_S	et	f	\N
119892	sotsallaabi	sotsallaabi =abi  (SgP  >sots+alla+abi !17_S	et	f	\N
119896	vigastuse	vigastuse =vigastuse  (SgG  >vigastus !11_S	et	f	\N
119897	vigastuse	"vigastus %vigasta  )US_vS  <vigastama ;27_V	et	f	\N
119901	haigekassa	haigekassa =kassa  (SgN  >haige+kassa !16_S	et	f	\N
119902	haigekassa	haigekassa =kassa  (SgG  >haige+kassa !16_S	et	f	\N
119906	tola	tola =tola  (SgN  >tola !17_S	et	f	\N
119907	tola	tola =tola  (SgG  >tola !17_S	et	f	\N
119908	tola	tola =tola  (SgP  >tola !17_S	et	f	\N
119909	asja	asja =asja  (SgG  >asi !24_S	et	f	\N
119910	asja	asja =asja  (SgP  >asi !24_S	et	f	\N
119911	asja	asja =asja  (SgAdt  >asi !24_S	et	f	\N
119934	aids	?aids =aids  (SgN  >aids !22_S	et	f	\N
119983	muinsuskaitse	muinsuskaitse =kaitse  (SgN  >muinsus+kaitse !05_S	et	f	\N
119985	muinsuskaitse	muinsuskaitse =kaitse  (SgN  >muinsus+kaitse !06_S	et	f	\N
119987	muinsuskaitse	muinsuskaitse =kaitse  (SgG  >muinsus+kaitse !06_S	et	f	\N
119997	muulastest	muulastest =muulas  (PlEl  >muulane !12?10_S	et	f	\N
119998	muulastest	"muulane %muula  )NE_aA  <muul ;22_S	et	f	\N
120000	muulastest	muulastest =las  (PlEl  >muu+laps !14_S	et	f	\N
120002	muulastest	muulastest =laste  (PlEl  >muu+last !22_S	et	f	\N
120013	öisetel	?öisetel =öise  (PlAd  >öise !06_S	et	f	\N
120014	öisetel	?öisetel =öisete  (PlAd  >öisett !22_S	et	f	\N
120022	ekp	?ekp =ekp  (SgN  >ekp !22_S	et	f	\N
120027	rahvusrinde	rahvusrinde =rinde  (PlG  >rahvus+rind !22_S	et	f	\N
120028	rahvusrinde	rahvusrinde =rinde  (SgG  >rahvus+rinne !06_S	et	f	\N
120029	rahvusrinde	rahvusrinde =rinde  (PlP  >rahvus+rind !22_S	et	f	\N
120046	hoolutud	hoolutud =lutu  (PlN  >hoo+lutu !16_S	et	f	\N
120048	hoolutud	hoolutud =lutu  (PlN  >hoo+lutt !22_S	et	f	\N
120052	aug	?aug =aug  (SgN  >aug !22_S	et	f	\N
120053	organiseerimises	organiseerimises =organiseerimise  (SgIn  >organiseerimine !12_S	et	f	\N
120054	organiseerimises	"organiseerimine %organiseeri  )MINE_vS  <organiseerima ;28_V	et	f	\N
120073	kuuluga	kuuluga =kuulu  (SgKom  >kuuld !22_S	et	f	\N
120074	kuuluga	kuuluga =luga  (SgN  >kuu+luga !18_S	et	f	\N
120075	kuuluga	kuuluga =luga  (SgP  >kuu+luga !18_S	et	f	\N
120091	veretult	veretult =veretu  (SgAbl  >veretu !01_A	et	f	\N
120092	veretult	"veretu %vere  )TU2_kA  <veri ;20_S	et	f	\N
120093	veretult	veretult =veretult  (ID  >veretult !41_D	et	f	\N
120094	veretult	"veretult %vere  )TULT2_mD  <veri ;20_S	et	f	\N
120095	veretult	"veretult %veretu  )LT_mD  <veretu ;01_A	et	f	\N
120098	liidus	liidus =liidu  (SgIn  >liit !22_S	et	f	\N
120099	liidus	liidus =liidus  (SgN  >liidus !09_S	et	f	\N
120118	sõnavabadust	sõnavabadust =dust  (SgN  >sõna+vaba+dust !22_S	et	f	\N
119800	rajatakse	rajatakse =raja  (IndPrIps  >rajama !27_V	et	f	\N
119801	rajatakse	rajatakse =takse  (PlP  >raja+taks !22_S	et	f	\N
119810	rahvarinde	rahvarinde =rinde  (PlG  >rahva+rind !22_S	et	f	\N
119811	rahvarinde	rahvarinde =rinde  (SgG  >rahva+rinne !06_S	et	f	\N
119812	rahvarinde	rahvarinde =rinde  (PlP  >rahva+rind !22_S	et	f	\N
119824	otsustav	otsustav =otsusta  (PtsPrPs  >otsustama !27_V	et	f	\N
119825	otsustav	otsustav =otsustav  (SgN  >otsustav !02_A	et	f	\N
119826	otsustav	"otsustav %otsusta  )V_vA  <otsustama ;27_V	et	f	\N
119827	otsustav	otsustav =ustav  (SgN  >ots+ustav !02_A	et	f	\N
119841	kõrgemal	kõrgemal =kõrgema  (SgAd  >kõrgem !02_A	et	f	\N
119842	kõrgemal	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
119843	kõrgemal	kõrgemal =kõrgemal  (ID  >kõrgemal !41_D	et	f	\N
119844	kõrgemal	kõrgemal =ema  (SgAd  >kõrg+ema !17_S	et	f	\N
119847	otsustavam	otsustavam =otsustavam  (SgN  >otsustavam !02_A	et	f	\N
119848	otsustavam	"otsustavam %otsusta  )VAM_cA  <otsustama ;27_V	et	f	\N
119849	otsustavam	"otsustavam %otsustava  )M_cA  <otsustav ;02_A	et	f	\N
119850	otsustavam	otsustavam =ustavam  (SgN  >ots+ustavam !02_A	et	f	\N
119851	otsustavam	"ots+ustavam %ustava  )M_cA  <ots+ustav ;02_A	et	f	\N
119856	kaoma	?kaoma =kaoma  (SgN  >kaoma !16_S	et	f	\N
119857	kaoma	?kaoma =kaoma  (SgG  >kaoma !16_S	et	f	\N
119858	kaoma	?kaoma =kaoma  (IndPrPs_  >kaomama !29_V	et	f	\N
119859	kaoma	?kaoma =kaoma  (ImpPrSg2  >kaomama !29_V	et	f	\N
119875	kaasaegsem	kaasaegsem =aegsem  (SgN  >kaas+aegsem !02_A	et	f	\N
119876	kaasaegsem	"kaas+aegsem %aegse  )M_cA  <kaas+aegne ;02_A	et	f	\N
119903	kulud	kulud =kulu  (PlN  >kulu !17_S	et	f	\N
119904	kulud	kulud =kulu  (PlN  >kulg !22_S	et	f	\N
119905	kulud	kulud =kulu  (IndPrSg2  >kuluma !27_V	et	f	\N
119939	liitu	liitu =liitu  (SgN  >liitu !01_A	et	f	\N
119940	liitu	"liitu %lii  )TU2_kA  <lii ;26_S	et	f	\N
119941	liitu	liitu =liitu  (SgG  >liitu !01_A	et	f	\N
119942	liitu	liitu =liitu  (SgP  >liit !22_S	et	f	\N
119943	liitu	liitu =liitu  (SgAdt  >liit !22_S	et	f	\N
119944	liitu	liitu =liitu  (IndPrPs_  >liituma !27_V	et	f	\N
119945	liitu	liitu =liitu  (ImpPrSg2  >liituma !27_V	et	f	\N
119961	otseselt	otseselt =otsese  (SgAbl  >otsene !10_A	et	f	\N
119962	otseselt	otseselt =otseselt  (ID  >otseselt !41_D	et	f	\N
119963	otseselt	"otseselt %otsese  )LT_mD  <otsene ;10_A	et	f	\N
119969	astumist	astumist =astumis  (SgP  >astumine !12_S	et	f	\N
119970	astumist	"astumine %astu  )MINE_vS  <astuma ;28_V	et	f	\N
119973	tagasihoidlikum	tagasihoidlikum =hoidlikum  (SgN  >tagasi+hoidlikum !02_A	et	f	\N
119974	tagasihoidlikum	"tagasi+hoidlikum %hoidliku  )M_cA  <tagasi+hoidlik ;25_A	et	f	\N
119988	kellest	kellest =kelle  (SgEl  >kes !00_P	et	f	\N
119989	kellest	kellest =kelle  (PlEl  >kell !22_S	et	f	\N
119995	impeeriumimeelselt	impeeriumimeelselt =meelse  (SgAbl  >impeeriumi+meelne !02_A	et	f	\N
119996	impeeriumimeelselt	"impeeriumi+meelselt %meelse  )LT_mD  <impeeriumi+meelne ;02_A	et	f	\N
120003	uuendus	uuendus =uuendus  (SgN  >uuendus !11_S	et	f	\N
120004	uuendus	"uuendus %uuenda  )US_vS  <uuendama ;27_V	et	f	\N
120006	bürokraatia	bürokraatia =bürokraatia  (SgN  >bürokraatia !01_S	et	f	\N
120007	bürokraatia	bürokraatia =bürokraatia  (SgG  >bürokraatia !01_S	et	f	\N
120042	emotsionaalselt	emotsionaalselt =emotsionaalse  (SgAbl  >emotsionaalne !02_A	et	f	\N
120043	emotsionaalselt	emotsionaalselt =emotsionaalselt  (ID  >emotsionaalselt !41_D	et	f	\N
120044	emotsionaalselt	"emotsionaalselt %emotsionaalse  )LT_mD  <emotsionaalne ;02_A	et	f	\N
120062	sept	?sept =sept  (SgN  >sept !22_S	et	f	\N
120064	riigikogu	riigikogu =kogu  (SgN  >riigi+kogu !17_S	et	f	\N
120065	riigikogu	riigikogu =kogu  (SgG  >riigi+kogu !17_S	et	f	\N
120066	riigikogu	riigikogu =kogu  (SgP  >riigi+kogu !17_S	et	f	\N
120071	panus	panus =panu  (SgIn  >panu !17_S	et	f	\N
120072	panus	panus =panus  (SgN  >panus !09_S	et	f	\N
120079	käitumise	käitumise =käitumise  (SgG  >käitumine !12_S	et	f	\N
120080	käitumise	"käitumine %käitu  )MINE_vS  <käituma ;27_V	et	f	\N
120089	teeneks	teeneks =teene  (SgTr  >teene !06_S	et	f	\N
120090	teeneks	"teene %tee  )NE_aA  <tee ;26_S	et	f	\N
120096	uuendamine	uuendamine =uuendamine  (SgN  >uuendamine !12_S	et	f	\N
120097	uuendamine	"uuendamine %uuenda  )MINE_vS  <uuendama ;27_V	et	f	\N
120102	avalikult	avalikult =avaliku  (SgAbl  >avalik !25_A	et	f	\N
120103	avalikult	avalikult =avalikult  (ID  >avalikult !41_D	et	f	\N
120104	avalikult	"avalikult %avaliku  )LT_mD  <avalik ;25_A	et	f	\N
120110	terroreziimist	?terroreziimist =terroreziimi  (SgEl  >terroreziimi !16_S	et	f	\N
120113	terroreziimist	?terroreziimist =terroreziimi  (SgEl  >terroreziim !22_S	et	f	\N
120116	terroreziimist	?terroreziimist =terroreziimis  (SgP  >terroreziimis !09_S	et	f	\N
120117	terroreziimist	?terroreziimist =terroreziimis  (SgP  >terroreziimine !10_A	et	f	\N
120123	muutmist	muutmist =muutmis  (SgP  >muutmine !12?10_S	et	f	\N
120124	muutmist	"muutmine %muut  )MINE_vS  <muutma ;34_V	et	f	\N
120127	mõtlemise	mõtlemise =mõtlemise  (SgG  >mõtlemine !12_S	et	f	\N
120128	mõtlemise	"mõtlemine %mõtle  )MINE_vS  <mõtlema ;30_V	et	f	\N
120135	mõrenevat	?mõrenevat =mõrene  (KvtPrPs  >mõrenema !27_V	et	f	\N
119802	viljekuks	?viljekuks =viljeku  (SgTr  >viljeku !01_S	et	f	\N
119803	viljekuks	?viljekuks =viljeku  (SgTr  >viljek !02_S	et	f	\N
119804	viljekuks	?viljekuks =viljeku  (KndPrPs  >viljekuma !27_V	et	f	\N
119805	omadused	omadused =omaduse  (PlN  >omadus !11_S	et	f	\N
119806	omadused	"omadus %oma  )US_aS  <oma ;17_A	et	f	\N
119834	aita	aita =aita  (SgP  >ait !22_S	et	f	\N
119835	aita	aita =aita  (SgAdt  >ait !22_S	et	f	\N
119836	aita	aita =aita  (IndPrPs_  >aitama !29_V	et	f	\N
119837	aita	aita =aita  (ImpPrSg2  >aitama !29_V	et	f	\N
119869	vaesusesse	vaesusesse =vaesuse  (SgIll  >vaesus !11~09_S	et	f	\N
119870	vaesusesse	"vaesus %vae  )SUS_aS  <vaag ;22_S	et	f	\N
119871	vaesusesse	vaesusesse =vaesuses  (SgAdt  >vaesusene !12_A	et	f	\N
119872	vaesusesse	"vaesusene %vaesuse  )NE_aA  <vaesus ;09_S	et	f	\N
119873	vaesusesse	"vaesusene %vaesuse  )NE_aA  <vaesus ;11_S	et	f	\N
119874	vaesusesse	vaesusesse =use  (PlIll  >vaes+usk !22_S	et	f	\N
119877	gumannsem	?gumannsem =gumannsem  (SgN  >gumannsem !02_A	et	f	\N
119878	õnnestunud	õnnestunud =õnnestu  (PtsPtPs  >õnnestuma !27_V	et	f	\N
119879	õnnestunud	õnnestunud =õnnestunu  (PlN  >õnnestunu !01_S	et	f	\N
119880	õnnestunud	"õnnestunu %õnnestu  )NU_vS  <õnnestuma ;27_V	et	f	\N
119882	õnnestunud	õnnestunud =õnnestunud  (ID  >õnnestunud !41_A	et	f	\N
119884	õnnestunud	"õnnestunud %õnnestu  )NUD_vA  <õnnestuma ;27_V	et	f	\N
119893	haiglasse	haiglasse =haigla  (SgIll  >haigla !01_S	et	f	\N
119894	haiglasse	haiglasse =haiglas  (SgAdt  >haiglane !12_A	et	f	\N
119895	haiglasse	"haiglane %haigla  )NE_aA  <haigla ;01_S	et	f	\N
119916	kellegi	kellegi =kelle  (SgG  >keegi !00_P	et	f	\N
119917	kellegi	kellegi =kelle  (SgG^  >kes !00_P	et	f	\N
119918	kellegi	kellegi =kelle  (PlP^  >kell !22_S	et	f	\N
119949	loodi	loodi =loo  (IndIpfIps  >looma !38_V	et	f	\N
119950	loodi	loodi =loodi  (ID  >loodi !41_D	et	f	\N
119951	loodi	loodi =loodi  (SgG  >lood !22_S	et	f	\N
119952	loodi	loodi =loodi  (SgP  >lood !22_S	et	f	\N
119953	loodi	loodi =loodi  (SgAdt  >lood !22_S	et	f	\N
119954	loodi	loodi =loodi  (IndPrPs_  >loodima !28_V	et	f	\N
119955	loodi	loodi =loodi  (ImpPrSg2  >loodima !28_V	et	f	\N
119959	endasse	endasse =enda  (SgIll  >enda !00_P	et	f	\N
119960	endasse	endasse =enda  (SgIll  >ise !00_P	et	f	\N
119964	nõudnud	nõudnud =nõud  (PtsPtPs  >nõudma !34_V	et	f	\N
119965	nõudnud	nõudnud =nõudnu  (PlN  >nõudnu !01_S	et	f	\N
119966	nõudnud	"nõudnu %nõud  )NU_vS  <nõudma ;34_V	et	f	\N
119967	nõudnud	nõudnud =nõudnud  (ID  >nõudnud !41_A	et	f	\N
119968	nõudnud	"nõudnud %nõud  )NUD_vA  <nõudma ;34_V	et	f	\N
119971	autonoomia	autonoomia =autonoomia  (SgN  >autonoomia !01_S	et	f	\N
119972	autonoomia	autonoomia =autonoomia  (SgG  >autonoomia !01_S	et	f	\N
119978	meelestatud	meelestatud =meelesta  (PtsPtIps  >meelestama !27_V	et	f	\N
119979	meelestatud	meelestatud =meelestatu  (PlN  >meelestatu !01_S	et	f	\N
119980	meelestatud	"meelestatu %meelesta  )TU1_vS  <meelestama ;27_V	et	f	\N
119981	meelestatud	meelestatud =meelestatud  (ID  >meelestatud !41_A	et	f	\N
119982	meelestatud	"meelestatud %meelesta  )TUD_vA  <meelestama ;27_V	et	f	\N
119984	meelestatud	meelestatud =lestatu  (PlN  >mee+lestatu !01_S	et	f	\N
119986	meelestatud	"mee+lestatu %lesta  )TU2_kA  <mee+lest ;22_S	et	f	\N
120015	kokkusaamistel	kokkusaamistel =saamis  (PlAd  >kokku+saamine !12?10_S	et	f	\N
120016	kokkusaamistel	"kokku+saamine %saami  )NE_aA  <kokku+saam ;22_S	et	f	\N
120024	loojaks	loojaks =looja  (SgTr  >looja !01_S	et	f	\N
120025	loojaks	"looja %loo  )JA_vS  <looma ;38_V	et	f	\N
120026	loojaks	loojaks =jaks  (SgN  >loo+jaks !22_S	et	f	\N
120036	keelelele	?keelelele =keelelele  (PlP  >keelelel !19_S	et	f	\N
120037	keelelele	?keelelele =lele  (SgN  >keele+lele !16_S	et	f	\N
120038	keelelele	?keelelele =lele  (SgG  >keele+lele !16_S	et	f	\N
120039	keelelele	?keelelele =ele  (SgAll  >keel+ele !16_S	et	f	\N
120040	andmise	andmise =andmise  (SgG  >andmine !12?10_S	et	f	\N
120041	andmise	"andmine %and  )MINE_vS  <andma ;34_V	et	f	\N
120067	presidendi	presidendi =presidendi  (SgG  >president !22_S	et	f	\N
120068	presidendi	presidendi =sidendi  (SgG  >pre+sidend !02_S	et	f	\N
120081	hoolutletud	?hoolutletud =hoolutle  (PtsPtIps  >hoolutlema !27_V	et	f	\N
120082	hoolutletud	?hoolutletud =hoolutletu  (PlN  >hoolutletu !01_S	et	f	\N
120083	hoolutletud	?hoolutletud =hoolutletu  (IndPrSg2  >hoolutletuma !27_V	et	f	\N
120084	hoolutletud	?hoolutletud =hoolutletud  (ID  >hoolutletud !41_A	et	f	\N
120085	hoolutletud	?hoolutletud =lutletu  (PlN  >hoo+lutletu !01_A	et	f	\N
120100	mihhail	?mihhail =mihhai  (SgAd  >mihhai !26_S	et	f	\N
120101	mihhail	?mihhail =mihhail  (SgN  >mihhail !22_S	et	f	\N
120105	staali	?staali =staali  (SgN  >staali !16_S	et	f	\N
120106	staali	?staali =staali  (SgG  >staali !16_S	et	f	\N
120107	staali	?staali =staali  (SgG  >staal !22_S	et	f	\N
120108	staali	?staali =staali  (SgP  >staal !22_S	et	f	\N
120109	staali	?staali =staali  (SgAdt  >staal !22_S	et	f	\N
120112	staali	?staali =staali  (IndPrPs_  >staalima !28_V	et	f	\N
120115	staali	?staali =staali  (ImpPrSg2  >staalima !28_V	et	f	\N
120150	ensv	?ensv =ensv  (SgN  >ensv !22_S	et	f	\N
119831	isesesvumisprotsessis	?isesesvumisprotsessis =isesesvumisprotsessis  (SgN  >isesesvumisprotsessis !09_S	et	f	\N
119832	isesesvumisprotsessis	?isesesvumisprotsessis =sesvumisprotsessi  (SgIn  >ise+sesvumisprotsess !22_S	et	f	\N
119833	isesesvumisprotsessis	?isesesvumisprotsessis =sesvumisprotsessis  (SgN  >ise+sesvumisprotsessis !09_S	et	f	\N
119838	ülevalt	ülevalt =üleva  (SgAbl  >ülev !02_A	et	f	\N
119839	ülevalt	ülevalt =ülevalt  (ID  >ülevalt !41_D	et	f	\N
119840	ülevalt	"ülevalt %üleva  )LT_mD  <ülev ;02_A	et	f	\N
119853	pidavat	pidavat =pida  (KvtPrPs  >pida !40_V	et	f	\N
119854	pidavat	pidavat =pida  (KvtPrPs  >pidama !28_V	et	f	\N
119855	pidavat	pidavat =pidava  (SgP  >pidav !02_A	et	f	\N
119860	pidavat	"pidav %pida  )V_vA  <pidama ;28_V	et	f	\N
119914	külmkappi	külmkappi =kappi  (SgP  >külm+kapp !22_S	et	f	\N
119915	külmkappi	külmkappi =kappi  (SgAdt  >külm+kapp !22_S	et	f	\N
119919	käest	käest =käe  (SgEl  >käsi !15_S	et	f	\N
119920	käest	käest =käes  (SgP  >käene !10_A	et	f	\N
119921	käest	"käene %käe  )NE_aA  <käsi ;15_S	et	f	\N
119922	käest	käest =käest  (ID  >käest !41_DK	et	f	\N
119925	ostmiseks	ostmiseks =ostmise  (SgTr  >ostmine !12?10_S	et	f	\N
119926	ostmiseks	"ostmine %ost  )MINE_vS  <ostma ;34_V	et	f	\N
119927	parema	parema =parema  (SgG  >parem !02_A	et	f	\N
119928	parema	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
119929	muutunud	muutunud =muutu  (PtsPtPs  >muutuma !27_V	et	f	\N
119930	muutunud	muutunud =muutunu  (PlN  >muutunu !01_S	et	f	\N
119931	muutunud	"muutunu %muutu  )NU_vS  <muutuma ;27_V	et	f	\N
119932	muutunud	muutunud =muutunud  (ID  >muutunud !41_A	et	f	\N
119933	muutunud	"muutunud %muutu  )NUD_vA  <muutuma ;27_V	et	f	\N
119936	töökohti	töökohti =kohti  (SgP  >töö+koht !22_S	et	f	\N
119937	töökohti	töökohti =kohti  (SgAdt  >töö+koht !22_S	et	f	\N
119938	töökohti	töökohti =kohti  (PlP  >töö+koht !22_S	et	f	\N
119956	tõusis	tõusis =tõus  (IndIpfSg3  >tõusma !32_V	et	f	\N
119957	tõusis	tõusis =tõusi  (SgIn  >tõus !22_S	et	f	\N
119999	koosnevale	koosnevale =koosneva  (SgAll  >koosnev !02_A	et	f	\N
120001	koosnevale	"koosnev %koosne  )V_vA  <koosnema ;27_V	et	f	\N
120005	lodvik	?lodvik =lodvik  (SgN  >lodvik !02_S	et	f	\N
120020	laulvaks	laulvaks =laulva  (SgTr  >laulev !02_A	et	f	\N
120021	laulvaks	"laulev %laul  )V_vA  <laulma ;33_V	et	f	\N
120031	nõudmised	nõudmised =nõudmise  (PlN  >nõudmine !12?10_S	et	f	\N
120034	nõudmised	"nõudmine %nõud  )MINE_vS  <nõudma ;34_V	et	f	\N
120069	valimistel	valimistel =valimis  (PlAd  >valimine !12_S	et	f	\N
120070	valimistel	"valimine %vali  )MINE_vS  <valima ;27_V	et	f	\N
120076	hindasid	hindasid =hinda  (PlP  >hind !22_S	et	f	\N
120077	hindasid	hindasid =hinda  (IndIpfSg2  >hindama !29_V	et	f	\N
120078	hindasid	hindasid =hinda  (IndIpfPl3  >hindama !29_V	et	f	\N
120086	shokegija	?shokegija =shokegija  (SgN  >shokegija !01_S	et	f	\N
120087	shokegija	?shokegija =shokegija  (SgG  >shokegija !01_S	et	f	\N
120088	shokegija	?shokegija =shokegija  (SgG  >shokegijas !02_A	et	f	\N
120121	liberaalsemaks	liberaalsemaks =liberaalsema  (SgTr  >liberaalsem !02_A	et	f	\N
120122	liberaalsemaks	"liberaalsem %liberaalse  )M_cA  <liberaalne ;02_A	et	f	\N
120129	kõiki	kõiki =kõiki  (PlP  >kõik !00_P	et	f	\N
120130	kõiki	kõiki =kõiki  (SgP  >kõik !22_S	et	f	\N
120131	kõiki	kõiki =kõiki  (SgAdt  >kõik !22_S	et	f	\N
120141	süvenenud	süvenenud =süvene  (PtsPtPs  >süvenema !27_V	et	f	\N
120142	süvenenud	süvenenud =süvenenu  (PlN  >süvenenu !01_S	et	f	\N
120143	süvenenud	"süvenenu %süvene  )NU_vS  <süvenema ;27_V	et	f	\N
120144	süvenenud	süvenenud =süvenenud  (ID  >süvenenud !41_A	et	f	\N
120145	süvenenud	"süvenenud %süvene  )NUD_vA  <süvenema ;27_V	et	f	\N
120146	ksoteh	?ksoteh =ksoteh  (ID  >ksoteh !41_I	et	f	\N
120155	katkestatud	katkestatud =katkesta  (PtsPtIps  >katkestama !27_V	et	f	\N
120156	katkestatud	katkestatud =katkestatu  (PlN  >katkestatu !01_S	et	f	\N
120157	katkestatud	"katkestatu %katkesta  )TU1_vS  <katkestama ;27_V	et	f	\N
120158	katkestatud	katkestatud =katkestatud  (ID  >katkestatud !41_A	et	f	\N
120159	katkestatud	"katkestatud %katkesta  )TUD_vA  <katkestama ;27_V	et	f	\N
120174	tollajal	?tollajal =tollaja  (SgAd  >tollaja !01_S	et	f	\N
120175	tollajal	?tollajal =tollaja  (SgAd  >tollajas !02_A	et	f	\N
120176	tollajal	?tollajal =tollajal  (SgN  >tollajal !19_S	et	f	\N
120192	kõrgeim	kõrgeim =kõrgeim  (SgN  >kõrgeim !02_A	et	f	\N
120193	kõrgeim	"kõrgeim %kõrge  )IM_sA  <kõrge ;01_A	et	f	\N
120199	maksustamine	maksustamine =maksustamine  (SgN  >maksustamine !12_S	et	f	\N
120200	maksustamine	"maksustamine %maksusta  )MINE_vS  <maksustama ;27_V	et	f	\N
120205	otsustamine	otsustamine =otsustamine  (SgN  >otsustamine !12_S	et	f	\N
120207	otsustamine	"otsustamine %otsusta  )MINE_vS  <otsustama ;27_V	et	f	\N
120228	tilkima	?tilkima =tilki  (Sup  >tilkima !28_V	et	f	\N
120229	tilkima	?tilkima =tilkima  (SgG  >tilkim !02_A	et	f	\N
120242	suvist	suvist =suvis  (SgP  >suvine !10_A	et	f	\N
120243	suvist	"suvine %suvi  )NE_aA  <suvi ;20_S	et	f	\N
120244	külla	külla =külla  (SgG  >küll !22_S	et	f	\N
120245	külla	külla =külla  (SgP  >küll !22_S	et	f	\N
120011	toimuvatest	toimuvatest =toimuva  (PlEl  >toimuv !02_A	et	f	\N
120012	toimuvatest	"toimuv %toimu  )V_vA  <toimuma ;27_V	et	f	\N
120017	isamaalisi	isamaalisi =maalisi  (PlP  >isa+maaline !12_A	et	f	\N
120018	isamaalisi	"isa+maaline %maa  )LINE_aA  <isa+maa ;26_S	et	f	\N
120019	isamaalisi	"isa+maaline %maali  )NE_aA  <isa+maal ;22_S	et	f	\N
120023	läbisuruda	?läbisuruda =läbisuru  (Inf  >läbisuruma !27_V	et	f	\N
120030	kodakondsusest	kodakondsusest =kodakondsuse  (SgEl  >kodakondsus !11~09_S	et	f	\N
120032	kodakondsusest	kodakondsusest =kodakondsuses  (SgP  >kodakondsusene !12_A	et	f	\N
120033	kodakondsusest	"kodakondsusene %kodakondsuse  )NE_aA  <kodakondsus ;09_S	et	f	\N
120035	kodakondsusest	"kodakondsusene %kodakondsuse  )NE_aA  <kodakondsus ;11_S	et	f	\N
120045	läbimõeldud	läbimõeldud =mõel  (PtsPtIps  >läbi+_mõtlema !30_V	et	f	\N
120047	läbimõeldud	läbimõeldud =mõeldu  (PlN  >läbi+mõeldu !01_S	et	f	\N
120049	rühmitustest	rühmitustest =rühmitus  (PlEl  >rühmitus !11_S	et	f	\N
120050	rühmitustest	"rühmitus %rühmita  )US_vS  <rühmitama ;27_V	et	f	\N
120051	rühmitustest	"rühmitus %rühmi  )TUS2_aS  <rühm ;22_S	et	f	\N
120055	võtnud	võtnud =võt  (PtsPtPs  >võtma !35_V	et	f	\N
120056	võtnud	võtnud =võtnu  (PlN  >võtnu !01_S	et	f	\N
120057	võtnud	"võtnu %võt  )NU_vS  <võtma ;35_V	et	f	\N
120058	võtnud	võtnud =võtnud  (ID  >võtnud !41_A	et	f	\N
120059	võtnud	"võtnud %võt  )NUD_vA  <võtma ;35_V	et	f	\N
120060	valimistest	valimistest =valimis  (PlEl  >valimine !12_S	et	f	\N
120061	valimistest	"valimine %vali  )MINE_vS  <valima ;27_V	et	f	\N
120063	valimistest	valimistest =test  (SgN  >valimis+test !22_S	et	f	\N
120111	küüsitamistest	küüsitamistest =küüsitamis  (PlEl  >küüsitamine !12_S	et	f	\N
120114	küüsitamistest	"küüsitamine %küüsita  )MINE_vS  <küüsitama ;27_V	et	f	\N
120125	lähedasemaks	lähedasemaks =lähedasema  (SgTr  >lähedasem !02_A	et	f	\N
120126	lähedasemaks	"lähedasem %lähedase  )M_cA  <lähedane ;12_AS	et	f	\N
120132	pankrotistuvat	pankrotistuvat =pankrotistu  (KvtPrPs  >pankrotistuma !27_V	et	f	\N
120133	pankrotistuvat	pankrotistuvat =pankrotistuva  (SgP  >pankrotistuv !02_A	et	f	\N
120134	pankrotistuvat	"pankrotistuv %pankrotistu  )V_vA  <pankrotistuma ;27_V	et	f	\N
120138	päästa	päästa =pääst  (Inf  >päästma !34_V	et	f	\N
120139	päästa	päästa =päästa  (IndPrPs_  >päästma !34_V	et	f	\N
120140	päästa	päästa =päästa  (ImpPrSg2  >päästma !34_V	et	f	\N
120148	käivaid	käivaid =käiva  (PlP  >käiv !02_A	et	f	\N
120149	käivaid	"käiv %käi  )V_vA  <käima ;38_V	et	f	\N
120165	neljaks	neljaks =nelja  (SgTr  >neljas !02_O	et	f	\N
120166	neljaks	neljaks =nelja  (SgTr  >neli !24_N	et	f	\N
120170	viirumaa	?viirumaa =viirumaa  (SgN  >viirumaa !26_S	et	f	\N
120171	viirumaa	?viirumaa =viirumaa  (SgG  >viirumaa !26_S	et	f	\N
120172	viirumaa	?viirumaa =umaa  (SgN  >viir+umaa !26_S	et	f	\N
120173	viirumaa	?viirumaa =umaa  (SgG  >viir+umaa !26_S	et	f	\N
120218	lihtkäistöölised	?lihtkäistöölised =lihtkäistöölise  (PlN  >lihtkäistööline !12?10_A	et	f	\N
120219	lihtkäistöölised	?lihtkäistöölised =käistöölise  (PlN  >liht+käistööline !12?10_A	et	f	\N
120220	nadu	nadu =nadu  (SgN  >nadu !18_S	et	f	\N
120221	nadu	nadu =nadu  (SgP  >nadu !18_S	et	f	\N
120225	jumalasõna	jumalasõna =sõna  (SgN  >jumala+sõna !17_S	et	f	\N
120226	jumalasõna	jumalasõna =sõna  (SgG  >jumala+sõna !17_S	et	f	\N
120227	jumalasõna	jumalasõna =sõna  (SgP  >jumala+sõna !17_S	et	f	\N
120248	tahtmist	tahtmist =tahtmis  (SgP  >tahtmine !12?10_S	et	f	\N
120249	tahtmist	"tahtmine %taht  )MINE_vS  <tahtma ;34_V	et	f	\N
120255	kõigil	kõigil =kõigi  (PlAd  >kõik !00_P	et	f	\N
120256	kõigil	kõigil =kõigi  (SgAd  >kõik !22_S	et	f	\N
120257	naiselikumaks	naiselikumaks =naiselikuma  (SgTr  >naiselikum !02_A	et	f	\N
120258	naiselikumaks	"naiselikum %naiseliku  )M_cA  <naiselik ;25_A	et	f	\N
120270	puhkamisega	puhkamisega =puhkamise  (SgKom  >puhkamine !12_S	et	f	\N
120271	puhkamisega	"puhkamine %puhka  )MINE_vS  <puhkama ;29_V	et	f	\N
120272	maagiliseks	maagiliseks =maagilise  (SgTr  >maagiline !12_A	et	f	\N
120273	maagiliseks	"maagiline %maagi  )LINE_aA  <maag ;22_S	et	f	\N
120274	maagiliseks	"maagiline %maagi  )LINE_aA  <maak ;22_S	et	f	\N
120300	aparaatiks	?aparaatiks =aparaati  (SgTr  >aparaati !16_S	et	f	\N
120301	valmistamise	valmistamise =valmistamise  (SgG  >valmistamine !12_S	et	f	\N
120302	valmistamise	"valmistamine %valmista  )MINE_vS  <valmistama ;27_V	et	f	\N
120303	söömise	söömise =söömise  (SgG  >söömine !12?10_S	et	f	\N
120304	söömise	"söömine %söö  )MINE_vS  <sööma ;38_V	et	f	\N
120305	söömise	"söömine %söömi  )NE_aA  <sööm ;22_S	et	f	\N
120320	külga	?külga =külga  (SgN  >külga !16_S	et	f	\N
120321	külga	?külga =külga  (SgG  >külga !16_S	et	f	\N
120322	külga	?külga =külga  (IndPrPs_  >külgama !29_V	et	f	\N
120323	külga	?külga =külga  (ImpPrSg2  >külgama !29_V	et	f	\N
120330	tekkimist	tekkimist =tekkimis  (SgP  >tekkimine !12_S	et	f	\N
120331	tekkimist	"tekkimine %tekki  )MINE_vS  <tekkima ;27_V	et	f	\N
120334	tekkimist	"tekkimine %tekki  )MINE_vS  <tekkima ;28_V	et	f	\N
120356	19102005br	### 19102005br	et	f	\N
120362	tungmise	?tungmise =tungmise  (SgG  >tungmine !12?10_A	et	f	\N
120119	sõnavabadust	sõnavabadust =vabadus  (SgP  >sõna+vabadus !11_S	et	f	\N
120120	sõnavabadust	"sõna+vabadus %vaba  )US_aS  <sõna+vaba ;17_A	et	f	\N
120147	glasnostiga	?glasnostiga =glasnosti  (SgKom  >glasnosti !01_S	et	f	\N
120177	tuhat	tuhat =tuhat  (SgP  >tuhat !02_N	et	f	\N
120178	tuhat	tuhat =tuhat  (SgN  >tuhat !02_N	et	f	\N
120188	hansa	hansa =hansa  (SgN  >hansa !16_S	et	f	\N
120189	hansa	hansa =hansa  (SgG  >hansa !16_S	et	f	\N
120190	valitsusega	valitsusega =valitsuse  (SgKom  >valitsus !11_S	et	f	\N
120191	valitsusega	"valitsus %valitse  )US_vS  <valitsema ;27_V	et	f	\N
120196	magistraati	magistraati =magistraati  (SgP  >magistraat !22_S	et	f	\N
120197	magistraati	magistraati =magistraati  (SgAdt  >magistraat !22_S	et	f	\N
120198	ülesanned	### ülesanned	et	f	\N
120201	kohtu	kohtu =kohtu  (SgG  >kohus !05_S	et	f	\N
120202	kohtu	kohtu =kohtu  (IndPrPs_  >kohtuma !27_V	et	f	\N
120203	kohtu	kohtu =kohtu  (ImpPrSg2  >kohtuma !27_V	et	f	\N
120204	pidamine	pidamine =pidamine  (SgN  >pidamine !12_S	et	f	\N
120206	pidamine	"pidamine %pida  )MINE_vS  <pidama ;28_V	et	f	\N
120208	koondasid	koondasid =koonda  (IndIpfSg2  >koondama !27_V	et	f	\N
120209	koondasid	koondasid =koonda  (IndIpfPl3  >koondama !27_V	et	f	\N
120224	murred	?murred =murre  (IndPrSg2  >murrema !27_V	et	f	\N
120236	aktsenti	aktsenti =aktsenti  (SgP  >aktsent !22_S	et	f	\N
120237	aktsenti	aktsenti =aktsenti  (SgAdt  >aktsent !22_S	et	f	\N
120240	nõuetega	nõuetega =nõue  (PlKom  >nõue !06_S	et	f	\N
120241	nõuetega	nõuetega =e  (PlKom  >nõu+esi !15_S	et	f	\N
120261	kaunimaks	kaunimaks =kaunima  (SgTr  >kaunim !02_A	et	f	\N
120262	kaunimaks	"kaunim %kauni  )M_cA  <kaunis ;05_A	et	f	\N
120263	kaunimaks	"kaunim %kauni  )M_cA  <kaunis ;07_A	et	f	\N
120264	kaunimaks	kaunimaks =maks  (SgN  >kauni+maks !22_S	et	f	\N
120288	ramatutega	?ramatutega =ramatu  (PlKom  >ramatu !01_A	et	f	\N
120299	maagiliks	?maagiliks =gili  (SgTr  >maa+gili !17_S	et	f	\N
120315	väikestega	väikestega =väikes  (PlKom  >väike !12?10_A	et	f	\N
120316	väikestega	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
120317	väikestega	väikestega =väikes  (PlKom  >väikene !12?10_A	et	f	\N
120318	väikestega	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
120319	väikestega	väikestega =keste  (SgKom  >väi+keste !06_S	et	f	\N
120332	sportides	sportides =sporti  (PlIn  >sport !22_S	et	f	\N
120333	sportides	sportides =sporti  (Ger  >sportima !28_V	et	f	\N
120344	kõikidega	kõikidega =kõiki  (PlKom  >kõik !00_P	et	f	\N
120345	kõikidega	kõikidega =kõiki  (PlKom  >kõik !22_S	et	f	\N
120346	naiselikumateks	naiselikumateks =naiselikuma  (PlTr  >naiselikum !02_A	et	f	\N
120347	naiselikumateks	"naiselikum %naiseliku  )M_cA  <naiselik ;25_A	et	f	\N
120354	n	### n	et	f	\N
120364	fakti	fakti =fakti  (SgG  >fakt !22_S	et	f	\N
120365	fakti	fakti =fakti  (SgP  >fakt !22_S	et	f	\N
120366	fakti	fakti =fakti  (SgAdt  >fakt !22_S	et	f	\N
120376	valvapostil	?valvapostil =valvapostil  (SgN  >valvapostil !02_S	et	f	\N
120382	ringkäiku	ringkäiku =käiku  (SgP  >ring+käik !22_S	et	f	\N
120383	ringkäiku	ringkäiku =käiku  (SgAdt  >ring+käik !22_S	et	f	\N
120389	ringkäikuid	?ringkäikuid =ringkäiku  (PlP  >ringkäiku !01_S	et	f	\N
120392	ringkäikuid	?ringkäikuid =ringkäikui  (PlN  >ringkäikui !26_S	et	f	\N
120393	ringkäikuid	?ringkäikuid =ringkäikui  (SgP  >ringkäikui !26_S	et	f	\N
120394	ringkäikuid	?ringkäikuid =käikui  (PlN  >ring+käikui !26_S	et	f	\N
120395	ringkäikuid	?ringkäikuid =käikui  (SgP  >ring+käikui !26_S	et	f	\N
120396	ringkäikuid	?ringkäikuid =käikuid  (SgN  >ring+käikuid !22_S	et	f	\N
120413	järjekorse	?järjekorse =järjekorse  (SgG  >järjekorne !02_A	et	f	\N
120414	järjekorse	?järjekorse =järjekorse  (PlP  >järjekors !22_S	et	f	\N
120415	järjekorse	?järjekorse =korse  (SgN  >järje+korse !06_S	et	f	\N
120416	järjekorse	?järjekorse =korse  (PlP  >järje+kors !22_S	et	f	\N
120434	juhtunust	juhtunust =juhtunu  (SgEl  >juhtunu !01_S	et	f	\N
120435	juhtunust	"juhtunu %juhtu  )NU_vS  <juhtuma ;27_V	et	f	\N
120446	silmestasid	?silmestasid =silmesta  (IndIpfSg2  >silmestama !27_V	et	f	\N
120448	silmestasid	?silmestasid =silmesta  (IndIpfPl3  >silmestama !27_V	et	f	\N
120450	silmestasid	?silmestasid =esta  (PlP  >silm+esta !16_S	et	f	\N
120475	kasvu	kasvu =kasvu  (SgG  >kasv !22_S	et	f	\N
120477	kasvu	kasvu =kasvu  (SgP  >kasv !22_S	et	f	\N
120478	kasvu	kasvu =kasvu  (SgAdt  >kasv !22_S	et	f	\N
120479	rides	?rides =ride  (SgIn  >ride !16_S	et	f	\N
120480	rides	?rides =ride  (IndIpfSg3  >ridema !27_V	et	f	\N
120481	rides	?rides =rides  (SgN  >rides !09_S	et	f	\N
120487	tundumatu	tundumatu =tundumatu  (SgN  >tundumatu !01_A	et	f	\N
120488	tundumatu	"tundumatu %tundu  )MATU_vA  <tunduma ;27_V	et	f	\N
120489	tundumatu	tundumatu =tundumatu  (SgG  >tundumatu !01_A	et	f	\N
120493	kontori	kontori =kontori  (SgG  >kontor !02_S	et	f	\N
120494	kontori	kontori =ori  (SgN  >kont+ori !24_S	et	f	\N
120505	perimetril	?perimetril =perimetri  (SgAd  >perimetter !02_S	et	f	\N
120506	perimetril	?perimetril =perimetril  (SgN  >perimetril !02_S	et	f	\N
120511	turvalisuse	turvalisuse =turvalisuse  (SgG  >turvalisus !11?09_S	et	f	\N
120136	mõrenevat	?mõrenevat =mõreneva  (SgP  >mõrenev !02_A	et	f	\N
120137	mõrenevat	?mõrenevat =mõreneva  (SgP  >mõreneva !16_S	et	f	\N
120153	suud	suud =suu  (PlN  >suu !26_S	et	f	\N
120154	suud	suud =suu  (SgP  >suu !26_S	et	f	\N
120160	ristisõda	ristisõda =sõda  (SgN  >risti+sõda !18_S	et	f	\N
120162	ristisõda	ristisõda =sõda  (SgP  >risti+sõda !18_S	et	f	\N
120167	keskosa	keskosa =osa  (SgN  >kesk+osa !17_S	et	f	\N
120168	keskosa	keskosa =osa  (SgG  >kesk+osa !17_S	et	f	\N
120169	keskosa	keskosa =osa  (SgP  >kesk+osa !17_S	et	f	\N
120179	tuh	?tuh =tuh  (ID  >tuh !41_I	et	f	\N
120186	uus-pärnu	uus-pärnu =pärnu  (SgN  >uus-pärnu !01_H	et	f	\N
120187	uus-pärnu	uus-pärnu =pärnu  (SgG  >uus-pärnu !01_H	et	f	\N
120215	pagarad	?pagarad =pagara  (PlN  >pagara !01_S	et	f	\N
120216	linnaselavad	linnaselavad =lava  (PlN  >linn+ase+lava !17_S	et	f	\N
120217	linnaselavad	linnaselavad =elava  (PlN  >linnas+elav !02_A	et	f	\N
120222	korralduse	korralduse =korralduse  (SgG  >korraldus !11_S	et	f	\N
120223	korralduse	"korraldus %korralda  )US_vS  <korraldama ;27_V	et	f	\N
120230	alatud	alatud =ala  (PtsPtIps  >algama !29_V	et	f	\N
120231	alatud	alatud =alatu  (PlN  >alatu !01_AS	et	f	\N
120232	alatud	"alatu %ala  )TU1_vS  <algama ;29_V	et	f	\N
120233	alatud	"alatu %ala  )TU2_kA  <ala ;17_S	et	f	\N
120234	alatud	alatud =alatud  (ID  >alatud !41_A	et	f	\N
120235	alatud	"alatud %ala  )TUD_vA  <algama ;29_V	et	f	\N
120238	tohti	tohti =tohti  (SgP  >toht !22_S	et	f	\N
120239	tohti	tohti =tohti  (SgAdt  >toht !22_S	et	f	\N
120250	salvis	salvis =salvi  (SgIn  >salv !22_S	et	f	\N
120251	salvis	salvis =salvi  (PlIn  >salv !22_S	et	f	\N
120252	salvis	salvis =salvi  (IndIpfSg3  >salvima !28_V	et	f	\N
120275	vaatamisaega	vaatamisaega =aega  (SgP  >vaatamis+aeg !22_S	et	f	\N
120276	vaatamisaega	vaatamisaega =aega  (SgAdt  >vaatamis+aeg !22_S	et	f	\N
120277	oloevad	?oloevad =oloeva  (PlN  >oloeva !01_S	et	f	\N
120292	soovitamatu	soovitamatu =soovitamatu  (SgN  >soovitamatu !01_A	et	f	\N
120293	soovitamatu	"soovitamatu %soovi  )TAMATU_vA  <soovima ;28_V	et	f	\N
120294	soovitamatu	"soovitamatu %soovita  )MATU_vA  <soovitama ;27_V	et	f	\N
120295	soovitamatu	soovitamatu =soovitamatu  (SgG  >soovitamatu !01_A	et	f	\N
120324	külmatamisest	?külmatamisest =külmatamise  (SgEl  >külmatamine !12_S	et	f	\N
120325	külmatamisest	?külmatamisest =tamise  (SgEl  >külma+tamine !10_A	et	f	\N
120326	külmatamisest	?külmatamisest =atamise  (SgEl  >külm+atamine !12_S	et	f	\N
120350	kiirete	kiirete =kiire  (PlG  >kiire !01_A	et	f	\N
120351	kiirete	kiirete =kiire  (PlG  >kiire !06_S	et	f	\N
120352	kiirete	kiirete =kiire  (PlG  >kiire !06_AS	et	f	\N
120353	kiirete	kiirete =e  (PlG  >kiir+esi !15_S	et	f	\N
120358	territoriumil	?territoriumil =territoriumi  (SgAd  >territoriumi !16_S	et	f	\N
120360	territoriumil	?territoriumil =territoriumi  (SgAd  >territorium !19_S	et	f	\N
120361	territoriumil	?territoriumil =territoriumil  (SgN  >territoriumil !02_S	et	f	\N
120368	meiega	meiega =meie  (PlKom  >mina !00_P	et	f	\N
120369	meiega	meiega =meie  (SgKom  >meie !16_S	et	f	\N
120379	territoriumi	?territoriumi =territoriumi  (SgN  >territoriumi !16_S	et	f	\N
120380	territoriumi	?territoriumi =territoriumi  (SgG  >territoriumi !16_S	et	f	\N
120381	territoriumi	?territoriumi =territoriumi  (SgG  >territorium !19_S	et	f	\N
120384	territoriumi	?territoriumi =territoriumi  (SgP  >territorium !19_S	et	f	\N
120385	territoriumi	?territoriumi =territoriumi  (SgAdt  >territorium !19_S	et	f	\N
120386	territoriumi	?territoriumi =territoriumi  (IndPrPs_  >territoriumima !28_V	et	f	\N
120387	territoriumi	?territoriumi =territoriumi  (ImpPrSg2  >territoriumima !28_V	et	f	\N
120388	tagantjärale	?tagantjärale =tagantjära  (SgAll  >tagantjära !16_S	et	f	\N
120390	tagantjärale	?tagantjärale =tagantjärale  (PlP  >tagantjäral !19_S	et	f	\N
120391	tagantjärale	?tagantjärale =jära  (SgAll  >tagant+jära !17_S	et	f	\N
120397	kohaseltbr	### kohaseltbr	et	f	\N
120410	ümbermõõtul	?ümbermõõtul =ümbermõõtul  (SgN  >ümbermõõtul !02_S	et	f	\N
120411	ümbermõõtul	?ümbermõõtul =mõõtu  (SgAd  >ümber+mõõtu !01_A	et	f	\N
120412	ümbermõõtul	?ümbermõõtul =mõõtul  (SgN  >ümber+mõõtul !02_S	et	f	\N
120426	putkas	putkas =putka  (SgIn  >putka !16_S	et	f	\N
120427	putkas	putkas =putka  (IndIpfSg3  >putkama !29_V	et	f	\N
120428	rohlat	?rohlat =rohla  (SgP  >rohla !16_S	et	f	\N
120429	rohlat	?rohlat =rohlat  (SgN  >rohlat !02_S	et	f	\N
120430	varjus	varjus =varju  (SgIn  >vari !24_S	et	f	\N
120431	varjus	varjus =varju  (PlIn  >vari !24_S	et	f	\N
120432	varjus	varjus =varju  (IndIpfSg3  >varjuma !27_V	et	f	\N
120433	varjus	varjus =varjus  (ID  >varjus !41_K	et	f	\N
120471	territorium	?territorium =territorium  (SgN  >territorium !19_S	et	f	\N
120472	kuuritegija	kuuritegija =tegija  (SgN  >kuuri+tegija !01_S	et	f	\N
120473	kuuritegija	kuuritegija =tegija  (SgG  >kuuri+tegija !01_S	et	f	\N
120495	vahetuse	vahetuse =vahetuse  (SgG  >vahetus !11_S	et	f	\N
120496	vahetuse	"vahetus %vaheta  )US_vS  <vahetama ;27_V	et	f	\N
120497	vahetuse	"vahetus %vahe  )TUS2_aS  <vahe ;16_S	et	f	\N
120550	qni	### qni	et	f	\N
120577	ou	?ou =ou  (SgN  >ou !26_S	et	f	\N
120151	protsessid	protsessid =protsessi  (PlN  >protsess !22_S	et	f	\N
120152	protsessid	protsessid =protsessi  (IndPrSg2  >protsessima !28_V	et	f	\N
120161	mõjus	mõjus =mõju  (SgIn  >mõju !17_S	et	f	\N
120163	mõjus	mõjus =mõju  (IndIpfSg3  >mõjuma !27_V	et	f	\N
120164	mõjus	mõjus =mõjus  (SgN  >mõjus !02_A	et	f	\N
120180	viljandi	?viljandi =viljandi  (SgN  >viljandi !01_S	et	f	\N
120181	viljandi	?viljandi =viljandi  (SgG  >viljandi !01_S	et	f	\N
120182	viljandi	?viljandi =viljandi  (SgG  >viljand !02_S	et	f	\N
120183	viljandi	?viljandi =viljandi  (SgG  >viljant !22_S	et	f	\N
120184	viljandi	?viljandi =viljandi  (IndPrPs_  >viljantima !28_V	et	f	\N
120185	viljandi	?viljandi =viljandi  (ImpPrSg2  >viljantima !28_V	et	f	\N
120194	road	road =roa  (PlN  >ruga !18_S	et	f	\N
120195	road	road =roa  (PlN  >roog !22_S	et	f	\N
120210	organiseeritud	organiseeritud =organiseeri  (PtsPtIps  >organiseerima !28_V	et	f	\N
120211	organiseeritud	organiseeritud =organiseeritu  (PlN  >organiseeritu !01_S	et	f	\N
120212	organiseeritud	"organiseeritu %organiseeri  )TU1_vS  <organiseerima ;28_V	et	f	\N
120213	organiseeritud	organiseeritud =organiseeritud  (ID  >organiseeritud !41_A	et	f	\N
120214	organiseeritud	"organiseeritud %organiseeri  )TUD_vA  <organiseerima ;28_V	et	f	\N
120282	salvetud	salvetud =salvetu  (PlN  >salvetu !01_A	et	f	\N
120283	salvetud	"salvetu %salve  )TU2_kA  <salv ;22_S	et	f	\N
120289	parases	?parases =parase  (SgIn  >parane !10_A	et	f	\N
120290	koguses	koguses =koguse  (SgIn  >kogus !09_S	et	f	\N
120291	koguses	koguses =koguse  (SgIn  >kogus !02_A	et	f	\N
120311	töökta	?töökta =töökta  (SgN  >töökta !01_S	et	f	\N
120312	töökta	?töökta =töökta  (SgG  >töökta !01_S	et	f	\N
120313	töökta	?töökta =töökta  (IndPrPs_  >tööktama !29_V	et	f	\N
120314	töökta	?töökta =töökta  (ImpPrSg2  >tööktama !29_V	et	f	\N
120337	suvise	suvise =suvise  (SgG  >suvine !10_A	et	f	\N
120338	suvise	"suvine %suvi  )NE_aA  <suvi ;20_S	et	f	\N
120339	mahlakamalt	mahlakamalt =mahlakama  (SgAbl  >mahlakam !02_A	et	f	\N
120340	mahlakamalt	"mahlakam %mahlaka  )M_cA  <mahlakas ;02_A	et	f	\N
120341	mahlakamalt	mahlakamalt =mahlakamalt  (ID  >mahlakamalt !41_D	et	f	\N
120342	mahlakamalt	"mahlakamalt %mahlaka  )MALT_mD  <mahlakas ;02_A	et	f	\N
120343	mahlakamalt	mahlakamalt =kama  (SgAbl  >mahla+kama !17_S	et	f	\N
120355	valdbr	?valdbr =valdbr  (SgN  >valdbr !22_S	et	f	\N
120370	tuvastatud	tuvastatud =tuvasta  (PtsPtIps  >tuvastama !27_V	et	f	\N
120372	tuvastatud	tuvastatud =tuvastatu  (PlN  >tuvastatu !01_S	et	f	\N
120373	tuvastatud	"tuvastatu %tuvasta  )TU1_vS  <tuvastama ;27_V	et	f	\N
120374	tuvastatud	tuvastatud =tuvastatud  (ID  >tuvastatud !41_A	et	f	\N
120375	tuvastatud	"tuvastatud %tuvasta  )TUD_vA  <tuvastama ;27_V	et	f	\N
120417	märkinud	märkinud =märki  (PtsPtPs  >märkima !28_V	et	f	\N
120418	märkinud	märkinud =märkinu  (PlN  >märkinu !01_S	et	f	\N
120420	märkinud	"märkinu %märki  )NU_vS  <märkima ;28_V	et	f	\N
120422	märkinud	märkinud =märkinud  (ID  >märkinud !41_A	et	f	\N
120424	märkinud	"märkinud %märki  )NUD_vA  <märkima ;28_V	et	f	\N
120455	avastasid	avastasid =avasta  (IndIpfSg2  >avastama !27_V	et	f	\N
120456	avastasid	avastasid =avasta  (IndIpfPl3  >avastama !27_V	et	f	\N
120459	ava	ava =ava  (SgN  >ava !17_S	et	f	\N
120460	ava	ava =ava  (SgG  >ava !17_S	et	f	\N
120461	ava	ava =ava  (SgP  >ava !17_S	et	f	\N
120462	ava	ava =ava  (IndPrPs_  >avama !27_V	et	f	\N
120463	ava	ava =ava  (ImpPrSg2  >avama !27_V	et	f	\N
120465	silmistas	?silmistas =silmista  (SgIn  >silmista !01_S	et	f	\N
120466	silmistas	?silmistas =silmista  (IndIpfSg3  >silmistama !27_V	et	f	\N
120467	silmistas	?silmistas =ista  (SgIn  >silm+ista !16_S	et	f	\N
120468	silmistas	?silmistas =istas  (SgN  >silm+istas !07_S	et	f	\N
120469	asuva	asuva =asuva  (SgG  >asuv !02_A	et	f	\N
120470	asuva	"asuv %asu  )V_vA  <asuma ;27_V	et	f	\N
120498	pealebr	?pealebr =pealebr  (SgN  >pealebr !22_S	et	f	\N
120499	pealebr	?pealebr =ebr  (SgN  >peal+ebr !22_S	et	f	\N
120500	pealebr	?pealebr =lebr  (SgN  >pea+lebr !22_S	et	f	\N
120501	märkida	märkida =märki  (Inf  >märkima !28_V	et	f	\N
120502	märkida	märkida =ida  (SgN  >märk+ida !17_S	et	f	\N
120503	märkida	märkida =ida  (SgG  >märk+ida !17_S	et	f	\N
120504	märkida	märkida =ida  (SgP  >märk+ida !17_S	et	f	\N
120507	paigaldadud	?paigaldadud =paigaldadu  (IndPrSg2  >paigaldaduma !27_V	et	f	\N
120508	paigaldadud	?paigaldadud =paigaldadud  (ID  >paigaldadud !41_A	et	f	\N
120509	paigaldadud	?paigaldadud =dadu  (PlN  >paigal+dadu !17_S	et	f	\N
120510	paigaldadud	?paigaldadud =galdadu  (PlN  >pai+galdadu !01_S	et	f	\N
120516	mbr	### mbr	et	f	\N
120525	järeldust	järeldust =järeldus  (SgP  >järeldus !11_S	et	f	\N
120526	järeldust	"järeldus %järelda  )US_vS  <järeldama ;27_V	et	f	\N
120527	järeldust	järeldust =dust  (SgN  >järel+dust !22_S	et	f	\N
120531	valve	valve =valve  (SgN  >valve !06_S	et	f	\N
120532	valve	valve =valve  (SgG  >valve !06_S	et	f	\N
120544	q	### q	et	f	\N
120545	tugebdas	?tugebdas =tugebda  (SgIn  >tugebda !01_S	et	f	\N
120548	sõnades	sõnades =sõna  (PlIn  >sõna !17_S	et	f	\N
120246	külla	külla =külla  (SgAdt  >küla !17_S	et	f	\N
120247	külla	külla =külla  (SgAdt  >küll !22_S	et	f	\N
120253	mahlakam	mahlakam =mahlakam  (SgN  >mahlakam !02_A	et	f	\N
120254	mahlakam	"mahlakam %mahlaka  )M_cA  <mahlakas ;02_A	et	f	\N
120259	mehelikumaks	mehelikumaks =mehelikuma  (SgTr  >mehelikum !02_A	et	f	\N
120260	mehelikumaks	"mehelikum %meheliku  )M_cA  <mehelik ;25_A	et	f	\N
120265	tagajärge	tagajärge =järge  (SgN  >taga+järge !05_S	et	f	\N
120266	tagajärge	tagajärge =järge  (SgP  >taga+järg !22_S	et	f	\N
120267	tagajärge	tagajärge =järge  (SgAdt  >taga+järg !22_S	et	f	\N
120268	sportimise-	sportimise- =sportimise  (SgG  >sportimine !12_S	et	f	\N
120269	sportimise-	"sportimine %sporti  )MINE_vS  <sportima ;28_V	et	f	\N
120278	jõudmisega	jõudmisega =jõudmise  (SgKom  >jõudmine !12?10_S	et	f	\N
120279	jõudmisega	"jõudmine %jõud  )MINE_vS  <jõudma ;34_V	et	f	\N
120280	tulid	tulid =tul  (IndIpfSg2  >tulema !36_V	et	f	\N
120281	tulid	tulid =tul  (IndIpfPl3  >tulema !36_V	et	f	\N
120284	murretu	?murretu =murretu  (SgN  >murretu !01_A	et	f	\N
120285	murretu	?murretu =murretu  (SgG  >murretu !01_A	et	f	\N
120286	murretu	?murretu =murretu  (IndPrPs_  >murretuma !27_V	et	f	\N
120287	murretu	?murretu =murretu  (ImpPrSg2  >murretuma !27_V	et	f	\N
120296	pingele	pingele =pinge  (SgAll  >pinge !06_S	et	f	\N
120297	pingele	pingele =pinge  (PlAll  >ping !22_S	et	f	\N
120298	pingele	pingele =pinge  (PlAll  >pink !22_S	et	f	\N
120306	naistest	naistest =nais  (PlEl  >naine !12_S	et	f	\N
120307	naistest	naistest =test  (SgN  >nais+test !22_S	et	f	\N
120308	kiiredest	kiiredest =ede  (SgEl  >kiir+ede !16_S	et	f	\N
120309	kiiredest	kiiredest =edes  (SgP  >kiir+edene !10_A	et	f	\N
120310	kiiredest	"kiir+edene %ede  )NE_aA  <kiir+ede ;16_S	et	f	\N
120327	stressi	stressi =stressi  (SgG  >stress !22_S	et	f	\N
120328	stressi	stressi =stressi  (SgP  >stress !22_S	et	f	\N
120329	stressi	stressi =stressi  (SgAdt  >stress !22_S	et	f	\N
120335	teisse	teisse =te  (PlIll  >sa !00_P	et	f	\N
120336	teisse	teisse =te  (PlIll  >tee !26_S	et	f	\N
120348	mehelikumateks	mehelikumateks =mehelikuma  (PlTr  >mehelikum !02_A	et	f	\N
120349	mehelikumateks	"mehelikum %meheliku  )M_cA  <mehelik ;25_A	et	f	\N
120357	valvataval	valvataval =valvatava  (SgAd  >valvatav !02_A	et	f	\N
120359	valvataval	"valvatav %valva  )TAV_vAS  <valvama ;29_V	et	f	\N
120378	y	### y	et	f	\N
120398	juhandi	?juhandi =juhandi  (SgN  >juhandi !01_S	et	f	\N
120399	juhandi	?juhandi =juhandi  (SgG  >juhandi !01_S	et	f	\N
120400	juhandi	?juhandi =juhandi  (SgG  >juhand !02_S	et	f	\N
120401	juhandi	?juhandi =juhandi  (SgG  >juhant !22_S	et	f	\N
120402	juhandi	?juhandi =juhandi  (IndPrPs_  >juhantima !28_V	et	f	\N
120403	juhandi	?juhandi =juhandi  (ImpPrSg2  >juhantima !28_V	et	f	\N
120436	kordapidaja	kordapidaja =pidaja  (SgN  >korda+pidaja !01_S	et	f	\N
120437	kordapidaja	kordapidaja =pidaja  (SgG  >korda+pidaja !01_S	et	f	\N
120438	patruli	?patruli =patruli  (ID  >patruli !41_D	et	f	\N
120439	patruli	?patruli =patruli  (SgG  >patrul !02_S	et	f	\N
120440	saatnud	saatnud =saat  (PtsPtPs  >saatma !34_V	et	f	\N
120441	saatnud	saatnud =saatnu  (PlN  >saatnu !01_S	et	f	\N
120442	saatnud	"saatnu %saat  )NU_vS  <saatma ;34_V	et	f	\N
120443	saatnud	saatnud =saatnud  (ID  >saatnud !41_A	et	f	\N
120444	saatnud	"saatnud %saat  )NUD_vA  <saatma ;34_V	et	f	\N
120445	territoiumi	?territoiumi =territoiumi  (SgN  >territoiumi !16_S	et	f	\N
120447	territoiumi	?territoiumi =territoiumi  (SgG  >territoiumi !16_S	et	f	\N
120449	territoiumi	?territoiumi =territoiumi  (SgG  >territoium !19_S	et	f	\N
120451	territoiumi	?territoiumi =territoiumi  (SgP  >territoium !19_S	et	f	\N
120452	territoiumi	?territoiumi =territoiumi  (SgAdt  >territoium !19_S	et	f	\N
120453	territoiumi	?territoiumi =territoiumi  (IndPrPs_  >territoiumima !28_V	et	f	\N
120454	territoiumi	?territoiumi =territoiumi  (ImpPrSg2  >territoiumima !28_V	et	f	\N
120464	patruliga	?patruliga =patruli  (SgKom  >patrul !02_S	et	f	\N
120474	pika	pika =pika  (SgG  >pikk !22_S	et	f	\N
120476	pika	pika =pika  (SgG  >pikk !22_AS	et	f	\N
120482	kuhagi	?kuhagi =kuha  (SgN^  >kuha !17_S	et	f	\N
120483	kuhagi	?kuhagi =kuha  (SgG^  >kuha !17_S	et	f	\N
120484	kuhagi	?kuhagi =kuha  (SgP^  >kuha !17_S	et	f	\N
120485	kuhagi	?kuhagi =kuha  (IndPrPs_^  >kuhama !27_V	et	f	\N
120486	kuhagi	?kuhagi =kuha  (ImpPrSg2^  >kuhama !27_V	et	f	\N
120492	määletada	?määletada =määleta  (Inf  >määletama !27_V	et	f	\N
120513	nõudele	nõudele =nõu  (PlAll  >nõu !26_S	et	f	\N
120515	nõudele	nõudele =nõude  (SgAll  >nõue !06_S	et	f	\N
120517	vajatakse	vajatakse =vaja  (IndPrIps  >vajama !27_V	et	f	\N
120518	vajatakse	vajatakse =takse  (PlP  >vaja+taks !22_S	et	f	\N
120519	võtti	võtti =võtti  (SgP  >võtt !22_S	et	f	\N
120520	võtti	võtti =võtti  (SgAdt  >võtt !22_S	et	f	\N
120521	kaugusel	kaugusel =kauguse  (SgAd  >kaugus !11~09_S	et	f	\N
120522	kaugusel	"kaugus %kauge  )US_aS  <kauge ;01_A	et	f	\N
120523	kaugusel	kaugusel =kauguse  (SgAd  >kaugune !10~12_A	et	f	\N
120524	kaugusel	kaugusel =use  (PlAd  >kaug+usk !22_S	et	f	\N
120528	objekti	objekti =objekti  (SgG  >objekt !22_S	et	f	\N
120363	tungmise	?tungmise =tungmise  (IndPrPs_  >tungmisema !27_V	et	f	\N
120367	tungmise	?tungmise =tungmise  (ImpPrSg2  >tungmisema !27_V	et	f	\N
120371	järgminebr	?järgminebr =järgminebr  (SgN  >järgminebr !22_S	et	f	\N
120377	x	### x	et	f	\N
120404	paigaltud	?paigaltud =paigaltu  (PlN  >paigaltu !01_S	et	f	\N
120405	paigaltud	?paigaltud =paigaltu  (IndPrSg2  >paigaltuma !27_V	et	f	\N
120406	paigaltud	?paigaltud =galtu  (PlN  >pai+galtu !16_S	et	f	\N
120407	tara	tara =tara  (SgN  >tara !17_S	et	f	\N
120408	tara	tara =tara  (SgG  >tara !17_S	et	f	\N
120409	tara	tara =tara  (SgP  >tara !17_S	et	f	\N
120419	kahtlast	kahtlast =kahtlas  (SgP  >kahtlane !12?10_A	et	f	\N
120421	kahtlast	kahtlast =la  (SgEl  >kaht+la !26_S	et	f	\N
120423	kahtlast	kahtlast =las  (SgP  >kaht+laps !14_S	et	f	\N
120425	kahtlast	kahtlast =last  (SgN  >kaht+last !22_S	et	f	\N
120457	mantee	?mantee =mantee  (SgN  >mantee !26_S	et	f	\N
120458	mantee	?mantee =mantee  (SgG  >mantee !26_S	et	f	\N
120490	varjas	varjas =varja  (SgIn  >vari !24_S	et	f	\N
120491	varjas	varjas =varja  (IndIpfSg3  >varjama !29_V	et	f	\N
120535	z	### z	et	f	\N
120536	kaine	kaine =kaine  (SgN  >kaine !01_A	et	f	\N
120537	kaine	"kaine %kai  )NE_aA  <kai ;26_S	et	f	\N
120538	kaine	kaine =kaine  (SgN  >kaine !06_A	et	f	\N
120539	kaine	kaine =kaine  (SgG  >kaine !01_A	et	f	\N
120540	kaine	kaine =kaine  (SgG  >kaine !06_A	et	f	\N
120541	kaine	kaine =kaine  (PlP  >kain !22_S	et	f	\N
120551	märkasid	märkasid =märka  (IndIpfSg2  >märkama !29_V	et	f	\N
120552	märkasid	märkasid =märka  (IndIpfPl3  >märkama !29_V	et	f	\N
120599	tulistamist	tulistamist =tulistamis  (SgP  >tulistamine !12_S	et	f	\N
120600	tulistamist	"tulistamine %tulista  )MINE_vS  <tulistama ;27_V	et	f	\N
120620	domineerisid	domineerisid =domineeri  (IndIpfSg2  >domineerima !28_V	et	f	\N
120621	domineerisid	domineerisid =domineeri  (IndIpfPl3  >domineerima !28_V	et	f	\N
120622	vaimuelus	vaimuelus =elu  (SgIn  >vaimu+elu !17_S	et	f	\N
120623	vaimuelus	vaimuelus =elus  (SgN  >vaimu+elus !02_A	et	f	\N
120644	laieneminebr	?laieneminebr =laieneminebr  (SgN  >laieneminebr !22_S	et	f	\N
120645	laieneminebr	?laieneminebr =eneminebr  (SgN  >lai+eneminebr !22_S	et	f	\N
120672	maailmamainega	maailmamainega =maine  (SgKom  >maa+ilma+maine !06_S	et	f	\N
120673	maailmamainega	"maa+ilma+maine %mai  )NE_aA  <maa+ilma+maa ;26_S	et	f	\N
120688	tantsimispeod	?tantsimispeod =tantsimispeo  (PlN  >tantsimispeo !01_S	et	f	\N
120689	tantsimispeod	?tantsimispeod =tantsimispeod  (SgN  >tantsimispeod !22_S	et	f	\N
120728	kirjanduselu	kirjanduselu =elu  (SgN  >kirjandus+elu !17_S	et	f	\N
120729	kirjanduselu	kirjanduselu =elu  (SgG  >kirjandus+elu !17_S	et	f	\N
120730	kirjanduselu	kirjanduselu =elu  (SgP  >kirjandus+elu !17_S	et	f	\N
120753	meeldinud	meeldinud =meeldi  (PtsPtPs  >meeldima !27_V	et	f	\N
120754	meeldinud	meeldinud =meeldinu  (PlN  >meeldinu !01_S	et	f	\N
120755	meeldinud	"meeldinu %meeldi  )NU_vS  <meeldima ;27_V	et	f	\N
120757	meeldinud	meeldinud =meeldinud  (ID  >meeldinud !41_A	et	f	\N
120759	meeldinud	"meeldinud %meeldi  )NUD_vA  <meeldima ;27_V	et	f	\N
120763	ha	### ha	et	f	\N
120772	liituma	liituma =liitu  (Sup  >liituma !27_V	et	f	\N
120773	liituma	liituma =liituma  (SgG  >liitum !02_A	et	f	\N
120774	liituma	"liitum %lii  )TUM2_cA  <lii ;26_S	et	f	\N
120783	omama	omama =oma  (Sup  >omama !27_V	et	f	\N
120784	omama	omama =omama  (SgG  >omam !02_A	et	f	\N
120785	omama	"omam %oma  )M_cA  <oma ;17_A	et	f	\N
120798	iseloomust	iseloomust =us  (SgP  >ise+loom+uks !14_S	et	f	\N
120799	iseloomust	iseloomust =must  (SgN  >ise+loo+must !22_AS	et	f	\N
120800	iseloomust	iseloomust =loomu  (SgEl  >ise+loom !22_S	et	f	\N
120801	iseloomust	iseloomust =loomus  (SgP  >ise+loomus !11~09_S	et	f	\N
120829	reisidaspan	?reisidaspan =reisidaspan  (SgN  >reisidaspan !02_S	et	f	\N
120830	reisidaspan	?reisidaspan =daspan  (SgN  >reisi+daspan !02_S	et	f	\N
120846	hobbita	?hobbita =hobbi  (SgAb  >hobbi !16_S	et	f	\N
120847	hobbita	?hobbita =hobbi  (SgAb  >hobb !22_S	et	f	\N
120848	hobbita	?hobbita =hobbi  (IndPrIps_  >hobbima !28_V	et	f	\N
120849	hobbita	?hobbita =hobbita  (IndPrPs_  >hobbitama !27_V	et	f	\N
120850	hobbita	?hobbita =hobbita  (ImpPrSg2  >hobbitama !27_V	et	f	\N
120853	mingides	?mingides =mingi  (PlIn  >ming !22_S	et	f	\N
120854	mingides	?mingides =mingi  (Ger  >mingima !28_V	et	f	\N
120860	nendeta	nendeta =nen  (PlAb  >see !00_P	et	f	\N
120861	nendeta	nendeta =nen  (PlAb  >tema !00_P	et	f	\N
120868	aidata	aidata =aida  (SgAb  >ait !22_S	et	f	\N
120869	aidata	aidata =aida  (Inf  >aitama !29_V	et	f	\N
120870	aidata	aidata =aida  (IndPrIps_  >aitama !29_V	et	f	\N
120871	veedas	?veedas =veeda  (SgIn  >veeda !16_S	et	f	\N
120872	veedas	?veedas =veeda  (IndIpfSg3  >veedama !29_V	et	f	\N
120873	veedas	?veedas =veedas  (SgN  >veedas !07_S	et	f	\N
120893	hobbiga	?hobbiga =hobbi  (SgKom  >hobbi !16_S	et	f	\N
120894	hobbiga	?hobbiga =hobbi  (SgKom  >hobb !22_S	et	f	\N
120905	aitavaid	aitavaid =aitava  (PlP  >aitav !02_A	et	f	\N
120906	aitavaid	"aitav %aita  )V_vA  <aitama ;29_V	et	f	\N
120512	turvalisuse	"turvalisus %turva  )LISUS_aS  <turb ;22_SA	et	f	\N
120514	turvalisuse	"turvalisus %turva  )LISUS_aS  <turv ;22_S	et	f	\N
120542	muutmine	muutmine =muutmine  (SgN  >muutmine !12?10_S	et	f	\N
120543	muutmine	"muutmine %muut  )MINE_vS  <muutma ;34_V	et	f	\N
120559	juhtimina	?juhtimina =juhtimi  (SgEs  >juhtimi !01_S	et	f	\N
120560	juhtimina	?juhtimina =juhtimi  (SgEs  >juhtim !02_A	et	f	\N
120561	juhtimina	?juhtimina =juhtimina  (SgG  >juhtimin !19_S	et	f	\N
120562	juhtimina	?juhtimina =juhtimina  (SgP  >juhtimin !19_S	et	f	\N
120563	juhtimina	?juhtimina =juhtimina  (SgAdt  >juhtimin !19_S	et	f	\N
120564	juhtimina	?juhtimina =imi  (SgEs  >juht+imi !17_S	et	f	\N
120565	juhtimina	?juhtimina =imina  (SgG  >juht+imin !02_S	et	f	\N
120572	järeldusi	järeldusi =järeldusi  (PlP  >järeldus !11_S	et	f	\N
120575	järeldusi	"järeldus %järelda  )US_vS  <järeldama ;27_V	et	f	\N
120590	sotsiaaldemokratlikud	?sotsiaaldemokratlikud =sotsiaaldemokratliku  (PlN  >sotsiaaldemokratlik !25_A	et	f	\N
120591	sotsiaaldemokratlikud	?sotsiaaldemokratlikud =sotsiaaldemokratliku  (IndPrSg2  >sotsiaaldemokratlikuma !27_V	et	f	\N
120592	sotsiaaldemokratlikud	?sotsiaaldemokratlikud =demokratliku  (PlN  >sotsiaal+demokratlik !25_A	et	f	\N
120612	abinõusidbr	?abinõusidbr =idbr  (SgN  >abi+nõus+idbr !22_S	et	f	\N
120613	abinõusidbr	?abinõusidbr =sidbr  (SgN  >abi+nõu+sidbr !22_S	et	f	\N
120614	abinõusidbr	?abinõusidbr =nõusidbr  (SgN  >abi+nõusidbr !22_S	et	f	\N
120624	valgustaja	valgustaja =valgustaja  (SgN  >valgustaja !01_S	et	f	\N
120625	valgustaja	"valgustaja %valgusta  )JA_vS  <valgustama ;27_V	et	f	\N
120626	valgustaja	valgustaja =valgustaja  (SgG  >valgustaja !01_S	et	f	\N
120627	valgustaja	valgustaja =aja  (SgG  >valgust+aeg !22_S	et	f	\N
120632	õigusi	õigusi =õigusi  (PlP  >õigus !11_S	et	f	\N
120633	õigusi	"õigus %õige  )US_aS  <õige ;01_A	et	f	\N
120636	aastakümnetel	?aastakümnetel =aastakümnete  (PlAd  >aastakümnett !22_S	et	f	\N
120637	aastakümnetel	?aastakümnetel =kümnete  (PlAd  >aasta+kümnett !22_S	et	f	\N
120638	aastakümnetel	?aastakümnetel =takümnete  (PlAd  >aas+takümnett !22_S	et	f	\N
120646	paremat	paremat =parema  (SgP  >parem !02_A	et	f	\N
120647	paremat	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
120674	jcstruve	?jcstruve =jcstruve  (SgN  >jcstruve !16_S	et	f	\N
120675	jcstruve	?jcstruve =jcstruve  (SgG  >jcstruve !16_S	et	f	\N
120676	jcstruve	?jcstruve =jcstruve  (IndPrPs_  >jcstruvema !27_V	et	f	\N
120677	jcstruve	?jcstruve =jcstruve  (ImpPrSg2  >jcstruvema !27_V	et	f	\N
120700	ühendati	ühendati =ühenda  (IndIpfIps  >ühendama !27_V	et	f	\N
120701	ühendati	ühendati =ati  (SgG  >ühend+att !22_S	et	f	\N
120711	peaministr	?peaministr =ministr  (SgN  >pea+ministr !22_S	et	f	\N
120731	kollektiviseerimine	kollektiviseerimine =kollektiviseerimine  (SgN  >kollektiviseerimine !12_S	et	f	\N
120732	kollektiviseerimine	"kollektiviseerimine %kollektiviseeri  )MINE_vS  <kollektiviseerima ;28_V	et	f	\N
120756	enamlastele	enamlastele =enamlas  (PlAll  >enamlane !12_S	et	f	\N
120758	enamlastele	enamlastele =las  (PlAll  >enam+laps !14_S	et	f	\N
120760	enamlastele	enamlastele =laste  (PlAll  >enam+last !22_S	et	f	\N
120764	massiline	massiline =massiline  (SgN  >massiline !12_A	et	f	\N
120765	massiline	"massiline %massi  )LINE_aA  <mass ;22_S	et	f	\N
120786	laostanudbr	?laostanudbr =tanudbr  (SgN  >laos+tanudbr !22_S	et	f	\N
120787	laostanudbr	?laostanudbr =stanudbr  (SgN  >lao+stanudbr !22_S	et	f	\N
120817	kultuuriliseid	?kultuuriliseid =kultuurilisei  (PlN  >kultuurilisei !26_S	et	f	\N
120819	kultuuriliseid	?kultuuriliseid =kultuurilisei  (SgP  >kultuurilisei !26_S	et	f	\N
120820	kultuuriliseid	?kultuuriliseid =ilise  (PlP  >kultuur+iline !10_A	et	f	\N
120821	kultuuriliseid	?kultuuriliseid =ilisei  (PlN  >kultuur+ilisei !26_S	et	f	\N
120822	kultuuriliseid	?kultuuriliseid =ilisei  (SgP  >kultuur+ilisei !26_S	et	f	\N
120826	tuju	tuju =tuju  (SgN  >tuju !17_S	et	f	\N
120827	tuju	tuju =tuju  (SgG  >tuju !17_S	et	f	\N
120828	tuju	tuju =tuju  (SgP  >tuju !17_S	et	f	\N
120857	kujuta	kujuta =kuju  (SgAb  >kuju !17_S	et	f	\N
120858	kujuta	kujuta =kujuta  (IndPrPs_  >kujutama !27_V	et	f	\N
120859	kujuta	kujuta =kujuta  (ImpPrSg2  >kujutama !27_V	et	f	\N
120862	kõigedele	### kõigedele	et	f	\N
120885	pankast	pankast =panka  (SgEl  >pangas !07_S	et	f	\N
120886	pankast	pankast =pankas  (SgP  >pankane !12~10_A	et	f	\N
120888	pankast	"pankane %panka  )NE_aA  <pangas ;07_S	et	f	\N
120907	kuiuta	?kuiuta =kuiu  (SgAb  >kuiu !16_S	et	f	\N
120908	kuiuta	?kuiuta =kuiu  (IndPrIps_  >kuiuma !27_V	et	f	\N
120909	kuiuta	?kuiuta =kuiuta  (IndPrPs_  >kuiutama !27_V	et	f	\N
120910	kuiuta	?kuiuta =kuiuta  (ImpPrSg2  >kuiutama !27_V	et	f	\N
120911	kuiuta	?kuiuta =uta  (SgN  >kui+uta !16_S	et	f	\N
120912	kuiuta	?kuiuta =uta  (SgG  >kui+uta !16_S	et	f	\N
120920	tähtsamat	tähtsamat =tähtsama  (SgP  >tähtsam !02_A	et	f	\N
120921	tähtsamat	"tähtsam %tähtsa  )M_cA  <tähtis ;02_A	et	f	\N
120948	panaksin	?panaksin =panaksi  (IndPrSg1  >panaksima !28_V	et	f	\N
120949	panaksin	?panaksin =panaksin  (SgN  >panaksin !19_S	et	f	\N
120950	prooblemiks	?prooblemiks =prooblemi  (SgTr  >prooblemi !01_S	et	f	\N
120951	prooblemiks	?prooblemiks =prooblemi  (SgTr  >prooblem !02_A	et	f	\N
120984	tõstetatud	?tõstetatud =tõsteta  (PtsPtIps  >tõstetama !27_V	et	f	\N
120529	objekti	objekti =objekti  (SgP  >objekt !22_S	et	f	\N
120530	objekti	objekti =objekti  (SgAdt  >objekt !22_S	et	f	\N
120533	valvekorda	valvekorda =korda  (SgP  >valve+kord !22_S	et	f	\N
120534	valvekorda	valvekorda =korda  (SgAdt  >valve+kord !22_S	et	f	\N
120546	hommikuni	hommikuni =hommiku  (SgTer  >hommik !02_S	et	f	\N
120547	hommikuni	hommikuni =uni  (SgN  >hommik+uni !20_S	et	f	\N
120570	juhtumist	juhtumist =juhtumi  (SgEl  >juhtum !02_S	et	f	\N
120571	juhtumist	juhtumist =juhtumis  (SgP  >juhtumine !12_S	et	f	\N
120573	juhtumist	"juhtumine %juhtu  )MINE_vS  <juhtuma ;27_V	et	f	\N
120574	juhtumist	"juhtumine %juhtumi  )NE_aA  <juhtum ;02_S	et	f	\N
120576	pbr	### pbr	et	f	\N
120579	tegevdirektorbr	### tegevdirektorbr	et	f	\N
120581	teaduselu	teaduselu =elu  (SgN  >teadus+elu !17_S	et	f	\N
120582	teaduselu	teaduselu =elu  (SgG  >teadus+elu !17_S	et	f	\N
120583	teaduselu	teaduselu =elu  (SgP  >teadus+elu !17_S	et	f	\N
120584	teravnesid	teravnesid =teravne  (IndIpfSg2  >teravnema !27_V	et	f	\N
120585	teravnesid	teravnesid =teravne  (IndIpfPl3  >teravnema !27_V	et	f	\N
120593	töölis	?töölis =tööli  (SgIn  >tööli !16_S	et	f	\N
120594	töölis	?töölis =tööli  (SgIn  >tööl !22_S	et	f	\N
120595	töölis	?töölis =tööli  (IndIpfSg3  >töölima !28_V	et	f	\N
120596	töölis	?töölis =töölis  (SgN  >töölis !09_S	et	f	\N
120597	kindlustatuse	kindlustatuse =kindlustatuse  (SgG  >kindlustatus !11?09_S	et	f	\N
120598	kindlustatuse	"kindlustatus %kindlusta  )TUS1_aS  <kindlustama ;27_V	et	f	\N
120601	rahulolematuselaine	?rahulolematuselaine =rahulolematuselaine  (SgN  >rahulolematuselaine !16_S	et	f	\N
120602	rahulolematuselaine	?rahulolematuselaine =rahulolematuselaine  (SgG  >rahulolematuselaine !16_S	et	f	\N
120603	rahulolematuselaine	?rahulolematuselaine =rahulolematuselaine  (PlP  >rahulolematuselain !19_S	et	f	\N
120604	rahulolematuselaine	?rahulolematuselaine =olematuselaine  (SgN  >rahul+olematuselaine !16_S	et	f	\N
120605	rahulolematuselaine	?rahulolematuselaine =olematuselaine  (SgG  >rahul+olematuselaine !16_S	et	f	\N
120606	rahulolematuselaine	?rahulolematuselaine =olematuselaine  (PlP  >rahul+olematuselain !19_S	et	f	\N
120607	rahulolematuselaine	?rahulolematuselaine =lolematuselaine  (SgN  >rahu+lolematuselaine !16_S	et	f	\N
120608	rahulolematuselaine	?rahulolematuselaine =lolematuselaine  (SgG  >rahu+lolematuselaine !16_S	et	f	\N
120609	rahulolematuselaine	?rahulolematuselaine =lolematuselaine  (PlP  >rahu+lolematuselain !19_S	et	f	\N
120628	crjakobson	?crjakobson =crjakobson  (SgN  >crjakobson !19_S	et	f	\N
120634	järgnevatel	järgnevatel =järgneva  (PlAd  >järgnev !02_A	et	f	\N
120635	järgnevatel	"järgnev %järgne  )V_vA  <järgnema ;27_V	et	f	\N
120680	laulu-	laulu- =laulu  (SgG  >laul !22_S	et	f	\N
120681	laulu-	laulu- =laulu  (SgP  >laul !22_S	et	f	\N
120682	laulu-	laulu- =laulu  (SgAdt  >laul !22_S	et	f	\N
120690	jkrossbr	?jkrossbr =jkrossbr  (SgN  >jkrossbr !22_S	et	f	\N
120696	jposka	?jposka =jposka  (SgN  >jposka !16_S	et	f	\N
120697	jposka	?jposka =jposka  (SgG  >jposka !16_S	et	f	\N
120698	jposka	?jposka =jposka  (IndPrPs_  >jposkama !29_V	et	f	\N
120699	jposka	?jposka =jposka  (ImpPrSg2  >jposkama !29_V	et	f	\N
120713	okkupatsiooni	?okkupatsiooni =okkupatsioo  (SgTer  >okkupatsioo !26_S	et	f	\N
120714	okkupatsiooni	?okkupatsiooni =okkupatsiooni  (SgN  >okkupatsiooni !16_S	et	f	\N
120715	okkupatsiooni	?okkupatsiooni =okkupatsiooni  (SgG  >okkupatsiooni !16_S	et	f	\N
120716	okkupatsiooni	?okkupatsiooni =okkupatsiooni  (SgG  >okkupatsioon !22_S	et	f	\N
120717	okkupatsiooni	?okkupatsiooni =okkupatsiooni  (SgP  >okkupatsioon !22_S	et	f	\N
120718	okkupatsiooni	?okkupatsiooni =okkupatsiooni  (SgAdt  >okkupatsioon !22_S	et	f	\N
120719	okkupatsiooni	?okkupatsiooni =okkupatsiooni  (IndPrPs_  >okkupatsioonima !28_V	et	f	\N
120720	okkupatsiooni	?okkupatsiooni =okkupatsiooni  (ImpPrSg2  >okkupatsioonima !28_V	et	f	\N
120733	külaühiskondabr	?külaühiskondabr =külaühiskondabr  (SgN  >külaühiskondabr !22_S	et	f	\N
120734	külaühiskondabr	?külaühiskondabr =kondabr  (SgN  >küla+ühis+kondabr !22_S	et	f	\N
120735	külaühiskondabr	?külaühiskondabr =ühiskondabr  (SgN  >küla+ühiskondabr !22_S	et	f	\N
120736	riikmeteks	riikmeteks =me  (PlTr  >riik+mesi !15_S	et	f	\N
120737	riikmeteks	riikmeteks =mete  (PlTr  >riik+mett !22_S	et	f	\N
120743	toimuvatega	toimuvatega =toimuva  (PlKom  >toimuv !02_A	et	f	\N
120744	toimuvatega	"toimuv %toimu  )V_vA  <toimuma ;27_V	et	f	\N
120768	küüditatuid	küüditatuid =küüditatu  (PlP  >küüditatu !01_S	et	f	\N
120769	küüditatuid	"küüditatu %küüdita  )TU1_vS  <küüditama ;27_V	et	f	\N
120778	harjunud	harjunud =harju  (PtsPtPs  >harjuma !27_V	et	f	\N
120779	harjunud	harjunud =harjunu  (PlN  >harjunu !01_S	et	f	\N
120780	harjunud	"harjunu %harju  )NU_vS  <harjuma ;27_V	et	f	\N
120781	harjunud	harjunud =harjunud  (ID  >harjunud !41_A	et	f	\N
120782	harjunud	"harjunud %harju  )NUD_vA  <harjuma ;27_V	et	f	\N
120788	laostanud	laostanud =laosta  (PtsPtPs  >laostama !27_V	et	f	\N
120789	laostanud	laostanud =laostanu  (PlN  >laostanu !01_S	et	f	\N
120790	laostanud	"laostanu %laosta  )NU_vS  <laostama ;27_V	et	f	\N
120791	laostanud	laostanud =laostanud  (ID  >laostanud !41_A	et	f	\N
120792	laostanud	"laostanud %laosta  )NUD_vA  <laostama ;27_V	et	f	\N
120793	laostanud	laostanud =tanu  (PlN  >laos+tanu !17_S	et	f	\N
120549	sõnades	sõnades =sõna  (Ger  >sõnama !27_V	et	f	\N
120553	klimaator	?klimaator =klimaator  (SgN  >klimaator !02_S	et	f	\N
120554	katkestanud	katkestanud =katkesta  (PtsPtPs  >katkestama !27_V	et	f	\N
120555	katkestanud	katkestanud =katkestanu  (PlN  >katkestanu !01_S	et	f	\N
120556	katkestanud	"katkestanu %katkesta  )NU_vS  <katkestama ;27_V	et	f	\N
120557	katkestanud	katkestanud =katkestanud  (ID  >katkestanud !41_A	et	f	\N
120558	katkestanud	"katkestanud %katkesta  )NUD_vA  <katkestama ;27_V	et	f	\N
120566	tehtus	tehtus =tehtu  (SgIn  >tehtu !01_S	et	f	\N
120567	tehtus	"tehtu %teh  )TU1_vS  <tegema ;28_V	et	f	\N
120568	tehtus	tehtus =tehtus  (SgN  >tehtus !11~09_S	et	f	\N
120569	tehtus	"tehtus %teh  )TUS1_aS  <tegema ;28_V	et	f	\N
120610	vabadusi	vabadusi =vabadusi  (PlP  >vabadus !11_S	et	f	\N
120611	vabadusi	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
120639	kiir	kiir =kiir  (SgN  >kiir !13_S	et	f	\N
120640	kiir	kiir =kiir  (SgN  >kiir !22_S	et	f	\N
120641	hoogsalt	hoogsalt =hoogsa  (SgAbl  >hoogne !02_A	et	f	\N
120642	hoogsalt	hoogsalt =hoogsalt  (ID  >hoogsalt !41_D	et	f	\N
120643	hoogsalt	"hoogsalt %hoogsa  )LT_mD  <hoogne ;02_A	et	f	\N
120652	hinnadetõusu	?hinnadetõusu =hinnadetõusu  (IndPrPs_  >hinnadetõusuma !27_V	et	f	\N
120653	hinnadetõusu	?hinnadetõusu =hinnadetõusu  (ImpPrSg2  >hinnadetõusuma !27_V	et	f	\N
120654	hinnadetõusu	?hinnadetõusu =detõusu  (SgN  >hinna+detõusu !01_S	et	f	\N
120655	hinnadetõusu	?hinnadetõusu =detõusu  (SgG  >hinna+detõusu !01_S	et	f	\N
120669	vaheaega	vaheaega =aega  (SgP  >vahe+aeg !22_S	et	f	\N
120671	vaheaega	vaheaega =aega  (SgAdt  >vahe+aeg !22_S	et	f	\N
120678	asutati	asutati =asuta  (IndIpfIps  >asutama !27_V	et	f	\N
120679	asutati	asutati =tati  (SgG  >asu+tatt !22_S	et	f	\N
120683	mänguseltsi	mänguseltsi =seltsi  (SgG  >mängu+selts !22_S	et	f	\N
120685	mänguseltsi	mänguseltsi =seltsi  (SgP  >mängu+selts !22_S	et	f	\N
120687	mänguseltsi	mänguseltsi =seltsi  (SgAdt  >mängu+selts !22_S	et	f	\N
120693	maanõukogu	maanõukogu =kogu  (SgN  >maa+nõu+kogu !17_S	et	f	\N
120694	maanõukogu	maanõukogu =kogu  (SgG  >maa+nõu+kogu !17_S	et	f	\N
120695	maanõukogu	maanõukogu =kogu  (SgP  >maa+nõu+kogu !17_S	et	f	\N
120702	ühtseks	ühtseks =ühtse  (SgTr  >ühtne !02_A	et	f	\N
120703	ühtseks	ühtseks =seks  (SgN  >üht+seks !22_S	et	f	\N
120704	haldusüksuseks	haldusüksuseks =use  (PlTr  >haldus+üks+usk !22_S	et	f	\N
120705	haldusüksuseks	haldusüksuseks =üksuse  (SgTr  >haldus+üksus !11~09_S	et	f	\N
120712	konstantin	?konstantin =konstantin  (SgN  >konstantin !19_S	et	f	\N
120722	gne	### gne	et	f	\N
120738	frtuglas	?frtuglas =frtugla  (SgIn  >frtugla !16_S	et	f	\N
120739	frtuglas	?frtuglas =frtugla  (IndIpfSg3  >frtuglama !27_V	et	f	\N
120740	frtuglas	?frtuglas =frtuglas  (SgN  >frtuglas !07_S	et	f	\N
120742	jt	### jt	et	f	\N
120766	küüditamine	küüditamine =küüditamine  (SgN  >küüditamine !12_S	et	f	\N
120767	küüditamine	"küüditamine %küüdita  )MINE_vS  <küüditama ;27_V	et	f	\N
120770	moel	moel =moe  (SgAd  >mood !22_S	et	f	\N
120771	moel	moel =moel  (ID  >moel !41_K	et	f	\N
120775	kolhoosi	kolhoosi =kolhoosi  (SgG  >kolhoos !22_S	et	f	\N
120776	kolhoosi	kolhoosi =kolhoosi  (SgP  >kolhoos !22_S	et	f	\N
120777	kolhoosi	kolhoosi =kolhoosi  (SgAdt  >kolhoos !22_S	et	f	\N
120794	kannatused	kannatused =kannatuse  (PlN  >kannatus !11_S	et	f	\N
120795	kannatused	"kannatus %kannata  )US_vS  <kannatama ;27_V	et	f	\N
120796	kannatused	"kannatus %kanna  )TUS2_aS  <kanna ;16_S	et	f	\N
120797	kannatused	"kannatus %kanna  )TUS2_aS  <kand ;22_S	et	f	\N
120806	elukohast	elukohast =koha  (SgEl  >elu+koha !17_S	et	f	\N
120807	elukohast	elukohast =koha  (SgEl  >elu+koht !22_S	et	f	\N
120808	elukohast	elukohast =kohas  (SgP  >elu+kohane !10_A	et	f	\N
120809	elukohast	"elu+kohane %koha  )NE_aA  <elu+koha ;17_S	et	f	\N
120810	elukohast	"elu+kohane %koha  )NE_aA  <elu+koht ;22_S	et	f	\N
120831	spanja	?spanja =spanja  (SgN  >spanja !16_S	et	f	\N
120832	spanja	?spanja =spanja  (SgG  >spanjas !02_A	et	f	\N
120833	spanja	?spanja =spanja  (SgG  >spanja !16_S	et	f	\N
120834	spanja	?spanja =spanja  (IndPrPs_  >spanjama !29_V	et	f	\N
120835	spanja	?spanja =spanja  (ImpPrSg2  >spanjama !29_V	et	f	\N
120836	hiilgav	hiilgav =hiilga  (PtsPrPs  >hiilgama !29_V	et	f	\N
120837	hiilgav	hiilgav =hiilgav  (SgN  >hiilgav !02_A	et	f	\N
120838	hiilgav	"hiilgav %hiilga  )V_vA  <hiilgama ;29_V	et	f	\N
120839	sellesarnast	sellesarnast =sarna  (SgEl  >selle+sarn !22_S	et	f	\N
120840	sellesarnast	sellesarnast =sarnas  (SgP  >selle+sarnane !10_A	et	f	\N
120841	sellesarnast	"selle+sarnane %sarna  )NE_aA  <selle+sarn ;22_S	et	f	\N
120842	aegabr	?aegabr =aegabr  (SgN  >aegabr !22_S	et	f	\N
120843	aegabr	?aegabr =abr  (SgN  >aeg+abr !22_S	et	f	\N
120851	looduseta	looduseta =looduse  (SgAb  >loodus !11~09_S	et	f	\N
120852	looduseta	"loodus %loo  )TUS1_aS  <looma ;38_V	et	f	\N
120896	lõbus	lõbus =lõbu  (SgIn  >lõbu !17_S	et	f	\N
120897	lõbus	lõbus =lõbus  (SgN  >lõbus !02_A	et	f	\N
120922	poega	poega =poe  (SgKom  >pood !22_S	et	f	\N
120923	poega	poega =poega  (SgP  >poeg !22_S	et	f	\N
120924	poega	poega =poega  (SgAdt  >poeg !22_S	et	f	\N
120578	ou	?ou =ou  (SgG  >ou !26_S	et	f	\N
120580	põhjusedbr	### põhjusedbr	et	f	\N
120586	lätis	?lätis =läti  (SgIn  >läti !16_S	et	f	\N
120587	lätis	?lätis =läti  (SgIn  >lätt !22_S	et	f	\N
120588	lätis	?lätis =läti  (IndIpfSg3  >lätima !27_V	et	f	\N
120589	lätis	?lätis =lätis  (SgN  >lätis !09_S	et	f	\N
120615	kasvatus	kasvatus =kasvatu  (SgIn  >kasvatu !01_AS	et	f	\N
120616	kasvatus	"kasvatu %kasva  )TU1_vS  <kasvama ;28_V	et	f	\N
120617	kasvatus	kasvatus =kasvatus  (SgN  >kasvatus !11_S	et	f	\N
120618	kasvatus	"kasvatus %kasvata  )US_vS  <kasvatama ;27_V	et	f	\N
120619	kasvatus	"kasvatus %kasva  )TUS1_aS  <kasvama ;28_V	et	f	\N
120629	baltisaksa	baltisaksa =saksa  (SgG  >balti+saks !23?22_S	et	f	\N
120630	baltisaksa	baltisaksa =saksa  (SgP  >balti+saks !23?22_S	et	f	\N
120631	baltisaksa	baltisaksa =saksa  (SgAdt  >balti+saks !23?22_S	et	f	\N
120648	elut	?elut =elut  (SgN  >elut !02_S	et	f	\N
120649	vähesus	?vähesus =vähesu  (SgIn  >vähesu !01_S	et	f	\N
120650	vähesus	?vähesus =vähesu  (IndIpfSg3  >vähesuma !27_V	et	f	\N
120651	vähesus	?vähesus =vähesus  (SgN  >vähesus !11_S	et	f	\N
120656	ülikiire	ülikiire =kiire  (SgN  >üli+kiire !01_A	et	f	\N
120657	ülikiire	ülikiire =kiire  (SgN  >üli+kiire !06_S	et	f	\N
120658	ülikiire	ülikiire =kiire  (SgN  >üli+kiire !06_AS	et	f	\N
120659	ülikiire	ülikiire =kiire  (SgG  >üli+kiire !01_A	et	f	\N
120660	ülikiire	ülikiire =kiire  (SgG  >üli+kiire !06_S	et	f	\N
120661	ülikiire	ülikiire =kiire  (SgG  >üli+kiire !06_AS	et	f	\N
120662	ülikiire	ülikiire =kiire  (SgG  >üli+kiir !13_S	et	f	\N
120663	ülikiire	ülikiire =kiire  (PlP  >üli+kiir !22_S	et	f	\N
120664	inflatsiooni	inflatsiooni =inflatsiooni  (SgG  >inflatsioon !22_S	et	f	\N
120665	inflatsiooni	inflatsiooni =inflatsiooni  (SgP  >inflatsioon !22_S	et	f	\N
120666	inflatsiooni	inflatsiooni =inflatsiooni  (SgAdt  >inflatsioon !22_S	et	f	\N
120667	saja-aastast	saja-aastast =aasta  (SgEl  >saja-aasta !01_S	et	f	\N
120668	saja-aastast	saja-aastast =aastas  (SgP  >saja-aastane !12~10_A	et	f	\N
120670	saja-aastast	"saja-aastane %aasta  )NE_aA  <saja-aasta ;01_S	et	f	\N
120684	vanemuine	vanemuine =uine  (SgN  >vanem+uine !10_A	et	f	\N
120686	vanemuine	"vanem+uine %ui  )NE_aA  <vanem+ui ;26_S	et	f	\N
120691	ajutine	ajutine =ajutine  (SgN  >ajutine !12_A	et	f	\N
120692	ajutine	ajutine =tine  (SgN  >aju+tine !02_A	et	f	\N
120706	järgnevalt	järgnevalt =järgneva  (SgAbl  >järgnev !02_A	et	f	\N
120707	järgnevalt	"järgnev %järgne  )V_vA  <järgnema ;27_V	et	f	\N
120708	järgnevalt	järgnevalt =järgnevalt  (ID  >järgnevalt !41_D	et	f	\N
120709	järgnevalt	"järgnevalt %järgne  )VALT_mD  <järgnema ;27_V	et	f	\N
120710	järgnevalt	"järgnevalt %järgneva  )LT_mD  <järgnev ;02_A	et	f	\N
120721	vaherahu	vaherahu =ahu  (SgN  >vaher+ahu !17_S	et	f	\N
120723	vaherahu	vaherahu =ahu  (SgG  >vaher+ahu !17_S	et	f	\N
120724	vaherahu	vaherahu =ahu  (SgP  >vaher+ahu !17_S	et	f	\N
120725	vaherahu	vaherahu =rahu  (SgN  >vahe+rahu !17_S	et	f	\N
120726	vaherahu	vaherahu =rahu  (SgG  >vahe+rahu !17_S	et	f	\N
120727	vaherahu	vaherahu =rahu  (SgP  >vahe+rahu !17_S	et	f	\N
120741	jaavik	?jaavik =jaavik  (SgN  >jaavik !02_S	et	f	\N
120745	samanimelist	samanimelist =nimelis  (SgP  >sama+nimeline !12_A	et	f	\N
120746	samanimelist	"sama+nimeline %nime  )LINE_aA  <sama+nimi ;20_S	et	f	\N
120747	paranesid	paranesid =parane  (IndIpfSg2  >paranema !27_V	et	f	\N
120748	paranesid	paranesid =parane  (IndIpfPl3  >paranema !27_V	et	f	\N
120749	populaarseks	populaarseks =populaarse  (SgTr  >populaarne !02_A	et	f	\N
120750	populaarseks	populaarseks =seks  (SgN  >populaar+seks !22_S	et	f	\N
120751	hävitama	hävitama =hävi  (SupIps  >hävima !27_V	et	f	\N
120752	hävitama	hävitama =hävita  (Sup  >hävitama !27_V	et	f	\N
120761	ületasid	ületasid =ületa  (IndIpfSg2  >ületama !27_V	et	f	\N
120762	ületasid	ületasid =ületa  (IndIpfPl3  >ületama !27_V	et	f	\N
120811	erialast	erialast =ala  (SgEl  >eri+ala !17_S	et	f	\N
120812	erialast	erialast =alas  (SgP  >eri+alane !10_AS	et	f	\N
120813	erialast	"eri+alane %ala  )NE_aA  <eri+ala ;17_S	et	f	\N
120816	eluliseid	?eluliseid =elulisei  (PlN  >elulisei !26_S	et	f	\N
120818	eluliseid	?eluliseid =elulisei  (SgP  >elulisei !26_S	et	f	\N
120863	perebr	?perebr =perebr  (SgN  >perebr !22_S	et	f	\N
120866	sind	sind =sin  (SgP  >sa !00_P	et	f	\N
120867	sind	sind =sin  (SgP  >sina !00_P	et	f	\N
120874	harastused	?harastused =harastuse  (PlN  >harastus !11_S	et	f	\N
120875	targem	targem =targem  (SgN  >targem !02_A	et	f	\N
120876	targem	"targem %targe  )M_cA  <tark ;22_AS	et	f	\N
120879	palka	palka =palka  (SgP  >palk !22_S	et	f	\N
120880	palka	palka =palka  (SgAdt  >palk !22_S	et	f	\N
120881	palka	palka =palka  (IndPrPs_  >palkama !29_V	et	f	\N
120882	palka	palka =palka  (ImpPrSg2  >palkama !29_V	et	f	\N
120895	tervislikkult	?tervislikkult =tervislikkult  (ID  >tervislikkult !41_D	et	f	\N
120898	ravimetele	ravimetele =e  (PlAll  >ravim+esi !15_S	et	f	\N
120899	ravimetele	ravimetele =me  (PlAll  >ravi+mesi !15_S	et	f	\N
120900	ravimetele	ravimetele =mete  (PlAll  >ravi+mett !22_S	et	f	\N
120901	käime	käime =käi  (IndPrPl1  >käima !38_V	et	f	\N
120802	vanusest	vanusest =vanuse  (SgEl  >vanus !09_S	et	f	\N
120803	vanusest	vanusest =vanuse  (SgEl  >vanune !10_A	et	f	\N
120804	vanusest	vanusest =vanuses  (SgP  >vanusene !12_A	et	f	\N
120805	vanusest	"vanusene %vanuse  )NE_aA  <vanus ;09_S	et	f	\N
120814	rahata	rahata =raha  (SgAb  >raha !17_S	et	f	\N
120815	rahata	rahata =raha  (SgAb  >rahk !22_S	et	f	\N
120823	inimsel	?inimsel =inimse  (SgAd  >inimne !02_A	et	f	\N
120824	inimsel	?inimsel =inimse  (PlAd  >inimss !22_S	et	f	\N
120825	inimsel	?inimsel =inimsel  (SgN  >inimsel !02_S	et	f	\N
120844	suhtlemiseta	suhtlemiseta =suhtlemise  (SgAb  >suhtlemine !12_S	et	f	\N
120845	suhtlemiseta	"suhtlemine %suhtle  )MINE_vS  <suhtlema ;30_V	et	f	\N
120855	rahaga	rahaga =raha  (SgKom  >raha !17_S	et	f	\N
120856	rahaga	rahaga =raha  (SgKom  >rahk !22_S	et	f	\N
120864	abikaasa	abikaasa =kaasa  (SgN  >abi+kaasa !16_S	et	f	\N
120865	abikaasa	abikaasa =kaasa  (SgG  >abi+kaasa !16_S	et	f	\N
120877	peame	peame =pea  (IndPrPl1  >pida !40_V	et	f	\N
120878	peame	peame =pea  (IndPrPl1  >pidama !28_V	et	f	\N
120883	tasuline	tasuline =tasuline  (SgN  >tasuline !12_A	et	f	\N
120884	tasuline	"tasuline %tasu  )LINE_aA  <tasu ;17_S	et	f	\N
120887	laenu	laenu =laenu  (SgG  >laen !22_S	et	f	\N
120889	laenu	laenu =laenu  (SgP  >laen !22_S	et	f	\N
120890	laenu	laenu =laenu  (SgAdt  >laen !22_S	et	f	\N
120891	laenu	laenu =laenu  (IndPrPs_  >laenuma !27_V	et	f	\N
120892	laenu	laenu =laenu  (ImpPrSg2  >laenuma !27_V	et	f	\N
120903	jälutamas	?jälutamas =jäluta  (SupIn  >jälutama !27_V	et	f	\N
120904	jälutamas	?jälutamas =jälutama  (SgIn  >jälutam !02_A	et	f	\N
120915	lahutatud	lahutatud =lahuta  (PtsPtIps  >lahutama !27_V	et	f	\N
120916	lahutatud	lahutatud =lahutatu  (PlN  >lahutatu !01_S	et	f	\N
120917	lahutatud	"lahutatu %lahuta  )TU1_vS  <lahutama ;27_V	et	f	\N
120918	lahutatud	lahutatud =lahutatud  (ID  >lahutatud !41_A	et	f	\N
120919	lahutatud	"lahutatud %lahuta  )TUD_vA  <lahutama ;27_V	et	f	\N
120925	omandavad	omandavad =omanda  (IndPrPl3  >omandama !27_V	et	f	\N
120926	omandavad	omandavad =omandava  (PlN  >omandav !02_A	et	f	\N
120927	omandavad	"omandav %omanda  )V_vA  <omandama ;27_V	et	f	\N
120938	muudatakse	?muudatakse =muudatakse  (SgG  >muudatakne !02_A	et	f	\N
120939	muudatakse	?muudatakse =muudatakse  (PlP  >muudataks !22_S	et	f	\N
120940	muudatakse	?muudatakse =atakse  (SgG  >muud+atakne !02_A	et	f	\N
120941	muudatakse	?muudatakse =datakse  (SgG  >muu+datakne !02_A	et	f	\N
120969	väha	?väha =väha  (SgN  >väha !17_S	et	f	\N
120970	väha	?väha =väha  (SgG  >väha !17_S	et	f	\N
120971	väha	?väha =väha  (SgP  >väha !17_S	et	f	\N
120972	väha	?väha =väha  (IndPrPs_  >vähama !27_V	et	f	\N
120973	väha	?väha =väha  (ImpPrSg2  >vähama !27_V	et	f	\N
120975	sõbradeta	?sõbradeta =sõbra  (PlAb  >sõbra !16_S	et	f	\N
120976	sõbradeta	?sõbradeta =sõbradeta  (IndPrPs_  >sõbradetama !27_V	et	f	\N
120977	sõbradeta	?sõbradeta =sõbradeta  (ImpPrSg2  >sõbradetama !27_V	et	f	\N
120980	tõenäolisi	tõenäolisi =näolisi  (PlP  >tõe+näoline !12_A	et	f	\N
120981	tõenäolisi	"tõe+näoline %näo  )LINE_aA  <tõe+nägu ;18_S	et	f	\N
120982	nõudmisi	nõudmisi =nõudmisi  (PlP  >nõudmine !12_S	et	f	\N
120983	nõudmisi	"nõudmine %nõud  )MINE_vS  <nõudma ;34_V	et	f	\N
120989	rahalist	rahalist =rahalis  (SgP  >rahaline !12_A	et	f	\N
120990	rahalist	"rahaline %raha  )LINE_aA  <raha ;17_S	et	f	\N
120991	rahalist	"rahaline %raha  )LINE_aA  <rahk ;22_S	et	f	\N
120997	spansuhtlemise	?spansuhtlemise =spansuhtlemise  (SgG  >spansuhtlemine !12_S	et	f	\N
121014	värskes	?värskes =värske  (SgIn  >värske !01_AS	et	f	\N
121015	värskes	?värskes =värske  (PlIn  >värsk !22_S	et	f	\N
121016	värskes	?värskes =värske  (IndIpfSg3  >värskema !27_V	et	f	\N
121017	värskes	?värskes =värskes  (SgN  >värskes !09_S	et	f	\N
121018	kallis	kallis =kalli  (SgIn  >kallis !05~07_A	et	f	\N
121019	kallis	kallis =kallis  (SgN  >kallis !05~07_A	et	f	\N
121020	tasulise	tasulise =tasulise  (SgG  >tasuline !12_A	et	f	\N
121021	tasulise	"tasuline %tasu  )LINE_aA  <tasu ;17_S	et	f	\N
121031	tuttavad	tuttavad =tuttava  (PlN  >tuttav !02_AS	et	f	\N
121032	tuttavad	tuttavad =ava  (PlN  >tutt+ava !17_S	et	f	\N
121038	meelest	meelest =meele  (SgEl  >meel !13_S	et	f	\N
121039	meelest	meelest =meeles  (SgP  >meelene !10_A	et	f	\N
121040	meelest	"meelene %meele  )NE_aA  <meel ;13_S	et	f	\N
121041	meelest	meelest =meelest  (ID  >meelest !41_K	et	f	\N
121042	meelest	meelest =lest  (SgN  >mee+lest !22_S	et	f	\N
121055	uudisedabr	?uudisedabr =uudisedabr  (SgN  >uudisedabr !22_S	et	f	\N
121057	uudisedabr	?uudisedabr =dabr  (SgN  >uudise+dabr !22_S	et	f	\N
121058	uudisedabr	?uudisedabr =edabr  (SgN  >uudis+edabr !22_S	et	f	\N
121067	paremine	paremine =ine  (SgN  >parem+ine !16_S	et	f	\N
121068	paremine	paremine =ine  (SgG  >parem+ine !16_S	et	f	\N
121069	kompjutiseerida	?kompjutiseerida =kompjutiseeri  (Inf  >kompjutiseerima !28_V	et	f	\N
121078	ehitus	ehitus =ehitu  (SgIn  >ehitu !01_AS	et	f	\N
121079	ehitus	"ehitu %ehi  )TU1_vS  <ehtima ;28_V	et	f	\N
121080	ehitus	ehitus =ehitu  (IndIpfSg3  >ehituma !27_V	et	f	\N
120902	käime	käime =käime  (PlP  >käim !22_S	et	f	\N
120913	täispere	täispere =pere  (SgN  >täis+pere !16_S	et	f	\N
120914	täispere	täispere =pere  (SgG  >täis+pere !16_S	et	f	\N
120942	lihtsam	lihtsam =lihtsam  (SgN  >lihtsam !02_A	et	f	\N
120943	lihtsam	"lihtsam %lihtsa  )M_cA  <lihtne ;02_A	et	f	\N
120952	võõrkeeltest	võõrkeeltest =test  (SgN  >võõr+keel+test !22_S	et	f	\N
120953	võõrkeeltest	võõrkeeltest =keel  (PlEl  >võõr+keel !13_S	et	f	\N
120956	töötaja	töötaja =töötaja  (SgN  >töötaja !01_S	et	f	\N
120957	töötaja	"töötaja %tööta  )JA_vS  <töötama ;27_V	et	f	\N
120958	töötaja	töötaja =töötaja  (SgG  >töötaja !01_S	et	f	\N
120963	emakeeltest	emakeeltest =test  (SgN  >ema+keel+test !22_S	et	f	\N
120964	emakeeltest	emakeeltest =keel  (PlEl  >ema+keel !13_S	et	f	\N
121008	elamebr	?elamebr =elamebr  (SgN  >elamebr !22_S	et	f	\N
121022	osakonnas	osakonnas =osakonna  (SgIn  >osakond !22_S	et	f	\N
121023	osakonnas	osakonnas =konna  (SgIn  >osa+konn !22_S	et	f	\N
121050	nisuguset	?nisuguset =guse  (SgP  >nisu+guse !16_S	et	f	\N
121052	rahat	?rahat =rahat  (SgN  >rahat !02_S	et	f	\N
121059	söema	?söema =söema  (SgN  >söema !16_S	et	f	\N
121060	söema	?söema =söema  (SgG  >söema !16_S	et	f	\N
121061	söema	?söema =söema  (IndPrPs_  >söemama !29_V	et	f	\N
121062	söema	?söema =söema  (ImpPrSg2  >söemama !29_V	et	f	\N
121100	postiga	postiga =posti  (SgKom  >post !22_S	et	f	\N
121101	postiga	postiga =iga  (SgN  >post+iga !18_S	et	f	\N
121102	postiga	postiga =iga  (SgP  >post+iga !18_S	et	f	\N
121107	otsime	otsime =otsi  (IndPrPl1  >otsima !28_V	et	f	\N
121108	otsime	otsime =ime  (SgN  >ots+ime !16_S	et	f	\N
121109	otsime	otsime =ime  (SgG  >ots+ime !16_S	et	f	\N
121142	mitmest	mitmest =mitme  (SgEl  >mitu !05_P	et	f	\N
121143	mitmest	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
121144	mitmest	mitmest =mitmes  (SgP  >mitmene !12~10_A	et	f	\N
121153	huvitavamat	huvitavamat =huvitavama  (SgP  >huvitavam !02_A	et	f	\N
121154	huvitavamat	"huvitavam %huvita  )VAM_cA  <huvitama ;27_V	et	f	\N
121155	huvitavamat	"huvitavam %huvitava  )M_cA  <huvitav ;02_A	et	f	\N
121198	arvutitabr	?arvutitabr =arvutitabr  (SgN  >arvutitabr !22_S	et	f	\N
121200	arvutitabr	?arvutitabr =tabr  (SgN  >arvuti+tabr !22_S	et	f	\N
121202	arvutitabr	?arvutitabr =titabr  (SgN  >arvu+titabr !22_S	et	f	\N
121203	arvutitabr	?arvutitabr =utitabr  (SgN  >arv+utitabr !22_S	et	f	\N
121227	punktid	punktid =punkti  (PlN  >punkt !22_S	et	f	\N
121228	punktid	punktid =punkti  (IndPrSg2  >punktima !28_V	et	f	\N
121234	ülekormus	?ülekormus =ülekormu  (IndIpfSg3  >ülekormuma !27_V	et	f	\N
121235	ülekormus	?ülekormus =ülekormus  (SgN  >ülekormus !11~09_S	et	f	\N
121236	ülekormus	?ülekormus =kormu  (SgIn  >üle+kormu !16_S	et	f	\N
121237	ülekormus	?ülekormus =kormus  (SgN  >üle+kormus !11~09_S	et	f	\N
121252	mugavust	mugavust =mugavus  (SgP  >mugavus !11_S	et	f	\N
121253	mugavust	"mugavus %mugava  )US_aS  <mugav ;02_A	et	f	\N
121264	süüdi	süüdi =süüdi  (ID  >süüdi !41_D	et	f	\N
121265	süüdi	süüdi =süüdi  (SgG  >süüd !22_S	et	f	\N
121266	süüdi	süüdi =süüdi  (SgP  >süüd !22_S	et	f	\N
121267	süüdi	süüdi =süüdi  (SgAdt  >süüd !22_S	et	f	\N
121270	otsustamist	otsustamist =otsustamis  (SgP  >otsustamine !12_S	et	f	\N
121271	otsustamist	"otsustamine %otsusta  )MINE_vS  <otsustama ;27_V	et	f	\N
121281	firma	firma =firma  (SgN  >firma !16_S	et	f	\N
121282	firma	firma =firma  (SgG  >firma !16_S	et	f	\N
121283	tööprojekti	tööprojekti =projekti  (SgG  >töö+projekt !22_S	et	f	\N
121284	tööprojekti	tööprojekti =projekti  (SgP  >töö+projekt !22_S	et	f	\N
121285	tööprojekti	tööprojekti =projekti  (SgAdt  >töö+projekt !22_S	et	f	\N
121296	uueid	?uueid =uue  (PlP  >uue !06_S	et	f	\N
121297	uueid	?uueid =uueid  (SgN  >uueid !02_S	et	f	\N
121314	disaini	disaini =disaini  (SgG  >disain !22_S	et	f	\N
121315	disaini	disaini =disaini  (SgP  >disain !22_S	et	f	\N
121316	disaini	disaini =disaini  (SgAdt  >disain !22_S	et	f	\N
121317	joonestamis	?joonestamis =joonestami  (SgIn  >joonestam !02_A	et	f	\N
121318	joonestamis	?joonestamis =joonestamis  (SgN  >joonestamis !09_S	et	f	\N
121319	joonestamis	?joonestamis =stami  (SgIn  >joone+stami !17_S	et	f	\N
121320	joonestamis	?joonestamis =stamis  (SgN  >joone+stamis !09_S	et	f	\N
121323	tsirklid	?tsirklid =tsirkli  (PlN  >tsirkli !01_S	et	f	\N
121324	tsirklid	?tsirklid =tsirkli  (PlN  >tsirkel !02_S	et	f	\N
121325	tsirklid	?tsirklid =tsirkli  (IndPrSg2  >tsirklima !28_V	et	f	\N
121346	pidavad	pidavad =pidava  (PlN  >pidav !02_A	et	f	\N
121347	pidavad	"pidav %pida  )V_vA  <pidama ;28_V	et	f	\N
121350	väljas	väljas =välja  (SgIn  >väli !24_S	et	f	\N
121353	väljas	väljas =välja  (IndIpfSg3  >väljama !29_V	et	f	\N
121354	väljas	väljas =väljas  (ID  >väljas !41_D	et	f	\N
121359	muusikuga	muusikuga =muusiku  (SgKom  >muusik !02_S	et	f	\N
121360	muusikuga	muusikuga =siku  (SgKom  >muu+sikk !22_S	et	f	\N
121361	treeningusse	treeningusse =treeningu  (SgIll  >treening !02_S	et	f	\N
121362	treeningusse	treeningusse =usse  (PlP  >treening+uss !22_S	et	f	\N
121379	erilised	erilised =erilise  (PlN  >eriline !12_A	et	f	\N
120928	haridust	haridust =haridus  (SgP  >haridus !11_S	et	f	\N
120929	haridust	haridust =dust  (SgN  >hari+dust !22_S	et	f	\N
120930	õppivad	õppivad =õppiva  (PlN  >õppiv !02_A	et	f	\N
120933	õppivad	"õppiv %õppi  )V_vA  <õppima ;28_V	et	f	\N
120944	otsida	otsida =otsi  (Inf  >otsima !28_V	et	f	\N
120945	otsida	otsida =ida  (SgN  >ots+ida !17_S	et	f	\N
120946	otsida	otsida =ida  (SgG  >ots+ida !17_S	et	f	\N
120947	otsida	otsida =ida  (SgP  >ots+ida !17_S	et	f	\N
120959	valdavad	valdavad =valda  (IndPrPl3  >valdama !29_V	et	f	\N
120960	valdavad	valdavad =valdava  (PlN  >valdav !02_A	et	f	\N
120961	valdavad	"valdav %valda  )V_vA  <valdama ;29_V	et	f	\N
120962	valdavad	valdavad =ava  (PlN  >vald+ava !17_S	et	f	\N
120965	rool	rool =roo  (SgAd  >rood !22_S	et	f	\N
120966	rool	rool =roo  (SgAd  >roog !22_S	et	f	\N
120967	rool	rool =roo  (SgAd  >roo !26_S	et	f	\N
120968	rool	rool =rool  (SgN  >rool !22_S	et	f	\N
120996	huvitavamspan	?huvitavamspan =huvitavamspan  (SgN  >huvitavamspan !02_S	et	f	\N
120998	huvitavamspan	?huvitavamspan =tavamspan  (SgN  >huvi+tavamspan !02_S	et	f	\N
120999	inglisekeel	inglisekeel =kee  (SgAd  >inglise+kesi !15_S	et	f	\N
121000	inglisekeel	inglisekeel =kee  (SgAd  >inglise+kee !26_S	et	f	\N
121002	inglisekeel	inglisekeel =keel  (SgN  >inglise+keel !13_S	et	f	\N
121033	ringis	ringis =ringi  (SgIn  >ring !22_S	et	f	\N
121034	ringis	ringis =ringi  (IndIpfSg3  >ringima !28_V	et	f	\N
121035	ringis	ringis =ringis  (ID  >ringis !41_K	et	f	\N
121049	hoia	hoia =hoia  (IndPrPs_  >hoidma !34_V	et	f	\N
121051	hoia	hoia =hoia  (ImpPrSg2  >hoidma !34_V	et	f	\N
121063	toiduainedeta	?toiduainedeta =toiduaine  (PlAb  >toiduaine !16_S	et	f	\N
121064	toiduainedeta	?toiduainedeta =toiduainedeta  (IndPrPs_  >toiduainedetama !27_V	et	f	\N
121065	toiduainedeta	?toiduainedeta =toiduainedeta  (ImpPrSg2  >toiduainedetama !27_V	et	f	\N
121070	oppida	?oppida =oppi  (Inf  >oppima !28_V	et	f	\N
121089	arvutis	arvutis =arvuti  (SgIn  >arvuti !01_S	et	f	\N
121090	arvutis	arvutis =arvutis  (SgN  >arvutis !11_S	et	f	\N
121091	arvutis	arvutis =uti  (SgIn  >arv+utt !22_S	et	f	\N
121092	arvutis	arvutis =uti  (PlIn  >arv+utt !22_S	et	f	\N
121093	aadressi	aadressi =aadressi  (SgG  >aadress !22_S	et	f	\N
121094	aadressi	aadressi =aadressi  (SgP  >aadress !22_S	et	f	\N
121096	aadressi	aadressi =aadressi  (SgAdt  >aadress !22_S	et	f	\N
121113	mailmas	?mailmas =mailma  (IndIpfSg3  >mailmama !29_V	et	f	\N
121114	mailmas	?mailmas =mailmas  (SgN  >mailmas !07_S	et	f	\N
121115	sööme	sööme =söö  (IndPrPl1  >sööma !38_V	et	f	\N
121116	sööme	sööme =sööme  (PlP  >sööm !22_S	et	f	\N
121122	inimeseid	?inimeseid =inimesei  (PlN  >inimesei !26_S	et	f	\N
121123	inimeseid	?inimeseid =inimesei  (SgP  >inimesei !26_S	et	f	\N
121124	inimeseid	?inimeseid =esei  (PlN  >inim+esei !26_S	et	f	\N
121125	inimeseid	?inimeseid =esei  (SgP  >inim+esei !26_S	et	f	\N
121126	inimeseid	?inimeseid =eseid  (SgN  >inim+eseid !22_S	et	f	\N
121136	maitse	maitse =maitse  (SgN  >maitse !06_S	et	f	\N
121137	maitse	maitse =maitse  (SgG  >maitse !06_S	et	f	\N
121138	maitse	maitse =maitse  (IndPrPs_  >maitsema !28_V	et	f	\N
121139	maitse	maitse =maitse  (IndPrPs_  >maitsma !32_V	et	f	\N
121140	maitse	maitse =maitse  (ImpPrSg2  >maitsema !28_V	et	f	\N
121141	maitse	maitse =maitse  (ImpPrSg2  >maitsma !32_V	et	f	\N
121169	tööstbr	?tööstbr =tööstbr  (SgN  >tööstbr !22_S	et	f	\N
121226	kõiged	?kõiged =kõige  (IndPrSg2  >kõigema !27_V	et	f	\N
121256	liisada	### liisada	et	f	\N
121259	kutseline	kutseline =kutseline  (SgN  >kutseline !12_A	et	f	\N
121260	kutseline	"kutseline %kutse  )LINE_aA  <kutse ;06_S	et	f	\N
121309	arhitekst	### arhitekst	et	f	\N
121331	kirjuatmine	?kirjuatmine =kirjuatmine  (SgN  >kirjuatmine !12_A	et	f	\N
121334	pastapliiats	pastapliiats =ats  (SgN  >pasta+plii+ats !22_S	et	f	\N
121336	pastapliiats	pastapliiats =pliiats  (SgN  >pasta+pliiats !02_S	et	f	\N
121340	tahtejõulisust	tahtejõulisust =jõulisus  (SgP  >tahte+jõulisus !11_S	et	f	\N
121341	tahtejõulisust	"tahte+jõulisus %jõu  )LISUS_aS  <tahte+jõud ;22_S	et	f	\N
121342	tahtejõulisust	"tahte+jõulisus %jõuli  )SUS_aS  <tahte+jõul ;22_S	et	f	\N
121343	õppematerjali	õppematerjali =materjali  (SgG  >õppe+materjal !19_S	et	f	\N
121344	õppematerjali	õppematerjali =materjali  (SgP  >õppe+materjal !19_S	et	f	\N
121345	õppematerjali	õppematerjali =materjali  (SgAdt  >õppe+materjal !19_S	et	f	\N
121367	viisakas	viisakas =viisaka  (SgIn  >viisakas !02_A	et	f	\N
121368	viisakas	viisakas =viisakas  (SgN  >viisakas !02_A	et	f	\N
121369	viisakas	viisakas =aka  (SgIn  >viis+aka !16_S	et	f	\N
121375	ehitavad	ehitavad =ehita  (IndPrPl3  >ehitama !27_V	et	f	\N
121376	ehitavad	ehitavad =ehitava  (PlN  >ehitav !02_A	et	f	\N
121377	ehitavad	"ehitav %ehi  )TAV_vAS  <ehtima ;28_V	et	f	\N
121378	ehitavad	"ehitav %ehita  )V_vA  <ehitama ;27_V	et	f	\N
121387	ehitajaks	ehitajaks =ehitaja  (SgTr  >ehitaja !01_S	et	f	\N
121388	ehitajaks	"ehitaja %ehita  )JA_vS  <ehitama ;27_V	et	f	\N
121398	grammatiliselt	grammatiliselt =grammatilise  (SgAbl  >grammatiline !12_A	et	f	\N
121399	grammatiliselt	grammatiliselt =grammatiliselt  (ID  >grammatiliselt !41_D	et	f	\N
120931	stipeendiumiga	?stipeendiumiga =stipeendiumi  (SgKom  >stipeendium !19~02_S	et	f	\N
120932	stipeendiumiga	?stipeendiumiga =stipeendiumi  (SgKom  >stipeendiumi !16_S	et	f	\N
120934	suitseta	suitseta =suitse  (SgAb  >suitse !06_S	et	f	\N
120935	suitseta	suitseta =suitse  (IndPrIps_  >suitsema !28_V	et	f	\N
120936	suitseta	suitseta =suitseta  (IndPrPs_  >suitsetama !27_V	et	f	\N
120937	suitseta	suitseta =suitseta  (ImpPrSg2  >suitsetama !27_V	et	f	\N
120954	osatakse	osatakse =osa  (IndPrIps  >oskama !29_V	et	f	\N
120955	osatakse	osatakse =takse  (PlP  >osa+taks !22_S	et	f	\N
120974	raskebr	?raskebr =raskebr  (SgN  >raskebr !22_S	et	f	\N
120978	euroliidus	euroliidus =liidu  (SgIn  >euro+liit !22_S	et	f	\N
120979	euroliidus	euroliidus =liidus  (SgN  >euro+liidus !09_S	et	f	\N
120995	piired	?piired =piire  (IndPrSg2  >piirema !27_V	et	f	\N
121001	saksakeel	saksakeel =kee  (SgAd  >saksa+kesi !15_S	et	f	\N
121003	saksakeel	saksakeel =kee  (SgAd  >saksa+kee !26_S	et	f	\N
121004	saksakeel	saksakeel =keel  (SgN  >saksa+keel !13_S	et	f	\N
121009	täiskasvanu	täiskasvanu =vanu  (PlP  >täis+kas+vana !17_AS	et	f	\N
121010	täiskasvanu	täiskasvanu =kasvanu  (SgN  >täis+kasvanu !01_S	et	f	\N
121011	täiskasvanu	täiskasvanu =kasvanu  (SgG  >täis+kasvanu !01_S	et	f	\N
121043	praigu	?praigu =praigu  (SgN  >praigu !16_S	et	f	\N
121044	praigu	?praigu =praigu  (SgG  >praigu !16_S	et	f	\N
121045	praigu	?praigu =praigu  (IndPrPs_  >praiguma !27_V	et	f	\N
121046	praigu	?praigu =praigu  (IndPrPs_  >praikuma !28_V	et	f	\N
121047	praigu	?praigu =praigu  (ImpPrSg2  >praiguma !27_V	et	f	\N
121048	praigu	?praigu =praigu  (ImpPrSg2  >praikuma !28_V	et	f	\N
121053	jalgida	jalgida =ida  (SgN  >jalg+ida !17_S	et	f	\N
121054	jalgida	jalgida =ida  (SgG  >jalg+ida !17_S	et	f	\N
121056	jalgida	jalgida =ida  (SgP  >jalg+ida !17_S	et	f	\N
121066	kõrg	?kõrg =kõrg  (SgN  >kõrg !22_S	et	f	\N
121071	suheldada	?suheldada =suhelda  (Inf  >suheldama !27_V	et	f	\N
121072	ettevõttest	ettevõttest =võtte  (SgEl  >ette+võte !06_S	et	f	\N
121073	ettevõttest	ettevõttest =võttes  (SgP  >ette+võttene !12~10_A	et	f	\N
121074	ettevõttest	"ette+võttene %võtte  )NE_aA  <ette+võte ;06_S	et	f	\N
121095	emeile	?emeile =emei  (SgAll  >emei !26_S	et	f	\N
121097	emeile	?emeile =emeile  (PlP  >emeil !22_S	et	f	\N
121098	emeile	?emeile =emeile  (IndPrPs_  >emeilema !27_V	et	f	\N
121099	emeile	?emeile =emeile  (ImpPrSg2  >emeilema !27_V	et	f	\N
121103	suheldab	?suheldab =suhelda  (IndPrSg3  >suheldama !27_V	et	f	\N
121131	panevad	panevad =pane  (IndPrPl3  >panema !36_V	et	f	\N
121132	panevad	panevad =paneva  (PlN  >panev !02_A	et	f	\N
121133	panevad	"panev %pane  )V_vA  <panema ;36_V	et	f	\N
121134	assortiment	?assortiment =assortiment  (SgN  >assortiment !22_S	et	f	\N
121135	võttab	?võttab =võtta  (IndPrSg3  >võttama !29_V	et	f	\N
121156	armastuseta	armastuseta =armastuse  (SgAb  >armastus !11_S	et	f	\N
121157	armastuseta	"armastus %armasta  )US_vS  <armastama ;27_V	et	f	\N
121183	konkurentsivõime	konkurentsivõime =võime  (SgN  >konkurentsi+võime !06_S	et	f	\N
121184	konkurentsivõime	konkurentsivõime =võime  (SgG  >konkurentsi+võime !06_S	et	f	\N
121185	konkurentsivõime	konkurentsivõime =võime  (PlP  >konkurentsi+võim !22_S	et	f	\N
121186	ühiskondas	?ühiskondas =ühiskonda  (SgIn  >ühiskonda !16_S	et	f	\N
121187	ühiskondas	?ühiskondas =ühiskonda  (IndIpfSg3  >ühiskondama !27_V	et	f	\N
121188	ühiskondas	?ühiskondas =konda  (SgIn  >ühis+konda !16_S	et	f	\N
121189	ühiskondas	?ühiskondas =kondas  (SgN  >ühis+kondas !07_S	et	f	\N
121195	internetita	?internetita =interneti  (IndPrIps_  >internettima !28_V	et	f	\N
121196	internetita	?internetita =internetita  (IndPrPs_  >internetitama !27_V	et	f	\N
121197	internetita	?internetita =internetita  (ImpPrSg2  >internetitama !27_V	et	f	\N
121199	internetita	?internetita =neti  (SgAb  >inter+neti !16_S	et	f	\N
121201	internetita	?internetita =neti  (SgAb  >inter+nett !22_AS	et	f	\N
121207	karjääri	karjääri =karjääri  (SgG  >karjäär !22_S	et	f	\N
121208	karjääri	karjääri =karjääri  (SgP  >karjäär !22_S	et	f	\N
121209	karjääri	karjääri =karjääri  (SgAdt  >karjäär !22_S	et	f	\N
121214	tugevalt	tugevalt =tugeva  (SgAbl  >tugev !02_A	et	f	\N
121215	tugevalt	"tugev %tuge  )V_vA  <tugema ;27_V	et	f	\N
121216	tugevalt	tugevalt =tugevalt  (ID  >tugevalt !41_D	et	f	\N
121218	tugevalt	"tugevalt %tuge  )VALT_mD  <tugema ;27_V	et	f	\N
121220	tugevalt	"tugevalt %tugeva  )LT_mD  <tugev ;02_A	et	f	\N
121222	olgugi	olgugi =olgugi  (ID  >olgugi !41_J	et	f	\N
121223	olgugi	olgugi =ol  (ImpPrPs^  >olema !36_V	et	f	\N
121232	temno	?temno =temno  (SgN  >temno !16_S	et	f	\N
121233	temno	?temno =temno  (SgG  >temno !16_S	et	f	\N
121240	teisest	teisest =teise  (SgEl  >teine !12_OP	et	f	\N
121241	teisest	teisest =teise  (SgEl  >teise !12_P	et	f	\N
121242	teisest	teisest =teises  (SgP  >teisene !10_A	et	f	\N
121243	teisest	"teisene %teise  )NE_aA  <teine ;12_NP	et	f	\N
121244	vajas	vajas =vaja  (SgIn  >vaja !17_S	et	f	\N
121245	vajas	vajas =vaja  (IndIpfSg3  >vajama !27_V	et	f	\N
121261	auhindu	auhindu =hindu  (SgN  >au+hindu !16_S	et	f	\N
121262	auhindu	auhindu =hindu  (SgG  >au+hindu !16_S	et	f	\N
120985	tõstetatud	?tõstetatud =tõstetatu  (PlN  >tõstetatu !01_S	et	f	\N
120986	tõstetatud	?tõstetatud =tõstetatu  (IndPrSg2  >tõstetatuma !27_V	et	f	\N
120987	tõstetatud	?tõstetatud =tõstetatud  (ID  >tõstetatud !41_A	et	f	\N
120988	tõstetatud	?tõstetatud =tatu  (PlN  >tõste+tatu !16_S	et	f	\N
120992	pidevalt	pidevalt =pideva  (SgAbl  >pidev !02_A	et	f	\N
120993	pidevalt	pidevalt =pidevalt  (ID  >pidevalt !41_D	et	f	\N
120994	pidevalt	"pidevalt %pideva  )LT_mD  <pidev ;02_A	et	f	\N
121005	soomekeel	soomekeel =kee  (SgAd  >soome+kesi !15_S	et	f	\N
121006	soomekeel	soomekeel =kee  (SgAd  >soome+kee !26_S	et	f	\N
121007	soomekeel	soomekeel =keel  (SgN  >soome+keel !13_S	et	f	\N
121012	jäoks	?jäoks =jäo  (SgTr  >jäo !26_S	et	f	\N
121013	jäoks	?jäoks =jäoks  (SgN  >jäoks !22_S	et	f	\N
121024	üüri	üüri =üüri  (SgG  >üür !22_S	et	f	\N
121025	üüri	üüri =üüri  (SgP  >üür !22_S	et	f	\N
121026	üüri	üüri =üüri  (SgAdt  >üür !22_S	et	f	\N
121027	üüri	üüri =üüri  (IndPrPs_  >üürima !28_V	et	f	\N
121028	üüri	üüri =üüri  (ImpPrSg2  >üürima !28_V	et	f	\N
121029	võimelised	võimelised =võimelise  (PlN  >võimeline !12_A	et	f	\N
121030	võimelised	"võimeline %võime  )LINE_aA  <võime ;06_S	et	f	\N
121036	otsustbr	?otsustbr =otsustbr  (SgN  >otsustbr !22_S	et	f	\N
121037	otsustbr	?otsustbr =ustbr  (SgN  >ots+ustbr !22_S	et	f	\N
121075	kiiremine	?kiiremine =kiiremine  (SgN  >kiiremine !12_S	et	f	\N
121076	kiiremine	?kiiremine =kiiremine  (PlP  >kiiremin !19_S	et	f	\N
121077	kiiremine	?kiiremine =emine  (SgN  >kiir+emine !10_A	et	f	\N
121084	politsei	politsei =politsei  (SgN  >politsei !26_S	et	f	\N
121085	politsei	politsei =politsei  (SgG  >politsei !26_S	et	f	\N
121104	sõpraga	### sõpraga	et	f	\N
121105	arvutuga	arvutuga =arvutu  (SgKom  >arvutu !01_A	et	f	\N
121106	arvutuga	"arvutu %arvu  )TU2_kA  <arv ;22_S	et	f	\N
121110	samatooriumi	samatooriumi =tooriumi  (SgG  >sama+toorium !19~02_S	et	f	\N
121111	samatooriumi	samatooriumi =tooriumi  (SgP  >sama+toorium !19_S	et	f	\N
121112	samatooriumi	samatooriumi =tooriumi  (SgAdt  >sama+toorium !19_S	et	f	\N
121127	supermarketis	?supermarketis =supermarketi  (SgIn  >supermarkett !22_S	et	f	\N
121128	supermarketis	?supermarketis =supermarketis  (SgN  >supermarketis !09_S	et	f	\N
121129	supermarketis	?supermarketis =marketi  (SgIn  >super+markett !22_S	et	f	\N
121130	supermarketis	?supermarketis =marketis  (SgN  >super+marketis !11_S	et	f	\N
121145	asjast	asjast =asja  (SgEl  >asi !24_S	et	f	\N
121146	asjast	asjast =asjas  (SgP  >asjane !10_A	et	f	\N
121147	asjast	"asjane %asja  )NE_aA  <asi ;24_S	et	f	\N
121158	materiaalselt	materiaalselt =materiaalse  (SgAbl  >materiaalne !02_A	et	f	\N
121159	materiaalselt	materiaalselt =materiaalselt  (ID  >materiaalselt !41_D	et	f	\N
121160	materiaalselt	"materiaalselt %materiaalse  )LT_mD  <materiaalne ;02_A	et	f	\N
121167	rahad	rahad =raha  (PlN  >raha !17_S	et	f	\N
121168	rahad	rahad =raha  (PlN  >rahk !22_S	et	f	\N
121180	eriala	eriala =ala  (SgN  >eri+ala !17_S	et	f	\N
121181	eriala	eriala =ala  (SgG  >eri+ala !17_S	et	f	\N
121182	eriala	eriala =ala  (SgP  >eri+ala !17_S	et	f	\N
121190	paremaksbr	?paremaksbr =aksbr  (SgN  >parem+aksbr !22_S	et	f	\N
121191	kujutavad	kujutavad =kujuta  (IndPrPl3  >kujutama !27_V	et	f	\N
121192	kujutavad	kujutavad =kujutava  (PlN  >kujutav !02_A	et	f	\N
121193	kujutavad	"kujutav %kujuta  )V_vA  <kujutama ;27_V	et	f	\N
121194	kujutavad	kujutavad =tava  (PlN  >kuju+tava !17_S	et	f	\N
121204	üksinda	üksinda =üksinda  (ID  >üksinda !41_D	et	f	\N
121205	üksinda	üksinda =inda  (SgP  >üks+ind !22_S	et	f	\N
121206	üksinda	üksinda =inda  (SgAdt  >üks+ind !22_S	et	f	\N
121210	piidevalt	?piidevalt =piideva  (SgAbl  >piideva !01_S	et	f	\N
121211	piidevalt	?piidevalt =piideva  (SgAbl  >piidev !02_A	et	f	\N
121212	piidevalt	?piidevalt =piidevalt  (ID  >piidevalt !41_D	et	f	\N
121224	teiseski	teiseski =teise  (SgIn^  >teine !12_OP	et	f	\N
121225	teiseski	teiseski =teise  (SgIn^  >teise !12_P	et	f	\N
121246	puhkada	?puhkada =ada  (SgN  >puhk+ada !17_S	et	f	\N
121247	puhkada	?puhkada =ada  (SgG  >puhk+ada !17_S	et	f	\N
121248	puhkada	?puhkada =ada  (SgP  >puhk+ada !17_S	et	f	\N
121254	radio	?radio =radio  (SgN  >radio !01_S	et	f	\N
121255	radio	?radio =radio  (SgG  >radio !01_S	et	f	\N
121257	kõigele	kõigele =kõige  (SgAll  >kõik !00_P	et	f	\N
121258	kõigele	kõigele =kõige  (PlAll  >kõik !22_S	et	f	\N
121277	tagasihoitud	tagasihoitud =hoi  (PtsPtIps  >tagasi+_hoidma !34_V	et	f	\N
121278	tagasihoitud	tagasihoitud =hoitu  (PlN  >tagasi+hoitu !01_S	et	f	\N
121279	firmajuhtija	firmajuhtija =juhtija  (SgN  >firma+juhtija !01_S	et	f	\N
121280	firmajuhtija	firmajuhtija =juhtija  (SgG  >firma+juhtija !01_S	et	f	\N
121326	stiili	stiili =stiili  (SgG  >stiil !22_S	et	f	\N
121327	stiili	stiili =stiili  (SgP  >stiil !22_S	et	f	\N
121328	stiili	stiili =stiili  (SgAdt  >stiil !22_S	et	f	\N
121329	stiili	stiili =stiili  (IndPrPs_  >stiilima !28_V	et	f	\N
121330	stiili	stiili =stiili  (ImpPrSg2  >stiilima !28_V	et	f	\N
121348	laud	laud =lau  (PlN  >laug !22_SA	et	f	\N
121349	laud	laud =laud  (SgN  >laud !22_S	et	f	\N
121081	ehitus	ehitus =ehitus  (SgN  >ehitus !11_S	et	f	\N
121082	ehitus	"ehitus %ehita  )US_vS  <ehitama ;27_V	et	f	\N
121083	ehitus	"ehitus %ehi  )TUS1_aS  <ehtima ;28_V	et	f	\N
121086	sõidujaamat	?sõidujaamat =sõidujaama  (SgP  >sõidujaama !16_S	et	f	\N
121087	sõidujaamat	?sõidujaamat =jaama  (SgP  >sõidu+jaama !16_S	et	f	\N
121088	sõidujaamat	?sõidujaamat =jaamat  (SgN  >sõidu+jaamat !02_S	et	f	\N
121117	värske	?värske =värske  (SgN  >värske !01_AS	et	f	\N
121118	värske	?värske =värske  (SgG  >värske !01_AS	et	f	\N
121119	värske	?värske =värske  (PlP  >värsk !22_S	et	f	\N
121120	värske	?värske =värske  (IndPrPs_  >värskema !27_V	et	f	\N
121121	värske	?värske =värske  (ImpPrSg2  >värskema !27_V	et	f	\N
121148	kvalifitseeritud	kvalifitseeritud =kvalifitseeri  (PtsPtIps  >kvalifitseerima !28_V	et	f	\N
121149	kvalifitseeritud	kvalifitseeritud =kvalifitseeritu  (PlN  >kvalifitseeritu !01_S	et	f	\N
121150	kvalifitseeritud	"kvalifitseeritu %kvalifitseeri  )TU1_vS  <kvalifitseerima ;28_V	et	f	\N
121151	kvalifitseeritud	kvalifitseeritud =kvalifitseeritud  (ID  >kvalifitseeritud !41_A	et	f	\N
121152	kvalifitseeritud	"kvalifitseeritud %kvalifitseeri  )TUD_vA  <kvalifitseerima ;28_V	et	f	\N
121161	rahuldust	rahuldust =rahuldus  (SgP  >rahuldus !11_S	et	f	\N
121162	rahuldust	"rahuldus %rahulda  )US_vS  <rahuldama ;27_V	et	f	\N
121163	rahuldust	rahuldust =dust  (SgN  >rahul+dust !22_S	et	f	\N
121164	haridusest	haridusest =hariduse  (SgEl  >haridus !11_S	et	f	\N
121165	haridusest	haridusest =hariduses  (SgP  >haridusene !12_A	et	f	\N
121166	haridusest	"haridusene %hariduse  )NE_aA  <haridus ;11_S	et	f	\N
121170	sina	sina =sina  (SgN  >sina !00_P	et	f	\N
121171	sina	sina =si  (SgEs  >si !26_S	et	f	\N
121172	sina	sina =sina  (SgN  >sina !17_S	et	f	\N
121173	sina	sina =sina  (SgG  >sina !17_S	et	f	\N
121174	sina	sina =sina  (SgP  >sina !17_S	et	f	\N
121175	sina	sina =sina  (IndPrPs_  >sinama !27_V	et	f	\N
121176	sina	sina =sina  (ImpPrSg2  >sinama !27_V	et	f	\N
121177	taibukalt	taibukalt =taibuka  (SgAbl  >taibukas !02_A	et	f	\N
121178	taibukalt	taibukalt =taibukalt  (ID  >taibukalt !41_D	et	f	\N
121179	taibukalt	"taibukalt %taibuka  )LT_mD  <taibukas ;02_A	et	f	\N
121213	eladabr	?eladabr =eladabr  (SgN  >eladabr !22_S	et	f	\N
121217	mõjuvad	mõjuvad =mõju  (IndPrPl3  >mõjuma !27_V	et	f	\N
121219	mõjuvad	mõjuvad =mõjuva  (PlN  >mõjuv !02_A	et	f	\N
121221	mõjuvad	"mõjuv %mõju  )V_vA  <mõjuma ;27_V	et	f	\N
121229	normaalselt	normaalselt =normaalse  (SgAbl  >normaalne !02_A	et	f	\N
121230	normaalselt	normaalselt =normaalselt  (ID  >normaalselt !41_D	et	f	\N
121231	normaalselt	"normaalselt %normaalse  )LT_mD  <normaalne ;02_A	et	f	\N
121238	abukasa	?abukasa =abukasa  (SgN  >abukasa !16_S	et	f	\N
121239	abukasa	?abukasa =abukasa  (SgG  >abukasa !16_S	et	f	\N
121249	viisakaid	viisakaid =viisaka  (PlP  >viisakas !02_A	et	f	\N
121250	viisakaid	viisakaid =kai  (PlN  >viisa+kai !26_S	et	f	\N
121251	viisakaid	viisakaid =kai  (SgP  >viisa+kai !26_S	et	f	\N
121268	seaduste	seaduste =seadus  (PlG  >seadus !11~09_S	et	f	\N
121269	seaduste	seaduste =duste  (PlP  >sea+dust !22_S	et	f	\N
121272	advokaati	advokaati =advokaati  (SgP  >advokaat !22_S	et	f	\N
121273	advokaati	advokaati =advokaati  (SgAdt  >advokaat !22_S	et	f	\N
121286	oskusid	?oskusid =osku  (PlP  >osku !16_S	et	f	\N
121287	oskusid	?oskusid =osku  (IndIpfSg2  >oskuma !27_V	et	f	\N
121288	oskusid	?oskusid =osku  (IndIpfPl3  >oskuma !27_V	et	f	\N
121289	julge	julge =julge  (SgN  >julge !01_A	et	f	\N
121290	julge	julge =julge  (SgG  >julge !01_A	et	f	\N
121291	julge	julge =julge  (IndPrPs_  >julgema !27_V	et	f	\N
121292	julge	julge =julge  (ImpPrSg2  >julgema !27_V	et	f	\N
121298	tehnoloogijaid	?tehnoloogijaid =tehnoloogija  (PlP  >tehnoloogija !01_S	et	f	\N
121299	tehnoloogijaid	?tehnoloogijaid =tehnoloogija  (PlP  >tehnoloogijas !02_A	et	f	\N
121300	tehnoloogijaid	?tehnoloogijaid =tehnoloogijai  (PlN  >tehnoloogijai !26_S	et	f	\N
121301	tehnoloogijaid	?tehnoloogijaid =tehnoloogijai  (SgP  >tehnoloogijai !26_S	et	f	\N
121302	tehnoloogijaid	?tehnoloogijaid =gija  (PlP  >tehno+loo+gijas !09_S	et	f	\N
121303	tehnoloogijaid	?tehnoloogijaid =gijai  (PlN  >tehno+loo+gijai !26_S	et	f	\N
121304	tehnoloogijaid	?tehnoloogijaid =gijai  (SgP  >tehno+loo+gijai !26_S	et	f	\N
121305	tehnoloogijaid	?tehnoloogijaid =gijaid  (SgN  >tehno+loo+gijaid !22_S	et	f	\N
121306	tehnoloogijaid	?tehnoloogijaid =loogija  (PlP  >tehno+loogija !01_S	et	f	\N
121307	tehnoloogijaid	?tehnoloogijaid =loogija  (PlP  >tehno+loogijas !02_A	et	f	\N
121308	tehnoloogijaid	?tehnoloogijaid =loogijai  (PlN  >tehno+loogijai !26_S	et	f	\N
121310	tehnoloogijaid	?tehnoloogijaid =loogijai  (SgP  >tehno+loogijai !26_S	et	f	\N
121332	leidmine	leidmine =leidmine  (SgN  >leidmine !12?10_S	et	f	\N
121333	leidmine	"leidmine %leid  )MINE_vS  <leidma ;34_V	et	f	\N
121351	saalis	saalis =saali  (SgIn  >saal !22_S	et	f	\N
121352	saalis	saalis =saali  (IndIpfSg3  >saalima !28_V	et	f	\N
121373	ehitajad	ehitajad =ehitaja  (PlN  >ehitaja !01_S	et	f	\N
121374	ehitajad	"ehitaja %ehita  )JA_vS  <ehitama ;27_V	et	f	\N
121404	vormis	vormis =vormi  (SgIn  >vorm !22_S	et	f	\N
121405	vormis	vormis =vormi  (IndIpfSg3  >vormima !28_V	et	f	\N
121263	auhindu	auhindu =hindu  (PlP  >au+hind !22_S	et	f	\N
121274	prokuröri	prokuröri =prokuröri  (SgG  >prokurör !19_S	et	f	\N
121275	prokuröri	prokuröri =prokuröri  (SgP  >prokurör !19_S	et	f	\N
121276	prokuröri	prokuröri =prokuröri  (SgAdt  >prokurör !19_S	et	f	\N
121293	jallas	?jallas =jalla  (SgIn  >jalla !16_S	et	f	\N
121294	jallas	?jallas =jalla  (IndIpfSg3  >jallama !29_V	et	f	\N
121295	jallas	?jallas =jallas  (SgN  >jallas !07_S	et	f	\N
121311	hooneid	hooneid =hoone  (PlP  >hoone !06_S	et	f	\N
121312	hooneid	"hoone %hoo  )NE_aA  <hoog ;22_S	et	f	\N
121313	hooneid	hooneid =neid  (SgN  >hoo+neid !22_S	et	f	\N
121321	pliiatsid	pliiatsid =pliiatsi  (PlN  >pliiats !02_S	et	f	\N
121322	pliiatsid	pliiatsid =atsi  (PlN  >plii+ats !22_S	et	f	\N
121335	fotoapparat	?fotoapparat =fotoappara  (SgP  >fotoappara !16_S	et	f	\N
121337	fotoapparat	?fotoapparat =appara  (SgP  >foto+appara !01_S	et	f	\N
121338	sihikindlust	sihikindlust =kindlus  (SgP  >sihi+kindlus !11~09_S	et	f	\N
121339	sihikindlust	"sihi+kindlus %kindla  )US_aS  <sihi+kindel ;02_A	et	f	\N
121357	mattid	### mattid	et	f	\N
121358	naitab	?naitab =naita  (IndPrSg3  >naitama !27_V	et	f	\N
121364	haigusi	haigusi =haigusi  (PlP  >haigus !11_S	et	f	\N
121365	haigusi	"haigus %haige  )US_aS  <haige ;01_AS	et	f	\N
121370	ehitaja	ehitaja =ehitaja  (SgN  >ehitaja !01_S	et	f	\N
121371	ehitaja	"ehitaja %ehita  )JA_vS  <ehitama ;27_V	et	f	\N
121372	ehitaja	ehitaja =ehitaja  (SgG  >ehitaja !01_S	et	f	\N
121381	ehitajate	ehitajate =ehitaja  (PlG  >ehitaja !01_S	et	f	\N
121382	ehitajate	"ehitaja %ehita  )JA_vS  <ehitama ;27_V	et	f	\N
121391	pliiats	pliiats =pliiats  (SgN  >pliiats !02_S	et	f	\N
121392	pliiats	pliiats =ats  (SgN  >plii+ats !22_S	et	f	\N
121393	sõnaraamatud	sõnaraamatud =atu  (PlN  >sõna+raam+att !22_S	et	f	\N
121394	sõnaraamatud	sõnaraamatud =raamatu  (PlN  >sõna+raamat !02_S	et	f	\N
121397	tak	### tak	et	f	\N
121401	teistele	teistele =teis  (PlAll  >teine !12_OP	et	f	\N
121402	teistele	teistele =teis  (PlAll  >teise !12_P	et	f	\N
121403	teistele	teistele =teiste  (PlAll  >teist !22_S	et	f	\N
121430	õpitab	?õpitab =õpita  (IndPrSg3  >õpitama !27_V	et	f	\N
121433	naeratusega	naeratusega =naeratuse  (SgKom  >naeratus !11_S	et	f	\N
121434	naeratusega	"naeratus %naerata  )US_vS  <naeratama ;27_V	et	f	\N
121440	makaroonid	?makaroonid =makarooni  (PlN  >makarooni !16_S	et	f	\N
121441	makaroonid	?makaroonid =makarooni  (PlN  >makaroon !22_S	et	f	\N
121442	makaroonid	?makaroonid =makarooni  (IndPrSg2  >makaroonima !28_V	et	f	\N
121445	värvid	värvid =värvi  (PlN  >värv !22_S	et	f	\N
121446	värvid	värvid =värvi  (IndPrSg2  >värvima !28_V	et	f	\N
121500	politseinik	politseinik =politseinik  (SgN  >politseinik !02_S	et	f	\N
121501	politseinik	politseinik =politseinik  (SgN  >politseinik !25_S	et	f	\N
121506	kooliprogrammi	kooliprogrammi =programmi  (SgG  >kooli+programm !22_S	et	f	\N
121507	kooliprogrammi	kooliprogrammi =programmi  (SgP  >kooli+programm !22_S	et	f	\N
121508	kooliprogrammi	kooliprogrammi =programmi  (SgAdt  >kooli+programm !22_S	et	f	\N
121523	loodusõppetus	loodusõppetus =õppetu  (SgIn  >loodus+õppetu !01_A	et	f	\N
121524	loodusõppetus	"loodus+õppetu %õppe  )TU2_kA  <loodus+õpe ;06_S	et	f	\N
121525	loodusõppetus	loodusõppetus =õppetus  (SgN  >loodus+õppetus !11_S	et	f	\N
121526	loodusõppetus	"loodus+õppetus %õppe  )TUS2_aS  <loodus+õpe ;06_S	et	f	\N
121531	maardu	?maardu =maardu  (SgN  >maardu !01_S	et	f	\N
121532	maardu	?maardu =maardu  (SgG  >maardu !01_S	et	f	\N
121533	maardu	?maardu =maardu  (IndPrPs_  >maarduma !27_V	et	f	\N
121534	maardu	?maardu =maardu  (ImpPrSg2  >maarduma !27_V	et	f	\N
121549	esmas	?esmas =esma  (SgIn  >esma !16_S	et	f	\N
121550	esmas	?esmas =esma  (IndIpfSg3  >esmama !29_V	et	f	\N
121551	esmas	?esmas =esmas  (SgN  >esmas !07_S	et	f	\N
121557	klaasid	klaasid =klaasi  (PlN  >klaas !22_S	et	f	\N
121558	klaasid	klaasid =klaasi  (IndPrSg2  >klaasima !28_V	et	f	\N
121564	lodan	?lodan =loda  (IndPrSg1  >lodama !27_V	et	f	\N
121565	lodan	?lodan =lodan  (SgN  >lodan !02_S	et	f	\N
121583	fakultet	### fakultet	et	f	\N
121585	olulise	olulise =olulise  (SgG  >oluline !12_A	et	f	\N
121586	olulise	"oluline %olu  )LINE_aA  <olu ;17_S	et	f	\N
121611	gümnasiuumis	?gümnasiuumis =gümnasiuumi  (SgIn  >gümnasiuumi !16_S	et	f	\N
121612	gümnasiuumis	?gümnasiuumis =gümnasiuumi  (SgIn  >gümnasiuum !22_S	et	f	\N
121613	gümnasiuumis	?gümnasiuumis =gümnasiuumi  (IndIpfSg3  >gümnasiuumima !28_V	et	f	\N
121614	gümnasiuumis	?gümnasiuumis =gümnasiuumis  (SgN  >gümnasiuumis !09_S	et	f	\N
121670	erituma	erituma =eritu  (Sup  >erituma !27_V	et	f	\N
121671	erituma	erituma =erituma  (SgG  >eritum !02_A	et	f	\N
121672	erituma	"eritum %eri  )TUM2_cA  <eri ;17_S	et	f	\N
121674	protsessis	protsessis =protsessi  (SgIn  >protsess !22_S	et	f	\N
121675	protsessis	protsessis =protsessi  (IndIpfSg3  >protsessima !28_V	et	f	\N
121703	räägisin	?räägisin =räägi  (IndIpfSg1  >räägima !28_V	et	f	\N
121704	räägisin	?räägisin =räägisin  (SgN  >räägisin !19_S	et	f	\N
121708	remonteerima	?remonteerima =remonteeri  (Sup  >remonteerima !28_V	et	f	\N
121709	remonteerima	?remonteerima =remonteerima  (SgG  >remonteerim !02_A	et	f	\N
121355	pallid	pallid =palli  (PlN  >pall !22_S	et	f	\N
121356	pallid	pallid =palli  (IndPrSg2  >pallima !28_V	et	f	\N
121363	arstbr	?arstbr =arstbr  (SgN  >arstbr !22_S	et	f	\N
121366	hoolisteda	### hoolisteda	et	f	\N
121383	ehitustööristad	?ehitustööristad =ehitustöörista  (PlN  >ehitustöörista !16_S	et	f	\N
121384	ehitustööristad	?ehitustööristad =ehitustöörista  (IndPrSg2  >ehitustööristama !27_V	et	f	\N
121385	ehitustööristad	?ehitustööristad =rista  (PlN  >ehitus+töö+rista !16_S	et	f	\N
121386	ehitustööristad	?ehitustööristad =töörista  (PlN  >ehitus+töörista !01_S	et	f	\N
121395	tööaega	tööaega =aega  (SgP  >töö+aeg !22_S	et	f	\N
121396	tööaega	tööaega =aega  (SgAdt  >töö+aeg !22_S	et	f	\N
121406	edukas	edukas =eduka  (SgIn  >edukas !02_A	et	f	\N
121407	edukas	edukas =edukas  (SgN  >edukas !02_A	et	f	\N
121447	rutiintöö	?rutiintöö =rutiintöö  (SgN  >rutiintöö !26_S	et	f	\N
121448	rutiintöö	?rutiintöö =rutiintöö  (SgG  >rutiintöö !26_S	et	f	\N
121449	punktuaalne	?punktuaalne =punktuaalne  (SgN  >punktuaalne !02_A	et	f	\N
121450	punktuaalne	?punktuaalne =punktuaalne  (PlP  >punktuaaln !22_S	et	f	\N
121451	punktuaalne	?punktuaalne =uaalne  (SgN  >punkt+uaalne !02_A	et	f	\N
121452	punktuaalne	?punktuaalne =uaalne  (PlP  >punkt+uaaln !22_S	et	f	\N
121453	punktuaalne	?punktuaalne =tuaalne  (SgN  >punk+tuaalne !02_A	et	f	\N
121454	punktuaalne	?punktuaalne =tuaalne  (PlP  >punk+tuaaln !22_S	et	f	\N
121466	tingimus	tingimus =tingimus  (SgN  >tingimus !11_S	et	f	\N
121467	tingimus	tingimus =imu  (SgIn  >ting+imu !17_S	et	f	\N
121468	kruvikeeraja	kruvikeeraja =keeraja  (SgN  >kruvi+keeraja !01_S	et	f	\N
121469	kruvikeeraja	kruvikeeraja =keeraja  (SgG  >kruvi+keeraja !01_S	et	f	\N
121479	turvamees	turvamees =mee  (SgIn  >turva+mesi !15_S	et	f	\N
121480	turvamees	turvamees =mees  (SgN  >turva+mees !13_S	et	f	\N
121488	tarkus	tarkus =tarkus  (SgN  >tarkus !11~09_S	et	f	\N
121489	tarkus	"tarkus %tark  )US_aS  <tark ;22_AS	et	f	\N
121490	lasteaias	lasteaias =aia  (SgIn  >laste+aed !22_S	et	f	\N
121491	lasteaias	lasteaias =aia  (SgIn  >laste+ai !22_S	et	f	\N
121495	ravima	ravima =ravi  (Sup  >ravima !27_V	et	f	\N
121496	ravima	ravima =ravima  (SgG  >ravim !02_S	et	f	\N
121517	niiveliiriga	?niiveliiriga =niiveliiri  (SgKom  >niiveliiri !16_S	et	f	\N
121518	niiveliiriga	?niiveliiriga =niiveliiri  (SgKom  >niiveliir !22_S	et	f	\N
121519	niiveliiriga	?niiveliiriga =veliiri  (SgKom  >nii+veliiri !16_S	et	f	\N
121520	niiveliiriga	?niiveliiriga =veliiri  (SgKom  >nii+veliir !22_S	et	f	\N
121527	nõudnik	?nõudnik =nõudnik  (SgN  >nõudnik !25_S	et	f	\N
121538	õpisin	?õpisin =õpi  (IndIpfSg1  >õpima !27_V	et	f	\N
121539	õpisin	?õpisin =õpisin  (SgN  >õpisin !19_S	et	f	\N
121548	päiv	?päiv =päiv  (SgN  >päiv !22_S	et	f	\N
121559	pedagogid	### pedagogid	et	f	\N
121566	realiserima	?realiserima =realiserima  (SgG  >realiserim !02_A	et	f	\N
121573	mehannikase	?mehannikase =mehannikase  (SgG  >mehannikane !12_A	et	f	\N
121574	fakultetis	?fakultetis =fakulteti  (SgIn  >fakultett !22_S	et	f	\N
121575	fakultetis	?fakultetis =fakultetis  (SgN  >fakultetis !09_S	et	f	\N
121578	mehannikasse	?mehannikasse =mehannika  (SgIll  >mehannika !01_S	et	f	\N
121579	mehannikasse	?mehannikasse =mehannika  (SgIll  >mehannikas !02_A	et	f	\N
121580	mehannikasse	?mehannikasse =mehannikas  (SgAdt  >mehannikane !12_A	et	f	\N
121581	mehannikasse	?mehannikasse =mehannikasse  (SgG  >mehannikasne !02_A	et	f	\N
121582	mehannikasse	?mehannikasse =mehannikasse  (PlP  >mehannikass !22_S	et	f	\N
121595	lemmikaine	lemmikaine =aine  (SgN  >lemmik+aine !06_S	et	f	\N
121596	lemmikaine	lemmikaine =aine  (SgG  >lemmik+aine !06_S	et	f	\N
121597	lemmikaine	lemmikaine =aine  (PlP  >lemmik+ain !22_S	et	f	\N
121598	ujumine	ujumine =ujumine  (SgN  >ujumine !12_S	et	f	\N
121599	ujumine	"ujumine %uju  )MINE_vS  <ujuma ;27_V	et	f	\N
121601	ujumine	"ujumine %ujumi  )NE_aA  <ujum ;02_S	et	f	\N
121603	tootmistehnika	tootmistehnika =tehnika  (SgN  >tootmis+tehnika !01_S	et	f	\N
121604	tootmistehnika	tootmistehnika =tehnika  (SgG  >tootmis+tehnika !01_S	et	f	\N
121634	õppimises	õppimises =õppimise  (SgIn  >õppimine !12_S	et	f	\N
121635	õppimises	"õppimine %õppi  )MINE_vS  <õppima ;28_V	et	f	\N
121638	tänapäevases	tänapäevases =päevase  (SgIn  >täna+päevane !10_A	et	f	\N
121639	tänapäevases	"täna+päevane %päeva  )NE_aA  <täna+päev ;22_S	et	f	\N
121640	raskem	raskem =raskem  (SgN  >raskem !02_A	et	f	\N
121641	raskem	"raskem %raske  )M_cA  <raske ;01_A	et	f	\N
121666	hulgast	hulgast =hulga  (SgEl  >hulk !22_S	et	f	\N
121667	hulgast	hulgast =hulgas  (SgP  >hulgane !10_A	et	f	\N
121668	hulgast	"hulgane %hulga  )NE_aA  <hulk ;22_S	et	f	\N
121669	hulgast	hulgast =hulgast  (ID  >hulgast !41_K	et	f	\N
121679	ttü	### ttü	et	f	\N
121680	rääkisid	rääkisid =rääki  (PlP  >rääk !22_S	et	f	\N
121681	rääkisid	rääkisid =rääki  (IndIpfSg2  >rääkima !28_V	et	f	\N
121682	rääkisid	rääkisid =rääki  (IndIpfPl3  >rääkima !28_V	et	f	\N
121697	kutseõppekeskust	kutseõppekeskust =us  (SgP  >kutse+õppe+kesk+uks !14_S	et	f	\N
121698	kutseõppekeskust	kutseõppekeskust =keskus  (SgP  >kutse+õppe+keskus !11~09_S	et	f	\N
121701	kuut	kuut =kuu  (SgP  >kuus !14_N	et	f	\N
121380	erilised	"eriline %eri  )LINE_aA  <eri ;17_S	et	f	\N
121389	ehitajatel	ehitajatel =ehitaja  (PlAd  >ehitaja !01_S	et	f	\N
121390	ehitajatel	"ehitaja %ehita  )JA_vS  <ehitama ;27_V	et	f	\N
121427	pastapliatsid	?pastapliatsid =pastapliatsi  (PlN  >pastapliats !22_S	et	f	\N
121428	pastapliatsid	?pastapliatsid =pastapliatsi  (IndPrSg2  >pastapliatsima !28_V	et	f	\N
121429	pastapliatsid	?pastapliatsid =pliatsi  (PlN  >pasta+pliats !22_S	et	f	\N
121435	vabakutseline	vabakutseline =kutseline  (SgN  >vaba+kutseline !12_A	et	f	\N
121436	vabakutseline	"vaba+kutseline %kutse  )LINE_aA  <vaba+kutse ;06_S	et	f	\N
121437	kunstiga	kunstiga =kunsti  (SgKom  >kunst !22_S	et	f	\N
121438	kunstiga	kunstiga =iga  (SgN  >kunst+iga !18_S	et	f	\N
121439	kunstiga	kunstiga =iga  (SgP  >kunst+iga !18_S	et	f	\N
121455	juhiload	juhiload =loa  (PlN  >juhi+luba !18_S	et	f	\N
121456	juhiload	juhiload =loa  (PlN  >juhi+luga !18_S	et	f	\N
121471	tänaval	tänaval =tänava  (SgAd  >tänav !02_A	et	f	\N
121472	tänaval	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
121473	tänaval	tänaval =tänava  (SgAd  >tänav !02_S	et	f	\N
121486	kõikide	kõikide =kõiki  (PlG  >kõik !00_P	et	f	\N
121487	kõikide	kõikide =kõiki  (PlG  >kõik !22_S	et	f	\N
121492	vastupanu	vastupanu =panu  (SgN  >vastu+panu !17_S	et	f	\N
121493	vastupanu	vastupanu =panu  (SgG  >vastu+panu !17_S	et	f	\N
121494	vastupanu	vastupanu =panu  (SgP  >vastu+panu !17_S	et	f	\N
121504	aus	aus =au  (SgIn  >au !26_S	et	f	\N
121505	aus	aus =aus  (SgN  >aus !02_A	et	f	\N
121509	korrapeetja	?korrapeetja =korrapeetja  (SgN  >korrapeetja !16_S	et	f	\N
121510	korrapeetja	?korrapeetja =korrapeetja  (SgG  >korrapeetjas !02_A	et	f	\N
121511	korrapeetja	?korrapeetja =korrapeetja  (SgG  >korrapeetja !16_S	et	f	\N
121512	korrapeetja	?korrapeetja =peetja  (SgN  >korra+peetja !01_S	et	f	\N
121513	korrapeetja	?korrapeetja =peetja  (SgG  >korra+peetja !01_S	et	f	\N
121514	korrapeetja	?korrapeetja =peetja  (SgG  >korra+peetjas !02_A	et	f	\N
121515	geodeesia	geodeesia =geodeesia  (SgN  >geodeesia !01_S	et	f	\N
121516	geodeesia	geodeesia =geodeesia  (SgG  >geodeesia !01_S	et	f	\N
121522	diploom	?diploom =diploom  (SgN  >diploom !22_S	et	f	\N
121536	kohtla-järves	kohtla-järves =järve  (SgIn  >kohtla-järv !22_S	et	f	\N
121537	kohtla-järves	kohtla-järves =järve  (PlIn  >kohtla-järv !22_S	et	f	\N
121543	ttu	### ttu	et	f	\N
121544	mõtlin	?mõtlin =mõtlin  (SgN  >mõtlin !02_S	et	f	\N
121547	perspektivid	?perspektivid =perspektivi  (PlN  >perspektiv !02_A	et	f	\N
121552	ttus	### ttus	et	f	\N
121560	üsed	?üsed =üse  (PlN  >üse !16_S	et	f	\N
121561	üsed	?üsed =üse  (IndPrSg2  >üsema !27_V	et	f	\N
121584	meeldip	?meeldip =meeldip  (SgN  >meeldip !02_S	et	f	\N
121615	muu	muu =muu  (ID  >muu !41_I	et	f	\N
121616	muu	muu =muu  (SgN  >muu !26_S	et	f	\N
121617	muu	muu =muu  (SgN  >muu !26_P	et	f	\N
121618	muu	muu =muu  (SgG  >muu !26_S	et	f	\N
121619	muu	muu =muu  (SgG  >muu !26_P	et	f	\N
121620	muu	muu =muu  (IndPrPs_  >muuma !27_V	et	f	\N
121621	muu	muu =muu  (ImpPrSg2  >muuma !27_V	et	f	\N
121623	halba	halba =halba  (SgP  >halb !22_A	et	f	\N
121624	halba	halba =halba  (SgAdt  >halb !22_A	et	f	\N
121633	abit	?abit =abit  (SgN  >abit !02_S	et	f	\N
121647	keskkonnast	keskkonnast =keskkonna  (SgEl  >keskkond !22_S	et	f	\N
121648	keskkonnast	keskkonnast =keskkonnas  (SgP  >keskkonnane !12_A	et	f	\N
121649	keskkonnast	"keskkonnane %keskkonna  )NE_aA  <keskkond ;22_S	et	f	\N
121650	tuttavatest	tuttavatest =tuttava  (PlEl  >tuttav !02_AS	et	f	\N
121651	tuttavatest	tuttavatest =test  (SgN  >tutt+ava+test !22_S	et	f	\N
121661	tassivad	tassivad =tassi  (IndPrPl3  >tassima !28_V	et	f	\N
121662	tassivad	tassivad =tassiva  (PlN  >tassiv !02_A	et	f	\N
121663	tassivad	"tassiv %tassi  )V_vA  <tassima ;28_V	et	f	\N
121676	maardus	?maardus =maardu  (SgIn  >maardu !01_S	et	f	\N
121677	maardus	?maardus =maardu  (IndIpfSg3  >maarduma !27_V	et	f	\N
121678	maardus	?maardus =maardus  (SgN  >maardus !11~09_S	et	f	\N
121693	eksamihindad	?eksamihindad =eksamihinda  (PlN  >eksamihinda !16_S	et	f	\N
121694	eksamihindad	?eksamihindad =eksamihinda  (IndPrSg2  >eksamihindama !27_V	et	f	\N
121695	eksamihindad	?eksamihindad =hinda  (PlN  >eksami+hinda !16_S	et	f	\N
121696	eksamihindad	?eksamihindad =amihinda  (PlN  >eks+amihinda !16_S	et	f	\N
121705	mehhatroonika	?mehhatroonika =mehhatroonika  (SgN  >mehhatroonika !01_S	et	f	\N
121706	mehhatroonika	?mehhatroonika =mehhatroonika  (SgG  >mehhatroonika !01_S	et	f	\N
121707	mehhatroonika	?mehhatroonika =mehhatroonika  (SgG  >mehhatroonikas !02_A	et	f	\N
121713	lõpema	?lõpema =lõpe  (Sup  >lõpema !27_V	et	f	\N
121714	lõpema	?lõpema =lõpema  (SgG  >lõpem !02_A	et	f	\N
121718	opida	?opida =opi  (Inf  >opima !27_V	et	f	\N
121729	vimane	?vimane =vimane  (SgN  >vimane !10_A	et	f	\N
121730	vimane	?vimane =vimane  (IndPrPs_  >vimanema !27_V	et	f	\N
121731	vimane	?vimane =vimane  (ImpPrSg2  >vimanema !27_V	et	f	\N
121746	jargmisele	?jargmisele =jargmise  (SgAll  >jargmine !12?10_A	et	f	\N
121747	jargmisele	?jargmisele =jargmisele  (PlP  >jargmisel !19_S	et	f	\N
121754	kodutöö	kodutöö =töö  (SgN  >kodu+töö !26_S	et	f	\N
121400	grammatiliselt	"grammatiliselt %grammatilise  )LT_mD  <grammatiline ;12_A	et	f	\N
121421	suhtlemise	suhtlemise =suhtlemise  (SgG  >suhtlemine !12_S	et	f	\N
121422	suhtlemise	"suhtlemine %suhtle  )MINE_vS  <suhtlema ;30_V	et	f	\N
121423	pliatsid	?pliatsid =pliat  (IndIpfSg2  >pliatma !34_V	et	f	\N
121424	pliatsid	?pliatsid =pliat  (IndIpfPl3  >pliatma !34_V	et	f	\N
121425	pliatsid	?pliatsid =pliatsi  (PlN  >pliats !22_S	et	f	\N
121426	pliatsid	?pliatsid =pliatsi  (IndPrSg2  >pliatsima !28_V	et	f	\N
121462	rõivast	rõivast =rõiva  (SgEl  >rõivas !07_S	et	f	\N
121463	rõivast	rõivast =rõivas  (SgP  >rõivas !07_S	et	f	\N
121464	rõivast	rõivast =rõivas  (SgP  >rõivane !10_A	et	f	\N
121465	rõivast	"rõivane %rõiva  )NE_aA  <rõivas ;07_S	et	f	\N
121470	hammer	?hammer =hammer  (SgN  >hammer !02_S	et	f	\N
121474	korralagetus	?korralagetus =korralagetu  (SgIn  >korralagetu !01_A	et	f	\N
121475	korralagetus	?korralagetus =korralagetu  (IndIpfSg3  >korralagetuma !27_V	et	f	\N
121476	korralagetus	?korralagetus =korralagetus  (SgN  >korralagetus !11?09_S	et	f	\N
121477	korralagetus	?korralagetus =lagetu  (SgIn  >korra+lagetu !01_AS	et	f	\N
121478	korralagetus	?korralagetus =lagetus  (SgN  >korra+lagetus !11_S	et	f	\N
121481	korra	korra =korra  (ID  >korra !41_D	et	f	\N
121482	korra	korra =korra  (SgG  >kord !22_S	et	f	\N
121483	jälgima	jälgima =jälgi  (Sup  >jälgima !27_V	et	f	\N
121484	jälgima	jälgima =jälgima  (SgG  >jälgim !02_A	et	f	\N
121485	jälgima	"jälgim %jälgi  )M_cA  <jälk ;22_A	et	f	\N
121497	diagnoost	?diagnoost =diagnoo  (SgEl  >diagnoo !26_S	et	f	\N
121502	külmavereline	külmavereline =vereline  (SgN  >külma+vereline !12_A	et	f	\N
121503	külmavereline	"külma+vereline %vere  )LINE_aA  <külma+veri ;20_S	et	f	\N
121521	teodolitidega	### teodolitidega	et	f	\N
121535	ttüst	?ttüst =ttüst  (SgN  >ttüst !22_S	et	f	\N
121553	tulesin	?tulesin =tulesin  (SgN  >tulesin !19_S	et	f	\N
121562	rägima	?rägima =rägi  (Sup  >rägima !27_V	et	f	\N
121563	rägima	?rägima =rägima  (SgG  >rägim !02_A	et	f	\N
121587	kannuka	?kannuka =kannuka  (SgN  >kannuka !01_S	et	f	\N
121588	kannuka	?kannuka =kannuka  (SgG  >kannuka !01_S	et	f	\N
121589	kannuka	?kannuka =kannuka  (SgG  >kannukas !02_A	et	f	\N
121593	aastane	aastane =aastane  (SgN  >aastane !12~10_A	et	f	\N
121594	aastane	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
121608	suurega	suurega =suure  (SgKom  >suur !13_A	et	f	\N
121609	suurega	suurega =re  (SgKom  >suu+re !26_S	et	f	\N
121625	tundist	?tundist =tundi  (SgEl  >tundi !16_S	et	f	\N
121628	tundist	?tundist =tundi  (SgEl  >tunt !22_S	et	f	\N
121630	tundist	?tundist =tundis  (SgP  >tundis !09_S	et	f	\N
121632	tundist	?tundist =tundist  (SgN  >tundist !22_S	et	f	\N
121636	nõuavad	nõuavad =nõua  (IndPrPl3  >nõudma !34_V	et	f	\N
121637	nõuavad	nõuavad =ava  (PlN  >nõu+ava !17_S	et	f	\N
121642	rahuldav	rahuldav =rahulda  (PtsPrPs  >rahuldama !27_V	et	f	\N
121643	rahuldav	rahuldav =rahuldav  (SgN  >rahuldav !02_A	et	f	\N
121644	rahuldav	"rahuldav %rahulda  )V_vA  <rahuldama ;27_V	et	f	\N
121645	teadmistele	teadmistele =teadmis  (PlAll  >teadmine !12?10_S	et	f	\N
121646	teadmistele	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
121656	tõuge	tõuge =tõuge  (SgN  >tõuge !06_S	et	f	\N
121657	tõuge	tõuge =tõuge  (PlP  >tõug !22_S	et	f	\N
121658	avaldavad	avaldavad =avalda  (IndPrPl3  >avaldama !27_V	et	f	\N
121659	avaldavad	avaldavad =avaldava  (PlN  >avaldav !02_A	et	f	\N
121660	avaldavad	"avaldav %avalda  )V_vA  <avaldama ;27_V	et	f	\N
121673	õpimise	?õpimise =õpimise  (SgG  >õpimine !12_S	et	f	\N
121691	kutseõppekeskuses	kutseõppekeskuses =use  (PlIn  >kutse+õppe+kesk+usk !22_S	et	f	\N
121692	kutseõppekeskuses	kutseõppekeskuses =keskuse  (SgIn  >kutse+õppe+keskus !11~09_S	et	f	\N
121699	hollandias	?hollandias =hollandia  (SgIn  >hollandia !01_S	et	f	\N
121700	hollandias	?hollandias =hollandias  (SgN  >hollandias !11_S	et	f	\N
121719	kesklinnavene	kesklinnavene =vene  (SgN  >kesk+linna+vene !16_S	et	f	\N
121720	kesklinnavene	kesklinnavene =vene  (SgG  >kesk+linna+vene !16_S	et	f	\N
121721	opin	?opin =opi  (IndPrSg1  >opima !27_V	et	f	\N
121722	opin	?opin =opi  (IndPrSg1  >oppima !28_V	et	f	\N
121723	opin	?opin =opin  (SgN  >opin !02_S	et	f	\N
121734	korral	korral =korra  (SgAd  >kord !22_S	et	f	\N
121735	korral	korral =korral  (ID  >korral !41_DK	et	f	\N
121736	ütle	ütle =ütle  (IndPrPs_  >ütlema !30_V	et	f	\N
121737	ütle	ütle =ütle  (ImpPrSg2  >ütlema !30_V	et	f	\N
121766	räägid	räägid =räägi  (PlN  >rääk !22_S	et	f	\N
121767	räägid	räägid =räägi  (IndPrSg2  >rääkima !28_V	et	f	\N
121774	näiteb	?näiteb =näite  (IndPrSg3  >näitema !27_V	et	f	\N
121775	stabiiltselt	?stabiiltselt =stabiiltse  (SgAbl  >stabiiltne !02_A	et	f	\N
121776	stabiiltselt	?stabiiltselt =stabiiltse  (PlAbl  >stabiilts !22_S	et	f	\N
121777	stabiiltselt	?stabiiltselt =stabiiltselt  (ID  >stabiiltselt !41_D	et	f	\N
121788	mulje	mulje =mulje  (SgN  >mulje !06_S	et	f	\N
121789	mulje	mulje =mulje  (SgG  >mulje !06_S	et	f	\N
121801	kardan	kardan =karda  (IndPrSg1  >kardama !29_V	et	f	\N
121802	kardan	kardan =karda  (IndPrSg1  >kartma !34_V	et	f	\N
121408	garanteeritud	garanteeritud =garanteeri  (PtsPtIps  >garanteerima !28_V	et	f	\N
121409	garanteeritud	garanteeritud =garanteeritu  (PlN  >garanteeritu !01_S	et	f	\N
121410	garanteeritud	"garanteeritu %garanteeri  )TU1_vS  <garanteerima ;28_V	et	f	\N
121411	garanteeritud	garanteeritud =garanteeritud  (ID  >garanteeritud !41_A	et	f	\N
121412	garanteeritud	"garanteeritud %garanteeri  )TUD_vA  <garanteerima ;28_V	et	f	\N
121413	müügiesindaja	müügiesindaja =esindaja  (SgN  >müügi+esindaja !01_S	et	f	\N
121414	müügiesindaja	müügiesindaja =esindaja  (SgG  >müügi+esindaja !01_S	et	f	\N
121415	kaupa	kaupa =kaupa  (ID  >kaupa !41_K	et	f	\N
121416	kaupa	kaupa =kaupa  (ID  >kaupa !41_D	et	f	\N
121417	kaupa	kaupa =kaupa  (SgP  >kaup !22_S	et	f	\N
121418	kaupa	kaupa =kaupa  (SgAdt  >kaup !22_S	et	f	\N
121419	teenindamine	teenindamine =teenindamine  (SgN  >teenindamine !12_S	et	f	\N
121420	teenindamine	"teenindamine %teeninda  )MINE_vS  <teenindama ;27_V	et	f	\N
121431	asjatundja	asjatundja =tundja  (SgN  >asja+tundja !01_S	et	f	\N
121432	asjatundja	asjatundja =tundja  (SgG  >asja+tundja !01_S	et	f	\N
121443	vabakutselise	vabakutselise =kutselise  (SgG  >vaba+kutseline !12_A	et	f	\N
121444	vabakutselise	"vaba+kutseline %kutse  )LINE_aA  <vaba+kutse ;06_S	et	f	\N
121457	töövahdid	?töövahdid =töövahdi  (PlN  >töövahdi !01_S	et	f	\N
121458	töövahdid	?töövahdid =töövahdi  (PlN  >töövahd !02_S	et	f	\N
121459	töövahdid	?töövahdid =töövahdi  (IndPrSg2  >töövahdima !28_V	et	f	\N
121460	töövahdid	?töövahdid =vahdi  (PlN  >töö+vahdi !16_S	et	f	\N
121461	töövahdid	?töövahdid =vahdi  (PlN  >töö+vahd !22_S	et	f	\N
121498	patsienti	patsienti =patsienti  (SgP  >patsient !22_S	et	f	\N
121499	patsienti	patsienti =patsienti  (SgAdt  >patsient !22_S	et	f	\N
121528	instrumentiga	### instrumentiga	et	f	\N
121529	kaheksateist	kaheksateist =te  (PlEl  >kaheksa+tee !26_S	et	f	\N
121530	kaheksateist	kaheksateist =teist  (SgN  >kaheksa+teist !22_S	et	f	\N
121540	kesklina	kesklina =lina  (SgN  >kesk+lina !17_S	et	f	\N
121541	kesklina	kesklina =lina  (SgG  >kesk+lina !17_S	et	f	\N
121542	kesklina	kesklina =lina  (SgP  >kesk+lina !17_S	et	f	\N
121545	pristizne	?pristizne =pristizne  (SgN  >pristizne !02_A	et	f	\N
121546	pristizne	?pristizne =pristizne  (PlP  >pristizn !22_S	et	f	\N
121554	hastid	?hastid =hasti  (PlN  >hasti !16_S	et	f	\N
121555	hastid	?hastid =hasti  (PlN  >hast !22_S	et	f	\N
121556	hastid	?hastid =hasti  (IndPrSg2  >hastima !28_V	et	f	\N
121567	ehitajana	ehitajana =ehitaja  (SgEs  >ehitaja !01_S	et	f	\N
121568	ehitajana	"ehitaja %ehita  )JA_vS  <ehitama ;27_V	et	f	\N
121569	muusikakooli	muusikakooli =kooli  (SgG  >muusika+kool !22_S	et	f	\N
121570	muusikakooli	muusikakooli =kooli  (SgP  >muusika+kool !22_S	et	f	\N
121571	muusikakooli	muusikakooli =kooli  (SgAdt  >muusika+kool !22_S	et	f	\N
121572	muusikakooli	muusikakooli =kooli  (PlP  >muusika+kool !22_S	et	f	\N
121576	tehnika	tehnika =tehnika  (SgN  >tehnika !01_S	et	f	\N
121577	tehnika	tehnika =tehnika  (SgG  >tehnika !01_S	et	f	\N
121590	üheksateist	üheksateist =te  (PlEl  >üheksa+tee !26_S	et	f	\N
121591	üheksateist	üheksateist =teist  (SgN  >üheksa+teist !22_S	et	f	\N
121592	üheksateist	üheksateist =ateist  (SgN  >üheks+ateist !22_S	et	f	\N
121600	jooksmine	jooksmine =jooksmine  (SgN  >jooksmine !12?10_S	et	f	\N
121602	jooksmine	"jooksmine %jooks  )MINE_vS  <jooksma ;32_V	et	f	\N
121605	arendav	arendav =arenda  (PtsPrPs  >arendama !27_V	et	f	\N
121606	arendav	arendav =arendav  (SgN  >arendav !02_A	et	f	\N
121607	arendav	"arendav %arenda  )V_vA  <arendama ;27_V	et	f	\N
121610	palkaga	?palkaga =palka  (SgKom  >palka !16_S	et	f	\N
121622	jatkab	?jatkab =jatka  (IndPrSg3  >jatkama !29_V	et	f	\N
121626	jargmistest	?jargmistest =jargmis  (PlEl  >jargmis !09_S	et	f	\N
121627	jargmistest	?jargmistest =jargmis  (PlEl  >jargmine !12?10_A	et	f	\N
121629	jargmistest	?jargmistest =jargmiste  (PlEl  >jargmist !22_S	et	f	\N
121631	jargmistest	?jargmistest =jargmistes  (SgP  >jargmistene !12_A	et	f	\N
121652	sugulastest	sugulastest =sugulas  (PlEl  >sugulane !12_S	et	f	\N
121653	sugulastest	sugulastest =test  (SgN  >sugulas+test !22_S	et	f	\N
121654	sugulastest	sugulastest =las  (PlEl  >sugu+laps !14_S	et	f	\N
121655	sugulastest	sugulastest =laste  (PlEl  >sugu+last !22_S	et	f	\N
121664	hakka	hakka =hakka  (IndPrPs_  >hakkama !29_V	et	f	\N
121665	hakka	hakka =hakka  (ImpPrSg2  >hakkama !29_V	et	f	\N
121683	tesduskond	?tesduskond =tesduskond  (SgN  >tesduskond !22_S	et	f	\N
121684	ökonoomika	ökonoomika =ökonoomika  (SgN  >ökonoomika !01_S	et	f	\N
121685	ökonoomika	ökonoomika =ökonoomika  (SgG  >ökonoomika !01_S	et	f	\N
121686	lõpetanud	lõpetanud =lõpeta  (PtsPtPs  >lõpetama !27_V	et	f	\N
121687	lõpetanud	lõpetanud =lõpetanu  (PlN  >lõpetanu !01_S	et	f	\N
121688	lõpetanud	"lõpetanu %lõpeta  )NU_vS  <lõpetama ;27_V	et	f	\N
121689	lõpetanud	lõpetanud =lõpetanud  (ID  >lõpetanud !41_A	et	f	\N
121690	lõpetanud	"lõpetanud %lõpeta  )NUD_vA  <lõpetama ;27_V	et	f	\N
121738	spordihoone	spordihoone =hoone  (SgN  >spordi+hoone !06_S	et	f	\N
121739	spordihoone	"spordi+hoone %hoo  )NE_aA  <spordi+hoog ;22_S	et	f	\N
121740	spordihoone	spordihoone =hoone  (SgG  >spordi+hoone !06_S	et	f	\N
121702	kuut	kuut =kuut  (SgN  >kuut !22_S	et	f	\N
121727	valitsin	?valitsin =valitsi  (IndPrSg1  >valitsima !28_V	et	f	\N
121728	valitsin	?valitsin =valitsin  (SgN  >valitsin !19_S	et	f	\N
121748	arvamisel	arvamisel =arvamise  (SgAd  >arvamine !12_S	et	f	\N
121749	arvamisel	"arvamine %arva  )MINE_vS  <arvama ;29_V	et	f	\N
121780	vendenud	?vendenud =vende  (PtsPtPs  >vendema !27_V	et	f	\N
121781	vendenud	?vendenud =vendenu  (PlN  >vendenu !01_S	et	f	\N
121782	vendenud	?vendenud =vendenu  (IndPrSg2  >vendenuma !27_V	et	f	\N
121783	vendenud	?vendenud =vendenud  (ID  >vendenud !41_A	et	f	\N
121786	tiulin	?tiulin =tiuli  (IndPrSg1  >tiulima !28_V	et	f	\N
121787	tiulin	?tiulin =tiulin  (SgN  >tiulin !02_S	et	f	\N
121795	õppelast	õppelast =la  (SgEl  >õppe+la !26_S	et	f	\N
121796	õppelast	õppelast =las  (SgP  >õppe+laps !14_S	et	f	\N
121797	õppelast	õppelast =last  (SgN  >õppe+last !22_S	et	f	\N
121806	võrkpalli	võrkpalli =palli  (SgG  >võrk+pall !22_S	et	f	\N
121807	võrkpalli	võrkpalli =palli  (SgP  >võrk+pall !22_S	et	f	\N
121808	võrkpalli	võrkpalli =palli  (SgAdt  >võrk+pall !22_S	et	f	\N
121832	noormees	noormees =mee  (SgIn  >noor+mesi !15_S	et	f	\N
121834	noormees	noormees =mees  (SgN  >noor+mees !13_S	et	f	\N
121852	hoonet	hoonet =hoone  (SgP  >hoone !06_S	et	f	\N
121853	hoonet	"hoone %hoo  )NE_aA  <hoog ;22_S	et	f	\N
121857	tegada	?tegada =tega  (Inf  >tegama !27_V	et	f	\N
121864	plus	### plus	et	f	\N
121867	seisa	seisa =seisa  (IndPrPs_  >seisma !32_V	et	f	\N
121868	seisa	seisa =seisa  (ImpPrSg2  >seisma !32_V	et	f	\N
121883	tahtud	?tahtud =tahtu  (PlN  >tahtu !01_S	et	f	\N
121884	tahtud	?tahtud =tahtu  (IndPrSg2  >tahtuma !27_V	et	f	\N
121885	tahtud	?tahtud =tahtud  (ID  >tahtud !41_A	et	f	\N
121889	rägimis	?rägimis =rägimi  (SgIn  >rägimi !01_S	et	f	\N
121890	rägimis	?rägimis =rägimi  (SgIn  >rägim !02_A	et	f	\N
121891	rägimis	?rägimis =rägimis  (SgN  >rägimis !11_S	et	f	\N
121906	hivitav	?hivitav =hivi  (PtsPrIps  >hivima !27_V	et	f	\N
121907	hivitav	?hivitav =hivita  (PtsPrPs  >hivitama !27_V	et	f	\N
121908	hivitav	?hivitav =hivitav  (SgN  >hivitav !02_A	et	f	\N
121909	tansi	?tansi =tansi  (SgN  >tansi !16_S	et	f	\N
121910	tansi	?tansi =tansi  (SgG  >tansi !16_S	et	f	\N
121911	tansi	?tansi =tansi  (SgG  >tanss !22_S	et	f	\N
121912	tansi	?tansi =tansi  (SgP  >tans !22_S	et	f	\N
121913	tansi	?tansi =tansi  (SgAdt  >tans !22_S	et	f	\N
121914	tansi	?tansi =tansi  (IndPrPs_  >tanssima !28_V	et	f	\N
121915	tansi	?tansi =tansi  (ImpPrSg2  >tanssima !28_V	et	f	\N
121918	keskkool	keskkool =koo  (SgAd  >kesk+kubu !18_S	et	f	\N
121920	keskkool	keskkool =kool  (SgN  >kesk+kool !22_S	et	f	\N
121921	avaldust	avaldust =avaldus  (SgP  >avaldus !11_S	et	f	\N
121922	avaldust	"avaldus %avalda  )US_vS  <avaldama ;27_V	et	f	\N
121934	meldib	?meldib =meldi  (IndPrSg3  >meltima !28_V	et	f	\N
121937	ap	### ap	et	f	\N
121948	arstiks	arstiks =arsti  (SgTr  >arst !22_S	et	f	\N
121949	arstiks	arstiks =arsti  (KndPrPs  >arstima !28_V	et	f	\N
121950	arstiks	arstiks =iks  (SgN  >arst+iks !22_S	et	f	\N
121954	seisukohal	seisukohal =koha  (SgAd  >seisu+koha !17_S	et	f	\N
121955	seisukohal	seisukohal =koha  (SgAd  >seisu+koht !22_S	et	f	\N
121987	est	?est =est  (SgN  >est !22_S	et	f	\N
121988	soojustehnika	soojustehnika =tehnika  (SgN  >soojus+tehnika !01_S	et	f	\N
121989	soojustehnika	soojustehnika =tehnika  (SgG  >soojus+tehnika !01_S	et	f	\N
122001	gramaatikat	?gramaatikat =gramaatika  (SgP  >gramaatika !01_S	et	f	\N
122002	gramaatikat	?gramaatikat =gramaatika  (SgP  >gramaatikas !02_A	et	f	\N
122019	inseneeriks	?inseneeriks =inseneeri  (SgTr  >inseneeri !16_S	et	f	\N
122020	inseneeriks	?inseneeriks =inseneeri  (SgTr  >inseneer !22_S	et	f	\N
122021	inseneeriks	?inseneeriks =inseneeri  (KndPrPs  >inseneerima !28_V	et	f	\N
122024	õpitamise	?õpitamise =õpitamise  (SgG  >õpitamine !12_S	et	f	\N
122025	õpitamise	?õpitamise =tamise  (SgG  >õpi+tamine !10_A	et	f	\N
122031	veelgi	veelgi =vee  (SgAd^  >vesi !15_S	et	f	\N
122032	veelgi	veelgi =veel  (ID^  >veel !41_D	et	f	\N
122050	söökla	söökla =söökla  (SgN  >söökla !01_S	et	f	\N
122051	söökla	söökla =söökla  (SgG  >söökla !01_S	et	f	\N
122077	xx	### xx	et	f	\N
122078	lõuna-jaapanis	?lõuna-jaapanis =jaapani  (SgIn  >lõuna-jaapan !02_S	et	f	\N
122079	lõuna-jaapanis	?lõuna-jaapanis =jaapanis  (SgN  >lõuna-jaapanis !11_S	et	f	\N
122090	sadaks	### sadaks	et	f	\N
122120	kilo	kilo =kilo  (SgN  >kilo !17_S	et	f	\N
122121	kilo	kilo =kilo  (SgG  >kilo !17_S	et	f	\N
122122	kilo	kilo =kilo  (SgP  >kilo !17_S	et	f	\N
122123	uusaasta	uusaasta =aasta  (SgN  >uus+aasta !01_S	et	f	\N
122124	uusaasta	uusaasta =aasta  (SgG  >uus+aasta !01_S	et	f	\N
122135	rohelised	rohelised =rohelise  (PlN  >roheline !12_A	et	f	\N
122136	rohelised	"roheline %rohe  )LINE_aA  <rohe ;16_S	et	f	\N
122146	grillpraadi	grillpraadi =praadi  (SgP  >grill+praad !22_S	et	f	\N
122147	grillpraadi	grillpraadi =praadi  (SgAdt  >grill+praad !22_S	et	f	\N
122149	reisija	reisija =reisija  (SgN  >reisija !01_S	et	f	\N
121710	remonteerima	?remonteerima =eerima  (SgG  >remont+eerim !02_A	et	f	\N
121711	jamas	jamas =jama  (SgIn  >jama !17_S	et	f	\N
121712	jamas	jamas =jama  (IndIpfSg3  >jamama !27_V	et	f	\N
121715	teistega	teistega =teis  (PlKom  >teine !12_OP	et	f	\N
121716	teistega	teistega =teis  (PlKom  >teise !12_P	et	f	\N
121717	räägida	?räägida =räägi  (Inf  >räägima !28_V	et	f	\N
121724	mehanika	?mehanika =mehanika  (SgN  >mehanika !01_S	et	f	\N
121725	mehanika	?mehanika =mehanika  (SgG  >mehanika !01_S	et	f	\N
121726	mehanika	?mehanika =mehanika  (SgG  >mehanikas !02_A	et	f	\N
121732	re	re =re  (SgN  >re !26_S	et	f	\N
121733	re	re =re  (SgG  >re !26_S	et	f	\N
121742	kolmkümne	?kolmkümne =kolmkümne  (SgN  >kolmkümne !02_A	et	f	\N
121743	kolmkümne	?kolmkümne =kolmkümne  (PlP  >kolmkümn !22_S	et	f	\N
121744	kolmkümne	?kolmkümne =kümne  (SgN  >kolm+kümne !02_A	et	f	\N
121745	kolmkümne	?kolmkümne =kümne  (PlP  >kolm+kümn !22_S	et	f	\N
121756	arves	arves =arve  (SgIn  >arve !06_S	et	f	\N
121757	arves	arves =arve  (PlIn  >arv !22_S	et	f	\N
121768	valeta	valeta =vale  (SgAb  >vale !16_SA	et	f	\N
121769	valeta	valeta =valeta  (IndPrPs_  >valetama !27_V	et	f	\N
121770	valeta	valeta =valeta  (ImpPrSg2  >valetama !27_V	et	f	\N
121784	energeetika	energeetika =energeetika  (SgN  >energeetika !01_S	et	f	\N
121785	energeetika	energeetika =energeetika  (SgG  >energeetika !01_S	et	f	\N
121845	ilusam	ilusam =ilusam  (SgN  >ilusam !02_A	et	f	\N
121846	ilusam	"ilusam %ilusa  )M_cA  <ilus ;02_A	et	f	\N
121847	nig	### nig	et	f	\N
121854	veedsin	?veedsin =veedsi  (IndPrSg1  >veedsima !28_V	et	f	\N
121855	veedsin	?veedsin =veedsin  (SgN  >veedsin !02_S	et	f	\N
121860	suuurem	?suuurem =suuurem  (SgN  >suuurem !02_A	et	f	\N
121861	suuurem	?suuurem =urem  (SgN  >suu+urem !02_A	et	f	\N
121862	õppehooned	õppehooned =hoone  (PlN  >õppe+hoone !06_S	et	f	\N
121863	õppehooned	"õppe+hoone %hoo  )NE_aA  <õppe+hoog ;22_S	et	f	\N
121872	õppimise	õppimise =õppimise  (SgG  >õppimine !12_S	et	f	\N
121873	õppimise	"õppimine %õppi  )MINE_vS  <õppima ;28_V	et	f	\N
121876	kondal	?kondal =konda  (SgAd  >konda !16_S	et	f	\N
121877	kondal	?kondal =kondal  (SgN  >kondal !02_S	et	f	\N
121878	mehatroonikuks	?mehatroonikuks =mehatrooniku  (SgTr  >mehatroonik !02_S	et	f	\N
121879	mehatroonikuks	?mehatroonikuks =mehatrooniku  (KndPrPs  >mehatroonikuma !27_V	et	f	\N
121886	eestikeele	eestikeele =kee  (SgAll  >eesti+kesi !15_S	et	f	\N
121887	eestikeele	eestikeele =kee  (SgAll  >eesti+kee !26_S	et	f	\N
121888	eestikeele	eestikeele =keele  (SgG  >eesti+keel !13_S	et	f	\N
121925	teandus	?teandus =teandu  (SgIn  >teandu !01_S	et	f	\N
121926	teandus	?teandus =teandu  (IndIpfSg3  >teanduma !27_V	et	f	\N
121927	teandus	?teandus =teandus  (SgN  >teandus !11~09_S	et	f	\N
121935	motorid	?motorid =motori  (PlN  >motori !01_S	et	f	\N
121936	motorid	?motorid =motori  (PlN  >motor !02_S	et	f	\N
121967	ülikoolist	ülikoolist =kooli  (SgEl  >üli+kool !22_S	et	f	\N
121968	ülikoolist	ülikoolist =kooli  (PlEl  >üli+kool !22_S	et	f	\N
121969	ülikoolist	ülikoolist =koolis  (SgP  >üli+kooline !10_A	et	f	\N
121970	ülikoolist	"üli+kooline %koo  )LINE_aA  <üli+kubu ;18_S	et	f	\N
121971	ülikoolist	"üli+kooline %kooli  )NE_aA  <üli+kool ;22_S	et	f	\N
121973	soobivad	?soobivad =soobi  (IndPrPl3  >soobima !27_V	et	f	\N
121974	soobivad	?soobivad =soobi  (IndPrPl3  >soopima !28_V	et	f	\N
121975	soobivad	?soobivad =soobiva  (PlN  >soobiva !01_S	et	f	\N
121976	soobivad	?soobivad =soobiva  (PlN  >soobiv !02_A	et	f	\N
121977	soobivad	?soobivad =biva  (PlN  >soo+biva !17_S	et	f	\N
121978	loengutelt	loengutelt =loengu  (PlAbl  >loeng !02_S	et	f	\N
121979	loengutelt	loengutelt =ute  (SgAbl  >loeng+utt !22_S	et	f	\N
121980	loengutelt	loengutelt =ute  (PlAbl  >loeng+utt !22_S	et	f	\N
121985	tegelda	tegelda =tegel  (Inf  >tegelema !31_V	et	f	\N
121986	tegelda	tegelda =tegel  (IndPrIps_  >tegelema !31_V	et	f	\N
122036	lahendamist	lahendamist =lahendamis  (SgP  >lahendamine !12_S	et	f	\N
122037	lahendamist	"lahendamine %lahenda  )MINE_vS  <lahendama ;27_V	et	f	\N
122043	õneks	?õneks =õne  (SgTr  >õne !16_S	et	f	\N
122044	õneks	?õneks =õne  (KndPrPs  >õnema !27_V	et	f	\N
122048	koduloomat	?koduloomat =kodulooma  (SgP  >kodulooma !16_S	et	f	\N
122049	koduloomat	?koduloomat =loomat  (SgN  >kodu+loomat !02_S	et	f	\N
122080	mägid	?mägid =mägi  (IndPrSg2  >mägima !27_V	et	f	\N
122081	mägisse	?mägisse =mägisse  (SgG  >mägisne !02_A	et	f	\N
122082	mägisse	?mägisse =mägisse  (PlP  >mägiss !22_S	et	f	\N
122087	mangida	?mangida =mangi  (Inf  >mangima !28_V	et	f	\N
122088	vihma	vihma =vihma  (SgG  >vihm !22_S	et	f	\N
122089	vihma	vihma =vihma  (SgP  >vihm !22_S	et	f	\N
122091	vihma	vihma =vihma  (SgAdt  >vihm !22_S	et	f	\N
122092	jalgsiga	jalgsiga =si  (SgKom  >jalg+si !26_S	et	f	\N
122093	jalgsiga	jalgsiga =siga  (SgN  >jalg+siga !18_SA	et	f	\N
122094	jalgsiga	jalgsiga =siga  (SgP  >jalg+siga !18_SA	et	f	\N
122097	olaks	?olaks =ola  (SgTr  >ola !17_S	et	f	\N
122098	olaks	?olaks =ola  (KndPrPs  >olama !27_V	et	f	\N
122099	belgiasse	?belgiasse =belgia  (SgIll  >belgia !01_S	et	f	\N
121741	spordihoone	spordihoone =hoone  (PlP  >spordi+hoon !22_A	et	f	\N
121750	üheksast	üheksast =üheksa  (SgEl  >üheksa !01_N	et	f	\N
121751	üheksast	üheksast =üheksas  (SgP  >üheksane !12_A	et	f	\N
121752	üheksast	"üheksane %üheksa  )NE_aA  <üheksa ;01_N	et	f	\N
121753	üheksast	üheksast =ast  (SgN  >üheks+ast !22_S	et	f	\N
121758	spikirdasin	?spikirdasin =spikirda  (IndIpfSg1  >spikirdama !27_V	et	f	\N
121759	spikirdasin	?spikirdasin =spikirdasin  (SgN  >spikirdasin !19_S	et	f	\N
121760	loengudest	?loengudest =loengudes  (SgP  >loengudene !12_A	et	f	\N
121761	loengudest	?loengudest =udes  (SgP  >loeng+udes !09_S	et	f	\N
121762	loengudest	?loengudest =udes  (SgP  >loeng+udene !10_A	et	f	\N
121765	leidsib	?leidsib =leidsi  (IndPrSg3  >leidsima !28_V	et	f	\N
121790	suurused	suurused =suuruse  (PlN  >suurus !11~09_S	et	f	\N
121791	suurused	"suurus %suur  )US_aS  <suur ;13_A	et	f	\N
121792	suurused	suurused =suuruse  (PlN  >suurune !10~12_A	et	f	\N
121793	tunen	?tunen =tune  (IndPrSg1  >tunema !27_V	et	f	\N
121794	tunen	?tunen =tunen  (SgN  >tunen !02_S	et	f	\N
121798	mittu	?mittu =mittu  (ID  >mittu !41_D	et	f	\N
121799	mittu	?mittu =mittu  (IndPrPs_  >mittuma !27_V	et	f	\N
121800	mittu	?mittu =mittu  (ImpPrSg2  >mittuma !27_V	et	f	\N
121803	eksmati	eksmati =mati  (SgN  >eks+mati !16_S	et	f	\N
121804	eksmati	eksmati =mati  (SgG  >eks+mati !16_S	et	f	\N
121805	eksmati	eksmati =mati  (SgG  >eks+matt !22_SA	et	f	\N
121809	meeskonnas	meeskonnas =meeskonna  (SgIn  >meeskond !22_S	et	f	\N
121810	meeskonnas	meeskonnas =konna  (SgIn  >mees+konn !22_S	et	f	\N
121811	tootarendus	?tootarendus =tootarendu  (IndIpfSg3  >tootarenduma !27_V	et	f	\N
121812	tootarendus	?tootarendus =tootarendus  (SgN  >tootarendus !11_S	et	f	\N
121813	tootarendus	?tootarendus =tarendu  (SgIn  >too+tarendu !01_S	et	f	\N
121814	tootarendus	?tootarendus =tarendus  (SgN  >too+tarendus !11_S	et	f	\N
121840	kuulnud	kuulnud =kuul  (PtsPtPs  >kuulma !33_V	et	f	\N
121841	kuulnud	kuulnud =kuulnu  (PlN  >kuulnu !01_S	et	f	\N
121842	kuulnud	"kuulnu %kuul  )NU_vS  <kuulma ;33_V	et	f	\N
121843	kuulnud	kuulnud =kuulnud  (ID  >kuulnud !41_A	et	f	\N
121844	kuulnud	"kuulnud %kuul  )NUD_vA  <kuulma ;33_V	et	f	\N
121848	õppeasutus	õppeasutus =asutu  (SgIn  >õppe+asutu !01_AS	et	f	\N
121849	õppeasutus	"õppe+asutu %asu  )TU2_kA  <õppe+asu ;17_S	et	f	\N
121850	õppeasutus	õppeasutus =asutus  (SgN  >õppe+asutus !11_S	et	f	\N
121851	õppeasutus	"õppe+asutus %asu  )TUS2_aS  <õppe+asu ;17_S	et	f	\N
121856	õppingukorralduse	?õppingukorralduse =õppingukorralduse  (SgG  >õppingukorraldus !11_S	et	f	\N
121870	kolmeks	kolmeks =kolme  (SgTr  >kolm !22_N	et	f	\N
121871	kolmeks	kolmeks =kolme  (PlTr  >kolm !22_N	et	f	\N
121874	mehaanikateadus	mehaanikateadus =teadu  (SgIn  >mehaanika+tead !22_S	et	f	\N
121875	mehaanikateadus	mehaanikateadus =teadus  (SgN  >mehaanika+teadus !11~09_S	et	f	\N
121905	breakdance	?breakdance =breakdance  (PlP  >breakdanc !22_S	et	f	\N
121916	lõpuksin	?lõpuksin =lõpu  (KndPrSg1  >lõpuma !27_V	et	f	\N
121917	lõpuksin	?lõpuksin =lõpuksi  (IndPrSg1  >lõpuksima !28_V	et	f	\N
121919	lõpuksin	?lõpuksin =lõpuksin  (SgN  >lõpuksin !19_S	et	f	\N
121923	mehaanika	mehaanika =mehaanika  (SgN  >mehaanika !01_S	et	f	\N
121924	mehaanika	mehaanika =mehaanika  (SgG  >mehaanika !01_S	et	f	\N
121928	konna	konna =konna  (SgG  >konn !22_S	et	f	\N
121929	konna	konna =konna  (SgP  >konn !22_S	et	f	\N
121930	konna	konna =konna  (SgAdt  >konn !22_S	et	f	\N
121945	lastepõlves	lastepõlves =põlve  (SgIn  >laste+põlv !22_S	et	f	\N
121946	lastepõlves	lastepõlves =põlve  (SgIn  >laste+põli !24_S	et	f	\N
121947	lastepõlves	lastepõlves =põlve  (PlIn  >laste+põlv !22_S	et	f	\N
121951	jätkada	### jätkada	et	f	\N
121965	kuulsamad	kuulsamad =kuulsama  (PlN  >kuulsam !02_A	et	f	\N
121966	kuulsamad	"kuulsam %kuulsa  )M_cA  <kuulus ;02_A	et	f	\N
121981	suuline	suuline =suuline  (SgN  >suuline !12?10_AS	et	f	\N
121982	suuline	"suuline %suu  )LINE_aA  <suu ;26_S	et	f	\N
121983	sündin	?sündin =sündi  (IndPrSg1  >süntima !28_V	et	f	\N
121984	sündin	?sündin =sündin  (SgN  >sündin !02_S	et	f	\N
122008	info	info =info  (SgN  >info !16_S	et	f	\N
122009	info	info =info  (SgG  >info !16_S	et	f	\N
122014	karjamaa	karjamaa =maa  (SgN  >karja+maa !26_S	et	f	\N
122015	karjamaa	karjamaa =maa  (SgG  >karja+maa !26_S	et	f	\N
122022	ehitusteaduskonda	ehitusteaduskonda =teaduskonda  (SgP  >ehitus+teaduskond !22_S	et	f	\N
122023	ehitusteaduskonda	ehitusteaduskonda =teaduskonda  (SgAdt  >ehitus+teaduskond !22_S	et	f	\N
122028	tudengielu	tudengielu =elu  (SgN  >tudengi+elu !17_S	et	f	\N
122029	tudengielu	tudengielu =elu  (SgG  >tudengi+elu !17_S	et	f	\N
122030	tudengielu	tudengielu =elu  (SgP  >tudengi+elu !17_S	et	f	\N
122033	jalgpalli	jalgpalli =palli  (SgG  >jalg+pall !22_S	et	f	\N
122034	jalgpalli	jalgpalli =palli  (SgP  >jalg+pall !22_S	et	f	\N
122035	jalgpalli	jalgpalli =palli  (SgAdt  >jalg+pall !22_S	et	f	\N
122059	jaapani	?jaapani =jaapa  (SgTer  >jaapa !16_S	et	f	\N
122061	jaapani	?jaapani =jaapani  (SgG  >jaapan !02_S	et	f	\N
122063	sündiks	?sündiks =sündi  (SgTr  >sündi !16_S	et	f	\N
122064	sündiks	?sündiks =sündi  (SgTr  >sünt !22_S	et	f	\N
121755	kodutöö	kodutöö =töö  (SgG  >kodu+töö !26_S	et	f	\N
121763	estlastega	?estlastega =estlas  (PlKom  >estlas !07_S	et	f	\N
121764	estlastega	?estlastega =estlas  (PlKom  >estlane !12?10_S	et	f	\N
121771	narvast	?narvast =narva  (SgEl  >narva !16_S	et	f	\N
121772	narvast	?narvast =narvas  (SgP  >narvas !07_S	et	f	\N
121773	narvast	?narvast =narvas  (SgP  >narvane !10_A	et	f	\N
121778	soovitasid	soovitasid =soovita  (IndIpfSg2  >soovitama !27_V	et	f	\N
121779	soovitasid	soovitasid =soovita  (IndIpfPl3  >soovitama !27_V	et	f	\N
121815	huuvitav	?huuvitav =huuvi  (PtsPrIps  >huuvima !28_V	et	f	\N
121816	huuvitav	?huuvitav =huuvita  (PtsPrPs  >huuvitama !27_V	et	f	\N
121817	huuvitav	?huuvitav =huuvitav  (SgN  >huuvitav !02_A	et	f	\N
121822	asuvad	asuvad =asu  (IndPrPl3  >asuma !27_V	et	f	\N
121824	asuvad	asuvad =asuva  (PlN  >asuv !02_A	et	f	\N
121825	asuvad	"asuv %asu  )V_vA  <asuma ;27_V	et	f	\N
121828	üheksateistkümne	?üheksateistkümne =üheksateistkümne  (SgN  >üheksateistkümne !02_A	et	f	\N
121829	üheksateistkümne	?üheksateistkümne =üheksateistkümne  (PlP  >üheksateistkümn !22_S	et	f	\N
121830	üheksateistkümne	?üheksateistkümne =kümne  (SgN  >üheksa+teist+kümne !02_A	et	f	\N
121831	üheksateistkümne	?üheksateistkümne =kümne  (PlP  >üheksa+teist+kümn !22_S	et	f	\N
121833	üheksateistkümne	?üheksateistkümne =teistkümne  (SgN  >üheksa+teistkümne !02_A	et	f	\N
121835	üheksateistkümne	?üheksateistkümne =teistkümne  (PlP  >üheksa+teistkümn !22_S	et	f	\N
121836	üheksateistkümne	?üheksateistkümne =ateistkümne  (SgN  >üheks+ateistkümne !02_A	et	f	\N
121837	üheksateistkümne	?üheksateistkümne =ateistkümne  (PlP  >üheks+ateistkümn !22_S	et	f	\N
121838	üheksateistkümne	?üheksateistkümne =ksateistkümne  (SgN  >ühe+ksateistkümne !02_A	et	f	\N
121839	üheksateistkümne	?üheksateistkümne =ksateistkümne  (PlP  >ühe+ksateistkümn !22_S	et	f	\N
121865	tunniplaani	tunniplaani =plaani  (SgG  >tunni+plaan !22_S	et	f	\N
121866	tunniplaani	tunniplaani =plaani  (SgP  >tunni+plaan !22_S	et	f	\N
121869	tunniplaani	tunniplaani =plaani  (SgAdt  >tunni+plaan !22_S	et	f	\N
121892	hobbid	?hobbid =hobbi  (PlN  >hobbi !16_S	et	f	\N
121893	hobbid	?hobbid =hobbi  (PlN  >hobb !22_S	et	f	\N
121894	hobbid	?hobbid =hobbi  (IndPrSg2  >hobbima !28_V	et	f	\N
121938	gitarri	?gitarri =gitarri  (SgN  >gitarri !01_S	et	f	\N
121939	gitarri	?gitarri =gitarri  (SgG  >gitarri !01_S	et	f	\N
121940	gitarri	?gitarri =gitarri  (SgG  >gitarr !22_S	et	f	\N
121941	gitarri	?gitarri =gitarri  (SgP  >gitarr !22_S	et	f	\N
121942	gitarri	?gitarri =gitarri  (SgAdt  >gitarr !22_S	et	f	\N
121943	gitarri	?gitarri =gitarri  (IndPrPs_  >gitarrima !28_V	et	f	\N
121944	gitarri	?gitarri =gitarri  (ImpPrSg2  >gitarrima !28_V	et	f	\N
121962	ehituses	ehituses =ehituse  (SgIn  >ehitus !11_S	et	f	\N
121963	ehituses	"ehitus %ehita  )US_vS  <ehitama ;27_V	et	f	\N
121964	ehituses	"ehitus %ehi  )TUS1_aS  <ehtima ;28_V	et	f	\N
121972	õppime	### õppime	et	f	\N
121990	elistan	?elistan =elista  (IndPrSg1  >elistama !27_V	et	f	\N
121991	elistan	?elistan =elistan  (SgN  >elistan !19_S	et	f	\N
121992	studengid	?studengid =studengi  (PlN  >studeng !02_S	et	f	\N
121993	studengid	?studengid =studengi  (PlN  >studenk !22_S	et	f	\N
121994	studengid	?studengid =studengi  (IndPrSg2  >studenkima !28_V	et	f	\N
121995	sõbralikumad	sõbralikumad =sõbralikuma  (PlN  >sõbralikum !02_A	et	f	\N
121996	sõbralikumad	"sõbralikum %sõbraliku  )M_cA  <sõbralik ;25_A	et	f	\N
122026	materiaal	?materiaal =materiaa  (SgAd  >materiaa !26_S	et	f	\N
122027	materiaal	?materiaal =materiaal  (SgN  >materiaal !22_S	et	f	\N
122045	koostis	koostis =koosti  (SgIn  >koost !22_S	et	f	\N
122046	koostis	koostis =koosti  (PlIn  >koost !22_S	et	f	\N
122047	koostis	koostis =koostis  (SgN  >koostis !11~09_S	et	f	\N
122052	abituriendidele	?abituriendidele =abituriendi  (PlAll  >abituriend !22_S	et	f	\N
122053	abituriendidele	?abituriendidele =turiendi  (PlAll  >abi+turiend !22_S	et	f	\N
122054	kuuleda	?kuuleda =kuule  (Inf  >kuulema !27_V	et	f	\N
122055	kuuleda	?kuuleda =eda  (SgN  >kuul+eda !17_S	et	f	\N
122056	kuuleda	?kuuleda =eda  (SgG  >kuul+eda !17_S	et	f	\N
122057	kuuleda	?kuuleda =eda  (SgP  >kuul+eda !17_S	et	f	\N
122058	kuuleda	?kuuleda =leda  (SgN  >kuu+leda !17_S	et	f	\N
122060	kuuleda	?kuuleda =leda  (SgG  >kuu+leda !17_S	et	f	\N
122062	kuuleda	?kuuleda =leda  (SgP  >kuu+leda !17_S	et	f	\N
122067	aedga	?aedga =aedga  (SgN  >aedga !01_S	et	f	\N
122068	aedga	?aedga =aedga  (SgG  >aedga !01_S	et	f	\N
122069	aedga	?aedga =aedga  (IndPrPs_  >aedgama !29_V	et	f	\N
122070	aedga	?aedga =aedga  (ImpPrSg2  >aedgama !29_V	et	f	\N
122071	pruuni	pruuni =pruuni  (SgG  >pruun !22_AS	et	f	\N
122072	pruuni	pruuni =pruuni  (SgP  >pruun !22_AS	et	f	\N
122073	pruuni	pruuni =pruuni  (SgAdt  >pruun !22_AS	et	f	\N
122083	ujuks	ujuks =uju  (SgTr  >uju !17_S	et	f	\N
122084	ujuks	ujuks =uju  (KndPrPs  >ujuma !27_V	et	f	\N
122101	prantsusmaale	prantsusmaale =maa  (SgAll  >prantsus+maa !26_S	et	f	\N
122102	prantsusmaale	prantsusmaale =maale  (PlP  >prantsus+maal !22_S	et	f	\N
122125	pubis	?pubis =pubi  (SgIn  >pubi !17_S	et	f	\N
122126	pubis	?pubis =pubi  (IndIpfSg3  >pubima !27_V	et	f	\N
121818	sisteemid	?sisteemid =sisteemi  (PlN  >sisteemi !16_S	et	f	\N
121819	sisteemid	?sisteemid =sisteemi  (PlN  >sisteem !22_S	et	f	\N
121820	sisteemid	?sisteemid =sisteemi  (IndPrSg2  >sisteemima !28_V	et	f	\N
121821	koduneülesandeid	?koduneülesandeid =koduneülesandei  (PlN  >koduneülesandei !26_S	et	f	\N
121823	koduneülesandeid	?koduneülesandeid =koduneülesandei  (SgP  >koduneülesandei !26_S	et	f	\N
121826	koduneülesandeid	?koduneülesandeid =neülesandei  (PlN  >kodu+neülesandei !26_S	et	f	\N
121827	koduneülesandeid	?koduneülesandeid =neülesandei  (SgP  >kodu+neülesandei !26_S	et	f	\N
121858	üülikool	?üülikool =üülikoo  (SgAd  >üülikoo !26_S	et	f	\N
121859	üülikool	?üülikool =üülikool  (SgN  >üülikool !22_S	et	f	\N
121880	meehatroomikud	?meehatroomikud =meehatroomiku  (PlN  >meehatroomik !02_S	et	f	\N
121881	meehatroomikud	?meehatroomikud =meehatroomiku  (IndPrSg2  >meehatroomikuma !27_V	et	f	\N
121882	meehatroomikud	?meehatroomikud =hatroomiku  (PlN  >mee+hatroomik !02_S	et	f	\N
121895	hobbi	?hobbi =hobbi  (SgN  >hobbi !16_S	et	f	\N
121896	hobbi	?hobbi =hobbi  (SgG  >hobbi !16_S	et	f	\N
121897	hobbi	?hobbi =hobbi  (SgG  >hobb !22_S	et	f	\N
121898	hobbi	?hobbi =hobbi  (SgP  >hobb !22_S	et	f	\N
121899	hobbi	?hobbi =hobbi  (SgAdt  >hobb !22_S	et	f	\N
121900	hobbi	?hobbi =hobbi  (IndPrPs_  >hobbima !28_V	et	f	\N
121901	hobbi	?hobbi =hobbi  (ImpPrSg2  >hobbima !28_V	et	f	\N
121902	spordi	spordi =spordi  (SgG  >sport !22_S	et	f	\N
121903	spordi	spordi =spordi  (IndPrPs_  >sportima !28_V	et	f	\N
121904	spordi	spordi =spordi  (ImpPrSg2  >sportima !28_V	et	f	\N
121931	töökohas	töökohas =koha  (SgIn  >töö+koha !17_S	et	f	\N
121932	töökohas	töökohas =koha  (SgIn  >töö+koht !22_S	et	f	\N
121933	kond	?kond =kond  (SgN  >kond !22_S	et	f	\N
121952	tuleviku	tuleviku =tuleviku  (SgG  >tulevik !25_S	et	f	\N
121953	tuleviku	tuleviku =viku  (SgG  >tule+vikk !22_S	et	f	\N
121956	elutus	elutus =elutu  (SgIn  >elutu !01_A	et	f	\N
121957	elutus	"elutu %elu  )TU2_kA  <elu ;17_S	et	f	\N
121958	elutus	elutus =elutus  (SgN  >elutus !11_S	et	f	\N
121959	elutus	"elutus %elu  )TUS2_aS  <elu ;17_S	et	f	\N
121960	kelleks	kelleks =kelle  (SgTr  >kes !00_P	et	f	\N
121961	kelleks	kelleks =kelle  (PlTr  >kell !22_S	et	f	\N
121997	kasaaegne	?kasaaegne =kasaaegne  (SgN  >kasaaegne !02_A	et	f	\N
121998	kasaaegne	?kasaaegne =kasaaegne  (PlP  >kasaaegn !22_S	et	f	\N
121999	kasaaegne	?kasaaegne =aaegne  (SgN  >kas+aaegne !02_A	et	f	\N
122000	kasaaegne	?kasaaegne =aaegne  (PlP  >kas+aaegn !22_S	et	f	\N
122003	suhtlemis	?suhtlemis =suhtlemi  (SgIn  >suhtlemi !01_S	et	f	\N
122004	suhtlemis	?suhtlemis =suhtlemi  (SgIn  >suhtlem !02_A	et	f	\N
122005	suhtlemis	?suhtlemis =suhtlemis  (SgN  >suhtlemis !11_S	et	f	\N
122006	suhtlemis	?suhtlemis =lemi  (SgIn  >suht+lemi !17_S	et	f	\N
122007	suhtlemis	?suhtlemis =lemis  (SgN  >suht+lemis !09_S	et	f	\N
122010	raamatukogus	raamatukogus =kogu  (SgIn  >raamatu+kogu !17_S	et	f	\N
122011	raamatukogus	raamatukogus =kogus  (SgN  >raamatu+kogus !02_A	et	f	\N
122012	raamatukogus	raamatukogus =kogus  (SgN  >raamatu+kogus !09_S	et	f	\N
122013	exam	?exam =exam  (SgN  >exam !02_S	et	f	\N
122016	ehituse	ehituse =ehituse  (SgG  >ehitus !11_S	et	f	\N
122017	ehituse	"ehitus %ehita  )US_vS  <ehitama ;27_V	et	f	\N
122018	ehituse	"ehitus %ehi  )TUS1_aS  <ehtima ;28_V	et	f	\N
122038	valdata	?valdata =valda  (SgAb  >valda !16_S	et	f	\N
122039	valdata	?valdata =valda  (Inf  >valtama !29_V	et	f	\N
122040	valdata	?valdata =valda  (IndPrIps_  >valtama !29_V	et	f	\N
122041	valdata	?valdata =valdata  (IndPrPs_  >valdatama !27_V	et	f	\N
122042	valdata	?valdata =valdata  (ImpPrSg2  >valdatama !27_V	et	f	\N
122085	meris	?meris =meri  (IndIpfSg3  >merima !27_V	et	f	\N
122086	meris	?meris =meris  (SgN  >meris !09_S	et	f	\N
122104	itaaliasse	?itaaliasse =itaalia  (SgIll  >itaalia !01_S	et	f	\N
122106	itaaliasse	?itaaliasse =itaalias  (SgAdt  >itaalias !11_S	et	f	\N
122107	itaaliasse	?itaaliasse =itaaliasse  (SgG  >itaaliasne !02_A	et	f	\N
122108	itaaliasse	?itaaliasse =itaaliasse  (PlP  >itaaliass !22_S	et	f	\N
122117	rimis	?rimis =rimi  (SgIn  >rimi !17_S	et	f	\N
122118	rimis	?rimis =rimi  (IndIpfSg3  >rimima !27_V	et	f	\N
122119	rimis	?rimis =rimis  (SgN  >rimis !09_S	et	f	\N
122131	juuli	juuli =juuli  (SgN  >juuli !16_S	et	f	\N
122132	juuli	juuli =juuli  (SgG  >juuli !16_S	et	f	\N
122144	randa	randa =randa  (SgP  >rand !22_S	et	f	\N
122145	randa	randa =randa  (SgAdt  >rand !22_S	et	f	\N
122152	inimesedega	### inimesedega	et	f	\N
122153	õpinud	?õpinud =õpi  (PtsPtPs  >õpima !27_V	et	f	\N
122154	õpinud	?õpinud =õpinu  (PlN  >õpinu !01_S	et	f	\N
122155	õpinud	?õpinud =õpinu  (IndPrSg2  >õpinuma !27_V	et	f	\N
122156	õpinud	?õpinud =õpinud  (ID  >õpinud !41_A	et	f	\N
122161	jaapan	?jaapan =jaapa  (IndPrSg1  >jaapama !29_V	et	f	\N
122162	jaapan	?jaapan =jaapan  (SgN  >jaapan !02_S	et	f	\N
122178	oppima	?oppima =oppi  (Sup  >oppima !28_V	et	f	\N
122179	oppima	?oppima =oppima  (SgG  >oppim !02_A	et	f	\N
122183	sveitsis	?sveitsis =sveitsi  (SgIn  >sveits !22_S	et	f	\N
122184	sveitsis	?sveitsis =sveitsi  (IndIpfSg3  >sveitsima !28_V	et	f	\N
122065	sündiks	?sündiks =sündi  (KndPrPs  >süntima !28_V	et	f	\N
122066	kolmkümmend	?kolmkümmend =kolmkümmend  (SgN  >kolmkümmend !22_S	et	f	\N
122074	koera	koera =koera  (SgG  >koer !23?22_SA	et	f	\N
122075	koera	koera =koera  (SgP  >koer !23?22_SA	et	f	\N
122076	koera	koera =koera  (SgAdt  >koer !23?22_SA	et	f	\N
122095	jüüa	?jüüa =jüüa  (SgN  >jüüa !16_S	et	f	\N
122096	jüüa	?jüüa =jüüa  (SgG  >jüüa !16_S	et	f	\N
122113	hommikust	hommikust =hommiku  (SgEl  >hommik !02_S	et	f	\N
122114	hommikust	hommikust =hommikus  (SgP  >hommikune !12_A	et	f	\N
122115	hommikust	"hommikune %hommiku  )NE_aA  <hommik ;02_S	et	f	\N
122116	hommikust	hommikust =us  (SgP  >hommik+uks !14_S	et	f	\N
122128	brüsselis	?brüsselis =brüsseli  (SgIn  >brüssel !02_S	et	f	\N
122129	brüsselis	?brüsselis =brüsselis  (SgN  >brüsselis !11_S	et	f	\N
122130	õppin	?õppin =õppin  (SgN  >õppin !02_S	et	f	\N
122141	pesu	pesu =pesu  (SgN  >pesu !17_S	et	f	\N
122142	pesu	pesu =pesu  (SgG  >pesu !17_S	et	f	\N
122143	pesu	pesu =pesu  (SgP  >pesu !17_S	et	f	\N
122148	oleda	### oleda	et	f	\N
122157	jala	jala =jala  (ID  >jala !41_D	et	f	\N
122158	jala	jala =jala  (SgG  >jalg !22_S	et	f	\N
122163	elatud	elatud =ela  (PtsPtIps  >elama !27_V	et	f	\N
122164	elatud	elatud =elatu  (PlN  >elatu !01_S	et	f	\N
122165	elatud	"elatu %ela  )TU1_vS  <elama ;27_V	et	f	\N
122166	elatud	elatud =elatu  (IndPrSg2  >elatuma !27_V	et	f	\N
122167	elatud	elatud =elatud  (ID  >elatud !41_A	et	f	\N
122168	elatud	"elatud %ela  )TUD_vA  <elama ;27_V	et	f	\N
122199	maaid	?maaid =maaid  (SgN  >maaid !02_S	et	f	\N
122200	täitunud	täitunud =täitu  (PtsPtPs  >täituma !27_V	et	f	\N
122201	täitunud	täitunud =täitunu  (PlN  >täitunu !01_S	et	f	\N
122202	täitunud	"täitunu %täitu  )NU_vS  <täituma ;27_V	et	f	\N
122203	täitunud	täitunud =täitunud  (ID  >täitunud !41_A	et	f	\N
122204	täitunud	"täitunud %täitu  )NUD_vA  <täituma ;27_V	et	f	\N
122217	õunapuud	õunapuud =puu  (PlN  >õuna+puu !26_S	et	f	\N
122218	õunapuud	õunapuud =puu  (SgP  >õuna+puu !26_S	et	f	\N
122220	õunapuud	õunapuud =puud  (SgN  >õuna+puud !22_S	et	f	\N
122223	keskaias	keskaias =aia  (SgIn  >kesk+aed !22_S	et	f	\N
122224	keskaias	keskaias =aia  (SgIn  >kesk+ai !22_S	et	f	\N
122227	tt	### tt	et	f	\N
122228	eluloost	eluloost =loo  (SgEl  >elu+lugu !18_S	et	f	\N
122229	eluloost	eluloost =loo  (SgEl  >elu+loog !22_S	et	f	\N
122230	eluloost	eluloost =loo  (SgEl  >elu+lood !22_S	et	f	\N
122231	keelel	keelel =keele  (SgAd  >keel !13_S	et	f	\N
122232	keelel	keelel =keele  (PlAd  >keeld !22_S	et	f	\N
122242	aafrikas	?aafrikas =aafrika  (SgIn  >aafrika !01_S	et	f	\N
122243	aafrikas	?aafrikas =aafrika  (SgIn  >aafrikas !02_S	et	f	\N
122244	aafrikas	?aafrikas =aafrikas  (SgN  >aafrikas !02_S	et	f	\N
122254	esimenel	?esimenel =esimene  (PlAd  >esimen !19_S	et	f	\N
122255	esimenel	?esimenel =mene  (SgAd  >esi+mene !16_S	et	f	\N
122256	esimenel	?esimenel =menel  (SgN  >esi+menel !02_S	et	f	\N
122262	meldiv	meldiv =meldi  (PtsPrPs  >meldima !28_V	et	f	\N
122264	meldiv	meldiv =meldiv  (SgN  >meldiv !02_A	et	f	\N
122265	meldiv	"meldiv %meldi  )V_vA  <meldima ;28_V	et	f	\N
122273	korea	korea =korea  (SgN  >korea !26_S	et	f	\N
122274	korea	korea =korea  (SgG  >korea !26_S	et	f	\N
122283	maakohti	maakohti =kohti  (SgP  >maa+koht !22_S	et	f	\N
122284	maakohti	maakohti =kohti  (SgAdt  >maa+koht !22_S	et	f	\N
122285	maakohti	maakohti =kohti  (PlP  >maa+koht !22_S	et	f	\N
122289	töötid	### töötid	et	f	\N
122292	tokios	?tokios =tokio  (SgIn  >tokio !01_S	et	f	\N
122293	tokios	?tokios =tokios  (SgN  >tokios !22_S	et	f	\N
122303	õpetajani	õpetajani =õpetaja  (SgTer  >õpetaja !01_S	et	f	\N
122304	õpetajani	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
122315	suvis	?suvis =suvi  (IndIpfSg3  >suvima !27_V	et	f	\N
122316	suvis	?suvis =suvis  (SgN  >suvis !09_S	et	f	\N
122328	vanaema	vanaema =ema  (SgN  >vana+ema !17_S	et	f	\N
122329	vanaema	vanaema =ema  (SgG  >vana+ema !17_S	et	f	\N
122330	vanaema	vanaema =ema  (SgP  >vana+ema !17_S	et	f	\N
122338	kompaniid	kompaniid =kompanii  (PlN  >kompanii !26_S	et	f	\N
122339	kompaniid	kompaniid =kompanii  (SgP  >kompanii !26_S	et	f	\N
122340	lõpetama	lõpetama =lõpe  (SupIps  >lõppema !28_V	et	f	\N
122341	lõpetama	lõpetama =lõpe  (SupIps  >lõpma !35_V	et	f	\N
122342	lõpetama	lõpetama =lõpeta  (Sup  >lõpetama !27_V	et	f	\N
122343	teasin	?teasin =teasi  (IndPrSg1  >teasima !28_V	et	f	\N
122344	teasin	?teasin =teasin  (SgN  >teasin !02_S	et	f	\N
122368	kohvi	kohvi =kohvi  (SgG  >kohv !22_S	et	f	\N
122369	kohvi	kohvi =kohvi  (SgP  >kohv !22_S	et	f	\N
122370	kohvi	kohvi =kohvi  (SgAdt  >kohv !22_S	et	f	\N
122422	inimesedeks	### inimesedeks	et	f	\N
122423	erinevate	erinevate =erineva  (PlG  >erinev !02_A	et	f	\N
122424	erinevate	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
122433	eksistentsialistlikku	?eksistentsialistlikku =eksistentsialistlikku  (SgP  >eksistentsialistlik !25_A	et	f	\N
122100	belgiasse	?belgiasse =belgias  (SgAdt  >belgias !11_S	et	f	\N
122103	belgiasse	?belgiasse =belgiasse  (SgG  >belgiasne !02_A	et	f	\N
122105	belgiasse	?belgiasse =belgiasse  (PlP  >belgiass !22_S	et	f	\N
122109	jaapanisse	?jaapanisse =jaapani  (SgIll  >jaapan !02_S	et	f	\N
122110	jaapanisse	?jaapanisse =jaapanis  (SgAdt  >jaapanis !11_S	et	f	\N
122111	jaapanisse	?jaapanisse =jaapanisse  (SgG  >jaapanisne !02_A	et	f	\N
122112	jaapanisse	?jaapanisse =jaapanisse  (PlP  >jaapaniss !22_S	et	f	\N
122133	teotahteline	teotahteline =tahteline  (SgN  >teo+tahteline !12_A	et	f	\N
122134	teotahteline	"teo+tahteline %tahte  )LINE_aA  <teo+tahe ;06_S	et	f	\N
122159	jaapanis	?jaapanis =jaapani  (SgIn  >jaapan !02_S	et	f	\N
122160	jaapanis	?jaapanis =jaapanis  (SgN  >jaapanis !11_S	et	f	\N
122170	sõime	sõime =sõ  (IndIpfPl1  >sööma !38_V	et	f	\N
122171	sõime	sõime =sõime  (SgG  >sõim !22_S	et	f	\N
122172	sõime	sõime =sõime  (SgP  >sõim !22_S	et	f	\N
122173	sõime	sõime =sõime  (SgAdt  >sõim !22_S	et	f	\N
122174	sõime	sõime =sõime  (PlP  >sõim !22_S	et	f	\N
122175	õhtust	õhtust =õhtu  (SgEl  >õhtu !01_S	et	f	\N
122176	õhtust	õhtust =õhtus  (SgP  >õhtune !12~10_A	et	f	\N
122177	õhtust	"õhtune %õhtu  )NE_aA  <õhtu ;01_S	et	f	\N
122180	hollandis	?hollandis =hollandi  (SgIn  >hollandi !01_S	et	f	\N
122181	hollandis	?hollandis =hollandi  (SgIn  >holland !02_S	et	f	\N
122182	hollandis	?hollandis =hollandi  (SgIn  >hollant !22_S	et	f	\N
122186	hollandis	?hollandis =hollandi  (IndIpfSg3  >hollandima !28_V	et	f	\N
122187	hollandis	?hollandis =hollandis  (SgN  >hollandis !11_S	et	f	\N
122188	prantsusmaal	prantsusmaal =maa  (SgAd  >prantsus+maa !26_S	et	f	\N
122189	prantsusmaal	prantsusmaal =maal  (SgN  >prantsus+maal !22_S	et	f	\N
122205	muinasjuttu	muinasjuttu =juttu  (SgP  >muinas+jutt !22_S	et	f	\N
122206	muinasjuttu	muinasjuttu =juttu  (SgAdt  >muinas+jutt !22_S	et	f	\N
122211	kassiga	kassiga =kassi  (SgKom  >kass !22_S	et	f	\N
122212	kassiga	kassiga =si  (SgKom  >kas+si !26_S	et	f	\N
122213	kassiga	kassiga =siga  (SgN  >kas+siga !18_SA	et	f	\N
122214	kassiga	kassiga =siga  (SgP  >kas+siga !18_SA	et	f	\N
122225	spordiauto	spordiauto =auto  (SgN  >spordi+auto !16_S	et	f	\N
122226	spordiauto	spordiauto =auto  (SgG  >spordi+auto !16_S	et	f	\N
122250	belgias	?belgias =belgia  (SgIn  >belgia !01_S	et	f	\N
122251	belgias	?belgias =belgias  (SgN  >belgias !11_S	et	f	\N
122290	töötaks	töötaks =tööta  (KndPrPs  >töötama !27_V	et	f	\N
122291	töötaks	töötaks =taks  (SgN  >töö+taks !22_S	et	f	\N
122308	puumaja	puumaja =maja  (SgN  >puu+maja !17_S	et	f	\N
122310	puumaja	puumaja =maja  (SgG  >puu+maja !17_S	et	f	\N
122311	puumaja	puumaja =maja  (SgP  >puu+maja !17_S	et	f	\N
122317	mägile	?mägile =mägile  (IndPrPs_  >mägilema !27_V	et	f	\N
122318	mägile	?mägile =mägile  (ImpPrSg2  >mägilema !27_V	et	f	\N
122320	valia	?valia =valia  (SgN  >valia !01_S	et	f	\N
122321	valia	?valia =valia  (SgG  >valia !01_S	et	f	\N
122323	taevas	taevas =taeva  (SgIn  >taevas !07_S	et	f	\N
122324	taevas	taevas =taevas  (SgN  >taevas !07_S	et	f	\N
122331	vanaisa	vanaisa =isa  (SgN  >vana+isa !17_S	et	f	\N
122332	vanaisa	vanaisa =isa  (SgG  >vana+isa !17_S	et	f	\N
122333	vanaisa	vanaisa =isa  (SgP  >vana+isa !17_S	et	f	\N
122334	käsitööd	käsitööd =töö  (PlN  >käsi+töö !26_S	et	f	\N
122335	käsitööd	käsitööd =töö  (SgP  >käsi+töö !26_S	et	f	\N
122336	sündmusid	?sündmusid =sündmu  (IndIpfSg2  >sündmuma !27_V	et	f	\N
122337	sündmusid	?sündmusid =sündmu  (IndIpfPl3  >sündmuma !27_V	et	f	\N
122378	suusakuurortisse	?suusakuurortisse =suusakuurortisse  (SgG  >suusakuurortisne !02_A	et	f	\N
122379	suusakuurortisse	?suusakuurortisse =suusakuurortisse  (PlP  >suusakuurortiss !22_S	et	f	\N
122380	suusakuurortisse	?suusakuurortisse =rortisse  (SgG  >suusa+kuu+rortisne !02_A	et	f	\N
122381	suusakuurortisse	?suusakuurortisse =rortisse  (PlP  >suusa+kuu+rortiss !22_S	et	f	\N
122382	suusakuurortisse	?suusakuurortisse =kuurorti  (SgIll  >suusa+kuurorti !01_S	et	f	\N
122383	suusakuurortisse	?suusakuurortisse =kuurortis  (SgAdt  >suusa+kuurortis !11_S	et	f	\N
122384	suusakuurortisse	?suusakuurortisse =kuurortisse  (SgG  >suusa+kuurortisne !02_A	et	f	\N
122385	suusakuurortisse	?suusakuurortisse =kuurortisse  (PlP  >suusa+kuurortiss !22_S	et	f	\N
122386	suusakuurortisse	?suusakuurortisse =sakuurortisse  (SgG  >suu+sakuurortisne !02_A	et	f	\N
122387	suusakuurortisse	?suusakuurortisse =sakuurortisse  (PlP  >suu+sakuurortiss !22_S	et	f	\N
122390	unusta	unusta =unusta  (IndPrPs_  >unustama !27_V	et	f	\N
122391	unusta	unusta =unusta  (ImpPrSg2  >unustama !27_V	et	f	\N
122392	münchenisse	?münchenisse =müncheni  (SgIll  >münchen !02_S	et	f	\N
122393	münchenisse	?münchenisse =münchenis  (SgAdt  >münchenis !11_S	et	f	\N
122394	münchenisse	?münchenisse =münchenisse  (SgG  >münchenisne !02_A	et	f	\N
122395	münchenisse	?münchenisse =münchenisse  (PlP  >müncheniss !22_S	et	f	\N
122405	võõrasse	võõrasse =võõra  (SgIll  >võõras !07_AS	et	f	\N
122407	võõrasse	võõrasse =asse  (PlP  >võõr+ass !22_S	et	f	\N
122412	tubaga	### tubaga	et	f	\N
122415	tuleda	### tuleda	et	f	\N
122419	vaene	vaene =vaene  (SgN  >vaene !10_AS	et	f	\N
122420	vaene	"vaene %vae  )NE_aA  <vaag ;22_S	et	f	\N
122127	pubis	?pubis =pubis  (SgN  >pubis !09_S	et	f	\N
122137	silmad	silmad =silma  (PlN  >silm !22_S	et	f	\N
122138	silmad	silmad =silma  (IndPrSg2  >silmama !29_V	et	f	\N
122139	august	august =augu  (SgEl  >auk !22_S	et	f	\N
122140	august	august =august  (SgN  >august !02_S	et	f	\N
122215	aias	aias =aia  (SgIn  >aed !22_S	et	f	\N
122216	aias	aias =aia  (SgIn  >ai !22_S	et	f	\N
122245	lõuna-ameerikas	?lõuna-ameerikas =ameerika  (SgIn  >lõuna-ameerikas !02_A	et	f	\N
122246	lõuna-ameerikas	?lõuna-ameerikas =ameerikas  (SgN  >lõuna-ameerikas !02_A	et	f	\N
122247	sportin	?sportin =sportin  (SgN  >sportin !02_S	et	f	\N
122252	peregi	peregi =pere  (SgN^  >pere !16_S	et	f	\N
122253	peregi	peregi =pere  (SgG^  >pere !16_S	et	f	\N
122257	ulikooli	?ulikooli =ulikooli  (SgN  >ulikooli !16_S	et	f	\N
122258	ulikooli	?ulikooli =ulikooli  (SgG  >ulikooli !16_S	et	f	\N
122259	ulikooli	?ulikooli =ulikooli  (SgG  >ulikool !22_S	et	f	\N
122260	ulikooli	?ulikooli =ulikooli  (SgP  >ulikool !22_S	et	f	\N
122261	ulikooli	?ulikooli =ulikooli  (SgAdt  >ulikool !22_S	et	f	\N
122263	ulikooli	?ulikooli =ulikooli  (IndPrPs_  >ulikoolima !28_V	et	f	\N
122266	ulikooli	?ulikooli =ulikooli  (ImpPrSg2  >ulikoolima !28_V	et	f	\N
122268	reisinud	reisinud =reisi  (PtsPtPs  >reisima !28_V	et	f	\N
122269	reisinud	reisinud =reisinu  (PlN  >reisinu !01_S	et	f	\N
122270	reisinud	"reisinu %reisi  )NU_vS  <reisima ;28_V	et	f	\N
122271	reisinud	reisinud =reisinud  (ID  >reisinud !41_A	et	f	\N
122272	reisinud	"reisinud %reisi  )NUD_vA  <reisima ;28_V	et	f	\N
122280	sõbrid	?sõbrid =sõbri  (PlN  >sõbri !16_S	et	f	\N
122281	sõbrid	?sõbrid =sõbri  (IndPrSg2  >sõbrima !27_V	et	f	\N
122282	sõbrid	?sõbrid =sõbri  (IndPrSg2  >sõprima !28_V	et	f	\N
122313	nädalalõppis	?nädalalõppis =nädalalõppi  (IndIpfSg3  >nädalalõppima !28_V	et	f	\N
122314	nädalalõppis	?nädalalõppis =nädalalõppis  (SgN  >nädalalõppis !09_S	et	f	\N
122325	kuht	?kuht =kuht  (SgN  >kuht !22_S	et	f	\N
122348	uruguayasse	?uruguayasse =uruguaya  (SgIll  >uruguaya !26_S	et	f	\N
122349	uruguayasse	?uruguayasse =uruguayasse  (SgG  >uruguayasne !02_A	et	f	\N
122350	uruguayasse	?uruguayasse =uruguayasse  (PlP  >uruguayass !22_S	et	f	\N
122354	lapimaale	lapimaale =maa  (SgAll  >lapi+maa !26_S	et	f	\N
122355	lapimaale	lapimaale =maale  (PlP  >lapi+maal !22_S	et	f	\N
122362	venda	venda =venda  (SgP  >vend !22_S	et	f	\N
122363	venda	venda =venda  (SgAdt  >vend !22_S	et	f	\N
122364	ülikoolisse	ülikoolisse =kooli  (SgIll  >üli+kool !22_S	et	f	\N
122365	ülikoolisse	ülikoolisse =kooli  (PlIll  >üli+kool !22_S	et	f	\N
122366	joon	joon =joo  (IndPrSg1  >jooma !38_V	et	f	\N
122367	joon	joon =joon  (SgN  >joon !13_S	et	f	\N
122388	küllalt	küllalt =külla  (SgAbl  >küll !22_S	et	f	\N
122389	küllalt	küllalt =küllalt  (ID  >küllalt !41_D	et	f	\N
122436	camus	?camus =camu  (SgIn  >camu !17_S	et	f	\N
122437	camus	?camus =camu  (IndIpfSg3  >camuma !27_V	et	f	\N
122438	camus	?camus =camus  (SgN  >camus !09_S	et	f	\N
122454	jpsartre	?jpsartre =jpsartre  (SgN  >jpsartre !06_S	et	f	\N
122456	jpsartre	?jpsartre =jpsartre  (SgG  >jpsartre !06_S	et	f	\N
122458	jpsartre	?jpsartre =jpsartre  (IndPrPs_  >jpsartrema !27_V	et	f	\N
122460	jpsartre	?jpsartre =jpsartre  (ImpPrSg2  >jpsartrema !27_V	et	f	\N
122479	õiguste	õiguste =õigus  (PlG  >õigus !11~09_S	et	f	\N
122480	õiguste	"õigus %õige  )US_aS  <õige ;01_A	et	f	\N
122489	eksperemente	?eksperemente =eksperemente  (PlP  >eksperement !22_S	et	f	\N
122490	eksperemente	?eksperemente =mente  (SgN  >eks+pere+mente !06_S	et	f	\N
122491	eksperemente	?eksperemente =mente  (SgG  >eks+pere+mende !06_S	et	f	\N
122492	eksperemente	?eksperemente =mente  (PlP  >eks+pere+ment !22_S	et	f	\N
122493	eksperemente	?eksperemente =peremente  (PlP  >eks+perement !22_S	et	f	\N
122508	unistustes	unistustes =unistus  (PlIn  >unistus !11_S	et	f	\N
122509	unistustes	"unistus %unista  )US_vS  <unistama ;27_V	et	f	\N
122512	näitasid	näitasid =näita  (IndIpfSg2  >näitama !29_V	et	f	\N
122513	näitasid	näitasid =näita  (IndIpfPl3  >näitama !29_V	et	f	\N
122515	dadaistid	?dadaistid =dadaisti  (PlN  >dadaist !22_S	et	f	\N
122516	dadaistid	?dadaistid =dadaisti  (IndPrSg2  >dadaistima !28_V	et	f	\N
122524	mõted	?mõted =mõte  (IndPrSg2  >mõtema !27_V	et	f	\N
122567	maades	maades =maa  (PlIn  >maa !26_S	et	f	\N
122568	maades	maades =maade  (PlIn  >maat !22_S	et	f	\N
122571	lõpude	?lõpude =lõpu  (PlG  >lõpu !16_S	et	f	\N
122572	keeleeksperementatiivse	?keeleeksperementatiivse =keeleeksperementatiivse  (SgG  >keeleeksperementatiivne !02_A	et	f	\N
122574	keeleeksperementatiivse	?keeleeksperementatiivse =keeleeksperementatiivse  (PlP  >keeleeksperementatiivs !22_S	et	f	\N
122576	keeleeksperementatiivse	?keeleeksperementatiivse =mentatiivse  (SgG  >keele+eks+pere+mentatiivne !02_A	et	f	\N
122577	keeleeksperementatiivse	?keeleeksperementatiivse =mentatiivse  (PlP  >keele+eks+pere+mentatiivs !22_S	et	f	\N
122578	keeleeksperementatiivse	?keeleeksperementatiivse =perementatiivse  (SgG  >keele+eks+perementatiivne !02_A	et	f	\N
122579	keeleeksperementatiivse	?keeleeksperementatiivse =perementatiivse  (PlP  >keele+eks+perementatiivs !22_S	et	f	\N
122580	keeleeksperementatiivse	?keeleeksperementatiivse =eksperementatiivse  (SgG  >keele+eksperementatiivne !02_A	et	f	\N
122150	reisija	"reisija %reisi  )JA_vS  <reisima ;28_V	et	f	\N
122151	reisija	reisija =reisija  (SgG  >reisija !01_S	et	f	\N
122169	rääkime	### rääkime	et	f	\N
122192	portugali	?portugali =portugali  (ID  >portugali !41_G	et	f	\N
122193	portugali	?portugali =portugali  (SgG  >portugal !19_S	et	f	\N
122194	portugali	?portugali =portugali  (SgP  >portugal !19_S	et	f	\N
122195	portugali	?portugali =portugali  (SgAdt  >portugal !19_S	et	f	\N
122196	portugali	?portugali =ugali  (SgG  >port+ugal !02_S	et	f	\N
122197	paljuseid	paljuseid =paljuse  (PlP  >paljus !09_S	et	f	\N
122198	paljuseid	"paljus %palja  )US_aS  <paljas ;07_A	et	f	\N
122207	kivimaja	kivimaja =aja  (SgG  >kivim+aeg !22_S	et	f	\N
122208	kivimaja	kivimaja =maja  (SgN  >kivi+maja !17_S	et	f	\N
122209	kivimaja	kivimaja =maja  (SgG  >kivi+maja !17_S	et	f	\N
122210	kivimaja	kivimaja =maja  (SgP  >kivi+maja !17_S	et	f	\N
122233	tubli	tubli =tubli  (SgN  >tubli !16_A	et	f	\N
122234	tubli	tubli =tubli  (SgG  >tubli !16_A	et	f	\N
122235	seeleks	?seeleks =seele  (SgTr  >seele !06_S	et	f	\N
122236	seeleks	?seeleks =seele  (PlTr  >seel !22_S	et	f	\N
122237	seeleks	?seeleks =seele  (KndPrPs  >seelema !27_V	et	f	\N
122238	seeleks	?seeleks =leks  (SgN  >see+leks !22_S	et	f	\N
122239	mereäärnes	?mereäärnes =mereäärne  (PlIn  >mereäärn !22_S	et	f	\N
122240	mereäärnes	?mereäärnes =äärne  (PlIn  >mere+äärn !22_S	et	f	\N
122241	mereäärnes	?mereäärnes =äärnes  (SgN  >mere+äärnes !09_S	et	f	\N
122248	võimlemine	võimlemine =võimlemine  (SgN  >võimlemine !12_S	et	f	\N
122249	võimlemine	"võimlemine %võimle  )MINE_vS  <võimlema ;30_V	et	f	\N
122267	õpliopilasele	?õpliopilasele =õpliopilase  (SgAll  >õpliopilane !12_S	et	f	\N
122276	asia	?asia =asia  (SgN  >asia !01_S	et	f	\N
122278	asia	?asia =asia  (SgG  >asia !01_S	et	f	\N
122286	maakohtis	?maakohtis =maakohti  (IndIpfSg3  >maakohtima !28_V	et	f	\N
122287	maakohtis	?maakohtis =maakohtis  (SgN  >maakohtis !11_S	et	f	\N
122288	maakohtis	?maakohtis =kohtis  (SgN  >maa+kohtis !09_S	et	f	\N
122294	töötale	?töötale =tööta  (SgAll  >tööta !16_S	et	f	\N
122295	töötale	?töötale =töötale  (IndPrPs_  >töötalema !27_V	et	f	\N
122296	töötale	?töötale =töötale  (ImpPrSg2  >töötalema !27_V	et	f	\N
122297	töötale	?töötale =tale  (SgN  >töö+tale !16_S	et	f	\N
122298	töötale	?töötale =tale  (SgG  >töö+tale !16_S	et	f	\N
122356	austraaliasse	?austraaliasse =austraalia  (SgIll  >austraalia !01_S	et	f	\N
122357	austraaliasse	?austraaliasse =austraalias  (SgAdt  >austraalias !11_S	et	f	\N
122358	austraaliasse	?austraaliasse =austraaliasse  (SgG  >austraaliasne !02_A	et	f	\N
122359	austraaliasse	?austraaliasse =austraaliasse  (PlP  >austraaliass !22_S	et	f	\N
122396	münchen	?münchen =münche  (IndPrSg1  >münchema !27_V	et	f	\N
122397	münchen	?münchen =münchen  (SgN  >münchen !02_S	et	f	\N
122399	söövad	söövad =söö  (IndPrPl3  >sööma !38_V	et	f	\N
122400	söövad	söövad =sööva  (PlN  >sööv !02_A	et	f	\N
122401	söövad	"sööv %söö  )V_vA  <sööma ;38_V	et	f	\N
122402	jumalast	jumalast =jumala  (SgEl  >jumal !02_S	et	f	\N
122403	jumalast	jumalast =jumalas  (SgP  >jumalane !12_S	et	f	\N
122404	jumalast	"jumalane %jumala  )NE_aA  <jumal ;02_S	et	f	\N
122416	keematakse	?keematakse =keema  (IndPrIps  >keemama !29_V	et	f	\N
122417	keematakse	?keematakse =keematakse  (SgG  >keematakne !02_A	et	f	\N
122418	keematakse	?keematakse =keematakse  (PlP  >keemataks !22_S	et	f	\N
122425	autoritest	autoritest =autori  (PlEl  >autor !02_S	et	f	\N
122426	autoritest	autoritest =test  (SgN  >autori+test !22_S	et	f	\N
122427	loetud	loetud =loe  (PtsPtIps  >lugema !28_V	et	f	\N
122428	loetud	loetud =loetu  (PlN  >loetu !01_S	et	f	\N
122429	loetud	"loetu %loe  )TU1_vS  <lugema ;28_V	et	f	\N
122430	loetud	"loetu %loe  )TU2_kA  <lood ;22_S	et	f	\N
122431	loetud	loetud =loetud  (ID  >loetud !41_A	et	f	\N
122432	loetud	"loetud %loe  )TUD_vA  <lugema ;28_V	et	f	\N
122447	kafka	?kafka =kafka  (SgN  >kafka !16_S	et	f	\N
122448	kafka	?kafka =kafka  (SgG  >kafka !16_S	et	f	\N
122449	kafka	?kafka =kafka  (IndPrPs_  >kafkama !29_V	et	f	\N
122450	kafka	?kafka =kafka  (ImpPrSg2  >kafkama !29_V	et	f	\N
122531	dada	?dada =dada  (SgN  >dada !17_S	et	f	\N
122532	dada	?dada =dada  (SgG  >dada !17_S	et	f	\N
122533	dada	?dada =dada  (SgP  >dada !17_S	et	f	\N
122535	dada	?dada =dada  (IndPrPs_  >dadama !27_V	et	f	\N
122537	dada	?dada =dada  (ImpPrSg2  >dadama !27_V	et	f	\N
122543	nonsence	?nonsence =nonsence  (PlP  >nonsenc !22_S	et	f	\N
122550	hoddis	?hoddis =hoddi  (SgIn  >hoddi !16_S	et	f	\N
122551	hoddis	?hoddis =hoddi  (SgIn  >hodd !22_S	et	f	\N
122552	hoddis	?hoddis =hoddi  (IndIpfSg3  >hoddima !28_V	et	f	\N
122553	hoddis	?hoddis =hoddis  (SgN  >hoddis !09_S	et	f	\N
122561	ühenesid	?ühenesid =ühene  (IndIpfSg2  >ühenema !27_V	et	f	\N
122562	ühenesid	?ühenesid =ühene  (IndIpfPl3  >ühenema !27_V	et	f	\N
122563	ühenesid	?ühenesid =nesi  (PlN  >ühe+nesi !17_S	et	f	\N
122565	club	### club	et	f	\N
122569	omad	omad =oma  (PlN  >oma !17_A	et	f	\N
122570	omad	omad =oma  (IndPrSg2  >omama !27_V	et	f	\N
122185	sveitsis	?sveitsis =sveitsis  (SgN  >sveitsis !09_S	et	f	\N
122190	rahvusvahelises	rahvusvahelises =vahelise  (SgIn  >rahvus+vaheline !12_A	et	f	\N
122191	rahvusvahelises	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
122219	kirsipuud	kirsipuud =puu  (PlN  >kirsi+puu !26_S	et	f	\N
122221	kirsipuud	kirsipuud =puu  (SgP  >kirsi+puu !26_S	et	f	\N
122222	kirsipuud	kirsipuud =puud  (SgN  >kirsi+puud !22_S	et	f	\N
122275	kagu	kagu =kagu  (SgN  >kagu !17_S	et	f	\N
122277	kagu	kagu =kagu  (SgG  >kagu !17_S	et	f	\N
122279	kagu	kagu =kagu  (SgP  >kagu !17_S	et	f	\N
122299	jaamga	?jaamga =jaamga  (SgN  >jaamga !01_S	et	f	\N
122300	jaamga	?jaamga =jaamga  (SgG  >jaamga !01_S	et	f	\N
122301	jaamga	?jaamga =jaamga  (IndPrPs_  >jaamgama !29_V	et	f	\N
122302	jaamga	?jaamga =jaamga  (ImpPrSg2  >jaamgama !29_V	et	f	\N
122305	sooviks	sooviks =soovi  (SgTr  >soov !22_S	et	f	\N
122306	sooviks	sooviks =soovi  (KndPrPs  >soovima !28_V	et	f	\N
122307	sooviks	sooviks =iks  (SgN  >soov+iks !22_S	et	f	\N
122309	sooviks	sooviks =viks  (SgN  >soo+viks !22_AS	et	f	\N
122312	ostada	### ostada	et	f	\N
122319	toiduaised	?toiduaised =aise  (PlN  >toidu+aise !06_S	et	f	\N
122322	nägeks	?nägeks =näge  (SgTr  >näge !16_S	et	f	\N
122326	ütelda	ütelda =ütel  (Inf  >ütlema !30_V	et	f	\N
122327	ütelda	ütelda =ütel  (IndPrIps_  >ütlema !30_V	et	f	\N
122345	lõpetanu	lõpetanu =lõpetanu  (SgN  >lõpetanu !01_S	et	f	\N
122346	lõpetanu	"lõpetanu %lõpeta  )NU_vS  <lõpetama ;27_V	et	f	\N
122347	lõpetanu	lõpetanu =lõpetanu  (SgG  >lõpetanu !01_S	et	f	\N
122351	hiinasse	?hiinasse =hiina  (SgIll  >hiina !16_S	et	f	\N
122352	hiinasse	?hiinasse =hiinasse  (SgG  >hiinasne !02_A	et	f	\N
122353	hiinasse	?hiinasse =hiinasse  (PlP  >hiinass !22_S	et	f	\N
122360	hobusest	hobusest =hobuse  (SgEl  >hobune !10_S	et	f	\N
122361	hobusest	"hobune %hobu  )NE_aA  <hobu ;17_S	et	f	\N
122371	buksterwaagis	?buksterwaagis =buksterwaagi  (SgIn  >buksterwaagi !16_S	et	f	\N
122372	buksterwaagis	?buksterwaagis =buksterwaagi  (SgIn  >buksterwaak !22_S	et	f	\N
122373	buksterwaagis	?buksterwaagis =buksterwaagi  (IndIpfSg3  >buksterwaagima !28_V	et	f	\N
122374	buksterwaagis	?buksterwaagis =buksterwaagis  (SgN  >buksterwaagis !09_S	et	f	\N
122375	teneriifil	?teneriifil =teneriifi  (SgAd  >teneriifi !16_S	et	f	\N
122376	teneriifil	?teneriifil =teneriifi  (SgAd  >teneriif !22_S	et	f	\N
122377	teneriifil	?teneriifil =teneriifil  (SgN  >teneriifil !02_S	et	f	\N
122398	nägeda	### nägeda	et	f	\N
122406	maalle	?maalle =maalle  (SgN  >maalle !06_S	et	f	\N
122408	maalle	?maalle =maalle  (SgG  >maalle !06_S	et	f	\N
122409	maalle	?maalle =maalle  (PlP  >maall !22_S	et	f	\N
122410	maalle	?maalle =maalle  (IndPrPs_  >maallema !30_V	et	f	\N
122411	maalle	?maalle =maalle  (ImpPrSg2  >maallema !30_V	et	f	\N
122413	elutuba	elutuba =tuba  (SgN  >elu+tuba !18_S	et	f	\N
122414	elutuba	elutuba =tuba  (SgP  >elu+tuba !18_S	et	f	\N
122451	hhesse	?hhesse =hhesse  (SgN  >hhesse !06_S	et	f	\N
122452	hhesse	?hhesse =hhesse  (SgG  >hhesne !02_A	et	f	\N
122453	hhesse	?hhesse =hhesse  (SgG  >hhesse !06_S	et	f	\N
122455	hhesse	?hhesse =hhesse  (PlP  >hhess !22_S	et	f	\N
122457	hhesse	?hhesse =hhesse  (IndPrPs_  >hhessema !27_V	et	f	\N
122459	hhesse	?hhesse =hhesse  (ImpPrSg2  >hhessema !27_V	et	f	\N
122461	eksistentsialistlikule	?eksistentsialistlikule =eksistentsialistliku  (SgAll  >eksistentsialistlik !25_A	et	f	\N
122462	eksistentsialistlikule	?eksistentsialistlikule =eksistentsialistlikule  (PlP  >eksistentsialistlikul !19_S	et	f	\N
122463	eksistentsialistlikule	?eksistentsialistlikule =alistliku  (SgAll  >eksistentsi+alistlik !25_A	et	f	\N
122464	eksistentsialistlikule	?eksistentsialistlikule =alistlikule  (PlP  >eksistentsi+alistlikul !19_S	et	f	\N
122465	eksistentsialistlikule	?eksistentsialistlikule =stentsialistliku  (SgAll  >eksi+stentsialistlik !25_A	et	f	\N
122466	eksistentsialistlikule	?eksistentsialistlikule =stentsialistlikule  (PlP  >eksi+stentsialistlikul !19_S	et	f	\N
122467	eksistentsialistlikule	?eksistentsialistlikule =istentsialistliku  (SgAll  >eks+istentsialistlik !25_A	et	f	\N
122468	eksistentsialistlikule	?eksistentsialistlikule =istentsialistlikule  (PlP  >eks+istentsialistlikul !19_S	et	f	\N
122471	sisulised	sisulised =sisulise  (PlN  >sisuline !12_A	et	f	\N
122472	sisulised	"sisuline %sisu  )LINE_aA  <sisu ;17_S	et	f	\N
122481	eksperementatiivne	?eksperementatiivne =eksperementatiivne  (SgN  >eksperementatiivne !02_A	et	f	\N
122482	eksperementatiivne	?eksperementatiivne =eksperementatiivne  (PlP  >eksperementatiivn !22_S	et	f	\N
122483	eksperementatiivne	?eksperementatiivne =mentatiivne  (SgN  >eks+pere+mentatiivne !02_A	et	f	\N
122484	eksperementatiivne	?eksperementatiivne =mentatiivne  (PlP  >eks+pere+mentatiivn !22_S	et	f	\N
122485	eksperementatiivne	?eksperementatiivne =perementatiivne  (SgN  >eks+perementatiivne !02_A	et	f	\N
122486	eksperementatiivne	?eksperementatiivne =perementatiivne  (PlP  >eks+perementatiivn !22_S	et	f	\N
122487	otsimine	otsimine =otsimine  (SgN  >otsimine !12_S	et	f	\N
122488	otsimine	"otsimine %otsi  )MINE_vS  <otsima ;28_V	et	f	\N
122496	vananenud	vananenud =vanane  (PtsPtPs  >vananema !27_V	et	f	\N
122497	vananenud	vananenud =vananenu  (PlN  >vananenu !01_S	et	f	\N
122498	vananenud	"vananenu %vanane  )NU_vS  <vananema ;27_V	et	f	\N
122499	vananenud	vananenud =vananenud  (ID  >vananenud !41_A	et	f	\N
122421	vaene	vaene =vaene  (PlP  >vaen !22_S	et	f	\N
122501	uuendamist	uuendamist =uuendamis  (SgP  >uuendamine !12_S	et	f	\N
122502	uuendamist	"uuendamine %uuenda  )MINE_vS  <uuendama ;27_V	et	f	\N
122521	schvitters	?schvitters =schvitters  (SgN  >schvitters !02_S	et	f	\N
122529	tähenduseta	tähenduseta =tähenduse  (SgAb  >tähendus !11_S	et	f	\N
122530	tähenduseta	"tähendus %tähenda  )US_vS  <tähendama ;27_V	et	f	\N
122546	dadaismi	dadaismi =dadaismi  (SgG  >dadaism !22_S	et	f	\N
122547	dadaismi	dadaismi =dadaismi  (SgP  >dadaism !22_S	et	f	\N
122548	dadaismi	dadaismi =dadaismi  (SgAdt  >dadaism !22_S	et	f	\N
122554	ekspressionismi	ekspressionismi =ekspressionismi  (SgG  >ekspressionism !22_S	et	f	\N
122555	ekspressionismi	ekspressionismi =ekspressionismi  (SgP  >ekspressionism !22_S	et	f	\N
122556	ekspressionismi	ekspressionismi =ekspressionismi  (SgAdt  >ekspressionism !22_S	et	f	\N
122557	hõlmas	hõlmas =hõlma  (SgIn  >hõlm !22_S	et	f	\N
122558	hõlmas	hõlmas =hõlma  (IndIpfSg3  >hõlmama !29_V	et	f	\N
122559	maalis	maalis =maali  (SgIn  >maal !22_S	et	f	\N
122560	maalis	maalis =maali  (IndIpfSg3  >maalima !28_V	et	f	\N
122584	vool	vool =voo  (SgAd  >voog !22_S	et	f	\N
122586	vool	vool =vool  (SgN  >vool !22_S	et	f	\N
122601	breton	?breton =breton  (SgN  >breton !02_S	et	f	\N
122605	hilisemad	hilisemad =hilisema  (PlN  >hilisem !02_A	et	f	\N
122607	hilisemad	"hilisem %hilise  )M_cA  <hiline ;10_A	et	f	\N
122609	hilisemad	hilisemad =ema  (PlN  >hilis+ema !17_S	et	f	\N
122632	paradoksi	paradoksi =paradoksi  (SgG  >paradoks !22_S	et	f	\N
122634	paradoksi	paradoksi =paradoksi  (SgP  >paradoks !22_S	et	f	\N
122637	paradoksi	paradoksi =paradoksi  (SgAdt  >paradoks !22_S	et	f	\N
122645	kaota	kaota =kao  (SgAb  >kabu !18_S	et	f	\N
122646	kaota	kaota =kao  (SgAb  >kadu !18_S	et	f	\N
122647	kaota	kaota =kao  (IndPrIps_  >kaduma !28_V	et	f	\N
122648	kaota	kaota =kaota  (IndPrPs_  >kaotama !27_V	et	f	\N
122650	kaota	kaota =kaota  (ImpPrSg2  >kaotama !27_V	et	f	\N
122652	kaasaegsust	kaasaegsust =aegsus  (SgP  >kaas+aegsus !11~09_S	et	f	\N
122653	kaasaegsust	"kaas+aegsus %aegsa  )US_aS  <kaas+aegus ;02_A	et	f	\N
122654	kaasaegsust	"kaas+aegsus %aegse  )US_aS  <kaas+aegne ;02_A	et	f	\N
122678	kordumist	kordumist =kordumis  (SgP  >kordumine !12_S	et	f	\N
122679	kordumist	"kordumine %kordu  )MINE_vS  <korduma ;27_V	et	f	\N
122704	tähte	tähte =tähte  (SgP  >täht !22_S	et	f	\N
122706	tähte	tähte =tähte  (SgAdt  >täht !22_S	et	f	\N
122707	tähte	tähte =tähte  (PlP  >täht !22_S	et	f	\N
122714	quenan	?quenan =quena  (IndPrSg1  >quenama !29_V	et	f	\N
122715	quenan	?quenan =quenan  (SgN  >quenan !02_S	et	f	\N
122731	hulgas	hulgas =hulga  (SgIn  >hulk !22_S	et	f	\N
122732	hulgas	hulgas =hulgas  (ID  >hulgas !41_DK	et	f	\N
122733	mitmed	mitmed =mitme  (PlN  >mitu !05_P	et	f	\N
122734	mitmed	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
122757	analüüsis	analüüsis =analüüsi  (SgIn  >analüüs !22_S	et	f	\N
122758	analüüsis	analüüsis =analüüsi  (IndIpfSg3  >analüüsima !28_V	et	f	\N
122770	tsvetajeva	?tsvetajeva =tsvetajeva  (SgN  >tsvetajeva !16_S	et	f	\N
122771	tsvetajeva	?tsvetajeva =tsvetajeva  (SgG  >tsvetajev !02_A	et	f	\N
122772	tsvetajeva	?tsvetajeva =tsvetajeva  (SgG  >tsvetajeva !16_S	et	f	\N
122792	vananemist	vananemist =vananemis  (SgP  >vananemine !12_S	et	f	\N
122793	vananemist	"vananemine %vanane  )MINE_vS  <vananema ;27_V	et	f	\N
122805	majakovski	?majakovski =majakovski  (IndPrPs_  >majakovskima !28_V	et	f	\N
122806	majakovski	?majakovski =majakovski  (ImpPrSg2  >majakovskima !28_V	et	f	\N
122807	majakovski	?majakovski =kovski  (SgN  >maja+kovski !01_S	et	f	\N
122808	majakovski	?majakovski =kovski  (SgG  >maja+kovski !01_S	et	f	\N
122809	majakovski	?majakovski =kovski  (SgG  >maja+kovsk !22_S	et	f	\N
122810	majakovski	?majakovski =kovski  (SgP  >maja+kovsk !22_S	et	f	\N
122811	majakovski	?majakovski =kovski  (SgAdt  >maja+kovsk !22_S	et	f	\N
122812	majakovski	?majakovski =majakovs  (SgN^  >majakovs !22_S	et	f	\N
122813	majakovski	?majakovski =kovs  (SgN^  >maja+kovs !22_S	et	f	\N
122829	võrdlustega	võrdlustega =võrdlus  (PlKom  >võrdlus !11~09_S	et	f	\N
122830	võrdlustega	võrdlustega =luste  (SgKom  >võrd+luste !06_S	et	f	\N
122851	tavaliste	tavaliste =tavalis  (PlG  >tavaline !12_A	et	f	\N
122852	tavaliste	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
122867	näided	?näided =näide  (IndPrSg2  >näidema !27_V	et	f	\N
122872	tappev	tappev =tapp  (PtsPrPs  >tapma !35_V	et	f	\N
122874	tappev	tappev =tappev  (SgN  >tappev !02_A	et	f	\N
122876	tappev	"tappev %tapp  )V_vA  <tapma ;35_V	et	f	\N
122887	suhtumist	suhtumist =suhtumis  (SgP  >suhtumine !12_S	et	f	\N
122890	suhtumist	"suhtumine %suhtu  )MINE_vS  <suhtuma ;27_V	et	f	\N
122896	ainukese	ainukese =ainukese  (SgG  >ainuke !12_AS	et	f	\N
122898	ainukese	"ainuke %ainu  )KE_dS  <ainu ;16_S	et	f	\N
122901	ainukese	"ainuke %ainu  )KE_dA  <ainus ;07_AS	et	f	\N
122902	ainukese	ainukese =ainukese  (SgG  >ainukene !12_S	et	f	\N
122903	ainukese	"ainukene %ainu  )KENE_dS  <ainu ;16_S	et	f	\N
122904	ainukese	"ainukene %ainu  )KENE_dA  <ainus ;07_AS	et	f	\N
122905	hesse	?hesse =hesse  (SgN  >hesse !06_S	et	f	\N
122434	eksistentsialistlikku	?eksistentsialistlikku =eksistentsialistlikku  (SgAdt  >eksistentsialistlik !25_A	et	f	\N
122435	eksistentsialistlikku	?eksistentsialistlikku =eksistentsialistlikku  (IndPrPs_  >eksistentsialistlikkuma !27_V	et	f	\N
122439	eksistentsialistlikku	?eksistentsialistlikku =eksistentsialistlikku  (ImpPrSg2  >eksistentsialistlikkuma !27_V	et	f	\N
122440	eksistentsialistlikku	?eksistentsialistlikku =alistlikku  (SgP  >eksistentsi+alistlik !25_A	et	f	\N
122441	eksistentsialistlikku	?eksistentsialistlikku =alistlikku  (SgAdt  >eksistentsi+alistlik !25_A	et	f	\N
122442	eksistentsialistlikku	?eksistentsialistlikku =stentsialistlikku  (SgP  >eksi+stentsialistlik !25_A	et	f	\N
122443	eksistentsialistlikku	?eksistentsialistlikku =stentsialistlikku  (SgAdt  >eksi+stentsialistlik !25_A	et	f	\N
122444	eksistentsialistlikku	?eksistentsialistlikku =istentsialistlikku  (SgP  >eks+istentsialistlik !25_A	et	f	\N
122445	eksistentsialistlikku	?eksistentsialistlikku =istentsialistlikku  (SgAdt  >eks+istentsialistlik !25_A	et	f	\N
122446	f	### f	et	f	\N
122469	vormilised	vormilised =vormilise  (PlN  >vormiline !12_A	et	f	\N
122470	vormilised	"vormiline %vormi  )LINE_aA  <vorm ;22_S	et	f	\N
122473	mõjutanud	mõjutanud =mõjuta  (PtsPtPs  >mõjutama !27_V	et	f	\N
122474	mõjutanud	mõjutanud =mõjutanu  (PlN  >mõjutanu !01_S	et	f	\N
122475	mõjutanud	"mõjutanu %mõjuta  )NU_vS  <mõjutama ;27_V	et	f	\N
122476	mõjutanud	mõjutanud =mõjutanud  (ID  >mõjutanud !41_A	et	f	\N
122477	mõjutanud	"mõjutanud %mõjuta  )NUD_vA  <mõjutama ;27_V	et	f	\N
122478	mõjutanud	mõjutanud =tanu  (PlN  >mõju+tanu !17_S	et	f	\N
122494	luuletajad	luuletajad =luuletaja  (PlN  >luuletaja !01_S	et	f	\N
122495	luuletajad	"luuletaja %luuleta  )JA_vS  <luuletama ;27_V	et	f	\N
122510	eitasid	eitasid =eita  (IndIpfSg2  >eitama !27_V	et	f	\N
122511	eitasid	eitasid =eita  (IndIpfPl3  >eitama !27_V	et	f	\N
122522	irratsionaalsus	irratsionaalsus =irratsionaalsus  (SgN  >irratsionaalsus !11~09_S	et	f	\N
122523	irratsionaalsus	"irratsionaalsus %irratsionaalse  )US_aS  <irratsionaalne ;02_A	et	f	\N
122544	liitudes	liitudes =liitu  (PlIn  >liit !22_S	et	f	\N
122545	liitudes	liitudes =liitu  (Ger  >liituma !27_V	et	f	\N
122564	andsind	?andsind =andsind  (SgN  >andsind !02_S	et	f	\N
122566	sturm	?sturm =sturm  (SgN  >sturm !22_S	et	f	\N
122603	eluard	?eluard =eluard  (SgN  >eluard !22_S	et	f	\N
122604	eluard	?eluard =ard  (SgN  >elu+ard !22_S	et	f	\N
122617	dali	?dali =dali  (SgN  >dali !17_S	et	f	\N
122618	dali	?dali =dali  (SgG  >dali !17_S	et	f	\N
122619	dali	?dali =dali  (SgP  >dali !17_S	et	f	\N
122620	dali	?dali =dali  (IndPrPs_  >dalima !27_V	et	f	\N
122621	dali	?dali =dali  (ImpPrSg2  >dalima !27_V	et	f	\N
122686	unikaalsete	unikaalsete =unikaalse  (PlG  >unikaalne !02_A	et	f	\N
122687	unikaalsete	unikaalsete =sete  (SgN  >unikaal+sete !06_S	et	f	\N
122688	võtsid	võtsid =võt  (IndIpfSg2  >võtma !35_V	et	f	\N
122689	võtsid	võtsid =võt  (IndIpfPl3  >võtma !35_V	et	f	\N
122697	lipograami	?lipograami =lipograami  (SgN  >lipograami !16_S	et	f	\N
122698	lipograami	?lipograami =lipograami  (SgG  >lipograami !16_S	et	f	\N
122699	lipograami	?lipograami =lipograami  (SgG  >lipograam !22_S	et	f	\N
122700	lipograami	?lipograami =lipograami  (SgP  >lipograam !22_S	et	f	\N
122701	lipograami	?lipograami =lipograami  (SgAdt  >lipograam !22_S	et	f	\N
122702	lipograami	?lipograami =lipograami  (IndPrPs_  >lipograamima !28_V	et	f	\N
122703	lipograami	?lipograami =lipograami  (ImpPrSg2  >lipograamima !28_V	et	f	\N
122705	kasutamiseta	kasutamiseta =kasutamise  (SgAb  >kasutamine !12_S	et	f	\N
122708	kasutamiseta	"kasutamine %kasuta  )MINE_vS  <kasutama ;27_V	et	f	\N
122712	perec	### perec	et	f	\N
122720	uuenduste	uuenduste =uuendus  (PlG  >uuendus !11_S	et	f	\N
122721	uuenduste	"uuendus %uuenda  )US_vS  <uuendama ;27_V	et	f	\N
122729	luuletajaid	luuletajaid =luuletaja  (PlP  >luuletaja !01_S	et	f	\N
122730	luuletajaid	"luuletaja %luuleta  )JA_vS  <luuletama ;27_V	et	f	\N
122746	armastust	armastust =armastus  (SgP  >armastus !11_S	et	f	\N
122748	armastust	"armastus %armasta  )US_vS  <armastama ;27_V	et	f	\N
122750	looduse	looduse =looduse  (SgG  >loodus !11~09_S	et	f	\N
122751	looduse	"loodus %loo  )TUS1_aS  <looma ;38_V	et	f	\N
122755	tseliot	?tseliot =tselio  (SgP  >tselio !01_S	et	f	\N
122756	tseliot	?tseliot =tseliot  (SgN  >tseliot !22_S	et	f	\N
122759	natuuri	natuuri =natuuri  (SgG  >natuur !22_S	et	f	\N
122760	natuuri	natuuri =natuuri  (SgP  >natuur !22_S	et	f	\N
122761	natuuri	natuuri =natuuri  (SgAdt  >natuur !22_S	et	f	\N
122767	ahhmatova	?ahhmatova =ahhmatova  (SgN  >ahhmatova !16_S	et	f	\N
122768	ahhmatova	?ahhmatova =ahhmatova  (SgG  >ahhmatov !02_A	et	f	\N
122769	ahhmatova	?ahhmatova =ahhmatova  (SgG  >ahhmatova !16_S	et	f	\N
122779	metafooriline	metafooriline =metafooriline  (SgN  >metafooriline !12_A	et	f	\N
122780	metafooriline	"metafooriline %metafoori  )LINE_aA  <metafoor ;22_S	et	f	\N
122781	metafooriline	metafooriline =fooriline  (SgN  >meta+fooriline !12_A	et	f	\N
122782	metafooriline	"meta+fooriline %foori  )LINE_aA  <meta+foor ;22_S	et	f	\N
122786	luuge	?luuge =luuge  (SgN  >luuge !06_S	et	f	\N
122787	luuge	?luuge =luuge  (PlP  >luug !22_S	et	f	\N
122788	luuge	?luuge =luuge  (IndPrPs_  >luugema !27_V	et	f	\N
122789	luuge	?luuge =luuge  (ImpPrSg2  >luugema !27_V	et	f	\N
122500	vananenud	"vananenud %vanane  )NUD_vA  <vananema ;27_V	et	f	\N
122503	mänginud	mänginud =mängi  (PtsPtPs  >mängima !28_V	et	f	\N
122504	mänginud	mänginud =mänginu  (PlN  >mänginu !01_S	et	f	\N
122505	mänginud	"mänginu %mängi  )NU_vS  <mängima ;28_V	et	f	\N
122506	mänginud	mänginud =mänginud  (ID  >mänginud !41_A	et	f	\N
122507	mänginud	"mänginud %mängi  )NUD_vA  <mängima ;28_V	et	f	\N
122514	protesti	protesti =protesti  (SgG  >protest !22_S	et	f	\N
122517	protesti	protesti =protesti  (SgP  >protest !22_S	et	f	\N
122518	protesti	protesti =protesti  (SgAdt  >protest !22_S	et	f	\N
122519	protesti	protesti =protesti  (IndPrPs_  >protestima !28_V	et	f	\N
122520	protesti	protesti =protesti  (ImpPrSg2  >protestima !28_V	et	f	\N
122525	esitasid	esitasid =esita  (IndIpfSg2  >esitama !27_V	et	f	\N
122526	esitasid	esitasid =esita  (IndIpfPl3  >esitama !27_V	et	f	\N
122527	voola	voola =voola  (IndPrPs_  >voolama !29_V	et	f	\N
122528	voola	voola =voola  (ImpPrSg2  >voolama !29_V	et	f	\N
122534	lällutust	lällutust =lällutus  (SgP  >lällutus !11_S	et	f	\N
122536	lällutust	"lällutus %lälluta  )US_vS  <lällutama ;27_V	et	f	\N
122538	mõttetust	mõttetust =mõttetu  (SgEl  >mõttetu !01_A	et	f	\N
122539	mõttetust	"mõttetu %mõtte  )TU2_kA  <mõte ;06_S	et	f	\N
122540	mõttetust	mõttetust =mõttetus  (SgP  >mõttetus !11_S	et	f	\N
122541	mõttetust	"mõttetus %mõtte  )TUS2_aS  <mõte ;06_S	et	f	\N
122542	mõttetust	mõttetust =tust  (SgN  >mõtte+tust !22_S	et	f	\N
122549	benn	?benn =benn  (SgN  >benn !22_S	et	f	\N
122598	filmikunsti	filmikunsti =kunsti  (SgG  >filmi+kunst !22_S	et	f	\N
122599	filmikunsti	filmikunsti =kunsti  (SgP  >filmi+kunst !22_S	et	f	\N
122600	filmikunsti	filmikunsti =kunsti  (SgAdt  >filmi+kunst !22_S	et	f	\N
122606	schwittersi	?schwittersi =schwittersi  (SgN  >schwittersi !01_S	et	f	\N
122608	schwittersi	?schwittersi =schwittersi  (SgG  >schwittersi !01_S	et	f	\N
122610	schwittersi	?schwittersi =schwittersi  (SgG  >schwitters !02_S	et	f	\N
122611	schwittersi	?schwittersi =schwittersi  (SgG  >schwitterss !22_S	et	f	\N
122612	schwittersi	?schwittersi =schwittersi  (IndPrPs_  >schwitterssima !28_V	et	f	\N
122613	schwittersi	?schwittersi =schwittersi  (ImpPrSg2  >schwitterssima !28_V	et	f	\N
122636	kombineerisid	kombineerisid =kombineeri  (IndIpfSg2  >kombineerima !28_V	et	f	\N
122638	kombineerisid	kombineerisid =kombineeri  (IndIpfPl3  >kombineerima !28_V	et	f	\N
122656	konkretism	?konkretism =konkretism  (SgN  >konkretism !22_S	et	f	\N
122658	konkretistid	?konkretistid =konkretisti  (PlN  >konkretist !22_S	et	f	\N
122660	konkretistid	?konkretistid =konkretisti  (IndPrSg2  >konkretistima !28_V	et	f	\N
122670	eksperementeerisid	?eksperementeerisid =eksperementeeri  (PlP  >eksperementeeri !16_S	et	f	\N
122671	eksperementeerisid	?eksperementeerisid =eksperementeeri  (PlP  >eksperementeer !22_S	et	f	\N
122672	eksperementeerisid	?eksperementeerisid =eksperementeeri  (IndIpfSg2  >eksperementeerima !28_V	et	f	\N
122673	eksperementeerisid	?eksperementeerisid =eksperementeeri  (IndIpfPl3  >eksperementeerima !28_V	et	f	\N
122674	eksperementeerisid	?eksperementeerisid =menteeri  (PlP  >eks+pere+menteeri !16_S	et	f	\N
122675	eksperementeerisid	?eksperementeerisid =menteeri  (PlP  >eks+pere+menteer !22_S	et	f	\N
122676	eksperementeerisid	?eksperementeerisid =perementeeri  (PlP  >eks+perementeeri !16_S	et	f	\N
122677	eksperementeerisid	?eksperementeerisid =perementeeri  (PlP  >eks+perementeer !22_S	et	f	\N
122695	terved	terved =terve  (PlN  >terve !01_AS	et	f	\N
122696	terved	terved =terve  (PlN  >terve !06_AS	et	f	\N
122722	püüdlemine	püüdlemine =püüdlemine  (SgN  >püüdlemine !12_S	et	f	\N
122723	püüdlemine	"püüdlemine %püüdle  )MINE_vS  <püüdlema ;30_V	et	f	\N
122752	luuletaja	luuletaja =luuletaja  (SgN  >luuletaja !01_S	et	f	\N
122753	luuletaja	"luuletaja %luuleta  )JA_vS  <luuletama ;27_V	et	f	\N
122754	luuletaja	luuletaja =luuletaja  (SgG  >luuletaja !01_S	et	f	\N
122762	mahukaid	mahukaid =mahuka  (PlP  >mahukas !02_A	et	f	\N
122763	mahukaid	mahukaid =kai  (PlN  >mahu+kai !26_S	et	f	\N
122764	mahukaid	mahukaid =kai  (SgP  >mahu+kai !26_S	et	f	\N
122797	neruda	?neruda =neru  (Inf  >neruma !27_V	et	f	\N
122804	vladimir	?vladimir =vladimir  (SgN  >vladimir !19_S	et	f	\N
122816	rikkaid	?rikkaid =rikka  (PlP  >rikas !07_A	et	f	\N
122817	rikkaid	?rikkaid =rikkai  (PlN  >rikkai !26_S	et	f	\N
122818	rikkaid	?rikkaid =rikkai  (SgP  >rikkai !26_S	et	f	\N
122819	rikkaid	?rikkaid =rikkaid  (SgN  >rikkaid !22_S	et	f	\N
122831	sõjakas	sõjakas =sõjaka  (SgIn  >sõjakas !02_A	et	f	\N
122832	sõjakas	sõjakas =sõjakas  (SgN  >sõjakas !02_A	et	f	\N
122845	monstr	?monstr =monstr  (SgN  >monstr !22_S	et	f	\N
122846	loodud	loodud =loo  (PtsPtIps  >looma !38_V	et	f	\N
122847	loodud	loodud =loodu  (PlN  >loodu !01_S	et	f	\N
122848	loodud	"loodu %loo  )TU1_vS  <looma ;38_V	et	f	\N
122849	loodud	loodud =loodud  (ID  >loodud !41_A	et	f	\N
122850	loodud	"loodud %loo  )TUD_vA  <looma ;38_V	et	f	\N
122882	ebanormaalsetes	ebanormaalsetes =sete  (PlIn  >eba+normaal+sett !22_S	et	f	\N
122884	ebanormaalsetes	ebanormaalsetes =normaalse  (PlIn  >eba+normaalne !02_A	et	f	\N
122885	esindajate	esindajate =esindaja  (PlG  >esindaja !01_S	et	f	\N
122886	esindajate	"esindaja %esinda  )JA_vS  <esindama ;27_V	et	f	\N
122573	suunast	suunast =suuna  (SgEl  >suund !22_S	et	f	\N
122575	suunast	suunast =suunas  (SgP  >suunane !10_A	et	f	\N
122585	suunast	"suunane %suuna  )NE_aA  <suund ;22_S	et	f	\N
122587	suunast	suunast =suunast  (ID  >suunast !41_K	et	f	\N
122590	kunstiliike	kunstiliike =liike  (SgN  >kunsti+liike !12?10_S	et	f	\N
122591	kunstiliike	"kunsti+liike %lii  )KE_dS  <kunsti+lii ;26_S	et	f	\N
122592	kunstiliike	kunstiliike =liike  (PlP  >kunsti+liik !22_S	et	f	\N
122622	dlynchi	?dlynchi =dlynchi  (SgN  >dlynchi !01_S	et	f	\N
122623	dlynchi	?dlynchi =dlynchi  (SgG  >dlynchi !01_S	et	f	\N
122624	dlynchi	?dlynchi =dlynchi  (SgG  >dlynch !22_S	et	f	\N
122625	dlynchi	?dlynchi =dlynchi  (SgP  >dlynch !22_S	et	f	\N
122626	dlynchi	?dlynchi =dlynchi  (SgAdt  >dlynch !22_S	et	f	\N
122627	dlynchi	?dlynchi =dlynchi  (IndPrPs_  >dlynchima !28_V	et	f	\N
122628	dlynchi	?dlynchi =dlynchi  (ImpPrSg2  >dlynchima !28_V	et	f	\N
122631	absurdi	absurdi =absurdi  (SgG  >absurd !22_S	et	f	\N
122633	absurdi	absurdi =absurdi  (SgP  >absurd !22_S	et	f	\N
122635	absurdi	absurdi =absurdi  (SgAdt  >absurd !22_S	et	f	\N
122639	reaalsusi	reaalsusi =reaalsusi  (PlP  >reaalsus !11_S	et	f	\N
122640	reaalsusi	"reaalsus %reaalse  )US_aS  <reaalne ;02_A	et	f	\N
122641	reaalsusi	reaalsusi =susi  (SgN  >reaal+susi !15_S	et	f	\N
122642	reaalsusi	reaalsusi =susi  (PlP  >reaal+susi !15_S	et	f	\N
122643	hallunatsioon	?hallunatsioon =hallunatsioon  (SgN  >hallunatsioon !22_S	et	f	\N
122644	hallunatsioon	?hallunatsioon =unatsioon  (SgN  >hall+unatsioon !22_S	et	f	\N
122669	artmann	?artmann =artmann  (SgN  >artmann !22_S	et	f	\N
122716	inimkonna	inimkonna =inimkonna  (SgG  >inimkond !22_S	et	f	\N
122717	inimkonna	inimkonna =konna  (SgG  >inim+konn !22_S	et	f	\N
122718	inimkonna	inimkonna =konna  (SgP  >inim+konn !22_S	et	f	\N
122719	inimkonna	inimkonna =konna  (SgAdt  >inim+konn !22_S	et	f	\N
122724	urbaniseerutud	urbaniseerutud =urbaniseeru  (PtsPtIps  >urbaniseeruma !27_V	et	f	\N
122725	urbaniseerutud	urbaniseerutud =urbaniseerutu  (PlN  >urbaniseerutu !01_A	et	f	\N
122726	urbaniseerutud	"urbaniseerutu %urbaniseeru  )TU1_vS  <urbaniseeruma ;27_V	et	f	\N
122727	urbaniseerutud	urbaniseerutud =urbaniseerutud  (ID  >urbaniseerutud !41_A	et	f	\N
122728	urbaniseerutud	"urbaniseerutud %urbaniseeru  )TUD_vA  <urbaniseeruma ;27_V	et	f	\N
122735	austria	?austria =austria  (SgN  >austria !01_S	et	f	\N
122736	austria	?austria =austria  (SgG  >austria !01_S	et	f	\N
122739	rilket	?rilket =rilke  (SgP  >rilke !06_S	et	f	\N
122773	noorusest	noorusest =nooruse  (SgEl  >noorus !11~09_S	et	f	\N
122774	noorusest	"noorus %noor  )US_aS  <noor ;13_AS	et	f	\N
122775	noorusest	noorusest =nooruses  (SgP  >noorusene !12_A	et	f	\N
122776	noorusest	"noorusene %nooruse  )NE_aA  <noorus ;09_S	et	f	\N
122777	noorusest	"noorusene %nooruse  )NE_aA  <noorus ;11_S	et	f	\N
122778	noorusest	noorusest =use  (PlEl  >noor+usk !22_S	et	f	\N
122794	bbrecht	?bbrecht =bbrecht  (SgN  >bbrecht !22_S	et	f	\N
122795	pablo	?pablo =pablo  (SgN  >pablo !16_S	et	f	\N
122796	pablo	?pablo =pablo  (SgG  >pablo !16_S	et	f	\N
122814	omapärase	omapärase =pärase  (SgG  >oma+pärane !10_A	et	f	\N
122815	omapärase	"oma+pärane %pära  )NE_aA  <oma+pära ;17_S	et	f	\N
122820	löövad	löövad =löö  (IndPrPl3  >lööma !38_V	et	f	\N
122822	löövad	löövad =lööva  (PlN  >lööv !02_A	et	f	\N
122824	löövad	"lööv %löö  )V_vA  <lööma ;38_V	et	f	\N
122826	võimatute	võimatute =võimatu  (PlG  >võimatu !01_A	et	f	\N
122828	võimatute	"võimatu %või  )MATU_vA  <võima ;37_V	et	f	\N
122868	eksistentsialistlikust	?eksistentsialistlikust =eksistentsialistliku  (SgEl  >eksistentsialistlik !25_A	et	f	\N
122869	eksistentsialistlikust	?eksistentsialistlikust =eksistentsialistlikus  (SgP  >eksistentsialistlikus !11?09_S	et	f	\N
122870	eksistentsialistlikust	?eksistentsialistlikust =alistliku  (SgEl  >eksistentsi+alistlik !25_A	et	f	\N
122871	eksistentsialistlikust	?eksistentsialistlikust =alistlikus  (SgP  >eksistentsi+alistlikus !11?09_S	et	f	\N
122873	eksistentsialistlikust	?eksistentsialistlikust =stentsialistliku  (SgEl  >eksi+stentsialistlik !25_A	et	f	\N
122875	eksistentsialistlikust	?eksistentsialistlikust =stentsialistlikus  (SgP  >eksi+stentsialistlikus !11?09_S	et	f	\N
122877	eksistentsialistlikust	?eksistentsialistlikust =istentsialistliku  (SgEl  >eks+istentsialistlik !25_A	et	f	\N
122879	eksistentsialistlikust	?eksistentsialistlikust =istentsialistlikus  (SgP  >eks+istentsialistlikus !11?09_S	et	f	\N
122881	käitumine	käitumine =käitumine  (SgN  >käitumine !12_S	et	f	\N
122883	käitumine	"käitumine %käitu  )MINE_vS  <käituma ;27_V	et	f	\N
122918	ühtlasi	ühtlasi =ühtlasi  (ID  >ühtlasi !41_D	et	f	\N
122919	ühtlasi	ühtlasi =ühtlasi  (PlP  >ühtlane !12_A	et	f	\N
122923	kogenud	kogenud =koge  (PtsPtPs  >kogema !27_V	et	f	\N
122924	kogenud	kogenud =kogenu  (PlN  >kogenu !01_S	et	f	\N
122925	kogenud	"kogenu %koge  )NU_vS  <kogema ;27_V	et	f	\N
122926	kogenud	kogenud =kogenud  (ID  >kogenud !41_A	et	f	\N
122927	kogenud	"kogenud %koge  )NUD_vA  <kogema ;27_V	et	f	\N
122958	post-modernismi	post-modernismi =modernismi  (SgG  >post-modernism !22_S	et	f	\N
122959	post-modernismi	post-modernismi =modernismi  (SgP  >post-modernism !22_S	et	f	\N
122960	post-modernismi	post-modernismi =modernismi  (SgAdt  >post-modernism !22_S	et	f	\N
122581	keeleeksperementatiivse	?keeleeksperementatiivse =eksperementatiivse  (PlP  >keele+eksperementatiivs !22_S	et	f	\N
122582	keeleeksperementatiivse	?keeleeksperementatiivse =eeksperementatiivse  (SgG  >keel+eeksperementatiivne !02_A	et	f	\N
122583	keeleeksperementatiivse	?keeleeksperementatiivse =eeksperementatiivse  (PlP  >keel+eeksperementatiivs !22_S	et	f	\N
122588	mitmeid	mitmeid =mitme  (PlP  >mitu !05_P	et	f	\N
122589	mitmeid	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
122593	maali	maali =maali  (SgG  >maal !22_S	et	f	\N
122594	maali	maali =maali  (SgP  >maal !22_S	et	f	\N
122595	maali	maali =maali  (SgAdt  >maal !22_S	et	f	\N
122596	maali	maali =maali  (IndPrPs_  >maalima !28_V	et	f	\N
122597	maali	maali =maali  (ImpPrSg2  >maalima !28_V	et	f	\N
122602	aragon	?aragon =aragon  (SgN  >aragon !19_S	et	f	\N
122614	rääkimata	rääkimata =rääki  (SupAb  >rääkima !28_V	et	f	\N
122615	rääkimata	rääkimata =rääkimata  (ID  >rääkimata !41_D	et	f	\N
122616	rääkimata	"rääkimata %rääki  )MATA_vA  <rääkima ;28_V	et	f	\N
122629	uuendust	uuendust =uuendus  (SgP  >uuendus !11_S	et	f	\N
122630	uuendust	"uuendus %uuenda  )US_vS  <uuendama ;27_V	et	f	\N
122649	omapärasust	omapärasust =pärasus  (SgP  >oma+pärasus !11_S	et	f	\N
122651	omapärasust	"oma+pärasus %pära  )SUS_aS  <oma+pära ;17_S	et	f	\N
122655	keeleeksperementatiivne	?keeleeksperementatiivne =keeleeksperementatiivne  (SgN  >keeleeksperementatiivne !02_A	et	f	\N
122657	keeleeksperementatiivne	?keeleeksperementatiivne =keeleeksperementatiivne  (PlP  >keeleeksperementatiivn !22_S	et	f	\N
122659	keeleeksperementatiivne	?keeleeksperementatiivne =mentatiivne  (SgN  >keele+eks+pere+mentatiivne !02_A	et	f	\N
122661	keeleeksperementatiivne	?keeleeksperementatiivne =mentatiivne  (PlP  >keele+eks+pere+mentatiivn !22_S	et	f	\N
122662	keeleeksperementatiivne	?keeleeksperementatiivne =perementatiivne  (SgN  >keele+eks+perementatiivne !02_A	et	f	\N
122663	keeleeksperementatiivne	?keeleeksperementatiivne =perementatiivne  (PlP  >keele+eks+perementatiivn !22_S	et	f	\N
122664	keeleeksperementatiivne	?keeleeksperementatiivne =eksperementatiivne  (SgN  >keele+eksperementatiivne !02_A	et	f	\N
122665	keeleeksperementatiivne	?keeleeksperementatiivne =eksperementatiivne  (PlP  >keele+eksperementatiivn !22_S	et	f	\N
122666	keeleeksperementatiivne	?keeleeksperementatiivne =eeksperementatiivne  (SgN  >keel+eeksperementatiivne !02_A	et	f	\N
122667	keeleeksperementatiivne	?keeleeksperementatiivne =eeksperementatiivne  (PlP  >keel+eeksperementatiivn !22_S	et	f	\N
122668	anclister	?anclister =anclister  (SgN  >anclister !02_S	et	f	\N
122680	lõid	lõid =lõ  (IndIpfSg2  >looma !38_V	et	f	\N
122681	lõid	lõid =lõ  (IndIpfSg2  >lööma !38_V	et	f	\N
122682	lõid	lõid =lõ  (IndIpfPl3  >looma !38_V	et	f	\N
122683	lõid	lõid =lõ  (IndIpfPl3  >lööma !38_V	et	f	\N
122684	oulipo	?oulipo =oulipo  (SgN  >oulipo !16_S	et	f	\N
122685	oulipo	?oulipo =oulipo  (SgG  >oulipo !16_S	et	f	\N
122690	järgnev	järgnev =järgne  (PtsPrPs  >järgnema !27_V	et	f	\N
122691	järgnev	järgnev =järgnev  (SgN  >järgnev !02_A	et	f	\N
122692	järgnev	"järgnev %järgne  )V_vA  <järgnema ;27_V	et	f	\N
122693	sõnaraamatust	sõnaraamatust =atu  (SgEl  >sõna+raam+att !22_S	et	f	\N
122694	sõnaraamatust	sõnaraamatust =raamatu  (SgEl  >sõna+raamat !02_S	et	f	\N
122709	georges	?georges =george  (PlIn  >geork !22_S	et	f	\N
122710	georges	?georges =george  (IndIpfSg3  >georgema !27_V	et	f	\N
122711	georges	?georges =georges  (SgN  >georges !09_S	et	f	\N
122713	raymond	?raymond =raymond  (SgN  >raymond !22_S	et	f	\N
122737	luuletajat	luuletajat =luuletaja  (SgP  >luuletaja !01_S	et	f	\N
122738	luuletajat	"luuletaja %luuleta  )JA_vS  <luuletama ;27_V	et	f	\N
122740	lugeja	lugeja =lugeja  (SgN  >lugeja !01_S	et	f	\N
122741	lugeja	"lugeja %luge  )JA_vS  <lugema ;28_V	et	f	\N
122742	lugeja	lugeja =lugeja  (SgG  >lugeja !01_S	et	f	\N
122743	rilke	?rilke =rilke  (SgN  >rilke !06_S	et	f	\N
122744	rilke	?rilke =rilke  (SgG  >rilge !06_S	et	f	\N
122745	rilke	?rilke =rilke  (PlP  >rilk !22_S	et	f	\N
122747	rilke	?rilke =rilke  (IndPrPs_  >rilkema !27_V	et	f	\N
122749	rilke	?rilke =rilke  (ImpPrSg2  >rilkema !27_V	et	f	\N
122765	nobeli	?nobeli =nobeli  (ID  >nobeli !41_D	et	f	\N
122766	nobeli	?nobeli =nobeli  (SgG  >nobel !02_S	et	f	\N
122783	üksindusest	üksindusest =üksinduse  (SgEl  >üksindus !11_S	et	f	\N
122784	üksindusest	üksindusest =üksinduses  (SgP  >üksindusene !12_A	et	f	\N
122785	üksindusest	"üksindusene %üksinduse  )NE_aA  <üksindus ;11_S	et	f	\N
122790	hingele	hingele =hinge  (SgAll  >hing !22_S	et	f	\N
122791	hingele	hingele =hinge  (PlAll  >hink !22_S	et	f	\N
122834	sisemaailma	sisemaailma =ilma  (SgG  >sise+maa+ilm !22_S	et	f	\N
122835	sisemaailma	sisemaailma =ilma  (SgP  >sise+maa+ilm !22_S	et	f	\N
122836	sisemaailma	sisemaailma =ilma  (SgAdt  >sise+maa+ilm !22_S	et	f	\N
122837	kirjeldamine	kirjeldamine =kirjeldamine  (SgN  >kirjeldamine !12_S	et	f	\N
122838	kirjeldamine	"kirjeldamine %kirjelda  )MINE_vS  <kirjeldama ;27_V	et	f	\N
122839	degradeerimine	degradeerimine =degradeerimine  (SgN  >degradeerimine !12_S	et	f	\N
122840	degradeerimine	"degradeerimine %degradeeri  )MINE_vS  <degradeerima ;28_V	et	f	\N
122841	muutumine	muutumine =muutumine  (SgN  >muutumine !12_S	et	f	\N
122842	muutumine	"muutumine %muutu  )MINE_vS  <muutuma ;27_V	et	f	\N
122853	loogiline	loogiline =loogiline  (SgN  >loogiline !12_A	et	f	\N
122798	sotsialismi	sotsialismi =sotsialismi  (SgG  >sotsialism !22_S	et	f	\N
122799	sotsialismi	sotsialismi =sotsialismi  (SgP  >sotsialism !22_S	et	f	\N
122800	sotsialismi	sotsialismi =sotsialismi  (SgAdt  >sotsialism !22_S	et	f	\N
122801	kommunismi	kommunismi =kommunismi  (SgG  >kommunism !22_S	et	f	\N
122802	kommunismi	kommunismi =kommunismi  (SgP  >kommunism !22_S	et	f	\N
122803	kommunismi	kommunismi =kommunismi  (SgAdt  >kommunism !22_S	et	f	\N
122821	lugejat	lugejat =lugeja  (SgP  >lugeja !01_S	et	f	\N
122823	lugejat	"lugeja %luge  )JA_vS  <lugema ;28_V	et	f	\N
122825	metafooridega	metafooridega =metafoori  (PlKom  >metafoor !22_S	et	f	\N
122827	metafooridega	metafooridega =foori  (PlKom  >meta+foor !22_S	et	f	\N
122833	enetapmine	?enetapmine =enetapmine  (SgN  >enetapmine !12_A	et	f	\N
122843	karm	karm =karm  (SgN  >karm !22_S	et	f	\N
122844	karm	karm =karm  (SgN  >karm !22_A	et	f	\N
122855	toimi	toimi =toimi  (SgG  >toim !22_S	et	f	\N
122856	toimi	toimi =toimi  (SgP  >toim !22_S	et	f	\N
122857	toimi	toimi =toimi  (SgAdt  >toim !22_S	et	f	\N
122858	toimi	toimi =toimi  (PlP  >toim !22_S	et	f	\N
122859	toimi	toimi =toimi  (IndPrPs_  >toimima !28_V	et	f	\N
122860	toimi	toimi =toimi  (ImpPrSg2  >toimima !28_V	et	f	\N
122888	seadusse	seadusse =seadu  (SgIll  >sead !22_S	et	f	\N
122889	seadusse	seadusse =seadus  (SgAdt  >seadus !11_S	et	f	\N
122891	vabaduse	vabaduse =vabaduse  (SgG  >vabadus !11_S	et	f	\N
122892	vabaduse	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
122897	toitja	toitja =toitja  (SgN  >toitja !01_S	et	f	\N
122899	toitja	"toitja %toit  )JA_vS  <toitma ;34_V	et	f	\N
122900	toitja	toitja =toitja  (SgG  >toitja !01_S	et	f	\N
122928	kaugelseisavast	?kaugelseisavast =kaugelseisava  (SgEl  >kaugelseisav !02_A	et	f	\N
122929	kaugelseisavast	?kaugelseisavast =kaugelseisava  (SgEl  >kaugelseisava !16_S	et	f	\N
122930	kaugelseisavast	?kaugelseisavast =kaugelseisavas  (SgP  >kaugelseisavane !12_A	et	f	\N
122931	kaugelseisavast	?kaugelseisavast =seisava  (SgEl  >kaugel+seisava !01_S	et	f	\N
122932	kaugelseisavast	?kaugelseisavast =seisava  (SgEl  >kaugel+seisav !02_A	et	f	\N
122933	kaugelseisavast	?kaugelseisavast =seisavas  (SgP  >kaugel+seisavane !12_A	et	f	\N
122934	kaugelseisavast	?kaugelseisavast =elseisava  (SgEl  >kaug+elseisav !02_A	et	f	\N
122935	kaugelseisavast	?kaugelseisavast =elseisava  (SgEl  >kaug+elseisava !16_S	et	f	\N
122936	kaugelseisavast	?kaugelseisavast =elseisavas  (SgP  >kaug+elseisavane !12_A	et	f	\N
122946	kritiseerivaid	kritiseerivaid =kritiseeriva  (PlP  >kritiseeriv !02_A	et	f	\N
122947	kritiseerivaid	"kritiseeriv %kritiseeri  )V_vA  <kritiseerima ;28_V	et	f	\N
122948	psühholoogia	psühholoogia =psühholoogia  (SgN  >psühholoogia !01_S	et	f	\N
122949	psühholoogia	psühholoogia =psühholoogia  (SgG  >psühholoogia !01_S	et	f	\N
122980	paremani	paremani =parema  (SgTer  >parem !02_A	et	f	\N
122981	paremani	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
122991	romaani	romaani =romaani  (ID  >romaani !41_G	et	f	\N
122992	romaani	romaani =romaani  (SgG  >romaan !22_S	et	f	\N
122993	romaani	romaani =romaani  (SgP  >romaan !22_S	et	f	\N
122994	romaani	romaani =romaani  (SgAdt  >romaan !22_S	et	f	\N
123001	mõistujuttu	mõistujuttu =juttu  (SgP  >mõistu+jutt !22_S	et	f	\N
123003	mõistujuttu	mõistujuttu =juttu  (SgAdt  >mõistu+jutt !22_S	et	f	\N
123014	k	### k	et	f	\N
123015	protagonist	?protagonist =protagoni  (SgEl  >protagon !19_S	et	f	\N
123016	protagonist	?protagonist =protagonis  (SgP  >protagonis !09_S	et	f	\N
123017	protagonist	?protagonist =protagonist  (SgN  >protagonist !22_S	et	f	\N
123038	tavainimese	tavainimese =ese  (SgN  >tava+inim+ese !04_S	et	f	\N
123040	tavainimese	tavainimese =inimese  (SgG  >tava+inimene !12_S	et	f	\N
123072	valest	valest =vale  (SgEl  >vale !16_SA	et	f	\N
123073	valest	valest =vales  (SgP  >valene !10_A	et	f	\N
123074	valest	"valene %vale  )NE_aA  <vale ;16_SA	et	f	\N
123084	las	las =la  (SgIn  >la !26_S	et	f	\N
123085	las	las =las  (ID  >las !41_D	et	f	\N
123086	keela	keela =keela  (IndPrPs_  >keelama !29_V	et	f	\N
123087	keela	keela =keela  (ImpPrSg2  >keelama !29_V	et	f	\N
123091	proovi	proovi =proovi  (SgG  >proov !22_S	et	f	\N
123092	proovi	proovi =proovi  (SgP  >proov !22_S	et	f	\N
123093	proovi	proovi =proovi  (SgAdt  >proov !22_S	et	f	\N
123094	proovi	proovi =proovi  (IndPrPs_  >proovima !28_V	et	f	\N
123096	proovi	proovi =proovi  (ImpPrSg2  >proovima !28_V	et	f	\N
123108	püstitanud	püstitanud =püstita  (PtsPtPs  >püstitama !27_V	et	f	\N
123109	püstitanud	püstitanud =püstitanu  (PlN  >püstitanu !01_S	et	f	\N
123110	püstitanud	"püstitanu %püstita  )NU_vS  <püstitama ;27_V	et	f	\N
123111	püstitanud	püstitanud =püstitanud  (ID  >püstitanud !41_A	et	f	\N
123112	püstitanud	"püstitanud %püstita  )NUD_vA  <püstitama ;27_V	et	f	\N
123113	püstitanud	püstitanud =tanu  (PlN  >püsti+tanu !17_S	et	f	\N
123123	koosne	koosne =koosne  (IndPrPs_  >koosnema !27_V	et	f	\N
123127	koosne	koosne =koosne  (ImpPrSg2  >koosnema !27_V	et	f	\N
123130	õpetusest	õpetusest =õpetuse  (SgEl  >õpetus !11_S	et	f	\N
123131	õpetusest	"õpetus %õpeta  )US_vS  <õpetama ;27_V	et	f	\N
123132	õpetusest	õpetusest =õpetuses  (SgP  >õpetusene !12_A	et	f	\N
122854	loogiline	"loogiline %loogi  )LINE_aA  <loog ;22_S	et	f	\N
122861	omaste	omaste =omas  (PlG  >omas !09_S	et	f	\N
122862	omaste	omaste =omas  (PlG  >omane !10_A	et	f	\N
122863	fkafka	?fkafka =fkafka  (SgN  >fkafka !16_S	et	f	\N
122864	fkafka	?fkafka =fkafka  (SgG  >fkafka !16_S	et	f	\N
122865	fkafka	?fkafka =fkafka  (IndPrPs_  >fkafkama !29_V	et	f	\N
122866	fkafka	?fkafka =fkafka  (ImpPrSg2  >fkafkama !29_V	et	f	\N
122878	emotsionaalsus	emotsionaalsus =emotsionaalsus  (SgN  >emotsionaalsus !11~09_S	et	f	\N
122880	emotsionaalsus	"emotsionaalsus %emotsionaalse  )US_aS  <emotsionaalne ;02_A	et	f	\N
122916	erinevatele	erinevatele =erineva  (PlAll  >erinev !02_A	et	f	\N
122917	erinevatele	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
122940	hirmu	hirmu =hirmu  (SgG  >hirm !22_S	et	f	\N
122941	hirmu	hirmu =hirmu  (SgP  >hirm !22_S	et	f	\N
122942	hirmu	hirmu =hirmu  (SgAdt  >hirm !22_S	et	f	\N
122943	hirmu	hirmu =hirmu  (IndPrPs_  >hirmuma !27_V	et	f	\N
122944	hirmu	hirmu =hirmu  (ImpPrSg2  >hirmuma !27_V	et	f	\N
122950	ajavoolu	ajavoolu =voolu  (SgG  >aja+vool !22_S	et	f	\N
122951	ajavoolu	ajavoolu =voolu  (SgP  >aja+vool !22_S	et	f	\N
122952	ajavoolu	ajavoolu =voolu  (SgAdt  >aja+vool !22_S	et	f	\N
122969	reaalsusele	reaalsusele =reaalsuse  (SgAll  >reaalsus !11~09_S	et	f	\N
122970	reaalsusele	"reaalsus %reaalse  )US_aS  <reaalne ;02_A	et	f	\N
122978	tajumist	tajumist =tajumis  (SgP  >tajumine !12_S	et	f	\N
122979	tajumist	"tajumine %taju  )MINE_vS  <tajuma ;27_V	et	f	\N
122997	lühikest	lühikest =lühikes  (SgP  >lühike !12_A	et	f	\N
122998	lühikest	"lühike %lühi  )KE_dS  <lüht ;22_S	et	f	\N
122999	lühikest	lühikest =lühikes  (SgP  >lühikene !12_S	et	f	\N
123000	lühikest	"lühikene %lühi  )KENE_dS  <lüht ;22_S	et	f	\N
123002	lühikest	lühikest =kest  (SgN  >lühi+kest !22_S	et	f	\N
123013	josef	?josef =josef  (SgN  >josef !02_S	et	f	\N
123033	lase	lase =lase  (SgN  >lase !05_S	et	f	\N
123034	lase	lase =lase  (SgN  >lase !06_S	et	f	\N
123035	lase	lase =lase  (IndPrPs_  >laskma !34_V	et	f	\N
123036	lase	lase =lase  (ImpPrSg2  >laskma !34_V	et	f	\N
123037	takistus	takistus =takistu  (IndIpfSg3  >takistuma !27_V	et	f	\N
123039	takistus	takistus =takistus  (SgN  >takistus !11_S	et	f	\N
123041	takistus	"takistus %takista  )US_vS  <takistama ;27_V	et	f	\N
123044	sügavam	sügavam =sügavam  (SgN  >sügavam !02_A	et	f	\N
123045	sügavam	"sügavam %süga  )VAM_cA  <sügama ;27_V	et	f	\N
123046	sügavam	"sügavam %sügava  )M_cA  <sügav ;02_A	et	f	\N
123047	kättesaamatusest	kättesaamatusest =saamatuse  (SgEl  >kätte+saamatus !11_S	et	f	\N
123048	kättesaamatusest	"kätte+saamatus %saama  )TUS2_aS  <kätte+saam ;22_S	et	f	\N
123049	kättesaamatusest	kättesaamatusest =saamatuses  (SgP  >kätte+saamatusene !12_A	et	f	\N
123050	kättesaamatusest	"kätte+saamatusene %saamatuse  )NE_aA  <kätte+saamatus ;11_S	et	f	\N
123056	mõistus	mõistus =mõistu  (SgIn  >mõist !22_S	et	f	\N
123057	mõistus	mõistus =mõistus  (SgN  >mõistus !11~09_S	et	f	\N
123060	kättesaadavusest	kättesaadavusest =saadavuse  (SgEl  >kätte+saadavus !11_S	et	f	\N
123062	kättesaadavusest	"kätte+saadavus %saadava  )US_aS  <kätte+saadav ;02_A	et	f	\N
123064	kättesaadavusest	kättesaadavusest =saadavuses  (SgP  >kätte+saadavusene !12_A	et	f	\N
123065	kättesaadavusest	"kätte+saadavusene %saadavuse  )NE_aA  <kätte+saadavus ;11_S	et	f	\N
123088	kange	kange =kange  (SgN  >kange !01_A	et	f	\N
123089	kange	kange =kange  (SgG  >kange !01_A	et	f	\N
123090	kange	kange =kange  (PlP  >kang !22_S	et	f	\N
123095	keelust	keelust =keelu  (SgEl  >keeld !22_S	et	f	\N
123097	keelust	keelust =us  (SgP  >keel+uks !14_S	et	f	\N
123098	mõtle	mõtle =mõtle  (IndPrPs_  >mõtlema !30_V	et	f	\N
123099	mõtle	mõtle =mõtle  (ImpPrSg2  >mõtlema !30_V	et	f	\N
123116	vägevamate	vägevamate =vägevama  (PlG  >vägevam !02_A	et	f	\N
123117	vägevamate	"vägevam %vägeva  )M_cA  <vägev ;02_A	et	f	\N
123136	piiratuse	piiratuse =piiratuse  (SgG  >piiratus !11_S	et	f	\N
123137	piiratuse	"piiratus %piira  )TUS1_aS  <piirama ;29_V	et	f	\N
123138	piiratuse	"piiratus %piira  )TUS2_aS  <piird ;22_S	et	f	\N
123150	cwolf	?cwolf =cwolf  (SgN  >cwolf !22_S	et	f	\N
123170	vormikeelt	vormikeelt =kee  (SgAbl  >vormi+kesi !15_S	et	f	\N
123171	vormikeelt	vormikeelt =kee  (SgAbl  >vormi+kee !26_S	et	f	\N
123172	vormikeelt	vormikeelt =keel  (SgP  >vormi+keel !13_S	et	f	\N
123176	jääda	jääda =jää  (Inf  >jääma !37_V	et	f	\N
123177	jääda	jääda =jää  (IndPrIps_  >jääma !37_V	et	f	\N
123187	peatükkis	?peatükkis =peatükki  (IndIpfSg3  >peatükkima !28_V	et	f	\N
123188	peatükkis	?peatükkis =peatükkis  (SgN  >peatükkis !11_S	et	f	\N
123204	peategija	peategija =tegija  (SgN  >pea+tegija !01_S	et	f	\N
123205	peategija	peategija =tegija  (SgG  >pea+tegija !01_S	et	f	\N
123206	kattest	kattest =katte  (SgEl  >kate !06_S	et	f	\N
123207	kattest	kattest =kattes  (SgP  >kattene !12~10_A	et	f	\N
123208	kattest	"kattene %katte  )NE_aA  <kate ;06_S	et	f	\N
123228	godotd	?godotd =godotd  (SgN  >godotd !22_S	et	f	\N
123231	tähenda	tähenda =tähenda  (IndPrPs_  >tähendama !27_V	et	f	\N
123232	tähenda	tähenda =tähenda  (ImpPrSg2  >tähendama !27_V	et	f	\N
122893	vastikus	vastikus =vastiku  (SgIn  >vastik !02_A	et	f	\N
122894	vastikus	vastikus =vastikus  (SgN  >vastikus !11_S	et	f	\N
122895	vastikus	"vastikus %vastiku  )US_aS  <vastik ;02_A	et	f	\N
122912	sartre	?sartre =sartre  (SgN  >sartre !06_S	et	f	\N
122913	sartre	?sartre =sartre  (SgG  >sartre !06_S	et	f	\N
122914	sartre	?sartre =sartre  (IndPrPs_  >sartrema !27_V	et	f	\N
122915	sartre	?sartre =sartre  (ImpPrSg2  >sartrema !27_V	et	f	\N
122922	harry	### harry	et	f	\N
122945	mooel	?mooel =mooel  (SgN  >mooel !02_S	et	f	\N
122953	jooneline	jooneline =jooneline  (SgN  >jooneline !12_A	et	f	\N
122954	jooneline	"jooneline %joone  )LINE_aA  <joon ;13_S	et	f	\N
122955	jooneline	"jooneline %jooneli  )NE_aA  <joonel ;02_S	et	f	\N
122956	tsükliline	tsükliline =tsükliline  (SgN  >tsükliline !12_A	et	f	\N
122957	tsükliline	"tsükliline %tsükli  )LINE_aA  <tsükkel ;02_S	et	f	\N
122971	eksistentsialistlik	?eksistentsialistlik =eksistentsialistlik  (SgN  >eksistentsialistlik !25_A	et	f	\N
122972	eksistentsialistlik	?eksistentsialistlik =alistlik  (SgN  >eksistentsi+alistlik !25_A	et	f	\N
122973	eksistentsialistlik	?eksistentsialistlik =stentsialistlik  (SgN  >eksi+stentsialistlik !25_A	et	f	\N
122974	eksistentsialistlik	?eksistentsialistlik =istentsialistlik  (SgN  >eks+istentsialistlik !25_A	et	f	\N
123021	arvamusest	arvamusest =arvamuse  (SgEl  >arvamus !11_S	et	f	\N
123022	arvamusest	arvamusest =arvamuses  (SgP  >arvamusene !12_A	et	f	\N
123023	arvamusest	"arvamusene %arvamuse  )NE_aA  <arvamus ;11_S	et	f	\N
123026	tõenäolisema	tõenäolisema =näolisema  (SgG  >tõe+näolisem !02_A	et	f	\N
123027	tõenäolisema	"tõe+näolisem %näo  )LISEM_cA  <tõe+nägu ;18_S	et	f	\N
123028	tõenäolisema	"tõe+näolisem %näolise  )M_cA  <tõe+näoline ;10_A	et	f	\N
123029	tõenäolisema	"tõe+näolisem %näolise  )M_cA  <tõe+näoline ;12_A	et	f	\N
123051	kohus	kohus =kohu  (IndIpfSg3  >kohuma !27_V	et	f	\N
123052	kohus	kohus =kohus  (SgN  >kohus !05_S	et	f	\N
123053	kohus	kohus =kohus  (SgN  >kohus !09_S	et	f	\N
123061	ebaloogiline	ebaloogiline =loogiline  (SgN  >eba+loogiline !12_A	et	f	\N
123063	ebaloogiline	"eba+loogiline %loogi  )LINE_aA  <eba+loog ;22_S	et	f	\N
123066	ülemuse	ülemuse =ülemuse  (SgG  >ülemus !11_S	et	f	\N
123067	ülemuse	"ülemus %ülema  )US_aS  <ülem ;02_AS	et	f	\N
123068	tahe	tahe =tahe  (SgN  >tahe !02_A	et	f	\N
123069	tahe	tahe =tahe  (SgN  >tahe !06_S	et	f	\N
123075	kohast	kohast =koha  (SgEl  >koha !17_S	et	f	\N
123076	kohast	kohast =koha  (SgEl  >koht !22_S	et	f	\N
123077	kohast	kohast =kohas  (SgP  >kohane !10_A	et	f	\N
123079	kohast	"kohane %koha  )NE_aA  <koha ;17_S	et	f	\N
123081	kohast	"kohane %koha  )NE_aA  <koht ;22_S	et	f	\N
123082	las	las =la  (SgIn  >la !26_S	et	f	\N
123083	las	las =las  (ID  >las !41_D	et	f	\N
123128	patuseid	patuseid =patuse  (PlP  >patune !10_A	et	f	\N
123129	patuseid	"patune %patu  )NE_aA  <patt ;22_S	et	f	\N
123141	puudumise	puudumise =puudumise  (SgG  >puudumine !12_S	et	f	\N
123142	puudumise	"puudumine %puudu  )MINE_vS  <puuduma ;27_V	et	f	\N
123148	courage	### courage	et	f	\N
123151	medeia	?medeia =medeia  (SgN  >medeia !16_S	et	f	\N
123152	medeia	?medeia =medeia  (SgG  >medeia !16_S	et	f	\N
123153	medeia	?medeia =eia  (SgN  >med+eia !16_S	et	f	\N
123154	medeia	?medeia =eia  (SgG  >med+eia !16_S	et	f	\N
123155	frkafka	?frkafka =frkafka  (SgN  >frkafka !16_S	et	f	\N
123156	frkafka	?frkafka =frkafka  (SgG  >frkafka !16_S	et	f	\N
123157	frkafka	?frkafka =frkafka  (IndPrPs_  >frkafkama !29_V	et	f	\N
123158	frkafka	?frkafka =frkafka  (ImpPrSg2  >frkafkama !29_V	et	f	\N
123161	tegemist	tegemist =tegemis  (SgP  >tegemine !12_S	et	f	\N
123162	tegemist	"tegemine %tege  )MINE_vS  <tegema ;28_V	et	f	\N
123166	nähtustega	nähtustega =nähtus  (PlKom  >nähtus !11~09_S	et	f	\N
123167	nähtustega	"nähtus %näh  )TUS1_aS  <nägema ;28_V	et	f	\N
123181	lõppus	?lõppus =lõppu  (IndIpfSg3  >lõppuma !27_V	et	f	\N
123182	lõppus	?lõppus =lõppus  (SgN  >lõppus !11~09_S	et	f	\N
123194	üksisiku	üksisiku =siku  (SgG  >üksi+sikk !22_S	et	f	\N
123195	üksisiku	üksisiku =isiku  (SgG  >üks+isik !02_S	et	f	\N
123196	demonstreeritud	demonstreeritud =demonstreeri  (PtsPtIps  >demonstreerima !28_V	et	f	\N
123197	demonstreeritud	demonstreeritud =demonstreeritu  (PlN  >demonstreeritu !01_S	et	f	\N
123198	demonstreeritud	"demonstreeritu %demonstreeri  )TU1_vS  <demonstreerima ;28_V	et	f	\N
123199	demonstreeritud	demonstreeritud =demonstreeritud  (ID  >demonstreeritud !41_A	et	f	\N
123200	demonstreeritud	"demonstreeritud %demonstreeri  )TUD_vA  <demonstreerima ;28_V	et	f	\N
123201	leheküljest	leheküljest =külje  (SgEl  >lehe+külg !22_S	et	f	\N
123202	leheküljest	leheküljest =küljes  (SgP  >lehe+küljene !10_A	et	f	\N
123203	leheküljest	"lehe+küljene %külje  )NE_aA  <lehe+külg ;22_S	et	f	\N
123221	absurdifilosoofiasse	absurdifilosoofiasse =asse  (PlP  >absurdi+filosoofi+ass !22_S	et	f	\N
123222	absurdifilosoofiasse	absurdifilosoofiasse =filosoofia  (SgIll  >absurdi+filosoofia !01_S	et	f	\N
123233	peitnud	peitnud =peit  (PtsPtPs  >peitma !34_V	et	f	\N
123234	peitnud	peitnud =peitnu  (PlN  >peitnu !01_S	et	f	\N
123235	peitnud	"peitnu %peit  )NU_vS  <peitma ;34_V	et	f	\N
123236	peitnud	peitnud =peitnud  (ID  >peitnud !41_A	et	f	\N
122906	hesse	?hesse =hesse  (SgG  >hesne !02_A	et	f	\N
122907	hesse	?hesse =hesse  (SgG  >hesse !06_S	et	f	\N
122908	hesse	?hesse =hesse  (PlP  >hess !22_S	et	f	\N
122909	hesse	?hesse =hesse  (IndPrPs_  >hessema !27_V	et	f	\N
122910	hesse	?hesse =hesse  (ImpPrSg2  >hessema !27_V	et	f	\N
122911	jp	### jp	et	f	\N
122920	sügava	sügava =sügava  (SgG  >sügav !02_A	et	f	\N
122921	sügava	"sügav %süga  )V_vA  <sügama ;27_V	et	f	\N
122937	peenelt	peenelt =peene  (SgAbl  >peen !13_A	et	f	\N
122938	peenelt	peenelt =peenelt  (ID  >peenelt !41_D	et	f	\N
122939	peenelt	"peenelt %peene  )LT_mD  <peen ;13_A	et	f	\N
122964	maagiliste	maagiliste =maagilis  (PlG  >maagiline !12_A	et	f	\N
122965	maagiliste	"maagiline %maagi  )LINE_aA  <maag ;22_S	et	f	\N
122966	maagiliste	"maagiline %maagi  )LINE_aA  <maak ;22_S	et	f	\N
122967	lisamisega	lisamisega =lisamise  (SgKom  >lisamine !12_S	et	f	\N
122968	lisamisega	"lisamine %lisa  )MINE_vS  <lisama ;27_V	et	f	\N
122975	psühhoanalüüsi	psühhoanalüüsi =analüüsi  (SgG  >psühho+analüüs !22_S	et	f	\N
122976	psühhoanalüüsi	psühhoanalüüsi =analüüsi  (SgP  >psühho+analüüs !22_S	et	f	\N
122977	psühhoanalüüsi	psühhoanalüüsi =analüüsi  (SgAdt  >psühho+analüüs !22_S	et	f	\N
122984	tõlke	tõlke =tõlke  (SgG  >tõlge !06_S	et	f	\N
122985	tõlke	tõlke =tõlke  (PlP  >tõlk !22_S	et	f	\N
122986	peidetud	peidetud =peide  (PtsPtIps  >peitma !34_V	et	f	\N
122987	peidetud	peidetud =peidetu  (PlN  >peidetu !01_AS	et	f	\N
122988	peidetud	"peidetu %peide  )TU1_vS  <peitma ;34_V	et	f	\N
122989	peidetud	peidetud =peidetud  (ID  >peidetud !41_A	et	f	\N
122990	peidetud	"peidetud %peide  )TUD_vA  <peitma ;34_V	et	f	\N
122995	peaidee	peaidee =idee  (SgN  >pea+idee !26_S	et	f	\N
122996	peaidee	peaidee =idee  (SgG  >pea+idee !26_S	et	f	\N
123004	teoseks	teoseks =teose  (SgTr  >teos !09_S	et	f	\N
123005	teoseks	teoseks =seks  (SgN  >teo+seks !22_S	et	f	\N
123011	süüdistust	süüdistust =süüdistus  (SgP  >süüdistus !11_S	et	f	\N
123012	süüdistust	"süüdistus %süüdista  )US_vS  <süüdistama ;27_V	et	f	\N
123024	paraboolis	paraboolis =parabooli  (SgIn  >parabool !22_S	et	f	\N
123025	paraboolis	paraboolis =booli  (SgIn  >para+bool !22_S	et	f	\N
123058	tõtt	tõtt =tõ  (SgP  >tõsi !15_S	et	f	\N
123059	tõtt	tõtt =tõtt  (SgN  >tõtt !22_S	et	f	\N
123070	valikuvabadus	valikuvabadus =vabadus  (SgN  >valiku+vabadus !11_S	et	f	\N
123071	valikuvabadus	"valiku+vabadus %vaba  )US_aS  <valiku+vaba ;17_A	et	f	\N
123114	takistuse	takistuse =takistuse  (SgG  >takistus !11_S	et	f	\N
123115	takistuse	"takistus %takista  )US_vS  <takistama ;27_V	et	f	\N
123120	süütu	süütu =süütu  (SgN  >süütu !01_A	et	f	\N
123121	süütu	"süütu %süü  )TU2_kA  <süü ;26_S	et	f	\N
123122	süütu	süütu =süütu  (SgG  >süütu !01_A	et	f	\N
123143	lüürika	lüürika =lüürika  (SgN  >lüürika !01_S	et	f	\N
123144	lüürika	lüürika =lüürika  (SgG  >lüürika !01_S	et	f	\N
123149	mbulgakov	?mbulgakov =mbulgakov  (SgN  >mbulgakov !02_A	et	f	\N
123163	aja-	aja- =aja  (SgG  >aeg !22_S	et	f	\N
123164	aja-	aja- =aja  (IndPrPs_  >ajama !27_V	et	f	\N
123165	aja-	aja- =aja  (ImpPrSg2  >ajama !27_V	et	f	\N
123192	mifoloogiast	?mifoloogiast =mifoloogia  (SgEl  >mifoloogia !01_S	et	f	\N
123193	mifoloogiast	?mifoloogiast =mifoloogias  (SgP  >mifoloogias !11_S	et	f	\N
123226	s	### s	et	f	\N
123229	loogilised	loogilised =loogilise  (PlN  >loogiline !12_A	et	f	\N
123230	loogilised	"loogiline %loogi  )LINE_aA  <loog ;22_S	et	f	\N
123242	fantaasia	fantaasia =fantaasia  (SgN  >fantaasia !01_S	et	f	\N
123243	fantaasia	fantaasia =fantaasia  (SgG  >fantaasia !01_S	et	f	\N
123248	loogika	loogika =loogika  (SgN  >loogika !01_S	et	f	\N
123249	loogika	loogika =loogika  (SgG  >loogika !01_S	et	f	\N
123261	körti	körti =körti  (SgP  >kört !22_S	et	f	\N
123262	körti	körti =körti  (SgAdt  >kört !22_S	et	f	\N
123278	hambutu	hambutu =hambutu  (SgN  >hambutu !01_A	et	f	\N
123279	hambutu	"hambutu %hambu  )TU1_vS  <hambuma ;27_V	et	f	\N
123280	hambutu	hambutu =hambutu  (SgG  >hambutu !01_A	et	f	\N
123293	otsas	otsas =otsa  (SgIn  >ots !23?22_S	et	f	\N
123295	otsas	otsas =otsa  (IndIpfSg3  >otsama !29_V	et	f	\N
123296	otsas	otsas =otsas  (ID  >otsas !41_DK	et	f	\N
123308	kratti	kratti =kratti  (SgP  >kratt !22_S	et	f	\N
123309	kratti	kratti =kratti  (SgAdt  >kratt !22_S	et	f	\N
123315	küünlasöömisest	küünlasöömisest =söömise  (SgEl  >küünla+söömine !12?10_S	et	f	\N
123316	küünlasöömisest	"küünla+söömine %söömi  )NE_aA  <küünla+sööm ;22_S	et	f	\N
123317	noosi	noosi =noosi  (SgG  >noos !22_S	et	f	\N
123318	noosi	noosi =noosi  (SgP  >noos !22_S	et	f	\N
123319	noosi	noosi =noosi  (SgAdt  >noos !22_S	et	f	\N
123320	peas	peas =pea  (SgIn  >pea !26_S	et	f	\N
123321	peas	peas =peas  (ID  >peas !41_D	et	f	\N
123332	too	too =too  (SgN  >too !00_P	et	f	\N
123333	too	too =too  (IndPrPs_  >tooma !38_V	et	f	\N
123334	too	too =too  (ImpPrSg2  >tooma !38_V	et	f	\N
123351	lugemise	lugemise =lugemise  (SgG  >lugemine !12_S	et	f	\N
123352	lugemise	"lugemine %luge  )MINE_vS  <lugema ;28_V	et	f	\N
122961	post-modernismi	post-modernismi =ismi  (SgG  >post-modern+ism !22_S	et	f	\N
122962	post-modernismi	post-modernismi =ismi  (SgP  >post-modern+ism !22_S	et	f	\N
122963	post-modernismi	post-modernismi =ismi  (SgAdt  >post-modern+ism !22_S	et	f	\N
122982	kohapärane	kohapärane =pärane  (SgN  >koha+pärane !10_A	et	f	\N
122983	kohapärane	"koha+pärane %pära  )NE_aA  <koha+pära ;17_S	et	f	\N
123006	allegooria	allegooria =allegooria  (SgN  >allegooria !01_S	et	f	\N
123007	allegooria	allegooria =allegooria  (SgG  >allegooria !01_S	et	f	\N
123008	josefile	?josefile =josefi  (SgAll  >josefi !01_S	et	f	\N
123009	josefile	?josefile =josefi  (SgAll  >josef !02_S	et	f	\N
123010	josefile	?josefile =josefi  (SgAll  >joseff !22_S	et	f	\N
123018	sõltuv	sõltuv =sõltu  (PtsPrPs  >sõltuma !27_V	et	f	\N
123019	sõltuv	sõltuv =sõltuv  (SgN  >sõltuv !02_A	et	f	\N
123020	sõltuv	"sõltuv %sõltu  )V_vA  <sõltuma ;27_V	et	f	\N
123030	viisiga	viisiga =viisi  (SgKom  >viis !22_S	et	f	\N
123031	viisiga	viisiga =iga  (SgN  >viis+iga !18_S	et	f	\N
123032	viisiga	viisiga =iga  (SgP  >viis+iga !18_S	et	f	\N
123042	võidelda	võidelda =võidel  (Inf  >võitlema !30_V	et	f	\N
123043	võidelda	võidelda =võidel  (IndPrIps_  >võitlema !30_V	et	f	\N
123054	õiglust	õiglust =õiglus  (SgP  >õiglus !11~09_S	et	f	\N
123055	õiglust	"õiglus %õiglase  )US_aS  <õiglane ;12_A	et	f	\N
123078	kuskilt	kuskilt =kuskilt  (ID  >kuskilt !41_D	et	f	\N
123080	kuskilt	kuskilt =kilt  (SgN  >kus+kilt !22_S	et	f	\N
123100	võimalusest	võimalusest =võimaluse  (SgEl  >võimalus !11_S	et	f	\N
123101	võimalusest	võimalusest =võimaluses  (SgP  >võimalusene !12_A	et	f	\N
123102	võimalusest	"võimalusene %võimaluse  )NE_aA  <võimalus ;11_S	et	f	\N
123103	tunnete	tunnete =tunne  (PlG  >tunne !06_S	et	f	\N
123104	tunnete	tunnete =tunne  (IndPrPl2  >tundma !34_V	et	f	\N
123105	peegeldus	peegeldus =peegeldu  (IndIpfSg3  >peegelduma !27_V	et	f	\N
123106	peegeldus	peegeldus =peegeldus  (SgN  >peegeldus !11_S	et	f	\N
123107	peegeldus	"peegeldus %peegelda  )US_vS  <peegeldama ;27_V	et	f	\N
123118	kardab	kardab =karda  (IndPrSg3  >kardama !29_V	et	f	\N
123119	kardab	kardab =karda  (IndPrSg3  >kartma !34_V	et	f	\N
123124	kuriteost	kuriteost =teo  (SgEl  >kuri+tegu !18_S	et	f	\N
123125	kuriteost	kuriteost =teo  (SgEl  >kuri+tigu !18_S	et	f	\N
123126	kuriteost	kuriteost =teos  (SgP  >kuri+teos !09_S	et	f	\N
123134	karistus	karistus =karistus  (SgN  >karistus !11_S	et	f	\N
123135	karistus	"karistus %karista  )US_vS  <karistama ;27_V	et	f	\N
123139	nürimeelsuse	nürimeelsuse =meelsuse  (SgG  >nüri+meelsus !11~09_S	et	f	\N
123140	nürimeelsuse	"nüri+meelsus %meelse  )US_aS  <nüri+meelne ;02_A	et	f	\N
123145	mitmes	mitmes =mitme  (SgIn  >mitu !05_P	et	f	\N
123146	mitmes	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
123147	mitmes	mitmes =mitmes  (SgN  >mitmes !02_P	et	f	\N
123168	probleemistik	probleemistik =probleemistik  (SgN  >probleemistik !25_S	et	f	\N
123169	probleemistik	probleemistik =istik  (SgN  >probleem+istik !02_S	et	f	\N
123173	seisukohti	seisukohti =kohti  (SgP  >seisu+koht !22_S	et	f	\N
123174	seisukohti	seisukohti =kohti  (SgAdt  >seisu+koht !22_S	et	f	\N
123175	seisukohti	seisukohti =kohti  (PlP  >seisu+koht !22_S	et	f	\N
123178	surevad	surevad =sure  (IndPrPl3  >surema !36_V	et	f	\N
123179	surevad	surevad =sureva  (PlN  >surev !02_A	et	f	\N
123180	surevad	"surev %sure  )V_vA  <surema ;36_V	et	f	\N
123189	näite	näite =näi  (IndPrPl2  >näima !37_V	et	f	\N
123190	näite	näite =näite  (SgG  >näide !06_S	et	f	\N
123191	näite	näite =näite  (PlP  >näit !22_S	et	f	\N
123214	gerooiline	?gerooiline =gerooiline  (SgN  >gerooiline !12_A	et	f	\N
123223	kalduvat	kalduvat =kaldu  (KvtPrPs  >kalduma !27_V	et	f	\N
123224	kalduvat	kalduvat =kalduva  (SgP  >kalduv !02_A	et	f	\N
123225	kalduvat	"kalduv %kaldu  )V_vA  <kalduma ;27_V	et	f	\N
123266	luupainaja	luupainaja =painaja  (SgN  >luu+painaja !01_S	et	f	\N
123267	luupainaja	luupainaja =painaja  (SgG  >luu+painaja !01_S	et	f	\N
123274	naeris	naeris =naer  (IndIpfSg3  >naerma !33_V	et	f	\N
123275	naeris	naeris =naeri  (SgIn  >naeris !07_S	et	f	\N
123276	naeris	naeris =naeri  (SgIn  >naer !22_S	et	f	\N
123277	naeris	naeris =naeris  (SgN  >naeris !07_S	et	f	\N
123297	viilaka	viilaka =viilaka  (SgG  >viilakas !02_S	et	f	\N
123298	viilaka	viilaka =aka  (SgN  >viil+aka !16_S	et	f	\N
123299	viilaka	viilaka =aka  (SgG  >viil+aka !16_S	et	f	\N
123310	kuula	kuula =kuula  (IndPrPs_  >kuulama !29_V	et	f	\N
123311	kuula	kuula =kuula  (ImpPrSg2  >kuulama !29_V	et	f	\N
123324	tüki	tüki =tüki  (SgG  >tükk !22_S	et	f	\N
123326	tüki	tüki =tüki  (IndPrPs_  >tükkima !28_V	et	f	\N
123328	tüki	tüki =tüki  (ImpPrSg2  >tükkima !28_V	et	f	\N
123354	lugejal	lugejal =lugeja  (SgAd  >lugeja !01_S	et	f	\N
123355	lugejal	"lugeja %luge  )JA_vS  <lugema ;28_V	et	f	\N
123362	olukorrast	olukorrast =korra  (SgEl  >olu+kord !22_S	et	f	\N
123363	olukorrast	olukorrast =korras  (SgP  >olu+korrane !10_A	et	f	\N
123364	olukorrast	"olu+korrane %korra  )NE_aA  <olu+kord ;22_S	et	f	\N
123372	lugejale	lugejale =lugeja  (SgAll  >lugeja !01_S	et	f	\N
123373	lugejale	"lugeja %luge  )JA_vS  <lugema ;28_V	et	f	\N
123133	õpetusest	"õpetusene %õpetuse  )NE_aA  <õpetus ;11_S	et	f	\N
123159	ühiskonnaga	ühiskonnaga =ühiskonna  (SgKom  >ühiskond !22_S	et	f	\N
123160	ühiskonnaga	ühiskonnaga =konna  (SgKom  >ühis+konn !22_S	et	f	\N
123183	võidulaulu	võidulaulu =laulu  (SgG  >võidu+laul !22_S	et	f	\N
123184	võidulaulu	võidulaulu =laulu  (SgP  >võidu+laul !22_S	et	f	\N
123185	võidulaulu	võidulaulu =laulu  (SgAdt  >võidu+laul !22_S	et	f	\N
123186	persikov	?persikov =persikov  (SgN  >persikov !02_A	et	f	\N
123209	muutuvad	muutuvad =muutu  (IndPrPl3  >muutuma !27_V	et	f	\N
123210	muutuvad	muutuvad =muutuva  (PlN  >muutuv !02_A	et	f	\N
123211	muutuvad	"muutuv %muutu  )V_vA  <muutuma ;27_V	et	f	\N
123212	traagilisemaks	traagilisemaks =traagilisema  (SgTr  >traagilisem !02_A	et	f	\N
123213	traagilisemaks	"traagilisem %traagilise  )M_cA  <traagiline ;12_A	et	f	\N
123215	küljest	küljest =külje  (SgEl  >külg !22_S	et	f	\N
123216	küljest	küljest =küljes  (SgP  >küljene !10_A	et	f	\N
123217	küljest	"küljene %külje  )NE_aA  <külg ;22_S	et	f	\N
123218	küljest	küljest =küljest  (ID  >küljest !41_DK	et	f	\N
123219	mõtleksid	mõtleksid =mõtle  (KndPrSg2  >mõtlema !30_V	et	f	\N
123220	mõtleksid	mõtleksid =mõtle  (KndPrPl3  >mõtlema !30_V	et	f	\N
123227	beckett	?beckett =beckett  (SgN  >beckett !22_S	et	f	\N
123238	lõpus	lõpus =lõpu  (SgIn  >lõpp !22_SA	et	f	\N
123239	lõpus	lõpus =lõpus  (SgN  >lõpus !09_S	et	f	\N
123244	aeglaselt	aeglaselt =aeglase  (SgAbl  >aeglane !12?10_A	et	f	\N
123245	aeglaselt	aeglaselt =aeglaselt  (ID  >aeglaselt !41_D	et	f	\N
123246	aeglaselt	"aeglaselt %aeglase  )LT_mD  <aeglane ;10_A	et	f	\N
123247	aeglaselt	"aeglaselt %aeglase  )LT_mD  <aeglane ;12_A	et	f	\N
123250	arusaamatu	arusaamatu =saamatu  (SgN  >aru+saamatu !01_A	et	f	\N
123251	arusaamatu	"aru+saamatu %saama  )TU2_kA  <aru+saam ;22_S	et	f	\N
123252	arusaamatu	arusaamatu =saamatu  (SgG  >aru+saamatu !01_A	et	f	\N
123257	kivirähki	kivirähki =rähki  (SgP  >kivi+rähk !22_S	et	f	\N
123258	kivirähki	kivirähki =rähki  (SgAdt  >kivi+rähk !22_S	et	f	\N
123259	kivirähki	kivirähki =rähki  (PlP  >kivi+rähk !22_S	et	f	\N
123289	istus	istus =istu  (SgIn  >ist !22_S	et	f	\N
123291	istus	istus =istu  (IndIpfSg3  >istuma !28_V	et	f	\N
123306	umbe	umbe =umbe  (ID  >umbe !41_D	et	f	\N
123307	umbe	umbe =umbe  (SgG  >umme !06_S	et	f	\N
123335	usalda	usalda =usalda  (IndPrPs_  >usaldama !27_V	et	f	\N
123336	usalda	usalda =usalda  (ImpPrSg2  >usaldama !27_V	et	f	\N
123346	httpadmhmaorupeoplefinougrhtmlprozaestoncikivirahkr1html	### httpadmhmaorupeoplefinougrhtmlprozaestoncikivirahkr1html	et	f	\N
123370	toimuvast	toimuvast =toimuva  (SgEl  >toimuv !02_A	et	f	\N
123371	toimuvast	"toimuv %toimu  )V_vA  <toimuma ;27_V	et	f	\N
123377	seostu	seostu =seostu  (IndPrPs_  >seostuma !27_V	et	f	\N
123378	seostu	seostu =seostu  (ImpPrSg2  >seostuma !27_V	et	f	\N
123379	iseloomuomadustega	iseloomuomadustega =omadus  (PlKom  >ise+loomu+omadus !11_S	et	f	\N
123380	iseloomuomadustega	"ise+loomu+omadus %oma  )US_aS  <ise+loomu+oma ;17_A	et	f	\N
123381	kujunevad	kujunevad =kujune  (IndPrPl3  >kujunema !27_V	et	f	\N
123382	kujunevad	kujunevad =kujuneva  (PlN  >kujunev !02_A	et	f	\N
123383	kujunevad	"kujunev %kujune  )V_vA  <kujunema ;27_V	et	f	\N
123386	lendav	lendav =lenda  (PtsPrPs  >lendama !29_V	et	f	\N
123387	lendav	lendav =lendav  (SgN  >lendav !02_A	et	f	\N
123388	lendav	"lendav %lenda  )V_vA  <lendama ;29_V	et	f	\N
123407	kodukäija	kodukäija =käija  (SgN  >kodu+käija !01_S	et	f	\N
123408	kodukäija	kodukäija =käija  (SgG  >kodu+käija !01_S	et	f	\N
123410	lause	lause =lause  (SgN  >lause !06_S	et	f	\N
123411	lause	lause =lause  (SgG  >lause !06_S	et	f	\N
123418	magas	magas =maga  (IndIpfSg3  >magama !27_V	et	f	\N
123419	magas	magas =magas  (SgN  >magas !02_S	et	f	\N
123433	originaali	originaali =originaali  (SgG  >originaal !22_S	et	f	\N
123434	originaali	originaali =originaali  (SgP  >originaal !22_S	et	f	\N
123435	originaali	originaali =originaali  (SgAdt  >originaal !22_S	et	f	\N
123436	ebaadekvaatsusest	ebaadekvaatsusest =adekvaatsuse  (SgEl  >eba+adekvaatsus !11~09_S	et	f	\N
123437	ebaadekvaatsusest	"eba+adekvaatsus %adekvaatse  )US_aS  <eba+adekvaatne ;02_A	et	f	\N
123444	suhtumisest	suhtumisest =suhtumise  (SgEl  >suhtumine !12_S	et	f	\N
123445	suhtumisest	"suhtumine %suhtu  )MINE_vS  <suhtuma ;27_V	et	f	\N
123462	prussakas	prussakas =prussaka  (SgIn  >prussakas !02_S	et	f	\N
123463	prussakas	prussakas =prussakas  (SgN  >prussakas !02_S	et	f	\N
123481	loobumist	loobumist =loobumis  (SgP  >loobumine !12_S	et	f	\N
123482	loobumist	"loobumine %loobu  )MINE_vS  <loobuma ;27_V	et	f	\N
123483	rehepappi	rehepappi =pappi  (SgP  >rehe+papp !22_S	et	f	\N
123484	rehepappi	rehepappi =pappi  (SgAdt  >rehe+papp !22_S	et	f	\N
123517	iganes	iganes =igane  (IndIpfSg3  >iganema !27_V	et	f	\N
123518	iganes	iganes =iganes  (ID  >iganes !41_D	et	f	\N
123537	tegevusele	tegevusele =tegevuse  (SgAll  >tegevus !11_S	et	f	\N
123538	tegevusele	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
123539	tegevusele	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
123540	tegevusele	tegevusele =use  (PlAll  >tegev+usk !22_S	et	f	\N
123543	toimumise	toimumise =toimumise  (SgG  >toimumine !12_S	et	f	\N
123237	peitnud	"peitnud %peit  )NUD_vA  <peitma ;34_V	et	f	\N
123240	tegijad	tegijad =tegija  (PlN  >tegija !01_S	et	f	\N
123241	tegijad	"tegija %tegi  )JA_vS  <tegema ;28_V	et	f	\N
123253	kõrvutavlingvistiliseks	?kõrvutavlingvistiliseks =kõrvutavlingvistilise  (SgTr  >kõrvutavlingvistiline !12_A	et	f	\N
123254	kõrvutavlingvistiliseks	?kõrvutavlingvistiliseks =tavlingvistilise  (SgTr  >kõrvu+tavlingvistiline !12_A	et	f	\N
123260	joosep	?joosep =joosep  (SgN  >joosep !02_S	et	f	\N
123263	häda	häda =häda  (SgN  >häda !17_S	et	f	\N
123264	häda	häda =häda  (SgG  >häda !17_S	et	f	\N
123265	häda	häda =häda  (SgP  >häda !17_S	et	f	\N
123270	sihukesel	sihukesel =sihukese  (SgAd  >sihuke !12_P	et	f	\N
123271	sihukesel	sihukesel =sihukese  (SgAd  >sihukene !12_P	et	f	\N
123272	seepi	seepi =seepi  (SgP  >seep !22_S	et	f	\N
123273	seepi	seepi =seepi  (SgAdt  >seep !22_S	et	f	\N
123284	naaberkülast	naaberkülast =küla  (SgEl  >naaber+küla !17_S	et	f	\N
123285	naaberkülast	naaberkülast =külas  (SgP  >naaber+külane !10_A	et	f	\N
123286	naaberkülast	"naaber+külane %küla  )NE_aA  <naaber+küla ;17_S	et	f	\N
123287	sõid	sõid =sõ  (IndIpfSg2  >sööma !38_V	et	f	\N
123288	sõid	sõid =sõ  (IndIpfPl3  >sööma !38_V	et	f	\N
123302	jätke	jätke =jät  (ImpPrPl2  >jätma !35_V	et	f	\N
123303	jätke	jätke =jätke  (SgN  >jätke !06_S	et	f	\N
123304	jätke	jätke =jätke  (SgG  >jätke !06_S	et	f	\N
123305	jätke	jätke =jätke  (PlP  >jätk !22_S	et	f	\N
123330	solki	solki =solki  (SgP  >solk !22_S	et	f	\N
123331	solki	solki =solki  (SgAdt  >solk !22_S	et	f	\N
123337	head-paremat	head-paremat =parema  (SgP  >head-parem !02_A	et	f	\N
123338	head-paremat	"head-parem %pare  )M_cA  <head-hea ;26_A	et	f	\N
123339	toomata	toomata =too  (SupAb  >tooma !38_V	et	f	\N
123340	toomata	toomata =toomata  (ID  >toomata !41_A	et	f	\N
123341	toomata	"toomata %too  )MATA_vA  <tooma ;38_V	et	f	\N
123342	rumalus	rumalus =rumalus  (SgN  >rumalus !11_S	et	f	\N
123343	rumalus	"rumalus %rumala  )US_aS  <rumal ;02_A	et	f	\N
123347	jubal	?jubal =jubal  (SgN  >jubal !02_S	et	f	\N
123348	pealkirja	pealkirja =kirja  (SgG  >peal+kiri !24_S	et	f	\N
123349	pealkirja	pealkirja =kirja  (SgP  >peal+kiri !24_S	et	f	\N
123350	pealkirja	pealkirja =kirja  (SgAdt  >peal+kiri !24_S	et	f	\N
123358	muinasjuttude	muinasjuttude =ude  (SgN  >muinas+jutt+ude !04_S	et	f	\N
123359	muinasjuttude	muinasjuttude =juttu  (PlG  >muinas+jutt !22_S	et	f	\N
123360	nutikusega	nutikusega =nutikuse  (SgKom  >nutikus !11_S	et	f	\N
123361	nutikusega	"nutikus %nutika  )US_aS  <nutikas ;02_A	et	f	\N
123374	kuju	kuju =kuju  (SgN  >kuju !17_S	et	f	\N
123375	kuju	kuju =kuju  (SgG  >kuju !17_S	et	f	\N
123376	kuju	kuju =kuju  (SgP  >kuju !17_S	et	f	\N
123399	tegele	tegele =tegele  (IndPrPs_  >tegelema !31~27_V	et	f	\N
123400	tegele	tegele =tegele  (ImpPrSg2  >tegelema !31~27_V	et	f	\N
123403	peremees	peremees =mee  (SgIn  >pere+mesi !15_S	et	f	\N
123404	peremees	peremees =mees  (SgN  >pere+mees !13_S	et	f	\N
123405	mütoloogia	mütoloogia =mütoloogia  (SgN  >mütoloogia !01_S	et	f	\N
123406	mütoloogia	mütoloogia =mütoloogia  (SgG  >mütoloogia !01_S	et	f	\N
123426	vihane	vihane =vihane  (SgN  >vihane !10_A	et	f	\N
123427	vihane	"vihane %viha  )NE_aA  <viha ;17_SA	et	f	\N
123428	vihane	"vihane %viha  )NE_aA  <viht ;22_S	et	f	\N
123429	elukas	elukas =eluka  (SgIn  >elukas !02_S	et	f	\N
123430	elukas	elukas =elukas  (SgN  >elukas !02_S	et	f	\N
123458	sidususe	sidususe =sidususe  (SgG  >sidusus !11_S	et	f	\N
123459	sidususe	"sidusus %sidusa  )US_aS  <sidus ;02_A	et	f	\N
123460	sidususe	"sidusus %siduse  )US_aS  <sidus ;02_A	et	f	\N
123474	kahetsust	kahetsust =kahetsus  (SgP  >kahetsus !11_S	et	f	\N
123475	kahetsust	"kahetsus %kahetse  )US_vS  <kahetsema ;27_V	et	f	\N
123485	usaldusväärseks	usaldusväärseks =seks  (SgN  >usaldus+väär+seks !22_S	et	f	\N
123486	usaldusväärseks	usaldusväärseks =väärse  (SgTr  >usaldus+väärne !02_A	et	f	\N
123495	mitmel	mitmel =mitme  (SgAd  >mitu !05_P	et	f	\N
123496	mitmel	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
123503	juhatatud	juhatatud =juhata  (PtsPtIps  >juhatama !27_V	et	f	\N
123504	juhatatud	juhatatud =juhatatu  (PlN  >juhatatu !01_S	et	f	\N
123505	juhatatud	"juhatatu %juhata  )TU1_vS  <juhatama ;27_V	et	f	\N
123506	juhatatud	juhatatud =juhatatud  (ID  >juhatatud !41_A	et	f	\N
123507	juhatatud	"juhatatud %juhata  )TUD_vA  <juhatama ;27_V	et	f	\N
123508	ajaliselt	ajaliselt =ajalise  (SgAbl  >ajaline !12_A	et	f	\N
123509	ajaliselt	"ajaline %aja  )LINE_aA  <aeg ;22_S	et	f	\N
123510	ajaliselt	ajaliselt =ajaliselt  (ID  >ajaliselt !41_D	et	f	\N
123511	ajaliselt	"ajaliselt %aja  )LISELT_mD  <aeg ;22_S	et	f	\N
123512	ajaliselt	"ajaliselt %ajalise  )LT_mD  <ajaline ;12_A	et	f	\N
123515	võis	võis =või  (SgIn  >või !26_S	et	f	\N
123516	võis	võis =või  (IndIpfSg3  >võima !37_V	et	f	\N
123519	edasistest	edasistest =edasis  (PlEl  >edasine !12_A	et	f	\N
123520	edasistest	edasistest =iste  (SgEl  >edas+iste !06_S	et	f	\N
123521	edasistest	edasistest =iste  (PlEl  >edas+ist !22_S	et	f	\N
123522	edasistest	edasistest =istes  (SgP  >edas+istene !12~10_A	et	f	\N
123255	analüüsiks	analüüsiks =analüüsi  (SgTr  >analüüs !22_S	et	f	\N
123256	analüüsiks	analüüsiks =analüüsi  (KndPrPs  >analüüsima !28_V	et	f	\N
123268	kallal	kallal =kalla  (SgAd  >kalla !16_S	et	f	\N
123269	kallal	kallal =kallal  (ID  >kallal !41_DK	et	f	\N
123281	nisujahu	nisujahu =jahu  (SgN  >nisu+jahu !17_S	et	f	\N
123282	nisujahu	nisujahu =jahu  (SgG  >nisu+jahu !17_S	et	f	\N
123283	nisujahu	nisujahu =jahu  (SgP  >nisu+jahu !17_S	et	f	\N
123290	tünni	tünni =tünni  (SgG  >tünn !22_S	et	f	\N
123292	tünni	tünni =tünni  (SgP  >tünn !22_S	et	f	\N
123294	tünni	tünni =tünni  (SgAdt  >tünn !22_S	et	f	\N
123300	ristirahvas	ristirahvas =rahva  (SgIn  >risti+rahvas !07_S	et	f	\N
123301	ristirahvas	ristirahvas =rahvas  (SgN  >risti+rahvas !07_S	et	f	\N
123312	jahu	jahu =jahu  (SgN  >jahu !17_S	et	f	\N
123313	jahu	jahu =jahu  (SgG  >jahu !17_S	et	f	\N
123314	jahu	jahu =jahu  (SgP  >jahu !17_S	et	f	\N
123322	öelnud	öelnud =öel  (PtsPtPs  >ütlema !30_V	et	f	\N
123323	öelnud	öelnud =öelnu  (PlN  >öelnu !01_S	et	f	\N
123325	öelnud	"öelnu %öel  )NU_vS  <ütlema ;30_V	et	f	\N
123327	öelnud	öelnud =öelnud  (ID  >öelnud !41_A	et	f	\N
123329	öelnud	"öelnud %öel  )NUD_vA  <ütlema ;30_V	et	f	\N
123344	allikas	allikas =allika  (SgIn  >allikas !02_S	et	f	\N
123345	allikas	allikas =allikas  (SgN  >allikas !02_S	et	f	\N
123356	rehepapist	rehepapist =papi  (SgEl  >rehe+papi !16_S	et	f	\N
123357	rehepapist	rehepapist =papi  (SgEl  >rehe+papp !22_S	et	f	\N
123368	hingedekuu	hingedekuu =kuu  (SgN  >hingede+kuu !26_S	et	f	\N
123369	hingedekuu	hingedekuu =kuu  (SgG  >hingede+kuu !26_S	et	f	\N
123389	ahnele	ahnele =ahne  (SgAll  >ahne !01_A	et	f	\N
123390	ahnele	ahnele =ahne  (SgAll  >ahne !06_A	et	f	\N
123415	sulane	sulane =sulane  (SgN  >sulane !10_S	et	f	\N
123416	sulane	sulane =sulane  (IndPrPs_  >sulanema !27_V	et	f	\N
123417	sulane	sulane =sulane  (ImpPrSg2  >sulanema !27_V	et	f	\N
123422	sulast	sulast =sula  (SgEl  >sula !17_AS	et	f	\N
123423	sulast	sulast =sulas  (SgP  >sulane !10_S	et	f	\N
123424	piinas	piinas =piina  (SgIn  >piin !22_S	et	f	\N
123425	piinas	piinas =piina  (IndIpfSg3  >piinama !29_V	et	f	\N
123431	vigastusi	vigastusi =vigastusi  (PlP  >vigastus !11_S	et	f	\N
123432	vigastusi	"vigastus %vigasta  )US_vS  <vigastama ;27_V	et	f	\N
123438	rehepapi	rehepapi =papi  (SgN  >rehe+papi !16_S	et	f	\N
123439	rehepapi	rehepapi =papi  (SgG  >rehe+papi !16_S	et	f	\N
123440	rehepapi	rehepapi =papi  (SgG  >rehe+papp !22_S	et	f	\N
123456	osalejatele	osalejatele =osaleja  (PlAll  >osaleja !01_S	et	f	\N
123457	osalejatele	"osaleja %osale  )JA_vS  <osalema ;27_V	et	f	\N
123461	referents	?referents =referents  (SgN  >referents !22_S	et	f	\N
123466	objektiivsuse	objektiivsuse =objektiivsuse  (SgG  >objektiivsus !11~09_S	et	f	\N
123467	objektiivsuse	"objektiivsus %objektiivse  )US_aS  <objektiivne ;02_A	et	f	\N
123532	väljendatud	väljendatud =väljenda  (PtsPtIps  >väljendama !27_V	et	f	\N
123533	väljendatud	väljendatud =väljendatu  (PlN  >väljendatu !01_S	et	f	\N
123534	väljendatud	"väljendatu %väljenda  )TU1_vS  <väljendama ;27_V	et	f	\N
123535	väljendatud	väljendatud =väljendatud  (ID  >väljendatud !41_A	et	f	\N
123536	väljendatud	"väljendatud %väljenda  )TUD_vA  <väljendama ;27_V	et	f	\N
123548	kaasamist	kaasamist =kaasamis  (SgP  >kaasamine !12_S	et	f	\N
123549	kaasamist	"kaasamine %kaasa  )MINE_vS  <kaasama ;29_V	et	f	\N
123555	toimuva	toimuva =toimuva  (SgG  >toimuv !02_A	et	f	\N
123556	toimuva	"toimuv %toimu  )V_vA  <toimuma ;27_V	et	f	\N
123571	käitumisest	käitumisest =käitumise  (SgEl  >käitumine !12_S	et	f	\N
123572	käitumisest	"käitumine %käitu  )MINE_vS  <käituma ;27_V	et	f	\N
123575	pererahvas	pererahvas =rahva  (SgIn  >pere+rahvas !07_S	et	f	\N
123576	pererahvas	pererahvas =rahvas  (SgN  >pere+rahvas !07_S	et	f	\N
123581	õpetatud	õpetatud =õpeta  (PtsPtIps  >õpetama !27_V	et	f	\N
123582	õpetatud	õpetatud =õpetatu  (PlN  >õpetatu !01_S	et	f	\N
123583	õpetatud	"õpetatu %õpeta  )TU1_vS  <õpetama ;27_V	et	f	\N
123584	õpetatud	õpetatud =õpetatud  (ID  >õpetatud !41_A	et	f	\N
123585	õpetatud	"õpetatud %õpeta  )TUD_vA  <õpetama ;27_V	et	f	\N
123608	sammud	sammud =sammu  (PlN  >samm !22_S	et	f	\N
123609	sammud	sammud =sammu  (IndPrSg2  >sammuma !28_V	et	f	\N
123610	suunas	suunas =suuna  (SgIn  >suund !22_S	et	f	\N
123611	suunas	suunas =suuna  (IndIpfSg3  >suunama !29_V	et	f	\N
123612	suunas	suunas =suunas  (ID  >suunas !41_K	et	f	\N
123617	pärisori	pärisori =ori  (SgN  >päris+ori !24_S	et	f	\N
123618	pärisori	pärisori =sori  (SgN  >päri+sori !17_S	et	f	\N
123619	pärisori	pärisori =sori  (SgG  >päri+sori !17_S	et	f	\N
123620	pärisori	pärisori =sori  (SgP  >päri+sori !17_S	et	f	\N
123630	kehtivad	kehtivad =kehti  (IndPrPl3  >kehtima !27_V	et	f	\N
123631	kehtivad	kehtivad =kehtiva  (PlN  >kehtiv !02_A	et	f	\N
123632	kehtivad	"kehtiv %kehti  )V_vA  <kehtima ;27_V	et	f	\N
123646	dogmast	dogmast =dogma  (SgEl  >dogma !16_S	et	f	\N
123647	dogmast	dogmast =dogmas  (SgP  >dogmane !10_A	et	f	\N
123648	dogmast	"dogmane %dogma  )NE_aA  <dogma ;16_S	et	f	\N
123353	lugemise	"lugemine %lugemi  )NE_aA  <lugem ;02_S	et	f	\N
123365	omapäraseim	omapäraseim =seim  (SgN  >oma+pära+seim !22_S	et	f	\N
123366	omapäraseim	omapäraseim =päraseim  (SgN  >oma+päraseim !02_A	et	f	\N
123367	omapäraseim	"oma+päraseim %pärase  )IM_sA  <oma+pärane ;10_A	et	f	\N
123384	lugejatel	lugejatel =lugeja  (PlAd  >lugeja !01_S	et	f	\N
123385	lugejatel	"lugeja %luge  )JA_vS  <lugema ;28_V	et	f	\N
123401	mässa	mässa =mässa  (IndPrPs_  >mässama !29_V	et	f	\N
123402	mässa	mässa =mässa  (ImpPrSg2  >mässama !29_V	et	f	\N
123409	viha	viha =viha  (SgN  >viha !17_SA	et	f	\N
123412	viha	viha =viha  (SgG  >viha !17_SA	et	f	\N
123413	viha	viha =viha  (SgG  >viht !22_S	et	f	\N
123414	viha	viha =viha  (SgP  >viha !17_SA	et	f	\N
123441	krati	krati =krati  (SgG  >kratt !22_S	et	f	\N
123442	krati	krati =krati  (IndPrPs_  >krattima !28_V	et	f	\N
123443	krati	krati =krati  (ImpPrSg2  >krattima !28_V	et	f	\N
123448	küsimuste-vastuste	küsimuste-vastuste =vastus  (PlG  >küsimuste-vastus !09_S	et	f	\N
123449	küsimuste-vastuste	küsimuste-vastuste =us  (PlG  >küsimuste-vast+uks !14_S	et	f	\N
123464	neutraalsuse	neutraalsuse =neutraalsuse  (SgG  >neutraalsus !11~09_S	et	f	\N
123465	neutraalsuse	"neutraalsus %neutraalse  )US_aS  <neutraalne ;02_A	et	f	\N
123476	pettumust	pettumust =pettumus  (SgP  >pettumus !11_S	et	f	\N
123477	pettumust	"pettumus %pettu  )MUS_vS  <pettuma ;27_V	et	f	\N
123478	arukuses	arukuses =arukuse  (SgIn  >arukus !11_S	et	f	\N
123479	arukuses	"arukus %aruka  )US_aS  <arukas ;02_A	et	f	\N
123480	arukuses	arukuses =kuse  (SgIn  >aru+kusi !20_S	et	f	\N
123487	koduse	koduse =koduse  (SgG  >kodune !10_A	et	f	\N
123488	koduse	"kodune %kodu  )NE_aA  <kodu ;17_S	et	f	\N
123489	ohutu	ohutu =ohutu  (SgN  >ohutu !01_A	et	f	\N
123490	ohutu	"ohutu %ohu  )TU2_kA  <oht ;22_S	et	f	\N
123491	ohutu	ohutu =ohutu  (SgG  >ohutu !01_A	et	f	\N
123492	pildi	pildi =pildi  (SgG  >pilt !22_S	et	f	\N
123493	pildi	pildi =pildi  (SgP  >pild !22_S	et	f	\N
123494	pildi	pildi =pildi  (SgAdt  >pild !22_S	et	f	\N
123497	tare	tare =tare  (SgN  >tare !16_S	et	f	\N
123498	tare	tare =tare  (SgG  >tare !16_S	et	f	\N
123499	küünlasöömise	küünlasöömise =söömise  (SgG  >küünla+söömine !12?10_S	et	f	\N
123500	küünlasöömise	"küünla+söömine %söömi  )NE_aA  <küünla+sööm ;22_S	et	f	\N
123513	umbmäärane	umbmäärane =määrane  (SgN  >umb+määrane !10_A	et	f	\N
123514	umbmäärane	"umb+määrane %määra  )NE_aA  <umb+määr ;22_S	et	f	\N
123541	selgem	selgem =selgem  (SgN  >selgem !02_A	et	f	\N
123542	selgem	"selgem %selge  )M_cA  <selge ;01_A	et	f	\N
123545	vormiga	vormiga =vormi  (SgKom  >vorm !22_S	et	f	\N
123546	vormiga	vormiga =iga  (SgN  >vorm+iga !18_S	et	f	\N
123547	vormiga	vormiga =iga  (SgP  >vorm+iga !18_S	et	f	\N
123577	varastamine	varastamine =varastamine  (SgN  >varastamine !12_S	et	f	\N
123578	varastamine	"varastamine %varasta  )MINE_vS  <varastama ;27_V	et	f	\N
123586	haldusjaotus	haldusjaotus =jaotu  (SgIn  >haldus+jaotu !01_A	et	f	\N
123587	haldusjaotus	"haldus+jaotu %jao  )TU2_kA  <haldus+jagu ;18_S	et	f	\N
123588	haldusjaotus	haldusjaotus =jaotus  (SgN  >haldus+jaotus !11~09_S	et	f	\N
123589	haldusjaotus	"haldus+jaotus %jao  )TUS2_aS  <haldus+jagu ;18_S	et	f	\N
123594	domineeriv	domineeriv =domineeri  (PtsPrPs  >domineerima !28_V	et	f	\N
123595	domineeriv	domineeriv =domineeriv  (SgN  >domineeriv !02_A	et	f	\N
123596	domineeriv	"domineeriv %domineeri  )V_vA  <domineerima ;28_V	et	f	\N
123633	kodukari	kodukari =kari  (SgN  >kodu+kari !17_S	et	f	\N
123634	kodukari	kodukari =kari  (SgN  >kodu+kari !24_S	et	f	\N
123635	kodukari	kodukari =kari  (SgG  >kodu+kari !17_S	et	f	\N
123636	kodukari	kodukari =kari  (SgP  >kodu+kari !17_S	et	f	\N
123637	põgenemine	põgenemine =põgenemine  (SgN  >põgenemine !12_S	et	f	\N
123638	põgenemine	"põgenemine %põgene  )MINE_vS  <põgenema ;27_V	et	f	\N
123642	sõnaraamatu	sõnaraamatu =atu  (SgG  >sõna+raam+att !22_S	et	f	\N
123643	sõnaraamatu	sõnaraamatu =raamatu  (SgG  >sõna+raamat !02_S	et	f	\N
123664	valgustusidee	valgustusidee =idee  (SgN  >valgustus+idee !26_S	et	f	\N
123665	valgustusidee	valgustusidee =idee  (SgG  >valgustus+idee !26_S	et	f	\N
123666	feodaalkorda	?feodaalkorda =feodaalkorda  (SgN  >feodaalkorda !16_S	et	f	\N
123667	feodaalkorda	?feodaalkorda =feodaalkorda  (SgG  >feodaalkorda !16_S	et	f	\N
123668	feodaalkorda	?feodaalkorda =feodaalkorda  (IndPrPs_  >feodaalkordama !27_V	et	f	\N
123669	feodaalkorda	?feodaalkorda =feodaalkorda  (ImpPrSg2  >feodaalkordama !27_V	et	f	\N
123675	arenemine	arenemine =arenemine  (SgN  >arenemine !12_S	et	f	\N
123677	arenemine	"arenemine %arene  )MINE_vS  <arenema ;27_V	et	f	\N
123685	haridusedga	?haridusedga =haridusedga  (SgN  >haridusedga !16_S	et	f	\N
123686	haridusedga	?haridusedga =haridusedga  (SgG  >haridusedga !16_S	et	f	\N
123687	haridusedga	?haridusedga =edga  (SgN  >haridus+edga !16_S	et	f	\N
123689	haridusedga	?haridusedga =edga  (SgG  >haridus+edga !16_S	et	f	\N
123690	haridusedga	?haridusedga =dusedga  (SgN  >hari+dusedga !01_S	et	f	\N
123692	haridusedga	?haridusedga =dusedga  (SgG  >hari+dusedga !01_S	et	f	\N
123697	rahvaluule	rahvaluule =luu  (SgAll  >rahva+luu !26_S	et	f	\N
123698	rahvaluule	rahvaluule =luule  (SgN  >rahva+luule !06_S	et	f	\N
123391	folkloori	folkloori =folkloori  (SgG  >folkloor !22_S	et	f	\N
123392	folkloori	folkloori =folkloori  (SgP  >folkloor !22_S	et	f	\N
123393	folkloori	folkloori =folkloori  (SgAdt  >folkloor !22_S	et	f	\N
123394	folkloori	folkloori =loori  (SgN  >folk+loori !16_S	et	f	\N
123395	folkloori	folkloori =loori  (SgG  >folk+loori !16_S	et	f	\N
123396	folkloori	folkloori =loori  (SgG  >folk+loor !22_S	et	f	\N
123397	folkloori	folkloori =loori  (SgP  >folk+loor !22_S	et	f	\N
123398	folkloori	folkloori =loori  (SgAdt  >folk+loor !22_S	et	f	\N
123420	unenägu	unenägu =nägu  (SgN  >une+nägu !18_S	et	f	\N
123421	unenägu	unenägu =nägu  (SgP  >une+nägu !18_S	et	f	\N
123446	rehepapilt	rehepapilt =papi  (SgAbl  >rehe+papi !16_S	et	f	\N
123447	rehepapilt	rehepapilt =papi  (SgAbl  >rehe+papp !22_S	et	f	\N
123450	vahetus	vahetus =vahetu  (SgIn  >vahetu !01_A	et	f	\N
123451	vahetus	"vahetu %vahe  )TU2_kA  <vahe ;16_S	et	f	\N
123452	vahetus	vahetus =vahetu  (IndIpfSg3  >vahetuma !27_V	et	f	\N
123453	vahetus	vahetus =vahetus  (SgN  >vahetus !11_S	et	f	\N
123454	vahetus	"vahetus %vaheta  )US_vS  <vahetama ;27_V	et	f	\N
123455	vahetus	"vahetus %vahe  )TUS2_aS  <vahe ;16_S	et	f	\N
123468	värvitud	värvitud =värvi  (PtsPtIps  >värvima !28_V	et	f	\N
123469	värvitud	värvitud =värvitu  (PlN  >värvitu !01_AS	et	f	\N
123470	värvitud	"värvitu %värvi  )TU1_vS  <värvima ;28_V	et	f	\N
123471	värvitud	"värvitu %värvi  )TU2_kA  <värv ;22_S	et	f	\N
123472	värvitud	värvitud =värvitud  (ID  >värvitud !41_A	et	f	\N
123473	värvitud	"värvitud %värvi  )TUD_vA  <värvima ;28_V	et	f	\N
123501	kauge	kauge =kauge  (SgN  >kauge !01_A	et	f	\N
123502	kauge	kauge =kauge  (SgG  >kauge !01_A	et	f	\N
123524	kõneleja	kõneleja =kõneleja  (SgN  >kõneleja !01_S	et	f	\N
123525	kõneleja	"kõneleja %kõnele  )JA_vS  <kõnelema ;27_V	et	f	\N
123526	kõneleja	"kõneleja %kõnele  )JA_vS  <kõnelema ;31_V	et	f	\N
123527	kõneleja	kõneleja =kõneleja  (SgG  >kõneleja !01_S	et	f	\N
123528	kujutlus	kujutlus =kujutlus  (SgN  >kujutlus !11_S	et	f	\N
123529	kujutlus	"kujutlus %kujutle  )US_vS  <kujutlema ;27_V	et	f	\N
123566	tingitud	tingitud =tingi  (PtsPtIps  >tingima !28_V	et	f	\N
123567	tingitud	tingitud =tingitu  (PlN  >tingitu !01_AS	et	f	\N
123568	tingitud	"tingitu %tingi  )TU1_vS  <tingima ;28_V	et	f	\N
123569	tingitud	tingitud =tingitud  (ID  >tingitud !41_A	et	f	\N
123570	tingitud	"tingitud %tingi  )TUD_vA  <tingima ;28_V	et	f	\N
123592	asjaajamine	asjaajamine =ajamine  (SgN  >asja+ajamine !12_S	et	f	\N
123593	asjaajamine	"asja+ajamine %ajami  )NE_aA  <asja+ajam ;02_S	et	f	\N
123599	õli	õli =õli  (SgN  >õli !17_S	et	f	\N
123600	õli	õli =õli  (SgG  >õli !17_S	et	f	\N
123601	õli	õli =õli  (SgP  >õli !17_S	et	f	\N
123639	põgeneja	põgeneja =põgeneja  (SgN  >põgeneja !01_S	et	f	\N
123640	põgeneja	"põgeneja %põgene  )JA_vS  <põgenema ;27_V	et	f	\N
123641	põgeneja	põgeneja =põgeneja  (SgG  >põgeneja !01_S	et	f	\N
123670	ratsionalismi	ratsionalismi =ratsionalismi  (SgG  >ratsionalism !22_S	et	f	\N
123671	ratsionalismi	ratsionalismi =ratsionalismi  (SgP  >ratsionalism !22_S	et	f	\N
123672	ratsionalismi	ratsionalismi =ratsionalismi  (SgAdt  >ratsionalism !22_S	et	f	\N
123676	valgustatud	valgustatud =valgusta  (PtsPtIps  >valgustama !27_V	et	f	\N
123678	valgustatud	valgustatud =valgustatu  (PlN  >valgustatu !01_S	et	f	\N
123679	valgustatud	"valgustatu %valgusta  )TU1_vS  <valgustama ;27_V	et	f	\N
123680	valgustatud	valgustatud =valgustatud  (ID  >valgustatud !41_A	et	f	\N
123681	valgustatud	"valgustatud %valgusta  )TUD_vA  <valgustama ;27_V	et	f	\N
123683	valgustatud	valgustatud =atu  (PlN  >valgust+att !22_S	et	f	\N
123705	ões-it	### ões-it	et	f	\N
123714	kaval	kaval =kava  (SgAd  >kava !17_S	et	f	\N
123715	kaval	kaval =kaval  (SgN  >kaval !02_A	et	f	\N
123722	poolehoidu	poolehoidu =hoidu  (SgP  >poole+hoid !22_S	et	f	\N
123723	poolehoidu	poolehoidu =hoidu  (SgAdt  >poole+hoid !22_S	et	f	\N
123724	registreeritud	registreeritud =registreeri  (PtsPtIps  >registreerima !28_V	et	f	\N
123726	registreeritud	registreeritud =registreeritu  (PlN  >registreeritu !01_S	et	f	\N
123728	registreeritud	"registreeritu %registreeri  )TU1_vS  <registreerima ;28_V	et	f	\N
123729	registreeritud	registreeritud =registreeritud  (ID  >registreeritud !41_A	et	f	\N
123730	registreeritud	"registreeritud %registreeri  )TUD_vA  <registreerima ;28_V	et	f	\N
123751	põgeneva	põgeneva =põgeneva  (SgG  >põgenev !02_A	et	f	\N
123752	põgeneva	"põgenev %põgene  )V_vA  <põgenema ;27_V	et	f	\N
123761	välditud	välditud =väldi  (PtsPtIps  >vältima !28_V	et	f	\N
123762	välditud	välditud =välditu  (PlN  >välditu !01_AS	et	f	\N
123764	välditud	"välditu %väldi  )TU1_vS  <vältima ;28_V	et	f	\N
123766	välditud	välditud =välditud  (ID  >välditud !41_A	et	f	\N
123767	välditud	"välditud %väldi  )TUD_vA  <vältima ;28_V	et	f	\N
123794	suuremal	suuremal =suurema  (SgAd  >suurem !02_A	et	f	\N
123795	suuremal	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
123796	suuremal	suuremal =ema  (SgAd  >suur+ema !17_S	et	f	\N
123800	rajajatest	rajajatest =rajaja  (PlEl  >rajaja !01_S	et	f	\N
123801	rajajatest	"rajaja %raja  )JA_vS  <rajama ;27_V	et	f	\N
123523	edasistest	"edas+istene %iste  )NE_aA  <edas+iste ;06_S	et	f	\N
123530	minevikku	minevikku =minevikku  (SgP  >minevik !25_S	et	f	\N
123531	minevikku	minevikku =minevikku  (SgAdt  >minevik !25_S	et	f	\N
123550	toimuvasse	toimuvasse =toimuva  (SgIll  >toimuv !02_A	et	f	\N
123551	toimuvasse	"toimuv %toimu  )V_vA  <toimuma ;27_V	et	f	\N
123557	olevikuvormi	olevikuvormi =vormi  (SgG  >oleviku+vorm !22_S	et	f	\N
123558	olevikuvormi	olevikuvormi =vormi  (SgP  >oleviku+vorm !22_S	et	f	\N
123559	olevikuvormi	olevikuvormi =vormi  (SgAdt  >oleviku+vorm !22_S	et	f	\N
123590	maksustuskord	?maksustuskord =maksustuskord  (SgN  >maksustuskord !22_S	et	f	\N
123591	maksustuskord	?maksustuskord =stuskord  (SgN  >maksu+stuskord !22_S	et	f	\N
123597	fr	### fr	et	f	\N
123602	arenemisega	arenemisega =arenemise  (SgKom  >arenemine !12_S	et	f	\N
123603	arenemisega	"arenemine %arene  )MINE_vS  <arenema ;27_V	et	f	\N
123613	kalevipoja	kalevipoja =poja  (SgN  >kalevi+poja !17_S	et	f	\N
123614	kalevipoja	kalevipoja =poja  (SgG  >kalevi+poja !17_S	et	f	\N
123615	kalevipoja	kalevipoja =poja  (SgG  >kalevi+poeg !22_S	et	f	\N
123616	kalevipoja	kalevipoja =poja  (SgP  >kalevi+poja !17_S	et	f	\N
123621	baltikumis	?baltikumis =baltikumi  (SgIn  >baltikum !19_S	et	f	\N
123622	baltikumis	?baltikumis =baltikumis  (SgN  >baltikumis !09_S	et	f	\N
123623	baltikumis	?baltikumis =kumi  (SgIn  >balti+kumi !17_S	et	f	\N
123624	baltikumis	?baltikumis =kumis  (SgN  >balti+kumis !09_S	et	f	\N
123625	baltikumis	?baltikumis =ikumi  (SgIn  >balt+ikumi !01_S	et	f	\N
123626	baltikumis	?baltikumis =ikumi  (SgIn  >balt+ikum !02_S	et	f	\N
123627	baltikumis	?baltikumis =ikumis  (SgN  >balt+ikumis !11_S	et	f	\N
123628	omaks	omaks =oma  (SgTr  >oma !17_A	et	f	\N
123629	omaks	omaks =oma  (KndPrPs  >omama !27_V	et	f	\N
123644	kujulise	kujulise =kujulise  (SgG  >kujuline !12_A	et	f	\N
123645	kujulise	"kujuline %kuju  )LINE_aA  <kuju ;17_S	et	f	\N
123658	lõuna-eestisse	lõuna-eestisse =eesti  (SgIll  >lõuna-eesti !16_H	et	f	\N
123659	lõuna-eestisse	lõuna-eestisse =tisse  (PlP  >lõuna-ees+tiss !22_S	et	f	\N
123693	sellelperioodil	?sellelperioodil =sellelperioodi  (SgAd  >sellelperioodi !16_S	et	f	\N
123694	sellelperioodil	?sellelperioodil =sellelperioodi  (SgAd  >sellelperioot !22_S	et	f	\N
123695	sellelperioodil	?sellelperioodil =sellelperioodil  (SgN  >sellelperioodil !02_S	et	f	\N
123703	kasuks	kasuks =kasu  (SgTr  >kasu !17_S	et	f	\N
123704	kasuks	kasuks =uks  (SgN  >kas+uks !14_S	et	f	\N
123713	1838a	### 1838a	et	f	\N
123716	strotug	### strotug	et	f	\N
123718	vallutamist	vallutamist =vallutamis  (SgP  >vallutamine !12_S	et	f	\N
123719	vallutamist	"vallutamine %valluta  )MINE_vS  <vallutama ;27_V	et	f	\N
123735	eesti-	eesti- =eesti  (ID  >eesti !41_G	et	f	\N
123736	eesti-	eesti- =eesti  (SgN  >eesti !16_H	et	f	\N
123737	eesti-	eesti- =eesti  (SgG  >eesti !16_H	et	f	\N
123738	koosseisus	koosseisus =seisu  (SgIn  >koos+seis !22_S	et	f	\N
123739	koosseisus	koosseisus =seisus  (SgN  >koos+seisus !11~09_S	et	f	\N
123747	kohtukeeleks	kohtukeeleks =keele  (SgTr  >kohtu+keel !13_S	et	f	\N
123748	kohtukeeleks	kohtukeeleks =keele  (PlTr  >kohtu+keeld !22_S	et	f	\N
123749	kehtisid	kehtisid =kehti  (IndIpfSg2  >kehtima !27_V	et	f	\N
123750	kehtisid	kehtisid =kehti  (IndIpfPl3  >kehtima !27_V	et	f	\N
123774	sellinne	?sellinne =sellinne  (SgN  >sellinne !02_A	et	f	\N
123775	sellinne	?sellinne =sellinne  (PlP  >sellinn !22_S	et	f	\N
123778	armeesse	armeesse =armee  (SgIll  >armee !26_S	et	f	\N
123779	armeesse	armeesse =armees  (SgAdt  >armeene !12_A	et	f	\N
123780	armeesse	"armeene %armee  )NE_aA  <armee ;26_S	et	f	\N
123802	estofiile	estofiile =estofiile  (PlP  >estofiil !22_S	et	f	\N
123803	estofiile	estofiile =fii  (SgAll  >esto+fii !26_S	et	f	\N
123828	tegutsenud	tegutsenud =tegutse  (PtsPtPs  >tegutsema !27_V	et	f	\N
123829	tegutsenud	tegutsenud =tegutsenu  (PlN  >tegutsenu !01_S	et	f	\N
123830	tegutsenud	"tegutsenu %tegutse  )NU_vS  <tegutsema ;27_V	et	f	\N
123831	tegutsenud	tegutsenud =tegutsenud  (ID  >tegutsenud !41_A	et	f	\N
123832	tegutsenud	"tegutsenud %tegutse  )NUD_vA  <tegutsema ;27_V	et	f	\N
123853	hostel	?hostel =hoste  (SgAd  >hoste !06_S	et	f	\N
123854	hostel	?hostel =hoste  (PlAd  >host !22_S	et	f	\N
123856	hostel	?hostel =hostel  (SgN  >hostel !02_S	et	f	\N
123860	gruppiga	### gruppiga	et	f	\N
123863	käsmusse	?käsmusse =käsmu  (SgIll  >käsmu !16_S	et	f	\N
123864	käsmusse	?käsmusse =käsmus  (SgAdt  >käsmus !11_S	et	f	\N
123865	käsmusse	?käsmusse =käsmusse  (SgG  >käsmusne !02_A	et	f	\N
123866	käsmusse	?käsmusse =käsmusse  (PlP  >käsmuss !22_S	et	f	\N
123897	neiu	neiu =neiu  (SgN  >neiu !16_S	et	f	\N
123898	neiu	neiu =neiu  (SgG  >neiu !16_S	et	f	\N
123899	neiu	neiu =neiu  (SgG  >neid !22_S	et	f	\N
123900	bella	?bella =bella  (SgN  >bella !16_S	et	f	\N
123901	bella	?bella =bella  (SgG  >bella !16_S	et	f	\N
123902	bella	?bella =bella  (IndPrPs_  >bellama !29_V	et	f	\N
123903	bella	?bella =bella  (ImpPrSg2  >bellama !29_V	et	f	\N
123911	viiene	viiene =viiene  (SgN  >viiene !10_AS	et	f	\N
123912	viiene	"viiene %viie  )NE_aA  <viis ;14_N	et	f	\N
123923	tütarlaps	tütarlaps =laps  (SgN  >tütar+laps !14_S	et	f	\N
123544	toimumise	"toimumine %toimu  )MINE_vS  <toimuma ;27_V	et	f	\N
123552	kujutlev	kujutlev =kujutle  (PtsPrPs  >kujutlema !27_V	et	f	\N
123553	kujutlev	kujutlev =kujutlev  (SgN  >kujutlev !02_A	et	f	\N
123554	kujutlev	"kujutlev %kujutle  )V_vA  <kujutlema ;27_V	et	f	\N
123560	õigustatud	õigustatud =õigusta  (PtsPtIps  >õigustama !27_V	et	f	\N
123561	õigustatud	õigustatud =õigustatu  (PlN  >õigustatu !01_S	et	f	\N
123562	õigustatud	"õigustatu %õigusta  )TU1_vS  <õigustama ;27_V	et	f	\N
123563	õigustatud	õigustatud =õigustatud  (ID  >õigustatud !41_A	et	f	\N
123564	õigustatud	"õigustatud %õigusta  )TUD_vA  <õigustama ;27_V	et	f	\N
123565	õigustatud	õigustatud =atu  (PlN  >õigust+att !22_S	et	f	\N
123573	kõhuvalus	kõhuvalus =valu  (SgIn  >kõhu+valu !17_S	et	f	\N
123574	kõhuvalus	kõhuvalus =valus  (SgN  >kõhu+valus !02_A	et	f	\N
123579	hoolde	hoolde =hool  (SgAdt  >hool !13_S	et	f	\N
123580	hoolde	hoolde =hoolde  (SgG  >hoole !06_S	et	f	\N
123598	faehlmann	?faehlmann =faehlmann  (SgN  >faehlmann !22_S	et	f	\N
123604	säilitamisega	säilitamisega =säilitamise  (SgKom  >säilitamine !12_S	et	f	\N
123605	säilitamisega	"säilitamine %säilita  )MINE_vS  <säilitama ;27_V	et	f	\N
123606	kirjutamisega	kirjutamisega =kirjutamise  (SgKom  >kirjutamine !12_S	et	f	\N
123607	kirjutamisega	"kirjutamine %kirjuta  )MINE_vS  <kirjutama ;27_V	et	f	\N
123649	valgustusajastu	valgustusajastu =ajastu  (SgN  >valgustus+ajastu !01_S	et	f	\N
123650	valgustusajastu	valgustusajastu =ajastu  (SgG  >valgustus+ajastu !01_S	et	f	\N
123660	valgustus	valgustus =valgustu  (IndIpfSg3  >valgustuma !27_V	et	f	\N
123661	valgustus	valgustus =valgustus  (SgN  >valgustus !11_S	et	f	\N
123662	valgustus	"valgustus %valgusta  )US_vS  <valgustama ;27_V	et	f	\N
123663	valgustus	valgustus =ustu  (SgIn  >valg+ustu !01_S	et	f	\N
123673	saavutustele	saavutustele =saavutus  (PlAll  >saavutus !11_S	et	f	\N
123674	saavutustele	"saavutus %saavuta  )US_vS  <saavutama ;27_V	et	f	\N
123682	monarhia	monarhia =monarhia  (SgN  >monarhia !01_S	et	f	\N
123684	monarhia	monarhia =monarhia  (SgG  >monarhia !01_S	et	f	\N
123696	herder	?herder =herder  (SgN  >herder !02_S	et	f	\N
123701	erikorda	erikorda =korda  (SgP  >eri+kord !22_S	et	f	\N
123702	erikorda	erikorda =korda  (SgAdt  >eri+kord !22_S	et	f	\N
123706	kultuurilooga	kultuurilooga =loo  (SgKom  >kultuuri+lugu !18_S	et	f	\N
123707	kultuurilooga	kultuurilooga =loo  (SgKom  >kultuuri+loog !22_S	et	f	\N
123708	kultuurilooga	kultuurilooga =loo  (SgKom  >kultuuri+lood !22_S	et	f	\N
123709	kultuurilooga	kultuurilooga =looga  (SgG  >kultuuri+look !22_S	et	f	\N
123725	peterbusis	?peterbusis =peterbusi  (PlIn  >peterbus !11_S	et	f	\N
123727	peterbusis	?peterbusis =peterbusis  (SgN  >peterbusis !09_S	et	f	\N
123759	säilimine	säilimine =säilimine  (SgN  >säilimine !12_S	et	f	\N
123760	säilimine	"säilimine %säili  )MINE_vS  <säilima ;28_V	et	f	\N
123763	assimileerimine	assimileerimine =assimileerimine  (SgN  >assimileerimine !12_S	et	f	\N
123765	assimileerimine	"assimileerimine %assimileeri  )MINE_vS  <assimileerima ;28_V	et	f	\N
123776	algusaastatel	algusaastatel =tate  (PlAd  >algus+aas+tatt !22_S	et	f	\N
123777	algusaastatel	algusaastatel =aasta  (PlAd  >algus+aasta !01_S	et	f	\N
123781	julgelt	julgelt =julge  (SgAbl  >julge !01_A	et	f	\N
123782	julgelt	julgelt =julge  (PlAbl  >julk !22_S	et	f	\N
123783	julgelt	julgelt =julgelt  (ID  >julgelt !41_D	et	f	\N
123784	julgelt	"julgelt %julge  )LT_mD  <julge ;01_A	et	f	\N
123797	muutustega	muutustega =muutus  (PlKom  >muutus !11~09_S	et	f	\N
123798	muutustega	"muutus %muu  )TUS2_aS  <muu ;26_S	et	f	\N
123799	faehmann	?faehmann =faehmann  (SgN  >faehmann !22_S	et	f	\N
123809	suulist	suulist =suulis  (SgP  >suuline !12?10_AS	et	f	\N
123810	suulist	"suuline %suu  )LINE_aA  <suu ;26_S	et	f	\N
123814	faelmanni	?faelmanni =faelmanni  (SgN  >faelmanni !01_S	et	f	\N
123815	faelmanni	?faelmanni =faelmanni  (SgG  >faelmanni !01_S	et	f	\N
123816	faelmanni	?faelmanni =faelmanni  (SgG  >faelmann !22_S	et	f	\N
123818	faelmanni	?faelmanni =faelmanni  (SgP  >faelmann !22_S	et	f	\N
123819	faelmanni	?faelmanni =faelmanni  (SgAdt  >faelmann !22_S	et	f	\N
123821	faelmanni	?faelmanni =faelmanni  (IndPrPs_  >faelmannima !28_V	et	f	\N
123822	faelmanni	?faelmanni =faelmanni  (ImpPrSg2  >faelmannima !28_V	et	f	\N
123836	rahvaloo	rahvaloo =loo  (SgG  >rahva+lugu !18_S	et	f	\N
123837	rahvaloo	rahvaloo =loo  (SgG  >rahva+loog !22_S	et	f	\N
123838	rahvaloo	rahvaloo =loo  (SgG  >rahva+lood !22_S	et	f	\N
123855	academic	### academic	et	f	\N
123867	narvasse	?narvasse =narva  (SgIll  >narva !16_S	et	f	\N
123868	narvasse	?narvasse =narvasse  (SgG  >narvasne !02_A	et	f	\N
123869	narvasse	?narvasse =narvasse  (PlP  >narvass !22_S	et	f	\N
123879	pidasis	?pidasis =pidasis  (SgN  >pidasis !11_S	et	f	\N
123886	uinuv	uinuv =uinu  (PtsPrPs  >uinuma !27_V	et	f	\N
123887	uinuv	uinuv =uinuv  (SgN  >uinuv !02_A	et	f	\N
123888	uinuv	"uinuv %uinu  )V_vA  <uinuma ;27_V	et	f	\N
123889	tavalises	tavalises =tavalise  (SgIn  >tavaline !12_A	et	f	\N
123890	tavalises	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
123904	seitseteist	seitseteist =te  (PlEl  >seitse+tee !26_S	et	f	\N
123905	seitseteist	seitseteist =teist  (SgN  >seitse+teist !22_S	et	f	\N
123651	suhtlesid	suhtlesid =suhtle  (IndIpfSg2  >suhtlema !30_V	et	f	\N
123652	suhtlesid	suhtlesid =suhtle  (IndIpfPl3  >suhtlema !30_V	et	f	\N
123653	emakeeles	emakeeles =keele  (SgIn  >ema+keel !13_S	et	f	\N
123654	emakeeles	emakeeles =keele  (PlIn  >ema+keeld !22_S	et	f	\N
123655	levisid	levisid =levi  (PlP  >levi !17_S	et	f	\N
123656	levisid	levisid =levi  (IndIpfSg2  >levima !27_V	et	f	\N
123657	levisid	levisid =levi  (IndIpfPl3  >levima !27_V	et	f	\N
123688	teadmistega	teadmistega =teadmis  (PlKom  >teadmine !12?10_S	et	f	\N
123691	teadmistega	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
123717	baltisakslaste	baltisakslaste =las  (PlG  >balt+isaks+laps !14_S	et	f	\N
123720	baltisakslaste	baltisakslaste =laste  (PlP  >balt+isaks+last !22_S	et	f	\N
123721	baltisakslaste	baltisakslaste =sakslas  (PlG  >balti+sakslane !12?10_S	et	f	\N
123733	baltisaksasoost	baltisaksasoost =soo  (SgEl  >balti+saksa+sugu !18_S	et	f	\N
123734	baltisaksasoost	baltisaksasoost =soo  (SgEl  >balti+saksa+soo !26_S	et	f	\N
123740	valiseva	?valiseva =valiseva  (SgN  >valiseva !16_S	et	f	\N
123741	valiseva	?valiseva =valiseva  (SgG  >valisev !02_A	et	f	\N
123742	valiseva	?valiseva =valiseva  (SgG  >valiseva !16_S	et	f	\N
123743	valitsevaks	valitsevaks =valitseva  (SgTr  >valitsev !02_A	et	f	\N
123744	valitsevaks	"valitsev %valitse  )V_vA  <valitsema ;27_V	et	f	\N
123757	rehkendamise	rehkendamise =rehkendamise  (SgG  >rehkendamine !12_S	et	f	\N
123758	rehkendamise	"rehkendamine %rehkenda  )MINE_vS  <rehkendama ;27_V	et	f	\N
123770	saksastumine	saksastumine =saksastumine  (SgN  >saksastumine !12_S	et	f	\N
123771	saksastumine	"saksastumine %saksastu  )MINE_vS  <saksastuma ;27_V	et	f	\N
123785	saadik	saadik =saadik  (ID  >saadik !41_DK	et	f	\N
123786	saadik	saadik =saadik  (SgN  >saadik !02_S	et	f	\N
123817	vägilasmuistendite	?vägilasmuistendite =vägilasmuistendi  (IndPrPl2  >vägilasmuistentima !28_V	et	f	\N
123833	kalevipoega	kalevipoega =poe  (SgKom  >kalevi+pood !22_S	et	f	\N
123834	kalevipoega	kalevipoega =poega  (SgP  >kalevi+poeg !22_S	et	f	\N
123835	kalevipoega	kalevipoega =poega  (SgAdt  >kalevi+poeg !22_S	et	f	\N
123845	laulsid	laulsid =laul  (IndIpfSg2  >laulma !33_V	et	f	\N
123846	laulsid	laulsid =laul  (IndIpfPl3  >laulma !33_V	et	f	\N
123847	paistsis	?paistsis =paistsi  (SgIn  >paists !22_S	et	f	\N
123848	paistsis	?paistsis =paistsi  (IndIpfSg3  >paistsima !28_V	et	f	\N
123849	paistsis	?paistsis =paistsis  (SgN  >paistsis !09_S	et	f	\N
123880	päivitasime	?päivitasime =päivita  (IndIpfPl1  >päivitama !27_V	et	f	\N
123881	söime	?söime =söime  (SgN  >söime !06_S	et	f	\N
123882	söime	?söime =söime  (SgG  >söime !06_S	et	f	\N
123883	söime	?söime =söime  (PlP  >söim !22_S	et	f	\N
123884	söime	?söime =söime  (IndPrPs_  >söimema !27_V	et	f	\N
123885	söime	?söime =söime  (ImpPrSg2  >söimema !27_V	et	f	\N
123891	viiekorruselises	viiekorruselises =korruselise  (SgIn  >viie+korruseline !12_A	et	f	\N
123892	viiekorruselises	"viie+korruseline %korruse  )LINE_aA  <viie+korrus ;09_S	et	f	\N
123893	tavalistes	tavalistes =tavalis  (PlIn  >tavaline !12_A	et	f	\N
123894	tavalistes	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
123906	viieteistaastaselt	viieteistaastaselt =aastase  (SgAbl  >viie+teist+aastane !12~10_A	et	f	\N
123907	viieteistaastaselt	"viie+teist+aastane %aasta  )NE_aA  <viie+teist+aasta ;01_S	et	f	\N
123908	viieteistaastaselt	"viie+teist+aastaselt %aasta  )SELT_mD  <viie+teist+aasta ;01_S	et	f	\N
123909	viieteistaastaselt	"viie+teist+aastaselt %aastase  )LT_mD  <viie+teist+aastane ;10_A	et	f	\N
123910	viieteistaastaselt	"viie+teist+aastaselt %aastase  )LT_mD  <viie+teist+aastane ;12_A	et	f	\N
123916	roosad	roosad =roosa  (PlN  >roosa !16_AS	et	f	\N
123918	roosad	roosad =roosa  (PlN  >roosk !22_S	et	f	\N
123919	imekaunis	imekaunis =kauni  (SgIn  >ime+kaunis !05~07_A	et	f	\N
123920	imekaunis	imekaunis =kauni  (SgIn  >ime+kaun !22_S	et	f	\N
123921	imekaunis	imekaunis =kauni  (PlIn  >ime+kaun !22_S	et	f	\N
123922	imekaunis	imekaunis =kaunis  (SgN  >ime+kaunis !05~07_A	et	f	\N
123925	kasutanud	kasutanud =kasuta  (PtsPtPs  >kasutama !27_V	et	f	\N
123926	kasutanud	kasutanud =kasutanu  (PlN  >kasutanu !01_S	et	f	\N
123927	kasutanud	"kasutanu %kasuta  )NU_vS  <kasutama ;27_V	et	f	\N
123928	kasutanud	kasutanud =kasutanud  (ID  >kasutanud !41_A	et	f	\N
123929	kasutanud	"kasutanud %kasuta  )NUD_vA  <kasutama ;27_V	et	f	\N
123930	kasutanud	kasutanud =tanu  (PlN  >kasu+tanu !17_S	et	f	\N
123932	päikesepaistelisel	päikesepaistelisel =paistelise  (SgAd  >päikese+paisteline !12_A	et	f	\N
123934	päikesepaistelisel	"päikese+paisteline %paiste  )LINE_aA  <päikese+paiste ;06_S	et	f	\N
123935	sünnipäevapeole	sünnipäevapeole =peo  (SgAll  >sünni+päeva+pidu !18_S	et	f	\N
123936	sünnipäevapeole	sünnipäevapeole =peo  (SgAll  >sünni+päeva+peo !26_S	et	f	\N
123943	punast	punast =puna  (SgEl  >puna !17_S	et	f	\N
123944	punast	punast =punas  (SgP  >punane !10_AS	et	f	\N
123945	punast	"punane %puna  )NE_aA  <puna ;17_S	et	f	\N
123952	kingitus	kingitus =kingitu  (SgIn  >kingitu !01_AS	et	f	\N
123953	kingitus	"kingitu %kingi  )TU1_vS  <kinkima ;28_V	et	f	\N
123955	kingitus	"kingitu %kingi  )TU2_kA  <kink ;22_S	et	f	\N
123957	kingitus	kingitus =kingitus  (SgN  >kingitus !11_S	et	f	\N
123958	kingitus	"kingitus %kingi  )TUS1_aS  <kinkima ;28_V	et	f	\N
123699	rahvaluule	rahvaluule =luule  (SgG  >rahva+luule !06_S	et	f	\N
123700	rahvaluule	rahvaluule =luule  (PlP  >rahva+luul !22_S	et	f	\N
123710	taibas	?taibas =taiba  (SgIn  >taiba !16_S	et	f	\N
123711	taibas	?taibas =taiba  (IndIpfSg3  >taibama !29_V	et	f	\N
123712	taibas	?taibas =taibas  (SgN  >taibas !07_S	et	f	\N
123731	pististikolleegium	?pististikolleegium =pististikolleegium  (SgN  >pististikolleegium !19~02_S	et	f	\N
123732	pististikolleegium	?pististikolleegium =istikolleegium  (SgN  >pist+istikolleegium !19~02_S	et	f	\N
123745	asjaajamis-	asjaajamis- =mi  (SgIn  >asja+aja+mi !26_S	et	f	\N
123746	asjaajamis-	asjaajamis- =ajami  (SgIn  >asja+ajam !02_S	et	f	\N
123753	tabamiseks	tabamiseks =tabamise  (SgTr  >tabamine !12_S	et	f	\N
123754	tabamiseks	"tabamine %taba  )MINE_vS  <tabama ;27_V	et	f	\N
123755	harimisel	harimisel =harimise  (SgAd  >harimine !12_S	et	f	\N
123756	harimisel	"harimine %hari  )MINE_vS  <harima ;27_V	et	f	\N
123768	venestumine	venestumine =venestumine  (SgN  >venestumine !12_S	et	f	\N
123769	venestumine	"venestumine %venestu  )MINE_vS  <venestuma ;27_V	et	f	\N
123772	rajamiseks	rajamiseks =rajamise  (SgTr  >rajamine !12_S	et	f	\N
123773	rajamiseks	"rajamine %raja  )MINE_vS  <rajama ;27_V	et	f	\N
123787	juurdunud	juurdunud =juurdu  (PtsPtPs  >juurduma !27_V	et	f	\N
123788	juurdunud	juurdunud =juurdunu  (PlN  >juurdunu !01_S	et	f	\N
123789	juurdunud	"juurdunu %juurdu  )NU_vS  <juurduma ;27_V	et	f	\N
123790	juurdunud	juurdunud =juurdunud  (ID  >juurdunud !41_A	et	f	\N
123791	juurdunud	"juurdunud %juurdu  )NUD_vA  <juurduma ;27_V	et	f	\N
123792	väiksemal	väiksemal =väiksema  (SgAd  >väiksem !02_A	et	f	\N
123793	väiksemal	"väiksem %väikse  )M_cA  <väike ;10_A	et	f	\N
123870	ursula	?ursula =ursula  (SgN  >ursula !01_S	et	f	\N
123871	ursula	?ursula =ursula  (SgG  >ursula !01_S	et	f	\N
123877	ettekannet	ettekannet =kanne  (SgP  >ette+kanne !05_S	et	f	\N
123878	ettekannet	ettekannet =kanne  (SgP  >ette+kanne !06_S	et	f	\N
123895	kolmetoalises	kolmetoalises =toalise  (SgIn  >kolme+toaline !12?10_A	et	f	\N
123896	kolmetoalises	"kolme+toaline %toa  )LINE_aA  <kolme+tuba ;18_S	et	f	\N
123913	pikad	pikad =pika  (PlN  >pikk !22_S	et	f	\N
123914	pikad	pikad =pika  (PlN  >pikk !22_AS	et	f	\N
123931	kevadisel	kevadisel =kevadise  (SgAd  >kevadine !12_A	et	f	\N
123933	kevadisel	"kevadine %kevadi  )NE_aA  <kevad ;02_S	et	f	\N
123937	artur	?artur =artur  (SgN  >artur !02_S	et	f	\N
123954	võrreldagi	võrreldagi =võrrel  (Inf^  >võrdlema !30_V	et	f	\N
123956	võrreldagi	võrreldagi =võrrel  (IndPrIps_^  >võrdlema !30_V	et	f	\N
123978	bellat	?bellat =bella  (SgP  >bella !16_S	et	f	\N
123979	bellat	?bellat =bellat  (SgN  >bellat !02_S	et	f	\N
123990	kahvatuks	kahvatuks =kahvatu  (SgTr  >kahvatu !01_A	et	f	\N
123991	kahvatuks	"kahvatu %kahva  )TU2_kA  <kahv ;22_S	et	f	\N
123992	kahvatuks	kahvatuks =kahvatu  (KndPrPs  >kahvatuma !27_V	et	f	\N
124000	puutus	puutus =puutu  (SgIn  >puutu !01_A	et	f	\N
124001	puutus	"puutu %puu  )TU2_kA  <puu ;26_S	et	f	\N
124002	puutus	puutus =puutu  (IndIpfSg3  >puutuma !27_V	et	f	\N
124003	puutus	puutus =puutus  (SgN  >puutus !11~09_S	et	f	\N
124004	puutus	"puutus %puu  )TUS2_aS  <puu ;26_S	et	f	\N
124019	naersid	naersid =naer  (IndIpfSg2  >naerma !33_V	et	f	\N
124020	naersid	naersid =naer  (IndIpfPl3  >naerma !33_V	et	f	\N
124031	gerda	?gerda =gerda  (SgN  >gerda !16_S	et	f	\N
124033	gerda	?gerda =gerda  (SgG  >gerda !16_S	et	f	\N
124035	gerda	?gerda =gerda  (IndPrPs_  >gerdama !29_V	et	f	\N
124036	gerda	?gerda =gerda  (ImpPrSg2  >gerdama !29_V	et	f	\N
124042	kolmekorruselises	kolmekorruselises =korruselise  (SgIn  >kolme+korruseline !12_A	et	f	\N
124043	kolmekorruselises	"kolme+korruseline %korruse  )LINE_aA  <kolme+korrus ;09_S	et	f	\N
124055	kuninganna	kuninganna =kuninganna  (SgN  >kuninganna !16_S	et	f	\N
124056	kuninganna	kuninganna =kuninganna  (SgG  >kuninganna !16_S	et	f	\N
124057	kuninganna	kuninganna =anna  (SgN  >kuning+anna !16_S	et	f	\N
124058	kuninganna	kuninganna =anna  (SgG  >kuning+anna !16_S	et	f	\N
124064	nägid	nägid =näg  (IndIpfSg2  >nägema !28_V	et	f	\N
124065	nägid	nägid =näg  (IndIpfPl3  >nägema !28_V	et	f	\N
124083	rahulikult	rahulikult =rahuliku  (SgAbl  >rahulik !25_A	et	f	\N
124084	rahulikult	rahulikult =rahulikult  (ID  >rahulikult !41_D	et	f	\N
124085	rahulikult	"rahulikult %rahuliku  )LT_mD  <rahulik ;25_A	et	f	\N
124092	kuningannaga	kuningannaga =kuninganna  (SgKom  >kuninganna !16_S	et	f	\N
124093	kuningannaga	kuningannaga =anna  (SgKom  >kuning+anna !16_S	et	f	\N
124124	taignast	taignast =taigna  (SgEl  >taigen !02_S	et	f	\N
124125	taignast	taignast =taignas  (SgP  >taignane !12~10_A	et	f	\N
124126	taignast	"taignane %taigna  )NE_aA  <taigen ;02_S	et	f	\N
124139	otsustasid	otsustasid =otsusta  (IndIpfSg2  >otsustama !27_V	et	f	\N
124140	otsustasid	otsustasid =otsusta  (IndIpfPl3  >otsustama !27_V	et	f	\N
124141	mikrolaineahju	mikrolaineahju =ahju  (SgG  >mikro+laine+ahi !24_S	et	f	\N
124142	mikrolaineahju	mikrolaineahju =ahju  (SgP  >mikro+laine+ahi !24_S	et	f	\N
124143	mikrolaineahju	mikrolaineahju =ahju  (SgAdt  >mikro+laine+ahi !24_S	et	f	\N
124168	centrum	?centrum =centrum  (SgN  >centrum !02_S	et	f	\N
124172	karu	karu =karu  (SgN  >karu !17_S	et	f	\N
123804	kuulunud	kuulunud =kuulu  (PtsPtPs  >kuuluma !27_V	et	f	\N
123805	kuulunud	kuulunud =kuulunu  (PlN  >kuulunu !01_S	et	f	\N
123806	kuulunud	"kuulunu %kuulu  )NU_vS  <kuuluma ;27_V	et	f	\N
123807	kuulunud	kuulunud =kuulunud  (ID  >kuulunud !41_A	et	f	\N
123808	kuulunud	"kuulunud %kuulu  )NUD_vA  <kuuluma ;27_V	et	f	\N
123811	pärimust	pärimust =pärimus  (SgP  >pärimus !11_S	et	f	\N
123812	pärimust	"pärimus %päri  )MUS_vS  <pärima ;27_V	et	f	\N
123813	pärimust	pärimust =must  (SgN  >päri+must !22_AS	et	f	\N
123820	kogumisse	kogumisse =kogumi  (SgIll  >kogum !02_S	et	f	\N
123823	kogumisse	kogumisse =kogumis  (SgAdt  >kogumine !12_S	et	f	\N
123824	kogumisse	"kogumine %kogu  )MINE_vS  <koguma ;27_V	et	f	\N
123825	kogumisse	"kogumine %kogumi  )NE_aA  <kogum ;02_S	et	f	\N
123826	kogumisse	kogumisse =mi  (SgIll  >kogu+mi !26_S	et	f	\N
123827	kogumisse	kogumisse =misse  (PlP  >kogu+miss !22_S	et	f	\N
123839	uurimisega	uurimisega =uurimise  (SgKom  >uurimine !12_S	et	f	\N
123840	uurimisega	"uurimine %uuri  )MINE_vS  <uurima ;28_V	et	f	\N
123841	berliinis	?berliinis =berliini  (SgIn  >berliini !16_S	et	f	\N
123842	berliinis	?berliinis =berliini  (SgIn  >berliin !22_S	et	f	\N
123843	berliinis	?berliinis =berliini  (IndIpfSg3  >berliinima !28_V	et	f	\N
123844	berliinis	?berliinis =berliinis  (SgN  >berliinis !09_S	et	f	\N
123850	lendasis	?lendasis =lendasis  (SgN  >lendasis !11_S	et	f	\N
123851	lendasis	?lendasis =asis  (SgN  >lend+asis !09_S	et	f	\N
123852	kun	### kun	et	f	\N
123857	väikes	?väikes =väike  (SgIn  >väige !06_S	et	f	\N
123858	väikes	?väikes =väike  (IndIpfSg3  >väikema !27_V	et	f	\N
123859	väikes	?väikes =väikes  (SgN  >väikes !09_S	et	f	\N
123861	lahemaa	lahemaa =maa  (SgN  >lahe+maa !26_S	et	f	\N
123862	lahemaa	lahemaa =maa  (SgG  >lahe+maa !26_S	et	f	\N
123872	narvale	?narvale =narva  (SgAll  >narva !16_S	et	f	\N
123873	narvale	?narvale =narvale  (IndPrPs_  >narvalema !27_V	et	f	\N
123874	narvale	?narvale =narvale  (ImpPrSg2  >narvalema !27_V	et	f	\N
123875	anneli	?anneli =anneli  (ID  >anneli !41_D	et	f	\N
123876	anneli	?anneli =anneli  (SgG  >annel !02_S	et	f	\N
123915	põõsed	?põõsed =põõse  (PlN  >põõse !06_S	et	f	\N
123917	põõsed	?põõsed =põõse  (IndPrSg2  >põõsema !28_V	et	f	\N
123949	kullast	kullast =kulla  (SgEl  >kuld !22_S	et	f	\N
123950	kullast	kullast =kullas  (SgP  >kullane !10_A	et	f	\N
123951	kullast	"kullane %kulla  )NE_aA  <kuld ;22_S	et	f	\N
123960	roosid	roosid =roo  (PlP  >roo !26_S	et	f	\N
123961	roosid	roosid =roosi  (PlN  >roos !22_S	et	f	\N
123972	põsemusi	põsemusi =musi  (SgN  >põse+musi !17_S	et	f	\N
123973	põsemusi	põsemusi =musi  (SgG  >põse+musi !17_S	et	f	\N
123974	põsemusi	põsemusi =musi  (SgP  >põse+musi !17_S	et	f	\N
123982	hingetuna	hingetuna =hingetu  (SgEs  >hingetu !01_A	et	f	\N
123983	hingetuna	"hingetu %hinge  )TU2_kA  <hing ;22_S	et	f	\N
124011	teadvusele	teadvusele =teadvuse  (SgAll  >teadvus !11~09_S	et	f	\N
124012	teadvusele	"teadvus %tead  )VUS_aS  <teadma ;34_V	et	f	\N
124013	teadvusele	"teadvus %teadva  )US_aS  <teadev ;02_A	et	f	\N
124014	teadvuse	teadvuse =teadvuse  (SgG  >teadvus !11~09_S	et	f	\N
124015	teadvuse	"teadvus %tead  )VUS_aS  <teadma ;34_V	et	f	\N
124016	teadvuse	"teadvus %teadva  )US_aS  <teadev ;02_A	et	f	\N
124021	tantsisid	tantsisid =tantsi  (PlP  >tants !22_S	et	f	\N
124022	tantsisid	tantsisid =tantsi  (IndIpfSg2  >tantsima !28_V	et	f	\N
124023	tantsisid	tantsisid =tantsi  (IndIpfPl3  >tantsima !28_V	et	f	\N
124047	kail	kail =kai  (SgAd  >kai !26_S	et	f	\N
124048	kail	kail =kail  (SgN  >kail !22_S	et	f	\N
124062	vestlesid	vestlesid =vestle  (IndIpfSg2  >vestlema !30_V	et	f	\N
124063	vestlesid	vestlesid =vestle  (IndIpfPl3  >vestlema !30_V	et	f	\N
124071	kuri	?kuri =kuri  (SgN  >kuri !24_A	et	f	\N
124072	kuri	?kuri =kuri  (IndPrPs_  >kurima !27_V	et	f	\N
124073	kuri	?kuri =kuri  (ImpPrSg2  >kurima !27_V	et	f	\N
124090	nähes	nähes =näh  (Ger  >nägema !28_V	et	f	\N
124091	nähes	nähes =nähe  (PlIn  >näht !22_S	et	f	\N
124099	politseinikule	politseinikule =politseiniku  (SgAll  >politseinik !25_S	et	f	\N
124100	politseinikule	politseinikule =politseiniku  (SgAll  >politseinik !02_S	et	f	\N
124117	kakuke	kakuke =kakuke  (SgN  >kakuke !12_S	et	f	\N
124118	kakuke	"kakuke %kaku  )KE_dS  <kakk ;22_S	et	f	\N
124136	ideest	ideest =idee  (SgEl  >idee !26_S	et	f	\N
124137	ideest	ideest =idees  (SgP  >ideene !12~10_A	et	f	\N
124138	ideest	"ideene %idee  )NE_aA  <idee ;26_S	et	f	\N
124144	lapseke	lapseke =lapseke  (SgN  >lapseke !12_S	et	f	\N
124145	lapseke	"lapseke %lapse  )KE_dS  <laps ;14_S	et	f	\N
124157	õnneks	õnneks =õnne  (SgTr  >õnn !22_S	et	f	\N
124158	õnneks	õnneks =õnne  (PlTr  >õnn !22_S	et	f	\N
124166	kauplust	kauplust =kauplus  (SgP  >kauplus !11~09_S	et	f	\N
124167	kauplust	kauplust =lust  (SgN  >kaup+lust !22_S	et	f	\N
124195	rebane	rebane =rebane  (SgN  >rebane !10_S	et	f	\N
124196	rebane	"rebane %reba  )NE_aA  <reba ;17_S	et	f	\N
124211	köögiaknast	köögiaknast =akna  (SgEl  >köögi+aken !08_S	et	f	\N
124212	köögiaknast	köögiaknast =aknas  (SgP  >köögi+aknane !12~10_A	et	f	\N
123924	tütarlaps	tütarlaps =laps  (SgN  >tütar+laps !22_S	et	f	\N
123938	bellale	?bellale =bella  (SgAll  >bella !16_S	et	f	\N
123939	bellale	?bellale =bellale  (IndPrPs_  >bellalema !27_V	et	f	\N
123940	bellale	?bellale =bellale  (ImpPrSg2  >bellalema !27_V	et	f	\N
123941	tütarlapsele	tütarlapsele =lapse  (SgAll  >tütar+laps !14_S	et	f	\N
123942	tütarlapsele	tütarlapsele =lapse  (PlAll  >tütar+laps !22_S	et	f	\N
123946	roosi	roosi =roosi  (SgG  >roos !22_S	et	f	\N
123947	roosi	roosi =roosi  (SgP  >roos !22_S	et	f	\N
123948	roosi	roosi =roosi  (SgAdt  >roos !22_S	et	f	\N
123962	erinevat	erinevat =erine  (KvtPrPs  >erinema !27_V	et	f	\N
123963	erinevat	erinevat =erineva  (SgP  >erinev !02_A	et	f	\N
123964	erinevat	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
123970	arturile	?arturile =arturi  (SgAll  >arturi !01_S	et	f	\N
123971	arturile	?arturile =arturi  (SgAll  >artur !02_S	et	f	\N
123980	toimetati	toimetati =toimeta  (IndIpfIps  >toimetama !27_V	et	f	\N
123981	toimetati	toimetati =tati  (SgG  >toime+tatt !22_S	et	f	\N
123997	põlvele	põlvele =põlve  (SgAll  >põlv !22_S	et	f	\N
123998	põlvele	põlvele =põlve  (SgAll  >põli !24_S	et	f	\N
123999	põlvele	põlvele =põlve  (PlAll  >põlv !22_S	et	f	\N
124005	sinitu	?sinitu =sinitu  (SgN  >sinitu !01_AS	et	f	\N
124006	sinitu	?sinitu =sinitu  (SgG  >sinitu !01_AS	et	f	\N
124009	sinitu	?sinitu =sinitu  (IndPrPs_  >sinituma !27_V	et	f	\N
124010	sinitu	?sinitu =sinitu  (ImpPrSg2  >sinituma !27_V	et	f	\N
124024	arturi	?arturi =arturi  (SgN  >arturi !01_S	et	f	\N
124025	arturi	?arturi =arturi  (SgG  >arturi !01_S	et	f	\N
124026	arturi	?arturi =arturi  (SgG  >artur !02_S	et	f	\N
124040	asuvas	asuvas =asuva  (SgIn  >asuv !02_A	et	f	\N
124041	asuvas	"asuv %asu  )V_vA  <asuma ;27_V	et	f	\N
124049	vanaemake	vanaemake =emake  (SgN  >vana+emake !12_S	et	f	\N
124050	vanaemake	"vana+emake %ema  )KE_dS  <vana+ema ;17_S	et	f	\N
124051	öö-paev	?öö-paev =paev  (SgN  >öö-paev !22_S	et	f	\N
124059	laevale	laevale =laeva  (SgAll  >laev !22_S	et	f	\N
124060	laevale	laevale =vale  (SgN  >lae+vale !16_SA	et	f	\N
124061	laevale	laevale =vale  (SgG  >lae+vale !16_SA	et	f	\N
124079	kööki	kööki =kööki  (SgP  >köök !22_S	et	f	\N
124080	kööki	kööki =kööki  (SgAdt  >köök !22_S	et	f	\N
124088	majake	majake =majake  (SgN  >majake !12_S	et	f	\N
124089	majake	"majake %maja  )KE_dS  <maja ;17_S	et	f	\N
124096	tüdruke	?tüdruke =tüdruke  (SgN  >tüdruke !12_S	et	f	\N
124130	teeks	teeks =tee  (SgTr  >tee !26_S	et	f	\N
124131	teeks	teeks =tee  (KndPrPs  >tegema !28_V	et	f	\N
124146	käsi	käsi =käsi  (ID  >käsi !41_D	et	f	\N
124147	käsi	käsi =käsi  (SgN  >käsi !15_S	et	f	\N
124148	käsi	käsi =käsi  (PlP  >käsi !15_S	et	f	\N
124149	käsi	käsi =käsi  (IndPrPs_  >käskima !28_V	et	f	\N
124151	käsi	käsi =käsi  (ImpPrSg2  >käskima !28_V	et	f	\N
124159	juhtu	juhtu =juhtu  (SgP  >juht !22_S	et	f	\N
124160	juhtu	juhtu =juhtu  (SgAdt  >juht !22_S	et	f	\N
124161	juhtu	juhtu =juhtu  (IndPrPs_  >juhtuma !27_V	et	f	\N
124162	juhtu	juhtu =juhtu  (ImpPrSg2  >juhtuma !27_V	et	f	\N
124163	aknast	aknast =akna  (SgEl  >aken !08_S	et	f	\N
124164	aknast	aknast =aknas  (SgP  >aknane !12~10_A	et	f	\N
124165	aknast	"aknane %akna  )NE_aA  <aken ;08_S	et	f	\N
124201	nõustus	nõustus =nõustu  (IndIpfSg3  >nõustuma !27_V	et	f	\N
124202	nõustus	nõustus =nõustus  (SgN  >nõustus !11~09_S	et	f	\N
124203	nõustus	"nõustus %nõusta  )US_vS  <nõustama ;27_V	et	f	\N
124216	suusakurordil	?suusakurordil =suusakurordi  (SgAd  >suusakurort !22_S	et	f	\N
124217	suusakurordil	?suusakurordil =suusakurordil  (SgN  >suusakurordil !02_S	et	f	\N
124218	suusakurordil	?suusakurordil =kurordi  (SgAd  >suusa+kurordi !01_S	et	f	\N
124219	suusakurordil	?suusakurordil =kurordi  (SgAd  >suusa+kurort !22_S	et	f	\N
124220	suusakurordil	?suusakurordil =sakurordi  (SgAd  >suu+sakurort !22_S	et	f	\N
124221	suusakurordil	?suusakurordil =sakurordil  (SgN  >suu+sakurordil !02_S	et	f	\N
124251	ootamatusega	ootamatusega =ootamatuse  (SgKom  >ootamatus !11?09_S	et	f	\N
124252	ootamatusega	"ootamatus %oota  )MATUS_aS  <ootama ;29_V	et	f	\N
124257	tatöveeringut	?tatöveeringut =tatöveeringu  (SgP  >tatöveering !02_S	et	f	\N
124258	kunstrüpsmed	?kunstrüpsmed =rüpsme  (PlN  >kunst+rüpsme !06_S	et	f	\N
124279	päevast	päevast =päeva  (SgEl  >päev !22_S	et	f	\N
124280	päevast	päevast =päevas  (SgP  >päevane !10_A	et	f	\N
124281	päevast	"päevane %päeva  )NE_aA  <päev ;22_S	et	f	\N
124282	päevast	päevast =ast  (SgN  >päev+ast !22_S	et	f	\N
124301	ilu	ilu =ilu  (SgN  >ilu !17_S	et	f	\N
124302	ilu	ilu =ilu  (SgG  >ilu !17_S	et	f	\N
124303	ilu	ilu =ilu  (SgP  >ilu !17_S	et	f	\N
124308	armus	armus =armu  (SgIn  >arm !22_S	et	f	\N
124309	armus	armus =armu  (IndIpfSg3  >armuma !27_V	et	f	\N
124317	mobiiltelefoni	mobiiltelefoni =telefoni  (SgG  >mobiil+telefon !19_S	et	f	\N
124318	mobiiltelefoni	mobiiltelefoni =telefoni  (SgP  >mobiil+telefon !19_S	et	f	\N
124319	mobiiltelefoni	mobiiltelefoni =telefoni  (SgAdt  >mobiil+telefon !19_S	et	f	\N
124331	logo	logo =logo  (SgN  >logo !17~16_S	et	f	\N
123959	kingitus	"kingitus %kingi  )TUS2_aS  <kink ;22_S	et	f	\N
123975	paanikasse	paanikasse =paanika  (SgIll  >paanika !01_S	et	f	\N
123976	paanikasse	paanikasse =paanikas  (SgAdt  >paanikane !12_A	et	f	\N
123977	paanikasse	"paanikane %paanika  )NE_aA  <paanika ;01_S	et	f	\N
123993	lasi	lasi =las  (IndIpfSg3  >laskma !34_V	et	f	\N
123994	lasi	lasi =lasi  (SgN  >lasi !17_S	et	f	\N
123995	lasi	lasi =lasi  (SgG  >lasi !17_S	et	f	\N
123996	lasi	lasi =lasi  (SgP  >lasi !17_S	et	f	\N
124007	õrnusega	õrnusega =õrnuse  (SgKom  >õrnus !11~09_S	et	f	\N
124008	õrnusega	"õrnus %õrn  )US_aS  <õrn ;22_A	et	f	\N
124037	poisike	poisike =poisike  (SgN  >poisike !12_S	et	f	\N
124038	poisike	"poisike %poisi  )KE_dS  <poiss ;22_S	et	f	\N
124039	poisike	"poisike %poisi  )KE_dS  <poiss ;23_S	et	f	\N
124044	gerdale	?gerdale =gerda  (SgAll  >gerda !16_S	et	f	\N
124045	gerdale	?gerdale =gerdale  (IndPrPs_  >gerdalema !27_V	et	f	\N
124046	gerdale	?gerdale =gerdale  (ImpPrSg2  >gerdalema !27_V	et	f	\N
124068	vaikisid	vaikisid =vaiki  (PlP  >vaik !22_S	et	f	\N
124069	vaikisid	vaikisid =vaiki  (IndIpfSg2  >vaikima !27_V	et	f	\N
124070	vaikisid	vaikisid =vaiki  (IndIpfPl3  >vaikima !27_V	et	f	\N
124094	appi	appi =appi  (ID  >appi !41_I	et	f	\N
124095	appi	appi =appi  (SgAdt  >abi !17_S	et	f	\N
124097	tuttavale	tuttavale =tuttava  (SgAll  >tuttav !02_AS	et	f	\N
124098	tuttavale	tuttavale =ava  (SgAll  >tutt+ava !17_S	et	f	\N
124101	päästaski	?päästaski =päästaski  (SgG  >päästask !02_S	et	f	\N
124102	päästaski	?päästaski =päästaski  (IndPrPs_  >päästaskima !28_V	et	f	\N
124103	päästaski	?päästaski =päästaski  (ImpPrSg2  >päästaskima !28_V	et	f	\N
124104	päästaski	?päästaski =taski  (SgN  >pääs+taski !16_S	et	f	\N
124105	päästaski	?päästaski =taski  (SgG  >pääs+taski !16_S	et	f	\N
124106	päästaski	?päästaski =taski  (SgG  >pääs+task !22_S	et	f	\N
124107	päästaski	?päästaski =taski  (SgP  >pääs+task !22_S	et	f	\N
124108	päästaski	?päästaski =taski  (SgAdt  >pääs+task !22_S	et	f	\N
124109	päästaski	?päästaski =staski  (SgN  >pää+staski !16_S	et	f	\N
124110	päästaski	?päästaski =staski  (SgG  >pää+staski !16_S	et	f	\N
124111	päästaski	?päästaski =staski  (SgG  >pää+stask !22_S	et	f	\N
124112	päästaski	?päästaski =staski  (SgP  >pää+stask !22_S	et	f	\N
124113	päästaski	?päästaski =staski  (SgAdt  >pää+stask !22_S	et	f	\N
124114	päästaski	?päästaski =päästa  (SgIn^  >päästa !01_S	et	f	\N
124115	päästaski	?päästaski =päästa  (IndIpfSg3^  >päästama !27_V	et	f	\N
124116	päästaski	?päästaski =päästas  (SgN^  >päästas !07_S	et	f	\N
124127	järsku	järsku =järsku  (ID  >järsku !41_D	et	f	\N
124128	järsku	järsku =järsku  (SgP  >järsk !22_A	et	f	\N
124129	järsku	järsku =järsku  (SgAdt  >järsk !22_A	et	f	\N
124134	prooviks	prooviks =proovi  (SgTr  >proov !22_S	et	f	\N
124135	prooviks	prooviks =proovi  (KndPrPs  >proovima !28_V	et	f	\N
124150	jalgu	jalgu =jalgu  (ID  >jalgu !41_D	et	f	\N
124152	jalgu	jalgu =jalgu  (PlP  >jalg !22_S	et	f	\N
124153	mõtlesid	mõtlesid =mõtle  (IndIpfSg2  >mõtlema !30_V	et	f	\N
124154	mõtlesid	mõtlesid =mõtle  (IndIpfPl3  >mõtlema !30_V	et	f	\N
124155	vanemate	vanemate =vanema  (PlG  >vanem !02_AS	et	f	\N
124156	vanemate	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
124175	akki	?akki =akki  (ID  >akki !41_D	et	f	\N
124176	akki	?akki =akki  (SgP  >akk !22_S	et	f	\N
124177	akki	?akki =akki  (SgAdt  >akk !22_S	et	f	\N
124178	pettunud	pettunud =pettu  (PtsPtPs  >pettuma !27_V	et	f	\N
124179	pettunud	pettunud =pettunu  (PlN  >pettunu !01_S	et	f	\N
124180	pettunud	"pettunu %pettu  )NU_vS  <pettuma ;27_V	et	f	\N
124181	pettunud	pettunud =pettunud  (ID  >pettunud !41_A	et	f	\N
124182	pettunud	"pettunud %pettu  )NUD_vA  <pettuma ;27_V	et	f	\N
124204	tulles	tulles =tull  (Ger  >tulema !36_V	et	f	\N
124205	tulles	tulles =tulle  (PlIn  >tull !22_S	et	f	\N
124206	hirmutatud	hirmutatud =hirmuta  (PtsPtIps  >hirmutama !27_V	et	f	\N
124207	hirmutatud	hirmutatud =hirmutatu  (PlN  >hirmutatu !01_S	et	f	\N
124208	hirmutatud	"hirmutatu %hirmuta  )TU1_vS  <hirmutama ;27_V	et	f	\N
124209	hirmutatud	hirmutatud =hirmutatud  (ID  >hirmutatud !41_A	et	f	\N
124210	hirmutatud	"hirmutatud %hirmuta  )TUD_vA  <hirmutama ;27_V	et	f	\N
124248	hetke	hetke =hetke  (SgG  >hetk !22_S	et	f	\N
124249	hetke	hetke =hetke  (SgP  >hetk !22_S	et	f	\N
124250	hetke	hetke =hetke  (SgAdt  >hetk !22_S	et	f	\N
124253	hetke	hetke =hetke  (PlP  >hetk !22_S	et	f	\N
124271	noormes	?noormes =noorme  (SgIn  >noorme !06_S	et	f	\N
124272	noormes	?noormes =noorme  (PlIn  >noorm !22_S	et	f	\N
124273	noormes	?noormes =noorme  (IndIpfSg3  >noormema !27_V	et	f	\N
124274	noormes	?noormes =noormes  (SgN  >noormes !09_S	et	f	\N
124293	ilusalongi	ilusalongi =salongi  (SgG  >ilu+salong !22_S	et	f	\N
124294	ilusalongi	ilusalongi =salongi  (SgP  >ilu+salong !22_S	et	f	\N
124295	ilusalongi	ilusalongi =salongi  (SgAdt  >ilu+salong !22_S	et	f	\N
124304	töötajad	töötajad =töötaja  (PlN  >töötaja !01_S	et	f	\N
124305	töötajad	"töötaja %tööta  )JA_vS  <töötama ;27_V	et	f	\N
123965	lõhnanud	lõhnanud =lõhna  (PtsPtPs  >lõhnama !29_V	et	f	\N
123966	lõhnanud	lõhnanud =lõhnanu  (PlN  >lõhnanu !01_S	et	f	\N
123967	lõhnanud	"lõhnanu %lõhna  )NU_vS  <lõhnama ;29_V	et	f	\N
123968	lõhnanud	lõhnanud =lõhnanud  (ID  >lõhnanud !41_A	et	f	\N
123969	lõhnanud	"lõhnanud %lõhna  )NUD_vA  <lõhnama ;29_V	et	f	\N
123984	muutusid	muutusid =muutu  (PlP  >muut !22_S	et	f	\N
123985	muutusid	muutusid =muutu  (IndIpfSg2  >muutuma !27_V	et	f	\N
123986	muutusid	muutusid =muutu  (IndIpfPl3  >muutuma !27_V	et	f	\N
123987	ilme	ilme =ilme  (SgN  >ilme !06_S	et	f	\N
123988	ilme	ilme =ilme  (SgG  >ilme !06_S	et	f	\N
123989	ilme	ilme =ilme  (PlP  >ilm !22_S	et	f	\N
124017	lõbutsesid	lõbutsesid =lõbutse  (IndIpfSg2  >lõbutsema !27_V	et	f	\N
124018	lõbutsesid	lõbutsesid =lõbutse  (IndIpfPl3  >lõbutsema !27_V	et	f	\N
124027	eriline	eriline =eriline  (SgN  >eriline !12_A	et	f	\N
124028	eriline	"eriline %eri  )LINE_aA  <eri ;17_S	et	f	\N
124029	lumekuninganna	lumekuninganna =anna  (SgN  >lume+kuning+anna !16_S	et	f	\N
124030	lumekuninganna	lumekuninganna =anna  (SgG  >lume+kuning+anna !16_S	et	f	\N
124032	lumekuninganna	lumekuninganna =kuninganna  (SgN  >lume+kuninganna !16_S	et	f	\N
124034	lumekuninganna	lumekuninganna =kuninganna  (SgG  >lume+kuninganna !16_S	et	f	\N
124052	kiusakas	kiusakas =kiusaka  (SgIn  >kiusakas !02_A	et	f	\N
124053	kiusakas	kiusakas =kiusakas  (SgN  >kiusakas !02_A	et	f	\N
124054	kiusakas	kiusakas =aka  (SgIn  >kius+aka !16_S	et	f	\N
124066	tädike	tädike =tädike  (SgN  >tädike !12_S	et	f	\N
124067	tädike	"tädike %tädi  )KE_dS  <tädi ;17_S	et	f	\N
124074	vastates	vastates =vasta  (Ger  >vastama !29_V	et	f	\N
124075	vastates	vastates =ate  (PlIn  >vast+att !22_S	et	f	\N
124076	nägisid	?nägisid =nägi  (PlP  >nägi !17_S	et	f	\N
124077	nägisid	?nägisid =nägi  (IndIpfSg2  >nägima !27_V	et	f	\N
124078	nägisid	?nägisid =nägi  (IndIpfPl3  >nägima !27_V	et	f	\N
124081	käskis	käskis =käski  (SgIn  >käsk !22_S	et	f	\N
124082	käskis	käskis =käski  (IndIpfSg3  >käskima !28_V	et	f	\N
124086	röövijatega	röövijatega =röövija  (PlKom  >röövija !01_S	et	f	\N
124087	röövijatega	"röövija %röövi  )JA_vS  <röövima ;28_V	et	f	\N
124119	lähem	lähem =lähem  (SgN  >lähem !02_A	et	f	\N
124120	lähem	"lähem %lähe  )M_cA  <lähike ;12_A	et	f	\N
124121	säästukas	?säästukas =säästuka  (SgIn  >säästuka !01_S	et	f	\N
124122	säästukas	?säästukas =säästuka  (SgIn  >säästukas !02_A	et	f	\N
124123	säästukas	?säästukas =säästukas  (SgN  >säästukas !02_A	et	f	\N
124132	pitsat	pitsat =pitsa  (SgP  >pitsa !16_S	et	f	\N
124133	pitsat	pitsat =pitsat  (SgN  >pitsat !02_S	et	f	\N
124169	ümbritsevat	ümbritsevat =ümbritse  (KvtPrPs  >ümbritsema !27_V	et	f	\N
124170	ümbritsevat	ümbritsevat =ümbritseva  (SgP  >ümbritsev !02_A	et	f	\N
124171	ümbritsevat	"ümbritsev %ümbritse  )V_vA  <ümbritsema ;27_V	et	f	\N
124183	kakukest	kakukest =kakukes  (SgP  >kakuke !12_S	et	f	\N
124184	kakukest	"kakuke %kaku  )KE_dS  <kakk ;22_S	et	f	\N
124185	kakukest	kakukest =kakukes  (SgP  >kakukene !12_S	et	f	\N
124186	kakukest	"kakukene %kaku  )KENE_dS  <kakk ;22_S	et	f	\N
124187	kakukest	kakukest =kest  (SgN  >kaku+kest !22_S	et	f	\N
124190	rebast	rebast =reba  (SgEl  >reba !17_S	et	f	\N
124191	rebast	rebast =rebas  (SgP  >rebane !10_S	et	f	\N
124192	rebast	"rebane %reba  )NE_aA  <reba ;17_S	et	f	\N
124222	kolmekorrusselises	?kolmekorrusselises =kolmekorrusselise  (SgIn  >kolmekorrusseline !12_A	et	f	\N
124223	kolmekorrusselises	?kolmekorrusselises =korrusselise  (SgIn  >kolme+korrusseline !12_A	et	f	\N
124224	kolmekorrusselises	?kolmekorrusselises =ekorrusselise  (SgIn  >kolm+ekorrusseline !12_A	et	f	\N
124232	õppimisse	õppimisse =õppimis  (SgAdt  >õppimine !12_S	et	f	\N
124233	õppimisse	"õppimine %õppi  )MINE_vS  <õppima ;28_V	et	f	\N
124246	ootasid	ootasid =oota  (IndIpfSg2  >ootama !29_V	et	f	\N
124247	ootasid	ootasid =oota  (IndIpfPl3  >ootama !29_V	et	f	\N
124262	raamatukokku	?raamatukokku =raamatukokku  (IndPrPs_  >raamatukokkuma !27_V	et	f	\N
124263	raamatukokku	?raamatukokku =raamatukokku  (ImpPrSg2  >raamatukokkuma !27_V	et	f	\N
124275	imeilus	imeilus =ilu  (SgIn  >ime+ilu !17_S	et	f	\N
124276	imeilus	imeilus =ilus  (SgN  >ime+ilus !02_A	et	f	\N
124283	kohtunud	kohtunud =kohtu  (PtsPtPs  >kohtuma !27_V	et	f	\N
124284	kohtunud	kohtunud =kohtunu  (PlN  >kohtunu !01_S	et	f	\N
124285	kohtunud	"kohtunu %kohtu  )NU_vS  <kohtuma ;27_V	et	f	\N
124286	kohtunud	kohtunud =kohtunud  (ID  >kohtunud !41_A	et	f	\N
124287	kohtunud	"kohtunud %kohtu  )NUD_vA  <kohtuma ;27_V	et	f	\N
124296	riidepoodi	riidepoodi =poodi  (SgP  >riide+pood !22_S	et	f	\N
124297	riidepoodi	riidepoodi =poodi  (SgAdt  >riide+pood !22_S	et	f	\N
124306	imestasid	imestasid =imesta  (IndIpfSg2  >imestama !27_V	et	f	\N
124307	imestasid	imestasid =imesta  (IndIpfPl3  >imestama !27_V	et	f	\N
124367	imepisikesed	imepisikesed =pisikese  (PlN  >ime+pisike !12_A	et	f	\N
124368	imepisikesed	imepisikesed =pisikese  (PlN  >ime+pisikene !12_A	et	f	\N
124373	vanamees	vanamees =mee  (SgIn  >vana+mesi !15_S	et	f	\N
124374	vanamees	vanamees =mees  (SgN  >vana+mees !13_S	et	f	\N
124383	kaagutamine	kaagutamine =kaagutamine  (SgN  >kaagutamine !12_S	et	f	\N
124173	karu	karu =karu  (SgG  >karu !17_S	et	f	\N
124174	karu	karu =karu  (SgP  >karu !17_S	et	f	\N
124188	alkoholiletti	alkoholiletti =letti  (SgP  >alkoholi+lett !22_S	et	f	\N
124189	alkoholiletti	alkoholiletti =letti  (SgAdt  >alkoholi+lett !22_S	et	f	\N
124193	teiselt	teiselt =teise  (SgAbl  >teine !12_OP	et	f	\N
124194	teiselt	teiselt =teise  (SgAbl  >teise !12_P	et	f	\N
124197	kakukesele	kakukesele =kakukese  (SgAll  >kakuke !12_S	et	f	\N
124198	kakukesele	"kakuke %kaku  )KE_dS  <kakk ;22_S	et	f	\N
124199	kakukesele	kakukesele =kakukese  (SgAll  >kakukene !12_S	et	f	\N
124200	kakukesele	"kakukene %kaku  )KENE_dS  <kakk ;22_S	et	f	\N
124225	kasuema	kasuema =ema  (SgN  >kasu+ema !17_S	et	f	\N
124226	kasuema	kasuema =ema  (SgG  >kasu+ema !17_S	et	f	\N
124227	kasuema	kasuema =ema  (SgP  >kasu+ema !17_S	et	f	\N
124228	noorukitest	noorukitest =nooruki  (PlEl  >nooruk !02_S	et	f	\N
124229	noorukitest	noorukitest =test  (SgN  >nooruki+test !22_S	et	f	\N
124237	hambabrekette	?hambabrekette =hambabrekette  (PlP  >hambabrekett !22_S	et	f	\N
124238	hambabrekette	?hambabrekette =brekette  (PlP  >hamba+brekett !22_S	et	f	\N
124241	tutvumises	tutvumises =tutvumise  (SgIn  >tutvumine !12_S	et	f	\N
124242	tutvumises	"tutvumine %tutvu  )MINE_vS  <tutvuma ;27_V	et	f	\N
124243	balli	balli =balli  (SgG  >ball !22_S	et	f	\N
124244	balli	balli =balli  (SgP  >ball !22_S	et	f	\N
124245	balli	balli =balli  (SgAdt  >ball !22_S	et	f	\N
124259	detektiivromaani	detektiivromaani =romaani  (SgG  >detektiiv+romaan !22_S	et	f	\N
124260	detektiivromaani	detektiivromaani =romaani  (SgP  >detektiiv+romaan !22_S	et	f	\N
124261	detektiivromaani	detektiivromaani =romaani  (SgAdt  >detektiiv+romaan !22_S	et	f	\N
124264	lausus	lausus =lausu  (PlIn  >lausk !22_A	et	f	\N
124265	lausus	lausus =lausu  (IndIpfSg3  >lausuma !28_V	et	f	\N
124266	lausus	lausus =lausus  (SgN  >lausus !11~09_S	et	f	\N
124267	lausus	"lausus %lau  )SUS_aS  <laug ;22_SA	et	f	\N
124288	tütreke	tütreke =tütreke  (SgN  >tütreke !12_S	et	f	\N
124289	tütreke	"tütreke %tütre  )KE_dS  <tütar ;08_S	et	f	\N
124298	mõistas	?mõistas =mõista  (SgIn  >mõista !01_S	et	f	\N
124299	mõistas	?mõistas =mõista  (IndIpfSg3  >mõistama !27_V	et	f	\N
124300	mõistas	?mõistas =mõistas  (SgN  >mõistas !07_S	et	f	\N
124313	faberge	### faberge	et	f	\N
124314	playerit	?playerit =playeri  (SgP  >playeri !01_S	et	f	\N
124315	playerit	?playerit =playeri  (SgP  >player !02_S	et	f	\N
124316	playerit	?playerit =erit  (SgN  >play+erit !02_S	et	f	\N
124326	vääriliseks	vääriliseks =väärilise  (SgTr  >vääriline !12_A	et	f	\N
124327	vääriliseks	"vääriline %vääri  )LINE_aA  <väär ;22_S	et	f	\N
124328	kana	kana =kana  (SgN  >kana !17_S	et	f	\N
124329	kana	kana =kana  (SgG  >kana !17_S	et	f	\N
124330	kana	kana =kana  (SgP  >kana !17_S	et	f	\N
124334	päikesel	päikesel =päikese  (SgAd  >päike !12?10_S	et	f	\N
124335	päikesel	päikesel =päikese  (SgAd  >päikene !12?10_S	et	f	\N
124345	muna	muna =muna  (SgN  >muna !17_S	et	f	\N
124346	muna	muna =muna  (SgG  >muna !17_S	et	f	\N
124347	muna	muna =muna  (SgP  >muna !17_S	et	f	\N
124348	lapselaste	lapselaste =las  (PlG  >lapse+laps !14_S	et	f	\N
124349	lapselaste	lapselaste =laste  (PlP  >lapse+last !22_S	et	f	\N
124352	üllatus	üllatus =üllatu  (IndIpfSg3  >üllatuma !27_V	et	f	\N
124353	üllatus	üllatus =üllatus  (SgN  >üllatus !11_S	et	f	\N
124354	üllatus	"üllatus %üllata  )US_vS  <üllatama ;27_V	et	f	\N
124364	kodulaenu	kodulaenu =laenu  (SgG  >kodu+laen !22_S	et	f	\N
124365	kodulaenu	kodulaenu =laenu  (SgP  >kodu+laen !22_S	et	f	\N
124366	kodulaenu	kodulaenu =laenu  (SgAdt  >kodu+laen !22_S	et	f	\N
124422	sealsetes	sealsetes =sealse  (PlIn  >sealne !02_A	et	f	\N
124423	sealsetes	sealsetes =sete  (PlIn  >seal+sett !22_S	et	f	\N
124424	kasvavaid	kasvavaid =kasvava  (PlP  >kasvav !02_A	et	f	\N
124425	kasvavaid	"kasvav %kasva  )V_vA  <kasvama ;28_V	et	f	\N
124432	vaikselt	vaikselt =vaikse  (SgAbl  >vaikne !02_A	et	f	\N
124433	vaikselt	vaikselt =vaikselt  (ID  >vaikselt !41_D	et	f	\N
124434	vaikselt	"vaikselt %vaikse  )LT_mD  <vaikne ;02_A	et	f	\N
124447	paigast	paigast =paiga  (SgEl  >paik !22_S	et	f	\N
124448	paigast	paigast =paigas  (SgP  >paigas !09_S	et	f	\N
124450	paigast	paigast =paigas  (SgP  >paigane !10_A	et	f	\N
124452	paigast	"paigane %paiga  )NE_aA  <paik ;22_S	et	f	\N
124460	kukkumise	kukkumise =kukkumise  (SgG  >kukkumine !12_S	et	f	\N
124461	kukkumise	"kukkumine %kukku  )MINE_vS  <kukkuma ;28_V	et	f	\N
124551	tuttavaks	tuttavaks =tuttava  (SgTr  >tuttav !02_AS	et	f	\N
124552	tuttavaks	tuttavaks =ava  (SgTr  >tutt+ava !17_S	et	f	\N
124553	elamust	elamust =elamu  (SgEl  >elamu !01_S	et	f	\N
124554	elamust	elamust =elamus  (SgP  >elamus !11_S	et	f	\N
124575	vähemuses	vähemuses =vähemuse  (SgIn  >vähemus !11_S	et	f	\N
124576	vähemuses	"vähemus %vähema  )US_aS  <vähem ;02_A	et	f	\N
124577	vähemuses	vähemuses =use  (PlIn  >vähem+usk !22_S	et	f	\N
124580	iseloomulikku	iseloomulikku =loomulikku  (SgP  >ise+loomulik !25_A	et	f	\N
124581	iseloomulikku	iseloomulikku =loomulikku  (SgAdt  >ise+loomulik !25_A	et	f	\N
124213	köögiaknast	"köögi+aknane %akna  )NE_aA  <köögi+aken ;08_S	et	f	\N
124214	tuhkatriinu	tuhkatriinu =triinu  (SgN  >tuhka+triinu !16_S	et	f	\N
124215	tuhkatriinu	tuhkatriinu =triinu  (SgG  >tuhka+triinu !16_S	et	f	\N
124230	tantsijaks	tantsijaks =tantsija  (SgTr  >tantsija !01_S	et	f	\N
124231	tantsijaks	"tantsija %tantsi  )JA_vS  <tantsima ;28_V	et	f	\N
124234	välimusest	välimusest =välimuse  (SgEl  >välimus !11_S	et	f	\N
124235	välimusest	välimusest =välimuses  (SgP  >välimusene !12_A	et	f	\N
124236	välimusest	"välimusene %välimuse  )NE_aA  <välimus ;11_S	et	f	\N
124239	kolis	kolis =koli  (SgIn  >koli !17_S	et	f	\N
124240	kolis	kolis =koli  (IndIpfSg3  >kolima !27_V	et	f	\N
124254	ettevalmistusid	?ettevalmistusid =ettevalmistu  (IndIpfSg2  >ettevalmistuma !27_V	et	f	\N
124255	ettevalmistusid	?ettevalmistusid =ettevalmistu  (IndIpfPl3  >ettevalmistuma !27_V	et	f	\N
124256	ettevalmistusid	?ettevalmistusid =tusi  (PlN  >ette+valmis+tusi !17_S	et	f	\N
124268	laenata	laenata =laena  (Inf  >laenama !29_V	et	f	\N
124269	laenata	laenata =laena  (IndPrIps_  >laenama !29_V	et	f	\N
124270	laenata	laenata =nata  (SgG  >lae+natt !22_S	et	f	\N
124277	jube	jube =jube  (ID  >jube !41_D	et	f	\N
124278	jube	jube =jube  (SgN  >jube !02_A	et	f	\N
124290	lahke	lahke =lahke  (SgN  >lahke !01_A	et	f	\N
124291	lahke	lahke =lahke  (SgG  >lahke !01_A	et	f	\N
124292	lahke	lahke =lahke  (PlP  >lahk !22_S	et	f	\N
124310	surid	surid =sur  (IndIpfSg2  >surema !36_V	et	f	\N
124311	surid	surid =sur  (IndIpfPl3  >surema !36_V	et	f	\N
124312	brilliantmunad	### brilliantmunad	et	f	\N
124320	ainukeseks	ainukeseks =ainukese  (SgTr  >ainuke !12_AS	et	f	\N
124321	ainukeseks	"ainuke %ainu  )KE_dS  <ainu ;16_S	et	f	\N
124322	ainukeseks	"ainuke %ainu  )KE_dA  <ainus ;07_AS	et	f	\N
124323	ainukeseks	ainukeseks =ainukese  (SgTr  >ainukene !12_S	et	f	\N
124324	ainukeseks	"ainukene %ainu  )KENE_dS  <ainu ;16_S	et	f	\N
124325	ainukeseks	"ainukene %ainu  )KENE_dA  <ainus ;07_AS	et	f	\N
124336	plahvatused	plahvatused =plahvatuse  (PlN  >plahvatus !11_S	et	f	\N
124337	plahvatused	"plahvatus %plahvata  )US_vS  <plahvatama ;27_V	et	f	\N
124338	radioaktiivsete	radioaktiivsete =radioaktiivse  (PlG  >radioaktiivne !02_A	et	f	\N
124339	radioaktiivsete	radioaktiivsete =sete  (SgN  >radio+aktiiv+sete !06_S	et	f	\N
124340	radioaktiivsete	radioaktiivsete =aktiivse  (PlG  >radio+aktiivne !02_A	et	f	\N
124341	atakki	atakki =atakki  (SgP  >atakk !22_S	et	f	\N
124342	atakki	atakki =atakki  (SgAdt  >atakk !22_S	et	f	\N
124375	lõpenud	?lõpenud =lõpe  (PtsPtPs  >lõpema !27_V	et	f	\N
124376	lõpenud	?lõpenud =lõpenu  (PlN  >lõpenu !01_S	et	f	\N
124377	lõpenud	?lõpenud =lõpenu  (IndPrSg2  >lõpenuma !27_V	et	f	\N
124378	lõpenud	?lõpenud =lõpenud  (ID  >lõpenud !41_A	et	f	\N
124381	kostsid	kostsid =kost  (IndIpfSg2  >kostma !34_V	et	f	\N
124382	kostsid	kostsid =kost  (IndIpfPl3  >kostma !34_V	et	f	\N
124404	kostav	?kostav =kosta  (PtsPrPs  >kostama !29_V	et	f	\N
124405	kostav	?kostav =kostav  (SgN  >kostav !02_A	et	f	\N
124440	kisa	kisa =kisa  (SgN  >kisa !17_S	et	f	\N
124441	kisa	kisa =kisa  (SgG  >kisa !17_S	et	f	\N
124442	kisa	kisa =kisa  (SgP  >kisa !17_S	et	f	\N
124443	kisa	kisa =kisa  (IndPrPs_  >kisama !27_V	et	f	\N
124444	kisa	kisa =kisa  (ImpPrSg2  >kisama !27_V	et	f	\N
124464	kohvrisisu	kohvrisisu =sisu  (SgN  >kohvri+sisu !17_S	et	f	\N
124465	kohvrisisu	kohvrisisu =sisu  (SgG  >kohvri+sisu !17_S	et	f	\N
124466	kohvrisisu	kohvrisisu =sisu  (SgP  >kohvri+sisu !17_S	et	f	\N
124467	kruuvikeerajad	?kruuvikeerajad =kruuvikeeraja  (PlN  >kruuvikeeraja !01_S	et	f	\N
124468	kruuvikeerajad	?kruuvikeerajad =kruuvikeeraja  (PlN  >kruuvikeerajas !02_A	et	f	\N
124475	lukkseppa	lukkseppa =seppa  (SgP  >lukk+sepp !22_S	et	f	\N
124476	lukkseppa	lukkseppa =seppa  (SgAdt  >lukk+sepp !22_S	et	f	\N
124500	kõigest	kõigest =kõige  (SgEl  >kõik !00_P	et	f	\N
124501	kõigest	kõigest =kõige  (PlEl  >kõik !22_S	et	f	\N
124502	kõigest	kõigest =kõigest  (ID  >kõigest !41_D	et	f	\N
124522	peatus	peatus =peatu  (SgIn  >peatu !01_A	et	f	\N
124523	peatus	"peatu %pea  )TU2_kA  <pea ;26_S	et	f	\N
124524	peatus	peatus =peatu  (IndIpfSg3  >peatuma !27_V	et	f	\N
124525	peatus	peatus =peatus  (SgN  >peatus !11~09_S	et	f	\N
124526	peatus	"peatus %peata  )US_vS  <peatama ;27_V	et	f	\N
124527	peatus	"peatus %pea  )TUS2_aS  <pea ;26_S	et	f	\N
124528	rongist	rongist =rongi  (SgEl  >rong !22_S	et	f	\N
124529	rongist	rongist =rongi  (PlEl  >ronk !22_S	et	f	\N
124534	vea	vea =vea  (SgG  >viga !18_S	et	f	\N
124535	vea	vea =vea  (IndPrPs_  >vedama !28_V	et	f	\N
124536	vea	vea =vea  (ImpPrSg2  >vedama !28_V	et	f	\N
124537	peaksin	peaksin =pea  (KndPrSg1  >pida !40_V	et	f	\N
124538	peaksin	peaksin =pea  (KndPrSg1  >pidama !28_V	et	f	\N
124544	terroristi	terroristi =terroristi  (SgG  >terrorist !22_S	et	f	\N
124545	terroristi	terroristi =terroristi  (SgP  >terrorist !22_S	et	f	\N
124546	terroristi	terroristi =terroristi  (SgAdt  >terrorist !22_S	et	f	\N
124549	erirahvustest	erirahvustest =test  (SgN  >eri+rahvus+test !22_S	et	f	\N
124550	erirahvustest	erirahvustest =rahvus  (PlEl  >eri+rahvus !11~09_S	et	f	\N
124332	logo	logo =logo  (SgG  >logo !17~16_S	et	f	\N
124333	logo	logo =logo  (SgP  >logo !17_S	et	f	\N
124343	erilist	erilist =erilis  (SgP  >eriline !12_A	et	f	\N
124344	erilist	"eriline %eri  )LINE_aA  <eri ;17_S	et	f	\N
124350	hõõrus	hõõrus =hõõru  (SgIn  >hõõr !22_S	et	f	\N
124351	hõõrus	hõõrus =hõõru  (IndIpfSg3  >hõõruma !28_V	et	f	\N
124355	brilliandimoodi	?brilliandimoodi =brilliandimoodi  (SgN  >brilliandimoodi !16_S	et	f	\N
124356	brilliandimoodi	?brilliandimoodi =brilliandimoodi  (SgG  >brilliandimoodi !16_S	et	f	\N
124357	brilliandimoodi	?brilliandimoodi =brilliandimoodi  (SgG  >brilliandimoot !22_S	et	f	\N
124358	brilliandimoodi	?brilliandimoodi =brilliandimoodi  (SgP  >brilliandimood !22_S	et	f	\N
124359	brilliandimoodi	?brilliandimoodi =brilliandimoodi  (SgAdt  >brilliandimood !22_S	et	f	\N
124360	brilliandimoodi	?brilliandimoodi =brilliandimoodi  (IndPrPs_  >brilliandimootima !28_V	et	f	\N
124362	brilliandimoodi	?brilliandimoodi =brilliandimoodi  (ImpPrSg2  >brilliandimootima !28_V	et	f	\N
124369	killukesed	killukesed =killukese  (PlN  >killuke !12_S	et	f	\N
124370	killukesed	"killuke %killu  )KE_dS  <kild ;22_S	et	f	\N
124371	killukesed	killukesed =killukese  (PlN  >killukene !12_S	et	f	\N
124372	killukesed	"killukene %killu  )KENE_dS  <kild ;22_S	et	f	\N
124379	karjumine	karjumine =karjumine  (SgN  >karjumine !12_S	et	f	\N
124380	karjumine	"karjumine %karju  )MINE_vS  <karjuma ;28_V	et	f	\N
124385	kanapea	kanapea =pea  (SgN  >kana+pea !26_S	et	f	\N
124386	kanapea	kanapea =pea  (SgG  >kana+pea !26_S	et	f	\N
124390	hilisemast	hilisemast =hilisema  (SgEl  >hilisem !02_A	et	f	\N
124391	hilisemast	"hilisem %hilise  )M_cA  <hiline ;10_A	et	f	\N
124392	hilisemast	hilisemast =ema  (SgEl  >hilis+ema !17_S	et	f	\N
124393	hilisemast	hilisemast =emas  (SgP  >hilis+emane !10_AS	et	f	\N
124394	hilisemast	"hilis+emane %ema  )NE_aA  <hilis+ema ;17_S	et	f	\N
124399	lahendatud	lahendatud =lahenda  (PtsPtIps  >lahendama !27_V	et	f	\N
124400	lahendatud	lahendatud =lahendatu  (PlN  >lahendatu !01_S	et	f	\N
124401	lahendatud	"lahendatu %lahenda  )TU1_vS  <lahendama ;27_V	et	f	\N
124402	lahendatud	lahendatud =lahendatud  (ID  >lahendatud !41_A	et	f	\N
124403	lahendatud	"lahendatud %lahenda  )TUD_vA  <lahendama ;27_V	et	f	\N
124426	arutanud	arutanud =aruta  (PtsPtPs  >arutama !27_V	et	f	\N
124427	arutanud	arutanud =arutanu  (PlN  >arutanu !01_S	et	f	\N
124428	arutanud	"arutanu %aruta  )NU_vS  <arutama ;27_V	et	f	\N
124429	arutanud	arutanud =arutanud  (ID  >arutanud !41_A	et	f	\N
124430	arutanud	"arutanud %aruta  )NUD_vA  <arutama ;27_V	et	f	\N
124431	arutanud	arutanud =tanu  (PlN  >aru+tanu !17_S	et	f	\N
124477	jätnud	jätnud =jät  (PtsPtPs  >jätma !35_V	et	f	\N
124478	jätnud	jätnud =jätnu  (PlN  >jätnu !01_S	et	f	\N
124479	jätnud	"jätnu %jät  )NU_vS  <jätma ;35_V	et	f	\N
124480	jätnud	jätnud =jätnud  (ID  >jätnud !41_A	et	f	\N
124481	jätnud	"jätnud %jät  )NUD_vA  <jätma ;35_V	et	f	\N
124493	ettekujutama	?ettekujutama =ettekuju  (SupIps  >ettekujuma !27_V	et	f	\N
124494	ettekujutama	?ettekujutama =ettekujuta  (Sup  >ettekujutama !27_V	et	f	\N
124495	ettekujutama	?ettekujutama =ettekujutama  (SgG  >ettekujutam !02_A	et	f	\N
124496	ettekujutama	?ettekujutama =tama  (SgN  >ette+kuju+tama !17_S	et	f	\N
124497	ettekujutama	?ettekujutama =tama  (SgG  >ette+kuju+tama !17_S	et	f	\N
124498	ettekujutama	?ettekujutama =tama  (SgP  >ette+kuju+tama !17_S	et	f	\N
124499	ettekujutama	?ettekujutama =kujutama  (SgG  >ette+kujutam !02_A	et	f	\N
124503	neetud	neetud =nee  (PtsPtIps  >needma !34_V	et	f	\N
124504	neetud	neetud =neetu  (PlN  >neetu !01_S	et	f	\N
124505	neetud	"neetu %nee  )TU1_vS  <needma ;34_V	et	f	\N
124506	neetud	neetud =neetud  (ID  >neetud !41_A	et	f	\N
124507	neetud	"neetud %nee  )TUD_vA  <needma ;34_V	et	f	\N
124508	kupeed	kupeed =kupee  (PlN  >kupee !26_S	et	f	\N
124509	kupeed	kupeed =kupee  (SgP  >kupee !26_S	et	f	\N
124547	kaugetele	kaugetele =kauge  (PlAll  >kauge !01_A	et	f	\N
124548	kaugetele	kaugetele =e  (PlAll  >kaug+esi !15_S	et	f	\N
124555	üleval	üleval =üleva  (SgAd  >ülev !02_A	et	f	\N
124556	üleval	üleval =üleval  (ID  >üleval !41_D	et	f	\N
124566	sõitsid	sõitsid =sõit  (IndIpfSg2  >sõitma !34_V	et	f	\N
124567	sõitsid	sõitsid =sõit  (IndIpfPl3  >sõitma !34_V	et	f	\N
124599	peterburgi	?peterburgi =peterburgi  (SgG  >peterburk !22_S	et	f	\N
124600	peterburgi	?peterburgi =peterburgi  (SgP  >peterburg !22_S	et	f	\N
124603	peterburgi	?peterburgi =peterburgi  (SgAdt  >peterburg !22_S	et	f	\N
124605	peterburgi	?peterburgi =peterburgi  (IndPrPs_  >peterburkima !28_V	et	f	\N
124606	peterburgi	?peterburgi =peterburgi  (ImpPrSg2  >peterburkima !28_V	et	f	\N
124607	peterburgi	?peterburgi =peterbur  (SgN^  >peterbur !19_S	et	f	\N
124608	tudengitest	tudengitest =tudengi  (PlEl  >tudeng !02_S	et	f	\N
124609	tudengitest	tudengitest =test  (SgN  >tudengi+test !22_S	et	f	\N
124616	uurimist	uurimist =uurimis  (SgP  >uurimine !12_S	et	f	\N
124617	uurimist	"uurimine %uuri  )MINE_vS  <uurima ;28_V	et	f	\N
124655	eriku	?eriku =eriku  (SgN  >eriku !01_S	et	f	\N
124656	eriku	?eriku =eriku  (SgG  >eriku !01_S	et	f	\N
124657	eriku	?eriku =eriku  (SgG  >erik !02_S	et	f	\N
124658	eriku	?eriku =eriku  (IndPrPs_  >erikuma !27_V	et	f	\N
124361	silmitses	silmitses =silmitse  (IndIpfSg3  >silmitsema !27_V	et	f	\N
124363	silmitses	silmitses =itse  (PlIn  >silm+its !22_S	et	f	\N
124395	lööma	lööma =löö  (Sup  >lööma !38_V	et	f	\N
124396	lööma	lööma =lööma  (SgG  >lööm !22_S	et	f	\N
124397	lööma	lööma =lööma  (SgP  >lööm !22_S	et	f	\N
124398	lööma	lööma =lööma  (SgAdt  >lööm !22_S	et	f	\N
124407	sihtmärki	sihtmärki =märki  (SgP  >siht+märk !22_S	et	f	\N
124408	sihtmärki	sihtmärki =märki  (SgAdt  >siht+märk !22_S	et	f	\N
124413	köhiseb	?köhiseb =köhise  (IndPrSg3  >köhisema !27_V	et	f	\N
124419	reisisid	reisisid =reisi  (PlP  >reis !22_S	et	f	\N
124420	reisisid	reisisid =reisi  (IndIpfSg2  >reisima !28_V	et	f	\N
124421	reisisid	reisisid =reisi  (IndIpfPl3  >reisima !28_V	et	f	\N
124435	silmitsesid	silmitsesid =silmitse  (IndIpfSg2  >silmitsema !27_V	et	f	\N
124436	silmitsesid	silmitsesid =silmitse  (IndIpfPl3  >silmitsema !27_V	et	f	\N
124437	toimuvat	toimuvat =toimu  (KvtPrPs  >toimuma !27_V	et	f	\N
124438	toimuvat	toimuvat =toimuva  (SgP  >toimuv !02_A	et	f	\N
124439	toimuvat	"toimuv %toimu  )V_vA  <toimuma ;27_V	et	f	\N
124445	pidurdamise	pidurdamise =pidurdamise  (SgG  >pidurdamine !12_S	et	f	\N
124446	pidurdamise	"pidurdamine %pidurda  )MINE_vS  <pidurdama ;27_V	et	f	\N
124456	pagasiriiulist	pagasiriiulist =riiuli  (SgEl  >pagasi+riiul !02_S	et	f	\N
124457	pagasiriiulist	pagasiriiulist =riiulis  (SgP  >pagasi+riiuline !12_A	et	f	\N
124458	pagasiriiulist	"pagasi+riiuline %riiu  )LINE_aA  <pagasi+riid ;22_S	et	f	\N
124459	pagasiriiulist	"pagasi+riiuline %riiuli  )NE_aA  <pagasi+riiul ;02_S	et	f	\N
124469	väikestes	väikestes =väikes  (PlIn  >väike !12?10_A	et	f	\N
124470	väikestes	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
124471	väikestes	väikestes =väikes  (PlIn  >väikene !12?10_A	et	f	\N
124472	väikestes	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
124473	väikestes	väikestes =keste  (SgIn  >väi+keste !06_S	et	f	\N
124474	väikestes	väikestes =keste  (PlIn  >väi+kest !22_S	et	f	\N
124510	kurja	?kurja =kurja  (SgN  >kurja !16_S	et	f	\N
124511	kurja	?kurja =kurja  (SgG  >kurjas !02_A	et	f	\N
124512	kurja	?kurja =kurja  (SgG  >kurja !16_S	et	f	\N
124513	kurja	?kurja =kurja  (SgG  >kuri !24_A	et	f	\N
124514	kurja	?kurja =kurja  (SgP  >kuri !24_A	et	f	\N
124515	kurja	?kurja =kurja  (SgAdt  >kuri !24_A	et	f	\N
124516	kurja	?kurja =kurja  (IndPrPs_  >kurjama !29_V	et	f	\N
124517	kurja	?kurja =kurja  (ImpPrSg2  >kurjama !29_V	et	f	\N
124518	hakkanud	?hakkanud =hakkanu  (PlN  >hakkanu !01_S	et	f	\N
124519	hakkanud	?hakkanud =hakkanu  (IndPrSg2  >hakkanuma !27_V	et	f	\N
124520	hakkanud	?hakkanud =hakkanud  (ID  >hakkanud !41_A	et	f	\N
124521	hakkanud	?hakkanud =anu  (PlN  >hakk+anu !17_S	et	f	\N
124573	natukese	natukese =natukese  (SgG  >natuke !12_S	et	f	\N
124574	natukese	natukese =natukese  (SgG  >natukene !12_S	et	f	\N
124578	g-d	g-d =g  (SgP  >g !xx_Q	et	f	\N
124579	g-d	g-d =g  (PlN  >g !xx_Q	et	f	\N
124614	koorimuusika	koorimuusika =muusika  (SgN  >koori+muusika !01_S	et	f	\N
124615	koorimuusika	koorimuusika =muusika  (SgG  >koori+muusika !01_S	et	f	\N
124625	tantsu-	tantsu- =tantsu  (SgG  >tants !22_S	et	f	\N
124626	tantsu-	tantsu- =tantsu  (SgP  >tants !22_S	et	f	\N
124627	tantsu-	tantsu- =tantsu  (SgAdt  >tants !22_S	et	f	\N
124638	tanejevi	?tanejevi =tanejevi  (ID  >tanejevi !41_D	et	f	\N
124639	tanejevi	?tanejevi =tanejevi  (SgG  >tanejev !02_A	et	f	\N
124650	innovatsioonidele	?innovatsioonidele =innovatsiooni  (PlAll  >innovatsiooni !16_S	et	f	\N
124651	innovatsioonidele	?innovatsioonidele =innovatsiooni  (PlAll  >innovatsioon !22_S	et	f	\N
124667	slovakkiaga	?slovakkiaga =slovakkia  (SgKom  >slovakkia !01_S	et	f	\N
124706	kõrgemaks	kõrgemaks =kõrgema  (SgTr  >kõrgem !02_A	et	f	\N
124707	kõrgemaks	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
124708	kõrgemaks	kõrgemaks =maks  (SgN  >kõrge+maks !22_S	et	f	\N
124709	kõrgemaks	kõrgemaks =ema  (SgTr  >kõrg+ema !17_S	et	f	\N
124713	tehnoloogiade	?tehnoloogiade =tehnoloogiade  (PlP  >tehnoloogiad !22_S	et	f	\N
124714	tehnoloogiade	?tehnoloogiade =gia  (PlG  >tehno+loo+gia !26_S	et	f	\N
124715	tehnoloogiade	?tehnoloogiade =giade  (SgN  >tehno+loo+giade !06_S	et	f	\N
124716	tehnoloogiade	?tehnoloogiade =giade  (PlP  >tehno+loo+giad !22_S	et	f	\N
124717	tehnoloogiade	?tehnoloogiade =loogiade  (PlP  >tehno+loogiad !22_S	et	f	\N
124720	arvu	arvu =arvu  (SgG  >arv !22_S	et	f	\N
124721	arvu	arvu =arvu  (SgP  >arv !22_S	et	f	\N
124722	arvu	arvu =arvu  (SgAdt  >arv !22_S	et	f	\N
124728	omandajate	omandajate =omandaja  (PlG  >omandaja !01_S	et	f	\N
124729	omandajate	"omandaja %omanda  )JA_vS  <omandama ;27_V	et	f	\N
124735	uurimiste	uurimiste =uurimis  (PlG  >uurimine !12_S	et	f	\N
124736	uurimiste	"uurimine %uuri  )MINE_vS  <uurima ;28_V	et	f	\N
124739	hiljuti	hiljuti =hilju  (IndIpfIps  >hiljuma !28_V	et	f	\N
124740	hiljuti	hiljuti =hiljuti  (ID  >hiljuti !41_D	et	f	\N
124777	koostöö	koostöö =töö  (SgN  >koos+töö !26_S	et	f	\N
124778	koostöö	koostöö =töö  (SgG  >koos+töö !26_S	et	f	\N
124779	ühistegevust	ühistegevust =us  (SgP  >ühis+tegev+uks !14_S	et	f	\N
124780	ühistegevust	ühistegevust =tegevus  (SgP  >ühis+tegevus !11_S	et	f	\N
124384	kaagutamine	"kaagutamine %kaaguta  )MINE_vS  <kaagutama ;27_V	et	f	\N
124387	mune	mune =mune  (PlP  >muna !17_S	et	f	\N
124388	mune	mune =mune  (IndPrPs_  >munema !27_V	et	f	\N
124389	mune	mune =mune  (ImpPrSg2  >munema !27_V	et	f	\N
124406	uinatab	?uinatab =uinata  (IndPrSg3  >uinatama !27_V	et	f	\N
124409	silmast	silmast =silma  (SgEl  >silm !22_S	et	f	\N
124410	silmast	silmast =silmas  (SgP  >silmane !10_A	et	f	\N
124411	silmast	"silmane %silma  )NE_aA  <silm ;22_S	et	f	\N
124412	silmast	silmast =ast  (SgN  >silm+ast !22_S	et	f	\N
124414	istunud	istunud =istu  (PtsPtPs  >istuma !28_V	et	f	\N
124415	istunud	istunud =istunu  (PlN  >istunu !01_S	et	f	\N
124416	istunud	"istunu %istu  )NU_vS  <istuma ;28_V	et	f	\N
124417	istunud	istunud =istunud  (ID  >istunud !41_A	et	f	\N
124418	istunud	"istunud %istu  )NUD_vA  <istuma ;28_V	et	f	\N
124449	liikunud	liikunud =liiku  (PtsPtPs  >liikuma !28_V	et	f	\N
124451	liikunud	liikunud =liikunu  (PlN  >liikunu !01_S	et	f	\N
124453	liikunud	"liikunu %liiku  )NU_vS  <liikuma ;28_V	et	f	\N
124454	liikunud	liikunud =liikunud  (ID  >liikunud !41_A	et	f	\N
124455	liikunud	"liikunud %liiku  )NUD_vA  <liikuma ;28_V	et	f	\N
124462	sõitjad	sõitjad =sõitja  (PlN  >sõitja !01_S	et	f	\N
124463	sõitjad	"sõitja %sõit  )JA_vS  <sõitma ;34_V	et	f	\N
124482	kupeest	kupeest =kupee  (SgEl  >kupee !26_S	et	f	\N
124483	kupeest	kupeest =kupees  (SgP  >kupeene !12~10_A	et	f	\N
124484	kupeest	"kupeene %kupee  )NE_aA  <kupee ;26_S	et	f	\N
124485	suurustanud	suurustanud =suurusta  (PtsPtPs  >suurustama !27_V	et	f	\N
124486	suurustanud	suurustanud =suurustanu  (PlN  >suurustanu !01_S	et	f	\N
124487	suurustanud	"suurustanu %suurusta  )NU_vS  <suurustama ;27_V	et	f	\N
124488	suurustanud	suurustanud =suurustanud  (ID  >suurustanud !41_A	et	f	\N
124489	suurustanud	"suurustanud %suurusta  )NUD_vA  <suurustama ;27_V	et	f	\N
124490	suurustanud	suurustanud =tanu  (PlN  >suurus+tanu !17_S	et	f	\N
124491	juhtunut	juhtunut =juhtunu  (SgP  >juhtunu !01_S	et	f	\N
124492	juhtunut	"juhtunu %juhtu  )NU_vS  <juhtuma ;27_V	et	f	\N
124530	ehmatusest	ehmatusest =ehmatuse  (SgEl  >ehmatus !11_S	et	f	\N
124531	ehmatusest	"ehmatus %ehmata  )US_vS  <ehmatama ;27_V	et	f	\N
124532	ehmatusest	ehmatusest =ehmatuses  (SgP  >ehmatusene !12_A	et	f	\N
124533	ehmatusest	"ehmatusene %ehmatuse  )NE_aA  <ehmatus ;11_S	et	f	\N
124539	langenud	langenud =lange  (PtsPtPs  >langema !27_V	et	f	\N
124540	langenud	langenud =langenu  (PlN  >langenu !01_S	et	f	\N
124541	langenud	"langenu %lange  )NU_vS  <langema ;27_V	et	f	\N
124542	langenud	langenud =langenud  (ID  >langenud !41_A	et	f	\N
124543	langenud	"langenud %lange  )NUD_vA  <langema ;27_V	et	f	\N
124557	mineralnije	### mineralnije	et	f	\N
124558	vodõ	### vodõ	et	f	\N
124564	rääkides	rääkides =rääki  (PlIn  >rääk !22_S	et	f	\N
124565	rääkides	rääkides =rääki  (Ger  >rääkima !28_V	et	f	\N
124570	g	### g	et	f	\N
124571	naljakas	naljakas =naljaka  (SgIn  >naljakas !02_A	et	f	\N
124572	naljakas	naljakas =naljakas  (SgN  >naljakas !02_A	et	f	\N
124585	lüüra	lüüra =lüüra  (SgN  >lüüra !16_S	et	f	\N
124586	lüüra	lüüra =lüüra  (SgG  >lüüra !16_S	et	f	\N
124594	rahmaninovi	?rahmaninovi =rahmaninovi  (ID  >rahmaninovi !41_D	et	f	\N
124595	rahmaninovi	?rahmaninovi =rahmaninovi  (SgG  >rahmaninov !02_A	et	f	\N
124620	kollektiivi	kollektiivi =kollektiivi  (SgG  >kollektiiv !22_S	et	f	\N
124621	kollektiivi	kollektiivi =kollektiivi  (SgP  >kollektiiv !22_S	et	f	\N
124622	kollektiivi	kollektiivi =kollektiivi  (SgAdt  >kollektiiv !22_S	et	f	\N
124635	tunduv	tunduv =tundu  (PtsPrPs  >tunduma !27_V	et	f	\N
124636	tunduv	tunduv =tunduv  (SgN  >tunduv !02_A	et	f	\N
124637	tunduv	"tunduv %tundu  )V_vA  <tunduma ;27_V	et	f	\N
124652	arengufondi	arengufondi =fondi  (SgG  >arengu+fond !22_S	et	f	\N
124653	arengufondi	arengufondi =fondi  (SgP  >arengu+fond !22_S	et	f	\N
124654	arengufondi	arengufondi =fondi  (SgAdt  >arengu+fond !22_S	et	f	\N
124674	leedust	leedust =leedu  (SgEl  >leedu !16_S	et	f	\N
124675	leedust	"leedu %lee  )TU1_vS  <leema ;37_V	et	f	\N
124676	leedust	leedust =leedus  (SgP  >leedus !11~09_S	et	f	\N
124677	leedust	"leedus %lee  )TUS1_aS  <leema ;37_V	et	f	\N
124678	uudest	?uudest =uude  (PlEl  >uut !22_S	et	f	\N
124679	uudest	?uudest =uudes  (SgP  >uudes !09_S	et	f	\N
124680	uudest	?uudest =uudes  (SgP  >uudene !10_A	et	f	\N
124683	lauri	?lauri =lauri  (SgN  >lauri !16_S	et	f	\N
124684	lauri	?lauri =lauri  (SgG  >lauri !16_S	et	f	\N
124685	lauri	?lauri =lauri  (SgG  >laur !22_S	et	f	\N
124686	lauri	?lauri =lauri  (SgP  >laur !22_S	et	f	\N
124687	lauri	?lauri =lauri  (SgAdt  >laur !22_S	et	f	\N
124690	lauri	?lauri =lauri  (IndPrPs_  >laurima !28_V	et	f	\N
124693	lauri	?lauri =lauri  (ImpPrSg2  >laurima !28_V	et	f	\N
124699	majandusanalüüsi	majandusanalüüsi =analüüsi  (SgG  >majandus+analüüs !22_S	et	f	\N
124700	majandusanalüüsi	majandusanalüüsi =analüüsi  (SgP  >majandus+analüüs !22_S	et	f	\N
124701	majandusanalüüsi	majandusanalüüsi =analüüsi  (SgAdt  >majandus+analüüs !22_S	et	f	\N
124724	konstrueerimisele	konstrueerimisele =konstrueerimise  (SgAll  >konstrueerimine !12_S	et	f	\N
124559	linnast	linnast =linna  (SgEl  >linn !22_S	et	f	\N
124560	linnast	linnast =linnas  (SgP  >linnas !09_S	et	f	\N
124561	linnast	linnast =linnas  (SgP  >linnane !10_A	et	f	\N
124562	linnast	"linnane %linna  )NE_aA  <linn ;22_S	et	f	\N
124563	linnast	linnast =ast  (SgN  >linn+ast !22_S	et	f	\N
124568	palavasse	palavasse =palava  (SgIll  >palav !02_A	et	f	\N
124569	palavasse	"palav %pala  )V_vA  <palama ;27_V	et	f	\N
124582	xviii-xx	### xviii-xx	et	f	\N
124583	koorilaul	koorilaul =lau  (SgAd  >koori+laug !22_SA	et	f	\N
124584	koorilaul	koorilaul =laul  (SgN  >koori+laul !22_S	et	f	\N
124587	helisevad	helisevad =helise  (IndPrPl3  >helisema !27_V	et	f	\N
124588	helisevad	helisevad =heliseva  (PlN  >helisev !02_A	et	f	\N
124590	helisevad	"helisev %helise  )V_vA  <helisema ;27_V	et	f	\N
124610	lõpetajatest	lõpetajatest =lõpetaja  (PlEl  >lõpetaja !01_S	et	f	\N
124611	lõpetajatest	"lõpetaja %lõpeta  )JA_vS  <lõpetama ;27_V	et	f	\N
124612	erinevates	erinevates =erineva  (PlIn  >erinev !02_A	et	f	\N
124613	erinevates	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
124623	esitavate	esitavate =esitava  (PlG  >esitav !02_A	et	f	\N
124624	esitavate	"esitav %esita  )V_vA  <esitama ;27_V	et	f	\N
124628	rituaallaule	?rituaallaule =rituaallau  (SgAll  >rituaallau !26_S	et	f	\N
124629	rituaallaule	?rituaallaule =rituaallaule  (PlP  >rituaallaul !19_S	et	f	\N
124640	innovatsiooni	?innovatsiooni =innovatsioo  (SgTer  >innovatsioo !26_S	et	f	\N
124641	innovatsiooni	?innovatsiooni =innovatsiooni  (SgN  >innovatsiooni !16_S	et	f	\N
124642	innovatsiooni	?innovatsiooni =innovatsiooni  (SgG  >innovatsiooni !16_S	et	f	\N
124643	innovatsiooni	?innovatsiooni =innovatsiooni  (SgG  >innovatsioon !22_S	et	f	\N
124644	innovatsiooni	?innovatsiooni =innovatsiooni  (SgP  >innovatsioon !22_S	et	f	\N
124645	innovatsiooni	?innovatsiooni =innovatsiooni  (SgAdt  >innovatsioon !22_S	et	f	\N
124646	innovatsiooni	?innovatsiooni =innovatsiooni  (IndPrPs_  >innovatsioonima !28_V	et	f	\N
124647	innovatsiooni	?innovatsiooni =innovatsiooni  (ImpPrSg2  >innovatsioonima !28_V	et	f	\N
124648	värskemas	?värskemas =värske  (SupIn  >värskema !27_V	et	f	\N
124649	värskemas	?värskemas =värskema  (SgIn  >värskem !02_A	et	f	\N
124668	innovatsioonide	?innovatsioonide =innovatsiooni  (PlG  >innovatsiooni !16_S	et	f	\N
124669	innovatsioonide	?innovatsioonide =innovatsiooni  (PlG  >innovatsioon !22_S	et	f	\N
124670	lätist	?lätist =läti  (SgEl  >läti !16_S	et	f	\N
124671	lätist	?lätist =läti  (SgEl  >lätt !22_S	et	f	\N
124672	lätist	?lätist =lätis  (SgP  >lätis !09_S	et	f	\N
124673	lätist	?lätist =lätist  (SgN  >lätist !22_S	et	f	\N
124681	tulemuste	tulemuste =tulemus  (PlG  >tulemus !11_S	et	f	\N
124682	tulemuste	tulemuste =muste  (PlP  >tule+must !22_AS	et	f	\N
124688	tammiste	tammiste =tammis  (PlG  >tammine !10_A	et	f	\N
124689	tammiste	"tammine %tammi  )NE_aA  <tamm ;22_S	et	f	\N
124691	tammiste	tammiste =iste  (SgN  >tamm+iste !05_S	et	f	\N
124692	tammiste	tammiste =iste  (SgN  >tamm+iste !06_S	et	f	\N
124694	tammiste	tammiste =iste  (SgG  >tamm+iste !06_S	et	f	\N
124695	tammiste	tammiste =iste  (PlP  >tamm+ist !22_S	et	f	\N
124696	majandusministeeriumi	majandusministeeriumi =ministeeriumi  (SgG  >majandus+ministeerium !19~02_S	et	f	\N
124697	majandusministeeriumi	majandusministeeriumi =ministeeriumi  (SgP  >majandus+ministeerium !19_S	et	f	\N
124698	majandusministeeriumi	majandusministeeriumi =ministeeriumi  (SgAdt  >majandus+ministeerium !19_S	et	f	\N
124718	esimeste	esimeste =esimes  (PlG  >esimene !12_OP	et	f	\N
124719	esimeste	esimeste =meste  (PlP  >esi+mest !22_S	et	f	\N
124726	patentimise	patentimise =patentimise  (SgG  >patentimine !12_S	et	f	\N
124727	patentimise	"patentimine %patenti  )MINE_vS  <patentima ;28_V	et	f	\N
124730	kõrgete	kõrgete =kõrge  (PlG  >kõrge !01_A	et	f	\N
124731	kõrgete	kõrgete =e  (PlG  >kõrg+esi !15_S	et	f	\N
124741	kippuvad	kippuvad =kippuva  (PlN  >kippuv !02_A	et	f	\N
124742	kippuvad	"kippuv %kippu  )V_vA  <kippuma ;28_V	et	f	\N
124747	kohtla-järve	kohtla-järve =järve  (SgG  >kohtla-järv !22_S	et	f	\N
124748	kohtla-järve	kohtla-järve =järve  (SgP  >kohtla-järv !22_S	et	f	\N
124749	kohtla-järve	kohtla-järve =järve  (SgAdt  >kohtla-järv !22_S	et	f	\N
124750	kohtla-järve	kohtla-järve =järve  (PlP  >kohtla-järv !22_S	et	f	\N
124757	projekti	projekti =projekti  (SgG  >projekt !22_S	et	f	\N
124758	projekti	projekti =projekti  (SgP  >projekt !22_S	et	f	\N
124759	projekti	projekti =projekti  (SgAdt  >projekt !22_S	et	f	\N
124769	eelarve	eelarve =arve  (SgN  >eel+arve !06_S	et	f	\N
124770	eelarve	eelarve =arve  (SgG  >eel+arve !06_S	et	f	\N
124771	eelarve	eelarve =arve  (PlP  >eel+arv !22_S	et	f	\N
124773	rahastamine	?rahastamine =rahastamine  (SgN  >rahastamine !12_S	et	f	\N
124774	rahastamine	?rahastamine =rahastamine  (PlP  >rahastamin !19_S	et	f	\N
124775	rahastamine	?rahastamine =stamine  (SgN  >raha+stamine !10_A	et	f	\N
124797	boiko	?boiko =boiko  (SgN  >boiko !16_S	et	f	\N
124799	boiko	?boiko =boiko  (SgG  >boiko !16_S	et	f	\N
124810	tutvustuse	tutvustuse =tutvustuse  (SgG  >tutvustus !11_S	et	f	\N
124814	tutvustuse	"tutvustus %tutvusta  )US_vS  <tutvustama ;27_V	et	f	\N
124829	kultuuripärandiga	kultuuripärandiga =iga  (SgN  >kultuuri+pärand+iga !18_S	et	f	\N
124589	bortnjanski	?bortnjanski =bortnjanski  (SgG  >bortnjansk !02_S	et	f	\N
124591	bortnjanski	?bortnjanski =bortnjanski  (IndPrPs_  >bortnjanskima !28_V	et	f	\N
124592	bortnjanski	?bortnjanski =bortnjanski  (ImpPrSg2  >bortnjanskima !28_V	et	f	\N
124593	bortnjanski	?bortnjanski =bortnjans  (SgN^  >bortnjans !02_S	et	f	\N
124596	heliloojade	?heliloojade =helilooja  (PlG  >helilooja !16_S	et	f	\N
124597	heliloojade	?heliloojade =jade  (SgN  >heli+loo+jade !16_S	et	f	\N
124598	heliloojade	?heliloojade =jade  (SgG  >heli+loo+jade !16_S	et	f	\N
124601	konservatooriumi	konservatooriumi =konservatooriumi  (SgG  >konservatoorium !19~02_S	et	f	\N
124602	konservatooriumi	konservatooriumi =konservatooriumi  (SgP  >konservatoorium !19_S	et	f	\N
124604	konservatooriumi	konservatooriumi =konservatooriumi  (SgAdt  >konservatoorium !19_S	et	f	\N
124618	levitamist	levitamist =levitamis  (SgP  >levitamine !12_S	et	f	\N
124619	levitamist	"levitamine %levita  )MINE_vS  <levitama ;27_V	et	f	\N
124630	orkestreeritud	orkestreeritud =orkestreeri  (PtsPtIps  >orkestreerima !28_V	et	f	\N
124631	orkestreeritud	orkestreeritud =orkestreeritu  (PlN  >orkestreeritu !01_S	et	f	\N
124632	orkestreeritud	"orkestreeritu %orkestreeri  )TU1_vS  <orkestreerima ;28_V	et	f	\N
124633	orkestreeritud	orkestreeritud =orkestreeritud  (ID  >orkestreeritud !41_A	et	f	\N
124634	orkestreeritud	"orkestreeritud %orkestreeri  )TUD_vA  <orkestreerima ;28_V	et	f	\N
124660	tergi	?tergi =tergi  (ID  >tergi !41_D	et	f	\N
124661	tergi	?tergi =tergi  (SgG  >terk !22_S	et	f	\N
124662	tergi	?tergi =tergi  (SgP  >terg !22_S	et	f	\N
124663	tergi	?tergi =tergi  (SgAdt  >terg !22_S	et	f	\N
124664	tergi	?tergi =tergi  (IndPrPs_  >terkima !28_V	et	f	\N
124665	tergi	?tergi =tergi  (ImpPrSg2  >terkima !28_V	et	f	\N
124710	info-kommunikatsiooni	info-kommunikatsiooni =kommunikatsiooni  (SgG  >info-kommunikatsioon !22_S	et	f	\N
124711	info-kommunikatsiooni	info-kommunikatsiooni =kommunikatsiooni  (SgP  >info-kommunikatsioon !22_S	et	f	\N
124712	info-kommunikatsiooni	info-kommunikatsiooni =kommunikatsiooni  (SgAdt  >info-kommunikatsioon !22_S	et	f	\N
124732	ekspordi	ekspordi =ekspordi  (SgG  >eksport !22_S	et	f	\N
124733	ekspordi	ekspordi =ekspordi  (IndPrPs_  >eksportima !28_V	et	f	\N
124734	ekspordi	ekspordi =ekspordi  (ImpPrSg2  >eksportima !28_V	et	f	\N
124737	aastateks	aastateks =aasta  (PlTr  >aasta !01_S	et	f	\N
124738	aastateks	aastateks =tate  (PlTr  >aas+tatt !22_S	et	f	\N
124760	uee	?uee =uee  (SgN  >uee !26_S	et	f	\N
124761	uee	?uee =uee  (SgG  >uee !26_S	et	f	\N
124762	loomine	loomine =loomine  (SgN  >loomine !12?10_S	et	f	\N
124763	loomine	"loomine %loo  )MINE_vS  <looma ;38_V	et	f	\N
124764	loomine	"loomine %loomi  )NE_aA  <loom ;22_S	et	f	\N
124765	loomine	loomine =ine  (SgN  >loom+ine !16_S	et	f	\N
124766	loomine	loomine =ine  (SgG  >loom+ine !16_S	et	f	\N
124802	piirialase	piirialase =alase  (SgG  >piiri+alane !10_AS	et	f	\N
124803	piirialase	"piiri+alane %ala  )NE_aA  <piiri+ala ;17_S	et	f	\N
124823	juhtkod	?juhtkod =juhtko  (PlN  >juhtko !16_S	et	f	\N
124824	juhtkod	?juhtkod =juhtkod  (SgN  >juhtkod !02_S	et	f	\N
124832	turistimarsruuti	turistimarsruuti =marsruuti  (SgP  >turisti+marsruut !22_S	et	f	\N
124834	turistimarsruuti	turistimarsruuti =marsruuti  (SgAdt  >turisti+marsruut !22_S	et	f	\N
124839	kultuurivaldkonnas	kultuurivaldkonnas =konna  (SgIn  >kultuuri+vald+konn !22_S	et	f	\N
124840	kultuurivaldkonnas	kultuurivaldkonnas =valdkonna  (SgIn  >kultuuri+valdkond !22_S	et	f	\N
124851	õppeseminari	õppeseminari =seminari  (SgG  >õppe+seminar !19_S	et	f	\N
124852	õppeseminari	õppeseminari =seminari  (SgP  >õppe+seminar !19_S	et	f	\N
124853	õppeseminari	õppeseminari =seminari  (SgAdt  >õppe+seminar !19_S	et	f	\N
124907	kutsutud	kutsutud =kutsu  (PtsPtIps  >kutsuma !28_V	et	f	\N
124908	kutsutud	kutsutud =kutsutu  (PlN  >kutsutu !01_S	et	f	\N
124909	kutsutud	"kutsutu %kutsu  )TU1_vS  <kutsuma ;28_V	et	f	\N
124910	kutsutud	"kutsutu %kutsu  )TU2_kA  <kutsu ;16_S	et	f	\N
124911	kutsutud	kutsutud =kutsutud  (ID  >kutsutud !41_A	et	f	\N
124912	kutsutud	"kutsutud %kutsu  )TUD_vA  <kutsuma ;28_V	et	f	\N
124916	põhja	põhja =põhja  (SgG  >põhi !24_S	et	f	\N
124917	põhja	põhja =põhja  (SgP  >põhi !24_S	et	f	\N
124918	põhja	põhja =põhja  (SgAdt  >põhi !24_S	et	f	\N
124919	põhja	põhja =põhja  (IndPrPs_  >põhjama !29_V	et	f	\N
124920	põhja	põhja =põhja  (ImpPrSg2  >põhjama !29_V	et	f	\N
124930	peetri-aegsete	peetri-aegsete =aegse  (PlG  >peetri-aegne !02_A	et	f	\N
124931	peetri-aegsete	peetri-aegsete =sete  (SgN  >peetri-aeg+sete !06_S	et	f	\N
124937	leksika	leksika =leksika  (SgN  >leksika !01_S	et	f	\N
124938	leksika	leksika =leksika  (SgG  >leksika !01_S	et	f	\N
124939	optimistlikku	optimistlikku =optimistlikku  (SgP  >optimistlik !25_A	et	f	\N
124940	optimistlikku	optimistlikku =optimistlikku  (SgAdt  >optimistlik !25_A	et	f	\N
124950	kurameerivad	kurameerivad =kurameeri  (IndPrPl3  >kurameerima !28_V	et	f	\N
124951	kurameerivad	kurameerivad =kurameeriva  (PlN  >kurameeriv !02_A	et	f	\N
124952	kurameerivad	"kurameeriv %kurameeri  )V_vA  <kurameerima ;28_V	et	f	\N
124955	tunnistasid	tunnistasid =tunnista  (IndIpfSg2  >tunnistama !27_V	et	f	\N
124956	tunnistasid	tunnistasid =tunnista  (IndIpfPl3  >tunnistama !27_V	et	f	\N
124990	kp	### kp	et	f	\N
124994	külma	külma =külma  (SgG  >külm !22_AS	et	f	\N
124659	eriku	?eriku =eriku  (ImpPrSg2  >erikuma !27_V	et	f	\N
124666	itaaliaga	?itaaliaga =itaalia  (SgKom  >itaalia !01_S	et	f	\N
124702	esimees	esimees =mee  (SgIn  >esi+mesi !15_S	et	f	\N
124703	esimees	esimees =mees  (SgN  >esi+mees !13_S	et	f	\N
124704	näitajate	näitajate =näitaja  (PlG  >näitaja !01_S	et	f	\N
124705	näitajate	"näitaja %näita  )JA_vS  <näitama ;29_V	et	f	\N
124723	katsemisele	?katsemisele =katsemise  (SgAll  >katsemine !12_S	et	f	\N
124754	koostasid	koostasid =koosta  (PlP  >koost !22_S	et	f	\N
124755	koostasid	koostasid =koosta  (IndIpfSg2  >koostama !27_V	et	f	\N
124756	koostasid	koostasid =koosta  (IndIpfPl3  >koostama !27_V	et	f	\N
124787	kohtla-järvel	kohtla-järvel =järve  (SgAd  >kohtla-järv !22_S	et	f	\N
124789	kohtla-järvel	kohtla-järvel =järve  (PlAd  >kohtla-järv !22_S	et	f	\N
124794	filosoofia	filosoofia =filosoofia  (SgN  >filosoofia !01_S	et	f	\N
124795	filosoofia	filosoofia =filosoofia  (SgG  >filosoofia !01_S	et	f	\N
124809	nedne	?nedne =nedne  (SgN  >nedne !02_A	et	f	\N
124811	nedne	?nedne =nedne  (PlP  >nedn !22_S	et	f	\N
124812	nedne	?nedne =nedne  (IndPrPs_  >nednema !27_V	et	f	\N
124813	nedne	?nedne =nedne  (ImpPrSg2  >nednema !27_V	et	f	\N
124835	sihiks	sihiks =sihi  (SgTr  >siht !22_S	et	f	\N
124836	sihiks	sihiks =sihi  (KndPrPs  >sihtima !28_V	et	f	\N
124872	aleksandr	?aleksandr =ksandr  (SgN  >ale+ksandr !22_S	et	f	\N
124922	poolteist	poolteist =te  (PlEl  >pool+tee !26_S	et	f	\N
124924	poolteist	poolteist =teist  (SgN  >pool+teist !22_S	et	f	\N
124948	avaldamise	avaldamise =avaldamise  (SgG  >avaldamine !12_S	et	f	\N
124949	avaldamise	"avaldamine %avalda  )MINE_vS  <avaldama ;27_V	et	f	\N
124958	krapula	?krapula =krapula  (SgN  >krapula !01_S	et	f	\N
124959	krapula	?krapula =krapula  (SgG  >krapula !01_S	et	f	\N
124961	seisid	seisid =seis  (IndIpfSg2  >seisma !32_V	et	f	\N
124962	seisid	seisid =seis  (IndIpfPl3  >seisma !32_V	et	f	\N
124963	seisid	seisid =seisi  (PlN  >seis !22_S	et	f	\N
124980	postkontori	postkontori =ori  (SgN  >post+kont+ori !24_S	et	f	\N
124981	postkontori	postkontori =kontori  (SgG  >post+kontor !02_S	et	f	\N
125005	adressaati	adressaati =adressaati  (SgP  >adressaat !22_S	et	f	\N
125006	adressaati	adressaati =adressaati  (SgAdt  >adressaat !22_S	et	f	\N
125010	venelastele	venelastele =venelas  (PlAll  >venelane !12_S	et	f	\N
125011	venelastele	venelastele =las  (PlAll  >vene+laps !14_S	et	f	\N
125012	venelastele	venelastele =laste  (PlAll  >vene+last !22_S	et	f	\N
125024	petrovide	### petrovide	et	f	\N
125037	ja-a	### ja-a	et	f	\N
125052	kõlavad	kõlavad =kõla  (IndPrPl3  >kõlama !27_V	et	f	\N
125053	kõlavad	kõlavad =kõlava  (PlN  >kõlav !02_A	et	f	\N
125054	kõlavad	"kõlav %kõla  )V_vA  <kõlama ;27_V	et	f	\N
125082	med	### med	et	f	\N
125087	gastinsõ	### gastinsõ	et	f	\N
125091	prännikule	?prännikule =pränniku  (SgAll  >pränniku !01_S	et	f	\N
125093	prännikule	?prännikule =pränniku  (SgAll  >prännik !02_S	et	f	\N
125094	prännikule	?prännikule =prännikule  (PlP  >prännikul !19_S	et	f	\N
125108	stockholm	?stockholm =stockholm  (SgN  >stockholm !22_S	et	f	\N
125109	stroomi	?stroomi =stroomi  (SgN  >stroomi !16_S	et	f	\N
125110	stroomi	?stroomi =stroomi  (SgG  >stroomi !16_S	et	f	\N
125111	stroomi	?stroomi =stroomi  (SgG  >stroom !22_S	et	f	\N
125112	stroomi	?stroomi =stroomi  (SgP  >stroom !22_S	et	f	\N
125113	stroomi	?stroomi =stroomi  (SgAdt  >stroom !22_S	et	f	\N
125114	stroomi	?stroomi =stroomi  (IndPrPs_  >stroomima !28_V	et	f	\N
125115	stroomi	?stroomi =stroomi  (ImpPrSg2  >stroomima !28_V	et	f	\N
125116	pealinna	pealinna =inna  (SgG  >peal+ind !22_S	et	f	\N
125117	pealinna	pealinna =linna  (SgG  >pea+linn !22_S	et	f	\N
125118	pealinna	pealinna =linna  (SgP  >pea+linn !22_S	et	f	\N
125119	pealinna	pealinna =linna  (SgAdt  >pea+linn !22_S	et	f	\N
125125	põhja-tallinna	?põhja-tallinna =tallinna  (SgN  >põhja-tallinna !16_S	et	f	\N
125126	põhja-tallinna	?põhja-tallinna =tallinna  (SgG  >põhja-tallinna !16_S	et	f	\N
125127	põhja-tallinna	?põhja-tallinna =tallinna  (SgP  >põhja-tallinn !22_H	et	f	\N
125130	põhja-tallinna	?põhja-tallinna =tallinna  (SgAdt  >põhja-tallinn !22_H	et	f	\N
125215	mahajäetud	mahajäetud =jäe  (PtsPtIps  >maha+_jätma !35_V	et	f	\N
125218	mahajäetud	mahajäetud =jäetu  (PlN  >maha+jäetu !01_S	et	f	\N
125233	küllatki	?küllatki =küllatki  (SgG  >küllatk !22_S	et	f	\N
125234	küllatki	?küllatki =küllatki  (SgP  >küllatk !22_S	et	f	\N
125235	küllatki	?küllatki =küllatki  (SgAdt  >küllatk !22_S	et	f	\N
125236	küllatki	?küllatki =küllatki  (IndPrPs_  >küllatkima !28_V	et	f	\N
125237	küllatki	?küllatki =küllatki  (ImpPrSg2  >küllatkima !28_V	et	f	\N
125238	küllatki	?küllatki =külla  (SgP^  >külla !16_S	et	f	\N
125239	küllatki	?küllatki =küllat  (SgN^  >küllat !02_S	et	f	\N
125275	pelgulinnas	pelgulinnas =linna  (SgIn  >pelgu+linn !22_S	et	f	\N
125276	pelgulinnas	pelgulinnas =linnas  (SgN  >pelgu+linnas !09_S	et	f	\N
125322	srtoomi	?srtoomi =srtoomi  (SgN  >srtoomi !16_S	et	f	\N
125323	srtoomi	?srtoomi =srtoomi  (SgG  >srtoomi !16_S	et	f	\N
125324	srtoomi	?srtoomi =srtoomi  (SgG  >srtoom !22_S	et	f	\N
124725	konstrueerimisele	"konstrueerimine %konstrueeri  )MINE_vS  <konstrueerima ;28_V	et	f	\N
124743	kohtla-järve	kohtla-järve =järve  (SgG  >kohtla-järv !22_S	et	f	\N
124744	kohtla-järve	kohtla-järve =järve  (SgP  >kohtla-järv !22_S	et	f	\N
124745	kohtla-järve	kohtla-järve =järve  (SgAdt  >kohtla-järv !22_S	et	f	\N
124746	kohtla-järve	kohtla-järve =järve  (PlP  >kohtla-järv !22_S	et	f	\N
124751	sankt-peterburi	?sankt-peterburi =peterburi  (SgG  >sankt-peterbur !19_S	et	f	\N
124752	sankt-peterburi	?sankt-peterburi =peterburi  (SgP  >sankt-peterbur !19_S	et	f	\N
124753	sankt-peterburi	?sankt-peterburi =peterburi  (SgAdt  >sankt-peterbur !19_S	et	f	\N
124767	ettekavatsetud	ettekavatsetud =kavatse  (PtsPtIps  >ette+_kavatsema !27_V	et	f	\N
124768	ettekavatsetud	ettekavatsetud =kavatsetu  (PlN  >ette+kavatsetu !01_S	et	f	\N
124772	mln	### mln	et	f	\N
124776	interreg	### interreg	et	f	\N
124782	filiaali	filiaali =filiaali  (SgG  >filiaal !22_S	et	f	\N
124783	filiaali	filiaali =filiaali  (SgP  >filiaal !22_S	et	f	\N
124784	filiaali	filiaali =filiaali  (SgAdt  >filiaal !22_S	et	f	\N
124796	aleksei	?aleksei =aleksei  (SgN  >aleksei !26_S	et	f	\N
124798	aleksei	?aleksei =aleksei  (SgG  >aleksei !26_S	et	f	\N
124800	aleksei	?aleksei =ksei  (SgN  >ale+ksei !26_S	et	f	\N
124801	aleksei	?aleksei =ksei  (SgG  >ale+ksei !26_S	et	f	\N
124804	raamides	raamides =raami  (PlIn  >raam !22_S	et	f	\N
124805	raamides	raamides =raami  (Ger  >raamima !28_V	et	f	\N
124815	produkti	produkti =produkti  (SgG  >produkt !22_S	et	f	\N
124816	produkti	produkti =produkti  (SgP  >produkt !22_S	et	f	\N
124817	produkti	produkti =produkti  (SgAdt  >produkt !22_S	et	f	\N
124818	uhkuseks	uhkuseks =uhkuse  (SgTr  >uhkus !11~09_S	et	f	\N
124819	uhkuseks	"uhkus %uhke  )US_aS  <uhke ;01_A	et	f	\N
124820	põlevkivimuuseumi	põlevkivimuuseumi =muuseumi  (SgG  >põlev+kivi+muuseum !19~02_S	et	f	\N
124821	põlevkivimuuseumi	põlevkivimuuseumi =muuseumi  (SgP  >põlev+kivi+muuseum !19_S	et	f	\N
124822	põlevkivimuuseumi	põlevkivimuuseumi =muuseumi  (SgAdt  >põlev+kivi+muuseum !19_S	et	f	\N
124845	pealegi	pealegi =pealegi  (ID  >pealegi !41_D	et	f	\N
124846	pealegi	pealegi =pea  (SgAll^  >pea !26_S	et	f	\N
124847	pealegi	pealegi =peale  (ID^  >peale !41_DK	et	f	\N
124868	erilisest	erilisest =erilise  (SgEl  >eriline !12_A	et	f	\N
124869	erilisest	"eriline %eri  )LINE_aA  <eri ;17_S	et	f	\N
124875	eelkäjate	?eelkäjate =eelkäja  (PlG  >eelkäja !01_S	et	f	\N
124876	eelkäjate	?eelkäjate =eelkäja  (PlG  >eelkäjas !02_A	et	f	\N
124882	soomes	?soomes =soome  (PlIn  >soom !22_S	et	f	\N
124883	soomes	?soomes =soome  (IndIpfSg3  >soomema !27_V	et	f	\N
124884	soomes	?soomes =soomes  (SgN  >soomes !09_S	et	f	\N
124885	kaitseala	kaitseala =ala  (SgN  >kaitse+ala !17_S	et	f	\N
124887	kaitseala	kaitseala =ala  (SgG  >kaitse+ala !17_S	et	f	\N
124889	kaitseala	kaitseala =ala  (SgP  >kaitse+ala !17_S	et	f	\N
124893	marieham	?marieham =marieham  (SgN  >marieham !02_A	et	f	\N
124894	marieham	?marieham =eham  (SgN  >mari+eham !02_A	et	f	\N
124895	aleksandri	?aleksandri =aleksandri  (SgG  >aleksander !02_S	et	f	\N
124896	aleksandri	?aleksandri =aleksandri  (IndPrPs_  >aleksandrima !28_V	et	f	\N
124897	aleksandri	?aleksandri =aleksandri  (ImpPrSg2  >aleksandrima !28_V	et	f	\N
124898	aleksandri	?aleksandri =ksandri  (SgN  >ale+ksandri !01_S	et	f	\N
124899	aleksandri	?aleksandri =ksandri  (SgG  >ale+ksandri !01_S	et	f	\N
124900	aleksandri	?aleksandri =ksandri  (SgG  >ale+ksander !02_S	et	f	\N
124921	kestsid	kestsid =kest  (IndIpfSg2  >kestma !34_V	et	f	\N
124923	kestsid	kestsid =kest  (IndIpfPl3  >kestma !34_V	et	f	\N
124941	tjebja	?tjebja =tjebja  (SgN  >tjebja !16_S	et	f	\N
124942	tjebja	?tjebja =tjebja  (SgG  >tjebjas !02_A	et	f	\N
124943	tjebja	?tjebja =tjebja  (SgG  >tjebja !16_S	et	f	\N
124944	tjebja	?tjebja =tjebja  (IndPrPs_  >tjebjama !27_V	et	f	\N
124945	tjebja	?tjebja =tjebja  (ImpPrSg2  >tjebjama !27_V	et	f	\N
124988	valitsemise	valitsemise =valitsemise  (SgG  >valitsemine !12_S	et	f	\N
124989	valitsemise	"valitsemine %valitse  )MINE_vS  <valitsema ;27_V	et	f	\N
125015	varjasid	varjasid =varja  (PlP  >vari !24_S	et	f	\N
125016	varjasid	varjasid =varja  (IndIpfSg2  >varjama !29_V	et	f	\N
125017	varjasid	varjasid =varja  (IndIpfPl3  >varjama !29_V	et	f	\N
125020	tuletasid	tuletasid =tuleta  (IndIpfSg2  >tuletama !27_V	et	f	\N
125022	tuletasid	tuletasid =tuleta  (IndIpfPl3  >tuletama !27_V	et	f	\N
125023	sidorovite	?sidorovite =sidorovi  (PlG  >sidorov !02_A	et	f	\N
125025	perepelkinite	?perepelkinite =perepelkini  (PlG  >perepelkin !02_S	et	f	\N
125026	perepelkinite	?perepelkinite =pelkini  (PlG  >pere+pelkin !02_S	et	f	\N
125035	põlise	põlise =põlise  (SgG  >põline !10_A	et	f	\N
125036	põlise	"põline %põli  )NE_aA  <põli ;24_S	et	f	\N
125043	novgorodi	### novgorodi	et	f	\N
125044	segu	segu =segu  (SgN  >segu !17_S	et	f	\N
125045	segu	segu =segu  (SgG  >segu !17_S	et	f	\N
125046	segu	segu =segu  (SgP  >segu !17_S	et	f	\N
125047	keetmise	keetmise =keetmise  (SgG  >keetmine !12?10_S	et	f	\N
125048	keetmise	"keetmine %keet  )MINE_vS  <keetma ;34_V	et	f	\N
125058	kartuh	?kartuh =kartuh  (ID  >kartuh !41_I	et	f	\N
125059	soni	soni =soni  (SgN  >soni !17_S	et	f	\N
124781	ühistegevust	"ühis+tegevus %tegeva  )US_aS  <ühis+tegev ;02_A	et	f	\N
124785	loomisest	loomisest =loomise  (SgEl  >loomis !09_S	et	f	\N
124786	loomisest	loomisest =loomise  (SgEl  >loomine !12?10_S	et	f	\N
124788	loomisest	"loomine %loo  )MINE_vS  <looma ;38_V	et	f	\N
124790	loomisest	"loomine %loomi  )NE_aA  <loom ;22_S	et	f	\N
124791	esindaja	esindaja =esindaja  (SgN  >esindaja !01_S	et	f	\N
124792	esindaja	"esindaja %esinda  )JA_vS  <esindama ;27_V	et	f	\N
124793	esindaja	esindaja =esindaja  (SgG  >esindaja !01_S	et	f	\N
124806	üliõpilaste	üliõpilaste =las  (PlG  >üli+õpi+laps !14_S	et	f	\N
124807	üliõpilaste	üliõpilaste =laste  (PlP  >üli+õpi+last !22_S	et	f	\N
124808	üliõpilaste	üliõpilaste =õpilas  (PlG  >üli+õpilane !12_S	et	f	\N
124825	plaanitakse	plaanitakse =plaani  (IndPrIps  >plaanima !28_V	et	f	\N
124826	plaanitakse	plaanitakse =takse  (PlP  >plaani+taks !22_S	et	f	\N
124827	sankt-peterburisse	?sankt-peterburisse =peterburi  (SgIll  >sankt-peterbur !19_S	et	f	\N
124828	sankt-peterburisse	?sankt-peterburisse =peterburisse  (SgG  >sankt-peterburisne !02_A	et	f	\N
124830	sankt-peterburisse	?sankt-peterburisse =peterburisse  (PlP  >sankt-peterburiss !22_S	et	f	\N
124843	arendamisega	arendamisega =arendamise  (SgKom  >arendamine !12_S	et	f	\N
124844	arendamisega	"arendamine %arenda  )MINE_vS  <arendama ;27_V	et	f	\N
124873	uhked	uhked =uhke  (PlN  >uhke !01_A	et	f	\N
124874	uhked	uhked =uhke  (PlN  >uhe !06_S	et	f	\N
124877	alandi	alandi =alandi  (SgN  >alandi !01_S	et	f	\N
124878	alandi	alandi =alandi  (SgG  >alandi !01_S	et	f	\N
124879	alandi	alandi =alandi  (SgG  >aland !02_S	et	f	\N
124880	asutasid	asutasid =asuta  (IndIpfSg2  >asutama !27_V	et	f	\N
124881	asutasid	asutasid =asuta  (IndIpfPl3  >asutama !27_V	et	f	\N
124886	põhjamaades	põhjamaades =maa  (PlIn  >põhja+maa !26_S	et	f	\N
124888	põhjamaades	põhjamaades =maade  (PlIn  >põhja+maat !22_S	et	f	\N
124901	aleksandrova	?aleksandrova =aleksandrova  (SgN  >aleksandrova !16_S	et	f	\N
124902	aleksandrova	?aleksandrova =aleksandrova  (SgG  >aleksandrov !02_A	et	f	\N
124903	aleksandrova	?aleksandrova =aleksandrova  (SgG  >aleksandrova !16_S	et	f	\N
124904	aleksandrova	?aleksandrova =ksandrova  (SgN  >ale+ksandrova !01_S	et	f	\N
124905	aleksandrova	?aleksandrova =ksandrova  (SgG  >ale+ksandrova !01_S	et	f	\N
124906	aleksandrova	?aleksandrova =ksandrova  (SgG  >ale+ksandrov !02_A	et	f	\N
124935	tollest	tollest =tolle  (SgEl  >too !00_P	et	f	\N
124936	tollest	tollest =tolle  (PlEl  >toll !22_S	et	f	\N
124953	kohalike	kohalike =kohalike  (PlG  >kohalik !25_AS	et	f	\N
124954	kohalike	kohalike =ike  (SgN  >kohal+ike !06_S	et	f	\N
124957	südamlikkult	?südamlikkult =südamlikkult  (ID  >südamlikkult !41_D	et	f	\N
124960	pohmell	?pohmell =pohmell  (SgN  >pohmell !22_S	et	f	\N
124969	bomarsund	?bomarsund =bomarsund  (SgN  >bomarsund !22_S	et	f	\N
124970	krimmi	?krimmi =krimmi  (SgN  >krimmi !16_S	et	f	\N
124971	krimmi	?krimmi =krimmi  (SgG  >krimmi !16_S	et	f	\N
124972	krimmi	?krimmi =krimmi  (SgG  >krimm !22_S	et	f	\N
124973	krimmi	?krimmi =krimmi  (SgP  >krimm !22_S	et	f	\N
124974	krimmi	?krimmi =krimmi  (SgAdt  >krimm !22_S	et	f	\N
124975	krimmi	?krimmi =krimmi  (IndPrPs_  >krimmima !28_V	et	f	\N
124976	krimmi	?krimmi =krimmi  (ImpPrSg2  >krimmima !28_V	et	f	\N
124977	kaupmeeste	kaupmeeste =mees  (PlG  >kaup+meene !10_A	et	f	\N
124978	kaupmeeste	"kaup+meene %mee  )NE_aA  <kaup+mesi ;15_S	et	f	\N
124979	kaupmeeste	kaupmeeste =mees  (PlG  >kaup+mees !13_S	et	f	\N
124982	postihoone	postihoone =hoone  (SgN  >posti+hoone !06_S	et	f	\N
124983	postihoone	"posti+hoone %hoo  )NE_aA  <posti+hoog ;22_S	et	f	\N
124984	postihoone	postihoone =hoone  (SgG  >posti+hoone !06_S	et	f	\N
124985	postihoone	postihoone =hoone  (PlP  >posti+hoon !22_A	et	f	\N
124986	nikolai	?nikolai =nikolai  (SgN  >nikolai !26_S	et	f	\N
124987	nikolai	?nikolai =nikolai  (SgG  >nikolai !26_S	et	f	\N
125013	mõistatus	mõistatus =mõistatus  (SgN  >mõistatus !11_S	et	f	\N
125014	mõistatus	"mõistatus %mõistata  )US_vS  <mõistatama ;27_V	et	f	\N
125027	uhkust	uhkust =uhkus  (SgP  >uhkus !11~09_S	et	f	\N
125028	uhkust	"uhkus %uhke  )US_aS  <uhke ;01_A	et	f	\N
125029	turisti	turisti =turisti  (SgG  >turist !22_S	et	f	\N
125030	turisti	turisti =turisti  (SgP  >turist !22_S	et	f	\N
125031	turisti	turisti =turisti  (SgAdt  >turist !22_S	et	f	\N
125039	kuka	?kuka =kuka  (SgN  >kuka !16_S	et	f	\N
125040	kuka	?kuka =kuka  (SgG  >kuka !16_S	et	f	\N
125041	kuka	?kuka =kuka  (IndPrPs_  >kukama !27_V	et	f	\N
125042	kuka	?kuka =kuka  (ImpPrSg2  >kukama !27_V	et	f	\N
125055	rootslaste	rootslaste =rootslas  (PlG  >rootslane !12?10_S	et	f	\N
125056	rootslaste	rootslaste =las  (PlG  >roots+laps !14_S	et	f	\N
125057	rootslaste	rootslaste =laste  (PlP  >roots+last !22_S	et	f	\N
125061	ek	### ek	et	f	\N
125083	kofta	?kofta =kofta  (SgN  >kofta !16_S	et	f	\N
125084	kofta	?kofta =kofta  (SgG  >kofta !16_S	et	f	\N
125085	kofta	?kofta =kofta  (IndPrPs_  >koftama !29_V	et	f	\N
125086	kofta	?kofta =kofta  (ImpPrSg2  >koftama !29_V	et	f	\N
125098	söödavat	söödavat =söö  (KvtPrIps  >sööma !38_V	et	f	\N
125099	söödavat	söödavat =söödava  (SgP  >söödav !02_A	et	f	\N
124831	kultuuripärandiga	kultuuripärandiga =iga  (SgP  >kultuuri+pärand+iga !18_S	et	f	\N
124833	kultuuripärandiga	kultuuripärandiga =pärandi  (SgKom  >kultuuri+pärand !02_S	et	f	\N
124837	infotehnoloogia	infotehnoloogia =tehnoloogia  (SgN  >info+tehnoloogia !01_S	et	f	\N
124838	infotehnoloogia	infotehnoloogia =tehnoloogia  (SgG  >info+tehnoloogia !01_S	et	f	\N
124841	lõpetamise	lõpetamise =lõpetamise  (SgG  >lõpetamine !12_S	et	f	\N
124842	lõpetamise	"lõpetamine %lõpeta  )MINE_vS  <lõpetama ;27_V	et	f	\N
124848	korraldavad	korraldavad =korralda  (IndPrPl3  >korraldama !27_V	et	f	\N
124849	korraldavad	korraldavad =korraldava  (PlN  >korraldav !02_A	et	f	\N
124850	korraldavad	"korraldav %korralda  )V_vA  <korraldama ;27_V	et	f	\N
124854	viinud	viinud =vii  (PtsPtPs  >viima !38_V	et	f	\N
124855	viinud	viinud =viinu  (PlN  >viinu !01_S	et	f	\N
124856	viinud	"viinu %vii  )NU_vS  <viima ;38_V	et	f	\N
124857	viinud	viinud =viinu  (PlN  >viinu !06_S	et	f	\N
124858	viinud	viinud =viinud  (ID  >viinud !41_A	et	f	\N
124859	viinud	"viinud %vii  )NUD_vA  <viima ;38_V	et	f	\N
124860	äratanud	äratanud =ärata  (PtsPtPs  >äratama !27_V	et	f	\N
124861	äratanud	äratanud =äratanu  (PlN  >äratanu !01_S	et	f	\N
124862	äratanud	"äratanu %ärata  )NU_vS  <äratama ;27_V	et	f	\N
124863	äratanud	äratanud =äratanud  (ID  >äratanud !41_A	et	f	\N
124864	äratanud	"äratanud %ärata  )NUD_vA  <äratama ;27_V	et	f	\N
124865	äratanud	äratanud =tanu  (PlN  >ära+tanu !17_S	et	f	\N
124866	ühiskondlikku	ühiskondlikku =ühiskondlikku  (SgP  >ühiskondlik !25_A	et	f	\N
124867	ühiskondlikku	ühiskondlikku =ühiskondlikku  (SgAdt  >ühiskondlik !25_A	et	f	\N
124870	dusman	?dusman =dusma  (IndPrSg1  >dusmama !29_V	et	f	\N
124871	dusman	?dusman =dusman  (SgN  >dusman !02_S	et	f	\N
124890	impeeriumi	impeeriumi =impeeriumi  (SgG  >impeerium !19~02_S	et	f	\N
124891	impeeriumi	impeeriumi =impeeriumi  (SgP  >impeerium !19_S	et	f	\N
124892	impeeriumi	impeeriumi =impeeriumi  (SgAdt  >impeerium !19_S	et	f	\N
124913	seaduslikult	seaduslikult =seadusliku  (SgAbl  >seaduslik !25_A	et	f	\N
124914	seaduslikult	seaduslikult =seaduslikult  (ID  >seaduslikult !41_D	et	f	\N
124915	seaduslikult	"seaduslikult %seadusliku  )LT_mD  <seaduslik ;25_A	et	f	\N
124925	seadmestatud	seadmestatud =seadmesta  (PtsPtIps  >seadmestama !27_V	et	f	\N
124926	seadmestatud	seadmestatud =seadmestatu  (PlN  >seadmestatu !01_S	et	f	\N
124927	seadmestatud	"seadmestatu %seadmesta  )TU1_vS  <seadmestama ;27_V	et	f	\N
124928	seadmestatud	seadmestatud =seadmestatud  (ID  >seadmestatud !41_A	et	f	\N
124929	seadmestatud	"seadmestatud %seadmesta  )TUD_vA  <seadmestama ;27_V	et	f	\N
124932	kaardiväelaste	kaardiväelaste =las  (PlG  >kaardi+väe+laps !14_S	et	f	\N
124933	kaardiväelaste	kaardiväelaste =laste  (PlP  >kaardi+väe+last !22_S	et	f	\N
124934	kaardiväelaste	kaardiväelaste =väelas  (PlG  >kaardi+väelane !12?10_S	et	f	\N
124946	tähenduses	tähenduses =tähenduse  (SgIn  >tähendus !11_S	et	f	\N
124947	tähenduses	"tähendus %tähenda  )US_vS  <tähendama ;27_V	et	f	\N
124964	bomarsundi	?bomarsundi =bomarsundi  (SgG  >bomarsunt !22_S	et	f	\N
124965	bomarsundi	?bomarsundi =bomarsundi  (SgP  >bomarsund !22_S	et	f	\N
124966	bomarsundi	?bomarsundi =bomarsundi  (SgAdt  >bomarsund !22_S	et	f	\N
124967	bomarsundi	?bomarsundi =bomarsundi  (IndPrPs_  >bomarsuntima !28_V	et	f	\N
124968	bomarsundi	?bomarsundi =bomarsundi  (ImpPrSg2  >bomarsuntima !28_V	et	f	\N
124991	imelikust	imelikust =imeliku  (SgEl  >imelik !25_A	et	f	\N
124992	imelikust	imelikust =imelikus  (SgP  >imelikus !11?09_S	et	f	\N
124993	imelikust	"imelikus %imeliku  )US_aS  <imelik ;25_A	et	f	\N
124999	ühtegi	ühtegi =ühte  (SgAdt  >ükski !00_P	et	f	\N
125000	ühtegi	ühtegi =ühte  (SgP  >ükski !00_P	et	f	\N
125001	ühtegi	ühtegi =ühte  (ID^  >ühte !41_D	et	f	\N
125002	ühtegi	ühtegi =ühte  (SgG^  >ühe !06_S	et	f	\N
125003	ühtegi	ühtegi =ühte  (SgP^  >üks !22_NP	et	f	\N
125004	ühtegi	ühtegi =ühte  (SgAdt^  >üks !22_NP	et	f	\N
125032	kõnelemine	kõnelemine =kõnelemine  (SgN  >kõnelemine !12_S	et	f	\N
125033	kõnelemine	"kõnelemine %kõnele  )MINE_vS  <kõnelema ;27_V	et	f	\N
125034	kõnelemine	"kõnelemine %kõnele  )MINE_vS  <kõnelema ;31_V	et	f	\N
125049	toredalt	toredalt =toreda  (SgAbl  >tore !02_A	et	f	\N
125050	toredalt	toredalt =toredalt  (ID  >toredalt !41_D	et	f	\N
125051	toredalt	"toredalt %toreda  )LT_mD  <tore ;02_A	et	f	\N
125088	sarska	?sarska =sarska  (SgN  >sarska !01_S	et	f	\N
125089	sarska	?sarska =sarska  (SgG  >sarska !01_S	et	f	\N
125090	sarska	?sarska =sarska  (IndPrPs_  >sarskama !29_V	et	f	\N
125092	sarska	?sarska =sarska  (ImpPrSg2  >sarskama !29_V	et	f	\N
125101	kotkase	kotkase =kotkase  (SgG  >kotkane !12~10_A	et	f	\N
125102	kotkase	"kotkane %kotka  )NE_aA  <kotkas ;07_S	et	f	\N
125157	hetkest	hetkest =hetke  (SgEl  >hetk !22_S	et	f	\N
125158	hetkest	hetkest =hetke  (PlEl  >hetk !22_S	et	f	\N
125159	hetkest	hetkest =hetkes  (SgP  >hetkene !12~10_A	et	f	\N
125160	hetkest	"hetkene %hetke  )NE_aA  <hetk ;22_S	et	f	\N
125173	linnavolikogus	linnavolikogus =kogu  (SgIn  >linna+voli+kogu !17_S	et	f	\N
125174	linnavolikogus	linnavolikogus =kogus  (SgN  >linna+voli+kogus !02_A	et	f	\N
125175	linnavolikogus	linnavolikogus =kogus  (SgN  >linna+voli+kogus !09_S	et	f	\N
124995	külma	külma =külma  (SgP  >külm !22_AS	et	f	\N
124996	külma	külma =külma  (SgAdt  >külm !22_AS	et	f	\N
124997	külma	külma =külma  (IndPrPs_  >külmama !29_V	et	f	\N
124998	külma	külma =külma  (ImpPrSg2  >külmama !29_V	et	f	\N
125007	posti	posti =posti  (SgG  >post !22_S	et	f	\N
125008	posti	posti =posti  (SgP  >post !22_S	et	f	\N
125009	posti	posti =posti  (SgAdt  >post !22_S	et	f	\N
125018	juuri	juuri =juur  (PlP  >juur !13_S	et	f	\N
125019	juuri	juuri =juuri  (IndPrPs_  >juurima !28_V	et	f	\N
125021	juuri	juuri =juuri  (ImpPrSg2  >juurima !28_V	et	f	\N
125038	durak	?durak =durak  (SgN  >durak !02_S	et	f	\N
125065	butka	?butka =butka  (SgN  >butka !16_S	et	f	\N
125066	butka	?butka =butka  (SgG  >butka !16_S	et	f	\N
125067	butka	?butka =butka  (IndPrPs_  >butkama !29_V	et	f	\N
125068	butka	?butka =butka  (ImpPrSg2  >butkama !29_V	et	f	\N
125069	hleib	?hleib =hleib  (SgN  >hleib !22_S	et	f	\N
125070	siiani	siiani =siia  (SgTer  >siig !22_S	et	f	\N
125071	siiani	siiani =siiani  (ID  >siiani !41_D	et	f	\N
125072	tootmiseks	tootmiseks =tootmise  (SgTr  >tootmine !12?10_S	et	f	\N
125073	tootmiseks	"tootmine %toot  )MINE_vS  <tootma ;34_V	et	f	\N
125074	pirogi	?pirogi =pirogi  (SgG  >pirog !02_S	et	f	\N
125075	pirogi	?pirogi =piro  (SgN^  >piro !17~16_S	et	f	\N
125076	pirogi	?pirogi =piro  (SgG^  >piro !17~16_S	et	f	\N
125077	pirogi	?pirogi =piro  (SgP^  >piro !17_S	et	f	\N
125078	tegemise	tegemise =tegemise  (SgG  >tegemine !12_S	et	f	\N
125079	tegemise	"tegemine %tege  )MINE_vS  <tegema ;28_V	et	f	\N
125080	tuulutamist	tuulutamist =tuulutamis  (SgP  >tuulutamine !12_S	et	f	\N
125081	tuulutamist	"tuulutamine %tuuluta  )MINE_vS  <tuulutama ;27_V	et	f	\N
125095	vana-vanaisa	vana-vanaisa =isa  (SgN  >vana-vana+isa !17_S	et	f	\N
125096	vana-vanaisa	vana-vanaisa =isa  (SgG  >vana-vana+isa !17_S	et	f	\N
125097	vana-vanaisa	vana-vanaisa =isa  (SgP  >vana-vana+isa !17_S	et	f	\N
125120	volikogu	volikogu =kogu  (SgN  >voli+kogu !17_S	et	f	\N
125121	volikogu	volikogu =kogu  (SgG  >voli+kogu !17_S	et	f	\N
125122	volikogu	volikogu =kogu  (SgP  >voli+kogu !17_S	et	f	\N
125135	kinnitatud	kinnitatud =kinnita  (PtsPtIps  >kinnitama !27_V	et	f	\N
125136	kinnitatud	kinnitatud =kinnitatu  (PlN  >kinnitatu !01_S	et	f	\N
125137	kinnitatud	"kinnitatu %kinnita  )TU1_vS  <kinnitama ;27_V	et	f	\N
125138	kinnitatud	kinnitatud =kinnitatud  (ID  >kinnitatud !41_A	et	f	\N
125139	kinnitatud	"kinnitatud %kinnita  )TUD_vA  <kinnitama ;27_V	et	f	\N
125147	sõnas	sõnas =sõna  (SgIn  >sõna !17_S	et	f	\N
125148	sõnas	sõnas =sõna  (IndIpfSg3  >sõnama !27_V	et	f	\N
125152	põhja-tallinn	?põhja-tallinn =tallinn  (SgN  >põhja-tallinn !22_H	et	f	\N
125161	määravateks	määravateks =määrava  (PlTr  >määrav !02_A	et	f	\N
125162	määravateks	"määrav %määra  )V_vA  <määrama ;29_V	et	f	\N
125168	väljatöötama	?väljatöötama =väljatöötama  (SgG  >väljatöötam !02_A	et	f	\N
125169	väljatöötama	?väljatöötama =tama  (SgN  >välja+töö+tama !17_S	et	f	\N
125170	väljatöötama	?väljatöötama =tama  (SgG  >välja+töö+tama !17_S	et	f	\N
125171	väljatöötama	?väljatöötama =tama  (SgP  >välja+töö+tama !17_S	et	f	\N
125172	väljatöötama	?väljatöötama =töötama  (SgG  >välja+töötam !02_A	et	f	\N
125176	lähi	?lähi =lähi  (SgN  >lähi !17_S	et	f	\N
125177	lähi	?lähi =lähi  (SgG  >lähi !17_S	et	f	\N
125178	lähi	?lähi =lähi  (SgP  >lähi !17_S	et	f	\N
125179	lähi	?lähi =lähi  (IndPrPs_  >lähima !27_V	et	f	\N
125180	lähi	?lähi =lähi  (ImpPrSg2  >lähima !27_V	et	f	\N
125201	lihvimata	lihvimata =lihvi  (SupAb  >lihvima !28_V	et	f	\N
125202	lihvimata	lihvimata =lihvimata  (ID  >lihvimata !41_A	et	f	\N
125203	lihvimata	"lihvimata %lihvi  )MATA_vA  <lihvima ;28_V	et	f	\N
125206	plaanis	plaanis =plaani  (SgIn  >plaan !22_S	et	f	\N
125207	plaanis	plaanis =plaani  (IndIpfSg3  >plaanima !28_V	et	f	\N
125208	renoveerida	?renoveerida =renoveeri  (Inf  >renoveerima !28_V	et	f	\N
125214	hüljatud	hüljatud =hülja  (PtsPtIps  >hülgama !29_V	et	f	\N
125216	hüljatud	hüljatud =hüljatu  (PlN  >hüljatu !01_S	et	f	\N
125217	hüljatud	"hüljatu %hülja  )TU1_vS  <hülgama ;29_V	et	f	\N
125219	hüljatud	hüljatud =hüljatud  (ID  >hüljatud !41_A	et	f	\N
125220	hüljatud	"hüljatud %hülja  )TUD_vA  <hülgama ;29_V	et	f	\N
125226	renoveerimist	?renoveerimist =renoveerimi  (SgEl  >renoveerim !02_A	et	f	\N
125228	renoveerimist	?renoveerimist =renoveerimis  (SgP  >renoveerimis !09_S	et	f	\N
125230	renoveerimist	?renoveerimist =renoveerimis  (SgP  >renoveerimine !12_S	et	f	\N
125231	renoveerimist	?renoveerimist =renoveerimist  (SgN  >renoveerimist !22_S	et	f	\N
125240	kulunud	kulunud =kulu  (PtsPtPs  >kuluma !27_V	et	f	\N
125241	kulunud	kulunud =kulunu  (PlN  >kulunu !01_S	et	f	\N
125242	kulunud	"kulunu %kulu  )NU_vS  <kuluma ;27_V	et	f	\N
125243	kulunud	kulunud =kulunud  (ID  >kulunud !41_A	et	f	\N
125244	kulunud	"kulunud %kulu  )NUD_vA  <kuluma ;27_V	et	f	\N
125259	loomist	loomist =loomi  (SgEl  >loom !22_S	et	f	\N
125260	loomist	loomist =loomi  (PlEl  >loom !22_S	et	f	\N
125261	loomist	loomist =loomis  (SgP  >loomis !09_S	et	f	\N
125060	soni	soni =soni  (SgG  >soni !17_S	et	f	\N
125062	soni	soni =soni  (SgP  >soni !17_S	et	f	\N
125063	soni	soni =soni  (IndPrPs_  >sonima !27_V	et	f	\N
125064	soni	soni =soni  (ImpPrSg2  >sonima !27_V	et	f	\N
125103	autasu	autasu =tasu  (SgN  >au+tasu !17_S	et	f	\N
125104	autasu	autasu =tasu  (SgG  >au+tasu !17_S	et	f	\N
125105	autasu	autasu =tasu  (SgP  >au+tasu !17_S	et	f	\N
125123	kinnitati	kinnitati =kinnita  (IndIpfIps  >kinnitama !27_V	et	f	\N
125124	kinnitati	kinnitati =tati  (SgG  >kinni+tatt !22_S	et	f	\N
125129	arengukava	arengukava =kava  (SgN  >arengu+kava !17_S	et	f	\N
125132	arengukava	arengukava =kava  (SgG  >arengu+kava !17_S	et	f	\N
125134	arengukava	arengukava =kava  (SgP  >arengu+kava !17_S	et	f	\N
125140	jätkuvalt	jätkuvalt =jätkuva  (SgAbl  >jätkuv !02_A	et	f	\N
125141	jätkuvalt	"jätkuv %jätku  )V_vA  <jätkuma ;27_V	et	f	\N
125142	jätkuvalt	jätkuvalt =jätkuvalt  (ID  >jätkuvalt !41_D	et	f	\N
125143	jätkuvalt	"jätkuvalt %jätku  )VALT_mD  <jätkuma ;27_V	et	f	\N
125149	jõudsalt	jõudsalt =jõudsa  (SgAbl  >jõudus !02_A	et	f	\N
125150	jõudsalt	jõudsalt =jõudsalt  (ID  >jõudsalt !41_D	et	f	\N
125151	jõudsalt	"jõudsalt %jõudsa  )LT_mD  <jõudus ;02_A	et	f	\N
125153	loomise	loomise =loomise  (SgG  >loomis !09_S	et	f	\N
125154	loomise	loomise =loomise  (SgG  >loomine !12?10_S	et	f	\N
125155	loomise	"loomine %loo  )MINE_vS  <looma ;38_V	et	f	\N
125156	loomise	"loomine %loomi  )NE_aA  <loom ;22_S	et	f	\N
125163	tasakaalustatud	tasakaalustatud =kaalusta  (PtsPtIps  >tasa+kaalustama !27_V	et	f	\N
125164	tasakaalustatud	tasakaalustatud =kaalustatu  (PlN  >tasa+kaalustatu !01_S	et	f	\N
125165	arenguplaani	arenguplaani =plaani  (SgG  >arengu+plaan !22_S	et	f	\N
125166	arenguplaani	arenguplaani =plaani  (SgP  >arengu+plaan !22_S	et	f	\N
125167	arenguplaani	arenguplaani =plaani  (SgAdt  >arengu+plaan !22_S	et	f	\N
125190	plaanitu	plaanitu =plaanitu  (SgN  >plaanitu !01_AS	et	f	\N
125191	plaanitu	"plaanitu %plaani  )TU1_vS  <plaanima ;28_V	et	f	\N
125192	plaanitu	"plaanitu %plaani  )TU2_kA  <plaan ;22_S	et	f	\N
125193	plaanitu	plaanitu =plaanitu  (SgG  >plaanitu !01_AS	et	f	\N
125194	väita	väita =väi  (SgAb  >väi !26_S	et	f	\N
125195	väita	väita =väit  (Inf  >väitma !34_V	et	f	\N
125196	väita	väita =väita  (IndPrPs_  >väitama !29_V	et	f	\N
125197	väita	väita =väita  (ImpPrSg2  >väitama !29_V	et	f	\N
125271	plaanides	plaanides =plaani  (PlIn  >plaan !22_S	et	f	\N
125272	plaanides	plaanides =plaani  (Ger  >plaanima !28_V	et	f	\N
125277	suuremahuline	suuremahuline =mahuline  (SgN  >suure+mahuline !12_A	et	f	\N
125278	suuremahuline	"suure+mahuline %mahu  )LINE_aA  <suure+maht ;22_S	et	f	\N
125282	kalamaja	kalamaja =maja  (SgN  >kala+maja !17_S	et	f	\N
125284	kalamaja	kalamaja =maja  (SgG  >kala+maja !17_S	et	f	\N
125286	kalamaja	kalamaja =maja  (SgP  >kala+maja !17_S	et	f	\N
125290	tänava	tänava =tänava  (SgG  >tänav !02_A	et	f	\N
125292	tänava	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
125295	tänava	tänava =tänava  (SgG  >tänav !02_S	et	f	\N
125305	pargid	pargid =pargi  (PlN  >park !22_S	et	f	\N
125306	pargid	pargid =pargi  (IndPrSg2  >parkima !28_V	et	f	\N
125331	kõrvale	kõrvale =kõrva  (SgAll  >kõrv !22_S	et	f	\N
125332	kõrvale	kõrvale =kõrvale  (ID  >kõrvale !41_DK	et	f	\N
125333	möödunud	möödunud =möödu  (PtsPtPs  >mööduma !27_V	et	f	\N
125334	möödunud	möödunud =möödunu  (PlN  >möödunu !01_S	et	f	\N
125335	möödunud	"möödunu %möödu  )NU_vS  <mööduma ;27_V	et	f	\N
125336	möödunud	möödunud =möödunud  (ID  >möödunud !41_A	et	f	\N
125337	möödunud	"möödunud %möödu  )NUD_vA  <mööduma ;27_V	et	f	\N
125338	cafe	?cafe =cafe  (SgN  >cafe !06_S	et	f	\N
125377	ajastutruu	ajastutruu =truu  (SgN  >ajastu+truu !26_A	et	f	\N
125378	ajastutruu	ajastutruu =truu  (SgG  >ajastu+truu !26_A	et	f	\N
125389	postereid	?postereid =postere  (PlP  >posteri !01_S	et	f	\N
125391	postereid	?postereid =postere  (PlP  >poster !02_S	et	f	\N
125392	postereid	?postereid =posterei  (PlN  >posterei !26_S	et	f	\N
125393	postereid	?postereid =posterei  (SgP  >posterei !26_S	et	f	\N
125394	postereid	?postereid =erei  (PlN  >post+erei !26_S	et	f	\N
125395	postereid	?postereid =erei  (SgP  >post+erei !26_S	et	f	\N
125396	postereid	?postereid =ereid  (SgN  >post+ereid !22_S	et	f	\N
125397	avatuks	avatuks =ava  (KndPtIps  >avama !27_V	et	f	\N
125398	avatuks	avatuks =avatu  (SgTr  >avatu !01_AS	et	f	\N
125399	avatuks	"avatu %ava  )TU1_vS  <avama ;27_V	et	f	\N
125400	avatuks	"avatu %ava  )TU2_kA  <ava ;17_S	et	f	\N
125401	avatuks	avatuks =tuks  (SgN  >ava+tuks !22_S	et	f	\N
125437	koorides	koorides =koori  (PlIn  >koor !22_S	et	f	\N
125438	koorides	koorides =koori  (Ger  >koorima !28_V	et	f	\N
125439	uurimine	uurimine =uurimine  (SgN  >uurimine !12_S	et	f	\N
125440	uurimine	"uurimine %uuri  )MINE_vS  <uurima ;28_V	et	f	\N
125443	vaimumuusika	vaimumuusika =muusika  (SgN  >vaimu+muusika !01_S	et	f	\N
125444	vaimumuusika	vaimumuusika =muusika  (SgG  >vaimu+muusika !01_S	et	f	\N
125449	orkestreerivad	orkestreerivad =orkestreeri  (IndPrPl3  >orkestreerima !28_V	et	f	\N
125450	orkestreerivad	orkestreerivad =orkestreeriva  (PlN  >orkestreeriv !02_A	et	f	\N
125100	söödavat	"söödav %söö  )TAV_vAS  <sööma ;38_V	et	f	\N
125106	maiustuseks	maiustuseks =maiustuse  (SgTr  >maiustus !11_S	et	f	\N
125107	maiustuseks	"maiustus %maiusta  )US_vS  <maiustama ;27_V	et	f	\N
125128	linnaosa	linnaosa =osa  (SgN  >linna+osa !17_S	et	f	\N
125131	linnaosa	linnaosa =osa  (SgG  >linna+osa !17_S	et	f	\N
125133	linnaosa	linnaosa =osa  (SgP  >linna+osa !17_S	et	f	\N
125144	võmule	?võmule =võmu  (SgAll  >võmu !17_S	et	f	\N
125145	võmule	?võmule =võmule  (IndPrPs_  >võmulema !27_V	et	f	\N
125146	võmule	?võmule =võmule  (ImpPrSg2  >võmulema !27_V	et	f	\N
125185	arendajad	arendajad =arendaja  (PlN  >arendaja !01_S	et	f	\N
125186	arendajad	"arendaja %arenda  )JA_vS  <arendama ;27_V	et	f	\N
125198	pelgalt	pelgalt =pelga  (SgAbl  >pelk !22_A	et	f	\N
125199	pelgalt	pelgalt =pelgalt  (ID  >pelgalt !41_D	et	f	\N
125200	pelgalt	"pelgalt %pelga  )LT_mD  <pelk ;22_A	et	f	\N
125204	teemant	teemant =teemant  (SgN  >teemant !22_S	et	f	\N
125205	teemant	teemant =mant  (SgN  >tee+mant !22_S	et	f	\N
125221	arhitektuuriliselt	arhitektuuriliselt =arhitektuurilise  (SgAbl  >arhitektuuriline !12_A	et	f	\N
125222	arhitektuuriliselt	"arhitektuuriline %arhitektuuri  )LINE_aA  <arhitektuur ;22_S	et	f	\N
125223	arhitektuuriliselt	arhitektuuriliselt =arhitektuuriliselt  (ID  >arhitektuuriliselt !41_D	et	f	\N
125224	arhitektuuriliselt	"arhitektuuriliselt %arhitektuuri  )LISELT_mD  <arhitektuur ;22_S	et	f	\N
125225	arhitektuuriliselt	"arhitektuuriliselt %arhitektuurilise  )LT_mD  <arhitektuuriline ;12_A	et	f	\N
125227	ootavad	ootavad =oota  (IndPrPl3  >ootama !29_V	et	f	\N
125229	ootavad	ootavad =ootava  (PlN  >ootav !02_A	et	f	\N
125232	ootavad	"ootav %oota  )V_vA  <ootama ;29_V	et	f	\N
125247	räsitud	räsitud =räsi  (PtsPtIps  >räsima !27_V	et	f	\N
125249	räsitud	räsitud =räsitu  (PlN  >räsitu !01_AS	et	f	\N
125251	räsitud	"räsitu %räsi  )TU1_vS  <räsima ;27_V	et	f	\N
125253	räsitud	räsitud =räsitud  (ID  >räsitud !41_A	et	f	\N
125254	räsitud	"räsitud %räsi  )TUD_vA  <räsima ;27_V	et	f	\N
125257	rajamist	rajamist =rajamis  (SgP  >rajamine !12_S	et	f	\N
125258	rajamist	"rajamine %raja  )MINE_vS  <rajama ;27_V	et	f	\N
125265	moodustavad	moodustavad =moodusta  (IndPrPl3  >moodustama !27_V	et	f	\N
125266	moodustavad	moodustavad =moodustava  (PlN  >moodustav !02_A	et	f	\N
125267	moodustavad	"moodustav %moodusta  )V_vA  <moodustama ;27_V	et	f	\N
125288	sitsi	sitsi =sitsi  (SgG  >sits !22_S	et	f	\N
125289	sitsi	sitsi =sitsi  (SgP  >sits !22_S	et	f	\N
125291	sitsi	sitsi =sitsi  (SgAdt  >sits !22_S	et	f	\N
125293	sitsi	sitsi =sitsi  (IndPrPs_  >sitsima !28_V	et	f	\N
125294	sitsi	sitsi =sitsi  (ImpPrSg2  >sitsima !28_V	et	f	\N
125296	renoveerimisele	?renoveerimisele =renoveerimise  (SgAll  >renoveerimine !12_S	et	f	\N
125301	spordikompleksi	spordikompleksi =kompleksi  (SgG  >spordi+kompleks !22_S	et	f	\N
125302	spordikompleksi	spordikompleksi =kompleksi  (SgP  >spordi+kompleks !22_S	et	f	\N
125303	spordikompleksi	spordikompleksi =kompleksi  (SgAdt  >spordi+kompleks !22_S	et	f	\N
125307	meelitavad	meelitavad =meelita  (IndPrPl3  >meelitama !27_V	et	f	\N
125308	meelitavad	meelitavad =meelitava  (PlN  >meelitav !02_A	et	f	\N
125309	meelitavad	"meelitav %meelita  )V_vA  <meelitama ;27_V	et	f	\N
125310	meelitavad	meelitavad =tava  (PlN  >meeli+tava !17_S	et	f	\N
125311	otsustatud	otsustatud =otsusta  (PtsPtIps  >otsustama !27_V	et	f	\N
125312	otsustatud	otsustatud =otsustatu  (PlN  >otsustatu !01_S	et	f	\N
125313	otsustatud	"otsustatu %otsusta  )TU1_vS  <otsustama ;27_V	et	f	\N
125314	otsustatud	otsustatud =otsustatud  (ID  >otsustatud !41_A	et	f	\N
125315	otsustatud	"otsustatud %otsusta  )TUD_vA  <otsustama ;27_V	et	f	\N
125319	puhkeala	puhkeala =ala  (SgN  >puhke+ala !17_S	et	f	\N
125320	puhkeala	puhkeala =ala  (SgG  >puhke+ala !17_S	et	f	\N
125321	puhkeala	puhkeala =ala  (SgP  >puhke+ala !17_S	et	f	\N
125341	vanaaegsete	vanaaegsete =sete  (SgN  >vana+aeg+sete !06_S	et	f	\N
125342	vanaaegsete	vanaaegsete =aegse  (PlG  >vana+aegne !02_A	et	f	\N
125349	arhitektuuransamblist	?arhitektuuransamblist =arhitektuuransambli  (SgEl  >arhitektuuransambel !02_S	et	f	\N
125350	arhitektuuransamblist	?arhitektuuransamblist =arhitektuuransamblis  (SgP  >arhitektuuransamblis !09_S	et	f	\N
125351	arhitektuuransamblist	?arhitektuuransamblist =arhitektuuransamblis  (SgP  >arhitektuuransambline !12_A	et	f	\N
125352	arhitektuuransamblist	?arhitektuuransamblist =arhitektuuransamblist  (SgN  >arhitektuuransamblist !22_S	et	f	\N
125379	külastajatele	külastajatele =külastaja  (PlAll  >külastaja !01_S	et	f	\N
125380	külastajatele	"külastaja %külasta  )JA_vS  <külastama ;27_V	et	f	\N
125431	üliõpilastest	üliõpilastest =test  (SgN  >üli+õpilas+test !22_S	et	f	\N
125432	üliõpilastest	üliõpilastest =las  (PlEl  >üli+õpi+laps !14_S	et	f	\N
125433	üliõpilastest	üliõpilastest =laste  (PlEl  >üli+õpi+last !22_S	et	f	\N
125434	üliõpilastest	üliõpilastest =õpilas  (PlEl  >üli+õpilane !12_S	et	f	\N
125435	vilistlastest	vilistlastest =vilistlas  (PlEl  >vilistlane !12_S	et	f	\N
125436	vilistlastest	vilistlastest =test  (SgN  >vilistlas+test !22_S	et	f	\N
125459	rajasid	rajasid =raja  (PlP  >raja !17_S	et	f	\N
125460	rajasid	rajasid =raja  (IndIpfSg2  >rajama !27_V	et	f	\N
125461	rajasid	rajasid =raja  (IndIpfPl3  >rajama !27_V	et	f	\N
125181	paika	paika =paika  (SgP  >paik !22_S	et	f	\N
125182	paika	paika =paika  (SgAdt  >paik !22_S	et	f	\N
125183	paika	paika =paika  (IndPrPs_  >paikama !29_V	et	f	\N
125184	paika	paika =paika  (ImpPrSg2  >paikama !29_V	et	f	\N
125187	rahastajad	?rahastajad =rahastaja  (PlN  >rahastaja !01_S	et	f	\N
125188	rahastajad	?rahastajad =rahastaja  (PlN  >rahastajas !02_A	et	f	\N
125189	rahastajad	?rahastajad =staja  (PlN  >raha+staja !17_S	et	f	\N
125209	amortiseeritud	amortiseeritud =amortiseeri  (PtsPtIps  >amortiseerima !28_V	et	f	\N
125210	amortiseeritud	amortiseeritud =amortiseeritu  (PlN  >amortiseeritu !01_S	et	f	\N
125211	amortiseeritud	"amortiseeritu %amortiseeri  )TU1_vS  <amortiseerima ;28_V	et	f	\N
125212	amortiseeritud	amortiseeritud =amortiseeritud  (ID  >amortiseeritud !41_A	et	f	\N
125213	amortiseeritud	"amortiseeritud %amortiseeri  )TUD_vA  <amortiseerima ;28_V	et	f	\N
125245	jätkata	jätkata =jätka  (Inf  >jätkama !29_V	et	f	\N
125246	jätkata	jätkata =jätka  (IndPrIps_  >jätkama !29_V	et	f	\N
125248	munitsipaalelamufondi	munitsipaalelamufondi =fondi  (SgG  >munitsipaal+elamu+fond !22_S	et	f	\N
125250	munitsipaalelamufondi	munitsipaalelamufondi =fondi  (SgP  >munitsipaal+elamu+fond !22_S	et	f	\N
125252	munitsipaalelamufondi	munitsipaalelamufondi =fondi  (SgAdt  >munitsipaal+elamu+fond !22_S	et	f	\N
125255	varjupaikade	varjupaikade =kade  (SgN  >varju+pai+kade !02_A	et	f	\N
125256	varjupaikade	varjupaikade =paika  (PlG  >varju+paik !22_S	et	f	\N
125273	renoveerimistööd	renoveerimistööd =töö  (PlN  >renoveerimis+töö !26_S	et	f	\N
125274	renoveerimistööd	renoveerimistööd =töö  (SgP  >renoveerimis+töö !26_S	et	f	\N
125283	pelgulinna	pelgulinna =linna  (SgG  >pelgu+linn !22_S	et	f	\N
125285	pelgulinna	pelgulinna =linna  (SgP  >pelgu+linn !22_S	et	f	\N
125287	pelgulinna	pelgulinna =linna  (SgAdt  >pelgu+linn !22_S	et	f	\N
125297	lasteaiad	lasteaiad =aia  (PlN  >laste+aed !22_S	et	f	\N
125298	lasteaiad	lasteaiad =aia  (PlN  >laste+ai !22_S	et	f	\N
125299	kultuuriasutusi	kultuuriasutusi =asutusi  (PlP  >kultuuri+asutus !11_S	et	f	\N
125300	kultuuriasutusi	"kultuuri+asutus %asu  )TUS2_aS  <kultuuri+asu ;17_S	et	f	\N
125364	külastajale	külastajale =külastaja  (SgAll  >külastaja !01_S	et	f	\N
125365	külastajale	"külastaja %külasta  )JA_vS  <külastama ;27_V	et	f	\N
125366	arvestatud	arvestatud =arvesta  (PtsPtIps  >arvestama !27_V	et	f	\N
125367	arvestatud	arvestatud =arvestatu  (PlN  >arvestatu !01_S	et	f	\N
125368	arvestatud	"arvestatu %arvesta  )TU1_vS  <arvestama ;27_V	et	f	\N
125369	arvestatud	arvestatud =arvestatud  (ID  >arvestatud !41_A	et	f	\N
125370	arvestatud	"arvestatud %arvesta  )TUD_vA  <arvestama ;27_V	et	f	\N
125371	interjööri	interjööri =interjööri  (SgG  >interjöör !22_S	et	f	\N
125372	interjööri	interjööri =interjööri  (SgP  >interjöör !22_S	et	f	\N
125373	interjööri	interjööri =interjööri  (SgAdt  >interjöör !22_S	et	f	\N
125381	ostmise	ostmise =ostmise  (SgG  >ostmine !12?10_S	et	f	\N
125382	ostmise	"ostmine %ost  )MINE_vS  <ostma ;34_V	et	f	\N
125388	postkaarte	postkaarte =kaar  (PlG  >post+kaar !13_S	et	f	\N
125390	postkaarte	postkaarte =kaarte  (PlP  >post+kaart !22_S	et	f	\N
125402	laupäeviti	?laupäeviti =laupäevi  (IndIpfIps  >laupäevima !28_V	et	f	\N
125403	laupäeviti	?laupäeviti =laupäeviti  (ID  >laupäeviti !41_D	et	f	\N
125404	laupäeviti	?laupäeviti =laupäeviti  (SgG  >laupäevitt !22_S	et	f	\N
125405	laupäeviti	?laupäeviti =laupäeviti  (IndPrPs_  >laupäevittima !28_V	et	f	\N
125406	laupäeviti	?laupäeviti =laupäeviti  (ImpPrSg2  >laupäevittima !28_V	et	f	\N
125407	laupäeviti	?laupäeviti =iti  (SgN  >lau+päev+iti !16_S	et	f	\N
125408	laupäeviti	?laupäeviti =iti  (SgG  >lau+päev+iti !16_S	et	f	\N
125409	laupäeviti	?laupäeviti =iti  (SgG  >lau+päev+itt !22_S	et	f	\N
125410	laupäeviti	?laupäeviti =päeviti  (SgG  >lau+päevit !02_S	et	f	\N
125411	laupäeviti	?laupäeviti =päeviti  (SgG  >lau+päevitt !22_S	et	f	\N
125412	abilinnapea	abilinnapea =pea  (SgN  >abi+linna+pea !26_S	et	f	\N
125413	abilinnapea	abilinnapea =pea  (SgG  >abi+linna+pea !26_S	et	f	\N
125417	mikkeli	?mikkeli =mikkeli  (ID  >mikkeli !41_D	et	f	\N
125418	mikkeli	?mikkeli =mikkeli  (SgG  >mikkel !02_S	et	f	\N
125419	väliskunsti	väliskunsti =kunsti  (SgG  >välis+kunst !22_S	et	f	\N
125420	väliskunsti	väliskunsti =kunsti  (SgP  >välis+kunst !22_S	et	f	\N
125421	väliskunsti	väliskunsti =kunsti  (SgAdt  >välis+kunst !22_S	et	f	\N
125422	kumu	kumu =kumu  (SgN  >kumu !17_S	et	f	\N
125424	kumu	kumu =kumu  (SgG  >kumu !17_S	et	f	\N
125425	kumu	kumu =kumu  (SgP  >kumu !17_S	et	f	\N
125447	lüürika-	lüürika- =lüürika  (SgN  >lüürika !01_S	et	f	\N
125448	lüürika-	lüürika- =lüürika  (SgG  >lüürika !01_S	et	f	\N
125452	rootsalste	?rootsalste =rootsalste  (PlP  >rootsalst !22_S	et	f	\N
125453	rootsalste	?rootsalste =alste  (SgN  >roots+alste !06_S	et	f	\N
125454	rootsalste	?rootsalste =alste  (SgG  >roots+alste !06_S	et	f	\N
125455	rootsalste	?rootsalste =alste  (PlP  >roots+alst !22_S	et	f	\N
125456	rootsalste	?rootsalste =tsalste  (SgN  >roo+tsalste !06_S	et	f	\N
125457	rootsalste	?rootsalste =tsalste  (SgG  >roo+tsalste !06_S	et	f	\N
125458	rootsalste	?rootsalste =tsalste  (PlP  >roo+tsalst !22_S	et	f	\N
125465	mariehamn	?mariehamn =mariehamn  (SgN  >mariehamn !22_S	et	f	\N
125262	loomist	loomist =loomis  (SgP  >loomine !12?10_S	et	f	\N
125263	loomist	"loomine %loo  )MINE_vS  <looma ;38_V	et	f	\N
125264	loomist	"loomine %loomi  )NE_aA  <loom ;22_S	et	f	\N
125268	esinevad	esinevad =esine  (IndPrPl3  >esinema !27_V	et	f	\N
125269	esinevad	esinevad =esineva  (PlN  >esinev !02_A	et	f	\N
125270	esinevad	"esinev %esine  )V_vA  <esinema ;27_V	et	f	\N
125279	eelistumad	?eelistumad =eelistuma  (PlN  >eelistum !02_A	et	f	\N
125280	eelistumad	?eelistumad =tuma  (PlN  >eelis+tuma !17_S	et	f	\N
125281	eelistumad	?eelistumad =istuma  (PlN  >eel+istum !02_A	et	f	\N
125304	renoveerimisega	?renoveerimisega =renoveerimise  (SgKom  >renoveerimine !12_S	et	f	\N
125316	ligipääsetavamaks	ligipääsetavamaks =maks  (SgN  >ligi+pääse+tava+maks !22_S	et	f	\N
125317	ligipääsetavamaks	ligipääsetavamaks =pääsetavama  (SgTr  >ligi+pääsetavam !02_A	et	f	\N
125318	ligipääsetavamaks	"ligi+pääsetavam %pääsetava  )M_cA  <ligi+pääsetav ;02_A	et	f	\N
125339	väljapeetud	väljapeetud =pee  (PtsPtIps  >välja+_pidama !28_V	et	f	\N
125340	väljapeetud	väljapeetud =peetu  (PlN  >välja+peetu !01_SA	et	f	\N
125345	majakeses	majakeses =majakese  (SgIn  >majake !12_S	et	f	\N
125346	majakeses	"majake %maja  )KE_dS  <maja ;17_S	et	f	\N
125347	majakeses	majakeses =majakese  (SgIn  >majakene !12_S	et	f	\N
125348	majakeses	"majakene %maja  )KENE_dS  <maja ;17_S	et	f	\N
125358	mõeldud	mõeldud =mõel  (PtsPtIps  >mõtlema !30_V	et	f	\N
125360	mõeldud	mõeldud =mõeldu  (PlN  >mõeldu !01_S	et	f	\N
125361	mõeldud	"mõeldu %mõel  )TU1_vS  <mõtlema ;30_V	et	f	\N
125362	mõeldud	mõeldud =mõeldud  (ID  >mõeldud !41_A	et	f	\N
125363	mõeldud	"mõeldud %mõel  )TUD_vA  <mõtlema ;30_V	et	f	\N
125374	ilmestavad	ilmestavad =ilmesta  (IndPrPl3  >ilmestama !27_V	et	f	\N
125375	ilmestavad	ilmestavad =ilmestava  (PlN  >ilmestav !02_A	et	f	\N
125376	ilmestavad	"ilmestav %ilmesta  )V_vA  <ilmestama ;27_V	et	f	\N
125383	pargiteemalist	pargiteemalist =mali  (SgEl  >pargi+tee+mali !17_S	et	f	\N
125384	pargiteemalist	pargiteemalist =malis  (SgP  >pargi+tee+maline !10_A	et	f	\N
125385	pargiteemalist	"pargi+tee+maline %mali  )NE_aA  <pargi+tee+mali ;17_S	et	f	\N
125386	pargiteemalist	pargiteemalist =teemalis  (SgP  >pargi+teemaline !12_A	et	f	\N
125387	pargiteemalist	"pargi+teemaline %teema  )LINE_aA  <pargi+teema ;16_S	et	f	\N
125414	anton-hannsemi	?anton-hannsemi =hannsemi  (SgN  >anton-hannsemi !01_S	et	f	\N
125415	anton-hannsemi	?anton-hannsemi =hannsemi  (SgG  >anton-hannsemi !01_S	et	f	\N
125416	anton-hannsemi	?anton-hannsemi =hannsemi  (SgG  >anton-hannsem !02_A	et	f	\N
125423	järge	järge =järge  (SgN  >järge !05_S	et	f	\N
125426	järge	järge =järge  (SgP  >järg !22_S	et	f	\N
125427	järge	järge =järge  (SgAdt  >järg !22_S	et	f	\N
125441	levitamine	levitamine =levitamine  (SgN  >levitamine !12_S	et	f	\N
125442	levitamine	"levitamine %levita  )MINE_vS  <levitama ;27_V	et	f	\N
125445	rahvalaule	rahvalaule =lau  (SgAll  >rahva+laug !22_SA	et	f	\N
125446	rahvalaule	rahvalaule =laule  (PlP  >rahva+laul !22_S	et	f	\N
125467	aleksandrovna	?aleksandrovna =aleksandrovna  (SgN  >aleksandrovna !16_S	et	f	\N
125468	aleksandrovna	?aleksandrovna =aleksandrovna  (SgG  >aleksandrovna !16_S	et	f	\N
125469	aleksandrovna	?aleksandrovna =ksandrovna  (SgN  >ale+ksandrovna !01_S	et	f	\N
125470	aleksandrovna	?aleksandrovna =ksandrovna  (SgG  >ale+ksandrovna !01_S	et	f	\N
125472	seadmestasid	seadmestasid =seadmesta  (IndIpfSg2  >seadmestama !27_V	et	f	\N
125473	seadmestasid	seadmestasid =seadmesta  (IndIpfPl3  >seadmestama !27_V	et	f	\N
125496	turismisuuna	turismisuuna =suu  (SgEs  >turismi+suu !26_S	et	f	\N
125497	turismisuuna	turismisuuna =suuna  (SgG  >turismi+suund !22_S	et	f	\N
125541	otsusele	otsusele =otsuse  (SgAll  >otsus !09_S	et	f	\N
125542	otsusele	otsusele =use  (PlAll  >ots+usk !22_S	et	f	\N
125543	kaasates	kaasates =kaasa  (Ger  >kaasama !29_V	et	f	\N
125544	kaasates	kaasates =ate  (PlIn  >kaas+att !22_S	et	f	\N
125547	erisuuna	erisuuna =suu  (SgEs  >eri+suu !26_S	et	f	\N
125548	erisuuna	erisuuna =suuna  (SgG  >eri+suund !22_S	et	f	\N
125561	suurlinna	suurlinna =linna  (SgG  >suur+linn !22_S	et	f	\N
125562	suurlinna	suurlinna =linna  (SgP  >suur+linn !22_S	et	f	\N
125563	suurlinna	suurlinna =linna  (SgAdt  >suur+linn !22_S	et	f	\N
125567	analüüsimisel	analüüsimisel =analüüsimise  (SgAd  >analüüsimine !12_S	et	f	\N
125568	analüüsimisel	"analüüsimine %analüüsi  )MINE_vS  <analüüsima ;28_V	et	f	\N
125594	dr	### dr	et	f	\N
125600	osaliseks	osaliseks =osalise  (SgTr  >osaline !12_SA	et	f	\N
125601	osaliseks	"osaline %osa  )LINE_aA  <osa ;17_S	et	f	\N
125604	töörühma	töörühma =rühma  (SgG  >töö+rühm !22_S	et	f	\N
125607	töörühma	töörühma =rühma  (SgP  >töö+rühm !22_S	et	f	\N
125609	töörühma	töörühma =rühma  (SgAdt  >töö+rühm !22_S	et	f	\N
125639	puhtalt	puhtalt =puhta  (SgAbl  >puhas !07_A	et	f	\N
125640	puhtalt	puhtalt =puhtalt  (ID  >puhtalt !41_D	et	f	\N
125641	puhtalt	"puhtalt %puhta  )LT_mD  <puhas ;07_A	et	f	\N
125642	puhtalt	puhtalt =alt  (SgN  >puht+alt !22_S	et	f	\N
125651	pohmakat	?pohmakat =pohmaka  (SgP  >pohmaka !01_S	et	f	\N
125652	pohmakat	?pohmakat =pohmaka  (SgP  >pohmakas !02_S	et	f	\N
125660	kindlus	kindlus =kindlus  (SgN  >kindlus !11~09_S	et	f	\N
125325	srtoomi	?srtoomi =srtoomi  (SgP  >srtoom !22_S	et	f	\N
125326	srtoomi	?srtoomi =srtoomi  (SgAdt  >srtoom !22_S	et	f	\N
125327	srtoomi	?srtoomi =srtoomi  (IndPrPs_  >srtoomima !28_V	et	f	\N
125328	srtoomi	?srtoomi =srtoomi  (ImpPrSg2  >srtoomima !28_V	et	f	\N
125329	vetelpääste	vetelpääste =pääste  (SgN  >vetel+pääste !06_S	et	f	\N
125330	vetelpääste	vetelpääste =pääste  (SgG  >vetel+pääste !06_S	et	f	\N
125343	kohvikute	kohvikute =kohviku  (PlG  >kohvik !02_S	et	f	\N
125344	kohvikute	kohvikute =ute  (SgG  >kohvik+utt !22_S	et	f	\N
125353	weizenbergi	?weizenbergi =weizenbergi  (SgG  >weizenberk !22_S	et	f	\N
125354	weizenbergi	?weizenbergi =weizenbergi  (SgP  >weizenberg !22_S	et	f	\N
125355	weizenbergi	?weizenbergi =weizenbergi  (SgAdt  >weizenberg !22_S	et	f	\N
125356	weizenbergi	?weizenbergi =weizenbergi  (IndPrPs_  >weizenberkima !28_V	et	f	\N
125357	weizenbergi	?weizenbergi =weizenbergi  (ImpPrSg2  >weizenberkima !28_V	et	f	\N
125359	weizenbergi	?weizenbergi =weizenber  (SgN^  >weizenber !02_S	et	f	\N
125428	lira	lira =lira  (SgN  >lira !17_S	et	f	\N
125429	lira	lira =lira  (SgG  >lira !17_S	et	f	\N
125430	lira	lira =lira  (SgP  >lira !17_S	et	f	\N
125478	kinnitasid	kinnitasid =kinnita  (IndIpfSg2  >kinnitama !27_V	et	f	\N
125481	kinnitasid	kinnitasid =kinnita  (IndIpfPl3  >kinnitama !27_V	et	f	\N
125494	osalemisel	osalemisel =osalemise  (SgAd  >osalemine !12_S	et	f	\N
125495	osalemisel	"osalemine %osale  )MINE_vS  <osalema ;27_V	et	f	\N
125498	virtuaalmaailma	?virtuaalmaailma =virtuaalmaailma  (SgN  >virtuaalmaailma !16_S	et	f	\N
125499	virtuaalmaailma	?virtuaalmaailma =virtuaalmaailma  (SgG  >virtuaalmaailma !16_S	et	f	\N
125500	osalusel	osalusel =osaluse  (SgAd  >osalus !11_S	et	f	\N
125501	osalusel	"osalus %osale  )US_vS  <osalema ;27_V	et	f	\N
125513	virtuaalharu	?virtuaalharu =virtuaalharu  (IndPrPs_  >virtuaalharuma !27_V	et	f	\N
125515	virtuaalharu	?virtuaalharu =virtuaalharu  (ImpPrSg2  >virtuaalharuma !27_V	et	f	\N
125519	kaastata	?kaastata =kaasta  (SgAb  >kaasta !01_S	et	f	\N
125520	kaastata	?kaastata =kaasta  (IndPrIps_  >kaastama !27_V	et	f	\N
125521	kaastata	?kaastata =kaastata  (IndPrPs_  >kaastatama !27_V	et	f	\N
125522	kaastata	?kaastata =kaastata  (ImpPrSg2  >kaastatama !27_V	et	f	\N
125523	kaastata	?kaastata =tata  (SgN  >kaas+tata !16_S	et	f	\N
125524	kaastata	?kaastata =tata  (SgG  >kaas+tata !16_S	et	f	\N
125525	kultuurialane	kultuurialane =alane  (SgN  >kultuuri+alane !10_AS	et	f	\N
125526	kultuurialane	"kultuuri+alane %ala  )NE_aA  <kultuuri+ala ;17_S	et	f	\N
125549	avamine	avamine =avamine  (SgN  >avamine !12_S	et	f	\N
125550	avamine	"avamine %ava  )MINE_vS  <avama ;27_V	et	f	\N
125557	lähemale	lähemale =lähema  (SgAll  >lähem !02_A	et	f	\N
125559	lähemale	"lähem %lähe  )M_cA  <lähike ;12_A	et	f	\N
125560	lähemale	lähemale =lähemale  (ID  >lähemale !41_D	et	f	\N
125564	võrgukogu	võrgukogu =kogu  (SgN  >võrgu+kogu !17_S	et	f	\N
125565	võrgukogu	võrgukogu =kogu  (SgG  >võrgu+kogu !17_S	et	f	\N
125566	võrgukogu	võrgukogu =kogu  (SgP  >võrgu+kogu !17_S	et	f	\N
125576	koolituse	koolituse =koolituse  (SgG  >koolitus !11_S	et	f	\N
125577	koolituse	"koolitus %koolita  )US_vS  <koolitama ;27_V	et	f	\N
125578	koolituse	"koolitus %kooli  )TUS2_aS  <kool ;22_S	et	f	\N
125583	saadud	saadud =saa  (PtsPtIps  >saama !37_V	et	f	\N
125584	saadud	saadud =saadu  (PlN  >saadu !01_S	et	f	\N
125585	saadud	"saadu %saa  )TU1_vS  <saama ;37_V	et	f	\N
125586	saadud	saadud =saadud  (ID  >saadud !41_A	et	f	\N
125587	saadud	"saadud %saa  )TUD_vA  <saama ;37_V	et	f	\N
125597	menu	menu =menu  (SgN  >menu !17_S	et	f	\N
125598	menu	menu =menu  (SgG  >menu !17_S	et	f	\N
125599	menu	menu =menu  (SgP  >menu !17_S	et	f	\N
125602	osaliseks	osaliseks =osalise  (SgTr  >osaline !12_SA	et	f	\N
125603	osaliseks	"osaline %osa  )LINE_aA  <osa ;17_S	et	f	\N
125610	aleksander	?aleksander =aleksander  (SgN  >aleksander !02_S	et	f	\N
125611	aleksander	?aleksander =ksander  (SgN  >ale+ksander !02_S	et	f	\N
125612	ahvenamaa	ahvenamaa =maa  (SgN  >ahvena+maa !26_S	et	f	\N
125613	ahvenamaa	ahvenamaa =maa  (SgG  >ahvena+maa !26_S	et	f	\N
125616	koosseisu	koosseisu =seisu  (SgG  >koos+seis !22_S	et	f	\N
125617	koosseisu	koosseisu =seisu  (SgP  >koos+seis !22_S	et	f	\N
125618	koosseisu	koosseisu =seisu  (SgAdt  >koos+seis !22_S	et	f	\N
125628	koguni	koguni =kogu  (SgTer  >kogu !17_S	et	f	\N
125629	koguni	koguni =koguni  (ID  >koguni !41_D	et	f	\N
125634	imelikult	imelikult =imeliku  (SgAbl  >imelik !25_A	et	f	\N
125635	imelikult	imelikult =imelikult  (ID  >imelikult !41_D	et	f	\N
125636	imelikult	"imelikult %imeliku  )LT_mD  <imelik ;25_A	et	f	\N
125662	hävitatud	hävitatud =hävita  (PtsPtIps  >hävitama !27_V	et	f	\N
125663	hävitatud	hävitatud =hävitatu  (PlN  >hävitatu !01_S	et	f	\N
125664	hävitatud	"hävitatu %hävita  )TU1_vS  <hävitama ;27_V	et	f	\N
125665	hävitatud	hävitatud =hävitatud  (ID  >hävitatud !41_A	et	f	\N
125666	hävitatud	"hävitatud %hävita  )TUD_vA  <hävitama ;27_V	et	f	\N
125675	aimata	aimata =aima  (SgAb  >aim !22_S	et	f	\N
125676	aimata	aimata =aima  (Inf  >aimama !29_V	et	f	\N
125678	aimata	aimata =aima  (IndPrIps_  >aimama !29_V	et	f	\N
125451	orkestreerivad	"orkestreeriv %orkestreeri  )V_vA  <orkestreerima ;28_V	et	f	\N
125471	sundsher	?sundsher =sundsher  (SgN  >sundsher !02_S	et	f	\N
125487	saajat	saajat =saaja  (SgP  >saaja !01_S	et	f	\N
125488	saajat	"saaja %saa  )JA_vS  <saama ;37_V	et	f	\N
125511	internetipõhine	internetipõhine =põhine  (SgN  >interneti+põhine !10_A	et	f	\N
125512	internetipõhine	"interneti+põhine %põhi  )NE_aA  <interneti+põhi ;24_S	et	f	\N
125534	toimimise	toimimise =toimimise  (SgG  >toimimine !12_S	et	f	\N
125535	toimimise	"toimimine %toimi  )MINE_vS  <toimima ;28_V	et	f	\N
125551	peterbuuri	?peterbuuri =peterbuuri  (SgN  >peterbuuri !16_S	et	f	\N
125552	peterbuuri	?peterbuuri =peterbuuri  (SgG  >peterbuuri !16_S	et	f	\N
125553	peterbuuri	?peterbuuri =peterbuuri  (SgG  >peterbuur !22_S	et	f	\N
125554	peterbuuri	?peterbuuri =peterbuuri  (SgP  >peterbuur !22_S	et	f	\N
125555	peterbuuri	?peterbuuri =peterbuuri  (SgAdt  >peterbuur !22_S	et	f	\N
125556	peterbuuri	?peterbuuri =peterbuuri  (IndPrPs_  >peterbuurima !28_V	et	f	\N
125558	peterbuuri	?peterbuuri =peterbuuri  (ImpPrSg2  >peterbuurima !28_V	et	f	\N
125569	järgneva	järgneva =järgneva  (SgG  >järgnev !02_A	et	f	\N
125570	järgneva	"järgnev %järgne  )V_vA  <järgnema ;27_V	et	f	\N
125571	väljavalitud	väljavalitud =vali  (PtsPtIps  >välja+_valima !27_V	et	f	\N
125572	väljavalitud	väljavalitud =valitu  (PlN  >välja+valitu !01_S	et	f	\N
125573	läbivad	läbivad =läbi  (IndPrPl3  >läbima !27_V	et	f	\N
125574	läbivad	läbivad =läbiva  (PlN  >läbiv !02_A	et	f	\N
125575	läbivad	"läbiv %läbi  )V_vA  <läbima ;27_V	et	f	\N
125579	loomisega	loomisega =loomise  (SgKom  >loomis !09_S	et	f	\N
125580	loomisega	loomisega =loomise  (SgKom  >loomine !12?10_S	et	f	\N
125581	loomisega	"loomine %loo  )MINE_vS  <looma ;38_V	et	f	\N
125582	loomisega	"loomine %loomi  )NE_aA  <loom ;22_S	et	f	\N
125626	varajasem	varajasem =varajasem  (SgN  >varajasem !02_A	et	f	\N
125627	varajasem	"varajasem %varajase  )M_cA  <varajane ;12_A	et	f	\N
125653	ahvenamaale	ahvenamaale =maa  (SgAll  >ahvena+maa !26_S	et	f	\N
125654	ahvenamaale	ahvenamaale =maale  (PlP  >ahvena+maal !22_S	et	f	\N
125667	sõjameeste	sõjameeste =mees  (PlG  >sõja+meene !10_A	et	f	\N
125668	sõjameeste	"sõja+meene %mee  )NE_aA  <sõja+mesi ;15_S	et	f	\N
125669	sõjameeste	sõjameeste =mees  (PlG  >sõja+mees !13_S	et	f	\N
125670	käsitööliste	käsitööliste =iste  (SgN  >käsi+tööl+iste !05_S	et	f	\N
125671	käsitööliste	käsitööliste =iste  (SgN  >käsi+tööl+iste !06_S	et	f	\N
125672	käsitööliste	käsitööliste =iste  (SgG  >käsi+tööl+iste !06_S	et	f	\N
125673	käsitööliste	käsitööliste =iste  (PlP  >käsi+tööl+ist !22_S	et	f	\N
125674	käsitööliste	käsitööliste =töölis  (PlG  >käsi+tööline !12?10_S	et	f	\N
125685	suurejooneline	suurejooneline =jooneline  (SgN  >suure+jooneline !12_A	et	f	\N
125686	suurejooneline	"suure+jooneline %joone  )LINE_aA  <suure+joon ;13_S	et	f	\N
125687	suurejooneline	"suure+jooneline %jooneli  )NE_aA  <suure+joonel ;02_S	et	f	\N
125697	plahvatuslikult	plahvatuslikult =plahvatusliku  (SgAbl  >plahvatuslik !25_A	et	f	\N
125698	plahvatuslikult	plahvatuslikult =plahvatuslikult  (ID  >plahvatuslikult !41_D	et	f	\N
125699	plahvatuslikult	"plahvatuslikult %plahvatusliku  )LT_mD  <plahvatuslik ;25_A	et	f	\N
125718	segakeeles	segakeeles =keele  (SgIn  >sega+keel !13_S	et	f	\N
125719	segakeeles	segakeeles =keele  (PlIn  >sega+keeld !22_S	et	f	\N
125732	tõelist	tõelist =tõelis  (SgP  >tõeline !12?10_A	et	f	\N
125733	tõelist	"tõeline %tõe  )LINE_aA  <tõsi ;15_S	et	f	\N
125734	tõelist	"tõeline %tõe  )LINE_aA  <tõde ;18_S	et	f	\N
125775	maiustus	maiustus =maiustus  (SgN  >maiustus !11_S	et	f	\N
125776	maiustus	"maiustus %maiusta  )US_vS  <maiustama ;27_V	et	f	\N
125777	maiustus	maiustus =ustu  (SgIn  >mai+ustu !01_S	et	f	\N
125791	kohandasid	kohandasid =kohanda  (IndIpfSg2  >kohandama !27_V	et	f	\N
125792	kohandasid	kohandasid =kohanda  (IndIpfPl3  >kohandama !27_V	et	f	\N
125825	komsomolskaja	?komsomolskaja =komsomolskaja  (SgN  >komsomolskaja !01_S	et	f	\N
125826	komsomolskaja	?komsomolskaja =komsomolskaja  (SgG  >komsomolskaja !01_S	et	f	\N
125830	komsomolskaja	?komsomolskaja =komsomolskaja  (SgG  >komsomolskajas !02_A	et	f	\N
125831	komsomolskaja	?komsomolskaja =somolskaja  (SgN  >kom+somolskaja !01_S	et	f	\N
125832	komsomolskaja	?komsomolskaja =somolskaja  (SgG  >kom+somolskaja !01_S	et	f	\N
125833	komsomolskaja	?komsomolskaja =somolskaja  (SgG  >kom+somolskajas !02_A	et	f	\N
125842	perepjolkinite	?perepjolkinite =perepjolkini  (PlG  >perepjolkin !02_S	et	f	\N
125891	aastalgi	aastalgi =talgi  (SgG  >aas+talk !22_S	et	f	\N
125892	aastalgi	aastalgi =aasta  (SgAd^  >aasta !01_S	et	f	\N
125947	värskel	?värskel =värske  (SgAd  >värske !01_AS	et	f	\N
125949	värskel	?värskel =värske  (PlAd  >värsk !22_S	et	f	\N
125951	värskel	?värskel =värskel  (SgN  >värskel !02_S	et	f	\N
125952	kelgutajaid	kelgutajaid =kelgutaja  (PlP  >kelgutaja !01_S	et	f	\N
125953	kelgutajaid	"kelgutaja %kelguta  )JA_vS  <kelgutama ;27_V	et	f	\N
125961	soovijate	soovijate =soovija  (PlG  >soovija !01_S	et	f	\N
125963	soovijate	"soovija %soovi  )JA_vS  <soovima ;28_V	et	f	\N
125968	meelepärane	meelepärane =pärane  (SgN  >meele+pärane !10_A	et	f	\N
125969	meelepärane	"meele+pärane %pära  )NE_aA  <meele+pära ;17_S	et	f	\N
125462	looduskaitseala	looduskaitseala =ala  (SgN  >loodus+kaitse+ala !17_S	et	f	\N
125463	looduskaitseala	looduskaitseala =ala  (SgG  >loodus+kaitse+ala !17_S	et	f	\N
125464	looduskaitseala	looduskaitseala =ala  (SgP  >loodus+kaitse+ala !17_S	et	f	\N
125482	siiralt	siiralt =siira  (SgAbl  >siiras !07_A	et	f	\N
125483	siiralt	siiralt =siiralt  (ID  >siiralt !41_D	et	f	\N
125484	siiralt	"siiralt %siira  )LT_mD  <siiras ;07_A	et	f	\N
125485	kindluse	kindluse =kindluse  (SgG  >kindlus !11~09_S	et	f	\N
125486	kindluse	"kindlus %kindla  )US_aS  <kindel ;02_A	et	f	\N
125489	kohandamise	kohandamise =kohandamise  (SgG  >kohandamine !12_S	et	f	\N
125490	kohandamise	"kohandamine %kohanda  )MINE_vS  <kohandama ;27_V	et	f	\N
125514	avamisest	avamisest =avamise  (SgEl  >avamine !12_S	et	f	\N
125516	avamisest	"avamine %ava  )MINE_vS  <avama ;27_V	et	f	\N
125527	kultuurialane	kultuurialane =alane  (SgN  >kultuuri+alane !10_AS	et	f	\N
125528	kultuurialane	"kultuuri+alane %ala  )NE_aA  <kultuuri+ala ;17_S	et	f	\N
125619	lõppemisele	lõppemisele =lõppemise  (SgAll  >lõppemine !12_S	et	f	\N
125620	lõppemisele	"lõppemine %lõppe  )MINE_vS  <lõppema ;27_V	et	f	\N
125621	lõppemisele	"lõppemine %lõppe  )MINE_vS  <lõppema ;28_V	et	f	\N
125622	lõppemisele	lõppemisele =emise  (SgAll  >lõpp+emis !09_S	et	f	\N
125630	seadistasid	seadistasid =seadista  (IndIpfSg2  >seadistama !27_V	et	f	\N
125631	seadistasid	seadistasid =seadista  (IndIpfPl3  >seadistama !27_V	et	f	\N
125649	õudsat	?õudsat =õudsa  (SgP  >õudsa !01_S	et	f	\N
125650	õudsat	?õudsat =õudsat  (SgN  >õudsat !02_S	et	f	\N
125657	mil	mil =mi  (SgAd  >mis !00_P	et	f	\N
125658	mil	mil =mi  (SgAd  >mi !26_S	et	f	\N
125659	mil	mil =mil  (ID  >mil !41_D	et	f	\N
125713	sidorov	?sidorov =sidorov  (SgN  >sidorov !02_A	et	f	\N
125716	põlisahvenamaalastega	põlisahvenamaalastega =las  (PlKom  >põlis+ahvena+maa+laps !14_S	et	f	\N
125717	põlisahvenamaalastega	põlisahvenamaalastega =maalas  (PlKom  >põlis+ahvena+maalane !12?10_S	et	f	\N
125723	põnevalt	põnevalt =põneva  (SgAbl  >põnev !02_A	et	f	\N
125724	põnevalt	põnevalt =põnevalt  (ID  >põnevalt !41_D	et	f	\N
125725	põnevalt	"põnevalt %põneva  )LT_mD  <põnev ;02_A	et	f	\N
125728	putka	putka =putka  (SgN  >putka !16_S	et	f	\N
125729	putka	putka =putka  (SgG  >putka !16_S	et	f	\N
125730	putka	putka =putka  (IndPrPs_  >putkama !29_V	et	f	\N
125731	putka	putka =putka  (ImpPrSg2  >putkama !29_V	et	f	\N
125737	vanavanaisa	vanavanaisa =isa  (SgN  >vana+vana+isa !17_S	et	f	\N
125738	vanavanaisa	vanavanaisa =isa  (SgG  >vana+vana+isa !17_S	et	f	\N
125739	vanavanaisa	vanavanaisa =isa  (SgP  >vana+vana+isa !17_S	et	f	\N
125742	kohalikus	kohalikus =kohaliku  (SgIn  >kohalik !25_AS	et	f	\N
125743	kohalikus	kohalikus =kohalikus  (SgN  >kohalikus !11?09_S	et	f	\N
125744	kohalikus	"kohalikus %kohaliku  )US_aS  <kohalik ;25_AS	et	f	\N
125760	kujutati	kujutati =kujuta  (IndIpfIps  >kujutama !27_V	et	f	\N
125762	kujutati	kujutati =tati  (SgG  >kuju+tatt !22_S	et	f	\N
125783	marienhamn	?marienhamn =marienhamn  (SgN  >marienhamn !22_S	et	f	\N
125784	marienhamn	?marienhamn =enhamn  (SgN  >mari+enhamn !22_S	et	f	\N
125786	juriidiliselt	juriidiliselt =juriidilise  (SgAbl  >juriidiline !12_A	et	f	\N
125787	juriidiliselt	juriidiliselt =juriidiliselt  (ID  >juriidiliselt !41_D	et	f	\N
125788	juriidiliselt	"juriidiliselt %juriidilise  )LT_mD  <juriidiline ;12_A	et	f	\N
125799	laadi	laadi =laadi  (SgG  >laad !22_S	et	f	\N
125800	laadi	laadi =laadi  (SgP  >laad !22_S	et	f	\N
125801	laadi	laadi =laadi  (SgAdt  >laad !22_S	et	f	\N
125802	laadi	laadi =laadi  (IndPrPs_  >laadima !28_V	et	f	\N
125803	laadi	laadi =laadi  (ImpPrSg2  >laadima !28_V	et	f	\N
125818	käibele	käibele =käibe  (SgAll  >käive !06_S	et	f	\N
125819	käibele	käibele =käibele  (ID  >käibele !41_D	et	f	\N
125834	aastakümnel	?aastakümnel =aastakümne  (PlAd  >aastakümn !22_S	et	f	\N
125835	aastakümnel	?aastakümnel =aastakümnel  (SgN  >aastakümnel !02_S	et	f	\N
125836	aastakümnel	?aastakümnel =kümne  (PlAd  >aasta+kümn !22_S	et	f	\N
125837	aastakümnel	?aastakümnel =kümnel  (SgN  >aasta+kümnel !02_S	et	f	\N
125838	aastakümnel	?aastakümnel =takümne  (PlAd  >aas+takümn !22_S	et	f	\N
125839	aastakümnel	?aastakümnel =takümnel  (SgN  >aas+takümnel !02_S	et	f	\N
125865	pilku	pilku =pilku  (SgP  >pilk !22_S	et	f	\N
125866	pilku	pilku =pilku  (SgAdt  >pilk !22_S	et	f	\N
125867	pilku	pilku =pilku  (PlP  >pilk !22_S	et	f	\N
125871	pressitud	pressitud =pressi  (PtsPtIps  >pressima !28_V	et	f	\N
125872	pressitud	pressitud =pressitu  (PlN  >pressitu !01_AS	et	f	\N
125873	pressitud	"pressitu %pressi  )TU1_vS  <pressima ;28_V	et	f	\N
125874	pressitud	"pressitu %pressi  )TU2_kA  <press ;22_S	et	f	\N
125875	pressitud	pressitud =pressitud  (ID  >pressitud !41_A	et	f	\N
125876	pressitud	"pressitud %pressi  )TUD_vA  <pressima ;28_V	et	f	\N
125881	samagust	?samagust =samagus  (SgP  >samagus !11_S	et	f	\N
125882	samagust	?samagust =gust  (SgN  >sama+gust !22_S	et	f	\N
125885	lumerohke	lumerohke =rohke  (SgN  >lume+rohke !01_A	et	f	\N
125886	lumerohke	lumerohke =rohke  (SgG  >lume+rohke !01_A	et	f	\N
125887	nähtuseks	nähtuseks =nähtuse  (SgTr  >nähtus !11~09_S	et	f	\N
125466	mariehamn	?mariehamn =ehamn  (SgN  >mari+ehamn !22_S	et	f	\N
125474	anitshkovi	?anitshkovi =anitshkovi  (ID  >anitshkovi !41_D	et	f	\N
125475	anitshkovi	?anitshkovi =anitshkovi  (SgG  >anitshkov !02_A	et	f	\N
125476	karasho	?karasho =karasho  (SgN  >karasho !16_S	et	f	\N
125477	karasho	?karasho =karasho  (SgG  >karasho !16_S	et	f	\N
125479	kurameerides	kurameerides =kurameeri  (Ger  >kurameerima !28_V	et	f	\N
125480	kurameerides	kurameerides =meeri  (PlIn  >kura+meer !22_S	et	f	\N
125491	stpeterburi	?stpeterburi =stpeterburi  (SgG  >stpeterbur !19_S	et	f	\N
125492	stpeterburi	?stpeterburi =stpeterburi  (SgP  >stpeterbur !19_S	et	f	\N
125493	stpeterburi	?stpeterburi =stpeterburi  (SgAdt  >stpeterbur !19_S	et	f	\N
125502	tõhus	tõhus =tõhu  (SgIn  >tõhk !22_S	et	f	\N
125503	tõhus	tõhus =tõhus  (SgN  >tõhus !02_A	et	f	\N
125504	neti-	?neti- =neti  (SgN  >neti !16_S	et	f	\N
125505	neti-	?neti- =neti  (SgG  >neti !16_S	et	f	\N
125506	neti-	?neti- =neti  (SgG  >nett !22_AS	et	f	\N
125507	neti-	?neti- =neti  (IndPrPs_  >netima !27_V	et	f	\N
125508	neti-	?neti- =neti  (IndPrPs_  >nettima !28_V	et	f	\N
125509	neti-	?neti- =neti  (ImpPrSg2  >netima !27_V	et	f	\N
125510	neti-	?neti- =neti  (ImpPrSg2  >nettima !28_V	et	f	\N
125517	kohtlajärvel	kohtlajärvel =järve  (SgAd  >kohtla+järv !22_S	et	f	\N
125518	kohtlajärvel	kohtlajärvel =järve  (PlAd  >kohtla+järv !22_S	et	f	\N
125529	haru	haru =haru  (SgN  >haru !17_S	et	f	\N
125530	haru	haru =haru  (SgG  >haru !17_S	et	f	\N
125531	haru	haru =haru  (SgP  >haru !17_S	et	f	\N
125532	toimimise	toimimise =toimimise  (SgG  >toimimine !12_S	et	f	\N
125533	toimimise	"toimimine %toimi  )MINE_vS  <toimima ;28_V	et	f	\N
125536	põlevkivi	põlevkivi =kivi  (SgN  >põlev+kivi !17_S	et	f	\N
125537	põlevkivi	põlevkivi =kivi  (SgG  >põlev+kivi !17_S	et	f	\N
125538	põlevkivi	põlevkivi =kivi  (SgP  >põlev+kivi !17_S	et	f	\N
125539	võrgupõhine	võrgupõhine =põhine  (SgN  >võrgu+põhine !10_A	et	f	\N
125540	võrgupõhine	"võrgu+põhine %põhi  )NE_aA  <võrgu+põhi ;24_S	et	f	\N
125545	turismialase	turismialase =alase  (SgG  >turismi+alane !10_AS	et	f	\N
125546	turismialase	"turismi+alane %ala  )NE_aA  <turismi+ala ;17_S	et	f	\N
125588	harumuuseumi	harumuuseumi =muuseumi  (SgG  >haru+muuseum !19~02_S	et	f	\N
125589	harumuuseumi	harumuuseumi =muuseumi  (SgP  >haru+muuseum !19_S	et	f	\N
125590	harumuuseumi	harumuuseumi =muuseumi  (SgAdt  >haru+muuseum !19_S	et	f	\N
125591	viivad	viivad =vii  (IndPrPl3  >viima !38_V	et	f	\N
125592	viivad	viivad =viiva  (PlN  >viiv !02_A	et	f	\N
125593	viivad	"viiv %vii  )V_vA  <viima ;38_V	et	f	\N
125595	kõnealune	kõnealune =alune  (SgN  >kõne+alune !10_AS	et	f	\N
125596	kõnealune	"kõne+alune %alu  )NE_aA  <kõne+alg ;22_S	et	f	\N
125605	töörühma	töörühma =rühma  (SgG  >töö+rühm !22_S	et	f	\N
125606	töörühma	töörühma =rühma  (SgP  >töö+rühm !22_S	et	f	\N
125608	töörühma	töörühma =rühma  (SgAdt  >töö+rühm !22_S	et	f	\N
125614	rootslastega	rootslastega =rootslas  (PlKom  >rootslane !12?10_S	et	f	\N
125615	rootslastega	rootslastega =las  (PlKom  >roots+laps !14_S	et	f	\N
125623	loewe	?loewe =loewe  (SgN  >loewe !06_S	et	f	\N
125624	loewe	?loewe =loewe  (SgG  >loewe !06_S	et	f	\N
125625	loewe	?loewe =loewe  (PlP  >loew !22_S	et	f	\N
125632	juhtimisel	juhtimisel =juhtimise  (SgAd  >juhtimine !12_S	et	f	\N
125633	juhtimisel	"juhtimine %juhti  )MINE_vS  <juhtima ;28_V	et	f	\N
125637	sõjaline	sõjaline =sõjaline  (SgN  >sõjaline !12_A	et	f	\N
125638	sõjaline	"sõjaline %sõja  )LINE_aA  <sõda ;18_S	et	f	\N
125643	otstarbekohaselt	otstarbekohaselt =kohase  (SgAbl  >ots+tarbe+kohane !10_A	et	f	\N
125644	otstarbekohaselt	"ots+tarbe+kohane %koha  )NE_aA  <ots+tarbe+koha ;17_S	et	f	\N
125645	otstarbekohaselt	"ots+tarbe+kohane %koha  )NE_aA  <ots+tarbe+koht ;22_S	et	f	\N
125646	otstarbekohaselt	"ots+tarbe+kohaselt %koha  )SELT_mD  <ots+tarbe+koha ;17_S	et	f	\N
125647	otstarbekohaselt	"ots+tarbe+kohaselt %koha  )SELT_mD  <ots+tarbe+koht ;22_S	et	f	\N
125648	otstarbekohaselt	"ots+tarbe+kohaselt %kohase  )LT_mD  <ots+tarbe+kohane ;10_A	et	f	\N
125655	rajamise	rajamise =rajamise  (SgG  >rajamine !12_S	et	f	\N
125656	rajamise	"rajamine %raja  )MINE_vS  <rajama ;27_V	et	f	\N
125681	trendist	?trendist =trendi  (SgEl  >trendi !16_S	et	f	\N
125682	trendist	?trendist =trendi  (SgEl  >trent !22_S	et	f	\N
125683	trendist	?trendist =trendis  (SgP  >trendis !09_S	et	f	\N
125684	trendist	?trendist =trendist  (SgN  >trendist !22_S	et	f	\N
125700	kasvanud	kasvanud =kasva  (PtsPtPs  >kasvama !28_V	et	f	\N
125701	kasvanud	kasvanud =kasvanu  (PlN  >kasvanu !01_S	et	f	\N
125702	kasvanud	"kasvanu %kasva  )NU_vS  <kasvama ;28_V	et	f	\N
125703	kasvanud	kasvanud =kasvanud  (ID  >kasvanud !41_A	et	f	\N
125704	kasvanud	"kasvanud %kasva  )NUD_vA  <kasvama ;28_V	et	f	\N
125720	keeta	keeta =kee  (SgAb  >kesi !15_S	et	f	\N
125721	keeta	keeta =kee  (SgAb  >kee !26_S	et	f	\N
125722	keeta	keeta =keet  (Inf  >keetma !34_V	et	f	\N
125740	eneselt	eneselt =enese  (SgAbl  >enese !00_P	et	f	\N
125741	eneselt	eneselt =enese  (SgAbl  >ise !00_P	et	f	\N
125745	toiduaine	toiduaine =aine  (SgN  >toidu+aine !06_S	et	f	\N
125746	toiduaine	toiduaine =aine  (SgG  >toidu+aine !06_S	et	f	\N
125661	kindlus	"kindlus %kindla  )US_aS  <kindel ;02_A	et	f	\N
125677	postijaama	postijaama =jaama  (SgG  >posti+jaam !22_S	et	f	\N
125679	postijaama	postijaama =jaama  (SgP  >posti+jaam !22_S	et	f	\N
125680	postijaama	postijaama =jaama  (SgAdt  >posti+jaam !22_S	et	f	\N
125710	päritolu	päritolu =olu  (SgN  >pärit+olu !17_S	et	f	\N
125711	päritolu	päritolu =olu  (SgG  >pärit+olu !17_S	et	f	\N
125712	päritolu	päritolu =olu  (SgP  >pärit+olu !17_S	et	f	\N
125715	perepjolkin	?perepjolkin =perepjolkin  (SgN  >perepjolkin !02_S	et	f	\N
125748	vormitud	vormitud =vormi  (PtsPtIps  >vormima !28_V	et	f	\N
125749	vormitud	vormitud =vormitu  (PlN  >vormitu !01_AS	et	f	\N
125750	vormitud	"vormitu %vormi  )TU1_vS  <vormima ;28_V	et	f	\N
125751	vormitud	"vormitu %vormi  )TU2_kA  <vorm ;22_S	et	f	\N
125752	vormitud	vormitud =vormitud  (ID  >vormitud !41_A	et	f	\N
125755	vormitud	"vormitud %vormi  )TUD_vA  <vormima ;28_V	et	f	\N
125765	medalitelgi	medalitelgi =telgi  (SgG  >medali+telk !22_S	et	f	\N
125766	medalitelgi	medalitelgi =telgi  (SgP  >medali+telg !22_S	et	f	\N
125767	medalitelgi	medalitelgi =telgi  (SgAdt  >medali+telg !22_S	et	f	\N
125768	medalitelgi	medalitelgi =telgi  (PlP  >medali+telg !22_S	et	f	\N
125769	medalitelgi	medalitelgi =medali  (PlAd^  >medal !02_S	et	f	\N
125781	alandid	alandid =alandi  (PlN  >alandi !01_S	et	f	\N
125782	alandid	alandid =alandi  (PlN  >aland !02_S	et	f	\N
125785	alandidel	### alandidel	et	f	\N
125789	lõppu	lõppu =lõppu  (SgP  >lõpp !22_SA	et	f	\N
125790	lõppu	lõppu =lõppu  (SgAdt  >lõpp !22_SA	et	f	\N
125795	majoor	?majoor =majoor  (SgN  >majoor !22_S	et	f	\N
125796	tehnikasõnavara	tehnikasõnavara =vara  (SgN  >tehnika+sõna+vara !17_S	et	f	\N
125797	tehnikasõnavara	tehnikasõnavara =vara  (SgG  >tehnika+sõna+vara !17_S	et	f	\N
125798	tehnikasõnavara	tehnikasõnavara =vara  (SgP  >tehnika+sõna+vara !17_S	et	f	\N
125809	ütlevad	ütlevad =ütle  (IndPrPl3  >ütlema !30_V	et	f	\N
125810	ütlevad	ütlevad =ütleva  (PlN  >ütlev !02_A	et	f	\N
125811	ütlevad	"ütlev %ütle  )V_vA  <ütlema ;30_V	et	f	\N
125812	ütlev	ütlev =ütle  (PtsPrPs  >ütlema !30_V	et	f	\N
125813	ütlev	ütlev =ütlev  (SgN  >ütlev !02_A	et	f	\N
125814	ütlev	"ütlev %ütle  )V_vA  <ütlema ;30_V	et	f	\N
125815	joomisest	joomisest =joomise  (SgEl  >joomine !12?10_S	et	f	\N
125816	joomisest	"joomine %joo  )MINE_vS  <jooma ;38_V	et	f	\N
125817	joomisest	"joomine %joomi  )NE_aA  <joom ;22_S	et	f	\N
125828	korrespondentile	### korrespondentile	et	f	\N
125849	põlisalandlastega	?põlisalandlastega =põlisalandlas  (PlKom  >põlisalandlane !12_S	et	f	\N
125850	põlisalandlastega	?põlisalandlastega =alandlas  (PlKom  >põlis+alandlane !12_S	et	f	\N
125861	kingitused	kingitused =kingituse  (PlN  >kingitus !11_S	et	f	\N
125862	kingitused	"kingitus %kingi  )TUS1_aS  <kinkima ;28_V	et	f	\N
125863	kingitused	"kingitus %kingi  )TUS2_aS  <kink ;22_S	et	f	\N
125864	alandlane	?alandlane =alandlane  (SgN  >alandlane !12_S	et	f	\N
125868	maguspala	maguspala =pala  (SgN  >magus+pala !17_S	et	f	\N
125869	maguspala	maguspala =pala  (SgG  >magus+pala !17_S	et	f	\N
125870	maguspala	maguspala =pala  (SgP  >magus+pala !17_S	et	f	\N
125899	toonud	toonud =too  (PtsPtPs  >tooma !38_V	et	f	\N
125900	toonud	toonud =toonu  (PlN  >toonu !01_S	et	f	\N
125901	toonud	"toonu %too  )NU_vS  <tooma ;38_V	et	f	\N
125902	toonud	toonud =toonu  (PlN  >toonu !06_S	et	f	\N
125903	toonud	toonud =toonud  (ID  >toonud !41_A	et	f	\N
125904	toonud	"toonud %too  )NUD_vA  <tooma ;38_V	et	f	\N
125907	võitlesid	võitlesid =võitle  (IndIpfSg2  >võitlema !30_V	et	f	\N
125908	võitlesid	võitlesid =võitle  (IndIpfPl3  >võitlema !30_V	et	f	\N
125927	teid	teid =te  (PlP  >sa !00_P	et	f	\N
125928	teid	teid =te  (PlP  >sina !00_P	et	f	\N
125929	teid	teid =te  (PlP  >tee !26_S	et	f	\N
126008	arenguprogrammi	arenguprogrammi =programmi  (SgG  >arengu+programm !22_S	et	f	\N
126009	arenguprogrammi	arenguprogrammi =programmi  (SgP  >arengu+programm !22_S	et	f	\N
126010	arenguprogrammi	arenguprogrammi =programmi  (SgAdt  >arengu+programm !22_S	et	f	\N
126023	määravaks	määravaks =määrava  (SgTr  >määrav !02_A	et	f	\N
126024	määravaks	"määrav %määra  )V_vA  <määrama ;29_V	et	f	\N
126032	täidetud	täidetud =täide  (PtsPtIps  >täitma !34_V	et	f	\N
126033	täidetud	täidetud =täidetu  (PlN  >täidetu !01_AS	et	f	\N
126034	täidetud	"täidetu %täide  )TU1_vS  <täitma ;34_V	et	f	\N
126035	täidetud	täidetud =täidetud  (ID  >täidetud !41_A	et	f	\N
126036	täidetud	"täidetud %täide  )TUD_vA  <täitma ;34_V	et	f	\N
126037	nimeta	nimeta =nime  (SgAb  >nimi !20_S	et	f	\N
126038	nimeta	nimeta =nimeta  (IndPrPs_  >nimetama !27_V	et	f	\N
126039	nimeta	nimeta =nimeta  (ImpPrSg2  >nimetama !27_V	et	f	\N
126059	linnale	linnale =linna  (SgAll  >linn !22_S	et	f	\N
126061	linnale	linnale =ale  (SgN  >linn+ale !16_S	et	f	\N
126063	linnale	linnale =ale  (SgG  >linn+ale !16_S	et	f	\N
126067	räbaldunud	räbaldunud =räbaldu  (PtsPtPs  >räbalduma !27_V	et	f	\N
126068	räbaldunud	räbaldunud =räbaldunu  (PlN  >räbaldunu !01_S	et	f	\N
126069	räbaldunud	"räbaldunu %räbaldu  )NU_vS  <räbalduma ;27_V	et	f	\N
125688	säilitanud	säilitanud =säilita  (PtsPtPs  >säilitama !27_V	et	f	\N
125689	säilitanud	säilitanud =säilitanu  (PlN  >säilitanu !01_S	et	f	\N
125690	säilitanud	"säilitanu %säilita  )NU_vS  <säilitama ;27_V	et	f	\N
125691	säilitanud	säilitanud =säilitanud  (ID  >säilitanud !41_A	et	f	\N
125692	säilitanud	"säilitanud %säilita  )NUD_vA  <säilitama ;27_V	et	f	\N
125693	ahvenamaal	ahvenamaal =maa  (SgAd  >ahvena+maa !26_S	et	f	\N
125694	ahvenamaal	ahvenamaal =maal  (SgN  >ahvena+maal !22_S	et	f	\N
125695	aadressaatide	?aadressaatide =aadressaati  (PlG  >aadressaati !16_S	et	f	\N
125696	aadressaatide	?aadressaatide =aadressaati  (PlG  >aadressaat !22_S	et	f	\N
125705	mõistatusel	mõistatusel =mõistatuse  (SgAd  >mõistatus !11_S	et	f	\N
125706	mõistatusel	"mõistatus %mõistata  )US_vS  <mõistatama ;27_V	et	f	\N
125707	lahendus	lahendus =lahendu  (IndIpfSg3  >lahenduma !27_V	et	f	\N
125708	lahendus	lahendus =lahendus  (SgN  >lahendus !11_S	et	f	\N
125709	lahendus	"lahendus %lahenda  )US_vS  <lahendama ;27_V	et	f	\N
125714	petrov	?petrov =petrov  (SgN  >petrov !02_A	et	f	\N
125726	müts	müts =müts  (ID  >müts !41_I	et	f	\N
125727	müts	müts =müts  (SgN  >müts !22_S	et	f	\N
125735	küpsetamiseks	küpsetamiseks =küpsetamise  (SgTr  >küpsetamine !12_S	et	f	\N
125736	küpsetamiseks	"küpsetamine %küpseta  )MINE_vS  <küpsetama ;27_V	et	f	\N
125759	tsaarikotkast	tsaarikotkast =kotka  (SgEl  >tsaari+kotkas !07_S	et	f	\N
125761	tsaarikotkast	tsaarikotkast =kotkas  (SgP  >tsaari+kotkas !07_S	et	f	\N
125763	tsaarikotkast	tsaarikotkast =kotkas  (SgP  >tsaari+kotkane !12~10_A	et	f	\N
125764	tsaarikotkast	"tsaari+kotkane %kotka  )NE_aA  <tsaari+kotkas ;07_S	et	f	\N
125770	aurahast	aurahast =raha  (SgEl  >au+raha !17_S	et	f	\N
125771	aurahast	aurahast =raha  (SgEl  >au+rahk !22_S	et	f	\N
125772	aurahast	aurahast =rahas  (SgP  >au+rahane !10_A	et	f	\N
125773	aurahast	"au+rahane %raha  )NE_aA  <au+raha ;17_S	et	f	\N
125774	aurahast	"au+rahane %raha  )NE_aA  <au+rahk ;22_S	et	f	\N
125778	maiuspala	maiuspala =pala  (SgN  >maius+pala !17_S	et	f	\N
125779	maiuspala	maiuspala =pala  (SgG  >maius+pala !17_S	et	f	\N
125780	maiuspala	maiuspala =pala  (SgP  >maius+pala !17_S	et	f	\N
125793	varustasid	varustasid =varusta  (IndIpfSg2  >varustama !27_V	et	f	\N
125794	varustasid	varustasid =varusta  (IndIpfPl3  >varustama !27_V	et	f	\N
125820	viibisid	viibisid =viibi  (IndIpfSg2  >viibima !27_V	et	f	\N
125821	viibisid	viibisid =viibi  (IndIpfPl3  >viibima !27_V	et	f	\N
125822	aastakümnet	### aastakümnet	et	f	\N
125840	mõistatuse	mõistatuse =mõistatuse  (SgG  >mõistatus !11_S	et	f	\N
125841	mõistatuse	"mõistatus %mõistata  )US_vS  <mõistatama ;27_V	et	f	\N
125847	selletõttu	selletõttu =tõttu  (SgP  >selle+tõtt !22_S	et	f	\N
125848	selletõttu	selletõttu =tõttu  (SgAdt  >selle+tõtt !22_S	et	f	\N
125854	tunduvad	tunduvad =tundu  (IndPrPl3  >tunduma !27_V	et	f	\N
125855	tunduvad	tunduvad =tunduva  (PlN  >tunduv !02_A	et	f	\N
125856	tunduvad	"tunduv %tundu  )V_vA  <tunduma ;27_V	et	f	\N
125857	kartuus	?kartuus =kartuu  (SgIn  >kartuu !26_S	et	f	\N
125858	kartuus	?kartuus =kartuus  (SgN  >kartuus !22_S	et	f	\N
125877	kotkast	kotkast =kotka  (SgEl  >kotkas !07_S	et	f	\N
125878	kotkast	kotkast =kotkas  (SgP  >kotkas !07_S	et	f	\N
125879	kotkast	kotkast =kotkas  (SgP  >kotkane !12~10_A	et	f	\N
125880	kotkast	"kotkane %kotka  )NE_aA  <kotkas ;07_S	et	f	\N
125883	nimetatigi	nimetatigi =nimeta  (IndIpfIps^  >nimetama !27_V	et	f	\N
125884	nimetatigi	nimetatigi =tati  (SgG^  >nime+tatt !22_S	et	f	\N
125932	suusatajad	suusatajad =suusataja  (PlN  >suusataja !01_S	et	f	\N
125933	suusatajad	"suusataja %suusata  )JA_vS  <suusatama ;27_V	et	f	\N
125934	jääaluse	jääaluse =aluse  (SgG  >jää+alus !09_S	et	f	\N
125935	jääaluse	jääaluse =aluse  (SgG  >jää+alune !10_AS	et	f	\N
125937	jääaluse	"jää+alune %alu  )NE_aA  <jää+alg ;22_S	et	f	\N
125940	raeküla	raeküla =küla  (SgN  >rae+küla !17_S	et	f	\N
125941	raeküla	raeküla =küla  (SgG  >rae+küla !17_S	et	f	\N
125943	raeküla	raeküla =küla  (SgP  >rae+küla !17_S	et	f	\N
125954	väikeseid	väikeseid =väikese  (PlP  >väike !10_A	et	f	\N
125955	väikeseid	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
125956	väikeseid	väikeseid =väikese  (PlP  >väikene !10_A	et	f	\N
125957	väikeseid	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
125958	kannata	kannata =kanna  (SgAb  >kanna !16_S	et	f	\N
125959	kannata	kannata =kanna  (SgAb  >kand !22_S	et	f	\N
125960	kannata	kannata =kannata  (IndPrPs_  >kannatama !27_V	et	f	\N
125962	kannata	kannata =kannata  (ImpPrSg2  >kannatama !27_V	et	f	\N
125964	puudusest	puudusest =puuduse  (SgEl  >puudus !11~09_S	et	f	\N
125965	puudusest	puudusest =puuduses  (SgP  >puudusene !12_A	et	f	\N
125966	puudusest	"puudusene %puuduse  )NE_aA  <puudus ;09_S	et	f	\N
125967	puudusest	"puudusene %puuduse  )NE_aA  <puudus ;11_S	et	f	\N
125973	neljakümnele	?neljakümnele =neljakümne  (PlAll  >neljakümn !22_S	et	f	\N
125974	neljakümnele	?neljakümnele =kümne  (PlAll  >nelja+kümn !22_S	et	f	\N
125977	kujundatud	kujundatud =kujunda  (PtsPtIps  >kujundama !27_V	et	f	\N
125978	kujundatud	kujundatud =kujundatu  (PlN  >kujundatu !01_S	et	f	\N
125747	toiduaine	toiduaine =aine  (PlP  >toidu+ain !22_S	et	f	\N
125753	küpsetatud	küpsetatud =küpseta  (PtsPtIps  >küpsetama !27_V	et	f	\N
125754	küpsetatud	küpsetatud =küpsetatu  (PlN  >küpsetatu !01_S	et	f	\N
125756	küpsetatud	"küpsetatu %küpseta  )TU1_vS  <küpsetama ;27_V	et	f	\N
125757	küpsetatud	küpsetatud =küpsetatud  (ID  >küpsetatud !41_A	et	f	\N
125758	küpsetatud	"küpsetatud %küpseta  )TUD_vA  <küpsetama ;27_V	et	f	\N
125804	kohalikke	kohalikke =kohalikke  (PlP  >kohalik !25_AS	et	f	\N
125805	kohalikke	kohalikke =ikke  (SgG  >kohal+ike !06_S	et	f	\N
125806	südamlikult	südamlikult =südamliku  (SgAbl  >südamlik !25_A	et	f	\N
125807	südamlikult	südamlikult =südamlikult  (ID  >südamlikult !41_D	et	f	\N
125808	südamlikult	"südamlikult %südamliku  )LT_mD  <südamlik ;25_A	et	f	\N
125823	pravda	?pravda =pravda  (SgN  >pravda !16_S	et	f	\N
125824	pravda	?pravda =pravda  (SgG  >pravda !16_S	et	f	\N
125827	pravda	?pravda =pravda  (IndPrPs_  >pravdama !29_V	et	f	\N
125829	pravda	?pravda =pravda  (ImpPrSg2  >pravdama !29_V	et	f	\N
125843	vaikima	vaikima =vaiki  (Sup  >vaikima !27_V	et	f	\N
125844	vaikima	vaikima =ima  (SgN  >vaik+ima !17_S	et	f	\N
125845	vaikima	vaikima =ima  (SgG  >vaik+ima !17_S	et	f	\N
125846	vaikima	vaikima =ima  (SgP  >vaik+ima !17_S	et	f	\N
125851	soomerootslaste	soomerootslaste =las  (PlG  >soome+roots+laps !14_S	et	f	\N
125852	soomerootslaste	soomerootslaste =laste  (PlP  >soome+roots+last !22_S	et	f	\N
125853	soomerootslaste	soomerootslaste =rootslas  (PlG  >soome+rootslane !12?10_S	et	f	\N
125859	kamsun	?kamsun =kamsu  (IndPrSg1  >kamsuma !27_V	et	f	\N
125860	kamsun	?kamsun =kamsun  (SgN  >kamsun !02_S	et	f	\N
125889	harukordseks	harukordseks =seks  (SgN  >haru+kord+seks !22_S	et	f	\N
125890	harukordseks	harukordseks =kordse  (SgTr  >haru+kordne !02_AS	et	f	\N
125905	endaga	endaga =enda  (SgKom  >enda !00_P	et	f	\N
125906	endaga	endaga =enda  (SgKom  >ise !00_P	et	f	\N
125909	öisetelt	?öisetelt =öise  (PlAbl  >öise !06_S	et	f	\N
125910	öisetelt	?öisetelt =öisete  (PlAbl  >öisett !22_S	et	f	\N
125911	öisetelt	?öisetelt =öisetelt  (ID  >öisetelt !41_D	et	f	\N
125917	soolaga	soolaga =soola  (SgKom  >sool !22_S	et	f	\N
125918	soolaga	soolaga =la  (SgKom  >soo+la !26_S	et	f	\N
125919	soolaga	soolaga =laga  (SgN  >soo+laga !17_S	et	f	\N
125920	soolaga	soolaga =laga  (SgG  >soo+laga !17_S	et	f	\N
125921	soolaga	soolaga =laga  (SgP  >soo+laga !17_S	et	f	\N
125936	kalapüügi	kalapüügi =püügi  (SgG  >kala+püük !22_S	et	f	\N
125938	kalapüügi	kalapüügi =püü  (SgN^  >kala+püü !26_S	et	f	\N
125939	kalapüügi	kalapüügi =püü  (SgG^  >kala+püü !26_S	et	f	\N
125942	suusarada	suusarada =rada  (SgN  >suusa+rada !18_S	et	f	\N
125944	suusarada	suusarada =rada  (SgP  >suusa+rada !18_S	et	f	\N
125945	soovivad	soovivad =soovi  (IndPrPl3  >soovima !28_V	et	f	\N
125946	soovivad	soovivad =sooviva  (PlN  >sooviv !02_A	et	f	\N
125948	soovivad	"sooviv %soovi  )V_vA  <soovima ;28_V	et	f	\N
125950	soovivad	soovivad =iva  (PlN  >soov+iva !17_S	et	f	\N
125970	lossikompleksi	lossikompleksi =kompleksi  (SgG  >lossi+kompleks !22_S	et	f	\N
125971	lossikompleksi	lossikompleksi =kompleksi  (SgP  >lossi+kompleks !22_S	et	f	\N
125972	lossikompleksi	lossikompleksi =kompleksi  (SgAdt  >lossi+kompleks !22_S	et	f	\N
125982	ajaloolisele	ajaloolisele =loolise  (SgAll  >aja+looline !12?10_A	et	f	\N
125983	ajaloolisele	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
125984	ajaloolisele	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
125985	ajaloolisele	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
125986	ajaloolisele	ajaloolisele =loolise  (SgAll  >aja+looline !12?10_S	et	f	\N
125987	pargiainelisi	pargiainelisi =ainelisi  (PlP  >pargi+aineline !12_A	et	f	\N
125988	pargiainelisi	"pargi+aineline %aine  )LINE_aA  <pargi+aine ;06_S	et	f	\N
125989	arendamise	arendamise =arendamise  (SgG  >arendamine !12_S	et	f	\N
125990	arendamise	"arendamine %arenda  )MINE_vS  <arendama ;27_V	et	f	\N
126000	stroomirannas	?stroomirannas =stroomiranna  (SgIn  >stroomiranna !16_S	et	f	\N
126006	heakskiidetud	heakskiidetud =kiide  (PtsPtIps  >heaks+_kiitma !34_V	et	f	\N
126007	heakskiidetud	heakskiidetud =kiidetu  (PlN  >heaks+kiidetu !01_AS	et	f	\N
126017	põhjaosa	põhjaosa =osa  (SgN  >põhja+osa !17_S	et	f	\N
126018	põhjaosa	põhjaosa =osa  (SgG  >põhja+osa !17_S	et	f	\N
126019	põhjaosa	põhjaosa =osa  (SgP  >põhja+osa !17_S	et	f	\N
126025	linnaosavanem	linnaosavanem =vanem  (SgN  >linna+osa+vanem !02_AS	et	f	\N
126026	linnaosavanem	"linna+osa+vanem %vane  )M_cA  <linna+osa+vana ;17_AS	et	f	\N
126029	nimestikku	nimestikku =nimestikku  (SgP  >nimestik !25_S	et	f	\N
126030	nimestikku	nimestikku =nimestikku  (SgAdt  >nimestik !25_S	et	f	\N
126031	investorid	?investorid =investori  (PlN  >investor !02_S	et	f	\N
126040	teemandiks	teemandiks =teemandi  (SgTr  >teemant !22_S	et	f	\N
126041	teemandiks	teemandiks =mandi  (SgTr  >tee+mant !22_S	et	f	\N
126054	rekontruktsiooni	?rekontruktsiooni =rekontruktsioo  (SgTer  >rekontruktsioo !26_S	et	f	\N
126056	rekontruktsiooni	?rekontruktsiooni =rekontruktsiooni  (SgN  >rekontruktsiooni !16_S	et	f	\N
126058	rekontruktsiooni	?rekontruktsiooni =rekontruktsiooni  (SgG  >rekontruktsiooni !16_S	et	f	\N
126060	rekontruktsiooni	?rekontruktsiooni =rekontruktsiooni  (SgG  >rekontruktsioon !22_S	et	f	\N
125888	nähtuseks	"nähtus %näh  )TUS1_aS  <nägema ;28_V	et	f	\N
125893	kiirustanud	kiirustanud =kiirusta  (PtsPtPs  >kiirustama !27_V	et	f	\N
125894	kiirustanud	kiirustanud =kiirustanu  (PlN  >kiirustanu !01_S	et	f	\N
125895	kiirustanud	"kiirustanu %kiirusta  )NU_vS  <kiirustama ;27_V	et	f	\N
125896	kiirustanud	kiirustanud =kiirustanud  (ID  >kiirustanud !41_A	et	f	\N
125897	kiirustanud	"kiirustanud %kiirusta  )NUD_vA  <kiirustama ;27_V	et	f	\N
125898	kiirustanud	kiirustanud =tanu  (PlN  >kiirus+tanu !17_S	et	f	\N
125912	tänavatelt	tänavatelt =tänava  (PlAbl  >tänav !02_A	et	f	\N
125913	tänavatelt	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
125914	tänavatelt	tänavatelt =tänava  (PlAbl  >tänav !02_S	et	f	\N
125915	tänavatelt	tänavatelt =ate  (PlAbl  >tänav+att !22_S	et	f	\N
125916	tänavatelt	tänavatelt =vate  (PlAbl  >täna+vatt !22_S	et	f	\N
125922	puisata	?puisata =puisa  (SgAb  >puisa !16_S	et	f	\N
125923	puisata	?puisata =puisa  (Inf  >puisama !29_V	et	f	\N
125924	puisata	?puisata =puisa  (IndPrIps_  >puisama !29_V	et	f	\N
125925	puisata	?puisata =puisata  (IndPrPs_  >puisatama !27_V	et	f	\N
125926	puisata	?puisata =puisata  (ImpPrSg2  >puisatama !27_V	et	f	\N
125930	jaga	jaga =jaga  (IndPrPs_  >jagama !27_V	et	f	\N
125931	jaga	jaga =jaga  (ImpPrSg2  >jagama !27_V	et	f	\N
125975	suveterass	?suveterass =suveterass  (SgN  >suveterass !22_S	et	f	\N
125976	suveterass	?suveterass =terass  (SgN  >suve+terass !22_S	et	f	\N
125991	vastavalt	vastavalt =vastava  (SgAbl  >vastav !02_A	et	f	\N
125992	vastavalt	"vastav %vasta  )V_vA  <vastama ;29_V	et	f	\N
125993	vastavalt	vastavalt =vastavalt  (ID  >vastavalt !41_D	et	f	\N
125994	vastavalt	"vastavalt %vasta  )VALT_mD  <vastama ;29_V	et	f	\N
125995	vastavalt	"vastavalt %vastava  )LT_mD  <vastav ;02_A	et	f	\N
125996	vastavalt	vastavalt =ava  (SgAbl  >vast+ava !17_S	et	f	\N
125997	evilde	### evilde	et	f	\N
125998	lisas	lisas =lisa  (SgIn  >lisa !17_S	et	f	\N
125999	lisas	lisas =lisa  (IndIpfSg3  >lisama !27_V	et	f	\N
126011	stabiilselt	stabiilselt =stabiilse  (SgAbl  >stabiilne !02_A	et	f	\N
126012	stabiilselt	stabiilselt =stabiilselt  (ID  >stabiilselt !41_D	et	f	\N
126013	stabiilselt	"stabiilselt %stabiilse  )LT_mD  <stabiilne ;02_A	et	f	\N
126077	kujundavad	kujundavad =kujunda  (IndPrPl3  >kujundama !27_V	et	f	\N
126078	kujundavad	kujundavad =kujundava  (PlN  >kujundav !02_A	et	f	\N
126079	kujundavad	"kujundav %kujunda  )V_vA  <kujundama ;27_V	et	f	\N
126094	piirkonna	piirkonna =piirkonna  (SgG  >piirkond !22_S	et	f	\N
126095	piirkonna	piirkonna =konna  (SgG  >piir+konn !22_S	et	f	\N
126096	piirkonna	piirkonna =konna  (SgP  >piir+konn !22_S	et	f	\N
126097	piirkonna	piirkonna =konna  (SgAdt  >piir+konn !22_S	et	f	\N
126100	seatud	seatud =sea  (PtsPtIps  >seadma !34_V	et	f	\N
126101	seatud	seatud =seatu  (PlN  >seatu !01_S	et	f	\N
126102	seatud	"seatu %sea  )TU1_vS  <seadma ;34_V	et	f	\N
126103	seatud	"seatu %sea  )TU2_kA  <siga ;18_SA	et	f	\N
126104	seatud	seatud =seatud  (ID  >seatud !41_A	et	f	\N
126105	seatud	"seatud %sea  )TUD_vA  <seadma ;34_V	et	f	\N
126109	sõlmile	sõlmile =sõlmi  (SgAll  >sõlm !22_S	et	f	\N
126110	sõlmile	sõlmile =sõlmi  (PlAll  >sõlm !22_S	et	f	\N
126113	sotsiaalsetele	sotsiaalsetele =sotsiaalse  (PlAll  >sotsiaalne !02_A	et	f	\N
126114	sotsiaalsetele	sotsiaalsetele =sete  (PlAll  >sotsiaal+sett !22_S	et	f	\N
126142	kohtla	?kohtla =kohtla  (SgN  >kohtla !01_S	et	f	\N
126143	kohtla	?kohtla =kohtla  (SgG  >kohtla !01_S	et	f	\N
126144	kohtla	?kohtla =kohtla  (IndPrPs_  >kohtlama !29_V	et	f	\N
126145	kohtla	?kohtla =kohtla  (ImpPrSg2  >kohtlama !29_V	et	f	\N
126146	veene	veene =veene  (SgN  >veene !06_S	et	f	\N
126147	veene	"veene %vee  )NE_aA  <vesi ;15_S	et	f	\N
126148	veene	veene =veene  (SgN  >veene !10_A	et	f	\N
126149	veene	veene =veene  (PlP  >veen !22_S	et	f	\N
126173	muusemi	muusemi =muusemi  (SgG  >muusem !02_A	et	f	\N
126174	muusemi	"muusem %muu  )SEM_cA  <muu ;26_S	et	f	\N
126184	pärandiga	pärandiga =pärandi  (SgKom  >pärand !02_S	et	f	\N
126185	pärandiga	pärandiga =iga  (SgN  >pärand+iga !18_S	et	f	\N
126188	pärandiga	pärandiga =iga  (SgP  >pärand+iga !18_S	et	f	\N
126206	adusman	?adusman =adusman  (SgN  >adusman !19_S	et	f	\N
126230	käede	?käede =käe  (PlG  >käe !26_S	et	f	\N
126231	käede	?käede =käede  (SgN  >käede !06_S	et	f	\N
126232	käede	?käede =käede  (PlP  >käed !22_S	et	f	\N
126233	käede	?käede =käede  (IndPrPs_  >käedema !27_V	et	f	\N
126234	käede	?käede =käede  (ImpPrSg2  >käedema !27_V	et	f	\N
126256	turismi	turismi =turismi  (SgG  >turism !22_S	et	f	\N
126257	turismi	turismi =turismi  (SgP  >turism !22_S	et	f	\N
126258	turismi	turismi =turismi  (SgAdt  >turism !22_S	et	f	\N
126266	perekonnaga	perekonnaga =perekonna  (SgKom  >perekond !22_S	et	f	\N
126267	perekonnaga	perekonnaga =konna  (SgKom  >pere+konn !22_S	et	f	\N
126281	pedagoogikaülikooli	pedagoogikaülikooli =kooli  (SgG  >pedagoogika+üli+kool !22_S	et	f	\N
126282	pedagoogikaülikooli	pedagoogikaülikooli =kooli  (SgP  >pedagoogika+üli+kool !22_S	et	f	\N
126283	pedagoogikaülikooli	pedagoogikaülikooli =kooli  (SgAdt  >pedagoogika+üli+kool !22_S	et	f	\N
125979	kujundatud	"kujundatu %kujunda  )TU1_vS  <kujundama ;27_V	et	f	\N
125980	kujundatud	kujundatud =kujundatud  (ID  >kujundatud !41_A	et	f	\N
125981	kujundatud	"kujundatud %kujunda  )TUD_vA  <kujundama ;27_V	et	f	\N
126020	alumatult	?alumatult =alumatu  (SgAbl  >alumatu !01_A	et	f	\N
126021	alumatult	?alumatult =alumatult  (ID  >alumatult !41_D	et	f	\N
126022	alumatult	?alumatult =matu  (SgAbl  >alu+matu !16_S	et	f	\N
126027	järgnevaks	järgnevaks =järgneva  (SgTr  >järgnev !02_A	et	f	\N
126028	järgnevaks	"järgnev %järgne  )V_vA  <järgnema ;27_V	et	f	\N
126047	majaperemeeste	majaperemeeste =mees  (PlG  >maja+pere+meene !10_A	et	f	\N
126048	majaperemeeste	"maja+pere+meene %mee  )NE_aA  <maja+pere+mesi ;15_S	et	f	\N
126049	majaperemeeste	majaperemeeste =mees  (PlG  >maja+pere+mees !13_S	et	f	\N
126050	arhitektuuri	arhitektuuri =arhitektuuri  (SgG  >arhitektuur !22_S	et	f	\N
126051	arhitektuuri	arhitektuuri =arhitektuuri  (SgP  >arhitektuur !22_S	et	f	\N
126052	arhitektuuri	arhitektuuri =arhitektuuri  (SgAdt  >arhitektuur !22_S	et	f	\N
126115	täiendatakse	täiendatakse =täienda  (IndPrIps  >täiendama !27_V	et	f	\N
126116	täiendatakse	täiendatakse =takse  (PlP  >täi+enda+taks !22_S	et	f	\N
126117	kultuuriasutuste	kultuuriasutuste =tuste  (PlP  >kultuuri+asu+tust !22_S	et	f	\N
126118	kultuuriasutuste	kultuuriasutuste =asutus  (PlG  >kultuuri+asutus !11_S	et	f	\N
126119	kultuuriasutuste	"kultuuri+asutus %asu  )TUS2_aS  <kultuuri+asu ;17_S	et	f	\N
126120	baasi	baasi =baasi  (SgG  >baas !22_S	et	f	\N
126121	baasi	baasi =baasi  (SgP  >baas !22_S	et	f	\N
126122	baasi	baasi =baasi  (SgAdt  >baas !22_S	et	f	\N
126123	noortekeskust	noortekeskust =us  (SgP  >noorte+kesk+uks !14_S	et	f	\N
126124	noortekeskust	noortekeskust =keskus  (SgP  >noorte+keskus !11~09_S	et	f	\N
126125	lemmikumaid	?lemmikumaid =lemmikumai  (PlN  >lemmikumai !26_S	et	f	\N
126126	lemmikumaid	?lemmikumaid =lemmikumai  (SgP  >lemmikumai !26_S	et	f	\N
126127	lemmikumaid	?lemmikumaid =umai  (PlN  >lemmik+umai !26_S	et	f	\N
126128	lemmikumaid	?lemmikumaid =umai  (SgP  >lemmik+umai !26_S	et	f	\N
126129	lemmikumaid	?lemmikumaid =umaid  (SgN  >lemmik+umaid !22_S	et	f	\N
126135	merimetsa	merimetsa =metsa  (SgG  >meri+mets !22_S	et	f	\N
126136	merimetsa	merimetsa =metsa  (SgP  >meri+mets !22_S	et	f	\N
126137	merimetsa	merimetsa =metsa  (SgAdt  >meri+mets !22_S	et	f	\N
126158	alustatud	alustatud =alusta  (PtsPtIps  >alustama !27_V	et	f	\N
126159	alustatud	alustatud =alustatu  (PlN  >alustatu !01_S	et	f	\N
126160	alustatud	"alustatu %alusta  )TU1_vS  <alustama ;27_V	et	f	\N
126161	alustatud	alustatud =alustatud  (ID  >alustatud !41_A	et	f	\N
126162	alustatud	"alustatud %alusta  )TUD_vA  <alustama ;27_V	et	f	\N
126163	üliõpilastele	üliõpilastele =las  (PlAll  >üli+õpi+laps !14_S	et	f	\N
126164	üliõpilastele	üliõpilastele =laste  (PlAll  >üli+õpi+last !22_S	et	f	\N
126165	üliõpilastele	üliõpilastele =õpilas  (PlAll  >üli+õpilane !12_S	et	f	\N
126166	kaasatakse	kaasatakse =kaasa  (IndPrIps  >kaasama !29_V	et	f	\N
126167	kaasatakse	kaasatakse =takse  (PlP  >kaasa+taks !22_S	et	f	\N
126171	pärandiks	pärandiks =pärandi  (SgTr  >pärand !02_S	et	f	\N
126172	pärandiks	pärandiks =iks  (SgN  >pärand+iks !22_S	et	f	\N
126175	struktuuri	struktuuri =struktuuri  (SgG  >struktuur !22_S	et	f	\N
126176	struktuuri	struktuuri =struktuuri  (SgP  >struktuur !22_S	et	f	\N
126177	struktuuri	struktuuri =struktuuri  (SgAdt  >struktuur !22_S	et	f	\N
126189	analüüsitakse	analüüsitakse =analüüsi  (IndPrIps  >analüüsima !28_V	et	f	\N
126190	analüüsitakse	analüüsitakse =takse  (PlP  >analüüsi+taks !22_S	et	f	\N
126238	balt	?balt =balt  (SgN  >balt !22_S	et	f	\N
126244	kluubis	?kluubis =kluubi  (SgIn  >kluubi !16_S	et	f	\N
126247	kluubis	?kluubis =kluubi  (SgIn  >kluup !22_S	et	f	\N
126249	kluubis	?kluubis =kluubi  (IndIpfSg3  >kluubima !27_V	et	f	\N
126251	kluubis	?kluubis =kluubis  (SgN  >kluubis !09_S	et	f	\N
126261	solvavalt	solvavalt =solvava  (SgAbl  >solvav !02_A	et	f	\N
126262	solvavalt	"solvav %solva  )V_vA  <solvama ;29_V	et	f	\N
126263	solvavalt	solvavalt =solvavalt  (ID  >solvavalt !41_D	et	f	\N
126264	solvavalt	"solvavalt %solva  )VALT_mD  <solvama ;29_V	et	f	\N
126265	solvavalt	"solvavalt %solvava  )LT_mD  <solvav ;02_A	et	f	\N
126303	õppekohta	õppekohta =kohta  (SgP  >õppe+koht !22_S	et	f	\N
126304	õppekohta	õppekohta =kohta  (SgAdt  >õppe+koht !22_S	et	f	\N
126305	räägisid	?räägisid =räägi  (PlP  >räägi !16_S	et	f	\N
126306	räägisid	?räägisid =räägi  (PlP  >rääg !22_S	et	f	\N
126307	räägisid	?räägisid =räägi  (IndIpfSg2  >räägima !28_V	et	f	\N
126308	räägisid	?räägisid =räägi  (IndIpfPl3  >räägima !28_V	et	f	\N
126322	õnnetusi	õnnetusi =õnnetusi  (PlP  >õnnetus !11_S	et	f	\N
126323	õnnetusi	"õnnetus %õnne  )TUS2_aS  <õnn ;22_S	et	f	\N
126324	elulugu	elulugu =lugu  (SgN  >elu+lugu !18_S	et	f	\N
126325	elulugu	elulugu =lugu  (SgP  >elu+lugu !18_S	et	f	\N
126326	ühetoalises	ühetoalises =toalise  (SgIn  >ühe+toaline !12?10_A	et	f	\N
126327	ühetoalises	"ühe+toaline %toa  )LINE_aA  <ühe+tuba ;18_S	et	f	\N
126348	parimad	parimad =parima  (PlN  >parim !02_A	et	f	\N
126349	parimad	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
126001	toimunud	toimunud =toimu  (PtsPtPs  >toimuma !27_V	et	f	\N
126002	toimunud	toimunud =toimunu  (PlN  >toimunu !01_S	et	f	\N
126003	toimunud	"toimunu %toimu  )NU_vS  <toimuma ;27_V	et	f	\N
126004	toimunud	toimunud =toimunud  (ID  >toimunud !41_A	et	f	\N
126005	toimunud	"toimunud %toimu  )NUD_vA  <toimuma ;27_V	et	f	\N
126014	sõltumata	sõltumata =sõltu  (SupAb  >sõltuma !27_V	et	f	\N
126015	sõltumata	sõltumata =sõltumata  (ID  >sõltumata !41_A	et	f	\N
126016	sõltumata	"sõltumata %sõltu  )MATA_vA  <sõltuma ;27_V	et	f	\N
126042	lagunenud	lagunenud =lagune  (PtsPtPs  >lagunema !27_V	et	f	\N
126043	lagunenud	lagunenud =lagunenu  (PlN  >lagunenu !01_S	et	f	\N
126044	lagunenud	"lagunenu %lagune  )NU_vS  <lagunema ;27_V	et	f	\N
126045	lagunenud	lagunenud =lagunenud  (ID  >lagunenud !41_A	et	f	\N
126046	lagunenud	"lagunenud %lagune  )NUD_vA  <lagunema ;27_V	et	f	\N
126053	vajavad	vajavad =vaja  (IndPrPl3  >vajama !27_V	et	f	\N
126055	vajavad	vajavad =vajava  (PlN  >vajav !02_A	et	f	\N
126057	vajavad	"vajav %vaja  )V_vA  <vajama ;27_V	et	f	\N
126075	projektiks	projektiks =projekti  (SgTr  >projekt !22_S	et	f	\N
126076	projektiks	projektiks =iks  (SgN  >projekt+iks !22_S	et	f	\N
126082	põhiosa	põhiosa =osa  (SgN  >põhi+osa !17_S	et	f	\N
126083	põhiosa	põhiosa =osa  (SgG  >põhi+osa !17_S	et	f	\N
126084	põhiosa	põhiosa =osa  (SgP  >põhi+osa !17_S	et	f	\N
126085	lähimatel	lähimatel =lähima  (PlAd  >lähim !02_A	et	f	\N
126086	lähimatel	"lähim %lähi  )IM_sA  <lähike ;12_A	et	f	\N
126087	lähimatel	lähimatel =mate  (SgAd  >lähi+mate !16_S	et	f	\N
126088	lähimatel	lähimatel =mate  (PlAd  >lähi+matt !22_SA	et	f	\N
126138	rannamajakese	rannamajakese =majakese  (SgG  >ranna+majake !12_S	et	f	\N
126139	rannamajakese	"ranna+majake %maja  )KE_dS  <ranna+maja ;17_S	et	f	\N
126140	rannamajakese	rannamajakese =majakese  (SgG  >ranna+majakene !12_S	et	f	\N
126141	rannamajakese	"ranna+majakene %maja  )KENE_dS  <ranna+maja ;17_S	et	f	\N
126150	finanseeritakse	?finanseeritakse =finanseeri  (IndPrIps  >finanseerima !28_V	et	f	\N
126151	finanseeritakse	?finanseeritakse =finanseeritakse  (SgG  >finanseeritakne !02_A	et	f	\N
126152	finanseeritakse	?finanseeritakse =finanseeritakse  (PlP  >finanseeritaks !22_S	et	f	\N
126155	edukalt	edukalt =eduka  (SgAbl  >edukas !02_A	et	f	\N
126156	edukalt	edukalt =edukalt  (ID  >edukalt !41_D	et	f	\N
126157	edukalt	"edukalt %eduka  )LT_mD  <edukas ;02_A	et	f	\N
126178	vahelist	vahelist =vahelis  (SgP  >vaheline !12_A	et	f	\N
126179	vahelist	"vaheline %vahe  )LINE_aA  <vahe ;16_S	et	f	\N
126180	kaasnemise	kaasnemise =kaasnemise  (SgG  >kaasnemine !12_S	et	f	\N
126181	kaasnemise	"kaasnemine %kaasne  )MINE_vS  <kaasnema ;27_V	et	f	\N
126194	alustavad	alustavad =alusta  (IndPrPl3  >alustama !27_V	et	f	\N
126195	alustavad	alustavad =alustava  (PlN  >alustav !02_A	et	f	\N
126196	alustavad	"alustav %alusta  )V_vA  <alustama ;27_V	et	f	\N
126197	alustavad	alustavad =tava  (PlN  >alus+tava !17_S	et	f	\N
126200	järvel	järvel =järve  (SgAd  >järv !22_S	et	f	\N
126201	järvel	järvel =järve  (PlAd  >järv !22_S	et	f	\N
126202	kuulajates	kuulajates =kuulaja  (PlIn  >kuulaja !01_S	et	f	\N
126203	kuulajates	"kuulaja %kuula  )JA_vS  <kuulama ;29_V	et	f	\N
126204	tutvumise	tutvumise =tutvumise  (SgG  >tutvumine !12_S	et	f	\N
126205	tutvumise	"tutvumine %tutvu  )MINE_vS  <tutvuma ;27_V	et	f	\N
126215	katus	katus =katu  (SgIn  >katt !22_S	et	f	\N
126217	katus	katus =katus  (SgN  >katus !09_S	et	f	\N
126223	halvem	halvem =halvem  (SgN  >halvem !02_A	et	f	\N
126224	halvem	"halvem %halve  )M_cA  <halb ;22_A	et	f	\N
126226	sõrme	sõrme =sõrme  (SgG  >sõrm !22_S	et	f	\N
126227	sõrme	sõrme =sõrme  (SgP  >sõrm !22_S	et	f	\N
126228	sõrme	sõrme =sõrme  (SgAdt  >sõrm !22_S	et	f	\N
126229	sõrme	sõrme =sõrme  (PlP  >sõrm !22_S	et	f	\N
126236	neliteist	neliteist =te  (PlEl  >neli+tee !26_S	et	f	\N
126237	neliteist	neliteist =teist  (SgN  >neli+teist !22_S	et	f	\N
126240	purjetamise	purjetamise =purjetamise  (SgG  >purjetamine !12_S	et	f	\N
126241	purjetamise	"purjetamine %purjeta  )MINE_vS  <purjetama ;27_V	et	f	\N
126252	õnnelikum	õnnelikum =õnnelikum  (SgN  >õnnelikum !02_A	et	f	\N
126253	õnnelikum	"õnnelikum %õnneliku  )M_cA  <õnnelik ;25_A	et	f	\N
126317	sooritatud	sooritatud =soorita  (PtsPtIps  >sooritama !27_V	et	f	\N
126318	sooritatud	sooritatud =sooritatu  (PlN  >sooritatu !01_S	et	f	\N
126319	sooritatud	"sooritatu %soorita  )TU1_vS  <sooritama ;27_V	et	f	\N
126320	sooritatud	sooritatud =sooritatud  (ID  >sooritatud !41_A	et	f	\N
126321	sooritatud	"sooritatud %soorita  )TUD_vA  <sooritama ;27_V	et	f	\N
126336	auhinda	auhinda =hinda  (SgP  >au+hind !22_S	et	f	\N
126337	auhinda	auhinda =hinda  (SgAdt  >au+hind !22_S	et	f	\N
126338	auhinda	auhinda =hinda  (IndPrPs_  >au+hindama !29_V	et	f	\N
126339	auhinda	auhinda =hinda  (ImpPrSg2  >au+hindama !29_V	et	f	\N
126340	enesekindlust	enesekindlust =kindlus  (SgP  >enese+kindlus !11~09_S	et	f	\N
126341	enesekindlust	"enese+kindlus %kindla  )US_aS  <enese+kindel ;02_A	et	f	\N
126346	muusikakoolis	muusikakoolis =kooli  (SgIn  >muusika+kool !22_S	et	f	\N
126347	muusikakoolis	muusikakoolis =kooli  (PlIn  >muusika+kool !22_S	et	f	\N
126062	rekontruktsiooni	?rekontruktsiooni =rekontruktsiooni  (SgP  >rekontruktsioon !22_S	et	f	\N
126064	rekontruktsiooni	?rekontruktsiooni =rekontruktsiooni  (SgAdt  >rekontruktsioon !22_S	et	f	\N
126065	rekontruktsiooni	?rekontruktsiooni =rekontruktsiooni  (IndPrPs_  >rekontruktsioonima !28_V	et	f	\N
126066	rekontruktsiooni	?rekontruktsiooni =rekontruktsiooni  (ImpPrSg2  >rekontruktsioonima !28_V	et	f	\N
126080	piirkonnad	piirkonnad =piirkonna  (PlN  >piirkond !22_S	et	f	\N
126081	piirkonnad	piirkonnad =konna  (PlN  >piir+konn !22_S	et	f	\N
126108	transpordi	transpordi =transpordi  (SgG  >transport !22_S	et	f	\N
126111	transpordi	transpordi =transpordi  (IndPrPs_  >transportima !28_V	et	f	\N
126112	transpordi	transpordi =transpordi  (ImpPrSg2  >transportima !28_V	et	f	\N
126130	rannatsooni	rannatsooni =tsooni  (SgG  >ranna+tsoon !22_S	et	f	\N
126131	rannatsooni	rannatsooni =tsooni  (SgP  >ranna+tsoon !22_S	et	f	\N
126132	rannatsooni	rannatsooni =tsooni  (SgAdt  >ranna+tsoon !22_S	et	f	\N
126133	ligipääsetavaks	ligipääsetavaks =tava  (SgTr  >ligi+pääse+tava !17_S	et	f	\N
126134	ligipääsetavaks	ligipääsetavaks =pääsetava  (SgTr  >ligi+pääsetav !02_A	et	f	\N
126153	vaheline	vaheline =vaheline  (SgN  >vaheline !12_A	et	f	\N
126154	vaheline	"vaheline %vahe  )LINE_aA  <vahe ;16_S	et	f	\N
126182	turismimarsruuti	turismimarsruuti =marsruuti  (SgP  >turismi+marsruut !22_S	et	f	\N
126183	turismimarsruuti	turismimarsruuti =marsruuti  (SgAdt  >turismi+marsruut !22_S	et	f	\N
126186	tutvumiseks	tutvumiseks =tutvumise  (SgTr  >tutvumine !12_S	et	f	\N
126187	tutvumiseks	"tutvumine %tutvu  )MINE_vS  <tutvuma ;27_V	et	f	\N
126191	infotehnolooge	infotehnolooge =looge  (SgN  >info+tehno+looge !06_S	et	f	\N
126192	infotehnolooge	infotehnolooge =looge  (PlP  >info+tehno+loog !22_S	et	f	\N
126193	infotehnolooge	infotehnolooge =tehnolooge  (PlP  >info+tehnoloog !22_S	et	f	\N
126198	arendamist	arendamist =arendamis  (SgP  >arendamine !12_S	et	f	\N
126199	arendamist	"arendamine %arenda  )MINE_vS  <arendama ;27_V	et	f	\N
126207	pedagoogika	pedagoogika =pedagoogika  (SgN  >pedagoogika !01_S	et	f	\N
126208	pedagoogika	pedagoogika =pedagoogika  (SgG  >pedagoogika !01_S	et	f	\N
126209	sõrmu	?sõrmu =sõrmu  (SgN  >sõrmu !16_S	et	f	\N
126210	sõrmu	?sõrmu =sõrmu  (SgG  >sõrmu !16_S	et	f	\N
126211	sõrmu	?sõrmu =sõrmu  (IndPrPs_  >sõrmuma !27_V	et	f	\N
126212	sõrmu	?sõrmu =sõrmu  (ImpPrSg2  >sõrmuma !27_V	et	f	\N
126213	kamiini	?kamiini =kamii  (SgTer  >kamii !26_S	et	f	\N
126214	kamiini	?kamiini =kamiini  (SgN  >kamiini !16_S	et	f	\N
126216	kamiini	?kamiini =kamiini  (SgG  >kamiini !16_S	et	f	\N
126218	kamiini	?kamiini =kamiini  (SgG  >kamiin !22_S	et	f	\N
126219	kamiini	?kamiini =kamiini  (SgP  >kamiin !22_S	et	f	\N
126220	kamiini	?kamiini =kamiini  (SgAdt  >kamiin !22_S	et	f	\N
126221	kamiini	?kamiini =kamiini  (IndPrPs_  >kamiinima !28_V	et	f	\N
126222	kamiini	?kamiini =kamiini  (ImpPrSg2  >kamiinima !28_V	et	f	\N
126225	kehalisekasvatuse	?kehalisekasvatuse =kehalisekasvatuse  (SgG  >kehalisekasvatus !11?09_S	et	f	\N
126309	lapsepõlves	lapsepõlves =põlve  (SgIn  >lapse+põlv !22_S	et	f	\N
126310	lapsepõlves	lapsepõlves =põlve  (SgIn  >lapse+põli !24_S	et	f	\N
126311	lapsepõlves	lapsepõlves =põlve  (PlIn  >lapse+põlv !22_S	et	f	\N
126330	esimesse	esimesse =esimes  (SgAdt  >esimene !12_OP	et	f	\N
126331	esimesse	esimesse =messe  (PlP  >esi+mess !22_S	et	f	\N
126334	meeldisid	meeldisid =meeldi  (IndIpfSg2  >meeldima !27_V	et	f	\N
126335	meeldisid	meeldisid =meeldi  (IndIpfPl3  >meeldima !27_V	et	f	\N
126384	tehnikaülikooli	tehnikaülikooli =kooli  (SgG  >tehnika+üli+kool !22_S	et	f	\N
126385	tehnikaülikooli	tehnikaülikooli =kooli  (SgP  >tehnika+üli+kool !22_S	et	f	\N
126386	tehnikaülikooli	tehnikaülikooli =kooli  (SgAdt  >tehnika+üli+kool !22_S	et	f	\N
126387	tehnikaülikooli	tehnikaülikooli =kooli  (PlP  >tehnika+üli+kool !22_S	et	f	\N
126390	lahkusin	lahkusin =lahku  (IndIpfSg1  >lahkuma !27_V	et	f	\N
126391	lahkusin	lahkusin =usin  (SgN  >lahk+usin !02_A	et	f	\N
126403	abistajana	abistajana =abistaja  (SgEs  >abistaja !01_S	et	f	\N
126404	abistajana	"abistaja %abista  )JA_vS  <abistama ;27_V	et	f	\N
126431	igavlev	igavlev =igavle  (PtsPrPs  >igavlema !27_V	et	f	\N
126432	igavlev	igavlev =igavlev  (SgN  >igavlev !02_A	et	f	\N
126433	igavlev	"igavlev %igavle  )V_vA  <igavlema ;27_V	et	f	\N
126455	lemmikuks	lemmikuks =lemmiku  (SgTr  >lemmik !02_S	et	f	\N
126456	lemmikuks	lemmikuks =uks  (SgN  >lemmik+uks !14_S	et	f	\N
126459	vedas	vedas =veda  (SgIn  >veda !17_S	et	f	\N
126460	vedas	vedas =veda  (IndIpfSg3  >vedama !28_V	et	f	\N
126469	ringides	ringides =ringi  (PlIn  >ring !22_S	et	f	\N
126470	ringides	ringides =ringi  (Ger  >ringima !28_V	et	f	\N
126473	aastaseks	aastaseks =aastase  (SgTr  >aastane !12~10_A	et	f	\N
126474	aastaseks	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
126475	aastaseks	aastaseks =seks  (SgN  >aasta+seks !22_S	et	f	\N
126483	tavalisesse	tavalisesse =tavalise  (SgIll  >tavaline !12_A	et	f	\N
126484	tavalisesse	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
126490	täppisteadusvõime	täppisteadusvõime =võime  (SgN  >täppis+teadus+võime !06_S	et	f	\N
126491	täppisteadusvõime	täppisteadusvõime =võime  (SgG  >täppis+teadus+võime !06_S	et	f	\N
126492	täppisteadusvõime	täppisteadusvõime =võime  (PlP  >täppis+teadus+võim !22_S	et	f	\N
126070	räbaldunud	räbaldunud =räbaldunud  (ID  >räbaldunud !41_A	et	f	\N
126071	räbaldunud	"räbaldunud %räbaldu  )NUD_vA  <räbalduma ;27_V	et	f	\N
126072	varjupaike	varjupaike =paike  (SgN  >varju+paike !12?10_AS	et	f	\N
126073	varjupaike	"varju+paike %pai  )KE_dA  <varju+pai ;26_AS	et	f	\N
126074	varjupaike	varjupaike =paike  (PlP  >varju+paik !22_S	et	f	\N
126089	võrku	võrku =võrku  (SgP  >võrk !22_S	et	f	\N
126090	võrku	võrku =võrku  (SgAdt  >võrk !22_S	et	f	\N
126091	kanalisatsiooni	kanalisatsiooni =kanalisatsiooni  (SgG  >kanalisatsioon !22_S	et	f	\N
126092	kanalisatsiooni	kanalisatsiooni =kanalisatsiooni  (SgP  >kanalisatsioon !22_S	et	f	\N
126093	kanalisatsiooni	kanalisatsiooni =kanalisatsiooni  (SgAdt  >kanalisatsioon !22_S	et	f	\N
126098	teedeehitus	teedeehitus =ehitu  (SgIn  >teede+ehitu !01_AS	et	f	\N
126099	teedeehitus	teedeehitus =ehitus  (SgN  >teede+ehitus !11_S	et	f	\N
126106	ümbersõiduteed	ümbersõiduteed =tee  (PlN  >ümber+sõidu+tee !26_S	et	f	\N
126107	ümbersõiduteed	ümbersõiduteed =tee  (SgP  >ümber+sõidu+tee !26_S	et	f	\N
126168	projektiga	projektiga =projekti  (SgKom  >projekt !22_S	et	f	\N
126169	projektiga	projektiga =iga  (SgN  >projekt+iga !18_S	et	f	\N
126170	projektiga	projektiga =iga  (SgP  >projekt+iga !18_S	et	f	\N
126235	jalade	### jalade	et	f	\N
126239	saili	?saili =saili  (SgN  >saili !16_S	et	f	\N
126242	saili	?saili =saili  (SgG  >saili !16_S	et	f	\N
126243	saili	?saili =saili  (SgG  >sail !22_S	et	f	\N
126245	saili	?saili =saili  (SgP  >sail !22_S	et	f	\N
126246	saili	?saili =saili  (SgAdt  >sail !22_S	et	f	\N
126248	saili	?saili =saili  (IndPrPs_  >sailima !28_V	et	f	\N
126250	saili	?saili =saili  (ImpPrSg2  >sailima !28_V	et	f	\N
126254	purjetamisega	purjetamisega =purjetamise  (SgKom  >purjetamine !12_S	et	f	\N
126255	purjetamisega	"purjetamine %purjeta  )MINE_vS  <purjetama ;27_V	et	f	\N
126259	klassikaaslastega	klassikaaslastega =las  (PlKom  >klassi+kaas+laps !14_S	et	f	\N
126260	klassikaaslastega	klassikaaslastega =kaaslas  (PlKom  >klassi+kaaslane !12?10_S	et	f	\N
126268	veenemaale	?veenemaale =veenemaa  (SgAll  >veenemaa !26_S	et	f	\N
126269	veenemaale	?veenemaale =veenemaale  (SgN  >veenemaale !16_S	et	f	\N
126270	veenemaale	?veenemaale =veenemaale  (SgG  >veenemaale !16_S	et	f	\N
126271	veenemaale	?veenemaale =veenemaale  (PlP  >veenemaal !22_S	et	f	\N
126272	veenemaale	?veenemaale =nemaa  (SgAll  >vee+nemaa !26_S	et	f	\N
126273	veenemaale	?veenemaale =nemaale  (SgN  >vee+nemaale !16_S	et	f	\N
126274	veenemaale	?veenemaale =nemaale  (SgG  >vee+nemaale !16_S	et	f	\N
126275	veenemaale	?veenemaale =nemaale  (PlP  >vee+nemaal !22_S	et	f	\N
126276	stipendiumi	stipendiumi =stipendiumi  (SgG  >stipendium !19~02_S	et	f	\N
126277	stipendiumi	stipendiumi =stipendiumi  (SgP  >stipendium !19_S	et	f	\N
126278	stipendiumi	stipendiumi =stipendiumi  (SgAdt  >stipendium !19_S	et	f	\N
126279	triibuline	triibuline =triibuline  (SgN  >triibuline !12_A	et	f	\N
126280	triibuline	"triibuline %triibu  )LINE_aA  <triip ;22_S	et	f	\N
126285	suuremas	suuremas =suurema  (SgIn  >suurem !02_A	et	f	\N
126286	suuremas	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
126287	suuremas	suuremas =ema  (SgIn  >suur+ema !17_S	et	f	\N
126292	tunnides	?tunnides =tunni  (PlIn  >tunni !16_S	et	f	\N
126293	tunnides	?tunnides =tunni  (PlIn  >tunn !22_S	et	f	\N
126294	tunnides	?tunnides =tunni  (Ger  >tunnima !28_V	et	f	\N
126295	haigeks	haigeks =haige  (SgTr  >haige !01_AS	et	f	\N
126296	haigeks	haigeks =haige  (PlTr  >haik !22_S	et	f	\N
126299	usunud	?usunud =usu  (PtsPtPs  >usuma !27_V	et	f	\N
126300	usunud	?usunud =usunu  (PlN  >usunu !01_S	et	f	\N
126301	usunud	?usunud =usunu  (IndPrSg2  >usunuma !27_V	et	f	\N
126302	usunud	?usunud =usunud  (ID  >usunud !41_A	et	f	\N
126368	veendunud	veendunud =veendu  (PtsPtPs  >veenduma !27_V	et	f	\N
126369	veendunud	veendunud =veendunu  (PlN  >veendunu !01_S	et	f	\N
126370	veendunud	"veendunu %veendu  )NU_vS  <veenduma ;27_V	et	f	\N
126371	veendunud	veendunud =veendunud  (ID  >veendunud !41_A	et	f	\N
126372	veendunud	"veendunud %veendu  )NUD_vA  <veenduma ;27_V	et	f	\N
126375	inseneerina	?inseneerina =inseneeri  (SgEs  >inseneeri !16_S	et	f	\N
126376	inseneerina	?inseneerina =inseneeri  (SgEs  >inseneer !22_S	et	f	\N
126377	inseneerina	?inseneerina =inseneerina  (SgG  >inseneerin !02_S	et	f	\N
126392	eksinud	eksinud =eksi  (PtsPtPs  >eksima !28_V	et	f	\N
126393	eksinud	eksinud =eksinu  (PlN  >eksinu !01_S	et	f	\N
126394	eksinud	"eksinu %eksi  )NU_vS  <eksima ;28_V	et	f	\N
126395	eksinud	eksinud =eksinud  (ID  >eksinud !41_A	et	f	\N
126396	eksinud	"eksinud %eksi  )NUD_vA  <eksima ;28_V	et	f	\N
126397	müüjana	müüjana =müüja  (SgEs  >müüja !01_S	et	f	\N
126398	müüjana	"müüja %müü  )JA_vS  <müüma ;38_V	et	f	\N
126440	idamaise	idamaise =maise  (SgG  >ida+maine !10_A	et	f	\N
126441	idamaise	"ida+maine %mai  )NE_aA  <ida+maa ;26_S	et	f	\N
126442	idamaise	idamaise =maise  (PlP  >ida+mais !22_S	et	f	\N
126482	sse	### sse	et	f	\N
126485	koolisse	koolisse =kooli  (SgIll  >kool !22_S	et	f	\N
126486	koolisse	koolisse =kooli  (PlIll  >kool !22_S	et	f	\N
126493	puudus	puudus =puudu  (IndIpfSg3  >puuduma !27_V	et	f	\N
126284	pedagoogikaülikooli	pedagoogikaülikooli =kooli  (PlP  >pedagoogika+üli+kool !22_S	et	f	\N
126288	otsustus	otsustus =otsustu  (IndIpfSg3  >otsustuma !27_V	et	f	\N
126289	otsustus	otsustus =otsustus  (SgN  >otsustus !11_S	et	f	\N
126290	otsustus	"otsustus %otsusta  )US_vS  <otsustama ;27_V	et	f	\N
126291	otsustus	otsustus =ustu  (SgIn  >ots+ustu !01_S	et	f	\N
126297	korraks	korraks =korra  (SgTr  >kord !22_S	et	f	\N
126298	korraks	korraks =korraks  (ID  >korraks !41_D	et	f	\N
126312	õppinud	õppinud =õppi  (PtsPtPs  >õppima !28_V	et	f	\N
126313	õppinud	õppinud =õppinu  (PlN  >õppinu !01_S	et	f	\N
126314	õppinud	"õppinu %õppi  )NU_vS  <õppima ;28_V	et	f	\N
126315	õppinud	õppinud =õppinud  (ID  >õppinud !41_A	et	f	\N
126316	õppinud	"õppinud %õppi  )NUD_vA  <õppima ;28_V	et	f	\N
126328	kolmetoalise	kolmetoalise =toalise  (SgG  >kolme+toaline !12?10_A	et	f	\N
126329	kolmetoalise	"kolme+toaline %toa  )LINE_aA  <kolme+tuba ;18_S	et	f	\N
126332	klassiõpetaja	klassiõpetaja =õpetaja  (SgN  >klassi+õpetaja !01_S	et	f	\N
126333	klassiõpetaja	klassiõpetaja =õpetaja  (SgG  >klassi+õpetaja !01_S	et	f	\N
126342	keskkoolis	keskkoolis =kooli  (SgIn  >kesk+kool !22_S	et	f	\N
126343	keskkoolis	keskkoolis =kooli  (PlIn  >kesk+kool !22_S	et	f	\N
126344	neljaga	neljaga =nelja  (SgKom  >neljas !02_O	et	f	\N
126345	neljaga	neljaga =nelja  (SgKom  >neli !24_N	et	f	\N
126358	ülekäikurada	ülekäikurada =rada  (SgN  >üle+käiku+rada !18_S	et	f	\N
126359	ülekäikurada	ülekäikurada =rada  (SgP  >üle+käiku+rada !18_S	et	f	\N
126360	valgete	valgete =valge  (PlG  >valge !01_AS	et	f	\N
126361	valgete	valgete =e  (PlG  >valg+esi !15_S	et	f	\N
126364	mustatest	mustatest =test  (SgN  >musta+test !22_S	et	f	\N
126365	mustatest	mustatest =ate  (PlEl  >must+att !22_S	et	f	\N
126366	lisata	lisata =lisa  (SgAb  >lisa !17_S	et	f	\N
126367	lisata	lisata =lisa  (IndPrIps_  >lisama !27_V	et	f	\N
126373	lahendust	lahendust =lahendus  (SgP  >lahendus !11_S	et	f	\N
126374	lahendust	"lahendus %lahenda  )US_vS  <lahendama ;27_V	et	f	\N
126378	monteerijana	monteerijana =monteerija  (SgEs  >monteerija !01_S	et	f	\N
126379	monteerijana	"monteerija %monteeri  )JA_vS  <monteerima ;28_V	et	f	\N
126399	hippodroomis	?hippodroomis =hippodroomi  (SgIn  >hippodroomi !16_S	et	f	\N
126400	hippodroomis	?hippodroomis =hippodroomi  (SgIn  >hippodroom !22_S	et	f	\N
126401	hippodroomis	?hippodroomis =hippodroomi  (IndIpfSg3  >hippodroomima !28_V	et	f	\N
126402	hippodroomis	?hippodroomis =hippodroomis  (SgN  >hippodroomis !09_S	et	f	\N
126410	tehnikasuunaga	tehnikasuunaga =naga  (SgN  >tehnika+suu+naga !17_S	et	f	\N
126411	tehnikasuunaga	tehnikasuunaga =naga  (SgG  >tehnika+suu+naga !17_S	et	f	\N
126412	tehnikasuunaga	tehnikasuunaga =naga  (SgP  >tehnika+suu+naga !17_S	et	f	\N
126413	tehnikasuunaga	tehnikasuunaga =suuna  (SgKom  >tehnika+suund !22_S	et	f	\N
126414	igatsenud	igatsenud =igatse  (PtsPtPs  >igatsema !27_V	et	f	\N
126415	igatsenud	igatsenud =igatsenu  (PlN  >igatsenu !01_S	et	f	\N
126416	igatsenud	"igatsenu %igatse  )NU_vS  <igatsema ;27_V	et	f	\N
126417	igatsenud	igatsenud =igatsenud  (ID  >igatsenud !41_A	et	f	\N
126418	igatsenud	"igatsenud %igatse  )NUD_vA  <igatsema ;27_V	et	f	\N
126443	köitnud	köitnud =köit  (PtsPtPs  >köitma !34_V	et	f	\N
126444	köitnud	köitnud =köitnu  (PlN  >köitnu !01_S	et	f	\N
126445	köitnud	"köitnu %köit  )NU_vS  <köitma ;34_V	et	f	\N
126446	köitnud	köitnud =köitnud  (ID  >köitnud !41_A	et	f	\N
126447	köitnud	"köitnud %köit  )NUD_vA  <köitma ;34_V	et	f	\N
126448	kevadel	kevadel =kevade  (SgAd  >kevade !01_S	et	f	\N
126449	kevadel	kevadel =kevade  (SgAd  >kevad !02_S	et	f	\N
126461	juuste	juuste =juus  (PlG  >juus !09_S	et	f	\N
126462	juuste	juuste =juuste  (PlP  >juust !22_S	et	f	\N
126465	liitumist	liitumist =liitumi  (SgEl  >liitum !02_A	et	f	\N
126466	liitumist	"liitum %lii  )TUM2_cA  <lii ;26_S	et	f	\N
126467	liitumist	liitumist =liitumis  (SgP  >liitumine !12_S	et	f	\N
126468	liitumist	"liitumine %liitu  )MINE_vS  <liituma ;27_V	et	f	\N
126471	joonistamisest	joonistamisest =joonistamise  (SgEl  >joonistamine !12_S	et	f	\N
126472	joonistamisest	"joonistamine %joonista  )MINE_vS  <joonistama ;27_V	et	f	\N
126487	da	### da	et	f	\N
126488	ühtsust	ühtsust =ühtsus  (SgP  >ühtsus !11~09_S	et	f	\N
126489	ühtsust	"ühtsus %ühtse  )US_aS  <ühtne ;02_A	et	f	\N
126497	juhuslikult	juhuslikult =juhusliku  (SgAbl  >juhuslik !25_A	et	f	\N
126498	juhuslikult	juhuslikult =juhuslikult  (ID  >juhuslikult !41_D	et	f	\N
126499	juhuslikult	"juhuslikult %juhusliku  )LT_mD  <juhuslik ;25_A	et	f	\N
126507	türgis	?türgis =türgi  (SgIn  >türk !22_S	et	f	\N
126509	türgis	?türgis =türgi  (IndIpfSg3  >türgima !28_V	et	f	\N
126510	türgis	?türgis =türgis  (SgN  >türgis !09_S	et	f	\N
126521	tolleks	tolleks =tolle  (SgTr  >too !00_P	et	f	\N
126522	tolleks	tolleks =tolle  (PlTr  >toll !22_S	et	f	\N
126523	tpüsse	?tpüsse =tpüsse  (SgN  >tpüsse !06_S	et	f	\N
126524	tpüsse	?tpüsse =tpüsse  (SgG  >tpüsne !02_A	et	f	\N
126525	tpüsse	?tpüsse =tpüsse  (SgG  >tpüsse !06_S	et	f	\N
126526	tpüsse	?tpüsse =tpüsse  (PlP  >tpüss !22_S	et	f	\N
126527	tpüsse	?tpüsse =tpüsse  (IndPrPs_  >tpüssema !27_V	et	f	\N
126350	kaheteistkümnenda	?kaheteistkümnenda =kaheteistkümnenda  (SgN  >kaheteistkümnenda !16_S	et	f	\N
126351	kaheteistkümnenda	?kaheteistkümnenda =kaheteistkümnenda  (SgG  >kaheteistkümnenda !16_S	et	f	\N
126352	kaheteistkümnenda	?kaheteistkümnenda =kaheteistkümnenda  (IndPrPs_  >kaheteistkümnendama !27_V	et	f	\N
126353	kaheteistkümnenda	?kaheteistkümnenda =kaheteistkümnenda  (ImpPrSg2  >kaheteistkümnendama !27_V	et	f	\N
126354	kaheteistkümnenda	?kaheteistkümnenda =kümnenda  (SgN  >kahe+teist+kümnenda !01_S	et	f	\N
126355	kaheteistkümnenda	?kaheteistkümnenda =kümnenda  (SgG  >kahe+teist+kümnenda !01_S	et	f	\N
126356	kaheteistkümnenda	?kaheteistkümnenda =teistkümnenda  (SgN  >kahe+teistkümnenda !16_S	et	f	\N
126357	kaheteistkümnenda	?kaheteistkümnenda =teistkümnenda  (SgG  >kahe+teistkümnenda !16_S	et	f	\N
126362	armasta	armasta =armasta  (IndPrPs_  >armastama !27_V	et	f	\N
126363	armasta	armasta =armasta  (ImpPrSg2  >armastama !27_V	et	f	\N
126380	suunaga	suunaga =suuna  (SgKom  >suund !22_S	et	f	\N
126381	suunaga	suunaga =naga  (SgN  >suu+naga !17_S	et	f	\N
126382	suunaga	suunaga =naga  (SgG  >suu+naga !17_S	et	f	\N
126383	suunaga	suunaga =naga  (SgP  >suu+naga !17_S	et	f	\N
126405	püüdnud	püüdnud =püüd  (PtsPtPs  >püüdma !34_V	et	f	\N
126406	püüdnud	püüdnud =püüdnu  (PlN  >püüdnu !01_S	et	f	\N
126407	püüdnud	"püüdnu %püüd  )NU_vS  <püüdma ;34_V	et	f	\N
126408	püüdnud	püüdnud =püüdnud  (ID  >püüdnud !41_A	et	f	\N
126409	püüdnud	"püüdnud %püüd  )NUD_vA  <püüdma ;34_V	et	f	\N
126434	idamaad	idamaad =maa  (PlN  >ida+maa !26_S	et	f	\N
126435	idamaad	idamaad =maa  (SgP  >ida+maa !26_S	et	f	\N
126436	idamaist	idamaist =ma  (PlEl  >ida+maa !26_S	et	f	\N
126437	idamaist	idamaist =mai  (SgEl  >ida+mai !26_S	et	f	\N
126438	idamaist	idamaist =mais  (SgP  >ida+maine !10_A	et	f	\N
126439	idamaist	"ida+maine %mai  )NE_aA  <ida+maa ;26_S	et	f	\N
126479	era	era =era  (SgN  >era !17_S	et	f	\N
126480	era	era =era  (SgG  >era !17_S	et	f	\N
126481	era	era =era  (SgP  >era !17_S	et	f	\N
126495	sooritamist	sooritamist =sooritamis  (SgP  >sooritamine !12_S	et	f	\N
126496	sooritamist	"sooritamine %soorita  )MINE_vS  <sooritama ;27_V	et	f	\N
126528	konkurs	?konkurs =konkurs  (SgN  >konkurs !02_S	et	f	\N
126536	kannatamatult	kannatamatult =kannatamatu  (SgAbl  >kannatamatu !01_A	et	f	\N
126538	kannatamatult	"kannatamatu %kannata  )MATU_vA  <kannatama ;27_V	et	f	\N
126540	kannatamatult	kannatamatult =kannatamatult  (ID  >kannatamatult !41_D	et	f	\N
126541	kannatamatult	"kannatamatult %kannata  )MATULT_mD  <kannatama ;27_V	et	f	\N
126542	kannatamatult	"kannatamatult %kannatamatu  )LT_mD  <kannatamatu ;01_A	et	f	\N
126543	ida-virumaal	ida-virumaal =maa  (SgAd  >ida-viru+maa !26_S	et	f	\N
126544	ida-virumaal	ida-virumaal =maal  (SgN  >ida-viru+maal !22_S	et	f	\N
126545	rahvusest	rahvusest =rahvuse  (SgEl  >rahvus !11~09_S	et	f	\N
126547	rahvusest	rahvusest =rahvuses  (SgP  >rahvusene !12_A	et	f	\N
126549	rahvusest	"rahvusene %rahvuse  )NE_aA  <rahvus ;09_S	et	f	\N
126550	rahvusest	"rahvusene %rahvuse  )NE_aA  <rahvus ;11_S	et	f	\N
126553	kiviõli	kiviõli =õli  (SgN  >kivi+õli !17_S	et	f	\N
126554	kiviõli	kiviõli =õli  (SgG  >kivi+õli !17_S	et	f	\N
126555	kiviõli	kiviõli =õli  (SgP  >kivi+õli !17_S	et	f	\N
126558	väikesena	väikesena =väikese  (SgEs  >väike !12?10_A	et	f	\N
126559	väikesena	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
126560	väikesena	väikesena =väikese  (SgEs  >väikene !12?10_A	et	f	\N
126561	väikesena	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
126591	elukutsest	elukutsest =kutse  (SgEl  >elu+kutse !06_S	et	f	\N
126593	elukutsest	elukutsest =kutse  (PlEl  >elu+kuts !22_S	et	f	\N
126595	elukutsest	elukutsest =kutses  (SgP  >elu+kutsene !10_A	et	f	\N
126596	elukutsest	"elu+kutsene %kutse  )NE_aA  <elu+kutse ;06_S	et	f	\N
126628	dokumentid	?dokumentid =umenti  (PlN  >dok+umenti !01_S	et	f	\N
126631	kahest	kahest =kahe  (SgEl  >kaks !22_N	et	f	\N
126632	kahest	kahest =kahe  (PlEl  >kahk !22_S	et	f	\N
126633	kahest	kahest =kahes  (SgP  >kahene !10_AS	et	f	\N
126634	kahest	"kahene %kahe  )NE_aA  <kaks ;22_N	et	f	\N
126641	kompositsiooni	kompositsiooni =kompositsiooni  (SgG  >kompositsioon !22_S	et	f	\N
126642	kompositsiooni	kompositsiooni =kompositsiooni  (SgP  >kompositsioon !22_S	et	f	\N
126643	kompositsiooni	kompositsiooni =kompositsiooni  (SgAdt  >kompositsioon !22_S	et	f	\N
126646	kompositsiooni	kompositsiooni =positsiooni  (SgG  >kom+positsioon !22_S	et	f	\N
126647	kompositsiooni	kompositsiooni =positsiooni  (SgP  >kom+positsioon !22_S	et	f	\N
126648	kompositsiooni	kompositsiooni =positsiooni  (SgAdt  >kom+positsioon !22_S	et	f	\N
126677	valikust	valikust =valiku  (SgEl  >valik !02_S	et	f	\N
126678	valikust	valikust =us  (SgP  >valik+uks !14_S	et	f	\N
126711	pealinnas	pealinnas =inna  (SgIn  >peal+ind !22_S	et	f	\N
126712	pealinnas	pealinnas =linna  (SgIn  >pea+linn !22_S	et	f	\N
126713	pealinnas	pealinnas =linnas  (SgN  >pea+linnas !09_S	et	f	\N
126716	olengi	olengi =olengi  (SgG  >oleng !02_S	et	f	\N
126717	olengi	olengi =ole  (IndPrSg1^  >olema !36_V	et	f	\N
126726	paralleelselt	paralleelselt =paralleelse  (SgAbl  >paralleelne !02_A	et	f	\N
126727	paralleelselt	paralleelselt =paralleelselt  (ID  >paralleelselt !41_D	et	f	\N
126388	informaatika	informaatika =informaatika  (SgN  >informaatika !01_S	et	f	\N
126389	informaatika	informaatika =informaatika  (SgG  >informaatika !01_S	et	f	\N
126419	plastikatehasse	?plastikatehasse =plastikateha  (SgIll  >plastikateha !16_S	et	f	\N
126420	plastikatehasse	?plastikatehasse =plastikatehas  (SgAdt  >plastikatehane !12_A	et	f	\N
126421	plastikatehasse	?plastikatehasse =plastikatehasse  (SgG  >plastikatehasne !02_A	et	f	\N
126422	plastikatehasse	?plastikatehasse =plastikatehasse  (PlP  >plastikatehass !22_S	et	f	\N
126423	plastikatehasse	?plastikatehasse =ateha  (SgIll  >plastik+ateha !01_S	et	f	\N
126424	plastikatehasse	?plastikatehasse =atehas  (SgAdt  >plastik+atehane !12_A	et	f	\N
126425	plastikatehasse	?plastikatehasse =atehasse  (SgG  >plastik+atehasne !02_A	et	f	\N
126426	plastikatehasse	?plastikatehasse =atehasse  (PlP  >plastik+atehass !22_S	et	f	\N
126427	plastikatehasse	?plastikatehasse =ikateha  (SgIll  >plast+ikateha !16_S	et	f	\N
126428	plastikatehasse	?plastikatehasse =ikatehas  (SgAdt  >plast+ikatehane !12_A	et	f	\N
126429	plastikatehasse	?plastikatehasse =ikatehasse  (SgG  >plast+ikatehasne !02_A	et	f	\N
126430	plastikatehasse	?plastikatehasse =ikatehasse  (PlP  >plast+ikatehass !22_S	et	f	\N
126450	mail	mail =ma  (PlAd  >maa !26_S	et	f	\N
126451	mail	mail =mai  (SgAd  >mai !26_S	et	f	\N
126452	rabav	rabav =raba  (PtsPrPs  >rabama !27_V	et	f	\N
126453	rabav	rabav =rabav  (SgN  >rabav !02_A	et	f	\N
126454	rabav	"rabav %raba  )V_vA  <rabama ;27_V	et	f	\N
126457	arvuks	arvuks =arvu  (SgTr  >arv !22_S	et	f	\N
126458	arvuks	arvuks =uks  (SgN  >arv+uks !14_S	et	f	\N
126463	värvimisest	värvimisest =värvimise  (SgEl  >värvimine !12_S	et	f	\N
126464	värvimisest	"värvimine %värvi  )MINE_vS  <värvima ;28_V	et	f	\N
126476	arvele	arvele =arve  (SgAll  >arve !06_S	et	f	\N
126477	arvele	arvele =arve  (PlAll  >arv !22_S	et	f	\N
126478	arvele	arvele =arvele  (ID  >arvele !41_K	et	f	\N
126500	türgi	?türgi =türgi  (ID  >türgi !41_D	et	f	\N
126501	türgi	?türgi =türgi  (SgG  >türk !22_S	et	f	\N
126502	türgi	?türgi =türgi  (SgP  >türg !22_S	et	f	\N
126503	türgi	?türgi =türgi  (SgAdt  >türg !22_S	et	f	\N
126504	türgi	?türgi =türgi  (IndPrPs_  >türkima !28_V	et	f	\N
126505	türgi	?türgi =türgi  (ImpPrSg2  >türkima !28_V	et	f	\N
126530	dal	### dal	et	f	\N
126531	tpüs	### tpüs	et	f	\N
126532	nüüdki	nüüdki =nüü  (PlN^  >nüü !26_S	et	f	\N
126533	nüüdki	nüüdki =nüü  (SgP^  >nüü !26_S	et	f	\N
126534	nüüdki	nüüdki =nüüd  (ID^  >nüüd !41_D	et	f	\N
126546	kiviõlis	kiviõlis =õli  (SgIn  >kivi+õli !17_S	et	f	\N
126548	kiviõlis	kiviõlis =õli  (PlIn  >kivi+õlg !22_S	et	f	\N
126551	raudtee	raudtee =tee  (SgN  >raud+tee !26_S	et	f	\N
126552	raudtee	raudtee =tee  (SgG  >raud+tee !26_S	et	f	\N
126567	rahvastepalli	rahvastepalli =palli  (SgG  >rahvaste+pall !22_S	et	f	\N
126569	rahvastepalli	rahvastepalli =palli  (SgP  >rahvaste+pall !22_S	et	f	\N
126571	rahvastepalli	rahvastepalli =palli  (SgAdt  >rahvaste+pall !22_S	et	f	\N
126577	nukudele	?nukudele =nuku  (PlAll  >nuku !16_S	et	f	\N
126587	hulga	hulga =hulga  (ID  >hulga !41_D	et	f	\N
126588	hulga	hulga =hulga  (SgG  >hulk !22_S	et	f	\N
126607	grafikusse	?grafikusse =grafiku  (SgIll  >grafiku !01_S	et	f	\N
126608	grafikusse	?grafikusse =grafiku  (SgIll  >grafik !02_S	et	f	\N
126609	grafikusse	?grafikusse =grafikus  (SgAdt  >grafikus !11_S	et	f	\N
126610	grafikusse	?grafikusse =grafikusse  (SgG  >grafikusne !02_A	et	f	\N
126611	grafikusse	?grafikusse =grafikusse  (PlP  >grafikuss !22_S	et	f	\N
126612	aeroobika	aeroobika =aeroobika  (SgN  >aeroobika !01_S	et	f	\N
126613	aeroobika	aeroobika =aeroobika  (SgG  >aeroobika !01_S	et	f	\N
126637	maalimine	maalimine =maalimine  (SgN  >maalimine !12_S	et	f	\N
126638	maalimine	"maalimine %maali  )MINE_vS  <maalima ;28_V	et	f	\N
126652	joonistamises	joonistamises =joonistamise  (SgIn  >joonistamine !12_S	et	f	\N
126653	joonistamises	"joonistamine %joonista  )MINE_vS  <joonistama ;27_V	et	f	\N
126654	kompositsioonis	kompositsioonis =kompositsiooni  (SgIn  >kompositsioon !22_S	et	f	\N
126655	kompositsioonis	kompositsioonis =positsiooni  (SgIn  >kom+positsioon !22_S	et	f	\N
126668	lohustada	?lohustada =lohusta  (Inf  >lohustama !27_V	et	f	\N
126669	lohustada	?lohustada =stada  (SgN  >lohu+stada !17_S	et	f	\N
126670	lohustada	?lohustada =stada  (SgG  >lohu+stada !17_S	et	f	\N
126671	lohustada	?lohustada =stada  (SgP  >lohu+stada !17_S	et	f	\N
126675	tehnikakõrgkoolis	tehnikakõrgkoolis =kooli  (SgIn  >tehnika+kõrg+kool !22_S	et	f	\N
126676	tehnikakõrgkoolis	tehnikakõrgkoolis =kooli  (PlIn  >tehnika+kõrg+kool !22_S	et	f	\N
126679	elukutse	elukutse =kutse  (SgN  >elu+kutse !06_S	et	f	\N
126680	elukutse	elukutse =kutse  (SgG  >elu+kutse !06_S	et	f	\N
126681	elukutse	elukutse =kutse  (PlP  >elu+kuts !22_S	et	f	\N
126708	planeerimise	planeerimise =planeerimise  (SgG  >planeerimine !12_S	et	f	\N
126709	planeerimise	"planeerimine %planeeri  )MINE_vS  <planeerima ;28_V	et	f	\N
126710	jäeb	?jäeb =jäeb  (SgN  >jäeb !22_S	et	f	\N
126718	majanduskooli	majanduskooli =kooli  (SgG  >majandus+kool !22_S	et	f	\N
126719	majanduskooli	majanduskooli =kooli  (SgP  >majandus+kool !22_S	et	f	\N
126720	majanduskooli	majanduskooli =kooli  (SgAdt  >majandus+kool !22_S	et	f	\N
126494	puudus	puudus =puudus  (SgN  >puudus !11~09_S	et	f	\N
126511	mainori	?mainori =mainori  (SgN  >mainori !01_S	et	f	\N
126512	mainori	?mainori =mainori  (SgG  >mainori !01_S	et	f	\N
126513	mainori	?mainori =mainori  (SgG  >mainor !02_S	et	f	\N
126514	mainori	?mainori =nori  (SgN  >mai+nori !17_S	et	f	\N
126516	mainori	?mainori =nori  (SgG  >mai+nori !17_S	et	f	\N
126518	mainori	?mainori =nori  (SgP  >mai+nori !17_S	et	f	\N
126535	sessiooni	sessiooni =sessiooni  (SgG  >sessioon !22_S	et	f	\N
126537	sessiooni	sessiooni =sessiooni  (SgP  >sessioon !22_S	et	f	\N
126539	sessiooni	sessiooni =sessiooni  (SgAdt  >sessioon !22_S	et	f	\N
126556	lõbusam	lõbusam =lõbusam  (SgN  >lõbusam !02_A	et	f	\N
126557	lõbusam	"lõbusam %lõbusa  )M_cA  <lõbus ;02_A	et	f	\N
126562	laulda	laulda =laul  (Inf  >laulma !33_V	et	f	\N
126563	laulda	laulda =laul  (IndPrIps_  >laulma !33_V	et	f	\N
126575	õmmelda	õmmelda =õmmel  (Inf  >õmblema !30_V	et	f	\N
126576	õmmelda	õmmelda =õmmel  (IndPrIps_  >õmblema !30_V	et	f	\N
126580	joonistamine	joonistamine =joonistamine  (SgN  >joonistamine !12_S	et	f	\N
126581	joonistamine	"joonistamine %joonista  )MINE_vS  <joonistama ;27_V	et	f	\N
126584	näitustest	näitustest =näitus  (PlEl  >näitus !11~09_S	et	f	\N
126585	näitustest	näitustest =test  (SgN  >näitus+test !22_S	et	f	\N
126586	näitustest	näitustest =us  (PlEl  >näit+uks !14_S	et	f	\N
126589	tulevasest	tulevasest =tulevase  (SgEl  >tulevane !12_AS	et	f	\N
126590	tulevasest	tulevasest =vase  (SgEl  >tule+vask !22_S	et	f	\N
126592	tulevasest	tulevasest =vases  (SgP  >tule+vasene !10_A	et	f	\N
126594	tulevasest	"tule+vasene %vase  )NE_aA  <tule+vask ;22_S	et	f	\N
126597	akademiasse	?akademiasse =akademia  (SgIll  >akademia !01_S	et	f	\N
126598	akademiasse	?akademiasse =akademias  (SgAdt  >akademias !11_S	et	f	\N
126599	akademiasse	?akademiasse =akademiasse  (SgG  >akademiasne !02_A	et	f	\N
126600	akademiasse	?akademiasse =akademiasse  (PlP  >akademiass !22_S	et	f	\N
126601	kaheteistkümnendas	?kaheteistkümnendas =kaheteistkümnenda  (SgIn  >kaheteistkümnenda !16_S	et	f	\N
126602	kaheteistkümnendas	?kaheteistkümnendas =kaheteistkümnenda  (IndIpfSg3  >kaheteistkümnendama !27_V	et	f	\N
126603	kaheteistkümnendas	?kaheteistkümnendas =kümnenda  (SgIn  >kahe+teist+kümnenda !01_S	et	f	\N
126604	kaheteistkümnendas	?kaheteistkümnendas =teistkümnenda  (SgIn  >kahe+teistkümnenda !16_S	et	f	\N
126621	närvipingeline	närvipingeline =pingeline  (SgN  >närvi+pingeline !12_A	et	f	\N
126622	närvipingeline	"närvi+pingeline %pinge  )LINE_aA  <närvi+pinge ;06_S	et	f	\N
126656	tegemisel	tegemisel =tegemise  (SgAd  >tegemine !12_S	et	f	\N
126657	tegemisel	"tegemine %tege  )MINE_vS  <tegema ;28_V	et	f	\N
126689	küllaldki	?küllaldki =küllaldki  (SgG  >küllaldk !22_S	et	f	\N
126690	küllaldki	?küllaldki =küllaldki  (SgP  >küllaldk !22_S	et	f	\N
126691	küllaldki	?küllaldki =küllaldki  (SgAdt  >küllaldk !22_S	et	f	\N
126692	küllaldki	?küllaldki =küllaldki  (IndPrPs_  >küllaldkima !28_V	et	f	\N
126693	küllaldki	?küllaldki =küllaldki  (ImpPrSg2  >küllaldkima !28_V	et	f	\N
126694	küllaldki	?küllaldki =küllald  (SgN^  >küllald !02_S	et	f	\N
126697	peagi	peagi =peagi  (ID  >peagi !41_D	et	f	\N
126699	peagi	peagi =pea  (IndPrPs_^  >pida !40_V	et	f	\N
126700	peagi	peagi =pea  (ID^  >pea !41_D	et	f	\N
126701	peagi	peagi =pea  (SgN^  >pea !26_S	et	f	\N
126702	peagi	peagi =pea  (SgG^  >pea !26_S	et	f	\N
126703	peagi	peagi =pea  (IndPrPs_^  >pidama !28_V	et	f	\N
126704	peagi	peagi =pea  (ImpPrSg2^  >pidama !28_V	et	f	\N
126705	mitmesse	mitmesse =mitme  (SgIll  >mitu !05_P	et	f	\N
126706	mitmesse	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
126707	mitmesse	mitmesse =mitmes  (SgAdt  >mitmene !12_A	et	f	\N
126714	kasvatajana	kasvatajana =kasvataja  (SgEs  >kasvataja !01_S	et	f	\N
126715	kasvatajana	"kasvataja %kasvata  )JA_vS  <kasvatama ;27_V	et	f	\N
126732	bakalaurest	?bakalaurest =bakalaure  (PlEl  >bakalaur !19_S	et	f	\N
126733	bakalaurest	?bakalaurest =bakalaures  (SgP  >bakalaurene !12_A	et	f	\N
126741	aastasest	aastasest =aastase  (SgEl  >aastane !12~10_A	et	f	\N
126742	aastasest	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
126807	insenerid-geodesistid	?insenerid-geodesistid =geodesisti  (PlN  >insenerid-geodesist !22_S	et	f	\N
126808	insenerid-geodesistid	?insenerid-geodesistid =geodesisti  (IndPrSg2  >insenerid-geodesistima !28_V	et	f	\N
126809	insenerid-geodesistid	?insenerid-geodesistid =desisti  (PlN  >insenerid-geo+desisti !01_S	et	f	\N
126810	insenerid-geodesistid	?insenerid-geodesistid =desisti  (PlN  >insenerid-geo+desist !22_S	et	f	\N
126813	spetsialiseerimisega	spetsialiseerimisega =spetsialiseerimise  (SgKom  >spetsialiseerimine !12_S	et	f	\N
126814	spetsialiseerimisega	"spetsialiseerimine %spetsialiseeri  )MINE_vS  <spetsialiseerima ;28_V	et	f	\N
126815	romanistika	romanistika =romanistika  (SgN  >romanistika !01_S	et	f	\N
126816	romanistika	romanistika =romanistika  (SgG  >romanistika !01_S	et	f	\N
126825	diplomitööd	diplomitööd =töö  (PlN  >diplomi+töö !26_S	et	f	\N
126826	diplomitööd	diplomitööd =töö  (SgP  >diplomi+töö !26_S	et	f	\N
126827	bakalauruse	?bakalauruse =bakalauruse  (SgG  >bakalaurus !11~09_S	et	f	\N
126853	kodanikuks	kodanikuks =kodaniku  (SgTr  >kodanik !25_S	et	f	\N
126854	kodanikuks	kodanikuks =uks  (SgN  >kodanik+uks !14_S	et	f	\N
126506	puhkust	puhkust =puhkus  (SgP  >puhkus !11~09_S	et	f	\N
126508	puhkust	puhkust =us  (SgP  >puhk+uks !14_S	et	f	\N
126515	kõrgkooli	kõrgkooli =kooli  (SgG  >kõrg+kool !22_S	et	f	\N
126517	kõrgkooli	kõrgkooli =kooli  (SgP  >kõrg+kool !22_S	et	f	\N
126519	kõrgkooli	kõrgkooli =kooli  (SgAdt  >kõrg+kool !22_S	et	f	\N
126520	kõrgkooli	kõrgkooli =kooli  (PlP  >kõrg+kool !22_S	et	f	\N
126564	kiigel	kiigel =kiige  (SgAd  >kiik !22_S	et	f	\N
126565	kiigel	kiigel =kiige  (PlAd  >kiik !22_S	et	f	\N
126566	hüpata	hüpata =hüpa  (Inf  >hüppama !29_V	et	f	\N
126568	hüpata	hüpata =hüpa  (IndPrIps_  >hüppama !29_V	et	f	\N
126570	hüpata	hüpata =hüpata  (IndPrPs_  >hüpatama !27_V	et	f	\N
126572	hüpata	hüpata =hüpata  (ImpPrSg2  >hüpatama !27_V	et	f	\N
126582	üritustes	üritustes =üritus  (PlIn  >üritus !11_S	et	f	\N
126583	üritustes	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
126614	kannatus	kannatus =kannatu  (SgIn  >kannatu !01_AS	et	f	\N
126615	kannatus	"kannatu %kanna  )TU2_kA  <kanna ;16_S	et	f	\N
126616	kannatus	"kannatu %kanna  )TU2_kA  <kand ;22_S	et	f	\N
126617	kannatus	kannatus =kannatus  (SgN  >kannatus !11_S	et	f	\N
126618	kannatus	"kannatus %kannata  )US_vS  <kannatama ;27_V	et	f	\N
126619	kannatus	"kannatus %kanna  )TUS2_aS  <kanna ;16_S	et	f	\N
126620	kannatus	"kannatus %kanna  )TUS2_aS  <kand ;22_S	et	f	\N
126625	kergelt	kergelt =kerge  (SgAbl  >kerge !01_A	et	f	\N
126626	kergelt	kergelt =kergelt  (ID  >kergelt !41_D	et	f	\N
126627	kergelt	"kergelt %kerge  )LT_mD  <kerge ;01_A	et	f	\N
126639	joonestamine	joonestamine =joonestamine  (SgN  >joonestamine !12_S	et	f	\N
126640	joonestamine	"joonestamine %joonesta  )MINE_vS  <joonestama ;27_V	et	f	\N
126649	sisseastumiskonkurs	?sisseastumiskonkurs =sisseastumiskonkurs  (SgN  >sisseastumiskonkurs !22_S	et	f	\N
126650	sisseastumiskonkurs	?sisseastumiskonkurs =konkurs  (SgN  >sisse+astumis+konkurs !02_S	et	f	\N
126651	sisseastumiskonkurs	?sisseastumiskonkurs =astumiskonkurs  (SgN  >sisse+astumiskonkurs !22_S	et	f	\N
126658	minimaalselt	minimaalselt =minimaalse  (SgAbl  >minimaalne !02_A	et	f	\N
126659	minimaalselt	minimaalselt =minimaalselt  (ID  >minimaalselt !41_D	et	f	\N
126660	minimaalselt	"minimaalselt %minimaalse  )LT_mD  <minimaalne ;02_A	et	f	\N
126661	pingereast	pingereast =ast  (SgN  >ping+ere+ast !22_S	et	f	\N
126662	pingereast	pingereast =rea  (SgEl  >pinge+rida !18_S	et	f	\N
126672	polütehnikumisse	polütehnikumisse =polütehnikumi  (SgIll  >polütehnikum !19_S	et	f	\N
126673	polütehnikumisse	polütehnikumisse =polütehnikumis  (SgAdt  >polütehnikumine !12_S	et	f	\N
126674	polütehnikumisse	"polütehnikumine %polütehnikumi  )NE_aA  <polütehnikum ;19_S	et	f	\N
126682	kaaludes	kaaludes =kaalu  (PlIn  >kaal !22_S	et	f	\N
126683	kaaludes	kaaludes =kaalu  (Ger  >kaaluma !28_V	et	f	\N
126734	lõpeta	lõpeta =lõpe  (IndPrIps_  >lõppema !28_V	et	f	\N
126735	lõpeta	lõpeta =lõpe  (IndPrIps_  >lõpma !35_V	et	f	\N
126736	lõpeta	lõpeta =lõpeta  (IndPrPs_  >lõpetama !27_V	et	f	\N
126737	lõpeta	lõpeta =lõpeta  (ImpPrSg2  >lõpetama !27_V	et	f	\N
126744	kunstiringe	kunstiringe =ringe  (SgN  >kunsti+ringe !06_S	et	f	\N
126746	kunstiringe	kunstiringe =ringe  (SgG  >kunsti+ringe !06_S	et	f	\N
126747	kunstiringe	kunstiringe =ringe  (PlP  >kunsti+ring !22_S	et	f	\N
126748	õmblemine	õmblemine =õmblemine  (SgN  >õmblemine !12_S	et	f	\N
126749	õmblemine	"õmblemine %õmble  )MINE_vS  <õmblema ;30_V	et	f	\N
126751	tänaseni	tänaseni =tänase  (SgTer  >tänane !10_A	et	f	\N
126752	tänaseni	tänaseni =tänaseni  (ID  >tänaseni !41_D	et	f	\N
126753	kaisukaru	?kaisukaru =kaisukaru  (IndPrPs_  >kaisukaruma !27_V	et	f	\N
126754	kaisukaru	?kaisukaru =kaisukaru  (ImpPrSg2  >kaisukaruma !27_V	et	f	\N
126755	kaisukaru	?kaisukaru =sukaru  (SgN  >kai+sukaru !01_S	et	f	\N
126756	kaisukaru	?kaisukaru =sukaru  (SgG  >kai+sukaru !01_S	et	f	\N
126778	avanesid	avanesid =avane  (IndIpfSg2  >avanema !27_V	et	f	\N
126779	avanesid	avanesid =avane  (IndIpfPl3  >avanema !27_V	et	f	\N
126791	kaheksakümne	?kaheksakümne =kaheksakümne  (SgN  >kaheksakümne !02_A	et	f	\N
126792	kaheksakümne	?kaheksakümne =kaheksakümne  (PlP  >kaheksakümn !22_S	et	f	\N
126793	kaheksakümne	?kaheksakümne =kümne  (SgN  >kaheksa+kümne !02_A	et	f	\N
126796	kaheksakümne	?kaheksakümne =kümne  (PlP  >kaheksa+kümn !22_S	et	f	\N
126798	kaheksakümne	?kaheksakümne =ksakümne  (SgN  >kahe+ksakümne !02_A	et	f	\N
126800	kaheksakümne	?kaheksakümne =ksakümne  (PlP  >kahe+ksakümn !22_S	et	f	\N
126828	astmet	?astmet =astme  (SgP  >astme !06_S	et	f	\N
126829	kallim	kallim =kallim  (SgN  >kallim !02_AS	et	f	\N
126830	kallim	"kallim %kalli  )M_cA  <kallis ;05_A	et	f	\N
126831	kallim	"kallim %kalli  )M_cA  <kallis ;07_A	et	f	\N
126838	ostmine	ostmine =ostmine  (SgN  >ostmine !12?10_S	et	f	\N
126839	ostmine	"ostmine %ost  )MINE_vS  <ostma ;34_V	et	f	\N
126858	täitmisega	täitmisega =täitmise  (SgKom  >täitmine !12?10_S	et	f	\N
126860	täitmisega	"täitmine %täit  )MINE_vS  <täitma ;34_V	et	f	\N
126866	hümnaasiumis	?hümnaasiumis =hümnaasiumi  (SgIn  >hümnaasium !19~02_S	et	f	\N
126867	hümnaasiumis	?hümnaasiumis =hümnaasiumi  (SgIn  >hümnaasiumi !16_S	et	f	\N
126868	hümnaasiumis	?hümnaasiumis =hümnaasiumi  (IndIpfSg3  >hümnaasiumima !28_V	et	f	\N
126529	tpüsse	?tpüsse =tpüsse  (ImpPrSg2  >tpüssema !27_V	et	f	\N
126573	hüpenööriga	?hüpenööriga =hüpenööri  (SgKom  >hüpenööri !16_S	et	f	\N
126574	hüpenööriga	?hüpenööriga =hüpenööri  (SgKom  >hüpenöör !22_S	et	f	\N
126578	klassijuhataja	klassijuhataja =juhataja  (SgN  >klassi+juhataja !01_S	et	f	\N
126579	klassijuhataja	klassijuhataja =juhataja  (SgG  >klassi+juhataja !01_S	et	f	\N
126605	sellisesse	sellisesse =sellise  (SgIll  >selline !10_P	et	f	\N
126606	sellisesse	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
126623	kõigiga	kõigiga =kõigi  (PlKom  >kõik !00_P	et	f	\N
126624	kõigiga	kõigiga =kõigi  (SgKom  >kõik !22_S	et	f	\N
126629	koosnesid	koosnesid =koosne  (IndIpfSg2  >koosnema !27_V	et	f	\N
126630	koosnesid	koosnesid =koosne  (IndIpfPl3  >koosnema !27_V	et	f	\N
126635	esitlemine	esitlemine =esitlemine  (SgN  >esitlemine !12_S	et	f	\N
126636	esitlemine	"esitlemine %esitle  )MINE_vS  <esitlema ;27_V	et	f	\N
126644	koostamine	koostamine =koostamine  (SgN  >koostamine !12_S	et	f	\N
126645	koostamine	"koostamine %koosta  )MINE_vS  <koostama ;27_V	et	f	\N
126663	häbi	häbi =häbi  (SgN  >häbi !17_S	et	f	\N
126664	häbi	häbi =häbi  (SgG  >häbi !17_S	et	f	\N
126665	häbi	häbi =häbi  (SgP  >häbi !17_S	et	f	\N
126666	suudsid	?suudsid =suudsi  (PlN  >suuds !22_S	et	f	\N
126667	suudsid	?suudsid =suudsi  (IndPrSg2  >suudsima !28_V	et	f	\N
126684	kokkuvõtte	kokkuvõtte =võtte  (SgG  >kokku+võte !06_S	et	f	\N
126685	kokkuvõtte	kokkuvõtte =võtte  (PlP  >kokku+võtt !22_S	et	f	\N
126686	veadel	?veadel =vea  (PlAd  >vea !26_S	et	f	\N
126687	veadel	?veadel =veade  (PlAd  >veat !22_S	et	f	\N
126688	veadel	?veadel =veadel  (SgN  >veadel !02_S	et	f	\N
126695	ruttu	ruttu =ruttu  (ID  >ruttu !41_D	et	f	\N
126696	ruttu	ruttu =ruttu  (SgP  >rutt !22_S	et	f	\N
126698	ruttu	ruttu =ruttu  (SgAdt  >rutt !22_S	et	f	\N
126724	salajasim	salajasim =salajasim  (SgN  >salajasim !02_A	et	f	\N
126725	salajasim	"salajasim %salajasi  )IM_sA  <salajane ;12_A	et	f	\N
126750	õmblemiskursustel	?õmblemiskursustel =õmblemiskursus  (PlAd  >õmblemiskursus !11~09_S	et	f	\N
126759	unistusin	?unistusin =unistu  (IndIpfSg1  >unistuma !27_V	et	f	\N
126760	unistusin	?unistusin =unistusin  (SgN  >unistusin !19_S	et	f	\N
126761	unistusin	?unistusin =stusin  (SgN  >uni+stusin !02_S	et	f	\N
126762	ammune	ammune =ammune  (SgN  >ammune !10_A	et	f	\N
126763	ammune	"ammune %ammu  )NE_aA  <amb ;22_S	et	f	\N
126811	vanavanemad	vanavanemad =vanema  (PlN  >vana+vanem !02_AS	et	f	\N
126812	vanavanemad	"vana+vanem %vane  )M_cA  <vana+vana ;17_AS	et	f	\N
126834	kolmandaks	kolmandaks =kolmanda  (SgTr  >kolmas !02_O	et	f	\N
126835	kolmandaks	kolmandaks =kolmandaks  (ID  >kolmandaks !41_D	et	f	\N
126840	kadumist	kadumist =kadumi  (SgEl  >kadum !02_S	et	f	\N
126841	kadumist	kadumist =kadumis  (SgP  >kadumine !12_S	et	f	\N
126842	kadumist	"kadumine %kadu  )MINE_vS  <kaduma ;28_V	et	f	\N
126843	kadumist	"kadumine %kadumi  )NE_aA  <kadum ;02_S	et	f	\N
126844	astumine	astumine =astumine  (SgN  >astumine !12_S	et	f	\N
126845	astumine	"astumine %astu  )MINE_vS  <astuma ;28_V	et	f	\N
126849	saamine	saamine =saamine  (SgN  >saamine !12?10_S	et	f	\N
126851	saamine	"saamine %saa  )MINE_vS  <saama ;37_V	et	f	\N
126852	saamine	"saamine %saami  )NE_aA  <saam ;22_S	et	f	\N
126884	ks	### ks	et	f	\N
126893	lõpitamine	?lõpitamine =lõpitamine  (SgN  >lõpitamine !12_S	et	f	\N
126894	lõpitamine	?lõpitamine =lõpitamine  (PlP  >lõpitamin !19_S	et	f	\N
126920	õpetajana	õpetajana =õpetaja  (SgEs  >õpetaja !01_S	et	f	\N
126921	õpetajana	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
126929	lugevad	lugevad =lugeva  (PlN  >lugev !02_A	et	f	\N
126930	lugevad	"lugev %luge  )V_vA  <lugema ;28_V	et	f	\N
126937	söögi	söögi =söögi  (SgG  >söök !22_S	et	f	\N
126938	söögi	söögi =söö  (IndPrPs_^  >sööma !38_V	et	f	\N
126939	söögi	söögi =söö  (ImpPrSg2^  >sööma !38_V	et	f	\N
126940	hobi	hobi =hobi  (SgN  >hobi !17_S	et	f	\N
126941	hobi	hobi =hobi  (SgG  >hobi !17_S	et	f	\N
126942	hobi	hobi =hobi  (SgP  >hobi !17_S	et	f	\N
126966	muusikakool	muusikakool =koo  (SgAd  >muusika+kubu !18_S	et	f	\N
126967	muusikakool	muusikakool =kool  (SgN  >muusika+kool !22_S	et	f	\N
126996	passi	passi =passi  (SgG  >pass !22_S	et	f	\N
126998	passi	passi =passi  (SgP  >pass !22_S	et	f	\N
126999	passi	passi =passi  (SgAdt  >pass !22_S	et	f	\N
127000	passi	passi =passi  (IndPrPs_  >passima !28_V	et	f	\N
127001	passi	passi =passi  (ImpPrSg2  >passima !28_V	et	f	\N
127023	korralikult	korralikult =korraliku  (SgAbl  >korralik !25_A	et	f	\N
127024	korralikult	korralikult =korralikult  (ID  >korralikult !41_D	et	f	\N
127025	korralikult	"korralikult %korraliku  )LT_mD  <korralik ;25_A	et	f	\N
127044	tükkaega	tükkaega =aega  (SgP  >tükk+aeg !22_S	et	f	\N
127045	tükkaega	tükkaega =aega  (SgAdt  >tükk+aeg !22_S	et	f	\N
127051	elam	?elam =elam  (SgN  >elam !02_A	et	f	\N
127068	harrastuste	harrastuste =harrastus  (PlG  >harrastus !11_S	et	f	\N
127069	harrastuste	"harrastus %harrasta  )US_vS  <harrastama ;27_V	et	f	\N
127093	õue	õue =õue  (ID  >õue !41_D	et	f	\N
126721	majanduskooli	majanduskooli =kooli  (PlP  >majandus+kool !22_S	et	f	\N
126722	kõrvalainega	kõrvalainega =aine  (SgKom  >kõrval+aine !06_S	et	f	\N
126723	kõrvalainega	kõrvalainega =laine  (SgKom  >kõrva+laine !06_S	et	f	\N
126739	kuue	kuue =kuue  (SgG  >kuus !14_N	et	f	\N
126740	kuue	kuue =kuue  (SgG  >kuub !22_S	et	f	\N
126764	ühiskeele	ühiskeele =kee  (SgAll  >ühis+kesi !15_S	et	f	\N
126765	ühiskeele	ühiskeele =kee  (SgAll  >ühis+kee !26_S	et	f	\N
126766	ühiskeele	ühiskeele =keele  (SgG  >ühis+keel !13_S	et	f	\N
126781	eredam	eredam =eredam  (SgN  >eredam !02_A	et	f	\N
126782	eredam	"eredam %ereda  )M_cA  <ere ;02_A	et	f	\N
126785	vaevaline	vaevaline =vaevaline  (SgN  >vaevaline !12_A	et	f	\N
126786	vaevaline	"vaevaline %vaeva  )LINE_aA  <vaev ;22_S	et	f	\N
126832	kukkumine	kukkumine =kukkumine  (SgN  >kukkumine !12_S	et	f	\N
126833	kukkumine	"kukkumine %kukku  )MINE_vS  <kukkuma ;28_V	et	f	\N
126846	kodakontsuse	?kodakontsuse =kodakontsuse  (SgG  >kodakontsus !11~09_S	et	f	\N
126847	kodakontsuse	?kodakontsuse =suse  (SgN  >koda+kont+suse !16_S	et	f	\N
126848	kodakontsuse	?kodakontsuse =suse  (SgG  >koda+kont+suse !16_S	et	f	\N
126850	kodakontsuse	?kodakontsuse =kontsuse  (SgG  >koda+kontsus !11~09_S	et	f	\N
126855	taotlusanketti	?taotlusanketti =taotlusanketti  (SgP  >taotlusankett !22_S	et	f	\N
126856	taotlusanketti	?taotlusanketti =taotlusanketti  (SgAdt  >taotlusankett !22_S	et	f	\N
126857	taotlusanketti	?taotlusanketti =anketti  (SgN  >taotlus+anketti !01_S	et	f	\N
126859	taotlusanketti	?taotlusanketti =anketti  (SgG  >taotlus+anketti !01_S	et	f	\N
126861	taotlusanketti	?taotlusanketti =anketti  (SgP  >taotlus+ankett !22_S	et	f	\N
126862	taotlusanketti	?taotlusanketti =anketti  (SgAdt  >taotlus+ankett !22_S	et	f	\N
126870	loengutel	loengutel =loengu  (PlAd  >loeng !02_S	et	f	\N
126871	loengutel	loengutel =ute  (SgAd  >loeng+utt !22_S	et	f	\N
126872	loengutel	loengutel =ute  (PlAd  >loeng+utt !22_S	et	f	\N
126873	studiasse	?studiasse =studia  (SgIll  >studia !01_S	et	f	\N
126874	studiasse	?studiasse =studias  (SgAdt  >studias !11_S	et	f	\N
126875	studiasse	?studiasse =studiasse  (SgG  >studiasne !02_A	et	f	\N
126876	studiasse	?studiasse =studiasse  (PlP  >studiass !22_S	et	f	\N
126981	tapmine	tapmine =tapmine  (SgN  >tapmine !12?10_S	et	f	\N
126982	tapmine	"tapmine %tap  )MINE_vS  <tapma ;35_V	et	f	\N
126983	mure	mure =mure  (SgN  >mure !02_A	et	f	\N
126984	mure	mure =mure  (SgN  >mure !16_S	et	f	\N
126985	mure	mure =mure  (SgG  >mure !16_S	et	f	\N
127026	6-aastane	-aastane =aastane  (SgN  >-aastane !12~10_A	et	f	\N
127027	6-aastane	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
127070	naiskonnas	naiskonnas =naiskonna  (SgIn  >naiskond !22_S	et	f	\N
127071	naiskonnas	naiskonnas =konna  (SgIn  >nais+konn !22_S	et	f	\N
127085	hullem	hullem =hullem  (SgN  >hullem !02_A	et	f	\N
127086	hullem	"hullem %hulle  )M_cA  <hull ;22_AS	et	f	\N
127089	tolles	tolles =tolle  (SgIn  >too !00_P	et	f	\N
127090	tolles	tolles =tolle  (PlIn  >toll !22_S	et	f	\N
127091	kuueaastane	kuueaastane =aastane  (SgN  >kuue+aastane !12~10_A	et	f	\N
127092	kuueaastane	"kuue+aastane %aasta  )NE_aA  <kuue+aasta ;01_S	et	f	\N
127100	valus	valus =valu  (SgIn  >valu !17_S	et	f	\N
127101	valus	valus =valu  (IndIpfSg3  >valuma !27_V	et	f	\N
127102	valus	valus =valus  (SgN  >valus !02_A	et	f	\N
127111	südamet	### südamet	et	f	\N
127118	korraga	korraga =korra  (SgKom  >kord !22_S	et	f	\N
127119	korraga	korraga =korraga  (ID  >korraga !41_D	et	f	\N
127132	meenukam	?meenukam =meenukam  (SgN  >meenukam !02_A	et	f	\N
127133	meenukam	?meenukam =nukam  (SgN  >mee+nukam !02_A	et	f	\N
127137	õnnelikuima	?õnnelikuima =õnnelikuima  (SgG  >õnnelikuim !02_A	et	f	\N
127147	väikse	väikse =väikse  (SgG  >väike !10_A	et	f	\N
127148	väikse	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
127154	huvitavate	huvitavate =huvitava  (PlG  >huvitav !02_A	et	f	\N
127155	huvitavate	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
127169	ebamugavalt	ebamugavalt =mugava  (SgAbl  >eba+mugav !02_A	et	f	\N
127170	ebamugavalt	ebamugavalt =mugavalt  (ID  >eba+mugavalt !41_D	et	f	\N
127171	ebamugavalt	"eba+mugavalt %mugava  )LT_mD  <eba+mugav ;02_A	et	f	\N
127201	teaduskonna	teaduskonna =teaduskonna  (SgG  >teaduskond !22_S	et	f	\N
127202	teaduskonna	teaduskonna =konna  (SgG  >teadus+konn !22_S	et	f	\N
127203	teaduskonna	teaduskonna =konna  (SgP  >teadus+konn !22_S	et	f	\N
127204	teaduskonna	teaduskonna =konna  (SgAdt  >teadus+konn !22_S	et	f	\N
127205	optimistlikult	optimistlikult =optimistliku  (SgAbl  >optimistlik !25_A	et	f	\N
127206	optimistlikult	optimistlikult =optimistlikult  (ID  >optimistlikult !41_D	et	f	\N
127207	optimistlikult	"optimistlikult %optimistliku  )LT_mD  <optimistlik ;25_A	et	f	\N
127212	tuluusi	?tuluusi =tuluusi  (SgN  >tuluusi !16_S	et	f	\N
127213	tuluusi	?tuluusi =tuluusi  (SgG  >tuluusi !16_S	et	f	\N
127214	tuluusi	?tuluusi =tuluusi  (SgG  >tuluus !22_S	et	f	\N
127215	tuluusi	?tuluusi =tuluusi  (SgP  >tuluus !22_S	et	f	\N
127216	tuluusi	?tuluusi =tuluusi  (SgAdt  >tuluus !22_S	et	f	\N
127217	tuluusi	?tuluusi =tuluusi  (IndPrPs_  >tuluusima !28_V	et	f	\N
127218	tuluusi	?tuluusi =tuluusi  (ImpPrSg2  >tuluusima !28_V	et	f	\N
126728	paralleelselt	"paralleelselt %paralleelse  )LT_mD  <paralleelne ;02_A	et	f	\N
126729	kudumisega	kudumisega =kudumise  (SgKom  >kudumine !12_S	et	f	\N
126730	kudumisega	"kudumine %kudu  )MINE_vS  <kuduma ;28_V	et	f	\N
126731	kudumisega	"kudumine %kudumi  )NE_aA  <kudum ;02_S	et	f	\N
126738	humanitaar	?humanitaar =humanitaar  (SgN  >humanitaar !22_S	et	f	\N
126743	kaasaegsedtansud	?kaasaegsedtansud =kaasaegsedtansu  (IndPrSg2  >kaasaegsedtansuma !27_V	et	f	\N
126745	kaasaegsedtansud	?kaasaegsedtansud =sedtansu  (PlN  >kaas+aeg+sedtansu !01_S	et	f	\N
126757	põhikoolis	põhikoolis =kooli  (SgIn  >põhi+kool !22_S	et	f	\N
126758	põhikoolis	põhikoolis =kooli  (PlIn  >põhi+kool !22_S	et	f	\N
126767	lõpetamine	lõpetamine =lõpetamine  (SgN  >lõpetamine !12_S	et	f	\N
126768	lõpetamine	"lõpetamine %lõpeta  )MINE_vS  <lõpetama ;27_V	et	f	\N
126769	läbimine	läbimine =läbimine  (SgN  >läbimine !12_S	et	f	\N
126770	läbimine	"läbimine %läbi  )MINE_vS  <läbima ;27_V	et	f	\N
126771	läbimine	"läbimine %läbimi  )NE_aA  <läbim ;02_S	et	f	\N
126772	järgnevale	järgnevale =järgneva  (SgAll  >järgnev !02_A	et	f	\N
126773	järgnevale	"järgnev %järgne  )V_vA  <järgnema ;27_V	et	f	\N
126774	positiivsem	positiivsem =positiivsem  (SgN  >positiivsem !02_A	et	f	\N
126775	positiivsem	"positiivsem %positiivse  )M_cA  <positiivne ;02_A	et	f	\N
126776	sissesaamine	sissesaamine =saamine  (SgN  >sisse+saamine !12?10_S	et	f	\N
126777	sissesaamine	"sisse+saamine %saami  )NE_aA  <sisse+saam ;22_S	et	f	\N
126780	horisontid	### horisontid	et	f	\N
126783	taastumine	taastumine =taastumine  (SgN  >taastumine !12_S	et	f	\N
126784	taastumine	"taastumine %taastu  )MINE_vS  <taastuma ;27_V	et	f	\N
126787	kakskümend	?kakskümend =kakskümend  (SgN  >kakskümend !22_S	et	f	\N
126788	kakskümend	?kakskümend =kümend  (SgN  >kaks+kümend !02_S	et	f	\N
126789	üheksasaja	?üheksasaja =üheksasaja  (SgN  >üheksasaja !01_S	et	f	\N
126790	üheksasaja	?üheksasaja =üheksasaja  (SgG  >üheksasaja !01_S	et	f	\N
126794	üheksasaja	?üheksasaja =üheksasaja  (SgG  >üheksasajas !02_A	et	f	\N
126795	üheksasaja	?üheksasaja =saja  (SgN  >üheksa+saja !17_S	et	f	\N
126797	üheksasaja	?üheksasaja =saja  (SgG  >üheksa+saja !17_S	et	f	\N
126799	üheksasaja	?üheksasaja =saja  (SgP  >üheksa+saja !17_S	et	f	\N
126801	üheksasaja	?üheksasaja =asaja  (SgN  >üheks+asaja !01_S	et	f	\N
126802	üheksasaja	?üheksasaja =asaja  (SgG  >üheks+asaja !01_S	et	f	\N
126803	üheksasaja	?üheksasaja =asaja  (SgG  >üheks+asajas !02_A	et	f	\N
126804	üheksasaja	?üheksasaja =ksasaja  (SgN  >ühe+ksasaja !01_S	et	f	\N
126805	üheksasaja	?üheksasaja =ksasaja  (SgG  >ühe+ksasaja !01_S	et	f	\N
126806	üheksasaja	?üheksasaja =ksasaja  (SgG  >ühe+ksasajas !02_A	et	f	\N
126817	otsustanud	otsustanud =otsusta  (PtsPtPs  >otsustama !27_V	et	f	\N
126818	otsustanud	otsustanud =otsustanu  (PlN  >otsustanu !01_S	et	f	\N
126819	otsustanud	"otsustanu %otsusta  )NU_vS  <otsustama ;27_V	et	f	\N
126820	otsustanud	otsustanud =otsustanud  (ID  >otsustanud !41_A	et	f	\N
126821	otsustanud	"otsustanud %otsusta  )NUD_vA  <otsustama ;27_V	et	f	\N
126822	lisaeriala	lisaeriala =ala  (SgN  >lisa+eri+ala !17_S	et	f	\N
126823	lisaeriala	lisaeriala =ala  (SgG  >lisa+eri+ala !17_S	et	f	\N
126824	lisaeriala	lisaeriala =ala  (SgP  >lisa+eri+ala !17_S	et	f	\N
126836	pikkaks	?pikkaks =pikka  (KndPrPs  >pikkama !29_V	et	f	\N
126837	pikkaks	?pikkaks =aks  (SgN  >pikk+aks !22_S	et	f	\N
126863	näitlijaks	?näitlijaks =näitlija  (SgTr  >näitlija !01_S	et	f	\N
126864	näitlijaks	?näitlijaks =näitlija  (SgTr  >näitlijas !02_A	et	f	\N
126865	näitlijaks	?näitlijaks =lija  (SgTr  >näit+lija !17_S	et	f	\N
126877	suhtumine	suhtumine =suhtumine  (SgN  >suhtumine !12_S	et	f	\N
126878	suhtumine	"suhtumine %suhtu  )MINE_vS  <suhtuma ;27_V	et	f	\N
126879	aastusin	?aastusin =aastu  (IndIpfSg1  >aastuma !27_V	et	f	\N
126880	aastusin	?aastusin =aastusin  (SgN  >aastusin !19_S	et	f	\N
126881	aastusin	?aastusin =tusin  (SgN  >aas+tusin !02_S	et	f	\N
126885	stuudiasse	?stuudiasse =stuudia  (SgIll  >stuudia !01_S	et	f	\N
126886	stuudiasse	?stuudiasse =stuudias  (SgAdt  >stuudias !11_S	et	f	\N
126887	stuudiasse	?stuudiasse =stuudiasse  (SgG  >stuudiasne !02_A	et	f	\N
126888	stuudiasse	?stuudiasse =stuudiasse  (PlP  >stuudiass !22_S	et	f	\N
126922	poisid	poisid =poi  (PlP  >poi !26_S	et	f	\N
126923	poisid	poisid =poisi  (PlN  >poiss !23?22_S	et	f	\N
126924	vaga	vaga =vaga  (SgN  >vaga !17_A	et	f	\N
126927	vaga	vaga =vaga  (SgG  >vaga !17_A	et	f	\N
126928	vaga	vaga =vaga  (SgP  >vaga !17_A	et	f	\N
126931	mahtra	mahtra =mahtra  (SgN  >mahtra !01_S	et	f	\N
126932	mahtra	mahtra =mahtra  (SgG  >mahtra !01_S	et	f	\N
126933	üheksas	üheksas =üheksa  (SgIn  >üheksa !01_N	et	f	\N
126934	üheksas	üheksas =üheksas  (SgN  >üheksas !02_O	et	f	\N
126978	poola	?poola =poola  (ID  >poola !41_G	et	f	\N
126979	poola	?poola =poola  (IndPrPs_  >poolama !29_V	et	f	\N
126980	poola	?poola =poola  (ImpPrSg2  >poolama !29_V	et	f	\N
126991	ükskõikseks	ükskõikseks =seks  (SgN  >üks+kõik+seks !22_S	et	f	\N
126992	ükskõikseks	ükskõikseks =kõikse  (SgTr  >üks+kõikne !02_A	et	f	\N
126993	hirmus	hirmus =hirmu  (SgIn  >hirm !22_S	et	f	\N
126994	hirmus	hirmus =hirmu  (IndIpfSg3  >hirmuma !27_V	et	f	\N
126869	hümnaasiumis	?hümnaasiumis =hümnaasiumis  (SgN  >hümnaasiumis !09_S	et	f	\N
126882	õpides	?õpides =õpi  (PlIn  >õpi !16_S	et	f	\N
126883	õpides	?õpides =õpi  (Ger  >õpima !27_V	et	f	\N
126895	õpimine	?õpimine =õpimine  (SgN  >õpimine !12_S	et	f	\N
126896	õpimine	?õpimine =õpimine  (PlP  >õpimin !19_S	et	f	\N
126897	kahekümnendal	?kahekümnendal =kahekümnenda  (SgAd  >kahekümnenda !16_S	et	f	\N
126898	kahekümnendal	?kahekümnendal =kahekümnendal  (SgN  >kahekümnendal !02_S	et	f	\N
126899	kahekümnendal	?kahekümnendal =kümnenda  (SgAd  >kahe+kümnenda !01_S	et	f	\N
126906	neljakümne	?neljakümne =neljakümne  (SgN  >neljakümne !02_A	et	f	\N
126907	neljakümne	?neljakümne =neljakümne  (PlP  >neljakümn !22_S	et	f	\N
126908	neljakümne	?neljakümne =kümne  (SgN  >nelja+kümne !02_A	et	f	\N
126909	neljakümne	?neljakümne =kümne  (PlP  >nelja+kümn !22_S	et	f	\N
126910	seitsekümne	?seitsekümne =seitsekümne  (SgN  >seitsekümne !02_A	et	f	\N
126911	seitsekümne	?seitsekümne =seitsekümne  (PlP  >seitsekümn !22_S	et	f	\N
126912	seitsekümne	?seitsekümne =kümne  (SgN  >seitse+kümne !02_A	et	f	\N
126913	seitsekümne	?seitsekümne =kümne  (PlP  >seitse+kümn !22_S	et	f	\N
126915	pedagoogiline	pedagoogiline =pedagoogiline  (SgN  >pedagoogiline !12_A	et	f	\N
126916	pedagoogiline	"pedagoogiline %pedagoogi  )LINE_aA  <pedagoog ;22_S	et	f	\N
126935	klaaverit	?klaaverit =klaaveri  (SgP  >klaaveri !01_S	et	f	\N
126936	klaaverit	?klaaverit =klaaveri  (SgP  >klaaver !02_S	et	f	\N
126951	külastamine	külastamine =külastamine  (SgN  >külastamine !12_S	et	f	\N
126952	külastamine	"külastamine %külasta  )MINE_vS  <külastama ;27_V	et	f	\N
126953	õnnestumine	õnnestumine =õnnestumine  (SgN  >õnnestumine !12_S	et	f	\N
126954	õnnestumine	"õnnestumine %õnnestu  )MINE_vS  <õnnestuma ;27_V	et	f	\N
126960	sündist	?sündist =sündi  (SgEl  >sündi !16_S	et	f	\N
126961	sündist	?sündist =sündi  (SgEl  >sünt !22_S	et	f	\N
126962	sündist	?sündist =sündis  (SgP  >sündis !09_S	et	f	\N
126963	sündist	?sündist =sündist  (SgN  >sündist !22_S	et	f	\N
126964	päikesepaisteline	päikesepaisteline =paisteline  (SgN  >päikese+paisteline !12_A	et	f	\N
126965	päikesepaisteline	"päikese+paisteline %paiste  )LINE_aA  <päikese+paiste ;06_S	et	f	\N
126976	väikses	väikses =väikse  (SgIn  >väike !10_A	et	f	\N
126977	väikses	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
127002	üheksakorrulises	?üheksakorrulises =üheksakorrulise  (SgIn  >üheksakorruline !12_A	et	f	\N
127003	üheksakorrulises	?üheksakorrulises =korrulise  (SgIn  >üheksa+korruline !12_A	et	f	\N
127004	üheksakorrulises	?üheksakorrulises =akorrulise  (SgIn  >üheks+akorruline !12_A	et	f	\N
127005	üheksakorrulises	?üheksakorrulises =ksakorrulise  (SgIn  >ühe+ksakorruline !12_A	et	f	\N
127016	citymarketis	?citymarketis =citymarketi  (SgIn  >citymarkett !22_S	et	f	\N
127018	citymarketis	?citymarketis =citymarketis  (SgN  >citymarketis !09_S	et	f	\N
127030	tolaastal	?tolaastal =tolaasta  (SgAd  >tolaasta !01_S	et	f	\N
127048	krasnodaari	?krasnodaari =krasnodaari  (SgN  >krasnodaari !16_S	et	f	\N
127049	krasnodaari	?krasnodaari =krasnodaari  (SgG  >krasnodaari !16_S	et	f	\N
127050	krasnodaari	?krasnodaari =krasnodaari  (SgG  >krasnodaar !22_S	et	f	\N
127052	krasnodaari	?krasnodaari =krasnodaari  (SgP  >krasnodaar !22_S	et	f	\N
127053	krasnodaari	?krasnodaari =krasnodaari  (SgAdt  >krasnodaar !22_S	et	f	\N
127054	krasnodaari	?krasnodaari =krasnodaari  (IndPrPs_  >krasnodaarima !28_V	et	f	\N
127055	krasnodaari	?krasnodaari =krasnodaari  (ImpPrSg2  >krasnodaarima !28_V	et	f	\N
127065	kift	?kift =kift  (SgN  >kift !22_S	et	f	\N
127099	krimustusega	?krimustusega =krimustuse  (SgKom  >krimustus !11_S	et	f	\N
127141	taltsutamiseks	taltsutamiseks =taltsutamise  (SgTr  >taltsutamine !12_S	et	f	\N
127142	taltsutamiseks	"taltsutamine %taltsuta  )MINE_vS  <taltsutama ;27_V	et	f	\N
127143	lähenesid	lähenesid =lähene  (IndIpfSg2  >lähenema !27_V	et	f	\N
127144	lähenesid	lähenesid =lähene  (IndIpfPl3  >lähenema !27_V	et	f	\N
127158	abilisena	abilisena =abilise  (SgEs  >abiline !12_S	et	f	\N
127159	abilisena	"abiline %abi  )LINE_aA  <abi ;17_S	et	f	\N
127160	väljapääsu	väljapääsu =pääsu  (SgN  >välja+pääsu !16_S	et	f	\N
127161	väljapääsu	väljapääsu =pääsu  (SgG  >välja+pääsu !16_S	et	f	\N
127162	väljapääsu	väljapääsu =pääsu  (SgG  >välja+pääs !22_S	et	f	\N
127163	väljapääsu	väljapääsu =pääsu  (SgP  >välja+pääs !22_S	et	f	\N
127164	väljapääsu	väljapääsu =pääsu  (SgAdt  >välja+pääs !22_S	et	f	\N
127165	eratunde	eratunde =tunde  (SgG  >era+tunne !06_S	et	f	\N
127166	eratunde	eratunde =tunde  (PlP  >era+tund !22_S	et	f	\N
127167	kooliealistele	kooliealistele =ealis  (PlAll  >kooli+ealine !12?10_A	et	f	\N
127168	kooliealistele	"kooli+ealine %ea  )LINE_aA  <kooli+iga ;18_S	et	f	\N
127195	hoolitsema	hoolitsema =hoolitse  (Sup  >hoolitsema !27_V	et	f	\N
127196	hoolitsema	hoolitsema =ema  (SgN  >hoo+lits+ema !17_S	et	f	\N
127197	hoolitsema	hoolitsema =ema  (SgG  >hoo+lits+ema !17_S	et	f	\N
127198	hoolitsema	hoolitsema =ema  (SgP  >hoo+lits+ema !17_S	et	f	\N
127238	lootustega	lootustega =lootus  (PlKom  >lootus !11~09_S	et	f	\N
127239	lootustega	"lootus %loo  )TUS2_aS  <lugu ;18_S	et	f	\N
127240	lootustega	"lootus %loo  )TUS2_aS  <loog ;22_S	et	f	\N
127241	lootustega	"lootus %loo  )TUS2_aS  <lood ;22_S	et	f	\N
126889	lõpitamist	?lõpitamist =lõpitami  (SgEl  >lõpitam !02_A	et	f	\N
126890	lõpitamist	?lõpitamist =lõpitamis  (SgP  >lõpitamis !09_S	et	f	\N
126891	lõpitamist	?lõpitamist =lõpitamis  (SgP  >lõpitamine !12_S	et	f	\N
126892	lõpitamist	?lõpitamist =lõpitamist  (SgN  >lõpitamist !22_S	et	f	\N
126900	kümneesimesel	?kümneesimesel =kümneesimese  (SgAd  >kümneesimene !12_A	et	f	\N
126901	kümneesimesel	?kümneesimesel =mese  (SgAd  >kümne+esi+mese !16_S	et	f	\N
126902	kümneesimesel	?kümneesimesel =mesel  (SgN  >kümne+esi+mesel !02_S	et	f	\N
126903	lõppetasin	?lõppetasin =lõppeta  (IndIpfSg1  >lõppetama !27_V	et	f	\N
126904	lõppetasin	?lõppetasin =lõppetasin  (SgN  >lõppetasin !19_S	et	f	\N
126905	lõppetasin	?lõppetasin =etasin  (SgN  >lõpp+etasin !19_S	et	f	\N
126914	pihkva	?pihkva =pihkva  (SgN  >pihkva !01_S	et	f	\N
126917	pihkva	?pihkva =pihkva  (SgG  >pihkva !01_S	et	f	\N
126918	pihkva	?pihkva =pihkva  (IndPrPs_  >pihkvama !29_V	et	f	\N
126919	pihkva	?pihkva =pihkva  (ImpPrSg2  >pihkvama !29_V	et	f	\N
126925	sõpralikud	?sõpralikud =sõpraliku  (PlN  >sõpralik !25_A	et	f	\N
126926	sõpralikud	?sõpralikud =sõpraliku  (IndPrSg2  >sõpralikuma !27_V	et	f	\N
126943	kuudumine	?kuudumine =kuudumine  (SgN  >kuudumine !12_S	et	f	\N
126944	kuudumine	?kuudumine =kuudumine  (PlP  >kuudumin !19_S	et	f	\N
126945	kuudumine	?kuudumine =dumine  (SgN  >kuu+dumine !10_A	et	f	\N
126946	olulisemat	olulisemat =olulisema  (SgP  >olulisem !02_A	et	f	\N
126947	olulisemat	"olulisem %olu  )LISEM_cA  <olu ;17_S	et	f	\N
126948	olulisemat	"olulisem %olulise  )M_cA  <oluline ;12_A	et	f	\N
126949	lemmiktöö	lemmiktöö =töö  (SgN  >lemmik+töö !26_S	et	f	\N
126950	lemmiktöö	lemmiktöö =töö  (SgG  >lemmik+töö !26_S	et	f	\N
126955	muusikakoolisse	muusikakoolisse =kooli  (SgIll  >muusika+kool !22_S	et	f	\N
126956	muusikakoolisse	muusikakoolisse =kooli  (PlIll  >muusika+kool !22_S	et	f	\N
126957	viiest	viiest =viie  (SgEl  >viis !14_N	et	f	\N
126958	viiest	viiest =viies  (SgP  >viiene !10_AS	et	f	\N
126959	viiest	"viiene %viie  )NE_aA  <viis ;14_N	et	f	\N
126968	kardsin	?kardsin =kardsi  (IndPrSg1  >kardsima !28_V	et	f	\N
126969	kardsin	?kardsin =kardsin  (SgN  >kardsin !02_S	et	f	\N
126970	astu	astu =astu  (IndPrPs_  >astuma !28_V	et	f	\N
126971	astu	astu =astu  (ImpPrSg2  >astuma !28_V	et	f	\N
126972	siiamani	?siiamani =siiamani  (SgG  >siiaman !02_S	et	f	\N
126973	siiamani	?siiamani =mani  (SgN  >siia+mani !17_S	et	f	\N
126974	siiamani	?siiamani =mani  (SgG  >siia+mani !17_S	et	f	\N
126975	siiamani	?siiamani =mani  (SgP  >siia+mani !17_S	et	f	\N
126986	astunud	astunud =astu  (PtsPtPs  >astuma !28_V	et	f	\N
126987	astunud	astunud =astunu  (PlN  >astunu !01_S	et	f	\N
126988	astunud	"astunu %astu  )NU_vS  <astuma ;28_V	et	f	\N
126989	astunud	astunud =astunud  (ID  >astunud !41_A	et	f	\N
126990	astunud	"astunud %astu  )NUD_vA  <astuma ;28_V	et	f	\N
127006	kahetoaline	kahetoaline =toaline  (SgN  >kahe+toaline !12?10_A	et	f	\N
127007	kahetoaline	"kahe+toaline %toa  )LINE_aA  <kahe+tuba ;18_S	et	f	\N
127012	parallelselt	?parallelselt =parallelse  (SgAbl  >parallelne !02_A	et	f	\N
127017	parallelselt	?parallelselt =parallelselt  (ID  >parallelselt !41_D	et	f	\N
127019	õppimisega	õppimisega =õppimise  (SgKom  >õppimine !12_S	et	f	\N
127020	õppimisega	"õppimine %õppi  )MINE_vS  <õppima ;28_V	et	f	\N
127021	jõua	jõua =jõua  (IndPrPs_  >jõudma !34_V	et	f	\N
127022	jõua	jõua =jõua  (ImpPrSg2  >jõudma !34_V	et	f	\N
127028	momenti	momenti =momenti  (SgP  >moment !22_S	et	f	\N
127029	momenti	momenti =momenti  (SgAdt  >moment !22_S	et	f	\N
127031	kaotus	kaotus =kaotu  (SgIn  >kaotu !01_A	et	f	\N
127032	kaotus	"kaotu %kao  )TU1_vS  <kaduma ;28_V	et	f	\N
127033	kaotus	"kaotu %kao  )TU2_kA  <kabu ;18_S	et	f	\N
127034	kaotus	"kaotu %kao  )TU2_kA  <kadu ;18_S	et	f	\N
127035	kaotus	kaotus =kaotus  (SgN  >kaotus !11~09_S	et	f	\N
127036	kaotus	"kaotus %kaota  )US_vS  <kaotama ;27_V	et	f	\N
127037	kaotus	"kaotus %kao  )TUS1_aS  <kaduma ;28_V	et	f	\N
127038	kaotus	"kaotus %kao  )TUS2_aS  <kabu ;18_S	et	f	\N
127039	kaotus	"kaotus %kao  )TUS2_aS  <kadu ;18_S	et	f	\N
127040	kiirovis	?kiirovis =kiirovi  (SgIn  >kiirov !02_A	et	f	\N
127041	kiirovis	?kiirovis =kiirovis  (SgN  >kiirovis !11_S	et	f	\N
127042	kiirovis	?kiirovis =ovi  (SgIn  >kiir+ovi !17_S	et	f	\N
127043	kiirovis	?kiirovis =ovis  (SgN  >kiir+ovis !09_S	et	f	\N
127046	lõppude	lõppude =lõppu  (PlG  >lõpp !22_SA	et	f	\N
127047	lõppude	lõppude =ude  (SgN  >lõpp+ude !04_S	et	f	\N
127058	azoovi	?azoovi =azoovi  (SgN  >azoovi !16_S	et	f	\N
127059	azoovi	?azoovi =azoovi  (SgG  >azoovi !16_S	et	f	\N
127060	azoovi	?azoovi =azoovi  (SgG  >azoov !22_S	et	f	\N
127061	azoovi	?azoovi =azoovi  (SgP  >azoov !22_S	et	f	\N
127062	azoovi	?azoovi =azoovi  (SgAdt  >azoov !22_S	et	f	\N
127063	azoovi	?azoovi =azoovi  (IndPrPs_  >azoovima !28_V	et	f	\N
127064	azoovi	?azoovi =azoovi  (ImpPrSg2  >azoovima !28_V	et	f	\N
127078	tüdrukutele	tüdrukutele =tüdruku  (PlAll  >tüdruk !02_S	et	f	\N
127079	tüdrukutele	tüdrukutele =ute  (SgAll  >tüdruk+utt !22_S	et	f	\N
127080	tüdrukutele	tüdrukutele =ute  (PlAll  >tüdruk+utt !22_S	et	f	\N
126995	hirmus	hirmus =hirmus  (ID  >hirmus !41_D	et	f	\N
126997	hirmus	hirmus =hirmus  (SgN  >hirmus !02_A	et	f	\N
127008	vabaabielus	vabaabielus =elu  (SgIn  >vaba+abi+elu !17_S	et	f	\N
127009	vabaabielus	vabaabielus =elus  (SgN  >vaba+abi+elus !02_A	et	f	\N
127010	pedagoogikaülikoolis	pedagoogikaülikoolis =kooli  (SgIn  >pedagoogika+üli+kool !22_S	et	f	\N
127011	pedagoogikaülikoolis	pedagoogikaülikoolis =kooli  (PlIn  >pedagoogika+üli+kool !22_S	et	f	\N
127013	mustakivi	mustakivi =kivi  (SgN  >musta+kivi !17_S	et	f	\N
127014	mustakivi	mustakivi =kivi  (SgG  >musta+kivi !17_S	et	f	\N
127015	mustakivi	mustakivi =kivi  (SgP  >musta+kivi !17_S	et	f	\N
127056	parim	parim =parim  (SgN  >parim !02_A	et	f	\N
127057	parim	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
127066	medõde	medõde =õde  (SgN  >med+õde !18_S	et	f	\N
127067	medõde	medõde =õde  (SgP  >med+õde !18_S	et	f	\N
127072	kehakultuuri	kehakultuuri =kultuuri  (SgG  >keha+kultuur !22_S	et	f	\N
127073	kehakultuuri	kehakultuuri =kultuuri  (SgP  >keha+kultuur !22_S	et	f	\N
127074	kehakultuuri	kehakultuuri =kultuuri  (SgAdt  >keha+kultuur !22_S	et	f	\N
127075	sügisest	sügisest =sügise  (SgEl  >sügis !09_S	et	f	\N
127076	sügisest	sügisest =sügises  (SgP  >sügisene !12_A	et	f	\N
127077	sügisest	"sügisene %sügise  )NE_aA  <sügis ;09_S	et	f	\N
127081	halvemaid	halvemaid =halvema  (PlP  >halvem !02_A	et	f	\N
127082	halvemaid	"halvem %halve  )M_cA  <halb ;22_A	et	f	\N
127103	peotantsuringi	peotantsuringi =ringi  (SgG  >peo+tantsu+ring !22_S	et	f	\N
127104	peotantsuringi	peotantsuringi =ringi  (SgP  >peo+tantsu+ring !22_S	et	f	\N
127105	peotantsuringi	peotantsuringi =ringi  (SgAdt  >peo+tantsu+ring !22_S	et	f	\N
127106	trennida	?trennida =trenni  (Inf  >trennima !28_V	et	f	\N
127109	sadamas	sadamas =sada  (SupIn  >sadama !28_V	et	f	\N
127110	sadamas	sadamas =sadama  (SgIn  >sadam !02_S	et	f	\N
127123	eluaastast	eluaastast =aasta  (SgEl  >elu+aasta !01_S	et	f	\N
127124	eluaastast	eluaastast =aastas  (SgP  >elu+aastane !12~10_A	et	f	\N
127125	eluaastast	"elu+aastane %aasta  )NE_aA  <elu+aasta ;01_S	et	f	\N
127126	jäigi	jäigi =jäigi  (SgG  >jäik !22_A	et	f	\N
127127	jäigi	jäigi =jä  (IndIpfSg3^  >jääma !37_V	et	f	\N
127134	ootamatu	ootamatu =ootamatu  (SgN  >ootamatu !01_A	et	f	\N
127135	ootamatu	"ootamatu %oota  )MATU_vA  <ootama ;29_V	et	f	\N
127136	ootamatu	ootamatu =ootamatu  (SgG  >ootamatu !01_A	et	f	\N
127145	tõsised	tõsised =tõsise  (PlN  >tõsine !10_A	et	f	\N
127146	tõsised	"tõsine %tõsi  )NE_aA  <tõsi ;15_S	et	f	\N
127149	kindlalt	kindlalt =kindla  (SgAbl  >kindel !02_A	et	f	\N
127150	kindlalt	kindlalt =kindlalt  (ID  >kindlalt !41_D	et	f	\N
127151	kindlalt	"kindlalt %kindla  )LT_mD  <kindel ;02_A	et	f	\N
127156	raamatupidaja	raamatupidaja =pidaja  (SgN  >raamatu+pidaja !01_S	et	f	\N
127157	raamatupidaja	raamatupidaja =pidaja  (SgG  >raamatu+pidaja !01_S	et	f	\N
127172	lootust	lootust =lootu  (SgEl  >lootu !01_A	et	f	\N
127173	lootust	"lootu %loo  )TU2_kA  <lugu ;18_S	et	f	\N
127174	lootust	"lootu %loo  )TU2_kA  <loog ;22_S	et	f	\N
127175	lootust	"lootu %loo  )TU2_kA  <lood ;22_S	et	f	\N
127177	lootust	lootust =lootus  (SgP  >lootus !11~09_S	et	f	\N
127178	lootust	"lootus %loo  )TUS2_aS  <lugu ;18_S	et	f	\N
127180	lootust	"lootus %loo  )TUS2_aS  <loog ;22_S	et	f	\N
127181	lootust	"lootus %loo  )TUS2_aS  <lood ;22_S	et	f	\N
127182	lootust	lootust =tust  (SgN  >loo+tust !22_S	et	f	\N
127185	aeg-ajalt	aeg-ajalt =aja  (SgAbl  >aeg-aeg !22_S	et	f	\N
127186	aeg-ajalt	aeg-ajalt =ajalt  (ID  >aeg-ajalt !41_D	et	f	\N
127192	naabritest	naabritest =naabri  (PlEl  >naaber !02_S	et	f	\N
127193	naabritest	naabritest =test  (SgN  >naabri+test !22_S	et	f	\N
127194	naabritest	naabritest =brite  (PlEl  >naa+britt !22_S	et	f	\N
127199	juhtuks	juhtuks =juhtu  (KndPrPs  >juhtuma !27_V	et	f	\N
127200	juhtuks	juhtuks =uks  (SgN  >juht+uks !14_S	et	f	\N
127228	ona	?ona =ona  (SgN  >ona !17_S	et	f	\N
127229	ona	?ona =ona  (SgG  >ona !17_S	et	f	\N
127230	ona	?ona =ona  (SgP  >ona !17_S	et	f	\N
127231	ona	?ona =ona  (IndPrPs_  >onama !27_V	et	f	\N
127232	ona	?ona =ona  (ImpPrSg2  >onama !27_V	et	f	\N
127233	viljandis	?viljandis =viljandi  (SgIn  >viljandi !01_S	et	f	\N
127234	viljandis	?viljandis =viljandi  (SgIn  >viljand !02_S	et	f	\N
127235	viljandis	?viljandis =viljandi  (SgIn  >viljant !22_S	et	f	\N
127236	viljandis	?viljandis =viljandi  (IndIpfSg3  >viljandima !28_V	et	f	\N
127237	viljandis	?viljandis =viljandis  (SgN  >viljandis !11_S	et	f	\N
127244	kassikene	kassikene =kassikene  (SgN  >kassikene !12_S	et	f	\N
127245	kassikene	"kassikene %kassi  )KENE_dS  <kass ;22_S	et	f	\N
127246	kassikene	kassikene =sikene  (SgN  >kas+sikene !10_A	et	f	\N
127247	kassikene	"kas+sikene %si  )KENE_dS  <kas+si ;26_S	et	f	\N
127252	toilas	?toilas =toila  (SgIn  >toila !16_S	et	f	\N
127253	toilas	?toilas =toila  (IndIpfSg3  >toilama !29_V	et	f	\N
127254	toilas	?toilas =toilas  (SgN  >toilas !07_S	et	f	\N
127257	kirsipuu	kirsipuu =puu  (SgN  >kirsi+puu !26_S	et	f	\N
127258	kirsipuu	kirsipuu =puu  (SgG  >kirsi+puu !26_S	et	f	\N
127265	varres	varres =varre  (SgIn  >vars !14_S	et	f	\N
127083	vedasalt	?vedasalt =vedasa  (SgAbl  >vedasa !01_S	et	f	\N
127084	vedasalt	?vedasalt =vedasalt  (ID  >vedasalt !41_D	et	f	\N
127087	kurvem	kurvem =kurvem  (SgN  >kurvem !02_A	et	f	\N
127088	kurvem	"kurvem %kurve  )M_cA  <kurb ;22_A	et	f	\N
127112	harrastanud	harrastanud =harrasta  (PtsPtPs  >harrastama !27_V	et	f	\N
127113	harrastanud	harrastanud =harrastanu  (PlN  >harrastanu !01_S	et	f	\N
127114	harrastanud	"harrastanu %harrasta  )NU_vS  <harrastama ;27_V	et	f	\N
127115	harrastanud	harrastanud =harrastanud  (ID  >harrastanud !41_A	et	f	\N
127116	harrastanud	"harrastanud %harrasta  )NUD_vA  <harrastama ;27_V	et	f	\N
127121	lemmiktegevus	lemmiktegevus =tegevus  (SgN  >lemmik+tegevus !11_S	et	f	\N
127122	lemmiktegevus	"lemmik+tegevus %tegeva  )US_aS  <lemmik+tegev ;02_A	et	f	\N
127128	harrastuseks	harrastuseks =harrastuse  (SgTr  >harrastus !11_S	et	f	\N
127129	harrastuseks	"harrastus %harrasta  )US_vS  <harrastama ;27_V	et	f	\N
127130	saavutamine	saavutamine =saavutamine  (SgN  >saavutamine !12_S	et	f	\N
127131	saavutamine	"saavutamine %saavuta  )MINE_vS  <saavutama ;27_V	et	f	\N
127176	kaotama	kaotama =kao  (SupIps  >kaduma !28_V	et	f	\N
127179	kaotama	kaotama =kaota  (Sup  >kaotama !27_V	et	f	\N
127183	nutsin	nutsin =nut  (IndIpfSg1  >nutma !35_V	et	f	\N
127184	nutsin	nutsin =nutsi  (IndPrSg1  >nutsima !28_V	et	f	\N
127187	kiindunud	kiindunud =kiindu  (PtsPtPs  >kiinduma !27_V	et	f	\N
127188	kiindunud	kiindunud =kiindunu  (PlN  >kiindunu !01_S	et	f	\N
127189	kiindunud	"kiindunu %kiindu  )NU_vS  <kiinduma ;27_V	et	f	\N
127190	kiindunud	kiindunud =kiindunud  (ID  >kiindunud !41_A	et	f	\N
127191	kiindunud	"kiindunud %kiindu  )NUD_vA  <kiinduma ;27_V	et	f	\N
127224	nädalavahetustel	nädalavahetustel =us  (PlAd  >nädala+vahet+uks !14_S	et	f	\N
127225	nädalavahetustel	nädalavahetustel =tuste  (PlAd  >nädala+vahe+tust !22_S	et	f	\N
127226	nädalavahetustel	nädalavahetustel =vahetus  (PlAd  >nädala+vahetus !11_S	et	f	\N
127227	nädalavahetustel	"nädala+vahetus %vahe  )TUS2_aS  <nädala+vahe ;16_S	et	f	\N
127262	karjus	karjus =karju  (PlIn  >kari !24_S	et	f	\N
127263	karjus	karjus =karju  (IndIpfSg3  >karjuma !28_V	et	f	\N
127264	karjus	karjus =karjus  (SgN  >karjus !09_S	et	f	\N
127267	vaeseke	vaeseke =vaeseke  (SgN  >vaeseke !12_AS	et	f	\N
127268	vaeseke	"vaeseke %vaese  )KE_dA  <vaene ;10_AS	et	f	\N
127269	kassikest	kassikest =kassikes  (SgP  >kassike !12_S	et	f	\N
127270	kassikest	"kassike %kassi  )KE_dS  <kass ;22_S	et	f	\N
127271	kassikest	kassikest =kassikes  (SgP  >kassikene !12_S	et	f	\N
127272	kassikest	"kassikene %kassi  )KENE_dS  <kass ;22_S	et	f	\N
127273	kassikest	kassikest =kest  (SgN  >kassi+kest !22_S	et	f	\N
127274	kassikest	kassikest =sike  (PlEl  >kas+sikk !22_S	et	f	\N
127275	kassikest	kassikest =sikes  (SgP  >kas+sikene !10_A	et	f	\N
127276	kassikest	"kas+sikene %si  )KENE_dS  <kas+si ;26_S	et	f	\N
127277	koolisime	koolisime =ime  (SgN  >koolis+ime !16_S	et	f	\N
127278	koolisime	koolisime =ime  (SgG  >koolis+ime !16_S	et	f	\N
127283	nägisin	?nägisin =nägi  (IndIpfSg1  >nägima !27_V	et	f	\N
127284	nägisin	?nägisin =nägisin  (SgN  >nägisin !19_S	et	f	\N
127332	ostetud	ostetud =oste  (PtsPtIps  >ostma !34_V	et	f	\N
127333	ostetud	ostetud =ostetu  (PlN  >ostetu !01_AS	et	f	\N
127334	ostetud	"ostetu %oste  )TU1_vS  <ostma ;34_V	et	f	\N
127335	ostetud	ostetud =ostetud  (ID  >ostetud !41_A	et	f	\N
127336	ostetud	"ostetud %oste  )TUD_vA  <ostma ;34_V	et	f	\N
127362	huuvidest	?huuvidest =huuvi  (PlEl  >huuvi !16_S	et	f	\N
127363	huuvidest	?huuvidest =huuvi  (PlEl  >huuv !22_S	et	f	\N
127364	huuvidest	?huuvidest =huuvides  (SgP  >huuvidene !12_A	et	f	\N
127372	kaksteist	kaksteist =te  (PlEl  >kaks+tee !26_S	et	f	\N
127373	kaksteist	kaksteist =teist  (SgN  >kaks+teist !22_S	et	f	\N
127374	seitsmeaastane	seitsmeaastane =aastane  (SgN  >seitsme+aastane !12~10_A	et	f	\N
127375	seitsmeaastane	"seitsme+aastane %aasta  )NE_aA  <seitsme+aasta ;01_S	et	f	\N
127397	istudes	istudes =istu  (PlIn  >ist !22_S	et	f	\N
127398	istudes	istudes =istu  (Ger  >istuma !28_V	et	f	\N
127405	tekikottis	?tekikottis =tekikotti  (IndIpfSg3  >tekikottima !28_V	et	f	\N
127406	tekikottis	?tekikottis =tekikottis  (SgN  >tekikottis !09_S	et	f	\N
127413	stockmanni	?stockmanni =stockmanni  (SgN  >stockmanni !01_S	et	f	\N
127414	stockmanni	?stockmanni =stockmanni  (SgG  >stockmanni !01_S	et	f	\N
127415	stockmanni	?stockmanni =stockmanni  (SgG  >stockmann !22_S	et	f	\N
127416	stockmanni	?stockmanni =stockmanni  (SgP  >stockmann !22_S	et	f	\N
127417	stockmanni	?stockmanni =stockmanni  (SgAdt  >stockmann !22_S	et	f	\N
127418	stockmanni	?stockmanni =stockmanni  (IndPrPs_  >stockmannima !28_V	et	f	\N
127419	stockmanni	?stockmanni =stockmanni  (ImpPrSg2  >stockmannima !28_V	et	f	\N
127437	puuduseks	puuduseks =puuduse  (SgTr  >puudus !11~09_S	et	f	\N
127438	puuduseks	puuduseks =seks  (SgN  >puudu+seks !22_S	et	f	\N
127452	põhjaks	põhjaks =põhja  (SgTr  >põhi !24_S	et	f	\N
127453	põhjaks	põhjaks =põhja  (KndPrPs  >põhjama !29_V	et	f	\N
127454	tarbijaid	tarbijaid =tarbija  (PlP  >tarbija !01_S	et	f	\N
127455	tarbijaid	"tarbija %tarbi  )JA_vS  <tarbima ;27_V	et	f	\N
127474	kauplemine	kauplemine =kauplemine  (SgN  >kauplemine !12_S	et	f	\N
127094	õue	õue =õue  (SgG  >õu !22_S	et	f	\N
127095	õue	õue =õue  (SgP  >õu !22_S	et	f	\N
127096	õue	õue =õue  (SgAdt  >õu !22_S	et	f	\N
127097	põlved	põlved =põlve  (PlN  >põlv !22_S	et	f	\N
127098	põlved	põlved =põlve  (PlN  >põli !24_S	et	f	\N
127107	ostusin	?ostusin =ostu  (IndIpfSg1  >ostuma !27_V	et	f	\N
127108	ostusin	?ostusin =ostusin  (SgN  >ostusin !19_S	et	f	\N
127117	mitut	mitut =mitu  (SgP  >mitu !05_P	et	f	\N
127120	mitut	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
127138	tegevusala	tegevusala =ala  (SgN  >tegevus+ala !17_S	et	f	\N
127139	tegevusala	tegevusala =ala  (SgG  >tegevus+ala !17_S	et	f	\N
127140	tegevusala	tegevusala =ala  (SgP  >tegevus+ala !17_S	et	f	\N
127152	lähimat	lähimat =lähima  (SgP  >lähim !02_A	et	f	\N
127153	lähimat	"lähim %lähi  )IM_sA  <lähike ;12_A	et	f	\N
127208	aktiivseks	aktiivseks =aktiivse  (SgTr  >aktiivne !02_A	et	f	\N
127209	aktiivseks	aktiivseks =seks  (SgN  >aktiiv+seks !22_S	et	f	\N
127210	reisimist	reisimist =reisimis  (SgP  >reisimine !12_S	et	f	\N
127211	reisimist	"reisimine %reisi  )MINE_vS  <reisima ;28_V	et	f	\N
127222	puhkuseks	puhkuseks =puhkuse  (SgTr  >puhkus !11~09_S	et	f	\N
127223	puhkuseks	puhkuseks =use  (PlTr  >puhk+usk !22_S	et	f	\N
127250	meenutama	meenutama =meenu  (SupIps  >meenuma !27_V	et	f	\N
127251	meenutama	meenutama =meenuta  (Sup  >meenutama !27_V	et	f	\N
127285	puutuma	puutuma =puutu  (Sup  >puutuma !27_V	et	f	\N
127286	puutuma	puutuma =puutuma  (SgG  >puutum !02_A	et	f	\N
127287	puutuma	"puutum %puu  )TUM2_cA  <puu ;26_S	et	f	\N
127292	isat	?isat =isat  (SgN  >isat !02_S	et	f	\N
127293	liigutama	liigutama =liigu  (SupIps  >liikuma !28_V	et	f	\N
127294	liigutama	liigutama =liiguta  (Sup  >liigutama !27_V	et	f	\N
127316	mingid	mingid =mingi  (PlN  >mingi !01_P	et	f	\N
127317	mingid	mingid =mingi  (PlN  >mink !22_S	et	f	\N
127318	mingid	mingid =mingi  (IndPrSg2  >minkima !28_V	et	f	\N
127326	tervem	tervem =tervem  (SgN  >tervem !02_A	et	f	\N
127327	tervem	"tervem %terve  )M_cA  <terve ;01_AS	et	f	\N
127328	tervem	"tervem %terve  )M_cA  <terve ;06_AS	et	f	\N
127344	saaremaal	saaremaal =maa  (SgAd  >saare+maa !26_S	et	f	\N
127345	saaremaal	saaremaal =maal  (SgN  >saare+maal !22_S	et	f	\N
127348	kutsipõlves	?kutsipõlves =kutsipõlve  (PlIn  >kutsipõlv !22_S	et	f	\N
127358	tagahoovis	tagahoovis =hoovi  (SgIn  >taga+hoov !22_S	et	f	\N
127359	tagahoovis	tagahoovis =hoovi  (PlIn  >taga+hoob !22_S	et	f	\N
127360	puurist	puurist =puuri  (SgEl  >puur !22_S	et	f	\N
127361	puurist	puurist =rist  (SgN  >puu+rist !22_S	et	f	\N
127376	tädi	tädi =tädi  (SgN  >tädi !17_S	et	f	\N
127377	tädi	tädi =tädi  (SgG  >tädi !17_S	et	f	\N
127378	tädi	tädi =tädi  (SgP  >tädi !17_S	et	f	\N
127387	sheesi	?sheesi =sheesi  (SgN  >sheesi !16_S	et	f	\N
127388	sheesi	?sheesi =sheesi  (SgG  >sheesi !16_S	et	f	\N
127389	sheesi	?sheesi =sheesi  (SgG  >shees !22_S	et	f	\N
127390	sheesi	?sheesi =sheesi  (SgP  >shees !22_S	et	f	\N
127391	sheesi	?sheesi =sheesi  (SgAdt  >shees !22_S	et	f	\N
127392	sheesi	?sheesi =sheesi  (IndPrPs_  >sheesima !28_V	et	f	\N
127393	sheesi	?sheesi =sheesi  (ImpPrSg2  >sheesima !28_V	et	f	\N
127401	sime	?sime =sime  (SgN  >sime !16_S	et	f	\N
127402	sime	?sime =sime  (SgG  >sime !16_S	et	f	\N
127403	sime	?sime =sime  (IndPrPs_  >simema !27_V	et	f	\N
127404	sime	?sime =sime  (ImpPrSg2  >simema !27_V	et	f	\N
127412	stockmann	?stockmann =stockmann  (SgN  >stockmann !22_S	et	f	\N
127422	ülimalt	ülimalt =ülima  (SgAbl  >ülim !02_A	et	f	\N
127423	ülimalt	ülimalt =ülimalt  (ID  >ülimalt !41_D	et	f	\N
127424	ülimalt	"ülimalt %ülima  )LT_mD  <ülim ;02_A	et	f	\N
127459	varastamist	varastamist =varastamis  (SgP  >varastamine !12_S	et	f	\N
127460	varastamist	"varastamine %varasta  )MINE_vS  <varastama ;27_V	et	f	\N
127461	iialgi	iialgi =iialgi  (ID  >iialgi !41_D	et	f	\N
127462	iialgi	iialgi =iial  (ID^  >iial !41_D	et	f	\N
127463	univorm	univorm =univorm  (SgN  >univorm !22_S	et	f	\N
127464	univorm	univorm =vorm  (SgN  >uni+vorm !22_S	et	f	\N
127465	rahule	rahule =rahu  (SgAll  >rahu !17_S	et	f	\N
127466	rahule	rahule =rahu  (PlAll  >rahk !22_S	et	f	\N
127467	rahule	rahule =rahule  (ID  >rahule !41_D	et	f	\N
127468	sobivat	sobivat =sobi  (KvtPrPs  >sobima !27_V	et	f	\N
127469	sobivat	sobivat =sobiva  (SgP  >sobiv !02_A	et	f	\N
127470	sobivat	"sobiv %sobi  )V_vA  <sobima ;27_V	et	f	\N
127476	kristiine	?kristiine =kristiine  (SgN  >kristiine !12~10_A	et	f	\N
127477	kristiine	?kristiine =kristiine  (PlP  >kristiin !22_S	et	f	\N
127478	kristiine	?kristiine =kristiine  (IndPrPs_  >kristiinema !27_V	et	f	\N
127479	kristiine	?kristiine =kristiine  (ImpPrSg2  >kristiinema !27_V	et	f	\N
127484	keskust	keskust =keskus  (SgP  >keskus !11~09_S	et	f	\N
127485	keskust	keskust =us  (SgP  >kesk+uks !14_S	et	f	\N
127488	soodsa	soodsa =soodsa  (SgG  >soodus !02_A	et	f	\N
127489	soodsa	soodsa =soodsa  (SgG  >soodne !02_A	et	f	\N
127494	jalutamist	jalutamist =jalutamis  (SgP  >jalutamine !12_S	et	f	\N
127495	jalutamist	"jalutamine %jaluta  )MINE_vS  <jalutama ;27_V	et	f	\N
127219	tuluusi	?tuluusi =usi  (SgN  >tulu+usi !17_S	et	f	\N
127220	tuluusi	?tuluusi =usi  (SgG  >tulu+usi !17_S	et	f	\N
127221	tuluusi	?tuluusi =usi  (SgP  >tulu+usi !17_S	et	f	\N
127242	õnnelikumatest	õnnelikumatest =õnnelikuma  (PlEl  >õnnelikum !02_A	et	f	\N
127243	õnnelikumatest	"õnnelikum %õnneliku  )M_cA  <õnnelik ;25_A	et	f	\N
127248	loomake	loomake =loomake  (SgN  >loomake !12_S	et	f	\N
127249	loomake	"loomake %looma  )KE_dS  <loom ;22_S	et	f	\N
127288	liigu	liigu =liigu  (SgG  >liik !22_S	et	f	\N
127289	liigu	liigu =liigu  (PlP  >liig !22_S	et	f	\N
127290	liigu	liigu =liigu  (IndPrPs_  >liikuma !28_V	et	f	\N
127291	liigu	liigu =liigu  (ImpPrSg2  >liikuma !28_V	et	f	\N
127302	raijoon	?raijoon =raijoon  (SgN  >raijoon !22_S	et	f	\N
127312	sõbradega	?sõbradega =sõbra  (PlKom  >sõbra !16_S	et	f	\N
127319	minusi	?minusi =minusi  (ID  >minusi !41_D	et	f	\N
127346	üleannetu	üleannetu =annetu  (SgN  >üle+annetu !01_A	et	f	\N
127347	üleannetu	üleannetu =annetu  (SgG  >üle+annetu !01_A	et	f	\N
127349	tahas	?tahas =taha  (IndIpfSg3  >tahama !27_V	et	f	\N
127350	tahas	?tahas =tahas  (SgN  >tahas !09_S	et	f	\N
127354	puuris	puuris =puuri  (SgIn  >puur !22_S	et	f	\N
127355	puuris	puuris =puuri  (IndIpfSg3  >puurima !28_V	et	f	\N
127365	käpades	?käpades =käpa  (PlIn  >käpa !16_S	et	f	\N
127366	käpades	?käpades =käpa  (Ger  >käpama !27_V	et	f	\N
127367	karistanud	karistanud =karista  (PtsPtPs  >karistama !27_V	et	f	\N
127368	karistanud	karistanud =karistanu  (PlN  >karistanu !01_S	et	f	\N
127369	karistanud	"karistanu %karista  )NU_vS  <karistama ;27_V	et	f	\N
127370	karistanud	karistanud =karistanud  (ID  >karistanud !41_A	et	f	\N
127371	karistanud	"karistanud %karista  )NUD_vA  <karistama ;27_V	et	f	\N
127379	loomaaeda	loomaaeda =aeda  (SgP  >looma+aed !22_S	et	f	\N
127380	loomaaeda	loomaaeda =aeda  (SgAdt  >looma+aed !22_S	et	f	\N
127382	hoolikas	hoolikas =hoolika  (SgIn  >hoolikas !02_A	et	f	\N
127383	hoolikas	hoolikas =hoolikas  (SgN  >hoolikas !02_A	et	f	\N
127394	ehmatis	?ehmatis =ehmati  (SgIn  >ehmat !02_S	et	f	\N
127395	ehmatis	?ehmatis =ehmati  (SgIn  >ehmatt !22_S	et	f	\N
127396	ehmatis	?ehmatis =ehmatis  (SgN  >ehmatis !11_S	et	f	\N
127399	lei	lei =lei  (SgN  >lei !26_S	et	f	\N
127400	lei	lei =lei  (SgG  >lei !26_S	et	f	\N
127407	olnu	olnu =olnu  (SgN  >olnu !01_S	et	f	\N
127408	olnu	"olnu %ol  )NU_vS  <olema ;36_V	et	f	\N
127409	olnu	olnu =olnu  (SgN  >olnu !06_S	et	f	\N
127410	olnu	olnu =olnu  (SgG  >olnu !01_S	et	f	\N
127411	olnu	olnu =olnu  (SgG  >olnu !06_S	et	f	\N
127429	ebaühtemoodid	?ebaühtemoodid =ebaühtemoodi  (PlN  >ebaühtemoodi !16_S	et	f	\N
127430	ebaühtemoodid	?ebaühtemoodid =ebaühtemoodi  (PlN  >ebaühtemoot !22_S	et	f	\N
127431	ebaühtemoodid	?ebaühtemoodid =ebaühtemoodi  (IndPrSg2  >ebaühtemootima !28_V	et	f	\N
127432	ebaühtemoodid	?ebaühtemoodid =moodi  (PlN  >eba+ühte+moot !22_S	et	f	\N
127433	ebaühtemoodid	?ebaühtemoodid =emoodi  (PlN  >eba+üht+emoodi !16_S	et	f	\N
127434	ebaühtemoodid	?ebaühtemoodid =emoodi  (PlN  >eba+üht+emoot !22_S	et	f	\N
127435	ebaühtemoodid	?ebaühtemoodid =ühtemoodi  (PlN  >eba+ühtemoodi !16_S	et	f	\N
127436	ebaühtemoodid	?ebaühtemoodid =ühtemoodi  (PlN  >eba+ühtemoot !22_S	et	f	\N
127449	turude	?turude =turu  (PlG  >turu !17_S	et	f	\N
127473	kehakated	### kehakated	et	f	\N
127480	koduses	koduses =koduse  (SgIn  >kodune !10_A	et	f	\N
127481	koduses	"kodune %kodu  )NE_aA  <kodu ;17_S	et	f	\N
127482	vajad	vajad =vaja  (PlN  >vaja !17_S	et	f	\N
127483	vajad	vajad =vaja  (IndPrSg2  >vajama !27_V	et	f	\N
127486	ajalt	ajalt =aja  (SgAbl  >aeg !22_S	et	f	\N
127487	ajalt	ajalt =ajalt  (ID  >ajalt !41_D	et	f	\N
127502	võta	võta =võta  (IndPrPs_  >võtma !35_V	et	f	\N
127503	võta	võta =võta  (ImpPrSg2  >võtma !35_V	et	f	\N
127515	oodavad	?oodavad =ooda  (IndPrPl3  >oodama !29_V	et	f	\N
127516	oodavad	?oodavad =oodava  (PlN  >oodava !01_S	et	f	\N
127517	oodavad	?oodavad =oodava  (PlN  >oodav !02_A	et	f	\N
127522	kvaliteetiga	kvaliteetiga =iga  (SgN  >kvaliteet+iga !18_S	et	f	\N
127524	kvaliteetiga	kvaliteetiga =iga  (SgP  >kvaliteet+iga !18_S	et	f	\N
127528	teenindus	teenindus =teenindus  (SgN  >teenindus !11_S	et	f	\N
127529	teenindus	"teenindus %teeninda  )US_vS  <teenindama ;27_V	et	f	\N
127540	riide	riide =riide  (SgG  >riie !06_S	et	f	\N
127541	riide	riide =riide  (PlP  >riid !22_S	et	f	\N
127549	butikki	?butikki =butik  (SgN^  >butik !02_S	et	f	\N
127550	modsam	?modsam =modsam  (SgN  >modsam !02_A	et	f	\N
127552	halp	?halp =halp  (SgN  >halp !22_S	et	f	\N
127562	positivne	?positivne =positivne  (SgN  >positivne !02_A	et	f	\N
127563	positivne	?positivne =positivne  (PlP  >positivn !22_S	et	f	\N
127564	õppesin	?õppesin =õppe  (IndIpfSg1  >õppema !27_V	et	f	\N
127565	õppesin	?õppesin =õppesin  (SgN  >õppesin !19_S	et	f	\N
127577	algklassde	?algklassde =klassde  (SgN  >alg+klassde !06_S	et	f	\N
127578	algklassde	?algklassde =klassde  (SgG  >alg+klassde !06_S	et	f	\N
127579	algklassde	?algklassde =klassde  (PlP  >alg+klassd !22_S	et	f	\N
127580	sündmine	?sündmine =sündmine  (SgN  >sündmine !12?10_A	et	f	\N
127255	ronis	ronis =roni  (SgIn  >roni !17_S	et	f	\N
127256	ronis	ronis =roni  (IndIpfSg3  >ronima !27_V	et	f	\N
127259	otsale	otsale =otsa  (SgAll  >ots !23?22_S	et	f	\N
127260	otsale	otsale =ale  (SgN  >ots+ale !16_S	et	f	\N
127261	otsale	otsale =ale  (SgG  >ots+ale !16_S	et	f	\N
127279	kastis	kastis =kast  (IndIpfSg3  >kastma !34_V	et	f	\N
127280	kastis	kastis =kasti  (SgIn  >kast !22_S	et	f	\N
127281	kastisse	kastisse =kasti  (SgIll  >kast !22_S	et	f	\N
127282	kastisse	kastisse =tisse  (PlP  >kas+tiss !22_S	et	f	\N
127306	puhke	puhke =puhke  (SgG  >puhe !06_S	et	f	\N
127307	puhke	puhke =puhke  (PlP  >puhk !22_S	et	f	\N
127308	puhke	puhke =puhke  (IndPrPs_  >puhkema !27_V	et	f	\N
127309	puhke	puhke =puhke  (ImpPrSg2  >puhkema !27_V	et	f	\N
127310	plats	plats =plats  (ID  >plats !41_I	et	f	\N
127311	plats	plats =plats  (SgN  >plats !22_S	et	f	\N
127320	kaabeltelevisiooni	kaabeltelevisiooni =visiooni  (SgG  >kaabel+tele+visioon !22_S	et	f	\N
127321	kaabeltelevisiooni	kaabeltelevisiooni =visiooni  (SgP  >kaabel+tele+visioon !22_S	et	f	\N
127322	kaabeltelevisiooni	kaabeltelevisiooni =visiooni  (SgAdt  >kaabel+tele+visioon !22_S	et	f	\N
127323	kaabeltelevisiooni	kaabeltelevisiooni =televisiooni  (SgG  >kaabel+televisioon !22_S	et	f	\N
127324	kaabeltelevisiooni	kaabeltelevisiooni =televisiooni  (SgP  >kaabel+televisioon !22_S	et	f	\N
127325	kaabeltelevisiooni	kaabeltelevisiooni =televisiooni  (SgAdt  >kaabel+televisioon !22_S	et	f	\N
127340	elav	elav =ela  (PtsPrPs  >elama !27_V	et	f	\N
127341	elav	elav =elav  (SgN  >elav !02_A	et	f	\N
127342	elav	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
127343	afganihurt	?afganihurt =afganihurt  (SgN  >afganihurt !22_S	et	f	\N
127351	siga	siga =si  (SgKom  >si !26_S	et	f	\N
127352	siga	siga =siga  (SgN  >siga !18_SA	et	f	\N
127353	siga	siga =siga  (SgP  >siga !18_SA	et	f	\N
127356	tagahoovis	tagahoovis =hoovi  (SgIn  >taga+hoov !22_S	et	f	\N
127357	tagahoovis	tagahoovis =hoovi  (PlIn  >taga+hoob !22_S	et	f	\N
127381	fotoapparadiga	### fotoapparadiga	et	f	\N
127420	plussiks	plussiks =plussi  (SgTr  >pluss !22_S	et	f	\N
127421	plussiks	plussiks =iks  (SgN  >pluss+iks !22_S	et	f	\N
127425	stockmannis	?stockmannis =stockmanni  (SgIn  >stockmanni !01_S	et	f	\N
127426	stockmannis	?stockmannis =stockmanni  (SgIn  >stockmann !22_S	et	f	\N
127427	stockmannis	?stockmannis =stockmanni  (IndIpfSg3  >stockmannima !28_V	et	f	\N
127428	stockmannis	?stockmannis =stockmannis  (SgN  >stockmannis !11_S	et	f	\N
127439	rikka	?rikka =rikka  (ID  >rikka !41_D	et	f	\N
127440	rikka	?rikka =rikka  (SgG  >rikas !07_A	et	f	\N
127441	rikka	?rikka =rikka  (IndPrPs_  >rikkama !29_V	et	f	\N
127442	rikka	?rikka =rikka  (ImpPrSg2  >rikkama !29_V	et	f	\N
127456	mustust	mustust =mustus  (SgP  >mustus !11~09_S	et	f	\N
127457	mustust	"mustus %must  )US_aS  <must ;22_AS	et	f	\N
127458	mustust	mustust =us  (SgP  >must+uks !14_S	et	f	\N
127471	missimõõte	missimõõte =mõõte  (SgG  >missi+mõõde !06_S	et	f	\N
127472	missimõõte	missimõõte =mõõte  (PlP  >missi+mõõt !22_S	et	f	\N
127490	ventilatsiooni	ventilatsiooni =ventilatsiooni  (SgG  >ventilatsioon !22_S	et	f	\N
127491	ventilatsiooni	ventilatsiooni =ventilatsiooni  (SgP  >ventilatsioon !22_S	et	f	\N
127492	ventilatsiooni	ventilatsiooni =ventilatsiooni  (SgAdt  >ventilatsioon !22_S	et	f	\N
127506	aeda	aeda =aeda  (SgP  >aed !22_S	et	f	\N
127507	aeda	aeda =aeda  (SgAdt  >aed !22_S	et	f	\N
127508	kauplustele	kauplustele =kauplus  (PlAll  >kauplus !11~09_S	et	f	\N
127509	kauplustele	kauplustele =luste  (SgAll  >kaup+luste !06_S	et	f	\N
127510	kauplustele	kauplustele =luste  (PlAll  >kaup+lust !22_S	et	f	\N
127511	citymarkest	?citymarkest =citymarkes  (SgP  >citymarkene !12_S	et	f	\N
127543	vajaks	vajaks =vaja  (SgTr  >vaja !17_S	et	f	\N
127544	vajaks	vajaks =vaja  (KndPrPs  >vajama !27_V	et	f	\N
127555	teenindusega	teenindusega =teeninduse  (SgKom  >teenindus !11_S	et	f	\N
127556	teenindusega	"teenindus %teeninda  )US_vS  <teenindama ;27_V	et	f	\N
127568	kodulinna	kodulinna =linna  (SgG  >kodu+linn !22_S	et	f	\N
127569	kodulinna	kodulinna =linna  (SgP  >kodu+linn !22_S	et	f	\N
127570	kodulinna	kodulinna =linna  (SgAdt  >kodu+linn !22_S	et	f	\N
127588	tootan	?tootan =toota  (IndPrSg1  >tootama !27_V	et	f	\N
127589	tootan	?tootan =tootan  (SgN  >tootan !02_S	et	f	\N
127590	suurepärased	suurepärased =pärase  (PlN  >suure+pärane !10_A	et	f	\N
127591	suurepärased	"suure+pärane %pära  )NE_aA  <suure+pära ;17_S	et	f	\N
127592	lähe	lähe =lähe  (IndPrPs_  >minema !36_V	et	f	\N
127593	lähe	lähe =lähe  (SgN  >lähe !06_S	et	f	\N
127606	negativne	?negativne =negativne  (SgN  >negativne !02_A	et	f	\N
127607	negativne	?negativne =negativne  (PlP  >negativn !22_S	et	f	\N
127620	astumise	astumise =astumise  (SgG  >astumine !12_S	et	f	\N
127621	astumise	"astumine %astu  )MINE_vS  <astuma ;28_V	et	f	\N
127624	laagna	?laagna =laagna  (SgN  >laagna !01_S	et	f	\N
127625	laagna	?laagna =laagna  (SgG  >laagna !01_S	et	f	\N
127627	laagna	?laagna =laagna  (IndPrPs_  >laagnama !29_V	et	f	\N
127628	laagna	?laagna =laagna  (ImpPrSg2  >laagnama !29_V	et	f	\N
127649	jööksul	?jööksul =jööksu  (SgAd  >jööksu !01_S	et	f	\N
127266	varres	varres =varre  (PlIn  >varr !22_S	et	f	\N
127295	elukoha	elukoha =koha  (SgN  >elu+koha !17_S	et	f	\N
127296	elukoha	elukoha =koha  (SgG  >elu+koha !17_S	et	f	\N
127297	elukoha	elukoha =koha  (SgG  >elu+koht !22_S	et	f	\N
127298	elukoha	elukoha =koha  (SgP  >elu+koha !17_S	et	f	\N
127299	eramaja	eramaja =maja  (SgN  >era+maja !17_S	et	f	\N
127300	eramaja	eramaja =maja  (SgG  >era+maja !17_S	et	f	\N
127301	eramaja	eramaja =maja  (SgP  >era+maja !17_S	et	f	\N
127303	nabrid	?nabrid =nabri  (PlN  >nabri !16_S	et	f	\N
127304	nabrid	?nabrid =nabri  (IndPrSg2  >nabrima !27_V	et	f	\N
127305	nabrid	?nabrid =nabri  (IndPrSg2  >naprima !28_V	et	f	\N
127313	käimine	käimine =käimine  (SgN  >käimine !12?10_S	et	f	\N
127314	käimine	"käimine %käi  )MINE_vS  <käima ;38_V	et	f	\N
127315	käimine	"käimine %käimi  )NE_aA  <käim ;22_S	et	f	\N
127329	maitsvam	maitsvam =maitsvam  (SgN  >maitsvam !02_A	et	f	\N
127330	maitsvam	"maitsvam %maits  )VAM_cA  <maitsma ;32_V	et	f	\N
127331	maitsvam	"maitsvam %maitsva  )M_cA  <maitsev ;02_A	et	f	\N
127337	ööeldes	?ööeldes =elde  (SgIn  >öö+elle !06_S	et	f	\N
127338	ööeldes	?ööeldes =elde  (PlIn  >öö+elt !22_S	et	f	\N
127339	ööeldes	?ööeldes =eldes  (SgN  >öö+eldes !09_S	et	f	\N
127384	banaani	banaani =banaani  (SgG  >banaan !22_S	et	f	\N
127385	banaani	banaani =banaani  (SgP  >banaan !22_S	et	f	\N
127386	banaani	banaani =banaani  (SgAdt  >banaan !22_S	et	f	\N
127443	müüjad	müüjad =müüja  (PlN  >müüja !01_S	et	f	\N
127444	müüjad	"müüja %müü  )JA_vS  <müüma ;38_V	et	f	\N
127445	lõpetuseks	lõpetuseks =lõpetuse  (SgTr  >lõpetus !11_S	et	f	\N
127446	lõpetuseks	"lõpetus %lõpeta  )US_vS  <lõpetama ;27_V	et	f	\N
127447	lõpetuseks	"lõpetus %lõpe  )TUS1_aS  <lõppema ;28_V	et	f	\N
127448	lõpetuseks	"lõpetus %lõpe  )TUS1_aS  <lõpma ;35_V	et	f	\N
127450	populaarsus	populaarsus =populaarsus  (SgN  >populaarsus !11~09_S	et	f	\N
127451	populaarsus	"populaarsus %populaarse  )US_aS  <populaarne ;02_A	et	f	\N
127512	citymarketi	?citymarketi =citymarketi  (SgG  >citymarkett !22_S	et	f	\N
127513	citymarketi	?citymarketi =citymarketi  (IndPrPs_  >citymarkettima !28_V	et	f	\N
127514	citymarketi	?citymarketi =citymarketi  (ImpPrSg2  >citymarkettima !28_V	et	f	\N
127526	parkla	parkla =parkla  (SgN  >parkla !01_S	et	f	\N
127527	parkla	parkla =parkla  (SgG  >parkla !01_S	et	f	\N
127533	õhtudel	### õhtudel	et	f	\N
127542	pikkad	?pikkad =pikka  (IndPrSg2  >pikkama !29_V	et	f	\N
127557	põhjamaal	põhjamaal =maa  (SgAd  >põhja+maa !26_S	et	f	\N
127558	põhjamaal	põhjamaal =maal  (SgN  >põhja+maal !22_S	et	f	\N
127571	töötanud	töötanud =tööta  (PtsPtPs  >töötama !27_V	et	f	\N
127572	töötanud	töötanud =töötanu  (PlN  >töötanu !01_S	et	f	\N
127573	töötanud	"töötanu %tööta  )NU_vS  <töötama ;27_V	et	f	\N
127574	töötanud	töötanud =töötanud  (ID  >töötanud !41_A	et	f	\N
127575	töötanud	"töötanud %tööta  )NUD_vA  <töötama ;27_V	et	f	\N
127576	töötanud	töötanud =tanu  (PlN  >töö+tanu !17_S	et	f	\N
127596	kautasin	?kautasin =kauta  (IndIpfSg1  >kautama !27_V	et	f	\N
127597	kautasin	?kautasin =kautasin  (SgN  >kautasin !19_S	et	f	\N
127602	nõusi	?nõusi =nõusi  (SgN  >nõusi !16_S	et	f	\N
127603	nõusi	?nõusi =nõusi  (SgG  >nõusi !16_S	et	f	\N
127604	nõusi	?nõusi =nõusi  (IndPrPs_  >nõusima !28_V	et	f	\N
127605	nõusi	?nõusi =nõusi  (ImpPrSg2  >nõusima !28_V	et	f	\N
127622	teisesse	teisesse =teise  (SgIll  >teine !12_OP	et	f	\N
127623	teisesse	teisesse =teise  (SgIll  >teise !12_P	et	f	\N
127651	pahad	pahad =paha  (PlN  >paha !17_AS	et	f	\N
127652	pahad	pahad =paha  (PlN  >pahk !22_S	et	f	\N
127655	mälus	mälus =mälu  (SgIn  >mälu !17_S	et	f	\N
127656	mälus	mälus =mälu  (IndIpfSg3  >mäluma !27_V	et	f	\N
127666	pahast	pahast =paha  (SgEl  >paha !17_AS	et	f	\N
127668	pahast	pahast =paha  (SgEl  >pahk !22_S	et	f	\N
127669	pahast	pahast =pahas  (SgP  >pahane !10_A	et	f	\N
127670	pahast	"pahane %paha  )NE_aA  <pahk ;22_S	et	f	\N
127687	abielus	abielus =elu  (SgIn  >abi+elu !17_S	et	f	\N
127688	abielus	abielus =elus  (SgN  >abi+elus !02_A	et	f	\N
127691	hoidamise	?hoidamise =hoidamise  (SgG  >hoidamine !12_S	et	f	\N
127715	mikrorajoonis	mikrorajoonis =rajooni  (SgIn  >mikro+rajoon !22_S	et	f	\N
127716	mikrorajoonis	mikrorajoonis =rajooni  (IndIpfSg3  >mikro+rajoonima !28_V	et	f	\N
127750	seisukoras	?seisukoras =seisukora  (SgIn  >seisukora !16_S	et	f	\N
127751	seisukoras	?seisukoras =kora  (SgIn  >seisu+kora !17_S	et	f	\N
127752	seisukoras	?seisukoras =koras  (SgN  >seisu+koras !09_S	et	f	\N
127773	transportimine	transportimine =transportimine  (SgN  >transportimine !12_S	et	f	\N
127775	transportimine	"transportimine %transporti  )MINE_vS  <transportima ;28_V	et	f	\N
127781	germani	?germani =germa  (SgTer  >germa !16_S	et	f	\N
127782	germani	?germani =germani  (SgG  >german !02_S	et	f	\N
127783	müra	müra =müra  (SgN  >müra !17_S	et	f	\N
127784	müra	müra =müra  (SgG  >müra !17_S	et	f	\N
127785	müra	müra =müra  (SgP  >müra !17_S	et	f	\N
127786	müra	müra =müra  (IndPrPs_  >mürama !27_V	et	f	\N
127475	kauplemine	"kauplemine %kauple  )MINE_vS  <kauplema ;30_V	et	f	\N
127493	jatkuda	?jatkuda =jatku  (Inf  >jatkuma !27_V	et	f	\N
127498	külastamist	külastamist =külastamis  (SgP  >külastamine !12_S	et	f	\N
127499	külastamist	"külastamine %külasta  )MINE_vS  <külastama ;27_V	et	f	\N
127530	ostukorvi	ostukorvi =korvi  (SgG  >ostu+korv !22_S	et	f	\N
127531	ostukorvi	ostukorvi =korvi  (SgP  >ostu+korv !22_S	et	f	\N
127532	ostukorvi	ostukorvi =korvi  (SgAdt  >ostu+korv !22_S	et	f	\N
127559	huvitavaks	huvitavaks =huvitava  (SgTr  >huvitav !02_A	et	f	\N
127560	huvitavaks	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
127561	huvitavaks	huvitavaks =tava  (SgTr  >huvi+tava !17_S	et	f	\N
127594	tragiline	tragiline =tragiline  (SgN  >tragiline !12_A	et	f	\N
127595	tragiline	"tragiline %tragi  )LINE_aA  <tragi ;17_SA	et	f	\N
127610	lahkumine	lahkumine =lahkumine  (SgN  >lahkumine !12_S	et	f	\N
127611	lahkumine	"lahkumine %lahku  )MINE_vS  <lahkuma ;27_V	et	f	\N
127616	kavatse	kavatse =kavatse  (IndPrPs_  >kavatsema !27_V	et	f	\N
127617	kavatse	kavatse =kavatse  (ImpPrSg2  >kavatsema !27_V	et	f	\N
127618	kooliaasta	kooliaasta =aasta  (SgN  >kooli+aasta !01_S	et	f	\N
127619	kooliaasta	kooliaasta =aasta  (SgG  >kooli+aasta !01_S	et	f	\N
127626	gümnaasiuum	?gümnaasiuum =gümnaasiuum  (SgN  >gümnaasiuum !22_S	et	f	\N
127629	mõtelnud	mõtelnud =mõtel  (PtsPtPs  >mõtlema !30_V	et	f	\N
127630	mõtelnud	mõtelnud =mõtelnu  (PlN  >mõtelnu !01_S	et	f	\N
127631	mõtelnud	"mõtelnu %mõtel  )NU_vS  <mõtlema ;30_V	et	f	\N
127632	mõtelnud	mõtelnud =mõtelnud  (ID  >mõtelnud !41_A	et	f	\N
127633	mõtelnud	"mõtelnud %mõtel  )NUD_vA  <mõtlema ;30_V	et	f	\N
127634	instrumenti	instrumenti =instrumenti  (SgP  >instrument !22_S	et	f	\N
127635	instrumenti	instrumenti =instrumenti  (SgAdt  >instrument !22_S	et	f	\N
127662	positivseid	?positivseid =positivse  (PlP  >positivne !02_A	et	f	\N
127663	positivseid	?positivseid =positivsei  (PlN  >positivsei !26_S	et	f	\N
127664	positivseid	?positivseid =positivsei  (SgP  >positivsei !26_S	et	f	\N
127671	solvatav	solvatav =solva  (PtsPrIps  >solvama !29_V	et	f	\N
127672	solvatav	solvatav =solvatav  (SgN  >solvatav !02_A	et	f	\N
127673	solvatav	"solvatav %solva  )TAV_vAS  <solvama ;29_V	et	f	\N
127685	toaline	toaline =toaline  (SgN  >toaline !12?10_A	et	f	\N
127686	toaline	"toaline %toa  )LINE_aA  <tuba ;18_S	et	f	\N
127703	valvamisest	valvamisest =valvamise  (SgEl  >valvamine !12_S	et	f	\N
127704	valvamisest	"valvamine %valva  )MINE_vS  <valvama ;29_V	et	f	\N
127718	kaugel	kaugel =kauge  (SgAd  >kauge !01_A	et	f	\N
127719	kaugel	kaugel =kaugel  (ID  >kaugel !41_D	et	f	\N
127727	peatust	peatust =peatu  (SgEl  >peatu !01_A	et	f	\N
127728	peatust	"peatu %pea  )TU2_kA  <pea ;26_S	et	f	\N
127729	peatust	peatust =peatus  (SgP  >peatus !11~09_S	et	f	\N
127730	peatust	"peatus %peata  )US_vS  <peatama ;27_V	et	f	\N
127731	peatust	"peatus %pea  )TUS2_aS  <pea ;26_S	et	f	\N
127732	peatust	peatust =tust  (SgN  >pea+tust !22_S	et	f	\N
127734	maasti	?maasti =maasti  (ID  >maasti !41_D	et	f	\N
127736	maasti	?maasti =maasti  (SgG  >maast !22_S	et	f	\N
127737	maasti	?maasti =maasti  (SgP  >maast !22_S	et	f	\N
127738	maasti	?maasti =maasti  (SgAdt  >maast !22_S	et	f	\N
127739	maasti	?maasti =maasti  (IndPrPs_  >maastima !28_V	et	f	\N
127740	maasti	?maasti =maasti  (ImpPrSg2  >maastima !28_V	et	f	\N
127741	trepikoda	trepikoda =koda  (SgN  >trepi+koda !18_S	et	f	\N
127742	trepikoda	trepikoda =koda  (SgP  >trepi+koda !18_S	et	f	\N
127754	kaugus	kaugus =kaugu  (IndIpfSg3  >kauguma !27_V	et	f	\N
127757	kaugus	kaugus =kaugus  (SgN  >kaugus !11~09_S	et	f	\N
127758	kaugus	"kaugus %kauge  )US_aS  <kauge ;01_A	et	f	\N
127769	soojaks	soojaks =sooja  (SgTr  >soe !24_AS	et	f	\N
127770	soojaks	soojaks =jaks  (SgN  >soo+jaks !22_S	et	f	\N
127771	möbli	?möbli =möbli  (SgN  >möbli !16_S	et	f	\N
127772	möbli	?möbli =möbli  (SgG  >möbli !16_S	et	f	\N
127774	möbli	?möbli =möbli  (SgP  >möbl !22_S	et	f	\N
127776	möbli	?möbli =möbli  (SgAdt  >möbl !22_S	et	f	\N
127777	möbli	?möbli =möbli  (IndPrPs_  >möblima !27_V	et	f	\N
127778	möbli	?möbli =möbli  (IndPrPs_  >möplima !28_V	et	f	\N
127779	möbli	?möbli =möbli  (ImpPrSg2  >möblima !27_V	et	f	\N
127780	möbli	?möbli =möbli  (ImpPrSg2  >möplima !28_V	et	f	\N
127788	küllastajad	küllastajad =küllastaja  (PlN  >küllastaja !01_S	et	f	\N
127789	küllastajad	"küllastaja %küllasta  )JA_vS  <küllastama ;27_V	et	f	\N
127806	koridoori	?koridoori =koridoori  (SgN  >koridoori !16_S	et	f	\N
127807	koridoori	?koridoori =koridoori  (SgG  >koridoori !16_S	et	f	\N
127808	koridoori	?koridoori =koridoori  (SgG  >koridoor !22_S	et	f	\N
127809	koridoori	?koridoori =koridoori  (SgP  >koridoor !22_S	et	f	\N
127810	koridoori	?koridoori =koridoori  (SgAdt  >koridoor !22_S	et	f	\N
127811	koridoori	?koridoori =koridoori  (IndPrPs_  >koridoorima !28_V	et	f	\N
127812	koridoori	?koridoori =koridoori  (ImpPrSg2  >koridoorima !28_V	et	f	\N
127824	wc	### wc	et	f	\N
127828	paremale	paremale =parema  (SgAll  >parem !02_A	et	f	\N
127829	paremale	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
127830	paremale	paremale =paremale  (ID  >paremale !41_D	et	f	\N
127496	autoparkla	autoparkla =parkla  (SgN  >auto+parkla !01_S	et	f	\N
127497	autoparkla	autoparkla =parkla  (SgG  >auto+parkla !01_S	et	f	\N
127500	kaubanduskeskuste	kaubanduskeskuste =us  (PlG  >kaubandus+kesk+uks !14_S	et	f	\N
127501	kaubanduskeskuste	kaubanduskeskuste =keskus  (PlG  >kaubandus+keskus !11~09_S	et	f	\N
127504	joogid	joogid =joogi  (PlN  >joogi !16_S	et	f	\N
127505	joogid	joogid =joogi  (PlN  >jook !22_S	et	f	\N
127518	ülimatu	?ülimatu =ülimatu  (SgN  >ülimatu !01_A	et	f	\N
127519	ülimatu	?ülimatu =ülimatu  (SgG  >ülimatu !01_A	et	f	\N
127520	ülimatu	?ülimatu =ülimatu  (IndPrPs_  >ülimatuma !27_V	et	f	\N
127521	ülimatu	?ülimatu =ülimatu  (ImpPrSg2  >ülimatuma !27_V	et	f	\N
127523	ülimatu	?ülimatu =matu  (SgN  >üli+matu !16_S	et	f	\N
127525	ülimatu	?ülimatu =matu  (SgG  >üli+matu !16_S	et	f	\N
127534	võimalda	võimalda =võimalda  (IndPrPs_  >võimaldama !27_V	et	f	\N
127535	võimalda	võimalda =võimalda  (ImpPrSg2  >võimaldama !27_V	et	f	\N
127536	pettumuse	pettumuse =pettumuse  (SgG  >pettumus !11_S	et	f	\N
127537	pettumuse	"pettumus %pettu  )MUS_vS  <pettuma ;27_V	et	f	\N
127538	soodustusi	soodustusi =soodustusi  (PlP  >soodustus !11_S	et	f	\N
127539	soodustusi	"soodustus %soodusta  )US_vS  <soodustama ;27_V	et	f	\N
127545	kaubamaja	kaubamaja =maja  (SgN  >kauba+maja !17_S	et	f	\N
127546	kaubamaja	kaubamaja =maja  (SgG  >kauba+maja !17_S	et	f	\N
127547	kaubamaja	kaubamaja =maja  (SgP  >kauba+maja !17_S	et	f	\N
127548	butikkega	### butikkega	et	f	\N
127551	butik	?butik =butik  (SgN  >butik !02_S	et	f	\N
127553	proovimist	proovimist =proovimis  (SgP  >proovimine !12_S	et	f	\N
127554	proovimist	"proovimine %proovi  )MINE_vS  <proovima ;28_V	et	f	\N
127566	algklassiõpetaja	algklassiõpetaja =õpetaja  (SgN  >alg+klassi+õpetaja !01_S	et	f	\N
127567	algklassiõpetaja	algklassiõpetaja =õpetaja  (SgG  >alg+klassi+õpetaja !01_S	et	f	\N
127583	pojal	pojal =poja  (SgAd  >poja !17_S	et	f	\N
127584	pojal	pojal =poja  (SgAd  >poeg !22_S	et	f	\N
127585	se	### se	et	f	\N
127598	jatku	?jatku =jatku  (SgN  >jatku !16_S	et	f	\N
127599	jatku	?jatku =jatku  (SgG  >jatku !16_S	et	f	\N
127600	jatku	?jatku =jatku  (IndPrPs_  >jatkuma !27_V	et	f	\N
127601	jatku	?jatku =jatku  (ImpPrSg2  >jatkuma !27_V	et	f	\N
127608	monent	?monent =monent  (SgN  >monent !22_S	et	f	\N
127643	tpusse	?tpusse =tpusse  (SgN  >tpusse !06_S	et	f	\N
127644	tpusse	?tpusse =tpusse  (SgG  >tpusne !02_A	et	f	\N
127645	tpusse	?tpusse =tpusse  (SgG  >tpusse !06_S	et	f	\N
127646	tpusse	?tpusse =tpusse  (PlP  >tpuss !22_S	et	f	\N
127647	tpusse	?tpusse =tpusse  (IndPrPs_  >tpussema !27_V	et	f	\N
127648	tpusse	?tpusse =tpusse  (ImpPrSg2  >tpussema !27_V	et	f	\N
127674	nuttasin	?nuttasin =nutta  (IndIpfSg1  >nuttama !29_V	et	f	\N
127675	nuttasin	?nuttasin =nuttasin  (SgN  >nuttasin !19_S	et	f	\N
127676	reeageris	?reeageris =reeageri  (SgIn  >reeager !02_S	et	f	\N
127677	reeageris	?reeageris =reeageris  (SgN  >reeageris !09_S	et	f	\N
127678	reeageris	?reeageris =ageri  (SgIn  >ree+ageri !01_S	et	f	\N
127679	reeageris	?reeageris =ageri  (SgIn  >ree+ager !02_S	et	f	\N
127680	reeageris	?reeageris =ageris  (SgN  >ree+ageris !11_S	et	f	\N
127689	poeglaps	poeglaps =laps  (SgN  >poeg+laps !14_S	et	f	\N
127690	poeglaps	poeglaps =laps  (SgN  >poeg+laps !22_S	et	f	\N
127692	homikust	?homikust =homiku  (SgEl  >homiku !01_S	et	f	\N
127693	homikust	?homikust =homiku  (SgEl  >homik !02_S	et	f	\N
127694	homikust	?homikust =homikus  (SgP  >homikus !11_S	et	f	\N
127705	käja	?käja =käja  (SgN  >käja !17_S	et	f	\N
127706	käja	?käja =käja  (SgG  >käja !17_S	et	f	\N
127707	käja	?käja =käja  (SgP  >käja !17_S	et	f	\N
127708	käja	?käja =käja  (IndPrPs_  >käjama !27_V	et	f	\N
127709	käja	?käja =käja  (ImpPrSg2  >käjama !27_V	et	f	\N
127713	terveks	terveks =terve  (SgTr  >terve !01_AS	et	f	\N
127714	terveks	terveks =terve  (SgTr  >terve !06_AS	et	f	\N
127733	üheksakorruseline	üheksakorruseline =korruseline  (SgN  >üheksa+korruseline !12_A	et	f	\N
127735	üheksakorruseline	"üheksa+korruseline %korruse  )LINE_aA  <üheksa+korrus ;09_S	et	f	\N
127753	peatuste	peatuste =peatus  (PlG  >peatus !11~09_S	et	f	\N
127755	peatuste	"peatus %peata  )US_vS  <peatama ;27_V	et	f	\N
127756	peatuste	"peatus %pea  )TUS2_aS  <pea ;26_S	et	f	\N
127759	peatuste	peatuste =tuste  (PlP  >pea+tust !22_S	et	f	\N
127795	suurusega	suurusega =suuruse  (SgKom  >suurus !11~09_S	et	f	\N
127796	suurusega	"suurus %suur  )US_aS  <suur ;13_A	et	f	\N
127797	suurusega	suurusega =suuruse  (SgKom  >suurune !10~12_A	et	f	\N
127821	kak	### kak	et	f	\N
127822	vannituba	vannituba =tuba  (SgN  >vanni+tuba !18_S	et	f	\N
127823	vannituba	vannituba =tuba  (SgP  >vanni+tuba !18_S	et	f	\N
127825	tavalisemad	tavalisemad =tavalisema  (PlN  >tavalisem !02_A	et	f	\N
127826	tavalisemad	"tavalisem %tava  )LISEM_cA  <tava ;17_S	et	f	\N
127827	tavalisemad	"tavalisem %tavalise  )M_cA  <tavaline ;12_A	et	f	\N
127843	neljale	neljale =nelja  (SgAll  >neljas !02_O	et	f	\N
127844	neljale	neljale =nelja  (SgAll  >neli !24_N	et	f	\N
127867	korterierat	?korterierat =korteriera  (SgP  >korteriera !16_S	et	f	\N
127581	sündmine	?sündmine =sündmine  (IndPrPs_  >sündminema !27_V	et	f	\N
127582	sündmine	?sündmine =sündmine  (ImpPrSg2  >sündminema !27_V	et	f	\N
127586	saabimine	?saabimine =saabimine  (SgN  >saabimine !12_S	et	f	\N
127587	saabimine	?saabimine =saabimine  (PlP  >saabimin !19_S	et	f	\N
127609	esimise	?esimise =esimise  (SgG  >esimine !12_S	et	f	\N
127612	õpimisega	?õpimisega =õpimise  (SgKom  >õpimine !12_S	et	f	\N
127613	vahe	vahe =vahe  (SgN  >vahe !02_A	et	f	\N
127614	vahe	vahe =vahe  (SgN  >vahe !16_S	et	f	\N
127615	vahe	vahe =vahe  (SgG  >vahe !16_S	et	f	\N
127636	soovitajate	soovitajate =soovitaja  (PlG  >soovitaja !01_S	et	f	\N
127637	soovitajate	"soovitaja %soovita  )JA_vS  <soovitama ;27_V	et	f	\N
127638	ahastanud	ahastanud =ahasta  (PtsPtPs  >ahastama !27_V	et	f	\N
127639	ahastanud	ahastanud =ahastanu  (PlN  >ahastanu !01_S	et	f	\N
127640	ahastanud	"ahastanu %ahasta  )NU_vS  <ahastama ;27_V	et	f	\N
127641	ahastanud	ahastanud =ahastanud  (ID  >ahastanud !41_A	et	f	\N
127642	ahastanud	"ahastanud %ahasta  )NUD_vA  <ahastama ;27_V	et	f	\N
127657	igaveseks	igaveseks =igavese  (SgTr  >igavene !12_A	et	f	\N
127658	igaveseks	igaveseks =igaveseks  (ID  >igaveseks !41_D	et	f	\N
127681	näitusele	näitusele =näituse  (SgAll  >näitus !11~09_S	et	f	\N
127682	näitusele	näitusele =use  (PlAll  >näit+usk !22_S	et	f	\N
127710	pojaga	pojaga =poja  (SgKom  >poja !17_S	et	f	\N
127711	pojaga	pojaga =poja  (SgKom  >poeg !22_S	et	f	\N
127712	ramatut	?ramatut =ramatu  (SgP  >ramatu !01_A	et	f	\N
127717	lasnamä	### lasnamä	et	f	\N
127720	bissi	?bissi =bissi  (SgN  >bissi !16_S	et	f	\N
127721	bissi	?bissi =bissi  (SgG  >bissi !16_S	et	f	\N
127722	bissi	?bissi =bissi  (SgG  >biss !22_S	et	f	\N
127723	bissi	?bissi =bissi  (SgP  >biss !22_S	et	f	\N
127724	bissi	?bissi =bissi  (SgAdt  >biss !22_S	et	f	\N
127725	bissi	?bissi =bissi  (IndPrPs_  >bissima !28_V	et	f	\N
127726	bissi	?bissi =bissi  (ImpPrSg2  >bissima !28_V	et	f	\N
127743	buside	?buside =busi  (PlG  >busi !17_S	et	f	\N
127760	kompenseeritud	kompenseeritud =kompenseeri  (PtsPtIps  >kompenseerima !28_V	et	f	\N
127761	kompenseeritud	kompenseeritud =kompenseeritu  (PlN  >kompenseeritu !01_S	et	f	\N
127762	kompenseeritud	"kompenseeritu %kompenseeri  )TU1_vS  <kompenseerima ;28_V	et	f	\N
127763	kompenseeritud	kompenseeritud =kompenseeritud  (ID  >kompenseeritud !41_A	et	f	\N
127764	kompenseeritud	"kompenseeritud %kompenseeri  )TUD_vA  <kompenseerima ;28_V	et	f	\N
127766	tellishoones	tellishoones =hoone  (SgIn  >tellis+hoone !06_S	et	f	\N
127767	tellishoones	"tellis+hoone %hoo  )NE_aA  <tellis+hoog ;22_S	et	f	\N
127768	tellishoones	tellishoones =hoone  (PlIn  >tellis+hoon !22_A	et	f	\N
127800	eluruumi	eluruumi =ruumi  (SgG  >elu+ruum !22_S	et	f	\N
127801	eluruumi	eluruumi =ruumi  (SgP  >elu+ruum !22_S	et	f	\N
127802	eluruumi	eluruumi =ruumi  (SgAdt  >elu+ruum !22_S	et	f	\N
127813	koridooris	?koridooris =koridoori  (SgIn  >koridoori !16_S	et	f	\N
127814	koridooris	?koridooris =koridoori  (SgIn  >koridoor !22_S	et	f	\N
127815	koridooris	?koridooris =koridoori  (IndIpfSg3  >koridoorima !28_V	et	f	\N
127816	koridooris	?koridooris =koridooris  (SgN  >koridooris !09_S	et	f	\N
127835	pantud	?pantud =pantu  (PlN  >pantu !16_S	et	f	\N
127836	pantud	?pantud =pantu  (IndPrSg2  >pantuma !27_V	et	f	\N
127837	pantud	?pantud =pantud  (ID  >pantud !41_A	et	f	\N
127845	remonteeritud	?remonteeritud =remonteeri  (PtsPtIps  >remonteerima !28_V	et	f	\N
127846	remonteeritud	?remonteeritud =remonteeritu  (PlN  >remonteeritu !01_S	et	f	\N
127847	remonteeritud	?remonteeritud =remonteeritu  (IndPrSg2  >remonteerituma !27_V	et	f	\N
127848	remonteeritud	?remonteeritud =remonteeritud  (ID  >remonteeritud !41_A	et	f	\N
127849	remonteeritud	?remonteeritud =eeritu  (PlN  >remont+eeritu !01_AS	et	f	\N
127853	meenuta	meenuta =meenu  (IndPrIps_  >meenuma !27_V	et	f	\N
127854	meenuta	meenuta =meenuta  (IndPrPs_  >meenutama !27_V	et	f	\N
127855	meenuta	meenuta =meenuta  (ImpPrSg2  >meenutama !27_V	et	f	\N
127873	alt	alt =alt  (ID  >alt !41_DK	et	f	\N
127874	alt	alt =alt  (SgN  >alt !22_S	et	f	\N
127887	tikkud	### tikkud	et	f	\N
127933	kaitstud	kaitstud =kaits  (PtsPtIps  >kaitsma !32_V	et	f	\N
127934	kaitstud	kaitstud =kaitstu  (PlN  >kaitstu !01_S	et	f	\N
127935	kaitstud	"kaitstu %kaits  )TU1_vS  <kaitsma ;32_V	et	f	\N
127936	kaitstud	kaitstud =kaitstud  (ID  >kaitstud !41_A	et	f	\N
127937	kaitstud	"kaitstud %kaits  )TUD_vA  <kaitsma ;32_V	et	f	\N
127943	halva	halva =halva  (SgG  >halb !22_A	et	f	\N
127944	halva	halva =halva  (IndPrPs_  >halvama !29_V	et	f	\N
127945	halva	halva =halva  (ImpPrSg2  >halvama !29_V	et	f	\N
127946	kiirem	kiirem =kiirem  (SgN  >kiirem !02_A	et	f	\N
127947	kiirem	"kiirem %kiire  )M_cA  <kiire ;01_A	et	f	\N
127948	kiirem	"kiirem %kiire  )M_cA  <kiire ;06_AS	et	f	\N
127960	kahetoalises	kahetoalises =toalise  (SgIn  >kahe+toaline !12?10_A	et	f	\N
127961	kahetoalises	"kahe+toaline %toa  )LINE_aA  <kahe+tuba ;18_S	et	f	\N
127989	petakse	?petakse =petakse  (SgG  >petakne !02_A	et	f	\N
127990	omatakse	omatakse =oma  (IndPrIps  >omama !27_V	et	f	\N
127991	omatakse	omatakse =takse  (PlP  >oma+taks !22_S	et	f	\N
127650	jööksul	?jööksul =jööksul  (SgN  >jööksul !02_S	et	f	\N
127653	mäletagi	mäletagi =mäleta  (IndPrPs_^  >mäletama !27_V	et	f	\N
127654	mäletagi	mäletagi =mäleta  (ImpPrSg2^  >mäletama !27_V	et	f	\N
127659	negativseid	?negativseid =negativse  (PlP  >negativne !02_A	et	f	\N
127660	negativseid	?negativseid =negativsei  (PlN  >negativsei !26_S	et	f	\N
127661	negativseid	?negativseid =negativsei  (SgP  >negativsei !26_S	et	f	\N
127665	reeageresin	?reeageresin =reeageresin  (SgN  >reeageresin !19_S	et	f	\N
127667	reeageresin	?reeageresin =ageresin  (SgN  >ree+ageresin !19_S	et	f	\N
127683	õetütra	?õetütra =õetütra  (SgN  >õetütra !01_S	et	f	\N
127684	õetütra	?õetütra =õetütra  (SgG  >õetütra !01_S	et	f	\N
127695	kallale	kallale =kalla  (SgAll  >kalla !16_S	et	f	\N
127696	kallale	kallale =kallale  (ID  >kallale !41_DK	et	f	\N
127697	turva	turva =turva  (SgG  >turb !22_SA	et	f	\N
127698	turva	turva =turva  (SgG  >turv !22_S	et	f	\N
127699	turva	turva =turva  (SgP  >turv !22_S	et	f	\N
127700	turva	turva =turva  (SgAdt  >turv !22_S	et	f	\N
127701	turva	turva =turva  (IndPrPs_  >turvama !29_V	et	f	\N
127702	turva	turva =turva  (ImpPrSg2  >turvama !29_V	et	f	\N
127744	peatustele	peatustele =peatus  (PlAll  >peatus !11~09_S	et	f	\N
127745	peatustele	"peatus %peata  )US_vS  <peatama ;27_V	et	f	\N
127746	peatustele	"peatus %pea  )TUS2_aS  <pea ;26_S	et	f	\N
127747	peatustele	peatustele =tuste  (PlAll  >pea+tust !22_S	et	f	\N
127748	halvas	halvas =halva  (SgIn  >halb !22_A	et	f	\N
127749	halvas	halvas =halva  (IndIpfSg3  >halvama !29_V	et	f	\N
127765	treppikoda	### treppikoda	et	f	\N
127790	võõraste	võõraste =võõras  (PlG  >võõras !07_AS	et	f	\N
127791	võõraste	võõraste =aste  (SgN  >võõr+aste !05_S	et	f	\N
127792	võõraste	võõraste =aste  (SgN  >võõr+aste !06_S	et	f	\N
127793	võõraste	võõraste =aste  (SgG  >võõr+aste !06_S	et	f	\N
127794	võõraste	võõraste =aste  (PlP  >võõr+ast !22_S	et	f	\N
127798	vasakule	vasakule =vasaku  (SgAll  >vasak !02_A	et	f	\N
127799	vasakule	vasakule =vasakule  (ID  >vasakule !41_D	et	f	\N
127833	magamistuba	magamistuba =tuba  (SgN  >magamis+tuba !18_S	et	f	\N
127834	magamistuba	magamistuba =tuba  (SgP  >magamis+tuba !18_S	et	f	\N
127838	toonides	toonides =tooni  (PlIn  >toon !22_S	et	f	\N
127839	toonides	toonides =tooni  (Ger  >toonima !28_V	et	f	\N
127840	rõdu	rõdu =rõdu  (SgN  >rõdu !17_S	et	f	\N
127841	rõdu	rõdu =rõdu  (SgG  >rõdu !17_S	et	f	\N
127842	rõdu	rõdu =rõdu  (SgP  >rõdu !17_S	et	f	\N
127850	pealinnasse	pealinnasse =asse  (PlP  >pea+linn+ass !22_S	et	f	\N
127851	pealinnasse	pealinnasse =inna  (SgIll  >peal+ind !22_S	et	f	\N
127852	pealinnasse	pealinnasse =linna  (SgIll  >pea+linn !22_S	et	f	\N
127863	müüra	?müüra =müüra  (SgN  >müüra !16_S	et	f	\N
127864	müüra	?müüra =müüra  (SgG  >müüra !16_S	et	f	\N
127865	müüra	?müüra =müüra  (IndPrPs_  >müürama !29_V	et	f	\N
127866	müüra	?müüra =müüra  (ImpPrSg2  >müürama !29_V	et	f	\N
127878	kuulavad	kuulavad =kuula  (IndPrPl3  >kuulama !29_V	et	f	\N
127879	kuulavad	kuulavad =kuulava  (PlN  >kuulav !02_A	et	f	\N
127880	kuulavad	"kuulav %kuula  )V_vA  <kuulama ;29_V	et	f	\N
127881	kuulavad	kuulavad =ava  (PlN  >kuul+ava !17_S	et	f	\N
127882	kuulavad	kuulavad =lava  (PlN  >kuu+lava !17_S	et	f	\N
127895	rahast	rahast =raha  (SgEl  >raha !17_S	et	f	\N
127896	rahast	rahast =raha  (SgEl  >rahk !22_S	et	f	\N
127897	rahast	rahast =rahas  (SgP  >rahane !10_A	et	f	\N
127898	rahast	"rahane %raha  )NE_aA  <raha ;17_S	et	f	\N
127899	rahast	"rahane %raha  )NE_aA  <rahk ;22_S	et	f	\N
127908	ühetoaline	ühetoaline =toaline  (SgN  >ühe+toaline !12?10_A	et	f	\N
127909	ühetoaline	"ühe+toaline %toa  )LINE_aA  <ühe+tuba ;18_S	et	f	\N
127910	kesklinna	kesklinna =linna  (SgG  >kesk+linn !22_S	et	f	\N
127911	kesklinna	kesklinna =linna  (SgP  >kesk+linn !22_S	et	f	\N
127912	kesklinna	kesklinna =linna  (SgAdt  >kesk+linn !22_S	et	f	\N
127913	see-eest	see-eest =ee  (SgEl  >see-esi !15_S	et	f	\N
127914	see-eest	see-eest =ees  (SgP  >see-eene !10_A	et	f	\N
127915	see-eest	"see-eene %ee  )NE_aA  <see-esi ;15_S	et	f	\N
127916	see-eest	see-eest =eest  (ID  >see-eest !41_DK	et	f	\N
127917	vaikuses	vaikuses =vaikuse  (SgIn  >vaikus !11~09_S	et	f	\N
127918	vaikuses	vaikuses =use  (PlIn  >vaik+usk !22_S	et	f	\N
127919	viiekorruseline	viiekorruseline =korruseline  (SgN  >viie+korruseline !12_A	et	f	\N
127920	viiekorruseline	"viie+korruseline %korruse  )LINE_aA  <viie+korrus ;09_S	et	f	\N
127924	kottid	### kottid	et	f	\N
127928	kergenga	?kergenga =kergenga  (SgN  >kergenga !01_S	et	f	\N
127929	kergenga	?kergenga =kergenga  (SgG  >kergenga !01_S	et	f	\N
127930	kergenga	?kergenga =kergenga  (SgG  >kergengas !02_S	et	f	\N
127931	kergenga	?kergenga =enga  (SgN  >kerg+enga !16_S	et	f	\N
127932	kergenga	?kergenga =enga  (SgG  >kerg+enga !16_S	et	f	\N
127956	väielda	?väielda =väielda  (IndPrPs_  >väieldama !27_V	et	f	\N
127957	väielda	?väielda =väielda  (ImpPrSg2  >väieldama !27_V	et	f	\N
127958	väielda	?väielda =elda  (SgN  >väi+elda !16_S	et	f	\N
127959	väielda	?väielda =elda  (SgG  >väi+elda !16_S	et	f	\N
127787	müra	müra =müra  (ImpPrSg2  >mürama !27_V	et	f	\N
127803	esikust	esikust =esiku  (SgEl  >esik !02_S	et	f	\N
127804	esikust	esikust =us  (SgP  >esik+uks !14_S	et	f	\N
127805	esikust	esikust =kus  (SgP  >esi+kusi !20_S	et	f	\N
127817	sellises	sellises =sellise  (SgIn  >selline !10_P	et	f	\N
127818	sellises	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
127819	häire	häire =häire  (SgN  >häire !06_S	et	f	\N
127820	häire	häire =häire  (SgG  >häire !06_S	et	f	\N
127870	probleemi	probleemi =probleemi  (SgG  >probleem !22_S	et	f	\N
127871	probleemi	probleemi =probleemi  (SgP  >probleem !22_S	et	f	\N
127872	probleemi	probleemi =probleemi  (SgAdt  >probleem !22_S	et	f	\N
127883	koputavad	koputavad =koputa  (IndPrPl3  >koputama !27_V	et	f	\N
127884	koputavad	koputavad =koputava  (PlN  >koputav !02_A	et	f	\N
127885	koputavad	"koputav %koputa  )V_vA  <koputama ;27_V	et	f	\N
127905	korrussel	?korrussel =korrusse  (SgAd  >korrusne !02_A	et	f	\N
127906	korrussel	?korrussel =korrusse  (PlAd  >korruss !22_S	et	f	\N
127907	korrussel	?korrussel =korrussel  (SgN  >korrussel !02_S	et	f	\N
127921	lifti	lifti =lifti  (SgG  >lift !22_S	et	f	\N
127922	lifti	lifti =lifti  (SgP  >lift !22_S	et	f	\N
127923	lifti	lifti =lifti  (SgAdt  >lift !22_S	et	f	\N
127952	halvad	halvad =halva  (PlN  >halb !22_A	et	f	\N
127953	halvad	halvad =halva  (IndPrSg2  >halvama !29_V	et	f	\N
127954	soobib	?soobib =soobi  (IndPrSg3  >soobima !27_V	et	f	\N
127955	soobib	?soobib =soobi  (IndPrSg3  >soopima !28_V	et	f	\N
127964	ni	### ni	et	f	\N
127974	mailm	?mailm =mailm  (SgN  >mailm !22_S	et	f	\N
127993	rockbändis	rockbändis =bändi  (SgIn  >rock+bändi !16_S	et	f	\N
127994	rockbändis	rockbändis =bändi  (SgIn  >rock+bänd !22_S	et	f	\N
128010	kap	### kap	et	f	\N
128042	südistasin	?südistasin =südista  (IndIpfSg1  >südistama !27_V	et	f	\N
128043	südistasin	?südistasin =südistasin  (SgN  >südistasin !19_S	et	f	\N
128079	jalga	jalga =jalga  (ID  >jalga !41_D	et	f	\N
128080	jalga	jalga =jalga  (SgP  >jalg !22_S	et	f	\N
128081	jalga	jalga =jalga  (SgAdt  >jalg !22_S	et	f	\N
128091	voor	voor =voor  (SgN  >voor !13_S	et	f	\N
128092	voor	voor =voor  (SgN  >voor !22_S	et	f	\N
128116	sooritamisega	sooritamisega =sooritamise  (SgKom  >sooritamine !12_S	et	f	\N
128117	sooritamisega	"sooritamine %soorita  )MINE_vS  <sooritama ;27_V	et	f	\N
128138	telkides	telkides =telki  (PlIn  >telk !22_S	et	f	\N
128139	telkides	telkides =telki  (Ger  >telkima !28_V	et	f	\N
128160	tööt	?tööt =tööt  (SgN  >tööt !22_S	et	f	\N
128165	operatsiooni	operatsiooni =operatsiooni  (SgG  >operatsioon !22_S	et	f	\N
128166	operatsiooni	operatsiooni =operatsiooni  (SgP  >operatsioon !22_S	et	f	\N
128167	operatsiooni	operatsiooni =operatsiooni  (SgAdt  >operatsioon !22_S	et	f	\N
128168	praeguni	?praeguni =praeguni  (SgG  >praegun !02_S	et	f	\N
128169	praeguni	?praeguni =guni  (SgN  >prae+guni !17_S	et	f	\N
128170	praeguni	?praeguni =guni  (SgG  >prae+guni !17_S	et	f	\N
128171	praeguni	?praeguni =guni  (SgP  >prae+guni !17_S	et	f	\N
128216	õpetoetust	?õpetoetust =õpetoetu  (SgEl  >õpetoetu !01_A	et	f	\N
128217	õpetoetust	?õpetoetust =õpetoetus  (SgP  >õpetoetus !11~09_S	et	f	\N
128226	õpimisest	?õpimisest =õpimise  (SgEl  >õpimine !12_S	et	f	\N
128241	sarnaste	sarnaste =sarnas  (PlG  >sarnane !10_A	et	f	\N
128242	sarnaste	"sarnane %sarna  )NE_aA  <sarn ;22_S	et	f	\N
128250	selleperast	?selleperast =sellepera  (SgEl  >sellepera !16_S	et	f	\N
128251	selleperast	?selleperast =selleperas  (SgP  >selleperane !12_A	et	f	\N
128252	selleperast	?selleperast =pera  (SgEl  >selle+pera !17_S	et	f	\N
128253	selleperast	?selleperast =peras  (SgP  >selle+peras !09_S	et	f	\N
128254	selleperast	?selleperast =peras  (SgP  >selle+perane !10_A	et	f	\N
128259	üllatusi	üllatusi =üllatusi  (PlP  >üllatus !11_S	et	f	\N
128260	üllatusi	"üllatus %üllata  )US_vS  <üllatama ;27_V	et	f	\N
128262	liitusin	liitusin =liitu  (IndIpfSg1  >liituma !27_V	et	f	\N
128263	liitusin	liitusin =usin  (SgN  >liit+usin !02_A	et	f	\N
128265	korraldust	korraldust =korraldus  (SgP  >korraldus !11_S	et	f	\N
128267	korraldust	"korraldus %korralda  )US_vS  <korraldama ;27_V	et	f	\N
128278	heid	?heid =heid  (SgN  >heid !22_S	et	f	\N
128286	oskada	### oskada	et	f	\N
128304	telliskivi	telliskivi =kivi  (SgN  >tellis+kivi !17_S	et	f	\N
128305	telliskivi	telliskivi =kivi  (SgG  >tellis+kivi !17_S	et	f	\N
128306	telliskivi	telliskivi =kivi  (SgP  >tellis+kivi !17_S	et	f	\N
128307	tõlkijana	tõlkijana =tõlkija  (SgEs  >tõlkija !01_S	et	f	\N
128308	tõlkijana	"tõlkija %tõlki  )JA_vS  <tõlkima ;28_V	et	f	\N
128336	papagoi	papagoi =papagoi  (SgN  >papagoi !26_S	et	f	\N
128337	papagoi	papagoi =papagoi  (SgG  >papagoi !26_S	et	f	\N
128344	märkanud	?märkanud =märkanu  (PlN  >märkanu !01_S	et	f	\N
128345	märkanud	?märkanud =märkanu  (IndPrSg2  >märkanuma !27_V	et	f	\N
128346	märkanud	?märkanud =märkanud  (ID  >märkanud !41_A	et	f	\N
128347	märkanud	?märkanud =anu  (PlN  >märk+anu !17_S	et	f	\N
128352	pirita	?pirita =piri  (SgAb  >piri !17_S	et	f	\N
128353	pirita	?pirita =piri  (IndPrIps_  >pirima !27_V	et	f	\N
127831	paremale	paremale =ale  (SgN  >parem+ale !16_S	et	f	\N
127832	paremale	paremale =ale  (SgG  >parem+ale !16_S	et	f	\N
127856	kujutanud	kujutanud =kujuta  (PtsPtPs  >kujutama !27_V	et	f	\N
127857	kujutanud	kujutanud =kujutanu  (PlN  >kujutanu !01_S	et	f	\N
127858	kujutanud	"kujutanu %kujuta  )NU_vS  <kujutama ;27_V	et	f	\N
127859	kujutanud	kujutanud =kujutanud  (ID  >kujutanud !41_A	et	f	\N
127860	kujutanud	"kujutanud %kujuta  )NUD_vA  <kujutama ;27_V	et	f	\N
127861	kujutanud	kujutanud =tanu  (PlN  >kuju+tanu !17_S	et	f	\N
127862	halveme	?halveme =halve  (IndPrPl1  >halvema !27_V	et	f	\N
127869	mõttet	?mõttet =mõtte  (SgP  >mõtte !06_S	et	f	\N
127890	soola	soola =soola  (SgG  >sool !22_S	et	f	\N
127891	soola	soola =soola  (SgP  >sool !22_S	et	f	\N
127892	soola	soola =soola  (SgAdt  >sool !22_S	et	f	\N
127893	soola	soola =soola  (IndPrPs_  >soolama !29_V	et	f	\N
127894	soola	soola =soola  (ImpPrSg2  >soolama !29_V	et	f	\N
127925	lärmi	lärmi =lärmi  (SgG  >lärm !22_S	et	f	\N
127926	lärmi	lärmi =lärmi  (SgP  >lärm !22_S	et	f	\N
127927	lärmi	lärmi =lärmi  (SgAdt  >lärm !22_S	et	f	\N
127938	lõhna	lõhna =lõhna  (SgG  >lõhn !22_S	et	f	\N
127939	lõhna	lõhna =lõhna  (SgP  >lõhn !22_S	et	f	\N
127940	lõhna	lõhna =lõhna  (SgAdt  >lõhn !22_S	et	f	\N
127941	lõhna	lõhna =lõhna  (IndPrPs_  >lõhnama !29_V	et	f	\N
127942	lõhna	lõhna =lõhna  (ImpPrSg2  >lõhnama !29_V	et	f	\N
127972	otame	?otame =ota  (IndPrPl1  >otama !27_V	et	f	\N
127973	tänäpäevane	?tänäpäevane =tänäpäevane  (SgN  >tänäpäevane !12_A	et	f	\N
127977	nisuguseid	?nisuguseid =nisugusei  (PlN  >nisugusei !26_S	et	f	\N
127978	nisuguseid	?nisuguseid =nisugusei  (SgP  >nisugusei !26_S	et	f	\N
127981	nisuguseid	?nisuguseid =gusei  (PlN  >nisu+gusei !26_S	et	f	\N
127983	nisuguseid	?nisuguseid =gusei  (SgP  >nisu+gusei !26_S	et	f	\N
127985	nisuguseid	?nisuguseid =guseid  (SgN  >nisu+guseid !22_S	et	f	\N
127992	surepärases	?surepärases =surepärase  (SgIn  >surepärane !12_A	et	f	\N
128019	ohtis	?ohtis =ohti  (IndIpfSg3  >ohtima !28_V	et	f	\N
128020	ohtis	?ohtis =ohtis  (SgN  >ohtis !09_S	et	f	\N
128021	ümbritsevad	ümbritsevad =ümbritse  (IndPrPl3  >ümbritsema !27_V	et	f	\N
128022	ümbritsevad	ümbritsevad =ümbritseva  (PlN  >ümbritsev !02_A	et	f	\N
128023	ümbritsevad	"ümbritsev %ümbritse  )V_vA  <ümbritsema ;27_V	et	f	\N
128036	hülgati	?hülgati =hülga  (IndIpfIps  >hülkama !29_V	et	f	\N
128037	hülgati	?hülgati =hülgati  (ID  >hülgati !41_D	et	f	\N
128038	hülgati	?hülgati =hülgati  (SgG  >hülgat !02_S	et	f	\N
128039	hülgati	?hülgati =hülgati  (SgG  >hülgatt !22_S	et	f	\N
128040	hülgati	?hülgati =hülgati  (IndPrPs_  >hülgattima !28_V	et	f	\N
128041	hülgati	?hülgati =hülgati  (ImpPrSg2  >hülgattima !28_V	et	f	\N
128044	südi	südi =südi  (SgN  >südi !17_A	et	f	\N
128045	südi	südi =südi  (SgG  >südi !17_A	et	f	\N
128046	südi	südi =südi  (SgP  >südi !17_A	et	f	\N
128047	tõsiselt	tõsiselt =tõsise  (SgAbl  >tõsine !10_A	et	f	\N
128049	tõsiselt	"tõsine %tõsi  )NE_aA  <tõsi ;15_S	et	f	\N
128050	tõsiselt	tõsiselt =tõsiselt  (ID  >tõsiselt !41_D	et	f	\N
128052	tõsiselt	"tõsiselt %tõsise  )LT_mD  <tõsine ;10_A	et	f	\N
128066	negatiivsus	negatiivsus =negatiivsus  (SgN  >negatiivsus !11~09_S	et	f	\N
128067	negatiivsus	"negatiivsus %negatiivse  )US_aS  <negatiivne ;02_A	et	f	\N
128112	ehki	?ehki =ehki  (ID  >ehki !41_D	et	f	\N
128128	meeldejääv	meeldejääv =jää  (PtsPrPs  >meelde+_jääma !37_V	et	f	\N
128129	meeldejääv	meeldejääv =jääv  (SgN  >meelde+jääv !02_A	et	f	\N
128131	pärmiskülas	?pärmiskülas =pärmisküla  (SgIn  >pärmisküla !01_S	et	f	\N
128133	pärmiskülas	?pärmiskülas =sküla  (SgIn  >pärmi+sküla !17_S	et	f	\N
128135	pärmiskülas	?pärmiskülas =skülas  (SgN  >pärmi+skülas !09_S	et	f	\N
128140	klubi	klubi =klubi  (SgN  >klubi !17_S	et	f	\N
128141	klubi	klubi =klubi  (SgG  >klubi !17_S	et	f	\N
128142	klubi	klubi =klubi  (SgP  >klubi !17_S	et	f	\N
128143	transpordikooli	transpordikooli =kooli  (SgG  >transpordi+kool !22_S	et	f	\N
128144	transpordikooli	transpordikooli =kooli  (SgP  >transpordi+kool !22_S	et	f	\N
128145	transpordikooli	transpordikooli =kooli  (SgAdt  >transpordi+kool !22_S	et	f	\N
128146	transpordikooli	transpordikooli =kooli  (PlP  >transpordi+kool !22_S	et	f	\N
128152	ehhki	?ehhki =ehhki  (SgN  >ehhki !01_S	et	f	\N
128153	ehhki	?ehhki =ehhki  (SgG  >ehhki !01_S	et	f	\N
128154	ehhki	?ehhki =ehhki  (SgG  >ehhk !22_S	et	f	\N
128155	ehhki	?ehhki =ehhki  (SgP  >ehhk !22_S	et	f	\N
128156	ehhki	?ehhki =ehhki  (SgAdt  >ehhk !22_S	et	f	\N
128157	ehhki	?ehhki =ehhki  (IndPrPs_  >ehhkima !28_V	et	f	\N
128158	ehhki	?ehhki =ehhki  (ImpPrSg2  >ehhkima !28_V	et	f	\N
128159	ehhki	?ehhki =ehh  (SgN^  >ehh !22_S	et	f	\N
128161	lähedam	lähedam =lähedam  (SgN  >lähedam !02_A	et	f	\N
128162	lähedam	"lähedam %läheda  )M_cA  <läheda ;02_A	et	f	\N
128176	leidiski	leidiski =leid  (IndIpfSg3^  >leidma !34_V	et	f	\N
128177	leidiski	leidiski =leidis  (SgN^  >leidis !09_S	et	f	\N
128178	toetuseta	toetuseta =toetuse  (SgAb  >toetus !11~09_S	et	f	\N
128179	toetuseta	"toetus %toeta  )US_vS  <toetama ;27_V	et	f	\N
127868	korterierat	?korterierat =erat  (SgN  >korteri+erat !02_S	et	f	\N
127875	tüütavad	tüütavad =tüüta  (IndPrPl3  >tüütama !29_V	et	f	\N
127876	tüütavad	tüütavad =tüütava  (PlN  >tüütav !02_A	et	f	\N
127877	tüütavad	"tüütav %tüüta  )V_vA  <tüütama ;29_V	et	f	\N
127886	küsivad	küsivad =küsi  (IndPrPl3  >küsima !27_V	et	f	\N
127888	küsivad	küsivad =küsiva  (PlN  >küsiv !02_A	et	f	\N
127889	küsivad	"küsiv %küsi  )V_vA  <küsima ;27_V	et	f	\N
127900	tasu	tasu =tasu  (SgN  >tasu !17_S	et	f	\N
127901	tasu	tasu =tasu  (SgG  >tasu !17_S	et	f	\N
127902	tasu	tasu =tasu  (SgP  >tasu !17_S	et	f	\N
127903	tasu	tasu =tasu  (IndPrPs_  >tasuma !27_V	et	f	\N
127904	tasu	tasu =tasu  (ImpPrSg2  >tasuma !27_V	et	f	\N
127949	nähtav	nähtav =näh  (PtsPrIps  >nägema !28_V	et	f	\N
127950	nähtav	nähtav =nähtav  (SgN  >nähtav !02_A	et	f	\N
127951	nähtav	"nähtav %näh  )TAV_vAS  <nägema ;28_V	et	f	\N
127969	ukkem	?ukkem =ukkem  (SgN  >ukkem !02_A	et	f	\N
127987	vahetamine	vahetamine =vahetamine  (SgN  >vahetamine !12_S	et	f	\N
127988	vahetamine	"vahetamine %vaheta  )MINE_vS  <vahetama ;27_V	et	f	\N
127997	keskes	?keskes =keske  (SgIn  >keske !01_A	et	f	\N
127998	keskes	?keskes =keske  (IndIpfSg3  >keskema !27_V	et	f	\N
127999	keskes	?keskes =keskes  (SgN  >keskes !09_S	et	f	\N
128016	turvaline	turvaline =turvaline  (SgN  >turvaline !12_A	et	f	\N
128017	turvaline	"turvaline %turva  )LINE_aA  <turb ;22_SA	et	f	\N
128018	turvaline	"turvaline %turva  )LINE_aA  <turv ;22_S	et	f	\N
128031	kurvalt	kurvalt =kurva  (SgAbl  >kurb !22_A	et	f	\N
128033	kurvalt	kurvalt =kurvalt  (ID  >kurvalt !41_D	et	f	\N
128035	kurvalt	"kurvalt %kurva  )LT_mD  <kurb ;22_A	et	f	\N
128048	usuma	?usuma =usu  (Sup  >usuma !27_V	et	f	\N
128059	pettus	pettus =pettu  (IndIpfSg3  >pettuma !27_V	et	f	\N
128060	pettus	pettus =pettus  (SgN  >pettus !11~09_S	et	f	\N
128082	vahetusid	vahetusid =vahetu  (IndIpfSg2  >vahetuma !27_V	et	f	\N
128083	vahetusid	vahetusid =vahetu  (IndIpfPl3  >vahetuma !27_V	et	f	\N
128084	tasku	tasku =tasku  (SgN  >tasku !01_S	et	f	\N
128085	tasku	tasku =tasku  (SgG  >tasku !01_S	et	f	\N
128097	tingimatu	tingimatu =tingimatu  (SgN  >tingimatu !01_A	et	f	\N
128098	tingimatu	"tingimatu %tingi  )MATU_vA  <tingima ;28_V	et	f	\N
128099	tingimatu	tingimatu =tingimatu  (SgG  >tingimatu !01_A	et	f	\N
128100	tingimatu	tingimatu =imatu  (SgN  >ting+imatu !01_A	et	f	\N
128101	tingimatu	"ting+imatu %ima  )TU2_kA  <ting+ima ;17_S	et	f	\N
128102	tingimatu	tingimatu =imatu  (SgG  >ting+imatu !01_A	et	f	\N
128109	seitsemeaastane	?seitsemeaastane =seitsemeaastane  (SgN  >seitsemeaastane !12~10_A	et	f	\N
128110	seitsemeaastane	?seitsemeaastane =meaastane  (SgN  >seitse+meaastane !12~10_A	et	f	\N
128111	seitsemeaastane	?seitsemeaastane =meaastane  (PlP  >seitse+meaastan !19_S	et	f	\N
128121	üheksaastane	üheksaastane =aastane  (SgN  >üheks+aastane !12~10_A	et	f	\N
128122	üheksaastane	"üheks+aastane %aasta  )NE_aA  <üheks+aasta ;01_S	et	f	\N
128123	unistanud	unistanud =unista  (PtsPtPs  >unistama !27_V	et	f	\N
128124	unistanud	unistanud =unistanu  (PlN  >unistanu !01_S	et	f	\N
128125	unistanud	"unistanu %unista  )NU_vS  <unistama ;27_V	et	f	\N
128126	unistanud	unistanud =unistanud  (ID  >unistanud !41_A	et	f	\N
128127	unistanud	"unistanud %unista  )NUD_vA  <unistama ;27_V	et	f	\N
128130	lõpupidu	lõpupidu =pidu  (SgN  >lõpu+pidu !17_S	et	f	\N
128132	lõpupidu	lõpupidu =pidu  (SgN  >lõpu+pidu !18_S	et	f	\N
128134	lõpupidu	lõpupidu =pidu  (SgG  >lõpu+pidu !17_S	et	f	\N
128136	lõpupidu	lõpupidu =pidu  (SgP  >lõpu+pidu !17_S	et	f	\N
128137	lõpupidu	lõpupidu =pidu  (SgP  >lõpu+pidu !18_S	et	f	\N
128147	tugispetsialisti	tugispetsialisti =spetsialisti  (SgG  >tugi+spetsialist !22_S	et	f	\N
128148	tugispetsialisti	tugispetsialisti =spetsialisti  (SgP  >tugi+spetsialist !22_S	et	f	\N
128149	tugispetsialisti	tugispetsialisti =spetsialisti  (SgAdt  >tugi+spetsialist !22_S	et	f	\N
128181	ootusärav	?ootusärav =ootusärav  (SgN  >ootusärav !02_A	et	f	\N
128182	ootusärav	?ootusärav =ärav  (SgN  >ootus+ärav !02_A	et	f	\N
128183	lootusrikas	?lootusrikas =lootusrika  (SgIn  >lootusrika !01_S	et	f	\N
128184	lootusrikas	?lootusrikas =lootusrika  (SgIn  >lootusrikas !02_A	et	f	\N
128185	lootusrikas	?lootusrikas =lootusrikas  (SgN  >lootusrikas !02_A	et	f	\N
128186	lootusrikas	?lootusrikas =rika  (SgIn  >lootus+rika !16_S	et	f	\N
128187	lootusrikas	?lootusrikas =rikas  (SgN  >lootus+rikas !07_A	et	f	\N
128188	lootusrikas	?lootusrikas =tusrika  (SgIn  >loo+tusrika !01_S	et	f	\N
128189	lootusrikas	?lootusrikas =tusrika  (SgIn  >loo+tusrikas !02_S	et	f	\N
128190	lootusrikas	?lootusrikas =tusrikas  (SgN  >loo+tusrikas !02_S	et	f	\N
128191	kinkisid	kinkisid =kinki  (PlP  >kink !22_S	et	f	\N
128192	kinkisid	kinkisid =kinki  (IndIpfSg2  >kinkima !28_V	et	f	\N
128193	kinkisid	kinkisid =kinki  (IndIpfPl3  >kinkima !28_V	et	f	\N
128201	nukkuga	?nukkuga =uga  (SgN  >nukk+uga !17_S	et	f	\N
128202	nukkuga	?nukkuga =uga  (SgG  >nukk+uga !17_S	et	f	\N
128203	nukkuga	?nukkuga =uga  (SgP  >nukk+uga !17_S	et	f	\N
128204	viitsime	viitsime =viit  (IndIpfPl1  >viitma !34_V	et	f	\N
128205	viitsime	viitsime =viitsi  (IndPrPl1  >viitsima !28_V	et	f	\N
127962	hrushovi	?hrushovi =hrushovi  (ID  >hrushovi !41_D	et	f	\N
127963	hrushovi	?hrushovi =hrushovi  (SgG  >hrushov !02_A	et	f	\N
127965	kolmetoaline	kolmetoaline =toaline  (SgN  >kolme+toaline !12?10_A	et	f	\N
127966	kolmetoaline	"kolme+toaline %toa  )LINE_aA  <kolme+tuba ;18_S	et	f	\N
127967	kõigel	kõigel =kõige  (SgAd  >kõik !00_P	et	f	\N
127968	kõigel	kõigel =kõige  (PlAd  >kõik !22_S	et	f	\N
127970	tingitsem	?tingitsem =tingitsem  (SgN  >tingitsem !02_A	et	f	\N
127971	tingitsem	?tingitsem =itsem  (SgN  >ting+itsem !02_A	et	f	\N
127975	ettevatlik	?ettevatlik =ettevatlik  (SgN  >ettevatlik !25_A	et	f	\N
127976	ettevatlik	?ettevatlik =vatlik  (SgN  >ette+vatlik !25_A	et	f	\N
127979	küsimuseid	?küsimuseid =küsimusei  (PlN  >küsimusei !26_S	et	f	\N
127980	küsimuseid	?küsimuseid =küsimusei  (SgP  >küsimusei !26_S	et	f	\N
127982	küsimuseid	?küsimuseid =musei  (PlN  >küsi+musei !26_S	et	f	\N
127984	küsimuseid	?küsimuseid =musei  (SgP  >küsi+musei !26_S	et	f	\N
127986	küsimuseid	?küsimuseid =museid  (SgN  >küsi+museid !22_S	et	f	\N
128003	vodi	?vodi =vodi  (SgN  >vodi !17_S	et	f	\N
128004	vodi	?vodi =vodi  (SgG  >vodi !17_S	et	f	\N
128005	vodi	?vodi =vodi  (SgP  >vodi !17_S	et	f	\N
128006	vodi	?vodi =vodi  (IndPrPs_  >vodima !27_V	et	f	\N
128007	vodi	?vodi =vodi  (ImpPrSg2  >vodima !27_V	et	f	\N
128008	televisoon	?televisoon =televisoon  (SgN  >televisoon !22_S	et	f	\N
128009	televisoon	?televisoon =visoon  (SgN  >tele+visoon !22_S	et	f	\N
128064	ettevaatlikum	ettevaatlikum =vaatlikum  (SgN  >ette+vaatlikum !02_A	et	f	\N
128065	ettevaatlikum	"ette+vaatlikum %vaatliku  )M_cA  <ette+vaatlik ;25_A	et	f	\N
128071	reaalkoolis	reaalkoolis =kooli  (SgIn  >reaal+kool !22_S	et	f	\N
128072	reaalkoolis	reaalkoolis =kooli  (PlIn  >reaal+kool !22_S	et	f	\N
128073	joonistanud	joonistanud =joonista  (PtsPtPs  >joonistama !27_V	et	f	\N
128074	joonistanud	joonistanud =joonistanu  (PlN  >joonistanu !01_S	et	f	\N
128075	joonistanud	"joonistanu %joonista  )NU_vS  <joonistama ;27_V	et	f	\N
128076	joonistanud	joonistanud =joonistanud  (ID  >joonistanud !41_A	et	f	\N
128077	joonistanud	"joonistanud %joonista  )NUD_vA  <joonistama ;27_V	et	f	\N
128078	joonistanud	joonistanud =tanu  (PlN  >joonis+tanu !17_S	et	f	\N
128095	kukusin	?kukusin =kuku  (IndIpfSg1  >kukuma !27_V	et	f	\N
128096	kukusin	?kukusin =kukusin  (SgN  >kukusin !19_S	et	f	\N
128103	akademias	?akademias =akademia  (SgIn  >akademia !01_S	et	f	\N
128104	akademias	?akademias =akademias  (SgN  >akademias !11_S	et	f	\N
128163	sattis	?sattis =satti  (IndIpfSg3  >sattima !28_V	et	f	\N
128164	sattis	?sattis =sattis  (ID  >sattis !41_DA	et	f	\N
128172	õppiksin	?õppiksin =õppiksi  (IndPrSg1  >õppiksima !28_V	et	f	\N
128173	õppiksin	?õppiksin =õppiksin  (SgN  >õppiksin !19_S	et	f	\N
128174	valjapääsu	?valjapääsu =valjapääsu  (IndPrPs_  >valjapääsuma !27_V	et	f	\N
128175	valjapääsu	?valjapääsu =valjapääsu  (ImpPrSg2  >valjapääsuma !27_V	et	f	\N
128214	oota	oota =oota  (IndPrPs_  >ootama !29_V	et	f	\N
128215	oota	oota =oota  (ImpPrSg2  >ootama !29_V	et	f	\N
128243	teistsuguseks	teistsuguseks =seks  (SgN  >teist+sugu+seks !22_S	et	f	\N
128244	teistsuguseks	teistsuguseks =suguse  (SgTr  >teist+sugune !10_P	et	f	\N
128245	muudavad	muudavad =muuda  (IndPrPl3  >muutma !34_V	et	f	\N
128246	muudavad	"muudav %muu  )TAV_vAS  <muuma ;27_V	et	f	\N
128247	muudavad	muudavad =ava  (PlN  >muud+ava !17_S	et	f	\N
128279	tudengidega	### tudengidega	et	f	\N
128293	näita	näita =näita  (IndPrPs_  >näitama !29_V	et	f	\N
128294	näita	näita =näita  (ImpPrSg2  >näitama !29_V	et	f	\N
128325	aafrikast	?aafrikast =aafrika  (SgEl  >aafrika !01_S	et	f	\N
128326	aafrikast	?aafrikast =aafrika  (SgEl  >aafrikas !02_S	et	f	\N
128327	aafrikast	?aafrikast =aafrikas  (SgP  >aafrikane !12_A	et	f	\N
128403	ülesehitust	ülesehitust =ehitu  (SgEl  >üles+ehitu !01_AS	et	f	\N
128404	ülesehitust	ülesehitust =ehitus  (SgP  >üles+ehitus !11_S	et	f	\N
128418	tv-3	### tv-3	et	f	\N
128455	sarjas	sarjas =sarja  (SgIn  >sari !24_S	et	f	\N
128456	sarjas	sarjas =sarja  (IndIpfSg3  >sarjama !29_V	et	f	\N
128460	arusaamatuks	arusaamatuks =tuks  (SgN  >aru+saama+tuks !22_S	et	f	\N
128461	arusaamatuks	arusaamatuks =saamatu  (SgTr  >aru+saamatu !01_A	et	f	\N
128462	arusaamatuks	"aru+saamatu %saama  )TU2_kA  <aru+saam ;22_S	et	f	\N
128463	tõlkimata	tõlkimata =tõlki  (SupAb  >tõlkima !28_V	et	f	\N
128464	tõlkimata	tõlkimata =tõlkimata  (ID  >tõlkimata !41_A	et	f	\N
128465	tõlkimata	"tõlkimata %tõlki  )MATA_vA  <tõlkima ;28_V	et	f	\N
128467	max	### max	et	f	\N
128483	raskendanud	raskendanud =raskenda  (PtsPtPs  >raskendama !27_V	et	f	\N
128484	raskendanud	raskendanud =raskendanu  (PlN  >raskendanu !01_S	et	f	\N
128485	raskendanud	"raskendanu %raskenda  )NU_vS  <raskendama ;27_V	et	f	\N
128486	raskendanud	raskendanud =raskendanud  (ID  >raskendanud !41_A	et	f	\N
128487	raskendanud	"raskendanud %raskenda  )NUD_vA  <raskendama ;27_V	et	f	\N
128495	n-ö	### n-ö	et	f	\N
128516	raske-	raske- =raske  (SgN  >raske !01_A	et	f	\N
128517	raske-	raske- =raske  (SgG  >raske !01_A	et	f	\N
128518	raske-	raske- =raske  (PlP  >rask !22_S	et	f	\N
128522	muutu	muutu =muutu  (SgN  >muutu !01_A	et	f	\N
127995	paremas	paremas =parema  (SgIn  >parem !02_A	et	f	\N
127996	paremas	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
128000	seisas	?seisas =seisa  (SgIn  >seisa !16_S	et	f	\N
128001	seisas	?seisas =seisa  (IndIpfSg3  >seisama !29_V	et	f	\N
128002	seisas	?seisas =seisas  (SgN  >seisas !07_S	et	f	\N
128011	inimiseid	?inimiseid =inimisei  (PlN  >inimisei !26_S	et	f	\N
128012	inimiseid	?inimiseid =inimisei  (SgP  >inimisei !26_S	et	f	\N
128013	inimiseid	?inimiseid =isei  (PlN  >inim+isei !26_S	et	f	\N
128014	inimiseid	?inimiseid =isei  (SgP  >inim+isei !26_S	et	f	\N
128015	inimiseid	?inimiseid =iseid  (SgN  >inim+iseid !22_S	et	f	\N
128024	toimu	toimu =toimu  (IndPrPs_  >toimuma !27_V	et	f	\N
128025	toimu	toimu =toimu  (ImpPrSg2  >toimuma !27_V	et	f	\N
128026	lõppenud	lõppenud =lõppe  (PtsPtPs  >lõppema !27~28_V	et	f	\N
128027	lõppenud	lõppenud =lõppenu  (PlN  >lõppenu !01_S	et	f	\N
128028	lõppenud	"lõppenu %lõppe  )NU_vS  <lõppema ;27_V	et	f	\N
128029	lõppenud	"lõppenu %lõppe  )NU_vS  <lõppema ;28_V	et	f	\N
128030	lõppenud	lõppenud =lõppenud  (ID  >lõppenud !41_A	et	f	\N
128032	lõppenud	"lõppenud %lõppe  )NUD_vA  <lõppema ;27_V	et	f	\N
128034	lõppenud	"lõppenud %lõppe  )NUD_vA  <lõppema ;28_V	et	f	\N
128051	armastusse	armastusse =armastus  (SgAdt  >armastus !11_S	et	f	\N
128053	armastusse	"armastus %armasta  )US_vS  <armastama ;27_V	et	f	\N
128054	rikutud	rikutud =riku  (PtsPtIps  >rikkuma !28_V	et	f	\N
128055	rikutud	rikutud =rikutu  (PlN  >rikutu !01_AS	et	f	\N
128056	rikutud	"rikutu %riku  )TU1_vS  <rikkuma ;28_V	et	f	\N
128057	rikutud	rikutud =rikutud  (ID  >rikutud !41_A	et	f	\N
128058	rikutud	"rikutud %riku  )TUD_vA  <rikkuma ;28_V	et	f	\N
128061	haigus	haigus =haigu  (SgIn  >haik !22_S	et	f	\N
128062	haigus	haigus =haigus  (SgN  >haigus !11~09_S	et	f	\N
128063	haigus	"haigus %haige  )US_aS  <haige ;01_AS	et	f	\N
128068	vapustav	vapustav =vapusta  (PtsPrPs  >vapustama !27_V	et	f	\N
128069	vapustav	vapustav =vapustav  (SgN  >vapustav !02_A	et	f	\N
128070	vapustav	"vapustav %vapusta  )V_vA  <vapustama ;27_V	et	f	\N
128086	pihta	pihta =pihta  (ID  >pihta !41_DK	et	f	\N
128087	pihta	pihta =pihta  (SgP  >piht !22_S	et	f	\N
128088	pihta	pihta =pihta  (SgAdt  >piht !22_S	et	f	\N
128089	pihta	pihta =pihta  (IndPrPs_  >pihtama !29_V	et	f	\N
128090	pihta	pihta =pihta  (ImpPrSg2  >pihtama !29_V	et	f	\N
128093	joonistusi	joonistusi =joonistusi  (PlP  >joonistus !11_S	et	f	\N
128094	joonistusi	"joonistus %joonista  )US_vS  <joonistama ;27_V	et	f	\N
128105	hirmustas	?hirmustas =hirmusta  (SgIn  >hirmusta !01_S	et	f	\N
128106	hirmustas	?hirmustas =hirmusta  (IndIpfSg3  >hirmustama !27_V	et	f	\N
128107	hirmustas	?hirmustas =usta  (SgIn  >hirm+usta !16_S	et	f	\N
128108	hirmustas	?hirmustas =ustas  (SgN  >hirm+ustas !07_S	et	f	\N
128113	aastavahetusel	aastavahetusel =use  (PlAd  >aasta+vahet+usk !22_S	et	f	\N
128114	aastavahetusel	aastavahetusel =vahetuse  (SgAd  >aasta+vahetus !11_S	et	f	\N
128115	aastavahetusel	"aasta+vahetus %vahe  )TUS2_aS  <aasta+vahe ;16_S	et	f	\N
128118	suvereis	suvereis =reis  (SgN  >suve+reis !14_S	et	f	\N
128119	suvereis	suvereis =reis  (SgN  >suve+reis !22_S	et	f	\N
128120	õppilased	?õppilased =õppilase  (PlN  >õppilane !12_S	et	f	\N
128150	sooritamine	sooritamine =sooritamine  (SgN  >sooritamine !12_S	et	f	\N
128151	sooritamine	"sooritamine %soorita  )MINE_vS  <sooritama ;27_V	et	f	\N
128196	üllatusena	üllatusena =üllatuse  (SgEs  >üllatus !11_S	et	f	\N
128197	üllatusena	"üllatus %üllata  )US_vS  <üllatama ;27_V	et	f	\N
128208	lähedasem	lähedasem =lähedasem  (SgN  >lähedasem !02_A	et	f	\N
128209	lähedasem	"lähedasem %lähedase  )M_cA  <lähedane ;12_AS	et	f	\N
128222	sella	?sella =sella  (SgN  >sella !16_S	et	f	\N
128223	sella	?sella =sella  (SgG  >sella !16_S	et	f	\N
128224	sella	?sella =sella  (IndPrPs_  >sellama !29_V	et	f	\N
128225	sella	?sella =sella  (ImpPrSg2  >sellama !29_V	et	f	\N
128227	ültse	?ültse =ültse  (SgN  >ültse !06_S	et	f	\N
128228	ültse	?ültse =ültse  (SgG  >ültne !02_A	et	f	\N
128229	ültse	?ültse =ültse  (SgG  >ültse !06_S	et	f	\N
128230	ültse	?ültse =ültse  (PlP  >ülts !22_S	et	f	\N
128231	ültse	?ültse =ültse  (IndPrPs_  >ültsema !27_V	et	f	\N
128232	ültse	?ültse =ültse  (ImpPrSg2  >ültsema !27_V	et	f	\N
128233	informatsioni	?informatsioni =informatsio  (SgTer  >informatsio !01_S	et	f	\N
128234	informatsioni	?informatsioni =informatsioni  (SgN  >informatsioni !16_S	et	f	\N
128235	informatsioni	?informatsioni =informatsioni  (SgG  >informatsion !19~02_S	et	f	\N
128236	informatsioni	?informatsioni =informatsioni  (SgG  >informatsioni !16_S	et	f	\N
128237	informatsioni	?informatsioni =informatsioni  (SgP  >informatsion !19_S	et	f	\N
128238	informatsioni	?informatsioni =informatsioni  (SgAdt  >informatsion !19_S	et	f	\N
128239	informatsioni	?informatsioni =informatsioni  (IndPrPs_  >informatsionima !28_V	et	f	\N
128240	informatsioni	?informatsioni =informatsioni  (ImpPrSg2  >informatsionima !28_V	et	f	\N
128271	omaelu	omaelu =elu  (SgN  >oma+elu !17_S	et	f	\N
128272	omaelu	omaelu =elu  (SgG  >oma+elu !17_S	et	f	\N
128273	omaelu	omaelu =elu  (SgP  >oma+elu !17_S	et	f	\N
128180	toetuseta	"toetus %toe  )TUS2_aS  <tugi ;21_S	et	f	\N
128194	sünnipäevile	sünnipäevile =päevi  (SgAll  >sünni+päev !22_S	et	f	\N
128195	sünnipäevile	sünnipäevile =päevi  (PlAll  >sünni+päev !22_S	et	f	\N
128198	range	range =range  (SgN  >range !01_A	et	f	\N
128199	range	range =range  (SgG  >range !01_A	et	f	\N
128200	range	range =range  (PlP  >rang !22_S	et	f	\N
128206	vanemateta	vanemateta =vanema  (PlAb  >vanem !02_AS	et	f	\N
128207	vanemateta	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
128210	ülikoolilt	ülikoolilt =kooli  (SgAbl  >üli+kool !22_S	et	f	\N
128211	ülikoolilt	ülikoolilt =kooli  (PlAbl  >üli+kool !22_S	et	f	\N
128212	tulevikust	tulevikust =tuleviku  (SgEl  >tulevik !25_S	et	f	\N
128213	tulevikust	tulevikust =viku  (SgEl  >tule+vikk !22_S	et	f	\N
128220	kadedusväärseks	kadedusväärseks =seks  (SgN  >kadedus+väär+seks !22_S	et	f	\N
128221	kadedusväärseks	kadedusväärseks =väärse  (SgTr  >kadedus+väärne !02_A	et	f	\N
128255	pallju	?pallju =pallju  (SgN  >pallju !01_S	et	f	\N
128256	pallju	?pallju =pallju  (SgG  >pallju !01_S	et	f	\N
128257	pallju	?pallju =pallju  (IndPrPs_  >palljuma !27_V	et	f	\N
128258	pallju	?pallju =pallju  (ImpPrSg2  >palljuma !27_V	et	f	\N
128269	ühiselamus	ühiselamus =elamu  (SgIn  >ühis+elamu !01_S	et	f	\N
128270	ühiselamus	ühiselamus =elamus  (SgN  >ühis+elamus !11_S	et	f	\N
128274	ülikoolielus	ülikoolielus =elu  (SgIn  >üli+kooli+elu !17_S	et	f	\N
128275	ülikoolielus	ülikoolielus =elus  (SgN  >üli+kooli+elus !02_A	et	f	\N
128300	suurepäraselt	suurepäraselt =pärase  (SgAbl  >suure+pärane !10_A	et	f	\N
128301	suurepäraselt	"suure+pärane %pära  )NE_aA  <suure+pära ;17_S	et	f	\N
128302	suurepäraselt	"suure+päraselt %pära  )SELT_mD  <suure+pära ;17_S	et	f	\N
128303	suurepäraselt	"suure+päraselt %pärase  )LT_mD  <suure+pärane ;10_A	et	f	\N
128328	papagoit	?papagoit =papagoit  (SgN  >papagoit !22_S	et	f	\N
128332	puuru	?puuru =puuru  (SgN  >puuru !16_S	et	f	\N
128333	puuru	?puuru =puuru  (SgG  >puuru !16_S	et	f	\N
128334	puuru	?puuru =puuru  (IndPrPs_  >puuruma !27_V	et	f	\N
128335	puuru	?puuru =puuru  (ImpPrSg2  >puuruma !27_V	et	f	\N
128341	magasid	magasid =maga  (IndIpfSg2  >magama !27_V	et	f	\N
128342	magasid	magasid =maga  (IndIpfPl3  >magama !27_V	et	f	\N
128343	magasid	magasid =magasi  (PlN  >magas !02_S	et	f	\N
128358	kallase	kallase =kallase  (SgG  >kallane !10_A	et	f	\N
128359	kallase	"kallane %kalla  )NE_aA  <kalla ;16_S	et	f	\N
128363	allpoole	allpoole =poole  (SgN  >all+poole !05_S	et	f	\N
128364	allpoole	allpoole =poole  (PlP  >all+pool !22_S	et	f	\N
128372	küünistamine	küünistamine =küünistamine  (SgN  >küünistamine !12_S	et	f	\N
128373	küünistamine	"küünistamine %küünista  )MINE_vS  <küünistama ;27_V	et	f	\N
128374	lossis	lossis =lossi  (SgIn  >loss !22_S	et	f	\N
128375	lossis	lossis =lossi  (IndIpfSg3  >lossima !28_V	et	f	\N
128376	lossis	lossis =lossis  (ID  >lossis !41_DA	et	f	\N
128380	viieastane	?viieastane =viieastane  (SgN  >viieastane !12_A	et	f	\N
128381	viieastane	?viieastane =viieastane  (PlP  >viieastan !19_S	et	f	\N
128382	viieastane	?viieastane =astane  (SgN  >viie+astane !12~10_A	et	f	\N
128396	pidasid	pidasid =pida  (IndIpfSg2  >pidama !28_V	et	f	\N
128397	pidasid	pidasid =pida  (IndIpfPl3  >pidama !28_V	et	f	\N
128401	subtiitrite	subtiitrite =subtiitri  (PlG  >subtiiter !02_S	et	f	\N
128402	subtiitrite	subtiitrite =tiitri  (PlG  >sub+tiiter !02_S	et	f	\N
128426	kateiks	?kateiks =katei  (SgTr  >katei !26_S	et	f	\N
128427	kateiks	?kateiks =kateiks  (SgN  >kateiks !22_S	et	f	\N
128431	mcguire	?mcguire =mcguire  (SgN  >mcguire !06_S	et	f	\N
128432	mcguire	?mcguire =mcguire  (SgG  >mcguire !06_S	et	f	\N
128433	mcguire	?mcguire =mcguire  (PlP  >mcguir !22_S	et	f	\N
128434	mcguire	?mcguire =mcguire  (IndPrPs_  >mcguirema !27_V	et	f	\N
128435	mcguire	?mcguire =mcguire  (ImpPrSg2  >mcguirema !27_V	et	f	\N
128445	suu	suu =suu  (SgN  >suu !26_S	et	f	\N
128447	suu	suu =suu  (SgG  >suu !26_S	et	f	\N
128452	kõnevooru	kõnevooru =vooru  (SgG  >kõne+voor !22_S	et	f	\N
128453	kõnevooru	kõnevooru =vooru  (SgP  >kõne+voor !22_S	et	f	\N
128454	kõnevooru	kõnevooru =vooru  (SgAdt  >kõne+voor !22_S	et	f	\N
128457	sarjast	sarjast =sarja  (SgEl  >sari !24_S	et	f	\N
128458	sarjast	sarjast =sarjas  (SgP  >sarjane !10_A	et	f	\N
128459	sarjast	"sarjane %sarja  )NE_aA  <sari ;24_S	et	f	\N
128468	okey	### okey	et	f	\N
128478	ruumissiis	?ruumissiis =ruumissi  (PlIn  >ruumissi !01_S	et	f	\N
128479	ruumissiis	?ruumissiis =ruumissii  (SgIn  >ruumissii !26_S	et	f	\N
128480	ruumissiis	?ruumissiis =ruumissiis  (SgN  >ruumissiis !22_S	et	f	\N
128481	ruumissiis	?ruumissiis =issii  (SgIn  >ruum+issii !26_S	et	f	\N
128482	ruumissiis	?ruumissiis =issiis  (SgN  >ruum+issiis !22_S	et	f	\N
128492	kursiivi	kursiivi =kursiivi  (SgG  >kursiiv !22_S	et	f	\N
128493	kursiivi	kursiivi =kursiivi  (SgP  >kursiiv !22_S	et	f	\N
128494	kursiivi	kursiivi =kursiivi  (SgAdt  >kursiiv !22_S	et	f	\N
128500	näitamiseks	näitamiseks =näitamise  (SgTr  >näitamine !12_S	et	f	\N
128501	näitamiseks	"näitamine %näita  )MINE_vS  <näitama ;29_V	et	f	\N
128514	soovisin	soovisin =soovi  (IndIpfSg1  >soovima !28_V	et	f	\N
128218	meeldivaks	meeldivaks =meeldiva  (SgTr  >meeldiv !02_A	et	f	\N
128219	meeldivaks	"meeldiv %meeldi  )V_vA  <meeldima ;27_V	et	f	\N
128248	unistused	unistused =unistuse  (PlN  >unistus !11_S	et	f	\N
128249	unistused	"unistus %unista  )US_vS  <unistama ;27_V	et	f	\N
128261	nattuke	?nattuke =nattuke  (SgN  >nattuke !12_S	et	f	\N
128264	ülikoolielu	ülikoolielu =elu  (SgN  >üli+kooli+elu !17_S	et	f	\N
128266	ülikoolielu	ülikoolielu =elu  (SgG  >üli+kooli+elu !17_S	et	f	\N
128268	ülikoolielu	ülikoolielu =elu  (SgP  >üli+kooli+elu !17_S	et	f	\N
128276	tulevikule	tulevikule =tuleviku  (SgAll  >tulevik !25_S	et	f	\N
128277	tulevikule	tulevikule =viku  (SgAll  >tule+vikk !22_S	et	f	\N
128280	ülikoolil	ülikoolil =kooli  (SgAd  >üli+kool !22_S	et	f	\N
128281	ülikoolil	ülikoolil =kooli  (PlAd  >üli+kool !22_S	et	f	\N
128282	arusaada	?arusaada =arusaada  (SgN  >arusaada !16_S	et	f	\N
128283	arusaada	?arusaada =arusaada  (SgG  >arusaada !16_S	et	f	\N
128284	arusaada	?arusaada =saada  (SgN  >aru+saada !16_S	et	f	\N
128285	arusaada	?arusaada =saada  (SgG  >aru+saada !16_S	et	f	\N
128290	turvalisena	turvalisena =turvalise  (SgEs  >turvaline !12_A	et	f	\N
128291	turvalisena	"turvaline %turva  )LINE_aA  <turb ;22_SA	et	f	\N
128292	turvalisena	"turvaline %turva  )LINE_aA  <turv ;22_S	et	f	\N
128298	seisukohta	seisukohta =kohta  (SgP  >seisu+koht !22_S	et	f	\N
128299	seisukohta	seisukohta =kohta  (SgAdt  >seisu+koht !22_S	et	f	\N
128309	väärtushinanguid	?väärtushinanguid =väärtushinangu  (PlP  >väärtushinang !02_S	et	f	\N
128310	väärtushinanguid	?väärtushinanguid =väärtushinangui  (PlN  >väärtushinangui !26_S	et	f	\N
128311	väärtushinanguid	?väärtushinanguid =väärtushinangui  (SgP  >väärtushinangui !26_S	et	f	\N
128312	väärtushinanguid	?väärtushinanguid =hinangu  (PlP  >väärtus+hinangu !01_S	et	f	\N
128313	väärtushinanguid	?väärtushinanguid =hinangu  (PlP  >väärtus+hinang !02_S	et	f	\N
128314	väärtushinanguid	?väärtushinanguid =hinangui  (PlN  >väärtus+hinangui !26_S	et	f	\N
128315	väärtushinanguid	?väärtushinanguid =hinangui  (SgP  >väärtus+hinangui !26_S	et	f	\N
128316	väärtushinanguid	?väärtushinanguid =ushinangu  (PlP  >väärt+ushinang !02_S	et	f	\N
128317	väärtushinanguid	?väärtushinanguid =ushinangui  (PlN  >väärt+ushinangui !26_S	et	f	\N
128318	väärtushinanguid	?väärtushinanguid =ushinangui  (SgP  >väärt+ushinangui !26_S	et	f	\N
128319	väärtushinanguid	?väärtushinanguid =tushinangu  (PlP  >väär+tushinang !02_S	et	f	\N
128321	väärtushinanguid	?väärtushinanguid =tushinangui  (PlN  >väär+tushinangui !26_S	et	f	\N
128323	väärtushinanguid	?väärtushinanguid =tushinangui  (SgP  >väär+tushinangui !26_S	et	f	\N
128338	puurus	?puurus =puuru  (SgIn  >puuru !16_S	et	f	\N
128339	puurus	?puurus =puuru  (IndIpfSg3  >puuruma !27_V	et	f	\N
128340	puurus	?puurus =puurus  (SgN  >puurus !11~09_S	et	f	\N
128348	sõidsin	?sõidsin =sõidsi  (IndPrSg1  >sõidsima !28_V	et	f	\N
128349	sõidsin	?sõidsin =sõidsin  (SgN  >sõidsin !02_S	et	f	\N
128350	russalka	?russalka =russalka  (SgN  >russalka !16_S	et	f	\N
128351	russalka	?russalka =russalka  (SgG  >russalka !16_S	et	f	\N
128365	kaheksaastane	?kaheksaastane =kaheksaastane  (SgN  >kaheksaastane !12~10_A	et	f	\N
128366	kaheksaastane	?kaheksaastane =astane  (SgN  >kaheksa+astane !12~10_A	et	f	\N
128367	kaheksaastane	?kaheksaastane =ksaastane  (SgN  >kahe+ksaastane !12~10_A	et	f	\N
128388	krõmmis	?krõmmis =krõmmi  (SgIn  >krõmmi !16_S	et	f	\N
128389	krõmmis	?krõmmis =krõmmi  (SgIn  >krõmm !22_S	et	f	\N
128390	krõmmis	?krõmmis =krõmmi  (IndIpfSg3  >krõmmima !28_V	et	f	\N
128391	krõmmis	?krõmmis =krõmmis  (SgN  >krõmmis !09_S	et	f	\N
128428	tv-2	### tv-2	et	f	\N
128429	lizzi	?lizzi =lizzi  (SgN  >lizzi !16_S	et	f	\N
128430	lizzi	?lizzi =lizzi  (SgG  >lizzi !16_S	et	f	\N
128443	õigeaegselt	õigeaegselt =aegse  (SgAbl  >õige+aegne !02_A	et	f	\N
128444	õigeaegselt	"õige+aegselt %aegse  )LT_mD  <õige+aegne ;02_A	et	f	\N
128449	kadusid	kadusid =kadu  (PlP  >kadu !18_S	et	f	\N
128450	kadusid	kadusid =kadu  (IndIpfSg2  >kaduma !28_V	et	f	\N
128451	kadusid	kadusid =kadu  (IndIpfPl3  >kaduma !28_V	et	f	\N
128469	ashli	?ashli =ashli  (SgN  >ashli !01_S	et	f	\N
128470	ashli	?ashli =ashli  (SgG  >ashli !01_S	et	f	\N
128471	ashli	?ashli =ashli  (SgG  >ashl !22_S	et	f	\N
128472	ashli	?ashli =ashli  (SgP  >ashl !22_S	et	f	\N
128473	ashli	?ashli =ashli  (SgAdt  >ashl !22_S	et	f	\N
128474	ashli	?ashli =ashli  (IndPrPs_  >ashlima !28_V	et	f	\N
128475	ashli	?ashli =ashli  (ImpPrSg2  >ashlima !28_V	et	f	\N
128476	nähtavus	nähtavus =nähtavus  (SgN  >nähtavus !11_S	et	f	\N
128477	nähtavus	"nähtavus %näh  )TAVUS_aS  <nägema ;28_V	et	f	\N
128498	vead	vead =vea  (PlN  >viga !18_S	et	f	\N
128499	vead	vead =vea  (IndPrSg2  >vedama !28_V	et	f	\N
128505	jälgimiseks	jälgimiseks =jälgimise  (SgTr  >jälgimine !12_S	et	f	\N
128506	jälgimiseks	"jälgimine %jälgi  )MINE_vS  <jälgima ;27_V	et	f	\N
128507	helindatud	helindatud =helinda  (PtsPtIps  >helindama !27_V	et	f	\N
128508	helindatud	helindatud =helindatu  (PlN  >helindatu !01_S	et	f	\N
128509	helindatud	"helindatu %helinda  )TU1_vS  <helindama ;27_V	et	f	\N
128510	helindatud	helindatud =helindatud  (ID  >helindatud !41_A	et	f	\N
128287	ennas	?ennas =enna  (SgIn  >enna !16_S	et	f	\N
128288	ennas	?ennas =enna  (IndIpfSg3  >ennama !29_V	et	f	\N
128289	ennas	?ennas =ennas  (SgN  >ennas !07_S	et	f	\N
128295	valguses	valguses =valguse  (SgIn  >valgus !11~09_S	et	f	\N
128296	valguses	"valgus %valge  )US_aS  <valge ;01_AS	et	f	\N
128297	valguses	valguses =use  (PlIn  >valg+usk !22_S	et	f	\N
128320	intellektuaalselt	intellektuaalselt =intellektuaalse  (SgAbl  >intellektuaalne !02_A	et	f	\N
128322	intellektuaalselt	intellektuaalselt =intellektuaalselt  (ID  >intellektuaalselt !41_D	et	f	\N
128324	intellektuaalselt	"intellektuaalselt %intellektuaalse  )LT_mD  <intellektuaalne ;02_A	et	f	\N
128329	auku	auku =auku  (ID  >auku !41_D	et	f	\N
128330	auku	auku =auku  (SgP  >auk !22_S	et	f	\N
128331	auku	auku =auku  (SgAdt  >auk !22_S	et	f	\N
128368	rotveiler	?rotveiler =rotveiler  (SgN  >rotveiler !02_S	et	f	\N
128369	tuvi	tuvi =tuvi  (SgN  >tuvi !17_S	et	f	\N
128370	tuvi	tuvi =tuvi  (SgG  >tuvi !17_S	et	f	\N
128371	tuvi	tuvi =tuvi  (SgP  >tuvi !17_S	et	f	\N
128377	momentil	?momentil =momenti  (SgAd  >momenti !01_S	et	f	\N
128378	unistuses	unistuses =unistuse  (SgIn  >unistus !11_S	et	f	\N
128379	unistuses	"unistus %unista  )US_vS  <unistama ;27_V	et	f	\N
128383	mäede	?mäede =mäe  (PlG  >mäe !26_S	et	f	\N
128384	mäede	?mäede =mäede  (SgN  >mäede !06_S	et	f	\N
128385	mäede	?mäede =mäede  (PlP  >mäed !22_S	et	f	\N
128386	mäede	?mäede =mäede  (IndPrPs_  >mäedema !27_V	et	f	\N
128387	mäede	?mäede =mäede  (ImpPrSg2  >mäedema !27_V	et	f	\N
128398	sõnakulmatuse	?sõnakulmatuse =sõnakulmatuse  (SgG  >sõnakulmatus !11?09_S	et	f	\N
128399	sõnakulmatuse	?sõnakulmatuse =kulmatuse  (SgG  >sõna+kulmatus !11_S	et	f	\N
128406	keelelist	keelelist =keelelis  (SgP  >keeleline !12_A	et	f	\N
128408	keelelist	"keeleline %keele  )LINE_aA  <keel ;13_S	et	f	\N
128409	adekvaatsust	adekvaatsust =adekvaatsus  (SgP  >adekvaatsus !11~09_S	et	f	\N
128410	adekvaatsust	"adekvaatsus %adekvaatse  )US_aS  <adekvaatne ;02_A	et	f	\N
128411	sünkroonsust	sünkroonsust =sünkroonsus  (SgP  >sünkroonsus !11~09_S	et	f	\N
128412	sünkroonsust	"sünkroonsus %sünkroonse  )US_aS  <sünkroonne ;02_A	et	f	\N
128438	tv	### tv	et	f	\N
128439	üldmulje	üldmulje =mulje  (SgN  >üld+mulje !06_S	et	f	\N
128440	üldmulje	üldmulje =mulje  (SgG  >üld+mulje !06_S	et	f	\N
128441	subtiitrid	subtiitrid =subtiitri  (PlN  >subtiiter !02_S	et	f	\N
128442	subtiitrid	subtiitrid =tiitri  (PlN  >sub+tiiter !02_S	et	f	\N
128466	right	?right =right  (SgN  >right !22_S	et	f	\N
128496	kanal	kanal =kana  (SgAd  >kana !17_S	et	f	\N
128497	kanal	kanal =kanal  (SgN  >kanal !02_S	et	f	\N
128502	kasti	kasti =kasti  (SgG  >kast !22_S	et	f	\N
128503	kasti	kasti =kasti  (SgP  >kast !22_S	et	f	\N
128504	kasti	kasti =kasti  (SgAdt  >kast !22_S	et	f	\N
128512	pöördumine	pöördumine =pöördumine  (SgN  >pöördumine !12_S	et	f	\N
128513	pöördumine	"pöördumine %pöördu  )MINE_vS  <pöörduma ;27_V	et	f	\N
128531	väsitavaks	väsitavaks =väsitava  (SgTr  >väsitav !02_A	et	f	\N
128532	väsitavaks	"väsitav %väsi  )TAV_vAS  <väsima ;27_V	et	f	\N
128533	väsitavaks	"väsitav %väsita  )V_vA  <väsitama ;27_V	et	f	\N
128556	filmis	filmis =filmi  (SgIn  >film !22_S	et	f	\N
128557	filmis	filmis =filmi  (IndIpfSg3  >filmima !28_V	et	f	\N
128566	vaatajale	vaatajale =vaataja  (SgAll  >vaataja !01_S	et	f	\N
128567	vaatajale	"vaataja %vaata  )JA_vS  <vaatama ;29_V	et	f	\N
128576	vaheldusid	vaheldusid =vaheldu  (IndIpfSg2  >vahelduma !27_V	et	f	\N
128577	vaheldusid	vaheldusid =vaheldu  (IndIpfPl3  >vahelduma !27_V	et	f	\N
128578	kiirusega	kiirusega =kiiruse  (SgKom  >kiirus !11~09_S	et	f	\N
128579	kiirusega	"kiirus %kiire  )US_aS  <kiire ;01_A	et	f	\N
128602	tagaplaanil	tagaplaanil =tagaplaanil  (ID  >taga+plaanil !41_D	et	f	\N
128603	tagaplaanil	tagaplaanil =plaani  (SgAd  >taga+plaan !22_S	et	f	\N
128618	subtiitre	?subtiitre =tiitre  (SgN  >sub+tiitre !06_S	et	f	\N
128619	subtiitre	?subtiitre =tiitre  (SgG  >sub+tiitre !06_S	et	f	\N
128630	mahast	?mahast =mahas  (SgP  >mahas !09_S	et	f	\N
128631	mahast	?mahast =mahas  (SgP  >mahane !10_A	et	f	\N
128643	hiiri	hiiri =hiir  (PlP  >hiir !13_S	et	f	\N
128644	hiiri	hiiri =hiiri  (SgG  >hiir !22_A	et	f	\N
128645	hiiri	hiiri =hiiri  (SgP  >hiir !22_A	et	f	\N
128646	hiiri	hiiri =hiiri  (SgAdt  >hiir !22_A	et	f	\N
128656	kiusata	kiusata =kiusa  (Inf  >kiusama !29_V	et	f	\N
128657	kiusata	kiusata =kiusa  (IndPrIps_  >kiusama !29_V	et	f	\N
128666	pereisa	pereisa =isa  (SgN  >pere+isa !17_S	et	f	\N
128667	pereisa	pereisa =isa  (SgG  >pere+isa !17_S	et	f	\N
128668	pereisa	pereisa =isa  (SgP  >pere+isa !17_S	et	f	\N
128682	häälesid	?häälesid =hääle  (IndIpfSg2  >häälema !27_V	et	f	\N
128683	häälesid	?häälesid =hääle  (IndIpfPl3  >häälema !27_V	et	f	\N
128700	õpilaskodu	õpilaskodu =kodu  (SgN  >õpilas+kodu !17_S	et	f	\N
128701	õpilaskodu	õpilaskodu =kodu  (SgG  >õpilas+kodu !17_S	et	f	\N
128702	õpilaskodu	õpilaskodu =kodu  (SgP  >õpilas+kodu !17_S	et	f	\N
128715	remonditud	remonditud =remondi  (PtsPtIps  >remontima !28_V	et	f	\N
128716	remonditud	remonditud =remonditu  (PlN  >remonditu !01_A	et	f	\N
128354	pirita	?pirita =pirita  (IndPrPs_  >piritama !27_V	et	f	\N
128355	pirita	?pirita =pirita  (ImpPrSg2  >piritama !27_V	et	f	\N
128356	kivikallas	kivikallas =kalla  (SgIn  >kivi+kalla !16_S	et	f	\N
128357	kivikallas	kivikallas =kallas  (SgN  >kivi+kallas !07_S	et	f	\N
128360	kallas	kallas =kalla  (SgIn  >kalla !16_S	et	f	\N
128361	kallas	kallas =kalla  (IndIpfSg3  >kallama !29_V	et	f	\N
128362	kallas	kallas =kallas  (SgN  >kallas !07_S	et	f	\N
128392	eramajdes	?eramajdes =eramajde  (PlIn  >eramajd !22_S	et	f	\N
128393	eramajdes	?eramajdes =majde  (SgIn  >era+majde !06_S	et	f	\N
128394	eramajdes	?eramajdes =majde  (PlIn  >era+majd !22_S	et	f	\N
128395	eramajdes	?eramajdes =majdes  (SgN  >era+majdes !09_S	et	f	\N
128400	subtitreerimispõhimõtete	### subtitreerimispõhimõtete	et	f	\N
128405	paigutust	paigutust =paigutus  (SgP  >paigutus !11_S	et	f	\N
128407	paigutust	"paigutus %paiguta  )US_vS  <paigutama ;27_V	et	f	\N
128413	sarja	sarja =sarja  (SgG  >sari !24_S	et	f	\N
128414	sarja	sarja =sarja  (SgP  >sari !24_S	et	f	\N
128415	sarja	sarja =sarja  (SgAdt  >sari !24_S	et	f	\N
128416	sarja	sarja =sarja  (IndPrPs_  >sarjama !29_V	et	f	\N
128417	sarja	sarja =sarja  (ImpPrSg2  >sarjama !29_V	et	f	\N
128419	mcleodi	?mcleodi =mcleodi  (SgN  >mcleodi !16_S	et	f	\N
128420	mcleodi	?mcleodi =mcleodi  (SgG  >mcleodi !16_S	et	f	\N
128421	mcleodi	?mcleodi =mcleodi  (SgG  >mcleot !22_S	et	f	\N
128422	mcleodi	?mcleodi =mcleodi  (SgP  >mcleod !22_S	et	f	\N
128423	mcleodi	?mcleodi =mcleodi  (SgAdt  >mcleod !22_S	et	f	\N
128424	mcleodi	?mcleodi =mcleodi  (IndPrPs_  >mcleotima !28_V	et	f	\N
128425	mcleodi	?mcleodi =mcleodi  (ImpPrSg2  >mcleotima !28_V	et	f	\N
128436	politseiakadeemia	politseiakadeemia =akadeemia  (SgN  >politsei+akadeemia !01_S	et	f	\N
128437	politseiakadeemia	politseiakadeemia =akadeemia  (SgG  >politsei+akadeemia !01_S	et	f	\N
128446	avas	avas =ava  (SgIn  >ava !17_S	et	f	\N
128448	avas	avas =ava  (IndIpfSg3  >avama !27_V	et	f	\N
128488	lugemist	lugemist =lugemi  (SgEl  >lugem !02_S	et	f	\N
128489	lugemist	lugemist =lugemis  (SgP  >lugemine !12_S	et	f	\N
128490	lugemist	"lugemine %luge  )MINE_vS  <lugema ;28_V	et	f	\N
128491	lugemist	"lugemine %lugemi  )NE_aA  <lugem ;02_S	et	f	\N
128534	vormistus	vormistus =vormistu  (IndIpfSg3  >vormistuma !27_V	et	f	\N
128535	vormistus	vormistus =vormistus  (SgN  >vormistus !11_S	et	f	\N
128536	vormistus	"vormistus %vormista  )US_vS  <vormistama ;27_V	et	f	\N
128537	vormistus	vormistus =istu  (SgIn  >vorm+ist !22_S	et	f	\N
128549	vaatleja	vaatleja =vaatleja  (SgN  >vaatleja !01_S	et	f	\N
128550	vaatleja	"vaatleja %vaatle  )JA_vS  <vaatlema ;30_V	et	f	\N
128551	vaatleja	vaatleja =vaatleja  (SgG  >vaatleja !01_S	et	f	\N
128554	kujundamise	kujundamise =kujundamise  (SgG  >kujundamine !12_S	et	f	\N
128555	kujundamise	"kujundamine %kujunda  )MINE_vS  <kujundama ;27_V	et	f	\N
128558	tähelepanelikult	tähelepanelikult =kult  (SgN  >tähe+lepa+neli+kult !22_S	et	f	\N
128559	tähelepanelikult	tähelepanelikult =neliku  (SgAbl  >tähe+lepa+nelik !02_S	et	f	\N
128560	tähelepanelikult	tähelepanelikult =paneliku  (SgAbl  >tähele+panelik !25_A	et	f	\N
128561	tähelepanelikult	"tähele+panelikult %paneliku  )LT_mD  <tähele+panelik ;25_A	et	f	\N
128604	kõnelused	kõnelused =kõneluse  (PlN  >kõnelus !11_S	et	f	\N
128605	kõnelused	"kõnelus %kõnele  )US_vS  <kõnelema ;27_V	et	f	\N
128620	alternattivi	?alternattivi =alternattivi  (ID  >alternattivi !41_D	et	f	\N
128621	alternattivi	?alternattivi =alternattivi  (SgG  >alternattiv !02_A	et	f	\N
128622	alternattivi	?alternattivi =ernattivi  (SgG  >alt+ernattiv !02_A	et	f	\N
128627	jähima	?jähima =jähi  (Sup  >jähima !27_V	et	f	\N
128628	jähima	?jähima =jähima  (SgG  >jähim !02_A	et	f	\N
128629	jööb	?jööb =jööb  (SgN  >jööb !22_S	et	f	\N
128647	muinasjutudes	?muinasjutudes =muinasjutu  (Ger  >muinasjutuma !27_V	et	f	\N
128648	muinasjutudes	?muinasjutudes =jutu  (PlIn  >muinas+jutu !16_S	et	f	\N
128658	kartnud	kartnud =kart  (PtsPtPs  >kartma !34_V	et	f	\N
128659	kartnud	kartnud =kartnu  (PlN  >kartnu !01_S	et	f	\N
128660	kartnud	"kartnu %kart  )NU_vS  <kartma ;34_V	et	f	\N
128661	kartnud	kartnud =kartnud  (ID  >kartnud !41_A	et	f	\N
128662	kartnud	"kartnud %kart  )NUD_vA  <kartma ;34_V	et	f	\N
128678	kopeerida	kopeerida =kopeeri  (Inf  >kopeerima !28_V	et	f	\N
128679	kopeerida	kopeerida =ida  (SgN  >kopeer+ida !17_S	et	f	\N
128680	kopeerida	kopeerida =ida  (SgG  >kopeer+ida !17_S	et	f	\N
128681	kopeerida	kopeerida =ida  (SgP  >kopeer+ida !17_S	et	f	\N
128684	lobisemise	lobisemise =lobisemise  (SgG  >lobisemine !12_S	et	f	\N
128685	lobisemise	"lobisemine %lobise  )MINE_vS  <lobisema ;27_V	et	f	\N
128698	pärnust	pärnust =pärnu  (SgEl  >pärnu !01_H	et	f	\N
128699	pärnust	pärnust =us  (SgP  >pärn+uks !14_S	et	f	\N
128712	maia	maia =maia  (SgN  >maia !16_S	et	f	\N
128713	maia	maia =maia  (SgG  >maias !07_A	et	f	\N
128714	maia	maia =maia  (SgG  >maia !16_S	et	f	\N
128744	tegemata	tegemata =tege  (SupAb  >tegema !28_V	et	f	\N
128745	tegemata	tegemata =tegemata  (ID  >tegemata !41_A	et	f	\N
128746	tegemata	"tegemata %tege  )MATA_vA  <tegema ;28_V	et	f	\N
128749	koristavad	koristavad =korista  (IndPrPl3  >koristama !27_V	et	f	\N
128511	helindatud	"helindatud %helinda  )TUD_vA  <helindama ;27_V	et	f	\N
128538	paigutus	paigutus =paigutu  (IndIpfSg3  >paigutuma !27_V	et	f	\N
128539	paigutus	paigutus =paigutus  (SgN  >paigutus !11_S	et	f	\N
128540	paigutus	"paigutus %paiguta  )US_vS  <paigutama ;27_V	et	f	\N
128541	vasakus	vasakus =vasaku  (SgIn  >vasak !02_A	et	f	\N
128542	vasakus	vasakus =vasakus  (SgN  >vasakus !11_S	et	f	\N
128543	vasakus	"vasakus %vasaku  )US_aS  <vasak ;02_A	et	f	\N
128562	subtiitreid	subtiitreid =subtiitre  (PlP  >subtiiter !02_S	et	f	\N
128563	subtiitreid	subtiitreid =tiitre  (PlP  >sub+tiiter !02_S	et	f	\N
128569	aitähh	?aitähh =aitähh  (SgN  >aitähh !22_S	et	f	\N
128598	rkasin	?rkasin =rkasi  (IndPrSg1  >rkasima !27_V	et	f	\N
128599	rkasin	?rkasin =rkasin  (SgN  >rkasin !02_S	et	f	\N
128611	häirinud	häirinud =häiri  (PtsPtPs  >häirima !28_V	et	f	\N
128612	häirinud	häirinud =häirinu  (PlN  >häirinu !01_S	et	f	\N
128613	häirinud	"häirinu %häiri  )NU_vS  <häirima ;28_V	et	f	\N
128614	häirinud	häirinud =häirinud  (ID  >häirinud !41_A	et	f	\N
128615	häirinud	"häirinud %häiri  )NUD_vA  <häirima ;28_V	et	f	\N
128623	kanaleid	kanaleid =kanale  (PlP  >kanal !02_S	et	f	\N
128624	kanaleid	kanaleid =lei  (PlN  >kana+lei !26_S	et	f	\N
128625	kanaleid	kanaleid =lei  (SgP  >kana+lei !26_S	et	f	\N
128626	kanaleid	kanaleid =leid  (SgN  >kana+leid !22_S	et	f	\N
128632	soovinud	soovinud =soovi  (PtsPtPs  >soovima !28_V	et	f	\N
128633	soovinud	soovinud =soovinu  (PlN  >soovinu !01_S	et	f	\N
128634	soovinud	"soovinu %soovi  )NU_vS  <soovima ;28_V	et	f	\N
128635	soovinud	soovinud =soovinud  (ID  >soovinud !41_A	et	f	\N
128636	soovinud	"soovinud %soovi  )NUD_vA  <soovima ;28_V	et	f	\N
128637	soovinud	soovinud =vinu  (PlN  >soo+vinu !17_S	et	f	\N
128669	meremees	meremees =mee  (SgIn  >mere+mesi !15_S	et	f	\N
128670	meremees	meremees =mees  (SgN  >mere+mees !13_S	et	f	\N
128673	roheline	roheline =roheline  (SgN  >roheline !12_A	et	f	\N
128674	roheline	"roheline %rohe  )LINE_aA  <rohe ;16_S	et	f	\N
128676	sinikate	sinikate =sinika  (PlG  >sinikas !02_S	et	f	\N
128677	sinikate	sinikate =kate  (SgN  >sini+kate !06_S	et	f	\N
128686	räägiv	?räägiv =räägi  (PtsPrPs  >räägima !28_V	et	f	\N
128687	räägiv	?räägiv =räägiv  (SgN  >räägiv !02_A	et	f	\N
128693	ühielamus	?ühielamus =ühielamu  (IndIpfSg3  >ühielamuma !27_V	et	f	\N
128697	ühielamus	?ühielamus =ühielamus  (SgN  >ühielamus !11?09_S	et	f	\N
128706	kõrgemale	kõrgemale =kõrgema  (SgAll  >kõrgem !02_A	et	f	\N
128707	kõrgemale	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
128708	kõrgemale	kõrgemale =kõrgemale  (ID  >kõrgemale !41_D	et	f	\N
128709	kõrgemale	kõrgemale =male  (SgN  >kõrge+male !16_S	et	f	\N
128710	kõrgemale	kõrgemale =male  (SgG  >kõrge+male !16_S	et	f	\N
128711	kõrgemale	kõrgemale =ema  (SgAll  >kõrg+ema !17_S	et	f	\N
128721	helesiniste	?helesiniste =helesinis  (PlG  >helesinis !09_S	et	f	\N
128722	helesiniste	?helesiniste =helesiniste  (PlP  >helesinist !22_S	et	f	\N
128723	helesiniste	?helesiniste =sinis  (PlG  >hele+sinis !09_S	et	f	\N
128724	helesiniste	?helesiniste =sinis  (PlG  >hele+sinine !10_AS	et	f	\N
128725	helesiniste	?helesiniste =siniste  (PlP  >hele+sinist !22_S	et	f	\N
128728	elamises	elamises =elamise  (SgIn  >elamine !12_S	et	f	\N
128729	elamises	"elamine %ela  )MINE_vS  <elama ;27_V	et	f	\N
128742	õhkkonnale	õhkkonnale =õhkkonna  (SgAll  >õhkkond !22_S	et	f	\N
128743	õhkkonnale	õhkkonnale =konna  (SgAll  >õhk+konn !22_S	et	f	\N
128771	muinastuttud	?muinastuttud =muinastuttu  (IndPrSg2  >muinastuttuma !27_V	et	f	\N
128772	muinastuttud	?muinastuttud =tuttud  (ID  >muinas+tuttud !41_A	et	f	\N
128775	abitseb	?abitseb =abitse  (IndPrSg3  >abitsema !27_V	et	f	\N
128776	töödada	?töödada =dada  (SgN  >töö+dada !17_S	et	f	\N
128777	töödada	?töödada =dada  (SgG  >töö+dada !17_S	et	f	\N
128778	töödada	?töödada =dada  (SgP  >töö+dada !17_S	et	f	\N
128794	huvitavatest	huvitavatest =huvitava  (PlEl  >huvitav !02_A	et	f	\N
128795	huvitavatest	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
128796	huvitavatest	huvitavatest =test  (SgN  >huvi+tava+test !22_S	et	f	\N
128822	töötajaid	töötajaid =töötaja  (PlP  >töötaja !01_S	et	f	\N
128823	töötajaid	"töötaja %tööta  )JA_vS  <töötama ;27_V	et	f	\N
128824	abivalmisad	?abivalmisad =abivalmisa  (PlN  >abivalmisa !16_S	et	f	\N
128825	abivalmisad	?abivalmisad =valmisa  (PlN  >abi+valmisa !01_S	et	f	\N
128833	tõestasid	tõestasid =tõesta  (IndIpfSg2  >tõestama !27_V	et	f	\N
128834	tõestasid	tõestasid =tõesta  (IndIpfPl3  >tõestama !27_V	et	f	\N
128835	kolmest	kolmest =kolme  (SgEl  >kolm !22_N	et	f	\N
128836	kolmest	kolmest =kolme  (PlEl  >kolm !22_N	et	f	\N
128837	kolmest	kolmest =kolmes  (SgP  >kolmene !10_AS	et	f	\N
128838	kolmest	"kolmene %kolme  )NE_aA  <kolm ;22_N	et	f	\N
128866	väja	?väja =väja  (SgN  >väja !17_S	et	f	\N
128867	väja	?väja =väja  (SgG  >väja !17_S	et	f	\N
128868	väja	?väja =väja  (SgP  >väja !17_S	et	f	\N
128869	väja	?väja =väja  (IndPrPs_  >väjama !27_V	et	f	\N
128870	väja	?väja =väja  (ImpPrSg2  >väjama !27_V	et	f	\N
128878	unist	unist =unis  (SgP  >unine !10_A	et	f	\N
128515	soovisin	soovisin =visin  (SgN  >soo+visin !02_S	et	f	\N
128519	vaheldus	vaheldus =vaheldu  (IndIpfSg3  >vahelduma !27_V	et	f	\N
128520	vaheldus	vaheldus =vaheldus  (SgN  >vaheldus !11_S	et	f	\N
128521	vaheldus	"vaheldus %vahelda  )US_vS  <vaheldama ;27_V	et	f	\N
128529	igavaks	igavaks =igava  (SgTr  >igav !02_A	et	f	\N
128530	igavaks	igavaks =vaks  (SgN  >iga+vaks !22_S	et	f	\N
128568	tähandab	?tähandab =tähanda  (IndPrSg3  >tähandama !27_V	et	f	\N
128570	prego	?prego =prego  (SgN  >prego !17~16_S	et	f	\N
128571	prego	?prego =prego  (SgG  >prego !17~16_S	et	f	\N
128572	prego	?prego =prego  (SgP  >prego !17_S	et	f	\N
128573	jäätud	jäätud =jäätu  (PlN  >jäätu !01_A	et	f	\N
128574	jäätud	"jäätu %jää  )TU2_kA  <jää ;26_S	et	f	\N
128575	jäätud	jäätud =jäätu  (IndPrSg2  >jäätuma !27_V	et	f	\N
128580	aeglasemalt	aeglasemalt =aeglasema  (SgAbl  >aeglasem !02_A	et	f	\N
128581	aeglasemalt	"aeglasem %aeglase  )M_cA  <aeglane ;10_A	et	f	\N
128582	aeglasemalt	"aeglasem %aeglase  )M_cA  <aeglane ;12_A	et	f	\N
128583	aeglasemalt	aeglasemalt =aeglasemalt  (ID  >aeglasemalt !41_D	et	f	\N
128584	aeglasemalt	"aeglasemalt %aeglase  )MALT_mD  <aeglane ;10_A	et	f	\N
128585	aeglasemalt	"aeglasemalt %aeglase  )MALT_mD  <aeglane ;12_A	et	f	\N
128594	kordi	kordi =kordi  (SgP  >kord !22_S	et	f	\N
128595	kordi	kordi =kordi  (SgAdt  >kord !22_S	et	f	\N
128596	kordi	kordi =kordi  (PlP  >kord !22_S	et	f	\N
128606	esikohal	esikohal =koha  (SgAd  >esi+koha !17_S	et	f	\N
128607	esikohal	esikohal =koha  (SgAd  >esi+koht !22_S	et	f	\N
128608	toimuv	toimuv =toimu  (PtsPrPs  >toimuma !27_V	et	f	\N
128609	toimuv	toimuv =toimuv  (SgN  >toimuv !02_A	et	f	\N
128610	toimuv	"toimuv %toimu  )V_vA  <toimuma ;27_V	et	f	\N
128651	hiire	hiire =hiire  (SgG  >hiir !13_S	et	f	\N
128652	hiire	hiire =hiire  (PlP  >hiir !22_A	et	f	\N
128653	jubedalt	jubedalt =jubeda  (SgAbl  >jube !02_A	et	f	\N
128654	jubedalt	jubedalt =jubedalt  (ID  >jubedalt !41_D	et	f	\N
128655	jubedalt	"jubedalt %jubeda  )LT_mD  <jube ;02_A	et	f	\N
128688	närvi	närvi =närvi  (ID  >närvi !41_D	et	f	\N
128689	närvi	närvi =närvi  (SgG  >närv !22_S	et	f	\N
128690	närvi	närvi =närvi  (SgP  >närv !22_S	et	f	\N
128691	närvi	närvi =närvi  (SgAdt  >närv !22_S	et	f	\N
128692	meditsiinikooli	meditsiinikooli =kooli  (SgG  >meditsiini+kool !22_S	et	f	\N
128694	meditsiinikooli	meditsiinikooli =kooli  (SgP  >meditsiini+kool !22_S	et	f	\N
128695	meditsiinikooli	meditsiinikooli =kooli  (SgAdt  >meditsiini+kool !22_S	et	f	\N
128696	meditsiinikooli	meditsiinikooli =kooli  (PlP  >meditsiini+kool !22_S	et	f	\N
128703	hoones	hoones =hoone  (SgIn  >hoone !06_S	et	f	\N
128704	hoones	"hoone %hoo  )NE_aA  <hoog ;22_S	et	f	\N
128705	hoones	hoones =hoone  (PlIn  >hoon !22_A	et	f	\N
128730	korridoris	?korridoris =korridori  (SgIn  >korridor !19_S	et	f	\N
128731	korridoris	?korridoris =korridoris  (SgN  >korridoris !09_S	et	f	\N
128752	lahe	lahe =lahe  (SgN  >lahe !02_A	et	f	\N
128753	lahe	lahe =lahe  (SgN  >lahe !05_S	et	f	\N
128754	lahe	lahe =lahe  (SgG  >laht !22_S	et	f	\N
128755	artkle	?artkle =artkle  (SgN  >artkle !06_S	et	f	\N
128756	artkle	?artkle =artkle  (SgG  >artkle !06_S	et	f	\N
128757	artkle	?artkle =artkle  (PlP  >artkl !22_S	et	f	\N
128758	artkle	?artkle =artkle  (IndPrPs_  >artklema !30_V	et	f	\N
128759	artkle	?artkle =artkle  (ImpPrSg2  >artklema !30_V	et	f	\N
128770	infoormeerida	?infoormeerida =infoormeeri  (Inf  >infoormeerima !28_V	et	f	\N
128779	lõpetasid	lõpetasid =lõpeta  (IndIpfSg2  >lõpetama !27_V	et	f	\N
128780	lõpetasid	lõpetasid =lõpeta  (IndIpfPl3  >lõpetama !27_V	et	f	\N
128788	rahalikult	?rahalikult =rahaliku  (SgAbl  >rahalik !25_A	et	f	\N
128789	rahalikult	?rahalikult =rahalikult  (ID  >rahalikult !41_D	et	f	\N
128792	aruannet	aruannet =anne  (SgP  >aru+anne !05_S	et	f	\N
128793	aruannet	aruannet =anne  (SgP  >aru+anne !06_S	et	f	\N
128797	huvitanud	huvitanud =huvita  (PtsPtPs  >huvitama !27_V	et	f	\N
128798	huvitanud	huvitanud =huvitanu  (PlN  >huvitanu !01_S	et	f	\N
128799	huvitanud	"huvitanu %huvita  )NU_vS  <huvitama ;27_V	et	f	\N
128800	huvitanud	huvitanud =huvitanud  (ID  >huvitanud !41_A	et	f	\N
128801	huvitanud	"huvitanud %huvita  )NUD_vA  <huvitama ;27_V	et	f	\N
128802	huvitanud	huvitanud =tanu  (PlN  >huvi+tanu !17_S	et	f	\N
128810	suhtlemist	suhtlemist =suhtlemis  (SgP  >suhtlemine !12_S	et	f	\N
128811	suhtlemist	"suhtlemine %suhtle  )MINE_vS  <suhtlema ;30_V	et	f	\N
128817	kavatsenud	kavatsenud =kavatse  (PtsPtPs  >kavatsema !27_V	et	f	\N
128818	kavatsenud	kavatsenud =kavatsenu  (PlN  >kavatsenu !01_S	et	f	\N
128819	kavatsenud	"kavatsenu %kavatse  )NU_vS  <kavatsema ;27_V	et	f	\N
128820	kavatsenud	kavatsenud =kavatsenud  (ID  >kavatsenud !41_A	et	f	\N
128821	kavatsenud	"kavatsenud %kavatse  )NUD_vA  <kavatsema ;27_V	et	f	\N
128842	kaugemal	kaugemal =kaugema  (SgAd  >kaugem !02_A	et	f	\N
128843	kaugemal	"kaugem %kauge  )M_cA  <kauge ;01_A	et	f	\N
128844	kaugemal	kaugemal =kaugemal  (ID  >kaugemal !41_D	et	f	\N
128845	kaugemal	kaugemal =ema  (SgAd  >kaug+ema !17_S	et	f	\N
128850	pliiatsiga	pliiatsiga =pliiatsi  (SgKom  >pliiats !02_S	et	f	\N
128523	muutu	"muutu %muu  )TU2_kA  <muu ;26_S	et	f	\N
128524	muutu	muutu =muutu  (SgG  >muutu !01_A	et	f	\N
128525	muutu	muutu =muutu  (SgP  >muut !22_S	et	f	\N
128526	muutu	muutu =muutu  (SgAdt  >muut !22_S	et	f	\N
128527	muutu	muutu =muutu  (IndPrPs_  >muutuma !27_V	et	f	\N
128528	muutu	muutu =muutu  (ImpPrSg2  >muutuma !27_V	et	f	\N
128544	tõlkinud	tõlkinud =tõlki  (PtsPtPs  >tõlkima !28_V	et	f	\N
128545	tõlkinud	tõlkinud =tõlkinu  (PlN  >tõlkinu !01_S	et	f	\N
128546	tõlkinud	"tõlkinu %tõlki  )NU_vS  <tõlkima ;28_V	et	f	\N
128547	tõlkinud	tõlkinud =tõlkinud  (ID  >tõlkinud !41_A	et	f	\N
128548	tõlkinud	"tõlkinud %tõlki  )NUD_vA  <tõlkima ;28_V	et	f	\N
128552	märka	märka =märka  (IndPrPs_  >märkama !29_V	et	f	\N
128553	märka	märka =märka  (ImpPrSg2  >märkama !29_V	et	f	\N
128564	gracia	?gracia =gracia  (SgN  >gracia !01_S	et	f	\N
128565	gracia	?gracia =gracia  (SgG  >gracia !01_S	et	f	\N
128586	kujundus	kujundus =kujundus  (SgN  >kujundus !11_S	et	f	\N
128587	kujundus	"kujundus %kujunda  )US_vS  <kujundama ;27_V	et	f	\N
128588	põhiidee	põhiidee =idee  (SgN  >põhi+idee !26_S	et	f	\N
128589	põhiidee	põhiidee =idee  (SgG  >põhi+idee !26_S	et	f	\N
128590	kao	kao =kao  (SgG  >kabu !18_S	et	f	\N
128591	kao	kao =kao  (SgG  >kadu !18_S	et	f	\N
128592	kao	kao =kao  (IndPrPs_  >kaduma !28_V	et	f	\N
128593	kao	kao =kao  (ImpPrSg2  >kaduma !28_V	et	f	\N
128597	ä	### ä	et	f	\N
128600	kujundamisel	kujundamisel =kujundamise  (SgAd  >kujundamine !12_S	et	f	\N
128601	kujundamisel	"kujundamine %kujunda  )MINE_vS  <kujundama ;27_V	et	f	\N
128616	üheaegselt	üheaegselt =aegse  (SgAbl  >ühe+aegne !02_A	et	f	\N
128617	üheaegselt	"ühe+aegselt %aegse  )LT_mD  <ühe+aegne ;02_A	et	f	\N
128638	pistisin	?pistisin =pisti  (IndIpfSg1  >pistima !28_V	et	f	\N
128639	pistisin	?pistisin =pistisin  (SgN  >pistisin !19_S	et	f	\N
128640	pistisin	?pistisin =isin  (SgN  >pist+isin !02_S	et	f	\N
128641	emased	emased =emase  (PlN  >emane !10_AS	et	f	\N
128642	emased	"emane %ema  )NE_aA  <ema ;17_S	et	f	\N
128649	emane	emane =emane  (SgN  >emane !10_AS	et	f	\N
128650	emane	"emane %ema  )NE_aA  <ema ;17_S	et	f	\N
128663	turtsusid	turtsusid =turtsu  (PlP  >turts !22_S	et	f	\N
128664	turtsusid	turtsusid =turtsu  (IndIpfSg2  >turtsuma !28_V	et	f	\N
128665	turtsusid	turtsusid =turtsu  (IndIpfPl3  >turtsuma !28_V	et	f	\N
128671	lõunamaadest	lõunamaadest =maa  (PlEl  >lõuna+maa !26_S	et	f	\N
128672	lõunamaadest	lõunamaadest =maade  (PlEl  >lõuna+maat !22_S	et	f	\N
128675	tiivadega	?tiivadega =tiiva  (PlKom  >tiiva !16_S	et	f	\N
128732	kuulame	kuulame =kuula  (IndPrPl1  >kuulama !29_V	et	f	\N
128733	kuulame	kuulame =lame  (SgN  >kuu+lame !02_A	et	f	\N
128760	lõpetamisest	lõpetamisest =lõpetamise  (SgEl  >lõpetamine !12_S	et	f	\N
128761	lõpetamisest	"lõpetamine %lõpeta  )MINE_vS  <lõpetama ;27_V	et	f	\N
128790	igavuiset	?igavuiset =vuise  (SgP  >iga+vuise !06_S	et	f	\N
128803	rahulikuid	?rahulikuid =rahulikui  (PlN  >rahulikui !26_S	et	f	\N
128804	rahulikuid	?rahulikuid =rahulikui  (SgP  >rahulikui !26_S	et	f	\N
128805	rahulikuid	?rahulikuid =ikui  (PlN  >rahul+ikui !26_S	et	f	\N
128806	rahulikuid	?rahulikuid =ikui  (SgP  >rahul+ikui !26_S	et	f	\N
128807	rahulikuid	?rahulikuid =ikuid  (SgN  >rahul+ikuid !22_S	et	f	\N
128829	kiindumus	kiindumus =kiindumus  (SgN  >kiindumus !11_S	et	f	\N
128830	kiindumus	"kiindumus %kiindu  )MUS_vS  <kiinduma ;27_V	et	f	\N
128839	kooliajast	kooliajast =aja  (SgEl  >kooli+aeg !22_S	et	f	\N
128840	kooliajast	kooliajast =ajas  (SgP  >kooli+ajane !10_A	et	f	\N
128841	kooliajast	"kooli+ajane %aja  )NE_aA  <kooli+aeg ;22_S	et	f	\N
128846	presssekretärina	?presssekretärina =presssekretäri  (SgEs  >presssekretär !19_S	et	f	\N
128847	presssekretärina	?presssekretärina =presssekretärina  (SgG  >presssekretärin !19_S	et	f	\N
128848	presssekretärina	?presssekretärina =presssekretärina  (SgP  >presssekretärin !19_S	et	f	\N
128849	presssekretärina	?presssekretärina =presssekretärina  (SgAdt  >presssekretärin !19_S	et	f	\N
128852	muuga	muuga =muu  (SgKom  >muu !26_S	et	f	\N
128853	muuga	muuga =muu  (SgKom  >muu !26_P	et	f	\N
128860	lehtede	lehtede =lehte  (PlG  >leht !22_S	et	f	\N
128861	lehtede	lehtede =ede  (SgN  >leht+ede !16_S	et	f	\N
128862	lehtede	lehtede =ede  (SgG  >leht+ede !16_S	et	f	\N
128875	objektiivselt	objektiivselt =objektiivse  (SgAbl  >objektiivne !02_A	et	f	\N
128876	objektiivselt	objektiivselt =objektiivselt  (ID  >objektiivselt !41_D	et	f	\N
128877	objektiivselt	"objektiivselt %objektiivse  )LT_mD  <objektiivne ;02_A	et	f	\N
128880	viitud	?viitud =viitu  (PlN  >viitu !01_A	et	f	\N
128881	viitud	?viitud =viitu  (IndPrSg2  >viituma !27_V	et	f	\N
128882	viitud	?viitud =viitud  (ID  >viitud !41_A	et	f	\N
128885	tõelised	tõelised =tõelise  (PlN  >tõeline !12?10_A	et	f	\N
128886	tõelised	"tõeline %tõe  )LINE_aA  <tõsi ;15_S	et	f	\N
128887	tõelised	"tõeline %tõe  )LINE_aA  <tõde ;18_S	et	f	\N
128896	suhtlemistega	suhtlemistega =suhtlemis  (PlKom  >suhtlemine !12_S	et	f	\N
128897	suhtlemistega	"suhtlemine %suhtle  )MINE_vS  <suhtlema ;30_V	et	f	\N
128929	valivad	valivad =vali  (IndPrPl3  >valima !27_V	et	f	\N
128717	remonditud	"remonditu %remondi  )TU1_vS  <remontima ;28_V	et	f	\N
128718	remonditud	"remonditu %remondi  )TU2_kA  <remont ;22_S	et	f	\N
128719	remonditud	remonditud =remonditud  (ID  >remonditud !41_A	et	f	\N
128720	remonditud	"remonditud %remondi  )TUD_vA  <remontima ;28_V	et	f	\N
128726	ühiselamu	ühiselamu =elamu  (SgN  >ühis+elamu !01_S	et	f	\N
128727	ühiselamu	ühiselamu =elamu  (SgG  >ühis+elamu !01_S	et	f	\N
128734	ühikaid	?ühikaid =ühika  (PlP  >ühika !01_S	et	f	\N
128735	ühikaid	?ühikaid =ühika  (PlP  >ühikas !02_S	et	f	\N
128736	ühikaid	?ühikaid =ühikai  (PlN  >ühikai !26_S	et	f	\N
128737	ühikaid	?ühikaid =ühikai  (SgP  >ühikai !26_S	et	f	\N
128738	elamiskohaga	elamiskohaga =koha  (SgKom  >elamis+koha !17_S	et	f	\N
128739	elamiskohaga	elamiskohaga =koha  (SgKom  >elamis+koht !22_S	et	f	\N
128740	harjumused	harjumused =harjumuse  (PlN  >harjumus !11_S	et	f	\N
128741	harjumused	"harjumus %harju  )MUS_vS  <harjuma ;27_V	et	f	\N
128747	ebahea	ebahea =hea  (SgN  >eba+hea !26_AS	et	f	\N
128748	ebahea	ebahea =hea  (SgG  >eba+hea !26_AS	et	f	\N
128786	aktiivsetele	aktiivsetele =aktiivse  (PlAll  >aktiivne !02_A	et	f	\N
128787	aktiivsetele	aktiivsetele =sete  (PlAll  >aktiiv+sett !22_S	et	f	\N
128808	inimestiga	?inimestiga =esti  (SgKom  >inim+esti !16_S	et	f	\N
128809	inimestiga	?inimestiga =esti  (SgKom  >inim+est !22_S	et	f	\N
128814	esseed	esseed =essee  (PlN  >essee !26_S	et	f	\N
128815	esseed	esseed =essee  (SgP  >essee !26_S	et	f	\N
128826	teistes	teistes =teis  (PlIn  >teine !12_OP	et	f	\N
128827	teistes	teistes =teis  (PlIn  >teise !12_P	et	f	\N
128828	teistes	teistes =teiste  (PlIn  >teist !22_S	et	f	\N
128898	internetile	?internetile =neti  (SgAll  >inter+neti !16_S	et	f	\N
128899	internetile	?internetile =neti  (SgAll  >inter+nett !22_AS	et	f	\N
128903	auselt	auselt =auselt  (ID  >auselt !41_D	et	f	\N
128904	auselt	"auselt %au  )SELT_mD  <au ;26_S	et	f	\N
128908	omandamine	omandamine =omandamine  (SgN  >omandamine !12_S	et	f	\N
128909	omandamine	"omandamine %omanda  )MINE_vS  <omandama ;27_V	et	f	\N
128910	meeskonnaks	meeskonnaks =meeskonna  (SgTr  >meeskond !22_S	et	f	\N
128911	meeskonnaks	meeskonnaks =konna  (SgTr  >mees+konn !22_S	et	f	\N
128914	tahtmises	tahtmises =tahtmise  (SgIn  >tahtmine !12?10_S	et	f	\N
128915	tahtmises	"tahtmine %taht  )MINE_vS  <tahtma ;34_V	et	f	\N
128927	rikkalikum	rikkalikum =rikkalikum  (SgN  >rikkalikum !02_A	et	f	\N
128928	rikkalikum	"rikkalikum %rikkaliku  )M_cA  <rikkalik ;25_A	et	f	\N
128981	tavapäraseks	tavapäraseks =seks  (SgN  >tava+pära+seks !22_S	et	f	\N
128982	tavapäraseks	tavapäraseks =pärase  (SgTr  >tava+pärane !10_A	et	f	\N
128983	tavapäraseks	"tava+pärane %pära  )NE_aA  <tava+pära ;17_S	et	f	\N
128996	täita	täita =täi  (SgAb  >täi !26_S	et	f	\N
128997	täita	täita =täi  (IndPrIps_  >täima !27_V	et	f	\N
128998	täita	täita =täit  (Inf  >täitma !34_V	et	f	\N
128999	täita	täita =täita  (IndPrPs_  >täitama !27_V	et	f	\N
129000	täita	täita =täita  (ImpPrSg2  >täitama !27_V	et	f	\N
129013	võimas	võimas =või  (SupIn  >võima !37_V	et	f	\N
129014	võimas	võimas =võimas  (SgN  >võimas !03~05_A	et	f	\N
129023	õpetakse	?õpetakse =õpe  (IndPrIps  >õpema !27_V	et	f	\N
129024	õpetakse	?õpetakse =õpetakse  (SgG  >õpetakne !02_A	et	f	\N
129025	õpetakse	?õpetakse =õpetakse  (PlP  >õpetaks !22_S	et	f	\N
129053	meeletu	meeletu =meeletu  (SgN  >meeletu !01_A	et	f	\N
129054	meeletu	"meeletu %meele  )TU2_kA  <meel ;13_S	et	f	\N
129055	meeletu	meeletu =meeletu  (SgG  >meeletu !01_A	et	f	\N
129056	meeletu	meeletu =letu  (SgN  >mee+letu !16_S	et	f	\N
129057	meeletu	meeletu =letu  (SgG  >mee+letu !16_S	et	f	\N
129065	osata	osata =osa  (SgAb  >osa !17_S	et	f	\N
129066	osata	osata =osa  (Inf  >oskama !29_V	et	f	\N
129067	osata	osata =osa  (IndPrIps_  >oskama !29_V	et	f	\N
129068	osata	osata =osata  (IndPrPs_  >osatama !27_V	et	f	\N
129069	osata	osata =osata  (ImpPrSg2  >osatama !27_V	et	f	\N
129072	kuulud	kuulud =kuulu  (PlN  >kuuld !22_S	et	f	\N
129073	kuulud	kuulud =kuulu  (IndPrSg2  >kuuluma !27_V	et	f	\N
129087	saamise	saamise =saamise  (SgG  >saamine !12?10_S	et	f	\N
129088	saamise	"saamine %saa  )MINE_vS  <saama ;37_V	et	f	\N
129089	saamise	"saamine %saami  )NE_aA  <saam ;22_S	et	f	\N
129096	alatiseks	alatiseks =alatise  (SgTr  >alatine !12_A	et	f	\N
129097	alatiseks	alatiseks =alatiseks  (ID  >alatiseks !41_D	et	f	\N
129100	unistusele	unistusele =unistuse  (SgAll  >unistus !11_S	et	f	\N
129101	unistusele	"unistus %unista  )US_vS  <unistama ;27_V	et	f	\N
129109	mängisid	mängisid =mängi  (PlP  >mäng !22_S	et	f	\N
129110	mängisid	mängisid =mängi  (IndIpfSg2  >mängima !28_V	et	f	\N
129111	mängisid	mängisid =mängi  (IndIpfPl3  >mängima !28_V	et	f	\N
129121	neljast	neljast =nelja  (SgEl  >neljas !02_O	et	f	\N
129122	neljast	neljast =nelja  (SgEl  >neli !24_N	et	f	\N
129123	neljast	neljast =neljas  (SgP  >neljane !10_A	et	f	\N
129124	neljast	"neljane %nelja  )NE_aA  <neli ;24_N	et	f	\N
129174	võite	võite =või  (IndPrPl2  >võima !37_V	et	f	\N
129175	võite	võite =võite  (PlP  >võit !22_S	et	f	\N
128750	koristavad	koristavad =koristava  (PlN  >koristav !02_A	et	f	\N
128751	koristavad	"koristav %korista  )V_vA  <koristama ;27_V	et	f	\N
128762	korraldusest	korraldusest =korralduse  (SgEl  >korraldus !11_S	et	f	\N
128763	korraldusest	"korraldus %korralda  )US_vS  <korraldama ;27_V	et	f	\N
128764	korraldusest	korraldusest =korralduses  (SgP  >korraldusene !12_A	et	f	\N
128765	korraldusest	"korraldusene %korralduse  )NE_aA  <korraldus ;11_S	et	f	\N
128766	palusid	palusid =palu  (PlP  >palu !17_S	et	f	\N
128767	palusid	palusid =palu  (IndIpfSg2  >paluma !27_V	et	f	\N
128768	palusid	palusid =palu  (IndIpfPl3  >paluma !27_V	et	f	\N
128769	sõbradele	?sõbradele =sõbra  (PlAll  >sõbra !16_S	et	f	\N
128773	paranda	paranda =paranda  (IndPrPs_  >parandama !27_V	et	f	\N
128774	paranda	paranda =paranda  (ImpPrSg2  >parandama !27_V	et	f	\N
128781	õppevad	?õppevad =õppe  (IndPrPl3  >õppema !27_V	et	f	\N
128782	õppevad	?õppevad =õppeva  (PlN  >õppeva !01_S	et	f	\N
128783	õppevad	?õppevad =õppeva  (PlN  >õppev !02_A	et	f	\N
128784	veetmine	veetmine =veetmine  (SgN  >veetmine !12?10_S	et	f	\N
128785	veetmine	"veetmine %veet  )MINE_vS  <veetma ;34_V	et	f	\N
128791	esseet	?esseet =esseet  (SgN  >esseet !22_S	et	f	\N
128812	kirjalikuid	?kirjalikuid =kirjalikui  (PlN  >kirjalikui !26_S	et	f	\N
128813	kirjalikuid	?kirjalikuid =kirjalikui  (SgP  >kirjalikui !26_S	et	f	\N
128816	aruanned	### aruanned	et	f	\N
128831	lähedamad	lähedamad =lähedama  (PlN  >lähedam !02_A	et	f	\N
128832	lähedamad	"lähedam %läheda  )M_cA  <läheda ;02_A	et	f	\N
128854	sisene	sisene =sisene  (SgN  >sisene !10_A	et	f	\N
128855	sisene	sisene =sisene  (IndPrPs_  >sisenema !27_V	et	f	\N
128856	sisene	sisene =sisene  (ImpPrSg2  >sisenema !27_V	et	f	\N
128863	looda	looda =loo  (IndPrIps_  >looma !38_V	et	f	\N
128864	looda	looda =looda  (IndPrPs_  >lootma !34_V	et	f	\N
128865	looda	looda =looda  (ImpPrSg2  >lootma !34_V	et	f	\N
128922	unistusi	unistusi =unistusi  (PlP  >unistus !11_S	et	f	\N
128923	unistusi	"unistus %unista  )US_vS  <unistama ;27_V	et	f	\N
128924	eneseväärikust	eneseväärikust =vääriku  (SgEl  >enese+väärik !02_S	et	f	\N
128925	eneseväärikust	eneseväärikust =väärikus  (SgP  >enese+väärikus !11_S	et	f	\N
128926	eneseväärikust	"enese+väärikus %väärika  )US_aS  <enese+väärikas ;02_A	et	f	\N
128936	arusaamisega	arusaamisega =saamise  (SgKom  >aru+saamine !12?10_S	et	f	\N
128937	arusaamisega	"aru+saamine %saami  )NE_aA  <aru+saam ;22_S	et	f	\N
128955	magistrikraadi	magistrikraadi =kraadi  (SgG  >magistri+kraad !22_S	et	f	\N
128956	magistrikraadi	magistrikraadi =kraadi  (SgP  >magistri+kraad !22_S	et	f	\N
128957	magistrikraadi	magistrikraadi =kraadi  (SgAdt  >magistri+kraad !22_S	et	f	\N
128963	julgustavat	julgustavat =julgusta  (KvtPrPs  >julgustama !27_V	et	f	\N
128964	julgustavat	julgustavat =julgustava  (SgP  >julgustav !02_A	et	f	\N
128965	julgustavat	"julgustav %julgusta  )V_vA  <julgustama ;27_V	et	f	\N
128989	ainust	ainust =ainu  (SgEl  >ainus !07_AS	et	f	\N
128990	ainust	ainust =ainu  (SgEl  >ainu !16_S	et	f	\N
128993	ainust	ainust =ainu  (PlEl  >ain !22_S	et	f	\N
128994	ainust	ainust =ainus  (SgP  >ainus !05_AS	et	f	\N
128995	ainust	ainust =ainus  (SgP  >ainus !07_AS	et	f	\N
129001	äitahh	?äitahh =äitahh  (SgN  >äitahh !22_S	et	f	\N
129044	kuuluda	kuuluda =kuulu  (Inf  >kuuluma !27_V	et	f	\N
129045	kuuluda	kuuluda =luda  (SgN  >kuu+luda !17_S	et	f	\N
129046	kuuluda	kuuluda =luda  (SgG  >kuu+luda !17_S	et	f	\N
129047	kuuluda	kuuluda =luda  (SgP  >kuu+luda !17_S	et	f	\N
129063	tähtsama	tähtsama =tähtsama  (SgG  >tähtsam !02_A	et	f	\N
129064	tähtsama	"tähtsam %tähtsa  )M_cA  <tähtis ;02_A	et	f	\N
129074	saatkonnas	saatkonnas =saatkonna  (SgIn  >saatkond !22_S	et	f	\N
129075	saatkonnas	saatkonnas =konna  (SgIn  >saat+konn !22_S	et	f	\N
129086	päeg	?päeg =päeg  (SgN  >päeg !22_S	et	f	\N
129090	ps	### ps	et	f	\N
129091	käekirja	käekirja =kirja  (SgG  >käe+kiri !24_S	et	f	\N
129092	käekirja	käekirja =kirja  (SgP  >käe+kiri !24_S	et	f	\N
129093	käekirja	käekirja =kirja  (SgAdt  >käe+kiri !24_S	et	f	\N
129102	lapsepõlvene	lapsepõlvene =põlvene  (SgN  >lapse+põlvene !10_A	et	f	\N
129103	lapsepõlvene	"lapse+põlvene %põlve  )NE_aA  <lapse+põlv ;22_S	et	f	\N
129104	lapsepõlvene	"lapse+põlvene %põlve  )NE_aA  <lapse+põli ;24_S	et	f	\N
129112	ajalooline	ajalooline =looline  (SgN  >aja+looline !12?10_A	et	f	\N
129113	ajalooline	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
129114	ajalooline	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
129115	ajalooline	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
129116	ajalooline	ajalooline =looline  (SgN  >aja+looline !12?10_S	et	f	\N
129144	õppejõudu	õppejõudu =jõudu  (SgP  >õppe+jõud !22_S	et	f	\N
129145	õppejõudu	õppejõudu =jõudu  (SgAdt  >õppe+jõud !22_S	et	f	\N
129153	spontaanselt	spontaanselt =spontaanse  (SgAbl  >spontaanne !02_A	et	f	\N
129154	spontaanselt	spontaanselt =spontaanselt  (ID  >spontaanselt !41_D	et	f	\N
129155	spontaanselt	"spontaanselt %spontaanse  )LT_mD  <spontaanne ;02_A	et	f	\N
129156	artikkli	?artikkli =artikkli  (SgN  >artikkli !01_S	et	f	\N
129157	artikkli	?artikkli =artikkli  (SgG  >artikkli !01_S	et	f	\N
128851	pliiatsiga	pliiatsiga =atsi  (SgKom  >plii+ats !22_S	et	f	\N
128857	igavalt	igavalt =igava  (SgAbl  >igav !02_A	et	f	\N
128858	igavalt	igavalt =igavalt  (ID  >igavalt !41_D	et	f	\N
128859	igavalt	"igavalt %igava  )LT_mD  <igav ;02_A	et	f	\N
128871	muutumist	muutumist =muutumi  (SgEl  >muutum !02_A	et	f	\N
128872	muutumist	"muutum %muu  )TUM2_cA  <muu ;26_S	et	f	\N
128873	muutumist	muutumist =muutumis  (SgP  >muutumine !12_S	et	f	\N
128874	muutumist	"muutumine %muutu  )MINE_vS  <muutuma ;27_V	et	f	\N
128883	mälestuseks	mälestuseks =mälestuse  (SgTr  >mälestus !11_S	et	f	\N
128884	mälestuseks	"mälestus %mälesta  )US_vS  <mälestama ;27_V	et	f	\N
128891	kõikest	?kõikest =kõikes  (SgP  >kõikes !09_S	et	f	\N
128892	kõikest	?kõikest =kõikes  (SgP  >kõike !12?10_S	et	f	\N
128893	kõikest	?kõikest =kõikes  (SgP  >kõikene !12?10_S	et	f	\N
128894	professionaaliks	professionaaliks =professionaali  (SgTr  >professionaal !22_S	et	f	\N
128895	professionaaliks	professionaaliks =iks  (SgN  >professionaal+iks !22_S	et	f	\N
128912	rebase	rebase =rebase  (SgG  >rebane !10_S	et	f	\N
128913	rebase	"rebane %reba  )NE_aA  <reba ;17_S	et	f	\N
128916	soovides	soovides =soovi  (PlIn  >soov !22_S	et	f	\N
128917	soovides	soovides =soovi  (Ger  >soovima !28_V	et	f	\N
128938	tuplide	### tuplide	et	f	\N
128939	viibimiseks	viibimiseks =viibimise  (SgTr  >viibimine !12_S	et	f	\N
128940	viibimiseks	"viibimine %viibi  )MINE_vS  <viibima ;27_V	et	f	\N
128948	realiseerimiseks	realiseerimiseks =realiseerimise  (SgTr  >realiseerimine !12_S	et	f	\N
128949	realiseerimiseks	"realiseerimine %realiseeri  )MINE_vS  <realiseerima ;28_V	et	f	\N
128952	ülikooliga	ülikooliga =iga  (SgN  >üli+kool+iga !18_S	et	f	\N
128953	ülikooliga	ülikooliga =iga  (SgP  >üli+kool+iga !18_S	et	f	\N
128954	ülikooliga	ülikooliga =kooli  (SgKom  >üli+kool !22_S	et	f	\N
128961	teadmiste	teadmiste =teadmis  (PlG  >teadmine !12?10_S	et	f	\N
128962	teadmiste	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
128973	näidis	näidis =näidi  (SgIn  >näit !22_S	et	f	\N
128974	näidis	näidis =näidis  (SgN  >näidis !09_S	et	f	\N
128984	eirlisi	?eirlisi =eirlisi  (ID  >eirlisi !41_D	et	f	\N
128985	eirlisi	?eirlisi =eirlisi  (PlP  >eirline !12_A	et	f	\N
129002	lauljaks	lauljaks =laulja  (SgTr  >laulja !01_S	et	f	\N
129003	lauljaks	"laulja %laul  )JA_vS  <laulma ;33_V	et	f	\N
129004	mõttesid	?mõttesid =mõtte  (IndIpfSg2  >mõttema !27_V	et	f	\N
129005	mõttesid	?mõttesid =mõtte  (IndIpfPl3  >mõttema !27_V	et	f	\N
129015	hingeelu	hingeelu =elu  (SgN  >hinge+elu !17_S	et	f	\N
129016	hingeelu	hingeelu =elu  (SgG  >hinge+elu !17_S	et	f	\N
129017	hingeelu	hingeelu =elu  (SgP  >hinge+elu !17_S	et	f	\N
129048	sammu	sammu =sammu  (SgG  >samm !22_S	et	f	\N
129049	sammu	sammu =sammu  (SgP  >samm !22_S	et	f	\N
129050	sammu	sammu =sammu  (SgAdt  >samm !22_S	et	f	\N
129051	sammu	sammu =sammu  (IndPrPs_  >sammuma !28_V	et	f	\N
129052	sammu	sammu =sammu  (ImpPrSg2  >sammuma !28_V	et	f	\N
129070	säili	säili =säili  (IndPrPs_  >säilima !28_V	et	f	\N
129071	säili	säili =säili  (ImpPrSg2  >säilima !28_V	et	f	\N
129098	ennustamine	ennustamine =ennustamine  (SgN  >ennustamine !12_S	et	f	\N
129099	ennustamine	"ennustamine %ennusta  )MINE_vS  <ennustama ;27_V	et	f	\N
129117	põhine	põhine =põhine  (SgN  >põhine !10_A	et	f	\N
129118	põhine	"põhine %põhi  )NE_aA  <põhi ;24_S	et	f	\N
129119	põhine	põhine =põhine  (IndPrPs_  >põhinema !27_V	et	f	\N
129120	põhine	põhine =põhine  (ImpPrSg2  >põhinema !27_V	et	f	\N
129125	võimust	võimust =võimu  (SgEl  >võim !22_S	et	f	\N
129126	võimust	võimust =võimus  (SgP  >võimus !09_S	et	f	\N
129127	võimust	võimust =must  (SgN  >või+must !22_AS	et	f	\N
129128	vallatum	vallatum =vallatum  (SgN  >vallatum !02_A	et	f	\N
129129	vallatum	"vallatum %valla  )TUM1_cA  <valdama ;29_V	et	f	\N
129130	vallatum	"vallatum %valla  )TUM2_cA  <vald ;22_S	et	f	\N
129131	vallatum	"vallatum %vallatu  )M_cA  <vallatu ;01_AS	et	f	\N
129141	õppiv	õppiv =õppi  (PtsPrPs  >õppima !28_V	et	f	\N
129142	õppiv	õppiv =õppiv  (SgN  >õppiv !02_A	et	f	\N
129143	õppiv	"õppiv %õppi  )V_vA  <õppima ;28_V	et	f	\N
129146	sellelt	sellelt =selle  (SgAbl  >see !00_P	et	f	\N
129147	sellelt	sellelt =selle  (PlAbl  >sell !22_S	et	f	\N
129148	kordumatu	kordumatu =kordumatu  (SgN  >kordumatu !01_A	et	f	\N
129149	kordumatu	"kordumatu %kordu  )MATU_vA  <korduma ;27_V	et	f	\N
129150	kordumatu	kordumatu =kordumatu  (SgG  >kordumatu !01_A	et	f	\N
129163	peangi	peangi =pea  (IndPrSg1^  >pida !40_V	et	f	\N
129164	peangi	peangi =pea  (IndPrSg1^  >pidama !28_V	et	f	\N
129208	lõppetada	?lõppetada =lõppeta  (Inf  >lõppetama !27_V	et	f	\N
129213	intervjeerida	?intervjeerida =intervjeeri  (Inf  >intervjeerima !28_V	et	f	\N
129221	hakavad	?hakavad =haka  (IndPrPl3  >hakama !27_V	et	f	\N
129222	hakavad	?hakavad =hakava  (PlN  >hakava !01_S	et	f	\N
129223	hakavad	?hakavad =hakava  (PlN  >hakav !02_A	et	f	\N
129232	õppesid	?õppesid =õppe  (IndIpfSg2  >õppema !27_V	et	f	\N
129233	õppesid	?õppesid =õppe  (IndIpfPl3  >õppema !27_V	et	f	\N
129234	infotunned	### infotunned	et	f	\N
128879	unist	"unine %uni  )NE_aA  <uni ;20_S	et	f	\N
128888	truud	truud =truu  (PlN  >truu !26_A	et	f	\N
128889	truud	truud =truu  (SgP  >truu !26_A	et	f	\N
128890	mõttedega	### mõttedega	et	f	\N
128900	ajalehti	ajalehti =lehti  (SgP  >aja+leht !22_S	et	f	\N
128901	ajalehti	ajalehti =lehti  (SgAdt  >aja+leht !22_S	et	f	\N
128902	ajalehti	ajalehti =lehti  (PlP  >aja+leht !22_S	et	f	\N
128905	konkreetselt	konkreetselt =konkreetse  (SgAbl  >konkreetne !02_A	et	f	\N
128906	konkreetselt	konkreetselt =konkreetselt  (ID  >konkreetselt !41_D	et	f	\N
128907	konkreetselt	"konkreetselt %konkreetse  )LT_mD  <konkreetne ;02_A	et	f	\N
128918	täpsemini	täpsemini =täpsemi  (SgTer  >täpsem !02_A	et	f	\N
128919	täpsemini	"täpsem %täpse  )M_cA  <täpne ;02_A	et	f	\N
128920	tavapärased	tavapärased =pärase  (PlN  >tava+pärane !10_A	et	f	\N
128921	tavapärased	"tava+pärane %pära  )NE_aA  <tava+pära ;17_S	et	f	\N
128934	mõtleva	mõtleva =mõtleva  (SgG  >mõtlev !02_A	et	f	\N
128935	mõtleva	"mõtlev %mõtle  )V_vA  <mõtlema ;30_V	et	f	\N
128946	jõudmiseks	jõudmiseks =jõudmise  (SgTr  >jõudmine !12?10_S	et	f	\N
128947	jõudmiseks	"jõudmine %jõud  )MINE_vS  <jõudma ;34_V	et	f	\N
128950	tegu	tegu =tegu  (SgN  >tegu !18_S	et	f	\N
128951	tegu	tegu =tegu  (SgP  >tegu !18_S	et	f	\N
128971	rebastel	rebastel =rebas  (PlAd  >rebane !10_S	et	f	\N
128972	rebastel	"rebane %reba  )NE_aA  <reba ;17_S	et	f	\N
128975	tegevusest	tegevusest =tegevuse  (SgEl  >tegevus !11_S	et	f	\N
128976	tegevusest	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
128977	tegevusest	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
128978	tegevusest	tegevusest =tegevuses  (SgP  >tegevusene !12_A	et	f	\N
128979	tegevusest	"tegevusene %tegevuse  )NE_aA  <tegevus ;11_S	et	f	\N
128980	tegevusest	tegevusest =use  (PlEl  >tegev+usk !22_S	et	f	\N
129006	teaksid	teaksid =tea  (KndPrSg2  >teadma !34_V	et	f	\N
129007	teaksid	teaksid =tea  (KndPrPl3  >teadma !34_V	et	f	\N
129010	muutuksid	muutuksid =muutu  (KndPrSg2  >muutuma !27_V	et	f	\N
129011	muutuksid	muutuksid =muutu  (KndPrPl3  >muutuma !27_V	et	f	\N
129012	muutuksid	muutuksid =tuksi  (PlN  >muu+tuks !22_S	et	f	\N
129018	punkti	punkti =punkti  (SgG  >punkt !22_S	et	f	\N
129019	punkti	punkti =punkti  (SgP  >punkt !22_S	et	f	\N
129020	punkti	punkti =punkti  (SgAdt  >punkt !22_S	et	f	\N
129021	punkti	punkti =punkti  (IndPrPs_  >punktima !28_V	et	f	\N
129022	punkti	punkti =punkti  (ImpPrSg2  >punktima !28_V	et	f	\N
129026	keeli	keeli =keel  (PlP  >keel !13_S	et	f	\N
129027	keeli	keeli =keeli  (ID  >keeli !41_D	et	f	\N
129036	suureneksid	suureneksid =suurene  (KndPrSg2  >suurenema !27_V	et	f	\N
129037	suureneksid	suureneksid =suurene  (KndPrPl3  >suurenema !27_V	et	f	\N
129040	oskagi	oskagi =oska  (IndPrPs_^  >oskama !29_V	et	f	\N
129041	oskagi	oskagi =oska  (ImpPrSg2^  >oskama !29_V	et	f	\N
129042	inteligentsed	?inteligentsed =inteligentse  (PlN  >inteligentne !02_A	et	f	\N
129043	inteligentsed	?inteligentsed =inteligentse  (IndPrSg2  >inteligentsema !27_V	et	f	\N
129060	tedmisi	?tedmisi =tedmisi  (ID  >tedmisi !41_D	et	f	\N
129081	nutikas	nutikas =nutika  (SgIn  >nutikas !02_A	et	f	\N
129082	nutikas	nutikas =nutikas  (SgN  >nutikas !02_A	et	f	\N
129094	soobiv	?soobiv =soobi  (PtsPrPs  >soobima !27_V	et	f	\N
129095	soobiv	?soobiv =soobiv  (SgN  >soobiv !02_A	et	f	\N
129107	köidav	?köidav =köida  (PtsPrPs  >köidama !29_V	et	f	\N
129108	köidav	?köidav =köidav  (SgN  >köidav !02_A	et	f	\N
129165	äitäh	?äitäh =äitäh  (ID  >äitäh !41_I	et	f	\N
129170	kuskile	kuskile =kuskile  (ID  >kuskile !41_D	et	f	\N
129171	kuskile	kuskile =kile  (SgN  >kus+kile !02_A	et	f	\N
129172	kuskile	kuskile =kile  (SgN  >kus+kile !16_S	et	f	\N
129173	kuskile	kuskile =kile  (SgG  >kus+kile !16_S	et	f	\N
129190	lõppetamist	?lõppetamist =lõppetami  (SgEl  >lõppetam !02_A	et	f	\N
129191	lõppetamist	?lõppetamist =lõppetamis  (SgP  >lõppetamis !09_S	et	f	\N
129192	lõppetamist	?lõppetamist =lõppetamis  (SgP  >lõppetamine !12_S	et	f	\N
129193	lõppetamist	?lõppetamist =lõppetamist  (SgN  >lõppetamist !22_S	et	f	\N
129194	lõppetamist	?lõppetamist =etami  (SgEl  >lõpp+etami !01_S	et	f	\N
129195	lõppetamist	?lõppetamist =etami  (SgEl  >lõpp+etam !02_A	et	f	\N
129196	lõppetamist	?lõppetamist =etamis  (SgP  >lõpp+etamis !11_S	et	f	\N
129197	lõppetamist	?lõppetamist =etamis  (SgP  >lõpp+etamine !12_S	et	f	\N
129198	lõppetamist	?lõppetamist =etamist  (SgN  >lõpp+etamist !22_S	et	f	\N
129207	lepida	?lepida =lepi  (Inf  >lepima !27_V	et	f	\N
129209	saiaprotsendiliselt	saiaprotsendiliselt =protsendilise  (SgAbl  >saia+protsendiline !12_A	et	f	\N
129210	saiaprotsendiliselt	"saia+protsendiline %protsendi  )LINE_aA  <saia+protsent ;22_S	et	f	\N
129211	saiaprotsendiliselt	"saia+protsendiliselt %protsendi  )LISELT_mD  <saia+protsent ;22_S	et	f	\N
129212	saiaprotsendiliselt	"saia+protsendiliselt %protsendilise  )LT_mD  <saia+protsendiline ;12_A	et	f	\N
129216	õppetamisest	?õppetamisest =õppetamise  (SgEl  >õppetamine !12_S	et	f	\N
129217	õppetamisest	?õppetamisest =tamise  (SgEl  >õppe+tamine !10_A	et	f	\N
129246	media	?media =media  (SgN  >media !01_S	et	f	\N
129247	media	?media =media  (SgG  >media !01_S	et	f	\N
128930	valivad	valivad =valiva  (PlN  >valiv !02_A	et	f	\N
128931	valivad	"valiv %vali  )V_vA  <valima ;27_V	et	f	\N
128932	endas	endas =enda  (SgIn  >enda !00_P	et	f	\N
128933	endas	endas =enda  (SgIn  >ise !00_P	et	f	\N
128941	ainus	ainus =ainu  (SgIn  >ainus !07_AS	et	f	\N
128942	ainus	ainus =ainu  (SgIn  >ainu !16_S	et	f	\N
128943	ainus	ainus =ainu  (PlIn  >ain !22_S	et	f	\N
128944	ainus	ainus =ainus  (SgN  >ainus !03~05_AS	et	f	\N
128945	ainus	ainus =ainus  (SgN  >ainus !07_AS	et	f	\N
128958	saamisel	saamisel =saamise  (SgAd  >saamine !12?10_S	et	f	\N
128959	saamisel	"saamine %saa  )MINE_vS  <saama ;37_V	et	f	\N
128960	saamisel	"saamine %saami  )NE_aA  <saam ;22_S	et	f	\N
128966	hooleka	?hooleka =hooleka  (SgN  >hooleka !01_S	et	f	\N
128967	hooleka	?hooleka =hooleka  (SgG  >hooleka !01_S	et	f	\N
128968	hooleka	?hooleka =hooleka  (SgG  >hoolekas !02_A	et	f	\N
128969	hooleka	?hooleka =leka  (SgN  >hoo+leka !16_S	et	f	\N
128970	hooleka	?hooleka =leka  (SgG  >hoo+leka !16_S	et	f	\N
128986	pakkuv	pakkuv =pakku  (PtsPrPs  >pakkuma !28_V	et	f	\N
128987	pakkuv	pakkuv =pakkuv  (SgN  >pakkuv !02_A	et	f	\N
128988	pakkuv	"pakkuv %pakku  )V_vA  <pakkuma ;28_V	et	f	\N
128991	nõudmist	nõudmist =nõudmis  (SgP  >nõudmine !12?10_S	et	f	\N
128992	nõudmist	"nõudmine %nõud  )MINE_vS  <nõudma ;34_V	et	f	\N
129008	järelduseks	järelduseks =järelduse  (SgTr  >järeldus !11_S	et	f	\N
129009	järelduseks	"järeldus %järelda  )US_vS  <järeldama ;27_V	et	f	\N
129028	mõnusaks	mõnusaks =mõnusa  (SgTr  >mõnus !02_A	et	f	\N
129029	mõnusaks	mõnusaks =saks  (SgN  >mõnu+saks !23?22_S	et	f	\N
129030	luuletus	luuletus =luuletu  (SgIn  >luuletu !01_A	et	f	\N
129031	luuletus	"luuletu %luule  )TU2_kA  <luule ;06_S	et	f	\N
129032	luuletus	luuletus =luuletus  (SgN  >luuletus !11_S	et	f	\N
129033	luuletus	"luuletus %luuleta  )US_vS  <luuletama ;27_V	et	f	\N
129034	luuletus	"luuletus %luule  )TUS2_aS  <luule ;06_S	et	f	\N
129035	luuletus	luuletus =letu  (SgIn  >luu+letu !16_S	et	f	\N
129038	paraneksid	paraneksid =parane  (KndPrSg2  >paranema !27_V	et	f	\N
129039	paraneksid	paraneksid =parane  (KndPrPl3  >paranema !27_V	et	f	\N
129058	paanika	paanika =paanika  (SgN  >paanika !01_S	et	f	\N
129059	paanika	paanika =paanika  (SgG  >paanika !01_S	et	f	\N
129061	ajust	ajust =aju  (SgEl  >aju !17_S	et	f	\N
129062	ajust	ajust =aju  (PlEl  >aeg !22_S	et	f	\N
129076	vaimustanud	vaimustanud =vaimusta  (PtsPtPs  >vaimustama !27_V	et	f	\N
129077	vaimustanud	vaimustanud =vaimustanu  (PlN  >vaimustanu !01_S	et	f	\N
129078	vaimustanud	"vaimustanu %vaimusta  )NU_vS  <vaimustama ;27_V	et	f	\N
129079	vaimustanud	vaimustanud =vaimustanud  (ID  >vaimustanud !41_A	et	f	\N
129080	vaimustanud	"vaimustanud %vaimusta  )NUD_vA  <vaimustama ;27_V	et	f	\N
129083	majast	majast =maja  (SgEl  >maja !17_S	et	f	\N
129084	majast	majast =majas  (SgP  >majane !10_A	et	f	\N
129085	majast	"majane %maja  )NE_aA  <maja ;17_S	et	f	\N
129105	harrastuseni	harrastuseni =harrastuse  (SgTer  >harrastus !11_S	et	f	\N
129106	harrastuseni	"harrastus %harrasta  )US_vS  <harrastama ;27_V	et	f	\N
129132	vastutusrikkas	?vastutusrikkas =vastutusrikka  (SgIn  >vastutusrikka !16_S	et	f	\N
129133	vastutusrikkas	?vastutusrikkas =rikka  (SgIn  >vastutus+rikas !07_A	et	f	\N
129134	vastutusrikkas	?vastutusrikkas =rikkas  (SgN  >vastutus+rikkas !07_S	et	f	\N
129135	vastutusrikkas	?vastutusrikkas =tusrikka  (SgIn  >vastu+tusrikka !01_S	et	f	\N
129136	vastutusrikkas	?vastutusrikkas =utusrikka  (SgIn  >vast+utusrikka !16_S	et	f	\N
129137	ahvatlus	ahvatlus =ahvatlus  (SgN  >ahvatlus !11_S	et	f	\N
129138	ahvatlus	"ahvatlus %ahvatle  )US_vS  <ahvatlema ;27_V	et	f	\N
129139	seista	seista =seis  (Inf  >seisma !32_V	et	f	\N
129140	seista	seista =seis  (IndPrIps_  >seisma !32_V	et	f	\N
129151	viieteist	viieteist =te  (PlEl  >viie+tee !26_S	et	f	\N
129152	viieteist	viieteist =teist  (SgN  >viie+teist !22_S	et	f	\N
129166	seegi	seegi =seegi  (SgG  >seek !22_S	et	f	\N
129167	seegi	seegi =see  (SgN^  >see !00_P	et	f	\N
129180	gramaatika	?gramaatika =gramaatika  (SgN  >gramaatika !01_S	et	f	\N
129181	gramaatika	?gramaatika =gramaatika  (SgG  >gramaatika !01_S	et	f	\N
129182	gramaatika	?gramaatika =gramaatika  (SgG  >gramaatikas !02_A	et	f	\N
129188	teoks	teoks =teo  (SgTr  >tegu !18_S	et	f	\N
129189	teoks	teoks =teo  (SgTr  >tigu !18_S	et	f	\N
129226	floristiks	?floristiks =floristi  (SgTr  >floristi !01_S	et	f	\N
129227	floristiks	?floristiks =floristi  (SgTr  >florist !22_S	et	f	\N
129228	floristiks	?floristiks =floristi  (KndPrPs  >floristima !28_V	et	f	\N
129237	leidmist	leidmist =leidmis  (SgP  >leidmine !12?10_S	et	f	\N
129238	leidmist	"leidmine %leid  )MINE_vS  <leidma ;34_V	et	f	\N
129239	puistata	puistata =puista  (Inf  >puistama !29_V	et	f	\N
129240	puistata	puistata =puista  (IndPrIps_  >puistama !29_V	et	f	\N
129241	töökohta	töökohta =kohta  (SgP  >töö+koht !22_S	et	f	\N
129242	töökohta	töökohta =kohta  (SgAdt  >töö+koht !22_S	et	f	\N
129248	suhtlemisega	suhtlemisega =suhtlemise  (SgKom  >suhtlemine !12_S	et	f	\N
129249	suhtlemisega	"suhtlemine %suhtle  )MINE_vS  <suhtlema ;30_V	et	f	\N
129269	sportsmenitega	?sportsmenitega =sportsmeni  (PlKom  >sportsmen !02_S	et	f	\N
129158	artikkli	?artikkli =artikkli  (SgG  >artikkl !22_S	et	f	\N
129159	artikkli	?artikkli =artikkli  (SgP  >artikkl !22_S	et	f	\N
129160	artikkli	?artikkli =artikkli  (SgAdt  >artikkl !22_S	et	f	\N
129161	artikkli	?artikkli =artikkli  (IndPrPs_  >artikklima !28_V	et	f	\N
129162	artikkli	?artikkli =artikkli  (ImpPrSg2  >artikklima !28_V	et	f	\N
129168	otsust	otsust =otsus  (SgP  >otsus !09_S	et	f	\N
129169	otsust	otsust =us  (SgP  >ots+uks !14_S	et	f	\N
129178	õppetajate	?õppetajate =õppetaja  (PlG  >õppetaja !01_S	et	f	\N
129179	õppetajate	?õppetajate =õppetaja  (PlG  >õppetajas !02_A	et	f	\N
129203	saia	saia =saia  (SgG  >sai !22_S	et	f	\N
129204	saia	saia =saia  (SgP  >sai !22_S	et	f	\N
129205	saia	saia =saia  (SgAdt  >sai !22_S	et	f	\N
129206	ennaga	?ennaga =enna  (SgKom  >enna !16_S	et	f	\N
129214	töötamises	töötamises =töötamise  (SgIn  >töötamine !12_S	et	f	\N
129215	töötamises	"töötamine %tööta  )MINE_vS  <töötama ;27_V	et	f	\N
129224	hakasin	?hakasin =haka  (IndIpfSg1  >hakama !27_V	et	f	\N
129225	hakasin	?hakasin =hakasin  (SgN  >hakasin !19_S	et	f	\N
129250	elusuhtumisega	elusuhtumisega =uhtumise  (SgKom  >elus+uhtumine !12_S	et	f	\N
129251	elusuhtumisega	elusuhtumisega =suhtumise  (SgKom  >elu+suhtumine !12_S	et	f	\N
129268	politikutega	?politikutega =politiku  (PlKom  >politik !02_S	et	f	\N
129308	orinteeruda	?orinteeruda =orinteeru  (Inf  >orinteeruma !27_V	et	f	\N
129309	eriallal	?eriallal =erialla  (SgAd  >erialla !16_S	et	f	\N
129310	eriallal	?eriallal =eriallal  (SgN  >eriallal !02_S	et	f	\N
129311	eriallal	?eriallal =allal  (SgN  >eri+allal !02_S	et	f	\N
129317	ajakurjandus	?ajakurjandus =ajakurjandu  (IndIpfSg3  >ajakurjanduma !27_V	et	f	\N
129318	ajakurjandus	?ajakurjandus =ajakurjandus  (SgN  >ajakurjandus !11_S	et	f	\N
129319	ajakurjandus	?ajakurjandus =kurjandu  (SgIn  >aja+kurjandu !01_S	et	f	\N
129320	ajakurjandus	?ajakurjandus =kurjandus  (SgN  >aja+kurjandus !11_S	et	f	\N
129326	õppetajana	?õppetajana =õppetaja  (SgEs  >õppetaja !01_S	et	f	\N
129327	õppetajana	?õppetajana =õppetaja  (SgEs  >õppetajas !02_A	et	f	\N
129328	õppetajana	?õppetajana =taja  (SgEs  >õppe+taja !17_S	et	f	\N
129336	teisena	teisena =teise  (SgEs  >teine !12_OP	et	f	\N
129337	teisena	teisena =teise  (SgEs  >teise !12_P	et	f	\N
129342	politiiline	?politiiline =politiiline  (SgN  >politiiline !12?10_A	et	f	\N
129369	lektoorid	?lektoorid =lektoori  (PlN  >lektoori !16_S	et	f	\N
129370	lektoorid	?lektoorid =lektoori  (PlN  >lektoor !22_S	et	f	\N
129371	lektoorid	?lektoorid =lektoori  (IndPrSg2  >lektoorima !28_V	et	f	\N
129376	õpetaksid	õpetaksid =õpeta  (KndPrSg2  >õpetama !27_V	et	f	\N
129377	õpetaksid	õpetaksid =õpeta  (KndPrPl3  >õpetama !27_V	et	f	\N
129384	vaatamisvärsuseid	?vaatamisvärsuseid =vaatamisvärsuse  (PlP  >vaatamisvärsus !09_S	et	f	\N
129385	vaatamisvärsuseid	?vaatamisvärsuseid =vaatamisvärsusei  (PlN  >vaatamisvärsusei !26_S	et	f	\N
129386	vaatamisvärsuseid	?vaatamisvärsuseid =vaatamisvärsusei  (SgP  >vaatamisvärsusei !26_S	et	f	\N
129387	vaatamisvärsuseid	?vaatamisvärsuseid =värsuse  (PlP  >vaatamis+värsus !09_S	et	f	\N
129388	vaatamisvärsuseid	?vaatamisvärsuseid =värsusei  (PlN  >vaatamis+värsusei !26_S	et	f	\N
129389	vaatamisvärsuseid	?vaatamisvärsuseid =värsusei  (SgP  >vaatamis+värsusei !26_S	et	f	\N
129394	objektivselt	?objektivselt =objektivse  (SgAbl  >objektivne !02_A	et	f	\N
129395	objektivselt	?objektivselt =objektivse  (PlAbl  >objektivs !22_S	et	f	\N
129396	objektivselt	?objektivselt =objektivselt  (ID  >objektivselt !41_D	et	f	\N
129427	tervitav	tervitav =tervita  (PtsPrPs  >tervitama !27_V	et	f	\N
129428	tervitav	tervitav =tervitav  (SgN  >tervitav !02_A	et	f	\N
129429	tervitav	"tervitav %tervita  )V_vA  <tervitama ;27_V	et	f	\N
129465	püsiv	püsiv =püsi  (PtsPrPs  >püsima !27_V	et	f	\N
129466	püsiv	püsiv =püsiv  (SgN  >püsiv !02_A	et	f	\N
129467	püsiv	"püsiv %püsi  )V_vA  <püsima ;27_V	et	f	\N
129476	tuttava	tuttava =tuttava  (SgG  >tuttav !02_AS	et	f	\N
129477	tuttava	tuttava =ava  (SgN  >tutt+ava !17_S	et	f	\N
129478	tuttava	tuttava =ava  (SgG  >tutt+ava !17_S	et	f	\N
129479	tuttava	tuttava =ava  (SgP  >tutt+ava !17_S	et	f	\N
129493	kahtlemata	kahtlemata =kahtle  (SupAb  >kahtlema !30_V	et	f	\N
129494	kahtlemata	kahtlemata =kahtlemata  (ID  >kahtlemata !41_D	et	f	\N
129495	kahtlemata	"kahtlemata %kahtle  )MATA_vA  <kahtlema ;30_V	et	f	\N
129500	kultuuriparadoks	kultuuriparadoks =do  (SgTr  >kultuuri+para+do !26_S	et	f	\N
129501	kultuuriparadoks	kultuuriparadoks =paradoks  (SgN  >kultuuri+paradoks !22_S	et	f	\N
129505	pööra	pööra =pööra  (SgG  >pöör !22_S	et	f	\N
129506	pööra	pööra =pööra  (SgP  >pöör !22_S	et	f	\N
129507	pööra	pööra =pööra  (SgAdt  >pöör !22_S	et	f	\N
129508	pööra	pööra =pööra  (IndPrPs_  >pöörama !29_V	et	f	\N
129509	pööra	pööra =pööra  (ImpPrSg2  >pöörama !29_V	et	f	\N
129540	konfutsiaanlik	?konfutsiaanlik =konfutsiaanlik  (SgN  >konfutsiaanlik !25_A	et	f	\N
129547	tõest	tõest =tõe  (SgEl  >tõsi !15_S	et	f	\N
129548	tõest	tõest =tõe  (SgEl  >tõde !18_S	et	f	\N
129550	tõest	tõest =tões  (SgP  >tõene !10_A	et	f	\N
129552	tõest	"tõene %tõe  )NE_aA  <tõde ;18_S	et	f	\N
129553	hüve	hüve =hüve  (SgN  >hüve !16_S	et	f	\N
129176	kirjutamise	kirjutamise =kirjutamise  (SgG  >kirjutamine !12_S	et	f	\N
129177	kirjutamise	"kirjutamine %kirjuta  )MINE_vS  <kirjutama ;27_V	et	f	\N
129183	täiendamist	täiendamist =täiendamis  (SgP  >täiendamine !12_S	et	f	\N
129184	täiendamist	"täiendamine %täienda  )MINE_vS  <täiendama ;27_V	et	f	\N
129185	õppingud	?õppingud =õppingu  (PlN  >õppingu !01_S	et	f	\N
129186	õppingud	?õppingud =õppingu  (PlN  >õpping !02_S	et	f	\N
129187	õppingud	?õppingud =õppingu  (IndPrSg2  >õppinguma !27_V	et	f	\N
129199	otsustavad	otsustavad =otsusta  (IndPrPl3  >otsustama !27_V	et	f	\N
129200	otsustavad	otsustavad =otsustava  (PlN  >otsustav !02_A	et	f	\N
129201	otsustavad	"otsustav %otsusta  )V_vA  <otsustama ;27_V	et	f	\N
129202	otsustavad	otsustavad =ustava  (PlN  >ots+ustav !02_A	et	f	\N
129218	huvitavale	huvitavale =huvitava  (SgAll  >huvitav !02_A	et	f	\N
129219	huvitavale	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
129220	huvitavale	huvitavale =tava  (SgAll  >huvi+tava !17_S	et	f	\N
129229	aktiine	aktiine =aktiine  (PlP  >aktiin !22_S	et	f	\N
129230	aktiine	aktiine =ine  (SgN  >akti+ine !16_S	et	f	\N
129231	aktiine	aktiine =ine  (SgG  >akti+ine !16_S	et	f	\N
129235	kriitiserin	?kriitiserin =kriitiserin  (SgN  >kriitiserin !19_S	et	f	\N
129236	kriitiserin	?kriitiserin =iserin  (SgN  >kriit+iserin !19_S	et	f	\N
129271	ülikooliõpilastega	ülikooliõpilastega =las  (PlKom  >üli+kooli+õpi+laps !14_S	et	f	\N
129272	ülikooliõpilastega	ülikooliõpilastega =õpilas  (PlKom  >üli+kooli+õpilane !12_S	et	f	\N
129273	ida-viirumaal	?ida-viirumaal =viirumaa  (SgAd  >ida-viirumaa !26_S	et	f	\N
129274	ida-viirumaal	?ida-viirumaal =viirumaal  (SgN  >ida-viirumaal !22_S	et	f	\N
129275	ida-viirumaal	?ida-viirumaal =umaa  (SgAd  >ida-viir+umaa !26_S	et	f	\N
129276	ida-viirumaal	?ida-viirumaal =umaal  (SgN  >ida-viir+umaal !22_S	et	f	\N
129302	saade	saade =saade  (SgN  >saade !06_S	et	f	\N
129303	saade	saade =saade  (PlP  >saad !22_S	et	f	\N
129314	professionaalselt	professionaalselt =professionaalse  (SgAbl  >professionaalne !02_A	et	f	\N
129315	professionaalselt	professionaalselt =professionaalselt  (ID  >professionaalselt !41_D	et	f	\N
129316	professionaalselt	"professionaalselt %professionaalse  )LT_mD  <professionaalne ;02_A	et	f	\N
129321	aitada	### aitada	et	f	\N
129322	huuvitavaid	?huuvitavaid =huuvitava  (PlP  >huuvitav !02_A	et	f	\N
129323	huuvitavaid	?huuvitavaid =huuvitavai  (PlN  >huuvitavai !26_S	et	f	\N
129324	huuvitavaid	?huuvitavaid =huuvitavai  (SgP  >huuvitavai !26_S	et	f	\N
129338	mingeit	?mingeit =mingeit  (SgN  >mingeit !22_S	et	f	\N
129350	vastusi	?vastusi =vastusi  (ID  >vastusi !41_D	et	f	\N
129351	vastusi	?vastusi =usi  (SgN  >vast+usi !17_S	et	f	\N
129352	vastusi	?vastusi =usi  (SgG  >vast+usi !17_S	et	f	\N
129353	vastusi	?vastusi =usi  (SgP  >vast+usi !17_S	et	f	\N
129358	postimees	postimees =mee  (SgIn  >posti+mesi !15_S	et	f	\N
129359	postimees	postimees =mees  (SgN  >posti+mees !13_S	et	f	\N
129365	kanaalid	?kanaalid =kanaali  (PlN  >kanaali !16_S	et	f	\N
129366	kanaalid	?kanaalid =kanaali  (PlN  >kanaal !22_S	et	f	\N
129367	kanaalid	?kanaalid =kanaali  (IndPrSg2  >kanaalima !28_V	et	f	\N
129368	kanaalid	?kanaalid =ali  (PlN  >kana+ali !17_S	et	f	\N
129379	tulevaks	tulevaks =tuleva  (SgTr  >tulev !02_A	et	f	\N
129380	tulevaks	"tulev %tule  )V_vA  <tulema ;36_V	et	f	\N
129381	tulevaks	tulevaks =vaks  (SgN  >tule+vaks !22_S	et	f	\N
129421	viisteist	viisteist =te  (PlEl  >viis+tee !26_S	et	f	\N
129422	viisteist	viisteist =teist  (SgN  >viis+teist !22_S	et	f	\N
129432	rääkimist	rääkimist =rääkimis  (SgP  >rääkimine !12_S	et	f	\N
129433	rääkimist	"rääkimine %rääki  )MINE_vS  <rääkima ;28_V	et	f	\N
129449	viitsimise	viitsimise =viitsimise  (SgG  >viitsimine !12_S	et	f	\N
129450	viitsimise	"viitsimine %viitsi  )MINE_vS  <viitsima ;28_V	et	f	\N
129451	laeva	laeva =laeva  (SgG  >laev !22_S	et	f	\N
129452	laeva	laeva =laeva  (SgP  >laev !22_S	et	f	\N
129453	laeva	laeva =laeva  (SgAdt  >laev !22_S	et	f	\N
129459	miski	miski =mis  (SgN  >miski !00_P	et	f	\N
129460	miski	miski =miski  (SgN  >miski !01_S	et	f	\N
129461	miski	miski =miski  (SgG  >miski !01_S	et	f	\N
129462	miski	miski =mis  (SgN^  >mis !00_P	et	f	\N
129463	miski	miski =mis  (PlN^  >mis !00_P	et	f	\N
129464	miski	miski =mi  (SgIn^  >mi !26_S	et	f	\N
129468	kõrini	kõrini =kõri  (SgTer  >kõri !17_S	et	f	\N
129469	kõrini	kõrini =kõrini  (SgG  >kõrin !02_S	et	f	\N
129470	laevafirma	laevafirma =firma  (SgN  >laeva+firma !16_S	et	f	\N
129471	laevafirma	laevafirma =firma  (SgG  >laeva+firma !16_S	et	f	\N
129472	muidkui	?muidkui =muidkui  (SgN  >muidkui !26_S	et	f	\N
129473	muidkui	?muidkui =muidkui  (SgG  >muidkui !26_S	et	f	\N
129484	sidet	sidet =side  (SgP  >side !04_S	et	f	\N
129485	sidet	sidet =side  (SgP  >side !16_S	et	f	\N
129488	tpü	### tpü	et	f	\N
129491	vastustega	vastustega =vastus  (PlKom  >vastus !09_S	et	f	\N
129492	vastustega	vastustega =us  (PlKom  >vast+uks !14_S	et	f	\N
129510	märgata	märgata =märga  (Inf  >märkama !29_V	et	f	\N
129511	märgata	märgata =märga  (IndPrIps_  >märkama !29_V	et	f	\N
129543	lühema	lühema =lühema  (SgG  >lühem !02_A	et	f	\N
129243	raiskata	?raiskata =raiska  (SgAb  >raiska !01_S	et	f	\N
129244	raiskata	?raiskata =raiskata  (IndPrPs_  >raiskatama !27_V	et	f	\N
129245	raiskata	?raiskata =raiskata  (ImpPrSg2  >raiskatama !27_V	et	f	\N
129252	proectis	?proectis =proecti  (SgIn  >proect !22_S	et	f	\N
129253	proectis	?proectis =proecti  (IndIpfSg3  >proectima !28_V	et	f	\N
129254	proectis	?proectis =proectis  (SgN  >proectis !09_S	et	f	\N
129263	kiirustavad	kiirustavad =kiirusta  (IndPrPl3  >kiirustama !27_V	et	f	\N
129264	kiirustavad	kiirustavad =kiirustava  (PlN  >kiirustav !02_A	et	f	\N
129265	kiirustavad	"kiirustav %kiirusta  )V_vA  <kiirustama ;27_V	et	f	\N
129266	kiirustavad	kiirustavad =tava  (PlN  >kiirus+tava !17_S	et	f	\N
129267	kiirustavad	kiirustavad =ustava  (PlN  >kiir+ustav !02_A	et	f	\N
129300	saade	saade =saade  (SgN  >saade !06_S	et	f	\N
129301	saade	saade =saade  (PlP  >saad !22_S	et	f	\N
129354	ajalehtedest	ajalehtedest =ede  (SgEl  >aja+leht+ede !16_S	et	f	\N
129355	ajalehtedest	ajalehtedest =edes  (SgP  >aja+leht+edene !10_A	et	f	\N
129356	ajalehtedest	"aja+leht+edene %ede  )NE_aA  <aja+leht+ede ;16_S	et	f	\N
129357	ajalehtedest	ajalehtedest =lehte  (PlEl  >aja+leht !22_S	et	f	\N
129360	pressa	?pressa =pressa  (SgN  >pressa !16_S	et	f	\N
129361	pressa	?pressa =pressa  (SgG  >pressa !16_S	et	f	\N
129362	pressa	?pressa =pressa  (IndPrPs_  >pressama !29_V	et	f	\N
129363	pressa	?pressa =pressa  (ImpPrSg2  >pressama !29_V	et	f	\N
129372	tähelepanelikud	tähelepanelikud =neliku  (PlN  >tähe+lepa+nelik !02_S	et	f	\N
129373	tähelepanelikud	tähelepanelikud =paneliku  (PlN  >tähele+panelik !25_A	et	f	\N
129399	avauksepäeva	avauksepäeva =päeva  (SgG  >ava+ukse+päev !22_S	et	f	\N
129400	avauksepäeva	avauksepäeva =päeva  (SgP  >ava+ukse+päev !22_S	et	f	\N
129401	avauksepäeva	avauksepäeva =päeva  (SgAdt  >ava+ukse+päev !22_S	et	f	\N
129405	üristusi	?üristusi =üristusi  (PlP  >üristus !11_S	et	f	\N
129425	varases	varases =varase  (SgIn  >varane !10_A	et	f	\N
129426	varases	"varane %vara  )NE_aA  <vara ;17_S	et	f	\N
129436	laiskus	laiskus =laisku  (IndIpfSg3  >laiskuma !27_V	et	f	\N
129437	laiskus	laiskus =laiskus  (SgN  >laiskus !11~09_S	et	f	\N
129438	laiskus	"laiskus %laisk  )US_aS  <laisk ;22_A	et	f	\N
129486	iirimaa	iirimaa =maa  (SgN  >iiri+maa !26_S	et	f	\N
129487	iirimaa	iirimaa =maa  (SgG  >iiri+maa !26_S	et	f	\N
129489	peaksime	peaksime =pea  (KndPrPl1  >pida !40_V	et	f	\N
129490	peaksime	peaksime =pea  (KndPrPl1  >pidama !28_V	et	f	\N
129498	tele	tele =tele  (SgN  >tele !16_S	et	f	\N
129499	tele	tele =tele  (SgG  >tele !16_S	et	f	\N
129518	venelastel	venelastel =venelas  (PlAd  >venelane !12_S	et	f	\N
129519	venelastel	venelastel =las  (PlAd  >vene+laps !14_S	et	f	\N
129520	venelastel	venelastel =laste  (PlAd  >vene+last !22_S	et	f	\N
129521	kultuuriterritooriumi	kultuuriterritooriumi =territooriumi  (SgG  >kultuuri+territoorium !19~02_S	et	f	\N
129522	kultuuriterritooriumi	kultuuriterritooriumi =territooriumi  (SgP  >kultuuri+territoorium !19_S	et	f	\N
129523	kultuuriterritooriumi	kultuuriterritooriumi =territooriumi  (SgAdt  >kultuuri+territoorium !19_S	et	f	\N
129588	teretorium	?teretorium =teretorium  (SgN  >teretorium !19_S	et	f	\N
129589	teretorium	?teretorium =torium  (SgN  >tere+torium !19_S	et	f	\N
129604	seletavad	seletavad =seleta  (IndPrPl3  >seletama !27_V	et	f	\N
129605	seletavad	seletavad =seletava  (PlN  >seletav !02_A	et	f	\N
129606	seletavad	"seletav %seleta  )V_vA  <seletama ;27_V	et	f	\N
129615	keeleparadoksiga	keeleparadoksiga =si  (SgKom  >keele+para+dok+si !26_S	et	f	\N
129616	keeleparadoksiga	keeleparadoksiga =siga  (SgN  >keele+para+dok+siga !18_SA	et	f	\N
129617	keeleparadoksiga	keeleparadoksiga =siga  (SgP  >keele+para+dok+siga !18_SA	et	f	\N
129618	keeleparadoksiga	keeleparadoksiga =paradoksi  (SgKom  >keele+paradoks !22_S	et	f	\N
129643	sarnasust	sarnasust =sarnasus  (SgP  >sarnasus !11_S	et	f	\N
129644	sarnasust	"sarnasus %sarna  )SUS_aS  <sarn ;22_S	et	f	\N
129645	erinevust	erinevust =erinevus  (SgP  >erinevus !11?09_S	et	f	\N
129646	erinevust	"erinevus %erine  )VUS_aS  <erinema ;27_V	et	f	\N
129647	erinevust	"erinevus %erineva  )US_aS  <erinev ;02_A	et	f	\N
129708	esindajad	esindajad =esindaja  (PlN  >esindaja !01_S	et	f	\N
129709	esindajad	"esindaja %esinda  )JA_vS  <esindama ;27_V	et	f	\N
129713	hoidakse	?hoidakse =hoidakse  (SgG  >hoidakne !02_A	et	f	\N
129744	suurbritania	?suurbritania =suurbritania  (SgN  >suurbritania !01_S	et	f	\N
129745	suurbritania	?suurbritania =suurbritania  (SgG  >suurbritania !01_S	et	f	\N
129746	suurbritania	?suurbritania =britania  (SgN  >suur+britania !01_S	et	f	\N
129747	suurbritania	?suurbritania =britania  (SgG  >suur+britania !01_S	et	f	\N
129763	aeglasemad	aeglasemad =aeglasema  (PlN  >aeglasem !02_A	et	f	\N
129764	aeglasemad	"aeglasem %aeglase  )M_cA  <aeglane ;10_A	et	f	\N
129765	aeglasemad	"aeglasem %aeglase  )M_cA  <aeglane ;12_A	et	f	\N
129774	multikultuuriline	multikultuuriline =kultuuriline  (SgN  >multi+kultuuriline !12_A	et	f	\N
129775	multikultuuriline	"multi+kultuuriline %kultuuri  )LINE_aA  <multi+kultuur ;22_S	et	f	\N
129810	sisaldus	sisaldus =sisaldu  (IndIpfSg3  >sisalduma !27_V	et	f	\N
129811	sisaldus	sisaldus =sisaldus  (SgN  >sisaldus !11_S	et	f	\N
129812	sisaldus	"sisaldus %sisalda  )US_vS  <sisaldama ;27_V	et	f	\N
129255	erinevatel	erinevatel =erineva  (PlAd  >erinev !02_A	et	f	\N
129256	erinevatel	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
129257	töötamine	töötamine =töötamine  (SgN  >töötamine !12_S	et	f	\N
129258	töötamine	"töötamine %tööta  )MINE_vS  <töötama ;27_V	et	f	\N
129259	õelda	?õelda =õelda  (SgN  >õelda !01_S	et	f	\N
129260	õelda	?õelda =õelda  (SgG  >õelda !01_S	et	f	\N
129261	õelda	?õelda =õelda  (IndPrPs_  >õeldama !27_V	et	f	\N
129262	õelda	?õelda =õelda  (ImpPrSg2  >õeldama !27_V	et	f	\N
129283	väliskorrespondend	?väliskorrespondend =väliskorrespondend  (SgN  >väliskorrespondend !22_S	et	f	\N
129284	väliskorrespondend	?väliskorrespondend =korrespondend  (SgN  >välis+korrespondend !22_S	et	f	\N
129285	väliskorrespondend	?väliskorrespondend =skorrespondend  (SgN  >väli+skorrespondend !22_S	et	f	\N
129304	neljas	neljas =nelja  (SgIn  >neljas !02_O	et	f	\N
129305	neljas	neljas =nelja  (SgIn  >neli !24_N	et	f	\N
129306	neljas	neljas =neljas  (SgN  >neljas !02_O	et	f	\N
129329	nõutav	nõutav =nõu  (PtsPrIps  >nõudma !34_V	et	f	\N
129330	nõutav	nõutav =nõuta  (PtsPrPs  >nõutama !27_V	et	f	\N
129331	nõutav	nõutav =nõutav  (SgN  >nõutav !02_A	et	f	\N
129332	nõutav	"nõutav %nõu  )TAV_vAS  <nõudma ;34_V	et	f	\N
129333	nõutav	"nõutav %nõuta  )V_vA  <nõutama ;27_V	et	f	\N
129349	uudisi	?uudisi =uudisi  (ID  >uudisi !41_D	et	f	\N
129378	informaatsion	?informaatsion =informaatsion  (SgN  >informaatsion !19~02_S	et	f	\N
129382	erialla	?erialla =erialla  (SgN  >erialla !16_S	et	f	\N
129383	erialla	?erialla =erialla  (SgG  >erialla !16_S	et	f	\N
129391	kutse	kutse =kutse  (SgN  >kutse !06_S	et	f	\N
129392	kutse	kutse =kutse  (SgG  >kutse !06_S	et	f	\N
129393	kutse	kutse =kutse  (PlP  >kuts !22_S	et	f	\N
129402	perspektiivsem	perspektiivsem =perspektiivsem  (SgN  >perspektiivsem !02_A	et	f	\N
129403	perspektiivsem	"perspektiivsem %perspektiivse  )M_cA  <perspektiivne ;02_A	et	f	\N
129408	seitsmekümne	?seitsmekümne =seitsmekümne  (SgN  >seitsmekümne !02_A	et	f	\N
129409	seitsmekümne	?seitsmekümne =seitsmekümne  (PlP  >seitsmekümn !22_S	et	f	\N
129410	seitsmekümne	?seitsmekümne =kümne  (SgN  >seitsme+kümne !02_A	et	f	\N
129411	seitsmekümne	?seitsmekümne =kümne  (PlP  >seitsme+kümn !22_S	et	f	\N
129416	lasteaeda	lasteaeda =aeda  (SgP  >laste+aed !22_S	et	f	\N
129417	lasteaeda	lasteaeda =aeda  (SgAdt  >laste+aed !22_S	et	f	\N
129430	paratamatu	paratamatu =paratamatu  (SgN  >paratamatu !01_A	et	f	\N
129431	paratamatu	paratamatu =paratamatu  (SgG  >paratamatu !01_A	et	f	\N
129454	sujuvalt	sujuvalt =sujuva  (SgAbl  >sujuv !02_A	et	f	\N
129455	sujuvalt	"sujuv %suju  )V_vA  <sujuma ;27_V	et	f	\N
129456	sujuvalt	sujuvalt =sujuvalt  (ID  >sujuvalt !41_D	et	f	\N
129457	sujuvalt	"sujuvalt %suju  )VALT_mD  <sujuma ;27_V	et	f	\N
129458	sujuvalt	"sujuvalt %sujuva  )LT_mD  <sujuv ;02_A	et	f	\N
129474	mõttetes	?mõttetes =mõtte  (PlIn  >mõtte !06_S	et	f	\N
129475	mõttetes	?mõttetes =mõttete  (PlIn  >mõttett !22_S	et	f	\N
129480	iirimaale	iirimaale =maa  (SgAll  >iiri+maa !26_S	et	f	\N
129481	iirimaale	iirimaale =maale  (PlP  >iiri+maal !22_S	et	f	\N
129502	võõrkeele	võõrkeele =kee  (SgAll  >võõr+kesi !15_S	et	f	\N
129503	võõrkeele	võõrkeele =kee  (SgAll  >võõr+kee !26_S	et	f	\N
129504	võõrkeele	võõrkeele =keele  (SgG  >võõr+keel !13_S	et	f	\N
129514	kõnelevad	kõnelevad =kõnele  (IndPrPl3  >kõnelema !31~27_V	et	f	\N
129515	kõnelevad	kõnelevad =kõneleva  (PlN  >kõnelev !02_A	et	f	\N
129516	kõnelevad	"kõnelev %kõnele  )V_vA  <kõnelema ;27_V	et	f	\N
129517	kõnelevad	"kõnelev %kõnele  )V_vA  <kõnelema ;31_V	et	f	\N
129530	mõjuta	mõjuta =mõju  (SgAb  >mõju !17_S	et	f	\N
129531	mõjuta	mõjuta =mõju  (IndPrIps_  >mõjuma !27_V	et	f	\N
129532	mõjuta	mõjuta =mõjuta  (IndPrPs_  >mõjutama !27_V	et	f	\N
129533	mõjuta	mõjuta =mõjuta  (ImpPrSg2  >mõjutama !27_V	et	f	\N
129534	viisi	viisi =viis  (PlP  >viis !14_N	et	f	\N
129535	viisi	viisi =viisi  (ID  >viisi !41_D	et	f	\N
129536	viisi	viisi =viisi  (ID  >viisi !41_K	et	f	\N
129537	viisi	viisi =viisi  (SgG  >viis !22_S	et	f	\N
129538	viisi	viisi =viisi  (SgP  >viis !22_S	et	f	\N
129539	viisi	viisi =viisi  (SgAdt  >viis !22_S	et	f	\N
129541	dünaamika	dünaamika =dünaamika  (SgN  >dünaamika !01_S	et	f	\N
129542	dünaamika	dünaamika =dünaamika  (SgG  >dünaamika !01_S	et	f	\N
129576	õppimesel	?õppimesel =õppimese  (SgAd  >õppimene !12_A	et	f	\N
129595	kaduvad	kaduvad =kaduva  (PlN  >kaduv !02_A	et	f	\N
129596	kaduvad	"kaduv %kadu  )V_vA  <kaduma ;28_V	et	f	\N
129602	arusaamisest	arusaamisest =saamise  (SgEl  >aru+saamine !12?10_S	et	f	\N
129603	arusaamisest	"aru+saamine %saami  )NE_aA  <aru+saam ;22_S	et	f	\N
129612	segavad	segavad =sega  (IndPrPl3  >segama !27_V	et	f	\N
129613	segavad	segavad =segava  (PlN  >segav !02_A	et	f	\N
129614	segavad	"segav %sega  )V_vA  <segama ;27_V	et	f	\N
129653	seletamiseks	seletamiseks =seletamise  (SgTr  >seletamine !12_S	et	f	\N
129654	seletamiseks	"seletamine %seleta  )MINE_vS  <seletama ;27_V	et	f	\N
129655	pühenduvad	pühenduvad =pühendu  (IndPrPl3  >pühenduma !27_V	et	f	\N
129656	pühenduvad	pühenduvad =pühenduva  (PlN  >pühenduv !02_A	et	f	\N
129270	muusikantitega	?muusikantitega =sikanti  (PlKom  >muu+sikanti !01_S	et	f	\N
129277	pakkuti	?pakkuti =pakkuti  (SgN  >pakkuti !01_S	et	f	\N
129278	pakkuti	?pakkuti =pakkuti  (SgG  >pakkuti !01_S	et	f	\N
129279	pakkuti	?pakkuti =pakkuti  (SgG  >pakkut !02_S	et	f	\N
129280	pakkuti	?pakkuti =pakkuti  (SgG  >pakkutt !22_S	et	f	\N
129281	pakkuti	?pakkuti =pakkuti  (IndPrPs_  >pakkuttima !28_V	et	f	\N
129282	pakkuti	?pakkuti =pakkuti  (ImpPrSg2  >pakkuttima !28_V	et	f	\N
129286	intervjuud	intervjuud =intervjuu  (PlN  >intervjuu !26_S	et	f	\N
129287	intervjuud	intervjuud =intervjuu  (SgP  >intervjuu !26_S	et	f	\N
129288	televiisionil	?televiisionil =televiisioni  (SgAd  >televiision !19~02_S	et	f	\N
129289	televiisionil	?televiisionil =televiisioni  (SgAd  >televiisioni !16_S	et	f	\N
129290	televiisionil	?televiisionil =televiisionil  (SgN  >televiisionil !02_S	et	f	\N
129291	televiisionil	?televiisionil =oni  (SgAd  >tele+viisi+oni !17_S	et	f	\N
129292	televiisionil	?televiisionil =ioni  (SgAd  >tele+viis+ioni !16_S	et	f	\N
129293	televiisionil	?televiisionil =ioni  (SgAd  >tele+viis+ion !22_S	et	f	\N
129294	televiisionil	?televiisionil =viisioni  (SgAd  >tele+viision !19~02_S	et	f	\N
129295	televiisionil	?televiisionil =viisioni  (SgAd  >tele+viisioni !16_S	et	f	\N
129296	televiisionil	?televiisionil =viisionil  (SgN  >tele+viisionil !02_S	et	f	\N
129297	toimetaja	toimetaja =toimetaja  (SgN  >toimetaja !01_S	et	f	\N
129298	toimetaja	"toimetaja %toimeta  )JA_vS  <toimetama ;27_V	et	f	\N
129299	toimetaja	toimetaja =toimetaja  (SgG  >toimetaja !01_S	et	f	\N
129307	intervjuut	?intervjuut =intervjuut  (SgN  >intervjuut !22_S	et	f	\N
129312	selletan	?selletan =selleta  (IndPrSg1  >selletama !27_V	et	f	\N
129313	selletan	?selletan =selletan  (SgN  >selletan !19_S	et	f	\N
129325	ajakirjanikkuna	### ajakirjanikkuna	et	f	\N
129334	tarkad	?tarkad =tarka  (PlN  >tarka !16_S	et	f	\N
129335	tarkad	?tarkad =tarka  (IndPrSg2  >tarkama !29_V	et	f	\N
129339	tegesin	?tegesin =tegesin  (SgN  >tegesin !19_S	et	f	\N
129340	kujundamiseks	kujundamiseks =kujundamise  (SgTr  >kujundamine !12_S	et	f	\N
129341	kujundamiseks	"kujundamine %kujunda  )MINE_vS  <kujundama ;27_V	et	f	\N
129343	sündmusesse	sündmusesse =sündmuse  (SgIll  >sündmus !11~09_S	et	f	\N
129344	sündmusesse	sündmusesse =sündmuses  (SgAdt  >sündmusene !12_A	et	f	\N
129345	sündmusesse	"sündmusene %sündmuse  )NE_aA  <sündmus ;09_S	et	f	\N
129346	sündmusesse	"sündmusene %sündmuse  )NE_aA  <sündmus ;11_S	et	f	\N
129347	tänapäevane	tänapäevane =päevane  (SgN  >täna+päevane !10_A	et	f	\N
129348	tänapäevane	"täna+päevane %päeva  )NE_aA  <täna+päev ;22_S	et	f	\N
129364	etv	?etv =etv  (SgN  >etv !22_S	et	f	\N
129374	meiele	meiele =meie  (SgAll  >meie !16_S	et	f	\N
129375	meiele	meiele =meie  (PlAll  >meig !22_S	et	f	\N
129390	kõig	?kõig =kõig  (SgN  >kõig !22_S	et	f	\N
129397	reaalsus	reaalsus =reaalsus  (SgN  >reaalsus !11~09_S	et	f	\N
129398	reaalsus	"reaalsus %reaalse  )US_aS  <reaalne ;02_A	et	f	\N
129404	studentile	?studentile =studenti  (SgAll  >studenti !01_S	et	f	\N
129406	annaks	annaks =anna  (SgTr  >anna !16_S	et	f	\N
129407	annaks	annaks =anna  (KndPrPs  >andma !34_V	et	f	\N
129412	tollel	tollel =tolle  (SgAd  >too !00_P	et	f	\N
129413	tollel	tollel =tolle  (PlAd  >toll !22_S	et	f	\N
129414	pooleteistaastasena	pooleteistaastasena =aastase  (SgEs  >poole+teist+aastane !12~10_A	et	f	\N
129415	pooleteistaastasena	"poole+teist+aastane %aasta  )NE_aA  <poole+teist+aasta ;01_S	et	f	\N
129418	kaheksaastasena	?kaheksaastasena =kaheksaastase  (SgEs  >kaheksaastane !12~10_A	et	f	\N
129419	kaheksaastasena	?kaheksaastasena =astase  (SgEs  >kaheksa+astane !12~10_A	et	f	\N
129420	kaheksaastasena	?kaheksaastasena =ksaastase  (SgEs  >kahe+ksaastane !12~10_A	et	f	\N
129423	omapärasus	omapärasus =pärasus  (SgN  >oma+pärasus !11_S	et	f	\N
129424	omapärasus	"oma+pärasus %pära  )SUS_aS  <oma+pära ;17_S	et	f	\N
129434	kaasasündinud	kaasasündinud =sündi  (PtsPtPs  >kaasa+_sündima !28_V	et	f	\N
129435	kaasasündinud	kaasasündinud =sündinu  (PlN  >kaasa+sündinu !01_S	et	f	\N
129439	võitu	võitu =võitu  (ID  >võitu !41_A	et	f	\N
129440	võitu	"võitu %või  )TU1_vS  <võidma ;34_V	et	f	\N
129441	võitu	"võitu %või  )TU2_kA  <või ;26_S	et	f	\N
129442	võitu	võitu =võitu  (SgN  >võitu !01_SA	et	f	\N
129443	võitu	võitu =võitu  (SgG  >võitu !01_SA	et	f	\N
129444	võitu	võitu =võitu  (SgP  >võit !22_S	et	f	\N
129445	võitu	võitu =võitu  (SgAdt  >võit !22_S	et	f	\N
129446	lõpetamata	lõpetamata =lõpeta  (SupAb  >lõpetama !27_V	et	f	\N
129447	lõpetamata	lõpetamata =lõpetamata  (ID  >lõpetamata !41_A	et	f	\N
129448	lõpetamata	"lõpetamata %lõpeta  )MATA_vA  <lõpetama ;27_V	et	f	\N
129482	iirimaad	iirimaad =maa  (PlN  >iiri+maa !26_S	et	f	\N
129483	iirimaad	iirimaad =maa  (SgP  >iiri+maa !26_S	et	f	\N
129496	arusaamisel	arusaamisel =saamise  (SgAd  >aru+saamine !12?10_S	et	f	\N
129497	arusaamisel	"aru+saamine %saami  )NE_aA  <aru+saam ;22_S	et	f	\N
129512	isikuomaseks	isikuomaseks =seks  (SgN  >isiku+oma+seks !22_S	et	f	\N
129513	isikuomaseks	isikuomaseks =omase  (SgTr  >isiku+omane !10_A	et	f	\N
129524	erinevusest	erinevusest =erinevuse  (SgEl  >erinevus !11?09_S	et	f	\N
129525	erinevusest	"erinevus %erine  )VUS_aS  <erinema ;27_V	et	f	\N
129526	erinevusest	"erinevus %erineva  )US_aS  <erinev ;02_A	et	f	\N
129527	erinevusest	erinevusest =erinevuses  (SgP  >erinevusene !12_A	et	f	\N
129528	erinevusest	"erinevusene %erinevuse  )NE_aA  <erinevus ;09_S	et	f	\N
129529	erinevusest	"erinevusene %erinevuse  )NE_aA  <erinevus ;11_S	et	f	\N
129545	pikema	pikema =pikema  (SgG  >pikem !02_A	et	f	\N
129546	pikema	"pikem %pike  )M_cA  <pikk ;22_AS	et	f	\N
129549	lahtiseks	lahtiseks =lahtise  (SgTr  >lahtine !12~10_A	et	f	\N
129551	lahtiseks	lahtiseks =seks  (SgN  >lahti+seks !22_S	et	f	\N
129557	vastand	vastand =vastand  (SgN  >vastand !02_S	et	f	\N
129558	vastand	vastand =and  (SgN  >vast+and !22_S	et	f	\N
129559	tõeni	tõeni =tõe  (SgTer  >tõsi !15_S	et	f	\N
129560	tõeni	tõeni =tõe  (SgTer  >tõde !18_S	et	f	\N
129565	analüüsivaks	analüüsivaks =analüüsiva  (SgTr  >analüüsiv !02_A	et	f	\N
129566	analüüsivaks	"analüüsiv %analüüsi  )V_vA  <analüüsima ;28_V	et	f	\N
129567	analüüsivaks	analüüsivaks =vaks  (SgN  >analüüsi+vaks !22_S	et	f	\N
129572	läänes	läänes =lääne  (SgIn  >lääs !14_S	et	f	\N
129573	läänes	läänes =lääne  (PlIn  >lään !22_S	et	f	\N
129577	suuremaks	suuremaks =suurema  (SgTr  >suurem !02_A	et	f	\N
129578	suuremaks	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
129579	suuremaks	suuremaks =maks  (SgN  >suure+maks !22_S	et	f	\N
129580	suuremaks	suuremaks =ema  (SgTr  >suur+ema !17_S	et	f	\N
129583	vestlusepartneri	?vestlusepartneri =vestlusepartneri  (SgG  >vestlusepartner !02_S	et	f	\N
129584	vestlusepartneri	?vestlusepartneri =epartneri  (SgG  >vestlus+epartner !02_S	et	f	\N
129591	rahvade	?rahvade =rahva  (PlG  >rahva !16_S	et	f	\N
129597	ülatatud	?ülatatud =ülata  (PtsPtIps  >ülatama !27_V	et	f	\N
129598	ülatatud	?ülatatud =ülatatu  (PlN  >ülatatu !01_S	et	f	\N
129599	ülatatud	?ülatatud =ülatatu  (IndPrSg2  >ülatatuma !27_V	et	f	\N
129600	ülatatud	?ülatatud =ülatatud  (ID  >ülatatud !41_A	et	f	\N
129601	ülatatud	?ülatatud =tatu  (PlN  >üla+tatu !16_S	et	f	\N
129610	orienteerimist	orienteerimist =orienteerimis  (SgP  >orienteerimine !12_S	et	f	\N
129611	orienteerimist	"orienteerimine %orienteeri  )MINE_vS  <orienteerima ;28_V	et	f	\N
129639	prognoosida	prognoosida =prognoosi  (Inf  >prognoosima !28_V	et	f	\N
129640	prognoosida	prognoosida =ida  (SgN  >prognoos+ida !17_S	et	f	\N
129641	prognoosida	prognoosida =ida  (SgG  >prognoos+ida !17_S	et	f	\N
129642	prognoosida	prognoosida =ida  (SgP  >prognoos+ida !17_S	et	f	\N
129669	ebakindluse	ebakindluse =kindluse  (SgG  >eba+kindlus !11~09_S	et	f	\N
129671	ebakindluse	"eba+kindlus %kindla  )US_aS  <eba+kindel ;02_A	et	f	\N
129675	sügav	sügav =süga  (PtsPrPs  >sügama !27_V	et	f	\N
129676	sügav	sügav =sügav  (SgN  >sügav !02_A	et	f	\N
129677	sügav	"sügav %süga  )V_vA  <sügama ;27_V	et	f	\N
129684	põhinevad	põhinevad =põhine  (IndPrPl3  >põhinema !27_V	et	f	\N
129685	põhinevad	põhinevad =põhineva  (PlN  >põhinev !02_A	et	f	\N
129686	põhinevad	"põhinev %põhine  )V_vA  <põhinema ;27_V	et	f	\N
129689	käitumisega	käitumisega =käitumise  (SgKom  >käitumine !12_S	et	f	\N
129690	käitumisega	"käitumine %käitu  )MINE_vS  <käituma ;27_V	et	f	\N
129706	agressivne	?agressivne =agressivne  (SgN  >agressivne !02_A	et	f	\N
129707	agressivne	?agressivne =agressivne  (PlP  >agressivn !22_S	et	f	\N
129716	ebakindlust	ebakindlust =kindlus  (SgP  >eba+kindlus !11~09_S	et	f	\N
129718	ebakindlust	"eba+kindlus %kindla  )US_aS  <eba+kindel ;02_A	et	f	\N
129723	uskumistest	uskumistest =uskumis  (PlEl  >uskumine !12_S	et	f	\N
129724	uskumistest	"uskumine %usku  )MINE_vS  <uskuma ;28_V	et	f	\N
129725	uskumistest	uskumistest =test  (SgN  >usku+mis+test !22_S	et	f	\N
129726	sisalduv	sisalduv =sisaldu  (PtsPrPs  >sisalduma !27_V	et	f	\N
129727	sisalduv	sisalduv =sisalduv  (SgN  >sisalduv !02_A	et	f	\N
129728	sisalduv	"sisalduv %sisaldu  )V_vA  <sisalduma ;27_V	et	f	\N
129734	välistavad	välistavad =välista  (IndPrPl3  >välistama !27_V	et	f	\N
129735	välistavad	välistavad =välistava  (PlN  >välistav !02_A	et	f	\N
129736	välistavad	"välistav %välista  )V_vA  <välistama ;27_V	et	f	\N
129738	välistavad	välistavad =tava  (PlN  >välis+tava !17_S	et	f	\N
129754	kergemini	kergemini =kergemi  (SgTer  >kergem !02_A	et	f	\N
129755	kergemini	"kergem %kerge  )M_cA  <kerge ;01_A	et	f	\N
129756	kergemini	kergemini =mi  (SgTer  >kerge+mi !26_S	et	f	\N
129757	kergemini	kergemini =mini  (SgN  >kerge+mini !17~16_S	et	f	\N
129758	kergemini	kergemini =mini  (SgG  >kerge+mini !17~16_S	et	f	\N
129759	kergemini	kergemini =mini  (SgP  >kerge+mini !17_S	et	f	\N
129782	eestimal	eestimal =ima  (SgAd  >eest+ima !17_S	et	f	\N
129783	eestimal	eestimal =imal  (SgN  >eest+imal !02_A	et	f	\N
129784	erinevatest	erinevatest =erineva  (PlEl  >erinev !02_A	et	f	\N
129785	erinevatest	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
129788	riikil	### riikil	et	f	\N
129818	sillmaringi	?sillmaringi =sillmaringi  (SgG  >sillmaring !02_S	et	f	\N
129819	sillmaringi	?sillmaringi =sillmaringi  (SgG  >sillmarink !22_S	et	f	\N
129820	sillmaringi	?sillmaringi =sillmaringi  (IndPrPs_  >sillmarinkima !28_V	et	f	\N
129821	sillmaringi	?sillmaringi =sillmaringi  (ImpPrSg2  >sillmarinkima !28_V	et	f	\N
129822	sillmaringi	?sillmaringi =sillmarin  (SgN^  >sillmarin !19_S	et	f	\N
129544	lühema	"lühem %lühe  )M_cA  <lühike ;12_A	et	f	\N
129554	otsimisega	otsimisega =otsimise  (SgKom  >otsimine !12_S	et	f	\N
129555	otsimisega	"otsimine %otsi  )MINE_vS  <otsima ;28_V	et	f	\N
129561	mõtteviisi	mõtteviisi =viisi  (ID  >mõtte+viisi !41_D	et	f	\N
129562	mõtteviisi	mõtteviisi =viisi  (SgG  >mõtte+viis !22_S	et	f	\N
129563	mõtteviisi	mõtteviisi =viisi  (SgP  >mõtte+viis !22_S	et	f	\N
129564	mõtteviisi	mõtteviisi =viisi  (SgAdt  >mõtte+viis !22_S	et	f	\N
129568	sünteesivaks	sünteesivaks =sünteesiva  (SgTr  >sünteesiv !02_A	et	f	\N
129569	sünteesivaks	"sünteesiv %sünteesi  )V_vA  <sünteesima ;28_V	et	f	\N
129570	sünteesivaks	sünteesivaks =vaks  (SgN  >sünteesi+vaks !22_S	et	f	\N
129571	sünteesivaks	sünteesivaks =iva  (SgTr  >süntees+iva !17_S	et	f	\N
129648	erinevusi	erinevusi =erinevusi  (PlP  >erinevus !11_S	et	f	\N
129649	erinevusi	"erinevus %erine  )VUS_aS  <erinema ;27_V	et	f	\N
129650	erinevusi	"erinevus %erineva  )US_aS  <erinev ;02_A	et	f	\N
129657	otsimisele	otsimisele =otsimise  (SgAll  >otsimine !12_S	et	f	\N
129659	otsimisele	"otsimine %otsi  )MINE_vS  <otsima ;28_V	et	f	\N
129668	talumise	talumise =talumise  (SgG  >talumine !12_S	et	f	\N
129670	talumise	"talumine %talu  )MINE_vS  <taluma ;27_V	et	f	\N
129672	talumise	"talumine %talumi  )NE_aA  <talum ;02_S	et	f	\N
129695	väärtusest	väärtusest =väärtuse  (SgEl  >väärtus !11~09_S	et	f	\N
129697	väärtusest	väärtusest =väärtuses  (SgP  >väärtusene !12_A	et	f	\N
129698	väärtusest	"väärtusene %väärtuse  )NE_aA  <väärtus ;09_S	et	f	\N
129699	väärtusest	"väärtusene %väärtuse  )NE_aA  <väärtus ;11_S	et	f	\N
129700	väärtusest	väärtusest =use  (PlEl  >väärt+usk !22_S	et	f	\N
129714	taluvad	taluvad =talu  (IndPrPl3  >taluma !27_V	et	f	\N
129715	taluvad	taluvad =taluva  (PlN  >taluv !02_A	et	f	\N
129717	taluvad	"taluv %talu  )V_vA  <taluma ;27_V	et	f	\N
129737	teineteise	teineteise =teise  (SgAdt  >teine+teise !12_P	et	f	\N
129739	teineteise	teineteise =teise  (SgG  >teine+teise !12_P	et	f	\N
129766	avalikkud	?avalikkud =avalikku  (IndPrSg2  >avalikkuma !27_V	et	f	\N
129789	riigikeelt	riigikeelt =kee  (SgAbl  >riigi+kesi !15_S	et	f	\N
129790	riigikeelt	riigikeelt =kee  (SgAbl  >riigi+kee !26_S	et	f	\N
129791	riigikeelt	riigikeelt =keel  (SgP  >riigi+keel !13_S	et	f	\N
129795	elavatest	elavatest =elava  (PlEl  >elav !02_A	et	f	\N
129796	elavatest	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
129797	elavatest	elavatest =ate  (PlEl  >elav+att !22_S	et	f	\N
129803	keelest	keelest =keele  (SgEl  >keel !13_S	et	f	\N
129804	keelest	keelest =keele  (PlEl  >keeld !22_S	et	f	\N
129805	keelest	keelest =keeles  (SgP  >keelene !10_A	et	f	\N
129806	keelest	"keelene %keele  )NE_aA  <keel ;13_S	et	f	\N
129813	erinevases	?erinevases =erinevase  (SgIn  >erinevane !12_A	et	f	\N
129814	erinevases	?erinevases =nevase  (SgIn  >eri+nevane !10_A	et	f	\N
129823	jõuvad	?jõuvad =jõuva  (PlN  >jõuva !16_S	et	f	\N
129824	jõuvad	?jõuvad =jõuva  (IndPrSg2  >jõuvama !29_V	et	f	\N
129827	leia	leia =leia  (IndPrPs_  >leidma !34_V	et	f	\N
129828	leia	leia =leia  (ImpPrSg2  >leidma !34_V	et	f	\N
129839	emakeel	emakeel =kee  (SgAd  >ema+kesi !15_S	et	f	\N
129840	emakeel	emakeel =kee  (SgAd  >ema+kee !26_S	et	f	\N
129841	emakeel	emakeel =keel  (SgN  >ema+keel !13_S	et	f	\N
129845	võõramaalne	?võõramaalne =võõramaalne  (SgN  >võõramaalne !02_A	et	f	\N
129846	võõramaalne	?võõramaalne =võõramaalne  (PlP  >võõramaaln !22_S	et	f	\N
129847	võõramaalne	?võõramaalne =maalne  (SgN  >võõra+maalne !02_A	et	f	\N
129848	võõramaalne	?võõramaalne =maalne  (PlP  >võõra+maaln !22_S	et	f	\N
129849	võõramaalne	?võõramaalne =amaalne  (SgN  >võõr+amaalne !02_A	et	f	\N
129851	võõramaalne	?võõramaalne =amaalne  (PlP  >võõr+amaaln !22_S	et	f	\N
129860	gruppid	### gruppid	et	f	\N
129880	kultuuriparadoksiga	kultuuriparadoksiga =si  (SgKom  >kultuuri+para+dok+si !26_S	et	f	\N
129881	kultuuriparadoksiga	kultuuriparadoksiga =siga  (SgN  >kultuuri+para+dok+siga !18_SA	et	f	\N
129882	kultuuriparadoksiga	kultuuriparadoksiga =siga  (SgP  >kultuuri+para+dok+siga !18_SA	et	f	\N
129883	kultuuriparadoksiga	kultuuriparadoksiga =paradoksi  (SgKom  >kultuuri+paradoks !22_S	et	f	\N
129900	magistratuuris	?magistratuuris =magistratuuri  (SgIn  >magistratuuri !16_S	et	f	\N
129901	magistratuuris	?magistratuuris =magistratuuri  (SgIn  >magistratuur !22_S	et	f	\N
129902	magistratuuris	?magistratuuris =magistratuuri  (IndIpfSg3  >magistratuurima !28_V	et	f	\N
129903	magistratuuris	?magistratuuris =magistratuuris  (SgN  >magistratuuris !09_S	et	f	\N
129904	astad	?astad =asta  (PlN  >asta !16_S	et	f	\N
129905	astad	?astad =asta  (IndPrSg2  >astama !29_V	et	f	\N
129925	klassisõper	?klassisõper =klassisõper  (SgN  >klassisõper !02_S	et	f	\N
129926	klassisõper	?klassisõper =sõper  (SgN  >klassi+sõper !02_S	et	f	\N
129932	kellelt	kellelt =kelle  (SgAbl  >kes !00_P	et	f	\N
129933	kellelt	kellelt =kelle  (PlAbl  >kell !22_S	et	f	\N
129953	õppemaja	õppemaja =maja  (SgN  >õppe+maja !17_S	et	f	\N
129954	õppemaja	õppemaja =maja  (SgG  >õppe+maja !17_S	et	f	\N
129955	õppemaja	õppemaja =maja  (SgP  >õppe+maja !17_S	et	f	\N
129992	kehti	kehti =kehti  (IndPrPs_  >kehtima !27_V	et	f	\N
129556	hüve	hüve =hüve  (SgG  >hüve !16_S	et	f	\N
129574	teoretilisi	?teoretilisi =teoretilisi  (PlP  >teoretiline !12_A	et	f	\N
129575	teoretilisi	?teoretilisi =retilisi  (PlP  >teo+retiline !12_A	et	f	\N
129581	vääriti	vääriti =vääri  (IndIpfIps  >väärima !28_V	et	f	\N
129582	vääriti	vääriti =vääriti  (ID  >vääriti !41_D	et	f	\N
129585	keele-	keele- =kee  (SgAll  >kesi !15_S	et	f	\N
129586	keele-	keele- =kee  (SgAll  >kee !26_S	et	f	\N
129587	keele-	keele- =keele  (SgG  >keel !13_S	et	f	\N
129590	hulg	?hulg =hulg  (SgN  >hulg !22_S	et	f	\N
129592	tekkistavad	?tekkistavad =tekkista  (IndPrPl3  >tekkistama !27_V	et	f	\N
129593	tekkistavad	?tekkistavad =tekkistava  (PlN  >tekkistav !02_A	et	f	\N
129594	tekkistavad	?tekkistavad =tekkistava  (PlN  >tekkistava !16_S	et	f	\N
129607	tava-	tava- =tava  (SgN  >tava !17_S	et	f	\N
129608	tava-	tava- =tava  (SgG  >tava !17_S	et	f	\N
129609	tava-	tava- =tava  (SgP  >tava !17_S	et	f	\N
129619	keeleteritooriumi	?keeleteritooriumi =keeleteritooriumi  (SgN  >keeleteritooriumi !16_S	et	f	\N
129620	keeleteritooriumi	?keeleteritooriumi =keeleteritooriumi  (SgG  >keeleteritoorium !19~02_S	et	f	\N
129621	keeleteritooriumi	?keeleteritooriumi =keeleteritooriumi  (SgG  >keeleteritooriumi !16_S	et	f	\N
129622	keeleteritooriumi	?keeleteritooriumi =keeleteritooriumi  (SgP  >keeleteritoorium !19_S	et	f	\N
129623	keeleteritooriumi	?keeleteritooriumi =keeleteritooriumi  (SgAdt  >keeleteritoorium !19_S	et	f	\N
129624	keeleteritooriumi	?keeleteritooriumi =keeleteritooriumi  (IndPrPs_  >keeleteritooriumima !28_V	et	f	\N
129625	keeleteritooriumi	?keeleteritooriumi =keeleteritooriumi  (ImpPrSg2  >keeleteritooriumima !28_V	et	f	\N
129626	keeleteritooriumi	?keeleteritooriumi =teritooriumi  (SgN  >keele+teritooriumi !16_S	et	f	\N
129627	keeleteritooriumi	?keeleteritooriumi =teritooriumi  (SgG  >keele+teritoorium !19~02_S	et	f	\N
129628	keeleteritooriumi	?keeleteritooriumi =teritooriumi  (SgG  >keele+teritooriumi !16_S	et	f	\N
129629	keeleteritooriumi	?keeleteritooriumi =teritooriumi  (SgP  >keele+teritoorium !19_S	et	f	\N
129630	keeleteritooriumi	?keeleteritooriumi =teritooriumi  (SgAdt  >keele+teritoorium !19_S	et	f	\N
129631	keeleteritooriumi	?keeleteritooriumi =eteritooriumi  (SgN  >keel+eteritooriumi !16_S	et	f	\N
129632	keeleteritooriumi	?keeleteritooriumi =eteritooriumi  (SgG  >keel+eteritoorium !19~02_S	et	f	\N
129633	keeleteritooriumi	?keeleteritooriumi =eteritooriumi  (SgG  >keel+eteritooriumi !16_S	et	f	\N
129634	keeleteritooriumi	?keeleteritooriumi =eteritooriumi  (SgP  >keel+eteritoorium !19_S	et	f	\N
129635	keeleteritooriumi	?keeleteritooriumi =eteritooriumi  (SgAdt  >keel+eteritoorium !19_S	et	f	\N
129636	vastada	?vastada =ada  (SgN  >vast+ada !17_S	et	f	\N
129637	vastada	?vastada =ada  (SgG  >vast+ada !17_S	et	f	\N
129638	vastada	?vastada =ada  (SgP  >vast+ada !17_S	et	f	\N
129651	õpid	õpid =õpi  (PlN  >õpp !22_S	et	f	\N
129652	õpid	õpid =õpi  (IndPrSg2  >õppima !28_V	et	f	\N
129660	enesearendamisvõimalused	?enesearendamisvõimalused =enesearendamisvõimaluse  (PlN  >enesearendamisvõimalus !11?09_S	et	f	\N
129661	enesearendamisvõimalused	?enesearendamisvõimalused =arendamisvõimaluse  (PlN  >enese+arendamisvõimalus !11?09_S	et	f	\N
129662	viisil	viisil =viisi  (SgAd  >viis !22_S	et	f	\N
129663	viisil	viisil =viisil  (ID  >viisil !41_DK	et	f	\N
129664	küsitlusest	küsitlusest =küsitluse  (SgEl  >küsitlus !11_S	et	f	\N
129665	küsitlusest	"küsitlus %küsitle  )US_vS  <küsitlema ;27_V	et	f	\N
129666	küsitlusest	küsitlusest =küsitluses  (SgP  >küsitlusene !12_A	et	f	\N
129667	küsitlusest	"küsitlusene %küsitluse  )NE_aA  <küsitlus ;11_S	et	f	\N
129673	usutakse	usutakse =usu  (IndPrIps  >uskuma !28_V	et	f	\N
129674	usutakse	usutakse =takse  (PlP  >usu+taks !22_S	et	f	\N
129680	veelahe	veelahe =ahe  (SgN  >veel+ahe !06_S	et	f	\N
129681	veelahe	veelahe =lahe  (SgN  >vee+lahe !02_A	et	f	\N
129682	veelahe	veelahe =lahe  (SgN  >vee+lahe !05_S	et	f	\N
129683	veelahe	veelahe =lahe  (SgG  >vee+laht !22_S	et	f	\N
129687	jõuavad	jõuavad =jõua  (IndPrPl3  >jõudma !34_V	et	f	\N
129688	jõuavad	jõuavad =ava  (PlN  >jõu+ava !17_S	et	f	\N
129691	kultuurisest	?kultuurisest =kultuurise  (SgEl  >kultuuris !09_S	et	f	\N
129693	kultuurisest	?kultuurisest =kultuurises  (SgP  >kultuurisene !12_A	et	f	\N
129694	kultuurisest	?kultuurisest =ises  (SgP  >kultuur+ises !09_S	et	f	\N
129696	kultuurisest	?kultuurisest =ises  (SgP  >kultuur+isene !10_A	et	f	\N
129701	uskumusest	uskumusest =uskumuse  (SgEl  >uskumus !11_S	et	f	\N
129702	uskumusest	uskumusest =uskumuses  (SgP  >uskumusene !12_A	et	f	\N
129703	uskumusest	"uskumusene %uskumuse  )NE_aA  <uskumus ;11_S	et	f	\N
129710	visa	visa =visa  (SgN  >visa !17_A	et	f	\N
129711	visa	visa =visa  (SgG  >visa !17_A	et	f	\N
129712	visa	visa =visa  (SgP  >visa !17_A	et	f	\N
129740	teooria	teooria =teooria  (SgN  >teooria !01_S	et	f	\N
129741	teooria	teooria =teooria  (SgG  >teooria !01_S	et	f	\N
129742	isamaa	isamaa =maa  (SgN  >isa+maa !26_S	et	f	\N
129743	isamaa	isamaa =maa  (SgG  >isa+maa !26_S	et	f	\N
129776	multicultural	?multicultural =multicultura  (SgAd  >multicultura !16_S	et	f	\N
129777	multicultural	?multicultural =multicultural  (SgN  >multicultural !19_S	et	f	\N
129779	multicultural	?multicultural =cultura  (SgAd  >multi+cultura !01_S	et	f	\N
129780	multicultural	?multicultural =cultural  (SgN  >multi+cultural !19_S	et	f	\N
129658	pühenduvad	"pühenduv %pühendu  )V_vA  <pühenduma ;27_V	et	f	\N
129678	filosoofiline	filosoofiline =filosoofiline  (SgN  >filosoofiline !12_A	et	f	\N
129679	filosoofiline	"filosoofiline %filosoofi  )LINE_aA  <filosoof ;22_S	et	f	\N
129692	enesestmõistetavuset	### enesestmõistetavuset	et	f	\N
129704	konfliktne	?konfliktne =konfliktne  (SgN  >konfliktne !02_A	et	f	\N
129705	konfliktne	?konfliktne =konfliktne  (PlP  >konfliktn !22_S	et	f	\N
129719	küsimuste	küsimuste =küsimus  (PlG  >küsimus !11_S	et	f	\N
129720	küsimuste	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
129721	küsimuste	küsimuste =muste  (PlP  >küsi+must !22_AS	et	f	\N
129722	araldab	?araldab =aralda  (IndPrSg3  >araldama !27_V	et	f	\N
129729	iseennes	?iseennes =iseenne  (PlIn  >iseenn !22_S	et	f	\N
129730	iseennes	?iseennes =enne  (PlIn  >ise+enn !22_S	et	f	\N
129731	iseennes	?iseennes =ennes  (SgN  >ise+ennes !09_S	et	f	\N
129732	mõistetavas	mõistetavas =mõistetava  (SgIn  >mõistetav !02_A	et	f	\N
129733	mõistetavas	"mõistetav %mõiste  )TAV_vAS  <mõistma ;34_V	et	f	\N
129748	avavad	avavad =ava  (IndPrPl3  >avama !27_V	et	f	\N
129749	avavad	avavad =avava  (PlN  >avav !02_A	et	f	\N
129750	avavad	"avav %ava  )V_vA  <avama ;27_V	et	f	\N
129751	erinevamate	erinevamate =erinevama  (PlG  >erinevam !02_A	et	f	\N
129752	erinevamate	"erinevam %erine  )VAM_cA  <erinema ;27_V	et	f	\N
129753	erinevamate	"erinevam %erineva  )M_cA  <erinev ;02_A	et	f	\N
129760	jooni	jooni =joon  (PlP  >joon !13_S	et	f	\N
129761	jooni	jooni =jooni  (IndPrPs_  >joonima !28_V	et	f	\N
129762	jooni	jooni =jooni  (ImpPrSg2  >joonima !28_V	et	f	\N
129767	kiirevad	?kiirevad =kiire  (IndPrPl3  >kiirema !27_V	et	f	\N
129768	kiirevad	?kiirevad =kiireva  (PlN  >kiireva !01_S	et	f	\N
129769	kiirevad	?kiirevad =kiireva  (PlN  >kiirev !02_A	et	f	\N
129770	kiirevad	?kiirevad =eva  (PlN  >kiir+eva !17_S	et	f	\N
129771	kultuuriterritorium	?kultuuriterritorium =kultuuriterritorium  (SgN  >kultuuriterritorium !19_S	et	f	\N
129772	kultuuriterritorium	?kultuuriterritorium =territorium  (SgN  >kultuuri+territorium !19_S	et	f	\N
129773	kultuuriterritorium	?kultuuriterritorium =iterritorium  (SgN  >kultuur+iterritorium !19_S	et	f	\N
129778	väikel	?väikel =väike  (SgAd  >väige !06_S	et	f	\N
129781	väikel	?väikel =väikel  (SgN  >väikel !02_S	et	f	\N
129792	kanadas	### kanadas	et	f	\N
129800	sugukeel	sugukeel =kee  (SgAd  >sugu+kesi !15_S	et	f	\N
129801	sugukeel	sugukeel =kee  (SgAd  >sugu+kee !26_S	et	f	\N
129802	sugukeel	sugukeel =keel  (SgN  >sugu+keel !13_S	et	f	\N
129807	tatarstanis	?tatarstanis =tatarstani  (SgIn  >tatarstan !02_S	et	f	\N
129808	tatarstanis	?tatarstanis =tatarstanis  (SgN  >tatarstanis !09_S	et	f	\N
129815	loogikast	loogikast =loogika  (SgEl  >loogika !01_S	et	f	\N
129816	loogikast	loogikast =loogikas  (SgP  >loogikane !12_A	et	f	\N
129817	loogikast	"loogikane %loogika  )NE_aA  <loogika ;01_S	et	f	\N
129850	rääkib	### rääkib	et	f	\N
129861	tekkivad	tekkivad =tekki  (IndPrPl3  >tekkima !27_V	et	f	\N
129862	tekkivad	tekkivad =tekkiva  (PlN  >tekkiv !02_A	et	f	\N
129863	tekkivad	"tekkiv %tekki  )V_vA  <tekkima ;27_V	et	f	\N
129864	tekkivad	"tekkiv %tekki  )V_vA  <tekkima ;28_V	et	f	\N
129877	kahtletama	?kahtletama =kahtleta  (Sup  >kahtletama !27_V	et	f	\N
129878	kahtletama	?kahtletama =kahtletama  (SgG  >kahtletam !02_A	et	f	\N
129879	kahtletama	?kahtletama =letama  (SgG  >kaht+letam !02_A	et	f	\N
129892	radios	?radios =radio  (SgIn  >radio !01_S	et	f	\N
129893	radios	?radios =radios  (SgN  >radios !22_S	et	f	\N
129897	semenarid	?semenarid =semenari  (PlN  >semenar !19_S	et	f	\N
129898	lõpetamis	?lõpetamis =lõpetami  (SgIn  >lõpetam !02_A	et	f	\N
129899	lõpetamis	?lõpetamis =lõpetamis  (SgN  >lõpetamis !09_S	et	f	\N
129906	präegu	?präegu =präegu  (SgN  >präegu !16_S	et	f	\N
129907	präegu	?präegu =präegu  (SgG  >präegu !16_S	et	f	\N
129908	präegu	?präegu =präegu  (IndPrPs_  >präeguma !27_V	et	f	\N
129909	präegu	?präegu =präegu  (IndPrPs_  >präekuma !28_V	et	f	\N
129910	präegu	?präegu =präegu  (ImpPrSg2  >präeguma !27_V	et	f	\N
129911	präegu	?präegu =präegu  (ImpPrSg2  >präekuma !28_V	et	f	\N
129914	räärida	?räärida =rääri  (Inf  >räärima !28_V	et	f	\N
129922	loesin	?loesin =loesi  (IndPrSg1  >loesima !28_V	et	f	\N
129923	loesin	?loesin =loesin  (SgN  >loesin !02_S	et	f	\N
129924	dots	?dots =dots  (SgN  >dots !22_S	et	f	\N
129947	olevikusse	olevikusse =oleviku  (SgIll  >olevik !25_S	et	f	\N
129948	olevikusse	olevikusse =kusse  (SgAdt  >olevi+kusi !20_S	et	f	\N
129949	otsustusest	otsustusest =otsustuse  (SgEl  >otsustus !11_S	et	f	\N
129950	otsustusest	"otsustus %otsusta  )US_vS  <otsustama ;27_V	et	f	\N
129951	otsustusest	otsustusest =otsustuses  (SgP  >otsustusene !12_A	et	f	\N
129952	otsustusest	"otsustusene %otsustuse  )NE_aA  <otsustus ;11_S	et	f	\N
129994	kalendarit	### kalendarit	et	f	\N
130015	tõlgen	?tõlgen =tõlge  (IndPrSg1  >tõlgema !27_V	et	f	\N
130016	tõlgen	?tõlgen =tõlgen  (SgN  >tõlgen !02_S	et	f	\N
130040	andragoogika	?andragoogika =andragoogika  (SgN  >andragoogika !01_S	et	f	\N
130041	andragoogika	?andragoogika =andragoogika  (SgG  >andragoogika !01_S	et	f	\N
130042	andragoogika	?andragoogika =andragoogika  (SgG  >andragoogikas !02_A	et	f	\N
129786	keeltest	keeltest =keel  (PlEl  >keel !13_S	et	f	\N
129787	keeltest	keeltest =test  (SgN  >keel+test !22_S	et	f	\N
129793	elavate	elavate =elava  (PlG  >elav !02_A	et	f	\N
129794	elavate	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
129798	japanlastest	?japanlastest =japanlas  (PlEl  >japanlane !12_S	et	f	\N
129799	japanlastest	?japanlastest =japanlastes  (SgP  >japanlastene !12_A	et	f	\N
129809	udmurdidel	### udmurdidel	et	f	\N
129831	aranenud	?aranenud =arane  (PtsPtPs  >aranema !27_V	et	f	\N
129832	aranenud	?aranenud =aranenu  (PlN  >aranenu !01_S	et	f	\N
129833	aranenud	?aranenud =aranenu  (IndPrSg2  >aranenuma !27_V	et	f	\N
129834	aranenud	?aranenud =aranenud  (ID  >aranenud !41_A	et	f	\N
129835	aranenud	?aranenud =nenu  (PlN  >ara+nenu !17_S	et	f	\N
129852	veatega	?veatega =veate  (SgKom  >veade !06_S	et	f	\N
129853	riikist	?riikist =riikis  (SgP  >riikis !11~09_S	et	f	\N
129854	riikist	?riikist =riikist  (SgN  >riikist !22_S	et	f	\N
129872	arusamine	?arusamine =arusamine  (SgN  >arusamine !12_S	et	f	\N
129873	arusamine	?arusamine =arusamine  (PlP  >arusamin !19_S	et	f	\N
129874	arusamine	?arusamine =samine  (SgN  >aru+samine !10_A	et	f	\N
129884	paremeni	?paremeni =paremeni  (SgG  >paremen !19_S	et	f	\N
129885	paremeni	?paremeni =paremeni  (SgP  >paremen !19_S	et	f	\N
129886	paremeni	?paremeni =paremeni  (SgAdt  >paremen !19_S	et	f	\N
129891	opimisest	?opimisest =opimise  (SgEl  >opimine !12_S	et	f	\N
129894	tundid	?tundid =tundi  (PlN  >tundi !16_S	et	f	\N
129895	tundid	?tundid =tundi  (PlN  >tunt !22_S	et	f	\N
129896	tundid	?tundid =tundi  (IndPrSg2  >tuntima !28_V	et	f	\N
129912	eriaial	eriaial =aia  (SgAd  >eri+aed !22_S	et	f	\N
129913	eriaial	eriaial =aia  (SgAd  >eri+ai !22_S	et	f	\N
129927	eliala	?eliala =eliala  (SgN  >eliala !01_S	et	f	\N
129928	eliala	?eliala =eliala  (SgG  >eliala !01_S	et	f	\N
129930	jutustused	jutustused =jutustuse  (PlN  >jutustus !11_S	et	f	\N
129931	jutustused	"jutustus %jutusta  )US_vS  <jutustama ;27_V	et	f	\N
129967	loeda	?loeda =loeda  (SgN  >loeda !16_S	et	f	\N
129968	loeda	?loeda =loeda  (SgG  >loeda !16_S	et	f	\N
129969	loeda	?loeda =loeda  (IndPrPs_  >loedama !29_V	et	f	\N
129970	loeda	?loeda =loeda  (ImpPrSg2  >loedama !29_V	et	f	\N
129971	tlü	### tlü	et	f	\N
129975	valda	valda =valda  (SgP  >vald !22_S	et	f	\N
129976	valda	valda =valda  (SgAdt  >vald !22_S	et	f	\N
129977	valda	valda =valda  (IndPrPs_  >valdama !29_V	et	f	\N
129978	valda	valda =valda  (ImpPrSg2  >valdama !29_V	et	f	\N
129982	riigikeel	riigikeel =kee  (SgAd  >riigi+kesi !15_S	et	f	\N
129983	riigikeel	riigikeel =kee  (SgAd  >riigi+kee !26_S	et	f	\N
129984	riigikeel	riigikeel =keel  (SgN  >riigi+keel !13_S	et	f	\N
129988	sõbraid	?sõbraid =sõbrai  (PlN  >sõbrai !26_S	et	f	\N
129989	sõbraid	?sõbraid =sõbrai  (SgP  >sõbrai !26_S	et	f	\N
129990	sõbraid	?sõbraid =sõbraid  (SgN  >sõbraid !22_S	et	f	\N
129991	suvit	?suvit =suvit  (SgN  >suvit !02_S	et	f	\N
129997	hinnadest	?hinnadest =hinna  (PlEl  >hinna !16_S	et	f	\N
129998	hinnadest	?hinnadest =hinnades  (SgP  >hinnadene !12_A	et	f	\N
129999	emakeelest	emakeelest =keele  (SgEl  >ema+keel !13_S	et	f	\N
130000	emakeelest	emakeelest =keele  (PlEl  >ema+keeld !22_S	et	f	\N
130001	emakeelest	emakeelest =keeles  (SgP  >ema+keelene !10_A	et	f	\N
130002	emakeelest	"ema+keelene %keele  )NE_aA  <ema+keel ;13_S	et	f	\N
130020	õppetada	?õppetada =õppeta  (Inf  >õppetama !27_V	et	f	\N
130021	õppetada	?õppetada =tada  (SgN  >õppe+tada !17_S	et	f	\N
130022	õppetada	?õppetada =tada  (SgG  >õppe+tada !17_S	et	f	\N
130023	õppetada	?õppetada =tada  (SgP  >õppe+tada !17_S	et	f	\N
130025	jutustusi	jutustusi =jutustusi  (PlP  >jutustus !11_S	et	f	\N
130026	jutustusi	"jutustus %jutusta  )US_vS  <jutustama ;27_V	et	f	\N
130033	suuremat	suuremat =suurema  (SgP  >suurem !02_A	et	f	\N
130034	suuremat	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
130050	astumisel	astumisel =astumise  (SgAd  >astumine !12_S	et	f	\N
130051	astumisel	"astumine %astu  )MINE_vS  <astuma ;28_V	et	f	\N
130072	hinneid	?hinneid =hinnei  (PlN  >hinnei !26_S	et	f	\N
130073	hinneid	?hinneid =hinnei  (SgP  >hinnei !26_S	et	f	\N
130074	hinneid	?hinneid =hinneid  (SgN  >hinneid !22_S	et	f	\N
130085	võõrkeelt	võõrkeelt =kee  (SgAbl  >võõr+kesi !15_S	et	f	\N
130086	võõrkeelt	võõrkeelt =kee  (SgAbl  >võõr+kee !26_S	et	f	\N
130087	võõrkeelt	võõrkeelt =keel  (SgP  >võõr+keel !13_S	et	f	\N
130091	keeliteadmised	?keeliteadmised =keeliteadmise  (PlN  >keeliteadmine !12_A	et	f	\N
130092	keeliteadmised	?keeliteadmised =iteadmise  (PlN  >keel+iteadmine !12_A	et	f	\N
130101	saadsin	?saadsin =saadsi  (IndPrSg1  >saadsima !28_V	et	f	\N
130102	saadsin	?saadsin =saadsin  (SgN  >saadsin !02_S	et	f	\N
130109	õppimis	?õppimis =õppimi  (SgIn  >õppimi !01_S	et	f	\N
130110	õppimis	?õppimis =õppimi  (SgIn  >õppim !02_A	et	f	\N
130111	õppimis	?õppimis =õppimis  (SgN  >õppimis !11_S	et	f	\N
130142	mui	?mui =mui  (SgN  >mui !26_S	et	f	\N
130143	mui	?mui =mui  (SgG  >mui !26_S	et	f	\N
130164	õppitada	?õppitada =õppita  (Inf  >õppitama !27_V	et	f	\N
130175	oleb	### oleb	et	f	\N
129825	uskulikud	?uskulikud =uskuliku  (PlN  >uskulik !25_A	et	f	\N
129826	uskulikud	?uskulikud =uskuliku  (IndPrSg2  >uskulikuma !27_V	et	f	\N
129829	idapooles	idapooles =poole  (SgIn  >ida+pool !13_NS	et	f	\N
129830	idapooles	idapooles =poole  (PlIn  >ida+pool !22_S	et	f	\N
129836	automaatselt	automaatselt =automaatse  (SgAbl  >automaatne !02_A	et	f	\N
129837	automaatselt	automaatselt =automaatselt  (ID  >automaatselt !41_D	et	f	\N
129838	automaatselt	"automaatselt %automaatse  )LT_mD  <automaatne ;02_A	et	f	\N
129865	õppimisel	õppimisel =õppimise  (SgAd  >õppimine !12_S	et	f	\N
129866	õppimisel	"õppimine %õppi  )MINE_vS  <õppima ;28_V	et	f	\N
129867	vallata	vallata =valla  (SgAb  >vald !22_S	et	f	\N
129868	vallata	vallata =valla  (Inf  >valdama !29_V	et	f	\N
129869	vallata	vallata =valla  (IndPrIps_  >valdama !29_V	et	f	\N
129870	vallata	vallata =vallata  (IndPrPs_  >vallatama !27_V	et	f	\N
129871	vallata	vallata =vallata  (ImpPrSg2  >vallatama !27_V	et	f	\N
129889	otan	?otan =ota  (IndPrSg1  >otama !27_V	et	f	\N
129890	otan	?otan =otan  (SgN  >otan !02_S	et	f	\N
129917	rääkivad	rääkivad =rääkiva  (PlN  >rääkiv !02_A	et	f	\N
129918	rääkivad	"rääkiv %rääki  )V_vA  <rääkima ;28_V	et	f	\N
129919	õpisid	?õpisid =õpi  (PlP  >õpi !16_S	et	f	\N
129920	õpisid	?õpisid =õpi  (IndIpfSg2  >õpima !27_V	et	f	\N
129921	õpisid	?õpisid =õpi  (IndIpfPl3  >õpima !27_V	et	f	\N
129934	juutustas	?juutustas =juutusta  (SgIn  >juutusta !01_S	et	f	\N
129935	juutustas	?juutustas =juutusta  (IndIpfSg3  >juutustama !27_V	et	f	\N
129940	karjeeri	?karjeeri =karjeeri  (SgN  >karjeeri !16_S	et	f	\N
129941	karjeeri	?karjeeri =karjeeri  (SgG  >karjeeri !16_S	et	f	\N
129942	karjeeri	?karjeeri =karjeeri  (SgG  >karjeer !22_S	et	f	\N
129943	karjeeri	?karjeeri =karjeeri  (SgP  >karjeer !22_S	et	f	\N
129944	karjeeri	?karjeeri =karjeeri  (SgAdt  >karjeer !22_S	et	f	\N
129945	karjeeri	?karjeeri =karjeeri  (IndPrPs_  >karjeerima !28_V	et	f	\N
129946	karjeeri	?karjeeri =karjeeri  (ImpPrSg2  >karjeerima !28_V	et	f	\N
129961	kohtumiseid	?kohtumiseid =kohtumisei  (PlN  >kohtumisei !26_S	et	f	\N
129962	kohtumiseid	?kohtumiseid =kohtumisei  (SgP  >kohtumisei !26_S	et	f	\N
129963	kohtumiseid	?kohtumiseid =eid  (SgN  >kohtu+mis+eid !22_S	et	f	\N
129964	kohtumiseid	?kohtumiseid =umise  (PlP  >koht+umine !10_A	et	f	\N
129965	kohtumiseid	?kohtumiseid =umisei  (PlN  >koht+umisei !26_S	et	f	\N
129966	kohtumiseid	?kohtumiseid =umisei  (SgP  >koht+umisei !26_S	et	f	\N
129972	töötaga	?töötaga =tööta  (SgKom  >tööta !16_S	et	f	\N
129973	tulevases	tulevases =tulevase  (SgIn  >tulevane !12_AS	et	f	\N
129974	tulevases	tulevases =vase  (SgIn  >tule+vask !22_S	et	f	\N
129979	kursusid	?kursusid =kursu  (PlP  >kursu !16_S	et	f	\N
129980	kursusid	?kursusid =kursu  (IndIpfSg2  >kursuma !27_V	et	f	\N
129981	kursusid	?kursusid =kursu  (IndIpfPl3  >kursuma !27_V	et	f	\N
129986	teadmist	teadmist =teadmis  (SgP  >teadmine !12?10_S	et	f	\N
129987	teadmist	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
130044	tasuliselt	tasuliselt =tasulise  (SgAbl  >tasuline !12_A	et	f	\N
130045	tasuliselt	"tasuline %tasu  )LINE_aA  <tasu ;17_S	et	f	\N
130046	tasuliselt	tasuliselt =tasuliselt  (ID  >tasuliselt !41_D	et	f	\N
130047	tasuliselt	"tasuliselt %tasu  )LISELT_mD  <tasu ;17_S	et	f	\N
130048	tasuliselt	"tasuliselt %tasulise  )LT_mD  <tasuline ;12_A	et	f	\N
130052	päevõppe	päevõppe =õppe  (SgG  >päev+õpe !06_S	et	f	\N
130053	päevõppe	päevõppe =õppe  (PlP  >päev+õpp !22_S	et	f	\N
130080	filoloogilist	filoloogilist =filoloogilis  (SgP  >filoloogiline !12_A	et	f	\N
130081	filoloogilist	"filoloogiline %filoloogi  )LINE_aA  <filoloog ;22_S	et	f	\N
130082	ööldas	?ööldas =öölda  (SgIn  >öölda !01_S	et	f	\N
130083	ööldas	?ööldas =öölda  (IndIpfSg3  >ööldama !27_V	et	f	\N
130084	ööldas	?ööldas =ööldas  (SgN  >ööldas !07_S	et	f	\N
130112	õpejõudu	?õpejõudu =õpejõudu  (IndPrPs_  >õpejõuduma !27_V	et	f	\N
130113	õpejõudu	?õpejõudu =õpejõudu  (ImpPrSg2  >õpejõuduma !27_V	et	f	\N
130120	ilmuvad	ilmuvad =ilmu  (IndPrPl3  >ilmuma !27_V	et	f	\N
130121	ilmuvad	ilmuvad =ilmuva  (PlN  >ilmuv !02_A	et	f	\N
130122	ilmuvad	"ilmuv %ilmu  )V_vA  <ilmuma ;27_V	et	f	\N
130123	puhkamiseks	puhkamiseks =puhkamise  (SgTr  >puhkamine !12_S	et	f	\N
130124	puhkamiseks	"puhkamine %puhka  )MINE_vS  <puhkama ;29_V	et	f	\N
130136	kooliaega	kooliaega =aega  (SgP  >kooli+aeg !22_S	et	f	\N
130137	kooliaega	kooliaega =aega  (SgAdt  >kooli+aeg !22_S	et	f	\N
130161	rikkendada	?rikkendada =rikkenda  (Inf  >rikkendama !27_V	et	f	\N
130168	õpita	õpita =õpi  (SgAb  >õpp !22_S	et	f	\N
130169	õpita	õpita =õpi  (IndPrIps_  >õppima !28_V	et	f	\N
130170	õppid	### õppid	et	f	\N
130180	õpitajatega	?õpitajatega =õpitaja  (PlKom  >õpitaja !01_S	et	f	\N
130181	õpitajatega	?õpitajatega =õpitaja  (PlKom  >õpitajas !02_A	et	f	\N
130182	sooritamiseks	sooritamiseks =sooritamise  (SgTr  >sooritamine !12_S	et	f	\N
130183	sooritamiseks	"sooritamine %soorita  )MINE_vS  <sooritama ;27_V	et	f	\N
130194	arva	arva =arva  (IndPrPs_  >arvama !29_V	et	f	\N
130195	arva	arva =arva  (ImpPrSg2  >arvama !29_V	et	f	\N
130198	paku	paku =paku  (SgG  >pakk !22_S	et	f	\N
129842	nõrgaid	?nõrgaid =nõrgai  (PlN  >nõrgai !26_S	et	f	\N
129843	nõrgaid	?nõrgaid =nõrgai  (SgP  >nõrgai !26_S	et	f	\N
129844	nõrgaid	?nõrgaid =nõrgaid  (SgN  >nõrgaid !22_S	et	f	\N
129855	veade	?veade =vea  (PlG  >vea !26_S	et	f	\N
129856	veade	?veade =veade  (SgN  >veade !06_S	et	f	\N
129857	veade	?veade =veade  (PlP  >vead !22_S	et	f	\N
129858	veade	?veade =veade  (IndPrPs_  >veadema !27_V	et	f	\N
129859	veade	?veade =veade  (ImpPrSg2  >veadema !27_V	et	f	\N
129875	eraldamatud	eraldamatud =eraldamatu  (PlN  >eraldamatu !01_A	et	f	\N
129876	eraldamatud	"eraldamatu %eralda  )MATU_vA  <eraldama ;27_V	et	f	\N
129887	suheldavad	suheldavad =suheldava  (PlN  >suheldav !02_A	et	f	\N
129888	suheldavad	"suheldav %suhel  )TAV_vAS  <suhtlema ;30_V	et	f	\N
129915	anan	?anan =ana  (IndPrSg1  >anama !27_V	et	f	\N
129916	anan	?anan =anan  (SgN  >anan !02_S	et	f	\N
129929	õppeda	?õppeda =õppe  (Inf  >õppema !27_V	et	f	\N
129936	suhtelda	?suhtelda =suhtelda  (IndPrPs_  >suhteldama !27_V	et	f	\N
129937	suhtelda	?suhtelda =suhtelda  (ImpPrSg2  >suhteldama !27_V	et	f	\N
129938	suhtelda	?suhtelda =elda  (SgN  >suht+elda !16_S	et	f	\N
129939	suhtelda	?suhtelda =elda  (SgG  >suht+elda !16_S	et	f	\N
129956	midugi	?midugi =midu  (SgN^  >midu !17_S	et	f	\N
129957	midugi	?midugi =midu  (SgG^  >midu !17_S	et	f	\N
129958	midugi	?midugi =midu  (SgP^  >midu !17_S	et	f	\N
129959	midugi	?midugi =midu  (IndPrPs_^  >miduma !27_V	et	f	\N
129960	midugi	?midugi =midu  (ImpPrSg2^  >miduma !27_V	et	f	\N
129985	huvitam	?huvitam =huvitam  (SgN  >huvitam !02_A	et	f	\N
130003	tulevikul	tulevikul =tuleviku  (SgAd  >tulevik !25_S	et	f	\N
130004	tulevikul	tulevikul =viku  (SgAd  >tule+vikk !22_S	et	f	\N
130017	õppetasin	?õppetasin =õppeta  (IndIpfSg1  >õppetama !27_V	et	f	\N
130018	õppetasin	?õppetasin =õppetasin  (SgN  >õppetasin !19_S	et	f	\N
130019	õppetasin	?õppetasin =tasin  (SgN  >õppe+tasin !02_S	et	f	\N
130027	vanemates	vanemates =vanema  (PlIn  >vanem !02_AS	et	f	\N
130028	vanemates	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
130029	vanemates	vanemates =ate  (PlIn  >vanem+att !22_S	et	f	\N
130030	õppetajatest	?õppetajatest =õppetaja  (PlEl  >õppetaja !01_S	et	f	\N
130031	õppetajatest	?õppetajatest =õppetaja  (PlEl  >õppetajas !02_A	et	f	\N
130032	õppetajatest	?õppetajatest =õppetajate  (PlEl  >õppetajatt !22_S	et	f	\N
130035	õppetajatest	?õppetajatest =õppetajates  (SgP  >õppetajatene !12_A	et	f	\N
130036	õppetajatest	?õppetajatest =tajate  (PlEl  >õppe+tajatt !22_S	et	f	\N
130037	õppetajatest	?õppetajatest =tajates  (SgP  >õppe+tajatene !12_A	et	f	\N
130065	rumalusi	rumalusi =rumalusi  (PlP  >rumalus !11_S	et	f	\N
130066	rumalusi	"rumalus %rumala  )US_aS  <rumal ;02_A	et	f	\N
130069	hoolikalt	hoolikalt =hoolika  (SgAbl  >hoolikas !02_A	et	f	\N
130070	hoolikalt	hoolikalt =hoolikalt  (ID  >hoolikalt !41_D	et	f	\N
130071	hoolikalt	"hoolikalt %hoolika  )LT_mD  <hoolikas ;02_A	et	f	\N
130075	sessi	sessi =sessi  (SgG  >sess !22_S	et	f	\N
130076	sessi	sessi =sessi  (SgP  >sess !22_S	et	f	\N
130077	sessi	sessi =sessi  (SgAdt  >sess !22_S	et	f	\N
130098	mõttest	mõttest =mõtte  (SgEl  >mõte !06_S	et	f	\N
130099	mõttest	mõttest =mõttes  (SgP  >mõttene !12~10_A	et	f	\N
130100	mõttest	"mõttene %mõtte  )NE_aA  <mõte ;06_S	et	f	\N
130125	saavutused	saavutused =saavutuse  (PlN  >saavutus !11_S	et	f	\N
130126	saavutused	"saavutus %saavuta  )US_vS  <saavutama ;27_V	et	f	\N
130130	võimalike	võimalike =võimalike  (PlG  >võimalik !25_A	et	f	\N
130131	võimalike	võimalike =malike  (SgN  >või+malike !12_S	et	f	\N
130132	võimalike	"või+malike %mali  )KE_dS  <või+mali ;17_S	et	f	\N
130149	haridussüsteemist	haridussüsteemist =süsteemi  (SgEl  >haridus+süsteem !22_S	et	f	\N
130150	haridussüsteemist	haridussüsteemist =süsteemis  (SgP  >haridus+süsteemine !10_A	et	f	\N
130151	haridussüsteemist	"haridus+süsteemine %süsteemi  )NE_aA  <haridus+süsteem ;22_S	et	f	\N
130165	koolitusi	koolitusi =koolitusi  (PlP  >koolitus !11_S	et	f	\N
130166	koolitusi	"koolitus %koolita  )US_vS  <koolitama ;27_V	et	f	\N
130167	koolitusi	"koolitus %kooli  )TUS2_aS  <kool ;22_S	et	f	\N
130176	arusaamine	arusaamine =saamine  (SgN  >aru+saamine !12?10_S	et	f	\N
130177	arusaamine	"aru+saamine %saami  )NE_aA  <aru+saam ;22_S	et	f	\N
130208	suurepärast	suurepärast =pära  (SgEl  >suure+pära !17_S	et	f	\N
130209	suurepärast	suurepärast =päras  (SgP  >suure+pärane !10_A	et	f	\N
130210	suurepärast	"suure+pärane %pära  )NE_aA  <suure+pära ;17_S	et	f	\N
130220	vaatada	### vaatada	et	f	\N
130271	rahuldatud	rahuldatud =rahulda  (PtsPtIps  >rahuldama !27_V	et	f	\N
130272	rahuldatud	rahuldatud =rahuldatu  (PlN  >rahuldatu !01_S	et	f	\N
130273	rahuldatud	"rahuldatu %rahulda  )TU1_vS  <rahuldama ;27_V	et	f	\N
130274	rahuldatud	rahuldatud =rahuldatud  (ID  >rahuldatud !41_A	et	f	\N
130275	rahuldatud	"rahuldatud %rahulda  )TUD_vA  <rahuldama ;27_V	et	f	\N
129993	kehti	kehti =kehti  (ImpPrSg2  >kehtima !27_V	et	f	\N
129995	stipeendijat	?stipeendijat =stipeendija  (SgP  >stipeendija !01_S	et	f	\N
129996	stipeendijat	?stipeendijat =stipeendija  (SgP  >stipeendijas !02_A	et	f	\N
130005	täieslikult	?täieslikult =täiesliku  (SgAbl  >täieslik !25_A	et	f	\N
130006	täieslikult	?täieslikult =täieslikult  (ID  >täieslikult !41_D	et	f	\N
130007	täieslikult	?täieslikult =sliku  (SgAbl  >täie+sliku !16_S	et	f	\N
130008	täieslikult	?täieslikult =sliku  (SgAbl  >täie+slikk !22_S	et	f	\N
130009	täieslikult	?täieslikult =esliku  (SgAbl  >täi+eslik !25_A	et	f	\N
130010	täieslikult	?täieslikult =esliku  (SgAbl  >täi+esliku !01_S	et	f	\N
130011	võõrkeel	võõrkeel =kee  (SgAd  >võõr+kesi !15_S	et	f	\N
130012	võõrkeel	võõrkeel =kee  (SgAd  >võõr+kee !26_S	et	f	\N
130013	võõrkeel	võõrkeel =keel  (SgN  >võõr+keel !13_S	et	f	\N
130014	pakkub	### pakkub	et	f	\N
130024	tlus	### tlus	et	f	\N
130038	magistriõppe	magistriõppe =õppe  (SgG  >magistri+õpe !06_S	et	f	\N
130039	magistriõppe	magistriõppe =õppe  (PlP  >magistri+õpp !22_S	et	f	\N
130043	päevõppet	?päevõppet =õppe  (SgP  >päev+õppe !06_S	et	f	\N
130049	tsükkelõppet	### tsükkelõppet	et	f	\N
130059	südamesse	südamesse =südame  (SgIll  >süda !04_S	et	f	\N
130060	südamesse	südamesse =messe  (PlP  >süda+mess !22_S	et	f	\N
130063	kodutööd	kodutööd =töö  (PlN  >kodu+töö !26_S	et	f	\N
130064	kodutööd	kodutööd =töö  (SgP  >kodu+töö !26_S	et	f	\N
130067	tõsise	tõsise =tõsise  (SgG  >tõsine !10_A	et	f	\N
130068	tõsise	"tõsine %tõsi  )NE_aA  <tõsi ;15_S	et	f	\N
130078	kõigipealt	?kõigipealt =kõigipea  (SgAbl  >kõigipea !26_S	et	f	\N
130079	kõigipealt	?kõigipealt =kõigipealt  (ID  >kõigipealt !41_D	et	f	\N
130088	seltsiv	seltsiv =seltsi  (PtsPrPs  >seltsima !28_V	et	f	\N
130089	seltsiv	seltsiv =seltsiv  (SgN  >seltsiv !02_A	et	f	\N
130090	seltsiv	"seltsiv %seltsi  )V_vA  <seltsima ;28_V	et	f	\N
130097	plaanerida	### plaanerida	et	f	\N
130103	erialat	?erialat =eriala  (SgP  >eriala !01_S	et	f	\N
130104	erialat	?erialat =alat  (SgN  >eri+alat !02_S	et	f	\N
130106	lugemisest	lugemisest =lugemise  (SgEl  >lugemine !12_S	et	f	\N
130107	lugemisest	"lugemine %luge  )MINE_vS  <lugema ;28_V	et	f	\N
130108	lugemisest	"lugemine %lugemi  )NE_aA  <lugem ;02_S	et	f	\N
130144	eraala	eraala =ala  (SgN  >era+ala !17_S	et	f	\N
130145	eraala	eraala =ala  (SgG  >era+ala !17_S	et	f	\N
130146	eraala	eraala =ala  (SgP  >era+ala !17_S	et	f	\N
130152	tulevatest	tulevatest =tuleva  (PlEl  >tulev !02_A	et	f	\N
130153	tulevatest	"tulev %tule  )V_vA  <tulema ;36_V	et	f	\N
130154	tulevatest	tulevatest =ate  (PlEl  >tulev+att !22_S	et	f	\N
130155	tulevatest	tulevatest =vate  (PlEl  >tule+vatt !22_S	et	f	\N
130162	valikusse	valikusse =valiku  (SgIll  >valik !02_S	et	f	\N
130163	valikusse	valikusse =usse  (PlP  >valik+uss !22_S	et	f	\N
130171	kohtud	kohtud =kohtu  (PlN  >kohus !05_S	et	f	\N
130172	kohtud	kohtud =kohtu  (IndPrSg2  >kohtuma !27_V	et	f	\N
130178	üliõpilastega	üliõpilastega =las  (PlKom  >üli+õpi+laps !14_S	et	f	\N
130179	üliõpilastega	üliõpilastega =õpilas  (PlKom  >üli+õpilane !12_S	et	f	\N
130189	hoides	hoides =hoid  (Ger  >hoidma !34_V	et	f	\N
130190	hoides	hoides =hoide  (SgIn  >hoie !06_S	et	f	\N
130201	kraadi	kraadi =kraadi  (SgG  >kraad !22_S	et	f	\N
130202	kraadi	kraadi =kraadi  (SgP  >kraad !22_S	et	f	\N
130203	kraadi	kraadi =kraadi  (SgAdt  >kraad !22_S	et	f	\N
130204	kraadi	kraadi =kraadi  (IndPrPs_  >kraadima !28_V	et	f	\N
130205	kraadi	kraadi =kraadi  (ImpPrSg2  >kraadima !28_V	et	f	\N
130225	aidama	?aidama =aida  (Sup  >aidama !29_V	et	f	\N
130226	aidama	?aidama =aidama  (SgG  >aidam !02_S	et	f	\N
130235	rahvusvaheline	rahvusvaheline =vaheline  (SgN  >rahvus+vaheline !12_A	et	f	\N
130236	rahvusvaheline	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
130240	tulemusest	tulemusest =tulemuse  (SgEl  >tulemus !11_S	et	f	\N
130241	tulemusest	tulemusest =tulemuses  (SgP  >tulemusene !12_A	et	f	\N
130242	tulemusest	"tulemusene %tulemuse  )NE_aA  <tulemus ;11_S	et	f	\N
130248	rakendus	rakendus =rakendu  (IndIpfSg3  >rakenduma !27_V	et	f	\N
130249	rakendus	rakendus =rakendus  (SgN  >rakendus !11_S	et	f	\N
130250	rakendus	"rakendus %rakenda  )US_vS  <rakendama ;27_V	et	f	\N
130254	moodsaim	moodsaim =moodsaim  (SgN  >moodsaim !02_A	et	f	\N
130255	moodsaim	"moodsaim %moodsa  )IM_sA  <moodne ;02_A	et	f	\N
130276	televisioonis	televisioonis =televisiooni  (SgIn  >televisioon !22_S	et	f	\N
130277	televisioonis	televisioonis =visiooni  (SgIn  >tele+visioon !22_S	et	f	\N
130296	sõtsin	?sõtsin =sõtsi  (IndPrSg1  >sõtsima !28_V	et	f	\N
130297	sõtsin	?sõtsin =sõtsin  (SgN  >sõtsin !02_S	et	f	\N
130318	töökohad	töökohad =koha  (PlN  >töö+koha !17_S	et	f	\N
130319	töökohad	töökohad =koha  (PlN  >töö+koht !22_S	et	f	\N
130335	infotehnoolog	?infotehnoolog =olog  (SgN  >info+tehno+olog !02_S	et	f	\N
130339	soovitused	soovitused =soovituse  (PlN  >soovitus !11_S	et	f	\N
130340	soovitused	"soovitus %soovita  )US_vS  <soovitama ;27_V	et	f	\N
130341	soovitused	"soovitus %soovi  )TUS1_aS  <soovima ;28_V	et	f	\N
130054	julgenud	julgenud =julge  (PtsPtPs  >julgema !27_V	et	f	\N
130055	julgenud	julgenud =julgenu  (PlN  >julgenu !01_S	et	f	\N
130056	julgenud	"julgenu %julge  )NU_vS  <julgema ;27_V	et	f	\N
130057	julgenud	julgenud =julgenud  (ID  >julgenud !41_A	et	f	\N
130058	julgenud	"julgenud %julge  )NUD_vA  <julgema ;27_V	et	f	\N
130061	lendasid	lendasid =lenda  (IndIpfSg2  >lendama !29_V	et	f	\N
130062	lendasid	lendasid =lenda  (IndIpfPl3  >lendama !29_V	et	f	\N
130093	keeliteadmiseid	?keeliteadmiseid =keeliteadmisei  (PlN  >keeliteadmisei !26_S	et	f	\N
130094	keeliteadmiseid	?keeliteadmiseid =keeliteadmisei  (SgP  >keeliteadmisei !26_S	et	f	\N
130095	keeliteadmiseid	?keeliteadmiseid =iteadmisei  (PlN  >keel+iteadmisei !26_S	et	f	\N
130096	keeliteadmiseid	?keeliteadmiseid =iteadmisei  (SgP  >keel+iteadmisei !26_S	et	f	\N
130105	füloolog	### füloolog	et	f	\N
130114	võõr-	?võõr- =võõr  (SgN  >võõr !22_S	et	f	\N
130115	planeeritud	planeeritud =planeeri  (PtsPtIps  >planeerima !28_V	et	f	\N
130116	planeeritud	planeeritud =planeeritu  (PlN  >planeeritu !01_S	et	f	\N
130117	planeeritud	"planeeritu %planeeri  )TU1_vS  <planeerima ;28_V	et	f	\N
130118	planeeritud	planeeritud =planeeritud  (ID  >planeeritud !41_A	et	f	\N
130119	planeeritud	"planeeritud %planeeri  )TUD_vA  <planeerima ;28_V	et	f	\N
130127	vaatenurgast	vaatenurgast =nurga  (SgEl  >vaate+nurk !22_S	et	f	\N
130128	vaatenurgast	vaatenurgast =nurgas  (SgP  >vaate+nurgane !10_A	et	f	\N
130129	vaatenurgast	"vaate+nurgane %nurga  )NE_aA  <vaate+nurk ;22_S	et	f	\N
130133	targemaks	targemaks =targe  (SupTr  >targema !27_V	et	f	\N
130134	targemaks	targemaks =targema  (SgTr  >targem !02_A	et	f	\N
130135	targemaks	"targem %targe  )M_cA  <tark ;22_AS	et	f	\N
130138	omandamist	omandamist =omandamis  (SgP  >omandamine !12_S	et	f	\N
130139	omandamist	"omandamine %omanda  )MINE_vS  <omandama ;27_V	et	f	\N
130140	tead	tead =tea  (IndPrSg2  >teadma !34_V	et	f	\N
130141	tead	tead =tead  (SgN  >tead !22_S	et	f	\N
130147	mingis	mingis =mingi  (SgIn  >mingi !01_P	et	f	\N
130148	mingis	mingis =mingi  (SgIn  >mink !22_S	et	f	\N
130173	targat	?targat =targa  (SgP  >targa !16_S	et	f	\N
130174	targat	?targat =targat  (SgN  >targat !02_S	et	f	\N
130206	võõrkeeles	võõrkeeles =keele  (SgIn  >võõr+keel !13_S	et	f	\N
130207	võõrkeeles	võõrkeeles =keele  (PlIn  >võõr+keeld !22_S	et	f	\N
130230	tõlkijaks	tõlkijaks =tõlkija  (SgTr  >tõlkija !01_S	et	f	\N
130231	tõlkijaks	"tõlkija %tõlki  )JA_vS  <tõlkima ;28_V	et	f	\N
130234	millesed	?millesed =millese  (PlN  >millene !10_A	et	f	\N
130243	akrediteeritud	?akrediteeritud =akrediteeri  (PtsPtIps  >akrediteerima !28_V	et	f	\N
130244	akrediteeritud	?akrediteeritud =akrediteeritu  (PlN  >akrediteeritu !01_S	et	f	\N
130245	akrediteeritud	?akrediteeritud =akrediteeritu  (IndPrSg2  >akrediteerituma !27_V	et	f	\N
130246	akrediteeritud	?akrediteeritud =akrediteeritud  (ID  >akrediteeritud !41_A	et	f	\N
130247	juutustused	?juutustused =juutustuse  (PlN  >juutustus !11_S	et	f	\N
130253	sõprad	?sõprad =sõpra  (IndPrSg2  >sõprama !29_V	et	f	\N
130256	nissugune	?nissugune =nissugune  (SgN  >nissugune !12_A	et	f	\N
130257	nissugune	?nissugune =nissugune  (PlP  >nissugun !19_S	et	f	\N
130264	internetist	?internetist =internetis  (SgP  >internetis !09_S	et	f	\N
130265	internetist	?internetist =internetist  (SgN  >internetist !22_S	et	f	\N
130266	internetist	?internetist =neti  (SgEl  >inter+neti !16_S	et	f	\N
130267	internetist	?internetist =neti  (SgEl  >inter+nett !22_AS	et	f	\N
130268	internetist	?internetist =netis  (SgP  >inter+netis !09_S	et	f	\N
130269	internetist	?internetist =netist  (SgN  >inter+netist !22_S	et	f	\N
130290	vajandusel	?vajandusel =vajanduse  (SgAd  >vajandus !11_S	et	f	\N
130317	kujumise	?kujumise =kujumise  (SgG  >kujumine !12_S	et	f	\N
130322	sõbradest	?sõbradest =sõbra  (PlEl  >sõbra !16_S	et	f	\N
130323	sõbradest	?sõbradest =sõbrades  (SgP  >sõbradene !12_A	et	f	\N
130333	ärijuhataja	ärijuhataja =juhataja  (SgN  >äri+juhataja !01_S	et	f	\N
130334	ärijuhataja	ärijuhataja =juhataja  (SgG  >äri+juhataja !01_S	et	f	\N
130353	palli	palli =palli  (SgG  >pall !22_S	et	f	\N
130354	palli	palli =palli  (SgP  >pall !22_S	et	f	\N
130355	palli	palli =palli  (SgAdt  >pall !22_S	et	f	\N
130356	palli	palli =palli  (IndPrPs_  >pallima !28_V	et	f	\N
130357	palli	palli =palli  (ImpPrSg2  >pallima !28_V	et	f	\N
130358	fakulteetis	?fakulteetis =fakulteeti  (SgIn  >fakulteeti !16_S	et	f	\N
130359	fakulteetis	?fakulteetis =fakulteeti  (IndIpfSg3  >fakulteetima !28_V	et	f	\N
130360	fakulteetis	?fakulteetis =fakulteetis  (SgN  >fakulteetis !09_S	et	f	\N
130362	soovitus	soovitus =soovitu  (SgIn  >soovitu !01_AS	et	f	\N
130363	soovitus	"soovitu %soovi  )TU1_vS  <soovima ;28_V	et	f	\N
130364	soovitus	"soovitu %soovi  )TU2_kA  <soov ;22_S	et	f	\N
130365	soovitus	soovitus =soovitus  (SgN  >soovitus !11_S	et	f	\N
130366	soovitus	"soovitus %soovita  )US_vS  <soovitama ;27_V	et	f	\N
130367	soovitus	"soovitus %soovi  )TUS1_aS  <soovima ;28_V	et	f	\N
130368	soovitus	"soovitus %soovi  )TUS2_aS  <soov ;22_S	et	f	\N
130377	sõbraannast	sõbraannast =anna  (SgEl  >sõbra+anna !16_S	et	f	\N
130378	sõbraannast	sõbraannast =annas  (SgP  >sõbra+annane !10_A	et	f	\N
130379	sõbraannast	"sõbra+annane %anna  )NE_aA  <sõbra+anna ;16_S	et	f	\N
130184	kõigesse	kõigesse =kõige  (SgIll  >kõik !00_P	et	f	\N
130185	kõigesse	kõigesse =kõige  (PlIll  >kõik !22_S	et	f	\N
130186	ahmatova	?ahmatova =ahmatova  (SgN  >ahmatova !16_S	et	f	\N
130187	ahmatova	?ahmatova =ahmatova  (SgG  >ahmatov !02_A	et	f	\N
130188	ahmatova	?ahmatova =ahmatova  (SgG  >ahmatova !16_S	et	f	\N
130191	pingi	pingi =pingi  (SgG  >pink !22_S	et	f	\N
130192	pingi	pingi =pingi  (SgP  >ping !22_S	et	f	\N
130193	pingi	pingi =pingi  (SgAdt  >ping !22_S	et	f	\N
130196	raiskamine	raiskamine =raiskamine  (SgN  >raiskamine !12_S	et	f	\N
130197	raiskamine	"raiskamine %raiska  )MINE_vS  <raiskama ;29_V	et	f	\N
130211	andes	andes =and  (Ger  >andma !34_V	et	f	\N
130212	andes	andes =ande  (SgIn  >anne !06_S	et	f	\N
130214	tasutud	tasutud =tasu  (PtsPtIps  >tasuma !27_V	et	f	\N
130215	tasutud	tasutud =tasutu  (PlN  >tasutu !01_AS	et	f	\N
130216	tasutud	"tasutu %tasu  )TU1_vS  <tasuma ;27_V	et	f	\N
130217	tasutud	"tasutu %tasu  )TU2_kA  <tasu ;17_S	et	f	\N
130218	tasutud	tasutud =tasutud  (ID  >tasutud !41_A	et	f	\N
130219	tasutud	"tasutud %tasu  )TUD_vA  <tasuma ;27_V	et	f	\N
130221	üttelda	?üttelda =üttelda  (IndPrPs_  >ütteldama !27_V	et	f	\N
130224	üttelda	?üttelda =üttelda  (ImpPrSg2  >ütteldama !27_V	et	f	\N
130227	valdada	?valdada =ada  (SgN  >vald+ada !17_S	et	f	\N
130228	valdada	?valdada =ada  (SgG  >vald+ada !17_S	et	f	\N
130229	valdada	?valdada =ada  (SgP  >vald+ada !17_S	et	f	\N
130232	millelegi	millelegi =mille  (SgAll  >miski !00_P	et	f	\N
130233	millelegi	millelegi =mille  (SgAll^  >mis !00_P	et	f	\N
130237	marketing	?marketing =marketing  (SgN  >marketing !02_S	et	f	\N
130238	planeerimine	planeerimine =planeerimine  (SgN  >planeerimine !12_S	et	f	\N
130239	planeerimine	"planeerimine %planeeri  )MINE_vS  <planeerima ;28_V	et	f	\N
130251	andmine	andmine =andmine  (SgN  >andmine !12?10_S	et	f	\N
130252	andmine	"andmine %and  )MINE_vS  <andma ;34_V	et	f	\N
130263	paljem	?paljem =paljem  (SgN  >paljem !02_A	et	f	\N
130288	tellis	tellis =telli  (IndIpfSg3  >tellima !28_V	et	f	\N
130289	tellis	tellis =tellis  (SgN  >tellis !09_S	et	f	\N
130306	interneetis	?interneetis =interneeti  (SgIn  >interneeti !16_S	et	f	\N
130309	interneetis	?interneetis =interneeti  (IndIpfSg3  >interneetima !28_V	et	f	\N
130311	interneetis	?interneetis =interneetis  (SgN  >interneetis !09_S	et	f	\N
130312	interneetis	?interneetis =neetis  (SgN  >inter+neetis !11~09_S	et	f	\N
130313	silme	silme =silme  (PlG  >silm !22_S	et	f	\N
130314	silme	silme =silme  (PlP  >silm !22_S	et	f	\N
130336	psühholog	### psühholog	et	f	\N
130337	rahvusvaheliste	rahvusvaheliste =vahelis  (PlG  >rahvus+vaheline !12_A	et	f	\N
130338	rahvusvaheliste	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
130369	kavatsus	kavatsus =kavatsus  (SgN  >kavatsus !11_S	et	f	\N
130370	kavatsus	"kavatsus %kavatse  )US_vS  <kavatsema ;27_V	et	f	\N
130371	erinevastega	?erinevastega =erinevas  (PlKom  >erinevane !12_A	et	f	\N
130372	erinevastega	?erinevastega =nevas  (PlKom  >eri+nevas !09_S	et	f	\N
130373	erinevastega	?erinevastega =nevas  (PlKom  >eri+nevane !10_A	et	f	\N
130404	taekwondo	?taekwondo =taekwondo  (SgN  >taekwondo !16_S	et	f	\N
130405	taekwondo	?taekwondo =taekwondo  (SgG  >taekwondo !16_S	et	f	\N
130410	stromkas	?stromkas =stromka  (SgIn  >stromka !16_S	et	f	\N
130411	stromkas	?stromkas =stromka  (IndIpfSg3  >stromkama !29_V	et	f	\N
130412	stromkas	?stromkas =stromkas  (SgN  >stromkas !07_S	et	f	\N
130436	kala	kala =kala  (SgN  >kala !17_S	et	f	\N
130437	kala	kala =kala  (SgG  >kala !17_S	et	f	\N
130438	kala	kala =kala  (SgP  >kala !17_S	et	f	\N
130457	ülemus	ülemus =ülemus  (SgN  >ülemus !11_S	et	f	\N
130458	ülemus	"ülemus %ülema  )US_aS  <ülem ;02_AS	et	f	\N
130496	räpinas	### räpinas	et	f	\N
130506	järves	järves =järve  (SgIn  >järv !22_S	et	f	\N
130507	järves	järves =järve  (PlIn  >järv !22_S	et	f	\N
130520	seganud	seganud =sega  (PtsPtPs  >segama !27_V	et	f	\N
130521	seganud	seganud =seganu  (PlN  >seganu !01_S	et	f	\N
130522	seganud	"seganu %sega  )NU_vS  <segama ;27_V	et	f	\N
130523	seganud	seganud =seganud  (ID  >seganud !41_A	et	f	\N
130524	seganud	"seganud %sega  )NUD_vA  <segama ;27_V	et	f	\N
130531	sääske	sääske =sääske  (SgP  >sääsk !22_S	et	f	\N
130532	sääske	sääske =sääske  (SgAdt  >sääsk !22_S	et	f	\N
130533	sääske	sääske =sääske  (PlP  >sääsk !22_S	et	f	\N
130550	kasvatajad	kasvatajad =kasvataja  (PlN  >kasvataja !01_S	et	f	\N
130551	kasvatajad	"kasvataja %kasvata  )JA_vS  <kasvatama ;27_V	et	f	\N
130560	personalist	personalist =personali  (SgEl  >personal !19_S	et	f	\N
130561	personalist	personalist =personalis  (SgP  >personaline !12_A	et	f	\N
130562	personalist	"personaline %personali  )NE_aA  <personal ;19_S	et	f	\N
130565	igapäevane	igapäevane =päevane  (SgN  >iga+päevane !10_A	et	f	\N
130566	igapäevane	"iga+päevane %päeva  )NE_aA  <iga+päev ;22_S	et	f	\N
130572	süütamine	süütamine =süütamine  (SgN  >süütamine !12_S	et	f	\N
130573	süütamine	"süütamine %süüta  )MINE_vS  <süütama ;29_V	et	f	\N
130574	ebaturvalisena	ebaturvalisena =turvalise  (SgEs  >eba+turvaline !12_A	et	f	\N
130199	paku	paku =paku  (IndPrPs_  >pakkuma !28_V	et	f	\N
130200	paku	paku =paku  (ImpPrSg2  >pakkuma !28_V	et	f	\N
130213	inimisele	?inimisele =inimise  (SgAll  >inimine !12_S	et	f	\N
130222	müüjale	müüjale =müüja  (SgAll  >müüja !01_S	et	f	\N
130223	müüjale	"müüja %müü  )JA_vS  <müüma ;38_V	et	f	\N
130258	kõrgemat	kõrgemat =kõrgema  (SgP  >kõrgem !02_A	et	f	\N
130259	kõrgemat	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
130260	kõrgus	kõrgus =kõrgu  (IndIpfSg3  >kõrguma !27_V	et	f	\N
130261	kõrgus	kõrgus =kõrgus  (SgN  >kõrgus !11~09_S	et	f	\N
130262	kõrgus	"kõrgus %kõrge  )US_aS  <kõrge ;01_A	et	f	\N
130270	saavustada	?saavustada =saavusta  (Inf  >saavustama !27_V	et	f	\N
130278	varianteid	?varianteid =variantei  (PlN  >variantei !26_S	et	f	\N
130279	varianteid	?varianteid =variantei  (SgP  >variantei !26_S	et	f	\N
130280	varianteid	?varianteid =ante  (PlP  >vari+ande !06_S	et	f	\N
130281	varianteid	?varianteid =antei  (PlN  >vari+antei !26_S	et	f	\N
130282	varianteid	?varianteid =antei  (SgP  >vari+antei !26_S	et	f	\N
130283	varianteid	?varianteid =anteid  (SgN  >vari+anteid !22_S	et	f	\N
130286	sõpadelt	?sõpadelt =sõpa  (PlAbl  >sõpa !16_S	et	f	\N
130287	sõpadelt	?sõpadelt =sõpadelt  (ID  >sõpadelt !41_D	et	f	\N
130298	sekretääriga	?sekretääriga =sekretääri  (SgKom  >sekretääri !16_S	et	f	\N
130299	sekretääriga	?sekretääriga =sekretääri  (SgKom  >sekretäär !22_S	et	f	\N
130315	lootan	?lootan =loota  (IndPrSg1  >lootama !27_V	et	f	\N
130316	lootan	?lootan =lootan  (SgN  >lootan !02_S	et	f	\N
130320	raadio-	raadio- =raadio  (SgN  >raadio !01_S	et	f	\N
130321	raadio-	raadio- =raadio  (SgG  >raadio !01_S	et	f	\N
130324	telesaadele	?telesaadele =telesaa  (PlAll  >telesaa !26_S	et	f	\N
130325	telesaadele	?telesaadele =telesaade  (SgAll  >telesaade !16_S	et	f	\N
130326	telesaadele	?telesaadele =telesaade  (PlAll  >telesaat !22_S	et	f	\N
130327	telesaadele	?telesaadele =saa  (PlAll  >tele+saa !26_S	et	f	\N
130328	vaheldusrikkas	?vaheldusrikkas =vaheldusrikka  (SgIn  >vaheldusrikka !16_S	et	f	\N
130329	vaheldusrikkas	?vaheldusrikkas =rikka  (SgIn  >vaheldus+rikas !07_A	et	f	\N
130330	vaheldusrikkas	?vaheldusrikkas =rikkas  (SgN  >vaheldus+rikkas !07_S	et	f	\N
130331	toimetajana	toimetajana =toimetaja  (SgEs  >toimetaja !01_S	et	f	\N
130332	toimetajana	"toimetaja %toimeta  )JA_vS  <toimetama ;27_V	et	f	\N
130374	ajalehedes	?ajalehedes =lehe  (PlIn  >aja+lehe !16_S	et	f	\N
130394	arvestused	arvestused =arvestuse  (PlN  >arvestus !11_S	et	f	\N
130395	arvestused	"arvestus %arvesta  )US_vS  <arvestama ;27_V	et	f	\N
130429	judoga	?judoga =judo  (SgKom  >judo !17~16_S	et	f	\N
130441	kinnos	?kinnos =kinno  (SgIn  >kinno !16_S	et	f	\N
130442	kinnos	?kinnos =kinnos  (SgN  >kinnos !11~09_S	et	f	\N
130449	rägi	?rägi =rägi  (SgN  >rägi !17_S	et	f	\N
130450	rägi	?rägi =rägi  (SgG  >rägi !17_S	et	f	\N
130451	rägi	?rägi =rägi  (SgP  >rägi !17_S	et	f	\N
130452	rägi	?rägi =rägi  (IndPrPs_  >rägima !27_V	et	f	\N
130453	rägi	?rägi =rägi  (ImpPrSg2  >rägima !27_V	et	f	\N
130456	kukkun	?kukkun =kukkun  (SgN  >kukkun !02_S	et	f	\N
130461	ülemusele	ülemusele =ülemuse  (SgAll  >ülemus !11_S	et	f	\N
130462	ülemusele	"ülemus %ülema  )US_aS  <ülem ;02_AS	et	f	\N
130463	ülemusele	ülemusele =use  (PlAll  >ülem+usk !22_S	et	f	\N
130470	arendaja	arendaja =arendaja  (SgN  >arendaja !01_S	et	f	\N
130471	arendaja	"arendaja %arenda  )JA_vS  <arendama ;27_V	et	f	\N
130472	arendaja	arendaja =arendaja  (SgG  >arendaja !01_S	et	f	\N
130473	arendustööd	arendustööd =töö  (PlN  >arendus+töö !26_S	et	f	\N
130474	arendustööd	arendustööd =töö  (SgP  >arendus+töö !26_S	et	f	\N
130475	suveperioodi	suveperioodi =perioodi  (SgG  >suve+periood !22_S	et	f	\N
130476	suveperioodi	suveperioodi =perioodi  (SgP  >suve+periood !22_S	et	f	\N
130477	suveperioodi	suveperioodi =perioodi  (SgAdt  >suve+periood !22_S	et	f	\N
130497	avastanud	avastanud =avasta  (PtsPtPs  >avastama !27_V	et	f	\N
130498	avastanud	avastanud =avastanu  (PlN  >avastanu !01_S	et	f	\N
130499	avastanud	"avastanu %avasta  )NU_vS  <avastama ;27_V	et	f	\N
130500	avastanud	avastanud =avastanud  (ID  >avastanud !41_A	et	f	\N
130501	avastanud	"avastanud %avasta  )NUD_vA  <avastama ;27_V	et	f	\N
130503	windsurfing	?windsurfing =windsurfing  (SgN  >windsurfing !02_S	et	f	\N
130556	suurimaks	"suurim %suuri  )IM_sA  <suur ;13_A	et	f	\N
130557	suurimaks	suurimaks =maks  (SgN  >suuri+maks !22_S	et	f	\N
130558	suurimaks	suurimaks =ima  (SgTr  >suur+ima !17_S	et	f	\N
130559	suurimaks	suurimaks =rima  (SgTr  >suu+rima !17_S	et	f	\N
130579	prügi	prügi =prügi  (SgN  >prügi !17_S	et	f	\N
130580	prügi	prügi =prügi  (SgG  >prügi !17_S	et	f	\N
130581	prügi	prügi =prügi  (SgP  >prügi !17_S	et	f	\N
130602	kinnised	kinnised =kinnise  (PlN  >kinnis !09_S	et	f	\N
130603	kinnised	kinnised =kinnise  (PlN  >kinnine !10~12_A	et	f	\N
130623	soje	?soje =soje  (SgN  >soje !16_S	et	f	\N
130624	soje	?soje =soje  (SgG  >soje !16_S	et	f	\N
130625	soje	?soje =soje  (IndPrPs_  >sojema !27_V	et	f	\N
130626	soje	?soje =soje  (ImpPrSg2  >sojema !27_V	et	f	\N
130638	jargmine	?jargmine =jargmine  (SgN  >jargmine !12?10_A	et	f	\N
130284	elukutselise	elukutselise =kutselise  (SgG  >elu+kutseline !12_A	et	f	\N
130285	elukutselise	"elu+kutseline %kutse  )LINE_aA  <elu+kutse ;06_S	et	f	\N
130291	seatatud	?seatatud =seata  (PtsPtIps  >seatama !27_V	et	f	\N
130292	seatatud	?seatatud =seatatu  (PlN  >seatatu !01_S	et	f	\N
130293	seatatud	?seatatud =seatatu  (IndPrSg2  >seatatuma !27_V	et	f	\N
130294	seatatud	?seatatud =seatatud  (ID  >seatatud !41_A	et	f	\N
130295	seatatud	?seatatud =tatu  (PlN  >sea+tatu !16_S	et	f	\N
130300	koduleheküljal	?koduleheküljal =kodulehekülja  (SgAd  >koduleheküljas !02_A	et	f	\N
130301	koduleheküljal	?koduleheküljal =kodulehekülja  (SgAd  >kodulehekülja !16_S	et	f	\N
130302	koduleheküljal	?koduleheküljal =koduleheküljal  (SgN  >koduleheküljal !02_S	et	f	\N
130303	koduleheküljal	?koduleheküljal =külja  (SgAd  >kodu+lehe+küljas !02_A	et	f	\N
130304	koduleheküljal	?koduleheküljal =külja  (SgAd  >kodu+lehe+külja !16_S	et	f	\N
130305	koduleheküljal	?koduleheküljal =küljal  (SgN  >kodu+lehe+küljal !02_S	et	f	\N
130307	koduleheküljal	?koduleheküljal =lehekülja  (SgAd  >kodu+leheküljas !02_A	et	f	\N
130308	koduleheküljal	?koduleheküljal =lehekülja  (SgAd  >kodu+lehekülja !16_S	et	f	\N
130310	koduleheküljal	?koduleheküljal =leheküljal  (SgN  >kodu+leheküljal !02_S	et	f	\N
130343	muutaksin	?muutaksin =muuta  (KndPrSg1  >muutama !27_V	et	f	\N
130344	muutaksin	?muutaksin =muutaksi  (IndPrSg1  >muutaksima !28_V	et	f	\N
130345	muutaksin	?muutaksin =muutaksin  (SgN  >muutaksin !19_S	et	f	\N
130346	muutaksin	?muutaksin =taksin  (SgN  >muu+taksin !02_S	et	f	\N
130347	õppetasid	?õppetasid =õppeta  (IndIpfSg2  >õppetama !27_V	et	f	\N
130348	õppetasid	?õppetasid =õppeta  (IndIpfPl3  >õppetama !27_V	et	f	\N
130349	õppetasid	?õppetasid =tasi  (PlN  >õppe+tasi !17_S	et	f	\N
130350	lõppukirjandit	### lõppukirjandit	et	f	\N
130375	tutvumisele	tutvumisele =tutvumise  (SgAll  >tutvumine !12_S	et	f	\N
130376	tutvumisele	"tutvumine %tutvu  )MINE_vS  <tutvuma ;27_V	et	f	\N
130385	reisivad	reisivad =reisi  (IndPrPl3  >reisima !28_V	et	f	\N
130386	reisivad	reisivad =reisiva  (PlN  >reisiv !02_A	et	f	\N
130387	reisivad	"reisiv %reisi  )V_vA  <reisima ;28_V	et	f	\N
130391	klassivennadega	?klassivennadega =klassivenna  (PlKom  >klassivenna !16_S	et	f	\N
130392	klassivennadega	?klassivennadega =venna  (PlKom  >klassi+venna !16_S	et	f	\N
130396	kurtnasse	?kurtnasse =kurtna  (SgIll  >kurtna !01_S	et	f	\N
130397	kurtnasse	?kurtnasse =kurtnas  (SgAdt  >kurtnane !12_A	et	f	\N
130398	kurtnasse	?kurtnasse =kurtnasse  (SgG  >kurtnasne !02_A	et	f	\N
130399	kurtnasse	?kurtnasse =kurtnasse  (PlP  >kurtnass !22_S	et	f	\N
130400	kurtnasse	?kurtnasse =nasse  (SgN  >kurt+nasse !06_S	et	f	\N
130401	kurtnasse	?kurtnasse =nasse  (SgG  >kurt+nasne !02_A	et	f	\N
130402	kurtnasse	?kurtnasse =nasse  (SgG  >kurt+nasse !06_S	et	f	\N
130403	kurtnasse	?kurtnasse =nasse  (PlP  >kurt+nass !22_S	et	f	\N
130422	tallinasse	?tallinasse =tallinas  (SgAdt  >tallinane !12_A	et	f	\N
130423	tallinasse	?tallinasse =tallinasse  (SgG  >tallinasne !02_A	et	f	\N
130424	tallinasse	?tallinasse =tallinasse  (PlP  >tallinass !22_S	et	f	\N
130425	tallinasse	?tallinasse =nasse  (SgN  >talli+nasse !06_S	et	f	\N
130426	tallinasse	?tallinasse =nasse  (SgG  >talli+nasne !02_A	et	f	\N
130427	tallinasse	?tallinasse =nasse  (SgG  >talli+nasse !06_S	et	f	\N
130428	tallinasse	?tallinasse =nasse  (PlP  >talli+nass !22_S	et	f	\N
130430	näginud	?näginud =nägi  (PtsPtPs  >nägima !27_V	et	f	\N
130431	näginud	?näginud =näginu  (PlN  >näginu !01_S	et	f	\N
130432	näginud	?näginud =näginu  (IndPrSg2  >näginuma !27_V	et	f	\N
130433	näginud	?näginud =näginud  (ID  >näginud !41_A	et	f	\N
130439	marjud	?marjud =marju  (PlN  >marju !16_S	et	f	\N
130440	marjud	?marjud =marju  (IndPrSg2  >marjuma !27_V	et	f	\N
130459	soovis	soovis =soovi  (SgIn  >soov !22_S	et	f	\N
130460	soovis	soovis =soovi  (IndIpfSg3  >soovima !28_V	et	f	\N
130481	pettang	?pettang =pettang  (SgN  >pettang !02_S	et	f	\N
130489	kordagi	kordagi =korda  (ID^  >korda !41_D	et	f	\N
130490	kordagi	kordagi =korda  (SgP^  >kord !22_S	et	f	\N
130491	kordagi	kordagi =korda  (SgAdt^  >kord !22_S	et	f	\N
130492	kordagi	kordagi =korda  (IndPrPs_^  >kordama !29_V	et	f	\N
130493	kordagi	kordagi =korda  (ImpPrSg2^  >kordama !29_V	et	f	\N
130494	nädalavahetused	nädalavahetused =vahetuse  (PlN  >nädala+vahetus !11_S	et	f	\N
130495	nädalavahetused	"nädala+vahetus %vahe  )TUS2_aS  <nädala+vahe ;16_S	et	f	\N
130529	merile	?merile =merile  (IndPrPs_  >merilema !27_V	et	f	\N
130530	merile	?merile =merile  (ImpPrSg2  >merilema !27_V	et	f	\N
130543	tõestamine	tõestamine =tõestamine  (SgN  >tõestamine !12_S	et	f	\N
130544	tõestamine	"tõestamine %tõesta  )MINE_vS  <tõestama ;27_V	et	f	\N
130563	lastevaheline	lastevaheline =vaheline  (SgN  >laste+vaheline !12_A	et	f	\N
130564	lastevaheline	"laste+vaheline %vahe  )LINE_aA  <laste+vahe ;16_S	et	f	\N
130587	haigestunud	haigestunud =haigestu  (PtsPtPs  >haigestuma !27_V	et	f	\N
130588	haigestunud	haigestunud =haigestunu  (PlN  >haigestunu !01_S	et	f	\N
130589	haigestunud	"haigestunu %haigestu  )NU_vS  <haigestuma ;27_V	et	f	\N
130590	haigestunud	haigestunud =haigestunud  (ID  >haigestunud !41_A	et	f	\N
130591	haigestunud	"haigestunud %haigestu  )NUD_vA  <haigestuma ;27_V	et	f	\N
130342	soovitused	"soovitus %soovi  )TUS2_aS  <soov ;22_S	et	f	\N
130351	kaheksakümmend	?kaheksakümmend =kaheksakümmend  (SgN  >kaheksakümmend !22_S	et	f	\N
130352	kaheksakümmend	?kaheksakümmend =ksakümmend  (SgN  >kahe+ksakümmend !22_S	et	f	\N
130361	leidab	?leidab =leida  (IndPrSg3  >leidama !29_V	et	f	\N
130406	pääris	?pääris =pääri  (SgIn  >pääri !16_S	et	f	\N
130407	pääris	?pääris =pääri  (SgIn  >päär !22_S	et	f	\N
130408	pääris	?pääris =pääri  (IndIpfSg3  >päärima !28_V	et	f	\N
130409	pääris	?pääris =pääris  (SgN  >pääris !09_S	et	f	\N
130413	otepääl	?otepääl =otepää  (SgAd  >otepää !26_S	et	f	\N
130414	otepääl	?otepääl =otepääl  (SgN  >otepääl !22_S	et	f	\N
130418	päevatasin	?päevatasin =päevata  (IndIpfSg1  >päevatama !27_V	et	f	\N
130419	päevatasin	?päevatasin =päevatasin  (SgN  >päevatasin !19_S	et	f	\N
130420	päevatasin	?päevatasin =tasin  (SgN  >päeva+tasin !02_S	et	f	\N
130421	päevatasin	?päevatasin =atasin  (SgN  >päev+atasin !19_S	et	f	\N
130434	ameerikas	?ameerikas =ameerika  (SgIn  >ameerikas !02_A	et	f	\N
130435	ameerikas	?ameerikas =ameerikas  (SgN  >ameerikas !02_A	et	f	\N
130464	ühendust	ühendust =ühendus  (SgP  >ühendus !11_S	et	f	\N
130465	ühendust	"ühendus %ühenda  )US_vS  <ühendama ;27_V	et	f	\N
130466	ühendust	ühendust =us  (SgP  >ühend+uks !14_S	et	f	\N
130478	käidud	käidud =käi  (PtsPtIps  >käima !38_V	et	f	\N
130479	käidud	käidud =käidu  (PlN  >käidu !01_S	et	f	\N
130480	käidud	"käidu %käi  )TU1_vS  <käima ;38_V	et	f	\N
130482	käidud	käidud =käidud  (ID  >käidud !41_A	et	f	\N
130483	käidud	"käidud %käi  )TUD_vA  <käima ;38_V	et	f	\N
130502	spordiala	spordiala =ala  (SgN  >spordi+ala !17_S	et	f	\N
130504	spordiala	spordiala =ala  (SgG  >spordi+ala !17_S	et	f	\N
130505	spordiala	spordiala =ala  (SgP  >spordi+ala !17_S	et	f	\N
130511	külmemaks	külmemaks =külmema  (SgTr  >külmem !02_A	et	f	\N
130512	külmemaks	"külmem %külme  )M_cA  <külm ;22_AS	et	f	\N
130513	külmemaks	külmemaks =ema  (SgTr  >külm+ema !17_S	et	f	\N
130514	suvet	?suvet =suve  (SgP  >suve !16_S	et	f	\N
130517	purje	purje =purje  (SgG  >puri !24_S	et	f	\N
130518	purje	purje =purje  (SgP  >puri !24_S	et	f	\N
130519	purje	purje =purje  (SgAdt  >puri !24_S	et	f	\N
130534	tahelepanu	?tahelepanu =tahelepanu  (SgN  >tahelepanu !01_S	et	f	\N
130535	tahelepanu	?tahelepanu =tahelepanu  (SgG  >tahelepanu !01_S	et	f	\N
130536	tahelepanu	?tahelepanu =tahelepanu  (IndPrPs_  >tahelepanuma !27_V	et	f	\N
130537	tahelepanu	?tahelepanu =tahelepanu  (ImpPrSg2  >tahelepanuma !27_V	et	f	\N
130538	tahelepanu	?tahelepanu =lepanu  (SgN  >tahe+lepanu !01_S	et	f	\N
130539	tahelepanu	?tahelepanu =lepanu  (SgG  >tahe+lepanu !01_S	et	f	\N
130545	turvalised	turvalised =turvalise  (PlN  >turvaline !12_A	et	f	\N
130546	turvalised	"turvaline %turva  )LINE_aA  <turb ;22_SA	et	f	\N
130547	turvalised	"turvaline %turva  )LINE_aA  <turv ;22_S	et	f	\N
130582	haigestunud	haigestunud =haigestu  (PtsPtPs  >haigestuma !27_V	et	f	\N
130583	haigestunud	haigestunud =haigestunu  (PlN  >haigestunu !01_S	et	f	\N
130584	haigestunud	"haigestunu %haigestu  )NU_vS  <haigestuma ;27_V	et	f	\N
130585	haigestunud	haigestunud =haigestunud  (ID  >haigestunud !41_A	et	f	\N
130586	haigestunud	"haigestunud %haigestu  )NUD_vA  <haigestuma ;27_V	et	f	\N
130604	oskulikumaks	?oskulikumaks =oskuliku  (SupTr  >oskulikuma !27_V	et	f	\N
130605	oskulikumaks	?oskulikumaks =oskulikuma  (SgTr  >oskulikum !02_A	et	f	\N
130612	sekku	sekku =sekku  (IndPrPs_  >sekkuma !27_V	et	f	\N
130613	sekku	sekku =sekku  (ImpPrSg2  >sekkuma !27_V	et	f	\N
130614	teole	teole =teo  (SgAll  >tegu !18_S	et	f	\N
130615	teole	teole =teo  (SgAll  >tigu !18_S	et	f	\N
130633	kaisin	?kaisin =kaisi  (IndPrSg1  >kaisima !28_V	et	f	\N
130634	kaisin	?kaisin =kaisin  (SgN  >kaisin !02_S	et	f	\N
130636	hermitag	### hermitag	et	f	\N
130637	sojem	?sojem =sojem  (SgN  >sojem !02_A	et	f	\N
130641	kõikile	?kõikile =kõikile  (IndPrPs_  >kõikilema !27_V	et	f	\N
130642	kõikile	?kõikile =kõikile  (ImpPrSg2  >kõikilema !27_V	et	f	\N
130643	lugemiselamus	lugemiselamus =elamu  (SgIn  >lugemis+elamu !01_S	et	f	\N
130644	lugemiselamus	lugemiselamus =elamus  (SgN  >lugemis+elamus !11_S	et	f	\N
130662	konspekti	konspekti =konspekti  (SgG  >konspekt !22_S	et	f	\N
130663	konspekti	konspekti =konspekti  (SgP  >konspekt !22_S	et	f	\N
130664	konspekti	konspekti =konspekti  (SgAdt  >konspekt !22_S	et	f	\N
130665	konspekti	konspekti =konspekti  (IndPrPs_  >konspektima !28_V	et	f	\N
130666	konspekti	konspekti =konspekti  (ImpPrSg2  >konspektima !28_V	et	f	\N
130667	telefoniga	telefoniga =telefoni  (SgKom  >telefon !19_S	et	f	\N
130668	telefoniga	telefoniga =iga  (SgN  >telefon+iga !18_S	et	f	\N
130669	telefoniga	telefoniga =iga  (SgP  >telefon+iga !18_S	et	f	\N
130672	riietust	riietust =riietus  (SgP  >riietus !11_S	et	f	\N
130673	riietust	"riietus %riieta  )US_vS  <riietama ;27_V	et	f	\N
130674	korjata	korjata =korja  (Inf  >korjama !29_V	et	f	\N
130675	korjata	korjata =korja  (IndPrIps_  >korjama !29_V	et	f	\N
130678	hilisem	hilisem =hilisem  (SgN  >hilisem !02_A	et	f	\N
130679	hilisem	"hilisem %hilise  )M_cA  <hiline ;10_A	et	f	\N
130380	valikuks	valikuks =valiku  (SgTr  >valik !02_S	et	f	\N
130381	valikuks	valikuks =uks  (SgN  >valik+uks !14_S	et	f	\N
130382	suhtlevad	suhtlevad =suhtle  (IndPrPl3  >suhtlema !30_V	et	f	\N
130383	suhtlevad	suhtlevad =suhtleva  (PlN  >suhtlev !02_A	et	f	\N
130384	suhtlevad	"suhtlev %suhtle  )V_vA  <suhtlema ;30_V	et	f	\N
130388	tudengidel	### tudengidel	et	f	\N
130389	otepääs	?otepääs =otepää  (SgIn  >otepää !26_S	et	f	\N
130390	otepääs	?otepääs =otepääs  (SgN  >otepääs !22_S	et	f	\N
130393	õpetajadega	### õpetajadega	et	f	\N
130415	pedast	?pedast =peda  (SgEl  >peda !17_S	et	f	\N
130416	pedast	?pedast =pedas  (SgP  >pedas !07_S	et	f	\N
130417	pedast	?pedast =pedas  (SgP  >pedane !10_A	et	f	\N
130443	ultse	?ultse =ultse  (SgN  >ultse !06_S	et	f	\N
130444	ultse	?ultse =ultse  (SgG  >ultne !02_A	et	f	\N
130445	ultse	?ultse =ultse  (SgG  >ultse !06_S	et	f	\N
130446	ultse	?ultse =ultse  (PlP  >ults !22_S	et	f	\N
130447	ultse	?ultse =ultse  (IndPrPs_  >ultsema !27_V	et	f	\N
130448	ultse	?ultse =ultse  (ImpPrSg2  >ultsema !27_V	et	f	\N
130454	astat	?astat =asta  (SgP  >asta !16_S	et	f	\N
130455	astat	?astat =astat  (SgN  >astat !02_S	et	f	\N
130467	tarkvara	tarkvara =vara  (SgN  >tark+vara !17_S	et	f	\N
130468	tarkvara	tarkvara =vara  (SgG  >tark+vara !17_S	et	f	\N
130469	tarkvara	tarkvara =vara  (SgP  >tark+vara !17_S	et	f	\N
130484	freesbe	?freesbe =freesbe  (SgN  >freesbe !06_S	et	f	\N
130485	freesbe	?freesbe =freesbe  (SgG  >freesbe !06_S	et	f	\N
130486	freesbe	?freesbe =freesbe  (PlP  >freesb !22_S	et	f	\N
130487	freesbe	?freesbe =freesbe  (IndPrPs_  >freesbema !27_V	et	f	\N
130488	freesbe	?freesbe =freesbe  (ImpPrSg2  >freesbema !27_V	et	f	\N
130508	peletavad	peletavad =peleta  (IndPrPl3  >peletama !27_V	et	f	\N
130509	peletavad	peletavad =peletava  (PlN  >peletav !02_A	et	f	\N
130510	peletavad	"peletav %peleta  )V_vA  <peletama ;27_V	et	f	\N
130515	neljameetrilise	neljameetrilise =meetrilise  (SgG  >nelja+meetriline !12_A	et	f	\N
130516	neljameetrilise	"nelja+meetriline %meetri  )LINE_aA  <nelja+meeter ;02_S	et	f	\N
130525	puhkuda	?puhkuda =puhku  (Inf  >puhkuma !27_V	et	f	\N
130526	puhkuda	?puhkuda =uda  (SgN  >puhk+uda !17_S	et	f	\N
130527	puhkuda	?puhkuda =uda  (SgG  >puhk+uda !17_S	et	f	\N
130528	puhkuda	?puhkuda =uda  (SgP  >puhk+uda !17_S	et	f	\N
130540	mitteturvaline	mitteturvaline =turvaline  (SgN  >mitte+turvaline !12_A	et	f	\N
130541	mitteturvaline	"mitte+turvaline %turva  )LINE_aA  <mitte+turb ;22_SA	et	f	\N
130542	mitteturvaline	"mitte+turvaline %turva  )LINE_aA  <mitte+turv ;22_S	et	f	\N
130548	vägivalda	vägivalda =valda  (SgP  >vägi+vald !22_S	et	f	\N
130549	vägivalda	vägivalda =valda  (SgAdt  >vägi+vald !22_S	et	f	\N
130552	trauma	trauma =trauma  (SgN  >trauma !16_S	et	f	\N
130553	trauma	trauma =trauma  (SgG  >trauma !16_S	et	f	\N
130554	lapsevanemad	lapsevanemad =vanema  (PlN  >lapse+vanem !02_AS	et	f	\N
130555	lapsevanemad	"lapse+vanem %vane  )M_cA  <lapse+vana ;17_AS	et	f	\N
130567	nähtus	nähtus =nähtu  (SgIn  >nähtu !01_S	et	f	\N
130568	nähtus	"nähtu %näh  )TU1_vS  <nägema ;28_V	et	f	\N
130569	nähtus	nähtus =nähtu  (IndIpfSg3  >nähtuma !27_V	et	f	\N
130570	nähtus	nähtus =nähtus  (SgN  >nähtus !11~09_S	et	f	\N
130571	nähtus	"nähtus %näh  )TUS1_aS  <nägema ;28_V	et	f	\N
130577	alale	alale =ala  (SgAll  >ala !17_S	et	f	\N
130578	alale	alale =alale  (ID  >alale !41_D	et	f	\N
130595	kasvatajatel	kasvatajatel =kasvataja  (PlAd  >kasvataja !01_S	et	f	\N
130596	kasvatajatel	"kasvataja %kasvata  )JA_vS  <kasvatama ;27_V	et	f	\N
130597	ükskõiksus	ükskõiksus =kõiksus  (SgN  >üks+kõiksus !11~09_S	et	f	\N
130598	ükskõiksus	"üks+kõiksus %kõikse  )US_aS  <üks+kõikne ;02_A	et	f	\N
130599	territoriumid	?territoriumid =territoriumi  (PlN  >territoriumi !16_S	et	f	\N
130600	territoriumid	?territoriumid =territoriumi  (PlN  >territorium !19_S	et	f	\N
130601	territoriumid	?territoriumid =territoriumi  (IndPrSg2  >territoriumima !28_V	et	f	\N
130608	lasteomavahelised	lasteomavahelised =vahelise  (PlN  >laste+oma+vaheline !12_A	et	f	\N
130609	lasteomavahelised	"laste+oma+vaheline %vahe  )LINE_aA  <laste+oma+vahe ;16_S	et	f	\N
130621	krasnojarskis	?krasnojarskis =krasnojarski  (IndIpfSg3  >krasnojarskima !28_V	et	f	\N
130622	krasnojarskis	?krasnojarskis =krasnojarskis  (SgN  >krasnojarskis !09_S	et	f	\N
130645	iluskirjandus	?iluskirjandus =iluskirjandu  (IndIpfSg3  >iluskirjanduma !27_V	et	f	\N
130646	iluskirjandus	?iluskirjandus =iluskirjandus  (SgN  >iluskirjandus !11_S	et	f	\N
130647	iluskirjandus	?iluskirjandus =skirjandu  (SgIn  >ilu+skirjandu !01_S	et	f	\N
130648	iluskirjandus	?iluskirjandus =skirjandus  (SgN  >ilu+skirjandus !11_S	et	f	\N
130651	ilukirjandusest	ilukirjandusest =kirjanduse  (SgEl  >ilu+kirjandus !11_S	et	f	\N
130652	ilukirjandusest	ilukirjandusest =kirjanduses  (SgP  >ilu+kirjandusene !12_A	et	f	\N
130653	ilukirjandusest	"ilu+kirjandusene %kirjanduse  )NE_aA  <ilu+kirjandus ;11_S	et	f	\N
130676	helista	helista =helista  (IndPrPs_  >helistama !27_V	et	f	\N
130677	helista	helista =helista  (ImpPrSg2  >helistama !27_V	et	f	\N
130704	ajama	ajama =aja  (Sup  >ajama !27_V	et	f	\N
130706	ajama	ajama =ajama  (SgG  >ajam !02_S	et	f	\N
130575	ebaturvalisena	"eba+turvaline %turva  )LINE_aA  <eba+turb ;22_SA	et	f	\N
130576	ebaturvalisena	"eba+turvaline %turva  )LINE_aA  <eba+turv ;22_S	et	f	\N
130606	töötajatel	töötajatel =töötaja  (PlAd  >töötaja !01_S	et	f	\N
130607	töötajatel	"töötaja %tööta  )JA_vS  <töötama ;27_V	et	f	\N
130616	haigestatud	haigestatud =haigesta  (PtsPtIps  >haigestama !27_V	et	f	\N
130617	haigestatud	haigestatud =haigestatu  (PlN  >haigestatu !01_S	et	f	\N
130618	haigestatud	"haigestatu %haigesta  )TU1_vS  <haigestama ;27_V	et	f	\N
130619	haigestatud	haigestatud =haigestatud  (ID  >haigestatud !41_A	et	f	\N
130620	haigestatud	"haigestatud %haigesta  )TUD_vA  <haigestama ;27_V	et	f	\N
130627	baikali	?baikali =baikali  (ID  >baikali !41_D	et	f	\N
130628	baikali	?baikali =baikali  (SgG  >baikal !02_S	et	f	\N
130629	soja	soja =soja  (SgN  >soja !17_S	et	f	\N
130630	soja	soja =soja  (SgG  >soja !17_S	et	f	\N
130631	soja	soja =soja  (SgP  >soja !17_S	et	f	\N
130649	rikaks	?rikaks =rika  (SgTr  >rika !16_S	et	f	\N
130650	rikaks	?rikaks =rika  (KndPrPs  >rikama !27_V	et	f	\N
130654	sõpra	sõpra =sõpra  (SgP  >sõber !24_S	et	f	\N
130655	sõpra	sõpra =sõpra  (SgAdt  >sõber !24_S	et	f	\N
130656	uusid	?uusid =uusi  (PlN  >uusi !16_S	et	f	\N
130657	uusid	?uusid =uusi  (IndPrSg2  >uusima !28_V	et	f	\N
130670	pakkumine	pakkumine =pakkumine  (SgN  >pakkumine !12_S	et	f	\N
130671	pakkumine	"pakkumine %pakku  )MINE_vS  <pakkuma ;28_V	et	f	\N
130689	kellelegi	kellelegi =kelle  (SgAll  >keegi !00_P	et	f	\N
130690	kellelegi	kellelegi =kelle  (SgAll^  >kes !00_P	et	f	\N
130691	kellelegi	kellelegi =kelle  (PlAll^  >kell !22_S	et	f	\N
130715	teavitada	?teavitada =teavita  (Inf  >teavitama !27_V	et	f	\N
130723	mitmekesine	?mitmekesine =mitmekesine  (SgN  >mitmekesine !12_A	et	f	\N
130724	mitmekesine	?mitmekesine =mitmekesine  (PlP  >mitmekesin !19_S	et	f	\N
130725	õpimist	?õpimist =õpimi  (SgEl  >õpimi !01_S	et	f	\N
130726	õpimist	?õpimist =õpimi  (SgEl  >õpim !02_A	et	f	\N
130727	õpimist	?õpimist =õpimis  (SgP  >õpimis !11_S	et	f	\N
130728	õpimist	?õpimist =õpimis  (SgP  >õpimine !12_S	et	f	\N
130729	õpimist	?õpimist =õpimist  (SgN  >õpimist !22_S	et	f	\N
130732	kooriga	kooriga =koori  (SgKom  >koor !22_S	et	f	\N
130733	kooriga	kooriga =iga  (SgN  >koor+iga !18_S	et	f	\N
130734	kooriga	kooriga =iga  (SgP  >koor+iga !18_S	et	f	\N
130738	kuueteistkümne	?kuueteistkümne =kuueteistkümne  (SgN  >kuueteistkümne !02_A	et	f	\N
130739	kuueteistkümne	?kuueteistkümne =kuueteistkümne  (PlP  >kuueteistkümn !22_S	et	f	\N
130740	kuueteistkümne	?kuueteistkümne =kümne  (SgN  >kuue+teist+kümne !02_A	et	f	\N
130741	kuueteistkümne	?kuueteistkümne =kümne  (PlP  >kuue+teist+kümn !22_S	et	f	\N
130742	kuueteistkümne	?kuueteistkümne =teistkümne  (SgN  >kuue+teistkümne !02_A	et	f	\N
130743	kuueteistkümne	?kuueteistkümne =teistkümne  (PlP  >kuue+teistkümn !22_S	et	f	\N
130744	kuueteistkümne	?kuueteistkümne =eteistkümne  (SgN  >kuu+eteistkümne !02_A	et	f	\N
130745	kuueteistkümne	?kuueteistkümne =eteistkümne  (PlP  >kuu+eteistkümn !22_S	et	f	\N
130762	unistuseks	unistuseks =unistuse  (SgTr  >unistus !11_S	et	f	\N
130763	unistuseks	"unistus %unista  )US_vS  <unistama ;27_V	et	f	\N
130771	kaheksasateistkümnes	?kaheksasateistkümnes =kaheksasateistkümne  (PlIn  >kaheksasateistkümn !22_S	et	f	\N
130772	kaheksasateistkümnes	?kaheksasateistkümnes =sateistkümne  (PlIn  >kaheksa+sateistkümn !22_S	et	f	\N
130773	kaheksasateistkümnes	?kaheksasateistkümnes =ksasateistkümne  (PlIn  >kahe+ksasateistkümn !22_S	et	f	\N
130780	küsi	küsi =küsi  (IndPrPs_  >küsima !27_V	et	f	\N
130781	küsi	küsi =küsi  (ImpPrSg2  >küsima !27_V	et	f	\N
130798	judo	?judo =judo  (SgN  >judo !17~16_S	et	f	\N
130799	judo	?judo =judo  (SgG  >judo !17~16_S	et	f	\N
130800	judo	?judo =judo  (SgP  >judo !17_S	et	f	\N
130804	räägites	?räägites =räägite  (PlIn  >räägitt !22_S	et	f	\N
130811	tülitsin	?tülitsin =tülitsi  (IndPrSg1  >tülitsima !28_V	et	f	\N
130812	tülitsin	?tülitsin =tülitsin  (SgN  >tülitsin !19_S	et	f	\N
130813	pääsu	pääsu =pääsu  (SgN  >pääsu !16_S	et	f	\N
130814	pääsu	pääsu =pääsu  (SgG  >pääsu !16_S	et	f	\N
130815	pääsu	pääsu =pääsu  (SgG  >pääs !22_S	et	f	\N
130816	pääsu	pääsu =pääsu  (SgP  >pääs !22_S	et	f	\N
130817	pääsu	pääsu =pääsu  (SgAdt  >pääs !22_S	et	f	\N
130818	rangluu	rangluu =luu  (SgN  >rang+luu !26_S	et	f	\N
130819	rangluu	rangluu =luu  (SgG  >rang+luu !26_S	et	f	\N
130829	emake	emake =emake  (SgN  >emake !12_S	et	f	\N
130830	emake	"emake %ema  )KE_dS  <ema ;17_S	et	f	\N
130846	lille	lille =lille  (SgG  >lill !22_S	et	f	\N
130847	lille	lille =lille  (SgP  >lill !22_S	et	f	\N
130848	lille	lille =lille  (SgAdt  >lill !22_S	et	f	\N
130849	lille	lille =lille  (PlP  >lill !22_S	et	f	\N
130864	suudelda	suudelda =suudel  (Inf  >suudlema !30_V	et	f	\N
130865	suudelda	suudelda =suudel  (IndPrIps_  >suudlema !30_V	et	f	\N
130874	möödanud	?möödanud =möödanu  (PlN  >möödanu !01_S	et	f	\N
130875	möödanud	?möödanud =möödanu  (IndPrSg2  >möödanuma !27_V	et	f	\N
130876	möödanud	?möödanud =möödanud  (ID  >möödanud !41_A	et	f	\N
130881	ähvarda	ähvarda =ähvarda  (IndPrPs_  >ähvardama !27_V	et	f	\N
130592	vanematel	vanematel =vanema  (PlAd  >vanem !02_AS	et	f	\N
130593	vanematel	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
130594	vanematel	vanematel =ate  (PlAd  >vanem+att !22_S	et	f	\N
130610	suhtlemises	suhtlemises =suhtlemise  (SgIn  >suhtlemine !12_S	et	f	\N
130611	suhtlemises	"suhtlemine %suhtle  )MINE_vS  <suhtlema ;30_V	et	f	\N
130632	veet	?veet =veet  (SgN  >veet !22_S	et	f	\N
130635	pitergoff	?pitergoff =pitergoff  (SgN  >pitergoff !22_S	et	f	\N
130682	õmblejaks	õmblejaks =õmbleja  (SgTr  >õmbleja !01_S	et	f	\N
130683	õmblejaks	"õmbleja %õmble  )JA_vS  <õmblema ;30_V	et	f	\N
130686	näidetakse	?näidetakse =näide  (IndPrIps  >näidema !27_V	et	f	\N
130687	näidetakse	?näidetakse =näidetakse  (SgG  >näidetakne !02_A	et	f	\N
130688	näidetakse	?näidetakse =näidetakse  (PlP  >näidetaks !22_S	et	f	\N
130708	hakata	hakata =haka  (Inf  >hakkama !29_V	et	f	\N
130709	hakata	hakata =haka  (IndPrIps_  >hakkama !29_V	et	f	\N
130710	hakata	hakata =hakata  (IndPrPs_  >hakatama !27_V	et	f	\N
130711	hakata	hakata =hakata  (ImpPrSg2  >hakatama !27_V	et	f	\N
130730	tansiga	?tansiga =tansi  (SgKom  >tansi !16_S	et	f	\N
130731	tansiga	?tansiga =tansi  (SgKom  >tanss !22_S	et	f	\N
130735	kõrvpalliga	?kõrvpalliga =kõrvpalli  (SgKom  >kõrvpalli !01_S	et	f	\N
130736	kõrvpalliga	?kõrvpalliga =kõrvpalli  (SgKom  >kõrvpall !22_S	et	f	\N
130783	koodus	?koodus =koodu  (SgIn  >koodu !16_S	et	f	\N
130784	koodus	?koodus =koodu  (IndIpfSg3  >kooduma !27_V	et	f	\N
130785	koodus	?koodus =koodus  (SgN  >koodus !11~09_S	et	f	\N
130788	kunstikooli	kunstikooli =kooli  (SgG  >kunsti+kool !22_S	et	f	\N
130789	kunstikooli	kunstikooli =kooli  (SgP  >kunsti+kool !22_S	et	f	\N
130791	kunstikooli	kunstikooli =kooli  (SgAdt  >kunsti+kool !22_S	et	f	\N
130792	kunstikooli	kunstikooli =kooli  (PlP  >kunsti+kool !22_S	et	f	\N
130794	kõva	kõva =kõva  (SgN  >kõva !17_A	et	f	\N
130795	kõva	kõva =kõva  (SgG  >kõva !17_A	et	f	\N
130796	kõva	kõva =kõva  (SgP  >kõva !17_A	et	f	\N
130809	dekanaadis	dekanaadis =dekanaadi  (SgIn  >dekanaat !22_S	et	f	\N
130810	dekanaadis	dekanaadis =naadi  (SgIn  >deka+naat !22_S	et	f	\N
130820	kasulikku	kasulikku =kasulikku  (SgP  >kasulik !25_A	et	f	\N
130821	kasulikku	kasulikku =kasulikku  (SgAdt  >kasulik !25_A	et	f	\N
130838	tütrakele	?tütrakele =tütrake  (PlAll  >tütrakk !22_S	et	f	\N
130839	tütrakele	?tütrakele =tütrakele  (PlP  >tütrakel !19_S	et	f	\N
130840	põlla	?põlla =põlla  (SgN  >põlla !16_S	et	f	\N
130841	põlla	?põlla =põlla  (SgG  >põlla !16_S	et	f	\N
130842	põlla	?põlla =põlla  (IndPrPs_  >põllama !29_V	et	f	\N
130843	põlla	?põlla =põlla  (ImpPrSg2  >põllama !29_V	et	f	\N
130844	kaldus	kaldus =kaldu  (IndIpfSg3  >kalduma !27_V	et	f	\N
130845	kaldus	kaldus =kaldus  (SgN  >kaldus !11~09_S	et	f	\N
130853	ilusamad	ilusamad =ilusama  (PlN  >ilusam !02_A	et	f	\N
130854	ilusamad	"ilusam %ilusa  )M_cA  <ilus ;02_A	et	f	\N
130859	mutike	mutike =mutike  (SgN  >mutike !12_S	et	f	\N
130860	mutike	"mutike %muti  )KE_dS  <muti ;16_S	et	f	\N
130861	mutike	"mutike %muti  )KE_dS  <mutt ;22_S	et	f	\N
130868	heameelest	heameelest =lest  (SgN  >hea+mee+lest !22_S	et	f	\N
130869	heameelest	heameelest =meele  (SgEl  >hea+meel !13_S	et	f	\N
130870	heameelest	heameelest =meeles  (SgP  >hea+meelene !10_A	et	f	\N
130871	heameelest	"hea+meelene %meele  )NE_aA  <hea+meel ;13_S	et	f	\N
130872	puuraiuja	puuraiuja =raiuja  (SgN  >puu+raiuja !01_S	et	f	\N
130873	puuraiuja	puuraiuja =raiuja  (SgG  >puu+raiuja !01_S	et	f	\N
130877	kuulis	kuulis =kuul  (IndIpfSg3  >kuulma !33_V	et	f	\N
130878	kuulis	kuulis =kuuli  (SgIn  >kuul !22_S	et	f	\N
130879	laula	laula =laula  (IndPrPs_  >laulma !33_V	et	f	\N
130880	laula	laula =laula  (ImpPrSg2  >laulma !33_V	et	f	\N
130883	punamütsikese	punamütsikese =mütsikese  (SgG  >puna+mütsike !12_S	et	f	\N
130884	punamütsikese	"puna+mütsike %mütsi  )KE_dS  <puna+müts ;22_S	et	f	\N
130885	punamütsikese	punamütsikese =mütsikese  (SgG  >puna+mütsikene !12_S	et	f	\N
130886	punamütsikese	"puna+mütsikene %mütsi  )KENE_dS  <puna+müts ;22_S	et	f	\N
130889	kirvest	kirvest =kirve  (SgEl  >kirves !07_S	et	f	\N
130890	kirvest	kirvest =kirves  (SgP  >kirves !07_S	et	f	\N
130891	kirvest	kirvest =kirves  (SgP  >kirvene !10_A	et	f	\N
130892	kirvest	"kirvene %kirve  )NE_aA  <kirves ;07_S	et	f	\N
130893	elukohta	elukohta =kohta  (SgP  >elu+koht !22_S	et	f	\N
130894	elukohta	elukohta =kohta  (SgAdt  >elu+koht !22_S	et	f	\N
130898	transportimiseks	transportimiseks =transportimise  (SgTr  >transportimine !12_S	et	f	\N
130899	transportimiseks	"transportimine %transporti  )MINE_vS  <transportima ;28_V	et	f	\N
130912	värvitatud	?värvitatud =värvita  (PtsPtIps  >värvitama !27_V	et	f	\N
130913	värvitatud	?värvitatud =värvitatu  (PlN  >värvitatu !01_S	et	f	\N
130914	värvitatud	?värvitatud =värvitatu  (IndPrSg2  >värvitatuma !27_V	et	f	\N
130915	värvitatud	?värvitatud =värvitatud  (ID  >värvitatud !41_A	et	f	\N
130916	värvitatud	?värvitatud =tatu  (PlN  >värvi+tatu !16_S	et	f	\N
130917	värvitatud	?värvitatud =itatu  (PlN  >värv+itatu !01_S	et	f	\N
130939	reede	reede =reede  (SgN  >reede !01_S	et	f	\N
130940	reede	reede =reede  (SgG  >reede !01_S	et	f	\N
130639	jargmine	?jargmine =jargmine  (IndPrPs_  >jargminema !27_V	et	f	\N
130640	jargmine	?jargmine =jargmine  (ImpPrSg2  >jargminema !27_V	et	f	\N
130658	kursusetööd	kursusetööd =töö  (PlN  >kursuse+töö !26_S	et	f	\N
130659	kursusetööd	kursusetööd =töö  (SgP  >kursuse+töö !26_S	et	f	\N
130660	kursusetöö	kursusetöö =töö  (SgN  >kursuse+töö !26_S	et	f	\N
130661	kursusetöö	kursusetöö =töö  (SgG  >kursuse+töö !26_S	et	f	\N
130680	õmblejana	õmblejana =õmbleja  (SgEs  >õmbleja !01_S	et	f	\N
130681	õmblejana	"õmbleja %õmble  )JA_vS  <õmblema ;30_V	et	f	\N
130684	laulumängut	?laulumängut =mängut  (SgN  >laulu+mängut !02_S	et	f	\N
130685	laulumängut	?laulumängut =lumängu  (SgP  >lau+lumängu !01_S	et	f	\N
130692	muusiumisse	?muusiumisse =muusiumi  (SgIll  >muusium !19~02_S	et	f	\N
130693	muusiumisse	?muusiumisse =muusiumi  (SgIll  >muusiumi !16_S	et	f	\N
130694	muusiumisse	?muusiumisse =muusiumisse  (SgG  >muusiumisne !02_A	et	f	\N
130695	muusiumisse	?muusiumisse =muusiumisse  (PlP  >muusiumiss !22_S	et	f	\N
130696	muusiumisse	?muusiumisse =siumi  (SgIll  >muu+siumi !16_S	et	f	\N
130697	muusiumisse	?muusiumisse =siumi  (SgIll  >muu+sium !22_S	et	f	\N
130698	muusiumisse	?muusiumisse =siumisse  (SgG  >muu+siumisne !02_A	et	f	\N
130699	muusiumisse	?muusiumisse =siumisse  (PlP  >muu+siumiss !22_S	et	f	\N
130700	näitust	näitust =näitus  (SgP  >näitus !11~09_S	et	f	\N
130701	näitust	näitust =us  (SgP  >näit+uks !14_S	et	f	\N
130702	seisasin	?seisasin =seisa  (IndIpfSg1  >seisama !29_V	et	f	\N
130703	seisasin	?seisasin =seisasin  (SgN  >seisasin !19_S	et	f	\N
130750	ebaõnnestus	ebaõnnestus =õnnestu  (IndIpfSg3  >eba+õnnestuma !27_V	et	f	\N
130751	ebaõnnestus	ebaõnnestus =õnnestus  (SgN  >eba+õnnestus !11_S	et	f	\N
130753	siiamanii	?siiamanii =siiamanii  (SgN  >siiamanii !26_S	et	f	\N
130754	siiamanii	?siiamanii =siiamanii  (SgG  >siiamanii !26_S	et	f	\N
130755	siiamanii	?siiamanii =manii  (SgN  >siia+manii !26_S	et	f	\N
130756	siiamanii	?siiamanii =manii  (SgG  >siia+manii !26_S	et	f	\N
130759	tegelemine	tegelemine =tegelemine  (SgN  >tegelemine !12_S	et	f	\N
130760	tegelemine	"tegelemine %tegele  )MINE_vS  <tegelema ;27_V	et	f	\N
130761	tegelemine	"tegelemine %tegele  )MINE_vS  <tegelema ;31_V	et	f	\N
130767	juhtugi	juhtugi =juhtu  (SgP^  >juht !22_S	et	f	\N
130768	juhtugi	juhtugi =juhtu  (SgAdt^  >juht !22_S	et	f	\N
130769	juhtugi	juhtugi =juhtu  (IndPrPs_^  >juhtuma !27_V	et	f	\N
130770	juhtugi	juhtugi =juhtu  (ImpPrSg2^  >juhtuma !27_V	et	f	\N
130774	mcdonalsis	?mcdonalsis =mcdonalsi  (SgIn  >mcdonalsi !01_S	et	f	\N
130775	mcdonalsis	?mcdonalsis =mcdonalsi  (SgIn  >mcdonalss !22_S	et	f	\N
130776	mcdonalsis	?mcdonalsis =mcdonalsi  (IndIpfSg3  >mcdonalsima !28_V	et	f	\N
130777	mcdonalsis	?mcdonalsis =mcdonalsis  (SgN  >mcdonalsis !11_S	et	f	\N
130778	tenin	?tenin =teni  (IndPrSg1  >tenima !27_V	et	f	\N
130779	tenin	?tenin =tenin  (SgN  >tenin !02_S	et	f	\N
130782	posittivset	?posittivset =posittivse  (SgP  >posittivne !02_A	et	f	\N
130786	sisseastus	?sisseastus =sisseastu  (IndIpfSg3  >sisseastuma !27_V	et	f	\N
130787	sisseastus	?sisseastus =sisseastus  (SgN  >sisseastus !11~09_S	et	f	\N
130790	sisseastus	?sisseastus =astu  (SgIn  >sisse+astu !16_S	et	f	\N
130793	sisseastus	?sisseastus =astus  (SgN  >sisse+astus !11~09_S	et	f	\N
130797	kickboxing	?kickboxing =kickboxing  (SgN  >kickboxing !02_S	et	f	\N
130805	sisseastuda	?sisseastuda =sisseastu  (Inf  >sisseastuma !27_V	et	f	\N
130806	skandaali	skandaali =skandaali  (SgG  >skandaal !22_S	et	f	\N
130807	skandaali	skandaali =skandaali  (SgP  >skandaal !22_S	et	f	\N
130808	skandaali	skandaali =skandaali  (SgAdt  >skandaal !22_S	et	f	\N
130831	lapsekest	lapsekest =lapsekes  (SgP  >lapseke !12_S	et	f	\N
130832	lapsekest	"lapseke %lapse  )KE_dS  <laps ;14_S	et	f	\N
130833	lapsekest	lapsekest =lapsekes  (SgP  >lapsekene !12_S	et	f	\N
130834	lapsekest	"lapsekene %lapse  )KENE_dS  <laps ;14_S	et	f	\N
130835	lapsekest	lapsekest =kest  (SgN  >lapse+kest !22_S	et	f	\N
130836	rada	rada =rada  (SgN  >rada !18_S	et	f	\N
130837	rada	rada =rada  (SgP  >rada !18_S	et	f	\N
130857	tundmatut	tundmatut =tundmatu  (SgP  >tundmatu !01_AS	et	f	\N
130858	tundmatut	"tundmatu %tund  )MATU_vA  <tundma ;34_V	et	f	\N
130918	domofooni	?domofooni =domofoo  (SgTer  >domofoo !26_S	et	f	\N
130919	domofooni	?domofooni =domofooni  (SgN  >domofooni !16_S	et	f	\N
130920	domofooni	?domofooni =domofooni  (SgG  >domofooni !16_S	et	f	\N
130921	domofooni	?domofooni =domofooni  (SgG  >domofoon !22_S	et	f	\N
130922	domofooni	?domofooni =domofooni  (SgP  >domofoon !22_S	et	f	\N
130923	domofooni	?domofooni =domofooni  (SgAdt  >domofoon !22_S	et	f	\N
130924	domofooni	?domofooni =domofooni  (IndPrPs_  >domofoonima !28_V	et	f	\N
130925	domofooni	?domofooni =domofooni  (ImpPrSg2  >domofoonima !28_V	et	f	\N
130930	kliendikaart	kliendikaart =kaar  (SgP  >kliendi+kaar !13_S	et	f	\N
130931	kliendikaart	kliendikaart =kaart  (SgN  >kliendi+kaart !22_S	et	f	\N
130949	vendi	vendi =vendi  (SgP  >vend !22_S	et	f	\N
130950	vendi	vendi =vendi  (SgAdt  >vend !22_S	et	f	\N
130951	vendi	vendi =vendi  (PlP  >vend !22_S	et	f	\N
130963	kerjanud	kerjanud =kerja  (PtsPtPs  >kerjama !29_V	et	f	\N
130964	kerjanud	kerjanud =kerjanu  (PlN  >kerjanu !01_S	et	f	\N
130705	hakkata	?hakkata =hakkata  (IndPrPs_  >hakkatama !27_V	et	f	\N
130707	hakkata	?hakkata =hakkata  (ImpPrSg2  >hakkatama !27_V	et	f	\N
130716	pikaks	pikaks =pika  (SgTr  >pikk !22_S	et	f	\N
130717	pikaks	pikaks =pika  (SgTr  >pikk !22_AS	et	f	\N
130737	tansiõpimise	?tansiõpimise =tansiõpimise  (SgG  >tansiõpimine !12_S	et	f	\N
130746	lapseärikooli	lapseärikooli =kooli  (SgG  >lapse+äri+kool !22_S	et	f	\N
130747	lapseärikooli	lapseärikooli =kooli  (SgP  >lapse+äri+kool !22_S	et	f	\N
130748	lapseärikooli	lapseärikooli =kooli  (SgAdt  >lapse+äri+kool !22_S	et	f	\N
130749	lapseärikooli	lapseärikooli =kooli  (PlP  >lapse+äri+kool !22_S	et	f	\N
130752	eksamideks	?eksamideks =ami  (PlTr  >eks+ami !17_S	et	f	\N
130757	ärikoolis	ärikoolis =kooli  (SgIn  >äri+kool !22_S	et	f	\N
130758	ärikoolis	ärikoolis =kooli  (PlIn  >äri+kool !22_S	et	f	\N
130764	ootanud	?ootanud =ootanu  (PlN  >ootanu !01_S	et	f	\N
130765	ootanud	?ootanud =ootanu  (IndPrSg2  >ootanuma !27_V	et	f	\N
130766	ootanud	?ootanud =ootanud  (ID  >ootanud !41_A	et	f	\N
130801	tugevat	tugevat =tuge  (KvtPrPs  >tugema !27_V	et	f	\N
130802	tugevat	tugevat =tugeva  (SgP  >tugev !02_A	et	f	\N
130803	tugevat	"tugev %tuge  )V_vA  <tugema ;27_V	et	f	\N
130850	mutikele	?mutikele =mutikele  (PlP  >mutikel !19_S	et	f	\N
130851	mutikele	?mutikele =kele  (SgN  >muti+kele !16_S	et	f	\N
130852	mutikele	?mutikele =kele  (SgG  >muti+kele !16_S	et	f	\N
130855	hunti	hunti =hunti  (SgP  >hunt !22_S	et	f	\N
130856	hunti	hunti =hunti  (SgAdt  >hunt !22_S	et	f	\N
130867	tudrukut	?tudrukut =tudruku  (SgP  >tudruku !01_S	et	f	\N
130887	kirvese	kirvese =kirvese  (SgG  >kirvene !10_A	et	f	\N
130888	kirvese	"kirvene %kirve  )NE_aA  <kirves ;07_S	et	f	\N
130895	tutvustav	tutvustav =tutvusta  (PtsPrPs  >tutvustama !27_V	et	f	\N
130896	tutvustav	tutvustav =tutvustav  (SgN  >tutvustav !02_A	et	f	\N
130897	tutvustav	"tutvustav %tutvusta  )V_vA  <tutvustama ;27_V	et	f	\N
130905	sissepääses	sissepääses =pääse  (SgIn  >sisse+pääse !06_S	et	f	\N
130906	sissepääses	sissepääses =pääse  (PlIn  >sisse+pääs !22_S	et	f	\N
130907	ust	ust =us  (SgP  >uks !14_S	et	f	\N
130908	ust	ust =ust  (ID  >ust !41_I	et	f	\N
130909	tellidest	?tellidest =telli  (PlEl  >telli !16_S	et	f	\N
130910	tellidest	?tellidest =telli  (PlEl  >tell !22_S	et	f	\N
130911	tellidest	?tellidest =tellides  (SgP  >tellidene !12_A	et	f	\N
130926	prisma	prisma =prisma  (SgN  >prisma !16_S	et	f	\N
130927	prisma	prisma =prisma  (SgG  >prisma !16_S	et	f	\N
130928	osakonda	osakonda =osakonda  (SgP  >osakond !22_S	et	f	\N
130929	osakonda	osakonda =osakonda  (SgAdt  >osakond !22_S	et	f	\N
130932	hinda	hinda =hinda  (SgP  >hind !22_S	et	f	\N
130933	hinda	hinda =hinda  (SgAdt  >hind !22_S	et	f	\N
130934	hinda	hinda =hinda  (IndPrPs_  >hindama !29_V	et	f	\N
130935	hinda	hinda =hinda  (ImpPrSg2  >hindama !29_V	et	f	\N
130936	laskumine	laskumine =laskumine  (SgN  >laskumine !12_S	et	f	\N
130937	laskumine	"laskumine %lasku  )MINE_vS  <laskuma ;27_V	et	f	\N
130938	pankomaat	?pankomaat =pankomaat  (SgN  >pankomaat !22_S	et	f	\N
130972	tava	tava =tava  (SgN  >tava !17_S	et	f	\N
130973	tava	tava =tava  (SgG  >tava !17_S	et	f	\N
130974	tava	tava =tava  (SgP  >tava !17_S	et	f	\N
130994	kontsertedel	kontsertedel =ede  (SgAd  >kontsert+ede !16_S	et	f	\N
130996	kontsertedel	kontsertedel =edel  (SgN  >kontsert+edel !02_S	et	f	\N
131006	keedasin	?keedasin =keeda  (IndIpfSg1  >keedama !29_V	et	f	\N
131007	keedasin	?keedasin =keedasin  (SgN  >keedasin !19_S	et	f	\N
131020	üksikuks	üksikuks =üksiku  (SgTr  >üksik !02_A	et	f	\N
131021	üksikuks	üksikuks =uks  (SgN  >üksik+uks !14_S	et	f	\N
131024	lünka	lünka =lünka  (SgP  >lünk !22_S	et	f	\N
131028	lünka	lünka =lünka  (SgAdt  >lünk !22_S	et	f	\N
131050	da-	### da-	et	f	\N
131052	suletakse	suletakse =sule  (IndPrIps  >sulgema !28_V	et	f	\N
131053	suletakse	suletakse =takse  (PlP  >sule+taks !22_S	et	f	\N
131116	endist	endist =end  (PlEl  >enda !00_P	et	f	\N
131117	endist	endist =end  (PlEl  >ise !00_P	et	f	\N
131118	endist	endist =endis  (SgP  >endine !10~12_A	et	f	\N
131131	väikevendale	?väikevendale =väikevenda  (SgAll  >väikevenda !16_S	et	f	\N
131132	väikevendale	?väikevendale =venda  (SgAll  >väike+venda !16_S	et	f	\N
131133	väikevendale	?väikevendale =kevenda  (SgAll  >väi+kevenda !01_S	et	f	\N
131144	teegin	?teegin =teegi  (IndPrSg1  >teekima !28_V	et	f	\N
131145	teegin	?teegin =teegin  (SgN  >teegin !02_S	et	f	\N
131160	iseenesest	iseenesest =iseenesest  (ID  >ise+enesest !41_D	et	f	\N
131161	iseenesest	iseenesest =enese  (SgEl  >ise+enese !00_P	et	f	\N
131164	lapsuke	lapsuke =lapsuke  (SgN  >lapsuke !12_S	et	f	\N
131165	lapsuke	"lapsuke %lapsu  )KE_dS  <laps ;22_S	et	f	\N
131166	valatud	valatud =vala  (PtsPtIps  >valama !27_V	et	f	\N
131167	valatud	valatud =valatu  (PlN  >valatu !01_AS	et	f	\N
131168	valatud	"valatu %vala  )TU1_vS  <valama ;27_V	et	f	\N
131169	valatud	valatud =valatud  (ID  >valatud !41_A	et	f	\N
131170	valatud	"valatud %vala  )TUD_vA  <valama ;27_V	et	f	\N
131171	ümbritseva	ümbritseva =ümbritseva  (SgG  >ümbritsev !02_A	et	f	\N
130712	tahtsis	?tahtsis =tahtsi  (SgIn  >tahts !22_S	et	f	\N
130713	tahtsis	?tahtsis =tahtsi  (IndIpfSg3  >tahtsima !28_V	et	f	\N
130714	tahtsis	?tahtsis =tahtsis  (SgN  >tahtsis !09_S	et	f	\N
130718	viitsinud	viitsinud =viitsi  (PtsPtPs  >viitsima !28_V	et	f	\N
130719	viitsinud	viitsinud =viitsinu  (PlN  >viitsinu !01_S	et	f	\N
130720	viitsinud	"viitsinu %viitsi  )NU_vS  <viitsima ;28_V	et	f	\N
130721	viitsinud	viitsinud =viitsinud  (ID  >viitsinud !41_A	et	f	\N
130722	viitsinud	"viitsinud %viitsi  )NUD_vA  <viitsima ;28_V	et	f	\N
130822	punamütsike	punamütsike =mütsike  (SgN  >puna+mütsike !12_S	et	f	\N
130823	punamütsike	"puna+mütsike %mütsi  )KE_dS  <puna+müts ;22_S	et	f	\N
130824	punamütsikest	punamütsikest =kest  (SgN  >puna+mütsi+kest !22_S	et	f	\N
130825	punamütsikest	punamütsikest =mütsikes  (SgP  >puna+mütsike !12_S	et	f	\N
130826	punamütsikest	"puna+mütsike %mütsi  )KE_dS  <puna+müts ;22_S	et	f	\N
130827	punamütsikest	punamütsikest =mütsikes  (SgP  >puna+mütsikene !12_S	et	f	\N
130828	punamütsikest	"puna+mütsikene %mütsi  )KENE_dS  <puna+müts ;22_S	et	f	\N
130862	lähedale	lähedale =läheda  (SgAll  >läheda !02_A	et	f	\N
130863	lähedale	lähedale =lähedale  (ID  >lähedale !41_DK	et	f	\N
130866	vanaemat	?vanaemat =emat  (SgN  >vana+emat !02_S	et	f	\N
130900	lukustatud	lukustatud =lukusta  (PtsPtIps  >lukustama !27_V	et	f	\N
130901	lukustatud	lukustatud =lukustatu  (PlN  >lukustatu !01_S	et	f	\N
130902	lukustatud	"lukustatu %lukusta  )TU1_vS  <lukustama ;27_V	et	f	\N
130903	lukustatud	lukustatud =lukustatud  (ID  >lukustatud !41_A	et	f	\N
130904	lukustatud	"lukustatud %lukusta  )TUD_vA  <lukustama ;27_V	et	f	\N
130944	keset	keset =kese  (SgP  >kese !05_S	et	f	\N
130945	keset	keset =keset  (ID  >keset !41_K	et	f	\N
130952	kolmeaastane	kolmeaastane =aastane  (SgN  >kolme+aastane !12~10_A	et	f	\N
130953	kolmeaastane	"kolme+aastane %aasta  )NE_aA  <kolme+aasta ;01_S	et	f	\N
130954	kaubanduskooli	kaubanduskooli =kooli  (SgG  >kaubandus+kool !22_S	et	f	\N
130955	kaubanduskooli	kaubanduskooli =kooli  (SgP  >kaubandus+kool !22_S	et	f	\N
130956	kaubanduskooli	kaubanduskooli =kooli  (SgAdt  >kaubandus+kool !22_S	et	f	\N
130957	kaubanduskooli	kaubanduskooli =kooli  (PlP  >kaubandus+kool !22_S	et	f	\N
130970	kaheteistaastasena	kaheteistaastasena =aastase  (SgEs  >kahe+teist+aastane !12~10_A	et	f	\N
130971	kaheteistaastasena	"kahe+teist+aastane %aasta  )NE_aA  <kahe+teist+aasta ;01_S	et	f	\N
130989	nevskil	?nevskil =nevski  (SgAd  >nevski !01_S	et	f	\N
130990	nevskil	?nevskil =nevski  (SgAd  >nevsk !22_S	et	f	\N
130991	mariinski	?mariinski =mariinski  (SgG  >mariinsk !02_S	et	f	\N
130992	mariinski	?mariinski =mariinski  (IndPrPs_  >mariinskima !28_V	et	f	\N
130993	mariinski	?mariinski =mariinski  (ImpPrSg2  >mariinskima !28_V	et	f	\N
130995	mariinski	?mariinski =inski  (SgN  >mari+inski !01_S	et	f	\N
130997	mariinski	?mariinski =inski  (SgG  >mari+inski !01_S	et	f	\N
130998	mariinski	?mariinski =inski  (SgG  >mari+insk !22_S	et	f	\N
130999	mariinski	?mariinski =inski  (SgP  >mari+insk !22_S	et	f	\N
131000	mariinski	?mariinski =inski  (SgAdt  >mari+insk !22_S	et	f	\N
131001	mariinski	?mariinski =mariins  (SgN^  >mariins !02_S	et	f	\N
131002	mariinski	?mariinski =ins  (SgN^  >mari+ins !22_S	et	f	\N
131003	muretum	muretum =muretum  (SgN  >muretum !02_A	et	f	\N
131004	muretum	"muretum %mure  )TUM2_cA  <mure ;16_S	et	f	\N
131005	muretum	"muretum %muretu  )M_cA  <muretu ;01_A	et	f	\N
131034	pangakaart	pangakaart =kaar  (SgP  >panga+kaar !13_S	et	f	\N
131038	pangakaart	pangakaart =kaart  (SgN  >panga+kaart !22_S	et	f	\N
131041	koolitööd	koolitööd =töö  (PlN  >kooli+töö !26_S	et	f	\N
131042	koolitööd	koolitööd =töö  (SgP  >kooli+töö !26_S	et	f	\N
131043	täida	täida =täi  (Inf  >täima !27_V	et	f	\N
131044	täida	täida =täida  (IndPrPs_  >täitma !34_V	et	f	\N
131045	täida	täida =täida  (ImpPrSg2  >täitma !34_V	et	f	\N
131071	tegisin	?tegisin =tegi  (IndIpfSg1  >tegima !27_V	et	f	\N
131072	tegisin	?tegisin =tegisin  (SgN  >tegisin !19_S	et	f	\N
131079	peasin	?peasin =peasi  (IndPrSg1  >peasima !28_V	et	f	\N
131080	peasin	?peasin =peasin  (SgN  >peasin !02_S	et	f	\N
131093	järveid	?järveid =järve  (PlP  >järve !06_S	et	f	\N
131095	järveid	?järveid =järvei  (PlN  >järvei !26_S	et	f	\N
131097	järveid	?järveid =järvei  (SgP  >järvei !26_S	et	f	\N
131098	järveid	?järveid =järveid  (SgN  >järveid !22_S	et	f	\N
131106	keeleid	?keeleid =keele  (PlP  >keele !06_S	et	f	\N
131108	keeleid	?keeleid =keelei  (PlN  >keelei !26_S	et	f	\N
131110	keeleid	?keeleid =keelei  (SgP  >keelei !26_S	et	f	\N
131112	keeleid	?keeleid =keeleid  (SgN  >keeleid !22_S	et	f	\N
131114	keeleid	?keeleid =eid  (SgN  >keel+eid !22_S	et	f	\N
131152	lennata	lennata =lenna  (Inf  >lendama !29_V	et	f	\N
131153	lennata	lennata =lenna  (IndPrIps_  >lendama !29_V	et	f	\N
131156	luksus	luksus =luksu  (SgIn  >luks !22_S	et	f	\N
131157	luksus	luksus =luksu  (SgIn  >luks !22_SA	et	f	\N
131158	luksus	luksus =luksu  (IndIpfSg3  >luksuma !28_V	et	f	\N
131159	luksus	luksus =luksus  (SgN  >luksus !11~09_S	et	f	\N
131190	pühitud	pühitud =pühi  (PtsPtIps  >pühkima !28_V	et	f	\N
131191	pühitud	pühitud =pühitu  (PlN  >pühitu !01_AS	et	f	\N
130882	ähvarda	ähvarda =ähvarda  (ImpPrSg2  >ähvardama !27_V	et	f	\N
130941	lillede	lillede =lille  (PlG  >lill !22_S	et	f	\N
130942	lillede	lillede =ede  (SgN  >lill+ede !16_S	et	f	\N
130943	lillede	lillede =ede  (SgG  >lill+ede !16_S	et	f	\N
130946	ainukene	ainukene =ainukene  (SgN  >ainukene !12_S	et	f	\N
130947	ainukene	"ainukene %ainu  )KENE_dS  <ainu ;16_S	et	f	\N
130948	ainukene	"ainukene %ainu  )KENE_dA  <ainus ;07_AS	et	f	\N
130958	palunud	palunud =palu  (PtsPtPs  >paluma !27_V	et	f	\N
130959	palunud	palunud =palunu  (PlN  >palunu !01_S	et	f	\N
130960	palunud	"palunu %palu  )NU_vS  <paluma ;27_V	et	f	\N
130961	palunud	palunud =palunud  (ID  >palunud !41_A	et	f	\N
130962	palunud	"palunud %palu  )NUD_vA  <paluma ;27_V	et	f	\N
130968	laskis	laskis =lask  (IndIpfSg3  >laskma !34_V	et	f	\N
130969	laskis	laskis =laski  (SgIn  >lask !22_S	et	f	\N
130978	võõrases	?võõrases =võõrase  (SgIn  >võõrane !10_A	et	f	\N
130979	võõrases	?võõrases =ases  (SgN  >võõr+ases !09_S	et	f	\N
130980	meeltis	?meeltis =meelti  (IndIpfSg3  >meeltima !28_V	et	f	\N
130981	meeltis	?meeltis =meeltis  (ID  >meeltis !41_DA	et	f	\N
130987	müüjade	### müüjade	et	f	\N
131008	peenarel	?peenarel =peenarel  (SgN  >peenarel !19_S	et	f	\N
131009	peenarel	?peenarel =arel  (SgN  >peen+arel !02_S	et	f	\N
131022	harrastusi	harrastusi =harrastusi  (PlP  >harrastus !11_S	et	f	\N
131023	harrastusi	"harrastus %harrasta  )US_vS  <harrastama ;27_V	et	f	\N
131029	maksimarket	?maksimarket =marke  (SgP  >maksi+marke !06_S	et	f	\N
131056	jõgid	?jõgid =jõgi  (IndPrSg2  >jõgima !27_V	et	f	\N
131057	võõrased	?võõrased =võõrase  (PlN  >võõrane !10_A	et	f	\N
131060	lobisemine	lobisemine =lobisemine  (SgN  >lobisemine !12_S	et	f	\N
131061	lobisemine	"lobisemine %lobise  )MINE_vS  <lobisema ;27_V	et	f	\N
131062	asenda	asenda =asenda  (IndPrPs_  >asendama !27_V	et	f	\N
131063	asenda	asenda =asenda  (ImpPrSg2  >asendama !27_V	et	f	\N
131067	joo	joo =joo  (IndPrPs_  >jooma !38_V	et	f	\N
131068	joo	joo =joo  (ImpPrSg2  >jooma !38_V	et	f	\N
131091	metsi	metsi =metsi  (SgG  >mets !22_S	et	f	\N
131092	metsi	metsi =metsi  (SgP  >mets !22_S	et	f	\N
131094	metsi	metsi =metsi  (SgAdt  >mets !22_S	et	f	\N
131096	metsi	metsi =metsi  (PlP  >mets !22_S	et	f	\N
131099	linnu	linnu =linnu  (SgG  >lind !22_S	et	f	\N
131100	linnu	linnu =linnu  (PlP  >linn !22_S	et	f	\N
131119	lobisemist	lobisemist =lobisemi  (SgEl  >lobisem !02_A	et	f	\N
131120	lobisemist	"lobisem %lobi  )SEM_cA  <lobi ;17_S	et	f	\N
131121	lobisemist	lobisemist =lobisemis  (SgP  >lobisemine !12_S	et	f	\N
131122	lobisemist	"lobisemine %lobise  )MINE_vS  <lobisema ;27_V	et	f	\N
131123	keedsin	?keedsin =keedsi  (IndPrSg1  >keedsima !28_V	et	f	\N
131124	keedsin	?keedsin =keedsin  (SgN  >keedsin !02_S	et	f	\N
131126	maksimarkis	?maksimarkis =maksimarki  (IndIpfSg3  >maksimarkima !28_V	et	f	\N
131127	maksimarkis	?maksimarkis =maksimarkis  (SgN  >maksimarkis !09_S	et	f	\N
131139	käekirjat	?käekirjat =käekirja  (SgP  >käekirjas !02_A	et	f	\N
131140	käekirjat	?käekirjat =käekirja  (SgP  >käekirja !16_S	et	f	\N
131141	käekirjat	?käekirjat =kirja  (SgP  >käe+kirjas !02_A	et	f	\N
131142	käekirjat	?käekirjat =kirja  (SgP  >käe+kirja !16_S	et	f	\N
131143	käekirjat	?käekirjat =kirjat  (SgN  >käe+kirjat !02_S	et	f	\N
131149	küüsi	küüsi =küüs  (PlP  >küüs !14_S	et	f	\N
131150	küüsi	küüsi =küüsi  (ID  >küüsi !41_D	et	f	\N
131151	küüsi	küüsi =küüsi  (ID  >küüsi !41_K	et	f	\N
131184	tormamine	tormamine =tormamine  (SgN  >tormamine !12_S	et	f	\N
131185	tormamine	"tormamine %torma  )MINE_vS  <tormama ;29_V	et	f	\N
131203	surfamisega	?surfamisega =surfamise  (SgKom  >surfamine !12_S	et	f	\N
131211	tõsiasja	tõsiasja =asja  (SgG  >tõsi+asi !24_S	et	f	\N
131212	tõsiasja	tõsiasja =asja  (SgP  >tõsi+asi !24_S	et	f	\N
131213	tõsiasja	tõsiasja =asja  (SgAdt  >tõsi+asi !24_S	et	f	\N
131245	küsimuselemilleta	?küsimuselemilleta =küsimuselemilleta  (IndPrPs_  >küsimuselemilletama !27_V	et	f	\N
131246	küsimuselemilleta	?küsimuselemilleta =küsimuselemilleta  (ImpPrSg2  >küsimuselemilletama !27_V	et	f	\N
131247	pisikese	pisikese =pisikese  (SgG  >pisike !12_A	et	f	\N
131248	pisikese	pisikese =pisikese  (SgG  >pisikene !12_A	et	f	\N
131251	võttes	võttes =võtt  (Ger  >võtma !35_V	et	f	\N
131253	võttes	võttes =võtte  (SgIn  >võte !06_S	et	f	\N
131256	toimivad	toimivad =toimi  (IndPrPl3  >toimima !28_V	et	f	\N
131258	toimivad	toimivad =toimiva  (PlN  >toimiv !02_A	et	f	\N
131259	toimivad	"toimiv %toimi  )V_vA  <toimima ;28_V	et	f	\N
131282	punktist	punktist =punkti  (SgEl  >punkt !22_S	et	f	\N
131284	punktist	punktist =ist  (SgN  >punkt+ist !22_S	et	f	\N
131292	avastamata	avastamata =avasta  (SupAb  >avastama !27_V	et	f	\N
131293	avastamata	avastamata =avastamata  (ID  >avastamata !41_A	et	f	\N
131294	avastamata	"avastamata %avasta  )MATA_vA  <avastama ;27_V	et	f	\N
131301	ebaturvaline	ebaturvaline =turvaline  (SgN  >eba+turvaline !12_A	et	f	\N
131302	ebaturvaline	"eba+turvaline %turva  )LINE_aA  <eba+turb ;22_SA	et	f	\N
131303	ebaturvaline	"eba+turvaline %turva  )LINE_aA  <eba+turv ;22_S	et	f	\N
130965	kerjanud	"kerjanu %kerja  )NU_vS  <kerjama ;29_V	et	f	\N
130966	kerjanud	kerjanud =kerjanud  (ID  >kerjanud !41_A	et	f	\N
130967	kerjanud	"kerjanud %kerja  )NUD_vA  <kerjama ;29_V	et	f	\N
130975	loodusrikase	?loodusrikase =loodusrikase  (SgG  >loodusrikane !12_A	et	f	\N
130976	loodusrikase	?loodusrikase =rikase  (SgG  >loodus+rikane !10_A	et	f	\N
130977	loodusrikase	?loodusrikase =dusrikase  (SgG  >loo+dusrikane !12_A	et	f	\N
131010	kanaali	?kanaali =kanaali  (SgN  >kanaali !16_S	et	f	\N
131011	kanaali	?kanaali =kanaali  (SgG  >kanaali !16_S	et	f	\N
131012	kanaali	?kanaali =kanaali  (SgG  >kanaal !22_S	et	f	\N
131013	kanaali	?kanaali =kanaali  (SgP  >kanaal !22_S	et	f	\N
131014	kanaali	?kanaali =kanaali  (SgAdt  >kanaal !22_S	et	f	\N
131015	kanaali	?kanaali =kanaali  (IndPrPs_  >kanaalima !28_V	et	f	\N
131016	kanaali	?kanaali =kanaali  (ImpPrSg2  >kanaalima !28_V	et	f	\N
131017	kanaali	?kanaali =ali  (SgN  >kana+ali !17_S	et	f	\N
131018	kanaali	?kanaali =ali  (SgG  >kana+ali !17_S	et	f	\N
131019	kanaali	?kanaali =ali  (SgP  >kana+ali !17_S	et	f	\N
131025	olev	olev =ole  (PtsPrPs  >olema !36_V	et	f	\N
131026	olev	olev =olev  (SgN  >olev !02_A	et	f	\N
131027	olev	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
131030	maksimarketis	?maksimarketis =maksimarketi  (SgIn  >maksimarkett !22_S	et	f	\N
131031	maksimarketis	?maksimarketis =maksimarketis  (SgN  >maksimarketis !09_S	et	f	\N
131032	maksimarketis	?maksimarketis =marketi  (SgIn  >maksi+markett !22_S	et	f	\N
131033	maksimarketis	?maksimarketis =marketis  (SgN  >maksi+marketis !11_S	et	f	\N
131048	infinitiivi	infinitiivi =infinitiivi  (SgG  >infinitiiv !22_S	et	f	\N
131049	infinitiivi	infinitiivi =infinitiivi  (SgP  >infinitiiv !22_S	et	f	\N
131051	infinitiivi	infinitiivi =infinitiivi  (SgAdt  >infinitiiv !22_S	et	f	\N
131054	osastavasse	osastavasse =osastava  (SgIll  >osastav !02_A	et	f	\N
131055	osastavasse	"osastav %osasta  )V_vA  <osastama ;27_V	et	f	\N
131081	keetnud	keetnud =keet  (PtsPtPs  >keetma !34_V	et	f	\N
131082	keetnud	keetnud =keetnu  (PlN  >keetnu !01_S	et	f	\N
131083	keetnud	"keetnu %keet  )NU_vS  <keetma ;34_V	et	f	\N
131084	keetnud	keetnud =keetnud  (ID  >keetnud !41_A	et	f	\N
131085	keetnud	"keetnud %keet  )NUD_vA  <keetma ;34_V	et	f	\N
131086	tupu	?tupu =tupu  (SgN  >tupu !16_S	et	f	\N
131087	tupu	?tupu =tupu  (SgG  >tupu !16_S	et	f	\N
131088	tupu	?tupu =tupu  (IndPrPs_  >tupuma !27_V	et	f	\N
131089	tupu	?tupu =tupu  (ImpPrSg2  >tupuma !27_V	et	f	\N
131090	uuid	?uuid =uuid  (SgN  >uuid !02_S	et	f	\N
131101	võõraseid	?võõraseid =võõrase  (PlP  >võõrane !10_A	et	f	\N
131102	võõraseid	?võõraseid =võõrasei  (PlN  >võõrasei !26_S	et	f	\N
131103	võõraseid	?võõraseid =võõrasei  (SgP  >võõrasei !26_S	et	f	\N
131104	võõraseid	?võõraseid =eid  (SgN  >võõras+eid !22_S	et	f	\N
131105	võõraseid	?võõraseid =sei  (PlN  >võõra+sei !26_S	et	f	\N
131107	võõraseid	?võõraseid =sei  (SgP  >võõra+sei !26_S	et	f	\N
131109	võõraseid	?võõraseid =seid  (SgN  >võõra+seid !22_S	et	f	\N
131111	võõraseid	?võõraseid =asei  (PlN  >võõr+asei !26_S	et	f	\N
131113	võõraseid	?võõraseid =asei  (SgP  >võõr+asei !26_S	et	f	\N
131115	võõraseid	?võõraseid =aseid  (SgN  >võõr+aseid !22_S	et	f	\N
131134	võõrasid	?võõrasid =võõra  (PlP  >võõra !16_S	et	f	\N
131135	võõrasid	?võõrasid =võõra  (IndIpfSg2  >võõrama !29_V	et	f	\N
131136	võõrasid	?võõrasid =võõra  (IndIpfPl3  >võõrama !29_V	et	f	\N
131162	mõistetavad	mõistetavad =mõistetava  (PlN  >mõistetav !02_A	et	f	\N
131163	mõistetavad	"mõistetav %mõiste  )TAV_vAS  <mõistma ;34_V	et	f	\N
131173	võlud	võlud =võlu  (PlN  >võlu !17_S	et	f	\N
131174	võlud	võlud =võlu  (IndPrSg2  >võluma !27_V	et	f	\N
131178	kõrvalt	kõrvalt =kõrva  (SgAbl  >kõrv !22_S	et	f	\N
131179	kõrvalt	kõrvalt =kõrvalt  (ID  >kõrvalt !41_DK	et	f	\N
131180	jää	jää =jää  (SgN  >jää !26_S	et	f	\N
131181	jää	jää =jää  (SgG  >jää !26_S	et	f	\N
131182	jää	jää =jää  (IndPrPs_  >jääma !37_V	et	f	\N
131183	jää	jää =jää  (ImpPrSg2  >jääma !37_V	et	f	\N
131186	peast	peast =pea  (SgEl  >pea !26_S	et	f	\N
131187	peast	peast =peas  (SgP  >peane !10_S	et	f	\N
131188	peast	"peane %pea  )NE_aA  <pea ;26_S	et	f	\N
131189	peast	peast =peast  (ID  >peast !41_DK	et	f	\N
131197	egiptuses	?egiptuses =egiptuse  (SgIn  >egiptus !11_S	et	f	\N
131198	surfamist	?surfamist =surfami  (SgEl  >surfami !01_S	et	f	\N
131199	surfamist	?surfamist =surfami  (SgEl  >surfam !02_S	et	f	\N
131200	surfamist	?surfamist =surfamis  (SgP  >surfamis !11_S	et	f	\N
131201	surfamist	?surfamist =surfamis  (SgP  >surfamine !12_S	et	f	\N
131202	surfamist	?surfamist =surfamist  (SgN  >surfamist !22_S	et	f	\N
131206	puhkevatest	puhkevatest =puhkeva  (PlEl  >puhkev !02_A	et	f	\N
131207	puhkevatest	"puhkev %puhke  )V_vA  <puhkema ;27_V	et	f	\N
131208	puhkevatest	puhkevatest =vate  (PlEl  >puhke+vatt !22_S	et	f	\N
131217	ostmisel	ostmisel =ostmise  (SgAd  >ostmine !12?10_S	et	f	\N
131218	ostmisel	"ostmine %ost  )MINE_vS  <ostma ;34_V	et	f	\N
131219	magnetlaineid	magnetlaineid =neid  (SgN  >magnet+lai+neid !22_S	et	f	\N
130982	metroojaama	metroojaama =jaama  (SgG  >metroo+jaam !22_S	et	f	\N
130983	metroojaama	metroojaama =jaama  (SgP  >metroo+jaam !22_S	et	f	\N
130984	metroojaama	metroojaama =jaama  (SgAdt  >metroo+jaam !22_S	et	f	\N
130985	lõunamaalaste	lõunamaalaste =las  (PlG  >lõuna+maa+laps !14_S	et	f	\N
130986	lõunamaalaste	lõunamaalaste =laste  (PlP  >lõuna+maa+last !22_S	et	f	\N
130988	lõunamaalaste	lõunamaalaste =maalas  (PlG  >lõuna+maalane !12?10_S	et	f	\N
131035	pangakaartiga	?pangakaartiga =tiga  (SgN  >panga+kaar+tiga !17_S	et	f	\N
131036	pangakaartiga	?pangakaartiga =tiga  (SgG  >panga+kaar+tiga !17_S	et	f	\N
131037	pangakaartiga	?pangakaartiga =tiga  (SgP  >panga+kaar+tiga !17_S	et	f	\N
131039	väikevenda	väikevenda =venda  (SgP  >väike+vend !22_S	et	f	\N
131040	väikevenda	väikevenda =venda  (SgAdt  >väike+vend !22_S	et	f	\N
131046	sobiva	sobiva =sobiva  (SgG  >sobiv !02_A	et	f	\N
131047	sobiva	"sobiv %sobi  )V_vA  <sobima ;27_V	et	f	\N
131058	ainsuse	ainsuse =ainsuse  (SgG  >ainsus !11~09_S	et	f	\N
131059	ainsuse	"ainsus %ainsa  )US_aS  <ainus ;03_AS	et	f	\N
131064	kohvikust	kohvikust =kohviku  (SgEl  >kohvik !02_S	et	f	\N
131065	kohvikust	kohvikust =us  (SgP  >kohvik+uks !14_S	et	f	\N
131066	kohvikust	kohvikust =kus  (SgP  >kohvi+kusi !20_S	et	f	\N
131069	ostasin	?ostasin =osta  (IndIpfSg1  >ostama !29_V	et	f	\N
131070	ostasin	?ostasin =ostasin  (SgN  >ostasin !19_S	et	f	\N
131073	joonud	joonud =joo  (PtsPtPs  >jooma !38_V	et	f	\N
131074	joonud	joonud =joonu  (PlN  >joonu !01_S	et	f	\N
131075	joonud	"joonu %joo  )NU_vS  <jooma ;38_V	et	f	\N
131076	joonud	joonud =joonu  (PlN  >joonu !06_S	et	f	\N
131077	joonud	joonud =joonud  (ID  >joonud !41_A	et	f	\N
131078	joonud	"joonud %joo  )NUD_vA  <jooma ;38_V	et	f	\N
131125	uud	?uud =uud  (SgN  >uud !22_S	et	f	\N
131128	tubaid	?tubaid =tubai  (PlN  >tubai !26_S	et	f	\N
131129	tubaid	?tubaid =tubai  (SgP  >tubai !26_S	et	f	\N
131130	tubaid	?tubaid =tubaid  (SgN  >tubaid !22_S	et	f	\N
131137	keelesid	?keelesid =keele  (IndIpfSg2  >keelema !27_V	et	f	\N
131138	keelesid	?keelesid =keele  (IndIpfPl3  >keelema !27_V	et	f	\N
131146	sadu	sadu =sadu  (SgN  >sadu !18_S	et	f	\N
131147	sadu	sadu =sadu  (SgP  >sadu !18_S	et	f	\N
131148	sadu	sadu =sadu  (PlP  >sada !18_N	et	f	\N
131154	mandrilt	mandrilt =mandri  (SgAbl  >mander !02_S	et	f	\N
131155	mandrilt	mandrilt =mandri  (SgAbl  >manner !03_S	et	f	\N
131195	dahabi	?dahabi =dahabi  (SgN  >dahabi !01_S	et	f	\N
131196	dahabi	?dahabi =dahabi  (SgG  >dahabi !01_S	et	f	\N
131204	ümbritsevatest	ümbritsevatest =ümbritseva  (PlEl  >ümbritsev !02_A	et	f	\N
131205	ümbritsevatest	"ümbritsev %ümbritse  )V_vA  <ümbritsema ;27_V	et	f	\N
131228	kehtestatud	kehtestatud =kehtesta  (PtsPtIps  >kehtestama !27_V	et	f	\N
131229	kehtestatud	kehtestatud =kehtestatu  (PlN  >kehtestatu !01_S	et	f	\N
131230	kehtestatud	"kehtestatu %kehtesta  )TU1_vS  <kehtestama ;27_V	et	f	\N
131231	kehtestatud	kehtestatud =kehtestatud  (ID  >kehtestatud !41_A	et	f	\N
131232	kehtestatud	"kehtestatud %kehtesta  )TUD_vA  <kehtestama ;27_V	et	f	\N
131235	arutletud	arutletud =arutle  (PtsPtIps  >arutlema !27_V	et	f	\N
131236	arutletud	arutletud =arutletu  (PlN  >arutletu !01_S	et	f	\N
131237	arutletud	"arutletu %arutle  )TU1_vS  <arutlema ;27_V	et	f	\N
131238	arutletud	arutletud =arutletud  (ID  >arutletud !41_A	et	f	\N
131239	arutletud	"arutletud %arutle  )TUD_vA  <arutlema ;27_V	et	f	\N
131257	mugavused	mugavused =mugavuse  (PlN  >mugavus !11_S	et	f	\N
131260	mugavused	"mugavus %mugava  )US_aS  <mugav ;02_A	et	f	\N
131272	pinevuseta	pinevuseta =pinevuse  (SgAb  >pinevus !11_S	et	f	\N
131273	pinevuseta	"pinevus %pineva  )US_aS  <pinev ;02_A	et	f	\N
131297	kaubavahetus	kaubavahetus =vahetu  (SgIn  >kauba+vahetu !01_A	et	f	\N
131298	kaubavahetus	"kauba+vahetu %vahe  )TU2_kA  <kauba+vahe ;16_S	et	f	\N
131299	kaubavahetus	kaubavahetus =vahetus  (SgN  >kauba+vahetus !11_S	et	f	\N
131300	kaubavahetus	"kauba+vahetus %vahe  )TUS2_aS  <kauba+vahe ;16_S	et	f	\N
131308	mugavustega	mugavustega =mugavus  (PlKom  >mugavus !11_S	et	f	\N
131309	mugavustega	"mugavus %mugava  )US_aS  <mugav ;02_A	et	f	\N
131317	hoolitsevad	hoolitsevad =hoolitse  (IndPrPl3  >hoolitsema !27_V	et	f	\N
131318	hoolitsevad	hoolitsevad =hoolitseva  (PlN  >hoolitsev !02_A	et	f	\N
131319	hoolitsevad	"hoolitsev %hoolitse  )V_vA  <hoolitsema ;27_V	et	f	\N
131320	asendamatu	asendamatu =asendamatu  (SgN  >asendamatu !01_A	et	f	\N
131321	asendamatu	"asendamatu %asenda  )MATU_vA  <asendama ;27_V	et	f	\N
131322	asendamatu	asendamatu =asendamatu  (SgG  >asendamatu !01_A	et	f	\N
131349	päevagi	päevagi =päeva  (SgG^  >päev !22_S	et	f	\N
131350	päevagi	päevagi =päeva  (SgP^  >päev !22_S	et	f	\N
131352	päevagi	päevagi =päeva  (SgAdt^  >päev !22_S	et	f	\N
131353	mugavusega	mugavusega =mugavuse  (SgKom  >mugavus !11_S	et	f	\N
131354	mugavusega	"mugavus %mugava  )US_aS  <mugav ;02_A	et	f	\N
131385	saamatud	saamatud =saamatu  (PlN  >saamatu !01_A	et	f	\N
131386	saamatud	"saamatu %saa  )MATU_vA  <saama ;37_V	et	f	\N
131387	saamatud	"saamatu %saama  )TU2_kA  <saam ;22_S	et	f	\N
131388	floora	floora =floora  (SgN  >floora !16_S	et	f	\N
131389	floora	floora =floora  (SgG  >floora !16_S	et	f	\N
131172	ümbritseva	"ümbritsev %ümbritse  )V_vA  <ümbritsema ;27_V	et	f	\N
131175	lõputu	lõputu =lõputu  (SgN  >lõputu !01_A	et	f	\N
131176	lõputu	"lõputu %lõpu  )TU2_kA  <lõpp ;22_SA	et	f	\N
131177	lõputu	lõputu =lõputu  (SgG  >lõputu !01_A	et	f	\N
131209	tunnista	tunnista =tunnista  (IndPrPs_  >tunnistama !27_V	et	f	\N
131210	tunnista	tunnista =tunnista  (ImpPrSg2  >tunnistama !27_V	et	f	\N
131214	võimsam	võimsam =võimsam  (SgN  >võimsam !02_A	et	f	\N
131215	võimsam	"võimsam %võimsa  )M_cA  <võimas ;03_A	et	f	\N
131216	võimsam	"võimsam %võimsa  )M_cA  <võimas ;05_A	et	f	\N
131223	vägistamisega	vägistamisega =vägistamise  (SgKom  >vägistamine !12_S	et	f	\N
131224	vägistamisega	"vägistamine %vägista  )MINE_vS  <vägistama ;27_V	et	f	\N
131233	lõputud	lõputud =lõputu  (PlN  >lõputu !01_A	et	f	\N
131234	lõputud	"lõputu %lõpu  )TU2_kA  <lõpp ;22_SA	et	f	\N
131240	teeksid	teeksid =tee  (KndPrSg2  >tegema !28_V	et	f	\N
131241	teeksid	teeksid =tee  (KndPrPl3  >tegema !28_V	et	f	\N
131242	päevakohane	päevakohane =kohane  (SgN  >päeva+kohane !10_A	et	f	\N
131243	päevakohane	"päeva+kohane %koha  )NE_aA  <päeva+koha ;17_S	et	f	\N
131244	päevakohane	"päeva+kohane %koha  )NE_aA  <päeva+koht ;22_S	et	f	\N
131254	arvesse	arvesse =arve  (SgIll  >arve !06_S	et	f	\N
131255	arvesse	arvesse =arve  (PlIll  >arv !22_S	et	f	\N
131261	kõrgepinge	kõrgepinge =pinge  (SgN  >kõrge+pinge !06_S	et	f	\N
131262	kõrgepinge	kõrgepinge =pinge  (SgG  >kõrge+pinge !06_S	et	f	\N
131263	kõrgepinge	kõrgepinge =pinge  (PlP  >kõrge+ping !22_S	et	f	\N
131264	kujutaks	kujutaks =kujuta  (KndPrPs  >kujutama !27_V	et	f	\N
131265	kujutaks	kujutaks =taks  (SgN  >kuju+taks !22_S	et	f	\N
131266	surfata	?surfata =surfa  (SgAb  >surfa !16_S	et	f	\N
131267	surfata	?surfata =surfata  (IndPrPs_  >surfatama !27_V	et	f	\N
131268	surfata	?surfata =surfata  (ImpPrSg2  >surfatama !27_V	et	f	\N
131304	nüüdisaegsete	nüüdisaegsete =sete  (SgN  >nüüdis+aeg+sete !06_S	et	f	\N
131305	nüüdisaegsete	nüüdisaegsete =aegse  (PlG  >nüüdis+aegne !02_A	et	f	\N
131310	silmi	silmi =silmi  (ID  >silmi !41_D	et	f	\N
131311	silmi	silmi =silmi  (SgG  >silm !22_S	et	f	\N
131312	silmi	silmi =silmi  (SgP  >silm !22_S	et	f	\N
131313	silmi	silmi =silmi  (SgAdt  >silm !22_S	et	f	\N
131314	silmi	silmi =silmi  (PlP  >silm !22_S	et	f	\N
131323	kogumiseks	kogumiseks =kogumise  (SgTr  >kogumine !12_S	et	f	\N
131324	kogumiseks	"kogumine %kogu  )MINE_vS  <koguma ;27_V	et	f	\N
131325	kogumiseks	"kogumine %kogumi  )NE_aA  <kogum ;02_S	et	f	\N
131331	muudetud	muudetud =muude  (PtsPtIps  >muutma !34_V	et	f	\N
131332	muudetud	muudetud =muudetu  (PlN  >muudetu !01_AS	et	f	\N
131333	muudetud	"muudetu %muude  )TU1_vS  <muutma ;34_V	et	f	\N
131334	muudetud	muudetud =muudetud  (ID  >muudetud !41_A	et	f	\N
131335	muudetud	"muudetud %muude  )TUD_vA  <muutma ;34_V	et	f	\N
131336	tehnoloogiliseks	tehnoloogiliseks =tehnoloogilise  (SgTr  >tehnoloogiline !12_A	et	f	\N
131337	tehnoloogiliseks	"tehnoloogiline %tehnoloogi  )LINE_aA  <tehnoloog ;22_S	et	f	\N
131338	tehnoloogiliseks	tehnoloogiliseks =loogilise  (SgTr  >tehno+loogiline !12_A	et	f	\N
131342	tehnoloogiliseks	"tehno+loogiline %loogi  )LINE_aA  <tehno+loog ;22_S	et	f	\N
131347	pikemat	pikemat =pikema  (SgP  >pikem !02_A	et	f	\N
131348	pikemat	"pikem %pike  )M_cA  <pikk ;22_AS	et	f	\N
131361	lihtsamaks	lihtsamaks =lihtsama  (SgTr  >lihtsam !02_A	et	f	\N
131362	lihtsamaks	"lihtsam %lihtsa  )M_cA  <lihtne ;02_A	et	f	\N
131363	lihtsamaks	lihtsamaks =maks  (SgN  >lihtsa+maks !22_S	et	f	\N
131384	materjaalsete	?materjaalsete =materjaalse  (PlG  >materjaalne !02_A	et	f	\N
131392	puutu	puutu =puutu  (SgN  >puutu !01_A	et	f	\N
131393	puutu	"puutu %puu  )TU2_kA  <puu ;26_S	et	f	\N
131394	puutu	puutu =puutu  (SgG  >puutu !01_A	et	f	\N
131395	puutu	puutu =puutu  (IndPrPs_  >puutuma !27_V	et	f	\N
131396	puutu	puutu =puutu  (ImpPrSg2  >puutuma !27_V	et	f	\N
131411	täielikult	täielikult =täieliku  (SgAbl  >täielik !25_A	et	f	\N
131412	täielikult	täielikult =täielikult  (ID  >täielikult !41_D	et	f	\N
131413	täielikult	"täielikult %täieliku  )LT_mD  <täielik ;25_A	et	f	\N
131416	elavadki	elavadki =ela  (IndPrPl3^  >elama !27_V	et	f	\N
131419	elavadki	elavadki =elava  (PlN^  >elav !02_A	et	f	\N
131420	elavadki	"elav %ela  )V_vA^  <elama ;27_V	et	f	\N
131440	kasvatasid	kasvatasid =kasvata  (IndIpfSg2  >kasvatama !27_V	et	f	\N
131441	kasvatasid	kasvatasid =kasvata  (IndIpfPl3  >kasvatama !27_V	et	f	\N
131462	derigent	?derigent =derigent  (SgN  >derigent !22_S	et	f	\N
131463	d	### d	et	f	\N
131466	hiir	hiir =hiir  (SgN  >hiir !13_S	et	f	\N
131467	hiir	hiir =hiir  (SgN  >hiir !22_A	et	f	\N
131468	riigipööre	?riigipööre =riigipööre  (SgN  >riigipööre !16_S	et	f	\N
131469	riigipööre	?riigipööre =riigipööre  (SgG  >riigipööre !16_S	et	f	\N
131470	riigipööre	?riigipööre =riigipööre  (PlP  >riigipöör !22_S	et	f	\N
131490	rahvaste	rahvaste =rahvas  (PlG  >rahvas !07_S	et	f	\N
131491	rahvaste	rahvaste =rahvas  (PlG  >rahvane !10_A	et	f	\N
131492	rahvaste	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
131502	parteine	parteine =parteine  (SgN  >parteine !12~10_A	et	f	\N
131192	pühitud	"pühitu %pühi  )TU1_vS  <pühkima ;28_V	et	f	\N
131193	pühitud	pühitud =pühitud  (ID  >pühitud !41_A	et	f	\N
131194	pühitud	"pühitud %pühi  )TUD_vA  <pühkima ;28_V	et	f	\N
131221	tütarlapse	tütarlapse =lapse  (SgG  >tütar+laps !14_S	et	f	\N
131222	tütarlapse	tütarlapse =lapse  (PlP  >tütar+laps !22_S	et	f	\N
131225	käituvad	käituvad =käitu  (IndPrPl3  >käituma !27_V	et	f	\N
131226	käituvad	käituvad =käituva  (PlN  >käituv !02_A	et	f	\N
131227	käituvad	"käituv %käitu  )V_vA  <käituma ;27_V	et	f	\N
131249	lap-topi	lap-topi =topi  (SgG  >lap-topp !22_S	et	f	\N
131250	lap-topi	lap-topi =topi  (IndPrPs_  >lap-toppima !28_V	et	f	\N
131252	lap-topi	lap-topi =topi  (ImpPrSg2  >lap-toppima !28_V	et	f	\N
131277	kujutakski	kujutakski =kujuta  (KndPrPs^  >kujutama !27_V	et	f	\N
131278	kujutakski	kujutakski =taks  (SgN^  >kuju+taks !22_S	et	f	\N
131281	mustemad	mustemad =mustema  (PlN  >mustem !02_A	et	f	\N
131283	mustemad	"mustem %muste  )M_cA  <must ;22_AS	et	f	\N
131285	mustemad	mustemad =ema  (PlN  >must+ema !17_S	et	f	\N
131290	hobuseid	hobuseid =hobuse  (PlP  >hobune !10_S	et	f	\N
131291	hobuseid	"hobune %hobu  )NE_aA  <hobu ;17_S	et	f	\N
131295	hobusega	hobusega =hobuse  (SgKom  >hobune !10_S	et	f	\N
131296	hobusega	"hobune %hobu  )NE_aA  <hobu ;17_S	et	f	\N
131328	hinnata	hinnata =hinna  (SgAb  >hind !22_S	et	f	\N
131329	hinnata	hinnata =hinna  (Inf  >hindama !29_V	et	f	\N
131330	hinnata	hinnata =hinna  (IndPrIps_  >hindama !29_V	et	f	\N
131351	vastupidada	### vastupidada	et	f	\N
131366	kõnni	kõnni =kõnni  (SgG  >kõnd !22_S	et	f	\N
131367	kõnni	kõnni =kõnni  (IndPrPs_  >kõndima !28_V	et	f	\N
131368	kõnni	kõnni =kõnni  (ImpPrSg2  >kõndima !28_V	et	f	\N
131373	mugavamalt	mugavamalt =mugavama  (SgAbl  >mugavam !02_A	et	f	\N
131374	mugavamalt	"mugavam %mugava  )M_cA  <mugav ;02_A	et	f	\N
131377	mugavamalt	mugavamalt =mugavamalt  (ID  >mugavamalt !41_D	et	f	\N
131378	mugavamalt	"mugavamalt %mugava  )MALT_mD  <mugav ;02_A	et	f	\N
131397	ronides	ronides =roni  (PlIn  >roni !17_S	et	f	\N
131398	ronides	ronides =roni  (Ger  >ronima !27_V	et	f	\N
131399	kõrgustesse	kõrgustesse =kõrgus  (PlIll  >kõrgus !11~09_S	et	f	\N
131400	kõrgustesse	"kõrgus %kõrge  )US_aS  <kõrge ;01_A	et	f	\N
131401	kõrgustesse	kõrgustesse =kõrgus  (PlIll  >kõrgune !10~12_A	et	f	\N
131402	kõrgustesse	kõrgustesse =us  (PlIll  >kõrg+uks !14_S	et	f	\N
131403	püüdes	püüdes =püü  (PlIn  >püü !26_S	et	f	\N
131404	püüdes	püüdes =püüd  (Ger  >püüdma !34_V	et	f	\N
131405	püüdes	püüdes =püüde  (SgIn  >püüe !06_S	et	f	\N
131417	pettes	pettes =pett  (Ger  >petma !35_V	et	f	\N
131418	pettes	pettes =pette  (SgIn  >pete !06_S	et	f	\N
131426	rahvasuugi	rahvasuugi =suu  (SgN^  >rahva+suu !26_S	et	f	\N
131427	rahvasuugi	rahvasuugi =suu  (SgG^  >rahva+suu !26_S	et	f	\N
131436	vaikivad	vaikivad =vaiki  (IndPrPl3  >vaikima !27_V	et	f	\N
131437	vaikivad	vaikivad =vaikiva  (PlN  >vaikiv !02_A	et	f	\N
131438	vaikivad	"vaikiv %vaiki  )V_vA  <vaikima ;27_V	et	f	\N
131439	vaikivad	vaikivad =iva  (PlN  >vaik+iva !17_S	et	f	\N
131446	linde	linde =linde  (SgG  >linne !06_S	et	f	\N
131447	linde	linde =linde  (PlP  >lind !22_S	et	f	\N
131450	meenutavad	meenutavad =meenuta  (IndPrPl3  >meenutama !27_V	et	f	\N
131451	meenutavad	meenutavad =meenutava  (PlN  >meenutav !02_A	et	f	\N
131452	meenutavad	"meenutav %meenu  )TAV_vAS  <meenuma ;27_V	et	f	\N
131453	meenutavad	"meenutav %meenuta  )V_vA  <meenutama ;27_V	et	f	\N
131461	ernesaks	?ernesaks =ernesa  (SgTr  >ernesa !01_S	et	f	\N
131472	päevil	päevil =päevi  (SgAd  >päev !22_S	et	f	\N
131473	päevil	päevil =päevi  (PlAd  >päev !22_S	et	f	\N
131479	nendesse	nendesse =nen  (PlIll  >see !00_P	et	f	\N
131480	nendesse	nendesse =nen  (PlIll  >tema !00_P	et	f	\N
131485	keelasid	keelasid =keela  (IndIpfSg2  >keelama !29_V	et	f	\N
131486	keelasid	keelasid =keela  (IndIpfPl3  >keelama !29_V	et	f	\N
131513	koondunud	koondunud =koondu  (PtsPtPs  >koonduma !27_V	et	f	\N
131515	koondunud	koondunud =koondunu  (PlN  >koondunu !01_S	et	f	\N
131517	koondunud	"koondunu %koondu  )NU_vS  <koonduma ;27_V	et	f	\N
131518	koondunud	koondunud =koondunud  (ID  >koondunud !41_A	et	f	\N
131519	koondunud	"koondunud %koondu  )NUD_vA  <koonduma ;27_V	et	f	\N
131520	kultuuripeod	kultuuripeod =peo  (PlN  >kultuuri+pidu !18_S	et	f	\N
131521	kultuuripeod	kultuuripeod =peo  (PlN  >kultuuri+peo !26_S	et	f	\N
131522	kultuuripeod	kultuuripeod =peo  (SgP  >kultuuri+peo !26_S	et	f	\N
131533	1940ndatel	?ndatel =ndate  (PlAd  >ndatt !22_S	et	f	\N
131534	1940ndatel	?ndatel =ndatel  (SgN  >ndatel !02_S	et	f	\N
131536	konfliktuseteooria	?konfliktuseteooria =konfliktuseteooria  (SgN  >konfliktuseteooria !01_S	et	f	\N
131537	konfliktuseteooria	?konfliktuseteooria =konfliktuseteooria  (SgG  >konfliktuseteooria !01_S	et	f	\N
131538	helge	helge =helge  (SgN  >helge !01_A	et	f	\N
131539	helge	helge =helge  (SgG  >helge !01_A	et	f	\N
131545	erka	?erka =erka  (SgN  >erka !16_S	et	f	\N
131546	erka	?erka =erka  (SgG  >erka !16_S	et	f	\N
131547	erka	?erka =erka  (IndPrPs_  >erkama !29_V	et	f	\N
131549	erka	?erka =erka  (ImpPrSg2  >erkama !29_V	et	f	\N
131220	magnetlaineid	magnetlaineid =laine  (PlP  >magnet+laine !06_S	et	f	\N
131269	enamusele	enamusele =enamuse  (SgAll  >enamus !11_S	et	f	\N
131270	enamusele	"enamus %enama  )US_aS  <enam ;02_A	et	f	\N
131271	enamusele	enamusele =use  (PlAll  >enam+usk !22_S	et	f	\N
131274	tsivilisatsiooni	tsivilisatsiooni =tsivilisatsiooni  (SgG  >tsivilisatsioon !22_S	et	f	\N
131275	tsivilisatsiooni	tsivilisatsiooni =tsivilisatsiooni  (SgP  >tsivilisatsioon !22_S	et	f	\N
131276	tsivilisatsiooni	tsivilisatsiooni =tsivilisatsiooni  (SgAdt  >tsivilisatsioon !22_S	et	f	\N
131279	lohakamad	lohakamad =lohakama  (PlN  >lohakam !02_A	et	f	\N
131280	lohakamad	"lohakam %lohaka  )M_cA  <lohakas ;02_A	et	f	\N
131286	kaasaja	kaasaja =kaasaja  (SgN  >kaasaja !01_S	et	f	\N
131287	kaasaja	"kaasaja %kaasa  )JA_vS  <kaasama ;29_V	et	f	\N
131288	kaasaja	kaasaja =kaasaja  (SgG  >kaasaja !01_S	et	f	\N
131289	kaasaja	kaasaja =aja  (SgG  >kaas+aeg !22_S	et	f	\N
131306	luksusteta	luksusteta =luksus  (PlAb  >luksus !11~09_S	et	f	\N
131307	luksusteta	luksusteta =us  (PlAb  >luks+uks !14_S	et	f	\N
131355	ettekujutada	?ettekujutada =ettekujuta  (Inf  >ettekujutama !27_V	et	f	\N
131356	ettekujutada	?ettekujutada =tada  (SgN  >ette+kuju+tada !17_S	et	f	\N
131357	ettekujutada	?ettekujutada =tada  (SgG  >ette+kuju+tada !17_S	et	f	\N
131358	ettekujutada	?ettekujutada =tada  (SgP  >ette+kuju+tada !17_S	et	f	\N
131369	kiiremini	kiiremini =kiiremi  (SgTer  >kiirem !02_A	et	f	\N
131370	kiiremini	"kiirem %kiire  )M_cA  <kiire ;01_A	et	f	\N
131371	kiiremini	"kiirem %kiire  )M_cA  <kiire ;06_AS	et	f	\N
131372	kiiremini	kiiremini =mi  (SgTer  >kiire+mi !26_S	et	f	\N
131375	kiiremini	kiiremini =mini  (SgN  >kiire+mini !17~16_S	et	f	\N
131376	kiiremini	kiiremini =mini  (SgG  >kiire+mini !17~16_S	et	f	\N
131379	kiiremini	kiiremini =mini  (SgP  >kiire+mini !17_S	et	f	\N
131380	rahalisiressursse	?rahalisiressursse =rahalisiressursse  (SgG  >rahalisiressursne !02_A	et	f	\N
131381	liigselt	liigselt =liigse  (SgAbl  >liigne !02_A	et	f	\N
131382	liigselt	liigselt =liigselt  (ID  >liigselt !41_D	et	f	\N
131383	liigselt	"liigselt %liigse  )LT_mD  <liigne ;02_A	et	f	\N
131406	võita	võita =või  (SgAb  >või !26_S	et	f	\N
131407	võita	võita =või  (IndPrIps_  >võidma !34_V	et	f	\N
131408	võita	võita =võit  (Inf  >võitma !34_V	et	f	\N
131409	võita	võita =võita  (IndPrPs_  >võitama !27_V	et	f	\N
131410	võita	võita =võita  (ImpPrSg2  >võitama !27_V	et	f	\N
131431	ohte	ohte =ohte  (SgG  >ohe !06_S	et	f	\N
131432	ohte	ohte =ohte  (PlP  >oht !22_S	et	f	\N
131456	folklorist	folklorist =folklorist  (SgN  >folklorist !22_S	et	f	\N
131457	folklorist	folklorist =lori  (SgEl  >folk+lori !17_S	et	f	\N
131471	kontakteeruda	?kontakteeruda =kontakteeru  (Inf  >kontakteeruma !27_V	et	f	\N
131483	purustused	purustused =purustuse  (PlN  >purustus !11_S	et	f	\N
131484	purustused	"purustus %purusta  )US_vS  <purustama ;27_V	et	f	\N
131504	draama	draama =draama  (SgN  >draama !16_S	et	f	\N
131505	draama	draama =draama  (SgG  >draama !16_S	et	f	\N
131508	lubatud	lubatud =luba  (PtsPtIps  >lubama !27_V	et	f	\N
131509	lubatud	lubatud =lubatu  (PlN  >lubatu !01_AS	et	f	\N
131510	lubatud	"lubatu %luba  )TU1_vS  <lubama ;27_V	et	f	\N
131511	lubatud	lubatud =lubatud  (ID  >lubatud !41_A	et	f	\N
131512	lubatud	"lubatud %luba  )TUD_vA  <lubama ;27_V	et	f	\N
131523	1972a	### 1972a	et	f	\N
131527	tooming	?tooming =tooming  (SgN  >tooming !02_S	et	f	\N
131528	tooming	?tooming =ing  (SgN  >toom+ing !22_S	et	f	\N
131529	tooming	?tooming =ming  (SgN  >too+ming !22_S	et	f	\N
131540	vastandus	vastandus =vastandu  (IndIpfSg3  >vastanduma !27_V	et	f	\N
131541	vastandus	vastandus =vastandus  (SgN  >vastandus !11_S	et	f	\N
131542	vastandus	"vastandus %vastanda  )US_vS  <vastandama ;27_V	et	f	\N
131548	250-liikmelisse	-liikmelisse =liikmelis  (SgAdt  >-liikmeline !12_A	et	f	\N
131550	250-liikmelisse	"-liikmeline %liikme  )LINE_aA  <-liige ;05_S	et	f	\N
131566	barbarus	?barbarus =barbaru  (SgIn  >barbaru !01_S	et	f	\N
131568	barbarus	?barbarus =barbaru  (IndIpfSg3  >barbaruma !27_V	et	f	\N
131569	barbarus	?barbarus =barbarus  (SgN  >barbarus !11_S	et	f	\N
131581	jegorjevski	?jegorjevski =jegorjevski  (IndPrPs_  >jegorjevskima !28_V	et	f	\N
131583	jegorjevski	?jegorjevski =jegorjevski  (ImpPrSg2  >jegorjevskima !28_V	et	f	\N
131584	jegorjevski	?jegorjevski =jegorjevs  (SgN^  >jegorjevs !22_S	et	f	\N
131586	keskkomitee	keskkomitee =komitee  (SgN  >kesk+komitee !26_S	et	f	\N
131587	keskkomitee	keskkomitee =komitee  (SgG  >kesk+komitee !26_S	et	f	\N
131631	antarktikas	?antarktikas =antarktika  (SgIn  >antarktika !01_S	et	f	\N
131632	antarktikas	?antarktikas =antarktika  (SgIn  >antarktikas !02_A	et	f	\N
131633	antarktikas	?antarktikas =antarktikas  (SgN  >antarktikas !02_A	et	f	\N
131656	puurimised	puurimised =puurimise  (PlN  >puurimine !12_S	et	f	\N
131657	puurimised	"puurimine %puuri  )MINE_vS  <puurima ;28_V	et	f	\N
131662	hüdrotermiliste	hüdrotermiliste =termilis  (PlG  >hüdro+termiline !12_A	et	f	\N
131663	hüdrotermiliste	"hüdro+termiline %termi  )LINE_aA  <hüdro+term ;22_S	et	f	\N
131664	vesistu	vesistu =vesistu  (SgN  >vesistu !01_S	et	f	\N
131665	vesistu	vesistu =vesistu  (SgG  >vesistu !01_S	et	f	\N
131666	vesistu	vesistu =vesistu  (IndPrPs_  >vesistuma !27_V	et	f	\N
131315	pesta	pesta =pes  (IndPrIps_  >pesema !36_V	et	f	\N
131316	pesta	pesta =pes  (Inf  >pesema !36_V	et	f	\N
131326	kätetöö	kätetöö =töö  (SgN  >käte+töö !26_S	et	f	\N
131327	kätetöö	kätetöö =töö  (SgG  >käte+töö !26_S	et	f	\N
131339	kujutagi	kujutagi =tagi  (SgN  >kuju+tagi !17_S	et	f	\N
131340	kujutagi	kujutagi =tagi  (SgG  >kuju+tagi !17_S	et	f	\N
131341	kujutagi	kujutagi =tagi  (SgP  >kuju+tagi !17_S	et	f	\N
131343	kujutagi	kujutagi =kuju  (SgAb^  >kuju !17_S	et	f	\N
131344	kujutagi	kujutagi =kujuta  (IndPrPs_^  >kujutama !27_V	et	f	\N
131345	kujutagi	kujutagi =kujuta  (ImpPrSg2^  >kujutama !27_V	et	f	\N
131346	oam	?oam =oam  (SgN  >oam !22_S	et	f	\N
131359	olegi	olegi =ole  (IndPrPs_^  >olema !36_V	et	f	\N
131360	olegi	olegi =ole  (ImpPrSg2^  >olema !36_V	et	f	\N
131364	laisaks	laisaks =laisa  (SgTr  >laisk !22_A	et	f	\N
131365	laisaks	laisaks =saks  (SgN  >lai+saks !23?22_S	et	f	\N
131414	usaldust	usaldust =usaldus  (SgP  >usaldus !11_S	et	f	\N
131415	usaldust	"usaldus %usalda  )US_vS  <usaldama ;27_V	et	f	\N
131433	kurjust	kurjust =kurjus  (SgP  >kurjus !11~09_S	et	f	\N
131434	kurjust	"kurjus %kurj  )US_aS  <kuri ;24_A	et	f	\N
131458	arhiivi	arhiivi =arhiivi  (SgG  >arhiiv !22_S	et	f	\N
131459	arhiivi	arhiivi =arhiivi  (SgP  >arhiiv !22_S	et	f	\N
131460	arhiivi	arhiivi =arhiivi  (SgAdt  >arhiiv !22_S	et	f	\N
131477	kandjana	kandjana =kandja  (SgEs  >kandja !01_S	et	f	\N
131478	kandjana	"kandja %kand  )JA_vS  <kandma ;34_V	et	f	\N
131493	okupatsiooni	okupatsiooni =okupatsiooni  (SgG  >okupatsioon !22_S	et	f	\N
131494	okupatsiooni	okupatsiooni =okupatsiooni  (SgP  >okupatsioon !22_S	et	f	\N
131495	okupatsiooni	okupatsiooni =okupatsiooni  (SgAdt  >okupatsioon !22_S	et	f	\N
131496	kirjanikutele	?kirjanikutele =kirjanikute  (PlAll  >kirjanikutt !22_S	et	f	\N
131497	kirjanikutele	?kirjanikutele =kirjanikutele  (IndPrPs_  >kirjanikutelema !36_V	et	f	\N
131498	kirjanikutele	?kirjanikutele =kirjanikutele  (ImpPrSg2  >kirjanikutelema !36_V	et	f	\N
131499	kirjanikutele	?kirjanikutele =nikute  (PlAll  >kirja+nikutt !22_S	et	f	\N
131506	kirjanikut	?kirjanikut =niku  (SgP  >kirja+niku !16_S	et	f	\N
131507	kirjanikut	?kirjanikut =nikut  (SgN  >kirja+nikut !02_S	et	f	\N
131530	populaarseim	populaarseim =populaarseim  (SgN  >populaarseim !02_A	et	f	\N
131531	populaarseim	"populaarseim %populaarse  )IM_sA  <populaarne ;02_A	et	f	\N
131532	populaarseim	populaarseim =seim  (SgN  >populaar+seim !22_S	et	f	\N
131559	ernesaksa	?ernesaksa =ernesaksa  (SgN  >ernesaksa !16_S	et	f	\N
131560	ernesaksa	?ernesaksa =ernesaksa  (SgG  >ernesaksa !16_S	et	f	\N
131563	arvukalt	arvukalt =arvuka  (SgAbl  >arvukas !02_A	et	f	\N
131564	arvukalt	arvukalt =arvukalt  (ID  >arvukalt !41_D	et	f	\N
131565	arvukalt	"arvukalt %arvuka  )LT_mD  <arvukas ;02_A	et	f	\N
131572	adamson	?adamson =adamson  (SgN  >adamson !19_S	et	f	\N
131574	lepnurm	?lepnurm =lepnurm  (SgN  >lepnurm !22_S	et	f	\N
131597	stalinismi	?stalinismi =stalinismi  (SgG  >stalinism !22_S	et	f	\N
131598	stalinismi	?stalinismi =stalinismi  (SgP  >stalinism !22_S	et	f	\N
131599	stalinismi	?stalinismi =stalinismi  (SgAdt  >stalinism !22_S	et	f	\N
131600	stalinismi	?stalinismi =stalinismi  (IndPrPs_  >stalinismima !28_V	et	f	\N
131601	stalinismi	?stalinismi =stalinismi  (ImpPrSg2  >stalinismima !28_V	et	f	\N
131609	allutatud	allutatud =alluta  (PtsPtIps  >allutama !27_V	et	f	\N
131610	allutatud	allutatud =allutatu  (PlN  >allutatu !01_S	et	f	\N
131611	allutatud	"allutatu %alluta  )TU1_vS  <allutama ;27_V	et	f	\N
131612	allutatud	allutatud =allutatud  (ID  >allutatud !41_A	et	f	\N
131613	allutatud	"allutatud %alluta  )TUD_vA  <allutama ;27_V	et	f	\N
131622	varrandi	?varrandi =varrandi  (SgN  >varrandi !01_S	et	f	\N
131623	varrandi	?varrandi =varrandi  (SgG  >varrandi !01_S	et	f	\N
131625	varrandi	?varrandi =varrandi  (SgG  >varrand !02_S	et	f	\N
131627	varrandi	?varrandi =varrandi  (SgG  >varrant !22_S	et	f	\N
131628	varrandi	?varrandi =varrandi  (IndPrPs_  >varrantima !28_V	et	f	\N
131630	varrandi	?varrandi =varrandi  (ImpPrSg2  >varrantima !28_V	et	f	\N
131639	leidsid	leidsid =leid  (IndIpfSg2  >leidma !34_V	et	f	\N
131640	leidsid	leidsid =leid  (IndIpfPl3  >leidma !34_V	et	f	\N
131652	kolmekilomeetrilise	kolmekilomeetrilise =meetrilise  (SgG  >kolme+kilo+meetriline !12_A	et	f	\N
131653	kolmekilomeetrilise	"kolme+kilo+meetriline %meetri  )LINE_aA  <kolme+kilo+meeter ;02_S	et	f	\N
131654	kolmekilomeetrilise	kolmekilomeetrilise =kilomeetrilise  (SgG  >kolme+kilomeetriline !12_A	et	f	\N
131655	kolmekilomeetrilise	"kolme+kilomeetriline %kilomeetri  )LINE_aA  <kolme+kilomeeter ;02_S	et	f	\N
131698	külgede	külgede =külge  (PlG  >külg !22_S	et	f	\N
131699	külgede	külgede =ede  (SgN  >külg+ede !16_S	et	f	\N
131700	külgede	külgede =ede  (SgG  >külg+ede !16_S	et	f	\N
131709	teotihuacan	?teotihuacan =teotihuacan  (SgN  >teotihuacan !02_S	et	f	\N
131710	teotihuacan	?teotihuacan =acan  (SgN  >teo+tihu+acan !02_S	et	f	\N
131711	teotihuacan	?teotihuacan =tihuacan  (SgN  >teo+tihuacan !02_S	et	f	\N
131743	tänulikkuse	tänulikkuse =tänulikkuse  (SgG  >tänulikkus !11~09_S	et	f	\N
131744	tänulikkuse	"tänulikkus %tänulikku  )US_aS  <tänulik ;25_A	et	f	\N
131750	stseeni	stseeni =stseeni  (SgG  >stseen !22_S	et	f	\N
131751	stseeni	stseeni =stseeni  (SgP  >stseen !22_S	et	f	\N
131390	fauna	fauna =fauna  (SgN  >fauna !16_S	et	f	\N
131391	fauna	fauna =fauna  (SgG  >fauna !16_S	et	f	\N
131421	erinevalt	erinevalt =erineva  (SgAbl  >erinev !02_A	et	f	\N
131422	erinevalt	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
131423	erinevalt	erinevalt =erinevalt  (ID  >erinevalt !41_D	et	f	\N
131424	erinevalt	"erinevalt %erine  )VALT_mD  <erinema ;27_V	et	f	\N
131425	erinevalt	"erinevalt %erineva  )LT_mD  <erinev ;02_A	et	f	\N
131428	halvata	halvata =halva  (SgAb  >halb !22_A	et	f	\N
131429	halvata	halvata =halva  (Inf  >halvama !29_V	et	f	\N
131430	halvata	halvata =halva  (IndPrIps_  >halvama !29_V	et	f	\N
131435	ms	### ms	et	f	\N
131442	koduloomi	koduloomi =loomi  (SgG  >kodu+loom !22_S	et	f	\N
131443	koduloomi	koduloomi =loomi  (SgP  >kodu+loom !22_S	et	f	\N
131444	koduloomi	koduloomi =loomi  (SgAdt  >kodu+loom !22_S	et	f	\N
131445	koduloomi	koduloomi =loomi  (PlP  >kodu+loom !22_S	et	f	\N
131448	lea	?lea =lea  (SgN  >lea !26_S	et	f	\N
131449	lea	?lea =lea  (SgG  >lea !26_S	et	f	\N
131454	loorits	?loorits =loorits  (SgN  >loorits !02_S	et	f	\N
131455	loorits	?loorits =rits  (SgN  >loo+rits !22_S	et	f	\N
131464	vaarandi	vaarandi =andi  (SgP  >vaar+and !22_S	et	f	\N
131465	vaarandi	vaarandi =andi  (SgAdt  >vaar+and !22_S	et	f	\N
131474	ühiskultuuri	ühiskultuuri =kultuuri  (SgG  >ühis+kultuur !22_S	et	f	\N
131475	ühiskultuuri	ühiskultuuri =kultuuri  (SgP  >ühis+kultuur !22_S	et	f	\N
131476	ühiskultuuri	ühiskultuuri =kultuuri  (SgAdt  >ühis+kultuur !22_S	et	f	\N
131481	aastatesse	aastatesse =aasta  (PlIll  >aasta !01_S	et	f	\N
131482	aastatesse	aastatesse =tate  (PlIll  >aas+tatt !22_S	et	f	\N
131487	natsistid	?natsistid =natsisti  (PlN  >natsisti !01_S	et	f	\N
131488	natsistid	?natsistid =natsisti  (PlN  >natsist !22_S	et	f	\N
131489	natsistid	?natsistid =natsisti  (IndPrSg2  >natsistima !28_V	et	f	\N
131500	ideeline	ideeline =ideeline  (SgN  >ideeline !12?10_A	et	f	\N
131501	ideeline	"ideeline %idee  )LINE_aA  <idee ;26_S	et	f	\N
131514	esto	?esto =esto  (SgN  >esto !16_S	et	f	\N
131516	esto	?esto =esto  (SgG  >esto !16_S	et	f	\N
131524	torontos	?torontos =toronto  (SgIn  >toronto !16_S	et	f	\N
131535	tiraazid	?tiraazid =tiraazi  (PlN  >tiraazi !16_S	et	f	\N
131543	moodustamise	moodustamise =moodustamise  (SgG  >moodustamine !12_S	et	f	\N
131544	moodustamise	"moodustamine %moodusta  )MINE_vS  <moodustama ;27_V	et	f	\N
131570	hint	?hint =hint  (SgN  >hint !22_S	et	f	\N
131579	organiseerimine	organiseerimine =organiseerimine  (SgN  >organiseerimine !12_S	et	f	\N
131582	organiseerimine	"organiseerimine %organiseeri  )MINE_vS  <organiseerima ;28_V	et	f	\N
131585	ekbp	?ekbp =ekbp  (SgN  >ekbp !22_S	et	f	\N
131588	viii	?viii =viii  (SgN  >viii !26_S	et	f	\N
131589	viii	?viii =viii  (SgG  >viii !26_S	et	f	\N
131592	ustavate	ustavate =ustava  (PlG  >ustav !02_A	et	f	\N
131593	ustavate	"ustav %us  )TAV_vAS  <uskuma ;28_V	et	f	\N
131594	puhastus	puhastus =puhastu  (IndIpfSg3  >puhastuma !27_V	et	f	\N
131595	puhastus	puhastus =puhastus  (SgN  >puhastus !11_S	et	f	\N
131596	puhastus	"puhastus %puhasta  )US_vS  <puhastama ;27_V	et	f	\N
131607	täitsid	täitsid =täit  (IndIpfSg2  >täitma !34_V	et	f	\N
131608	täitsid	täitsid =täit  (IndIpfPl3  >täitma !34_V	et	f	\N
131634	antarktika	?antarktika =antarktika  (SgN  >antarktika !01_S	et	f	\N
131635	antarktika	?antarktika =antarktika  (SgG  >antarktika !01_S	et	f	\N
131636	antarktika	?antarktika =antarktika  (SgG  >antarktikas !02_A	et	f	\N
131642	vostoki	?vostoki =vostoki  (SgN  >vostoki !01_S	et	f	\N
131643	vostoki	?vostoki =vostoki  (SgG  >vostoki !01_S	et	f	\N
131644	vostoki	?vostoki =vostoki  (SgG  >vostok !02_S	et	f	\N
131645	vostoki	?vostoki =vostoki  (SgG  >vostokk !22_S	et	f	\N
131646	vostoki	?vostoki =vostoki  (IndPrPs_  >vostokkima !28_V	et	f	\N
131647	vostoki	?vostoki =vostoki  (ImpPrSg2  >vostokkima !28_V	et	f	\N
131680	atmosfäärist	atmosfäärist =atmosfääri  (SgEl  >atmosfäär !22_S	et	f	\N
131682	atmosfäärist	atmosfäärist =atmosfääris  (SgP  >atmosfäärine !10_A	et	f	\N
131684	atmosfäärist	"atmosfäärine %atmosfääri  )NE_aA  <atmosfäär ;22_S	et	f	\N
131691	mexico	?mexico =mexico  (SgN  >mexico !16_S	et	f	\N
131692	mexico	?mexico =mexico  (SgG  >mexico !16_S	et	f	\N
131701	laius	laius =laiu  (SgIn  >laid !22_S	et	f	\N
131702	laius	laius =laiu  (PlIn  >laid !22_S	et	f	\N
131703	laius	laius =laiu  (PlIn  >lai !22_A	et	f	\N
131704	laius	laius =laiu  (IndIpfSg3  >laiuma !27_V	et	f	\N
131705	laius	laius =laius  (SgN  >laius !11~09_S	et	f	\N
131706	laius	"laius %lai  )US_aS  <lai ;22_A	et	f	\N
131708	iztapalapas	?iztapalapas =iztapalapa  (SgIn  >iztapalapa !16_S	et	f	\N
131716	keraamika	keraamika =keraamika  (SgN  >keraamika !01_S	et	f	\N
131717	keraamika	keraamika =keraamika  (SgG  >keraamika !01_S	et	f	\N
131718	kultusehitiste	?kultusehitiste =kultusehitis  (PlG  >kultusehitis !09_S	et	f	\N
131719	kultusehitiste	?kultusehitiste =kultusehitiste  (PlP  >kultusehitist !22_S	et	f	\N
131720	kultusehitiste	?kultusehitiste =hitis  (PlG  >kultuse+hitis !09_S	et	f	\N
131721	kultusehitiste	?kultusehitiste =hitiste  (PlP  >kultuse+hitist !22_S	et	f	\N
131726	aastail	aastail =aasta  (PlAd  >aasta !01_S	et	f	\N
131503	parteine	"parteine %partei  )NE_aA  <partei ;26_S	et	f	\N
131525	1946a	### 1946a	et	f	\N
131526	oswald	?oswald =oswald  (SgN  >oswald !02_S	et	f	\N
131554	sega-	sega- =sega  (IndPrPs_  >segama !27_V	et	f	\N
131555	sega-	sega- =sega  (ImpPrSg2  >segama !27_V	et	f	\N
131556	meeskoor	meeskoor =koor  (SgN  >mees+koor !13_S	et	f	\N
131557	meeskoor	meeskoor =koor  (SgN  >mees+koor !22_S	et	f	\N
131558	meeskoor	meeskoor =skoor  (SgN  >mee+skoor !22_S	et	f	\N
131567	semper	?semper =semper  (SgN  >semper !02_S	et	f	\N
131573	sagrits	?sagrits =sagrits  (SgN  >sagrits !02_S	et	f	\N
131578	loomeliitude	loomeliitude =ude  (SgN  >loom+eliit+ude !04_S	et	f	\N
131580	loomeliitude	loomeliitude =liitu  (PlG  >loome+liit !22_S	et	f	\N
131590	nõiajahti	nõiajahti =jahti  (SgP  >nõia+jaht !22_S	et	f	\N
131591	nõiajahti	nõiajahti =jahti  (SgAdt  >nõia+jaht !22_S	et	f	\N
131602	ani	?ani =ani  (SgN  >ani !17_S	et	f	\N
131603	ani	?ani =ani  (SgG  >ani !17_S	et	f	\N
131604	ani	?ani =ani  (SgP  >ani !17_S	et	f	\N
131605	ani	?ani =ani  (IndPrPs_  >anima !27_V	et	f	\N
131606	ani	?ani =ani  (ImpPrSg2  >anima !27_V	et	f	\N
131614	tsentsuur	?tsentsuur =tsentsuur  (SgN  >tsentsuur !22_S	et	f	\N
131616	keskseks	keskseks =keskse  (SgTr  >keskne !02_A	et	f	\N
131617	keskseks	keskseks =seks  (SgN  >kesk+seks !22_S	et	f	\N
131637	avastus	avastus =avastus  (SgN  >avastus !11_S	et	f	\N
131638	avastus	"avastus %avasta  )US_vS  <avastama ;27_V	et	f	\N
131641	soojalembesite	### soojalembesite	et	f	\N
131651	settekivimide	### settekivimide	et	f	\N
131676	kilomeetri	kilomeetri =kilomeetri  (SgG  >kilomeeter !02_S	et	f	\N
131677	kilomeetri	kilomeetri =meetri  (SgG  >kilo+meeter !02_S	et	f	\N
131686	mehhikos	?mehhikos =mehhiko  (SgIn  >mehhiko !16_S	et	f	\N
131687	mehhiko	?mehhiko =mehhiko  (SgN  >mehhiko !16_S	et	f	\N
131688	mehhiko	?mehhiko =mehhiko  (SgG  >mehhiko !16_S	et	f	\N
131712	viitanud	?viitanud =viitanu  (PlN  >viitanu !01_S	et	f	\N
131713	viitanud	?viitanud =viitanu  (IndPrSg2  >viitanuma !27_V	et	f	\N
131714	viitanud	?viitanud =viitanud  (ID  >viitanud !41_A	et	f	\N
131715	viitanud	?viitanud =anu  (PlN  >viit+anu !17_S	et	f	\N
131722	kontrollkraavi	kontrollkraavi =kraavi  (SgG  >kont+roll+kraav !22_S	et	f	\N
131723	kontrollkraavi	kontrollkraavi =kraavi  (SgP  >kont+roll+kraav !22_S	et	f	\N
131724	kontrollkraavi	kontrollkraavi =kraavi  (SgAdt  >kont+roll+kraav !22_S	et	f	\N
131732	lahkusid	lahkusid =lahku  (PlP  >lahk !22_S	et	f	\N
131733	lahkusid	lahkusid =lahku  (IndIpfSg2  >lahkuma !27_V	et	f	\N
131734	lahkusid	lahkusid =lahku  (IndIpfPl3  >lahkuma !27_V	et	f	\N
131735	koolera	koolera =koolera  (SgN  >koolera !01_S	et	f	\N
131738	koolera	koolera =koolera  (SgG  >koolera !01_S	et	f	\N
131740	koolera	koolera =era  (SgN  >kool+era !17_S	et	f	\N
131741	koolera	koolera =era  (SgG  >kool+era !17_S	et	f	\N
131742	koolera	koolera =era  (SgP  >kool+era !17_S	et	f	\N
131753	püstitasid	püstitasid =püstita  (IndIpfSg2  >püstitama !27_V	et	f	\N
131754	püstitasid	püstitasid =püstita  (IndIpfPl3  >püstitama !27_V	et	f	\N
131763	kohaga	kohaga =koha  (SgKom  >koha !17_S	et	f	\N
131764	kohaga	kohaga =koha  (SgKom  >koht !22_S	et	f	\N
131770	lihtsaks	lihtsaks =lihtsa  (SgTr  >lihtne !02_A	et	f	\N
131771	lihtsaks	lihtsaks =saks  (SgN  >liht+saks !23?22_S	et	f	\N
131772	tamara	?tamara =tamara  (SgN  >tamara !01_S	et	f	\N
131773	tamara	?tamara =tamara  (SgG  >tamara !01_S	et	f	\N
131778	lugejatele	lugejatele =lugeja  (PlAll  >lugeja !01_S	et	f	\N
131779	lugejatele	"lugeja %luge  )JA_vS  <lugema ;28_V	et	f	\N
131789	kullasega	kullasega =kullase  (SgKom  >kullane !10_A	et	f	\N
131790	kullasega	"kullane %kulla  )NE_aA  <kuld ;22_S	et	f	\N
131797	ühemassilised	ühemassilised =massilise  (PlN  >ühe+massiline !12_A	et	f	\N
131799	ühemassilised	"ühe+massiline %massi  )LINE_aA  <ühe+mass ;22_S	et	f	\N
131800	ringadega	?ringadega =ringa  (PlKom  >ringa !16_S	et	f	\N
131801	ringadega	?ringadega =ade  (SgKom  >ring+ade !16_S	et	f	\N
131802	pats	pats =pats  (ID  >pats !41_I	et	f	\N
131803	pats	pats =pats  (SgN  >pats !22_S	et	f	\N
131812	tänasepäeval	?tänasepäeval =tänasepäeva  (SgAd  >tänasepäeva !16_S	et	f	\N
131813	tänasepäeval	?tänasepäeval =tänasepäeval  (SgN  >tänasepäeval !02_S	et	f	\N
131814	tänasepäeval	?tänasepäeval =sepäeva  (SgAd  >täna+sepäeva !01_S	et	f	\N
131889	eraldavad	eraldavad =eralda  (IndPrPl3  >eraldama !27_V	et	f	\N
131890	eraldavad	eraldavad =eraldava  (PlN  >eraldav !02_A	et	f	\N
131891	eraldavad	"eraldav %eralda  )V_vA  <eraldama ;27_V	et	f	\N
131899	venetsia	?venetsia =venetsia  (SgN  >venetsia !01_S	et	f	\N
131900	venetsia	?venetsia =venetsia  (SgG  >venetsia !01_S	et	f	\N
131901	venetsia	?venetsia =tsia  (SgN  >vene+tsia !26_S	et	f	\N
131902	venetsia	?venetsia =tsia  (SgG  >vene+tsia !26_S	et	f	\N
131903	elementina	### elementina	et	f	\N
131904	lõbusaks	lõbusaks =lõbusa  (SgTr  >lõbus !02_A	et	f	\N
131906	lõbusaks	lõbusaks =saks  (SgN  >lõbu+saks !23?22_S	et	f	\N
131908	ühendusega	ühendusega =ühenduse  (SgKom  >ühendus !11_S	et	f	\N
131909	ühendusega	"ühendus %ühenda  )US_vS  <ühendama ;27_V	et	f	\N
131551	põldroosi	põldroosi =roosi  (SgG  >põld+roos !22_S	et	f	\N
131552	põldroosi	põldroosi =roosi  (SgP  >põld+roos !22_S	et	f	\N
131553	põldroosi	põldroosi =roosi  (SgAdt  >põld+roos !22_S	et	f	\N
131561	sümfoonia-	sümfoonia- =sümfoonia  (SgN  >sümfoonia !01_S	et	f	\N
131562	sümfoonia-	sümfoonia- =sümfoonia  (SgG  >sümfoonia !01_S	et	f	\N
131571	eric	### eric	et	f	\N
131575	tagalaperioodi	tagalaperioodi =perioodi  (SgG  >tagala+periood !22_S	et	f	\N
131576	tagalaperioodi	tagalaperioodi =perioodi  (SgP  >tagala+periood !22_S	et	f	\N
131577	tagalaperioodi	tagalaperioodi =perioodi  (SgAdt  >tagala+periood !22_S	et	f	\N
131615	johannes	?johannes =johanne  (PlIn  >johann !22_S	et	f	\N
131618	kirjanikku	kirjanikku =kirjanikku  (SgP  >kirjanik !25_S	et	f	\N
131619	kirjanikku	kirjanikku =kirjanikku  (SgAdt  >kirjanik !25_S	et	f	\N
131620	deboora	?deboora =deboora  (SgN  >deboora !16_S	et	f	\N
131621	deboora	?deboora =deboora  (SgG  >deboora !16_S	et	f	\N
131624	luulekogu	luulekogu =kogu  (SgN  >luule+kogu !17_S	et	f	\N
131626	luulekogu	luulekogu =kogu  (SgG  >luule+kogu !17_S	et	f	\N
131629	luulekogu	luulekogu =kogu  (SgP  >luule+kogu !17_S	et	f	\N
131648	leid	leid =lei  (PlN  >lei !26_S	et	f	\N
131649	leid	leid =lei  (SgP  >lei !26_S	et	f	\N
131650	leid	leid =leid  (SgN  >leid !22_S	et	f	\N
131658	termofiili	?termofiili =termofiili  (SgN  >termofiili !16_S	et	f	\N
131659	termofiili	?termofiili =termofiili  (SgG  >termofiili !16_S	et	f	\N
131660	termofiili	?termofiili =termofiili  (SgG  >termofiil !22_S	et	f	\N
131661	termofiili	?termofiili =termofiili  (SgP  >termofiil !22_S	et	f	\N
131668	termofiili	?termofiili =termofiili  (SgAdt  >termofiil !22_S	et	f	\N
131669	termofiili	?termofiili =termofiili  (IndPrPs_  >termofiilima !28_V	et	f	\N
131670	termofiili	?termofiili =termofiili  (ImpPrSg2  >termofiilima !28_V	et	f	\N
131671	termofiili	?termofiili =fiili  (SgN  >termo+fiili !16_S	et	f	\N
131672	termofiili	?termofiili =fiili  (SgG  >termo+fiili !16_S	et	f	\N
131673	termofiili	?termofiili =fiili  (SgG  >termo+fiil !22_S	et	f	\N
131674	termofiili	?termofiili =fiili  (SgP  >termo+fiil !22_S	et	f	\N
131675	termofiili	?termofiili =fiili  (SgAdt  >termo+fiil !22_S	et	f	\N
131678	eraldatud	eraldatud =eralda  (PtsPtIps  >eraldama !27_V	et	f	\N
131679	eraldatud	eraldatud =eraldatu  (PlN  >eraldatu !01_S	et	f	\N
131681	eraldatud	"eraldatu %eralda  )TU1_vS  <eraldama ;27_V	et	f	\N
131683	eraldatud	eraldatud =eraldatud  (ID  >eraldatud !41_A	et	f	\N
131685	eraldatud	"eraldatud %eralda  )TUD_vA  <eraldama ;27_V	et	f	\N
131689	teatasid	teatasid =teata  (IndIpfSg2  >teatama !27_V	et	f	\N
131690	teatasid	teatasid =teata  (IndIpfPl3  >teatama !27_V	et	f	\N
131695	iztapalapa	?iztapalapa =iztapalapa  (SgN  >iztapalapa !16_S	et	f	\N
131697	iztapalapa	?iztapalapa =iztapalapa  (SgG  >iztapalapa !16_S	et	f	\N
131736	pääsemise	pääsemise =pääsemise  (SgG  >pääsemine !12_S	et	f	\N
131737	pääsemise	"pääsemine %pääse  )MINE_vS  <pääsema ;28_V	et	f	\N
131739	pääsemise	pääsemise =emise  (SgG  >pääs+emis !09_S	et	f	\N
131745	maas	maas =maa  (SgIn  >maa !26_S	et	f	\N
131746	maas	maas =maas  (ID  >maas !41_D	et	f	\N
131755	iigsete	?iigsete =iigse  (PlG  >iigne !02_A	et	f	\N
131756	iigsete	?iigsete =iigse  (PlG  >iigse !06_S	et	f	\N
131758	iigsete	?iigsete =iigse  (IndPrPl2  >iigsema !27_V	et	f	\N
131774	korjagina	?korjagina =korjagina  (SgG  >korjagin !19_S	et	f	\N
131775	korjagina	?korjagina =korjagina  (SgP  >korjagin !19_S	et	f	\N
131776	korjagina	?korjagina =korjagina  (SgAdt  >korjagin !19_S	et	f	\N
131798	lokkid	### lokkid	et	f	\N
131815	seksuaalselt	seksuaalselt =seksuaalse  (SgAbl  >seksuaalne !02_A	et	f	\N
131816	seksuaalselt	seksuaalselt =seksuaalselt  (ID  >seksuaalselt !41_D	et	f	\N
131817	seksuaalselt	"seksuaalselt %seksuaalse  )LT_mD  <seksuaalne ;02_A	et	f	\N
131825	värvi	värvi =värvi  (SgG  >värv !22_S	et	f	\N
131827	värvi	värvi =värvi  (SgP  >värv !22_S	et	f	\N
131828	värvi	värvi =värvi  (SgAdt  >värv !22_S	et	f	\N
131829	värvi	värvi =värvi  (IndPrPs_  >värvima !28_V	et	f	\N
131830	värvi	värvi =värvi  (ImpPrSg2  >värvima !28_V	et	f	\N
131835	kaneeli	kaneeli =kaneeli  (SgG  >kaneel !22_S	et	f	\N
131836	kaneeli	kaneeli =kaneeli  (SgP  >kaneel !22_S	et	f	\N
131837	kaneeli	kaneeli =kaneeli  (SgAdt  >kaneel !22_S	et	f	\N
131838	helkuga	?helkuga =helku  (SgKom  >helku !16_S	et	f	\N
131848	punutud	punutud =punu  (PtsPtIps  >punuma !27_V	et	f	\N
131849	punutud	punutud =punutu  (PlN  >punutu !01_AS	et	f	\N
131850	punutud	"punutu %punu  )TU1_vS  <punuma ;27_V	et	f	\N
131851	punutud	"punutu %punu  )TU2_kA  <punu ;17_S	et	f	\N
131853	punutud	punutud =punutud  (ID  >punutud !41_A	et	f	\N
131854	punutud	"punutud %punu  )TUD_vA  <punuma ;27_V	et	f	\N
131859	kuldsete	kuldsete =kuldse  (PlG  >kuldne !02_A	et	f	\N
131860	kuldsete	kuldsete =sete  (SgN  >kuld+sete !06_S	et	f	\N
131877	laenada	?laenada =nada  (SgN  >lae+nada !17_S	et	f	\N
131878	laenada	?laenada =nada  (SgG  >lae+nada !17_S	et	f	\N
131879	laenada	?laenada =nada  (SgP  >lae+nada !17_S	et	f	\N
131885	riietuskappis	?riietuskappis =riietuskappi  (IndIpfSg3  >riietuskappima !28_V	et	f	\N
131667	vesistu	vesistu =vesistu  (ImpPrSg2  >vesistuma !27_V	et	f	\N
131693	äärelinna	äärelinna =linna  (SgG  >ääre+linn !22_S	et	f	\N
131694	äärelinna	äärelinna =linna  (SgP  >ääre+linn !22_S	et	f	\N
131696	äärelinna	äärelinna =linna  (SgAdt  >ääre+linn !22_S	et	f	\N
131707	associated	?associated =ciate  (PlN  >asso+ciade !06_S	et	f	\N
131725	kaevasid	kaevasid =kaeva  (IndIpfSg2  >kaevama !29_V	et	f	\N
131727	kaevasid	kaevasid =kaeva  (IndIpfPl3  >kaevama !29_V	et	f	\N
131784	värviga	värviga =värvi  (SgKom  >värv !22_S	et	f	\N
131785	värviga	värviga =iga  (SgN  >värv+iga !18_S	et	f	\N
131786	värviga	värviga =iga  (SgP  >värv+iga !18_S	et	f	\N
131795	pakkuvad	pakkuvad =pakkuva  (PlN  >pakkuv !02_A	et	f	\N
131796	pakkuvad	"pakkuv %pakku  )V_vA  <pakkuma ;28_V	et	f	\N
131804	tagastamine	tagastamine =tagastamine  (SgN  >tagastamine !12_S	et	f	\N
131805	tagastamine	"tagastamine %tagasta  )MINE_vS  <tagastama ;27_V	et	f	\N
131823	juuksete	?juuksete =juukse  (PlG  >juukne !02_A	et	f	\N
131824	juuksete	?juuksete =juukse  (PlG  >juukse !06_S	et	f	\N
131826	juuksete	?juuksete =juukse  (IndPrPl2  >juuksema !28_V	et	f	\N
131831	effektselt	?effektselt =effektse  (SgAbl  >effektne !02_A	et	f	\N
131832	effektselt	?effektselt =effektselt  (ID  >effektselt !41_D	et	f	\N
131839	stiilselt	stiilselt =stiilse  (SgAbl  >stiilne !02_A	et	f	\N
131840	stiilselt	stiilselt =stiilselt  (ID  >stiilselt !41_D	et	f	\N
131841	stiilselt	"stiilselt %stiilse  )LT_mD  <stiilne ;02_A	et	f	\N
131842	aksesuaaridele	?aksesuaaridele =aksesuaari  (PlAll  >aksesuaari !16_S	et	f	\N
131843	aksesuaaridele	?aksesuaaridele =aksesuaari  (PlAll  >aksesuaar !22_S	et	f	\N
131868	metallehedega	?metallehedega =lehe  (PlKom  >metal+lehe !16_S	et	f	\N
131869	gotje	?gotje =gotje  (SgN  >gotje !06_S	et	f	\N
131870	gotje	?gotje =gotje  (SgG  >godje !06_S	et	f	\N
131871	gotje	?gotje =gotje  (IndPrPs_  >gotjema !27_V	et	f	\N
131872	gotje	?gotje =gotje  (ImpPrSg2  >gotjema !27_V	et	f	\N
131874	lahutamatu	lahutamatu =lahutamatu  (SgN  >lahutamatu !01_A	et	f	\N
131875	lahutamatu	"lahutamatu %lahuta  )MATU_vA  <lahutama ;27_V	et	f	\N
131876	lahutamatu	lahutamatu =lahutamatu  (SgG  >lahutamatu !01_A	et	f	\N
131905	peoks	peoks =peo  (SgTr  >pidu !18_S	et	f	\N
131907	peoks	peoks =peo  (SgTr  >peo !26_S	et	f	\N
131944	aroomaga	?aroomaga =arooma  (SgKom  >arooma !16_S	et	f	\N
131947	kuldehed	### kuldehed	et	f	\N
131965	toila	?toila =toila  (SgN  >toila !16_S	et	f	\N
131966	toila	?toila =toila  (SgG  >toila !16_S	et	f	\N
131967	toila	?toila =toila  (IndPrPs_  >toilama !29_V	et	f	\N
131968	toila	?toila =toila  (ImpPrSg2  >toilama !29_V	et	f	\N
131992	jõulukingituseks	jõulukingituseks =kingituse  (SgTr  >jõulu+kingitus !11_S	et	f	\N
131993	jõulukingituseks	"jõulu+kingitus %kingi  )TUS2_aS  <jõulu+kink ;22_S	et	f	\N
131996	effektne	?effektne =effektne  (SgN  >effektne !02_A	et	f	\N
131997	effektne	?effektne =effektne  (PlP  >effektn !22_S	et	f	\N
132035	maksu	maksu =maksu  (SgG  >maks !22_S	et	f	\N
132036	maksu	maksu =maksu  (SgP  >maks !22_S	et	f	\N
132037	maksu	maksu =maksu  (SgAdt  >maks !22_S	et	f	\N
132038	maksu	maksu =maksu  (PlP  >maks !22_S	et	f	\N
132046	tähtsaksedeks	### tähtsaksedeks	et	f	\N
132056	võõramaiseid	võõramaiseid =maise  (PlP  >võõra+maine !10_A	et	f	\N
132057	võõramaiseid	"võõra+maine %mai  )NE_aA  <võõra+maa ;26_S	et	f	\N
132058	öölda	?öölda =öölda  (SgN  >öölda !01_S	et	f	\N
132059	öölda	?öölda =öölda  (SgG  >öölda !01_S	et	f	\N
132060	öölda	?öölda =öölda  (IndPrPs_  >ööldama !27_V	et	f	\N
132061	öölda	?öölda =öölda  (ImpPrSg2  >ööldama !27_V	et	f	\N
132074	ajad	ajad =aja  (PlN  >aeg !22_S	et	f	\N
132075	ajad	ajad =aja  (IndPrSg2  >ajama !27_V	et	f	\N
132078	masenduses	masenduses =masenduse  (SgIn  >masendus !11_S	et	f	\N
132079	masenduses	"masendus %masenda  )US_vS  <masendama ;27_V	et	f	\N
132080	otsusi	?otsusi =otsusi  (ID  >otsusi !41_D	et	f	\N
132081	otsusi	?otsusi =usi  (SgN  >ots+usi !17_S	et	f	\N
132082	otsusi	?otsusi =usi  (SgG  >ots+usi !17_S	et	f	\N
132083	otsusi	?otsusi =usi  (SgP  >ots+usi !17_S	et	f	\N
132105	hitler	?hitler =hitler  (SgN  >hitler !02_S	et	f	\N
132107	süütuid	süütuid =süütu  (PlP  >süütu !01_A	et	f	\N
132108	süütuid	"süütu %süü  )TU2_kA  <süü ;26_S	et	f	\N
132109	süütuid	süütuid =tui  (PlN  >süü+tui !26_S	et	f	\N
132110	süütuid	süütuid =tui  (SgP  >süü+tui !26_S	et	f	\N
132114	hirmsam	hirmsam =hirmsam  (SgN  >hirmsam !02_A	et	f	\N
132115	hirmsam	"hirmsam %hirmsa  )M_cA  <hirmus ;02_A	et	f	\N
132123	näitekunsti	näitekunsti =kunsti  (SgG  >näite+kunst !22_S	et	f	\N
132124	näitekunsti	näitekunsti =kunsti  (SgP  >näite+kunst !22_S	et	f	\N
132127	näitekunsti	näitekunsti =kunsti  (SgAdt  >näite+kunst !22_S	et	f	\N
132128	loomevoluks	?loomevoluks =loomevolu  (KndPrPs  >loomevoluma !27_V	et	f	\N
132129	loomevoluks	?loomevoluks =volu  (SgTr  >loome+volu !17_S	et	f	\N
132130	loomevoluks	?loomevoluks =evolu  (SgTr  >loom+evolu !01_S	et	f	\N
132131	loomevoluks	?loomevoluks =mevolu  (SgTr  >loo+mevolu !01_S	et	f	\N
132136	vtormis	?vtormis =vtormi  (SgIn  >vtormi !16_S	et	f	\N
131728	aastail	aastail =tai  (SgAd  >aas+tai !26_S	et	f	\N
131729	puutuvad	puutuvad =puutu  (IndPrPl3  >puutuma !27_V	et	f	\N
131730	puutuvad	puutuvad =puutuva  (PlN  >puutuv !02_A	et	f	\N
131731	puutuvad	"puutuv %puutu  )V_vA  <puutuma ;27_V	et	f	\N
131747	evangeeliumi	evangeeliumi =evangeeliumi  (SgG  >evangeelium !19~02_S	et	f	\N
131748	evangeeliumi	evangeeliumi =evangeeliumi  (SgP  >evangeelium !19_S	et	f	\N
131749	evangeeliumi	evangeeliumi =evangeeliumi  (SgAdt  >evangeelium !19_S	et	f	\N
131760	asjaolu	asjaolu =olu  (SgN  >asja+olu !17_S	et	f	\N
131761	asjaolu	asjaolu =olu  (SgG  >asja+olu !17_S	et	f	\N
131762	asjaolu	asjaolu =olu  (SgP  >asja+olu !17_S	et	f	\N
131765	juan	?juan =juan  (SgN  >juan !22_S	et	f	\N
131766	sanches	?sanches =sanche  (SgIn  >sanche !06_S	et	f	\N
131767	sanches	?sanches =sanche  (PlIn  >sanch !22_S	et	f	\N
131768	sanches	?sanches =sanche  (IndIpfSg3  >sanchema !27_V	et	f	\N
131769	sanches	?sanches =sanches  (SgN  >sanches !09_S	et	f	\N
131780	kaunitada	?kaunitada =kaunita  (Inf  >kaunitama !27_V	et	f	\N
131781	kaunitada	?kaunitada =tada  (SgN  >kauni+tada !17_S	et	f	\N
131782	kaunitada	?kaunitada =tada  (SgG  >kauni+tada !17_S	et	f	\N
131783	kaunitada	?kaunitada =tada  (SgP  >kauni+tada !17_S	et	f	\N
131793	stiilsem	stiilsem =stiilsem  (SgN  >stiilsem !02_A	et	f	\N
131794	stiilsem	"stiilsem %stiilse  )M_cA  <stiilne ;02_A	et	f	\N
131806	paelake	paelake =paela  (ImpPrPl2  >paelama !29_V	et	f	\N
131807	paelake	paelake =paelake  (SgN  >paelake !12_S	et	f	\N
131808	paelake	"paelake %paela  )KE_dS  <pael ;22_S	et	f	\N
131809	paelake	"paelake %paela  )KE_dS  <pael ;23_S	et	f	\N
131810	paelake	paelake =lake  (SgN  >pae+lake !06_S	et	f	\N
131811	paelake	"pae+lake %la  )KE_dS  <pae+la ;26_S	et	f	\N
131833	toonid	toonid =tooni  (PlN  >toon !22_S	et	f	\N
131834	toonid	toonid =tooni  (IndPrSg2  >toonima !28_V	et	f	\N
131844	banaanivormeline	banaanivormeline =ine  (SgN  >banaani+vormel+ine !16_S	et	f	\N
131845	banaanivormeline	banaanivormeline =ine  (SgG  >banaani+vormel+ine !16_S	et	f	\N
131846	banaanivormeline	banaanivormeline =vormeline  (SgN  >banaani+vormeline !12_A	et	f	\N
131847	banaanivormeline	"banaani+vormeline %vormeli  )NE_aA  <banaani+vormel ;02_S	et	f	\N
131855	gabanna	?gabanna =gabanna  (SgN  >gabanna !16_S	et	f	\N
131858	gabanna	?gabanna =gabanna  (SgG  >gabanna !16_S	et	f	\N
131863	galjano	?galjano =galjano  (SgN  >galjano !01_S	et	f	\N
131864	galjano	?galjano =galjano  (SgG  >galjano !01_S	et	f	\N
131873	nootid	### nootid	et	f	\N
131880	iseseisvam	iseseisvam =seisvam  (SgN  >ise+seisvam !02_A	et	f	\N
131881	iseseisvam	"ise+seisvam %seisva  )M_cA  <ise+seisev ;02_A	et	f	\N
131882	sõltumatum	sõltumatum =sõltumatum  (SgN  >sõltumatum !02_A	et	f	\N
131883	sõltumatum	"sõltumatum %sõltu  )MATUM_cA  <sõltuma ;27_V	et	f	\N
131884	sõltumatum	"sõltumatum %sõltumatu  )M_cA  <sõltumatu ;01_A	et	f	\N
131892	individuaalsust	individuaalsust =individuaalsus  (SgP  >individuaalsus !11~09_S	et	f	\N
131893	individuaalsust	"individuaalsus %individuaalse  )US_aS  <individuaalne ;02_A	et	f	\N
131946	juveliirehed	### juveliirehed	et	f	\N
131954	spa	### spa	et	f	\N
131960	lõdvestus	lõdvestus =lõdvestus  (SgN  >lõdvestus !11_S	et	f	\N
131961	lõdvestus	"lõdvestus %lõdvesta  )US_vS  <lõdvestama ;27_V	et	f	\N
131969	keskusse	keskusse =keskus  (SgAdt  >keskus !11_S	et	f	\N
131970	keskusse	keskusse =usse  (PlP  >kesk+uss !22_S	et	f	\N
131979	maiustustele	maiustustele =maiustus  (PlAll  >maiustus !11_S	et	f	\N
131980	maiustustele	"maiustus %maiusta  )US_vS  <maiustama ;27_V	et	f	\N
131981	maiustustele	maiustustele =tuste  (PlAll  >maius+tust !22_S	et	f	\N
131994	pakkimine	pakkimine =pakkimine  (SgN  >pakkimine !12_S	et	f	\N
131995	pakkimine	"pakkimine %pakki  )MINE_vS  <pakkima ;28_V	et	f	\N
132012	arvutati	arvutati =arvuta  (IndIpfIps  >arvutama !27_V	et	f	\N
132013	arvutati	arvutati =tati  (SgG  >arvu+tatt !22_S	et	f	\N
132016	hinde	hinde =hinde  (SgG  >hinne !06_S	et	f	\N
132017	hinde	hinde =hinde  (PlP  >hind !22_S	et	f	\N
132018	mett	mett =me  (SgP  >mesi !15_S	et	f	\N
132019	mett	mett =mett  (SgN  >mett !22_S	et	f	\N
132023	röövimisi	röövimisi =röövimisi  (PlP  >röövimine !12_S	et	f	\N
132024	röövimisi	"röövimine %röövi  )MINE_vS  <röövima ;28_V	et	f	\N
132030	jurjevi	?jurjevi =jurjevi  (ID  >jurjevi !41_D	et	f	\N
132031	jurjevi	?jurjevi =jurjevi  (SgG  >jurjev !02_A	et	f	\N
132045	hiljemal	?hiljemal =hiljemal  (ID  >hiljemal !41_D	et	f	\N
132064	80-ndate	?-ndate =ndate  (SgN  >-ndate !06_S	et	f	\N
132065	80-ndate	?-ndate =ndate  (IndPrPs_  >-ndatema !27_V	et	f	\N
132066	80-ndate	?-ndate =ndate  (ImpPrSg2  >-ndatema !27_V	et	f	\N
132090	iseseisvus	iseseisvus =seisvu  (IndIpfSg3  >ise+seisvuma !27_V	et	f	\N
132091	iseseisvus	iseseisvus =seisvus  (SgN  >ise+seisvus !11~09_S	et	f	\N
132092	iseseisvus	"ise+seisvus %seisva  )US_aS  <ise+seisev ;02_A	et	f	\N
132096	kaitsesid	kaitsesid =kaitse  (IndIpfSg2  >kaitsma !32_V	et	f	\N
132097	kaitsesid	kaitsesid =kaitse  (IndIpfPl3  >kaitsma !32_V	et	f	\N
132098	kaitsesid	kaitsesid =kaitse  (IndIpfSg2  >kaitsema !28_V	et	f	\N
132099	kaitsesid	kaitsesid =kaitse  (IndIpfPl3  >kaitsema !28_V	et	f	\N
131752	stseeni	stseeni =stseeni  (SgAdt  >stseen !22_S	et	f	\N
131757	paganline	?paganline =paganline  (SgN  >paganline !12_A	et	f	\N
131759	paganline	?paganline =paganline  (PlP  >paganlin !19_S	et	f	\N
131777	jõulunõuanned	### jõulunõuanned	et	f	\N
131787	burgundia	?burgundia =burgundia  (SgN  >burgundia !01_S	et	f	\N
131788	burgundia	?burgundia =burgundia  (SgG  >burgundia !01_S	et	f	\N
131791	piisad	piisad =piisa  (PlN  >piisk !22_S	et	f	\N
131792	piisad	piisad =piisa  (IndPrSg2  >piisama !29_V	et	f	\N
131818	ladi	?ladi =ladi  (SgN  >ladi !17_S	et	f	\N
131819	ladi	?ladi =ladi  (SgG  >ladi !17_S	et	f	\N
131820	ladi	?ladi =ladi  (SgP  >ladi !17_S	et	f	\N
131821	ladi	?ladi =ladi  (IndPrPs_  >ladima !27_V	et	f	\N
131822	ladi	?ladi =ladi  (ImpPrSg2  >ladima !27_V	et	f	\N
131852	dolce	?dolce =dolce  (SgN  >dolce !06_S	et	f	\N
131856	dolce	?dolce =dolce  (SgG  >dolce !06_S	et	f	\N
131857	dolce	?dolce =dolce  (PlP  >dolc !22_S	et	f	\N
131861	valmistajate	valmistajate =valmistaja  (PlG  >valmistaja !01_S	et	f	\N
131862	valmistajate	"valmistaja %valmista  )JA_vS  <valmistama ;27_V	et	f	\N
131865	mustlaste	mustlaste =mustlas  (PlG  >mustlane !12?10_S	et	f	\N
131866	mustlaste	mustlaste =las  (PlG  >must+laps !14_S	et	f	\N
131867	mustlaste	mustlaste =laste  (PlP  >must+last !22_S	et	f	\N
131887	effektsed	?effektsed =effektse  (PlN  >effektne !02_A	et	f	\N
131888	effektsed	?effektsed =effektse  (IndPrSg2  >effektsema !27_V	et	f	\N
131894	juhttendentsi	juhttendentsi =tendentsi  (SgG  >juht+tendents !22_S	et	f	\N
131895	juhttendentsi	juhttendentsi =tendentsi  (SgP  >juht+tendents !22_S	et	f	\N
131896	juhttendentsi	juhttendentsi =tendentsi  (SgAdt  >juht+tendents !22_S	et	f	\N
131897	stiilides	stiilides =stiili  (PlIn  >stiil !22_S	et	f	\N
131898	stiilides	stiilides =stiili  (Ger  >stiilima !28_V	et	f	\N
131938	kingituseks	kingituseks =kingituse  (SgTr  >kingitus !11_S	et	f	\N
131939	kingituseks	"kingitus %kingi  )TUS1_aS  <kinkima ;28_V	et	f	\N
131940	kingituseks	"kingitus %kingi  )TUS2_aS  <kink ;22_S	et	f	\N
131949	meestest	meestest =mees  (PlEl  >meene !10_A	et	f	\N
131951	meestest	"meene %mee  )NE_aA  <mesi ;15_S	et	f	\N
131952	meestest	meestest =mees  (PlEl  >mees !13_S	et	f	\N
131953	meestest	meestest =test  (SgN  >mees+test !22_S	et	f	\N
131962	nädalavahetuseks	nädalavahetuseks =use  (PlTr  >nädala+vahet+usk !22_S	et	f	\N
131963	nädalavahetuseks	nädalavahetuseks =vahetuse  (SgTr  >nädala+vahetus !11_S	et	f	\N
131964	nädalavahetuseks	"nädala+vahetus %vahe  )TUS2_aS  <nädala+vahe ;16_S	et	f	\N
132001	lindike	lindike =lindike  (SgN  >lindike !12_S	et	f	\N
132002	lindike	"lindike %lindi  )KE_dS  <lint ;22_S	et	f	\N
132003	lindike	lindike =ike  (SgN  >lind+ike !06_S	et	f	\N
132005	tujut	?tujut =tujut  (SgN  >tujut !02_S	et	f	\N
132008	heat	?heat =heat  (SgN  >heat !22_S	et	f	\N
132041	mugavamad	mugavamad =mugavama  (PlN  >mugavam !02_A	et	f	\N
132042	mugavamad	"mugavam %mugava  )M_cA  <mugav ;02_A	et	f	\N
132043	sõjadest	?sõjadest =sõja  (PlEl  >sõja !17_S	et	f	\N
132044	sõjadest	?sõjadest =sõjades  (SgP  >sõjadene !12_A	et	f	\N
132048	loodesega	loodesega =loodese  (SgKom  >loodene !10_A	et	f	\N
132049	loodesega	"loodene %loode  )NE_aA  <loe ;06_S	et	f	\N
132050	loodesega	"loodene %loode  )NE_aA  <loode ;06_S	et	f	\N
132051	kaalu	kaalu =kaalu  (SgG  >kaal !22_S	et	f	\N
132052	kaalu	kaalu =kaalu  (SgP  >kaal !22_S	et	f	\N
132053	kaalu	kaalu =kaalu  (SgAdt  >kaal !22_S	et	f	\N
132054	kaalu	kaalu =kaalu  (IndPrPs_  >kaaluma !28_V	et	f	\N
132055	kaalu	kaalu =kaalu  (ImpPrSg2  >kaaluma !28_V	et	f	\N
132072	tahtmisi	tahtmisi =tahtmisi  (PlP  >tahtmine !12_S	et	f	\N
132073	tahtmisi	"tahtmine %taht  )MINE_vS  <tahtma ;34_V	et	f	\N
132084	kartsid	kartsid =kart  (IndIpfSg2  >kartma !34_V	et	f	\N
132085	kartsid	kartsid =kart  (IndIpfPl3  >kartma !34_V	et	f	\N
132086	kartsid	kartsid =kartsi  (PlN  >karts !22_S	et	f	\N
132100	kangelasteks	kangelasteks =kangelas  (PlTr  >kangelane !12_S	et	f	\N
132101	kangelasteks	kangelasteks =las  (PlTr  >kange+laps !14_S	et	f	\N
132102	kangelasteks	kangelasteks =laste  (PlTr  >kange+last !22_S	et	f	\N
132103	sõjaväelises	sõjaväelises =väelise  (SgIn  >sõja+väeline !12?10_A	et	f	\N
132104	sõjaväelises	"sõja+väeline %väe  )LINE_aA  <sõja+vägi ;21_S	et	f	\N
132106	õudsam	?õudsam =õudsam  (SgN  >õudsam !02_A	et	f	\N
132111	hukka	hukka =hukka  (ID  >hukka !41_D	et	f	\N
132112	hukka	hukka =hukka  (IndPrPs_  >hukkama !29_V	et	f	\N
132113	hukka	hukka =hukka  (ImpPrSg2  >hukkama !29_V	et	f	\N
132125	vpanso	?vpanso =vpanso  (SgN  >vpanso !16_S	et	f	\N
132126	vpanso	?vpanso =vpanso  (SgG  >vpanso !16_S	et	f	\N
132143	vilminduses	?vilminduses =vilminduse  (SgIn  >vilmindus !11_S	et	f	\N
132147	korrigeerisid	korrigeerisid =korrigeeri  (IndIpfSg2  >korrigeerima !28_V	et	f	\N
132148	korrigeerisid	korrigeerisid =korrigeeri  (IndIpfPl3  >korrigeerima !28_V	et	f	\N
132184	perestroikat	?perestroikat =perestroika  (SgP  >perestroikas !02_A	et	f	\N
132185	perestroikat	?perestroikat =perestroika  (SgP  >perestroika !16_S	et	f	\N
132218	estis	?estis =est  (IndIpfSg3  >estma !34_V	et	f	\N
132219	estis	?estis =esti  (SgIn  >esti !16_S	et	f	\N
131886	riietuskappis	?riietuskappis =riietuskappis  (SgN  >riietuskappis !09_S	et	f	\N
131910	roppult	?roppult =roppult  (ID  >roppult !41_D	et	f	\N
131911	roppult	?roppult =ult  (SgN  >ropp+ult !22_S	et	f	\N
131917	soovitavate	soovitavate =soovitava  (PlG  >soovitav !02_A	et	f	\N
131918	soovitavate	"soovitav %soovi  )TAV_vAS  <soovima ;28_V	et	f	\N
131919	soovitavate	"soovitav %soovita  )V_vA  <soovitama ;27_V	et	f	\N
131924	ootage	### ootage	et	f	\N
131936	tualettlaud	tualettlaud =lau  (PlN  >tualett+laug !22_SA	et	f	\N
131937	tualettlaud	tualettlaud =laud  (SgN  >tualett+laud !22_S	et	f	\N
131941	tualettvesi	tualettvesi =vesi  (SgN  >tualett+vesi !15_S	et	f	\N
131942	tualettvesi	tualettvesi =vesi  (PlP  >tualett+vesi !15_S	et	f	\N
131943	lemmig	### lemmig	et	f	\N
131945	mint	?mint =mint  (SgN  >mint !22_S	et	f	\N
131948	kallide	?kallide =kalli  (PlG  >kalli !16_S	et	f	\N
131950	kallide	?kallide =kalli  (PlG  >kall !22_S	et	f	\N
131955	salongi	salongi =salongi  (SgG  >salong !22_S	et	f	\N
131956	salongi	salongi =salongi  (SgP  >salong !22_S	et	f	\N
131957	salongi	salongi =salongi  (SgAdt  >salong !22_S	et	f	\N
131971	selgunud	selgunud =selgu  (PtsPtPs  >selguma !27_V	et	f	\N
131972	selgunud	selgunud =selgunu  (PlN  >selgunu !01_S	et	f	\N
131973	selgunud	"selgunu %selgu  )NU_vS  <selguma ;27_V	et	f	\N
131974	selgunud	selgunud =selgunud  (ID  >selgunud !41_A	et	f	\N
131975	selgunud	"selgunud %selgu  )NUD_vA  <selguma ;27_V	et	f	\N
131998	särav	särav =sära  (PtsPrPs  >särama !27_V	et	f	\N
131999	särav	särav =särav  (SgN  >särav !02_A	et	f	\N
132000	särav	"särav %sära  )V_vA  <särama ;27_V	et	f	\N
132004	pidulikut	### pidulikut	et	f	\N
132007	avatada	?avatada =avata  (Inf  >avatama !27_V	et	f	\N
132009	avatada	?avatada =tada  (SgN  >ava+tada !17_S	et	f	\N
132010	avatada	?avatada =tada  (SgG  >ava+tada !17_S	et	f	\N
132011	avatada	?avatada =tada  (SgP  >ava+tada !17_S	et	f	\N
132020	hakkatakse	?hakkatakse =hakkatakse  (SgG  >hakkatakne !02_A	et	f	\N
132021	hakkatakse	?hakkatakse =hakkatakse  (PlP  >hakkataks !22_S	et	f	\N
132022	hakkatakse	?hakkatakse =atakse  (SgG  >hakk+atakne !02_A	et	f	\N
132062	kaubateed	kaubateed =tee  (PlN  >kauba+tee !26_S	et	f	\N
132063	kaubateed	kaubateed =tee  (SgP  >kauba+tee !26_S	et	f	\N
132067	teletorni	teletorni =torni  (SgG  >tele+torn !22_S	et	f	\N
132068	teletorni	teletorni =torni  (SgP  >tele+torn !22_S	et	f	\N
132069	teletorni	teletorni =torni  (SgAdt  >tele+torn !22_S	et	f	\N
132070	vaatlemisi	vaatlemisi =vaatlemisi  (PlP  >vaatlemine !12_S	et	f	\N
132071	vaatlemisi	"vaatlemine %vaatle  )MINE_vS  <vaatlema ;30_V	et	f	\N
132088	piire	piire =piire  (SgN  >piire !06_S	et	f	\N
132089	piire	piire =piire  (PlP  >piir !22_S	et	f	\N
132122	jkross	?jkross =jkross  (SgN  >jkross !22_S	et	f	\N
132134	tegutsesid	tegutsesid =tegutse  (IndIpfSg2  >tegutsema !27_V	et	f	\N
132135	tegutsesid	tegutsesid =tegutse  (IndIpfPl3  >tegutsema !27_V	et	f	\N
132139	populaarsem	populaarsem =populaarsem  (SgN  >populaarsem !02_A	et	f	\N
132140	populaarsem	"populaarsem %populaarse  )M_cA  <populaarne ;02_A	et	f	\N
132154	ulevalt	?ulevalt =uleva  (SgAbl  >uleva !01_S	et	f	\N
132155	ulevalt	?ulevalt =uleva  (SgAbl  >ulev !02_A	et	f	\N
132156	ulevalt	?ulevalt =ulevalt  (ID  >ulevalt !41_D	et	f	\N
132174	reigani	?reigani =reiga  (SgTer  >reiga !16_S	et	f	\N
132175	reigani	?reigani =reigani  (SgG  >reigan !02_S	et	f	\N
132180	võtmist	võtmist =võtmis  (SgP  >võtmine !12?10_S	et	f	\N
132181	võtmist	"võtmine %võt  )MINE_vS  <võtma ;35_V	et	f	\N
132186	paranemine	paranemine =paranemine  (SgN  >paranemine !12_S	et	f	\N
132187	paranemine	"paranemine %parane  )MINE_vS  <paranema ;27_V	et	f	\N
132188	sula	sula =sula  (SgN  >sula !17_AS	et	f	\N
132189	sula	sula =sula  (SgG  >sula !17_AS	et	f	\N
132190	sula	sula =sula  (SgP  >sula !17_AS	et	f	\N
132191	sula	sula =sula  (IndPrPs_  >sulama !27_V	et	f	\N
132192	sula	sula =sula  (ImpPrSg2  >sulama !27_V	et	f	\N
132214	sõjaväeline	sõjaväeline =väeline  (SgN  >sõja+väeline !12?10_A	et	f	\N
132215	sõjaväeline	"sõja+väeline %väe  )LINE_aA  <sõja+vägi ;21_S	et	f	\N
132233	ainukest	ainukest =ainukes  (SgP  >ainuke !12_AS	et	f	\N
132234	ainukest	"ainuke %ainu  )KE_dS  <ainu ;16_S	et	f	\N
132235	ainukest	"ainuke %ainu  )KE_dA  <ainus ;07_AS	et	f	\N
132236	ainukest	ainukest =ainukes  (SgP  >ainukene !12_S	et	f	\N
132237	ainukest	"ainukene %ainu  )KENE_dS  <ainu ;16_S	et	f	\N
132238	ainukest	"ainukene %ainu  )KENE_dA  <ainus ;07_AS	et	f	\N
132239	ainukest	ainukest =kest  (SgN  >ainu+kest !22_S	et	f	\N
132240	keerlenud	?keerlenud =keerlenu  (PlN  >keerlenu !01_S	et	f	\N
132241	keerlenud	?keerlenud =keerlenu  (IndPrSg2  >keerlenuma !27_V	et	f	\N
132242	keerlenud	?keerlenud =keerlenud  (ID  >keerlenud !41_A	et	f	\N
132262	augustu	?augustu =augustu  (SgN  >augustu !01_S	et	f	\N
132263	augustu	?augustu =augustu  (SgG  >augustu !01_S	et	f	\N
132264	augustu	?augustu =augustu  (IndPrPs_  >augustuma !27_V	et	f	\N
132265	augustu	?augustu =augustu  (ImpPrSg2  >augustuma !27_V	et	f	\N
132266	augustu	?augustu =gustu  (SgN  >au+gustu !16_S	et	f	\N
131912	tindimus	?tindimus =tindimu  (SgIn  >tindimu !01_S	et	f	\N
131913	tindimus	?tindimus =tindimu  (IndIpfSg3  >tindimuma !27_V	et	f	\N
131914	tindimus	?tindimus =tindimus  (SgN  >tindimus !11_S	et	f	\N
131915	edukate	edukate =eduka  (PlG  >edukas !02_A	et	f	\N
131916	edukate	edukate =kate  (SgN  >edu+kate !06_S	et	f	\N
131920	kingituste	kingituste =kingitus  (PlG  >kingitus !11_S	et	f	\N
131921	kingituste	"kingitus %kingi  )TUS1_aS  <kinkima ;28_V	et	f	\N
131922	kingituste	"kingitus %kingi  )TUS2_aS  <kink ;22_S	et	f	\N
131923	kingituste	kingituste =tuste  (PlP  >kingi+tust !22_S	et	f	\N
131925	hullkiires	hullkiires =kiire  (SgIn  >hull+kiire !01_A	et	f	\N
131926	hullkiires	hullkiires =kiire  (SgIn  >hull+kiire !06_S	et	f	\N
131927	hullkiires	hullkiires =kiire  (SgIn  >hull+kiire !06_AS	et	f	\N
131928	hullkiires	hullkiires =kiire  (SgIn  >hull+kiir !13_S	et	f	\N
131929	hullkiires	hullkiires =kiire  (PlIn  >hull+kiird !22_S	et	f	\N
131930	hullkiires	hullkiires =kiire  (PlIn  >hull+kiir !22_S	et	f	\N
131931	meeste	meeste =mees  (PlG  >meene !10_A	et	f	\N
131932	meeste	"meene %mee  )NE_aA  <mesi ;15_S	et	f	\N
131933	meeste	meeste =mees  (PlG  >mees !13_S	et	f	\N
131934	valimisel	valimisel =valimise  (SgAd  >valimine !12_S	et	f	\N
131935	valimisel	"valimine %vali  )MINE_vS  <valima ;27_V	et	f	\N
131958	kinkekaart	kinkekaart =kaar  (SgP  >kinke+kaar !13_S	et	f	\N
131959	kinkekaart	kinkekaart =kaart  (SgN  >kinke+kaart !22_S	et	f	\N
131976	kingitusega	kingitusega =kingituse  (SgKom  >kingitus !11_S	et	f	\N
131977	kingitusega	"kingitus %kingi  )TUS1_aS  <kinkima ;28_V	et	f	\N
131978	kingitusega	"kingitus %kingi  )TUS2_aS  <kink ;22_S	et	f	\N
131982	martsipaani	?martsipaani =martsipaa  (SgTer  >martsipaa !26_S	et	f	\N
131983	martsipaani	?martsipaani =martsipaani  (SgN  >martsipaani !16_S	et	f	\N
131984	martsipaani	?martsipaani =martsipaani  (SgG  >martsipaani !16_S	et	f	\N
131985	martsipaani	?martsipaani =martsipaani  (SgG  >martsipaan !22_S	et	f	\N
131986	martsipaani	?martsipaani =martsipaani  (SgP  >martsipaan !22_S	et	f	\N
131987	martsipaani	?martsipaani =martsipaani  (SgAdt  >martsipaan !22_S	et	f	\N
131988	martsipaani	?martsipaani =martsipaani  (IndPrPs_  >martsipaanima !28_V	et	f	\N
131989	martsipaani	?martsipaani =martsipaani  (ImpPrSg2  >martsipaanima !28_V	et	f	\N
131990	arusa	?arusa =arusa  (SgN  >arusa !01_S	et	f	\N
131991	arusa	?arusa =arusa  (SgG  >arusa !01_S	et	f	\N
132006	ruttem	?ruttem =ruttem  (SgN  >ruttem !02_A	et	f	\N
132014	loomade	loomade =looma  (PlG  >loom !22_S	et	f	\N
132015	loomade	loomade =made  (SgN  >loo+made !04_S	et	f	\N
132025	asustus	asustus =asustus  (SgN  >asustus !11_S	et	f	\N
132026	asustus	"asustus %asusta  )US_vS  <asustama ;27_V	et	f	\N
132027	tänapäevase	tänapäevase =ase  (SgN  >täna+päev+ase !04_S	et	f	\N
132028	tänapäevase	tänapäevase =päevase  (SgG  >täna+päevane !10_A	et	f	\N
132029	tänapäevase	"täna+päevane %päeva  )NE_aA  <täna+päev ;22_S	et	f	\N
132032	asukaid	asukaid =asuka  (PlP  >asukas !02_S	et	f	\N
132033	asukaid	asukaid =kai  (PlN  >asu+kai !26_S	et	f	\N
132034	asukaid	asukaid =kai  (SgP  >asu+kai !26_S	et	f	\N
132039	maksaksid	maksaksid =maksa  (KndPrSg2  >maksma !32_V	et	f	\N
132040	maksaksid	maksaksid =maksa  (KndPrPl3  >maksma !32_V	et	f	\N
132047	maakundade	?maakundade =kunda  (PlG  >maa+kunda !16_S	et	f	\N
132076	säilitasid	säilitasid =säilita  (IndIpfSg2  >säilitama !27_V	et	f	\N
132077	säilitasid	säilitasid =säilita  (IndIpfPl3  >säilitama !27_V	et	f	\N
132087	vilniuses	?vilniuses =vilniuse  (SgIn  >vilnius !11_S	et	f	\N
132093	deklaratsiooni	deklaratsiooni =deklaratsiooni  (SgG  >deklaratsioon !22_S	et	f	\N
132094	deklaratsiooni	deklaratsiooni =deklaratsiooni  (SgP  >deklaratsioon !22_S	et	f	\N
132095	deklaratsiooni	deklaratsiooni =deklaratsiooni  (SgAdt  >deklaratsioon !22_S	et	f	\N
132116	munt	?munt =munt  (SgN  >munt !22_S	et	f	\N
132132	akesküla	?akesküla =akesküla  (SgN  >akesküla !01_S	et	f	\N
132133	akesküla	?akesküla =akesküla  (SgG  >akesküla !01_S	et	f	\N
132144	vabamaks	vabamaks =vabama  (SgTr  >vabam !02_A	et	f	\N
132145	vabamaks	"vabam %vaba  )M_cA  <vaba ;17_A	et	f	\N
132146	vabamaks	vabamaks =maks  (SgN  >vaba+maks !22_S	et	f	\N
132157	öölaulupidu	öölaulupidu =pidu  (SgN  >öö+laulu+pidu !17_S	et	f	\N
132158	öölaulupidu	öölaulupidu =pidu  (SgN  >öö+laulu+pidu !18_S	et	f	\N
132159	öölaulupidu	öölaulupidu =pidu  (SgG  >öö+laulu+pidu !17_S	et	f	\N
132160	öölaulupidu	öölaulupidu =pidu  (SgP  >öö+laulu+pidu !17_S	et	f	\N
132161	öölaulupidu	öölaulupidu =pidu  (SgP  >öö+laulu+pidu !18_S	et	f	\N
132166	lähenemiseks	lähenemiseks =lähenemise  (SgTr  >lähenemine !12_S	et	f	\N
132167	lähenemiseks	"lähenemine %lähene  )MINE_vS  <lähenema ;27_V	et	f	\N
132176	tetsheri	?tetsheri =tetsheri  (SgN  >tetsheri !01_S	et	f	\N
132177	tetsheri	?tetsheri =tetsheri  (SgG  >tetsheri !01_S	et	f	\N
132178	tetsheri	?tetsheri =tetsheri  (SgG  >tetsher !02_S	et	f	\N
132182	reformid	reformid =reformi  (PlN  >reform !22_S	et	f	\N
132183	reformid	reformid =reformi  (IndPrSg2  >reformima !28_V	et	f	\N
132193	nhrushov	?nhrushov =nhrushov  (SgN  >nhrushov !02_A	et	f	\N
132225	lootuse	lootuse =lootuse  (SgG  >lootus !11~09_S	et	f	\N
132117	ajaloolisi	ajaloolisi =loolisi  (PlP  >aja+looline !12_A	et	f	\N
132118	ajaloolisi	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
132119	ajaloolisi	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
132120	ajaloolisi	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
132121	ajaloolisi	ajaloolisi =loolisi  (PlP  >aja+looline !12_S	et	f	\N
132142	pärt	?pärt =pärt  (SgN  >pärt !22_S	et	f	\N
132149	ahistatud	ahistatud =ahista  (PtsPtIps  >ahistama !27_V	et	f	\N
132150	ahistatud	ahistatud =ahistatu  (PlN  >ahistatu !01_S	et	f	\N
132151	ahistatud	"ahistatu %ahista  )TU1_vS  <ahistama ;27_V	et	f	\N
132152	ahistatud	ahistatud =ahistatud  (ID  >ahistatud !41_A	et	f	\N
132153	ahistatud	"ahistatud %ahista  )TUD_vA  <ahistama ;27_V	et	f	\N
132164	laulval	laulval =laulva  (SgAd  >laulev !02_A	et	f	\N
132165	laulval	"laulev %laul  )V_vA  <laulma ;33_V	et	f	\N
132168	üliolulinerahvas	?üliolulinerahvas =üliolulinerahva  (SgIn  >üliolulinerahva !16_S	et	f	\N
132169	üliolulinerahvas	?üliolulinerahvas =linerahva  (SgIn  >üli+olu+linerahva !16_S	et	f	\N
132170	üliolulinerahvas	?üliolulinerahvas =olulinerahva  (SgIn  >üli+olulinerahva !16_S	et	f	\N
132172	halvenemisest	halvenemisest =halvenemise  (SgEl  >halvenemine !12_S	et	f	\N
132173	halvenemisest	"halvenemine %halvene  )MINE_vS  <halvenema ;27_V	et	f	\N
132196	rihma	rihma =rihma  (SgG  >rihm !22_S	et	f	\N
132197	rihma	rihma =rihma  (SgP  >rihm !22_S	et	f	\N
132198	rihma	rihma =rihma  (SgAdt  >rihm !22_S	et	f	\N
132199	rihma	rihma =rihma  (IndPrPs_  >rihmama !29_V	et	f	\N
132200	rihma	rihma =rihma  (ImpPrSg2  >rihmama !29_V	et	f	\N
132201	surutud	surutud =suru  (PtsPtIps  >suruma !27_V	et	f	\N
132202	surutud	surutud =surutu  (PlN  >surutu !01_AS	et	f	\N
132203	surutud	"surutu %suru  )TU1_vS  <suruma ;27_V	et	f	\N
132204	surutud	"surutu %suru  )TU2_kA  <suru ;17_S	et	f	\N
132205	surutud	surutud =surutud  (ID  >surutud !41_A	et	f	\N
132206	surutud	"surutud %suru  )TUD_vA  <suruma ;27_V	et	f	\N
132210	erakorraline	erakorraline =korraline  (SgN  >era+korraline !12_AS	et	f	\N
132211	erakorraline	"era+korraline %korra  )LINE_aA  <era+kord ;22_S	et	f	\N
132223	tabas	tabas =taba  (SgIn  >taba !17_S	et	f	\N
132224	tabas	tabas =taba  (IndIpfSg3  >tabama !27_V	et	f	\N
132231	suutsid	suutsid =suut  (IndIpfSg2  >suutma !34_V	et	f	\N
132232	suutsid	suutsid =suut  (IndIpfPl3  >suutma !34_V	et	f	\N
132248	putshi	?putshi =putshi  (SgN  >putshi !01_S	et	f	\N
132249	putshi	?putshi =putshi  (SgG  >putshi !01_S	et	f	\N
132250	putshi	?putshi =putshi  (SgG  >putsh !22_S	et	f	\N
132251	putshi	?putshi =putshi  (SgP  >putsh !22_S	et	f	\N
132252	putshi	?putshi =putshi  (SgAdt  >putsh !22_S	et	f	\N
132253	putshi	?putshi =putshi  (IndPrPs_  >putshima !28_V	et	f	\N
132254	putshi	?putshi =putshi  (ImpPrSg2  >putshima !28_V	et	f	\N
132255	mõndagi	mõndagi =mõn  (SgAdt^  >mõni !20_P	et	f	\N
132256	mõndagi	mõndagi =mõn  (SgP^  >mõni !20_P	et	f	\N
132289	õpiks	õpiks =õpi  (SgTr  >õpp !22_S	et	f	\N
132290	õpiks	õpiks =õpi  (KndPrPs  >õppima !28_V	et	f	\N
132305	paradiisi	paradiisi =paradiisi  (SgG  >paradiis !22_S	et	f	\N
132307	paradiisi	paradiisi =paradiisi  (SgP  >paradiis !22_S	et	f	\N
132308	paradiisi	paradiisi =paradiisi  (SgAdt  >paradiis !22_S	et	f	\N
132352	pärisorja	pärisorja =orja  (SgG  >päris+ori !24_S	et	f	\N
132353	pärisorja	pärisorja =orja  (SgP  >päris+ori !24_S	et	f	\N
132354	pärisorja	pärisorja =orja  (SgAdt  >päris+ori !24_S	et	f	\N
132361	jannsen	?jannsen =jannse  (IndPrSg1  >jannsema !27_V	et	f	\N
132362	jannsen	?jannsen =jannsen  (SgN  >jannsen !02_S	et	f	\N
132421	kontrollinud	kontrollinud =kontrolli  (PtsPtPs  >kontrollima !28_V	et	f	\N
132422	kontrollinud	kontrollinud =kontrollinu  (PlN  >kontrollinu !01_S	et	f	\N
132423	kontrollinud	"kontrollinu %kontrolli  )NU_vS  <kontrollima ;28_V	et	f	\N
132424	kontrollinud	kontrollinud =kontrollinud  (ID  >kontrollinud !41_A	et	f	\N
132425	kontrollinud	"kontrollinud %kontrolli  )NUD_vA  <kontrollima ;28_V	et	f	\N
132444	100-liikmeline	-liikmeline =liikmeline  (SgN  >-liikmeline !12_A	et	f	\N
132445	100-liikmeline	"-liikmeline %liikme  )LINE_aA  <-liige ;05_S	et	f	\N
132448	kpäts	?kpäts =kpäts  (SgN  >kpäts !22_S	et	f	\N
132453	vähemusrahvaste	vähemusrahvaste =rahvas  (PlG  >vähemus+rahvas !07_S	et	f	\N
132454	vähemusrahvaste	vähemusrahvaste =rahvas  (PlG  >vähemus+rahvane !10_A	et	f	\N
132455	vähemusrahvaste	"vähemus+rahvane %rahva  )NE_aA  <vähemus+rahvas ;07_S	et	f	\N
132491	1941a	### 1941a	et	f	\N
132492	keelati	keelati =keela  (IndIpfIps  >keelama !29_V	et	f	\N
132493	keelati	keelati =ati  (SgG  >keel+att !22_S	et	f	\N
132497	hrustsovi	?hrustsovi =hrustsovi  (ID  >hrustsovi !41_D	et	f	\N
132498	hrustsovi	?hrustsovi =hrustsovi  (SgG  >hrustsov !02_A	et	f	\N
132525	öölaulupidude	öölaulupidude =pidu  (PlG  >öö+laulu+pidu !17_S	et	f	\N
132526	öölaulupidude	öölaulupidude =pidu  (PlG  >öö+laulu+pidu !18_S	et	f	\N
132532	juhiks	juhiks =juhi  (SgTr  >juht !22_S	et	f	\N
132533	juhiks	juhiks =juhi  (KndPrPs  >juhtima !28_V	et	f	\N
132544	suurendamine	suurendamine =suurendamine  (SgN  >suurendamine !12_S	et	f	\N
132545	suurendamine	"suurendamine %suurenda  )MINE_vS  <suurendama ;27_V	et	f	\N
132137	vtormis	?vtormis =vtormi  (SgIn  >vtorm !22_S	et	f	\N
132138	vtormis	?vtormis =vtormi  (IndIpfSg3  >vtormima !28_V	et	f	\N
132141	vtormis	?vtormis =vtormis  (SgN  >vtormis !09_S	et	f	\N
132162	tõene	tõene =tõene  (SgN  >tõene !10_A	et	f	\N
132163	tõene	"tõene %tõe  )NE_aA  <tõde ;18_S	et	f	\N
132171	gorbatshov	?gorbatshov =gorbatshov  (SgN  >gorbatshov !02_A	et	f	\N
132179	nl	### nl	et	f	\N
132194	lõtvestas	?lõtvestas =lõtvesta  (SgIn  >lõtvesta !01_S	et	f	\N
132195	lõtvestas	?lõtvestas =lõtvesta  (IndIpfSg3  >lõtvestama !27_V	et	f	\N
132207	kuulutatud	kuulutatud =kuuluta  (PtsPtIps  >kuulutama !27_V	et	f	\N
132208	kuulutatud	kuulutatud =kuulutatu  (PlN  >kuulutatu !01_S	et	f	\N
132209	kuulutatud	"kuulutatu %kuuluta  )TU1_vS  <kuulutama ;27_V	et	f	\N
132212	kuulutatud	kuulutatud =kuulutatud  (ID  >kuulutatud !41_A	et	f	\N
132213	kuulutatud	"kuulutatud %kuuluta  )TUD_vA  <kuulutama ;27_V	et	f	\N
132216	toimunut	toimunut =toimunu  (SgP  >toimunu !01_S	et	f	\N
132217	toimunut	"toimunu %toimu  )NU_vS  <toimuma ;27_V	et	f	\N
132257	võitnud	võitnud =võit  (PtsPtPs  >võitma !34_V	et	f	\N
132258	võitnud	võitnud =võitnu  (PlN  >võitnu !01_S	et	f	\N
132259	võitnud	"võitnu %võit  )NU_vS  <võitma ;34_V	et	f	\N
132260	võitnud	võitnud =võitnud  (ID  >võitnud !41_A	et	f	\N
132261	võitnud	"võitnud %võit  )NUD_vA  <võitma ;34_V	et	f	\N
132275	dogmaatikast	dogmaatikast =dogmaatika  (SgEl  >dogmaatika !01_S	et	f	\N
132277	dogmaatikast	dogmaatikast =dogmaatikas  (SgP  >dogmaatikane !12_A	et	f	\N
132278	dogmaatikast	"dogmaatikane %dogmaatika  )NE_aA  <dogmaatika ;01_S	et	f	\N
132279	prantsusmaa	prantsusmaa =maa  (SgN  >prantsus+maa !26_S	et	f	\N
132280	prantsusmaa	prantsusmaa =maa  (SgG  >prantsus+maa !26_S	et	f	\N
132281	100-aastase	-aastase =aastase  (SgG  >-aastane !12~10_A	et	f	\N
132282	100-aastase	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
132283	100-aastase	-aastase =tase  (SgN  >-aas+tase !04_S	et	f	\N
132310	mõistes	mõistes =mõist  (Ger  >mõistma !34_V	et	f	\N
132311	mõistes	mõistes =mõiste  (SgIn  >mõiste !06_S	et	f	\N
132312	mõistes	mõistes =mõiste  (PlIn  >mõist !22_S	et	f	\N
132321	1õpetatud	õpetatud =õpeta  (PtsPtIps  >õpetama !27_V	et	f	\N
132322	1õpetatud	õpetatud =õpetatu  (PlN  >õpetatu !01_S	et	f	\N
132323	1õpetatud	"õpetatu %õpeta  )TU1_vS  <õpetama ;27_V	et	f	\N
132324	1õpetatud	õpetatud =õpetatud  (ID  >õpetatud !41_A	et	f	\N
132325	1õpetatud	"õpetatud %õpeta  )TUD_vA  <õpetama ;27_V	et	f	\N
132355	eestikeelseks	eestikeelseks =seks  (SgN  >eesti+keel+seks !22_S	et	f	\N
132356	eestikeelseks	eestikeelseks =keelse  (SgTr  >eesti+keelne !02_A	et	f	\N
132359	ilmalikku	ilmalikku =ilmalikku  (SgP  >ilmalik !25_A	et	f	\N
132360	ilmalikku	ilmalikku =ilmalikku  (SgAdt  >ilmalik !25_A	et	f	\N
132369	liideriks	liideriks =liideri  (SgTr  >liider !02_S	et	f	\N
132370	liideriks	liideriks =iks  (SgN  >liider+iks !22_S	et	f	\N
132388	vanglasse	vanglasse =vangla  (SgIll  >vangla !01_S	et	f	\N
132391	vanglasse	vanglasse =vanglas  (SgAdt  >vanglane !12_S	et	f	\N
132393	vanglasse	"vanglane %vangla  )NE_aA  <vangla ;01_S	et	f	\N
132395	saatmise	saatmise =saatmise  (SgG  >saatmine !12?10_S	et	f	\N
132397	saatmise	"saatmine %saat  )MINE_vS  <saatma ;34_V	et	f	\N
132413	kultuuriajaloos	kultuuriajaloos =loo  (SgIn  >kultuuri+aja+lugu !18_S	et	f	\N
132414	kultuuriajaloos	kultuuriajaloos =loo  (SgIn  >kultuuri+aja+loog !22_S	et	f	\N
132415	kultuuriajaloos	kultuuriajaloos =loo  (SgIn  >kultuuri+aja+lood !22_S	et	f	\N
132416	kultuuriajaloos	kultuuriajaloos =loos  (SgN  >kultuuri+aja+loos !22_S	et	f	\N
132432	kuulevust	kuulevust =kuulevus  (SgP  >kuulevus !11_S	et	f	\N
132434	kuulevust	"kuulevus %kuuleva  )US_aS  <kuulev ;02_A	et	f	\N
132449	võisid	võisid =või  (PlP  >või !26_S	et	f	\N
132450	võisid	võisid =või  (IndIpfSg2  >võima !37_V	et	f	\N
132451	võisid	võisid =või  (IndIpfPl3  >võima !37_V	et	f	\N
132460	moskvale	?moskvale =moskvale  (IndPrPs_  >moskvalema !27_V	et	f	\N
132461	moskvale	?moskvale =moskvale  (ImpPrSg2  >moskvalema !27_V	et	f	\N
132468	laevaehitus	laevaehitus =ehitu  (SgIn  >laeva+ehitu !01_AS	et	f	\N
132469	laevaehitus	laevaehitus =ehitus  (SgN  >laeva+ehitus !11_S	et	f	\N
132470	märgatav	märgatav =märga  (PtsPrIps  >märkama !29_V	et	f	\N
132471	märgatav	märgatav =märgatav  (SgN  >märgatav !02_A	et	f	\N
132472	märgatav	"märgatav %märga  )TAV_vAS  <märkama ;29_V	et	f	\N
132474	1928a	### 1928a	et	f	\N
132484	töölisasulaid	töölisasulaid =laid  (SgN  >töölis+asu+laid !22_S	et	f	\N
132485	töölisasulaid	töölisasulaid =asula  (PlP  >töölis+asula !01_S	et	f	\N
132509	taastus	taastus =taastu  (IndIpfSg3  >taastuma !27_V	et	f	\N
132511	taastus	taastus =taastus  (SgN  >taastus !11~09_S	et	f	\N
132512	taastus	"taastus %taasta  )US_vS  <taastama ;27_V	et	f	\N
132527	võimuvahetus	võimuvahetus =vahetu  (SgIn  >võimu+vahetu !01_A	et	f	\N
132528	võimuvahetus	"võimu+vahetu %vahe  )TU2_kA  <võimu+vahe ;16_S	et	f	\N
132529	võimuvahetus	võimuvahetus =vahetus  (SgN  >võimu+vahetus !11_S	et	f	\N
132530	võimuvahetus	"võimu+vahetus %vahe  )TUS2_aS  <võimu+vahe ;16_S	et	f	\N
132546	kogunesid	kogunesid =kogune  (IndIpfSg2  >kogunema !27_V	et	f	\N
132220	estis	?estis =esti  (SgIn  >est !22_S	et	f	\N
132221	estis	?estis =esti  (IndIpfSg3  >estima !28_V	et	f	\N
132222	estis	?estis =estis  (SgN  >estis !09_S	et	f	\N
132245	vilniuse	?vilniuse =vilniuse  (SgG  >vilnius !11_S	et	f	\N
132246	verised	verised =verise  (PlN  >verine !10_A	et	f	\N
132247	verised	"verine %veri  )NE_aA  <veri ;20_S	et	f	\N
132268	identiteet	?identiteet =identiteet  (SgN  >identiteet !22_S	et	f	\N
132273	kristlikust	kristlikust =kristliku  (SgEl  >kristlik !25_A	et	f	\N
132274	kristlikust	kristlikust =kristlikus  (SgP  >kristlikus !11_S	et	f	\N
132276	kristlikust	"kristlikus %kristliku  )US_aS  <kristlik ;25_A	et	f	\N
132304	pääsemist	pääsemist =pääsemis  (SgP  >pääsemine !12_S	et	f	\N
132306	pääsemist	"pääsemine %pääse  )MINE_vS  <pääsema ;28_V	et	f	\N
132309	pääsemist	pääsemist =emis  (SgP  >pääs+emis !09_S	et	f	\N
132315	õhutasid	õhutasid =õhuta  (IndIpfSg2  >õhutama !27_V	et	f	\N
132316	õhutasid	õhutasid =õhuta  (IndIpfPl3  >õhutama !27_V	et	f	\N
132326	faehlmanni	?faehlmanni =faehlmanni  (SgN  >faehlmanni !01_S	et	f	\N
132327	faehlmanni	?faehlmanni =faehlmanni  (SgG  >faehlmanni !01_S	et	f	\N
132328	faehlmanni	?faehlmanni =faehlmanni  (SgG  >faehlmann !22_S	et	f	\N
132329	faehlmanni	?faehlmanni =faehlmanni  (SgP  >faehlmann !22_S	et	f	\N
132330	faehlmanni	?faehlmanni =faehlmanni  (SgAdt  >faehlmann !22_S	et	f	\N
132331	faehlmanni	?faehlmanni =faehlmanni  (IndPrPs_  >faehlmannima !28_V	et	f	\N
132332	faehlmanni	?faehlmanni =faehlmanni  (ImpPrSg2  >faehlmannima !28_V	et	f	\N
132340	kokkupanija	kokkupanija =panija  (SgN  >kokku+panija !01_S	et	f	\N
132341	kokkupanija	kokkupanija =panija  (SgG  >kokku+panija !01_S	et	f	\N
132345	aadlike	aadlike =aadlike  (SgN  >aadlike !12_S	et	f	\N
132346	aadlike	"aadlike %aadli  )KE_dS  <aadel ;02_S	et	f	\N
132347	aadlike	aadlike =aadlike  (PlG  >aadlik !25_S	et	f	\N
132357	trükimisi	?trükimisi =trükimisi  (ID  >trükimisi !41_D	et	f	\N
132358	trükimisi	?trükimisi =trükimisi  (PlP  >trükimine !12_S	et	f	\N
132383	postipapa	postipapa =papa  (SgN  >posti+papa !16_S	et	f	\N
132384	postipapa	postipapa =papa  (SgG  >posti+papa !16_S	et	f	\N
132385	köleri	?köleri =köleri  (SgN  >köleri !01_S	et	f	\N
132386	köleri	?köleri =köleri  (SgG  >köleri !01_S	et	f	\N
132387	köleri	?köleri =köleri  (SgG  >köler !02_S	et	f	\N
132389	sattumisest	sattumisest =sattumise  (SgEl  >sattumine !12_S	et	f	\N
132390	sattumisest	"sattumine %sattu  )MINE_vS  <sattuma ;27_V	et	f	\N
132392	sattumisest	"sattumine %sattu  )MINE_vS  <sattuma ;28_V	et	f	\N
132408	uurimises	uurimises =uurimise  (SgIn  >uurimine !12_S	et	f	\N
132409	uurimises	"uurimine %uuri  )MINE_vS  <uurima ;28_V	et	f	\N
132410	arendamises	arendamises =arendamise  (SgIn  >arendamine !12_S	et	f	\N
132411	arendamises	"arendamine %arenda  )MINE_vS  <arendama ;27_V	et	f	\N
132437	represeeriti	?represeeriti =represeeri  (IndIpfIps  >represeerima !28_V	et	f	\N
132438	represeeriti	?represeeriti =represeeriti  (ID  >represeeriti !41_D	et	f	\N
132439	represeeriti	?represeeriti =represeeriti  (SgG  >represeeritt !22_S	et	f	\N
132440	represeeriti	?represeeriti =represeeriti  (IndPrPs_  >represeerittima !28_V	et	f	\N
132441	represeeriti	?represeeriti =represeeriti  (ImpPrSg2  >represeerittima !28_V	et	f	\N
132477	integreerumine	?integreerumine =integreerumine  (SgN  >integreerumine !12_S	et	f	\N
132481	integreerumine	?integreerumine =integreerumine  (PlP  >integreerumin !19_S	et	f	\N
132482	kaevandusi	kaevandusi =kaevandusi  (PlP  >kaevandus !11_S	et	f	\N
132483	kaevandusi	"kaevandus %kaevanda  )US_vS  <kaevandama ;27_V	et	f	\N
132534	lbrezhniv	?lbrezhniv =lbrezhni  (PtsPrPs  >lbrezhnima !28_V	et	f	\N
132535	lbrezhniv	?lbrezhniv =lbrezhniv  (SgN  >lbrezhniv !02_A	et	f	\N
132536	liikmeskonna	liikmeskonna =liikmeskonna  (SgG  >liikmeskond !22_S	et	f	\N
132538	liikmeskonna	liikmeskonna =konna  (SgG  >liikmes+konn !22_S	et	f	\N
132540	liikmeskonna	liikmeskonna =konna  (SgP  >liikmes+konn !22_S	et	f	\N
132541	liikmeskonna	liikmeskonna =konna  (SgAdt  >liikmes+konn !22_S	et	f	\N
132560	suuremate	suuremate =suurema  (PlG  >suurem !02_A	et	f	\N
132561	suuremate	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
132562	suuremate	suuremate =mate  (SgN  >suure+mate !16_S	et	f	\N
132563	suuremate	suuremate =mate  (SgG  >suure+mate !16_S	et	f	\N
132576	püsimuse	püsimuse =püsimuse  (SgG  >püsimus !11_S	et	f	\N
132577	püsimuse	"püsimus %püsi  )MUS_vS  <püsima ;27_V	et	f	\N
132585	väljaspoolt	?väljaspoolt =väljaspoo  (SgAbl  >väljaspoo !26_S	et	f	\N
132587	väljaspoolt	?väljaspoolt =poo  (SgAbl  >väljas+poo !26_S	et	f	\N
132588	väljaspoolt	?väljaspoolt =spoo  (SgAbl  >välja+spoo !26_S	et	f	\N
132589	väljaspoolt	?väljaspoolt =spoolt  (SgN  >välja+spoolt !22_S	et	f	\N
132608	koordis	?koordis =koordi  (SgIn  >koort !22_S	et	f	\N
132609	koordis	?koordis =koordi  (IndIpfSg3  >koordima !28_V	et	f	\N
132610	koordis	?koordis =koordis  (SgN  >koordis !09_S	et	f	\N
132625	usuvabaduse	usuvabaduse =vabaduse  (SgG  >usu+vabadus !11_S	et	f	\N
132626	usuvabaduse	"usu+vabadus %vaba  )US_aS  <usu+vaba ;17_A	et	f	\N
132627	põletamine	põletamine =põletamine  (SgN  >põletamine !12_S	et	f	\N
132628	põletamine	"põletamine %põleta  )MINE_vS  <põletama ;27_V	et	f	\N
132646	balett	?balett =balett  (SgN  >balett !22_S	et	f	\N
132226	lootuse	"lootus %loo  )TUS2_aS  <lugu ;18_S	et	f	\N
132227	lootuse	"lootus %loo  )TUS2_aS  <loog ;22_S	et	f	\N
132228	lootuse	"lootus %loo  )TUS2_aS  <lood ;22_S	et	f	\N
132229	hoidsid	hoidsid =hoid  (IndIpfSg2  >hoidma !34_V	et	f	\N
132230	hoidsid	hoidsid =hoid  (IndIpfPl3  >hoidma !34_V	et	f	\N
132243	värsked	?värsked =värske  (PlN  >värske !01_AS	et	f	\N
132244	värsked	?värsked =värske  (IndPrSg2  >värskema !27_V	et	f	\N
132270	nähtavale	nähtavale =nähtava  (SgAll  >nähtav !02_A	et	f	\N
132271	nähtavale	"nähtav %näh  )TAV_vAS  <nägema ;28_V	et	f	\N
132272	nähtavale	nähtavale =nähtavale  (ID  >nähtavale !41_D	et	f	\N
132302	vabanemist	vabanemist =vabanemis  (SgP  >vabanemine !12_S	et	f	\N
132303	vabanemist	"vabanemine %vabane  )MINE_vS  <vabanema ;27_V	et	f	\N
132313	jutlustajad	jutlustajad =jutlustaja  (PlN  >jutlustaja !01_S	et	f	\N
132314	jutlustajad	"jutlustaja %jutlusta  )JA_vS  <jutlustama ;27_V	et	f	\N
132342	ões-i	ões-i =ões  (SgG  >ões !xx_Q	et	f	\N
132343	ões-i	ões-i =ões  (SgP  >ões !xx_Q	et	f	\N
132344	ões-i	ões-i =ões  (SgAdt  >ões !xx_Q	et	f	\N
132348	talurahvast	talurahvast =rahva  (SgEl  >talu+rahvas !07_S	et	f	\N
132349	talurahvast	talurahvast =rahvas  (SgP  >talu+rahvas !07_S	et	f	\N
132350	talurahvast	talurahvast =rahvas  (SgP  >talu+rahvane !10_A	et	f	\N
132351	talurahvast	"talu+rahvane %rahva  )NE_aA  <talu+rahvas ;07_S	et	f	\N
132363	kogutud	kogutud =kogu  (PtsPtIps  >koguma !27_V	et	f	\N
132364	kogutud	kogutud =kogutu  (PlN  >kogutu !01_AS	et	f	\N
132365	kogutud	"kogutu %kogu  )TU1_vS  <koguma ;27_V	et	f	\N
132366	kogutud	"kogutu %kogu  )TU2_kA  <kogu ;17_S	et	f	\N
132367	kogutud	kogutud =kogutud  (ID  >kogutud !41_A	et	f	\N
132368	kogutud	"kogutud %kogu  )TUD_vA  <koguma ;27_V	et	f	\N
132401	algatusel	algatusel =algatuse  (SgAd  >algatus !11_S	et	f	\N
132402	algatusel	"algatus %algata  )US_vS  <algatama ;27_V	et	f	\N
132403	üldlaulupidu	üldlaulupidu =pidu  (SgN  >üld+laulu+pidu !17_S	et	f	\N
132404	üldlaulupidu	üldlaulupidu =pidu  (SgN  >üld+laulu+pidu !18_S	et	f	\N
132405	üldlaulupidu	üldlaulupidu =pidu  (SgG  >üld+laulu+pidu !17_S	et	f	\N
132406	üldlaulupidu	üldlaulupidu =pidu  (SgP  >üld+laulu+pidu !17_S	et	f	\N
132407	üldlaulupidu	üldlaulupidu =pidu  (SgP  >üld+laulu+pidu !18_S	et	f	\N
132412	ev	### ev	et	f	\N
132417	hrustshovi	?hrustshovi =hrustshovi  (ID  >hrustshovi !41_D	et	f	\N
132418	hrustshovi	?hrustshovi =hrustshovi  (SgG  >hrustshov !02_A	et	f	\N
132419	seisnesid	seisnesid =seisne  (IndIpfSg2  >seisnema !27_V	et	f	\N
132420	seisnesid	seisnesid =seisne  (IndIpfPl3  >seisnema !27_V	et	f	\N
132435	tegutsemist	tegutsemist =tegutsemis  (SgP  >tegutsemine !12_S	et	f	\N
132436	tegutsemist	"tegutsemine %tegutse  )MINE_vS  <tegutsema ;27_V	et	f	\N
132442	keelseks	keelseks =keelse  (SgTr  >keelne !02_A	et	f	\N
132443	keelseks	keelseks =seks  (SgN  >keel+seks !22_S	et	f	\N
132452	1925a	### 1925a	et	f	\N
132458	õppeasutused	õppeasutused =asutuse  (PlN  >õppe+asutus !11_S	et	f	\N
132459	õppeasutused	"õppe+asutus %asu  )TUS2_aS  <õppe+asu ;17_S	et	f	\N
132462	majanduselu	majanduselu =elu  (SgN  >majandus+elu !17_S	et	f	\N
132463	majanduselu	majanduselu =elu  (SgG  >majandus+elu !17_S	et	f	\N
132464	majanduselu	majanduselu =elu  (SgP  >majandus+elu !17_S	et	f	\N
132465	leidmisele	leidmisele =leidmise  (SgAll  >leidmine !12?10_S	et	f	\N
132466	leidmisele	"leidmine %leid  )MINE_vS  <leidma ;34_V	et	f	\N
132467	turgpeamised	?turgpeamised =turgpeamise  (PlN  >turgpeamine !10_A	et	f	\N
132478	majandussüsteemi	majandussüsteemi =süsteemi  (SgG  >majandus+süsteem !22_S	et	f	\N
132479	majandussüsteemi	majandussüsteemi =süsteemi  (SgP  >majandus+süsteem !22_S	et	f	\N
132480	majandussüsteemi	majandussüsteemi =süsteemi  (SgAdt  >majandus+süsteem !22_S	et	f	\N
132486	juhtiva	juhtiva =juhtiva  (SgG  >juhtiv !02_A	et	f	\N
132487	juhtiva	"juhtiv %juhti  )V_vA  <juhtima ;28_V	et	f	\N
132488	juhtiva	juhtiva =iva  (SgN  >juht+iva !17_S	et	f	\N
132489	juhtiva	juhtiva =iva  (SgG  >juht+iva !17_S	et	f	\N
132490	juhtiva	juhtiva =iva  (SgP  >juht+iva !17_S	et	f	\N
132494	vabaduses	vabaduses =vabaduse  (SgIn  >vabadus !11_S	et	f	\N
132495	vabaduses	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
132499	muutuma	muutuma =muutu  (Sup  >muutuma !27_V	et	f	\N
132500	muutuma	muutuma =muutuma  (SgG  >muutum !02_A	et	f	\N
132501	muutuma	"muutum %muu  )TUM2_cA  <muu ;26_S	et	f	\N
132513	avatus	avatus =avatu  (SgIn  >avatu !01_AS	et	f	\N
132514	avatus	"avatu %ava  )TU1_vS  <avama ;27_V	et	f	\N
132515	avatus	"avatu %ava  )TU2_kA  <ava ;17_S	et	f	\N
132516	avatus	avatus =avatus  (SgN  >avatus !11_S	et	f	\N
132517	avatus	"avatus %ava  )TUS1_aS  <avama ;27_V	et	f	\N
132518	avatus	"avatus %ava  )TUS2_aS  <ava ;17_S	et	f	\N
132519	laulupeol	laulupeol =peo  (SgAd  >laulu+pidu !18_S	et	f	\N
132520	laulupeol	laulupeol =peo  (SgAd  >laulu+peo !26_S	et	f	\N
132523	60ndatel	?ndatel =ndate  (PlAd  >ndatt !22_S	et	f	\N
132524	60ndatel	?ndatel =ndatel  (SgN  >ndatel !02_S	et	f	\N
132531	nlkp	### nlkp	et	f	\N
132537	kihistumine	kihistumine =kihistumine  (SgN  >kihistumine !12_S	et	f	\N
132267	augustu	?augustu =gustu  (SgG  >au+gustu !16_S	et	f	\N
132269	fek	### fek	et	f	\N
132284	hilinemisega	hilinemisega =hilinemise  (SgKom  >hilinemine !12_S	et	f	\N
132285	hilinemisega	"hilinemine %hiline  )MINE_vS  <hilinema ;27_V	et	f	\N
132286	maakeele	maakeele =kee  (SgAll  >maa+kesi !15_S	et	f	\N
132287	maakeele	maakeele =kee  (SgAll  >maa+kee !26_S	et	f	\N
132288	maakeele	maakeele =keele  (SgG  >maa+keel !13_S	et	f	\N
132291	usulise	usulise =usulise  (SgG  >usuline !12_A	et	f	\N
132292	usulise	"usuline %usu  )LINE_aA  <usk ;22_S	et	f	\N
132293	vennastekoguduslikud	?vennastekoguduslikud =vennastekogudusliku  (PlN  >vennastekoguduslik !25_A	et	f	\N
132294	vennastekoguduslikud	?vennastekoguduslikud =vennastekogudusliku  (IndPrSg2  >vennastekoguduslikuma !27_V	et	f	\N
132295	vennastekoguduslikud	?vennastekoguduslikud =dusliku  (PlN  >vennaste+kogu+duslik !25_A	et	f	\N
132296	vennastekoguduslikud	?vennastekoguduslikud =dusliku  (PlN  >vennaste+kogu+dusliku !01_S	et	f	\N
132297	vennastekoguduslikud	?vennastekoguduslikud =kogudusliku  (PlN  >vennaste+koguduslik !25_A	et	f	\N
132298	vennastekoguduslikud	?vennastekoguduslikud =tekogudusliku  (PlN  >vennas+tekoguduslik !25_A	et	f	\N
132299	vennastekoguduslikud	?vennastekoguduslikud =stekogudusliku  (PlN  >venna+stekoguduslik !25_A	et	f	\N
132300	maisetest	maisetest =e  (PlEl  >mais+esi !15_S	et	f	\N
132301	maisetest	maisetest =sete  (PlEl  >mai+sett !22_S	et	f	\N
132317	röövima	röövima =röövi  (Sup  >röövima !28_V	et	f	\N
132318	röövima	röövima =ima  (SgN  >rööv+ima !17_S	et	f	\N
132319	röövima	röövima =ima  (SgG  >rööv+ima !17_S	et	f	\N
132320	röövima	röövima =ima  (SgP  >rööv+ima !17_S	et	f	\N
132333	vajalikkusest	vajalikkusest =vajalikkuse  (SgEl  >vajalikkus !11~09_S	et	f	\N
132334	vajalikkusest	"vajalikkus %vajalikku  )US_aS  <vajalik ;25_A	et	f	\N
132335	vajalikkusest	vajalikkusest =vajalikkuses  (SgP  >vajalikkusene !12_A	et	f	\N
132336	vajalikkusest	"vajalikkusene %vajalikkuse  )NE_aA  <vajalikkus ;09_S	et	f	\N
132337	vajalikkusest	"vajalikkusene %vajalikkuse  )NE_aA  <vajalikkus ;11_S	et	f	\N
132338	korralda	korralda =korralda  (IndPrPs_  >korraldama !27_V	et	f	\N
132339	korralda	korralda =korralda  (ImpPrSg2  >korraldama !27_V	et	f	\N
132371	aleksandrikooli	?aleksandrikooli =aleksandrikooli  (SgN  >aleksandrikooli !16_S	et	f	\N
132372	aleksandrikooli	?aleksandrikooli =aleksandrikooli  (SgG  >aleksandrikooli !16_S	et	f	\N
132373	aleksandrikooli	?aleksandrikooli =aleksandrikooli  (SgG  >aleksandrikool !22_S	et	f	\N
132374	aleksandrikooli	?aleksandrikooli =aleksandrikooli  (SgP  >aleksandrikool !22_S	et	f	\N
132375	aleksandrikooli	?aleksandrikooli =aleksandrikooli  (SgAdt  >aleksandrikool !22_S	et	f	\N
132376	aleksandrikooli	?aleksandrikooli =aleksandrikooli  (IndPrPs_  >aleksandrikoolima !28_V	et	f	\N
132377	aleksandrikooli	?aleksandrikooli =aleksandrikooli  (ImpPrSg2  >aleksandrikoolima !28_V	et	f	\N
132378	aleksandrikooli	?aleksandrikooli =ksandrikooli  (SgN  >ale+ksandrikooli !16_S	et	f	\N
132379	aleksandrikooli	?aleksandrikooli =ksandrikooli  (SgG  >ale+ksandrikooli !16_S	et	f	\N
132380	aleksandrikooli	?aleksandrikooli =ksandrikooli  (SgG  >ale+ksandrikool !22_S	et	f	\N
132381	aleksandrikooli	?aleksandrikooli =ksandrikooli  (SgP  >ale+ksandrikool !22_S	et	f	\N
132382	aleksandrikooli	?aleksandrikooli =ksandrikooli  (SgAdt  >ale+ksandrikool !22_S	et	f	\N
132394	palvekirju	palvekirju =kirju  (SgN  >palve+kirju !01_A	et	f	\N
132396	palvekirju	palvekirju =kirju  (SgN  >palve+kirju !16_A	et	f	\N
132398	palvekirju	palvekirju =kirju  (SgG  >palve+kirju !01_A	et	f	\N
132399	palvekirju	palvekirju =kirju  (SgG  >palve+kirju !16_A	et	f	\N
132400	palvekirju	palvekirju =kirju  (PlP  >palve+kiri !24_S	et	f	\N
132426	moskvast	?moskvast =moskvas  (SgP  >moskvas !07_S	et	f	\N
132427	moskvast	?moskvast =moskvas  (SgP  >moskvane !12~10_A	et	f	\N
132428	keelanud	keelanud =keela  (PtsPtPs  >keelama !29_V	et	f	\N
132429	keelanud	keelanud =keelanu  (PlN  >keelanu !01_S	et	f	\N
132430	keelanud	"keelanu %keela  )NU_vS  <keelama ;29_V	et	f	\N
132431	keelanud	keelanud =keelanud  (ID  >keelanud !41_A	et	f	\N
132433	keelanud	"keelanud %keela  )NUD_vA  <keelama ;29_V	et	f	\N
132446	riigivanem	riigivanem =vanem  (SgN  >riigi+vanem !02_AS	et	f	\N
132447	riigivanem	"riigi+vanem %vane  )M_cA  <riigi+vana ;17_AS	et	f	\N
132456	pisirahvas	pisirahvas =rahva  (SgIn  >pisi+rahvas !07_S	et	f	\N
132457	pisirahvas	pisirahvas =rahvas  (SgN  >pisi+rahvas !07_S	et	f	\N
132473	evs	?evs =evs  (SgN  >evs !22_S	et	f	\N
132475	tihedam	tihedam =tihedam  (SgN  >tihedam !02_A	et	f	\N
132476	tihedam	"tihedam %tiheda  )M_cA  <tihe ;02_A	et	f	\N
132496	ensvs	?ensvs =ensvs  (SgN  >ensvs !22_S	et	f	\N
132502	eksistentsiaalne	?eksistentsiaalne =eksistentsiaalne  (SgN  >eksistentsiaalne !02_A	et	f	\N
132503	eksistentsiaalne	?eksistentsiaalne =eksistentsiaalne  (PlP  >eksistentsiaaln !22_S	et	f	\N
132504	eksistentsiaalne	?eksistentsiaalne =aalne  (SgN  >eksistentsi+aalne !02_A	et	f	\N
132505	eksistentsiaalne	?eksistentsiaalne =aalne  (PlP  >eksistentsi+aaln !22_S	et	f	\N
132506	eksistentsiaalne	?eksistentsiaalne =stentsiaalne  (SgN  >eksi+stentsiaalne !02_A	et	f	\N
132507	eksistentsiaalne	?eksistentsiaalne =stentsiaalne  (PlP  >eksi+stentsiaaln !22_S	et	f	\N
132508	eksistentsiaalne	?eksistentsiaalne =istentsiaalne  (SgN  >eks+istentsiaalne !02_A	et	f	\N
132510	eksistentsiaalne	?eksistentsiaalne =istentsiaalne  (PlP  >eks+istentsiaaln !22_S	et	f	\N
132521	taaselustumiseks	taaselustumiseks =elustumise  (SgTr  >taas+elustumine !12_S	et	f	\N
132522	taaselustumiseks	"taas+elustumine %elustu  )MINE_vS  <taas+elustuma ;27_V	et	f	\N
132578	toetust	toetust =toetu  (SgEl  >toetu !01_A	et	f	\N
132579	toetust	"toetu %toe  )TU2_kA  <tugi ;21_S	et	f	\N
132580	toetust	toetust =toetus  (SgP  >toetus !11~09_S	et	f	\N
132581	toetust	"toetus %toeta  )US_vS  <toetama ;27_V	et	f	\N
132582	toetust	"toetus %toe  )TUS2_aS  <tugi ;21_S	et	f	\N
132583	toetust	toetust =tust  (SgN  >toe+tust !22_S	et	f	\N
132590	kuriteodest	?kuriteodest =kuriteode  (PlEl  >kuriteot !22_S	et	f	\N
132591	kuriteodest	?kuriteodest =kuriteodes  (SgP  >kuriteodene !12_A	et	f	\N
132592	kuriteodest	?kuriteodest =teo  (PlEl  >kuri+teo !26_S	et	f	\N
132593	kuriteodest	?kuriteodest =teode  (PlEl  >kuri+teot !22_S	et	f	\N
132594	kuriteodest	?kuriteodest =teodes  (SgP  >kuri+teodes !09_S	et	f	\N
132595	kuriteodest	?kuriteodest =teodes  (SgP  >kuri+teodene !10_A	et	f	\N
132606	sotsialistlikku	sotsialistlikku =sotsialistlikku  (SgP  >sotsialistlik !25_A	et	f	\N
132607	sotsialistlikku	sotsialistlikku =sotsialistlikku  (SgAdt  >sotsialistlik !25_A	et	f	\N
132621	tsarivalitsus	?tsarivalitsus =tsarivalitsu  (PlIn  >tsarivalits !22_S	et	f	\N
132622	tsarivalitsus	?tsarivalitsus =tsarivalitsu  (IndIpfSg3  >tsarivalitsuma !27_V	et	f	\N
132623	tsarivalitsus	?tsarivalitsus =tsarivalitsus  (SgN  >tsarivalitsus !11~09_S	et	f	\N
132634	teadustegevuse	teadustegevuse =tegevuse  (SgG  >teadus+tegevus !11_S	et	f	\N
132635	teadustegevuse	"teadus+tegevus %tegeva  )US_aS  <teadus+tegev ;02_A	et	f	\N
132640	mägiste	mägiste =mägis  (PlG  >mägine !10_A	et	f	\N
132642	mägiste	"mägine %mägi  )NE_aA  <mägi ;21_S	et	f	\N
132650	anderson	?anderson =anderson  (SgN  >anderson !19_S	et	f	\N
132652	kunstiajalugu	kunstiajalugu =lugu  (SgN  >kunsti+aja+lugu !18_S	et	f	\N
132653	kunstiajalugu	kunstiajalugu =lugu  (SgP  >kunsti+aja+lugu !18_S	et	f	\N
132667	küüditatud	küüditatud =küüdita  (PtsPtIps  >küüditama !27_V	et	f	\N
132668	küüditatud	küüditatud =küüditatu  (PlN  >küüditatu !01_S	et	f	\N
132669	küüditatud	"küüditatu %küüdita  )TU1_vS  <küüditama ;27_V	et	f	\N
132670	küüditatud	küüditatud =küüditatud  (ID  >küüditatud !41_A	et	f	\N
132671	küüditatud	"küüditatud %küüdita  )TUD_vA  <küüditama ;27_V	et	f	\N
132672	juhtivatel	juhtivatel =juhtiva  (PlAd  >juhtiv !02_A	et	f	\N
132673	juhtivatel	"juhtiv %juhti  )V_vA  <juhtima ;28_V	et	f	\N
132674	juhtivatel	juhtivatel =ate  (PlAd  >juhtiv+att !22_S	et	f	\N
132685	arutlev	arutlev =arutle  (PtsPrPs  >arutlema !27_V	et	f	\N
132686	arutlev	arutlev =arutlev  (SgN  >arutlev !02_A	et	f	\N
132687	arutlev	"arutlev %arutle  )V_vA  <arutlema ;27_V	et	f	\N
132699	harrastav	harrastav =harrasta  (PtsPrPs  >harrastama !27_V	et	f	\N
132700	harrastav	harrastav =harrastav  (SgN  >harrastav !02_A	et	f	\N
132701	harrastav	"harrastav %harrasta  )V_vA  <harrastama ;27_V	et	f	\N
132713	suzeetid	?suzeetid =suzeeti  (PlN  >suzeeti !16_S	et	f	\N
132737	rahvapidu	rahvapidu =pidu  (SgN  >rahva+pidu !17_S	et	f	\N
132738	rahvapidu	rahvapidu =pidu  (SgN  >rahva+pidu !18_S	et	f	\N
132739	rahvapidu	rahvapidu =pidu  (SgG  >rahva+pidu !17_S	et	f	\N
132740	rahvapidu	rahvapidu =pidu  (SgP  >rahva+pidu !17_S	et	f	\N
132741	rahvapidu	rahvapidu =pidu  (SgP  >rahva+pidu !18_S	et	f	\N
132750	kultuurinähtus	kultuurinähtus =nähtu  (SgIn  >kultuuri+nähtu !01_S	et	f	\N
132751	kultuurinähtus	kultuurinähtus =nähtus  (SgN  >kultuuri+nähtus !11~09_S	et	f	\N
132752	laudi	laudi =laudi  (SgN  >laudi !01_S	et	f	\N
132753	laudi	laudi =laudi  (SgG  >laudi !01_S	et	f	\N
132754	laudi	laudi =laudi  (SgG  >laut !22_S	et	f	\N
132755	laudi	laudi =laudi  (SgP  >laud !22_S	et	f	\N
132756	laudi	laudi =laudi  (SgAdt  >laud !22_S	et	f	\N
132757	laudi	laudi =laudi  (PlP  >laud !22_S	et	f	\N
132758	laudi	laudi =laudi  (IndPrPs_  >lautima !28_V	et	f	\N
132759	laudi	laudi =laudi  (ImpPrSg2  >lautima !28_V	et	f	\N
132774	laulutraditsiooni	laulutraditsiooni =traditsiooni  (SgG  >laulu+traditsioon !22_S	et	f	\N
132775	laulutraditsiooni	laulutraditsiooni =traditsiooni  (SgP  >laulu+traditsioon !22_S	et	f	\N
132776	laulutraditsiooni	laulutraditsiooni =traditsiooni  (SgAdt  >laulu+traditsioon !22_S	et	f	\N
132782	regilaulu	regilaulu =laulu  (SgG  >regi+laul !22_S	et	f	\N
132783	regilaulu	regilaulu =laulu  (SgP  >regi+laul !22_S	et	f	\N
132784	regilaulu	regilaulu =laulu  (SgAdt  >regi+laul !22_S	et	f	\N
132789	eeslaulja	eeslaulja =laulja  (SgN  >ees+laulja !01_S	et	f	\N
132790	eeslaulja	eeslaulja =laulja  (SgG  >ees+laulja !01_S	et	f	\N
132798	laulumisega	laulumisega =lumise  (SgKom  >lau+lumine !10_A	et	f	\N
132799	laulumisega	"lau+lumine %lumi  )NE_aA  <lau+lumi ;20_S	et	f	\N
132813	tarapita	?tarapita =tarapi  (SgAb  >tarapi !01_S	et	f	\N
132814	tarapita	?tarapita =tarapi  (SgAb  >tarap !02_S	et	f	\N
132815	tarapita	?tarapita =tarapi  (SgAb  >tarapp !22_S	et	f	\N
132816	tarapita	?tarapita =tarapi  (IndPrIps_  >tarappima !28_V	et	f	\N
132817	tarapita	?tarapita =tarapita  (IndPrPs_  >tarapitama !27_V	et	f	\N
132818	tarapita	?tarapita =tarapita  (ImpPrSg2  >tarapitama !27_V	et	f	\N
132836	näitek	?näitek =näitek  (SgN  >näitek !02_S	et	f	\N
132858	loomust	loomust =loomu  (SgEl  >loom !22_S	et	f	\N
132539	kihistumine	"kihistumine %kihistu  )MINE_vS  <kihistuma ;27_V	et	f	\N
132542	asjaajamisele	asjaajamisele =ajamise  (SgAll  >asja+ajamine !12_S	et	f	\N
132543	asjaajamisele	"asja+ajamine %ajami  )NE_aA  <asja+ajam ;02_S	et	f	\N
132554	kakskeelsust	kakskeelsust =keelsus  (SgP  >kaks+keelsus !11~09_S	et	f	\N
132555	kakskeelsust	"kaks+keelsus %keelse  )US_aS  <kaks+keelne ;02_A	et	f	\N
132565	üleskutse	üleskutse =kutse  (SgN  >üles+kutse !06_S	et	f	\N
132566	üleskutse	üleskutse =kutse  (SgG  >üles+kutse !06_S	et	f	\N
132567	üleskutse	üleskutse =kutse  (PlP  >üles+kuts !22_S	et	f	\N
132569	vaino	?vaino =vaino  (SgN  >vaino !16_S	et	f	\N
132571	vaino	?vaino =vaino  (SgG  >vaino !16_S	et	f	\N
132574	nõudmisest	nõudmisest =nõudmise  (SgEl  >nõudmine !12?10_S	et	f	\N
132575	nõudmisest	"nõudmine %nõud  )MINE_vS  <nõudma ;34_V	et	f	\N
132601	tuntumaid	tuntumaid =tuntuma  (PlP  >tuntum !02_A	et	f	\N
132602	tuntumaid	"tuntum %tun  )TUM1_cA  <tundma ;34_V	et	f	\N
132603	uurimissuundi	uurimissuundi =suundi  (SgP  >uurimis+suund !22_S	et	f	\N
132604	uurimissuundi	uurimissuundi =suundi  (SgAdt  >uurimis+suund !22_S	et	f	\N
132605	uurimissuundi	uurimissuundi =suundi  (PlP  >uurimis+suund !22_S	et	f	\N
132639	saareste	saareste =saares  (PlG  >saarene !10_A	et	f	\N
132641	saareste	"saarene %saare  )NE_aA  <saar ;13_S	et	f	\N
132656	ühismälu	ühismälu =mälu  (SgN  >ühis+mälu !17_S	et	f	\N
132657	ühismälu	ühismälu =mälu  (SgG  >ühis+mälu !17_S	et	f	\N
132659	ühismälu	ühismälu =mälu  (SgP  >ühis+mälu !17_S	et	f	\N
132666	iseseisvapõllumehed	### iseseisvapõllumehed	et	f	\N
132680	juhtiw	### juhtiw	et	f	\N
132683	pikkus	pikkus =pikkus  (SgN  >pikkus !11~09_S	et	f	\N
132684	pikkus	"pikkus %pikk  )US_aS  <pikk ;22_AS	et	f	\N
132706	eestlast	eestlast =eestlas  (SgP  >eestlane !12?10_S	et	f	\N
132710	eestlast	eestlast =la  (SgEl  >eest+la !26_S	et	f	\N
132711	eestlast	eestlast =las  (SgP  >eest+laps !14_S	et	f	\N
132712	eestlast	eestlast =last  (SgN  >eest+last !22_S	et	f	\N
132725	instrumentid	### instrumentid	et	f	\N
132742	laulmine	laulmine =laulmine  (SgN  >laulmine !12?10_S	et	f	\N
132743	laulmine	"laulmine %laul  )MINE_vS  <laulma ;33_V	et	f	\N
132796	laulurahvas	laulurahvas =rahva  (SgIn  >laulu+rahvas !07_S	et	f	\N
132797	laulurahvas	laulurahvas =rahvas  (SgN  >laulu+rahvas !07_S	et	f	\N
132825	maalev	?maalev =maale  (PtsPrPs  >maalema !27_V	et	f	\N
132826	maalev	?maalev =maalev  (SgN  >maalev !02_A	et	f	\N
132828	võistlesid	võistlesid =võistle  (IndIpfSg2  >võistlema !30_V	et	f	\N
132829	võistlesid	võistlesid =võistle  (IndIpfPl3  >võistlema !30_V	et	f	\N
132830	osast	osast =osa  (SgEl  >osa !17_S	et	f	\N
132831	osast	osast =osas  (SgP  >osane !10_A	et	f	\N
132832	osast	"osane %osa  )NE_aA  <osa ;17_S	et	f	\N
132838	kooris	kooris =koori  (SgIn  >koor !22_S	et	f	\N
132839	kooris	kooris =koori  (PlIn  >koor !13_S	et	f	\N
132840	kooris	kooris =koori  (IndIpfSg3  >koorima !28_V	et	f	\N
132841	uhekesi	?uhekesi =uhekesi  (ID  >uhekesi !41_D	et	f	\N
132842	uhekesi	?uhekesi =uhekesi  (PlP  >uheke !12_S	et	f	\N
132843	uhekesi	?uhekesi =uhekesi  (PlP  >uhekene !12_S	et	f	\N
132846	iseloomustama	?iseloomustama =iseloomusta  (Sup  >iseloomustama !27_V	et	f	\N
132847	iseloomustama	?iseloomustama =iseloomustama  (SgG  >iseloomustam !02_A	et	f	\N
132848	iseloomustama	?iseloomustama =ama  (SgN  >ise+loo+must+ama !17_S	et	f	\N
132849	iseloomustama	?iseloomustama =ama  (SgG  >ise+loo+must+ama !17_S	et	f	\N
132850	iseloomustama	?iseloomustama =ama  (SgP  >ise+loo+must+ama !17_S	et	f	\N
132851	iseloomustama	?iseloomustama =stama  (SgN  >ise+loomu+stama !17_S	et	f	\N
132852	iseloomustama	?iseloomustama =stama  (SgG  >ise+loomu+stama !17_S	et	f	\N
132853	iseloomustama	?iseloomustama =stama  (SgP  >ise+loomu+stama !17_S	et	f	\N
132854	iseloomustama	?iseloomustama =ustama  (SgG  >ise+loom+ustam !02_A	et	f	\N
132855	iseloomustama	?iseloomustama =mustama  (SgG  >ise+loo+mustam !02_A	et	f	\N
132856	iseloomustama	?iseloomustama =loomusta  (Sup  >ise+loomustama !27_V	et	f	\N
132857	iseloomustama	?iseloomustama =loomustama  (SgG  >ise+loomustam !02_A	et	f	\N
132862	organisaat	?organisaat =organisaat  (SgN  >organisaat !22_S	et	f	\N
132863	võtjate	võtjate =võtja  (PlG  >võtja !01_S	et	f	\N
132864	võtjate	"võtja %võt  )JA_vS  <võtma ;35_V	et	f	\N
132865	puhkata	?puhkata =puhka  (SgAb  >puhka !16_S	et	f	\N
132866	puhkata	?puhkata =puhkata  (IndPrPs_  >puhkatama !27_V	et	f	\N
132867	puhkata	?puhkata =puhkata  (ImpPrSg2  >puhkatama !27_V	et	f	\N
132877	uuemad	uuemad =uuema  (PlN  >uuem !02_A	et	f	\N
132878	uuemad	"uuem %uue  )M_cA  <uus ;14_A	et	f	\N
132879	kujunenud	kujunenud =kujune  (PtsPtPs  >kujunema !27_V	et	f	\N
132880	kujunenud	kujunenud =kujunenu  (PlN  >kujunenu !01_S	et	f	\N
132881	kujunenud	"kujunenu %kujune  )NU_vS  <kujunema ;27_V	et	f	\N
132882	kujunenud	kujunenud =kujunenud  (ID  >kujunenud !41_A	et	f	\N
132883	kujunenud	"kujunenud %kujune  )NUD_vA  <kujunema ;27_V	et	f	\N
132884	laulnud	laulnud =laul  (PtsPtPs  >laulma !33_V	et	f	\N
132885	laulnud	laulnud =laulnu  (PlN  >laulnu !01_S	et	f	\N
132886	laulnud	"laulnu %laul  )NU_vS  <laulma ;33_V	et	f	\N
132547	kogunesid	kogunesid =kogune  (IndIpfPl3  >kogunema !27_V	et	f	\N
132556	öölaulupeol	öölaulupeol =peo  (SgAd  >öö+laulu+pidu !18_S	et	f	\N
132557	öölaulupeol	öölaulupeol =peo  (SgAd  >öö+laulu+peo !26_S	et	f	\N
132568	meelsema	meelsema =meelsema  (SgG  >meelsem !02_A	et	f	\N
132570	meelsema	"meelsem %meelse  )M_cA  <meelne ;02_A	et	f	\N
132584	parteid	parteid =partei  (PlN  >partei !26_S	et	f	\N
132586	parteid	parteid =partei  (SgP  >partei !26_S	et	f	\N
132598	iseloomusta	iseloomusta =musta  (SgG  >ise+loo+must !22_AS	et	f	\N
132599	iseloomusta	iseloomusta =musta  (SgP  >ise+loo+must !22_AS	et	f	\N
132600	iseloomusta	iseloomusta =musta  (SgAdt  >ise+loo+must !22_AS	et	f	\N
132611	alguseks	alguseks =alguse  (SgTr  >algus !11~09_S	et	f	\N
132612	alguseks	alguseks =seks  (SgN  >algu+seks !22_S	et	f	\N
132613	alguseks	alguseks =use  (PlTr  >alg+usk !22_S	et	f	\N
132614	rahutuste	rahutuste =rahutus  (PlG  >rahutus !11_S	et	f	\N
132615	rahutuste	"rahutus %rahu  )TUS2_aS  <rahu ;17_S	et	f	\N
132616	rahutuste	rahutuste =tuste  (PlP  >rahu+tust !22_S	et	f	\N
132624	demokratlikke	?demokratlikke =demokratlikke  (PlP  >demokratlik !25_A	et	f	\N
132629	põllumajanduslikkel	?põllumajanduslikkel =põllumajanduslikkel  (SgN  >põllumajanduslikkel !02_S	et	f	\N
132630	põllumajanduslikkel	?põllumajanduslikkel =majanduslikkel  (SgN  >põllu+majanduslikkel !02_S	et	f	\N
132631	helikunsti	helikunsti =kunsti  (SgG  >heli+kunst !22_S	et	f	\N
132632	helikunsti	helikunsti =kunsti  (SgP  >heli+kunst !22_S	et	f	\N
132633	helikunsti	helikunsti =kunsti  (SgAdt  >heli+kunst !22_S	et	f	\N
132636	viljelemine	viljelemine =viljelemine  (SgN  >viljelemine !12_S	et	f	\N
132637	viljelemine	"viljelemine %viljele  )MINE_vS  <viljelema ;27_V	et	f	\N
132638	viljelemine	"viljelemine %viljele  )MINE_vS  <viljelema ;31_V	et	f	\N
132643	keeleuuendaja	keeleuuendaja =uuendaja  (SgN  >keele+uuendaja !01_S	et	f	\N
132644	keeleuuendaja	keeleuuendaja =uuendaja  (SgG  >keele+uuendaja !01_S	et	f	\N
132654	üksteise	üksteise =teise  (SgAdt  >üks+teise !12_P	et	f	\N
132655	üksteise	üksteise =teise  (SgG  >üks+teise !12_P	et	f	\N
132675	taastamine	taastamine =taastamine  (SgN  >taastamine !12_S	et	f	\N
132676	taastamine	"taastamine %taasta  )MINE_vS  <taastama ;27_V	et	f	\N
132688	analüüsiv	analüüsiv =analüüsi  (PtsPrPs  >analüüsima !28_V	et	f	\N
132689	analüüsiv	analüüsiv =analüüsiv  (SgN  >analüüsiv !02_A	et	f	\N
132690	analüüsiv	"analüüsiv %analüüsi  )V_vA  <analüüsima ;28_V	et	f	\N
132702	arusaamatuid	arusaamatuid =tui  (PlN  >aru+saama+tui !26_S	et	f	\N
132703	arusaamatuid	arusaamatuid =tui  (SgP  >aru+saama+tui !26_S	et	f	\N
132704	arusaamatuid	arusaamatuid =saamatu  (PlP  >aru+saamatu !01_A	et	f	\N
132705	arusaamatuid	"aru+saamatu %saama  )TU2_kA  <aru+saam ;22_S	et	f	\N
132716	moned	?moned =mone  (PlN  >mone !16_S	et	f	\N
132717	moned	?moned =mone  (IndPrSg2  >monema !27_V	et	f	\N
132718	lauldati	?lauldati =laulda  (IndIpfIps  >lauldama !27_V	et	f	\N
132719	lauldati	?lauldati =laulda  (IndIpfIps  >laultama !29_V	et	f	\N
132720	lauldati	?lauldati =lauldati  (ID  >lauldati !41_D	et	f	\N
132721	lauldati	?lauldati =lauldati  (SgG  >lauldat !02_S	et	f	\N
132722	lauldati	?lauldati =lauldati  (SgG  >lauldatt !22_S	et	f	\N
132723	lauldati	?lauldati =lauldati  (IndPrPs_  >lauldattima !28_V	et	f	\N
132724	lauldati	?lauldati =lauldati  (ImpPrSg2  >lauldattima !28_V	et	f	\N
132726	ülemaaline	ülemaaline =maaline  (SgN  >üle+maaline !12?10_A	et	f	\N
132727	ülemaaline	"üle+maaline %maa  )LINE_aA  <üle+maa ;26_S	et	f	\N
132728	ülemaaline	"üle+maaline %maali  )NE_aA  <üle+maal ;22_S	et	f	\N
132744	tahelepanuvärane	?tahelepanuvärane =tahelepanuvärane  (SgN  >tahelepanuvärane !12_A	et	f	\N
132745	tahelepanuvärane	?tahelepanuvärane =tahelepanuvärane  (PlP  >tahelepanuväran !19_S	et	f	\N
132746	tahelepanuvärane	?tahelepanuvärane =nuvärane  (SgN  >tahe+lepa+nuvärane !12_A	et	f	\N
132747	tahelepanuvärane	?tahelepanuvärane =nuvärane  (PlP  >tahe+lepa+nuväran !19_S	et	f	\N
132748	tahelepanuvärane	?tahelepanuvärane =lepanuvärane  (SgN  >tahe+lepanuvärane !12_A	et	f	\N
132749	tahelepanuvärane	?tahelepanuvärane =lepanuvärane  (PlP  >tahe+lepanuväran !19_S	et	f	\N
132760	rahvalaul	rahvalaul =lau  (SgAd  >rahva+laug !22_SA	et	f	\N
132761	rahvalaul	rahvalaul =laul  (SgN  >rahva+laul !22_S	et	f	\N
132762	asu	asu =asu  (SgN  >asu !17_S	et	f	\N
132763	asu	asu =asu  (SgG  >asu !17_S	et	f	\N
132764	asu	asu =asu  (SgP  >asu !17_S	et	f	\N
132765	asu	asu =asu  (IndPrPs_  >asuma !27_V	et	f	\N
132766	asu	asu =asu  (ImpPrSg2  >asuma !27_V	et	f	\N
132767	lauluga	lauluga =laulu  (SgKom  >laul !22_S	et	f	\N
132768	lauluga	lauluga =luga  (SgN  >lau+luga !18_S	et	f	\N
132769	lauluga	lauluga =luga  (SgP  >lau+luga !18_S	et	f	\N
132770	vanemat	vanemat =vanema  (SgP  >vanem !02_AS	et	f	\N
132772	vanemat	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
132779	kujundenud	?kujundenud =kujundenu  (PlN  >kujundenu !01_S	et	f	\N
132780	kujundenud	?kujundenud =kujundenu  (IndPrSg2  >kujundenuma !27_V	et	f	\N
132781	kujundenud	?kujundenud =kujundenud  (ID  >kujundenud !41_A	et	f	\N
132806	kirikuajast	kirikuajast =aja  (SgEl  >kiriku+aeg !22_S	et	f	\N
132807	kirikuajast	kirikuajast =ajas  (SgP  >kiriku+ajane !10_A	et	f	\N
132548	rahvaslaule	?rahvaslaule =rahvaslau  (SgAll  >rahvaslau !26_S	et	f	\N
132549	rahvaslaule	?rahvaslaule =rahvaslaule  (PlP  >rahvaslaul !19_S	et	f	\N
132550	rahvaslaule	?rahvaslaule =slau  (SgAll  >rahva+slau !26_S	et	f	\N
132551	rahvaslaule	?rahvaslaule =slaule  (SgN  >rahva+slaule !06_S	et	f	\N
132552	rahvaslaule	?rahvaslaule =slaule  (SgG  >rahva+slaule !06_S	et	f	\N
132553	rahvaslaule	?rahvaslaule =slaule  (PlP  >rahva+slaul !22_S	et	f	\N
132558	isamaalaule	isamaalaule =lau  (SgAll  >isa+maa+laug !22_SA	et	f	\N
132559	isamaalaule	isamaalaule =laule  (PlP  >isa+maa+laul !22_S	et	f	\N
132564	tekkell	?tekkell =tekkell  (SgN  >tekkell !22_S	et	f	\N
132572	väljase	väljase =väljase  (SgG  >väljane !10_A	et	f	\N
132573	väljase	"väljane %välja  )NE_aA  <väli ;24_S	et	f	\N
132596	tähtsust	tähtsust =tähtsus  (SgP  >tähtsus !11~09_S	et	f	\N
132597	tähtsust	"tähtsus %tähtsa  )US_aS  <tähtis ;02_A	et	f	\N
132617	mässumeelsuse	mässumeelsuse =meelsuse  (SgG  >mässu+meelsus !11~09_S	et	f	\N
132618	mässumeelsuse	"mässu+meelsus %meelse  )US_aS  <mässu+meelne ;02_A	et	f	\N
132619	tsarimanifest	?tsarimanifest =tsarimanife  (PlEl  >tsarimaniff !22_S	et	f	\N
132620	tsarimanifest	?tsarimanifest =tsarimanifes  (SgP  >tsarimanifene !12_A	et	f	\N
132645	aavik	?aavik =aavik  (SgN  >aavik !02_S	et	f	\N
132651	tamperwe	?tamperwe =tamperwe  (PlP  >tamperw !22_S	et	f	\N
132662	majandusest	majandusest =majanduse  (SgEl  >majandus !11_S	et	f	\N
132663	majandusest	"majandus %majanda  )US_vS  <majandama ;27_V	et	f	\N
132664	majandusest	majandusest =majanduses  (SgP  >majandusene !12_A	et	f	\N
132665	majandusest	"majandusene %majanduse  )NE_aA  <majandus ;11_S	et	f	\N
132677	kunstiloome	kunstiloome =loome  (SgN  >kunsti+loome !06_S	et	f	\N
132678	kunstiloome	kunstiloome =loome  (SgG  >kunsti+loome !06_S	et	f	\N
132679	kunstiloome	kunstiloome =loome  (PlP  >kunsti+loom !22_S	et	f	\N
132696	soovitatav	soovitatav =soovita  (PtsPrIps  >soovitama !27_V	et	f	\N
132697	soovitatav	soovitatav =soovitatav  (SgN  >soovitatav !02_A	et	f	\N
132698	soovitatav	"soovitatav %soovita  )TAV_vAS  <soovitama ;27_V	et	f	\N
132707	hällist	hällist =hälli  (SgEl  >häll !22_S	et	f	\N
132708	hällist	hällist =hällis  (SgP  >hälline !10_A	et	f	\N
132709	hällist	"hälline %hälli  )NE_aA  <häll ;22_S	et	f	\N
132714	eralised	eralised =eralise  (PlN  >eraline !12_A	et	f	\N
132715	eralised	"eraline %era  )LINE_aA  <era ;17_S	et	f	\N
132771	rõõmsam	rõõmsam =rõõmsam  (SgN  >rõõmsam !02_A	et	f	\N
132773	rõõmsam	"rõõmsam %rõõmsa  )M_cA  <rõõmus ;02_A	et	f	\N
132777	regivärsiline	regivärsiline =värsiline  (SgN  >regi+värsiline !12_A	et	f	\N
132778	regivärsiline	"regi+värsiline %värsi  )LINE_aA  <regi+värss ;22_S	et	f	\N
132791	koor	koor =koor  (SgN  >koor !13_S	et	f	\N
132792	koor	koor =koor  (SgN  >koor !22_S	et	f	\N
132800	uuritud	uuritud =uuri  (PtsPtIps  >uurima !28_V	et	f	\N
132801	uuritud	uuritud =uuritu  (PlN  >uuritu !01_AS	et	f	\N
132802	uuritud	"uuritu %uuri  )TU1_vS  <uurima ;28_V	et	f	\N
132803	uuritud	"uuritu %uuri  )TU2_kA  <uur ;22_S	et	f	\N
132804	uuritud	uuritud =uuritud  (ID  >uuritud !41_A	et	f	\N
132805	uuritud	"uuritud %uuri  )TUD_vA  <uurima ;28_V	et	f	\N
132809	jumalasid	### jumalasid	et	f	\N
132819	lauludetüüp	?lauludetüüp =lauludetüüp  (SgN  >lauludetüüp !22_S	et	f	\N
132820	lauludetüüp	?lauludetüüp =detüüp  (SgN  >laulu+detüüp !22_S	et	f	\N
132821	lauludetüüp	?lauludetüüp =ludetüüp  (SgN  >lau+ludetüüp !22_S	et	f	\N
132837	mängisi	?mängisi =mängisi  (ID  >mängisi !41_D	et	f	\N
132906	bojaan	?bojaan =bojaan  (SgN  >bojaan !22_S	et	f	\N
132918	võttas	?võttas =võtta  (IndIpfSg3  >võttama !29_V	et	f	\N
132919	võttas	?võttas =võttas  (SgN  >võttas !07_S	et	f	\N
132920	lauldasid	?lauldasid =laulda  (IndIpfSg2  >lauldama !27_V	et	f	\N
132921	lauldasid	?lauldasid =laulda  (IndIpfPl3  >lauldama !27_V	et	f	\N
132930	külakoolis	külakoolis =kooli  (SgIn  >küla+kool !22_S	et	f	\N
132931	külakoolis	külakoolis =kooli  (PlIn  >küla+kool !22_S	et	f	\N
132936	ultra	ultra =ultra  (SgN  >ultra !01_S	et	f	\N
132937	ultra	ultra =ultra  (SgG  >ultra !01_S	et	f	\N
132948	väiksed	väiksed =väikse  (PlN  >väike !10_A	et	f	\N
132949	väiksed	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
133006	meeskoori	meeskoori =koor  (PlP  >mees+koor !13_S	et	f	\N
133007	meeskoori	meeskoori =koori  (SgG  >mees+koor !22_S	et	f	\N
133008	meeskoori	meeskoori =koori  (SgP  >mees+koor !22_S	et	f	\N
133009	meeskoori	meeskoori =koori  (SgAdt  >mees+koor !22_S	et	f	\N
133010	meeskoori	meeskoori =skoori  (SgG  >mee+skoor !22_S	et	f	\N
133011	meeskoori	meeskoori =skoori  (SgP  >mee+skoor !22_S	et	f	\N
133012	meeskoori	meeskoori =skoori  (SgAdt  >mee+skoor !22_S	et	f	\N
133029	rock	?rock =rock  (SgN  >rock !22_S	et	f	\N
133049	korraldamisega	korraldamisega =korraldamise  (SgKom  >korraldamine !12_S	et	f	\N
133050	korraldamisega	"korraldamine %korralda  )MINE_vS  <korraldama ;27_V	et	f	\N
133072	rahvalauluks	rahvalauluks =luks  (SgN  >rahva+lau+luks !22_S	et	f	\N
133073	rahvalauluks	rahvalauluks =luks  (SgN  >rahva+lau+luks !22_SA	et	f	\N
133074	rahvalauluks	rahvalauluks =laulu  (SgTr  >rahva+laul !22_S	et	f	\N
132647	lavakunstikool	lavakunstikool =koo  (SgAd  >lava+kunsti+kubu !18_S	et	f	\N
132648	lavakunstikool	lavakunstikool =kool  (SgN  >lava+kunsti+kool !22_S	et	f	\N
132649	gsuits	?gsuits =gsuits  (SgN  >gsuits !22_S	et	f	\N
132658	kultuurimälu	kultuurimälu =mälu  (SgN  >kultuuri+mälu !17_S	et	f	\N
132660	kultuurimälu	kultuurimälu =mälu  (SgG  >kultuuri+mälu !17_S	et	f	\N
132661	kultuurimälu	kultuurimälu =mälu  (SgP  >kultuuri+mälu !17_S	et	f	\N
132681	kirjutamine	kirjutamine =kirjutamine  (SgN  >kirjutamine !12_S	et	f	\N
132682	kirjutamine	"kirjutamine %kirjuta  )MINE_vS  <kirjutama ;27_V	et	f	\N
132691	üldistav	üldistav =üldista  (PtsPrPs  >üldistama !27_V	et	f	\N
132692	üldistav	üldistav =üldistav  (SgN  >üldistav !02_A	et	f	\N
132693	üldistav	"üldistav %üldista  )V_vA  <üldistama ;27_V	et	f	\N
132694	väiteid	väiteid =väite  (PlP  >väide !06_S	et	f	\N
132695	väiteid	väiteid =te  (PlP  >väi+tee !26_S	et	f	\N
132729	pidu	pidu =pidu  (SgN  >pidu !17_S	et	f	\N
132730	pidu	pidu =pidu  (SgN  >pidu !18_S	et	f	\N
132731	pidu	pidu =pidu  (SgG  >pidu !17_S	et	f	\N
132732	pidu	pidu =pidu  (SgP  >pidu !17_S	et	f	\N
132733	pidu	pidu =pidu  (SgP  >pidu !18_S	et	f	\N
132734	tõestavad	tõestavad =tõesta  (IndPrPl3  >tõestama !27_V	et	f	\N
132735	tõestavad	tõestavad =tõestava  (PlN  >tõestav !02_A	et	f	\N
132736	tõestavad	"tõestav %tõesta  )V_vA  <tõestama ;27_V	et	f	\N
132785	esitavad	esitavad =esita  (IndPrPl3  >esitama !27_V	et	f	\N
132786	esitavad	esitavad =esitava  (PlN  >esitav !02_A	et	f	\N
132787	esitavad	"esitav %esita  )V_vA  <esitama ;27_V	et	f	\N
132788	esitavad	esitavad =tava  (PlN  >esi+tava !17_S	et	f	\N
132793	vaheldumisi	vaheldumisi =vaheldumisi  (ID  >vaheldumisi !41_D	et	f	\N
132794	vaheldumisi	vaheldumisi =vaheldumisi  (PlP  >vaheldumine !12_S	et	f	\N
132795	vaheldumisi	"vaheldumine %vaheldu  )MINE_vS  <vahelduma ;27_V	et	f	\N
132827	ennamik	?ennamik =ennamik  (SgN  >ennamik !25_S	et	f	\N
132833	vanema	vanema =vanema  (SgG  >vanem !02_AS	et	f	\N
132834	vanema	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
132844	uuema	uuema =uuema  (SgG  >uuem !02_A	et	f	\N
132845	uuema	"uuem %uue  )M_cA  <uus ;14_A	et	f	\N
132872	mailmast	?mailmast =mailmas  (SgP  >mailmas !07_S	et	f	\N
132873	mailmast	?mailmast =mailmas  (SgP  >mailmane !12~10_A	et	f	\N
132874	laulja	laulja =laulja  (SgN  >laulja !01_S	et	f	\N
132875	laulja	"laulja %laul  )JA_vS  <laulma ;33_V	et	f	\N
132876	laulja	laulja =laulja  (SgG  >laulja !01_S	et	f	\N
132894	ülendavat	ülendavat =ülenda  (KvtPrPs  >ülendama !27_V	et	f	\N
132895	ülendavat	ülendavat =ülendava  (SgP  >ülendav !02_A	et	f	\N
132896	ülendavat	"ülendav %ülenda  )V_vA  <ülendama ;27_V	et	f	\N
132902	muusikaalseid	?muusikaalseid =muusikaalse  (PlP  >muusikaalne !02_A	et	f	\N
132903	muusikaalseid	?muusikaalseid =muusikaalsei  (PlN  >muusikaalsei !26_S	et	f	\N
132904	muusikaalseid	?muusikaalseid =muusikaalsei  (SgP  >muusikaalsei !26_S	et	f	\N
132905	muusikaalseid	?muusikaalseid =alse  (PlP  >muusika+alne !02_A	et	f	\N
132907	muusikaalseid	?muusikaalseid =alsei  (PlN  >muusika+alsei !26_S	et	f	\N
132909	muusikaalseid	?muusikaalseid =alsei  (SgP  >muusika+alsei !26_S	et	f	\N
132911	muusikaalseid	?muusikaalseid =alseid  (SgN  >muusika+alseid !22_S	et	f	\N
132912	muusikaalseid	?muusikaalseid =sikaalse  (PlP  >muu+sikaalne !02_A	et	f	\N
132913	muusikaalseid	?muusikaalseid =sikaalsei  (PlN  >muu+sikaalsei !26_S	et	f	\N
132914	muusikaalseid	?muusikaalseid =sikaalsei  (SgP  >muu+sikaalsei !26_S	et	f	\N
132922	olivad	?olivad =oli  (IndPrPl3  >olima !27_V	et	f	\N
132923	olivad	?olivad =oliva  (PlN  >oliva !01_S	et	f	\N
132924	olivad	?olivad =oliva  (PlN  >oliv !02_A	et	f	\N
132925	raadiosaatest	raadiosaatest =saate  (SgEl  >raadio+saade !06_S	et	f	\N
132926	raadiosaatest	raadiosaatest =saates  (SgP  >raadio+saatene !12~10_A	et	f	\N
132927	raadiosaatest	"raadio+saatene %saate  )NE_aA  <raadio+saade ;06_S	et	f	\N
132932	festivaale	?festivaale =festivaa  (SgAll  >festivaa !26_S	et	f	\N
132933	festivaale	?festivaale =festivaale  (SgN  >festivaale !16_S	et	f	\N
132934	festivaale	?festivaale =festivaale  (SgG  >festivaale !16_S	et	f	\N
132935	festivaale	?festivaale =festivaale  (PlP  >festivaal !22_S	et	f	\N
132941	lauldavad	lauldavad =lauldava  (PlN  >lauldav !02_A	et	f	\N
132942	lauldavad	"lauldav %laul  )TAV_vAS  <laulma ;33_V	et	f	\N
132953	nuttab	?nuttab =nutta  (IndPrSg3  >nuttama !29_V	et	f	\N
132959	hobby	### hobby	et	f	\N
132960	selga	selga =selga  (ID  >selga !41_D	et	f	\N
132961	selga	selga =selga  (SgP  >selg !22_S	et	f	\N
132962	selga	selga =selga  (SgAdt  >selg !22_S	et	f	\N
132967	looduslikult	looduslikult =loodusliku  (SgAbl  >looduslik !25_A	et	f	\N
132968	looduslikult	looduslikult =looduslikult  (ID  >looduslikult !41_D	et	f	\N
132969	looduslikult	"looduslikult %loodusliku  )LT_mD  <looduslik ;25_A	et	f	\N
132984	pärandati	pärandati =päranda  (IndIpfIps  >pärandama !27_V	et	f	\N
132985	pärandati	pärandati =ati  (SgG  >pärand+att !22_S	et	f	\N
132986	põlvest	põlvest =põlve  (SgEl  >põlv !22_S	et	f	\N
132987	põlvest	põlvest =põlve  (SgEl  >põli !24_S	et	f	\N
132988	põlvest	põlvest =põlve  (PlEl  >põlv !22_S	et	f	\N
132808	kirikuajast	"kiriku+ajane %aja  )NE_aA  <kiriku+aeg ;22_S	et	f	\N
132810	usuldasid	?usuldasid =usulda  (IndIpfSg2  >usuldama !27_V	et	f	\N
132811	usuldasid	?usuldasid =usulda  (IndIpfPl3  >usuldama !27_V	et	f	\N
132812	sõdujumal	?sõdujumal =sõdujumal  (SgN  >sõdujumal !19_S	et	f	\N
132822	jaganeb	?jaganeb =jagane  (IndPrSg3  >jaganema !27_V	et	f	\N
132823	tüüpis	?tüüpis =tüüpi  (IndIpfSg3  >tüüpima !28_V	et	f	\N
132824	tüüpis	?tüüpis =tüüpis  (SgN  >tüüpis !11~09_S	et	f	\N
132835	informatsiion	?informatsiion =informatsiion  (SgN  >informatsiion !19_S	et	f	\N
132868	neiuga	neiuga =neiu  (SgKom  >neiu !16_S	et	f	\N
132869	neiuga	neiuga =neiu  (SgKom  >neid !22_S	et	f	\N
132870	peole	peole =peo  (SgAll  >pidu !18_S	et	f	\N
132871	peole	peole =peo  (SgAll  >peo !26_S	et	f	\N
132899	tunneid	?tunneid =tunnei  (PlN  >tunnei !26_S	et	f	\N
132900	tunneid	?tunneid =tunnei  (SgP  >tunnei !26_S	et	f	\N
132901	tunneid	?tunneid =tunneid  (SgN  >tunneid !22_S	et	f	\N
132928	kulturile	?kulturile =kulturi  (SgAll  >kulturi !01_S	et	f	\N
132929	kulturile	?kulturile =kulturi  (SgAll  >kultur !02_S	et	f	\N
132938	go	### go	et	f	\N
132939	laulupeos	laulupeos =peo  (SgIn  >laulu+pidu !18_S	et	f	\N
132940	laulupeos	laulupeos =peo  (SgIn  >laulu+peo !26_S	et	f	\N
132950	lapsele	lapsele =lapse  (SgAll  >laps !14_S	et	f	\N
132951	lapsele	lapsele =lapse  (PlAll  >laps !22_S	et	f	\N
132970	komposiitorid	?komposiitorid =komposiitori  (PlN  >komposiitor !02_S	et	f	\N
132971	komposiitorid	?komposiitorid =posiitori  (PlN  >kom+posiitor !02_S	et	f	\N
132972	isamaalaul	isamaalaul =lau  (SgAd  >isa+maa+laug !22_SA	et	f	\N
132973	isamaalaul	isamaalaul =laul  (SgN  >isa+maa+laul !22_S	et	f	\N
132980	laulmisega	laulmisega =laulmise  (SgKom  >laulmine !12?10_S	et	f	\N
132981	laulmisega	"laulmine %laul  )MINE_vS  <laulma ;33_V	et	f	\N
133031	rahvatantsi	rahvatantsi =tantsi  (SgG  >rahva+tants !22_S	et	f	\N
133032	rahvatantsi	rahvatantsi =tantsi  (SgP  >rahva+tants !22_S	et	f	\N
133033	rahvatantsi	rahvatantsi =tantsi  (SgAdt  >rahva+tants !22_S	et	f	\N
133042	ülemailma	?ülemailma =ülemailma  (SgN  >ülemailma !16_S	et	f	\N
133044	ülemailma	?ülemailma =ülemailma  (SgG  >ülemailma !16_S	et	f	\N
133047	eurovision	?eurovision =eurovision  (SgN  >eurovision !19_S	et	f	\N
133048	eurovision	?eurovision =vision  (SgN  >euro+vision !19_S	et	f	\N
133079	rahvalaulupeod	rahvalaulupeod =peo  (PlN  >rahva+laulu+pidu !18_S	et	f	\N
133080	rahvalaulupeod	rahvalaulupeod =peo  (PlN  >rahva+laulu+peo !26_S	et	f	\N
133081	rahvalaulupeod	rahvalaulupeod =peo  (SgP  >rahva+laulu+peo !26_S	et	f	\N
133082	rahvalauluga	rahvalauluga =luga  (SgN  >rahva+lau+luga !18_S	et	f	\N
133083	rahvalauluga	rahvalauluga =luga  (SgP  >rahva+lau+luga !18_S	et	f	\N
133084	rahvalauluga	rahvalauluga =laulu  (SgKom  >rahva+laul !22_S	et	f	\N
133142	riplim	?riplim =riplim  (SgN  >riplim !02_A	et	f	\N
133150	folkloorirühmi	folkloorirühmi =rühmi  (SgG  >folkloori+rühm !22_S	et	f	\N
133151	folkloorirühmi	folkloorirühmi =rühmi  (SgP  >folkloori+rühm !22_S	et	f	\N
133152	folkloorirühmi	folkloorirühmi =rühmi  (SgAdt  >folkloori+rühm !22_S	et	f	\N
133153	folkloorirühmi	folkloorirühmi =rühmi  (PlP  >folkloori+rühm !22_S	et	f	\N
133164	lindades	?lindades =linda  (PlIn  >linda !16_S	et	f	\N
133165	lindades	?lindades =ade  (SgIn  >lind+ade !16_S	et	f	\N
133166	lindades	?lindades =ades  (SgN  >lind+ades !09_S	et	f	\N
133169	laulatakse	?laulatakse =laula  (IndPrIps  >laulama !29_V	et	f	\N
133170	laulatakse	?laulatakse =laulatakse  (SgG  >laulatakne !02_A	et	f	\N
133171	laulatakse	?laulatakse =laulatakse  (PlP  >laulataks !22_S	et	f	\N
133172	laulatakse	?laulatakse =latakse  (SgG  >lau+latakne !02_A	et	f	\N
133175	austasid	austasid =austa  (IndIpfSg2  >austama !27_V	et	f	\N
133176	austasid	austasid =austa  (IndIpfPl3  >austama !27_V	et	f	\N
133191	imiteerisid	imiteerisid =imiteeri  (IndIpfSg2  >imiteerima !28_V	et	f	\N
133192	imiteerisid	imiteerisid =imiteeri  (IndIpfPl3  >imiteerima !28_V	et	f	\N
133193	tuius	?tuius =tuiu  (SgIn  >tuiu !16_S	et	f	\N
133194	tuius	?tuius =tuiu  (IndIpfSg3  >tuiuma !27_V	et	f	\N
133195	tuius	?tuius =tuius  (SgN  >tuius !11~09_S	et	f	\N
133196	ilmas	ilmas =ilma  (SgIn  >ilm !22_S	et	f	\N
133197	ilmas	ilmas =ilmas  (ID  >ilmas !41_D	et	f	\N
133198	laulas	?laulas =laula  (SgIn  >laula !16_S	et	f	\N
133199	laulas	?laulas =laula  (IndIpfSg3  >laulama !29_V	et	f	\N
133200	laulas	?laulas =laulas  (SgN  >laulas !07_S	et	f	\N
133215	lauljad	lauljad =laulja  (PlN  >laulja !01_S	et	f	\N
133216	lauljad	"laulja %laul  )JA_vS  <laulma ;33_V	et	f	\N
133217	ansamble	?ansamble =ansamble  (IndPrPs_  >ansamblema !27_V	et	f	\N
133218	ansamble	?ansamble =ansamble  (ImpPrSg2  >ansamblema !27_V	et	f	\N
133223	bändid	bändid =bändi  (PlN  >bändi !16_S	et	f	\N
133224	bändid	bändid =bändi  (PlN  >bänd !22_S	et	f	\N
133242	pidudest	pidudest =pidu  (PlEl  >pidu !17_S	et	f	\N
133243	pidudest	pidudest =pidu  (PlEl  >pidu !18_S	et	f	\N
133246	laulupeo	laulupeo =peo  (SgN  >laulu+peo !26_S	et	f	\N
133247	laulupeo	laulupeo =peo  (SgG  >laulu+pidu !18_S	et	f	\N
133248	laulupeo	laulupeo =peo  (SgG  >laulu+peo !26_S	et	f	\N
133249	koguvad	koguvad =kogu  (IndPrPl3  >koguma !27_V	et	f	\N
132859	loomust	loomust =loomus  (SgP  >loomus !11~09_S	et	f	\N
132860	loomust	loomust =us  (SgP  >loom+uks !14_S	et	f	\N
132861	loomust	loomust =must  (SgN  >loo+must !22_AS	et	f	\N
132892	kogedes	kogedes =koge  (PlIn  >koge !16_S	et	f	\N
132893	kogedes	kogedes =koge  (Ger  >kogema !27_V	et	f	\N
132908	kannel	kannel =kanne  (PlAd  >kann !22_S	et	f	\N
132910	kannel	kannel =kannel  (SgN  >kannel !08_S	et	f	\N
132943	tantsivad	tantsivad =tantsi  (IndPrPl3  >tantsima !28_V	et	f	\N
132944	tantsivad	tantsivad =tantsiva  (PlN  >tantsiv !02_A	et	f	\N
132945	tantsivad	"tantsiv %tantsi  )V_vA  <tantsima ;28_V	et	f	\N
132946	väiksem	väiksem =väiksem  (SgN  >väiksem !02_A	et	f	\N
132947	väiksem	"väiksem %väikse  )M_cA  <väike ;10_A	et	f	\N
132952	psühoologid	### psühoologid	et	f	\N
132954	laulugruppid	?laulugruppid =lugruppi  (PlN  >lau+lugruppi !01_S	et	f	\N
132955	ontsamblis	?ontsamblis =ontsambli  (SgIn  >ontsambli !01_S	et	f	\N
132956	ontsamblis	?ontsamblis =ontsambli  (SgIn  >ontsambel !02_S	et	f	\N
132957	ontsamblis	?ontsamblis =ontsambli  (IndIpfSg3  >ontsamblima !28_V	et	f	\N
132958	ontsamblis	?ontsamblis =ontsamblis  (SgN  >ontsamblis !11_S	et	f	\N
132978	kõikides	kõikides =kõiki  (PlIn  >kõik !00_P	et	f	\N
132979	kõikides	kõikides =kõiki  (PlIn  >kõik !22_S	et	f	\N
132982	lauled	?lauled =laule  (PlN  >laule !06_S	et	f	\N
132983	lauled	?lauled =laule  (IndPrSg2  >laulema !27_V	et	f	\N
133017	toimumisse	toimumisse =toimumis  (SgAdt  >toimumine !12_S	et	f	\N
133018	toimumisse	"toimumine %toimu  )MINE_vS  <toimuma ;27_V	et	f	\N
133096	teostus	teostus =teostu  (IndIpfSg3  >teostuma !27_V	et	f	\N
133097	teostus	teostus =teostus  (SgN  >teostus !11~09_S	et	f	\N
133098	teostus	"teostus %teosta  )US_vS  <teostama ;27_V	et	f	\N
133102	seltsist	seltsist =seltsi  (SgEl  >selts !22_S	et	f	\N
133103	seltsist	seltsist =seltsist  (ID  >seltsist !41_K	et	f	\N
133112	vallandusid	vallandusid =vallandu  (IndIpfSg2  >vallanduma !27_V	et	f	\N
133113	vallandusid	vallandusid =vallandu  (IndIpfPl3  >vallanduma !27_V	et	f	\N
133121	hoidjaiks	hoidjaiks =hoidja  (PlTr  >hoidja !01_S	et	f	\N
133122	hoidjaiks	"hoidja %hoid  )JA_vS  <hoidma ;34_V	et	f	\N
133123	hoidjaiks	hoidjaiks =iks  (SgN  >hoidja+iks !22_S	et	f	\N
133129	riimilise	riimilise =riimilise  (SgG  >riimiline !12_A	et	f	\N
133130	riimilise	"riimiline %riimi  )LINE_aA  <riim ;22_S	et	f	\N
133148	stiilit	?stiilit =stiili  (SgP  >stiili !16_S	et	f	\N
133149	stiilit	?stiilit =stiilit  (SgN  >stiilit !02_S	et	f	\N
133157	tänasepäeva	?tänasepäeva =tänasepäeva  (SgN  >tänasepäeva !16_S	et	f	\N
133158	tänasepäeva	?tänasepäeva =tänasepäeva  (SgG  >tänasepäeva !16_S	et	f	\N
133159	tänasepäeva	?tänasepäeva =sepäeva  (SgN  >täna+sepäeva !01_S	et	f	\N
133160	tänasepäeva	?tänasepäeva =sepäeva  (SgG  >täna+sepäeva !01_S	et	f	\N
133202	öö	öö =öö  (SgN  >öö !26_S	et	f	\N
133204	öö	öö =öö  (SgG  >öö !26_S	et	f	\N
133225	lauljate	lauljate =laulja  (PlG  >laulja !01_S	et	f	\N
133226	lauljate	"laulja %laul  )JA_vS  <laulma ;33_V	et	f	\N
133244	üritus	üritus =üritus  (SgN  >üritus !11_S	et	f	\N
133245	üritus	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
133261	korraldajad	korraldajad =korraldaja  (PlN  >korraldaja !01_S	et	f	\N
133262	korraldajad	"korraldaja %korralda  )JA_vS  <korraldama ;27_V	et	f	\N
133302	valentinipäev	?valentinipäev =valentinipäev  (SgN  >valentinipäev !22_S	et	f	\N
133303	lootuses	lootuses =lootuse  (SgIn  >lootus !11~09_S	et	f	\N
133304	lootuses	"lootus %loo  )TUS2_aS  <lugu ;18_S	et	f	\N
133305	lootuses	"lootus %loo  )TUS2_aS  <loog ;22_S	et	f	\N
133306	lootuses	"lootus %loo  )TUS2_aS  <lood ;22_S	et	f	\N
133312	kompositoreid	?kompositoreid =kompositore  (PlP  >kompositor !02_S	et	f	\N
133313	kompositoreid	?kompositoreid =kompositorei  (PlN  >kompositorei !26_S	et	f	\N
133314	kompositoreid	?kompositoreid =kompositorei  (SgP  >kompositorei !26_S	et	f	\N
133315	kompositoreid	?kompositoreid =positorei  (PlN  >kom+positorei !26_S	et	f	\N
133316	kompositoreid	?kompositoreid =positorei  (SgP  >kom+positorei !26_S	et	f	\N
133318	ülde	?ülde =ülde  (SgN  >ülde !06_S	et	f	\N
133319	ülde	?ülde =ülde  (PlP  >üld !22_S	et	f	\N
133320	ülde	?ülde =ülde  (IndPrPs_  >üldema !27_V	et	f	\N
133321	ülde	?ülde =ülde  (ImpPrSg2  >üldema !27_V	et	f	\N
133322	pealtvaataja	pealtvaataja =vaataja  (SgN  >pealt+vaataja !01_S	et	f	\N
133323	pealtvaataja	pealtvaataja =vaataja  (SgG  >pealt+vaataja !01_S	et	f	\N
133331	merelaulu	merelaulu =laulu  (SgG  >mere+laul !22_S	et	f	\N
133332	merelaulu	merelaulu =laulu  (SgP  >mere+laul !22_S	et	f	\N
133333	merelaulu	merelaulu =laulu  (SgAdt  >mere+laul !22_S	et	f	\N
133336	triiprida	triiprida =rida  (SgN  >triip+rida !18_S	et	f	\N
133337	triiprida	triiprida =rida  (SgP  >triip+rida !18_S	et	f	\N
133338	tähest	tähest =tähe  (SgEl  >täht !22_S	et	f	\N
133339	tähest	tähest =tähes  (SgP  >tähene !10_A	et	f	\N
133340	tähest	"tähene %tähe  )NE_aA  <täht ;22_S	et	f	\N
133341	neilt	neilt =ne  (PlAbl  >see !00_P	et	f	\N
133342	neilt	neilt =ne  (PlAbl  >ta !00_P	et	f	\N
133345	jaata	jaata =jaata  (IndPrPs_  >jaatama !27_V	et	f	\N
132887	laulnud	laulnud =laulnud  (ID  >laulnud !41_A	et	f	\N
132888	laulnud	"laulnud %laul  )NUD_vA  <laulma ;33_V	et	f	\N
132889	perest	perest =pere  (SgEl  >pere !16_S	et	f	\N
132890	perest	perest =peres  (SgP  >perene !10_A	et	f	\N
132891	perest	"perene %pere  )NE_aA  <pere ;16_S	et	f	\N
132897	lauldid	?lauldid =lauldi  (PlN  >lault !22_S	et	f	\N
132898	lauldid	?lauldid =lauldi  (IndPrSg2  >laultima !28_V	et	f	\N
132915	laulurahv	?laulurahv =laulurahv  (SgN  >laulurahv !22_S	et	f	\N
132916	laulurahv	?laulurahv =rahv  (SgN  >laulu+rahv !22_S	et	f	\N
132917	laulurahv	?laulurahv =lurahv  (SgN  >lau+lurahv !22_S	et	f	\N
132963	rahvatatsid	?rahvatatsid =rahvatatsi  (PlN  >rahvatats !22_S	et	f	\N
132964	rahvatatsid	?rahvatatsid =rahvatatsi  (IndPrSg2  >rahvatatsima !28_V	et	f	\N
132965	rahvatatsid	?rahvatatsid =tatsi  (PlN  >rahva+tatsi !16_S	et	f	\N
132966	rahvatatsid	?rahvatatsid =tatsi  (PlN  >rahva+tats !22_S	et	f	\N
132974	avalikum	avalikum =avalikum  (SgN  >avalikum !02_A	et	f	\N
132975	avalikum	"avalikum %avaliku  )M_cA  <avalik ;25_A	et	f	\N
132976	sõbralikum	sõbralikum =sõbralikum  (SgN  >sõbralikum !02_A	et	f	\N
132977	sõbralikum	"sõbralikum %sõbraliku  )M_cA  <sõbralik ;25_A	et	f	\N
132992	suuliselt	suuliselt =suulise  (SgAbl  >suuline !12?10_AS	et	f	\N
132993	suuliselt	"suuline %suu  )LINE_aA  <suu ;26_S	et	f	\N
132994	suuliselt	suuliselt =suuliselt  (ID  >suuliselt !41_D	et	f	\N
132995	suuliselt	"suuliselt %suu  )LISELT_mD  <suu ;26_S	et	f	\N
132996	suuliselt	"suuliselt %suulise  )LT_mD  <suuline ;10_AS	et	f	\N
132997	suuliselt	"suuliselt %suulise  )LT_mD  <suuline ;12_AS	et	f	\N
132998	rahvaslikku	?rahvaslikku =rahvaslikku  (SgP  >rahvaslik !25_A	et	f	\N
132999	rahvaslikku	?rahvaslikku =rahvaslikku  (SgAdt  >rahvaslik !25_A	et	f	\N
133000	rahvaslikku	?rahvaslikku =rahvaslikku  (IndPrPs_  >rahvaslikkuma !27_V	et	f	\N
133001	rahvaslikku	?rahvaslikku =rahvaslikku  (ImpPrSg2  >rahvaslikkuma !27_V	et	f	\N
133002	rahvaslikku	?rahvaslikku =slikku  (SgP  >rahva+slikk !22_S	et	f	\N
133003	rahvaslikku	?rahvaslikku =slikku  (SgAdt  >rahva+slikk !22_S	et	f	\N
133013	lauljaga	lauljaga =laulja  (SgKom  >laulja !01_S	et	f	\N
133014	lauljaga	"laulja %laul  )JA_vS  <laulma ;33_V	et	f	\N
133037	rahvastel	rahvastel =rahvas  (PlAd  >rahvas !07_S	et	f	\N
133038	rahvastel	rahvastel =rahvas  (PlAd  >rahvane !10_A	et	f	\N
133039	rahvastel	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
133040	rajas	rajas =raja  (SgIn  >raja !17_S	et	f	\N
133041	rajas	rajas =raja  (SgIn  >rada !18_S	et	f	\N
133043	rajas	rajas =raja  (IndIpfSg3  >rajama !27_V	et	f	\N
133054	vaimupüha	vaimupüha =püha  (SgN  >vaimu+püha !17_SA	et	f	\N
133055	vaimupüha	vaimupüha =püha  (SgG  >vaimu+püha !17_SA	et	f	\N
133056	vaimupüha	vaimupüha =püha  (SgP  >vaimu+püha !17_SA	et	f	\N
133060	vaieldamatu	vaieldamatu =vaieldamatu  (SgN  >vaieldamatu !01_A	et	f	\N
133061	vaieldamatu	"vaieldamatu %vaiel  )TAMATU_vA  <vaidlema ;30_V	et	f	\N
133062	vaieldamatu	vaieldamatu =vaieldamatu  (SgG  >vaieldamatu !01_A	et	f	\N
133065	muusikasse	muusikasse =muusika  (SgIll  >muusika !01_S	et	f	\N
133066	muusikasse	muusikasse =muusikas  (SgAdt  >muusikane !12_A	et	f	\N
133067	muusikasse	"muusikane %muusika  )NE_aA  <muusika ;01_S	et	f	\N
133068	loengust	loengust =loengu  (SgEl  >loeng !02_S	et	f	\N
133069	loengust	loengust =us  (SgP  >loeng+uks !14_S	et	f	\N
133070	regivärsiliseks	regivärsiliseks =värsilise  (SgTr  >regi+värsiline !12_A	et	f	\N
133071	regivärsiliseks	"regi+värsiline %värsi  )LINE_aA  <regi+värss ;22_S	et	f	\N
133075	folkloor	folkloor =folkloor  (SgN  >folkloor !22_S	et	f	\N
133076	folkloor	folkloor =loor  (SgN  >folk+loor !22_S	et	f	\N
133088	tähtsusega	tähtsusega =tähtsuse  (SgKom  >tähtsus !11~09_S	et	f	\N
133091	tähtsusega	"tähtsus %tähtsa  )US_aS  <tähtis ;02_A	et	f	\N
133099	vanemuise	?vanemuise =vanemuise  (PlP  >vanemuis !22_S	et	f	\N
133100	vanemuise	?vanemuise =uise  (SgN  >vanem+uise !06_S	et	f	\N
133101	vanemuise	?vanemuise =uise  (SgG  >vanem+uise !06_S	et	f	\N
133104	eesotsas	eesotsas =eesotsas  (ID  >ees+otsas !41_D	et	f	\N
133105	eesotsas	eesotsas =otsa  (SgIn  >ees+ots !23?22_S	et	f	\N
133106	jannseniga	?jannseniga =jannseni  (SgKom  >jannsen !02_S	et	f	\N
133107	muusikaline	muusikaline =muusikaline  (SgN  >muusikaline !12_A	et	f	\N
133108	muusikaline	"muusikaline %muusika  )LINE_aA  <muusika ;01_S	et	f	\N
133109	muusikaline	"muusikaline %muusikali  )NE_aA  <muusikal ;19_S	et	f	\N
133114	hingestatud	hingestatud =hingesta  (PtsPtIps  >hingestama !27_V	et	f	\N
133115	hingestatud	hingestatud =hingestatu  (PlN  >hingestatu !01_S	et	f	\N
133116	hingestatud	"hingestatu %hingesta  )TU1_vS  <hingestama ;27_V	et	f	\N
133117	hingestatud	hingestatud =hingestatud  (ID  >hingestatud !41_A	et	f	\N
133118	hingestatud	"hingestatud %hingesta  )TUD_vA  <hingestama ;27_V	et	f	\N
133124	koosmõju	koosmõju =mõju  (SgN  >koos+mõju !17_S	et	f	\N
133125	koosmõju	koosmõju =mõju  (SgG  >koos+mõju !17_S	et	f	\N
133126	koosmõju	koosmõju =mõju  (SgP  >koos+mõju !17_S	et	f	\N
133133	tuvastatav	tuvastatav =tuvasta  (PtsPrIps  >tuvastama !27_V	et	f	\N
133134	tuvastatav	tuvastatav =tuvastatav  (SgN  >tuvastatav !02_A	et	f	\N
133135	tuvastatav	"tuvastatav %tuvasta  )TAV_vAS  <tuvastama ;27_V	et	f	\N
132989	põlvest	põlvest =põlves  (SgP  >põlvene !10_A	et	f	\N
132990	põlvest	"põlvene %põlve  )NE_aA  <põlv ;22_S	et	f	\N
132991	põlvest	"põlvene %põlve  )NE_aA  <põli ;24_S	et	f	\N
133004	eesimene	eesimene =imene  (SgN  >ees+imene !10_A	et	f	\N
133005	eesimene	"ees+imene %ime  )NE_aA  <ees+ime ;16_S	et	f	\N
133015	mängijaga	mängijaga =mängija  (SgKom  >mängija !01_S	et	f	\N
133016	mängijaga	"mängija %mängi  )JA_vS  <mängima ;28_V	et	f	\N
133019	valitsenud	valitsenud =valitse  (PtsPtPs  >valitsema !27_V	et	f	\N
133020	valitsenud	valitsenud =valitsenu  (PlN  >valitsenu !01_S	et	f	\N
133021	valitsenud	"valitsenu %valitse  )NU_vS  <valitsema ;27_V	et	f	\N
133022	valitsenud	valitsenud =valitsenud  (ID  >valitsenud !41_A	et	f	\N
133023	valitsenud	"valitsenud %valitse  )NUD_vA  <valitsema ;27_V	et	f	\N
133024	tantsi	tantsi =tantsi  (SgG  >tants !22_S	et	f	\N
133025	tantsi	tantsi =tantsi  (SgP  >tants !22_S	et	f	\N
133026	tantsi	tantsi =tantsi  (SgAdt  >tants !22_S	et	f	\N
133027	tantsi	tantsi =tantsi  (IndPrPs_  >tantsima !28_V	et	f	\N
133028	tantsi	tantsi =tantsi  (ImpPrSg2  >tantsima !28_V	et	f	\N
133030	pop	### pop	et	f	\N
133034	määletaks	?määletaks =määle  (KndPrIps  >määlema !27_V	et	f	\N
133035	määletaks	?määletaks =määleta  (KndPrPs  >määletama !27_V	et	f	\N
133036	määletaks	?määletaks =määletaks  (SgN  >määletaks !22_S	et	f	\N
133045	hämmardav	?hämmardav =hämmarda  (PtsPrPs  >hämmardama !27_V	et	f	\N
133046	hämmardav	?hämmardav =hämmardav  (SgN  >hämmardav !02_A	et	f	\N
133051	laulupüha	laulupüha =püha  (SgN  >laulu+püha !17_SA	et	f	\N
133052	laulupüha	laulupüha =püha  (SgG  >laulu+püha !17_SA	et	f	\N
133053	laulupüha	laulupüha =püha  (SgP  >laulu+püha !17_SA	et	f	\N
133057	lõbusalt	lõbusalt =lõbusa  (SgAbl  >lõbus !02_A	et	f	\N
133058	lõbusalt	lõbusalt =lõbusalt  (ID  >lõbusalt !41_D	et	f	\N
133059	lõbusalt	"lõbusalt %lõbusa  )LT_mD  <lõbus ;02_A	et	f	\N
133063	tavalise	tavalise =tavalise  (SgG  >tavaline !12_A	et	f	\N
133064	tavalise	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
133077	organiseeritsid	?organiseeritsid =organiseeritsi  (PlN  >organiseerits !02_S	et	f	\N
133078	organiseeritsid	?organiseeritsid =organiseeritsi  (IndPrSg2  >organiseeritsima !28_V	et	f	\N
133085	tutvumine	tutvumine =tutvumine  (SgN  >tutvumine !12_S	et	f	\N
133086	tutvumine	"tutvumine %tutvu  )MINE_vS  <tutvuma ;27_V	et	f	\N
133087	ajaloolise	ajaloolise =loolise  (SgG  >aja+looline !12?10_A	et	f	\N
133089	ajaloolise	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
133090	ajaloolise	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
133092	ajaloolise	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
133093	ajaloolise	ajaloolise =loolise  (SgG  >aja+looline !12?10_S	et	f	\N
133110	lõpetamised	lõpetamised =lõpetamise  (PlN  >lõpetamine !12_S	et	f	\N
133111	lõpetamised	"lõpetamine %lõpeta  )MINE_vS  <lõpetama ;27_V	et	f	\N
133154	põhimõteliselt	?põhimõteliselt =põhimõtelise  (SgAbl  >põhimõteline !12_A	et	f	\N
133155	põhimõteliselt	?põhimõteliselt =põhimõteliselt  (ID  >põhimõteliselt !41_D	et	f	\N
133156	põhimõteliselt	?põhimõteliselt =mõtelise  (SgAbl  >põhi+mõteline !12_A	et	f	\N
133173	kõiges	kõiges =kõige  (SgIn  >kõik !00_P	et	f	\N
133174	kõiges	kõiges =kõige  (PlIn  >kõik !22_S	et	f	\N
133186	pulma	pulma =pulma  (SgG  >pulm !22_S	et	f	\N
133187	pulma	pulma =pulma  (SgP  >pulm !22_S	et	f	\N
133188	pulma	pulma =pulma  (SgAdt  >pulm !22_S	et	f	\N
133201	jüüri	?jüüri =jüüri  (SgN  >jüüri !16_S	et	f	\N
133203	jüüri	?jüüri =jüüri  (SgG  >jüüri !16_S	et	f	\N
133205	jüüri	?jüüri =jüüri  (SgG  >jüür !22_S	et	f	\N
133206	jüüri	?jüüri =jüüri  (SgP  >jüür !22_S	et	f	\N
133207	jüüri	?jüüri =jüüri  (SgAdt  >jüür !22_S	et	f	\N
133208	jüüri	?jüüri =jüüri  (IndPrPs_  >jüürima !28_V	et	f	\N
133209	jüüri	?jüüri =jüüri  (ImpPrSg2  >jüürima !28_V	et	f	\N
133238	üritusest	üritusest =ürituse  (SgEl  >üritus !11_S	et	f	\N
133239	üritusest	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
133240	üritusest	üritusest =ürituses  (SgP  >üritusene !12_A	et	f	\N
133241	üritusest	"üritusene %ürituse  )NE_aA  <üritus ;11_S	et	f	\N
133255	pillemängudest	?pillemängudest =pillemängudes  (SgP  >pillemängudene !12_A	et	f	\N
133264	stiileid	?stiileid =stiile  (PlP  >stiile !06_S	et	f	\N
133265	stiileid	?stiileid =stiilei  (PlN  >stiilei !26_S	et	f	\N
133266	stiileid	?stiileid =stiilei  (SgP  >stiilei !26_S	et	f	\N
133267	stiileid	?stiileid =stiileid  (SgN  >stiileid !22_S	et	f	\N
133284	tuttvuda	?tuttvuda =tuttvu  (Inf  >tuttvuma !27_V	et	f	\N
133285	tuttvuda	?tuttvuda =vuda  (SgN  >tutt+vuda !17_S	et	f	\N
133286	tuttvuda	?tuttvuda =vuda  (SgG  >tutt+vuda !17_S	et	f	\N
133287	tuttvuda	?tuttvuda =vuda  (SgP  >tutt+vuda !17_S	et	f	\N
133292	saksa-	saksa- =saksa  (ID  >saksa !41_G	et	f	\N
133293	saksa-	saksa- =saksa  (SgG  >saks !23?22_S	et	f	\N
133294	saksa-	saksa- =saksa  (SgP  >saks !23?22_S	et	f	\N
133295	saksa-	saksa- =saksa  (SgAdt  >saks !23?22_S	et	f	\N
133325	tõstsid	tõstsid =tõst  (IndIpfSg2  >tõstma !34_V	et	f	\N
133326	tõstsid	tõstsid =tõst  (IndIpfPl3  >tõstma !34_V	et	f	\N
133094	korraldamise	korraldamise =korraldamise  (SgG  >korraldamine !12_S	et	f	\N
133095	korraldamise	"korraldamine %korralda  )MINE_vS  <korraldama ;27_V	et	f	\N
133119	kujunesid	kujunesid =kujune  (IndIpfSg2  >kujunema !27_V	et	f	\N
133120	kujunesid	kujunesid =kujune  (IndIpfPl3  >kujunema !27_V	et	f	\N
133127	eeldused	eeldused =eelduse  (PlN  >eeldus !11~09_S	et	f	\N
133128	eeldused	"eeldus %eelda  )US_vS  <eeldama ;27_V	et	f	\N
133131	riimiline	riimiline =riimiline  (SgN  >riimiline !12_A	et	f	\N
133132	riimiline	"riimiline %riimi  )LINE_aA  <riim ;22_S	et	f	\N
133146	heelilojad	?heelilojad =heeliloja  (PlN  >heeliloja !01_S	et	f	\N
133147	heelilojad	?heelilojad =heeliloja  (PlN  >heelilojas !02_A	et	f	\N
133161	lõõgastuvad	lõõgastuvad =lõõgastu  (IndPrPl3  >lõõgastuma !27_V	et	f	\N
133162	lõõgastuvad	lõõgastuvad =lõõgastuva  (PlN  >lõõgastuv !02_A	et	f	\N
133163	lõõgastuvad	"lõõgastuv %lõõgastu  )V_vA  <lõõgastuma ;27_V	et	f	\N
133167	rühmad	rühmad =rühma  (PlN  >rühm !22_S	et	f	\N
133168	rühmad	rühmad =rühma  (IndPrSg2  >rühmama !29_V	et	f	\N
133177	ebamääletanud	?ebamääletanud =ebamääleta  (PtsPtPs  >ebamääletama !27_V	et	f	\N
133178	ebamääletanud	?ebamääletanud =ebamääletanu  (PlN  >ebamääletanu !01_S	et	f	\N
133179	ebamääletanud	?ebamääletanud =ebamääletanu  (IndPrSg2  >ebamääletanuma !27_V	et	f	\N
133180	ebamääletanud	?ebamääletanud =ebamääletanud  (ID  >ebamääletanud !41_A	et	f	\N
133181	ebamääletanud	?ebamääletanud =määletanu  (PlN  >eba+määletanu !01_S	et	f	\N
133182	ebamääletanud	?ebamääletanud =määletanud  (ID  >eba+määletanud !41_A	et	f	\N
133210	juhtimisega	juhtimisega =juhtimise  (SgKom  >juhtimine !12_S	et	f	\N
133211	juhtimisega	"juhtimine %juhti  )MINE_vS  <juhtima ;28_V	et	f	\N
133212	abimisel	?abimisel =abimise  (SgAd  >abimine !12_S	et	f	\N
133227	tuntus	tuntus =tuntu  (SgIn  >tuntu !01_S	et	f	\N
133228	tuntus	"tuntu %tun  )TU1_vS  <tundma ;34_V	et	f	\N
133229	tuntus	tuntus =tuntus  (SgN  >tuntus !11~09_S	et	f	\N
133230	tuntus	"tuntus %tun  )TUS1_aS  <tundma ;34_V	et	f	\N
133233	tähestab	?tähestab =tähesta  (IndPrSg3  >tähestama !27_V	et	f	\N
133234	tähestada	?tähestada =tähesta  (Inf  >tähestama !27_V	et	f	\N
133235	tähestada	?tähestada =stada  (SgN  >tähe+stada !17_S	et	f	\N
133236	tähestada	?tähestada =stada  (SgG  >tähe+stada !17_S	et	f	\N
133237	tähestada	?tähestada =stada  (SgP  >tähe+stada !17_S	et	f	\N
133254	lauljast	lauljast =laulja  (SgEl  >laulja !01_S	et	f	\N
133256	lauljast	"laulja %laul  )JA_vS  <laulma ;33_V	et	f	\N
133257	lauljast	lauljast =lauljas  (SgP  >lauljane !12~10_A	et	f	\N
133258	lauljast	"lauljane %laulja  )NE_aA  <laulja ;01_S	et	f	\N
133259	laulupeole	laulupeole =peo  (SgAll  >laulu+pidu !18_S	et	f	\N
133260	laulupeole	laulupeole =peo  (SgAll  >laulu+peo !26_S	et	f	\N
133317	hümm	?hümm =hümm  (SgN  >hümm !22_S	et	f	\N
133324	üleeelmisel	?üleeelmisel =üleeelmise  (SgAd  >üleeelmine !12_A	et	f	\N
133327	väina	väina =väi  (SgEs  >väi !26_S	et	f	\N
133328	väina	väina =väina  (SgG  >väin !22_S	et	f	\N
133329	väina	väina =väina  (SgP  >väin !22_S	et	f	\N
133330	väina	väina =väina  (SgAdt  >väin !22_S	et	f	\N
133334	puhkasid	puhkasid =puhka  (IndIpfSg2  >puhkama !29_V	et	f	\N
133335	puhkasid	puhkasid =puhka  (IndIpfPl3  >puhkama !29_V	et	f	\N
133385	kurustest	?kurustest =kurus  (PlEl  >kurus !09_S	et	f	\N
133386	kurustest	?kurustest =kurustes  (SgP  >kurustene !12_A	et	f	\N
133407	muistlased	?muistlased =muistlase  (PlN  >muistlane !12?10_S	et	f	\N
133408	folkloorist	folkloorist =folkloori  (SgEl  >folkloor !22_S	et	f	\N
133409	folkloorist	folkloorist =rist  (SgN  >folk+loo+rist !22_S	et	f	\N
133410	folkloorist	folkloorist =loori  (SgEl  >folk+loori !16_S	et	f	\N
133411	folkloorist	folkloorist =loori  (SgEl  >folk+loor !22_S	et	f	\N
133436	korraldasid	korraldasid =korralda  (IndIpfSg2  >korraldama !27_V	et	f	\N
133437	korraldasid	korraldasid =korralda  (IndIpfPl3  >korraldama !27_V	et	f	\N
133482	bajan	?bajan =baja  (IndPrSg1  >bajama !27_V	et	f	\N
133483	bajan	?bajan =bajan  (SgN  >bajan !02_S	et	f	\N
133496	folklor	?folklor =folklor  (SgN  >folklor !02_S	et	f	\N
133501	torupilli	torupilli =pilli  (SgG  >toru+pill !22_S	et	f	\N
133502	torupilli	torupilli =pilli  (SgP  >toru+pill !22_S	et	f	\N
133503	torupilli	torupilli =pilli  (SgAdt  >toru+pill !22_S	et	f	\N
133504	naiskoor	naiskoor =koor  (SgN  >nais+koor !13_S	et	f	\N
133505	naiskoor	naiskoor =koor  (SgN  >nais+koor !22_S	et	f	\N
133506	segakoor	segakoor =koor  (SgN  >sega+koor !13_S	et	f	\N
133507	segakoor	segakoor =koor  (SgN  >sega+koor !22_S	et	f	\N
133508	lastekoor	lastekoor =koor  (SgN  >laste+koor !13_S	et	f	\N
133509	lastekoor	lastekoor =koor  (SgN  >laste+koor !22_S	et	f	\N
133510	derigendid	?derigendid =derigendi  (PlN  >derigent !22_S	et	f	\N
133511	derigendid	?derigendid =derigendi  (IndPrSg2  >derigentima !28_V	et	f	\N
133516	flöötit	?flöötit =flöötit  (SgN  >flöötit !02_S	et	f	\N
133518	laulaga	laulaga =la  (SgKom  >lau+la !26_S	et	f	\N
133519	laulaga	laulaga =laga  (SgN  >lau+laga !17_S	et	f	\N
133520	laulaga	laulaga =laga  (SgG  >lau+laga !17_S	et	f	\N
133521	laulaga	laulaga =laga  (SgP  >lau+laga !17_S	et	f	\N
133136	trükitult	trükitult =trükitu  (SgAbl  >trükitu !01_AS	et	f	\N
133137	trükitult	"trükitu %trüki  )TU1_vS  <trükkima ;28_V	et	f	\N
133138	trükitult	"trükitu %trüki  )TU2_kA  <trükk ;22_S	et	f	\N
133139	trükitult	trükitult =trükitult  (ID  >trükitult !41_D	et	f	\N
133140	trükitult	"trükitult %trüki  )TULT1_mD  <trükkima ;28_V	et	f	\N
133141	trükitult	"trükitult %trüki  )TULT2_mD  <trükk ;22_S	et	f	\N
133143	meestel	meestel =mees  (PlAd  >meene !10_A	et	f	\N
133144	meestel	"meene %mee  )NE_aA  <mesi ;15_S	et	f	\N
133145	meestel	meestel =mees  (PlAd  >mees !13_S	et	f	\N
133183	laulasid	?laulasid =laula  (PlP  >laula !16_S	et	f	\N
133184	laulasid	?laulasid =laula  (IndIpfSg2  >laulama !29_V	et	f	\N
133185	laulasid	?laulasid =laula  (IndIpfPl3  >laulama !29_V	et	f	\N
133189	vaate	vaate =vaate  (SgG  >vaade !06_S	et	f	\N
133190	vaate	vaate =vaate  (PlP  >vaat !22_S	et	f	\N
133213	ärkamine	ärkamine =ärkamine  (SgN  >ärkamine !12_S	et	f	\N
133214	ärkamine	"ärkamine %ärka  )MINE_vS  <ärkama ;29_V	et	f	\N
133219	eelistavad	eelistavad =eelista  (IndPrPl3  >eelistama !27_V	et	f	\N
133220	eelistavad	eelistavad =eelistava  (PlN  >eelistav !02_A	et	f	\N
133221	eelistavad	"eelistav %eelista  )V_vA  <eelistama ;27_V	et	f	\N
133222	eelistavad	eelistavad =tava  (PlN  >eelis+tava !17_S	et	f	\N
133231	uhkus	uhkus =uhkus  (SgN  >uhkus !11~09_S	et	f	\N
133232	uhkus	"uhkus %uhke  )US_aS  <uhke ;01_A	et	f	\N
133263	traditsiooned	?traditsiooned =traditsioone  (PlN  >traditsioone !16_S	et	f	\N
133268	riigidest	?riigidest =riigi  (PlEl  >riigi !16_S	et	f	\N
133269	riigidest	?riigidest =riigi  (PlEl  >riig !22_S	et	f	\N
133270	riigidest	?riigidest =riigides  (SgP  >riigidene !12_A	et	f	\N
133271	koori	koori =koor  (PlP  >koor !13_S	et	f	\N
133272	koori	koori =koori  (SgG  >koor !22_S	et	f	\N
133273	koori	koori =koori  (SgP  >koor !22_S	et	f	\N
133274	koori	koori =koori  (SgAdt  >koor !22_S	et	f	\N
133275	koori	koori =koori  (IndPrPs_  >koorima !28_V	et	f	\N
133276	koori	koori =koori  (ImpPrSg2  >koorima !28_V	et	f	\N
133280	üldses	?üldses =üldse  (SgIn  >üldne !02_A	et	f	\N
133281	üldses	?üldses =üldse  (PlIn  >ülds !22_S	et	f	\N
133282	üldses	?üldses =üldse  (IndIpfSg3  >üldsema !27_V	et	f	\N
133283	üldses	?üldses =üldses  (SgN  >üldses !09_S	et	f	\N
133350	pillid	pillid =pilli  (PlN  >pill !22_S	et	f	\N
133351	pillid	pillid =pilli  (IndPrSg2  >pillima !28_V	et	f	\N
133352	bojaani	?bojaani =bojaa  (SgTer  >bojaa !26_S	et	f	\N
133353	bojaani	?bojaani =bojaani  (SgN  >bojaani !16_S	et	f	\N
133354	bojaani	?bojaani =bojaani  (SgG  >bojaani !16_S	et	f	\N
133355	bojaani	?bojaani =bojaani  (SgG  >bojaan !22_S	et	f	\N
133356	bojaani	?bojaani =bojaani  (SgP  >bojaan !22_S	et	f	\N
133357	bojaani	?bojaani =bojaani  (SgAdt  >bojaan !22_S	et	f	\N
133358	bojaani	?bojaani =bojaani  (IndPrPs_  >bojaanima !28_V	et	f	\N
133359	bojaani	?bojaani =bojaani  (ImpPrSg2  >bojaanima !28_V	et	f	\N
133393	üldlaulu	üldlaulu =laulu  (SgG  >üld+laul !22_S	et	f	\N
133394	üldlaulu	üldlaulu =laulu  (SgP  >üld+laul !22_S	et	f	\N
133395	üldlaulu	üldlaulu =laulu  (SgAdt  >üld+laul !22_S	et	f	\N
133418	iseseisvu	iseseisvu =seisvu  (IndPrPs_  >ise+seisvuma !27_V	et	f	\N
133419	iseseisvu	iseseisvu =seisvu  (ImpPrSg2  >ise+seisvuma !27_V	et	f	\N
133420	lauldav	lauldav =laul  (PtsPrIps  >laulma !33_V	et	f	\N
133421	lauldav	lauldav =lauldav  (SgN  >lauldav !02_A	et	f	\N
133422	lauldav	"lauldav %laul  )TAV_vAS  <laulma ;33_V	et	f	\N
133426	ravi	ravi =ravi  (SgN  >ravi !17_S	et	f	\N
133427	ravi	ravi =ravi  (SgG  >ravi !17_S	et	f	\N
133428	ravi	ravi =ravi  (SgP  >ravi !17_S	et	f	\N
133429	ravi	ravi =ravi  (IndPrPs_  >ravima !27_V	et	f	\N
133430	ravi	ravi =ravi  (ImpPrSg2  >ravima !27_V	et	f	\N
133434	kohtusid	kohtusid =kohtu  (IndIpfSg2  >kohtuma !27_V	et	f	\N
133435	kohtusid	kohtusid =kohtu  (IndIpfPl3  >kohtuma !27_V	et	f	\N
133440	kirikust	kirikust =kiriku  (SgEl  >kirik !02_S	et	f	\N
133441	kirikust	kirikust =us  (SgP  >kirik+uks !14_S	et	f	\N
133442	kirikust	kirikust =kus  (SgP  >kiri+kusi !20_S	et	f	\N
133445	repertuaari	repertuaari =repertuaari  (SgG  >repertuaar !22_S	et	f	\N
133446	repertuaari	repertuaari =repertuaari  (SgP  >repertuaar !22_S	et	f	\N
133447	repertuaari	repertuaari =repertuaari  (SgAdt  >repertuaar !22_S	et	f	\N
133476	täesti	?täesti =täesti  (ID  >täesti !41_D	et	f	\N
133477	täesti	?täesti =täesti  (SgG  >täest !22_S	et	f	\N
133478	täesti	?täesti =täesti  (SgP  >täest !22_S	et	f	\N
133479	täesti	?täesti =täesti  (SgAdt  >täest !22_S	et	f	\N
133480	täesti	?täesti =täesti  (IndPrPs_  >täestima !28_V	et	f	\N
133481	täesti	?täesti =täesti  (ImpPrSg2  >täestima !28_V	et	f	\N
133485	palad	palad =pala  (PlN  >pala !17_S	et	f	\N
133486	palad	palad =pala  (IndPrSg2  >palama !27_V	et	f	\N
133497	onsamblid	?onsamblid =onsambli  (PlN  >onsambli !01_S	et	f	\N
133498	onsamblid	?onsamblid =onsambli  (PlN  >onsambel !02_S	et	f	\N
133499	onsamblid	?onsamblid =onsambli  (IndPrSg2  >onsamblima !28_V	et	f	\N
133512	kaudna	?kaudna =kaudna  (SgN  >kaudna !01_S	et	f	\N
133250	koguvad	koguvad =koguva  (PlN  >koguv !02_A	et	f	\N
133251	koguvad	"koguv %kogu  )V_vA  <koguma ;27_V	et	f	\N
133252	koorid	koorid =koori  (PlN  >koor !22_S	et	f	\N
133253	koorid	koorid =koori  (IndPrSg2  >koorima !28_V	et	f	\N
133277	leinud	?leinud =leinu  (PlN  >leinu !16_S	et	f	\N
133278	leinud	?leinud =leinu  (IndPrSg2  >leinuma !28_V	et	f	\N
133279	leinud	?leinud =leinud  (ID  >leinud !41_A	et	f	\N
133288	rootsi-	rootsi- =rootsi  (ID  >rootsi !41_G	et	f	\N
133289	rootsi-	rootsi- =rootsi  (SgG  >roots !22_S	et	f	\N
133290	rootsi-	rootsi- =rootsi  (SgP  >roots !22_S	et	f	\N
133291	rootsi-	rootsi- =rootsi  (SgAdt  >roots !22_S	et	f	\N
133296	provin	?provin =provi  (IndPrSg1  >provima !27_V	et	f	\N
133297	provin	?provin =provin  (SgN  >provin !02_S	et	f	\N
133298	rõõmsamelne	?rõõmsamelne =rõõmsamelne  (SgN  >rõõmsamelne !02_A	et	f	\N
133299	rõõmsamelne	?rõõmsamelne =rõõmsamelne  (PlP  >rõõmsameln !22_S	et	f	\N
133300	rõõmsamelne	?rõõmsamelne =melne  (SgN  >rõõmsa+melne !02_A	et	f	\N
133301	rõõmsamelne	?rõõmsamelne =melne  (PlP  >rõõmsa+meln !22_S	et	f	\N
133307	kohata	kohata =koha  (SgAb  >koha !17_S	et	f	\N
133308	kohata	kohata =koha  (SgAb  >koht !22_S	et	f	\N
133309	kohata	kohata =koha  (Inf  >kohtama !29_V	et	f	\N
133310	kohata	kohata =koha  (IndPrIps_  >kohama !27_V	et	f	\N
133311	kohata	kohata =koha  (IndPrIps_  >kohtama !29_V	et	f	\N
133362	uuendanud	uuendanud =uuenda  (PtsPtPs  >uuendama !27_V	et	f	\N
133363	uuendanud	uuendanud =uuendanu  (PlN  >uuendanu !01_S	et	f	\N
133364	uuendanud	"uuendanu %uuenda  )NU_vS  <uuendama ;27_V	et	f	\N
133365	uuendanud	uuendanud =uuendanud  (ID  >uuendanud !41_A	et	f	\N
133366	uuendanud	"uuendanud %uuenda  )NUD_vA  <uuendama ;27_V	et	f	\N
133376	kõigist	kõigist =kõigi  (PlEl  >kõik !00_P	et	f	\N
133377	kõigist	kõigist =kõigi  (SgEl  >kõik !22_S	et	f	\N
133383	järjepidavuse	järjepidavuse =pidavuse  (SgG  >järje+pidavus !11_S	et	f	\N
133384	järjepidavuse	"järje+pidavus %pidava  )US_aS  <järje+pidav ;02_A	et	f	\N
133396	tantsupeod	tantsupeod =peo  (PlN  >tantsu+pidu !18_S	et	f	\N
133397	tantsupeod	tantsupeod =peo  (PlN  >tantsu+peo !26_S	et	f	\N
133398	tantsupeod	tantsupeod =peo  (SgP  >tantsu+peo !26_S	et	f	\N
133404	tunnustus	tunnustus =tunnustus  (SgN  >tunnustus !11_S	et	f	\N
133405	tunnustus	"tunnustus %tunnusta  )US_vS  <tunnustama ;27_V	et	f	\N
133412	kirikulaul	kirikulaul =lau  (SgAd  >kiriku+laug !22_SA	et	f	\N
133413	kirikulaul	kirikulaul =laul  (SgN  >kiriku+laul !22_S	et	f	\N
133423	massilisem	massilisem =massilisem  (SgN  >massilisem !02_A	et	f	\N
133424	massilisem	"massilisem %massi  )LISEM_cA  <mass ;22_S	et	f	\N
133425	massilisem	"massilisem %massilise  )M_cA  <massiline ;12_A	et	f	\N
133438	suheldasid	?suheldasid =suhelda  (IndIpfSg2  >suheldama !27_V	et	f	\N
133439	suheldasid	?suheldasid =suhelda  (IndIpfPl3  >suheldama !27_V	et	f	\N
133460	võimsus	võimsus =võimsus  (SgN  >võimsus !11~09_S	et	f	\N
133461	võimsus	"võimsus %võimsa  )US_aS  <võimas ;03_A	et	f	\N
133473	grigooriuse	?grigooriuse =grigooriuse  (SgG  >grigoorius !11_S	et	f	\N
133474	pidudel	pidudel =pidu  (PlAd  >pidu !17_S	et	f	\N
133475	pidudel	pidudel =pidu  (PlAd  >pidu !18_S	et	f	\N
133492	piazolo	?piazolo =piazolo  (SgN  >piazolo !01_S	et	f	\N
133493	piazolo	?piazolo =piazolo  (SgG  >piazolo !01_S	et	f	\N
133500	rook	?rook =rook  (SgN  >rook !22_S	et	f	\N
133522	tans	?tans =tans  (SgN  >tans !22_S	et	f	\N
133527	teama	?teama =teama  (SgN  >teama !16_S	et	f	\N
133528	teama	?teama =teama  (SgG  >teama !16_S	et	f	\N
133529	teama	?teama =teama  (IndPrPs_  >teamama !29_V	et	f	\N
133530	teama	?teama =teama  (ImpPrSg2  >teamama !29_V	et	f	\N
133536	tuntused	tuntused =tuntuse  (PlN  >tuntus !11~09_S	et	f	\N
133537	tuntused	"tuntus %tun  )TUS1_aS  <tundma ;34_V	et	f	\N
133542	sugusastega	?sugusastega =sugusas  (PlKom  >sugusane !12_A	et	f	\N
133543	sugusastega	?sugusastega =saste  (SgKom  >sugu+saste !06_S	et	f	\N
133577	kulasin	?kulasin =kula  (IndIpfSg1  >kulama !27_V	et	f	\N
133578	kulasin	?kulasin =kulasin  (SgN  >kulasin !19_S	et	f	\N
133584	armasid	?armasid =arma  (PlP  >arma !16_S	et	f	\N
133585	armasid	?armasid =arma  (IndIpfSg2  >armama !29_V	et	f	\N
133586	armasid	?armasid =arma  (IndIpfPl3  >armama !29_V	et	f	\N
133595	eestlastes	eestlastes =eestlas  (PlIn  >eestlane !12?10_S	et	f	\N
133596	eestlastes	eestlastes =las  (PlIn  >eest+laps !14_S	et	f	\N
133597	eestlastes	eestlastes =laste  (PlIn  >eest+last !22_S	et	f	\N
133622	tähistati	tähistati =tähista  (IndIpfIps  >tähistama !27_V	et	f	\N
133623	tähistati	tähistati =tati  (SgG  >tähis+tatt !22_S	et	f	\N
133669	xii	?xii =xii  (SgN  >xii !26_S	et	f	\N
133670	xii	?xii =xii  (SgG  >xii !26_S	et	f	\N
133673	suunamise	suunamise =suunamise  (SgG  >suunamine !12_S	et	f	\N
133674	suunamise	"suunamine %suuna  )MINE_vS  <suunama ;29_V	et	f	\N
133675	juubelilaulupeoga	juubelilaulupeoga =peo  (SgKom  >juubeli+laulu+pidu !18_S	et	f	\N
133676	juubelilaulupeoga	juubelilaulupeoga =peo  (SgKom  >juubeli+laulu+peo !26_S	et	f	\N
133685	ülesehitus	ülesehitus =ehitu  (SgIn  >üles+ehitu !01_AS	et	f	\N
133343	rahvalaulust	rahvalaulust =lust  (SgN  >rahva+lau+lust !22_S	et	f	\N
133344	rahvalaulust	rahvalaulust =laulu  (SgEl  >rahva+laul !22_S	et	f	\N
133360	setumaal	setumaal =maa  (SgAd  >setu+maa !26_S	et	f	\N
133361	setumaal	setumaal =maal  (SgN  >setu+maal !22_S	et	f	\N
133367	värska	?värska =värska  (SgN  >värska !01_S	et	f	\N
133368	värska	?värska =värska  (SgG  >värska !01_S	et	f	\N
133369	värska	?värska =värska  (IndPrPs_  >värskama !29_V	et	f	\N
133370	värska	?värska =värska  (ImpPrSg2  >värskama !29_V	et	f	\N
133371	poissid	### poissid	et	f	\N
133372	saja	saja =saja  (SgG  >sajas !02_O	et	f	\N
133373	saja	saja =saja  (SgG  >sada !18_N	et	f	\N
133374	saja	saja =saja  (IndPrPs_  >sadama !28_V	et	f	\N
133375	saja	saja =saja  (ImpPrSg2  >sadama !28_V	et	f	\N
133387	ülemaali	ülemaali =maali  (SgG  >üle+maal !22_S	et	f	\N
133388	ülemaali	ülemaali =maali  (SgP  >üle+maal !22_S	et	f	\N
133389	ülemaali	ülemaali =maali  (SgAdt  >üle+maal !22_S	et	f	\N
133401	nimekirja	nimekirja =kirja  (SgG  >nime+kiri !24_S	et	f	\N
133402	nimekirja	nimekirja =kirja  (SgP  >nime+kiri !24_S	et	f	\N
133403	nimekirja	nimekirja =kirja  (SgAdt  >nime+kiri !24_S	et	f	\N
133406	üheneb	?üheneb =ühene  (IndPrSg3  >ühenema !27_V	et	f	\N
133416	unikaalsust	unikaalsust =unikaalsus  (SgP  >unikaalsus !11~09_S	et	f	\N
133417	unikaalsust	"unikaalsus %unikaalse  )US_aS  <unikaalne ;02_A	et	f	\N
133466	erakorraliselt	erakorraliselt =korralise  (SgAbl  >era+korraline !12_AS	et	f	\N
133467	erakorraliselt	"era+korraline %korra  )LINE_aA  <era+kord ;22_S	et	f	\N
133468	erakorraliselt	"era+korraliselt %korra  )LISELT_mD  <era+kord ;22_S	et	f	\N
133469	erakorraliselt	"era+korraliselt %korralise  )LT_mD  <era+korraline ;12_AS	et	f	\N
133470	tansivad	?tansivad =tansi  (IndPrPl3  >tanssima !28_V	et	f	\N
133471	tansivad	?tansivad =tansiva  (PlN  >tansiva !01_S	et	f	\N
133472	tansivad	?tansivad =tansiva  (PlN  >tansiv !02_A	et	f	\N
133484	bajanit	?bajanit =bajani  (SgP  >bajan !02_S	et	f	\N
133491	sommer	?sommer =sommer  (SgN  >sommer !02_S	et	f	\N
133544	algselt	algselt =algse  (SgAbl  >algne !02_A	et	f	\N
133545	algselt	algselt =algselt  (ID  >algselt !41_D	et	f	\N
133546	algselt	"algselt %algse  )LT_mD  <algne ;02_A	et	f	\N
133570	laupeole	laupeole =peo  (SgAll  >lau+pidu !18_S	et	f	\N
133571	laupeole	laupeole =peo  (SgAll  >lau+peo !26_S	et	f	\N
133593	sümboliks	sümboliks =sümboli  (SgTr  >sümbol !02_S	et	f	\N
133594	sümboliks	sümboliks =iks  (SgN  >sümbol+iks !22_S	et	f	\N
133624	tähistasid	tähistasid =tähista  (IndIpfSg2  >tähistama !27_V	et	f	\N
133625	tähistasid	tähistasid =tähista  (IndIpfPl3  >tähistama !27_V	et	f	\N
133629	sugulastega	sugulastega =sugulas  (PlKom  >sugulane !12_S	et	f	\N
133630	sugulastega	sugulastega =las  (PlKom  >sugu+laps !14_S	et	f	\N
133634	rahv	?rahv =rahv  (SgN  >rahv !22_S	et	f	\N
133677	üldlaulupidude	üldlaulupidude =pidu  (PlG  >üld+laulu+pidu !17_S	et	f	\N
133678	üldlaulupidude	üldlaulupidude =pidu  (PlG  >üld+laulu+pidu !18_S	et	f	\N
133679	aastapäeva	aastapäeva =päeva  (SgG  >aasta+päev !22_S	et	f	\N
133680	aastapäeva	aastapäeva =päeva  (SgP  >aasta+päev !22_S	et	f	\N
133681	aastapäeva	aastapäeva =päeva  (SgAdt  >aasta+päev !22_S	et	f	\N
133682	1980ndate	?ndate =ndate  (SgN  >ndate !06_S	et	f	\N
133683	1980ndate	?ndate =ndate  (IndPrPs_  >ndatema !27_V	et	f	\N
133684	1980ndate	?ndate =ndate  (ImpPrSg2  >ndatema !27_V	et	f	\N
133687	üüritused	üüritused =üürituse  (PlN  >üüritus !11_S	et	f	\N
133688	üüritused	"üüritus %üüri  )TUS1_aS  <üürima ;28_V	et	f	\N
133689	üüritused	"üüritus %üüri  )TUS2_aS  <üür ;22_S	et	f	\N
133690	rahvapeod	rahvapeod =peo  (PlN  >rahva+pidu !18_S	et	f	\N
133691	rahvapeod	rahvapeod =peo  (PlN  >rahva+peo !26_S	et	f	\N
133692	rahvapeod	rahvapeod =peo  (SgP  >rahva+peo !26_S	et	f	\N
133696	räp	### räp	et	f	\N
133697	vanilla	?vanilla =vanilla  (SgN  >vanilla !16_S	et	f	\N
133698	vanilla	?vanilla =vanilla  (SgG  >vanilla !16_S	et	f	\N
133730	regilaul	regilaul =lau  (SgAd  >regi+laug !22_SA	et	f	\N
133731	regilaul	regilaul =laul  (SgN  >regi+laul !22_S	et	f	\N
133732	jagavad	jagavad =jaga  (IndPrPl3  >jagama !27_V	et	f	\N
133733	jagavad	jagavad =jagava  (PlN  >jagav !02_A	et	f	\N
133734	jagavad	"jagav %jaga  )V_vA  <jagama ;27_V	et	f	\N
133742	folklooride	folklooride =folkloori  (PlG  >folkloor !22_S	et	f	\N
133743	folklooride	folklooride =loori  (PlG  >folk+loori !16_S	et	f	\N
133744	folklooride	folklooride =loori  (PlG  >folk+loor !22_S	et	f	\N
133748	väärsused	väärsused =väärsuse  (PlN  >väärsus !11~09_S	et	f	\N
133749	väärsused	"väärsus %väärse  )US_aS  <väärne ;02_A	et	f	\N
133753	teemaid	teemaid =ma  (PlP  >tee+maa !26_S	et	f	\N
133754	teemaid	teemaid =mai  (PlN  >tee+mai !26_S	et	f	\N
133756	teemaid	teemaid =mai  (SgP  >tee+mai !26_S	et	f	\N
133760	horisonti	horisonti =horisonti  (SgP  >horisont !22_S	et	f	\N
133761	horisonti	horisonti =horisonti  (SgAdt  >horisont !22_S	et	f	\N
133777	keskuste	keskuste =keskus  (PlG  >keskus !11~09_S	et	f	\N
133778	keskuste	keskuste =us  (PlG  >kesk+uks !14_S	et	f	\N
133779	muusika-	muusika- =muusika  (SgN  >muusika !01_S	et	f	\N
133346	jaata	jaata =jaata  (ImpPrSg2  >jaatama !27_V	et	f	\N
133347	folklooridele	folklooridele =folkloori  (PlAll  >folkloor !22_S	et	f	\N
133348	folklooridele	folklooridele =loori  (PlAll  >folk+loori !16_S	et	f	\N
133349	folklooridele	folklooridele =loori  (PlAll  >folk+loor !22_S	et	f	\N
133378	tantsupidu	tantsupidu =pidu  (SgN  >tantsu+pidu !17_S	et	f	\N
133379	tantsupidu	tantsupidu =pidu  (SgN  >tantsu+pidu !18_S	et	f	\N
133380	tantsupidu	tantsupidu =pidu  (SgG  >tantsu+pidu !17_S	et	f	\N
133381	tantsupidu	tantsupidu =pidu  (SgP  >tantsu+pidu !17_S	et	f	\N
133382	tantsupidu	tantsupidu =pidu  (SgP  >tantsu+pidu !18_S	et	f	\N
133390	aastadega	?aastadega =tade  (SgKom  >aas+tade !16_S	et	f	\N
133391	peos	peos =peo  (SgIn  >pidu !18_S	et	f	\N
133392	peos	peos =peo  (SgIn  >peo !26_S	et	f	\N
133399	unesco	?unesco =unesco  (SgN  >unesco !16_S	et	f	\N
133400	unesco	?unesco =unesco  (SgG  >unesco !16_S	et	f	\N
133414	isikpärasust	isikpärasust =pärasus  (SgP  >isik+pärasus !11_S	et	f	\N
133415	isikpärasust	"isik+pärasus %pära  )SUS_aS  <isik+pära ;17_S	et	f	\N
133431	panatseeja	?panatseeja =panatseeja  (SgN  >panatseeja !16_S	et	f	\N
133432	panatseeja	?panatseeja =panatseeja  (SgG  >panatseejas !02_A	et	f	\N
133433	panatseeja	?panatseeja =panatseeja  (SgG  >panatseeja !16_S	et	f	\N
133443	meeskoorid	meeskoorid =koori  (PlN  >mees+koor !22_S	et	f	\N
133444	meeskoorid	meeskoorid =skoori  (PlN  >mee+skoor !22_S	et	f	\N
133448	pealesunnitud	pealesunnitud =sunni  (PtsPtIps  >peale+_sundima !28_V	et	f	\N
133449	pealesunnitud	pealesunnitud =sunnitu  (PlN  >peale+sunnitu !01_AS	et	f	\N
133450	pealesunnitud	"peale+sunnitu %sunni  )TU2_kA  <peale+sund ;22_S	et	f	\N
133451	legentidest	?legentidest =legenti  (PlEl  >legent !22_S	et	f	\N
133452	legentidest	?legentidest =legentides  (SgP  >legentidene !12_A	et	f	\N
133453	loodusest	loodusest =looduse  (SgEl  >loodus !11~09_S	et	f	\N
133454	loodusest	"loodus %loo  )TUS1_aS  <looma ;38_V	et	f	\N
133455	loodusest	loodusest =looduses  (SgP  >loodusene !12_A	et	f	\N
133456	loodusest	"loodusene %looduse  )NE_aA  <loodus ;09_S	et	f	\N
133457	loodusest	"loodusene %looduse  )NE_aA  <loodus ;11_S	et	f	\N
133458	trageediline	?trageediline =trageediline  (SgN  >trageediline !12_A	et	f	\N
133459	trageediline	?trageediline =trageediline  (PlP  >trageedilin !19_S	et	f	\N
133462	kahekümne	?kahekümne =kahekümne  (SgN  >kahekümne !02_A	et	f	\N
133463	kahekümne	?kahekümne =kahekümne  (PlP  >kahekümn !22_S	et	f	\N
133464	kahekümne	?kahekümne =kümne  (SgN  >kahe+kümne !02_A	et	f	\N
133465	kahekümne	?kahekümne =kümne  (PlP  >kahe+kümn !22_S	et	f	\N
133487	populäärne	?populäärne =populäärne  (SgN  >populäärne !02_A	et	f	\N
133488	populäärne	?populäärne =populäärne  (PlP  >populäärn !22_S	et	f	\N
133489	populäärne	?populäärne =uläärne  (SgN  >pop+uläärne !02_A	et	f	\N
133490	populäärne	?populäärne =uläärne  (PlP  >pop+uläärn !22_S	et	f	\N
133494	filmimuusika	filmimuusika =muusika  (SgN  >filmi+muusika !01_S	et	f	\N
133495	filmimuusika	filmimuusika =muusika  (SgG  >filmi+muusika !01_S	et	f	\N
133517	kitarrit	?kitarrit =kitarri  (SgP  >kitarri !01_S	et	f	\N
133523	laulupidadel	?laulupidadel =pida  (PlAd  >laulu+pida !17_S	et	f	\N
133531	paljum	?paljum =paljum  (SgN  >paljum !02_S	et	f	\N
133538	teedsid	?teedsid =teedsi  (PlN  >teeds !22_S	et	f	\N
133539	teedsid	?teedsid =teedsi  (IndPrSg2  >teedsima !28_V	et	f	\N
133552	eesmärgi	eesmärgi =märgi  (SgG  >ees+märk !22_S	et	f	\N
133553	eesmärgi	eesmärgi =märgi  (SgP  >ees+märg !22_AS	et	f	\N
133554	eesmärgi	eesmärgi =märgi  (SgAdt  >ees+märg !22_AS	et	f	\N
133555	eesmärgi	eesmärgi =märgi  (PlP  >ees+märg !22_AS	et	f	\N
133579	vaatisin	?vaatisin =vaati  (IndIpfSg1  >vaatima !28_V	et	f	\N
133580	vaatisin	?vaatisin =vaatisin  (SgN  >vaatisin !19_S	et	f	\N
133581	lauljaid	lauljaid =laulja  (PlP  >laulja !01_S	et	f	\N
133582	lauljaid	"laulja %laul  )JA_vS  <laulma ;33_V	et	f	\N
133589	kanel	?kanel =kane  (SgAd  >kane !16_S	et	f	\N
133590	kanel	?kanel =kanel  (SgN  >kanel !02_S	et	f	\N
133591	laulmisele	laulmisele =laulmise  (SgAll  >laulmine !12?10_S	et	f	\N
133592	laulmisele	"laulmine %laul  )MINE_vS  <laulma ;33_V	et	f	\N
133598	laulajad	?laulajad =laulaja  (PlN  >laulaja !01_S	et	f	\N
133599	laulajad	?laulajad =laulaja  (PlN  >laulajas !02_A	et	f	\N
133600	laulajad	?laulajad =laja  (PlN  >lau+laja !17_S	et	f	\N
133618	gustavi	?gustavi =gustavi  (ID  >gustavi !41_D	et	f	\N
133619	gustavi	?gustavi =gustavi  (SgG  >gustav !02_A	et	f	\N
133635	peo	peo =peo  (SgN  >peo !26_S	et	f	\N
133636	peo	peo =peo  (SgG  >pidu !18_S	et	f	\N
133637	peo	peo =peo  (SgG  >peo !26_S	et	f	\N
133695	mitmekesised	?mitmekesised =mitmekesise  (PlN  >mitmekesis !09_S	et	f	\N
133712	ärkamise	ärkamise =ärkamise  (SgG  >ärkamine !12_S	et	f	\N
133713	ärkamise	"ärkamine %ärka  )MINE_vS  <ärkama ;29_V	et	f	\N
133716	pärinud	pärinud =päri  (PtsPtPs  >pärima !27_V	et	f	\N
133717	pärinud	pärinud =pärinu  (PlN  >pärinu !01_S	et	f	\N
133718	pärinud	"pärinu %päri  )NU_vS  <pärima ;27_V	et	f	\N
133719	pärinud	pärinud =pärinud  (ID  >pärinud !41_A	et	f	\N
133720	pärinud	"pärinud %päri  )NUD_vA  <pärima ;27_V	et	f	\N
133513	kaudna	?kaudna =kaudna  (SgG  >kaudna !01_S	et	f	\N
133514	kaudna	?kaudna =kaudna  (IndPrPs_  >kaudnama !29_V	et	f	\N
133515	kaudna	?kaudna =kaudna  (ImpPrSg2  >kaudnama !29_V	et	f	\N
133524	rahvakultuuriga	rahvakultuuriga =iga  (SgN  >rahva+kultuur+iga !18_S	et	f	\N
133525	rahvakultuuriga	rahvakultuuriga =iga  (SgP  >rahva+kultuur+iga !18_S	et	f	\N
133526	rahvakultuuriga	rahvakultuuriga =kultuuri  (SgKom  >rahva+kultuur !22_S	et	f	\N
133534	saadsid	?saadsid =saadsi  (PlN  >saads !22_S	et	f	\N
133535	saadsid	?saadsid =saadsi  (IndPrSg2  >saadsima !28_V	et	f	\N
133540	vies	?vies =vie  (SgIn  >vie !26_S	et	f	\N
133541	vies	?vies =vies  (SgN  >vies !09_S	et	f	\N
133547	rakendatud	rakendatud =rakenda  (PtsPtIps  >rakendama !27_V	et	f	\N
133548	rakendatud	rakendatud =rakendatu  (PlN  >rakendatu !01_S	et	f	\N
133549	rakendatud	"rakendatu %rakenda  )TU1_vS  <rakendama ;27_V	et	f	\N
133550	rakendatud	rakendatud =rakendatud  (ID  >rakendatud !41_A	et	f	\N
133551	rakendatud	"rakendatud %rakenda  )TUD_vA  <rakendama ;27_V	et	f	\N
133556	saavutamiseks	saavutamiseks =saavutamise  (SgTr  >saavutamine !12_S	et	f	\N
133557	saavutamiseks	"saavutamine %saavuta  )MINE_vS  <saavutama ;27_V	et	f	\N
133558	valgevenemaal	valgevenemaal =maa  (SgAd  >valge+vene+maa !26_S	et	f	\N
133559	valgevenemaal	valgevenemaal =maal  (SgN  >valge+vene+maal !22_S	et	f	\N
133560	üheksakümnenda	?üheksakümnenda =üheksakümnenda  (SgN  >üheksakümnenda !16_S	et	f	\N
133561	üheksakümnenda	?üheksakümnenda =üheksakümnenda  (SgG  >üheksakümnenda !16_S	et	f	\N
133562	üheksakümnenda	?üheksakümnenda =üheksakümnenda  (IndPrPs_  >üheksakümnendama !27_V	et	f	\N
133563	üheksakümnenda	?üheksakümnenda =üheksakümnenda  (ImpPrSg2  >üheksakümnendama !27_V	et	f	\N
133564	üheksakümnenda	?üheksakümnenda =kümnenda  (SgN  >üheksa+kümnenda !01_S	et	f	\N
133565	üheksakümnenda	?üheksakümnenda =kümnenda  (SgG  >üheksa+kümnenda !01_S	et	f	\N
133566	üheksakümnenda	?üheksakümnenda =akümnenda  (SgN  >üheks+akümnenda !16_S	et	f	\N
133567	üheksakümnenda	?üheksakümnenda =akümnenda  (SgG  >üheks+akümnenda !16_S	et	f	\N
133568	üheksakümnenda	?üheksakümnenda =ksakümnenda  (SgN  >ühe+ksakümnenda !16_S	et	f	\N
133569	üheksakümnenda	?üheksakümnenda =ksakümnenda  (SgG  >ühe+ksakümnenda !16_S	et	f	\N
133575	nantsida	?nantsida =nantsi  (Inf  >nantsima !28_V	et	f	\N
133587	tantsid	tantsid =tantsi  (PlN  >tants !22_S	et	f	\N
133588	tantsid	tantsid =tantsi  (IndPrSg2  >tantsima !28_V	et	f	\N
133601	laulamine	?laulamine =laulamine  (SgN  >laulamine !12_S	et	f	\N
133602	laulamine	?laulamine =laulamine  (PlP  >laulamin !19_S	et	f	\N
133603	laulamine	?laulamine =lamine  (SgN  >lau+lamine !10_A	et	f	\N
133611	iseseisuv	?iseseisuv =iseseisu  (PtsPrPs  >iseseisuma !27_V	et	f	\N
133612	iseseisuv	?iseseisuv =iseseisuv  (SgN  >iseseisuv !02_A	et	f	\N
133613	iseseisuv	?iseseisuv =seisuv  (SgN  >ise+seisuv !02_A	et	f	\N
133615	üldlaulupeod	üldlaulupeod =peo  (PlN  >üld+laulu+pidu !18_S	et	f	\N
133616	üldlaulupeod	üldlaulupeod =peo  (PlN  >üld+laulu+peo !26_S	et	f	\N
133617	üldlaulupeod	üldlaulupeod =peo  (SgP  >üld+laulu+peo !26_S	et	f	\N
133620	ernesaksi	?ernesaksi =ernesaksi  (IndPrPs_  >ernesaksima !28_V	et	f	\N
133621	ernesaksi	?ernesaksi =ernesaksi  (ImpPrSg2  >ernesaksima !28_V	et	f	\N
133638	koore	koore =koore  (SgG  >koor !13_S	et	f	\N
133639	koore	koore =koore  (PlP  >koor !22_S	et	f	\N
133640	tantsijaid	tantsijaid =tantsija  (PlP  >tantsija !01_S	et	f	\N
133641	tantsijaid	"tantsija %tantsi  )JA_vS  <tantsima ;28_V	et	f	\N
133654	välismaalseid	?välismaalseid =välismaalse  (PlP  >välismaalne !02_A	et	f	\N
133655	välismaalseid	?välismaalseid =välismaalsei  (PlN  >välismaalsei !26_S	et	f	\N
133656	välismaalseid	?välismaalseid =välismaalsei  (SgP  >välismaalsei !26_S	et	f	\N
133657	välismaalseid	?välismaalseid =maalse  (PlP  >välis+maalne !02_A	et	f	\N
133658	välismaalseid	?välismaalseid =maalse  (PlP  >välis+maalse !06_S	et	f	\N
133659	välismaalseid	?välismaalseid =maalsei  (PlN  >välis+maalsei !26_S	et	f	\N
133660	välismaalseid	?välismaalseid =maalsei  (SgP  >välis+maalsei !26_S	et	f	\N
133661	välismaalseid	?välismaalseid =maalseid  (SgN  >välis+maalseid !22_S	et	f	\N
133662	välismaalseid	?välismaalseid =smaalse  (PlP  >väli+smaalne !02_A	et	f	\N
133663	välismaalseid	?välismaalseid =smaalse  (PlP  >väli+smaalse !06_S	et	f	\N
133664	välismaalseid	?välismaalseid =smaalsei  (PlN  >väli+smaalsei !26_S	et	f	\N
133665	välismaalseid	?välismaalseid =smaalsei  (SgP  >väli+smaalsei !26_S	et	f	\N
133666	välismaalseid	?välismaalseid =smaalseid  (SgN  >väli+smaalseid !22_S	et	f	\N
133671	üldlaulupeost	üldlaulupeost =peo  (SgEl  >üld+laulu+pidu !18_S	et	f	\N
133672	üldlaulupeost	üldlaulupeost =peo  (SgEl  >üld+laulu+peo !26_S	et	f	\N
133693	lisandusid	lisandusid =lisandu  (IndIpfSg2  >lisanduma !27_V	et	f	\N
133694	lisandusid	lisandusid =lisandu  (IndIpfPl3  >lisanduma !27_V	et	f	\N
133704	seotatud	?seotatud =seota  (PtsPtIps  >seotama !27_V	et	f	\N
133705	seotatud	?seotatud =seotatu  (PlN  >seotatu !01_S	et	f	\N
133706	seotatud	?seotatud =seotatu  (IndPrSg2  >seotatuma !27_V	et	f	\N
133707	seotatud	?seotatud =seotatud  (ID  >seotatud !41_A	et	f	\N
133714	lõpupoole	lõpupoole =poole  (SgN  >lõpu+poole !05_S	et	f	\N
133715	lõpupoole	lõpupoole =poole  (PlP  >lõpu+pool !22_S	et	f	\N
133750	avasid	avasid =ava  (PlP  >ava !17_S	et	f	\N
133532	eestlasid	?eestlasid =eestla  (IndIpfSg2  >eestlama !29_V	et	f	\N
133533	eestlasid	?eestlasid =eestla  (IndIpfPl3  >eestlama !29_V	et	f	\N
133572	väljendusvähed	### väljendusvähed	et	f	\N
133573	laulada	?laulada =lada  (SgN  >lau+lada !17_S	et	f	\N
133574	laulada	?laulada =lada  (SgG  >lau+lada !17_S	et	f	\N
133576	laulada	?laulada =lada  (SgP  >lau+lada !17_S	et	f	\N
133583	rahvadel	?rahvadel =rahva  (PlAd  >rahva !16_S	et	f	\N
133604	olulisemaist	olulisemaist =olulisema  (PlEl  >olulisem !02_A	et	f	\N
133605	olulisemaist	"olulisem %olu  )LISEM_cA  <olu ;17_S	et	f	\N
133606	olulisemaist	"olulisem %olulise  )M_cA  <oluline ;12_A	et	f	\N
133607	oskusest	oskusest =oskuse  (SgEl  >oskus !11~09_S	et	f	\N
133608	oskusest	oskusest =oskuses  (SgP  >oskusene !12_A	et	f	\N
133609	oskusest	"oskusene %oskuse  )NE_aA  <oskus ;09_S	et	f	\N
133610	oskusest	"oskusene %oskuse  )NE_aA  <oskus ;11_S	et	f	\N
133614	solvutada	?solvutada =solvuta  (Inf  >solvutama !27_V	et	f	\N
133626	kiigutates	?kiigutates =kiigutate  (PlIn  >kiigutatt !22_S	et	f	\N
133627	identitee	?identitee =identitee  (SgN  >identitee !26_S	et	f	\N
133628	identitee	?identitee =identitee  (SgG  >identitee !26_S	et	f	\N
133631	ühendavat	ühendavat =ühenda  (KvtPrPs  >ühendama !27_V	et	f	\N
133632	ühendavat	ühendavat =ühendava  (SgP  >ühendav !02_A	et	f	\N
133633	ühendavat	"ühendav %ühenda  )V_vA  <ühendama ;27_V	et	f	\N
133642	kuulastajaid	?kuulastajaid =kuulastaja  (PlP  >kuulastaja !01_S	et	f	\N
133643	kuulastajaid	?kuulastajaid =kuulastaja  (PlP  >kuulastajas !02_A	et	f	\N
133644	kuulastajaid	?kuulastajaid =kuulastajai  (PlN  >kuulastajai !26_S	et	f	\N
133645	kuulastajaid	?kuulastajaid =kuulastajai  (SgP  >kuulastajai !26_S	et	f	\N
133646	kuulastajaid	?kuulastajaid =astaja  (PlP  >kuul+astaja !01_S	et	f	\N
133647	kuulastajaid	?kuulastajaid =astaja  (PlP  >kuul+astajas !02_A	et	f	\N
133648	kuulastajaid	?kuulastajaid =astajai  (PlN  >kuul+astajai !26_S	et	f	\N
133649	kuulastajaid	?kuulastajaid =astajai  (SgP  >kuul+astajai !26_S	et	f	\N
133650	kuulastajaid	?kuulastajaid =lastaja  (PlP  >kuu+lastaja !01_S	et	f	\N
133651	kuulastajaid	?kuulastajaid =lastaja  (PlP  >kuu+lastajas !02_A	et	f	\N
133652	kuulastajaid	?kuulastajaid =lastajai  (PlN  >kuu+lastajai !26_S	et	f	\N
133653	kuulastajaid	?kuulastajaid =lastajai  (SgP  >kuu+lastajai !26_S	et	f	\N
133667	vabadussõda	vabadussõda =sõda  (SgN  >vabadus+sõda !18_S	et	f	\N
133668	vabadussõda	vabadussõda =sõda  (SgP  >vabadus+sõda !18_S	et	f	\N
133699	ninja	?ninja =ninja  (SgN  >ninja !16_S	et	f	\N
133700	ninja	?ninja =ninja  (SgG  >ninjas !02_A	et	f	\N
133701	ninja	?ninja =ninja  (SgG  >ninja !16_S	et	f	\N
133702	ninja	?ninja =ninja  (IndPrPs_  >ninjama !29_V	et	f	\N
133703	ninja	?ninja =ninja  (ImpPrSg2  >ninjama !29_V	et	f	\N
133708	rahvapidustega	rahvapidustega =pidus  (PlKom  >rahva+pidune !10_A	et	f	\N
133709	rahvapidustega	"rahva+pidune %pidu  )NE_aA  <rahva+pidu ;18_S	et	f	\N
133721	pop-	### pop-	et	f	\N
133727	ebamuusikaline	ebamuusikaline =muusikaline  (SgN  >eba+muusikaline !12_A	et	f	\N
133728	ebamuusikaline	"eba+muusikaline %muusika  )LINE_aA  <eba+muusika ;01_S	et	f	\N
133729	ebamuusikaline	"eba+muusikaline %muusikali  )NE_aA  <eba+muusikal ;19_S	et	f	\N
133745	autorilaulu	autorilaulu =laulu  (SgG  >autori+laul !22_S	et	f	\N
133746	autorilaulu	autorilaulu =laulu  (SgP  >autori+laul !22_S	et	f	\N
133747	autorilaulu	autorilaulu =laulu  (SgAdt  >autori+laul !22_S	et	f	\N
133751	uuete	?uuete =uue  (PlG  >uue !06_S	et	f	\N
133762	pulmalaul	pulmalaul =lau  (SgAd  >pulma+laug !22_SA	et	f	\N
133763	pulmalaul	pulmalaul =laul  (SgN  >pulma+laul !22_S	et	f	\N
133774	tähtsame	?tähtsame =tähtsa  (IndPrPl1  >tähtsama !29_V	et	f	\N
133775	tähtsame	?tähtsame =same  (SgN  >täht+same !16_S	et	f	\N
133776	tähtsame	?tähtsame =same  (SgG  >täht+same !16_S	et	f	\N
133786	ühiskonnaelus	ühiskonnaelus =elu  (SgIn  >ühis+konna+elu !17_S	et	f	\N
133787	ühiskonnaelus	ühiskonnaelus =elus  (SgN  >ühis+konna+elus !02_A	et	f	\N
133811	eestirahv	?eestirahv =eestirahv  (SgN  >eestirahv !22_S	et	f	\N
133812	eestirahv	?eestirahv =rahv  (SgN  >eesti+rahv !22_S	et	f	\N
133813	eestirahv	?eestirahv =irahv  (SgN  >eest+irahv !22_S	et	f	\N
133814	eestirahv	?eestirahv =tirahv  (SgN  >ees+tirahv !22_S	et	f	\N
133823	ülemane	?ülemane =ülemane  (SgN  >ülemane !12_A	et	f	\N
133825	ülemane	?ülemane =ülemane  (PlP  >üleman !19_S	et	f	\N
133827	ülemane	?ülemane =ane  (SgN  >ülem+ane !16_S	et	f	\N
133829	ülemane	?ülemane =ane  (SgG  >ülem+ane !16_S	et	f	\N
133843	folkloorfestivalid	?folkloorfestivalid =folkloorfestivali  (PlN  >folkloorfestival !19_S	et	f	\N
133844	folkloorfestivalid	?folkloorfestivalid =loorfestivali  (PlN  >folk+loorfestival !19_S	et	f	\N
133845	aulurahva	?aulurahva =aulurahva  (SgN  >aulurahva !16_S	et	f	\N
133846	aulurahva	?aulurahva =aulurahva  (SgG  >aulurahva !16_S	et	f	\N
133847	aulurahva	?aulurahva =lurahva  (SgN  >au+lurahva !01_S	et	f	\N
133848	aulurahva	?aulurahva =lurahva  (SgG  >au+lurahva !01_S	et	f	\N
133853	estlaste	?estlaste =estlas  (PlG  >estlas !07_S	et	f	\N
133854	estlaste	?estlaste =estlas  (PlG  >estlane !12?10_S	et	f	\N
133857	tantsimisega	tantsimisega =tantsimise  (SgKom  >tantsimine !12_S	et	f	\N
133686	ülesehitus	ülesehitus =ehitus  (SgN  >üles+ehitus !11_S	et	f	\N
133710	töötamise	töötamise =töötamise  (SgG  >töötamine !12_S	et	f	\N
133711	töötamise	"töötamine %tööta  )MINE_vS  <töötama ;27_V	et	f	\N
133739	koosnevad	koosnevad =koosne  (IndPrPl3  >koosnema !27_V	et	f	\N
133740	koosnevad	koosnevad =koosneva  (PlN  >koosnev !02_A	et	f	\N
133741	koosnevad	"koosnev %koosne  )V_vA  <koosnema ;27_V	et	f	\N
133757	avardavad	avardavad =avarda  (IndPrPl3  >avardama !27_V	et	f	\N
133758	avardavad	avardavad =avardava  (PlN  >avardav !02_A	et	f	\N
133759	avardavad	"avardav %avarda  )V_vA  <avardama ;27_V	et	f	\N
133768	erinevaides	?erinevaides =erinevai  (PlIn  >erinevai !26_S	et	f	\N
133769	erinevaides	?erinevaides =erinevaide  (PlIn  >erinevait !22_S	et	f	\N
133770	erinevaides	?erinevaides =nevai  (PlIn  >eri+nevai !26_S	et	f	\N
133771	erinevaides	?erinevaides =nevaide  (PlIn  >eri+nevait !22_S	et	f	\N
133772	laulute	?laulute =laulu  (IndPrPl2  >lauluma !28_V	et	f	\N
133773	laulute	?laulute =lute  (SgN  >lau+lute !06_S	et	f	\N
133794	eestirahvu	?eestirahvu =eestirahvu  (IndPrPs_  >eestirahvuma !27_V	et	f	\N
133795	eestirahvu	?eestirahvu =eestirahvu  (ImpPrSg2  >eestirahvuma !27_V	et	f	\N
133796	eestirahvu	?eestirahvu =rahvu  (SgN  >eesti+rahvu !16_S	et	f	\N
133797	eestirahvu	?eestirahvu =rahvu  (SgG  >eesti+rahvu !16_S	et	f	\N
133798	eestirahvu	?eestirahvu =irahvu  (SgN  >eest+irahvu !01_S	et	f	\N
133799	eestirahvu	?eestirahvu =irahvu  (SgG  >eest+irahvu !01_S	et	f	\N
133800	eestirahvu	?eestirahvu =tirahvu  (SgN  >ees+tirahvu !01_S	et	f	\N
133801	eestirahvu	?eestirahvu =tirahvu  (SgG  >ees+tirahvu !01_S	et	f	\N
133824	laulpidu	?laulpidu =laulpidu  (SgN  >laulpidu !01_S	et	f	\N
133826	laulpidu	?laulpidu =laulpidu  (SgG  >laulpidu !01_S	et	f	\N
133828	laulpidu	?laulpidu =laulpidu  (IndPrPs_  >laulpiduma !27_V	et	f	\N
133830	laulpidu	?laulpidu =laulpidu  (ImpPrSg2  >laulpiduma !27_V	et	f	\N
133831	laulapeol	?laulapeol =laulapeo  (SgAd  >laulapeo !01_S	et	f	\N
133832	laulapeol	?laulapeol =laulapeol  (SgN  >laulapeol !19_S	et	f	\N
133833	laulapeol	?laulapeol =lapeo  (SgAd  >lau+lapeo !01_S	et	f	\N
133834	laulapeol	?laulapeol =lapeol  (SgN  >lau+lapeol !19_S	et	f	\N
133849	muusikale	muusikale =muusika  (SgAll  >muusika !01_S	et	f	\N
133850	muusikale	muusikale =muusikale  (PlP  >muusikal !19_S	et	f	\N
133855	laulmise	laulmise =laulmise  (SgG  >laulmine !12?10_S	et	f	\N
133856	laulmise	"laulmine %laul  )MINE_vS  <laulma ;33_V	et	f	\N
133864	pulmast	pulmast =pulma  (SgEl  >pulm !22_S	et	f	\N
133865	pulmast	pulmast =pulmas  (SgP  >pulmane !10_A	et	f	\N
133866	pulmast	"pulmane %pulma  )NE_aA  <pulm ;22_S	et	f	\N
133886	veeda	veeda =veeda  (IndPrPs_  >veetma !34_V	et	f	\N
133887	veeda	veeda =veeda  (ImpPrSg2  >veetma !34_V	et	f	\N
133897	arendavad	arendavad =arenda  (IndPrPl3  >arendama !27_V	et	f	\N
133898	arendavad	arendavad =arendava  (PlN  >arendav !02_A	et	f	\N
133899	arendavad	"arendav %arenda  )V_vA  <arendama ;27_V	et	f	\N
133925	festivallid	?festivallid =festivalli  (PlN  >festivall !22_S	et	f	\N
133927	festivallid	?festivallid =festivalli  (IndPrSg2  >festivallima !28_V	et	f	\N
133938	kaldale	kaldale =kalda  (SgAll  >kallas !07_S	et	f	\N
133939	kaldale	kaldale =ale  (SgN  >kald+ale !16_S	et	f	\N
133940	kaldale	kaldale =ale  (SgG  >kald+ale !16_S	et	f	\N
133947	suuredes	suuredes =ede  (SgIn  >suur+ede !16_S	et	f	\N
133948	suuredes	suuredes =re  (PlIn  >suu+re !26_S	et	f	\N
133955	loominguses	?loominguses =loominguse  (SgIn  >loomingus !11_S	et	f	\N
133957	loominguses	?loominguses =inguse  (SgIn  >loom+ingus !11~09_S	et	f	\N
133958	loominguses	?loominguses =minguse  (SgIn  >loo+mingus !11~09_S	et	f	\N
133959	folkloore	folkloore =folkloore  (PlP  >folkloor !22_S	et	f	\N
133960	folkloore	folkloore =loore  (PlP  >folk+loor !22_S	et	f	\N
133964	kuulsam	kuulsam =kuulsam  (SgN  >kuulsam !02_A	et	f	\N
133965	kuulsam	"kuulsam %kuulsa  )M_cA  <kuulus ;02_A	et	f	\N
133984	lülitati	lülitati =lülita  (IndIpfIps  >lülitama !27_V	et	f	\N
133985	lülitati	lülitati =tati  (SgG  >lüli+tatt !22_S	et	f	\N
133989	esinejat	esinejat =esineja  (SgP  >esineja !01_S	et	f	\N
133990	esinejat	"esineja %esine  )JA_vS  <esinema ;27_V	et	f	\N
133995	soomad	?soomad =sooma  (PlN  >sooma !16_S	et	f	\N
133996	soomad	?soomad =sooma  (IndPrSg2  >soomama !29_V	et	f	\N
134003	tansida	?tansida =tansi  (Inf  >tansima !28_V	et	f	\N
134070	vabarigi	?vabarigi =rigi  (SgN  >vaba+rigi !17_S	et	f	\N
134071	vabarigi	?vabarigi =rigi  (SgG  >vaba+rigi !17_S	et	f	\N
134072	vabarigi	?vabarigi =rigi  (SgP  >vaba+rigi !17_S	et	f	\N
134073	vabarigi	?vabarigi =vabari  (SgN^  >vabari !01_S	et	f	\N
134074	vabarigi	?vabarigi =vabari  (SgG^  >vabari !01_S	et	f	\N
134075	vabarigi	?vabarigi =vabari  (SgG^  >vabar !02_S	et	f	\N
134076	julis	?julis =juli  (SgIn  >juli !17_S	et	f	\N
134077	julis	?julis =juli  (IndIpfSg3  >julima !27_V	et	f	\N
134078	julis	?julis =julis  (SgN  >julis !09_S	et	f	\N
134091	märksõna	märksõna =sõna  (SgN  >märk+sõna !17_S	et	f	\N
134092	märksõna	märksõna =sõna  (SgG  >märk+sõna !17_S	et	f	\N
134093	märksõna	märksõna =sõna  (SgP  >märk+sõna !17_S	et	f	\N
134100	tudrukud	?tudrukud =tudruku  (PlN  >tudruku !01_S	et	f	\N
133722	rokmuusika	?rokmuusika =rokmuusika  (SgN  >rokmuusika !01_S	et	f	\N
133723	rokmuusika	?rokmuusika =rokmuusika  (SgG  >rokmuusika !01_S	et	f	\N
133724	rokmuusika	?rokmuusika =rokmuusika  (SgG  >rokmuusikas !02_A	et	f	\N
133725	laulumaa	laulumaa =maa  (SgN  >laulu+maa !26_S	et	f	\N
133726	laulumaa	laulumaa =maa  (SgG  >laulu+maa !26_S	et	f	\N
133735	xviii	?xviii =xviii  (SgN  >xviii !26_S	et	f	\N
133736	xviii	?xviii =xviii  (SgG  >xviii !26_S	et	f	\N
133737	maalest	maalest =maale  (PlEl  >maal !22_S	et	f	\N
133738	maalest	maalest =lest  (SgN  >maa+lest !22_S	et	f	\N
133764	töölaul	töölaul =au  (SgAd  >tööl+au !26_S	et	f	\N
133765	töölaul	töölaul =aul  (SgN  >tööl+aul !22_S	et	f	\N
133766	töölaul	töölaul =lau  (SgAd  >töö+laug !22_SA	et	f	\N
133767	töölaul	töölaul =laul  (SgN  >töö+laul !22_S	et	f	\N
133781	vokaalnekollektiivid	?vokaalnekollektiivid =vokaalnekollektiivi  (PlN  >vokaalnekollektiivi !16_S	et	f	\N
133782	vokaalnekollektiivid	?vokaalnekollektiivid =vokaalnekollektiivi  (PlN  >vokaalnekollektiiv !22_S	et	f	\N
133783	vokaalnekollektiivid	?vokaalnekollektiivid =vokaalnekollektiivi  (IndPrSg2  >vokaalnekollektiivima !28_V	et	f	\N
133784	vokaalnekollektiivid	?vokaalnekollektiivid =nekollektiivi  (PlN  >vokaal+nekollektiivi !16_S	et	f	\N
133785	vokaalnekollektiivid	?vokaalnekollektiivid =nekollektiivi  (PlN  >vokaal+nekollektiiv !22_S	et	f	\N
133788	mõjvad	?mõjvad =mõjva  (PlN  >mõjva !16_S	et	f	\N
133789	mõjvad	?mõjvad =mõjva  (IndPrSg2  >mõjvama !29_V	et	f	\N
133790	hoolima	hoolima =hooli  (Sup  >hoolima !28_V	et	f	\N
133791	hoolima	hoolima =lima  (SgN  >hoo+lima !17_S	et	f	\N
133792	hoolima	hoolima =lima  (SgG  >hoo+lima !17_S	et	f	\N
133793	hoolima	hoolima =lima  (SgP  >hoo+lima !17_S	et	f	\N
133808	poolnud	?poolnud =poolnu  (PlN  >poolnu !01_S	et	f	\N
133809	poolnud	?poolnud =poolnu  (IndPrSg2  >poolnuma !27_V	et	f	\N
133810	poolnud	?poolnud =poolnud  (ID  >poolnud !41_A	et	f	\N
133821	maatused	maatused =maatuse  (PlN  >maatus !11~09_S	et	f	\N
133822	maatused	"maatus %maa  )TUS2_aS  <maa ;26_S	et	f	\N
133838	rahvamuusika	rahvamuusika =muusika  (SgN  >rahva+muusika !01_S	et	f	\N
133839	rahvamuusika	rahvamuusika =muusika  (SgG  >rahva+muusika !01_S	et	f	\N
133840	esitajaid	esitajaid =esitaja  (PlP  >esitaja !01_S	et	f	\N
133841	esitajaid	"esitaja %esita  )JA_vS  <esitama ;27_V	et	f	\N
133892	rahvamuusikast	rahvamuusikast =muusika  (SgEl  >rahva+muusika !01_S	et	f	\N
133893	rahvamuusikast	rahvamuusikast =muusikas  (SgP  >rahva+muusikane !12_A	et	f	\N
133894	rahvamuusikast	"rahva+muusikane %muusika  )NE_aA  <rahva+muusika ;01_S	et	f	\N
133900	natukest	natukest =natukes  (SgP  >natuke !12_S	et	f	\N
133901	natukest	natukest =natukes  (SgP  >natukene !12_S	et	f	\N
133918	inimesid	### inimesid	et	f	\N
133919	helilojad	?helilojad =heliloja  (PlN  >heliloja !01_S	et	f	\N
133920	helilojad	?helilojad =heliloja  (PlN  >helilojas !02_A	et	f	\N
133921	helilojad	?helilojad =loja  (PlN  >heli+loja !17_S	et	f	\N
133942	õht	?õht =õht  (SgN  >õht !22_S	et	f	\N
133961	festivaalid	?festivaalid =festivaali  (PlN  >festivaali !16_S	et	f	\N
133962	festivaalid	?festivaalid =festivaali  (PlN  >festivaal !22_S	et	f	\N
133963	festivaalid	?festivaalid =festivaali  (IndPrSg2  >festivaalima !28_V	et	f	\N
133966	festivaal	?festivaal =festivaa  (SgAd  >festivaa !26_S	et	f	\N
133967	festivaal	?festivaal =festivaal  (SgN  >festivaal !22_S	et	f	\N
133972	südas	?südas =süda  (IndIpfSg3  >südama !27_V	et	f	\N
133973	südas	?südas =südas  (SgN  >südas !07_S	et	f	\N
133986	esinemised	esinemised =esinemise  (PlN  >esinemine !12_S	et	f	\N
133987	esinemised	"esinemine %esine  )MINE_vS  <esinema ;27_V	et	f	\N
134004	pidusel	pidusel =piduse  (SgAd  >pidune !10_A	et	f	\N
134005	pidusel	"pidune %pidu  )NE_aA  <pidu ;18_S	et	f	\N
134015	lauldatakse	?lauldatakse =laulda  (IndPrIps  >lauldama !27_V	et	f	\N
134016	lauldatakse	?lauldatakse =laulda  (IndPrIps  >laultama !29_V	et	f	\N
134017	lauldatakse	?lauldatakse =lauldatakse  (SgG  >lauldatakne !02_A	et	f	\N
134018	lauldatakse	?lauldatakse =lauldatakse  (PlP  >lauldataks !22_S	et	f	\N
134041	viljandisse	?viljandisse =viljandi  (SgIll  >viljandi !01_S	et	f	\N
134042	viljandisse	?viljandisse =viljandi  (SgIll  >viljand !02_S	et	f	\N
134043	viljandisse	?viljandisse =viljandi  (SgIll  >viljant !22_S	et	f	\N
134044	viljandisse	?viljandisse =viljandis  (SgAdt  >viljandis !11_S	et	f	\N
134045	viljandisse	?viljandisse =viljandisse  (SgG  >viljandisne !02_A	et	f	\N
134046	viljandisse	?viljandisse =viljandisse  (PlP  >viljandiss !22_S	et	f	\N
134062	ülemaalne	?ülemaalne =ülemaalne  (SgN  >ülemaalne !02_A	et	f	\N
134063	ülemaalne	?ülemaalne =ülemaalne  (PlP  >ülemaaln !22_S	et	f	\N
134064	ülemaalne	?ülemaalne =aalne  (SgN  >ülem+aalne !02_A	et	f	\N
134065	ülemaalne	?ülemaalne =aalne  (PlP  >ülem+aaln !22_S	et	f	\N
134066	ülemaalne	?ülemaalne =maalne  (SgN  >üle+maalne !02_A	et	f	\N
134067	ülemaalne	?ülemaalne =maalne  (PlP  >üle+maaln !22_S	et	f	\N
134068	esimen	?esimen =esimen  (SgN  >esimen !19_S	et	f	\N
134069	kuulturiosanadele	### kuulturiosanadele	et	f	\N
134094	korraldamises	korraldamises =korraldamise  (SgIn  >korraldamine !12_S	et	f	\N
134095	korraldamises	"korraldamine %korralda  )MINE_vS  <korraldama ;27_V	et	f	\N
133752	avasid	avasid =ava  (IndIpfSg2  >avama !27_V	et	f	\N
133755	avasid	avasid =ava  (IndIpfPl3  >avama !27_V	et	f	\N
133817	valjendusvahend	?valjendusvahend =valjendusvahend  (SgN  >valjendusvahend !22_S	et	f	\N
133842	vedakse	?vedakse =vedakse  (SgG  >vedakne !02_A	et	f	\N
133869	põlva	?põlva =põlva  (SgN  >põlva !16_S	et	f	\N
133870	põlva	?põlva =põlva  (SgG  >põlva !16_S	et	f	\N
133871	põlva	?põlva =põlva  (IndPrPs_  >põlvama !29_V	et	f	\N
133872	põlva	?põlva =põlva  (ImpPrSg2  >põlvama !29_V	et	f	\N
133873	pöördakse	?pöördakse =pöördakse  (SgG  >pöördakne !02_A	et	f	\N
133888	nissuguseid	?nissuguseid =nissugusei  (PlN  >nissugusei !26_S	et	f	\N
133889	nissuguseid	?nissuguseid =nissugusei  (SgP  >nissugusei !26_S	et	f	\N
133922	folklööri	?folklööri =folklööri  (SgN  >folklööri !16_S	et	f	\N
133923	folklööri	?folklööri =folklööri  (SgG  >folklööri !16_S	et	f	\N
133924	folklööri	?folklööri =folklööri  (SgG  >folklöör !22_S	et	f	\N
133926	folklööri	?folklööri =folklööri  (SgP  >folklöör !22_S	et	f	\N
133928	folklööri	?folklööri =folklööri  (SgAdt  >folklöör !22_S	et	f	\N
133929	folklööri	?folklööri =folklööri  (IndPrPs_  >folklöörima !28_V	et	f	\N
133930	folklööri	?folklööri =folklööri  (ImpPrSg2  >folklöörima !28_V	et	f	\N
133931	folklööri	?folklööri =lööri  (SgN  >folk+lööri !16_S	et	f	\N
133932	folklööri	?folklööri =lööri  (SgG  >folk+lööri !16_S	et	f	\N
133933	folklööri	?folklööri =lööri  (SgG  >folk+löör !22_S	et	f	\N
133934	folklööri	?folklööri =lööri  (SgP  >folk+löör !22_S	et	f	\N
133935	folklööri	?folklööri =lööri  (SgAdt  >folk+löör !22_S	et	f	\N
133941	uul	?uul =uul  (SgN  >uul !22_S	et	f	\N
133949	hääli	hääli =hääl  (PlP  >hääl !13_S	et	f	\N
133950	hääli	hääli =hääli  (ID  >hääli !41_D	et	f	\N
133951	hääli	hääli =hääli  (IndPrPs_  >häälima !28_V	et	f	\N
133952	hääli	hääli =hääli  (ImpPrSg2  >häälima !28_V	et	f	\N
133969	rahvahingu	rahvahingu =hingu  (SgG  >rahva+hink !22_S	et	f	\N
133970	rahvahingu	rahvahingu =hingu  (SgP  >rahva+hing !22_S	et	f	\N
133971	rahvahingu	rahvahingu =hingu  (SgAdt  >rahva+hing !22_S	et	f	\N
133977	repertuari	?repertuari =repertuari  (SgN  >repertuari !16_S	et	f	\N
133978	repertuari	?repertuari =repertuari  (SgG  >repertuari !16_S	et	f	\N
133979	repertuari	?repertuari =repertuari  (SgG  >repertuar !19_S	et	f	\N
133980	repertuari	?repertuari =repertuari  (SgP  >repertuar !19_S	et	f	\N
133981	repertuari	?repertuari =repertuari  (SgAdt  >repertuar !19_S	et	f	\N
133982	repertuari	?repertuari =repertuari  (IndPrPs_  >repertuarima !28_V	et	f	\N
133983	repertuari	?repertuari =repertuari  (ImpPrSg2  >repertuarima !28_V	et	f	\N
133997	tansid	?tansid =tansi  (PlN  >tansi !16_S	et	f	\N
133998	tansid	?tansid =tansi  (PlN  >tanss !22_S	et	f	\N
133999	tansid	?tansid =tansi  (IndPrSg2  >tanssima !28_V	et	f	\N
134006	muinastud	?muinastud =muinastu  (PlN  >muinastu !01_S	et	f	\N
134007	muinastud	?muinastud =muinastu  (IndPrSg2  >muinastuma !27_V	et	f	\N
134010	laulame	laulame =laula  (IndPrPl1  >laulma !33_V	et	f	\N
134011	laulame	laulame =lame  (SgN  >lau+lame !02_A	et	f	\N
134028	kakskümmendani	?kakskümmendani =kakskümmenda  (SgTer  >kakskümmenda !16_S	et	f	\N
134029	kakskümmendani	?kakskümmendani =kakskümmendani  (SgG  >kakskümmendan !02_S	et	f	\N
134030	kakskümmendani	?kakskümmendani =kümmenda  (SgTer  >kaks+kümmenda !01_S	et	f	\N
134031	kakskümmendani	?kakskümmendani =kümmendani  (SgG  >kaks+kümmendan !19_S	et	f	\N
134032	kakskümmendani	?kakskümmendani =kümmendani  (SgP  >kaks+kümmendan !19_S	et	f	\N
134033	kakskümmendani	?kakskümmendani =kümmendani  (SgAdt  >kaks+kümmendan !19_S	et	f	\N
134034	trükki	trükki =trükki  (SgP  >trükk !22_S	et	f	\N
134035	trükki	trükki =trükki  (SgAdt  >trükk !22_S	et	f	\N
134047	põhiteema	põhiteema =teema  (SgN  >põhi+teema !16_S	et	f	\N
134048	põhiteema	põhiteema =teema  (SgG  >põhi+teema !16_S	et	f	\N
134049	õnnek	?õnnek =õnnek  (SgN  >õnnek !02_S	et	f	\N
134060	sundmuseks	?sundmuseks =sundmuse  (SgTr  >sundmus !11~09_S	et	f	\N
134061	sundmuseks	?sundmuseks =muse  (SgTr  >sund+muse !16_S	et	f	\N
134079	lauljat	lauljat =laulja  (SgP  >laulja !01_S	et	f	\N
134080	lauljat	"laulja %laul  )JA_vS  <laulma ;33_V	et	f	\N
134096	voldemarilt	?voldemarilt =voldemari  (SgAbl  >voldemar !19_S	et	f	\N
134097	liitusid	liitusid =liitu  (PlP  >liit !22_S	et	f	\N
134098	liitusid	liitusid =liitu  (IndIpfSg2  >liituma !27_V	et	f	\N
134099	liitusid	liitusid =liitu  (IndIpfPl3  >liituma !27_V	et	f	\N
134106	imelene	?imelene =imelene  (SgN  >imelene !12_A	et	f	\N
134107	imelene	?imelene =imelene  (PlP  >imelen !19_S	et	f	\N
134108	imelene	?imelene =lene  (SgN  >ime+lene !16_S	et	f	\N
134109	imelene	?imelene =lene  (SgG  >ime+lene !16_S	et	f	\N
134110	kuulamises	kuulamises =kuulamise  (SgIn  >kuulamine !12_S	et	f	\N
134111	kuulamises	"kuulamine %kuula  )MINE_vS  <kuulama ;29_V	et	f	\N
134112	armukest	armukest =armukes  (SgP  >armuke !12_S	et	f	\N
134113	armukest	"armuke %armu  )KE_dS  <arm ;22_S	et	f	\N
134114	armukest	armukest =armukes  (SgP  >armukene !12_S	et	f	\N
134115	armukest	"armukene %armu  )KENE_dS  <arm ;22_S	et	f	\N
134116	armukest	armukest =kest  (SgN  >armu+kest !22_S	et	f	\N
133780	muusika-	muusika- =muusika  (SgG  >muusika !01_S	et	f	\N
133802	nimetatavad	nimetatavad =nimetatava  (PlN  >nimetatav !02_A	et	f	\N
133803	nimetatavad	"nimetatav %nimeta  )TAV_vAS  <nimetama ;27_V	et	f	\N
133804	rahvu	?rahvu =rahvu  (SgN  >rahvu !16_S	et	f	\N
133805	rahvu	?rahvu =rahvu  (SgG  >rahvu !16_S	et	f	\N
133806	rahvu	?rahvu =rahvu  (IndPrPs_  >rahvuma !27_V	et	f	\N
133807	rahvu	?rahvu =rahvu  (ImpPrSg2  >rahvuma !27_V	et	f	\N
133815	saatsid	saatsid =saat  (IndIpfSg2  >saatma !34_V	et	f	\N
133816	saatsid	saatsid =saat  (IndIpfPl3  >saatma !34_V	et	f	\N
133818	tegis	?tegis =tegi  (SgIn  >tegi !17_S	et	f	\N
133819	tegis	?tegis =tegi  (IndIpfSg3  >tegima !27_V	et	f	\N
133820	tegis	?tegis =tegis  (SgN  >tegis !09_S	et	f	\N
133835	lauluks	lauluks =laulu  (SgTr  >laul !22_S	et	f	\N
133836	lauluks	lauluks =luks  (SgN  >lau+luks !22_S	et	f	\N
133837	lauluks	lauluks =luks  (SgN  >lau+luks !22_SA	et	f	\N
133851	eestirahvas	eestirahvas =rahva  (SgIn  >eesti+rahvas !07_S	et	f	\N
133852	eestirahvas	eestirahvas =rahvas  (SgN  >eesti+rahvas !07_S	et	f	\N
133859	tantsides	tantsides =tantsi  (PlIn  >tants !22_S	et	f	\N
133860	tantsides	tantsides =tantsi  (Ger  >tantsima !28_V	et	f	\N
133861	käisisid	?käisisid =käisi  (PlP  >käisi !16_S	et	f	\N
133862	käisisid	?käisisid =käisi  (IndIpfSg2  >käisima !28_V	et	f	\N
133863	käisisid	?käisisid =käisi  (IndIpfPl3  >käisima !28_V	et	f	\N
133867	edastati	edastati =edasta  (IndIpfIps  >edastama !27_V	et	f	\N
133868	edastati	edastati =tati  (SgG  >edas+tatt !22_S	et	f	\N
133874	folkloorefestivaale	?folkloorefestivaale =folkloorefestivaa  (SgAll  >folkloorefestivaa !26_S	et	f	\N
133875	folkloorefestivaale	?folkloorefestivaale =folkloorefestivaale  (SgN  >folkloorefestivaale !16_S	et	f	\N
133876	folkloorefestivaale	?folkloorefestivaale =folkloorefestivaale  (SgG  >folkloorefestivaale !16_S	et	f	\N
133877	folkloorefestivaale	?folkloorefestivaale =folkloorefestivaale  (PlP  >folkloorefestivaal !22_S	et	f	\N
133878	folkloorefestivaale	?folkloorefestivaale =refestivaa  (SgAll  >folk+loo+refestivaa !26_S	et	f	\N
133879	folkloorefestivaale	?folkloorefestivaale =refestivaale  (SgN  >folk+loo+refestivaale !16_S	et	f	\N
133880	folkloorefestivaale	?folkloorefestivaale =refestivaale  (SgG  >folk+loo+refestivaale !16_S	et	f	\N
133881	folkloorefestivaale	?folkloorefestivaale =refestivaale  (PlP  >folk+loo+refestivaal !22_S	et	f	\N
133882	folkloorefestivaale	?folkloorefestivaale =loorefestivaa  (SgAll  >folk+loorefestivaa !26_S	et	f	\N
133883	folkloorefestivaale	?folkloorefestivaale =loorefestivaale  (SgN  >folk+loorefestivaale !16_S	et	f	\N
133884	folkloorefestivaale	?folkloorefestivaale =loorefestivaale  (SgG  >folk+loorefestivaale !16_S	et	f	\N
133885	folkloorefestivaale	?folkloorefestivaale =loorefestivaale  (PlP  >folk+loorefestivaal !22_S	et	f	\N
133890	festifale	?festifale =festifa  (SgAll  >festifa !01_S	et	f	\N
133891	festifale	?festifale =festifale  (PlP  >festifal !19_S	et	f	\N
133902	rahvalaulad	?rahvalaulad =rahvalaula  (PlN  >rahvalaula !01_S	et	f	\N
133903	rahvalaulad	?rahvalaulad =laula  (PlN  >rahva+laula !16_S	et	f	\N
133904	istuvad	istuvad =istu  (IndPrPl3  >istuma !28_V	et	f	\N
133905	istuvad	istuvad =istuva  (PlN  >istuv !02_A	et	f	\N
133906	istuvad	"istuv %istu  )V_vA  <istuma ;28_V	et	f	\N
133908	õmblevad	õmblevad =õmble  (IndPrPl3  >õmblema !30_V	et	f	\N
133909	õmblevad	õmblevad =õmbleva  (PlN  >õmblev !02_A	et	f	\N
133910	õmblevad	"õmblev %õmble  )V_vA  <õmblema ;30_V	et	f	\N
133911	lauluvad	?lauluvad =laulu  (IndPrPl3  >lauluma !28_V	et	f	\N
133912	lauluvad	?lauluvad =lauluva  (PlN  >lauluva !01_S	et	f	\N
133913	lauluvad	?lauluvad =lauluva  (PlN  >lauluv !02_A	et	f	\N
133914	lauluvad	?lauluvad =luva  (PlN  >lau+luva !17_S	et	f	\N
133936	festivallil	?festivallil =festivalli  (SgAd  >festivall !22_S	et	f	\N
133937	festivallil	?festivallil =festivallil  (SgN  >festivallil !02_S	et	f	\N
133943	tasakeselt	?tasakeselt =tasakese  (SgAbl  >tasake !12_S	et	f	\N
133944	tasakeselt	?tasakeselt =tasakese  (SgAbl  >tasakene !12_S	et	f	\N
133953	omas	omas =oma  (SgIn  >oma !17_A	et	f	\N
133954	omas	omas =oma  (IndIpfSg3  >omama !27_V	et	f	\N
133956	omas	omas =omas  (SgN  >omas !09_S	et	f	\N
133974	ümbertseb	?ümbertseb =ümbertse  (IndPrSg3  >ümbertsema !27_V	et	f	\N
134000	lauda	lauda =lauda  (SgG  >laut !22_S	et	f	\N
134001	lauda	lauda =lauda  (SgP  >laud !22_S	et	f	\N
134002	lauda	lauda =lauda  (SgAdt  >laud !22_S	et	f	\N
134025	laulused	?laulused =lauluse  (PlN  >laulus !11~09_S	et	f	\N
134026	laulused	?laulused =luse  (PlN  >lau+luse !16_S	et	f	\N
134027	laldakse	?laldakse =laldakse  (SgG  >laldakne !02_A	et	f	\N
134037	laulusel	?laulusel =lauluse  (SgAd  >laulus !11~09_S	et	f	\N
134038	laulusel	?laulusel =laulusel  (SgN  >laulusel !19_S	et	f	\N
134039	laulusel	?laulusel =luse  (SgAd  >lau+luse !16_S	et	f	\N
134040	laulusel	?laulusel =lusel  (SgN  >lau+lusel !02_S	et	f	\N
134050	mäletavad	mäletavad =mäleta  (IndPrPl3  >mäletama !27_V	et	f	\N
134051	mäletavad	mäletavad =mäletava  (PlN  >mäletav !02_A	et	f	\N
134052	mäletavad	"mäletav %mäleta  )V_vA  <mäletama ;27_V	et	f	\N
134053	tapsustada	?tapsustada =tapsusta  (Inf  >tapsustama !27_V	et	f	\N
134056	sootsialne	?sootsialne =sootsialne  (SgN  >sootsialne !02_A	et	f	\N
134057	sootsialne	?sootsialne =sootsialne  (PlP  >sootsialn !22_S	et	f	\N
133858	tantsimisega	"tantsimine %tantsi  )MINE_vS  <tantsima ;28_V	et	f	\N
133895	estlasi	?estlasi =estlasi  (ID  >estlasi !41_D	et	f	\N
133896	estlasi	?estlasi =estlasi  (PlP  >estlane !12_S	et	f	\N
133907	naitesk	?naitesk =naitesk  (SgN  >naitesk !02_S	et	f	\N
133915	tuleksisid	?tuleksisid =tuleksi  (IndIpfSg2  >tuleksima !28_V	et	f	\N
133916	tuleksisid	?tuleksisid =tuleksi  (IndIpfPl3  >tuleksima !28_V	et	f	\N
133917	tuleksisid	?tuleksisid =ksisi  (PlN  >tule+ksisi !17_S	et	f	\N
133945	lapsevoodi	lapsevoodi =voodi  (SgN  >lapse+voodi !01_S	et	f	\N
133946	lapsevoodi	lapsevoodi =voodi  (SgG  >lapse+voodi !01_S	et	f	\N
133968	jaok	?jaok =jaok  (SgN  >jaok !22_S	et	f	\N
133975	laulal	?laulal =laula  (SgAd  >laula !16_S	et	f	\N
133976	laulal	?laulal =laulal  (SgN  >laulal !02_S	et	f	\N
133988	kulsaim	?kulsaim =kulsaim  (SgN  >kulsaim !02_A	et	f	\N
133991	tähelepanuväärsem	tähelepanuväärsem =väärsem  (SgN  >tähele+panu+väärsem !02_A	et	f	\N
133992	tähelepanuväärsem	"tähele+panu+väärsem %väärse  )M_cA  <tähele+panu+väärne ;02_A	et	f	\N
133993	rahvusluse	rahvusluse =rahvusluse  (SgG  >rahvuslus !11_S	et	f	\N
133994	rahvusluse	"rahvuslus %rahvuslase  )US_aS  <rahvuslane ;12_S	et	f	\N
134008	tundil	?tundil =tundi  (SgAd  >tundi !16_S	et	f	\N
134009	tundil	?tundil =tundi  (SgAd  >tunt !22_S	et	f	\N
134012	regi	regi =regi  (SgN  >regi !21_S	et	f	\N
134013	regi	regi =re  (SgN^  >re !26_S	et	f	\N
134014	regi	regi =re  (SgG^  >re !26_S	et	f	\N
134019	üheksandil	?üheksandil =üheksandi  (SgAd  >üheksant !22_S	et	f	\N
134020	üheksandil	?üheksandil =üheksandil  (SgN  >üheksandil !02_S	et	f	\N
134021	üheksandil	?üheksandil =andi  (SgAd  >üheks+andi !16_S	et	f	\N
134022	üheksandil	?üheksandil =andi  (SgAd  >üheks+ant !22_S	et	f	\N
134023	üheksandil	?üheksandil =ksandi  (SgAd  >ühe+ksandi !16_S	et	f	\N
134024	üheksandil	?üheksandil =ksandi  (SgAd  >ühe+ksant !22_S	et	f	\N
134036	rap	### rap	et	f	\N
134054	vaned	?vaned =vane  (PlN  >vane !16_S	et	f	\N
134055	vaned	?vaned =vane  (IndPrSg2  >vanema !27_V	et	f	\N
134102	kestavad	kestavad =kesta  (IndPrPl3  >kestama !29_V	et	f	\N
134103	kestavad	kestavad =kesta  (IndPrPl3  >kestma !34_V	et	f	\N
134104	kestavad	kestavad =kestava  (PlN  >kestav !02_A	et	f	\N
134105	kestavad	"kestav %kesta  )V_vA  <kestama ;29_V	et	f	\N
134119	laulmiseta	laulmiseta =laulmise  (SgAb  >laulmine !12?10_S	et	f	\N
134120	laulmiseta	"laulmine %laul  )MINE_vS  <laulma ;33_V	et	f	\N
134123	rütmikas	rütmikas =rütmika  (SgIn  >rütmika !01_S	et	f	\N
134124	rütmikas	rütmikas =rütmika  (SgIn  >rütmikas !02_A	et	f	\N
134125	rütmikas	rütmikas =rütmikas  (SgN  >rütmikas !02_A	et	f	\N
134147	õnnelikus	õnnelikus =õnneliku  (SgIn  >õnnelik !25_A	et	f	\N
134148	õnnelikus	õnnelikus =õnnelikus  (SgN  >õnnelikus !11?09_S	et	f	\N
134150	õnnelikus	"õnnelikus %õnneliku  )US_aS  <õnnelik ;25_A	et	f	\N
134186	tantsimine	tantsimine =tantsimine  (SgN  >tantsimine !12_S	et	f	\N
134187	tantsimine	"tantsimine %tantsi  )MINE_vS  <tantsima ;28_V	et	f	\N
134188	jälgpalli	?jälgpalli =jälgpalli  (SgN  >jälgpalli !01_S	et	f	\N
134190	jälgpalli	?jälgpalli =jälgpalli  (SgG  >jälgpalli !01_S	et	f	\N
134192	jälgpalli	?jälgpalli =jälgpalli  (SgG  >jälgpall !22_S	et	f	\N
134193	jälgpalli	?jälgpalli =jälgpalli  (SgP  >jälgpall !22_S	et	f	\N
134194	jälgpalli	?jälgpalli =jälgpalli  (SgAdt  >jälgpall !22_S	et	f	\N
134195	jälgpalli	?jälgpalli =jälgpalli  (IndPrPs_  >jälgpallima !28_V	et	f	\N
134196	jälgpalli	?jälgpalli =jälgpalli  (ImpPrSg2  >jälgpallima !28_V	et	f	\N
134225	tavalist	tavalist =tavalis  (SgP  >tavaline !12_A	et	f	\N
134226	tavalist	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
134236	uskuga	?uskuga =usku  (SgKom  >usku !16_S	et	f	\N
134242	vormeeris	?vormeeris =vormeeri  (SgIn  >vormeeri !16_S	et	f	\N
134243	vormeeris	?vormeeris =vormeeri  (SgIn  >vormeer !22_S	et	f	\N
134244	vormeeris	?vormeeris =vormeeri  (IndIpfSg3  >vormeerima !28_V	et	f	\N
134245	vormeeris	?vormeeris =vormeeris  (SgN  >vormeeris !09_S	et	f	\N
134246	vormeeris	?vormeeris =eeri  (SgIn  >vorm+eeri !16_S	et	f	\N
134247	vormeeris	?vormeeris =eeri  (SgIn  >vorm+eer !22_S	et	f	\N
134248	vormeeris	?vormeeris =eeris  (SgN  >vorm+eeris !09_S	et	f	\N
134285	käimas	käimas =käi  (SupIn  >käima !38_V	et	f	\N
134286	käimas	käimas =käima  (SgIn  >käim !22_S	et	f	\N
134289	salme	salme =salme  (SgG  >salm !22_S	et	f	\N
134291	salme	salme =salme  (SgP  >salm !22_S	et	f	\N
134292	salme	salme =salme  (SgAdt  >salm !22_S	et	f	\N
134293	salme	salme =salme  (PlP  >salm !22_S	et	f	\N
134299	suurendamist	suurendamist =suurendamis  (SgP  >suurendamine !12_S	et	f	\N
134300	suurendamist	"suurendamine %suurenda  )MINE_vS  <suurendama ;27_V	et	f	\N
134311	tähelepanuväärtsem	?tähelepanuväärtsem =tähelepanuväärtsem  (SgN  >tähelepanuväärtsem !02_A	et	f	\N
134312	tähelepanuväärtsem	?tähelepanuväärtsem =väärtsem  (SgN  >tähele+panu+väärtsem !02_A	et	f	\N
134313	tähelepanuväärtsem	?tähelepanuväärtsem =nuväärtsem  (SgN  >tähe+lepa+nuväärtsem !02_A	et	f	\N
134314	tähelepanuväärtsem	?tähelepanuväärtsem =panuväärtsem  (SgN  >tähele+panuväärtsem !02_A	et	f	\N
134058	sootsialne	?sootsialne =tsialne  (SgN  >soo+tsialne !02_A	et	f	\N
134059	sootsialne	?sootsialne =tsialne  (PlP  >soo+tsialn !22_S	et	f	\N
134081	kõigis	kõigis =kõigi  (PlIn  >kõik !00_P	et	f	\N
134082	kõigis	kõigis =kõigi  (SgIn  >kõik !22_S	et	f	\N
134083	laulukoore	laulukoore =koore  (SgG  >laulu+koor !13_S	et	f	\N
134084	laulukoore	laulukoore =koore  (PlP  >laulu+koor !22_S	et	f	\N
134085	asutanud	asutanud =asuta  (PtsPtPs  >asutama !27_V	et	f	\N
134086	asutanud	asutanud =asutanu  (PlN  >asutanu !01_S	et	f	\N
134087	asutanud	"asutanu %asuta  )NU_vS  <asutama ;27_V	et	f	\N
134088	asutanud	asutanud =asutanud  (ID  >asutanud !41_A	et	f	\N
134089	asutanud	"asutanud %asuta  )NUD_vA  <asutama ;27_V	et	f	\N
134090	asutanud	asutanud =tanu  (PlN  >asu+tanu !17_S	et	f	\N
134144	tigedalt	tigedalt =tigeda  (SgAbl  >tige !02_A	et	f	\N
134145	tigedalt	tigedalt =tigedalt  (ID  >tigedalt !41_D	et	f	\N
134146	tigedalt	"tigedalt %tigeda  )LT_mD  <tige ;02_A	et	f	\N
134162	kannelit	### kannelit	et	f	\N
134206	väljendusvaheg	### väljendusvaheg	et	f	\N
134207	vanavanaema	vanavanaema =ema  (SgN  >vana+vana+ema !17_S	et	f	\N
134208	vanavanaema	vanavanaema =ema  (SgG  >vana+vana+ema !17_S	et	f	\N
134209	vanavanaema	vanavanaema =ema  (SgP  >vana+vana+ema !17_S	et	f	\N
134210	laulmiseks	laulmiseks =laulmise  (SgTr  >laulmine !12?10_S	et	f	\N
134211	laulmiseks	"laulmine %laul  )MINE_vS  <laulma ;33_V	et	f	\N
134230	venekeeles	venekeeles =keele  (SgIn  >vene+keel !13_S	et	f	\N
134232	venekeeles	venekeeles =keele  (PlIn  >vene+keeld !22_S	et	f	\N
134237	muusikainstrumentid	### muusikainstrumentid	et	f	\N
134287	kirikutes	kirikutes =kiriku  (PlIn  >kirik !02_S	et	f	\N
134288	kirikutes	kirikutes =ute  (SgIn  >kirik+utt !22_S	et	f	\N
134290	kirikutes	kirikutes =ute  (PlIn  >kirik+utt !22_S	et	f	\N
134297	põhiosat	?põhiosat =põhiosa  (SgP  >põhiosa !16_S	et	f	\N
134298	põhiosat	?põhiosat =osat  (SgN  >põhi+osat !02_S	et	f	\N
134303	peost	peost =peo  (SgEl  >pidu !18_S	et	f	\N
134304	peost	peost =peo  (SgEl  >peo !26_S	et	f	\N
134346	traditsioonlaulmine	?traditsioonlaulmine =traditsioonlaulmine  (SgN  >traditsioonlaulmine !12_A	et	f	\N
134355	kaasaegsases	?kaasaegsases =kaasaegsase  (SgIn  >kaasaegsane !12~10_A	et	f	\N
134356	kaasaegsases	?kaasaegsases =sase  (SgIn  >kaas+aeg+sase !16_S	et	f	\N
134357	kaasaegsases	?kaasaegsases =sases  (SgN  >kaas+aeg+sases !09_S	et	f	\N
134358	kaasaegsases	?kaasaegsases =egsase  (SgIn  >kaasa+egsane !10_A	et	f	\N
134359	kaasaegsases	?kaasaegsases =aegsase  (SgIn  >kaas+aegsane !12~10_A	et	f	\N
134360	värskas	?värskas =värska  (SgIn  >värska !01_S	et	f	\N
134361	värskas	?värskas =värska  (IndIpfSg3  >värskama !29_V	et	f	\N
134362	värskas	?värskas =värskas  (SgN  >värskas !07_S	et	f	\N
134386	repertuar	?repertuar =repertuar  (SgN  >repertuar !19_S	et	f	\N
134397	tavast	tavast =tava  (SgEl  >tava !17_S	et	f	\N
134398	tavast	tavast =tavas  (SgP  >tavane !10_A	et	f	\N
134399	tavast	"tavane %tava  )NE_aA  <tava ;17_S	et	f	\N
134400	lauldud	lauldud =laul  (PtsPtIps  >laulma !33_V	et	f	\N
134401	lauldud	lauldud =lauldu  (PlN  >lauldu !01_S	et	f	\N
134402	lauldud	"lauldu %laul  )TU1_vS  <laulma ;33_V	et	f	\N
134403	lauldud	lauldud =lauldud  (ID  >lauldud !41_A	et	f	\N
134404	lauldud	"lauldud %laul  )TUD_vA  <laulma ;33_V	et	f	\N
134407	tähtsem	?tähtsem =tähtsem  (SgN  >tähtsem !02_A	et	f	\N
134437	kulturis	?kulturis =kulturi  (SgIn  >kulturi !01_S	et	f	\N
134438	kulturis	?kulturis =kulturi  (SgIn  >kultur !02_S	et	f	\N
134439	kulturis	?kulturis =kulturis  (SgN  >kulturis !11_S	et	f	\N
134446	vokalselt	?vokalselt =vokalse  (SgAbl  >vokalne !02_A	et	f	\N
134447	vokalselt	?vokalselt =vokalse  (PlAbl  >vokalss !22_S	et	f	\N
134448	vokalselt	?vokalselt =vokalselt  (ID  >vokalselt !41_D	et	f	\N
134458	milled	?milled =mille  (IndPrSg2  >millema !30_V	et	f	\N
134467	lauldese	?lauldese =lauldese  (SgG  >lauldene !12~10_A	et	f	\N
134468	rahvalaulaga	rahvalaulaga =la  (SgKom  >rahva+lau+la !26_S	et	f	\N
134469	rahvalaulaga	rahvalaulaga =laga  (SgN  >rahva+lau+laga !17_S	et	f	\N
134470	rahvalaulaga	rahvalaulaga =laga  (SgG  >rahva+lau+laga !17_S	et	f	\N
134471	rahvalaulaga	rahvalaulaga =laga  (SgP  >rahva+lau+laga !17_S	et	f	\N
134485	kallimad	kallimad =kallima  (PlN  >kallim !02_AS	et	f	\N
134486	kallimad	"kallim %kalli  )M_cA  <kallis ;05_A	et	f	\N
134487	kallimad	"kallim %kalli  )M_cA  <kallis ;07_A	et	f	\N
134532	veemine	?veemine =veemine  (SgN  >veemine !10_A	et	f	\N
134533	veemine	?veemine =veemine  (IndPrPs_  >veeminema !27_V	et	f	\N
134534	veemine	?veemine =veemine  (ImpPrSg2  >veeminema !27_V	et	f	\N
134541	hingaliselt	?hingaliselt =hingalise  (SgAbl  >hingaline !12_A	et	f	\N
134542	hingaliselt	?hingaliselt =hingaliselt  (ID  >hingaliselt !41_D	et	f	\N
134555	mälestusid	?mälestusid =mälestu  (IndIpfSg2  >mälestuma !27_V	et	f	\N
134556	mälestusid	?mälestusid =mälestu  (IndIpfPl3  >mälestuma !27_V	et	f	\N
134578	häälest	häälest =hääle  (SgEl  >hääl !13_S	et	f	\N
134579	häälest	häälest =hääles  (SgP  >häälene !10_A	et	f	\N
134580	häälest	"häälene %hääle  )NE_aA  <hääl ;13_S	et	f	\N
134586	fragmentid	?fragmentid =fragmenti  (PlN  >fragmenti !01_S	et	f	\N
134101	tudrukud	?tudrukud =tudruku  (IndPrSg2  >tudrukuma !27_V	et	f	\N
134121	meloodia	meloodia =meloodia  (SgN  >meloodia !01_S	et	f	\N
134122	meloodia	meloodia =meloodia  (SgG  >meloodia !01_S	et	f	\N
134126	liiguda	?liiguda =liigu  (Inf  >liiguma !27_V	et	f	\N
134127	liiguda	?liiguda =uda  (SgN  >liig+uda !17_S	et	f	\N
134128	liiguda	?liiguda =uda  (SgG  >liig+uda !17_S	et	f	\N
134129	liiguda	?liiguda =uda  (SgP  >liig+uda !17_S	et	f	\N
134130	rütmi	rütmi =rütmi  (SgG  >rütm !22_S	et	f	\N
134131	rütmi	rütmi =rütmi  (SgP  >rütm !22_S	et	f	\N
134132	rütmi	rütmi =rütmi  (SgAdt  >rütm !22_S	et	f	\N
134138	vanemuisega	?vanemuisega =uise  (SgKom  >vanem+uise !06_S	et	f	\N
134139	kujuda	?kujuda =kuju  (Inf  >kujuma !27_V	et	f	\N
134149	analüseerimine	?analüseerimine =analüseerimine  (SgN  >analüseerimine !12_S	et	f	\N
134151	analüseerimine	?analüseerimine =analüseerimine  (PlP  >analüseerimin !19_S	et	f	\N
134156	viltspilli	?viltspilli =viltspilli  (SgN  >viltspilli !01_S	et	f	\N
134157	viltspilli	?viltspilli =viltspilli  (SgG  >viltspilli !01_S	et	f	\N
134158	viltspilli	?viltspilli =viltspilli  (SgG  >viltspill !22_S	et	f	\N
134159	viltspilli	?viltspilli =viltspilli  (SgP  >viltspill !22_S	et	f	\N
134160	viltspilli	?viltspilli =viltspilli  (SgAdt  >viltspill !22_S	et	f	\N
134161	viltspilli	?viltspilli =viltspilli  (IndPrPs_  >viltspillima !28_V	et	f	\N
134163	viltspilli	?viltspilli =viltspilli  (ImpPrSg2  >viltspillima !28_V	et	f	\N
134164	viltspilli	?viltspilli =spilli  (SgN  >vilt+spilli !16_S	et	f	\N
134165	viltspilli	?viltspilli =spilli  (SgG  >vilt+spilli !16_S	et	f	\N
134166	viltspilli	?viltspilli =spilli  (SgG  >vilt+spill !22_S	et	f	\N
134167	viltspilli	?viltspilli =spilli  (SgP  >vilt+spill !22_S	et	f	\N
134168	viltspilli	?viltspilli =spilli  (SgAdt  >vilt+spill !22_S	et	f	\N
134171	ärkamisega	ärkamisega =ärkamise  (SgKom  >ärkamine !12_S	et	f	\N
134172	ärkamisega	"ärkamine %ärka  )MINE_vS  <ärkama ;29_V	et	f	\N
134178	võtasid	?võtasid =võta  (PlP  >võta !16_S	et	f	\N
134179	võtasid	?võtasid =võta  (IndIpfSg2  >võtama !27_V	et	f	\N
134180	võtasid	?võtasid =võta  (IndIpfPl3  >võtama !27_V	et	f	\N
134197	kultuuriidentiteedist	?kultuuriidentiteedist =kultuuriidentiteedi  (SgEl  >kultuuriidentiteedi !16_S	et	f	\N
134198	kultuuriidentiteedist	?kultuuriidentiteedist =kultuuriidentiteedi  (SgEl  >kultuuriidentiteet !22_S	et	f	\N
134199	kultuuriidentiteedist	?kultuuriidentiteedist =kultuuriidentiteedis  (SgP  >kultuuriidentiteedis !09_S	et	f	\N
134200	kultuuriidentiteedist	?kultuuriidentiteedist =identiteedi  (SgEl  >kultuuri+identiteedi !16_S	et	f	\N
134201	kultuuriidentiteedist	?kultuuriidentiteedist =identiteedi  (SgEl  >kultuuri+identiteet !22_S	et	f	\N
134202	kultuuriidentiteedist	?kultuuriidentiteedist =identiteedis  (SgP  >kultuuri+identiteedis !09_S	et	f	\N
134203	kultuuriidentiteedist	?kultuuriidentiteedist =iidentiteedi  (SgEl  >kultuur+iidentiteedi !16_S	et	f	\N
134204	kultuuriidentiteedist	?kultuuriidentiteedist =iidentiteedi  (SgEl  >kultuur+iidentiteet !22_S	et	f	\N
134205	kultuuriidentiteedist	?kultuuriidentiteedist =iidentiteedis  (SgP  >kultuur+iidentiteedis !09_S	et	f	\N
134221	säiletanud	?säiletanud =säileta  (PtsPtPs  >säiletama !27_V	et	f	\N
134222	säiletanud	?säiletanud =säiletanu  (PlN  >säiletanu !01_S	et	f	\N
134223	säiletanud	?säiletanud =säiletanu  (IndPrSg2  >säiletanuma !27_V	et	f	\N
134224	säiletanud	?säiletanud =säiletanud  (ID  >säiletanud !41_A	et	f	\N
134229	olmest	olmest =olme  (SgEl  >olme !06_S	et	f	\N
134231	olmest	olmest =olmes  (SgP  >olmene !10_A	et	f	\N
134233	olmest	"olmene %olme  )NE_aA  <olme ;06_S	et	f	\N
134278	laulmist	laulmist =laulmis  (SgP  >laulmine !12?10_S	et	f	\N
134280	laulmist	"laulmine %laul  )MINE_vS  <laulma ;33_V	et	f	\N
134294	laiemale	laiemale =laiema  (SgAll  >laiem !02_A	et	f	\N
134295	laiemale	"laiem %laie  )M_cA  <lai ;22_A	et	f	\N
134296	laiemale	laiemale =ema  (SgAll  >lai+ema !17_S	et	f	\N
134324	mängimise	mängimise =mängimise  (SgG  >mängimine !12_S	et	f	\N
134325	mängimise	"mängimine %mängi  )MINE_vS  <mängima ;28_V	et	f	\N
134326	rahvuslikku	rahvuslikku =rahvuslikku  (SgP  >rahvuslik !25_A	et	f	\N
134327	rahvuslikku	rahvuslikku =rahvuslikku  (SgAdt  >rahvuslik !25_A	et	f	\N
134340	moderniseeritakse	moderniseeritakse =moderniseeri  (IndPrIps  >moderniseerima !28_V	et	f	\N
134341	moderniseeritakse	moderniseeritakse =takse  (PlP  >modern+ise+eri+taks !22_S	et	f	\N
134368	regivärsilised	regivärsilised =värsilise  (PlN  >regi+värsiline !12_A	et	f	\N
134369	regivärsilised	"regi+värsiline %värsi  )LINE_aA  <regi+värss ;22_S	et	f	\N
134372	kiirikuses	?kiirikuses =kiirikuse  (SgIn  >kiirikus !11_S	et	f	\N
134373	kiirikuses	?kiirikuses =ikuse  (SgIn  >kiir+ikus !09_S	et	f	\N
134376	võitsid	võitsid =võit  (IndIpfSg2  >võitma !34_V	et	f	\N
134377	võitsid	võitsid =võit  (IndIpfPl3  >võitma !34_V	et	f	\N
134378	tähelepanuvad	?tähelepanuvad =tähelepanu  (IndPrPl3  >tähelepanuma !27_V	et	f	\N
134379	tähelepanuvad	?tähelepanuvad =tähelepanuva  (PlN  >tähelepanuv !02_A	et	f	\N
134380	tähelepanuvad	?tähelepanuvad =tähelepanuva  (PlN  >tähelepanuva !16_S	et	f	\N
134381	tähelepanuvad	?tähelepanuvad =nuva  (PlN  >tähe+lepa+nuva !17_S	et	f	\N
134382	tähelepanuvad	?tähelepanuvad =panuva  (PlN  >tähele+panuva !01_S	et	f	\N
134383	tähelepanuvad	?tähelepanuvad =panuva  (PlN  >tähele+panuv !02_A	et	f	\N
134117	kuulatajate	kuulatajate =kuulataja  (PlG  >kuulataja !01_S	et	f	\N
134118	kuulatajate	"kuulataja %kuulata  )JA_vS  <kuulatama ;27_V	et	f	\N
134133	maaelu	maaelu =elu  (SgN  >maa+elu !17_S	et	f	\N
134134	maaelu	maaelu =elu  (SgG  >maa+elu !17_S	et	f	\N
134135	maaelu	maaelu =elu  (SgP  >maa+elu !17_S	et	f	\N
134140	korraldadi	### korraldadi	et	f	\N
134189	mängimine	mängimine =mängimine  (SgN  >mängimine !12_S	et	f	\N
134191	mängimine	"mängimine %mängi  )MINE_vS  <mängima ;28_V	et	f	\N
134212	ajadest	?ajadest =aja  (PlEl  >aja !17_S	et	f	\N
134213	ajadest	?ajadest =ajades  (SgP  >ajadene !12_A	et	f	\N
134214	tantsimise	tantsimise =tantsimise  (SgG  >tantsimine !12_S	et	f	\N
134215	tantsimise	"tantsimine %tantsi  )MINE_vS  <tantsima ;28_V	et	f	\N
134216	ajaloolised	ajaloolised =loolise  (PlN  >aja+looline !12?10_A	et	f	\N
134217	ajaloolised	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
134218	ajaloolised	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
134219	ajaloolised	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
134220	ajaloolised	ajaloolised =loolise  (PlN  >aja+looline !12?10_S	et	f	\N
134234	ristimine	ristimine =ristimine  (SgN  >ristimine !12_S	et	f	\N
134235	ristimine	"ristimine %risti  )MINE_vS  <ristima ;28_V	et	f	\N
134259	laulurahvast	laulurahvast =rahva  (SgEl  >laulu+rahvas !07_S	et	f	\N
134260	laulurahvast	laulurahvast =rahvas  (SgP  >laulu+rahvas !07_S	et	f	\N
134261	laulurahvast	laulurahvast =rahvas  (SgP  >laulu+rahvane !10_A	et	f	\N
134262	laulurahvast	"laulu+rahvane %rahva  )NE_aA  <laulu+rahvas ;07_S	et	f	\N
134277	jätasid	?jätasid =jäta  (PlP  >jäta !16_S	et	f	\N
134279	jätasid	?jätasid =jäta  (IndIpfSg2  >jätama !27_V	et	f	\N
134281	jätasid	?jätasid =jäta  (IndIpfPl3  >jätama !27_V	et	f	\N
134282	kultuuriosa	kultuuriosa =osa  (SgN  >kultuuri+osa !17_S	et	f	\N
134283	kultuuriosa	kultuuriosa =osa  (SgG  >kultuuri+osa !17_S	et	f	\N
134284	kultuuriosa	kultuuriosa =osa  (SgP  >kultuuri+osa !17_S	et	f	\N
134301	rahvasele	rahvasele =rahvase  (SgAll  >rahvane !10_A	et	f	\N
134302	rahvasele	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
134307	üleeestiline	?üleeestiline =üleeestiline  (SgN  >üleeestiline !12_A	et	f	\N
134308	üleeestiline	?üleeestiline =üleeestiline  (PlP  >üleeestilin !19_S	et	f	\N
134309	üleeestiline	?üleeestiline =iline  (SgN  >üle+eest+iline !10_A	et	f	\N
134310	üleeestiline	?üleeestiline =tiline  (SgN  >üle+ees+tiline !10_A	et	f	\N
134316	lähedamatest	lähedamatest =lähedama  (PlEl  >lähedam !02_A	et	f	\N
134317	lähedamatest	"lähedam %läheda  )M_cA  <läheda ;02_A	et	f	\N
134321	bajaani	bajaani =bajaani  (SgG  >bajaan !22_S	et	f	\N
134322	bajaani	bajaani =bajaani  (SgP  >bajaan !22_S	et	f	\N
134323	bajaani	bajaani =bajaani  (SgAdt  >bajaan !22_S	et	f	\N
134328	halvaid	?halvaid =halvai  (PlN  >halvai !26_S	et	f	\N
134329	halvaid	?halvaid =halvai  (SgP  >halvai !26_S	et	f	\N
134330	halvaid	?halvaid =halvaid  (SgN  >halvaid !22_S	et	f	\N
134347	ühendamine	ühendamine =ühendamine  (SgN  >ühendamine !12_S	et	f	\N
134348	ühendamine	"ühendamine %ühenda  )MINE_vS  <ühendama ;27_V	et	f	\N
134363	esindavad	esindavad =esinda  (IndPrPl3  >esindama !27_V	et	f	\N
134365	esindavad	esindavad =esindava  (PlN  >esindav !02_A	et	f	\N
134367	esindavad	"esindav %esinda  )V_vA  <esindama ;27_V	et	f	\N
134374	näidab	?näidab =näida  (IndPrSg3  >näidama !29_V	et	f	\N
134389	sümbool	?sümbool =sümboo  (SgAd  >sümboo !26_S	et	f	\N
134390	sümbool	?sümbool =sümbool  (SgN  >sümbool !22_S	et	f	\N
134392	olenevalt	olenevalt =oleneva  (SgAbl  >olenev !02_A	et	f	\N
134393	olenevalt	"olenev %olene  )V_vA  <olenema ;27_V	et	f	\N
134394	olenevalt	olenevalt =olenevalt  (ID  >olenevalt !41_D	et	f	\N
134395	olenevalt	"olenevalt %olene  )VALT_mD  <olenema ;27_V	et	f	\N
134396	olenevalt	"olenevalt %oleneva  )LT_mD  <olenev ;02_A	et	f	\N
134418	tunna	?tunna =tunna  (SgN  >tunna !16_S	et	f	\N
134419	tunna	?tunna =tunna  (SgG  >tunna !16_S	et	f	\N
134420	tunna	?tunna =tunna  (IndPrPs_  >tunnama !29_V	et	f	\N
134421	tunna	?tunna =tunna  (ImpPrSg2  >tunnama !29_V	et	f	\N
134422	rahvalaulupeol	rahvalaulupeol =peo  (SgAd  >rahva+laulu+pidu !18_S	et	f	\N
134423	rahvalaulupeol	rahvalaulupeol =peo  (SgAd  >rahva+laulu+peo !26_S	et	f	\N
134424	poistekoor	poistekoor =koor  (SgN  >poiste+koor !13_S	et	f	\N
134425	poistekoor	poistekoor =koor  (SgN  >poiste+koor !22_S	et	f	\N
134435	neie	?neie =neie  (SgN  >neie !06_S	et	f	\N
134436	neie	?neie =neie  (SgG  >neie !06_S	et	f	\N
134440	suheldasida	### suheldasida	et	f	\N
134455	kolektiivid	?kolektiivid =kolektiivi  (PlN  >kolektiivi !16_S	et	f	\N
134456	kolektiivid	?kolektiivid =kolektiivi  (PlN  >kolektiiv !22_S	et	f	\N
134457	kolektiivid	?kolektiivid =kolektiivi  (IndPrSg2  >kolektiivima !28_V	et	f	\N
134460	arhividest	?arhividest =arhivides  (SgP  >arhividene !12_A	et	f	\N
134474	laulde	?laulde =laulde  (SgN  >laulde !06_S	et	f	\N
134475	laulde	?laulde =laulde  (PlP  >lauld !22_S	et	f	\N
134476	laulde	?laulde =laulde  (IndPrPs_  >lauldema !27_V	et	f	\N
134477	laulde	?laulde =laulde  (ImpPrSg2  >lauldema !27_V	et	f	\N
134494	tsaari-	tsaari- =tsaari  (SgG  >tsaar !22_S	et	f	\N
134136	unelaul	unelaul =lau  (SgAd  >une+laug !22_SA	et	f	\N
134137	unelaul	unelaul =laul  (SgN  >une+laul !22_S	et	f	\N
134141	tunnasid	?tunnasid =tunna  (PlP  >tunna !16_S	et	f	\N
134142	tunnasid	?tunnasid =tunna  (IndIpfSg2  >tunnama !29_V	et	f	\N
134143	tunnasid	?tunnasid =tunna  (IndIpfPl3  >tunnama !29_V	et	f	\N
134152	eestastest	eestastest =aste  (SgEl  >eest+aste !06_S	et	f	\N
134153	eestastest	eestastest =aste  (PlEl  >eest+ast !22_S	et	f	\N
134154	eestastest	eestastest =astes  (SgP  >eest+astene !12~10_A	et	f	\N
134155	eestastest	"eest+astene %aste  )NE_aA  <eest+aste ;06_S	et	f	\N
134169	filmides	filmides =filmi  (PlIn  >film !22_S	et	f	\N
134170	filmides	filmides =filmi  (Ger  >filmima !28_V	et	f	\N
134173	stabiliseeritud	stabiliseeritud =stabiliseeri  (PtsPtIps  >stabiliseerima !28_V	et	f	\N
134174	stabiliseeritud	stabiliseeritud =stabiliseeritu  (PlN  >stabiliseeritu !01_S	et	f	\N
134175	stabiliseeritud	"stabiliseeritu %stabiliseeri  )TU1_vS  <stabiliseerima ;28_V	et	f	\N
134176	stabiliseeritud	stabiliseeritud =stabiliseeritud  (ID  >stabiliseeritud !41_A	et	f	\N
134177	stabiliseeritud	"stabiliseeritud %stabiliseeri  )TUD_vA  <stabiliseerima ;28_V	et	f	\N
134181	kooreid	?kooreid =koore  (PlP  >koore !06_S	et	f	\N
134182	kooreid	?kooreid =koorei  (PlN  >koorei !26_S	et	f	\N
134183	kooreid	?kooreid =koorei  (SgP  >koorei !26_S	et	f	\N
134184	kooreid	?kooreid =kooreid  (SgN  >kooreid !22_S	et	f	\N
134185	kooreid	?kooreid =eid  (SgN  >koor+eid !22_S	et	f	\N
134227	tegemises	tegemises =tegemise  (SgIn  >tegemine !12_S	et	f	\N
134228	tegemises	"tegemine %tege  )MINE_vS  <tegema ;28_V	et	f	\N
134238	variatiivne	?variatiivne =variatiivne  (SgN  >variatiivne !02_A	et	f	\N
134239	variatiivne	?variatiivne =variatiivne  (PlP  >variatiivn !22_S	et	f	\N
134240	variatiivne	?variatiivne =atiivne  (SgN  >vari+atiivne !02_A	et	f	\N
134241	variatiivne	?variatiivne =atiivne  (PlP  >vari+atiivn !22_S	et	f	\N
134249	tänapäeviti	?tänapäeviti =tänapäevi  (IndIpfIps  >tänapäevima !28_V	et	f	\N
134250	tänapäeviti	?tänapäeviti =tänapäeviti  (ID  >tänapäeviti !41_D	et	f	\N
134251	tänapäeviti	?tänapäeviti =tänapäeviti  (SgG  >tänapäevitt !22_S	et	f	\N
134252	tänapäeviti	?tänapäeviti =tänapäeviti  (IndPrPs_  >tänapäevittima !28_V	et	f	\N
134253	tänapäeviti	?tänapäeviti =tänapäeviti  (ImpPrSg2  >tänapäevittima !28_V	et	f	\N
134254	tänapäeviti	?tänapäeviti =iti  (SgN  >täna+päev+iti !16_S	et	f	\N
134255	tänapäeviti	?tänapäeviti =iti  (SgG  >täna+päev+iti !16_S	et	f	\N
134256	tänapäeviti	?tänapäeviti =iti  (SgG  >täna+päev+itt !22_S	et	f	\N
134257	tänapäeviti	?tänapäeviti =päeviti  (SgG  >täna+päevit !02_S	et	f	\N
134258	tänapäeviti	?tänapäeviti =päeviti  (SgG  >täna+päevitt !22_S	et	f	\N
134263	eritähtsus	eritähtsus =tähtsus  (SgN  >eri+tähtsus !11~09_S	et	f	\N
134264	eritähtsus	"eri+tähtsus %tähtsa  )US_aS  <eri+tähtis ;02_A	et	f	\N
134265	vääri	vääri =vääri  (ID  >vääri !41_D	et	f	\N
134266	vääri	vääri =vääri  (SgG  >väär !02_A	et	f	\N
134267	vääri	vääri =vääri  (SgG  >väär !22_S	et	f	\N
134268	vääri	vääri =vääri  (SgG  >väär !22_A	et	f	\N
134269	vääri	vääri =vääri  (SgP  >väär !22_S	et	f	\N
134270	vääri	vääri =vääri  (SgP  >väär !22_A	et	f	\N
134271	vääri	vääri =vääri  (SgAdt  >väär !22_S	et	f	\N
134272	vääri	vääri =vääri  (SgAdt  >väär !22_A	et	f	\N
134273	vääri	vääri =vääri  (PlP  >väär !22_S	et	f	\N
134274	vääri	vääri =vääri  (PlP  >väär !22_A	et	f	\N
134275	vääri	vääri =vääri  (IndPrPs_  >väärima !28_V	et	f	\N
134276	vääri	vääri =vääri  (ImpPrSg2  >väärima !28_V	et	f	\N
134305	toppelt	?toppelt =toppe  (SgAbl  >tope !06_S	et	f	\N
134306	toppelt	?toppelt =toppelt  (ID  >toppelt !41_D	et	f	\N
134318	rahvastest	rahvastest =rahvas  (PlEl  >rahvas !07_S	et	f	\N
134319	rahvastest	rahvastest =rahvas  (PlEl  >rahvane !10_A	et	f	\N
134320	rahvastest	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
134342	protestiline	protestiline =protestiline  (SgN  >protestiline !12_A	et	f	\N
134343	protestiline	"protestiline %protesti  )LINE_aA  <protest ;22_S	et	f	\N
134349	ühendamine	ühendamine =ühendamine  (SgN  >ühendamine !12_S	et	f	\N
134350	ühendamine	"ühendamine %ühenda  )MINE_vS  <ühendama ;27_V	et	f	\N
134351	lauluajalood	lauluajalood =loo  (PlN  >laulu+aja+lugu !18_S	et	f	\N
134352	lauluajalood	lauluajalood =loo  (PlN  >laulu+aja+loog !22_S	et	f	\N
134353	lauluajalood	lauluajalood =loo  (PlN  >laulu+aja+lood !22_S	et	f	\N
134354	lauluajalood	lauluajalood =lood  (SgN  >laulu+aja+lood !22_S	et	f	\N
134364	kuulturile	?kuulturile =kuulturi  (SgAll  >kuulturi !01_S	et	f	\N
134366	kuulturile	?kuulturile =kuulturi  (SgAll  >kuultur !02_S	et	f	\N
134370	salmid	salmid =salmi  (PlN  >salm !22_S	et	f	\N
134371	salmid	salmid =salmi  (IndPrSg2  >salmima !28_V	et	f	\N
134375	kuultur	?kuultur =kuultur  (SgN  >kuultur !02_S	et	f	\N
134410	korraldamisele	korraldamisele =korraldamise  (SgAll  >korraldamine !12_S	et	f	\N
134411	korraldamisele	"korraldamine %korralda  )MINE_vS  <korraldama ;27_V	et	f	\N
134412	ühendavad	ühendavad =ühenda  (IndPrPl3  >ühendama !27_V	et	f	\N
134413	ühendavad	ühendavad =ühendava  (PlN  >ühendav !02_A	et	f	\N
134414	ühendavad	"ühendav %ühenda  )V_vA  <ühendama ;27_V	et	f	\N
134315	tähelepanuväärtsem	?tähelepanuväärtsem =lepanuväärtsem  (SgN  >tähe+lepanuväärtsem !02_A	et	f	\N
134331	tõsta	tõsta =tõst  (Inf  >tõstma !34_V	et	f	\N
134332	tõsta	tõsta =tõsta  (IndPrPs_  >tõstma !34_V	et	f	\N
134333	tõsta	tõsta =tõsta  (ImpPrSg2  >tõstma !34_V	et	f	\N
134334	stiilid	stiilid =stiili  (PlN  >stiil !22_S	et	f	\N
134335	stiilid	stiilid =stiili  (IndPrSg2  >stiilima !28_V	et	f	\N
134336	liigutused	liigutused =liigutuse  (PlN  >liigutus !11_S	et	f	\N
134337	liigutused	"liigutus %liiguta  )US_vS  <liigutama ;27_V	et	f	\N
134338	liigutused	"liigutus %liigu  )TUS1_aS  <liikuma ;28_V	et	f	\N
134339	liigutused	"liigutus %liigu  )TUS2_aS  <liik ;22_S	et	f	\N
134344	laulav	?laulav =laula  (PtsPrPs  >laulama !29_V	et	f	\N
134345	laulav	?laulav =laulav  (SgN  >laulav !02_A	et	f	\N
134391	üleelada	### üleelada	et	f	\N
134408	järgnevate	järgnevate =järgneva  (PlG  >järgnev !02_A	et	f	\N
134409	järgnevate	"järgnev %järgne  )V_vA  <järgnema ;27_V	et	f	\N
134426	peerega	?peerega =peere  (SgKom  >peere !06_S	et	f	\N
134427	rahvalaulpidu	?rahvalaulpidu =rahvalaulpidu  (IndPrPs_  >rahvalaulpiduma !27_V	et	f	\N
134428	rahvalaulpidu	?rahvalaulpidu =rahvalaulpidu  (ImpPrSg2  >rahvalaulpiduma !27_V	et	f	\N
134429	rahvalaulpidu	?rahvalaulpidu =laulpidu  (SgN  >rahva+laulpidu !01_S	et	f	\N
134430	rahvalaulpidu	?rahvalaulpidu =laulpidu  (SgG  >rahva+laulpidu !01_S	et	f	\N
134464	traditsionides	?traditsionides =traditsioni  (PlIn  >traditsioni !16_S	et	f	\N
134465	traditsionides	?traditsionides =traditsioni  (PlIn  >traditsion !19_S	et	f	\N
134466	traditsionides	?traditsionides =traditsioni  (Ger  >traditsionima !28_V	et	f	\N
134478	hoianevad	?hoianevad =hoiane  (IndPrPl3  >hoianema !27_V	et	f	\N
134479	hoianevad	?hoianevad =hoianeva  (PlN  >hoianev !02_A	et	f	\N
134480	hoianevad	?hoianevad =hoianeva  (PlN  >hoianeva !16_S	et	f	\N
134481	traditsionid	?traditsionid =traditsioni  (PlN  >traditsion !19~02_S	et	f	\N
134482	traditsionid	?traditsionid =traditsioni  (PlN  >traditsioni !16_S	et	f	\N
134483	traditsionid	?traditsionid =traditsioni  (IndPrSg2  >traditsionima !28_V	et	f	\N
134501	pulmaid	?pulmaid =pulmai  (PlN  >pulmai !26_S	et	f	\N
134502	pulmaid	?pulmaid =pulmai  (SgP  >pulmai !26_S	et	f	\N
134505	pulmaid	?pulmaid =pulmaid  (SgN  >pulmaid !22_S	et	f	\N
134506	pidutsevad	pidutsevad =pidutse  (IndPrPl3  >pidutsema !27_V	et	f	\N
134507	pidutsevad	pidutsevad =pidutseva  (PlN  >pidutsev !02_A	et	f	\N
134508	pidutsevad	"pidutsev %pidutse  )V_vA  <pidutsema ;27_V	et	f	\N
134520	põlull	?põlull =põlull  (SgN  >põlull !22_S	et	f	\N
134521	proovisid	proovisid =proovi  (PlP  >proov !22_S	et	f	\N
134522	proovisid	proovisid =proovi  (IndIpfSg2  >proovima !28_V	et	f	\N
134523	proovisid	proovisid =proovi  (IndIpfPl3  >proovima !28_V	et	f	\N
134536	igasuguks	?igasuguks =igasugu  (KndPrPs  >igasuguma !27_V	et	f	\N
134540	minevikut	### minevikut	et	f	\N
134543	tähelepanuväärnu	?tähelepanuväärnu =tähelepanuväärnu  (IndPrPs_  >tähelepanuväärnuma !27_V	et	f	\N
134544	tähelepanuväärnu	?tähelepanuväärnu =tähelepanuväärnu  (ImpPrSg2  >tähelepanuväärnuma !27_V	et	f	\N
134545	tähelepanuväärnu	?tähelepanuväärnu =väärnu  (SgN  >tähele+panu+väärnu !01_S	et	f	\N
134546	tähelepanuväärnu	?tähelepanuväärnu =väärnu  (SgG  >tähele+panu+väärnu !01_S	et	f	\N
134547	tähelepanuväärnu	?tähelepanuväärnu =nuväärnu  (SgN  >tähe+lepa+nuväärnu !01_S	et	f	\N
134548	tähelepanuväärnu	?tähelepanuväärnu =nuväärnu  (SgG  >tähe+lepa+nuväärnu !01_S	et	f	\N
134597	muusikafestivaalid	?muusikafestivaalid =muusikafestivaali  (PlN  >muusikafestivaali !16_S	et	f	\N
134598	muusikafestivaalid	?muusikafestivaalid =muusikafestivaali  (PlN  >muusikafestivaal !22_S	et	f	\N
134599	muusikafestivaalid	?muusikafestivaalid =muusikafestivaali  (IndPrSg2  >muusikafestivaalima !28_V	et	f	\N
134600	muusikafestivaalid	?muusikafestivaalid =festivaali  (PlN  >muusika+festivaali !16_S	et	f	\N
134601	muusikafestivaalid	?muusikafestivaalid =festivaali  (PlN  >muusika+festivaal !22_S	et	f	\N
134602	muusikafestivaalid	?muusikafestivaalid =sikafestivaali  (PlN  >muu+sikafestivaali !16_S	et	f	\N
134603	muusikafestivaalid	?muusikafestivaalid =sikafestivaali  (PlN  >muu+sikafestivaal !22_S	et	f	\N
134610	vanalt	vanalt =vana  (SgAbl  >vana !17_AS	et	f	\N
134611	vanalt	vanalt =vanalt  (ID  >vanalt !41_D	et	f	\N
134612	vanalt	"vanalt %vana  )LT_mD  <vana ;17_AS	et	f	\N
134613	tanapaeviti	?tanapaeviti =tanapaevi  (IndIpfIps  >tanapaevima !28_V	et	f	\N
134614	tanapaeviti	?tanapaeviti =tanapaeviti  (ID  >tanapaeviti !41_D	et	f	\N
134615	tanapaeviti	?tanapaeviti =tanapaeviti  (SgG  >tanapaevitt !22_S	et	f	\N
134616	tanapaeviti	?tanapaeviti =tanapaeviti  (IndPrPs_  >tanapaevittima !28_V	et	f	\N
134617	tanapaeviti	?tanapaeviti =tanapaeviti  (ImpPrSg2  >tanapaevittima !28_V	et	f	\N
134618	meldivad	meldivad =meldiva  (PlN  >meldiv !02_A	et	f	\N
134619	meldivad	"meldiv %meldi  )V_vA  <meldima ;28_V	et	f	\N
134633	laulvad	laulvad =laulva  (PlN  >laulev !02_A	et	f	\N
134634	laulvad	"laulev %laul  )V_vA  <laulma ;33_V	et	f	\N
134645	muusikalne	?muusikalne =muusikalne  (SgN  >muusikalne !02_A	et	f	\N
134646	muusikalne	?muusikalne =muusikalne  (PlP  >muusikaln !22_S	et	f	\N
134647	muusikalne	?muusikalne =sikalne  (SgN  >muu+sikalne !02_A	et	f	\N
134648	muusikalne	?muusikalne =sikalne  (PlP  >muu+sikaln !22_S	et	f	\N
134384	tähelepanuvad	?tähelepanuvad =lepanuva  (PlN  >tähe+lepanuv !02_A	et	f	\N
134385	tähelepanuvad	?tähelepanuvad =lepanuva  (PlN  >tähe+lepanuva !16_S	et	f	\N
134387	profesionaalse	?profesionaalse =profesionaalse  (SgG  >profesionaalne !02_A	et	f	\N
134388	profesionaalse	?profesionaalse =profesionaalse  (PlP  >profesionaals !22_S	et	f	\N
134405	asutamine	asutamine =asutamine  (SgN  >asutamine !12_S	et	f	\N
134406	asutamine	"asutamine %asuta  )MINE_vS  <asutama ;27_V	et	f	\N
134416	tugeva	tugeva =tugeva  (SgG  >tugev !02_A	et	f	\N
134417	tugeva	"tugev %tuge  )V_vA  <tugema ;27_V	et	f	\N
134452	traditsioniks	?traditsioniks =traditsioni  (SgTr  >traditsion !19~02_S	et	f	\N
134453	traditsioniks	?traditsioniks =traditsioni  (SgTr  >traditsioni !16_S	et	f	\N
134454	traditsioniks	?traditsioniks =traditsioni  (KndPrPs  >traditsionima !28_V	et	f	\N
134459	otsivad	otsivad =otsi  (IndPrPl3  >otsima !28_V	et	f	\N
134461	otsivad	otsivad =otsiva  (PlN  >otsiv !02_A	et	f	\N
134462	otsivad	"otsiv %otsi  )V_vA  <otsima ;28_V	et	f	\N
134463	otsivad	otsivad =iva  (PlN  >ots+iva !17_S	et	f	\N
134484	lauldega	### lauldega	et	f	\N
134488	mõtteaega	mõtteaega =aega  (SgP  >mõtte+aeg !22_S	et	f	\N
134489	mõtteaega	mõtteaega =aega  (SgAdt  >mõtte+aeg !22_S	et	f	\N
134503	pidutsesid	pidutsesid =pidutse  (IndIpfSg2  >pidutsema !27_V	et	f	\N
134504	pidutsesid	pidutsesid =pidutse  (IndIpfPl3  >pidutsema !27_V	et	f	\N
134509	hingale	?hingale =hinga  (SgAll  >hinga !16_S	et	f	\N
134510	hingale	?hingale =hingale  (IndPrPs_  >hingalema !27_V	et	f	\N
134511	hingale	?hingale =hingale  (ImpPrSg2  >hingalema !27_V	et	f	\N
134559	istusid	istusid =istu  (PlP  >ist !22_S	et	f	\N
134560	istusid	istusid =istu  (IndIpfSg2  >istuma !28_V	et	f	\N
134561	istusid	istusid =istu  (IndIpfPl3  >istuma !28_V	et	f	\N
134581	salvestatud	salvestatud =salvesta  (PtsPtIps  >salvestama !27_V	et	f	\N
134582	salvestatud	salvestatud =salvestatu  (PlN  >salvestatu !01_S	et	f	\N
134583	salvestatud	"salvestatu %salvesta  )TU1_vS  <salvestama ;27_V	et	f	\N
134584	salvestatud	salvestatud =salvestatud  (ID  >salvestatud !41_A	et	f	\N
134585	salvestatud	"salvestatud %salvesta  )TUD_vA  <salvestama ;27_V	et	f	\N
134589	laulumine	laulumine =lumine  (SgN  >lau+lumine !10_A	et	f	\N
134590	laulumine	"lau+lumine %lumi  )NE_aA  <lau+lumi ;20_S	et	f	\N
134620	rägivad	?rägivad =rägi  (IndPrPl3  >rägima !27_V	et	f	\N
134621	rägivad	?rägivad =rägiva  (PlN  >rägiva !01_S	et	f	\N
134622	rägivad	?rägivad =rägiva  (PlN  >rägiv !02_A	et	f	\N
134666	â	### â	et	f	\N
134677	eesmãrgi	### eesmãrgi	et	f	\N
134718	serveri	?serveri =serveri  (SgN  >serveri !01_S	et	f	\N
134719	serveri	?serveri =serveri  (SgG  >serveri !01_S	et	f	\N
134720	serveri	?serveri =serveri  (SgG  >server !02_S	et	f	\N
134723	pakkume	### pakkume	et	f	\N
134746	kasutaja	kasutaja =kasutaja  (SgN  >kasutaja !01_S	et	f	\N
134747	kasutaja	"kasutaja %kasuta  )JA_vS  <kasutama ;27_V	et	f	\N
134748	kasutaja	kasutaja =kasutaja  (SgG  >kasutaja !01_S	et	f	\N
134758	serveriruumi	?serveriruumi =serveriruumi  (SgN  >serveriruumi !16_S	et	f	\N
134759	serveriruumi	?serveriruumi =serveriruumi  (SgG  >serveriruumi !16_S	et	f	\N
134760	serveriruumi	?serveriruumi =serveriruumi  (SgG  >serveriruum !22_S	et	f	\N
134761	serveriruumi	?serveriruumi =serveriruumi  (SgP  >serveriruum !22_S	et	f	\N
134762	serveriruumi	?serveriruumi =serveriruumi  (SgAdt  >serveriruum !22_S	et	f	\N
134763	serveriruumi	?serveriruumi =serveriruumi  (IndPrPs_  >serveriruumima !28_V	et	f	\N
134764	serveriruumi	?serveriruumi =serveriruumi  (ImpPrSg2  >serveriruumima !28_V	et	f	\N
134772	viiruste	viiruste =viirus  (PlG  >viirus !11~09_S	et	f	\N
134773	viiruste	viiruste =us  (PlG  >viir+uks !14_S	et	f	\N
134774	spämmi	?spämmi =spämmi  (SgN  >spämmi !16_S	et	f	\N
134775	spämmi	?spämmi =spämmi  (SgG  >spämmi !16_S	et	f	\N
134776	spämmi	?spämmi =spämmi  (SgG  >spämm !22_S	et	f	\N
134777	spämmi	?spämmi =spämmi  (SgP  >spämm !22_S	et	f	\N
134778	spämmi	?spämmi =spämmi  (SgAdt  >spämm !22_S	et	f	\N
134779	spämmi	?spämmi =spämmi  (IndPrPs_  >spämmima !28_V	et	f	\N
134780	spämmi	?spämmi =spämmi  (ImpPrSg2  >spämmima !28_V	et	f	\N
134783	adressiraamat	?adressiraamat =adressiraama  (SgP  >adressiraama !16_S	et	f	\N
134809	gb	### gb	et	f	\N
134826	esmaspäevast	esmaspäevast =ast  (SgN  >esmas+päev+ast !22_S	et	f	\N
134827	esmaspäevast	esmaspäevast =päeva  (SgEl  >esmas+päev !22_S	et	f	\N
134828	esmaspäevast	esmaspäevast =päevas  (SgP  >esmas+päevane !10_A	et	f	\N
134829	esmaspäevast	"esmas+päevane %päeva  )NE_aA  <esmas+päev ;22_S	et	f	\N
134832	märgid	märgid =märgi  (PlN  >märk !22_S	et	f	\N
134833	märgid	märgid =märgi  (IndPrSg2  >märkima !28_V	et	f	\N
134837	plokerida	### plokerida	et	f	\N
134838	adreseid	?adreseid =adrese  (PlP  >adrene !10_A	et	f	\N
134839	adreseid	?adreseid =adresei  (PlN  >adresei !26_S	et	f	\N
134840	adreseid	?adreseid =adresei  (SgP  >adresei !26_S	et	f	\N
134846	interneti	?interneti =interneti  (IndPrPs_  >internettima !28_V	et	f	\N
134847	interneti	?interneti =interneti  (ImpPrSg2  >internettima !28_V	et	f	\N
134848	interneti	?interneti =neti  (SgN  >inter+neti !16_S	et	f	\N
134415	ühendavad	ühendavad =ava  (PlN  >ühend+ava !17_S	et	f	\N
134431	koostavad	koostavad =koosta  (IndPrPl3  >koostama !27_V	et	f	\N
134432	koostavad	koostavad =koostava  (PlN  >koostav !02_A	et	f	\N
134433	koostavad	"koostav %koosta  )V_vA  <koostama ;27_V	et	f	\N
134434	koostavad	koostavad =tava  (PlN  >koos+tava !17_S	et	f	\N
134441	näiste	?näiste =näiste  (SgN  >näiste !06_S	et	f	\N
134442	näiste	?näiste =näiste  (SgG  >näiste !06_S	et	f	\N
134443	näiste	?näiste =näiste  (PlP  >näist !22_S	et	f	\N
134444	näiste	?näiste =näiste  (IndPrPs_  >näistema !27_V	et	f	\N
134445	näiste	?näiste =näiste  (ImpPrSg2  >näistema !27_V	et	f	\N
134449	kirukus	?kirukus =kiruku  (SgIn  >kiruku !01_S	et	f	\N
134450	kirukus	?kirukus =kiruku  (IndIpfSg3  >kirukuma !27_V	et	f	\N
134451	kirukus	?kirukus =kirukus  (SgN  >kirukus !11_S	et	f	\N
134472	mängiva	mängiva =mängiva  (SgG  >mängiv !02_A	et	f	\N
134473	mängiva	"mängiv %mängi  )V_vA  <mängima ;28_V	et	f	\N
134490	sündimine	sündimine =sündimine  (SgN  >sündimine !12_S	et	f	\N
134491	sündimine	"sündimine %sündi  )MINE_vS  <sündima ;28_V	et	f	\N
134492	pidude	pidude =pidu  (PlG  >pidu !17_S	et	f	\N
134493	pidude	pidude =pidu  (PlG  >pidu !18_S	et	f	\N
134497	kultuuridentiteet	?kultuuridentiteet =kultuuridentiteet  (SgN  >kultuuridentiteet !22_S	et	f	\N
134498	kultuuridentiteet	?kultuuridentiteet =dentiteet  (SgN  >kultuuri+dentiteet !22_S	et	f	\N
134499	kultuuridentiteet	?kultuuridentiteet =identiteet  (SgN  >kultuur+identiteet !22_S	et	f	\N
134500	laulub	?laulub =laulu  (IndPrSg3  >lauluma !28_V	et	f	\N
134512	ideesse	ideesse =idee  (SgIll  >idee !26_S	et	f	\N
134513	ideesse	ideesse =idees  (SgAdt  >ideene !12_A	et	f	\N
134514	ideesse	"ideene %idee  )NE_aA  <idee ;26_S	et	f	\N
134515	maleta	maleta =male  (SgAb  >male !16_S	et	f	\N
134516	maleta	maleta =maleta  (IndPrPs_  >maletama !27_V	et	f	\N
134517	maleta	maleta =maleta  (ImpPrSg2  >maletama !27_V	et	f	\N
134524	mentalitee	?mentalitee =mentalitee  (SgN  >mentalitee !26_S	et	f	\N
134525	mentalitee	?mentalitee =mentalitee  (SgG  >mentalitee !26_S	et	f	\N
134535	ühindab	?ühindab =ühinda  (IndPrSg3  >ühindama !27_V	et	f	\N
134557	sega	sega =sega  (IndPrPs_  >segama !27_V	et	f	\N
134558	sega	sega =sega  (ImpPrSg2  >segama !27_V	et	f	\N
134562	vana-vana	vana-vana =vana  (SgN  >vana-vana !17_AS	et	f	\N
134563	vana-vana	vana-vana =vana  (SgG  >vana-vana !17_AS	et	f	\N
134564	vana-vana	vana-vana =vana  (SgP  >vana-vana !17_AS	et	f	\N
134565	laulust	laulust =laulu  (SgEl  >laul !22_S	et	f	\N
134566	laulust	laulust =lust  (SgN  >lau+lust !22_S	et	f	\N
134567	raagimist	?raagimist =raagimi  (SgEl  >raagimi !01_S	et	f	\N
134568	raagimist	?raagimist =raagimi  (SgEl  >raagim !02_A	et	f	\N
134569	raagimist	?raagimist =raagimis  (SgP  >raagimis !11_S	et	f	\N
134570	raagimist	?raagimist =raagimis  (SgP  >raagimine !12_S	et	f	\N
134571	raagimist	?raagimist =raagimist  (SgN  >raagimist !22_S	et	f	\N
134572	raagimist	?raagimist =imi  (SgEl  >raag+imi !17_S	et	f	\N
134573	raagimist	?raagimist =imis  (SgP  >raag+imis !09_S	et	f	\N
134574	raagimist	?raagimist =imis  (SgP  >raag+imine !10_A	et	f	\N
134575	raagimist	?raagimist =imist  (SgN  >raag+imist !22_S	et	f	\N
134576	hüüdmine	hüüdmine =hüüdmine  (SgN  >hüüdmine !12?10_S	et	f	\N
134577	hüüdmine	"hüüdmine %hüüd  )MINE_vS  <hüüdma ;34_V	et	f	\N
134591	aljal	?aljal =alja  (SgAd  >aljas !02_A	et	f	\N
134592	aljal	?aljal =alja  (SgAd  >alja !16_S	et	f	\N
134593	aljal	?aljal =aljal  (SgN  >aljal !02_S	et	f	\N
134649	alus	alus =alu  (SgIn  >alg !22_S	et	f	\N
134650	alus	alus =alu  (PlIn  >ala !17_S	et	f	\N
134651	alus	alus =alus  (SgN  >alus !09_S	et	f	\N
134658	padar	?padar =padar  (SgN  >padar !02_S	et	f	\N
134672	vãljendusvahend	### vãljendusvahend	et	f	\N
134702	toestus	toestus =toestus  (SgN  >toestus !11~09_S	et	f	\N
134703	toestus	"toestus %toesta  )US_vS  <toestama ;27_V	et	f	\N
134721	kasutajatele	kasutajatele =kasutaja  (PlAll  >kasutaja !01_S	et	f	\N
134722	kasutajatele	"kasutaja %kasuta  )JA_vS  <kasutama ;27_V	et	f	\N
134726	aadressiraamatud	?aadressiraamatud =aadressiraamatu  (PlN  >aadressiraamatu !01_A	et	f	\N
134727	aadressiraamatud	?aadressiraamatud =aadressiraamatu  (IndPrSg2  >aadressiraamatuma !27_V	et	f	\N
134728	aadressiraamatud	?aadressiraamatud =aadressiraamatud  (ID  >aadressiraamatud !41_A	et	f	\N
134743	e-posti	e-posti =posti  (SgG  >e-post !22_S	et	f	\N
134744	e-posti	e-posti =posti  (SgP  >e-post !22_S	et	f	\N
134745	e-posti	e-posti =posti  (SgAdt  >e-post !22_S	et	f	\N
134749	arvutile	arvutile =arvuti  (SgAll  >arvuti !01_S	et	f	\N
134750	arvutile	arvutile =uti  (SgAll  >arv+utt !22_S	et	f	\N
134751	arvutile	arvutile =uti  (PlAll  >arv+utt !22_S	et	f	\N
134784	kasutajana	kasutajana =kasutaja  (SgEs  >kasutaja !01_S	et	f	\N
134785	kasutajana	"kasutaja %kasuta  )JA_vS  <kasutama ;27_V	et	f	\N
134786	unistuste	unistuste =unistus  (PlG  >unistus !11_S	et	f	\N
134787	unistuste	"unistus %unista  )US_vS  <unistama ;27_V	et	f	\N
134796	adressiautomaatne	?adressiautomaatne =adressiautomaatne  (SgN  >adressiautomaatne !02_A	et	f	\N
134797	adressiautomaatne	?adressiautomaatne =adressiautomaatne  (PlP  >adressiautomaatn !22_S	et	f	\N
134495	tsaari-	tsaari- =tsaari  (SgP  >tsaar !22_S	et	f	\N
134496	tsaari-	tsaari- =tsaari  (SgAdt  >tsaar !22_S	et	f	\N
134518	ajalools	?ajalools =ajalools  (SgN  >ajalools !22_S	et	f	\N
134519	ajalools	?ajalools =lools  (SgN  >aja+lools !22_S	et	f	\N
134526	tõendatud	tõendatud =tõenda  (PtsPtIps  >tõendama !27_V	et	f	\N
134527	tõendatud	tõendatud =tõendatu  (PlN  >tõendatu !01_S	et	f	\N
134528	tõendatud	"tõendatu %tõenda  )TU1_vS  <tõendama ;27_V	et	f	\N
134529	tõendatud	tõendatud =tõendatud  (ID  >tõendatud !41_A	et	f	\N
134530	tõendatud	"tõendatud %tõenda  )TUD_vA  <tõendama ;27_V	et	f	\N
134531	tõendatud	tõendatud =atu  (PlN  >tõend+att !22_S	et	f	\N
134537	ideet	?ideet =ideet  (SgN  >ideet !22_S	et	f	\N
134538	ritooriline	?ritooriline =ritooriline  (SgN  >ritooriline !12_A	et	f	\N
134539	ritooriline	?ritooriline =ritooriline  (PlP  >ritoorilin !19_S	et	f	\N
134549	levitud	levitud =levi  (PtsPtIps  >levima !27_V	et	f	\N
134550	levitud	levitud =levitu  (PlN  >levitu !01_AS	et	f	\N
134551	levitud	"levitu %levi  )TU1_vS  <levima ;27_V	et	f	\N
134552	levitud	"levitu %levi  )TU2_kA  <levi ;17_S	et	f	\N
134553	levitud	levitud =levitud  (ID  >levitud !41_A	et	f	\N
134554	levitud	"levitud %levi  )TUD_vA  <levima ;27_V	et	f	\N
134596	mootivid	?mootivid =mootivi  (PlN  >mootiv !02_A	et	f	\N
134604	lauluvaljakul	?lauluvaljakul =lauluvaljakul  (SgN  >lauluvaljakul !19_S	et	f	\N
134605	lauluvaljakul	?lauluvaljakul =valjaku  (SgAd  >laulu+valjak !02_S	et	f	\N
134606	lauluvaljakul	?lauluvaljakul =valjakul  (SgN  >laulu+valjakul !19_S	et	f	\N
134607	lauluvaljakul	?lauluvaljakul =luvaljakul  (SgN  >lau+luvaljakul !19_S	et	f	\N
134627	emotsionalne	?emotsionalne =emotsionalne  (SgN  >emotsionalne !02_A	et	f	\N
134628	emotsionalne	?emotsionalne =emotsionalne  (PlP  >emotsionaln !22_S	et	f	\N
134663	benton	?benton =benton  (SgN  >benton !02_S	et	f	\N
134664	surfan	?surfan =surfan  (SgN  >surfan !02_S	et	f	\N
134668	vãiteid	### vãiteid	et	f	\N
134669	nãidetega	### nãidetega	et	f	\N
134680	jatnud	?jatnud =jatnu  (PlN  >jatnu !01_S	et	f	\N
134681	jatnud	?jatnud =jatnu  (IndPrSg2  >jatnuma !27_V	et	f	\N
134682	jatnud	?jatnud =jatnud  (ID  >jatnud !41_A	et	f	\N
134684	vabadussãµda	### vabadussãµda	et	f	\N
134685	lauluvãljakul	### lauluvãljakul	et	f	\N
134692	kãµik	### kãµik	et	f	\N
134695	saaksa	?saaksa =saaksa  (SgN  >saaksa !01_S	et	f	\N
134696	saaksa	?saaksa =saaksa  (SgG  >saaksa !01_S	et	f	\N
134697	saaksa	?saaksa =saaksa  (IndPrPs_  >saaksama !29_V	et	f	\N
134698	saaksa	?saaksa =saaksa  (ImpPrSg2  >saaksama !29_V	et	f	\N
134704	rahvapidude	rahvapidude =pidu  (PlG  >rahva+pidu !17_S	et	f	\N
134705	rahvapidude	rahvapidude =pidu  (PlG  >rahva+pidu !18_S	et	f	\N
134709	juubelilaulupeo	juubelilaulupeo =peo  (SgN  >juubeli+laulu+peo !26_S	et	f	\N
134710	juubelilaulupeo	juubelilaulupeo =peo  (SgG  >juubeli+laulu+pidu !18_S	et	f	\N
134711	juubelilaulupeo	juubelilaulupeo =peo  (SgG  >juubeli+laulu+peo !26_S	et	f	\N
134714	laulupidusid	laulupidusid =pidu  (PlP  >laulu+pidu !17_S	et	f	\N
134715	laulupidusid	laulupidusid =pidu  (PlP  >laulu+pidu !18_S	et	f	\N
134716	e-postee	?e-postee =postee  (SgN  >e-postee !26_S	et	f	\N
134717	e-postee	?e-postee =postee  (SgG  >e-postee !26_S	et	f	\N
134733	rämpsposti	?rämpsposti =rämpsposti  (SgN  >rämpsposti !01_S	et	f	\N
134735	rämpsposti	?rämpsposti =rämpsposti  (SgG  >rämpsposti !01_S	et	f	\N
134737	rämpsposti	?rämpsposti =rämpsposti  (IndPrPs_  >rämpspostima !28_V	et	f	\N
134740	rämpsposti	?rämpsposti =rämpsposti  (ImpPrSg2  >rämpspostima !28_V	et	f	\N
134765	mb	### mb	et	f	\N
134768	leenaee	?leenaee =leenaee  (SgN  >leenaee !26_S	et	f	\N
134769	leenaee	?leenaee =leenaee  (SgG  >leenaee !26_S	et	f	\N
134770	leenaee	?leenaee =aee  (SgN  >leen+aee !26_S	et	f	\N
134771	leenaee	?leenaee =aee  (SgG  >leen+aee !26_S	et	f	\N
134781	kalender-meeldetuletaja	kalender-meeldetuletaja =tuletaja  (SgN  >kalender-meelde+tuletaja !01_S	et	f	\N
134782	kalender-meeldetuletaja	kalender-meeldetuletaja =tuletaja  (SgG  >kalender-meelde+tuletaja !01_S	et	f	\N
134805	forum	?forum =forum  (SgN  >forum !02_S	et	f	\N
134806	küsitlus	küsitlus =küsitlus  (SgN  >küsitlus !11_S	et	f	\N
134807	küsitlus	"küsitlus %küsitle  )US_vS  <küsitlema ;27_V	et	f	\N
134823	prügikastiga	prügikastiga =iga  (SgN  >prügi+kast+iga !18_S	et	f	\N
134824	prügikastiga	prügikastiga =iga  (SgP  >prügi+kast+iga !18_S	et	f	\N
134825	prügikastiga	prügikastiga =kasti  (SgKom  >prügi+kast !22_S	et	f	\N
134834	häälipost	?häälipost =häälipo  (SgEl  >häälipo !16_S	et	f	\N
134835	video	video =video  (SgN  >video !01_S	et	f	\N
134836	video	video =video  (SgG  >video !01_S	et	f	\N
134855	postkasti	postkasti =kasti  (SgG  >post+kast !22_S	et	f	\N
134856	postkasti	postkasti =kasti  (SgP  >post+kast !22_S	et	f	\N
134857	postkasti	postkasti =kasti  (SgAdt  >post+kast !22_S	et	f	\N
134862	tasuliste	tasuliste =tasulis  (PlG  >tasuline !12_A	et	f	\N
134863	tasuliste	"tasuline %tasu  )LINE_aA  <tasu ;17_S	et	f	\N
134876	sunifon	?sunifon =sunifon  (SgN  >sunifon !19_S	et	f	\N
134878	kontroolltöö	?kontroolltöö =kontroolltöö  (SgN  >kontroolltöö !26_S	et	f	\N
134587	ausam	ausam =ausam  (SgN  >ausam !02_A	et	f	\N
134588	ausam	"ausam %ausa  )M_cA  <aus ;02_A	et	f	\N
134594	suhtlemised	suhtlemised =suhtlemise  (PlN  >suhtlemine !12_S	et	f	\N
134595	suhtlemised	"suhtlemine %suhtle  )MINE_vS  <suhtlema ;30_V	et	f	\N
134608	eläma	?eläma =eläma  (SgN  >eläma !01_S	et	f	\N
134609	eläma	?eläma =eläma  (SgG  >eläma !01_S	et	f	\N
134623	rahvatansid	?rahvatansid =rahvatansi  (PlN  >rahvatanss !22_S	et	f	\N
134624	rahvatansid	?rahvatansid =rahvatansi  (IndPrSg2  >rahvatanssima !28_V	et	f	\N
134625	rahvatansid	?rahvatansid =tansi  (PlN  >rahva+tansi !16_S	et	f	\N
134626	rahvatansid	?rahvatansid =tansi  (PlN  >rahva+tanss !22_S	et	f	\N
134629	musikalne	?musikalne =musikalne  (SgN  >musikalne !02_A	et	f	\N
134630	musikalne	?musikalne =musikalne  (PlP  >musikaln !22_S	et	f	\N
134631	musikalne	?musikalne =kalne  (SgN  >musi+kalne !02_A	et	f	\N
134632	musikalne	?musikalne =kalne  (PlP  >musi+kaln !22_S	et	f	\N
134635	vendunud	?vendunud =vendu  (PtsPtPs  >venduma !27_V	et	f	\N
134636	vendunud	?vendunud =vendunu  (PlN  >vendunu !01_S	et	f	\N
134637	vendunud	?vendunud =vendunu  (IndPrSg2  >vendunuma !27_V	et	f	\N
134638	vendunud	?vendunud =vendunud  (ID  >vendunud !41_A	et	f	\N
134639	hiirekõrvul	hiirekõrvul =hiirekõrvul  (ID  >hiire+kõrvul !41_DA	et	f	\N
134640	hiirekõrvul	hiirekõrvul =kõrvu  (PlAd  >hiire+kõrv !22_S	et	f	\N
134641	lauluringi	lauluringi =ringi  (SgG  >laulu+ring !22_S	et	f	\N
134642	lauluringi	lauluringi =ringi  (SgP  >laulu+ring !22_S	et	f	\N
134643	lauluringi	lauluringi =ringi  (SgAdt  >laulu+ring !22_S	et	f	\N
134644	lauluringi	lauluringi =lurin  (SgN^  >lau+lurin !02_S	et	f	\N
134652	etvs	?etvs =etvs  (SgN  >etvs !22_S	et	f	\N
134665	laulurahvaâ	### laulurahvaâ	et	f	\N
134667	sãµna	### sãµna	et	f	\N
134670	tãhelepanuvããrne	### tãhelepanuvããrne	et	f	\N
134673	tããtades	### tããtades	et	f	\N
134674	tulevikusse	tulevikusse =tuleviku  (SgIll  >tulevik !25_S	et	f	\N
134675	tulevikusse	tulevikusse =viku  (SgIll  >tule+vikk !22_S	et	f	\N
134676	pãrinevad	### pãrinevad	et	f	\N
134678	tãhtusega	### tãhtusega	et	f	\N
134679	jãlje	### jãlje	et	f	\N
134683	pãrast	### pãrast	et	f	\N
134688	kahekumne	?kahekumne =kahekumne  (SgN  >kahekumne !02_A	et	f	\N
134689	kahekumne	?kahekumne =kahekumne  (PlP  >kahekumn !22_S	et	f	\N
134690	kahekumne	?kahekumne =kumne  (SgN  >kahe+kumne !02_A	et	f	\N
134691	kahekumne	?kahekumne =kumne  (PlP  >kahe+kumn !22_S	et	f	\N
134712	tansud	?tansud =tansu  (PlN  >tansu !16_S	et	f	\N
134713	tansud	?tansud =tansu  (IndPrSg2  >tansuma !27_V	et	f	\N
134724	saatmist	saatmist =saatmis  (SgP  >saatmine !12?10_S	et	f	\N
134725	saatmist	"saatmine %saat  )MINE_vS  <saatma ;34_V	et	f	\N
134736	filtrid	filtrid =filtri  (PlN  >filter !02_S	et	f	\N
134739	filtrid	filtrid =filtri  (IndPrSg2  >filtrima !28_V	et	f	\N
134741	serveril	?serveril =serveri  (SgAd  >serveri !01_S	et	f	\N
134742	serveril	?serveril =serveri  (SgAd  >server !02_S	et	f	\N
134754	tasulised	tasulised =tasulise  (PlN  >tasuline !12_A	et	f	\N
134755	tasulised	"tasuline %tasu  )LINE_aA  <tasu ;17_S	et	f	\N
134791	wwwleenaeesinukasutajanimi	?wwwleenaeesinukasutajanimi =wwwleenaeesinukasutajanimi  (SgG  >wwwleenaeesinukasutajanim !02_A	et	f	\N
134792	häälpost	?häälpost =häälpo  (SgEl  >häälpo !16_S	et	f	\N
134793	häälpost	?häälpost =häälpos  (SgP  >häälpos !11~09_S	et	f	\N
134794	wwwleenazee	?wwwleenazee =wwwleenazee  (SgN  >wwwleenazee !26_S	et	f	\N
134795	wwwleenazee	?wwwleenazee =wwwleenazee  (SgG  >wwwleenazee !26_S	et	f	\N
134801	melelahutus	?melelahutus =melelahutu  (SgIn  >melelahutu !01_A	et	f	\N
134802	melelahutus	?melelahutus =melelahutu  (IndIpfSg3  >melelahutuma !27_V	et	f	\N
134803	melelahutus	?melelahutus =melelahutus  (SgN  >melelahutus !11?09_S	et	f	\N
134808	server	?server =server  (SgN  >server !02_S	et	f	\N
134811	php	### php	et	f	\N
134822	spamifiltriga	?spamifiltriga =spamifiltri  (SgKom  >spamifilter !02_S	et	f	\N
134877	õpisime	?õpisime =õpi  (IndIpfPl1  >õpima !27_V	et	f	\N
134894	keemiatootest	keemiatootest =test  (SgN  >keemia+too+test !22_S	et	f	\N
134895	keemiatootest	keemiatootest =toote  (SgEl  >keemia+toode !06_S	et	f	\N
134896	keemiatootest	keemiatootest =tootes  (SgP  >keemia+tootene !12~10_A	et	f	\N
134897	keemiatootest	"keemia+tootene %toote  )NE_aA  <keemia+toode ;06_S	et	f	\N
134922	päevavalgust	päevavalgust =us  (SgP  >päeva+valg+uks !14_S	et	f	\N
134923	päevavalgust	päevavalgust =valgu  (SgEl  >päeva+valk !22_S	et	f	\N
134924	päevavalgust	päevavalgust =valgus  (SgP  >päeva+valgus !11~09_S	et	f	\N
134925	päevavalgust	"päeva+valgus %valge  )US_aS  <päeva+valge ;01_AS	et	f	\N
134932	nõudvak	?nõudvak =nõudvak  (SgN  >nõudvak !02_S	et	f	\N
134935	kohtvalgustus	kohtvalgustus =ustu  (SgIn  >koht+valg+ustu !01_S	et	f	\N
134936	kohtvalgustus	kohtvalgustus =valgustus  (SgN  >koht+valgustus !11_S	et	f	\N
134957	ergonoomilised	?ergonoomilised =ergonoomilise  (PlN  >ergonoomiline !12_A	et	f	\N
134974	lahendusi	lahendusi =lahendusi  (PlP  >lahendus !11_S	et	f	\N
134975	lahendusi	"lahendus %lahenda  )US_vS  <lahendama ;27_V	et	f	\N
134983	virve	virve =virve  (SgN  >virve !06_S	et	f	\N
134653	ajuloo	ajuloo =loo  (SgG  >aju+lugu !18_S	et	f	\N
134654	ajuloo	ajuloo =loo  (SgG  >aju+loog !22_S	et	f	\N
134655	ajuloo	ajuloo =loo  (SgG  >aju+lood !22_S	et	f	\N
134656	tanel	?tanel =tane  (SgAd  >tane !16_S	et	f	\N
134657	tanel	?tanel =tanel  (SgN  >tanel !02_S	et	f	\N
134659	dave	?dave =dave  (SgN  >dave !16_S	et	f	\N
134660	dave	?dave =dave  (SgG  >dave !16_S	et	f	\N
134661	dave	?dave =dave  (IndPrPs_  >davema !27_V	et	f	\N
134662	dave	?dave =dave  (ImpPrSg2  >davema !27_V	et	f	\N
134671	kultuurinãhtus	### kultuurinãhtus	et	f	\N
134686	lauluvãljakule	### lauluvãljakule	et	f	\N
134687	tãhistada	### tãhistada	et	f	\N
134693	iseloomus	iseloomus =loomu  (SgIn  >ise+loom !22_S	et	f	\N
134694	iseloomus	iseloomus =loomus  (SgN  >ise+loomus !11~09_S	et	f	\N
134699	häilist	häilist =häili  (SgEl  >häil !22_S	et	f	\N
134700	häilist	häilist =häilis  (SgP  >häiline !12?10_A	et	f	\N
134701	häilist	"häiline %häili  )NE_aA  <häil ;22_S	et	f	\N
134706	naikoorid	?naikoorid =naikoori  (PlN  >naikoori !16_S	et	f	\N
134707	naikoorid	?naikoorid =naikoori  (PlN  >naikoor !22_S	et	f	\N
134708	naikoorid	?naikoorid =naikoori  (IndPrSg2  >naikoorima !28_V	et	f	\N
134729	säilitamist	säilitamist =säilitamis  (SgP  >säilitamine !12_S	et	f	\N
134730	säilitamist	"säilitamine %säilita  )MINE_vS  <säilitama ;27_V	et	f	\N
134731	meelelahutust	meelelahutust =lahutu  (SgEl  >meele+lahutu !01_AS	et	f	\N
134732	meelelahutust	"meele+lahutu %lahu  )TU2_kA  <meele+lahk ;22_S	et	f	\N
134734	meelelahutust	meelelahutust =lahutus  (SgP  >meele+lahutus !11_S	et	f	\N
134738	meelelahutust	"meele+lahutus %lahu  )TUS2_aS  <meele+lahk ;22_S	et	f	\N
134752	salvestamist	salvestamist =salvestamis  (SgP  >salvestamine !12_S	et	f	\N
134753	salvestamist	"salvestamine %salvesta  )MINE_vS  <salvestama ;27_V	et	f	\N
134756	eekkuus	?eekkuus =eekkuu  (SgIn  >eekkuu !26_S	et	f	\N
134757	eekkuus	?eekkuus =eekkuus  (SgN  >eekkuus !22_S	et	f	\N
134766	wwwleenaee	?wwwleenaee =wwwleenaee  (SgN  >wwwleenaee !26_S	et	f	\N
134767	wwwleenaee	?wwwleenaee =wwwleenaee  (SgG  >wwwleenaee !26_S	et	f	\N
134788	aadrissiks	?aadrissiks =aadrissi  (SgTr  >aadrissi !01_S	et	f	\N
134789	aadrissiks	?aadrissiks =aadrissi  (SgTr  >aadriss !22_S	et	f	\N
134790	aadrissiks	?aadrissiks =aadrissi  (KndPrPs  >aadrissima !28_V	et	f	\N
134798	loogimine	?loogimine =loogimine  (SgN  >loogimine !12_S	et	f	\N
134799	loogimine	?loogimine =loogimine  (PlP  >loogimin !19_S	et	f	\N
134800	loogimine	?loogimine =gimine  (SgN  >loo+gimine !10_A	et	f	\N
134804	naiteleht	?naiteleht =naiteleht  (SgN  >naiteleht !22_S	et	f	\N
134812	lisa	lisa =lisa  (SgN  >lisa !17_S	et	f	\N
134813	lisa	lisa =lisa  (SgG  >lisa !17_S	et	f	\N
134814	lisa	lisa =lisa  (SgP  >lisa !17_S	et	f	\N
134815	lisa	lisa =lisa  (IndPrPs_  >lisama !27_V	et	f	\N
134816	lisa	lisa =lisa  (ImpPrSg2  >lisama !27_V	et	f	\N
134817	java	?java =java  (SgN  >java !17_S	et	f	\N
134818	java	?java =java  (SgG  >java !17_S	et	f	\N
134819	java	?java =java  (SgP  >java !17_S	et	f	\N
134820	java	?java =java  (IndPrPs_  >javama !27_V	et	f	\N
134821	java	?java =java  (ImpPrSg2  >javama !27_V	et	f	\N
134841	mailid	?mailid =maili  (PlN  >maili !16_S	et	f	\N
134842	mailid	?mailid =maili  (PlN  >mail !22_S	et	f	\N
134843	mailid	?mailid =maili  (IndPrSg2  >mailima !28_V	et	f	\N
134851	sunee	?sunee =sunee  (SgN  >sunee !26_S	et	f	\N
134852	sunee	?sunee =sunee  (SgG  >sunee !26_S	et	f	\N
134858	laeneb	?laeneb =laene  (IndPrSg3  >laenema !27_V	et	f	\N
134866	piiritu	piiritu =piiritu  (SgN  >piiritu !01_A	et	f	\N
134867	piiritu	"piiritu %piiri  )TU2_kA  <piir ;22_S	et	f	\N
134868	piiritu	piiritu =piiritu  (SgG  >piiritu !01_A	et	f	\N
134872	viirustest	viirustest =viirus  (PlEl  >viirus !11~09_S	et	f	\N
134873	viirustest	viirustest =test  (SgN  >viirus+test !22_S	et	f	\N
134874	viirustest	viirustest =us  (PlEl  >viir+uks !14_S	et	f	\N
134905	toote	toote =too  (IndPrPl2  >tooma !38_V	et	f	\N
134906	toote	toote =toote  (SgG  >toode !06_S	et	f	\N
134907	toote	toote =toote  (PlP  >toot !22_S	et	f	\N
134915	ebaeffektivne	?ebaeffektivne =ebaeffektivne  (SgN  >ebaeffektivne !02_A	et	f	\N
134916	ebaeffektivne	?ebaeffektivne =ebaeffektivne  (PlP  >ebaeffektivn !22_S	et	f	\N
134917	ebaeffektivne	?ebaeffektivne =effektivne  (SgN  >eba+effektivne !02_A	et	f	\N
134918	ebaeffektivne	?ebaeffektivne =effektivne  (PlP  >eba+effektivn !22_S	et	f	\N
134919	tootja	tootja =tootja  (SgN  >tootja !01_S	et	f	\N
134920	tootja	"tootja %toot  )JA_vS  <tootma ;34_V	et	f	\N
134921	tootja	tootja =tootja  (SgG  >tootja !01_S	et	f	\N
134931	täpsust	täpsust =täpsus  (SgP  >täpsus !11~09_S	et	f	\N
134933	täpsust	"täpsus %täpsa  )US_aS  <täppis ;02_A	et	f	\N
134934	täpsust	"täpsus %täpse  )US_aS  <täpne ;02_A	et	f	\N
134940	valgust	valgust =valgu  (SgEl  >valk !22_S	et	f	\N
134941	valgust	valgust =valgus  (SgP  >valgus !11~09_S	et	f	\N
134942	valgust	"valgus %valge  )US_aS  <valge ;01_AS	et	f	\N
134943	valgust	valgust =us  (SgP  >valg+uks !14_S	et	f	\N
134948	kõrguse	kõrguse =kõrguse  (SgG  >kõrgus !11~09_S	et	f	\N
134810	html	### html	et	f	\N
134830	punasega	punasega =punase  (SgKom  >punane !10_AS	et	f	\N
134831	punasega	"punane %puna  )NE_aA  <puna ;17_S	et	f	\N
134844	wwwsunee	?wwwsunee =wwwsunee  (SgN  >wwwsunee !26_S	et	f	\N
134845	wwwsunee	?wwwsunee =wwwsunee  (SgG  >wwwsunee !26_S	et	f	\N
134853	kasutajaid	kasutajaid =kasutaja  (PlP  >kasutaja !01_S	et	f	\N
134854	kasutajaid	"kasutaja %kasuta  )JA_vS  <kasutama ;27_V	et	f	\N
134859	juhtiv	juhtiv =juhti  (PtsPrPs  >juhtima !28_V	et	f	\N
134860	juhtiv	juhtiv =juhtiv  (SgN  >juhtiv !02_A	et	f	\N
134861	juhtiv	"juhtiv %juhti  )V_vA  <juhtima ;28_V	et	f	\N
134875	aadressiraamat	?aadressiraamat =aadressiraama  (SgP  >aadressiraama !16_S	et	f	\N
134926	laed	laed =lae  (PlN  >lagi !21_S	et	f	\N
134927	laed	laed =lae  (PlN  >laad !22_S	et	f	\N
134928	laed	laed =lae  (IndPrSg2  >laadima !28_V	et	f	\N
134929	valgustamisel	valgustamisel =valgustamise  (SgAd  >valgustamine !12_S	et	f	\N
134930	valgustamisel	"valgustamine %valgusta  )MINE_vS  <valgustama ;27_V	et	f	\N
134937	pimestavat	pimestavat =pimesta  (KvtPrPs  >pimestama !27_V	et	f	\N
134938	pimestavat	pimestavat =pimestava  (SgP  >pimestav !02_A	et	f	\N
134939	pimestavat	"pimestav %pimesta  )V_vA  <pimestama ;27_V	et	f	\N
134944	istekoha	istekoha =koha  (SgN  >iste+koha !17_S	et	f	\N
134945	istekoha	istekoha =koha  (SgG  >iste+koha !17_S	et	f	\N
134946	istekoha	istekoha =koha  (SgG  >iste+koht !22_S	et	f	\N
134947	istekoha	istekoha =koha  (SgP  >iste+koha !17_S	et	f	\N
134959	soovitusest	soovitusest =soovituse  (SgEl  >soovitus !11_S	et	f	\N
134961	soovitusest	"soovitus %soovita  )US_vS  <soovitama ;27_V	et	f	\N
134963	soovitusest	"soovitus %soovi  )TUS1_aS  <soovima ;28_V	et	f	\N
134964	soovitusest	"soovitus %soovi  )TUS2_aS  <soov ;22_S	et	f	\N
134966	soovitusest	soovitusest =soovituses  (SgP  >soovitusene !12_A	et	f	\N
134968	soovitusest	"soovitusene %soovituse  )NE_aA  <soovitus ;11_S	et	f	\N
134988	wwwnetiee	?wwwnetiee =wwwnetiee  (SgN  >wwwnetiee !26_S	et	f	\N
134989	wwwnetiee	?wwwnetiee =wwwnetiee  (SgG  >wwwnetiee !26_S	et	f	\N
134990	ergonoomika	?ergonoomika =ergonoomika  (SgN  >ergonoomika !01_S	et	f	\N
134991	ergonoomika	?ergonoomika =ergonoomika  (SgG  >ergonoomika !01_S	et	f	\N
134992	ergonoomika	?ergonoomika =ergonoomika  (SgG  >ergonoomikas !02_A	et	f	\N
134997	kristjuhan	?kristjuhan =kristjuhan  (SgN  >kristjuhan !19_S	et	f	\N
135021	erklilla	erklilla =lilla  (SgN  >erk+lilla !16_AS	et	f	\N
135022	erklilla	erklilla =lilla  (SgG  >erk+lilla !16_AS	et	f	\N
135026	häirivad	häirivad =häiri  (IndPrPl3  >häirima !28_V	et	f	\N
135027	häirivad	häirivad =häiriva  (PlN  >häiriv !02_A	et	f	\N
135028	häirivad	"häiriv %häiri  )V_vA  <häirima ;28_V	et	f	\N
135074	parandavad	parandavad =paranda  (IndPrPl3  >parandama !27_V	et	f	\N
135075	parandavad	parandavad =parandava  (PlN  >parandav !02_A	et	f	\N
135076	parandavad	"parandav %paranda  )V_vA  <parandama ;27_V	et	f	\N
135077	valgustust	valgustust =valgustus  (SgP  >valgustus !11_S	et	f	\N
135078	valgustust	"valgustus %valgusta  )US_vS  <valgustama ;27_V	et	f	\N
135079	valgustust	valgustust =us  (SgP  >valgust+uks !14_S	et	f	\N
135080	valgustust	valgustust =tust  (SgN  >valgus+tust !22_S	et	f	\N
135081	valgustust	valgustust =ustu  (SgEl  >valg+ustu !01_S	et	f	\N
135101	regulaarselt	regulaarselt =regulaarse  (SgAbl  >regulaarne !02_A	et	f	\N
135102	regulaarselt	regulaarselt =regulaarselt  (ID  >regulaarselt !41_D	et	f	\N
135103	regulaarselt	"regulaarselt %regulaarse  )LT_mD  <regulaarne ;02_A	et	f	\N
135106	sobivaid	sobivaid =sobiva  (PlP  >sobiv !02_A	et	f	\N
135107	sobivaid	"sobiv %sobi  )V_vA  <sobima ;27_V	et	f	\N
135129	sekretäri	sekretäri =sekretäri  (SgG  >sekretär !19_S	et	f	\N
135130	sekretäri	sekretäri =sekretäri  (SgP  >sekretär !19_S	et	f	\N
135131	sekretäri	sekretäri =sekretäri  (SgAdt  >sekretär !19_S	et	f	\N
135135	martinsoni	?martinsoni =martinso  (SgTer  >martinso !16_S	et	f	\N
135136	martinsoni	?martinsoni =martinsoni  (SgG  >martinson !19_S	et	f	\N
135137	martinsoni	?martinsoni =martinsoni  (SgP  >martinson !19_S	et	f	\N
135138	martinsoni	?martinsoni =martinsoni  (SgAdt  >martinson !19_S	et	f	\N
135161	täitmise	täitmise =täitmise  (SgG  >täitmine !12?10_S	et	f	\N
135162	täitmise	"täitmine %täit  )MINE_vS  <täitma ;34_V	et	f	\N
135165	sõltumatu	sõltumatu =sõltumatu  (SgN  >sõltumatu !01_A	et	f	\N
135166	sõltumatu	"sõltumatu %sõltu  )MATU_vA  <sõltuma ;27_V	et	f	\N
135167	sõltumatu	sõltumatu =sõltumatu  (SgG  >sõltumatu !01_A	et	f	\N
135175	saite	saite =sa  (IndIpfPl2  >saama !37_V	et	f	\N
135176	saite	saite =saite  (PlP  >sait !22_S	et	f	\N
135184	nõuannet	nõuannet =anne  (SgP  >nõu+anne !05_S	et	f	\N
135185	nõuannet	nõuannet =anne  (SgP  >nõu+anne !06_S	et	f	\N
135196	kohandamine	kohandamine =kohandamine  (SgN  >kohandamine !12_S	et	f	\N
135197	kohandamine	"kohandamine %kohanda  )MINE_vS  <kohandama ;27_V	et	f	\N
135217	ergonoomilisust	?ergonoomilisust =ergonoomilisus  (SgP  >ergonoomilisus !11?09_S	et	f	\N
135218	wwwsekretaree	?wwwsekretaree =wwwsekretaree  (SgN  >wwwsekretaree !26_S	et	f	\N
135219	wwwsekretaree	?wwwsekretaree =wwwsekretaree  (SgG  >wwwsekretaree !26_S	et	f	\N
135236	pinges	pinges =pinge  (SgIn  >pinge !06_S	et	f	\N
135237	pinges	pinges =pinge  (PlIn  >ping !22_S	et	f	\N
134849	interneti	?interneti =neti  (SgG  >inter+neti !16_S	et	f	\N
134850	interneti	?interneti =neti  (SgG  >inter+nett !22_AS	et	f	\N
134864	teeninduste	teeninduste =teenindus  (PlG  >teenindus !11_S	et	f	\N
134865	teeninduste	"teenindus %teeninda  )US_vS  <teenindama ;27_V	et	f	\N
134869	rämpspostist	?rämpspostist =rämpsposti  (SgEl  >rämpsposti !01_S	et	f	\N
134870	rämpspostist	?rämpspostist =rämpspostis  (SgP  >rämpspostis !11_S	et	f	\N
134871	rämpspostist	?rämpspostist =rämpspostist  (SgN  >rämpspostist !22_S	et	f	\N
134889	surepäraselt	?surepäraselt =surepärase  (SgAbl  >surepärane !12_A	et	f	\N
134890	surepäraselt	?surepäraselt =surepäraselt  (ID  >surepäraselt !41_D	et	f	\N
134891	ravivad	ravivad =ravi  (IndPrPl3  >ravima !27_V	et	f	\N
134892	ravivad	ravivad =raviva  (PlN  >raviv !02_A	et	f	\N
134893	ravivad	"raviv %ravi  )V_vA  <ravima ;27_V	et	f	\N
134898	keemiatooteid	keemiatooteid =te  (PlP  >keemia+too+tee !26_S	et	f	\N
134899	keemiatooteid	keemiatooteid =toote  (PlP  >keemia+toode !06_S	et	f	\N
134903	keemia	keemia =keemia  (SgN  >keemia !01_S	et	f	\N
134904	keemia	keemia =keemia  (SgG  >keemia !01_S	et	f	\N
134972	parandamiseks	parandamiseks =parandamise  (SgTr  >parandamine !12_S	et	f	\N
134973	parandamiseks	"parandamine %paranda  )MINE_vS  <parandama ;27_V	et	f	\N
134981	otsimiseks	otsimiseks =otsimise  (SgTr  >otsimine !12_S	et	f	\N
134982	otsimiseks	"otsimine %otsi  )MINE_vS  <otsima ;28_V	et	f	\N
134986	wwwtturaamatee	?wwwtturaamatee =wwwtturaamatee  (SgN  >wwwtturaamatee !26_S	et	f	\N
134987	wwwtturaamatee	?wwwtturaamatee =wwwtturaamatee  (SgG  >wwwtturaamatee !26_S	et	f	\N
134993	eva-maria	?eva-maria =maria  (SgN  >eva-maria !01_S	et	f	\N
134994	eva-maria	?eva-maria =maria  (SgG  >eva-maria !01_S	et	f	\N
134996	wwwsekretaree160102prd	### wwwsekretaree160102prd	et	f	\N
135035	tugevamad	tugevamad =tugevama  (PlN  >tugevam !02_A	et	f	\N
135036	tugevamad	"tugevam %tuge  )VAM_cA  <tugema ;27_V	et	f	\N
135037	tugevamad	"tugevam %tugeva  )M_cA  <tugev ;02_A	et	f	\N
135047	eneseregulatsiooni	eneseregulatsiooni =regulatsiooni  (SgG  >enese+regulatsioon !22_S	et	f	\N
135048	eneseregulatsiooni	eneseregulatsiooni =regulatsiooni  (SgP  >enese+regulatsioon !22_S	et	f	\N
135049	eneseregulatsiooni	eneseregulatsiooni =regulatsiooni  (SgAdt  >enese+regulatsioon !22_S	et	f	\N
135065	tugevdamist	tugevdamist =tugevdamis  (SgP  >tugevdamine !12_S	et	f	\N
135066	tugevdamist	"tugevdamine %tugevda  )MINE_vS  <tugevdama ;27_V	et	f	\N
135085	nõudvaks	nõudvaks =nõudva  (SgTr  >nõudev !02_A	et	f	\N
135086	nõudvaks	"nõudev %nõud  )V_vA  <nõudma ;34_V	et	f	\N
135108	töötavatele	töötavatele =töötava  (PlAll  >töötav !02_A	et	f	\N
135109	töötavatele	"töötav %tööta  )V_vA  <töötama ;27_V	et	f	\N
135110	töötavatele	töötavatele =vate  (PlAll  >tööta+vatt !22_S	et	f	\N
135134	katrin	?katrin =katrin  (SgN  >katrin !02_S	et	f	\N
135142	riklikku	?riklikku =riklikku  (SgN  >riklikku !01_S	et	f	\N
135143	riklikku	?riklikku =riklikku  (SgG  >riklikku !01_S	et	f	\N
135144	riklikku	?riklikku =riklikku  (SgP  >riklik !25_A	et	f	\N
135145	riklikku	?riklikku =riklikku  (SgAdt  >riklik !25_A	et	f	\N
135147	riklikku	?riklikku =riklikku  (IndPrPs_  >riklikkuma !27_V	et	f	\N
135149	riklikku	?riklikku =riklikku  (ImpPrSg2  >riklikkuma !27_V	et	f	\N
135153	töösuhted	töösuhted =uhte  (PlN  >töös+uhe !06_S	et	f	\N
135155	töösuhted	töösuhted =suhte  (PlN  >töö+suhe !06_S	et	f	\N
135177	telli	telli =telli  (IndPrPs_  >tellima !28_V	et	f	\N
135178	telli	telli =telli  (ImpPrSg2  >tellima !28_V	et	f	\N
135179	arvutiajakirja	arvutiajakirja =kirja  (SgG  >arvuti+aja+kiri !24_S	et	f	\N
135180	arvutiajakirja	arvutiajakirja =kirja  (SgP  >arvuti+aja+kiri !24_S	et	f	\N
135181	arvutiajakirja	arvutiajakirja =kirja  (SgAdt  >arvuti+aja+kiri !24_S	et	f	\N
135201	sobivasse	sobivasse =sobiva  (SgIll  >sobiv !02_A	et	f	\N
135202	sobivasse	"sobiv %sobi  )V_vA  <sobima ;27_V	et	f	\N
135207	koolitus	koolitus =koolitu  (SgIn  >koolitu !01_AS	et	f	\N
135208	koolitus	"koolitu %kooli  )TU2_kA  <kool ;22_S	et	f	\N
135209	koolitus	koolitus =koolitus  (SgN  >koolitus !11_S	et	f	\N
135210	koolitus	"koolitus %koolita  )US_vS  <koolitama ;27_V	et	f	\N
135211	koolitus	"koolitus %kooli  )TUS2_aS  <kool ;22_S	et	f	\N
135225	sindroomi	?sindroomi =sindroomi  (SgN  >sindroomi !16_S	et	f	\N
135226	sindroomi	?sindroomi =sindroomi  (SgG  >sindroomi !16_S	et	f	\N
135227	sindroomi	?sindroomi =sindroomi  (SgG  >sindroom !22_S	et	f	\N
135228	sindroomi	?sindroomi =sindroomi  (SgP  >sindroom !22_S	et	f	\N
135229	sindroomi	?sindroomi =sindroomi  (SgAdt  >sindroom !22_S	et	f	\N
135230	sindroomi	?sindroomi =sindroomi  (IndPrPs_  >sindroomima !28_V	et	f	\N
135231	sindroomi	?sindroomi =sindroomi  (ImpPrSg2  >sindroomima !28_V	et	f	\N
135250	ülekoormushaigusi	ülekoormushaigusi =haigusi  (PlP  >üle+koormus+haigus !11_S	et	f	\N
135251	ülekoormushaigusi	"üle+koormus+haigus %haige  )US_aS  <üle+koormus+haige ;01_AS	et	f	\N
135270	töötervishoidu-	töötervishoidu- =hoidu  (SgP  >töö+tervis+hoid !22_S	et	f	\N
135272	töötervishoidu-	töötervishoidu- =hoidu  (SgAdt  >töö+tervis+hoid !22_S	et	f	\N
135277	world	?world =world  (SgN  >world !22_S	et	f	\N
135294	töötajale	töötajale =töötaja  (SgAll  >töötaja !01_S	et	f	\N
134879	kontroolltöö	?kontroolltöö =kontroolltöö  (SgG  >kontroolltöö !26_S	et	f	\N
134880	kontroolltöö	?kontroolltöö =roolltöö  (SgN  >kont+roolltöö !26_S	et	f	\N
134881	kontroolltöö	?kontroolltöö =roolltöö  (SgG  >kont+roolltöö !26_S	et	f	\N
134882	loodusele	loodusele =looduse  (SgAll  >loodus !11~09_S	et	f	\N
134883	loodusele	"loodus %loo  )TUS1_aS  <looma ;38_V	et	f	\N
134884	puhastavad	puhastavad =puhasta  (IndPrPl3  >puhastama !27_V	et	f	\N
134885	puhastavad	puhastavad =puhastava  (PlN  >puhastav !02_A	et	f	\N
134886	puhastavad	"puhastav %puhasta  )V_vA  <puhastama ;27_V	et	f	\N
134887	puhastavad	puhastavad =ava  (PlN  >puhast+ava !17_S	et	f	\N
134888	puhastavad	puhastavad =tava  (PlN  >puhas+tava !17_S	et	f	\N
134900	leidsimine	?leidsimine =leidsimine  (SgN  >leidsimine !12_S	et	f	\N
134901	leidsimine	?leidsimine =leidsimine  (PlP  >leidsimin !19_S	et	f	\N
134902	leidsimine	?leidsimine =simine  (SgN  >leid+simine !10_A	et	f	\N
134908	jatkavad	?jatkavad =jatka  (IndPrPl3  >jatkama !29_V	et	f	\N
134909	jatkavad	?jatkavad =jatkava  (PlN  >jatkava !01_S	et	f	\N
134910	jatkavad	?jatkavad =jatkava  (PlN  >jatkav !02_A	et	f	\N
134911	toitumises	toitumises =toitumise  (SgIn  >toitumine !12_S	et	f	\N
134912	toitumises	"toitumine %toitu  )MINE_vS  <toituma ;27_V	et	f	\N
134913	rohu	rohu =rohu  (SgG  >roht !22_S	et	f	\N
134914	rohu	rohu =rohu  (SgG  >rohi !24_S	et	f	\N
134953	ramatu	?ramatu =ramatu  (SgN  >ramatu !01_A	et	f	\N
134954	ramatu	?ramatu =ramatu  (SgG  >ramatu !01_A	et	f	\N
134955	ramatu	?ramatu =ramatu  (IndPrPs_  >ramatuma !27_V	et	f	\N
134956	ramatu	?ramatu =ramatu  (ImpPrSg2  >ramatuma !27_V	et	f	\N
134958	ergonoomilisest	?ergonoomilisest =ergonoomilise  (SgEl  >ergonoomiline !12_A	et	f	\N
134965	väljaande	väljaande =ande  (SgG  >välja+anne !06_S	et	f	\N
134967	väljaande	väljaande =ande  (PlP  >välja+and !22_S	et	f	\N
134979	ohutusalase	ohutusalase =alase  (SgG  >ohutus+alane !10_AS	et	f	\N
134980	ohutusalase	"ohutus+alane %ala  )NE_aA  <ohutus+ala ;17_S	et	f	\N
135005	turja	turja =turja  (SgG  >turi !24_S	et	f	\N
135006	turja	turja =turja  (SgP  >turi !24_S	et	f	\N
135007	turja	turja =turja  (SgAdt  >turi !24_S	et	f	\N
135017	liialdus	liialdus =liialdus  (SgN  >liialdus !11_S	et	f	\N
135018	liialdus	"liialdus %liialda  )US_vS  <liialdama ;27_V	et	f	\N
135019	kollane	kollane =kollane  (SgN  >kollane !10_A	et	f	\N
135020	kollane	"kollane %kolla  )NE_aA  <kold ;22_S	et	f	\N
135023	loovad	loovad =loo  (IndPrPl3  >looma !38_V	et	f	\N
135024	loovad	loovad =loova  (PlN  >loov !02_A	et	f	\N
135025	loovad	"loov %loo  )V_vA  <looma ;38_V	et	f	\N
135031	keskendumist	keskendumist =keskendumis  (SgP  >keskendumine !12_S	et	f	\N
135032	keskendumist	"keskendumine %keskendu  )MINE_vS  <keskenduma ;27_V	et	f	\N
135050	autogeensest	?autogeensest =autogeense  (SgEl  >autogeenne !02_A	et	f	\N
135051	autogeensest	?autogeensest =autogeense  (PlEl  >autogeens !22_S	et	f	\N
135052	autogeensest	?autogeensest =autogeenses  (SgP  >autogeensene !12~10_A	et	f	\N
135054	autogeensest	?autogeensest =geense  (SgEl  >auto+geenne !02_A	et	f	\N
135056	autogeensest	?autogeensest =geense  (SgEl  >auto+geense !06_S	et	f	\N
135057	autogeensest	?autogeensest =geense  (PlEl  >auto+geens !22_S	et	f	\N
135058	autogeensest	?autogeensest =geenses  (SgP  >auto+geenses !09_S	et	f	\N
135059	autogeensest	?autogeensest =geenses  (SgP  >auto+geensene !12~10_A	et	f	\N
135060	autogeensest	?autogeensest =togeense  (SgEl  >au+togeenne !02_A	et	f	\N
135061	autogeensest	?autogeensest =togeenses  (SgP  >au+togeensene !12~10_A	et	f	\N
135067	arvutikasutaja	arvutikasutaja =kasutaja  (SgN  >arvuti+kasutaja !01_S	et	f	\N
135068	arvutikasutaja	arvutikasutaja =kasutaja  (SgG  >arvuti+kasutaja !01_S	et	f	\N
135087	soovitav	soovitav =soovi  (PtsPrIps  >soovima !28_V	et	f	\N
135088	soovitav	soovitav =soovita  (PtsPrPs  >soovitama !27_V	et	f	\N
135089	soovitav	soovitav =soovitav  (SgN  >soovitav !02_A	et	f	\N
135090	soovitav	"soovitav %soovi  )TAV_vAS  <soovima ;28_V	et	f	\N
135091	soovitav	"soovitav %soovita  )V_vA  <soovitama ;27_V	et	f	\N
135117	parandaksid	parandaksid =paranda  (KndPrSg2  >parandama !27_V	et	f	\N
135118	parandaksid	parandaksid =paranda  (KndPrPl3  >parandama !27_V	et	f	\N
135119	töötamiskoha	töötamiskoha =koha  (SgN  >tööta+mis+koha !17_S	et	f	\N
135120	töötamiskoha	töötamiskoha =koha  (SgG  >tööta+mis+koha !17_S	et	f	\N
135121	töötamiskoha	töötamiskoha =koha  (SgG  >tööta+mis+koht !22_S	et	f	\N
135122	töötamiskoha	töötamiskoha =koha  (SgP  >tööta+mis+koha !17_S	et	f	\N
135139	tööinspektsiooni	tööinspektsiooni =inspektsiooni  (SgG  >töö+inspektsioon !22_S	et	f	\N
135140	tööinspektsiooni	tööinspektsiooni =inspektsiooni  (SgP  >töö+inspektsioon !22_S	et	f	\N
135141	tööinspektsiooni	tööinspektsiooni =inspektsiooni  (SgAdt  >töö+inspektsioon !22_S	et	f	\N
135150	tööohutust	tööohutust =tust  (SgN  >töö+ohu+tust !22_S	et	f	\N
135151	tööohutust	tööohutust =ohutu  (SgEl  >töö+ohutu !01_A	et	f	\N
135152	tööohutust	"töö+ohutu %ohu  )TU2_kA  <töö+oht ;22_S	et	f	\N
135154	tööohutust	tööohutust =ohutus  (SgP  >töö+ohutus !11_S	et	f	\N
135156	tööohutust	"töö+ohutus %ohu  )TUS2_aS  <töö+oht ;22_S	et	f	\N
135163	täitmisel	täitmisel =täitmise  (SgAd  >täitmine !12?10_S	et	f	\N
134949	kõrguse	"kõrgus %kõrge  )US_aS  <kõrge ;01_A	et	f	\N
134950	kõrguse	kõrguse =kõrguse  (SgG  >kõrgune !10~12_A	et	f	\N
134951	arvutitöökohta	arvutitöökohta =kohta  (SgP  >arvuti+töö+koht !22_S	et	f	\N
134952	arvutitöökohta	arvutitöökohta =kohta  (SgAdt  >arvuti+töö+koht !22_S	et	f	\N
134960	koosneva	koosneva =koosneva  (SgG  >koosnev !02_A	et	f	\N
134962	koosneva	"koosnev %koosne  )V_vA  <koosnema ;27_V	et	f	\N
134969	ohutuse	ohutuse =ohutuse  (SgG  >ohutus !11_S	et	f	\N
134970	ohutuse	"ohutus %ohuta  )US_vS  <ohutama ;27_V	et	f	\N
134971	ohutuse	"ohutus %ohu  )TUS2_aS  <oht ;22_S	et	f	\N
134976	ergonoomika-	?ergonoomika- =ergonoomika  (SgN  >ergonoomika !01_S	et	f	\N
134977	ergonoomika-	?ergonoomika- =ergonoomika  (SgG  >ergonoomika !01_S	et	f	\N
134978	ergonoomika-	?ergonoomika- =ergonoomika  (SgG  >ergonoomikas !02_A	et	f	\N
134985	siirak	?siirak =siirak  (SgN  >siirak !02_S	et	f	\N
134995	reimers	?reimers =reimers  (SgN  >reimers !02_S	et	f	\N
134998	wwwparnueeraulpageergo	?wwwparnueeraulpageergo =wwwparnueeraulpageergo  (SgN  >wwwparnueeraulpageergo !16_S	et	f	\N
134999	wwwparnueeraulpageergo	?wwwparnueeraulpageergo =wwwparnueeraulpageergo  (SgG  >wwwparnueeraulpageergo !16_S	et	f	\N
135000	väsimist	väsimist =väsimis  (SgP  >väsimine !12_S	et	f	\N
135001	väsimist	"väsimine %väsi  )MINE_vS  <väsima ;27_V	et	f	\N
135012	meestele	meestele =mees  (PlAll  >meene !10_A	et	f	\N
135013	meestele	"meene %mee  )NE_aA  <mesi ;15_S	et	f	\N
135014	meestele	meestele =mees  (PlAll  >mees !13_S	et	f	\N
135029	pikaajalist	pikaajalist =ajalis  (SgP  >pika+ajaline !12_A	et	f	\N
135030	pikaajalist	"pika+ajaline %aja  )LINE_aA  <pika+aeg ;22_S	et	f	\N
135033	särtsakamad	särtsakamad =särtsakama  (PlN  >särtsakam !02_A	et	f	\N
135034	särtsakamad	"särtsakam %särtsaka  )M_cA  <särtsakas ;02_A	et	f	\N
135062	füüsise	?füüsise =füüsise  (SgG  >füüsis !09_S	et	f	\N
135063	füüsise	?füüsise =füüsise  (IndPrPs_  >füüsisema !27_V	et	f	\N
135064	füüsise	?füüsise =füüsise  (ImpPrSg2  >füüsisema !27_V	et	f	\N
135072	valgusallikas	valgusallikas =allika  (SgIn  >valgus+allikas !02_S	et	f	\N
135073	valgusallikas	valgusallikas =allikas  (SgN  >valgus+allikas !02_S	et	f	\N
135092	ergonoomilisi	?ergonoomilisi =ergonoomilisi  (PlP  >ergonoomiline !12_A	et	f	\N
135104	töötajatele	töötajatele =töötaja  (PlAll  >töötaja !01_S	et	f	\N
135105	töötajatele	"töötaja %tööta  )JA_vS  <töötama ;27_V	et	f	\N
135111	koolitust	koolitust =koolitu  (SgEl  >koolitu !01_AS	et	f	\N
135112	koolitust	"koolitu %kooli  )TU2_kA  <kool ;22_S	et	f	\N
135113	koolitust	koolitust =koolitus  (SgP  >koolitus !11_S	et	f	\N
135114	koolitust	"koolitus %koolita  )US_vS  <koolitama ;27_V	et	f	\N
135115	koolitust	"koolitus %kooli  )TUS2_aS  <kool ;22_S	et	f	\N
135116	koolitust	koolitust =tust  (SgN  >kooli+tust !22_S	et	f	\N
135123	kujundust	kujundust =kujundus  (SgP  >kujundus !11_S	et	f	\N
135124	kujundust	"kujundus %kujunda  )US_vS  <kujundama ;27_V	et	f	\N
135125	sari	sari =sari  (SgN  >sari !17_S	et	f	\N
135126	sari	sari =sari  (SgN  >sari !24_S	et	f	\N
135127	sari	sari =sari  (SgG  >sari !17_S	et	f	\N
135128	sari	sari =sari  (SgP  >sari !17_S	et	f	\N
135146	töötervishoidu	töötervishoidu =hoidu  (SgP  >töö+tervis+hoid !22_S	et	f	\N
135148	töötervishoidu	töötervishoidu =hoidu  (SgAdt  >töö+tervis+hoid !22_S	et	f	\N
135159	nõuete	nõuete =nõue  (PlG  >nõue !06_S	et	f	\N
135160	nõuete	nõuete =e  (PlG  >nõu+esi !15_S	et	f	\N
135168	otsuste	otsuste =otsus  (PlG  >otsus !09_S	et	f	\N
135169	otsuste	otsuste =us  (PlG  >ots+uks !14_S	et	f	\N
135170	kohustatud	kohustatud =kohusta  (PtsPtIps  >kohustama !27_V	et	f	\N
135171	kohustatud	kohustatud =kohustatu  (PlN  >kohustatu !01_S	et	f	\N
135172	kohustatud	"kohustatu %kohusta  )TU1_vS  <kohustama ;27_V	et	f	\N
135173	kohustatud	kohustatud =kohustatud  (ID  >kohustatud !41_A	et	f	\N
135174	kohustatud	"kohustatud %kohusta  )TUD_vA  <kohustama ;27_V	et	f	\N
135182	valgustusega	valgustusega =valgustuse  (SgKom  >valgustus !11_S	et	f	\N
135183	valgustusega	"valgustus %valgusta  )US_vS  <valgustama ;27_V	et	f	\N
135220	kuiva	kuiva =kuiva  (SgG  >kuiv !22_AS	et	f	\N
135221	kuiva	kuiva =kuiva  (SgP  >kuiv !22_AS	et	f	\N
135222	kuiva	kuiva =kuiva  (SgAdt  >kuiv !22_AS	et	f	\N
135223	kuiva	kuiva =kuiva  (IndPrPs_  >kuivama !28_V	et	f	\N
135224	kuiva	kuiva =kuiva  (ImpPrSg2  >kuivama !28_V	et	f	\N
135235	turjalihased	?turjalihased =turjalihase  (PlN  >turjalihane !12_A	et	f	\N
135239	eri	eri =eri  (ID  >eri !41_A	et	f	\N
135241	eri	eri =eri  (SgN  >eri !17_S	et	f	\N
135243	eri	eri =eri  (SgG  >eri !17_S	et	f	\N
135244	eri	eri =eri  (SgP  >eri !17_S	et	f	\N
135255	lagi	lagi =lagi  (SgN  >lagi !21_S	et	f	\N
135256	lagi	lagi =la  (SgN^  >la !26_S	et	f	\N
135257	lagi	lagi =la  (SgG^  >la !26_S	et	f	\N
135274	tööohutusalaseid	tööohutusalaseid =alase  (PlP  >töö+ohutus+alasi !01_S	et	f	\N
135275	tööohutusalaseid	tööohutusalaseid =alase  (PlP  >töö+ohutus+alane !10_AS	et	f	\N
135276	tööohutusalaseid	"töö+ohutus+alane %ala  )NE_aA  <töö+ohutus+ala ;17_S	et	f	\N
135279	kulusid	kulusid =kulu  (PlP  >kulu !17_S	et	f	\N
135280	kulusid	kulusid =kulu  (IndIpfSg2  >kuluma !27_V	et	f	\N
134984	virve	virve =virve  (SgG  >virve !06_S	et	f	\N
135002	lihaseid	lihaseid =lihase  (PlP  >lihas !09_S	et	f	\N
135003	lihaseid	lihaseid =lihase  (PlP  >lihane !10_A	et	f	\N
135004	lihaseid	"lihane %liha  )NE_aA  <liha ;17_S	et	f	\N
135008	töötajate	töötajate =töötaja  (PlG  >töötaja !01_S	et	f	\N
135009	töötajate	"töötaja %tööta  )JA_vS  <töötama ;27_V	et	f	\N
135010	sooga	sooga =soo  (SgKom  >sugu !18_S	et	f	\N
135011	sooga	sooga =soo  (SgKom  >soo !26_S	et	f	\N
135015	kinnist	kinnist =kinnis  (SgP  >kinnis !09_S	et	f	\N
135016	kinnist	kinnist =kinnis  (SgP  >kinnine !10~12_A	et	f	\N
135038	eakama	eakama =eakama  (SgG  >eakam !02_A	et	f	\N
135039	eakama	"eakam %eaka  )M_cA  <eakas ;02_A	et	f	\N
135040	eakama	eakama =kama  (SgN  >ea+kama !17_S	et	f	\N
135041	eakama	eakama =kama  (SgG  >ea+kama !17_S	et	f	\N
135042	eakama	eakama =kama  (SgP  >ea+kama !17_S	et	f	\N
135043	suurvõtke	?suurvõtke =suurvõtke  (PlP  >suurvõtk !22_S	et	f	\N
135044	suurvõtke	?suurvõtke =võtke  (SgN  >suur+võtke !06_S	et	f	\N
135045	suurvõtke	?suurvõtke =võtke  (SgG  >suur+võtke !06_S	et	f	\N
135046	suurvõtke	?suurvõtke =võtke  (PlP  >suur+võtk !22_S	et	f	\N
135053	treeningust	treeningust =treeningu  (SgEl  >treening !02_S	et	f	\N
135055	treeningust	treeningust =us  (SgP  >treening+uks !14_S	et	f	\N
135069	päevavalgus	päevavalgus =valgu  (SgIn  >päeva+valk !22_S	et	f	\N
135070	päevavalgus	päevavalgus =valgus  (SgN  >päeva+valgus !11~09_S	et	f	\N
135071	päevavalgus	"päeva+valgus %valge  )US_aS  <päeva+valge ;01_AS	et	f	\N
135082	heleduste	heleduste =heledus  (PlG  >heledus !11_S	et	f	\N
135083	heleduste	"heledus %heleda  )US_aS  <hele ;02_A	et	f	\N
135084	heleduste	heleduste =duste  (PlP  >hele+dust !22_S	et	f	\N
135093	kõrgust	kõrgust =kõrgus  (SgP  >kõrgus !11~09_S	et	f	\N
135094	kõrgust	"kõrgus %kõrge  )US_aS  <kõrge ;01_A	et	f	\N
135095	kõrgust	kõrgust =kõrgus  (SgP  >kõrgune !10~12_A	et	f	\N
135096	kõrgust	kõrgust =us  (SgP  >kõrg+uks !14_S	et	f	\N
135097	arvutikohta	arvutikohta =kohta  (SgP  >arvuti+koht !22_S	et	f	\N
135098	arvutikohta	arvutikohta =kohta  (SgAdt  >arvuti+koht !22_S	et	f	\N
135099	mid	mid =mi  (PlN  >mi !26_S	et	f	\N
135100	mid	mid =mi  (SgP  >mi !26_S	et	f	\N
135132	httpwwwrahvaraamatee	?httpwwwrahvaraamatee =httpwwwrahvaraamatee  (SgN  >httpwwwrahvaraamatee !26_S	et	f	\N
135133	httpwwwrahvaraamatee	?httpwwwrahvaraamatee =httpwwwrahvaraamatee  (SgG  >httpwwwrahvaraamatee !26_S	et	f	\N
135157	reguleerivate	reguleerivate =reguleeriva  (PlG  >reguleeriv !02_A	et	f	\N
135158	reguleerivate	"reguleeriv %reguleeri  )V_vA  <reguleerima ;28_V	et	f	\N
135186	nägemisvälja	nägemisvälja =välja  (SgG  >nägemis+väli !24_S	et	f	\N
135187	nägemisvälja	nägemisvälja =välja  (SgP  >nägemis+väli !24_S	et	f	\N
135188	nägemisvälja	nägemisvälja =välja  (SgAdt  >nägemis+väli !24_S	et	f	\N
135190	joonel	joonel =joone  (SgAd  >joon !13_S	et	f	\N
135191	joonel	joonel =joonel  (SgN  >joonel !02_S	et	f	\N
135192	arvutitöökoha	arvutitöökoha =koha  (SgN  >arvuti+töö+koha !17_S	et	f	\N
135193	arvutitöökoha	arvutitöökoha =koha  (SgG  >arvuti+töö+koha !17_S	et	f	\N
135194	arvutitöökoha	arvutitöökoha =koha  (SgG  >arvuti+töö+koht !22_S	et	f	\N
135195	arvutitöökoha	arvutitöökoha =koha  (SgP  >arvuti+töö+koha !17_S	et	f	\N
135198	klaviatuuri	klaviatuuri =klaviatuuri  (SgG  >klaviatuur !22_S	et	f	\N
135199	klaviatuuri	klaviatuuri =klaviatuuri  (SgP  >klaviatuur !22_S	et	f	\N
135200	klaviatuuri	klaviatuuri =klaviatuuri  (SgAdt  >klaviatuur !22_S	et	f	\N
135203	kõrgusele	kõrgusele =kõrguse  (SgAll  >kõrgus !11~09_S	et	f	\N
135204	kõrgusele	"kõrgus %kõrge  )US_aS  <kõrge ;01_A	et	f	\N
135205	kõrgusele	kõrgusele =kõrguse  (SgAll  >kõrgune !10~12_A	et	f	\N
135206	kõrgusele	kõrgusele =use  (PlAll  >kõrg+usk !22_S	et	f	\N
135214	ergoonomika	?ergoonomika =ergoonomika  (SgN  >ergoonomika !01_S	et	f	\N
135215	ergoonomika	?ergoonomika =ergoonomika  (SgG  >ergoonomika !01_S	et	f	\N
135216	ergoonomika	?ergoonomika =ergoonomika  (SgG  >ergoonomikas !02_A	et	f	\N
135240	kehapoolte	?kehapoolte =poolte  (SgN  >keha+poolte !06_S	et	f	\N
135242	kehapoolte	?kehapoolte =poolte  (SgG  >keha+poolde !06_S	et	f	\N
135248	ülekoormushaiguste	ülekoormushaiguste =haigus  (PlG  >üle+koormus+haigus !11~09_S	et	f	\N
135249	ülekoormushaiguste	"üle+koormus+haigus %haige  )US_aS  <üle+koormus+haige ;01_AS	et	f	\N
135258	valguse	valguse =valguse  (SgG  >valgus !11~09_S	et	f	\N
135259	valguse	"valgus %valge  )US_aS  <valge ;01_AS	et	f	\N
135260	näiliselt	näiliselt =näilise  (SgAbl  >näiline !12?10_A	et	f	\N
135261	näiliselt	näiliselt =näiliselt  (ID  >näiliselt !41_D	et	f	\N
135262	näiliselt	"näiliselt %näilise  )LT_mD  <näiline ;10_A	et	f	\N
135263	näiliselt	"näiliselt %näilise  )LT_mD  <näiline ;12_A	et	f	\N
135264	tööandja	tööandja =andja  (SgN  >töö+andja !01_S	et	f	\N
135265	tööandja	tööandja =andja  (SgG  >töö+andja !01_S	et	f	\N
135282	nõudva	nõudva =nõudva  (SgG  >nõudev !02_A	et	f	\N
135283	nõudva	"nõudev %nõud  )V_vA  <nõudma ;34_V	et	f	\N
135286	kohtvalgusteid	kohtvalgusteid =te  (PlP  >koht+valgus+tee !26_S	et	f	\N
135287	kohtvalgusteid	kohtvalgusteid =valguste  (PlP  >koht+valgusti !01_S	et	f	\N
135164	täitmisel	"täitmine %täit  )MINE_vS  <täitma ;34_V	et	f	\N
135189	ergonoomilise	?ergonoomilise =ergonoomilise  (SgG  >ergonoomiline !12_A	et	f	\N
135212	käsiraamatus	käsiraamatus =atu  (SgIn  >käsi+raam+att !22_S	et	f	\N
135213	käsiraamatus	käsiraamatus =raamatu  (SgIn  >käsi+raamat !02_S	et	f	\N
135232	kipitavad	kipitavad =kipita  (IndPrPl3  >kipitama !27_V	et	f	\N
135233	kipitavad	kipitavad =kipitava  (PlN  >kipitav !02_A	et	f	\N
135234	kipitavad	"kipitav %kipita  )V_vA  <kipitama ;27_V	et	f	\N
135245	lihased	lihased =lihase  (PlN  >lihas !09_S	et	f	\N
135246	lihased	lihased =lihase  (PlN  >lihane !10_A	et	f	\N
135247	lihased	"lihane %liha  )NE_aA  <liha ;17_S	et	f	\N
135252	liigutaval	liigutaval =liigutava  (SgAd  >liigutav !02_A	et	f	\N
135253	liigutaval	"liigutav %liigu  )TAV_vAS  <liikuma ;28_V	et	f	\N
135254	liigutaval	"liigutav %liiguta  )V_vA  <liigutama ;27_V	et	f	\N
135266	volitanud	volitanud =volita  (PtsPtPs  >volitama !27_V	et	f	\N
135267	volitanud	volitanud =volitanu  (PlN  >volitanu !01_S	et	f	\N
135268	volitanud	"volitanu %volita  )NU_vS  <volitama ;27_V	et	f	\N
135269	volitanud	volitanud =volitanud  (ID  >volitanud !41_A	et	f	\N
135271	volitanud	"volitanud %volita  )NUD_vA  <volitama ;27_V	et	f	\N
135273	volitanud	volitanud =tanu  (PlN  >voli+tanu !17_S	et	f	\N
135278	pc	### pc	et	f	\N
135288	vajalikku	vajalikku =vajalikku  (SgP  >vajalik !25_A	et	f	\N
135289	vajalikku	vajalikku =vajalikku  (SgAdt  >vajalik !25_A	et	f	\N
135297	tooli	tooli =tooli  (SgG  >tool !22_S	et	f	\N
135300	tooli	tooli =tooli  (SgP  >tool !22_S	et	f	\N
135301	tooli	tooli =tooli  (SgAdt  >tool !22_S	et	f	\N
135326	ülaosa	ülaosa =osa  (SgN  >üla+osa !17_S	et	f	\N
135327	ülaosa	ülaosa =osa  (SgG  >üla+osa !17_S	et	f	\N
135328	ülaosa	ülaosa =osa  (SgP  >üla+osa !17_S	et	f	\N
135331	istmepinda	istmepinda =pinda  (SgG  >istme+pint !22_S	et	f	\N
135332	istmepinda	istmepinda =pinda  (SgP  >istme+pind !22_S	et	f	\N
135333	istmepinda	istmepinda =pinda  (SgAdt  >istme+pind !22_S	et	f	\N
135347	sündroomi	sündroomi =sündroomi  (SgG  >sündroom !22_S	et	f	\N
135348	sündroomi	sündroomi =sündroomi  (SgP  >sündroom !22_S	et	f	\N
135349	sündroomi	sündroomi =sündroomi  (SgAdt  >sündroom !22_S	et	f	\N
135353	värvust	värvust =värvu  (SgEl  >värb !22_S	et	f	\N
135354	värvust	värvust =värvus  (SgP  >värvus !11~09_S	et	f	\N
135355	värvust	värvust =us  (SgP  >värv+uks !14_S	et	f	\N
135360	töötatakse	töötatakse =tööta  (IndPrIps  >töötama !27_V	et	f	\N
135361	töötatakse	töötatakse =takse  (PlP  >tööta+taks !22_S	et	f	\N
135367	soovitavad	soovitavad =soovita  (IndPrPl3  >soovitama !27_V	et	f	\N
135368	soovitavad	soovitavad =soovitava  (PlN  >soovitav !02_A	et	f	\N
135369	soovitavad	"soovitav %soovi  )TAV_vAS  <soovima ;28_V	et	f	\N
135370	soovitavad	"soovitav %soovita  )V_vA  <soovitama ;27_V	et	f	\N
135371	soovitavad	soovitavad =tava  (PlN  >soovi+tava !17_S	et	f	\N
135374	bild	?bild =bild  (SgN  >bild !22_S	et	f	\N
135375	kodulinnas	kodulinnas =linna  (SgIn  >kodu+linn !22_S	et	f	\N
135376	kodulinnas	kodulinnas =linnas  (SgN  >kodu+linnas !09_S	et	f	\N
135379	leo	leo =leo  (SgG  >ligu !18_S	et	f	\N
135380	leo	leo =leo  (IndPrPs_  >liguma !28_V	et	f	\N
135381	leo	leo =leo  (ImpPrSg2  >liguma !28_V	et	f	\N
135384	fregat	?fregat =fregat  (SgN  >fregat !02_S	et	f	\N
135385	meesterahvas	meesterahvas =rahva  (SgIn  >meeste+rahvas !07_S	et	f	\N
135386	meesterahvas	meesterahvas =rahvas  (SgN  >meeste+rahvas !07_S	et	f	\N
135390	praend	?praend =praend  (SgN  >praend !02_S	et	f	\N
135412	koktelid	?koktelid =kokteli  (PlN  >koktel !02_S	et	f	\N
135428	18-aastane	-aastane =aastane  (SgN  >-aastane !12~10_A	et	f	\N
135429	18-aastane	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
135434	napoleoni	?napoleoni =napoleo  (SgTer  >napoleo !01_S	et	f	\N
135435	napoleoni	?napoleoni =napoleoni  (SgN  >napoleoni !16_S	et	f	\N
135436	napoleoni	?napoleoni =napoleoni  (SgG  >napoleoni !16_S	et	f	\N
135437	napoleoni	?napoleoni =napoleoni  (SgG  >napoleon !19_S	et	f	\N
135438	napoleoni	?napoleoni =napoleoni  (SgP  >napoleon !19_S	et	f	\N
135439	napoleoni	?napoleoni =napoleoni  (SgAdt  >napoleon !19_S	et	f	\N
135440	napoleoni	?napoleoni =napoleoni  (IndPrPs_  >napoleonima !28_V	et	f	\N
135441	napoleoni	?napoleoni =napoleoni  (ImpPrSg2  >napoleonima !28_V	et	f	\N
135457	krevettiga	?krevettiga =krevetti  (SgKom  >krevetti !01_S	et	f	\N
135490	ulukiliha	?ulukiliha =ulukiliha  (SgN  >ulukiliha !16_S	et	f	\N
135491	ulukiliha	?ulukiliha =ulukiliha  (SgG  >ulukiliha !16_S	et	f	\N
135492	ulukiliha	?ulukiliha =kiliha  (SgN  >ulu+kiliha !01_S	et	f	\N
135493	ulukiliha	?ulukiliha =kiliha  (SgG  >ulu+kiliha !01_S	et	f	\N
135506	telime	?telime =teli  (IndPrPl1  >telima !27_V	et	f	\N
135521	seenid	?seenid =seeni  (PlN  >seeni !16_S	et	f	\N
135522	seenid	?seenid =seeni  (IndPrSg2  >seenima !28_V	et	f	\N
135523	ananasid	### ananasid	et	f	\N
135524	sing	?sing =sing  (SgN  >sing !22_S	et	f	\N
135542	söömas	söömas =söö  (SupIn  >sööma !38_V	et	f	\N
135543	söömas	söömas =sööma  (SgIn  >sööm !22_S	et	f	\N
135561	taines	?taines =taine  (PlIn  >tain !22_S	et	f	\N
135238	pinges	pinges =pinge  (PlIn  >pink !22_S	et	f	\N
135284	sellekohale	sellekohale =koha  (SgAll  >selle+koha !17_S	et	f	\N
135285	sellekohale	sellekohale =koha  (SgAll  >selle+koht !22_S	et	f	\N
135292	kohandatavaid	kohandatavaid =kohandatava  (PlP  >kohandatav !02_A	et	f	\N
135293	kohandatavaid	"kohandatav %kohanda  )TAV_vAS  <kohandama ;27_V	et	f	\N
135311	vöö	vöö =vöö  (SgN  >vöö !26_S	et	f	\N
135312	vöö	vöö =vöö  (SgG  >vöö !26_S	et	f	\N
135334	töötajal	töötajal =töötaja  (SgAd  >töötaja !01_S	et	f	\N
135335	töötajal	"töötaja %tööta  )JA_vS  <töötama ;27_V	et	f	\N
135341	istuval	istuval =istuva  (SgAd  >istuv !02_A	et	f	\N
135342	istuval	"istuv %istu  )V_vA  <istuma ;28_V	et	f	\N
135362	tavabüroo	tavabüroo =büroo  (SgN  >tava+büroo !26_S	et	f	\N
135363	tavabüroo	tavabüroo =büroo  (SgG  >tava+büroo !26_S	et	f	\N
135396	frikartul	?frikartul =frikartu  (SgAd  >frikartu !01_S	et	f	\N
135415	krõpsusalat	?krõpsusalat =krõpsusala  (SgP  >krõpsusala !01_S	et	f	\N
135416	rosolje	rosolje =rosolje  (SgN  >rosolje !16_S	et	f	\N
135417	rosolje	rosolje =rosolje  (SgG  >rosolje !16_S	et	f	\N
135418	prae	prae =prae  (SgG  >praad !22_S	et	f	\N
135419	prae	prae =prae  (IndPrPs_  >praadima !28_V	et	f	\N
135420	prae	prae =prae  (ImpPrSg2  >praadima !28_V	et	f	\N
135443	beami	?beami =beami  (SgN  >beami !16_S	et	f	\N
135444	beami	?beami =beami  (SgG  >beami !16_S	et	f	\N
135445	beami	?beami =beami  (SgG  >beam !22_S	et	f	\N
135446	beami	?beami =beami  (SgP  >beam !22_S	et	f	\N
135447	beami	?beami =beami  (SgAdt  >beam !22_S	et	f	\N
135448	beami	?beami =beami  (IndPrPs_  >beamima !28_V	et	f	\N
135449	beami	?beami =beami  (ImpPrSg2  >beamima !28_V	et	f	\N
135453	hottellis	?hottellis =hottelli  (SgIn  >hottelli !01_S	et	f	\N
135454	hottellis	?hottellis =hottelli  (SgIn  >hottell !22_S	et	f	\N
135455	hottellis	?hottellis =hottelli  (IndIpfSg3  >hottellima !28_V	et	f	\N
135456	hottellis	?hottellis =hottellis  (SgN  >hottellis !11_S	et	f	\N
135476	komvikuid	?komvikuid =komviku  (PlP  >komviku !01_S	et	f	\N
135477	komvikuid	?komvikuid =komviku  (PlP  >komvik !02_S	et	f	\N
135478	komvikuid	?komvikuid =komvikui  (PlN  >komvikui !26_S	et	f	\N
135479	komvikuid	?komvikuid =komvikui  (SgP  >komvikui !26_S	et	f	\N
135480	komvikuid	?komvikuid =vikui  (PlN  >kom+vikui !26_S	et	f	\N
135481	komvikuid	?komvikuid =vikui  (SgP  >kom+vikui !26_S	et	f	\N
135482	komvikuid	?komvikuid =vikuid  (SgN  >kom+vikuid !22_S	et	f	\N
135487	jaätis	?jaätis =jaät  (IndIpfSg3  >jaätma !34_V	et	f	\N
135488	jaätis	?jaätis =jaäti  (IndIpfSg3  >jaätima !28_V	et	f	\N
135489	jaätis	?jaätis =jaätis  (SgN  >jaätis !11~09_S	et	f	\N
135496	sealiha	sealiha =iha  (SgN  >seal+iha !17_S	et	f	\N
135498	sealiha	sealiha =iha  (SgG  >seal+iha !17_S	et	f	\N
135499	sealiha	sealiha =iha  (SgP  >seal+iha !17_S	et	f	\N
135500	sealiha	sealiha =liha  (SgN  >sea+liha !17_S	et	f	\N
135501	sealiha	sealiha =liha  (SgG  >sea+liha !17_S	et	f	\N
135502	sealiha	sealiha =liha  (SgP  >sea+liha !17_S	et	f	\N
135509	petri	?petri =petri  (ID  >petri !41_D	et	f	\N
135510	petri	?petri =petri  (SgG  >petter !02_S	et	f	\N
135514	menüüd	menüüd =menüü  (PlN  >menüü !26_S	et	f	\N
135515	menüüd	menüüd =menüü  (SgP  >menüü !26_S	et	f	\N
135526	pizz	### pizz	et	f	\N
135528	õuna	õuna =õu  (SgEs  >õud !22_S	et	f	\N
135531	õuna	õuna =õuna  (SgG  >õun !23?22_S	et	f	\N
135534	õuna	õuna =õuna  (SgP  >õun !23?22_S	et	f	\N
135535	õuna	õuna =õuna  (SgAdt  >õun !23?22_S	et	f	\N
135539	restoreni	?restoreni =restoreni  (SgG  >restoren !19_S	et	f	\N
135540	restoreni	?restoreni =restoreni  (SgP  >restoren !19_S	et	f	\N
135541	restoreni	?restoreni =restoreni  (SgAdt  >restoren !19_S	et	f	\N
135549	roogi	roogi =roogi  (SgG  >roog !22_S	et	f	\N
135550	roogi	roogi =roogi  (SgP  >roog !22_S	et	f	\N
135551	roogi	roogi =roogi  (SgAdt  >roog !22_S	et	f	\N
135552	roogi	roogi =roogi  (PlP  >roog !22_S	et	f	\N
135553	roogi	roogi =roogi  (IndPrPs_  >rookima !28_V	et	f	\N
135554	roogi	roogi =roogi  (ImpPrSg2  >rookima !28_V	et	f	\N
135555	roogi	roogi =roo  (SgN^  >roo !26_S	et	f	\N
135556	roogi	roogi =roo  (SgG^  >rood !22_S	et	f	\N
135559	roogi	roogi =roo  (SgG^  >roog !22_S	et	f	\N
135560	roogi	roogi =roo  (SgG^  >roo !26_S	et	f	\N
135566	premier	?premier =premier  (SgN  >premier !19_S	et	f	\N
135567	premier	?premier =mier  (SgN  >pre+mier !22_S	et	f	\N
135578	kãi	### kãi	et	f	\N
135584	mity	### mity	et	f	\N
135591	sããmas	### sããmas	et	f	\N
135615	kolliasjadest	?kolliasjadest =kolliasja  (PlEl  >kolliasja !16_S	et	f	\N
135616	kolliasjadest	?kolliasjadest =kolliasjades  (SgP  >kolliasjadene !12_A	et	f	\N
135621	kaisime	?kaisime =kaisi  (IndPrPl1  >kaisima !28_V	et	f	\N
135628	same	?same =same  (SgN  >same !16_S	et	f	\N
135629	same	?same =same  (SgG  >same !16_S	et	f	\N
135630	same	?same =same  (IndPrPs_  >samema !27_V	et	f	\N
135631	same	?same =same  (ImpPrSg2  >samema !27_V	et	f	\N
135636	sõpratega	### sõpratega	et	f	\N
135281	kulusid	kulusid =kulu  (IndIpfPl3  >kuluma !27_V	et	f	\N
135290	kohandatavad	kohandatavad =kohandatava  (PlN  >kohandatav !02_A	et	f	\N
135291	kohandatavad	"kohandatav %kohanda  )TAV_vAS  <kohandama ;27_V	et	f	\N
135313	15-20cm	### 15-20cm	et	f	\N
135343	täitmiseks	täitmiseks =täitmise  (SgTr  >täitmine !12?10_S	et	f	\N
135344	täitmiseks	"täitmine %täit  )MINE_vS  <täitma ;34_V	et	f	\N
135388	seljanka	seljanka =seljanka  (SgN  >seljanka !16_S	et	f	\N
135389	seljanka	seljanka =seljanka  (SgG  >seljanka !16_S	et	f	\N
135392	lõhe	lõhe =lõhe  (SgN  >lõhe !16_S	et	f	\N
135393	lõhe	lõhe =lõhe  (SgG  >lõhe !16_S	et	f	\N
135394	lõhe	lõhe =lõhe  (SgG  >lõhi !20_S	et	f	\N
135395	lõhe	lõhe =lõhe  (SgP  >lõhi !20_S	et	f	\N
135421	magustoitu	magustoitu =toitu  (SgN  >magus+toitu !01_A	et	f	\N
135422	magustoitu	"magus+toitu %toi  )TU2_kA  <magus+toi ;26_S	et	f	\N
135423	magustoitu	magustoitu =toitu  (SgG  >magus+toitu !01_A	et	f	\N
135424	magustoitu	magustoitu =toitu  (SgP  >magus+toit !22_S	et	f	\N
135425	magustoitu	magustoitu =toitu  (SgAdt  >magus+toit !22_S	et	f	\N
135442	jeam	?jeam =jeam  (SgN  >jeam !22_S	et	f	\N
135452	juustueskalop	### juustueskalop	et	f	\N
135483	martini	?martini =martini  (SgG  >martin !02_S	et	f	\N
135516	piza	?piza =piza  (SgN  >piza !17_S	et	f	\N
135517	piza	?piza =piza  (SgG  >piza !17_S	et	f	\N
135518	piza	?piza =piza  (SgP  >piza !17_S	et	f	\N
135519	piza	?piza =piza  (IndPrPs_  >pizama !27_V	et	f	\N
135520	piza	?piza =piza  (ImpPrSg2  >pizama !27_V	et	f	\N
135530	vinamarja	?vinamarja =vinamarja  (SgN  >vinamarja !16_S	et	f	\N
135533	vinamarja	?vinamarja =vinamarja  (SgG  >vinamarjas !02_A	et	f	\N
135536	vinamarja	?vinamarja =vinamarja  (SgG  >vinamarja !16_S	et	f	\N
135575	küslaugu	?küslaugu =küslaugu  (IndPrPs_  >küslauguma !27_V	et	f	\N
135576	küslaugu	?küslaugu =küslaugu  (ImpPrSg2  >küslauguma !27_V	et	f	\N
135580	kutsehariduskeskuses	kutsehariduskeskuses =use  (PlIn  >kutse+haridus+kesk+usk !22_S	et	f	\N
135581	kutsehariduskeskuses	kutsehariduskeskuses =keskuse  (SgIn  >kutse+haridus+keskus !11~09_S	et	f	\N
135587	kãia	### kãia	et	f	\N
135588	kursusekaaslastega	kursusekaaslastega =las  (PlKom  >kursuse+kaas+laps !14_S	et	f	\N
135589	kursusekaaslastega	kursusekaaslastega =kaaslas  (PlKom  >kursuse+kaaslane !12?10_S	et	f	\N
135593	vãµi	### vãµi	et	f	\N
135595	kodune	kodune =kodune  (SgN  >kodune !10_A	et	f	\N
135596	kodune	"kodune %kodu  )NE_aA  <kodu ;17_S	et	f	\N
135597	kodune	kodune =kodune  (IndPrPs_  >kodunema !27_V	et	f	\N
135598	kodune	kodune =kodune  (ImpPrSg2  >kodunema !27_V	et	f	\N
135599	vãga	### vãga	et	f	\N
135604	maitsva	maitsva =maitsva  (SgG  >maitsev !02_A	et	f	\N
135605	maitsva	"maitsev %maits  )V_vA  <maitsma ;32_V	et	f	\N
135606	maitsva	"maitsev %maitse  )V_vA  <maitsema ;28_V	et	f	\N
135619	heamulje	heamulje =mulje  (SgN  >hea+mulje !06_S	et	f	\N
135620	heamulje	heamulje =mulje  (SgG  >hea+mulje !06_S	et	f	\N
135642	moonika	?moonika =moonika  (SgN  >moonika !01_S	et	f	\N
135643	moonika	?moonika =moonika  (SgG  >moonika !01_S	et	f	\N
135644	moonika	?moonika =moonika  (SgG  >moonikas !02_S	et	f	\N
135647	mikro	?mikro =mikro  (SgN  >mikro !16_S	et	f	\N
135648	mikro	?mikro =mikro  (SgG  >mikro !16_S	et	f	\N
135666	kievi	?kievi =kievi  (SgN  >kievi !16_S	et	f	\N
135667	kievi	?kievi =kievi  (SgG  >kievi !16_S	et	f	\N
135669	kievi	?kievi =kievi  (SgG  >kiev !22_S	et	f	\N
135670	kievi	?kievi =kievi  (SgP  >kiev !22_S	et	f	\N
135671	kievi	?kievi =kievi  (SgAdt  >kiev !22_S	et	f	\N
135672	kievi	?kievi =kievi  (IndPrPs_  >kievima !28_V	et	f	\N
135673	kievi	?kievi =kievi  (ImpPrSg2  >kievima !28_V	et	f	\N
135681	puuvilja	puuvilja =vilja  (SgG  >puu+vili !24_S	et	f	\N
135682	puuvilja	puuvilja =vilja  (SgP  >puu+vili !24_S	et	f	\N
135683	puuvilja	puuvilja =vilja  (SgAdt  >puu+vili !24_S	et	f	\N
135692	hr	### hr	et	f	\N
135693	lev	### lev	et	f	\N
135694	tolstoi	?tolstoi =tolstoi  (SgN  >tolstoi !26_S	et	f	\N
135695	tolstoi	?tolstoi =tolstoi  (SgG  >tolstoi !26_S	et	f	\N
135700	management	?management =management  (SgN  >management !22_S	et	f	\N
135701	management	?management =gement  (SgN  >mana+gement !22_S	et	f	\N
135702	cicbrevers	?cicbrevers =cicbrevers  (SgN  >cicbrevers !22_S	et	f	\N
135727	saadav	saadav =saa  (PtsPrIps  >saama !37_V	et	f	\N
135728	saadav	saadav =saadav  (SgN  >saadav !02_A	et	f	\N
135729	saadav	"saadav %saa  )TAV_vAS  <saama ;37_V	et	f	\N
135769	viiralti	viiralti =alti  (SgG  >viir+aldis !07_A	et	f	\N
135770	viiralti	viiralti =alti  (SgP  >viir+alt !22_S	et	f	\N
135771	viiralti	viiralti =alti  (SgAdt  >viir+alt !22_S	et	f	\N
135772	eduart	?eduart =eduart  (SgN  >eduart !22_S	et	f	\N
135773	eduart	?eduart =art  (SgN  >edu+art !22_S	et	f	\N
135774	ündinud	?ündinud =ündi  (PtsPtPs  >ündima !28_V	et	f	\N
135775	ündinud	?ündinud =ündinu  (PlN  >ündinu !01_S	et	f	\N
135776	ündinud	?ündinud =ündinu  (IndPrSg2  >ündinuma !27_V	et	f	\N
135777	ündinud	?ündinud =ündinud  (ID  >ündinud !41_A	et	f	\N
135798	havata	?havata =hava  (SgAb  >hava !17_S	et	f	\N
135295	töötajale	"töötaja %tööta  )JA_vS  <töötama ;27_V	et	f	\N
135314	kõrgusel	kõrgusel =kõrguse  (SgAd  >kõrgus !11~09_S	et	f	\N
135315	kõrgusel	"kõrgus %kõrge  )US_aS  <kõrge ;01_A	et	f	\N
135316	kõrgusel	kõrgusel =kõrguse  (SgAd  >kõrgune !10~12_A	et	f	\N
135317	kõrgusel	kõrgusel =use  (PlAd  >kõrg+usk !22_S	et	f	\N
135318	pinnast	pinnast =pinna  (SgEl  >pind !22_S	et	f	\N
135319	pinnast	pinnast =pinnas  (SgP  >pinnas !09_S	et	f	\N
135320	pinnast	pinnast =pinnas  (SgP  >pinnane !10_A	et	f	\N
135321	pinnast	"pinnane %pinna  )NE_aA  <pind ;22_S	et	f	\N
135336	istumise	istumise =istumise  (SgG  >istumine !12_S	et	f	\N
135337	istumise	"istumine %istu  )MINE_vS  <istuma ;28_V	et	f	\N
135345	väsimust	väsimust =väsimus  (SgP  >väsimus !11_S	et	f	\N
135346	väsimust	"väsimus %väsi  )MUS_vS  <väsima ;27_V	et	f	\N
135352	pisikesekasvulised	?pisikesekasvulised =pisikesekasvulise  (PlN  >pisikesekasvuline !12_A	et	f	\N
135356	helehall	helehall =hall  (SgN  >hele+hall !22_S	et	f	\N
135357	helehall	helehall =hall  (SgN  >hele+hall !22_AS	et	f	\N
135358	ruumides	ruumides =ruumi  (PlIn  >ruum !22_S	et	f	\N
135359	ruumides	ruumides =ruumi  (Ger  >ruumima !28_V	et	f	\N
135364	pastelsemad	pastelsemad =pastelsema  (PlN  >pastelsem !02_A	et	f	\N
135365	pastelsemad	"pastelsem %pastelse  )M_cA  <pastelne ;02_A	et	f	\N
135366	õeldakse	?õeldakse =õeldakse  (SgG  >õeldakne !02_A	et	f	\N
135372	chip	### chip	et	f	\N
135382	privadis	?privadis =privadi  (SgIn  >privadi !01_S	et	f	\N
135383	privadis	?privadis =privadis  (SgN  >privadis !11_S	et	f	\N
135391	kodukotled	### kodukotled	et	f	\N
135397	magustoid	magustoid =toi  (PlN  >magus+toi !26_S	et	f	\N
135398	magustoid	magustoid =toi  (SgP  >magus+toi !26_S	et	f	\N
135402	koogid	koogid =koogi  (PlN  >kook !22_S	et	f	\N
135403	koogid	koogid =koogi  (IndPrSg2  >kookima !28_V	et	f	\N
135406	kakao	kakao =kakao  (SgN  >kakao !26_S	et	f	\N
135407	kakao	kakao =kakao  (SgG  >kakao !26_S	et	f	\N
135408	mineraalvesi	mineraalvesi =vesi  (SgN  >mineraal+vesi !15_S	et	f	\N
135409	mineraalvesi	mineraalvesi =vesi  (PlP  >mineraal+vesi !15_S	et	f	\N
135413	aramiskoolaga	aramiskoolaga =koola  (SgKom  >ara+mis+koola !16_S	et	f	\N
135414	aramiskoolaga	aramiskoolaga =koola  (SgKom  >ara+mis+kool !22_S	et	f	\N
135433	friikartulidega	### friikartulidega	et	f	\N
135458	veini	veini =veini  (SgG  >vein !22_S	et	f	\N
135459	veini	veini =veini  (SgP  >vein !22_S	et	f	\N
135460	veini	veini =veini  (SgAdt  >vein !22_S	et	f	\N
135471	keedetud	keedetud =keede  (PtsPtIps  >keetma !34_V	et	f	\N
135472	keedetud	keedetud =keedetu  (PlN  >keedetu !01_AS	et	f	\N
135473	keedetud	"keedetu %keede  )TU1_vS  <keetma ;34_V	et	f	\N
135474	keedetud	keedetud =keedetud  (ID  >keedetud !41_A	et	f	\N
135475	keedetud	"keedetud %keede  )TUD_vA  <keetma ;34_V	et	f	\N
135484	joovad	joovad =joo  (IndPrPl3  >jooma !38_V	et	f	\N
135485	joovad	joovad =joova  (PlN  >joov !02_A	et	f	\N
135486	joovad	"joov %joo  )V_vA  <jooma ;38_V	et	f	\N
135494	kanaliha	kanaliha =liha  (SgN  >kana+liha !17_S	et	f	\N
135495	kanaliha	kanaliha =liha  (SgG  >kana+liha !17_S	et	f	\N
135497	kanaliha	kanaliha =liha  (SgP  >kana+liha !17_S	et	f	\N
135503	baris	?baris =bari  (SgIn  >bari !17_S	et	f	\N
135504	baris	?baris =bari  (IndIpfSg3  >barima !27_V	et	f	\N
135505	baris	?baris =baris  (SgN  >baris !09_S	et	f	\N
135507	magustoite	magustoite =toite  (SgG  >magus+toide !06_S	et	f	\N
135508	magustoite	magustoite =toite  (PlP  >magus+toit !22_S	et	f	\N
135537	vanili	?vanili =vanili  (ID  >vanili !41_D	et	f	\N
135577	sããgikohad	### sããgikohad	et	f	\N
135586	sãµpratega	### sãµpratega	et	f	\N
135592	vãµãµrastega	### vãµãµrastega	et	f	\N
135601	loomaliha	loomaliha =liha  (SgN  >looma+liha !17_S	et	f	\N
135602	loomaliha	loomaliha =liha  (SgG  >looma+liha !17_S	et	f	\N
135603	loomaliha	loomaliha =liha  (SgP  >looma+liha !17_S	et	f	\N
135607	vãµib	### vãµib	et	f	\N
135608	saiakesi	saiakesi =saiakesi  (PlP  >saiake !12_S	et	f	\N
135609	saiakesi	"saiake %saia  )KE_dS  <sai ;22_S	et	f	\N
135610	saiakesi	saiakesi =saiakesi  (PlP  >saiakene !12_S	et	f	\N
135611	saiakesi	"saiakene %saia  )KENE_dS  <sai ;22_S	et	f	\N
135632	söögikohad	söögikohad =koha  (PlN  >söögi+koha !17_S	et	f	\N
135633	söögikohad	söögikohad =koha  (PlN  >söögi+koht !22_S	et	f	\N
135634	trilobit	?trilobit =trilobi  (SgP  >trilobi !01_S	et	f	\N
135635	trilobit	?trilobit =trilobi  (SgP  >trilob !02_S	et	f	\N
135660	praed	praed =prae  (PlN  >praad !22_S	et	f	\N
135661	praed	praed =prae  (IndPrSg2  >praadima !28_V	et	f	\N
135676	püree	püree =püree  (SgN  >püree !26_S	et	f	\N
135677	püree	püree =püree  (SgG  >püree !26_S	et	f	\N
135684	tortid	### tortid	et	f	\N
135705	poognega	### poognega	et	f	\N
135739	jutub	?jutub =jutu  (IndPrSg3  >jutuma !27_V	et	f	\N
135752	piisavaid	piisavaid =piisava  (PlP  >piisav !02_A	et	f	\N
135753	piisavaid	"piisav %piisa  )V_vA  <piisama ;29_V	et	f	\N
135754	minumoodi	minumoodi =moodi  (SgP  >minu+mood !22_S	et	f	\N
135296	kõrgusega	kõrgusega =kõrguse  (SgKom  >kõrgus !11~09_S	et	f	\N
135298	kõrgusega	"kõrgus %kõrge  )US_aS  <kõrge ;01_A	et	f	\N
135299	kõrgusega	kõrgusega =kõrguse  (SgKom  >kõrgune !10~12_A	et	f	\N
135302	kõrguste	kõrguste =kõrgus  (PlG  >kõrgus !11~09_S	et	f	\N
135303	kõrguste	"kõrgus %kõrge  )US_aS  <kõrge ;01_A	et	f	\N
135304	kõrguste	kõrguste =kõrgus  (PlG  >kõrgune !10~12_A	et	f	\N
135305	kõrguste	kõrguste =us  (PlG  >kõrg+uks !14_S	et	f	\N
135306	polsterdatud	polsterdatud =polsterda  (PtsPtIps  >polsterdama !27_V	et	f	\N
135307	polsterdatud	polsterdatud =polsterdatu  (PlN  >polsterdatu !01_S	et	f	\N
135308	polsterdatud	"polsterdatu %polsterda  )TU1_vS  <polsterdama ;27_V	et	f	\N
135309	polsterdatud	polsterdatud =polsterdatud  (ID  >polsterdatud !41_A	et	f	\N
135310	polsterdatud	"polsterdatud %polsterda  )TUD_vA  <polsterdama ;27_V	et	f	\N
135322	seljatugi	seljatugi =tugi  (SgN  >selja+tugi !21_S	et	f	\N
135323	seljatugi	seljatugi =seljatu  (SgN^  >seljatu !01_AS	et	f	\N
135324	seljatugi	"seljatu %selja  )TU2_kA^  <selg ;22_S	et	f	\N
135325	seljatugi	seljatugi =seljatu  (SgG^  >seljatu !01_AS	et	f	\N
135329	kaldumise	kaldumise =kaldumise  (SgG  >kaldumine !12_S	et	f	\N
135330	kaldumise	"kaldumine %kaldu  )MINE_vS  <kalduma ;27_V	et	f	\N
135338	liikuvus	liikuvus =liikuvus  (SgN  >liikuvus !11_S	et	f	\N
135339	liikuvus	"liikuvus %liiku  )VUS_aS  <liikuma ;28_V	et	f	\N
135340	liikuvus	"liikuvus %liikuva  )US_aS  <liikuv ;02_A	et	f	\N
135350	alaselga	alaselga =selga  (SgP  >ala+selg !22_S	et	f	\N
135351	alaselga	alaselga =selga  (SgAdt  >ala+selg !22_S	et	f	\N
135373	computer	?computer =computer  (SgN  >computer !19_S	et	f	\N
135377	haid	haid =hai  (PlN  >hai !26_S	et	f	\N
135378	haid	haid =hai  (SgP  >hai !26_S	et	f	\N
135387	kartilisalat	?kartilisalat =kartilisala  (SgP  >kartilisala !01_S	et	f	\N
135399	puvilja	?puvilja =puvilja  (SgN  >puvilja !16_S	et	f	\N
135400	puvilja	?puvilja =puvilja  (SgG  >puviljas !02_A	et	f	\N
135401	puvilja	?puvilja =puvilja  (SgG  >puvilja !16_S	et	f	\N
135404	kuumad	kuumad =kuuma  (PlN  >kuum !22_AS	et	f	\N
135405	kuumad	kuumad =kuuma  (IndPrSg2  >kuumama !29_V	et	f	\N
135410	viski	viski =viski  (SgN  >viski !16_S	et	f	\N
135411	viski	viski =viski  (SgG  >viski !16_S	et	f	\N
135426	evestis	?evestis =evesti  (IndIpfSg3  >evestima !28_V	et	f	\N
135427	evestis	?evestis =evestis  (SgN  >evestis !11_S	et	f	\N
135430	20-kümne	-kümne =kümne  (SgG  >-kümmend !05_N	et	f	\N
135431	20-kümne	-kümne =kümne  (SgG  >-kümme !05_N	et	f	\N
135432	kraabisalat	?kraabisalat =kraabisala  (SgP  >kraabisala !01_S	et	f	\N
135450	valmistasid	valmistasid =valmista  (IndIpfSg2  >valmistama !27_V	et	f	\N
135451	valmistasid	valmistasid =valmista  (IndIpfPl3  >valmistama !27_V	et	f	\N
135461	restoraanis	?restoraanis =restoraani  (SgIn  >restoraani !16_S	et	f	\N
135462	restoraanis	?restoraanis =restoraani  (SgIn  >restoraan !22_S	et	f	\N
135463	restoraanis	?restoraanis =restoraani  (IndIpfSg3  >restoraanima !28_V	et	f	\N
135464	restoraanis	?restoraanis =restoraanis  (SgN  >restoraanis !09_S	et	f	\N
135465	praetud	praetud =prae  (PtsPtIps  >praadima !28_V	et	f	\N
135466	praetud	praetud =praetu  (PlN  >praetu !01_SA	et	f	\N
135467	praetud	"praetu %prae  )TU1_vS  <praadima ;28_V	et	f	\N
135468	praetud	"praetu %prae  )TU2_kA  <praad ;22_S	et	f	\N
135469	praetud	praetud =praetud  (ID  >praetud !41_A	et	f	\N
135470	praetud	"praetud %prae  )TUD_vA  <praadima ;28_V	et	f	\N
135511	pizas	?pizas =piza  (SgIn  >piza !17_S	et	f	\N
135512	pizas	?pizas =piza  (IndIpfSg3  >pizama !27_V	et	f	\N
135513	pizas	?pizas =pizas  (SgN  >pizas !09_S	et	f	\N
135525	teined	?teined =teine  (IndPrSg2  >teinema !27_V	et	f	\N
135527	apelsini	apelsini =apelsini  (SgG  >apelsin !19_S	et	f	\N
135529	apelsini	apelsini =apelsini  (SgP  >apelsin !19_S	et	f	\N
135532	apelsini	apelsini =apelsini  (SgAdt  >apelsin !19_S	et	f	\N
135538	ananasiga	### ananasiga	et	f	\N
135544	pakkutakse	?pakkutakse =pakkutakse  (SgG  >pakkutakne !02_A	et	f	\N
135545	pakkutakse	?pakkutakse =pakkutakse  (PlP  >pakkutaks !22_S	et	f	\N
135546	huvutavaid	?huvutavaid =huvutava  (PlP  >huvutav !02_A	et	f	\N
135547	huvutavaid	?huvutavaid =huvutavai  (PlN  >huvutavai !26_S	et	f	\N
135548	huvutavaid	?huvutavaid =huvutavai  (SgP  >huvutavai !26_S	et	f	\N
135557	punases	punases =punase  (SgIn  >punane !10_AS	et	f	\N
135558	punases	"punane %puna  )NE_aA  <puna ;17_S	et	f	\N
135585	kãinud	### kãinud	et	f	\N
135637	võõrastega	võõrastega =võõras  (PlKom  >võõras !07_AS	et	f	\N
135638	võõrastega	võõrastega =aste  (SgKom  >võõr+aste !06_S	et	f	\N
135662	uhha	?uhha =uhha  (SgN  >uhha !16_S	et	f	\N
135663	uhha	?uhha =uhha  (SgG  >uhha !16_S	et	f	\N
135664	uhha	?uhha =uhha  (IndPrPs_  >uhhama !29_V	et	f	\N
135665	uhha	?uhha =uhha  (ImpPrSg2  >uhhama !29_V	et	f	\N
135668	kotlett	?kotlett =kotlett  (SgN  >kotlett !22_S	et	f	\N
135696	rahvusvahelisse	rahvusvahelisse =vahelis  (SgAdt  >rahvus+vaheline !12_A	et	f	\N
135697	rahvusvahelisse	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
135698	cec	### cec	et	f	\N
135703	räkkida	?räkkida =räkki  (Inf  >räkkima !28_V	et	f	\N
135562	taines	?taines =taine  (IndIpfSg3  >tainema !27_V	et	f	\N
135563	taines	?taines =taines  (SgN  >taines !09_S	et	f	\N
135564	värviline	värviline =värviline  (SgN  >värviline !12_A	et	f	\N
135565	värviline	"värviline %värvi  )LINE_aA  <värv ;22_S	et	f	\N
135568	wiroonia	?wiroonia =wiroonia  (SgN  >wiroonia !01_S	et	f	\N
135569	wiroonia	?wiroonia =wiroonia  (SgG  >wiroonia !01_S	et	f	\N
135570	ebameeldivu	?ebameeldivu =ebameeldivu  (IndPrPs_  >ebameeldivuma !27_V	et	f	\N
135571	ebameeldivu	?ebameeldivu =ebameeldivu  (ImpPrSg2  >ebameeldivuma !27_V	et	f	\N
135572	ebameeldivu	?ebameeldivu =meeldivu  (SgN  >eba+meeldivu !01_S	et	f	\N
135573	ebameeldivu	?ebameeldivu =meeldivu  (SgG  >eba+meeldivu !01_S	et	f	\N
135574	krevettid	?krevettid =krevetti  (PlN  >krevetti !01_S	et	f	\N
135579	ãµpin	### ãµpin	et	f	\N
135582	sããn	### sããn	et	f	\N
135583	lãµunad	### lãµunad	et	f	\N
135590	vãljas	### vãljas	et	f	\N
135594	interjããr	### interjããr	et	f	\N
135600	nãiteks	### nãiteks	et	f	\N
135612	kohtusime	kohtusime =kohtu  (IndIpfPl1  >kohtuma !27_V	et	f	\N
135613	kohtusime	kohtusime =ime  (SgN  >kohtus+ime !16_S	et	f	\N
135614	kohtusime	kohtusime =ime  (SgG  >kohtus+ime !16_S	et	f	\N
135617	jattis	?jattis =jatti  (IndIpfSg3  >jattima !28_V	et	f	\N
135618	jattis	?jattis =jattis  (ID  >jattis !41_DA	et	f	\N
135622	paegu	?paegu =paegu  (SgN  >paegu !16_S	et	f	\N
135623	paegu	?paegu =paegu  (SgG  >paegu !16_S	et	f	\N
135624	paegu	?paegu =paegu  (IndPrPs_  >paeguma !27_V	et	f	\N
135625	paegu	?paegu =paegu  (IndPrPs_  >paekuma !28_V	et	f	\N
135626	paegu	?paegu =paegu  (ImpPrSg2  >paeguma !27_V	et	f	\N
135627	paegu	?paegu =paegu  (ImpPrSg2  >paekuma !28_V	et	f	\N
135639	kohvikusse	kohvikusse =kohviku  (SgIll  >kohvik !02_S	et	f	\N
135640	kohvikusse	kohvikusse =usse  (PlP  >kohvik+uss !22_S	et	f	\N
135641	kohvikusse	kohvikusse =kusse  (SgAdt  >kohvi+kusi !20_S	et	f	\N
135649	alexi	?alexi =alexi  (SgN  >alexi !01_S	et	f	\N
135650	alexi	?alexi =alexi  (SgG  >alexi !01_S	et	f	\N
135654	võõrasega	?võõrasega =võõrase  (SgKom  >võõrane !10_A	et	f	\N
135655	võõrasega	?võõrasega =sega  (SgN  >võõra+sega !17_S	et	f	\N
135656	võõrasega	?võõrasega =sega  (SgG  >võõra+sega !17_S	et	f	\N
135657	võõrasega	?võõrasega =sega  (SgP  >võõra+sega !17_S	et	f	\N
135658	menüü	menüü =menüü  (SgN  >menüü !26_S	et	f	\N
135659	menüü	menüü =menüü  (SgG  >menüü !26_S	et	f	\N
135674	frii	?frii =frii  (SgN  >frii !26_S	et	f	\N
135675	frii	?frii =frii  (SgG  >frii !26_S	et	f	\N
135704	kegi	?kegi =kegi  (SgN  >kegi !17_S	et	f	\N
135706	kegi	?kegi =kegi  (SgG  >kegi !17_S	et	f	\N
135707	kegi	?kegi =kegi  (SgP  >kegi !17_S	et	f	\N
135708	kegi	?kegi =kegi  (IndPrPs_  >kegima !27_V	et	f	\N
135709	kegi	?kegi =kegi  (ImpPrSg2  >kegima !27_V	et	f	\N
135710	pilli	pilli =pilli  (SgG  >pill !22_S	et	f	\N
135711	pilli	pilli =pilli  (SgP  >pill !22_S	et	f	\N
135712	pilli	pilli =pilli  (SgAdt  >pill !22_S	et	f	\N
135713	pilli	pilli =pilli  (IndPrPs_  >pillima !28_V	et	f	\N
135714	pilli	pilli =pilli  (ImpPrSg2  >pillima !28_V	et	f	\N
135722	bassivõimu	bassivõimu =võimu  (SgG  >bassi+võim !22_S	et	f	\N
135723	bassivõimu	bassivõimu =võimu  (SgP  >bassi+võim !22_S	et	f	\N
135724	bassivõimu	bassivõimu =võimu  (SgAdt  >bassi+võim !22_S	et	f	\N
135731	pääse	pääse =pääse  (SgN  >pääse !05_S	et	f	\N
135732	pääse	pääse =pääse  (SgN  >pääse !06_S	et	f	\N
135733	pääse	pääse =pääse  (SgG  >pääse !06_S	et	f	\N
135734	pääse	pääse =pääse  (PlP  >pääs !22_S	et	f	\N
135735	pääse	pääse =pääse  (IndPrPs_  >pääsema !28_V	et	f	\N
135736	pääse	pääse =pääse  (ImpPrSg2  >pääsema !28_V	et	f	\N
135740	elmises	?elmises =elmise  (SgIn  >elmine !10_A	et	f	\N
135741	elmises	?elmises =elmise  (IndIpfSg3  >elmisema !27_V	et	f	\N
135756	alalpool	alalpool =pool  (ID  >alal+pool !41_DK	et	f	\N
135757	alalpool	alalpool =pool  (SgN  >alal+pool !13_NS	et	f	\N
135758	alalpool	alalpool =pool  (SgN  >alal+pool !22_S	et	f	\N
135759	masinasid	### masinasid	et	f	\N
135760	vessu	?vessu =vessu  (SgN  >vessu !16_S	et	f	\N
135761	vessu	?vessu =vessu  (SgG  >vessu !16_S	et	f	\N
135762	vessu	?vessu =vessu  (IndPrPs_  >vessuma !27_V	et	f	\N
135763	vessu	?vessu =vessu  (ImpPrSg2  >vessuma !27_V	et	f	\N
135767	sõltu	sõltu =sõltu  (IndPrPs_  >sõltuma !27_V	et	f	\N
135768	sõltu	sõltu =sõltu  (ImpPrSg2  >sõltuma !27_V	et	f	\N
135792	vababadussõjas	?vababadussõjas =vababadussõja  (SgIn  >vababadussõjas !02_A	et	f	\N
135793	vababadussõjas	?vababadussõjas =vababadussõja  (SgIn  >vababadussõja !16_S	et	f	\N
135794	vababadussõjas	?vababadussõjas =vababadussõjas  (SgN  >vababadussõjas !02_A	et	f	\N
135795	vababadussõjas	?vababadussõjas =badussõja  (SgIn  >vaba+badussõjas !02_A	et	f	\N
135796	vababadussõjas	?vababadussõjas =badussõja  (SgIn  >vaba+badussõja !16_S	et	f	\N
135797	vababadussõjas	?vababadussõjas =badussõjas  (SgN  >vaba+badussõjas !02_A	et	f	\N
135809	lemmikala	lemmikala =ala  (SgN  >lemmik+ala !17_S	et	f	\N
135645	neptuni	?neptuni =neptu  (SgTer  >neptu !16_S	et	f	\N
135646	neptuni	?neptuni =neptuni  (SgG  >neptun !02_S	et	f	\N
135651	sööklasse	sööklasse =söökla  (SgIll  >söökla !01_S	et	f	\N
135652	sööklasse	sööklasse =sööklas  (SgAdt  >sööklane !12_S	et	f	\N
135653	sööklasse	"sööklane %söökla  )NE_aA  <söökla ;01_S	et	f	\N
135678	kapsa	kapsa =kapsa  (SgG  >kapsas !07_S	et	f	\N
135679	kapsa	kapsa =kapsa  (IndPrPs_  >kapsama !29_V	et	f	\N
135680	kapsa	kapsa =kapsa  (ImpPrSg2  >kapsama !29_V	et	f	\N
135685	taotlus	taotlus =taotlus  (SgN  >taotlus !11~09_S	et	f	\N
135686	taotlus	"taotlus %taotle  )US_vS  <taotlema ;27_V	et	f	\N
135687	kiirendatud	kiirendatud =kiirenda  (PtsPtIps  >kiirendama !27_V	et	f	\N
135688	kiirendatud	kiirendatud =kiirendatu  (PlN  >kiirendatu !01_S	et	f	\N
135689	kiirendatud	"kiirendatu %kiirenda  )TU1_vS  <kiirendama ;27_V	et	f	\N
135690	kiirendatud	kiirendatud =kiirendatud  (ID  >kiirendatud !41_A	et	f	\N
135691	kiirendatud	"kiirendatud %kiirenda  )TUD_vA  <kiirendama ;27_V	et	f	\N
135699	ship	### ship	et	f	\N
135737	ettenähtud	ettenähtud =näh  (PtsPtIps  >ette+_nägema !28_V	et	f	\N
135738	ettenähtud	ettenähtud =nähtu  (PlN  >ette+nähtu !01_S	et	f	\N
135742	öeldnud	?öeldnud =öeldnu  (PlN  >öeldnu !01_S	et	f	\N
135743	öeldnud	?öeldnud =öeldnu  (IndPrSg2  >öeldnuma !27_V	et	f	\N
135744	öeldnud	?öeldnud =öeldnud  (ID  >öeldnud !41_A	et	f	\N
135790	puulõige	puulõige =lõige  (SgN  >puu+lõige !05_S	et	f	\N
135791	puulõige	puulõige =lõige  (SgN  >puu+lõige !06_S	et	f	\N
135805	jääma	jääma =jää  (Sup  >jääma !37_V	et	f	\N
135806	jääma	jääma =jääma  (SgG  >jääm !22_S	et	f	\N
135807	jääma	jääma =jääma  (SgP  >jääm !22_S	et	f	\N
135808	jääma	jääma =jääma  (SgAdt  >jääm !22_S	et	f	\N
135840	technikaga	?technikaga =technika  (SgKom  >technika !01_S	et	f	\N
135841	technikaga	?technikaga =technika  (SgKom  >technikas !02_S	et	f	\N
135842	vaimustus	vaimustus =vaimustu  (IndIpfSg3  >vaimustuma !27_V	et	f	\N
135843	vaimustus	vaimustus =vaimustus  (SgN  >vaimustus !11_S	et	f	\N
135844	vaimustus	"vaimustus %vaimusta  )US_vS  <vaimustama ;27_V	et	f	\N
135845	vaimustus	vaimustus =ustu  (SgIn  >vaim+ustu !01_S	et	f	\N
135849	jõudmist	jõudmist =jõudmis  (SgP  >jõudmine !12?10_S	et	f	\N
135850	jõudmist	"jõudmine %jõud  )MINE_vS  <jõudma ;34_V	et	f	\N
135864	inimestedest	?inimestedest =inimestedes  (SgP  >inimestedene !12_A	et	f	\N
135865	inimestedest	?inimestedest =estedes  (SgP  >inim+estedene !12_A	et	f	\N
135881	salu	salu =salu  (SgN  >salu !17_S	et	f	\N
135882	salu	salu =salu  (SgG  >salu !17_S	et	f	\N
135883	salu	salu =salu  (SgP  >salu !17_S	et	f	\N
135918	kaheksakümmendviis	?kaheksakümmendviis =kaheksakümmendvii  (SgIn  >kaheksakümmendvii !26_S	et	f	\N
135919	kaheksakümmendviis	?kaheksakümmendviis =kaheksakümmendviis  (SgN  >kaheksakümmendviis !22_S	et	f	\N
135920	kaheksakümmendviis	?kaheksakümmendviis =kümmendvi  (PlIn  >kaheksa+kümmendvi !01_S	et	f	\N
135921	kaheksakümmendviis	?kaheksakümmendviis =kümmendvii  (SgIn  >kaheksa+kümmendvii !26_S	et	f	\N
135922	kaheksakümmendviis	?kaheksakümmendviis =kümmendviis  (SgN  >kaheksa+kümmendviis !22_S	et	f	\N
135923	kaheksakümmendviis	?kaheksakümmendviis =ksakümmendvii  (SgIn  >kahe+ksakümmendvii !26_S	et	f	\N
135924	kaheksakümmendviis	?kaheksakümmendviis =ksakümmendviis  (SgN  >kahe+ksakümmendviis !22_S	et	f	\N
135944	kahvel	kahvel =kahve  (PlAd  >kahv !22_S	et	f	\N
135946	kahvel	kahvel =kahvel  (SgN  >kahvel !02_S	et	f	\N
135949	telisel	?telisel =telise  (SgAd  >teline !10_A	et	f	\N
135950	telisel	?telisel =telisel  (SgN  >telisel !19_S	et	f	\N
135951	vaada	?vaada =vaada  (SgN  >vaada !16_S	et	f	\N
135952	vaada	?vaada =vaada  (SgG  >vaada !16_S	et	f	\N
135953	vaada	?vaada =vaada  (IndPrPs_  >vaadama !29_V	et	f	\N
135954	vaada	?vaada =vaada  (ImpPrSg2  >vaadama !29_V	et	f	\N
135970	päevikku	?päevikku =päevikku  (SgN  >päevikku !01_S	et	f	\N
135971	päevikku	?päevikku =päevikku  (SgG  >päevikku !01_S	et	f	\N
135972	päevikku	?päevikku =päevikku  (IndPrPs_  >päevikkuma !27_V	et	f	\N
135973	päevikku	?päevikku =päevikku  (ImpPrSg2  >päevikkuma !27_V	et	f	\N
135974	päevikku	?päevikku =ikku  (SgP  >päev+ikk !22_S	et	f	\N
135975	päevikku	?päevikku =ikku  (SgAdt  >päev+ikk !22_S	et	f	\N
136017	tuhatüheksasadakaheksakümmend	?tuhatüheksasadakaheksakümmend =tuhatüheksasadakaheksakümmend  (SgN  >tuhatüheksasadakaheksakümmend !22_S	et	f	\N
136018	tuhatüheksasadakaheksakümmend	?tuhatüheksasadakaheksakümmend =tüheksasadakaheksakümmend  (SgN  >tuha+tüheksasadakaheksakümmend !22_S	et	f	\N
136062	lapsevanematele	lapsevanematele =ate  (PlAll  >lapse+vanem+att !22_S	et	f	\N
136063	lapsevanematele	lapsevanematele =vanema  (PlAll  >lapse+vanem !02_AS	et	f	\N
136064	lapsevanematele	"lapse+vanem %vane  )M_cA  <lapse+vana ;17_AS	et	f	\N
136065	kõrvatunde	kõrvatunde =tunde  (SgG  >kõrva+tunne !06_S	et	f	\N
136066	kõrvatunde	kõrvatunde =tunde  (PlP  >kõrva+tund !22_S	et	f	\N
136079	nõutuseni	nõutuseni =nõutuse  (SgTer  >nõutus !11~09_S	et	f	\N
136080	nõutuseni	"nõutus %nõuta  )US_vS  <nõutama ;27_V	et	f	\N
136081	nõutuseni	"nõutus %nõu  )TUS1_aS  <nõudma ;34_V	et	f	\N
136082	nõutuseni	"nõutus %nõu  )TUS2_aS  <nõu ;26_S	et	f	\N
135715	kontrabassi	kontrabassi =bassi  (SgG  >kontra+bass !22_S	et	f	\N
135716	kontrabassi	kontrabassi =bassi  (SgP  >kontra+bass !22_S	et	f	\N
135717	kontrabassi	kontrabassi =bassi  (SgAdt  >kontra+bass !22_S	et	f	\N
135718	mängi	mängi =mängi  (SgP  >mäng !22_S	et	f	\N
135719	mängi	mängi =mängi  (SgAdt  >mäng !22_S	et	f	\N
135720	mängi	mängi =mängi  (IndPrPs_  >mängima !28_V	et	f	\N
135721	mängi	mängi =mängi  (ImpPrSg2  >mängima !28_V	et	f	\N
135725	normalsed	?normalsed =normalse  (PlN  >normalne !02_A	et	f	\N
135726	normalsed	?normalsed =alse  (PlN  >norm+alne !02_A	et	f	\N
135730	201s	### 201s	et	f	\N
135745	inimnene	?inimnene =inimnene  (SgN  >inimnene !12_A	et	f	\N
135746	inimnene	?inimnene =inimnene  (PlP  >inimnen !19_S	et	f	\N
135747	inimnene	?inimnene =nene  (SgN  >inim+nene !16_S	et	f	\N
135748	inimnene	?inimnene =nene  (SgG  >inim+nene !16_S	et	f	\N
135749	tulevikukodu	tulevikukodu =kodu  (SgN  >tuleviku+kodu !17_S	et	f	\N
135750	tulevikukodu	tulevikukodu =kodu  (SgG  >tuleviku+kodu !17_S	et	f	\N
135751	tulevikukodu	tulevikukodu =kodu  (SgP  >tuleviku+kodu !17_S	et	f	\N
135764	lambi	lambi =lambi  (SgG  >lamp !22_SA	et	f	\N
135765	lambi	lambi =lambi  (IndPrPs_  >lampima !28_V	et	f	\N
135766	lambi	lambi =lambi  (ImpPrSg2  >lampima !28_V	et	f	\N
135833	oslos	?oslos =oslo  (SgIn  >oslo !16_S	et	f	\N
135834	oslos	?oslos =oslos  (SgN  >oslos !11~09_S	et	f	\N
135838	kunsttööstuskoolis	kunsttööstuskoolis =kooli  (SgIn  >kunst+tööstus+kool !22_S	et	f	\N
135839	kunsttööstuskoolis	kunsttööstuskoolis =kooli  (PlIn  >kunst+tööstus+kool !22_S	et	f	\N
135846	loodusemaaline	loodusemaaline =maaline  (SgN  >looduse+maaline !12?10_A	et	f	\N
135847	loodusemaaline	"looduse+maaline %maa  )LINE_aA  <looduse+maa ;26_S	et	f	\N
135848	loodusemaaline	"looduse+maaline %maali  )NE_aA  <looduse+maal ;22_S	et	f	\N
135884	neljateistkümnendal	?neljateistkümnendal =neljateistkümnenda  (SgAd  >neljateistkümnenda !16_S	et	f	\N
135885	neljateistkümnendal	?neljateistkümnendal =neljateistkümnendal  (SgN  >neljateistkümnendal !02_S	et	f	\N
135886	neljateistkümnendal	?neljateistkümnendal =kümnenda  (SgAd  >nelja+teist+kümnenda !01_S	et	f	\N
135887	neljateistkümnendal	?neljateistkümnendal =teistkümnenda  (SgAd  >nelja+teistkümnenda !16_S	et	f	\N
135888	neljateistkümnendal	?neljateistkümnendal =teistkümnendal  (SgN  >nelja+teistkümnendal !02_S	et	f	\N
135893	õppisib	### õppisib	et	f	\N
135901	kuueteistkümneseitme	?kuueteistkümneseitme =kuueteistkümneseitme  (PlP  >kuueteistkümneseitm !22_S	et	f	\N
135902	kuueteistkümneseitme	?kuueteistkümneseitme =seitme  (SgN  >kuue+teist+kümne+seitme !06_S	et	f	\N
135903	kuueteistkümneseitme	?kuueteistkümneseitme =seitme  (SgG  >kuue+teist+kümne+seitme !06_S	et	f	\N
135904	kuueteistkümneseitme	?kuueteistkümneseitme =seitme  (PlP  >kuue+teist+kümne+seitm !22_S	et	f	\N
135905	kuueteistkümneseitme	?kuueteistkümneseitme =kümneseitme  (PlP  >kuue+teist+kümneseitm !22_S	et	f	\N
135906	kuueteistkümneseitme	?kuueteistkümneseitme =teistkümneseitme  (PlP  >kuue+teistkümneseitm !22_S	et	f	\N
135907	kuueteistkümneseitme	?kuueteistkümneseitme =eteistkümneseitme  (PlP  >kuu+eteistkümneseitm !22_S	et	f	\N
135909	seitsmekümmend	?seitsmekümmend =seitsmekümmend  (SgN  >seitsmekümmend !22_S	et	f	\N
135943	glaas	?glaas =glaa  (SgIn  >glaa !26_S	et	f	\N
135945	glaas	?glaas =glaas  (SgN  >glaas !22_S	et	f	\N
135976	keetas	?keetas =keeta  (SgIn  >keeta !16_S	et	f	\N
135977	keetas	?keetas =keeta  (IndIpfSg3  >keetama !27_V	et	f	\N
135978	keetas	?keetas =keetas  (SgN  >keetas !07_S	et	f	\N
136047	puhu	puhu =puhu  (SgG  >puhk !22_S	et	f	\N
136048	puhu	puhu =puhu  (IndPrPs_  >puhuma !27_V	et	f	\N
136049	puhu	puhu =puhu  (ImpPrSg2  >puhuma !27_V	et	f	\N
136059	asukkaid	?asukkaid =asukka  (PlP  >asukka !01_S	et	f	\N
136060	asukkaid	?asukkaid =asukkai  (PlN  >asukkai !26_S	et	f	\N
136061	asukkaid	?asukkaid =asukkai  (SgP  >asukkai !26_S	et	f	\N
136091	vastavust	vastavust =vastavus  (SgP  >vastavus !11_S	et	f	\N
136092	vastavust	"vastavus %vasta  )VUS_aS  <vastama ;29_V	et	f	\N
136093	vastavust	"vastavus %vastava  )US_aS  <vastav ;02_A	et	f	\N
136104	tagajärgjed	?tagajärgjed =järgje  (PlN  >taga+järgje !06_S	et	f	\N
136108	ülokooli	?ülokooli =ülokooli  (SgN  >ülokooli !16_S	et	f	\N
136109	ülokooli	?ülokooli =ülokooli  (SgG  >ülokooli !16_S	et	f	\N
136110	ülokooli	?ülokooli =ülokooli  (SgG  >ülokool !22_S	et	f	\N
136111	ülokooli	?ülokooli =ülokooli  (SgP  >ülokool !22_S	et	f	\N
136112	ülokooli	?ülokooli =ülokooli  (SgAdt  >ülokool !22_S	et	f	\N
136113	ülokooli	?ülokooli =ülokooli  (IndPrPs_  >ülokoolima !28_V	et	f	\N
136114	ülokooli	?ülokooli =ülokooli  (ImpPrSg2  >ülokoolima !28_V	et	f	\N
136134	tainast	tainast =taina  (SgEl  >tainas !07_S	et	f	\N
136135	tainast	tainast =tainas  (SgP  >tainas !07_S	et	f	\N
136136	tainast	tainast =tainas  (SgP  >tainane !10~12_A	et	f	\N
136137	tainast	"tainane %taina  )NE_aA  <tainas ;07_S	et	f	\N
136175	alandamisele	alandamisele =alandamise  (SgAll  >alandamine !12_S	et	f	\N
136176	alandamisele	"alandamine %alanda  )MINE_vS  <alandama ;27_V	et	f	\N
136187	vastukaalune	vastukaalune =kaalune  (SgN  >vastu+kaalune !10_A	et	f	\N
136188	vastukaalune	"vastu+kaalune %kaalu  )NE_aA  <vastu+kaal ;22_S	et	f	\N
136206	budapestis	?budapestis =budapesti  (IndIpfSg3  >budapestima !28_V	et	f	\N
135755	minumoodi	minumoodi =moodi  (SgAdt  >minu+mood !22_S	et	f	\N
135778	kunsttöötuskoolis	?kunsttöötuskoolis =kunsttöötuskooli  (SgIn  >kunsttöötuskooli !16_S	et	f	\N
135779	kunsttöötuskoolis	?kunsttöötuskoolis =kunsttöötuskooli  (SgIn  >kunsttöötuskool !22_S	et	f	\N
135780	kunsttöötuskoolis	?kunsttöötuskoolis =kunsttöötuskooli  (IndIpfSg3  >kunsttöötuskoolima !28_V	et	f	\N
135781	kunsttöötuskoolis	?kunsttöötuskoolis =kunsttöötuskoolis  (SgN  >kunsttöötuskoolis !09_S	et	f	\N
135782	kunsttöötuskoolis	?kunsttöötuskoolis =skooli  (SgIn  >kunst+töötu+skooli !16_S	et	f	\N
135783	kunsttöötuskoolis	?kunsttöötuskoolis =skoolis  (SgN  >kunst+töötu+skoolis !09_S	et	f	\N
135784	kunsttöötuskoolis	?kunsttöötuskoolis =tuskooli  (SgIn  >kunst+töö+tuskooli !16_S	et	f	\N
135785	kunsttöötuskoolis	?kunsttöötuskoolis =tuskooli  (SgIn  >kunst+töö+tuskool !22_S	et	f	\N
135786	kunsttöötuskoolis	?kunsttöötuskoolis =tuskoolis  (SgN  >kunst+töö+tuskoolis !09_S	et	f	\N
135787	kunsttöötuskoolis	?kunsttöötuskoolis =töötuskooli  (SgIn  >kunst+töötuskooli !16_S	et	f	\N
135788	kunsttöötuskoolis	?kunsttöötuskoolis =töötuskooli  (SgIn  >kunst+töötuskool !22_S	et	f	\N
135789	kunsttöötuskoolis	?kunsttöötuskoolis =töötuskoolis  (SgN  >kunst+töötuskoolis !09_S	et	f	\N
135802	vaimustust	vaimustust =vaimustus  (SgP  >vaimustus !11_S	et	f	\N
135803	vaimustust	"vaimustus %vaimusta  )US_vS  <vaimustama ;27_V	et	f	\N
135804	vaimustust	vaimustust =ustu  (SgEl  >vaim+ustu !01_S	et	f	\N
135821	pariisis	?pariisis =pariisi  (SgIn  >pariis !22_S	et	f	\N
135822	pariisis	?pariisis =pariisi  (IndIpfSg3  >pariisima !28_V	et	f	\N
135823	pariisis	?pariisis =pariisis  (SgN  >pariisis !09_S	et	f	\N
135858	huvitus	huvitus =huvitu  (SgIn  >huvitu !01_A	et	f	\N
135859	huvitus	"huvitu %huvi  )TU2_kA  <huvi ;17_S	et	f	\N
135860	huvitus	huvitus =huvitu  (IndIpfSg3  >huvituma !27_V	et	f	\N
135861	huvitus	huvitus =huvitus  (SgN  >huvitus !11_S	et	f	\N
135862	huvitus	"huvitus %huvita  )US_vS  <huvitama ;27_V	et	f	\N
135863	huvitus	"huvitus %huvi  )TUS2_aS  <huvi ;17_S	et	f	\N
135866	haavata	haavata =haava  (SgAb  >haab !22_S	et	f	\N
135867	haavata	haavata =haava  (SgAb  >haav !22_S	et	f	\N
135868	haavata	haavata =haava  (Inf  >haavama !29_V	et	f	\N
135869	haavata	haavata =haava  (IndPrIps_  >haavama !29_V	et	f	\N
135870	popularne	?popularne =popularne  (SgN  >popularne !02_A	et	f	\N
135871	popularne	?popularne =popularne  (PlP  >popularn !22_S	et	f	\N
135872	popularne	?popularne =ularne  (SgN  >pop+ularne !02_A	et	f	\N
135873	popularne	?popularne =ularne  (PlP  >pop+ularn !22_S	et	f	\N
135896	neliteistkümnendal	?neliteistkümnendal =neliteistkümnenda  (SgAd  >neliteistkümnenda !16_S	et	f	\N
135897	neliteistkümnendal	?neliteistkümnendal =neliteistkümnendal  (SgN  >neliteistkümnendal !02_S	et	f	\N
135898	neliteistkümnendal	?neliteistkümnendal =kümnenda  (SgAd  >neli+teist+kümnenda !01_S	et	f	\N
135899	neliteistkümnendal	?neliteistkümnendal =teistkümnenda  (SgAd  >neli+teistkümnenda !16_S	et	f	\N
135900	neliteistkümnendal	?neliteistkümnendal =teistkümnendal  (SgN  >neli+teistkümnendal !02_S	et	f	\N
135908	üheksasada	### üheksasada	et	f	\N
135910	kaheksakümneviie	?kaheksakümneviie =kaheksakümneviie  (SgN  >kaheksakümneviie !01_S	et	f	\N
135911	kaheksakümneviie	?kaheksakümneviie =kaheksakümneviie  (SgG  >kaheksakümneviie !01_S	et	f	\N
135912	kaheksakümneviie	?kaheksakümneviie =viie  (SgN  >kaheksa+kümne+viie !06_S	et	f	\N
135913	kaheksakümneviie	?kaheksakümneviie =viie  (SgG  >kaheksa+kümne+viie !06_S	et	f	\N
135914	kaheksakümneviie	?kaheksakümneviie =kümneviie  (SgN  >kaheksa+kümneviie !01_S	et	f	\N
135915	kaheksakümneviie	?kaheksakümneviie =kümneviie  (SgG  >kaheksa+kümneviie !01_S	et	f	\N
135916	kaheksakümneviie	?kaheksakümneviie =ksakümneviie  (SgN  >kahe+ksakümneviie !01_S	et	f	\N
135917	kaheksakümneviie	?kaheksakümneviie =ksakümneviie  (SgG  >kahe+ksakümneviie !01_S	et	f	\N
135947	teppiline	?teppiline =teppiline  (SgN  >teppiline !12_A	et	f	\N
135948	teppiline	?teppiline =teppiline  (PlP  >teppilin !19_S	et	f	\N
135955	üheksakümne	?üheksakümne =üheksakümne  (SgN  >üheksakümne !02_A	et	f	\N
135956	üheksakümne	?üheksakümne =üheksakümne  (PlP  >üheksakümn !22_S	et	f	\N
135957	üheksakümne	?üheksakümne =kümne  (SgN  >üheksa+kümne !02_A	et	f	\N
135958	üheksakümne	?üheksakümne =kümne  (PlP  >üheksa+kümn !22_S	et	f	\N
135959	üheksakümne	?üheksakümne =akümne  (SgN  >üheks+akümne !02_A	et	f	\N
135960	üheksakümne	?üheksakümne =akümne  (PlP  >üheks+akümn !22_S	et	f	\N
135961	üheksakümne	?üheksakümne =ksakümne  (SgN  >ühe+ksakümne !02_A	et	f	\N
135962	üheksakümne	?üheksakümne =ksakümne  (PlP  >ühe+ksakümn !22_S	et	f	\N
135966	õ	### õ	et	f	\N
135967	rval	### rval	et	f	\N
135981	naljane	naljane =naljane  (SgN  >naljane !10_A	et	f	\N
135982	naljane	"naljane %nalja  )NE_aA  <nali ;24_S	et	f	\N
135984	pottilille	?pottilille =pottilille  (PlP  >pottilill !22_S	et	f	\N
135985	pottilille	?pottilille =ilille  (PlP  >pott+ilill !22_S	et	f	\N
135990	neljateistkümnes	?neljateistkümnes =neljateistkümne  (PlIn  >neljateistkümn !22_S	et	f	\N
135991	neljateistkümnes	?neljateistkümnes =kümne  (PlIn  >nelja+teist+kümn !22_S	et	f	\N
135992	neljateistkümnes	?neljateistkümnes =teistkümne  (PlIn  >nelja+teistkümn !22_S	et	f	\N
136027	kaheksakümneviiendast	?kaheksakümneviiendast =kaheksakümneviienda  (SgEl  >kaheksakümneviienda !16_S	et	f	\N
135799	havata	?havata =hava  (IndPrIps_  >havama !27_V	et	f	\N
135800	havata	?havata =havata  (IndPrPs_  >havatama !27_V	et	f	\N
135801	havata	?havata =havata  (ImpPrSg2  >havatama !27_V	et	f	\N
135826	expressionismist	?expressionismist =expressionismi  (SgEl  >expressionism !22_S	et	f	\N
135828	expressionismist	?expressionismist =expressionismis  (SgP  >expressionismis !09_S	et	f	\N
135830	expressionismist	?expressionismist =expressionismis  (SgP  >expressionismine !12_A	et	f	\N
135832	expressionismist	?expressionismist =expressionismist  (SgN  >expressionismist !22_S	et	f	\N
135835	norra	?norra =norra  (ID  >norra !41_G	et	f	\N
135836	norra	?norra =norra  (IndPrPs_  >norrama !29_V	et	f	\N
135837	norra	?norra =norra  (ImpPrSg2  >norrama !29_V	et	f	\N
135874	impressionismust	?impressionismust =impressionismus  (SgP  >impressionismus !11~09_S	et	f	\N
135875	ekspressionismust	?ekspressionismust =ekspressionismus  (SgP  >ekspressionismus !11~09_S	et	f	\N
135876	ekspressionismust	?ekspressionismust =onismu  (SgEl  >eks+pressi+onismu !01_S	et	f	\N
135877	ekspressionismust	?ekspressionismust =onismus  (SgP  >eks+pressi+onismus !11_S	et	f	\N
135878	ekspressionismust	?ekspressionismust =ionismu  (SgEl  >ekspress+ionismu !01_S	et	f	\N
135879	ekspressionismust	?ekspressionismust =ionismus  (SgP  >ekspress+ionismus !11_S	et	f	\N
135880	ekspressionismust	?ekspressionismust =pressionismus  (SgP  >eks+pressionismus !11~09_S	et	f	\N
135895	julil	?julil =juli  (SgAd  >juli !17_S	et	f	\N
135963	jooksev	jooksev =jooks  (PtsPrPs  >jooksma !32_V	et	f	\N
135964	jooksev	jooksev =jooksev  (SgN  >jooksev !02_A	et	f	\N
135965	jooksev	"jooksev %jooks  )V_vA  <jooksma ;32_V	et	f	\N
135993	tuhandeüheksasajakuuekümneseitsme	?tuhandeüheksasajakuuekümneseitsme =seitsme  (SgN  >tuhande+üheksa+saja+kuue+kümne+seitsme !06_S	et	f	\N
135994	tuhandeüheksasajakuuekümneseitsme	?tuhandeüheksasajakuuekümneseitsme =seitsme  (SgG  >tuhande+üheksa+saja+kuue+kümne+seitsme !06_S	et	f	\N
135995	tuhandeüheksasajakuuekümneseitsme	?tuhandeüheksasajakuuekümneseitsme =seitsme  (PlP  >tuhande+üheksa+saja+kuue+kümne+seitsm !22_S	et	f	\N
136019	tuhandeüheksasaja	?tuhandeüheksasaja =tuhandeüheksasaja  (SgN  >tuhandeüheksasaja !01_S	et	f	\N
136020	tuhandeüheksasaja	?tuhandeüheksasaja =tuhandeüheksasaja  (SgG  >tuhandeüheksasaja !01_S	et	f	\N
136021	tuhandeüheksasaja	?tuhandeüheksasaja =tuhandeüheksasaja  (SgG  >tuhandeüheksasajas !02_A	et	f	\N
136022	tuhandeüheksasaja	?tuhandeüheksasaja =saja  (SgN  >tuhande+üheksa+saja !17_S	et	f	\N
136023	tuhandeüheksasaja	?tuhandeüheksasaja =saja  (SgG  >tuhande+üheksa+saja !17_S	et	f	\N
136024	tuhandeüheksasaja	?tuhandeüheksasaja =saja  (SgP  >tuhande+üheksa+saja !17_S	et	f	\N
136025	tuhandeüheksasaja	?tuhandeüheksasaja =asaja  (SgN  >tuhande+üheks+asaja !01_S	et	f	\N
136026	tuhandeüheksasaja	?tuhandeüheksasaja =asaja  (SgG  >tuhande+üheks+asaja !01_S	et	f	\N
136028	tuhandeüheksasaja	?tuhandeüheksasaja =asaja  (SgG  >tuhande+üheks+asajas !02_A	et	f	\N
136029	tuhandeüheksasaja	?tuhandeüheksasaja =ksasaja  (SgN  >tuhande+ühe+ksasaja !01_S	et	f	\N
136032	tuhandeüheksasaja	?tuhandeüheksasaja =ksasaja  (SgG  >tuhande+ühe+ksasaja !01_S	et	f	\N
136033	tuhandeüheksasaja	?tuhandeüheksasaja =ksasaja  (SgG  >tuhande+ühe+ksasajas !02_A	et	f	\N
136036	tuhandeüheksasaja	?tuhandeüheksasaja =üheksasaja  (SgN  >tuhande+üheksasaja !01_S	et	f	\N
136037	tuhandeüheksasaja	?tuhandeüheksasaja =üheksasaja  (SgG  >tuhande+üheksasaja !01_S	et	f	\N
136039	tuhandeüheksasaja	?tuhandeüheksasaja =üheksasaja  (SgG  >tuhande+üheksasajas !02_A	et	f	\N
136046	romantilline	?romantilline =romantilline  (SgN  >romantilline !12_A	et	f	\N
136050	uuni	uuni =uuni  (SgG  >uun !22_S	et	f	\N
136051	uuni	uuni =uuni  (SgP  >uun !22_S	et	f	\N
136052	uuni	uuni =uuni  (SgAdt  >uun !22_S	et	f	\N
136055	ungari	?ungari =ungari  (SgN  >ungari !01_S	et	f	\N
136056	ungari	?ungari =ungari  (SgG  >ungari !01_S	et	f	\N
136057	ungari	?ungari =ungari  (SgG  >ungar !02_S	et	f	\N
136107	ajalugust	?ajalugust =ajalugus  (SgP  >ajalugus !11?09_S	et	f	\N
136117	lasteaga	?lasteaga =lastea  (SgKom  >lastea !26_S	et	f	\N
136142	pääses	pääses =pääse  (SgIn  >pääse !06_S	et	f	\N
136143	pääses	pääses =pääse  (PlIn  >pääs !22_S	et	f	\N
136144	pääses	pääses =pääse  (IndIpfSg3  >pääsema !28_V	et	f	\N
136158	eleganned	### eleganned	et	f	\N
136164	iso	?iso =iso  (SgN  >iso !17~16_S	et	f	\N
136165	iso	?iso =iso  (SgG  >iso !17~16_S	et	f	\N
136166	iso	?iso =iso  (SgP  >iso !17_S	et	f	\N
136167	kadri	kadri =kadri  (SgN  >kadri !16_S	et	f	\N
136168	kadri	kadri =kadri  (SgG  >kadri !16_S	et	f	\N
136180	pingulisust	pingulisust =pingulisus  (SgP  >pingulisus !11?09_S	et	f	\N
136181	pingulisust	"pingulisus %pingu  )LISUS_aS  <ping ;22_S	et	f	\N
136182	külmustamise	?külmustamise =külmustamise  (SgG  >külmustamine !12_S	et	f	\N
136183	külmustamise	?külmustamise =ustamise  (SgG  >külm+ustamine !12_S	et	f	\N
136196	poissit	?poissit =poissit  (SgN  >poissit !02_S	et	f	\N
136197	eevi	?eevi =eevi  (SgN  >eevi !16_S	et	f	\N
136198	eevi	?eevi =eevi  (SgG  >eevi !16_S	et	f	\N
136199	eevi	?eevi =eevi  (SgG  >eev !22_S	et	f	\N
136200	eevi	?eevi =eevi  (SgP  >eev !22_S	et	f	\N
136201	eevi	?eevi =eevi  (SgAdt  >eev !22_S	et	f	\N
136202	eevi	?eevi =eevi  (IndPrPs_  >eevima !28_V	et	f	\N
136203	eevi	?eevi =eevi  (ImpPrSg2  >eevima !28_V	et	f	\N
136213	aastlane	?aastlane =aastlane  (SgN  >aastlane !12?10_S	et	f	\N
135810	lemmikala	lemmikala =ala  (SgG  >lemmik+ala !17_S	et	f	\N
135811	lemmikala	lemmikala =ala  (SgP  >lemmik+ala !17_S	et	f	\N
135812	pariisi	?pariisi =pariisi  (ID  >pariisi !41_G	et	f	\N
135813	pariisi	?pariisi =pariisi  (SgG  >pariis !22_S	et	f	\N
135814	pariisi	?pariisi =pariisi  (SgP  >pariis !22_S	et	f	\N
135815	pariisi	?pariisi =pariisi  (SgAdt  >pariis !22_S	et	f	\N
135816	pariisi	?pariisi =pariisi  (IndPrPs_  >pariisima !28_V	et	f	\N
135817	pariisi	?pariisi =pariisi  (ImpPrSg2  >pariisima !28_V	et	f	\N
135818	tunnustust	tunnustust =tunnustus  (SgP  >tunnustus !11_S	et	f	\N
135819	tunnustust	"tunnustus %tunnusta  )US_vS  <tunnustama ;27_V	et	f	\N
135820	tunnustust	tunnustust =tust  (SgN  >tunnus+tust !22_S	et	f	\N
135824	mõjustatud	mõjustatud =mõjusta  (PtsPtIps  >mõjustama !27_V	et	f	\N
135825	mõjustatud	mõjustatud =mõjustatu  (PlN  >mõjustatu !01_S	et	f	\N
135827	mõjustatud	"mõjustatu %mõjusta  )TU1_vS  <mõjustama ;27_V	et	f	\N
135829	mõjustatud	mõjustatud =mõjustatud  (ID  >mõjustatud !41_A	et	f	\N
135831	mõjustatud	"mõjustatud %mõjusta  )TUD_vA  <mõjustama ;27_V	et	f	\N
135851	kultuurkapitali	kultuurkapitali =tali  (SgN  >kultuur+kapi+tali !17_S	et	f	\N
135852	kultuurkapitali	kultuurkapitali =tali  (SgN  >kultuur+kapi+tali !24_S	et	f	\N
135853	kultuurkapitali	kultuurkapitali =tali  (SgG  >kultuur+kapi+tali !17_S	et	f	\N
135854	kultuurkapitali	kultuurkapitali =tali  (SgP  >kultuur+kapi+tali !17_S	et	f	\N
135855	kultuurkapitali	kultuurkapitali =kapitali  (SgG  >kultuur+kapital !19_S	et	f	\N
135856	kultuurkapitali	kultuurkapitali =kapitali  (SgP  >kultuur+kapital !19_S	et	f	\N
135857	kultuurkapitali	kultuurkapitali =kapitali  (SgAdt  >kultuur+kapital !19_S	et	f	\N
135889	käisi	?käisi =käisi  (SgN  >käisi !16_S	et	f	\N
135890	käisi	?käisi =käisi  (SgG  >käisi !16_S	et	f	\N
135891	käisi	?käisi =käisi  (IndPrPs_  >käisima !28_V	et	f	\N
135892	käisi	?käisi =käisi  (ImpPrSg2  >käisima !28_V	et	f	\N
135894	töötasib	### töötasib	et	f	\N
135925	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =tuhandeüheksasajaüheksakümne  (SgN  >tuhandeüheksasajaüheksakümne !02_A	et	f	\N
135926	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =tuhandeüheksasajaüheksakümne  (PlP  >tuhandeüheksasajaüheksakümn !22_S	et	f	\N
135927	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =kümne  (SgN  >tuhande+üheksa+saja+üheksa+kümne !02_A	et	f	\N
135928	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =kümne  (PlP  >tuhande+üheksa+saja+üheksa+kümn !22_S	et	f	\N
135929	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =akümne  (SgN  >tuhande+üheksa+saja+üheks+akümne !02_A	et	f	\N
135930	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =akümne  (PlP  >tuhande+üheksa+saja+üheks+akümn !22_S	et	f	\N
135931	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =ksakümne  (SgN  >tuhande+üheksa+saja+ühe+ksakümne !02_A	et	f	\N
135932	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =ksakümne  (PlP  >tuhande+üheksa+saja+ühe+ksakümn !22_S	et	f	\N
135933	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =üheksakümne  (SgN  >tuhande+üheksa+saja+üheksakümne !02_A	et	f	\N
135934	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =üheksakümne  (PlP  >tuhande+üheksa+saja+üheksakümn !22_S	et	f	\N
135935	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =sajaüheksakümne  (SgN  >tuhande+üheksa+sajaüheksakümne !02_A	et	f	\N
135936	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =sajaüheksakümne  (PlP  >tuhande+üheksa+sajaüheksakümn !22_S	et	f	\N
135937	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =asajaüheksakümne  (SgN  >tuhande+üheks+asajaüheksakümne !02_A	et	f	\N
135938	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =asajaüheksakümne  (PlP  >tuhande+üheks+asajaüheksakümn !22_S	et	f	\N
135939	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =ksasajaüheksakümne  (SgN  >tuhande+ühe+ksasajaüheksakümne !02_A	et	f	\N
135940	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =ksasajaüheksakümne  (PlP  >tuhande+ühe+ksasajaüheksakümn !22_S	et	f	\N
135941	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =üheksasajaüheksakümne  (SgN  >tuhande+üheksasajaüheksakümne !02_A	et	f	\N
135942	tuhandeüheksasajaüheksakümne	?tuhandeüheksasajaüheksakümne =üheksasajaüheksakümne  (PlP  >tuhande+üheksasajaüheksakümn !22_S	et	f	\N
135968	vasakul	vasakul =vasaku  (SgAd  >vasak !02_A	et	f	\N
135969	vasakul	vasakul =vasakul  (ID  >vasakul !41_D	et	f	\N
135979	sööki	sööki =sööki  (SgP  >söök !22_S	et	f	\N
135980	sööki	sööki =sööki  (SgAdt  >söök !22_S	et	f	\N
135983	keetab	?keetab =keeta  (IndPrSg3  >keetama !27_V	et	f	\N
135986	lae	lae =lae  (SgG  >lagi !21_S	et	f	\N
135987	lae	lae =lae  (SgG  >laad !22_S	et	f	\N
135988	lae	lae =lae  (IndPrPs_  >laadima !28_V	et	f	\N
135989	lae	lae =lae  (ImpPrSg2  >laadima !28_V	et	f	\N
135996	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =tuhandeüheksasajaseitsmekümnenelja  (SgN  >tuhandeüheksasajaseitsmekümnenelja !16_S	et	f	\N
135997	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =tuhandeüheksasajaseitsmekümnenelja  (SgG  >tuhandeüheksasajaseitsmekümneneljas !02_A	et	f	\N
135998	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =tuhandeüheksasajaseitsmekümnenelja  (SgG  >tuhandeüheksasajaseitsmekümnenelja !16_S	et	f	\N
135999	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =kümnenelja  (SgN  >tuhande+üheksa+saja+seitsme+kümnenelja !16_S	et	f	\N
136000	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =kümnenelja  (SgG  >tuhande+üheksa+saja+seitsme+kümneneljas !02_A	et	f	\N
136001	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =kümnenelja  (SgG  >tuhande+üheksa+saja+seitsme+kümnenelja !16_S	et	f	\N
136002	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =seitsmekümnenelja  (SgN  >tuhande+üheksa+saja+seitsmekümnenelja !16_S	et	f	\N
136003	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =seitsmekümnenelja  (SgG  >tuhande+üheksa+saja+seitsmekümneneljas !02_A	et	f	\N
136004	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =seitsmekümnenelja  (SgG  >tuhande+üheksa+saja+seitsmekümnenelja !16_S	et	f	\N
136005	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =sajaseitsmekümnenelja  (SgN  >tuhande+üheksa+sajaseitsmekümnenelja !16_S	et	f	\N
136006	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =sajaseitsmekümnenelja  (SgG  >tuhande+üheksa+sajaseitsmekümneneljas !02_A	et	f	\N
136007	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =sajaseitsmekümnenelja  (SgG  >tuhande+üheksa+sajaseitsmekümnenelja !16_S	et	f	\N
136008	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =asajaseitsmekümnenelja  (SgN  >tuhande+üheks+asajaseitsmekümnenelja !16_S	et	f	\N
136009	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =asajaseitsmekümnenelja  (SgG  >tuhande+üheks+asajaseitsmekümneneljas !02_A	et	f	\N
136010	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =asajaseitsmekümnenelja  (SgG  >tuhande+üheks+asajaseitsmekümnenelja !16_S	et	f	\N
136011	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =ksasajaseitsmekümnenelja  (SgN  >tuhande+ühe+ksasajaseitsmekümnenelja !16_S	et	f	\N
136012	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =ksasajaseitsmekümnenelja  (SgG  >tuhande+ühe+ksasajaseitsmekümneneljas !02_A	et	f	\N
136013	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =ksasajaseitsmekümnenelja  (SgG  >tuhande+ühe+ksasajaseitsmekümnenelja !16_S	et	f	\N
136014	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =üheksasajaseitsmekümnenelja  (SgN  >tuhande+üheksasajaseitsmekümnenelja !16_S	et	f	\N
136015	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =üheksasajaseitsmekümnenelja  (SgG  >tuhande+üheksasajaseitsmekümneneljas !02_A	et	f	\N
136016	tuhandeüheksasajaseitsmekümnenelja	?tuhandeüheksasajaseitsmekümnenelja =üheksasajaseitsmekümnenelja  (SgG  >tuhande+üheksasajaseitsmekümnenelja !16_S	et	f	\N
136042	puus	puus =puu  (SgIn  >puu !26_S	et	f	\N
136043	puus	puus =puus  (SgN  >puus !22_S	et	f	\N
136083	võb	### võb	et	f	\N
136084	lapsevanem	lapsevanem =vanem  (SgN  >lapse+vanem !02_AS	et	f	\N
136085	lapsevanem	"lapse+vanem %vane  )M_cA  <lapse+vana ;17_AS	et	f	\N
136086	osutanud	osutanud =osuta  (PtsPtPs  >osutama !27_V	et	f	\N
136087	osutanud	osutanud =osutanu  (PlN  >osutanu !01_S	et	f	\N
136088	osutanud	"osutanu %osuta  )NU_vS  <osutama ;27_V	et	f	\N
136089	osutanud	osutanud =osutanud  (ID  >osutanud !41_A	et	f	\N
136090	osutanud	"osutanud %osuta  )NUD_vA  <osutama ;27_V	et	f	\N
136096	nõrgemaks	nõrgemaks =nõrgema  (SgTr  >nõrgem !02_A	et	f	\N
136097	nõrgemaks	"nõrgem %nõrge  )M_cA  <nõrk ;22_A	et	f	\N
136119	aiasse	aiasse =aia  (SgIll  >aed !22_S	et	f	\N
136120	aiasse	aiasse =aia  (SgIll  >ai !22_S	et	f	\N
136127	suitsetava	suitsetava =suitsetava  (SgG  >suitsetav !02_A	et	f	\N
136128	suitsetava	"suitsetav %suitse  )TAV_vAS  <suitsema ;28_V	et	f	\N
136129	suitsetava	"suitsetav %suitseta  )V_vA  <suitsetama ;27_V	et	f	\N
136130	väikesele	väikesele =väikese  (SgAll  >väike !12?10_A	et	f	\N
136131	väikesele	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
136132	väikesele	väikesele =väikese  (SgAll  >väikene !12?10_A	et	f	\N
136133	väikesele	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
136152	maitsvat	maitsvat =maits  (KvtPrPs  >maitsma !32_V	et	f	\N
136153	maitsvat	maitsvat =maitsva  (SgP  >maitsev !02_A	et	f	\N
136154	maitsvat	"maitsev %maits  )V_vA  <maitsma ;32_V	et	f	\N
136155	maitsvat	"maitsev %maitse  )V_vA  <maitsema ;28_V	et	f	\N
136159	armastasivad	?armastasivad =armastasiva  (PlN  >armastasiv !02_A	et	f	\N
136160	armastasivad	?armastasivad =armastasiva  (PlN  >armastasiva !16_S	et	f	\N
136161	kampsu	kampsu =kampsu  (SgG  >kamps !22_S	et	f	\N
136162	kampsu	kampsu =kampsu  (SgP  >kamps !22_S	et	f	\N
136163	kampsu	kampsu =kampsu  (SgAdt  >kamps !22_S	et	f	\N
136169	ravimtaime	ravimtaime =taime  (SgG  >ravim+taim !22_S	et	f	\N
136170	ravimtaime	ravimtaime =taime  (SgP  >ravim+taim !22_S	et	f	\N
136171	ravimtaime	ravimtaime =taime  (SgAdt  >ravim+taim !22_S	et	f	\N
136172	ravimtaime	ravimtaime =taime  (PlP  >ravim+taim !22_S	et	f	\N
136177	mentsuatsionieelset	?mentsuatsionieelset =mentsuatsionieelse  (SgP  >mentsuatsionieelne !02_A	et	f	\N
136178	närvilisust	närvilisust =närvilisus  (SgP  >närvilisus !11?09_S	et	f	\N
136179	närvilisust	"närvilisus %närvi  )LISUS_aS  <närv ;22_S	et	f	\N
136184	värskendav	värskendav =värskenda  (PtsPrPs  >värskendama !27_V	et	f	\N
136185	värskendav	värskendav =värskendav  (SgN  >värskendav !02_A	et	f	\N
136186	värskendav	"värskendav %värskenda  )V_vA  <värskendama ;27_V	et	f	\N
136191	kampus	?kampus =kampu  (SgIn  >kampu !16_S	et	f	\N
136192	kampus	?kampus =kampu  (IndIpfSg3  >kampuma !27_V	et	f	\N
136193	kampus	?kampus =kampus  (SgN  >kampus !11~09_S	et	f	\N
136223	filmist	filmist =filmi  (SgEl  >film !22_S	et	f	\N
136030	kaheksakümneviiendast	?kaheksakümneviiendast =kaheksakümneviiendas  (SgP  >kaheksakümneviiendane !12_A	et	f	\N
136031	kaheksakümneviiendast	?kaheksakümneviiendast =viienda  (SgEl  >kaheksa+kümne+viienda !01_S	et	f	\N
136034	kaheksakümneviiendast	?kaheksakümneviiendast =viiendas  (SgP  >kaheksa+kümne+viiendane !12_A	et	f	\N
136035	kaheksakümneviiendast	?kaheksakümneviiendast =kümneviienda  (SgEl  >kaheksa+kümneviienda !16_S	et	f	\N
136038	kaheksakümneviiendast	?kaheksakümneviiendast =kümneviiendas  (SgP  >kaheksa+kümneviiendane !12_A	et	f	\N
136040	kaheksakümneviiendast	?kaheksakümneviiendast =ksakümneviienda  (SgEl  >kahe+ksakümneviienda !16_S	et	f	\N
136041	kaheksakümneviiendast	?kaheksakümneviiendast =ksakümneviiendas  (SgP  >kahe+ksakümneviiendane !12_A	et	f	\N
136044	pastakas	pastakas =pastaka  (SgIn  >pastakas !02_S	et	f	\N
136045	pastakas	pastakas =pastakas  (SgN  >pastakas !02_S	et	f	\N
136053	joosta	joosta =joos  (IndPrIps_  >jooksma !32_V	et	f	\N
136054	joosta	joosta =joos  (Inf  >jooksma !32_V	et	f	\N
136058	olisi	?olisi =olisi  (ID  >olisi !41_D	et	f	\N
136067	ülekormuseni	?ülekormuseni =ülekormuse  (SgTer  >ülekormus !11~09_S	et	f	\N
136068	ülekormuseni	?ülekormuseni =ülekormuseni  (SgG  >ülekormusen !19_S	et	f	\N
136069	ülekormuseni	?ülekormuseni =ülekormuseni  (SgP  >ülekormusen !19_S	et	f	\N
136070	ülekormuseni	?ülekormuseni =ülekormuseni  (SgAdt  >ülekormusen !19_S	et	f	\N
136071	ülekormuseni	?ülekormuseni =kormuse  (SgTer  >üle+kormus !11~09_S	et	f	\N
136072	ülekormuseni	?ülekormuseni =kormuseni  (SgG  >üle+kormusen !19_S	et	f	\N
136073	ülekormuseni	?ülekormuseni =kormuseni  (SgP  >üle+kormusen !19_S	et	f	\N
136074	ülekormuseni	?ülekormuseni =kormuseni  (SgAdt  >üle+kormusen !19_S	et	f	\N
136075	reformima	reformima =reformi  (Sup  >reformima !28_V	et	f	\N
136076	reformima	reformima =ima  (SgN  >reform+ima !17_S	et	f	\N
136077	reformima	reformima =ima  (SgG  >reform+ima !17_S	et	f	\N
136078	reformima	reformima =ima  (SgP  >reform+ima !17_S	et	f	\N
136094	hetkelist	hetkelist =hetkelis  (SgP  >hetkeline !12_A	et	f	\N
136095	hetkelist	"hetkeline %hetke  )LINE_aA  <hetk ;22_S	et	f	\N
136105	nõude	nõude =nõu  (PlG  >nõu !26_S	et	f	\N
136106	nõude	nõude =nõude  (SgG  >nõue !06_S	et	f	\N
136118	üliõpilaned	### üliõpilaned	et	f	\N
136138	keeda	keeda =kee  (Inf  >keema !37_V	et	f	\N
136139	keeda	keeda =kee  (IndPrIps_  >keema !37_V	et	f	\N
136140	keeda	keeda =keeda  (IndPrPs_  >keetma !34_V	et	f	\N
136141	keeda	keeda =keeda  (ImpPrSg2  >keetma !34_V	et	f	\N
136145	restorandisse	?restorandisse =restorandi  (SgIll  >restorant !22_S	et	f	\N
136146	restorandisse	?restorandisse =restorandisse  (SgG  >restorandisne !02_A	et	f	\N
136147	restorandisse	?restorandisse =restorandisse  (PlP  >restorandiss !22_S	et	f	\N
136148	restorandisse	?restorandisse =disse  (SgN  >restoran+disse !06_S	et	f	\N
136149	restorandisse	?restorandisse =disse  (SgG  >restoran+disne !02_A	et	f	\N
136150	restorandisse	?restorandisse =disse  (SgG  >restoran+disse !06_S	et	f	\N
136151	restorandisse	?restorandisse =disse  (PlP  >restoran+diss !22_S	et	f	\N
136156	õhtusööki	õhtusööki =sööki  (SgP  >õhtu+söök !22_S	et	f	\N
136157	õhtusööki	õhtusööki =sööki  (SgAdt  >õhtu+söök !22_S	et	f	\N
136216	praantsuse	?praantsuse =praantsuse  (SgG  >praantsus !11~09_S	et	f	\N
136218	temad	?temad =tema  (IndPrSg2  >temama !27_V	et	f	\N
136244	rõhil	?rõhil =rõhi  (SgAd  >rõhi !17_S	et	f	\N
136269	inetud	inetud =inetu  (PlN  >inetu !01_A	et	f	\N
136270	inetud	"inetu %ine  )TU2_kA  <ine ;16_S	et	f	\N
136310	tasete	?tasete =tase  (IndPrPl2  >tasema !27_V	et	f	\N
136327	mustad	mustad =musta  (PlN  >must !22_AS	et	f	\N
136328	mustad	mustad =musta  (IndPrSg2  >mustama !29_V	et	f	\N
136341	torti	torti =torti  (ID  >torti !41_D	et	f	\N
136342	torti	torti =torti  (SgP  >tort !22_S	et	f	\N
136343	torti	torti =torti  (SgAdt  >tort !22_S	et	f	\N
136351	jutukas	jutukas =jutuka  (SgIn  >jutukas !02_A	et	f	\N
136352	jutukas	jutukas =jutukas  (SgN  >jutukas !02_A	et	f	\N
136360	mõmmi	mõmmi =mõmmi  (SgG  >mõmm !22_S	et	f	\N
136361	mõmmi	mõmmi =mõmmi  (SgP  >mõmm !22_S	et	f	\N
136362	mõmmi	mõmmi =mõmmi  (SgAdt  >mõmm !22_S	et	f	\N
136392	pingelistes	pingelistes =pingelis  (PlIn  >pingeline !12_A	et	f	\N
136393	pingelistes	"pingeline %pinge  )LINE_aA  <pinge ;06_S	et	f	\N
136400	kaupersega	?kaupersega =kauperse  (SgKom  >kauperne !02_A	et	f	\N
136401	brainstormi	?brainstormi =brainstormi  (SgN  >brainstormi !01_S	et	f	\N
136402	brainstormi	?brainstormi =brainstormi  (SgG  >brainstormi !01_S	et	f	\N
136403	brainstormi	?brainstormi =brainstormi  (SgG  >brainstorm !22_S	et	f	\N
136404	brainstormi	?brainstormi =brainstormi  (SgP  >brainstorm !22_S	et	f	\N
136405	brainstormi	?brainstormi =brainstormi  (SgAdt  >brainstorm !22_S	et	f	\N
136406	brainstormi	?brainstormi =brainstormi  (IndPrPs_  >brainstormima !28_V	et	f	\N
136407	brainstormi	?brainstormi =brainstormi  (ImpPrSg2  >brainstormima !28_V	et	f	\N
136409	baltiriigides	?baltiriigides =baltiriigi  (PlIn  >baltiriigi !16_S	et	f	\N
136410	baltiriigides	?baltiriigides =baltiriigi  (PlIn  >baltiriig !22_S	et	f	\N
136411	baltiriigides	?baltiriigides =baltiriigi  (Ger  >baltiriigima !28_V	et	f	\N
136412	baltiriigides	?baltiriigides =riigi  (PlIn  >balti+riigi !16_S	et	f	\N
136098	koormatud	koormatud =koorma  (PtsPtIps  >koormama !29_V	et	f	\N
136099	koormatud	koormatud =koormatu  (PlN  >koormatu !01_A	et	f	\N
136100	koormatud	"koormatu %koorma  )TU1_vS  <koormama ;29_V	et	f	\N
136101	koormatud	"koormatu %koorma  )TU2_kA  <koorem ;02_S	et	f	\N
136102	koormatud	koormatud =koormatud  (ID  >koormatud !41_A	et	f	\N
136103	koormatud	"koormatud %koorma  )TUD_vA  <koormama ;29_V	et	f	\N
136115	pedagoogilise	pedagoogilise =pedagoogilise  (SgG  >pedagoogiline !12_A	et	f	\N
136116	pedagoogilise	"pedagoogiline %pedagoogi  )LINE_aA  <pedagoog ;22_S	et	f	\N
136121	tallinnissa	?tallinnissa =tallinnissa  (SgN  >tallinnissa !16_S	et	f	\N
136122	tallinnissa	?tallinnissa =tallinnissa  (SgG  >tallinnissa !16_S	et	f	\N
136123	tallinnissa	?tallinnissa =issa  (SgN  >tallinn+issa !16_S	et	f	\N
136124	tallinnissa	?tallinnissa =issa  (SgG  >tallinn+issa !16_S	et	f	\N
136125	toivo	?toivo =toivo  (SgN  >toivo !16_S	et	f	\N
136126	toivo	?toivo =toivo  (SgG  >toivo !16_S	et	f	\N
136173	palavikku	palavikku =palavikku  (SgP  >palavik !25_S	et	f	\N
136174	palavikku	palavikku =palavikku  (SgAdt  >palavik !25_S	et	f	\N
136189	noorid	?noorid =noori  (PlN  >noori !16_S	et	f	\N
136190	noorid	?noorid =noori  (IndPrSg2  >noorima !28_V	et	f	\N
136194	lühen	?lühen =lühe  (IndPrSg1  >lühema !27_V	et	f	\N
136195	lühen	?lühen =lühen  (SgN  >lühen !02_S	et	f	\N
136204	janos	?janos =jano  (SgIn  >jano !17~16_S	et	f	\N
136205	janos	?janos =janos  (SgN  >janos !11~09_S	et	f	\N
136237	rõhi	?rõhi =rõhi  (SgN  >rõhi !17_S	et	f	\N
136238	rõhi	?rõhi =rõhi  (SgG  >rõhi !17_S	et	f	\N
136239	rõhi	?rõhi =rõhi  (SgP  >rõhi !17_S	et	f	\N
136240	rõhi	?rõhi =rõhi  (IndPrPs_  >rõhima !27_V	et	f	\N
136241	rõhi	?rõhi =rõhi  (ImpPrSg2  >rõhima !27_V	et	f	\N
136242	lastetuba	lastetuba =tuba  (SgN  >laste+tuba !18_S	et	f	\N
136243	lastetuba	lastetuba =tuba  (SgP  >laste+tuba !18_S	et	f	\N
136245	meesel	meesel =meese  (SgAd  >meene !10_A	et	f	\N
136246	meesel	"meene %mee  )NE_aA  <mesi ;15_S	et	f	\N
136262	suomi	?suomi =suomi  (SgN  >suomi !16_S	et	f	\N
136263	suomi	?suomi =suomi  (SgG  >suomi !16_S	et	f	\N
136264	suomi	?suomi =suomi  (SgG  >suom !22_S	et	f	\N
136265	suomi	?suomi =suomi  (SgP  >suom !22_S	et	f	\N
136266	suomi	?suomi =suomi  (SgAdt  >suom !22_S	et	f	\N
136267	suomi	?suomi =suomi  (IndPrPs_  >suomima !28_V	et	f	\N
136268	suomi	?suomi =suomi  (ImpPrSg2  >suomima !28_V	et	f	\N
136283	tiinal	?tiinal =tiina  (SgAd  >tiina !16_S	et	f	\N
136284	tiinal	?tiinal =tiinal  (SgN  >tiinal !02_S	et	f	\N
136306	selektiivsem	selektiivsem =selektiivsem  (SgN  >selektiivsem !02_A	et	f	\N
136307	selektiivsem	"selektiivsem %selektiivse  )M_cA  <selektiivne ;02_A	et	f	\N
136308	eraldamine	eraldamine =eraldamine  (SgN  >eraldamine !12_S	et	f	\N
136309	eraldamine	"eraldamine %eralda  )MINE_vS  <eraldama ;27_V	et	f	\N
136325	vanuses	vanuses =vanuse  (SgIn  >vanus !09_S	et	f	\N
136326	vanuses	vanuses =vanuse  (SgIn  >vanune !10_A	et	f	\N
136371	teenindavad	teenindavad =teeninda  (IndPrPl3  >teenindama !27_V	et	f	\N
136373	teenindavad	teenindavad =teenindava  (PlN  >teenindav !02_A	et	f	\N
136375	teenindavad	"teenindav %teeninda  )V_vA  <teenindama ;27_V	et	f	\N
136376	teemu	?teemu =teemu  (SgN  >teemu !16_S	et	f	\N
136377	teemu	?teemu =teemu  (SgG  >teemu !16_S	et	f	\N
136378	teemu	?teemu =teemu  (IndPrPs_  >teemuma !27_V	et	f	\N
136379	teemu	?teemu =teemu  (ImpPrSg2  >teemuma !27_V	et	f	\N
136382	tõsisest	tõsisest =tõsise  (SgEl  >tõsine !10_A	et	f	\N
136383	tõsisest	"tõsine %tõsi  )NE_aA  <tõsi ;15_S	et	f	\N
136384	teemast	teemast =teema  (SgEl  >teema !16_S	et	f	\N
136385	teemast	teemast =teemas  (SgP  >teemane !10_A	et	f	\N
136386	teemast	"teemane %teema  )NE_aA  <teema ;16_S	et	f	\N
136387	teemast	teemast =mast  (SgN  >tee+mast !22_S	et	f	\N
136388	olulises	olulises =olulise  (SgIn  >oluline !12_A	et	f	\N
136389	olulises	"oluline %olu  )LINE_aA  <olu ;17_S	et	f	\N
136408	brainstorm	?brainstorm =brainstorm  (SgN  >brainstorm !22_S	et	f	\N
136424	sellisi	?sellisi =sellisi  (ID  >sellisi !41_D	et	f	\N
136449	emailid	emailid =emaili  (PlN  >email !22_S	et	f	\N
136450	emailid	emailid =emaili  (IndPrSg2  >emailima !28_V	et	f	\N
136455	korrekstuse	?korrekstuse =korrekstuse  (SgG  >korrekstus !11~09_S	et	f	\N
136457	proovis	proovis =proovi  (SgIn  >proov !22_S	et	f	\N
136458	proovis	proovis =proovi  (IndIpfSg3  >proovima !28_V	et	f	\N
136476	büroojõulupeosest	?büroojõulupeosest =büroojõulupeose  (PlEl  >büroojõulupeos !22_S	et	f	\N
136477	büroojõulupeosest	?büroojõulupeosest =büroojõulupeoses  (SgP  >büroojõulupeosene !12_A	et	f	\N
136478	büroojõulupeosest	?büroojõulupeosest =peose  (SgEl  >büroo+jõulu+peose !06_S	et	f	\N
136479	büroojõulupeosest	?büroojõulupeosest =peoses  (SgP  >büroo+jõulu+peoses !09_S	et	f	\N
136480	büroojõulupeosest	?büroojõulupeosest =peoses  (SgP  >büroo+jõulu+peosene !10_A	et	f	\N
136481	büroojõulupeosest	?büroojõulupeosest =lupeose  (PlEl  >büroo+jõu+lupeos !22_S	et	f	\N
136482	büroojõulupeosest	?büroojõulupeosest =lupeoses  (SgP  >büroo+jõu+lupeosene !12_A	et	f	\N
136483	büroojõulupeosest	?büroojõulupeosest =jõulupeose  (PlEl  >büroo+jõulupeos !22_S	et	f	\N
136207	budapestis	?budapestis =budapestis  (SgN  >budapestis !09_S	et	f	\N
136208	budapestis	?budapestis =pesti  (SgIn  >buda+pesti !16_S	et	f	\N
136209	budapestis	?budapestis =pesti  (SgIn  >buda+pest !22_S	et	f	\N
136210	budapestis	?budapestis =pestis  (SgN  >buda+pestis !09_S	et	f	\N
136211	janosi	?janosi =janosi  (ID  >janosi !41_D	et	f	\N
136212	janosi	?janosi =janosi  (PlP  >janos !11_S	et	f	\N
136219	võileiba	võileiba =leiba  (SgP  >või+leib !22_S	et	f	\N
136220	võileiba	võileiba =leiba  (SgAdt  >või+leib !22_S	et	f	\N
136221	musträstas	musträstas =rästa  (SgIn  >must+rästas !07_S	et	f	\N
136222	musträstas	musträstas =rästas  (SgN  >must+rästas !07_S	et	f	\N
136247	janu	janu =janu  (SgN  >janu !17_S	et	f	\N
136248	janu	janu =janu  (SgG  >janu !17_S	et	f	\N
136249	janu	janu =janu  (SgP  >janu !17_S	et	f	\N
136250	janu	janu =janu  (IndPrPs_  >januma !27_V	et	f	\N
136251	janu	janu =janu  (ImpPrSg2  >januma !27_V	et	f	\N
136271	juust	juust =juus  (SgP  >juus !09_S	et	f	\N
136272	juust	juust =juust  (SgN  >juust !22_S	et	f	\N
136278	tiina	?tiina =tii  (SgEs  >tii !26_S	et	f	\N
136279	tiina	?tiina =tiina  (SgN  >tiina !16_S	et	f	\N
136280	tiina	?tiina =tiina  (SgG  >tiina !16_S	et	f	\N
136281	tiina	?tiina =tiina  (IndPrPs_  >tiinama !29_V	et	f	\N
136282	tiina	?tiina =tiina  (ImpPrSg2  >tiinama !29_V	et	f	\N
136285	cismi	?cismi =cismi  (SgN  >cismi !16_S	et	f	\N
136286	cismi	?cismi =cismi  (SgG  >cismi !16_S	et	f	\N
136287	cismi	?cismi =cismi  (SgG  >cism !22_S	et	f	\N
136288	cismi	?cismi =cismi  (SgP  >cism !22_S	et	f	\N
136289	cismi	?cismi =cismi  (SgAdt  >cism !22_S	et	f	\N
136290	cismi	?cismi =cismi  (IndPrPs_  >cismima !28_V	et	f	\N
136291	cismi	?cismi =cismi  (ImpPrSg2  >cismima !28_V	et	f	\N
136317	tulevast	tulevast =tuleva  (SgEl  >tulev !02_A	et	f	\N
136318	tulevast	"tulev %tule  )V_vA  <tulema ;36_V	et	f	\N
136319	tulevast	tulevast =tulevas  (SgP  >tulevane !12_AS	et	f	\N
136320	tulevast	tulevast =ast  (SgN  >tulev+ast !22_S	et	f	\N
136321	laiu	laiu =laiu  (SgG  >laid !22_S	et	f	\N
136322	laiu	laiu =laiu  (PlP  >lai !22_A	et	f	\N
136323	laiu	laiu =laiu  (IndPrPs_  >laiuma !27_V	et	f	\N
136324	laiu	laiu =laiu  (ImpPrSg2  >laiuma !27_V	et	f	\N
136329	käded	?käded =käde  (PlN  >käde !16_S	et	f	\N
136330	käded	?käded =käde  (IndPrSg2  >kädema !27_V	et	f	\N
136353	kingitust	kingitust =kingitu  (SgEl  >kingitu !01_AS	et	f	\N
136354	kingitust	"kingitu %kingi  )TU1_vS  <kinkima ;28_V	et	f	\N
136355	kingitust	"kingitu %kingi  )TU2_kA  <kink ;22_S	et	f	\N
136356	kingitust	kingitust =kingitus  (SgP  >kingitus !11_S	et	f	\N
136357	kingitust	"kingitus %kingi  )TUS1_aS  <kinkima ;28_V	et	f	\N
136358	kingitust	"kingitus %kingi  )TUS2_aS  <kink ;22_S	et	f	\N
136359	kingitust	kingitust =tust  (SgN  >kingi+tust !22_S	et	f	\N
136368	lastekasvatusest	lastekasvatusest =kasvatuse  (SgEl  >laste+kasvatus !11_S	et	f	\N
136369	lastekasvatusest	lastekasvatusest =kasvatuses  (SgP  >laste+kasvatusene !12_A	et	f	\N
136370	lastekasvatusest	"laste+kasvatusene %kasvatuse  )NE_aA  <laste+kasvatus ;11_S	et	f	\N
136428	pöörane	pöörane =pöörane  (SgN  >pöörane !10_A	et	f	\N
136429	pöörane	"pöörane %pööra  )NE_aA  <pöör ;22_S	et	f	\N
136430	kolmveerand	kolmveerand =and  (SgN  >kolm+veer+and !22_S	et	f	\N
136431	kolmveerand	kolmveerand =veerand  (SgN  >kolm+veerand !02_N	et	f	\N
136432	uuelt	uuelt =uue  (SgAbl  >uus !14_A	et	f	\N
136433	uuelt	uuelt =uuelt  (ID  >uuelt !41_D	et	f	\N
136434	uuelt	"uuelt %uue  )LT_mD  <uus ;14_A	et	f	\N
136462	rühma	rühma =rühma  (SgG  >rühm !22_S	et	f	\N
136464	rühma	rühma =rühma  (SgP  >rühm !22_S	et	f	\N
136466	rühma	rühma =rühma  (SgAdt  >rühm !22_S	et	f	\N
136468	rühma	rühma =rühma  (IndPrPs_  >rühmama !29_V	et	f	\N
136469	rühma	rühma =rühma  (ImpPrSg2  >rühmama !29_V	et	f	\N
136513	käitusid	käitusid =käitu  (IndIpfSg2  >käituma !27_V	et	f	\N
136514	käitusid	käitusid =käitu  (IndIpfPl3  >käituma !27_V	et	f	\N
136518	vastutust	vastutust =vastutus  (SgP  >vastutus !11_S	et	f	\N
136519	vastutust	"vastutus %vastuta  )US_vS  <vastutama ;27_V	et	f	\N
136520	vastutust	vastutust =tust  (SgN  >vastu+tust !22_S	et	f	\N
136572	tugitooli	tugitooli =tooli  (SgG  >tugi+tool !22_S	et	f	\N
136573	tugitooli	tugitooli =tooli  (SgP  >tugi+tool !22_S	et	f	\N
136574	tugitooli	tugitooli =tooli  (SgAdt  >tugi+tool !22_S	et	f	\N
136586	vaasit	?vaasit =vaasi  (SgP  >vaasi !16_S	et	f	\N
136587	vaasit	?vaasit =vaasit  (SgN  >vaasit !02_S	et	f	\N
136589	lorandi	?lorandi =lorandi  (SgN  >lorandi !01_S	et	f	\N
136590	lorandi	?lorandi =lorandi  (SgG  >lorandi !01_S	et	f	\N
136591	lorandi	?lorandi =lorandi  (SgG  >lorand !02_S	et	f	\N
136592	lorandi	?lorandi =lorandi  (SgG  >lorant !22_S	et	f	\N
136593	lorandi	?lorandi =lorandi  (IndPrPs_  >lorantima !28_V	et	f	\N
136594	lorandi	?lorandi =lorandi  (ImpPrSg2  >lorantima !28_V	et	f	\N
136595	seminarit	### seminarit	et	f	\N
136596	veerand	veerand =veerand  (SgN  >veerand !02_NS	et	f	\N
136597	veerand	veerand =and  (SgN  >veer+and !22_S	et	f	\N
136214	aastlane	?aastlane =aastlane  (IndPrPs_  >aastlanema !27_V	et	f	\N
136215	aastlane	?aastlane =aastlane  (ImpPrSg2  >aastlanema !27_V	et	f	\N
136217	talinnas	?talinnas =talinna  (SgIn  >talinna !16_S	et	f	\N
136226	kapsasta	?kapsasta =kapsasta  (SgN  >kapsasta !01_S	et	f	\N
136227	kapsasta	?kapsasta =kapsasta  (SgG  >kapsasta !01_S	et	f	\N
136228	kapsasta	?kapsasta =kapsasta  (IndPrPs_  >kapsastama !27_V	et	f	\N
136229	kapsasta	?kapsasta =kapsasta  (ImpPrSg2  >kapsastama !27_V	et	f	\N
136230	poest	poest =poe  (SgEl  >pood !22_S	et	f	\N
136231	poest	poest =poes  (SgP  >poene !10_A	et	f	\N
136232	poest	"poene %poe  )NE_aA  <pood ;22_S	et	f	\N
136233	keelavad	keelavad =keela  (IndPrPl3  >keelama !29_V	et	f	\N
136234	keelavad	keelavad =keelava  (PlN  >keelav !02_A	et	f	\N
136235	keelavad	"keelav %keela  )V_vA  <keelama ;29_V	et	f	\N
136236	keelavad	keelavad =ava  (PlN  >keel+ava !17_S	et	f	\N
136253	viinamarja	viinamarja =marja  (SgG  >viina+mari !24_S	et	f	\N
136255	viinamarja	viinamarja =marja  (SgP  >viina+mari !24_S	et	f	\N
136257	viinamarja	viinamarja =marja  (SgAdt  >viina+mari !24_S	et	f	\N
136258	nelle	?nelle =nelle  (SgN  >nelle !06_S	et	f	\N
136259	nelle	?nelle =nelle  (PlP  >nell !22_S	et	f	\N
136260	nelle	?nelle =nelle  (IndPrPs_  >nellema !30_V	et	f	\N
136261	nelle	?nelle =nelle  (ImpPrSg2  >nellema !30_V	et	f	\N
136273	tõnu	?tõnu =tõnu  (SgN  >tõnu !17_S	et	f	\N
136274	tõnu	?tõnu =tõnu  (SgG  >tõnu !17_S	et	f	\N
136275	tõnu	?tõnu =tõnu  (SgP  >tõnu !17_S	et	f	\N
136276	tõnu	?tõnu =tõnu  (IndPrPs_  >tõnuma !27_V	et	f	\N
136277	tõnu	?tõnu =tõnu  (ImpPrSg2  >tõnuma !27_V	et	f	\N
136295	muutuste	muutuste =muutus  (PlG  >muutus !11~09_S	et	f	\N
136296	muutuste	"muutus %muu  )TUS2_aS  <muu ;26_S	et	f	\N
136297	muutuste	muutuste =tuste  (PlP  >muu+tust !22_S	et	f	\N
136298	õpitud	õpitud =õpi  (PtsPtIps  >õppima !28_V	et	f	\N
136299	õpitud	õpitud =õpitu  (PlN  >õpitu !01_S	et	f	\N
136300	õpitud	"õpitu %õpi  )TU1_vS  <õppima ;28_V	et	f	\N
136301	õpitud	"õpitu %õpi  )TU2_kA  <õpp ;22_S	et	f	\N
136302	õpitud	õpitud =õpitud  (ID  >õpitud !41_A	et	f	\N
136303	õpitud	"õpitud %õpi  )TUD_vA  <õppima ;28_V	et	f	\N
136311	liigitus	liigitus =liigitu  (SgIn  >liigitu !01_AS	et	f	\N
136312	liigitus	"liigitu %liigi  )TU2_kA  <liik ;22_S	et	f	\N
136313	liigitus	liigitus =liigitu  (IndIpfSg3  >liigituma !27_V	et	f	\N
136314	liigitus	liigitus =liigitus  (SgN  >liigitus !11_S	et	f	\N
136315	liigitus	"liigitus %liigita  )US_vS  <liigitama ;27_V	et	f	\N
136316	liigitus	"liigitus %liigi  )TUS2_aS  <liik ;22_S	et	f	\N
136331	vaikesed	?vaikesed =vaikese  (PlN  >vaike !12?10_S	et	f	\N
136332	vaikesed	?vaikesed =vaikese  (PlN  >vaikene !12?10_S	et	f	\N
136333	luise	luise =luise  (SgN  >luise !06_S	et	f	\N
136334	luise	luise =luise  (SgG  >luine !10_A	et	f	\N
136335	luise	"luine %lui  )NE_aA  <luu ;26_S	et	f	\N
136336	sünnipäevapidu	sünnipäevapidu =pidu  (SgN  >sünni+päeva+pidu !17_S	et	f	\N
136337	sünnipäevapidu	sünnipäevapidu =pidu  (SgN  >sünni+päeva+pidu !18_S	et	f	\N
136338	sünnipäevapidu	sünnipäevapidu =pidu  (SgG  >sünni+päeva+pidu !17_S	et	f	\N
136339	sünnipäevapidu	sünnipäevapidu =pidu  (SgP  >sünni+päeva+pidu !17_S	et	f	\N
136340	sünnipäevapidu	sünnipäevapidu =pidu  (SgP  >sünni+päeva+pidu !18_S	et	f	\N
136349	ütleda	### ütleda	et	f	\N
136350	kuin	?kuin =kuin  (SgN  >kuin !22_S	et	f	\N
136363	pikem	pikem =pikem  (SgN  >pikem !02_A	et	f	\N
136364	pikem	"pikem %pike  )M_cA  <pikk ;22_AS	et	f	\N
136365	lihtsadest	?lihtsadest =lihtsades  (SgP  >lihtsadene !12_A	et	f	\N
136366	lihtsadest	?lihtsadest =sades  (SgP  >liht+sades !09_S	et	f	\N
136367	lihtsadest	?lihtsadest =sades  (SgP  >liht+sadene !10_A	et	f	\N
136390	vastutavates	vastutavates =vastutava  (PlIn  >vastutav !02_A	et	f	\N
136391	vastutavates	"vastutav %vastuta  )V_vA  <vastutama ;27_V	et	f	\N
136399	renars	?renars =renars  (SgN  >renars !02_S	et	f	\N
136422	huvitaks	huvitaks =huvita  (KndPrPs  >huvitama !27_V	et	f	\N
136423	huvitaks	huvitaks =taks  (SgN  >huvi+taks !22_S	et	f	\N
136437	emailsari	emailsari =sari  (SgN  >email+sari !17_S	et	f	\N
136439	emailsari	emailsari =sari  (SgN  >email+sari !24_S	et	f	\N
136441	emailsari	emailsari =sari  (SgG  >email+sari !17_S	et	f	\N
136444	emailsari	emailsari =sari  (SgP  >email+sari !17_S	et	f	\N
136497	koerast	koerast =koera  (SgEl  >koer !23?22_SA	et	f	\N
136498	koerast	koerast =koeras  (SgP  >koeras !09_S	et	f	\N
136499	koerast	koerast =koeras  (SgP  >koerane !10_A	et	f	\N
136500	koerast	"koerane %koera  )NE_aA  <koer ;22_SA	et	f	\N
136501	koerast	"koerane %koera  )NE_aA  <koer ;23_SA	et	f	\N
136504	värki	värki =värki  (SgP  >värk !22_S	et	f	\N
136505	värki	värki =värki  (SgAdt  >värk !22_S	et	f	\N
136510	artikel	?artikel =artikel  (SgN  >artikel !19_S	et	f	\N
136523	osama	?osama =osa  (Sup  >osama !27_V	et	f	\N
136524	osama	?osama =osama  (SgG  >osam !02_A	et	f	\N
136527	armunud	armunud =armu  (PtsPtPs  >armuma !27_V	et	f	\N
136528	armunud	armunud =armunu  (PlN  >armunu !01_S	et	f	\N
136529	armunud	"armunu %armu  )NU_vS  <armuma ;27_V	et	f	\N
136224	filmist	filmist =filmis  (SgP  >filmine !10_A	et	f	\N
136225	filmist	"filmine %filmi  )NE_aA  <film ;22_S	et	f	\N
136252	puut	?puut =puut  (SgN  >puut !22_S	et	f	\N
136254	õunat	?õunat =õuna  (SgP  >õuna !16_S	et	f	\N
136256	õunat	?õunat =õunat  (SgN  >õunat !02_S	et	f	\N
136292	koolisüsteemi	koolisüsteemi =süsteemi  (SgG  >kooli+süsteem !22_S	et	f	\N
136293	koolisüsteemi	koolisüsteemi =süsteemi  (SgP  >kooli+süsteem !22_S	et	f	\N
136294	koolisüsteemi	koolisüsteemi =süsteemi  (SgAdt  >kooli+süsteem !22_S	et	f	\N
136304	rohkust	rohkust =rohkus  (SgP  >rohkus !11~09_S	et	f	\N
136305	rohkust	"rohkus %rohke  )US_aS  <rohke ;01_A	et	f	\N
136344	leenale	leenale =ale  (SgN  >leen+ale !16_S	et	f	\N
136345	leenale	leenale =ale  (SgG  >leen+ale !16_S	et	f	\N
136346	ilusem	ilusem =ilusem  (SgN  >ilusem !02_A	et	f	\N
136347	ilusem	"ilusem %ilu  )SEM_cA  <ilu ;17_S	et	f	\N
136348	ilusem	"ilusem %iluse  )M_cA  <ilus ;02_A	et	f	\N
136372	natukesi	natukesi =natukesi  (PlP  >natuke !12_S	et	f	\N
136374	natukesi	natukesi =natukesi  (PlP  >natukene !12_S	et	f	\N
136380	tarbijatele	tarbijatele =tarbija  (PlAll  >tarbija !01_S	et	f	\N
136381	tarbijatele	"tarbija %tarbi  )JA_vS  <tarbima ;27_V	et	f	\N
136394	naiste-meeste	naiste-meeste =mees  (PlG  >naiste-meene !10_A	et	f	\N
136395	naiste-meeste	"naiste-meene %mee  )NE_aA  <naiste-mesi ;15_S	et	f	\N
136396	naiste-meeste	naiste-meeste =mees  (PlG  >naiste-mees !13_S	et	f	\N
136397	intervjuu	intervjuu =intervjuu  (SgN  >intervjuu !26_S	et	f	\N
136398	intervjuu	intervjuu =intervjuu  (SgG  >intervjuu !26_S	et	f	\N
136445	organiseermisest	?organiseermisest =organiseermise  (SgEl  >organiseermine !12_A	et	f	\N
136447	personaliosakonnast	personaliosakonnast =konna  (SgEl  >personali+osa+konn !22_S	et	f	\N
136448	personaliosakonnast	personaliosakonnast =konnas  (SgP  >personali+osa+konnane !10_A	et	f	\N
136451	personaliosakonnast	"personali+osa+konnane %konna  )NE_aA  <personali+osa+konn ;22_S	et	f	\N
136452	personaliosakonnast	personaliosakonnast =osakonna  (SgEl  >personali+osakond !22_S	et	f	\N
136453	personaliosakonnast	personaliosakonnast =osakonnas  (SgP  >personali+osakonnane !12_A	et	f	\N
136454	personaliosakonnast	"personali+osakonnane %osakonna  )NE_aA  <personali+osakond ;22_S	et	f	\N
136485	proovitakse	proovitakse =proovi  (IndPrIps  >proovima !28_V	et	f	\N
136486	proovitakse	proovitakse =takse  (PlP  >proovi+taks !22_S	et	f	\N
136502	lehtesi	lehtesi =esi  (SgN  >leht+esi !15_S	et	f	\N
136503	lehtesi	lehtesi =esi  (PlP  >leht+esi !15_S	et	f	\N
136511	häbinägu	häbinägu =nägu  (SgN  >häbi+nägu !18_S	et	f	\N
136512	häbinägu	häbinägu =nägu  (SgP  >häbi+nägu !18_S	et	f	\N
136515	ometigi	ometigi =ometigi  (ID  >ometigi !41_D	et	f	\N
136516	ometigi	ometigi =ometi  (ID^  >ometi !41_D	et	f	\N
136554	carmeni	?carmeni =carme  (SgTer  >carme !06_S	et	f	\N
136555	carmeni	?carmeni =carmeni  (SgG  >carmen !02_S	et	f	\N
136556	kurjaks	?kurjaks =kurja  (SgTr  >kurjas !02_A	et	f	\N
136557	kurjaks	?kurjaks =kurja  (SgTr  >kurja !16_S	et	f	\N
136558	kurjaks	?kurjaks =kurja  (SgTr  >kuri !24_A	et	f	\N
136559	kurjaks	?kurjaks =kurja  (KndPrPs  >kurjama !29_V	et	f	\N
136565	raamaturiiul	raamaturiiul =riiu  (SgAd  >raamatu+riid !22_S	et	f	\N
136566	raamaturiiul	raamaturiiul =riiul  (SgN  >raamatu+riiul !02_S	et	f	\N
136610	keeleteadust	keeleteadust =teadu  (SgEl  >keele+tead !22_S	et	f	\N
136611	keeleteadust	keeleteadust =teadus  (SgP  >keele+teadus !11~09_S	et	f	\N
136627	vaiksemas	vaiksemas =vaiksema  (SgIn  >vaiksem !02_A	et	f	\N
136628	vaiksemas	"vaiksem %vaikse  )M_cA  <vaikne ;02_A	et	f	\N
136638	praktikumi	praktikumi =praktikumi  (SgG  >praktikum !19_S	et	f	\N
136639	praktikumi	praktikumi =praktikumi  (SgP  >praktikum !19_S	et	f	\N
136640	praktikumi	praktikumi =praktikumi  (SgAdt  >praktikum !19_S	et	f	\N
136651	harjutused	harjutused =harjutuse  (PlN  >harjutus !11_S	et	f	\N
136653	harjutused	"harjutus %harjuta  )US_vS  <harjutama ;27_V	et	f	\N
136654	harjutused	"harjutus %harju  )TUS1_aS  <harjuma ;27_V	et	f	\N
136659	koristana	?koristana =korista  (SgEs  >korista !01_S	et	f	\N
136701	astal	?astal =asta  (SgAd  >asta !16_S	et	f	\N
136702	astal	?astal =astal  (SgN  >astal !02_S	et	f	\N
136724	maitseaine	maitseaine =aine  (SgN  >maitse+aine !06_S	et	f	\N
136725	maitseaine	maitseaine =aine  (SgG  >maitse+aine !06_S	et	f	\N
136726	maitseaine	maitseaine =aine  (PlP  >maitse+ain !22_S	et	f	\N
136733	koolilastel	koolilastel =las  (PlAd  >kooli+laps !14_S	et	f	\N
136734	koolilastel	koolilastel =laste  (PlAd  >kooli+last !22_S	et	f	\N
136735	koolilastel	koolilastel =ilas  (PlAd  >kool+ilane !10_A	et	f	\N
136736	koolilastel	"kool+ilane %ila  )NE_aA  <kool+ila ;17_S	et	f	\N
136741	külaühiskonda	külaühiskonda =ühiskonda  (SgP  >küla+ühiskond !22_S	et	f	\N
136742	külaühiskonda	külaühiskonda =ühiskonda  (SgAdt  >küla+ühiskond !22_S	et	f	\N
136743	teadusraamatud	teadusraamatud =atu  (PlN  >teadus+raam+att !22_S	et	f	\N
136744	teadusraamatud	teadusraamatud =raamatu  (PlN  >teadus+raamat !02_S	et	f	\N
136745	talupoegadet	?talupoegadet =ade  (SgP  >talu+poeg+ade !16_S	et	f	\N
136746	talupoegadet	?talupoegadet =gade  (SgP  >talu+poe+gade !16_S	et	f	\N
136754	kirjandusvool	kirjandusvool =voo  (SgAd  >kirjandus+voog !22_S	et	f	\N
136413	baltiriigides	?baltiriigides =riigi  (PlIn  >balti+riig !22_S	et	f	\N
136414	baltiriigides	?baltiriigides =iriigi  (PlIn  >balt+iriigi !16_S	et	f	\N
136415	baltiriigides	?baltiriigides =iriigi  (PlIn  >balt+iriig !22_S	et	f	\N
136416	moest	moest =moe  (SgEl  >mood !22_S	et	f	\N
136417	moest	moest =moes  (SgP  >moene !10_A	et	f	\N
136418	moest	"moene %moe  )NE_aA  <mood ;22_S	et	f	\N
136419	renarsile	?renarsile =renarsi  (SgAll  >renarsi !01_S	et	f	\N
136420	renarsile	?renarsile =renarsi  (SgAll  >renars !02_S	et	f	\N
136421	renarsile	?renarsile =renarsi  (SgAll  >renarss !22_S	et	f	\N
136425	otsis	otsis =otsi  (SgIn  >ots !22_S	et	f	\N
136426	otsis	otsis =otsi  (PlIn  >ots !23?22_S	et	f	\N
136427	otsis	otsis =otsi  (IndIpfSg3  >otsima !28_V	et	f	\N
136435	väljamõeldud	väljamõeldud =mõel  (PtsPtIps  >välja+_mõtlema !30_V	et	f	\N
136436	väljamõeldud	väljamõeldud =mõeldu  (PlN  >välja+mõeldu !01_S	et	f	\N
136438	jõulupidu	jõulupidu =pidu  (SgN  >jõulu+pidu !17_S	et	f	\N
136440	jõulupidu	jõulupidu =pidu  (SgN  >jõulu+pidu !18_S	et	f	\N
136442	jõulupidu	jõulupidu =pidu  (SgG  >jõulu+pidu !17_S	et	f	\N
136443	jõulupidu	jõulupidu =pidu  (SgP  >jõulu+pidu !17_S	et	f	\N
136446	jõulupidu	jõulupidu =pidu  (SgP  >jõulu+pidu !18_S	et	f	\N
136456	poliitikaalse	?poliitikaalse =poliitikaalse  (SgG  >poliitikaalne !02_A	et	f	\N
136459	poliitikaalse	?poliitikaalse =poliitikaalse  (PlP  >poliitikaals !22_S	et	f	\N
136460	poliitikaalse	?poliitikaalse =alse  (SgN  >poliitika+alse !06_S	et	f	\N
136461	poliitikaalse	?poliitikaalse =alse  (SgG  >poliitika+alne !02_A	et	f	\N
136463	poliitikaalse	?poliitikaalse =alse  (PlP  >poliitika+als !22_S	et	f	\N
136465	poliitikaalse	?poliitikaalse =ikaalse  (SgG  >poliit+ikaalne !02_A	et	f	\N
136467	poliitikaalse	?poliitikaalse =ikaalse  (PlP  >poliit+ikaals !22_S	et	f	\N
136470	õigse	?õigse =õigse  (SgN  >õigse !06_S	et	f	\N
136471	õigse	?õigse =õigse  (SgG  >õigne !02_A	et	f	\N
136472	õigse	?õigse =õigse  (SgG  >õigse !06_S	et	f	\N
136473	õigse	?õigse =õigse  (PlP  >õigs !22_S	et	f	\N
136474	õigse	?õigse =õigse  (IndPrPs_  >õigsema !27_V	et	f	\N
136475	õigse	?õigse =õigse  (ImpPrSg2  >õigsema !27_V	et	f	\N
136506	reklaamitakse	reklaamitakse =reklaami  (IndPrIps  >reklaamima !28_V	et	f	\N
136508	reklaamitakse	reklaamitakse =takse  (PlP  >reklaami+taks !22_S	et	f	\N
136526	yeslam	?yeslam =yeslam  (SgN  >yeslam !02_A	et	f	\N
136532	saudi-araabias	?saudi-araabias =araabia  (SgIn  >saudi-araabia !01_S	et	f	\N
136533	saudi-araabias	?saudi-araabias =araabias  (SgN  >saudi-araabias !11_S	et	f	\N
136534	saudi-araabias	?saudi-araabias =abia  (SgIn  >saudi-ara+abia !01_S	et	f	\N
136536	saudi-araabias	?saudi-araabias =abias  (SgN  >saudi-ara+abias !11_S	et	f	\N
136540	moderni	?moderni =moderni  (SgN  >moderni !01_S	et	f	\N
136541	moderni	?moderni =moderni  (SgG  >moderni !01_S	et	f	\N
136542	moderni	?moderni =moderni  (SgG  >modern !22_A	et	f	\N
136543	moderni	?moderni =moderni  (SgP  >modern !22_A	et	f	\N
136544	moderni	?moderni =moderni  (SgAdt  >modern !22_A	et	f	\N
136545	moderni	?moderni =moderni  (IndPrPs_  >modernima !28_V	et	f	\N
136546	moderni	?moderni =moderni  (ImpPrSg2  >modernima !28_V	et	f	\N
136547	iraanis	?iraanis =iraani  (SgIn  >iraani !16_S	et	f	\N
136548	iraanis	?iraanis =iraani  (SgIn  >iraan !22_S	et	f	\N
136549	iraanis	?iraanis =iraani  (IndIpfSg3  >iraanima !28_V	et	f	\N
136550	iraanis	?iraanis =iraanis  (SgN  >iraanis !09_S	et	f	\N
136560	selguks	selguks =selgu  (KndPrPs  >selguma !27_V	et	f	\N
136561	selguks	selguks =uks  (SgN  >selg+uks !14_S	et	f	\N
136577	aks	?aks =aks  (SgN  >aks !22_S	et	f	\N
136578	neben	?neben =nebe  (IndPrSg1  >nebema !27_V	et	f	\N
136579	neben	?neben =neben  (SgN  >neben !02_S	et	f	\N
136600	mule	?mule =mule  (SgN  >mule !16_S	et	f	\N
136601	mule	?mule =mule  (SgG  >mule !16_S	et	f	\N
136602	mule	?mule =mule  (IndPrPs_  >mulema !27_V	et	f	\N
136603	mule	?mule =mule  (ImpPrSg2  >mulema !27_V	et	f	\N
136613	hariduslugu	hariduslugu =lugu  (SgN  >haridus+lugu !18_S	et	f	\N
136614	hariduslugu	hariduslugu =lugu  (SgP  >haridus+lugu !18_S	et	f	\N
136624	juustu	juustu =juustu  (SgG  >juust !22_S	et	f	\N
136625	juustu	juustu =juustu  (SgP  >juust !22_S	et	f	\N
136626	juustu	juustu =juustu  (SgAdt  >juust !22_S	et	f	\N
136643	nädalavahetust	nädalavahetust =us  (SgP  >nädala+vahet+uks !14_S	et	f	\N
136644	nädalavahetust	nädalavahetust =tust  (SgN  >nädala+vahe+tust !22_S	et	f	\N
136645	nädalavahetust	nädalavahetust =vahetu  (SgEl  >nädala+vahetu !01_A	et	f	\N
136646	nädalavahetust	"nädala+vahetu %vahe  )TU2_kA  <nädala+vahe ;16_S	et	f	\N
136647	nädalavahetust	nädalavahetust =vahetus  (SgP  >nädala+vahetus !11_S	et	f	\N
136648	nädalavahetust	"nädala+vahetus %vahe  )TUS2_aS  <nädala+vahe ;16_S	et	f	\N
136660	vahest	vahest =vahe  (SgEl  >vahe !16_S	et	f	\N
136661	vahest	vahest =vahe  (PlEl  >vahk !22_S	et	f	\N
136662	vahest	vahest =vahe  (PlEl  >vaht !22_S	et	f	\N
136663	vahest	vahest =vahes  (SgP  >vahene !10_A	et	f	\N
136665	vahest	"vahene %vahe  )NE_aA  <vahe ;16_S	et	f	\N
136666	vahest	vahest =vahest  (ID  >vahest !41_D	et	f	\N
136671	kellegagi	kellegagi =kelle  (SgKom  >keegi !00_P	et	f	\N
136484	büroojõulupeosest	?büroojõulupeosest =jõulupeoses  (SgP  >büroo+jõulupeosene !12_A	et	f	\N
136487	huvitavamaks	huvitavamaks =huvitavama  (SgTr  >huvitavam !02_A	et	f	\N
136488	huvitavamaks	"huvitavam %huvita  )VAM_cA  <huvitama ;27_V	et	f	\N
136489	huvitavamaks	"huvitavam %huvitava  )M_cA  <huvitav ;02_A	et	f	\N
136490	huvitavamaks	huvitavamaks =maks  (SgN  >huvi+tava+maks !22_S	et	f	\N
136491	poliitiklastest	?poliitiklastest =poliitiklas  (PlEl  >poliitiklane !12_S	et	f	\N
136492	poliitiklastest	?poliitiklastest =poliitiklaste  (PlEl  >poliitiklast !22_S	et	f	\N
136493	poliitiklastest	?poliitiklastest =poliitiklastes  (SgP  >poliitiklastene !12_A	et	f	\N
136494	poliitiklastest	?poliitiklastest =iklas  (PlEl  >poliit+iklas !07_S	et	f	\N
136495	poliitiklastest	?poliitiklastest =iklas  (PlEl  >poliit+iklane !12?10_S	et	f	\N
136496	poliitiklastest	?poliitiklastest =iklastes  (SgP  >poliit+iklastene !12_A	et	f	\N
136507	silmakompress	silmakompress =press  (SgN  >silma+kom+press !22_S	et	f	\N
136509	silmakompress	silmakompress =kompress  (SgN  >silma+kompress !22_S	et	f	\N
136517	olukorrasid	?olukorrasid =olukorra  (PlP  >olukorra !16_S	et	f	\N
136521	carmen	?carmen =carme  (IndPrSg1  >carmema !27_V	et	f	\N
136522	carmen	?carmen =carmen  (SgN  >carmen !02_S	et	f	\N
136525	bin	### bin	et	f	\N
136551	meikitud	?meikitud =meikitu  (PlN  >meikitu !01_AS	et	f	\N
136552	meikitud	?meikitud =meikitu  (IndPrSg2  >meikituma !27_V	et	f	\N
136553	meikitud	?meikitud =meikitud  (ID  >meikitud !41_A	et	f	\N
136562	kapi	kapi =kapi  (SgG  >kapp !22_S	et	f	\N
136563	kapi	kapi =kapi  (IndPrPs_  >kappima !28_V	et	f	\N
136564	kapi	kapi =kapi  (ImpPrSg2  >kappima !28_V	et	f	\N
136580	patja	patja =patja  (SgP  >padi !24_S	et	f	\N
136581	patja	patja =patja  (SgAdt  >padi !24_S	et	f	\N
136582	tekki	tekki =tekki  (SgP  >tekk !22_S	et	f	\N
136583	tekki	tekki =tekki  (SgAdt  >tekk !22_S	et	f	\N
136584	tekki	tekki =tekki  (IndPrPs_  >tekkima !27_V	et	f	\N
136585	tekki	tekki =tekki  (ImpPrSg2  >tekkima !27_V	et	f	\N
136588	eötvös	### eötvös	et	f	\N
136606	keeletundi	keeletundi =tundi  (SgP  >keele+tund !22_S	et	f	\N
136607	keeletundi	keeletundi =tundi  (SgAdt  >keele+tund !22_S	et	f	\N
136612	fagotit	?fagotit =fagoti  (SgP  >fagot !02_S	et	f	\N
136618	margariini	margariini =margariini  (SgG  >margariin !22_S	et	f	\N
136619	margariini	margariini =margariini  (SgP  >margariin !22_S	et	f	\N
136620	margariini	margariini =margariini  (SgAdt  >margariin !22_S	et	f	\N
136629	kapsast	kapsast =kapsa  (SgEl  >kapsas !07_S	et	f	\N
136630	kapsast	kapsast =kapsas  (SgP  >kapsas !07_S	et	f	\N
136631	kapsast	kapsast =kapsas  (SgP  >kapsane !10_A	et	f	\N
136632	kapsast	"kapsane %kapsa  )NE_aA  <kapsas ;07_S	et	f	\N
136633	laata	laata =laata  (SgP  >laat !22_S	et	f	\N
136634	laata	laata =laata  (SgAdt  >laat !22_S	et	f	\N
136635	inimeest	inimeest =ee  (SgEl  >inim+esi !15_S	et	f	\N
136636	inimeest	inimeest =ees  (SgP  >inim+eene !10_A	et	f	\N
136637	inimeest	"inim+eene %ee  )NE_aA  <inim+esi ;15_S	et	f	\N
136641	reeda	reeda =reeda  (IndPrPs_  >reetma !34_V	et	f	\N
136642	reeda	reeda =reeda  (ImpPrSg2  >reetma !34_V	et	f	\N
136652	tööma	?tööma =tööma  (SgN  >tööma !16_S	et	f	\N
136655	tööma	?tööma =tööma  (SgG  >tööma !16_S	et	f	\N
136656	tööma	?tööma =tööma  (IndPrPs_  >töömama !29_V	et	f	\N
136657	tööma	?tööma =tööma  (ImpPrSg2  >töömama !29_V	et	f	\N
136667	hommikusööki	hommikusööki =sööki  (SgP  >hommiku+söök !22_S	et	f	\N
136668	hommikusööki	hommikusööki =sööki  (SgAdt  >hommiku+söök !22_S	et	f	\N
136675	läikima	läikima =läiki  (Sup  >läikima !28_V	et	f	\N
136678	läikima	läikima =ima  (SgN  >läik+ima !17_S	et	f	\N
136681	läikima	läikima =ima  (SgG  >läik+ima !17_S	et	f	\N
136684	läikima	läikima =ima  (SgP  >läik+ima !17_S	et	f	\N
136685	tuled	tuled =tule  (PlN  >tuli !20_S	et	f	\N
136686	tuled	tuled =tule  (IndPrSg2  >tulema !36_V	et	f	\N
136705	km	### km	et	f	\N
136713	puhkepäeviti	?puhkepäeviti =puhkepäevi  (IndIpfIps  >puhkepäevima !28_V	et	f	\N
136714	puhkepäeviti	?puhkepäeviti =puhkepäeviti  (ID  >puhkepäeviti !41_D	et	f	\N
136715	puhkepäeviti	?puhkepäeviti =puhkepäeviti  (SgG  >puhkepäevitt !22_S	et	f	\N
136716	puhkepäeviti	?puhkepäeviti =puhkepäeviti  (IndPrPs_  >puhkepäevittima !28_V	et	f	\N
136717	puhkepäeviti	?puhkepäeviti =puhkepäeviti  (ImpPrSg2  >puhkepäevittima !28_V	et	f	\N
136718	puhkepäeviti	?puhkepäeviti =iti  (SgN  >puhke+päev+iti !16_S	et	f	\N
136719	puhkepäeviti	?puhkepäeviti =iti  (SgG  >puhke+päev+iti !16_S	et	f	\N
136720	puhkepäeviti	?puhkepäeviti =iti  (SgG  >puhke+päev+itt !22_S	et	f	\N
136721	puhkepäeviti	?puhkepäeviti =päeviti  (SgG  >puhke+päevit !02_S	et	f	\N
136722	puhkepäeviti	?puhkepäeviti =päeviti  (SgG  >puhke+päevitt !22_S	et	f	\N
136723	puhkepäeviti	?puhkepäeviti =epäeviti  (SgG  >puhk+epäevitt !22_S	et	f	\N
136747	vaqbatahtlikult	?vaqbatahtlikult =vaqbatahtliku  (SgAbl  >vaqbatahtlik !25_A	et	f	\N
136748	vaqbatahtlikult	?vaqbatahtlikult =vaqbatahtlikult  (ID  >vaqbatahtlikult !41_D	et	f	\N
136756	tunnistati	tunnistati =tunnista  (IndIpfIps  >tunnistama !27_V	et	f	\N
136757	tunnistati	tunnistati =tati  (SgG  >tunnis+tatt !22_S	et	f	\N
136530	armunud	armunud =armunud  (ID  >armunud !41_A	et	f	\N
136531	armunud	"armunud %armu  )NUD_vA  <armuma ;27_V	et	f	\N
136535	carmenil	?carmenil =carmeni  (SgAd  >carmen !02_S	et	f	\N
136537	paistas	?paistas =paista  (SgIn  >paista !01_S	et	f	\N
136538	paistas	?paistas =paista  (IndIpfSg3  >paistama !27_V	et	f	\N
136539	paistas	?paistas =paistas  (SgN  >paistas !07_S	et	f	\N
136567	väikest	väikest =väikes  (SgP  >väike !12?10_A	et	f	\N
136568	väikest	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
136569	väikest	väikest =väikes  (SgP  >väikene !12?10_A	et	f	\N
136570	väikest	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
136571	väikest	väikest =kest  (SgN  >väi+kest !22_S	et	f	\N
136575	treppi	treppi =treppi  (SgP  >trepp !22_S	et	f	\N
136576	treppi	treppi =treppi  (SgAdt  >trepp !22_S	et	f	\N
136604	etnograafia	etnograafia =etnograafia  (SgN  >etnograafia !01_S	et	f	\N
136605	etnograafia	etnograafia =etnograafia  (SgG  >etnograafia !01_S	et	f	\N
136608	keeleteadus	keeleteadus =teadu  (SgIn  >keele+tead !22_S	et	f	\N
136609	keeleteadus	keeleteadus =teadus  (SgN  >keele+teadus !11~09_S	et	f	\N
136621	vorsti	vorsti =vorsti  (SgG  >vorst !22_S	et	f	\N
136622	vorsti	vorsti =vorsti  (SgP  >vorst !22_S	et	f	\N
136623	vorsti	vorsti =vorsti  (SgAdt  >vorst !22_S	et	f	\N
136658	pidab	### pidab	et	f	\N
136669	kaarte	kaarte =kaar  (PlG  >kaar !13_S	et	f	\N
136670	kaarte	kaarte =kaarte  (PlP  >kaart !22_S	et	f	\N
136696	lillele	lillele =lille  (SgAll  >lill !22_S	et	f	\N
136697	lillele	lillele =lille  (PlAll  >lill !22_S	et	f	\N
136700	suvipuhkeajag	### suvipuhkeajag	et	f	\N
136727	laise	?laise =laise  (SgN  >laise !06_S	et	f	\N
136728	laise	?laise =laise  (SgG  >laise !06_S	et	f	\N
136729	laise	?laise =laise  (PlP  >lais !22_S	et	f	\N
136730	laise	?laise =laise  (IndPrPs_  >laisema !28_V	et	f	\N
136731	laise	?laise =laise  (ImpPrSg2  >laisema !28_V	et	f	\N
136737	hivid	?hivid =hivi  (PlN  >hivi !17_S	et	f	\N
136738	hivid	?hivid =hivi  (IndPrSg2  >hivima !27_V	et	f	\N
136772	kustuti	kustuti =kustu  (IndIpfIps  >kustuma !28_V	et	f	\N
136773	kustuti	kustuti =kustuti  (SgN  >kustuti !01_S	et	f	\N
136774	kustuti	kustuti =kustuti  (SgG  >kustuti !01_S	et	f	\N
136775	kustuti	kustuti =uti  (SgG  >kust+utt !22_S	et	f	\N
136776	kustuti	kustuti =tuti  (SgG  >kus+tutt !22_S	et	f	\N
136777	jätkasid	jätkasid =jätka  (IndIpfSg2  >jätkama !29_V	et	f	\N
136778	jätkasid	jätkasid =jätka  (IndIpfPl3  >jätkama !29_V	et	f	\N
136797	õitses	õitses =õitse  (IndIpfSg3  >õitsma !32_V	et	f	\N
136799	õitses	õitses =õitse  (IndIpfSg3  >õitsema !28_V	et	f	\N
136811	formaalseteks	formaalseteks =formaalse  (PlTr  >formaalne !02_A	et	f	\N
136813	formaalseteks	formaalseteks =sete  (PlTr  >formaal+sett !22_S	et	f	\N
136824	trükivabaduse	trükivabaduse =vabaduse  (SgG  >trüki+vabadus !11_S	et	f	\N
136825	trükivabaduse	"trüki+vabadus %vaba  )US_aS  <trüki+vaba ;17_A	et	f	\N
136857	küüdiatmist	?küüdiatmist =küüdiatmi  (SgEl  >küüdiatm !22_S	et	f	\N
136858	küüdiatmist	?küüdiatmist =küüdiatmis  (SgP  >küüdiatmis !09_S	et	f	\N
136859	küüdiatmist	?küüdiatmist =küüdiatmis  (SgP  >küüdiatmine !12_A	et	f	\N
136860	küüdiatmist	?küüdiatmist =küüdiatmist  (SgN  >küüdiatmist !22_S	et	f	\N
136874	kamuniste	?kamuniste =kamunis  (PlG  >kamunis !11_S	et	f	\N
136875	kamuniste	?kamuniste =kamuniste  (PlP  >kamunist !22_S	et	f	\N
136888	valdkondi	valdkondi =valdkondi  (SgP  >valdkond !22_S	et	f	\N
136889	valdkondi	valdkondi =valdkondi  (SgAdt  >valdkond !22_S	et	f	\N
136890	valdkondi	valdkondi =valdkondi  (PlP  >valdkond !22_S	et	f	\N
136891	valdkondi	valdkondi =kondi  (SgG  >vald+kont !22_S	et	f	\N
136894	veski	veski =veski  (SgN  >veski !01_S	et	f	\N
136895	veski	veski =veski  (SgG  >veski !01_S	et	f	\N
136902	kõrgele	kõrgele =kõrge  (SgAll  >kõrge !01_A	et	f	\N
136903	kõrgele	kõrgele =kõrge  (PlAll  >kõrk !22_A	et	f	\N
136904	kõrgele	kõrgele =kõrgele  (ID  >kõrgele !41_D	et	f	\N
136927	kuskohas	kuskohas =koha  (SgIn  >kus+koha !17_S	et	f	\N
136928	kuskohas	kuskohas =koha  (SgIn  >kus+koht !22_S	et	f	\N
136939	ebaeffektiivne	?ebaeffektiivne =ebaeffektiivne  (SgN  >ebaeffektiivne !02_A	et	f	\N
136940	ebaeffektiivne	?ebaeffektiivne =ebaeffektiivne  (PlP  >ebaeffektiivn !22_S	et	f	\N
136941	ebaeffektiivne	?ebaeffektiivne =effektiivne  (SgN  >eba+effektiivne !02_A	et	f	\N
136942	ebaeffektiivne	?ebaeffektiivne =effektiivne  (PlP  >eba+effektiivn !22_S	et	f	\N
136972	soveticus	?soveticus =soveticus  (SgN  >soveticus !11?09_S	et	f	\N
136980	energetika	?energetika =energetika  (SgN  >energetika !01_S	et	f	\N
136981	energetika	?energetika =energetika  (SgG  >energetika !01_S	et	f	\N
136982	energetika	?energetika =energetika  (SgG  >energetikas !02_A	et	f	\N
136993	mitmetest	mitmetest =mitme  (PlEl  >mitu !05_P	et	f	\N
136994	mitmetest	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
136995	mitmetest	mitmetest =test  (SgN  >mitme+test !22_S	et	f	\N
137042	muretsenud	muretsenud =muretse  (PtsPtPs  >muretsema !27_V	et	f	\N
137043	muretsenud	muretsenud =muretsenu  (PlN  >muretsenu !01_S	et	f	\N
137044	muretsenud	"muretsenu %muretse  )NU_vS  <muretsema ;27_V	et	f	\N
136598	fagotti	fagotti =fagotti  (SgP  >fagott !22_S	et	f	\N
136599	fagotti	fagotti =fagotti  (SgAdt  >fagott !22_S	et	f	\N
136615	laupäeva	laupäeva =päeva  (SgG  >lau+päev !22_S	et	f	\N
136616	laupäeva	laupäeva =päeva  (SgP  >lau+päev !22_S	et	f	\N
136617	laupäeva	laupäeva =päeva  (SgAdt  >lau+päev !22_S	et	f	\N
136649	jos	### jos	et	f	\N
136650	mut	### mut	et	f	\N
136664	tantsimajase	?tantsimajase =tantsimajase  (SgG  >tantsimajane !12_A	et	f	\N
136676	löömalõi	?löömalõi =löömalõi  (SgN  >löömalõi !26_S	et	f	\N
136677	löömalõi	?löömalõi =löömalõi  (SgG  >löömalõi !26_S	et	f	\N
136679	löömalõi	?löömalõi =lõi  (SgN  >lööma+lõi !26_S	et	f	\N
136683	löömalõi	?löömalõi =lõi  (SgG  >lööma+lõi !26_S	et	f	\N
136687	mesilane	mesilane =mesilane  (SgN  >mesilane !12_S	et	f	\N
136688	mesilane	"mesilane %mesila  )NE_aA  <mesila ;01_S	et	f	\N
136689	vihmaussi	vihmaussi =ussi  (SgG  >vihma+uss !22_S	et	f	\N
136690	vihmaussi	vihmaussi =ussi  (SgP  >vihma+uss !22_S	et	f	\N
136691	vihmaussi	vihmaussi =ussi  (SgAdt  >vihma+uss !22_S	et	f	\N
136692	ootamiseks	ootamiseks =ootamise  (SgTr  >ootamine !12_S	et	f	\N
136693	ootamiseks	"ootamine %oota  )MINE_vS  <ootama ;29_V	et	f	\N
136698	huvitavates	huvitavates =huvitava  (PlIn  >huvitav !02_A	et	f	\N
136699	huvitavates	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
136703	suvila	suvila =suvila  (SgN  >suvila !01_S	et	f	\N
136704	suvila	suvila =suvila  (SgG  >suvila !01_S	et	f	\N
136732	prantlased	?prantlased =prantlase  (PlN  >prantlane !12?10_S	et	f	\N
136749	laostunud	laostunud =laostu  (PtsPtPs  >laostuma !27_V	et	f	\N
136750	laostunud	laostunud =laostunu  (PlN  >laostunu !01_S	et	f	\N
136751	laostunud	"laostunu %laostu  )NU_vS  <laostuma ;27_V	et	f	\N
136752	laostunud	laostunud =laostunud  (ID  >laostunud !41_A	et	f	\N
136753	laostunud	"laostunud %laostu  )NUD_vA  <laostuma ;27_V	et	f	\N
136760	teadustekeskuseks	?teadustekeskuseks =teadustekeskuse  (SgTr  >teadustekeskus !11~09_S	et	f	\N
136761	teadustekeskuseks	?teadustekeskuseks =tekeskuse  (SgTr  >teadus+tekeskus !11_S	et	f	\N
136762	teadustekeskuseks	?teadustekeskuseks =stekeskuse  (SgTr  >teadu+stekeskus !11_S	et	f	\N
136767	jätkunud	jätkunud =jätku  (PtsPtPs  >jätkuma !27_V	et	f	\N
136768	jätkunud	jätkunud =jätkunu  (PlN  >jätkunu !01_S	et	f	\N
136769	jätkunud	"jätkunu %jätku  )NU_vS  <jätkuma ;27_V	et	f	\N
136770	jätkunud	jätkunud =jätkunud  (ID  >jätkunud !41_A	et	f	\N
136771	jätkunud	"jätkunud %jätku  )NUD_vA  <jätkuma ;27_V	et	f	\N
136817	massiliselt	massiliselt =massilise  (SgAbl  >massiline !12_A	et	f	\N
136818	massiliselt	"massiline %massi  )LINE_aA  <mass ;22_S	et	f	\N
136819	massiliselt	massiliselt =massiliselt  (ID  >massiliselt !41_D	et	f	\N
136820	massiliselt	"massiliselt %massi  )LISELT_mD  <mass ;22_S	et	f	\N
136821	massiliselt	"massiliselt %massilise  )LT_mD  <massiline ;12_A	et	f	\N
136831	kunstniketega	?kunstniketega =nike  (PlKom  >kunst+nike !06_S	et	f	\N
136832	hävitamine	hävitamine =hävitamine  (SgN  >hävitamine !12_S	et	f	\N
136833	hävitamine	"hävitamine %hävita  )MINE_vS  <hävitama ;27_V	et	f	\N
136844	sohvoosid	?sohvoosid =sohvoo  (PlP  >sohvoo !26_S	et	f	\N
136845	sohvoosid	?sohvoosid =sohvoosi  (PlN  >sohvoosi !16_S	et	f	\N
136846	sohvoosid	?sohvoosid =sohvoosi  (PlN  >sohvoos !22_S	et	f	\N
136847	sohvoosid	?sohvoosid =sohvoosi  (IndPrSg2  >sohvoosima !28_V	et	f	\N
136851	vaesemad	vaesemad =vaesema  (PlN  >vaesem !02_A	et	f	\N
136852	vaesemad	"vaesem %vae  )SEM_cA  <vaag ;22_S	et	f	\N
136853	vaesemad	"vaesem %vaese  )M_cA  <vaene ;10_AS	et	f	\N
136854	vaesemad	vaesemad =ema  (PlN  >vaes+ema !17_S	et	f	\N
136861	soetud	soetud =soe  (PtsPtIps  >sugema !28_V	et	f	\N
136862	soetud	soetud =soetu  (PlN  >soetu !01_S	et	f	\N
136863	soetud	"soetu %soe  )TU1_vS  <sugema ;28_V	et	f	\N
136864	soetud	"soetu %soe  )TU2_kA  <susi ;15_S	et	f	\N
136865	soetud	soetud =soetu  (IndPrSg2  >soetuma !27_V	et	f	\N
136866	soetud	soetud =soetud  (ID  >soetud !41_A	et	f	\N
136867	soetud	"soetud %soe  )TUD_vA  <sugema ;28_V	et	f	\N
136886	arendasid	arendasid =arenda  (IndIpfSg2  >arendama !27_V	et	f	\N
136887	arendasid	arendasid =arenda  (IndIpfPl3  >arendama !27_V	et	f	\N
136896	ariste	?ariste =aris  (PlG  >aris !09_S	et	f	\N
136897	ariste	?ariste =ariste  (PlP  >arist !22_S	et	f	\N
136909	ilmumine	ilmumine =ilmumine  (SgN  >ilmumine !12_S	et	f	\N
136910	ilmumine	"ilmumine %ilmu  )MINE_vS  <ilmuma ;27_V	et	f	\N
136919	riigistamine	riigistamine =riigistamine  (SgN  >riigistamine !12_S	et	f	\N
136920	riigistamine	"riigistamine %riigista  )MINE_vS  <riigistama ;27_V	et	f	\N
136929	erinevuseks	erinevuseks =erinevuse  (SgTr  >erinevus !11?09_S	et	f	\N
136930	erinevuseks	"erinevus %erine  )VUS_aS  <erinema ;27_V	et	f	\N
136931	erinevuseks	"erinevus %erineva  )US_aS  <erinev ;02_A	et	f	\N
136946	muurahvased	muurahvased =rahvase  (PlN  >muu+rahvane !10_A	et	f	\N
136947	muurahvased	"muu+rahvane %rahva  )NE_aA  <muu+rahvas ;07_S	et	f	\N
136950	riigikeeleks	riigikeeleks =keele  (SgTr  >riigi+keel !13_S	et	f	\N
136951	riigikeeleks	riigikeeleks =keele  (PlTr  >riigi+keeld !22_S	et	f	\N
136964	kohanemiseks	kohanemiseks =kohanemise  (SgTr  >kohanemine !12_S	et	f	\N
136672	kellegagi	kellegagi =kelle  (SgKom^  >kes !00_P	et	f	\N
136673	liblikas	liblikas =liblika  (SgIn  >liblikas !02_S	et	f	\N
136674	liblikas	liblikas =liblikas  (SgN  >liblikas !02_S	et	f	\N
136680	tiiba	tiiba =tiiba  (SgP  >tiib !22_S	et	f	\N
136682	tiiba	tiiba =tiiba  (SgAdt  >tiib !22_S	et	f	\N
136694	lillelt	lillelt =lille  (SgAbl  >lill !22_S	et	f	\N
136695	lillelt	lillelt =lille  (PlAbl  >lill !22_S	et	f	\N
136706	jalgrataga	?jalgrataga =rata  (SgKom  >jalg+rata !16_S	et	f	\N
136707	karjaaris	?karjaaris =karjaari  (SgIn  >karjaari !16_S	et	f	\N
136708	karjaaris	?karjaaris =karjaari  (SgIn  >karjaar !22_S	et	f	\N
136709	karjaaris	?karjaaris =karjaari  (IndIpfSg3  >karjaarima !28_V	et	f	\N
136710	karjaaris	?karjaaris =karjaaris  (SgN  >karjaaris !09_S	et	f	\N
136711	karjaaris	?karjaaris =ari  (SgIn  >karja+ari !17_S	et	f	\N
136712	karjaaris	?karjaaris =aris  (SgN  >karja+aris !09_S	et	f	\N
136739	hobbies	?hobbies =hobbie  (SgIn  >hobbie !01_S	et	f	\N
136740	hobbies	?hobbies =hobbies  (SgN  >hobbies !11_S	et	f	\N
136758	rahvusteadus	rahvusteadus =teadu  (SgIn  >rahvus+tead !22_S	et	f	\N
136759	rahvusteadus	rahvusteadus =teadus  (SgN  >rahvus+teadus !11~09_S	et	f	\N
136780	dokumentalistika	?dokumentalistika =dokumentalistika  (SgN  >dokumentalistika !01_S	et	f	\N
136781	dokumentalistika	?dokumentalistika =dokumentalistika  (SgG  >dokumentalistika !01_S	et	f	\N
136782	dokumentalistika	?dokumentalistika =dokumentalistika  (SgG  >dokumentalistikas !02_A	et	f	\N
136783	dokumentalistika	?dokumentalistika =umentalistika  (SgN  >dok+umentalistika !01_S	et	f	\N
136784	dokumentalistika	?dokumentalistika =umentalistika  (SgG  >dok+umentalistika !01_S	et	f	\N
136785	dokumentalistika	?dokumentalistika =umentalistika  (SgG  >dok+umentalistikas !02_A	et	f	\N
136787	klassikalist	klassikalist =klassikalis  (SgP  >klassikaline !12_A	et	f	\N
136788	klassikalist	"klassikaline %klassika  )LINE_aA  <klassika ;01_S	et	f	\N
136789	klassikalist	klassikalist =kali  (SgEl  >klassi+kali !17_S	et	f	\N
136790	klassikalist	klassikalist =kalis  (SgP  >klassi+kaline !10_A	et	f	\N
136791	klassikalist	"klassi+kaline %kali  )NE_aA  <klassi+kali ;17_S	et	f	\N
136809	usuvabadus	usuvabadus =vabadus  (SgN  >usu+vabadus !11_S	et	f	\N
136810	usuvabadus	"usu+vabadus %vaba  )US_aS  <usu+vaba ;17_A	et	f	\N
136822	populaarseteks	populaarseteks =populaarse  (PlTr  >populaarne !02_A	et	f	\N
136823	populaarseteks	populaarseteks =sete  (PlTr  >populaar+sett !22_S	et	f	\N
136826	visatud	visatud =visa  (PtsPtIps  >viskama !29_V	et	f	\N
136827	visatud	visatud =visatu  (PlN  >visatu !01_AS	et	f	\N
136828	visatud	"visatu %visa  )TU1_vS  <viskama ;29_V	et	f	\N
136829	visatud	visatud =visatud  (ID  >visatud !41_A	et	f	\N
136830	visatud	"visatud %visa  )TUD_vA  <viskama ;29_V	et	f	\N
136836	töötlemine	töötlemine =töötlemine  (SgN  >töötlemine !12_S	et	f	\N
136837	töötlemine	"töötlemine %töötle  )MINE_vS  <töötlema ;30_V	et	f	\N
136848	koonduvad	koonduvad =koondu  (IndPrPl3  >koonduma !27_V	et	f	\N
136849	koonduvad	koonduvad =koonduva  (PlN  >koonduv !02_A	et	f	\N
136850	koonduvad	"koonduv %koondu  )V_vA  <koonduma ;27_V	et	f	\N
136868	agressiivsemateks	agressiivsemateks =agressiivsema  (PlTr  >agressiivsem !02_A	et	f	\N
136869	agressiivsemateks	"agressiivsem %agressiivse  )M_cA  <agressiivne ;02_A	et	f	\N
136872	tüükiline	?tüükiline =tüükiline  (SgN  >tüükiline !12_A	et	f	\N
136873	tüükiline	?tüükiline =tüükiline  (PlP  >tüükilin !19_S	et	f	\N
136879	esindajaid	esindajaid =esindaja  (PlP  >esindaja !01_S	et	f	\N
136880	esindajaid	"esindaja %esinda  )JA_vS  <esindama ;27_V	et	f	\N
136898	saavutuseks	saavutuseks =saavutuse  (SgTr  >saavutus !11_S	et	f	\N
136899	saavutuseks	"saavutus %saavuta  )US_vS  <saavutama ;27_V	et	f	\N
136911	suunda	suunda =suunda  (ID  >suunda !41_K	et	f	\N
136912	suunda	suunda =suunda  (SgP  >suund !22_S	et	f	\N
136913	suunda	suunda =suunda  (SgAdt  >suund !22_S	et	f	\N
136921	seatakse	seatakse =sea  (IndPrIps  >seadma !34_V	et	f	\N
136922	seatakse	seatakse =takse  (PlP  >sea+taks !22_S	et	f	\N
136934	tsentraliseeritud	tsentraliseeritud =tsentraliseeri  (PtsPtIps  >tsentraliseerima !28_V	et	f	\N
136935	tsentraliseeritud	tsentraliseeritud =tsentraliseeritu  (PlN  >tsentraliseeritu !01_S	et	f	\N
136936	tsentraliseeritud	"tsentraliseeritu %tsentraliseeri  )TU1_vS  <tsentraliseerima ;28_V	et	f	\N
136937	tsentraliseeritud	tsentraliseeritud =tsentraliseeritud  (ID  >tsentraliseeritud !41_A	et	f	\N
136938	tsentraliseeritud	"tsentraliseeritud %tsentraliseeri  )TUD_vA  <tsentraliseerima ;28_V	et	f	\N
136943	situatsiooni	situatsiooni =situatsiooni  (SgG  >situatsioon !22_S	et	f	\N
136944	situatsiooni	situatsiooni =situatsiooni  (SgP  >situatsioon !22_S	et	f	\N
136945	situatsiooni	situatsiooni =situatsiooni  (SgAdt  >situatsioon !22_S	et	f	\N
136948	statujad	?statujad =statuja  (PlN  >statuja !01_S	et	f	\N
136949	statujad	?statujad =statuja  (PlN  >statujas !02_A	et	f	\N
136952	venestamine	venestamine =venestamine  (SgN  >venestamine !12_S	et	f	\N
136953	venestamine	"venestamine %venesta  )MINE_vS  <venestama ;27_V	et	f	\N
136957	kasutamiseks	kasutamiseks =kasutamise  (SgTr  >kasutamine !12_S	et	f	\N
136958	kasutamiseks	"kasutamine %kasuta  )MINE_vS  <kasutama ;27_V	et	f	\N
136959	päevaplaani	päevaplaani =plaani  (SgG  >päeva+plaan !22_S	et	f	\N
136960	päevaplaani	päevaplaani =plaani  (SgP  >päeva+plaan !22_S	et	f	\N
136755	kirjandusvool	kirjandusvool =vool  (SgN  >kirjandus+vool !22_S	et	f	\N
136763	juurdusid	juurdusid =juurdu  (IndIpfSg2  >juurduma !27_V	et	f	\N
136764	juurdusid	juurdusid =juurdu  (IndIpfPl3  >juurduma !27_V	et	f	\N
136765	huvitusid	huvitusid =huvitu  (IndIpfSg2  >huvituma !27_V	et	f	\N
136766	huvitusid	huvitusid =huvitu  (IndIpfPl3  >huvituma !27_V	et	f	\N
136796	eestima	eestima =ima  (SgN  >eest+ima !17_S	et	f	\N
136798	eestima	eestima =ima  (SgG  >eest+ima !17_S	et	f	\N
136800	eestima	eestima =ima  (SgP  >eest+ima !17_S	et	f	\N
136806	pidurdavad	pidurdavad =pidurda  (IndPrPl3  >pidurdama !27_V	et	f	\N
136807	pidurdavad	pidurdavad =pidurdava  (PlN  >pidurdav !02_A	et	f	\N
136808	pidurdavad	"pidurdav %pidurda  )V_vA  <pidurdama ;27_V	et	f	\N
136812	kalendripäevi	kalendripäevi =päevi  (SgG  >kalendri+päev !22_S	et	f	\N
136814	kalendripäevi	kalendripäevi =päevi  (SgP  >kalendri+päev !22_S	et	f	\N
136815	kalendripäevi	kalendripäevi =päevi  (SgAdt  >kalendri+päev !22_S	et	f	\N
136816	kalendripäevi	kalendripäevi =päevi  (PlP  >kalendri+päev !22_S	et	f	\N
136838	moskvat	?moskvat =moskvat  (SgN  >moskvat !02_S	et	f	\N
136839	peegeldasid	peegeldasid =peegelda  (IndIpfSg2  >peegeldama !27_V	et	f	\N
136840	peegeldasid	peegeldasid =peegelda  (IndIpfPl3  >peegeldama !27_V	et	f	\N
136876	voolu	voolu =voolu  (SgG  >vool !22_S	et	f	\N
136877	voolu	voolu =voolu  (SgP  >vool !22_S	et	f	\N
136878	voolu	voolu =voolu  (SgAdt  >vool !22_S	et	f	\N
136892	keeleks	keeleks =keele  (SgTr  >keel !13_S	et	f	\N
136893	keeleks	keeleks =keele  (PlTr  >keeld !22_S	et	f	\N
136900	viimine	viimine =viimine  (SgN  >viimine !12?10_S	et	f	\N
136901	viimine	"viimine %vii  )MINE_vS  <viima ;38_V	et	f	\N
136932	teostamine	teostamine =teostamine  (SgN  >teostamine !12_S	et	f	\N
136933	teostamine	"teostamine %teosta  )MINE_vS  <teostama ;27_V	et	f	\N
136962	küüditamist	küüditamist =küüditamis  (SgP  >küüditamine !12_S	et	f	\N
136963	küüditamist	"küüditamine %küüdita  )MINE_vS  <küüditama ;27_V	et	f	\N
136973	rikkalikult	rikkalikult =rikkaliku  (SgAbl  >rikkalik !25_A	et	f	\N
136974	rikkalikult	rikkalikult =rikkalikult  (ID  >rikkalikult !41_D	et	f	\N
136976	rikkalikult	"rikkalikult %rikkaliku  )LT_mD  <rikkalik ;25_A	et	f	\N
136996	raskustele	raskustele =raskus  (PlAll  >raskus !11~09_S	et	f	\N
136997	raskustele	"raskus %raske  )US_aS  <raske ;01_A	et	f	\N
136998	raskustele	raskustele =raskus  (PlAll  >raskune !12~10_A	et	f	\N
137007	tehnikakõrgkool	tehnikakõrgkool =koo  (SgAd  >tehnika+kõrg+kubu !18_S	et	f	\N
137008	tehnikakõrgkool	tehnikakõrgkool =kool  (SgN  >tehnika+kõrg+kool !22_S	et	f	\N
137015	iseseisvusega	iseseisvusega =seisvuse  (SgKom  >ise+seisvus !11~09_S	et	f	\N
137016	iseseisvusega	"ise+seisvus %seisva  )US_aS  <ise+seisev ;02_A	et	f	\N
137017	inspiratsiooni	inspiratsiooni =inspiratsiooni  (SgG  >inspiratsioon !22_S	et	f	\N
137018	inspiratsiooni	inspiratsiooni =inspiratsiooni  (SgP  >inspiratsioon !22_S	et	f	\N
137019	inspiratsiooni	inspiratsiooni =inspiratsiooni  (SgAdt  >inspiratsioon !22_S	et	f	\N
137020	rõhutati	rõhutati =rõhuta  (IndIpfIps  >rõhutama !27_V	et	f	\N
137021	rõhutati	rõhutati =tati  (SgG  >rõhu+tatt !22_S	et	f	\N
137022	okupeeritud	okupeeritud =okupeeri  (PtsPtIps  >okupeerima !28_V	et	f	\N
137023	okupeeritud	okupeeritud =okupeeritu  (PlN  >okupeeritu !01_S	et	f	\N
137024	okupeeritud	"okupeeritu %okupeeri  )TU1_vS  <okupeerima ;28_V	et	f	\N
137025	okupeeritud	okupeeritud =okupeeritud  (ID  >okupeeritud !41_A	et	f	\N
137026	okupeeritud	"okupeeritud %okupeeri  )TUD_vA  <okupeerima ;28_V	et	f	\N
137030	ideoloogiline	ideoloogiline =ideoloogiline  (SgN  >ideoloogiline !12_A	et	f	\N
137031	ideoloogiline	"ideoloogiline %ideoloogi  )LINE_aA  <ideoloog ;22_S	et	f	\N
137032	ideoloogiline	ideoloogiline =loogiline  (SgN  >ideo+loogiline !12_A	et	f	\N
137033	ideoloogiline	"ideo+loogiline %loogi  )LINE_aA  <ideo+loog ;22_S	et	f	\N
137036	di	### di	et	f	\N
137066	lõppesid	lõppesid =lõppe  (IndIpfSg2  >lõppema !27~28_V	et	f	\N
137067	lõppesid	lõppesid =lõppe  (IndIpfPl3  >lõppema !27~28_V	et	f	\N
137092	dissidentluse	?dissidentluse =dissidentluse  (SgG  >dissidentlus !11~09_S	et	f	\N
137105	varane	varane =varane  (SgN  >varane !10_A	et	f	\N
137106	varane	"varane %vara  )NE_aA  <vara ;17_S	et	f	\N
137131	kasvatama	kasvatama =kasva  (SupIps  >kasvama !28_V	et	f	\N
137132	kasvatama	kasvatama =kasvata  (Sup  >kasvatama !27_V	et	f	\N
137156	sulatama	sulatama =sula  (SupIps  >sulama !27_V	et	f	\N
137157	sulatama	sulatama =sulata  (Sup  >sulatama !27_V	et	f	\N
137166	rändamise	rändamise =rändamise  (SgG  >rändamine !12_S	et	f	\N
137167	rändamise	"rändamine %rända  )MINE_vS  <rändama ;29_V	et	f	\N
137182	liivakääpadesse	?liivakääpadesse =liivakääpa  (PlIll  >liivakääpa !16_S	et	f	\N
137183	liivakääpadesse	?liivakääpadesse =liivakääpades  (SgAdt  >liivakääpadene !12_A	et	f	\N
137184	liivakääpadesse	?liivakääpadesse =liivakääpadesse  (SgG  >liivakääpadesne !02_A	et	f	\N
137185	liivakääpadesse	?liivakääpadesse =liivakääpadesse  (PlP  >liivakääpadess !22_S	et	f	\N
137186	liivakääpadesse	?liivakääpadesse =kääpa  (PlIll  >liiva+kääpa !16_S	et	f	\N
137187	liivakääpadesse	?liivakääpadesse =kääpades  (SgAdt  >liiva+kääpadene !12_A	et	f	\N
136779	tugevkülg	?tugevkülg =tugevkülg  (SgN  >tugevkülg !22_S	et	f	\N
136786	jõgever	?jõgever =jõgever  (SgN  >jõgever !19_S	et	f	\N
136792	grammafoonis	?grammafoonis =grammafooni  (SgIn  >grammafooni !16_S	et	f	\N
136793	grammafoonis	?grammafoonis =grammafooni  (SgIn  >grammafoon !22_S	et	f	\N
136794	grammafoonis	?grammafoonis =grammafooni  (IndIpfSg3  >grammafoonima !28_V	et	f	\N
136795	grammafoonis	?grammafoonis =grammafoonis  (SgN  >grammafoonis !09_S	et	f	\N
136801	kena	kena =kena  (SgN  >kena !17_A	et	f	\N
136802	kena	kena =kena  (SgG  >kena !17_A	et	f	\N
136803	kena	kena =kena  (SgP  >kena !17_A	et	f	\N
136804	arene	arene =arene  (IndPrPs_  >arenema !27_V	et	f	\N
136805	arene	arene =arene  (ImpPrSg2  >arenema !27_V	et	f	\N
136834	täielikum	täielikum =täielikum  (SgN  >täielikum !02_A	et	f	\N
136835	täielikum	"täielikum %täieliku  )M_cA  <täielik ;25_A	et	f	\N
136841	tondiöömaja	tondiöömaja =maja  (SgN  >tondi+öö+maja !17_S	et	f	\N
136842	tondiöömaja	tondiöömaja =maja  (SgG  >tondi+öö+maja !17_S	et	f	\N
136843	tondiöömaja	tondiöömaja =maja  (SgP  >tondi+öö+maja !17_S	et	f	\N
136855	jõukamaid	jõukamaid =jõukama  (PlP  >jõukam !02_A	et	f	\N
136856	jõukamaid	"jõukam %jõuka  )M_cA  <jõukas ;02_A	et	f	\N
136870	majandust	majandust =majandus  (SgP  >majandus !11_S	et	f	\N
136871	majandust	"majandus %majanda  )US_vS  <majandama ;27_V	et	f	\N
136881	kõrgema	kõrgema =kõrgema  (SgG  >kõrgem !02_A	et	f	\N
136882	kõrgema	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
136883	kõrgema	kõrgema =ema  (SgN  >kõrg+ema !17_S	et	f	\N
136884	kõrgema	kõrgema =ema  (SgG  >kõrg+ema !17_S	et	f	\N
136885	kõrgema	kõrgema =ema  (SgP  >kõrg+ema !17_S	et	f	\N
136905	arendamine	arendamine =arendamine  (SgN  >arendamine !12_S	et	f	\N
136906	arendamine	"arendamine %arenda  )MINE_vS  <arendama ;27_V	et	f	\N
136907	entsüklopeedia	entsüklopeedia =entsüklopeedia  (SgN  >entsüklopeedia !01_S	et	f	\N
136908	entsüklopeedia	entsüklopeedia =entsüklopeedia  (SgG  >entsüklopeedia !01_S	et	f	\N
136914	vers-barbarus	?vers-barbarus =barbaru  (SgIn  >vers-barbaru !01_S	et	f	\N
136915	vers-barbarus	?vers-barbarus =barbaru  (IndIpfSg3  >vers-barbaruma !27_V	et	f	\N
136916	vers-barbarus	?vers-barbarus =barbarus  (SgN  >vers-barbarus !11_S	et	f	\N
136917	natsionaliseerimine	natsionaliseerimine =natsionaliseerimine  (SgN  >natsionaliseerimine !12_S	et	f	\N
136918	natsionaliseerimine	"natsionaliseerimine %natsionaliseeri  )MINE_vS  <natsionaliseerima ;28_V	et	f	\N
136923	sõjatehnika	sõjatehnika =tehnika  (SgN  >sõja+tehnika !01_S	et	f	\N
136924	sõjatehnika	sõjatehnika =tehnika  (SgG  >sõja+tehnika !01_S	et	f	\N
136925	juuni	juuni =juuni  (SgN  >juuni !16_S	et	f	\N
136926	juuni	juuni =juuni  (SgG  >juuni !16_S	et	f	\N
136954	loomaid	loomaid =ma  (PlP  >loo+maa !26_S	et	f	\N
136955	loomaid	loomaid =mai  (PlN  >loo+mai !26_S	et	f	\N
136956	loomaid	loomaid =mai  (SgP  >loo+mai !26_S	et	f	\N
136969	homo	homo =homo  (SgN  >homo !17~16_S	et	f	\N
136970	homo	homo =homo  (SgG  >homo !17~16_S	et	f	\N
136971	homo	homo =homo  (SgP  >homo !17_S	et	f	\N
136999	kajastus	kajastus =kajastu  (IndIpfSg3  >kajastuma !27_V	et	f	\N
137000	kajastus	kajastus =kajastus  (SgN  >kajastus !11_S	et	f	\N
137001	kajastus	"kajastus %kajasta  )US_vS  <kajastama ;27_V	et	f	\N
137002	ühiskondlikus	ühiskondlikus =ühiskondliku  (SgIn  >ühiskondlik !25_A	et	f	\N
137003	ühiskondlikus	ühiskondlikus =ühiskondlikus  (SgN  >ühiskondlikus !11?09_S	et	f	\N
137004	ühiskondlikus	"ühiskondlikus %ühiskondliku  )US_aS  <ühiskondlik ;25_A	et	f	\N
137009	kunstikool	kunstikool =koo  (SgAd  >kunsti+kubu !18_S	et	f	\N
137010	kunstikool	kunstikool =kool  (SgN  >kunsti+kool !22_S	et	f	\N
137013	arheoloogia	arheoloogia =arheoloogia  (SgN  >arheoloogia !01_S	et	f	\N
137014	arheoloogia	arheoloogia =arheoloogia  (SgG  >arheoloogia !01_S	et	f	\N
137027	nsvl	### nsvl	et	f	\N
137037	vii	vii =vii  (IndPrPs_  >viima !38_V	et	f	\N
137038	vii	vii =vii  (ImpPrSg2  >viima !38_V	et	f	\N
137055	hrustsov	?hrustsov =hrustsov  (SgN  >hrustsov !02_A	et	f	\N
137062	hobuste	hobuste =hobus  (PlG  >hobune !10_S	et	f	\N
137063	hobuste	"hobune %hobu  )NE_aA  <hobu ;17_S	et	f	\N
137074	perioodi	perioodi =perioodi  (SgG  >periood !22_S	et	f	\N
137075	perioodi	perioodi =perioodi  (SgP  >periood !22_S	et	f	\N
137076	perioodi	perioodi =perioodi  (SgAdt  >periood !22_S	et	f	\N
137077	sulaks	sulaks =sula  (SgTr  >sula !17_AS	et	f	\N
137078	sulaks	sulaks =sula  (KndPrPs  >sulama !27_V	et	f	\N
137084	olevatest	olevatest =oleva  (PlEl  >olev !02_A	et	f	\N
137085	olevatest	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
137086	inimlikum	inimlikum =inimlikum  (SgN  >inimlikum !02_A	et	f	\N
137087	inimlikum	"inimlikum %inimliku  )M_cA  <inimlik ;25_A	et	f	\N
137088	säilitamisele	säilitamisele =säilitamise  (SgAll  >säilitamine !12_S	et	f	\N
137089	säilitamisele	"säilitamine %säilita  )MINE_vS  <säilitama ;27_V	et	f	\N
137090	julguse	julguse =julguse  (SgG  >julgus !11~09_S	et	f	\N
137091	julguse	"julgus %julge  )US_aS  <julge ;01_A	et	f	\N
137095	seminaritööd	?seminaritööd =seminaritöö  (PlN  >seminaritöö !26_S	et	f	\N
137096	seminaritööd	?seminaritööd =seminaritöö  (SgP  >seminaritöö !26_S	et	f	\N
136961	päevaplaani	päevaplaani =plaani  (SgAdt  >päeva+plaan !22_S	et	f	\N
136966	usuvabadust	usuvabadust =dust  (SgN  >usu+vaba+dust !22_S	et	f	\N
136967	usuvabadust	usuvabadust =vabadus  (SgP  >usu+vabadus !11_S	et	f	\N
136968	usuvabadust	"usu+vabadus %vaba  )US_aS  <usu+vaba ;17_A	et	f	\N
136983	mõistati	?mõistati =mõista  (IndIpfIps  >mõistama !27_V	et	f	\N
136984	mõistati	?mõistati =mõistati  (ID  >mõistati !41_D	et	f	\N
136985	mõistati	?mõistati =mõistati  (SgG  >mõistat !02_S	et	f	\N
136986	mõistati	?mõistati =mõistati  (SgG  >mõistatt !22_S	et	f	\N
136987	mõistati	?mõistati =mõistati  (IndPrPs_  >mõistattima !28_V	et	f	\N
136988	mõistati	?mõistati =mõistati  (ImpPrSg2  >mõistattima !28_V	et	f	\N
136989	süütjaks	?süütjaks =süütja  (SgTr  >süütja !01_S	et	f	\N
136990	süütjaks	?süütjaks =süütja  (SgTr  >süütjas !02_A	et	f	\N
136991	süütjaks	?süütjaks =süütja  (KndPrPs  >süütjama !29_V	et	f	\N
137005	seltsid	seltsid =seltsi  (PlN  >selts !22_S	et	f	\N
137006	seltsid	seltsid =seltsi  (IndPrSg2  >seltsima !28_V	et	f	\N
137064	destaliniseerumine	?destaliniseerumine =destaliniseerumine  (SgN  >destaliniseerumine !12_S	et	f	\N
137065	destaliniseerumine	?destaliniseerumine =destaliniseerumine  (PlP  >destaliniseerumin !19_S	et	f	\N
137072	pehmem	pehmem =pehmem  (SgN  >pehmem !02_A	et	f	\N
137073	pehmem	"pehmem %pehme  )M_cA  <pehme ;01_A	et	f	\N
137079	intuitsiooni	intuitsiooni =intuitsiooni  (SgG  >intuitsioon !22_S	et	f	\N
137080	intuitsiooni	intuitsiooni =intuitsiooni  (SgP  >intuitsioon !22_S	et	f	\N
137081	intuitsiooni	intuitsiooni =intuitsiooni  (SgAdt  >intuitsioon !22_S	et	f	\N
137082	pooldajatega	pooldajatega =pooldaja  (PlKom  >pooldaja !01_S	et	f	\N
137083	pooldajatega	"pooldaja %poolda  )JA_vS  <pooldama ;27_V	et	f	\N
137094	sahharov	?sahharov =sahharov  (SgN  >sahharov !02_A	et	f	\N
137103	sõnastikku	sõnastikku =sõnastikku  (SgP  >sõnastik !25_S	et	f	\N
137104	sõnastikku	sõnastikku =sõnastikku  (SgAdt  >sõnastik !25_S	et	f	\N
137112	arvatud	arvatud =arva  (PtsPtIps  >arvama !29_V	et	f	\N
137113	arvatud	arvatud =arvatu  (PlN  >arvatu !01_AS	et	f	\N
137114	arvatud	"arvatu %arva  )TU1_vS  <arvama ;29_V	et	f	\N
137115	arvatud	arvatud =arvatud  (ID  >arvatud !41_A	et	f	\N
137116	arvatud	"arvatud %arva  )TUD_vA  <arvama ;29_V	et	f	\N
137117	arvatud	arvatud =atu  (PlN  >arv+att !22_S	et	f	\N
137141	kultuuriainetest	kultuuriainetest =test  (SgN  >kultuuri+aine+test !22_S	et	f	\N
137142	kultuuriainetest	kultuuriainetest =aine  (PlEl  >kultuuri+aine !06_S	et	f	\N
137146	sünvoolne	?sünvoolne =sünvoolne  (SgN  >sünvoolne !02_A	et	f	\N
137147	sünvoolne	?sünvoolne =sünvoolne  (PlP  >sünvooln !22_S	et	f	\N
137148	viitavad	viitavad =viita  (IndPrPl3  >viitama !29_V	et	f	\N
137149	viitavad	viitavad =viitava  (PlN  >viitav !02_A	et	f	\N
137150	viitavad	"viitav %viita  )V_vA  <viitama ;29_V	et	f	\N
137151	viitavad	viitavad =ava  (PlN  >viit+ava !17_S	et	f	\N
137152	linu	linu =linu  (PlP  >lina !17_S	et	f	\N
137153	linu	linu =linu  (IndPrPs_  >linuma !27_V	et	f	\N
137154	linu	linu =linu  (ImpPrSg2  >linuma !27_V	et	f	\N
137164	lõuna-	lõuna- =lõuna  (SgN  >lõuna !06_S	et	f	\N
137165	lõuna-	lõuna- =lõuna  (SgG  >lõuna !06_S	et	f	\N
137172	hoolitsesid	hoolitsesid =hoolitse  (IndIpfSg2  >hoolitsema !27_V	et	f	\N
137173	hoolitsesid	hoolitsesid =hoolitse  (IndIpfPl3  >hoolitsema !27_V	et	f	\N
137208	teki	teki =teki  (SgG  >tekk !22_S	et	f	\N
137209	teki	teki =teki  (IndPrPs_  >tekkima !28_V	et	f	\N
137210	teki	teki =teki  (ImpPrSg2  >tekkima !28_V	et	f	\N
137218	atekr	?atekr =atekr  (SgN  >atekr !22_S	et	f	\N
137229	metallkirvestele	metallkirvestele =kirves  (PlAll  >metall+kirves !07_S	et	f	\N
137230	metallkirvestele	metallkirvestele =kirves  (PlAll  >metall+kirvene !10_A	et	f	\N
137231	metallkirvestele	"metall+kirvene %kirve  )NE_aA  <metall+kirves ;07_S	et	f	\N
137241	sulama	sulama =sula  (Sup  >sulama !27_V	et	f	\N
137242	sulama	sulama =sulama  (SgG  >sulam !02_S	et	f	\N
137243	sulama	"sulam %sula  )M_cA  <sula ;17_AS	et	f	\N
137244	anastavalt	anastavalt =anastava  (SgAbl  >anastav !02_A	et	f	\N
137245	anastavalt	"anastav %anasta  )V_vA  <anastama ;27_V	et	f	\N
137246	anastavalt	anastavalt =anastavalt  (ID  >anastavalt !41_D	et	f	\N
137247	anastavalt	"anastavalt %anasta  )VALT_mD  <anastama ;27_V	et	f	\N
137261	hirssi	hirssi =hirssi  (SgP  >hirss !22_S	et	f	\N
137263	hirssi	hirssi =hirssi  (SgAdt  >hirss !22_S	et	f	\N
137264	kanapit	?kanapit =kanapi  (SgP  >kanapi !01_S	et	f	\N
137265	kanapit	?kanapit =kanapi  (SgP  >kanap !02_S	et	f	\N
137270	kaitsmiseks	kaitsmiseks =kaitsmise  (SgTr  >kaitsmine !12?10_S	et	f	\N
137271	kaitsmiseks	"kaitsmine %kaits  )MINE_vS  <kaitsma ;32_V	et	f	\N
137283	kombeks	kombeks =kombe  (SgTr  >komme !06_S	et	f	\N
137284	kombeks	kombeks =kombe  (PlTr  >komp !22_S	et	f	\N
137296	kujutasid	kujutasid =kujuta  (IndIpfSg2  >kujutama !27_V	et	f	\N
137297	kujutasid	kujutasid =kujuta  (IndIpfPl3  >kujutama !27_V	et	f	\N
137307	elutul	elutul =elutu  (SgAd  >elutu !01_A	et	f	\N
137308	elutul	"elutu %elu  )TU2_kA  <elu ;17_S	et	f	\N
137342	10-kroonise	-kroonise =kroonise  (SgG  >-kroonine !10_AS	et	f	\N
137343	10-kroonise	"-kroonine %krooni  )NE_aA  <-kroon ;22_S	et	f	\N
136965	kohanemiseks	"kohanemine %kohane  )MINE_vS  <kohanema ;27_V	et	f	\N
136975	sünnipäevi	sünnipäevi =päevi  (SgG  >sünni+päev !22_S	et	f	\N
136977	sünnipäevi	sünnipäevi =päevi  (SgP  >sünni+päev !22_S	et	f	\N
136978	sünnipäevi	sünnipäevi =päevi  (SgAdt  >sünni+päev !22_S	et	f	\N
136979	sünnipäevi	sünnipäevi =päevi  (PlP  >sünni+päev !22_S	et	f	\N
136992	1918a	### 1918a	et	f	\N
137011	etnoloogia	etnoloogia =etnoloogia  (SgN  >etnoloogia !01_S	et	f	\N
137012	etnoloogia	etnoloogia =etnoloogia  (SgG  >etnoloogia !01_S	et	f	\N
137028	ühiskonda	ühiskonda =ühiskonda  (SgP  >ühiskond !22_S	et	f	\N
137029	ühiskonda	ühiskonda =ühiskonda  (SgAdt  >ühiskond !22_S	et	f	\N
137034	stalin	?stalin =stali  (IndPrSg1  >stalima !27_V	et	f	\N
137035	stalin	?stalin =stalin  (SgN  >stalin !02_S	et	f	\N
137039	sovetikus	?sovetikus =sovetiku  (SgIn  >sovetik !02_S	et	f	\N
137040	sovetikus	?sovetikus =sovetiku  (IndIpfSg3  >sovetikuma !27_V	et	f	\N
137041	sovetikus	?sovetikus =sovetikus  (SgN  >sovetikus !11?09_S	et	f	\N
137051	nikita	?nikita =niki  (SgAb  >niki !16_S	et	f	\N
137052	nikita	?nikita =niki  (SgAb  >nikk !22_S	et	f	\N
137053	nikita	?nikita =niki  (IndPrIps_  >nikima !27_V	et	f	\N
137054	nikita	?nikita =niki  (IndPrIps_  >nikkima !28_V	et	f	\N
137056	nikita	?nikita =nikita  (IndPrPs_  >nikitama !27_V	et	f	\N
137057	nikita	?nikita =nikita  (ImpPrSg2  >nikitama !27_V	et	f	\N
137058	maisi	maisi =maisi  (ID  >maisi !41_D	et	f	\N
137059	maisi	maisi =maisi  (SgG  >mais !22_S	et	f	\N
137060	maisi	maisi =maisi  (SgP  >mais !22_S	et	f	\N
137061	maisi	maisi =maisi  (SgAdt  >mais !22_S	et	f	\N
137068	reabiliteerimine	?reabiliteerimine =reabiliteerimine  (SgN  >reabiliteerimine !12_S	et	f	\N
137069	reabiliteerimine	?reabiliteerimine =reabiliteerimine  (PlP  >reabiliteerimin !19_S	et	f	\N
137070	reabiliteerimine	?reabiliteerimine =biliteerimine  (SgN  >rea+biliteerimine !12_S	et	f	\N
137071	reabiliteerimine	?reabiliteerimine =biliteerimine  (PlP  >rea+biliteerimin !19_S	et	f	\N
137093	tuntuimad	?tuntuimad =tuntuima  (PlN  >tuntuim !02_A	et	f	\N
137107	aasttuh	?aasttuh =aasttuh  (ID  >aasttuh !41_I	et	f	\N
137108	kr	### kr	et	f	\N
137109	tina	tina =tina  (SgN  >tina !17_S	et	f	\N
137110	tina	tina =tina  (SgG  >tina !17_S	et	f	\N
137111	tina	tina =tina  (SgP  >tina !17_S	et	f	\N
137118	saaremaalt	saaremaalt =alt  (SgN  >saar+ema+alt !22_S	et	f	\N
137119	saaremaalt	saaremaalt =maa  (SgAbl  >saare+maa !26_S	et	f	\N
137133	hobuseliha	hobuseliha =liha  (SgN  >hobuse+liha !17_S	et	f	\N
137134	hobuseliha	hobuseliha =liha  (SgG  >hobuse+liha !17_S	et	f	\N
137135	hobuseliha	hobuseliha =liha  (SgP  >hobuse+liha !17_S	et	f	\N
137155	1300a	### 1300a	et	f	\N
137158	pronksigi	pronksigi =pronksi  (SgG^  >pronks !22_S	et	f	\N
137159	pronksigi	pronksigi =pronksi  (SgP^  >pronks !22_S	et	f	\N
137160	pronksigi	pronksigi =pronksi  (SgAdt^  >pronks !22_S	et	f	\N
137178	rikkamaid	?rikkamaid =rikkama  (PlP  >rikkam !02_A	et	f	\N
137179	rikkamaid	?rikkamaid =rikkamai  (PlN  >rikkamai !26_S	et	f	\N
137180	rikkamaid	?rikkamaid =rikkamai  (SgP  >rikkamai !26_S	et	f	\N
137220	ajaarvamisevahetus	?ajaarvamisevahetus =ajaarvamisevahetu  (SgIn  >ajaarvamisevahetu !01_A	et	f	\N
137221	ajaarvamisevahetus	?ajaarvamisevahetus =ajaarvamisevahetu  (IndIpfSg3  >ajaarvamisevahetuma !27_V	et	f	\N
137222	ajaarvamisevahetus	?ajaarvamisevahetus =ajaarvamisevahetus  (SgN  >ajaarvamisevahetus !11?09_S	et	f	\N
137223	ajaarvamisevahetus	?ajaarvamisevahetus =evahetu  (SgIn  >aja+arvamis+evahetu !01_A	et	f	\N
137224	ajaarvamisevahetus	?ajaarvamisevahetus =evahetus  (SgN  >aja+arvamis+evahetus !11?09_S	et	f	\N
137225	ajaarvamisevahetus	?ajaarvamisevahetus =amisevahetu  (SgIn  >aja+arv+amisevahetu !01_A	et	f	\N
137226	ajaarvamisevahetus	?ajaarvamisevahetus =amisevahetus  (SgN  >aja+arv+amisevahetus !11?09_S	et	f	\N
137227	ajaarvamisevahetus	?ajaarvamisevahetus =arvamisevahetu  (SgIn  >aja+arvamisevahetu !01_A	et	f	\N
137228	ajaarvamisevahetus	?ajaarvamisevahetus =arvamisevahetus  (SgN  >aja+arvamisevahetus !11?09_S	et	f	\N
137235	kitsi	kitsi =kitsi  (SgN  >kitsi !16_A	et	f	\N
137236	kitsi	kitsi =kitsi  (SgG  >kitsi !16_A	et	f	\N
137237	kitsi	kitsi =kitsi  (SgG  >kits !22_S	et	f	\N
137238	kitsi	kitsi =kitsi  (SgP  >kits !22_S	et	f	\N
137239	kitsi	kitsi =kitsi  (SgAdt  >kits !22_S	et	f	\N
137240	kitsi	kitsi =kitsi  (PlP  >kits !22_S	et	f	\N
137254	uskulised	?uskulised =uskulise  (PlN  >uskuline !12_A	et	f	\N
137287	küljes	küljes =külje  (SgIn  >külg !22_S	et	f	\N
137288	küljes	küljes =küljes  (ID  >küljes !41_DK	et	f	\N
137300	veelinde	veelinde =inde  (PlP  >veel+ind !22_S	et	f	\N
137301	veelinde	veelinde =linde  (SgG  >vee+linne !06_S	et	f	\N
137302	veelinde	veelinde =linde  (PlP  >vee+lind !22_S	et	f	\N
137303	vastavate	vastavate =vastava  (PlG  >vastav !02_A	et	f	\N
137304	vastavate	"vastav %vasta  )V_vA  <vastama ;29_V	et	f	\N
137309	komiteedi	?komiteedi =komiteedi  (SgN  >komiteedi !16_S	et	f	\N
137310	komiteedi	?komiteedi =komiteedi  (SgG  >komiteedi !16_S	et	f	\N
137311	komiteedi	?komiteedi =komiteedi  (SgG  >komiteet !22_S	et	f	\N
137312	komiteedi	?komiteedi =komiteedi  (SgP  >komiteed !22_S	et	f	\N
137313	komiteedi	?komiteedi =komiteedi  (SgAdt  >komiteed !22_S	et	f	\N
137045	muretsenud	muretsenud =muretsenud  (ID  >muretsenud !41_A	et	f	\N
137046	muretsenud	"muretsenud %muretse  )NUD_vA  <muretsema ;27_V	et	f	\N
137047	hilistalinismile	?hilistalinismile =hilistalinismi  (SgAll  >hilistalinism !22_S	et	f	\N
137048	hilistalinismile	?hilistalinismile =nismi  (SgAll  >hilis+tali+nismi !16_S	et	f	\N
137049	hilistalinismile	?hilistalinismile =nismi  (SgAll  >hilis+tali+nism !22_S	et	f	\N
137050	hilistalinismile	?hilistalinismile =talinismi  (SgAll  >hilis+talinism !22_S	et	f	\N
137124	kivist	kivist =kivi  (SgEl  >kivi !17_S	et	f	\N
137125	kivist	kivist =kivis  (SgP  >kivine !10_A	et	f	\N
137126	kivist	"kivine %kivi  )NE_aA  <kivi ;17_S	et	f	\N
137138	teravilja	teravilja =vilja  (SgG  >tera+vili !24_S	et	f	\N
137139	teravilja	teravilja =vilja  (SgP  >tera+vili !24_S	et	f	\N
137140	teravilja	teravilja =vilja  (SgAdt  >tera+vili !24_S	et	f	\N
137161	eristuvad	eristuvad =eristu  (IndPrPl3  >eristuma !27_V	et	f	\N
137162	eristuvad	eristuvad =eristuva  (PlN  >eristuv !02_A	et	f	\N
137163	eristuvad	"eristuv %eristu  )V_vA  <eristuma ;27_V	et	f	\N
137181	matusi	?matusi =matusi  (ID  >matusi !41_D	et	f	\N
137194	pealik	pealik =pealik  (SgN  >pealik !02_S	et	f	\N
137195	pealik	pealik =pealik  (SgN  >pealik !25_S	et	f	\N
137204	lähimatele	lähimatele =lähima  (PlAll  >lähim !02_A	et	f	\N
137205	lähimatele	"lähim %lähi  )IM_sA  <lähike ;12_A	et	f	\N
137206	lähimatele	lähimatele =mate  (SgAll  >lähi+mate !16_S	et	f	\N
137207	lähimatele	lähimatele =mate  (PlAll  >lähi+matt !22_SA	et	f	\N
137211	rohul	rohul =rohu  (SgAd  >roht !22_S	et	f	\N
137212	rohul	rohul =rohu  (SgAd  >rohi !24_S	et	f	\N
137248	majanduselt	majanduselt =majanduse  (SgAbl  >majandus !11_S	et	f	\N
137249	majanduselt	"majandus %majanda  )US_vS  <majandama ;27_V	et	f	\N
137337	ühenduses	ühenduses =ühenduse  (SgIn  >ühendus !11_S	et	f	\N
137338	ühenduses	"ühendus %ühenda  )US_vS  <ühendama ;27_V	et	f	\N
137339	ühenduses	ühenduses =use  (PlIn  >ühend+usk !22_S	et	f	\N
137367	merkel	?merkel =merke  (SgAd  >merge !06_S	et	f	\N
137368	merkel	?merkel =merkel  (SgN  >merkel !02_S	et	f	\N
137378	parandamisega	parandamisega =parandamise  (SgKom  >parandamine !12_S	et	f	\N
137379	parandamisega	"parandamine %paranda  )MINE_vS  <parandama ;27_V	et	f	\N
137386	likvideerimine	likvideerimine =likvideerimine  (SgN  >likvideerimine !12_S	et	f	\N
137387	likvideerimine	"likvideerimine %likvideeri  )MINE_vS  <likvideerima ;28_V	et	f	\N
137394	orjad	orjad =orja  (PlN  >ori !24_S	et	f	\N
137395	orjad	orjad =orja  (IndPrSg2  >orjama !29_V	et	f	\N
137426	löögi	löögi =löögi  (SgG  >löök !22_S	et	f	\N
137427	löögi	löögi =löö  (IndPrPs_^  >lööma !38_V	et	f	\N
137428	löögi	löögi =löö  (ImpPrSg2^  >lööma !38_V	et	f	\N
137443	üldlaulupeo	üldlaulupeo =peo  (SgN  >üld+laulu+peo !26_S	et	f	\N
137444	üldlaulupeo	üldlaulupeo =peo  (SgG  >üld+laulu+pidu !18_S	et	f	\N
137445	üldlaulupeo	üldlaulupeo =peo  (SgG  >üld+laulu+peo !26_S	et	f	\N
137447	isamaakõne	isamaakõne =kõne  (SgN  >isa+maa+kõne !16_S	et	f	\N
137448	isamaakõne	isamaakõne =kõne  (SgG  >isa+maa+kõne !16_S	et	f	\N
137454	hurti	hurti =hurti  (SgP  >hurt !22_S	et	f	\N
137455	hurti	hurti =hurti  (SgAdt  >hurt !22_S	et	f	\N
137456	hurti	hurti =hurti  (PlP  >hurt !22_S	et	f	\N
137457	moraali	moraali =moraali  (SgG  >moraal !22_S	et	f	\N
137458	moraali	moraali =moraali  (SgP  >moraal !22_S	et	f	\N
137459	moraali	moraali =moraali  (SgAdt  >moraal !22_S	et	f	\N
137463	kogusid	kogusid =kogu  (PlP  >kogu !17_S	et	f	\N
137464	kogusid	kogusid =kogu  (IndIpfSg2  >koguma !27_V	et	f	\N
137465	kogusid	kogusid =kogu  (IndIpfPl3  >koguma !27_V	et	f	\N
137466	kogusid	kogusid =kogusi  (PlN  >kogus !02_A	et	f	\N
137472	väitsid	väitsid =väit  (IndIpfSg2  >väitma !34_V	et	f	\N
137473	väitsid	väitsid =väit  (IndIpfPl3  >väitma !34_V	et	f	\N
137474	väitsid	väitsid =väitsi  (PlN  >väits !22_S	et	f	\N
137488	peetaxe	?peetaxe =axe  (SgN  >peet+axe !06_S	et	f	\N
137489	peetaxe	?peetaxe =axe  (SgG  >peet+axe !06_S	et	f	\N
137497	lübecki	?lübecki =lübecki  (SgG  >lübeck !22_S	et	f	\N
137498	lübecki	?lübecki =lübecki  (SgP  >lübeck !22_S	et	f	\N
137499	lübecki	?lübecki =lübecki  (SgAdt  >lübeck !22_S	et	f	\N
137501	kaupmeestest	kaupmeestest =test  (SgN  >kaup+mees+test !22_S	et	f	\N
137504	kaupmeestest	kaupmeestest =mees  (PlEl  >kaup+meene !10_A	et	f	\N
137505	kaupmeestest	"kaup+meene %mee  )NE_aA  <kaup+mesi ;15_S	et	f	\N
137507	kaupmeestest	kaupmeestest =mees  (PlEl  >kaup+mees !13_S	et	f	\N
137519	henrik	?henrik =henrik  (SgN  >henrik !02_S	et	f	\N
137523	tähtsax	### tähtsax	et	f	\N
137529	ühiskonnast	ühiskonnast =ühiskonna  (SgEl  >ühiskond !22_S	et	f	\N
137530	ühiskonnast	ühiskonnast =ühiskonnas  (SgP  >ühiskonnane !12_A	et	f	\N
137531	ühiskonnast	"ühiskonnane %ühiskonna  )NE_aA  <ühiskond ;22_S	et	f	\N
137532	ühiskonnast	ühiskonnast =konna  (SgEl  >ühis+konn !22_S	et	f	\N
137533	ühiskonnast	ühiskonnast =konnas  (SgP  >ühis+konnane !10_A	et	f	\N
137534	ühiskonnast	"ühis+konnane %konna  )NE_aA  <ühis+konn ;22_S	et	f	\N
137543	pühitsetud	pühitsetud =pühitse  (PtsPtIps  >pühitsema !27_V	et	f	\N
137544	pühitsetud	pühitsetud =pühitsetu  (PlN  >pühitsetu !01_S	et	f	\N
137097	seminaritööd	?seminaritööd =seminaritööd  (SgN  >seminaritööd !22_S	et	f	\N
137098	seminaritööd	?seminaritööd =itöö  (PlN  >seminar+itöö !26_S	et	f	\N
137099	seminaritööd	?seminaritööd =itöö  (SgP  >seminar+itöö !26_S	et	f	\N
137100	seminaritööd	?seminaritööd =itööd  (SgN  >seminar+itööd !22_S	et	f	\N
137101	arusaamatusi	arusaamatusi =saamatusi  (PlP  >aru+saamatus !11_S	et	f	\N
137102	arusaamatusi	"aru+saamatus %saama  )TUS2_aS  <aru+saam ;22_S	et	f	\N
137120	iia	?iia =iia  (SgN  >iia !16_S	et	f	\N
137121	iia	?iia =iia  (SgG  >iia !16_S	et	f	\N
137122	iia	?iia =iia  (IndPrPs_  >iiama !29_V	et	f	\N
137123	iia	?iia =iia  (ImpPrSg2  >iiama !29_V	et	f	\N
137127	luust	luust =luu  (SgEl  >luu !26_S	et	f	\N
137128	luust	luust =luus  (SgP  >luune !10_A	et	f	\N
137129	asulaid	asulaid =asula  (PlP  >asula !01_S	et	f	\N
137130	asulaid	asulaid =laid  (SgN  >asu+laid !22_S	et	f	\N
137136	saaki	saaki =saaki  (SgP  >saak !22_S	et	f	\N
137137	saaki	saaki =saaki  (SgAdt  >saak !22_S	et	f	\N
137143	lina	lina =lina  (SgN  >lina !17_S	et	f	\N
137144	lina	lina =lina  (SgG  >lina !17_S	et	f	\N
137145	lina	lina =lina  (SgP  >lina !17_S	et	f	\N
137168	rahutu	rahutu =rahutu  (SgN  >rahutu !01_A	et	f	\N
137169	rahutu	"rahutu %rahu  )TU2_kA  <rahu ;17_S	et	f	\N
137170	rahutu	rahutu =rahutu  (SgG  >rahutu !01_A	et	f	\N
137171	skandinaaviaga	?skandinaaviaga =skandinaavia  (SgKom  >skandinaavia !01_S	et	f	\N
137174	peitsid	peitsid =peit  (IndIpfSg2  >peitma !34_V	et	f	\N
137175	peitsid	peitsid =peit  (IndIpfPl3  >peitma !34_V	et	f	\N
137176	peitsid	peitsid =peitsi  (PlN  >peits !22_S	et	f	\N
137177	peitsid	peitsid =peitsi  (IndPrSg2  >peitsima !28_V	et	f	\N
137198	rikkam	?rikkam =rikkam  (SgN  >rikkam !02_A	et	f	\N
137199	kauplevad	kauplevad =kauple  (IndPrPl3  >kauplema !30_V	et	f	\N
137200	kauplevad	kauplevad =kaupleva  (PlN  >kauplev !02_A	et	f	\N
137201	kauplevad	"kauplev %kauple  )V_vA  <kauplema ;30_V	et	f	\N
137202	meisterdamine	meisterdamine =meisterdamine  (SgN  >meisterdamine !12_S	et	f	\N
137203	meisterdamine	"meisterdamine %meisterda  )MINE_vS  <meisterdama ;27_V	et	f	\N
137213	lilledel	lilledel =lille  (PlAd  >lill !22_S	et	f	\N
137214	lilledel	lilledel =ede  (SgAd  >lill+ede !16_S	et	f	\N
137215	lilledel	lilledel =edel  (SgN  >lill+edel !02_S	et	f	\N
137232	elatusala	elatusala =ala  (SgN  >elatus+ala !17_S	et	f	\N
137233	elatusala	elatusala =ala  (SgG  >elatus+ala !17_S	et	f	\N
137234	elatusala	elatusala =ala  (SgP  >elatus+ala !17_S	et	f	\N
137250	muutusi	muutusi =muutusi  (PlP  >muutus !11_S	et	f	\N
137251	muutusi	"muutus %muu  )TUS2_aS  <muu ;26_S	et	f	\N
137255	ümbritsevasse	ümbritsevasse =ümbritseva  (SgIll  >ümbritsev !02_A	et	f	\N
137256	ümbritsevasse	"ümbritsev %ümbritse  )V_vA  <ümbritsema ;27_V	et	f	\N
137259	nisu	nisu =nisu  (SgN  >nisu !17_S	et	f	\N
137260	nisu	nisu =nisu  (SgG  >nisu !17_S	et	f	\N
137262	nisu	nisu =nisu  (SgP  >nisu !17_S	et	f	\N
137277	asva	?asva =asva  (SgN  >asva !16_S	et	f	\N
137278	asva	?asva =asva  (SgG  >asva !16_S	et	f	\N
137279	asva	?asva =asva  (IndPrPs_  >asvama !29_V	et	f	\N
137280	asva	?asva =asva  (ImpPrSg2  >asvama !29_V	et	f	\N
137281	suurpere	suurpere =pere  (SgN  >suur+pere !16_S	et	f	\N
137282	suurpere	suurpere =pere  (SgG  >suur+pere !16_S	et	f	\N
137289	merevaigust	merevaigust =vaigu  (SgEl  >mere+vaik !22_S	et	f	\N
137290	merevaigust	merevaigust =vaigus  (SgP  >mere+vaigune !10_A	et	f	\N
137291	merevaigust	"mere+vaigune %vaigu  )NE_aA  <mere+vaik ;22_S	et	f	\N
137292	kujukesi	kujukesi =kujukesi  (PlP  >kujuke !12_S	et	f	\N
137293	kujukesi	"kujuke %kuju  )KE_dS  <kuju ;17_S	et	f	\N
137294	kujukesi	kujukesi =kujukesi  (PlP  >kujukene !12_S	et	f	\N
137295	kujukesi	"kujukene %kuju  )KENE_dS  <kuju ;17_S	et	f	\N
137305	elaval	elaval =elava  (SgAd  >elav !02_A	et	f	\N
137306	elaval	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
137323	sõnavabadus	sõnavabadus =vabadus  (SgN  >sõna+vabadus !11_S	et	f	\N
137324	sõnavabadus	"sõna+vabadus %vaba  )US_aS  <sõna+vaba ;17_A	et	f	\N
137325	tekkimine	tekkimine =tekkimine  (SgN  >tekkimine !12_S	et	f	\N
137326	tekkimine	"tekkimine %tekki  )MINE_vS  <tekkima ;27_V	et	f	\N
137327	tekkimine	"tekkimine %tekki  )MINE_vS  <tekkima ;28_V	et	f	\N
137352	võimineesmakordselt	?võimineesmakordselt =võimineesmakordse  (SgAbl  >võimineesmakordne !02_A	et	f	\N
137353	võimineesmakordselt	?võimineesmakordselt =võimineesmakordselt  (ID  >võimineesmakordselt !41_D	et	f	\N
137354	võimineesmakordselt	?võimineesmakordselt =mineesmakordse  (SgAbl  >või+mineesmakordne !02_A	et	f	\N
137355	eellaulupidu	eellaulupidu =pidu  (SgN  >eel+laulu+pidu !17_S	et	f	\N
137356	eellaulupidu	eellaulupidu =pidu  (SgN  >eel+laulu+pidu !18_S	et	f	\N
137357	eellaulupidu	eellaulupidu =pidu  (SgG  >eel+laulu+pidu !17_S	et	f	\N
137358	eellaulupidu	eellaulupidu =pidu  (SgP  >eel+laulu+pidu !17_S	et	f	\N
137359	eellaulupidu	eellaulupidu =pidu  (SgP  >eel+laulu+pidu !18_S	et	f	\N
137369	filo	?filo =filo  (SgN  >filo !17~16_S	et	f	\N
137370	filo	?filo =filo  (SgG  >filo !17~16_S	et	f	\N
137371	filo	?filo =filo  (SgP  >filo !17_S	et	f	\N
137375	parandamise	parandamise =parandamise  (SgG  >parandamine !12_S	et	f	\N
137188	liivakääpadesse	?liivakääpadesse =kääpadesse  (SgG  >liiva+kääpadesne !02_A	et	f	\N
137189	liivakääpadesse	?liivakääpadesse =kääpadesse  (PlP  >liiva+kääpadess !22_S	et	f	\N
137190	liivakääpadesse	?liivakääpadesse =akääpa  (PlIll  >liiv+akääpa !16_S	et	f	\N
137191	liivakääpadesse	?liivakääpadesse =akääpades  (SgAdt  >liiv+akääpadene !12_A	et	f	\N
137192	liivakääpadesse	?liivakääpadesse =akääpadesse  (SgG  >liiv+akääpadesne !02_A	et	f	\N
137193	liivakääpadesse	?liivakääpadesse =akääpadesse  (PlP  >liiv+akääpadess !22_S	et	f	\N
137196	pealikuks	pealikuks =pealiku  (SgTr  >pealik !25_S	et	f	\N
137197	pealikuks	pealikuks =pealiku  (SgTr  >pealik !02_S	et	f	\N
137216	varasele	varasele =varase  (SgAll  >varane !10_A	et	f	\N
137217	varasele	"varane %vara  )NE_aA  <vara ;17_S	et	f	\N
137219	ekr-	?ekr- =ekr  (SgN  >ekr !22_S	et	f	\N
137252	omavahelised	omavahelised =vahelise  (PlN  >oma+vaheline !12_A	et	f	\N
137253	omavahelised	"oma+vaheline %vahe  )LINE_aA  <oma+vahe ;16_S	et	f	\N
137257	tüüpi	tüüpi =tüüpi  (SgP  >tüüp !22_S	et	f	\N
137258	tüüpi	tüüpi =tüüpi  (SgAdt  >tüüp !22_S	et	f	\N
137266	kari	kari =kari  (SgN  >kari !17_S	et	f	\N
137267	kari	kari =kari  (SgN  >kari !24_S	et	f	\N
137268	kari	kari =kari  (SgG  >kari !17_S	et	f	\N
137269	kari	kari =kari  (SgP  >kari !17_S	et	f	\N
137272	kindlustatud	kindlustatud =kindlusta  (PtsPtIps  >kindlustama !27_V	et	f	\N
137273	kindlustatud	kindlustatud =kindlustatu  (PlN  >kindlustatu !01_S	et	f	\N
137274	kindlustatud	"kindlustatu %kindlusta  )TU1_vS  <kindlustama ;27_V	et	f	\N
137275	kindlustatud	kindlustatud =kindlustatud  (ID  >kindlustatud !41_A	et	f	\N
137276	kindlustatud	"kindlustatud %kindlusta  )TUD_vA  <kindlustama ;27_V	et	f	\N
137285	kaelas	kaelas =kaela  (SgIn  >kael !23?22_S	et	f	\N
137286	kaelas	kaelas =kaelas  (ID  >kaelas !41_K	et	f	\N
137298	kopraid	kopraid =kopra  (PlP  >kopra !01_S	et	f	\N
137299	kopraid	kopraid =kopra  (PlP  >kobras !07_S	et	f	\N
137328	tõus	tõus =tõu  (SgIn  >tõug !22_S	et	f	\N
137329	tõus	tõus =tõu  (SgIn  >tõu !26_S	et	f	\N
137330	tõus	tõus =tõus  (SgN  >tõus !22_S	et	f	\N
137331	suletud	suletud =sule  (PtsPtIps  >sulgema !28_V	et	f	\N
137332	suletud	suletud =suletu  (PlN  >suletu !01_AS	et	f	\N
137333	suletud	"suletu %sule  )TU1_vS  <sulgema ;28_V	et	f	\N
137334	suletud	"suletu %sule  )TU2_kA  <sulg ;22_S	et	f	\N
137335	suletud	suletud =suletud  (ID  >suletud !41_A	et	f	\N
137336	suletud	"suletud %sule  )TUD_vA  <sulgema ;28_V	et	f	\N
137340	julgust	julgust =julgus  (SgP  >julgus !11~09_S	et	f	\N
137341	julgust	"julgus %julge  )US_aS  <julge ;01_A	et	f	\N
137345	huvilised	huvilised =huvilise  (PlN  >huviline !12_SA	et	f	\N
137346	huvilised	"huviline %huvi  )LINE_aA  <huvi ;17_S	et	f	\N
137380	likvideerimist	likvideerimist =likvideerimis  (SgP  >likvideerimine !12_S	et	f	\N
137381	likvideerimist	"likvideerimine %likvideeri  )MINE_vS  <likvideerima ;28_V	et	f	\N
137383	talupoega	talupoega =poe  (SgKom  >talu+pood !22_S	et	f	\N
137384	talupoega	talupoega =poega  (SgP  >talu+poeg !22_S	et	f	\N
137385	talupoega	talupoega =poega  (SgAdt  >talu+poeg !22_S	et	f	\N
137391	saagiga	saagiga =saagi  (SgKom  >saak !22_S	et	f	\N
137392	saagiga	saagiga =iga  (SgN  >saag+iga !18_S	et	f	\N
137393	saagiga	saagiga =iga  (SgP  >saag+iga !18_S	et	f	\N
137396	edendamisse	edendamisse =edendamis  (SgAdt  >edendamine !12_S	et	f	\N
137397	edendamisse	"edendamine %edenda  )MINE_vS  <edendama ;27_V	et	f	\N
137407	köler	?köler =köler  (SgN  >köler !02_S	et	f	\N
137413	teatavaks	teatavaks =teatava  (SgTr  >teatav !02_A	et	f	\N
137414	teatavaks	"teatav %tea  )TAV_vAS  <teadma ;34_V	et	f	\N
137415	teatavaks	"teatav %teata  )V_vA  <teatama ;27_V	et	f	\N
137416	petersonid	?petersonid =petersoni  (PlN  >peterson !19_S	et	f	\N
137421	märt	?märt =märt  (SgN  >märt !22_S	et	f	\N
137432	tõstis	tõstis =tõst  (IndIpfSg3  >tõstma !34_V	et	f	\N
137434	tõstis	tõstis =tõsti  (SgIn  >tõst !22_S	et	f	\N
137437	jannsenist	?jannsenist =jannseni  (SgEl  >jannsen !02_S	et	f	\N
137438	jannsenist	?jannsenist =jannsenis  (SgP  >jannsenis !11_S	et	f	\N
137439	jannsenist	?jannsenist =jannsenist  (SgN  >jannsenist !22_S	et	f	\N
137452	sakala	?sakala =sakala  (SgN  >sakala !01_S	et	f	\N
137453	sakala	?sakala =sakala  (SgG  >sakala !01_S	et	f	\N
137470	harituimateist	harituimateist =te  (PlEl  >hari+tuima+tee !26_S	et	f	\N
137471	harituimateist	harituimateist =teist  (SgN  >hari+tuima+teist !22_S	et	f	\N
137478	tähtsamatex	### tähtsamatex	et	f	\N
137480	linnadex	### linnadex	et	f	\N
137486	pärisorjastatud	pärisorjastatud =orjasta  (PtsPtIps  >päris+orjastama !27_V	et	f	\N
137487	pärisorjastatud	pärisorjastatud =orjastatu  (PlN  >päris+orjastatu !01_S	et	f	\N
137508	gotlandi	?gotlandi =gotlandi  (SgN  >gotlandi !01_S	et	f	\N
137509	gotlandi	?gotlandi =gotlandi  (SgG  >gotlandi !01_S	et	f	\N
137510	gotlandi	?gotlandi =gotlandi  (SgG  >gotland !02_S	et	f	\N
137511	gotlandi	?gotlandi =gotlandi  (SgG  >gotlant !22_S	et	f	\N
137512	gotlandi	?gotlandi =gotlandi  (IndPrPs_  >gotlantima !28_V	et	f	\N
137513	gotlandi	?gotlandi =gotlandi  (ImpPrSg2  >gotlantima !28_V	et	f	\N
137514	henriku	?henriku =henriku  (SgN  >henriku !01_S	et	f	\N
137314	komiteedi	?komiteedi =komiteedi  (IndPrPs_  >komiteetima !28_V	et	f	\N
137315	komiteedi	?komiteedi =komiteedi  (ImpPrSg2  >komiteetima !28_V	et	f	\N
137316	komiteedi	?komiteedi =iteedi  (SgN  >kom+iteedi !16_S	et	f	\N
137317	komiteedi	?komiteedi =iteedi  (SgG  >kom+iteedi !16_S	et	f	\N
137318	komiteedi	?komiteedi =iteedi  (SgG  >kom+iteet !22_S	et	f	\N
137319	komiteedi	?komiteedi =iteedi  (SgP  >kom+iteed !22_S	et	f	\N
137320	komiteedi	?komiteedi =iteedi  (SgAdt  >kom+iteed !22_S	et	f	\N
137321	valimiskampaania	valimiskampaania =kampaania  (SgN  >valimis+kampaania !01_S	et	f	\N
137322	valimiskampaania	valimiskampaania =kampaania  (SgG  >valimis+kampaania !01_S	et	f	\N
137347	seltsis	seltsis =seltsi  (SgIn  >selts !22_S	et	f	\N
137348	seltsis	seltsis =seltsi  (IndIpfSg3  >seltsima !28_V	et	f	\N
137349	seltsis	seltsis =seltsis  (ID  >seltsis !41_DK	et	f	\N
137350	tegutsemise	tegutsemise =tegutsemise  (SgG  >tegutsemine !12_S	et	f	\N
137351	tegutsemise	"tegutsemine %tegutse  )MINE_vS  <tegutsema ;27_V	et	f	\N
137372	eluolu	eluolu =olu  (SgN  >elu+olu !17_S	et	f	\N
137373	eluolu	eluolu =olu  (SgG  >elu+olu !17_S	et	f	\N
137374	eluolu	eluolu =olu  (SgP  >elu+olu !17_S	et	f	\N
137382	1802a	### 1802a	et	f	\N
137388	1832a	### 1832a	et	f	\N
137409	juhatamisel	juhatamisel =juhatamise  (SgAd  >juhatamine !12_S	et	f	\N
137410	juhatamisel	"juhatamine %juhata  )MINE_vS  <juhatama ;27_V	et	f	\N
137420	sisn	?sisn =sisn  (SgN  >sisn !22_S	et	f	\N
137429	al	### al	et	f	\N
137430	esimesi	esimesi =esimesi  (PlP  >esimene !12_OP	et	f	\N
137431	esimesi	esimesi =mesi  (SgN  >esi+mesi !15_S	et	f	\N
137433	esimesi	esimesi =mesi  (PlP  >esi+mesi !15_S	et	f	\N
137435	iseteadvust	iseteadvust =teadvus  (SgP  >ise+teadvus !11~09_S	et	f	\N
137436	iseteadvust	"ise+teadvus %teadva  )US_aS  <ise+teadev ;02_A	et	f	\N
137440	toimumine	toimumine =toimumine  (SgN  >toimumine !12_S	et	f	\N
137441	toimumine	"toimumine %toimu  )MINE_vS  <toimuma ;27_V	et	f	\N
137446	pids	?pids =pids  (SgN  >pids !22_S	et	f	\N
137467	1862a	### 1862a	et	f	\N
137477	ca	### ca	et	f	\N
137493	linnadevahelisi	linnadevahelisi =vahelisi  (PlP  >linnade+vaheline !12_A	et	f	\N
137494	linnadevahelisi	"linnade+vaheline %vahe  )LINE_aA  <linnade+vahe ;16_S	et	f	\N
137495	kannatasid	kannatasid =kannata  (IndIpfSg2  >kannatama !27_V	et	f	\N
137496	kannatasid	kannatasid =kannata  (IndIpfPl3  >kannatama !27_V	et	f	\N
137520	1205a	### 1205a	et	f	\N
137521	ristimisest	ristimisest =ristimise  (SgEl  >ristimine !12_S	et	f	\N
137522	ristimisest	"ristimine %risti  )MINE_vS  <ristima ;28_V	et	f	\N
137552	visalt	visalt =visa  (SgAbl  >visa !17_A	et	f	\N
137553	visalt	visalt =visalt  (ID  >visalt !41_D	et	f	\N
137554	visalt	"visalt %visa  )LT_mD  <visa ;17_A	et	f	\N
137563	sajni	?sajni =sajni  (SgN  >sajni !16_S	et	f	\N
137564	sajni	?sajni =sajni  (SgG  >sajni !16_S	et	f	\N
137565	sajni	?sajni =sajni  (SgG  >sajn !22_S	et	f	\N
137566	sajni	?sajni =sajni  (SgP  >sajn !22_S	et	f	\N
137567	sajni	?sajni =sajni  (SgAdt  >sajn !22_S	et	f	\N
137568	sajni	?sajni =sajni  (IndPrPs_  >sajnima !28_V	et	f	\N
137569	sajni	?sajni =sajni  (ImpPrSg2  >sajnima !28_V	et	f	\N
137572	pühitsemine	pühitsemine =pühitsemine  (SgN  >pühitsemine !12_S	et	f	\N
137575	pühitsemine	"pühitsemine %pühitse  )MINE_vS  <pühitsema ;27_V	et	f	\N
137582	kiriklikud	kiriklikud =kirikliku  (PlN  >kiriklik !25_A	et	f	\N
137583	kiriklikud	kiriklikud =kliku  (PlN  >kiri+klikk !22_S	et	f	\N
137584	veritasu	veritasu =tasu  (SgN  >veri+tasu !17_S	et	f	\N
137585	veritasu	veritasu =tasu  (SgG  >veri+tasu !17_S	et	f	\N
137586	veritasu	veritasu =tasu  (SgP  >veri+tasu !17_S	et	f	\N
137589	pühapäevased	pühapäevased =päevase  (PlN  >püha+päevane !10_A	et	f	\N
137590	pühapäevased	"püha+päevane %päeva  )NE_aA  <püha+päev ;22_S	et	f	\N
137605	teadaolevalt	teadaolevalt =oleva  (SgAbl  >teada+olev !02_A	et	f	\N
137607	teadaolevalt	"teada+olevalt %oleva  )LT_mD  <teada+olev ;02_A	et	f	\N
137619	kaubalinnu	kaubalinnu =linnu  (SgG  >kauba+lind !22_S	et	f	\N
137620	kaubalinnu	kaubalinnu =linnu  (PlP  >kauba+linn !22_S	et	f	\N
137659	eerineb	?eerineb =eerine  (IndPrSg3  >eerinema !27_V	et	f	\N
137660	soemad	?soemad =soema  (PlN  >soema !16_S	et	f	\N
137661	soemad	?soemad =soema  (IndPrSg2  >soemama !29_V	et	f	\N
137677	verona	?verona =vero  (SgEs  >vero !17~16_S	et	f	\N
137683	san	### san	et	f	\N
137684	marko	?marko =marko  (SgN  >marko !16_S	et	f	\N
137685	marko	?marko =marko  (SgG  >marko !16_S	et	f	\N
137692	tegelisid	### tegelisid	et	f	\N
137697	leonardo	?leonardo =leonardo  (SgN  >leonardo !16_S	et	f	\N
137698	leonardo	?leonardo =leonardo  (SgG  >leonardo !16_S	et	f	\N
137725	val	### val	et	f	\N
137754	alpides	alpides =alpi  (PlIn  >alp !22_A	et	f	\N
137755	alpides	alpides =alpi  (Ger  >alpima !28_V	et	f	\N
137756	ajata	ajata =aja  (SgAb  >aeg !22_S	et	f	\N
137757	ajata	ajata =ajata  (IndPrPs_  >ajatama !27_V	et	f	\N
137758	ajata	ajata =ajata  (ImpPrSg2  >ajatama !27_V	et	f	\N
137774	bar	### bar	et	f	\N
137787	underground	?underground =underground  (SgN  >underground !22_S	et	f	\N
137344	jacobson	?jacobson =jacobson  (SgN  >jacobson !19_S	et	f	\N
137360	jannesen	?jannesen =jannesen  (SgN  >jannesen !19_S	et	f	\N
137361	tähtsid	?tähtsid =tähtsi  (PlN  >tähts !22_S	et	f	\N
137362	tähtsid	?tähtsid =tähtsi  (IndPrSg2  >tähtsima !28_V	et	f	\N
137363	luuletajast	luuletajast =luuletaja  (SgEl  >luuletaja !01_S	et	f	\N
137364	luuletajast	"luuletaja %luuleta  )JA_vS  <luuletama ;27_V	et	f	\N
137365	luuletajast	luuletajast =luuletajas  (SgP  >luuletajane !12_A	et	f	\N
137366	luuletajast	"luuletajane %luuletaja  )NE_aA  <luuletaja ;01_S	et	f	\N
137389	eluteed	eluteed =tee  (PlN  >elu+tee !26_S	et	f	\N
137390	eluteed	eluteed =tee  (SgP  >elu+tee !26_S	et	f	\N
137398	perno	?perno =perno  (SgN  >perno !16_S	et	f	\N
137399	perno	?perno =perno  (SgG  >perno !16_S	et	f	\N
137400	paari	paari =paari  (ID  >paari !41_D	et	f	\N
137401	paari	paari =paari  (SgG  >paar !22_NS	et	f	\N
137402	paari	paari =paari  (SgP  >paar !22_NS	et	f	\N
137403	paari	paari =paari  (SgAdt  >paar !22_NS	et	f	\N
137404	paari	paari =paari  (IndPrPs_  >paarima !28_V	et	f	\N
137405	paari	paari =paari  (ImpPrSg2  >paarima !28_V	et	f	\N
137406	ülipopulaarseks	ülipopulaarseks =seks  (SgN  >üli+populaar+seks !22_S	et	f	\N
137408	ülipopulaarseks	ülipopulaarseks =populaarse  (SgTr  >üli+populaarne !02_A	et	f	\N
137411	saatmine	saatmine =saatmine  (SgN  >saatmine !12?10_S	et	f	\N
137412	saatmine	"saatmine %saat  )MINE_vS  <saatma ;34_V	et	f	\N
137417	palvekirja	palvekirja =kirja  (SgG  >palve+kiri !24_S	et	f	\N
137418	palvekirja	palvekirja =kirja  (SgP  >palve+kiri !24_S	et	f	\N
137419	palvekirja	palvekirja =kirja  (SgAdt  >palve+kiri !24_S	et	f	\N
137422	jakobsoni	?jakobsoni =jakobso  (SgTer  >jakobso !16_S	et	f	\N
137423	jakobsoni	?jakobsoni =jakobsoni  (SgG  >jakobson !19_S	et	f	\N
137424	jakobsoni	?jakobsoni =jakobsoni  (SgP  >jakobson !19_S	et	f	\N
137425	jakobsoni	?jakobsoni =jakobsoni  (SgAdt  >jakobson !19_S	et	f	\N
137442	1869a	### 1869a	et	f	\N
137449	andekamaid	andekamaid =andekama  (PlP  >andekam !02_A	et	f	\N
137450	andekamaid	"andekam %andeka  )M_cA  <andekas ;02_A	et	f	\N
137451	1878a	### 1878a	et	f	\N
137468	liikumisele	liikumisele =liikumise  (SgAll  >liikumine !12_S	et	f	\N
137469	liikumisele	"liikumine %liiku  )MINE_vS  <liikuma ;28_V	et	f	\N
137479	väiksematex	### väiksematex	et	f	\N
137500	visbyru	?visbyru =visbyru  (SgN  >visbyru !01_S	et	f	\N
137502	visbyru	?visbyru =visbyru  (SgG  >visbyru !01_S	et	f	\N
137503	visbyru	?visbyru =visbyru  (IndPrPs_  >visbyruma !27_V	et	f	\N
137506	visbyru	?visbyru =visbyru  (ImpPrSg2  >visbyruma !27_V	et	f	\N
137524	mälestisex	### mälestisex	et	f	\N
137528	pühadex	### pühadex	et	f	\N
137555	muutumatux	### muutumatux	et	f	\N
137556	sajanditex	### sajanditex	et	f	\N
137576	austamise	austamise =austamise  (SgG  >austamine !12_S	et	f	\N
137577	austamise	"austamine %austa  )MINE_vS  <austama ;27_V	et	f	\N
137578	külakatoliiklus	külakatoliiklus =katoliiklus  (SgN  >küla+katoliiklus !11~09_S	et	f	\N
137579	külakatoliiklus	"küla+katoliiklus %katoliiklase  )US_aS  <küla+katoliiklane ;12_S	et	f	\N
137580	katolikud	?katolikud =katoliku  (PlN  >katolik !25_A	et	f	\N
137581	katolikud	?katolikud =katoliku  (IndPrSg2  >katolikuma !27_V	et	f	\N
137591	aastastele	aastastele =aastas  (PlAll  >aastane !12~10_A	et	f	\N
137592	aastastele	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
137593	elementaarselt	elementaarselt =elementaarse  (SgAbl  >elementaarne !02_A	et	f	\N
137594	elementaarselt	elementaarselt =elementaarselt  (ID  >elementaarselt !41_D	et	f	\N
137595	elementaarselt	"elementaarselt %elementaarse  )LT_mD  <elementaarne ;02_A	et	f	\N
137616	saksamaa	saksamaa =maa  (SgN  >saksa+maa !26_S	et	f	\N
137618	saksamaa	saksamaa =maa  (SgG  >saksa+maa !26_S	et	f	\N
137654	müüavisi	### müüavisi	et	f	\N
137687	väna	?väna =väna  (SgN  >väna !17_S	et	f	\N
137688	väna	?väna =väna  (SgG  >väna !17_S	et	f	\N
137689	väna	?väna =väna  (SgP  >väna !17_S	et	f	\N
137690	väna	?väna =väna  (IndPrPs_  >vänama !27_V	et	f	\N
137691	väna	?väna =väna  (ImpPrSg2  >vänama !27_V	et	f	\N
137705	adriaatika	?adriaatika =adriaatika  (SgN  >adriaatika !01_S	et	f	\N
137706	adriaatika	?adriaatika =adriaatika  (SgG  >adriaatika !01_S	et	f	\N
137707	adriaatika	?adriaatika =adriaatika  (SgG  >adriaatikas !02_A	et	f	\N
137712	julia	?julia =julia  (SgN  >julia !01_S	et	f	\N
137713	julia	?julia =julia  (SgG  >julia !01_S	et	f	\N
137714	rohelises	rohelises =rohelise  (SgIn  >roheline !12_A	et	f	\N
137715	rohelises	"roheline %rohe  )LINE_aA  <rohe ;16_S	et	f	\N
137716	selel	?selel =sele  (SgAd  >sele !16_S	et	f	\N
137717	selel	?selel =selel  (SgN  >selel !02_S	et	f	\N
137718	suusakuurortis	?suusakuurortis =suusakuurorti  (IndIpfSg3  >suusakuurortima !28_V	et	f	\N
137719	suusakuurortis	?suusakuurortis =suusakuurortis  (SgN  >suusakuurortis !09_S	et	f	\N
137720	suusakuurortis	?suusakuurortis =kuurorti  (SgIn  >suusa+kuurorti !01_S	et	f	\N
137722	suusakuurortis	?suusakuurortis =kuurortis  (SgN  >suusa+kuurortis !11_S	et	f	\N
137723	suusakuurortis	?suusakuurortis =sakuurortis  (SgN  >suu+sakuurortis !09_S	et	f	\N
137728	orgu	orgu =orgu  (SgP  >org !22_S	et	f	\N
137376	parandamise	"parandamine %paranda  )MINE_vS  <parandama ;27_V	et	f	\N
137377	estofilid	?estofilid =fili  (PlN  >esto+fili !17_S	et	f	\N
137460	pooldaja	pooldaja =pooldaja  (SgN  >pooldaja !01_S	et	f	\N
137461	pooldaja	"pooldaja %poolda  )JA_vS  <pooldama ;27_V	et	f	\N
137462	pooldaja	pooldaja =pooldaja  (SgG  >pooldaja !01_S	et	f	\N
137475	säilimist	säilimist =säilimis  (SgP  >säilimine !12_S	et	f	\N
137476	säilimist	"säilimine %säili  )MINE_vS  <säilima ;28_V	et	f	\N
137481	maaadel	?maaadel =maaa  (PlAd  >maaa !26_S	et	f	\N
137482	maaadel	?maaadel =maaade  (SgAd  >maaade !16_S	et	f	\N
137483	maaadel	?maaadel =maaade  (PlAd  >maaat !22_S	et	f	\N
137484	maaadel	?maaadel =ade  (SgAd  >maa+ade !16_S	et	f	\N
137485	maaadel	?maaadel =adel  (SgN  >maa+adel !02_S	et	f	\N
137490	jõukamaks	jõukamaks =jõukama  (SgTr  >jõukam !02_A	et	f	\N
137491	jõukamaks	"jõukam %jõuka  )M_cA  <jõukas ;02_A	et	f	\N
137492	jõukamaks	jõukamaks =kama  (SgTr  >jõu+kama !17_S	et	f	\N
137538	ülemvõimu	ülemvõimu =võimu  (SgG  >ülem+võim !22_S	et	f	\N
137539	ülemvõimu	ülemvõimu =võimu  (SgP  >ülem+võim !22_S	et	f	\N
137540	ülemvõimu	ülemvõimu =võimu  (SgAdt  >ülem+võim !22_S	et	f	\N
137557	sunniviisiliselt	sunniviisiliselt =viisilise  (SgAbl  >sunni+viisiline !12_A	et	f	\N
137558	sunniviisiliselt	"sunni+viisiline %viisi  )LINE_aA  <sunni+viis ;22_S	et	f	\N
137559	sunniviisiliselt	"sunni+viisiliselt %viisi  )LISELT_mD  <sunni+viis ;22_S	et	f	\N
137560	sunniviisiliselt	"sunni+viisiliselt %viisilise  )LT_mD  <sunni+viisiline ;12_A	et	f	\N
137570	välisid	?välisid =väli  (IndIpfSg2  >välima !27_V	et	f	\N
137571	välisid	?välisid =väli  (IndIpfPl3  >välima !27_V	et	f	\N
137596	käsku	käsku =käsku  (SgP  >käsk !22_S	et	f	\N
137597	käsku	käsku =käsku  (SgAdt  >käsk !22_S	et	f	\N
137598	kristlikult	kristlikult =kristliku  (SgAbl  >kristlik !25_A	et	f	\N
137599	kristlikult	kristlikult =kristlikult  (ID  >kristlikult !41_D	et	f	\N
137600	kristlikult	"kristlikult %kristliku  )LT_mD  <kristlik ;25_A	et	f	\N
137612	2põhja	põhja =põhja  (SgG  >põhi !24_S	et	f	\N
137613	2põhja	põhja =põhja  (SgP  >põhi !24_S	et	f	\N
137614	2põhja	põhja =põhja  (SgAdt  >põhi !24_S	et	f	\N
137615	2põhja	põhja =põhja  (IndPrPs_  >põhjama !29_V	et	f	\N
137617	2põhja	põhja =põhja  (ImpPrSg2  >põhjama !29_V	et	f	\N
137621	orduriiri	?orduriiri =orduriiri  (SgN  >orduriiri !16_S	et	f	\N
137622	orduriiri	?orduriiri =orduriiri  (SgG  >orduriiri !16_S	et	f	\N
137625	orduriiri	?orduriiri =orduriiri  (SgG  >orduriir !22_S	et	f	\N
137626	orduriiri	?orduriiri =orduriiri  (SgP  >orduriir !22_S	et	f	\N
137627	orduriiri	?orduriiri =orduriiri  (SgAdt  >orduriir !22_S	et	f	\N
137628	orduriiri	?orduriiri =orduriiri  (IndPrPs_  >orduriirima !28_V	et	f	\N
137629	orduriiri	?orduriiri =orduriiri  (ImpPrSg2  >orduriirima !28_V	et	f	\N
137630	orduriiri	?orduriiri =riiri  (SgN  >ordu+riiri !16_S	et	f	\N
137631	orduriiri	?orduriiri =riiri  (SgG  >ordu+riiri !16_S	et	f	\N
137632	orduriiri	?orduriiri =riiri  (SgG  >ordu+riir !22_S	et	f	\N
137633	orduriiri	?orduriiri =riiri  (SgP  >ordu+riir !22_S	et	f	\N
137634	orduriiri	?orduriiri =riiri  (SgAdt  >ordu+riir !22_S	et	f	\N
137635	hansakaupmeestel	hansakaupmeestel =mees  (PlAd  >hansa+kaup+meene !10_A	et	f	\N
137636	hansakaupmeestel	"hansa+kaup+meene %mee  )NE_aA  <hansa+kaup+mesi ;15_S	et	f	\N
137637	hansakaupmeestel	hansakaupmeestel =mees  (PlAd  >hansa+kaup+mees !13_S	et	f	\N
137638	sisemaal	sisemaal =maa  (SgAd  >sise+maa !26_S	et	f	\N
137639	sisemaal	sisemaal =maal  (SgN  >sise+maal !22_S	et	f	\N
137662	puuviljud	?puuviljud =puuvilju  (PlN  >puuvilju !01_S	et	f	\N
137663	puuviljud	?puuviljud =puuvilju  (IndPrSg2  >puuviljuma !27_V	et	f	\N
137664	puuviljud	?puuviljud =vilju  (PlN  >puu+vilju !16_S	et	f	\N
137669	jaanu	?jaanu =jaanu  (SgN  >jaanu !16_S	et	f	\N
137670	jaanu	?jaanu =jaanu  (SgG  >jaanu !16_S	et	f	\N
137671	jaanu	?jaanu =jaanu  (IndPrPs_  >jaanuma !28_V	et	f	\N
137672	jaanu	?jaanu =jaanu  (ImpPrSg2  >jaanuma !28_V	et	f	\N
137693	skulpterid	?skulpterid =skulpteri  (PlN  >skulpteri !01_S	et	f	\N
137694	skulpterid	?skulpterid =skulpteri  (PlN  >skulpter !02_S	et	f	\N
137695	mikkel	mikkel =mikke  (SgAd  >mike !06_S	et	f	\N
137696	mikkel	"mike %mi  )KE_dS  <mi ;26_S	et	f	\N
137704	kurordilinn	?kurordilinn =kurordilinn  (SgN  >kurordilinn !22_S	et	f	\N
137749	metsikuima	metsikuima =metsikuima  (SgG  >metsikuim !02_A	et	f	\N
137750	metsikuima	"metsikuim %metsiku  )IM_sA  <metsik ;02_AS	et	f	\N
137751	metsikuima	metsikuima =ima  (SgN  >metsiku+ima !17_S	et	f	\N
137752	metsikuima	metsikuima =ima  (SgG  >metsiku+ima !17_S	et	f	\N
137753	metsikuima	metsikuima =ima  (SgP  >metsiku+ima !17_S	et	f	\N
137767	ski	### ski	et	f	\N
137775	gringo	?gringo =gringo  (SgN  >gringo !16_S	et	f	\N
137776	gringo	?gringo =gringo  (SgG  >gringo !16_S	et	f	\N
137808	veetmise	veetmise =veetmise  (SgG  >veetmine !12?10_S	et	f	\N
137810	veetmise	"veetmine %veet  )MINE_vS  <veetma ;34_V	et	f	\N
137821	telkida	telkida =telki  (Inf  >telkima !28_V	et	f	\N
137822	telkida	telkida =ida  (SgN  >telk+ida !17_S	et	f	\N
137823	telkida	telkida =ida  (SgG  >telk+ida !17_S	et	f	\N
137515	henriku	?henriku =henriku  (SgG  >henriku !01_S	et	f	\N
137516	henriku	?henriku =henriku  (SgG  >henrik !02_S	et	f	\N
137517	henriku	?henriku =henriku  (IndPrPs_  >henrikuma !27_V	et	f	\N
137518	henriku	?henriku =henriku  (ImpPrSg2  >henrikuma !27_V	et	f	\N
137525	muude	muude =muu  (PlG  >muu !26_P	et	f	\N
137526	muude	muude =muu  (PlG  >muu !26_S	et	f	\N
137527	muude	muude =muude  (SgN  >muude !06_S	et	f	\N
137535	ulatuma	ulatuma =ulatu  (Sup  >ulatuma !27_V	et	f	\N
137536	ulatuma	ulatuma =ulatuma  (SgG  >ulatum !02_A	et	f	\N
137537	ulatuma	"ulatum %ula  )TUM1_cA  <ulama ;27_V	et	f	\N
137541	maxe	?maxe =maxe  (SgN  >maxe !06_S	et	f	\N
137542	maxe	?maxe =maxe  (SgG  >maxe !06_S	et	f	\N
137548	ürituste	ürituste =üritus  (PlG  >üritus !11_S	et	f	\N
137549	ürituste	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
137561	säilisid	säilisid =säili  (IndIpfSg2  >säilima !28_V	et	f	\N
137562	säilisid	säilisid =säili  (IndIpfPl3  >säilima !28_V	et	f	\N
137573	õnnistamine	õnnistamine =õnnistamine  (SgN  >õnnistamine !12_S	et	f	\N
137574	õnnistamine	"õnnistamine %õnnista  )MINE_vS  <õnnistama ;27_V	et	f	\N
137602	talupojast	talupojast =poja  (SgEl  >talu+poja !17_S	et	f	\N
137603	talupojast	talupojast =poja  (SgEl  >talu+poeg !22_S	et	f	\N
137604	talupojast	talupojast =pojas  (SgP  >talu+pojane !10_A	et	f	\N
137606	talupojast	"talu+pojane %poja  )NE_aA  <talu+poja ;17_S	et	f	\N
137608	talupojast	"talu+pojane %poja  )NE_aA  <talu+poeg ;22_S	et	f	\N
137609	rostocki	?rostocki =rostocki  (SgG  >rostock !22_S	et	f	\N
137610	rostocki	?rostocki =rostocki  (SgP  >rostock !22_S	et	f	\N
137611	rostocki	?rostocki =rostocki  (SgAdt  >rostock !22_S	et	f	\N
137623	preisimaal	preisimaal =maa  (SgAd  >preisi+maa !26_S	et	f	\N
137624	preisimaal	preisimaal =maal  (SgN  >preisi+maal !22_S	et	f	\N
137640	kaunase	kaunase =kaunase  (SgG  >kaunane !10_A	et	f	\N
137641	kaunase	"kaunane %kauna  )NE_aA  <kaun ;22_S	et	f	\N
137642	kaunase	"kaunane %kauna  )NE_aA  <kaun ;23_S	et	f	\N
137647	taotlesid	taotlesid =taotle  (IndIpfSg2  >taotlema !27_V	et	f	\N
137648	taotlesid	taotlesid =taotle  (IndIpfPl3  >taotlema !27_V	et	f	\N
137665	kustutavad	kustutavad =kustuta  (IndPrPl3  >kustutama !27_V	et	f	\N
137666	kustutavad	kustutavad =kustutava  (PlN  >kustutav !02_A	et	f	\N
137667	kustutavad	"kustutav %kustu  )TAV_vAS  <kustuma ;28_V	et	f	\N
137668	kustutavad	"kustutav %kustuta  )V_vA  <kustutama ;27_V	et	f	\N
137676	diezolo	?diezolo =diezolo  (SgN  >diezolo !01_S	et	f	\N
137678	diezolo	?diezolo =diezolo  (SgG  >diezolo !01_S	et	f	\N
137699	vinci	?vinci =vinci  (SgN  >vinci !16_S	et	f	\N
137700	vinci	?vinci =vinci  (SgG  >vinci !16_S	et	f	\N
137701	vinci	?vinci =vinci  (SgG  >vinc !22_S	et	f	\N
137702	vinci	?vinci =vinci  (SgP  >vinc !22_S	et	f	\N
137703	vinci	?vinci =vinci  (SgAdt  >vinc !22_S	et	f	\N
137721	suusakuurorti	suusakuurorti =kuurorti  (SgP  >suusa+kuurort !22_S	et	f	\N
137724	suusakuurorti	suusakuurorti =kuurorti  (SgAdt  >suusa+kuurort !22_S	et	f	\N
137727	val	### val	et	f	\N
137744	maini	maini =mai  (SgTer  >mai !26_S	et	f	\N
137745	maini	maini =maini  (IndPrPs_  >mainima !28_V	et	f	\N
137746	maini	maini =maini  (ImpPrSg2  >mainima !28_V	et	f	\N
137747	lõbusaima	lõbusaima =lõbusaima  (SgG  >lõbusaim !02_A	et	f	\N
137748	lõbusaima	"lõbusaim %lõbusa  )IM_sA  <lõbus ;02_A	et	f	\N
137773	saloon	?saloon =saloon  (SgN  >saloon !22_S	et	f	\N
137785	malaysia	?malaysia =malaysia  (SgN  >malaysia !01_S	et	f	\N
137786	malaysia	?malaysia =malaysia  (SgG  >malaysia !01_S	et	f	\N
137788	suuruses	suuruses =suuruse  (SgIn  >suurus !11~09_S	et	f	\N
137789	suuruses	"suurus %suur  )US_aS  <suur ;13_A	et	f	\N
137790	suuruses	suuruses =suuruse  (SgIn  >suurune !10~12_A	et	f	\N
137791	suuruses	suuruses =use  (PlIn  >suur+usk !22_S	et	f	\N
137792	suuruses	suuruses =ruse  (PlIn  >suu+rusk !22_S	et	f	\N
137795	sulgpalli	sulgpalli =palli  (SgG  >sulg+pall !22_S	et	f	\N
137796	sulgpalli	sulgpalli =palli  (SgP  >sulg+pall !22_S	et	f	\N
137797	sulgpalli	sulgpalli =palli  (SgAdt  >sulg+pall !22_S	et	f	\N
137809	viisiks	viisiks =viisi  (SgTr  >viis !22_S	et	f	\N
137811	viisiks	viisiks =iks  (SgN  >viis+iks !22_S	et	f	\N
137819	puhkajaid	puhkajaid =puhkaja  (PlP  >puhkaja !01_S	et	f	\N
137820	puhkajaid	"puhkaja %puhka  )JA_vS  <puhkama ;29_V	et	f	\N
137832	puhkamisele	puhkamisele =puhkamise  (SgAll  >puhkamine !12_S	et	f	\N
137833	puhkamisele	"puhkamine %puhka  )MINE_vS  <puhkama ;29_V	et	f	\N
137834	hobusetalu	hobusetalu =talu  (SgN  >hobuse+talu !17_S	et	f	\N
137835	hobusetalu	hobusetalu =talu  (SgG  >hobuse+talu !17_S	et	f	\N
137836	hobusetalu	hobusetalu =talu  (SgP  >hobuse+talu !17_S	et	f	\N
137843	lähistel	lähistel =lähis  (PlAd  >lähis !09_S	et	f	\N
137844	lähistel	lähistel =lähis  (PlAd  >lähine !10_A	et	f	\N
137845	lähistel	lähistel =lähistel  (ID  >lähistel !41_K	et	f	\N
137850	hobustega	hobustega =hobus  (PlKom  >hobune !10_S	et	f	\N
137851	hobustega	"hobune %hobu  )NE_aA  <hobu ;17_S	et	f	\N
137865	miniköög	?miniköög =miniköög  (SgN  >miniköög !22_S	et	f	\N
137866	miniköög	?miniköög =köög  (SgN  >mini+köög !22_S	et	f	\N
137545	pühitsetud	"pühitsetu %pühitse  )TU1_vS  <pühitsema ;27_V	et	f	\N
137546	pühitsetud	pühitsetud =pühitsetud  (ID  >pühitsetud !41_A	et	f	\N
137547	pühitsetud	"pühitsetud %pühitse  )TUD_vA  <pühitsema ;27_V	et	f	\N
137550	kommete	kommete =komme  (PlG  >komme !06_S	et	f	\N
137551	kommete	kommete =me  (PlG  >kom+mesi !15_S	et	f	\N
137587	hääbusid	hääbusid =hääbu  (IndIpfSg2  >hääbuma !27_V	et	f	\N
137588	hääbusid	hääbusid =hääbu  (IndIpfPl3  >hääbuma !27_V	et	f	\N
137601	pulck	?pulck =pulck  (SgN  >pulck !22_S	et	f	\N
137643	polotski	?polotski =polotski  (SgG  >polotsk !02_S	et	f	\N
137644	polotski	?polotski =polotski  (IndPrPs_  >polotskima !28_V	et	f	\N
137645	polotski	?polotski =polotski  (ImpPrSg2  >polotskima !28_V	et	f	\N
137646	polotski	?polotski =polots  (SgN^  >polots !02_S	et	f	\N
137649	osasaamist	osasaamist =saami  (SgEl  >osa+saam !22_S	et	f	\N
137650	osasaamist	osasaamist =saamis  (SgP  >osa+saamine !12?10_S	et	f	\N
137651	osasaamist	"osa+saamine %saami  )NE_aA  <osa+saam ;22_S	et	f	\N
137652	pealinnaks	pealinnaks =inna  (SgTr  >peal+ind !22_S	et	f	\N
137653	pealinnaks	pealinnaks =linna  (SgTr  >pea+linn !22_S	et	f	\N
137655	veos	veos =veo  (SgIn  >vedu !18_S	et	f	\N
137656	veos	veos =veos  (SgN  >veos !09_S	et	f	\N
137657	mälestussambad	mälestussambad =samba  (PlN  >mälestus+sammas !07_S	et	f	\N
137658	mälestussambad	mälestussambad =samba  (PlN  >mälestus+samba !16_S	et	f	\N
137673	lido	?lido =lido  (SgN  >lido !17~16_S	et	f	\N
137674	lido	?lido =lido  (SgG  >lido !17~16_S	et	f	\N
137675	lido	?lido =lido  (SgP  >lido !17_S	et	f	\N
137679	venetsias	?venetsias =venetsia  (SgIn  >venetsia !01_S	et	f	\N
137680	venetsias	?venetsias =venetsias  (SgN  >venetsias !11_S	et	f	\N
137681	venetsias	?venetsias =tsia  (SgIn  >vene+tsia !26_S	et	f	\N
137682	venetsias	?venetsias =tsias  (SgN  >vene+tsias !22_S	et	f	\N
137686	gondelega	### gondelega	et	f	\N
137708	roomeo	?roomeo =roomeo  (SgN  >roomeo !01_S	et	f	\N
137709	roomeo	?roomeo =roomeo  (SgG  >roomeo !01_S	et	f	\N
137710	roomeo	?roomeo =meo  (SgN  >roo+meo !26_S	et	f	\N
137711	roomeo	?roomeo =meo  (SgG  >roo+meo !26_S	et	f	\N
137726	thorens	?thorens =thorens  (SgN  >thorens !02_S	et	f	\N
137730	paiknev	paiknev =paikne  (PtsPrPs  >paiknema !27_V	et	f	\N
137731	paiknev	paiknev =paiknev  (SgN  >paiknev !02_A	et	f	\N
137732	paiknev	"paiknev %paikne  )V_vA  <paiknema ;27_V	et	f	\N
137765	biza	?biza =biza  (SgN  >biza !17_S	et	f	\N
137766	biza	?biza =biza  (SgG  >biza !17_S	et	f	\N
137768	biza	?biza =biza  (SgP  >biza !17_S	et	f	\N
137769	biza	?biza =biza  (IndPrPs_  >bizama !27_V	et	f	\N
137770	biza	?biza =biza  (ImpPrSg2  >bizama !27_V	et	f	\N
137779	sulgemist	sulgemist =sulgemis  (SgP  >sulgemine !12_S	et	f	\N
137780	sulgemist	"sulgemine %sulge  )MINE_vS  <sulgema ;27_V	et	f	\N
137781	sulgemist	"sulgemine %sulge  )MINE_vS  <sulgema ;28_V	et	f	\N
137782	sulgemist	sulgemist =emis  (SgP  >sulg+emis !09_S	et	f	\N
137793	spordihallis	spordihallis =halli  (SgIn  >spordi+hall !22_S	et	f	\N
137794	spordihallis	spordihallis =halli  (SgIn  >spordi+hall !22_AS	et	f	\N
137805	kogunevad	kogunevad =kogune  (IndPrPl3  >kogunema !27_V	et	f	\N
137806	kogunevad	kogunevad =koguneva  (PlN  >kogunev !02_A	et	f	\N
137807	kogunevad	"kogunev %kogune  )V_vA  <kogunema ;27_V	et	f	\N
137815	popularsumaks	?popularsumaks =popularsu  (SupTr  >popularsuma !27_V	et	f	\N
137816	muutumas	muutumas =muutu  (SupIn  >muutuma !27_V	et	f	\N
137817	muutumas	muutumas =muutuma  (SgIn  >muutum !02_A	et	f	\N
137818	muutumas	"muutum %muu  )TUM2_cA  <muu ;26_S	et	f	\N
137829	lemmikuteks	lemmikuteks =lemmiku  (PlTr  >lemmik !02_S	et	f	\N
137830	lemmikuteks	lemmikuteks =ute  (SgTr  >lemmik+utt !22_S	et	f	\N
137831	lemmikuteks	lemmikuteks =ute  (PlTr  >lemmik+utt !22_S	et	f	\N
137840	maastikul	maastikul =maastiku  (SgAd  >maastik !25_S	et	f	\N
137841	maastikul	maastikul =tiku  (SgAd  >maas+tikk !22_S	et	f	\N
137842	maastikul	maastikul =tiku  (PlAd  >maas+tikk !22_S	et	f	\N
137873	puhkajate	puhkajate =puhkaja  (PlG  >puhkaja !01_S	et	f	\N
137874	puhkajate	"puhkaja %puhka  )JA_vS  <puhkama ;29_V	et	f	\N
137875	kasutuses	kasutuses =kasutuse  (SgIn  >kasutus !11_S	et	f	\N
137876	kasutuses	"kasutus %kasuta  )US_vS  <kasutama ;27_V	et	f	\N
137877	kasutuses	"kasutus %kasu  )TUS2_aS  <kasu ;17_S	et	f	\N
137887	ulatuvad	ulatuvad =ulatu  (IndPrPl3  >ulatuma !27_V	et	f	\N
137888	ulatuvad	ulatuvad =ulatuva  (PlN  >ulatuv !02_A	et	f	\N
137889	ulatuvad	"ulatuv %ulatu  )V_vA  <ulatuma ;27_V	et	f	\N
137897	sõitmiseks	sõitmiseks =sõitmise  (SgTr  >sõitmine !12?10_S	et	f	\N
137898	sõitmiseks	"sõitmine %sõit  )MINE_vS  <sõitma ;34_V	et	f	\N
137901	harrastamiseks	harrastamiseks =harrastamise  (SgTr  >harrastamine !12_S	et	f	\N
137902	harrastamiseks	"harrastamine %harrasta  )MINE_vS  <harrastama ;27_V	et	f	\N
137912	kallaste	kallaste =kallas  (PlG  >kallas !07_S	et	f	\N
137913	kallaste	kallaste =kallas  (PlG  >kallane !10_A	et	f	\N
137914	kallaste	"kallane %kalla  )NE_aA  <kalla ;16_S	et	f	\N
137930	unustamatuid	unustamatuid =unustamatu  (PlP  >unustamatu !01_A	et	f	\N
137931	unustamatuid	"unustamatu %unusta  )MATU_vA  <unustama ;27_V	et	f	\N
137729	orgu	orgu =orgu  (SgAdt  >org !22_S	et	f	\N
137733	ühendatud	ühendatud =ühenda  (PtsPtIps  >ühendama !27_V	et	f	\N
137734	ühendatud	ühendatud =ühendatu  (PlN  >ühendatu !01_S	et	f	\N
137735	ühendatud	"ühendatu %ühenda  )TU1_vS  <ühendama ;27_V	et	f	\N
137736	ühendatud	ühendatud =ühendatud  (ID  >ühendatud !41_A	et	f	\N
137737	ühendatud	"ühendatud %ühenda  )TUD_vA  <ühendama ;27_V	et	f	\N
137738	ühendatud	ühendatud =atu  (PlN  >ühend+att !22_S	et	f	\N
137739	thorensis	?thorensis =thorensi  (SgIn  >thorensi !01_S	et	f	\N
137740	thorensis	?thorensis =thorensi  (SgIn  >thorens !02_S	et	f	\N
137741	thorensis	?thorensis =thorensi  (SgIn  >thorenss !22_S	et	f	\N
137742	thorensis	?thorensis =thorensi  (IndIpfSg3  >thorensima !28_V	et	f	\N
137743	thorensis	?thorensis =thorensis  (SgN  >thorensis !11_S	et	f	\N
137759	thorensi	?thorensi =thorensi  (SgN  >thorensi !01_S	et	f	\N
137760	thorensi	?thorensi =thorensi  (SgG  >thorensi !01_S	et	f	\N
137761	thorensi	?thorensi =thorensi  (SgG  >thorens !02_S	et	f	\N
137762	thorensi	?thorensi =thorensi  (SgG  >thorenss !22_S	et	f	\N
137763	thorensi	?thorensi =thorensi  (IndPrPs_  >thorenssima !28_V	et	f	\N
137764	thorensi	?thorensi =thorensi  (ImpPrSg2  >thorenssima !28_V	et	f	\N
137771	hulgi	hulgi =hulgi  (ID  >hulgi !41_D	et	f	\N
137772	hulgi	hulgi =hulgi  (SgG  >hulk !22_S	et	f	\N
137777	tango	tango =tango  (SgN  >tango !16_S	et	f	\N
137778	tango	tango =tango  (SgG  >tango !16_S	et	f	\N
137783	elava	elava =elava  (SgG  >elav !02_A	et	f	\N
137784	elava	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
137812	tõõstad	?tõõstad =tõõsta  (PlN  >tõõsta !01_S	et	f	\N
137813	tõõstad	?tõõstad =tõõsta  (IndPrSg2  >tõõstama !27_V	et	f	\N
137837	looduskaunil	looduskaunil =kauni  (SgAd  >loodus+kaunis !05~07_A	et	f	\N
137838	looduskaunil	looduskaunil =kauni  (SgAd  >loodus+kaun !22_S	et	f	\N
137839	looduskaunil	looduskaunil =kauni  (PlAd  >loodus+kaun !22_S	et	f	\N
137847	meeldiva	meeldiva =meeldiva  (SgG  >meeldiv !02_A	et	f	\N
137849	meeldiva	"meeldiv %meeldi  )V_vA  <meeldima ;27_V	et	f	\N
137852	ratsustada	?ratsustada =ratsusta  (Inf  >ratsustama !27_V	et	f	\N
137853	ratsustada	?ratsustada =stada  (SgN  >ratsu+stada !17_S	et	f	\N
137854	ratsustada	?ratsustada =stada  (SgG  >ratsu+stada !17_S	et	f	\N
137855	ratsustada	?ratsustada =stada  (SgP  >ratsu+stada !17_S	et	f	\N
137856	kolessiga	?kolessiga =kolessi  (SgKom  >kolessi !01_S	et	f	\N
137857	kolessiga	?kolessiga =kolessi  (SgKom  >koless !22_S	et	f	\N
137869	terass	?terass =terass  (SgN  >terass !22_S	et	f	\N
137890	sadelevad	?sadelevad =sadele  (IndPrPl3  >sadelema !31~27_V	et	f	\N
137891	sadelevad	?sadelevad =sadeleva  (PlN  >sadelev !02_A	et	f	\N
137892	sadelevad	?sadelevad =sadeleva  (PlN  >sadeleva !16_S	et	f	\N
137895	matkamiseks	matkamiseks =matkamise  (SgTr  >matkamine !12_S	et	f	\N
137896	matkamiseks	"matkamine %matka  )MINE_vS  <matkama ;29_V	et	f	\N
137923	kodumaad	kodumaad =maa  (PlN  >kodu+maa !26_S	et	f	\N
137924	kodumaad	kodumaad =maa  (SgP  >kodu+maa !26_S	et	f	\N
137932	lõunamaa	lõunamaa =maa  (SgN  >lõuna+maa !26_S	et	f	\N
137933	lõunamaa	lõunamaa =maa  (SgG  >lõuna+maa !26_S	et	f	\N
137942	sousse	?sousse =sou  (SgIll  >sou !26_S	et	f	\N
137943	sousse	?sousse =sousse  (SgG  >sousne !02_A	et	f	\N
137944	sousse	?sousse =sousse  (SgG  >souse !06_S	et	f	\N
137945	sousse	?sousse =sousse  (PlP  >souss !22_S	et	f	\N
137946	sousse	?sousse =sousse  (IndPrPs_  >soussema !27_V	et	f	\N
137947	sousse	?sousse =sousse  (ImpPrSg2  >soussema !27_V	et	f	\N
137957	soussest	?soussest =sousse  (SgEl  >sousne !02_A	et	f	\N
137958	soussest	?soussest =sousse  (SgEl  >souse !06_S	et	f	\N
137959	soussest	?soussest =sousses  (SgP  >sousses !09_S	et	f	\N
137960	soussest	?soussest =sousses  (SgP  >soussene !12~10_A	et	f	\N
137992	tuntuim	?tuntuim =tuntuim  (SgN  >tuntuim !02_A	et	f	\N
138006	argipäeva	argipäeva =päeva  (SgG  >argi+päev !22_S	et	f	\N
138007	argipäeva	argipäeva =päeva  (SgP  >argi+päev !22_S	et	f	\N
138008	argipäeva	argipäeva =päeva  (SgAdt  >argi+päev !22_S	et	f	\N
138036	väsitav	väsitav =väsi  (PtsPrIps  >väsima !27_V	et	f	\N
138037	väsitav	väsitav =väsita  (PtsPrPs  >väsitama !27_V	et	f	\N
138038	väsitav	väsitav =väsitav  (SgN  >väsitav !02_A	et	f	\N
138039	väsitav	"väsitav %väsi  )TAV_vAS  <väsima ;27_V	et	f	\N
138040	väsitav	"väsitav %väsita  )V_vA  <väsitama ;27_V	et	f	\N
138069	kapelli	kapelli =kapelli  (SgG  >kapell !22_S	et	f	\N
138070	kapelli	kapelli =kapelli  (SgP  >kapell !22_S	et	f	\N
138071	kapelli	kapelli =kapelli  (SgAdt  >kapell !22_S	et	f	\N
138078	roomas	roomas =rooma  (SgIn  >room !22_S	et	f	\N
138079	roomas	roomas =rooma  (IndIpfSg3  >roomama !29_V	et	f	\N
138081	vatikanis	?vatikanis =vatikani  (SgIn  >vatikan !19_S	et	f	\N
138082	vatikanis	?vatikanis =vatikanis  (SgN  >vatikanis !09_S	et	f	\N
138083	vatikanis	?vatikanis =kani  (SgIn  >vati+kani !17_S	et	f	\N
138084	vatikanis	?vatikanis =kanis  (SgN  >vati+kanis !09_S	et	f	\N
138085	kirikumessad	?kirikumessad =kirikumessa  (PlN  >kirikumessa !16_S	et	f	\N
138086	kirikumessad	?kirikumessad =messa  (PlN  >kiriku+messa !16_S	et	f	\N
137798	tervisekeskuses	tervisekeskuses =use  (PlIn  >tervise+kesk+usk !22_S	et	f	\N
137799	tervisekeskuses	tervisekeskuses =keskuse  (SgIn  >tervise+keskus !11~09_S	et	f	\N
137800	ujula	ujula =ujula  (SgN  >ujula !01_S	et	f	\N
137801	ujula	ujula =ujula  (SgG  >ujula !01_S	et	f	\N
137802	mullibasseinid	?mullibasseinid =mullibasseini  (PlN  >mullibasseini !16_S	et	f	\N
137803	mullibasseinid	?mullibasseinid =mullibasseini  (PlN  >mullibassein !19_S	et	f	\N
137804	mullibasseinid	?mullibasseinid =mullibasseini  (IndPrSg2  >mullibasseinima !28_V	et	f	\N
137814	ennesetunnet	### ennesetunnet	et	f	\N
137825	talus	talus =talu  (SgIn  >talu !17_S	et	f	\N
137826	talus	talus =talu  (IndIpfSg3  >taluma !27_V	et	f	\N
137863	sisustusega	sisustusega =sisustuse  (SgKom  >sisustus !11_S	et	f	\N
137864	sisustusega	"sisustus %sisusta  )US_vS  <sisustama ;27_V	et	f	\N
137878	reisides	reisides =reisi  (PlIn  >reis !22_S	et	f	\N
137879	reisides	reisides =reisi  (Ger  >reisima !28_V	et	f	\N
137885	salapärase	salapärase =pärase  (SgG  >sala+pärane !10_A	et	f	\N
137886	salapärase	"sala+pärane %pära  )NE_aA  <sala+pära ;17_S	et	f	\N
137908	suusatamiseks	suusatamiseks =suusatamise  (SgTr  >suusatamine !12_S	et	f	\N
137909	suusatamiseks	"suusatamine %suusata  )MINE_vS  <suusatama ;27_V	et	f	\N
137915	kauksis	?kauksis =kauksi  (SgIn  >kauks !22_S	et	f	\N
137916	kauksis	?kauksis =kauksi  (IndIpfSg3  >kauksima !28_V	et	f	\N
137917	kauksis	?kauksis =kauksis  (SgN  >kauksis !09_S	et	f	\N
137921	omapäraste	omapäraste =päras  (PlG  >oma+pärane !10_A	et	f	\N
137922	omapäraste	"oma+pärane %pära  )NE_aA  <oma+pära ;17_S	et	f	\N
137961	ujulasse	ujulasse =ujula  (SgIll  >ujula !01_S	et	f	\N
137962	ujulasse	ujulasse =ujulas  (SgAdt  >ujulane !12_S	et	f	\N
137963	ujulasse	"ujulane %ujula  )NE_aA  <ujula ;01_S	et	f	\N
137968	mediinat	?mediinat =mediina  (SgP  >mediina !16_S	et	f	\N
137970	mediinat	?mediinat =iina  (SgP  >med+iina !16_S	et	f	\N
137972	mediinat	?mediinat =iinat  (SgN  >med+iinat !02_S	et	f	\N
137982	kõrbesse	kõrbesse =kõrbe  (SgIll  >kõrb !02_S	et	f	\N
137983	kõrbesse	kõrbesse =kõrbe  (SgIll  >kõrve !06_S	et	f	\N
137984	kõrbesse	kõrbesse =kõrbes  (SgAdt  >kõrbene !12_A	et	f	\N
137985	kõrbesse	"kõrbene %kõrbe  )NE_aA  <kõrb ;02_S	et	f	\N
137986	kõrbesse	"kõrbene %kõrbe  )NE_aA  <kõrve ;06_S	et	f	\N
138015	aura	aura =aura  (SgN  >aura !16_S	et	f	\N
138016	aura	aura =aura  (SgG  >aura !16_S	et	f	\N
138017	aura	aura =aura  (IndPrPs_  >aurama !29_V	et	f	\N
138018	aura	aura =aura  (ImpPrSg2  >aurama !29_V	et	f	\N
138019	tuneesiasse	?tuneesiasse =tuneesia  (SgIll  >tuneesia !01_S	et	f	\N
138020	tuneesiasse	?tuneesiasse =tuneesias  (SgAdt  >tuneesias !11_S	et	f	\N
138021	tuneesiasse	?tuneesiasse =tuneesiasse  (SgG  >tuneesiasne !02_A	et	f	\N
138022	tuneesiasse	?tuneesiasse =tuneesiasse  (PlP  >tuneesiass !22_S	et	f	\N
138026	oksendasid	oksendasid =oksenda  (IndIpfSg2  >oksendama !27_V	et	f	\N
138027	oksendasid	oksendasid =oksenda  (IndIpfPl3  >oksendama !27_V	et	f	\N
138028	nutsid	nutsid =nut  (IndIpfSg2  >nutma !35_V	et	f	\N
138029	nutsid	nutsid =nut  (IndIpfPl3  >nutma !35_V	et	f	\N
138030	nutsid	nutsid =nutsi  (IndPrSg2  >nutsima !28_V	et	f	\N
138031	tasane	tasane =tasane  (SgN  >tasane !10_A	et	f	\N
138034	tasane	tasane =tasane  (IndPrPs_  >tasanema !27_V	et	f	\N
138035	tasane	tasane =tasane  (ImpPrSg2  >tasanema !27_V	et	f	\N
138041	peatusi	peatusi =peatusi  (PlP  >peatus !11_S	et	f	\N
138042	peatusi	"peatus %peata  )US_vS  <peatama ;27_V	et	f	\N
138043	peatusi	"peatus %pea  )TUS2_aS  <pea ;26_S	et	f	\N
138052	krotshi	?krotshi =krotshi  (SgN  >krotshi !01_S	et	f	\N
138053	krotshi	?krotshi =krotshi  (SgG  >krotshi !01_S	et	f	\N
138054	krotshi	?krotshi =krotshi  (SgG  >krotsh !22_S	et	f	\N
138055	krotshi	?krotshi =krotshi  (SgP  >krotsh !22_S	et	f	\N
138056	krotshi	?krotshi =krotshi  (SgAdt  >krotsh !22_S	et	f	\N
138057	krotshi	?krotshi =krotshi  (IndPrPs_  >krotshima !28_V	et	f	\N
138058	krotshi	?krotshi =krotshi  (ImpPrSg2  >krotshima !28_V	et	f	\N
138072	roomasse	roomasse =rooma  (SgIll  >room !22_S	et	f	\N
138073	roomasse	roomasse =masse  (PlP  >roo+mass !22_S	et	f	\N
138074	ioann	?ioann =ioann  (SgN  >ioann !22_S	et	f	\N
138094	viskasid	viskasid =viska  (IndIpfSg2  >viskama !29_V	et	f	\N
138095	viskasid	viskasid =viska  (IndIpfPl3  >viskama !29_V	et	f	\N
138099	veneetsias	?veneetsias =veneetsia  (SgIn  >veneetsia !01_S	et	f	\N
138100	veneetsias	?veneetsias =veneetsias  (SgN  >veneetsias !11_S	et	f	\N
138101	veneetsias	?veneetsias =etsia  (SgIn  >vene+etsia !01_S	et	f	\N
138102	veneetsias	?veneetsias =etsias  (SgN  >vene+etsias !11_S	et	f	\N
138107	maski	maski =maski  (SgG  >mask !22_S	et	f	\N
138109	maski	maski =maski  (SgP  >mask !22_S	et	f	\N
138112	maski	maski =maski  (SgAdt  >mask !22_S	et	f	\N
138128	holland	?holland =holland  (SgN  >holland !02_S	et	f	\N
138129	belgia	?belgia =belgia  (SgN  >belgia !01_S	et	f	\N
138130	belgia	?belgia =belgia  (SgG  >belgia !01_S	et	f	\N
138131	seikluseotsijad	?seikluseotsijad =seikluseotsija  (PlN  >seikluseotsija !01_S	et	f	\N
138132	seikluseotsijad	?seikluseotsijad =seikluseotsija  (PlN  >seikluseotsijas !02_A	et	f	\N
137824	telkida	telkida =ida  (SgP  >telk+ida !17_S	et	f	\N
137827	talutööd	talutööd =töö  (PlN  >talu+töö !26_S	et	f	\N
137828	talutööd	talutööd =töö  (SgP  >talu+töö !26_S	et	f	\N
137846	nädalavahetuse	nädalavahetuse =vahetuse  (SgG  >nädala+vahetus !11_S	et	f	\N
137848	nädalavahetuse	"nädala+vahetus %vahe  )TUS2_aS  <nädala+vahe ;16_S	et	f	\N
137858	loodusesse	loodusesse =looduse  (SgIll  >loodus !11~09_S	et	f	\N
137859	loodusesse	"loodus %loo  )TUS1_aS  <looma ;38_V	et	f	\N
137860	loodusesse	loodusesse =looduses  (SgAdt  >loodusene !12_A	et	f	\N
137861	loodusesse	"loodusene %looduse  )NE_aA  <loodus ;09_S	et	f	\N
137862	loodusesse	"loodusene %looduse  )NE_aA  <loodus ;11_S	et	f	\N
137867	pehme	pehme =pehme  (SgN  >pehme !01_A	et	f	\N
137868	pehme	pehme =pehme  (SgG  >pehme !01_A	et	f	\N
137880	tegelekult	?tegelekult =tegelekult  (ID  >tegelekult !41_D	et	f	\N
137906	kalastamiseks	kalastamiseks =kalastamise  (SgTr  >kalastamine !12_S	et	f	\N
137907	kalastamiseks	"kalastamine %kalasta  )MINE_vS  <kalastama ;27_V	et	f	\N
137910	eksootika	eksootika =eksootika  (SgN  >eksootika !01_S	et	f	\N
137911	eksootika	eksootika =eksootika  (SgG  >eksootika !01_S	et	f	\N
137925	aafrikasse	?aafrikasse =aafrika  (SgIll  >aafrika !01_S	et	f	\N
137926	aafrikasse	?aafrikasse =aafrika  (SgIll  >aafrikas !02_S	et	f	\N
137927	aafrikasse	?aafrikasse =aafrikas  (SgAdt  >aafrikane !12_A	et	f	\N
137928	aafrikasse	?aafrikasse =aafrikasse  (SgG  >aafrikasne !02_A	et	f	\N
137929	aafrikasse	?aafrikasse =aafrikasse  (PlP  >aafrikass !22_S	et	f	\N
137940	tuneesias	?tuneesias =tuneesia  (SgIn  >tuneesia !01_S	et	f	\N
137941	tuneesias	?tuneesias =tuneesias  (SgN  >tuneesias !11_S	et	f	\N
137949	päriselu	päriselu =elu  (SgN  >päris+elu !17_S	et	f	\N
137950	päriselu	päriselu =elu  (SgG  >päris+elu !17_S	et	f	\N
137951	päriselu	päriselu =elu  (SgP  >päris+elu !17_S	et	f	\N
137954	port	?port =port  (SgN  >port !22_S	et	f	\N
137967	mediina	?mediina =medii  (SgEs  >medii !26_S	et	f	\N
137969	mediina	?mediina =mediina  (SgN  >mediina !16_S	et	f	\N
137971	mediina	?mediina =mediina  (SgG  >mediina !16_S	et	f	\N
137973	mediina	?mediina =ii  (SgEs  >med+ii !26_S	et	f	\N
137974	mediina	?mediina =iina  (SgN  >med+iina !16_S	et	f	\N
137975	mediina	?mediina =iina  (SgG  >med+iina !16_S	et	f	\N
137977	päevale	päevale =päeva  (SgAll  >päev !22_S	et	f	\N
137978	päevale	päevale =ale  (SgN  >päev+ale !16_S	et	f	\N
137979	päevale	päevale =ale  (SgG  >päev+ale !16_S	et	f	\N
138011	vaatamisväärsuste	vaatamisväärsuste =väärsus  (PlG  >vaatamis+väärsus !11~09_S	et	f	\N
138012	vaatamisväärsuste	"vaatamis+väärsus %väärse  )US_aS  <vaatamis+väärne ;02_A	et	f	\N
138075	pavel	?pavel =pave  (SgAd  >pave !16_S	et	f	\N
138080	pavel	?pavel =pavel  (SgN  >pavel !02_S	et	f	\N
138120	taanilinnas	taanilinnas =linna  (SgIn  >taani+linn !22_S	et	f	\N
138121	taanilinnas	taanilinnas =linnas  (SgN  >taani+linnas !09_S	et	f	\N
138126	eralda	eralda =eralda  (IndPrPs_  >eraldama !27_V	et	f	\N
138127	eralda	eralda =eralda  (ImpPrSg2  >eraldama !27_V	et	f	\N
138149	disney	### disney	et	f	\N
138150	rahvatantsu	rahvatantsu =tantsu  (SgG  >rahva+tants !22_S	et	f	\N
138151	rahvatantsu	rahvatantsu =tantsu  (SgP  >rahva+tants !22_S	et	f	\N
138152	rahvatantsu	rahvatantsu =tantsu  (SgAdt  >rahva+tants !22_S	et	f	\N
138158	müüati	?müüati =müüati  (ID  >müüati !41_D	et	f	\N
138159	müüati	?müüati =müüati  (SgG  >müüat !02_S	et	f	\N
138160	merevaiku	merevaiku =vaiku  (SgP  >mere+vaik !22_S	et	f	\N
138161	merevaiku	merevaiku =vaiku  (SgAdt  >mere+vaik !22_S	et	f	\N
138167	puhanud	puhanud =puha  (PtsPtPs  >puhkama !29_V	et	f	\N
138168	puhanud	puhanud =puhanu  (PlN  >puhanu !01_S	et	f	\N
138169	puhanud	"puhanu %puha  )NU_vS  <puhkama ;29_V	et	f	\N
138170	puhanud	puhanud =puhanud  (ID  >puhanud !41_A	et	f	\N
138171	puhanud	"puhanud %puha  )NUD_vA  <puhkama ;29_V	et	f	\N
138211	hi-tech	?hi-tech =tech  (SgN  >hi-tech !22_S	et	f	\N
138224	sünnipäevale	sünnipäevale =ale  (SgN  >sünni+päev+ale !16_S	et	f	\N
138225	sünnipäevale	sünnipäevale =ale  (SgG  >sünni+päev+ale !16_S	et	f	\N
138226	sünnipäevale	sünnipäevale =päeva  (SgAll  >sünni+päev !22_S	et	f	\N
138231	jurmalas	?jurmalas =jurmala  (SgIn  >jurmala !01_S	et	f	\N
138253	kahekohalises	kahekohalises =kohalise  (SgIn  >kahe+kohaline !12_A	et	f	\N
138254	kahekohalises	"kahe+kohaline %koha  )LINE_aA  <kahe+koha ;17_S	et	f	\N
138255	kahekohalises	"kahe+kohaline %koha  )LINE_aA  <kahe+koht ;22_S	et	f	\N
138263	tantsuplatsi	tantsuplatsi =platsi  (SgG  >tantsu+plats !22_S	et	f	\N
138264	tantsuplatsi	tantsuplatsi =platsi  (SgP  >tantsu+plats !22_S	et	f	\N
138265	tantsuplatsi	tantsuplatsi =platsi  (SgAdt  >tantsu+plats !22_S	et	f	\N
138270	jurmalasse	?jurmalasse =jurmala  (SgIll  >jurmala !01_S	et	f	\N
138271	jurmalasse	?jurmalasse =jurmalas  (SgAdt  >jurmalane !12_S	et	f	\N
138272	jurmalasse	?jurmalasse =jurmalasse  (SgG  >jurmalasne !02_A	et	f	\N
138273	jurmalasse	?jurmalasse =jurmalasse  (PlP  >jurmalass !22_S	et	f	\N
138274	akvaparki	akvaparki =parki  (SgP  >akva+park !22_S	et	f	\N
138275	akvaparki	akvaparki =parki  (SgAdt  >akva+park !22_S	et	f	\N
138286	plakaadid	?plakaadid =plakaadi  (PlN  >plakaadi !16_S	et	f	\N
137870	dussiruum	?dussiruum =dussiruum  (SgN  >dussiruum !22_S	et	f	\N
137871	ööbimiseks	ööbimiseks =ööbimise  (SgTr  >ööbimine !12_S	et	f	\N
137872	ööbimiseks	"ööbimine %ööbi  )MINE_vS  <ööbima ;27_V	et	f	\N
137881	teadmatus	teadmatus =teadmatu  (SgIn  >teadmatu !01_A	et	f	\N
137882	teadmatus	"teadmatu %tead  )MATU_vA  <teadma ;34_V	et	f	\N
137883	teadmatus	teadmatus =teadmatus  (SgN  >teadmatus !11_S	et	f	\N
137884	teadmatus	"teadmatus %tead  )MATUS_aS  <teadma ;34_V	et	f	\N
137893	suurepäraseid	suurepäraseid =pärase  (PlP  >suure+pärane !10_A	et	f	\N
137894	suurepäraseid	"suure+pärane %pära  )NE_aA  <suure+pära ;17_S	et	f	\N
137899	ratsutamiseks	ratsutamiseks =ratsutamise  (SgTr  >ratsutamine !12_S	et	f	\N
137900	ratsutamiseks	"ratsutamine %ratsuta  )MINE_vS  <ratsutama ;27_V	et	f	\N
137903	tekkimiseks	tekkimiseks =tekkimise  (SgTr  >tekkimine !12_S	et	f	\N
137904	tekkimiseks	"tekkimine %tekki  )MINE_vS  <tekkima ;27_V	et	f	\N
137905	tekkimiseks	"tekkimine %tekki  )MINE_vS  <tekkima ;28_V	et	f	\N
137918	hotelli	hotelli =hotelli  (SgG  >hotell !22_S	et	f	\N
137919	hotelli	hotelli =hotelli  (SgP  >hotell !22_S	et	f	\N
137920	hotelli	hotelli =hotelli  (SgAdt  >hotell !22_S	et	f	\N
137948	palace	### palace	et	f	\N
137952	sahaaras	?sahaaras =sahaara  (SgIn  >sahaara !16_S	et	f	\N
137976	saharas	?saharas =sahara  (SgIn  >sahara !01_S	et	f	\N
137987	tuneesia	?tuneesia =tuneesia  (SgN  >tuneesia !01_S	et	f	\N
137988	tuneesia	?tuneesia =tuneesia  (SgG  >tuneesia !01_S	et	f	\N
137990	pjeridi	?pjeridi =pjeridi  (SgN  >pjeridi !01_S	et	f	\N
137991	pjeridi	?pjeridi =pjeridi  (SgG  >pjeridi !01_S	et	f	\N
137993	tuneesiast	?tuneesiast =tuneesia  (SgEl  >tuneesia !01_S	et	f	\N
137994	tuneesiast	?tuneesiast =tuneesias  (SgP  >tuneesias !11_S	et	f	\N
138000	halli	halli =halli  (SgG  >hall !22_S	et	f	\N
138001	halli	halli =halli  (SgG  >hall !22_AS	et	f	\N
138002	halli	halli =halli  (SgP  >hall !22_S	et	f	\N
138003	halli	halli =halli  (SgP  >hall !22_AS	et	f	\N
138004	halli	halli =halli  (SgAdt  >hall !22_S	et	f	\N
138005	halli	halli =halli  (SgAdt  >hall !22_AS	et	f	\N
138009	jume	jume =jume  (SgN  >jume !16_S	et	f	\N
138010	jume	jume =jume  (SgG  >jume !16_S	et	f	\N
138023	praamiga	praamiga =praami  (SgKom  >praam !22_S	et	f	\N
138024	praamiga	praamiga =iga  (SgN  >praam+iga !18_S	et	f	\N
138025	praamiga	praamiga =iga  (SgP  >praam+iga !18_S	et	f	\N
138032	rõõmustusid	rõõmustusid =rõõmustu  (IndIpfSg2  >rõõmustuma !27_V	et	f	\N
138033	rõõmustusid	rõõmustusid =rõõmustu  (IndIpfPl3  >rõõmustuma !27_V	et	f	\N
138046	leedus	leedus =leedu  (SgIn  >leedu !16_S	et	f	\N
138047	leedus	"leedu %lee  )TU1_vS  <leema ;37_V	et	f	\N
138048	leedus	leedus =leedus  (SgN  >leedus !11~09_S	et	f	\N
138049	leedus	"leedus %lee  )TUS1_aS  <leema ;37_V	et	f	\N
138050	florentsias	?florentsias =florentsia  (SgIn  >florentsia !01_S	et	f	\N
138051	florentsias	?florentsias =florentsias  (SgN  >florentsias !11_S	et	f	\N
138059	medichi	?medichi =medichi  (SgN  >medichi !01_S	et	f	\N
138060	medichi	?medichi =medichi  (SgG  >medichi !01_S	et	f	\N
138061	medichi	?medichi =medichi  (SgG  >medich !22_S	et	f	\N
138062	medichi	?medichi =medichi  (SgP  >medich !22_S	et	f	\N
138063	medichi	?medichi =medichi  (SgAdt  >medich !22_S	et	f	\N
138064	medichi	?medichi =ichi  (SgN  >med+ichi !16_S	et	f	\N
138065	medichi	?medichi =ichi  (SgG  >med+ichi !16_S	et	f	\N
138066	medichi	?medichi =ichi  (SgG  >med+ich !22_S	et	f	\N
138067	medichi	?medichi =ichi  (SgP  >med+ich !22_S	et	f	\N
138068	medichi	?medichi =ichi  (SgAdt  >med+ich !22_S	et	f	\N
138076	sünnipaev	?sünnipaev =sünnipaev  (SgN  >sünnipaev !22_S	et	f	\N
138077	sünnipaev	?sünnipaev =paev  (SgN  >sünni+paev !22_S	et	f	\N
138137	eifeli	?eifeli =eifeli  (ID  >eifeli !41_D	et	f	\N
138138	eifeli	?eifeli =eifeli  (SgG  >eifel !02_S	et	f	\N
138139	eifeli	?eifeli =feli  (SgN  >ei+feli !17_S	et	f	\N
138140	eifeli	?eifeli =feli  (SgG  >ei+feli !17_S	et	f	\N
138141	eifeli	?eifeli =feli  (SgP  >ei+feli !17_S	et	f	\N
138164	show	### show	et	f	\N
138176	natsiooni	natsiooni =natsiooni  (SgG  >natsioon !22_S	et	f	\N
138177	natsiooni	natsiooni =natsiooni  (SgP  >natsioon !22_S	et	f	\N
138178	natsiooni	natsiooni =natsiooni  (SgAdt  >natsioon !22_S	et	f	\N
138179	natsiooni	natsiooni =iooni  (SgG  >nats+ioon !22_S	et	f	\N
138180	natsiooni	natsiooni =iooni  (SgP  >nats+ioon !22_S	et	f	\N
138181	natsiooni	natsiooni =iooni  (SgAdt  >nats+ioon !22_S	et	f	\N
138182	helsinkis	?helsinkis =helsinki  (IndIpfSg3  >helsinkima !28_V	et	f	\N
138183	helsinkis	?helsinkis =helsinkis  (SgN  >helsinkis !11_S	et	f	\N
138184	loomaaijad	?loomaaijad =loomaaija  (PlN  >loomaaija !01_S	et	f	\N
138185	loomaaijad	?loomaaijad =loomaaija  (PlN  >loomaaijas !02_A	et	f	\N
138186	loomaaijad	?loomaaijad =ija  (PlN  >loo+maa+ija !17_S	et	f	\N
138187	loomaaijad	?loomaaijad =aija  (PlN  >looma+aija !01_S	et	f	\N
138188	loomaaijad	?loomaaijad =aaija  (PlN  >loom+aaija !01_S	et	f	\N
138189	loomaaijad	?loomaaijad =aaija  (PlN  >loom+aaijas !02_A	et	f	\N
138190	loomaaijad	?loomaaijad =maaija  (PlN  >loo+maaija !01_S	et	f	\N
137934	iseeladseid	?iseeladseid =iseeladse  (PlP  >iseeladne !02_A	et	f	\N
137935	iseeladseid	?iseeladseid =iseeladsei  (PlN  >iseeladsei !26_S	et	f	\N
137936	iseeladseid	?iseeladseid =iseeladsei  (SgP  >iseeladsei !26_S	et	f	\N
137937	iseeladseid	?iseeladseid =eladse  (PlP  >ise+eladne !02_A	et	f	\N
137938	iseeladseid	?iseeladseid =eladsei  (PlN  >ise+eladsei !26_S	et	f	\N
137939	iseeladseid	?iseeladseid =eladsei  (SgP  >ise+eladsei !26_S	et	f	\N
137953	mediinas	?mediinas =mediina  (SgIn  >mediina !16_S	et	f	\N
137955	mediinas	?mediinas =iina  (SgIn  >med+iina !16_S	et	f	\N
137956	mediinas	?mediinas =iinas  (SgN  >med+iinas !07_S	et	f	\N
137964	sadamasse	sadamasse =sadama  (SgIll  >sadam !02_S	et	f	\N
137965	sadamasse	sadamasse =sadamas  (SgAdt  >sadamane !12_A	et	f	\N
137966	sadamasse	"sadamane %sadama  )NE_aA  <sadam ;02_S	et	f	\N
137980	sahara	?sahara =sahara  (SgN  >sahara !01_S	et	f	\N
137981	sahara	?sahara =sahara  (SgG  >sahara !01_S	et	f	\N
137989	chott	?chott =chott  (SgN  >chott !22_S	et	f	\N
137995	hingesooiendavat	?hingesooiendavat =hingesooienda  (KvtPrPs  >hingesooiendama !27_V	et	f	\N
137996	hingesooiendavat	?hingesooiendavat =hingesooiendava  (SgP  >hingesooiendav !02_A	et	f	\N
137997	hingesooiendavat	?hingesooiendavat =hingesooiendava  (SgP  >hingesooiendava !16_S	et	f	\N
137998	hingesooiendavat	?hingesooiendavat =sooiendava  (SgP  >hinge+sooiendav !02_A	et	f	\N
137999	hingesooiendavat	?hingesooiendavat =sooiendava  (SgP  >hinge+sooiendava !16_S	et	f	\N
138013	külastamisest	külastamisest =külastamise  (SgEl  >külastamine !12_S	et	f	\N
138014	külastamisest	"külastamine %külasta  )MINE_vS  <külastama ;27_V	et	f	\N
138044	poolas	?poolas =poola  (IndIpfSg3  >poolama !29_V	et	f	\N
138045	poolas	?poolas =poolas  (SgN  >poolas !07_S	et	f	\N
138096	münti	münti =münti  (SgP  >münt !22_S	et	f	\N
138097	münti	münti =münti  (SgAdt  >münt !22_S	et	f	\N
138098	navona	?navona =navo  (SgEs  >navo !17~16_S	et	f	\N
138122	reisimisest	reisimisest =reisimise  (SgEl  >reisimine !12_S	et	f	\N
138123	reisimisest	"reisimine %reisi  )MINE_vS  <reisima ;28_V	et	f	\N
138124	riikis	?riikis =riiki  (IndIpfSg3  >riikima !28_V	et	f	\N
138125	riikis	?riikis =riikis  (SgN  >riikis !11~09_S	et	f	\N
138155	unesko	?unesko =unesko  (SgN  >unesko !16_S	et	f	\N
138156	unesko	?unesko =unesko  (SgG  >unesko !16_S	et	f	\N
138157	ukrainast	?ukrainast =ukrainas  (SgP  >ukrainane !12_A	et	f	\N
138165	tuline	tuline =tuline  (SgN  >tuline !10_A	et	f	\N
138166	tuline	"tuline %tuli  )NE_aA  <tuli ;20_S	et	f	\N
138172	positiivsust	positiivsust =positiivsus  (SgP  >positiivsus !11~09_S	et	f	\N
138173	positiivsust	"positiivsus %positiivse  )US_aS  <positiivne ;02_A	et	f	\N
138174	araablastega	araablastega =araablas  (PlKom  >araablane !12?10_S	et	f	\N
138175	araablastega	araablastega =ablas  (PlKom  >ara+ablas !07_A	et	f	\N
138203	italias	?italias =italia  (SgIn  >italia !01_S	et	f	\N
138204	italias	?italias =italias  (SgN  >italias !11_S	et	f	\N
138205	italia	?italia =italia  (SgN  >italia !01_S	et	f	\N
138206	italia	?italia =italia  (SgG  >italia !01_S	et	f	\N
138223	moe-show	### moe-show	et	f	\N
138234	ledos	?ledos =ledo  (SgIn  >ledo !17~16_S	et	f	\N
138235	ledos	?ledos =ledos  (SgN  >ledos !11~09_S	et	f	\N
138239	rolluisutama	?rolluisutama =rolluisu  (SupIps  >rolluisuma !27_V	et	f	\N
138240	rolluisutama	?rolluisutama =rolluisuta  (Sup  >rolluisutama !27_V	et	f	\N
138241	rolluisutama	?rolluisutama =rolluisutama  (SgG  >rolluisutam !02_A	et	f	\N
138242	rolluisutama	?rolluisutama =tama  (SgN  >roll+uisu+tama !17_S	et	f	\N
138243	rolluisutama	?rolluisutama =tama  (SgG  >roll+uisu+tama !17_S	et	f	\N
138244	rolluisutama	?rolluisutama =tama  (SgP  >roll+uisu+tama !17_S	et	f	\N
138245	rolluisutama	?rolluisutama =uisutama  (SgG  >roll+uisutam !02_A	et	f	\N
138249	hostellis	?hostellis =hostelli  (SgIn  >hostelli !01_S	et	f	\N
138250	hostellis	?hostellis =hostelli  (SgIn  >hostell !22_S	et	f	\N
138251	hostellis	?hostellis =hostelli  (IndIpfSg3  >hostellima !28_V	et	f	\N
138252	hostellis	?hostellis =hostellis  (SgN  >hostellis !11_S	et	f	\N
138256	jäätsime	?jäätsime =jäät  (IndIpfPl1  >jäätma !34_V	et	f	\N
138257	jäätsime	?jäätsime =jäätsi  (IndPrPl1  >jäätsima !28_V	et	f	\N
138258	jäätsime	?jäätsime =tsime  (SgN  >jää+tsime !16_S	et	f	\N
138259	jäätsime	?jäätsime =tsime  (SgG  >jää+tsime !16_S	et	f	\N
138260	larocca	?larocca =larocca  (SgN  >larocca !01_S	et	f	\N
138261	larocca	?larocca =larocca  (SgG  >larocca !01_S	et	f	\N
138285	magniitid	?magniitid =magniiti  (PlN  >magniiti !16_S	et	f	\N
138293	kaunimad	kaunimad =kaunima  (PlN  >kaunim !02_A	et	f	\N
138294	kaunimad	"kaunim %kauni  )M_cA  <kaunis ;05_A	et	f	\N
138295	kaunimad	"kaunim %kauni  )M_cA  <kaunis ;07_A	et	f	\N
138312	vanalinna	vanalinna =linna  (SgG  >vana+linn !22_S	et	f	\N
138313	vanalinna	vanalinna =linna  (SgP  >vana+linn !22_S	et	f	\N
138314	vanalinna	vanalinna =linna  (SgAdt  >vana+linn !22_S	et	f	\N
138315	tänavaid	tänavaid =tänava  (PlP  >tänav !02_A	et	f	\N
138316	tänavaid	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
138317	tänavaid	tänavaid =tänava  (PlP  >tänav !02_S	et	f	\N
138320	võimatuid	võimatuid =võimatu  (PlP  >võimatu !01_A	et	f	\N
138321	võimatuid	"võimatu %või  )MATU_vA  <võima ;37_V	et	f	\N
138087	kirikumessad	?kirikumessad =umessa  (PlN  >kirik+umessa !01_S	et	f	\N
138088	kirikumessad	?kirikumessad =kumessa  (PlN  >kiri+kumessa !01_S	et	f	\N
138089	trevi	?trevi =trevi  (SgN  >trevi !17_S	et	f	\N
138090	trevi	?trevi =trevi  (SgG  >trevi !17_S	et	f	\N
138091	trevi	?trevi =trevi  (SgP  >trevi !17_S	et	f	\N
138092	trevi	?trevi =trevi  (IndPrPs_  >trevima !27_V	et	f	\N
138093	trevi	?trevi =trevi  (ImpPrSg2  >trevima !27_V	et	f	\N
138103	veneetsiani	?veneetsiani =veneetsia  (SgTer  >veneetsia !01_S	et	f	\N
138104	veneetsiani	?veneetsiani =veneetsiani  (SgN  >veneetsiani !16_S	et	f	\N
138105	veneetsiani	?veneetsiani =veneetsiani  (SgG  >veneetsian !19~02_S	et	f	\N
138106	veneetsiani	?veneetsiani =veneetsiani  (SgG  >veneetsiani !16_S	et	f	\N
138108	veneetsiani	?veneetsiani =veneetsiani  (SgP  >veneetsian !19_S	et	f	\N
138110	veneetsiani	?veneetsiani =veneetsiani  (SgAdt  >veneetsian !19_S	et	f	\N
138111	veneetsiani	?veneetsiani =veneetsiani  (IndPrPs_  >veneetsianima !28_V	et	f	\N
138113	veneetsiani	?veneetsiani =veneetsiani  (ImpPrSg2  >veneetsianima !28_V	et	f	\N
138114	veneetsiani	?veneetsiani =etsia  (SgTer  >vene+etsia !01_S	et	f	\N
138115	veneetsiani	?veneetsiani =etsiani  (SgN  >vene+etsiani !16_S	et	f	\N
138116	veneetsiani	?veneetsiani =etsiani  (SgG  >vene+etsian !19~02_S	et	f	\N
138117	veneetsiani	?veneetsiani =etsiani  (SgG  >vene+etsiani !16_S	et	f	\N
138118	veneetsiani	?veneetsiani =etsiani  (SgP  >vene+etsian !19_S	et	f	\N
138119	veneetsiani	?veneetsiani =etsiani  (SgAdt  >vene+etsian !19_S	et	f	\N
138135	kestas	kestas =kesta  (SgIn  >kest !22_S	et	f	\N
138136	kestas	kestas =kesta  (IndIpfSg3  >kestama !29_V	et	f	\N
138142	luvri	?luvri =luvri  (SgN  >luvri !16_S	et	f	\N
138143	luvri	?luvri =luvri  (SgG  >luvri !16_S	et	f	\N
138144	luvri	?luvri =luvri  (SgG  >luvr !22_S	et	f	\N
138145	luvri	?luvri =luvri  (SgP  >luvr !22_S	et	f	\N
138146	luvri	?luvri =luvri  (SgAdt  >luvr !22_S	et	f	\N
138147	luvri	?luvri =luvri  (IndPrPs_  >luvrima !28_V	et	f	\N
138148	luvri	?luvri =luvri  (ImpPrSg2  >luvrima !28_V	et	f	\N
138162	osalemise	osalemise =osalemise  (SgG  >osalemine !12_S	et	f	\N
138163	osalemise	"osalemine %osale  )MINE_vS  <osalema ;27_V	et	f	\N
138192	looduslikus	looduslikus =loodusliku  (SgIn  >looduslik !25_A	et	f	\N
138193	looduslikus	looduslikus =looduslikus  (SgN  >looduslikus !11?09_S	et	f	\N
138194	looduslikus	"looduslikus %loodusliku  )US_aS  <looduslik ;25_A	et	f	\N
138222	italiased	### italiased	et	f	\N
138289	õluklaasid	?õluklaasid =õluklaa  (PlP  >õluklaa !26_S	et	f	\N
138290	õluklaasid	?õluklaasid =õluklaasi  (PlN  >õluklaasi !16_S	et	f	\N
138291	õluklaasid	?õluklaasid =õluklaasi  (PlN  >õluklaas !22_S	et	f	\N
138292	õluklaasid	?õluklaasid =õluklaasi  (IndPrSg2  >õluklaasima !28_V	et	f	\N
138301	juga	juga =juga  (SgN  >juga !18_S	et	f	\N
138302	juga	juga =juga  (SgP  >juga !18_S	et	f	\N
138333	tarbijale	tarbijale =tarbija  (SgAll  >tarbija !01_S	et	f	\N
138334	tarbijale	"tarbija %tarbi  )JA_vS  <tarbima ;27_V	et	f	\N
138354	sellstest	?sellstest =sellste  (SgEl  >sellste !06_S	et	f	\N
138355	sellstest	?sellstest =sellste  (PlEl  >sellst !22_S	et	f	\N
138356	sellstest	?sellstest =sellstes  (SgP  >sellstes !09_S	et	f	\N
138357	sellstest	?sellstest =sellstes  (SgP  >sellstene !12~10_A	et	f	\N
138359	tuntum	tuntum =tuntum  (SgN  >tuntum !02_A	et	f	\N
138360	tuntum	"tuntum %tun  )TUM1_cA  <tundma ;34_V	et	f	\N
138390	tokyo	?tokyo =tokyo  (SgN  >tokyo !26_S	et	f	\N
138391	tokyo	?tokyo =tokyo  (SgG  >tokyo !26_S	et	f	\N
138407	raekoda	raekoda =koda  (SgN  >rae+koda !18_S	et	f	\N
138408	raekoda	raekoda =koda  (SgP  >rae+koda !18_S	et	f	\N
138476	periodil	?periodil =periodi  (SgAd  >periodi !16_S	et	f	\N
138477	periodil	?periodil =periodi  (SgAd  >periot !22_S	et	f	\N
138478	periodil	?periodil =periodil  (SgN  >periodil !02_S	et	f	\N
138506	martin	?martin =martin  (SgN  >martin !02_S	et	f	\N
138522	reliikvia	reliikvia =reliikvia  (SgN  >reliikvia !01_S	et	f	\N
138523	reliikvia	reliikvia =reliikvia  (SgG  >reliikvia !01_S	et	f	\N
138539	rängmunbadena	### rängmunbadena	et	f	\N
138542	beginid	?beginid =begini  (PlN  >begin !02_S	et	f	\N
138568	tutvusid	tutvusid =tutvu  (IndIpfSg2  >tutvuma !27_V	et	f	\N
138569	tutvusid	tutvusid =tutvu  (IndIpfPl3  >tutvuma !27_V	et	f	\N
138583	tööriistaks	tööriistaks =taks  (SgN  >töö+riis+taks !22_S	et	f	\N
138584	tööriistaks	tööriistaks =riista  (SgTr  >töö+riist !22_S	et	f	\N
138589	pidamist	pidamist =pidamis  (SgP  >pidamine !12_S	et	f	\N
138592	pidamist	"pidamine %pida  )MINE_vS  <pidama ;28_V	et	f	\N
138593	põletamist	põletamist =põletamis  (SgP  >põletamine !12_S	et	f	\N
138594	põletamist	"põletamine %põleta  )MINE_vS  <põletama ;27_V	et	f	\N
138635	märatles	?märatles =märatle  (IndIpfSg3  >märatlema !27_V	et	f	\N
138636	sihe	?sihe =sihe  (SgN  >sihe !16_S	et	f	\N
138637	sihe	?sihe =sihe  (SgG  >sihe !16_S	et	f	\N
138638	sihe	?sihe =sihe  (IndPrPs_  >sihema !27_V	et	f	\N
138639	sihe	?sihe =sihe  (ImpPrSg2  >sihema !27_V	et	f	\N
138643	vaimuvara	vaimuvara =vara  (SgN  >vaimu+vara !17_S	et	f	\N
138644	vaimuvara	vaimuvara =vara  (SgG  >vaimu+vara !17_S	et	f	\N
138133	seikluseotsijad	?seikluseotsijad =eotsija  (PlN  >seiklus+eotsija !01_S	et	f	\N
138134	seikluseotsijad	?seikluseotsijad =eotsija  (PlN  >seiklus+eotsijas !02_A	et	f	\N
138153	kuhugile	?kuhugile =gile  (SgN  >kuhu+gile !16_S	et	f	\N
138154	kuhugile	?kuhugile =gile  (SgG  >kuhu+gile !16_S	et	f	\N
138197	summa	summa =summa  (SgN  >summa !16_S	et	f	\N
138198	summa	summa =summa  (SgG  >summa !16_S	et	f	\N
138199	summa	summa =summa  (SgG  >summ !22_S	et	f	\N
138200	summa	summa =summa  (SgG  >sumb !22_S	et	f	\N
138201	summa	summa =summa  (SgP  >summ !22_S	et	f	\N
138202	summa	summa =summa  (SgAdt  >summ !22_S	et	f	\N
138227	lätisse	?lätisse =läti  (SgIll  >läti !16_S	et	f	\N
138228	lätisse	?lätisse =läti  (SgIll  >lätt !22_S	et	f	\N
138229	lätisse	?lätisse =lätisse  (SgG  >lätisne !02_A	et	f	\N
138230	lätisse	?lätisse =lätisse  (PlP  >lätiss !22_S	et	f	\N
138266	rnb	### rnb	et	f	\N
138267	trance	?trance =trance  (SgN  >trance !06_S	et	f	\N
138268	trance	?trance =trance  (SgG  >trance !06_S	et	f	\N
138269	trance	?trance =trance  (PlP  >tranc !22_S	et	f	\N
138276	baltikas	?baltikas =baltika  (SgIn  >baltika !01_S	et	f	\N
138277	baltikas	?baltikas =baltika  (SgIn  >baltikas !02_S	et	f	\N
138278	baltikas	?baltikas =baltikas  (SgN  >baltikas !02_S	et	f	\N
138279	baltikas	?baltikas =ika  (SgIn  >balt+ika !16_S	et	f	\N
138280	baltikas	?baltikas =ikas  (SgN  >balt+ikas !07_S	et	f	\N
138281	alkoholtsed	?alkoholtsed =alkoholtse  (PlN  >alkoholtne !02_A	et	f	\N
138282	alkoholtsed	?alkoholtsed =alkoholtse  (IndPrSg2  >alkoholtsema !27_V	et	f	\N
138283	alkoholtsed	?alkoholtsed =holtse  (PlN  >alko+holtne !02_A	et	f	\N
138284	alkoholtsed	?alkoholtsed =holtse  (PlN  >alko+holtse !06_S	et	f	\N
138345	tahabgi	?tahabgi =tahabgi  (SgN  >tahabgi !01_S	et	f	\N
138346	tahabgi	?tahabgi =tahabgi  (SgG  >tahabgi !01_S	et	f	\N
138347	tahabgi	?tahabgi =tahabgi  (SgG  >tahabg !02_S	et	f	\N
138348	tahabgi	?tahabgi =tahabgi  (IndPrPs_  >tahabgima !28_V	et	f	\N
138349	tahabgi	?tahabgi =tahabgi  (ImpPrSg2  >tahabgima !28_V	et	f	\N
138363	tuntuvad	?tuntuvad =tuntu  (IndPrPl3  >tuntuma !27_V	et	f	\N
138364	tuntuvad	?tuntuvad =tuntuva  (PlN  >tuntuva !01_S	et	f	\N
138365	tuntuvad	?tuntuvad =tuntuva  (PlN  >tuntuv !02_A	et	f	\N
138375	rakishi	?rakishi =rakishi  (SgN  >rakishi !01_S	et	f	\N
138376	rakishi	?rakishi =rakishi  (SgG  >rakishi !01_S	et	f	\N
138377	rakishi	?rakishi =rakishi  (SgG  >rakish !22_S	et	f	\N
138378	rakishi	?rakishi =rakishi  (SgP  >rakish !22_S	et	f	\N
138379	rakishi	?rakishi =rakishi  (SgAdt  >rakish !22_S	et	f	\N
138380	rakishi	?rakishi =rakishi  (IndPrPs_  >rakishima !28_V	et	f	\N
138381	rakishi	?rakishi =rakishi  (ImpPrSg2  >rakishima !28_V	et	f	\N
138387	astaat	?astaat =astaat  (SgN  >astaat !22_S	et	f	\N
138392	japaanamaal	?japaanamaal =japaanamaa  (SgAd  >japaanamaa !26_S	et	f	\N
138393	japaanamaal	?japaanamaal =japaanamaal  (SgN  >japaanamaal !22_S	et	f	\N
138394	yokozuna	?yokozuna =yokozu  (SgEs  >yokozu !01_S	et	f	\N
138397	omasid	omasid =oma  (PlP  >oma !17_A	et	f	\N
138398	omasid	omasid =oma  (IndIpfSg2  >omama !27_V	et	f	\N
138399	omasid	omasid =oma  (IndIpfPl3  >omama !27_V	et	f	\N
138400	õigust	õigust =õigus  (SgP  >õigus !11~09_S	et	f	\N
138401	õigust	"õigus %õige  )US_aS  <õige ;01_A	et	f	\N
138402	vina	vina =vina  (SgN  >vina !17_S	et	f	\N
138403	vina	vina =vina  (SgG  >vina !17_S	et	f	\N
138404	vina	vina =vina  (SgP  >vina !17_S	et	f	\N
138405	vina	vina =vina  (IndPrPs_  >vinama !27_V	et	f	\N
138406	vina	vina =vina  (ImpPrSg2  >vinama !27_V	et	f	\N
138418	toomekirikute	toomekirikute =ute  (SgG  >toome+kirik+utt !22_S	et	f	\N
138419	toomekirikute	toomekirikute =kiriku  (PlG  >toome+kirik !02_S	et	f	\N
138422	kapiituli	?kapiituli =ituli  (SgG  >kapi+itul !02_S	et	f	\N
138423	toomehäärana	?toomehäärana =toomehäära  (SgEs  >toomehäära !16_S	et	f	\N
138424	toomehäärana	?toomehäärana =häära  (SgEs  >toome+häära !16_S	et	f	\N
138425	toomehäärana	?toomehäärana =ehäära  (SgEs  >toom+ehäära !16_S	et	f	\N
138426	toomehäärana	?toomehäärana =mehäära  (SgEs  >too+mehäära !16_S	et	f	\N
138439	käsitöölistel	käsitöölistel =iste  (SgAd  >käsi+tööl+iste !06_S	et	f	\N
138440	käsitöölistel	käsitöölistel =iste  (PlAd  >käsi+tööl+ist !22_S	et	f	\N
138441	käsitöölistel	käsitöölistel =töölis  (PlAd  >käsi+tööline !12?10_S	et	f	\N
138442	käsitööline	käsitööline =ine  (SgN  >käsi+tööl+ine !16_S	et	f	\N
138443	käsitööline	käsitööline =ine  (SgG  >käsi+tööl+ine !16_S	et	f	\N
138444	käsitööline	käsitööline =tööline  (SgN  >käsi+tööline !12?10_S	et	f	\N
138447	täuslikult	?täuslikult =täusliku  (SgAbl  >täuslik !25_A	et	f	\N
138448	täuslikult	?täuslikult =täusliku  (SgAbl  >täusliku !01_S	et	f	\N
138449	täuslikult	?täuslikult =täuslikult  (ID  >täuslikult !41_D	et	f	\N
138450	kasulikus	kasulikus =kasuliku  (SgIn  >kasulik !25_A	et	f	\N
138451	kasulikus	kasulikus =kasulikus  (SgN  >kasulikus !11?09_S	et	f	\N
138452	kasulikus	"kasulikus %kasuliku  )US_aS  <kasulik ;25_A	et	f	\N
138457	pernkt	?pernkt =pernkt  (SgN  >pernkt !22_S	et	f	\N
138463	russov	?russov =russov  (SgN  >russov !02_A	et	f	\N
138191	loomaaijad	?loomaaijad =maaija  (PlN  >loo+maaijas !02_A	et	f	\N
138195	parimatest	parimatest =parima  (PlEl  >parim !02_A	et	f	\N
138196	parimatest	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
138207	modne	?modne =modne  (SgN  >modne !02_A	et	f	\N
138208	modne	?modne =modne  (PlP  >modn !22_S	et	f	\N
138209	modne	?modne =modne  (IndPrPs_  >modnema !27_V	et	f	\N
138210	modne	?modne =modne  (ImpPrSg2  >modnema !27_V	et	f	\N
138212	sisseinterjeeris	?sisseinterjeeris =sisseinterjeeri  (SgIn  >sisseinterjeeri !16_S	et	f	\N
138213	sisseinterjeeris	?sisseinterjeeris =sisseinterjeeri  (SgIn  >sisseinterjeer !22_S	et	f	\N
138214	sisseinterjeeris	?sisseinterjeeris =sisseinterjeeri  (IndIpfSg3  >sisseinterjeerima !28_V	et	f	\N
138215	sisseinterjeeris	?sisseinterjeeris =sisseinterjeeris  (SgN  >sisseinterjeeris !09_S	et	f	\N
138216	sisseinterjeeris	?sisseinterjeeris =jeeri  (SgIn  >sisse+inter+jeeri !16_S	et	f	\N
138217	sisseinterjeeris	?sisseinterjeeris =jeeri  (SgIn  >sisse+inter+jeer !22_S	et	f	\N
138218	sisseinterjeeris	?sisseinterjeeris =jeeris  (SgN  >sisse+inter+jeeris !09_S	et	f	\N
138219	sisseinterjeeris	?sisseinterjeeris =interjeeri  (SgIn  >sisse+interjeeri !16_S	et	f	\N
138220	sisseinterjeeris	?sisseinterjeeris =interjeeri  (SgIn  >sisse+interjeer !22_S	et	f	\N
138221	sisseinterjeeris	?sisseinterjeeris =interjeeris  (SgN  >sisse+interjeeris !09_S	et	f	\N
138232	päival	?päival =päiva  (SgAd  >päiva !16_S	et	f	\N
138233	päival	?päival =päival  (SgN  >päival !02_S	et	f	\N
138236	meelerõõmu	meelerõõmu =rõõmu  (SgG  >meele+rõõm !22_S	et	f	\N
138237	meelerõõmu	meelerõõmu =rõõmu  (SgP  >meele+rõõm !22_S	et	f	\N
138238	meelerõõmu	meelerõõmu =rõõmu  (SgAdt  >meele+rõõm !22_S	et	f	\N
138246	peatusime	peatusime =peatu  (IndIpfPl1  >peatuma !27_V	et	f	\N
138247	peatusime	peatusime =ime  (SgN  >peatus+ime !16_S	et	f	\N
138248	peatusime	peatusime =ime  (SgG  >peatus+ime !16_S	et	f	\N
138262	klub	### klub	et	f	\N
138296	linnule	linnule =linnu  (SgAll  >lind !22_S	et	f	\N
138297	linnule	linnule =linnu  (PlAll  >linn !22_S	et	f	\N
138303	allee	allee =allee  (SgN  >allee !26_S	et	f	\N
138304	allee	allee =allee  (SgG  >allee !26_S	et	f	\N
138318	ekskursile	ekskursile =ekskursi  (SgAll  >ekskurss !22_S	et	f	\N
138319	ekskursile	ekskursile =kursi  (SgAll  >eks+kurss !22_S	et	f	\N
138329	sellisest	sellisest =sellise  (SgEl  >selline !10_P	et	f	\N
138330	sellisest	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
138338	tootest	tootest =toote  (SgEl  >toode !06_S	et	f	\N
138339	tootest	tootest =tootes  (SgP  >tootene !12~10_A	et	f	\N
138340	tootest	"tootene %toote  )NE_aA  <toode ;06_S	et	f	\N
138341	tootest	tootest =test  (SgN  >too+test !22_S	et	f	\N
138342	reklaamija	reklaamija =reklaamija  (SgN  >reklaamija !01_S	et	f	\N
138343	reklaamija	"reklaamija %reklaami  )JA_vS  <reklaamima ;28_V	et	f	\N
138344	reklaamija	reklaamija =reklaamija  (SgG  >reklaamija !01_S	et	f	\N
138350	weebileheküljele	### weebileheküljele	et	f	\N
138351	muus	muus =muu  (SgIn  >muu !26_S	et	f	\N
138352	muus	muus =muu  (SgIn  >muu !26_P	et	f	\N
138353	muus	muus =muu  (IndIpfSg3  >muuma !27_V	et	f	\N
138358	ennekõige	?ennekõige =ennekõige  (PlP  >ennekõig !22_S	et	f	\N
138366	assemeleerimine	?assemeleerimine =assemeleerimine  (SgN  >assemeleerimine !12_S	et	f	\N
138367	assemeleerimine	?assemeleerimine =assemeleerimine  (PlP  >assemeleerimin !19_S	et	f	\N
138368	baruto	?baruto =baruto  (SgN  >baruto !16_S	et	f	\N
138369	baruto	?baruto =baruto  (SgG  >baruto !16_S	et	f	\N
138420	antsid	?antsid =antsi  (PlN  >ants !22_S	et	f	\N
138421	antsid	?antsid =antsi  (IndPrSg2  >antsima !28_V	et	f	\N
138430	uhkemaid	uhkemaid =uhkema  (PlP  >uhkem !02_A	et	f	\N
138431	uhkemaid	"uhkem %uhke  )M_cA  <uhke ;01_A	et	f	\N
138453	geograafiaasetuses	geograafiaasetuses =use  (PlIn  >geograafia+aset+usk !22_S	et	f	\N
138454	geograafiaasetuses	geograafiaasetuses =asetuse  (SgIn  >geograafia+asetus !11_S	et	f	\N
138458	notke	?notke =notke  (SgN  >notke !06_S	et	f	\N
138460	notke	?notke =notke  (SgG  >notke !06_S	et	f	\N
138462	notke	?notke =notke  (PlP  >notk !22_S	et	f	\N
138464	notke	?notke =notke  (IndPrPs_  >notkema !27_V	et	f	\N
138465	notke	?notke =notke  (ImpPrSg2  >notkema !27_V	et	f	\N
138466	benkt	?benkt =benkt  (SgN  >benkt !22_S	et	f	\N
138469	surmatantsu	surmatantsu =tantsu  (SgG  >surma+tants !22_S	et	f	\N
138470	surmatantsu	surmatantsu =tantsu  (SgP  >surma+tants !22_S	et	f	\N
138471	surmatantsu	surmatantsu =tantsu  (SgAdt  >surma+tants !22_S	et	f	\N
138472	vaadeldavad	vaadeldavad =vaadeldava  (PlN  >vaadeldav !02_A	et	f	\N
138473	vaadeldavad	"vaadeldav %vaadel  )TAV_vAS  <vaatlema ;30_V	et	f	\N
138474	baltimaad	baltimaad =maa  (PlN  >balti+maa !26_S	et	f	\N
138475	baltimaad	baltimaad =maa  (SgP  >balti+maa !26_S	et	f	\N
138479	javandrat	?javandrat =javandra  (SgP  >javandra !01_S	et	f	\N
138485	vandrati	?vandrati =vandra  (IndIpfIps  >vandrama !29_V	et	f	\N
138487	vandrati	?vandrati =vandrati  (ID  >vandrati !41_D	et	f	\N
138489	vandrati	?vandrati =vandrati  (SgG  >vandrat !02_S	et	f	\N
138490	vandrati	?vandrati =vandrati  (SgG  >vandratt !22_S	et	f	\N
138491	vandrati	?vandrati =vandrati  (IndPrPs_  >vandrattima !28_V	et	f	\N
138492	vandrati	?vandrati =vandrati  (ImpPrSg2  >vandrattima !28_V	et	f	\N
138287	plakaadid	?plakaadid =plakaadi  (PlN  >plakaat !22_S	et	f	\N
138288	plakaadid	?plakaadid =plakaadi  (IndPrSg2  >plakaatima !28_V	et	f	\N
138298	ontika	?ontika =ontika  (SgN  >ontika !01_S	et	f	\N
138299	ontika	?ontika =ontika  (SgG  >ontika !01_S	et	f	\N
138300	ontika	?ontika =ontika  (SgG  >ontikas !02_S	et	f	\N
138305	räpinasse	?räpinasse =räpinas  (SgAdt  >räpinane !12_A	et	f	\N
138306	räpinasse	?räpinasse =räpinasse  (SgG  >räpinasne !02_A	et	f	\N
138307	räpinasse	?räpinasse =räpinasse  (PlP  >räpinass !22_S	et	f	\N
138308	räpinasse	?räpinasse =nasse  (SgN  >räpi+nasse !06_S	et	f	\N
138309	räpinasse	?räpinasse =nasse  (SgG  >räpi+nasne !02_A	et	f	\N
138310	räpinasse	?räpinasse =nasse  (SgG  >räpi+nasse !06_S	et	f	\N
138311	räpinasse	?räpinasse =nasse  (PlP  >räpi+nass !22_S	et	f	\N
138335	teade	teade =teade  (SgN  >teade !05_S	et	f	\N
138336	teade	teade =teade  (SgN  >teade !06_S	et	f	\N
138337	teade	teade =teade  (PlP  >tead !22_S	et	f	\N
138361	kultuurseks	kultuurseks =kultuurse  (SgTr  >kultuurne !02_A	et	f	\N
138362	kultuurseks	kultuurseks =seks  (SgN  >kultuur+seks !22_S	et	f	\N
138388	tokyos	?tokyos =tokyo  (SgIn  >tokyo !26_S	et	f	\N
138389	tokyos	?tokyos =tokyos  (SgN  >tokyos !22_S	et	f	\N
138445	õppepoisid	õppepoisid =poi  (PlP  >õppe+poi !26_S	et	f	\N
138446	õppepoisid	õppepoisid =poisi  (PlN  >õppe+poiss !23?22_S	et	f	\N
138467	vandrat	?vandrat =vandra  (SgP  >vandra !01_S	et	f	\N
138468	vandrat	?vandrat =vandrat  (SgN  >vandrat !02_S	et	f	\N
138493	mõisnikustelt	?mõisnikustelt =mõisnikus  (PlAbl  >mõisnikus !11_S	et	f	\N
138494	mõisnikustelt	?mõisnikustelt =mõisnikustelt  (ID  >mõisnikustelt !41_D	et	f	\N
138495	tootedega	?tootedega =tede  (SgKom  >too+tede !16_S	et	f	\N
138498	talupojale	talupojale =poja  (SgAll  >talu+poja !17_S	et	f	\N
138499	talupojale	talupojale =poja  (SgAll  >talu+poeg !22_S	et	f	\N
138501	ilmalikustunud	?ilmalikustunud =ilmalikustu  (PtsPtPs  >ilmalikustuma !27_V	et	f	\N
138502	ilmalikustunud	?ilmalikustunud =ilmalikustunu  (PlN  >ilmalikustunu !01_S	et	f	\N
138503	ilmalikustunud	?ilmalikustunud =ilmalikustunu  (IndPrSg2  >ilmalikustunuma !27_V	et	f	\N
138504	ilmalikustunud	?ilmalikustunud =ilmalikustunud  (ID  >ilmalikustunud !41_A	et	f	\N
138505	ilmalikustunud	?ilmalikustunud =alikustunu  (PlN  >ilm+alikustunu !01_S	et	f	\N
138512	teesi	teesi =teesi  (SgG  >tees !22_S	et	f	\N
138513	teesi	teesi =teesi  (SgP  >tees !22_S	et	f	\N
138514	teesi	teesi =teesi  (SgAdt  >tees !22_S	et	f	\N
138518	välised	välised =välise  (PlN  >väline !10_A	et	f	\N
138519	välised	"väline %väli  )NE_aA  <väli ;24_S	et	f	\N
138528	11-aastatastele	?-aastatastele =aastatas  (PlAll  >-aastatane !12_A	et	f	\N
138529	11-aastatastele	?-aastatastele =aastatastele  (IndPrPs_  >-aastatastelema !36_V	et	f	\N
138530	11-aastatastele	?-aastatastele =aastatastele  (ImpPrSg2  >-aastatastelema !36_V	et	f	\N
138531	11-aastatastele	?-aastatastele =taste  (SgAll  >-aasta+taste !06_S	et	f	\N
138532	11-aastatastele	?-aastatastele =taste  (PlAll  >-aasta+tast !22_S	et	f	\N
138533	11-aastatastele	?-aastatastele =tatas  (PlAll  >-aas+tatas !07_S	et	f	\N
138534	11-aastatastele	?-aastatastele =tatas  (PlAll  >-aas+tatane !10_A	et	f	\N
138540	keelemurre	keelemurre =murre  (SgN  >keele+murre !05_S	et	f	\N
138541	keelemurre	keelemurre =murre  (SgN  >keele+murre !06_S	et	f	\N
138545	jaotus	jaotus =jaotu  (SgIn  >jaotu !01_A	et	f	\N
138546	jaotus	"jaotu %jao  )TU2_kA  <jagu ;18_S	et	f	\N
138547	jaotus	jaotus =jaotu  (IndIpfSg3  >jaotuma !27_V	et	f	\N
138548	jaotus	jaotus =jaotus  (SgN  >jaotus !11~09_S	et	f	\N
138549	jaotus	"jaotus %jaota  )US_vS  <jaotama ;27_V	et	f	\N
138550	jaotus	"jaotus %jao  )TUS2_aS  <jagu ;18_S	et	f	\N
138551	kerkisid	kerkisid =kerki  (IndIpfSg2  >kerkima !27_V	et	f	\N
138552	kerkisid	kerkisid =kerki  (IndIpfPl3  >kerkima !27_V	et	f	\N
138558	kauplemist	kauplemist =kauplemis  (SgP  >kauplemine !12_S	et	f	\N
138559	kauplemist	"kauplemine %kauple  )MINE_vS  <kauplema ;30_V	et	f	\N
138565	kirjakunsti	kirjakunsti =kunsti  (SgG  >kirja+kunst !22_S	et	f	\N
138566	kirjakunsti	kirjakunsti =kunsti  (SgP  >kirja+kunst !22_S	et	f	\N
138567	kirjakunsti	kirjakunsti =kunsti  (SgAdt  >kirja+kunst !22_S	et	f	\N
138612	peaaigu	?peaaigu =peaaigu  (IndPrPs_  >peaaiguma !27_V	et	f	\N
138613	peaaigu	?peaaigu =peaaigu  (ImpPrSg2  >peaaiguma !27_V	et	f	\N
138614	peaaigu	?peaaigu =aigu  (SgN  >pea+aigu !16_S	et	f	\N
138615	peaaigu	?peaaigu =aigu  (SgG  >pea+aigu !16_S	et	f	\N
138616	ümberjutustada	?ümberjutustada =ümberjutusta  (Inf  >ümberjutustama !27_V	et	f	\N
138617	ümberjutustada	?ümberjutustada =stada  (SgN  >ümber+jutu+stada !17_S	et	f	\N
138618	ümberjutustada	?ümberjutustada =stada  (SgG  >ümber+jutu+stada !17_S	et	f	\N
138619	ümberjutustada	?ümberjutustada =stada  (SgP  >ümber+jutu+stada !17_S	et	f	\N
138624	rahvuslaste	rahvuslaste =rahvuslas  (PlG  >rahvuslane !12_S	et	f	\N
138625	rahvuslaste	rahvuslaste =las  (PlG  >rahvus+laps !14_S	et	f	\N
138626	rahvuslaste	rahvuslaste =laste  (PlP  >rahvus+last !22_S	et	f	\N
138633	akstsioonile	?akstsioonile =akstsiooni  (SgAll  >akstsiooni !16_S	et	f	\N
138634	akstsioonile	?akstsioonile =akstsiooni  (SgAll  >akstsioon !22_S	et	f	\N
138670	vilniust	?vilniust =vilniu  (SgEl  >vilniu !01_S	et	f	\N
138322	kaplinksi	?kaplinksi =kaplinksi  (SgN  >kaplinksi !01_S	et	f	\N
138323	kaplinksi	?kaplinksi =kaplinksi  (SgG  >kaplinksi !01_S	et	f	\N
138324	kaplinksi	?kaplinksi =kaplinksi  (SgG  >kaplinks !22_S	et	f	\N
138325	kaplinksi	?kaplinksi =kaplinksi  (SgP  >kaplinks !22_S	et	f	\N
138326	kaplinksi	?kaplinksi =kaplinksi  (SgAdt  >kaplinks !22_S	et	f	\N
138327	kaplinksi	?kaplinksi =kaplinksi  (IndPrPs_  >kaplinksima !28_V	et	f	\N
138328	kaplinksi	?kaplinksi =kaplinksi  (ImpPrSg2  >kaplinksima !28_V	et	f	\N
138331	reklaamid	reklaamid =reklaami  (PlN  >reklaam !22_S	et	f	\N
138332	reklaamid	reklaamid =reklaami  (IndPrSg2  >reklaamima !28_V	et	f	\N
138370	sundinud	sundinud =sundi  (PtsPtPs  >sundima !28_V	et	f	\N
138371	sundinud	sundinud =sundinu  (PlN  >sundinu !01_S	et	f	\N
138372	sundinud	"sundinu %sundi  )NU_vS  <sundima ;28_V	et	f	\N
138373	sundinud	sundinud =sundinud  (ID  >sundinud !41_A	et	f	\N
138374	sundinud	"sundinud %sundi  )NUD_vA  <sundima ;28_V	et	f	\N
138382	sumo	sumo =sumo  (SgN  >sumo !17~16_S	et	f	\N
138383	sumo	sumo =sumo  (SgG  >sumo !17~16_S	et	f	\N
138384	sumo	sumo =sumo  (SgP  >sumo !17_S	et	f	\N
138385	kakskummend	?kakskummend =kakskummend  (SgN  >kakskummend !22_S	et	f	\N
138386	kakskummend	?kakskummend =kummend  (SgN  >kaks+kummend !02_S	et	f	\N
138395	pärnu	pärnu =pärnu  (SgN  >pärnu !01_H	et	f	\N
138396	pärnu	pärnu =pärnu  (SgG  >pärnu !01_H	et	f	\N
138409	kohtufunktisoone	?kohtufunktisoone =kohtufunktisoone  (SgN  >kohtufunktisoone !16_S	et	f	\N
138410	kohtufunktisoone	?kohtufunktisoone =kohtufunktisoone  (SgG  >kohtufunktisoone !16_S	et	f	\N
138411	kohtufunktisoone	?kohtufunktisoone =kohtufunktisoone  (PlP  >kohtufunktisoon !22_S	et	f	\N
138412	kohtufunktisoone	?kohtufunktisoone =funktisoone  (SgN  >kohtu+funktisoone !16_S	et	f	\N
138413	kohtufunktisoone	?kohtufunktisoone =funktisoone  (SgG  >kohtu+funktisoone !16_S	et	f	\N
138414	kohtufunktisoone	?kohtufunktisoone =funktisoone  (PlP  >kohtu+funktisoon !22_S	et	f	\N
138415	kohtufunktisoone	?kohtufunktisoone =ufunktisoone  (SgN  >koht+ufunktisoone !16_S	et	f	\N
138416	kohtufunktisoone	?kohtufunktisoone =ufunktisoone  (SgG  >koht+ufunktisoone !16_S	et	f	\N
138417	kohtufunktisoone	?kohtufunktisoone =ufunktisoone  (PlP  >koht+ufunktisoon !22_S	et	f	\N
138427	kõrgemad	kõrgemad =kõrgema  (PlN  >kõrgem !02_A	et	f	\N
138428	kõrgemad	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
138429	kõrgemad	kõrgemad =ema  (PlN  >kõrg+ema !17_S	et	f	\N
138432	peenemaid	peenemaid =peenema  (PlP  >peenem !02_A	et	f	\N
138433	peenemaid	"peenem %peene  )M_cA  <peen ;13_A	et	f	\N
138434	peenemaid	peenemaid =ma  (PlP  >peene+maa !26_S	et	f	\N
138435	peenemaid	peenemaid =mai  (PlN  >peene+mai !26_S	et	f	\N
138436	peenemaid	peenemaid =mai  (SgP  >peene+mai !26_S	et	f	\N
138437	madalam	madalam =madalam  (SgN  >madalam !02_A	et	f	\N
138438	madalam	"madalam %madala  )M_cA  <madal ;02_AS	et	f	\N
138455	tähtsamas	tähtsamas =tähtsama  (SgIn  >tähtsam !02_A	et	f	\N
138456	tähtsamas	"tähtsam %tähtsa  )M_cA  <tähtis ;02_A	et	f	\N
138459	baltasar	?baltasar =baltasar  (SgN  >baltasar !19_S	et	f	\N
138461	baltasar	?baltasar =asar  (SgN  >balt+asar !02_S	et	f	\N
138480	koeli	?koeli =koeli  (SgN  >koeli !16_S	et	f	\N
138481	koeli	?koeli =koeli  (SgG  >koeli !16_S	et	f	\N
138482	koeli	?koeli =koeli  (SgG  >koel !22_S	et	f	\N
138483	koeli	?koeli =koeli  (SgP  >koel !22_S	et	f	\N
138484	koeli	?koeli =koeli  (SgAdt  >koel !22_S	et	f	\N
138486	koeli	?koeli =koeli  (IndPrPs_  >koelima !28_V	et	f	\N
138488	koeli	?koeli =koeli  (ImpPrSg2  >koelima !28_V	et	f	\N
138500	sajandils	?sajandils =sajandils  (SgN  >sajandils !22_S	et	f	\N
138510	rikastumisele	rikastumisele =rikastumise  (SgAll  >rikastumine !12_S	et	f	\N
138511	rikastumisele	"rikastumine %rikastu  )MINE_vS  <rikastuma ;27_V	et	f	\N
138535	kümmet	kümmet =kümme  (SgP  >kümmend !05_N	et	f	\N
138536	kümmet	kümmet =kümme  (SgP  >kümme !05_N	et	f	\N
138581	korraldamisesse	korraldamisesse =korraldamise  (SgIll  >korraldamine !12_S	et	f	\N
138582	korraldamisesse	"korraldamine %korralda  )MINE_vS  <korraldama ;27_V	et	f	\N
138585	kiriklikku	kiriklikku =kiriklikku  (SgP  >kiriklik !25_A	et	f	\N
138586	kiriklikku	kiriklikku =kiriklikku  (SgAdt  >kiriklik !25_A	et	f	\N
138587	kiriklikku	kiriklikku =klikku  (SgP  >kiri+klikk !22_S	et	f	\N
138588	kiriklikku	kiriklikku =klikku  (SgAdt  >kiri+klikk !22_S	et	f	\N
138590	matmist	matmist =matmis  (SgP  >matmine !12?10_S	et	f	\N
138591	matmist	"matmine %mat  )MINE_vS  <matma ;35_V	et	f	\N
138599	hakatud	hakatud =haka  (PtsPtIps  >hakkama !29_V	et	f	\N
138600	hakatud	hakatud =hakatu  (PlN  >hakatu !01_AS	et	f	\N
138601	hakatud	"hakatu %haka  )TU1_vS  <hakkama ;29_V	et	f	\N
138602	hakatud	hakatud =hakatud  (ID  >hakatud !41_A	et	f	\N
138603	hakatud	"hakatud %haka  )TUD_vA  <hakkama ;29_V	et	f	\N
138606	mõistsid	mõistsid =mõist  (IndIpfSg2  >mõistma !34_V	et	f	\N
138607	mõistsid	mõistsid =mõist  (IndIpfPl3  >mõistma !34_V	et	f	\N
138610	haridusalu	haridusalu =alu  (SgG  >haridus+alg !22_S	et	f	\N
138611	haridusalu	haridusalu =alu  (PlP  >haridus+ala !17_S	et	f	\N
138620	arenda	arenda =arenda  (IndPrPs_  >arendama !27_V	et	f	\N
138621	arenda	arenda =arenda  (ImpPrSg2  >arendama !27_V	et	f	\N
138496	elamu	elamu =elamu  (SgN  >elamu !01_S	et	f	\N
138497	elamu	elamu =elamu  (SgG  >elamu !01_S	et	f	\N
138515	kirikusüsteemi	kirikusüsteemi =süsteemi  (SgG  >kiriku+süsteem !22_S	et	f	\N
138516	kirikusüsteemi	kirikusüsteemi =süsteemi  (SgP  >kiriku+süsteem !22_S	et	f	\N
138517	kirikusüsteemi	kirikusüsteemi =süsteemi  (SgAdt  >kiriku+süsteem !22_S	et	f	\N
138543	avalikku	avalikku =avalikku  (SgP  >avalik !25_A	et	f	\N
138544	avalikku	avalikku =avalikku  (SgAdt  >avalik !25_A	et	f	\N
138570	üldisemalt	üldisemalt =üldisema  (SgAbl  >üldisem !02_A	et	f	\N
138571	üldisemalt	"üldisem %üldise  )M_cA  <üldine ;10_A	et	f	\N
138572	üldisemalt	"üldisem %üldise  )M_cA  <üldine ;12_A	et	f	\N
138573	üldisemalt	üldisemalt =üldisemalt  (ID  >üldisemalt !41_D	et	f	\N
138574	üldisemalt	"üldisemalt %üldise  )MALT_mD  <üldine ;10_A	et	f	\N
138575	üldisemalt	"üldisemalt %üldise  )MALT_mD  <üldine ;12_A	et	f	\N
138595	ristimist	ristimist =ristimis  (SgP  >ristimine !12_S	et	f	\N
138596	ristimist	"ristimine %risti  )MINE_vS  <ristima ;28_V	et	f	\N
138597	nõuetest	nõuetest =nõue  (PlEl  >nõue !06_S	et	f	\N
138598	nõuetest	nõuetest =e  (PlEl  >nõu+esi !15_S	et	f	\N
138622	1857a	### 1857a	et	f	\N
138623	orkestride	### orkestride	et	f	\N
138640	olulisemaks	olulisemaks =olulisema  (SgTr  >olulisem !02_A	et	f	\N
138641	olulisemaks	"olulisem %olu  )LISEM_cA  <olu ;17_S	et	f	\N
138642	olulisemaks	"olulisem %olulise  )M_cA  <oluline ;12_A	et	f	\N
138660	maastikku	maastikku =maastikku  (SgP  >maastik !25_S	et	f	\N
138661	maastikku	maastikku =maastikku  (SgAdt  >maastik !25_S	et	f	\N
138662	maastikku	maastikku =tikku  (SgP  >maas+tikk !22_S	et	f	\N
138663	maastikku	maastikku =tikku  (SgAdt  >maas+tigu !18_S	et	f	\N
138665	maastikku	maastikku =tikku  (SgAdt  >maas+tikk !22_S	et	f	\N
138667	maastikku	maastikku =tikku  (PlP  >maas+tikk !22_S	et	f	\N
138674	perekondale	?perekondale =perekonda  (SgAll  >perekonda !16_S	et	f	\N
138675	perekondale	?perekondale =konda  (SgAll  >pere+konda !16_S	et	f	\N
138676	meili	meili =meili  (SgG  >meil !22_S	et	f	\N
138677	meili	meili =meili  (SgP  >meil !22_S	et	f	\N
138678	meili	meili =meili  (SgAdt  >meil !22_S	et	f	\N
138679	meili	meili =meili  (IndPrPs_  >meilima !28_V	et	f	\N
138680	meili	meili =meili  (ImpPrSg2  >meilima !28_V	et	f	\N
138751	sörkin	?sörkin =sörkin  (SgN  >sörkin !02_S	et	f	\N
138769	nätiks	?nätiks =näti  (SgTr  >näti !16_S	et	f	\N
138770	nätiks	?nätiks =näti  (SgTr  >nätt !22_S	et	f	\N
138771	nätiks	?nätiks =näti  (KndPrPs  >nätima !27_V	et	f	\N
138772	nätiks	?nätiks =näti  (KndPrPs  >nättima !28_V	et	f	\N
138785	sajanud	?sajanud =saja  (PtsPtPs  >sajama !27_V	et	f	\N
138786	sajanud	?sajanud =sajanu  (PlN  >sajanu !01_S	et	f	\N
138787	sajanud	?sajanud =sajanu  (IndPrSg2  >sajanuma !27_V	et	f	\N
138788	sajanud	?sajanud =sajanud  (ID  >sajanud !41_A	et	f	\N
138794	kama	kama =kama  (SgN  >kama !17_S	et	f	\N
138795	kama	kama =kama  (SgG  >kama !17_S	et	f	\N
138796	kama	kama =kama  (SgP  >kama !17_S	et	f	\N
138797	suhkraga	?suhkraga =suhkra  (SgKom  >suhkra !01_S	et	f	\N
138815	saaremaale	saaremaale =ale  (SgN  >saar+ema+ale !16_S	et	f	\N
138816	saaremaale	saaremaale =ale  (SgG  >saar+ema+ale !16_S	et	f	\N
138817	saaremaale	saaremaale =maa  (SgAll  >saare+maa !26_S	et	f	\N
138818	saaremaale	saaremaale =maale  (PlP  >saare+maal !22_S	et	f	\N
138823	vajanad	### vajanad	et	f	\N
138825	sulatavad	sulatavad =sulata  (IndPrPl3  >sulatama !27_V	et	f	\N
138826	sulatavad	sulatavad =sulatava  (PlN  >sulatav !02_A	et	f	\N
138827	sulatavad	"sulatav %sula  )TAV_vAS  <sulama ;27_V	et	f	\N
138828	sulatavad	"sulatav %sulata  )V_vA  <sulatama ;27_V	et	f	\N
138829	sulatavad	sulatavad =tava  (PlN  >sula+tava !17_S	et	f	\N
138840	lõppetan	?lõppetan =lõppeta  (IndPrSg1  >lõppetama !27_V	et	f	\N
138841	lõppetan	?lõppetan =lõppetan  (SgN  >lõppetan !19_S	et	f	\N
138842	lõppetan	?lõppetan =etan  (SgN  >lõpp+etan !02_S	et	f	\N
138846	toompea	toompea =pea  (SgN  >toom+pea !26_S	et	f	\N
138847	toompea	toompea =pea  (SgG  >toom+pea !26_S	et	f	\N
138848	rakegoja	?rakegoja =rakegoja  (SgN  >rakegoja !01_S	et	f	\N
138849	rakegoja	?rakegoja =rakegoja  (SgG  >rakegoja !01_S	et	f	\N
138850	rakegoja	?rakegoja =rakegoja  (SgG  >rakegojas !02_A	et	f	\N
138859	hämmastav	hämmastav =hämmasta  (PtsPrPs  >hämmastama !27_V	et	f	\N
138860	hämmastav	hämmastav =hämmastav  (SgN  >hämmastav !02_A	et	f	\N
138861	hämmastav	"hämmastav %hämmasta  )V_vA  <hämmastama ;27_V	et	f	\N
138872	kulturist	?kulturist =kulturi  (SgEl  >kulturi !01_S	et	f	\N
138873	kulturist	?kulturist =kulturi  (SgEl  >kultur !02_S	et	f	\N
138874	kulturist	?kulturist =kulturis  (SgP  >kulturis !11_S	et	f	\N
138875	kulturist	?kulturist =kulturist  (SgN  >kulturist !22_S	et	f	\N
138887	lõunake	lõunake =lõunake  (SgN  >lõunake !12_S	et	f	\N
138888	lõunake	"lõunake %lõuna  )KE_dS  <lõuna ;06_S	et	f	\N
138889	lõunake	lõunake =nake  (SgN  >lõu+nake !06_S	et	f	\N
138929	üheteistkümneni	?üheteistkümneni =üheteistkümneni  (SgG  >üheteistkümnen !02_S	et	f	\N
138507	lutheri	?lutheri =lutheri  (SgN  >lutheri !01_S	et	f	\N
138508	lutheri	?lutheri =lutheri  (SgG  >lutheri !01_S	et	f	\N
138509	lutheri	?lutheri =lutheri  (SgG  >luther !02_S	et	f	\N
138520	kirikuskäimine	kirikuskäimine =käimine  (SgN  >kiri+kus+käimine !12?10_S	et	f	\N
138521	kirikuskäimine	"kiri+kus+käimine %käimi  )NE_aA  <kiri+kus+käim ;22_S	et	f	\N
138524	külakatoliikluseks	külakatoliikluseks =katoliikluse  (SgTr  >küla+katoliiklus !11~09_S	et	f	\N
138525	külakatoliikluseks	"küla+katoliiklus %katoliiklase  )US_aS  <küla+katoliiklane ;12_S	et	f	\N
138526	osalt	osalt =osa  (SgAbl  >osa !17_S	et	f	\N
138527	osalt	osalt =osalt  (ID  >osalt !41_D	et	f	\N
138537	kirikute	kirikute =kiriku  (PlG  >kirik !02_S	et	f	\N
138538	kirikute	kirikute =ute  (SgG  >kirik+utt !22_S	et	f	\N
138553	hansaliitu	hansaliitu =liitu  (SgN  >hansa+liitu !01_A	et	f	\N
138554	hansaliitu	"hansa+liitu %lii  )TU2_kA  <hansa+lii ;26_S	et	f	\N
138555	hansaliitu	hansaliitu =liitu  (SgG  >hansa+liitu !01_A	et	f	\N
138556	hansaliitu	hansaliitu =liitu  (SgP  >hansa+liit !22_S	et	f	\N
138557	hansaliitu	hansaliitu =liitu  (SgAdt  >hansa+liit !22_S	et	f	\N
138560	harjutud	harjutud =harju  (PtsPtIps  >harjuma !27_V	et	f	\N
138561	harjutud	harjutud =harjutu  (PlN  >harjutu !01_AS	et	f	\N
138562	harjutud	"harjutu %harju  )TU1_vS  <harjuma ;27_V	et	f	\N
138563	harjutud	harjutud =harjutud  (ID  >harjutud !41_A	et	f	\N
138564	harjutud	"harjutud %harju  )TUD_vA  <harjuma ;27_V	et	f	\N
138576	matsil	matsil =matsi  (SgAd  >mats !22_S	et	f	\N
138577	matsil	matsil =matsi  (SgAd  >mats !22_SA	et	f	\N
138578	ühiskonnaelu	ühiskonnaelu =elu  (SgN  >ühis+konna+elu !17_S	et	f	\N
138579	ühiskonnaelu	ühiskonnaelu =elu  (SgG  >ühis+konna+elu !17_S	et	f	\N
138580	ühiskonnaelu	ühiskonnaelu =elu  (SgP  >ühis+konna+elu !17_S	et	f	\N
138604	kontrollis	kontrollis =kontrolli  (SgIn  >kontroll !22_S	et	f	\N
138605	kontrollis	kontrollis =kontrolli  (IndIpfSg3  >kontrollima !28_V	et	f	\N
138608	tulemas	tulemas =tule  (SupIn  >tulema !36_V	et	f	\N
138609	tulemas	tulemas =tulema  (SgIn  >tulem !02_S	et	f	\N
138631	patriotide	?patriotide =patrioti  (PlG  >patrioti !16_S	et	f	\N
138632	patriotide	?patriotide =patrioti  (PlG  >patriot !22_S	et	f	\N
138646	tagastamist	tagastamist =tagastamis  (SgP  >tagastamine !12_S	et	f	\N
138647	tagastamist	"tagastamine %tagasta  )MINE_vS  <tagastama ;27_V	et	f	\N
138654	kirikusse	kirikusse =kiriku  (SgIll  >kirik !02_S	et	f	\N
138655	kirikusse	kirikusse =usse  (PlP  >kirik+uss !22_S	et	f	\N
138656	kirikusse	kirikusse =kusse  (SgAdt  >kiri+kusi !20_S	et	f	\N
138684	poodisse	?poodisse =poodi  (SgIll  >poodi !16_S	et	f	\N
138685	poodisse	?poodisse =poodisse  (SgG  >poodisne !02_A	et	f	\N
138686	poodisse	?poodisse =poodisse  (PlP  >poodiss !22_S	et	f	\N
138687	mahla	mahla =mahla  (SgG  >mahl !22_S	et	f	\N
138688	mahla	mahla =mahla  (SgP  >mahl !22_S	et	f	\N
138689	mahla	mahla =mahla  (SgAdt  >mahl !22_S	et	f	\N
138690	köögiviljasuppi	köögiviljasuppi =suppi  (SgP  >köögi+vilja+supp !22_S	et	f	\N
138691	köögiviljasuppi	köögiviljasuppi =suppi  (SgAdt  >köögi+vilja+supp !22_S	et	f	\N
138712	tundile	?tundile =tundi  (SgAll  >tundi !16_S	et	f	\N
138713	tundile	?tundile =tundi  (SgAll  >tunt !22_S	et	f	\N
138714	tundile	?tundile =tundile  (IndPrPs_  >tundilema !27_V	et	f	\N
138715	tundile	?tundile =tundile  (ImpPrSg2  >tundilema !27_V	et	f	\N
138735	aastaa	?aastaa =aastaa  (SgN  >aastaa !26_S	et	f	\N
138736	aastaa	?aastaa =aastaa  (SgG  >aastaa !26_S	et	f	\N
138737	aastaa	?aastaa =taa  (SgN  >aas+taa !26_S	et	f	\N
138739	aastaa	?aastaa =taa  (SgG  >aas+taa !26_S	et	f	\N
138749	helsinkist	?helsinkist =helsinkis  (SgP  >helsinkis !11_S	et	f	\N
138750	helsinkist	?helsinkist =helsinkist  (SgN  >helsinkist !22_S	et	f	\N
138755	lodus	lodus =lodu  (SgIn  >lodu !17_S	et	f	\N
138756	lodus	lodus =lodus  (ID  >lodus !41_DA	et	f	\N
138759	ülipilaselamus	?ülipilaselamus =ülipilaselamu  (IndIpfSg3  >ülipilaselamuma !27_V	et	f	\N
138760	ülipilaselamus	?ülipilaselamus =ülipilaselamus  (SgN  >ülipilaselamus !11?09_S	et	f	\N
138761	ülipilaselamus	?ülipilaselamus =selamu  (SgIn  >üli+pila+selamu !01_S	et	f	\N
138762	ülipilaselamus	?ülipilaselamus =selamus  (SgN  >üli+pila+selamus !11_S	et	f	\N
138763	ülipilaselamus	?ülipilaselamus =pilaselamus  (SgN  >üli+pilaselamus !11?09_S	et	f	\N
138800	kielil	?kielil =kieli  (SgAd  >kieli !16_S	et	f	\N
138801	kielil	?kielil =kieli  (SgAd  >kiel !22_S	et	f	\N
138810	sinne	?sinne =sinne  (SgN  >sinne !06_S	et	f	\N
138811	sinne	?sinne =sinne  (PlP  >sinn !22_S	et	f	\N
138812	sinne	?sinne =sinne  (IndPrPs_  >sinnema !27_V	et	f	\N
138813	sinne	?sinne =sinne  (ImpPrSg2  >sinnema !27_V	et	f	\N
138837	hapukoor	hapukoor =koor  (SgN  >hapu+koor !13_S	et	f	\N
138838	hapukoor	hapukoor =koor  (SgN  >hapu+koor !22_S	et	f	\N
138839	pelmenid	?pelmenid =pelmeni  (PlN  >pelmen !02_S	et	f	\N
138863	tõusan	?tõusan =tõusa  (IndPrSg1  >tõusama !29_V	et	f	\N
138864	tõusan	?tõusan =tõusan  (SgN  >tõusan !02_S	et	f	\N
138876	pesan	?pesan =pesa  (IndPrSg1  >pesama !27_V	et	f	\N
138877	pesan	?pesan =pesan  (SgN  >pesan !02_S	et	f	\N
138878	t-särgi	t-särgi =särgi  (SgG  >t-särk !22_S	et	f	\N
138627	ringikesi	ringikesi =ringikesi  (PlP  >ringike !12_S	et	f	\N
138628	ringikesi	"ringike %ringi  )KE_dS  <ring ;22_S	et	f	\N
138629	ringikesi	ringikesi =ringikesi  (PlP  >ringikene !12_S	et	f	\N
138630	ringikesi	"ringikene %ringi  )KENE_dS  <ring ;22_S	et	f	\N
138648	lidia	?lidia =lidia  (SgN  >lidia !01_S	et	f	\N
138649	lidia	?lidia =lidia  (SgG  >lidia !01_S	et	f	\N
138650	ulikoolis	?ulikoolis =ulikooli  (SgIn  >ulikooli !16_S	et	f	\N
138651	ulikoolis	?ulikoolis =ulikooli  (SgIn  >ulikool !22_S	et	f	\N
138652	ulikoolis	?ulikoolis =ulikooli  (IndIpfSg3  >ulikoolima !28_V	et	f	\N
138653	ulikoolis	?ulikoolis =ulikoolis  (SgN  >ulikoolis !09_S	et	f	\N
138664	varssavisse	?varssavisse =varssavi  (SgIll  >varssav !02_A	et	f	\N
138666	varssavisse	?varssavisse =varssavis  (SgAdt  >varssavis !11_S	et	f	\N
138668	varssavisse	?varssavisse =varssavisse  (SgG  >varssavisne !02_A	et	f	\N
138669	varssavisse	?varssavisse =varssavisse  (PlP  >varssaviss !22_S	et	f	\N
138672	postkaarti	postkaarti =kaarti  (SgP  >post+kaart !22_S	et	f	\N
138673	postkaarti	postkaarti =kaarti  (SgAdt  >post+kaart !22_S	et	f	\N
138703	blow	### blow	et	f	\N
138704	sõbradga	?sõbradga =sõbradga  (SgN  >sõbradga !01_S	et	f	\N
138705	sõbradga	?sõbradga =sõbradga  (SgG  >sõbradga !01_S	et	f	\N
138706	viihma	?viihma =viihma  (SgN  >viihma !01_S	et	f	\N
138707	viihma	?viihma =viihma  (SgG  >viihma !01_S	et	f	\N
138708	viihma	?viihma =viihma  (IndPrPs_  >viihmama !29_V	et	f	\N
138709	viihma	?viihma =viihma  (ImpPrSg2  >viihmama !29_V	et	f	\N
138716	üliopilanen	?üliopilanen =üliopilanen  (SgN  >üliopilanen !19_S	et	f	\N
138717	üliopilanen	?üliopilanen =opilanen  (SgN  >üli+opilanen !19_S	et	f	\N
138721	üliopilane	?üliopilane =üliopilane  (SgN  >üliopilane !12_S	et	f	\N
138722	üliopilane	?üliopilane =üliopilane  (PlP  >üliopilan !19_S	et	f	\N
138723	üliopilane	?üliopilane =opilane  (SgN  >üli+opilane !12_S	et	f	\N
138724	üliopilane	?üliopilane =opilane  (PlP  >üli+opilan !19_S	et	f	\N
138725	paikese	paikese =paikese  (SgG  >paike !12?10_AS	et	f	\N
138726	paikese	"paike %pai  )KE_dA  <pai ;26_AS	et	f	\N
138727	paikese	paikese =paikese  (SgG  >paikene !12?10_AS	et	f	\N
138728	paikese	"paikene %pai  )KENE_dA  <pai ;26_AS	et	f	\N
138734	hummekusts	### hummekusts	et	f	\N
138757	pärnusse	pärnusse =pärnu  (SgIll  >pärnu !01_H	et	f	\N
138758	pärnusse	pärnusse =usse  (PlP  >pärn+uss !22_S	et	f	\N
138768	inimehed	### inimehed	et	f	\N
138778	sushi	?sushi =sushi  (SgN  >sushi !16_S	et	f	\N
138779	sushi	?sushi =sushi  (SgG  >sushi !16_S	et	f	\N
138780	sushi	?sushi =sushi  (SgG  >sush !22_S	et	f	\N
138781	sushi	?sushi =sushi  (SgP  >sush !22_S	et	f	\N
138782	sushi	?sushi =sushi  (SgAdt  >sush !22_S	et	f	\N
138783	sushi	?sushi =sushi  (IndPrPs_  >sushima !28_V	et	f	\N
138784	sushi	?sushi =sushi  (ImpPrSg2  >sushima !28_V	et	f	\N
138798	kiel	?kiel =kie  (SgAd  >kie !26_S	et	f	\N
138799	kiel	?kiel =kiel  (SgN  >kiel !22_S	et	f	\N
138822	inimested	?inimested =este  (PlN  >inim+este !06_S	et	f	\N
138824	okay	### okay	et	f	\N
138832	sinine	?sinine =sinine  (SgN  >sinine !10_AS	et	f	\N
138833	sinine	?sinine =sinine  (IndPrPs_  >sininema !27_V	et	f	\N
138834	sinine	?sinine =sinine  (ImpPrSg2  >sininema !27_V	et	f	\N
138843	lemmikkohad	lemmikkohad =koha  (PlN  >lemmik+koha !17_S	et	f	\N
138844	lemmikkohad	lemmikkohad =koha  (PlN  >lemmik+koht !22_S	et	f	\N
138852	rakvere	### rakvere	et	f	\N
138853	huvidav	?huvidav =huvidav  (SgN  >huvidav !02_A	et	f	\N
138890	lieba	?lieba =lieba  (SgN  >lieba !16_S	et	f	\N
138891	lieba	?lieba =lieba  (SgG  >lieba !16_S	et	f	\N
138892	lieba	?lieba =lieba  (IndPrPs_  >liebama !29_V	et	f	\N
138894	lieba	?lieba =lieba  (ImpPrSg2  >liebama !29_V	et	f	\N
138910	täevas	?täevas =täeva  (SgIn  >täeva !16_S	et	f	\N
138911	täevas	?täevas =täeva  (IndIpfSg3  >täevama !29_V	et	f	\N
138913	täevas	?täevas =täevas  (SgN  >täevas !07_S	et	f	\N
138925	pruunet	### pruunet	et	f	\N
138935	televisorit	?televisorit =televisori  (SgP  >televisor !02_S	et	f	\N
138936	televisorit	?televisorit =visori  (SgP  >tele+visori !01_S	et	f	\N
138937	televisorit	?televisorit =visori  (SgP  >tele+visor !02_S	et	f	\N
138953	üliõpilanena	### üliõpilanena	et	f	\N
138968	nimetavad	nimetavad =nimeta  (IndPrPl3  >nimetama !27_V	et	f	\N
138969	nimetavad	nimetavad =nimetava  (PlN  >nimetav !02_A	et	f	\N
138970	nimetavad	"nimetav %nimeta  )V_vA  <nimetama ;27_V	et	f	\N
138971	nimetavad	nimetavad =tava  (PlN  >nime+tava !17_S	et	f	\N
138972	vane	?vane =vane  (SgN  >vane !16_S	et	f	\N
138973	vane	?vane =vane  (SgG  >vane !16_S	et	f	\N
138974	vane	?vane =vane  (IndPrPs_  >vanema !27_V	et	f	\N
138975	vane	?vane =vane  (ImpPrSg2  >vanema !27_V	et	f	\N
139011	toimisid	toimisid =toimi  (PlP  >toim !22_S	et	f	\N
139012	toimisid	toimisid =toimi  (IndIpfSg2  >toimima !28_V	et	f	\N
139013	toimisid	toimisid =toimi  (IndIpfPl3  >toimima !28_V	et	f	\N
139044	tahandeid	?tahandeid =tahande  (PlP  >tahandi !01_S	et	f	\N
139045	tahandeid	?tahandeid =tahande  (PlP  >tahand !02_S	et	f	\N
138645	vaimuvara	vaimuvara =vara  (SgP  >vaimu+vara !17_S	et	f	\N
138657	observatooriumi	observatooriumi =observatooriumi  (SgG  >observatoorium !19~02_S	et	f	\N
138658	observatooriumi	observatooriumi =observatooriumi  (SgP  >observatoorium !19_S	et	f	\N
138659	observatooriumi	observatooriumi =observatooriumi  (SgAdt  >observatoorium !19_S	et	f	\N
138681	aratasin	?aratasin =arata  (IndIpfSg1  >aratama !27_V	et	f	\N
138682	aratasin	?aratasin =aratasin  (SgN  >aratasin !19_S	et	f	\N
138683	aratasin	?aratasin =tasin  (SgN  >ara+tasin !02_S	et	f	\N
138693	randle	?randle =randle  (SgN  >randle !06_S	et	f	\N
138694	randle	?randle =randle  (SgG  >randle !06_S	et	f	\N
138695	randle	?randle =randle  (IndPrPs_  >randlema !30_V	et	f	\N
138696	randle	?randle =randle  (ImpPrSg2  >randlema !30_V	et	f	\N
138699	laine	laine =laine  (SgN  >laine !06_S	et	f	\N
138700	laine	laine =laine  (SgG  >laine !06_S	et	f	\N
138701	vanalinnas	vanalinnas =linna  (SgIn  >vana+linn !22_S	et	f	\N
138702	vanalinnas	vanalinnas =linnas  (SgN  >vana+linnas !09_S	et	f	\N
138710	sotsiaaltöö	sotsiaaltöö =töö  (SgN  >sotsiaal+töö !26_S	et	f	\N
138711	sotsiaaltöö	sotsiaaltöö =töö  (SgG  >sotsiaal+töö !26_S	et	f	\N
138729	paisteline	paisteline =paisteline  (SgN  >paisteline !12_A	et	f	\N
138730	paisteline	"paisteline %paiste  )LINE_aA  <paiste ;06_S	et	f	\N
138731	ujumisbasseins	?ujumisbasseins =ujumisbasseins  (SgN  >ujumisbasseins !22_S	et	f	\N
138732	ujumisbasseins	?ujumisbasseins =eins  (SgN  >ujumis+bass+eins !22_S	et	f	\N
138733	ujumisbasseins	?ujumisbasseins =basseins  (SgN  >ujumis+basseins !02_S	et	f	\N
138738	egi	?egi =egi  (SgN  >egi !17_S	et	f	\N
138740	egi	?egi =egi  (SgG  >egi !17_S	et	f	\N
138741	egi	?egi =egi  (SgP  >egi !17_S	et	f	\N
138742	egi	?egi =egi  (IndPrPs_  >egima !27_V	et	f	\N
138743	egi	?egi =egi  (ImpPrSg2  >egima !27_V	et	f	\N
138764	tundanud	?tundanud =tunda  (PtsPtPs  >tuntama !29_V	et	f	\N
138765	tundanud	?tundanud =tundanu  (PlN  >tundanu !01_S	et	f	\N
138766	tundanud	?tundanud =tundanu  (IndPrSg2  >tundanuma !27_V	et	f	\N
138767	tundanud	?tundanud =tundanud  (ID  >tundanud !41_A	et	f	\N
138789	sõitanud	?sõitanud =sõita  (PtsPtPs  >sõitama !27_V	et	f	\N
138790	sõitanud	?sõitanud =sõitanu  (PlN  >sõitanu !01_S	et	f	\N
138791	sõitanud	?sõitanud =sõitanu  (IndPrSg2  >sõitanuma !27_V	et	f	\N
138792	sõitanud	?sõitanud =sõitanud  (ID  >sõitanud !41_A	et	f	\N
138793	piritas	?piritas =pirita  (IndIpfSg3  >piritama !27_V	et	f	\N
138803	elumaja	elumaja =maja  (SgN  >elu+maja !17_S	et	f	\N
138804	elumaja	elumaja =maja  (SgG  >elu+maja !17_S	et	f	\N
138805	elumaja	elumaja =maja  (SgP  >elu+maja !17_S	et	f	\N
138806	sotsiaal	?sotsiaal =sotsiaa  (SgAd  >sotsiaa !26_S	et	f	\N
138807	sotsiaal	?sotsiaal =sotsiaal  (SgN  >sotsiaal !22_S	et	f	\N
138820	näedsid	?näedsid =näedsi  (PlN  >näeds !22_S	et	f	\N
138821	näedsid	?näedsid =näedsi  (IndPrSg2  >näedsima !28_V	et	f	\N
138835	pannkoogi	pannkoogi =koogi  (SgG  >pann+kook !22_S	et	f	\N
138836	pannkoogi	pannkoogi =koo  (SgG^  >pann+kubu !18_S	et	f	\N
138845	tallinas	### tallinas	et	f	\N
138854	erasmuse	?erasmuse =erasmuse  (SgG  >erasmus !11_S	et	f	\N
138855	erasmuse	?erasmuse =smuse  (SgN  >era+smuse !16_S	et	f	\N
138856	erasmuse	?erasmuse =smuse  (SgG  >era+smuse !16_S	et	f	\N
138862	tegeda	### tegeda	et	f	\N
138865	espresso	?espresso =espresso  (SgN  >espresso !16_S	et	f	\N
138866	espresso	?espresso =espresso  (SgG  >espresso !16_S	et	f	\N
138870	toitist	?toitist =toitis  (SgP  >toitis !11~09_S	et	f	\N
138871	toitist	?toitist =toitist  (SgN  >toitist !22_S	et	f	\N
138885	kampsuni	kampsuni =kampsu  (SgTer  >kamps !22_S	et	f	\N
138886	kampsuni	kampsuni =kampsuni  (SgG  >kampsun !02_S	et	f	\N
138893	kapsas	kapsas =kapsa  (SgIn  >kapsas !07_S	et	f	\N
138895	kapsas	kapsas =kapsa  (IndIpfSg3  >kapsama !29_V	et	f	\N
138896	kapsas	kapsas =kapsas  (SgN  >kapsas !07_S	et	f	\N
138899	jalatan	?jalatan =jalata  (IndPrSg1  >jalatama !27_V	et	f	\N
138900	jalatan	?jalatan =jalatan  (SgN  >jalatan !19_S	et	f	\N
138903	äärre	?äärre =äärre  (SgN  >äärre !06_S	et	f	\N
138904	äärre	?äärre =äärre  (SgG  >äärre !06_S	et	f	\N
138905	äärre	?äärre =äärre  (PlP  >äärr !22_S	et	f	\N
138906	äärre	?äärre =äärre  (IndPrPs_  >äärrema !27_V	et	f	\N
138907	äärre	?äärre =äärre  (ImpPrSg2  >äärrema !27_V	et	f	\N
138942	jaaniaris	?jaaniaris =jaaniari  (SgIn  >jaaniar !19~02_S	et	f	\N
138943	jaaniaris	?jaaniaris =jaaniari  (SgIn  >jaaniari !16_S	et	f	\N
138944	jaaniaris	?jaaniaris =jaaniari  (IndIpfSg3  >jaaniarima !28_V	et	f	\N
138945	jaaniaris	?jaaniaris =jaaniaris  (SgN  >jaaniaris !09_S	et	f	\N
138946	jaaniaris	?jaaniaris =ari  (SgIn  >jaani+ari !17_S	et	f	\N
138947	jaaniaris	?jaaniaris =aris  (SgN  >jaani+aris !09_S	et	f	\N
138948	suvil	### suvil	et	f	\N
138949	tahasin	?tahasin =taha  (IndIpfSg1  >tahama !27_V	et	f	\N
138950	tahasin	?tahasin =tahasin  (SgN  >tahasin !19_S	et	f	\N
138951	vahemine	?vahemine =vahemine  (SgN  >vahemine !12_S	et	f	\N
138952	vahemine	?vahemine =vahemine  (PlP  >vahemin !19_S	et	f	\N
138954	küsisid	küsisid =küsi  (IndIpfSg2  >küsima !27_V	et	f	\N
138671	vilniust	?vilniust =vilnius  (SgP  >vilnius !11_S	et	f	\N
138692	16c	### 16c	et	f	\N
138697	leidi	leidi =leidi  (SgP  >leid !22_S	et	f	\N
138698	leidi	leidi =leidi  (SgAdt  >leid !22_S	et	f	\N
138718	nädale	?nädale =näda  (SgAll  >näda !17_S	et	f	\N
138719	nädale	?nädale =nädale  (IndPrPs_  >nädalema !27_V	et	f	\N
138720	nädale	?nädale =nädale  (ImpPrSg2  >nädalema !27_V	et	f	\N
138744	austrias	?austrias =austria  (SgIn  >austria !01_S	et	f	\N
138745	austrias	?austrias =austrias  (SgN  >austrias !11_S	et	f	\N
138746	minen	?minen =minen  (SgN  >minen !02_S	et	f	\N
138747	räägima	?räägima =räägi  (Sup  >räägima !28_V	et	f	\N
138748	räägima	?räägima =räägima  (SgG  >räägim !02_A	et	f	\N
138752	lõplikult	lõplikult =lõpliku  (SgAbl  >lõplik !25_A	et	f	\N
138753	lõplikult	lõplikult =lõplikult  (ID  >lõplikult !41_D	et	f	\N
138754	lõplikult	"lõplikult %lõpliku  )LT_mD  <lõplik ;25_A	et	f	\N
138773	kreeka	?kreeka =kreeka  (SgN  >kreeka !16_S	et	f	\N
138774	kreeka	?kreeka =kreeka  (SgG  >kreekas !02_A	et	f	\N
138775	kreeka	?kreeka =kreeka  (SgG  >kreeka !16_S	et	f	\N
138776	kreeka	?kreeka =kreeka  (IndPrPs_  >kreekama !29_V	et	f	\N
138777	kreeka	?kreeka =kreeka  (ImpPrSg2  >kreekama !29_V	et	f	\N
138802	juuada	### juuada	et	f	\N
138808	sõberedga	?sõberedga =sõberedga  (SgN  >sõberedga !16_S	et	f	\N
138809	sõberedga	?sõberedga =sõberedga  (SgG  >sõberedga !16_S	et	f	\N
138814	turisted	### turisted	et	f	\N
138819	õtteppale	?õtteppale =õtteppa  (SgAll  >õtteppa !01_S	et	f	\N
138830	vihmane	vihmane =vihmane  (SgN  >vihmane !10_A	et	f	\N
138831	vihmane	"vihmane %vihma  )NE_aA  <vihm ;22_S	et	f	\N
138851	plads	?plads =plads  (SgN  >plads !22_S	et	f	\N
138857	hullud	hullud =hullu  (PlN  >hull !22_AS	et	f	\N
138858	hullud	hullud =hullu  (IndPrSg2  >hulluma !27_V	et	f	\N
138867	lugeksin	?lugeksin =lugeksi  (IndPrSg1  >lugeksima !28_V	et	f	\N
138868	lugeksin	?lugeksin =lugeksin  (SgN  >lugeksin !19_S	et	f	\N
138869	york	?york =york  (SgN  >york !22_S	et	f	\N
138882	roosa	roosa =roosa  (SgN  >roosa !16_AS	et	f	\N
138883	roosa	roosa =roosa  (SgG  >roosa !16_AS	et	f	\N
138884	roosa	roosa =roosa  (SgG  >roosk !22_S	et	f	\N
138915	pilves	pilves =pilve  (SgIn  >pilv !22_S	et	f	\N
138916	pilves	pilves =pilve  (PlIn  >pilv !22_S	et	f	\N
138917	pilves	pilves =pilves  (ID  >pilves !41_DA	et	f	\N
138918	finlandisse	?finlandisse =finlandi  (SgIll  >finlandi !01_S	et	f	\N
138919	finlandisse	?finlandisse =finlandi  (SgIll  >finland !02_S	et	f	\N
138920	finlandisse	?finlandisse =finlandi  (SgIll  >finlant !22_S	et	f	\N
138921	finlandisse	?finlandisse =finlandis  (SgAdt  >finlandis !11_S	et	f	\N
138922	finlandisse	?finlandisse =finlandisse  (SgG  >finlandisne !02_A	et	f	\N
138923	finlandisse	?finlandisse =finlandisse  (PlP  >finlandiss !22_S	et	f	\N
138924	päistab	?päistab =päista  (IndPrSg3  >päistama !27_V	et	f	\N
138926	kaheksast	kaheksast =kaheksa  (SgEl  >kaheksa !01_N	et	f	\N
138927	kaheksast	kaheksast =kaheksas  (SgP  >kaheksane !12_A	et	f	\N
138928	kaheksast	"kaheksane %kaheksa  )NE_aA  <kaheksa ;01_N	et	f	\N
138959	värrikas	?värrikas =värrika  (SgIn  >värrika !01_S	et	f	\N
138960	värrikas	?värrikas =värrika  (SgIn  >värrikas !02_S	et	f	\N
138961	värrikas	?värrikas =värrikas  (SgN  >värrikas !02_S	et	f	\N
138965	augustus	augustus =augustus  (SgN  >augustus !11_S	et	f	\N
138966	augustus	"augustus %augusta  )US_vS  <augustama ;27_V	et	f	\N
138967	pizzad	?pizzad =pizza  (PlN  >pizza !16_S	et	f	\N
138984	lauldest	?lauldest =laulde  (PlEl  >lault !22_S	et	f	\N
138985	lauldest	?lauldest =lauldes  (SgP  >lauldes !09_S	et	f	\N
138986	lauldest	?lauldest =lauldes  (SgP  >lauldene !12~10_A	et	f	\N
138994	taust	taust =tau  (SgEl  >tau !26_S	et	f	\N
138995	taust	taust =taust  (SgN  >taust !22_S	et	f	\N
139001	peatu	peatu =peatu  (SgN  >peatu !01_A	et	f	\N
139002	peatu	"peatu %pea  )TU2_kA  <pea ;26_S	et	f	\N
139003	peatu	peatu =peatu  (SgG  >peatu !01_A	et	f	\N
139004	peatu	peatu =peatu  (IndPrPs_  >peatuma !27_V	et	f	\N
139005	peatu	peatu =peatu  (ImpPrSg2  >peatuma !27_V	et	f	\N
139021	leitavad	leitavad =leitava  (PlN  >leitav !02_A	et	f	\N
139022	leitavad	"leitav %lei  )TAV_vAS  <leidma ;34_V	et	f	\N
139023	leitavad	leitavad =ava  (PlN  >leit+ava !17_S	et	f	\N
139028	mitmehäälselt	mitmehäälselt =häälse  (SgAbl  >mitme+häälne !02_A	et	f	\N
139029	mitmehäälselt	"mitme+häälselt %häälse  )LT_mD  <mitme+häälne ;02_A	et	f	\N
139030	aastase	aastase =aastase  (SgG  >aastane !12~10_A	et	f	\N
139031	aastase	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
139032	aastase	aastase =tase  (SgN  >aas+tase !04_S	et	f	\N
139040	raskuste	raskuste =raskus  (PlG  >raskus !11~09_S	et	f	\N
139041	raskuste	"raskus %raske  )US_aS  <raske ;01_A	et	f	\N
139042	raskuste	raskuste =raskus  (PlG  >raskune !12~10_A	et	f	\N
139050	kuulajale	kuulajale =kuulaja  (SgAll  >kuulaja !01_S	et	f	\N
139051	kuulajale	"kuulaja %kuula  )JA_vS  <kuulama ;29_V	et	f	\N
139052	kuulajale	kuulajale =aja  (SgAll  >kuul+aeg !22_S	et	f	\N
139054	arhiveeritakse	?arhiveeritakse =arhiveeri  (IndPrIps  >arhiveerima !28_V	et	f	\N
138879	t-särgi	t-särgi =särgi  (SgP  >t-särg !22_S	et	f	\N
138880	t-särgi	t-särgi =särgi  (SgAdt  >t-särg !22_S	et	f	\N
138881	t-särgi	t-särgi =särgi  (PlP  >t-särg !22_S	et	f	\N
138897	hapukoore	hapukoore =koore  (SgG  >hapu+koor !13_S	et	f	\N
138898	hapukoore	hapukoore =koore  (PlP  >hapu+koor !22_S	et	f	\N
138901	istan	?istan =ista  (IndPrSg1  >istama !29_V	et	f	\N
138902	istan	?istan =istan  (SgN  >istan !02_S	et	f	\N
138908	äärres	?äärres =äärre  (SgIn  >äärre !06_S	et	f	\N
138909	äärres	?äärres =äärre  (PlIn  >äärr !22_S	et	f	\N
138912	äärres	?äärres =äärre  (IndIpfSg3  >äärrema !27_V	et	f	\N
138914	äärres	?äärres =äärres  (SgN  >äärres !09_S	et	f	\N
138934	tomatikastmet	?tomatikastmet =kastme  (SgP  >tomati+kastme !06_S	et	f	\N
138938	eestilane	eestilane =ilane  (SgN  >eest+ilane !10_A	et	f	\N
138939	eestilane	"eest+ilane %ila  )NE_aA  <eest+ila ;17_S	et	f	\N
138940	eestilane	eestilane =tilane  (SgN  >ees+tilane !10_A	et	f	\N
138941	eestilane	"ees+tilane %tila  )NE_aA  <ees+tila ;17_S	et	f	\N
138976	vanesti	?vanesti =vanesti  (ID  >vanesti !41_D	et	f	\N
138977	vanesti	?vanesti =vanesti  (IndPrPs_  >vanestima !28_V	et	f	\N
138978	vanesti	?vanesti =vanesti  (ImpPrSg2  >vanestima !28_V	et	f	\N
138979	hirmutama	hirmutama =hirmu  (SupIps  >hirmuma !27_V	et	f	\N
138980	hirmutama	hirmutama =hirmuta  (Sup  >hirmutama !27_V	et	f	\N
138987	pulmarongi	pulmarongi =rongi  (SgG  >pulma+rong !22_S	et	f	\N
138988	pulmarongi	pulmarongi =rongi  (SgP  >pulma+rong !22_S	et	f	\N
138989	pulmarongi	pulmarongi =rongi  (SgAdt  >pulma+rong !22_S	et	f	\N
139000	kurvade	?kurvade =kurva  (PlG  >kurva !16_S	et	f	\N
139016	teadavad	?teadavad =teada  (IndPrPl3  >teadama !29_V	et	f	\N
139017	teadavad	?teadavad =teadava  (PlN  >teadava !01_S	et	f	\N
139018	teadavad	?teadavad =teadava  (PlN  >teadav !02_A	et	f	\N
139024	paigal	paigal =paiga  (SgAd  >paik !22_S	et	f	\N
139025	paigal	paigal =paigal  (ID  >paigal !41_D	et	f	\N
139026	suunad	suunad =suuna  (PlN  >suund !22_S	et	f	\N
139027	suunad	suunad =suuna  (IndPrSg2  >suunama !29_V	et	f	\N
139033	põhituuma	põhituuma =tuuma  (SgG  >põhi+tuum !22_S	et	f	\N
139034	põhituuma	põhituuma =tuuma  (SgP  >põhi+tuum !22_S	et	f	\N
139035	põhituuma	põhituuma =tuuma  (SgAdt  >põhi+tuum !22_S	et	f	\N
139057	rietust	?rietust =rietu  (SgEl  >rietu !01_A	et	f	\N
139058	rietust	?rietust =rietus  (SgP  >rietus !11~09_S	et	f	\N
139063	suurest	suurest =suure  (SgEl  >suur !13_A	et	f	\N
139064	suurest	suurest =re  (SgEl  >suu+re !26_S	et	f	\N
139065	suurest	suurest =rest  (SgN  >suu+rest !22_S	et	f	\N
139076	platsile	platsile =platsi  (SgAll  >plats !22_S	et	f	\N
139077	platsile	platsile =si  (SgAll  >plat+si !26_S	et	f	\N
139078	platsile	platsile =sile  (SgN  >plat+sile !02_A	et	f	\N
139079	väikesel	väikesel =väikese  (SgAd  >väike !12?10_A	et	f	\N
139080	väikesel	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
139081	väikesel	väikesel =väikese  (SgAd  >väikene !12?10_A	et	f	\N
139082	väikesel	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
139098	osalejate	osalejate =osaleja  (PlG  >osaleja !01_S	et	f	\N
139099	osalejate	"osaleja %osale  )JA_vS  <osalema ;27_V	et	f	\N
139100	sammusid	sammusid =sammu  (PlP  >samm !22_S	et	f	\N
139101	sammusid	sammusid =sammu  (IndIpfSg2  >sammuma !28_V	et	f	\N
139102	sammusid	sammusid =sammu  (IndIpfPl3  >sammuma !28_V	et	f	\N
139111	ammustest	ammustest =ammus  (PlEl  >ammune !10_A	et	f	\N
139112	ammustest	"ammune %ammu  )NE_aA  <amb ;22_S	et	f	\N
139122	tingimata	tingimata =tingi  (SupAb  >tingima !28_V	et	f	\N
139123	tingimata	tingimata =tingimata  (ID  >tingimata !41_D	et	f	\N
139124	tingimata	"tingimata %tingi  )MATA_vA  <tingima ;28_V	et	f	\N
139125	tingimata	tingimata =ima  (SgAb  >ting+ima !17_S	et	f	\N
139136	kokkupuutumis	kokkupuutumis =puutumi  (SgIn  >kokku+puutum !02_A	et	f	\N
139137	kokkupuutumis	"kokku+puutum %puu  )TUM2_cA  <kokku+puu ;26_S	et	f	\N
139143	tempo	tempo =tempo  (SgN  >tempo !16_S	et	f	\N
139144	tempo	tempo =tempo  (SgG  >tempo !16_S	et	f	\N
139153	märku	märku =märku  (SgP  >märk !22_S	et	f	\N
139154	märku	märku =märku  (SgAdt  >märk !22_S	et	f	\N
139155	käimise	käimise =käimise  (SgG  >käimine !12?10_S	et	f	\N
139156	käimise	"käimine %käi  )MINE_vS  <käima ;38_V	et	f	\N
139157	käimise	"käimine %käimi  )NE_aA  <käim ;22_S	et	f	\N
139196	piiripealsetes	piiripealsetes =sete  (PlIn  >piiri+peal+sett !22_S	et	f	\N
139197	piiripealsetes	piiripealsetes =pealse  (PlIn  >piiri+pealne !02_AS	et	f	\N
139207	laulupidade	?laulupidade =pida  (PlG  >laulu+pida !17_S	et	f	\N
139220	meeskooride	meeskooride =koori  (PlG  >mees+koor !22_S	et	f	\N
139221	meeskooride	meeskooride =skoori  (PlG  >mee+skoor !22_S	et	f	\N
139231	oodatavamaid	oodatavamaid =oodatavama  (PlP  >oodatavam !02_A	et	f	\N
139232	oodatavamaid	"oodatavam %ooda  )TAVAM_cA  <ootama ;29_V	et	f	\N
139233	perepidu	perepidu =pidu  (SgN  >pere+pidu !17_S	et	f	\N
139234	perepidu	perepidu =pidu  (SgN  >pere+pidu !18_S	et	f	\N
139235	perepidu	perepidu =pidu  (SgG  >pere+pidu !17_S	et	f	\N
139236	perepidu	perepidu =pidu  (SgP  >pere+pidu !17_S	et	f	\N
138930	üheteistkümneni	?üheteistkümneni =kümneni  (SgG  >ühe+teist+kümnen !02_S	et	f	\N
138931	üheteistkümneni	?üheteistkümneni =teistkümneni  (SgG  >ühe+teistkümnen !19_S	et	f	\N
138932	üheteistkümneni	?üheteistkümneni =teistkümneni  (SgP  >ühe+teistkümnen !19_S	et	f	\N
138933	üheteistkümneni	?üheteistkümneni =teistkümneni  (SgAdt  >ühe+teistkümnen !19_S	et	f	\N
138956	teanud	?teanud =teanu  (PlN  >teanu !16_S	et	f	\N
138957	teanud	?teanud =teanu  (IndPrSg2  >teanuma !28_V	et	f	\N
138958	teanud	?teanud =teanud  (ID  >teanud !41_A	et	f	\N
138962	tulenud	?tulenud =tulenu  (PlN  >tulenu !01_S	et	f	\N
138963	tulenud	?tulenud =tulenu  (IndPrSg2  >tulenuma !27_V	et	f	\N
138964	tulenud	?tulenud =tulenud  (ID  >tulenud !41_A	et	f	\N
138981	vanest	?vanest =vane  (SgEl  >vane !16_S	et	f	\N
138982	vanest	?vanest =vanes  (SgP  >vanes !09_S	et	f	\N
138983	vanest	?vanest =vanes  (SgP  >vanene !10_A	et	f	\N
138996	tansimisel	?tansimisel =tansimise  (SgAd  >tansimine !12_S	et	f	\N
139019	tõestusi	tõestusi =tõestusi  (PlP  >tõestus !11_S	et	f	\N
139020	tõestusi	"tõestus %tõesta  )US_vS  <tõestama ;27_V	et	f	\N
139036	eripärasust	eripärasust =pärasus  (SgP  >eri+pärasus !11_S	et	f	\N
139037	eripärasust	"eri+pärasus %pära  )SUS_aS  <eri+pära ;17_S	et	f	\N
139086	kollase	kollase =kollase  (SgG  >kollane !10_A	et	f	\N
139087	kollase	"kollane %kolla  )NE_aA  <kold ;22_S	et	f	\N
139090	komsomoli	komsomoli =komsomoli  (SgG  >komsomol !19_S	et	f	\N
139091	komsomoli	komsomoli =komsomoli  (SgP  >komsomol !19_S	et	f	\N
139092	komsomoli	komsomoli =komsomoli  (SgAdt  >komsomol !19_S	et	f	\N
139105	reet	?reet =reet  (SgN  >reet !22_S	et	f	\N
139126	põhitüüpi	põhitüüpi =tüüpi  (SgP  >põhi+tüüp !22_S	et	f	\N
139127	põhitüüpi	põhitüüpi =tüüpi  (SgAdt  >põhi+tüüp !22_S	et	f	\N
139138	saadetud	saadetud =saade  (PtsPtIps  >saatma !34_V	et	f	\N
139139	saadetud	saadetud =saadetu  (PlN  >saadetu !01_S	et	f	\N
139140	saadetud	"saadetu %saade  )TU1_vS  <saatma ;34_V	et	f	\N
139141	saadetud	saadetud =saadetud  (ID  >saadetud !41_A	et	f	\N
139142	saadetud	"saadetud %saade  )TUD_vA  <saatma ;34_V	et	f	\N
139145	rahuolu	rahuolu =olu  (SgN  >rahu+olu !17_S	et	f	\N
139146	rahuolu	rahuolu =olu  (SgG  >rahu+olu !17_S	et	f	\N
139147	rahuolu	rahuolu =olu  (SgP  >rahu+olu !17_S	et	f	\N
139158	edastasid	edastasid =edasta  (IndIpfSg2  >edastama !27_V	et	f	\N
139160	edastasid	edastasid =edasta  (IndIpfPl3  >edastama !27_V	et	f	\N
139172	ritooriliste	?ritooriliste =ritoorilis  (PlG  >ritoorilis !09_S	et	f	\N
139174	ritooriliste	?ritooriliste =ritoorilis  (PlG  >ritooriline !12_A	et	f	\N
139176	ritooriliste	?ritooriliste =ritooriliste  (PlP  >ritoorilist !22_S	et	f	\N
139177	aeglasem	aeglasem =aeglasem  (SgN  >aeglasem !02_A	et	f	\N
139178	aeglasem	"aeglasem %aeglase  )M_cA  <aeglane ;10_A	et	f	\N
139179	aeglasem	"aeglasem %aeglase  )M_cA  <aeglane ;12_A	et	f	\N
139194	puhpilliorkestrite	?puhpilliorkestrite =puhpilliorkestri  (PlG  >puhpilliorkester !02_S	et	f	\N
139195	puhpilliorkestrite	?puhpilliorkestrite =puhpilliorkestri  (IndPrPl2  >puhpilliorkestrima !28_V	et	f	\N
139204	ülemaalise	ülemaalise =maalise  (SgG  >üle+maaline !12?10_A	et	f	\N
139205	ülemaalise	"üle+maaline %maa  )LINE_aA  <üle+maa ;26_S	et	f	\N
139206	ülemaalise	"üle+maaline %maali  )NE_aA  <üle+maal ;22_S	et	f	\N
139222	igapäevasse	igapäevasse =asse  (PlP  >iga+päev+ass !22_S	et	f	\N
139223	igapäevasse	igapäevasse =päeva  (SgIll  >iga+päev !22_S	et	f	\N
139224	peoga	peoga =peo  (SgKom  >pidu !18_S	et	f	\N
139225	peoga	peoga =peo  (SgKom  >peo !26_S	et	f	\N
139255	annabgi	?annabgi =annabgi  (SgN  >annabgi !01_S	et	f	\N
139256	annabgi	?annabgi =annabgi  (SgG  >annabgi !01_S	et	f	\N
139257	annabgi	?annabgi =annabgi  (SgG  >annabg !02_S	et	f	\N
139258	annabgi	?annabgi =annabgi  (IndPrPs_  >annabgima !28_V	et	f	\N
139259	annabgi	?annabgi =annabgi  (ImpPrSg2  >annabgima !28_V	et	f	\N
139278	salmikuid	salmikuid =salmiku  (PlP  >salmik !02_S	et	f	\N
139279	salmikuid	salmikuid =ku  (PlP  >salmi+kuu !26_S	et	f	\N
139282	tsari	?tsari =tsari  (SgN  >tsari !17_S	et	f	\N
139283	tsari	?tsari =tsari  (SgG  >tsari !17_S	et	f	\N
139284	tsari	?tsari =tsari  (SgP  >tsari !17_S	et	f	\N
139285	tsari	?tsari =tsari  (IndPrPs_  >tsarima !27_V	et	f	\N
139286	tsari	?tsari =tsari  (ImpPrSg2  >tsarima !27_V	et	f	\N
139302	silmis	silmis =silmi  (SgIn  >silm !22_S	et	f	\N
139303	silmis	silmis =silmi  (PlIn  >silm !22_S	et	f	\N
139318	festivaalidel	?festivaalidel =festivaali  (PlAd  >festivaali !16_S	et	f	\N
139319	festivaalidel	?festivaalidel =festivaali  (PlAd  >festivaal !22_S	et	f	\N
139323	saavutanud	saavutanud =saavuta  (PtsPtPs  >saavutama !27_V	et	f	\N
139324	saavutanud	saavutanud =saavutanu  (PlN  >saavutanu !01_S	et	f	\N
139325	saavutanud	"saavutanu %saavuta  )NU_vS  <saavutama ;27_V	et	f	\N
139326	saavutanud	saavutanud =saavutanud  (ID  >saavutanud !41_A	et	f	\N
139327	saavutanud	"saavutanud %saavuta  )NUD_vA  <saavutama ;27_V	et	f	\N
139341	oskanud	?oskanud =oskanu  (PlN  >oskanu !01_S	et	f	\N
139342	oskanud	?oskanud =oskanu  (IndPrSg2  >oskanuma !27_V	et	f	\N
139343	oskanud	?oskanud =oskanud  (ID  >oskanud !41_A	et	f	\N
139356	veljo	?veljo =veljo  (SgN  >veljo !16_S	et	f	\N
138955	küsisid	küsisid =küsi  (IndIpfPl3  >küsima !27_V	et	f	\N
138990	festivaalis	?festivaalis =festivaali  (SgIn  >festivaali !16_S	et	f	\N
138991	festivaalis	?festivaalis =festivaali  (SgIn  >festivaal !22_S	et	f	\N
138992	festivaalis	?festivaalis =festivaali  (IndIpfSg3  >festivaalima !28_V	et	f	\N
138993	festivaalis	?festivaalis =festivaalis  (SgN  >festivaalis !09_S	et	f	\N
138997	argipäevaelus	argipäevaelus =elu  (SgIn  >argi+päeva+elu !17_S	et	f	\N
138998	argipäevaelus	argipäevaelus =elus  (SgN  >argi+päeva+elus !02_A	et	f	\N
138999	argipäevaelus	argipäevaelus =aelus  (SgN  >argi+päev+aelus !11~09_S	et	f	\N
139006	ajaloolist	ajaloolist =loolis  (SgP  >aja+looline !12?10_A	et	f	\N
139007	ajaloolist	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
139008	ajaloolist	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
139009	ajaloolist	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
139010	ajaloolist	ajaloolist =loolis  (SgP  >aja+looline !12?10_S	et	f	\N
139014	rahulikke	rahulikke =rahulikke  (PlP  >rahulik !25_A	et	f	\N
139015	rahulikke	rahulikke =ikke  (SgG  >rahul+ike !06_S	et	f	\N
139038	kokkuvõtvalt	kokkuvõtvalt =võtva  (SgAbl  >kokku+võttev !02_A	et	f	\N
139039	kokkuvõtvalt	"kokku+võtvalt %võtva  )LT_mD  <kokku+võttev ;02_A	et	f	\N
139043	sobip	?sobip =sobip  (SgN  >sobip !02_S	et	f	\N
139048	laujat	?laujat =lauja  (SgP  >lauja !01_S	et	f	\N
139049	laujat	?laujat =laujat  (SgN  >laujat !02_S	et	f	\N
139053	rägivärsilise	?rägivärsilise =rägivärsilise  (SgG  >rägivärsiline !12_A	et	f	\N
139061	kurerpillid	?kurerpillid =kurerpilli  (PlN  >kurerpill !22_S	et	f	\N
139062	kurerpillid	?kurerpillid =kurerpilli  (IndPrSg2  >kurerpillima !28_V	et	f	\N
139071	kogunud	kogunud =kogu  (PtsPtPs  >koguma !27_V	et	f	\N
139072	kogunud	kogunud =kogunu  (PlN  >kogunu !01_S	et	f	\N
139073	kogunud	"kogunu %kogu  )NU_vS  <koguma ;27_V	et	f	\N
139074	kogunud	kogunud =kogunud  (ID  >kogunud !41_A	et	f	\N
139075	kogunud	"kogunud %kogu  )NUD_vA  <koguma ;27_V	et	f	\N
139088	mütsike	mütsike =mütsike  (SgN  >mütsike !12_S	et	f	\N
139089	mütsike	"mütsike %mütsi  )KE_dS  <müts ;22_S	et	f	\N
139095	paduvihma	paduvihma =vihma  (SgG  >padu+vihm !22_S	et	f	\N
139096	paduvihma	paduvihma =vihma  (SgP  >padu+vihm !22_S	et	f	\N
139097	paduvihma	paduvihma =vihma  (SgAdt  >padu+vihm !22_S	et	f	\N
139115	riimilisi	riimilisi =riimilisi  (PlP  >riimiline !12_A	et	f	\N
139116	riimilisi	"riimiline %riimi  )LINE_aA  <riim ;22_S	et	f	\N
139133	hoidis	hoidis =hoid  (IndIpfSg3  >hoidma !34_V	et	f	\N
139134	hoidis	hoidis =hoidi  (SgIn  >hoid !22_S	et	f	\N
139135	hoidis	hoidis =hoidis  (SgN  >hoidis !09_S	et	f	\N
139150	kiigutade	### kiigutade	et	f	\N
139151	armastusrohke	armastusrohke =rohke  (SgN  >armastus+rohke !01_A	et	f	\N
139152	armastusrohke	armastusrohke =rohke  (SgG  >armastus+rohke !01_A	et	f	\N
139159	karjapoisid	karjapoisid =poi  (PlP  >karja+poi !26_S	et	f	\N
139161	karjapoisid	karjapoisid =poisi  (PlN  >karja+poiss !23?22_S	et	f	\N
139162	nukruv	nukruv =nukru  (PtsPrPs  >nukruma !27_V	et	f	\N
139163	nukruv	nukruv =nukruv  (SgN  >nukruv !02_A	et	f	\N
139164	nukruv	"nukruv %nukru  )V_vA  <nukruma ;27_V	et	f	\N
139186	regivärsiliste	regivärsiliste =värsilis  (PlG  >regi+värsiline !12_A	et	f	\N
139187	regivärsiliste	"regi+värsiline %värsi  )LINE_aA  <regi+värss ;22_S	et	f	\N
139188	kirikumuusika	kirikumuusika =muusika  (SgN  >kiriku+muusika !01_S	et	f	\N
139189	kirikumuusika	kirikumuusika =muusika  (SgG  >kiriku+muusika !01_S	et	f	\N
139202	ärkamist	ärkamist =ärkamis  (SgP  >ärkamine !12_S	et	f	\N
139203	ärkamist	"ärkamine %ärka  )MINE_vS  <ärkama ;29_V	et	f	\N
139218	jälgides	jälgides =jälgi  (PlIn  >jälg !22_S	et	f	\N
139219	jälgides	jälgides =jälgi  (Ger  >jälgima !27_V	et	f	\N
139244	nõukogu	nõukogu =kogu  (SgN  >nõu+kogu !17_S	et	f	\N
139245	nõukogu	nõukogu =kogu  (SgG  >nõu+kogu !17_S	et	f	\N
139246	nõukogu	nõukogu =kogu  (SgP  >nõu+kogu !17_S	et	f	\N
139247	üld	?üld =üld  (SgN  >üld !22_S	et	f	\N
139251	oelda	?oelda =oelda  (SgN  >oelda !01_S	et	f	\N
139252	oelda	?oelda =oelda  (SgG  >oelda !01_S	et	f	\N
139253	oelda	?oelda =oelda  (IndPrPs_  >oeldama !27_V	et	f	\N
139254	oelda	?oelda =oelda  (ImpPrSg2  >oeldama !27_V	et	f	\N
139270	kussütades	?kussütades =süta  (PlIn  >kus+süta !16_S	et	f	\N
139280	tunnustamise	tunnustamise =tunnustamise  (SgG  >tunnustamine !12_S	et	f	\N
139281	tunnustamise	"tunnustamine %tunnusta  )MINE_vS  <tunnustama ;27_V	et	f	\N
139289	kokkukuuluvust	kokkukuuluvust =kuuluvus  (SgP  >kokku+kuuluvus !11_S	et	f	\N
139290	kokkukuuluvust	"kokku+kuuluvus %kuuluva  )US_aS  <kokku+kuuluv ;02_A	et	f	\N
139293	inimeesi	?inimeesi =inimeesi  (SgN  >inimeesi !16_S	et	f	\N
139294	inimeesi	?inimeesi =inimeesi  (SgG  >inimeesi !16_S	et	f	\N
139295	inimeesi	?inimeesi =inimeesi  (SgG  >inimees !22_S	et	f	\N
139296	inimeesi	?inimeesi =inimeesi  (SgP  >inimees !22_S	et	f	\N
139297	inimeesi	?inimeesi =inimeesi  (SgAdt  >inimees !22_S	et	f	\N
139298	inimeesi	?inimeesi =inimeesi  (IndPrPs_  >inimeesima !28_V	et	f	\N
139299	inimeesi	?inimeesi =inimeesi  (ImpPrSg2  >inimeesima !28_V	et	f	\N
139300	inimeesi	?inimeesi =eesi  (SgN  >inim+eesi !16_S	et	f	\N
139301	inimeesi	?inimeesi =eesi  (SgG  >inim+eesi !16_S	et	f	\N
139046	tahandeid	?tahandeid =tahandei  (PlN  >tahandei !26_S	et	f	\N
139047	tahandeid	?tahandeid =tahandei  (SgP  >tahandei !26_S	et	f	\N
139059	piirivalve	piirivalve =valve  (SgN  >piiri+valve !06_S	et	f	\N
139060	piirivalve	piirivalve =valve  (SgG  >piiri+valve !06_S	et	f	\N
139093	sellistele	sellistele =sellis  (PlAll  >selline !10_P	et	f	\N
139094	sellistele	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
139103	populaarsemaks	populaarsemaks =populaarsema  (SgTr  >populaarsem !02_A	et	f	\N
139104	populaarsemaks	"populaarsem %populaarse  )M_cA  <populaarne ;02_A	et	f	\N
139106	hullu	hullu =hullu  (SgG  >hull !22_AS	et	f	\N
139107	hullu	hullu =hullu  (SgP  >hull !22_AS	et	f	\N
139108	hullu	hullu =hullu  (SgAdt  >hull !22_AS	et	f	\N
139109	hullu	hullu =hullu  (IndPrPs_  >hulluma !27_V	et	f	\N
139110	hullu	hullu =hullu  (ImpPrSg2  >hulluma !27_V	et	f	\N
139113	regivärsilisi	regivärsilisi =värsilisi  (PlP  >regi+värsiline !12_A	et	f	\N
139114	regivärsilisi	"regi+värsiline %värsi  )LINE_aA  <regi+värss ;22_S	et	f	\N
139180	aeglasemat	aeglasemat =aeglasema  (SgP  >aeglasem !02_A	et	f	\N
139181	aeglasemat	"aeglasem %aeglase  )M_cA  <aeglane ;10_A	et	f	\N
139182	aeglasemat	"aeglasem %aeglase  )M_cA  <aeglane ;12_A	et	f	\N
139183	lisandus	lisandus =lisandu  (IndIpfSg3  >lisanduma !27_V	et	f	\N
139184	lisandus	lisandus =lisandus  (SgN  >lisandus !11_S	et	f	\N
139185	lisandus	"lisandus %lisanda  )US_vS  <lisandama ;27_V	et	f	\N
139190	kiruku	?kiruku =kiruku  (SgN  >kiruku !01_S	et	f	\N
139191	kiruku	?kiruku =kiruku  (SgG  >kiruku !01_S	et	f	\N
139192	kiruku	?kiruku =kiruku  (IndPrPs_  >kirukuma !27_V	et	f	\N
139193	kiruku	?kiruku =kiruku  (ImpPrSg2  >kirukuma !27_V	et	f	\N
139198	riimilised	riimilised =riimilise  (PlN  >riimiline !12_A	et	f	\N
139199	riimilised	"riimiline %riimi  )LINE_aA  <riim ;22_S	et	f	\N
139210	kiidetud	kiidetud =kiide  (PtsPtIps  >kiitma !34_V	et	f	\N
139211	kiidetud	kiidetud =kiidetu  (PlN  >kiidetu !01_AS	et	f	\N
139214	kiidetud	"kiidetu %kiide  )TU1_vS  <kiitma ;34_V	et	f	\N
139215	kiidetud	kiidetud =kiidetud  (ID  >kiidetud !41_A	et	f	\N
139216	kiidetud	"kiidetud %kiide  )TUD_vA  <kiitma ;34_V	et	f	\N
139217	üldlaulupidade	?üldlaulupidade =pida  (PlG  >üld+laulu+pida !17_S	et	f	\N
139240	folklöör	?folklöör =folklöör  (SgN  >folklöör !22_S	et	f	\N
139241	folklöör	?folklöör =löör  (SgN  >folk+löör !22_S	et	f	\N
139262	nooremaks	nooremaks =noorema  (SgTr  >noorem !02_A	et	f	\N
139263	nooremaks	"noorem %noore  )M_cA  <noor ;13_AS	et	f	\N
139264	nooremaks	nooremaks =maks  (SgN  >noore+maks !22_S	et	f	\N
139265	nooremaks	nooremaks =ema  (SgTr  >noor+ema !17_S	et	f	\N
139271	pulmi	pulmi =pulmi  (SgG  >pulm !22_S	et	f	\N
139272	pulmi	pulmi =pulmi  (SgP  >pulm !22_S	et	f	\N
139273	pulmi	pulmi =pulmi  (SgAdt  >pulm !22_S	et	f	\N
139274	pulmi	pulmi =pulmi  (PlP  >pulm !22_S	et	f	\N
139275	lindude	lindude =lindu  (PlG  >lind !22_S	et	f	\N
139276	lindude	lindude =ude  (SgN  >lind+ude !04_S	et	f	\N
139287	väljendasid	väljendasid =väljenda  (IndIpfSg2  >väljendama !27_V	et	f	\N
139288	väljendasid	väljendasid =väljenda  (IndIpfPl3  >väljendama !27_V	et	f	\N
139307	teistel	teistel =teis  (PlAd  >teine !12_OP	et	f	\N
139308	teistel	teistel =teis  (PlAd  >teise !12_P	et	f	\N
139309	teistel	teistel =teiste  (PlAd  >teist !22_S	et	f	\N
139316	kaivad	?kaivad =kaiva  (PlN  >kaiva !16_S	et	f	\N
139317	kaivad	?kaivad =kaiva  (IndPrSg2  >kaivama !29_V	et	f	\N
139331	ajalehtedes	ajalehtedes =ede  (SgIn  >aja+leht+ede !16_S	et	f	\N
139332	ajalehtedes	ajalehtedes =lehte  (PlIn  >aja+leht !22_S	et	f	\N
139333	räägitud	räägitud =räägi  (PtsPtIps  >rääkima !28_V	et	f	\N
139334	räägitud	räägitud =räägitu  (PlN  >räägitu !01_AS	et	f	\N
139335	räägitud	"räägitu %räägi  )TU1_vS  <rääkima ;28_V	et	f	\N
139336	räägitud	"räägitu %räägi  )TU2_kA  <rääk ;22_S	et	f	\N
139337	räägitud	räägitud =räägitud  (ID  >räägitud !41_A	et	f	\N
139338	räägitud	"räägitud %räägi  )TUD_vA  <rääkima ;28_V	et	f	\N
139344	tuletavad	tuletavad =tuleta  (IndPrPl3  >tuletama !27_V	et	f	\N
139345	tuletavad	tuletavad =tuletava  (PlN  >tuletav !02_A	et	f	\N
139346	tuletavad	"tuletav %tuleta  )V_vA  <tuletama ;27_V	et	f	\N
139347	tuletavad	tuletavad =tava  (PlN  >tule+tava !17_S	et	f	\N
139348	konkursidel	### konkursidel	et	f	\N
139364	anne	anne =anne  (SgN  >anne !05_S	et	f	\N
139365	anne	anne =anne  (SgN  >anne !06_S	et	f	\N
139383	vaimulikut	?vaimulikut =uliku  (SgP  >vaim+uliku !01_S	et	f	\N
139384	vaimulikut	?vaimulikut =uliku  (SgP  >vaim+ulik !02_S	et	f	\N
139389	birgitta	?birgitta =birgitta  (SgN  >birgitta !01_S	et	f	\N
139390	birgitta	?birgitta =birgitta  (SgG  >birgitta !01_S	et	f	\N
139425	järgivad	järgivad =järgi  (IndPrPl3  >järgima !27_V	et	f	\N
139426	järgivad	järgivad =järgiva  (PlN  >järgiv !02_A	et	f	\N
139427	järgivad	"järgiv %järgi  )V_vA  <järgima ;27_V	et	f	\N
139428	europa	?europa =europa  (SgN  >europa !01_S	et	f	\N
139429	europa	?europa =europa  (SgG  >europa !01_S	et	f	\N
139455	tänäsepäevani	?tänäsepäevani =tänäsepäeva  (SgTer  >tänäsepäeva !16_S	et	f	\N
139055	arhiveeritakse	?arhiveeritakse =arhiveeritakse  (SgG  >arhiveeritakne !02_A	et	f	\N
139056	arhiveeritakse	?arhiveeritakse =arhiveeritakse  (PlP  >arhiveeritaks !22_S	et	f	\N
139066	närvipingest	närvipingest =pinge  (SgEl  >närvi+pinge !06_S	et	f	\N
139067	närvipingest	närvipingest =pinge  (PlEl  >närvi+ping !22_S	et	f	\N
139068	närvipingest	närvipingest =pinge  (PlEl  >närvi+pink !22_S	et	f	\N
139069	närvipingest	närvipingest =pinges  (SgP  >närvi+pingene !12~10_A	et	f	\N
139070	närvipingest	"närvi+pingene %pinge  )NE_aA  <närvi+pinge ;06_S	et	f	\N
139083	kestis	kestis =kest  (IndIpfSg3  >kestma !34_V	et	f	\N
139084	kestis	kestis =kesti  (SgIn  >kest !22_S	et	f	\N
139085	kestis	kestis =kesti  (PlIn  >kest !22_S	et	f	\N
139117	omavad	omavad =oma  (IndPrPl3  >omama !27_V	et	f	\N
139118	omavad	omavad =omava  (PlN  >omav !02_A	et	f	\N
139119	omavad	"omav %oma  )V_vA  <omama ;27_V	et	f	\N
139120	austust	austust =austus  (SgP  >austus !11~09_S	et	f	\N
139121	austust	"austus %austa  )US_vS  <austama ;27_V	et	f	\N
139128	ajalooliseid	ajalooliseid =loolise  (PlP  >aja+looline !10_A	et	f	\N
139129	ajalooliseid	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
139130	ajalooliseid	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
139131	ajalooliseid	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
139132	ajalooliseid	ajalooliseid =loolise  (PlP  >aja+looline !10_S	et	f	\N
139148	toites	toites =toit  (Ger  >toitma !34_V	et	f	\N
139149	toites	toites =toite  (SgIn  >toide !06_S	et	f	\N
139165	igapäevast	igapäevast =ast  (SgN  >iga+päev+ast !22_S	et	f	\N
139166	igapäevast	igapäevast =päeva  (SgEl  >iga+päev !22_S	et	f	\N
139167	igapäevast	igapäevast =päevas  (SgP  >iga+päevane !10_A	et	f	\N
139168	igapäevast	"iga+päevane %päeva  )NE_aA  <iga+päev ;22_S	et	f	\N
139169	esindatud	esindatud =esinda  (PtsPtIps  >esindama !27_V	et	f	\N
139170	esindatud	esindatud =esindatu  (PlN  >esindatu !01_S	et	f	\N
139171	esindatud	"esindatu %esinda  )TU1_vS  <esindama ;27_V	et	f	\N
139173	esindatud	esindatud =esindatud  (ID  >esindatud !41_A	et	f	\N
139175	esindatud	"esindatud %esinda  )TUD_vA  <esindama ;27_V	et	f	\N
139200	tähendasid	tähendasid =tähenda  (IndIpfSg2  >tähendama !27_V	et	f	\N
139201	tähendasid	tähendasid =tähenda  (IndIpfPl3  >tähendama !27_V	et	f	\N
139208	näitamine	näitamine =näitamine  (SgN  >näitamine !12_S	et	f	\N
139209	näitamine	"näitamine %näita  )MINE_vS  <näitama ;29_V	et	f	\N
139212	valitsejate	valitsejate =valitseja  (PlG  >valitseja !01_S	et	f	\N
139213	valitsejate	"valitseja %valitse  )JA_vS  <valitsema ;27_V	et	f	\N
139226	üli	?üli =üli  (SgN  >üli !17_S	et	f	\N
139227	üli	?üli =üli  (SgG  >üli !17_S	et	f	\N
139228	üli	?üli =üli  (SgP  >üli !17_S	et	f	\N
139229	üli	?üli =üli  (IndPrPs_  >ülima !27_V	et	f	\N
139230	üli	?üli =üli  (ImpPrSg2  >ülima !27_V	et	f	\N
139238	lootes	lootes =loot  (Ger  >lootma !34_V	et	f	\N
139239	lootes	lootes =loote  (SgIn  >loode !06_S	et	f	\N
139248	kajastavad	kajastavad =kajasta  (IndPrPl3  >kajastama !27_V	et	f	\N
139249	kajastavad	kajastavad =kajastava  (PlN  >kajastav !02_A	et	f	\N
139250	kajastavad	"kajastav %kajasta  )V_vA  <kajastama ;27_V	et	f	\N
139260	voimalust	?voimalust =voimalu  (SgEl  >voimalu !01_S	et	f	\N
139261	voimalust	?voimalust =voimalus  (SgP  >voimalus !11_S	et	f	\N
139266	saatel	saatel =saate  (SgAd  >saade !06_S	et	f	\N
139267	saatel	saatel =saatel  (ID  >saatel !41_K	et	f	\N
139277	ki	### ki	et	f	\N
139291	määletan	?määletan =määleta  (IndPrSg1  >määletama !27_V	et	f	\N
139292	määletan	?määletan =määletan  (SgN  >määletan !19_S	et	f	\N
139310	aastasse	aastasse =aasta  (SgIll  >aasta !01_S	et	f	\N
139311	aastasse	aastasse =aastas  (SgAdt  >aastane !12_A	et	f	\N
139312	aastasse	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
139313	aastasse	aastasse =tasse  (PlP  >aas+tass !22_S	et	f	\N
139320	konkursitel	?konkursitel =konkursi  (PlAd  >konkursi !01_S	et	f	\N
139321	konkursitel	?konkursitel =konkursi  (PlAd  >konkurs !02_S	et	f	\N
139322	konkursitel	?konkursitel =konkursite  (PlAd  >konkursitt !22_S	et	f	\N
139349	rahvusmuusika	rahvusmuusika =muusika  (SgN  >rahvus+muusika !01_S	et	f	\N
139350	rahvusmuusika	rahvusmuusika =muusika  (SgG  >rahvus+muusika !01_S	et	f	\N
139374	sündimusest	sündimusest =sündimuse  (SgEl  >sündimus !11_S	et	f	\N
139375	sündimusest	sündimusest =sündimuses  (SgP  >sündimusene !12_A	et	f	\N
139376	sündimusest	"sündimusene %sündimuse  )NE_aA  <sündimus ;11_S	et	f	\N
139381	erinevaks	erinevaks =erineva  (SgTr  >erinev !02_A	et	f	\N
139382	erinevaks	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
139385	muusitseerima	?muusitseerima =muusitseeri  (Sup  >muusitseerima !28_V	et	f	\N
139386	muusitseerima	?muusitseerima =muusitseerima  (SgG  >muusitseerim !02_A	et	f	\N
139387	muusitseerima	?muusitseerima =eerima  (SgG  >muu+sits+eerim !02_A	et	f	\N
139388	muusitseerima	?muusitseerima =sitseerima  (SgG  >muu+sitseerim !02_A	et	f	\N
139430	taju	taju =taju  (SgN  >taju !17_S	et	f	\N
139431	taju	taju =taju  (SgG  >taju !17_S	et	f	\N
139432	taju	taju =taju  (SgP  >taju !17_S	et	f	\N
139433	taju	taju =taju  (IndPrPs_  >tajuma !27_V	et	f	\N
139237	perepidu	perepidu =pidu  (SgP  >pere+pidu !18_S	et	f	\N
139242	leigarid	?leigarid =leigari  (PlN  >leigari !01_S	et	f	\N
139243	leigarid	?leigarid =leigari  (PlN  >leigar !02_S	et	f	\N
139268	karjamaal	karjamaal =maa  (SgAd  >karja+maa !26_S	et	f	\N
139269	karjamaal	karjamaal =maal  (SgN  >karja+maal !22_S	et	f	\N
139330	sajande	### sajande	et	f	\N
139351	põlvkonnad	põlvkonnad =põlvkonna  (PlN  >põlvkond !22_S	et	f	\N
139352	põlvkonnad	põlvkonnad =konna  (PlN  >põlv+konn !22_S	et	f	\N
139353	tundavad	?tundavad =tunda  (IndPrPl3  >tundama !29_V	et	f	\N
139354	tundavad	?tundavad =tundava  (PlN  >tundava !01_S	et	f	\N
139355	tundavad	?tundavad =tundava  (PlN  >tundav !02_A	et	f	\N
139361	lauluses	?lauluses =lauluse  (SgIn  >laulus !11~09_S	et	f	\N
139362	lauluses	?lauluses =luse  (SgIn  >lau+luse !16_S	et	f	\N
139363	lauluses	?lauluses =luses  (SgN  >lau+luses !09_S	et	f	\N
139370	tõendavad	tõendavad =tõenda  (IndPrPl3  >tõendama !27_V	et	f	\N
139371	tõendavad	tõendavad =tõendava  (PlN  >tõendav !02_A	et	f	\N
139372	tõendavad	"tõendav %tõenda  )V_vA  <tõendama ;27_V	et	f	\N
139373	tõendavad	tõendavad =ava  (PlN  >tõend+ava !17_S	et	f	\N
139406	kuulnudki	kuulnudki =kuul  (PtsPtPs^  >kuulma !33_V	et	f	\N
139407	kuulnudki	kuulnudki =kuulnu  (PlN^  >kuulnu !01_S	et	f	\N
139408	kuulnudki	"kuulnu %kuul  )NU_vS^  <kuulma ;33_V	et	f	\N
139409	kuulnudki	kuulnudki =kuulnud  (ID^  >kuulnud !41_A	et	f	\N
139410	kuulnudki	"kuulnud %kuul  )NUD_vA^  <kuulma ;33_V	et	f	\N
139420	rahvaslikeks	?rahvaslikeks =rahvaslike  (PlTr  >rahvaslik !25_A	et	f	\N
139421	rahvaslikeks	?rahvaslikeks =slike  (PlTr  >rahva+slikk !22_S	et	f	\N
139422	eeskuju	eeskuju =kuju  (SgN  >ees+kuju !17_S	et	f	\N
139423	eeskuju	eeskuju =kuju  (SgG  >ees+kuju !17_S	et	f	\N
139424	eeskuju	eeskuju =kuju  (SgP  >ees+kuju !17_S	et	f	\N
139468	emotsionalsed	?emotsionalsed =emotsionalse  (PlN  >emotsionalne !02_A	et	f	\N
139469	puhkpilliorkestrik	?puhkpilliorkestrik =puhkpilliorkestrik  (SgN  >puhkpilliorkestrik !02_S	et	f	\N
139470	puhkpilliorkestrik	?puhkpilliorkestrik =orkestrik  (SgN  >puhk+pilli+orkestrik !25_S	et	f	\N
139471	puhkpilliorkestrik	?puhkpilliorkestrik =pilliorkestrik  (SgN  >puhk+pilliorkestrik !02_S	et	f	\N
139476	põlvas	?põlvas =põlva  (SgIn  >põlva !16_S	et	f	\N
139478	põlvas	?põlvas =põlva  (IndIpfSg3  >põlvama !29_V	et	f	\N
139479	põlvas	?põlvas =põlvas  (SgN  >põlvas !07_S	et	f	\N
139480	rahvasluse	?rahvasluse =rahvasluse  (SgG  >rahvaslus !11_S	et	f	\N
139481	rahvasluse	?rahvasluse =sluse  (SgN  >rahva+sluse !16_S	et	f	\N
139482	rahvasluse	?rahvasluse =sluse  (SgG  >rahva+sluse !16_S	et	f	\N
139483	mõttedest	?mõttedest =mõttedes  (SgP  >mõttedene !12_A	et	f	\N
139488	rahvamaal	rahvamaal =maa  (SgAd  >rahva+maa !26_S	et	f	\N
139489	rahvamaal	rahvamaal =maal  (SgN  >rahva+maal !22_S	et	f	\N
139512	tegija	tegija =tegija  (SgN  >tegija !01_S	et	f	\N
139513	tegija	"tegija %tegi  )JA_vS  <tegema ;28_V	et	f	\N
139514	tegija	tegija =tegija  (SgG  >tegija !01_S	et	f	\N
139515	sündmusest	sündmusest =sündmuse  (SgEl  >sündmus !11~09_S	et	f	\N
139516	sündmusest	sündmusest =sündmuses  (SgP  >sündmusene !12_A	et	f	\N
139517	sündmusest	"sündmusene %sündmuse  )NE_aA  <sündmus ;09_S	et	f	\N
139518	sündmusest	"sündmusene %sündmuse  )NE_aA  <sündmus ;11_S	et	f	\N
139554	tahmist	tahmist =tahmi  (SgEl  >tahm !22_S	et	f	\N
139555	tahmist	tahmist =tahmis  (SgP  >tahmine !10_A	et	f	\N
139556	tahmist	"tahmine %tahmi  )NE_aA  <tahm ;22_S	et	f	\N
139573	kunstikultuuri	kunstikultuuri =kultuuri  (SgG  >kunsti+kultuur !22_S	et	f	\N
139574	kunstikultuuri	kunstikultuuri =kultuuri  (SgP  >kunsti+kultuur !22_S	et	f	\N
139575	kunstikultuuri	kunstikultuuri =kultuuri  (SgAdt  >kunsti+kultuur !22_S	et	f	\N
139580	laulurahvasena	laulurahvasena =rahvase  (SgEs  >laulu+rahvane !10_A	et	f	\N
139581	laulurahvasena	"laulu+rahvane %rahva  )NE_aA  <laulu+rahvas ;07_S	et	f	\N
139601	eurovisiooni	eurovisiooni =visiooni  (SgG  >euro+visioon !22_S	et	f	\N
139602	eurovisiooni	eurovisiooni =visiooni  (SgP  >euro+visioon !22_S	et	f	\N
139603	eurovisiooni	eurovisiooni =visiooni  (SgAdt  >euro+visioon !22_S	et	f	\N
139615	töötamist	töötamist =töötamis  (SgP  >töötamine !12_S	et	f	\N
139616	töötamist	"töötamine %tööta  )MINE_vS  <töötama ;27_V	et	f	\N
139624	üürituseid	?üürituseid =üüritusei  (PlN  >üüritusei !26_S	et	f	\N
139625	üürituseid	?üürituseid =üüritusei  (SgP  >üüritusei !26_S	et	f	\N
139626	üürituseid	?üürituseid =tusei  (PlN  >üüri+tusei !26_S	et	f	\N
139627	üürituseid	?üürituseid =tusei  (SgP  >üüri+tusei !26_S	et	f	\N
139628	üürituseid	?üürituseid =tuseid  (SgN  >üüri+tuseid !22_S	et	f	\N
139641	abistavad	abistavad =abista  (IndPrPl3  >abistama !27_V	et	f	\N
139642	abistavad	abistavad =abistava  (PlN  >abistav !02_A	et	f	\N
139643	abistavad	"abistav %abista  )V_vA  <abistama ;27_V	et	f	\N
139647	õnnelikkuks	?õnnelikkuks =õnnelikku  (KndPrPs  >õnnelikkuma !27_V	et	f	\N
139654	proffessionaalse	?proffessionaalse =proffessionaalse  (SgG  >proffessionaalne !02_A	et	f	\N
139655	proffessionaalse	?proffessionaalse =proffessionaalse  (PlP  >proffessionaals !22_S	et	f	\N
139665	rahvariide	rahvariide =riide  (SgG  >rahva+riie !06_S	et	f	\N
139666	rahvariide	rahvariide =riide  (PlP  >rahva+riid !22_S	et	f	\N
139304	esine	esine =esine  (SgN  >esine !10_AS	et	f	\N
139305	esine	esine =esine  (IndPrPs_  >esinema !27_V	et	f	\N
139306	esine	esine =esine  (ImpPrSg2  >esinema !27_V	et	f	\N
139314	televisioonist	televisioonist =televisiooni  (SgEl  >televisioon !22_S	et	f	\N
139315	televisioonist	televisioonist =visiooni  (SgEl  >tele+visioon !22_S	et	f	\N
139328	nokia	?nokia =nokia  (SgN  >nokia !01_S	et	f	\N
139329	nokia	?nokia =nokia  (SgG  >nokia !01_S	et	f	\N
139339	hüüdi	hüüdi =hüüdi  (SgP  >hüüd !22_S	et	f	\N
139340	hüüdi	hüüdi =hüüdi  (SgAdt  >hüüd !22_S	et	f	\N
139358	toormise	?toormise =toormise  (SgG  >toormine !12?10_A	et	f	\N
139359	toormise	?toormise =toormise  (IndPrPs_  >toormisema !27_V	et	f	\N
139360	toormise	?toormise =toormise  (ImpPrSg2  >toormisema !27_V	et	f	\N
139377	toimetusel	toimetusel =toimetuse  (SgAd  >toimetus !11_S	et	f	\N
139378	toimetusel	"toimetus %toimeta  )US_vS  <toimetama ;27_V	et	f	\N
139379	toimetusel	"toimetus %toime  )TUS2_aS  <toime ;06_S	et	f	\N
139380	toimetusel	"toimetus %toime  )TUS2_aS  <toim ;22_S	et	f	\N
139391	brigitta	?brigitta =brigitta  (SgN  >brigitta !01_S	et	f	\N
139392	brigitta	?brigitta =brigitta  (SgG  >brigitta !01_S	et	f	\N
139411	hiphopp	?hiphopp =hiphopp  (SgN  >hiphopp !22_S	et	f	\N
139412	meeldivat	meeldivat =meeldi  (KvtPrPs  >meeldima !27_V	et	f	\N
139413	meeldivat	meeldivat =meeldiva  (SgP  >meeldiv !02_A	et	f	\N
139414	meeldivat	"meeldiv %meeldi  )V_vA  <meeldima ;27_V	et	f	\N
139415	nje	### nje	et	f	\N
139416	kuulaja	kuulaja =kuulaja  (SgN  >kuulaja !01_S	et	f	\N
139417	kuulaja	"kuulaja %kuula  )JA_vS  <kuulama ;29_V	et	f	\N
139418	kuulaja	kuulaja =kuulaja  (SgG  >kuulaja !01_S	et	f	\N
139419	kuulaja	kuulaja =aja  (SgG  >kuul+aeg !22_S	et	f	\N
139437	erakorraldati	?erakorraldati =erakorralda  (IndIpfIps  >erakorraldama !27_V	et	f	\N
139438	erakorraldati	?erakorraldati =erakorraldati  (SgG  >erakorraldatt !22_S	et	f	\N
139439	erakorraldati	?erakorraldati =erakorraldati  (IndPrPs_  >erakorraldattima !28_V	et	f	\N
139440	erakorraldati	?erakorraldati =erakorraldati  (ImpPrSg2  >erakorraldattima !28_V	et	f	\N
139441	erakorraldati	?erakorraldati =korraldati  (SgG  >era+korraldatt !22_S	et	f	\N
139466	pillides	pillides =pilli  (PlIn  >pill !22_S	et	f	\N
139467	pillides	pillides =pilli  (Ger  >pillima !28_V	et	f	\N
139474	jõhvi	jõhvi =jõhvi  (SgG  >jõhv !22_S	et	f	\N
139475	jõhvi	jõhvi =jõhvi  (SgP  >jõhv !22_S	et	f	\N
139477	jõhvi	jõhvi =jõhvi  (SgAdt  >jõhv !22_S	et	f	\N
139499	videolõiged	### videolõiged	et	f	\N
139502	hingamisest	hingamisest =hingamise  (SgEl  >hingamine !12_S	et	f	\N
139503	hingamisest	"hingamine %hinga  )MINE_vS  <hingama ;29_V	et	f	\N
139510	arus	arus =aru  (SgIn  >aru !17_S	et	f	\N
139511	arus	arus =aru  (PlIn  >arg !22_A	et	f	\N
139531	emalaul	emalaul =lau  (SgAd  >ema+laug !22_SA	et	f	\N
139532	emalaul	emalaul =laul  (SgN  >ema+laul !22_S	et	f	\N
139537	nurgadest	?nurgadest =nurga  (PlEl  >nurga !16_S	et	f	\N
139539	nurgadest	?nurgadest =nurgades  (SgP  >nurgadene !12_A	et	f	\N
139545	hetkeks	hetkeks =hetke  (SgTr  >hetk !22_S	et	f	\N
139546	hetkeks	hetkeks =hetke  (PlTr  >hetk !22_S	et	f	\N
139549	vapustanud	vapustanud =vapusta  (PtsPtPs  >vapustama !27_V	et	f	\N
139550	vapustanud	vapustanud =vapustanu  (PlN  >vapustanu !01_S	et	f	\N
139551	vapustanud	"vapustanu %vapusta  )NU_vS  <vapustama ;27_V	et	f	\N
139552	vapustanud	vapustanud =vapustanud  (ID  >vapustanud !41_A	et	f	\N
139553	vapustanud	"vapustanud %vapusta  )NUD_vA  <vapustama ;27_V	et	f	\N
139576	koraalilaulud	?koraalilaulud =koraalilaulu  (IndPrSg2  >koraalilauluma !27_V	et	f	\N
139604	taneli	?taneli =taneli  (ID  >taneli !41_D	et	f	\N
139605	taneli	?taneli =taneli  (SgG  >tanel !02_S	et	f	\N
139644	häädas	?häädas =hääda  (SgIn  >hääda !16_S	et	f	\N
139645	häädas	?häädas =hääda  (IndIpfSg3  >häädama !29_V	et	f	\N
139646	häädas	?häädas =häädas  (SgN  >häädas !07_S	et	f	\N
139672	loodustega	loodustega =loodus  (PlKom  >loodus !11~09_S	et	f	\N
139673	loodustega	"loodus %loo  )TUS1_aS  <looma ;38_V	et	f	\N
139674	tegivad	?tegivad =tegi  (IndPrPl3  >tegima !27_V	et	f	\N
139675	tegivad	?tegivad =tegiva  (PlN  >tegiva !01_S	et	f	\N
139677	tegivad	?tegivad =tegiva  (PlN  >tegiv !02_A	et	f	\N
139682	lootusest	lootusest =lootuse  (SgEl  >lootus !11~09_S	et	f	\N
139683	lootusest	"lootus %loo  )TUS2_aS  <lugu ;18_S	et	f	\N
139684	lootusest	"lootus %loo  )TUS2_aS  <loog ;22_S	et	f	\N
139685	lootusest	"lootus %loo  )TUS2_aS  <lood ;22_S	et	f	\N
139686	lootusest	lootusest =lootuses  (SgP  >lootusene !12_A	et	f	\N
139687	lootusest	"lootusene %lootuse  )NE_aA  <lootus ;09_S	et	f	\N
139688	lootusest	"lootusene %lootuse  )NE_aA  <lootus ;11_S	et	f	\N
139704	sailinud	?sailinud =saili  (PtsPtPs  >sailima !28_V	et	f	\N
139705	sailinud	?sailinud =sailinu  (PlN  >sailinu !01_S	et	f	\N
139706	sailinud	?sailinud =sailinu  (IndPrSg2  >sailinuma !27_V	et	f	\N
139707	sailinud	?sailinud =sailinud  (ID  >sailinud !41_A	et	f	\N
139708	sailinud	?sailinud =linu  (PlN  >sai+linu !17_S	et	f	\N
139709	põlvkonnast	põlvkonnast =põlvkonna  (SgEl  >põlvkond !22_S	et	f	\N
139710	põlvkonnast	põlvkonnast =põlvkonnas  (SgP  >põlvkonnane !12_A	et	f	\N
139357	veljo	?veljo =veljo  (SgG  >veljo !16_S	et	f	\N
139366	kultuurinähtis	?kultuurinähtis =kultuurinähti  (IndIpfSg3  >kultuurinähtima !28_V	et	f	\N
139367	kultuurinähtis	?kultuurinähtis =kultuurinähtis  (SgN  >kultuurinähtis !09_S	et	f	\N
139368	kultuurinähtis	?kultuurinähtis =nähtis  (SgN  >kultuuri+nähtis !09_S	et	f	\N
139369	kultuurinähtis	?kultuurinähtis =inähtis  (SgN  >kultuur+inähtis !11_S	et	f	\N
139393	külastajad	külastajad =külastaja  (PlN  >külastaja !01_S	et	f	\N
139394	külastajad	"külastaja %külasta  )JA_vS  <külastama ;27_V	et	f	\N
139395	ülemaailne	?ülemaailne =ülemaailne  (SgN  >ülemaailne !02_A	et	f	\N
139396	ülemaailne	?ülemaailne =ülemaailne  (PlP  >ülemaailn !22_S	et	f	\N
139397	ülemaailne	?ülemaailne =ilne  (SgN  >üle+maa+ilne !02_A	et	f	\N
139398	ülemaailne	?ülemaailne =ilne  (PlP  >üle+maa+iln !22_S	et	f	\N
139399	ülemaailne	?ülemaailne =aailne  (SgN  >ülem+aailne !02_A	et	f	\N
139400	ülemaailne	?ülemaailne =aailne  (PlP  >ülem+aailn !22_S	et	f	\N
139401	ülemaailne	?ülemaailne =maailne  (SgN  >üle+maailne !02_A	et	f	\N
139402	ülemaailne	?ülemaailne =maailne  (PlP  >üle+maailn !22_S	et	f	\N
139403	kommetest	kommetest =komme  (PlEl  >komme !06_S	et	f	\N
139404	kommetest	kommetest =me  (PlEl  >kom+mesi !15_S	et	f	\N
139405	kommetest	kommetest =mete  (PlEl  >kom+mett !22_S	et	f	\N
139435	laulupärimust	laulupärimust =must  (SgN  >laulu+päri+must !22_AS	et	f	\N
139436	laulupärimust	laulupärimust =pärimus  (SgP  >laulu+pärimus !11_S	et	f	\N
139445	tantsurahvapidu	tantsurahvapidu =pidu  (SgN  >tantsu+rahva+pidu !17_S	et	f	\N
139446	tantsurahvapidu	tantsurahvapidu =pidu  (SgN  >tantsu+rahva+pidu !18_S	et	f	\N
139447	tantsurahvapidu	tantsurahvapidu =pidu  (SgG  >tantsu+rahva+pidu !17_S	et	f	\N
139448	tantsurahvapidu	tantsurahvapidu =pidu  (SgP  >tantsu+rahva+pidu !17_S	et	f	\N
139449	tantsurahvapidu	tantsurahvapidu =pidu  (SgP  >tantsu+rahva+pidu !18_S	et	f	\N
139450	järgivat	järgivat =järgi  (KvtPrPs  >järgima !27_V	et	f	\N
139451	järgivat	järgivat =järgiva  (SgP  >järgiv !02_A	et	f	\N
139452	järgivat	"järgiv %järgi  )V_vA  <järgima ;27_V	et	f	\N
139459	ivo	?ivo =ivo  (SgN  >ivo !17~16_S	et	f	\N
139460	ivo	?ivo =ivo  (SgG  >ivo !17~16_S	et	f	\N
139461	ivo	?ivo =ivo  (SgP  >ivo !17_S	et	f	\N
139462	pisikesed	pisikesed =pisikese  (PlN  >pisike !12_A	et	f	\N
139463	pisikesed	pisikesed =pisikese  (PlN  >pisikene !12_A	et	f	\N
139490	tad	### tad	et	f	\N
139500	südamest	südamest =südame  (SgEl  >süda !04_S	et	f	\N
139501	südamest	südamest =mest  (SgN  >süda+mest !22_S	et	f	\N
139528	isamaalaulu	isamaalaulu =laulu  (SgG  >isa+maa+laul !22_S	et	f	\N
139529	isamaalaulu	isamaalaulu =laulu  (SgP  >isa+maa+laul !22_S	et	f	\N
139530	isamaalaulu	isamaalaulu =laulu  (SgAdt  >isa+maa+laul !22_S	et	f	\N
139533	väikestest	väikestest =väikes  (PlEl  >väike !12?10_A	et	f	\N
139534	väikestest	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
139535	väikestest	väikestest =väikes  (PlEl  >väikene !12?10_A	et	f	\N
139536	väikestest	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
139538	väikestest	väikestest =keste  (SgEl  >väi+keste !06_S	et	f	\N
139540	väikestest	väikestest =keste  (PlEl  >väi+kest !22_S	et	f	\N
139541	väikestest	väikestest =kestes  (SgP  >väi+kestene !12~10_A	et	f	\N
139542	väikestest	"väi+kestene %keste  )NE_aA  <väi+keste ;06_S	et	f	\N
139543	pidudele	pidudele =pidu  (PlAll  >pidu !17_S	et	f	\N
139544	pidudele	pidudele =pidu  (PlAll  >pidu !18_S	et	f	\N
139562	rõmsad	?rõmsad =rõmsa  (PlN  >rõmsa !16_S	et	f	\N
139563	rõmsad	?rõmsad =rõmsa  (IndPrSg2  >rõmsama !29_V	et	f	\N
139582	põllutööd	põllutööd =töö  (PlN  >põllu+töö !26_S	et	f	\N
139583	põllutööd	põllutööd =töö  (SgP  >põllu+töö !26_S	et	f	\N
139584	lehma	lehma =lehma  (SgG  >lehm !22_S	et	f	\N
139585	lehma	lehma =lehma  (SgP  >lehm !22_S	et	f	\N
139586	lehma	lehma =lehma  (SgAdt  >lehm !22_S	et	f	\N
139587	hobu	hobu =hobu  (SgN  >hobu !17_S	et	f	\N
139588	hobu	hobu =hobu  (SgG  >hobu !17_S	et	f	\N
139589	hobu	hobu =hobu  (SgP  >hobu !17_S	et	f	\N
139590	kombe	kombe =kombe  (ID  >kombe !41_D	et	f	\N
139591	kombe	kombe =kombe  (SgN  >kombe !06_S	et	f	\N
139592	kombe	kombe =kombe  (SgG  >komme !06_S	et	f	\N
139593	pingedest	pingedest =ede  (SgEl  >ping+ede !16_S	et	f	\N
139594	pingedest	pingedest =edes  (SgP  >ping+edene !10_A	et	f	\N
139595	pingedest	"ping+edene %ede  )NE_aA  <ping+ede ;16_S	et	f	\N
139606	paderi	?paderi =paderi  (SgN  >paderi !01_S	et	f	\N
139607	paderi	?paderi =paderi  (SgG  >paderi !01_S	et	f	\N
139608	paderi	?paderi =paderi  (SgG  >pader !02_S	et	f	\N
139629	laulurahvade	?laulurahvade =laulurahva  (PlG  >laulurahva !16_S	et	f	\N
139630	laulurahvade	?laulurahvade =rahva  (PlG  >laulu+rahva !16_S	et	f	\N
139638	laste-	laste- =las  (PlG  >laps !14_S	et	f	\N
139639	laste-	laste- =laste  (PlP  >last !22_S	et	f	\N
139640	söltub	?söltub =söltu  (IndPrSg3  >söltuma !27_V	et	f	\N
139648	valjenusvahed	### valjenusvahed	et	f	\N
139649	toimusse	?toimusse =toimu  (SgIll  >toimu !16_S	et	f	\N
139650	toimusse	?toimusse =toimus  (SgAdt  >toimus !11_S	et	f	\N
139651	toimusse	?toimusse =toimusse  (SgG  >toimusne !02_A	et	f	\N
139434	taju	taju =taju  (ImpPrSg2  >tajuma !27_V	et	f	\N
139442	põhimõttelised	põhimõttelised =mõttelise  (PlN  >põhi+mõtteline !12_A	et	f	\N
139443	põhimõttelised	"põhi+mõtteline %mõtte  )LINE_aA  <põhi+mõte ;06_S	et	f	\N
139444	seitsekümmend	?seitsekümmend =seitsekümmend  (SgN  >seitsekümmend !22_S	et	f	\N
139453	uuemat	uuemat =uuema  (SgP  >uuem !02_A	et	f	\N
139454	uuemat	"uuem %uue  )M_cA  <uus ;14_A	et	f	\N
139457	noorused	noorused =nooruse  (PlN  >noorus !11~09_S	et	f	\N
139458	noorused	"noorus %noor  )US_aS  <noor ;13_AS	et	f	\N
139464	kõikjadel	?kõikjadel =jade  (SgAd  >kõik+jade !16_S	et	f	\N
139465	kõikjadel	?kõikjadel =jadel  (SgN  >kõik+jadel !02_S	et	f	\N
139472	kirikukooris	kirikukooris =koori  (SgIn  >kiriku+koor !22_S	et	f	\N
139473	kirikukooris	kirikukooris =koori  (PlIn  >kiriku+koor !13_S	et	f	\N
139484	vabadusest	vabadusest =vabaduse  (SgEl  >vabadus !11_S	et	f	\N
139485	vabadusest	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
139486	vabadusest	vabadusest =vabaduses  (SgP  >vabadusene !12_A	et	f	\N
139487	vabadusest	"vabadusene %vabaduse  )NE_aA  <vabadus ;11_S	et	f	\N
139491	gümni	?gümni =gümni  (SgN  >gümni !16_S	et	f	\N
139492	gümni	?gümni =gümni  (SgG  >gümni !16_S	et	f	\N
139493	gümni	?gümni =gümni  (SgG  >gümn !22_S	et	f	\N
139494	gümni	?gümni =gümni  (SgP  >gümn !22_S	et	f	\N
139495	gümni	?gümni =gümni  (SgAdt  >gümn !22_S	et	f	\N
139496	gümni	?gümni =gümni  (IndPrPs_  >gümnima !28_V	et	f	\N
139497	gümni	?gümni =gümni  (ImpPrSg2  >gümnima !28_V	et	f	\N
139498	ajadel	?ajadel =aja  (PlAd  >aja !17_S	et	f	\N
139504	sündisest	?sündisest =sündise  (SgEl  >sündis !09_S	et	f	\N
139505	sündisest	?sündisest =sündises  (SgP  >sündisene !12_A	et	f	\N
139547	seto	?seto =seto  (SgN  >seto !16_S	et	f	\N
139548	seto	?seto =seto  (SgG  >seto !16_S	et	f	\N
139557	jääme	jääme =jää  (IndPrPl1  >jääma !37_V	et	f	\N
139558	jääme	jääme =jääme  (PlP  >jääm !22_S	et	f	\N
139564	vanavanemate	vanavanemate =vanema  (PlG  >vana+vanem !02_AS	et	f	\N
139565	vanavanemate	"vana+vanem %vane  )M_cA  <vana+vana ;17_AS	et	f	\N
139577	pida	?pida =pida  (SgN  >pida !17_S	et	f	\N
139578	pida	?pida =pida  (SgG  >pida !17_S	et	f	\N
139579	pida	?pida =pida  (SgP  >pida !17_S	et	f	\N
139596	traditsioonilised	traditsioonilised =traditsioonilise  (PlN  >traditsiooniline !12_A	et	f	\N
139597	traditsioonilised	"traditsiooniline %traditsiooni  )LINE_aA  <traditsioon ;22_S	et	f	\N
139598	korjavad	korjavad =korja  (IndPrPl3  >korjama !29_V	et	f	\N
139599	korjavad	korjavad =korjava  (PlN  >korjav !02_A	et	f	\N
139600	korjavad	"korjav %korja  )V_vA  <korjama ;29_V	et	f	\N
139609	deiv	?deiv =deiv  (SgN  >deiv !22_S	et	f	\N
139622	popmuusikale	popmuusikale =muusika  (SgAll  >pop+muusika !01_S	et	f	\N
139623	popmuusikale	popmuusikale =muusikale  (PlP  >pop+muusikal !19_S	et	f	\N
139631	plaksud	plaksud =plaksu  (PlN  >plaks !22_S	et	f	\N
139632	plaksud	plaksud =plaksu  (IndPrSg2  >plaksuma !28_V	et	f	\N
139659	rahvapeost	rahvapeost =peo  (SgEl  >rahva+pidu !18_S	et	f	\N
139660	rahvapeost	rahvapeost =peo  (SgEl  >rahva+peo !26_S	et	f	\N
139676	luletusi	?luletusi =luletusi  (PlP  >luletus !11_S	et	f	\N
139691	veetavad	veetavad =veetava  (PlN  >veetav !02_A	et	f	\N
139692	veetavad	"veetav %vee  )TAV_vAS  <vedama ;28_V	et	f	\N
139693	veetavad	veetavad =tava  (PlN  >vee+tava !17_S	et	f	\N
139694	tantsjad	?tantsjad =tantsja  (PlN  >tantsja !01_S	et	f	\N
139695	tantsjad	?tantsjad =tantsja  (PlN  >tantsjas !02_A	et	f	\N
139696	tantsjad	?tantsjad =tantsja  (IndPrSg2  >tantsjama !29_V	et	f	\N
139747	laulupidudel	laulupidudel =pidu  (PlAd  >laulu+pidu !17_S	et	f	\N
139748	laulupidudel	laulupidudel =pidu  (PlAd  >laulu+pidu !18_S	et	f	\N
139760	naerata	naerata =naerata  (IndPrPs_  >naeratama !27_V	et	f	\N
139761	naerata	naerata =naerata  (ImpPrSg2  >naeratama !27_V	et	f	\N
139779	traditsiooniliselt	traditsiooniliselt =traditsioonilise  (SgAbl  >traditsiooniline !12_A	et	f	\N
139780	traditsiooniliselt	"traditsiooniline %traditsiooni  )LINE_aA  <traditsioon ;22_S	et	f	\N
139781	traditsiooniliselt	traditsiooniliselt =traditsiooniliselt  (ID  >traditsiooniliselt !41_D	et	f	\N
139782	traditsiooniliselt	"traditsiooniliselt %traditsiooni  )LISELT_mD  <traditsioon ;22_S	et	f	\N
139783	traditsiooniliselt	"traditsiooniliselt %traditsioonilise  )LT_mD  <traditsiooniline ;12_A	et	f	\N
139796	lubatakse	lubatakse =luba  (IndPrIps  >lubama !27_V	et	f	\N
139797	lubatakse	lubatakse =takse  (PlP  >luba+taks !22_S	et	f	\N
139802	genotüüpiliselt	?genotüüpiliselt =genotüüpilise  (SgAbl  >genotüüpiline !12_A	et	f	\N
139803	genotüüpiliselt	?genotüüpiliselt =genotüüpiliselt  (ID  >genotüüpiliselt !41_D	et	f	\N
139804	genotüüpiliselt	?genotüüpiliselt =ilise  (SgAbl  >geno+tüüp+iline !10_A	et	f	\N
139821	vene-	vene- =vene  (ID  >vene !41_G	et	f	\N
139822	vene-	vene- =vene  (SgN  >vene !16_S	et	f	\N
139823	vene-	vene- =vene  (SgG  >vene !16_S	et	f	\N
139826	traditsiooniliseks	traditsiooniliseks =traditsioonilise  (SgTr  >traditsiooniline !12_A	et	f	\N
139827	traditsiooniliseks	"traditsiooniline %traditsiooni  )LINE_aA  <traditsioon ;22_S	et	f	\N
139833	laulumeelelahetusi	laulumeelelahetusi =lahetusi  (PlP  >laulu+meele+lahetus !11_S	et	f	\N
139456	tänäsepäevani	?tänäsepäevani =tänäsepäevani  (SgG  >tänäsepäevan !02_S	et	f	\N
139506	võibid	?võibid =võibi  (PlN  >võibi !16_S	et	f	\N
139507	võibid	?võibid =võibi  (PlN  >võip !22_S	et	f	\N
139508	võibid	?võibid =võibi  (IndPrSg2  >võibima !27_V	et	f	\N
139509	võibid	?võibid =võibi  (IndPrSg2  >võipima !28_V	et	f	\N
139519	siamaani	?siamaani =siamaa  (SgTer  >siamaa !26_S	et	f	\N
139520	siamaani	?siamaani =siamaani  (SgN  >siamaani !16_S	et	f	\N
139521	siamaani	?siamaani =siamaani  (SgG  >siamaani !16_S	et	f	\N
139522	siamaani	?siamaani =siamaani  (SgG  >siamaan !22_S	et	f	\N
139523	siamaani	?siamaani =siamaani  (SgP  >siamaan !22_S	et	f	\N
139524	siamaani	?siamaani =siamaani  (SgAdt  >siamaan !22_S	et	f	\N
139525	siamaani	?siamaani =siamaani  (IndPrPs_  >siamaanima !28_V	et	f	\N
139526	siamaani	?siamaani =siamaani  (ImpPrSg2  >siamaanima !28_V	et	f	\N
139527	jüübelilaulupidude	### jüübelilaulupidude	et	f	\N
139559	õppetame	?õppetame =õppeta  (IndPrPl1  >õppetama !27_V	et	f	\N
139560	õppetame	?õppetame =tame  (SgN  >õppe+tame !16_S	et	f	\N
139561	õppetame	?õppetame =tame  (SgG  >õppe+tame !16_S	et	f	\N
139566	töörütmi	töörütmi =rütmi  (SgG  >töö+rütm !22_S	et	f	\N
139567	töörütmi	töörütmi =rütmi  (SgP  >töö+rütm !22_S	et	f	\N
139568	töörütmi	töörütmi =rütmi  (SgAdt  >töö+rütm !22_S	et	f	\N
139569	kurbelaule	?kurbelaule =kurbelau  (SgAll  >kurbelau !26_S	et	f	\N
139570	kurbelaule	?kurbelaule =kurbelaule  (PlP  >kurbelaul !19_S	et	f	\N
139571	kurbelaule	?kurbelaule =elau  (SgAll  >kurb+elau !26_S	et	f	\N
139572	kurbelaule	?kurbelaule =elaule  (PlP  >kurb+elaul !22_S	et	f	\N
139610	bentone	?bentone =bentone  (SgN  >bentone !12~10_A	et	f	\N
139611	bentone	?bentone =bentone  (IndPrPs_  >bentonema !27_V	et	f	\N
139612	bentone	?bentone =bentone  (ImpPrSg2  >bentonema !27_V	et	f	\N
139613	kiigutamist	kiigutamist =kiigutamis  (SgP  >kiigutamine !12_S	et	f	\N
139614	kiigutamist	"kiigutamine %kiiguta  )MINE_vS  <kiigutama ;27_V	et	f	\N
139617	tanapäeval	?tanapäeval =tanapäeva  (SgAd  >tanapäeva !16_S	et	f	\N
139618	tanapäeval	?tanapäeval =tanapäeval  (SgN  >tanapäeval !02_S	et	f	\N
139619	organiseerivad	organiseerivad =organiseeri  (IndPrPl3  >organiseerima !28_V	et	f	\N
139620	organiseerivad	organiseerivad =organiseeriva  (PlN  >organiseeriv !02_A	et	f	\N
139621	organiseerivad	"organiseeriv %organiseeri  )V_vA  <organiseerima ;28_V	et	f	\N
139633	unustanud	unustanud =unusta  (PtsPtPs  >unustama !27_V	et	f	\N
139634	unustanud	unustanud =unustanu  (PlN  >unustanu !01_S	et	f	\N
139635	unustanud	"unustanu %unusta  )NU_vS  <unustama ;27_V	et	f	\N
139636	unustanud	unustanud =unustanud  (ID  >unustanud !41_A	et	f	\N
139637	unustanud	"unustanud %unusta  )NUD_vA  <unustama ;27_V	et	f	\N
139656	muusikatalu	muusikatalu =talu  (SgN  >muusika+talu !17_S	et	f	\N
139657	muusikatalu	muusikatalu =talu  (SgG  >muusika+talu !17_S	et	f	\N
139658	muusikatalu	muusikatalu =talu  (SgP  >muusika+talu !17_S	et	f	\N
139661	rühmi	rühmi =rühmi  (SgG  >rühm !22_S	et	f	\N
139662	rühmi	rühmi =rühmi  (SgP  >rühm !22_S	et	f	\N
139663	rühmi	rühmi =rühmi  (SgAdt  >rühm !22_S	et	f	\N
139664	rühmi	rühmi =rühmi  (PlP  >rühm !22_S	et	f	\N
139668	ned	### ned	et	f	\N
139681	puhkem	?puhkem =puhkem  (SgN  >puhkem !02_A	et	f	\N
139689	rahavlaulu	?rahavlaulu =rahavlaulu  (IndPrPs_  >rahavlauluma !27_V	et	f	\N
139690	rahavlaulu	?rahavlaulu =rahavlaulu  (ImpPrSg2  >rahavlauluma !27_V	et	f	\N
139699	kaheteistkümnendal	?kaheteistkümnendal =kaheteistkümnenda  (SgAd  >kaheteistkümnenda !16_S	et	f	\N
139700	kaheteistkümnendal	?kaheteistkümnendal =kaheteistkümnendal  (SgN  >kaheteistkümnendal !02_S	et	f	\N
139701	kaheteistkümnendal	?kaheteistkümnendal =kümnenda  (SgAd  >kahe+teist+kümnenda !01_S	et	f	\N
139702	kaheteistkümnendal	?kaheteistkümnendal =teistkümnenda  (SgAd  >kahe+teistkümnenda !16_S	et	f	\N
139703	kaheteistkümnendal	?kaheteistkümnendal =teistkümnendal  (SgN  >kahe+teistkümnendal !02_S	et	f	\N
139720	sotsialne	?sotsialne =sotsialne  (SgN  >sotsialne !02_A	et	f	\N
139721	sotsialne	?sotsialne =sotsialne  (PlP  >sotsialn !22_S	et	f	\N
139729	tahti	tahti =tahti  (SgP  >taht !22_S	et	f	\N
139730	tahti	tahti =tahti  (SgAdt  >taht !22_S	et	f	\N
139753	popularsem	?popularsem =popularsem  (SgN  >popularsem !02_A	et	f	\N
139754	popularsem	?popularsem =ularsem  (SgN  >pop+ularsem !02_A	et	f	\N
139824	rikkumiseks	rikkumiseks =rikkumise  (SgTr  >rikkumine !12_S	et	f	\N
139825	rikkumiseks	"rikkumine %rikku  )MINE_vS  <rikkuma ;28_V	et	f	\N
139828	ürituseks	ürituseks =ürituse  (SgTr  >üritus !11_S	et	f	\N
139829	ürituseks	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
139859	võimaldasid	võimaldasid =võimalda  (IndIpfSg2  >võimaldama !27_V	et	f	\N
139860	võimaldasid	võimaldasid =võimalda  (IndIpfPl3  >võimaldama !27_V	et	f	\N
139874	unustda	?unustda =unustda  (SgN  >unustda !01_S	et	f	\N
139875	unustda	?unustda =unustda  (SgG  >unustda !01_S	et	f	\N
139876	möödusid	möödusid =möödu  (IndIpfSg2  >mööduma !27_V	et	f	\N
139877	möödusid	möödusid =möödu  (IndIpfPl3  >mööduma !27_V	et	f	\N
139878	spontaalselt	?spontaalselt =spontaalse  (SgAbl  >spontaalne !02_A	et	f	\N
139879	spontaalselt	?spontaalselt =spontaalse  (PlAbl  >spontaals !22_S	et	f	\N
139652	toimusse	?toimusse =toimusse  (PlP  >toimuss !22_S	et	f	\N
139653	manifistatsioon	?manifistatsioon =manifistatsioon  (SgN  >manifistatsioon !22_S	et	f	\N
139667	traditsiion	?traditsiion =traditsiion  (SgN  >traditsiion !19_S	et	f	\N
139669	kaitsvad	kaitsvad =kaitsva  (PlN  >kaitsev !02_A	et	f	\N
139670	kaitsvad	"kaitsev %kaits  )V_vA  <kaitsma ;32_V	et	f	\N
139671	kaitsvad	"kaitsev %kaitse  )V_vA  <kaitsema ;28_V	et	f	\N
139678	vabastavad	vabastavad =vabasta  (IndPrPl3  >vabastama !27_V	et	f	\N
139679	vabastavad	vabastavad =vabastava  (PlN  >vabastav !02_A	et	f	\N
139680	vabastavad	"vabastav %vabasta  )V_vA  <vabastama ;27_V	et	f	\N
139697	kultuuinähtu	?kultuuinähtu =kultuuinähtu  (IndPrPs_  >kultuuinähtuma !27_V	et	f	\N
139698	kultuuinähtu	?kultuuinähtu =kultuuinähtu  (ImpPrSg2  >kultuuinähtuma !27_V	et	f	\N
139718	rahvapeole	rahvapeole =peo  (SgAll  >rahva+pidu !18_S	et	f	\N
139719	rahvapeole	rahvapeole =peo  (SgAll  >rahva+peo !26_S	et	f	\N
139722	laulutradtsioon	?laulutradtsioon =laulutradtsioon  (SgN  >laulutradtsioon !22_S	et	f	\N
139723	laulutradtsioon	?laulutradtsioon =tradtsioon  (SgN  >laulu+tradtsioon !22_S	et	f	\N
139724	laulutradtsioon	?laulutradtsioon =lutradtsioon  (SgN  >lau+lutradtsioon !22_S	et	f	\N
139725	meestekoori	meestekoori =koor  (PlP  >meeste+koor !13_S	et	f	\N
139726	meestekoori	meestekoori =koori  (SgG  >meeste+koor !22_S	et	f	\N
139727	meestekoori	meestekoori =koori  (SgP  >meeste+koor !22_S	et	f	\N
139728	meestekoori	meestekoori =koori  (SgAdt  >meeste+koor !22_S	et	f	\N
139768	arkiividest	?arkiividest =arkiivi  (PlEl  >arkiivi !16_S	et	f	\N
139769	arkiividest	?arkiividest =arkiivi  (PlEl  >arkiiv !22_S	et	f	\N
139770	arkiividest	?arkiividest =arkiivides  (SgP  >arkiividene !12_A	et	f	\N
139777	regilaule	regilaule =lau  (SgAll  >regi+laug !22_SA	et	f	\N
139778	regilaule	regilaule =laule  (PlP  >regi+laul !22_S	et	f	\N
139784	üheksateistkümnenda	?üheksateistkümnenda =üheksateistkümnenda  (SgN  >üheksateistkümnenda !16_S	et	f	\N
139785	üheksateistkümnenda	?üheksateistkümnenda =üheksateistkümnenda  (SgG  >üheksateistkümnenda !16_S	et	f	\N
139786	üheksateistkümnenda	?üheksateistkümnenda =üheksateistkümnenda  (IndPrPs_  >üheksateistkümnendama !27_V	et	f	\N
139787	üheksateistkümnenda	?üheksateistkümnenda =üheksateistkümnenda  (ImpPrSg2  >üheksateistkümnendama !27_V	et	f	\N
139788	üheksateistkümnenda	?üheksateistkümnenda =kümnenda  (SgN  >üheksa+teist+kümnenda !01_S	et	f	\N
139789	üheksateistkümnenda	?üheksateistkümnenda =kümnenda  (SgG  >üheksa+teist+kümnenda !01_S	et	f	\N
139790	üheksateistkümnenda	?üheksateistkümnenda =teistkümnenda  (SgN  >üheksa+teistkümnenda !16_S	et	f	\N
139791	üheksateistkümnenda	?üheksateistkümnenda =teistkümnenda  (SgG  >üheksa+teistkümnenda !16_S	et	f	\N
139792	üheksateistkümnenda	?üheksateistkümnenda =ateistkümnenda  (SgN  >üheks+ateistkümnenda !16_S	et	f	\N
139793	üheksateistkümnenda	?üheksateistkümnenda =ateistkümnenda  (SgG  >üheks+ateistkümnenda !16_S	et	f	\N
139794	üheksateistkümnenda	?üheksateistkümnenda =ksateistkümnenda  (SgN  >ühe+ksateistkümnenda !16_S	et	f	\N
139795	üheksateistkümnenda	?üheksateistkümnenda =ksateistkümnenda  (SgG  >ühe+ksateistkümnenda !16_S	et	f	\N
139806	juttud	?juttud =juttu  (IndPrSg2  >juttuma !27_V	et	f	\N
139807	juttud	?juttud =juttud  (ID  >juttud !41_A	et	f	\N
139808	rüütmi	?rüütmi =rüütmi  (ID  >rüütmi !41_D	et	f	\N
139809	rüütmi	?rüütmi =rüütmi  (SgG  >rüütm !22_S	et	f	\N
139810	rüütmi	?rüütmi =rüütmi  (SgP  >rüütm !22_S	et	f	\N
139811	rüütmi	?rüütmi =rüütmi  (SgAdt  >rüütm !22_S	et	f	\N
139812	rüütmi	?rüütmi =rüütmi  (IndPrPs_  >rüütmima !28_V	et	f	\N
139813	rüütmi	?rüütmi =rüütmi  (ImpPrSg2  >rüütmima !28_V	et	f	\N
139814	rotsi-	?rotsi- =rotsi  (SgN  >rotsi !16_S	et	f	\N
139815	rotsi-	?rotsi- =rotsi  (SgG  >rotsi !16_S	et	f	\N
139816	rotsi-	?rotsi- =rotsi  (SgG  >rots !22_S	et	f	\N
139817	rotsi-	?rotsi- =rotsi  (SgP  >rots !22_S	et	f	\N
139818	rotsi-	?rotsi- =rotsi  (SgAdt  >rots !22_S	et	f	\N
139819	rotsi-	?rotsi- =rotsi  (IndPrPs_  >rotsima !28_V	et	f	\N
139820	rotsi-	?rotsi- =rotsi  (ImpPrSg2  >rotsima !28_V	et	f	\N
139841	laulmises	laulmises =laulmise  (SgIn  >laulmine !12?10_S	et	f	\N
139842	laulmises	"laulmine %laul  )MINE_vS  <laulma ;33_V	et	f	\N
139843	pealine	pealine =pealine  (SgN  >pealine !12?10_A	et	f	\N
139844	pealine	"pealine %pea  )LINE_aA  <pea ;26_S	et	f	\N
139845	pealine	pealine =ine  (SgN  >peal+ine !16_S	et	f	\N
139846	pealine	pealine =ine  (SgG  >peal+ine !16_S	et	f	\N
139855	lauldis	?lauldis =lauldi  (SgIn  >lault !22_S	et	f	\N
139856	lauldis	?lauldis =lauldi  (IndIpfSg3  >lauldima !28_V	et	f	\N
139857	lauldis	?lauldis =lauldis  (SgN  >lauldis !09_S	et	f	\N
139911	hälli	hälli =hälli  (SgG  >häll !22_S	et	f	\N
139912	hälli	hälli =hälli  (SgP  >häll !22_S	et	f	\N
139913	hälli	hälli =hälli  (SgAdt  >häll !22_S	et	f	\N
139914	hälli	hälli =hälli  (IndPrPs_  >hällima !28_V	et	f	\N
139915	hälli	hälli =hälli  (ImpPrSg2  >hällima !28_V	et	f	\N
139920	maga	maga =maga  (IndPrPs_  >magama !27_V	et	f	\N
139921	maga	maga =maga  (ImpPrSg2  >magama !27_V	et	f	\N
139936	takti	takti =takti  (SgG  >takt !22_S	et	f	\N
139937	takti	takti =takti  (SgP  >takt !22_S	et	f	\N
139938	takti	takti =takti  (SgAdt  >takt !22_S	et	f	\N
139711	põlvkonnast	"põlvkonnane %põlvkonna  )NE_aA  <põlvkond ;22_S	et	f	\N
139712	põlvkonnast	põlvkonnast =konna  (SgEl  >põlv+konn !22_S	et	f	\N
139713	põlvkonnast	põlvkonnast =konnas  (SgP  >põlv+konnane !10_A	et	f	\N
139714	põlvkonnast	"põlv+konnane %konna  )NE_aA  <põlv+konn ;22_S	et	f	\N
139731	tappama	?tappama =tappa  (Sup  >tappama !29_V	et	f	\N
139732	tappama	?tappama =tappama  (SgG  >tappam !02_A	et	f	\N
139743	kaa	?kaa =kaa  (SgN  >kaa !26_S	et	f	\N
139744	kaa	?kaa =kaa  (SgG  >kaa !26_S	et	f	\N
139762	tööpäeva	tööpäeva =päeva  (SgG  >töö+päev !22_S	et	f	\N
139763	tööpäeva	tööpäeva =päeva  (SgP  >töö+päev !22_S	et	f	\N
139764	tööpäeva	tööpäeva =päeva  (SgAdt  >töö+päev !22_S	et	f	\N
139765	leiatakse	?leiatakse =leia  (IndPrIps  >leiama !29_V	et	f	\N
139766	leiatakse	?leiatakse =leiatakse  (SgG  >leiatakne !02_A	et	f	\N
139767	leiatakse	?leiatakse =leiatakse  (PlP  >leiataks !22_S	et	f	\N
139798	instrumenditega	### instrumenditega	et	f	\N
139799	1960-ndes	### 1960-ndes	et	f	\N
139800	vastutus	vastutus =vastutus  (SgN  >vastutus !11_S	et	f	\N
139801	vastutus	"vastutus %vastuta  )US_vS  <vastutama ;27_V	et	f	\N
139805	eeposid	?eeposid =eepo  (PlP  >eepo !16_S	et	f	\N
139830	festivali	festivali =festivali  (SgG  >festival !19_S	et	f	\N
139831	festivali	festivali =festivali  (SgP  >festival !19_S	et	f	\N
139832	festivali	festivali =festivali  (SgAdt  >festival !19_S	et	f	\N
139835	pillesaateta	?pillesaateta =pillesaate  (SgAb  >pillesaate !16_S	et	f	\N
139836	pillesaateta	?pillesaateta =pillesaateta  (IndPrPs_  >pillesaatetama !27_V	et	f	\N
139837	pillesaateta	?pillesaateta =pillesaateta  (ImpPrSg2  >pillesaatetama !27_V	et	f	\N
139849	pillita	pillita =pilli  (SgAb  >pill !22_S	et	f	\N
139850	pillita	pillita =pilli  (IndPrIps_  >pillima !28_V	et	f	\N
139851	pillita	pillita =pillita  (IndPrPs_  >pillitama !27_V	et	f	\N
139852	pillita	pillita =pillita  (ImpPrSg2  >pillitama !27_V	et	f	\N
139887	puhkipilliorkestrit	?puhkipilliorkestrit =puhkipilliorkestri  (SgP  >puhkipilliorkester !02_S	et	f	\N
139888	puhkipilliorkestrit	?puhkipilliorkestrit =ipilliorkestri  (SgP  >puhk+ipilliorkester !02_S	et	f	\N
139906	tilkagi	tilkagi =tilka  (SgP^  >tilk !22_S	et	f	\N
139907	tilkagi	tilkagi =tilka  (SgAdt^  >tilk !22_S	et	f	\N
139918	hoidmiseks	hoidmiseks =hoidmise  (SgTr  >hoidmine !12?10_S	et	f	\N
139919	hoidmiseks	"hoidmine %hoid  )MINE_vS  <hoidma ;34_V	et	f	\N
139946	tundnud	tundnud =tund  (PtsPtPs  >tundma !34_V	et	f	\N
139947	tundnud	tundnud =tundnu  (PlN  >tundnu !01_S	et	f	\N
139948	tundnud	"tundnu %tund  )NU_vS  <tundma ;34_V	et	f	\N
139949	tundnud	tundnud =tundnud  (ID  >tundnud !41_A	et	f	\N
139950	tundnud	"tundnud %tund  )NUD_vA  <tundma ;34_V	et	f	\N
139991	vanalaulu	vanalaulu =laulu  (SgG  >vana+laul !22_S	et	f	\N
139992	vanalaulu	vanalaulu =laulu  (SgP  >vana+laul !22_S	et	f	\N
139993	vanalaulu	vanalaulu =laulu  (SgAdt  >vana+laul !22_S	et	f	\N
140022	lausid	?lausid =lau  (PlP  >lau !26_S	et	f	\N
140023	lausid	?lausid =lausi  (PlN  >lausi !16_S	et	f	\N
140024	lausid	?lausid =lausi  (PlN  >laus !22_S	et	f	\N
140025	lausid	?lausid =lausi  (IndPrSg2  >lausima !28_V	et	f	\N
140028	juhid	juhid =juhi  (PlN  >juht !22_S	et	f	\N
140029	juhid	juhid =juhi  (IndPrSg2  >juhtima !28_V	et	f	\N
140034	gumni	?gumni =gumni  (SgN  >gumni !16_S	et	f	\N
140035	gumni	?gumni =gumni  (SgG  >gumni !16_S	et	f	\N
140036	gumni	?gumni =gumni  (SgG  >gumn !22_S	et	f	\N
140037	gumni	?gumni =gumni  (SgP  >gumn !22_S	et	f	\N
140038	gumni	?gumni =gumni  (SgAdt  >gumn !22_S	et	f	\N
140039	gumni	?gumni =gumni  (IndPrPs_  >gumnima !28_V	et	f	\N
140040	gumni	?gumni =gumni  (ImpPrSg2  >gumnima !28_V	et	f	\N
140061	väl	### väl	et	f	\N
140071	rahvuslus	rahvuslus =rahvuslus  (SgN  >rahvuslus !11_S	et	f	\N
140072	rahvuslus	"rahvuslus %rahvuslase  )US_aS  <rahvuslane ;12_S	et	f	\N
140104	küttimise	küttimise =küttimise  (SgG  >küttimine !12_S	et	f	\N
140105	küttimise	"küttimine %kütti  )MINE_vS  <küttima ;28_V	et	f	\N
140116	algeliseid	?algeliseid =algelisei  (PlN  >algelisei !26_S	et	f	\N
140117	algeliseid	?algeliseid =algelisei  (SgP  >algelisei !26_S	et	f	\N
140118	algeliseid	?algeliseid =elise  (PlP  >alg+eline !10_A	et	f	\N
140119	algeliseid	?algeliseid =elisei  (PlN  >alg+elisei !26_S	et	f	\N
140120	algeliseid	?algeliseid =elisei  (SgP  >alg+elisei !26_S	et	f	\N
140135	harpuunid	harpuunid =harpuuni  (PlN  >harpuun !22_S	et	f	\N
140136	harpuunid	harpuunid =harpuuni  (IndPrSg2  >harpuunima !28_V	et	f	\N
140153	kvartsist	kvartsist =kvartsi  (SgEl  >kvarts !22_S	et	f	\N
140154	kvartsist	kvartsist =ist  (SgN  >kvarts+ist !22_S	et	f	\N
140177	kunda	?kunda =kunda  (SgN  >kunda !16_S	et	f	\N
140178	kunda	?kunda =kunda  (SgG  >kunda !16_S	et	f	\N
140179	kunda	?kunda =kunda  (IndPrPs_  >kundama !29_V	et	f	\N
140180	kunda	?kunda =kunda  (ImpPrSg2  >kundama !29_V	et	f	\N
140194	teokarpe	teokarpe =karpe  (SgG  >teo+karbe !06_S	et	f	\N
140196	teokarpe	teokarpe =karpe  (PlP  >teo+karp !22_S	et	f	\N
140216	sõjakirviste	?sõjakirviste =sõjakirvis  (PlG  >sõjakirvis !09_S	et	f	\N
140217	sõjakirviste	?sõjakirviste =sõjakirviste  (PlP  >sõjakirvist !22_S	et	f	\N
139715	kihnu	kihnu =kihnu  (SgG  >kihn !22_S	et	f	\N
139716	kihnu	kihnu =kihnu  (SgP  >kihn !22_S	et	f	\N
139717	kihnu	kihnu =kihnu  (SgAdt  >kihn !22_S	et	f	\N
139733	laulavrevolutsiion	?laulavrevolutsiion =laulavrevolutsiion  (SgN  >laulavrevolutsiion !19_S	et	f	\N
139734	laulavrevolutsiion	?laulavrevolutsiion =lavrevolutsiion  (SgN  >lau+lavrevolutsiion !19_S	et	f	\N
139735	organiseerisid	organiseerisid =organiseeri  (IndIpfSg2  >organiseerima !28_V	et	f	\N
139736	organiseerisid	organiseerisid =organiseeri  (IndIpfPl3  >organiseerima !28_V	et	f	\N
139737	konserdid	?konserdid =konserdi  (PlN  >konserdi !01_S	et	f	\N
139738	konserdid	?konserdid =konserdi  (PlN  >konserd !02_S	et	f	\N
139739	konserdid	?konserdid =konserdi  (PlN  >konsert !22_S	et	f	\N
139740	konserdid	?konserdid =konserdi  (IndPrSg2  >konsertima !28_V	et	f	\N
139741	puulmalaulikud	?puulmalaulikud =puulmalauliku  (PlN  >puulmalaulik !25_A	et	f	\N
139742	puulmalaulikud	?puulmalaulikud =puulmalauliku  (IndPrSg2  >puulmalaulikuma !27_V	et	f	\N
139745	lapsekoor	lapsekoor =koor  (SgN  >lapse+koor !13_S	et	f	\N
139746	lapsekoor	lapsekoor =koor  (SgN  >lapse+koor !22_S	et	f	\N
139749	korraldatatud	?korraldatatud =korraldata  (PtsPtIps  >korraldatama !27_V	et	f	\N
139750	korraldatatud	?korraldatatud =korraldatatu  (PlN  >korraldatatu !01_S	et	f	\N
139751	korraldatatud	?korraldatatud =korraldatatu  (IndPrSg2  >korraldatatuma !27_V	et	f	\N
139752	korraldatatud	?korraldatatud =korraldatatud  (ID  >korraldatatud !41_A	et	f	\N
139755	muju	?muju =muju  (SgN  >muju !17_S	et	f	\N
139756	muju	?muju =muju  (SgG  >muju !17_S	et	f	\N
139757	muju	?muju =muju  (SgP  >muju !17_S	et	f	\N
139758	muju	?muju =muju  (IndPrPs_  >mujuma !27_V	et	f	\N
139759	muju	?muju =muju  (ImpPrSg2  >mujuma !27_V	et	f	\N
139771	kirikudes	?kirikudes =kiriku  (Ger  >kirikuma !27_V	et	f	\N
139772	kirikudes	?kirikudes =udes  (SgN  >kirik+udes !09_S	et	f	\N
139773	kirikudes	?kirikudes =kudes  (SgN  >kiri+kudes !09_S	et	f	\N
139774	mõeltud	?mõeltud =mõeltu  (PlN  >mõeltu !01_S	et	f	\N
139775	mõeltud	?mõeltud =mõeltu  (IndPrSg2  >mõeltuma !27_V	et	f	\N
139776	mõeltud	?mõeltud =mõeltud  (ID  >mõeltud !41_A	et	f	\N
139838	meeste-	meeste- =mees  (PlG  >meene !10_A	et	f	\N
139839	meeste-	"meene %mee  )NE_aA  <mesi ;15_S	et	f	\N
139840	meeste-	meeste- =mees  (PlG  >mees !13_S	et	f	\N
139847	kujunand	?kujunand =kujunand  (SgN  >kujunand !22_S	et	f	\N
139848	kujunand	?kujunand =nand  (SgN  >kuju+nand !22_S	et	f	\N
139858	xiix	?xiix =xiix  (SgN  >xiix !22_S	et	f	\N
139862	näitis	?näitis =näit  (IndIpfSg3  >näitma !34_V	et	f	\N
139863	näitis	?näitis =näiti  (IndIpfSg3  >näitima !28_V	et	f	\N
139864	näitis	?näitis =näitis  (SgN  >näitis !11~09_S	et	f	\N
139870	tese	?tese =tese  (SgN  >tese !16_S	et	f	\N
139871	tese	?tese =tese  (SgG  >tese !16_S	et	f	\N
139872	tese	?tese =tese  (IndPrPs_  >tesema !27_V	et	f	\N
139873	tese	?tese =tese  (ImpPrSg2  >tesema !27_V	et	f	\N
139889	rahvapeos	rahvapeos =peo  (SgIn  >rahva+pidu !18_S	et	f	\N
139890	rahvapeos	rahvapeos =peo  (SgIn  >rahva+peo !26_S	et	f	\N
139892	enesetunde	enesetunde =tunde  (SgG  >enese+tunne !06_S	et	f	\N
139893	enesetunde	enesetunde =tunde  (PlP  >enese+tund !22_S	et	f	\N
139896	rahvalaulupidusid	rahvalaulupidusid =pidu  (PlP  >rahva+laulu+pidu !17_S	et	f	\N
139897	rahvalaulupidusid	rahvalaulupidusid =pidu  (PlP  >rahva+laulu+pidu !18_S	et	f	\N
139925	ullikene	?ullikene =ullikene  (SgN  >ullikene !12_S	et	f	\N
139926	ullikene	?ullikene =ullikene  (PlP  >ulliken !19_S	et	f	\N
139927	täheldasid	täheldasid =tähelda  (IndIpfSg2  >täheldama !27_V	et	f	\N
139928	täheldasid	täheldasid =tähelda  (IndIpfPl3  >täheldama !27_V	et	f	\N
139959	tegevuses	tegevuses =tegevuse  (SgIn  >tegevus !11_S	et	f	\N
139960	tegevuses	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
139961	tegevuses	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
139962	tegevuses	tegevuses =use  (PlIn  >tegev+usk !22_S	et	f	\N
139972	laulurahvapidu	laulurahvapidu =pidu  (SgN  >laulu+rahva+pidu !17_S	et	f	\N
139973	laulurahvapidu	laulurahvapidu =pidu  (SgN  >laulu+rahva+pidu !18_S	et	f	\N
139974	laulurahvapidu	laulurahvapidu =pidu  (SgG  >laulu+rahva+pidu !17_S	et	f	\N
139975	laulurahvapidu	laulurahvapidu =pidu  (SgP  >laulu+rahva+pidu !17_S	et	f	\N
139976	laulurahvapidu	laulurahvapidu =pidu  (SgP  >laulu+rahva+pidu !18_S	et	f	\N
139983	väljaarvatud	väljaarvatud =atu  (PlN  >välja+arv+att !22_S	et	f	\N
139984	väljaarvatud	väljaarvatud =arva  (PtsPtIps  >välja+_arvama !29_V	et	f	\N
139985	väljaarvatud	väljaarvatud =arvatu  (PlN  >välja+arvatu !01_AS	et	f	\N
139986	jaab	?jaab =jaab  (SgN  >jaab !22_S	et	f	\N
140011	kõge	?kõge =kõge  (SgN  >kõge !16_S	et	f	\N
140012	kõge	?kõge =kõge  (SgG  >kõge !16_S	et	f	\N
140013	kõge	?kõge =kõge  (IndPrPs_  >kõgema !27_V	et	f	\N
140014	kõge	?kõge =kõge  (ImpPrSg2  >kõgema !27_V	et	f	\N
140048	kulturil	?kulturil =kulturi  (SgAd  >kulturi !01_S	et	f	\N
140049	kulturil	?kulturil =kulturi  (SgAd  >kultur !02_S	et	f	\N
140053	võidi	võidi =või  (IndIpfIps  >võima !37_V	et	f	\N
140054	võidi	võidi =võidi  (SgG  >võit !22_S	et	f	\N
140058	tantsulise	tantsulise =tantsulise  (SgG  >tantsuline !12_A	et	f	\N
139834	laulumeelelahetusi	"laulu+meele+lahetus %lahe  )TUS2_aS  <laulu+meele+laht ;22_S	et	f	\N
139853	koores	koores =koore  (SgIn  >koor !13_S	et	f	\N
139854	koores	koores =koore  (PlIn  >koor !22_S	et	f	\N
139861	xix-xx	### xix-xx	et	f	\N
139865	laulusega	?laulusega =lauluse  (SgKom  >laulus !11~09_S	et	f	\N
139866	laulusega	?laulusega =sega  (SgN  >laulu+sega !17_S	et	f	\N
139867	laulusega	?laulusega =sega  (SgG  >laulu+sega !17_S	et	f	\N
139868	laulusega	?laulusega =sega  (SgP  >laulu+sega !17_S	et	f	\N
139869	laulusega	?laulusega =luse  (SgKom  >lau+luse !16_S	et	f	\N
139881	mittetavaline	mittetavaline =tavaline  (SgN  >mitte+tavaline !12_A	et	f	\N
139882	mittetavaline	"mitte+tavaline %tava  )LINE_aA  <mitte+tava ;17_S	et	f	\N
139885	meestekoor	meestekoor =koor  (SgN  >meeste+koor !13_S	et	f	\N
139886	meestekoor	meestekoor =koor  (SgN  >meeste+koor !22_S	et	f	\N
139894	lõbusamaks	lõbusamaks =lõbusama  (SgTr  >lõbusam !02_A	et	f	\N
139895	lõbusamaks	"lõbusam %lõbusa  )M_cA  <lõbus ;02_A	et	f	\N
139899	laulurahvastena	laulurahvastena =rahvas  (PlEs  >laulu+rahvas !07_S	et	f	\N
139900	laulurahvastena	laulurahvastena =rahvas  (PlEs  >laulu+rahvane !10_A	et	f	\N
139901	laulurahvastena	"laulu+rahvane %rahva  )NE_aA  <laulu+rahvas ;07_S	et	f	\N
139916	saatmisel	saatmisel =saatmise  (SgAd  >saatmine !12?10_S	et	f	\N
139917	saatmisel	"saatmine %saat  )MINE_vS  <saatma ;34_V	et	f	\N
139929	ühindavad	?ühindavad =ühinda  (IndPrPl3  >ühindama !27_V	et	f	\N
139930	ühindavad	?ühindavad =ühindava  (PlN  >ühindav !02_A	et	f	\N
139931	ühindavad	?ühindavad =ühindava  (PlN  >ühindava !16_S	et	f	\N
139932	hää	?hää =hää  (SgN  >hää !26_S	et	f	\N
139933	hää	?hää =hää  (SgG  >hää !26_S	et	f	\N
139934	hoidmise	hoidmise =hoidmise  (SgG  >hoidmine !12?10_S	et	f	\N
139935	hoidmise	"hoidmine %hoid  )MINE_vS  <hoidma ;34_V	et	f	\N
139940	tähtedega	tähtedega =tähte  (PlKom  >täht !22_S	et	f	\N
139941	tähtedega	tähtedega =ede  (SgKom  >täht+ede !16_S	et	f	\N
139956	kultuuriidentiteet	?kultuuriidentiteet =kultuuriidentiteet  (SgN  >kultuuriidentiteet !22_S	et	f	\N
139957	kultuuriidentiteet	?kultuuriidentiteet =identiteet  (SgN  >kultuuri+identiteet !22_S	et	f	\N
139958	kultuuriidentiteet	?kultuuriidentiteet =iidentiteet  (SgN  >kultuur+iidentiteet !22_S	et	f	\N
139963	rahvalaulupidu	rahvalaulupidu =pidu  (SgN  >rahva+laulu+pidu !17_S	et	f	\N
139964	rahvalaulupidu	rahvalaulupidu =pidu  (SgN  >rahva+laulu+pidu !18_S	et	f	\N
139965	rahvalaulupidu	rahvalaulupidu =pidu  (SgG  >rahva+laulu+pidu !17_S	et	f	\N
139966	rahvalaulupidu	rahvalaulupidu =pidu  (SgP  >rahva+laulu+pidu !17_S	et	f	\N
139967	rahvalaulupidu	rahvalaulupidu =pidu  (SgP  >rahva+laulu+pidu !18_S	et	f	\N
139968	jjannsen	?jjannsen =jjannse  (IndPrSg1  >jjannsema !27_V	et	f	\N
139969	jjannsen	?jjannsen =jjannsen  (SgN  >jjannsen !02_S	et	f	\N
139998	vananõukogu	vananõukogu =kogu  (SgN  >vana+nõu+kogu !17_S	et	f	\N
139999	vananõukogu	vananõukogu =kogu  (SgG  >vana+nõu+kogu !17_S	et	f	\N
140000	vananõukogu	vananõukogu =kogu  (SgP  >vana+nõu+kogu !17_S	et	f	\N
140018	valladest	?valladest =vallades  (SgP  >valladene !12_A	et	f	\N
140026	ärkamisaega	ärkamisaega =aega  (SgP  >ärkamis+aeg !22_S	et	f	\N
140027	ärkamisaega	ärkamisaega =aega  (SgAdt  >ärkamis+aeg !22_S	et	f	\N
140043	tantsujad	?tantsujad =tantsuja  (PlN  >tantsuja !01_S	et	f	\N
140044	tantsujad	?tantsujad =tantsuja  (PlN  >tantsujas !02_A	et	f	\N
140060	pöörajooks	?pöörajooks =pöörajoo  (SgTr  >pöörajoo !26_S	et	f	\N
140062	kogukonna	kogukonna =kogukonna  (SgG  >kogukond !22_S	et	f	\N
140063	kogukonna	kogukonna =konna  (SgG  >kogu+konn !22_S	et	f	\N
140064	kogukonna	kogukonna =konna  (SgP  >kogu+konn !22_S	et	f	\N
140065	kogukonna	kogukonna =konna  (SgAdt  >kogu+konn !22_S	et	f	\N
140078	ülemaline	?ülemaline =ülemaline  (SgN  >ülemaline !12_A	et	f	\N
140079	ülemaline	?ülemaline =ülemaline  (PlP  >ülemalin !19_S	et	f	\N
140080	ülemaline	?ülemaline =aline  (SgN  >ülem+aline !10_A	et	f	\N
140081	manifestatsion	?manifestatsion =manifestatsion  (SgN  >manifestatsion !19~02_S	et	f	\N
140091	sugulastlele	?sugulastlele =lastle  (SgAll  >sugu+lastle !06_S	et	f	\N
140100	aastatuhande	?aastatuhande =aastatuhande  (PlP  >aastatuhand !22_S	et	f	\N
140101	aastatuhande	?aastatuhande =tatuhande  (PlP  >aas+tatuhand !22_S	et	f	\N
140130	hülje-	?hülje- =hülje  (SgN  >hülje !06_S	et	f	\N
140131	hülje-	?hülje- =hülje  (SgG  >hülje !06_S	et	f	\N
140132	hülje-	?hülje- =hülje  (IndPrPs_  >hüljema !27_V	et	f	\N
140133	hülje-	?hülje- =hülje  (ImpPrSg2  >hüljema !27_V	et	f	\N
140137	liikmestes	liikmestes =liikmes  (PlIn  >liikmene !12~10_A	et	f	\N
140138	liikmestes	"liikmene %liikme  )NE_aA  <liige ;05_S	et	f	\N
140150	tulekivist	tulekivist =kivi  (SgEl  >tule+kivi !17_S	et	f	\N
140151	tulekivist	tulekivist =kivis  (SgP  >tule+kivine !10_A	et	f	\N
140152	tulekivist	"tule+kivine %kivi  )NE_aA  <tule+kivi ;17_S	et	f	\N
140175	veekogusid	veekogusid =kogu  (PlP  >vee+kogu !17_S	et	f	\N
140176	veekogusid	veekogusid =kogusi  (PlN  >vee+kogus !02_A	et	f	\N
140190	puurimine	puurimine =puurimine  (SgN  >puurimine !12_S	et	f	\N
140191	puurimine	"puurimine %puuri  )MINE_vS  <puurima ;28_V	et	f	\N
140203	kammkeraamika	kammkeraamika =keraamika  (SgN  >kamm+keraamika !01_S	et	f	\N
139880	spontaalselt	?spontaalselt =spontaalselt  (ID  >spontaalselt !41_D	et	f	\N
139883	naistekoor	naistekoor =koor  (SgN  >naiste+koor !13_S	et	f	\N
139884	naistekoor	naistekoor =koor  (SgN  >naiste+koor !22_S	et	f	\N
139891	lõdvestuda	?lõdvestuda =lõdvestu  (Inf  >lõdvestuma !27_V	et	f	\N
139898	motivation	?motivation =motivation  (SgN  >motivation !19_S	et	f	\N
139902	20-ndal	### 20-ndal	et	f	\N
139903	taasiseseisvumispäeva	taasiseseisvumispäeva =päeva  (SgG  >taas+ise+seisvumis+päev !22_S	et	f	\N
139904	taasiseseisvumispäeva	taasiseseisvumispäeva =päeva  (SgP  >taas+ise+seisvumis+päev !22_S	et	f	\N
139905	taasiseseisvumispäeva	taasiseseisvumispäeva =päeva  (SgAdt  >taas+ise+seisvumis+päev !22_S	et	f	\N
139908	valamata	valamata =vala  (SupAb  >valama !27_V	et	f	\N
139909	valamata	valamata =valamata  (ID  >valamata !41_A	et	f	\N
139910	valamata	"valamata %vala  )MATA_vA  <valama ;27_V	et	f	\N
139922	marjakene	marjakene =marjakene  (SgN  >marjakene !12_S	et	f	\N
139923	marjakene	"marjakene %marja  )KENE_dS  <marjas ;09_S	et	f	\N
139924	marjakene	"marjakene %marja  )KENE_dS  <mari ;24_S	et	f	\N
139951	tuhandilise	?tuhandilise =tuhandilise  (SgG  >tuhandiline !12_A	et	f	\N
139952	üliuhke	üliuhke =uhke  (SgN  >üli+uhke !01_A	et	f	\N
139953	üliuhke	üliuhke =uhke  (SgG  >üli+uhke !01_A	et	f	\N
139954	üliuhke	üliuhke =uhke  (SgG  >üli+uhe !06_S	et	f	\N
139955	üliuhke	üliuhke =uhke  (PlP  >üli+uhk !22_S	et	f	\N
139981	tantsis	tantsis =tantsi  (SgIn  >tants !22_S	et	f	\N
139982	tantsis	tantsis =tantsi  (IndIpfSg3  >tantsima !28_V	et	f	\N
139994	organiiseeritud	?organiiseeritud =organiiseeri  (PtsPtIps  >organiiseerima !28_V	et	f	\N
139995	organiiseeritud	?organiiseeritud =organiiseeritu  (PlN  >organiiseeritu !01_S	et	f	\N
139996	organiiseeritud	?organiiseeritud =organiiseeritu  (IndPrSg2  >organiiseerituma !27_V	et	f	\N
139997	organiiseeritud	?organiiseeritud =organiiseeritud  (ID  >organiiseeritud !41_A	et	f	\N
140001	kontrollima	kontrollima =kontrolli  (Sup  >kontrollima !28_V	et	f	\N
140002	kontrollima	kontrollima =ima  (SgN  >kont+roll+ima !17_S	et	f	\N
140003	kontrollima	kontrollima =ima  (SgG  >kont+roll+ima !17_S	et	f	\N
140004	kontrollima	kontrollima =ima  (SgP  >kont+roll+ima !17_S	et	f	\N
140007	mängimiseks	mängimiseks =mängimise  (SgTr  >mängimine !12_S	et	f	\N
140008	mängimiseks	"mängimine %mängi  )MINE_vS  <mängima ;28_V	et	f	\N
140009	jargnevate	?jargnevate =jargneva  (PlG  >jargneva !01_S	et	f	\N
140010	jargnevate	?jargnevate =jargneva  (PlG  >jargnev !02_A	et	f	\N
140015	muusikataju	muusikataju =taju  (SgN  >muusika+taju !17_S	et	f	\N
140016	muusikataju	muusikataju =taju  (SgG  >muusika+taju !17_S	et	f	\N
140017	muusikataju	muusikataju =taju  (SgP  >muusika+taju !17_S	et	f	\N
140019	akkordeon	?akkordeon =akkordeon  (SgN  >akkordeon !19_S	et	f	\N
140020	teadki	teadki =tea  (IndPrSg2^  >teadma !34_V	et	f	\N
140021	teadki	teadki =tead  (SgN^  >tead !22_S	et	f	\N
140030	luulupidu	?luulupidu =luulupidu  (IndPrPs_  >luulupiduma !27_V	et	f	\N
140031	luulupidu	?luulupidu =luulupidu  (ImpPrSg2  >luulupiduma !27_V	et	f	\N
140032	luulupidu	?luulupidu =lupidu  (SgN  >luu+lupidu !01_S	et	f	\N
140033	luulupidu	?luulupidu =lupidu  (SgG  >luu+lupidu !01_S	et	f	\N
140045	huivitavad	?huivitavad =huivita  (IndPrPl3  >huivitama !27_V	et	f	\N
140046	huivitavad	?huivitavad =huivitava  (PlN  >huivitav !02_A	et	f	\N
140047	huivitavad	?huivitavad =huivitava  (PlN  >huivitava !16_S	et	f	\N
140057	lüroeepilisi	?lüroeepilisi =lüroeepilisi  (PlP  >lüroeepiline !12_A	et	f	\N
140068	kuutma	?kuutma =kuut  (Sup  >kuutma !34_V	et	f	\N
140069	kuutma	?kuutma =kuutma  (IndPrPs_  >kuutmama !29_V	et	f	\N
140070	kuutma	?kuutma =kuutma  (ImpPrSg2  >kuutmama !29_V	et	f	\N
140075	väljendusvahe	väljendusvahe =vahe  (SgN  >väljendus+vahe !02_A	et	f	\N
140076	väljendusvahe	väljendusvahe =vahe  (SgN  >väljendus+vahe !16_S	et	f	\N
140077	väljendusvahe	väljendusvahe =vahe  (SgG  >väljendus+vahe !16_S	et	f	\N
140082	lauldaon	?lauldaon =lauldaon  (SgN  >lauldaon !22_S	et	f	\N
140094	arheoloogiline	arheoloogiline =arheoloogiline  (SgN  >arheoloogiline !12_A	et	f	\N
140095	arheoloogiline	"arheoloogiline %arheoloogi  )LINE_aA  <arheoloog ;22_S	et	f	\N
140102	aastatuhande	?aastatuhande =aastatuhande  (PlP  >aastatuhand !22_S	et	f	\N
140103	aastatuhande	?aastatuhande =tatuhande  (PlP  >aas+tatuhand !22_S	et	f	\N
140108	söödavaid	söödavaid =söödava  (PlP  >söödav !02_A	et	f	\N
140109	söödavaid	"söödav %söö  )TAV_vAS  <sööma ;38_V	et	f	\N
140124	karusloomi	karusloomi =loomi  (SgG  >karus+loom !22_S	et	f	\N
140125	karusloomi	karusloomi =loomi  (SgP  >karus+loom !22_S	et	f	\N
140126	karusloomi	karusloomi =loomi  (SgAdt  >karus+loom !22_S	et	f	\N
140127	karusloomi	karusloomi =loomi  (PlP  >karus+loom !22_S	et	f	\N
140145	kolle	kolle =kolle  (SgN  >kolle !06_S	et	f	\N
140146	kolle	kolle =kolle  (PlP  >koll !22_S	et	f	\N
140147	soojust	soojust =soojus  (SgP  >soojus !11~09_S	et	f	\N
140148	soojust	"soojus %sooj  )US_aS  <soe ;24_AS	et	f	\N
140149	soojust	soojust =soojus  (SgP  >soojune !10~12_A	et	f	\N
140171	loodusande	loodusande =ande  (SgG  >loodus+anne !06_S	et	f	\N
140172	loodusande	loodusande =ande  (PlP  >loodus+and !22_S	et	f	\N
140212	aastatuhandete	### aastatuhandete	et	f	\N
139939	estraadi	estraadi =estraadi  (SgG  >estraad !22_S	et	f	\N
139942	estraadi	estraadi =estraadi  (SgP  >estraad !22_S	et	f	\N
139943	estraadi	estraadi =estraadi  (SgAdt  >estraad !22_S	et	f	\N
139944	tv-saates	tv-saates =saat  (Ger  >tv-saatma !34_V	et	f	\N
139945	tv-saates	tv-saates =saate  (SgIn  >tv-saade !06_S	et	f	\N
139970	kõi	?kõi =kõi  (SgN  >kõi !26_S	et	f	\N
139971	kõi	?kõi =kõi  (SgG  >kõi !26_S	et	f	\N
139977	jälgimine	jälgimine =jälgimine  (SgN  >jälgimine !12_S	et	f	\N
139978	jälgimine	"jälgimine %jälgi  )MINE_vS  <jälgima ;27_V	et	f	\N
139979	kontrollimine	kontrollimine =kontrollimine  (SgN  >kontrollimine !12_S	et	f	\N
139980	kontrollimine	"kontrollimine %kontrolli  )MINE_vS  <kontrollima ;28_V	et	f	\N
139987	laulukooli	laulukooli =kooli  (SgG  >laulu+kool !22_S	et	f	\N
139988	laulukooli	laulukooli =kooli  (SgP  >laulu+kool !22_S	et	f	\N
139989	laulukooli	laulukooli =kooli  (SgAdt  >laulu+kool !22_S	et	f	\N
139990	laulukooli	laulukooli =kooli  (PlP  >laulu+kool !22_S	et	f	\N
140005	inemisi	?inemisi =inemisi  (ID  >inemisi !41_D	et	f	\N
140006	inemisi	?inemisi =inemisi  (PlP  >inemine !12_S	et	f	\N
140041	janseni	?janseni =janseni  (SgG  >jansen !02_S	et	f	\N
140042	soidab	?soidab =soida  (IndPrSg3  >soidama !29_V	et	f	\N
140050	länemeresoome	?länemeresoome =länemeresoome  (SgN  >länemeresoome !16_S	et	f	\N
140051	länemeresoome	?länemeresoome =länemeresoome  (SgG  >länemeresoome !16_S	et	f	\N
140052	länemeresoome	?länemeresoome =länemeresoome  (PlP  >länemeresoom !22_S	et	f	\N
140055	õõtsutamise	õõtsutamise =õõtsutamise  (SgG  >õõtsutamine !12_S	et	f	\N
140056	õõtsutamise	"õõtsutamine %õõtsuta  )MINE_vS  <õõtsutama ;27_V	et	f	\N
140066	kristin	?kristin =kristi  (IndPrSg1  >kristima !28_V	et	f	\N
140067	kristin	?kristin =kristin  (SgN  >kristin !02_S	et	f	\N
140083	säilimises	säilimises =säilimise  (SgIn  >säilimine !12_S	et	f	\N
140084	säilimises	"säilimine %säili  )MINE_vS  <säilima ;28_V	et	f	\N
140085	kättes	?kättes =kätte  (SgIn  >käte !06_S	et	f	\N
140086	kättes	?kättes =kätte  (IndIpfSg3  >kättema !27_V	et	f	\N
140087	kättes	?kättes =kättes  (SgN  >kättes !09_S	et	f	\N
140098	presoliitikum	?presoliitikum =presoliitikum  (SgN  >presoliitikum !19_S	et	f	\N
140099	presoliitikum	?presoliitikum =soliitikum  (SgN  >pre+soliitikum !19_S	et	f	\N
140110	juurikaid	juurikaid =juurika  (PlP  >juurikas !02_S	et	f	\N
140111	juurikaid	juurikaid =kai  (PlN  >juuri+kai !26_S	et	f	\N
140112	juurikaid	juurikaid =kai  (SgP  >juuri+kai !26_S	et	f	\N
140121	võrguid	võrguid =ui  (PlN  >võrg+ui !26_S	et	f	\N
140122	võrguid	võrguid =ui  (SgP  >võrg+ui !26_S	et	f	\N
140123	võrguid	võrguid =uid  (SgN  >võrg+uid !22_S	et	f	\N
140134	kobrasteküttimiseks	?kobrasteküttimiseks =kobrasteküttimise  (SgTr  >kobrasteküttimine !12_S	et	f	\N
140155	kaetud	kaetud =kae  (PtsPtIps  >kaema !27_V	et	f	\N
140156	kaetud	kaetud =kae  (PtsPtIps  >katma !35_V	et	f	\N
140157	kaetud	kaetud =kaetu  (PlN  >kaetu !01_SA	et	f	\N
140158	kaetud	"kaetu %kae  )TU1_vS  <kaema ;27_V	et	f	\N
140159	kaetud	"kaetu %kae  )TU1_vS  <katma ;35_V	et	f	\N
140160	kaetud	"kaetu %kae  )TU2_kA  <kae ;26_S	et	f	\N
140161	kaetud	kaetud =kaetud  (ID  >kaetud !41_A	et	f	\N
140162	kaetud	"kaetud %kae  )TUD_vA  <kaema ;27_V	et	f	\N
140163	kaetud	"kaetud %kae  )TUD_vA  <katma ;35_V	et	f	\N
140164	talveti	?talveti =talve  (IndIpfIps  >talvema !27_V	et	f	\N
140165	talveti	?talveti =talveti  (ID  >talveti !41_D	et	f	\N
140166	talveti	?talveti =talveti  (SgG  >talvett !22_S	et	f	\N
140167	talveti	?talveti =talveti  (IndPrPs_  >talvettima !28_V	et	f	\N
140168	talveti	?talveti =talveti  (ImpPrSg2  >talvettima !28_V	et	f	\N
140184	lihvitud	lihvitud =lihvi  (PtsPtIps  >lihvima !28_V	et	f	\N
140185	lihvitud	lihvitud =lihvitu  (PlN  >lihvitu !01_AS	et	f	\N
140186	lihvitud	"lihvitu %lihvi  )TU1_vS  <lihvima ;28_V	et	f	\N
140187	lihvitud	"lihvitu %lihvi  )TU2_kA  <lihv ;22_S	et	f	\N
140188	lihvitud	lihvitud =lihvitud  (ID  >lihvitud !41_A	et	f	\N
140189	lihvitud	"lihvitud %lihvi  )TUD_vA  <lihvima ;28_V	et	f	\N
140192	saagimine	saagimine =saagimine  (SgN  >saagimine !12_S	et	f	\N
140193	saagimine	"saagimine %saagi  )MINE_vS  <saagima ;28_V	et	f	\N
140195	kivipuru	kivipuru =puru  (SgN  >kivi+puru !17_S	et	f	\N
140197	kivipuru	kivipuru =puru  (SgG  >kivi+puru !17_S	et	f	\N
140198	kivipuru	kivipuru =puru  (SgP  >kivi+puru !17_S	et	f	\N
140213	noorimas	"noorim %noori  )IM_sA  <noor ;13_AS	et	f	\N
140214	noorimas	noorimas =ima  (SgIn  >noor+ima !17_S	et	f	\N
140215	vene-lik	### vene-lik	et	f	\N
140222	paati	paati =paati  (SgP  >paat !22_S	et	f	\N
140224	paati	paati =paati  (SgAdt  >paat !22_S	et	f	\N
140229	kägiras	?kägiras =kägira  (SgIn  >kägira !01_S	et	f	\N
140254	ainele	ainele =aine  (SgAll  >aine !06_S	et	f	\N
140255	ainele	ainele =aine  (PlAll  >ain !22_S	et	f	\N
140256	teduskonnale	?teduskonnale =teduskonna  (SgAll  >teduskonna !16_S	et	f	\N
140257	teduskonnale	?teduskonnale =teduskonna  (SgAll  >teduskond !22_S	et	f	\N
140298	majandustegevuse	majandustegevuse =tegevuse  (SgG  >majandus+tegevus !11_S	et	f	\N
140299	majandustegevuse	"majandus+tegevus %tegeva  )US_aS  <majandus+tegev ;02_A	et	f	\N
140059	tantsulise	"tantsuline %tantsu  )LINE_aA  <tants ;22_S	et	f	\N
140073	tegutsid	?tegutsid =tegutsi  (PlN  >teguts !02_S	et	f	\N
140074	tegutsid	?tegutsid =tegutsi  (IndPrSg2  >tegutsima !28_V	et	f	\N
140088	tähtsalt	tähtsalt =tähtsa  (SgAbl  >tähtis !02_A	et	f	\N
140089	tähtsalt	tähtsalt =tähtsalt  (ID  >tähtsalt !41_D	et	f	\N
140090	tähtsalt	"tähtsalt %tähtsa  )LT_mD  <tähtis ;02_A	et	f	\N
140092	üheteist	üheteist =te  (PlEl  >ühe+tee !26_S	et	f	\N
140093	üheteist	üheteist =teist  (SgN  >ühe+teist !22_S	et	f	\N
140096	pullis	pullis =pulli  (SgIn  >pull !22_S	et	f	\N
140097	pullis	pullis =pulli  (SgIn  >pull !22_SA	et	f	\N
140106	korjamisega	korjamisega =korjamise  (SgKom  >korjamine !12_S	et	f	\N
140107	korjamisega	"korjamine %korja  )MINE_vS  <korjama ;29_V	et	f	\N
140113	õngekonksuid	õngekonksuid =ui  (PlN  >õnge+konks+ui !26_S	et	f	\N
140114	õngekonksuid	õngekonksuid =ui  (SgP  >õnge+konks+ui !26_S	et	f	\N
140115	õngekonksuid	õngekonksuid =uid  (SgN  >õnge+konks+uid !22_S	et	f	\N
140128	küttimiseks	küttimiseks =küttimise  (SgTr  >küttimine !12_S	et	f	\N
140129	küttimiseks	"küttimine %kütti  )MINE_vS  <küttima ;28_V	et	f	\N
140139	koonusekujulistes	?koonusekujulistes =koonusekujulis  (PlIn  >koonusekujulis !09_S	et	f	\N
140140	koonusekujulistes	?koonusekujulistes =koonusekujulis  (PlIn  >koonusekujuline !12_A	et	f	\N
140141	koonusekujulistes	?koonusekujulistes =koonusekujuliste  (PlIn  >koonusekujulist !22_S	et	f	\N
140142	koonusekujulistes	?koonusekujulistes =usekujulis  (PlIn  >koon+usekujulis !09_S	et	f	\N
140143	koonusekujulistes	?koonusekujulistes =usekujulis  (PlIn  >koon+usekujuline !12_A	et	f	\N
140144	koonusekujulistes	?koonusekujulistes =usekujuliste  (PlIn  >koon+usekujulist !22_S	et	f	\N
140169	hõimud	hõimud =hõimu  (PlN  >hõim !22_S	et	f	\N
140170	hõimud	hõimud =hõimu  (IndPrSg2  >hõimuma !27_V	et	f	\N
140173	elupaiga	elupaiga =pai  (SgKom  >elu+pai !26_AS	et	f	\N
140174	elupaiga	elupaiga =paiga  (SgG  >elu+paik !22_S	et	f	\N
140181	kvartsi	kvartsi =kvartsi  (SgG  >kvarts !22_S	et	f	\N
140182	kvartsi	kvartsi =kvartsi  (SgP  >kvarts !22_S	et	f	\N
140183	kvartsi	kvartsi =kvartsi  (SgAdt  >kvarts !22_S	et	f	\N
140199	taimi	taimi =taimi  (SgG  >taim !22_S	et	f	\N
140200	taimi	taimi =taimi  (SgP  >taim !22_S	et	f	\N
140201	taimi	taimi =taimi  (SgAdt  >taim !22_S	et	f	\N
140202	taimi	taimi =taimi  (PlP  >taim !22_S	et	f	\N
140205	kaunistatud	kaunistatud =kaunista  (PtsPtIps  >kaunistama !27_V	et	f	\N
140206	kaunistatud	kaunistatud =kaunistatu  (PlN  >kaunistatu !01_S	et	f	\N
140207	kaunistatud	"kaunistatu %kaunista  )TU1_vS  <kaunistama ;27_V	et	f	\N
140208	kaunistatud	kaunistatud =kaunistatud  (ID  >kaunistatud !41_A	et	f	\N
140209	kaunistatud	"kaunistatud %kaunista  )TUD_vA  <kaunistama ;27_V	et	f	\N
140234	toie	?toie =toie  (SgN  >toie !06_S	et	f	\N
140236	toie	?toie =toie  (SgG  >toie !06_S	et	f	\N
140246	xx-3	### xx-3	et	f	\N
140250	erialane	erialane =alane  (SgN  >eri+alane !10_AS	et	f	\N
140251	erialane	"eri+alane %ala  )NE_aA  <eri+ala ;17_S	et	f	\N
140258	registrerumise	?registrerumise =registrerumise  (SgG  >registrerumine !12_S	et	f	\N
140264	naana	?naana =naana  (SgN  >naana !16_S	et	f	\N
140265	naana	?naana =naana  (SgG  >naana !16_S	et	f	\N
140266	naana	?naana =naana  (IndPrPs_  >naanama !29_V	et	f	\N
140267	naana	?naana =naana  (ImpPrSg2  >naanama !29_V	et	f	\N
140293	gruppeeritult	?gruppeeritult =gruppeeritu  (SgAbl  >gruppeeritu !01_S	et	f	\N
140294	gruppeeritult	?gruppeeritult =gruppeeritult  (ID  >gruppeeritult !41_D	et	f	\N
140320	lausumised	lausumised =lausumise  (PlN  >lausumine !12_S	et	f	\N
140321	lausumised	"lausumine %lausu  )MINE_vS  <lausuma ;28_V	et	f	\N
140333	pärimuskultuuri	?pärimuskultuuri =pärimuskultuuri  (SgN  >pärimuskultuuri !16_S	et	f	\N
140335	pärimuskultuuri	?pärimuskultuuri =pärimuskultuuri  (SgG  >pärimuskultuuri !16_S	et	f	\N
140337	pärimuskultuuri	?pärimuskultuuri =pärimuskultuuri  (SgG  >pärimuskultuur !22_S	et	f	\N
140338	pärimuskultuuri	?pärimuskultuuri =pärimuskultuuri  (SgP  >pärimuskultuur !22_S	et	f	\N
140339	pärimuskultuuri	?pärimuskultuuri =pärimuskultuuri  (SgAdt  >pärimuskultuur !22_S	et	f	\N
140340	pärimuskultuuri	?pärimuskultuuri =pärimuskultuuri  (IndPrPs_  >pärimuskultuurima !28_V	et	f	\N
140341	pärimuskultuuri	?pärimuskultuuri =pärimuskultuuri  (ImpPrSg2  >pärimuskultuurima !28_V	et	f	\N
140342	pärimuskultuuri	?pärimuskultuuri =muskultuuri  (SgN  >päri+muskultuuri !16_S	et	f	\N
140343	pärimuskultuuri	?pärimuskultuuri =muskultuuri  (SgG  >päri+muskultuuri !16_S	et	f	\N
140344	pärimuskultuuri	?pärimuskultuuri =muskultuuri  (SgG  >päri+muskultuur !22_S	et	f	\N
140345	pärimuskultuuri	?pärimuskultuuri =muskultuuri  (SgP  >päri+muskultuur !22_S	et	f	\N
140346	pärimuskultuuri	?pärimuskultuuri =muskultuuri  (SgAdt  >päri+muskultuur !22_S	et	f	\N
140350	asusid	asusid =asu  (PlP  >asu !17_S	et	f	\N
140352	asusid	asusid =asu  (IndIpfSg2  >asuma !27_V	et	f	\N
140353	asusid	asusid =asu  (IndIpfPl3  >asuma !27_V	et	f	\N
140354	põllumaad	põllumaad =maa  (PlN  >põllu+maa !26_S	et	f	\N
140355	põllumaad	põllumaad =maa  (SgP  >põllu+maa !26_S	et	f	\N
140397	tsigurit	?tsigurit =tsiguri  (SgP  >tsiguri !01_S	et	f	\N
140398	tsigurit	?tsigurit =tsiguri  (SgP  >tsigur !02_S	et	f	\N
140402	laiuvad	laiuvad =laiu  (IndPrPl3  >laiuma !27_V	et	f	\N
140204	kammkeraamika	kammkeraamika =keraamika  (SgG  >kamm+keraamika !01_S	et	f	\N
140210	kammivajutustega	?kammivajutustega =kammivajutus  (PlKom  >kammivajutus !11?09_S	et	f	\N
140211	kammivajutustega	?kammivajutustega =ivajutus  (PlKom  >kamm+ivajutus !11?09_S	et	f	\N
140219	kultuuriks	kultuuriks =kultuuri  (SgTr  >kultuur !22_S	et	f	\N
140221	kultuuriks	kultuuriks =iks  (SgN  >kultuur+iks !22_S	et	f	\N
140225	kirviste	?kirviste =kirvis  (PlG  >kirvis !09_S	et	f	\N
140227	kirviste	?kirviste =kirviste  (PlP  >kirvist !22_S	et	f	\N
140242	uurimistöö	uurimistöö =töö  (SgN  >uurimis+töö !26_S	et	f	\N
140243	uurimistöö	uurimistöö =töö  (SgG  >uurimis+töö !26_S	et	f	\N
140247	isikukood	isikukood =koo  (PlN  >isiku+kubu !18_S	et	f	\N
140248	isikukood	isikukood =kood  (SgN  >isiku+kood !22_S	et	f	\N
140249	xxx1111	### xxx1111	et	f	\N
140252	xxx1122	### xxx1122	et	f	\N
140253	refistreeruda	?refistreeruda =refistreeru  (Inf  >refistreeruma !27_V	et	f	\N
140278	õppetaja	?õppetaja =õppetaja  (SgN  >õppetaja !01_S	et	f	\N
140279	õppetaja	?õppetaja =õppetaja  (SgG  >õppetaja !01_S	et	f	\N
140280	õppetaja	?õppetaja =õppetaja  (SgG  >õppetajas !02_A	et	f	\N
140281	õppetaja	?õppetaja =taja  (SgN  >õppe+taja !17_S	et	f	\N
140282	õppetaja	?õppetaja =taja  (SgG  >õppe+taja !17_S	et	f	\N
140283	õppetaja	?õppetaja =taja  (SgP  >õppe+taja !17_S	et	f	\N
140289	vanausuliste	vanausuliste =usulis  (PlG  >vana+usuline !12_A	et	f	\N
140290	vanausuliste	"vana+usuline %usu  )LINE_aA  <vana+usk ;22_S	et	f	\N
140291	folklooriväljaanne	folklooriväljaanne =anne  (SgN  >folkloori+välja+anne !05_S	et	f	\N
140292	folklooriväljaanne	folklooriväljaanne =anne  (SgN  >folkloori+välja+anne !06_S	et	f	\N
140295	etiketi	etiketi =etiketi  (SgG  >etikett !22_S	et	f	\N
140296	etiketi	etiketi =etiketi  (IndPrPs_  >etikettima !28_V	et	f	\N
140297	etiketi	etiketi =etiketi  (ImpPrSg2  >etikettima !28_V	et	f	\N
140322	posijatest	posijatest =posija  (PlEl  >posija !01_S	et	f	\N
140323	posijatest	"posija %posi  )JA_vS  <posima ;27_V	et	f	\N
140324	posijatest	posijatest =test  (SgN  >posija+test !22_S	et	f	\N
140325	publitseeritud	publitseeritud =publitseeri  (PtsPtIps  >publitseerima !28_V	et	f	\N
140326	publitseeritud	publitseeritud =publitseeritu  (PlN  >publitseeritu !01_S	et	f	\N
140327	publitseeritud	"publitseeritu %publitseeri  )TU1_vS  <publitseerima ;28_V	et	f	\N
140328	publitseeritud	publitseeritud =publitseeritud  (ID  >publitseeritud !41_A	et	f	\N
140329	publitseeritud	"publitseeritud %publitseeri  )TUD_vA  <publitseerima ;28_V	et	f	\N
140356	normiks	normiks =normi  (SgTr  >norm !22_S	et	f	\N
140357	normiks	normiks =normi  (KndPrPs  >normima !28_V	et	f	\N
140358	normiks	normiks =iks  (SgN  >norm+iks !22_S	et	f	\N
140366	hinnatud	hinnatud =hinna  (PtsPtIps  >hindama !29_V	et	f	\N
140367	hinnatud	hinnatud =hinnatu  (PlN  >hinnatu !01_AS	et	f	\N
140368	hinnatud	"hinnatu %hinna  )TU1_vS  <hindama ;29_V	et	f	\N
140369	hinnatud	"hinnatu %hinna  )TU2_kA  <hind ;22_S	et	f	\N
140370	hinnatud	hinnatud =hinnatud  (ID  >hinnatud !41_A	et	f	\N
140371	hinnatud	"hinnatud %hinna  )TUD_vA  <hindama ;29_V	et	f	\N
140372	pottseppad	?pottseppad =pottseppa  (PlN  >pottseppa !01_S	et	f	\N
140382	vanausulistest	vanausulistest =usulis  (PlEl  >vana+usuline !12_A	et	f	\N
140383	vanausulistest	"vana+usuline %usu  )LINE_aA  <vana+usk ;22_S	et	f	\N
140384	ametihooneid	ametihooneid =neid  (SgN  >ameti+hoo+neid !22_S	et	f	\N
140385	ametihooneid	ametihooneid =hoone  (PlP  >ameti+hoone !06_S	et	f	\N
140386	ametihooneid	"ameti+hoone %hoo  )NE_aA  <ameti+hoog ;22_S	et	f	\N
140392	hõivatud	hõivatud =hõiva  (PtsPtIps  >hõivama !29_V	et	f	\N
140393	hõivatud	hõivatud =hõivatu  (PlN  >hõivatu !01_AS	et	f	\N
140394	hõivatud	"hõivatu %hõiva  )TU1_vS  <hõivama ;29_V	et	f	\N
140395	hõivatud	hõivatud =hõivatud  (ID  >hõivatud !41_A	et	f	\N
140396	hõivatud	"hõivatud %hõiva  )TUD_vA  <hõivama ;29_V	et	f	\N
140460	leidlikust	leidlikust =leidliku  (SgEl  >leidlik !25_A	et	f	\N
140461	leidlikust	leidlikust =leidlikus  (SgP  >leidlikus !11_S	et	f	\N
140462	leidlikust	"leidlikus %leidliku  )US_aS  <leidlik ;25_A	et	f	\N
140465	sissetallatud	sissetallatud =talla  (PtsPtIps  >sisse+_tallama !29_V	et	f	\N
140466	sissetallatud	sissetallatud =tallatu  (PlN  >sisse+tallatu !01_AS	et	f	\N
140467	sissetallatud	"sisse+tallatu %talla  )TU2_kA  <sisse+tald ;22_S	et	f	\N
140468	kilomeetripikkused	kilomeetripikkused =pikkuse  (PlN  >kilo+meetri+pikkus !11~09_S	et	f	\N
140469	kilomeetripikkused	"kilo+meetri+pikkus %pikk  )US_aS  <kilo+meetri+pikk ;22_AS	et	f	\N
140471	kilomeetripikkused	kilomeetripikkused =pikkuse  (PlN  >kilo+meetri+pikkune !12~10_A	et	f	\N
140480	mitmepäevapikkuseks	mitmepäevapikkuseks =seks  (SgN  >mitme+päeva+pikku+seks !22_S	et	f	\N
140481	mitmepäevapikkuseks	mitmepäevapikkuseks =use  (PlTr  >mitme+päeva+pikk+usk !22_S	et	f	\N
140482	mitmepäevapikkuseks	mitmepäevapikkuseks =pikkuse  (SgTr  >mitme+päeva+pikkus !11~09_S	et	f	\N
140483	mitmepäevapikkuseks	"mitme+päeva+pikkus %pikk  )US_aS  <mitme+päeva+pikk ;22_AS	et	f	\N
140484	mitmepäevapikkuseks	mitmepäevapikkuseks =pikkuse  (SgTr  >mitme+päeva+pikkune !12~10_A	et	f	\N
140492	majakesi	majakesi =majakesi  (PlP  >majake !12_S	et	f	\N
140493	majakesi	"majake %maja  )KE_dS  <maja ;17_S	et	f	\N
140494	majakesi	majakesi =majakesi  (PlP  >majakene !12_S	et	f	\N
140218	sõjakirviste	?sõjakirviste =kirvis  (PlG  >sõja+kirvis !09_S	et	f	\N
140220	sõjakirviste	?sõjakirviste =kirviste  (PlP  >sõja+kirvist !22_S	et	f	\N
140240	arheoloogilise	arheoloogilise =arheoloogilise  (SgG  >arheoloogiline !12_A	et	f	\N
140241	arheoloogilise	"arheoloogiline %arheoloogi  )LINE_aA  <arheoloog ;22_S	et	f	\N
140261	semesteer	?semesteer =semesteer  (SgN  >semesteer !22_S	et	f	\N
140268	povskaja	?povskaja =povskaja  (SgN  >povskaja !01_S	et	f	\N
140269	povskaja	?povskaja =povskaja  (SgG  >povskaja !01_S	et	f	\N
140270	povskaja	?povskaja =povskaja  (SgG  >povskajas !02_A	et	f	\N
140302	perekombestikuluule	?perekombestikuluule =perekombestikuluu  (SgAll  >perekombestikuluu !26_S	et	f	\N
140303	perekombestikuluule	?perekombestikuluule =perekombestikuluule  (SgN  >perekombestikuluule !16_S	et	f	\N
140304	perekombestikuluule	?perekombestikuluule =perekombestikuluule  (SgG  >perekombestikuluule !16_S	et	f	\N
140305	perekombestikuluule	?perekombestikuluule =perekombestikuluule  (PlP  >perekombestikuluul !22_S	et	f	\N
140306	perekombestikuluule	?perekombestikuluule =bestikuluu  (SgAll  >pere+kom+bestikuluu !26_S	et	f	\N
140307	perekombestikuluule	?perekombestikuluule =bestikuluule  (SgN  >pere+kom+bestikuluule !16_S	et	f	\N
140308	perekombestikuluule	?perekombestikuluule =bestikuluule  (SgG  >pere+kom+bestikuluule !16_S	et	f	\N
140309	perekombestikuluule	?perekombestikuluule =bestikuluule  (PlP  >pere+kom+bestikuluul !22_S	et	f	\N
140310	perekombestikuluule	?perekombestikuluule =kombestikuluu  (SgAll  >pere+kombestikuluu !26_S	et	f	\N
140311	perekombestikuluule	?perekombestikuluule =kombestikuluule  (SgN  >pere+kombestikuluule !16_S	et	f	\N
140312	perekombestikuluule	?perekombestikuluule =kombestikuluule  (SgG  >pere+kombestikuluule !16_S	et	f	\N
140313	perekombestikuluule	?perekombestikuluule =kombestikuluule  (PlP  >pere+kombestikuluul !22_S	et	f	\N
140318	pärimused	pärimused =pärimuse  (PlN  >pärimus !11_S	et	f	\N
140319	pärimused	"pärimus %päri  )MUS_vS  <pärima ;27_V	et	f	\N
140330	hummanitaarteaduste	?hummanitaarteaduste =hummanitaarteadus  (PlG  >hummanitaarteadus !11~09_S	et	f	\N
140347	peipsimaa	peipsimaa =maa  (SgN  >peipsi+maa !26_S	et	f	\N
140348	peipsimaa	peipsimaa =maa  (SgG  >peipsi+maa !26_S	et	f	\N
140359	mittetraditsioonilisi	mittetraditsioonilisi =traditsioonilisi  (PlP  >mitte+traditsiooniline !12_A	et	f	\N
140360	mittetraditsioonilisi	"mitte+traditsiooniline %traditsiooni  )LINE_aA  <mitte+traditsioon ;22_S	et	f	\N
140361	töökuse	töökuse =töökuse  (SgG  >töökus !11~09_S	et	f	\N
140362	töökuse	"töökus %tööka  )US_aS  <töökas ;02_A	et	f	\N
140363	töökuse	töökuse =kuse  (SgG  >töö+kusi !20_S	et	f	\N
140375	majandusdushooned	?majandusdushooned =majandusdushoone  (PlN  >majandusdushoone !16_S	et	f	\N
140387	pihkvas	?pihkvas =pihkva  (SgIn  >pihkva !01_S	et	f	\N
140389	pihkvas	?pihkvas =pihkva  (IndIpfSg3  >pihkvama !29_V	et	f	\N
140391	pihkvas	?pihkvas =pihkvas  (SgN  >pihkvas !07_S	et	f	\N
140413	kalastusriartelli	?kalastusriartelli =kalastusriartelli  (SgG  >kalastusriartell !22_S	et	f	\N
140414	kalastusriartelli	?kalastusriartelli =kalastusriartelli  (SgP  >kalastusriartell !22_S	et	f	\N
140415	kalastusriartelli	?kalastusriartelli =kalastusriartelli  (SgAdt  >kalastusriartell !22_S	et	f	\N
140416	kalastusriartelli	?kalastusriartelli =kalastusriartelli  (IndPrPs_  >kalastusriartellima !28_V	et	f	\N
140417	kalastusriartelli	?kalastusriartelli =kalastusriartelli  (ImpPrSg2  >kalastusriartellima !28_V	et	f	\N
140418	kalastusriartelli	?kalastusriartelli =stusriartelli  (SgG  >kala+stusriartell !22_S	et	f	\N
140419	kalastusriartelli	?kalastusriartelli =stusriartelli  (SgP  >kala+stusriartell !22_S	et	f	\N
140420	kalastusriartelli	?kalastusriartelli =stusriartelli  (SgAdt  >kala+stusriartell !22_S	et	f	\N
140423	järvele	järvele =järve  (SgAll  >järv !22_S	et	f	\N
140424	järvele	järvele =järve  (PlAll  >järv !22_S	et	f	\N
140425	kuudel	kuudel =kuu  (PlAd  >kuu !26_S	et	f	\N
140426	kuudel	kuudel =kuude  (PlAd  >kuut !22_S	et	f	\N
140433	aupaklikult	aupaklikult =pakliku  (SgAbl  >au+paklik !25_A	et	f	\N
140434	aupaklikult	"au+paklikult %pakliku  )LT_mD  <au+paklik ;25_A	et	f	\N
140445	aljoksin	?aljoksin =aljoksi  (IndPrSg1  >aljoksima !28_V	et	f	\N
140448	aljoksin	?aljoksin =aljoksin  (SgN  >aljoksin !19_S	et	f	\N
140453	kutselised	kutselised =kutselise  (PlN  >kutseline !12_A	et	f	\N
140454	kutselised	"kutseline %kutse  )LINE_aA  <kutse ;06_S	et	f	\N
140463	lumme	lumme =lumme  (SgAdt  >lumi !20_S	et	f	\N
140464	lumme	lumme =lumme  (PlP  >lumm !22_S	et	f	\N
140477	vahemaad	vahemaad =maa  (PlN  >vahe+maa !26_S	et	f	\N
140479	vahemaad	vahemaad =maa  (SgP  >vahe+maa !26_S	et	f	\N
140508	jääaluseks	jääaluseks =seks  (SgN  >jää+alu+seks !22_S	et	f	\N
140509	jääaluseks	jääaluseks =aluse  (SgTr  >jää+alus !09_S	et	f	\N
140510	jääaluseks	jääaluseks =aluse  (SgTr  >jää+alune !10_AS	et	f	\N
140511	jääaluseks	"jää+alune %alu  )NE_aA  <jää+alg ;22_S	et	f	\N
140539	ulgtöödel	?ulgtöödel =ulgtöö  (PlAd  >ulgtöö !26_S	et	f	\N
140540	ulgtöödel	?ulgtöödel =ulgtööde  (SgAd  >ulgtööde !16_S	et	f	\N
140541	ulgtöödel	?ulgtöödel =ulgtööde  (PlAd  >ulgtööt !22_S	et	f	\N
140575	mainega	mainega =maine  (SgKom  >maine !06_S	et	f	\N
140576	mainega	"maine %mai  )NE_aA  <maa ;26_S	et	f	\N
140583	keerata	keerata =keera  (Inf  >keerama !29_V	et	f	\N
140584	keerata	keerata =keera  (IndPrIps_  >keerama !29_V	et	f	\N
140599	potist	potist =poti  (SgEl  >poti !16_S	et	f	\N
140223	meenutavate	meenutavate =meenutava  (PlG  >meenutav !02_A	et	f	\N
140226	meenutavate	"meenutav %meenu  )TAV_vAS  <meenuma ;27_V	et	f	\N
140228	meenutavate	"meenutav %meenuta  )V_vA  <meenutama ;27_V	et	f	\N
140230	sunutele	?sunutele =sunute  (PlAll  >sunutt !22_S	et	f	\N
140231	sunutele	?sunutele =sunutele  (IndPrPs_  >sunutelema !36_V	et	f	\N
140232	sunutele	?sunutele =sunutele  (ImpPrSg2  >sunutelema !36_V	et	f	\N
140233	raviva	raviva =raviva  (SgG  >raviv !02_A	et	f	\N
140235	raviva	"raviv %ravi  )V_vA  <ravima ;27_V	et	f	\N
140237	päikesekivi	päikesekivi =kivi  (SgN  >päikese+kivi !17_S	et	f	\N
140238	päikesekivi	päikesekivi =kivi  (SgG  >päikese+kivi !17_S	et	f	\N
140239	päikesekivi	päikesekivi =kivi  (SgP  >päikese+kivi !17_S	et	f	\N
140244	arheoloogilisel	arheoloogilisel =arheoloogilise  (SgAd  >arheoloogiline !12_A	et	f	\N
140245	arheoloogilisel	"arheoloogiline %arheoloogi  )LINE_aA  <arheoloog ;22_S	et	f	\N
140259	panis	panis =pani  (SgIn  >pani !16_S	et	f	\N
140260	panis	panis =pani  (SgIn  >pan !19_S	et	f	\N
140262	õpperaamatus	õpperaamatus =atu  (SgIn  >õppe+raam+att !22_S	et	f	\N
140263	õpperaamatus	õpperaamatus =raamatu  (SgIn  >õppe+raamat !02_S	et	f	\N
140271	essti	?essti =essti  (SgN  >essti !01_S	et	f	\N
140272	essti	?essti =essti  (SgG  >essti !01_S	et	f	\N
140273	essti	?essti =essti  (SgG  >esst !22_S	et	f	\N
140274	essti	?essti =essti  (SgP  >esst !22_S	et	f	\N
140275	essti	?essti =essti  (SgAdt  >esst !22_S	et	f	\N
140276	essti	?essti =essti  (IndPrPs_  >esstima !28_V	et	f	\N
140277	essti	?essti =essti  (ImpPrSg2  >esstima !28_V	et	f	\N
140284	spetsialiseeritud	spetsialiseeritud =spetsialiseeri  (PtsPtIps  >spetsialiseerima !28_V	et	f	\N
140285	spetsialiseeritud	spetsialiseeritud =spetsialiseeritu  (PlN  >spetsialiseeritu !01_S	et	f	\N
140286	spetsialiseeritud	"spetsialiseeritu %spetsialiseeri  )TU1_vS  <spetsialiseerima ;28_V	et	f	\N
140287	spetsialiseeritud	spetsialiseeritud =spetsialiseeritud  (ID  >spetsialiseeritud !41_A	et	f	\N
140288	spetsialiseeritud	"spetsialiseeritud %spetsialiseeri  )TUD_vA  <spetsialiseerima ;28_V	et	f	\N
140300	kujunemisel	kujunemisel =kujunemise  (SgAd  >kujunemine !12_S	et	f	\N
140301	kujunemisel	"kujunemine %kujune  )MINE_vS  <kujunema ;27_V	et	f	\N
140314	mitte-muinasjutuslik	?mitte-muinasjutuslik =muinasjutuslik  (SgN  >mitte-muinasjutuslik !25_A	et	f	\N
140315	mitte-muinasjutuslik	?mitte-muinasjutuslik =jutuslik  (SgN  >mitte-muinas+jutuslik !25_A	et	f	\N
140331	õpetajatele	õpetajatele =õpetaja  (PlAll  >õpetaja !01_S	et	f	\N
140332	õpetajatele	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
140376	ümbruskonna	ümbruskonna =ümbruskonna  (SgG  >ümbruskond !22_S	et	f	\N
140377	ümbruskonna	ümbruskonna =konna  (SgG  >ümbrus+konn !22_S	et	f	\N
140378	ümbruskonna	ümbruskonna =konna  (SgP  >ümbrus+konn !22_S	et	f	\N
140379	ümbruskonna	ümbruskonna =konna  (SgAdt  >ümbrus+konn !22_S	et	f	\N
140390	petrogradis	?petrogradis =petrogradis  (SgN  >petrogradis !09_S	et	f	\N
140399	vanausuluste	vanausuluste =luste  (SgN  >vana+usu+luste !06_S	et	f	\N
140400	vanausuluste	vanausuluste =luste  (SgG  >vana+usu+luste !06_S	et	f	\N
140401	vanausuluste	vanausuluste =luste  (PlP  >vana+usu+lust !22_S	et	f	\N
140405	kallast	kallast =kalla  (SgEl  >kalla !16_S	et	f	\N
140406	kallast	kallast =kallas  (SgP  >kallas !07_S	et	f	\N
140407	kallast	kallast =kallas  (SgP  >kallane !10_A	et	f	\N
140408	kallast	"kallane %kalla  )NE_aA  <kalla ;16_S	et	f	\N
140409	kümneid	kümneid =kümne  (PlP  >kümmend !05_N	et	f	\N
140410	kümneid	kümneid =kümne  (PlP  >kümme !05_N	et	f	\N
140421	vaesetes	vaesetes =e  (PlIn  >vaes+esi !15_S	et	f	\N
140422	vaesetes	vaesetes =sete  (PlIn  >vae+sett !22_S	et	f	\N
140427	lihvisid	lihvisid =lihvi  (PlP  >lihv !22_S	et	f	\N
140428	lihvisid	lihvisid =lihvi  (IndIpfSg2  >lihvima !28_V	et	f	\N
140429	lihvisid	lihvisid =lihvi  (IndIpfPl3  >lihvima !28_V	et	f	\N
140430	püügi	püügi =püügi  (SgG  >püük !22_S	et	f	\N
140431	püügi	püügi =püü  (SgN^  >püü !26_S	et	f	\N
140432	püügi	püügi =püü  (SgG^  >püü !26_S	et	f	\N
140473	teetähistega	teetähistega =tähis  (PlKom  >tee+tähis !09_S	et	f	\N
140474	teetähistega	teetähistega =tähis  (PlKom  >tee+tähine !10_A	et	f	\N
140475	teetähistega	"tee+tähine %tähi  )NE_aA  <tee+täht ;22_S	et	f	\N
140502	tarbetuse	tarbetuse =tarbetuse  (SgG  >tarbetus !11_S	et	f	\N
140503	tarbetuse	"tarbetus %tarbe  )TUS2_aS  <tarve ;06_S	et	f	\N
140512	omapäraseid	omapäraseid =pärase  (PlP  >oma+pärane !10_A	et	f	\N
140513	omapäraseid	"oma+pärane %pära  )NE_aA  <oma+pära ;17_S	et	f	\N
140519	karakatitsadeks	?karakatitsadeks =karakatitsa  (PlTr  >karakatitsa !16_S	et	f	\N
140520	karakatitsadeks	?karakatitsadeks =karakatitsa  (PlTr  >karakatits !22_S	et	f	\N
140536	vaesem	vaesem =vaesem  (SgN  >vaesem !02_A	et	f	\N
140537	vaesem	"vaesem %vae  )SEM_cA  <vaag ;22_S	et	f	\N
140538	vaesem	"vaesem %vaese  )M_cA  <vaene ;10_AS	et	f	\N
140551	käsikääs	?käsikääs =käsikää  (SgIn  >käsikää !26_S	et	f	\N
140552	käsikääs	?käsikääs =käsikääs  (SgN  >käsikääs !22_S	et	f	\N
140553	käsikääs	?käsikääs =kää  (SgIn  >käsi+kää !26_S	et	f	\N
140554	käsikääs	?käsikääs =kääs  (SgN  >käsi+kääs !22_S	et	f	\N
140607	vetevaimust	vetevaimust =us  (SgP  >vete+vaim+uks !14_S	et	f	\N
140316	olulisel	olulisel =olulise  (SgAd  >oluline !12_A	et	f	\N
140317	olulisel	"oluline %olu  )LINE_aA  <olu ;17_S	et	f	\N
140334	huvilistele	huvilistele =huvilis  (PlAll  >huviline !12_SA	et	f	\N
140336	huvilistele	"huviline %huvi  )LINE_aA  <huvi ;17_S	et	f	\N
140349	vanausulised	vanausulised =usulise  (PlN  >vana+usuline !12_A	et	f	\N
140351	vanausulised	"vana+usuline %usu  )LINE_aA  <vana+usk ;22_S	et	f	\N
140364	meisterlikuse	meisterlikuse =meisterlikuse  (SgG  >meisterlikus !11?09_S	et	f	\N
140365	meisterlikuse	"meisterlikus %meisterliku  )US_aS  <meisterlik ;25_A	et	f	\N
140373	spetsialiseerusid	spetsialiseerusid =spetsialiseeru  (IndIpfSg2  >spetsialiseeruma !27_V	et	f	\N
140374	spetsialiseerusid	spetsialiseerusid =spetsialiseeru  (IndIpfPl3  >spetsialiseeruma !27_V	et	f	\N
140380	taludes	taludes =talu  (PlIn  >talu !17_S	et	f	\N
140381	taludes	taludes =talu  (Ger  >taluma !27_V	et	f	\N
140388	novgorodis	?novgorodis =novgorodis  (SgN  >novgorodis !09_S	et	f	\N
140411	kilomeetreid	kilomeetreid =kilomeetre  (PlP  >kilomeeter !02_S	et	f	\N
140412	kilomeetreid	kilomeetreid =meetre  (PlP  >kilo+meeter !02_S	et	f	\N
140435	suurus	suurus =suurus  (SgN  >suurus !11~09_S	et	f	\N
140436	suurus	"suurus %suur  )US_aS  <suur ;13_A	et	f	\N
140442	kljavin	?kljavin =kljavi  (IndPrSg1  >kljavima !27_V	et	f	\N
140443	kljavin	?kljavin =kljavin  (SgN  >kljavin !02_S	et	f	\N
140450	saveli	?saveli =saveli  (ID  >saveli !41_D	et	f	\N
140451	saveli	?saveli =saveli  (SgG  >savel !02_S	et	f	\N
140452	poljakov	?poljakov =poljakov  (SgN  >poljakov !02_A	et	f	\N
140455	välju	välju =välju  (PlP  >väli !24_S	et	f	\N
140456	välju	välju =välju  (IndPrPs_  >väljuma !27_V	et	f	\N
140457	välju	välju =välju  (ImpPrSg2  >väljuma !27_V	et	f	\N
140458	ilmutasid	ilmutasid =ilmuta  (IndIpfSg2  >ilmutama !27_V	et	f	\N
140459	ilmutasid	ilmutasid =ilmuta  (IndIpfPl3  >ilmutama !27_V	et	f	\N
140470	talveteed	talveteed =tee  (PlN  >talve+tee !26_S	et	f	\N
140472	talveteed	talveteed =tee  (SgP  >talve+tee !26_S	et	f	\N
140485	paigutatud	paigutatud =paiguta  (PtsPtIps  >paigutama !27_V	et	f	\N
140486	paigutatud	paigutatud =paigutatu  (PlN  >paigutatu !01_S	et	f	\N
140487	paigutatud	"paigutatu %paiguta  )TU1_vS  <paigutama ;27_V	et	f	\N
140488	paigutatud	paigutatud =paigutatud  (ID  >paigutatud !41_A	et	f	\N
140489	paigutatud	"paigutatud %paiguta  )TUD_vA  <paigutama ;27_V	et	f	\N
140496	kevadeti	?kevadeti =kevadeti  (SgG  >kevadett !22_S	et	f	\N
140497	kevadeti	?kevadeti =kevadeti  (IndPrPs_  >kevadettima !28_V	et	f	\N
140498	kevadeti	?kevadeti =kevadeti  (ImpPrSg2  >kevadettima !28_V	et	f	\N
140499	kevadeti	?kevadeti =eti  (SgN  >kevad+eti !16_S	et	f	\N
140500	kevadeti	?kevadeti =eti  (SgG  >kevad+eti !16_S	et	f	\N
140501	kevadeti	?kevadeti =eti  (SgG  >kevad+ett !22_S	et	f	\N
140506	saabumisel	saabumisel =saabumise  (SgAd  >saabumine !12_S	et	f	\N
140507	saabumisel	"saabumine %saabu  )MINE_vS  <saabuma ;27_V	et	f	\N
140514	kanderaamistikule	kanderaamistikule =istiku  (SgAll  >kande+raam+istik !02_S	et	f	\N
140515	kanderaamistikule	kanderaamistikule =raamistiku  (SgAll  >kande+raamistik !25_S	et	f	\N
140523	karakatitsate	### karakatitsate	et	f	\N
140548	aastaajast	aastaajast =aja  (SgEl  >aasta+aeg !22_S	et	f	\N
140549	aastaajast	aastaajast =ajas  (SgP  >aasta+ajane !10_A	et	f	\N
140550	aastaajast	"aasta+ajane %aja  )NE_aA  <aasta+aeg ;22_S	et	f	\N
140558	enneid	?enneid =ennei  (PlN  >ennei !26_S	et	f	\N
140559	enneid	?enneid =ennei  (SgP  >ennei !26_S	et	f	\N
140560	enneid	?enneid =enneid  (SgN  >enneid !22_S	et	f	\N
140581	kutsud	kutsud =kutsu  (PlN  >kutsu !16_S	et	f	\N
140582	kutsud	kutsud =kutsu  (IndPrSg2  >kutsuma !28_V	et	f	\N
140585	maagilisi	maagilisi =maagilisi  (PlP  >maagiline !12_A	et	f	\N
140586	maagilisi	"maagiline %maagi  )LINE_aA  <maag ;22_S	et	f	\N
140587	maagilisi	"maagiline %maagi  )LINE_aA  <maak ;22_S	et	f	\N
140596	ebasoodsam	ebasoodsam =soodsam  (SgN  >eba+soodsam !02_A	et	f	\N
140597	ebasoodsam	"eba+soodsam %soodsa  )M_cA  <eba+soodus ;02_A	et	f	\N
140598	ebasoodsam	"eba+soodsam %soodsa  )M_cA  <eba+soodne ;02_A	et	f	\N
140601	ekspeditsiooni	ekspeditsiooni =ekspeditsiooni  (SgG  >ekspeditsioon !22_S	et	f	\N
140602	ekspeditsiooni	ekspeditsiooni =ekspeditsiooni  (SgP  >ekspeditsioon !22_S	et	f	\N
140603	ekspeditsiooni	ekspeditsiooni =ekspeditsiooni  (SgAdt  >ekspeditsioon !22_S	et	f	\N
140650	näkineiuga	näkineiuga =neiu  (SgKom  >näki+neiu !16_S	et	f	\N
140651	näkineiuga	näkineiuga =neiu  (SgKom  >näki+neid !22_S	et	f	\N
140676	päriolu	päriolu =olu  (SgN  >päri+olu !17_S	et	f	\N
140677	päriolu	päriolu =olu  (SgG  >päri+olu !17_S	et	f	\N
140679	päriolu	päriolu =olu  (SgP  >päri+olu !17_S	et	f	\N
140680	jälitasid	jälitasid =jälita  (IndIpfSg2  >jälitama !27_V	et	f	\N
140681	jälitasid	jälitasid =jälita  (IndIpfPl3  >jälitama !27_V	et	f	\N
140692	sarnaseid	sarnaseid =sarnase  (PlP  >sarnane !10_A	et	f	\N
140693	sarnaseid	"sarnane %sarna  )NE_aA  <sarn ;22_S	et	f	\N
140694	õigeusuliste	õigeusuliste =usulis  (PlG  >õige+usuline !12_A	et	f	\N
140696	õigeusuliste	"õige+usuline %usu  )LINE_aA  <õige+usk ;22_S	et	f	\N
140706	paberlilledest	paberlilledest =ede  (SgEl  >paber+lill+ede !16_S	et	f	\N
140707	paberlilledest	paberlilledest =edes  (SgP  >paber+lill+edene !10_A	et	f	\N
140403	laiuvad	laiuvad =laiuva  (PlN  >laiuv !02_A	et	f	\N
140404	laiuvad	"laiuv %laiu  )V_vA  <laiuma ;27_V	et	f	\N
140437	folklooriekspeditsiooni	folklooriekspeditsiooni =ekspeditsiooni  (SgG  >folkloori+ekspeditsioon !22_S	et	f	\N
140438	folklooriekspeditsiooni	folklooriekspeditsiooni =ekspeditsiooni  (SgP  >folkloori+ekspeditsioon !22_S	et	f	\N
140439	folklooriekspeditsiooni	folklooriekspeditsiooni =ekspeditsiooni  (SgAdt  >folkloori+ekspeditsioon !22_S	et	f	\N
140440	ivan	?ivan =iva  (IndPrSg1  >ivama !27_V	et	f	\N
140441	ivan	?ivan =ivan  (SgN  >ivan !02_S	et	f	\N
140444	dementi	?dementi =dementi  (SgN  >dementi !01_S	et	f	\N
140446	dementi	?dementi =dementi  (SgG  >dementi !01_S	et	f	\N
140447	dementi	?dementi =dementi  (SgP  >dement !22_S	et	f	\N
140449	dementi	?dementi =dementi  (SgAdt  >dement !22_S	et	f	\N
140476	kilomeetrites	kilomeetrites =kilomeetri  (PlIn  >kilomeeter !02_S	et	f	\N
140478	kilomeetrites	kilomeetrites =meetri  (PlIn  >kilo+meeter !02_S	et	f	\N
140490	jälaste	?jälaste =jälas  (PlG  >jälas !09_S	et	f	\N
140491	jälaste	?jälaste =jälas  (PlG  >jälane !10_A	et	f	\N
140516	vaimukalt	vaimukalt =vaimuka  (SgAbl  >vaimukas !02_A	et	f	\N
140517	vaimukalt	vaimukalt =vaimukalt  (ID  >vaimukalt !41_D	et	f	\N
140518	vaimukalt	"vaimukalt %vaimuka  )LT_mD  <vaimukas ;02_A	et	f	\N
140528	tuisanuid	tuisanuid =tuisanu  (PlP  >tuisanu !01_S	et	f	\N
140529	tuisanuid	"tuisanu %tuisa  )NU_vS  <tuiskama ;29_V	et	f	\N
140530	lumehangeid	?lumehangeid =lumehange  (PlP  >lumehang !02_S	et	f	\N
140531	lumehangeid	?lumehangeid =lumehangei  (PlN  >lumehangei !26_S	et	f	\N
140532	lumehangeid	?lumehangeid =lumehangei  (SgP  >lumehangei !26_S	et	f	\N
140533	lumehangeid	?lumehangeid =hangei  (PlN  >lume+hangei !26_S	et	f	\N
140534	lumehangeid	?lumehangeid =hangei  (SgP  >lume+hangei !26_S	et	f	\N
140535	lumehangeid	?lumehangeid =hangeid  (SgN  >lume+hangeid !22_S	et	f	\N
140542	varustatud	varustatud =varusta  (PtsPtIps  >varustama !27_V	et	f	\N
140543	varustatud	varustatud =varustatu  (PlN  >varustatu !01_S	et	f	\N
140544	varustatud	"varustatu %varusta  )TU1_vS  <varustama ;27_V	et	f	\N
140545	varustatud	varustatud =varustatud  (ID  >varustatud !41_A	et	f	\N
140546	varustatud	"varustatud %varusta  )TUD_vA  <varustama ;27_V	et	f	\N
140547	laadogal	?laadogal =laadogal  (SgN  >laadogal !19_S	et	f	\N
140569	kinnitavad	kinnitavad =kinnita  (IndPrPl3  >kinnitama !27_V	et	f	\N
140570	kinnitavad	kinnitavad =kinnitava  (PlN  >kinnitav !02_A	et	f	\N
140571	kinnitavad	"kinnitav %kinnita  )V_vA  <kinnitama ;27_V	et	f	\N
140572	kinnitavad	kinnitavad =tava  (PlN  >kinni+tava !17_S	et	f	\N
140577	riijuta	?riijuta =riiju  (SgAb  >riiju !16_S	et	f	\N
140578	riijuta	?riijuta =riiju  (IndPrIps_  >riijuma !27_V	et	f	\N
140579	riijuta	?riijuta =riijuta  (IndPrPs_  >riijutama !27_V	et	f	\N
140580	riijuta	?riijuta =riijuta  (ImpPrSg2  >riijutama !27_V	et	f	\N
140588	artelli	artelli =artelli  (SgG  >artell !22_S	et	f	\N
140589	artelli	artelli =artelli  (SgP  >artell !22_S	et	f	\N
140590	artelli	artelli =artelli  (SgAdt  >artell !22_S	et	f	\N
140619	kuuldi	kuuldi =kuul  (IndIpfIps  >kuulma !33_V	et	f	\N
140620	kuuldi	kuuldi =kuuldi  (SgP  >kuuld !22_S	et	f	\N
140621	kuuldi	kuuldi =kuuldi  (SgAdt  >kuuld !22_S	et	f	\N
140622	suhtuti	suhtuti =suhtu  (IndIpfIps  >suhtuma !27_V	et	f	\N
140623	suhtuti	suhtuti =uti  (SgG  >suht+utt !22_S	et	f	\N
140634	suplemisest	suplemisest =suplemise  (SgEl  >suplemine !12_S	et	f	\N
140635	suplemisest	"suplemine %suple  )MINE_vS  <suplema ;30_V	et	f	\N
140684	pulmakommetes	pulmakommetes =me  (PlIn  >pulma+kom+mesi !15_S	et	f	\N
140685	pulmakommetes	pulmakommetes =mete  (PlIn  >pulma+kom+mett !22_S	et	f	\N
140686	pulmakommetes	pulmakommetes =komme  (PlIn  >pulma+komme !06_S	et	f	\N
140687	lausumistes	lausumistes =lausumis  (PlIn  >lausumine !12_S	et	f	\N
140689	lausumistes	"lausumine %lausu  )MINE_vS  <lausuma ;28_V	et	f	\N
140695	nina	nina =nina  (SgN  >nina !17_S	et	f	\N
140697	nina	nina =nina  (SgG  >nina !17_S	et	f	\N
140698	nina	nina =nina  (SgP  >nina !17_S	et	f	\N
140701	peighelele	?peighelele =peighelele  (PlP  >peighelel !19_S	et	f	\N
140702	hinnaline	hinnaline =hinnaline  (SgN  >hinnaline !12_A	et	f	\N
140703	hinnaline	"hinnaline %hinna  )LINE_aA  <hind ;22_S	et	f	\N
140704	tagastati	tagastati =tagasta  (IndIpfIps  >tagastama !27_V	et	f	\N
140705	tagastati	tagastati =tati  (SgG  >tagas+tatt !22_S	et	f	\N
140735	kostitamise	kostitamise =kostitamise  (SgG  >kostitamine !12_S	et	f	\N
140737	kostitamise	"kostitamine %kostita  )MINE_vS  <kostitama ;27_V	et	f	\N
140760	arvukus	arvukus =arvukus  (SgN  >arvukus !11_S	et	f	\N
140761	arvukus	"arvukus %arvuka  )US_aS  <arvukas ;02_A	et	f	\N
140762	pulmapidulisi	pulmapidulisi =pidulisi  (PlP  >pulma+piduline !12_S	et	f	\N
140763	pulmapidulisi	"pulma+piduline %pidu  )LINE_aA  <pulma+pidu ;17_S	et	f	\N
140766	piisas	piisas =piisa  (SgIn  >piisk !22_S	et	f	\N
140767	piisas	piisas =piisa  (IndIpfSg3  >piisama !29_V	et	f	\N
140768	eitavalt	eitavalt =eitava  (SgAbl  >eitav !02_A	et	f	\N
140769	eitavalt	"eitav %eita  )V_vA  <eitama ;27_V	et	f	\N
140770	eitavalt	eitavalt =eitavalt  (ID  >eitavalt !41_D	et	f	\N
140771	eitavalt	"eitavalt %eita  )VALT_mD  <eitama ;27_V	et	f	\N
140772	eitavalt	"eitavalt %eitava  )LT_mD  <eitav ;02_A	et	f	\N
140495	majakesi	"majakene %maja  )KENE_dS  <maja ;17_S	et	f	\N
140504	maaharijatele	maaharijatele =harija  (PlAll  >maa+harija !01_S	et	f	\N
140505	maaharijatele	maaharijatele =harija  (PlAll  >maa+harijas !02_A	et	f	\N
140521	peipsimaal	peipsimaal =maa  (SgAd  >peipsi+maa !26_S	et	f	\N
140522	peipsimaal	peipsimaal =maal  (SgN  >peipsi+maal !22_S	et	f	\N
140524	hinnatakse	hinnatakse =hinna  (IndPrIps  >hindama !29_V	et	f	\N
140525	hinnatakse	hinnatakse =takse  (PlP  >hinna+taks !22_S	et	f	\N
140526	sõiduomadusi	sõiduomadusi =omadusi  (PlP  >sõidu+omadus !11_S	et	f	\N
140527	sõiduomadusi	"sõidu+omadus %oma  )US_aS  <sõidu+oma ;17_A	et	f	\N
140555	kalameeste	kalameeste =mees  (PlG  >kala+meene !10_A	et	f	\N
140556	kalameeste	"kala+meene %mee  )NE_aA  <kala+mesi ;15_S	et	f	\N
140557	kalameeste	kalameeste =mees  (PlG  >kala+mees !13_S	et	f	\N
140561	ohtlikumaks	ohtlikumaks =ohtlikuma  (SgTr  >ohtlikum !02_A	et	f	\N
140562	ohtlikumaks	"ohtlikum %ohtliku  )M_cA  <ohtlik ;25_A	et	f	\N
140563	vihmaseks	vihmaseks =vihmase  (SgTr  >vihmane !10_A	et	f	\N
140564	vihmaseks	"vihmane %vihma  )NE_aA  <vihm ;22_S	et	f	\N
140565	vihmaseks	vihmaseks =seks  (SgN  >vihma+seks !22_S	et	f	\N
140566	jumalaema	jumalaema =ema  (SgN  >jumala+ema !17_S	et	f	\N
140567	jumalaema	jumalaema =ema  (SgG  >jumala+ema !17_S	et	f	\N
140568	jumalaema	jumalaema =ema  (SgP  >jumala+ema !17_S	et	f	\N
140573	kohtumist	kohtumist =kohtumis  (SgP  >kohtumine !12_S	et	f	\N
140574	kohtumist	"kohtumine %kohtu  )MINE_vS  <kohtuma ;27_V	et	f	\N
140591	omistatud	omistatud =omista  (PtsPtIps  >omistama !27_V	et	f	\N
140592	omistatud	omistatud =omistatu  (PlN  >omistatu !01_S	et	f	\N
140593	omistatud	"omistatu %omista  )TU1_vS  <omistama ;27_V	et	f	\N
140594	omistatud	omistatud =omistatud  (ID  >omistatud !41_A	et	f	\N
140595	omistatud	"omistatud %omista  )TUD_vA  <omistama ;27_V	et	f	\N
140616	peremehest	peremehest =mehe  (SgEl  >pere+mees !13_S	et	f	\N
140617	peremehest	peremehest =mehes  (SgP  >pere+mehene !10_A	et	f	\N
140618	peremehest	"pere+mehene %mehe  )NE_aA  <pere+mees ;13_S	et	f	\N
140624	selesse	?selesse =sele  (SgIll  >sele !16_S	et	f	\N
140625	selesse	?selesse =selesse  (SgG  >selesne !02_A	et	f	\N
140626	selesse	?selesse =selesse  (PlP  >seless !22_S	et	f	\N
140652	vaaraost	vaaraost =vaarao  (SgEl  >vaarao !26_S	et	f	\N
140653	vaaraost	vaaraost =ao  (SgEl  >vaar+agu !18_S	et	f	\N
140660	apokriiva	apokriiva =apokriiva  (SgN  >apokriiva !16_S	et	f	\N
140663	apokriiva	apokriiva =apokriiva  (SgG  >apokriiva !16_S	et	f	\N
140678	sõdalastaga	?sõdalastaga =sõdalasta  (SgKom  >sõdalasta !16_S	et	f	\N
140720	kütmise	kütmise =kütmise  (SgG  >kütmine !12?10_S	et	f	\N
140721	kütmise	"kütmine %küt  )MINE_vS  <kütma ;35_V	et	f	\N
140726	peigmees	peigmees =mee  (SgIn  >peig+mesi !15_S	et	f	\N
140727	peigmees	peigmees =mees  (SgN  >peig+mees !13_S	et	f	\N
140748	kattu	kattu =kattu  (SgP  >katt !22_S	et	f	\N
140749	kattu	kattu =kattu  (SgAdt  >kadu !18_S	et	f	\N
140750	kattu	kattu =kattu  (SgAdt  >katt !22_S	et	f	\N
140751	kattu	kattu =kattu  (IndPrPs_  >kattuma !27_V	et	f	\N
140752	kattu	kattu =kattu  (ImpPrSg2  >kattuma !27_V	et	f	\N
140753	ääretult	ääretult =ääretu  (SgAbl  >ääretu !01_A	et	f	\N
140754	ääretult	"ääretu %ääre  )TU2_kA  <äär ;13_S	et	f	\N
140755	ääretult	ääretult =ääretult  (ID  >ääretult !41_D	et	f	\N
140756	ääretult	"ääretult %ääre  )TULT2_mD  <äär ;13_S	et	f	\N
140757	ääretult	"ääretult %ääretu  )LT_mD  <ääretu ;01_A	et	f	\N
140764	austuse	austuse =austuse  (SgG  >austus !11~09_S	et	f	\N
140765	austuse	"austus %austa  )US_vS  <austama ;27_V	et	f	\N
140785	rohkus	rohkus =rohkus  (SgN  >rohkus !11~09_S	et	f	\N
140786	rohkus	"rohkus %rohke  )US_aS  <rohke ;01_A	et	f	\N
140812	pulmalisi	pulmalisi =pulmalisi  (PlP  >pulmaline !12_S	et	f	\N
140813	pulmalisi	"pulmaline %pulma  )LINE_aA  <pulm ;22_S	et	f	\N
140857	talvistepühad	?talvistepühad =talvistepüha  (PlN  >talvistepüha !16_S	et	f	\N
140866	tingimatta	?tingimatta =tingimatta  (SgN  >tingimatta !16_S	et	f	\N
140867	tingimatta	?tingimatta =tingimatta  (SgG  >tingimatta !16_S	et	f	\N
140868	tingimatta	?tingimatta =imatta  (SgN  >ting+imatta !01_S	et	f	\N
140869	tingimatta	?tingimatta =imatta  (SgG  >ting+imatta !01_S	et	f	\N
140890	naljalaule	naljalaule =lau  (SgAll  >nalja+laug !22_SA	et	f	\N
140891	naljalaule	naljalaule =laule  (PlP  >nalja+laul !22_S	et	f	\N
140901	meelt	meelt =mee  (SgAbl  >mesi !15_S	et	f	\N
140902	meelt	meelt =meel  (SgP  >meel !13_S	et	f	\N
140908	klaasi	klaasi =klaasi  (SgG  >klaas !22_S	et	f	\N
140909	klaasi	klaasi =klaasi  (SgP  >klaas !22_S	et	f	\N
140910	klaasi	klaasi =klaasi  (SgAdt  >klaas !22_S	et	f	\N
140911	klaasi	klaasi =klaasi  (IndPrPs_  >klaasima !28_V	et	f	\N
140912	klaasi	klaasi =klaasi  (ImpPrSg2  >klaasima !28_V	et	f	\N
140914	au	au =au  (SgP  >au !26_S	et	f	\N
140916	au	au =au  (SgN  >au !26_S	et	f	\N
140917	au	au =au  (SgG  >au !26_S	et	f	\N
140934	ületa	ületa =ületa  (IndPrPs_  >ületama !27_V	et	f	\N
140935	ületa	ületa =ületa  (ImpPrSg2  >ületama !27_V	et	f	\N
140941	leidlikuses	leidlikuses =leidlikuse  (SgIn  >leidlikus !11_S	et	f	\N
140600	potist	potist =poti  (SgEl  >pott !22_S	et	f	\N
140604	ühestki	ühestki =ühe  (SgEl  >ükski !00_P	et	f	\N
140605	ühestki	ühestki =ühe  (SgEl^  >üks !22_NP	et	f	\N
140606	ühestki	ühestki =ühes  (SgP^  >ühene !10_AS	et	f	\N
140608	ühestki	"ühene %ühe  )NE_aA^  <üks ;22_NP	et	f	\N
140610	ühestki	ühestki =ühest  (ID^  >ühest !41_D	et	f	\N
140612	mingist	mingist =mingi  (SgEl  >mingi !01_P	et	f	\N
140613	mingist	mingist =mingi  (SgEl  >mink !22_S	et	f	\N
140627	hirmutasid	hirmutasid =hirmuta  (IndIpfSg2  >hirmutama !27_V	et	f	\N
140628	hirmutasid	hirmutasid =hirmuta  (IndIpfPl3  >hirmutama !27_V	et	f	\N
140632	varasest	varasest =varase  (SgEl  >varane !10_A	et	f	\N
140633	varasest	"varane %vara  )NE_aA  <vara ;17_S	et	f	\N
140640	näkineiud	näkineiud =neiu  (PlN  >näki+neiu !16_S	et	f	\N
140641	näkineiud	näkineiud =neiu  (PlN  >näki+neid !22_S	et	f	\N
140642	elutsevad	elutsevad =elutse  (IndPrPl3  >elutsema !27_V	et	f	\N
140643	elutsevad	elutsevad =elutseva  (PlN  >elutsev !02_A	et	f	\N
140644	elutsevad	"elutsev %elutse  )V_vA  <elutsema ;27_V	et	f	\N
140657	inimkalast	inimkalast =kala  (SgEl  >inim+kala !17_S	et	f	\N
140658	inimkalast	inimkalast =kalas  (SgP  >inim+kalane !10_A	et	f	\N
140659	inimkalast	"inim+kalane %kala  )NE_aA  <inim+kala ;17_S	et	f	\N
140661	pärinevaid	pärinevaid =pärineva  (PlP  >pärinev !02_A	et	f	\N
140662	pärinevaid	"pärinev %pärine  )V_vA  <pärinema ;27_V	et	f	\N
140669	mustas	mustas =musta  (SgIn  >must !22_AS	et	f	\N
140670	mustas	mustas =musta  (IndIpfSg3  >mustama !29_V	et	f	\N
140671	uppunud	uppunud =uppu  (PtsPtPs  >uppuma !28_V	et	f	\N
140672	uppunud	uppunud =uppunu  (PlN  >uppunu !01_S	et	f	\N
140673	uppunud	"uppunu %uppu  )NU_vS  <uppuma ;28_V	et	f	\N
140674	uppunud	uppunud =uppunud  (ID  >uppunud !41_A	et	f	\N
140675	uppunud	"uppunud %uppu  )NUD_vA  <uppuma ;28_V	et	f	\N
140740	talitusi	talitusi =talitusi  (PlP  >talitus !11_S	et	f	\N
140741	talitusi	"talitus %talita  )US_vS  <talitama ;27_V	et	f	\N
140742	talitusi	"talitus %tali  )TUS2_aS  <tali ;17_S	et	f	\N
140758	esitajate	esitajate =esitaja  (PlG  >esitaja !01_S	et	f	\N
140759	esitajate	"esitaja %esita  )JA_vS  <esitama ;27_V	et	f	\N
140778	pulmakommete	pulmakommete =me  (PlG  >pulma+kom+mesi !15_S	et	f	\N
140779	pulmakommete	pulmakommete =komme  (PlG  >pulma+komme !06_S	et	f	\N
140839	tulevase	tulevase =tulevase  (SgG  >tulevane !12_AS	et	f	\N
140841	tulevase	tulevase =ase  (SgN  >tulev+ase !04_S	et	f	\N
140842	tulevase	tulevase =vase  (SgG  >tule+vask !22_S	et	f	\N
140843	varastasid	varastasid =varasta  (IndIpfSg2  >varastama !27_V	et	f	\N
140844	varastasid	varastasid =varasta  (IndIpfPl3  >varastama !27_V	et	f	\N
140845	rahvatarkust	rahvatarkust =us  (SgP  >rahva+tark+uks !14_S	et	f	\N
140846	rahvatarkust	rahvatarkust =tarkus  (SgP  >rahva+tarkus !11~09_S	et	f	\N
140847	rahvatarkust	"rahva+tarkus %tark  )US_aS  <rahva+tark ;22_AS	et	f	\N
140848	rahvatarkust	rahvatarkust =tarkus  (SgP  >rahva+tarkune !12~10_A	et	f	\N
140861	kelde	?kelde =kelde  (SgN  >kelde !06_S	et	f	\N
140862	kelde	?kelde =kelde  (SgG  >kelle !06_S	et	f	\N
140863	kelde	?kelde =kelde  (PlP  >keld !22_S	et	f	\N
140864	kelde	?kelde =kelde  (IndPrPs_  >keldema !27_V	et	f	\N
140865	kelde	?kelde =kelde  (ImpPrSg2  >keldema !27_V	et	f	\N
140896	vanaemasi	?vanaemasi =vanaemasi  (PlP  >vanaemane !12_A	et	f	\N
140899	lahutasid	lahutasid =lahuta  (IndIpfSg2  >lahutama !27_V	et	f	\N
140900	lahutasid	lahutasid =lahuta  (IndIpfPl3  >lahutama !27_V	et	f	\N
140920	kannatavad	kannatavad =kannata  (IndPrPl3  >kannatama !27_V	et	f	\N
140921	kannatavad	kannatavad =kannatava  (PlN  >kannatav !02_A	et	f	\N
140922	kannatavad	"kannatav %kannata  )V_vA  <kannatama ;27_V	et	f	\N
140923	kannatavad	kannatavad =tava  (PlN  >kanna+tava !17_S	et	f	\N
140926	eripärast	eripärast =pära  (SgEl  >eri+pära !17_S	et	f	\N
140927	eripärast	eripärast =päras  (SgP  >eri+pärane !10_A	et	f	\N
140928	eripärast	"eri+pärane %pära  )NE_aA  <eri+pära ;17_S	et	f	\N
140936	loode	loode =loode  (SgN  >loode !06_S	et	f	\N
140937	loode	loode =loode  (SgG  >loe !06_S	et	f	\N
140938	loode	loode =loode  (SgG  >loode !06_S	et	f	\N
140939	loode	loode =loode  (PlP  >lood !22_S	et	f	\N
140940	papist-armukesest	papist-armukesest =armukese  (SgEl  >papist-armuke !12_S	et	f	\N
140943	papist-armukesest	"papist-armuke %armu  )KE_dS  <papist-arm ;22_S	et	f	\N
140946	papist-armukesest	papist-armukesest =armukese  (SgEl  >papist-armukene !12_S	et	f	\N
140947	papist-armukesest	"papist-armukene %armu  )KENE_dS  <papist-arm ;22_S	et	f	\N
140972	oodatust	oodatust =oodatu  (SgEl  >oodatu !01_S	et	f	\N
140973	oodatust	"oodatu %ooda  )TU1_vS  <ootama ;29_V	et	f	\N
140981	oodatust	oodatust =oodatus  (SgP  >oodatus !11_S	et	f	\N
140982	oodatust	"oodatus %ooda  )TUS1_aS  <ootama ;29_V	et	f	\N
140996	pärimusjutt	?pärimusjutt =pärimusjutt  (SgN  >pärimusjutt !22_S	et	f	\N
140997	pärimusjutt	?pärimusjutt =musjutt  (SgN  >päri+musjutt !22_S	et	f	\N
141029	geneetiliselt	geneetiliselt =geneetilise  (SgAbl  >geneetiline !12_A	et	f	\N
141030	geneetiliselt	geneetiliselt =geneetiliselt  (ID  >geneetiliselt !41_D	et	f	\N
141031	geneetiliselt	"geneetiliselt %geneetilise  )LT_mD  <geneetiline ;12_A	et	f	\N
140609	vetevaimust	vetevaimust =vaimu  (SgEl  >vete+vaim !22_S	et	f	\N
140611	vetevaimust	vetevaimust =vaimu  (PlEl  >vete+vaim !22_S	et	f	\N
140614	muust	muust =muu  (SgEl  >muu !26_S	et	f	\N
140615	muust	muust =muu  (SgEl  >muu !26_P	et	f	\N
140629	pahuraid	pahuraid =pahura  (PlP  >pahur !02_A	et	f	\N
140630	pahuraid	pahuraid =rai  (PlN  >pahu+rai !26_S	et	f	\N
140631	pahuraid	pahuraid =rai  (SgP  >pahu+rai !26_S	et	f	\N
140636	lühijutukesed	lühijutukesed =jutukese  (PlN  >lühi+jutuke !12_S	et	f	\N
140637	lühijutukesed	"lühi+jutuke %jutu  )KE_dS  <lühi+jutt ;22_S	et	f	\N
140638	lühijutukesed	lühijutukesed =jutukese  (PlN  >lühi+jutukene !12_S	et	f	\N
140639	lühijutukesed	"lühi+jutukene %jutu  )KENE_dS  <lühi+jutt ;22_S	et	f	\N
140645	tekitatud	tekitatud =tekita  (PtsPtIps  >tekitama !27_V	et	f	\N
140646	tekitatud	tekitatud =tekitatu  (PlN  >tekitatu !01_S	et	f	\N
140647	tekitatud	"tekitatu %tekita  )TU1_vS  <tekitama ;27_V	et	f	\N
140648	tekitatud	tekitatud =tekitatud  (ID  >tekitatud !41_A	et	f	\N
140649	tekitatud	"tekitatud %tekita  )TUD_vA  <tekitama ;27_V	et	f	\N
140654	vaarao	vaarao =vaarao  (SgN  >vaarao !26_S	et	f	\N
140655	vaarao	vaarao =vaarao  (SgG  >vaarao !26_S	et	f	\N
140656	vaarao	vaarao =ao  (SgG  >vaar+agu !18_S	et	f	\N
140664	mütoloogilisi	mütoloogilisi =mütoloogilisi  (PlP  >mütoloogiline !12_A	et	f	\N
140665	mütoloogilisi	"mütoloogiline %mütoloogi  )LINE_aA  <mütoloog ;22_S	et	f	\N
140666	folklooris	folklooris =folkloori  (SgIn  >folkloor !22_S	et	f	\N
140667	folklooris	folklooris =loori  (SgIn  >folk+loori !16_S	et	f	\N
140668	folklooris	folklooris =loori  (SgIn  >folk+loor !22_S	et	f	\N
140682	eguptusest	?eguptusest =eguptuse  (SgEl  >eguptus !11_S	et	f	\N
140683	eguptusest	?eguptusest =eguptuses  (SgP  >eguptusene !12_A	et	f	\N
140688	maagilistes	maagilistes =maagilis  (PlIn  >maagiline !12_A	et	f	\N
140690	maagilistes	"maagiline %maagi  )LINE_aA  <maag ;22_S	et	f	\N
140691	maagilistes	"maagiline %maagi  )LINE_aA  <maak ;22_S	et	f	\N
140699	lubadust	lubadust =lubadus  (SgP  >lubadus !11_S	et	f	\N
140700	lubadust	lubadust =dust  (SgN  >luba+dust !22_S	et	f	\N
140710	lilledega	lilledega =lille  (PlKom  >lill !22_S	et	f	\N
140711	lilledega	lilledega =ede  (SgKom  >lill+ede !16_S	et	f	\N
140718	kööti	?kööti =kööti  (ID  >kööti !41_D	et	f	\N
140719	kööti	?kööti =kööti  (SgP  >kööt !22_S	et	f	\N
140722	kööti	?kööti =kööti  (SgAdt  >kööt !22_S	et	f	\N
140746	kommetega	kommetega =komme  (PlKom  >komme !06_S	et	f	\N
140747	kommetega	kommetega =me  (PlKom  >kom+mesi !15_S	et	f	\N
140773	süüdistuslaule	süüdistuslaule =lau  (SgAll  >süüdistus+laug !22_SA	et	f	\N
140775	süüdistuslaule	süüdistuslaule =laule  (PlP  >süüdistus+laul !22_S	et	f	\N
140792	peigmehest	peigmehest =mehe  (SgEl  >peig+mees !13_S	et	f	\N
140794	peigmehest	peigmehest =mehes  (SgP  >peig+mehene !10_A	et	f	\N
140795	peigmehest	"peig+mehene %mehe  )NE_aA  <peig+mees ;13_S	et	f	\N
140800	piiras	piiras =piira  (SgIn  >piird !22_S	et	f	\N
140802	piiras	piiras =piira  (IndIpfSg3  >piirama !29_V	et	f	\N
140819	väljavahetama	?väljavahetama =väljavaheta  (Sup  >väljavahetama !27_V	et	f	\N
140820	väljavahetama	?väljavahetama =väljavahetama  (SgG  >väljavahetam !02_A	et	f	\N
140821	väljavahetama	?väljavahetama =ama  (SgN  >välja+vahet+ama !17_S	et	f	\N
140822	väljavahetama	?väljavahetama =ama  (SgG  >välja+vahet+ama !17_S	et	f	\N
140823	väljavahetama	?väljavahetama =ama  (SgP  >välja+vahet+ama !17_S	et	f	\N
140824	väljavahetama	?väljavahetama =tama  (SgN  >välja+vahe+tama !17_S	et	f	\N
140825	väljavahetama	?väljavahetama =tama  (SgG  >välja+vahe+tama !17_S	et	f	\N
140826	väljavahetama	?väljavahetama =tama  (SgP  >välja+vahe+tama !17_S	et	f	\N
140827	väljavahetama	?väljavahetama =vahetama  (SgG  >välja+vahetam !02_A	et	f	\N
140837	äia	äia =äia  (SgG  >äi !22_S	et	f	\N
140838	äia	äia =äia  (SgP  >äi !22_S	et	f	\N
140840	äia	äia =äia  (SgAdt  >äi !22_S	et	f	\N
140872	kogujad	kogujad =koguja  (PlN  >koguja !01_S	et	f	\N
140875	kogujad	"koguja %kogu  )JA_vS  <koguma ;27_V	et	f	\N
140894	meenutasid	meenutasid =meenuta  (IndIpfSg2  >meenutama !27_V	et	f	\N
140895	meenutasid	meenutasid =meenuta  (IndIpfPl3  >meenutama !27_V	et	f	\N
140897	talvistel	talvistel =talvis  (PlAd  >talvine !10_A	et	f	\N
140898	talvistel	"talvine %talvi  )NE_aA  <talv ;22_S	et	f	\N
140903	vähesust	?vähesust =vähesu  (SgEl  >vähesu !01_S	et	f	\N
140904	vähesust	?vähesust =vähesus  (SgP  >vähesus !11_S	et	f	\N
140905	vähesust	?vähesust =sust  (SgN  >vähe+sust !22_S	et	f	\N
140906	haritustase	?haritustase =haritustase  (SgG  >haritustane !12_A	et	f	\N
140907	haritustase	?haritustase =tustase  (SgG  >hari+tustane !12~10_A	et	f	\N
140924	nappuse	nappuse =nappuse  (SgG  >nappus !11~09_S	et	f	\N
140925	nappuse	"nappus %napp  )US_aS  <napp ;22_A	et	f	\N
140929	fikseeritud	fikseeritud =fikseeri  (PtsPtIps  >fikseerima !28_V	et	f	\N
140930	fikseeritud	fikseeritud =fikseeritu  (PlN  >fikseeritu !01_S	et	f	\N
140931	fikseeritud	"fikseeritu %fikseeri  )TU1_vS  <fikseerima ;28_V	et	f	\N
140932	fikseeritud	fikseeritud =fikseeritud  (ID  >fikseeritud !41_A	et	f	\N
140933	fikseeritud	"fikseeritud %fikseeri  )TUD_vA  <fikseerima ;28_V	et	f	\N
140708	paberlilledest	"paber+lill+edene %ede  )NE_aA  <paber+lill+ede ;16_S	et	f	\N
140709	paberlilledest	paberlilledest =lille  (PlEl  >paber+lill !22_S	et	f	\N
140712	ehitud	ehitud =ehi  (PtsPtIps  >ehtima !28_V	et	f	\N
140713	ehitud	ehitud =ehitu  (PlN  >ehitu !01_AS	et	f	\N
140714	ehitud	"ehitu %ehi  )TU1_vS  <ehtima ;28_V	et	f	\N
140715	ehitud	ehitud =ehitu  (IndPrSg2  >ehituma !27_V	et	f	\N
140716	ehitud	ehitud =ehitud  (ID  >ehitud !41_A	et	f	\N
140717	ehitud	"ehitud %ehi  )TUD_vA  <ehtima ;28_V	et	f	\N
140723	kuuse	kuuse =kuuse  (SgG  >kuusk !22_S	et	f	\N
140724	kuuse	kuuse =kuuse  (SgG  >kuune !10_A	et	f	\N
140725	kuuse	"kuune %kuu  )NE_aA  <kuu ;26_S	et	f	\N
140728	noorpaar	?noorpaar =noorpaar  (SgN  >noorpaar !22_S	et	f	\N
140729	praemuna	praemuna =muna  (SgN  >prae+muna !17_S	et	f	\N
140730	praemuna	praemuna =muna  (SgG  >prae+muna !17_S	et	f	\N
140731	praemuna	praemuna =muna  (SgP  >prae+muna !17_S	et	f	\N
140732	väimes	?väimes =väime  (SgIn  >väime !06_S	et	f	\N
140733	väimes	?väimes =väime  (PlIn  >väim !22_S	et	f	\N
140734	väimes	?väimes =väime  (IndIpfSg3  >väimema !27_V	et	f	\N
140736	väimes	?väimes =väimes  (SgN  >väimes !09_S	et	f	\N
140738	oleva	oleva =oleva  (SgG  >olev !02_A	et	f	\N
140739	oleva	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
140743	sarnanevad	sarnanevad =sarnane  (IndPrPl3  >sarnanema !27_V	et	f	\N
140744	sarnanevad	sarnanevad =sarnaneva  (PlN  >sarnanev !02_A	et	f	\N
140745	sarnanevad	"sarnanev %sarnane  )V_vA  <sarnanema ;27_V	et	f	\N
140776	isamees	isamees =mee  (SgIn  >isa+mesi !15_S	et	f	\N
140777	isamees	isamees =mees  (SgN  >isa+mees !13_S	et	f	\N
140787	kaubast	kaubast =kauba  (SgEl  >kaup !22_S	et	f	\N
140788	kaubast	kaubast =kaubas  (SgP  >kaubane !10_A	et	f	\N
140789	kaubast	"kaubane %kauba  )NE_aA  <kaup ;22_S	et	f	\N
140790	kaupmehest	kaupmehest =mehe  (SgEl  >kaup+mees !13_S	et	f	\N
140791	kaupmehest	kaupmehest =mehes  (SgP  >kaup+mehene !10_A	et	f	\N
140793	kaupmehest	"kaup+mehene %mehe  )NE_aA  <kaup+mees ;13_S	et	f	\N
140798	noorpaari	?noorpaari =noorpaari  (SgN  >noorpaari !16_S	et	f	\N
140799	noorpaari	?noorpaari =noorpaari  (SgG  >noorpaari !16_S	et	f	\N
140801	noorpaari	?noorpaari =noorpaari  (SgG  >noorpaar !22_S	et	f	\N
140803	noorpaari	?noorpaari =noorpaari  (SgP  >noorpaar !22_S	et	f	\N
140804	noorpaari	?noorpaari =noorpaari  (SgAdt  >noorpaar !22_S	et	f	\N
140805	noorpaari	?noorpaari =noorpaari  (IndPrPs_  >noorpaarima !28_V	et	f	\N
140806	noorpaari	?noorpaari =noorpaari  (ImpPrSg2  >noorpaarima !28_V	et	f	\N
140807	lasknud	lasknud =lask  (PtsPtPs  >laskma !34_V	et	f	\N
140808	lasknud	lasknud =lasknu  (PlN  >lasknu !01_S	et	f	\N
140809	lasknud	"lasknu %lask  )NU_vS  <laskma ;34_V	et	f	\N
140810	lasknud	lasknud =lasknud  (ID  >lasknud !41_A	et	f	\N
140811	lasknud	"lasknud %lask  )NUD_vA  <laskma ;34_V	et	f	\N
140816	lauale	lauale =laua  (SgAll  >laud !22_S	et	f	\N
140817	lauale	lauale =ale  (SgN  >lau+ale !16_S	et	f	\N
140818	lauale	lauale =ale  (SgG  >lau+ale !16_S	et	f	\N
140828	mõistagi	mõistagi =mõistagi  (ID  >mõistagi !41_D	et	f	\N
140829	mõistagi	mõistagi =mõist  (Inf^  >mõistma !34_V	et	f	\N
140830	mõistagi	mõistagi =mõista  (IndPrPs_^  >mõistma !34_V	et	f	\N
140831	mõistagi	mõistagi =mõista  (ImpPrSg2^  >mõistma !34_V	et	f	\N
140832	sammul	sammul =sammu  (SgAd  >samm !22_S	et	f	\N
140833	sammul	sammul =sammu  (PlAd  >samb !22_S	et	f	\N
140834	lahtipunutud	lahtipunutud =punu  (PtsPtIps  >lahti+_punuma !27_V	et	f	\N
140835	lahtipunutud	lahtipunutud =punutu  (PlN  >lahti+punutu !01_AS	et	f	\N
140836	lahtipunutud	"lahti+punutu %punu  )TU2_kA  <lahti+punu ;17_S	et	f	\N
140880	vaatamatta	?vaatamatta =vaatamatta  (SgN  >vaatamatta !16_S	et	f	\N
140881	vaatamatta	?vaatamatta =vaatamatta  (SgG  >vaatamatta !16_S	et	f	\N
140882	folkloristi	folkloristi =folkloristi  (SgG  >folklorist !22_S	et	f	\N
140883	folkloristi	folkloristi =folkloristi  (SgP  >folklorist !22_S	et	f	\N
140884	folkloristi	folkloristi =folkloristi  (SgAdt  >folklorist !22_S	et	f	\N
140887	üleskirjutada	?üleskirjutada =üleskirjuta  (Inf  >üleskirjutama !27_V	et	f	\N
140888	neljavärsilisi	neljavärsilisi =värsilisi  (PlP  >nelja+värsiline !12_A	et	f	\N
140889	neljavärsilisi	"nelja+värsiline %värsi  )LINE_aA  <nelja+värss ;22_S	et	f	\N
140948	luiskajatest	luiskajatest =luiskaja  (PlEl  >luiskaja !01_S	et	f	\N
140949	luiskajatest	"luiskaja %luiska  )JA_vS  <luiskama ;29_V	et	f	\N
140950	mütoloogilise	mütoloogilise =mütoloogilise  (SgG  >mütoloogiline !12_A	et	f	\N
140951	mütoloogilise	"mütoloogiline %mütoloogi  )LINE_aA  <mütoloog ;22_S	et	f	\N
140952	liigi	liigi =liigi  (SgG  >liik !22_S	et	f	\N
140953	liigi	liigi =liigi  (SgP  >liig !22_S	et	f	\N
140954	liigi	liigi =liigi  (SgAdt  >liig !22_S	et	f	\N
140955	liigi	liigi =lii  (SgN^  >lii !26_S	et	f	\N
140956	liigi	liigi =lii  (SgG^  >lii !26_S	et	f	\N
140957	leidu	leidu =leidu  (SgP  >leid !22_S	et	f	\N
140958	leidu	leidu =leidu  (SgAdt  >leid !22_S	et	f	\N
140959	leidu	leidu =leidu  (IndPrPs_  >leiduma !27_V	et	f	\N
140960	leidu	leidu =leidu  (ImpPrSg2  >leiduma !27_V	et	f	\N
140974	vastuolulised	vastuolulised =olulise  (PlN  >vastu+oluline !12_A	et	f	\N
140774	eitavalt	eitavalt =tava  (SgAbl  >ei+tava !17_S	et	f	\N
140780	ostu-müügi	ostu-müügi =müügi  (SgG  >ostu-müük !22_S	et	f	\N
140781	ostu-müügi	ostu-müügi =müü  (SgN^  >ostu-müü !26_S	et	f	\N
140782	ostu-müügi	ostu-müügi =müü  (SgG^  >ostu-müü !26_S	et	f	\N
140783	ostu-müügi	ostu-müügi =müü  (IndPrPs_^  >ostu-müüma !38_V	et	f	\N
140784	ostu-müügi	ostu-müügi =müü  (ImpPrSg2^  >ostu-müüma !38_V	et	f	\N
140796	külarahvas	külarahvas =rahva  (SgIn  >küla+rahvas !07_S	et	f	\N
140797	külarahvas	külarahvas =rahvas  (SgN  >küla+rahvas !07_S	et	f	\N
140814	abielumees	abielumees =mee  (SgIn  >abi+elu+mesi !15_S	et	f	\N
140815	abielumees	abielumees =mees  (SgN  >abi+elu+mees !13_S	et	f	\N
140849	kooliõpilastele	kooliõpilastele =las  (PlAll  >kooli+õpi+laps !14_S	et	f	\N
140850	kooliõpilastele	kooliõpilastele =laste  (PlAll  >kooli+õpi+last !22_S	et	f	\N
140851	kooliõpilastele	kooliõpilastele =õpilas  (PlAll  >kooli+õpilane !12_S	et	f	\N
140852	arianti	?arianti =arianti  (SgP  >ariant !22_S	et	f	\N
140853	arianti	?arianti =arianti  (SgAdt  >ariant !22_S	et	f	\N
140854	üksikasjaliselt	üksikasjaliselt =asjalise  (SgAbl  >üksik+asjaline !12_SA	et	f	\N
140855	üksikasjaliselt	"üksik+asjaline %asja  )LINE_aA  <üksik+asi ;24_S	et	f	\N
140856	üksikasjaliselt	"üksik+asjaliselt %asja  )LISELT_mD  <üksik+asi ;24_S	et	f	\N
140858	ennustustest	ennustustest =ennustus  (PlEl  >ennustus !11_S	et	f	\N
140859	ennustustest	"ennustus %ennusta  )US_vS  <ennustama ;27_V	et	f	\N
140860	ennustustest	ennustustest =test  (SgN  >ennustus+test !22_S	et	f	\N
140870	raseduse	raseduse =raseduse  (SgG  >rasedus !11_S	et	f	\N
140871	raseduse	"rasedus %raseda  )US_aS  <rase ;02_AS	et	f	\N
140873	esitanud	esitanud =esita  (PtsPtPs  >esitama !27_V	et	f	\N
140874	esitanud	esitanud =esitanu  (PlN  >esitanu !01_S	et	f	\N
140876	esitanud	"esitanu %esita  )NU_vS  <esitama ;27_V	et	f	\N
140877	esitanud	esitanud =esitanud  (ID  >esitanud !41_A	et	f	\N
140878	esitanud	"esitanud %esita  )NUD_vA  <esitama ;27_V	et	f	\N
140879	esitanud	esitanud =tanu  (PlN  >esi+tanu !17_S	et	f	\N
140885	eelistasid	eelistasid =eelista  (IndIpfSg2  >eelistama !27_V	et	f	\N
140886	eelistasid	eelistasid =eelista  (IndIpfPl3  >eelistama !27_V	et	f	\N
140892	kirjeldasid	kirjeldasid =kirjelda  (IndIpfSg2  >kirjeldama !27_V	et	f	\N
140893	kirjeldasid	kirjeldasid =kirjelda  (IndIpfPl3  >kirjeldama !27_V	et	f	\N
140913	vanausulistel	vanausulistel =usulis  (PlAd  >vana+usuline !12_A	et	f	\N
140915	vanausulistel	"vana+usuline %usu  )LINE_aA  <vana+usk ;22_S	et	f	\N
140918	siinkohas	siinkohas =koha  (SgIn  >siin+koha !17_S	et	f	\N
140919	siinkohas	siinkohas =koha  (SgIn  >siin+koht !22_S	et	f	\N
140942	võistlejatest	võistlejatest =võistleja  (PlEl  >võistleja !01_S	et	f	\N
140944	võistlejatest	"võistleja %võistle  )JA_vS  <võistlema ;30_V	et	f	\N
140988	röövlist	röövlist =röövli  (SgEl  >röövel !02_S	et	f	\N
140989	röövlist	röövlist =röövlis  (SgP  >röövline !12~10_A	et	f	\N
140992	röövlist	"röövline %röövli  )NE_aA  <röövel ;02_S	et	f	\N
141013	nikola-imetegija	nikola-imetegija =tegija  (SgN  >nikola-ime+tegija !01_S	et	f	\N
141014	nikola-imetegija	nikola-imetegija =tegija  (SgG  >nikola-ime+tegija !01_S	et	f	\N
141020	imelistest	imelistest =imelis  (PlEl  >imeline !12_A	et	f	\N
141022	imelistest	"imeline %ime  )LINE_aA  <ime ;16_S	et	f	\N
141027	päästmise	päästmise =päästmise  (SgG  >päästmine !12?10_S	et	f	\N
141028	päästmise	"päästmine %pääst  )MINE_vS  <päästma ;34_V	et	f	\N
141032	ettekuulutuslikust	?ettekuulutuslikust =ettekuulutusliku  (SgEl  >ettekuulutuslik !25_A	et	f	\N
141033	ettekuulutuslikust	?ettekuulutuslikust =ettekuulutuslikus  (SgP  >ettekuulutuslikus !11?09_S	et	f	\N
141034	ettekuulutuslikust	?ettekuulutuslikust =tusliku  (SgEl  >ette+kuulu+tuslik !25_A	et	f	\N
141035	ettekuulutuslikust	?ettekuulutuslikust =tusliku  (SgEl  >ette+kuulu+tusliku !01_S	et	f	\N
141036	ettekuulutuslikust	?ettekuulutuslikust =tuslikus  (SgP  >ette+kuulu+tuslikus !11_S	et	f	\N
141037	ettekuulutuslikust	?ettekuulutuslikust =utusliku  (SgEl  >ette+kuul+utuslik !25_A	et	f	\N
141038	ettekuulutuslikust	?ettekuulutuslikust =utuslikus  (SgP  >ette+kuul+utuslikus !11?09_S	et	f	\N
141039	ettekuulutuslikust	?ettekuulutuslikust =lutusliku  (SgEl  >ette+kuu+lutuslik !25_A	et	f	\N
141040	ettekuulutuslikust	?ettekuulutuslikust =lutuslikus  (SgP  >ette+kuu+lutuslikus !11?09_S	et	f	\N
141042	ettekuulutuslikust	?ettekuulutuslikust =kuulutusliku  (SgEl  >ette+kuulutuslik !25_A	et	f	\N
141044	ettekuulutuslikust	?ettekuulutuslikust =kuulutuslikus  (SgP  >ette+kuulutuslikus !11?09_S	et	f	\N
141055	eakamad	eakamad =eakama  (PlN  >eakam !02_A	et	f	\N
141056	eakamad	"eakam %eaka  )M_cA  <eakas ;02_A	et	f	\N
141057	eakamad	eakamad =kama  (PlN  >ea+kama !17_S	et	f	\N
141063	veeuputusest	veeuputusest =uputuse  (SgEl  >vee+uputus !11_S	et	f	\N
141064	veeuputusest	veeuputusest =uputuses  (SgP  >vee+uputusene !12_A	et	f	\N
141065	veeuputusest	"vee+uputusene %uputuse  )NE_aA  <vee+uputus ;11_S	et	f	\N
141083	athose	?athose =athose  (SgG  >athos !11~09_S	et	f	\N
141099	võrdlemisi	võrdlemisi =võrdlemisi  (ID  >võrdlemisi !41_D	et	f	\N
141100	võrdlemisi	võrdlemisi =võrdlemisi  (PlP  >võrdlemine !12_S	et	f	\N
141101	võrdlemisi	"võrdlemine %võrdle  )MINE_vS  <võrdlema ;30_V	et	f	\N
141132	rütmika	rütmika =rütmika  (SgN  >rütmika !01_S	et	f	\N
140945	leidlikuses	"leidlikus %leidliku  )US_aS  <leidlik ;25_A	et	f	\N
140968	olinüleskirjutatud	?olinüleskirjutatud =olinüleskirjuta  (PtsPtIps  >olinüleskirjutama !27_V	et	f	\N
140969	olinüleskirjutatud	?olinüleskirjutatud =olinüleskirjutatu  (PlN  >olinüleskirjutatu !01_S	et	f	\N
140970	olinüleskirjutatud	?olinüleskirjutatud =olinüleskirjutatu  (IndPrSg2  >olinüleskirjutatuma !27_V	et	f	\N
140971	olinüleskirjutatud	?olinüleskirjutatud =olinüleskirjutatud  (ID  >olinüleskirjutatud !41_A	et	f	\N
140983	ajaloolaste	ajaloolaste =las  (PlG  >aja+loo+laps !14_S	et	f	\N
140984	ajaloolaste	ajaloolaste =laste  (PlP  >aja+loo+last !22_S	et	f	\N
140985	ajaloolaste	ajaloolaste =loolas  (PlG  >aja+loolane !12?10_S	et	f	\N
140990	vasjkast	?vasjkast =vasjka  (SgEl  >vasjka !01_S	et	f	\N
140991	vasjkast	?vasjkast =vasjkas  (SgP  >vasjkas !07_S	et	f	\N
140993	vasjkast	?vasjkast =vasjkas  (SgP  >vasjkane !12~10_A	et	f	\N
141005	kurat	kurat =kurat  (ID  >kurat !41_I	et	f	\N
141006	kurat	kurat =kurat  (SgN  >kurat !02_S	et	f	\N
141018	populaatsem	?populaatsem =populaatsem  (SgN  >populaatsem !02_A	et	f	\N
141019	populaatsem	?populaatsem =ulaatsem  (SgN  >pop+ulaatsem !02_A	et	f	\N
141050	igapäevaelus	igapäevaelus =elu  (SgIn  >iga+päeva+elu !17_S	et	f	\N
141051	igapäevaelus	igapäevaelus =elus  (SgN  >iga+päeva+elus !02_A	et	f	\N
141052	igapäevaelus	igapäevaelus =aelus  (SgN  >iga+päev+aelus !11~09_S	et	f	\N
141072	nutulaul	nutulaul =lau  (SgAd  >nutu+laug !22_SA	et	f	\N
141073	nutulaul	nutulaul =laul  (SgN  >nutu+laul !22_S	et	f	\N
141077	jutustustel	jutustustel =jutustus  (PlAd  >jutustus !11_S	et	f	\N
141078	jutustustel	"jutustus %jutusta  )US_vS  <jutustama ;27_V	et	f	\N
141079	samaarilanna	?samaarilanna =samaarilanna  (SgN  >samaarilanna !16_S	et	f	\N
141080	samaarilanna	?samaarilanna =samaarilanna  (SgG  >samaarilanna !16_S	et	f	\N
141081	samaarilanna	?samaarilanna =arilanna  (SgN  >sama+arilanna !16_S	et	f	\N
141082	samaarilanna	?samaarilanna =arilanna  (SgG  >sama+arilanna !16_S	et	f	\N
141084	surmatunnist	surmatunnist =tunni  (SgEl  >surma+tund !22_S	et	f	\N
141085	surmatunnist	surmatunnist =tunnis  (SgP  >surma+tunnine !10_A	et	f	\N
141086	surmatunnist	"surma+tunnine %tunni  )NE_aA  <surma+tund ;22_S	et	f	\N
141092	preestrideta	?preestrideta =preestrideta  (IndPrPs_  >preestridetama !27_V	et	f	\N
141093	preestrideta	?preestrideta =preestrideta  (ImpPrSg2  >preestridetama !27_V	et	f	\N
141094	lapsukest	lapsukest =lapsukes  (SgP  >lapsuke !12_S	et	f	\N
141095	lapsukest	"lapsuke %lapsu  )KE_dS  <laps ;22_S	et	f	\N
141096	lapsukest	lapsukest =lapsukes  (SgP  >lapsukene !12_S	et	f	\N
141097	lapsukest	"lapsukene %lapsu  )KENE_dS  <laps ;22_S	et	f	\N
141098	lapsukest	lapsukest =kest  (SgN  >lapsu+kest !22_S	et	f	\N
141130	rahvaluulele	rahvaluulele =luule  (SgAll  >rahva+luule !06_S	et	f	\N
141131	rahvaluulele	rahvaluulele =luule  (PlAll  >rahva+luul !22_S	et	f	\N
141182	trükikogumikke	trükikogumikke =mikke  (SgG  >trüki+kogu+mike !06_S	et	f	\N
141183	trükikogumikke	"trüki+kogu+mike %mi  )KE_dS  <trüki+kogu+mi ;26_S	et	f	\N
141184	trükikogumikke	trükikogumikke =mikke  (PlP  >trüki+kogu+mikk !22_S	et	f	\N
141185	trükikogumikke	trükikogumikke =kogumikke  (PlP  >trüki+kogumik !25_S	et	f	\N
141198	daugavpilsist	?daugavpilsist =daugavpilsis  (SgP  >daugavpilsis !09_S	et	f	\N
141199	daugavpilsist	?daugavpilsist =daugavpilsist  (SgN  >daugavpilsist !22_S	et	f	\N
141215	käsikirjalised	käsikirjalised =kirjalise  (PlN  >käsi+kirjaline !12_A	et	f	\N
141217	käsikirjalised	"käsi+kirjaline %kirja  )LINE_aA  <käsi+kiri ;24_S	et	f	\N
141220	noteeritud	noteeritud =noteeri  (PtsPtIps  >noteerima !28_V	et	f	\N
141221	noteeritud	noteeritud =noteeritu  (PlN  >noteeritu !01_S	et	f	\N
141222	noteeritud	"noteeritu %noteeri  )TU1_vS  <noteerima ;28_V	et	f	\N
141223	noteeritud	noteeritud =noteeritud  (ID  >noteeritud !41_A	et	f	\N
141224	noteeritud	"noteeritud %noteeri  )TUD_vA  <noteerima ;28_V	et	f	\N
141230	kallastes	kallastes =kallas  (PlIn  >kallas !07_S	et	f	\N
141231	kallastes	kallastes =kallas  (PlIn  >kallane !10_A	et	f	\N
141232	kallastes	"kallane %kalla  )NE_aA  <kalla ;16_S	et	f	\N
141247	nooremale	nooremale =noorema  (SgAll  >noorem !02_A	et	f	\N
141248	nooremale	"noorem %noore  )M_cA  <noor ;13_AS	et	f	\N
141249	nooremale	nooremale =ale  (SgN  >noorem+ale !16_S	et	f	\N
141250	nooremale	nooremale =ale  (SgG  >noorem+ale !16_S	et	f	\N
141251	nooremale	nooremale =male  (SgN  >noore+male !16_S	et	f	\N
141252	nooremale	nooremale =male  (SgG  >noore+male !16_S	et	f	\N
141253	nooremale	nooremale =ema  (SgAll  >noor+ema !17_S	et	f	\N
141297	jääaugust	jääaugust =augu  (SgEl  >jää+auk !22_S	et	f	\N
141298	jääaugust	jääaugust =august  (SgN  >jää+august !02_S	et	f	\N
141311	ülestõusmispüha	ülestõusmispüha =püha  (SgN  >üles+tõusmis+püha !17_SA	et	f	\N
141312	ülestõusmispüha	ülestõusmispüha =püha  (SgG  >üles+tõusmis+püha !17_SA	et	f	\N
141313	ülestõusmispüha	ülestõusmispüha =püha  (SgP  >üles+tõusmis+püha !17_SA	et	f	\N
141316	korilauljad	?korilauljad =korilaulja  (PlN  >korilauljas !02_A	et	f	\N
141317	korilauljad	?korilauljad =korilaulja  (PlN  >korilaulja !16_S	et	f	\N
141321	rabskije	### rabskije	et	f	\N
141338	sööginõusi	?sööginõusi =sööginõusi  (SgN  >sööginõusi !16_S	et	f	\N
141339	sööginõusi	?sööginõusi =sööginõusi  (SgG  >sööginõusi !16_S	et	f	\N
140961	keelelises	keelelises =keelelise  (SgIn  >keeleline !12_A	et	f	\N
140962	keelelises	"keeleline %keele  )LINE_aA  <keel ;13_S	et	f	\N
140963	pärimusi	pärimusi =pärimusi  (PlP  >pärimus !11_S	et	f	\N
140964	pärimusi	"pärimus %päri  )MUS_vS  <pärima ;27_V	et	f	\N
140965	pärimusi	pärimusi =musi  (SgN  >päri+musi !17_S	et	f	\N
140966	pärimusi	pärimusi =musi  (SgG  >päri+musi !17_S	et	f	\N
140967	pärimusi	pärimusi =musi  (SgP  >päri+musi !17_S	et	f	\N
141001	üksikult	üksikult =üksiku  (SgAbl  >üksik !02_A	et	f	\N
141002	üksikult	üksikult =üksikult  (ID  >üksikult !41_D	et	f	\N
141003	üksikult	"üksikult %üksiku  )LT_mD  <üksik ;02_A	et	f	\N
141004	üksikult	üksikult =kult  (SgN  >üksi+kult !22_S	et	f	\N
141007	vanausulisi	vanausulisi =usulisi  (PlP  >vana+usuline !12_A	et	f	\N
141008	vanausulisi	"vana+usuline %usu  )LINE_aA  <vana+usk ;22_S	et	f	\N
141009	tänapäevalgi	tänapäevalgi =algi  (SgG  >täna+päev+alk !22_S	et	f	\N
141010	tänapäevalgi	tänapäevalgi =algi  (SgP  >täna+päev+alg !22_S	et	f	\N
141011	tänapäevalgi	tänapäevalgi =algi  (SgAdt  >täna+päev+alg !22_S	et	f	\N
141012	tänapäevalgi	tänapäevalgi =päeva  (SgAd^  >täna+päev !22_S	et	f	\N
141015	levivad	levivad =levi  (IndPrPl3  >levima !27_V	et	f	\N
141016	levivad	levivad =leviva  (PlN  >leviv !02_A	et	f	\N
141017	levivad	"leviv %levi  )V_vA  <levima ;27_V	et	f	\N
141053	endimisi	?endimisi =endimisi  (ID  >endimisi !41_D	et	f	\N
141054	endimisi	?endimisi =endimisi  (PlP  >endimine !12_S	et	f	\N
141074	loodel	loodel =loode  (SgAd  >loe !06_S	et	f	\N
141075	loodel	loodel =loode  (SgAd  >loode !06_S	et	f	\N
141076	loodel	loodel =loode  (PlAd  >lood !22_S	et	f	\N
141135	süllaabi-tooniline	süllaabi-tooniline =tooniline  (SgN  >süllaabi-tooniline !12_A	et	f	\N
141136	süllaabi-tooniline	"süllaabi-tooniline %tooni  )LINE_aA  <süllaabi-toon ;22_S	et	f	\N
141144	antooniusest	?antooniusest =antooniuse  (SgEl  >antoonius !11_S	et	f	\N
141146	antooniusest	?antooniusest =antooniuses  (SgP  >antooniusene !12_A	et	f	\N
141162	hauatagusesse	hauatagusesse =sesse  (PlP  >haua+tagu+sess !22_S	et	f	\N
141164	hauatagusesse	hauatagusesse =taguse  (SgIll  >haua+tagune !10_AS	et	f	\N
141167	antoonius	?antoonius =antooniu  (SgIn  >antooniu !01_S	et	f	\N
141168	antoonius	?antoonius =antoonius  (SgN  >antoonius !11_S	et	f	\N
141193	masinakirja-	masinakirja- =kirja  (SgG  >masina+kiri !24_S	et	f	\N
141194	masinakirja-	masinakirja- =kirja  (SgP  >masina+kiri !24_S	et	f	\N
141195	masinakirja-	masinakirja- =kirja  (SgAdt  >masina+kiri !24_S	et	f	\N
141206	varieerimine	varieerimine =varieerimine  (SgN  >varieerimine !12_S	et	f	\N
141207	varieerimine	"varieerimine %varieeri  )MINE_vS  <varieerima ;28_V	et	f	\N
141237	taaselustus	taaselustus =elustu  (IndIpfSg3  >taas+elustuma !27_V	et	f	\N
141238	taaselustus	taaselustus =elustus  (SgN  >taas+elustus !11_S	et	f	\N
141239	taaselustus	"taas+elustus %elusta  )US_vS  <taas+elustama ;27_V	et	f	\N
141256	levinuid	levinuid =levinu  (PlP  >levinu !01_S	et	f	\N
141257	levinuid	"levinu %levi  )NU_vS  <levima ;27_V	et	f	\N
141258	kogumikus	kogumikus =kogumiku  (SgIn  >kogumik !25_S	et	f	\N
141259	kogumikus	kogumikus =miku  (SgIn  >kogu+mikk !22_S	et	f	\N
141262	stilistilisi	stilistilisi =stilistilisi  (PlP  >stilistiline !12_A	et	f	\N
141263	stilistilisi	"stilistiline %stilisti  )LINE_aA  <stilist ;22_S	et	f	\N
141273	söögilauda	söögilauda =lauda  (SgG  >söögi+laut !22_S	et	f	\N
141274	söögilauda	söögilauda =lauda  (SgP  >söögi+laud !22_S	et	f	\N
141275	söögilauda	söögilauda =lauda  (SgAdt  >söögi+laud !22_S	et	f	\N
141286	ristikujuliselt	ristikujuliselt =ujulise  (SgAbl  >ristik+ujuline !12_A	et	f	\N
141287	ristikujuliselt	"ristik+ujuline %uju  )LINE_aA  <ristik+uju ;17_S	et	f	\N
141288	ristikujuliselt	"ristik+ujuliselt %uju  )LISELT_mD  <ristik+uju ;17_S	et	f	\N
141289	ristikujuliselt	ristikujuliselt =kujulise  (SgAbl  >risti+kujuline !12_A	et	f	\N
141290	ristikujuliselt	"risti+kujuline %kuju  )LINE_aA  <risti+kuju ;17_S	et	f	\N
141291	ristikujuliselt	"risti+kujuliselt %kuju  )LISELT_mD  <risti+kuju ;17_S	et	f	\N
141292	ristikujuliselt	"risti+kujuliselt %kujulise  )LT_mD  <risti+kujuline ;12_A	et	f	\N
141314	suitsutakse	suitsutakse =suitsu  (IndPrIps  >suitsuma !27_V	et	f	\N
141315	suitsutakse	suitsutakse =takse  (PlP  >suitsu+taks !22_S	et	f	\N
141322	sõnapaarist	?sõnapaarist =sõnapaari  (SgEl  >sõnapaari !16_S	et	f	\N
141323	sõnapaarist	?sõnapaarist =sõnapaari  (SgEl  >sõnapaar !22_S	et	f	\N
141324	sõnapaarist	?sõnapaarist =sõnapaaris  (SgP  >sõnapaaris !09_S	et	f	\N
141325	sõnapaarist	?sõnapaarist =paarist  (SgN  >sõna+paarist !22_S	et	f	\N
141328	kogudusest	kogudusest =koguduse  (SgEl  >kogudus !11_S	et	f	\N
141329	kogudusest	kogudusest =koguduses  (SgP  >kogudusene !12_A	et	f	\N
141330	kogudusest	"kogudusene %koguduse  )NE_aA  <kogudus ;11_S	et	f	\N
141352	samast	samast =sama  (SgEl  >sama !17_P	et	f	\N
141353	samast	samast =samas  (SgP  >samane !10_AP	et	f	\N
141369	vetelpäästja	vetelpäästja =päästja  (SgN  >vetel+päästja !01_S	et	f	\N
141370	vetelpäästja	vetelpäästja =päästja  (SgG  >vetel+päästja !01_S	et	f	\N
141399	saates	saates =saat  (Ger  >saatma !34_V	et	f	\N
141400	saates	saates =saate  (SgIn  >saade !06_S	et	f	\N
141401	lehmakesed	lehmakesed =lehmakese  (PlN  >lehmake !12_S	et	f	\N
140975	vastuolulised	"vastu+oluline %olu  )LINE_aA  <vastu+olu ;17_S	et	f	\N
140976	lood	lood =loo  (PlN  >lugu !18_S	et	f	\N
140977	lood	lood =loo  (PlN  >loog !22_S	et	f	\N
140978	lood	lood =loo  (PlN  >lood !22_S	et	f	\N
140979	lood	lood =loo  (IndPrSg2  >looma !38_V	et	f	\N
140980	lood	lood =lood  (SgN  >lood !22_S	et	f	\N
140986	pärimus	pärimus =pärimus  (SgN  >pärimus !11_S	et	f	\N
140987	pärimus	"pärimus %päri  )MUS_vS  <pärima ;27_V	et	f	\N
140994	punasest	punasest =punase  (SgEl  >punane !10_AS	et	f	\N
140995	punasest	"punane %puna  )NE_aA  <puna ;17_S	et	f	\N
140998	kompaktselt	kompaktselt =kompaktse  (SgAbl  >kompaktne !02_A	et	f	\N
140999	kompaktselt	kompaktselt =kompaktselt  (ID  >kompaktselt !41_D	et	f	\N
141000	kompaktselt	"kompaktselt %kompaktse  )LT_mD  <kompaktne ;02_A	et	f	\N
141021	päästmistest	päästmistest =päästmis  (PlEl  >päästmine !12?10_S	et	f	\N
141023	päästmistest	"päästmine %pääst  )MINE_vS  <päästma ;34_V	et	f	\N
141024	päästmistest	päästmistest =test  (SgN  >päästmis+test !22_S	et	f	\N
141025	mikolale	?mikolale =mikola  (SgAll  >mikola !01_S	et	f	\N
141026	mikolale	?mikolale =mikolale  (PlP  >mikolal !19_S	et	f	\N
141046	eel	eel =ee  (SgAd  >esi !15_S	et	f	\N
141048	eel	eel =eel  (ID  >eel !41_DK	et	f	\N
141066	joosepi	?joosepi =joosepi  (SgN  >joosepi !01_S	et	f	\N
141067	joosepi	?joosepi =joosepi  (SgG  >joosepi !01_S	et	f	\N
141068	joosepi	?joosepi =joosepi  (SgG  >joosep !02_S	et	f	\N
141069	joosepi	?joosepi =joosepi  (SgG  >joosepp !22_S	et	f	\N
141070	joosepi	?joosepi =joosepi  (IndPrPs_  >jooseppima !28_V	et	f	\N
141071	joosepi	?joosepi =joosepi  (ImpPrSg2  >jooseppima !28_V	et	f	\N
141087	bojarinna	?bojarinna =bojarinna  (SgN  >bojarinna !16_S	et	f	\N
141088	bojarinna	?bojarinna =bojarinna  (SgG  >bojarinna !16_S	et	f	\N
141089	morozova	?morozova =morozova  (SgN  >morozova !16_S	et	f	\N
141090	morozova	?morozova =morozova  (SgG  >morozov !02_A	et	f	\N
141091	morozova	?morozova =morozova  (SgG  >morozova !16_S	et	f	\N
141137	saatuseks	saatuseks =saatuse  (SgTr  >saatus !11~09_S	et	f	\N
141138	saatuseks	saatuseks =use  (PlTr  >saat+usk !22_S	et	f	\N
141139	kaitsvaks	kaitsvaks =kaitsva  (SgTr  >kaitsev !02_A	et	f	\N
141140	kaitsvaks	"kaitsev %kaits  )V_vA  <kaitsma ;32_V	et	f	\N
141141	kaitsvaks	"kaitsev %kaitse  )V_vA  <kaitsema ;28_V	et	f	\N
141148	vt	### vt	et	f	\N
141152	taevasse	taevasse =taeva  (SgIll  >taevas !07_S	et	f	\N
141153	taevasse	taevasse =taevas  (SgAdt  >taevane !12_A	et	f	\N
141154	taevasse	"taevane %taeva  )NE_aA  <taevas ;07_S	et	f	\N
141191	allikatel	allikatel =allika  (PlAd  >allikas !02_S	et	f	\N
141192	allikatel	allikatel =ate  (PlAd  >allik+att !22_S	et	f	\N
141201	ilja	?ilja =ilja  (SgN  >ilja !16_S	et	f	\N
141202	ilja	?ilja =ilja  (SgG  >iljas !02_A	et	f	\N
141203	ilja	?ilja =ilja  (SgG  >ilja !16_S	et	f	\N
141204	ilja	?ilja =ilja  (IndPrPs_  >iljama !29_V	et	f	\N
141205	ilja	?ilja =ilja  (ImpPrSg2  >iljama !29_V	et	f	\N
141210	arhaailste	### arhaailste	et	f	\N
141211	moonutamises	moonutamises =moonutamise  (SgIn  >moonutamine !12_S	et	f	\N
141212	moonutamises	"moonutamine %moonuta  )MINE_vS  <moonutama ;27_V	et	f	\N
141218	kogumikud	kogumikud =kogumiku  (PlN  >kogumik !25_S	et	f	\N
141219	kogumikud	kogumikud =miku  (PlN  >kogu+mikk !22_S	et	f	\N
141225	rütmiliselt	rütmiliselt =rütmilise  (SgAbl  >rütmiline !12_A	et	f	\N
141226	rütmiliselt	"rütmiline %rütmi  )LINE_aA  <rütm ;22_S	et	f	\N
141227	rütmiliselt	rütmiliselt =rütmiliselt  (ID  >rütmiliselt !41_D	et	f	\N
141228	rütmiliselt	"rütmiliselt %rütmi  )LISELT_mD  <rütm ;22_S	et	f	\N
141229	rütmiliselt	"rütmiliselt %rütmilise  )LT_mD  <rütmiline ;12_A	et	f	\N
141233	ia	?ia =ia  (SgN  >ia !26_S	et	f	\N
141234	ia	?ia =ia  (SgG  >ia !26_S	et	f	\N
141260	luulele	luulele =luule  (SgAll  >luule !06_S	et	f	\N
141261	luulele	luulele =luule  (PlAll  >luul !22_S	et	f	\N
141264	lapsukese	lapsukese =lapsukese  (SgG  >lapsuke !12_S	et	f	\N
141265	lapsukese	"lapsuke %lapsu  )KE_dS  <laps ;22_S	et	f	\N
141266	lapsukese	lapsukese =lapsukese  (SgG  >lapsukene !12_S	et	f	\N
141267	lapsukese	"lapsukene %lapsu  )KENE_dS  <laps ;22_S	et	f	\N
141268	erakust	erakust =eraku  (SgEl  >erak !02_S	et	f	\N
141269	erakust	erakust =kus  (SgP  >era+kusi !20_S	et	f	\N
141276	tõsist	tõsist =tõsi  (PlEl  >tõsi !15_S	et	f	\N
141277	tõsist	tõsist =tõsis  (SgP  >tõsine !10_A	et	f	\N
141278	tõsist	"tõsine %tõsi  )NE_aA  <tõsi ;15_S	et	f	\N
141279	soosse	soosse =soo  (SgIll  >sugu !18_S	et	f	\N
141281	soosse	soosse =soo  (SgIll  >soo !26_S	et	f	\N
141284	varutakse	varutakse =varu  (IndPrIps  >varuma !27_V	et	f	\N
141285	varutakse	varutakse =takse  (PlP  >varu+taks !22_S	et	f	\N
141326	naisterahvas	naisterahvas =rahva  (SgIn  >naiste+rahvas !07_S	et	f	\N
141327	naisterahvas	naisterahvas =rahvas  (SgN  >naiste+rahvas !07_S	et	f	\N
141357	maagilise	maagilise =maagilise  (SgG  >maagiline !12_A	et	f	\N
141358	maagilise	"maagiline %maagi  )LINE_aA  <maag ;22_S	et	f	\N
141359	maagilise	"maagiline %maagi  )LINE_aA  <maak ;22_S	et	f	\N
141371	maine	maine =maine  (SgN  >maine !06_S	et	f	\N
141041	ilmutusest	ilmutusest =ilmutuse  (SgEl  >ilmutus !11_S	et	f	\N
141043	ilmutusest	"ilmutus %ilmuta  )US_vS  <ilmutama ;27_V	et	f	\N
141045	ilmutusest	"ilmutus %ilmu  )TUS1_aS  <ilmuma ;27_V	et	f	\N
141047	ilmutusest	ilmutusest =ilmutuses  (SgP  >ilmutusene !12_A	et	f	\N
141049	ilmutusest	"ilmutusene %ilmutuse  )NE_aA  <ilmutus ;11_S	et	f	\N
141058	paastu	paastu =paastu  (SgG  >paast !22_S	et	f	\N
141059	paastu	paastu =paastu  (SgP  >paast !22_S	et	f	\N
141060	paastu	paastu =paastu  (SgAdt  >paast !22_S	et	f	\N
141061	paastu	paastu =paastu  (IndPrPs_  >paastuma !28_V	et	f	\N
141062	paastu	paastu =paastu  (ImpPrSg2  >paastuma !28_V	et	f	\N
141102	kirikuslaavi	?kirikuslaavi =kirikuslaavi  (SgN  >kirikuslaavi !16_S	et	f	\N
141103	kirikuslaavi	?kirikuslaavi =kirikuslaavi  (SgG  >kirikuslaavi !16_S	et	f	\N
141104	kirikuslaavi	?kirikuslaavi =kirikuslaavi  (SgG  >kirikuslaav !22_S	et	f	\N
141105	kirikuslaavi	?kirikuslaavi =kirikuslaavi  (SgP  >kirikuslaav !22_S	et	f	\N
141106	kirikuslaavi	?kirikuslaavi =kirikuslaavi  (SgAdt  >kirikuslaav !22_S	et	f	\N
141107	kirikuslaavi	?kirikuslaavi =kirikuslaavi  (IndPrPs_  >kirikuslaavima !28_V	et	f	\N
141108	kirikuslaavi	?kirikuslaavi =kirikuslaavi  (ImpPrSg2  >kirikuslaavima !28_V	et	f	\N
141109	kirikuslaavi	?kirikuslaavi =avi  (SgN  >kiri+kusla+avi !17_S	et	f	\N
141110	kirikuslaavi	?kirikuslaavi =avi  (SgG  >kiri+kusla+avi !17_S	et	f	\N
141111	kirikuslaavi	?kirikuslaavi =avi  (SgP  >kiri+kusla+avi !17_S	et	f	\N
141112	kirikuslaavi	?kirikuslaavi =laavi  (SgN  >kiri+kus+laavi !16_S	et	f	\N
141113	kirikuslaavi	?kirikuslaavi =laavi  (SgG  >kiri+kus+laavi !16_S	et	f	\N
141114	kirikuslaavi	?kirikuslaavi =laavi  (SgG  >kiri+kus+laav !22_S	et	f	\N
141115	kirikuslaavi	?kirikuslaavi =laavi  (SgP  >kiri+kus+laav !22_S	et	f	\N
141116	kirikuslaavi	?kirikuslaavi =laavi  (SgAdt  >kiri+kus+laav !22_S	et	f	\N
141117	kirikuslaavi	?kirikuslaavi =slaavi  (SgG  >kiriku+slaav !22_S	et	f	\N
141118	kirikuslaavi	?kirikuslaavi =slaavi  (SgP  >kiriku+slaav !22_S	et	f	\N
141119	kirikuslaavi	?kirikuslaavi =slaavi  (SgAdt  >kiriku+slaav !22_S	et	f	\N
141120	kirikuslaavi	?kirikuslaavi =uslaavi  (SgN  >kirik+uslaavi !16_S	et	f	\N
141121	kirikuslaavi	?kirikuslaavi =uslaavi  (SgG  >kirik+uslaavi !16_S	et	f	\N
141122	kirikuslaavi	?kirikuslaavi =uslaavi  (SgG  >kirik+uslaav !22_S	et	f	\N
141123	kirikuslaavi	?kirikuslaavi =uslaavi  (SgP  >kirik+uslaav !22_S	et	f	\N
141124	kirikuslaavi	?kirikuslaavi =uslaavi  (SgAdt  >kirik+uslaav !22_S	et	f	\N
141125	kirikuslaavi	?kirikuslaavi =kuslaavi  (SgN  >kiri+kuslaavi !16_S	et	f	\N
141126	kirikuslaavi	?kirikuslaavi =kuslaavi  (SgG  >kiri+kuslaavi !16_S	et	f	\N
141127	kirikuslaavi	?kirikuslaavi =kuslaavi  (SgG  >kiri+kuslaav !22_S	et	f	\N
141128	kirikuslaavi	?kirikuslaavi =kuslaavi  (SgP  >kiri+kuslaav !22_S	et	f	\N
141129	kirikuslaavi	?kirikuslaavi =kuslaavi  (SgAdt  >kiri+kuslaav !22_S	et	f	\N
141142	jn	### jn	et	f	\N
141150	võrdle	võrdle =võrdle  (IndPrPs_  >võrdlema !30_V	et	f	\N
141151	võrdle	võrdle =võrdle  (ImpPrSg2  >võrdlema !30_V	et	f	\N
141169	lindu	lindu =lindu  (SgP  >lind !22_S	et	f	\N
141170	lindu	lindu =lindu  (SgAdt  >lind !22_S	et	f	\N
141171	linnuke	linnuke =linnuke  (SgN  >linnuke !12_S	et	f	\N
141172	linnuke	"linnuke %linnu  )KE_dS  <lind ;22_S	et	f	\N
141175	käsikirjalises	käsikirjalises =kirjalise  (SgIn  >käsi+kirjaline !12_A	et	f	\N
141176	käsikirjalises	"käsi+kirjaline %kirja  )LINE_aA  <käsi+kiri ;24_S	et	f	\N
141177	näidanud	näidanud =näida  (PtsPtPs  >näitama !29_V	et	f	\N
141178	näidanud	näidanud =näidanu  (PlN  >näidanu !01_S	et	f	\N
141179	näidanud	"näidanu %näida  )NU_vS  <näitama ;29_V	et	f	\N
141180	näidanud	näidanud =näidanud  (ID  >näidanud !41_A	et	f	\N
141181	näidanud	"näidanud %näida  )NUD_vA  <näitama ;29_V	et	f	\N
141186	trükituid	trükituid =trükitu  (PlP  >trükitu !01_AS	et	f	\N
141187	trükituid	"trükitu %trüki  )TU1_vS  <trükkima ;28_V	et	f	\N
141188	trükituid	"trükitu %trüki  )TU2_kA  <trükk ;22_S	et	f	\N
141189	trükituid	trükituid =tui  (PlN  >trüki+tui !26_S	et	f	\N
141190	trükituid	trükituid =tui  (SgP  >trüki+tui !26_S	et	f	\N
141200	nastavnik	?nastavnik =nastavnik  (SgN  >nastavnik !02_S	et	f	\N
141213	trüki-	trüki- =trüki  (SgG  >trükk !22_S	et	f	\N
141214	trüki-	trüki- =trüki  (IndPrPs_  >trükkima !28_V	et	f	\N
141216	trüki-	trüki- =trüki  (ImpPrSg2  >trükkima !28_V	et	f	\N
141270	lugemisega	lugemisega =lugemise  (SgKom  >lugemine !12_S	et	f	\N
141271	lugemisega	"lugemine %luge  )MINE_vS  <lugema ;28_V	et	f	\N
141272	lugemisega	"lugemine %lugemi  )NE_aA  <lugem ;02_S	et	f	\N
141299	eelnevalt	eelnevalt =eelneva  (SgAbl  >eelnev !02_A	et	f	\N
141300	eelnevalt	"eelnev %eelne  )V_vA  <eelnema ;27_V	et	f	\N
141301	eelnevalt	eelnevalt =eelnevalt  (ID  >eelnevalt !41_D	et	f	\N
141302	eelnevalt	"eelnevalt %eelne  )VALT_mD  <eelnema ;27_V	et	f	\N
141303	eelnevalt	"eelnevalt %eelneva  )LT_mD  <eelnev ;02_A	et	f	\N
141304	õnnistanud	õnnistanud =õnnista  (PtsPtPs  >õnnistama !27_V	et	f	\N
141305	õnnistanud	õnnistanud =õnnistanu  (PlN  >õnnistanu !01_S	et	f	\N
141306	õnnistanud	"õnnistanu %õnnista  )NU_vS  <õnnistama ;27_V	et	f	\N
141307	õnnistanud	õnnistanud =õnnistanud  (ID  >õnnistanud !41_A	et	f	\N
141308	õnnistanud	"õnnistanud %õnnista  )NUD_vA  <õnnistama ;27_V	et	f	\N
141133	rütmika	rütmika =rütmika  (SgG  >rütmika !01_S	et	f	\N
141134	rütmika	rütmika =rütmika  (SgG  >rütmikas !02_A	et	f	\N
141143	mungast	mungast =munga  (SgEl  >munk !22_S	et	f	\N
141145	mungast	mungast =mungas  (SgP  >mungane !10_A	et	f	\N
141147	mungast	"mungane %munga  )NE_aA  <munk ;22_S	et	f	\N
141149	arhaailisel	?arhaailisel =arhaailise  (SgAd  >arhaailine !12_A	et	f	\N
141155	veealusesse	veealusesse =sesse  (PlP  >vee+alu+sess !22_S	et	f	\N
141156	veealusesse	veealusesse =aluse  (SgIll  >vee+alus !09_S	et	f	\N
141157	veealusesse	veealusesse =aluse  (SgIll  >vee+alune !10_AS	et	f	\N
141158	veealusesse	"vee+alune %alu  )NE_aA  <vee+alg ;22_S	et	f	\N
141159	veealusesse	veealusesse =aluses  (SgAdt  >vee+alusene !12_A	et	f	\N
141160	veealusesse	"vee+alusene %aluse  )NE_aA  <vee+alus ;09_S	et	f	\N
141161	kuningriiki	kuningriiki =riiki  (SgP  >kuning+riik !22_S	et	f	\N
141163	kuningriiki	kuningriiki =riiki  (SgAdt  >kuning+riik !22_S	et	f	\N
141165	imelist	imelist =imelis  (SgP  >imeline !12_A	et	f	\N
141166	imelist	"imeline %ime  )LINE_aA  <ime ;16_S	et	f	\N
141173	suulises	suulises =suulise  (SgIn  >suuline !12?10_AS	et	f	\N
141174	suulises	"suuline %suu  )LINE_aA  <suu ;26_S	et	f	\N
141196	palvelatesse	palvelatesse =palvela  (PlIll  >palvela !01_S	et	f	\N
141197	palvelatesse	palvelatesse =late  (PlIll  >palve+latt !22_S	et	f	\N
141208	arusaamatute	arusaamatute =saamatu  (PlG  >aru+saamatu !01_A	et	f	\N
141209	arusaamatute	"aru+saamatu %saama  )TU2_kA  <aru+saam ;22_S	et	f	\N
141235	visiiti	visiiti =visiiti  (SgP  >visiit !22_S	et	f	\N
141236	visiiti	visiiti =visiiti  (SgAdt  >visiit !22_S	et	f	\N
141240	nooruspõlve	nooruspõlve =põlve  (SgG  >noorus+põlv !22_S	et	f	\N
141241	nooruspõlve	nooruspõlve =põlve  (SgG  >noorus+põli !24_S	et	f	\N
141242	nooruspõlve	nooruspõlve =põlve  (SgP  >noorus+põlv !22_S	et	f	\N
141243	nooruspõlve	nooruspõlve =põlve  (SgP  >noorus+põli !24_S	et	f	\N
141244	nooruspõlve	nooruspõlve =põlve  (SgAdt  >noorus+põlv !22_S	et	f	\N
141245	nooruspõlve	nooruspõlve =põlve  (SgAdt  >noorus+põli !24_S	et	f	\N
141246	nooruspõlve	nooruspõlve =põlve  (PlP  >noorus+põlv !22_S	et	f	\N
141254	põlvkonnale	põlvkonnale =põlvkonna  (SgAll  >põlvkond !22_S	et	f	\N
141255	põlvkonnale	põlvkonnale =konna  (SgAll  >põlv+konn !22_S	et	f	\N
141280	kolmekuningapäeva	kolmekuningapäeva =päeva  (SgG  >kolme+kuninga+päev !22_S	et	f	\N
141282	kolmekuningapäeva	kolmekuningapäeva =päeva  (SgP  >kolme+kuninga+päev !22_S	et	f	\N
141283	kolmekuningapäeva	kolmekuningapäeva =päeva  (SgAdt  >kolme+kuninga+päev !22_S	et	f	\N
141293	raijutud	?raijutud =raiju  (PtsPtIps  >raijuma !27_V	et	f	\N
141294	raijutud	?raijutud =raijutu  (PlN  >raijutu !01_AS	et	f	\N
141295	raijutud	?raijutud =raijutu  (IndPrSg2  >raijutuma !27_V	et	f	\N
141296	raijutud	?raijutud =raijutud  (ID  >raijutud !41_A	et	f	\N
141310	jordanitek	### jordanitek	et	f	\N
141318	etiketti	etiketti =etiketti  (SgP  >etikett !22_S	et	f	\N
141319	etiketti	etiketti =etiketti  (SgAdt  >etikett !22_S	et	f	\N
141336	märgistasid	märgistasid =märgista  (IndIpfSg2  >märgistama !27_V	et	f	\N
141337	märgistasid	märgistasid =märgista  (IndIpfPl3  >märgistama !27_V	et	f	\N
141349	peopesast	peopesast =pesa  (SgEl  >peo+pesa !17_S	et	f	\N
141350	peopesast	peopesast =pesas  (SgP  >peo+pesane !10_A	et	f	\N
141351	peopesast	"peo+pesane %pesa  )NE_aA  <peo+pesa ;17_S	et	f	\N
141360	mõjutamise	mõjutamise =mõjutamise  (SgG  >mõjutamine !12_S	et	f	\N
141361	mõjutamise	"mõjutamine %mõjuta  )MINE_vS  <mõjutama ;27_V	et	f	\N
141363	ikooni	ikooni =ikooni  (SgG  >ikoon !22_S	et	f	\N
141365	ikooni	ikooni =ikooni  (SgP  >ikoon !22_S	et	f	\N
141366	ikooni	ikooni =ikooni  (SgAdt  >ikoon !22_S	et	f	\N
141375	naastes	naastes =naas  (Ger  >naasma !32_V	et	f	\N
141376	naastes	naastes =naaste  (PlIn  >naast !22_S	et	f	\N
141378	igaastased	?igaastased =igaastase  (PlN  >igaastane !12~10_A	et	f	\N
141379	igaastased	?igaastased =astase  (PlN  >iga+astane !12~10_A	et	f	\N
141390	tulekahjust	tulekahjust =kahju  (SgEl  >tule+kahju !16~17_S	et	f	\N
141391	tulekahjust	tulekahjust =kahju  (SgEl  >tule+kahi !24_S	et	f	\N
141393	tulekahjust	tulekahjust =kahju  (PlEl  >tule+kahi !24_S	et	f	\N
141404	jääks	jääks =jää  (SgTr  >jää !26_S	et	f	\N
141406	jääks	jääks =jää  (KndPrPs  >jääma !37_V	et	f	\N
141413	neis	neis =ne  (PlIn  >see !00_P	et	f	\N
141414	neis	neis =ne  (PlIn  >ta !00_P	et	f	\N
141419	ämblikut	?ämblikut =ämbliku  (SgP  >ämbliku !01_S	et	f	\N
141439	ehitamisele	ehitamisele =ehitamise  (SgAll  >ehitamine !12_S	et	f	\N
141440	ehitamisele	"ehitamine %ehita  )MINE_vS  <ehitama ;27_V	et	f	\N
141486	pöördumisega	pöördumisega =pöördumise  (SgKom  >pöördumine !12_S	et	f	\N
141487	pöördumisega	"pöördumine %pöördu  )MINE_vS  <pöörduma ;27_V	et	f	\N
141490	heaolu	heaolu =olu  (SgN  >hea+olu !17_S	et	f	\N
141491	heaolu	heaolu =olu  (SgG  >hea+olu !17_S	et	f	\N
141492	heaolu	heaolu =olu  (SgP  >hea+olu !17_S	et	f	\N
141497	roppude	roppude =roppu  (PlG  >ropp !22_A	et	f	\N
141498	roppude	roppude =ude  (SgN  >ropp+ude !04_S	et	f	\N
141522	ergsamalt	?ergsamalt =ergsama  (SgAbl  >ergsam !02_A	et	f	\N
141523	ergsamalt	?ergsamalt =ergsamalt  (ID  >ergsamalt !41_D	et	f	\N
141309	õnnistanud	õnnistanud =tanu  (PlN  >õnnis+tanu !17_S	et	f	\N
141320	vanausulistel-fedosejevlastel	?vanausulistel-fedosejevlastel =fedosejevlas  (PlAd  >vanausulistel-fedosejevlane !12_S	et	f	\N
141331	palvelasse	palvelasse =palvela  (SgIll  >palvela !01_S	et	f	\N
141332	palvelasse	palvelasse =palvelas  (SgAdt  >palvelane !12_S	et	f	\N
141333	palvelasse	"palvelane %palvela  )NE_aA  <palvela ;01_S	et	f	\N
141334	palvelasse	palvelasse =la  (SgIll  >palve+la !26_S	et	f	\N
141335	palvelasse	palvelasse =lasse  (PlP  >palve+lass !22_S	et	f	\N
141347	kasutaks	kasutaks =kasuta  (KndPrPs  >kasutama !27_V	et	f	\N
141348	kasutaks	kasutaks =taks  (SgN  >kasu+taks !22_S	et	f	\N
141354	läbipõimutud	läbipõimutud =põimu  (PtsPtIps  >läbi+_põimuma !27_V	et	f	\N
141355	läbipõimutud	läbipõimutud =põimutu  (PlN  >läbi+põimutu !01_AS	et	f	\N
141356	läbipõimutud	"läbi+põimutu %põimu  )TU2_kA  <läbi+põim ;22_S	et	f	\N
141377	laadogalt	?laadogalt =laadogalt  (ID  >laadogalt !41_D	et	f	\N
141380	uinumise	uinumise =uinumise  (SgG  >uinumine !12_S	et	f	\N
141381	uinumise	"uinumine %uinu  )MINE_vS  <uinuma ;27_V	et	f	\N
141392	pajuoksi	pajuoksi =oksi  (SgG  >paju+oks !22_S	et	f	\N
141394	pajuoksi	pajuoksi =oksi  (SgP  >paju+oks !22_S	et	f	\N
141395	pajuoksi	pajuoksi =oksi  (SgAdt  >paju+oks !22_S	et	f	\N
141396	pajuoksi	pajuoksi =oksi  (PlP  >paju+oks !23?22_S	et	f	\N
141429	tapmise	tapmise =tapmise  (SgG  >tapmine !12?10_S	et	f	\N
141430	tapmise	"tapmine %tap  )MINE_vS  <tapma ;35_V	et	f	\N
141433	kurjuse	kurjuse =kurjuse  (SgG  >kurjus !11~09_S	et	f	\N
141434	kurjuse	"kurjus %kurj  )US_aS  <kuri ;24_A	et	f	\N
141441	omistamine	omistamine =omistamine  (SgN  >omistamine !12_S	et	f	\N
141442	omistamine	"omistamine %omista  )MINE_vS  <omistama ;27_V	et	f	\N
141467	lausumiste	lausumiste =lausumis  (PlG  >lausumine !12_S	et	f	\N
141468	lausumiste	"lausumine %lausu  )MINE_vS  <lausuma ;28_V	et	f	\N
141567	ristimise	ristimise =ristimise  (SgG  >ristimine !12_S	et	f	\N
141568	ristimise	"ristimine %risti  )MINE_vS  <ristima ;28_V	et	f	\N
141598	tülis	tülis =tüli  (SgIn  >tüli !17_S	et	f	\N
141599	tülis	tülis =tülis  (ID  >tülis !41_D	et	f	\N
141609	osutusid	osutusid =osutu  (IndIpfSg2  >osutuma !27_V	et	f	\N
141611	osutusid	osutusid =osutu  (IndIpfPl3  >osutuma !27_V	et	f	\N
141619	surija	surija =surija  (SgN  >surija !01_S	et	f	\N
141620	surija	"surija %suri  )JA_vS  <surema ;36_V	et	f	\N
141621	surija	surija =surija  (SgG  >surija !01_S	et	f	\N
141648	lähvad	?lähvad =lähva  (PlN  >lähva !16_S	et	f	\N
141649	lähvad	?lähvad =lähva  (IndPrSg2  >lähvama !29_V	et	f	\N
141655	ligistest	?ligistest =ligis  (PlEl  >ligis !09_S	et	f	\N
141656	ligistest	?ligistest =ligiste  (PlEl  >ligist !22_S	et	f	\N
141657	ligistest	?ligistest =ligistes  (SgP  >ligistene !12_A	et	f	\N
141658	ligistest	?ligistest =stest  (SgN  >ligi+stest !22_S	et	f	\N
141661	taganutta	?taganutta =taganutta  (SgN  >taganutta !16_S	et	f	\N
141662	taganutta	?taganutta =taganutta  (SgG  >taganutta !16_S	et	f	\N
141683	õnnetuste	õnnetuste =õnnetus  (PlG  >õnnetus !11_S	et	f	\N
141684	õnnetuste	"õnnetus %õnne  )TUS2_aS  <õnn ;22_S	et	f	\N
141685	õnnetuste	õnnetuste =tuste  (PlP  >õnne+tust !22_S	et	f	\N
141692	kadunu	kadunu =kadunu  (SgN  >kadunu !01_S	et	f	\N
141693	kadunu	"kadunu %kadu  )NU_vS  <kaduma ;28_V	et	f	\N
141694	kadunu	kadunu =kadunu  (SgG  >kadunu !01_S	et	f	\N
141719	aia	aia =aia  (SgG  >aed !22_S	et	f	\N
141720	aia	aia =aia  (SgG  >ai !22_S	et	f	\N
141721	aia	aia =aia  (SgP  >ai !22_S	et	f	\N
141722	aia	aia =aia  (SgAdt  >ai !22_S	et	f	\N
141760	kadunukest	kadunukest =kadunukes  (SgP  >kadunuke !12_S	et	f	\N
141762	kadunukest	"kadunuke %kadunu  )KE_dS  <kadunu ;01_S	et	f	\N
141763	kadunukest	kadunukest =kadunukes  (SgP  >kadunukene !12_S	et	f	\N
141764	kadunukest	"kadunukene %kadunu  )KENE_dS  <kadunu ;01_S	et	f	\N
141768	domineerivad	domineerivad =domineeri  (IndPrPl3  >domineerima !28_V	et	f	\N
141770	domineerivad	domineerivad =domineeriva  (PlN  >domineeriv !02_A	et	f	\N
141772	domineerivad	"domineeriv %domineeri  )V_vA  <domineerima ;28_V	et	f	\N
141779	mahajäätud	mahajäätud =jäätu  (PlN  >maha+jäätu !01_A	et	f	\N
141780	mahajäätud	"maha+jäätu %jää  )TU2_kA  <maha+jää ;26_S	et	f	\N
141783	mütoloogiliste	mütoloogiliste =mütoloogilis  (PlG  >mütoloogiline !12_A	et	f	\N
141784	mütoloogiliste	"mütoloogiline %mütoloogi  )LINE_aA  <mütoloog ;22_S	et	f	\N
141792	nõiutud	nõiutud =nõiu  (PtsPtIps  >nõiduma !28_V	et	f	\N
141793	nõiutud	nõiutud =nõiutu  (PlN  >nõiutu !01_S	et	f	\N
141794	nõiutud	"nõiutu %nõiu  )TU1_vS  <nõiduma ;28_V	et	f	\N
141795	nõiutud	nõiutud =nõiutud  (ID  >nõiutud !41_A	et	f	\N
141797	nõiutud	"nõiutud %nõiu  )TUD_vA  <nõiduma ;28_V	et	f	\N
141805	posimisest	posimisest =posimise  (SgEl  >posimine !12_S	et	f	\N
141806	posimisest	"posimine %posi  )MINE_vS  <posima ;27_V	et	f	\N
141826	ennustasid	ennustasid =ennusta  (IndIpfSg2  >ennustama !27_V	et	f	\N
141827	ennustasid	ennustasid =ennusta  (IndIpfPl3  >ennustama !27_V	et	f	\N
141830	rohisid	rohisid =rohi  (IndIpfSg2  >rohima !27_V	et	f	\N
141831	rohisid	rohisid =rohi  (IndIpfPl3  >rohima !27_V	et	f	\N
141845	kokorasi	?kokorasi =kokorasi  (PlP  >kokorane !12_A	et	f	\N
141340	sööginõusi	?sööginõusi =sööginõusi  (SgG  >sööginõus !22_S	et	f	\N
141341	sööginõusi	?sööginõusi =sööginõusi  (SgP  >sööginõus !22_S	et	f	\N
141342	sööginõusi	?sööginõusi =sööginõusi  (SgAdt  >sööginõus !22_S	et	f	\N
141343	sööginõusi	?sööginõusi =sööginõusi  (IndPrPs_  >sööginõusima !28_V	et	f	\N
141344	sööginõusi	?sööginõusi =sööginõusi  (ImpPrSg2  >sööginõusima !28_V	et	f	\N
141345	sööginõusi	?sööginõusi =nõusi  (SgN  >söögi+nõusi !16_S	et	f	\N
141346	sööginõusi	?sööginõusi =nõusi  (SgG  >söögi+nõusi !16_S	et	f	\N
141362	eelistati	eelistati =eelista  (IndIpfIps  >eelistama !27_V	et	f	\N
141364	eelistati	eelistati =tati  (SgG  >eelis+tatt !22_S	et	f	\N
141367	mikola-meeleheadtegija	mikola-meeleheadtegija =tegija  (SgN  >mikola-meele+head+tegija !01_S	et	f	\N
141368	mikola-meeleheadtegija	mikola-meeleheadtegija =tegija  (SgG  >mikola-meele+head+tegija !01_S	et	f	\N
141388	päästavad	päästavad =päästa  (IndPrPl3  >päästma !34_V	et	f	\N
141389	päästavad	päästavad =tava  (PlN  >pääs+tava !17_S	et	f	\N
141420	kristus-lapsuke	kristus-lapsuke =lapsuke  (SgN  >kristus-lapsuke !12_S	et	f	\N
141421	kristus-lapsuke	"kristus-lapsuke %lapsu  )KE_dS  <kristus-laps ;22_S	et	f	\N
141431	kehastuseks	kehastuseks =kehastuse  (SgTr  >kehastus !11_S	et	f	\N
141432	kehastuseks	"kehastus %kehasta  )US_vS  <kehastama ;27_V	et	f	\N
141435	karistusest	karistusest =karistuse  (SgEl  >karistus !11_S	et	f	\N
141436	karistusest	"karistus %karista  )US_vS  <karistama ;27_V	et	f	\N
141437	karistusest	karistusest =karistuses  (SgP  >karistusene !12_A	et	f	\N
141438	karistusest	"karistusene %karistuse  )NE_aA  <karistus ;11_S	et	f	\N
141447	vanakurja	?vanakurja =vanakurja  (SgN  >vanakurja !16_S	et	f	\N
141448	vanakurja	?vanakurja =vanakurja  (SgG  >vanakurjas !02_A	et	f	\N
141449	vanakurja	?vanakurja =vanakurja  (SgG  >vanakurja !16_S	et	f	\N
141450	vanakurja	?vanakurja =kurja  (SgN  >vana+kurja !16_S	et	f	\N
141451	vanakurja	?vanakurja =kurja  (SgG  >vana+kurjas !02_A	et	f	\N
141452	vanakurja	?vanakurja =kurja  (SgG  >vana+kurja !16_S	et	f	\N
141453	vanakurja	?vanakurja =kurja  (SgG  >vana+kuri !24_A	et	f	\N
141454	vanakurja	?vanakurja =kurja  (SgP  >vana+kuri !24_A	et	f	\N
141455	vanakurja	?vanakurja =kurja  (SgAdt  >vana+kuri !24_A	et	f	\N
141456	põimunud	põimunud =põimu  (PtsPtPs  >põimuma !27_V	et	f	\N
141457	põimunud	põimunud =põimunu  (PlN  >põimunu !01_S	et	f	\N
141458	põimunud	"põimunu %põimu  )NU_vS  <põimuma ;27_V	et	f	\N
141459	põimunud	põimunud =põimunud  (ID  >põimunud !41_A	et	f	\N
141460	põimunud	"põimunud %põimu  )NUD_vA  <põimuma ;27_V	et	f	\N
141461	vahetatud	vahetatud =vaheta  (PtsPtIps  >vahetama !27_V	et	f	\N
141462	vahetatud	vahetatud =vahetatu  (PlN  >vahetatu !01_S	et	f	\N
141463	vahetatud	"vahetatu %vaheta  )TU1_vS  <vahetama ;27_V	et	f	\N
141464	vahetatud	vahetatud =vahetatud  (ID  >vahetatud !41_A	et	f	\N
141465	vahetatud	"vahetatud %vaheta  )TUD_vA  <vahetama ;27_V	et	f	\N
141466	vahetatud	vahetatud =atu  (PlN  >vahet+att !22_S	et	f	\N
141488	metsloomade	metsloomade =made  (SgN  >mets+loo+made !04_S	et	f	\N
141489	metsloomade	metsloomade =looma  (PlG  >mets+loom !22_S	et	f	\N
141499	koheselt	koheselt =kohese  (SgAbl  >kohene !10_A	et	f	\N
141502	koheselt	koheselt =koheselt  (ID  >koheselt !41_D	et	f	\N
141504	koheselt	"koheselt %kohese  )LT_mD  <kohene ;10_A	et	f	\N
141515	vihjamisi	vihjamisi =vihjamisi  (ID  >vihjamisi !41_D	et	f	\N
141516	vihjamisi	vihjamisi =vihjamisi  (PlP  >vihjamine !12_S	et	f	\N
141517	vihjamisi	"vihjamine %vihja  )MINE_vS  <vihjama ;29_V	et	f	\N
141531	ehmatuses	ehmatuses =ehmatuse  (SgIn  >ehmatus !11_S	et	f	\N
141532	ehmatuses	"ehmatus %ehmata  )US_vS  <ehmatama ;27_V	et	f	\N
141552	väärteo	väärteo =eo  (SgG  >väärt+idu !18_S	et	f	\N
141553	väärteo	väärteo =teo  (SgG  >väär+tegu !18_S	et	f	\N
141554	väärteo	väärteo =teo  (SgG  >väär+tigu !18_S	et	f	\N
141558	elavast	elavast =elava  (SgEl  >elav !02_A	et	f	\N
141559	elavast	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
141560	elavast	elavast =ast  (SgN  >elav+ast !22_S	et	f	\N
141572	kolmekordselt	kolmekordselt =kordse  (SgAbl  >kolme+kordne !02_AS	et	f	\N
141573	kolmekordselt	"kolme+kordselt %kordse  )LT_mD  <kolme+kordne ;02_AS	et	f	\N
141574	kastetakse	kastetakse =kaste  (IndPrIps  >kastma !34_V	et	f	\N
141575	kastetakse	kastetakse =takse  (PlP  >kaste+taks !22_S	et	f	\N
141591	baseeruvad	baseeruvad =baseeru  (IndPrPl3  >baseeruma !27_V	et	f	\N
141593	baseeruvad	baseeruvad =baseeruva  (PlN  >baseeruv !02_A	et	f	\N
141595	baseeruvad	"baseeruv %baseeru  )V_vA  <baseeruma ;27_V	et	f	\N
141596	maagiasse	maagiasse =maagia  (SgIll  >maagia !01_S	et	f	\N
141597	maagiasse	maagiasse =asse  (PlP  >maagi+ass !22_S	et	f	\N
141605	neitraliseerib	?neitraliseerib =neitraliseeri  (IndPrSg3  >neitraliseerima !28_V	et	f	\N
141615	kombetalitused	kombetalitused =talituse  (PlN  >kombe+talitus !11_S	et	f	\N
141616	kombetalitused	"kombe+talitus %tali  )TUS2_aS  <kombe+tali ;17_S	et	f	\N
141636	talitused	talitused =talituse  (PlN  >talitus !11_S	et	f	\N
141637	talitused	"talitus %talita  )US_vS  <talitama ;27_V	et	f	\N
141638	talitused	"talitus %tali  )TUS2_aS  <tali ;17_S	et	f	\N
141666	arhhailisemad	?arhhailisemad =arhhailisema  (PlN  >arhhailisem !02_A	et	f	\N
141372	maine	"maine %mai  )NE_aA  <maa ;26_S	et	f	\N
141373	maine	maine =maine  (SgN  >maine !10_A	et	f	\N
141374	maine	maine =maine  (SgG  >maine !06_S	et	f	\N
141382	tulekahjude	tulekahjude =kahju  (PlG  >tule+kahju !16~17_S	et	f	\N
141383	tulekahjude	tulekahjude =kahju  (PlG  >tule+kahi !24_S	et	f	\N
141384	pühetsetud	?pühetsetud =pühetse  (PtsPtIps  >pühetsema !27_V	et	f	\N
141385	pühetsetud	?pühetsetud =pühetsetu  (PlN  >pühetsetu !01_S	et	f	\N
141386	pühetsetud	?pühetsetud =pühetsetu  (IndPrSg2  >pühetsetuma !27_V	et	f	\N
141387	pühetsetud	?pühetsetud =pühetsetud  (ID  >pühetsetud !41_A	et	f	\N
141397	karjamaale	karjamaale =maa  (SgAll  >karja+maa !26_S	et	f	\N
141398	karjamaale	karjamaale =maale  (PlP  >karja+maal !22_S	et	f	\N
141415	maija	?maija =maija  (SgN  >maija !01_S	et	f	\N
141416	maija	?maija =maija  (SgG  >maija !01_S	et	f	\N
141417	maija	?maija =maija  (IndPrPs_  >maijama !29_V	et	f	\N
141418	maija	?maija =maija  (ImpPrSg2  >maijama !29_V	et	f	\N
141426	ussi	ussi =ussi  (SgG  >uss !22_S	et	f	\N
141427	ussi	ussi =ussi  (SgP  >uss !22_S	et	f	\N
141428	ussi	ussi =ussi  (SgAdt  >uss !22_S	et	f	\N
141443	sattuvad	sattuvad =sattu  (IndPrPl3  >sattuma !27_V	et	f	\N
141444	sattuvad	sattuvad =sattuva  (PlN  >sattuv !02_A	et	f	\N
141445	sattuvad	"sattuv %sattu  )V_vA  <sattuma ;27_V	et	f	\N
141446	sattuvad	"sattuv %sattu  )V_vA  <sattuma ;28_V	et	f	\N
141469	hoolealuseid	hoolealuseid =aluse  (PlP  >hoole+alus !09_S	et	f	\N
141470	hoolealuseid	hoolealuseid =aluse  (PlP  >hoole+alune !10_AS	et	f	\N
141471	hoolealuseid	"hoole+alune %alu  )NE_aA  <hoole+alg ;22_S	et	f	\N
141475	surmast	surmast =surma  (SgEl  >surm !22_S	et	f	\N
141476	surmast	surmast =surmas  (SgP  >surmane !10_A	et	f	\N
141477	surmast	"surmane %surma  )NE_aA  <surm ;22_S	et	f	\N
141478	surmast	surmast =ast  (SgN  >surm+ast !22_S	et	f	\N
141482	täiendati	täiendati =täienda  (IndIpfIps  >täiendama !27_V	et	f	\N
141483	täiendati	täiendati =ati  (SgG  >täiend+att !22_S	et	f	\N
141493	emakest-ahju	emakest-ahju =ahju  (SgG  >emakest-ahi !24_S	et	f	\N
141494	emakest-ahju	emakest-ahju =ahju  (SgP  >emakest-ahi !24_S	et	f	\N
141495	emakest-ahju	emakest-ahju =ahju  (SgAdt  >emakest-ahi !24_S	et	f	\N
141506	tegusõna	tegusõna =sõna  (SgN  >tegu+sõna !17_S	et	f	\N
141507	tegusõna	tegusõna =sõna  (SgG  >tegu+sõna !17_S	et	f	\N
141508	tegusõna	tegusõna =sõna  (SgP  >tegu+sõna !17_S	et	f	\N
141509	eeslistavad	?eeslistavad =eeslista  (IndPrPl3  >eeslistama !27_V	et	f	\N
141510	eeslistavad	?eeslistavad =eeslistava  (PlN  >eeslistav !02_A	et	f	\N
141511	eeslistavad	?eeslistavad =eeslistava  (PlN  >eeslistava !16_S	et	f	\N
141512	eeslistavad	?eeslistavad =stava  (PlN  >eesli+stava !17_S	et	f	\N
141513	eeslistavad	?eeslistavad =listava  (PlN  >ees+listava !01_S	et	f	\N
141514	eeslistavad	?eeslistavad =listava  (PlN  >ees+listav !02_A	et	f	\N
141533	valdavas	valdavas =valdava  (SgIn  >valdav !02_A	et	f	\N
141534	valdavas	"valdav %valda  )V_vA  <valdama ;29_V	et	f	\N
141535	valdavas	valdavas =ava  (SgIn  >vald+ava !17_S	et	f	\N
141536	veendutud	veendutud =veendu  (PtsPtIps  >veenduma !27_V	et	f	\N
141537	veendutud	veendutud =veendutu  (PlN  >veendutu !01_AS	et	f	\N
141538	veendutud	"veendutu %veendu  )TU1_vS  <veenduma ;27_V	et	f	\N
141539	veendutud	veendutud =veendutud  (ID  >veendutud !41_A	et	f	\N
141540	veendutud	"veendutud %veendu  )TUD_vA  <veenduma ;27_V	et	f	\N
141541	kaitseb	kaitseb =kaitse  (IndPrSg3  >kaitsema !28_V	et	f	\N
141542	kaitseb	kaitseb =kaitse  (IndPrSg3  >kaitsma !32_V	et	f	\N
141548	kukuma	kukuma =kukuma  (SgG  >kukum !02_A	et	f	\N
141549	kukuma	"kukum %kuku  )M_cA  <kuku ;16_A	et	f	\N
141561	veest	veest =vee  (SgEl  >vesi !15_S	et	f	\N
141562	veest	veest =vees  (SgP  >veene !10_A	et	f	\N
141563	veest	"veene %vee  )NE_aA  <vesi ;15_S	et	f	\N
141564	rudimentses	?rudimentses =rudimentse  (SgIn  >rudimentne !02_A	et	f	\N
141565	rudimentses	?rudimentses =rudimentse  (PlIn  >rudiments !22_S	et	f	\N
141566	rudimentses	?rudimentses =rudimentse  (IndIpfSg3  >rudimentsema !27_V	et	f	\N
141590	kaitsva	kaitsva =kaitsva  (SgG  >kaitsev !02_A	et	f	\N
141592	kaitsva	"kaitsev %kaits  )V_vA  <kaitsma ;32_V	et	f	\N
141594	kaitsva	"kaitsev %kaitse  )V_vA  <kaitsema ;28_V	et	f	\N
141600	puhta	puhta =puhta  (ID  >puhta !41_D	et	f	\N
141601	puhta	puhta =puhta  (SgG  >puhas !07_A	et	f	\N
141602	väikelast	väikelast =la  (SgEl  >väike+la !26_S	et	f	\N
141603	väikelast	väikelast =las  (SgP  >väike+laps !14_S	et	f	\N
141604	väikelast	väikelast =last  (SgN  >väike+last !22_S	et	f	\N
141617	mütoloogilised	mütoloogilised =mütoloogilise  (PlN  >mütoloogiline !12_A	et	f	\N
141618	mütoloogilised	"mütoloogiline %mütoloogi  )LINE_aA  <mütoloog ;22_S	et	f	\N
141624	hauaristid	hauaristid =risti  (PlN  >haua+risti !16_S	et	f	\N
141625	hauaristid	hauaristid =risti  (PlN  >haua+rist !22_S	et	f	\N
141628	lahkunu	lahkunu =lahkunu  (SgN  >lahkunu !01_S	et	f	\N
141629	lahkunu	"lahkunu %lahku  )NU_vS  <lahkuma ;27_V	et	f	\N
141630	lahkunu	lahkunu =lahkunu  (SgG  >lahkunu !01_S	et	f	\N
141644	väikenegi	väikenegi =väikene  (SgN^  >väikene !12?10_A	et	f	\N
141645	väikenegi	"väikene %väi  )KENE_dS^  <väi ;26_S	et	f	\N
141402	lehmakesed	"lehmake %lehma  )KE_dS  <lehm ;22_S	et	f	\N
141403	lehmakesed	lehmakesed =lehmakese  (PlN  >lehmakene !12_S	et	f	\N
141405	lehmakesed	"lehmakene %lehma  )KENE_dS  <lehm ;22_S	et	f	\N
141407	lasti	lasti =las  (IndIpfIps  >laskma !34_V	et	f	\N
141408	lasti	lasti =lasti  (SgG  >last !22_S	et	f	\N
141409	lasti	lasti =lasti  (SgP  >last !22_S	et	f	\N
141410	lasti	lasti =lasti  (SgAdt  >last !22_S	et	f	\N
141411	lasti	lasti =lasti  (IndPrPs_  >lastima !28_V	et	f	\N
141412	lasti	lasti =lasti  (ImpPrSg2  >lastima !28_V	et	f	\N
141422	tagajalitajate	?tagajalitajate =tagajalitaja  (PlG  >tagajalitaja !01_S	et	f	\N
141423	tagajalitajate	?tagajalitajate =tagajalitaja  (PlG  >tagajalitajas !02_A	et	f	\N
141424	tagajalitajate	?tagajalitajate =jalitaja  (PlG  >taga+jalitaja !01_S	et	f	\N
141425	tagajalitajate	?tagajalitajate =jalitaja  (PlG  >taga+jalitajas !02_A	et	f	\N
141472	vastsest	vastsest =vastse  (SgEl  >vastne !02_SA	et	f	\N
141473	vastsest	vastsest =vastses  (SgP  >vastsene !10_A	et	f	\N
141474	vastsest	"vastsene %vastse  )NE_aA  <vastne ;02_SA	et	f	\N
141479	palveta	palveta =palve  (SgAb  >palve !06_S	et	f	\N
141480	palveta	palveta =palveta  (IndPrPs_  >palvetama !27_V	et	f	\N
141481	palveta	palveta =palveta  (ImpPrSg2  >palvetama !27_V	et	f	\N
141484	luulelise	luulelise =luulelise  (SgG  >luuleline !12_A	et	f	\N
141485	luulelise	"luuleline %luule  )LINE_aA  <luule ;06_S	et	f	\N
141496	id	### id	et	f	\N
141500	vastavad	vastavad =vasta  (IndPrPl3  >vastama !29_V	et	f	\N
141501	vastavad	vastavad =vastava  (PlN  >vastav !02_A	et	f	\N
141503	vastavad	"vastav %vasta  )V_vA  <vastama ;29_V	et	f	\N
141505	vastavad	vastavad =ava  (PlN  >vast+ava !17_S	et	f	\N
141518	vanakuri	?vanakuri =vanakuri  (SgG  >vanakur !19_S	et	f	\N
141519	vanakuri	?vanakuri =vanakuri  (SgP  >vanakur !19_S	et	f	\N
141520	vanakuri	?vanakuri =vanakuri  (SgAdt  >vanakur !19_S	et	f	\N
141521	vanakuri	?vanakuri =kuri  (SgN  >vana+kuri !24_A	et	f	\N
141543	hoolealust	hoolealust =alu  (SgEl  >hoole+alg !22_S	et	f	\N
141544	hoolealust	hoolealust =alu  (PlEl  >hoole+ala !17_S	et	f	\N
141545	hoolealust	hoolealust =alus  (SgP  >hoole+alus !09_S	et	f	\N
141546	hoolealust	hoolealust =alus  (SgP  >hoole+alune !10_AS	et	f	\N
141547	hoolealust	"hoole+alune %alu  )NE_aA  <hoole+alg ;22_S	et	f	\N
141555	pärinev	pärinev =pärine  (PtsPrPs  >pärinema !27_V	et	f	\N
141556	pärinev	pärinev =pärinev  (SgN  >pärinev !02_A	et	f	\N
141557	pärinev	"pärinev %pärine  )V_vA  <pärinema ;27_V	et	f	\N
141580	õnnistavad	õnnistavad =õnnista  (IndPrPl3  >õnnistama !27_V	et	f	\N
141581	õnnistavad	õnnistavad =õnnistava  (PlN  >õnnistav !02_A	et	f	\N
141582	õnnistavad	"õnnistav %õnnista  )V_vA  <õnnistama ;27_V	et	f	\N
141583	õnnistavad	õnnistavad =tava  (PlN  >õnnis+tava !17_S	et	f	\N
141584	ikooniga	ikooniga =ikooni  (SgKom  >ikoon !22_S	et	f	\N
141585	ikooniga	ikooniga =iga  (SgN  >ikoon+iga !18_S	et	f	\N
141586	ikooniga	ikooniga =iga  (SgP  >ikoon+iga !18_S	et	f	\N
141587	puistavad	puistavad =puista  (IndPrPl3  >puistama !29_V	et	f	\N
141588	puistavad	puistavad =puistava  (PlN  >puistav !02_A	et	f	\N
141589	puistavad	"puistav %puista  )V_vA  <puistama ;29_V	et	f	\N
141606	vanausulistega	vanausulistega =usulis  (PlKom  >vana+usuline !12_A	et	f	\N
141607	vanausulistega	"vana+usuline %usu  )LINE_aA  <vana+usk ;22_S	et	f	\N
141608	püsivamaks	püsivamaks =püsivama  (SgTr  >püsivam !02_A	et	f	\N
141610	püsivamaks	"püsivam %püsi  )VAM_cA  <püsima ;27_V	et	f	\N
141612	püsivamaks	"püsivam %püsiva  )M_cA  <püsiv ;02_A	et	f	\N
141622	hauda	hauda =hauda  (SgP  >haud !22_S	et	f	\N
141623	hauda	hauda =hauda  (SgAdt  >haud !22_S	et	f	\N
141626	veendumuste	veendumuste =veendumus  (PlG  >veendumus !11_S	et	f	\N
141627	veendumuste	"veendumus %veendu  )MUS_vS  <veenduma ;27_V	et	f	\N
141631	nelikümmend	?nelikümmend =nelikümmend  (SgN  >nelikümmend !22_S	et	f	\N
141632	nelikümmend	?nelikümmend =ümmend  (SgN  >nelik+ümmend !02_S	et	f	\N
141639	toimetatud	toimetatud =toimeta  (PtsPtIps  >toimetama !27_V	et	f	\N
141640	toimetatud	toimetatud =toimetatu  (PlN  >toimetatu !01_S	et	f	\N
141641	toimetatud	"toimetatu %toimeta  )TU1_vS  <toimetama ;27_V	et	f	\N
141642	toimetatud	toimetatud =toimetatud  (ID  >toimetatud !41_A	et	f	\N
141643	toimetatud	"toimetatud %toimeta  )TUD_vA  <toimetama ;27_V	et	f	\N
141650	kirstu	kirstu =kirstu  (SgG  >kirst !22_S	et	f	\N
141651	kirstu	kirstu =kirstu  (SgP  >kirst !22_S	et	f	\N
141652	kirstu	kirstu =kirstu  (SgAdt  >kirst !22_S	et	f	\N
141672	kutjad	?kutjad =kutja  (PlN  >kutja !01_S	et	f	\N
141673	kutjad	?kutjad =kutja  (PlN  >kutjas !02_A	et	f	\N
141674	kutjad	?kutjad =kutja  (IndPrSg2  >kutjama !29_V	et	f	\N
141689	maagilist	maagilist =maagilis  (SgP  >maagiline !12_A	et	f	\N
141690	maagilist	"maagiline %maagi  )LINE_aA  <maag ;22_S	et	f	\N
141691	maagilist	"maagiline %maagi  )LINE_aA  <maak ;22_S	et	f	\N
141695	veendumuse	veendumuse =veendumuse  (SgG  >veendumus !11_S	et	f	\N
141696	veendumuse	"veendumus %veendu  )MUS_vS  <veenduma ;27_V	et	f	\N
141697	üksk	?üksk =üksk  (SgN  >üksk !22_S	et	f	\N
141700	hammustusest	hammustusest =hammustuse  (SgEl  >hammustus !11_S	et	f	\N
141524	vastastikune	vastastikune =vastastikune  (SgN  >vastastikune !10?12_A	et	f	\N
141525	vastastikune	vastastikune =tikune  (SgN  >vastas+tikune !10_A	et	f	\N
141526	vastastikune	"vastas+tikune %tiku  )NE_aA  <vastas+tikk ;22_S	et	f	\N
141527	vastastikune	vastastikune =astikune  (SgN  >vast+astikune !10?12_A	et	f	\N
141528	vastastikune	"vast+astikune %astiku  )NE_aA  <vast+astik ;02_S	et	f	\N
141529	milleski	milleski =mille  (SgIn  >miski !00_P	et	f	\N
141530	milleski	milleski =mille  (SgIn^  >mis !00_P	et	f	\N
141550	vastutuse	vastutuse =vastutuse  (SgG  >vastutus !11_S	et	f	\N
141551	vastutuse	"vastutus %vastuta  )US_vS  <vastutama ;27_V	et	f	\N
141569	talituses	talituses =talituse  (SgIn  >talitus !11_S	et	f	\N
141570	talituses	"talitus %talita  )US_vS  <talitama ;27_V	et	f	\N
141571	talituses	"talitus %tali  )TUS2_aS  <tali ;17_S	et	f	\N
141576	surnuks	surnuks =sur  (KndPtPs  >surema !36_V	et	f	\N
141577	surnuks	surnuks =surnu  (SgTr  >surnu !01_S	et	f	\N
141578	surnuks	"surnu %sur  )NU_vS  <surema ;36_V	et	f	\N
141579	surnuks	surnuks =surnu  (SgTr  >surnu !06_S	et	f	\N
141613	mälestamise	mälestamise =mälestamise  (SgG  >mälestamine !12_S	et	f	\N
141614	mälestamise	"mälestamine %mälesta  )MINE_vS  <mälestama ;27_V	et	f	\N
141633	nähtamatult	nähtamatult =nähtamatu  (SgAbl  >nähtamatu !01_AS	et	f	\N
141634	nähtamatult	"nähtamatu %näh  )TAMATU_vA  <nägema ;28_V	et	f	\N
141635	nähtamatult	"nähtamatult %näh  )TAMATULT_mD  <nägema ;28_V	et	f	\N
141646	nõudmisega	nõudmisega =nõudmise  (SgKom  >nõudmine !12?10_S	et	f	\N
141647	nõudmisega	"nõudmine %nõud  )MINE_vS  <nõudma ;34_V	et	f	\N
141659	küünlajuppi	küünlajuppi =juppi  (SgP  >küünla+jupp !22_S	et	f	\N
141660	küünlajuppi	küünlajuppi =juppi  (SgAdt  >küünla+jupp !22_S	et	f	\N
141675	nisuterast	nisuterast =tera  (SgEl  >nisu+tera !17_S	et	f	\N
141676	nisuterast	nisuterast =teras  (SgP  >nisu+teras !09_S	et	f	\N
141677	nisuterast	nisuterast =teras  (SgP  >nisu+terane !10_A	et	f	\N
141678	nisuterast	"nisu+terane %tera  )NE_aA  <nisu+tera ;17_S	et	f	\N
141679	jälgivad	jälgivad =jälgi  (IndPrPl3  >jälgima !27_V	et	f	\N
141680	jälgivad	jälgivad =jälgiva  (PlN  >jälgiv !02_A	et	f	\N
141681	jälgivad	"jälgiv %jälgi  )V_vA  <jälgima ;27_V	et	f	\N
141686	surnut	surnut =surnu  (SgP  >surnu !01_S	et	f	\N
141687	surnut	"surnu %sur  )NU_vS  <surema ;36_V	et	f	\N
141688	surnut	surnut =surnu  (SgP  >surnu !06_S	et	f	\N
141706	kahjustatud	kahjustatud =kahjusta  (PtsPtIps  >kahjustama !27_V	et	f	\N
141707	kahjustatud	kahjustatud =kahjustatu  (PlN  >kahjustatu !01_S	et	f	\N
141708	kahjustatud	"kahjustatu %kahjusta  )TU1_vS  <kahjustama ;27_V	et	f	\N
141709	kahjustatud	kahjustatud =kahjustatud  (ID  >kahjustatud !41_A	et	f	\N
141710	kahjustatud	"kahjustatud %kahjusta  )TUD_vA  <kahjustama ;27_V	et	f	\N
141711	enesetapja	enesetapja =tapja  (SgN  >enese+tapja !01_S	et	f	\N
141712	enesetapja	enesetapja =tapja  (SgG  >enese+tapja !01_S	et	f	\N
141756	rändavatest	rändavatest =rändava  (PlEl  >rändav !02_A	et	f	\N
141757	rändavatest	"rändav %rända  )V_vA  <rändama ;29_V	et	f	\N
141758	rändavatest	rändavatest =test  (SgN  >ränd+ava+test !22_S	et	f	\N
141773	enesetapjatest	enesetapjatest =test  (SgN  >enese+tapja+test !22_S	et	f	\N
141774	enesetapjatest	enesetapjatest =tapja  (PlEl  >enese+tapja !01_S	et	f	\N
141796	otsimisest	otsimisest =otsimise  (SgEl  >otsimine !12_S	et	f	\N
141798	otsimisest	"otsimine %otsi  )MINE_vS  <otsima ;28_V	et	f	\N
141828	teeristmikul	teeristmikul =miku  (SgAd  >tee+rist+mikk !22_S	et	f	\N
141829	teeristmikul	teeristmikul =ristmiku  (SgAd  >tee+ristmik !25_S	et	f	\N
141835	pirrukestest	pirrukestest =pirrukes  (PlEl  >pirruke !12_S	et	f	\N
141837	pirrukestest	"pirruke %pirru  )KE_dS  <pird ;22_S	et	f	\N
141838	pirrukestest	pirrukestest =pirrukes  (PlEl  >pirrukene !12_S	et	f	\N
141839	pirrukestest	"pirrukene %pirru  )KENE_dS  <pird ;22_S	et	f	\N
141840	pirrukestest	pirrukestest =keste  (SgEl  >pirru+keste !06_S	et	f	\N
141841	pirrukestest	pirrukestest =keste  (PlEl  >pirru+kest !22_S	et	f	\N
141842	pirrukestest	pirrukestest =kestes  (SgP  >pirru+kestene !12~10_A	et	f	\N
141843	pirrukestest	"pirru+kestene %keste  )NE_aA  <pirru+keste ;06_S	et	f	\N
141851	veeklaasi	veeklaasi =klaasi  (SgG  >vee+klaas !22_S	et	f	\N
141853	veeklaasi	veeklaasi =klaasi  (SgP  >vee+klaas !22_S	et	f	\N
141855	veeklaasi	veeklaasi =klaasi  (SgAdt  >vee+klaas !22_S	et	f	\N
141894	pitsi	pitsi =pitsi  (SgG  >pits !22_S	et	f	\N
141895	pitsi	pitsi =pitsi  (SgP  >pits !22_S	et	f	\N
141897	pitsi	pitsi =pitsi  (SgAdt  >pits !22_S	et	f	\N
141903	makkaveipäeval	?makkaveipäeval =makkaveipäeva  (SgAd  >makkaveipäeva !16_S	et	f	\N
141904	makkaveipäeval	?makkaveipäeval =makkaveipäeval  (SgN  >makkaveipäeval !02_S	et	f	\N
141905	lükata	lükata =lüka  (Inf  >lükkama !29_V	et	f	\N
141906	lükata	lükata =lüka  (IndPrIps_  >lükkama !29_V	et	f	\N
141918	laialt	laialt =laia  (SgAbl  >laid !22_S	et	f	\N
141919	laialt	laialt =laia  (SgAbl  >lai !22_A	et	f	\N
141920	laialt	laialt =laialt  (ID  >laialt !41_D	et	f	\N
141921	laialt	"laialt %laia  )LT_mD  <lai ;22_A	et	f	\N
141923	laialt	laialt =alt  (SgN  >lai+alt !22_S	et	f	\N
141934	pühi	pühi =pühi  (PlP  >püha !17_SA	et	f	\N
141653	popuraarsed	?popuraarsed =popuraarse  (PlN  >popuraarne !02_A	et	f	\N
141654	popuraarsed	?popuraarsed =uraarse  (PlN  >pop+uraarne !02_A	et	f	\N
141663	valavad	valavad =vala  (IndPrPl3  >valama !27_V	et	f	\N
141664	valavad	valavad =valava  (PlN  >valav !02_A	et	f	\N
141665	valavad	"valav %vala  )V_vA  <valama ;27_V	et	f	\N
141704	pistes	pistes =pist  (Ger  >pistma !34_V	et	f	\N
141705	pistes	pistes =piste  (SgIn  >piste !06_S	et	f	\N
141713	surnuaia	surnuaia =aia  (SgG  >surnu+aed !22_S	et	f	\N
141714	surnuaia	surnuaia =aia  (SgG  >surnu+ai !22_S	et	f	\N
141715	surnuaia	surnuaia =aia  (SgP  >surnu+ai !22_S	et	f	\N
141716	surnuaia	surnuaia =aia  (SgAdt  >surnu+ai !22_S	et	f	\N
141717	tõstetakse	tõstetakse =tõste  (IndPrIps  >tõstma !34_V	et	f	\N
141718	tõstetakse	tõstetakse =takse  (PlP  >tõste+taks !22_S	et	f	\N
141725	maise	maise =maise  (SgG  >maine !10_A	et	f	\N
141726	maise	"maine %mai  )NE_aA  <maa ;26_S	et	f	\N
141727	maise	maise =maise  (PlP  >mais !22_S	et	f	\N
141733	kuskilgi	kuskilgi =kilgi  (SgG  >kus+kilk !22_S	et	f	\N
141734	kuskilgi	kuskilgi =kilgi  (SgP  >kus+kilg !22_S	et	f	\N
141735	kuskilgi	kuskilgi =kilgi  (SgAdt  >kus+kilg !22_S	et	f	\N
141736	kuskilgi	kuskilgi =kuskil  (ID^  >kuskil !41_D	et	f	\N
141737	uhkes	uhkes =uhke  (SgIn  >uhke !01_A	et	f	\N
141738	uhkes	uhkes =uhke  (SgIn  >uhe !06_S	et	f	\N
141739	helesinine	?helesinine =helesinine  (SgN  >helesinine !12_A	et	f	\N
141740	helesinine	?helesinine =helesinine  (PlP  >helesinin !19_S	et	f	\N
141742	helesinine	?helesinine =sinine  (SgN  >hele+sinine !10_AS	et	f	\N
141748	üheagselt	?üheagselt =üheagse  (SgAbl  >üheagne !02_A	et	f	\N
141749	üheagselt	?üheagselt =üheagse  (PlAbl  >üheags !22_S	et	f	\N
141750	üheagselt	?üheagselt =üheagselt  (ID  >üheagselt !41_D	et	f	\N
141751	üheagselt	?üheagselt =agse  (SgAbl  >ühe+agne !02_A	et	f	\N
141752	üheagselt	?üheagselt =agse  (SgAbl  >ühe+agse !06_S	et	f	\N
141753	üheagselt	?üheagselt =agse  (PlAbl  >ühe+ags !22_S	et	f	\N
141775	kuraditest	kuraditest =kuradi  (PlEl  >kurat !02_S	et	f	\N
141776	kuraditest	kuraditest =test  (SgN  >kuradi+test !22_S	et	f	\N
141781	põlevate	põlevate =põleva  (PlG  >põlev !02_A	et	f	\N
141782	põlevate	"põlev %põle  )V_vA  <põlema ;27_V	et	f	\N
141799	äranõiutud	äranõiutud =nõiu  (PtsPtIps  >ära+_nõiduma !28_V	et	f	\N
141800	äranõiutud	äranõiutud =nõiutu  (PlN  >ära+nõiutu !01_S	et	f	\N
141809	raamistiku	raamistiku =raamistiku  (SgG  >raamistik !25_S	et	f	\N
141810	raamistiku	raamistiku =istiku  (SgG  >raam+istik !02_S	et	f	\N
141813	ravitsejate	ravitsejate =ravitseja  (PlG  >ravitseja !01_S	et	f	\N
141814	ravitsejate	"ravitseja %ravitse  )JA_vS  <ravitsema ;27_V	et	f	\N
141817	posimised	posimised =posimise  (PlN  >posimine !12_S	et	f	\N
141818	posimised	"posimine %posi  )MINE_vS  <posima ;27_V	et	f	\N
141825	talsipühade	?talsipühade =talsipüha  (PlG  >talsipüha !16_S	et	f	\N
141865	määratu	määratu =määratu  (ID  >määratu !41_D	et	f	\N
141866	määratu	"määratu %määra  )TU1_vS  <määrama ;29_V	et	f	\N
141867	määratu	"määratu %määra  )TU2_kA  <määr ;22_S	et	f	\N
141868	määratu	määratu =määratu  (SgN  >määratu !01_AS	et	f	\N
141869	määratu	määratu =määratu  (SgG  >määratu !01_AS	et	f	\N
141872	väljavalitu	väljavalitu =valitu  (SgN  >välja+valitu !01_S	et	f	\N
141873	väljavalitu	väljavalitu =valitu  (SgG  >välja+valitu !01_S	et	f	\N
141899	jooki	jooki =jooki  (SgP  >jook !22_S	et	f	\N
141901	jooki	jooki =jooki  (SgAdt  >jook !22_S	et	f	\N
141911	riielnud	riielnud =riiel  (PtsPtPs  >riidlema !30_V	et	f	\N
141912	riielnud	riielnud =riielnu  (PlN  >riielnu !01_S	et	f	\N
141913	riielnud	"riielnu %riiel  )NU_vS  <riidlema ;30_V	et	f	\N
141914	riielnud	riielnud =riielnud  (ID  >riielnud !41_A	et	f	\N
141915	riielnud	"riielnud %riiel  )NUD_vA  <riidlema ;30_V	et	f	\N
141949	peetripühal	?peetripühal =peetripüha  (SgAd  >peetripüha !16_S	et	f	\N
141950	peetripühal	?peetripühal =peetripühal  (SgN  >peetripühal !19_S	et	f	\N
141951	peetripühal	?peetripühal =ripüha  (SgAd  >peet+ripüha !01_S	et	f	\N
141953	peetripühal	?peetripühal =ripühal  (SgN  >peet+ripühal !19_S	et	f	\N
141966	karnevali	karnevali =karnevali  (SgG  >karneval !19_S	et	f	\N
141968	karnevali	karnevali =karnevali  (SgP  >karneval !19_S	et	f	\N
141969	karnevali	karnevali =karnevali  (SgAdt  >karneval !19_S	et	f	\N
142026	purustamist	purustamist =purustamis  (SgP  >purustamine !12_S	et	f	\N
142027	purustamist	"purustamine %purusta  )MINE_vS  <purustama ;27_V	et	f	\N
142035	meelelahutused	meelelahutused =lahutuse  (PlN  >meele+lahutus !11_S	et	f	\N
142036	meelelahutused	"meele+lahutus %lahu  )TUS2_aS  <meele+lahk ;22_S	et	f	\N
142058	kolonni	kolonni =kolonni  (SgG  >kolonn !22_S	et	f	\N
142059	kolonni	kolonni =kolonni  (SgP  >kolonn !22_S	et	f	\N
142060	kolonni	kolonni =kolonni  (SgAdt  >kolonn !22_S	et	f	\N
142061	säravate	säravate =särava  (PlG  >särav !02_A	et	f	\N
142063	säravate	"särav %sära  )V_vA  <särama ;27_V	et	f	\N
142067	mustveest	mustveest =vee  (SgEl  >must+vesi !15_S	et	f	\N
142068	mustveest	mustveest =vees  (SgP  >must+veene !10_A	et	f	\N
142069	mustveest	"must+veene %vee  )NE_aA  <must+vesi ;15_S	et	f	\N
141667	täiendavad	täiendavad =täienda  (IndPrPl3  >täiendama !27_V	et	f	\N
141668	täiendavad	täiendavad =täiendava  (PlN  >täiendav !02_A	et	f	\N
141669	täiendavad	"täiendav %täienda  )V_vA  <täiendama ;27_V	et	f	\N
141670	täiendavad	täiendavad =ava  (PlN  >täiend+ava !17_S	et	f	\N
141671	kuteinik	?kuteinik =kuteinik  (SgN  >kuteinik !25_S	et	f	\N
141682	maiset	?maiset =maise  (SgP  >maise !06_S	et	f	\N
141698	kuul	kuul =kuu  (SgAd  >kuu !26_S	et	f	\N
141699	kuul	kuul =kuul  (SgN  >kuul !22_S	et	f	\N
141728	arsenid	?arsenid =arseni  (PlN  >arsen !02_S	et	f	\N
141744	ristimatta	?ristimatta =ristimatta  (SgN  >ristimatta !16_S	et	f	\N
141745	ristimatta	?ristimatta =ristimatta  (SgG  >ristimatta !16_S	et	f	\N
141746	ristimatta	?ristimatta =imatta  (SgN  >rist+imatta !01_S	et	f	\N
141747	ristimatta	?ristimatta =imatta  (SgG  >rist+imatta !01_S	et	f	\N
141754	tsükklis	?tsükklis =tsükkli  (SgIn  >tsükkli !01_S	et	f	\N
141755	tsükklis	?tsükklis =tsükkli  (SgIn  >tsükkl !22_S	et	f	\N
141759	tsükklis	?tsükklis =tsükkli  (IndIpfSg3  >tsükklima !28_V	et	f	\N
141761	tsükklis	?tsükklis =tsükklis  (SgN  >tsükklis !09_S	et	f	\N
141777	öösiti	öösiti =öösiti  (ID  >öösiti !41_D	et	f	\N
141778	öösiti	öösiti =siti  (SgG  >öö+sitt !22_SA	et	f	\N
141801	nõidujatest	nõidujatest =nõiduja  (PlEl  >nõiduja !01_S	et	f	\N
141802	nõidujatest	"nõiduja %nõidu  )JA_vS  <nõiduma ;28_V	et	f	\N
141815	meditsiinilised	meditsiinilised =meditsiinilise  (PlN  >meditsiiniline !12_A	et	f	\N
141816	meditsiinilised	"meditsiiniline %meditsiini  )LINE_aA  <meditsiin ;22_S	et	f	\N
141823	kirjelduses	kirjelduses =kirjelduse  (SgIn  >kirjeldus !11_S	et	f	\N
141824	kirjelduses	"kirjeldus %kirjelda  )US_vS  <kirjeldama ;27_V	et	f	\N
141844	küpsetisi	?küpsetisi =küpsetisi  (PlP  >küpsetis !11_S	et	f	\N
141874	jäänipaeva	?jäänipaeva =jäänipaeva  (SgN  >jäänipaeva !16_S	et	f	\N
141875	jäänipaeva	?jäänipaeva =jäänipaeva  (SgG  >jäänipaeva !16_S	et	f	\N
141876	jäänipaeva	?jäänipaeva =nipaeva  (SgN  >jää+nipaeva !01_S	et	f	\N
141877	jäänipaeva	?jäänipaeva =nipaeva  (SgG  >jää+nipaeva !01_S	et	f	\N
141878	rohttaimi	rohttaimi =taimi  (SgG  >roht+taim !22_S	et	f	\N
141879	rohttaimi	rohttaimi =taimi  (SgP  >roht+taim !22_S	et	f	\N
141880	rohttaimi	rohttaimi =taimi  (SgAdt  >roht+taim !22_S	et	f	\N
141881	rohttaimi	rohttaimi =taimi  (PlP  >roht+taim !22_S	et	f	\N
141882	rukiviljapäid	?rukiviljapäid =rukiviljapäi  (PlN  >rukiviljapäi !26_S	et	f	\N
141883	rukiviljapäid	?rukiviljapäid =rukiviljapäi  (SgP  >rukiviljapäi !26_S	et	f	\N
141884	rukiviljapäid	?rukiviljapäid =rukiviljapäid  (SgN  >rukiviljapäid !22_S	et	f	\N
141926	visanud	visanud =visa  (PtsPtPs  >viskama !29_V	et	f	\N
141927	visanud	visanud =visanu  (PlN  >visanu !01_S	et	f	\N
141928	visanud	"visanu %visa  )NU_vS  <viskama ;29_V	et	f	\N
141929	visanud	visanud =visanud  (ID  >visanud !41_A	et	f	\N
141930	visanud	"visanud %visa  )NUD_vA  <viskama ;29_V	et	f	\N
141942	lõigatud	lõigatud =lõiga  (PtsPtIps  >lõikama !29_V	et	f	\N
141943	lõigatud	lõigatud =lõigatu  (PlN  >lõigatu !01_AS	et	f	\N
141944	lõigatud	"lõigatu %lõiga  )TU1_vS  <lõikama ;29_V	et	f	\N
141945	lõigatud	lõigatud =lõigatud  (ID  >lõigatud !41_A	et	f	\N
141946	lõigatud	"lõigatud %lõiga  )TUD_vA  <lõikama ;29_V	et	f	\N
141952	petrovki	?petrovki =petrovki  (SgG  >petrovk !22_S	et	f	\N
141954	petrovki	?petrovki =petrovki  (SgP  >petrovk !22_S	et	f	\N
141955	petrovki	?petrovki =petrovki  (SgAdt  >petrovk !22_S	et	f	\N
141956	petrovki	?petrovki =petrovki  (IndPrPs_  >petrovkima !28_V	et	f	\N
141957	petrovki	?petrovki =petrovki  (ImpPrSg2  >petrovkima !28_V	et	f	\N
141960	lemmikpüha	lemmikpüha =püha  (SgN  >lemmik+püha !17_SA	et	f	\N
141961	lemmikpüha	lemmikpüha =püha  (SgG  >lemmik+püha !17_SA	et	f	\N
141962	lemmikpüha	lemmikpüha =püha  (SgP  >lemmik+püha !17_SA	et	f	\N
141963	maslenitsa	?maslenitsa =maslenitsa  (SgN  >maslenitsa !16_S	et	f	\N
141964	maslenitsa	?maslenitsa =maslenitsa  (SgG  >maslenitsa !16_S	et	f	\N
141965	maslenitsa	?maslenitsa =maslenitsa  (SgG  >maslenits !22_S	et	f	\N
141967	maslenitsa	?maslenitsa =maslenitsa  (SgP  >maslenits !22_S	et	f	\N
141970	maslenitsa	?maslenitsa =maslenitsa  (SgAdt  >maslenits !22_S	et	f	\N
141976	tüdrukute	tüdrukute =tüdruku  (PlG  >tüdruk !02_S	et	f	\N
141977	tüdrukute	tüdrukute =ute  (SgG  >tüdruk+utt !22_S	et	f	\N
141978	sallivalt	sallivalt =salliva  (SgAbl  >salliv !02_A	et	f	\N
141979	sallivalt	"salliv %salli  )V_vA  <sallima ;28_V	et	f	\N
141980	sallivalt	sallivalt =sallivalt  (ID  >sallivalt !41_D	et	f	\N
141981	sallivalt	"sallivalt %salli  )VALT_mD  <sallima ;28_V	et	f	\N
141982	sallivalt	"sallivalt %salliva  )LT_mD  <salliv ;02_A	et	f	\N
141983	sallivalt	sallivalt =iva  (SgAbl  >sall+iva !17_S	et	f	\N
142001	puuriidad	puuriidad =ida  (PlN  >puuri+ida !17_S	et	f	\N
142002	puuriidad	puuriidad =riida  (PlN  >puu+riit !22_S	et	f	\N
142006	jms	### jms	et	f	\N
142013	korsten	korsten =korsten  (SgN  >korsten !02_S	et	f	\N
142014	korsten	korsten =korsten  (SgN  >korsten !08_S	et	f	\N
142031	kaklemiseks	kaklemiseks =kaklemise  (SgTr  >kaklemine !12_S	et	f	\N
142032	kaklemiseks	"kaklemine %kakle  )MINE_vS  <kaklema ;30_V	et	f	\N
141701	hammustusest	"hammustus %hammusta  )US_vS  <hammustama ;27_V	et	f	\N
141702	hammustusest	hammustusest =hammustuses  (SgP  >hammustusene !12_A	et	f	\N
141703	hammustusest	"hammustusene %hammustuse  )NE_aA  <hammustus ;11_S	et	f	\N
141723	mütoloogilistes	mütoloogilistes =mütoloogilis  (PlIn  >mütoloogiline !12_A	et	f	\N
141724	mütoloogilistes	"mütoloogiline %mütoloogi  )LINE_aA  <mütoloog ;22_S	et	f	\N
141729	vennast	vennast =venna  (SgEl  >vend !22_S	et	f	\N
141730	vennast	vennast =vennas  (SgP  >vennas !09_S	et	f	\N
141731	vennast	vennast =vennas  (SgP  >vennane !10_A	et	f	\N
141732	vennast	"vennane %venna  )NE_aA  <vend ;22_S	et	f	\N
141741	lilleke	lilleke =lilleke  (SgN  >lilleke !12_S	et	f	\N
141743	lilleke	"lilleke %lille  )KE_dS  <lill ;22_S	et	f	\N
141765	reegioonides	?reegioonides =reegiooni  (PlIn  >reegiooni !16_S	et	f	\N
141766	reegioonides	?reegioonides =reegiooni  (PlIn  >reegioon !22_S	et	f	\N
141767	reegioonides	?reegioonides =reegiooni  (Ger  >reegioonima !28_V	et	f	\N
141769	reegioonides	?reegioonides =giooni  (PlIn  >ree+giooni !16_S	et	f	\N
141771	reegioonides	?reegioonides =giooni  (PlIn  >ree+gioon !22_S	et	f	\N
141785	temaatilised	temaatilised =temaatilise  (PlN  >temaatiline !12_A	et	f	\N
141786	temaatilised	temaatilised =atilise  (PlN  >tema+atiline !12_A	et	f	\N
141787	temaatilised	"tema+atiline %ati  )LINE_aA  <tema+att ;22_S	et	f	\N
141788	metsavaimust	metsavaimust =us  (SgP  >metsa+vaim+uks !14_S	et	f	\N
141789	metsavaimust	metsavaimust =imu  (SgEl  >mets+ava+imu !17_S	et	f	\N
141790	metsavaimust	metsavaimust =vaimu  (SgEl  >metsa+vaim !22_S	et	f	\N
141791	metsavaimust	metsavaimust =vaimu  (PlEl  >metsa+vaim !22_S	et	f	\N
141803	kaetamisest	kaetamisest =kaetamise  (SgEl  >kaetamine !12_S	et	f	\N
141804	kaetamisest	"kaetamine %kaeta  )MINE_vS  <kaetama ;27_V	et	f	\N
141807	kujutluste	kujutluste =kujutlus  (PlG  >kujutlus !11_S	et	f	\N
141808	kujutluste	"kujutlus %kujutle  )US_vS  <kujutlema ;27_V	et	f	\N
141811	posijate	posijate =posija  (PlG  >posija !01_S	et	f	\N
141812	posijate	"posija %posi  )JA_vS  <posima ;27_V	et	f	\N
141819	etnograafilisi	etnograafilisi =etnograafilisi  (PlP  >etnograafiline !12_A	et	f	\N
141820	etnograafilisi	"etnograafiline %etnograafi  )LINE_aA  <etnograaf ;22_S	et	f	\N
141821	etnograafilisi	etnograafilisi =graafilisi  (PlP  >etno+graafiline !12_A	et	f	\N
141822	etnograafilisi	"etno+graafiline %graafi  )LINE_aA  <etno+graaf ;22_S	et	f	\N
141832	kaeve	kaeve =kaeve  (SgN  >kaeve !06_S	et	f	\N
141833	kaeve	kaeve =kaeve  (SgG  >kaeve !06_S	et	f	\N
141834	kaeve	kaeve =kaeve  (PlP  >kaev !22_S	et	f	\N
141836	kaeve	"kaev %kae  )V_vA  <kaema ;27_V	et	f	\N
141846	kohatud	kohatud =koha  (PtsPtIps  >kohama !27_V	et	f	\N
141847	kohatud	kohatud =koha  (PtsPtIps  >kohtama !29_V	et	f	\N
141848	kohatud	kohatud =kohatu  (PlN  >kohatu !01_AS	et	f	\N
141849	kohatud	"kohatu %koha  )TU1_vS  <kohama ;27_V	et	f	\N
141850	kohatud	"kohatu %koha  )TU1_vS  <kohtama ;29_V	et	f	\N
141852	kohatud	"kohatu %koha  )TU2_kA  <koha ;17_S	et	f	\N
141854	kohatud	"kohatu %koha  )TU2_kA  <koht ;22_S	et	f	\N
141856	kohatud	kohatud =kohatud  (ID  >kohatud !41_A	et	f	\N
141857	kohatud	"kohatud %koha  )TUD_vA  <kohama ;27_V	et	f	\N
141858	kohatud	"kohatud %koha  )TUD_vA  <kohtama ;29_V	et	f	\N
141888	kevadine	kevadine =kevadine  (SgN  >kevadine !12_A	et	f	\N
141889	kevadine	"kevadine %kevadi  )NE_aA  <kevad ;02_S	et	f	\N
141890	kevadine	kevadine =ine  (SgN  >kevad+ine !16_S	et	f	\N
141891	kevadine	kevadine =ine  (SgG  >kevad+ine !16_S	et	f	\N
141971	söömisega	söömisega =söömise  (SgKom  >söömine !12?10_S	et	f	\N
141972	söömisega	"söömine %söö  )MINE_vS  <sööma ;38_V	et	f	\N
141973	söömisega	"söömine %söömi  )NE_aA  <sööm ;22_S	et	f	\N
141974	suhtusid	suhtusid =suhtu  (IndIpfSg2  >suhtuma !27_V	et	f	\N
141975	suhtusid	suhtusid =suhtu  (IndIpfPl3  >suhtuma !27_V	et	f	\N
141984	nooruses	nooruses =nooruse  (SgIn  >noorus !11~09_S	et	f	\N
141985	nooruses	"noorus %noor  )US_aS  <noor ;13_AS	et	f	\N
141986	nooruses	nooruses =use  (PlIn  >noor+usk !22_S	et	f	\N
141997	teivad	?teivad =teiva  (PlN  >teiva !16_S	et	f	\N
141998	teivad	?teivad =teiva  (IndPrSg2  >teivama !29_V	et	f	\N
142007	märatsemised	märatsemised =märatsemise  (PlN  >märatsemine !12_S	et	f	\N
142008	märatsemised	"märatsemine %märatse  )MINE_vS  <märatsema ;27_V	et	f	\N
142011	väiksema	väiksema =väiksema  (SgG  >väiksem !02_A	et	f	\N
142012	väiksema	"väiksem %väikse  )M_cA  <väike ;10_A	et	f	\N
142017	magava	magava =magava  (SgG  >magav !02_A	et	f	\N
142018	magava	"magav %maga  )V_vA  <magama ;27_V	et	f	\N
142038	istjaid	?istjaid =istja  (PlP  >istja !01_S	et	f	\N
142039	istjaid	?istjaid =istja  (PlP  >istjas !02_A	et	f	\N
142040	istjaid	?istjaid =istjai  (PlN  >istjai !26_S	et	f	\N
142041	istjaid	?istjaid =istjai  (SgP  >istjai !26_S	et	f	\N
142042	istjaid	?istjaid =istjaid  (SgN  >istjaid !22_S	et	f	\N
142050	marsisid	?marsisid =marsi  (PlP  >marsi !16_S	et	f	\N
142051	marsisid	?marsisid =marsi  (PlP  >mars !22_S	et	f	\N
142052	marsisid	?marsisid =marsi  (IndIpfSg2  >marsima !28_V	et	f	\N
142053	marsisid	?marsisid =marsi  (IndIpfPl3  >marsima !28_V	et	f	\N
142070	tulekahju	tulekahju =kahju  (SgN  >tule+kahju !16~17_S	et	f	\N
141859	asetatud	asetatud =aseta  (PtsPtIps  >asetama !27_V	et	f	\N
141860	asetatud	asetatud =asetatu  (PlN  >asetatu !01_S	et	f	\N
141861	asetatud	"asetatu %aseta  )TU1_vS  <asetama ;27_V	et	f	\N
141862	asetatud	asetatud =asetatud  (ID  >asetatud !41_A	et	f	\N
141863	asetatud	"asetatud %aseta  )TUD_vA  <asetama ;27_V	et	f	\N
141864	asetatud	asetatud =atu  (PlN  >aset+att !22_S	et	f	\N
141870	ennustustes	ennustustes =ennustus  (PlIn  >ennustus !11_S	et	f	\N
141871	ennustustes	"ennustus %ennusta  )US_vS  <ennustama ;27_V	et	f	\N
141885	lõunapoolsetes	lõunapoolsetes =sete  (PlIn  >lõuna+pool+sett !22_S	et	f	\N
141886	lõunapoolsetes	lõunapoolsetes =poolse  (PlIn  >lõuna+poolne !02_A	et	f	\N
141887	jegorij	### jegorij	et	f	\N
141892	joodi	joodi =joo  (IndIpfIps  >jooma !38_V	et	f	\N
141893	joodi	joodi =joodi  (SgG  >jood !22_S	et	f	\N
141896	joodi	joodi =joodi  (SgP  >jood !22_S	et	f	\N
141898	joodi	joodi =joodi  (SgAdt  >jood !22_S	et	f	\N
141900	joodi	joodi =joodi  (IndPrPs_  >joodima !28_V	et	f	\N
141902	joodi	joodi =joodi  (ImpPrSg2  >joodima !28_V	et	f	\N
141907	riietatult	riietatult =riietatu  (SgAbl  >riietatu !01_S	et	f	\N
141908	riietatult	"riietatu %riieta  )TU1_vS  <riietama ;27_V	et	f	\N
141909	riietatult	riietatult =riietatult  (ID  >riietatult !41_D	et	f	\N
141910	riietatult	"riietatult %riieta  )TULT1_mD  <riietama ;27_V	et	f	\N
141916	sümboliseeris	sümboliseeris =sümboliseeri  (IndIpfSg3  >sümboliseerima !28_V	et	f	\N
141917	sümboliseeris	sümboliseeris =eri  (SgIn  >sümbol+ise+eri !17_S	et	f	\N
141922	olevipäeva	olevipäeva =päeva  (SgG  >olevi+päev !22_S	et	f	\N
141924	olevipäeva	olevipäeva =päeva  (SgP  >olevi+päev !22_S	et	f	\N
141925	olevipäeva	olevipäeva =päeva  (SgAdt  >olevi+päev !22_S	et	f	\N
141931	pühi	pühi =pühi  (PlP  >püha !17_SA	et	f	\N
141932	pühi	pühi =pühi  (IndPrPs_  >pühkima !28_V	et	f	\N
141933	pühi	pühi =pühi  (ImpPrSg2  >pühkima !28_V	et	f	\N
141958	kutsimattagi	?kutsimattagi =kutsimatta  (SgN^  >kutsimatta !16_S	et	f	\N
141959	kutsimattagi	?kutsimattagi =kutsimatta  (SgG^  >kutsimatta !16_S	et	f	\N
141990	hoovi	hoovi =hoovi  (SgG  >hoov !22_S	et	f	\N
141991	hoovi	hoovi =hoovi  (SgP  >hoov !22_S	et	f	\N
141992	hoovi	hoovi =hoovi  (SgAdt  >hoov !22_S	et	f	\N
142003	sedalaadi	sedalaadi =laadi  (SgG  >seda+laad !22_S	et	f	\N
142004	sedalaadi	sedalaadi =laadi  (SgP  >seda+laad !22_S	et	f	\N
142005	sedalaadi	sedalaadi =laadi  (SgAdt  >seda+laad !22_S	et	f	\N
142009	ootamatuid	ootamatuid =ootamatu  (PlP  >ootamatu !01_A	et	f	\N
142010	ootamatuid	"ootamatu %oota  )MATU_vA  <ootama ;29_V	et	f	\N
142022	lumelinnust	lumelinnust =us  (SgP  >lume+linn+uks !14_S	et	f	\N
142023	lumelinnust	lumelinnust =linnu  (SgEl  >lume+lind !22_S	et	f	\N
142024	lumelinnust	lumelinnust =linnu  (PlEl  >lume+linn !22_S	et	f	\N
142025	lumelinnust	lumelinnust =linnus  (SgP  >lume+linnus !09_S	et	f	\N
142043	tuleturjutate	?tuleturjutate =tuleturjuta  (IndPrPl2  >tuleturjutama !27_V	et	f	\N
142044	erirõivas	erirõivas =rõiva  (SgIn  >eri+rõivas !07_S	et	f	\N
142045	erirõivas	erirõivas =rõivas  (SgN  >eri+rõivas !07_S	et	f	\N
142046	tes	### tes	et	f	\N
142047	läikivates	läikivates =läikiva  (PlIn  >läikiv !02_A	et	f	\N
142048	läikivates	"läikiv %läiki  )V_vA  <läikima ;28_V	et	f	\N
142049	läikivates	läikivates =ate  (PlIn  >läikiv+att !22_S	et	f	\N
142062	vaimustusest	vaimustusest =vaimustuse  (SgEl  >vaimustus !11_S	et	f	\N
142064	vaimustusest	"vaimustus %vaimusta  )US_vS  <vaimustama ;27_V	et	f	\N
142065	vaimustusest	vaimustusest =vaimustuses  (SgP  >vaimustusene !12_A	et	f	\N
142066	vaimustusest	"vaimustusene %vaimustuse  )NE_aA  <vaimustus ;11_S	et	f	\N
142079	kiiruses	kiiruses =kiiruse  (SgIn  >kiirus !11~09_S	et	f	\N
142080	kiiruses	"kiirus %kiire  )US_aS  <kiire ;01_A	et	f	\N
142081	kiiruses	kiiruses =use  (PlIn  >kiir+usk !22_S	et	f	\N
142082	jumaleteenistus	?jumaleteenistus =jumaleteenistu  (IndIpfSg3  >jumaleteenistuma !27_V	et	f	\N
142083	jumaleteenistus	?jumaleteenistus =jumaleteenistus  (SgN  >jumaleteenistus !11_S	et	f	\N
142134	nimetustes	nimetustes =nimetus  (PlIn  >nimetus !11_S	et	f	\N
142135	nimetustes	"nimetus %nimeta  )US_vS  <nimetama ;27_V	et	f	\N
142136	nimetustes	"nimetus %nime  )TUS2_aS  <nimi ;20_S	et	f	\N
142137	nimetustes	nimetustes =tuste  (PlIn  >nime+tust !22_S	et	f	\N
142147	kalevipojast	kalevipojast =poja  (SgEl  >kalevi+poja !17_S	et	f	\N
142148	kalevipojast	kalevipojast =poja  (SgEl  >kalevi+poeg !22_S	et	f	\N
142149	kalevipojast	kalevipojast =pojas  (SgP  >kalevi+pojane !10_A	et	f	\N
142151	kalevipojast	"kalevi+pojane %poja  )NE_aA  <kalevi+poja ;17_S	et	f	\N
142153	kalevipojast	"kalevi+pojane %poja  )NE_aA  <kalevi+poeg ;22_S	et	f	\N
142168	eestlastelt	eestlastelt =eestlas  (PlAbl  >eestlane !12?10_S	et	f	\N
142169	eestlastelt	eestlastelt =las  (PlAbl  >eest+laps !14_S	et	f	\N
142170	eestlastelt	eestlastelt =laste  (PlAbl  >eest+last !22_S	et	f	\N
142174	interpreteerisit	?interpreteerisit =risit  (SgN  >inter+pre+tee+risit !02_S	et	f	\N
142183	kuslike	?kuslike =kuslike  (SgN  >kuslike !12_S	et	f	\N
142184	kuslike	?kuslike =kuslike  (PlG  >kuslik !25_A	et	f	\N
142192	veenvam	veenvam =veenvam  (SgN  >veenvam !02_A	et	f	\N
142193	veenvam	"veenvam %veen  )VAM_cA  <veenma ;33_V	et	f	\N
141935	pühi	pühi =pühi  (IndPrPs_  >pühkima !28_V	et	f	\N
141936	pühi	pühi =pühi  (ImpPrSg2  >pühkima !28_V	et	f	\N
141937	kärarikkalt	?kärarikkalt =kärarikka  (SgAbl  >kärarikka !16_S	et	f	\N
141938	kärarikkalt	?kärarikkalt =kärarikkalt  (ID  >kärarikkalt !41_D	et	f	\N
141939	kärarikkalt	?kärarikkalt =rikka  (SgAbl  >kära+rikas !07_A	et	f	\N
141940	mandrist	mandrist =mandri  (SgEl  >mander !02_S	et	f	\N
141941	mandrist	mandrist =mandri  (SgEl  >manner !03_S	et	f	\N
141947	suvisel	suvisel =suvise  (SgAd  >suvine !10_A	et	f	\N
141948	suvisel	"suvine %suvi  )NE_aA  <suvi ;20_S	et	f	\N
141987	kartlikult	kartlikult =kartliku  (SgAbl  >kartlik !25_A	et	f	\N
141988	kartlikult	kartlikult =kartlikult  (ID  >kartlikult !41_D	et	f	\N
141989	kartlikult	"kartlikult %kartliku  )LT_mD  <kartlik ;25_A	et	f	\N
141993	nääri	nääri =nääri  (SgG  >näär !22_S	et	f	\N
141994	nääri	nääri =nääri  (SgP  >näär !22_S	et	f	\N
141995	nääri	nääri =nääri  (SgAdt  >näär !22_S	et	f	\N
141996	nääri	nääri =nääri  (PlP  >näär !22_S	et	f	\N
141999	korstnad	korstnad =korstna  (PlN  >korsten !02_S	et	f	\N
142000	korstnad	korstnad =korstna  (PlN  >korsten !08_S	et	f	\N
142015	rahulikku	rahulikku =rahulikku  (SgP  >rahulik !25_A	et	f	\N
142016	rahulikku	rahulikku =rahulikku  (SgAdt  >rahulik !25_A	et	f	\N
142019	sängi	sängi =sängi  (SgG  >säng !22_S	et	f	\N
142020	sängi	sängi =sängi  (SgP  >säng !22_S	et	f	\N
142021	sängi	sängi =sängi  (SgAdt  >säng !22_S	et	f	\N
142028	naaberküla	naaberküla =küla  (SgN  >naaber+küla !17_S	et	f	\N
142029	naaberküla	naaberküla =küla  (SgG  >naaber+küla !17_S	et	f	\N
142030	naaberküla	naaberküla =küla  (SgP  >naaber+küla !17_S	et	f	\N
142077	kustutamise	kustutamise =kustutamise  (SgG  >kustutamine !12_S	et	f	\N
142078	kustutamise	"kustutamine %kustuta  )MINE_vS  <kustutama ;27_V	et	f	\N
142084	valgustuspäeva	valgustuspäeva =päeva  (SgG  >valgustus+päev !22_S	et	f	\N
142085	valgustuspäeva	valgustuspäeva =päeva  (SgP  >valgustus+päev !22_S	et	f	\N
142086	valgustuspäeva	valgustuspäeva =päeva  (SgAdt  >valgustus+päev !22_S	et	f	\N
142087	koraldada	?koraldada =koralda  (Inf  >koraldama !27_V	et	f	\N
142099	liivased	liivased =liivase  (PlN  >liivane !10_A	et	f	\N
142100	liivased	"liivane %liiva  )NE_aA  <liiv ;22_S	et	f	\N
142107	istutanud	istutanud =istuta  (PtsPtPs  >istutama !27_V	et	f	\N
142108	istutanud	istutanud =istutanu  (PlN  >istutanu !01_S	et	f	\N
142109	istutanud	"istutanu %istuta  )NU_vS  <istutama ;27_V	et	f	\N
142110	istutanud	istutanud =istutanud  (ID  >istutanud !41_A	et	f	\N
142111	istutanud	"istutanud %istuta  )NUD_vA  <istutama ;27_V	et	f	\N
142114	põhjust	põhjust =põhju  (PlEl  >põhi !24_S	et	f	\N
142115	põhjust	põhjust =põhjus  (SgP  >põhjus !11~09_S	et	f	\N
142116	jutustajad	jutustajad =jutustaja  (PlN  >jutustaja !01_S	et	f	\N
142117	jutustajad	"jutustaja %jutusta  )JA_vS  <jutustama ;27_V	et	f	\N
142120	linnakestes	linnakestes =linnakes  (PlIn  >linnake !12_S	et	f	\N
142121	linnakestes	"linnake %linna  )KE_dS  <linn ;22_S	et	f	\N
142122	linnakestes	linnakestes =linnakes  (PlIn  >linnakene !12_S	et	f	\N
142123	linnakestes	"linnakene %linna  )KENE_dS  <linn ;22_S	et	f	\N
142124	linnakestes	linnakestes =keste  (SgIn  >linna+keste !06_S	et	f	\N
142125	linnakestes	linnakestes =keste  (PlIn  >linna+kest !22_S	et	f	\N
142128	kõnekeeles	kõnekeeles =keele  (SgIn  >kõne+keel !13_S	et	f	\N
142129	kõnekeeles	kõnekeeles =keele  (PlIn  >kõne+keeld !22_S	et	f	\N
142140	abel	?abel =abe  (SgAd  >abe !16_S	et	f	\N
142141	abel	?abel =abel  (SgN  >abel !02_S	et	f	\N
142144	folkloorile	folkloorile =folkloori  (SgAll  >folkloor !22_S	et	f	\N
142145	folkloorile	folkloorile =loori  (SgAll  >folk+loori !16_S	et	f	\N
142146	folkloorile	folkloorile =loori  (SgAll  >folk+loor !22_S	et	f	\N
142171	kukkumisest	kukkumisest =kukkumise  (SgEl  >kukkumine !12_S	et	f	\N
142172	kukkumisest	"kukkumine %kukku  )MINE_vS  <kukkuma ;28_V	et	f	\N
142173	samat	?samat =samat  (SgN  >samat !02_S	et	f	\N
142181	kõlba	kõlba =kõlba  (IndPrPs_  >kõlbama !29_V	et	f	\N
142182	kõlba	kõlba =kõlba  (ImpPrSg2  >kõlbama !29_V	et	f	\N
142204	tõusu	tõusu =tõusu  (SgG  >tõus !22_S	et	f	\N
142205	tõusu	tõusu =tõusu  (SgP  >tõus !22_S	et	f	\N
142206	tõusu	tõusu =tõusu  (SgAdt  >tõus !22_S	et	f	\N
142225	valgevene	valgevene =vene  (SgN  >valge+vene !16_S	et	f	\N
142226	valgevene	valgevene =vene  (SgG  >valge+vene !16_S	et	f	\N
142229	ausuliste	ausuliste =sulis  (PlG  >au+suline !10_A	et	f	\N
142230	ausuliste	"au+suline %suli  )NE_aA  <au+suli ;17_S	et	f	\N
142234	varnja	?varnja =varnja  (SgN  >varnja !01_S	et	f	\N
142235	varnja	?varnja =varnja  (SgG  >varnja !01_S	et	f	\N
142236	varnja	?varnja =varnja  (SgG  >varnjas !02_A	et	f	\N
142237	varnja	?varnja =varnja  (IndPrPs_  >varnjama !29_V	et	f	\N
142238	varnja	?varnja =varnja  (ImpPrSg2  >varnjama !29_V	et	f	\N
142244	kontekstuaalne	?kontekstuaalne =kontekstuaalne  (SgN  >kontekstuaalne !02_A	et	f	\N
142245	kontekstuaalne	?kontekstuaalne =kontekstuaalne  (PlP  >kontekstuaaln !22_S	et	f	\N
142246	kontekstuaalne	?kontekstuaalne =tuaalne  (SgN  >kont+eks+tuaalne !02_A	et	f	\N
142033	novgorodlaste	?novgorodlaste =novgorodlas  (PlG  >novgorodlane !12_S	et	f	\N
142034	novgorodlaste	?novgorodlaste =novgorodlaste  (PlP  >novgorodlast !22_S	et	f	\N
142037	talvistepühade	?talvistepühade =talvistepüha  (PlG  >talvistepüha !16_S	et	f	\N
142054	ehtisid	ehtisid =ehti  (IndIpfSg2  >ehtima !27_V	et	f	\N
142055	ehtisid	ehtisid =ehti  (IndIpfSg2  >ehtima !28_V	et	f	\N
142056	ehtisid	ehtisid =ehti  (IndIpfPl3  >ehtima !27_V	et	f	\N
142057	ehtisid	ehtisid =ehti  (IndIpfPl3  >ehtima !28_V	et	f	\N
142091	tõsieluloode	tõsieluloode =loode  (SgN  >tõsi+elu+loode !06_S	et	f	\N
142092	tõsieluloode	tõsieluloode =loode  (SgG  >tõsi+elu+loe !06_S	et	f	\N
142093	tõsieluloode	tõsieluloode =loode  (SgG  >tõsi+elu+loode !06_S	et	f	\N
142094	tõsieluloode	tõsieluloode =loode  (PlP  >tõsi+elu+lood !22_S	et	f	\N
142126	pärimuskultuur	?pärimuskultuur =pärimuskultuur  (SgN  >pärimuskultuur !22_S	et	f	\N
142127	pärimuskultuur	?pärimuskultuur =muskultuur  (SgN  >päri+muskultuur !22_S	et	f	\N
142130	laensõnu	?laensõnu =laensõnu  (SgN  >laensõnu !01_S	et	f	\N
142131	laensõnu	?laensõnu =laensõnu  (SgG  >laensõnu !01_S	et	f	\N
142132	laensõnu	?laensõnu =laensõnu  (IndPrPs_  >laensõnuma !27_V	et	f	\N
142133	laensõnu	?laensõnu =laensõnu  (ImpPrSg2  >laensõnuma !27_V	et	f	\N
142177	kukkub	### kukkub	et	f	\N
142185	kukkumist	kukkumist =kukkumis  (SgP  >kukkumine !12_S	et	f	\N
142186	kukkumist	"kukkumine %kukku  )MINE_vS  <kukkuma ;28_V	et	f	\N
142214	analoogiline	analoogiline =analoogiline  (SgN  >analoogiline !12_A	et	f	\N
142215	analoogiline	"analoogiline %analoogi  )LINE_aA  <analoog ;22_S	et	f	\N
142223	ritual	?ritual =ritua  (SgAd  >ritua !01_S	et	f	\N
142224	ritual	?ritual =ritual  (SgN  >ritual !19_S	et	f	\N
142227	asulates	asulates =asula  (PlIn  >asula !01_S	et	f	\N
142228	asulates	asulates =late  (PlIn  >asu+latt !22_S	et	f	\N
142242	kultuuridevaheline	kultuuridevaheline =vaheline  (SgN  >kultuuride+vaheline !12_A	et	f	\N
142243	kultuuridevaheline	"kultuuride+vaheline %vahe  )LINE_aA  <kultuuride+vahe ;16_S	et	f	\N
142247	vastasmõju	vastasmõju =mõju  (SgN  >vastas+mõju !17_S	et	f	\N
142249	vastasmõju	vastasmõju =mõju  (SgG  >vastas+mõju !17_S	et	f	\N
142251	vastasmõju	vastasmõju =mõju  (SgP  >vastas+mõju !17_S	et	f	\N
142261	laija	?laija =laija  (SgN  >laija !01_S	et	f	\N
142263	laija	?laija =laija  (SgG  >laija !01_S	et	f	\N
142264	laija	?laija =laija  (IndPrPs_  >laijama !29_V	et	f	\N
142265	laija	?laija =laija  (ImpPrSg2  >laijama !29_V	et	f	\N
142314	seotust	seotust =seotu  (SgEl  >seotu !01_A	et	f	\N
142315	seotust	"seotu %seo  )TU1_vS  <siduma ;28_V	et	f	\N
142316	seotust	seotust =seotus  (SgP  >seotus !11~09_S	et	f	\N
142317	seotust	"seotus %seo  )TUS1_aS  <siduma ;28_V	et	f	\N
142325	omamata	omamata =oma  (SupAb  >omama !27_V	et	f	\N
142326	omamata	omamata =omama  (SgAb  >omam !02_A	et	f	\N
142327	omamata	"omam %oma  )M_cA  <oma ;17_A	et	f	\N
142328	omamata	omamata =omamata  (ID  >omamata !41_A	et	f	\N
142329	omamata	"omamata %oma  )MATA_vA  <omama ;27_V	et	f	\N
142336	kihti	kihti =kihti  (SgP  >kiht !22_S	et	f	\N
142337	kihti	kihti =kihti  (SgAdt  >kiht !22_S	et	f	\N
142340	jegorov	?jegorov =jegorov  (SgN  >jegorov !02_A	et	f	\N
142343	külasi	?külasi =külasi  (ID  >külasi !41_D	et	f	\N
142354	olga	?olga =olga  (SgN  >olga !16_S	et	f	\N
142355	olga	?olga =olga  (SgG  >olga !16_S	et	f	\N
142356	olga	?olga =olga  (IndPrPs_  >olgama !29_V	et	f	\N
142358	olga	?olga =olga  (ImpPrSg2  >olgama !29_V	et	f	\N
142361	pulmakombeid	pulmakombeid =bei  (PlN  >pulma+kom+bei !26_S	et	f	\N
142362	pulmakombeid	pulmakombeid =bei  (SgP  >pulma+kom+bei !26_S	et	f	\N
142363	pulmakombeid	pulmakombeid =kombe  (PlP  >pulma+komme !06_S	et	f	\N
142368	ennustusi	ennustusi =ennustusi  (PlP  >ennustus !11_S	et	f	\N
142369	ennustusi	"ennustus %ennusta  )US_vS  <ennustama ;27_V	et	f	\N
142370	kogumiku	kogumiku =kogumiku  (SgG  >kogumik !25_S	et	f	\N
142371	kogumiku	kogumiku =miku  (SgG  >kogu+mikk !22_S	et	f	\N
142385	küsitluse	küsitluse =küsitluse  (SgG  >küsitlus !11_S	et	f	\N
142386	küsitluse	"küsitlus %küsitle  )US_vS  <küsitlema ;27_V	et	f	\N
142394	astatel	?astatel =astate  (PlAd  >astatt !22_S	et	f	\N
142402	aastakümned	### aastakümned	et	f	\N
142421	mitusada	### mitusada	et	f	\N
142422	üleantud	üleantud =an  (PtsPtIps  >üle+_andma !34_V	et	f	\N
142423	üleantud	üleantud =antu  (PlN  >üle+antu !01_S	et	f	\N
142427	kogujate	kogujate =koguja  (PlG  >koguja !01_S	et	f	\N
142428	kogujate	"koguja %kogu  )JA_vS  <koguma ;27_V	et	f	\N
142429	vaimilikud	?vaimilikud =vaimiliku  (PlN  >vaimilik !25_A	et	f	\N
142430	vaimilikud	?vaimilikud =vaimiliku  (IndPrSg2  >vaimilikuma !27_V	et	f	\N
142431	vaimilikud	?vaimilikud =iliku  (PlN  >vaim+iliku !01_S	et	f	\N
142432	vaimilikud	?vaimilikud =iliku  (PlN  >vaim+ilik !02_S	et	f	\N
142433	olmemaagia	olmemaagia =maagia  (SgN  >olme+maagia !01_S	et	f	\N
142434	olmemaagia	olmemaagia =maagia  (SgG  >olme+maagia !01_S	et	f	\N
142453	ekspeditisiooni	?ekspeditisiooni =ekspeditisioo  (SgTer  >ekspeditisioo !26_S	et	f	\N
142454	ekspeditisiooni	?ekspeditisiooni =ekspeditisiooni  (SgN  >ekspeditisiooni !16_S	et	f	\N
142071	tulekahju	tulekahju =kahju  (SgG  >tule+kahju !16~17_S	et	f	\N
142072	tulekahju	tulekahju =kahju  (SgG  >tule+kahi !24_S	et	f	\N
142073	tulekahju	tulekahju =kahju  (SgP  >tule+kahju !17_S	et	f	\N
142074	tulekahju	tulekahju =kahju  (SgP  >tule+kahi !24_S	et	f	\N
142075	tulekahju	tulekahju =kahju  (SgAdt  >tule+kahi !24_S	et	f	\N
142076	tulekahju	tulekahju =kahju  (PlP  >tule+kahi !24_S	et	f	\N
142088	tendentsi	tendentsi =tendentsi  (SgG  >tendents !22_S	et	f	\N
142089	tendentsi	tendentsi =tendentsi  (SgP  >tendents !22_S	et	f	\N
142090	tendentsi	tendentsi =tendentsi  (SgAdt  >tendents !22_S	et	f	\N
142095	kolmelt	kolmelt =kolme  (SgAbl  >kolm !22_N	et	f	\N
142096	kolmelt	kolmelt =kolme  (PlAbl  >kolm !22_N	et	f	\N
142097	pajatasid	pajatasid =pajata  (IndIpfSg2  >pajatama !27_V	et	f	\N
142098	pajatasid	pajatasid =pajata  (IndIpfPl3  >pajatama !27_V	et	f	\N
142101	pilliroopõõsast	pilliroopõõsast =põõsa  (SgEl  >pilli+roo+põõsas !07_S	et	f	\N
142102	pilliroopõõsast	pilliroopõõsast =põõsas  (SgP  >pilli+roo+põõsas !07_S	et	f	\N
142103	pilliroopõõsast	pilliroopõõsast =põõsas  (SgP  >pilli+roo+põõsane !10_A	et	f	\N
142104	pilliroopõõsast	"pilli+roo+põõsane %põõsa  )NE_aA  <pilli+roo+põõsas ;07_S	et	f	\N
142105	liivaranda	liivaranda =randa  (SgP  >liiva+rand !22_S	et	f	\N
142106	liivaranda	liivaranda =randa  (SgAdt  >liiva+rand !22_S	et	f	\N
142138	paptistõ	### paptistõ	et	f	\N
142142	avel	?avel =ave  (SgAd  >ave !16_S	et	f	\N
142143	avel	?avel =avel  (SgN  >avel !02_S	et	f	\N
142162	kuvist	?kuvist =kuvi  (SgEl  >kuvi !17_S	et	f	\N
142163	kuvist	?kuvist =kuvis  (SgP  >kuvis !09_S	et	f	\N
142164	kuvist	?kuvist =kuvist  (SgN  >kuvist !22_S	et	f	\N
142175	kägu	kägu =kägu  (SgN  >kägu !18_S	et	f	\N
142176	kägu	kägu =kägu  (SgP  >kägu !18_S	et	f	\N
142198	parallelides	### parallelides	et	f	\N
142207	sünnitajat	sünnitajat =sünnitaja  (SgP  >sünnitaja !01_S	et	f	\N
142208	sünnitajat	"sünnitaja %sünnita  )JA_vS  <sünnitama ;27_V	et	f	\N
142209	välistatud	välistatud =välista  (PtsPtIps  >välistama !27_V	et	f	\N
142210	välistatud	välistatud =välistatu  (PlN  >välistatu !01_S	et	f	\N
142211	välistatud	"välistatu %välista  )TU1_vS  <välistama ;27_V	et	f	\N
142212	välistatud	välistatud =välistatud  (ID  >välistatud !41_A	et	f	\N
142213	välistatud	"välistatud %välista  )TUD_vA  <välistama ;27_V	et	f	\N
142233	naberkülades	### naberkülades	et	f	\N
142253	ilmne	ilmne =ilmne  (SgN  >ilmne !02_A	et	f	\N
142254	ilmne	ilmne =ilmne  (IndPrPs_  >ilmnema !27_V	et	f	\N
142255	ilmne	ilmne =ilmne  (ImpPrSg2  >ilmnema !27_V	et	f	\N
142258	takistuseks	takistuseks =takistuse  (SgTr  >takistus !11_S	et	f	\N
142259	takistuseks	"takistus %takista  )US_vS  <takistama ;27_V	et	f	\N
142286	beloussovi	?beloussovi =beloussovi  (ID  >beloussovi !41_D	et	f	\N
142287	beloussovi	?beloussovi =beloussovi  (SgG  >beloussov !02_A	et	f	\N
142297	beloussov	?beloussov =beloussov  (SgN  >beloussov !02_A	et	f	\N
142298	parameetrite	parameetrite =parameetri  (PlG  >parameeter !02_S	et	f	\N
142299	parameetrite	parameetrite =meetri  (PlG  >para+meeter !02_S	et	f	\N
142300	seaduspärasusi	seaduspärasusi =susi  (SgN  >seadus+pära+susi !15_S	et	f	\N
142301	seaduspärasusi	seaduspärasusi =susi  (PlP  >seadus+pära+susi !15_S	et	f	\N
142302	seaduspärasusi	seaduspärasusi =pärasusi  (PlP  >seadus+pärasus !11_S	et	f	\N
142303	seaduspärasusi	"seadus+pärasus %pära  )SUS_aS  <seadus+pära ;17_S	et	f	\N
142307	rahvaluules	rahvaluules =luule  (SgIn  >rahva+luule !06_S	et	f	\N
142308	rahvaluules	rahvaluules =luule  (PlIn  >rahva+luul !22_S	et	f	\N
142309	ülekaalu	ülekaalu =kaalu  (SgG  >üle+kaal !22_S	et	f	\N
142310	ülekaalu	ülekaalu =kaalu  (SgP  >üle+kaal !22_S	et	f	\N
142312	ülekaalu	ülekaalu =kaalu  (SgAdt  >üle+kaal !22_S	et	f	\N
142339	gromov	?gromov =gromov  (SgN  >gromov !02_A	et	f	\N
142376	algkooli	algkooli =kooli  (SgG  >alg+kool !22_S	et	f	\N
142377	algkooli	algkooli =kooli  (SgP  >alg+kool !22_S	et	f	\N
142378	algkooli	algkooli =kooli  (SgAdt  >alg+kool !22_S	et	f	\N
142379	algkooli	algkooli =kooli  (PlP  >alg+kool !22_S	et	f	\N
142388	kajastatud	kajastatud =kajasta  (PtsPtIps  >kajastama !27_V	et	f	\N
142389	kajastatud	kajastatud =kajastatu  (PlN  >kajastatu !01_S	et	f	\N
142390	kajastatud	"kajastatu %kajasta  )TU1_vS  <kajastama ;27_V	et	f	\N
142391	kajastatud	kajastatud =kajastatud  (ID  >kajastatud !41_A	et	f	\N
142392	kajastatud	"kajastatud %kajasta  )TUD_vA  <kajastama ;27_V	et	f	\N
142399	feklistova	?feklistova =feklistova  (SgN  >feklistova !16_S	et	f	\N
142400	feklistova	?feklistova =feklistova  (SgG  >feklistov !02_A	et	f	\N
142401	feklistova	?feklistova =feklistova  (SgG  >feklistova !16_S	et	f	\N
142405	seiskunud	seiskunud =seisku  (PtsPtPs  >seiskuma !27_V	et	f	\N
142406	seiskunud	seiskunud =seiskunu  (PlN  >seiskunu !01_S	et	f	\N
142407	seiskunud	"seiskunu %seisku  )NU_vS  <seiskuma ;27_V	et	f	\N
142408	seiskunud	seiskunud =seiskunud  (ID  >seiskunud !41_A	et	f	\N
142409	seiskunud	"seiskunud %seisku  )NUD_vA  <seiskuma ;27_V	et	f	\N
142412	varunini	?varunini =varuni  (SgTer  >varun !02_S	et	f	\N
142413	varunini	?varunini =varunini  (SgG  >varunin !19_S	et	f	\N
142112	teo	teo =teo  (SgG  >tegu !18_S	et	f	\N
142113	teo	teo =teo  (SgG  >tigu !18_S	et	f	\N
142118	jahimees	jahimees =mee  (SgIn  >jahi+mesi !15_S	et	f	\N
142119	jahimees	jahimees =mees  (SgN  >jahi+mees !13_S	et	f	\N
142139	baptistõ	### baptistõ	et	f	\N
142150	heitnud	heitnud =heit  (PtsPtPs  >heitma !34_V	et	f	\N
142152	heitnud	heitnud =heitnu  (PlN  >heitnu !01_S	et	f	\N
142154	heitnud	"heitnu %heit  )NU_vS  <heitma ;34_V	et	f	\N
142155	heitnud	heitnud =heitnud  (ID  >heitnud !41_A	et	f	\N
142156	heitnud	"heitnud %heit  )NUD_vA  <heitma ;34_V	et	f	\N
142157	peletanud	peletanud =peleta  (PtsPtPs  >peletama !27_V	et	f	\N
142158	peletanud	peletanud =peletanu  (PlN  >peletanu !01_S	et	f	\N
142159	peletanud	"peletanu %peleta  )NU_vS  <peletama ;27_V	et	f	\N
142160	peletanud	peletanud =peletanud  (ID  >peletanud !41_A	et	f	\N
142161	peletanud	"peletanud %peleta  )NUD_vA  <peletama ;27_V	et	f	\N
142165	kaheteiskümnes	?kaheteiskümnes =kaheteiskümne  (PlIn  >kaheteiskümn !22_S	et	f	\N
142166	kaheteiskümnes	?kaheteiskümnes =kümne  (PlIn  >kahe+teis+kümn !22_S	et	f	\N
142167	kaheteiskümnes	?kaheteiskümnes =teiskümne  (PlIn  >kahe+teiskümn !22_S	et	f	\N
142178	hommikune	hommikune =hommikune  (SgN  >hommikune !12_A	et	f	\N
142179	hommikune	"hommikune %hommiku  )NE_aA  <hommik ;02_S	et	f	\N
142180	hommikune	hommikune =une  (SgG  >hommik+uni !20_S	et	f	\N
142187	õhtune	õhtune =õhtune  (SgN  >õhtune !12~10_A	et	f	\N
142188	õhtune	"õhtune %õhtu  )NE_aA  <õhtu ;01_S	et	f	\N
142189	seletus	seletus =seletu  (IndIpfSg3  >seletuma !27_V	et	f	\N
142190	seletus	seletus =seletus  (SgN  >seletus !11_S	et	f	\N
142191	seletus	"seletus %seleta  )US_vS  <seletama ;27_V	et	f	\N
142195	kinnitust	kinnitust =kinnitus  (SgP  >kinnitus !11_S	et	f	\N
142196	kinnitust	"kinnitus %kinnita  )US_vS  <kinnitama ;27_V	et	f	\N
142197	kinnitust	kinnitust =tust  (SgN  >kinni+tust !22_S	et	f	\N
142199	õnnetust	õnnetust =õnnetu  (SgEl  >õnnetu !01_A	et	f	\N
142200	õnnetust	"õnnetu %õnne  )TU2_kA  <õnn ;22_S	et	f	\N
142201	õnnetust	õnnetust =õnnetus  (SgP  >õnnetus !11_S	et	f	\N
142202	õnnetust	"õnnetus %õnne  )TUS2_aS  <õnn ;22_S	et	f	\N
142203	õnnetust	õnnetust =tust  (SgN  >õnne+tust !22_S	et	f	\N
142219	vitebski	?vitebski =vitebski  (SgG  >vitebsk !02_S	et	f	\N
142220	vitebski	?vitebski =vitebski  (IndPrPs_  >vitebskima !28_V	et	f	\N
142221	vitebski	?vitebski =vitebski  (ImpPrSg2  >vitebskima !28_V	et	f	\N
142222	vitebski	?vitebski =vitebs  (SgN^  >vitebs !22_S	et	f	\N
142239	keles	?keles =kele  (SgIn  >kele !16_S	et	f	\N
142240	keles	?keles =kele  (IndIpfSg3  >kelema !27_V	et	f	\N
142241	keles	?keles =keles  (SgN  >keles !09_S	et	f	\N
142260	võtmisel	võtmisel =võtmise  (SgAd  >võtmine !12?10_S	et	f	\N
142262	võtmisel	"võtmine %võt  )MINE_vS  <võtma ;35_V	et	f	\N
142266	teadusringlusesse	teadusringlusesse =ringluse  (SgIll  >teadus+ringlus !11~09_S	et	f	\N
142267	teadusringlusesse	"teadus+ringlus %ringlase  )US_aS  <teadus+ringlane ;12_S	et	f	\N
142268	teadusringlusesse	teadusringlusesse =ringluses  (SgAdt  >teadus+ringlusene !12_A	et	f	\N
142269	teadusringlusesse	"teadus+ringlusene %ringluse  )NE_aA  <teadus+ringlus ;09_S	et	f	\N
142270	teadusringlusesse	"teadus+ringlusene %ringluse  )NE_aA  <teadus+ringlus ;11_S	et	f	\N
142290	sisukas	sisukas =sisuka  (SgIn  >sisukas !02_A	et	f	\N
142291	sisukas	sisukas =sisukas  (SgN  >sisukas !02_A	et	f	\N
142311	ringtansulaulude	### ringtansulaulude	et	f	\N
142318	kaugema	kaugema =kaugema  (SgG  >kaugem !02_A	et	f	\N
142319	kaugema	"kaugem %kauge  )M_cA  <kauge ;01_A	et	f	\N
142320	kaugema	kaugema =ema  (SgN  >kaug+ema !17_S	et	f	\N
142321	kaugema	kaugema =ema  (SgG  >kaug+ema !17_S	et	f	\N
142322	kaugema	kaugema =ema  (SgP  >kaug+ema !17_S	et	f	\N
142330	kogumise	kogumise =kogumise  (SgG  >kogumine !12_S	et	f	\N
142331	kogumise	"kogumine %kogu  )MINE_vS  <koguma ;27_V	et	f	\N
142332	kogumise	"kogumine %kogumi  )NE_aA  <kogum ;02_S	et	f	\N
142338	konjaev	?konjaev =konjaev  (SgN  >konjaev !22_S	et	f	\N
142341	jogener	?jogener =jogener  (SgN  >jogener !19_S	et	f	\N
142347	külgi	külgi =külgi  (SgP  >külg !22_S	et	f	\N
142348	külgi	külgi =külgi  (SgAdt  >külg !22_S	et	f	\N
142349	külgi	külgi =külgi  (PlP  >külg !22_S	et	f	\N
142360	pahhutinaga	### pahhutinaga	et	f	\N
142372	pärliks	pärliks =pärli  (SgTr  >pärl !02_S	et	f	\N
142373	pärliks	pärliks =iks  (SgN  >pärl+iks !22_S	et	f	\N
142395	uurimisel	uurimisel =uurimise  (SgAd  >uurimine !12_S	et	f	\N
142396	uurimisel	"uurimine %uuri  )MINE_vS  <uurima ;28_V	et	f	\N
142397	folklooripraktika	folklooripraktika =praktika  (SgN  >folkloori+praktika !01_S	et	f	\N
142398	folklooripraktika	folklooripraktika =praktika  (SgG  >folkloori+praktika !01_S	et	f	\N
142419	peipsimaale	peipsimaale =maa  (SgAll  >peipsi+maa !26_S	et	f	\N
142420	peipsimaale	peipsimaale =maale  (PlP  >peipsi+maal !22_S	et	f	\N
142442	traditsiooniline	traditsiooniline =traditsiooniline  (SgN  >traditsiooniline !12_A	et	f	\N
142443	traditsiooniline	"traditsiooniline %traditsiooni  )LINE_aA  <traditsioon ;22_S	et	f	\N
142472	teemade	teemade =teema  (PlG  >teema !16_S	et	f	\N
142473	teemade	teemade =made  (SgN  >tee+made !04_S	et	f	\N
142194	veenvam	"veenvam %veenva  )M_cA  <veenev ;02_A	et	f	\N
142216	esiasukatel	esiasukatel =kate  (PlAd  >esi+asu+katt !22_S	et	f	\N
142217	esiasukatel	esiasukatel =katel  (SgN  >esi+asu+katel !08_S	et	f	\N
142218	esiasukatel	esiasukatel =asuka  (PlAd  >esi+asukas !02_S	et	f	\N
142231	ravitsejana	ravitsejana =ravitseja  (SgEs  >ravitseja !01_S	et	f	\N
142232	ravitsejana	"ravitseja %ravitse  )JA_vS  <ravitsema ;27_V	et	f	\N
142276	illustratiivmaterjalina	?illustratiivmaterjalina =illustratiivmaterjali  (SgEs  >illustratiivmaterjal !02_S	et	f	\N
142277	illustratiivmaterjalina	?illustratiivmaterjalina =illustratiivmaterjalina  (SgG  >illustratiivmaterjalin !19_S	et	f	\N
142278	illustratiivmaterjalina	?illustratiivmaterjalina =illustratiivmaterjalina  (SgP  >illustratiivmaterjalin !19_S	et	f	\N
142279	illustratiivmaterjalina	?illustratiivmaterjalina =illustratiivmaterjalina  (SgAdt  >illustratiivmaterjalin !19_S	et	f	\N
142280	tähtsaimaks	tähtsaimaks =tähtsaima  (SgTr  >tähtsaim !02_A	et	f	\N
142281	tähtsaimaks	"tähtsaim %tähtsa  )IM_sA  <tähtis ;02_A	et	f	\N
142282	tähtsaimaks	tähtsaimaks =maks  (SgN  >täht+sai+maks !22_S	et	f	\N
142288	vanausulistelt	vanausulistelt =usulis  (PlAbl  >vana+usuline !12_A	et	f	\N
142289	vanausulistelt	"vana+usuline %usu  )LINE_aA  <vana+usk ;22_S	et	f	\N
142295	korvata	korvata =korva  (Inf  >korvama !29_V	et	f	\N
142296	korvata	korvata =korva  (IndPrIps_  >korvama !29_V	et	f	\N
142333	kronoloogilist	kronoloogilist =kronoloogilis  (SgP  >kronoloogiline !12_A	et	f	\N
142334	kronoloogilist	kronoloogilist =loogilis  (SgP  >krono+loogiline !12_A	et	f	\N
142335	kronoloogilist	"krono+loogiline %loogi  )LINE_aA  <krono+loog ;22_S	et	f	\N
142342	brandt	?brandt =brandt  (SgN  >brandt !22_S	et	f	\N
142344	folklooritraditsiooni	folklooritraditsiooni =traditsiooni  (SgG  >folkloori+traditsioon !22_S	et	f	\N
142345	folklooritraditsiooni	folklooritraditsiooni =traditsiooni  (SgP  >folkloori+traditsioon !22_S	et	f	\N
142346	folklooritraditsiooni	folklooritraditsiooni =traditsiooni  (SgAdt  >folkloori+traditsioon !22_S	et	f	\N
142350	väärivad	väärivad =vääri  (IndPrPl3  >väärima !28_V	et	f	\N
142351	väärivad	väärivad =vääriva  (PlN  >vääriv !02_A	et	f	\N
142352	väärivad	"vääriv %vääri  )V_vA  <väärima ;28_V	et	f	\N
142353	väärivad	väärivad =iva  (PlN  >väär+iva !17_S	et	f	\N
142380	küsitlesid	küsitlesid =küsitle  (IndIpfSg2  >küsitlema !27_V	et	f	\N
142381	küsitlesid	küsitlesid =küsitle  (IndIpfPl3  >küsitlema !27_V	et	f	\N
142403	kogumistöö	kogumistöö =töö  (SgN  >kogu+mis+töö !26_S	et	f	\N
142404	kogumistöö	kogumistöö =töö  (SgG  >kogu+mis+töö !26_S	et	f	\N
142410	koguduste	koguduste =kogudus  (PlG  >kogudus !11_S	et	f	\N
142411	koguduste	koguduste =duste  (PlP  >kogu+dust !22_S	et	f	\N
142444	õnnistusrikkaks	?õnnistusrikkaks =õnnistusrikka  (SgTr  >õnnistusrikka !16_S	et	f	\N
142445	õnnistusrikkaks	?õnnistusrikkaks =tusrikka  (SgTr  >õnnis+tusrikka !01_S	et	f	\N
142484	peatükki	peatükki =tükki  (SgP  >pea+tükk !22_S	et	f	\N
142485	peatükki	peatükki =tükki  (SgAdt  >pea+tükk !22_S	et	f	\N
142501	ümbertrükitud	ümbertrükitud =trüki  (PtsPtIps  >ümber+_trükkima !28_V	et	f	\N
142502	ümbertrükitud	ümbertrükitud =trükitu  (PlN  >ümber+trükitu !01_AS	et	f	\N
142503	ümbertrükitud	"ümber+trükitu %trüki  )TU2_kA  <ümber+trükk ;22_S	et	f	\N
142519	sõna-	sõna- =sõna  (SgN  >sõna !17_S	et	f	\N
142520	sõna-	sõna- =sõna  (SgG  >sõna !17_S	et	f	\N
142521	sõna-	sõna- =sõna  (SgP  >sõna !17_S	et	f	\N
142522	sõna-	sõna- =sõna  (IndPrPs_  >sõnama !27_V	et	f	\N
142524	sõna-	sõna- =sõna  (ImpPrSg2  >sõnama !27_V	et	f	\N
142545	publitseerimisel	publitseerimisel =publitseerimise  (SgAd  >publitseerimine !12_S	et	f	\N
142546	publitseerimisel	"publitseerimine %publitseeri  )MINE_vS  <publitseerima ;28_V	et	f	\N
142551	kirjamärke	kirjamärke =märke  (SgG  >kirja+märge !06_S	et	f	\N
142554	kirjamärke	kirjamärke =märke  (PlP  >kirja+märk !22_S	et	f	\N
142569	tähistavaid	tähistavaid =tähistava  (PlP  >tähistav !02_A	et	f	\N
142570	tähistavaid	"tähistav %tähista  )V_vA  <tähistama ;27_V	et	f	\N
142602	meetrikates	meetrikates =meetrika  (PlIn  >meetrika !01_S	et	f	\N
142603	meetrikates	meetrikates =kate  (PlIn  >meetri+katt !22_S	et	f	\N
142620	zoja	?zoja =zoja  (SgN  >zoja !17_S	et	f	\N
142621	zoja	?zoja =zoja  (SgG  >zoja !17_S	et	f	\N
142622	zoja	?zoja =zoja  (SgP  >zoja !17_S	et	f	\N
142623	zoja	?zoja =zoja  (IndPrPs_  >zojama !27_V	et	f	\N
142624	zoja	?zoja =zoja  (ImpPrSg2  >zojama !27_V	et	f	\N
142628	kereketkinat	### kereketkinat	et	f	\N
142637	projektijuhte	projektijuhte =juhte  (SgG  >projekti+juhe !06_S	et	f	\N
142638	projektijuhte	projektijuhte =juhte  (PlP  >projekti+juht !22_S	et	f	\N
142659	omakasupüüdmatu	omakasupüüdmatu =püüdmatu  (SgN  >oma+kasu+püüdmatu !01_A	et	f	\N
142660	omakasupüüdmatu	omakasupüüdmatu =püüdmatu  (SgG  >oma+kasu+püüdmatu !01_A	et	f	\N
142729	analüüsitud	analüüsitud =analüüsi  (PtsPtIps  >analüüsima !28_V	et	f	\N
142730	analüüsitud	analüüsitud =analüüsitu  (PlN  >analüüsitu !01_A	et	f	\N
142731	analüüsitud	"analüüsitu %analüüsi  )TU1_vS  <analüüsima ;28_V	et	f	\N
142732	analüüsitud	"analüüsitu %analüüsi  )TU2_kA  <analüüs ;22_S	et	f	\N
142733	analüüsitud	analüüsitud =analüüsitud  (ID  >analüüsitud !41_A	et	f	\N
142734	analüüsitud	"analüüsitud %analüüsi  )TUD_vA  <analüüsima ;28_V	et	f	\N
142248	kontekstuaalne	?kontekstuaalne =tuaalne  (PlP  >kont+eks+tuaaln !22_S	et	f	\N
142250	kontekstuaalne	?kontekstuaalne =ekstuaalne  (SgN  >kont+ekstuaalne !02_A	et	f	\N
142252	kontekstuaalne	?kontekstuaalne =ekstuaalne  (PlP  >kont+ekstuaaln !22_S	et	f	\N
142256	nappus	nappus =nappus  (SgN  >nappus !11~09_S	et	f	\N
142257	nappus	"nappus %napp  )US_aS  <napp ;22_A	et	f	\N
142271	üksikuid	üksikuid =üksiku  (PlP  >üksik !02_A	et	f	\N
142272	üksikuid	üksikuid =ui  (PlN  >üksik+ui !26_S	et	f	\N
142273	üksikuid	üksikuid =ui  (SgP  >üksik+ui !26_S	et	f	\N
142274	üksikuid	üksikuid =uid  (SgN  >üksik+uid !22_S	et	f	\N
142275	üksikuid	üksikuid =ku  (PlP  >üksi+kuu !26_S	et	f	\N
142283	tõsiseks	tõsiseks =tõsise  (SgTr  >tõsine !10_A	et	f	\N
142284	tõsiseks	"tõsine %tõsi  )NE_aA  <tõsi ;15_S	et	f	\N
142285	tõsiseks	tõsiseks =seks  (SgN  >tõsi+seks !22_S	et	f	\N
142292	katse	katse =katse  (SgN  >katse !06_S	et	f	\N
142293	katse	katse =katse  (SgG  >katse !06_S	et	f	\N
142294	katse	katse =katse  (PlP  >kats !22_S	et	f	\N
142304	pärimuste	pärimuste =pärimus  (PlG  >pärimus !11_S	et	f	\N
142305	pärimuste	"pärimus %päri  )MUS_vS  <pärima ;27_V	et	f	\N
142306	pärimuste	pärimuste =muste  (PlP  >päri+must !22_AS	et	f	\N
142313	mittetavandilaulude	### mittetavandilaulude	et	f	\N
142323	kogujaid	kogujaid =koguja  (PlP  >koguja !01_S	et	f	\N
142324	kogujaid	"koguja %kogu  )JA_vS  <koguma ;27_V	et	f	\N
142357	gildebrandti	?gildebrandti =gildebrandti  (IndPrPs_  >gildebrandtima !28_V	et	f	\N
142359	gildebrandti	?gildebrandti =gildebrandti  (ImpPrSg2  >gildebrandtima !28_V	et	f	\N
142364	uskumusi	uskumusi =uskumusi  (PlP  >uskumus !11_S	et	f	\N
142365	uskumusi	uskumusi =musi  (SgN  >usku+musi !17_S	et	f	\N
142366	uskumusi	uskumusi =musi  (SgG  >usku+musi !17_S	et	f	\N
142367	uskumusi	uskumusi =musi  (SgP  >usku+musi !17_S	et	f	\N
142374	aasatal	?aasatal =aasatal  (SgN  >aasatal !19_S	et	f	\N
142375	aasatal	?aasatal =atal  (SgN  >aas+atal !02_S	et	f	\N
142382	kirjalikult	kirjalikult =kirjaliku  (SgAbl  >kirjalik !25_A	et	f	\N
142383	kirjalikult	kirjalikult =kirjalikult  (ID  >kirjalikult !41_D	et	f	\N
142384	kirjalikult	"kirjalikult %kirjaliku  )LT_mD  <kirjalik ;25_A	et	f	\N
142387	teaduslikku	teaduslikku =teaduslikku  (SgP  >teaduslik !25_A	et	f	\N
142393	teaduslikku	teaduslikku =teaduslikku  (SgAdt  >teaduslik !25_A	et	f	\N
142435	elusast	elusast =elusa  (SgEl  >elus !02_A	et	f	\N
142436	elusast	elusast =ast  (SgN  >elus+ast !22_S	et	f	\N
142440	kokkuvõtlikult	kokkuvõtlikult =võtliku  (SgAbl  >kokku+võtlik !25_A	et	f	\N
142441	kokkuvõtlikult	"kokku+võtlikult %võtliku  )LT_mD  <kokku+võtlik ;25_A	et	f	\N
142470	traditsioonilisest	traditsioonilisest =traditsioonilise  (SgEl  >traditsiooniline !12_A	et	f	\N
142471	traditsioonilisest	"traditsiooniline %traditsiooni  )LINE_aA  <traditsioon ;22_S	et	f	\N
142515	murdekeelele	murdekeelele =keele  (SgAll  >murde+keel !13_S	et	f	\N
142516	murdekeelele	murdekeelele =keele  (PlAll  >murde+keeld !22_S	et	f	\N
142539	oneetilisest	?oneetilisest =oneetilise  (SgEl  >oneetiline !12_A	et	f	\N
142556	parandanud	parandanud =paranda  (PtsPtPs  >parandama !27_V	et	f	\N
142557	parandanud	parandanud =parandanu  (PlN  >parandanu !01_S	et	f	\N
142561	parandanud	"parandanu %paranda  )NU_vS  <parandama ;27_V	et	f	\N
142563	parandanud	parandanud =parandanud  (ID  >parandanud !41_A	et	f	\N
142565	parandanud	"parandanud %paranda  )NUD_vA  <parandama ;27_V	et	f	\N
142576	markeeritud	markeeritud =markeeri  (PtsPtIps  >markeerima !28_V	et	f	\N
142577	markeeritud	markeeritud =markeeritu  (PlN  >markeeritu !01_S	et	f	\N
142578	markeeritud	"markeeritu %markeeri  )TU1_vS  <markeerima ;28_V	et	f	\N
142579	markeeritud	markeeritud =markeeritud  (ID  >markeeritud !41_A	et	f	\N
142580	markeeritud	"markeeritud %markeeri  )TUD_vA  <markeerima ;28_V	et	f	\N
142611	juhte	juhte =juhte  (SgG  >juhe !06_S	et	f	\N
142613	juhte	juhte =juhte  (PlP  >juht !22_S	et	f	\N
142631	raissa	?raissa =raissa  (SgN  >raissa !01_S	et	f	\N
142632	raissa	?raissa =raissa  (SgG  >raissa !01_S	et	f	\N
142635	raissa	?raissa =raissa  (IndPrPs_  >raissama !29_V	et	f	\N
142636	raissa	?raissa =raissa  (ImpPrSg2  >raissama !29_V	et	f	\N
142639	varuninit	?varuninit =ninit  (SgN  >varu+ninit !02_S	et	f	\N
142642	korraldustöö	korraldustöö =töö  (SgN  >korraldus+töö !26_S	et	f	\N
142643	korraldustöö	korraldustöö =töö  (SgG  >korraldus+töö !26_S	et	f	\N
142663	tseetamisest	?tseetamisest =tseetamise  (SgEl  >tseetamine !12_S	et	f	\N
142672	külitlusel	?külitlusel =külitluse  (SgAd  >külitlus !11_S	et	f	\N
142673	peegelduste	peegelduste =peegeldus  (PlG  >peegeldus !11_S	et	f	\N
142674	peegelduste	"peegeldus %peegelda  )US_vS  <peegeldama ;27_V	et	f	\N
142675	peegelduste	peegelduste =duste  (PlP  >peegel+dust !22_S	et	f	\N
142685	päritolumaa	päritolumaa =maa  (SgN  >pärit+olu+maa !26_S	et	f	\N
142686	päritolumaa	päritolumaa =maa  (SgG  >pärit+olu+maa !26_S	et	f	\N
142687	kasahstan	?kasahstan =kasahsta  (IndPrSg1  >kasahstama !27_V	et	f	\N
142688	kasahstan	?kasahstan =kasahstan  (SgN  >kasahstan !02_S	et	f	\N
142689	kasahstan	?kasahstan =ahstan  (SgN  >kas+ahstan !02_S	et	f	\N
142690	alguspoole	alguspoole =poole  (SgN  >algus+poole !05_S	et	f	\N
142414	varunini	?varunini =varunini  (SgP  >varunin !19_S	et	f	\N
142415	varunini	?varunini =varunini  (SgAdt  >varunin !19_S	et	f	\N
142416	varunini	?varunini =nini  (SgN  >varu+nini !17_S	et	f	\N
142417	varunini	?varunini =nini  (SgG  >varu+nini !17_S	et	f	\N
142418	varunini	?varunini =nini  (SgP  >varu+nini !17_S	et	f	\N
142424	eelistuste	eelistuste =eelistus  (PlG  >eelistus !11_S	et	f	\N
142425	eelistuste	"eelistus %eelista  )US_vS  <eelistama ;27_V	et	f	\N
142426	eelistuste	eelistuste =tuste  (PlP  >eelis+tust !22_S	et	f	\N
142437	käibivusest	käibivusest =käibivuse  (SgEl  >käibivus !11_S	et	f	\N
142438	käibivusest	"käibivus %käibi  )VUS_aS  <käibima ;27_V	et	f	\N
142439	käibivusest	"käibivus %käibiva  )US_aS  <käibiv ;02_A	et	f	\N
142446	oostajatelt	?oostajatelt =oostaja  (PlAbl  >oostaja !01_S	et	f	\N
142447	oostajatelt	?oostajatelt =oostaja  (PlAbl  >oostajas !02_A	et	f	\N
142448	oostajatelt	?oostajatelt =oostajate  (PlAbl  >oostajatt !22_S	et	f	\N
142449	oostajatelt	?oostajatelt =oostajatelt  (ID  >oostajatelt !41_D	et	f	\N
142450	kronoloogilisest	kronoloogilisest =kronoloogilise  (SgEl  >kronoloogiline !12_A	et	f	\N
142451	kronoloogilisest	kronoloogilisest =loogilise  (SgEl  >krono+loogiline !12_A	et	f	\N
142452	kronoloogilisest	"krono+loogiline %loogi  )LINE_aA  <krono+loog ;22_S	et	f	\N
142467	teadlikult	teadlikult =teadliku  (SgAbl  >teadlik !25_A	et	f	\N
142468	teadlikult	teadlikult =teadlikult  (ID  >teadlikult !41_D	et	f	\N
142469	teadlikult	"teadlikult %teadliku  )LT_mD  <teadlik ;25_A	et	f	\N
142486	liigendumatus	liigendumatus =liigendumatu  (SgIn  >liigendumatu !01_A	et	f	\N
142487	liigendumatus	"liigendumatu %liigendu  )MATU_vA  <liigenduma ;27_V	et	f	\N
142488	liigendumatus	liigendumatus =liigendumatus  (SgN  >liigendumatus !11?09_S	et	f	\N
142490	liigendumatus	"liigendumatus %liigendu  )MATUS_aS  <liigenduma ;27_V	et	f	\N
142492	terviklikkust	terviklikkust =terviklikkus  (SgP  >terviklikkus !11~09_S	et	f	\N
142493	terviklikkust	"terviklikkus %terviklikku  )US_aS  <terviklik ;25_A	et	f	\N
142510	säilitatud	säilitatud =säilita  (PtsPtIps  >säilitama !27_V	et	f	\N
142511	säilitatud	säilitatud =säilitatu  (PlN  >säilitatu !01_S	et	f	\N
142512	säilitatud	"säilitatu %säilita  )TU1_vS  <säilitama ;27_V	et	f	\N
142513	säilitatud	säilitatud =säilitatud  (ID  >säilitatud !41_A	et	f	\N
142514	säilitatud	"säilitatud %säilita  )TUD_vA  <säilitama ;27_V	et	f	\N
142517	leksikaline	leksikaline =leksikaline  (SgN  >leksikaline !12_A	et	f	\N
142518	leksikaline	"leksikaline %leksika  )LINE_aA  <leksika ;01_S	et	f	\N
142523	lausemoodustuslik	?lausemoodustuslik =lausemoodustuslik  (SgN  >lausemoodustuslik !25_A	et	f	\N
142525	lausemoodustuslik	?lausemoodustuslik =moodustuslik  (SgN  >lause+moodustuslik !25_A	et	f	\N
142526	lausemoodustuslik	?lausemoodustuslik =emoodustuslik  (SgN  >laus+emoodustuslik !25_A	et	f	\N
142527	lausemoodustuslik	?lausemoodustuslik =semoodustuslik  (SgN  >lau+semoodustuslik !25_A	et	f	\N
142531	mittenormikohane	?mittenormikohane =mittenormikohane  (SgN  >mittenormikohane !12_A	et	f	\N
142532	mittenormikohane	?mittenormikohane =mittenormikohane  (PlP  >mittenormikohan !19_S	et	f	\N
142533	mittenormikohane	?mittenormikohane =ikohane  (SgN  >mitte+norm+ikohane !12_A	et	f	\N
142534	mittenormikohane	?mittenormikohane =ikohane  (PlP  >mitte+norm+ikohan !19_S	et	f	\N
142535	mittenormikohane	?mittenormikohane =normikohane  (SgN  >mitte+normikohane !12_A	et	f	\N
142536	mittenormikohane	?mittenormikohane =normikohane  (PlP  >mitte+normikohan !19_S	et	f	\N
142540	loobunud	loobunud =loobu  (PtsPtPs  >loobuma !27_V	et	f	\N
142541	loobunud	loobunud =loobunu  (PlN  >loobunu !01_S	et	f	\N
142542	loobunud	"loobunu %loobu  )NU_vS  <loobuma ;27_V	et	f	\N
142543	loobunud	loobunud =loobunud  (ID  >loobunud !41_A	et	f	\N
142544	loobunud	"loobunud %loobu  )NUD_vA  <loobuma ;27_V	et	f	\N
142548	puuduvaid	puuduvaid =puuduva  (PlP  >puuduv !02_A	et	f	\N
142552	puuduvaid	"puuduv %puudu  )V_vA  <puuduma ;27_V	et	f	\N
142573	tseetamise	?tseetamise =tseetamise  (SgG  >tseetamine !12_S	et	f	\N
142586	kommentarid	?kommentarid =kommentari  (PlN  >kommentar !19_S	et	f	\N
142587	kommentarid	?kommentarid =mentari  (PlN  >kom+mentari !01_S	et	f	\N
142588	kommentarid	?kommentarid =mentari  (PlN  >kom+mentar !02_S	et	f	\N
142589	kursiivkirjas	?kursiivkirjas =kursiivkirja  (SgIn  >kursiivkirjas !02_A	et	f	\N
142590	kursiivkirjas	?kursiivkirjas =kursiivkirja  (SgIn  >kursiivkirja !16_S	et	f	\N
142591	kursiivkirjas	?kursiivkirjas =kursiivkirjas  (SgN  >kursiivkirjas !02_A	et	f	\N
142592	kursiivkirjas	?kursiivkirjas =ivkirja  (SgIn  >kursi+ivkirjas !02_A	et	f	\N
142593	kursiivkirjas	?kursiivkirjas =ivkirja  (SgIn  >kursi+ivkirja !16_S	et	f	\N
142594	kursiivkirjas	?kursiivkirjas =ivkirjas  (SgN  >kursi+ivkirjas !02_A	et	f	\N
142595	seletuseta	seletuseta =seletuse  (SgAb  >seletus !11_S	et	f	\N
142596	seletuseta	"seletus %seleta  )US_vS  <seletama ;27_V	et	f	\N
142604	koostajatel	koostajatel =koostaja  (PlAd  >koostaja !01_S	et	f	\N
142605	koostajatel	"koostaja %koosta  )JA_vS  <koostama ;27_V	et	f	\N
142606	vanauusliste	?vanauusliste =vanauuslis  (PlG  >vanauuslis !09_S	et	f	\N
142607	vanauusliste	?vanauusliste =vanauuslis  (PlG  >vanauusline !12_A	et	f	\N
142608	vanauusliste	?vanauusliste =vanauusliste  (PlP  >vanauuslist !22_S	et	f	\N
142609	vanauusliste	?vanauusliste =liste  (SgN  >vana+uus+liste !06_S	et	f	\N
142610	vanauusliste	?vanauusliste =liste  (SgG  >vana+uus+liste !06_S	et	f	\N
142455	ekspeditisiooni	?ekspeditisiooni =ekspeditisiooni  (SgG  >ekspeditisiooni !16_S	et	f	\N
142456	ekspeditisiooni	?ekspeditisiooni =ekspeditisiooni  (SgG  >ekspeditisioon !22_S	et	f	\N
142457	ekspeditisiooni	?ekspeditisiooni =ekspeditisiooni  (SgP  >ekspeditisioon !22_S	et	f	\N
142458	ekspeditisiooni	?ekspeditisiooni =ekspeditisiooni  (SgAdt  >ekspeditisioon !22_S	et	f	\N
142459	ekspeditisiooni	?ekspeditisiooni =ekspeditisiooni  (IndPrPs_  >ekspeditisioonima !28_V	et	f	\N
142460	ekspeditisiooni	?ekspeditisiooni =ekspeditisiooni  (ImpPrSg2  >ekspeditisioonima !28_V	et	f	\N
142461	ekspeditisiooni	?ekspeditisiooni =peditisioo  (SgTer  >eks+peditisioo !26_S	et	f	\N
142462	ekspeditisiooni	?ekspeditisiooni =peditisiooni  (SgN  >eks+peditisiooni !16_S	et	f	\N
142463	ekspeditisiooni	?ekspeditisiooni =peditisiooni  (SgG  >eks+peditisiooni !16_S	et	f	\N
142464	ekspeditisiooni	?ekspeditisiooni =peditisiooni  (SgG  >eks+peditisioon !22_S	et	f	\N
142465	ekspeditisiooni	?ekspeditisiooni =peditisiooni  (SgP  >eks+peditisioon !22_S	et	f	\N
142466	ekspeditisiooni	?ekspeditisiooni =peditisiooni  (SgAdt  >eks+peditisioon !22_S	et	f	\N
142474	peegeldavad	peegeldavad =peegelda  (IndPrPl3  >peegeldama !27_V	et	f	\N
142475	peegeldavad	peegeldavad =peegeldava  (PlN  >peegeldav !02_A	et	f	\N
142476	peegeldavad	"peegeldav %peegelda  )V_vA  <peegeldama ;27_V	et	f	\N
142494	elujõulisust	elujõulisust =jõulisus  (SgP  >elu+jõulisus !11_S	et	f	\N
142495	elujõulisust	"elu+jõulisus %jõu  )LISUS_aS  <elu+jõud ;22_S	et	f	\N
142496	elujõulisust	"elu+jõulisus %jõuli  )SUS_aS  <elu+jõul ;22_S	et	f	\N
142497	kogumikes	kogumikes =kogumike  (PlIn  >kogumik !25_S	et	f	\N
142498	kogumikes	kogumikes =mike  (PlIn  >kogu+mikk !22_S	et	f	\N
142504	romanova	?romanova =romanova  (SgN  >romanova !16_S	et	f	\N
142505	romanova	?romanova =romanova  (SgG  >romanov !02_A	et	f	\N
142506	romanova	?romanova =romanova  (SgG  >romanova !16_S	et	f	\N
142528	äramärgitud	äramärgitud =märgi  (PtsPtIps  >ära+_märkima !28_V	et	f	\N
142529	äramärgitud	äramärgitud =märgitu  (PlN  >ära+märgitu !01_AS	et	f	\N
142530	äramärgitud	"ära+märgitu %märgi  )TU2_kA  <ära+märk ;22_S	et	f	\N
142537	kirjakeeles	kirjakeeles =keele  (SgIn  >kirja+keel !13_S	et	f	\N
142538	kirjakeeles	kirjakeeles =keele  (PlIn  >kirja+keeld !22_S	et	f	\N
142574	murdekeeles	murdekeeles =keele  (SgIn  >murde+keel !13_S	et	f	\N
142575	murdekeeles	murdekeeles =keele  (PlIn  >murde+keeld !22_S	et	f	\N
142584	täpsustused	täpsustused =täpsustuse  (PlN  >täpsustus !11_S	et	f	\N
142585	täpsustused	"täpsustus %täpsusta  )US_vS  <täpsustama ;27_V	et	f	\N
142597	enned	?enned =enne  (IndPrSg2  >ennema !27_V	et	f	\N
142629	tihhomirovat	?tihhomirovat =tihhomirova  (SgP  >tihhomirov !02_A	et	f	\N
142630	tihhomirovat	?tihhomirovat =tihhomirova  (SgP  >tihhomirova !16_S	et	f	\N
142646	rovnovat	?rovnovat =rovnova  (SgP  >rovnova !01_S	et	f	\N
142647	rovnovat	?rovnovat =rovnova  (SgP  >rovnov !02_A	et	f	\N
142664	ää	?ää =ää  (SgN  >ää !26_S	et	f	\N
142665	ää	?ää =ää  (SgG  >ää !26_S	et	f	\N
142666	una	?una =una  (SgN  >una !17_S	et	f	\N
142667	una	?una =una  (SgG  >una !17_S	et	f	\N
142668	una	?una =una  (SgP  >una !17_S	et	f	\N
142669	una	?una =una  (IndPrPs_  >unama !27_V	et	f	\N
142670	una	?una =una  (ImpPrSg2  >unama !27_V	et	f	\N
142671	informantide	?informantide =informanti  (PlG  >informant !22_S	et	f	\N
142677	lukjanenko	?lukjanenko =lukjanenko  (SgN  >lukjanenko !16_S	et	f	\N
142679	lukjanenko	?lukjanenko =lukjanenko  (SgG  >lukjanenko !16_S	et	f	\N
142683	küberpunk	?küberpunk =küberpunk  (SgN  >küberpunk !22_S	et	f	\N
142684	küberpunk	?küberpunk =punk  (SgN  >küber+punk !22_S	et	f	\N
142695	90date	?date =date  (SgN  >date !06_S	et	f	\N
142696	90date	?date =date  (IndPrPs_  >datema !27_V	et	f	\N
142697	90date	?date =date  (ImpPrSg2  >datema !27_V	et	f	\N
142707	ettemääratus	ettemääratus =määratu  (SgIn  >ette+määratu !01_AS	et	f	\N
142708	ettemääratus	"ette+määratu %määra  )TU2_kA  <ette+määr ;22_S	et	f	\N
142709	ettemääratus	ettemääratus =määratus  (SgN  >ette+määratus !11_S	et	f	\N
142710	ettemääratus	"ette+määratus %määra  )TUS2_aS  <ette+määr ;22_S	et	f	\N
142714	tetraloogia	tetraloogia =tetraloogia  (SgN  >tetraloogia !01_S	et	f	\N
142715	tetraloogia	tetraloogia =tetraloogia  (SgG  >tetraloogia !01_S	et	f	\N
142724	lähituleviku	lähituleviku =viku  (SgG  >lähi+tule+vikk !22_S	et	f	\N
142725	lähituleviku	lähituleviku =tuleviku  (SgG  >lähi+tulevik !25_S	et	f	\N
142767	sissetungi	sissetungi =tungi  (SgG  >sisse+tung !22_S	et	f	\N
142768	sissetungi	sissetungi =tungi  (SgP  >sisse+tung !22_S	et	f	\N
142769	sissetungi	sissetungi =tungi  (SgAdt  >sisse+tung !22_S	et	f	\N
142770	sissetungi	sissetungi =tungi  (PlP  >sisse+tung !22_S	et	f	\N
142774	avane	avane =avane  (SgN  >avane !10_A	et	f	\N
142775	avane	"avane %ava  )NE_aA  <ava ;17_S	et	f	\N
142776	avane	avane =avane  (IndPrPs_  >avanema !27_V	et	f	\N
142777	avane	avane =avane  (ImpPrSg2  >avanema !27_V	et	f	\N
142778	ootamatud	ootamatud =ootamatu  (PlN  >ootamatu !01_A	et	f	\N
142779	ootamatud	"ootamatu %oota  )MATU_vA  <ootama ;29_V	et	f	\N
142794	stilistilist	stilistilist =stilistilis  (SgP  >stilistiline !12_A	et	f	\N
142795	stilistilist	"stilistiline %stilisti  )LINE_aA  <stilist ;22_S	et	f	\N
142477	jaotamine	jaotamine =jaotamine  (SgN  >jaotamine !12_S	et	f	\N
142478	jaotamine	"jaotamine %jaota  )MINE_vS  <jaotama ;27_V	et	f	\N
142479	mitsesse	?mitsesse =mitse  (SgIll  >mitne !02_A	et	f	\N
142480	mitsesse	?mitsesse =mitse  (SgIll  >mitse !06_S	et	f	\N
142481	mitsesse	?mitsesse =mitse  (PlIll  >mits !22_S	et	f	\N
142482	mitsesse	?mitsesse =mitsesse  (SgG  >mitsesne !02_A	et	f	\N
142483	mitsesse	?mitsesse =mitsesse  (PlP  >mitsess !22_S	et	f	\N
142489	polüfunktsionaalsus	?polüfunktsionaalsus =polüfunktsionaalsu  (IndIpfSg3  >polüfunktsionaalsuma !27_V	et	f	\N
142491	polüfunktsionaalsus	?polüfunktsionaalsus =polüfunktsionaalsus  (SgN  >polüfunktsionaalsus !11~09_S	et	f	\N
142499	koostajate	koostajate =koostaja  (PlG  >koostaja !01_S	et	f	\N
142500	koostajate	"koostaja %koosta  )JA_vS  <koostama ;27_V	et	f	\N
142507	toimetamata	toimetamata =toimeta  (SupAb  >toimetama !27_V	et	f	\N
142508	toimetamata	toimetamata =toimetamata  (ID  >toimetamata !41_A	et	f	\N
142509	toimetamata	"toimetamata %toimeta  )MATA_vA  <toimetama ;27_V	et	f	\N
142547	lisanud	lisanud =lisa  (PtsPtPs  >lisama !27_V	et	f	\N
142549	lisanud	lisanud =lisanu  (PlN  >lisanu !01_S	et	f	\N
142550	lisanud	"lisanu %lisa  )NU_vS  <lisama ;27_V	et	f	\N
142553	lisanud	lisanud =lisanud  (ID  >lisanud !41_A	et	f	\N
142555	lisanud	"lisanud %lisa  )NUD_vA  <lisama ;27_V	et	f	\N
142558	kõrvaldanud	kõrvaldanud =kõrvalda  (PtsPtPs  >kõrvaldama !27_V	et	f	\N
142559	kõrvaldanud	kõrvaldanud =kõrvaldanu  (PlN  >kõrvaldanu !01_S	et	f	\N
142560	kõrvaldanud	"kõrvaldanu %kõrvalda  )NU_vS  <kõrvaldama ;27_V	et	f	\N
142562	kõrvaldanud	kõrvaldanud =kõrvaldanud  (ID  >kõrvaldanud !41_A	et	f	\N
142564	kõrvaldanud	"kõrvaldanud %kõrvalda  )NUD_vA  <kõrvaldama ;27_V	et	f	\N
142566	murdekeele	murdekeele =kee  (SgAll  >murde+kesi !15_S	et	f	\N
142567	murdekeele	murdekeele =kee  (SgAll  >murde+kee !26_S	et	f	\N
142568	murdekeele	murdekeele =keele  (SgG  >murde+keel !13_S	et	f	\N
142571	märke	märke =märke  (SgG  >märge !06_S	et	f	\N
142572	märke	märke =märke  (PlP  >märk !22_S	et	f	\N
142581	harilikus	harilikus =hariliku  (SgIn  >harilik !25_A	et	f	\N
142582	harilikus	harilikus =harilikus  (SgN  >harilikus !11?09_S	et	f	\N
142583	harilikus	"harilikus %hariliku  )US_aS  <harilik ;25_A	et	f	\N
142598	pasportiseeritud	?pasportiseeritud =pasportiseeri  (PtsPtIps  >pasportiseerima !28_V	et	f	\N
142599	pasportiseeritud	?pasportiseeritud =pasportiseeritu  (PlN  >pasportiseeritu !01_S	et	f	\N
142600	pasportiseeritud	?pasportiseeritud =pasportiseeritu  (IndPrSg2  >pasportiseerituma !27_V	et	f	\N
142601	pasportiseeritud	?pasportiseeritud =pasportiseeritud  (ID  >pasportiseeritud !41_A	et	f	\N
142625	kutkinat	### kutkinat	et	f	\N
142644	hoolitsuse	hoolitsuse =hoolitsuse  (SgG  >hoolitsus !11_S	et	f	\N
142645	hoolitsuse	"hoolitsus %hoolitse  )US_vS  <hoolitsema ;27_V	et	f	\N
142676	sergei	?sergei =sergei  (SgN  >sergei !26_S	et	f	\N
142678	sergei	?sergei =sergei  (SgG  >sergei !26_S	et	f	\N
142735	helendav	helendav =helenda  (PtsPrPs  >helendama !27_V	et	f	\N
142736	helendav	helendav =helendav  (SgN  >helendav !02_A	et	f	\N
142737	helendav	"helendav %helenda  )V_vA  <helendama ;27_V	et	f	\N
142738	nõiduslikult	nõiduslikult =nõidusliku  (SgAbl  >nõiduslik !25_A	et	f	\N
142739	nõiduslikult	nõiduslikult =nõiduslikult  (ID  >nõiduslikult !41_D	et	f	\N
142740	nõiduslikult	"nõiduslikult %nõidusliku  )LT_mD  <nõiduslik ;25_A	et	f	\N
142749	asjakesed	asjakesed =asjakese  (PlN  >asjake !12_S	et	f	\N
142750	asjakesed	"asjake %asja  )KE_dS  <asi ;24_S	et	f	\N
142752	asjakesed	asjakesed =asjakese  (PlN  >asjakene !12_S	et	f	\N
142754	asjakesed	"asjakene %asja  )KENE_dS  <asi ;24_S	et	f	\N
142784	kaalutlustel	kaalutlustel =kaalutlus  (PlAd  >kaalutlus !11_S	et	f	\N
142785	kaalutlustel	"kaalutlus %kaalutle  )US_vS  <kaalutlema ;27_V	et	f	\N
142801	põhjendust	põhjendust =põhjendus  (SgP  >põhjendus !11_S	et	f	\N
142802	põhjendust	"põhjendus %põhjenda  )US_vS  <põhjendama ;27_V	et	f	\N
142805	arusaamist	arusaamist =saami  (SgEl  >aru+saam !22_S	et	f	\N
142806	arusaamist	arusaamist =saamis  (SgP  >aru+saamine !12?10_S	et	f	\N
142807	arusaamist	"aru+saamine %saami  )NE_aA  <aru+saam ;22_S	et	f	\N
142808	kangelaste	kangelaste =kangelas  (PlG  >kangelane !12_S	et	f	\N
142809	kangelaste	kangelaste =las  (PlG  >kange+laps !14_S	et	f	\N
142810	kangelaste	kangelaste =laste  (PlP  >kange+last !22_S	et	f	\N
142819	assotsiatsiooni	assotsiatsiooni =assotsiatsiooni  (SgG  >assotsiatsioon !22_S	et	f	\N
142820	assotsiatsiooni	assotsiatsiooni =assotsiatsiooni  (SgP  >assotsiatsioon !22_S	et	f	\N
142821	assotsiatsiooni	assotsiatsiooni =assotsiatsiooni  (SgAdt  >assotsiatsioon !22_S	et	f	\N
142826	põhjendatud	põhjendatud =põhjenda  (PtsPtIps  >põhjendama !27_V	et	f	\N
142827	põhjendatud	põhjendatud =põhjendatu  (PlN  >põhjendatu !01_S	et	f	\N
142828	põhjendatud	"põhjendatu %põhjenda  )TU1_vS  <põhjendama ;27_V	et	f	\N
142829	põhjendatud	põhjendatud =põhjendatud  (ID  >põhjendatud !41_A	et	f	\N
142830	põhjendatud	"põhjendatud %põhjenda  )TUD_vA  <põhjendama ;27_V	et	f	\N
142842	helendust	helendust =helendus  (SgP  >helendus !11_S	et	f	\N
142843	helendust	"helendus %helenda  )US_vS  <helendama ;27_V	et	f	\N
142844	lisatud	lisatud =lisa  (PtsPtIps  >lisama !27_V	et	f	\N
142845	lisatud	lisatud =lisatu  (PlN  >lisatu !01_AS	et	f	\N
142612	vanauusliste	?vanauusliste =liste  (PlP  >vana+uus+list !22_S	et	f	\N
142614	vanauusliste	?vanauusliste =uuslis  (PlG  >vana+uuslis !09_S	et	f	\N
142615	vanauusliste	?vanauusliste =uuslis  (PlG  >vana+uusline !12~10_A	et	f	\N
142616	vanauusliste	?vanauusliste =uusliste  (PlP  >vana+uuslist !22_S	et	f	\N
142617	anastasija	?anastasija =anastasija  (SgN  >anastasija !01_S	et	f	\N
142618	anastasija	?anastasija =anastasija  (SgG  >anastasija !01_S	et	f	\N
142619	anastasija	?anastasija =anastasija  (SgG  >anastasijas !02_A	et	f	\N
142626	hionia	?hionia =hionia  (SgN  >hionia !01_S	et	f	\N
142627	hionia	?hionia =hionia  (SgG  >hionia !01_S	et	f	\N
142633	poljakovat	?poljakovat =poljakova  (SgP  >poljakov !02_A	et	f	\N
142634	poljakovat	?poljakovat =poljakova  (SgP  >poljakova !16_S	et	f	\N
142640	suurepärase	suurepärase =pärase  (SgG  >suure+pärane !10_A	et	f	\N
142641	suurepärase	"suure+pärane %pära  )NE_aA  <suure+pära ;17_S	et	f	\N
142648	teadusakadeemia	teadusakadeemia =akadeemia  (SgN  >teadus+akadeemia !01_S	et	f	\N
142649	teadusakadeemia	teadusakadeemia =akadeemia  (SgG  >teadus+akadeemia !01_S	et	f	\N
142650	esitajatest	esitajatest =esitaja  (PlEl  >esitaja !01_S	et	f	\N
142651	esitajatest	"esitaja %esita  )JA_vS  <esitama ;27_V	et	f	\N
142652	kummardus	kummardus =kummardu  (IndIpfSg3  >kummarduma !27_V	et	f	\N
142653	kummardus	kummardus =kummardus  (SgN  >kummardus !11_S	et	f	\N
142654	kummardus	"kummardus %kummarda  )US_vS  <kummardama ;27_V	et	f	\N
142655	informantidele	?informantidele =informanti  (PlAll  >informant !22_S	et	f	\N
142656	hõitatusele	?hõitatusele =hõitatuse  (SgAll  >hõitatus !11_S	et	f	\N
142657	haiglusele	haiglusele =haigluse  (SgAll  >haiglus !11~09_S	et	f	\N
142658	haiglusele	"haiglus %haiglase  )US_aS  <haiglane ;12_A	et	f	\N
142661	väljaanne	väljaanne =anne  (SgN  >välja+anne !05_S	et	f	\N
142662	väljaanne	väljaanne =anne  (SgN  >välja+anne !06_S	et	f	\N
142680	ulme	ulme =ulme  (SgN  >ulme !06_S	et	f	\N
142681	ulme	ulme =ulme  (SgG  >ulme !06_S	et	f	\N
142682	ulme	ulme =ulme  (PlP  >ulm !22_S	et	f	\N
142698	tuntumatest	tuntumatest =tuntuma  (PlEl  >tuntum !02_A	et	f	\N
142699	tuntumatest	"tuntum %tun  )TUM1_cA  <tundma ;34_V	et	f	\N
142702	keskenduvat	keskenduvat =keskendu  (KvtPrPs  >keskenduma !27_V	et	f	\N
142703	keskenduvat	keskenduvat =keskenduva  (SgP  >keskenduv !02_A	et	f	\N
142704	keskenduvat	"keskenduv %keskendu  )V_vA  <keskenduma ;27_V	et	f	\N
142711	kadumine	kadumine =kadumine  (SgN  >kadumine !12_S	et	f	\N
142712	kadumine	"kadumine %kadu  )MINE_vS  <kaduma ;28_V	et	f	\N
142713	kadumine	"kadumine %kadumi  )NE_aA  <kadum ;02_S	et	f	\N
142716	vändatud	vändatud =vända  (PtsPtIps  >väntama !29_V	et	f	\N
142717	vändatud	vändatud =vändatu  (PlN  >vändatu !01_S	et	f	\N
142718	vändatud	"vändatu %vända  )TU1_vS  <väntama ;29_V	et	f	\N
142719	vändatud	"vändatu %vända  )TU2_kA  <vänt ;22_S	et	f	\N
142720	vändatud	vändatud =vändatud  (ID  >vändatud !41_A	et	f	\N
142721	vändatud	"vändatud %vända  )TUD_vA  <väntama ;29_V	et	f	\N
142722	samanimelise	samanimelise =nimelise  (SgG  >sama+nimeline !12_A	et	f	\N
142723	samanimelise	"sama+nimeline %nime  )LINE_aA  <sama+nimi ;20_S	et	f	\N
142728	deeptown	?deeptown =deeptown  (SgN  >deeptown !22_S	et	f	\N
142741	paki	paki =paki  (SgG  >pakk !22_S	et	f	\N
142742	paki	paki =paki  (IndPrPs_  >pakkima !28_V	et	f	\N
142743	paki	paki =paki  (ImpPrSg2  >pakkima !28_V	et	f	\N
142751	tupes	tupes =tupe  (SgIn  >tupp !22_S	et	f	\N
142753	tupes	tupes =tupe  (PlIn  >tupp !22_S	et	f	\N
142780	võrdseks	võrdseks =võrdse  (SgTr  >võrdne !02_A	et	f	\N
142781	võrdseks	võrdseks =seks  (SgN  >võrd+seks !22_S	et	f	\N
142782	stilistilistel	stilistilistel =stilistilis  (PlAd  >stilistiline !12_A	et	f	\N
142783	stilistilistel	"stilistiline %stilisti  )LINE_aA  <stilist ;22_S	et	f	\N
142786	peegelduse	peegelduse =peegelduse  (SgG  >peegeldus !11_S	et	f	\N
142787	peegelduse	"peegeldus %peegelda  )US_vS  <peegeldama ;27_V	et	f	\N
142803	ahaaa	?ahaaa =ahaaa  (SgN  >ahaaa !26_S	et	f	\N
142804	ahaaa	?ahaaa =ahaaa  (SgG  >ahaaa !26_S	et	f	\N
142860	koma	koma =koma  (SgN  >koma !17_S	et	f	\N
142861	koma	koma =koma  (SgG  >koma !17_S	et	f	\N
142862	koma	koma =koma  (SgP  >koma !17_S	et	f	\N
142865	rõivastusega	rõivastusega =rõivastuse  (SgKom  >rõivastus !11_S	et	f	\N
142866	rõivastusega	"rõivastus %rõivasta  )US_vS  <rõivastama ;27_V	et	f	\N
142871	linane	linane =linane  (SgN  >linane !10_A	et	f	\N
142872	linane	"linane %lina  )NE_aA  <lina ;17_S	et	f	\N
142892	muinasjutuhõngulisus	muinasjutuhõngulisus =hõngulisus  (SgN  >muinas+jutu+hõngulisus !11?09_S	et	f	\N
142893	muinasjutuhõngulisus	"muinas+jutu+hõngulisus %hõngu  )LISUS_aS  <muinas+jutu+hõng ;22_S	et	f	\N
142896	edasiseks	edasiseks =edasise  (SgTr  >edasine !12_A	et	f	\N
142898	edasiseks	edasiseks =seks  (SgN  >edasi+seks !22_S	et	f	\N
142913	sõnajärge	sõnajärge =järge  (SgN  >sõna+järge !05_S	et	f	\N
142914	sõnajärge	sõnajärge =järge  (SgP  >sõna+järg !22_S	et	f	\N
142915	sõnajärge	sõnajärge =järge  (SgAdt  >sõna+järg !22_S	et	f	\N
142929	vihje	vihje =vihje  (SgN  >vihje !06_S	et	f	\N
142930	vihje	vihje =vihje  (SgG  >vihje !06_S	et	f	\N
142691	alguspoole	alguspoole =poole  (PlP  >algus+pool !22_S	et	f	\N
142692	kirjandustegevust	kirjandustegevust =us  (SgP  >kirjandus+tegev+uks !14_S	et	f	\N
142693	kirjandustegevust	kirjandustegevust =tegevus  (SgP  >kirjandus+tegevus !11_S	et	f	\N
142694	kirjandustegevust	"kirjandus+tegevus %tegeva  )US_aS  <kirjandus+tegev ;02_A	et	f	\N
142700	esmapilgul	esmapilgul =pilgu  (SgAd  >esma+pilk !22_S	et	f	\N
142701	esmapilgul	esmapilgul =pilgu  (PlAd  >esma+pilk !22_S	et	f	\N
142705	peateemaks	peateemaks =maks  (SgN  >pea+tee+maks !22_S	et	f	\N
142706	peateemaks	peateemaks =teema  (SgTr  >pea+teema !16_S	et	f	\N
142726	eksisteerivas	eksisteerivas =eksisteeriva  (SgIn  >eksisteeriv !02_A	et	f	\N
142727	eksisteerivas	"eksisteeriv %eksisteeri  )V_vA  <eksisteerima ;28_V	et	f	\N
142745	särki	särki =särki  (SgP  >särk !22_S	et	f	\N
142748	särki	särki =särki  (SgAdt  >särk !22_S	et	f	\N
142755	ebaseaduslikult	ebaseaduslikult =seadusliku  (SgAbl  >eba+seaduslik !25_A	et	f	\N
142756	ebaseaduslikult	ebaseaduslikult =seaduslikult  (ID  >eba+seaduslikult !41_D	et	f	\N
142757	ebaseaduslikult	"eba+seaduslikult %seadusliku  )LT_mD  <eba+seaduslik ;25_A	et	f	\N
142758	taga-kaukaasia	?taga-kaukaasia =kaukaasia  (SgN  >taga-kaukaasia !01_S	et	f	\N
142759	taga-kaukaasia	?taga-kaukaasia =kaukaasia  (SgG  >taga-kaukaasia !01_S	et	f	\N
142760	taga-kaukaasia	?taga-kaukaasia =asia  (SgN  >taga-kauka+asia !01_S	et	f	\N
142761	taga-kaukaasia	?taga-kaukaasia =asia  (SgG  >taga-kauka+asia !01_S	et	f	\N
142764	pisikest	pisikest =pisikes  (SgP  >pisike !12_A	et	f	\N
142765	pisikest	pisikest =pisikes  (SgP  >pisikene !12_A	et	f	\N
142766	pisikest	pisikest =kest  (SgN  >pisi+kest !22_S	et	f	\N
142771	originaalteksti	originaalteksti =teksti  (SgG  >originaal+tekst !22_S	et	f	\N
142772	originaalteksti	originaalteksti =teksti  (SgP  >originaal+tekst !22_S	et	f	\N
142773	originaalteksti	originaalteksti =teksti  (SgAdt  >originaal+tekst !22_S	et	f	\N
142788	lõigu	lõigu =lõigu  (SgG  >lõik !22_S	et	f	\N
142789	lõigu	lõigu =lõigu  (IndPrPs_  >lõikuma !28_V	et	f	\N
142790	lõigu	lõigu =lõigu  (ImpPrSg2  >lõikuma !28_V	et	f	\N
142796	põhinevat	põhinevat =põhine  (KvtPrPs  >põhinema !27_V	et	f	\N
142797	põhinevat	põhinevat =põhineva  (SgP  >põhinev !02_A	et	f	\N
142799	põhinevat	"põhinev %põhine  )V_vA  <põhinema ;27_V	et	f	\N
142822	helenduse	helenduse =helenduse  (SgG  >helendus !11_S	et	f	\N
142823	helenduse	"helendus %helenda  )US_vS  <helendama ;27_V	et	f	\N
142838	värelevat	värelevat =värele  (KvtPrPs  >värelema !31~27_V	et	f	\N
142839	värelevat	värelevat =väreleva  (SgP  >värelev !02_A	et	f	\N
142840	värelevat	"värelev %värele  )V_vA  <värelema ;27_V	et	f	\N
142841	värelevat	"värelev %värele  )V_vA  <värelema ;31_V	et	f	\N
142858	mõistmise	mõistmise =mõistmise  (SgG  >mõistmine !12?10_S	et	f	\N
142859	mõistmise	"mõistmine %mõist  )MINE_vS  <mõistma ;34_V	et	f	\N
142882	kirjatud	kirjatud =kirja  (PtsPtIps  >kirjama !29_V	et	f	\N
142883	kirjatud	kirjatud =kirjatu  (PlN  >kirjatu !01_AS	et	f	\N
142884	kirjatud	"kirjatu %kirja  )TU1_vS  <kirjama ;29_V	et	f	\N
142885	kirjatud	"kirjatu %kirja  )TU2_kA  <kiri ;24_S	et	f	\N
142886	kirjatud	kirjatud =kirjatud  (ID  >kirjatud !41_A	et	f	\N
142887	kirjatud	"kirjatud %kirja  )TUD_vA  <kirjama ;29_V	et	f	\N
142888	särgi	särgi =särgi  (SgG  >särk !22_S	et	f	\N
142889	särgi	särgi =särgi  (SgP  >särg !22_S	et	f	\N
142890	särgi	särgi =särgi  (SgAdt  >särg !22_S	et	f	\N
142891	särgi	särgi =särgi  (PlP  >särg !22_S	et	f	\N
142921	puutumist	puutumist =puutumi  (SgEl  >puutum !02_A	et	f	\N
142922	puutumist	"puutum %puu  )TUM2_cA  <puu ;26_S	et	f	\N
142923	puutumist	puutumist =puutumis  (SgP  >puutumine !12_S	et	f	\N
142924	puutumist	"puutumine %puutu  )MINE_vS  <puutuma ;27_V	et	f	\N
142927	programmeerijaid	programmeerijaid =programmeerija  (PlP  >programmeerija !01_S	et	f	\N
142928	programmeerijaid	"programmeerija %programmeeri  )JA_vS  <programmeerima ;28_V	et	f	\N
142931	osavusest	osavusest =osavuse  (SgEl  >osavus !11_S	et	f	\N
142932	osavusest	"osavus %osava  )US_aS  <osav ;02_A	et	f	\N
142933	osavusest	osavusest =osavuses  (SgP  >osavusene !12_A	et	f	\N
142934	osavusest	"osavusene %osavuse  )NE_aA  <osavus ;11_S	et	f	\N
142946	lugejani	lugejani =lugeja  (SgTer  >lugeja !01_S	et	f	\N
142947	lugejani	"lugeja %luge  )JA_vS  <lugema ;28_V	et	f	\N
142948	antonüümia	antonüümia =antonüümia  (SgN  >antonüümia !01_S	et	f	\N
142949	antonüümia	antonüümia =antonüümia  (SgG  >antonüümia !01_S	et	f	\N
142950	tähenduste	tähenduste =tähendus  (PlG  >tähendus !11_S	et	f	\N
142953	tähenduste	"tähendus %tähenda  )US_vS  <tähendama ;27_V	et	f	\N
142962	sarnasuse	sarnasuse =sarnasuse  (SgG  >sarnasus !11_S	et	f	\N
142963	sarnasuse	"sarnasus %sarna  )SUS_aS  <sarn ;22_S	et	f	\N
142980	vektorvastandusel	?vektorvastandusel =vektorvastanduse  (SgAd  >vektorvastandus !11_S	et	f	\N
143014	kasutuse	kasutuse =kasutuse  (SgG  >kasutus !11_S	et	f	\N
143016	kasutuse	"kasutus %kasuta  )US_vS  <kasutama ;27_V	et	f	\N
143018	kasutuse	"kasutus %kasu  )TUS2_aS  <kasu ;17_S	et	f	\N
143023	isikuid	isikuid =isiku  (PlP  >isik !02_S	et	f	\N
143024	isikuid	isikuid =ui  (PlN  >isik+ui !26_S	et	f	\N
143025	isikuid	isikuid =ui  (SgP  >isik+ui !26_S	et	f	\N
142744	linasesse	linasesse =linase  (SgIll  >linane !10_A	et	f	\N
142746	linasesse	"linane %lina  )NE_aA  <lina ;17_S	et	f	\N
142747	linasesse	linasesse =sesse  (PlP  >lina+sess !22_S	et	f	\N
142762	programmeerijad	programmeerijad =programmeerija  (PlN  >programmeerija !01_S	et	f	\N
142763	programmeerijad	"programmeerija %programmeeri  )JA_vS  <programmeerima ;28_V	et	f	\N
142791	lause-lauselt	lause-lauselt =lause  (SgAbl  >lause-lause !06_S	et	f	\N
142792	lause-lauselt	lause-lauselt =lauselt  (ID  >lause-lauselt !41_D	et	f	\N
142793	lause-lauselt	"lause-lauselt %lau  )SELT_mD  <lause-laug ;22_SA	et	f	\N
142798	mõttemuutusel	mõttemuutusel =muutuse  (SgAd  >mõtte+muutus !11~09_S	et	f	\N
142800	mõttemuutusel	"mõtte+muutus %muu  )TUS2_aS  <mõtte+muu ;26_S	et	f	\N
142811	värviks	värviks =värvi  (SgTr  >värv !22_S	et	f	\N
142812	värviks	värviks =värvi  (KndPrPs  >värvima !28_V	et	f	\N
142813	värviks	värviks =iks  (SgN  >värv+iks !22_S	et	f	\N
142824	rõhutamine	rõhutamine =rõhutamine  (SgN  >rõhutamine !12_S	et	f	\N
142825	rõhutamine	"rõhutamine %rõhuta  )MINE_vS  <rõhutama ;27_V	et	f	\N
142867	talupoeg-kangelast	talupoeg-kangelast =kangelas  (SgP  >talupoeg-kangelane !12_S	et	f	\N
142868	talupoeg-kangelast	talupoeg-kangelast =la  (SgEl  >talupoeg-kange+la !26_S	et	f	\N
142869	talupoeg-kangelast	talupoeg-kangelast =las  (SgP  >talupoeg-kange+laps !14_S	et	f	\N
142870	talupoeg-kangelast	talupoeg-kangelast =last  (SgN  >talupoeg-kange+last !22_S	et	f	\N
142878	täpsustuseks	täpsustuseks =täpsustuse  (SgTr  >täpsustus !11_S	et	f	\N
142879	täpsustuseks	"täpsustus %täpsusta  )US_vS  <täpsustama ;27_V	et	f	\N
142894	rõivastus	rõivastus =rõivastu  (IndIpfSg3  >rõivastuma !27_V	et	f	\N
142895	rõivastus	rõivastus =rõivastus  (SgN  >rõivastus !11_S	et	f	\N
142897	rõivastus	"rõivastus %rõivasta  )US_vS  <rõivastama ;27_V	et	f	\N
142903	ivaniks	?ivaniks =ivani  (SgTr  >ivan !02_S	et	f	\N
142904	asjakesi	asjakesi =asjakesi  (PlP  >asjake !12_S	et	f	\N
142905	asjakesi	"asjake %asja  )KE_dS  <asi ;24_S	et	f	\N
142906	asjakesi	asjakesi =asjakesi  (PlP  >asjakene !12_S	et	f	\N
142907	asjakesi	"asjakene %asja  )KENE_dS  <asi ;24_S	et	f	\N
142925	solvata	solvata =solva  (Inf  >solvama !29_V	et	f	\N
142926	solvata	solvata =solva  (IndPrIps_  >solvama !29_V	et	f	\N
142935	märkaksid	märkaksid =märka  (KndPrSg2  >märkama !29_V	et	f	\N
142936	märkaksid	märkaksid =märka  (KndPrPl3  >märkama !29_V	et	f	\N
142966	leksikaalsemantilise	?leksikaalsemantilise =leksikaalsemantilise  (SgG  >leksikaalsemantiline !12_A	et	f	\N
142981	antonym	?antonym =antonym  (SgN  >antonym !19_S	et	f	\N
142986	nearantonym	?nearantonym =nearantonym  (SgN  >nearantonym !19_S	et	f	\N
142998	testlause	testlause =lause  (SgN  >test+lause !06_S	et	f	\N
142999	testlause	testlause =lause  (SgG  >test+lause !06_S	et	f	\N
143060	doktoritööd	doktoritööd =töö  (PlN  >doktori+töö !26_S	et	f	\N
143061	doktoritööd	doktoritööd =töö  (SgP  >doktori+töö !26_S	et	f	\N
143108	korraldamiseks	korraldamiseks =korraldamise  (SgTr  >korraldamine !12_S	et	f	\N
143109	korraldamiseks	"korraldamine %korralda  )MINE_vS  <korraldama ;27_V	et	f	\N
143133	õpilastevahetus	õpilastevahetus =vahetu  (SgIn  >õpi+laste+vahetu !01_A	et	f	\N
143134	õpilastevahetus	"õpi+laste+vahetu %vahe  )TU2_kA  <õpi+laste+vahe ;16_S	et	f	\N
143135	õpilastevahetus	õpilastevahetus =vahetus  (SgN  >õpi+laste+vahetus !11_S	et	f	\N
143136	õpilastevahetus	"õpi+laste+vahetus %vahe  )TUS2_aS  <õpi+laste+vahe ;16_S	et	f	\N
143173	kohtus	kohtus =kohtu  (SgIn  >kohus !05_S	et	f	\N
143175	kohtus	kohtus =kohtu  (IndIpfSg3  >kohtuma !27_V	et	f	\N
143194	bouwlingut	?bouwlingut =bouwlingu  (SgP  >bouwlingu !01_S	et	f	\N
143195	bouwlingut	?bouwlingut =bouwlingu  (SgP  >bouwling !02_S	et	f	\N
143218	suureim	?suureim =suureim  (SgN  >suureim !02_A	et	f	\N
143219	suureim	?suureim =eim  (SgN  >suur+eim !22_S	et	f	\N
143220	suureim	?suureim =reim  (SgN  >suu+reim !22_S	et	f	\N
143224	vartsusiseal	?vartsusiseal =vartsusisea  (SgAd  >vartsusisea !26_S	et	f	\N
143225	vartsusiseal	?vartsusiseal =vartsusiseal  (SgN  >vartsusiseal !19_S	et	f	\N
143239	jarv	?jarv =jarv  (SgN  >jarv !22_S	et	f	\N
143247	kohadkus	?kohadkus =kohadku  (SgIn  >kohadku !01_S	et	f	\N
143248	kohadkus	?kohadkus =kohadku  (IndIpfSg3  >kohadkuma !27_V	et	f	\N
143249	kohadkus	?kohadkus =kohadkus  (SgN  >kohadkus !11_S	et	f	\N
143251	soitsin	?soitsin =soit  (IndIpfSg1  >soitma !34_V	et	f	\N
143252	soitsin	?soitsin =soitsi  (IndPrSg1  >soitsima !28_V	et	f	\N
143253	soitsin	?soitsin =soitsin  (SgN  >soitsin !02_S	et	f	\N
143256	lumis	?lumis =lumi  (IndIpfSg3  >lumima !27_V	et	f	\N
143257	lumis	?lumis =lumis  (SgN  >lumis !09_S	et	f	\N
143258	sqitsida	?sqitsida =sqitsi  (Inf  >sqitsima !28_V	et	f	\N
143259	hiiumaal	hiiumaal =maa  (SgAd  >hiiu+maa !26_S	et	f	\N
143260	hiiumaal	hiiumaal =maal  (SgN  >hiiu+maal !22_S	et	f	\N
143275	voib	?voib =voib  (SgN  >voib !22_S	et	f	\N
143285	koormus	koormus =koormu  (IndIpfSg3  >koormuma !27_V	et	f	\N
143286	koormus	koormus =koormus  (SgN  >koormus !11~09_S	et	f	\N
143318	mutub	?mutub =mutu  (IndPrSg3  >mutuma !27_V	et	f	\N
143322	inglisekeele	inglisekeele =kee  (SgAll  >inglise+kesi !15_S	et	f	\N
143323	inglisekeele	inglisekeele =kee  (SgAll  >inglise+kee !26_S	et	f	\N
142814	sinakasvalge	sinakasvalge =valge  (SgN  >sina+kas+valge !01_AS	et	f	\N
142815	sinakasvalge	sinakasvalge =valge  (SgG  >sina+kas+valge !01_AS	et	f	\N
142816	lähedalt	lähedalt =läheda  (SgAbl  >läheda !02_A	et	f	\N
142817	lähedalt	lähedalt =lähedalt  (ID  >lähedalt !41_DK	et	f	\N
142818	lähedalt	"lähedalt %läheda  )LT_mD  <läheda ;02_A	et	f	\N
142831	keelelise	keelelise =keelelise  (SgG  >keeleline !12_A	et	f	\N
142832	keelelise	"keeleline %keele  )LINE_aA  <keel ;13_S	et	f	\N
142833	sobi	sobi =sobi  (SgN  >sobi !17_S	et	f	\N
142834	sobi	sobi =sobi  (SgG  >sobi !17_S	et	f	\N
142835	sobi	sobi =sobi  (SgP  >sobi !17_S	et	f	\N
142836	sobi	sobi =sobi  (IndPrPs_  >sobima !27_V	et	f	\N
142837	sobi	sobi =sobi  (ImpPrSg2  >sobima !27_V	et	f	\N
142853	asendatud	asendatud =asenda  (PtsPtIps  >asendama !27_V	et	f	\N
142854	asendatud	asendatud =asendatu  (PlN  >asendatu !01_S	et	f	\N
142855	asendatud	"asendatu %asenda  )TU1_vS  <asendama ;27_V	et	f	\N
142856	asendatud	asendatud =asendatud  (ID  >asendatud !41_A	et	f	\N
142857	asendatud	"asendatud %asenda  )TUD_vA  <asendama ;27_V	et	f	\N
142863	kaduma	kaduma =kadu  (Sup  >kaduma !28_V	et	f	\N
142864	kaduma	kaduma =kaduma  (SgG  >kadum !02_S	et	f	\N
142873	rõhutatud	rõhutatud =rõhuta  (PtsPtIps  >rõhutama !27_V	et	f	\N
142874	rõhutatud	rõhutatud =rõhutatu  (PlN  >rõhutatu !01_S	et	f	\N
142875	rõhutatud	"rõhutatu %rõhuta  )TU1_vS  <rõhutama ;27_V	et	f	\N
142876	rõhutatud	rõhutatud =rõhutatud  (ID  >rõhutatud !41_A	et	f	\N
142877	rõhutatud	"rõhutatud %rõhuta  )TUD_vA  <rõhutama ;27_V	et	f	\N
142880	linase	linase =linase  (SgG  >linane !10_A	et	f	\N
142881	linase	"linane %lina  )NE_aA  <lina ;17_S	et	f	\N
142899	tegevuseks	tegevuseks =tegevuse  (SgTr  >tegevus !11_S	et	f	\N
142900	tegevuseks	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
142901	tegevuseks	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
142902	tegevuseks	tegevuseks =use  (PlTr  >tegev+usk !22_S	et	f	\N
142908	asjakest	asjakest =asjakes  (SgP  >asjake !12_S	et	f	\N
142909	asjakest	"asjake %asja  )KE_dS  <asi ;24_S	et	f	\N
142910	asjakest	asjakest =asjakes  (SgP  >asjakene !12_S	et	f	\N
142911	asjakest	"asjakene %asja  )KENE_dS  <asi ;24_S	et	f	\N
142912	asjakest	asjakest =kest  (SgN  >asja+kest !22_S	et	f	\N
142941	proovigi	proovigi =proovi  (SgG^  >proov !22_S	et	f	\N
142942	proovigi	proovigi =proovi  (SgP^  >proov !22_S	et	f	\N
142943	proovigi	proovigi =proovi  (SgAdt^  >proov !22_S	et	f	\N
142944	proovigi	proovigi =proovi  (IndPrPs_^  >proovima !28_V	et	f	\N
142945	proovigi	proovigi =proovi  (ImpPrSg2^  >proovima !28_V	et	f	\N
142956	vastandussuhe	vastandussuhe =uhe  (SgN  >vastand+uss+uhe !05_S	et	f	\N
142957	vastandussuhe	vastandussuhe =uhe  (SgN  >vastand+uss+uhe !06_S	et	f	\N
142958	vastandussuhe	vastandussuhe =suhe  (SgN  >vastandus+suhe !06_S	et	f	\N
142967	paradigma	paradigma =paradigma  (SgN  >paradigma !16_S	et	f	\N
142968	paradigma	paradigma =paradigma  (SgG  >paradigma !16_S	et	f	\N
142971	sarnasussuhteks	### sarnasussuhteks	et	f	\N
142972	vastandatavatel	vastandatavatel =vastandatava  (PlAd  >vastandatav !02_A	et	f	\N
142973	vastandatavatel	"vastandatav %vastanda  )TAV_vAS  <vastandama ;27_V	et	f	\N
142977	vastandusel	vastandusel =vastanduse  (SgAd  >vastandus !11_S	et	f	\N
142978	vastandusel	"vastandus %vastanda  )US_vS  <vastandama ;27_V	et	f	\N
142979	vastandusel	vastandusel =use  (PlAd  >vastand+usk !22_S	et	f	\N
142987	xposnearantonym	?xposnearantonym =xposnearantonym  (SgN  >xposnearantonym !19_S	et	f	\N
142988	eristatud	eristatud =erista  (PtsPtIps  >eristama !27_V	et	f	\N
142989	eristatud	eristatud =eristatu  (PlN  >eristatu !01_S	et	f	\N
142990	eristatud	"eristatu %erista  )TU1_vS  <eristama ;27_V	et	f	\N
142991	eristatud	eristatud =eristatud  (ID  >eristatud !41_A	et	f	\N
142992	eristatud	"eristatud %erista  )TUD_vA  <eristama ;27_V	et	f	\N
142996	eelnevate	eelnevate =eelneva  (PlG  >eelnev !02_A	et	f	\N
142997	eelnevate	"eelnev %eelne  )V_vA  <eelnema ;27_V	et	f	\N
143015	konteksti	konteksti =konteksti  (SgG  >kontekst !22_S	et	f	\N
143017	konteksti	konteksti =konteksti  (SgP  >kontekst !22_S	et	f	\N
143019	konteksti	konteksti =konteksti  (SgAdt  >kontekst !22_S	et	f	\N
143020	deiktikuteks	?deiktikuteks =deiktiku  (PlTr  >deiktiku !01_S	et	f	\N
143021	deiktikuteks	?deiktikuteks =deiktiku  (PlTr  >deiktik !02_S	et	f	\N
143022	deiktikuteks	?deiktikuteks =deiktikute  (PlTr  >deiktikutt !22_S	et	f	\N
143037	deiksise	?deiksise =deiksise  (SgG  >deiksis !09_S	et	f	\N
143038	deiksise	?deiksise =deiksise  (IndPrPs_  >deiksisema !27_V	et	f	\N
143039	deiksise	?deiksise =deiksise  (ImpPrSg2  >deiksisema !27_V	et	f	\N
143040	teades	teades =tead  (Ger  >teadma !34_V	et	f	\N
143041	teades	teades =teade  (PlIn  >tead !22_S	et	f	\N
143044	jõutud	jõutud =jõu  (PtsPtIps  >jõudma !34_V	et	f	\N
143045	jõutud	jõutud =jõutu  (PlN  >jõutu !01_SA	et	f	\N
143046	jõutud	"jõutu %jõu  )TU1_vS  <jõudma ;34_V	et	f	\N
143047	jõutud	"jõutu %jõu  )TU2_kA  <jõud ;22_S	et	f	\N
143048	jõutud	jõutud =jõutud  (ID  >jõutud !41_A	et	f	\N
143049	jõutud	"jõutud %jõu  )TUD_vA  <jõudma ;34_V	et	f	\N
143076	põhjalikumalt	põhjalikumalt =põhjalikuma  (SgAbl  >põhjalikum !02_A	et	f	\N
142846	lisatud	"lisatu %lisa  )TU1_vS  <lisama ;27_V	et	f	\N
142847	lisatud	"lisatu %lisa  )TU2_kA  <lisa ;17_S	et	f	\N
142848	lisatud	lisatud =lisatud  (ID  >lisatud !41_A	et	f	\N
142849	lisatud	"lisatud %lisa  )TUD_vA  <lisama ;27_V	et	f	\N
142850	lausest	lausest =lause  (SgEl  >lause !06_S	et	f	\N
142851	lausest	lausest =lauses  (SgP  >lausene !10_A	et	f	\N
142852	lausest	"lausene %lause  )NE_aA  <lause ;06_S	et	f	\N
142916	eestipärasemaks	eestipärasemaks =pärasema  (SgTr  >eesti+pärasem !02_A	et	f	\N
142917	eestipärasemaks	"eesti+pärasem %pära  )SEM_cA  <eesti+pära ;17_S	et	f	\N
142918	eestipärasemaks	"eesti+pärasem %pärase  )M_cA  <eesti+pärane ;10_A	et	f	\N
142919	pooles	pooles =poole  (SgIn  >pool !13_NS	et	f	\N
142920	pooles	pooles =poole  (PlIn  >pool !22_S	et	f	\N
142951	vastandlikkus	vastandlikkus =vastandlikkus  (SgN  >vastandlikkus !11~09_S	et	f	\N
142952	vastandlikkus	"vastandlikkus %vastandlikku  )US_aS  <vastandlik ;25_A	et	f	\N
142954	vastandlikkus	vastandlikkus =andlikkus  (SgN  >vast+andlikkus !11~09_S	et	f	\N
142955	vastandlikkus	"vast+andlikkus %andlikku  )US_aS  <vast+andlik ;25_A	et	f	\N
142959	erinevuse	erinevuse =erinevuse  (SgG  >erinevus !11?09_S	et	f	\N
142960	erinevuse	"erinevus %erine  )VUS_aS  <erinema ;27_V	et	f	\N
142961	erinevuse	"erinevus %erineva  )US_aS  <erinev ;02_A	et	f	\N
142964	sünonüümiagi	sünonüümiagi =sünonüümia  (SgN^  >sünonüümia !01_S	et	f	\N
142965	sünonüümiagi	sünonüümiagi =sünonüümia  (SgG^  >sünonüümia !01_S	et	f	\N
142969	tähendusele	tähendusele =tähenduse  (SgAll  >tähendus !11_S	et	f	\N
142970	tähendusele	"tähendus %tähenda  )US_vS  <tähendama ;27_V	et	f	\N
142974	vastandustel	vastandustel =vastandus  (PlAd  >vastandus !11_S	et	f	\N
142975	vastandustel	"vastandus %vastanda  )US_vS  <vastandama ;27_V	et	f	\N
142976	vastandustel	vastandustel =us  (PlAd  >vastand+uks !14_S	et	f	\N
142993	sõnaliikidevaheliselt	?sõnaliikidevaheliselt =sõnaliikidevahelise  (SgAbl  >sõnaliikidevaheline !12_A	et	f	\N
142994	sõnaliikidevaheliselt	?sõnaliikidevaheliselt =sõnaliikidevaheliselt  (ID  >sõnaliikidevaheliselt !41_D	et	f	\N
142995	sõnaliikidevaheliselt	?sõnaliikidevaheliselt =liikidevahelise  (SgAbl  >sõna+liikidevaheline !12_A	et	f	\N
143000	z-d	z-d =z  (SgP  >z !xx_Q	et	f	\N
143001	z-d	z-d =z  (PlN  >z !xx_Q	et	f	\N
143004	lootusetus	lootusetus =lootusetu  (SgIn  >lootusetu !01_A	et	f	\N
143005	lootusetus	"lootusetu %lootuse  )TU2_kA  <lootus ;09_S	et	f	\N
143006	lootusetus	"lootusetu %lootuse  )TU2_kA  <lootus ;11_S	et	f	\N
143007	lootusetus	lootusetus =lootusetus  (SgN  >lootusetus !11?09_S	et	f	\N
143008	lootusetus	"lootusetus %lootuse  )TUS2_aS  <lootus ;09_S	et	f	\N
143009	lootusetus	"lootusetus %lootuse  )TUS2_aS  <lootus ;11_S	et	f	\N
143010	tundedtundmused	?tundedtundmused =tundedtundmuse  (PlN  >tundedtundmus !11~09_S	et	f	\N
143054	koostamisel	koostamisel =koostamise  (SgAd  >koostamine !12_S	et	f	\N
143055	koostamisel	"koostamine %koosta  )MINE_vS  <koostama ;27_V	et	f	\N
143057	pajusalu	pajusalu =salu  (SgN  >paju+salu !17_S	et	f	\N
143058	pajusalu	pajusalu =salu  (SgG  >paju+salu !17_S	et	f	\N
143059	pajusalu	pajusalu =salu  (SgP  >paju+salu !17_S	et	f	\N
143088	tõmmatud	tõmmatud =tõmma  (PtsPtIps  >tõmbama !29_V	et	f	\N
143089	tõmmatud	tõmmatud =tõmmatu  (PlN  >tõmmatu !01_A	et	f	\N
143090	tõmmatud	"tõmmatu %tõmma  )TU1_vS  <tõmbama ;29_V	et	f	\N
143091	tõmmatud	tõmmatud =tõmmatud  (ID  >tõmmatud !41_A	et	f	\N
143092	tõmmatud	"tõmmatud %tõmma  )TUD_vA  <tõmbama ;29_V	et	f	\N
143093	keelepoliitika	keelepoliitika =poliitika  (SgN  >keele+poliitika !01_S	et	f	\N
143094	keelepoliitika	keelepoliitika =poliitika  (SgG  >keele+poliitika !01_S	et	f	\N
143106	tagavate	tagavate =tagava  (PlG  >tagav !02_A	et	f	\N
143107	tagavate	"tagav %taga  )V_vA  <tagama ;27_V	et	f	\N
143110	eraldatava	eraldatava =eraldatava  (SgG  >eraldatav !02_A	et	f	\N
143111	eraldatava	"eraldatav %eralda  )TAV_vAS  <eraldama ;27_V	et	f	\N
143114	ministeeriumi	ministeeriumi =ministeeriumi  (SgG  >ministeerium !19~02_S	et	f	\N
143115	ministeeriumi	ministeeriumi =ministeeriumi  (SgP  >ministeerium !19_S	et	f	\N
143116	ministeeriumi	ministeeriumi =ministeeriumi  (SgAdt  >ministeerium !19_S	et	f	\N
143126	tagamine	tagamine =tagamine  (SgN  >tagamine !12_S	et	f	\N
143127	tagamine	"tagamine %taga  )MINE_vS  <tagama ;27_V	et	f	\N
143130	äinud	?äinud =äinu  (PlN  >äinu !16_S	et	f	\N
143131	äinud	?äinud =äinu  (IndPrSg2  >äinuma !28_V	et	f	\N
143132	äinud	?äinud =äinud  (ID  >äinud !41_A	et	f	\N
143152	hollandi	?hollandi =hollandi  (SgN  >hollandi !01_S	et	f	\N
143153	hollandi	?hollandi =hollandi  (SgG  >hollandi !01_S	et	f	\N
143154	hollandi	?hollandi =hollandi  (SgG  >holland !02_S	et	f	\N
143155	hollandi	?hollandi =hollandi  (SgG  >hollant !22_S	et	f	\N
143156	hollandi	?hollandi =hollandi  (IndPrPs_  >hollantima !28_V	et	f	\N
143157	hollandi	?hollandi =hollandi  (ImpPrSg2  >hollantima !28_V	et	f	\N
143181	keukenhof	### keukenhof	et	f	\N
143185	amsterdaammi	?amsterdaammi =amsterdaammi  (SgG  >amsterdaamm !22_S	et	f	\N
143186	amsterdaammi	?amsterdaammi =amsterdaammi  (SgP  >amsterdaamm !22_S	et	f	\N
143187	amsterdaammi	?amsterdaammi =amsterdaammi  (SgAdt  >amsterdaamm !22_S	et	f	\N
143188	amsterdaammi	?amsterdaammi =amsterdaammi  (IndPrPs_  >amsterdaammima !28_V	et	f	\N
142937	otsest	otsest =otse  (PlEl  >ots !22_S	et	f	\N
142938	otsest	otsest =otses  (SgP  >otsene !10_A	et	f	\N
142939	sõnaraamatus	sõnaraamatus =atu  (SgIn  >sõna+raam+att !22_S	et	f	\N
142940	sõnaraamatus	sõnaraamatus =raamatu  (SgIn  >sõna+raamat !02_S	et	f	\N
142982	vaste	vaste =vaste  (SgN  >vaste !06_S	et	f	\N
142983	vaste	vaste =vaste  (SgG  >vaste !06_S	et	f	\N
142984	lähiantonüümia	lähiantonüümia =antonüümia  (SgN  >lähi+antonüümia !01_S	et	f	\N
142985	lähiantonüümia	lähiantonüümia =antonüümia  (SgG  >lähi+antonüümia !01_S	et	f	\N
143002	liiki	liiki =liiki  (SgP  >liik !22_S	et	f	\N
143003	liiki	liiki =liiki  (SgAdt  >liik !22_S	et	f	\N
143011	deiksis	?deiksis =deiksi  (SgIn  >deiks !22_S	et	f	\N
143012	deiksis	?deiksis =deiksi  (IndIpfSg3  >deiksima !28_V	et	f	\N
143013	deiksis	?deiksis =deiksis  (SgN  >deiksis !09_S	et	f	\N
143028	deiktikutel	?deiktikutel =deiktiku  (PlAd  >deiktiku !01_S	et	f	\N
143031	deiktikutel	?deiktikutel =deiktiku  (PlAd  >deiktik !02_S	et	f	\N
143032	deiktikutel	?deiktikutel =deiktikute  (PlAd  >deiktikutt !22_S	et	f	\N
143035	sidumisel	sidumisel =sidumise  (SgAd  >sidumine !12_S	et	f	\N
143036	sidumisel	"sidumine %sidu  )MINE_vS  <siduma ;28_V	et	f	\N
143042	nullist	nullist =nulli  (SgEl  >null !22_NS	et	f	\N
143043	nullist	"nulline %nulli  )NE_aA  <null ;22_N	et	f	\N
143050	selleteemaline	selleteemaline =maline  (SgN  >selle+tee+maline !10_A	et	f	\N
143051	selleteemaline	"selle+tee+maline %mali  )NE_aA  <selle+tee+mali ;17_S	et	f	\N
143052	selleteemaline	selleteemaline =teemaline  (SgN  >selle+teemaline !12_A	et	f	\N
143053	selleteemaline	"selle+teemaline %teema  )LINE_aA  <selle+teema ;16_S	et	f	\N
143070	korpuslingvistika	?korpuslingvistika =korpuslingvistika  (SgN  >korpuslingvistika !01_S	et	f	\N
143071	korpuslingvistika	?korpuslingvistika =korpuslingvistika  (SgG  >korpuslingvistika !01_S	et	f	\N
143072	korpuslingvistika	?korpuslingvistika =korpuslingvistika  (SgG  >korpuslingvistikas !02_A	et	f	\N
143082	märgendamise	märgendamise =märgendamise  (SgG  >märgendamine !12_S	et	f	\N
143084	märgendamise	"märgendamine %märgenda  )MINE_vS  <märgendama ;27_V	et	f	\N
143095	teadusministeeriumi	teadusministeeriumi =ministeeriumi  (SgG  >teadus+ministeerium !19~02_S	et	f	\N
143096	teadusministeeriumi	teadusministeeriumi =ministeeriumi  (SgP  >teadus+ministeerium !19_S	et	f	\N
143097	teadusministeeriumi	teadusministeeriumi =ministeeriumi  (SgAdt  >teadus+ministeerium !19_S	et	f	\N
143117	avalikkuse	avalikkuse =avalikkuse  (SgG  >avalikkus !11~09_S	et	f	\N
143118	avalikkuse	"avalikkus %avalikku  )US_aS  <avalik ;25_A	et	f	\N
143119	korraldamine	korraldamine =korraldamine  (SgN  >korraldamine !12_S	et	f	\N
143120	korraldamine	"korraldamine %korralda  )MINE_vS  <korraldama ;27_V	et	f	\N
143128	üleriigiliste	üleriigiliste =riigilis  (PlG  >üle+riigiline !12_A	et	f	\N
143129	üleriigiliste	"üle+riigiline %riigi  )LINE_aA  <üle+riik ;22_S	et	f	\N
143158	pillede	### pillede	et	f	\N
143159	pael	pael =pae  (SgAd  >paas !22_S	et	f	\N
143160	pael	pael =pael  (SgN  >pael !23?22_S	et	f	\N
143168	haagasse	?haagasse =haaga  (SgIll  >haaga !16_S	et	f	\N
143169	haagasse	?haagasse =haagasse  (SgG  >haagasne !02_A	et	f	\N
143170	haagasse	?haagasse =haagasse  (PlP  >haagass !22_S	et	f	\N
143171	rahvusvahelinses	?rahvusvahelinses =rahvusvahelinse  (SgIn  >rahvusvahelinne !02_A	et	f	\N
143172	rahvusvahelinses	?rahvusvahelinses =rahvusvahelinse  (PlIn  >rahvusvahelinss !22_S	et	f	\N
143174	rahvusvahelinses	?rahvusvahelinses =linse  (PlIn  >rahvus+vahe+linss !22_S	et	f	\N
143176	rahvusvahelinses	?rahvusvahelinses =linses  (SgN  >rahvus+vahe+linses !09_S	et	f	\N
143177	rahvusvahelinses	?rahvusvahelinses =vahelinse  (SgIn  >rahvus+vahelinne !02_A	et	f	\N
143178	rahvusvahelinses	?rahvusvahelinses =vahelinse  (PlIn  >rahvus+vahelinss !22_S	et	f	\N
143179	rahvusvahelinses	?rahvusvahelinses =svahelinse  (SgIn  >rahvu+svahelinne !02_A	et	f	\N
143180	rahvusvahelinses	?rahvusvahelinses =svahelinse  (PlIn  >rahvu+svahelinss !22_S	et	f	\N
143190	veekanaleid	veekanaleid =lei  (PlN  >vee+kana+lei !26_S	et	f	\N
143191	veekanaleid	veekanaleid =lei  (SgP  >vee+kana+lei !26_S	et	f	\N
143192	veekanaleid	veekanaleid =leid  (SgN  >vee+kana+leid !22_S	et	f	\N
143193	veekanaleid	veekanaleid =kanale  (PlP  >vee+kanal !02_S	et	f	\N
143203	hollandist	?hollandist =hollandi  (SgEl  >hollandi !01_S	et	f	\N
143204	hollandist	?hollandist =hollandi  (SgEl  >holland !02_S	et	f	\N
143205	hollandist	?hollandist =hollandi  (SgEl  >hollant !22_S	et	f	\N
143206	hollandist	?hollandist =hollandis  (SgP  >hollandis !11_S	et	f	\N
143207	hollandist	?hollandist =hollandist  (SgN  >hollandist !22_S	et	f	\N
143209	tutvustusena	tutvustusena =tutvustuse  (SgEs  >tutvustus !11_S	et	f	\N
143210	tutvustusena	"tutvustus %tutvusta  )US_vS  <tutvustama ;27_V	et	f	\N
143211	olinmis	?olinmis =olinmi  (SgIn  >olinmi !01_S	et	f	\N
143212	olinmis	?olinmis =olinmi  (SgIn  >olinm !22_S	et	f	\N
143213	olinmis	?olinmis =olinmi  (IndIpfSg3  >olinmima !28_V	et	f	\N
143214	olinmis	?olinmis =olinmis  (SgN  >olinmis !11_S	et	f	\N
143217	sobradega	?sobradega =sobra  (PlKom  >sobra !16_S	et	f	\N
143228	kraatermis	?kraatermis =kraatermi  (SgIn  >kraatermi !01_S	et	f	\N
143231	kraatermis	?kraatermis =kraatermi  (SgIn  >kraaterm !22_S	et	f	\N
143232	kraatermis	?kraatermis =kraatermi  (IndIpfSg3  >kraatermima !28_V	et	f	\N
143026	isikuid	isikuid =uid  (SgN  >isik+uid !22_S	et	f	\N
143027	kasutamata	kasutamata =kasuta  (SupAb  >kasutama !27_V	et	f	\N
143029	kasutamata	kasutamata =kasutamata  (ID  >kasutamata !41_A	et	f	\N
143030	kasutamata	"kasutamata %kasuta  )MATA_vA  <kasutama ;27_V	et	f	\N
143033	mitmekülgselt	mitmekülgselt =külgse  (SgAbl  >mitme+külgne !02_A	et	f	\N
143034	mitmekülgselt	"mitme+külgselt %külgse  )LT_mD  <mitme+külgne ;02_A	et	f	\N
143056	renate	?renate =rena  (IndPrPl2  >renama !27_V	et	f	\N
143062	deiktikud	?deiktikud =deiktiku  (PlN  >deiktiku !01_S	et	f	\N
143063	deiktikud	?deiktikud =deiktiku  (PlN  >deiktik !02_S	et	f	\N
143064	deiktikud	?deiktikud =deiktiku  (IndPrSg2  >deiktikuma !27_V	et	f	\N
143065	selgitust	selgitust =selgitu  (SgEl  >selgitu !01_AS	et	f	\N
143066	selgitust	"selgitu %selgi  )TU1_vS  <selgima ;27_V	et	f	\N
143067	selgitust	selgitust =selgitus  (SgP  >selgitus !11_S	et	f	\N
143068	selgitust	"selgitus %selgita  )US_vS  <selgitama ;27_V	et	f	\N
143069	selgitust	"selgitus %selgi  )TUS1_aS  <selgima ;27_V	et	f	\N
143073	olemusest	olemusest =olemuse  (SgEl  >olemus !11_S	et	f	\N
143074	olemusest	olemusest =olemuses  (SgP  >olemusene !12_A	et	f	\N
143075	olemusest	"olemusene %olemuse  )NE_aA  <olemus ;11_S	et	f	\N
143080	käsitulust	käsitulust =tulu  (SgEl  >käsi+tulu !17_S	et	f	\N
143081	käsitulust	käsitulust =tulus  (SgP  >käsi+tulus !09_S	et	f	\N
143083	näol	näol =näo  (SgAd  >nägu !18_S	et	f	\N
143085	näol	näol =näol  (ID  >näol !41_K	et	f	\N
143099	htm-i	htm-i =htm  (SgG  >htm !xx_Q	et	f	\N
143100	htm-i	htm-i =htm  (SgP  >htm !xx_Q	et	f	\N
143101	htm-i	htm-i =htm  (SgAdt  >htm !xx_Q	et	f	\N
143112	teadlikkus	teadlikkus =teadlikkus  (SgN  >teadlikkus !11~09_S	et	f	\N
143113	teadlikkus	"teadlikkus %teadlikku  )US_aS  <teadlik ;25_A	et	f	\N
143140	hollandisse	?hollandisse =hollandi  (SgIll  >hollandi !01_S	et	f	\N
143141	hollandisse	?hollandisse =hollandi  (SgIll  >holland !02_S	et	f	\N
143142	hollandisse	?hollandisse =hollandi  (SgIll  >hollant !22_S	et	f	\N
143143	hollandisse	?hollandisse =hollandis  (SgAdt  >hollandis !11_S	et	f	\N
143144	hollandisse	?hollandisse =hollandisse  (SgG  >hollandisne !02_A	et	f	\N
143145	hollandisse	?hollandisse =hollandisse  (PlP  >hollandiss !22_S	et	f	\N
143227	tanapaeval	?tanapaeval =tanapaeva  (SgAd  >tanapaeva !16_S	et	f	\N
143229	tanapaeval	?tanapaeval =tanapaeval  (SgN  >tanapaeval !02_S	et	f	\N
143234	jarvsee	?jarvsee =jarvsee  (SgN  >jarvsee !26_S	et	f	\N
143235	jarvsee	?jarvsee =jarvsee  (SgG  >jarvsee !26_S	et	f	\N
143236	soitsivad	?soitsivad =soitsi  (IndPrPl3  >soitsima !28_V	et	f	\N
143237	soitsivad	?soitsivad =soitsiva  (PlN  >soitsiva !01_S	et	f	\N
143238	soitsivad	?soitsivad =soitsiva  (PlN  >soitsiv !02_A	et	f	\N
143262	vaneim	?vaneim =vaneim  (SgN  >vaneim !02_A	et	f	\N
143282	pisavalt	?pisavalt =pisava  (SgAbl  >pisava !01_S	et	f	\N
143283	pisavalt	?pisavalt =pisava  (SgAbl  >pisav !02_A	et	f	\N
143284	pisavalt	?pisavalt =pisavalt  (ID  >pisavalt !41_D	et	f	\N
143299	puudunud	puudunud =puudu  (PtsPtPs  >puuduma !27_V	et	f	\N
143300	puudunud	puudunud =puudunu  (PlN  >puudunu !01_S	et	f	\N
143301	puudunud	"puudunu %puudu  )NU_vS  <puuduma ;27_V	et	f	\N
143302	puudunud	puudunud =puudunud  (ID  >puudunud !41_A	et	f	\N
143303	puudunud	"puudunud %puudu  )NUD_vA  <puuduma ;27_V	et	f	\N
143304	arvada	?arvada =ada  (SgN  >arv+ada !17_S	et	f	\N
143305	arvada	?arvada =ada  (SgG  >arv+ada !17_S	et	f	\N
143306	arvada	?arvada =ada  (SgP  >arv+ada !17_S	et	f	\N
143311	bremeni	?bremeni =breme  (SgTer  >breme !16_S	et	f	\N
143312	bremeni	?bremeni =bremeni  (SgG  >bremen !02_S	et	f	\N
143313	rongisse	rongisse =rongi  (SgIll  >rong !22_S	et	f	\N
143314	rongisse	rongisse =rongi  (PlIll  >ronk !22_S	et	f	\N
143333	kalu	kalu =kalu  (SgN  >kalu !17_S	et	f	\N
143334	kalu	kalu =kalu  (SgG  >kalu !17_S	et	f	\N
143336	kalu	kalu =kalu  (SgP  >kalu !17_S	et	f	\N
143338	kalu	kalu =kalu  (PlP  >kala !17_S	et	f	\N
143339	tuttavaga	tuttavaga =tuttava  (SgKom  >tuttav !02_AS	et	f	\N
143340	tuttavaga	tuttavaga =ava  (SgKom  >tutt+ava !17_S	et	f	\N
143347	püüi	### püüi	et	f	\N
143354	eriri	?eriri =eriri  (SgN  >eriri !01_S	et	f	\N
143355	eriri	?eriri =eriri  (SgG  >eriri !01_S	et	f	\N
143356	eriri	?eriri =eriri  (SgG  >erir !02_S	et	f	\N
143370	kallimatest	kallimatest =kallima  (PlEl  >kallim !02_AS	et	f	\N
143371	kallimatest	"kallim %kalli  )M_cA  <kallis ;05_A	et	f	\N
143372	kallimatest	"kallim %kalli  )M_cA  <kallis ;07_A	et	f	\N
143373	kallimatest	kallimatest =mate  (SgEl  >kalli+mate !16_S	et	f	\N
143374	kallimatest	kallimatest =mate  (PlEl  >kalli+matt !22_SA	et	f	\N
143375	kallimatest	kallimatest =mates  (SgP  >kalli+matene !10_A	et	f	\N
143376	kallimatest	"kalli+matene %mate  )NE_aA  <kalli+mate ;16_S	et	f	\N
143434	öötasin	?öötasin =ööta  (IndIpfSg1  >öötama !27_V	et	f	\N
143435	öötasin	?öötasin =öötasin  (SgN  >öötasin !19_S	et	f	\N
143436	öötasin	?öötasin =tasin  (SgN  >öö+tasin !02_S	et	f	\N
143441	kasetti	?kasetti =kasetti  (SgN  >kasetti !01_S	et	f	\N
143442	kasetti	?kasetti =kasetti  (SgG  >kasetti !01_S	et	f	\N
143077	põhjalikumalt	"põhjalikum %põhjaliku  )M_cA  <põhjalik ;25_A	et	f	\N
143078	põhjalikumalt	põhjalikumalt =põhjalikumalt  (ID  >põhjalikumalt !41_D	et	f	\N
143079	põhjalikumalt	"põhjalikumalt %põhjaliku  )MALT_mD  <põhjalik ;25_A	et	f	\N
143086	käsituluse	käsituluse =tuluse  (SgG  >käsi+tulus !02_A	et	f	\N
143087	käsituluse	käsituluse =tuluse  (SgG  >käsi+tulus !09_S	et	f	\N
143098	htm	### htm	et	f	\N
143102	sihipärane	sihipärane =pärane  (SgN  >sihi+pärane !10_A	et	f	\N
143103	sihipärane	"sihi+pärane %pära  )NE_aA  <sihi+pära ;17_S	et	f	\N
143104	rakendamist	rakendamist =rakendamis  (SgP  >rakendamine !12_S	et	f	\N
143105	rakendamist	"rakendamine %rakenda  )MINE_vS  <rakendama ;27_V	et	f	\N
143121	tulemuslikkuse	tulemuslikkuse =tulemuslikkuse  (SgG  >tulemuslikkus !11~09_S	et	f	\N
143122	tulemuslikkuse	"tulemuslikkus %tulemuslikku  )US_aS  <tulemuslik ;25_A	et	f	\N
143123	kooskõla	kooskõla =kõla  (SgN  >koos+kõla !17_S	et	f	\N
143124	kooskõla	kooskõla =kõla  (SgG  >koos+kõla !17_S	et	f	\N
143125	kooskõla	kooskõla =kõla  (SgP  >koos+kõla !17_S	et	f	\N
143137	hollandiga	?hollandiga =hollandi  (SgKom  >hollandi !01_S	et	f	\N
143138	hollandiga	?hollandiga =hollandi  (SgKom  >holland !02_S	et	f	\N
143139	hollandiga	?hollandiga =hollandi  (SgKom  >hollant !22_S	et	f	\N
143146	plaanitud	plaanitud =plaani  (PtsPtIps  >plaanima !28_V	et	f	\N
143147	plaanitud	plaanitud =plaanitu  (PlN  >plaanitu !01_AS	et	f	\N
143148	plaanitud	"plaanitu %plaani  )TU1_vS  <plaanima ;28_V	et	f	\N
143149	plaanitud	"plaanitu %plaani  )TU2_kA  <plaan ;22_S	et	f	\N
143150	plaanitud	plaanitud =plaanitud  (ID  >plaanitud !41_A	et	f	\N
143151	plaanitud	"plaanitud %plaani  )TUD_vA  <plaanima ;28_V	et	f	\N
143161	gochi	?gochi =gochi  (SgN  >gochi !16_S	et	f	\N
143162	gochi	?gochi =gochi  (SgG  >gochi !16_S	et	f	\N
143163	gochi	?gochi =gochi  (SgG  >goch !22_S	et	f	\N
143164	gochi	?gochi =gochi  (SgP  >goch !22_S	et	f	\N
143165	gochi	?gochi =gochi  (SgAdt  >goch !22_S	et	f	\N
143166	gochi	?gochi =gochi  (IndPrPs_  >gochima !28_V	et	f	\N
143167	gochi	?gochi =gochi  (ImpPrSg2  >gochima !28_V	et	f	\N
143182	utrehti	?utrehti =utrehti  (ID  >utrehti !41_D	et	f	\N
143183	utrehti	?utrehti =utrehti  (SgP  >utreht !22_S	et	f	\N
143184	utrehti	?utrehti =utrehti  (SgAdt  >utreht !22_S	et	f	\N
143196	pankooke	?pankooke =pankooke  (SgN  >pankooke !12?10_S	et	f	\N
143197	pankooke	?pankooke =pankooke  (PlP  >pankook !22_S	et	f	\N
143208	arä	### arä	et	f	\N
143254	kohadma	?kohadma =kohadma  (SgN  >kohadma !01_S	et	f	\N
143255	kohadma	?kohadma =kohadma  (SgG  >kohadma !01_S	et	f	\N
143315	edahujutav	?edahujutav =edahuju  (PtsPrIps  >edahujuma !27_V	et	f	\N
143316	edahujutav	?edahujutav =edahujuta  (PtsPrPs  >edahujutama !27_V	et	f	\N
143317	edahujutav	?edahujutav =edahujutav  (SgN  >edahujutav !02_A	et	f	\N
143325	sõta	?sõta =sõta  (SgN  >sõta !16_S	et	f	\N
143326	sõta	?sõta =sõta  (SgG  >sõta !16_S	et	f	\N
143327	sõta	?sõta =sõta  (IndPrPs_  >sõtama !27_V	et	f	\N
143328	sõta	?sõta =sõta  (ImpPrSg2  >sõtama !27_V	et	f	\N
143335	püüa	püüa =püüa  (IndPrPs_  >püüdma !34_V	et	f	\N
143337	püüa	püüa =püüa  (ImpPrSg2  >püüdma !34_V	et	f	\N
143345	kiud	kiud =kiu  (PlN  >kiud !22_S	et	f	\N
143346	kiud	kiud =kiud  (SgN  >kiud !22_S	et	f	\N
143394	töölepingule	töölepingule =pingu  (SgAll  >tööle+ping !22_S	et	f	\N
143395	töölepingule	töölepingule =lepingu  (SgAll  >töö+leping !02_S	et	f	\N
143404	poolt-	poolt- =pool  (SgP  >pool !13_NS	et	f	\N
143405	poolt-	poolt- =poolt  (ID  >poolt !41_DK	et	f	\N
143412	riigasse	?riigasse =riiga  (SgIll  >riiga !16_S	et	f	\N
143413	riigasse	?riigasse =riigasse  (SgG  >riigasne !02_A	et	f	\N
143414	riigasse	?riigasse =riigasse  (PlP  >riigass !22_S	et	f	\N
143415	lõbustusparki	lõbustusparki =parki  (SgP  >lõbustus+park !22_S	et	f	\N
143416	lõbustusparki	lõbustusparki =parki  (SgAdt  >lõbustus+park !22_S	et	f	\N
143424	jalalihase	jalalihase =ihase  (SgG  >jalal+ihane !10_A	et	f	\N
143425	jalalihase	"jalal+ihane %iha  )NE_aA  <jalal+iha ;17_S	et	f	\N
143426	jalalihase	jalalihase =lihase  (SgG  >jala+lihas !09_S	et	f	\N
143427	jalalihase	jalalihase =lihase  (SgG  >jala+lihane !10_A	et	f	\N
143428	jalalihase	"jala+lihane %liha  )NE_aA  <jala+liha ;17_S	et	f	\N
143429	lamama	lamama =lama  (Sup  >lamama !27_V	et	f	\N
143430	lamama	lamama =lamama  (SgG  >lamam !02_S	et	f	\N
143439	montaziga	?montaziga =montazi  (SgKom  >montazi !01_S	et	f	\N
143460	gitari	?gitari =gitari  (SgN  >gitari !01_S	et	f	\N
143461	gitari	?gitari =gitari  (SgG  >gitari !01_S	et	f	\N
143462	gitari	?gitari =gitari  (SgG  >gitar !02_S	et	f	\N
143467	kokumit	?kokumit =kokumi  (SgP  >kokumi !01_S	et	f	\N
143468	kokumit	?kokumit =kokumi  (SgP  >kokum !02_S	et	f	\N
143472	reprodutseeritavus	reprodutseeritavus =reprodutseeritavus  (SgN  >reprodutseeritavus !11?09_S	et	f	\N
143474	reprodutseeritavus	"reprodutseeritavus %reprodutseeri  )TAVUS_aS  <reprodutseerima ;28_V	et	f	\N
143550	keelekümbluskooli	?keelekümbluskooli =keelekümbluskooli  (SgN  >keelekümbluskooli !16_S	et	f	\N
143551	keelekümbluskooli	?keelekümbluskooli =keelekümbluskooli  (SgG  >keelekümbluskooli !16_S	et	f	\N
143189	amsterdaammi	?amsterdaammi =amsterdaammi  (ImpPrSg2  >amsterdaammima !28_V	et	f	\N
143198	disco-pidu	disco-pidu =pidu  (SgN  >disco-pidu !17_S	et	f	\N
143199	disco-pidu	disco-pidu =pidu  (SgN  >disco-pidu !18_S	et	f	\N
143200	disco-pidu	disco-pidu =pidu  (SgG  >disco-pidu !17_S	et	f	\N
143201	disco-pidu	disco-pidu =pidu  (SgP  >disco-pidu !17_S	et	f	\N
143202	disco-pidu	disco-pidu =pidu  (SgP  >disco-pidu !18_S	et	f	\N
143215	sotsin	?sotsin =sotsi  (IndPrSg1  >sotsima !28_V	et	f	\N
143216	sotsin	?sotsin =sotsin  (SgN  >sotsin !02_S	et	f	\N
143221	vaatamis	?vaatamis =vaatami  (SgIn  >vaatami !01_S	et	f	\N
143222	vaatamis	?vaatamis =vaatami  (SgIn  >vaatam !02_A	et	f	\N
143223	vaatamis	?vaatamis =vaatamis  (SgN  >vaatamis !11_S	et	f	\N
143226	meteoriiti	meteoriiti =meteoriiti  (SgP  >meteoriit !22_S	et	f	\N
143230	meteoriiti	meteoriiti =meteoriiti  (SgAdt  >meteoriit !22_S	et	f	\N
143240	soitsime	?soitsime =soit  (IndIpfPl1  >soitma !34_V	et	f	\N
143241	soitsime	?soitsime =soitsi  (IndPrPl1  >soitsima !28_V	et	f	\N
143242	kullastasime	?kullastasime =kullasta  (IndIpfPl1  >kullastama !27_V	et	f	\N
143243	tuntuvaid	?tuntuvaid =tuntuva  (PlP  >tuntuva !01_S	et	f	\N
143244	tuntuvaid	?tuntuvaid =tuntuva  (PlP  >tuntuv !02_A	et	f	\N
143245	tuntuvaid	?tuntuvaid =tuntuvai  (PlN  >tuntuvai !26_S	et	f	\N
143246	tuntuvaid	?tuntuvaid =tuntuvai  (SgP  >tuntuvai !26_S	et	f	\N
143270	tada	?tada =tada  (SgN  >tada !17_S	et	f	\N
143271	tada	?tada =tada  (SgG  >tada !17_S	et	f	\N
143272	tada	?tada =tada  (SgP  >tada !17_S	et	f	\N
143273	tada	?tada =tada  (IndPrPs_  >tadama !27_V	et	f	\N
143274	tada	?tada =tada  (ImpPrSg2  >tadama !27_V	et	f	\N
143292	oppimiseta	?oppimiseta =oppimise  (SgAb  >oppimine !12_S	et	f	\N
143293	oppimiseta	?oppimiseta =oppimiseta  (IndPrPs_  >oppimisetama !27_V	et	f	\N
143294	oppimiseta	?oppimiseta =oppimiseta  (ImpPrSg2  >oppimisetama !27_V	et	f	\N
143329	kõkile	?kõkile =kõki  (SgAll  >kõki !16_S	et	f	\N
143330	kõkile	?kõkile =kõki  (SgAll  >kõkk !22_S	et	f	\N
143331	kõkile	?kõkile =kõkile  (IndPrPs_  >kõkilema !27_V	et	f	\N
143332	kõkile	?kõkile =kõkile  (ImpPrSg2  >kõkilema !27_V	et	f	\N
143341	melle	?melle =melle  (SgN  >melle !06_S	et	f	\N
143342	melle	?melle =melle  (PlP  >mell !22_S	et	f	\N
143343	melle	?melle =melle  (IndPrPs_  >mellema !30_V	et	f	\N
143344	melle	?melle =melle  (ImpPrSg2  >mellema !30_V	et	f	\N
143348	ühegi	ühegi =ühe  (SgG  >ükski !00_P	et	f	\N
143349	ühegi	ühegi =ühe  (SgN^  >ühe !06_S	et	f	\N
143350	ühegi	ühegi =ühe  (SgG^  >üks !22_NP	et	f	\N
143351	jõululinna	jõululinna =linna  (SgG  >jõulu+linn !22_S	et	f	\N
143352	jõululinna	jõululinna =linna  (SgP  >jõulu+linn !22_S	et	f	\N
143353	jõululinna	jõululinna =linna  (SgAdt  >jõulu+linn !22_S	et	f	\N
143361	jõulupüha	jõulupüha =püha  (SgN  >jõulu+püha !17_SA	et	f	\N
143362	jõulupüha	jõulupüha =püha  (SgG  >jõulu+püha !17_SA	et	f	\N
143363	jõulupüha	jõulupüha =püha  (SgP  >jõulu+püha !17_SA	et	f	\N
143368	tasulisel	tasulisel =tasulise  (SgAd  >tasuline !12_A	et	f	\N
143369	tasulisel	"tasuline %tasu  )LINE_aA  <tasu ;17_S	et	f	\N
143385	ärgi	?ärgi =ärgi  (ID  >ärgi !41_D	et	f	\N
143386	ärgi	?ärgi =ärgi  (SgG  >ärk !22_S	et	f	\N
143387	ärgi	?ärgi =ärgi  (SgP  >ärg !22_S	et	f	\N
143388	ärgi	?ärgi =ärgi  (SgAdt  >ärg !22_S	et	f	\N
143389	ärgi	?ärgi =ärgi  (IndPrPs_  >ärkima !28_V	et	f	\N
143390	ärgi	?ärgi =ärgi  (ImpPrSg2  >ärkima !28_V	et	f	\N
143392	komplekteerijana	komplekteerijana =komplekteerija  (SgEs  >komplekteerija !01_S	et	f	\N
143393	komplekteerijana	"komplekteerija %komplekteeri  )JA_vS  <komplekteerima ;28_V	et	f	\N
143437	vidio	?vidio =vidio  (SgN  >vidio !01_S	et	f	\N
143438	vidio	?vidio =vidio  (SgG  >vidio !01_S	et	f	\N
143440	filmistab	?filmistab =filmista  (IndPrSg3  >filmistama !27_V	et	f	\N
143463	püsivatest	püsivatest =püsiva  (PlEl  >püsiv !02_A	et	f	\N
143464	püsivatest	"püsiv %püsi  )V_vA  <püsima ;27_V	et	f	\N
143465	püsivatest	püsivatest =vate  (PlEl  >püsi+vatt !22_S	et	f	\N
143466	tähendusega	tähendusega =tähenduse  (SgKom  >tähendus !11_S	et	f	\N
143469	tähendusega	"tähendus %tähenda  )US_vS  <tähendama ;27_V	et	f	\N
143477	motiveeritus	motiveeritus =motiveeritu  (SgIn  >motiveeritu !01_S	et	f	\N
143478	motiveeritus	"motiveeritu %motiveeri  )TU1_vS  <motiveerima ;28_V	et	f	\N
143479	motiveeritus	motiveeritus =motiveeritus  (SgN  >motiveeritus !11_S	et	f	\N
143480	motiveeritus	"motiveeritus %motiveeri  )TUS1_aS  <motiveerima ;28_V	et	f	\N
143481	idiomaatilisus	?idiomaatilisus =idiomaatilisu  (IndIpfSg3  >idiomaatilisuma !27_V	et	f	\N
143482	idiomaatilisus	?idiomaatilisus =idiomaatilisus  (SgN  >idiomaatilisus !11?09_S	et	f	\N
143483	käibel	käibel =käibe  (SgAd  >käive !06_S	et	f	\N
143484	käibel	käibel =käibel  (ID  >käibel !41_D	et	f	\N
143485	nimetust	nimetust =nimetu  (SgEl  >nimetu !01_A	et	f	\N
143486	nimetust	"nimetu %nime  )TU2_kA  <nimi ;20_S	et	f	\N
143487	nimetust	nimetust =nimetus  (SgP  >nimetus !11_S	et	f	\N
143488	nimetust	"nimetus %nimeta  )US_vS  <nimetama ;27_V	et	f	\N
143489	nimetust	"nimetus %nime  )TUS2_aS  <nimi ;20_S	et	f	\N
143490	nimetust	nimetust =tust  (SgN  >nime+tust !22_S	et	f	\N
143233	kraatermis	?kraatermis =kraatermis  (SgN  >kraatermis !11_S	et	f	\N
143250	soitsida	?soitsida =soitsi  (Inf  >soitsima !28_V	et	f	\N
143261	hiiumal	?hiiumal =hiiumal  (ID  >hiiumal !41_D	et	f	\N
143263	tahn	?tahn =tahn  (SgN  >tahn !22_S	et	f	\N
143264	loengutest	loengutest =loengu  (PlEl  >loeng !02_S	et	f	\N
143265	loengutest	loengutest =test  (SgN  >loengu+test !22_S	et	f	\N
143266	loengutest	loengutest =ute  (SgEl  >loeng+utt !22_S	et	f	\N
143267	loengutest	loengutest =ute  (PlEl  >loeng+utt !22_S	et	f	\N
143268	loengutest	loengutest =utes  (SgP  >loeng+utene !10_A	et	f	\N
143269	loengutest	"loeng+utene %ute  )NE_aA  <loeng+utt ;22_S	et	f	\N
143276	klappi	klappi =klappi  (SgP  >klapp !22_S	et	f	\N
143277	klappi	klappi =klappi  (SgAdt  >klapp !22_S	et	f	\N
143278	õppesta	?õppesta =õppesta  (SgN  >õppesta !01_S	et	f	\N
143279	õppesta	?õppesta =õppesta  (SgG  >õppesta !01_S	et	f	\N
143280	õppesta	?õppesta =õppesta  (IndPrPs_  >õppestama !27_V	et	f	\N
143281	õppesta	?õppesta =õppesta  (ImpPrSg2  >õppestama !27_V	et	f	\N
143287	omandatud	omandatud =omanda  (PtsPtIps  >omandama !27_V	et	f	\N
143288	omandatud	omandatud =omandatu  (PlN  >omandatu !01_S	et	f	\N
143289	omandatud	"omandatu %omanda  )TU1_vS  <omandama ;27_V	et	f	\N
143290	omandatud	omandatud =omandatud  (ID  >omandatud !41_A	et	f	\N
143291	omandatud	"omandatud %omanda  )TUD_vA  <omandama ;27_V	et	f	\N
143295	vastupidavus	vastupidavus =pidavus  (SgN  >vastu+pidavus !11_S	et	f	\N
143296	vastupidavus	"vastu+pidavus %pidava  )US_aS  <vastu+pidav ;02_A	et	f	\N
143297	õigustuse	õigustuse =õigustuse  (SgG  >õigustus !11_S	et	f	\N
143298	õigustuse	"õigustus %õigusta  )US_vS  <õigustama ;27_V	et	f	\N
143307	õigustamise	õigustamise =õigustamise  (SgG  >õigustamine !12_S	et	f	\N
143308	õigustamise	"õigustamine %õigusta  )MINE_vS  <õigustama ;27_V	et	f	\N
143309	katseks	katseks =katse  (SgTr  >katse !06_S	et	f	\N
143310	katseks	katseks =katse  (PlTr  >kats !22_S	et	f	\N
143319	saksakeelt	saksakeelt =kee  (SgAbl  >saksa+kesi !15_S	et	f	\N
143320	saksakeelt	saksakeelt =kee  (SgAbl  >saksa+kee !26_S	et	f	\N
143321	saksakeelt	saksakeelt =keel  (SgP  >saksa+keel !13_S	et	f	\N
143357	girljandid	?girljandid =girljandi  (PlN  >girljandi !01_S	et	f	\N
143358	girljandid	?girljandid =girljandi  (PlN  >girljand !02_S	et	f	\N
143359	girljandid	?girljandid =girljandi  (PlN  >girljant !22_S	et	f	\N
143360	girljandid	?girljandid =girljandi  (IndPrSg2  >girljantima !28_V	et	f	\N
143364	sõtsime	?sõtsime =sõtsi  (IndPrPl1  >sõtsima !28_V	et	f	\N
143365	seejarel	?seejarel =seejarel  (SgN  >seejarel !19_S	et	f	\N
143366	seejarel	?seejarel =jare  (SgAd  >see+jare !16_S	et	f	\N
143367	seejarel	?seejarel =jarel  (SgN  >see+jarel !02_S	et	f	\N
143377	teiseti	?teiseti =teise  (IndIpfIps  >teisema !28_V	et	f	\N
143378	teiseti	?teiseti =teiseti  (ID  >teiseti !41_D	et	f	\N
143379	teiseti	?teiseti =teiseti  (SgG  >teisett !22_S	et	f	\N
143380	teiseti	?teiseti =teiseti  (IndPrPs_  >teisettima !28_V	et	f	\N
143381	teiseti	?teiseti =teiseti  (ImpPrSg2  >teisettima !28_V	et	f	\N
143382	teiseti	?teiseti =eti  (SgN  >teis+eti !16_S	et	f	\N
143383	teiseti	?teiseti =eti  (SgG  >teis+eti !16_S	et	f	\N
143384	teiseti	?teiseti =eti  (SgG  >teis+ett !22_S	et	f	\N
143391	oktobrikuust	?oktobrikuust =oktobrikuu  (SgEl  >oktobrikuu !26_S	et	f	\N
143396	pingelist	pingelist =pingelis  (SgP  >pingeline !12_A	et	f	\N
143397	pingelist	"pingeline %pinge  )LINE_aA  <pinge ;06_S	et	f	\N
143406	käsile	käsile =käsi  (PlAll  >käsi !15_S	et	f	\N
143407	käsile	käsile =käsile  (ID  >käsile !41_D	et	f	\N
143408	veenis	veenis =veen  (IndIpfSg3  >veenma !33_V	et	f	\N
143409	veenis	veenis =veeni  (SgIn  >veen !22_S	et	f	\N
143410	oktoobrikuu	oktoobrikuu =kuu  (SgN  >oktoobri+kuu !26_S	et	f	\N
143411	oktoobrikuu	oktoobrikuu =kuu  (SgG  >oktoobri+kuu !26_S	et	f	\N
143419	proovinud	proovinud =proovi  (PtsPtPs  >proovima !28_V	et	f	\N
143420	proovinud	proovinud =proovinu  (PlN  >proovinu !01_S	et	f	\N
143421	proovinud	"proovinu %proovi  )NU_vS  <proovima ;28_V	et	f	\N
143422	proovinud	proovinud =proovinud  (ID  >proovinud !41_A	et	f	\N
143423	proovinud	"proovinud %proovi  )NUD_vA  <proovima ;28_V	et	f	\N
143450	üliõppilased	?üliõppilased =üliõppilase  (PlN  >üliõppilane !12_S	et	f	\N
143451	üliõppilased	?üliõppilased =õppilase  (PlN  >üli+õppilane !12_S	et	f	\N
143452	loomaaja	loomaaja =aja  (SgG  >looma+aeg !22_S	et	f	\N
143453	loomaaja	loomaaja =maaja  (SgN  >loo+maaja !16_S	et	f	\N
143454	loomaaja	loomaaja =maaja  (SgG  >loo+maaja !16_S	et	f	\N
143455	otsustaime	### otsustaime	et	f	\N
143456	pragu	pragu =pragu  (SgN  >pragu !18_S	et	f	\N
143457	pragu	pragu =pragu  (SgP  >pragu !18_S	et	f	\N
143499	tulenevaid	tulenevaid =tuleneva  (PlP  >tulenev !02_A	et	f	\N
143500	tulenevaid	"tulenev %tulene  )V_vA  <tulenema ;27_V	et	f	\N
143509	keelekümbliskooli	?keelekümbliskooli =keelekümbliskooli  (SgN  >keelekümbliskooli !16_S	et	f	\N
143510	keelekümbliskooli	?keelekümbliskooli =keelekümbliskooli  (SgG  >keelekümbliskooli !16_S	et	f	\N
143511	keelekümbliskooli	?keelekümbliskooli =keelekümbliskooli  (SgG  >keelekümbliskool !22_S	et	f	\N
143512	keelekümbliskooli	?keelekümbliskooli =keelekümbliskooli  (SgP  >keelekümbliskool !22_S	et	f	\N
143324	inglisekeele	inglisekeele =keele  (SgG  >inglise+keel !13_S	et	f	\N
143398	vahetuses	vahetuses =vahetuse  (SgIn  >vahetus !11_S	et	f	\N
143399	vahetuses	"vahetus %vaheta  )US_vS  <vahetama ;27_V	et	f	\N
143400	vahetuses	"vahetus %vahe  )TUS2_aS  <vahe ;16_S	et	f	\N
143401	vahetuses	vahetuses =use  (PlIn  >vahet+usk !22_S	et	f	\N
143402	ületunnitööd	ületunnitööd =töö  (PlN  >üle+tunni+töö !26_S	et	f	\N
143403	ületunnitööd	ületunnitööd =töö  (SgP  >üle+tunni+töö !26_S	et	f	\N
143417	bobisõidu	?bobisõidu =bobisõidu  (IndPrPs_  >bobisõiduma !27_V	et	f	\N
143418	bobisõidu	?bobisõidu =bobisõidu  (ImpPrSg2  >bobisõiduma !27_V	et	f	\N
143431	selgitused	selgitused =selgituse  (PlN  >selgitus !11_S	et	f	\N
143432	selgitused	"selgitus %selgita  )US_vS  <selgitama ;27_V	et	f	\N
143433	selgitused	"selgitus %selgi  )TUS1_aS  <selgima ;27_V	et	f	\N
143448	kahekümneaastased	kahekümneaastased =aastase  (PlN  >kahe+kümne+aastane !12~10_A	et	f	\N
143449	kahekümneaastased	"kahe+kümne+aastane %aasta  )NE_aA  <kahe+kümne+aasta ;01_S	et	f	\N
143458	õppealajuhataja	õppealajuhataja =juhataja  (SgN  >õppe+ala+juhataja !01_S	et	f	\N
143459	õppealajuhataja	õppealajuhataja =juhataja  (SgG  >õppe+ala+juhataja !01_S	et	f	\N
143496	teesist	teesist =teesi  (SgEl  >tees !22_S	et	f	\N
143497	teesist	teesist =teesis  (SgP  >teesis !09_S	et	f	\N
143498	teesist	teesist =si  (SgEl  >tee+si !26_S	et	f	\N
143507	magistritöö	magistritöö =töö  (SgN  >magistri+töö !26_S	et	f	\N
143508	magistritöö	magistritöö =töö  (SgG  >magistri+töö !26_S	et	f	\N
143538	sõnastamisel	sõnastamisel =sõnastamise  (SgAd  >sõnastamine !12_S	et	f	\N
143539	sõnastamisel	"sõnastamine %sõnasta  )MINE_vS  <sõnastama ;27_V	et	f	\N
143570	esituslaadi	esituslaadi =laadi  (SgG  >esitus+laad !22_S	et	f	\N
143571	esituslaadi	esituslaadi =laadi  (SgP  >esitus+laad !22_S	et	f	\N
143572	esituslaadi	esituslaadi =laadi  (SgAdt  >esitus+laad !22_S	et	f	\N
143575	püstitatud	püstitatud =püstita  (PtsPtIps  >püstitama !27_V	et	f	\N
143576	püstitatud	püstitatud =püstitatu  (PlN  >püstitatu !01_S	et	f	\N
143577	püstitatud	"püstitatu %püstita  )TU1_vS  <püstitama ;27_V	et	f	\N
143578	püstitatud	püstitatud =püstitatud  (ID  >püstitatud !41_A	et	f	\N
143579	püstitatud	"püstitatud %püstita  )TUD_vA  <püstitama ;27_V	et	f	\N
143587	lisast	lisast =lisa  (SgEl  >lisa !17_S	et	f	\N
143588	lisast	lisast =lisas  (SgP  >lisane !10_A	et	f	\N
143589	lisast	"lisane %lisa  )NE_aA  <lisa ;17_S	et	f	\N
143590	seonduva	seonduva =seonduva  (SgG  >seonduv !02_A	et	f	\N
143591	seonduva	"seonduv %seondu  )V_vA  <seonduma ;27_V	et	f	\N
143600	õpetamisvõtteid	?õpetamisvõtteid =õpetamisvõttei  (PlN  >õpetamisvõttei !26_S	et	f	\N
143601	õpetamisvõtteid	?õpetamisvõtteid =õpetamisvõttei  (SgP  >õpetamisvõttei !26_S	et	f	\N
143617	resultaati	resultaati =resultaati  (SgP  >resultaat !22_S	et	f	\N
143618	resultaati	resultaati =resultaati  (SgAdt  >resultaat !22_S	et	f	\N
143631	õppijad	õppijad =õppija  (PlN  >õppija !01_S	et	f	\N
143632	õppijad	"õppija %õppi  )JA_vS  <õppima ;28_V	et	f	\N
143645	sünonüümi-antonüümi-fraseologismi	sünonüümi-antonüümi-fraseologismi =fraseologismi  (SgG  >sünonüümi-antonüümi-fraseologism !22_S	et	f	\N
143646	sünonüümi-antonüümi-fraseologismi	sünonüümi-antonüümi-fraseologismi =fraseologismi  (SgP  >sünonüümi-antonüümi-fraseologism !22_S	et	f	\N
143647	sünonüümi-antonüümi-fraseologismi	sünonüümi-antonüümi-fraseologismi =fraseologismi  (SgAdt  >sünonüümi-antonüümi-fraseologism !22_S	et	f	\N
143648	vivian	?vivian =vivian  (SgN  >vivian !19_S	et	f	\N
143652	multikompetentsuse	multikompetentsuse =kompetentsuse  (SgG  >multi+kompetentsus !11~09_S	et	f	\N
143653	multikompetentsuse	"multi+kompetentsus %kompetentse  )US_aS  <multi+kompetentne ;02_A	et	f	\N
143656	krasheni	?krasheni =krashe  (SgTer  >krashe !06_S	et	f	\N
143657	krasheni	?krasheni =krasheni  (SgG  >krashen !02_S	et	f	\N
143658	monitooringu	?monitooringu =monitooringu  (SgG  >monitooring !02_S	et	f	\N
143659	monitooringu	?monitooringu =monitooringu  (IndPrPs_  >monitooringuma !27_V	et	f	\N
143660	monitooringu	?monitooringu =monitooringu  (ImpPrSg2  >monitooringuma !27_V	et	f	\N
143679	küsitav	küsitav =küsi  (PtsPrIps  >küsima !27_V	et	f	\N
143680	küsitav	küsitav =küsita  (PtsPrPs  >küsitama !27_V	et	f	\N
143681	küsitav	küsitav =küsitav  (SgN  >küsitav !02_AS	et	f	\N
143682	küsitav	"küsitav %küsi  )TAV_vAS  <küsima ;27_V	et	f	\N
143683	küsitav	"küsitav %küsita  )V_vA  <küsitama ;27_V	et	f	\N
143685	psühholingvistilist	psühholingvistilist =lingvistilis  (SgP  >psühho+lingvistiline !12_A	et	f	\N
143686	psühholingvistilist	"psühho+lingvistiline %lingvisti  )LINE_aA  <psühho+lingvist ;22_S	et	f	\N
143689	avamist	avamist =avamis  (SgP  >avamine !12_S	et	f	\N
143690	avamist	"avamine %ava  )MINE_vS  <avama ;27_V	et	f	\N
143695	tooduga	tooduga =toodu  (SgKom  >toodu !01_S	et	f	\N
143696	tooduga	"toodu %too  )TU1_vS  <tooma ;38_V	et	f	\N
143699	täpsustamist	täpsustamist =täpsustamis  (SgP  >täpsustamine !12_S	et	f	\N
143700	täpsustamist	"täpsustamine %täpsusta  )MINE_vS  <täpsustama ;27_V	et	f	\N
143701	omavaheline	omavaheline =vaheline  (SgN  >oma+vaheline !12_A	et	f	\N
143702	omavaheline	"oma+vaheline %vahe  )LINE_aA  <oma+vahe ;16_S	et	f	\N
143719	töökoda	töökoda =koda  (SgN  >töö+koda !18_S	et	f	\N
143443	kasetti	?kasetti =kasetti  (SgP  >kasett !22_S	et	f	\N
143444	kasetti	?kasetti =kasetti  (SgAdt  >kasett !22_S	et	f	\N
143445	kasetti	?kasetti =etti  (SgP  >kas+ett !22_S	et	f	\N
143446	kasetti	?kasetti =etti  (SgAdt  >kas+ett !22_S	et	f	\N
143447	kuj	### kuj	et	f	\N
143470	ülekantud	ülekantud =kan  (PtsPtIps  >üle+_kandma !34_V	et	f	\N
143471	ülekantud	ülekantud =kantu  (PlN  >üle+kantu !01_S	et	f	\N
143473	püsivus	püsivus =püsivus  (SgN  >püsivus !11_S	et	f	\N
143475	püsivus	"püsivus %püsi  )VUS_aS  <püsima ;27_V	et	f	\N
143476	püsivus	"püsivus %püsiva  )US_aS  <püsiv ;02_A	et	f	\N
143492	peaasjalikult	peaasjalikult =asjaliku  (SgAbl  >pea+asjalik !25_A	et	f	\N
143494	peaasjalikult	"pea+asjalikult %asjaliku  )LT_mD  <pea+asjalik ;25_A	et	f	\N
143501	levinumad	levinumad =levinuma  (PlN  >levinum !02_A	et	f	\N
143502	levinumad	"levinum %levi  )NUM_cA  <levima ;27_V	et	f	\N
143526	tavakoolis	tavakoolis =kooli  (SgIn  >tava+kool !22_S	et	f	\N
143527	tavakoolis	tavakoolis =kooli  (PlIn  >tava+kool !22_S	et	f	\N
143541	eraldanud	eraldanud =eralda  (PtsPtPs  >eraldama !27_V	et	f	\N
143542	eraldanud	eraldanud =eraldanu  (PlN  >eraldanu !01_S	et	f	\N
143543	eraldanud	"eraldanu %eralda  )NU_vS  <eraldama ;27_V	et	f	\N
143544	eraldanud	eraldanud =eraldanud  (ID  >eraldanud !41_A	et	f	\N
143545	eraldanud	"eraldanud %eralda  )NUD_vA  <eraldama ;27_V	et	f	\N
143546	tavakooli	tavakooli =kooli  (SgG  >tava+kool !22_S	et	f	\N
143547	tavakooli	tavakooli =kooli  (SgP  >tava+kool !22_S	et	f	\N
143548	tavakooli	tavakooli =kooli  (SgAdt  >tava+kool !22_S	et	f	\N
143549	tavakooli	tavakooli =kooli  (PlP  >tava+kool !22_S	et	f	\N
143567	ülesande	ülesande =ande  (SgG  >üles+anne !06_S	et	f	\N
143568	ülesande	ülesande =ande  (PlP  >üles+and !22_S	et	f	\N
143569	ülesande	ülesande =sande  (PlP  >üle+sand !22_S	et	f	\N
143573	veendumus	veendumus =veendumus  (SgN  >veendumus !11_S	et	f	\N
143574	veendumus	"veendumus %veendu  )MUS_vS  <veenduma ;27_V	et	f	\N
143592	kaheleheküljeline	kaheleheküljeline =küljeline  (SgN  >kahe+lehe+küljeline !12_A	et	f	\N
143593	kaheleheküljeline	"kahe+lehe+küljeline %külje  )LINE_aA  <kahe+lehe+külg ;22_S	et	f	\N
143594	keelekümblusest	keelekümblusest =kümbluse  (SgEl  >keele+kümblus !11~09_S	et	f	\N
143595	keelekümblusest	keelekümblusest =kümbluses  (SgP  >keele+kümblusene !12_A	et	f	\N
143596	keelekümblusest	"keele+kümblusene %kümbluse  )NE_aA  <keele+kümblus ;09_S	et	f	\N
143597	keelekümblusest	"keele+kümblusene %kümbluse  )NE_aA  <keele+kümblus ;11_S	et	f	\N
143607	kohane	kohane =kohane  (SgN  >kohane !10_A	et	f	\N
143608	kohane	"kohane %koha  )NE_aA  <koha ;17_S	et	f	\N
143609	kohane	"kohane %koha  )NE_aA  <koht ;22_S	et	f	\N
143610	kohane	kohane =kohane  (IndPrPs_  >kohanema !27_V	et	f	\N
143611	kohane	kohane =kohane  (ImpPrSg2  >kohanema !27_V	et	f	\N
143622	püütud	püütud =püü  (PtsPtIps  >püüdma !34_V	et	f	\N
143623	püütud	püütud =püütu  (PlN  >püütu !01_S	et	f	\N
143624	püütud	"püütu %püü  )TU1_vS  <püüdma ;34_V	et	f	\N
143625	püütud	"püütu %püü  )TU2_kA  <püü ;26_S	et	f	\N
143626	püütud	püütud =püütud  (ID  >püütud !41_A	et	f	\N
143627	püütud	"püütud %püü  )TUD_vA  <püüdma ;34_V	et	f	\N
143628	määrata	määrata =määra  (SgAb  >määr !22_S	et	f	\N
143629	määrata	määrata =määra  (Inf  >määrama !29_V	et	f	\N
143630	määrata	määrata =määra  (IndPrIps_  >määrama !29_V	et	f	\N
143667	lähima	lähima =lähima  (SgG  >lähim !02_A	et	f	\N
143668	lähima	"lähim %lähi  )IM_sA  <lähike ;12_A	et	f	\N
143669	tsooni	tsooni =tsooni  (SgG  >tsoon !22_S	et	f	\N
143670	tsooni	tsooni =tsooni  (SgP  >tsoon !22_S	et	f	\N
143671	tsooni	tsooni =tsooni  (SgAdt  >tsoon !22_S	et	f	\N
143677	vajalikkus	vajalikkus =vajalikkus  (SgN  >vajalikkus !11~09_S	et	f	\N
143678	vajalikkus	"vajalikkus %vajalikku  )US_aS  <vajalik ;25_A	et	f	\N
143697	järjekindlalt	järjekindlalt =kindla  (SgAbl  >järje+kindel !02_A	et	f	\N
143698	järjekindlalt	"järje+kindlalt %kindla  )LT_mD  <järje+kindel ;02_A	et	f	\N
143710	vastustes	vastustes =vastus  (PlIn  >vastus !09_S	et	f	\N
143711	vastustes	vastustes =us  (PlIn  >vast+uks !14_S	et	f	\N
143712	metssiga	metssiga =si  (SgKom  >mets+si !26_S	et	f	\N
143713	metssiga	metssiga =siga  (SgN  >mets+siga !18_SA	et	f	\N
143714	metssiga	metssiga =siga  (SgP  >mets+siga !18_SA	et	f	\N
143729	otstarbekuse	otstarbekuse =kuse  (SgG  >ots+tarbe+kusi !20_S	et	f	\N
143730	otstarbekuse	otstarbekuse =tarbekuse  (SgG  >ots+tarbekus !11_S	et	f	\N
143731	otstarbekuse	"ots+tarbekus %tarbeka  )US_aS  <ots+tarbekas ;02_A	et	f	\N
143736	foundations	?foundations =foundations  (SgN  >foundations !22_S	et	f	\N
143739	education	?education =education  (SgN  >education !19_S	et	f	\N
143740	education	?education =cation  (SgN  >edu+cation !19_S	et	f	\N
143745	buffalo	?buffalo =buffalo  (SgN  >buffalo !01_S	et	f	\N
143747	buffalo	?buffalo =buffalo  (SgG  >buffalo !01_S	et	f	\N
143769	vocabulary	### vocabulary	et	f	\N
143772	pedagogy	### pedagogy	et	f	\N
143774	university	### university	et	f	\N
143775	cook	?cook =cook  (SgN  >cook !22_S	et	f	\N
143778	teaching	?teaching =teaching  (SgN  >teaching !02_S	et	f	\N
143491	tarvitavad	tarvitavad =tarvita  (IndPrPl3  >tarvitama !27_V	et	f	\N
143493	tarvitavad	tarvitavad =tarvitava  (PlN  >tarvitav !02_A	et	f	\N
143495	tarvitavad	"tarvitav %tarvita  )V_vA  <tarvitama ;27_V	et	f	\N
143503	huvitavamad	huvitavamad =huvitavama  (PlN  >huvitavam !02_A	et	f	\N
143504	huvitavamad	"huvitavam %huvita  )VAM_cA  <huvitama ;27_V	et	f	\N
143505	huvitavamad	"huvitavam %huvitava  )M_cA  <huvitav ;02_A	et	f	\N
143506	xxxxxxxxxxx	### xxxxxxxxxxx	et	f	\N
143580	sõnastus	sõnastus =sõnastu  (IndIpfSg3  >sõnastuma !27_V	et	f	\N
143581	sõnastus	sõnastus =sõnastus  (SgN  >sõnastus !11_S	et	f	\N
143582	sõnastus	"sõnastus %sõnasta  )US_vS  <sõnastama ;27_V	et	f	\N
143598	õpetamise	õpetamise =õpetamise  (SgG  >õpetamine !12_S	et	f	\N
143599	õpetamise	"õpetamine %õpeta  )MINE_vS  <õpetama ;27_V	et	f	\N
143612	mõeldamatu	mõeldamatu =mõeldamatu  (SgN  >mõeldamatu !01_A	et	f	\N
143613	mõeldamatu	"mõeldamatu %mõel  )TAMATU_vA  <mõtlema ;30_V	et	f	\N
143614	mõeldamatu	mõeldamatu =mõeldamatu  (SgG  >mõeldamatu !01_A	et	f	\N
143619	ankeedi	ankeedi =ankeedi  (SgG  >ankeet !22_S	et	f	\N
143620	ankeedi	ankeedi =ankeedi  (IndPrPs_  >ankeetima !28_V	et	f	\N
143621	ankeedi	ankeedi =ankeedi  (ImpPrSg2  >ankeetima !28_V	et	f	\N
143637	kohatu	kohatu =kohatu  (SgN  >kohatu !01_AS	et	f	\N
143638	kohatu	"kohatu %koha  )TU1_vS  <kohama ;27_V	et	f	\N
143639	kohatu	"kohatu %koha  )TU1_vS  <kohtama ;29_V	et	f	\N
143640	kohatu	"kohatu %koha  )TU2_kA  <koha ;17_S	et	f	\N
143641	kohatu	"kohatu %koha  )TU2_kA  <koht ;22_S	et	f	\N
143642	kohatu	kohatu =kohatu  (SgG  >kohatu !01_AS	et	f	\N
143649	cooki	?cooki =cooki  (ID  >cooki !41_D	et	f	\N
143650	cooki	?cooki =cooki  (SgP  >cook !22_S	et	f	\N
143651	cooki	?cooki =cooki  (SgAdt  >cook !22_S	et	f	\N
143663	võgotski	?võgotski =võgotski  (SgG  >võgotsk !02_S	et	f	\N
143664	võgotski	?võgotski =võgotski  (IndPrPs_  >võgotskima !28_V	et	f	\N
143665	võgotski	?võgotski =võgotski  (ImpPrSg2  >võgotskima !28_V	et	f	\N
143666	võgotski	?võgotski =võgots  (SgN^  >võgots !02_S	et	f	\N
143672	kontseptsiooni	kontseptsiooni =kontseptsiooni  (SgG  >kontseptsioon !22_S	et	f	\N
143673	kontseptsiooni	kontseptsiooni =kontseptsiooni  (SgP  >kontseptsioon !22_S	et	f	\N
143674	kontseptsiooni	kontseptsiooni =kontseptsiooni  (SgAdt  >kontseptsioon !22_S	et	f	\N
143684	kognitiivset	?kognitiivset =kognitiivse  (SgP  >kognitiivne !02_A	et	f	\N
143691	võinuks	võinuks =või  (KndPtPs  >võima !37_V	et	f	\N
143692	võinuks	võinuks =võinu  (SgTr  >võinu !01_S	et	f	\N
143693	võinuks	"võinu %või  )NU_vS  <võima ;37_V	et	f	\N
143694	võinuks	võinuks =võinu  (SgTr  >võinu !06_S	et	f	\N
143715	määrsõna	### määrsõna	et	f	\N
143716	nimisõna	nimisõna =sõna  (SgN  >nimi+sõna !17_S	et	f	\N
143717	nimisõna	nimisõna =sõna  (SgG  >nimi+sõna !17_S	et	f	\N
143718	nimisõna	nimisõna =sõna  (SgP  >nimi+sõna !17_S	et	f	\N
143721	näitajad	näitajad =näitaja  (PlN  >näitaja !01_S	et	f	\N
143722	näitajad	"näitaja %näita  )JA_vS  <näitama ;29_V	et	f	\N
143723	näitajad	näitajad =aja  (PlN  >näit+aeg !22_S	et	f	\N
143742	fourth	?fourth =fourth  (SgN  >fourth !22_S	et	f	\N
143746	toronto	?toronto =toronto  (SgN  >toronto !16_S	et	f	\N
143748	toronto	?toronto =toronto  (SgG  >toronto !16_S	et	f	\N
143767	huckin	?huckin =hucki  (IndPrSg1  >huckima !28_V	et	f	\N
143768	huckin	?huckin =huckin  (SgN  >huckin !02_S	et	f	\N
143771	rationale	### rationale	et	f	\N
143785	study	### study	et	f	\N
143787	hausenberg	?hausenberg =hausenberg  (SgN  >hausenberg !22_S	et	f	\N
143790	türk	?türk =türk  (SgN  >türk !22_S	et	f	\N
143795	lightbown	?lightbown =lightbown  (SgN  >lightbown !22_S	et	f	\N
143802	languages	?languages =language  (PlIn  >languak !22_S	et	f	\N
143805	shira	?shira =shira  (SgN  >shira !17_S	et	f	\N
143806	shira	?shira =shira  (SgG  >shira !17_S	et	f	\N
143807	shira	?shira =shira  (SgP  >shira !17_S	et	f	\N
143809	shira	?shira =shira  (IndPrPs_  >shirama !27_V	et	f	\N
143811	shira	?shira =shira  (ImpPrSg2  >shirama !27_V	et	f	\N
143823	paul	?paul =pau  (SgAd  >pau !26_S	et	f	\N
143824	paul	?paul =paul  (SgN  >paul !22_S	et	f	\N
143829	margaret	### margaret	et	f	\N
143833	eds	?eds =eds  (SgN  >eds !22_S	et	f	\N
143834	nature	### nature	et	f	\N
143838	nj	### nj	et	f	\N
143859	piirkondi	piirkondi =piirkondi  (SgP  >piirkond !22_S	et	f	\N
143860	piirkondi	piirkondi =piirkondi  (SgAdt  >piirkond !22_S	et	f	\N
143861	piirkondi	piirkondi =piirkondi  (PlP  >piirkond !22_S	et	f	\N
143862	piirkondi	piirkondi =kondi  (SgG  >piir+kont !22_S	et	f	\N
143865	muukeelne	muukeelne =eelne  (SgN  >muuk+eelne !02_A	et	f	\N
143866	muukeelne	muukeelne =keelne  (SgN  >muu+keelne !02_A	et	f	\N
143867	keeleline	keeleline =keeleline  (SgN  >keeleline !12_A	et	f	\N
143870	keeleline	"keeleline %keele  )LINE_aA  <keel ;13_S	et	f	\N
143888	koodivahetus	koodivahetus =vahetu  (SgIn  >koodi+vahetu !01_A	et	f	\N
143889	koodivahetus	"koodi+vahetu %vahe  )TU2_kA  <koodi+vahe ;16_S	et	f	\N
143890	koodivahetus	koodivahetus =vahetus  (SgN  >koodi+vahetus !11_S	et	f	\N
143513	keelekümbliskooli	?keelekümbliskooli =keelekümbliskooli  (SgAdt  >keelekümbliskool !22_S	et	f	\N
143514	keelekümbliskooli	?keelekümbliskooli =keelekümbliskooli  (IndPrPs_  >keelekümbliskoolima !28_V	et	f	\N
143515	keelekümbliskooli	?keelekümbliskooli =keelekümbliskooli  (ImpPrSg2  >keelekümbliskoolima !28_V	et	f	\N
143516	keelekümbliskooli	?keelekümbliskooli =kümbliskooli  (SgN  >keele+kümbliskooli !16_S	et	f	\N
143517	keelekümbliskooli	?keelekümbliskooli =kümbliskooli  (SgG  >keele+kümbliskooli !16_S	et	f	\N
143518	keelekümbliskooli	?keelekümbliskooli =kümbliskooli  (SgG  >keele+kümbliskool !22_S	et	f	\N
143519	keelekümbliskooli	?keelekümbliskooli =kümbliskooli  (SgP  >keele+kümbliskool !22_S	et	f	\N
143520	keelekümbliskooli	?keelekümbliskooli =kümbliskooli  (SgAdt  >keele+kümbliskool !22_S	et	f	\N
143521	keelekümbliskooli	?keelekümbliskooli =ekümbliskooli  (SgN  >keel+ekümbliskooli !16_S	et	f	\N
143522	keelekümbliskooli	?keelekümbliskooli =ekümbliskooli  (SgG  >keel+ekümbliskooli !16_S	et	f	\N
143523	keelekümbliskooli	?keelekümbliskooli =ekümbliskooli  (SgG  >keel+ekümbliskool !22_S	et	f	\N
143524	keelekümbliskooli	?keelekümbliskooli =ekümbliskooli  (SgP  >keel+ekümbliskool !22_S	et	f	\N
143525	keelekümbliskooli	?keelekümbliskooli =ekümbliskooli  (SgAdt  >keel+ekümbliskool !22_S	et	f	\N
143528	keelekümbluskoolis	?keelekümbluskoolis =keelekümbluskooli  (SgIn  >keelekümbluskooli !16_S	et	f	\N
143529	keelekümbluskoolis	?keelekümbluskoolis =keelekümbluskooli  (SgIn  >keelekümbluskool !22_S	et	f	\N
143530	keelekümbluskoolis	?keelekümbluskoolis =keelekümbluskooli  (IndIpfSg3  >keelekümbluskoolima !28_V	et	f	\N
143531	keelekümbluskoolis	?keelekümbluskoolis =keelekümbluskoolis  (SgN  >keelekümbluskoolis !09_S	et	f	\N
143532	keelekümbluskoolis	?keelekümbluskoolis =kümbluskooli  (SgIn  >keele+kümbluskooli !16_S	et	f	\N
143533	keelekümbluskoolis	?keelekümbluskoolis =kümbluskooli  (SgIn  >keele+kümbluskool !22_S	et	f	\N
143534	keelekümbluskoolis	?keelekümbluskoolis =kümbluskoolis  (SgN  >keele+kümbluskoolis !09_S	et	f	\N
143535	keelekümbluskoolis	?keelekümbluskoolis =ekümbluskooli  (SgIn  >keel+ekümbluskooli !16_S	et	f	\N
143536	keelekümbluskoolis	?keelekümbluskoolis =ekümbluskooli  (SgIn  >keel+ekümbluskool !22_S	et	f	\N
143537	keelekümbluskoolis	?keelekümbluskoolis =ekümbluskoolis  (SgN  >keel+ekümbluskoolis !09_S	et	f	\N
143540	magistrant	?magistrant =magistrant  (SgN  >magistrant !22_S	et	f	\N
143583	sissejuhatusest	sissejuhatusest =juhatuse  (SgEl  >sisse+juhatus !11_S	et	f	\N
143584	sissejuhatusest	"sisse+juhatus %juha  )TUS2_aS  <sisse+juha ;17_S	et	f	\N
143585	sissejuhatusest	sissejuhatusest =juhatuses  (SgP  >sisse+juhatusene !12_A	et	f	\N
143586	sissejuhatusest	"sisse+juhatusene %juhatuse  )NE_aA  <sisse+juhatus ;11_S	et	f	\N
143605	käsitlevate	käsitlevate =käsitleva  (PlG  >käsitlev !02_A	et	f	\N
143606	käsitlevate	"käsitlev %käsitle  )V_vA  <käsitlema ;27_V	et	f	\N
143654	käsitlused	käsitlused =käsitluse  (PlN  >käsitlus !11_S	et	f	\N
143655	käsitlused	"käsitlus %käsitle  )US_vS  <käsitlema ;27_V	et	f	\N
143661	interaktsionistlik	?interaktsionistlik =interaktsionistlik  (SgN  >interaktsionistlik !25_A	et	f	\N
143662	interaktsionistlik	?interaktsionistlik =aktsionistlik  (SgN  >inter+aktsionistlik !25_A	et	f	\N
143675	napisõnaline	napisõnaline =sõnaline  (SgN  >napi+sõnaline !12_A	et	f	\N
143676	napisõnaline	"napi+sõnaline %sõna  )LINE_aA  <napi+sõna ;17_S	et	f	\N
143705	analüüsi	analüüsi =analüüsi  (SgG  >analüüs !22_S	et	f	\N
143706	analüüsi	analüüsi =analüüsi  (SgP  >analüüs !22_S	et	f	\N
143707	analüüsi	analüüsi =analüüsi  (SgAdt  >analüüs !22_S	et	f	\N
143708	analüüsi	analüüsi =analüüsi  (IndPrPs_  >analüüsima !28_V	et	f	\N
143709	analüüsi	analüüsi =analüüsi  (ImpPrSg2  >analüüsima !28_V	et	f	\N
143735	baker	?baker =baker  (SgN  >baker !02_S	et	f	\N
143741	bilingualism	?bilingualism =bilingualism  (SgN  >bilingualism !22_S	et	f	\N
143753	colin	?colin =coli  (IndPrSg1  >colima !27_V	et	f	\N
143754	colin	?colin =colin  (SgN  >colin !02_S	et	f	\N
143760	coady	### coady	et	f	\N
143764	thomas	?thomas =thoma  (SgIn  >thoma !17_S	et	f	\N
143765	thomas	?thomas =thoma  (IndIpfSg3  >thomama !27_V	et	f	\N
143766	thomas	?thomas =thomas  (SgN  >thomas !09_S	et	f	\N
143780	arnold	?arnold =arnold  (SgN  >arnold !22_S	et	f	\N
143786	anu-reet	?anu-reet =reet  (SgN  >anu-reet !22_S	et	f	\N
143791	mõõtmine	mõõtmine =mõõtmine  (SgN  >mõõtmine !12?10_S	et	f	\N
143792	mõõtmine	"mõõtmine %mõõt  )MINE_vS  <mõõtma ;34_V	et	f	\N
143813	smetana	?smetana =smeta  (SgEs  >smeta !16_S	et	f	\N
143819	baltimore	?baltimore =baltimore  (PlP  >baltimor !19_S	et	f	\N
143820	baltimore	?baltimore =more  (SgN  >balti+more !16_S	et	f	\N
143821	baltimore	?baltimore =more  (SgG  >balti+more !16_S	et	f	\N
143839	ingrid	?ingrid =ingri  (PlN  >ingri !01_S	et	f	\N
143840	ingrid	?ingrid =ingri  (PlN  >inger !02_S	et	f	\N
143842	ingrid	?ingrid =ingri  (IndPrSg2  >ingrima !28_V	et	f	\N
143850	saarso	?saarso =saarso  (SgN  >saarso !16_S	et	f	\N
143851	saarso	?saarso =saarso  (SgG  >saarso !16_S	et	f	\N
143852	silvi	?silvi =silvi  (SgN  >silvi !16_S	et	f	\N
143853	silvi	?silvi =silvi  (SgG  >silvi !16_S	et	f	\N
143854	silvi	?silvi =silvi  (SgG  >silv !22_S	et	f	\N
143855	silvi	?silvi =silvi  (SgP  >silv !22_S	et	f	\N
143856	silvi	?silvi =silvi  (SgAdt  >silv !22_S	et	f	\N
143552	keelekümbluskooli	?keelekümbluskooli =keelekümbluskooli  (SgG  >keelekümbluskool !22_S	et	f	\N
143553	keelekümbluskooli	?keelekümbluskooli =keelekümbluskooli  (SgP  >keelekümbluskool !22_S	et	f	\N
143554	keelekümbluskooli	?keelekümbluskooli =keelekümbluskooli  (SgAdt  >keelekümbluskool !22_S	et	f	\N
143555	keelekümbluskooli	?keelekümbluskooli =keelekümbluskooli  (IndPrPs_  >keelekümbluskoolima !28_V	et	f	\N
143556	keelekümbluskooli	?keelekümbluskooli =keelekümbluskooli  (ImpPrSg2  >keelekümbluskoolima !28_V	et	f	\N
143557	keelekümbluskooli	?keelekümbluskooli =kümbluskooli  (SgN  >keele+kümbluskooli !16_S	et	f	\N
143558	keelekümbluskooli	?keelekümbluskooli =kümbluskooli  (SgG  >keele+kümbluskooli !16_S	et	f	\N
143559	keelekümbluskooli	?keelekümbluskooli =kümbluskooli  (SgG  >keele+kümbluskool !22_S	et	f	\N
143560	keelekümbluskooli	?keelekümbluskooli =kümbluskooli  (SgP  >keele+kümbluskool !22_S	et	f	\N
143561	keelekümbluskooli	?keelekümbluskooli =kümbluskooli  (SgAdt  >keele+kümbluskool !22_S	et	f	\N
143562	keelekümbluskooli	?keelekümbluskooli =ekümbluskooli  (SgN  >keel+ekümbluskooli !16_S	et	f	\N
143563	keelekümbluskooli	?keelekümbluskooli =ekümbluskooli  (SgG  >keel+ekümbluskooli !16_S	et	f	\N
143564	keelekümbluskooli	?keelekümbluskooli =ekümbluskooli  (SgG  >keel+ekümbluskool !22_S	et	f	\N
143565	keelekümbluskooli	?keelekümbluskooli =ekümbluskooli  (SgP  >keel+ekümbluskool !22_S	et	f	\N
143566	keelekümbluskooli	?keelekümbluskooli =ekümbluskooli  (SgAdt  >keel+ekümbluskool !22_S	et	f	\N
143602	viies	viies =vii  (Ger  >viima !38_V	et	f	\N
143603	viies	viies =viie  (SgIn  >viis !14_N	et	f	\N
143604	viies	viies =viies  (SgN  >viies !02_O	et	f	\N
143615	lindistusteta	lindistusteta =lindistus  (PlAb  >lindistus !11_S	et	f	\N
143616	lindistusteta	"lindistus %lindista  )US_vS  <lindistama ;27_V	et	f	\N
143633	sõnavarast	sõnavarast =vara  (SgEl  >sõna+vara !17_S	et	f	\N
143634	sõnavarast	sõnavarast =varas  (SgP  >sõna+varas !07_S	et	f	\N
143635	sõnavarast	sõnavarast =varas  (SgP  >sõna+varane !10_A	et	f	\N
143636	sõnavarast	"sõna+varane %vara  )NE_aA  <sõna+vara ;17_S	et	f	\N
143643	omandamise	omandamise =omandamise  (SgG  >omandamine !12_S	et	f	\N
143644	omandamise	"omandamine %omanda  )MINE_vS  <omandama ;27_V	et	f	\N
143687	käsitluste	käsitluste =käsitlus  (PlG  >käsitlus !11_S	et	f	\N
143688	käsitluste	"käsitlus %käsitle  )US_vS  <käsitlema ;27_V	et	f	\N
143703	võrdlemine	võrdlemine =võrdlemine  (SgN  >võrdlemine !12_S	et	f	\N
143704	võrdlemine	"võrdlemine %võrdle  )MINE_vS  <võrdlema ;30_V	et	f	\N
143724	kahtluse	kahtluse =kahtluse  (SgG  >kahtlus !11~09_S	et	f	\N
143725	kahtluse	"kahtlus %kahtlase  )US_aS  <kahtlane ;12_A	et	f	\N
143726	valimi	?valimi =valimi  (SgN  >valimi !01_S	et	f	\N
143727	valimi	?valimi =valimi  (SgG  >valimi !01_S	et	f	\N
143728	valimi	?valimi =valimi  (SgG  >valim !02_A	et	f	\N
143744	clevedon	?clevedon =clevedon  (SgN  >clevedon !19_S	et	f	\N
143750	matters	?matters =matters  (SgN  >matters !02_S	et	f	\N
143751	matters	?matters =ers  (SgN  >matt+ers !22_S	et	f	\N
143755	paradiso	?paradiso =paradiso  (SgN  >paradiso !16_S	et	f	\N
143756	paradiso	?paradiso =paradiso  (SgG  >paradiso !16_S	et	f	\N
143757	paradiso	?paradiso =diso  (SgN  >para+diso !17~16_S	et	f	\N
143758	paradiso	?paradiso =diso  (SgG  >para+diso !17~16_S	et	f	\N
143759	paradiso	?paradiso =diso  (SgP  >para+diso !17_S	et	f	\N
143761	james	?james =jame  (SgIn  >jame !16_S	et	f	\N
143762	james	?james =jame  (IndIpfSg3  >jamema !27_V	et	f	\N
143763	james	?james =james  (SgN  >james !09_S	et	f	\N
143779	london	?london =london  (SgN  >london !02_S	et	f	\N
143784	introductions	?introductions =introductions  (SgN  >introductions !22_S	et	f	\N
143815	getting	?getting =getting  (SgN  >getting !02_S	et	f	\N
143828	mckeown	?mckeown =mckeown  (SgN  >mckeown !22_S	et	f	\N
143831	curtis	?curtis =curti  (IndIpfSg3  >curtima !28_V	et	f	\N
143832	curtis	?curtis =curtis  (ID  >curtis !41_DA	et	f	\N
143835	hillsdale	?hillsdale =hillsda  (SgAll  >hillsda !01_S	et	f	\N
143836	hillsdale	?hillsdale =hillsdale  (IndPrPs_  >hillsdalema !27_V	et	f	\N
143837	hillsdale	?hillsdale =hillsdale  (ImpPrSg2  >hillsdalema !27_V	et	f	\N
143863	rannut	?rannut =rannu  (SgP  >rannu !16_S	et	f	\N
143864	rannut	?rannut =rannut  (SgN  >rannut !02_S	et	f	\N
143871	omandamisele	omandamisele =omandamise  (SgAll  >omandamine !12_S	et	f	\N
143872	omandamisele	"omandamine %omanda  )MINE_vS  <omandama ;27_V	et	f	\N
143876	muukeelsete	muukeelsete =sete  (SgN  >muu+keel+sete !06_S	et	f	\N
143877	muukeelsete	muukeelsete =eelse  (PlG  >muuk+eelne !02_A	et	f	\N
143879	muukeelsete	muukeelsete =keelse  (PlG  >muu+keelne !02_A	et	f	\N
143918	philology	### philology	et	f	\N
143922	kaudviiteid	?kaudviiteid =kaudviitei  (PlN  >kaudviitei !26_S	et	f	\N
143923	kaudviiteid	?kaudviiteid =kaudviitei  (SgP  >kaudviitei !26_S	et	f	\N
143934	rannuti	?rannuti =rannu  (IndIpfIps  >rannuma !27_V	et	f	\N
143935	rannuti	?rannuti =rannuti  (SgN  >rannuti !01_S	et	f	\N
143936	rannuti	?rannuti =rannuti  (SgG  >rannuti !01_S	et	f	\N
143937	rannuti	?rannuti =rannuti  (SgG  >rannut !02_S	et	f	\N
143939	rannuti	?rannuti =rannuti  (SgG  >rannutt !22_S	et	f	\N
143942	rannuti	?rannuti =rannuti  (IndPrPs_  >rannuttima !28_V	et	f	\N
143944	rannuti	?rannuti =rannuti  (ImpPrSg2  >rannuttima !28_V	et	f	\N
143720	töökoda	töökoda =koda  (SgP  >töö+koda !18_S	et	f	\N
143732	pretendeerivas	pretendeerivas =pretendeeriva  (SgIn  >pretendeeriv !02_A	et	f	\N
143733	pretendeerivas	"pretendeeriv %pretendeeri  )V_vA  <pretendeerima ;28_V	et	f	\N
143734	pretendeerivas	pretendeerivas =tendeeriva  (SgIn  >pre+tendeeriv !02_A	et	f	\N
143737	bilingual	?bilingual =bilingua  (SgAd  >bilingua !01_S	et	f	\N
143738	bilingual	?bilingual =bilingual  (SgN  >bilingual !19_S	et	f	\N
143743	edition	?edition =edition  (SgN  >edition !19_S	et	f	\N
143749	sydney	### sydney	et	f	\N
143752	ltd	### ltd	et	f	\N
143770	acquisition	?acquisition =acquisition  (SgN  >acquisition !19_S	et	f	\N
143773	cambridge	### cambridge	et	f	\N
143776	university	### university	et	f	\N
143777	learning	?learning =learning  (SgN  >learning !02_S	et	f	\N
143788	ülle	ülle =ülle  (ID  >ülle !41_D	et	f	\N
143789	ülle	ülle =ülle  (PlP  >üll !22_S	et	f	\N
143793	kirjastus	kirjastus =kirjastus  (SgN  >kirjastus !11_S	et	f	\N
143794	kirjastus	"kirjastus %kirjasta  )US_vS  <kirjastama ;27_V	et	f	\N
143796	patsy	### patsy	et	f	\N
143797	spada	?spada =spada  (SgN  >spada !17_S	et	f	\N
143798	spada	?spada =spada  (SgG  >spada !17_S	et	f	\N
143799	spada	?spada =spada  (SgP  >spada !17_S	et	f	\N
143800	spada	?spada =spada  (IndPrPs_  >spadama !27_V	et	f	\N
143801	spada	?spada =spada  (ImpPrSg2  >spadama !27_V	et	f	\N
143816	instruction	?instruction =instruction  (SgN  >instruction !19~02_S	et	f	\N
143817	strengthens	?strengthens =strengthens  (SgN  >strengthens !02_S	et	f	\N
143818	comprehension	?comprehension =comprehension  (SgN  >comprehension !19~02_S	et	f	\N
143830	mary	### mary	et	f	\N
143843	kristi	?kristi =kristi  (SgN  >kristi !16_S	et	f	\N
143844	kristi	?kristi =kristi  (SgG  >kristi !16_S	et	f	\N
143845	kristi	?kristi =kristi  (SgG  >krist !22_S	et	f	\N
143846	kristi	?kristi =kristi  (SgP  >krist !22_S	et	f	\N
143847	kristi	?kristi =kristi  (SgAdt  >krist !22_S	et	f	\N
143848	kristi	?kristi =kristi  (IndPrPs_  >kristima !28_V	et	f	\N
143849	kristi	?kristi =kristi  (ImpPrSg2  >kristima !28_V	et	f	\N
143868	rikastamine	rikastamine =rikastamine  (SgN  >rikastamine !12_S	et	f	\N
143869	rikastamine	"rikastamine %rikasta  )MINE_vS  <rikastama ;27_V	et	f	\N
143874	zabrodskaja	?zabrodskaja =zabrodskaja  (SgN  >zabrodskaja !01_S	et	f	\N
143880	zabrodskaja	?zabrodskaja =zabrodskaja  (SgG  >zabrodskaja !01_S	et	f	\N
143882	zabrodskaja	?zabrodskaja =zabrodskaja  (SgG  >zabrodskajas !02_A	et	f	\N
143895	linguistics	?linguistics =linguistics  (SgN  >linguistics !22_S	et	f	\N
143899	finnish	?finnish =finnish  (SgN  >finnish !22_S	et	f	\N
143900	finnish	?finnish =ish  (SgN  >finn+ish !22_S	et	f	\N
143911	sepper	?sepper =sepper  (SgN  >sepper !02_S	et	f	\N
143917	department	?department =department  (SgN  >department !22_S	et	f	\N
143919	teemakohase	teemakohase =kohase  (SgG  >teema+kohane !10_A	et	f	\N
143920	teemakohase	"teema+kohane %koha  )NE_aA  <teema+koha ;17_S	et	f	\N
143921	teemakohase	"teema+kohane %koha  )NE_aA  <teema+koht ;22_S	et	f	\N
143930	zikejev	?zikejev =zikejev  (SgN  >zikejev !02_A	et	f	\N
143938	märkuste	märkuste =märkus  (PlG  >märkus !11~09_S	et	f	\N
143940	märkuste	märkuste =us  (PlG  >märk+uks !14_S	et	f	\N
143956	õpetamisel	õpetamisel =õpetamise  (SgAd  >õpetamine !12_S	et	f	\N
143957	õpetamisel	"õpetamine %õpeta  )MINE_vS  <õpetama ;27_V	et	f	\N
143963	oskussõna	oskussõna =sõna  (SgN  >oskus+sõna !17_S	et	f	\N
143964	oskussõna	oskussõna =sõna  (SgG  >oskus+sõna !17_S	et	f	\N
143965	oskussõna	oskussõna =sõna  (SgP  >oskus+sõna !17_S	et	f	\N
143979	kasutusega	kasutusega =kasutuse  (SgKom  >kasutus !11_S	et	f	\N
143980	kasutusega	"kasutus %kasuta  )US_vS  <kasutama ;27_V	et	f	\N
143982	kasutusega	"kasutus %kasu  )TUS2_aS  <kasu ;17_S	et	f	\N
143985	kõnelda	kõnelda =kõnel  (Inf  >kõnelema !31_V	et	f	\N
143986	kõnelda	kõnelda =kõnel  (IndPrIps_  >kõnelema !31_V	et	f	\N
144014	harjuta	harjuta =harju  (IndPrIps_  >harjuma !27_V	et	f	\N
144015	harjuta	harjuta =harjuta  (IndPrPs_  >harjutama !27_V	et	f	\N
144016	harjuta	harjuta =harjuta  (ImpPrSg2  >harjutama !27_V	et	f	\N
144028	asjakohast	asjakohast =koha  (SgEl  >asja+koha !17_S	et	f	\N
144029	asjakohast	asjakohast =koha  (SgEl  >asja+koht !22_S	et	f	\N
144030	asjakohast	asjakohast =kohas  (SgP  >asja+kohane !10_A	et	f	\N
144031	asjakohast	"asja+kohane %koha  )NE_aA  <asja+koha ;17_S	et	f	\N
144032	asjakohast	"asja+kohane %koha  )NE_aA  <asja+koht ;22_S	et	f	\N
144037	seletatud	seletatud =seleta  (PtsPtIps  >seletama !27_V	et	f	\N
144038	seletatud	seletatud =seletatu  (PlN  >seletatu !01_S	et	f	\N
144039	seletatud	"seletatu %seleta  )TU1_vS  <seletama ;27_V	et	f	\N
144040	seletatud	seletatud =seletatud  (ID  >seletatud !41_A	et	f	\N
144041	seletatud	"seletatud %seleta  )TUD_vA  <seletama ;27_V	et	f	\N
144042	tulenevad	tulenevad =tulene  (IndPrPl3  >tulenema !27_V	et	f	\N
144043	tulenevad	tulenevad =tuleneva  (PlN  >tulenev !02_A	et	f	\N
144044	tulenevad	"tulenev %tulene  )V_vA  <tulenema ;27_V	et	f	\N
144062	vastandlikud	vastandlikud =vastandliku  (PlN  >vastandlik !25_A	et	f	\N
143781	ellis	ellis =elli  (SgIn  >ell !22_S	et	f	\N
143782	ellis	ellis =elli  (PlIn  >ell !22_S	et	f	\N
143783	oxford	?oxford =oxford  (SgN  >oxford !22_S	et	f	\N
143803	learned	?learned =learne  (IndPrSg2  >learnema !27_V	et	f	\N
143804	lubliner	?lubliner =lubliner  (SgN  >lubliner !19_S	et	f	\N
143808	linda	?linda =linda  (SgN  >linda !16_S	et	f	\N
143810	linda	?linda =linda  (SgG  >linda !16_S	et	f	\N
143812	linda	?linda =linda  (IndPrPs_  >lindama !29_V	et	f	\N
143814	linda	?linda =linda  (ImpPrSg2  >lindama !29_V	et	f	\N
143822	md	### md	et	f	\N
143825	brookes	?brookes =brooke  (SgIn  >brooge !06_S	et	f	\N
143826	brookes	?brookes =brooke  (IndIpfSg3  >brookema !27_V	et	f	\N
143827	brookes	?brookes =brookes  (SgN  >brookes !09_S	et	f	\N
143841	krall	?krall =krall  (SgN  >krall !22_S	et	f	\N
143878	algkoolilaste	algkoolilaste =las  (PlG  >alg+kooli+laps !14_S	et	f	\N
143881	algkoolilaste	algkoolilaste =laste  (PlP  >alg+kooli+last !22_S	et	f	\N
143883	algkoolilaste	algkoolilaste =ilas  (PlG  >alg+kool+ilane !10_A	et	f	\N
143884	algkoolilaste	"alg+kool+ilane %ila  )NE_aA  <alg+kool+ila ;17_S	et	f	\N
143892	finest	?finest =fine  (SgEl  >fine !16_S	et	f	\N
143893	finest	?finest =fines  (SgP  >fines !09_S	et	f	\N
143894	finest	?finest =fines  (SgP  >finene !10_A	et	f	\N
143904	krista	?krista =krist  (Inf  >kristma !34_V	et	f	\N
143905	krista	?krista =krista  (SgN  >krista !16_S	et	f	\N
143906	krista	?krista =krista  (SgG  >krista !16_S	et	f	\N
143907	krista	?krista =krista  (IndPrPs_  >kristama !29_V	et	f	\N
143908	krista	?krista =krista  (ImpPrSg2  >kristama !29_V	et	f	\N
143924	võõrkeelsetele	võõrkeelsetele =sete  (PlAll  >võõr+keel+sett !22_S	et	f	\N
143925	võõrkeelsetele	võõrkeelsetele =keelse  (PlAll  >võõr+keelne !02_A	et	f	\N
143931	kaudviitelised	?kaudviitelised =kaudviitelise  (PlN  >kaudviiteline !12_A	et	f	\N
143949	eksitakse	eksitakse =eksi  (IndPrIps  >eksima !28_V	et	f	\N
143950	eksitakse	eksitakse =takse  (PlP  >eksi+taks !22_S	et	f	\N
143951	lausete	lausete =lause  (PlG  >lause !06_S	et	f	\N
143952	lausete	lausete =e  (PlG  >laus+esi !15_S	et	f	\N
143953	lausete	lausete =sete  (SgN  >lau+sete !06_S	et	f	\N
143960	sõnavormi	sõnavormi =vormi  (SgG  >sõna+vorm !22_S	et	f	\N
143961	sõnavormi	sõnavormi =vormi  (SgP  >sõna+vorm !22_S	et	f	\N
143962	sõnavormi	sõnavormi =vormi  (SgAdt  >sõna+vorm !22_S	et	f	\N
143969	täpsema	täpsema =täpsema  (SgG  >täpsem !02_A	et	f	\N
143970	täpsema	"täpsem %täpse  )M_cA  <täpne ;02_A	et	f	\N
143995	lubamatud	lubamatud =lubamatu  (PlN  >lubamatu !01_A	et	f	\N
143996	lubamatud	"lubamatu %luba  )MATU_vA  <lubama ;27_V	et	f	\N
144004	moodustamine	moodustamine =moodustamine  (SgN  >moodustamine !12_S	et	f	\N
144005	moodustamine	"moodustamine %moodusta  )MINE_vS  <moodustama ;27_V	et	f	\N
144006	umbisikulist	umbisikulist =isikulis  (SgP  >umb+isikuline !12_A	et	f	\N
144007	umbisikulist	"umb+isikuline %isiku  )LINE_aA  <umb+isik ;02_S	et	f	\N
144010	saavuta	saavuta =saavuta  (IndPrPs_  >saavutama !27_V	et	f	\N
144011	saavuta	saavuta =saavuta  (ImpPrSg2  >saavutama !27_V	et	f	\N
144021	tõrjunud	tõrjunud =tõrju  (PtsPtPs  >tõrjuma !28_V	et	f	\N
144022	tõrjunud	tõrjunud =tõrjunu  (PlN  >tõrjunu !01_S	et	f	\N
144023	tõrjunud	"tõrjunu %tõrju  )NU_vS  <tõrjuma ;28_V	et	f	\N
144024	tõrjunud	tõrjunud =tõrjunud  (ID  >tõrjunud !41_A	et	f	\N
144025	tõrjunud	"tõrjunud %tõrju  )NUD_vA  <tõrjuma ;28_V	et	f	\N
144026	järelduse	järelduse =järelduse  (SgG  >järeldus !11_S	et	f	\N
144027	järelduse	"järeldus %järelda  )US_vS  <järeldama ;27_V	et	f	\N
144047	käsitletud	käsitletud =käsitle  (PtsPtIps  >käsitlema !27_V	et	f	\N
144048	käsitletud	käsitletud =käsitletu  (PlN  >käsitletu !01_S	et	f	\N
144049	käsitletud	"käsitletu %käsitle  )TU1_vS  <käsitlema ;27_V	et	f	\N
144050	käsitletud	käsitletud =käsitletud  (ID  >käsitletud !41_A	et	f	\N
144051	käsitletud	"käsitletud %käsitle  )TUD_vA  <käsitlema ;27_V	et	f	\N
144058	nähtusi	nähtusi =nähtusi  (PlP  >nähtus !11_S	et	f	\N
144059	nähtusi	"nähtus %näh  )TUS1_aS  <nägema ;28_V	et	f	\N
144064	kakskeelsuse	kakskeelsuse =keelsuse  (SgG  >kaks+keelsus !11~09_S	et	f	\N
144065	kakskeelsuse	"kaks+keelsus %keelse  )US_aS  <kaks+keelne ;02_A	et	f	\N
144081	tõlkimisega	tõlkimisega =tõlkimise  (SgKom  >tõlkimine !12_S	et	f	\N
144082	tõlkimisega	"tõlkimine %tõlki  )MINE_vS  <tõlkima ;28_V	et	f	\N
144083	rikastamisega	rikastamisega =rikastamise  (SgKom  >rikastamine !12_S	et	f	\N
144084	rikastamisega	"rikastamine %rikasta  )MINE_vS  <rikastama ;27_V	et	f	\N
144087	sõnastatud	sõnastatud =sõnasta  (PtsPtIps  >sõnastama !27_V	et	f	\N
144088	sõnastatud	sõnastatud =sõnastatu  (PlN  >sõnastatu !01_S	et	f	\N
144089	sõnastatud	"sõnastatu %sõnasta  )TU1_vS  <sõnastama ;27_V	et	f	\N
144090	sõnastatud	sõnastatud =sõnastatud  (ID  >sõnastatud !41_A	et	f	\N
144091	sõnastatud	"sõnastatud %sõnasta  )TUD_vA  <sõnastama ;27_V	et	f	\N
144106	äärmiselt	äärmiselt =äärmise  (SgAbl  >äärmine !12?10_A	et	f	\N
144107	äärmiselt	äärmiselt =äärmiselt  (ID  >äärmiselt !41_D	et	f	\N
144108	äärmiselt	"äärmiselt %äärmise  )LT_mD  <äärmine ;10_A	et	f	\N
143857	silvi	?silvi =silvi  (IndPrPs_  >silvima !28_V	et	f	\N
143858	silvi	?silvi =silvi  (ImpPrSg2  >silvima !28_V	et	f	\N
143873	anastassia	?anastassia =anastassia  (SgN  >anastassia !01_S	et	f	\N
143875	anastassia	?anastassia =anastassia  (SgG  >anastassia !01_S	et	f	\N
143885	vene-eestieesti-vene	vene-eestieesti-vene =vene  (ID  >vene-eestieesti-vene !41_G	et	f	\N
143886	vene-eestieesti-vene	vene-eestieesti-vene =vene  (SgN  >vene-eestieesti-vene !16_S	et	f	\N
143887	vene-eestieesti-vene	vene-eestieesti-vene =vene  (SgG  >vene-eestieesti-vene !16_S	et	f	\N
143897	annual	?annual =annua  (SgAd  >annua !01_S	et	f	\N
143898	annual	?annual =annual  (SgN  >annual !19_S	et	f	\N
143901	estonian	?estonian =estonian  (SgN  >estonian !19_S	et	f	\N
143902	estonian	?estonian =nian  (SgN  >esto+nian !22_S	et	f	\N
143912	osakonna	osakonna =osakonna  (SgG  >osakond !22_S	et	f	\N
143913	osakonna	osakonna =konna  (SgG  >osa+konn !22_S	et	f	\N
143914	osakonna	osakonna =konna  (SgP  >osa+konn !22_S	et	f	\N
143915	osakonna	osakonna =konna  (SgAdt  >osa+konn !22_S	et	f	\N
143916	publications	?publications =publications  (SgN  >publications !22_S	et	f	\N
143928	ferdinand	?ferdinand =ferdinand  (SgN  >ferdinand !22_S	et	f	\N
143946	olemaolevad	?olemaolevad =olemaoleva  (PlN  >olemaolev !02_A	et	f	\N
143947	olemaolevad	?olemaolevad =olemaoleva  (PlN  >olemaoleva !16_S	et	f	\N
143971	üldsõnavara	üldsõnavara =vara  (SgN  >üld+sõna+vara !17_S	et	f	\N
143972	üldsõnavara	üldsõnavara =vara  (SgG  >üld+sõna+vara !17_S	et	f	\N
143973	üldsõnavara	üldsõnavara =vara  (SgP  >üld+sõna+vara !17_S	et	f	\N
143977	üldisema	üldisema =üldisema  (SgG  >üldisem !02_A	et	f	\N
143978	üldisema	"üldisem %üldise  )M_cA  <üldine ;10_A	et	f	\N
143981	üldisema	"üldisem %üldise  )M_cA  <üldine ;12_A	et	f	\N
143983	hääldust	hääldust =hääldus  (SgP  >hääldus !11~09_S	et	f	\N
143984	hääldust	"hääldus %häälda  )US_vS  <hääldama ;27_V	et	f	\N
143987	oskussõnavara	oskussõnavara =vara  (SgN  >oskus+sõna+vara !17_S	et	f	\N
143988	oskussõnavara	oskussõnavara =vara  (SgG  >oskus+sõna+vara !17_S	et	f	\N
143989	oskussõnavara	oskussõnavara =vara  (SgP  >oskus+sõna+vara !17_S	et	f	\N
143997	hulgaliselt	hulgaliselt =hulgalise  (SgAbl  >hulgaline !12_A	et	f	\N
143998	hulgaliselt	"hulgaline %hulga  )LINE_aA  <hulk ;22_S	et	f	\N
143999	hulgaliselt	hulgaliselt =hulgaliselt  (ID  >hulgaliselt !41_D	et	f	\N
144000	hulgaliselt	"hulgaliselt %hulga  )LISELT_mD  <hulk ;22_S	et	f	\N
144001	hulgaliselt	"hulgaliselt %hulgalise  )LT_mD  <hulgaline ;12_A	et	f	\N
144018	ärgitamiseks	ärgitamiseks =ärgitamise  (SgTr  >ärgitamine !12_S	et	f	\N
144020	ärgitamiseks	"ärgitamine %ärgita  )MINE_vS  <ärgitama ;27_V	et	f	\N
144033	õppe	õppe =õppe  (SgG  >õpe !06_S	et	f	\N
144034	õppe	õppe =õppe  (PlP  >õpp !22_S	et	f	\N
144052	formuleerimist	formuleerimist =formuleerimis  (SgP  >formuleerimine !12_S	et	f	\N
144053	formuleerimist	"formuleerimine %formuleeri  )MINE_vS  <formuleerima ;28_V	et	f	\N
144054	metoodika	metoodika =metoodika  (SgN  >metoodika !01_S	et	f	\N
144055	metoodika	metoodika =metoodika  (SgG  >metoodika !01_S	et	f	\N
144066	keelekümbleja	keelekümbleja =kümbleja  (SgN  >keele+kümbleja !01_S	et	f	\N
144067	keelekümbleja	keelekümbleja =kümbleja  (SgG  >keele+kümbleja !01_S	et	f	\N
144077	harjutustes	harjutustes =harjutus  (PlIn  >harjutus !11_S	et	f	\N
144078	harjutustes	"harjutus %harjuta  )US_vS  <harjutama ;27_V	et	f	\N
144079	harjutustes	"harjutus %harju  )TUS1_aS  <harjuma ;27_V	et	f	\N
144080	harjutustes	harjutustes =tuste  (PlIn  >harju+tust !22_S	et	f	\N
144102	xxxxxxxxxxxxxxxxxxx	### xxxxxxxxxxxxxxxxxxx	et	f	\N
144132	otsekohesussilmakirjalikkus	?otsekohesussilmakirjalikkus =otsekohesussilmakirjalikku  (IndIpfSg3  >otsekohesussilmakirjalikkuma !27_V	et	f	\N
144133	otsekohesussilmakirjalikkus	?otsekohesussilmakirjalikkus =otsekohesussilmakirjalikkus  (SgN  >otsekohesussilmakirjalikkus !11~09_S	et	f	\N
144135	otsekohesussilmakirjalikkus	?otsekohesussilmakirjalikkus =sussilmakirjalikkus  (SgN  >otse+kohe+sussilmakirjalikkus !11~09_S	et	f	\N
144136	otsekohesussilmakirjalikkus	?otsekohesussilmakirjalikkus =kohesussilmakirjalikkus  (SgN  >otse+kohesussilmakirjalikkus !11~09_S	et	f	\N
144137	otsekohesussilmakirjalikkus	?otsekohesussilmakirjalikkus =ekohesussilmakirjalikkus  (SgN  >ots+ekohesussilmakirjalikkus !11~09_S	et	f	\N
144144	sihtasutuse	sihtasutuse =asutuse  (SgG  >siht+asutus !11_S	et	f	\N
144146	sihtasutuse	"siht+asutus %asu  )TUS2_aS  <siht+asu ;17_S	et	f	\N
144156	teavitamine	?teavitamine =teavitamine  (SgN  >teavitamine !12_S	et	f	\N
144157	teavitamine	?teavitamine =teavitamine  (PlP  >teavitamin !19_S	et	f	\N
144158	toetamiseks	toetamiseks =toetamise  (SgTr  >toetamine !12_S	et	f	\N
144159	toetamiseks	"toetamine %toeta  )MINE_vS  <toetama ;27_V	et	f	\N
144170	tns	### tns	et	f	\N
144185	teadustöö	teadustöö =töö  (SgN  >teadus+töö !26_S	et	f	\N
144186	teadustöö	teadustöö =töö  (SgG  >teadus+töö !26_S	et	f	\N
144220	sõnastuse	sõnastuse =sõnastuse  (SgG  >sõnastus !11_S	et	f	\N
144221	sõnastuse	"sõnastus %sõnasta  )US_vS  <sõnastama ;27_V	et	f	\N
144242	küsitlust	küsitlust =küsitlus  (SgP  >küsitlus !11_S	et	f	\N
144243	küsitlust	"küsitlus %küsitle  )US_vS  <küsitlema ;27_V	et	f	\N
144268	lisainformatsiooni	lisainformatsiooni =informatsiooni  (SgG  >lisa+informatsioon !22_S	et	f	\N
143891	koodivahetus	"koodi+vahetus %vahe  )TUS2_aS  <koodi+vahe ;16_S	et	f	\N
143896	proceedings	### proceedings	et	f	\N
143903	conference	?conference =conference  (PlP  >conferenc !22_S	et	f	\N
143909	maria-maren	?maria-maren =mare  (IndPrSg1  >maria-marema !27_V	et	f	\N
143910	maria-maren	?maria-maren =maren  (SgN  >maria-maren !02_S	et	f	\N
143926	allikatele	allikatele =allika  (PlAll  >allikas !02_S	et	f	\N
143927	allikatele	allikatele =ate  (PlAll  >allik+att !22_S	et	f	\N
143929	saussure	### saussure	et	f	\N
143932	viidatakse	viidatakse =viida  (IndPrIps  >viitama !29_V	et	f	\N
143933	viidatakse	viidatakse =takse  (PlP  >viida+taks !22_S	et	f	\N
143941	lõviosa	lõviosa =osa  (SgN  >lõvi+osa !17_S	et	f	\N
143943	lõviosa	lõviosa =osa  (SgG  >lõvi+osa !17_S	et	f	\N
143945	lõviosa	lõviosa =osa  (SgP  >lõvi+osa !17_S	et	f	\N
143948	pro	### pro	et	f	\N
143974	markeerimata	markeerimata =markeeri  (SupAb  >markeerima !28_V	et	f	\N
143975	markeerimata	markeerimata =markeerimata  (ID  >markeerimata !41_A	et	f	\N
143976	markeerimata	"markeerimata %markeeri  )MATA_vA  <markeerima ;28_V	et	f	\N
143990	perekonnasnimi	?perekonnasnimi =perekonnasnimi  (SgG  >perekonnasnim !02_A	et	f	\N
143991	perekonnasnimi	?perekonnasnimi =snimi  (SgN  >pere+konna+snimi !17_S	et	f	\N
143992	perekonnasnimi	?perekonnasnimi =snimi  (SgG  >pere+konna+snimi !17_S	et	f	\N
143993	perekonnasnimi	?perekonnasnimi =snimi  (SgP  >pere+konna+snimi !17_S	et	f	\N
143994	perekonnasnimi	?perekonnasnimi =konnasnimi  (SgG  >pere+konnasnim !02_A	et	f	\N
144045	järeldused	järeldused =järelduse  (PlN  >järeldus !11_S	et	f	\N
144046	järeldused	"järeldus %järelda  )US_vS  <järeldama ;27_V	et	f	\N
144092	resümee	resümee =resümee  (SgN  >resümee !26_S	et	f	\N
144093	resümee	resümee =resümee  (SgG  >resümee !26_S	et	f	\N
144094	soovida	soovida =soovi  (Inf  >soovima !28_V	et	f	\N
144095	soovida	soovida =ida  (SgN  >soov+ida !17_S	et	f	\N
144096	soovida	soovida =ida  (SgG  >soov+ida !17_S	et	f	\N
144097	soovida	soovida =ida  (SgP  >soov+ida !17_S	et	f	\N
144110	osalisele	osalisele =osalise  (SgAll  >osaline !12_SA	et	f	\N
144111	osalisele	"osaline %osa  )LINE_aA  <osa ;17_S	et	f	\N
144117	määratlemisele	määratlemisele =määratlemise  (SgAll  >määratlemine !12_S	et	f	\N
144118	määratlemisele	"määratlemine %määratle  )MINE_vS  <määratlema ;27_V	et	f	\N
144184	vrdl	### vrdl	et	f	\N
144205	käsilehe	käsilehe =ehe  (SgN  >käsil+ehe !02_A	et	f	\N
144206	käsilehe	käsilehe =ehe  (SgN  >käsil+ehe !05_S	et	f	\N
144207	käsilehe	käsilehe =ehe  (SgN  >käsil+ehe !06_S	et	f	\N
144208	käsilehe	käsilehe =lehe  (SgG  >käsi+leht !22_S	et	f	\N
144224	ilmunute	ilmunute =ilmunu  (PlG  >ilmunu !01_S	et	f	\N
144225	ilmunute	"ilmunu %ilmu  )NU_vS  <ilmuma ;27_V	et	f	\N
144226	üllitiste	?üllitiste =üllitis  (PlG  >üllitis !11_S	et	f	\N
144227	üllitiste	?üllitiste =üllitiste  (PlP  >üllitist !22_S	et	f	\N
144228	koolijihid	?koolijihid =jihi  (PlN  >kooli+jihi !17_S	et	f	\N
144229	koolijihid	?koolijihid =ijihi  (PlN  >kool+ijihi !01_S	et	f	\N
144232	ettekujutuse	ettekujutuse =kujutuse  (SgG  >ette+kujutus !11_S	et	f	\N
144233	ettekujutuse	"ette+kujutus %kuju  )TUS2_aS  <ette+kuju ;17_S	et	f	\N
144247	suhtuvad	suhtuvad =suhtu  (IndPrPl3  >suhtuma !27_V	et	f	\N
144248	suhtuvad	suhtuvad =suhtuva  (PlN  >suhtuv !02_A	et	f	\N
144249	suhtuvad	"suhtuv %suhtu  )V_vA  <suhtuma ;27_V	et	f	\N
144254	positiivsemalt	positiivsemalt =positiivsema  (SgAbl  >positiivsem !02_A	et	f	\N
144255	positiivsemalt	"positiivsem %positiivse  )M_cA  <positiivne ;02_A	et	f	\N
144256	positiivsemalt	positiivsemalt =positiivsemalt  (ID  >positiivsemalt !41_D	et	f	\N
144257	positiivsemalt	"positiivsemalt %positiivse  )MALT_mD  <positiivne ;02_A	et	f	\N
144266	rõhutasid	rõhutasid =rõhuta  (IndIpfSg2  >rõhutama !27_V	et	f	\N
144267	rõhutasid	rõhutasid =rõhuta  (IndIpfPl3  >rõhutama !27_V	et	f	\N
144273	sihtrühmi	sihtrühmi =rühmi  (SgG  >siht+rühm !22_S	et	f	\N
144274	sihtrühmi	sihtrühmi =rühmi  (SgP  >siht+rühm !22_S	et	f	\N
144275	sihtrühmi	sihtrühmi =rühmi  (SgAdt  >siht+rühm !22_S	et	f	\N
144276	sihtrühmi	sihtrühmi =rühmi  (PlP  >siht+rühm !22_S	et	f	\N
144302	infovajaduste	infovajaduste =duste  (PlP  >info+vaja+dust !22_S	et	f	\N
144303	infovajaduste	infovajaduste =vajadus  (PlG  >info+vajadus !11_S	et	f	\N
144304	sihtrühma	sihtrühma =rühma  (SgG  >siht+rühm !22_S	et	f	\N
144305	sihtrühma	sihtrühma =rühma  (SgP  >siht+rühm !22_S	et	f	\N
144306	sihtrühma	sihtrühma =rühma  (SgAdt  >siht+rühm !22_S	et	f	\N
144352	sisust	sisust =sisu  (SgEl  >sisu !17_S	et	f	\N
144353	sisust	sisust =sisus  (SgP  >sisus !09_S	et	f	\N
144354	sisust	"sisus %si  )SUS_aS  <si ;26_S	et	f	\N
144357	viimistlusse	viimistlusse =viimistlus  (SgAdt  >viimistlus !11_S	et	f	\N
144358	viimistlusse	"viimistlus %viimistle  )US_vS  <viimistlema ;27_V	et	f	\N
144379	müüte	müüte =müü  (IndPrPl2  >müüma !38_V	et	f	\N
144380	müüte	müüte =müüte  (PlP  >müüt !22_S	et	f	\N
144386	ebaselgus	ebaselgus =selgus  (SgN  >eba+selgus !11~09_S	et	f	\N
144387	ebaselgus	"eba+selgus %selge  )US_aS  <eba+selge ;01_A	et	f	\N
144388	uurimistulemuste	uurimistulemuste =muste  (PlP  >uurimis+tule+must !22_AS	et	f	\N
143954	sõnastuses	sõnastuses =sõnastuse  (SgIn  >sõnastus !11_S	et	f	\N
143955	sõnastuses	"sõnastus %sõnasta  )US_vS  <sõnastama ;27_V	et	f	\N
143958	aktiivsust	aktiivsust =aktiivsus  (SgP  >aktiivsus !11~09_S	et	f	\N
143959	aktiivsust	"aktiivsus %aktiivse  )US_aS  <aktiivne ;02_A	et	f	\N
143966	oskuskeele	oskuskeele =kee  (SgAll  >oskus+kesi !15_S	et	f	\N
143967	oskuskeele	oskuskeele =kee  (SgAll  >oskus+kee !26_S	et	f	\N
143968	oskuskeele	oskuskeele =keele  (SgG  >oskus+keel !13_S	et	f	\N
144002	võrdluskeelendeid	võrdluskeelendeid =ende  (PlP  >võrdlus+keel+enne !06_S	et	f	\N
144003	võrdluskeelendeid	võrdluskeelendeid =keelende  (PlP  >võrdlus+keelend !02_S	et	f	\N
144008	tegumoodi	tegumoodi =moodi  (SgP  >tegu+mood !22_S	et	f	\N
144009	tegumoodi	tegumoodi =moodi  (SgAdt  >tegu+mood !22_S	et	f	\N
144012	õpeta	õpeta =õpeta  (IndPrPs_  >õpetama !27_V	et	f	\N
144013	õpeta	õpeta =õpeta  (ImpPrSg2  >õpetama !27_V	et	f	\N
144017	sissejuhatuses	sissejuhatuses =juhatuse  (SgIn  >sisse+juhatus !11_S	et	f	\N
144019	sissejuhatuses	"sisse+juhatus %juha  )TUS2_aS  <sisse+juha ;17_S	et	f	\N
144035	edukamaid	edukamaid =edukama  (PlP  >edukam !02_A	et	f	\N
144036	edukamaid	"edukam %eduka  )M_cA  <edukas ;02_A	et	f	\N
144056	ümbritsevaid	ümbritsevaid =ümbritseva  (PlP  >ümbritsev !02_A	et	f	\N
144057	ümbritsevaid	"ümbritsev %ümbritse  )V_vA  <ümbritsema ;27_V	et	f	\N
144060	uuringutest	uuringutest =uuringu  (PlEl  >uuring !02_S	et	f	\N
144061	uuringutest	uuringutest =test  (SgN  >uuringu+test !22_S	et	f	\N
144098	esitatavatele	esitatavatele =esitatava  (PlAll  >esitatav !02_A	et	f	\N
144099	esitatavatele	"esitatav %esita  )TAV_vAS  <esitama ;27_V	et	f	\N
144100	nõuetele	nõuetele =nõue  (PlAll  >nõue !06_S	et	f	\N
144101	nõuetele	nõuetele =e  (PlAll  >nõu+esi !15_S	et	f	\N
144103	retsenseeritav	retsenseeritav =retsenseeri  (PtsPrIps  >retsenseerima !28_V	et	f	\N
144104	retsenseeritav	retsenseeritav =retsenseeritav  (SgN  >retsenseeritav !02_A	et	f	\N
144105	retsenseeritav	"retsenseeritav %retsenseeri  )TAV_vAS  <retsenseerima ;28_V	et	f	\N
144114	strateegiliste	strateegiliste =strateegilis  (PlG  >strateegiline !12_A	et	f	\N
144116	strateegiliste	"strateegiline %strateegi  )LINE_aA  <strateeg ;22_S	et	f	\N
144119	suletus	suletus =suletu  (SgIn  >suletu !01_AS	et	f	\N
144120	suletus	"suletu %sule  )TU1_vS  <sulgema ;28_V	et	f	\N
144121	suletus	"suletu %sule  )TU2_kA  <sulg ;22_S	et	f	\N
144122	suletus	suletus =suletus  (SgN  >suletus !11_S	et	f	\N
144123	suletus	"suletus %sule  )TUS1_aS  <sulgema ;28_V	et	f	\N
144124	suletus	"suletus %sule  )TUS2_aS  <sulg ;22_S	et	f	\N
144138	kaasatud	kaasatud =kaasa  (PtsPtIps  >kaasama !29_V	et	f	\N
144139	kaasatud	kaasatud =kaasatu  (PlN  >kaasatu !01_AS	et	f	\N
144140	kaasatud	"kaasatu %kaasa  )TU1_vS  <kaasama ;29_V	et	f	\N
144141	kaasatud	"kaasatu %kaasa  )TU2_kA  <kaasa ;16_S	et	f	\N
144142	kaasatud	kaasatud =kaasatud  (ID  >kaasatud !41_A	et	f	\N
144143	kaasatud	"kaasatud %kaasa  )TUD_vA  <kaasama ;29_V	et	f	\N
144145	kaasatud	kaasatud =atu  (PlN  >kaas+att !22_S	et	f	\N
144147	käivitatud	käivitatud =käivita  (PtsPtIps  >käivitama !27_V	et	f	\N
144148	käivitatud	käivitatud =käivitatu  (PlN  >käivitatu !01_S	et	f	\N
144149	käivitatud	"käivitatu %käivita  )TU1_vS  <käivitama ;27_V	et	f	\N
144150	käivitatud	käivitatud =käivitatud  (ID  >käivitatud !41_A	et	f	\N
144151	käivitatud	"käivitatud %käivita  )TUD_vA  <käivitama ;27_V	et	f	\N
144155	teavitustegevused	?teavitustegevused =teavitustegevuse  (PlN  >teavitustegevus !11?09_S	et	f	\N
144162	võimalikku	võimalikku =võimalikku  (SgP  >võimalik !25_A	et	f	\N
144165	võimalikku	võimalikku =võimalikku  (SgAdt  >võimalik !25_A	et	f	\N
144179	tutvumisel	tutvumisel =tutvumise  (SgAd  >tutvumine !12_S	et	f	\N
144180	tutvumisel	"tutvumine %tutvu  )MINE_vS  <tutvuma ;27_V	et	f	\N
144190	eesmärki	eesmärki =märki  (SgP  >ees+märk !22_S	et	f	\N
144191	eesmärki	eesmärki =märki  (SgAdt  >ees+märk !22_S	et	f	\N
144192	aktuaalsust	aktuaalsust =aktuaalsus  (SgP  >aktuaalsus !11~09_S	et	f	\N
144193	aktuaalsust	"aktuaalsus %aktuaalse  )US_aS  <aktuaalne ;02_A	et	f	\N
144200	referatiivne	?referatiivne =referatiivne  (SgN  >referatiivne !02_A	et	f	\N
144201	referatiivne	?referatiivne =referatiivne  (PlP  >referatiivn !22_S	et	f	\N
144211	mainimata	mainimata =maini  (SupAb  >mainima !28_V	et	f	\N
144212	mainimata	mainimata =mainimata  (ID  >mainimata !41_A	et	f	\N
144213	mainimata	"mainimata %maini  )MATA_vA  <mainima ;28_V	et	f	\N
144222	venekeelsetes	venekeelsetes =sete  (PlIn  >vene+keel+sett !22_S	et	f	\N
144223	venekeelsetes	venekeelsetes =keelse  (PlIn  >vene+keelne !02_A	et	f	\N
144234	keelekogukonna	keelekogukonna =konna  (SgG  >keele+kogu+konn !22_S	et	f	\N
144235	keelekogukonna	keelekogukonna =konna  (SgP  >keele+kogu+konn !22_S	et	f	\N
144236	keelekogukonna	keelekogukonna =konna  (SgAdt  >keele+kogu+konn !22_S	et	f	\N
144237	keelekogukonna	keelekogukonna =kogukonna  (SgG  >keele+kogukond !22_S	et	f	\N
144244	burlaka	?burlaka =burlaka  (SgN  >burlaka !01_S	et	f	\N
144245	burlaka	?burlaka =burlaka  (SgG  >burlaka !01_S	et	f	\N
144246	burlaka	?burlaka =burlaka  (SgG  >burlakas !02_A	et	f	\N
144258	vastav	vastav =vasta  (PtsPrPs  >vastama !29_V	et	f	\N
144259	vastav	vastav =vastav  (SgN  >vastav !02_A	et	f	\N
144063	vastandlikud	vastandlikud =andliku  (PlN  >vast+andlik !25_A	et	f	\N
144068	tavakooliõppija	tavakooliõppija =õppija  (SgN  >tava+kooli+õppija !01_S	et	f	\N
144069	tavakooliõppija	tavakooliõppija =õppija  (SgG  >tava+kooli+õppija !01_S	et	f	\N
144070	keelekümblusklassis	?keelekümblusklassis =keelekümblusklassi  (SgIn  >keelekümblusklass !22_S	et	f	\N
144071	keelekümblusklassis	?keelekümblusklassis =keelekümblusklassi  (IndIpfSg3  >keelekümblusklassima !28_V	et	f	\N
144072	keelekümblusklassis	?keelekümblusklassis =keelekümblusklassis  (SgN  >keelekümblusklassis !09_S	et	f	\N
144073	keelekümblusklassis	?keelekümblusklassis =kümblusklassi  (SgIn  >keele+kümblusklass !22_S	et	f	\N
144074	keelekümblusklassis	?keelekümblusklassis =kümblusklassis  (SgN  >keele+kümblusklassis !09_S	et	f	\N
144075	keelekümblusklassis	?keelekümblusklassis =ekümblusklassi  (SgIn  >keel+ekümblusklass !22_S	et	f	\N
144076	keelekümblusklassis	?keelekümblusklassis =ekümblusklassis  (SgN  >keel+ekümblusklassis !09_S	et	f	\N
144085	rikasta	rikasta =rikasta  (IndPrPs_  >rikastama !27_V	et	f	\N
144086	rikasta	rikasta =rikasta  (ImpPrSg2  >rikastama !27_V	et	f	\N
144112	kommunikatsiooni	kommunikatsiooni =kommunikatsiooni  (SgG  >kommunikatsioon !22_S	et	f	\N
144113	kommunikatsiooni	kommunikatsiooni =kommunikatsiooni  (SgP  >kommunikatsioon !22_S	et	f	\N
144115	kommunikatsiooni	kommunikatsiooni =kommunikatsiooni  (SgAdt  >kommunikatsioon !22_S	et	f	\N
144131	vaikelulisus	vaikelulisus =elulisus  (SgN  >vaik+elulisus !11?09_S	et	f	\N
144134	vaikelulisus	"vaik+elulisus %elu  )LISUS_aS  <vaik+elu ;17_S	et	f	\N
144152	kommunikatsiooniprogrammi	kommunikatsiooniprogrammi =programmi  (SgG  >kommunikatsiooni+programm !22_S	et	f	\N
144153	kommunikatsiooniprogrammi	kommunikatsiooniprogrammi =programmi  (SgP  >kommunikatsiooni+programm !22_S	et	f	\N
144154	kommunikatsiooniprogrammi	kommunikatsiooniprogrammi =programmi  (SgAdt  >kommunikatsiooni+programm !22_S	et	f	\N
144160	kommunikatsioonistrateegia	kommunikatsioonistrateegia =strateegia  (SgN  >kommunikatsiooni+strateegia !01_S	et	f	\N
144161	kommunikatsioonistrateegia	kommunikatsioonistrateegia =strateegia  (SgG  >kommunikatsiooni+strateegia !01_S	et	f	\N
144166	informeerimiseks	informeerimiseks =informeerimise  (SgTr  >informeerimine !12_S	et	f	\N
144167	informeerimiseks	"informeerimine %informeeri  )MINE_vS  <informeerima ;28_V	et	f	\N
144171	emori	?emori =emori  (SgN  >emori !01_S	et	f	\N
144172	emori	?emori =emori  (SgG  >emori !01_S	et	f	\N
144173	emori	?emori =emori  (SgG  >emor !02_S	et	f	\N
144176	lähemal	lähemal =lähema  (SgAd  >lähem !02_A	et	f	\N
144177	lähemal	"lähem %lähe  )M_cA  <lähike ;12_A	et	f	\N
144178	lähemal	lähemal =lähemal  (ID  >lähemal !41_D	et	f	\N
144181	nummerdamata	nummerdamata =nummerda  (SupAb  >nummerdama !27_V	et	f	\N
144182	nummerdamata	nummerdamata =nummerdamata  (ID  >nummerdamata !41_A	et	f	\N
144183	nummerdamata	"nummerdamata %nummerda  )MATA_vA  <nummerdama ;27_V	et	f	\N
144197	planeerimislähtekohti	planeerimislähtekohti =kohti  (SgP  >planeerimis+lähte+koht !22_S	et	f	\N
144198	planeerimislähtekohti	planeerimislähtekohti =kohti  (SgAdt  >planeerimis+lähte+koht !22_S	et	f	\N
144199	planeerimislähtekohti	planeerimislähtekohti =kohti  (PlP  >planeerimis+lähte+koht !22_S	et	f	\N
144202	loengukonspekti	loengukonspekti =konspekti  (SgG  >loengu+konspekt !22_S	et	f	\N
144203	loengukonspekti	loengukonspekti =konspekti  (SgP  >loengu+konspekt !22_S	et	f	\N
144204	loengukonspekti	loengukonspekti =konspekti  (SgAdt  >loengu+konspekt !22_S	et	f	\N
144209	põgusalt	põgusalt =põgusa  (SgAbl  >põgus !02_S	et	f	\N
144210	põgusalt	põgusalt =põgusalt  (ID  >põgusalt !41_D	et	f	\N
144214	artiklitepealkirjad	?artiklitepealkirjad =artiklitepealkirja  (PlN  >artiklitepealkirjas !02_A	et	f	\N
144215	artiklitepealkirjad	?artiklitepealkirjad =artiklitepealkirja  (PlN  >artiklitepealkirja !16_S	et	f	\N
144216	artiklitepealkirjad	?artiklitepealkirjad =tepealkirja  (PlN  >artikli+tepealkirjas !02_A	et	f	\N
144217	artiklitepealkirjad	?artiklitepealkirjad =tepealkirja  (PlN  >artikli+tepealkirja !16_S	et	f	\N
144218	eestikeelsete	eestikeelsete =sete  (SgN  >eesti+keel+sete !06_S	et	f	\N
144219	eestikeelsete	eestikeelsete =keelse  (PlG  >eesti+keelne !02_A	et	f	\N
144238	venekeelsete	venekeelsete =sete  (SgN  >vene+keel+sete !06_S	et	f	\N
144239	venekeelsete	venekeelsete =keelse  (PlG  >vene+keelne !02_A	et	f	\N
144240	järgnevana	järgnevana =järgneva  (SgEs  >järgnev !02_A	et	f	\N
144241	järgnevana	"järgnev %järgne  )V_vA  <järgnema ;27_V	et	f	\N
144271	vajadust	vajadust =vajadus  (SgP  >vajadus !11_S	et	f	\N
144272	vajadust	vajadust =dust  (SgN  >vaja+dust !22_S	et	f	\N
144277	rakendamisvõimalustele	?rakendamisvõimalustele =rakendamisvõimalus  (PlAll  >rakendamisvõimalus !11?09_S	et	f	\N
144278	rakendamisvõimalustele	?rakendamisvõimalustele =rakendamisvõimalustele  (IndPrPs_  >rakendamisvõimalustelema !36_V	et	f	\N
144279	rakendamisvõimalustele	?rakendamisvõimalustele =rakendamisvõimalustele  (ImpPrSg2  >rakendamisvõimalustelema !36_V	et	f	\N
144280	strateegi	strateegi =strateegi  (SgG  >strateeg !22_S	et	f	\N
144281	strateegi	strateegi =strateegi  (SgP  >strateeg !22_S	et	f	\N
144282	strateegi	strateegi =strateegi  (SgAdt  >strateeg !22_S	et	f	\N
144283	lähtuvad	lähtuvad =lähtu  (IndPrPl3  >lähtuma !27_V	et	f	\N
144284	lähtuvad	lähtuvad =lähtuva  (PlN  >lähtuv !02_A	et	f	\N
144285	lähtuvad	"lähtuv %lähtu  )V_vA  <lähtuma ;27_V	et	f	\N
144287	praktikasse	praktikasse =praktika  (SgIll  >praktika !01_S	et	f	\N
144288	praktikasse	praktikasse =praktikas  (SgAdt  >praktikane !12_A	et	f	\N
144109	äärmiselt	"äärmiselt %äärmise  )LT_mD  <äärmine ;12_A	et	f	\N
144125	muutusmeelsus	?muutusmeelsus =muutusmeelsu  (IndIpfSg3  >muutusmeelsuma !27_V	et	f	\N
144126	muutusmeelsus	?muutusmeelsus =muutusmeelsus  (SgN  >muutusmeelsus !11~09_S	et	f	\N
144127	muutusmeelsus	?muutusmeelsus =smeelsu  (SgIn  >muutu+smeelsu !01_S	et	f	\N
144128	muutusmeelsus	?muutusmeelsus =smeelsus  (SgN  >muutu+smeelsus !11~09_S	et	f	\N
144129	muutusmeelsus	?muutusmeelsus =tusmeelsu  (SgIn  >muu+tusmeelsu !01_S	et	f	\N
144130	muutusmeelsus	?muutusmeelsus =tusmeelsus  (SgN  >muu+tusmeelsus !11~09_S	et	f	\N
144163	lähenemise	lähenemise =lähenemise  (SgG  >lähenemine !12_S	et	f	\N
144164	lähenemise	"lähenemine %lähene  )MINE_vS  <lähenema ;27_V	et	f	\N
144168	sujuvaks	sujuvaks =sujuva  (SgTr  >sujuv !02_A	et	f	\N
144169	sujuvaks	"sujuv %suju  )V_vA  <sujuma ;27_V	et	f	\N
144174	bibliograafiast	bibliograafiast =bibliograafia  (SgEl  >bibliograafia !01_S	et	f	\N
144175	bibliograafiast	bibliograafiast =ast  (SgN  >bibliograafi+ast !22_S	et	f	\N
144187	lubamatu	lubamatu =lubamatu  (SgN  >lubamatu !01_A	et	f	\N
144188	lubamatu	"lubamatu %luba  )MATU_vA  <lubama ;27_V	et	f	\N
144189	lubamatu	lubamatu =lubamatu  (SgG  >lubamatu !01_A	et	f	\N
144194	lähteolukorrast	lähteolukorrast =korra  (SgEl  >lähte+olu+kord !22_S	et	f	\N
144195	lähteolukorrast	lähteolukorrast =korras  (SgP  >lähte+olu+korrane !10_A	et	f	\N
144196	lähteolukorrast	"lähte+olu+korrane %korra  )NE_aA  <lähte+olu+kord ;22_S	et	f	\N
144230	arutasid	arutasid =aruta  (IndIpfSg2  >arutama !27_V	et	f	\N
144231	arutasid	arutasid =aruta  (IndIpfPl3  >arutama !27_V	et	f	\N
144250	rahulikumalt	rahulikumalt =rahulikuma  (SgAbl  >rahulikum !02_A	et	f	\N
144251	rahulikumalt	"rahulikum %rahuliku  )M_cA  <rahulik ;25_A	et	f	\N
144252	rahulikumalt	rahulikumalt =rahulikumalt  (ID  >rahulikumalt !41_D	et	f	\N
144253	rahulikumalt	"rahulikumalt %rahuliku  )MALT_mD  <rahulik ;25_A	et	f	\N
144261	küsitletud	küsitletud =küsitle  (PtsPtIps  >küsitlema !27_V	et	f	\N
144262	küsitletud	küsitletud =küsitletu  (PlN  >küsitletu !01_S	et	f	\N
144263	küsitletud	"küsitletu %küsitle  )TU1_vS  <küsitlema ;27_V	et	f	\N
144264	küsitletud	küsitletud =küsitletud  (ID  >küsitletud !41_A	et	f	\N
144265	küsitletud	"küsitletud %küsitle  )TUD_vA  <küsitlema ;27_V	et	f	\N
144313	identiteeti	?identiteeti =identiteeti  (SgN  >identiteeti !16_S	et	f	\N
144314	identiteeti	?identiteeti =identiteeti  (SgG  >identiteeti !16_S	et	f	\N
144315	identiteeti	?identiteeti =identiteeti  (SgP  >identiteet !22_S	et	f	\N
144316	identiteeti	?identiteeti =identiteeti  (SgAdt  >identiteet !22_S	et	f	\N
144321	tundes	tundes =tund  (Ger  >tundma !34_V	et	f	\N
144323	tundes	tundes =tunde  (SgIn  >tunne !06_S	et	f	\N
144333	kaotamise	kaotamise =kaotamise  (SgG  >kaotamine !12_S	et	f	\N
144334	kaotamise	"kaotamine %kaota  )MINE_vS  <kaotama ;27_V	et	f	\N
144335	identiteedist	?identiteedist =identiteedi  (SgEl  >identiteedi !16_S	et	f	\N
144336	identiteedist	?identiteedist =identiteedi  (SgEl  >identiteet !22_S	et	f	\N
144337	identiteedist	?identiteedist =identiteedis  (SgP  >identiteedis !09_S	et	f	\N
144364	suurenenud	suurenenud =suurene  (PtsPtPs  >suurenema !27_V	et	f	\N
144365	suurenenud	suurenenud =suurenenu  (PlN  >suurenenu !01_S	et	f	\N
144366	suurenenud	"suurenenu %suurene  )NU_vS  <suurenema ;27_V	et	f	\N
144367	suurenenud	suurenenud =suurenenud  (ID  >suurenenud !41_A	et	f	\N
144368	suurenenud	"suurenenud %suurene  )NUD_vA  <suurenema ;27_V	et	f	\N
144374	eksitavaid	eksitavaid =eksitava  (PlP  >eksitav !02_A	et	f	\N
144375	eksitavaid	"eksitav %eksi  )TAV_vAS  <eksima ;28_V	et	f	\N
144376	eksitavaid	"eksitav %eksita  )V_vA  <eksitama ;27_V	et	f	\N
144384	rakendamise	rakendamise =rakendamise  (SgG  >rakendamine !12_S	et	f	\N
144385	rakendamise	"rakendamine %rakenda  )MINE_vS  <rakendama ;27_V	et	f	\N
144390	sünonüümia	sünonüümia =sünonüümia  (SgN  >sünonüümia !01_S	et	f	\N
144391	sünonüümia	sünonüümia =sünonüümia  (SgG  >sünonüümia !01_S	et	f	\N
144450	nakatumise	nakatumise =nakatumise  (SgG  >nakatumine !12_S	et	f	\N
144451	nakatumise	"nakatumine %nakatu  )MINE_vS  <nakatuma ;27_V	et	f	\N
144456	nakatuma	nakatuma =nakatu  (Sup  >nakatuma !27_V	et	f	\N
144457	nakatuma	nakatuma =nakatuma  (SgG  >nakatum !02_A	et	f	\N
144458	nakatuma	"nakatum %naka  )TUM1_cA  <nakkama ;29_V	et	f	\N
144460	nakka	nakka =nakka  (IndPrPs_  >nakkama !29_V	et	f	\N
144461	nakka	nakka =nakka  (ImpPrSg2  >nakkama !29_V	et	f	\N
144462	üksikute	üksikute =üksiku  (PlG  >üksik !02_A	et	f	\N
144463	üksikute	üksikute =ute  (SgG  >üksik+utt !22_S	et	f	\N
144497	viirust	viirust =viiru  (SgEl  >viirg !22_S	et	f	\N
144498	viirust	viirust =viiru  (SgEl  >viir !22_S	et	f	\N
144499	viirust	viirust =viirus  (SgP  >viirus !11~09_S	et	f	\N
144500	viirust	viirust =us  (SgP  >viir+uks !14_S	et	f	\N
144515	ringlusse	ringlusse =ringlus  (SgAdt  >ringlus !11_S	et	f	\N
144516	ringlusse	"ringlus %ringlase  )US_aS  <ringlane ;12_S	et	f	\N
144526	mitmenädalase	mitmenädalase =nädalase  (SgG  >mitme+nädalane !12_A	et	f	\N
144528	mitmenädalase	"mitme+nädalane %nädala  )NE_aA  <mitme+nädal ;02_S	et	f	\N
144560	hup	### hup	et	f	\N
144567	üksildaselt	üksildaselt =üksildase  (SgAbl  >üksildane !12_A	et	f	\N
144568	üksildaselt	üksildaselt =üksildaselt  (ID  >üksildaselt !41_D	et	f	\N
144260	vastav	"vastav %vasta  )V_vA  <vastama ;29_V	et	f	\N
144298	kestel	kestel =keste  (SgAd  >keste !06_S	et	f	\N
144300	kestel	kestel =keste  (PlAd  >kest !22_S	et	f	\N
144301	kestel	kestel =kestel  (ID  >kestel !41_K	et	f	\N
144309	läbivalt	läbivalt =läbiva  (SgAbl  >läbiv !02_A	et	f	\N
144310	läbivalt	"läbiv %läbi  )V_vA  <läbima ;27_V	et	f	\N
144311	läbivalt	läbivalt =läbivalt  (ID  >läbivalt !41_D	et	f	\N
144312	läbivalt	"läbivalt %läbi  )VALT_mD  <läbima ;27_V	et	f	\N
144326	suutmatuses	suutmatuses =suutmatuse  (SgIn  >suutmatus !11_S	et	f	\N
144327	suutmatuses	"suutmatus %suut  )MATUS_aS  <suutma ;34_V	et	f	\N
144330	mitte-eestlaste	mitte-eestlaste =eestlas  (PlG  >mitte-eestlane !12?10_S	et	f	\N
144331	mitte-eestlaste	mitte-eestlaste =las  (PlG  >mitte-eest+laps !14_S	et	f	\N
144332	mitte-eestlaste	mitte-eestlaste =laste  (PlP  >mitte-eest+last !22_S	et	f	\N
144345	temaatiliste	temaatiliste =temaatilis  (PlG  >temaatiline !12_A	et	f	\N
144346	temaatiliste	temaatiliste =atilis  (PlG  >tema+atiline !12_A	et	f	\N
144347	temaatiliste	"tema+atiline %ati  )LINE_aA  <tema+att ;22_S	et	f	\N
144348	lauseehitus	lauseehitus =ehitu  (SgIn  >lause+ehitu !01_AS	et	f	\N
144349	lauseehitus	lauseehitus =ehitus  (SgN  >lause+ehitus !11_S	et	f	\N
144355	keelelisse	keelelisse =keelelis  (SgAdt  >keeleline !12_A	et	f	\N
144356	keelelisse	"keeleline %keele  )LINE_aA  <keel ;13_S	et	f	\N
144369	põhjustanud	põhjustanud =põhjusta  (PtsPtPs  >põhjustama !27_V	et	f	\N
144370	põhjustanud	põhjustanud =põhjustanu  (PlN  >põhjustanu !01_S	et	f	\N
144371	põhjustanud	"põhjustanu %põhjusta  )NU_vS  <põhjustama ;27_V	et	f	\N
144372	põhjustanud	põhjustanud =põhjustanud  (ID  >põhjustanud !41_A	et	f	\N
144373	põhjustanud	"põhjustanud %põhjusta  )NUD_vA  <põhjustama ;27_V	et	f	\N
144381	tõrjuvat	tõrjuvat =tõrju  (KvtPrPs  >tõrjuma !28_V	et	f	\N
144382	tõrjuvat	tõrjuvat =tõrjuva  (SgP  >tõrjuv !02_A	et	f	\N
144383	tõrjuvat	"tõrjuv %tõrju  )V_vA  <tõrjuma ;28_V	et	f	\N
144402	majandusteaduskonna	majandusteaduskonna =konna  (SgG  >majandus+teadus+konn !22_S	et	f	\N
144403	majandusteaduskonna	majandusteaduskonna =konna  (SgP  >majandus+teadus+konn !22_S	et	f	\N
144404	majandusteaduskonna	majandusteaduskonna =konna  (SgAdt  >majandus+teadus+konn !22_S	et	f	\N
144405	majandusteaduskonna	majandusteaduskonna =teaduskonna  (SgG  >majandus+teaduskond !22_S	et	f	\N
144421	otsast	otsast =otsa  (SgEl  >ots !23?22_S	et	f	\N
144422	otsast	otsast =otsas  (SgP  >otsane !10_A	et	f	\N
144423	otsast	"otsane %otsa  )NE_aA  <ots ;22_S	et	f	\N
144424	otsast	"otsane %otsa  )NE_aA  <ots ;23_S	et	f	\N
144425	otsast	otsast =otsast  (ID  >otsast !41_DK	et	f	\N
144426	otsast	otsast =ast  (SgN  >ots+ast !22_S	et	f	\N
144441	läbinud	läbinud =läbi  (PtsPtPs  >läbima !27_V	et	f	\N
144442	läbinud	läbinud =läbinu  (PlN  >läbinu !01_S	et	f	\N
144443	läbinud	"läbinu %läbi  )NU_vS  <läbima ;27_V	et	f	\N
144444	läbinud	läbinud =läbinud  (ID  >läbinud !41_A	et	f	\N
144445	läbinud	"läbinud %läbi  )NUD_vA  <läbima ;27_V	et	f	\N
144448	linnugrippi	linnugrippi =grippi  (SgP  >linnu+gripp !22_S	et	f	\N
144449	linnugrippi	linnugrippi =grippi  (SgAdt  >linnu+gripp !22_S	et	f	\N
144454	nakatama	nakatama =naka  (SupIps  >nakkama !29_V	et	f	\N
144455	nakatama	nakatama =nakata  (Sup  >nakatama !27_V	et	f	\N
144459	h5n1	### h5n1	et	f	\N
144467	terves	terves =terve  (SgIn  >terve !01_AS	et	f	\N
144468	terves	terves =terve  (SgIn  >terve !06_AS	et	f	\N
144501	levimalevitama	?levimalevitama =levimalevita  (Sup  >levimalevitama !27_V	et	f	\N
144502	levimalevitama	?levimalevitama =levimalevitama  (SgG  >levimalevitam !02_A	et	f	\N
144503	levimalevitama	?levimalevitama =vitama  (SgG  >levi+male+vitam !02_A	et	f	\N
144504	levimalevitama	?levimalevitama =malevitama  (SgG  >levi+malevitam !02_A	et	f	\N
144538	dekabristi	dekabristi =dekabristi  (SgG  >dekabrist !22_S	et	f	\N
144539	dekabristi	dekabristi =dekabristi  (SgP  >dekabrist !22_S	et	f	\N
144540	dekabristi	dekabristi =dekabristi  (SgAdt  >dekabrist !22_S	et	f	\N
144555	maitsevad	maitsevad =maitse  (IndPrPl3  >maitsema !28_V	et	f	\N
144556	maitsevad	maitsevad =maitse  (IndPrPl3  >maitsma !32_V	et	f	\N
144557	maitsevad	maitsevad =maitseva  (PlN  >maitsev !02_A	et	f	\N
144558	maitsevad	"maitsev %maits  )V_vA  <maitsma ;32_V	et	f	\N
144559	maitsevad	"maitsev %maitse  )V_vA  <maitsema ;28_V	et	f	\N
144565	helistamine	helistamine =helistamine  (SgN  >helistamine !12_S	et	f	\N
144566	helistamine	"helistamine %helista  )MINE_vS  <helistama ;27_V	et	f	\N
144572	estisse	?estisse =esti  (SgIll  >esti !16_S	et	f	\N
144573	estisse	?estisse =esti  (SgIll  >est !22_S	et	f	\N
144574	estisse	?estisse =estisse  (SgG  >estisne !02_A	et	f	\N
144575	estisse	?estisse =estisse  (PlP  >estiss !22_S	et	f	\N
144576	tervist	tervist =tervis  (SgP  >tervis !09~11_S	et	f	\N
144577	tervist	tervist =tervist  (ID  >tervist !41_I	et	f	\N
144585	toitumist	toitumist =toitumi  (SgEl  >toitum !02_A	et	f	\N
144586	toitumist	"toitum %toi  )TUM2_cA  <toi ;26_S	et	f	\N
144587	toitumist	toitumist =toitumis  (SgP  >toitumine !12_S	et	f	\N
144588	toitumist	"toitumine %toitu  )MINE_vS  <toituma ;27_V	et	f	\N
144598	tarvimine	?tarvimine =tarvimine  (SgN  >tarvimine !12_S	et	f	\N
144269	lisainformatsiooni	lisainformatsiooni =informatsiooni  (SgP  >lisa+informatsioon !22_S	et	f	\N
144270	lisainformatsiooni	lisainformatsiooni =informatsiooni  (SgAdt  >lisa+informatsioon !22_S	et	f	\N
144286	infovajadustestleiab	?infovajadustestleiab =infovajadustestleiab  (SgN  >infovajadustestleiab !22_S	et	f	\N
144292	infovajadustestleiab	?infovajadustestleiab =dustestleiab  (SgN  >info+vaja+dustestleiab !22_S	et	f	\N
144293	infovajadustestleiab	?infovajadustestleiab =vajadustestleiab  (SgN  >info+vajadustestleiab !22_S	et	f	\N
144294	üleminekutemaatiliste	üleminekutemaatiliste =atilis  (PlG  >üle+mineku+tema+atiline !12_A	et	f	\N
144295	üleminekutemaatiliste	"üle+mineku+tema+atiline %ati  )LINE_aA  <üle+mineku+tema+att ;22_S	et	f	\N
144296	üleminekutemaatiliste	üleminekutemaatiliste =temaatilis  (PlG  >üle+mineku+temaatiline !12_A	et	f	\N
144307	endi	endi =end  (PlG  >enda !00_P	et	f	\N
144308	endi	endi =end  (PlG  >ise !00_P	et	f	\N
144324	tunnetamises	tunnetamises =tunnetamise  (SgIn  >tunnetamine !12_S	et	f	\N
144325	tunnetamises	"tunnetamine %tunneta  )MINE_vS  <tunnetama ;27_V	et	f	\N
144339	harjumaa	harjumaa =maa  (SgN  >harju+maa !26_S	et	f	\N
144340	harjumaa	harjumaa =maa  (SgG  >harju+maa !26_S	et	f	\N
144341	teemaliste	teemaliste =teemalis  (PlG  >teemaline !12_A	et	f	\N
144342	teemaliste	"teemaline %teema  )LINE_aA  <teema ;16_S	et	f	\N
144343	teemaliste	teemaliste =malis  (PlG  >tee+maline !10_A	et	f	\N
144344	teemaliste	"tee+maline %mali  )NE_aA  <tee+mali ;17_S	et	f	\N
144350	raskenda	raskenda =raskenda  (IndPrPs_  >raskendama !27_V	et	f	\N
144351	raskenda	raskenda =raskenda  (ImpPrSg2  >raskendama !27_V	et	f	\N
144363	pwerekonnanimi	?pwerekonnanimi =pwerekonnanimi  (SgG  >pwerekonnanim !02_A	et	f	\N
144377	toimumisest	toimumisest =toimumise  (SgEl  >toimumine !12_S	et	f	\N
144378	toimumisest	"toimumine %toimu  )MINE_vS  <toimuma ;27_V	et	f	\N
144392	sünonüümiast	sünonüümiast =sünonüümia  (SgEl  >sünonüümia !01_S	et	f	\N
144393	sünonüümiast	sünonüümiast =ast  (SgN  >sünonüümi+ast !22_S	et	f	\N
144394	refereerimise	refereerimise =refereerimise  (SgG  >refereerimine !12_S	et	f	\N
144395	refereerimise	"refereerimine %refereeri  )MINE_vS  <refereerima ;28_V	et	f	\N
144411	kahetse	kahetse =kahetse  (IndPrPs_  >kahetsema !27_V	et	f	\N
144412	kahetse	kahetse =kahetse  (ImpPrSg2  >kahetsema !27_V	et	f	\N
144416	ülikoolois	?ülikoolois =ülikooloi  (SgIn  >ülikooloi !26_S	et	f	\N
144417	ülikoolois	?ülikoolois =ülikoolois  (SgN  >ülikoolois !22_S	et	f	\N
144418	ülikoolois	?ülikoolois =ois  (SgN  >üli+kool+ois !22_S	et	f	\N
144419	ülikoolois	?ülikoolois =kooloi  (SgIn  >üli+kooloi !26_S	et	f	\N
144420	ülikoolois	?ülikoolois =koolois  (SgN  >üli+koolois !22_S	et	f	\N
144431	teaduskonda	teaduskonda =teaduskonda  (SgP  >teaduskond !22_S	et	f	\N
144432	teaduskonda	teaduskonda =teaduskonda  (SgAdt  >teaduskond !22_S	et	f	\N
144434	vanemust	vanemust =vanemus  (SgP  >vanemus !11_S	et	f	\N
144435	vanemust	"vanemus %vanema  )US_aS  <vanem ;02_AS	et	f	\N
144436	vanemust	vanemust =us  (SgP  >vanem+uks !14_S	et	f	\N
144466	üllar	?üllar =üllar  (SgN  >üllar !02_S	et	f	\N
144482	valmistuvad	valmistuvad =valmistu  (IndPrPl3  >valmistuma !27_V	et	f	\N
144483	valmistuvad	valmistuvad =valmistuva  (PlN  >valmistuv !02_A	et	f	\N
144484	valmistuvad	"valmistuv %valmistu  )V_vA  <valmistuma ;27_V	et	f	\N
144505	ulatuslikult	ulatuslikult =ulatusliku  (SgAbl  >ulatuslik !25_A	et	f	\N
144506	ulatuslikult	ulatuslikult =ulatuslikult  (ID  >ulatuslikult !41_D	et	f	\N
144507	ulatuslikult	"ulatuslikult %ulatusliku  )LT_mD  <ulatuslik ;25_A	et	f	\N
144508	kaasamakaasnema	?kaasamakaasnema =kaasamakaasnema  (SgG  >kaasamakaasnem !02_A	et	f	\N
144509	kaasamakaasnema	?kaasamakaasnema =makaasnema  (SgG  >kaasa+makaasnem !02_A	et	f	\N
144510	kaasamakaasnema	?kaasamakaasnema =amakaasnema  (SgG  >kaas+amakaasnem !02_A	et	f	\N
144517	esinemaesindama	?esinemaesindama =esinemaesinda  (Sup  >esinemaesindama !27_V	et	f	\N
144518	esinemaesindama	?esinemaesindama =esinemaesindama  (SgG  >esinemaesindam !02_A	et	f	\N
144519	esinemaesindama	?esinemaesindama =nemaesindama  (SgG  >esi+nemaesindam !02_A	et	f	\N
144527	kestvusega	kestvusega =kestvuse  (SgKom  >kestvus !11~09_S	et	f	\N
144529	kestvusega	"kestvus %kest  )VUS_aS  <kestma ;34_V	et	f	\N
144530	kestvusega	"kestvus %kestva  )US_aS  <kestev ;02_A	et	f	\N
144531	komandeeritud	komandeeritud =komandeeri  (PtsPtIps  >komandeerima !28_V	et	f	\N
144532	komandeeritud	komandeeritud =komandeeritu  (PlN  >komandeeritu !01_S	et	f	\N
144533	komandeeritud	"komandeeritu %komandeeri  )TU1_vS  <komandeerima ;28_V	et	f	\N
144534	komandeeritud	komandeeritud =komandeeritud  (ID  >komandeeritud !41_A	et	f	\N
144535	komandeeritud	"komandeeritud %komandeeri  )TUD_vA  <komandeerima ;28_V	et	f	\N
144536	komandeeritud	komandeeritud =eritu  (PlN  >kom+ande+eritu !01_AS	et	f	\N
144537	komandeeritud	"kom+ande+eritu %eri  )TU2_kA  <kom+ande+eri ;17_S	et	f	\N
144547	kummi	kummi =kummi  (ID  >kummi !41_D	et	f	\N
144548	kummi	kummi =kummi  (SgN  >kummi !16_S	et	f	\N
144549	kummi	kummi =kummi  (SgG  >kummi !16_S	et	f	\N
144550	kummi	kummi =kummi  (SgG  >kumm !22_S	et	f	\N
144551	kummi	kummi =kummi  (SgP  >kumm !22_S	et	f	\N
144552	kummi	kummi =kummi  (SgAdt  >kumm !22_S	et	f	\N
144553	kummi	kummi =kummi  (IndPrPs_  >kummima !28_V	et	f	\N
144554	kummi	kummi =kummi  (ImpPrSg2  >kummima !28_V	et	f	\N
144289	praktikasse	"praktikane %praktika  )NE_aA  <praktika ;01_S	et	f	\N
144290	lisades	lisades =lisa  (PlIn  >lisa !17_S	et	f	\N
144291	lisades	lisades =lisa  (Ger  >lisama !27_V	et	f	\N
144297	ärgitajaks	ärgitajaks =ärgitaja  (SgTr  >ärgitaja !01_S	et	f	\N
144299	ärgitajaks	"ärgitaja %ärgita  )JA_vS  <ärgitama ;27_V	et	f	\N
144317	ohustatud	ohustatud =ohusta  (PtsPtIps  >ohustama !27_V	et	f	\N
144318	ohustatud	ohustatud =ohustatu  (PlN  >ohustatu !01_S	et	f	\N
144319	ohustatud	"ohustatu %ohusta  )TU1_vS  <ohustama ;27_V	et	f	\N
144320	ohustatud	ohustatud =ohustatud  (ID  >ohustatud !41_A	et	f	\N
144322	ohustatud	"ohustatud %ohusta  )TUD_vA  <ohustama ;27_V	et	f	\N
144328	tundmist	tundmist =tundmis  (SgP  >tundmine !12?10_S	et	f	\N
144329	tundmist	"tundmine %tund  )MINE_vS  <tundma ;34_V	et	f	\N
144338	valim	?valim =valim  (SgN  >valim !02_A	et	f	\N
144359	tõsisemalt	tõsisemalt =tõsisema  (SgAbl  >tõsisem !02_A	et	f	\N
144360	tõsisemalt	"tõsisem %tõsise  )M_cA  <tõsine ;10_A	et	f	\N
144361	tõsisemalt	tõsisemalt =tõsisemalt  (ID  >tõsisemalt !41_D	et	f	\N
144362	tõsisemalt	"tõsisemalt %tõsise  )MALT_mD  <tõsine ;10_A	et	f	\N
144396	tsiteerimise	tsiteerimise =tsiteerimise  (SgG  >tsiteerimine !12_S	et	f	\N
144397	tsiteerimise	"tsiteerimine %tsiteeri  )MINE_vS  <tsiteerima ;28_V	et	f	\N
144406	tipikas	?tipikas =tipika  (SgIn  >tipika !01_S	et	f	\N
144407	tipikas	?tipikas =tipika  (SgIn  >tipikas !02_S	et	f	\N
144408	tipikas	?tipikas =tipikas  (SgN  >tipikas !02_S	et	f	\N
144409	üksendal	?üksendal =üksenda  (SgAd  >üksenda !01_S	et	f	\N
144410	üksendal	?üksendal =endal  (SgN  >üks+endal !02_S	et	f	\N
144427	õpi	õpi =õpi  (SgG  >õpp !22_S	et	f	\N
144428	õpi	õpi =õpi  (IndPrPs_  >õppima !28_V	et	f	\N
144429	õpi	õpi =õpi  (ImpPrSg2  >õppima !28_V	et	f	\N
144430	session	?session =session  (SgN  >session !19~02_S	et	f	\N
144433	rigikeelte	### rigikeelte	et	f	\N
144438	indale	?indale =inda  (SgAll  >inda !16_S	et	f	\N
144439	indale	?indale =indale  (IndPrPs_  >indalema !27_V	et	f	\N
144440	indale	?indale =indale  (ImpPrSg2  >indalema !27_V	et	f	\N
144474	ennetavalt	ennetavalt =ennetava  (SgAbl  >ennetav !02_A	et	f	\N
144475	ennetavalt	"ennetav %enneta  )V_vA  <ennetama ;27_V	et	f	\N
144476	ennetavalt	ennetavalt =ennetavalt  (ID  >ennetavalt !41_D	et	f	\N
144477	ennetavalt	"ennetavalt %enneta  )VALT_mD  <ennetama ;27_V	et	f	\N
144478	ennetavalt	ennetavalt =tava  (SgAbl  >enne+tava !17_S	et	f	\N
144488	tekkimatekitama	?tekkimatekitama =tekkimateki  (SupIps  >tekkimatekkima !28_V	et	f	\N
144489	tekkimatekitama	?tekkimatekitama =tekkimatekita  (Sup  >tekkimatekitama !27_V	et	f	\N
144490	tekkimatekitama	?tekkimatekitama =tekkimatekitama  (SgG  >tekkimatekitam !02_A	et	f	\N
144511	haigestumine	haigestumine =haigestumine  (SgN  >haigestumine !12_S	et	f	\N
144512	haigestumine	"haigestumine %haigestu  )MINE_vS  <haigestuma ;27_V	et	f	\N
144523	levimalevitaam	?levimalevitaam =levimalevitaam  (SgN  >levimalevitaam !22_S	et	f	\N
144524	levimalevitaam	?levimalevitaam =vitaam  (SgN  >levi+male+vitaam !22_S	et	f	\N
144525	levimalevitaam	?levimalevitaam =malevitaam  (SgN  >levi+malevitaam !22_S	et	f	\N
144543	rahvaraha	rahvaraha =raha  (SgN  >rahva+raha !17_S	et	f	\N
144544	rahvaraha	rahvaraha =raha  (SgG  >rahva+raha !17_S	et	f	\N
144545	rahvaraha	rahvaraha =raha  (SgG  >rahva+rahk !22_S	et	f	\N
144546	rahvaraha	rahvaraha =raha  (SgP  >rahva+raha !17_S	et	f	\N
144561	lup	### lup	et	f	\N
144593	kriililine	?kriililine =kriililine  (SgN  >kriililine !12_A	et	f	\N
144594	kriililine	?kriililine =kriililine  (PlP  >kriililin !19_S	et	f	\N
144595	lühendavad	lühendavad =lühenda  (IndPrPl3  >lühendama !27_V	et	f	\N
144596	lühendavad	lühendavad =lühendava  (PlN  >lühendav !02_A	et	f	\N
144597	lühendavad	"lühendav %lühenda  )V_vA  <lühendama ;27_V	et	f	\N
144604	väsinutena	väsinutena =väsinu  (PlEs  >väsinu !01_S	et	f	\N
144606	väsinutena	"väsinu %väsi  )NU_vS  <väsima ;27_V	et	f	\N
144614	riskimine	riskimine =riskimine  (SgN  >riskimine !12_S	et	f	\N
144615	riskimine	"riskimine %riski  )MINE_vS  <riskima ;28_V	et	f	\N
144636	vastajatest	vastajatest =vastaja  (PlEl  >vastaja !01_S	et	f	\N
144637	vastajatest	"vastaja %vasta  )JA_vS  <vastama ;29_V	et	f	\N
144638	vastajatest	vastajatest =test  (SgN  >vast+aja+test !22_S	et	f	\N
144670	töötu	töötu =töötu  (SgN  >töötu !01_AS	et	f	\N
144671	töötu	"töötu %töö  )TU2_kA  <töö ;26_S	et	f	\N
144672	töötu	töötu =töötu  (SgG  >töötu !01_AS	et	f	\N
144682	suitsetavad	suitsetavad =suitseta  (IndPrPl3  >suitsetama !27_V	et	f	\N
144683	suitsetavad	suitsetavad =suitsetava  (PlN  >suitsetav !02_A	et	f	\N
144684	suitsetavad	"suitsetav %suitse  )TAV_vAS  <suitsema ;28_V	et	f	\N
144686	suitsetavad	"suitsetav %suitseta  )V_vA  <suitsetama ;27_V	et	f	\N
144696	azaartne	?azaartne =azaartne  (SgN  >azaartne !02_A	et	f	\N
144697	azaartne	?azaartne =azaartne  (PlP  >azaartn !22_S	et	f	\N
144703	fie	?fie =fie  (SgN  >fie !26_S	et	f	\N
144704	fie	?fie =fie  (SgG  >fie !26_S	et	f	\N
144705	rajades	rajades =raja  (PlIn  >raja !17_S	et	f	\N
144706	rajades	rajades =raja  (Ger  >rajama !27_V	et	f	\N
144717	ehitamisest	ehitamisest =ehitamise  (SgEl  >ehitamine !12_S	et	f	\N
144389	uurimistulemuste	uurimistulemuste =tulemus  (PlG  >uurimis+tulemus !11_S	et	f	\N
144398	ideograafiline	ideograafiline =graafiline  (SgN  >ideo+graafiline !12_A	et	f	\N
144399	ideograafiline	"ideo+graafiline %graafi  )LINE_aA  <ideo+graaf ;22_S	et	f	\N
144400	põhikeeleks	põhikeeleks =keele  (SgTr  >põhi+keel !13_S	et	f	\N
144401	põhikeeleks	põhikeeleks =keele  (PlTr  >põhi+keeld !22_S	et	f	\N
144413	sundivad	sundivad =sundiva  (PlN  >sundiv !02_A	et	f	\N
144414	sundivad	"sundiv %sundi  )V_vA  <sundima ;28_V	et	f	\N
144415	sundivad	sundivad =iva  (PlN  >sund+iva !17_S	et	f	\N
144437	iseseisvuna	?iseseisvuna =seisvu  (SgEs  >ise+seisvu !01_S	et	f	\N
144446	tehnikaülikoolis	tehnikaülikoolis =kooli  (SgIn  >tehnika+üli+kool !22_S	et	f	\N
144447	tehnikaülikoolis	tehnikaülikoolis =kooli  (PlIn  >tehnika+üli+kool !22_S	et	f	\N
144452	väärinfo	väärinfo =info  (SgN  >väär+info !16_S	et	f	\N
144453	väärinfo	väärinfo =info  (SgG  >väär+info !16_S	et	f	\N
144464	nakatumine	nakatumine =nakatumine  (SgN  >nakatumine !12_S	et	f	\N
144465	nakatumine	"nakatumine %nakatu  )MINE_vS  <nakatuma ;27_V	et	f	\N
144469	laboratoorselt	laboratoorselt =laboratoorse  (SgAbl  >laboratoorne !02_A	et	f	\N
144470	laboratoorselt	laboratoorselt =laboratoorselt  (ID  >laboratoorselt !41_D	et	f	\N
144471	laboratoorselt	"laboratoorselt %laboratoorse  )LT_mD  <laboratoorne ;02_A	et	f	\N
144472	juhtuma	juhtuma =juhtu  (Sup  >juhtuma !27_V	et	f	\N
144473	juhtuma	juhtuma =juhtuma  (SgG  >juhtum !02_S	et	f	\N
144479	valmistamavalmistuma	?valmistamavalmistuma =valmistamavalmistu  (Sup  >valmistamavalmistuma !27_V	et	f	\N
144480	valmistamavalmistuma	?valmistamavalmistuma =valmistamavalmistuma  (SgG  >valmistamavalmistum !02_A	et	f	\N
144481	valmistamavalmistuma	?valmistamavalmistuma =tamavalmistuma  (SgG  >valmis+tamavalmistum !02_A	et	f	\N
144485	viirus	viirus =viiru  (SgIn  >viirg !22_S	et	f	\N
144486	viirus	viirus =viiru  (SgIn  >viir !22_S	et	f	\N
144487	viirus	viirus =viirus  (SgN  >viirus !11~09_S	et	f	\N
144491	ühinemaühendama	?ühinemaühendama =ühinemaühenda  (Sup  >ühinemaühendama !27_V	et	f	\N
144492	ühinemaühendama	?ühinemaühendama =ühinemaühendama  (SgG  >ühinemaühendam !02_A	et	f	\N
144493	tekita	tekita =teki  (SgAb  >tekk !22_S	et	f	\N
144494	tekita	tekita =teki  (IndPrIps_  >tekkima !28_V	et	f	\N
144495	tekita	tekita =tekita  (IndPrPs_  >tekitama !27_V	et	f	\N
144496	tekita	tekita =tekita  (ImpPrSg2  >tekitama !27_V	et	f	\N
144513	gripipandeemia	gripipandeemia =pandeemia  (SgN  >gripi+pandeemia !01_S	et	f	\N
144514	gripipandeemia	gripipandeemia =pandeemia  (SgG  >gripi+pandeemia !01_S	et	f	\N
144520	gripiviirus	gripiviirus =viiru  (SgIn  >gripi+viirg !22_S	et	f	\N
144521	gripiviirus	gripiviirus =viiru  (SgIn  >gripi+viir !22_S	et	f	\N
144522	gripiviirus	gripiviirus =viirus  (SgN  >gripi+viirus !11~09_S	et	f	\N
144541	ajuti	ajuti =aju  (IndIpfIps  >ajuma !27_V	et	f	\N
144542	ajuti	ajuti =ajuti  (ID  >ajuti !41_D	et	f	\N
144562	ahjast	?ahjast =ahja  (SgEl  >ahjas !02_A	et	f	\N
144563	ahjast	?ahjast =ahja  (SgEl  >ahja !16_S	et	f	\N
144564	ahjast	?ahjast =ahjas  (SgP  >ahjane !10_A	et	f	\N
144578	kahjustavad	kahjustavad =kahjusta  (IndPrPl3  >kahjustama !27_V	et	f	\N
144579	kahjustavad	kahjustavad =kahjustava  (PlN  >kahjustav !02_A	et	f	\N
144580	kahjustavad	"kahjustav %kahjusta  )V_vA  <kahjustama ;27_V	et	f	\N
144583	ebatervislikku	ebatervislikku =tervislikku  (SgP  >eba+tervislik !25_A	et	f	\N
144584	ebatervislikku	ebatervislikku =tervislikku  (SgAdt  >eba+tervislik !25_A	et	f	\N
144600	kohustatuks	kohustatuks =kohusta  (KndPtIps  >kohustama !27_V	et	f	\N
144601	kohustatuks	kohustatuks =kohustatu  (SgTr  >kohustatu !01_S	et	f	\N
144602	kohustatuks	"kohustatu %kohusta  )TU1_vS  <kohustama ;27_V	et	f	\N
144603	kolmal	?kolmal =kolma  (SgAd  >kolma !16_S	et	f	\N
144605	kolmal	?kolmal =kolmal  (SgN  >kolmal !02_S	et	f	\N
144609	pereelu	pereelu =elu  (SgN  >pere+elu !17_S	et	f	\N
144610	pereelu	pereelu =elu  (SgG  >pere+elu !17_S	et	f	\N
144611	pereelu	pereelu =elu  (SgP  >pere+elu !17_S	et	f	\N
144612	riskimine	riskimine =riskimine  (SgN  >riskimine !12_S	et	f	\N
144613	riskimine	"riskimine %riski  )MINE_vS  <riskima ;28_V	et	f	\N
144616	ohusetunne	?ohusetunne =ohusetunne  (SgN  >ohusetunne !02_A	et	f	\N
144617	ohusetunne	?ohusetunne =ohusetunne  (PlP  >ohusetunn !22_S	et	f	\N
144618	ohusetunne	?ohusetunne =setunne  (SgN  >ohu+setunne !02_A	et	f	\N
144619	ohusetunne	?ohusetunne =setunne  (PlP  >ohu+setunn !22_S	et	f	\N
144631	õilased	?õilased =õilase  (PlN  >õilane !12?10_S	et	f	\N
144632	pööratatud	?pööratatud =pöörata  (PtsPtIps  >pööratama !27_V	et	f	\N
144633	pööratatud	?pööratatud =pööratatu  (PlN  >pööratatu !01_S	et	f	\N
144634	pööratatud	?pööratatud =pööratatu  (IndPrSg2  >pööratatuma !27_V	et	f	\N
144635	pööratatud	?pööratatud =pööratatud  (ID  >pööratatud !41_A	et	f	\N
144639	jagunenud	jagunenud =jagune  (PtsPtPs  >jagunema !27_V	et	f	\N
144640	jagunenud	jagunenud =jagunenu  (PlN  >jagunenu !01_S	et	f	\N
144641	jagunenud	"jagunenu %jagune  )NU_vS  <jagunema ;27_V	et	f	\N
144642	jagunenud	jagunenud =jagunenud  (ID  >jagunenud !41_A	et	f	\N
144643	jagunenud	"jagunenud %jagune  )NUD_vA  <jagunema ;27_V	et	f	\N
144677	ebakindlalt	ebakindlalt =kindla  (SgAbl  >eba+kindel !02_A	et	f	\N
144569	üksildaselt	"üksildaselt %üksildase  )LT_mD  <üksildane ;12_A	et	f	\N
144589	rasvast	rasvast =rasva  (SgEl  >rasv !22_S	et	f	\N
144590	rasvast	rasvast =rasvas  (SgP  >rasvane !10_A	et	f	\N
144591	rasvast	"rasvane %rasva  )NE_aA  <rasv ;22_S	et	f	\N
144592	rasvast	rasvast =ast  (SgN  >rasv+ast !22_S	et	f	\N
144620	adrenaliini	adrenaliini =adrenaliini  (SgG  >adrenaliin !22_S	et	f	\N
144621	adrenaliini	adrenaliini =adrenaliini  (SgP  >adrenaliin !22_S	et	f	\N
144622	adrenaliini	adrenaliini =adrenaliini  (SgAdt  >adrenaliin !22_S	et	f	\N
144628	äri	äri =äri  (SgN  >äri !17_S	et	f	\N
144629	äri	äri =äri  (SgG  >äri !17_S	et	f	\N
144630	äri	äri =äri  (SgP  >äri !17_S	et	f	\N
144644	küsitlustest	küsitlustest =küsitlus  (PlEl  >küsitlus !11_S	et	f	\N
144645	küsitlustest	"küsitlus %küsitle  )US_vS  <küsitlema ;27_V	et	f	\N
144646	küsitlustest	küsitlustest =test  (SgN  >küsitlus+test !22_S	et	f	\N
144649	põhjusest	põhjusest =põhjuse  (SgEl  >põhjus !11~09_S	et	f	\N
144650	põhjusest	põhjusest =põhjuses  (SgP  >põhjusene !12_A	et	f	\N
144651	põhjusest	"põhjusene %põhjuse  )NE_aA  <põhjus ;09_S	et	f	\N
144652	põhjusest	"põhjusene %põhjuse  )NE_aA  <põhjus ;11_S	et	f	\N
144653	liigutavad	liigutavad =liiguta  (IndPrPl3  >liigutama !27_V	et	f	\N
144654	liigutavad	liigutavad =liigutava  (PlN  >liigutav !02_A	et	f	\N
144655	liigutavad	"liigutav %liigu  )TAV_vAS  <liikuma ;28_V	et	f	\N
144656	liigutavad	"liigutav %liiguta  )V_vA  <liigutama ;27_V	et	f	\N
144661	tubakas	tubakas =tubaka  (SgIn  >tubakas !02_S	et	f	\N
144662	tubakas	tubakas =tubakas  (SgN  >tubakas !02_S	et	f	\N
144663	elukestvust	elukestvust =kestvus  (SgP  >elu+kestvus !11~09_S	et	f	\N
144664	elukestvust	"elu+kestvus %kestva  )US_aS  <elu+kestev ;02_A	et	f	\N
144668	minimaalpalka	minimaalpalka =palka  (SgP  >minimaal+palk !22_S	et	f	\N
144669	minimaalpalka	minimaalpalka =palka  (SgAdt  >minimaal+palk !22_S	et	f	\N
144710	mõistmist	mõistmist =mõistmis  (SgP  >mõistmine !12?10_S	et	f	\N
144711	mõistmist	"mõistmine %mõist  )MINE_vS  <mõistma ;34_V	et	f	\N
144715	prügihoidla	prügihoidla =hoidla  (SgN  >prügi+hoidla !01_S	et	f	\N
144716	prügihoidla	prügihoidla =hoidla  (SgG  >prügi+hoidla !01_S	et	f	\N
144724	tüdinenud	tüdinenud =tüdine  (PtsPtPs  >tüdinema !27_V	et	f	\N
144725	tüdinenud	tüdinenud =tüdinenu  (PlN  >tüdinenu !01_S	et	f	\N
144726	tüdinenud	"tüdinenu %tüdine  )NU_vS  <tüdinema ;27_V	et	f	\N
144727	tüdinenud	tüdinenud =tüdinenud  (ID  >tüdinenud !41_A	et	f	\N
144728	tüdinenud	"tüdinenud %tüdine  )NUD_vA  <tüdinema ;27_V	et	f	\N
144760	rahastama	?rahastama =rahasta  (Sup  >rahastama !27_V	et	f	\N
144761	rahastama	?rahastama =rahastama  (SgG  >rahastam !02_A	et	f	\N
144762	rahastama	?rahastama =stama  (SgN  >raha+stama !17_S	et	f	\N
144763	rahastama	?rahastama =stama  (SgG  >raha+stama !17_S	et	f	\N
144765	rahastama	?rahastama =stama  (SgP  >raha+stama !17_S	et	f	\N
144776	keemilised	keemilised =keemilise  (PlN  >keemiline !12_A	et	f	\N
144777	keemilised	"keemiline %keemi  )LINE_aA  <keem ;22_S	et	f	\N
144787	mõlgutama	mõlgutama =mõlgu  (SupIps  >mõlkuma !28_V	et	f	\N
144788	mõlgutama	mõlgutama =mõlguta  (Sup  >mõlgutama !27_V	et	f	\N
144810	erakonnad	erakonnad =erakonna  (PlN  >erakond !22_S	et	f	\N
144811	erakonnad	erakonnad =konna  (PlN  >era+konn !22_S	et	f	\N
144822	murelikum	murelikum =murelikum  (SgN  >murelikum !02_A	et	f	\N
144823	murelikum	"murelikum %mureliku  )M_cA  <murelik ;25_A	et	f	\N
144883	kontrollimise	kontrollimise =kontrollimise  (SgG  >kontrollimine !12_S	et	f	\N
144884	kontrollimise	"kontrollimine %kontrolli  )MINE_vS  <kontrollima ;28_V	et	f	\N
144899	ekonimilise	?ekonimilise =ekonimilise  (SgG  >ekonimiline !12_A	et	f	\N
144901	valimiskordest	?valimiskordest =valimiskorde  (PlEl  >valimiskort !22_S	et	f	\N
144902	valimiskordest	?valimiskordest =valimiskordes  (SgP  >valimiskordene !12_A	et	f	\N
144903	valimiskordest	?valimiskordest =korde  (SgEl  >valimis+korre !06_S	et	f	\N
144904	valimiskordest	?valimiskordest =korde  (PlEl  >valimis+kort !22_S	et	f	\N
144905	valimiskordest	?valimiskordest =kordes  (SgP  >valimis+kordes !09_S	et	f	\N
144906	valimiskordest	?valimiskordest =kordes  (SgP  >valimis+kordene !12~10_A	et	f	\N
144921	pudutan	?pudutan =puduta  (IndPrSg1  >pudutama !27_V	et	f	\N
144922	pudutan	?pudutan =pudutan  (SgN  >pudutan !19_S	et	f	\N
144926	turvalisuste	turvalisuste =turvalisus  (PlG  >turvalisus !11?09_S	et	f	\N
144927	turvalisuste	"turvalisus %turva  )LISUS_aS  <turb ;22_SA	et	f	\N
144928	turvalisuste	"turvalisus %turva  )LISUS_aS  <turv ;22_S	et	f	\N
144934	kehras	?kehras =kehra  (SgIn  >kehra !16_S	et	f	\N
144935	kehras	?kehras =kehra  (IndIpfSg3  >kehrama !29_V	et	f	\N
144936	kehras	?kehras =kehras  (SgN  >kehras !07_S	et	f	\N
144949	gramaatikaga	?gramaatikaga =gramaatika  (SgKom  >gramaatika !01_S	et	f	\N
144950	gramaatikaga	?gramaatikaga =gramaatika  (SgKom  >gramaatikas !02_A	et	f	\N
144996	meeldne	?meeldne =meeldne  (SgN  >meeldne !02_A	et	f	\N
144997	meeldne	?meeldne =meeldne  (PlP  >meeldn !22_S	et	f	\N
144998	meeldne	?meeldne =meeldne  (IndPrPs_  >meeldnema !27_V	et	f	\N
144999	meeldne	?meeldne =meeldne  (ImpPrSg2  >meeldnema !27_V	et	f	\N
145016	ebaterveslik	?ebaterveslik =ebaterveslik  (SgN  >ebaterveslik !25_A	et	f	\N
144570	saadan	saadan =saada  (IndPrSg1  >saatma !34_V	et	f	\N
144571	saadan	saadan =saadan  (SgN  >saadan !02_S	et	f	\N
144581	ehitamises	ehitamises =ehitamise  (SgIn  >ehitamine !12_S	et	f	\N
144582	ehitamises	"ehitamine %ehita  )MINE_vS  <ehitama ;27_V	et	f	\N
144607	keerulised	keerulised =keerulise  (PlN  >keeruline !12_A	et	f	\N
144608	keerulised	"keeruline %keeru  )LINE_aA  <keerd ;22_SA	et	f	\N
144625	riskivad	riskivad =riski  (IndPrPl3  >riskima !28_V	et	f	\N
144626	riskivad	riskivad =riskiva  (PlN  >riskiv !02_A	et	f	\N
144627	riskivad	"riskiv %riski  )V_vA  <riskima ;28_V	et	f	\N
144647	vastati	vastati =vasta  (IndIpfIps  >vastama !29_V	et	f	\N
144648	vastati	vastati =ati  (SgG  >vast+att !22_S	et	f	\N
144665	makstatakse	?makstatakse =maksta  (IndPrIps  >makstama !29_V	et	f	\N
144666	makstatakse	?makstatakse =makstatakse  (SgG  >makstatakne !02_A	et	f	\N
144667	makstatakse	?makstatakse =makstatakse  (PlP  >makstataks !22_S	et	f	\N
144680	jöövad	?jöövad =jööva  (PlN  >jööva !16_S	et	f	\N
144681	jöövad	?jöövad =jööva  (IndPrSg2  >jöövama !29_V	et	f	\N
144700	kasinos	?kasinos =kasino  (SgIn  >kasino !01_S	et	f	\N
144701	kasinos	?kasinos =ino  (SgIn  >kas+ino !17~16_S	et	f	\N
144702	kasinos	?kasinos =inos  (SgN  >kas+inos !11~09_S	et	f	\N
144707	ürimuses	?ürimuses =ürimuse  (SgIn  >ürimus !11_S	et	f	\N
144714	pühkmehunnik	?pühkmehunnik =pühkmehunnik  (SgN  >pühkmehunnik !02_S	et	f	\N
144740	taivor	?taivor =taivor  (SgN  >taivor !02_S	et	f	\N
144752	ilusamaks	ilusamaks =ilusama  (SgTr  >ilusam !02_A	et	f	\N
144753	ilusamaks	"ilusam %ilusa  )M_cA  <ilus ;02_A	et	f	\N
144758	kodukeemilised	kodukeemilised =keemilise  (PlN  >kodu+keemiline !12_A	et	f	\N
144759	kodukeemilised	"kodu+keemiline %keemi  )LINE_aA  <kodu+keem ;22_S	et	f	\N
144798	kuritegevused	kuritegevused =tegevuse  (PlN  >kuri+tegevus !11_S	et	f	\N
144799	kuritegevused	"kuri+tegevus %tegeva  )US_aS  <kuri+tegev ;02_A	et	f	\N
144802	muutuses	muutuses =muutuse  (SgIn  >muutus !11~09_S	et	f	\N
144803	muutuses	"muutus %muu  )TUS2_aS  <muu ;26_S	et	f	\N
144818	kuritegevusega	kuritegevusega =tegevuse  (SgKom  >kuri+tegevus !11_S	et	f	\N
144819	kuritegevusega	"kuri+tegevus %tegeva  )US_aS  <kuri+tegev ;02_A	et	f	\N
144820	kuritegevusi	kuritegevusi =tegevusi  (PlP  >kuri+tegevus !11_S	et	f	\N
144821	kuritegevusi	"kuri+tegevus %tegeva  )US_aS  <kuri+tegev ;02_A	et	f	\N
144828	kasvada	kasvada =kasva  (Inf  >kasvama !28_V	et	f	\N
144829	kasvada	kasvada =vada  (SgN  >kas+vada !17_S	et	f	\N
144830	kasvada	kasvada =vada  (SgG  >kas+vada !17_S	et	f	\N
144831	kasvada	kasvada =vada  (SgP  >kas+vada !17_S	et	f	\N
144853	jääta	jääta =jää  (SgAb  >jää !26_S	et	f	\N
144854	jääta	jääta =jääta  (IndPrPs_  >jäätama !27_V	et	f	\N
144855	jääta	jääta =jääta  (ImpPrSg2  >jäätama !27_V	et	f	\N
144912	elukeskkonast	?elukeskkonast =elukeskkonas  (SgP  >elukeskkonane !12_A	et	f	\N
144913	elukeskkonast	?elukeskkonast =kona  (SgEl  >elu+kesk+kona !17_S	et	f	\N
144914	elukeskkonast	?elukeskkonast =konas  (SgP  >elu+kesk+konas !09_S	et	f	\N
144915	elukeskkonast	?elukeskkonast =konas  (SgP  >elu+kesk+konane !10_A	et	f	\N
144916	elukeskkonast	?elukeskkonast =keskkonas  (SgP  >elu+keskkonane !12_A	et	f	\N
144932	keeletaust	keeletaust =tau  (SgEl  >keele+tau !26_S	et	f	\N
144933	keeletaust	keeletaust =taust  (SgN  >keele+taust !22_S	et	f	\N
144937	kehra	?kehra =kehra  (SgN  >kehra !16_S	et	f	\N
144938	kehra	?kehra =kehra  (SgG  >kehra !16_S	et	f	\N
144939	kehra	?kehra =kehra  (IndPrPs_  >kehrama !29_V	et	f	\N
144940	kehra	?kehra =kehra  (ImpPrSg2  >kehrama !29_V	et	f	\N
144941	süsteemitehnika	süsteemitehnika =tehnika  (SgN  >süsteemi+tehnika !01_S	et	f	\N
144944	süsteemitehnika	süsteemitehnika =tehnika  (SgG  >süsteemi+tehnika !01_S	et	f	\N
144954	keevitajana	keevitajana =keevitaja  (SgEs  >keevitaja !01_S	et	f	\N
144955	keevitajana	"keevitaja %keevita  )JA_vS  <keevitama ;27_V	et	f	\N
144957	dokkeri	?dokkeri =dokkeri  (SgN  >dokkeri !01_S	et	f	\N
144958	dokkeri	?dokkeri =dokkeri  (SgG  >dokkeri !01_S	et	f	\N
144959	dokkeri	?dokkeri =dokkeri  (SgG  >dokker !02_S	et	f	\N
144960	dokkeri	?dokkeri =keri  (SgN  >dok+keri !17_S	et	f	\N
144963	dokkeri	?dokkeri =keri  (SgG  >dok+keri !17_S	et	f	\N
144964	dokkeri	?dokkeri =keri  (SgP  >dok+keri !17_S	et	f	\N
144974	eestikeeles	eestikeeles =keele  (SgIn  >eesti+keel !13_S	et	f	\N
144975	eestikeeles	eestikeeles =keele  (PlIn  >eesti+keeld !22_S	et	f	\N
145000	mugavalt	mugavalt =mugava  (SgAbl  >mugav !02_A	et	f	\N
145001	mugavalt	mugavalt =mugavalt  (ID  >mugavalt !41_D	et	f	\N
145002	mugavalt	"mugavalt %mugava  )LT_mD  <mugav ;02_A	et	f	\N
145034	jalgi	jalgi =jalgi  (SgP  >jalg !22_S	et	f	\N
145035	jalgi	jalgi =jalgi  (SgAdt  >jalg !22_S	et	f	\N
145037	tulevikuplaani	tulevikuplaani =plaani  (SgG  >tuleviku+plaan !22_S	et	f	\N
145038	tulevikuplaani	tulevikuplaani =plaani  (SgP  >tuleviku+plaan !22_S	et	f	\N
145039	tulevikuplaani	tulevikuplaani =plaani  (SgAdt  >tuleviku+plaan !22_S	et	f	\N
145051	programeerimine	?programeerimine =programeerimine  (SgN  >programeerimine !12_S	et	f	\N
145052	programeerimine	?programeerimine =programeerimine  (PlP  >programeerimin !19_S	et	f	\N
145059	liikuvad	liikuvad =liikuva  (PlN  >liikuv !02_A	et	f	\N
144599	tarvimine	?tarvimine =tarvimine  (PlP  >tarvimin !19_S	et	f	\N
144623	valitavad	valitavad =valitava  (PlN  >valitav !02_A	et	f	\N
144624	valitavad	"valitav %vali  )TAV_vAS  <valima ;27_V	et	f	\N
144657	vale-	vale- =vale  (SgN  >vale !16_SA	et	f	\N
144658	vale-	vale- =vale  (SgG  >vale !16_SA	et	f	\N
144659	toitumisest	toitumisest =toitumise  (SgEl  >toitumine !12_S	et	f	\N
144660	toitumisest	"toitumine %toitu  )MINE_vS  <toituma ;27_V	et	f	\N
144673	reeglena	?reeglena =reegle  (SgEs  >reegle !06_S	et	f	\N
144674	reeglena	?reeglena =glena  (SgN  >ree+glena !17_S	et	f	\N
144675	reeglena	?reeglena =glena  (SgG  >ree+glena !17_S	et	f	\N
144676	reeglena	?reeglena =glena  (SgP  >ree+glena !17_S	et	f	\N
144693	rooli	rooli =rooli  (SgG  >rool !22_S	et	f	\N
144694	rooli	rooli =rooli  (SgP  >rool !22_S	et	f	\N
144695	rooli	rooli =rooli  (SgAdt  >rool !22_S	et	f	\N
144698	rooli	rooli =rooli  (IndPrPs_  >roolima !28_V	et	f	\N
144699	rooli	rooli =rooli  (ImpPrSg2  >roolima !28_V	et	f	\N
144708	tarvitamine	tarvitamine =tarvitamine  (SgN  >tarvitamine !12_S	et	f	\N
144709	tarvitamine	"tarvitamine %tarvita  )MINE_vS  <tarvitama ;27_V	et	f	\N
144722	koristamisest	koristamisest =koristamise  (SgEl  >koristamine !12_S	et	f	\N
144723	koristamisest	"koristamine %korista  )MINE_vS  <koristama ;27_V	et	f	\N
144738	hüüriv	?hüüriv =hüüri  (PtsPrPs  >hüürima !28_V	et	f	\N
144739	hüüriv	?hüüriv =hüüriv  (SgN  >hüüriv !02_A	et	f	\N
144750	tegevad	tegevad =tegeva  (PlN  >tegev !02_A	et	f	\N
144751	tegevad	"tegev %tege  )V_vA  <tegema ;28_V	et	f	\N
144754	kodukeemilisi	kodukeemilisi =keemilisi  (PlP  >kodu+keemiline !12_A	et	f	\N
144755	kodukeemilisi	"kodu+keemiline %keemi  )LINE_aA  <kodu+keem ;22_S	et	f	\N
144756	müüdavad	müüdavad =müüdava  (PlN  >müüdav !02_A	et	f	\N
144757	müüdavad	"müüdav %müü  )TAV_vAS  <müüma ;38_V	et	f	\N
144764	rahastaksin	?rahastaksin =rahasta  (KndPrSg1  >rahastama !27_V	et	f	\N
144766	rahastaksin	?rahastaksin =rahastaksi  (IndPrSg1  >rahastaksima !28_V	et	f	\N
144767	rahastaksin	?rahastaksin =rahastaksin  (SgN  >rahastaksin !02_S	et	f	\N
144768	rahastaksin	?rahastaksin =staksin  (SgN  >raha+staksin !02_S	et	f	\N
144778	mürgised	mürgised =mürgise  (PlN  >mürgine !10_A	et	f	\N
144779	mürgised	"mürgine %mürgi  )NE_aA  <mürk ;22_S	et	f	\N
144794	rahvusvähemused	rahvusvähemused =vähemuse  (PlN  >rahvus+vähemus !11_S	et	f	\N
144795	rahvusvähemused	"rahvus+vähemus %vähema  )US_aS  <rahvus+vähem ;02_A	et	f	\N
144804	ligitiimne	?ligitiimne =ligitiimne  (SgN  >ligitiimne !02_A	et	f	\N
144805	ligitiimne	?ligitiimne =ligitiimne  (PlP  >ligitiimn !22_S	et	f	\N
144806	ligitiimne	?ligitiimne =tiimne  (SgN  >ligi+tiimne !02_A	et	f	\N
144807	ligitiimne	?ligitiimne =tiimne  (PlP  >ligi+tiimn !22_S	et	f	\N
144824	rahvusvähemusega	rahvusvähemusega =vähemuse  (SgKom  >rahvus+vähemus !11_S	et	f	\N
144825	rahvusvähemusega	"rahvus+vähemus %vähema  )US_aS  <rahvus+vähem ;02_A	et	f	\N
144826	vähemus	vähemus =vähemus  (SgN  >vähemus !11_S	et	f	\N
144827	vähemus	"vähemus %vähema  )US_aS  <vähem ;02_A	et	f	\N
144832	pinnas	pinnas =pinna  (SgIn  >pind !22_S	et	f	\N
144833	pinnas	pinnas =pinnas  (SgN  >pinnas !09_S	et	f	\N
144840	ettekanne	ettekanne =kanne  (SgN  >ette+kanne !05_S	et	f	\N
144841	ettekanne	ettekanne =kanne  (SgN  >ette+kanne !06_S	et	f	\N
144842	ettekanne	ettekanne =kanne  (PlP  >ette+kann !22_S	et	f	\N
144843	haldussüsteemist	haldussüsteemist =süsteemi  (SgEl  >haldus+süsteem !22_S	et	f	\N
144844	haldussüsteemist	haldussüsteemist =süsteemis  (SgP  >haldus+süsteemine !10_A	et	f	\N
144845	haldussüsteemist	"haldus+süsteemine %süsteemi  )NE_aA  <haldus+süsteem ;22_S	et	f	\N
144850	teemaringi	teemaringi =ringi  (SgG  >teema+ring !22_S	et	f	\N
144851	teemaringi	teemaringi =ringi  (SgP  >teema+ring !22_S	et	f	\N
144852	teemaringi	teemaringi =ringi  (SgAdt  >teema+ring !22_S	et	f	\N
144859	andakse	?andakse =andakse  (SgG  >andakne !02_A	et	f	\N
144870	tuvisalisuse	?tuvisalisuse =tuvisalisuse  (SgG  >tuvisalisus !11?09_S	et	f	\N
144871	tuvisalisuse	?tuvisalisuse =salisuse  (SgG  >tuvi+salisus !11_S	et	f	\N
144885	meies	meies =meie  (SgIn  >meie !16_S	et	f	\N
144886	meies	meies =meie  (PlIn  >meig !22_S	et	f	\N
144888	komisione	?komisione =komisione  (SgN  >komisione !16_S	et	f	\N
144889	komisione	?komisione =komisione  (SgG  >komisione !16_S	et	f	\N
144890	komisione	?komisione =komisione  (PlP  >komision !19_S	et	f	\N
144891	komisione	?komisione =isione  (SgN  >kom+isione !16_S	et	f	\N
144892	komisione	?komisione =isione  (SgG  >kom+isione !16_S	et	f	\N
144893	komisione	?komisione =isione  (PlP  >kom+ision !19_S	et	f	\N
144894	teeid	?teeid =teeid  (SgN  >teeid !02_S	et	f	\N
144918	kartavad	?kartavad =karta  (IndPrPl3  >kartama !29_V	et	f	\N
144919	kartavad	?kartavad =kartava  (PlN  >kartava !01_S	et	f	\N
144920	kartavad	?kartavad =kartava  (PlN  >kartav !02_A	et	f	\N
144923	temaid	?temaid =temai  (PlN  >temai !26_S	et	f	\N
144924	temaid	?temaid =temai  (SgP  >temai !26_S	et	f	\N
144925	temaid	?temaid =temaid  (SgN  >temaid !22_S	et	f	\N
144945	planid	?planid =plani  (PlN  >plani !17_S	et	f	\N
144946	planid	?planid =plani  (IndPrSg2  >planima !27_V	et	f	\N
144678	ebakindlalt	ebakindlalt =kindlalt  (ID  >eba+kindlalt !41_D	et	f	\N
144679	ebakindlalt	"eba+kindlalt %kindla  )LT_mD  <eba+kindel ;02_A	et	f	\N
144685	tohutult	tohutult =tohutu  (SgAbl  >tohutu !01_A	et	f	\N
144687	tohutult	"tohutu %tohu  )TU2_kA  <tohu ;17_S	et	f	\N
144688	tohutult	"tohutu %tohu  )TU2_kA  <toht ;22_S	et	f	\N
144689	tohutult	tohutult =tohutult  (ID  >tohutult !41_D	et	f	\N
144690	tohutult	"tohutult %tohu  )TULT2_mD  <tohu ;17_S	et	f	\N
144691	tohutult	"tohutult %tohu  )TULT2_mD  <toht ;22_S	et	f	\N
144692	tohutult	"tohutult %tohutu  )LT_mD  <tohutu ;01_A	et	f	\N
144712	keskkonda	keskkonda =keskkonda  (SgP  >keskkond !22_S	et	f	\N
144713	keskkonda	keskkonda =keskkonda  (SgAdt  >keskkond !22_S	et	f	\N
144719	kevade	kevade =kevade  (SgN  >kevade !01_S	et	f	\N
144720	kevade	kevade =kevade  (SgG  >kevade !01_S	et	f	\N
144721	kevade	kevade =kevade  (SgG  >kevad !02_S	et	f	\N
144730	minemata	minemata =mine  (SupAb  >minema !36_V	et	f	\N
144731	minemata	minemata =minemata  (ID  >minemata !41_A	et	f	\N
144732	minemata	"minemata %mine  )MATA_vA  <minema ;36_V	et	f	\N
144734	hüürib	?hüürib =hüüri  (IndPrSg3  >hüürima !28_V	et	f	\N
144735	vanni	vanni =vanni  (SgG  >vann !22_S	et	f	\N
144736	vanni	vanni =vanni  (SgP  >vann !22_S	et	f	\N
144737	vanni	vanni =vanni  (SgAdt  >vann !22_S	et	f	\N
144741	reklaameriv	?reklaameriv =reklaameriv  (SgN  >reklaameriv !02_A	et	f	\N
144742	reklaameriv	?reklaameriv =eriv  (SgN  >reklaam+eriv !02_A	et	f	\N
144743	puhastaval	puhastaval =puhastava  (SgAd  >puhastav !02_A	et	f	\N
144744	puhastaval	"puhastav %puhasta  )V_vA  <puhastama ;27_V	et	f	\N
144745	puhastaval	puhastaval =ava  (SgAd  >puhast+ava !17_S	et	f	\N
144746	puhastaval	puhastaval =aval  (SgN  >puhast+aval !02_A	et	f	\N
144747	puhastaval	puhastaval =tava  (SgAd  >puhas+tava !17_S	et	f	\N
144789	rahastada	?rahastada =rahasta  (Inf  >rahastama !27_V	et	f	\N
144790	rahastada	?rahastada =stada  (SgN  >raha+stada !17_S	et	f	\N
144791	rahastada	?rahastada =stada  (SgG  >raha+stada !17_S	et	f	\N
144792	rahastada	?rahastada =stada  (SgP  >raha+stada !17_S	et	f	\N
144793	uürituse	?uürituse =uürituse  (SgG  >uüritus !11_S	et	f	\N
144796	kuritegevus	kuritegevus =tegevus  (SgN  >kuri+tegevus !11_S	et	f	\N
144797	kuritegevus	"kuri+tegevus %tegeva  )US_aS  <kuri+tegev ;02_A	et	f	\N
144808	effektiivne	?effektiivne =effektiivne  (SgN  >effektiivne !02_A	et	f	\N
144809	effektiivne	?effektiivne =effektiivne  (PlP  >effektiivn !22_S	et	f	\N
144812	efektivsem	?efektivsem =efektivsem  (SgN  >efektivsem !02_A	et	f	\N
144813	usa	?usa =usa  (SgN  >usa !17_S	et	f	\N
144814	usa	?usa =usa  (SgG  >usa !17_S	et	f	\N
144815	usa	?usa =usa  (SgP  >usa !17_S	et	f	\N
144816	usa	?usa =usa  (IndPrPs_  >usama !27_V	et	f	\N
144817	usa	?usa =usa  (ImpPrSg2  >usama !27_V	et	f	\N
144834	tühistus	tühistus =tühistu  (IndIpfSg3  >tühistuma !27_V	et	f	\N
144835	tühistus	tühistus =tühistus  (SgN  >tühistus !11_S	et	f	\N
144836	tühistus	"tühistus %tühista  )US_vS  <tühistama ;27_V	et	f	\N
144856	halvam	?halvam =halvam  (SgN  >halvam !02_A	et	f	\N
144857	eelistamine	eelistamine =eelistamine  (SgN  >eelistamine !12_S	et	f	\N
144858	eelistamine	"eelistamine %eelista  )MINE_vS  <eelistama ;27_V	et	f	\N
144862	politseioperatsioneid	?politseioperatsioneid =politseioperatsione  (PlP  >politseioperatsion !02_S	et	f	\N
144863	politseioperatsioneid	?politseioperatsioneid =politseioperatsionei  (PlN  >politseioperatsionei !26_S	et	f	\N
144864	politseioperatsioneid	?politseioperatsioneid =politseioperatsionei  (SgP  >politseioperatsionei !26_S	et	f	\N
144865	politseioperatsioneid	?politseioperatsioneid =operatsione  (PlP  >politsei+operatsion !02_S	et	f	\N
144866	politseioperatsioneid	?politseioperatsioneid =operatsionei  (PlN  >politsei+operatsionei !26_S	et	f	\N
144867	politseioperatsioneid	?politseioperatsioneid =operatsionei  (SgP  >politsei+operatsionei !26_S	et	f	\N
144868	kuulume	kuulume =kuulu  (IndPrPl1  >kuuluma !27_V	et	f	\N
144869	kuulume	kuulume =lume  (SgG  >kuu+lumi !20_S	et	f	\N
144887	pakkun	?pakkun =pakkun  (SgN  >pakkun !02_S	et	f	\N
144895	lähendamise	lähendamise =lähendamise  (SgG  >lähendamine !12_S	et	f	\N
144896	lähendamise	"lähendamine %lähenda  )MINE_vS  <lähendama ;27_V	et	f	\N
144929	turvalises	turvalises =turvalise  (SgIn  >turvaline !12_A	et	f	\N
144930	turvalises	"turvaline %turva  )LINE_aA  <turb ;22_SA	et	f	\N
144931	turvalises	"turvaline %turva  )LINE_aA  <turv ;22_S	et	f	\N
144968	problemid	?problemid =problemi  (PlN  >problemi !01_S	et	f	\N
144969	problemid	?problemid =problemi  (PlN  >problem !02_A	et	f	\N
144970	vastuda	?vastuda =vastu  (Inf  >vastuma !27_V	et	f	\N
144971	vastuda	?vastuda =uda  (SgN  >vast+uda !17_S	et	f	\N
144972	vastuda	?vastuda =uda  (SgG  >vast+uda !17_S	et	f	\N
144973	vastuda	?vastuda =uda  (SgP  >vast+uda !17_S	et	f	\N
144987	sisseneda	?sisseneda =sissene  (Inf  >sissenema !27_V	et	f	\N
144988	sisseneda	?sisseneda =neda  (SgN  >sisse+neda !17_S	et	f	\N
144989	sisseneda	?sisseneda =neda  (SgG  >sisse+neda !17_S	et	f	\N
144990	sisseneda	?sisseneda =neda  (SgP  >sisse+neda !17_S	et	f	\N
144994	kuursid	?kuursid =kuursi  (PlN  >kuurs !22_S	et	f	\N
144995	kuursid	?kuursid =kuursi  (IndPrSg2  >kuursima !28_V	et	f	\N
144718	ehitamisest	"ehitamine %ehita  )MINE_vS  <ehitama ;27_V	et	f	\N
144729	juhut	?juhut =juhut  (SgN  >juhut !02_S	et	f	\N
144733	nõudpesuvahendite	?nõudpesuvahendite =nõudpesuvahendi  (IndPrPl2  >nõudpesuvahentima !28_V	et	f	\N
144748	ilusamaks	ilusamaks =ilusama  (SgTr  >ilusam !02_A	et	f	\N
144749	ilusamaks	"ilusam %ilusa  )M_cA  <ilus ;02_A	et	f	\N
144769	puhastamist	puhastamist =puhastamis  (SgP  >puhastamine !12_S	et	f	\N
144770	puhastamist	"puhastamine %puhasta  )MINE_vS  <puhastama ;27_V	et	f	\N
144771	määrdunud	määrdunud =määrdu  (PtsPtPs  >määrduma !27_V	et	f	\N
144772	määrdunud	määrdunud =määrdunu  (PlN  >määrdunu !01_S	et	f	\N
144773	määrdunud	"määrdunu %määrdu  )NU_vS  <määrduma ;27_V	et	f	\N
144774	määrdunud	määrdunud =määrdunud  (ID  >määrdunud !41_A	et	f	\N
144775	määrdunud	"määrdunud %määrdu  )NUD_vA  <määrduma ;27_V	et	f	\N
144780	trükkimist	trükkimist =trükkimis  (SgP  >trükkimine !12_S	et	f	\N
144781	trükkimist	"trükkimine %trükki  )MINE_vS  <trükkima ;28_V	et	f	\N
144782	rahastatud	?rahastatud =rahasta  (PtsPtIps  >rahastama !27_V	et	f	\N
144783	rahastatud	?rahastatud =rahastatu  (PlN  >rahastatu !01_S	et	f	\N
144784	rahastatud	?rahastatud =rahastatu  (IndPrSg2  >rahastatuma !27_V	et	f	\N
144785	rahastatud	?rahastatud =rahastatud  (ID  >rahastatud !41_A	et	f	\N
144786	rahastatud	?rahastatud =statu  (PlN  >raha+statu !16_S	et	f	\N
144800	küllalki	?küllalki =küllalki  (SgP  >küllalk !22_S	et	f	\N
144801	küllalki	?küllalki =küllalki  (SgAdt  >küllalk !22_S	et	f	\N
144837	häletama	?häletama =häle  (SupIps  >hälema !27_V	et	f	\N
144838	häletama	?häletama =häleta  (Sup  >häletama !27_V	et	f	\N
144839	häletama	?häletama =häletama  (SgG  >häletam !02_A	et	f	\N
144846	millisse	?millisse =milli  (SgIll  >milli !16_S	et	f	\N
144847	millisse	?millisse =milli  (SgIll  >mill !22_S	et	f	\N
144848	millisse	?millisse =millisse  (SgG  >millisne !02_A	et	f	\N
144849	millisse	?millisse =millisse  (PlP  >milliss !22_S	et	f	\N
144860	politseitöö	politseitöö =töö  (SgN  >politsei+töö !26_S	et	f	\N
144861	politseitöö	politseitöö =töö  (SgG  >politsei+töö !26_S	et	f	\N
144872	organisatsioneid	?organisatsioneid =organisatsione  (PlP  >organisatsion !02_S	et	f	\N
144873	organisatsioneid	?organisatsioneid =organisatsionei  (PlN  >organisatsionei !26_S	et	f	\N
144874	organisatsioneid	?organisatsioneid =organisatsionei  (SgP  >organisatsionei !26_S	et	f	\N
144875	turvalisuses	turvalisuses =turvalisuse  (SgIn  >turvalisus !11?09_S	et	f	\N
144876	turvalisuses	"turvalisus %turva  )LISUS_aS  <turb ;22_SA	et	f	\N
144877	turvalisuses	"turvalisus %turva  )LISUS_aS  <turv ;22_S	et	f	\N
144878	tõmbata	?tõmbata =tõmba  (SgAb  >tõmba !16_S	et	f	\N
144879	tõmbata	?tõmbata =tõmba  (Inf  >tõmpama !29_V	et	f	\N
144880	tõmbata	?tõmbata =tõmba  (IndPrIps_  >tõmpama !29_V	et	f	\N
144881	tõmbata	?tõmbata =tõmbata  (IndPrPs_  >tõmbatama !27_V	et	f	\N
144882	tõmbata	?tõmbata =tõmbata  (ImpPrSg2  >tõmbatama !27_V	et	f	\N
144897	valdkonnad	valdkonnad =valdkonna  (PlN  >valdkond !22_S	et	f	\N
144898	valdkonnad	valdkonnad =konna  (PlN  >vald+konn !22_S	et	f	\N
144900	rikased	?rikased =rikase  (PlN  >rikane !10_A	et	f	\N
144907	rahvusvähemusest	rahvusvähemusest =use  (PlEl  >rahvus+vähem+usk !22_S	et	f	\N
144908	rahvusvähemusest	rahvusvähemusest =vähemuse  (SgEl  >rahvus+vähemus !11_S	et	f	\N
144909	rahvusvähemusest	"rahvus+vähemus %vähema  )US_aS  <rahvus+vähem ;02_A	et	f	\N
144910	rahvusvähemusest	rahvusvähemusest =vähemuses  (SgP  >rahvus+vähemusene !12_A	et	f	\N
144911	rahvusvähemusest	"rahvus+vähemusene %vähemuse  )NE_aA  <rahvus+vähemus ;11_S	et	f	\N
144917	huvitaga	### huvitaga	et	f	\N
144942	selepärast	?selepärast =selepära  (SgEl  >selepära !16_S	et	f	\N
144943	selepärast	?selepärast =selepäras  (SgP  >selepärane !12_A	et	f	\N
144947	arvastused	?arvastused =arvastuse  (PlN  >arvastus !11_S	et	f	\N
144948	arvastused	?arvastused =astuse  (PlN  >arv+astus !11~09_S	et	f	\N
144951	aastaal	?aastaal =aastaa  (SgAd  >aastaa !26_S	et	f	\N
144952	aastaal	?aastaal =aastaal  (SgN  >aastaal !22_S	et	f	\N
144953	aastaal	?aastaal =taa  (SgAd  >aas+taa !26_S	et	f	\N
144956	aastaal	?aastaal =taal  (SgN  >aas+taal !22_S	et	f	\N
144961	professionid	?professionid =professioni  (PlN  >profession !19~02_S	et	f	\N
144962	professionid	?professionid =professioni  (PlN  >professioni !16_S	et	f	\N
144965	professionid	?professionid =professioni  (IndPrSg2  >professionima !28_V	et	f	\N
145003	õppides	õppides =õppi  (PlIn  >õpp !22_S	et	f	\N
145004	õppides	õppides =õppi  (Ger  >õppima !28_V	et	f	\N
145005	jatkan	?jatkan =jatka  (IndPrSg1  >jatkama !29_V	et	f	\N
145006	jatkan	?jatkan =jatkan  (SgN  >jatkan !02_S	et	f	\N
145013	üliõpilastel	üliõpilastel =las  (PlAd  >üli+õpi+laps !14_S	et	f	\N
145014	üliõpilastel	üliõpilastel =laste  (PlAd  >üli+õpi+last !22_S	et	f	\N
145015	üliõpilastel	üliõpilastel =õpilas  (PlAd  >üli+õpilane !12_S	et	f	\N
145020	kiirelt	kiirelt =kiire  (SgAbl  >kiire !01_A	et	f	\N
145022	kiirelt	kiirelt =kiire  (SgAbl  >kiire !06_S	et	f	\N
145023	kiirelt	kiirelt =kiire  (SgAbl  >kiire !06_AS	et	f	\N
145025	kiirelt	kiirelt =kiire  (SgAbl  >kiir !13_S	et	f	\N
145027	kiirelt	kiirelt =kiire  (PlAbl  >kiird !22_S	et	f	\N
144966	arvutidega	?arvutidega =tide  (SgKom  >arvu+tide !16_S	et	f	\N
144967	arvutidega	?arvutidega =uti  (PlKom  >arv+uti !16_S	et	f	\N
144976	olle	?olle =olle  (SgN  >olle !06_S	et	f	\N
144977	olle	?olle =olle  (PlP  >oll !22_S	et	f	\N
144978	olle	?olle =olle  (IndPrPs_  >ollema !30_V	et	f	\N
144979	olle	?olle =olle  (ImpPrSg2  >ollema !30_V	et	f	\N
144980	uuede	### uuede	et	f	\N
144981	internetisse	?internetisse =internetisse  (SgG  >internetisne !02_A	et	f	\N
144982	internetisse	?internetisse =internetisse  (PlP  >internetiss !22_S	et	f	\N
144983	internetisse	?internetisse =neti  (SgIll  >inter+neti !16_S	et	f	\N
144984	internetisse	?internetisse =neti  (SgIll  >inter+nett !22_AS	et	f	\N
144985	internetisse	?internetisse =netisse  (SgG  >inter+netisne !02_A	et	f	\N
144986	internetisse	?internetisse =netisse  (PlP  >inter+netiss !22_S	et	f	\N
144991	spordisaali	spordisaali =saali  (SgG  >spordi+saal !22_S	et	f	\N
144992	spordisaali	spordisaali =saali  (SgP  >spordi+saal !22_S	et	f	\N
144993	spordisaali	spordisaali =saali  (SgAdt  >spordi+saal !22_S	et	f	\N
145007	lapsepõlvu	?lapsepõlvu =lapsepõlvu  (IndPrPs_  >lapsepõlvuma !27_V	et	f	\N
145008	lapsepõlvu	?lapsepõlvu =lapsepõlvu  (ImpPrSg2  >lapsepõlvuma !27_V	et	f	\N
145009	lapsepõlvu	?lapsepõlvu =põlvu  (SgN  >lapse+põlvu !16_S	et	f	\N
145010	lapsepõlvu	?lapsepõlvu =põlvu  (SgG  >lapse+põlvu !16_S	et	f	\N
145011	lapsepõlvu	?lapsepõlvu =epõlvu  (SgN  >laps+epõlvu !01_S	et	f	\N
145012	lapsepõlvu	?lapsepõlvu =epõlvu  (SgG  >laps+epõlvu !01_S	et	f	\N
145045	saavutamise	saavutamise =saavutamise  (SgG  >saavutamine !12_S	et	f	\N
145046	saavutamise	"saavutamine %saavuta  )MINE_vS  <saavutama ;27_V	et	f	\N
145077	riigides	?riigides =riigi  (PlIn  >riigi !16_S	et	f	\N
145079	riigides	?riigides =riigi  (PlIn  >riig !22_S	et	f	\N
145080	riigides	?riigides =riigi  (Ger  >riigima !28_V	et	f	\N
145082	suhtluskeelt	suhtluskeelt =kee  (SgAbl  >suhtlus+kesi !15_S	et	f	\N
145083	suhtluskeelt	suhtluskeelt =kee  (SgAbl  >suhtlus+kee !26_S	et	f	\N
145084	suhtluskeelt	suhtluskeelt =keel  (SgP  >suhtlus+keel !13_S	et	f	\N
145091	perekonnaseis	perekonnaseis =seis  (SgN  >pere+konna+seis !22_S	et	f	\N
145092	perekonnaseis	perekonnaseis =konnase  (PlIn  >pere+konnane !10_A	et	f	\N
145093	perekonnaseis	"pere+konnane %konna  )NE_aA  <pere+konn ;22_S	et	f	\N
145103	müüjat	müüjat =müüja  (SgP  >müüja !01_S	et	f	\N
145104	müüjat	"müüja %müü  )JA_vS  <müüma ;38_V	et	f	\N
145107	pakkijaid	pakkijaid =pakkija  (PlP  >pakkija !01_S	et	f	\N
145108	pakkijaid	"pakkija %pakki  )JA_vS  <pakkima ;28_V	et	f	\N
145111	mnt3	### mnt3	et	f	\N
145112	mnt	### mnt	et	f	\N
145119	räkida	?räkida =räki  (Inf  >räkima !27_V	et	f	\N
145129	kuskel	?kuskel =kuske  (SgAd  >kuske !01_A	et	f	\N
145130	kuskel	?kuskel =kuske  (PlAd  >kusk !22_S	et	f	\N
145131	kuskel	?kuskel =kuskel  (SgN  >kuskel !02_S	et	f	\N
145141	simpoosiumid	?simpoosiumid =simpoosiumi  (PlN  >simpoosium !19~02_S	et	f	\N
145142	simpoosiumid	?simpoosiumid =simpoosiumi  (PlN  >simpoosiumi !16_S	et	f	\N
145143	simpoosiumid	?simpoosiumid =simpoosiumi  (IndPrSg2  >simpoosiumima !28_V	et	f	\N
145149	vajat	?vajat =vajat  (SgN  >vajat !02_S	et	f	\N
145162	võõrkkeeli	?võõrkkeeli =võõrkkeeli  (SgN  >võõrkkeeli !16_S	et	f	\N
145163	võõrkkeeli	?võõrkkeeli =võõrkkeeli  (SgG  >võõrkkeeli !16_S	et	f	\N
145164	võõrkkeeli	?võõrkkeeli =võõrkkeeli  (SgG  >võõrkkeel !22_S	et	f	\N
145165	võõrkkeeli	?võõrkkeeli =võõrkkeeli  (SgP  >võõrkkeel !22_S	et	f	\N
145166	võõrkkeeli	?võõrkkeeli =võõrkkeeli  (SgAdt  >võõrkkeel !22_S	et	f	\N
145167	võõrkkeeli	?võõrkkeeli =võõrkkeeli  (IndPrPs_  >võõrkkeelima !28_V	et	f	\N
145168	võõrkkeeli	?võõrkkeeli =võõrkkeeli  (ImpPrSg2  >võõrkkeelima !28_V	et	f	\N
145176	kõrvaklapideta	?kõrvaklapideta =kõrvaklapideta  (IndPrPs_  >kõrvaklapidetama !27_V	et	f	\N
145177	kõrvaklapideta	?kõrvaklapideta =kõrvaklapideta  (ImpPrSg2  >kõrvaklapidetama !27_V	et	f	\N
145178	kõrvaklapideta	?kõrvaklapideta =klapi  (PlAb  >kõrva+klapi !16_S	et	f	\N
145181	informatssiooni	?informatssiooni =informatssioo  (SgTer  >informatssioo !26_S	et	f	\N
145182	informatssiooni	?informatssiooni =informatssiooni  (SgN  >informatssiooni !16_S	et	f	\N
145183	informatssiooni	?informatssiooni =informatssiooni  (SgG  >informatssiooni !16_S	et	f	\N
145184	informatssiooni	?informatssiooni =informatssiooni  (SgG  >informatssioon !22_S	et	f	\N
145185	informatssiooni	?informatssiooni =informatssiooni  (SgP  >informatssioon !22_S	et	f	\N
145186	informatssiooni	?informatssiooni =informatssiooni  (SgAdt  >informatssioon !22_S	et	f	\N
145187	informatssiooni	?informatssiooni =informatssiooni  (IndPrPs_  >informatssioonima !28_V	et	f	\N
145188	informatssiooni	?informatssiooni =informatssiooni  (ImpPrSg2  >informatssioonima !28_V	et	f	\N
145210	koolitustel	koolitustel =koolitus  (PlAd  >koolitus !11_S	et	f	\N
145211	koolitustel	"koolitus %koolita  )US_vS  <koolitama ;27_V	et	f	\N
145212	koolitustel	"koolitus %kooli  )TUS2_aS  <kool ;22_S	et	f	\N
145213	koolitustel	koolitustel =tuste  (PlAd  >kooli+tust !22_S	et	f	\N
145225	tellimuseid	?tellimuseid =tellimusei  (PlN  >tellimusei !26_S	et	f	\N
145226	tellimuseid	?tellimuseid =tellimusei  (SgP  >tellimusei !26_S	et	f	\N
145227	tellimuseid	?tellimuseid =eid  (SgN  >tellimus+eid !22_S	et	f	\N
145017	ebaterveslik	?ebaterveslik =terveslik  (SgN  >eba+terveslik !25_A	et	f	\N
145018	krõpsud	krõpsud =krõpsu  (PlN  >krõps !22_S	et	f	\N
145019	krõpsud	krõpsud =krõpsu  (IndPrSg2  >krõpsuma !28_V	et	f	\N
145036	tagal	?tagal =tagal  (SgN  >tagal !02_S	et	f	\N
145040	rajamine	rajamine =rajamine  (SgN  >rajamine !12_S	et	f	\N
145041	rajamine	"rajamine %raja  )MINE_vS  <rajama ;27_V	et	f	\N
145042	toredamad	toredamad =toredama  (PlN  >toredam !02_A	et	f	\N
145043	toredamad	"toredam %toreda  )M_cA  <tore ;02_A	et	f	\N
145062	loengutega	loengutega =loengu  (PlKom  >loeng !02_S	et	f	\N
145063	loengutega	loengutega =ute  (SgKom  >loeng+utt !22_S	et	f	\N
145078	räägidakse	?räägidakse =räägidakse  (SgG  >räägidakne !02_A	et	f	\N
145094	autojuhiload	autojuhiload =loa  (PlN  >auto+juhi+luba !18_S	et	f	\N
145095	autojuhiload	autojuhiload =loa  (PlN  >auto+juhi+luga !18_S	et	f	\N
145120	e-mail	e-mail =ma  (PlAd  >e-maa !26_S	et	f	\N
145121	e-mail	e-mail =mai  (SgAd  >e-mai !26_S	et	f	\N
145123	keskmiselt	keskmiselt =keskmise  (SgAbl  >keskmine !12?10_A	et	f	\N
145124	keskmiselt	keskmiselt =keskmiselt  (ID  >keskmiselt !41_D	et	f	\N
145125	keskmiselt	"keskmiselt %keskmise  )LT_mD  <keskmine ;10_A	et	f	\N
145126	keskmiselt	"keskmiselt %keskmise  )LT_mD  <keskmine ;12_A	et	f	\N
145137	päägin	?päägin =päägi  (IndPrSg1  >pääkima !28_V	et	f	\N
145138	päägin	?päägin =päägin  (SgN  >päägin !02_S	et	f	\N
145157	080605a	### 080605a	et	f	\N
145160	õppitasin	?õppitasin =õppita  (IndIpfSg1  >õppitama !27_V	et	f	\N
145161	õppitasin	?õppitasin =õppitasin  (SgN  >õppitasin !19_S	et	f	\N
145169	koolituses	koolituses =koolituse  (SgIn  >koolitus !11_S	et	f	\N
145170	koolituses	"koolitus %koolita  )US_vS  <koolitama ;27_V	et	f	\N
145171	koolituses	"koolitus %kooli  )TUS2_aS  <kool ;22_S	et	f	\N
145174	tahksin	?tahksin =tahksi  (IndPrSg1  >tahksima !28_V	et	f	\N
145175	tahksin	?tahksin =tahksin  (SgN  >tahksin !02_S	et	f	\N
145216	osalejad	osalejad =osaleja  (PlN  >osaleja !01_S	et	f	\N
145217	osalejad	"osaleja %osale  )JA_vS  <osalema ;27_V	et	f	\N
145248	rühmast	rühmast =rühma  (SgEl  >rühm !22_S	et	f	\N
145249	rühmast	rühmast =rühmas  (SgP  >rühmane !10_A	et	f	\N
145250	rühmast	"rühmane %rühma  )NE_aA  <rühm ;22_S	et	f	\N
145255	müüjaks	müüjaks =müüja  (SgTr  >müüja !01_S	et	f	\N
145256	müüjaks	"müüja %müü  )JA_vS  <müüma ;38_V	et	f	\N
145290	abielusin	?abielusin =abielu  (IndIpfSg1  >abieluma !27_V	et	f	\N
145291	abielusin	?abielusin =abielusin  (SgN  >abielusin !19_S	et	f	\N
145292	abielusin	?abielusin =elusin  (SgN  >abi+elusin !19_S	et	f	\N
145299	saaksakele	saaksakele =sake  (SgAll  >saak+sake !16_S	et	f	\N
145300	saaksakele	saaksakele =sake  (PlAll  >saak+sakk !22_S	et	f	\N
145301	venekeelt	venekeelt =kee  (SgAbl  >vene+kesi !15_S	et	f	\N
145302	venekeelt	venekeelt =kee  (SgAbl  >vene+kee !26_S	et	f	\N
145303	venekeelt	venekeelt =keel  (SgP  >vene+keel !13_S	et	f	\N
145309	klasist	?klasist =klasi  (SgEl  >klasi !17_S	et	f	\N
145310	klasist	?klasist =klasis  (SgP  >klasis !09_S	et	f	\N
145311	klasist	?klasist =klasist  (SgN  >klasist !22_S	et	f	\N
145336	seitsesada	### seitsesada	et	f	\N
145352	oleg	### oleg	et	f	\N
145355	külastanut	külastanut =külastanu  (SgP  >külastanu !01_S	et	f	\N
145356	külastanut	"külastanu %külasta  )NU_vS  <külastama ;27_V	et	f	\N
145412	eek	?eek =eek  (SgN  >eek !22_S	et	f	\N
145417	sofia	?sofia =sofia  (SgN  >sofia !01_S	et	f	\N
145418	sofia	?sofia =sofia  (SgG  >sofia !01_S	et	f	\N
145419	paveli	?paveli =paveli  (ID  >paveli !41_D	et	f	\N
145420	paveli	?paveli =paveli  (SgG  >pavel !02_S	et	f	\N
145450	bootanikaaed	?bootanikaaed =bootanikaae  (PlN  >bootanikaae !26_S	et	f	\N
145451	bootanikaaed	?bootanikaaed =bootanikaae  (SgP  >bootanikaae !26_S	et	f	\N
145452	bootanikaaed	?bootanikaaed =bootanikaaed  (SgN  >bootanikaaed !22_S	et	f	\N
145460	sugulas	?sugulas =sugula  (SgIn  >sugula !01_S	et	f	\N
145461	restoranise	?restoranise =restoranise  (SgG  >restoranis !09_S	et	f	\N
145468	plaanit	?plaanit =plaani  (SgP  >plaani !16_S	et	f	\N
145469	plaanit	?plaanit =plaanit  (SgN  >plaanit !02_S	et	f	\N
145494	kunstliknäitakse	?kunstliknäitakse =kunstliknäitakse  (SgG  >kunstliknäitakne !02_A	et	f	\N
145495	kunstliknäitakse	?kunstliknäitakse =kunstliknäitakse  (PlP  >kunstliknäitaks !22_S	et	f	\N
145496	kunstliknäitakse	?kunstliknäitakse =liknäitakse  (SgG  >kunst+liknäitakne !02_A	et	f	\N
145497	kunstliknäitakse	?kunstliknäitakse =liknäitakse  (PlP  >kunst+liknäitaks !22_S	et	f	\N
145520	reserveeritud	reserveeritud =reserveeri  (PtsPtIps  >reserveerima !28_V	et	f	\N
145521	reserveeritud	reserveeritud =reserveeritu  (PlN  >reserveeritu !01_S	et	f	\N
145522	reserveeritud	"reserveeritu %reserveeri  )TU1_vS  <reserveerima ;28_V	et	f	\N
145523	reserveeritud	reserveeritud =reserveeritud  (ID  >reserveeritud !41_A	et	f	\N
145524	reserveeritud	"reserveeritud %reserveeri  )TUD_vA  <reserveerima ;28_V	et	f	\N
145535	ekskursioni	?ekskursioni =ekskursio  (SgTer  >ekskursio !01_S	et	f	\N
145536	ekskursioni	?ekskursioni =ekskursioni  (SgN  >ekskursioni !16_S	et	f	\N
145537	ekskursioni	?ekskursioni =ekskursioni  (SgG  >ekskursion !19~02_S	et	f	\N
145021	valmivad	valmivad =valmi  (IndPrPl3  >valmima !27_V	et	f	\N
145024	valmivad	valmivad =valmiva  (PlN  >valmiv !02_A	et	f	\N
145026	valmivad	"valmiv %valmi  )V_vA  <valmima ;27_V	et	f	\N
145031	maiustusi	maiustusi =maiustusi  (PlP  >maiustus !11_S	et	f	\N
145033	maiustusi	"maiustus %maiusta  )US_vS  <maiustama ;27_V	et	f	\N
145044	tähtist	?tähtist =tähtist  (SgN  >tähtist !22_S	et	f	\N
145047	ühiksateist	?ühiksateist =ühiksatei  (SgEl  >ühiksatei !26_S	et	f	\N
145048	ühiksateist	?ühiksateist =ühiksateist  (SgN  >ühiksateist !22_S	et	f	\N
145053	kooliga	kooliga =kooli  (SgKom  >kool !22_S	et	f	\N
145054	kooliga	kooliga =iga  (SgN  >kool+iga !18_S	et	f	\N
145055	kooliga	kooliga =iga  (SgP  >kool+iga !18_S	et	f	\N
145056	semenaarid	?semenaarid =semenaari  (PlN  >semenaari !16_S	et	f	\N
145057	semenaarid	?semenaarid =semenaari  (PlN  >semenaar !22_S	et	f	\N
145058	semenaarid	?semenaarid =semenaari  (IndPrSg2  >semenaarima !28_V	et	f	\N
145061	tudenge	### tudenge	et	f	\N
145074	kirjavahetusel	kirjavahetusel =use  (PlAd  >kirja+vahet+usk !22_S	et	f	\N
145075	kirjavahetusel	kirjavahetusel =vahetuse  (SgAd  >kirja+vahetus !11_S	et	f	\N
145076	kirjavahetusel	"kirja+vahetus %vahe  )TUS2_aS  <kirja+vahe ;16_S	et	f	\N
145085	kompuutri	?kompuutri =kompuutri  (SgN  >kompuutri !01_S	et	f	\N
145086	kompuutri	?kompuutri =kompuutri  (SgG  >kompuutri !01_S	et	f	\N
145087	kompuutri	?kompuutri =kompuutri  (SgG  >kompuuter !02_S	et	f	\N
145088	kompuutri	?kompuutri =kompuutri  (IndPrPs_  >kompuutrima !28_V	et	f	\N
145089	kompuutri	?kompuutri =kompuutri  (ImpPrSg2  >kompuutrima !28_V	et	f	\N
145090	kompuutri	?kompuutri =puutri  (SgG  >kom+puuter !02_S	et	f	\N
145099	kauplusesse	kauplusesse =kaupluse  (SgIll  >kauplus !11~09_S	et	f	\N
145100	kauplusesse	kauplusesse =kaupluses  (SgAdt  >kauplusene !12_A	et	f	\N
145101	kauplusesse	"kauplusene %kaupluse  )NE_aA  <kauplus ;09_S	et	f	\N
145102	kauplusesse	"kauplusene %kaupluse  )NE_aA  <kauplus ;11_S	et	f	\N
145132	telefooni	telefooni =telefooni  (IndPrPs_  >telefoonima !28_V	et	f	\N
145133	telefooni	telefooni =telefooni  (ImpPrSg2  >telefoonima !28_V	et	f	\N
145134	telefooni	telefooni =fooni  (SgG  >tele+foon !22_S	et	f	\N
145135	telefooni	telefooni =fooni  (SgP  >tele+foon !22_S	et	f	\N
145136	telefooni	telefooni =fooni  (SgAdt  >tele+foon !22_S	et	f	\N
145139	töödokumendidega	?töödokumendidega =töödokumendi  (PlKom  >töödokumend !22_S	et	f	\N
145140	töödokumendidega	?töödokumendidega =dokumendi  (PlKom  >töö+dokumend !22_S	et	f	\N
145144	harvam	?harvam =harvam  (SgN  >harvam !02_A	et	f	\N
145145	taidukaupluse	?taidukaupluse =taidukaupluse  (SgG  >taidukauplus !11~09_S	et	f	\N
145146	taidukaupluse	?taidukaupluse =dukaupluse  (SgG  >tai+dukauplus !11_S	et	f	\N
145150	läbivaadata	?läbivaadata =läbivaada  (SgAb  >läbivaada !16_S	et	f	\N
145151	läbivaadata	?läbivaadata =läbivaadata  (IndPrPs_  >läbivaadatama !27_V	et	f	\N
145152	läbivaadata	?läbivaadata =läbivaadata  (ImpPrSg2  >läbivaadatama !27_V	et	f	\N
145153	läbivaadata	?läbivaadata =vaada  (SgAb  >läbi+vaada !16_S	et	f	\N
145172	rahvuvaheline	rahvuvaheline =vaheline  (SgN  >rahvu+vaheline !12_A	et	f	\N
145173	rahvuvaheline	"rahvu+vaheline %vahe  )LINE_aA  <rahvu+vahe ;16_S	et	f	\N
145206	haigla	haigla =haigla  (SgN  >haigla !01_S	et	f	\N
145207	haigla	haigla =haigla  (SgG  >haigla !01_S	et	f	\N
145208	reaktiivede	reaktiivede =ede  (SgN  >reaktiiv+ede !16_S	et	f	\N
145209	reaktiivede	reaktiivede =ede  (SgG  >reaktiiv+ede !16_S	et	f	\N
145220	vastutava	vastutava =vastutava  (SgG  >vastutav !02_A	et	f	\N
145221	vastutava	"vastutav %vastuta  )V_vA  <vastutama ;27_V	et	f	\N
145222	vastutava	vastutava =tava  (SgN  >vastu+tava !17_S	et	f	\N
145223	vastutava	vastutava =tava  (SgG  >vastu+tava !17_S	et	f	\N
145224	vastutava	vastutava =tava  (SgP  >vastu+tava !17_S	et	f	\N
145235	eluk	?eluk =eluk  (SgN  >eluk !02_S	et	f	\N
145239	müügiagentina	?müügiagentina =agenti  (SgEs  >müügi+agenti !01_S	et	f	\N
145257	vabaj	### vabaj	et	f	\N
145274	kein	?kein =kein  (SgN  >kein !22_S	et	f	\N
145282	kelete	?kelete =kele  (IndPrPl2  >kelema !27_V	et	f	\N
145307	kümmendast	?kümmendast =kümmenda  (SgEl  >kümmenda !01_S	et	f	\N
145308	kümmendast	?kümmendast =kümmendas  (SgP  >kümmendane !12_A	et	f	\N
145333	aitah	?aitah =aitah  (ID  >aitah !41_I	et	f	\N
145383	käija	käija =käija  (SgN  >käija !01_S	et	f	\N
145384	käija	"käija %käi  )JA_vS  <käima ;38_V	et	f	\N
145385	käija	käija =käija  (SgG  >käija !01_S	et	f	\N
145388	fantani	?fantani =fanta  (SgTer  >fanta !16_S	et	f	\N
145389	fantani	?fantani =fantani  (SgG  >fantan !02_S	et	f	\N
145411	busiga	?busiga =busi  (SgKom  >busi !17_S	et	f	\N
145413	sevel	?sevel =seve  (SgAd  >seve !16_S	et	f	\N
145414	sevel	?sevel =sevel  (SgN  >sevel !02_S	et	f	\N
145416	rohiliset	### rohiliset	et	f	\N
145447	draamteater	?draamteater =draamteater  (SgN  >draamteater !02_S	et	f	\N
145464	huvitatut	huvitatut =huvitatu  (SgP  >huvitatu !01_S	et	f	\N
145465	huvitatut	"huvitatu %huvita  )TU1_vS  <huvitama ;27_V	et	f	\N
145466	vabanda	vabanda =vabanda  (IndPrPs_  >vabandama !27_V	et	f	\N
145467	vabanda	vabanda =vabanda  (ImpPrSg2  >vabandama !27_V	et	f	\N
145028	kiirelt	kiirelt =kiire  (PlAbl  >kiir !22_S	et	f	\N
145029	kiirelt	kiirelt =kiirelt  (ID  >kiirelt !41_D	et	f	\N
145030	kiirelt	"kiirelt %kiire  )LT_mD  <kiire ;01_A	et	f	\N
145032	kiirelt	"kiirelt %kiire  )LT_mD  <kiire ;06_AS	et	f	\N
145049	eelan	?eelan =eela  (IndPrSg1  >eelama !29_V	et	f	\N
145050	eelan	?eelan =eelan  (SgN  >eelan !02_S	et	f	\N
145064	väide	väide =väi  (PlG  >väi !26_S	et	f	\N
145065	väide	väide =väide  (SgN  >väide !06_S	et	f	\N
145068	suhtevad	?suhtevad =suhte  (IndPrPl3  >suhtema !27_V	et	f	\N
145069	suhtevad	?suhtevad =suhteva  (PlN  >suhteva !01_S	et	f	\N
145070	suhtevad	?suhtevad =suhteva  (PlN  >suhtev !02_A	et	f	\N
145071	suhtevad	?suhtevad =eva  (PlN  >suht+eva !17_S	et	f	\N
145072	väälismaal	?väälismaal =väälismaa  (SgAd  >väälismaa !26_S	et	f	\N
145073	väälismaal	?väälismaal =väälismaal  (SgN  >väälismaal !22_S	et	f	\N
145109	lisainfo	lisainfo =info  (SgN  >lisa+info !16_S	et	f	\N
145110	lisainfo	lisainfo =info  (SgG  >lisa+info !16_S	et	f	\N
145127	tutvan	?tutvan =tutva  (IndPrSg1  >tutvama !29_V	et	f	\N
145128	tutvan	?tutvan =tutvan  (SgN  >tutvan !02_S	et	f	\N
145147	juhatajale	juhatajale =juhataja  (SgAll  >juhataja !01_S	et	f	\N
145148	juhatajale	"juhataja %juhata  )JA_vS  <juhatama ;27_V	et	f	\N
145179	ingliskeeles	ingliskeeles =keele  (SgIn  >inglis+keel !13_S	et	f	\N
145180	ingliskeeles	ingliskeeles =keele  (PlIn  >inglis+keeld !22_S	et	f	\N
145189	virumaa	virumaa =maa  (SgN  >viru+maa !26_S	et	f	\N
145190	virumaa	virumaa =maa  (SgG  >viru+maa !26_S	et	f	\N
145214	seminaaridel	?seminaaridel =seminaari  (PlAd  >seminaari !16_S	et	f	\N
145215	seminaaridel	?seminaaridel =seminaari  (PlAd  >seminaar !22_S	et	f	\N
145240	suhtleja	suhtleja =suhtleja  (SgN  >suhtleja !01_S	et	f	\N
145241	suhtleja	"suhtleja %suhtle  )JA_vS  <suhtlema ;30_V	et	f	\N
145242	suhtleja	suhtleja =suhtleja  (SgG  >suhtleja !01_S	et	f	\N
145275	selleholda	?selleholda =selleholda  (SgN  >selleholda !16_S	et	f	\N
145276	selleholda	?selleholda =selleholda  (SgG  >selleholda !16_S	et	f	\N
145277	selleholda	?selleholda =selleholda  (IndPrPs_  >selleholdama !27_V	et	f	\N
145278	selleholda	?selleholda =selleholda  (ImpPrSg2  >selleholdama !27_V	et	f	\N
145279	selleholda	?selleholda =holda  (SgN  >selle+holda !16_S	et	f	\N
145280	selleholda	?selleholda =holda  (SgG  >selle+holda !16_S	et	f	\N
145304	eestikeelt	eestikeelt =kee  (SgAbl  >eesti+kesi !15_S	et	f	\N
145305	eestikeelt	eestikeelt =kee  (SgAbl  >eesti+kee !26_S	et	f	\N
145306	eestikeelt	eestikeelt =keel  (SgP  >eesti+keel !13_S	et	f	\N
145314	intensivselt	?intensivselt =intensivse  (SgAbl  >intensivne !02_A	et	f	\N
145315	intensivselt	?intensivselt =intensivse  (PlAbl  >intensivs !22_S	et	f	\N
145316	intensivselt	?intensivselt =intensivselt  (ID  >intensivselt !41_D	et	f	\N
145321	päavad	?päavad =päava  (PlN  >päava !16_S	et	f	\N
145322	päavad	?päavad =päava  (IndPrSg2  >päavama !29_V	et	f	\N
145323	rääkkima	?rääkkima =rääkki  (Sup  >rääkkima !28_V	et	f	\N
145324	rääkkima	?rääkkima =rääkkima  (SgG  >rääkkim !02_A	et	f	\N
145334	aabikaasa	?aabikaasa =aabikaasa  (SgN  >aabikaasa !16_S	et	f	\N
145335	aabikaasa	?aabikaasa =aabikaasa  (SgG  >aabikaasa !16_S	et	f	\N
145337	moskvani	?moskvani =moskvani  (SgG  >moskvan !02_S	et	f	\N
145338	danilovini	?danilovini =danilovi  (SgTer  >danilov !02_A	et	f	\N
145339	danilovini	?danilovini =danilovini  (SgG  >danilovin !19_S	et	f	\N
145340	danilovini	?danilovini =danilovini  (SgP  >danilovin !19_S	et	f	\N
145341	danilovini	?danilovini =danilovini  (SgAdt  >danilovin !19_S	et	f	\N
145346	mõnelin	?mõnelin =mõnelin  (SgN  >mõnelin !19_S	et	f	\N
145347	näitusel	näitusel =näituse  (SgAd  >näitus !11~09_S	et	f	\N
145348	näitusel	näitusel =use  (PlAd  >näit+usk !22_S	et	f	\N
145353	planin	?planin =plani  (IndPrSg1  >planima !27_V	et	f	\N
145354	planin	?planin =planin  (SgN  >planin !02_S	et	f	\N
145361	sinud	?sinud =sinu  (PlN  >sinu !17_S	et	f	\N
145362	sinud	?sinud =sinu  (IndPrSg2  >sinuma !27_V	et	f	\N
145386	sõitan	?sõitan =sõita  (IndPrSg1  >sõitama !27_V	et	f	\N
145387	sõitan	?sõitan =sõitan  (SgN  >sõitan !02_S	et	f	\N
145392	rahakotti	rahakotti =kotti  (SgP  >raha+kott !22_S	et	f	\N
145393	rahakotti	rahakotti =kotti  (SgAdt  >raha+kott !22_S	et	f	\N
145394	rahakotti	rahakotti =kotti  (PlP  >raha+kott !22_S	et	f	\N
145402	ettendusi	?ettendusi =ettendusi  (PlP  >ettendus !11_S	et	f	\N
145425	heag	?heag =heag  (SgN  >heag !22_S	et	f	\N
145431	plaanerinme	?plaanerinme =plaanerinme  (PlP  >plaanerinm !22_S	et	f	\N
145442	peeterburg	?peeterburg =peeterburg  (SgN  >peeterburg !22_S	et	f	\N
145443	peeterburg	?peeterburg =erburg  (SgN  >peet+erburg !02_S	et	f	\N
145472	televiska	?televiska =televiska  (SgN  >televiska !16_S	et	f	\N
145473	televiska	?televiska =televiska  (SgG  >televiska !16_S	et	f	\N
145474	televiska	?televiska =viska  (SgN  >tele+viska !16_S	et	f	\N
145475	televiska	?televiska =viska  (SgG  >tele+viska !16_S	et	f	\N
145478	restoraan	?restoraan =restoraan  (SgN  >restoraan !22_S	et	f	\N
145489	tütare	### tütare	et	f	\N
145513	sovin	?sovin =sovi  (IndPrSg1  >sovima !27_V	et	f	\N
145514	sovin	?sovin =sovin  (SgN  >sovin !02_S	et	f	\N
145060	liikuvad	"liikuv %liiku  )V_vA  <liikuma ;28_V	et	f	\N
145066	oskamine	oskamine =oskamine  (SgN  >oskamine !12_S	et	f	\N
145067	oskamine	"oskamine %oska  )MINE_vS  <oskama ;29_V	et	f	\N
145081	osada	?osada =osa  (Inf  >osama !27_V	et	f	\N
145096	töötasu	töötasu =tasu  (SgN  >töö+tasu !17_S	et	f	\N
145097	töötasu	töötasu =tasu  (SgG  >töö+tasu !17_S	et	f	\N
145098	töötasu	töötasu =tasu  (SgP  >töö+tasu !17_S	et	f	\N
145105	koristajaid	koristajaid =koristaja  (PlP  >koristaja !01_S	et	f	\N
145106	koristajaid	"koristaja %korista  )JA_vS  <koristama ;27_V	et	f	\N
145113	täiskasvane	?täiskasvane =täiskasvane  (SgN  >täiskasvane !12_A	et	f	\N
145114	täiskasvane	?täiskasvane =täiskasvane  (PlP  >täiskasvan !19_S	et	f	\N
145115	täiskasvane	?täiskasvane =vane  (SgN  >täis+kas+vane !16_S	et	f	\N
145116	täiskasvane	?täiskasvane =vane  (SgG  >täis+kas+vane !16_S	et	f	\N
145117	täiskasvane	?täiskasvane =kasvane  (SgN  >täis+kasvane !10_A	et	f	\N
145118	täiskasvane	?täiskasvane =skasvane  (SgN  >täi+skasvane !10_A	et	f	\N
145122	hotmailcom	?hotmailcom =hotmailcom  (SgN  >hotmailcom !19_S	et	f	\N
145154	töödata	?töödata =tööda  (SgAb  >tööda !16_S	et	f	\N
145155	töödata	?töödata =töödata  (IndPrPs_  >töödatama !27_V	et	f	\N
145156	töödata	?töödata =töödata  (ImpPrSg2  >töödatama !27_V	et	f	\N
145158	töödata	?töödata =data  (SgN  >töö+data !16_S	et	f	\N
145159	töödata	?töödata =data  (SgG  >töö+data !16_S	et	f	\N
145191	müüja	müüja =müüja  (SgN  >müüja !01_S	et	f	\N
145192	müüja	"müüja %müü  )JA_vS  <müüma ;38_V	et	f	\N
145193	müüja	müüja =müüja  (SgG  >müüja !01_S	et	f	\N
145194	kategooria	kategooria =kategooria  (SgN  >kategooria !01_S	et	f	\N
145195	kategooria	kategooria =kategooria  (SgG  >kategooria !01_S	et	f	\N
145196	registratorina	?registratorina =registratori  (SgEs  >registrator !02_S	et	f	\N
145197	registratorina	?registratorina =registratorina  (SgG  >registratorin !19_S	et	f	\N
145198	registratorina	?registratorina =registratorina  (SgP  >registratorin !19_S	et	f	\N
145199	registratorina	?registratorina =registratorina  (SgAdt  >registratorin !19_S	et	f	\N
145200	registratorina	?registratorina =stratori  (SgEs  >regi+stratori !01_S	et	f	\N
145201	registratorina	?registratorina =stratori  (SgEs  >regi+strator !02_S	et	f	\N
145202	registratorina	?registratorina =stratorina  (SgG  >regi+stratorin !19_S	et	f	\N
145203	registratorina	?registratorina =stratorina  (SgP  >regi+stratorin !19_S	et	f	\N
145204	registratorina	?registratorina =stratorina  (SgAdt  >regi+stratorin !19_S	et	f	\N
145205	28062005a	### 28062005a	et	f	\N
145218	erinevast	erinevast =erineva  (SgEl  >erinev !02_A	et	f	\N
145219	erinevast	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
145228	esindajatega	esindajatega =esindaja  (PlKom  >esindaja !01_S	et	f	\N
145229	esindajatega	"esindaja %esinda  )JA_vS  <esindama ;27_V	et	f	\N
145246	reisimisel	reisimisel =reisimise  (SgAd  >reisimine !12_S	et	f	\N
145247	reisimisel	"reisimine %reisi  )MINE_vS  <reisima ;28_V	et	f	\N
145251	avatate	?avatate =avata  (IndPrPl2  >avatama !27_V	et	f	\N
145252	avatate	?avatate =tate  (SgN  >ava+tate !06_S	et	f	\N
145261	firmaid	?firmaid =firmai  (PlN  >firmai !26_S	et	f	\N
145262	firmaid	?firmaid =firmai  (SgP  >firmai !26_S	et	f	\N
145263	firmaid	?firmaid =firmaid  (SgN  >firmaid !22_S	et	f	\N
145264	kulutuse	kulutuse =kulutuse  (SgG  >kulutus !11_S	et	f	\N
145265	kulutuse	"kulutus %kuluta  )US_vS  <kulutama ;27_V	et	f	\N
145266	kulutuse	"kulutus %kulu  )TUS1_aS  <kuluma ;27_V	et	f	\N
145267	kulutuse	"kulutus %kulu  )TUS2_aS  <kulu ;17_S	et	f	\N
145268	kulutuse	"kulutus %kulu  )TUS2_aS  <kulg ;22_S	et	f	\N
145285	eestise	?eestise =eestise  (SgG  >eestis !09_S	et	f	\N
145286	eestise	?eestise =eestise  (IndPrPs_  >eestisema !27_V	et	f	\N
145287	eestise	?eestise =eestise  (ImpPrSg2  >eestisema !27_V	et	f	\N
145288	eestise	?eestise =tise  (SgN  >ees+tise !16_S	et	f	\N
145289	eestise	?eestise =tise  (SgG  >ees+tise !16_S	et	f	\N
145293	keisin	?keisin =keisi  (IndPrSg1  >keisima !28_V	et	f	\N
145294	keisin	?keisin =keisin  (SgN  >keisin !02_S	et	f	\N
145295	kele	?kele =kele  (SgN  >kele !16_S	et	f	\N
145296	kele	?kele =kele  (SgG  >kele !16_S	et	f	\N
145297	kele	?kele =kele  (IndPrPs_  >kelema !27_V	et	f	\N
145298	kele	?kele =kele  (ImpPrSg2  >kelema !27_V	et	f	\N
145318	velismaal	?velismaal =velismaa  (SgAd  >velismaa !26_S	et	f	\N
145320	velismaal	?velismaal =velismaal  (SgN  >velismaal !22_S	et	f	\N
145349	suvepukust	?suvepukust =suvepukus  (SgP  >suvepukus !11?09_S	et	f	\N
145350	suvepukust	?suvepukust =puku  (SgEl  >suve+puku !16_S	et	f	\N
145351	suvepukust	?suvepukust =pukus  (SgP  >suve+pukus !09_S	et	f	\N
145363	selest	?selest =sele  (SgEl  >sele !16_S	et	f	\N
145364	selest	?selest =seles  (SgP  >seles !09_S	et	f	\N
145365	selest	?selest =seles  (SgP  >selene !10_A	et	f	\N
145375	lapsepõlvessõbranna	?lapsepõlvessõbranna =lapsepõlvessõbranna  (SgN  >lapsepõlvessõbranna !16_S	et	f	\N
145376	lapsepõlvessõbranna	?lapsepõlvessõbranna =lapsepõlvessõbranna  (SgG  >lapsepõlvessõbranna !16_S	et	f	\N
145377	lapsepõlvessõbranna	?lapsepõlvessõbranna =essõbranna  (SgN  >lapse+põlv+essõbranna !16_S	et	f	\N
145230	euroliigi	euroliigi =liigi  (SgG  >euro+liik !22_S	et	f	\N
145231	euroliigi	euroliigi =liigi  (SgP  >euro+liig !22_S	et	f	\N
145232	euroliigi	euroliigi =liigi  (SgAdt  >euro+liig !22_S	et	f	\N
145233	euroliigi	euroliigi =lii  (SgN^  >euro+lii !26_S	et	f	\N
145234	euroliigi	euroliigi =lii  (SgG^  >euro+lii !26_S	et	f	\N
145236	jaama	jaama =jaama  (SgG  >jaam !22_S	et	f	\N
145237	jaama	jaama =jaama  (SgP  >jaam !22_S	et	f	\N
145238	jaama	jaama =jaama  (SgAdt  >jaam !22_S	et	f	\N
145243	saakslane	?saakslane =saakslane  (SgN  >saakslane !12?10_S	et	f	\N
145244	saakslane	?saakslane =saakslane  (IndPrPs_  >saakslanema !27_V	et	f	\N
145245	saakslane	?saakslane =saakslane  (ImpPrSg2  >saakslanema !27_V	et	f	\N
145253	vajatate	?vajatate =vajata  (IndPrPl2  >vajatama !27_V	et	f	\N
145254	vajatate	?vajatate =tate  (SgN  >vaja+tate !06_S	et	f	\N
145258	ameriikas	?ameriikas =ameriika  (SgIn  >ameriikas !02_A	et	f	\N
145259	ameriikas	?ameriikas =ameriika  (SgIn  >ameriika !16_S	et	f	\N
145260	ameriikas	?ameriikas =ameriikas  (SgN  >ameriikas !02_A	et	f	\N
145269	cutsutakse	?cutsutakse =cutsu  (IndPrIps  >cutsuma !28_V	et	f	\N
145270	cutsutakse	?cutsutakse =cutsutakse  (SgG  >cutsutakne !02_A	et	f	\N
145271	cutsutakse	?cutsutakse =cutsutakse  (PlP  >cutsutaks !22_S	et	f	\N
145272	eestikelt	eestikelt =kelt  (SgN  >eesti+kelt !22_S	et	f	\N
145273	eestikelt	eestikelt =tike  (PlAbl  >ees+tikk !22_S	et	f	\N
145281	teatmine	?teatmine =teatmine  (SgN  >teatmine !12?10_S	et	f	\N
145283	teatmine	?teatmine =teatmine  (IndPrPs_  >teatminema !27_V	et	f	\N
145284	teatmine	?teatmine =teatmine  (ImpPrSg2  >teatminema !27_V	et	f	\N
145312	seeaves	?seeaves =ave  (SgIn  >see+ave !16_S	et	f	\N
145313	seeaves	?seeaves =aves  (SgN  >see+aves !09_S	et	f	\N
145317	läida	läida =läida  (IndPrPs_  >läitma !34_V	et	f	\N
145319	läida	läida =läida  (ImpPrSg2  >läitma !34_V	et	f	\N
145325	peatute	peatute =peatu  (PlG  >peatu !01_A	et	f	\N
145326	peatute	"peatu %pea  )TU2_kA  <pea ;26_S	et	f	\N
145327	peatute	peatute =peatu  (IndPrPl2  >peatuma !27_V	et	f	\N
145328	tana	?tana =tana  (SgN  >tana !17_S	et	f	\N
145329	tana	?tana =tana  (SgG  >tana !17_S	et	f	\N
145330	tana	?tana =tana  (SgP  >tana !17_S	et	f	\N
145331	tana	?tana =tana  (IndPrPs_  >tanama !27_V	et	f	\N
145332	tana	?tana =tana  (ImpPrSg2  >tanama !27_V	et	f	\N
145342	bussireisi	bussireisi =reis  (PlP  >bussi+reis !14_S	et	f	\N
145343	bussireisi	bussireisi =reisi  (SgG  >bussi+reis !22_S	et	f	\N
145344	bussireisi	bussireisi =reisi  (SgP  >bussi+reis !22_S	et	f	\N
145345	bussireisi	bussireisi =reisi  (SgAdt  >bussi+reis !22_S	et	f	\N
145357	ööpin	?ööpin =ööpin  (SgN  >ööpin !02_S	et	f	\N
145358	suvepuhkust	suvepuhkust =us  (SgP  >suve+puhk+uks !14_S	et	f	\N
145359	suvepuhkust	suvepuhkust =puhkus  (SgP  >suve+puhkus !11~09_S	et	f	\N
145360	mõnelik	?mõnelik =mõnelik  (SgN  >mõnelik !25_A	et	f	\N
145366	viieteistkümnendal	?viieteistkümnendal =viieteistkümnenda  (SgAd  >viieteistkümnenda !16_S	et	f	\N
145367	viieteistkümnendal	?viieteistkümnendal =viieteistkümnendal  (SgN  >viieteistkümnendal !02_S	et	f	\N
145368	viieteistkümnendal	?viieteistkümnendal =kümnenda  (SgAd  >viie+teist+kümnenda !01_S	et	f	\N
145369	viieteistkümnendal	?viieteistkümnendal =teistkümnenda  (SgAd  >viie+teistkümnenda !16_S	et	f	\N
145370	viieteistkümnendal	?viieteistkümnendal =teistkümnendal  (SgN  >viie+teistkümnendal !02_S	et	f	\N
145371	tiiju	?tiiju =tiiju  (SgN  >tiiju !16_S	et	f	\N
145372	tiiju	?tiiju =tiiju  (SgG  >tiiju !16_S	et	f	\N
145373	tiiju	?tiiju =tiiju  (IndPrPs_  >tiijuma !27_V	et	f	\N
145374	tiiju	?tiiju =tiiju  (ImpPrSg2  >tiijuma !27_V	et	f	\N
145390	elamine	elamine =elamine  (SgN  >elamine !12_S	et	f	\N
145391	elamine	"elamine %ela  )MINE_vS  <elama ;27_V	et	f	\N
145400	uutmed	?uutmed =uutme  (PlN  >uutme !06_S	et	f	\N
145401	uutmed	?uutmed =uutme  (IndPrSg2  >uutmema !27_V	et	f	\N
145407	sunul	?sunul =sunu  (SgAd  >sunu !17_S	et	f	\N
145408	sunul	?sunul =sunul  (SgN  >sunul !02_S	et	f	\N
145415	novgorod	?novgorod =novgoro  (PlN  >novgoro !01_S	et	f	\N
145421	mud	### mud	et	f	\N
145426	nagämiseni	?nagämiseni =nagämise  (SgTer  >nagämine !12_A	et	f	\N
145427	nagämiseni	?nagämiseni =nagämiseni  (SgG  >nagämisen !19_S	et	f	\N
145428	nagämiseni	?nagämiseni =nagämiseni  (SgP  >nagämisen !19_S	et	f	\N
145429	nagämiseni	?nagämiseni =nagämiseni  (SgAdt  >nagämisen !19_S	et	f	\N
145430	sõprana	### sõprana	et	f	\N
145434	peeterburgisse	?peeterburgisse =peeterburgi  (SgIll  >peeterburk !22_S	et	f	\N
145435	peeterburgisse	?peeterburgisse =peeterburgisse  (SgG  >peeterburgisne !02_A	et	f	\N
145436	peeterburgisse	?peeterburgisse =peeterburgisse  (PlP  >peeterburgiss !22_S	et	f	\N
145437	peeterburgisse	?peeterburgisse =erburgi  (SgIll  >peet+erburg !02_S	et	f	\N
145438	peeterburgisse	?peeterburgisse =erburgi  (SgIll  >peet+erburk !22_S	et	f	\N
145439	peeterburgisse	?peeterburgisse =erburgis  (SgAdt  >peet+erburgis !11_S	et	f	\N
145440	peeterburgisse	?peeterburgisse =erburgisse  (SgG  >peet+erburgisne !02_A	et	f	\N
145441	peeterburgisse	?peeterburgisse =erburgisse  (PlP  >peet+erburgiss !22_S	et	f	\N
145448	vanatänavad	vanatänavad =tänava  (PlN  >vana+tänav !02_A	et	f	\N
145378	lapsepõlvessõbranna	?lapsepõlvessõbranna =essõbranna  (SgG  >lapse+põlv+essõbranna !16_S	et	f	\N
145379	lapsepõlvessõbranna	?lapsepõlvessõbranna =põlvessõbranna  (SgN  >lapse+põlvessõbranna !16_S	et	f	\N
145380	lapsepõlvessõbranna	?lapsepõlvessõbranna =põlvessõbranna  (SgG  >lapse+põlvessõbranna !16_S	et	f	\N
145381	lapsepõlvessõbranna	?lapsepõlvessõbranna =epõlvessõbranna  (SgN  >laps+epõlvessõbranna !16_S	et	f	\N
145382	lapsepõlvessõbranna	?lapsepõlvessõbranna =epõlvessõbranna  (SgG  >laps+epõlvessõbranna !16_S	et	f	\N
145395	näitleija	?näitleija =näitleija  (SgN  >näitleija !01_S	et	f	\N
145396	näitleija	?näitleija =näitleija  (SgG  >näitleija !01_S	et	f	\N
145397	näitleija	?näitleija =näitleija  (SgG  >näitleijas !02_A	et	f	\N
145398	näitleija	?näitleija =leija  (SgN  >näit+leija !01_S	et	f	\N
145399	näitleija	?näitleija =leija  (SgG  >näit+leija !01_S	et	f	\N
145403	mari	mari =mari  (SgN  >mari !17~16_S	et	f	\N
145404	mari	mari =mari  (SgN  >mari !24_S	et	f	\N
145405	mari	mari =mari  (SgG  >mari !17~16_S	et	f	\N
145406	mari	mari =mari  (SgP  >mari !17_S	et	f	\N
145409	plaanilist	plaanilist =plaanilis  (SgP  >plaaniline !12_A	et	f	\N
145410	plaanilist	"plaaniline %plaani  )LINE_aA  <plaan ;22_S	et	f	\N
145422	vagä	### vagä	et	f	\N
145423	ekskursion	?ekskursion =ekskursion  (SgN  >ekskursion !19~02_S	et	f	\N
145424	ekskursion	?ekskursion =kursion  (SgN  >eks+kursion !19~02_S	et	f	\N
145432	venemale	venemale =male  (SgN  >vene+male !16_S	et	f	\N
145433	venemale	venemale =male  (SgG  >vene+male !16_S	et	f	\N
145444	kuulturikeskus	?kuulturikeskus =kuulturikesku  (IndIpfSg3  >kuulturikeskuma !27_V	et	f	\N
145445	kuulturikeskus	?kuulturikeskus =kuulturikeskus  (SgN  >kuulturikeskus !11~09_S	et	f	\N
145446	kuulturikeskus	?kuulturikeskus =turikeskus  (SgN  >kuul+turikeskus !11~09_S	et	f	\N
145463	isega	### isega	et	f	\N
145476	ostankino	?ostankino =ostankino  (SgN  >ostankino !16_S	et	f	\N
145477	ostankino	?ostankino =ostankino  (SgG  >ostankino !16_S	et	f	\N
145482	rimmi	?rimmi =rimmi  (SgN  >rimmi !16_S	et	f	\N
145483	rimmi	?rimmi =rimmi  (SgG  >rimmi !16_S	et	f	\N
145484	rimmi	?rimmi =rimmi  (SgG  >rimm !22_S	et	f	\N
145485	rimmi	?rimmi =rimmi  (SgP  >rimm !22_S	et	f	\N
145486	rimmi	?rimmi =rimmi  (SgAdt  >rimm !22_S	et	f	\N
145487	rimmi	?rimmi =rimmi  (IndPrPs_  >rimmima !28_V	et	f	\N
145488	rimmi	?rimmi =rimmi  (ImpPrSg2  >rimmima !28_V	et	f	\N
145498	loomaajas	loomaajas =aja  (SgIn  >looma+aeg !22_S	et	f	\N
145499	loomaajas	loomaajas =maaja  (SgIn  >loo+maaja !16_S	et	f	\N
145501	orlov	?orlov =orlov  (SgN  >orlov !02_A	et	f	\N
145502	ovadav	?ovadav =ovadav  (SgN  >ovadav !02_A	et	f	\N
145509	venemaalle	?venemaalle =venemaalle  (PlP  >venemaall !22_S	et	f	\N
145510	venemaalle	?venemaalle =maalle  (SgN  >vene+maalle !06_S	et	f	\N
145511	venemaalle	?venemaalle =maalle  (SgG  >vene+maalle !06_S	et	f	\N
145512	venemaalle	?venemaalle =maalle  (PlP  >vene+maall !22_S	et	f	\N
145527	etendust	etendust =etendus  (SgP  >etendus !11_S	et	f	\N
145528	etendust	"etendus %etenda  )US_vS  <etendama ;27_V	et	f	\N
145534	pilett	?pilett =pilett  (SgN  >pilett !22_S	et	f	\N
145556	petergoffi	?petergoffi =petergoffi  (SgP  >petergoff !22_S	et	f	\N
145557	petergoffi	?petergoffi =petergoffi  (SgAdt  >petergoff !22_S	et	f	\N
145558	nägemisvöörsuseid	?nägemisvöörsuseid =nägemisvöörsuse  (PlP  >nägemisvöörsus !09_S	et	f	\N
145559	nägemisvöörsuseid	?nägemisvöörsuseid =nägemisvöörsusei  (PlN  >nägemisvöörsusei !26_S	et	f	\N
145560	nägemisvöörsuseid	?nägemisvöörsuseid =nägemisvöörsusei  (SgP  >nägemisvöörsusei !26_S	et	f	\N
145561	nägemisvöörsuseid	?nägemisvöörsuseid =vöörsuse  (PlP  >nägemis+vöörsus !09_S	et	f	\N
145562	nägemisvöörsuseid	?nägemisvöörsuseid =vöörsusei  (PlN  >nägemis+vöörsusei !26_S	et	f	\N
145563	nägemisvöörsuseid	?nägemisvöörsuseid =vöörsusei  (SgP  >nägemis+vöörsusei !26_S	et	f	\N
145610	nelitoaline	nelitoaline =toaline  (SgN  >neli+toaline !12?10_A	et	f	\N
145611	nelitoaline	"neli+toaline %toa  )LINE_aA  <neli+tuba ;18_S	et	f	\N
145619	junil	?junil =juni  (SgAd  >juni !17_S	et	f	\N
145621	jõhvist	jõhvist =jõhvi  (SgEl  >jõhv !22_S	et	f	\N
145622	jõhvist	jõhvist =jõhvis  (SgP  >jõhvine !10_A	et	f	\N
145623	jõhvist	"jõhvine %jõhvi  )NE_aA  <jõhv ;22_S	et	f	\N
145648	ränka	ränka =ränka  (SgP  >ränk !22_A	et	f	\N
145649	ränka	ränka =ränka  (SgAdt  >ränk !22_A	et	f	\N
145653	keeluseadusest	keeluseadusest =seaduse  (SgEl  >keelu+seadus !11~09_S	et	f	\N
145654	keeluseadusest	keeluseadusest =seaduses  (SgP  >keelu+seadusene !12_A	et	f	\N
145655	keeluseadusest	"keelu+seadusene %seaduse  )NE_aA  <keelu+seadus ;09_S	et	f	\N
145656	keeluseadusest	"keelu+seadusene %seaduse  )NE_aA  <keelu+seadus ;11_S	et	f	\N
145663	kattai	?kattai =kattai  (SgN  >kattai !26_S	et	f	\N
145664	kattai	?kattai =kattai  (SgG  >kattai !26_S	et	f	\N
145665	vangi	vangi =vangi  (SgG  >vang !22_S	et	f	\N
145666	vangi	vangi =vangi  (SgP  >vang !22_S	et	f	\N
145667	vangi	vangi =vangi  (SgAdt  >vang !22_S	et	f	\N
145690	aleksi	?aleksi =aleksi  (SgN  >aleksi !01_S	et	f	\N
145691	aleksi	?aleksi =aleksi  (SgG  >aleksi !01_S	et	f	\N
145692	aleksi	?aleksi =aleksi  (IndPrPs_  >aleksima !28_V	et	f	\N
145449	vanatänavad	vanatänavad =tänava  (PlN  >vana+tänav !02_S	et	f	\N
145453	lossid	lossid =lossi  (PlN  >loss !22_S	et	f	\N
145454	lossid	lossid =lossi  (IndPrSg2  >lossima !28_V	et	f	\N
145455	peterburgist	?peterburgist =peterburgi  (SgEl  >peterburk !22_S	et	f	\N
145456	peterburgist	?peterburgist =peterburgis  (SgP  >peterburgis !09_S	et	f	\N
145457	peterburgist	?peterburgist =peterburgist  (SgN  >peterburgist !22_S	et	f	\N
145458	sõidama	?sõidama =sõida  (Sup  >sõidama !29_V	et	f	\N
145459	sõidama	?sõidama =sõidama  (SgG  >sõidam !02_S	et	f	\N
145462	plaanerin	?plaanerin =plaanerin  (SgN  >plaanerin !19_S	et	f	\N
145470	muvsolei	?muvsolei =muvsolei  (SgN  >muvsolei !26_S	et	f	\N
145471	muvsolei	?muvsolei =muvsolei  (SgG  >muvsolei !26_S	et	f	\N
145500	näitakse	?näitakse =näitakse  (SgG  >näitakne !02_A	et	f	\N
145507	päel	?päel =päe  (SgAd  >päe !26_S	et	f	\N
145508	päel	?päel =päel  (SgN  >päel !22_S	et	f	\N
145532	sõitu	sõitu =sõitu  (SgP  >sõit !22_S	et	f	\N
145533	sõitu	sõitu =sõitu  (SgAdt  >sõit !22_S	et	f	\N
145564	sõralikud	?sõralikud =sõraliku  (PlN  >sõralik !25_A	et	f	\N
145565	sõralikud	?sõralikud =sõraliku  (IndPrSg2  >sõralikuma !27_V	et	f	\N
145566	vadata	vadata =vada  (SgAb  >vada !17_S	et	f	\N
145567	vadata	vadata =vada  (IndPrIps_  >vadama !27_V	et	f	\N
145570	tervita	tervita =tervita  (IndPrPs_  >tervitama !27_V	et	f	\N
145571	tervita	tervita =tervita  (ImpPrSg2  >tervitama !27_V	et	f	\N
145572	marika	?marika =marika  (SgN  >marika !01_S	et	f	\N
145573	marika	?marika =marika  (SgG  >marika !01_S	et	f	\N
145574	marika	?marika =marika  (SgG  >marikas !02_S	et	f	\N
145577	kolmekohalikus	kolmekohalikus =kohaliku  (SgIn  >kolme+kohalik !25_AS	et	f	\N
145578	kolmekohalikus	kolmekohalikus =kohalikus  (SgN  >kolme+kohalikus !11?09_S	et	f	\N
145579	kolmekohalikus	"kolme+kohalikus %kohaliku  )US_aS  <kolme+kohalik ;25_AS	et	f	\N
145604	viiza	?viiza =viiza  (SgN  >viiza !16_S	et	f	\N
145605	viiza	?viiza =viiza  (SgG  >viiza !16_S	et	f	\N
145624	müüjaksib	?müüjaksib =müüjaksi  (IndPrSg3  >müüjaksima !28_V	et	f	\N
145642	tulivesi	tulivesi =vesi  (SgN  >tuli+vesi !15_S	et	f	\N
145643	tulivesi	tulivesi =vesi  (PlP  >tuli+vesi !15_S	et	f	\N
145668	erikuga	?erikuga =eriku  (SgKom  >eriku !01_S	et	f	\N
145669	erikuga	?erikuga =eriku  (SgKom  >erik !02_S	et	f	\N
145670	erikuga	?erikuga =kuga  (SgN  >eri+kuga !17_S	et	f	\N
145671	erikuga	?erikuga =kuga  (SgG  >eri+kuga !17_S	et	f	\N
145672	erikuga	?erikuga =kuga  (SgP  >eri+kuga !17_S	et	f	\N
145675	tapsid	tapsid =tap  (IndIpfSg2  >tapma !35_V	et	f	\N
145676	tapsid	tapsid =tap  (IndIpfPl3  >tapma !35_V	et	f	\N
145677	tapsid	tapsid =tapsi  (IndPrSg2  >tapsima !28_V	et	f	\N
145688	jubedamat	jubedamat =jubedama  (SgP  >jubedam !02_A	et	f	\N
145689	jubedamat	"jubedam %jubeda  )M_cA  <jube ;02_A	et	f	\N
145703	resurse	?resurse =resurse  (SgG  >resurne !02_A	et	f	\N
145704	resursid	?resursid =resursi  (PlN  >resursi !01_S	et	f	\N
145705	resursid	?resursid =resursi  (PlN  >resurs !02_S	et	f	\N
145706	resursid	?resursid =resursi  (PlN  >resurss !22_S	et	f	\N
145707	resursid	?resursid =resursi  (IndPrSg2  >resurssima !28_V	et	f	\N
145716	vajalikus	vajalikus =vajaliku  (SgIn  >vajalik !25_A	et	f	\N
145717	vajalikus	vajalikus =vajalikus  (SgN  >vajalikus !11?09_S	et	f	\N
145718	vajalikus	"vajalikus %vajaliku  )US_aS  <vajalik ;25_A	et	f	\N
145719	maista	?maista =maist  (Inf  >maistma !34_V	et	f	\N
145720	maista	?maista =maista  (SgN  >maista !01_S	et	f	\N
145721	maista	?maista =maista  (SgG  >maista !01_S	et	f	\N
145722	maista	?maista =maista  (IndPrPs_  >maistama !27_V	et	f	\N
145723	maista	?maista =maista  (ImpPrSg2  >maistama !27_V	et	f	\N
145774	sügavad	sügavad =süga  (IndPrPl3  >sügama !27_V	et	f	\N
145775	sügavad	sügavad =sügava  (PlN  >sügav !02_A	et	f	\N
145776	sügavad	"sügav %süga  )V_vA  <sügama ;27_V	et	f	\N
145786	nimetamise	nimetamise =nimetamise  (SgG  >nimetamine !12_S	et	f	\N
145787	nimetamise	"nimetamine %nimeta  )MINE_vS  <nimetama ;27_V	et	f	\N
145788	kantseleist	kantseleist =kantsele  (PlEl  >kantsel !02_S	et	f	\N
145789	kantseleist	kantseleist =kantselei  (SgEl  >kantselei !26_S	et	f	\N
145831	taibanud	taibanud =taiba  (PtsPtPs  >taipama !29_V	et	f	\N
145832	taibanud	taibanud =taibanu  (PlN  >taibanu !01_S	et	f	\N
145833	taibanud	"taibanu %taiba  )NU_vS  <taipama ;29_V	et	f	\N
145834	taibanud	taibanud =taibanud  (ID  >taibanud !41_A	et	f	\N
145835	taibanud	"taibanud %taiba  )NUD_vA  <taipama ;29_V	et	f	\N
145839	tegev	tegev =tege  (PtsPrPs  >tegema !28_V	et	f	\N
145840	tegev	tegev =tegev  (SgN  >tegev !02_A	et	f	\N
145841	tegev	"tegev %tege  )V_vA  <tegema ;28_V	et	f	\N
145842	täidesaadja	?täidesaadja =täidesaadja  (SgN  >täidesaadja !16_S	et	f	\N
145843	täidesaadja	?täidesaadja =täidesaadja  (SgG  >täidesaadjas !02_A	et	f	\N
145844	täidesaadja	?täidesaadja =täidesaadja  (SgG  >täidesaadja !16_S	et	f	\N
145845	täidesaadja	?täidesaadja =saadja  (SgN  >täide+saadja !01_S	et	f	\N
145846	täidesaadja	?täidesaadja =saadja  (SgG  >täide+saadja !01_S	et	f	\N
145847	täidesaadja	?täidesaadja =saadja  (SgG  >täide+saadjas !02_A	et	f	\N
145479	purskaevud	?purskaevud =purskaevu  (PlN  >purskaevu !01_S	et	f	\N
145480	purskaevud	?purskaevud =purskaevu  (IndPrSg2  >purskaevuma !27_V	et	f	\N
145481	purskaevud	?purskaevud =aevu  (PlN  >pursk+aevu !16_S	et	f	\N
145490	ruures	?ruures =ruure  (SgIn  >ruure !06_S	et	f	\N
145491	ruures	?ruures =ruure  (PlIn  >ruur !22_S	et	f	\N
145492	ruures	?ruures =ruure  (IndIpfSg3  >ruurema !27_V	et	f	\N
145493	ruures	?ruures =ruures  (SgN  >ruures !09_S	et	f	\N
145503	niina	?niina =niina  (SgN  >niina !16_S	et	f	\N
145504	niina	?niina =niina  (SgG  >niina !16_S	et	f	\N
145505	niina	?niina =niina  (IndPrPs_  >niinama !29_V	et	f	\N
145506	niina	?niina =niina  (ImpPrSg2  >niinama !29_V	et	f	\N
145518	maksad	maksad =maksa  (PlN  >maks !22_S	et	f	\N
145519	maksad	maksad =maksa  (IndPrSg2  >maksma !32_V	et	f	\N
145525	taa	?taa =taa  (SgN  >taa !26_S	et	f	\N
145526	taa	?taa =taa  (SgG  >taa !26_S	et	f	\N
145580	päivitama	?päivitama =päivi  (SupIps  >päivima !28_V	et	f	\N
145581	päivitama	?päivitama =päivita  (Sup  >päivitama !27_V	et	f	\N
145582	päivitama	?päivitama =päivitama  (SgG  >päivitam !02_A	et	f	\N
145591	biletid	?biletid =bileti  (PlN  >bilett !22_S	et	f	\N
145592	biletid	?biletid =bileti  (IndPrSg2  >bilettima !28_V	et	f	\N
145593	svetlana	### svetlana	et	f	\N
145595	rahull	?rahull =rahull  (SgN  >rahull !22_S	et	f	\N
145597	hasti	?hasti =hasti  (SgN  >hasti !16_S	et	f	\N
145598	hasti	?hasti =hasti  (SgG  >hasti !16_S	et	f	\N
145599	hasti	?hasti =hasti  (SgG  >hast !22_S	et	f	\N
145600	hasti	?hasti =hasti  (SgP  >hast !22_S	et	f	\N
145601	hasti	?hasti =hasti  (SgAdt  >hast !22_S	et	f	\N
145602	hasti	?hasti =hasti  (IndPrPs_  >hastima !28_V	et	f	\N
145603	hasti	?hasti =hasti  (ImpPrSg2  >hastima !28_V	et	f	\N
145606	biletit	### biletit	et	f	\N
145612	marike	marike =marike  (SgN  >marike !12_S	et	f	\N
145613	marike	"marike %mari  )KE_dS  <mari ;16_S	et	f	\N
145614	marike	"marike %mari  )KE_dS  <mari ;17_S	et	f	\N
145638	kohtumiseni	kohtumiseni =kohtumise  (SgTer  >kohtumine !12_S	et	f	\N
145639	kohtumiseni	"kohtumine %kohtu  )MINE_vS  <kohtuma ;27_V	et	f	\N
145657	lõikasid	lõikasid =lõika  (IndIpfSg2  >lõikama !29_V	et	f	\N
145658	lõikasid	lõikasid =lõika  (IndIpfPl3  >lõikama !29_V	et	f	\N
145659	tulivesiga	### tulivesiga	et	f	\N
145662	erik	?erik =erik  (SgN  >erik !02_S	et	f	\N
145673	selgusid	selgusid =selgu  (IndIpfSg2  >selguma !27_V	et	f	\N
145674	selgusid	selgusid =selgu  (IndIpfPl3  >selguma !27_V	et	f	\N
145696	tarbi	tarbi =tarbi  (IndPrPs_  >tarbima !27_V	et	f	\N
145697	tarbi	tarbi =tarbi  (ImpPrSg2  >tarbima !27_V	et	f	\N
145698	gaasi	gaasi =gaasi  (SgG  >gaas !22_S	et	f	\N
145699	gaasi	gaasi =gaasi  (SgP  >gaas !22_S	et	f	\N
145700	gaasi	gaasi =gaasi  (SgAdt  >gaas !22_S	et	f	\N
145710	sõltuvuses	sõltuvuses =sõltuvuse  (SgIn  >sõltuvus !11_S	et	f	\N
145711	sõltuvuses	"sõltuvus %sõltu  )VUS_aS  <sõltuma ;27_V	et	f	\N
145712	sõltuvuses	"sõltuvus %sõltuva  )US_aS  <sõltuv ;02_A	et	f	\N
145713	saavutusi	saavutusi =saavutusi  (PlP  >saavutus !11_S	et	f	\N
145714	saavutusi	"saavutus %saavuta  )US_vS  <saavutama ;27_V	et	f	\N
145727	kukkutada	?kukkutada =kukkuta  (Inf  >kukkutama !27_V	et	f	\N
145732	ûhendriikidest	### ûhendriikidest	et	f	\N
145740	algpunktiks	algpunktiks =iks  (SgN  >alg+punkt+iks !22_S	et	f	\N
145741	algpunktiks	algpunktiks =tiks  (SgN  >alg+punk+tiks !22_S	et	f	\N
145742	algpunktiks	algpunktiks =punkti  (SgTr  >alg+punkt !22_S	et	f	\N
145759	olemaks	olemaks =ole  (SupTr  >olema !36_V	et	f	\N
145760	olemaks	olemaks =olema  (SgTr  >olem !02_S	et	f	\N
145783	kohalt	kohalt =koha  (SgAbl  >koha !17_S	et	f	\N
145784	kohalt	kohalt =koha  (SgAbl  >koht !22_S	et	f	\N
145785	kohalt	kohalt =kohalt  (ID  >kohalt !41_DK	et	f	\N
145790	martti	?martti =martti  (SgN  >martti !01_S	et	f	\N
145791	martti	?martti =martti  (SgG  >martti !01_S	et	f	\N
145792	martti	?martti =martti  (SgG  >martt !22_S	et	f	\N
145793	martti	?martti =martti  (SgP  >martt !22_S	et	f	\N
145795	martti	?martti =martti  (SgAdt  >martt !22_S	et	f	\N
145796	martti	?martti =martti  (IndPrPs_  >marttima !28_V	et	f	\N
145797	martti	?martti =martti  (ImpPrSg2  >marttima !28_V	et	f	\N
145803	lipponeni	?lipponeni =lipponeni  (SgG  >lipponen !19_S	et	f	\N
145804	lipponeni	?lipponeni =lipponeni  (SgP  >lipponen !19_S	et	f	\N
145805	lipponeni	?lipponeni =lipponeni  (SgAdt  >lipponen !19_S	et	f	\N
145806	lipponeni	?lipponeni =one  (SgTer  >lipp+one !16_S	et	f	\N
145807	lipponeni	?lipponeni =oneni  (SgG  >lipp+onen !02_S	et	f	\N
145826	graanate	?graanate =graana  (IndPrPl2  >graanama !29_V	et	f	\N
145836	parlamend	?parlamend =parlamend  (SgN  >parlamend !22_S	et	f	\N
145837	rahust	rahust =rahu  (SgEl  >rahu !17_S	et	f	\N
145838	rahust	rahust =rahu  (PlEl  >rahk !22_S	et	f	\N
145851	uurivad	uurivad =uuri  (IndPrPl3  >uurima !28_V	et	f	\N
145852	uurivad	uurivad =uuriva  (PlN  >uuriv !02_A	et	f	\N
145853	uurivad	"uuriv %uuri  )V_vA  <uurima ;28_V	et	f	\N
145867	idolsid	?idolsid =idolsi  (PlN  >idolsi !01_S	et	f	\N
145515	peterburgis	?peterburgis =peterburgi  (SgIn  >peterburk !22_S	et	f	\N
145516	peterburgis	?peterburgis =peterburgi  (IndIpfSg3  >peterburgima !28_V	et	f	\N
145517	peterburgis	?peterburgis =peterburgis  (SgN  >peterburgis !09_S	et	f	\N
145529	nägemiseni	nägemiseni =nägemise  (SgTer  >nägemine !12_S	et	f	\N
145530	nägemiseni	"nägemine %näge  )MINE_vS  <nägema ;28_V	et	f	\N
145531	nägemiseni	nägemiseni =nägemiseni  (ID  >nägemiseni !41_I	et	f	\N
145594	plaanerinime	### plaanerinime	et	f	\N
145607	marinale	?marinale =marina  (SgAll  >marin !02_S	et	f	\N
145608	marinale	?marinale =nale  (SgN  >mari+nale !16_S	et	f	\N
145609	marinale	?marinale =nale  (SgG  >mari+nale !16_S	et	f	\N
145620	müüjasime	?müüjasime =müüja  (IndIpfPl1  >müüjama !29_V	et	f	\N
145627	ermitazi	### ermitazi	et	f	\N
145628	sõitme	?sõitme =sõitme  (SgN  >sõitme !06_S	et	f	\N
145629	sõitme	?sõitme =sõitme  (SgG  >sõitme !06_S	et	f	\N
145630	sõitme	?sõitme =sõitme  (PlP  >sõitm !22_S	et	f	\N
145631	sõitme	?sõitme =sõitme  (IndPrPs_  >sõitmema !27_V	et	f	\N
145632	sõitme	?sõitme =sõitme  (ImpPrSg2  >sõitmema !27_V	et	f	\N
145633	näetusel	?näetusel =näetuse  (SgAd  >näetus !11~09_S	et	f	\N
145634	näetusel	?näetusel =näetusel  (SgN  >näetusel !19_S	et	f	\N
145640	hirmsamat	hirmsamat =hirmsama  (SgP  >hirmsam !02_A	et	f	\N
145641	hirmsamat	"hirmsam %hirmsa  )M_cA  <hirmus ;02_A	et	f	\N
145644	hilda	?hilda =hilda  (SgN  >hilda !16_S	et	f	\N
145645	hilda	?hilda =hilda  (SgG  >hilda !16_S	et	f	\N
145646	hilda	?hilda =hilda  (IndPrPs_  >hildama !29_V	et	f	\N
145647	hilda	?hilda =hilda  (ImpPrSg2  >hildama !29_V	et	f	\N
145650	lootusetut	lootusetut =lootusetu  (SgP  >lootusetu !01_A	et	f	\N
145651	lootusetut	"lootusetu %lootuse  )TU2_kA  <lootus ;09_S	et	f	\N
145652	lootusetut	"lootusetu %lootuse  )TU2_kA  <lootus ;11_S	et	f	\N
145681	hildat	?hildat =hilda  (SgP  >hilda !16_S	et	f	\N
145682	hildat	?hildat =hildat  (SgN  >hildat !02_S	et	f	\N
145694	tarbi	tarbi =tarbi  (IndPrPs_  >tarbima !27_V	et	f	\N
145695	tarbi	tarbi =tarbi  (ImpPrSg2  >tarbima !27_V	et	f	\N
145724	tarvime	?tarvime =tarvi  (IndPrPl1  >tarvima !28_V	et	f	\N
145725	tõsi	tõsi =tõsi  (SgN  >tõsi !15_S	et	f	\N
145726	tõsi	tõsi =tõsi  (PlP  >tõsi !15_S	et	f	\N
145738	uuriva	uuriva =uuriva  (SgG  >uuriv !02_A	et	f	\N
145739	uuriva	"uuriv %uuri  )V_vA  <uurima ;28_V	et	f	\N
145745	bob	### bob	et	f	\N
145747	bernstein	?bernstein =bernstein  (SgN  >bernstein !22_S	et	f	\N
145748	demokraadliku	?demokraadliku =demokraadliku  (SgG  >demokraadlik !25_A	et	f	\N
145749	demokraadliku	?demokraadliku =demokraadliku  (IndPrPs_  >demokraadlikuma !27_V	et	f	\N
145750	demokraadliku	?demokraadliku =demokraadliku  (ImpPrSg2  >demokraadlikuma !27_V	et	f	\N
145754	asepresidedi	?asepresidedi =sidedi  (SgN  >ase+pre+sidedi !01_S	et	f	\N
145755	asepresidedi	?asepresidedi =sidedi  (SgG  >ase+pre+sidedi !01_S	et	f	\N
145756	ilewis	?ilewis =ilewi  (SgIn  >ilewi !01_S	et	f	\N
145758	ilewis	?ilewis =ilewis  (SgN  >ilewis !11_S	et	f	\N
145808	george	?george =george  (SgN  >george !06_S	et	f	\N
145809	george	?george =george  (IndPrPs_  >georgema !27_V	et	f	\N
145810	george	?george =george  (ImpPrSg2  >georgema !27_V	et	f	\N
145815	koalitsiooni	koalitsiooni =koalitsiooni  (SgG  >koalitsioon !22_S	et	f	\N
145816	koalitsiooni	koalitsiooni =koalitsiooni  (SgP  >koalitsioon !22_S	et	f	\N
145818	koalitsiooni	koalitsiooni =koalitsiooni  (SgAdt  >koalitsioon !22_S	et	f	\N
145822	müü	müü =müü  (SgN  >müü !26_S	et	f	\N
145823	müü	müü =müü  (SgG  >müü !26_S	et	f	\N
145824	müü	müü =müü  (IndPrPs_  >müüma !38_V	et	f	\N
145825	müü	müü =müü  (ImpPrSg2  >müüma !38_V	et	f	\N
145827	afganistaanis	?afganistaanis =afganistaani  (SgIn  >afganistaani !16_S	et	f	\N
145828	afganistaanis	?afganistaanis =afganistaani  (SgIn  >afganistaan !22_S	et	f	\N
145829	afganistaanis	?afganistaanis =afganistaani  (IndIpfSg3  >afganistaanima !28_V	et	f	\N
145830	afganistaanis	?afganistaanis =afganistaanis  (SgN  >afganistaanis !09_S	et	f	\N
145854	ajakijanikkud	?ajakijanikkud =ajakijanikku  (IndPrSg2  >ajakijanikkuma !27_V	et	f	\N
145859	kollast	kollast =kolla  (SgEl  >kold !22_S	et	f	\N
145860	kollast	kollast =kollas  (SgP  >kollane !10_A	et	f	\N
145861	kollast	"kollane %kolla  )NE_aA  <kold ;22_S	et	f	\N
145862	televisioonit	?televisioonit =televisiooni  (SgP  >televisiooni !16_S	et	f	\N
145863	televisioonit	?televisioonit =visiooni  (SgP  >tele+visiooni !16_S	et	f	\N
145886	sun	### sun	et	f	\N
145887	charlesi	?charlesi =charlesi  (ID  >charlesi !41_D	et	f	\N
145904	kontrollimatu	kontrollimatu =kontrollimatu  (SgN  >kontrollimatu !01_A	et	f	\N
145905	kontrollimatu	"kontrollimatu %kontrolli  )MATU_vA  <kontrollima ;28_V	et	f	\N
145906	kontrollimatu	kontrollimatu =kontrollimatu  (SgG  >kontrollimatu !01_A	et	f	\N
145907	kontrollimatu	kontrollimatu =imatu  (SgN  >kont+roll+imatu !01_A	et	f	\N
145908	kontrollimatu	"kont+roll+imatu %ima  )TU2_kA  <kont+roll+ima ;17_S	et	f	\N
145909	kontrollimatu	kontrollimatu =imatu  (SgG  >kont+roll+imatu !01_A	et	f	\N
145915	võimsaim	võimsaim =võimsaim  (SgN  >võimsaim !02_A	et	f	\N
145916	võimsaim	"võimsaim %võimsa  )IM_sA  <võimas ;03_A	et	f	\N
145538	ekskursioni	?ekskursioni =ekskursioni  (SgG  >ekskursioni !16_S	et	f	\N
145539	ekskursioni	?ekskursioni =ekskursioni  (SgP  >ekskursion !19_S	et	f	\N
145540	ekskursioni	?ekskursioni =ekskursioni  (SgAdt  >ekskursion !19_S	et	f	\N
145541	ekskursioni	?ekskursioni =ekskursioni  (IndPrPs_  >ekskursionima !28_V	et	f	\N
145542	ekskursioni	?ekskursioni =ekskursioni  (ImpPrSg2  >ekskursionima !28_V	et	f	\N
145543	ekskursioni	?ekskursioni =oni  (SgN  >eks+kursi+oni !17_S	et	f	\N
145544	ekskursioni	?ekskursioni =oni  (SgG  >eks+kursi+oni !17_S	et	f	\N
145545	ekskursioni	?ekskursioni =oni  (SgP  >eks+kursi+oni !17_S	et	f	\N
145546	ekskursioni	?ekskursioni =kursio  (SgTer  >eks+kursio !01_S	et	f	\N
145547	ekskursioni	?ekskursioni =kursioni  (SgN  >eks+kursioni !16_S	et	f	\N
145548	ekskursioni	?ekskursioni =kursioni  (SgG  >eks+kursion !19~02_S	et	f	\N
145549	ekskursioni	?ekskursioni =kursioni  (SgG  >eks+kursioni !16_S	et	f	\N
145550	ekskursioni	?ekskursioni =kursioni  (SgP  >eks+kursion !19_S	et	f	\N
145551	ekskursioni	?ekskursioni =kursioni  (SgAdt  >eks+kursion !19_S	et	f	\N
145552	nagemiseni	?nagemiseni =nagemise  (SgTer  >nagemine !12_S	et	f	\N
145553	nagemiseni	?nagemiseni =nagemiseni  (SgG  >nagemisen !19_S	et	f	\N
145554	nagemiseni	?nagemiseni =nagemiseni  (SgP  >nagemisen !19_S	et	f	\N
145555	nagemiseni	?nagemiseni =nagemiseni  (SgAdt  >nagemisen !19_S	et	f	\N
145568	loosid	loosid =loosi  (PlN  >loos !22_S	et	f	\N
145569	loosid	loosid =loosi  (IndPrSg2  >loosima !28_V	et	f	\N
145575	meere	meere =meere  (SgN  >meere !06_S	et	f	\N
145576	meere	meere =meere  (PlP  >meer !22_S	et	f	\N
145583	vaatamisväärsustega	vaatamisväärsustega =väärsus  (PlKom  >vaatamis+väärsus !11~09_S	et	f	\N
145584	vaatamisväärsustega	"vaatamis+väärsus %väärse  )US_aS  <vaatamis+väärne ;02_A	et	f	\N
145585	sunult	?sunult =sunu  (SgAbl  >sunu !17_S	et	f	\N
145586	sunult	?sunult =sunult  (ID  >sunult !41_D	et	f	\N
145587	juuba	?juuba =juuba  (SgN  >juuba !16_S	et	f	\N
145588	juuba	?juuba =juuba  (SgG  >juuba !16_S	et	f	\N
145589	juuba	?juuba =juuba  (IndPrPs_  >juubama !29_V	et	f	\N
145590	juuba	?juuba =juuba  (ImpPrSg2  >juubama !29_V	et	f	\N
145596	merike	?merike =merike  (SgN  >merike !12_S	et	f	\N
145615	jaana	?jaana =jaana  (SgN  >jaana !16_S	et	f	\N
145616	jaana	?jaana =jaana  (SgG  >jaana !16_S	et	f	\N
145617	jaana	?jaana =jaana  (IndPrPs_  >jaanama !29_V	et	f	\N
145618	jaana	?jaana =jaana  (ImpPrSg2  >jaanama !29_V	et	f	\N
145625	sõidada	### sõidada	et	f	\N
145626	vatada	?vatada =vata  (Inf  >vatama !27_V	et	f	\N
145635	petergofi	?petergofi =petergofi  (SgG  >petergoff !22_S	et	f	\N
145636	petergofi	?petergofi =petergofi  (IndPrPs_  >petergoffima !28_V	et	f	\N
145637	petergofi	?petergofi =petergofi  (ImpPrSg2  >petergoffima !28_V	et	f	\N
145660	juulius	?juulius =juuliu  (SgIn  >juuliu !01_S	et	f	\N
145661	juulius	?juulius =juulius  (SgN  >juulius !11_S	et	f	\N
145678	aleksandrile	?aleksandrile =aleksandri  (SgAll  >aleksander !02_S	et	f	\N
145679	aleksandrile	?aleksandrile =ksandri  (SgAll  >ale+ksandri !01_S	et	f	\N
145680	aleksandrile	?aleksandrile =ksandri  (SgAll  >ale+ksander !02_S	et	f	\N
145683	aleks	aleks =ale  (SgTr  >ale !16_S	et	f	\N
145684	aleks	aleks =ale  (PlTr  >alg !22_S	et	f	\N
145685	aleksile	?aleksile =aleksi  (SgAll  >aleksi !01_S	et	f	\N
145686	aleksile	?aleksile =ksile  (SgN  >ale+ksile !16_S	et	f	\N
145687	aleksile	?aleksile =ksile  (SgG  >ale+ksile !16_S	et	f	\N
145701	mõtlegi	mõtlegi =mõtle  (IndPrPs_^  >mõtlema !30_V	et	f	\N
145702	mõtlegi	mõtlegi =mõtle  (ImpPrSg2^  >mõtlema !30_V	et	f	\N
145708	kodutehnika	kodutehnika =tehnika  (SgN  >kodu+tehnika !01_S	et	f	\N
145709	kodutehnika	kodutehnika =tehnika  (SgG  >kodu+tehnika !01_S	et	f	\N
145728	lähiajaloos	lähiajaloos =loo  (SgIn  >lähi+aja+lugu !18_S	et	f	\N
145729	lähiajaloos	lähiajaloos =loo  (SgIn  >lähi+aja+loog !22_S	et	f	\N
145730	lähiajaloos	lähiajaloos =loo  (SgIn  >lähi+aja+lood !22_S	et	f	\N
145731	lähiajaloos	lähiajaloos =loos  (SgN  >lähi+aja+loos !22_S	et	f	\N
145734	ametikohalt	ametikohalt =koha  (SgAbl  >ameti+koha !17_S	et	f	\N
145735	ametikohalt	ametikohalt =koha  (SgAbl  >ameti+koht !22_S	et	f	\N
145746	woodward	?woodward =woodward  (SgN  >woodward !02_S	et	f	\N
145751	jäled	?jäled =jäle  (IndPrSg2  >jälema !27_V	et	f	\N
145752	presidendini	presidendini =presidendi  (SgTer  >president !22_S	et	f	\N
145753	presidendini	presidendini =sidendi  (SgTer  >pre+sidend !02_S	et	f	\N
145769	avaldanud	avaldanud =avalda  (PtsPtPs  >avaldama !27_V	et	f	\N
145770	avaldanud	avaldanud =avaldanu  (PlN  >avaldanu !01_S	et	f	\N
145771	avaldanud	"avaldanu %avalda  )NU_vS  <avaldama ;27_V	et	f	\N
145772	avaldanud	avaldanud =avaldanud  (ID  >avaldanud !41_A	et	f	\N
145773	avaldanud	"avaldanud %avalda  )NUD_vA  <avaldama ;27_V	et	f	\N
145777	jäätteenmäki	?jäätteenmäki =jäätteenmäki  (SgG  >jäätteenmäkk !22_S	et	f	\N
145778	jäätteenmäki	?jäätteenmäki =jäätteenmäki  (IndPrPs_  >jäätteenmäkkima !28_V	et	f	\N
145779	jäätteenmäki	?jäätteenmäki =jäätteenmäki  (ImpPrSg2  >jäätteenmäkkima !28_V	et	f	\N
145780	jäätteenmäki	?jäätteenmäki =teenmäki  (SgN  >jäät+teenmäki !01_S	et	f	\N
145781	jäätteenmäki	?jäätteenmäki =teenmäki  (SgG  >jäät+teenmäki !01_S	et	f	\N
145693	aleksi	?aleksi =aleksi  (ImpPrSg2  >aleksima !28_V	et	f	\N
145715	neeid	?neeid =neeid  (SgN  >neeid !02_S	et	f	\N
145733	nixon	?nixon =nixon  (SgN  >nixon !02_S	et	f	\N
145736	watergate	?watergate =waterga  (PlG  >waterga !01_S	et	f	\N
145737	watergate	?watergate =waterga  (PlG  >watergas !02_S	et	f	\N
145743	toimetajad	toimetajad =toimetaja  (PlN  >toimetaja !01_S	et	f	\N
145744	toimetajad	"toimetaja %toimeta  )JA_vS  <toimetama ;27_V	et	f	\N
145757	libby	### libby	et	f	\N
145761	judith	?judith =judith  (SgN  >judith !22_S	et	f	\N
145762	miller	?miller =miller  (SgN  >miller !02_S	et	f	\N
145763	timesista	?timesista =timesista  (SgN  >timesista !16_S	et	f	\N
145764	timesista	?timesista =timesista  (SgG  >timesista !16_S	et	f	\N
145765	timesista	?timesista =timesista  (IndPrPs_  >timesistama !27_V	et	f	\N
145766	timesista	?timesista =timesista  (ImpPrSg2  >timesistama !27_V	et	f	\N
145767	cia	?cia =cia  (SgN  >cia !26_S	et	f	\N
145768	cia	?cia =cia  (SgG  >cia !26_S	et	f	\N
145794	manninenilt	?manninenilt =mannineni  (SgAbl  >manninen !19_S	et	f	\N
145798	käsidlesid	?käsidlesid =käsidle  (IndIpfSg2  >käsidlema !27_V	et	f	\N
145799	käsidlesid	?käsidlesid =käsidle  (IndIpfPl3  >käsidlema !27_V	et	f	\N
145800	käsidlesid	?käsidlesid =dlesi  (PlN  >käsi+dlesi !17_S	et	f	\N
145811	bushile	?bushile =bushi  (SgAll  >bushi !16_S	et	f	\N
145812	bushile	?bushile =bushi  (SgAll  >bush !22_S	et	f	\N
145813	bushile	?bushile =bushile  (IndPrPs_  >bushilema !27_V	et	f	\N
145814	bushile	?bushile =bushile  (ImpPrSg2  >bushilema !27_V	et	f	\N
145817	iraaki	?iraaki =iraaki  (SgN  >iraaki !16_S	et	f	\N
145819	iraaki	?iraaki =iraaki  (SgG  >iraaki !16_S	et	f	\N
145820	iraaki	?iraaki =iraaki  (SgP  >iraak !22_S	et	f	\N
145821	iraaki	?iraaki =iraaki  (SgAdt  >iraak !22_S	et	f	\N
145873	iltasanomitest	?iltasanomitest =iltasanomite  (PlEl  >iltasanomitt !22_S	et	f	\N
145874	iltasanomitest	?iltasanomitest =iltasanomites  (SgP  >iltasanomitene !12_A	et	f	\N
145875	iltasanomitest	?iltasanomitest =sanomi  (PlEl  >ilta+sanomi !01_S	et	f	\N
145876	iltasanomitest	?iltasanomitest =sanomi  (PlEl  >ilta+sanom !02_S	et	f	\N
145877	iltasanomitest	?iltasanomitest =sanomite  (PlEl  >ilta+sanomitt !22_S	et	f	\N
145878	iltasanomitest	?iltasanomitest =sanomites  (SgP  >ilta+sanomitene !12_A	et	f	\N
145889	charles	?charles =charle  (SgIn  >charle !06_S	et	f	\N
145890	charles	?charles =charle  (PlIn  >charl !22_S	et	f	\N
145891	charles	?charles =charle  (IndIpfSg3  >charlema !30_V	et	f	\N
145892	charles	?charles =charles  (SgN  >charles !09_S	et	f	\N
145899	tavalised	tavalised =tavalise  (PlN  >tavaline !12_A	et	f	\N
145900	tavalised	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
145924	varajaseid	?varajaseid =varajase  (PlP  >varajas !02_A	et	f	\N
145925	varajaseid	?varajaseid =varajasei  (PlN  >varajasei !26_S	et	f	\N
145926	varajaseid	?varajaseid =varajasei  (SgP  >varajasei !26_S	et	f	\N
145927	varajaseid	?varajaseid =jasei  (PlN  >vara+jasei !26_S	et	f	\N
145928	varajaseid	?varajaseid =jasei  (SgP  >vara+jasei !26_S	et	f	\N
145929	varajaseid	?varajaseid =jaseid  (SgN  >vara+jaseid !22_S	et	f	\N
145943	väikseid	väikseid =väikse  (PlP  >väike !10_A	et	f	\N
145944	väikseid	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
145951	rahasi	?rahasi =rahasi  (ID  >rahasi !41_D	et	f	\N
145956	euro	euro =euro  (SgN  >euro !16_S	et	f	\N
145957	euro	euro =euro  (SgG  >euro !16_S	et	f	\N
145969	chaplini	?chaplini =chapli  (SgTer  >chappel !02_S	et	f	\N
145970	chaplini	?chaplini =chaplini  (SgG  >chaplin !02_S	et	f	\N
145977	peabgi	?peabgi =peabgi  (ID  >peabgi !41_D	et	f	\N
145978	peabgi	?peabgi =peabgi  (SgG  >peabg !22_S	et	f	\N
145979	peabgi	?peabgi =peabgi  (SgP  >peabg !22_S	et	f	\N
145980	peabgi	?peabgi =peabgi  (SgAdt  >peabg !22_S	et	f	\N
145981	peabgi	?peabgi =peabgi  (IndPrPs_  >peabgima !28_V	et	f	\N
145982	peabgi	?peabgi =peabgi  (ImpPrSg2  >peabgima !28_V	et	f	\N
145983	seebikat	?seebikat =seebika  (SgP  >seebika !01_S	et	f	\N
145984	seebikat	?seebikat =seebika  (SgP  >seebikas !02_S	et	f	\N
145985	seebikat	?seebikat =bika  (SgP  >see+bika !16_S	et	f	\N
145986	seebikat	?seebikat =bikat  (SgN  >see+bikat !02_S	et	f	\N
145987	naljakam	naljakam =naljakam  (SgN  >naljakam !02_A	et	f	\N
145988	naljakam	"naljakam %naljaka  )M_cA  <naljakas ;02_A	et	f	\N
145990	seebikad	?seebikad =seebika  (PlN  >seebika !01_S	et	f	\N
145991	seebikad	?seebikad =seebika  (PlN  >seebikas !02_S	et	f	\N
145992	seebikad	?seebikad =bika  (PlN  >see+bika !16_S	et	f	\N
145998	loba	loba =loba  (SgN  >loba !17_S	et	f	\N
145999	loba	loba =loba  (SgG  >loba !17_S	et	f	\N
146000	loba	loba =loba  (SgP  >loba !17_S	et	f	\N
146001	loba	loba =loba  (IndPrPs_  >lobama !27_V	et	f	\N
146002	loba	loba =loba  (ImpPrSg2  >lobama !27_V	et	f	\N
146006	jamad	jamad =jama  (PlN  >jama !17_S	et	f	\N
146007	jamad	jamad =jama  (IndPrSg2  >jamama !27_V	et	f	\N
146011	paperist	?paperist =paperi  (SgEl  >paperi !01_S	et	f	\N
146012	paperist	?paperist =paperi  (SgEl  >papper !02_S	et	f	\N
146013	paperist	?paperist =paperis  (SgP  >paperis !11_S	et	f	\N
146014	paperist	?paperist =paperist  (SgN  >paperist !22_S	et	f	\N
145782	jäätteenmäki	?jäätteenmäki =teenmäki  (SgG  >jäät+teenmäkk !22_S	et	f	\N
145801	paavo	?paavo =paavo  (SgN  >paavo !16_S	et	f	\N
145802	paavo	?paavo =paavo  (SgG  >paavo !16_S	et	f	\N
145864	telekas	telekas =teleka  (SgIn  >telekas !02_S	et	f	\N
145865	telekas	telekas =telekas  (SgN  >telekas !02_S	et	f	\N
145866	robinsonid	?robinsonid =robinsoni  (PlN  >robinson !19_S	et	f	\N
145870	himu	himu =himu  (SgN  >himu !17_S	et	f	\N
145871	himu	himu =himu  (SgG  >himu !17_S	et	f	\N
145872	himu	himu =himu  (SgP  >himu !17_S	et	f	\N
145879	vanheneid	?vanheneid =vanhene  (PlP  >vanhen !02_S	et	f	\N
145880	vanheneid	?vanheneid =vanhenei  (PlN  >vanhenei !26_S	et	f	\N
145881	vanheneid	?vanheneid =vanhenei  (SgP  >vanhenei !26_S	et	f	\N
145882	maksvad	maksvad =maksva  (PlN  >maksev !02_A	et	f	\N
145883	maksvad	"maksev %maks  )V_vA  <maksma ;32_V	et	f	\N
145884	mitteteevad	?mitteteevad =mitteteeva  (PlN  >mitteteeva !16_S	et	f	\N
145885	mitteteevad	?mitteteevad =teeva  (PlN  >mitte+teeva !16_S	et	f	\N
145894	camilla	?camilla =camilla  (SgN  >camilla !16_S	et	f	\N
145895	camilla	?camilla =camilla  (SgG  >camilla !16_S	et	f	\N
145896	tähentas	?tähentas =tähenta  (SgIn  >tähenta !01_S	et	f	\N
145913	aamen	aamen =aamen  (ID  >aamen !41_I	et	f	\N
145914	aamen	aamen =aamen  (SgN  >aamen !02_S	et	f	\N
145921	televisioonisaatet	?televisioonisaatet =televisioonisaate  (SgP  >televisioonisaate !16_S	et	f	\N
145922	televisioonisaatet	?televisioonisaatet =saate  (SgP  >tele+visiooni+saate !06_S	et	f	\N
145923	televisioonisaatet	?televisioonisaatet =visioonisaate  (SgP  >tele+visioonisaate !16_S	et	f	\N
145940	seiklusfilmi	seiklusfilmi =filmi  (SgG  >seiklus+film !22_S	et	f	\N
145941	seiklusfilmi	seiklusfilmi =filmi  (SgP  >seiklus+film !22_S	et	f	\N
145942	seiklusfilmi	seiklusfilmi =filmi  (SgAdt  >seiklus+film !22_S	et	f	\N
145955	njah	?njah =njah  (ID  >njah !41_I	et	f	\N
145959	peksa	peksa =peksa  (IndPrPs_  >peksma !32_V	et	f	\N
145960	peksa	peksa =peksa  (ImpPrSg2  >peksma !32_V	et	f	\N
145961	imesta	imesta =imesta  (IndPrPs_  >imestama !27_V	et	f	\N
145962	imesta	imesta =imesta  (ImpPrSg2  >imestama !27_V	et	f	\N
145965	peksmine	peksmine =peksmine  (SgN  >peksmine !12?10_S	et	f	\N
145966	peksmine	"peksmine %peks  )MINE_vS  <peksma ;32_V	et	f	\N
145973	tarantino	?tarantino =tarantino  (SgN  >tarantino !16_S	et	f	\N
145974	tarantino	?tarantino =tarantino  (SgG  >tarantino !16_S	et	f	\N
145975	kaklemine	kaklemine =kaklemine  (SgN  >kaklemine !12_S	et	f	\N
145976	kaklemine	"kaklemine %kakle  )MINE_vS  <kaklema ;30_V	et	f	\N
146020	lehtedes	lehtedes =lehte  (PlIn  >leht !22_S	et	f	\N
146021	lehtedes	lehtedes =ede  (SgIn  >leht+ede !16_S	et	f	\N
146052	sanomat	?sanomat =sanoma  (SgP  >sanoma !01_S	et	f	\N
146053	tampereel	?tampereel =tamperee  (SgAd  >tamperee !26_S	et	f	\N
146054	tampereel	?tampereel =tampereel  (SgN  >tampereel !22_S	et	f	\N
146081	hufvudstadsbladeti	?hufvudstadsbladeti =hufvudstadsbladeti  (SgG  >hufvudstadsbladett !22_S	et	f	\N
146082	hufvudstadsbladeti	?hufvudstadsbladeti =hufvudstadsbladeti  (IndPrPs_  >hufvudstadsbladettima !28_V	et	f	\N
146083	hufvudstadsbladeti	?hufvudstadsbladeti =hufvudstadsbladeti  (ImpPrSg2  >hufvudstadsbladettima !28_V	et	f	\N
146101	jagamisest	jagamisest =jagamise  (SgEl  >jagamine !12_S	et	f	\N
146103	jagamisest	"jagamine %jaga  )MINE_vS  <jagama ;27_V	et	f	\N
146107	hufvudstadsbladetit	### hufvudstadsbladetit	et	f	\N
146123	gümnaasiumiõpilast	gümnaasiumiõpilast =la  (SgEl  >gümnaasiumi+õpi+la !26_S	et	f	\N
146124	gümnaasiumiõpilast	gümnaasiumiõpilast =las  (SgP  >gümnaasiumi+õpi+laps !14_S	et	f	\N
146125	gümnaasiumiõpilast	gümnaasiumiõpilast =last  (SgN  >gümnaasiumi+õpi+last !22_S	et	f	\N
146126	gümnaasiumiõpilast	gümnaasiumiõpilast =õpilas  (SgP  >gümnaasiumi+õpilane !12_S	et	f	\N
146137	siirade	?siirade =siira  (PlG  >siira !16_S	et	f	\N
146138	vastutamatute	vastutamatute =vastutamatu  (PlG  >vastutamatu !01_A	et	f	\N
146141	vastutamatute	"vastutamatu %vastuta  )MATU_vA  <vastutama ;27_V	et	f	\N
146147	keid	?keid =kei  (PlN  >kei !26_S	et	f	\N
146148	keid	?keid =kei  (SgP  >kei !26_S	et	f	\N
146149	keid	?keid =keid  (SgN  >keid !22_S	et	f	\N
146150	pooltundise	?pooltundise =pooltundise  (SgG  >pooltundis !11_S	et	f	\N
146151	pooltundise	?pooltundise =undise  (SgG  >poolt+undis !09_S	et	f	\N
146152	pooltundise	?pooltundise =tundise  (SgG  >pool+tundis !09_S	et	f	\N
146171	helsingi	?helsingi =helsingi  (SgG  >helsing !02_S	et	f	\N
146172	helsingi	?helsingi =helsingi  (SgG  >helsink !22_S	et	f	\N
146174	helsingi	?helsingi =helsingi  (IndPrPs_  >helsinkima !28_V	et	f	\N
146175	helsingi	?helsingi =helsingi  (ImpPrSg2  >helsinkima !28_V	et	f	\N
146176	helsingi	?helsingi =helsi  (IndPrSg1^  >helssima !28_V	et	f	\N
146177	helsingi	?helsingi =helsin  (SgN^  >helsin !02_S	et	f	\N
146188	telekanalist	telekanalist =kanali  (SgEl  >tele+kanal !02_S	et	f	\N
146189	telekanalist	telekanalist =kanalis  (SgP  >tele+kanaline !12_A	et	f	\N
146190	telekanalist	"tele+kanaline %kana  )LINE_aA  <tele+kana ;17_S	et	f	\N
146191	telekanalist	"tele+kanaline %kanali  )NE_aA  <tele+kanal ;02_S	et	f	\N
146206	vaatatakse	?vaatatakse =vaatatakse  (SgG  >vaatatakne !02_A	et	f	\N
146207	vaatatakse	?vaatatakse =vaatatakse  (PlP  >vaatataks !22_S	et	f	\N
145848	täidesaadja	?täidesaadja =desaadja  (SgN  >täi+desaadja !01_S	et	f	\N
145849	täidesaadja	?täidesaadja =desaadja  (SgG  >täi+desaadja !01_S	et	f	\N
145850	täidesaadja	?täidesaadja =desaadja  (SgG  >täi+desaadjas !02_A	et	f	\N
145855	karnevaale	?karnevaale =karnevaa  (SgAll  >karnevaa !26_S	et	f	\N
145856	karnevaale	?karnevaale =karnevaale  (SgN  >karnevaale !16_S	et	f	\N
145857	karnevaale	?karnevaale =karnevaale  (SgG  >karnevaale !16_S	et	f	\N
145858	karnevaale	?karnevaale =karnevaale  (PlP  >karnevaal !22_S	et	f	\N
145893	tampax	### tampax	et	f	\N
145897	siniverelised	siniverelised =verelise  (PlN  >sini+vereline !12_A	et	f	\N
145898	siniverelised	"sini+vereline %vere  )LINE_aA  <sini+veri ;20_S	et	f	\N
145901	mata-hari	mata-hari =hari  (SgN  >mata-hari !24_S	et	f	\N
145902	mata-hari	mata-hari =hari  (IndPrPs_  >mata-harima !27_V	et	f	\N
145903	mata-hari	mata-hari =hari  (ImpPrSg2  >mata-harima !27_V	et	f	\N
145910	säilivad	säilivad =säili  (IndPrPl3  >säilima !28_V	et	f	\N
145911	säilivad	säilivad =säiliva  (PlN  >säiliv !02_A	et	f	\N
145912	säilivad	"säiliv %säili  )V_vA  <säilima ;28_V	et	f	\N
145918	võimsamaks	võimsamaks =võimsama  (SgTr  >võimsam !02_A	et	f	\N
145919	võimsamaks	"võimsam %võimsa  )M_cA  <võimas ;03_A	et	f	\N
145920	võimsamaks	"võimsam %võimsa  )M_cA  <võimas ;05_A	et	f	\N
145971	nenedes	?nenedes =nene  (PlIn  >nene !16_S	et	f	\N
145972	nenedes	?nenedes =nene  (Ger  >nenema !27_V	et	f	\N
146003	vaatakas	?vaatakas =vaataka  (SgIn  >vaataka !01_S	et	f	\N
146004	vaatakas	?vaatakas =vaataka  (SgIn  >vaatakas !02_A	et	f	\N
146005	vaatakas	?vaatakas =vaatakas  (SgN  >vaatakas !02_A	et	f	\N
146008	ameerikat	?ameerikat =ameerika  (SgP  >ameerikas !02_A	et	f	\N
146017	lehest	lehest =lehe  (SgEl  >leht !22_S	et	f	\N
146018	lehest	lehest =lehes  (SgP  >lehene !10_A	et	f	\N
146019	lehest	"lehene %lehe  )NE_aA  <leht ;22_S	et	f	\N
146031	liikagi	?liikagi =liika  (SgN^  >liika !16_S	et	f	\N
146032	liikagi	?liikagi =liika  (SgG^  >liikas !02_A	et	f	\N
146033	liikagi	?liikagi =liika  (SgG^  >liika !16_S	et	f	\N
146034	liikagi	?liikagi =liika  (IndPrPs_^  >liikama !29_V	et	f	\N
146035	liikagi	?liikagi =liika  (ImpPrSg2^  >liikama !29_V	et	f	\N
146039	riideit	?riideit =riideit  (SgN  >riideit !22_S	et	f	\N
146040	televiisoriprogramme	?televiisoriprogramme =televiisoriprogramme  (PlP  >televiisoriprogramm !22_S	et	f	\N
146041	televiisoriprogramme	?televiisoriprogramme =oriprogramme  (PlP  >tele+viis+oriprogramm !22_S	et	f	\N
146042	televiisoriprogramme	?televiisoriprogramme =viisoriprogramme  (PlP  >tele+viisoriprogramm !22_S	et	f	\N
146046	meediast	meediast =meedia  (SgEl  >meedia !01_S	et	f	\N
146047	meediast	meediast =dia  (SgEl  >mee+dia !26_S	et	f	\N
146048	meediast	meediast =dias  (SgP  >mee+diane !10_A	et	f	\N
146049	meediast	"mee+diane %dia  )NE_aA  <mee+dia ;26_S	et	f	\N
146063	täituks	täituks =täi  (KndPtIps  >täima !27_V	et	f	\N
146064	täituks	täituks =täitu  (SgTr  >täitu !01_A	et	f	\N
146065	täituks	"täitu %täi  )TU1_vS  <täima ;27_V	et	f	\N
146066	täituks	"täitu %täi  )TU2_kA  <täi ;26_S	et	f	\N
146067	täituks	täituks =täitu  (KndPrPs  >täituma !27_V	et	f	\N
146068	täituks	täituks =tuks  (SgN  >täi+tuks !22_S	et	f	\N
146074	tellivad	tellivad =telli  (IndPrPl3  >tellima !28_V	et	f	\N
146075	tellivad	tellivad =telliva  (PlN  >telliv !02_A	et	f	\N
146076	tellivad	"telliv %telli  )V_vA  <tellima ;28_V	et	f	\N
146111	soomerooslaste	soomerooslaste =las  (PlG  >soome+roos+laps !14_S	et	f	\N
146112	soomerooslaste	soomerooslaste =laste  (PlP  >soome+roos+last !22_S	et	f	\N
146119	hakkatas	?hakkatas =hakkata  (IndIpfSg3  >hakkatama !27_V	et	f	\N
146120	hakkatas	?hakkatas =atas  (SgN  >hakk+atas !07_S	et	f	\N
146139	arvustajate	arvustajate =arvustaja  (PlG  >arvustaja !01_S	et	f	\N
146140	arvustajate	"arvustaja %arvusta  )JA_vS  <arvustama ;27_V	et	f	\N
146145	avalikkuses	avalikkuses =avalikkuse  (SgIn  >avalikkus !11~09_S	et	f	\N
146146	avalikkuses	"avalikkus %avalikku  )US_aS  <avalik ;25_A	et	f	\N
146156	kuulijte	?kuulijte =kuulijte  (PlP  >kuulijt !22_S	et	f	\N
146157	kuulijte	?kuulijte =ijte  (SgN  >kuul+ijte !06_S	et	f	\N
146158	kuulijte	?kuulijte =ijte  (SgG  >kuul+ijte !06_S	et	f	\N
146159	kuulijte	?kuulijte =ijte  (PlP  >kuul+ijt !22_S	et	f	\N
146160	kuulijte	?kuulijte =lijte  (SgN  >kuu+lijte !06_S	et	f	\N
146161	kuulijte	?kuulijte =lijte  (SgG  >kuu+lijte !06_S	et	f	\N
146162	kuulijte	?kuulijte =lijte  (PlP  >kuu+lijt !22_S	et	f	\N
146164	vestlemise	vestlemise =vestlemise  (SgG  >vestlemine !12_S	et	f	\N
146166	vestlemise	"vestlemine %vestle  )MINE_vS  <vestlema ;30_V	et	f	\N
146173	11ndas	### 11ndas	et	f	\N
146178	ajakirjadus	?ajakirjadus =ajakirjadu  (IndIpfSg3  >ajakirjaduma !27_V	et	f	\N
146179	ajakirjadus	?ajakirjadus =ajakirjadus  (SgN  >ajakirjadus !11?09_S	et	f	\N
146180	ajakirjadus	?ajakirjadus =kirjadu  (SgIn  >aja+kirjadu !01_S	et	f	\N
146181	ajakirjadus	?ajakirjadus =kirjadus  (SgN  >aja+kirjadus !11_S	et	f	\N
146196	elanikkonda	elanikkonda =elanikkonda  (SgP  >elanikkond !22_S	et	f	\N
146197	elanikkonda	elanikkonda =elanikkonda  (SgAdt  >elanikkond !22_S	et	f	\N
146204	uunot	?uunot =uuno  (SgP  >uuno !16_S	et	f	\N
146205	uunot	?uunot =uunot  (SgN  >uunot !02_S	et	f	\N
145868	idolsid	?idolsid =idolsi  (PlN  >idolss !22_S	et	f	\N
145869	idolsid	?idolsid =idolsi  (IndPrSg2  >idolssima !28_V	et	f	\N
145888	telefoonikõnesid	### telefoonikõnesid	et	f	\N
145935	suvaliselt	suvaliselt =suvalise  (SgAbl  >suvaline !12_A	et	f	\N
145936	suvaliselt	"suvaline %suva  )LINE_aA  <suva ;17_S	et	f	\N
145937	suvaliselt	suvaliselt =suvaliselt  (ID  >suvaliselt !41_D	et	f	\N
145938	suvaliselt	"suvaliselt %suva  )LISELT_mD  <suva ;17_S	et	f	\N
145939	suvaliselt	"suvaliselt %suvalise  )LT_mD  <suvaline ;12_A	et	f	\N
145952	hollywood	?hollywood =hollywoo  (PlN  >hollywoo !26_S	et	f	\N
145953	hollywood	?hollywood =hollywoo  (SgP  >hollywoo !26_S	et	f	\N
145954	hollywood	?hollywood =hollywood  (SgN  >hollywood !22_S	et	f	\N
145989	teiset	### teiset	et	f	\N
146009	internettrükkideks	?internettrükkideks =internettrükki  (PlTr  >internettrükk !22_S	et	f	\N
146010	internettrükkideks	?internettrükkideks =nettrükki  (PlTr  >inter+nettrükk !22_S	et	f	\N
146015	internetiga	?internetiga =neti  (SgKom  >inter+neti !16_S	et	f	\N
146016	internetiga	?internetiga =neti  (SgKom  >inter+nett !22_AS	et	f	\N
146043	võmalik	?võmalik =võmalik  (SgN  >võmalik !25_A	et	f	\N
146044	paeb	?paeb =paeb  (SgN  >paeb !22_S	et	f	\N
146045	freelancer	?freelancer =freelancer  (SgN  >freelancer !02_S	et	f	\N
146055	jyväskyläs	### jyväskyläs	et	f	\N
146058	oulus	?oulus =oulu  (SgIn  >oulu !16_S	et	f	\N
146059	oulus	?oulus =oulu  (IndIpfSg3  >ouluma !28_V	et	f	\N
146060	oulus	?oulus =oulus  (SgN  >oulus !11~09_S	et	f	\N
146077	sanomate	?sanomate =sanoma  (PlG  >sanoma !01_S	et	f	\N
146086	lugijate	lugijate =lugija  (PlG  >lugija !01_S	et	f	\N
146087	lugijate	"lugija %lugi  )JA_vS  <lugema ;28_V	et	f	\N
146095	tahtlikult	tahtlikult =tahtliku  (SgAbl  >tahtlik !25_A	et	f	\N
146096	tahtlikult	tahtlikult =tahtlikult  (ID  >tahtlikult !41_D	et	f	\N
146097	tahtlikult	"tahtlikult %tahtliku  )LT_mD  <tahtlik ;25_A	et	f	\N
146100	teadmise	teadmise =teadmise  (SgG  >teadmine !12?10_S	et	f	\N
146102	teadmise	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
146106	en	### en	et	f	\N
146108	tellimise	tellimise =tellimise  (SgG  >tellimine !12_S	et	f	\N
146109	tellimise	"tellimine %telli  )MINE_vS  <tellima ;28_V	et	f	\N
146115	hbl	### hbl	et	f	\N
146127	idols-kavat	?idols-kavat =kavat  (SgN  >idols-kavat !02_S	et	f	\N
146128	nägemata	nägemata =näge  (SupAb  >nägema !28_V	et	f	\N
146129	nägemata	nägemata =nägemata  (ID  >nägemata !41_A	et	f	\N
146130	nägemata	"nägemata %näge  )MATA_vA  <nägema ;28_V	et	f	\N
146153	harilikult	harilikult =hariliku  (SgAbl  >harilik !25_A	et	f	\N
146154	harilikult	harilikult =harilikult  (ID  >harilikult !41_D	et	f	\N
146155	harilikult	"harilikult %hariliku  )LT_mD  <harilik ;25_A	et	f	\N
146182	sunninud	?sunninud =sunni  (PtsPtPs  >sunnima !28_V	et	f	\N
146183	sunninud	?sunninud =sunninu  (PlN  >sunninu !01_S	et	f	\N
146184	sunninud	?sunninud =sunninu  (IndPrSg2  >sunninuma !27_V	et	f	\N
146185	sunninud	?sunninud =sunninud  (ID  >sunninud !41_A	et	f	\N
146210	tõsielusari	tõsielusari =sari  (SgN  >tõsi+elu+sari !17_S	et	f	\N
146211	tõsielusari	tõsielusari =sari  (SgN  >tõsi+elu+sari !24_S	et	f	\N
146212	tõsielusari	tõsielusari =sari  (SgG  >tõsi+elu+sari !17_S	et	f	\N
146213	tõsielusari	tõsielusari =sari  (SgP  >tõsi+elu+sari !17_S	et	f	\N
146215	brother	?brother =brother  (SgN  >brother !02_S	et	f	\N
146221	race	?race =race  (SgN  >race !06_S	et	f	\N
146222	race	?race =race  (SgG  >race !06_S	et	f	\N
146234	tsensuuri	tsensuuri =tsensuuri  (SgG  >tsensuur !22_S	et	f	\N
146235	tsensuuri	tsensuuri =tsensuuri  (SgP  >tsensuur !22_S	et	f	\N
146236	tsensuuri	tsensuuri =tsensuuri  (SgAdt  >tsensuur !22_S	et	f	\N
146245	õpejõud	?õpejõud =õpejõu  (PlN  >õpejõu !26_S	et	f	\N
146246	õpejõud	?õpejõud =õpejõu  (SgP  >õpejõu !26_S	et	f	\N
146247	õpejõud	?õpejõud =õpejõud  (SgN  >õpejõud !22_S	et	f	\N
146261	madalkihti	madalkihti =kihti  (SgP  >madal+kiht !22_S	et	f	\N
146262	madalkihti	madalkihti =kihti  (SgAdt  >madal+kiht !22_S	et	f	\N
146273	meediad	meediad =meedia  (PlN  >meedia !01_S	et	f	\N
146274	meediad	meediad =dia  (PlN  >mee+dia !26_S	et	f	\N
146275	meediad	meediad =dia  (SgP  >mee+dia !26_S	et	f	\N
146325	telegraaf	telegraaf =telegraaf  (SgN  >telegraaf !22_S	et	f	\N
146326	telegraaf	telegraaf =graaf  (SgN  >tele+graaf !22_S	et	f	\N
146328	ulatus	ulatus =ulatu  (SgIn  >ulatu !01_AS	et	f	\N
146329	ulatus	"ulatu %ula  )TU1_vS  <ulama ;27_V	et	f	\N
146330	ulatus	ulatus =ulatu  (IndIpfSg3  >ulatuma !27_V	et	f	\N
146331	ulatus	ulatus =ulatus  (SgN  >ulatus !11_S	et	f	\N
146332	ulatus	"ulatus %ulata  )US_vS  <ulatama ;27_V	et	f	\N
146333	ulatus	"ulatus %ula  )TUS1_aS  <ulama ;27_V	et	f	\N
146334	edastamiseks	edastamiseks =edastamise  (SgTr  >edastamine !12_S	et	f	\N
146335	edastamiseks	"edastamine %edasta  )MINE_vS  <edastama ;27_V	et	f	\N
146358	mainitul	mainitul =mainitu  (SgAd  >mainitu !01_S	et	f	\N
146359	mainitul	"mainitu %maini  )TU1_vS  <mainima ;28_V	et	f	\N
146360	teatu	teatu =teatu  (SgN  >teatu !01_S	et	f	\N
146361	teatu	"teatu %tea  )TU1_vS  <teadma ;34_V	et	f	\N
145917	võimsaim	"võimsaim %võimsa  )IM_sA  <võimas ;05_A	et	f	\N
145930	huvitavamatelt	huvitavamatelt =huvitavama  (PlAbl  >huvitavam !02_A	et	f	\N
145931	huvitavamatelt	"huvitavam %huvita  )VAM_cA  <huvitama ;27_V	et	f	\N
145932	huvitavamatelt	"huvitavam %huvitava  )M_cA  <huvitav ;02_A	et	f	\N
145933	huvitavamatelt	huvitavamatelt =mate  (SgAbl  >huvi+tava+mate !16_S	et	f	\N
145934	huvitavamatelt	huvitavamatelt =mate  (PlAbl  >huvi+tava+matt !22_SA	et	f	\N
145945	kasutatkse	?kasutatkse =kasutatkse  (SgG  >kasutatkne !02_A	et	f	\N
145946	kasutatkse	?kasutatkse =tatkse  (SgN  >kasu+tatkse !06_S	et	f	\N
145947	kasutatkse	?kasutatkse =tatkse  (SgG  >kasu+tatkne !02_A	et	f	\N
145948	kasutatkse	?kasutatkse =tatkse  (SgG  >kasu+tatkse !06_S	et	f	\N
145949	kasutatkse	?kasutatkse =tatkse  (PlP  >kasu+tatks !22_S	et	f	\N
145950	kasutatkse	?kasutatkse =utatkse  (SgG  >kas+utatkne !02_A	et	f	\N
145958	kommipakkiga	### kommipakkiga	et	f	\N
145963	aastavanuseid	aastavanuseid =vanuse  (PlP  >aasta+vanus !09_S	et	f	\N
145964	aastavanuseid	aastavanuseid =vanuse  (PlP  >aasta+vanune !10_A	et	f	\N
145967	charlie	?charlie =charlie  (SgN  >charlie !01_S	et	f	\N
145968	charlie	?charlie =charlie  (SgG  >charlie !01_S	et	f	\N
145993	jooksnud	jooksnud =jooks  (PtsPtPs  >jooksma !32_V	et	f	\N
145994	jooksnud	jooksnud =jooksnu  (PlN  >jooksnu !01_S	et	f	\N
145995	jooksnud	"jooksnu %jooks  )NU_vS  <jooksma ;32_V	et	f	\N
145996	jooksnud	jooksnud =jooksnud  (ID  >jooksnud !41_A	et	f	\N
145997	jooksnud	"jooksnud %jooks  )NUD_vA  <jooksma ;32_V	et	f	\N
146038	helsitada	?helsitada =helsita  (Inf  >helsitama !27_V	et	f	\N
146056	kuopios	?kuopios =kuopio  (SgIn  >kuopio !01_S	et	f	\N
146057	kuopios	?kuopios =kuopios  (SgN  >kuopios !22_S	et	f	\N
146061	sönavabadus	?sönavabadus =sönavabadu  (IndIpfSg3  >sönavabaduma !27_V	et	f	\N
146062	sönavabadus	?sönavabadus =sönavabadus  (SgN  >sönavabadus !11?09_S	et	f	\N
146069	hs	### hs	et	f	\N
146088	mõtlemisesse	mõtlemisesse =mõtlemise  (SgIll  >mõtlemine !12_S	et	f	\N
146089	mõtlemisesse	"mõtlemine %mõtle  )MINE_vS  <mõtlema ;30_V	et	f	\N
146098	mõjumisest	mõjumisest =mõjumise  (SgEl  >mõjumine !12_S	et	f	\N
146099	mõjumisest	"mõjumine %mõju  )MINE_vS  <mõjuma ;27_V	et	f	\N
146113	eesmas	?eesmas =eesma  (IndIpfSg3  >eesmama !29_V	et	f	\N
146114	eesmas	?eesmas =eesmas  (SgN  >eesmas !07_S	et	f	\N
146121	programmid	programmid =programmi  (PlN  >programm !22_S	et	f	\N
146122	programmid	programmid =programmi  (IndPrSg2  >programmima !28_V	et	f	\N
146134	programmit	?programmit =programmi  (SgP  >programmi !01_S	et	f	\N
146135	sattusid	sattusid =sattu  (IndIpfSg2  >sattuma !27~28_V	et	f	\N
146136	sattusid	sattusid =sattu  (IndIpfPl3  >sattuma !27~28_V	et	f	\N
146142	programmist	programmist =programmi  (SgEl  >programm !22_S	et	f	\N
146143	programmist	programmist =programmis  (SgP  >programmine !12_A	et	f	\N
146144	programmist	"programmine %programmi  )NE_aA  <programm ;22_S	et	f	\N
146169	vabariiki	vabariiki =riiki  (SgP  >vaba+riik !22_S	et	f	\N
146170	vabariiki	vabariiki =riiki  (SgAdt  >vaba+riik !22_S	et	f	\N
146186	kaabelühendust	kaabelühendust =us  (SgP  >kaabel+ühend+uks !14_S	et	f	\N
146187	kaabelühendust	kaabelühendust =ühendus  (SgP  >kaabel+ühendus !11_S	et	f	\N
146192	raadiokanaleid	raadiokanaleid =lei  (PlN  >raadio+kana+lei !26_S	et	f	\N
146193	raadiokanaleid	raadiokanaleid =lei  (SgP  >raadio+kana+lei !26_S	et	f	\N
146194	raadiokanaleid	raadiokanaleid =leid  (SgN  >raadio+kana+leid !22_S	et	f	\N
146195	raadiokanaleid	raadiokanaleid =kanale  (PlP  >raadio+kanal !02_S	et	f	\N
146220	amazing	?amazing =amazing  (SgN  >amazing !02_S	et	f	\N
146248	nendeks	nendeks =nen  (PlTr  >see !00_P	et	f	\N
146249	nendeks	nendeks =nen  (PlTr  >tema !00_P	et	f	\N
146258	eksamhooaeg	?eksamhooaeg =eksamhooaeg  (SgN  >eksamhooaeg !22_S	et	f	\N
146260	eksamhooaeg	?eksamhooaeg =amhooaeg  (SgN  >eks+amhooaeg !02_S	et	f	\N
146263	meedial	meedial =meedia  (SgAd  >meedia !01_S	et	f	\N
146264	meedial	meedial =dia  (SgAd  >mee+dia !26_S	et	f	\N
146276	inimkonda	inimkonda =inimkonda  (SgP  >inimkond !22_S	et	f	\N
146277	inimkonda	inimkonda =inimkonda  (SgAdt  >inimkond !22_S	et	f	\N
146286	suulistel	suulistel =suulis  (PlAd  >suuline !12?10_AS	et	f	\N
146287	suulistel	"suuline %suu  )LINE_aA  <suu ;26_S	et	f	\N
146293	guttenbergi	?guttenbergi =guttenbergi  (SgG  >guttenberk !22_S	et	f	\N
146294	guttenbergi	?guttenbergi =guttenbergi  (SgP  >guttenberg !22_S	et	f	\N
146295	guttenbergi	?guttenbergi =guttenbergi  (SgAdt  >guttenberg !22_S	et	f	\N
146296	guttenbergi	?guttenbergi =guttenbergi  (IndPrPs_  >guttenberkima !28_V	et	f	\N
146297	guttenbergi	?guttenbergi =guttenbergi  (ImpPrSg2  >guttenberkima !28_V	et	f	\N
146298	guttenbergi	?guttenbergi =guttenber  (SgN^  >guttenber !02_S	et	f	\N
146307	massimeedia	massimeedia =dia  (SgN  >massi+mee+dia !26_S	et	f	\N
146308	massimeedia	massimeedia =dia  (SgG  >massi+mee+dia !26_S	et	f	\N
146309	massimeedia	massimeedia =meedia  (SgN  >massi+meedia !01_S	et	f	\N
146310	massimeedia	massimeedia =meedia  (SgG  >massi+meedia !01_S	et	f	\N
146317	mikael	?mikael =mikae  (SgAd  >mikae !26_S	et	f	\N
146318	mikael	?mikael =mikael  (SgN  >mikael !22_S	et	f	\N
146319	agricola	?agricola =agricola  (SgN  >agricola !01_S	et	f	\N
146320	agricola	?agricola =agricola  (SgG  >agricola !01_S	et	f	\N
146022	arvusmood	?arvusmood =arvusmoo  (PlN  >arvusmoo !26_S	et	f	\N
146023	arvusmood	?arvusmood =arvusmoo  (SgP  >arvusmoo !26_S	et	f	\N
146024	arvusmood	?arvusmood =arvusmood  (SgN  >arvusmood !22_S	et	f	\N
146025	arvusmood	?arvusmood =smoo  (PlN  >arvu+smoo !26_S	et	f	\N
146026	arvusmood	?arvusmood =smoo  (SgP  >arvu+smoo !26_S	et	f	\N
146027	arvusmood	?arvusmood =smood  (SgN  >arvu+smood !22_S	et	f	\N
146028	arvusmood	?arvusmood =usmoo  (PlN  >arv+usmoo !26_S	et	f	\N
146029	arvusmood	?arvusmood =usmoo  (SgP  >arv+usmoo !26_S	et	f	\N
146030	arvusmood	?arvusmood =usmood  (SgN  >arv+usmood !22_S	et	f	\N
146036	mõjukas	mõjukas =mõjuka  (SgIn  >mõjukas !02_A	et	f	\N
146037	mõjukas	mõjukas =mõjukas  (SgN  >mõjukas !02_A	et	f	\N
146050	helsingin	?helsingin =helsingi  (IndPrSg1  >helsinkima !28_V	et	f	\N
146051	helsingin	?helsingin =helsingin  (SgN  >helsingin !19_S	et	f	\N
146070	leheküljetel	?leheküljetel =leheküljete  (PlAd  >leheküljett !22_S	et	f	\N
146071	leheküljetel	?leheküljetel =külje  (PlAd  >lehe+külje !06_S	et	f	\N
146072	leheküljetel	?leheküljetel =küljete  (PlAd  >lehe+küljett !22_S	et	f	\N
146073	hss	### hss	et	f	\N
146078	kultuurtoimetuse	kultuurtoimetuse =toimetuse  (SgG  >kultuur+toimetus !11_S	et	f	\N
146079	kultuurtoimetuse	"kultuur+toimetus %toime  )TUS2_aS  <kultuur+toime ;06_S	et	f	\N
146080	kultuurtoimetuse	"kultuur+toimetus %toime  )TUS2_aS  <kultuur+toim ;22_S	et	f	\N
146084	tõeks	tõeks =tõe  (SgTr  >tõsi !15_S	et	f	\N
146085	tõeks	tõeks =tõe  (SgTr  >tõde !18_S	et	f	\N
146090	joonistatud	joonistatud =joonista  (PtsPtIps  >joonistama !27_V	et	f	\N
146091	joonistatud	joonistatud =joonistatu  (PlN  >joonistatu !01_S	et	f	\N
146092	joonistatud	"joonistatu %joonista  )TU1_vS  <joonistama ;27_V	et	f	\N
146093	joonistatud	joonistatud =joonistatud  (ID  >joonistatud !41_A	et	f	\N
146094	joonistatud	"joonistatud %joonista  )TUD_vA  <joonistama ;27_V	et	f	\N
146104	kirjutamisest	kirjutamisest =kirjutamise  (SgEl  >kirjutamine !12_S	et	f	\N
146105	kirjutamisest	"kirjutamine %kirjuta  )MINE_vS  <kirjutama ;27_V	et	f	\N
146110	hakada	?hakada =haka  (Inf  >hakama !27_V	et	f	\N
146116	lugemas	lugemas =luge  (SupIn  >lugema !28_V	et	f	\N
146117	lugemas	lugemas =lugema  (SgIn  >lugem !02_S	et	f	\N
146118	sanomatega	?sanomatega =sanoma  (PlKom  >sanoma !01_S	et	f	\N
146131	uskumatu	uskumatu =uskumatu  (SgN  >uskumatu !01_A	et	f	\N
146132	uskumatu	"uskumatu %usku  )MATU_vA  <uskuma ;28_V	et	f	\N
146133	uskumatu	uskumatu =uskumatu  (SgG  >uskumatu !01_A	et	f	\N
146163	omavahelise	omavahelise =vahelise  (SgG  >oma+vaheline !12_A	et	f	\N
146165	omavahelise	"oma+vaheline %vahe  )LINE_aA  <oma+vahe ;16_S	et	f	\N
146167	tähtisam	?tähtisam =tähtisam  (SgN  >tähtisam !02_A	et	f	\N
146168	tähtisam	?tähtisam =isam  (SgN  >täht+isam !02_A	et	f	\N
146198	kuulada	?kuulada =ada  (SgN  >kuul+ada !17_S	et	f	\N
146199	kuulada	?kuulada =ada  (SgG  >kuul+ada !17_S	et	f	\N
146200	kuulada	?kuulada =ada  (SgP  >kuul+ada !17_S	et	f	\N
146201	kuulada	?kuulada =lada  (SgN  >kuu+lada !17_S	et	f	\N
146202	kuulada	?kuulada =lada  (SgG  >kuu+lada !17_S	et	f	\N
146203	kuulada	?kuulada =lada  (SgP  >kuu+lada !17_S	et	f	\N
146216	hulkas	?hulkas =hulka  (IndIpfSg3  >hulkama !29_V	et	f	\N
146217	hulkas	?hulkas =hulkas  (SgN  >hulkas !07_S	et	f	\N
146223	kõrgelt	kõrgelt =kõrge  (SgAbl  >kõrge !01_A	et	f	\N
146224	kõrgelt	kõrgelt =kõrge  (PlAbl  >kõrk !22_A	et	f	\N
146225	kõrgelt	kõrgelt =kõrgelt  (ID  >kõrgelt !41_D	et	f	\N
146226	kõrgelt	"kõrgelt %kõrge  )LT_mD  <kõrge ;01_A	et	f	\N
146227	uutiseid	?uutiseid =uutise  (PlP  >uutis !09_S	et	f	\N
146228	uutiseid	?uutiseid =uutisei  (PlN  >uutisei !26_S	et	f	\N
146229	uutiseid	?uutiseid =uutisei  (SgP  >uutisei !26_S	et	f	\N
146230	uutiseid	?uutiseid =isei  (PlN  >uut+isei !26_S	et	f	\N
146231	uutiseid	?uutiseid =isei  (SgP  >uut+isei !26_S	et	f	\N
146232	uutiseid	?uutiseid =iseid  (SgN  >uut+iseid !22_S	et	f	\N
146233	hommiku-tv	### hommiku-tv	et	f	\N
146237	varase	varase =varase  (SgG  >varane !10_A	et	f	\N
146238	varase	"varane %vara  )NE_aA  <vara ;17_S	et	f	\N
146250	kõrgkultturist	?kõrgkultturist =kõrgkultturi  (SgEl  >kõrgkulttur !02_S	et	f	\N
146251	kõrgkultturist	?kõrgkultturist =kõrgkultturis  (SgP  >kõrgkultturis !09_S	et	f	\N
146252	kõrgkultturist	?kõrgkultturist =kõrgkultturist  (SgN  >kõrgkultturist !22_S	et	f	\N
146253	kõrgkultturist	?kõrgkultturist =kultturi  (SgEl  >kõrg+kultturi !01_S	et	f	\N
146254	kõrgkultturist	?kõrgkultturist =kultturi  (SgEl  >kõrg+kulttur !02_S	et	f	\N
146255	kõrgkultturist	?kõrgkultturist =kultturis  (SgP  >kõrg+kultturis !11_S	et	f	\N
146256	kõrgkultturist	?kõrgkultturist =kultturist  (SgN  >kõrg+kultturist !22_S	et	f	\N
146269	riigipea	riigipea =pea  (SgN  >riigi+pea !26_S	et	f	\N
146270	riigipea	riigipea =pea  (SgG  >riigi+pea !26_S	et	f	\N
146288	igapäevaelu	igapäevaelu =elu  (SgN  >iga+päeva+elu !17_S	et	f	\N
146289	igapäevaelu	igapäevaelu =elu  (SgG  >iga+päeva+elu !17_S	et	f	\N
146291	igapäevaelu	igapäevaelu =elu  (SgP  >iga+päeva+elu !17_S	et	f	\N
146303	lagunemise	lagunemise =lagunemise  (SgG  >lagunemine !12_S	et	f	\N
146304	lagunemise	"lagunemine %lagune  )MINE_vS  <lagunema ;27_V	et	f	\N
146208	kõrgkultuuriks	kõrgkultuuriks =iks  (SgN  >kõrg+kultuur+iks !22_S	et	f	\N
146209	kõrgkultuuriks	kõrgkultuuriks =kultuuri  (SgTr  >kõrg+kultuur !22_S	et	f	\N
146218	seikkailijat	?seikkailijat =seikkailija  (SgP  >seikkailija !01_S	et	f	\N
146219	seikkailijat	?seikkailijat =seikkailija  (SgP  >seikkailijas !02_A	et	f	\N
146239	konsentreerumist	?konsentreerumist =konsentreerumi  (SgEl  >konsentreerum !02_S	et	f	\N
146240	konsentreerumist	?konsentreerumist =konsentreerumis  (SgP  >konsentreerumis !09_S	et	f	\N
146241	konsentreerumist	?konsentreerumist =konsentreerumis  (SgP  >konsentreerumine !12_S	et	f	\N
146243	konsentreerumist	?konsentreerumist =konsentreerumist  (SgN  >konsentreerumist !22_S	et	f	\N
146257	detsembrikuu	detsembrikuu =kuu  (SgN  >detsembri+kuu !26_S	et	f	\N
146259	detsembrikuu	detsembrikuu =kuu  (SgG  >detsembri+kuu !26_S	et	f	\N
146265	puudust	puudust =puudus  (SgP  >puudus !11~09_S	et	f	\N
146266	puudust	puudust =dust  (SgN  >puu+dust !22_S	et	f	\N
146271	diivani	diivani =diiva  (SgTer  >diiva !16_S	et	f	\N
146272	diivani	diivani =diivani  (SgG  >diivan !02_S	et	f	\N
146278	informatsioonirikka	?informatsioonirikka =informatsioonirikka  (SgN  >informatsioonirikka !16_S	et	f	\N
146279	informatsioonirikka	?informatsioonirikka =informatsioonirikka  (SgG  >informatsioonirikka !16_S	et	f	\N
146280	informatsioonirikka	?informatsioonirikka =rikka  (SgG  >informatsiooni+rikas !07_A	et	f	\N
146285	seltskondlikutel	?seltskondlikutel =seltskondlikute  (PlAd  >seltskondlikutt !22_S	et	f	\N
146299	trükitu	trükitu =trükitu  (SgN  >trükitu !01_AS	et	f	\N
146300	trükitu	"trükitu %trüki  )TU1_vS  <trükkima ;28_V	et	f	\N
146301	trükitu	"trükitu %trüki  )TU2_kA  <trükk ;22_S	et	f	\N
146302	trükitu	trükitu =trükitu  (SgG  >trükitu !01_AS	et	f	\N
146338	vikipeedia	?vikipeedia =vikipeedia  (SgN  >vikipeedia !01_S	et	f	\N
146339	vikipeedia	?vikipeedia =vikipeedia  (SgG  >vikipeedia !01_S	et	f	\N
146352	turustamiskommunikatsiooni	turustamiskommunikatsiooni =kommunikatsiooni  (SgG  >turustamis+kommunikatsioon !22_S	et	f	\N
146353	turustamiskommunikatsiooni	turustamiskommunikatsiooni =kommunikatsiooni  (SgP  >turustamis+kommunikatsioon !22_S	et	f	\N
146354	turustamiskommunikatsiooni	turustamiskommunikatsiooni =kommunikatsiooni  (SgAdt  >turustamis+kommunikatsioon !22_S	et	f	\N
146355	reklaamiabinõu	reklaamiabinõu =nõu  (SgP  >reklaami+abi+nõu !26_S	et	f	\N
146356	reklaamiabinõu	reklaamiabinõu =nõu  (SgN  >reklaami+abi+nõu !26_S	et	f	\N
146357	reklaamiabinõu	reklaamiabinõu =nõu  (SgG  >reklaami+abi+nõu !26_S	et	f	\N
146366	ajutes	?ajutes =ajute  (PlIn  >ajutt !22_S	et	f	\N
146369	informatioonist	?informatioonist =informatiooni  (SgEl  >informatiooni !16_S	et	f	\N
146370	informatioonist	?informatioonist =informatiooni  (SgEl  >informatioon !22_S	et	f	\N
146371	informatioonist	?informatioonist =informatioonis  (SgP  >informatioonis !09_S	et	f	\N
146400	valdajad	valdajad =valdaja  (PlN  >valdaja !01_S	et	f	\N
146401	valdajad	"valdaja %valda  )JA_vS  <valdama ;29_V	et	f	\N
146402	valdajad	valdajad =aja  (PlN  >vald+aeg !22_S	et	f	\N
146408	subjektiivselt	subjektiivselt =subjektiivse  (SgAbl  >subjektiivne !02_A	et	f	\N
146409	subjektiivselt	subjektiivselt =subjektiivselt  (ID  >subjektiivselt !41_D	et	f	\N
146410	subjektiivselt	"subjektiivselt %subjektiivse  )LT_mD  <subjektiivne ;02_A	et	f	\N
146418	informatioonit	?informatioonit =informatiooni  (SgP  >informatiooni !16_S	et	f	\N
146419	nägemisvõimatu	nägemisvõimatu =võimatu  (SgN  >nägemis+võimatu !01_A	et	f	\N
146420	nägemisvõimatu	nägemisvõimatu =võimatu  (SgG  >nägemis+võimatu !01_A	et	f	\N
146424	vaikides	vaikides =vaiki  (PlIn  >vaik !22_S	et	f	\N
146425	vaikides	vaikides =vaiki  (Ger  >vaikima !27_V	et	f	\N
146437	nähtusel	nähtusel =nähtuse  (SgAd  >nähtus !11~09_S	et	f	\N
146438	nähtusel	"nähtus %näh  )TUS1_aS  <nägema ;28_V	et	f	\N
146443	teistesse	teistesse =teis  (PlIll  >teine !12_OP	et	f	\N
146444	teistesse	teistesse =teis  (PlIll  >teise !12_P	et	f	\N
146445	teistesse	teistesse =teiste  (PlIll  >teist !22_S	et	f	\N
146447	nähtustesse	nähtustesse =nähtus  (PlIll  >nähtus !11~09_S	et	f	\N
146448	nähtustesse	"nähtus %näh  )TUS1_aS  <nägema ;28_V	et	f	\N
146452	kirjakeel	kirjakeel =kee  (SgAd  >kirja+kesi !15_S	et	f	\N
146453	kirjakeel	kirjakeel =kee  (SgAd  >kirja+kee !26_S	et	f	\N
146454	kirjakeel	kirjakeel =keel  (SgN  >kirja+keel !13_S	et	f	\N
146474	usulised	usulised =usulise  (PlN  >usuline !12_A	et	f	\N
146475	usulised	"usuline %usu  )LINE_aA  <usk ;22_S	et	f	\N
146476	mitteusulistes	mitteusulistes =usulis  (PlIn  >mitte+usuline !12_A	et	f	\N
146477	mitteusulistes	"mitte+usuline %usu  )LINE_aA  <mitte+usk ;22_S	et	f	\N
146483	usulik	?usulik =usulik  (SgN  >usulik !25_A	et	f	\N
146499	räägijad	?räägijad =räägija  (PlN  >räägija !01_S	et	f	\N
146500	räägijad	?räägijad =räägija  (PlN  >räägijas !02_A	et	f	\N
146508	mõjupiirkonda	mõjupiirkonda =piirkonda  (SgP  >mõju+piirkond !22_S	et	f	\N
146509	mõjupiirkonda	mõjupiirkonda =piirkonda  (SgAdt  >mõju+piirkond !22_S	et	f	\N
146513	oskamisest	oskamisest =oskamise  (SgEl  >oskamine !12_S	et	f	\N
146514	oskamisest	"oskamine %oska  )MINE_vS  <oskama ;29_V	et	f	\N
146533	arto	?arto =arto  (SgN  >arto !16_S	et	f	\N
146534	arto	?arto =arto  (SgG  >arto !16_S	et	f	\N
146556	pidis	?pidis =pidi  (IndIpfSg3  >pidima !27_V	et	f	\N
146557	pidis	?pidis =pidis  (SgN  >pidis !09_S	et	f	\N
146214	big	### big	et	f	\N
146242	televisioonile	televisioonile =televisiooni  (SgAll  >televisioon !22_S	et	f	\N
146244	televisioonile	televisioonile =visiooni  (SgAll  >tele+visioon !22_S	et	f	\N
146267	brotheriks	?brotheriks =brotheri  (SgTr  >brotheri !01_S	et	f	\N
146268	brotheriks	?brotheriks =brotheri  (SgTr  >brother !02_S	et	f	\N
146281	meediaühiskonna	meediaühiskonna =konna  (SgG  >meedia+ühis+konn !22_S	et	f	\N
146282	meediaühiskonna	meediaühiskonna =konna  (SgP  >meedia+ühis+konn !22_S	et	f	\N
146283	meediaühiskonna	meediaühiskonna =konna  (SgAdt  >meedia+ühis+konn !22_S	et	f	\N
146284	meediaühiskonna	meediaühiskonna =ühiskonna  (SgG  >meedia+ühiskond !22_S	et	f	\N
146290	tähelepanuväärselt	tähelepanuväärselt =väärse  (SgAbl  >tähele+panu+väärne !02_A	et	f	\N
146292	tähelepanuväärselt	"tähele+panu+väärselt %väärse  )LT_mD  <tähele+panu+väärne ;02_A	et	f	\N
146313	rahvakeelde	rahvakeelde =keel  (SgAdt  >rahva+keel !13_S	et	f	\N
146314	rahvakeelde	rahvakeelde =keelde  (PlP  >rahva+keeld !22_S	et	f	\N
146315	niiöelda	?niiöelda =niiöelda  (IndPrPs_  >niiöeldama !27_V	et	f	\N
146316	niiöelda	?niiöelda =niiöelda  (ImpPrSg2  >niiöeldama !27_V	et	f	\N
146321	reeglipäraselt	reeglipäraselt =pärase  (SgAbl  >reegli+pärane !10_A	et	f	\N
146322	reeglipäraselt	"reegli+pärane %pära  )NE_aA  <reegli+pära ;17_S	et	f	\N
146323	reeglipäraselt	"reegli+päraselt %pära  )SELT_mD  <reegli+pära ;17_S	et	f	\N
146324	reeglipäraselt	"reegli+päraselt %pärase  )LT_mD  <reegli+pärane ;10_A	et	f	\N
146363	tõelisuse	tõelisuse =tõelisuse  (SgG  >tõelisus !11_S	et	f	\N
146364	tõelisuse	"tõelisus %tõe  )LISUS_aS  <tõsi ;15_S	et	f	\N
146365	tõelisuse	"tõelisus %tõe  )LISUS_aS  <tõde ;18_S	et	f	\N
146388	usaldatavus	usaldatavus =usaldatavus  (SgN  >usaldatavus !11?09_S	et	f	\N
146389	usaldatavus	"usaldatavus %usalda  )TAVUS_aS  <usaldama ;27_V	et	f	\N
146390	usaldatavus	"usaldatavus %usaldatava  )US_aS  <usaldatav ;02_A	et	f	\N
146413	algamisega	algamisega =algamise  (SgKom  >algamine !12_S	et	f	\N
146414	algamisega	"algamine %alga  )MINE_vS  <algama ;29_V	et	f	\N
146415	meediatõelisuses	meediatõelisuses =tõelisuse  (SgIn  >meedia+tõelisus !11_S	et	f	\N
146416	meediatõelisuses	"meedia+tõelisus %tõe  )LISUS_aS  <meedia+tõsi ;15_S	et	f	\N
146417	meediatõelisuses	"meedia+tõelisus %tõe  )LISUS_aS  <meedia+tõde ;18_S	et	f	\N
146468	iseennale	?iseennale =iseenna  (SgAll  >iseenna !16_S	et	f	\N
146469	iseennale	?iseennale =enna  (SgAll  >ise+enna !16_S	et	f	\N
146470	millisi	?millisi =millisi  (ID  >millisi !41_D	et	f	\N
146481	keelekasutusele	keelekasutusele =kasutuse  (SgAll  >keele+kasutus !11_S	et	f	\N
146482	keelekasutusele	"keele+kasutus %kasu  )TUS2_aS  <keele+kasu ;17_S	et	f	\N
146501	suurima	"suurim %suuri  )IM_sA  <suur ;13_A	et	f	\N
146502	suurima	suurima =ima  (SgN  >suur+ima !17_S	et	f	\N
146503	suurima	suurima =ima  (SgG  >suur+ima !17_S	et	f	\N
146504	suurima	suurima =ima  (SgP  >suur+ima !17_S	et	f	\N
146505	suurima	suurima =rima  (SgN  >suu+rima !17_S	et	f	\N
146506	suurima	suurima =rima  (SgG  >suu+rima !17_S	et	f	\N
146507	suurima	suurima =rima  (SgP  >suu+rima !17_S	et	f	\N
146517	suremist	suremist =suremis  (SgP  >suremine !12_S	et	f	\N
146518	suremist	"suremine %sure  )MINE_vS  <surema ;36_V	et	f	\N
146526	arenemises	arenemises =arenemise  (SgIn  >arenemine !12_S	et	f	\N
146527	arenemises	"arenemine %arene  )MINE_vS  <arenema ;27_V	et	f	\N
146535	arto	?arto =arto  (SgN  >arto !16_S	et	f	\N
146536	arto	?arto =arto  (SgG  >arto !16_S	et	f	\N
146547	arukas	arukas =aruka  (SgIn  >arukas !02_A	et	f	\N
146548	arukas	arukas =arukas  (SgN  >arukas !02_A	et	f	\N
146561	paeval	?paeval =paeva  (SgAd  >paeva !16_S	et	f	\N
146562	paeval	?paeval =paeval  (SgN  >paeval !02_S	et	f	\N
146563	keskpäevaeina	?keskpäevaeina =keskpäevaei  (SgEs  >keskpäevaei !26_S	et	f	\N
146564	keskpäevaeina	?keskpäevaeina =eina  (SgN  >kesk+päeva+eina !16_S	et	f	\N
146565	keskpäevaeina	?keskpäevaeina =eina  (SgG  >kesk+päeva+eina !16_S	et	f	\N
146566	keskpäevaeina	?keskpäevaeina =päevaei  (SgEs  >kesk+päevaei !26_S	et	f	\N
146567	telekasi	telekasi =telekasi  (SgG  >telekas !02_S	et	f	\N
146568	telekasi	telekasi =telekasi  (PlP  >telekane !12_A	et	f	\N
146569	telekasi	"telekane %teleka  )NE_aA  <telekas ;02_S	et	f	\N
146575	imre	?imre =imre  (SgN  >imre !06_S	et	f	\N
146576	imre	?imre =imre  (SgG  >imre !06_S	et	f	\N
146577	imre	?imre =imre  (PlP  >imr !22_S	et	f	\N
146578	imre	?imre =imre  (IndPrPs_  >imrema !27_V	et	f	\N
146579	imre	?imre =imre  (ImpPrSg2  >imrema !27_V	et	f	\N
146596	hapsburgi	?hapsburgi =hapsburgi  (SgG  >hapsburg !02_S	et	f	\N
146598	hapsburgi	?hapsburgi =hapsburgi  (SgG  >hapsburk !22_S	et	f	\N
146599	hapsburgi	?hapsburgi =hapsburgi  (IndPrPs_  >hapsburkima !28_V	et	f	\N
146600	hapsburgi	?hapsburgi =hapsburgi  (ImpPrSg2  >hapsburkima !28_V	et	f	\N
146601	hapsburgi	?hapsburgi =hapsbur  (SgN^  >hapsbur !02_S	et	f	\N
146602	vangistanud	vangistanud =vangista  (PtsPtPs  >vangistama !27_V	et	f	\N
146603	vangistanud	vangistanud =vangistanu  (PlN  >vangistanu !01_S	et	f	\N
146604	vangistanud	"vangistanu %vangista  )NU_vS  <vangistama ;27_V	et	f	\N
146605	vangistanud	vangistanud =vangistanud  (ID  >vangistanud !41_A	et	f	\N
146606	vangistanud	"vangistanud %vangista  )NUD_vA  <vangistama ;27_V	et	f	\N
146305	piibel	piibel =piibe  (PlAd  >piip !22_S	et	f	\N
146306	piibel	piibel =piibel  (SgN  >piibel !02_S	et	f	\N
146311	tõlkimine	tõlkimine =tõlkimine  (SgN  >tõlkimine !12_S	et	f	\N
146312	tõlkimine	"tõlkimine %tõlki  )MINE_vS  <tõlkima ;28_V	et	f	\N
146347	kandjate	kandjate =kandja  (PlG  >kandja !01_S	et	f	\N
146349	kandjate	"kandja %kand  )JA_vS  <kandma ;34_V	et	f	\N
146386	rahvusvahelist	rahvusvahelist =vahelis  (SgP  >rahvus+vaheline !12_A	et	f	\N
146387	rahvusvahelist	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
146411	balkani	?balkani =balka  (SgTer  >balka !16_S	et	f	\N
146412	balkani	?balkani =balkani  (SgG  >balkan !02_S	et	f	\N
146426	täpsem	täpsem =täpsem  (SgN  >täpsem !02_A	et	f	\N
146427	täpsem	"täpsem %täpse  )M_cA  <täpne ;02_A	et	f	\N
146439	mõjutused	mõjutused =mõjutuse  (PlN  >mõjutus !11_S	et	f	\N
146440	mõjutused	"mõjutus %mõjuta  )US_vS  <mõjutama ;27_V	et	f	\N
146441	mõjutused	"mõjutus %mõju  )TUS1_aS  <mõjuma ;27_V	et	f	\N
146442	mõjutused	"mõjutus %mõju  )TUS2_aS  <mõju ;17_S	et	f	\N
146458	tahtakse	?tahtakse =tahtakse  (SgG  >tahtakne !02_A	et	f	\N
146478	ühendustes	ühendustes =ühendus  (PlIn  >ühendus !11_S	et	f	\N
146479	ühendustes	"ühendus %ühenda  )US_vS  <ühendama ;27_V	et	f	\N
146480	ühendustes	ühendustes =us  (PlIn  >ühend+uks !14_S	et	f	\N
146484	ilmalikust	ilmalikust =ilmaliku  (SgEl  >ilmalik !25_A	et	f	\N
146485	ilmalikust	ilmalikust =ilmalikus  (SgP  >ilmalikus !11?09_S	et	f	\N
146486	ilmalikust	"ilmalikus %ilmaliku  )US_aS  <ilmalik ;25_A	et	f	\N
146489	üldisem	üldisem =üldisem  (SgN  >üldisem !02_A	et	f	\N
146490	üldisem	"üldisem %üldise  )M_cA  <üldine ;10_A	et	f	\N
146491	üldisem	"üldisem %üldise  )M_cA  <üldine ;12_A	et	f	\N
146492	suurimal	"suurim %suuri  )IM_sA  <suur ;13_A	et	f	\N
146493	suurimal	suurimal =ima  (SgAd  >suur+ima !17_S	et	f	\N
146494	suurimal	suurimal =imal  (SgN  >suur+imal !02_A	et	f	\N
146495	suurimal	suurimal =rima  (SgAd  >suu+rima !17_S	et	f	\N
146496	avalikus	avalikus =avaliku  (SgIn  >avalik !25_A	et	f	\N
146497	avalikus	avalikus =avalikus  (SgN  >avalikus !11?09_S	et	f	\N
146498	avalikus	"avalikus %avaliku  )US_aS  <avalik ;25_A	et	f	\N
146528	seisukorda	seisukorda =korda  (SgP  >seisu+kord !22_S	et	f	\N
146529	seisukorda	seisukorda =korda  (SgAdt  >seisu+kord !22_S	et	f	\N
146530	avalikkus	avalikkus =avalikkus  (SgN  >avalikkus !11~09_S	et	f	\N
146531	avalikkus	"avalikkus %avalikku  )US_aS  <avalik ;25_A	et	f	\N
146537	projektijuhtina	?projektijuhtina =ina  (SgN  >projekti+juht+ina !17_S	et	f	\N
146538	projektijuhtina	?projektijuhtina =ina  (SgG  >projekti+juht+ina !17_S	et	f	\N
146539	projektijuhtina	?projektijuhtina =ina  (SgP  >projekti+juht+ina !17_S	et	f	\N
146540	vabakutselisena	vabakutselisena =kutselise  (SgEs  >vaba+kutseline !12_A	et	f	\N
146541	vabakutselisena	"vaba+kutseline %kutse  )LINE_aA  <vaba+kutse ;06_S	et	f	\N
146546	huvim	?huvim =huvim  (SgN  >huvim !02_A	et	f	\N
146549	mötles	?mötles =mötle  (IndIpfSg3  >mötlema !30_V	et	f	\N
146550	mötles	?mötles =mötles  (SgN  >mötles !09_S	et	f	\N
146554	saas	?saas =saa  (SgIn  >saa !26_S	et	f	\N
146555	saas	?saas =saas  (SgN  >saas !22_S	et	f	\N
146572	kitarri	kitarri =kitarri  (SgG  >kitarr !22_S	et	f	\N
146573	kitarri	kitarri =kitarri  (SgP  >kitarr !22_S	et	f	\N
146574	kitarri	kitarri =kitarri  (SgAdt  >kitarr !22_S	et	f	\N
146611	bela	?bela =bela  (SgN  >bela !17_S	et	f	\N
146612	bela	?bela =bela  (SgG  >bela !17_S	et	f	\N
146613	bela	?bela =bela  (SgP  >bela !17_S	et	f	\N
146614	bela	?bela =bela  (IndPrPs_  >belama !27_V	et	f	\N
146615	bela	?bela =bela  (ImpPrSg2  >belama !27_V	et	f	\N
146620	kommunistud	?kommunistud =kommunistu  (IndPrSg2  >kommunistuma !27_V	et	f	\N
146623	kommunistud	?kommunistud =munistu  (PlN  >kom+munistu !01_S	et	f	\N
146637	saib	?saib =saib  (SgN  >saib !22_S	et	f	\N
146655	arreteerinud	arreteerinud =arreteeri  (PtsPtPs  >arreteerima !28_V	et	f	\N
146656	arreteerinud	arreteerinud =arreteerinu  (PlN  >arreteerinu !01_S	et	f	\N
146657	arreteerinud	"arreteerinu %arreteeri  )NU_vS  <arreteerima ;28_V	et	f	\N
146658	arreteerinud	arreteerinud =arreteerinud  (ID  >arreteerinud !41_A	et	f	\N
146659	arreteerinud	"arreteerinud %arreteeri  )NUD_vA  <arreteerima ;28_V	et	f	\N
146668	surmanuhtuse	?surmanuhtuse =surmanuhtuse  (SgG  >surmanuhtus !11~09_S	et	f	\N
146669	surmanuhtuse	?surmanuhtuse =nuhtuse  (SgG  >surma+nuhtus !11~09_S	et	f	\N
146670	surmanuhtuse	?surmanuhtuse =anuhtuse  (SgG  >surm+anuhtus !11_S	et	f	\N
146685	kaugetesse	kaugetesse =kauge  (PlIll  >kauge !01_A	et	f	\N
146687	kaugetesse	kaugetesse =e  (PlIll  >kaug+esi !15_S	et	f	\N
146703	õlu-aedis	?õlu-aedis =aedi  (SgIn  >õlu-aedi !16_S	et	f	\N
146704	õlu-aedis	?õlu-aedis =aedi  (SgIn  >õlu-aet !22_S	et	f	\N
146705	õlu-aedis	?õlu-aedis =aedi  (IndIpfSg3  >õlu-aedima !28_V	et	f	\N
146706	õlu-aedis	?õlu-aedis =aedis  (SgN  >õlu-aedis !09_S	et	f	\N
146707	jüüakse	?jüüakse =jüüakse  (SgG  >jüüakne !02_A	et	f	\N
146708	jüüakse	?jüüakse =jüüakse  (PlP  >jüüaks !22_S	et	f	\N
146709	kohtusse	kohtusse =kohtu  (SgIll  >kohus !05_S	et	f	\N
146710	kohtusse	kohtusse =kohtus  (SgAdt  >kohtune !12_A	et	f	\N
146327	gramofon	?gramofon =gramofon  (SgN  >gramofon !19_S	et	f	\N
146336	meediaühiskonda	meediaühiskonda =ühiskonda  (SgP  >meedia+ühiskond !22_S	et	f	\N
146337	meediaühiskonda	meediaühiskonda =ühiskonda  (SgAdt  >meedia+ühiskond !22_S	et	f	\N
146340	informatiooni	?informatiooni =informatioo  (SgTer  >informatioo !26_S	et	f	\N
146341	informatiooni	?informatiooni =informatiooni  (SgN  >informatiooni !16_S	et	f	\N
146342	informatiooni	?informatiooni =informatiooni  (SgG  >informatiooni !16_S	et	f	\N
146343	informatiooni	?informatiooni =informatiooni  (SgG  >informatioon !22_S	et	f	\N
146344	informatiooni	?informatiooni =informatiooni  (SgP  >informatioon !22_S	et	f	\N
146345	informatiooni	?informatiooni =informatiooni  (SgAdt  >informatioon !22_S	et	f	\N
146346	informatiooni	?informatiooni =informatiooni  (IndPrPs_  >informatioonima !28_V	et	f	\N
146348	informatiooni	?informatiooni =informatiooni  (ImpPrSg2  >informatioonima !28_V	et	f	\N
146350	wikipedias	?wikipedias =wikipedia  (SgIn  >wikipedia !01_S	et	f	\N
146351	wikipedias	?wikipedias =wikipedias  (SgN  >wikipedias !11_S	et	f	\N
146372	väärsus	väärsus =väärsus  (SgN  >väärsus !11~09_S	et	f	\N
146373	väärsus	"väärsus %väärse  )US_aS  <väärne ;02_A	et	f	\N
146374	meedias	meedias =meedia  (SgIn  >meedia !01_S	et	f	\N
146375	meedias	meedias =dia  (SgIn  >mee+dia !26_S	et	f	\N
146376	käsitlebgi	?käsitlebgi =käsitlebgi  (SgG  >käsitlebg !22_S	et	f	\N
146377	käsitlebgi	?käsitlebgi =käsitlebgi  (SgP  >käsitlebg !22_S	et	f	\N
146378	käsitlebgi	?käsitlebgi =käsitlebgi  (SgAdt  >käsitlebg !22_S	et	f	\N
146379	käsitlebgi	?käsitlebgi =käsitlebgi  (IndPrPs_  >käsitlebgima !28_V	et	f	\N
146380	käsitlebgi	?käsitlebgi =käsitlebgi  (ImpPrSg2  >käsitlebgima !28_V	et	f	\N
146381	väljunud	väljunud =välju  (PtsPtPs  >väljuma !27_V	et	f	\N
146382	väljunud	väljunud =väljunu  (PlN  >väljunu !01_S	et	f	\N
146383	väljunud	"väljunu %välju  )NU_vS  <väljuma ;27_V	et	f	\N
146384	väljunud	väljunud =väljunud  (ID  >väljunud !41_A	et	f	\N
146385	väljunud	"väljunud %välju  )NUD_vA  <väljuma ;27_V	et	f	\N
146394	propagandast	propagandast =propaganda  (SgEl  >propaganda !16_S	et	f	\N
146395	propagandast	propagandast =propagandas  (SgP  >propagandane !12_A	et	f	\N
146396	propagandast	"propagandane %propaganda  )NE_aA  <propaganda ;16_S	et	f	\N
146428	matti	matti =matti  (SgP  >matt !22_SA	et	f	\N
146429	matti	matti =matti  (SgAdt  >matt !22_SA	et	f	\N
146430	mervi	?mervi =mervi  (SgN  >mervi !16_S	et	f	\N
146431	mervi	?mervi =mervi  (SgG  >mervi !16_S	et	f	\N
146432	mervi	?mervi =mervi  (SgG  >merv !22_S	et	f	\N
146433	mervi	?mervi =mervi  (SgP  >merv !22_S	et	f	\N
146434	mervi	?mervi =mervi  (SgAdt  >merv !22_S	et	f	\N
146435	mervi	?mervi =mervi  (IndPrPs_  >mervima !28_V	et	f	\N
146436	mervi	?mervi =mervi  (ImpPrSg2  >mervima !28_V	et	f	\N
146459	teistelgi	teistelgi =telgi  (SgG  >teis+telk !22_S	et	f	\N
146460	teistelgi	teistelgi =telgi  (SgP  >teis+telg !22_S	et	f	\N
146461	teistelgi	teistelgi =telgi  (SgAdt  >teis+telg !22_S	et	f	\N
146462	teistelgi	teistelgi =telgi  (PlP  >teis+telg !22_S	et	f	\N
146463	teistelgi	teistelgi =teis  (PlAd^  >teine !12_OP	et	f	\N
146464	teistelgi	teistelgi =teis  (PlAd^  >teise !12_P	et	f	\N
146465	teistelgi	teistelgi =teiste  (PlAd^  >teist !22_S	et	f	\N
146466	uurimisele	uurimisele =uurimise  (SgAll  >uurimine !12_S	et	f	\N
146467	uurimisele	"uurimine %uuri  )MINE_vS  <uurima ;28_V	et	f	\N
146471	suhed	?suhed =suhe  (IndPrSg2  >suhema !27_V	et	f	\N
146487	arenemisele	arenemisele =arenemise  (SgAll  >arenemine !12_S	et	f	\N
146488	arenemisele	"arenemine %arene  )MINE_vS  <arenema ;27_V	et	f	\N
146510	loobuvad	loobuvad =loobu  (IndPrPl3  >loobuma !27_V	et	f	\N
146511	loobuvad	loobuvad =loobuva  (PlN  >loobuv !02_A	et	f	\N
146512	loobuvad	"loobuv %loobu  )V_vA  <loobuma ;27_V	et	f	\N
146515	lähemas	lähemas =lähema  (SgIn  >lähem !02_A	et	f	\N
146516	lähemas	"lähem %lähe  )M_cA  <lähike ;12_A	et	f	\N
146542	peeteri	peeteri =peeteri  (SgG  >peeter !02_S	et	f	\N
146543	peeteri	peeteri =eri  (SgN  >peet+eri !17_S	et	f	\N
146544	peeteri	peeteri =eri  (SgG  >peet+eri !17_S	et	f	\N
146545	peeteri	peeteri =eri  (SgP  >peet+eri !17_S	et	f	\N
146584	lapsevenamad	?lapsevenamad =lapsevenama  (PlN  >lapsevenam !02_A	et	f	\N
146585	lapsevenamad	?lapsevenamad =venama  (PlN  >lapse+venam !02_A	et	f	\N
146586	lapsevenamad	?lapsevenamad =evenama  (PlN  >laps+evenam !02_A	et	f	\N
146594	värbasib	### värbasib	et	f	\N
146616	töötamiseks	töötamiseks =töötamise  (SgTr  >töötamine !12_S	et	f	\N
146617	töötamiseks	"töötamine %tööta  )MINE_vS  <töötama ;27_V	et	f	\N
146628	mõrvanud	mõrvanud =mõrva  (PtsPtPs  >mõrvama !29_V	et	f	\N
146629	mõrvanud	mõrvanud =mõrvanu  (PlN  >mõrvanu !01_S	et	f	\N
146630	mõrvanud	"mõrvanu %mõrva  )NU_vS  <mõrvama ;29_V	et	f	\N
146631	mõrvanud	mõrvanud =mõrvanud  (ID  >mõrvanud !41_A	et	f	\N
146632	mõrvanud	"mõrvanud %mõrva  )NUD_vA  <mõrvama ;29_V	et	f	\N
146638	algasib	### algasib	et	f	\N
146646	pälju	?pälju =pälju  (SgN  >pälju !16_S	et	f	\N
146647	pälju	?pälju =pälju  (SgG  >pälju !16_S	et	f	\N
146648	pälju	?pälju =pälju  (IndPrPs_  >päljuma !27_V	et	f	\N
146362	teatu	teatu =teatu  (SgG  >teatu !01_S	et	f	\N
146367	meediatest	meediatest =meedia  (PlEl  >meedia !01_S	et	f	\N
146368	meediatest	meediatest =test  (SgN  >meedia+test !22_S	et	f	\N
146391	natsi-	natsi- =natsi  (SgG  >nats !22_S	et	f	\N
146392	natsi-	natsi- =natsi  (SgP  >nats !22_S	et	f	\N
146393	natsi-	natsi- =natsi  (SgAdt  >nats !22_S	et	f	\N
146397	tõelisus	tõelisus =tõelisus  (SgN  >tõelisus !11_S	et	f	\N
146398	tõelisus	"tõelisus %tõe  )LISUS_aS  <tõsi ;15_S	et	f	\N
146399	tõelisus	"tõelisus %tõe  )LISUS_aS  <tõde ;18_S	et	f	\N
146403	ruandas	?ruandas =ruanda  (SgIn  >ruanda !01_S	et	f	\N
146404	ruandas	?ruandas =ruanda  (IndIpfSg3  >ruandama !27_V	et	f	\N
146405	ruandas	?ruandas =ruandas  (SgN  >ruandas !07_S	et	f	\N
146406	raadiokanal	raadiokanal =kana  (SgAd  >raadio+kana !17_S	et	f	\N
146407	raadiokanal	raadiokanal =kanal  (SgN  >raadio+kanal !02_S	et	f	\N
146421	kriitiliselt	kriitiliselt =kriitilise  (SgAbl  >kriitiline !12_A	et	f	\N
146422	kriitiliselt	kriitiliselt =kriitiliselt  (ID  >kriitiliselt !41_D	et	f	\N
146423	kriitiliselt	"kriitiliselt %kriitilise  )LT_mD  <kriitiline ;12_A	et	f	\N
146446	liituvatesse	liituvatesse =liituva  (PlIll  >liituv !02_A	et	f	\N
146449	liituvatesse	"liituv %liitu  )V_vA  <liituma ;27_V	et	f	\N
146450	poolele	poolele =poole  (SgAll  >pool !13_NS	et	f	\N
146451	poolele	poolele =poole  (PlAll  >pool !22_S	et	f	\N
146455	kirjakeelt	kirjakeelt =kee  (SgAbl  >kirja+kesi !15_S	et	f	\N
146456	kirjakeelt	kirjakeelt =kee  (SgAbl  >kirja+kee !26_S	et	f	\N
146457	kirjakeelt	kirjakeelt =keel  (SgP  >kirja+keel !13_S	et	f	\N
146472	1500-ndail	?-ndail =ndai  (SgAd  >-ndai !26_S	et	f	\N
146473	1500-ndail	?-ndail =ndail  (SgN  >-ndail !22_S	et	f	\N
146519	tehaks	?tehaks =teha  (SgTr  >teha !17_S	et	f	\N
146520	tehaks	?tehaks =teha  (KndPrPs  >tehama !27_V	et	f	\N
146521	hakataks	hakataks =haka  (KndPrIps  >hakkama !29_V	et	f	\N
146522	hakataks	hakataks =hakata  (KndPrPs  >hakatama !27_V	et	f	\N
146523	mõjutustava	mõjutustava =tava  (SgN  >mõjutus+tava !17_S	et	f	\N
146524	mõjutustava	mõjutustava =tava  (SgG  >mõjutus+tava !17_S	et	f	\N
146525	mõjutustava	mõjutustava =tava  (SgP  >mõjutus+tava !17_S	et	f	\N
146532	nimid	?nimid =nimi  (IndPrSg2  >nimima !27_V	et	f	\N
146551	hundipassi	hundipassi =passi  (SgG  >hundi+pass !22_S	et	f	\N
146552	hundipassi	hundipassi =passi  (SgP  >hundi+pass !22_S	et	f	\N
146553	hundipassi	hundipassi =passi  (SgAdt  >hundi+pass !22_S	et	f	\N
146570	mangin	?mangin =mangi  (IndPrSg1  >mankima !28_V	et	f	\N
146571	mangin	?mangin =mangin  (SgN  >mangin !02_S	et	f	\N
146587	noorema	noorema =noorema  (SgG  >noorem !02_A	et	f	\N
146589	noorema	"noorem %noore  )M_cA  <noor ;13_AS	et	f	\N
146590	noorema	noorema =ema  (SgN  >noor+ema !17_S	et	f	\N
146591	noorema	noorema =ema  (SgG  >noor+ema !17_S	et	f	\N
146592	noorema	noorema =ema  (SgP  >noor+ema !17_S	et	f	\N
146593	luppsekk	?luppsekk =luppsekk  (SgN  >luppsekk !22_S	et	f	\N
146595	sõjavägis	?sõjavägis =sõjavägis  (SgN  >sõjavägis !09_S	et	f	\N
146597	sõjavägis	?sõjavägis =vägis  (SgN  >sõja+vägis !09_S	et	f	\N
146608	tagastasib	### tagastasib	et	f	\N
146618	kunni	kunni =kunni  (SgG  >kunn !22_S	et	f	\N
146622	kunni	kunni =kunni  (SgP  >kunn !22_S	et	f	\N
146624	kunni	kunni =kunni  (SgAdt  >kunn !22_S	et	f	\N
146633	kommunistikis	?kommunistikis =kommunistikis  (SgN  >kommunistikis !09_S	et	f	\N
146634	kommunistikis	?kommunistikis =munistikis  (SgN  >kom+munistikis !09_S	et	f	\N
146635	valitsusil	valitsusil =valitsusi  (PlAd  >valitsus !11_S	et	f	\N
146636	valitsusil	"valitsus %valitse  )US_vS  <valitsema ;27_V	et	f	\N
146639	langesib	### langesib	et	f	\N
146641	riivasib	### riivasib	et	f	\N
146663	süüdistanud	süüdistanud =süüdista  (PtsPtPs  >süüdistama !27_V	et	f	\N
146664	süüdistanud	süüdistanud =süüdistanu  (PlN  >süüdistanu !01_S	et	f	\N
146665	süüdistanud	"süüdistanu %süüdista  )NU_vS  <süüdistama ;27_V	et	f	\N
146666	süüdistanud	süüdistanud =süüdistanud  (ID  >süüdistanud !41_A	et	f	\N
146667	süüdistanud	"süüdistanud %süüdista  )NUD_vA  <süüdistama ;27_V	et	f	\N
146671	kõtkumamisega	?kõtkumamisega =kõtkumamise  (SgKom  >kõtkumamine !12_S	et	f	\N
146672	tundsib	?tundsib =tundsi  (IndPrSg3  >tundsima !28_V	et	f	\N
146680	teenindasib	### teenindasib	et	f	\N
146681	järjekindlusetu	järjekindlusetu =kindlusetu  (SgN  >järje+kindlusetu !01_A	et	f	\N
146682	järjekindlusetu	"järje+kindlusetu %kindluse  )TU2_kA  <järje+kindlus ;09_S	et	f	\N
146683	järjekindlusetu	"järje+kindlusetu %kindluse  )TU2_kA  <järje+kindlus ;11_S	et	f	\N
146684	järjekindlusetu	järjekindlusetu =kindlusetu  (SgG  >järje+kindlusetu !01_A	et	f	\N
146689	kreekasse	?kreekasse =kreeka  (SgIll  >kreekas !02_A	et	f	\N
146690	kreekasse	?kreekasse =kreeka  (SgIll  >kreeka !16_S	et	f	\N
146691	kreekasse	?kreekasse =kreekas  (SgAdt  >kreekane !12_A	et	f	\N
146692	kreekasse	?kreekasse =kreekasse  (SgG  >kreekasne !02_A	et	f	\N
146693	kreekasse	?kreekasse =kreekasse  (PlP  >kreekass !22_S	et	f	\N
146694	mängidakse	?mängidakse =mängidakse  (SgG  >mängidakne !02_A	et	f	\N
146699	pubisse	?pubisse =pubi  (SgIll  >pubi !17_S	et	f	\N
146700	pubisse	?pubisse =pubisse  (SgG  >pubisne !02_A	et	f	\N
146558	ärritav	ärritav =ärrita  (PtsPrPs  >ärritama !27_V	et	f	\N
146559	ärritav	ärritav =ärritav  (SgN  >ärritav !02_A	et	f	\N
146560	ärritav	"ärritav %ärrita  )V_vA  <ärritama ;27_V	et	f	\N
146580	nagy	### nagy	et	f	\N
146581	kapsovari	?kapsovari =kapsovari  (SgG  >kapsovar !19_S	et	f	\N
146582	kapsovari	?kapsovari =kapsovari  (SgP  >kapsovar !19_S	et	f	\N
146583	kapsovari	?kapsovari =kapsovari  (SgAdt  >kapsovar !19_S	et	f	\N
146588	talupoegad	?talupoegad =poega  (PlN  >talu+poega !16_S	et	f	\N
146619	mõrvas	mõrvas =mõrva  (SgIn  >mõrv !22_S	et	f	\N
146621	mõrvas	mõrvas =mõrva  (IndIpfSg3  >mõrvama !29_V	et	f	\N
146625	puhastusil	puhastusil =puhastusi  (PlAd  >puhastus !11_S	et	f	\N
146626	puhastusil	"puhastus %puhasta  )US_vS  <puhastama ;27_V	et	f	\N
146627	puhastusil	puhastusil =tusi  (PlAd  >puhas+tusk !22_S	et	f	\N
146650	tapenud	?tapenud =tape  (PtsPtPs  >tapema !27_V	et	f	\N
146651	tapenud	?tapenud =tapenu  (PlN  >tapenu !01_S	et	f	\N
146652	tapenud	?tapenud =tapenu  (IndPrSg2  >tapenuma !27_V	et	f	\N
146653	tapenud	?tapenud =tapenud  (ID  >tapenud !41_A	et	f	\N
146675	revalutsioonid	?revalutsioonid =revalutsiooni  (PlN  >revalutsiooni !16_S	et	f	\N
146676	revalutsioonid	?revalutsioonid =revalutsiooni  (PlN  >revalutsioon !22_S	et	f	\N
146677	revalutsioonid	?revalutsioonid =revalutsiooni  (IndPrSg2  >revalutsioonima !28_V	et	f	\N
146695	golfi	golfi =golfi  (SgG  >golf !22_S	et	f	\N
146696	golfi	golfi =golfi  (SgP  >golf !22_S	et	f	\N
146697	golfi	golfi =golfi  (SgAdt  >golf !22_S	et	f	\N
146721	töödadakse	?töödadakse =töödadakse  (SgG  >töödadakne !02_A	et	f	\N
146722	töödadakse	?töödadakse =dadakse  (SgG  >töö+dadakne !02_A	et	f	\N
146732	berlina	?berlina =berli  (SgEs  >berli !16_S	et	f	\N
146733	berlina	?berlina =berli  (SgEs  >berl !22_S	et	f	\N
146738	glasgow	### glasgow	et	f	\N
146762	levi	levi =levi  (SgN  >levi !17_S	et	f	\N
146763	levi	levi =levi  (SgG  >levi !17_S	et	f	\N
146765	levi	levi =levi  (SgP  >levi !17_S	et	f	\N
146766	levi	levi =levi  (IndPrPs_  >levima !27_V	et	f	\N
146768	levi	levi =levi  (ImpPrSg2  >levima !27_V	et	f	\N
146784	ostin	?ostin =osti  (IndPrSg1  >ostima !28_V	et	f	\N
146785	ostin	?ostin =ostin  (SgN  >ostin !02_S	et	f	\N
146786	kolun	?kolun =kolu  (IndPrSg1  >koluma !27_V	et	f	\N
146789	kolun	?kolun =kolun  (SgN  >kolun !02_S	et	f	\N
146790	mugavusamad	?mugavusamad =mugavusama  (PlN  >mugavusam !02_A	et	f	\N
146791	mugavusamad	?mugavusamad =ama  (PlN  >mugavus+ama !17_S	et	f	\N
146792	lingad	?lingad =linga  (PlN  >linga !16_S	et	f	\N
146793	lingad	?lingad =linga  (IndPrSg2  >lingama !29_V	et	f	\N
146795	nike	?nike =nike  (SgN  >nike !06_S	et	f	\N
146796	nike	?nike =nike  (IndPrPs_  >nikema !27_V	et	f	\N
146797	nike	?nike =nike  (ImpPrSg2  >nikema !27_V	et	f	\N
146828	kirjanduid	?kirjanduid =kirjandu  (PlP  >kirjandu !01_S	et	f	\N
146829	kirjanduid	?kirjanduid =kirjandui  (PlN  >kirjandui !26_S	et	f	\N
146830	kirjanduid	?kirjanduid =kirjandui  (SgP  >kirjandui !26_S	et	f	\N
146833	shidleri	?shidleri =shidleri  (SgN  >shidleri !01_S	et	f	\N
146834	shidleri	?shidleri =shidleri  (SgG  >shidleri !01_S	et	f	\N
146835	shidleri	?shidleri =shidleri  (SgG  >shidler !02_S	et	f	\N
146849	spielberg	?spielberg =spielberg  (SgN  >spielberg !02_S	et	f	\N
146857	roal	roal =roa  (SgAd  >ruga !18_S	et	f	\N
146858	roal	roal =roa  (SgAd  >roog !22_S	et	f	\N
146889	taksinud	?taksinud =taksi  (PtsPtPs  >taksima !28_V	et	f	\N
146890	taksinud	?taksinud =taksinu  (PlN  >taksinu !01_S	et	f	\N
146891	taksinud	?taksinud =taksinu  (IndPrSg2  >taksinuma !27_V	et	f	\N
146892	taksinud	?taksinud =taksinud  (ID  >taksinud !41_A	et	f	\N
146916	linnapea	linnapea =pea  (SgN  >linna+pea !26_S	et	f	\N
146917	linnapea	linnapea =pea  (SgG  >linna+pea !26_S	et	f	\N
146933	läärkeris	?läärkeris =läärkeri  (SgIn  >läärkeri !01_S	et	f	\N
146934	läärkeris	?läärkeris =läärkeri  (SgIn  >läärker !02_S	et	f	\N
146935	läärkeris	?läärkeris =läärkeris  (SgN  >läärkeris !11_S	et	f	\N
146954	sõidataks	?sõidataks =sõidata  (KndPrPs  >sõidatama !27_V	et	f	\N
146955	sõidataks	?sõidataks =sõidataks  (SgN  >sõidataks !22_S	et	f	\N
146956	teataksivad	?teataksivad =teataksi  (IndPrPl3  >teataksima !28_V	et	f	\N
146957	teataksivad	?teataksivad =teataksiva  (PlN  >teataksiv !02_A	et	f	\N
146958	teataksivad	?teataksivad =teataksiva  (PlN  >teataksiva !16_S	et	f	\N
146959	oleksit	?oleksit =oleksi  (SgP  >oleksi !01_S	et	f	\N
146971	nelj	### nelj	et	f	\N
146985	raamatukoju	?raamatukoju =raamatukoju  (IndPrPs_  >raamatukojuma !27_V	et	f	\N
146986	raamatukoju	?raamatukoju =raamatukoju  (ImpPrSg2  >raamatukojuma !27_V	et	f	\N
146987	jalgas	?jalgas =jalga  (IndIpfSg3  >jalgama !29_V	et	f	\N
146988	jalgas	?jalgas =jalgas  (SgN  >jalgas !07_S	et	f	\N
146989	puhkusesse	puhkusesse =puhkuse  (SgIll  >puhkus !11~09_S	et	f	\N
146990	puhkusesse	puhkusesse =puhkuses  (SgAdt  >puhkusene !12_A	et	f	\N
146991	puhkusesse	"puhkusene %puhkuse  )NE_aA  <puhkus ;09_S	et	f	\N
146992	puhkusesse	"puhkusene %puhkuse  )NE_aA  <puhkus ;11_S	et	f	\N
146993	puhkusesse	puhkusesse =use  (PlIll  >puhk+usk !22_S	et	f	\N
146607	vangistanud	vangistanud =tanu  (PlN  >vangis+tanu !17_S	et	f	\N
146609	valitsusid	?valitsusid =valitsu  (IndIpfSg2  >valitsuma !27_V	et	f	\N
146610	valitsusid	?valitsusid =valitsu  (IndIpfPl3  >valitsuma !27_V	et	f	\N
146640	tahtsib	?tahtsib =tahtsi  (IndPrSg3  >tahtsima !28_V	et	f	\N
146642	lõppemiseks	lõppemiseks =lõppemise  (SgTr  >lõppemine !12_S	et	f	\N
146643	lõppemiseks	"lõppemine %lõppe  )MINE_vS  <lõppema ;27_V	et	f	\N
146644	lõppemiseks	"lõppemine %lõppe  )MINE_vS  <lõppema ;28_V	et	f	\N
146645	lõppemiseks	lõppemiseks =emise  (SgTr  >lõpp+emis !09_S	et	f	\N
146673	haud	haud =hau  (IndPrSg2  >hauduma !28_V	et	f	\N
146674	haud	haud =haud  (SgN  >haud !22_S	et	f	\N
146678	ida-europaad	ida-europaad =paa  (PlN  >ida-euro+paa !26_SA	et	f	\N
146679	ida-europaad	ida-europaad =paa  (SgP  >ida-euro+paa !26_SA	et	f	\N
146730	jõudin	?jõudin =jõudi  (IndPrSg1  >jõutima !28_V	et	f	\N
146731	jõudin	?jõudin =jõudin  (SgN  >jõudin !02_S	et	f	\N
146737	metroga	?metroga =metro  (SgKom  >metro !16_S	et	f	\N
146752	seljas	seljas =selja  (SgIn  >selg !22_S	et	f	\N
146753	seljas	seljas =seljas  (ID  >seljas !41_D	et	f	\N
146764	kaukemajas	?kaukemajas =kaukemaja  (SgIn  >kaukemaja !01_S	et	f	\N
146767	kaukemajas	?kaukemajas =kaukemaja  (SgIn  >kaukemajas !02_A	et	f	\N
146769	kaukemajas	?kaukemajas =kaukemajas  (SgN  >kaukemajas !02_A	et	f	\N
146803	convese	?convese =convese  (SgG  >convene !10_A	et	f	\N
146808	t-sarkid	### t-sarkid	et	f	\N
146811	jõulukinkina	### jõulukinkina	et	f	\N
146831	lugisin	?lugisin =lugi  (IndIpfSg1  >lugima !27_V	et	f	\N
146832	lugisin	?lugisin =lugisin  (SgN  >lugisin !19_S	et	f	\N
146847	steven	?steven =steve  (IndPrSg1  >stevema !27_V	et	f	\N
146848	steven	?steven =steven  (SgN  >steven !02_S	et	f	\N
146851	krakovil	?krakovil =krakovi  (SgAd  >krakov !02_A	et	f	\N
146852	krakovil	?krakovil =krakovil  (ID  >krakovil !41_DA	et	f	\N
146866	dahli	?dahli =dahli  (SgN  >dahli !16_S	et	f	\N
146867	dahli	?dahli =dahli  (SgG  >dahli !16_S	et	f	\N
146868	dahli	?dahli =dahli  (SgG  >dahl !22_S	et	f	\N
146869	dahli	?dahli =dahli  (SgP  >dahl !22_S	et	f	\N
146870	dahli	?dahli =dahli  (SgAdt  >dahl !22_S	et	f	\N
146871	dahli	?dahli =dahli  (IndPrPs_  >dahlima !28_V	et	f	\N
146872	dahli	?dahli =dahli  (ImpPrSg2  >dahlima !28_V	et	f	\N
146873	vanemast	vanemast =vanema  (SgEl  >vanem !02_AS	et	f	\N
146875	vanemast	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
146876	vanemast	vanemast =ast  (SgN  >vanem+ast !22_S	et	f	\N
146878	tapsi	tapsi =tapsi  (IndPrPs_  >tapsima !28_V	et	f	\N
146879	tapsi	tapsi =tapsi  (ImpPrSg2  >tapsima !28_V	et	f	\N
146895	poksi	poksi =poksi  (SgG  >poks !22_S	et	f	\N
146896	poksi	poksi =poksi  (SgP  >poks !22_S	et	f	\N
146897	poksi	poksi =poksi  (SgAdt  >poks !22_S	et	f	\N
146898	poksi	poksi =poksi  (IndPrPs_  >poksima !28_V	et	f	\N
146899	poksi	poksi =poksi  (ImpPrSg2  >poksima !28_V	et	f	\N
146905	kuues	kuues =kuue  (SgIn  >kuus !14_N	et	f	\N
146906	kuues	kuues =kuue  (SgIn  >kuub !22_S	et	f	\N
146907	kuues	kuues =kuues  (SgN  >kuues !02_O	et	f	\N
146932	läänes-glasgows	?läänes-glasgows =glasgows  (SgN  >läänes-glasgows !22_S	et	f	\N
146946	oleksib	?oleksib =oleksi  (IndPrSg3  >oleksima !28_V	et	f	\N
146951	oleksivad	?oleksivad =oleksi  (IndPrPl3  >oleksima !28_V	et	f	\N
146952	oleksivad	?oleksivad =oleksiva  (PlN  >oleksiv !02_A	et	f	\N
146953	oleksivad	?oleksivad =oleksiva  (PlN  >oleksiva !16_S	et	f	\N
146961	lubaskin	?lubaskin =lubaski  (IndPrSg1  >lubaskima !28_V	et	f	\N
146962	lubaskin	?lubaskin =lubaskin  (SgN  >lubaskin !19_S	et	f	\N
146967	avaksivad	?avaksivad =avaksi  (IndPrPl3  >avaksima !28_V	et	f	\N
146968	avaksivad	?avaksivad =avaksiva  (PlN  >avaksiv !02_A	et	f	\N
146969	avaksivad	?avaksivad =avaksiva  (PlN  >avaksiva !16_S	et	f	\N
146970	avaksivad	?avaksivad =ksiva  (PlN  >ava+ksiva !17_S	et	f	\N
146974	süvel	?süvel =süve  (SgAd  >süve !16_S	et	f	\N
146975	süvel	?süvel =süvel  (SgN  >süvel !02_S	et	f	\N
146978	kroodi	?kroodi =kroodi  (SgN  >kroodi !16_S	et	f	\N
146979	kroodi	?kroodi =kroodi  (SgG  >kroodi !16_S	et	f	\N
146980	kroodi	?kroodi =kroodi  (SgG  >kroot !22_S	et	f	\N
146981	kroodi	?kroodi =kroodi  (SgP  >krood !22_S	et	f	\N
146982	kroodi	?kroodi =kroodi  (SgAdt  >krood !22_S	et	f	\N
146983	kroodi	?kroodi =kroodi  (IndPrPs_  >krootima !28_V	et	f	\N
146984	kroodi	?kroodi =kroodi  (ImpPrSg2  >krootima !28_V	et	f	\N
146994	läänel-glasgows	?läänel-glasgows =glasgows  (SgN  >läänel-glasgows !22_S	et	f	\N
147004	ligidal	ligidal =ligida  (SgAd  >ligida !02_A	et	f	\N
147005	ligidal	ligidal =ligidal  (ID  >ligidal !41_DK	et	f	\N
147008	alustasid	alustasid =alusta  (IndIpfSg2  >alustama !27_V	et	f	\N
147009	alustasid	alustasid =alusta  (IndIpfPl3  >alustama !27_V	et	f	\N
147029	kahekümnesal	?kahekümnesal =kahekümnesa  (SgAd  >kahekümnesa !16_S	et	f	\N
147030	kahekümnesal	?kahekümnesal =kahekümnesal  (SgN  >kahekümnesal !19_S	et	f	\N
147031	kahekümnesal	?kahekümnesal =kümnesa  (SgAd  >kahe+kümnesa !01_S	et	f	\N
147032	kahekümnesal	?kahekümnesal =kümnesal  (SgN  >kahe+kümnesal !19_S	et	f	\N
146649	pälju	?pälju =pälju  (ImpPrSg2  >päljuma !27_V	et	f	\N
146654	püüdusib	### püüdusib	et	f	\N
146660	voimalus	?voimalus =voimalu  (SgIn  >voimalu !01_S	et	f	\N
146661	voimalus	?voimalus =voimalu  (IndIpfSg3  >voimaluma !27_V	et	f	\N
146662	voimalus	?voimalus =voimalus  (SgN  >voimalus !11_S	et	f	\N
146686	maadesse	maadesse =maa  (PlIll  >maa !26_S	et	f	\N
146688	maadesse	maadesse =maade  (PlIll  >maat !22_S	et	f	\N
146698	viibidakse	?viibidakse =viibidakse  (SgG  >viibidakne !02_A	et	f	\N
146702	istudakse	?istudakse =istudakse  (SgG  >istudakne !02_A	et	f	\N
146713	poodis	?poodis =poodi  (SgIn  >poodi !16_S	et	f	\N
146714	poodis	?poodis =poodi  (IndIpfSg3  >poodima !28_V	et	f	\N
146715	poodis	?poodis =poodis  (SgN  >poodis !09_S	et	f	\N
146718	asemal	?asemal =asema  (SgAd  >asem !02_A	et	f	\N
146719	asemal	?asemal =asemal  (ID  >asemal !41_D	et	f	\N
146720	glasgows	?glasgows =glasgows  (SgN  >glasgows !22_S	et	f	\N
146739	poodid	?poodid =poodi  (PlN  >poodi !16_S	et	f	\N
146741	poodid	?poodid =poodi  (IndPrSg2  >pootima !28_V	et	f	\N
146749	jalas	jalas =jala  (SgIn  >jalg !22_S	et	f	\N
146750	jalas	jalas =jalas  (ID  >jalas !41_D	et	f	\N
146751	jalas	jalas =jalas  (SgN  >jalas !09_S	et	f	\N
146756	buchanani	?buchanani =buchanani  (SgG  >buchanan !19_S	et	f	\N
146758	buchanani	?buchanani =buchanani  (SgP  >buchanan !19_S	et	f	\N
146759	buchanani	?buchanani =buchanani  (SgAdt  >buchanan !19_S	et	f	\N
146770	kallised	?kallised =kallise  (PlN  >kalline !10_A	et	f	\N
146771	kallised	?kallised =kallise  (IndPrSg2  >kallisema !27_V	et	f	\N
146773	t-sätkid	?t-sätkid =sätki  (PlN  >t-sätki !16_S	et	f	\N
146774	t-sätkid	?t-sätkid =sätki  (PlN  >t-sätk !22_S	et	f	\N
146775	t-sätkid	?t-sätkid =sätki  (IndPrSg2  >t-sätkima !28_V	et	f	\N
146810	ajalagaraamatudid	### ajalagaraamatudid	et	f	\N
146850	juutid	### juutid	et	f	\N
146853	püüdsa	?püüdsa =püüdsa  (SgN  >püüdsa !01_S	et	f	\N
146854	püüdsa	?püüdsa =püüdsa  (SgG  >püüdsa !01_S	et	f	\N
146855	püüdsa	?püüdsa =püüdsa  (IndPrPs_  >püüdsama !29_V	et	f	\N
146856	püüdsa	?püüdsa =püüdsa  (ImpPrSg2  >püüdsama !29_V	et	f	\N
146859	dahli	?dahli =dahli  (SgN  >dahli !16_S	et	f	\N
146860	dahli	?dahli =dahli  (SgG  >dahli !16_S	et	f	\N
146861	dahli	?dahli =dahli  (SgG  >dahl !22_S	et	f	\N
146862	dahli	?dahli =dahli  (SgP  >dahl !22_S	et	f	\N
146863	dahli	?dahli =dahli  (SgAdt  >dahl !22_S	et	f	\N
146864	dahli	?dahli =dahli  (IndPrPs_  >dahlima !28_V	et	f	\N
146865	dahli	?dahli =dahli  (ImpPrSg2  >dahlima !28_V	et	f	\N
146874	raamatust	raamatust =raamatu  (SgEl  >raamat !02_S	et	f	\N
146877	raamatust	raamatust =atu  (SgEl  >raam+att !22_S	et	f	\N
146888	ronged	?ronged =ronge  (IndPrSg2  >rongema !27_V	et	f	\N
146944	jööksin	?jööksin =jööksi  (IndPrSg1  >jööksima !28_V	et	f	\N
146945	jööksin	?jööksin =jööksin  (SgN  >jööksin !02_S	et	f	\N
146997	viisteistkümnesal	?viisteistkümnesal =viisteistkümnesa  (SgAd  >viisteistkümnesa !16_S	et	f	\N
146998	viisteistkümnesal	?viisteistkümnesal =viisteistkümnesal  (SgN  >viisteistkümnesal !19_S	et	f	\N
146999	viisteistkümnesal	?viisteistkümnesal =kümnesa  (SgAd  >viis+teist+kümnesa !01_S	et	f	\N
147000	viisteistkümnesal	?viisteistkümnesal =kümnesal  (SgN  >viis+teist+kümnesal !19_S	et	f	\N
147001	viisteistkümnesal	?viisteistkümnesal =teistkümnesa  (SgAd  >viis+teistkümnesa !16_S	et	f	\N
147002	viisteistkümnesal	?viisteistkümnesal =teistkümnesal  (SgN  >viis+teistkümnesal !19_S	et	f	\N
147015	puhkepäevadis	?puhkepäevadis =puhkepäevadis  (SgN  >puhkepäevadis !09_S	et	f	\N
147016	puhkepäevadis	?puhkepäevadis =adi  (SgIn  >puhke+päev+adi !17_S	et	f	\N
147017	puhkepäevadis	?puhkepäevadis =adis  (SgN  >puhke+päev+adis !09_S	et	f	\N
147018	puhkepäevadis	?puhkepäevadis =päevadi  (SgIn  >puhke+päevadi !01_S	et	f	\N
147019	puhkepäevadis	?puhkepäevadis =päevadis  (SgN  >puhke+päevadis !11_S	et	f	\N
147020	puhkepäevadis	?puhkepäevadis =epäevadis  (SgN  >puhk+epäevadis !09_S	et	f	\N
147033	sõitin	?sõitin =sõitin  (SgN  >sõitin !02_S	et	f	\N
147034	sõitime	### sõitime	et	f	\N
147042	januaril	?januaril =januari  (SgAd  >januari !16_S	et	f	\N
147043	januaril	?januaril =januari  (SgAd  >januar !19_S	et	f	\N
147044	januaril	?januaril =januaril  (SgN  >januaril !02_S	et	f	\N
147071	tartivas	?tartivas =tartiva  (SgIn  >tartiva !01_S	et	f	\N
147072	tartivas	?tartivas =tartiva  (SgIn  >tartiv !02_A	et	f	\N
147084	iodvenden	?iodvenden =iodvenden  (SgN  >iodvenden !19_S	et	f	\N
147107	tubased	tubased =tubase  (PlN  >tubane !10_A	et	f	\N
147108	tubased	"tubane %tuba  )NE_aA  <tuba ;18_S	et	f	\N
147109	tubate	?tubate =tuba  (IndPrPl2  >tubama !27_V	et	f	\N
147111	nimide	### nimide	et	f	\N
147114	elatubas	?elatubas =elatuba  (SgIn  >elatuba !16_S	et	f	\N
147115	akenad	### akenad	et	f	\N
147116	köökis	?köökis =kööki  (IndIpfSg3  >köökima !28_V	et	f	\N
147117	köökis	?köökis =köökis  (SgN  >köökis !11~09_S	et	f	\N
147130	kitarrite	?kitarrite =kitarri  (PlG  >kitarri !01_S	et	f	\N
147131	kitarrite	?kitarrite =kitarri  (IndPrPl2  >kitarrima !28_V	et	f	\N
147132	tubas	?tubas =tuba  (IndIpfSg3  >tubama !27_V	et	f	\N
146701	pubisse	?pubisse =pubisse  (PlP  >pubiss !22_S	et	f	\N
146716	linas	linas =lina  (SgIn  >lina !17_S	et	f	\N
146717	linas	linas =linas  (ID  >linas !41_A	et	f	\N
146723	kesklinas	kesklinas =lina  (SgIn  >kesk+lina !17_S	et	f	\N
146724	kesklinas	kesklinas =linas  (ID  >kesk+linas !41_A	et	f	\N
146725	leipzigis	?leipzigis =leipzigis  (SgN  >leipzigis !11_S	et	f	\N
146754	kaukemajasse	?kaukemajasse =kaukemaja  (SgIll  >kaukemaja !01_S	et	f	\N
146755	kaukemajasse	?kaukemajasse =kaukemaja  (SgIll  >kaukemajas !02_A	et	f	\N
146757	kaukemajasse	?kaukemajasse =kaukemajas  (SgAdt  >kaukemajane !12_A	et	f	\N
146760	kaukemajasse	?kaukemajasse =kaukemajasse  (SgG  >kaukemajasne !02_A	et	f	\N
146761	kaukemajasse	?kaukemajasse =kaukemajasse  (PlP  >kaukemajass !22_S	et	f	\N
146781	internetaga	?internetaga =neta  (SgKom  >inter+neta !16_S	et	f	\N
146798	puma	?puma =puma  (SgN  >puma !17_S	et	f	\N
146799	puma	?puma =puma  (SgG  >puma !17_S	et	f	\N
146800	puma	?puma =puma  (SgP  >puma !17_S	et	f	\N
146801	puma	?puma =puma  (IndPrPs_  >pumama !27_V	et	f	\N
146802	puma	?puma =puma  (ImpPrSg2  >pumama !27_V	et	f	\N
146806	kolmkümend	?kolmkümend =kolmkümend  (SgN  >kolmkümend !22_S	et	f	\N
146807	kolmkümend	?kolmkümend =kümend  (SgN  >kolm+kümend !02_S	et	f	\N
146809	u	### u	et	f	\N
146812	vanavanemadist	?vanavanemadist =vanavanemadis  (SgP  >vanavanemadis !09_S	et	f	\N
146813	vanavanemadist	?vanavanemadist =vanavanemadist  (SgN  >vanavanemadist !22_S	et	f	\N
146814	vanavanemadist	?vanavanemadist =dist  (SgN  >vana+vanema+dist !22_S	et	f	\N
146815	vanavanemadist	?vanavanemadist =adi  (SgEl  >vana+vanem+adi !17_S	et	f	\N
146816	vanavanemadist	?vanavanemadist =adis  (SgP  >vana+vanem+adis !09_S	et	f	\N
146817	vanavanemadist	?vanavanemadist =adist  (SgN  >vana+vanem+adist !22_S	et	f	\N
146818	vanavanemadist	?vanavanemadist =vanemadis  (SgP  >vana+vanemadis !09_S	et	f	\N
146819	vanavanemadist	?vanavanemadist =vanemadist  (SgN  >vana+vanemadist !22_S	et	f	\N
146821	boris	?boris =bori  (SgIn  >bori !17_S	et	f	\N
146822	boris	?boris =bori  (IndIpfSg3  >borima !27_V	et	f	\N
146823	boris	?boris =boris  (SgN  >boris !09_S	et	f	\N
146836	tomas	?tomas =toma  (SgIn  >toma !17_S	et	f	\N
146837	tomas	?tomas =toma  (IndIpfSg3  >tomama !27_V	et	f	\N
146839	tomas	?tomas =tomas  (SgN  >tomas !09_S	et	f	\N
146880	luguid	?luguid =lugui  (PlN  >lugui !26_S	et	f	\N
146881	luguid	?luguid =lugui  (SgP  >lugui !26_S	et	f	\N
146882	luguid	?luguid =luguid  (SgN  >luguid !22_S	et	f	\N
146885	rongi	rongi =rongi  (SgG  >rong !22_S	et	f	\N
146886	rongi	rongi =rongi  (SgP  >rong !22_S	et	f	\N
146887	rongi	rongi =rongi  (SgAdt  >rong !22_S	et	f	\N
146900	hakanud	hakanud =haka  (PtsPtPs  >hakkama !29_V	et	f	\N
146901	hakanud	hakanud =hakanu  (PlN  >hakanu !01_S	et	f	\N
146902	hakanud	"hakanu %haka  )NU_vS  <hakkama ;29_V	et	f	\N
146903	hakanud	hakanud =hakanud  (ID  >hakanud !41_A	et	f	\N
146904	hakanud	"hakanud %haka  )NUD_vA  <hakkama ;29_V	et	f	\N
146914	ütlesi	?ütlesi =ütlesi  (ID  >ütlesi !41_D	et	f	\N
146915	ütlesi	?ütlesi =ütlesi  (PlP  >ütlene !12_A	et	f	\N
146925	tähtisem	tähtisem =tähtisem  (SgN  >tähtisem !02_A	et	f	\N
146926	tähtisem	"tähtisem %tähtise  )M_cA  <tähtis ;02_A	et	f	\N
146927	nõukogus	nõukogus =kogu  (SgIn  >nõu+kogu !17_S	et	f	\N
146928	nõukogus	nõukogus =kogus  (SgN  >nõu+kogus !02_A	et	f	\N
146929	nõukogus	nõukogus =kogus  (SgN  >nõu+kogus !09_S	et	f	\N
146930	teosesse	teosesse =teose  (SgIll  >teos !09_S	et	f	\N
146931	teosesse	teosesse =sesse  (PlP  >teo+sess !22_S	et	f	\N
146936	lomondi	?lomondi =lomondi  (SgN  >lomondi !01_S	et	f	\N
146937	lomondi	?lomondi =lomondi  (SgG  >lomondi !01_S	et	f	\N
146938	lomondi	?lomondi =lomondi  (SgG  >lomont !22_S	et	f	\N
146939	lomondi	?lomondi =lomondi  (SgP  >lomond !22_S	et	f	\N
146940	lomondi	?lomondi =lomondi  (SgAdt  >lomond !22_S	et	f	\N
146941	lomondi	?lomondi =lomondi  (IndPrPs_  >lomontima !28_V	et	f	\N
146942	lomondi	?lomondi =lomondi  (ImpPrSg2  >lomontima !28_V	et	f	\N
146943	vaadak	?vaadak =vaadak  (SgN  >vaadak !02_S	et	f	\N
146950	ajakirjankid	### ajakirjankid	et	f	\N
146960	odavem	?odavem =odavem  (SgN  >odavem !02_A	et	f	\N
146972	kuivem	kuivem =kuivem  (SgN  >kuivem !02_A	et	f	\N
146973	kuivem	"kuivem %kuive  )M_cA  <kuiv ;22_AS	et	f	\N
146995	alusta	alusta =alusta  (IndPrPs_  >alustama !27_V	et	f	\N
146996	alusta	alusta =alusta  (ImpPrSg2  >alustama !27_V	et	f	\N
147006	edinburghi	?edinburghi =edinburghi  (IndPrPs_  >edinburghima !28_V	et	f	\N
147007	edinburghi	?edinburghi =edinburghi  (ImpPrSg2  >edinburghima !28_V	et	f	\N
147040	söösime	?söösime =söösi  (IndPrPl1  >söösima !28_V	et	f	\N
147045	uurimise	uurimise =uurimise  (SgG  >uurimine !12_S	et	f	\N
147046	uurimise	"uurimine %uuri  )MINE_vS  <uurima ;28_V	et	f	\N
147059	voileib	?voileib =voileib  (SgN  >voileib !22_S	et	f	\N
147088	arkan	?arkan =arka  (IndPrSg1  >arkama !29_V	et	f	\N
147089	arkan	?arkan =arkan  (SgN  >arkan !02_S	et	f	\N
147090	kauplusid	?kauplusid =kauplu  (IndIpfSg2  >kaupluma !27_V	et	f	\N
147091	kauplusid	?kauplusid =kauplu  (IndIpfPl3  >kaupluma !27_V	et	f	\N
146711	kohtusse	"kohtune %kohtu  )NE_aA  <kohus ;05_S	et	f	\N
146712	kohtusse	kohtusse =usse  (PlP  >koht+uss !22_S	et	f	\N
146726	berlinnasse	?berlinnasse =berlinna  (SgIll  >berlinna !16_S	et	f	\N
146727	berlinnasse	?berlinnasse =berlinnas  (SgAdt  >berlinnane !12_A	et	f	\N
146728	berlinnasse	?berlinnasse =berlinnasse  (SgG  >berlinnasne !02_A	et	f	\N
146729	berlinnasse	?berlinnasse =berlinnasse  (PlP  >berlinnass !22_S	et	f	\N
146734	peatselt	peatselt =peatse  (SgAbl  >peatne !02_A	et	f	\N
146735	peatselt	peatselt =peatselt  (ID  >peatselt !41_D	et	f	\N
146736	peatselt	"peatselt %peatse  )LT_mD  <peatne ;02_A	et	f	\N
146740	poodid	?poodid =poodi  (PlN  >poodi !16_S	et	f	\N
146742	poodid	?poodid =poodi  (IndPrSg2  >pootima !28_V	et	f	\N
146743	sauchiehall	?sauchiehall =sauchiehall  (SgN  >sauchiehall !22_S	et	f	\N
146744	buchanan	?buchanan =buchanan  (SgN  >buchanan !19_S	et	f	\N
146745	argyll	?argyll =argyll  (SgN  >argyll !22_S	et	f	\N
146746	argyll	?argyll =yll  (SgN  >arg+yll !22_S	et	f	\N
146747	kalun	?kalun =kalu  (IndPrSg1  >kaluma !27_V	et	f	\N
146748	kalun	?kalun =kalun  (SgN  >kalun !02_S	et	f	\N
146772	t-särkid	### t-särkid	et	f	\N
146776	ansembli	?ansembli =ansembli  (SgN  >ansembli !01_S	et	f	\N
146777	ansembli	?ansembli =ansembli  (SgG  >ansembli !01_S	et	f	\N
146778	ansembli	?ansembli =ansembli  (SgG  >ansembel !02_S	et	f	\N
146779	ansembli	?ansembli =ansembli  (IndPrPs_  >ansemblima !28_V	et	f	\N
146780	ansembli	?ansembli =ansembli  (ImpPrSg2  >ansemblima !28_V	et	f	\N
146782	odavamad	odavamad =odavama  (PlN  >odavam !02_A	et	f	\N
146783	odavamad	"odavam %odava  )M_cA  <odav ;02_A	et	f	\N
146787	spordid	spordid =spordi  (PlN  >sport !22_S	et	f	\N
146788	spordid	spordid =spordi  (IndPrSg2  >sportima !28_V	et	f	\N
146794	markid	### markid	et	f	\N
146804	paarid	paarid =paari  (PlN  >paar !22_NS	et	f	\N
146805	paarid	paarid =paari  (IndPrSg2  >paarima !28_V	et	f	\N
146820	kirjutasi	?kirjutasi =kirjutasi  (PlP  >kirjutane !12_A	et	f	\N
146824	pasternak	### pasternak	et	f	\N
146825	pikke	pikke =pikke  (SgG  >pike !06_S	et	f	\N
146826	pikke	pikke =pikke  (PlP  >pikk !22_S	et	f	\N
146827	pikke	pikke =pikke  (PlP  >pikk !22_AS	et	f	\N
146838	keneeli	?keneeli =keneeli  (SgN  >keneeli !16_S	et	f	\N
146840	keneeli	?keneeli =keneeli  (SgG  >keneeli !16_S	et	f	\N
146841	keneeli	?keneeli =keneeli  (SgG  >keneel !22_S	et	f	\N
146842	keneeli	?keneeli =keneeli  (SgP  >keneel !22_S	et	f	\N
146843	keneeli	?keneeli =keneeli  (SgAdt  >keneel !22_S	et	f	\N
146844	keneeli	?keneeli =keneeli  (IndPrPs_  >keneelima !28_V	et	f	\N
146845	keneeli	?keneeli =keneeli  (ImpPrSg2  >keneelima !28_V	et	f	\N
146846	shidler	?shidler =shidler  (SgN  >shidler !02_S	et	f	\N
146883	taksin	?taksin =taksi  (IndPrSg1  >taksima !28_V	et	f	\N
146884	taksin	?taksin =taksin  (SgN  >taksin !02_S	et	f	\N
146893	vaadasin	?vaadasin =vaada  (IndIpfSg1  >vaadama !29_V	et	f	\N
146894	vaadasin	?vaadasin =vaadasin  (SgN  >vaadasin !19_S	et	f	\N
146908	võinud	võinud =või  (PtsPtPs  >võima !37_V	et	f	\N
146909	võinud	võinud =võinu  (PlN  >võinu !01_S	et	f	\N
146910	võinud	"võinu %või  )NU_vS  <võima ;37_V	et	f	\N
146911	võinud	võinud =võinu  (PlN  >võinu !06_S	et	f	\N
146912	võinud	võinud =võinud  (ID  >võinud !41_A	et	f	\N
146913	võinud	"võinud %või  )NUD_vA  <võima ;37_V	et	f	\N
146918	valimines	?valimines =valimine  (PlIn  >valimin !19_S	et	f	\N
146919	tegeksin	?tegeksin =tegeksi  (IndPrSg1  >tegeksima !28_V	et	f	\N
146920	tegeksin	?tegeksin =tegeksin  (SgN  >tegeksin !19_S	et	f	\N
146921	otsusid	?otsusid =otsu  (PlP  >otsu !16_S	et	f	\N
146922	otsusid	?otsusid =otsu  (IndIpfSg2  >otsuma !28_V	et	f	\N
146923	otsusid	?otsusid =otsu  (IndIpfPl3  >otsuma !28_V	et	f	\N
146924	otsusid	?otsusid =usi  (PlN  >ots+usi !17_S	et	f	\N
146947	kulutusid	?kulutusid =kulutu  (IndIpfSg2  >kulutuma !27_V	et	f	\N
146948	kulutusid	?kulutusid =kulutu  (IndIpfPl3  >kulutuma !27_V	et	f	\N
146949	kulutusid	?kulutusid =tusi  (PlN  >kulu+tusi !17_S	et	f	\N
146963	sulgevad	sulgevad =sulge  (IndPrPl3  >sulgema !27_V	et	f	\N
146964	sulgevad	sulgevad =sulgeva  (PlN  >sulgev !02_A	et	f	\N
146965	sulgevad	"sulgev %sulge  )V_vA  <sulgema ;27_V	et	f	\N
146966	sulgevad	"sulgev %sulge  )V_vA  <sulgema ;28_V	et	f	\N
146976	mai	mai =mai  (SgN  >mai !26_S	et	f	\N
146977	mai	mai =mai  (SgG  >mai !26_S	et	f	\N
147012	tegenud	?tegenud =tegenu  (PlN  >tegenu !01_S	et	f	\N
147013	tegenud	?tegenud =tegenu  (IndPrSg2  >tegenuma !27_V	et	f	\N
147014	tegenud	?tegenud =tegenud  (ID  >tegenud !41_A	et	f	\N
147021	ihfluentsa	?ihfluentsa =ihfluentsa  (SgN  >ihfluentsa !16_S	et	f	\N
147022	ihfluentsa	?ihfluentsa =ihfluentsa  (SgG  >ihfluentsa !16_S	et	f	\N
147023	tegen	?tegen =tegen  (SgN  >tegen !02_S	et	f	\N
147024	tegemina	?tegemina =tegemi  (SgEs  >tegemi !01_S	et	f	\N
147025	tegemina	?tegemina =tegemi  (SgEs  >tegem !02_A	et	f	\N
147026	tegemina	?tegemina =tegemina  (SgG  >tegemin !19_S	et	f	\N
147027	tegemina	?tegemina =tegemina  (SgP  >tegemin !19_S	et	f	\N
147028	tegemina	?tegemina =tegemina  (SgAdt  >tegemin !19_S	et	f	\N
147003	durfemlines	?durfemlines =durfemline  (PlIn  >durfemlin !19_S	et	f	\N
147010	kalustasid	?kalustasid =kalusta  (IndIpfSg2  >kalustama !27_V	et	f	\N
147011	kalustasid	?kalustasid =kalusta  (IndIpfPl3  >kalustama !27_V	et	f	\N
147035	kohtin	?kohtin =kohtin  (SgN  >kohtin !02_S	et	f	\N
147036	söösin	?söösin =söösi  (IndPrSg1  >söösima !28_V	et	f	\N
147037	söösin	?söösin =söösin  (SgN  >söösin !02_S	et	f	\N
147047	üheteistkümnesal	?üheteistkümnesal =üheteistkümnesa  (SgAd  >üheteistkümnesa !16_S	et	f	\N
147048	üheteistkümnesal	?üheteistkümnesal =üheteistkümnesal  (SgN  >üheteistkümnesal !19_S	et	f	\N
147049	üheteistkümnesal	?üheteistkümnesal =kümnesa  (SgAd  >ühe+teist+kümnesa !01_S	et	f	\N
147050	üheteistkümnesal	?üheteistkümnesal =kümnesal  (SgN  >ühe+teist+kümnesal !19_S	et	f	\N
147051	üheteistkümnesal	?üheteistkümnesal =teistkümnesa  (SgAd  >ühe+teistkümnesa !16_S	et	f	\N
147052	üheteistkümnesal	?üheteistkümnesal =teistkümnesal  (SgN  >ühe+teistkümnesal !19_S	et	f	\N
147062	keskpäevaeine	keskpäevaeine =eine  (SgN  >kesk+päeva+eine !06_S	et	f	\N
147063	keskpäevaeine	keskpäevaeine =eine  (SgG  >kesk+päeva+eine !06_S	et	f	\N
147073	internetti	?internetti =netti  (SgP  >inter+nett !22_AS	et	f	\N
147074	internetti	?internetti =netti  (SgAdt  >inter+nett !22_AS	et	f	\N
147075	kussteist	?kussteist =kusste  (PlEl  >kussti !01_S	et	f	\N
147076	kussteist	?kussteist =kusste  (PlEl  >kusste !06_S	et	f	\N
147077	kussteist	?kussteist =kusstei  (SgEl  >kusstei !26_S	et	f	\N
147078	kussteist	?kussteist =kussteist  (SgN  >kussteist !22_S	et	f	\N
147079	kussteist	?kussteist =stei  (SgEl  >kus+stei !26_S	et	f	\N
147080	kussteist	?kussteist =steist  (SgN  >kus+steist !22_S	et	f	\N
147085	hommiks	?hommiks =hommi  (SgTr  >hommi !16_S	et	f	\N
147086	hommiks	?hommiks =hommi  (SgTr  >homm !22_S	et	f	\N
147087	hommiks	?hommiks =hommi  (KndPrPs  >hommima !28_V	et	f	\N
147093	tegan	?tegan =tega  (IndPrSg1  >tegama !27_V	et	f	\N
147094	tegan	?tegan =tegan  (SgN  >tegan !02_S	et	f	\N
147110	sõberdega	### sõberdega	et	f	\N
147120	rüüli	?rüüli =rüüli  (SgN  >rüüli !16_S	et	f	\N
147121	rüüli	?rüüli =rüüli  (SgG  >rüüli !16_S	et	f	\N
147122	rüüli	?rüüli =rüüli  (SgG  >rüül !22_S	et	f	\N
147123	rüüli	?rüüli =rüüli  (SgP  >rüül !22_S	et	f	\N
147124	rüüli	?rüüli =rüüli  (SgAdt  >rüül !22_S	et	f	\N
147125	rüüli	?rüüli =rüüli  (IndPrPs_  >rüülima !28_V	et	f	\N
147126	rüüli	?rüüli =rüüli  (ImpPrSg2  >rüülima !28_V	et	f	\N
147128	cds	### cds	et	f	\N
147129	dvds	### dvds	et	f	\N
147134	käppis	?käppis =käppi  (IndIpfSg3  >käppima !28_V	et	f	\N
147135	käppis	?käppis =käppis  (ID  >käppis !41_DA	et	f	\N
147140	sään	?sään =sään  (SgN  >sään !22_S	et	f	\N
147150	setos	?setos =seto  (SgIn  >seto !16_S	et	f	\N
147151	setos	?setos =setos  (SgN  >setos !11~09_S	et	f	\N
147156	elavid	elavid =elavi  (PlN  >elav !02_A	et	f	\N
147157	elavid	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
147186	eramaal	eramaal =maa  (SgAd  >era+maa !26_S	et	f	\N
147187	eramaal	eramaal =maal  (SgN  >era+maal !22_S	et	f	\N
147203	venelastena	venelastena =venelas  (PlEs  >venelane !12_S	et	f	\N
147204	venelastena	venelastena =las  (PlEs  >vene+laps !14_S	et	f	\N
147220	kuulusam	?kuulusam =kuulusam  (SgN  >kuulusam !02_A	et	f	\N
147221	kuulusam	?kuulusam =usam  (SgN  >kuul+usam !02_A	et	f	\N
147222	kuulusam	?kuulusam =lusam  (SgN  >kuu+lusam !02_A	et	f	\N
147255	filmed	?filmed =filme  (PlN  >filme !06_S	et	f	\N
147256	filmed	?filmed =filme  (IndPrSg2  >filmema !27_V	et	f	\N
147257	arvestamata	arvestamata =arvesta  (SupAb  >arvestama !27_V	et	f	\N
147258	arvestamata	arvestamata =arvestamata  (ID  >arvestamata !41_A	et	f	\N
147259	arvestamata	"arvestamata %arvesta  )MATA_vA  <arvestama ;27_V	et	f	\N
147282	siim	?siim =siim  (SgN  >siim !22_S	et	f	\N
147290	neliteistkünendal	?neliteistkünendal =neliteistkünenda  (SgAd  >neliteistkünenda !16_S	et	f	\N
147291	neliteistkünendal	?neliteistkünendal =neliteistkünendal  (SgN  >neliteistkünendal !02_S	et	f	\N
147292	neliteistkünendal	?neliteistkünendal =künenda  (SgAd  >neli+teist+künenda !01_S	et	f	\N
147293	neliteistkünendal	?neliteistkünendal =teistkünenda  (SgAd  >neli+teistkünenda !16_S	et	f	\N
147294	neliteistkünendal	?neliteistkünendal =teistkünendal  (SgN  >neli+teistkünendal !02_S	et	f	\N
147295	gloucestoris	?gloucestoris =gloucestori  (SgIn  >gloucestor !02_S	et	f	\N
147296	gloucestoris	?gloucestoris =gloucestoris  (SgN  >gloucestoris !09_S	et	f	\N
147297	bristols	?bristols =bristols  (SgN  >bristols !22_S	et	f	\N
147298	üheksakümmend	?üheksakümmend =üheksakümmend  (SgN  >üheksakümmend !22_S	et	f	\N
147299	üheksakümmend	?üheksakümmend =akümmend  (SgN  >üheks+akümmend !22_S	et	f	\N
147300	üheksakümmend	?üheksakümmend =ksakümmend  (SgN  >ühe+ksakümmend !22_S	et	f	\N
147302	spaced	?spaced =space  (PlN  >space !06_S	et	f	\N
147315	shaun	?shaun =shaun  (SgN  >shaun !22_S	et	f	\N
147377	söövisin	?söövisin =söövi  (IndIpfSg1  >söövima !28_V	et	f	\N
147378	söövisin	?söövisin =söövisin  (SgN  >söövisin !19_S	et	f	\N
147389	juhtimine	juhtimine =juhtimine  (SgN  >juhtimine !12_S	et	f	\N
147390	juhtimine	"juhtimine %juhti  )MINE_vS  <juhtima ;28_V	et	f	\N
147038	joosin	?joosin =joosi  (IndPrSg1  >joosima !28_V	et	f	\N
147039	joosin	?joosin =joosin  (SgN  >joosin !02_S	et	f	\N
147053	esitamine	esitamine =esitamine  (SgN  >esitamine !12_S	et	f	\N
147054	esitamine	"esitamine %esita  )MINE_vS  <esitama ;27_V	et	f	\N
147064	pizzat	?pizzat =pizza  (SgP  >pizza !16_S	et	f	\N
147065	pizzat	?pizzat =pizzat  (SgN  >pizzat !02_S	et	f	\N
147095	üliokooli	?üliokooli =üliokooli  (SgN  >üliokooli !16_S	et	f	\N
147096	üliokooli	?üliokooli =üliokooli  (SgG  >üliokooli !16_S	et	f	\N
147097	üliokooli	?üliokooli =üliokooli  (SgG  >üliokool !22_S	et	f	\N
147098	üliokooli	?üliokooli =üliokooli  (SgP  >üliokool !22_S	et	f	\N
147099	üliokooli	?üliokooli =üliokooli  (SgAdt  >üliokool !22_S	et	f	\N
147100	üliokooli	?üliokooli =üliokooli  (IndPrPs_  >üliokoolima !28_V	et	f	\N
147101	üliokooli	?üliokooli =üliokooli  (ImpPrSg2  >üliokoolima !28_V	et	f	\N
147102	üliokooli	?üliokooli =okooli  (SgN  >üli+okooli !16_S	et	f	\N
147103	üliokooli	?üliokooli =okooli  (SgG  >üli+okooli !16_S	et	f	\N
147104	üliokooli	?üliokooli =okooli  (SgG  >üli+okool !22_S	et	f	\N
147105	üliokooli	?üliokooli =okooli  (SgP  >üli+okool !22_S	et	f	\N
147106	üliokooli	?üliokooli =okooli  (SgAdt  >üli+okool !22_S	et	f	\N
147127	räämatude	### räämatude	et	f	\N
147138	nadal	?nadal =nada  (SgAd  >nada !17_S	et	f	\N
147139	nadal	?nadal =nadal  (SgN  >nadal !02_S	et	f	\N
147143	sää	?sää =sää  (SgN  >sää !26_S	et	f	\N
147144	sää	?sää =sää  (SgG  >sää !26_S	et	f	\N
147152	setulased	?setulased =setulase  (PlN  >setulane !12_S	et	f	\N
147162	ortodaksiat	?ortodaksiat =ortodaksia  (SgP  >ortodaksia !01_S	et	f	\N
147163	ortodaksiat	?ortodaksiat =ortodaksiat  (SgN  >ortodaksiat !22_S	et	f	\N
147167	külastuvad	?külastuvad =külastu  (IndPrPl3  >külastuma !27_V	et	f	\N
147168	külastuvad	?külastuvad =külastuva  (PlN  >külastuv !02_A	et	f	\N
147169	külastuvad	?külastuvad =külastuva  (PlN  >külastuva !16_S	et	f	\N
147170	külastuvad	?külastuvad =tuva  (PlN  >külas+tuva !17_S	et	f	\N
147171	külastuvad	?külastuvad =stuva  (PlN  >küla+stuva !17_S	et	f	\N
147172	külu	?külu =külu  (SgN  >külu !17_S	et	f	\N
147173	külu	?külu =külu  (SgG  >külu !17_S	et	f	\N
147174	külu	?külu =külu  (SgP  >külu !17_S	et	f	\N
147175	külu	?külu =külu  (IndPrPs_  >küluma !27_V	et	f	\N
147176	külu	?külu =külu  (ImpPrSg2  >küluma !27_V	et	f	\N
147188	nahuvankeris	?nahuvankeris =nahuvankeri  (SgIn  >nahuvanker !02_S	et	f	\N
147189	nahuvankeris	?nahuvankeris =nahuvankeris  (SgN  >nahuvankeris !09_S	et	f	\N
147190	autotes	?autotes =autote  (PlIn  >autott !22_S	et	f	\N
147191	autotes	?autotes =tote  (PlIn  >au+tott !22_S	et	f	\N
147192	autotes	?autotes =totes  (SgN  >au+totes !09_S	et	f	\N
147230	pärni	pärni =pärni  (SgG  >pärn !22_S	et	f	\N
147231	pärni	pärni =pärni  (SgP  >pärn !22_S	et	f	\N
147232	pärni	pärni =pärni  (SgAdt  >pärn !22_S	et	f	\N
147233	pärni	pärni =pärni  (PlP  >pärn !22_S	et	f	\N
147235	elustast	?elustast =elusta  (SgEl  >elusta !01_S	et	f	\N
147236	elustast	?elustast =elustas  (SgP  >elustane !12_A	et	f	\N
147237	elustast	?elustast =tast  (SgN  >elus+tast !22_S	et	f	\N
147238	elustast	?elustast =stast  (SgN  >elu+stast !22_S	et	f	\N
147241	elustasisse	?elustasisse =elustasi  (PlIll  >elustane !12_A	et	f	\N
147242	elustasisse	?elustasisse =elustasisse  (SgG  >elustasisne !02_A	et	f	\N
147243	elustasisse	?elustasisse =elustasisse  (PlP  >elustasiss !22_S	et	f	\N
147244	elustasisse	?elustasisse =tasi  (SgIll  >elus+tasi !17_S	et	f	\N
147245	elustasisse	?elustasisse =tasisse  (SgG  >elus+tasisne !02_A	et	f	\N
147246	elustasisse	?elustasisse =tasisse  (PlP  >elus+tasiss !22_S	et	f	\N
147247	elustasisse	?elustasisse =stasi  (SgIll  >elu+stasi !17_S	et	f	\N
147248	elustasisse	?elustasisse =stasisse  (SgG  >elu+stasisne !02_A	et	f	\N
147249	elustasisse	?elustasisse =stasisse  (PlP  >elu+stasiss !22_S	et	f	\N
147252	edinburgisse	?edinburgisse =edinburgi  (SgIll  >edinburk !22_S	et	f	\N
147253	edinburgisse	?edinburgisse =edinburgisse  (SgG  >edinburgisne !02_A	et	f	\N
147254	edinburgisse	?edinburgisse =edinburgisse  (PlP  >edinburgiss !22_S	et	f	\N
147269	vägä	### vägä	et	f	\N
147270	auahne	auahne =ahne  (SgN  >au+ahne !01_A	et	f	\N
147271	auahne	auahne =ahne  (SgN  >au+ahne !06_A	et	f	\N
147272	auahne	auahne =ahne  (SgG  >au+ahne !01_A	et	f	\N
147273	auahne	auahne =ahne  (SgG  >au+ahne !06_A	et	f	\N
147276	reformierakonna	reformierakonna =konna  (SgG  >reformi+era+konn !22_S	et	f	\N
147277	reformierakonna	reformierakonna =konna  (SgP  >reformi+era+konn !22_S	et	f	\N
147278	reformierakonna	reformierakonna =konna  (SgAdt  >reformi+era+konn !22_S	et	f	\N
147279	reformierakonna	reformierakonna =erakonna  (SgG  >reformi+erakond !22_S	et	f	\N
147280	valimisi	valimisi =valimisi  (PlP  >valimine !12_S	et	f	\N
147281	valimisi	"valimine %vali  )MINE_vS  <valima ;27_V	et	f	\N
147283	pegg	?pegg =pegg  (SgN  >pegg !22_S	et	f	\N
147284	tunnev	?tunnev =tunne  (PtsPrPs  >tunnema !27_V	et	f	\N
147285	tunnev	?tunnev =tunnev  (SgN  >tunnev !02_A	et	f	\N
147286	suurbritannias	?suurbritannias =suurbritannia  (SgIn  >suurbritannia !01_S	et	f	\N
147041	vaaltesime	?vaaltesime =vaalte  (IndIpfPl1  >vaaltema !27_V	et	f	\N
147055	eestii	?eestii =eestii  (SgN  >eestii !26_S	et	f	\N
147056	eestii	?eestii =eestii  (SgG  >eestii !26_S	et	f	\N
147057	eestii	?eestii =tii  (SgN  >ees+tii !26_S	et	f	\N
147058	eestii	?eestii =tii  (SgG  >ees+tii !26_S	et	f	\N
147060	õhtu	õhtu =õhtu  (SgN  >õhtu !01_S	et	f	\N
147061	õhtu	õhtu =õhtu  (SgG  >õhtu !01_S	et	f	\N
147066	kõrtsi	kõrtsi =kõrtsi  (SgG  >kõrts !22_S	et	f	\N
147067	kõrtsi	kõrtsi =kõrtsi  (SgP  >kõrts !22_S	et	f	\N
147068	kõrtsi	kõrtsi =kõrtsi  (SgAdt  >kõrts !22_S	et	f	\N
147069	hommikueine	hommikueine =eine  (SgN  >hommiku+eine !06_S	et	f	\N
147070	hommikueine	hommikueine =eine  (SgG  >hommiku+eine !06_S	et	f	\N
147081	politika	?politika =politika  (SgN  >politika !01_S	et	f	\N
147082	politika	?politika =politika  (SgG  >politika !01_S	et	f	\N
147083	politika	?politika =politika  (SgG  >politikas !02_A	et	f	\N
147118	kappi	kappi =kappi  (SgP  >kapp !22_S	et	f	\N
147119	kappi	kappi =kappi  (SgAdt  >kapp !22_S	et	f	\N
147141	seed	?seed =seed  (SgN  >seed !22_S	et	f	\N
147145	nähan	?nähan =näha  (IndPrSg1  >nähama !27_V	et	f	\N
147146	nähan	?nähan =nähan  (SgN  >nähan !02_S	et	f	\N
147158	setutena	### setutena	et	f	\N
147166	kalat	?kalat =kalat  (SgN  >kalat !02_S	et	f	\N
147177	müüvad	müüvad =müü  (IndPrPl3  >müüma !38_V	et	f	\N
147178	müüvad	müüvad =müüva  (PlN  >müüv !02_A	et	f	\N
147179	müüvad	"müüv %müü  )V_vA  <müüma ;38_V	et	f	\N
147183	luhavad	?luhavad =luha  (IndPrPl3  >luhama !27_V	et	f	\N
147184	luhavad	?luhavad =luhava  (PlN  >luhava !01_S	et	f	\N
147185	luhavad	?luhavad =luhava  (PlN  >luhav !02_A	et	f	\N
147193	jõudavad	?jõudavad =jõuda  (IndPrPl3  >jõudama !29_V	et	f	\N
147194	jõudavad	?jõudavad =jõudava  (PlN  >jõudava !01_S	et	f	\N
147195	jõudavad	?jõudavad =jõudava  (PlN  >jõudav !02_A	et	f	\N
147196	jõudavad	?jõudavad =dava  (PlN  >jõu+dava !17_S	et	f	\N
147200	setulast	setulast =la  (SgEl  >setu+la !26_S	et	f	\N
147201	setulast	setulast =las  (SgP  >setu+laps !14_S	et	f	\N
147202	setulast	setulast =last  (SgN  >setu+last !22_S	et	f	\N
147208	elustasis	?elustasis =elustasi  (PlIn  >elustane !12_A	et	f	\N
147209	elustasis	?elustasis =elustasis  (SgN  >elustasis !09_S	et	f	\N
147210	elustasis	?elustasis =tasi  (SgIn  >elus+tasi !17_S	et	f	\N
147211	elustasis	?elustasis =tasis  (SgN  >elus+tasis !09_S	et	f	\N
147212	elustasis	?elustasis =stasi  (SgIn  >elu+stasi !17_S	et	f	\N
147213	elustasis	?elustasis =stasis  (SgN  >elu+stasis !09_S	et	f	\N
147214	rein	?rein =rein  (SgN  >rein !22_S	et	f	\N
147217	joonis	joonis =jooni  (PlIn  >joon !13_S	et	f	\N
147218	joonis	joonis =jooni  (IndIpfSg3  >joonima !28_V	et	f	\N
147219	joonis	joonis =joonis  (SgN  >joonis !09_S	et	f	\N
147223	juhatanud	juhatanud =juhata  (PtsPtPs  >juhatama !27_V	et	f	\N
147224	juhatanud	juhatanud =juhatanu  (PlN  >juhatanu !01_S	et	f	\N
147225	juhatanud	"juhatanu %juhata  )NU_vS  <juhatama ;27_V	et	f	\N
147226	juhatanud	juhatanud =juhatanud  (ID  >juhatanud !41_A	et	f	\N
147227	juhatanud	"juhatanud %juhata  )NUD_vA  <juhatama ;27_V	et	f	\N
147228	priiti	priiti =priiti  (SgP  >priit !22_S	et	f	\N
147229	priiti	priiti =priiti  (SgAdt  >priit !22_S	et	f	\N
147234	imelikut	### imelikut	et	f	\N
147239	valismaal	?valismaal =valismaa  (SgAd  >valismaa !26_S	et	f	\N
147240	valismaal	?valismaal =valismaal  (SgN  >valismaal !22_S	et	f	\N
147303	teostanud	teostanud =teosta  (PtsPtPs  >teostama !27_V	et	f	\N
147304	teostanud	teostanud =teostanu  (PlN  >teostanu !01_S	et	f	\N
147305	teostanud	"teostanu %teosta  )NU_vS  <teostama ;27_V	et	f	\N
147306	teostanud	teostanud =teostanud  (ID  >teostanud !41_A	et	f	\N
147308	teostanud	"teostanud %teosta  )NUD_vA  <teostama ;27_V	et	f	\N
147312	londons	?londons =londons  (SgN  >londons !02_S	et	f	\N
147321	tom	### tom	et	f	\N
147326	maureen	?maureen =maureen  (SgN  >maureen !22_S	et	f	\N
147345	peggaga	?peggaga =pegga  (SgKom  >pegga !16_S	et	f	\N
147371	laserplaatilt	?laserplaatilt =laserplaati  (SgAbl  >laserplaati !16_S	et	f	\N
147381	juuasime	?juuasime =juuasi  (IndPrPl1  >juuasima !28_V	et	f	\N
147382	kooliks	kooliks =kooli  (SgTr  >kool !22_S	et	f	\N
147383	kooliks	kooliks =kooli  (PlTr  >kool !22_S	et	f	\N
147384	kooliks	kooliks =iks  (SgN  >kool+iks !22_S	et	f	\N
147386	sõitasin	?sõitasin =sõita  (IndIpfSg1  >sõitama !27_V	et	f	\N
147387	sõitasin	?sõitasin =sõitasin  (SgN  >sõitasin !19_S	et	f	\N
147407	järell	?järell =järell  (SgN  >järell !22_S	et	f	\N
147409	parkisse	?parkisse =parkisse  (SgG  >parkisne !02_A	et	f	\N
147410	parkisse	?parkisse =parkisse  (PlP  >parkiss !22_S	et	f	\N
147423	rannaid	?rannaid =rannai  (PlN  >rannai !26_S	et	f	\N
147424	rannaid	?rannaid =rannai  (SgP  >rannai !26_S	et	f	\N
147425	rannaid	?rannaid =rannaid  (SgN  >rannaid !22_S	et	f	\N
147429	ansambeluid	?ansambeluid =ansambelui  (PlN  >ansambelui !26_S	et	f	\N
147430	ansambeluid	?ansambeluid =ansambelui  (SgP  >ansambelui !26_S	et	f	\N
147437	talvena	talvena =talve  (SgEs  >talv !22_S	et	f	\N
147092	kauplusid	?kauplusid =lusi  (PlN  >kaup+lusi !17_S	et	f	\N
147112	elatuba	?elatuba =elatuba  (SgN  >elatuba !16_S	et	f	\N
147113	elatuba	?elatuba =elatuba  (SgG  >elatuba !16_S	et	f	\N
147136	magamistubas	?magamistubas =magamistuba  (SgIn  >magamistuba !16_S	et	f	\N
147137	magamistubas	?magamistubas =tubas  (SgN  >magamis+tubas !07_S	et	f	\N
147197	autotega	### autotega	et	f	\N
147205	ökolooguna	?ökolooguna =guna  (SgN  >öko+loo+guna !17_S	et	f	\N
147206	ökolooguna	?ökolooguna =guna  (SgG  >öko+loo+guna !17_S	et	f	\N
147207	ökolooguna	?ökolooguna =guna  (SgP  >öko+loo+guna !17_S	et	f	\N
147215	raamatuga	raamatuga =raamatu  (SgKom  >raamat !02_S	et	f	\N
147216	raamatuga	raamatuga =atu  (SgKom  >raam+att !22_S	et	f	\N
147274	22-aastane	-aastane =aastane  (SgN  >-aastane !12~10_A	et	f	\N
147275	22-aastane	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
147313	filmaks	?filmaks =filma  (SgTr  >filma !16_S	et	f	\N
147314	filmaks	?filmaks =filma  (KndPrPs  >filmama !29_V	et	f	\N
147323	david	?david =davi  (PlN  >davi !17_S	et	f	\N
147324	david	?david =davi  (IndPrSg2  >davima !27_V	et	f	\N
147329	tuhandes	tuhandes =tuhande  (SgIn  >tuhat !02_N	et	f	\N
147330	tuhandes	tuhandes =tuhandes  (SgN  >tuhandes !02_O	et	f	\N
147332	frost	?frost =frost  (SgN  >frost !22_S	et	f	\N
147333	meelelahutussaades	?meelelahutussaades =meelelahutussaa  (PlIn  >meelelahutussaa !26_S	et	f	\N
147334	meelelahutussaades	?meelelahutussaades =meelelahutussaade  (SgIn  >meelelahutussaade !16_S	et	f	\N
147335	meelelahutussaades	?meelelahutussaades =meelelahutussaade  (PlIn  >meelelahutussaat !22_S	et	f	\N
147336	meelelahutussaades	?meelelahutussaades =saa  (PlIn  >meele+lahutus+saa !26_S	et	f	\N
147337	meelelahutussaades	?meelelahutussaades =saades  (SgN  >meele+lahutus+saades !09_S	et	f	\N
147338	meelelahutussaades	?meelelahutussaades =lahutussaa  (PlIn  >meele+lahutussaa !26_S	et	f	\N
147339	meelelahutussaades	?meelelahutussaades =lahutussaade  (SgIn  >meele+lahutussaade !16_S	et	f	\N
147340	meelelahutussaades	?meelelahutussaades =lahutussaade  (PlIn  >meele+lahutussaat !22_S	et	f	\N
147341	meelelahutussaades	?meelelahutussaades =lelahutussaa  (PlIn  >mee+lelahutussaa !26_S	et	f	\N
147342	meelelahutussaades	?meelelahutussaades =lelahutussaade  (SgIn  >mee+lelahutussaade !16_S	et	f	\N
147343	meelelahutussaades	?meelelahutussaades =lelahutussaade  (PlIn  >mee+lelahutussaat !22_S	et	f	\N
147348	peggi	?peggi =peggi  (SgN  >peggi !16_S	et	f	\N
147349	peggi	?peggi =peggi  (SgG  >peggi !16_S	et	f	\N
147350	peggi	?peggi =peggi  (SgG  >pegg !22_S	et	f	\N
147351	peggi	?peggi =peggi  (SgP  >pegg !22_S	et	f	\N
147352	peggi	?peggi =peggi  (SgAdt  >pegg !22_S	et	f	\N
147353	peggi	?peggi =peggi  (IndPrPs_  >peggima !28_V	et	f	\N
147354	peggi	?peggi =peggi  (ImpPrSg2  >peggima !28_V	et	f	\N
147363	jõulud-tv	### jõulud-tv	et	f	\N
147365	peasime	?peasime =peasi  (IndPrPl1  >peasima !28_V	et	f	\N
147366	äru	?äru =äru  (SgN  >äru !17_S	et	f	\N
147367	äru	?äru =äru  (SgG  >äru !17_S	et	f	\N
147368	äru	?äru =äru  (SgP  >äru !17_S	et	f	\N
147369	äru	?äru =äru  (IndPrPs_  >äruma !27_V	et	f	\N
147370	äru	?äru =äru  (ImpPrSg2  >äruma !27_V	et	f	\N
147372	kinks	?kinks =kinks  (SgN  >kinks !22_S	et	f	\N
147373	söömasime	?söömasime =sööma  (IndIpfPl1  >söömama !29_V	et	f	\N
147374	õd	### õd	et	f	\N
147379	jahisaaki	jahisaaki =saaki  (SgP  >jahi+saak !22_S	et	f	\N
147380	jahisaaki	jahisaaki =saaki  (SgAdt  >jahi+saak !22_S	et	f	\N
147385	lahteks	?lahteks =lahte  (KndPrPs  >lahtema !27_V	et	f	\N
147391	kurssu	?kurssu =kurssu  (SgN  >kurssu !01_S	et	f	\N
147392	kurssu	?kurssu =kurssu  (SgG  >kurssu !01_S	et	f	\N
147395	kurssu	?kurssu =kurssu  (IndPrPs_  >kurssuma !27_V	et	f	\N
147397	kurssu	?kurssu =kurssu  (ImpPrSg2  >kurssuma !27_V	et	f	\N
147411	rõõmutundavad	?rõõmutundavad =rõõmutunda  (IndPrPl3  >rõõmutundama !27_V	et	f	\N
147412	rõõmutundavad	?rõõmutundavad =rõõmutundava  (PlN  >rõõmutundav !02_A	et	f	\N
147413	rõõmutundavad	?rõõmutundavad =rõõmutundava  (PlN  >rõõmutundava !16_S	et	f	\N
147414	rõõmutundavad	?rõõmutundavad =tundava  (PlN  >rõõmu+tundava !01_S	et	f	\N
147416	rõõmutundavad	?rõõmutundavad =tundava  (PlN  >rõõmu+tundav !02_A	et	f	\N
147422	sõbrega	### sõbrega	et	f	\N
147431	ilmast	ilmast =ilma  (SgEl  >ilm !22_S	et	f	\N
147432	ilmast	ilmast =ilmas  (SgP  >ilmane !10_A	et	f	\N
147433	ilmast	"ilmane %ilma  )NE_aA  <ilm ;22_S	et	f	\N
147434	ilmast	ilmast =ast  (SgN  >ilm+ast !22_S	et	f	\N
147439	segakauplusete	### segakauplusete	et	f	\N
147448	apelsinad	### apelsinad	et	f	\N
147449	õunamahla	õunamahla =mahla  (SgG  >õuna+mahl !22_S	et	f	\N
147451	õunamahla	õunamahla =mahla  (SgP  >õuna+mahl !22_S	et	f	\N
147452	õunamahla	õunamahla =mahla  (SgAdt  >õuna+mahl !22_S	et	f	\N
147479	saasin	?saasin =saasi  (IndPrSg1  >saasima !28_V	et	f	\N
147480	saasin	?saasin =saasin  (SgN  >saasin !02_S	et	f	\N
147486	joomasin	?joomasin =jooma  (IndIpfSg1  >joomama !29_V	et	f	\N
147487	joomasin	?joomasin =joomasin  (SgN  >joomasin !19_S	et	f	\N
147496	dundeesse	?dundeesse =dundee  (SgIll  >dundee !26_S	et	f	\N
147497	dundeesse	?dundeesse =dundees  (SgAdt  >dundeene !12_A	et	f	\N
147133	tubas	?tubas =tubas  (SgN  >tubas !07_S	et	f	\N
147142	politik	?politik =politik  (SgN  >politik !02_S	et	f	\N
147147	grammar	?grammar =grammar  (SgN  >grammar !02_S	et	f	\N
147148	käheksa	?käheksa =käheksa  (SgN  >käheksa !01_S	et	f	\N
147149	käheksa	?käheksa =käheksa  (SgG  >käheksa !01_S	et	f	\N
147153	tahtasid	?tahtasid =tahta  (PlP  >tahta !16_S	et	f	\N
147154	tahtasid	?tahtasid =tahta  (IndIpfSg2  >tahtama !29_V	et	f	\N
147155	tahtasid	?tahtasid =tahta  (IndIpfPl3  >tahtama !29_V	et	f	\N
147159	harrastavad	harrastavad =harrasta  (IndPrPl3  >harrastama !27_V	et	f	\N
147160	harrastavad	harrastavad =harrastava  (PlN  >harrastav !02_A	et	f	\N
147161	harrastavad	"harrastav %harrasta  )V_vA  <harrastama ;27_V	et	f	\N
147164	pottsepatöökodat	?pottsepatöökodat =kodat  (SgN  >pott+sepa+töö+kodat !02_S	et	f	\N
147165	setulasi	?setulasi =setulasi  (PlP  >setulane !12_S	et	f	\N
147180	püüdavad	?püüdavad =püüda  (IndPrPl3  >püüdama !29_V	et	f	\N
147181	püüdavad	?püüdavad =püüdava  (PlN  >püüdava !01_S	et	f	\N
147182	püüdavad	?püüdavad =püüdava  (PlN  >püüdav !02_A	et	f	\N
147198	setulaste	setulaste =las  (PlG  >setu+laps !14_S	et	f	\N
147199	setulaste	setulaste =laste  (PlP  >setu+last !22_S	et	f	\N
147250	pärnilt	pärnilt =pärni  (SgAbl  >pärn !22_S	et	f	\N
147251	pärnilt	pärnilt =pärni  (PlAbl  >pärn !22_S	et	f	\N
147260	elustasi	?elustasi =elustasi  (PlP  >elustane !12_A	et	f	\N
147261	elustasi	?elustasi =tasi  (SgN  >elus+tasi !17_S	et	f	\N
147262	elustasi	?elustasi =tasi  (SgG  >elus+tasi !17_S	et	f	\N
147263	elustasi	?elustasi =tasi  (SgP  >elus+tasi !17_S	et	f	\N
147264	elustasi	?elustasi =stasi  (SgN  >elu+stasi !17_S	et	f	\N
147265	elustasi	?elustasi =stasi  (SgG  >elu+stasi !17_S	et	f	\N
147266	elustasi	?elustasi =stasi  (SgP  >elu+stasi !17_S	et	f	\N
147267	eeste	eeste =ees  (PlG  >eene !10_A	et	f	\N
147268	eeste	"eene %ee  )NE_aA  <esi ;15_S	et	f	\N
147301	arvam	?arvam =arvam  (SgN  >arvam !02_A	et	f	\N
147307	komöödia	komöödia =komöödia  (SgN  >komöödia !01_S	et	f	\N
147309	komöödia	komöödia =komöödia  (SgG  >komöödia !01_S	et	f	\N
147310	komöödia	komöödia =dia  (SgN  >kom+öö+dia !26_S	et	f	\N
147311	komöödia	komöödia =dia  (SgG  >kom+öö+dia !26_S	et	f	\N
147322	cruisega	?cruisega =cruise  (SgKom  >cruise !06_S	et	f	\N
147325	schwimmeraga	?schwimmeraga =schwimmera  (SgKom  >schwimmera !01_S	et	f	\N
147327	mccanniga	?mccanniga =mccanni  (SgKom  >mccanni !16_S	et	f	\N
147328	mccanniga	?mccanniga =mccanni  (SgKom  >mccann !22_S	et	f	\N
147359	spacedes	### spacedes	et	f	\N
147364	mängisme	?mängisme =mängisme  (PlP  >mängism !22_S	et	f	\N
147393	poliitaks	?poliitaks =poliita  (SgTr  >poliita !16_S	et	f	\N
147394	poliitaks	?poliitaks =poliita  (KndPrPs  >poliitama !27_V	et	f	\N
147396	poliitaks	?poliitaks =poliitaks  (SgN  >poliitaks !22_S	et	f	\N
147398	poliitaks	?poliitaks =aks  (SgN  >poliit+aks !22_S	et	f	\N
147441	grammi	grammi =grammi  (SgG  >gramm !22_S	et	f	\N
147442	grammi	grammi =grammi  (SgP  >gramm !22_S	et	f	\N
147443	grammi	grammi =grammi  (SgAdt  >gramm !22_S	et	f	\N
147455	porgandud	?porgandud =porgandu  (PlN  >porgandu !01_S	et	f	\N
147456	porgandud	?porgandud =porgandu  (IndPrSg2  >porganduma !27_V	et	f	\N
147457	juurviljasuppi	juurviljasuppi =suppi  (SgP  >juur+vilja+supp !22_S	et	f	\N
147458	juurviljasuppi	juurviljasuppi =suppi  (SgAdt  >juur+vilja+supp !22_S	et	f	\N
147462	spordikampsunad	### spordikampsunad	et	f	\N
147465	uuriminet	### uuriminet	et	f	\N
147469	esmaspäeva	esmaspäeva =päeva  (SgG  >esmas+päev !22_S	et	f	\N
147470	esmaspäeva	esmaspäeva =päeva  (SgP  >esmas+päev !22_S	et	f	\N
147471	esmaspäeva	esmaspäeva =päeva  (SgAdt  >esmas+päev !22_S	et	f	\N
147472	süüasin	?süüasin =süüasi  (IndPrSg1  >süüasima !28_V	et	f	\N
147473	süüasin	?süüasin =süüasin  (SgN  >süüasin !02_S	et	f	\N
147474	süüasin	?süüasin =asin  (SgN  >süü+asin !02_S	et	f	\N
147477	lähesin	?lähesin =lähe  (IndIpfSg1  >lähema !27_V	et	f	\N
147478	lähesin	?lähesin =lähesin  (SgN  >lähesin !19_S	et	f	\N
147483	teisipäeva	teisipäeva =päeva  (SgG  >teisi+päev !22_S	et	f	\N
147484	teisipäeva	teisipäeva =päeva  (SgP  >teisi+päev !22_S	et	f	\N
147485	teisipäeva	teisipäeva =päeva  (SgAdt  >teisi+päev !22_S	et	f	\N
147488	haiglast	haiglast =haigla  (SgEl  >haigla !01_S	et	f	\N
147489	haiglast	haiglast =haiglas  (SgP  >haiglane !12?10_A	et	f	\N
147490	haiglast	"haiglane %haigla  )NE_aA  <haigla ;01_S	et	f	\N
147526	buckfasti	?buckfasti =buckfasti  (ID  >buckfasti !41_D	et	f	\N
147527	buckfasti	?buckfasti =buckfasti  (IndPrPs_  >buckfastima !28_V	et	f	\N
147528	buckfasti	?buckfasti =buckfasti  (ImpPrSg2  >buckfastima !28_V	et	f	\N
147567	isu	isu =isu  (SgN  >isu !17_S	et	f	\N
147568	isu	isu =isu  (SgG  >isu !17_S	et	f	\N
147569	isu	isu =isu  (SgP  >isu !17_S	et	f	\N
147571	wogan	?wogan =woga  (IndPrSg1  >wogama !27_V	et	f	\N
147572	wogan	?wogan =wogan  (SgN  >wogan !02_S	et	f	\N
147589	tescos	?tescos =tesco  (SgIn  >tesco !16_S	et	f	\N
147590	tescos	?tescos =tescos  (SgN  >tescos !11~09_S	et	f	\N
147624	tales	?tales =tale  (SgIn  >tale !16_S	et	f	\N
147287	suurbritannias	?suurbritannias =suurbritannias  (SgN  >suurbritannias !11_S	et	f	\N
147288	suurbritannias	?suurbritannias =britannia  (SgIn  >suur+britannia !01_S	et	f	\N
147289	suurbritannias	?suurbritannias =britannias  (SgN  >suur+britannias !11_S	et	f	\N
147316	surnu	surnu =surnu  (SgN  >surnu !01_S	et	f	\N
147317	surnu	"surnu %sur  )NU_vS  <surema ;36_V	et	f	\N
147318	surnu	surnu =surnu  (SgN  >surnu !06_S	et	f	\N
147319	surnu	surnu =surnu  (SgG  >surnu !01_S	et	f	\N
147320	surnu	surnu =surnu  (SgG  >surnu !06_S	et	f	\N
147331	nick	?nick =nick  (SgN  >nick !22_S	et	f	\N
147344	filmas	?filmas =filma  (SgIn  >filma !16_S	et	f	\N
147346	filmas	?filmas =filma  (IndIpfSg3  >filmama !29_V	et	f	\N
147347	filmas	?filmas =filmas  (SgN  >filmas !07_S	et	f	\N
147355	lühikesti	lühikesti =kesti  (SgG  >lühi+kest !22_S	et	f	\N
147356	lühikesti	lühikesti =kesti  (SgP  >lühi+kest !22_S	et	f	\N
147357	lühikesti	lühikesti =kesti  (SgAdt  >lühi+kest !22_S	et	f	\N
147358	lühikesti	lühikesti =kesti  (PlP  >lühi+kest !22_S	et	f	\N
147360	lõõgastav	lõõgastav =lõõgasta  (PtsPrPs  >lõõgastama !27_V	et	f	\N
147361	lõõgastav	lõõgastav =lõõgastav  (SgN  >lõõgastav !02_A	et	f	\N
147362	lõõgastav	"lõõgastav %lõõgasta  )V_vA  <lõõgastama ;27_V	et	f	\N
147375	meheõde	meheõde =õde  (SgN  >mehe+õde !18_S	et	f	\N
147376	meheõde	meheõde =õde  (SgP  >mehe+õde !18_S	et	f	\N
147388	ragbimeeskondiga	?ragbimeeskondiga =ragbimeeskondi  (SgKom  >ragbimeeskont !22_S	et	f	\N
147402	ajutiseid	?ajutiseid =ajutisei  (PlN  >ajutisei !26_S	et	f	\N
147403	ajutiseid	?ajutiseid =ajutisei  (SgP  >ajutisei !26_S	et	f	\N
147404	ajutiseid	?ajutiseid =tisei  (PlN  >aju+tisei !26_S	et	f	\N
147405	ajutiseid	?ajutiseid =tisei  (SgP  >aju+tisei !26_S	et	f	\N
147406	ajutiseid	?ajutiseid =tiseid  (SgN  >aju+tiseid !22_S	et	f	\N
147408	uurimines	?uurimines =uurimine  (PlIn  >uurimin !19_S	et	f	\N
147417	jooakse	?jooakse =jooakse  (SgG  >jooakne !02_A	et	f	\N
147418	jooakse	?jooakse =jooakse  (PlP  >jooaks !22_S	et	f	\N
147419	minnavad	?minnavad =minna  (IndPrPl3  >minnama !29_V	et	f	\N
147420	minnavad	?minnavad =minnava  (PlN  >minnava !01_S	et	f	\N
147421	minnavad	?minnavad =minnava  (PlN  >minnav !02_A	et	f	\N
147426	usasse	?usasse =usa  (SgIll  >usa !17_S	et	f	\N
147427	usasse	?usasse =usasse  (SgG  >usasne !02_A	et	f	\N
147428	usasse	?usasse =usasse  (PlP  >usass !22_S	et	f	\N
147440	nelisada	### nelisada	et	f	\N
147459	naela	naela =naela  (SgG  >nael !23?22_S	et	f	\N
147460	naela	naela =naela  (SgP  >nael !23?22_S	et	f	\N
147461	naela	naela =naela  (SgAdt  >nael !23?22_S	et	f	\N
147475	minnesin	?minnesin =minne  (IndIpfSg1  >minnema !27_V	et	f	\N
147476	minnesin	?minnesin =minnesin  (SgN  >minnesin !19_S	et	f	\N
147491	mingisse	mingisse =mingi  (SgIll  >mingi !01_P	et	f	\N
147492	mingisse	mingisse =mingi  (SgIll  >mink !22_S	et	f	\N
147503	mängimaid	?mängimaid =mängima  (PlP  >mängim !02_A	et	f	\N
147504	mängimaid	?mängimaid =mängimai  (PlN  >mängimai !26_S	et	f	\N
147505	mängimaid	?mängimaid =mängimai  (SgP  >mängimai !26_S	et	f	\N
147506	lähesid	?lähesid =lähe  (IndIpfSg2  >lähema !27_V	et	f	\N
147507	lähesid	?lähesid =lähe  (IndIpfPl3  >lähema !27_V	et	f	\N
147521	trooni	trooni =trooni  (SgG  >troon !22_S	et	f	\N
147522	trooni	trooni =trooni  (SgP  >troon !22_S	et	f	\N
147523	trooni	trooni =trooni  (SgAdt  >troon !22_S	et	f	\N
147524	trooni	trooni =trooni  (IndPrPs_  >troonima !28_V	et	f	\N
147525	trooni	trooni =trooni  (ImpPrSg2  >troonima !28_V	et	f	\N
147570	terry	### terry	et	f	\N
147583	telev	?telev =tele  (PtsPrPs  >telema !27_V	et	f	\N
147584	telev	?telev =telev  (SgN  >telev !02_A	et	f	\N
147598	briti	briti =briti  (ID  >briti !41_G	et	f	\N
147599	briti	briti =briti  (SgG  >britt !22_S	et	f	\N
147603	vaieldav	vaieldav =vaiel  (PtsPrIps  >vaidlema !30_V	et	f	\N
147604	vaieldav	vaieldav =vaieldav  (SgN  >vaieldav !02_A	et	f	\N
147605	vaieldav	"vaieldav %vaiel  )TAV_vAS  <vaidlema ;30_V	et	f	\N
147606	publikta	?publikta =publikta  (SgN  >publikta !01_S	et	f	\N
147607	publikta	?publikta =publikta  (SgG  >publikta !01_S	et	f	\N
147608	kurbusaga	?kurbusaga =kurbusa  (SgKom  >kurbusa !01_S	et	f	\N
147609	kurbusaga	?kurbusaga =usa  (SgKom  >kurb+usa !17_S	et	f	\N
147610	mamma	mamma =mamma  (SgN  >mamma !16_S	et	f	\N
147611	mamma	mamma =mamma  (SgG  >mamma !16_S	et	f	\N
147612	armistad	?armistad =armista  (PlN  >armista !01_S	et	f	\N
147613	armistad	?armistad =armista  (IndPrSg2  >armistama !27_V	et	f	\N
147623	potter	?potter =potter  (SgN  >potter !02_S	et	f	\N
147668	nauditav	nauditav =naudi  (PtsPrIps  >nautima !28_V	et	f	\N
147669	nauditav	nauditav =nauditav  (SgN  >nauditav !02_A	et	f	\N
147670	nauditav	"nauditav %naudi  )TAV_vAS  <nautima ;28_V	et	f	\N
147674	nevisse	?nevisse =nevi  (SgIll  >nevi !17_S	et	f	\N
147675	nevisse	?nevisse =nevisse  (SgG  >nevisne !02_A	et	f	\N
147676	nevisse	?nevisse =nevisse  (PlP  >neviss !22_S	et	f	\N
147684	olukoras	?olukoras =olukora  (SgIn  >olukora !16_S	et	f	\N
147685	olukoras	?olukoras =kora  (SgIn  >olu+kora !17_S	et	f	\N
147686	olukoras	?olukoras =koras  (SgN  >olu+koras !09_S	et	f	\N
147399	ida-euroopa	ida-euroopa =euroopa  (ID  >ida-euroopa !41_G	et	f	\N
147400	ida-euroopa	ida-euroopa =euroopa  (SgN  >ida-euroopa !01_H	et	f	\N
147401	ida-euroopa	ida-euroopa =euroopa  (SgG  >ida-euroopa !01_H	et	f	\N
147415	kelvingroves	### kelvingroves	et	f	\N
147435	valtama	?valtama =valta  (Sup  >valtama !29_V	et	f	\N
147436	valtama	?valtama =valtama  (SgG  >valtam !02_A	et	f	\N
147447	banaanad	?banaanad =banaana  (PlN  >banaana !16_S	et	f	\N
147463	filmad	?filmad =filma  (PlN  >filma !16_S	et	f	\N
147464	filmad	?filmad =filma  (IndPrSg2  >filmama !29_V	et	f	\N
147500	socker	?socker =socker  (SgN  >socker !02_S	et	f	\N
147509	teeninduid	?teeninduid =teenindu  (PlP  >teenindu !01_S	et	f	\N
147510	teeninduid	?teeninduid =teenindui  (PlN  >teenindui !26_S	et	f	\N
147511	teeninduid	?teeninduid =teenindui  (SgP  >teenindui !26_S	et	f	\N
147512	teeninduid	?teeninduid =nindui  (PlN  >tee+nindui !26_S	et	f	\N
147513	teeninduid	?teeninduid =nindui  (SgP  >tee+nindui !26_S	et	f	\N
147514	teeninduid	?teeninduid =ninduid  (SgN  >tee+ninduid !22_S	et	f	\N
147515	hooliks	hooliks =hooli  (PlTr  >hool !13_S	et	f	\N
147516	hooliks	hooliks =hooli  (KndPrPs  >hoolima !28_V	et	f	\N
147517	vahetaks	vahetaks =vaheta  (KndPrPs  >vahetama !27_V	et	f	\N
147518	vahetaks	vahetaks =taks  (SgN  >vahe+taks !22_S	et	f	\N
147519	kuningaale	kuningaale =ale  (SgN  >kuninga+ale !16_S	et	f	\N
147520	kuningaale	kuningaale =ale  (SgG  >kuninga+ale !16_S	et	f	\N
147537	kenan	?kenan =kena  (IndPrSg1  >kenama !27_V	et	f	\N
147538	kenan	?kenan =kenan  (SgN  >kenan !02_S	et	f	\N
147580	kulus	kulus =kulu  (SgIn  >kulu !17_S	et	f	\N
147581	kulus	kulus =kulu  (SgIn  >kulg !22_S	et	f	\N
147582	kulus	kulus =kulu  (IndIpfSg3  >kuluma !27_V	et	f	\N
147585	raaddiktor	?raaddiktor =raaddiktor  (SgN  >raaddiktor !02_S	et	f	\N
147593	lapselapse	lapselapse =lapse  (SgG  >lapse+laps !14_S	et	f	\N
147594	lapselapse	lapselapse =lapse  (PlP  >lapse+laps !22_S	et	f	\N
147621	kuulsus	kuulsus =kuulsus  (SgN  >kuulsus !11~09_S	et	f	\N
147622	kuulsus	"kuulsus %kuulsa  )US_aS  <kuulus ;02_A	et	f	\N
147632	kirjutud	?kirjutud =kirju  (PtsPtIps  >kirjuma !27_V	et	f	\N
147633	kirjutud	?kirjutud =kirjutu  (PlN  >kirjutu !01_AS	et	f	\N
147634	kirjutud	?kirjutud =kirjutu  (IndPrSg2  >kirjutuma !27_V	et	f	\N
147635	kirjutud	?kirjutud =kirjutud  (ID  >kirjutud !41_A	et	f	\N
147644	lühidalt	lühidalt =lühida  (SgAbl  >lühida !02_A	et	f	\N
147645	lühidalt	lühidalt =lühidalt  (ID  >lühidalt !41_D	et	f	\N
147646	lühidalt	"lühidalt %lühida  )LT_mD  <lühida ;02_A	et	f	\N
147651	tõlkimasin	?tõlkimasin =tõlkimasin  (SgN  >tõlkimasin !19_S	et	f	\N
147657	maupinil	?maupinil =maupini  (SgAd  >maupin !02_S	et	f	\N
147658	kirjutus	kirjutus =kirjutus  (SgN  >kirjutus !11_S	et	f	\N
147660	kirjutus	"kirjutus %kirjuta  )US_vS  <kirjutama ;27_V	et	f	\N
147695	puhkusele	puhkusele =puhkuse  (SgAll  >puhkus !11~09_S	et	f	\N
147696	puhkusele	puhkusele =use  (PlAll  >puhk+usk !22_S	et	f	\N
147713	vegast	?vegast =vega  (SgEl  >vega !17_S	et	f	\N
147714	vegast	?vegast =vegas  (SgP  >vegas !07_S	et	f	\N
147715	vegast	?vegast =vegas  (SgP  >vegane !10_A	et	f	\N
147734	kaida	?kaida =kaida  (SgN  >kaida !16_S	et	f	\N
147735	kaida	?kaida =kaida  (SgG  >kaida !16_S	et	f	\N
147736	kaida	?kaida =kaida  (IndPrPs_  >kaidama !29_V	et	f	\N
147737	kaida	?kaida =kaida  (ImpPrSg2  >kaidama !29_V	et	f	\N
147743	ajalehteid	?ajalehteid =ajalehtei  (PlN  >ajalehtei !26_S	et	f	\N
147744	ajalehteid	?ajalehteid =ajalehtei  (SgP  >ajalehtei !26_S	et	f	\N
147745	ajalehteid	?ajalehteid =eid  (SgN  >aja+leht+eid !22_S	et	f	\N
147746	ajalehteid	?ajalehteid =lehtei  (PlN  >aja+lehtei !26_S	et	f	\N
147747	ajalehteid	?ajalehteid =lehtei  (SgP  >aja+lehtei !26_S	et	f	\N
147748	ajalehteid	?ajalehteid =lehteid  (SgN  >aja+lehteid !22_S	et	f	\N
147773	venelasedi	### venelasedi	et	f	\N
147779	konsertied	?konsertied =konsertie  (PlN  >konsertie !01_S	et	f	\N
147780	konsertied	?konsertied =konsertied  (SgN  >konsertied !22_S	et	f	\N
147808	suitsetamine	suitsetamine =suitsetamine  (SgN  >suitsetamine !12_S	et	f	\N
147809	suitsetamine	"suitsetamine %suitseta  )MINE_vS  <suitsetama ;27_V	et	f	\N
147829	talumatu	talumatu =talumatu  (SgN  >talumatu !01_A	et	f	\N
147830	talumatu	"talumatu %talu  )MATU_vA  <taluma ;27_V	et	f	\N
147831	talumatu	talumatu =talumatu  (SgG  >talumatu !01_A	et	f	\N
147841	tähendusrikasaline	?tähendusrikasaline =tähendusrikasaline  (SgN  >tähendusrikasaline !12_A	et	f	\N
147842	tähendusrikasaline	?tähendusrikasaline =tähendusrikasaline  (PlP  >tähendusrikasalin !19_S	et	f	\N
147843	tähendusrikasaline	?tähendusrikasaline =rikasaline  (SgN  >tähendus+rikasaline !12_A	et	f	\N
147844	tähendusrikasaline	?tähendusrikasaline =rikasaline  (PlP  >tähendus+rikasalin !19_S	et	f	\N
147852	buchana	?buchana =bucha  (SgEs  >bucha !16_S	et	f	\N
147866	kulukas	kulukas =kuluka  (SgIn  >kulukas !02_A	et	f	\N
147867	kulukas	kulukas =kulukas  (SgN  >kulukas !02_A	et	f	\N
147890	fitch	?fitch =fitch  (SgN  >fitch !22_S	et	f	\N
147891	riietatud	riietatud =riieta  (PtsPtIps  >riietama !27_V	et	f	\N
147892	riietatud	riietatud =riietatu  (PlN  >riietatu !01_S	et	f	\N
147893	riietatud	"riietatu %riieta  )TU1_vS  <riietama ;27_V	et	f	\N
147438	talvena	talvena =talve  (SgEs  >tali !24_S	et	f	\N
147444	moosi	moosi =moosi  (SgG  >moos !22_S	et	f	\N
147445	moosi	moosi =moosi  (SgP  >moos !22_S	et	f	\N
147446	moosi	moosi =moosi  (SgAdt  >moos !22_S	et	f	\N
147450	riisi	riisi =riisi  (SgG  >riis !22_S	et	f	\N
147453	riisi	riisi =riisi  (SgP  >riis !22_S	et	f	\N
147454	riisi	riisi =riisi  (SgAdt  >riis !22_S	et	f	\N
147466	nauti	?nauti =nauti  (ID  >nauti !41_D	et	f	\N
147467	nauti	?nauti =nauti  (SgP  >naut !22_S	et	f	\N
147468	nauti	?nauti =nauti  (SgAdt  >naut !22_S	et	f	\N
147481	pärastlõuna	pärastlõuna =lõuna  (SgN  >pärast+lõuna !06_S	et	f	\N
147482	pärastlõuna	pärastlõuna =lõuna  (SgG  >pärast+lõuna !06_S	et	f	\N
147493	nelijapäeval	?nelijapäeval =nelijapäeva  (SgAd  >nelijapäeva !16_S	et	f	\N
147494	nelijapäeval	?nelijapäeval =nelijapäeval  (SgN  >nelijapäeval !02_S	et	f	\N
147495	nelijapäeval	?nelijapäeval =japäeva  (SgAd  >neli+japäeva !01_S	et	f	\N
147508	maksuma	?maksuma =maksu  (Sup  >maksuma !28_V	et	f	\N
147529	probleemuid	probleemuid =ui  (PlN  >probleem+ui !26_S	et	f	\N
147530	probleemuid	probleemuid =ui  (SgP  >probleem+ui !26_S	et	f	\N
147532	probleemuid	probleemuid =uid  (SgN  >probleem+uid !22_S	et	f	\N
147534	rangers	?rangers =rangers  (SgN  >rangers !02_S	et	f	\N
147535	rangers	?rangers =ers  (SgN  >rang+ers !22_S	et	f	\N
147536	sügiset	### sügiset	et	f	\N
147542	lehi	lehi =lehi  (IndPrPs_  >lehtima !28_V	et	f	\N
147543	lehi	lehi =lehi  (ImpPrSg2  >lehtima !28_V	et	f	\N
147547	pue	?pue =pue  (SgN  >pue !26_S	et	f	\N
147548	pue	?pue =pue  (SgG  >pue !26_S	et	f	\N
147562	tomatkaste	?tomatkaste =tomatkas  (PlG  >tomatkane !12_A	et	f	\N
147563	soovima	soovima =soovi  (Sup  >soovima !28_V	et	f	\N
147564	soovima	soovima =ima  (SgN  >soov+ima !17_S	et	f	\N
147565	soovima	soovima =ima  (SgG  >soov+ima !17_S	et	f	\N
147566	soovima	soovima =ima  (SgP  >soov+ima !17_S	et	f	\N
147573	iiri	?iiri =iiri  (SgN  >iiri !16_S	et	f	\N
147574	iiri	?iiri =iiri  (SgG  >iiri !16_S	et	f	\N
147575	iiri	?iiri =iiri  (SgG  >iir !22_S	et	f	\N
147576	iiri	?iiri =iiri  (SgP  >iir !22_S	et	f	\N
147577	iiri	?iiri =iiri  (SgAdt  >iir !22_S	et	f	\N
147578	iiri	?iiri =iiri  (IndPrPs_  >iirima !28_V	et	f	\N
147579	iiri	?iiri =iiri  (ImpPrSg2  >iirima !28_V	et	f	\N
147586	bbc	### bbc	et	f	\N
147587	häälis	häälis =hääli  (PlIn  >hääl !13_S	et	f	\N
147588	häälis	häälis =hääli  (IndIpfSg3  >häälima !28_V	et	f	\N
147591	helen	?helen =hele  (IndPrSg1  >helema !27_V	et	f	\N
147592	helen	?helen =helen  (SgN  >helen !02_S	et	f	\N
147600	autojuhtaga	?autojuhtaga =autojuhta  (SgKom  >autojuhta !16_S	et	f	\N
147601	autojuhtaga	?autojuhtaga =juhta  (SgKom  >auto+juhta !16_S	et	f	\N
147602	autojuhtaga	?autojuhtaga =tojuhta  (SgKom  >au+tojuhta !01_S	et	f	\N
147616	armistan	?armistan =armista  (IndPrSg1  >armistama !27_V	et	f	\N
147617	armistan	?armistan =armistan  (SgN  >armistan !19_S	et	f	\N
147627	city	### city	et	f	\N
147628	armistead	?armistead =armistea  (PlN  >armistea !26_S	et	f	\N
147629	armistead	?armistead =armistea  (SgP  >armistea !26_S	et	f	\N
147630	armistead	?armistead =armistead  (SgN  >armistead !22_S	et	f	\N
147631	maupini	?maupini =maupini  (SgG  >maupin !02_S	et	f	\N
147647	millelgi	millelgi =mille  (SgAd  >miski !00_P	et	f	\N
147648	millelgi	millelgi =mille  (SgAd^  >mis !00_P	et	f	\N
147664	soovitama	soovitama =soovi  (SupIps  >soovima !28_V	et	f	\N
147665	soovitama	soovitama =soovita  (Sup  >soovitama !27_V	et	f	\N
147671	tallakse	?tallakse =tallakse  (SgG  >tallakne !02_A	et	f	\N
147672	sõidedakse	?sõidedakse =sõidedakse  (SgG  >sõidedakne !02_A	et	f	\N
147673	ben	### ben	et	f	\N
147679	vali	vali =vali  (SgN  >vali !24_A	et	f	\N
147681	vali	vali =vali  (IndPrPs_  >valima !27_V	et	f	\N
147682	vali	vali =vali  (ImpPrSg2  >valima !27_V	et	f	\N
147719	ühiselt	ühiselt =ühise  (SgAbl  >ühine !10_A	et	f	\N
147721	ühiselt	ühiselt =ühiselt  (ID  >ühiselt !41_D	et	f	\N
147722	ühiselt	"ühiselt %ühise  )LT_mD  <ühine ;10_A	et	f	\N
147725	kohtutakse	kohtutakse =kohtu  (IndPrIps  >kohtuma !27_V	et	f	\N
147726	kohtutakse	kohtutakse =takse  (PlP  >kohtu+taks !22_S	et	f	\N
147729	sõprusadkse	?sõprusadkse =sõprusadkse  (SgG  >sõprusadkne !02_A	et	f	\N
147730	sõprusadkse	?sõprusadkse =adkse  (SgN  >sõprus+adkse !06_S	et	f	\N
147731	sõprusadkse	?sõprusadkse =adkse  (SgG  >sõprus+adkne !02_A	et	f	\N
147732	sõprusadkse	?sõprusadkse =adkse  (SgG  >sõprus+adkse !06_S	et	f	\N
147733	sõprusadkse	?sõprusadkse =adkse  (PlP  >sõprus+adks !22_S	et	f	\N
147741	partitative	### partitative	et	f	\N
147749	eurolaul	eurolaul =lau  (SgAd  >euro+laug !22_SA	et	f	\N
147750	eurolaul	eurolaul =laul  (SgN  >euro+laul !22_S	et	f	\N
147755	eestlaneid	?eestlaneid =eestlane  (PlP  >eestlan !02_S	et	f	\N
147756	eestlaneid	?eestlaneid =eestlanei  (PlN  >eestlanei !26_S	et	f	\N
147757	eestlaneid	?eestlaneid =eestlanei  (SgP  >eestlanei !26_S	et	f	\N
147759	eestlaneid	?eestlaneid =lanei  (PlN  >eest+lanei !26_S	et	f	\N
147760	eestlaneid	?eestlaneid =lanei  (SgP  >eest+lanei !26_S	et	f	\N
147498	dundeesse	?dundeesse =dundeesse  (SgG  >dundeesne !02_A	et	f	\N
147499	dundeesse	?dundeesse =dundeesse  (PlP  >dundeess !22_S	et	f	\N
147501	dundee	?dundee =dundee  (SgN  >dundee !26_S	et	f	\N
147502	dundee	?dundee =dundee  (SgG  >dundee !26_S	et	f	\N
147531	glasgowks	?glasgowks =glasgowks  (SgN  >glasgowks !02_S	et	f	\N
147533	celtic	### celtic	et	f	\N
147539	sajaks	sajaks =saja  (SgTr  >sajas !02_O	et	f	\N
147540	sajaks	sajaks =saja  (SgTr  >sada !18_N	et	f	\N
147541	sajaks	sajaks =saja  (KndPrPs  >sadama !28_V	et	f	\N
147544	vähenevad	vähenevad =vähene  (IndPrPl3  >vähenema !27_V	et	f	\N
147545	vähenevad	vähenevad =väheneva  (PlN  >vähenev !02_A	et	f	\N
147546	vähenevad	"vähenev %vähene  )V_vA  <vähenema ;27_V	et	f	\N
147549	vingelt	vingelt =vinge  (SgAbl  >vinge !01_A	et	f	\N
147550	vingelt	vingelt =vinge  (PlAbl  >ving !22_S	et	f	\N
147551	vingelt	vingelt =vingelt  (ID  >vingelt !41_D	et	f	\N
147552	vingelt	"vingelt %vinge  )LT_mD  <vinge ;01_A	et	f	\N
147553	kaksikvõieib	?kaksikvõieib =kaksikvõieib  (SgN  >kaksikvõieib !22_S	et	f	\N
147554	kaksikvõieib	?kaksikvõieib =eib  (SgN  >kaksik+või+eib !22_S	et	f	\N
147555	kaksikvõieib	?kaksikvõieib =võieib  (SgN  >kaksik+võieib !02_S	et	f	\N
147556	kaksikvõieib	?kaksikvõieib =ikvõieib  (SgN  >kaks+ikvõieib !22_S	et	f	\N
147557	praadib	?praadib =praadi  (IndPrSg3  >praatima !28_V	et	f	\N
147558	grillima	grillima =grilli  (Sup  >grillima !28_V	et	f	\N
147559	grillima	grillima =ima  (SgN  >grill+ima !17_S	et	f	\N
147560	grillima	grillima =ima  (SgG  >grill+ima !17_S	et	f	\N
147561	grillima	grillima =ima  (SgP  >grill+ima !17_S	et	f	\N
147595	igivana	igivana =vana  (SgN  >igi+vana !17_AS	et	f	\N
147596	igivana	igivana =vana  (SgG  >igi+vana !17_AS	et	f	\N
147597	igivana	igivana =vana  (SgP  >igi+vana !17_AS	et	f	\N
147614	nagemist	?nagemist =nagemi  (SgEl  >nagemi !01_S	et	f	\N
147615	nagemist	?nagemist =nagemi  (SgEl  >nagem !02_A	et	f	\N
147618	nagemist	?nagemist =nagemis  (SgP  >nagemis !11_S	et	f	\N
147619	nagemist	?nagemist =nagemis  (SgP  >nagemine !12_S	et	f	\N
147620	nagemist	?nagemist =nagemist  (SgN  >nagemist !22_S	et	f	\N
147642	california	?california =california  (SgN  >california !01_S	et	f	\N
147643	california	?california =california  (SgG  >california !01_S	et	f	\N
147652	paljusse	paljusse =palju  (SgIll  >palju !16_P	et	f	\N
147653	paljusse	paljusse =paljus  (SgAdt  >paljus !11_S	et	f	\N
147654	paljusse	"paljus %palja  )US_aS  <paljas ;07_A	et	f	\N
147666	legema	?legema =lege  (Sup  >legema !27_V	et	f	\N
147667	legema	?legema =legema  (SgG  >legem !02_A	et	f	\N
147688	sooda	sooda =sooda  (SgN  >sooda !16_S	et	f	\N
147689	sooda	sooda =sooda  (SgG  >sooda !16_S	et	f	\N
147692	kelvingrovesse	?kelvingrovesse =kelvingroves  (SgAdt  >kelvingrovene !12_A	et	f	\N
147693	kelvingrovesse	?kelvingrovesse =kelvingrovesse  (SgG  >kelvingrovesne !02_A	et	f	\N
147694	kelvingrovesse	?kelvingrovesse =kelvingrovesse  (PlP  >kelvingrovess !22_S	et	f	\N
147697	ameerikasse	?ameerikasse =ameerika  (SgIll  >ameerikas !02_A	et	f	\N
147698	ameerikasse	?ameerikasse =ameerikas  (SgAdt  >ameerikane !12_A	et	f	\N
147699	ameerikasse	?ameerikasse =ameerikasse  (SgG  >ameerikasne !02_A	et	f	\N
147700	ameerikasse	?ameerikasse =ameerikasse  (PlP  >ameerikass !22_S	et	f	\N
147707	yorksse	?yorksse =yorksse  (SgN  >yorksse !06_S	et	f	\N
147708	yorksse	?yorksse =yorksse  (SgG  >yorksne !02_A	et	f	\N
147709	yorksse	?yorksse =yorksse  (SgG  >yorksse !06_S	et	f	\N
147710	yorksse	?yorksse =yorksse  (PlP  >yorkss !22_S	et	f	\N
147711	yorksse	?yorksse =yorksse  (IndPrPs_  >yorkssema !27_V	et	f	\N
147712	yorksse	?yorksse =yorksse  (ImpPrSg2  >yorkssema !27_V	et	f	\N
147716	celine	?celine =celine  (SgN  >celine !10_A	et	f	\N
147718	celine	?celine =celine  (IndPrPs_  >celinema !27_V	et	f	\N
147720	celine	?celine =celine  (ImpPrSg2  >celinema !27_V	et	f	\N
147723	keskpärane	keskpärane =pärane  (SgN  >kesk+pärane !10_A	et	f	\N
147724	keskpärane	"kesk+pärane %pära  )NE_aA  <kesk+pära ;17_S	et	f	\N
147740	plural	?plural =plura  (SgAd  >plura !17_S	et	f	\N
147742	plural	?plural =plural  (SgN  >plural !02_S	et	f	\N
147751	lemmikuid	lemmikuid =lemmiku  (PlP  >lemmik !02_S	et	f	\N
147752	lemmikuid	lemmikuid =ui  (PlN  >lemmik+ui !26_S	et	f	\N
147753	lemmikuid	lemmikuid =ui  (SgP  >lemmik+ui !26_S	et	f	\N
147754	lemmikuid	lemmikuid =uid  (SgN  >lemmik+uid !22_S	et	f	\N
147769	maid	maid =ma  (PlP  >maa !26_S	et	f	\N
147771	maid	maid =mai  (PlN  >mai !26_S	et	f	\N
147772	maid	maid =mai  (SgP  >mai !26_S	et	f	\N
147797	koige	?koige =koige  (SgN  >koige !06_S	et	f	\N
147798	koige	?koige =koige  (PlP  >koig !22_S	et	f	\N
147799	koige	?koige =koige  (IndPrPs_  >koigema !27_V	et	f	\N
147800	koige	?koige =koige  (ImpPrSg2  >koigema !27_V	et	f	\N
147804	lõppema	lõppema =lõppe  (Sup  >lõppema !27~28_V	et	f	\N
147805	lõppema	lõppema =ema  (SgN  >lõpp+ema !17_S	et	f	\N
147806	lõppema	lõppema =ema  (SgG  >lõpp+ema !17_S	et	f	\N
147807	lõppema	lõppema =ema  (SgP  >lõpp+ema !17_S	et	f	\N
147827	pimedus	pimedus =pimedus  (SgN  >pimedus !11_S	et	f	\N
147828	pimedus	"pimedus %pimeda  )US_aS  <pime ;02_AS	et	f	\N
147625	tales	?tales =tale  (IndIpfSg3  >talema !27_V	et	f	\N
147626	tales	?tales =tales  (SgN  >tales !09_S	et	f	\N
147636	maupin	?maupin =maupin  (SgN  >maupin !02_S	et	f	\N
147637	keelepeksi	keelepeksi =peksi  (SgG  >keele+peks !22_S	et	f	\N
147638	keelepeksi	keelepeksi =peksi  (SgP  >keele+peks !22_S	et	f	\N
147639	keelepeksi	keelepeksi =peksi  (SgAdt  >keele+peks !22_S	et	f	\N
147640	keelepeksi	keelepeksi =peksi  (PlP  >keele+peks !22_S	et	f	\N
147641	franciscos	?franciscos =francisco  (SgIn  >francisco !16_S	et	f	\N
147649	inemesee	?inemesee =inemesee  (SgN  >inemesee !26_S	et	f	\N
147650	inemesee	?inemesee =inemesee  (SgG  >inemesee !26_S	et	f	\N
147655	menukas	menukas =menuka  (SgIn  >menukas !02_A	et	f	\N
147656	menukas	menukas =menukas  (SgN  >menukas !02_A	et	f	\N
147659	style	?style =style  (SgN  >style !16_S	et	f	\N
147661	style	?style =style  (SgG  >style !16_S	et	f	\N
147662	style	?style =style  (IndPrPs_  >stylema !27_V	et	f	\N
147663	style	?style =style  (ImpPrSg2  >stylema !27_V	et	f	\N
147677	kuningriikt	?kuningriikt =kuningriikt  (SgN  >kuningriikt !22_S	et	f	\N
147678	kuningriikt	?kuningriikt =riikt  (SgN  >kuning+riikt !22_S	et	f	\N
147680	parkist	?parkist =parkist  (SgN  >parkist !22_S	et	f	\N
147683	tantsimakse	?tantsimakse =tantsimakse  (SgG  >tantsimakne !02_A	et	f	\N
147687	õnnetuseks	õnnetuseks =õnnetuse  (SgTr  >õnnetus !11_S	et	f	\N
147690	õnnetuseks	"õnnetus %õnne  )TUS2_aS  <õnn ;22_S	et	f	\N
147691	ujukakse	?ujukakse =ujukakse  (SgG  >ujukakne !02_A	et	f	\N
147717	dion	?dion =dion  (SgN  >dion !22_S	et	f	\N
147727	perekondakse	?perekondakse =perekondakse  (SgG  >perekondakne !02_A	et	f	\N
147728	perekondakse	?perekondakse =kondakse  (SgG  >pere+kondakne !02_A	et	f	\N
147738	sunnitöö	sunnitöö =töö  (SgN  >sunni+töö !26_S	et	f	\N
147739	sunnitöö	sunnitöö =töö  (SgG  >sunni+töö !26_S	et	f	\N
147781	armasaid	?armasaid =armasa  (PlP  >armasa !01_S	et	f	\N
147782	armasaid	?armasaid =armasai  (PlN  >armasai !26_S	et	f	\N
147783	armasaid	?armasaid =armasai  (SgP  >armasai !26_S	et	f	\N
147784	räpaneid	?räpaneid =räpane  (PlP  >räpan !02_S	et	f	\N
147785	räpaneid	?räpaneid =räpanei  (PlN  >räpanei !26_S	et	f	\N
147786	räpaneid	?räpaneid =räpanei  (SgP  >räpanei !26_S	et	f	\N
147787	sõbrannaid	?sõbrannaid =sõbrannai  (PlN  >sõbrannai !26_S	et	f	\N
147788	sõbrannaid	?sõbrannaid =sõbrannai  (SgP  >sõbrannai !26_S	et	f	\N
147789	tanavad	?tanavad =tana  (IndPrPl3  >tanama !27_V	et	f	\N
147790	tanavad	?tanavad =tanava  (PlN  >tanava !01_S	et	f	\N
147791	tanavad	?tanavad =tanava  (PlN  >tanav !02_A	et	f	\N
147792	pensionäri	pensionäri =pensionäri  (SgG  >pensionär !19_S	et	f	\N
147793	pensionäri	pensionäri =pensionäri  (SgP  >pensionär !19_S	et	f	\N
147795	pensionäri	pensionäri =pensionäri  (SgAdt  >pensionär !19_S	et	f	\N
147801	paljurassiline	paljurassiline =rassiline  (SgN  >palju+rassiline !12_A	et	f	\N
147802	paljurassiline	"palju+rassiline %rassi  )LINE_aA  <palju+rass ;22_S	et	f	\N
147803	poolased	?poolased =poolase  (PlN  >poolane !12?10_S	et	f	\N
147815	mõõdukas	mõõdukas =mõõduka  (SgIn  >mõõdukas !02_A	et	f	\N
147816	mõõdukas	mõõdukas =mõõdukas  (SgN  >mõõdukas !02_A	et	f	\N
147817	paike	paike =paike  (SgN  >paike !12?10_AS	et	f	\N
147818	paike	"paike %pai  )KE_dA  <pai ;26_AS	et	f	\N
147820	paike	paike =paike  (PlP  >paik !22_S	et	f	\N
147845	vihaga	vihaga =viha  (SgKom  >viha !17_SA	et	f	\N
147846	vihaga	vihaga =viha  (SgKom  >viht !22_S	et	f	\N
147854	topman	?topman =topma  (IndPrSg1  >topmama !29_V	et	f	\N
147855	topman	?topman =topman  (SgN  >topman !02_S	et	f	\N
147868	heakvaliteediline	heakvaliteediline =kvaliteediline  (SgN  >hea+kvaliteediline !12_A	et	f	\N
147869	heakvaliteediline	"hea+kvaliteediline %kvaliteedi  )LINE_aA  <hea+kvaliteet ;22_S	et	f	\N
147870	kuubi	kuubi =kuubi  (SgG  >kuup !22_S	et	f	\N
147871	kuubi	kuubi =kuubi  (SgP  >kuub !22_S	et	f	\N
147872	kuubi	kuubi =kuubi  (SgAdt  >kuub !22_S	et	f	\N
147873	kuubi	kuubi =kuubi  (PlP  >kuub !22_S	et	f	\N
147874	kuubi	kuubi =kuubi  (IndPrPs_  >kuupima !28_V	et	f	\N
147875	kuubi	kuubi =kuubi  (ImpPrSg2  >kuupima !28_V	et	f	\N
147876	riidedi	?riidedi =riidedi  (SgN  >riidedi !01_S	et	f	\N
147877	riidedi	?riidedi =riidedi  (SgG  >riidedi !01_S	et	f	\N
147899	viin	viin =vii  (IndPrSg1  >viima !38_V	et	f	\N
147900	viin	viin =viin  (SgN  >viin !22_S	et	f	\N
147901	agar	agar =agar  (SgN  >agar !02_S	et	f	\N
147902	agar	agar =agar  (SgN  >agar !02_A	et	f	\N
147912	samuel	?samuel =samue  (SgAd  >samue !01_S	et	f	\N
147913	samuel	?samuel =samuel  (SgN  >samuel !19_S	et	f	\N
147923	habemeajamisvesi	habemeajamisvesi =vesi  (SgN  >habeme+aja+mis+vesi !15_S	et	f	\N
147924	habemeajamisvesi	habemeajamisvesi =vesi  (PlP  >habeme+aja+mis+vesi !15_S	et	f	\N
147930	homework	?homework =homework  (SgN  >homework !22_S	et	f	\N
147952	tantsimasin	?tantsimasin =tantsimasin  (SgN  >tantsimasin !19_S	et	f	\N
147960	tiiu	?tiiu =tiiu  (SgN  >tiiu !16_S	et	f	\N
147961	tiiu	?tiiu =tiiu  (SgG  >tiiu !16_S	et	f	\N
147962	tiiu	?tiiu =tiiu  (IndPrPs_  >tiiuma !27_V	et	f	\N
147965	tiiu	?tiiu =tiiu  (ImpPrSg2  >tiiuma !27_V	et	f	\N
147701	franciscosse	?franciscosse =francisco  (SgIll  >francisco !16_S	et	f	\N
147702	franciscosse	?franciscosse =franciscosse  (SgG  >franciscosne !02_A	et	f	\N
147703	franciscosse	?franciscosse =franciscosse  (PlP  >franciscoss !22_S	et	f	\N
147704	vegasse	?vegasse =vega  (SgIll  >vega !17_S	et	f	\N
147705	vegasse	?vegasse =vegasse  (SgG  >vegasne !02_A	et	f	\N
147706	vegasse	?vegasse =vegasse  (PlP  >vegass !22_S	et	f	\N
147758	sõbered	### sõbered	et	f	\N
147762	käratsevid	käratsevid =käratsevi  (PlN  >käratsev !02_A	et	f	\N
147763	käratsevid	"käratsev %käratse  )V_vA  <käratsema ;27_V	et	f	\N
147774	ajaluguid	?ajaluguid =ajalugui  (PlN  >ajalugui !26_S	et	f	\N
147775	ajaluguid	?ajaluguid =ajalugui  (SgP  >ajalugui !26_S	et	f	\N
147776	ajaluguid	?ajaluguid =lugui  (PlN  >aja+lugui !26_S	et	f	\N
147777	ajaluguid	?ajaluguid =lugui  (SgP  >aja+lugui !26_S	et	f	\N
147778	ajaluguid	?ajaluguid =luguid  (SgN  >aja+luguid !22_S	et	f	\N
147794	tänavelt	?tänavelt =tänavelt  (ID  >tänavelt !41_D	et	f	\N
147796	tänavelt	?tänavelt =velt  (SgN  >täna+velt !22_S	et	f	\N
147819	paista	paista =paist  (Inf  >paistma !34_V	et	f	\N
147821	paista	paista =paista  (IndPrPs_  >paistma !34_V	et	f	\N
147822	paista	paista =paista  (ImpPrSg2  >paistma !34_V	et	f	\N
147856	zara	?zara =zara  (SgN  >zara !17_S	et	f	\N
147857	zara	?zara =zara  (SgG  >zara !17_S	et	f	\N
147858	zara	?zara =zara  (SgP  >zara !17_S	et	f	\N
147859	zara	?zara =zara  (IndPrPs_  >zarama !27_V	et	f	\N
147860	zara	?zara =zara  (ImpPrSg2  >zarama !27_V	et	f	\N
147903	golfimängija	golfimängija =mängija  (SgN  >golfi+mängija !01_S	et	f	\N
147904	golfimängija	golfimängija =mängija  (SgG  >golfi+mängija !01_S	et	f	\N
147905	kompakt-plaati	kompakt-plaati =plaati  (SgP  >kompakt-plaat !22_S	et	f	\N
147907	kompakt-plaati	kompakt-plaati =plaati  (SgAdt  >kompakt-plaat !22_S	et	f	\N
147914	minussa	?minussa =minussa  (SgN  >minussa !01_S	et	f	\N
147915	minussa	?minussa =minussa  (SgG  >minussa !01_S	et	f	\N
147921	beebi	beebi =beebi  (SgN  >beebi !16_S	et	f	\N
147922	beebi	beebi =beebi  (SgG  >beebi !16_S	et	f	\N
147925	auhindi	auhindi =hindi  (SgP  >au+hind !22_S	et	f	\N
147926	auhindi	auhindi =hindi  (SgAdt  >au+hind !22_S	et	f	\N
147941	viivitamasin	?viivitamasin =viivitamasin  (SgN  >viivitamasin !19_S	et	f	\N
147944	paev	?paev =paev  (SgN  >paev !22_S	et	f	\N
147947	vanemle	?vanemle =vanemle  (PlP  >vaneml !22_S	et	f	\N
147948	vanemle	?vanemle =vanemle  (IndPrPs_  >vanemlema !27_V	et	f	\N
147949	vanemle	?vanemle =vanemle  (ImpPrSg2  >vanemlema !27_V	et	f	\N
148007	vigastatud	vigastatud =vigasta  (PtsPtIps  >vigastama !27_V	et	f	\N
148008	vigastatud	vigastatud =vigastatu  (PlN  >vigastatu !01_S	et	f	\N
148009	vigastatud	"vigastatu %vigasta  )TU1_vS  <vigastama ;27_V	et	f	\N
148010	vigastatud	vigastatud =vigastatud  (ID  >vigastatud !41_A	et	f	\N
148011	vigastatud	"vigastatud %vigasta  )TUD_vA  <vigastama ;27_V	et	f	\N
148048	meilis	meilis =meili  (SgIn  >meil !22_S	et	f	\N
148049	meilis	meilis =meili  (IndIpfSg3  >meilima !28_V	et	f	\N
148055	suremine	suremine =suremine  (SgN  >suremine !12_S	et	f	\N
148056	suremine	"suremine %sure  )MINE_vS  <surema ;36_V	et	f	\N
148060	dialektiline	dialektiline =dialektiline  (SgN  >dialektiline !12_A	et	f	\N
148061	dialektiline	"dialektiline %dialekti  )LINE_aA  <dialekt ;22_S	et	f	\N
148068	sisadama	?sisadama =sisadama  (SgG  >sisadam !02_A	et	f	\N
148076	saavutus	saavutus =saavutus  (SgN  >saavutus !11_S	et	f	\N
148077	saavutus	"saavutus %saavuta  )US_vS  <saavutama ;27_V	et	f	\N
148084	elustus	elustus =elustu  (IndIpfSg3  >elustuma !27_V	et	f	\N
148085	elustus	elustus =elustus  (SgN  >elustus !11_S	et	f	\N
148086	elustus	"elustus %elusta  )US_vS  <elustama ;27_V	et	f	\N
148087	turkus	?turkus =turku  (SgIn  >turku !16_S	et	f	\N
148088	turkus	?turkus =turku  (IndIpfSg3  >turkuma !27_V	et	f	\N
148089	turkus	?turkus =turkus  (SgN  >turkus !11~09_S	et	f	\N
148093	puhtus	puhtus =puhtu  (IndIpfSg3  >puhtuma !27_V	et	f	\N
148094	puhtus	puhtus =puhtus  (SgN  >puhtus !11~09_S	et	f	\N
148095	puhtus	"puhtus %puhta  )US_aS  <puhas ;07_A	et	f	\N
148108	karri	karri =karri  (SgG  >karr !22_S	et	f	\N
148109	karri	karri =karri  (SgP  >karr !22_S	et	f	\N
148110	karri	karri =karri  (SgAdt  >karr !22_S	et	f	\N
148115	week	?week =week  (SgN  >week !22_S	et	f	\N
148134	luisa	?luisa =luisa  (SgN  >luisa !16_S	et	f	\N
148135	luisa	?luisa =luisa  (SgG  >luisa !16_S	et	f	\N
148136	luisa	?luisa =luisa  (IndPrPs_  >luisama !29_V	et	f	\N
148137	luisa	?luisa =luisa  (ImpPrSg2  >luisama !29_V	et	f	\N
148158	kolmapäeva	kolmapäeva =päeva  (SgG  >kolma+päev !22_S	et	f	\N
148159	kolmapäeva	kolmapäeva =päeva  (SgP  >kolma+päev !22_S	et	f	\N
148160	kolmapäeva	kolmapäeva =päeva  (SgAdt  >kolma+päev !22_S	et	f	\N
148170	vrait	?vrait =vrait  (SgN  >vrait !22_S	et	f	\N
148175	yorki	?yorki =yorki  (ID  >yorki !41_D	et	f	\N
148176	yorki	?yorki =yorki  (SgP  >york !22_S	et	f	\N
148177	yorki	?yorki =yorki  (SgAdt  >york !22_S	et	f	\N
148180	amsterdami	?amsterdami =amsterdami  (SgG  >amsterdam !02_A	et	f	\N
148181	yorkis	?yorkis =yorki  (IndIpfSg3  >yorkima !28_V	et	f	\N
147761	eestlaneid	?eestlaneid =laneid  (SgN  >eest+laneid !22_S	et	f	\N
147764	kaunimaid	kaunimaid =kaunima  (PlP  >kaunim !02_A	et	f	\N
147765	kaunimaid	"kaunim %kauni  )M_cA  <kaunis ;05_A	et	f	\N
147766	kaunimaid	"kaunim %kauni  )M_cA  <kaunis ;07_A	et	f	\N
147767	kaunimaid	kaunimaid =ma  (PlP  >kauni+maa !26_S	et	f	\N
147768	kaunimaid	kaunimaid =mai  (PlN  >kauni+mai !26_S	et	f	\N
147770	kaunimaid	kaunimaid =mai  (SgP  >kauni+mai !26_S	et	f	\N
147810	püsivalt	püsivalt =püsiva  (SgAbl  >püsiv !02_A	et	f	\N
147811	püsivalt	"püsiv %püsi  )V_vA  <püsima ;27_V	et	f	\N
147812	püsivalt	püsivalt =püsivalt  (ID  >püsivalt !41_D	et	f	\N
147813	püsivalt	"püsivalt %püsi  )VALT_mD  <püsima ;27_V	et	f	\N
147814	püsivalt	"püsivalt %püsiva  )LT_mD  <püsiv ;02_A	et	f	\N
147823	talvet	?talvet =talve  (SgP  >talve !06_S	et	f	\N
147824	rõhuv	rõhuv =rõhu  (PtsPrPs  >rõhuma !27_V	et	f	\N
147825	rõhuv	rõhuv =rõhuv  (SgN  >rõhuv !02_A	et	f	\N
147826	rõhuv	"rõhuv %rõhu  )V_vA  <rõhuma ;27_V	et	f	\N
147847	asetsev	asetsev =asetse  (PtsPrPs  >asetsema !27_V	et	f	\N
147848	asetsev	asetsev =asetsev  (SgN  >asetsev !02_A	et	f	\N
147849	asetsev	"asetsev %asetse  )V_vA  <asetsema ;27_V	et	f	\N
147881	kandmiseks	kandmiseks =kandmise  (SgTr  >kandmine !12?10_SA	et	f	\N
147882	kandmiseks	"kandmine %kand  )MINE_vS  <kandma ;34_V	et	f	\N
147896	interneril	?interneril =interneri  (SgAd  >interner !02_S	et	f	\N
147897	interneril	?interneril =neri  (SgAd  >inter+neri !17_S	et	f	\N
147908	divo	?divo =divo  (SgN  >divo !17~16_S	et	f	\N
147909	divo	?divo =divo  (SgG  >divo !17~16_S	et	f	\N
147910	divo	?divo =divo  (SgP  >divo !17_S	et	f	\N
147916	kumbki	kumbki =kumb  (SgN  >kumbki !00_P	et	f	\N
147917	kumbki	kumbki =kumb  (SgN^  >kumb !22_P	et	f	\N
147918	komplekti	komplekti =komplekti  (SgG  >komplekt !22_S	et	f	\N
147919	komplekti	komplekti =komplekti  (SgP  >komplekt !22_S	et	f	\N
147920	komplekti	komplekti =komplekti  (SgAdt  >komplekt !22_S	et	f	\N
147928	krediitkaart	krediitkaart =kaar  (SgP  >krediit+kaar !13_S	et	f	\N
147929	krediitkaart	krediitkaart =kaart  (SgN  >krediit+kaart !22_S	et	f	\N
147931	külasin	?külasin =küla  (IndIpfSg1  >külama !27_V	et	f	\N
147932	külasin	?külasin =külasin  (SgN  >külasin !19_S	et	f	\N
147942	joulud	?joulud =joulu  (PlN  >joulu !16_S	et	f	\N
147943	joulud	?joulud =joulu  (IndPrSg2  >jouluma !28_V	et	f	\N
147945	reismasin	?reismasin =reisma  (IndIpfSg1  >reismama !29_V	et	f	\N
147946	reismasin	?reismasin =reismasin  (SgN  >reismasin !19_S	et	f	\N
147953	kaalus	kaalus =kaalu  (SgIn  >kaal !22_S	et	f	\N
147954	kaalus	kaalus =kaalu  (IndIpfSg3  >kaaluma !28_V	et	f	\N
147970	kunstihoone	kunstihoone =hoone  (SgN  >kunsti+hoone !06_S	et	f	\N
147971	kunstihoone	"kunsti+hoone %hoo  )NE_aA  <kunsti+hoog ;22_S	et	f	\N
147972	kunstihoone	kunstihoone =hoone  (SgG  >kunsti+hoone !06_S	et	f	\N
147973	kunstihoone	kunstihoone =hoone  (PlP  >kunsti+hoon !22_A	et	f	\N
147981	kaarli	?kaarli =kaarli  (ID  >kaarli !41_D	et	f	\N
147982	kaarli	?kaarli =kaarli  (SgG  >kaarl !22_S	et	f	\N
147983	kaarli	?kaarli =kaarli  (SgP  >kaarl !22_S	et	f	\N
147984	kaarli	?kaarli =kaarli  (SgAdt  >kaarl !22_S	et	f	\N
147985	kaarli	?kaarli =kaarli  (IndPrPs_  >kaarlima !28_V	et	f	\N
147986	kaarli	?kaarli =kaarli  (ImpPrSg2  >kaarlima !28_V	et	f	\N
147987	faigi	?faigi =faigi  (SgN  >faigi !16_S	et	f	\N
147988	faigi	?faigi =faigi  (SgG  >faigi !16_S	et	f	\N
147989	faigi	?faigi =faigi  (SgG  >faik !22_S	et	f	\N
147990	faigi	?faigi =faigi  (SgP  >faig !22_S	et	f	\N
147991	faigi	?faigi =faigi  (SgAdt  >faig !22_S	et	f	\N
147992	faigi	?faigi =faigi  (IndPrPs_  >faikima !28_V	et	f	\N
147993	faigi	?faigi =faigi  (ImpPrSg2  >faikima !28_V	et	f	\N
147994	faigi	?faigi =fai  (SgN^  >fai !26_S	et	f	\N
147995	faigi	?faigi =fai  (SgG^  >fai !26_S	et	f	\N
147996	tonu	?tonu =tonu  (SgN  >tonu !17_S	et	f	\N
147997	tonu	?tonu =tonu  (SgG  >tonu !17_S	et	f	\N
147998	tonu	?tonu =tonu  (SgP  >tonu !17_S	et	f	\N
147999	tonu	?tonu =tonu  (IndPrPs_  >tonuma !27_V	et	f	\N
148000	tonu	?tonu =tonu  (ImpPrSg2  >tonuma !27_V	et	f	\N
148001	jultunud	jultunud =jultu  (PtsPtPs  >jultuma !27_V	et	f	\N
148002	jultunud	jultunud =jultunu  (PlN  >jultunu !01_S	et	f	\N
148003	jultunud	"jultunu %jultu  )NU_vS  <jultuma ;27_V	et	f	\N
148004	jultunud	jultunud =jultunud  (ID  >jultunud !41_A	et	f	\N
148005	jultunud	"jultunud %jultu  )NUD_vA  <jultuma ;27_V	et	f	\N
148016	kukepea	kukepea =pea  (SgN  >kuke+pea !26_S	et	f	\N
148017	kukepea	kukepea =pea  (SgG  >kuke+pea !26_S	et	f	\N
148020	nägemist	nägemist =nägemis  (SgP  >nägemine !12_S	et	f	\N
148021	nägemist	"nägemine %näge  )MINE_vS  <nägema ;28_V	et	f	\N
148022	nägemist	nägemist =nägemist  (ID  >nägemist !41_I	et	f	\N
148026	setumaa	setumaa =maa  (SgN  >setu+maa !26_S	et	f	\N
148027	setumaa	setumaa =maa  (SgG  >setu+maa !26_S	et	f	\N
148092	eelm	?eelm =eelm  (SgN  >eelm !22_S	et	f	\N
148106	ettekandja	ettekandja =kandja  (SgN  >ette+kandja !01_S	et	f	\N
148107	ettekandja	ettekandja =kandja  (SgG  >ette+kandja !01_S	et	f	\N
147832	niiske	niiske =niiske  (SgN  >niiske !01_A	et	f	\N
147833	niiske	niiske =niiske  (SgG  >niiske !01_A	et	f	\N
147834	niiske	niiske =niiske  (PlP  >niisk !22_S	et	f	\N
147835	paikesetõus	?paikesetõus =paikesetõu  (SgIn  >paikesetõu !26_S	et	f	\N
147836	paikesetõus	?paikesetõus =paikesetõus  (SgN  >paikesetõus !22_S	et	f	\N
147837	jäama	?jäama =jäama  (SgN  >jäama !16_S	et	f	\N
147838	jäama	?jäama =jäama  (SgG  >jäama !16_S	et	f	\N
147839	jäama	?jäama =jäama  (IndPrPs_  >jäamama !29_V	et	f	\N
147840	jäama	?jäama =jäama  (ImpPrSg2  >jäamama !29_V	et	f	\N
147850	teekonda	teekonda =teekonda  (SgP  >teekond !22_S	et	f	\N
147851	teekonda	teekonda =teekonda  (SgAdt  >teekond !22_S	et	f	\N
147853	kesk-glasgows	?kesk-glasgows =glasgows  (SgN  >kesk-glasgows !22_S	et	f	\N
147861	zara	?zara =zara  (SgN  >zara !17_S	et	f	\N
147862	zara	?zara =zara  (SgG  >zara !17_S	et	f	\N
147863	zara	?zara =zara  (SgP  >zara !17_S	et	f	\N
147864	zara	?zara =zara  (IndPrPs_  >zarama !27_V	et	f	\N
147865	zara	?zara =zara  (ImpPrSg2  >zarama !27_V	et	f	\N
147878	igapäevaseks	igapäevaseks =seks  (SgN  >iga+päeva+seks !22_S	et	f	\N
147879	igapäevaseks	igapäevaseks =päevase  (SgTr  >iga+päevane !10_A	et	f	\N
147880	igapäevaseks	"iga+päevane %päeva  )NE_aA  <iga+päev ;22_S	et	f	\N
147883	ainudainus	?ainudainus =ainudainu  (SgIn  >ainudainu !01_S	et	f	\N
147884	ainudainus	?ainudainus =ainudainu  (IndIpfSg3  >ainudainuma !27_V	et	f	\N
147885	ainudainus	?ainudainus =ainudainus  (SgN  >ainudainus !11~09_S	et	f	\N
147886	ainudainus	?ainudainus =dainu  (SgIn  >ainu+dainu !16_S	et	f	\N
147887	ainudainus	?ainudainus =dainus  (SgN  >ainu+dainus !11~09_S	et	f	\N
147888	abercrombie	?abercrombie =abercrombie  (SgN  >abercrombie !01_S	et	f	\N
147889	abercrombie	?abercrombie =abercrombie  (SgG  >abercrombie !01_S	et	f	\N
147906	fi	### fi	et	f	\N
147911	evelin	?evelin =evelin  (SgN  >evelin !19_S	et	f	\N
147927	mastercard	?mastercard =mastercard  (SgN  >mastercard !22_S	et	f	\N
147939	lennukaugus	lennukaugus =kaugus  (SgN  >lennu+kaugus !11~09_S	et	f	\N
147940	lennukaugus	"lennu+kaugus %kauge  )US_aS  <lennu+kauge ;01_A	et	f	\N
147950	puutume	puutume =puutu  (IndPrPl1  >puutuma !27_V	et	f	\N
147951	puutume	puutume =tume  (SgN  >puu+tume !02_A	et	f	\N
147959	sheet	?sheet =sheet  (SgN  >sheet !22_S	et	f	\N
147974	väljaku	väljaku =välja  (ImpPrPs  >väljama !29_V	et	f	\N
147975	väljaku	väljaku =väljaku  (SgG  >väljak !02_S	et	f	\N
147980	peep	?peep =peep  (SgN  >peep !22_S	et	f	\N
148012	sunnipaevkook	?sunnipaevkook =sunnipaevkook  (SgN  >sunnipaevkook !22_S	et	f	\N
148013	sunnipaevkook	?sunnipaevkook =paevkook  (SgN  >sunni+paevkook !22_S	et	f	\N
148051	elaniks	?elaniks =elani  (SgTr  >elan !02_S	et	f	\N
148066	elustusi	elustusi =elustusi  (PlP  >elustus !11_S	et	f	\N
148067	elustusi	"elustus %elusta  )US_vS  <elustama ;27_V	et	f	\N
148069	kaeba1987	kaeba =kaeba  (IndPrPs_  >kaebama !29_V	et	f	\N
148070	kaeba1987	kaeba =kaeba  (ImpPrSg2  >kaebama !29_V	et	f	\N
148073	still	?still =still  (SgN  >still !22_S	et	f	\N
148074	rugrats	?rugrats =rugrats  (SgN  >rugrats !02_S	et	f	\N
148078	rahvusvahelisest	rahvusvahelisest =vahelise  (SgEl  >rahvus+vaheline !12_A	et	f	\N
148079	rahvusvahelisest	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
148082	läbikäiminest	?läbikäiminest =läbikäimines  (SgP  >läbikäiminene !12_A	et	f	\N
148083	läbikäiminest	?läbikäiminest =käimines  (SgP  >läbi+käiminene !12_A	et	f	\N
148090	sisseehitatud	sisseehitatud =ehita  (PtsPtIps  >sisse+_ehitama !27_V	et	f	\N
148091	sisseehitatud	sisseehitatud =ehitatu  (PlN  >sisse+ehitatu !01_S	et	f	\N
148104	edinburghisse	?edinburghisse =edinburghisse  (SgG  >edinburghisne !02_A	et	f	\N
148105	edinburghisse	?edinburghisse =edinburghisse  (PlP  >edinburghiss !22_S	et	f	\N
148112	minutet	### minutet	et	f	\N
148138	luisa	?luisa =luisa  (SgN  >luisa !16_S	et	f	\N
148139	luisa	?luisa =luisa  (SgG  >luisa !16_S	et	f	\N
148140	luisa	?luisa =luisa  (IndPrPs_  >luisama !29_V	et	f	\N
148141	luisa	?luisa =luisa  (ImpPrSg2  >luisama !29_V	et	f	\N
148146	koolijuhataja	koolijuhataja =juhataja  (SgN  >kooli+juhataja !01_S	et	f	\N
148147	koolijuhataja	koolijuhataja =juhataja  (SgG  >kooli+juhataja !01_S	et	f	\N
148156	iraag	?iraag =iraag  (SgN  >iraag !22_S	et	f	\N
148161	neljapaeval	?neljapaeval =neljapaeva  (SgAd  >neljapaeva !16_S	et	f	\N
148162	neljapaeval	?neljapaeval =neljapaeval  (SgN  >neljapaeval !02_S	et	f	\N
148163	neljapaeval	?neljapaeval =paeva  (SgAd  >nelja+paeva !16_S	et	f	\N
148164	neljapaeval	?neljapaeval =paeval  (SgN  >nelja+paeval !02_S	et	f	\N
148171	kaima	kaima =kaima  (SgG  >kaim !22_S	et	f	\N
148172	kaima	kaima =kaima  (SgP  >kaim !22_S	et	f	\N
148173	kaima	kaima =kaima  (SgAdt  >kaim !22_S	et	f	\N
148201	lilianat	### lilianat	et	f	\N
148207	tegemasin	?tegemasin =tegemasin  (SgN  >tegemasin !19_S	et	f	\N
148210	tantsuõ	### tantsuõ	et	f	\N
148217	puiestee	puiestee =tee  (SgN  >puies+tee !26_S	et	f	\N
148218	puiestee	puiestee =tee  (SgG  >puies+tee !26_S	et	f	\N
148219	ostama	?ostama =osta  (Sup  >ostama !29_V	et	f	\N
148220	ostama	?ostama =ostama  (SgG  >ostam !02_A	et	f	\N
147894	riietatud	riietatud =riietatud  (ID  >riietatud !41_A	et	f	\N
147895	riietatud	"riietatud %riieta  )TUD_vA  <riietama ;27_V	et	f	\N
147898	amazoncouk	?amazoncouk =amazoncouk  (SgN  >amazoncouk !22_S	et	f	\N
147933	õemees	õemees =mee  (SgIn  >õe+mesi !15_S	et	f	\N
147934	õemees	õemees =mees  (SgN  >õe+mees !13_S	et	f	\N
147935	cardiffa	?cardiffa =cardiffa  (SgN  >cardiffa !01_S	et	f	\N
147936	cardiffa	?cardiffa =cardiffa  (SgG  >cardiffa !01_S	et	f	\N
147937	ilmastik	ilmastik =ilmastik  (SgN  >ilmastik !25_S	et	f	\N
147938	ilmastik	ilmastik =astik  (SgN  >ilm+astik !02_S	et	f	\N
147955	sugugi	sugugi =sugugi  (ID  >sugugi !41_D	et	f	\N
147956	sugugi	sugugi =sugu  (ID^  >sugu !41_DA	et	f	\N
147957	sugugi	sugugi =sugu  (SgN^  >sugu !18_S	et	f	\N
147958	sugugi	sugugi =sugu  (SgP^  >sugu !18_S	et	f	\N
147963	pargari	?pargari =pargari  (SgN  >pargari !01_S	et	f	\N
147964	pargari	?pargari =pargari  (SgG  >pargari !01_S	et	f	\N
147966	pargari	?pargari =pargari  (SgG  >pargar !02_S	et	f	\N
148018	pärastin	?pärastin =pärasti  (IndPrSg1  >pärastima !28_V	et	f	\N
148019	pärastin	?pärastin =pärastin  (SgN  >pärastin !19_S	et	f	\N
148050	reps	?reps =reps  (SgN  >reps !22_S	et	f	\N
148057	pindala	pindala =ala  (SgN  >pind+ala !17_S	et	f	\N
148058	pindala	pindala =ala  (SgG  >pind+ala !17_S	et	f	\N
148059	pindala	pindala =ala  (SgP  >pind+ala !17_S	et	f	\N
148062	keerukas	keerukas =keeruka  (SgIn  >keerukas !02_A	et	f	\N
148063	keerukas	keerukas =keerukas  (SgN  >keerukas !02_A	et	f	\N
148071	parnil	?parnil =parni  (SgAd  >parni !16_S	et	f	\N
148072	parnil	?parnil =parni  (SgAd  >parn !22_S	et	f	\N
148075	aaastal	?aaastal =aaasta  (SgAd  >aaasta !01_S	et	f	\N
148096	kuskümmendseitse	?kuskümmendseitse =kuskümmendseitse  (SgG  >kuskümmendseitne !02_A	et	f	\N
148097	kuskümmendseitse	?kuskümmendseitse =kuskümmendseitse  (PlP  >kuskümmendseits !22_S	et	f	\N
148098	kuskümmendseitse	?kuskümmendseitse =kuskümmendseitse  (IndPrPs_  >kuskümmendseitsema !27_V	et	f	\N
148099	kuskümmendseitse	?kuskümmendseitse =kuskümmendseitse  (ImpPrSg2  >kuskümmendseitsema !27_V	et	f	\N
148100	kuskümmendseitse	?kuskümmendseitse =kümmendseitse  (SgG  >kus+kümmendseitne !02_A	et	f	\N
148101	kuskümmendseitse	?kuskümmendseitse =kümmendseitse  (PlP  >kus+kümmendseits !22_S	et	f	\N
148102	kolmkummend	?kolmkummend =kolmkummend  (SgN  >kolmkummend !22_S	et	f	\N
148103	kolmkummend	?kolmkummend =kummend  (SgN  >kolm+kummend !02_S	et	f	\N
148128	nädalavahetus	nädalavahetus =vahetu  (SgIn  >nädala+vahetu !01_A	et	f	\N
148129	nädalavahetus	"nädala+vahetu %vahe  )TU2_kA  <nädala+vahe ;16_S	et	f	\N
148130	nädalavahetus	nädalavahetus =vahetus  (SgN  >nädala+vahetus !11_S	et	f	\N
148131	nädalavahetus	"nädala+vahetus %vahe  )TUS2_aS  <nädala+vahe ;16_S	et	f	\N
148165	kela	?kela =kela  (SgN  >kela !17_S	et	f	\N
148166	kela	?kela =kela  (SgG  >kela !17_S	et	f	\N
148167	kela	?kela =kela  (SgP  >kela !17_S	et	f	\N
148168	kela	?kela =kela  (IndPrPs_  >kelama !27_V	et	f	\N
148169	kela	?kela =kela  (ImpPrSg2  >kelama !27_V	et	f	\N
148202	külastamasin	?külastamasin =külastamasin  (SgN  >külastamasin !19_S	et	f	\N
148203	külastamasin	?külastamasin =tamasin  (SgN  >külas+tamasin !19_S	et	f	\N
148204	külastamasin	?külastamasin =stamasin  (SgN  >küla+stamasin !19_S	et	f	\N
148205	uinakutsin	?uinakutsin =uinakutsi  (IndPrSg1  >uinakutsima !28_V	et	f	\N
148206	uinakutsin	?uinakutsin =uinakutsin  (SgN  >uinakutsin !02_S	et	f	\N
148243	vooodist	?vooodist =vooodi  (SgEl  >vooodi !16_S	et	f	\N
148244	vooodist	?vooodist =vooodi  (SgEl  >vooot !22_S	et	f	\N
148245	vooodist	?vooodist =vooodis  (SgP  >vooodis !11_S	et	f	\N
148246	vooodist	?vooodist =odi  (SgEl  >voo+odi !17_S	et	f	\N
148247	vooodist	?vooodist =odis  (SgP  >voo+odis !09_S	et	f	\N
148248	vooodist	?vooodist =odist  (SgN  >voo+odist !22_S	et	f	\N
148283	apelsinimahla	apelsinimahla =mahla  (SgG  >apelsini+mahl !22_S	et	f	\N
148284	apelsinimahla	apelsinimahla =mahla  (SgP  >apelsini+mahl !22_S	et	f	\N
148285	apelsinimahla	apelsinimahla =mahla  (SgAdt  >apelsini+mahl !22_S	et	f	\N
148286	väärt	?väärt =väärt  (ID  >väärt !41_A	et	f	\N
148304	kõrget	kõrget =kõrge  (SgP  >kõrge !01_A	et	f	\N
148305	kõrget	kõrget =kõrge  (SgP  >kõrge !05_S	et	f	\N
148313	suunduva	suunduva =suunduva  (SgG  >suunduv !02_A	et	f	\N
148314	suunduva	"suunduv %suundu  )V_vA  <suunduma ;27_V	et	f	\N
148317	nõukogudeajast	nõukogudeajast =aja  (SgEl  >nõu+kogude+aeg !22_S	et	f	\N
148318	nõukogudeajast	nõukogudeajast =ajas  (SgP  >nõu+kogude+ajane !10_A	et	f	\N
148319	nõukogudeajast	"nõu+kogude+ajane %aja  )NE_aA  <nõu+kogude+aeg ;22_S	et	f	\N
148320	mälestussammaste	mälestussammaste =sammas  (PlG  >mälestus+sammas !07_S	et	f	\N
148321	mälestussammaste	mälestussammaste =sammas  (PlG  >mälestus+sammane !10_A	et	f	\N
148322	mälestussammaste	"mälestus+sammane %samma  )NE_aA  <mälestus+samb ;22_S	et	f	\N
148333	asukohast	asukohast =koha  (SgEl  >asu+koha !17_S	et	f	\N
148334	asukohast	asukohast =koha  (SgEl  >asu+koht !22_S	et	f	\N
148335	asukohast	asukohast =kohas  (SgP  >asu+kohane !10_A	et	f	\N
148336	asukohast	"asu+kohane %koha  )NE_aA  <asu+koha ;17_S	et	f	\N
148337	asukohast	"asu+kohane %koha  )NE_aA  <asu+koht ;22_S	et	f	\N
148345	jüri	jüri =jüri  (SgN  >jüri !17~16_S	et	f	\N
147967	juhata	juhata =juha  (SgAb  >juha !17_S	et	f	\N
147968	juhata	juhata =juhata  (IndPrPs_  >juhatama !27_V	et	f	\N
147969	juhata	juhata =juhata  (ImpPrSg2  >juhatama !27_V	et	f	\N
147976	gotsa	?gotsa =gotsa  (SgN  >gotsa !16_S	et	f	\N
147977	gotsa	?gotsa =gotsa  (SgG  >gotsa !16_S	et	f	\N
147978	gotsa	?gotsa =gotsa  (IndPrPs_  >gotsama !29_V	et	f	\N
147979	gotsa	?gotsa =gotsa  (ImpPrSg2  >gotsama !29_V	et	f	\N
148006	laugh	?laugh =laugh  (SgN  >laugh !22_S	et	f	\N
148014	kooki	kooki =kooki  (SgP  >kook !22_S	et	f	\N
148015	kooki	kooki =kooki  (SgAdt  >kook !22_S	et	f	\N
148023	estlane	?estlane =estlane  (SgN  >estlane !12?10_S	et	f	\N
148024	estlane	?estlane =estlane  (IndPrPs_  >estlanema !27_V	et	f	\N
148025	estlane	?estlane =estlane  (ImpPrSg2  >estlanema !27_V	et	f	\N
148028	massimeedi	?massimeedi =massimeedi  (SgN  >massimeedi !16_S	et	f	\N
148029	massimeedi	?massimeedi =massimeedi  (SgG  >massimeedi !16_S	et	f	\N
148030	massimeedi	?massimeedi =massimeedi  (SgG  >massimeet !22_S	et	f	\N
148031	massimeedi	?massimeedi =massimeedi  (SgP  >massimeed !22_S	et	f	\N
148032	massimeedi	?massimeedi =massimeedi  (SgAdt  >massimeed !22_S	et	f	\N
148033	massimeedi	?massimeedi =massimeedi  (IndPrPs_  >massimeetima !28_V	et	f	\N
148034	massimeedi	?massimeedi =massimeedi  (ImpPrSg2  >massimeetima !28_V	et	f	\N
148035	massimeedi	?massimeedi =edi  (SgN  >mass+ime+edi !17_S	et	f	\N
148036	massimeedi	?massimeedi =edi  (SgG  >mass+ime+edi !17_S	et	f	\N
148037	massimeedi	?massimeedi =edi  (SgP  >mass+ime+edi !17_S	et	f	\N
148038	massimeedi	?massimeedi =meedi  (SgN  >massi+meedi !16_S	et	f	\N
148039	massimeedi	?massimeedi =meedi  (SgG  >massi+meedi !16_S	et	f	\N
148040	massimeedi	?massimeedi =meedi  (SgG  >massi+meet !22_S	et	f	\N
148041	massimeedi	?massimeedi =meedi  (SgP  >massi+meed !22_S	et	f	\N
148042	massimeedi	?massimeedi =meedi  (SgAdt  >massi+meed !22_S	et	f	\N
148043	massimeedi	?massimeedi =imeedi  (SgN  >mass+imeedi !16_S	et	f	\N
148044	massimeedi	?massimeedi =imeedi  (SgG  >mass+imeedi !16_S	et	f	\N
148045	massimeedi	?massimeedi =imeedi  (SgG  >mass+imeet !22_S	et	f	\N
148046	massimeedi	?massimeedi =imeedi  (SgP  >mass+imeed !22_S	et	f	\N
148047	massimeedi	?massimeedi =imeedi  (SgAdt  >mass+imeed !22_S	et	f	\N
148052	teenistuskeel	teenistuskeel =kee  (SgAd  >teenistus+kesi !15_S	et	f	\N
148053	teenistuskeel	teenistuskeel =kee  (SgAd  >teenistus+kee !26_S	et	f	\N
148054	teenistuskeel	teenistuskeel =keel  (SgN  >teenistus+keel !13_S	et	f	\N
148064	armulugu	armulugu =lugu  (SgN  >armu+lugu !18_S	et	f	\N
148065	armulugu	armulugu =lugu  (SgP  >armu+lugu !18_S	et	f	\N
148080	elavist	elavist =elavi  (SgEl  >elav !02_A	et	f	\N
148081	elavist	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
148121	kolmapaev	?kolmapaev =kolmapaev  (SgN  >kolmapaev !22_S	et	f	\N
148122	kolmapaev	?kolmapaev =paev  (SgN  >kolma+paev !22_S	et	f	\N
148123	kolmapaev	?kolmapaev =apaev  (SgN  >kolm+apaev !22_S	et	f	\N
148132	vallaline	vallaline =vallaline  (SgN  >vallaline !12_AS	et	f	\N
148133	vallaline	"vallaline %valla  )LINE_aA  <vald ;22_S	et	f	\N
148142	john	?john =john  (SgN  >john !22_S	et	f	\N
148145	viiskümmend	?viiskümmend =viiskümmend  (SgN  >viiskümmend !22_S	et	f	\N
148148	päsis	?päsis =päsi  (SgIn  >päsi !17_S	et	f	\N
148149	päsis	?päsis =päsi  (IndIpfSg3  >päsima !27_V	et	f	\N
148150	päsis	?päsis =päsis  (SgN  >päsis !09_S	et	f	\N
148151	jonas	?jonas =jona  (SgIn  >jona !17_S	et	f	\N
148152	jonas	?jonas =jona  (IndIpfSg3  >jonama !27_V	et	f	\N
148153	jonas	?jonas =jonas  (SgN  >jonas !09_S	et	f	\N
148157	lu	### lu	et	f	\N
148174	olenisud	?olenisud =olenisu  (IndPrSg2  >olenisuma !27_V	et	f	\N
148188	võõrastemaja	võõrastemaja =maja  (SgN  >võõraste+maja !17_S	et	f	\N
148189	võõrastemaja	võõrastemaja =maja  (SgG  >võõraste+maja !17_S	et	f	\N
148190	võõrastemaja	võõrastemaja =maja  (SgP  >võõraste+maja !17_S	et	f	\N
148200	sõbranat	### sõbranat	et	f	\N
148221	vaastamisväärsustega	?vaastamisväärsustega =vaastamisväärsus  (PlKom  >vaastamisväärsus !11~09_S	et	f	\N
148232	tegemine	tegemine =tegemine  (SgN  >tegemine !12_S	et	f	\N
148233	tegemine	"tegemine %tege  )MINE_vS  <tegema ;28_V	et	f	\N
148237	gymnasti	?gymnasti =gymnasti  (ID  >gymnasti !41_D	et	f	\N
148238	gymnasti	?gymnasti =gymnasti  (IndPrPs_  >gymnastima !28_V	et	f	\N
148239	gymnasti	?gymnasti =gymnasti  (ImpPrSg2  >gymnastima !28_V	et	f	\N
148256	hommikusel	hommikusel =hommikuse  (SgAd  >hommikune !12_A	et	f	\N
148257	hommikusel	"hommikune %hommiku  )NE_aA  <hommik ;02_S	et	f	\N
148258	hommikusel	hommikusel =use  (PlAd  >hommik+usk !22_S	et	f	\N
148270	käärima	käärima =kääri  (Sup  >käärima !28_V	et	f	\N
148271	käärima	käärima =ima  (SgN  >käär+ima !17_S	et	f	\N
148272	käärima	käärima =ima  (SgG  >käär+ima !17_S	et	f	\N
148273	käärima	käärima =ima  (SgP  >käär+ima !17_S	et	f	\N
148279	tapselt	?tapselt =tapse  (SgAbl  >tapne !02_A	et	f	\N
148280	tapselt	?tapselt =tapse  (SgAbl  >tapse !06_S	et	f	\N
148281	tapselt	?tapselt =tapse  (PlAbl  >taps !22_S	et	f	\N
148282	tapselt	?tapselt =tapselt  (ID  >tapselt !41_D	et	f	\N
148289	surr	?surr =surr  (SgN  >surr !22_S	et	f	\N
148111	waitress	?waitress =waitress  (SgN  >waitress !22_S	et	f	\N
148113	teman	?teman =tema  (IndPrSg1  >temama !27_V	et	f	\N
148114	teman	?teman =teman  (SgN  >teman !02_S	et	f	\N
148116	võimelemine	?võimelemine =võimelemine  (SgN  >võimelemine !12_S	et	f	\N
148117	võimelemine	?võimelemine =võimelemine  (PlP  >võimelemin !19_S	et	f	\N
148118	võimelemine	?võimelemine =lemine  (SgN  >võime+lemine !10_A	et	f	\N
148119	võimelemine	?võimelemine =melemine  (SgN  >või+melemine !12_S	et	f	\N
148120	võimelemine	?võimelemine =melemine  (PlP  >või+melemin !19_S	et	f	\N
148124	klubbisse	?klubbisse =klubbi  (SgIll  >klubbi !16_S	et	f	\N
148125	klubbisse	?klubbisse =klubbi  (SgIll  >klubb !22_S	et	f	\N
148126	klubbisse	?klubbisse =klubbisse  (SgG  >klubbisne !02_A	et	f	\N
148127	klubbisse	?klubbisse =klubbisse  (PlP  >klubbiss !22_S	et	f	\N
148143	sünnitama	sünnitama =sünni  (SupIps  >sündima !28_V	et	f	\N
148144	sünnitama	sünnitama =sünnita  (Sup  >sünnitama !27_V	et	f	\N
148154	belfastis	?belfastis =belfasti  (IndIpfSg3  >belfastima !28_V	et	f	\N
148155	belfastis	?belfastis =belfastis  (SgN  >belfastis !11_S	et	f	\N
148178	yorkisse	?yorkisse =yorkisse  (SgG  >yorkisne !02_A	et	f	\N
148179	yorkisse	?yorkisse =yorkisse  (PlP  >yorkiss !22_S	et	f	\N
148191	hottelli	?hottelli =hottelli  (SgN  >hottelli !01_S	et	f	\N
148192	hottelli	?hottelli =hottelli  (SgG  >hottelli !01_S	et	f	\N
148193	hottelli	?hottelli =hottelli  (SgG  >hottell !22_S	et	f	\N
148194	hottelli	?hottelli =hottelli  (SgP  >hottell !22_S	et	f	\N
148195	hottelli	?hottelli =hottelli  (SgAdt  >hottell !22_S	et	f	\N
148196	hottelli	?hottelli =hottelli  (IndPrPs_  >hottellima !28_V	et	f	\N
148197	hottelli	?hottelli =hottelli  (ImpPrSg2  >hottellima !28_V	et	f	\N
148208	joobnud	joobnud =joobnu  (PlN  >joobnu !01_S	et	f	\N
148209	joobnud	joobnud =joobnud  (ID  >joobnud !41_A	et	f	\N
148230	mahasin	?mahasin =maha  (IndIpfSg1  >mahama !27_V	et	f	\N
148231	mahasin	?mahasin =mahasin  (SgN  >mahasin !19_S	et	f	\N
148234	sarnast	sarnast =sarna  (SgEl  >sarn !22_S	et	f	\N
148235	sarnast	sarnast =sarnas  (SgP  >sarnane !10_A	et	f	\N
148236	sarnast	"sarnane %sarna  )NE_aA  <sarn ;22_S	et	f	\N
148249	hotellist	hotellist =hotelli  (SgEl  >hotell !22_S	et	f	\N
148250	hotellist	hotellist =hotellis  (SgP  >hotelline !12_A	et	f	\N
148251	hotellist	"hotelline %hotelli  )NE_aA  <hotell ;22_S	et	f	\N
148252	lennujaama	lennujaama =jaama  (SgG  >lennu+jaam !22_S	et	f	\N
148253	lennujaama	lennujaama =jaama  (SgP  >lennu+jaam !22_S	et	f	\N
148254	lennujaama	lennujaama =jaama  (SgAdt  >lennu+jaam !22_S	et	f	\N
148265	pima	?pima =pima  (SgN  >pima !17_S	et	f	\N
148266	pima	?pima =pima  (SgG  >pima !17_S	et	f	\N
148267	pima	?pima =pima  (SgP  >pima !17_S	et	f	\N
148268	pima	?pima =pima  (IndPrPs_  >pimama !27_V	et	f	\N
148269	pima	?pima =pima  (ImpPrSg2  >pimama !27_V	et	f	\N
148274	dialogue	?dialogue =dialogue  (SgN  >dialogue !01_S	et	f	\N
148275	dialogue	?dialogue =dialogue  (SgG  >dialogue !01_S	et	f	\N
148287	naljamees	naljamees =mee  (SgIn  >nalja+mesi !15_S	et	f	\N
148288	naljamees	naljamees =mees  (SgN  >nalja+mees !13_S	et	f	\N
148290	jällen	?jällen =jälle  (IndPrSg1  >jällema !30_V	et	f	\N
148291	jällen	?jällen =jällen  (SgN  >jällen !02_S	et	f	\N
148299	korrusmaja	?korrusmaja =korrusmaja  (SgN  >korrusmaja !01_S	et	f	\N
148301	korrusmaja	?korrusmaja =korrusmaja  (SgG  >korrusmaja !01_S	et	f	\N
148303	korrusmaja	?korrusmaja =korrusmaja  (SgG  >korrusmajas !02_A	et	f	\N
148306	kaugusele	kaugusele =kauguse  (SgAll  >kaugus !11~09_S	et	f	\N
148307	kaugusele	"kaugus %kauge  )US_aS  <kauge ;01_A	et	f	\N
148308	kaugusele	kaugusele =kauguse  (SgAll  >kaugune !10~12_A	et	f	\N
148310	kaugusele	kaugusele =use  (PlAll  >kaug+usk !22_S	et	f	\N
148315	rannatee	rannatee =tee  (SgN  >ranna+tee !26_S	et	f	\N
148316	rannatee	rannatee =tee  (SgG  >ranna+tee !26_S	et	f	\N
148341	skuptorite	?skuptorite =skuptori  (PlG  >skuptori !01_S	et	f	\N
148342	skuptorite	?skuptorite =skuptori  (PlG  >skuptor !02_S	et	f	\N
148343	protestiks	protestiks =protesti  (SgTr  >protest !22_S	et	f	\N
148344	protestiks	protestiks =protesti  (KndPrPs  >protestima !28_V	et	f	\N
148359	algupärase	algupärase =pärase  (SgG  >algu+pärane !10_A	et	f	\N
148360	algupärase	"algu+pärane %pära  )NE_aA  <algu+pära ;17_S	et	f	\N
148361	tauno	?tauno =tauno  (SgN  >tauno !16_S	et	f	\N
148362	tauno	?tauno =tauno  (SgG  >tauno !16_S	et	f	\N
148365	merineitsi	merineitsi =neitsi  (SgN  >meri+neitsi !01_S	et	f	\N
148366	merineitsi	merineitsi =neitsi  (SgG  >meri+neitsi !01_S	et	f	\N
148408	gallerist	?gallerist =galleri  (SgEl  >galleri !01_S	et	f	\N
148409	gallerist	?gallerist =galleri  (SgEl  >galler !02_S	et	f	\N
148410	gallerist	?gallerist =galleris  (SgP  >galleris !11_S	et	f	\N
148411	gallerist	?gallerist =gallerist  (SgN  >gallerist !22_S	et	f	\N
148414	innukalt	innukalt =innuka  (SgAbl  >innukas !02_A	et	f	\N
148415	innukalt	innukalt =innukalt  (ID  >innukalt !41_D	et	f	\N
148417	innukalt	"innukalt %innuka  )LT_mD  <innukas ;02_A	et	f	\N
148427	mõjukam	mõjukam =mõjukam  (SgN  >mõjukam !02_A	et	f	\N
148428	mõjukam	"mõjukam %mõjuka  )M_cA  <mõjukas ;02_A	et	f	\N
148182	yorkis	?yorkis =yorkis  (ID  >yorkis !41_DA	et	f	\N
148183	joogi	joogi =joogi  (SgN  >joogi !16_S	et	f	\N
148184	joogi	joogi =joogi  (SgG  >joogi !16_S	et	f	\N
148185	joogi	joogi =joogi  (SgG  >jook !22_S	et	f	\N
148186	joogi	joogi =joo  (IndPrPs_^  >jooma !38_V	et	f	\N
148187	joogi	joogi =joo  (ImpPrSg2^  >jooma !38_V	et	f	\N
148198	jalutuskäiku	jalutuskäiku =käiku  (SgP  >jalutus+käik !22_S	et	f	\N
148199	jalutuskäiku	jalutuskäiku =käiku  (SgAdt  >jalutus+käik !22_S	et	f	\N
148211	aratama	?aratama =ara  (SupIps  >arama !27_V	et	f	\N
148212	aratama	?aratama =arata  (Sup  >aratama !27_V	et	f	\N
148213	aratama	?aratama =aratama  (SgG  >aratam !02_A	et	f	\N
148214	aratama	?aratama =tama  (SgN  >ara+tama !17_S	et	f	\N
148215	aratama	?aratama =tama  (SgG  >ara+tama !17_S	et	f	\N
148216	aratama	?aratama =tama  (SgP  >ara+tama !17_S	et	f	\N
148225	esmaspaev	?esmaspaev =esmaspaev  (SgN  >esmaspaev !22_S	et	f	\N
148226	esmaspaev	?esmaspaev =paev  (SgN  >esmas+paev !22_S	et	f	\N
148227	esmaspaev	?esmaspaev =spaev  (SgN  >esma+spaev !22_S	et	f	\N
148228	käimasin	?käimasin =käima  (IndIpfSg1  >käimama !29_V	et	f	\N
148229	käimasin	?käimasin =käimasin  (SgN  >käimasin !19_S	et	f	\N
148255	jätkamasin	?jätkamasin =jätkamasin  (SgN  >jätkamasin !19_S	et	f	\N
148259	ammendamine	ammendamine =ammendamine  (SgN  >ammendamine !12_S	et	f	\N
148260	ammendamine	"ammendamine %ammenda  )MINE_vS  <ammendama ;27_V	et	f	\N
148261	eksima	eksima =eksi  (Sup  >eksima !28_V	et	f	\N
148262	eksima	eksima =ima  (SgN  >eks+ima !17_S	et	f	\N
148263	eksima	eksima =ima  (SgG  >eks+ima !17_S	et	f	\N
148264	eksima	eksima =ima  (SgP  >eks+ima !17_S	et	f	\N
148338	mälestussambakompleksiga	mälestussambakompleksiga =iga  (SgN  >mälestus+samba+kompleks+iga !18_S	et	f	\N
148339	mälestussambakompleksiga	mälestussambakompleksiga =iga  (SgP  >mälestus+samba+kompleks+iga !18_S	et	f	\N
148340	mälestussambakompleksiga	mälestussambakompleksiga =kompleksi  (SgKom  >mälestus+samba+kompleks !22_S	et	f	\N
148349	juhitava	juhitava =juhitava  (SgG  >juhitav !02_A	et	f	\N
148350	juhitava	"juhitav %juhi  )TAV_vAS  <juhtima ;28_V	et	f	\N
148351	juhitava	juhitava =tava  (SgN  >juhi+tava !17_S	et	f	\N
148352	juhitava	juhitava =tava  (SgG  >juhi+tava !17_S	et	f	\N
148353	juhitava	juhitava =tava  (SgP  >juhi+tava !17_S	et	f	\N
148367	kopenhagenile	?kopenhagenile =kopenhageni  (SgAll  >kopenhagen !19_S	et	f	\N
148370	sobiks	sobiks =sobi  (SgTr  >sobi !17_S	et	f	\N
148371	sobiks	sobiks =sobi  (KndPrPs  >sobima !27_V	et	f	\N
148447	neiukest	neiukest =neiukes  (SgP  >neiuke !12_S	et	f	\N
148449	neiukest	"neiuke %neiu  )KE_dS  <neiu ;16_S	et	f	\N
148451	neiukest	"neiuke %neiu  )KE_dS  <neid ;22_S	et	f	\N
148452	neiukest	neiukest =neiukes  (SgP  >neiukene !12_S	et	f	\N
148453	neiukest	"neiukene %neiu  )KENE_dS  <neiu ;16_S	et	f	\N
148454	neiukest	"neiukene %neiu  )KENE_dS  <neid ;22_S	et	f	\N
148455	neiukest	neiukest =kest  (SgN  >neiu+kest !22_S	et	f	\N
148464	21meetrine	meetrine =meetrine  (SgN  >meetrine !12~10_A	et	f	\N
148465	21meetrine	"meetrine %meetri  )NE_aA  <meeter ;02_S	et	f	\N
148469	kutsusid	kutsusid =kutsu  (PlP  >kutsu !16_S	et	f	\N
148470	kutsusid	kutsusid =kutsu  (IndIpfSg2  >kutsuma !28_V	et	f	\N
148471	kutsusid	kutsusid =kutsu  (IndIpfPl3  >kutsuma !28_V	et	f	\N
148472	esindusest	esindusest =esinduse  (SgEl  >esindus !11_S	et	f	\N
148473	esindusest	"esindus %esinda  )US_vS  <esindama ;27_V	et	f	\N
148477	esindusest	esindusest =esinduses  (SgP  >esindusene !12_A	et	f	\N
148479	esindusest	"esindusene %esinduse  )NE_aA  <esindus ;11_S	et	f	\N
148490	vaidlusalune	vaidlusalune =alune  (SgN  >vaidlus+alune !10_AS	et	f	\N
148491	vaidlusalune	"vaidlus+alune %alu  )NE_aA  <vaidlus+alg ;22_S	et	f	\N
148519	naasmist	naasmist =naasmis  (SgP  >naasmine !12?10_S	et	f	\N
148520	naasmist	"naasmine %naas  )MINE_vS  <naasma ;32_V	et	f	\N
148567	ideeprojekti	ideeprojekti =projekti  (SgG  >idee+projekt !22_S	et	f	\N
148568	ideeprojekti	ideeprojekti =projekti  (SgP  >idee+projekt !22_S	et	f	\N
148569	ideeprojekti	ideeprojekti =projekti  (SgAdt  >idee+projekt !22_S	et	f	\N
148570	rannajoonest	rannajoonest =joone  (SgEl  >ranna+joon !13_S	et	f	\N
148571	rannajoonest	rannajoonest =joones  (SgP  >ranna+joonene !10_A	et	f	\N
148573	rannajoonest	"ranna+joonene %joone  )NE_aA  <ranna+joon ;13_S	et	f	\N
148593	komisjoni	komisjoni =komisjoni  (SgG  >komisjon !19_S	et	f	\N
148594	komisjoni	komisjoni =komisjoni  (SgP  >komisjon !19_S	et	f	\N
148595	komisjoni	komisjoni =komisjoni  (SgAdt  >komisjon !19_S	et	f	\N
148602	kunstiline	kunstiline =kunstiline  (SgN  >kunstiline !12_A	et	f	\N
148603	kunstiline	"kunstiline %kunsti  )LINE_aA  <kunst ;22_S	et	f	\N
148623	vaimustunud	vaimustunud =vaimustu  (PtsPtPs  >vaimustuma !27_V	et	f	\N
148624	vaimustunud	vaimustunud =vaimustunu  (PlN  >vaimustunu !01_S	et	f	\N
148625	vaimustunud	"vaimustunu %vaimustu  )NU_vS  <vaimustuma ;27_V	et	f	\N
148626	vaimustunud	vaimustunud =vaimustunud  (ID  >vaimustunud !41_A	et	f	\N
148627	vaimustunud	"vaimustunud %vaimustu  )NUD_vA  <vaimustuma ;27_V	et	f	\N
148645	arhitektideliit	?arhitektideliit =arhitektideliit  (SgN  >arhitektideliit !22_S	et	f	\N
148647	arhitektideliit	?arhitektideliit =deliit  (SgN  >arhitekti+deliit !22_S	et	f	\N
148222	eelnevus	eelnevus =eelnevus  (SgN  >eelnevus !11_S	et	f	\N
148223	eelnevus	"eelnevus %eelne  )VUS_aS  <eelnema ;27_V	et	f	\N
148224	eelnevus	"eelnevus %eelneva  )US_aS  <eelnev ;02_A	et	f	\N
148240	teisipaev	?teisipaev =teisipaev  (SgN  >teisipaev !22_S	et	f	\N
148241	teisipaev	?teisipaev =paev  (SgN  >teisi+paev !22_S	et	f	\N
148242	teisipaev	?teisipaev =ipaev  (SgN  >teis+ipaev !22_S	et	f	\N
148276	ostja	ostja =ostja  (SgN  >ostja !01_S	et	f	\N
148277	ostja	"ostja %ost  )JA_vS  <ostma ;34_V	et	f	\N
148278	ostja	ostja =ostja  (SgG  >ostja !01_S	et	f	\N
148300	mõõdulist	mõõdulist =mõõdulis  (SgP  >mõõduline !12_A	et	f	\N
148302	mõõdulist	"mõõduline %mõõdu  )LINE_aA  <mõõt ;22_S	et	f	\N
148323	kompleks	kompleks =komple  (KndPrPs  >komplema !30_V	et	f	\N
148324	kompleks	kompleks =kompleks  (SgN  >kompleks !22_S	et	f	\N
148354	planeerinud	planeerinud =planeeri  (PtsPtPs  >planeerima !28_V	et	f	\N
148355	planeerinud	planeerinud =planeerinu  (PlN  >planeerinu !01_S	et	f	\N
148356	planeerinud	"planeerinu %planeeri  )NU_vS  <planeerima ;28_V	et	f	\N
148357	planeerinud	planeerinud =planeerinud  (ID  >planeerinud !41_A	et	f	\N
148358	planeerinud	"planeerinud %planeeri  )NUD_vA  <planeerima ;28_V	et	f	\N
148368	algupärases	algupärases =pärase  (SgIn  >algu+pärane !10_A	et	f	\N
148369	algupärases	"algu+pärane %pära  )NE_aA  <algu+pära ;17_S	et	f	\N
148376	sõtnik	?sõtnik =sõtnik  (SgN  >sõtnik !25_S	et	f	\N
148377	sõtniku	?sõtniku =sõtniku  (SgN  >sõtniku !01_S	et	f	\N
148378	sõtniku	?sõtniku =sõtniku  (SgG  >sõtniku !01_S	et	f	\N
148379	sõtniku	?sõtniku =sõtniku  (SgG  >sõtnik !25_S	et	f	\N
148380	sõtniku	?sõtniku =sõtniku  (IndPrPs_  >sõtnikuma !27_V	et	f	\N
148381	sõtniku	?sõtniku =sõtniku  (ImpPrSg2  >sõtnikuma !27_V	et	f	\N
148382	spasse	?spasse =spasse  (SgN  >spasse !06_S	et	f	\N
148383	spasse	?spasse =spasse  (SgG  >spasne !02_A	et	f	\N
148384	spasse	?spasse =spasse  (SgG  >spasse !06_S	et	f	\N
148385	spasse	?spasse =spasse  (PlP  >spass !22_S	et	f	\N
148386	spasse	?spasse =spasse  (IndPrPs_  >spassema !27_V	et	f	\N
148387	spasse	?spasse =spasse  (ImpPrSg2  >spassema !27_V	et	f	\N
148388	botaanikaaeda	botaanikaaeda =aeda  (SgP  >botaanika+aed !22_S	et	f	\N
148389	botaanikaaeda	botaanikaaeda =aeda  (SgAdt  >botaanika+aed !22_S	et	f	\N
148395	galleriis	?galleriis =galleri  (PlIn  >galleri !01_S	et	f	\N
148396	galleriis	?galleriis =galleri  (PlIn  >galler !02_S	et	f	\N
148397	galleriis	?galleriis =gallerii  (SgIn  >gallerii !26_S	et	f	\N
148398	galleriis	?galleriis =galleriis  (SgN  >galleriis !22_S	et	f	\N
148399	esmaspäevalgi	esmaspäevalgi =algi  (SgG  >esmas+päev+alk !22_S	et	f	\N
148400	esmaspäevalgi	esmaspäevalgi =algi  (SgP  >esmas+päev+alg !22_S	et	f	\N
148401	esmaspäevalgi	esmaspäevalgi =algi  (SgAdt  >esmas+päev+alg !22_S	et	f	\N
148402	esmaspäevalgi	esmaspäevalgi =päeva  (SgAd^  >esmas+päev !22_S	et	f	\N
148403	innustunud	innustunud =innustu  (PtsPtPs  >innustuma !27_V	et	f	\N
148404	innustunud	innustunud =innustunu  (PlN  >innustunu !01_S	et	f	\N
148405	innustunud	"innustunu %innustu  )NU_vS  <innustuma ;27_V	et	f	\N
148406	innustunud	innustunud =innustunud  (ID  >innustunud !41_A	et	f	\N
148407	innustunud	"innustunud %innustu  )NUD_vA  <innustuma ;27_V	et	f	\N
148416	pronksist	pronksist =pronksi  (SgEl  >pronks !22_S	et	f	\N
148418	pronksist	pronksist =pronksis  (SgP  >pronksine !10_A	et	f	\N
148419	pronksist	"pronksine %pronksi  )NE_aA  <pronks ;22_S	et	f	\N
148420	pronksist	pronksist =ist  (SgN  >pronks+ist !22_S	et	f	\N
148421	sümboliseerivad	sümboliseerivad =sümboliseeri  (IndPrPl3  >sümboliseerima !28_V	et	f	\N
148422	sümboliseerivad	sümboliseerivad =sümboliseeriva  (PlN  >sümboliseeriv !02_A	et	f	\N
148423	sümboliseerivad	"sümboliseeriv %sümboliseeri  )V_vA  <sümboliseerima ;28_V	et	f	\N
148424	sümboliseerivad	sümboliseerivad =seeriva  (PlN  >sümboli+seeriv !02_A	et	f	\N
148438	kunstnikute	?kunstnikute =kunstniku  (PlG  >kunstniku !01_S	et	f	\N
148439	kunstnikute	?kunstnikute =kunstniku  (IndPrPl2  >kunstnikuma !27_V	et	f	\N
148443	kaela	kaela =kaela  (ID  >kaela !41_K	et	f	\N
148444	kaela	kaela =kaela  (SgG  >kael !23?22_S	et	f	\N
148445	kaela	kaela =kaela  (SgP  >kael !23?22_S	et	f	\N
148446	kaela	kaela =kaela  (SgAdt  >kael !23?22_S	et	f	\N
148458	suurele	suurele =suure  (SgAll  >suur !13_A	et	f	\N
148459	suurele	suurele =re  (SgAll  >suu+re !26_S	et	f	\N
148462	kõrgune	kõrgune =kõrgune  (SgN  >kõrgune !10~12_A	et	f	\N
148463	kõrgune	kõrgune =une  (SgG  >kõrg+uni !20_S	et	f	\N
148474	protestimaks	protestimaks =protesti  (SupTr  >protestima !28_V	et	f	\N
148476	protestimaks	protestimaks =maks  (SgN  >protesti+maks !22_S	et	f	\N
148481	kohtunikkogu	?kohtunikkogu =kohtunikkogu  (IndPrPs_  >kohtunikkoguma !27_V	et	f	\N
148482	kohtunikkogu	?kohtunikkogu =kohtunikkogu  (ImpPrSg2  >kohtunikkoguma !27_V	et	f	\N
148498	kompleksiga	kompleksiga =kompleksi  (SgKom  >kompleks !22_S	et	f	\N
148499	kompleksiga	kompleksiga =iga  (SgN  >kompleks+iga !18_S	et	f	\N
148500	kompleksiga	kompleksiga =iga  (SgP  >kompleks+iga !18_S	et	f	\N
148501	visualiseerisime	?visualiseerisime =visualiseeri  (IndIpfPl1  >visualiseerima !28_V	et	f	\N
148506	varja	varja =varja  (SgG  >vari !24_S	et	f	\N
148292	tallinnalahte	?tallinnalahte =tallinnalahte  (PlP  >tallinnalaht !22_S	et	f	\N
148293	tallinnalahte	?tallinnalahte =alahte  (PlP  >tallinn+alaht !22_S	et	f	\N
148294	konkursitööd	konkursitööd =töö  (PlN  >konkursi+töö !26_S	et	f	\N
148295	konkursitööd	konkursitööd =töö  (SgP  >konkursi+töö !26_S	et	f	\N
148296	lahte	lahte =lahte  (SgP  >laht !22_S	et	f	\N
148297	lahte	lahte =lahte  (SgAdt  >laht !22_S	et	f	\N
148298	lahte	lahte =lahte  (PlP  >laht !22_S	et	f	\N
148309	rannast	rannast =ranna  (SgEl  >rand !22_S	et	f	\N
148311	rannast	rannast =rannas  (SgP  >rannane !10_A	et	f	\N
148312	rannast	"rannane %ranna  )NE_aA  <rand ;22_S	et	f	\N
148325	suurusest	suurusest =suuruse  (SgEl  >suurus !11~09_S	et	f	\N
148326	suurusest	"suurus %suur  )US_aS  <suur ;13_A	et	f	\N
148327	suurusest	suurusest =suuruse  (SgEl  >suurune !10~12_A	et	f	\N
148328	suurusest	suurusest =suuruses  (SgP  >suurusene !12_A	et	f	\N
148329	suurusest	"suurusene %suuruse  )NE_aA  <suurus ;09_S	et	f	\N
148330	suurusest	"suurusene %suuruse  )NE_aA  <suurus ;11_S	et	f	\N
148331	suurusest	suurusest =use  (PlEl  >suur+usk !22_S	et	f	\N
148332	suurusest	suurusest =ruse  (PlEl  >suu+rusk !22_S	et	f	\N
148348	ratase	?ratase =ratase  (SgG  >ratane !10_A	et	f	\N
148372	mälestuskompleksiga	mälestuskompleksiga =iga  (SgN  >mälestus+kompleks+iga !18_S	et	f	\N
148373	mälestuskompleksiga	mälestuskompleksiga =iga  (SgP  >mälestus+kompleks+iga !18_S	et	f	\N
148374	mälestuskompleksiga	mälestuskompleksiga =kompleksi  (SgKom  >mälestus+kompleks !22_S	et	f	\N
148375	visualiseerime	?visualiseerime =visualiseeri  (IndPrPl1  >visualiseerima !28_V	et	f	\N
148426	projektit	?projektit =projekti  (SgP  >projekti !01_S	et	f	\N
148432	keskerakonna	keskerakonna =konna  (SgG  >kesk+era+konn !22_S	et	f	\N
148433	keskerakonna	keskerakonna =konna  (SgP  >kesk+era+konn !22_S	et	f	\N
148434	keskerakonna	keskerakonna =konna  (SgAdt  >kesk+era+konn !22_S	et	f	\N
148435	keskerakonna	keskerakonna =erakonna  (SgG  >kesk+erakond !22_S	et	f	\N
148441	kangrost	?kangrost =kangro  (SgEl  >kangro !01_S	et	f	\N
148442	kangrost	?kangrost =kangros  (SgP  >kangros !11~09_S	et	f	\N
148448	küsitakse	küsitakse =küsi  (IndPrIps  >küsima !27_V	et	f	\N
148450	küsitakse	küsitakse =takse  (PlP  >küsi+taks !22_S	et	f	\N
148466	kangelastele	kangelastele =kangelas  (PlAll  >kangelane !12_S	et	f	\N
148467	kangelastele	kangelastele =las  (PlAll  >kange+laps !14_S	et	f	\N
148468	kangelastele	kangelastele =laste  (PlAll  >kange+last !22_S	et	f	\N
148502	aselinnapea	aselinnapea =pea  (SgN  >ase+linna+pea !26_S	et	f	\N
148503	aselinnapea	aselinnapea =pea  (SgG  >ase+linna+pea !26_S	et	f	\N
148504	botaanika	botaanika =botaanika  (SgN  >botaanika !01_S	et	f	\N
148505	botaanika	botaanika =botaanika  (SgG  >botaanika !01_S	et	f	\N
148511	siluetti	siluetti =siluetti  (SgG  >siluett !22_S	et	f	\N
148512	siluetti	siluetti =siluetti  (SgP  >siluett !22_S	et	f	\N
148513	siluetti	siluetti =siluetti  (SgAdt  >siluett !22_S	et	f	\N
148532	asukoha	asukoha =koha  (SgN  >asu+koha !17_S	et	f	\N
148533	asukoha	asukoha =koha  (SgG  >asu+koha !17_S	et	f	\N
148534	asukoha	asukoha =koha  (SgG  >asu+koht !22_S	et	f	\N
148535	asukoha	asukoha =koha  (SgP  >asu+koha !17_S	et	f	\N
148536	varemgi	varemgi =varem  (ID^  >varem !41_D	et	f	\N
148537	varemgi	varemgi =varem  (SgN^  >varem !02_A	et	f	\N
148538	reklaaminud	reklaaminud =reklaami  (PtsPtPs  >reklaamima !28_V	et	f	\N
148539	reklaaminud	reklaaminud =reklaaminu  (PlN  >reklaaminu !01_S	et	f	\N
148540	reklaaminud	"reklaaminu %reklaami  )NU_vS  <reklaamima ;28_V	et	f	\N
148541	reklaaminud	reklaaminud =reklaaminud  (ID  >reklaaminud !41_A	et	f	\N
148542	reklaaminud	"reklaaminud %reklaami  )NUD_vA  <reklaamima ;28_V	et	f	\N
148543	keskerakonda	keskerakonda =erakonda  (SgP  >kesk+erakond !22_S	et	f	\N
148544	keskerakonda	keskerakonda =erakonda  (SgAdt  >kesk+erakond !22_S	et	f	\N
148560	suurune	suurune =suurune  (SgN  >suurune !10~12_A	et	f	\N
148561	suurune	suurune =une  (SgG  >suur+uni !20_S	et	f	\N
148576	ühenduse	ühenduse =ühenduse  (SgG  >ühendus !11_S	et	f	\N
148577	ühenduse	"ühendus %ühenda  )US_vS  <ühendama ;27_V	et	f	\N
148578	aegunud	aegunud =aegu  (PtsPtPs  >aeguma !27_V	et	f	\N
148579	aegunud	aegunud =aegunu  (PlN  >aegunu !01_S	et	f	\N
148580	aegunud	"aegunu %aegu  )NU_vS  <aeguma ;27_V	et	f	\N
148581	aegunud	aegunud =aegunud  (ID  >aegunud !41_A	et	f	\N
148582	aegunud	"aegunud %aegu  )NUD_vA  <aeguma ;27_V	et	f	\N
148583	memoriaalkompleksi	memoriaalkompleksi =kompleksi  (SgG  >memoriaal+kompleks !22_S	et	f	\N
148584	memoriaalkompleksi	memoriaalkompleksi =kompleksi  (SgP  >memoriaal+kompleks !22_S	et	f	\N
148585	memoriaalkompleksi	memoriaalkompleksi =kompleksi  (SgAdt  >memoriaal+kompleks !22_S	et	f	\N
148589	protestides	protestides =protesti  (PlIn  >protest !22_S	et	f	\N
148590	protestides	protestides =protesti  (Ger  >protestima !28_V	et	f	\N
148596	juhitud	juhitud =juhi  (PtsPtIps  >juhtima !28_V	et	f	\N
148597	juhitud	juhitud =juhitu  (PlN  >juhitu !01_AS	et	f	\N
148598	juhitud	"juhitu %juhi  )TU1_vS  <juhtima ;28_V	et	f	\N
148599	juhitud	"juhitu %juhi  )TU2_kA  <juht ;22_S	et	f	\N
148600	juhitud	juhitud =juhitud  (ID  >juhitud !41_A	et	f	\N
148601	juhitud	"juhitud %juhi  )TUD_vA  <juhtima ;28_V	et	f	\N
148346	jüri	jüri =jüri  (SgG  >jüri !17~16_S	et	f	\N
148347	jüri	jüri =jüri  (SgP  >jüri !17_S	et	f	\N
148363	püstitamist	püstitamist =püstitamis  (SgP  >püstitamine !12_S	et	f	\N
148364	püstitamist	"püstitamine %püstita  )MINE_vS  <püstitama ;27_V	et	f	\N
148390	silhuetti	?silhuetti =silhuetti  (SgG  >silhuett !22_S	et	f	\N
148391	silhuetti	?silhuetti =silhuetti  (SgP  >silhuett !22_S	et	f	\N
148392	silhuetti	?silhuetti =silhuetti  (SgAdt  >silhuett !22_S	et	f	\N
148393	silhuetti	?silhuetti =silhuetti  (IndPrPs_  >silhuettima !28_V	et	f	\N
148394	silhuetti	?silhuetti =silhuetti  (ImpPrSg2  >silhuettima !28_V	et	f	\N
148412	mägila	?mägila =mägila  (SgN  >mägila !01_S	et	f	\N
148413	mägila	?mägila =mägila  (SgG  >mägila !01_S	et	f	\N
148425	boigoteerib	?boigoteerib =boigoteeri  (IndPrSg3  >boigoteerima !28_V	et	f	\N
148440	kritiik	?kritiik =kritiik  (SgN  >kritiik !22_S	et	f	\N
148456	lahele	lahele =lahe  (SgAll  >laht !22_S	et	f	\N
148457	lahele	lahele =lahe  (PlAll  >lahk !22_S	et	f	\N
148460	võistlustööd	võistlustööd =töö  (PlN  >võistlus+töö !26_S	et	f	\N
148461	võistlustööd	võistlustööd =töö  (SgP  >võistlus+töö !26_S	et	f	\N
148483	projekteerinud	projekteerinud =projekteeri  (PtsPtPs  >projekteerima !28_V	et	f	\N
148484	projekteerinud	projekteerinud =projekteerinu  (PlN  >projekteerinu !01_S	et	f	\N
148485	projekteerinud	"projekteerinu %projekteeri  )NU_vS  <projekteerima ;28_V	et	f	\N
148486	projekteerinud	projekteerinud =projekteerinud  (ID  >projekteerinud !41_A	et	f	\N
148487	projekteerinud	"projekteerinud %projekteeri  )NUD_vA  <projekteerima ;28_V	et	f	\N
148488	kõmutekitanud	kõmutekitanud =tanu  (PlN  >kõmu+teki+tanu !17_S	et	f	\N
148489	kõmutekitanud	kõmutekitanud =tekitanu  (PlN  >kõmu+tekitanu !01_S	et	f	\N
148492	reklaamima	reklaamima =reklaami  (Sup  >reklaamima !28_V	et	f	\N
148493	reklaamima	reklaamima =ima  (SgN  >reklaam+ima !17_S	et	f	\N
148494	reklaamima	reklaamima =ima  (SgG  >reklaam+ima !17_S	et	f	\N
148495	reklaamima	reklaamima =ima  (SgP  >reklaam+ima !17_S	et	f	\N
148496	kopenhaageni	?kopenhaageni =kopenhaage  (SgTer  >kopenhaage !16_S	et	f	\N
148497	kopenhaageni	?kopenhaageni =kopenhaageni  (SgG  >kopenhaagen !02_S	et	f	\N
148514	pronkskuju	pronkskuju =kuju  (SgN  >pronks+kuju !17_S	et	f	\N
148516	pronkskuju	pronkskuju =kuju  (SgG  >pronks+kuju !17_S	et	f	\N
148518	pronkskuju	pronkskuju =kuju  (SgP  >pronks+kuju !17_S	et	f	\N
148529	nägemusest	nägemusest =nägemuse  (SgEl  >nägemus !11_S	et	f	\N
148530	nägemusest	nägemusest =nägemuses  (SgP  >nägemusene !12_A	et	f	\N
148531	nägemusest	"nägemusene %nägemuse  )NE_aA  <nägemus ;11_S	et	f	\N
148557	paneelmaja	paneelmaja =maja  (SgN  >paneel+maja !17_S	et	f	\N
148558	paneelmaja	paneelmaja =maja  (SgG  >paneel+maja !17_S	et	f	\N
148559	paneelmaja	paneelmaja =maja  (SgP  >paneel+maja !17_S	et	f	\N
148572	piritale	?piritale =piritale  (PlP  >pirital !19_S	et	f	\N
148574	piritale	?piritale =tale  (SgN  >piri+tale !16_S	et	f	\N
148575	piritale	?piritale =tale  (SgG  >piri+tale !16_S	et	f	\N
148604	turustamisega	turustamisega =turustamise  (SgKom  >turustamine !12_S	et	f	\N
148605	turustamisega	"turustamine %turusta  )MINE_vS  <turustama ;27_V	et	f	\N
148628	galerist	?galerist =galeri  (SgEl  >galeri !01_S	et	f	\N
148629	galerist	?galerist =galeri  (SgEl  >galer !02_S	et	f	\N
148630	galerist	?galerist =galeris  (SgP  >galeris !11_S	et	f	\N
148631	galerist	?galerist =galerist  (SgN  >galerist !22_S	et	f	\N
148632	vaimustunult	vaimustunult =vaimustunu  (SgAbl  >vaimustunu !01_S	et	f	\N
148633	vaimustunult	"vaimustunu %vaimustu  )NU_vS  <vaimustuma ;27_V	et	f	\N
148634	vaimustunult	vaimustunult =vaimustunult  (ID  >vaimustunult !41_D	et	f	\N
148635	vaimustunult	"vaimustunult %vaimustu  )NULT_mD  <vaimustuma ;27_V	et	f	\N
148636	rännanud	rännanud =ränna  (PtsPtPs  >rändama !29_V	et	f	\N
148637	rännanud	rännanud =rännanu  (PlN  >rännanu !01_S	et	f	\N
148638	rännanud	"rännanu %ränna  )NU_vS  <rändama ;29_V	et	f	\N
148639	rännanud	rännanud =rännanud  (ID  >rännanud !41_A	et	f	\N
148640	rännanud	"rännanud %ränna  )NUD_vA  <rändama ;29_V	et	f	\N
148641	visiooni	visiooni =visiooni  (SgG  >visioon !22_S	et	f	\N
148642	visiooni	visiooni =visiooni  (SgP  >visioon !22_S	et	f	\N
148643	visiooni	visiooni =visiooni  (SgAdt  >visioon !22_S	et	f	\N
148683	piiri	piiri =piiri  (SgG  >piir !22_S	et	f	\N
148684	piiri	piiri =piiri  (SgP  >piir !22_S	et	f	\N
148685	piiri	piiri =piiri  (SgAdt  >piir !22_S	et	f	\N
148697	muinsuskaitsekomisjoon	?muinsuskaitsekomisjoon =muinsuskaitsekomisjoon  (SgN  >muinsuskaitsekomisjoon !22_S	et	f	\N
148698	muinsuskaitsekomisjoon	?muinsuskaitsekomisjoon =isjoon  (SgN  >muinsus+kaitse+kom+isjoon !22_S	et	f	\N
148699	muinsuskaitsekomisjoon	?muinsuskaitsekomisjoon =komisjoon  (SgN  >muinsus+kaitse+komisjoon !22_S	et	f	\N
148700	muinsuskaitsekomisjoon	?muinsuskaitsekomisjoon =tsekomisjoon  (SgN  >muinsus+kai+tsekomisjoon !22_S	et	f	\N
148701	muinsuskaitsekomisjoon	?muinsuskaitsekomisjoon =kaitsekomisjoon  (SgN  >muinsus+kaitsekomisjoon !22_S	et	f	\N
148702	fotograaf	fotograaf =fotograaf  (SgN  >fotograaf !22_S	et	f	\N
148703	fotograaf	fotograaf =graaf  (SgN  >foto+graaf !22_S	et	f	\N
148718	riitta	?riitta =riitta  (SgN  >riitta !01_S	et	f	\N
148719	riitta	?riitta =riitta  (SgG  >riitta !01_S	et	f	\N
148429	voli	voli =voli  (SgN  >voli !17_S	et	f	\N
148430	voli	voli =voli  (SgG  >voli !17_S	et	f	\N
148431	voli	voli =voli  (SgP  >voli !17_S	et	f	\N
148436	ülejäänute	ülejäänute =jäänu  (PlG  >üle+jäänu !01_S	et	f	\N
148437	ülejäänute	ülejäänute =jäänu  (PlG  >üle+jäänu !06_S	et	f	\N
148475	ametivõimu	ametivõimu =võimu  (SgG  >ameti+võim !22_S	et	f	\N
148478	ametivõimu	ametivõimu =võimu  (SgP  >ameti+võim !22_S	et	f	\N
148480	ametivõimu	ametivõimu =võimu  (SgAdt  >ameti+võim !22_S	et	f	\N
148524	kuntniku	?kuntniku =kuntniku  (SgN  >kuntniku !01_S	et	f	\N
148525	kuntniku	?kuntniku =kuntniku  (SgG  >kuntniku !01_S	et	f	\N
148526	kuntniku	?kuntniku =kuntniku  (SgG  >kuntnik !25_S	et	f	\N
148527	kuntniku	?kuntniku =kuntniku  (IndPrPs_  >kuntnikuma !27_V	et	f	\N
148528	kuntniku	?kuntniku =kuntniku  (ImpPrSg2  >kuntnikuma !27_V	et	f	\N
148545	vägistamises	vägistamises =vägistamise  (SgIn  >vägistamine !12_S	et	f	\N
148546	vägistamises	"vägistamine %vägista  )MINE_vS  <vägistama ;27_V	et	f	\N
148552	järmise	?järmise =järmise  (SgG  >järmine !10_A	et	f	\N
148553	järmise	?järmise =järmise  (IndPrPs_  >järmisema !27_V	et	f	\N
148554	järmise	?järmise =järmise  (ImpPrSg2  >järmisema !27_V	et	f	\N
148555	kavatsusele	kavatsusele =kavatsuse  (SgAll  >kavatsus !11_S	et	f	\N
148556	kavatsusele	"kavatsus %kavatse  )US_vS  <kavatsema ;27_V	et	f	\N
148612	meetriseks	meetriseks =meetrise  (SgTr  >meetrine !12~10_A	et	f	\N
148613	meetriseks	"meetrine %meetri  )NE_aA  <meeter ;02_S	et	f	\N
148614	meetriseks	meetriseks =seks  (SgN  >meetri+seks !22_S	et	f	\N
148615	memoriaalkompleksiga	memoriaalkompleksiga =iga  (SgN  >memoriaal+kompleks+iga !18_S	et	f	\N
148616	memoriaalkompleksiga	memoriaalkompleksiga =iga  (SgP  >memoriaal+kompleks+iga !18_S	et	f	\N
148618	memoriaalkompleksiga	memoriaalkompleksiga =kompleksi  (SgKom  >memoriaal+kompleks !22_S	et	f	\N
148644	mõjuvõimsam	mõjuvõimsam =võimsam  (SgN  >mõju+võimsam !02_A	et	f	\N
148646	mõjuvõimsam	"mõju+võimsam %võimsa  )M_cA  <mõju+võimas ;03_A	et	f	\N
148648	mõjuvõimsam	"mõju+võimsam %võimsa  )M_cA  <mõju+võimas ;05_A	et	f	\N
148652	turustanud	turustanud =turusta  (PtsPtPs  >turustama !27_V	et	f	\N
148653	turustanud	turustanud =turustanu  (PlN  >turustanu !01_S	et	f	\N
148654	turustanud	"turustanu %turusta  )NU_vS  <turustama ;27_V	et	f	\N
148655	turustanud	turustanud =turustanud  (ID  >turustanud !41_A	et	f	\N
148656	turustanud	"turustanud %turusta  )NUD_vA  <turustama ;27_V	et	f	\N
148657	liitus	liitus =liitu  (SgIn  >liitu !01_A	et	f	\N
148658	liitus	"liitu %lii  )TU2_kA  <lii ;26_S	et	f	\N
148659	liitus	liitus =liitu  (IndIpfSg3  >liituma !27_V	et	f	\N
148660	liitus	liitus =liitus  (SgN  >liitus !11~09_S	et	f	\N
148661	liitus	"liitus %lii  )TUS2_aS  <lii ;26_S	et	f	\N
148671	fotograafist	fotograafist =fotograafi  (SgEl  >fotograaf !22_S	et	f	\N
148672	fotograafist	fotograafist =graafi  (SgEl  >foto+graaf !22_S	et	f	\N
148694	otsustajade	### otsustajade	et	f	\N
148706	brander	?brander =brander  (SgN  >brander !02_S	et	f	\N
148715	jan	### jan	et	f	\N
148716	alanco	?alanco =alanco  (SgN  >alanco !16_S	et	f	\N
148717	alanco	?alanco =alanco  (SgG  >alanco !16_S	et	f	\N
148723	koostanud	koostanud =koosta  (PtsPtPs  >koostama !27_V	et	f	\N
148724	koostanud	koostanud =koostanu  (PlN  >koostanu !01_S	et	f	\N
148725	koostanud	"koostanu %koosta  )NU_vS  <koostama ;27_V	et	f	\N
148726	koostanud	koostanud =koostanud  (ID  >koostanud !41_A	et	f	\N
148727	koostanud	"koostanud %koosta  )NUD_vA  <koostama ;27_V	et	f	\N
148728	koostanud	koostanud =tanu  (PlN  >koos+tanu !17_S	et	f	\N
148729	parimadest	?parimadest =parimades  (SgP  >parimadene !12_A	et	f	\N
148733	1900aastade	?aastade =tade  (SgN  >aas+tade !16_S	et	f	\N
148734	1900aastade	?aastade =tade  (SgG  >aas+tade !16_S	et	f	\N
148748	nyström	?nyström =nyström  (SgN  >nyström !02_S	et	f	\N
148752	koostamist	koostamist =koostamis  (SgP  >koostamine !12_S	et	f	\N
148753	koostamist	"koostamine %koosta  )MINE_vS  <koostama ;27_V	et	f	\N
148763	töölö	### töölö	et	f	\N
148764	eira	eira =eira  (IndPrPs_  >eirama !29_V	et	f	\N
148765	eira	eira =eira  (ImpPrSg2  >eirama !29_V	et	f	\N
148766	ühe-	ühe- =ühe  (SgN  >ühe !06_S	et	f	\N
148769	ühe-	ühe- =ühe  (SgG  >üks !22_NP	et	f	\N
148815	maastikuid	?maastikuid =maastiku  (PlP  >maastiku !01_S	et	f	\N
148816	maastikuid	?maastikuid =maastikui  (PlN  >maastikui !26_S	et	f	\N
148817	maastikuid	?maastikuid =maastikui  (SgP  >maastikui !26_S	et	f	\N
148818	maastikuid	?maastikuid =tikui  (PlN  >maas+tikui !26_S	et	f	\N
148819	maastikuid	?maastikuid =tikui  (SgP  >maas+tikui !26_S	et	f	\N
148821	maastikuid	?maastikuid =tikuid  (SgN  >maas+tikuid !22_S	et	f	\N
148837	töölös	### töölös	et	f	\N
148848	kulgev	kulgev =kulge  (PtsPrPs  >kulgema !27_V	et	f	\N
148849	kulgev	kulgev =kulgev  (SgN  >kulgev !02_A	et	f	\N
148850	kulgev	"kulgev %kulge  )V_vA  <kulgema ;27_V	et	f	\N
148853	järjestatud	järjestatud =järjesta  (PtsPtIps  >järjestama !27_V	et	f	\N
148854	järjestatud	järjestatud =järjestatu  (PlN  >järjestatu !01_S	et	f	\N
148855	järjestatud	"järjestatu %järjesta  )TU1_vS  <järjestama ;27_V	et	f	\N
148507	varja	varja =varja  (SgP  >vari !24_S	et	f	\N
148508	varja	varja =varja  (SgAdt  >vari !24_S	et	f	\N
148509	varja	varja =varja  (IndPrPs_  >varjama !29_V	et	f	\N
148510	varja	varja =varja  (ImpPrSg2  >varjama !29_V	et	f	\N
148515	suurekämblaline	suurekämblaline =kämblaline  (SgN  >suure+kämblaline !12_A	et	f	\N
148517	suurekämblaline	"suure+kämblaline %kämbla  )LINE_aA  <suure+kämmal ;08_S	et	f	\N
148521	ümbermaailma	ümbermaailma =ilma  (SgG  >ümber+maa+ilm !22_S	et	f	\N
148522	ümbermaailma	ümbermaailma =ilma  (SgP  >ümber+maa+ilm !22_S	et	f	\N
148523	ümbermaailma	ümbermaailma =ilma  (SgAdt  >ümber+maa+ilm !22_S	et	f	\N
148547	soõtniku	?soõtniku =soõtniku  (SgN  >soõtniku !01_S	et	f	\N
148548	soõtniku	?soõtniku =soõtniku  (SgG  >soõtniku !01_S	et	f	\N
148549	soõtniku	?soõtniku =soõtniku  (SgG  >soõtnik !25_S	et	f	\N
148550	soõtniku	?soõtniku =soõtniku  (IndPrPs_  >soõtnikuma !27_V	et	f	\N
148551	soõtniku	?soõtniku =soõtniku  (ImpPrSg2  >soõtnikuma !27_V	et	f	\N
148562	laekunud	laekunud =laeku  (PtsPtPs  >laekuma !27_V	et	f	\N
148563	laekunud	laekunud =laekunu  (PlN  >laekunu !01_S	et	f	\N
148564	laekunud	"laekunu %laeku  )NU_vS  <laekuma ;27_V	et	f	\N
148565	laekunud	laekunud =laekunud  (ID  >laekunud !41_A	et	f	\N
148566	laekunud	"laekunud %laeku  )NUD_vA  <laekuma ;27_V	et	f	\N
148586	ühenduste	ühenduste =ühendus  (PlG  >ühendus !11_S	et	f	\N
148587	ühenduste	"ühendus %ühenda  )US_vS  <ühendama ;27_V	et	f	\N
148588	ühenduste	ühenduste =us  (PlG  >ühend+uks !14_S	et	f	\N
148591	bürokraatlikkuse	bürokraatlikkuse =bürokraatlikkuse  (SgG  >bürokraatlikkus !11~09_S	et	f	\N
148592	bürokraatlikkuse	"bürokraatlikkus %bürokraatlikku  )US_aS  <bürokraatlik ;25_A	et	f	\N
148620	piira	piira =piira  (SgG  >piird !22_S	et	f	\N
148621	piira	piira =piira  (IndPrPs_  >piirama !29_V	et	f	\N
148622	piira	piira =piira  (ImpPrSg2  >piirama !29_V	et	f	\N
148662	keskerakonnaga	keskerakonnaga =konna  (SgKom  >kesk+era+konn !22_S	et	f	\N
148663	keskerakonnaga	keskerakonnaga =erakonna  (SgKom  >kesk+erakond !22_S	et	f	\N
148709	linnamuuseumi	linnamuuseumi =muuseumi  (SgG  >linna+muuseum !19~02_S	et	f	\N
148710	linnamuuseumi	linnamuuseumi =muuseumi  (SgP  >linna+muuseum !19_S	et	f	\N
148711	linnamuuseumi	linnamuuseumi =muuseumi  (SgAdt  >linna+muuseum !19_S	et	f	\N
148712	fotoarhiivi	fotoarhiivi =arhiivi  (SgG  >foto+arhiiv !22_S	et	f	\N
148713	fotoarhiivi	fotoarhiivi =arhiivi  (SgP  >foto+arhiiv !22_S	et	f	\N
148714	fotoarhiivi	fotoarhiivi =arhiivi  (SgAdt  >foto+arhiiv !22_S	et	f	\N
148730	avaltatud	?avaltatud =avaltatu  (PlN  >avaltatu !01_S	et	f	\N
148731	avaltatud	?avaltatud =avaltatu  (IndPrSg2  >avaltatuma !27_V	et	f	\N
148732	avaltatud	?avaltatud =avaltatud  (ID  >avaltatud !41_A	et	f	\N
148735	fotoraamatu	fotoraamatu =atu  (SgG  >foto+raam+att !22_S	et	f	\N
148736	fotoraamatu	fotoraamatu =raamatu  (SgG  >foto+raamat !02_S	et	f	\N
148737	muisuskaitsekomisjoonis	?muisuskaitsekomisjoonis =muisuskaitsekomisjooni  (SgIn  >muisuskaitsekomisjooni !16_S	et	f	\N
148738	muisuskaitsekomisjoonis	?muisuskaitsekomisjoonis =muisuskaitsekomisjooni  (SgIn  >muisuskaitsekomisjoon !22_S	et	f	\N
148739	muisuskaitsekomisjoonis	?muisuskaitsekomisjoonis =muisuskaitsekomisjooni  (IndIpfSg3  >muisuskaitsekomisjoonima !28_V	et	f	\N
148740	muisuskaitsekomisjoonis	?muisuskaitsekomisjoonis =muisuskaitsekomisjoonis  (SgN  >muisuskaitsekomisjoonis !09_S	et	f	\N
148747	gustaf	?gustaf =gustaf  (SgN  >gustaf !02_S	et	f	\N
148749	üldplaani	üldplaani =plaani  (SgG  >üld+plaan !22_S	et	f	\N
148750	üldplaani	üldplaani =plaani  (SgP  >üld+plaan !22_S	et	f	\N
148751	üldplaani	üldplaani =plaani  (SgAdt  >üld+plaan !22_S	et	f	\N
148770	kõrgede	kõrgede =ede  (SgN  >kõrg+ede !16_S	et	f	\N
148771	kõrgede	kõrgede =ede  (SgG  >kõrg+ede !16_S	et	f	\N
148779	fotograafiks	fotograafiks =fotograafi  (SgTr  >fotograaf !22_S	et	f	\N
148780	fotograafiks	fotograafiks =graafi  (SgTr  >foto+graaf !22_S	et	f	\N
148782	pildistamise	pildistamise =pildistamise  (SgG  >pildistamine !12_S	et	f	\N
148784	pildistamise	"pildistamine %pildista  )MINE_vS  <pildistama ;27_V	et	f	\N
148787	maastikufotograafina	maastikufotograafina =graafi  (SgEs  >maas+tiku+foto+graaf !22_S	et	f	\N
148788	maastikufotograafina	maastikufotograafina =fotograafi  (SgEs  >maas+tiku+fotograaf !22_S	et	f	\N
148793	joonestamise	joonestamise =joonestamise  (SgG  >joonestamine !12_S	et	f	\N
148795	joonestamise	"joonestamine %joonesta  )MINE_vS  <joonestama ;27_V	et	f	\N
148838	uudishimu	uudishimu =himu  (SgN  >uudis+himu !17_S	et	f	\N
148839	uudishimu	uudishimu =himu  (SgG  >uudis+himu !17_S	et	f	\N
148840	uudishimu	uudishimu =himu  (SgP  >uudis+himu !17_S	et	f	\N
148887	lõunapoolsi	?lõunapoolsi =lõunapoolsi  (SgG  >lõunapools !22_S	et	f	\N
148888	lõunapoolsi	?lõunapoolsi =lõunapoolsi  (SgP  >lõunapools !22_S	et	f	\N
148889	lõunapoolsi	?lõunapoolsi =lõunapoolsi  (SgAdt  >lõunapools !22_S	et	f	\N
148890	lõunapoolsi	?lõunapoolsi =lõunapoolsi  (IndPrPs_  >lõunapoolsima !28_V	et	f	\N
148891	lõunapoolsi	?lõunapoolsi =lõunapoolsi  (ImpPrSg2  >lõunapoolsima !28_V	et	f	\N
148892	lõunapoolsi	?lõunapoolsi =poolsi  (SgG  >lõuna+pools !22_S	et	f	\N
148893	lõunapoolsi	?lõunapoolsi =poolsi  (SgP  >lõuna+pools !22_S	et	f	\N
148894	lõunapoolsi	?lõunapoolsi =poolsi  (SgAdt  >lõuna+pools !22_S	et	f	\N
148895	lõunapoolsi	?lõunapoolsi =napoolsi  (SgN  >lõu+napoolsi !01_S	et	f	\N
148606	1990ndate	?ndate =ndate  (SgN  >ndate !06_S	et	f	\N
148607	1990ndate	?ndate =ndate  (IndPrPs_  >ndatema !27_V	et	f	\N
148608	1990ndate	?ndate =ndate  (ImpPrSg2  >ndatema !27_V	et	f	\N
148609	võrreldav	võrreldav =võrrel  (PtsPrIps  >võrdlema !30_V	et	f	\N
148610	võrreldav	võrreldav =võrreldav  (SgN  >võrreldav !02_A	et	f	\N
148611	võrreldav	"võrreldav %võrrel  )TAV_vAS  <võrdlema ;30_V	et	f	\N
148617	arvestusi	arvestusi =arvestusi  (PlP  >arvestus !11_S	et	f	\N
148619	arvestusi	"arvestus %arvesta  )US_vS  <arvestama ;27_V	et	f	\N
148664	signe	?signe =signe  (SgN  >signe !02_A	et	f	\N
148665	signe	?signe =signe  (PlP  >sign !22_S	et	f	\N
148666	signe	?signe =signe  (IndPrPs_  >signema !27_V	et	f	\N
148668	signe	?signe =signe  (ImpPrSg2  >signema !27_V	et	f	\N
148675	aastasada	### aastasada	et	f	\N
148677	helsingisse	?helsingisse =helsingi  (SgIll  >helsing !02_S	et	f	\N
148679	helsingisse	?helsingisse =helsingi  (SgIll  >helsink !22_S	et	f	\N
148680	helsingisse	?helsingisse =helsingis  (SgAdt  >helsingis !11_S	et	f	\N
148681	helsingisse	?helsingisse =helsingisse  (SgG  >helsingisne !02_A	et	f	\N
148682	helsingisse	?helsingisse =helsingisse  (PlP  >helsingiss !22_S	et	f	\N
148704	kiitatud	?kiitatud =kiita  (PtsPtIps  >kiitama !27_V	et	f	\N
148705	kiitatud	?kiitatud =kiitatu  (PlN  >kiitatu !01_S	et	f	\N
148707	kiitatud	?kiitatud =kiitatu  (IndPrSg2  >kiitatuma !27_V	et	f	\N
148708	kiitatud	?kiitatud =kiitatud  (ID  >kiitatud !41_A	et	f	\N
148756	branderile	?branderile =branderi  (SgAll  >branderi !01_S	et	f	\N
148757	branderile	?branderile =branderi  (SgAll  >brander !02_S	et	f	\N
148760	väledalt	väledalt =väleda  (SgAbl  >väle !02_A	et	f	\N
148761	väledalt	väledalt =väledalt  (ID  >väledalt !41_D	et	f	\N
148762	väledalt	"väledalt %väleda  )LT_mD  <väle ;02_A	et	f	\N
148781	tõestust	tõestust =tõestus  (SgP  >tõestus !11~09_S	et	f	\N
148783	tõestust	"tõestus %tõesta  )US_vS  <tõestama ;27_V	et	f	\N
148792	helsingis	?helsingis =helsingi  (SgIn  >helsing !02_S	et	f	\N
148794	helsingis	?helsingis =helsingi  (SgIn  >helsink !22_S	et	f	\N
148796	helsingis	?helsingis =helsingi  (IndIpfSg3  >helsingima !28_V	et	f	\N
148797	helsingis	?helsingis =helsingis  (SgN  >helsingis !11_S	et	f	\N
148802	fotograafateljeedest	?fotograafateljeedest =fotograafateljee  (PlEl  >fotograafateljee !26_S	et	f	\N
148803	fotograafateljeedest	?fotograafateljeedest =fotograafateljeede  (SgEl  >fotograafateljeede !16_S	et	f	\N
148804	fotograafateljeedest	?fotograafateljeedest =fotograafateljeede  (PlEl  >fotograafateljeet !22_S	et	f	\N
148805	fotograafateljeedest	?fotograafateljeedest =fotograafateljeedes  (SgP  >fotograafateljeedene !10_A	et	f	\N
148806	fotograafateljeedest	?fotograafateljeedest =graafateljee  (PlEl  >foto+graafateljee !26_S	et	f	\N
148807	fotograafateljeedest	?fotograafateljeedest =graafateljeede  (SgEl  >foto+graafateljeede !16_S	et	f	\N
148808	fotograafateljeedest	?fotograafateljeedest =graafateljeede  (PlEl  >foto+graafateljeet !22_S	et	f	\N
148809	fotograafateljeedest	?fotograafateljeedest =graafateljeedes  (SgP  >foto+graafateljeedene !10_A	et	f	\N
148830	mõõdujaid	?mõõdujaid =mõõduja  (PlP  >mõõduja !01_S	et	f	\N
148831	mõõdujaid	?mõõdujaid =mõõduja  (PlP  >mõõdujas !02_A	et	f	\N
148832	mõõdujaid	?mõõdujaid =mõõdujai  (PlN  >mõõdujai !26_S	et	f	\N
148833	mõõdujaid	?mõõdujaid =mõõdujai  (SgP  >mõõdujai !26_S	et	f	\N
148834	mõõdujaid	?mõõdujaid =jai  (PlN  >mõõdu+jai !26_S	et	f	\N
148835	mõõdujaid	?mõõdujaid =jai  (SgP  >mõõdu+jai !26_S	et	f	\N
148836	mõõdujaid	?mõõdujaid =jaid  (SgN  >mõõdu+jaid !22_S	et	f	\N
148851	seisav	?seisav =seisa  (PtsPrPs  >seisama !29_V	et	f	\N
148852	seisav	?seisav =seisav  (SgN  >seisav !02_A	et	f	\N
148882	kruunuhaka	?kruunuhaka =kruunuhaka  (SgN  >kruunuhaka !16_S	et	f	\N
148883	kruunuhaka	?kruunuhaka =kruunuhaka  (SgG  >kruunuhakas !02_A	et	f	\N
148884	kruunuhaka	?kruunuhaka =kruunuhaka  (SgG  >kruunuhaka !16_S	et	f	\N
148902	algupärane	algupärane =pärane  (SgN  >algu+pärane !10_A	et	f	\N
148903	algupärane	"algu+pärane %pära  )NE_aA  <algu+pära ;17_S	et	f	\N
148914	maakohta	maakohta =kohta  (SgP  >maa+koht !22_S	et	f	\N
148915	maakohta	maakohta =kohta  (SgAdt  >maa+koht !22_S	et	f	\N
148953	protokollidest	protokollidest =protokolli  (PlEl  >protokoll !22_S	et	f	\N
148954	protokollidest	protokollidest =kolli  (PlEl  >proto+koll !22_S	et	f	\N
148955	selgu	selgu =selgu  (IndPrPs_  >selguma !27_V	et	f	\N
148956	selgu	selgu =selgu  (ImpPrSg2  >selguma !27_V	et	f	\N
148972	fotografeerimise	fotografeerimise =fotografeerimise  (SgG  >fotografeerimine !12_S	et	f	\N
148973	fotografeerimise	"fotografeerimine %fotografeeri  )MINE_vS  <fotografeerima ;28_V	et	f	\N
148979	aastadel	?aastadel =tade  (SgAd  >aas+tade !16_S	et	f	\N
148980	aastadel	?aastadel =tadel  (SgN  >aas+tadel !02_S	et	f	\N
148993	vaimuhaiglasse	vaimuhaiglasse =haigla  (SgIll  >vaimu+haigla !01_S	et	f	\N
148994	vaimuhaiglasse	vaimuhaiglasse =haiglas  (SgAdt  >vaimu+haiglane !12_A	et	f	\N
148995	vaimuhaiglasse	"vaimu+haiglane %haigla  )NE_aA  <vaimu+haigla ;01_S	et	f	\N
149002	mattasti	mattasti =asti  (SgG  >matt+ast !22_S	et	f	\N
149003	mattasti	mattasti =asti  (SgP  >matt+ast !22_S	et	f	\N
149004	mattasti	mattasti =asti  (SgAdt  >matt+ast !22_S	et	f	\N
149010	hiiglaskuju	?hiiglaskuju =hiiglaskuju  (IndPrPs_  >hiiglaskujuma !27_V	et	f	\N
148649	ehituste	ehituste =ehitus  (PlG  >ehitus !11_S	et	f	\N
148650	ehituste	"ehitus %ehita  )US_vS  <ehitama ;27_V	et	f	\N
148651	ehituste	"ehitus %ehi  )TUS1_aS  <ehtima ;28_V	et	f	\N
148667	branderi	?branderi =branderi  (SgN  >branderi !01_S	et	f	\N
148669	branderi	?branderi =branderi  (SgG  >branderi !01_S	et	f	\N
148670	branderi	?branderi =branderi  (SgG  >brander !02_S	et	f	\N
148673	ringkäikule	?ringkäikule =ringkäiku  (SgAll  >ringkäiku !01_S	et	f	\N
148674	ringkäikule	?ringkäikule =käiku  (SgAll  >ring+käiku !16_S	et	f	\N
148676	tagusesse	tagusesse =taguse  (SgIll  >tagune !10_AS	et	f	\N
148678	tagusesse	tagusesse =sesse  (PlP  >tagu+sess !22_S	et	f	\N
148686	kolmekordistunud	kolmekordistunud =istunu  (PlN  >kolme+kord+istunu !01_S	et	f	\N
148687	kolmekordistunud	kolmekordistunud =kordistu  (PtsPtPs  >kolme+kordistuma !27_V	et	f	\N
148688	kolmekordistunud	kolmekordistunud =kordistunu  (PlN  >kolme+kordistunu !01_S	et	f	\N
148689	tohutu	tohutu =tohutu  (ID  >tohutu !41_D	et	f	\N
148690	tohutu	"tohutu %tohu  )TU2_kA  <tohu ;17_S	et	f	\N
148691	tohutu	"tohutu %tohu  )TU2_kA  <toht ;22_S	et	f	\N
148692	tohutu	tohutu =tohutu  (SgN  >tohutu !01_A	et	f	\N
148693	tohutu	tohutu =tohutu  (SgG  >tohutu !01_A	et	f	\N
148695	kaduvade	?kaduvade =ade  (SgN  >kaduv+ade !16_S	et	f	\N
148696	kaduvade	?kaduvade =ade  (SgG  >kaduv+ade !16_S	et	f	\N
148741	linnapildi	linnapildi =pildi  (SgG  >linna+pilt !22_S	et	f	\N
148742	linnapildi	linnapildi =pildi  (SgP  >linna+pild !22_S	et	f	\N
148743	linnapildi	linnapildi =pildi  (SgAdt  >linna+pild !22_S	et	f	\N
148744	kultuuriajaloo	kultuuriajaloo =loo  (SgG  >kultuuri+aja+lugu !18_S	et	f	\N
148745	kultuuriajaloo	kultuuriajaloo =loo  (SgG  >kultuuri+aja+loog !22_S	et	f	\N
148746	kultuuriajaloo	kultuuriajaloo =loo  (SgG  >kultuuri+aja+lood !22_S	et	f	\N
148758	pildistamispaigadest	?pildistamispaigadest =pildistamispaigades  (SgP  >pildistamispaigadene !12_A	et	f	\N
148759	pildistamispaigadest	?pildistamispaigadest =stamispaigades  (SgP  >pildi+stamispaigadene !12_A	et	f	\N
148772	kivimüüride	kivimüüride =üüri  (PlG  >kivim+üür !22_S	et	f	\N
148773	kivimüüride	kivimüüride =müüri  (PlG  >kivi+müür !22_S	et	f	\N
148774	pakarise	?pakarise =pakarise  (SgG  >pakaris !11_S	et	f	\N
148785	oskamise	oskamise =oskamise  (SgG  >oskamine !12_S	et	f	\N
148786	oskamise	"oskamine %oska  )MINE_vS  <oskama ;29_V	et	f	\N
148798	portree-fotograafimine	?portree-fotograafimine =fotograafimine  (SgN  >portree-fotograafimine !12_S	et	f	\N
148799	portree-fotograafimine	?portree-fotograafimine =fotograafimine  (PlP  >portree-fotograafimin !19_S	et	f	\N
148800	portree-fotograafimine	?portree-fotograafimine =graafimine  (SgN  >portree-foto+graafimine !12_S	et	f	\N
148801	portree-fotograafimine	?portree-fotograafimine =graafimine  (PlP  >portree-foto+graafimin !19_S	et	f	\N
148813	tehniikaga	?tehniikaga =tehniika  (SgKom  >tehniikas !02_S	et	f	\N
148814	tehniikaga	?tehniikaga =tehniika  (SgKom  >tehniika !16_S	et	f	\N
148827	elavuse	elavuse =elavuse  (SgG  >elavus !11_S	et	f	\N
148828	elavuse	"elavus %ela  )VUS_aS  <elama ;27_V	et	f	\N
148829	elavuse	"elavus %elava  )US_aS  <elav ;02_A	et	f	\N
148841	pildistamine	pildistamine =pildistamine  (SgN  >pildistamine !12_S	et	f	\N
148842	pildistamine	"pildistamine %pildista  )MINE_vS  <pildistama ;27_V	et	f	\N
148871	hermanni	?hermanni =hermanni  (SgN  >hermanni !01_S	et	f	\N
148872	hermanni	?hermanni =hermanni  (SgG  >hermanni !01_S	et	f	\N
148873	hermanni	?hermanni =hermanni  (SgG  >hermann !22_S	et	f	\N
148874	hermanni	?hermanni =hermanni  (SgP  >hermann !22_S	et	f	\N
148875	hermanni	?hermanni =hermanni  (SgAdt  >hermann !22_S	et	f	\N
148877	hermanni	?hermanni =hermanni  (IndPrPs_  >hermannima !28_V	et	f	\N
148879	hermanni	?hermanni =hermanni  (ImpPrSg2  >hermannima !28_V	et	f	\N
148885	linnaosade	linnaosade =sade  (SgN  >linn+ao+sade !04_S	et	f	\N
148886	linnaosade	linnaosade =osa  (PlG  >linna+osa !17_S	et	f	\N
148906	vältimatu	vältimatu =vältimatu  (SgN  >vältimatu !01_A	et	f	\N
148907	vältimatu	"vältimatu %välti  )MATU_vA  <vältima ;28_V	et	f	\N
148908	vältimatu	vältimatu =vältimatu  (SgG  >vältimatu !01_A	et	f	\N
148951	erimeeldusi	?erimeeldusi =erimeeldusi  (PlP  >erimeeldus !11_S	et	f	\N
148952	erimeeldusi	?erimeeldusi =meeldusi  (PlP  >eri+meeldus !11_S	et	f	\N
148957	erimeeldusde	?erimeeldusde =erimeeldusde  (PlP  >erimeeldusd !22_S	et	f	\N
148983	fotograafina	fotograafina =fotograafi  (SgEs  >fotograaf !22_S	et	f	\N
148984	fotograafina	fotograafina =graafi  (SgEs  >foto+graaf !22_S	et	f	\N
149000	nälga	nälga =nälga  (SgP  >nälg !22_S	et	f	\N
149001	nälga	nälga =nälga  (SgAdt  >nälg !22_S	et	f	\N
149015	linnavalitsusele	linnavalitsusele =use  (PlAll  >linn+ava+lits+usk !22_S	et	f	\N
149016	linnavalitsusele	linnavalitsusele =valitsuse  (SgAll  >linna+valitsus !11_S	et	f	\N
149025	andi	andi =andi  (SgP  >and !22_S	et	f	\N
149026	andi	andi =andi  (SgAdt  >and !22_S	et	f	\N
149027	kanglastele	?kanglastele =kanglas  (PlAll  >kanglas !07_S	et	f	\N
149028	kanglastele	?kanglastele =kanglas  (PlAll  >kanglane !12?10_S	et	f	\N
149029	kanglastele	?kanglastele =kanglastele  (IndPrPs_  >kanglastelema !36_V	et	f	\N
149030	kanglastele	?kanglastele =kanglastele  (ImpPrSg2  >kanglastelema !36_V	et	f	\N
149031	ekü	### ekü	et	f	\N
149074	ringikäimist	ringikäimist =käimi  (SgEl  >ringi+käim !22_S	et	f	\N
148720	riitta	?riitta =riitta  (IndPrPs_  >riittama !29_V	et	f	\N
148721	riitta	?riitta =riitta  (ImpPrSg2  >riittama !29_V	et	f	\N
148722	pakarinen	?pakarinen =pakarinen  (SgN  >pakarinen !19_S	et	f	\N
148754	komisjoon	?komisjoon =komisjoon  (SgN  >komisjoon !22_S	et	f	\N
148755	komisjoon	?komisjoon =isjoon  (SgN  >kom+isjoon !22_S	et	f	\N
148767	kahekorrulised	?kahekorrulised =kahekorrulise  (PlN  >kahekorruline !12_A	et	f	\N
148768	kahekorrulised	?kahekorrulised =korrulise  (PlN  >kahe+korruline !12_A	et	f	\N
148775	enesestmõistetatav	?enesestmõistetatav =enesestmõisteta  (PtsPrIps  >enesestmõistetama !27_V	et	f	\N
148776	enesestmõistetatav	?enesestmõistetatav =enesestmõistetata  (PtsPrPs  >enesestmõistetatama !27_V	et	f	\N
148777	enesestmõistetatav	?enesestmõistetatav =enesestmõistetatav  (SgN  >enesestmõistetatav !02_A	et	f	\N
148778	enesestmõistetatav	?enesestmõistetatav =mõistetatav  (SgN  >enesest+mõistetatav !02_A	et	f	\N
148789	parkanos	?parkanos =parkano  (SgIn  >parkano !01_S	et	f	\N
148790	parkanos	?parkanos =ano  (SgIn  >park+ano !17~16_S	et	f	\N
148791	parkanos	?parkanos =anos  (SgN  >park+anos !11~09_S	et	f	\N
148810	arenematu	arenematu =arenematu  (SgN  >arenematu !01_A	et	f	\N
148811	arenematu	"arenematu %arene  )MATU_vA  <arenema ;27_V	et	f	\N
148812	arenematu	arenematu =arenematu  (SgG  >arenematu !01_A	et	f	\N
148820	oskuslikult	oskuslikult =oskusliku  (SgAbl  >oskuslik !25_A	et	f	\N
148822	oskuslikult	oskuslikult =oskuslikult  (ID  >oskuslikult !41_D	et	f	\N
148823	oskuslikult	"oskuslikult %oskusliku  )LT_mD  <oskuslik ;25_A	et	f	\N
148824	hingetu	hingetu =hingetu  (SgN  >hingetu !01_A	et	f	\N
148825	hingetu	"hingetu %hinge  )TU2_kA  <hing ;22_S	et	f	\N
148826	hingetu	hingetu =hingetu  (SgG  >hingetu !01_A	et	f	\N
148843	ergutav	ergutav =ergu  (PtsPrIps  >erguma !27_V	et	f	\N
148844	ergutav	ergutav =erguta  (PtsPrPs  >ergutama !27_V	et	f	\N
148845	ergutav	ergutav =ergutav  (SgN  >ergutav !02_A	et	f	\N
148846	ergutav	"ergutav %ergu  )TAV_vAS  <erguma ;27_V	et	f	\N
148847	ergutav	"ergutav %erguta  )V_vA  <ergutama ;27_V	et	f	\N
148862	aastasaja	?aastasaja =aastasaja  (SgN  >aastasaja !01_S	et	f	\N
148863	aastasaja	?aastasaja =aastasaja  (SgG  >aastasaja !01_S	et	f	\N
148864	aastasaja	?aastasaja =aastasaja  (SgG  >aastasajas !02_A	et	f	\N
148865	aastasaja	?aastasaja =saja  (SgN  >aasta+saja !17_S	et	f	\N
148866	aastasaja	?aastasaja =saja  (SgG  >aasta+saja !17_S	et	f	\N
148867	aastasaja	?aastasaja =saja  (SgP  >aasta+saja !17_S	et	f	\N
148868	aastasaja	?aastasaja =tasaja  (SgN  >aas+tasaja !01_S	et	f	\N
148869	aastasaja	?aastasaja =tasaja  (SgG  >aas+tasaja !01_S	et	f	\N
148870	aastasaja	?aastasaja =tasaja  (SgG  >aas+tasajas !02_A	et	f	\N
148876	linnaosast	linnaosast =osa  (SgEl  >linna+osa !17_S	et	f	\N
148878	linnaosast	linnaosast =osas  (SgP  >linna+osane !10_A	et	f	\N
148880	linnaosast	"linna+osane %osa  )NE_aA  <linna+osa ;17_S	et	f	\N
148911	äratundmatuks	äratundmatuks =tuks  (SgN  >ära+tundma+tuks !22_S	et	f	\N
148913	äratundmatuks	äratundmatuks =tundmatu  (SgTr  >ära+tundmatu !01_AS	et	f	\N
148970	puhkemine	puhkemine =puhkemine  (SgN  >puhkemine !12_S	et	f	\N
148971	puhkemine	"puhkemine %puhke  )MINE_vS  <puhkema ;27_V	et	f	\N
148974	salvestus	salvestus =salvestu  (IndIpfSg3  >salvestuma !27_V	et	f	\N
148977	salvestus	salvestus =salvestus  (SgN  >salvestus !11_S	et	f	\N
148978	salvestus	"salvestus %salvesta  )US_vS  <salvestama ;27_V	et	f	\N
148981	püsiva	püsiva =püsiva  (SgG  >püsiv !02_A	et	f	\N
148982	püsiva	"püsiv %püsi  )V_vA  <püsima ;27_V	et	f	\N
148985	nägemisvõime	nägemisvõime =võime  (SgN  >nägemis+võime !06_S	et	f	\N
148986	nägemisvõime	nägemisvõime =võime  (SgG  >nägemis+võime !06_S	et	f	\N
148987	nägemisvõime	nägemisvõime =võime  (PlP  >nägemis+võim !22_S	et	f	\N
148988	rohekae	rohekae =kae  (SgN  >rohe+kae !26_S	et	f	\N
148989	rohekae	rohekae =kae  (SgG  >rohe+kae !26_S	et	f	\N
148990	kivelä	### kivelä	et	f	\N
149007	vildu	?vildu =vildu  (ID  >vildu !41_D	et	f	\N
149008	vildu	?vildu =vildu  (IndPrPs_  >vilduma !27_V	et	f	\N
149009	vildu	?vildu =vildu  (ImpPrSg2  >vilduma !27_V	et	f	\N
149040	züriist	?züriist =zürii  (SgEl  >zürii !26_S	et	f	\N
149041	züriist	?züriist =züriist  (SgN  >züriist !22_S	et	f	\N
149045	juhtimas	juhtimas =juhti  (SupIn  >juhtima !28_V	et	f	\N
149046	juhtimas	juhtimas =ima  (SgIn  >juht+ima !17_S	et	f	\N
149057	sõitavad	?sõitavad =sõita  (IndPrPl3  >sõitama !27_V	et	f	\N
149058	sõitavad	?sõitavad =sõitava  (PlN  >sõitava !01_S	et	f	\N
149059	sõitavad	?sõitavad =sõitava  (PlN  >sõitav !02_A	et	f	\N
149077	möned	?möned =möne  (PlN  >möne !16_S	et	f	\N
149078	möned	?möned =möne  (IndPrSg2  >mönema !27_V	et	f	\N
149098	kritiseerisid	kritiseerisid =kritiseeri  (IndIpfSg2  >kritiseerima !28_V	et	f	\N
149099	kritiseerisid	kritiseerisid =kritiseeri  (IndIpfPl3  >kritiseerima !28_V	et	f	\N
149103	alle	?alle =alle  (SgN  >alle !06_S	et	f	\N
149104	alle	?alle =alle  (IndPrPs_  >allema !30_V	et	f	\N
149105	alle	?alle =alle  (ImpPrSg2  >allema !30_V	et	f	\N
149118	sõtniki	?sõtniki =sõtniki  (SgN  >sõtniki !01_S	et	f	\N
149119	sõtniki	?sõtniki =sõtniki  (SgG  >sõtniki !01_S	et	f	\N
149120	sõtniki	?sõtniki =sõtniki  (IndPrPs_  >sõtnikkima !28_V	et	f	\N
148856	järjestatud	järjestatud =järjestatud  (ID  >järjestatud !41_A	et	f	\N
148857	järjestatud	"järjestatud %järjesta  )TUD_vA  <järjestama ;27_V	et	f	\N
148858	raamatusse	raamatusse =raamatu  (SgIll  >raamat !02_S	et	f	\N
148859	raamatusse	raamatusse =atu  (SgIll  >raam+att !22_S	et	f	\N
148860	uurimisretkeks	uurimisretkeks =retke  (SgTr  >uurimis+retk !22_S	et	f	\N
148861	uurimisretkeks	uurimisretkeks =retke  (PlTr  >uurimis+retk !22_S	et	f	\N
148881	hakanieme	?hakanieme =hakanieme  (PlP  >hakaniem !19_S	et	f	\N
148900	kampi	kampi =kampi  (SgP  >kamp !22_S	et	f	\N
148901	kampi	kampi =kampi  (SgAdt  >kamp !22_S	et	f	\N
148904	kaart	kaart =kaar  (SgP  >kaar !13_S	et	f	\N
148905	kaart	kaart =kaart  (SgN  >kaart !22_S	et	f	\N
148916	köögivilja	köögivilja =vilja  (SgG  >köögi+vili !24_S	et	f	\N
148917	köögivilja	köögivilja =vilja  (SgP  >köögi+vili !24_S	et	f	\N
148918	köögivilja	köögivilja =vilja  (SgAdt  >köögi+vili !24_S	et	f	\N
148958	tõõle	?tõõle =tõõ  (SgAll  >tõõ !26_S	et	f	\N
148959	tõõle	?tõõle =tõõle  (SgN  >tõõle !06_S	et	f	\N
148960	tõõle	?tõõle =tõõle  (SgG  >tõõle !06_S	et	f	\N
148961	tõõle	?tõõle =tõõle  (PlP  >tõõl !22_S	et	f	\N
148962	tõõle	?tõõle =tõõle  (IndPrPs_  >tõõlema !27_V	et	f	\N
148963	tõõle	?tõõle =tõõle  (ImpPrSg2  >tõõlema !27_V	et	f	\N
148964	fotograafi	fotograafi =fotograafi  (SgG  >fotograaf !22_S	et	f	\N
148965	fotograafi	fotograafi =fotograafi  (SgP  >fotograaf !22_S	et	f	\N
148966	fotograafi	fotograafi =fotograafi  (SgAdt  >fotograaf !22_S	et	f	\N
148967	fotograafi	fotograafi =graafi  (SgG  >foto+graaf !22_S	et	f	\N
148968	fotograafi	fotograafi =graafi  (SgP  >foto+graaf !22_S	et	f	\N
148969	fotograafi	fotograafi =graafi  (SgAdt  >foto+graaf !22_S	et	f	\N
149017	laekutati	?laekutati =laekuta  (IndIpfIps  >laekutama !27_V	et	f	\N
149018	laekutati	?laekutati =laekutati  (SgG  >laekutatt !22_S	et	f	\N
149019	laekutati	?laekutati =laekutati  (IndPrPs_  >laekutattima !28_V	et	f	\N
149020	laekutati	?laekutati =laekutati  (ImpPrSg2  >laekutattima !28_V	et	f	\N
149021	laekutati	?laekutati =kutati  (SgG  >lae+kutat !02_S	et	f	\N
149022	laekutati	?laekutati =kutati  (SgG  >lae+kutatt !22_S	et	f	\N
149052	1990aastade	?aastade =tade  (SgN  >aas+tade !16_S	et	f	\N
149053	1990aastade	?aastade =tade  (SgG  >aas+tade !16_S	et	f	\N
149054	kööpenhaminas	?kööpenhaminas =kööpenhamina  (SgIn  >kööpenhamin !19_S	et	f	\N
149060	botaanikaaiasse	botaanikaaiasse =aia  (SgIll  >botaanika+aed !22_S	et	f	\N
149061	botaanikaaiasse	botaanikaaiasse =aia  (SgIll  >botaanika+ai !22_S	et	f	\N
149062	vana-linna	vana-linna =linna  (SgG  >vana-linn !22_S	et	f	\N
149063	vana-linna	vana-linna =linna  (SgP  >vana-linn !22_S	et	f	\N
149064	vana-linna	vana-linna =linna  (SgAdt  >vana-linn !22_S	et	f	\N
149068	kandvast	kandvast =kandva  (SgEl  >kandev !02_A	et	f	\N
149069	kandvast	"kandev %kand  )V_vA  <kandma ;34_V	et	f	\N
149085	kavandust	kavandust =kavandus  (SgP  >kavandus !11_S	et	f	\N
149086	kavandust	"kavandus %kavanda  )US_vS  <kavandama ;27_V	et	f	\N
149106	satnud	?satnud =satnu  (PlN  >satnu !01_S	et	f	\N
149107	satnud	?satnud =satnu  (IndPrSg2  >satnuma !27_V	et	f	\N
149108	satnud	?satnud =satnud  (ID  >satnud !41_A	et	f	\N
149109	müüti	müüti =müüti  (SgP  >müüt !22_S	et	f	\N
149110	müüti	müüti =müüti  (SgAdt  >müüt !22_S	et	f	\N
149132	kangelaskuju	kangelaskuju =kuju  (SgN  >kangelas+kuju !17_S	et	f	\N
149133	kangelaskuju	kangelaskuju =kuju  (SgG  >kangelas+kuju !17_S	et	f	\N
149134	kangelaskuju	kangelaskuju =kuju  (SgP  >kangelas+kuju !17_S	et	f	\N
149140	tekitavad	tekitavad =tekita  (IndPrPl3  >tekitama !27_V	et	f	\N
149141	tekitavad	tekitavad =tekitava  (PlN  >tekitav !02_A	et	f	\N
149142	tekitavad	"tekitav %teki  )TAV_vAS  <tekkima ;28_V	et	f	\N
149143	tekitavad	"tekitav %tekita  )V_vA  <tekitama ;27_V	et	f	\N
149144	tekitavad	tekitavad =tava  (PlN  >teki+tava !17_S	et	f	\N
149149	mälestusmärgi	mälestusmärgi =märgi  (SgG  >mälestus+märk !22_S	et	f	\N
149150	mälestusmärgi	mälestusmärgi =märgi  (SgP  >mälestus+märg !22_AS	et	f	\N
149151	mälestusmärgi	mälestusmärgi =märgi  (SgAdt  >mälestus+märg !22_AS	et	f	\N
149152	mälestusmärgi	mälestusmärgi =märgi  (PlP  >mälestus+märg !22_AS	et	f	\N
149171	botaanikaaia	botaanikaaia =aia  (SgG  >botaanika+aed !22_S	et	f	\N
149172	botaanikaaia	botaanikaaia =aia  (SgG  >botaanika+ai !22_S	et	f	\N
149173	botaanikaaia	botaanikaaia =aia  (SgP  >botaanika+ai !22_S	et	f	\N
149174	botaanikaaia	botaanikaaia =aia  (SgAdt  >botaanika+ai !22_S	et	f	\N
149175	kunstikku	?kunstikku =kunstikku  (ID  >kunstikku !41_D	et	f	\N
149176	kunstikku	?kunstikku =kunstikku  (IndPrPs_  >kunstikkuma !27_V	et	f	\N
149177	kunstikku	?kunstikku =kunstikku  (ImpPrSg2  >kunstikkuma !27_V	et	f	\N
149178	kunstikku	?kunstikku =ikku  (SgP  >kunst+ikk !22_S	et	f	\N
149179	kunstikku	?kunstikku =ikku  (SgAdt  >kunst+ikk !22_S	et	f	\N
149180	mäglia	?mäglia =mäglia  (SgN  >mäglia !01_S	et	f	\N
149181	mäglia	?mäglia =mäglia  (SgG  >mäglia !01_S	et	f	\N
149200	eelistanud	eelistanud =eelista  (PtsPtPs  >eelistama !27_V	et	f	\N
149201	eelistanud	eelistanud =eelistanu  (PlN  >eelistanu !01_S	et	f	\N
149202	eelistanud	"eelistanu %eelista  )NU_vS  <eelistama ;27_V	et	f	\N
148896	lõunapoolsi	?lõunapoolsi =napoolsi  (SgG  >lõu+napoolsi !01_S	et	f	\N
148897	lõunapoolsi	?lõunapoolsi =napoolsi  (SgG  >lõu+napools !22_S	et	f	\N
148898	lõunapoolsi	?lõunapoolsi =napoolsi  (SgP  >lõu+napools !22_S	et	f	\N
148899	lõunapoolsi	?lõunapoolsi =napoolsi  (SgAdt  >lõu+napools !22_S	et	f	\N
148909	mönes	?mönes =möne  (SgIn  >möne !16_S	et	f	\N
148910	mönes	?mönes =möne  (IndIpfSg3  >mönema !27_V	et	f	\N
148912	mönes	?mönes =mönes  (SgN  >mönes !09_S	et	f	\N
148919	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =muinsuskaitsekomisjoo  (SgTer  >muinsuskaitsekomisjoo !26_S	et	f	\N
148920	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =muinsuskaitsekomisjooni  (SgN  >muinsuskaitsekomisjooni !16_S	et	f	\N
148921	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =muinsuskaitsekomisjooni  (SgG  >muinsuskaitsekomisjooni !16_S	et	f	\N
148922	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =muinsuskaitsekomisjooni  (SgG  >muinsuskaitsekomisjoon !22_S	et	f	\N
148923	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =muinsuskaitsekomisjooni  (SgP  >muinsuskaitsekomisjoon !22_S	et	f	\N
148924	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =muinsuskaitsekomisjooni  (SgAdt  >muinsuskaitsekomisjoon !22_S	et	f	\N
148925	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =muinsuskaitsekomisjooni  (IndPrPs_  >muinsuskaitsekomisjoonima !28_V	et	f	\N
148926	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =muinsuskaitsekomisjooni  (ImpPrSg2  >muinsuskaitsekomisjoonima !28_V	et	f	\N
148927	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =isjoo  (SgTer  >muinsus+kaitse+kom+isjoo !26_S	et	f	\N
148928	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =isjooni  (SgN  >muinsus+kaitse+kom+isjooni !16_S	et	f	\N
148929	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =isjooni  (SgG  >muinsus+kaitse+kom+isjooni !16_S	et	f	\N
148930	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =isjooni  (SgG  >muinsus+kaitse+kom+isjoon !22_S	et	f	\N
148931	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =isjooni  (SgP  >muinsus+kaitse+kom+isjoon !22_S	et	f	\N
148932	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =isjooni  (SgAdt  >muinsus+kaitse+kom+isjoon !22_S	et	f	\N
148933	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =komisjoo  (SgTer  >muinsus+kaitse+komisjoo !26_S	et	f	\N
148934	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =komisjooni  (SgN  >muinsus+kaitse+komisjooni !16_S	et	f	\N
148935	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =komisjooni  (SgG  >muinsus+kaitse+komisjooni !16_S	et	f	\N
148936	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =komisjooni  (SgG  >muinsus+kaitse+komisjoon !22_S	et	f	\N
148937	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =komisjooni  (SgP  >muinsus+kaitse+komisjoon !22_S	et	f	\N
148938	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =komisjooni  (SgAdt  >muinsus+kaitse+komisjoon !22_S	et	f	\N
148939	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =tsekomisjoo  (SgTer  >muinsus+kai+tsekomisjoo !26_S	et	f	\N
148940	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =tsekomisjooni  (SgN  >muinsus+kai+tsekomisjooni !16_S	et	f	\N
148941	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =tsekomisjooni  (SgG  >muinsus+kai+tsekomisjooni !16_S	et	f	\N
148942	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =tsekomisjooni  (SgG  >muinsus+kai+tsekomisjoon !22_S	et	f	\N
148943	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =tsekomisjooni  (SgP  >muinsus+kai+tsekomisjoon !22_S	et	f	\N
148944	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =tsekomisjooni  (SgAdt  >muinsus+kai+tsekomisjoon !22_S	et	f	\N
148945	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =kaitsekomisjoo  (SgTer  >muinsus+kaitsekomisjoo !26_S	et	f	\N
148946	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =kaitsekomisjooni  (SgN  >muinsus+kaitsekomisjooni !16_S	et	f	\N
148947	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =kaitsekomisjooni  (SgG  >muinsus+kaitsekomisjooni !16_S	et	f	\N
148948	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =kaitsekomisjooni  (SgG  >muinsus+kaitsekomisjoon !22_S	et	f	\N
148949	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =kaitsekomisjooni  (SgP  >muinsus+kaitsekomisjoon !22_S	et	f	\N
148950	muinsuskaitsekomisjooni	?muinsuskaitsekomisjooni =kaitsekomisjooni  (SgAdt  >muinsus+kaitsekomisjoon !22_S	et	f	\N
148975	süstemaatliline	?süstemaatliline =süstemaatliline  (SgN  >süstemaatliline !12_A	et	f	\N
148976	süstemaatliline	?süstemaatliline =süstemaatliline  (PlP  >süstemaatlilin !19_S	et	f	\N
148991	patsientid	### patsientid	et	f	\N
148992	nikkilä	### nikkilä	et	f	\N
148996	väitatud	?väitatud =väitatu  (PlN  >väitatu !01_S	et	f	\N
148997	väitatud	?väitatud =väitatu  (IndPrSg2  >väitatuma !27_V	et	f	\N
148998	väitatud	?väitatud =väitatud  (ID  >väitatud !41_A	et	f	\N
148999	väitatud	?väitatud =tatu  (PlN  >väi+tatu !16_S	et	f	\N
149005	ühishauda	ühishauda =hauda  (SgP  >ühis+haud !22_S	et	f	\N
149006	ühishauda	ühishauda =hauda  (SgAdt  >ühis+haud !22_S	et	f	\N
149023	poolelt	poolelt =poole  (SgAbl  >pool !13_NS	et	f	\N
149024	poolelt	poolelt =poole  (PlAbl  >pool !22_S	et	f	\N
149037	koost	koost =koo  (SgEl  >kubu !18_S	et	f	\N
149038	koost	koost =koost  (ID  >koost !41_D	et	f	\N
149039	koost	koost =koost  (SgN  >koost !22_S	et	f	\N
149047	kunstiala	kunstiala =ala  (SgN  >kunsti+ala !17_S	et	f	\N
149048	kunstiala	kunstiala =ala  (SgG  >kunsti+ala !17_S	et	f	\N
149049	kunstiala	kunstiala =ala  (SgP  >kunsti+ala !17_S	et	f	\N
149050	kalevipoeg-ideed	kalevipoeg-ideed =idee  (PlN  >kalevipoeg-idee !26_S	et	f	\N
149051	kalevipoeg-ideed	kalevipoeg-ideed =idee  (SgP  >kalevipoeg-idee !26_S	et	f	\N
149065	innustus	innustus =innustu  (IndIpfSg3  >innustuma !27_V	et	f	\N
149066	innustus	innustus =innustus  (SgN  >innustus !11_S	et	f	\N
149011	hiiglaskuju	?hiiglaskuju =hiiglaskuju  (ImpPrSg2  >hiiglaskujuma !27_V	et	f	\N
149012	hiiglaskuju	?hiiglaskuju =skuju  (SgN  >hiigla+skuju !17_S	et	f	\N
149013	hiiglaskuju	?hiiglaskuju =skuju  (SgG  >hiigla+skuju !17_S	et	f	\N
149014	hiiglaskuju	?hiiglaskuju =skuju  (SgP  >hiigla+skuju !17_S	et	f	\N
149032	erimeelsusi	erimeelsusi =meelsusi  (PlP  >eri+meelsus !11_S	et	f	\N
149033	erimeelsusi	"eri+meelsus %meelse  )US_aS  <eri+meelne ;02_A	et	f	\N
149034	skulptuuri	skulptuuri =skulptuuri  (SgG  >skulptuur !22_S	et	f	\N
149035	skulptuuri	skulptuuri =skulptuuri  (SgP  >skulptuur !22_S	et	f	\N
149036	skulptuuri	skulptuuri =skulptuuri  (SgAdt  >skulptuur !22_S	et	f	\N
149042	protesteeritades	?protesteeritades =protesteerita  (Ger  >protesteeritama !27_V	et	f	\N
149043	züriis	?züriis =zürii  (SgIn  >zürii !26_S	et	f	\N
149044	züriis	?züriis =züriis  (SgN  >züriis !22_S	et	f	\N
149055	meri-neitsi	meri-neitsi =neitsi  (SgN  >meri-neitsi !01_S	et	f	\N
149056	meri-neitsi	meri-neitsi =neitsi  (SgG  >meri-neitsi !01_S	et	f	\N
149072	päraste	päraste =päras  (PlG  >pärane !10_A	et	f	\N
149073	päraste	"pärane %pära  )NE_aA  <pära ;17_S	et	f	\N
149084	boikottib	### boikottib	et	f	\N
149089	riius	riius =riiu  (SgIn  >riid !22_S	et	f	\N
149090	riius	riius =riius  (ID  >riius !41_D	et	f	\N
149091	võimus	võimus =võimu  (SgIn  >võim !22_S	et	f	\N
149092	võimus	võimus =võimus  (SgN  >võimus !09_S	et	f	\N
149116	januaarikuu	?januaarikuu =januaarikuu  (SgN  >januaarikuu !26_S	et	f	\N
149117	januaarikuu	?januaarikuu =januaarikuu  (SgG  >januaarikuu !26_S	et	f	\N
149128	kõrguses	kõrguses =kõrguse  (SgIn  >kõrgus !11~09_S	et	f	\N
149129	kõrguses	"kõrgus %kõrge  )US_aS  <kõrge ;01_A	et	f	\N
149130	kõrguses	kõrguses =kõrguse  (SgIn  >kõrgune !10~12_A	et	f	\N
149131	kõrguses	kõrguses =use  (PlIn  >kõrg+usk !22_S	et	f	\N
149145	vanenud	?vanenud =vane  (PtsPtPs  >vanema !27_V	et	f	\N
149146	vanenud	?vanenud =vanenu  (PlN  >vanenu !01_S	et	f	\N
149147	vanenud	?vanenud =vanenu  (IndPrSg2  >vanenuma !27_V	et	f	\N
149148	vanenud	?vanenud =vanenud  (ID  >vanenud !41_A	et	f	\N
149156	vaieldud	vaieldud =vaiel  (PtsPtIps  >vaidlema !30_V	et	f	\N
149157	vaieldud	vaieldud =vaieldu  (PlN  >vaieldu !01_S	et	f	\N
149158	vaieldud	"vaieldu %vaiel  )TU1_vS  <vaidlema ;30_V	et	f	\N
149159	vaieldud	vaieldud =vaieldud  (ID  >vaieldud !41_A	et	f	\N
149160	vaieldud	"vaieldud %vaiel  )TUD_vA  <vaidlema ;30_V	et	f	\N
149183	rändamist	rändamist =rändamis  (SgP  >rändamine !12_S	et	f	\N
149184	rändamist	"rändamine %rända  )MINE_vS  <rändama ;29_V	et	f	\N
149185	kunstiku	?kunstiku =kunstiku  (SgN  >kunstiku !01_S	et	f	\N
149186	kunstiku	?kunstiku =kunstiku  (SgG  >kunstiku !01_S	et	f	\N
149187	kunstiku	?kunstiku =kunstiku  (SgG  >kunstik !02_S	et	f	\N
149188	kunstiku	?kunstiku =kunstiku  (IndPrPs_  >kunstikuma !27_V	et	f	\N
149189	kunstiku	?kunstiku =kunstiku  (ImpPrSg2  >kunstikuma !27_V	et	f	\N
149190	kunstiku	?kunstiku =iku  (SgN  >kunst+iku !16_S	et	f	\N
149191	kunstiku	?kunstiku =iku  (SgG  >kunst+iku !16_S	et	f	\N
149192	kunstiku	?kunstiku =iku  (SgG  >kunst+ikk !22_S	et	f	\N
149218	linnavolikogu	linnavolikogu =kogu  (SgN  >linna+voli+kogu !17_S	et	f	\N
149219	linnavolikogu	linnavolikogu =kogu  (SgG  >linna+voli+kogu !17_S	et	f	\N
149220	linnavolikogu	linnavolikogu =kogu  (SgP  >linna+voli+kogu !17_S	et	f	\N
149278	parkanost	?parkanost =parkano  (SgEl  >parkano !01_S	et	f	\N
149279	parkanost	?parkanost =ano  (SgEl  >park+ano !17~16_S	et	f	\N
149280	parkanost	?parkanost =anos  (SgP  >park+anos !11~09_S	et	f	\N
149285	portreede	portreede =portree  (PlG  >portree !26_S	et	f	\N
149286	portreede	portreede =reede  (SgN  >port+reede !01_S	et	f	\N
149287	portreede	portreede =reede  (SgG  >port+reede !01_S	et	f	\N
149288	ateljeetöö	ateljeetöö =töö  (SgN  >ateljee+töö !26_S	et	f	\N
149289	ateljeetöö	ateljeetöö =töö  (SgG  >ateljee+töö !26_S	et	f	\N
149293	piirdunud	piirdunud =piirdu  (PtsPtPs  >piirduma !27_V	et	f	\N
149294	piirdunud	piirdunud =piirdunu  (PlN  >piirdunu !01_S	et	f	\N
149295	piirdunud	"piirdunu %piirdu  )NU_vS  <piirduma ;27_V	et	f	\N
149298	piirdunud	piirdunud =piirdunud  (ID  >piirdunud !41_A	et	f	\N
149299	piirdunud	"piirdunud %piirdu  )NUD_vA  <piirduma ;27_V	et	f	\N
149307	pildistamiseks	pildistamiseks =pildistamise  (SgTr  >pildistamine !12_S	et	f	\N
149308	pildistamiseks	"pildistamine %pildista  )MINE_vS  <pildistama ;27_V	et	f	\N
149335	hakaniemi	?hakaniemi =hakaniemi  (SgN  >hakaniemi !16_S	et	f	\N
149336	hakaniemi	?hakaniemi =hakaniemi  (SgG  >hakaniemi !16_S	et	f	\N
149337	hakaniemi	?hakaniemi =hakaniemi  (SgG  >hakaniem !19_S	et	f	\N
149338	hakaniemi	?hakaniemi =hakaniemi  (SgP  >hakaniem !19_S	et	f	\N
149339	hakaniemi	?hakaniemi =hakaniemi  (SgAdt  >hakaniem !19_S	et	f	\N
149340	hakaniemi	?hakaniemi =hakaniemi  (IndPrPs_  >hakaniemima !28_V	et	f	\N
149341	hakaniemi	?hakaniemi =hakaniemi  (ImpPrSg2  >hakaniemima !28_V	et	f	\N
149387	kae	kae =kae  (ID  >kae !41_I	et	f	\N
149388	kae	kae =kae  (SgN  >kae !26_S	et	f	\N
149389	kae	kae =kae  (SgG  >kae !26_S	et	f	\N
149390	kae	kae =kae  (IndPrPs_  >kaema !27_V	et	f	\N
149391	kae	kae =kae  (ImpPrSg2  >kaema !27_V	et	f	\N
149067	innustus	"innustus %innusta  )US_vS  <innustama ;27_V	et	f	\N
149070	naasmisele	naasmisele =naasmise  (SgAll  >naasmine !12?10_S	et	f	\N
149071	naasmisele	"naasmine %naas  )MINE_vS  <naasma ;32_V	et	f	\N
149079	sümboliseerima	sümboliseerima =sümboliseeri  (Sup  >sümboliseerima !28_V	et	f	\N
149080	sümboliseerima	sümboliseerima =rima  (SgN  >sümboli+see+rima !17_S	et	f	\N
149081	sümboliseerima	sümboliseerima =rima  (SgG  >sümboli+see+rima !17_S	et	f	\N
149082	sümboliseerima	sümboliseerima =rima  (SgP  >sümboli+see+rima !17_S	et	f	\N
149083	sümboliseerima	sümboliseerima =erima  (SgG  >sümbol+ise+erim !02_S	et	f	\N
149122	kõrghoone	kõrghoone =hoone  (SgN  >kõrg+hoone !06_S	et	f	\N
149123	kõrghoone	"kõrg+hoone %hoo  )NE_aA  <kõrg+hoog ;22_S	et	f	\N
149124	kõrghoone	kõrghoone =hoone  (SgG  >kõrg+hoone !06_S	et	f	\N
149125	kõrghoone	kõrghoone =hoone  (PlP  >kõrg+hoon !22_A	et	f	\N
149169	hakaks	?hakaks =haka  (SgTr  >haka !16_S	et	f	\N
149170	hakaks	?hakaks =haka  (KndPrPs  >hakama !27_V	et	f	\N
149195	erakonnana	erakonnana =erakonna  (SgEs  >erakond !22_S	et	f	\N
149196	erakonnana	erakonnana =konna  (SgEs  >era+konn !22_S	et	f	\N
149230	helsingit	?helsingit =helsingi  (SgP  >helsing !02_S	et	f	\N
149238	pildiarhiivi	pildiarhiivi =arhiivi  (SgG  >pildi+arhiiv !22_S	et	f	\N
149240	pildiarhiivi	pildiarhiivi =arhiivi  (SgP  >pildi+arhiiv !22_S	et	f	\N
149242	pildiarhiivi	pildiarhiivi =arhiivi  (SgAdt  >pildi+arhiiv !22_S	et	f	\N
149263	pildistamispaikadest	?pildistamispaikadest =pildistamispaika  (PlEl  >pildistamispaika !16_S	et	f	\N
149264	pildistamispaikadest	?pildistamispaikadest =pildistamispaikades  (SgP  >pildistamispaikadene !12_A	et	f	\N
149265	pildistamispaikadest	?pildistamispaikadest =stamispaika  (PlEl  >pildi+stamispaika !16_S	et	f	\N
149266	pildistamispaikadest	?pildistamispaikadest =stamispaikades  (SgP  >pildi+stamispaikadene !12_A	et	f	\N
149272	pildistajaks	pildistajaks =pildistaja  (SgTr  >pildistaja !01_S	et	f	\N
149273	pildistajaks	"pildistaja %pildista  )JA_vS  <pildistama ;27_V	et	f	\N
149281	joonistuseõpetajaks	?joonistuseõpetajaks =joonistuseõpetaja  (SgTr  >joonistuseõpetaja !01_S	et	f	\N
149282	joonistuseõpetajaks	?joonistuseõpetajaks =joonistuseõpetaja  (SgTr  >joonistuseõpetajas !02_A	et	f	\N
149283	joonistuseõpetajaks	?joonistuseõpetajaks =tuseõpetaja  (SgTr  >joonis+tuseõpetaja !01_S	et	f	\N
149284	joonistuseõpetajaks	?joonistuseõpetajaks =tuseõpetaja  (SgTr  >joonis+tuseõpetajas !02_A	et	f	\N
149301	möödujaid	möödujaid =mööduja  (PlP  >mööduja !01_S	et	f	\N
149302	möödujaid	"mööduja %möödu  )JA_vS  <mööduma ;27_V	et	f	\N
149319	kõndiv	kõndiv =kõndi  (PtsPrPs  >kõndima !28_V	et	f	\N
149320	kõndiv	kõndiv =kõndiv  (SgN  >kõndiv !02_A	et	f	\N
149321	kõndiv	"kõndiv %kõndi  )V_vA  <kõndima ;28_V	et	f	\N
149327	liikudes	liikudes =liiku  (PlIn  >liik !22_S	et	f	\N
149328	liikudes	liikudes =liiku  (Ger  >liikuma !28_V	et	f	\N
149344	kamppi	?kamppi =kamppi  (SgN  >kamppi !01_S	et	f	\N
149345	kamppi	?kamppi =kamppi  (SgG  >kamppi !01_S	et	f	\N
149346	kamppi	?kamppi =kamppi  (SgG  >kampp !22_S	et	f	\N
149347	kamppi	?kamppi =kamppi  (SgP  >kampp !22_S	et	f	\N
149348	kamppi	?kamppi =kamppi  (SgAdt  >kampp !22_S	et	f	\N
149349	kamppi	?kamppi =kamppi  (IndPrPs_  >kamppima !28_V	et	f	\N
149350	kamppi	?kamppi =kamppi  (ImpPrSg2  >kamppima !28_V	et	f	\N
149353	vaadatud	vaadatud =vaada  (PtsPtIps  >vaatama !29_V	et	f	\N
149354	vaadatud	vaadatud =vaadatu  (PlN  >vaadatu !01_S	et	f	\N
149355	vaadatud	"vaadatu %vaada  )TU1_vS  <vaatama ;29_V	et	f	\N
149356	vaadatud	vaadatud =vaadatud  (ID  >vaadatud !41_A	et	f	\N
149357	vaadatud	"vaadatud %vaada  )TUD_vA  <vaatama ;29_V	et	f	\N
149360	otsustavalt	otsustavalt =otsustava  (SgAbl  >otsustav !02_A	et	f	\N
149361	otsustavalt	"otsustav %otsusta  )V_vA  <otsustama ;27_V	et	f	\N
149362	otsustavalt	otsustavalt =otsustavalt  (ID  >otsustavalt !41_D	et	f	\N
149363	otsustavalt	"otsustavalt %otsusta  )VALT_mD  <otsustama ;27_V	et	f	\N
149364	otsustavalt	"otsustavalt %otsustava  )LT_mD  <otsustav ;02_A	et	f	\N
149365	otsustavalt	otsustavalt =ustava  (SgAbl  >ots+ustav !02_A	et	f	\N
149366	otsustavalt	"ots+ustavalt %ustava  )LT_mD  <ots+ustav ;02_A	et	f	\N
149372	asemele	asemele =aseme  (SgAll  >ase !04_S	et	f	\N
149373	asemele	asemele =asemele  (ID  >asemele !41_DK	et	f	\N
149377	mitmeks	mitmeks =mitme  (SgTr  >mitu !05_P	et	f	\N
149378	mitmeks	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
149384	mõisasid	?mõisasid =mõisa  (PlP  >mõisa !16_S	et	f	\N
149385	mõisasid	?mõisasid =mõisa  (IndIpfSg2  >mõisama !29_V	et	f	\N
149386	mõisasid	?mõisasid =mõisa  (IndIpfPl3  >mõisama !29_V	et	f	\N
149458	planeeringu	?planeeringu =planeeringu  (SgG  >planeering !02_S	et	f	\N
149459	planeeringu	?planeeringu =planeeringu  (IndPrPs_  >planeeringuma !27_V	et	f	\N
149460	planeeringu	?planeeringu =planeeringu  (ImpPrSg2  >planeeringuma !27_V	et	f	\N
149467	pildistamisest	pildistamisest =pildistamise  (SgEl  >pildistamine !12_S	et	f	\N
149469	pildistamisest	"pildistamine %pildista  )MINE_vS  <pildistama ;27_V	et	f	\N
149484	algelise	algelise =algelise  (SgG  >algeline !12_A	et	f	\N
149485	algelise	"algeline %alge  )LINE_aA  <alge ;06_S	et	f	\N
149491	elulisuse	elulisuse =elulisuse  (SgG  >elulisus !11?09_S	et	f	\N
149492	elulisuse	"elulisus %elu  )LISUS_aS  <elu ;17_S	et	f	\N
149075	ringikäimist	ringikäimist =käimis  (SgP  >ringi+käimine !12?10_S	et	f	\N
149076	ringikäimist	"ringi+käimine %käimi  )NE_aA  <ringi+käim ;22_S	et	f	\N
149087	eal	eal =ea  (SgAd  >iga !18_S	et	f	\N
149088	eal	eal =eal  (ID  >eal !41_D	et	f	\N
149093	üksainus	üksainus =ainu  (SgIn  >üks+ainus !07_AS	et	f	\N
149094	üksainus	üksainus =ainu  (SgIn  >üks+ainu !16_S	et	f	\N
149095	üksainus	üksainus =ainu  (PlIn  >üks+ain !22_S	et	f	\N
149096	üksainus	üksainus =ainus  (SgN  >üks+ainus !03~05_AS	et	f	\N
149097	üksainus	üksainus =ainus  (SgN  >üks+ainus !07_AS	et	f	\N
149100	kujuprojekti	kujuprojekti =projekti  (SgG  >kuju+projekt !22_S	et	f	\N
149101	kujuprojekti	kujuprojekti =projekti  (SgP  >kuju+projekt !22_S	et	f	\N
149102	kujuprojekti	kujuprojekti =projekti  (SgAdt  >kuju+projekt !22_S	et	f	\N
149111	miite	?miite =miite  (SgN  >miite !06_S	et	f	\N
149112	miite	?miite =miite  (SgG  >miide !06_S	et	f	\N
149113	miite	?miite =miite  (PlP  >miit !22_S	et	f	\N
149114	miite	?miite =miite  (IndPrPs_  >miitema !27_V	et	f	\N
149115	miite	?miite =miite  (ImpPrSg2  >miitema !27_V	et	f	\N
149126	meetrine	meetrine =meetrine  (SgN  >meetrine !12~10_A	et	f	\N
149127	meetrine	"meetrine %meetri  )NE_aA  <meeter ;02_S	et	f	\N
149135	vastava	vastava =vastava  (SgG  >vastav !02_A	et	f	\N
149136	vastava	"vastav %vasta  )V_vA  <vastama ;29_V	et	f	\N
149137	vastava	vastava =ava  (SgN  >vast+ava !17_S	et	f	\N
149138	vastava	vastava =ava  (SgG  >vast+ava !17_S	et	f	\N
149139	vastava	vastava =ava  (SgP  >vast+ava !17_S	et	f	\N
149153	sõltumatuks	sõltumatuks =sõltumatu  (SgTr  >sõltumatu !01_A	et	f	\N
149154	sõltumatuks	"sõltumatu %sõltu  )MATU_vA  <sõltuma ;27_V	et	f	\N
149155	maastikuarhitket	### maastikuarhitket	et	f	\N
149163	kalevipoeg-projekti	kalevipoeg-projekti =projekti  (SgG  >kalevipoeg-projekt !22_S	et	f	\N
149164	kalevipoeg-projekti	kalevipoeg-projekti =projekti  (SgP  >kalevipoeg-projekt !22_S	et	f	\N
149165	kalevipoeg-projekti	kalevipoeg-projekti =projekti  (SgAdt  >kalevipoeg-projekt !22_S	et	f	\N
149197	ennegi	ennegi =ennegi  (ID  >ennegi !41_D	et	f	\N
149198	ennegi	ennegi =enne  (ID^  >enne !41_DK	et	f	\N
149199	ennegi	ennegi =enne  (SgN^  >enne !06_S	et	f	\N
149206	turundanud	?turundanud =turunda  (PtsPtPs  >turundama !27_V	et	f	\N
149207	turundanud	?turundanud =turundanu  (PlN  >turundanu !01_S	et	f	\N
149208	turundanud	?turundanud =turundanu  (IndPrSg2  >turundanuma !27_V	et	f	\N
149209	turundanud	?turundanud =turundanud  (ID  >turundanud !41_A	et	f	\N
149210	neidu	neidu =neidu  (SgP  >neid !22_S	et	f	\N
149211	neidu	neidu =neidu  (SgAdt  >neid !22_S	et	f	\N
149224	ülesannet	ülesannet =anne  (SgP  >üles+anne !05_S	et	f	\N
149225	ülesannet	ülesannet =anne  (SgP  >üles+anne !06_S	et	f	\N
149226	tagantjärgi	tagantjärgi =järgi  (SgG  >tagant+järk !22_S	et	f	\N
149227	tagantjärgi	tagantjärgi =järgi  (SgP  >tagant+järg !22_S	et	f	\N
149228	tagantjärgi	tagantjärgi =järgi  (SgAdt  >tagant+järg !22_S	et	f	\N
149229	tagantjärgi	tagantjärgi =järgi  (PlP  >tagant+järg !22_S	et	f	\N
149253	helsingi-teemalise	helsingi-teemalise =teemalise  (SgG  >helsingi-teemaline !12_A	et	f	\N
149254	helsingi-teemalise	"helsingi-teemaline %teema  )LINE_aA  <helsingi-teema ;16_S	et	f	\N
149255	helsingi-teemalise	helsingi-teemalise =malise  (SgG  >helsingi-tee+maline !10_A	et	f	\N
149256	helsingi-teemalise	"helsingi-tee+maline %mali  )NE_aA  <helsingi-tee+mali ;17_S	et	f	\N
149257	vaevalt	vaevalt =vaeva  (SgAbl  >vaev !22_S	et	f	\N
149258	vaevalt	vaevalt =vaevalt  (ID  >vaevalt !41_D	et	f	\N
149267	kahekororuselised	?kahekororuselised =kahekororuselise  (PlN  >kahekororuseline !12_A	et	f	\N
149268	kahekororuselised	?kahekororuselised =kororuselise  (PlN  >kahe+kororuseline !12_A	et	f	\N
149269	pakarineni	?pakarineni =pakarineni  (SgG  >pakarinen !19_S	et	f	\N
149270	pakarineni	?pakarineni =pakarineni  (SgP  >pakarinen !19_S	et	f	\N
149271	pakarineni	?pakarineni =pakarineni  (SgAdt  >pakarinen !19_S	et	f	\N
149329	sightseeingul	?sightseeingul =sightseeingu  (SgAd  >sightseeing !02_S	et	f	\N
149330	sightseeingul	?sightseeingul =sightseeingul  (SgN  >sightseeingul !02_S	et	f	\N
149351	originaalkaart	originaalkaart =kaar  (SgP  >originaal+kaar !13_S	et	f	\N
149352	originaalkaart	originaalkaart =kaart  (SgN  >originaal+kaart !22_S	et	f	\N
149382	dokumenteerimine	dokumenteerimine =dokumenteerimine  (SgN  >dokumenteerimine !12_S	et	f	\N
149383	dokumenteerimine	"dokumenteerimine %dokumenteeri  )MINE_vS  <dokumenteerima ;28_V	et	f	\N
149394	nikkilässe	?nikkilässe =nikkilässe  (SgG  >nikkiläsne !02_A	et	f	\N
149395	nikkilässe	?nikkilässe =nikkilässe  (PlP  >nikkiläss !22_S	et	f	\N
149400	väidetud	väidetud =väide  (PtsPtIps  >väitma !34_V	et	f	\N
149401	väidetud	väidetud =väidetu  (PlN  >väidetu !01_AS	et	f	\N
149402	väidetud	"väidetu %väide  )TU1_vS  <väitma ;34_V	et	f	\N
149404	väidetud	väidetud =väidetud  (ID  >väidetud !41_A	et	f	\N
149406	väidetud	"väidetud %väide  )TUD_vA  <väitma ;34_V	et	f	\N
149408	aastakümne	?aastakümne =aastakümne  (SgN  >aastakümne !02_A	et	f	\N
149409	aastakümne	?aastakümne =aastakümne  (PlP  >aastakümn !22_S	et	f	\N
149410	aastakümne	?aastakümne =kümne  (SgN  >aasta+kümne !02_A	et	f	\N
149411	aastakümne	?aastakümne =kümne  (PlP  >aasta+kümn !22_S	et	f	\N
149121	sõtniki	?sõtniki =sõtniki  (ImpPrSg2  >sõtnikkima !28_V	et	f	\N
149161	turundama	?turundama =turunda  (Sup  >turundama !27_V	et	f	\N
149162	turundama	?turundama =turundama  (SgG  >turundam !02_A	et	f	\N
149166	kompleksi	kompleksi =kompleksi  (SgG  >kompleks !22_S	et	f	\N
149167	kompleksi	kompleksi =kompleksi  (SgP  >kompleks !22_S	et	f	\N
149168	kompleksi	kompleksi =kompleksi  (SgAdt  >kompleks !22_S	et	f	\N
149182	kättega	?kättega =kätte  (SgKom  >käte !06_S	et	f	\N
149193	inimsekujud	?inimsekujud =inimsekuju  (IndPrSg2  >inimsekujuma !27_V	et	f	\N
149194	inimsekujud	?inimsekujud =sekuju  (PlN  >inim+sekuju !01_S	et	f	\N
149215	kaduvat	kaduvat =kadu  (KvtPrPs  >kaduma !28_V	et	f	\N
149216	kaduvat	kaduvat =kaduva  (SgP  >kaduv !02_A	et	f	\N
149217	kaduvat	"kaduv %kadu  )V_vA  <kaduma ;28_V	et	f	\N
149262	planeering	?planeering =planeering  (SgN  >planeering !02_S	et	f	\N
149309	heatujulistest	heatujulistest =tujulis  (PlEl  >hea+tujuline !12_A	et	f	\N
149310	heatujulistest	"hea+tujuline %tuju  )LINE_aA  <hea+tuju ;17_S	et	f	\N
149317	raudteed	raudteed =tee  (PlN  >raud+tee !26_S	et	f	\N
149318	raudteed	raudteed =tee  (SgP  >raud+tee !26_S	et	f	\N
149322	korrastatud	korrastatud =korrasta  (PtsPtIps  >korrastama !27_V	et	f	\N
149323	korrastatud	korrastatud =korrastatu  (PlN  >korrastatu !01_S	et	f	\N
149324	korrastatud	"korrastatu %korrasta  )TU1_vS  <korrastama ;27_V	et	f	\N
149325	korrastatud	korrastatud =korrastatud  (ID  >korrastatud !41_A	et	f	\N
149326	korrastatud	"korrastatud %korrasta  )TUD_vA  <korrastama ;27_V	et	f	\N
149358	nüüdislugeja	nüüdislugeja =lugeja  (SgN  >nüüdis+lugeja !01_S	et	f	\N
149359	nüüdislugeja	nüüdislugeja =lugeja  (SgG  >nüüdis+lugeja !01_S	et	f	\N
149367	tülli	tülli =tülli  (ID  >tülli !41_D	et	f	\N
149368	tülli	tülli =tülli  (SgG  >tüll !22_S	et	f	\N
149369	tülli	tülli =tülli  (SgP  >tüll !22_S	et	f	\N
149370	tülli	tülli =tülli  (SgAdt  >tüli !17_S	et	f	\N
149371	tülli	tülli =tülli  (SgAdt  >tüll !22_S	et	f	\N
149379	aastakümneks	?aastakümneks =aastakümne  (PlTr  >aastakümn !22_S	et	f	\N
149380	aastakümneks	?aastakümneks =kümne  (PlTr  >aasta+kümn !22_S	et	f	\N
149381	aastakümneks	?aastakümneks =takümne  (PlTr  >aas+takümn !22_S	et	f	\N
149414	äratasid	äratasid =ärata  (IndIpfSg2  >äratama !27_V	et	f	\N
149415	äratasid	äratasid =ärata  (IndIpfPl3  >äratama !27_V	et	f	\N
149441	terviklikult	terviklikult =tervikliku  (SgAbl  >terviklik !25_A	et	f	\N
149442	terviklikult	terviklikult =terviklikult  (ID  >terviklikult !41_D	et	f	\N
149443	terviklikult	"terviklikult %tervikliku  )LT_mD  <terviklik ;25_A	et	f	\N
149446	helsingiteemalist	?helsingiteemalist =helsingiteemali  (SgEl  >helsingiteemal !02_S	et	f	\N
149447	helsingiteemalist	?helsingiteemalist =helsingiteemalis  (SgP  >helsingiteemalis !09_S	et	f	\N
149448	helsingiteemalist	?helsingiteemalist =helsingiteemalis  (SgP  >helsingiteemaline !12_A	et	f	\N
149449	helsingiteemalist	?helsingiteemalist =helsingiteemalist  (SgN  >helsingiteemalist !22_S	et	f	\N
149461	ehitamine	ehitamine =ehitamine  (SgN  >ehitamine !12_S	et	f	\N
149462	ehitamine	"ehitamine %ehita  )MINE_vS  <ehitama ;27_V	et	f	\N
149470	parkanis	?parkanis =parkani  (SgIn  >parkan !02_S	et	f	\N
149472	parkanis	?parkanis =parkanis  (SgN  >parkanis !11_S	et	f	\N
149474	parkanis	?parkanis =ani  (SgIn  >park+ani !17_S	et	f	\N
149475	parkanis	?parkanis =anis  (SgN  >park+anis !09_S	et	f	\N
149483	bander	?bander =bander  (SgN  >bander !02_S	et	f	\N
149493	saladustema	?saladustema =saladustema  (SgG  >saladustem !02_A	et	f	\N
149494	saladustema	?saladustema =dustema  (SgG  >sala+dustem !02_A	et	f	\N
149543	fotograafitööd	?fotograafitööd =fotograafitöö  (PlN  >fotograafitöö !26_S	et	f	\N
149544	fotograafitööd	?fotograafitööd =fotograafitöö  (SgP  >fotograafitöö !26_S	et	f	\N
149545	fotograafitööd	?fotograafitööd =fotograafitööd  (SgN  >fotograafitööd !22_S	et	f	\N
149546	fotograafitööd	?fotograafitööd =graafitöö  (PlN  >foto+graafitöö !26_S	et	f	\N
149547	fotograafitööd	?fotograafitööd =graafitöö  (SgP  >foto+graafitöö !26_S	et	f	\N
149548	fotograafitööd	?fotograafitööd =graafitööd  (SgN  >foto+graafitööd !22_S	et	f	\N
149558	siirdati	?siirdati =siirda  (IndIpfIps  >siirtama !29_V	et	f	\N
149559	siirdati	?siirdati =siirdati  (ID  >siirdati !41_D	et	f	\N
149560	siirdati	?siirdati =siirdati  (SgG  >siirdat !02_S	et	f	\N
149561	siirdati	?siirdati =siirdati  (SgG  >siirdatt !22_S	et	f	\N
149562	siirdati	?siirdati =siirdati  (IndPrPs_  >siirdattima !28_V	et	f	\N
149563	siirdati	?siirdati =siirdati  (ImpPrSg2  >siirdattima !28_V	et	f	\N
149564	psühhoneuroloogia	psühhoneuroloogia =neuroloogia  (SgN  >psühho+neuroloogia !01_S	et	f	\N
149565	psühhoneuroloogia	psühhoneuroloogia =neuroloogia  (SgG  >psühho+neuroloogia !01_S	et	f	\N
149612	portreteerimist	portreteerimist =portreteerimis  (SgP  >portreteerimine !12_S	et	f	\N
149613	portreteerimist	"portreteerimine %portreteeri  )MINE_vS  <portreteerima ;28_V	et	f	\N
149641	erimeelsuse	erimeelsuse =meelsuse  (SgG  >eri+meelsus !11~09_S	et	f	\N
149642	erimeelsuse	"eri+meelsus %meelse  )US_aS  <eri+meelne ;02_A	et	f	\N
149651	tulenenud	tulenenud =tulene  (PtsPtPs  >tulenema !27_V	et	f	\N
149652	tulenenud	tulenenud =tulenenu  (PlN  >tulenenu !01_S	et	f	\N
149653	tulenenud	"tulenenu %tulene  )NU_vS  <tulenema ;27_V	et	f	\N
149203	eelistanud	eelistanud =eelistanud  (ID  >eelistanud !41_A	et	f	\N
149204	eelistanud	"eelistanud %eelista  )NUD_vA  <eelistama ;27_V	et	f	\N
149205	eelistanud	eelistanud =tanu  (PlN  >eelis+tanu !17_S	et	f	\N
149212	aastakümnega	### aastakümnega	et	f	\N
149213	ergutasid	ergutasid =erguta  (IndIpfSg2  >ergutama !27_V	et	f	\N
149214	ergutasid	ergutasid =erguta  (IndIpfPl3  >ergutama !27_V	et	f	\N
149221	muinsuskaitsekomisjoni	muinsuskaitsekomisjoni =komisjoni  (SgG  >muinsus+kaitse+komisjon !19_S	et	f	\N
149222	muinsuskaitsekomisjoni	muinsuskaitsekomisjoni =komisjoni  (SgP  >muinsus+kaitse+komisjon !19_S	et	f	\N
149223	muinsuskaitsekomisjoni	muinsuskaitsekomisjoni =komisjoni  (SgAdt  >muinsus+kaitse+komisjon !19_S	et	f	\N
149231	linnaummseumi	?linnaummseumi =linnaummseumi  (SgN  >linnaummseumi !16_S	et	f	\N
149232	linnaummseumi	?linnaummseumi =linnaummseumi  (SgG  >linnaummseum !19~02_S	et	f	\N
149233	linnaummseumi	?linnaummseumi =linnaummseumi  (SgG  >linnaummseumi !16_S	et	f	\N
149234	linnaummseumi	?linnaummseumi =linnaummseumi  (SgP  >linnaummseum !19_S	et	f	\N
149235	linnaummseumi	?linnaummseumi =linnaummseumi  (SgAdt  >linnaummseum !19_S	et	f	\N
149236	linnaummseumi	?linnaummseumi =linnaummseumi  (IndPrPs_  >linnaummseumima !28_V	et	f	\N
149237	linnaummseumi	?linnaummseumi =linnaummseumi  (ImpPrSg2  >linnaummseumima !28_V	et	f	\N
149239	linnaummseumi	?linnaummseumi =ummseumi  (SgN  >linna+ummseumi !01_S	et	f	\N
149241	linnaummseumi	?linnaummseumi =ummseumi  (SgG  >linna+ummseumi !01_S	et	f	\N
149243	linnaummseumi	?linnaummseumi =ummseumi  (SgG  >linna+ummseum !22_S	et	f	\N
149244	linnaummseumi	?linnaummseumi =ummseumi  (SgP  >linna+ummseum !22_S	et	f	\N
149245	linnaummseumi	?linnaummseumi =ummseumi  (SgAdt  >linna+ummseum !22_S	et	f	\N
149246	linnaummseumi	?linnaummseumi =aummseumi  (SgN  >linn+aummseumi !01_S	et	f	\N
149247	linnaummseumi	?linnaummseumi =aummseumi  (SgG  >linn+aummseumi !01_S	et	f	\N
149248	linnaummseumi	?linnaummseumi =aummseumi  (SgG  >linn+aummseum !22_S	et	f	\N
149249	linnaummseumi	?linnaummseumi =aummseumi  (SgP  >linn+aummseum !22_S	et	f	\N
149250	linnaummseumi	?linnaummseumi =aummseumi  (SgAdt  >linn+aummseum !22_S	et	f	\N
149251	parima	parima =parima  (SgG  >parim !02_A	et	f	\N
149252	parima	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
149259	juhatusel	juhatusel =juhatuse  (SgAd  >juhatus !11_S	et	f	\N
149260	juhatusel	"juhatus %juhata  )US_vS  <juhatama ;27_V	et	f	\N
149261	juhatusel	"juhatus %juha  )TUS2_aS  <juha ;17_S	et	f	\N
149274	etableerunud	?etableerunud =etableeru  (PtsPtPs  >etableeruma !27_V	et	f	\N
149275	etableerunud	?etableerunud =etableerunu  (PlN  >etableerunu !01_S	et	f	\N
149276	etableerunud	?etableerunud =etableerunu  (IndPrSg2  >etableerunuma !27_V	et	f	\N
149277	etableerunud	?etableerunud =etableerunud  (ID  >etableerunud !41_A	et	f	\N
149290	osavalt	osavalt =osava  (SgAbl  >osav !02_A	et	f	\N
149291	osavalt	osavalt =osavalt  (ID  >osavalt !41_D	et	f	\N
149292	osavalt	"osavalt %osava  )LT_mD  <osav ;02_A	et	f	\N
149296	elutu	elutu =elutu  (SgN  >elutu !01_A	et	f	\N
149297	elutu	"elutu %elu  )TU2_kA  <elu ;17_S	et	f	\N
149300	elutu	elutu =elutu  (SgG  >elutu !01_A	et	f	\N
149303	sata	?sata =sata  (SgN  >sata !16_S	et	f	\N
149304	sata	?sata =sata  (SgG  >sata !16_S	et	f	\N
149305	sata	?sata =sata  (IndPrPs_  >satama !27_V	et	f	\N
149306	sata	?sata =sata  (ImpPrSg2  >satama !27_V	et	f	\N
149311	naissoost	naissoost =soo  (SgEl  >nais+sugu !18_S	et	f	\N
149312	naissoost	naissoost =soo  (SgEl  >nais+soo !26_S	et	f	\N
149313	maastikufotograaf	maastikufotograaf =graaf  (SgN  >maas+tiku+foto+graaf !22_S	et	f	\N
149314	maastikufotograaf	maastikufotograaf =fotograaf  (SgN  >maas+tiku+fotograaf !22_S	et	f	\N
149315	detailiks	detailiks =detaili  (SgTr  >detail !22_S	et	f	\N
149316	detailiks	detailiks =iks  (SgN  >detail+iks !22_S	et	f	\N
149331	hermannist	?hermannist =hermanni  (SgEl  >hermanni !01_S	et	f	\N
149332	hermannist	?hermannist =hermanni  (SgEl  >hermann !22_S	et	f	\N
149333	hermannist	?hermannist =hermannis  (SgP  >hermannis !11_S	et	f	\N
149334	hermannist	?hermannist =hermannist  (SgN  >hermannist !22_S	et	f	\N
149342	lõunapoolsetesse	lõunapoolsetesse =sete  (PlIll  >lõuna+pool+sett !22_S	et	f	\N
149343	lõunapoolsetesse	lõunapoolsetesse =poolse  (PlIll  >lõuna+poolne !02_A	et	f	\N
149374	katkes	katkes =katke  (SgIn  >katke !06_S	et	f	\N
149375	katkes	katkes =katke  (PlIn  >katk !22_S	et	f	\N
149376	katkes	katkes =katke  (IndIpfSg3  >katkema !27_V	et	f	\N
149407	baranderi	?baranderi =baranderi  (SgG  >barander !02_S	et	f	\N
149416	otsustajad	otsustajad =otsustaja  (PlN  >otsustaja !01_S	et	f	\N
149417	otsustajad	"otsustaja %otsusta  )JA_vS  <otsustama ;27_V	et	f	\N
149426	fotoahiivi	?fotoahiivi =fotoahiivi  (SgN  >fotoahiivi !16_S	et	f	\N
149427	fotoahiivi	?fotoahiivi =fotoahiivi  (SgG  >fotoahiivi !16_S	et	f	\N
149428	fotoahiivi	?fotoahiivi =fotoahiivi  (SgG  >fotoahiiv !22_S	et	f	\N
149429	fotoahiivi	?fotoahiivi =fotoahiivi  (SgP  >fotoahiiv !22_S	et	f	\N
149430	fotoahiivi	?fotoahiivi =fotoahiivi  (SgAdt  >fotoahiiv !22_S	et	f	\N
149431	fotoahiivi	?fotoahiivi =fotoahiivi  (IndPrPs_  >fotoahiivima !28_V	et	f	\N
149432	fotoahiivi	?fotoahiivi =fotoahiivi  (ImpPrSg2  >fotoahiivima !28_V	et	f	\N
149433	fotoahiivi	?fotoahiivi =ivi  (SgN  >foto+ahi+ivi !17_S	et	f	\N
149392	1930ndatel	?ndatel =ndate  (PlAd  >ndatt !22_S	et	f	\N
149393	1930ndatel	?ndatel =ndatel  (SgN  >ndatel !02_S	et	f	\N
149396	tervisest	tervisest =tervise  (SgEl  >tervis !09~11_S	et	f	\N
149397	tervisest	tervisest =tervises  (SgP  >tervisene !12_A	et	f	\N
149398	tervisest	"tervisene %tervise  )NE_aA  <tervis ;09_S	et	f	\N
149399	tervisest	"tervisene %tervise  )NE_aA  <tervis ;11_S	et	f	\N
149403	ebaselgetes	ebaselgetes =e  (PlIn  >eba+selg+esi !15_S	et	f	\N
149405	ebaselgetes	ebaselgetes =selge  (PlIn  >eba+selge !01_A	et	f	\N
149444	parimat	parimat =parima  (SgP  >parim !02_A	et	f	\N
149445	parimat	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
149450	avaldatud	avaldatud =avalda  (PtsPtIps  >avaldama !27_V	et	f	\N
149451	avaldatud	avaldatud =avaldatu  (PlN  >avaldatu !01_S	et	f	\N
149452	avaldatud	"avaldatu %avalda  )TU1_vS  <avaldama ;27_V	et	f	\N
149453	avaldatud	avaldatud =avaldatud  (ID  >avaldatud !41_A	et	f	\N
149454	avaldatud	"avaldatud %avalda  )TUD_vA  <avaldama ;27_V	et	f	\N
149468	maastikkude	maastikkude =maastikku  (PlG  >maastik !25_S	et	f	\N
149471	maastikkude	maastikkude =ude  (SgN  >maas+tikk+ude !04_S	et	f	\N
149473	maastikkude	maastikkude =tikku  (PlG  >maas+tikk !22_S	et	f	\N
149481	alalgi	alalgi =ala  (SgAd^  >ala !17_S	et	f	\N
149482	alalgi	alalgi =alal  (ID^  >alal !41_D	et	f	\N
149486	rahuldunud	rahuldunud =rahuldu  (PtsPtPs  >rahulduma !27_V	et	f	\N
149487	rahuldunud	rahuldunud =rahuldunu  (PlN  >rahuldunu !01_S	et	f	\N
149488	rahuldunud	"rahuldunu %rahuldu  )NU_vS  <rahulduma ;27_V	et	f	\N
149489	rahuldunud	rahuldunud =rahuldunud  (ID  >rahuldunud !41_A	et	f	\N
149490	rahuldunud	"rahuldunud %rahuldu  )NUD_vA  <rahulduma ;27_V	et	f	\N
149504	helsingilaste	?helsingilaste =helsingilas  (PlG  >helsingilane !12_S	et	f	\N
149505	valjasteta	valjasteta =valjas  (PlAb  >valjas !07_S	et	f	\N
149506	valjasteta	valjasteta =valjas  (PlAb  >valjane !10_A	et	f	\N
149507	valjasteta	"valjane %valja  )NE_aA  <valjas ;07_S	et	f	\N
149511	järjekorda	järjekorda =korda  (SgP  >järje+kord !22_S	et	f	\N
149512	järjekorda	järjekorda =korda  (SgAdt  >järje+kord !22_S	et	f	\N
149513	liiguks	liiguks =liigu  (SgTr  >liik !22_S	et	f	\N
149514	liiguks	liiguks =liigu  (KndPrPs  >liikuma !28_V	et	f	\N
149515	liiguks	liiguks =uks  (SgN  >liig+uks !14_S	et	f	\N
149529	aastalprotokollides	?aastalprotokollides =aastalprotokolli  (PlIn  >aastalprotokoll !22_S	et	f	\N
149530	aastalprotokollides	?aastalprotokollides =aastalprotokolli  (Ger  >aastalprotokollima !28_V	et	f	\N
149531	aastalprotokollides	?aastalprotokollides =talprotokolli  (PlIn  >aas+talprotokoll !22_S	et	f	\N
149534	pildistamised	pildistamised =pildistamise  (PlN  >pildistamine !12_S	et	f	\N
149535	pildistamised	"pildistamine %pildista  )MINE_vS  <pildistama ;27_V	et	f	\N
149536	aastakümneteks	?aastakümneteks =aastakümnete  (PlTr  >aastakümnett !22_S	et	f	\N
149537	aastakümneteks	?aastakümneteks =kümnete  (PlTr  >aasta+kümnett !22_S	et	f	\N
149538	aastakümneteks	?aastakümneteks =takümnete  (PlTr  >aas+takümnett !22_S	et	f	\N
149551	nägemine	nägemine =nägemine  (SgN  >nägemine !12_S	et	f	\N
149552	nägemine	"nägemine %näge  )MINE_vS  <nägema ;28_V	et	f	\N
149566	meeltesegadusest	meeltesegadusest =segaduse  (SgEl  >meelte+segadus !11_S	et	f	\N
149567	meeltesegadusest	meeltesegadusest =segaduses  (SgP  >meelte+segadusene !12_A	et	f	\N
149568	meeltesegadusest	"meelte+segadusene %segaduse  )NE_aA  <meelte+segadus ;11_S	et	f	\N
149573	kaduva	kaduva =kaduva  (SgG  >kaduv !02_A	et	f	\N
149574	kaduva	"kaduv %kadu  )V_vA  <kaduma ;28_V	et	f	\N
149587	linnafotograafia	linnafotograafia =fotograafia  (SgN  >linna+fotograafia !01_S	et	f	\N
149588	linnafotograafia	linnafotograafia =fotograafia  (SgG  >linna+fotograafia !01_S	et	f	\N
149593	linnaosi	linnaosi =osi  (SgN  >linna+osi !24_S	et	f	\N
149594	linnaosi	linnaosi =osi  (PlP  >linna+osa !17_S	et	f	\N
149602	andekust	andekust =andekus  (SgP  >andekus !11_S	et	f	\N
149603	andekust	"andekus %andeka  )US_aS  <andekas ;02_A	et	f	\N
149604	andekust	andekust =kus  (SgP  >ande+kusi !20_S	et	f	\N
149624	rõõmsameelsusest	rõõmsameelsusest =meelsuse  (SgEl  >rõõmsa+meelsus !11~09_S	et	f	\N
149625	rõõmsameelsusest	"rõõmsa+meelsus %meelse  )US_aS  <rõõmsa+meelne ;02_A	et	f	\N
149626	rõõmsameelsusest	rõõmsameelsusest =meelsuses  (SgP  >rõõmsa+meelsusene !12_A	et	f	\N
149627	rõõmsameelsusest	"rõõmsa+meelsusene %meelsuse  )NE_aA  <rõõmsa+meelsus ;09_S	et	f	\N
149628	rõõmsameelsusest	"rõõmsa+meelsusene %meelsuse  )NE_aA  <rõõmsa+meelsus ;11_S	et	f	\N
149636	kruununhaka	?kruununhaka =kruununhaka  (SgN  >kruununhaka !16_S	et	f	\N
149637	kruununhaka	?kruununhaka =kruununhaka  (SgG  >kruununhakas !02_A	et	f	\N
149638	kruununhaka	?kruununhaka =kruununhaka  (SgG  >kruununhaka !16_S	et	f	\N
149656	pildistaja	pildistaja =pildistaja  (SgN  >pildistaja !01_S	et	f	\N
149657	pildistaja	"pildistaja %pildista  )JA_vS  <pildistama ;27_V	et	f	\N
149658	pildistaja	pildistaja =pildistaja  (SgG  >pildistaja !01_S	et	f	\N
149684	bürokraatlikuse	bürokraatlikuse =bürokraatlikuse  (SgG  >bürokraatlikus !11?09_S	et	f	\N
149685	bürokraatlikuse	"bürokraatlikus %bürokraatliku  )US_aS  <bürokraatlik ;25_A	et	f	\N
149696	varjuta	varjuta =varju  (SgAb  >vari !24_S	et	f	\N
149697	varjuta	varjuta =varju  (IndPrIps_  >varjuma !27_V	et	f	\N
149698	varjuta	varjuta =varjuta  (IndPrPs_  >varjutama !27_V	et	f	\N
149412	aastakümne	?aastakümne =takümne  (SgN  >aas+takümne !02_A	et	f	\N
149413	aastakümne	?aastakümne =takümne  (PlP  >aas+takümn !22_S	et	f	\N
149418	kaupunginvaltuusto	?kaupunginvaltuusto =kaupunginvaltuusto  (SgN  >kaupunginvaltuusto !16_S	et	f	\N
149419	kaupunginvaltuusto	?kaupunginvaltuusto =kaupunginvaltuusto  (SgG  >kaupunginvaltuusto !16_S	et	f	\N
149420	kaupunginvaltuusto	?kaupunginvaltuusto =unginvaltuusto  (SgN  >kaup+unginvaltuusto !16_S	et	f	\N
149421	kaupunginvaltuusto	?kaupunginvaltuusto =unginvaltuusto  (SgG  >kaup+unginvaltuusto !16_S	et	f	\N
149422	muinsuskaite	?muinsuskaite =muinsuskaite  (PlP  >muinsuskait !22_S	et	f	\N
149423	muinsuskaite	?muinsuskaite =kaite  (SgN  >muinsus+kaite !06_S	et	f	\N
149424	muinsuskaite	?muinsuskaite =kaite  (SgG  >muinsus+kaide !06_S	et	f	\N
149425	muinsuskaite	?muinsuskaite =kaite  (PlP  >muinsus+kait !22_S	et	f	\N
149463	esimesl	?esimesl =esimesl  (SgN  >esimesl !22_S	et	f	\N
149464	esimesl	?esimesl =mesl  (SgN  >esi+mesl !22_S	et	f	\N
149465	kahekorruselised	kahekorruselised =korruselise  (PlN  >kahe+korruseline !12_A	et	f	\N
149466	kahekorruselised	"kahe+korruseline %korruse  )LINE_aA  <kahe+korrus ;09_S	et	f	\N
149495	möödakäijaidlapsi	?möödakäijaidlapsi =möödakäijaidlapsi  (SgG  >möödakäijaidlaps !22_S	et	f	\N
149496	möödakäijaidlapsi	?möödakäijaidlapsi =möödakäijaidlapsi  (SgP  >möödakäijaidlaps !22_S	et	f	\N
149497	möödakäijaidlapsi	?möödakäijaidlapsi =möödakäijaidlapsi  (SgAdt  >möödakäijaidlaps !22_S	et	f	\N
149499	möödakäijaidlapsi	?möödakäijaidlapsi =möödakäijaidlapsi  (IndPrPs_  >möödakäijaidlapsima !28_V	et	f	\N
149500	möödakäijaidlapsi	?möödakäijaidlapsi =möödakäijaidlapsi  (ImpPrSg2  >möödakäijaidlapsima !28_V	et	f	\N
149501	möödakäijaidlapsi	?möödakäijaidlapsi =käijaidlapsi  (SgG  >mööda+käijaidlaps !22_S	et	f	\N
149502	möödakäijaidlapsi	?möödakäijaidlapsi =käijaidlapsi  (SgP  >mööda+käijaidlaps !22_S	et	f	\N
149503	möödakäijaidlapsi	?möödakäijaidlapsi =käijaidlapsi  (SgAdt  >mööda+käijaidlaps !22_S	et	f	\N
149508	seisev	seisev =seis  (PtsPrPs  >seisma !32_V	et	f	\N
149509	seisev	seisev =seisev  (SgN  >seisev !02_A	et	f	\N
149510	seisev	"seisev %seis  )V_vA  <seisma ;32_V	et	f	\N
149516	haganieme	?haganieme =haganieme  (PlP  >haganiem !19_S	et	f	\N
149595	puuhooned	puuhooned =hoone  (PlN  >puu+hoone !06_S	et	f	\N
149596	puuhooned	"puu+hoone %hoo  )NE_aA  <puu+hoog ;22_S	et	f	\N
149605	maastiku	maastiku =maastiku  (SgG  >maastik !25_S	et	f	\N
149606	maastiku	maastiku =tiku  (SgG  >maas+tikk !22_S	et	f	\N
149648	psühhiaatriahaiglasse	psühhiaatriahaiglasse =haigla  (SgIll  >psühhiaatria+haigla !01_S	et	f	\N
149649	psühhiaatriahaiglasse	psühhiaatriahaiglasse =haiglas  (SgAdt  >psühhiaatria+haiglane !12_A	et	f	\N
149650	psühhiaatriahaiglasse	"psühhiaatria+haiglane %haigla  )NE_aA  <psühhiaatria+haigla ;01_S	et	f	\N
149670	korraldatule	korraldatule =korraldatu  (SgAll  >korraldatu !01_S	et	f	\N
149671	korraldatule	"korraldatu %korralda  )TU1_vS  <korraldama ;27_V	et	f	\N
149677	lahes	lahes =lahe  (SgIn  >laht !22_S	et	f	\N
149678	lahes	lahes =lahe  (PlIn  >lahk !22_S	et	f	\N
149682	koosseistust	koosseistust =seistu  (SgEl  >koos+seistu !01_S	et	f	\N
149683	koosseistust	koosseistust =seistus  (SgP  >koos+seistus !11~09_S	et	f	\N
149709	skulptuuriprojekti	?skulptuuriprojekti =skulptuuriprojekti  (SgG  >skulptuuriprojekt !22_S	et	f	\N
149710	skulptuuriprojekti	?skulptuuriprojekti =skulptuuriprojekti  (SgP  >skulptuuriprojekt !22_S	et	f	\N
149711	skulptuuriprojekti	?skulptuuriprojekti =skulptuuriprojekti  (SgAdt  >skulptuuriprojekt !22_S	et	f	\N
149712	skulptuuriprojekti	?skulptuuriprojekti =skulptuuriprojekti  (IndPrPs_  >skulptuuriprojektima !28_V	et	f	\N
149713	skulptuuriprojekti	?skulptuuriprojekti =skulptuuriprojekti  (ImpPrSg2  >skulptuuriprojektima !28_V	et	f	\N
149714	skulptuuriprojekti	?skulptuuriprojekti =iprojekti  (SgG  >skulptuur+iprojekt !22_S	et	f	\N
149715	skulptuuriprojekti	?skulptuuriprojekti =iprojekti  (SgP  >skulptuur+iprojekt !22_S	et	f	\N
149716	skulptuuriprojekti	?skulptuuriprojekti =iprojekti  (SgAdt  >skulptuur+iprojekt !22_S	et	f	\N
149717	kiindumust	kiindumust =kiindumus  (SgP  >kiindumus !11_S	et	f	\N
149718	kiindumust	"kiindumus %kiindu  )MUS_vS  <kiinduma ;27_V	et	f	\N
149735	lõppedes	lõppedes =lõppe  (Ger  >lõppema !27~28_V	et	f	\N
149736	lõppedes	lõppedes =ede  (SgIn  >lõpp+ede !16_S	et	f	\N
149746	tõmbasid	tõmbasid =tõmba  (IndIpfSg2  >tõmbama !29_V	et	f	\N
149747	tõmbasid	tõmbasid =tõmba  (IndIpfPl3  >tõmbama !29_V	et	f	\N
149757	kalevipoja-üritust	kalevipoja-üritust =üritus  (SgP  >kalevipoja-üritus !11_S	et	f	\N
149758	kalevipoja-üritust	"kalevipoja-üritus %ürita  )US_vS  <kalevipoja-üritama ;27_V	et	f	\N
149803	helsingi-teemalist	helsingi-teemalist =teemalis  (SgP  >helsingi-teemaline !12_A	et	f	\N
149804	helsingi-teemalist	"helsingi-teemaline %teema  )LINE_aA  <helsingi-teema ;16_S	et	f	\N
149805	helsingi-teemalist	helsingi-teemalist =mali  (SgEl  >helsingi-tee+mali !17_S	et	f	\N
149806	helsingi-teemalist	helsingi-teemalist =malis  (SgP  >helsingi-tee+maline !10_A	et	f	\N
149807	helsingi-teemalist	"helsingi-tee+maline %mali  )NE_aA  <helsingi-tee+mali ;17_S	et	f	\N
149811	portreete	?portreete =portreete  (SgN  >portreete !16_S	et	f	\N
149812	portreete	?portreete =portreete  (SgG  >portreete !16_S	et	f	\N
149813	portreete	?portreete =portreete  (PlP  >portreet !22_S	et	f	\N
149814	portreete	?portreete =reete  (SgN  >port+reete !06_S	et	f	\N
149815	portreete	?portreete =reete  (PlP  >port+reet !22_S	et	f	\N
149434	fotoahiivi	?fotoahiivi =ivi  (SgG  >foto+ahi+ivi !17_S	et	f	\N
149435	fotoahiivi	?fotoahiivi =ivi  (SgP  >foto+ahi+ivi !17_S	et	f	\N
149436	fotoahiivi	?fotoahiivi =ahiivi  (SgN  >foto+ahiivi !16_S	et	f	\N
149437	fotoahiivi	?fotoahiivi =ahiivi  (SgG  >foto+ahiivi !16_S	et	f	\N
149438	fotoahiivi	?fotoahiivi =ahiivi  (SgG  >foto+ahiiv !22_S	et	f	\N
149439	fotoahiivi	?fotoahiivi =ahiivi  (SgP  >foto+ahiiv !22_S	et	f	\N
149440	fotoahiivi	?fotoahiivi =ahiivi  (SgAdt  >foto+ahiiv !22_S	et	f	\N
149455	linnaplaneeringut	?linnaplaneeringut =linnaplaneeringu  (SgP  >linnaplaneering !02_S	et	f	\N
149456	linnaplaneeringut	?linnaplaneeringut =planeeringu  (SgP  >linna+planeering !02_S	et	f	\N
149457	linnaplaneeringut	?linnaplaneeringut =aplaneeringu  (SgP  >linn+aplaneering !02_S	et	f	\N
149476	hoolinud	hoolinud =hooli  (PtsPtPs  >hoolima !28_V	et	f	\N
149477	hoolinud	hoolinud =hoolinu  (PlN  >hoolinu !01_S	et	f	\N
149478	hoolinud	"hoolinu %hooli  )NU_vS  <hoolima ;28_V	et	f	\N
149479	hoolinud	hoolinud =hoolinud  (ID  >hoolinud !41_A	et	f	\N
149480	hoolinud	"hoolinud %hooli  )NUD_vA  <hoolima ;28_V	et	f	\N
149517	kustkohast	kustkohast =koha  (SgEl  >kust+koha !17_S	et	f	\N
149518	kustkohast	kustkohast =koha  (SgEl  >kust+koht !22_S	et	f	\N
149519	kustkohast	kustkohast =kohas  (SgP  >kust+kohane !10_A	et	f	\N
149520	kustkohast	"kust+kohane %koha  )NE_aA  <kust+koha ;17_S	et	f	\N
149521	kustkohast	"kust+kohane %koha  )NE_aA  <kust+koht ;22_S	et	f	\N
149524	tundmatuseni	tundmatuseni =tundmatuse  (SgTer  >tundmatus !11_S	et	f	\N
149525	tundmatuseni	"tundmatus %tund  )MATUS_aS  <tundma ;34_V	et	f	\N
149526	hesingilastele	?hesingilastele =hesingilas  (PlAll  >hesingilane !12_S	et	f	\N
149527	hesingilastele	?hesingilastele =hesingilastele  (IndPrPs_  >hesingilastelema !36_V	et	f	\N
149528	hesingilastele	?hesingilastele =hesingilastele  (ImpPrSg2  >hesingilastelema !36_V	et	f	\N
149539	jäädvustamine	jäädvustamine =jäädvustamine  (SgN  >jäädvustamine !12_S	et	f	\N
149540	jäädvustamine	"jäädvustamine %jäädvusta  )MINE_vS  <jäädvustama ;27_V	et	f	\N
149541	põhikohaga	põhikohaga =koha  (SgKom  >põhi+koha !17_S	et	f	\N
149542	põhikohaga	põhikohaga =koha  (SgKom  >põhi+koht !22_S	et	f	\N
149555	glaukoomi	glaukoomi =glaukoomi  (SgG  >glaukoom !22_S	et	f	\N
149556	glaukoomi	glaukoomi =glaukoomi  (SgP  >glaukoom !22_S	et	f	\N
149557	glaukoomi	glaukoomi =glaukoomi  (SgAdt  >glaukoom !22_S	et	f	\N
149569	suurenemine	suurenemine =suurenemine  (SgN  >suurenemine !12_S	et	f	\N
149570	suurenemine	"suurenemine %suurene  )MINE_vS  <suurenema ;27_V	et	f	\N
149571	linnaisad	linnaisad =isa  (PlN  >linna+isa !17_S	et	f	\N
149572	linnaisad	linnaisad =aisa  (PlN  >linn+ais !23?22_S	et	f	\N
149585	pildiraamatu	pildiraamatu =atu  (SgG  >pildi+raam+att !22_S	et	f	\N
149586	pildiraamatu	pildiraamatu =raamatu  (SgG  >pildi+raamat !02_S	et	f	\N
149618	pildistamisega	pildistamisega =pildistamise  (SgKom  >pildistamine !12_S	et	f	\N
149619	pildistamisega	"pildistamine %pildista  )MINE_vS  <pildistama ;27_V	et	f	\N
149622	heatahtlikusest	heatahtlikusest =tahtlikuse  (SgEl  >hea+tahtlikus !11_S	et	f	\N
149623	heatahtlikusest	"hea+tahtlikus %tahtliku  )US_aS  <hea+tahtlik ;25_A	et	f	\N
149629	pildistajana	pildistajana =pildistaja  (SgEs  >pildistaja !01_S	et	f	\N
149630	pildistajana	"pildistaja %pildista  )JA_vS  <pildistama ;27_V	et	f	\N
149643	plaanipärane	plaanipärane =pärane  (SgN  >plaani+pärane !10_A	et	f	\N
149644	plaanipärane	"plaani+pärane %pära  )NE_aA  <plaani+pära ;17_S	et	f	\N
149645	mõisahooneid	mõisahooneid =neid  (SgN  >mõisa+hoo+neid !22_S	et	f	\N
149646	mõisahooneid	mõisahooneid =hoone  (PlP  >mõisa+hoone !06_S	et	f	\N
149647	mõisahooneid	"mõisa+hoone %hoo  )NE_aA  <mõisa+hoog ;22_S	et	f	\N
149665	tõrjuvad	tõrjuvad =tõrju  (IndPrPl3  >tõrjuma !28_V	et	f	\N
149666	tõrjuvad	tõrjuvad =tõrjuva  (PlN  >tõrjuv !02_A	et	f	\N
149667	tõrjuvad	"tõrjuv %tõrju  )V_vA  <tõrjuma ;28_V	et	f	\N
149668	mitmekorruselise	mitmekorruselise =korruselise  (SgG  >mitme+korruseline !12_A	et	f	\N
149669	mitmekorruselise	"mitme+korruseline %korruse  )LINE_aA  <mitme+korrus ;09_S	et	f	\N
149672	langenutele	langenutele =langenu  (PlAll  >langenu !01_S	et	f	\N
149673	langenutele	"langenu %lange  )NU_vS  <langema ;27_V	et	f	\N
149674	langenutele	langenutele =nute  (PlAll  >lange+nutt !22_S	et	f	\N
149675	erimeelsused	erimeelsused =meelsuse  (PlN  >eri+meelsus !11~09_S	et	f	\N
149676	erimeelsused	"eri+meelsus %meelse  )US_aS  <eri+meelne ;02_A	et	f	\N
149679	konkursikomisjoni	konkursikomisjoni =komisjoni  (SgG  >konkursi+komisjon !19_S	et	f	\N
149680	konkursikomisjoni	konkursikomisjoni =komisjoni  (SgP  >konkursi+komisjon !19_S	et	f	\N
149681	konkursikomisjoni	konkursikomisjoni =komisjoni  (SgAdt  >konkursi+komisjon !19_S	et	f	\N
149726	tallinalahte	?tallinalahte =tallinalahte  (PlP  >tallinalaht !22_S	et	f	\N
149727	tallinalahte	?tallinalahte =nalahte  (PlP  >talli+nalaht !22_S	et	f	\N
149743	mälestusmärgikompleksi	mälestusmärgikompleksi =kompleksi  (SgG  >mälestus+märgi+kompleks !22_S	et	f	\N
149744	mälestusmärgikompleksi	mälestusmärgikompleksi =kompleksi  (SgP  >mälestus+märgi+kompleks !22_S	et	f	\N
149745	mälestusmärgikompleksi	mälestusmärgikompleksi =kompleksi  (SgAdt  >mälestus+märgi+kompleks !22_S	et	f	\N
149750	zürii	?zürii =zürii  (SgN  >zürii !26_S	et	f	\N
149751	zürii	?zürii =zürii  (SgG  >zürii !26_S	et	f	\N
149498	plitseinikke	?plitseinikke =plitseinikke  (PlP  >plitseinik !25_S	et	f	\N
149522	möödapääsmatu	möödapääsmatu =pääsmatu  (SgN  >mööda+pääsmatu !01_A	et	f	\N
149523	möödapääsmatu	möödapääsmatu =pääsmatu  (SgG  >mööda+pääsmatu !01_A	et	f	\N
149532	erimeelsuste	erimeelsuste =meelsus  (PlG  >eri+meelsus !11~09_S	et	f	\N
149533	erimeelsuste	"eri+meelsus %meelse  )US_aS  <eri+meelne ;02_A	et	f	\N
149549	mõisaidtema	?mõisaidtema =mõisaidtema  (SgG  >mõisaidtem !02_A	et	f	\N
149550	mõisaidtema	?mõisaidtema =idtema  (SgG  >mõisa+idtem !02_A	et	f	\N
149553	nõrgenesid	nõrgenesid =nõrgene  (IndIpfSg2  >nõrgenema !27_V	et	f	\N
149554	nõrgenesid	nõrgenesid =nõrgene  (IndIpfPl3  >nõrgenema !27_V	et	f	\N
149575	puuhoonetest	puuhoonetest =test  (SgN  >puu+hoone+test !22_S	et	f	\N
149576	puuhoonetest	puuhoonetest =hoone  (PlEl  >puu+hoone !06_S	et	f	\N
149577	puuhoonetest	"puu+hoone %hoo  )NE_aA  <puu+hoog ;22_S	et	f	\N
149578	fotokogu	fotokogu =kogu  (SgN  >foto+kogu !17_S	et	f	\N
149579	fotokogu	fotokogu =kogu  (SgG  >foto+kogu !17_S	et	f	\N
149580	fotokogu	fotokogu =kogu  (SgP  >foto+kogu !17_S	et	f	\N
149581	helsingist	?helsingist =helsingi  (SgEl  >helsing !02_S	et	f	\N
149582	helsingist	?helsingist =helsingi  (SgEl  >helsink !22_S	et	f	\N
149583	helsingist	?helsingist =helsingis  (SgP  >helsingis !11_S	et	f	\N
149584	helsingist	?helsingist =helsingist  (SgN  >helsingist !22_S	et	f	\N
149589	pildistamiskohtadest	?pildistamiskohtadest =pildistamiskohta  (PlEl  >pildistamiskohta !16_S	et	f	\N
149590	pildistamiskohtadest	?pildistamiskohtadest =pildistamiskohtades  (SgP  >pildistamiskohtadene !12_A	et	f	\N
149591	pildistamiskohtadest	?pildistamiskohtadest =stamiskohta  (PlEl  >pildi+stamiskohta !16_S	et	f	\N
149592	pildistamiskohtadest	?pildistamiskohtadest =stamiskohtades  (SgP  >pildi+stamiskohtadene !12_A	et	f	\N
149597	tõestanud	tõestanud =tõesta  (PtsPtPs  >tõestama !27_V	et	f	\N
149598	tõestanud	tõestanud =tõestanu  (PlN  >tõestanu !01_S	et	f	\N
149599	tõestanud	"tõestanu %tõesta  )NU_vS  <tõestama ;27_V	et	f	\N
149600	tõestanud	tõestanud =tõestanud  (ID  >tõestanud !41_A	et	f	\N
149601	tõestanud	"tõestanud %tõesta  )NUD_vA  <tõestama ;27_V	et	f	\N
149607	armastanud	armastanud =armasta  (PtsPtPs  >armastama !27_V	et	f	\N
149608	armastanud	armastanud =armastanu  (PlN  >armastanu !01_S	et	f	\N
149609	armastanud	"armastanu %armasta  )NU_vS  <armastama ;27_V	et	f	\N
149610	armastanud	armastanud =armastanud  (ID  >armastanud !41_A	et	f	\N
149611	armastanud	"armastanud %armasta  )NUD_vA  <armastama ;27_V	et	f	\N
149614	ateljeetööd	ateljeetööd =töö  (PlN  >ateljee+töö !26_S	et	f	\N
149615	ateljeetööd	ateljeetööd =töö  (SgP  >ateljee+töö !26_S	et	f	\N
149616	töötamisest	töötamisest =töötamise  (SgEl  >töötamine !12_S	et	f	\N
149617	töötamisest	"töötamine %tööta  )MINE_vS  <töötama ;27_V	et	f	\N
149620	elavaks	elavaks =elava  (SgTr  >elav !02_A	et	f	\N
149621	elavaks	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
149631	rakmedeta	?rakmedeta =rakmedeta  (IndPrPs_  >rakmedetama !27_V	et	f	\N
149632	rakmedeta	?rakmedeta =rakmedeta  (ImpPrSg2  >rakmedetama !27_V	et	f	\N
149633	uurimusretkele	uurimusretkele =retke  (SgAll  >uurimus+retk !22_S	et	f	\N
149634	uurimusretkele	uurimusretkele =retke  (PlAll  >uurimus+retk !22_S	et	f	\N
149635	liikub	### liikub	et	f	\N
149639	prokollidest	?prokollidest =prokolli  (PlEl  >prokoll !22_S	et	f	\N
149640	prokollidest	?prokollidest =prokollides  (SgP  >prokollidene !12_A	et	f	\N
149659	vaatavat	vaatavat =vaata  (KvtPrPs  >vaatama !29_V	et	f	\N
149660	vaatavat	vaatavat =vaatava  (SgP  >vaatav !02_A	et	f	\N
149661	vaatavat	"vaatav %vaata  )V_vA  <vaatama ;29_V	et	f	\N
149662	kavandatu	kavandatu =kavandatu  (SgN  >kavandatu !01_S	et	f	\N
149663	kavandatu	"kavandatu %kavanda  )TU1_vS  <kavandama ;27_V	et	f	\N
149664	kavandatu	kavandatu =kavandatu  (SgG  >kavandatu !01_S	et	f	\N
149700	galeriipidaja	galeriipidaja =pidaja  (SgN  >galerii+pidaja !01_S	et	f	\N
149701	galeriipidaja	galeriipidaja =pidaja  (SgG  >galerii+pidaja !01_S	et	f	\N
149748	zrürii	?zrürii =zrürii  (SgN  >zrürii !26_S	et	f	\N
149749	zrürii	?zrürii =zrürii  (SgG  >zrürii !26_S	et	f	\N
149765	tõrkaks	?tõrkaks =tõrka  (SgTr  >tõrka !16_S	et	f	\N
149766	tõrkaks	?tõrkaks =tõrka  (KndPrPs  >tõrkama !29_V	et	f	\N
149781	linnamaja	linnamaja =maja  (SgN  >linna+maja !17_S	et	f	\N
149782	linnamaja	linnamaja =maja  (SgG  >linna+maja !17_S	et	f	\N
149783	linnamaja	linnamaja =maja  (SgP  >linna+maja !17_S	et	f	\N
149786	legenda	?legenda =legenda  (SgN  >legenda !01_S	et	f	\N
149787	legenda	?legenda =legenda  (SgG  >legenda !01_S	et	f	\N
149788	legenda	?legenda =legenda  (IndPrPs_  >legendama !27_V	et	f	\N
149789	legenda	?legenda =legenda  (ImpPrSg2  >legendama !27_V	et	f	\N
149794	pildistajast	pildistajast =pildistaja  (SgEl  >pildistaja !01_S	et	f	\N
149795	pildistajast	"pildistaja %pildista  )JA_vS  <pildistama ;27_V	et	f	\N
149798	avalikustanud	avalikustanud =avalikusta  (PtsPtPs  >avalikustama !27_V	et	f	\N
149799	avalikustanud	avalikustanud =avalikustanu  (PlN  >avalikustanu !01_S	et	f	\N
149800	avalikustanud	"avalikustanu %avalikusta  )NU_vS  <avalikustama ;27_V	et	f	\N
149801	avalikustanud	avalikustanud =avalikustanud  (ID  >avalikustanud !41_A	et	f	\N
149802	avalikustanud	"avalikustanud %avalikusta  )NUD_vA  <avalikustama ;27_V	et	f	\N
149654	tulenenud	tulenenud =tulenenud  (ID  >tulenenud !41_A	et	f	\N
149655	tulenenud	"tulenenud %tulene  )NUD_vA  <tulenema ;27_V	et	f	\N
149686	lõpeks	lõpeks =lõpe  (PlTr  >lõpp !22_SA	et	f	\N
149687	lõpeks	lõpeks =lõpe  (KndPrPs  >lõppema !28_V	et	f	\N
149688	lõpeks	lõpeks =lõpe  (KndPrPs  >lõpma !35_V	et	f	\N
149689	kavandanud	kavandanud =kavanda  (PtsPtPs  >kavandama !27_V	et	f	\N
149690	kavandanud	kavandanud =kavandanu  (PlN  >kavandanu !01_S	et	f	\N
149691	kavandanud	"kavandanu %kavanda  )NU_vS  <kavandama ;27_V	et	f	\N
149692	kavandanud	kavandanud =kavandanud  (ID  >kavandanud !41_A	et	f	\N
149693	kavandanud	"kavandanud %kavanda  )NUD_vA  <kavandama ;27_V	et	f	\N
149694	turismitee	turismitee =tee  (SgN  >turismi+tee !26_S	et	f	\N
149695	turismitee	turismitee =tee  (SgG  >turismi+tee !26_S	et	f	\N
149702	maailmareisi	maailmareisi =reis  (PlP  >maa+ilma+reis !14_S	et	f	\N
149703	maailmareisi	maailmareisi =reisi  (SgG  >maa+ilma+reis !22_S	et	f	\N
149704	maailmareisi	maailmareisi =reisi  (SgP  >maa+ilma+reis !22_S	et	f	\N
149705	maailmareisi	maailmareisi =reisi  (SgAdt  >maa+ilma+reis !22_S	et	f	\N
149706	siümboliseerivad	?siümboliseerivad =siümboliseeri  (IndPrPl3  >siümboliseerima !28_V	et	f	\N
149707	siümboliseerivad	?siümboliseerivad =siümboliseeriva  (PlN  >siümboliseeriv !02_A	et	f	\N
149708	siümboliseerivad	?siümboliseerivad =siümboliseeriva  (PlN  >siümboliseeriva !16_S	et	f	\N
149719	pälvinud	pälvinud =pälvi  (PtsPtPs  >pälvima !28_V	et	f	\N
149720	pälvinud	pälvinud =pälvinu  (PlN  >pälvinu !01_S	et	f	\N
149721	pälvinud	"pälvinu %pälvi  )NU_vS  <pälvima ;28_V	et	f	\N
149722	pälvinud	pälvinud =pälvinud  (ID  >pälvinud !41_A	et	f	\N
149723	pälvinud	"pälvinud %pälvi  )NUD_vA  <pälvima ;28_V	et	f	\N
149728	kavatsetud	kavatsetud =kavatse  (PtsPtIps  >kavatsema !27_V	et	f	\N
149729	kavatsetud	kavatsetud =kavatsetu  (PlN  >kavatsetu !01_S	et	f	\N
149730	kavatsetud	"kavatsetu %kavatse  )TU1_vS  <kavatsema ;27_V	et	f	\N
149731	kavatsetud	kavatsetud =kavatsetud  (ID  >kavatsetud !41_A	et	f	\N
149732	kavatsetud	"kavatsetud %kavatse  )TUD_vA  <kavatsema ;27_V	et	f	\N
149733	võitlustööd	võitlustööd =töö  (PlN  >võitlus+töö !26_S	et	f	\N
149734	võitlustööd	võitlustööd =töö  (SgP  >võitlus+töö !26_S	et	f	\N
149737	vastaval	vastaval =vastava  (SgAd  >vastav !02_A	et	f	\N
149738	vastaval	"vastav %vasta  )V_vA  <vastama ;29_V	et	f	\N
149739	vastaval	vastaval =ava  (SgAd  >vast+ava !17_S	et	f	\N
149740	vastaval	vastaval =aval  (SgN  >vast+aval !02_A	et	f	\N
149752	plaaninud	plaaninud =plaani  (PtsPtPs  >plaanima !28_V	et	f	\N
149753	plaaninud	plaaninud =plaaninu  (PlN  >plaaninu !01_S	et	f	\N
149754	plaaninud	"plaaninu %plaani  )NU_vS  <plaanima ;28_V	et	f	\N
149755	plaaninud	plaaninud =plaaninud  (ID  >plaaninud !41_A	et	f	\N
149756	plaaninud	"plaaninud %plaani  )NUD_vA  <plaanima ;28_V	et	f	\N
149816	maastikke	maastikke =maastikke  (PlP  >maastik !25_S	et	f	\N
149817	maastikke	maastikke =tikke  (SgG  >maas+tike !06_S	et	f	\N
149818	maastikke	maastikke =tikke  (PlP  >maas+tikk !22_S	et	f	\N
149834	rohelise	rohelise =rohelise  (SgG  >roheline !12_A	et	f	\N
149835	rohelise	"roheline %rohe  )LINE_aA  <rohe ;16_S	et	f	\N
149875	memoriaaliga	memoriaaliga =memoriaali  (SgKom  >memoriaal !22_S	et	f	\N
149876	memoriaaliga	memoriaaliga =iga  (SgN  >memoriaal+iga !18_S	et	f	\N
149877	memoriaaliga	memoriaaliga =iga  (SgP  >memoriaal+iga !18_S	et	f	\N
149908	ulatuvaks	ulatuvaks =ulatuva  (SgTr  >ulatuv !02_A	et	f	\N
149909	ulatuvaks	"ulatuv %ulatu  )V_vA  <ulatuma ;27_V	et	f	\N
149926	sh	### sh	et	f	\N
149927	sellistest	sellistest =sellis  (PlEl  >selline !10_P	et	f	\N
149928	sellistest	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
149952	branderil	?branderil =branderi  (SgAd  >branderi !01_S	et	f	\N
149953	branderil	?branderil =branderi  (SgAd  >brander !02_S	et	f	\N
149961	müüjaid	müüjaid =müüja  (PlP  >müüja !01_S	et	f	\N
149962	müüjaid	"müüja %müü  )JA_vS  <müüma ;38_V	et	f	\N
149968	lõunapoolsete	lõunapoolsete =sete  (SgN  >lõuna+pool+sete !06_S	et	f	\N
149969	lõunapoolsete	lõunapoolsete =poolse  (PlG  >lõuna+poolne !02_A	et	f	\N
150029	lageda	?lageda =lage  (Inf  >lagema !27_V	et	f	\N
150030	lageda	?lageda =lageda  (SgG  >lage !02_A	et	f	\N
150075	1930aastatel	aastatel =aasta  (PlAd  >aasta !01_S	et	f	\N
150076	1930aastatel	aastatel =tate  (PlAd  >aas+tatt !22_S	et	f	\N
150091	impotendi	?impotendi =impotendi  (SgG  >impotent !22_S	et	f	\N
150092	impotendi	?impotendi =impotendi  (SgP  >impotend !22_S	et	f	\N
150093	impotendi	?impotendi =impotendi  (SgAdt  >impotend !22_S	et	f	\N
150094	impotendi	?impotendi =impotendi  (IndPrPs_  >impotentima !28_V	et	f	\N
150095	impotendi	?impotendi =impotendi  (ImpPrSg2  >impotentima !28_V	et	f	\N
150096	mälestuskompleksi	mälestuskompleksi =kompleksi  (SgG  >mälestus+kompleks !22_S	et	f	\N
150097	mälestuskompleksi	mälestuskompleksi =kompleksi  (SgP  >mälestus+kompleks !22_S	et	f	\N
150098	mälestuskompleksi	mälestuskompleksi =kompleksi  (SgAdt  >mälestus+kompleks !22_S	et	f	\N
150122	spaa	?spaa =spaa  (SgN  >spaa !26_S	et	f	\N
150123	spaa	?spaa =spaa  (SgG  >spaa !26_S	et	f	\N
150159	nõukogute	?nõukogute =nõukogu  (IndPrPl2  >nõukoguma !27_V	et	f	\N
149699	varjuta	varjuta =varjuta  (ImpPrSg2  >varjutama !27_V	et	f	\N
149724	järgneval	järgneval =järgneva  (SgAd  >järgnev !02_A	et	f	\N
149725	järgneval	"järgnev %järgne  )V_vA  <järgnema ;27_V	et	f	\N
149741	rannatrepikoda	rannatrepikoda =koda  (SgN  >ranna+trepi+koda !18_S	et	f	\N
149742	rannatrepikoda	rannatrepikoda =koda  (SgP  >ranna+trepi+koda !18_S	et	f	\N
149759	mereneiu	mereneiu =neiu  (SgN  >mere+neiu !16_S	et	f	\N
149760	mereneiu	mereneiu =neiu  (SgG  >mere+neiu !16_S	et	f	\N
149761	mereneiu	mereneiu =neiu  (SgG  >mere+neid !22_S	et	f	\N
149767	turismiliini	turismiliini =lii  (SgTer  >turismi+lii !26_S	et	f	\N
149768	turismiliini	turismiliini =liini  (SgG  >turismi+liin !22_S	et	f	\N
149769	turismiliini	turismiliini =liini  (SgP  >turismi+liin !22_S	et	f	\N
149770	turismiliini	turismiliini =liini  (SgAdt  >turismi+liin !22_S	et	f	\N
149771	pronksikuju	pronksikuju =kuju  (SgN  >pronksi+kuju !17_S	et	f	\N
149772	pronksikuju	pronksikuju =kuju  (SgG  >pronksi+kuju !17_S	et	f	\N
149773	pronksikuju	pronksikuju =kuju  (SgP  >pronksi+kuju !17_S	et	f	\N
149774	kujuplaani	kujuplaani =plaani  (SgG  >kuju+plaan !22_S	et	f	\N
149775	kujuplaani	kujuplaani =plaani  (SgP  >kuju+plaan !22_S	et	f	\N
149776	kujuplaani	kujuplaani =plaani  (SgAdt  >kuju+plaan !22_S	et	f	\N
149784	kunstnikkute	?kunstnikkute =kunstnikku  (PlG  >kunstnikku !01_S	et	f	\N
149785	kunstnikkute	?kunstnikkute =kunstnikku  (IndPrPl2  >kunstnikkuma !27_V	et	f	\N
149792	tuleva	tuleva =tuleva  (SgG  >tulev !02_A	et	f	\N
149793	tuleva	"tulev %tule  )V_vA  <tulema ;36_V	et	f	\N
149796	kaduvate	kaduvate =kaduva  (PlG  >kaduv !02_A	et	f	\N
149797	kaduvate	"kaduv %kadu  )V_vA  <kaduma ;28_V	et	f	\N
149833	soomet	### soomet	et	f	\N
149851	ühendus	ühendus =ühendu  (IndIpfSg3  >ühenduma !27_V	et	f	\N
149852	ühendus	ühendus =ühendus  (SgN  >ühendus !11_S	et	f	\N
149853	ühendus	"ühendus %ühenda  )US_vS  <ühendama ;27_V	et	f	\N
149854	juhtitud	?juhtitud =juhtitu  (PlN  >juhtitu !01_AS	et	f	\N
149855	juhtitud	?juhtitud =juhtitu  (IndPrSg2  >juhtituma !27_V	et	f	\N
149856	juhtitud	?juhtitud =juhtitud  (ID  >juhtitud !41_A	et	f	\N
149857	juhtitud	?juhtitud =itu  (PlN  >juht+itu !16_S	et	f	\N
149858	algurärase	?algurärase =algurärase  (SgG  >algurärane !12_A	et	f	\N
149859	algurärase	?algurärase =rärase  (SgG  >algu+rärane !10_A	et	f	\N
149860	algurärase	?algurärase =urärase  (SgG  >alg+urärane !12_A	et	f	\N
149890	ühendusele	ühendusele =ühenduse  (SgAll  >ühendus !11_S	et	f	\N
149891	ühendusele	"ühendus %ühenda  )US_vS  <ühendama ;27_V	et	f	\N
149892	ühendusele	ühendusele =use  (PlAll  >ühend+usk !22_S	et	f	\N
149896	ehitustest	ehitustest =ehitus  (PlEl  >ehitus !11_S	et	f	\N
149897	ehitustest	"ehitus %ehita  )US_vS  <ehitama ;27_V	et	f	\N
149898	ehitustest	"ehitus %ehi  )TUS1_aS  <ehtima ;28_V	et	f	\N
149899	ehitustest	ehitustest =test  (SgN  >ehitus+test !22_S	et	f	\N
149920	helsingi-teemalistest	helsingi-teemalistest =teemalis  (PlEl  >helsingi-teemaline !12_A	et	f	\N
149921	helsingi-teemalistest	"helsingi-teemaline %teema  )LINE_aA  <helsingi-teema ;16_S	et	f	\N
149922	helsingi-teemalistest	helsingi-teemalistest =malis  (PlEl  >helsingi-tee+maline !10_A	et	f	\N
149923	helsingi-teemalistest	"helsingi-tee+maline %mali  )NE_aA  <helsingi-tee+mali ;17_S	et	f	\N
149929	kahekorrusellised	?kahekorrusellised =kahekorrusellise  (PlN  >kahekorruselline !12_A	et	f	\N
149930	kahekorrusellised	?kahekorrusellised =korrusellise  (PlN  >kahe+korruselline !12_A	et	f	\N
149943	asunud	asunud =asu  (PtsPtPs  >asuma !27_V	et	f	\N
149944	asunud	asunud =asunu  (PlN  >asunu !01_S	et	f	\N
149945	asunud	"asunu %asu  )NU_vS  <asuma ;27_V	et	f	\N
149946	asunud	asunud =asunud  (ID  >asunud !41_A	et	f	\N
149947	asunud	"asunud %asu  )NUD_vA  <asuma ;27_V	et	f	\N
149948	ametikoha	ametikoha =koha  (SgN  >ameti+koha !17_S	et	f	\N
149949	ametikoha	ametikoha =koha  (SgG  >ameti+koha !17_S	et	f	\N
149950	ametikoha	ametikoha =koha  (SgG  >ameti+koht !22_S	et	f	\N
149951	ametikoha	ametikoha =koha  (SgP  >ameti+koha !17_S	et	f	\N
149979	millisesse	millisesse =millise  (SgIll  >milline !10_P	et	f	\N
149980	millisesse	millisesse =sesse  (PlP  >milli+sess !22_S	et	f	\N
149992	salvestamine	salvestamine =salvestamine  (SgN  >salvestamine !12_S	et	f	\N
149993	salvestamine	"salvestamine %salvesta  )MINE_vS  <salvestama ;27_V	et	f	\N
149996	kehvemaks	kehvemaks =kehvema  (SgTr  >kehvem !02_A	et	f	\N
149997	kehvemaks	"kehvem %kehve  )M_cA  <kehv ;22_A	et	f	\N
149998	kehvemaks	kehvemaks =ema  (SgTr  >kehv+ema !17_S	et	f	\N
150001	kolmekordseks	kolmekordseks =seks  (SgN  >kolme+kord+seks !22_S	et	f	\N
150002	kolmekordseks	kolmekordseks =kordse  (SgTr  >kolme+kordne !02_AS	et	f	\N
150031	leidlikult	leidlikult =leidliku  (SgAbl  >leidlik !25_A	et	f	\N
150032	leidlikult	leidlikult =leidlikult  (ID  >leidlikult !41_D	et	f	\N
150033	leidlikult	"leidlikult %leidliku  )LT_mD  <leidlik ;25_A	et	f	\N
150034	erkuse	erkuse =erkuse  (SgG  >erkus !11~09_S	et	f	\N
150035	erkuse	"erkus %erk  )US_aS  <erk ;22_AS	et	f	\N
150049	uurimisretkesse	uurimisretkesse =retke  (SgIll  >uurimis+retk !22_S	et	f	\N
150050	uurimisretkesse	uurimisretkesse =retke  (PlIll  >uurimis+retk !22_S	et	f	\N
150051	uurimisretkesse	uurimisretkesse =retkes  (SgAdt  >uurimis+retkene !12_A	et	f	\N
149762	mälestusmärgikompleksiga	mälestusmärgikompleksiga =iga  (SgN  >mälestus+märgi+kompleks+iga !18_S	et	f	\N
149763	mälestusmärgikompleksiga	mälestusmärgikompleksiga =iga  (SgP  >mälestus+märgi+kompleks+iga !18_S	et	f	\N
149764	mälestusmärgikompleksiga	mälestusmärgikompleksiga =kompleksi  (SgKom  >mälestus+märgi+kompleks !22_S	et	f	\N
149777	linnajuhatusega	linnajuhatusega =hatuse  (SgKom  >linn+aju+hatune !10_A	et	f	\N
149778	linnajuhatusega	"linn+aju+hatune %hatu  )NE_aA  <linn+aju+hatt ;22_S	et	f	\N
149779	linnajuhatusega	linnajuhatusega =juhatuse  (SgKom  >linna+juhatus !11_S	et	f	\N
149780	linnajuhatusega	"linna+juhatus %juha  )TUS2_aS  <linna+juha ;17_S	et	f	\N
149790	neitsi	neitsi =neitsi  (SgN  >neitsi !01_S	et	f	\N
149791	neitsi	neitsi =neitsi  (SgG  >neitsi !01_S	et	f	\N
149808	mullistusi	?mullistusi =mullistusi  (PlP  >mullistus !11_S	et	f	\N
149821	peatuma	peatuma =peatu  (Sup  >peatuma !27_V	et	f	\N
149822	peatuma	peatuma =peatuma  (SgG  >peatum !02_A	et	f	\N
149823	peatuma	"peatum %pea  )TUM2_cA  <pea ;26_S	et	f	\N
149824	peatuma	"peatum %peatu  )M_cA  <peatu ;01_A	et	f	\N
149828	jälgiv	jälgiv =jälgi  (PtsPrPs  >jälgima !27_V	et	f	\N
149829	jälgiv	jälgiv =jälgiv  (SgN  >jälgiv !02_A	et	f	\N
149830	jälgiv	"jälgiv %jälgi  )V_vA  <jälgima ;27_V	et	f	\N
149842	mitmekorrulise	?mitmekorrulise =mitmekorrulise  (SgG  >mitmekorruline !12_A	et	f	\N
149843	mitmekorrulise	?mitmekorrulise =korrulise  (SgG  >mitme+korruline !12_A	et	f	\N
149850	memoriaalikompleksiga	### memoriaalikompleksiga	et	f	\N
149861	äratav	äratav =ärata  (PtsPrPs  >äratama !27_V	et	f	\N
149862	äratav	äratav =äratav  (SgN  >äratav !02_A	et	f	\N
149863	äratav	"äratav %ärata  )V_vA  <äratama ;27_V	et	f	\N
149878	visuaalseks	visuaalseks =visuaalse  (SgTr  >visuaalne !02_A	et	f	\N
149879	visuaalseks	visuaalseks =seks  (SgN  >visuaal+seks !22_S	et	f	\N
149903	kaduvaid	kaduvaid =kaduva  (PlP  >kaduv !02_A	et	f	\N
149904	kaduvaid	"kaduv %kadu  )V_vA  <kaduma ;28_V	et	f	\N
149919	pöhineb	?pöhineb =pöhine  (IndPrSg3  >pöhinema !27_V	et	f	\N
149936	fotografina	?fotografina =fotografi  (SgEs  >fotograff !22_S	et	f	\N
149937	fotografina	?fotografina =grafi  (SgEs  >foto+grafi !16_S	et	f	\N
149938	fotografina	?fotografina =grafi  (SgEs  >foto+graff !22_S	et	f	\N
149954	kohmakas	kohmakas =kohmaka  (SgIn  >kohmakas !02_A	et	f	\N
149955	kohmakas	kohmakas =kohmakas  (SgN  >kohmakas !02_A	et	f	\N
149965	rakendeta	?rakendeta =rakendeta  (IndPrPs_  >rakendetama !27_V	et	f	\N
149966	rakendeta	?rakendeta =rakendeta  (ImpPrSg2  >rakendetama !27_V	et	f	\N
149967	võttaks	?võttaks =võtta  (KndPrPs  >võttama !29_V	et	f	\N
149988	linnaümbruskonna	linnaümbruskonna =konna  (SgG  >linna+ümbrus+konn !22_S	et	f	\N
149989	linnaümbruskonna	linnaümbruskonna =konna  (SgP  >linna+ümbrus+konn !22_S	et	f	\N
149990	linnaümbruskonna	linnaümbruskonna =konna  (SgAdt  >linna+ümbrus+konn !22_S	et	f	\N
149991	linnaümbruskonna	linnaümbruskonna =ümbruskonna  (SgG  >linna+ümbruskond !22_S	et	f	\N
149999	helsingiga	?helsingiga =helsingi  (SgKom  >helsing !02_S	et	f	\N
150000	helsingiga	?helsingiga =helsingi  (SgKom  >helsink !22_S	et	f	\N
150005	pildistatud	pildistatud =pildista  (PtsPtIps  >pildistama !27_V	et	f	\N
150006	pildistatud	pildistatud =pildistatu  (PlN  >pildistatu !01_S	et	f	\N
150007	pildistatud	"pildistatu %pildista  )TU1_vS  <pildistama ;27_V	et	f	\N
150008	pildistatud	pildistatud =pildistatud  (ID  >pildistatud !41_A	et	f	\N
150009	pildistatud	"pildistatud %pildista  )TUD_vA  <pildistama ;27_V	et	f	\N
150014	fotokava	fotokava =kava  (SgN  >foto+kava !17_S	et	f	\N
150015	fotokava	fotokava =kava  (SgG  >foto+kava !17_S	et	f	\N
150016	fotokava	fotokava =kava  (SgP  >foto+kava !17_S	et	f	\N
150017	kohinal	kohinal =kohina  (SgAd  >kohin !02_S	et	f	\N
150018	kohinal	kohinal =kohinal  (ID  >kohinal !41_D	et	f	\N
150019	töölöt	### töölöt	et	f	\N
150046	fotografeerimine	fotografeerimine =fotografeerimine  (SgN  >fotografeerimine !12_S	et	f	\N
150047	fotografeerimine	"fotografeerimine %fotografeeri  )MINE_vS  <fotografeerima ;28_V	et	f	\N
150070	süstemaatiliselt	süstemaatiliselt =süstemaatilise  (SgAbl  >süstemaatiline !12_A	et	f	\N
150071	süstemaatiliselt	süstemaatiliselt =süstemaatiliselt  (ID  >süstemaatiliselt !41_D	et	f	\N
150072	süstemaatiliselt	"süstemaatiliselt %süstemaatilise  )LT_mD  <süstemaatiline ;12_A	et	f	\N
150105	planeeringuid	?planeeringuid =planeeringu  (PlP  >planeering !02_S	et	f	\N
150106	planeeringuid	?planeeringuid =planeeringui  (PlN  >planeeringui !26_S	et	f	\N
150107	planeeringuid	?planeeringuid =planeeringui  (SgP  >planeeringui !26_S	et	f	\N
150128	haldushoone	haldushoone =hoone  (SgN  >haldus+hoone !06_S	et	f	\N
150129	haldushoone	"haldus+hoone %hoo  )NE_aA  <haldus+hoog ;22_S	et	f	\N
150130	haldushoone	haldushoone =hoone  (SgG  >haldus+hoone !06_S	et	f	\N
150131	haldushoone	haldushoone =hoone  (PlP  >haldus+hoon !22_A	et	f	\N
150144	propageerinud	propageerinud =propageeri  (PtsPtPs  >propageerima !28_V	et	f	\N
150145	propageerinud	propageerinud =propageerinu  (PlN  >propageerinu !01_S	et	f	\N
150146	propageerinud	"propageerinu %propageeri  )NU_vS  <propageerima ;28_V	et	f	\N
150147	propageerinud	propageerinud =propageerinud  (ID  >propageerinud !41_A	et	f	\N
150148	propageerinud	"propageerinud %propageeri  )NUD_vA  <propageerima ;28_V	et	f	\N
149809	joonistuse	joonistuse =joonistuse  (SgG  >joonistus !11_S	et	f	\N
149810	joonistuse	"joonistus %joonista  )US_vS  <joonistama ;27_V	et	f	\N
149819	kauplejaid	kauplejaid =kaupleja  (PlP  >kaupleja !01_S	et	f	\N
149820	kauplejaid	"kaupleja %kauple  )JA_vS  <kauplema ;30_V	et	f	\N
149827	helsingilastes	?helsingilastes =helsingilas  (PlIn  >helsingilane !12_S	et	f	\N
149840	hiigelsuurele	hiigelsuurele =re  (SgAll  >hiigel+suu+re !26_S	et	f	\N
149841	hiigelsuurele	hiigelsuurele =suure  (SgAll  >hiigel+suur !13_A	et	f	\N
149844	tähtaegani	?tähtaegani =tähtaegani  (SgG  >tähtaegan !02_S	et	f	\N
149845	tähtaegani	?tähtaegani =ani  (SgN  >täht+aeg+ani !17_S	et	f	\N
149846	tähtaegani	?tähtaegani =ani  (SgG  >täht+aeg+ani !17_S	et	f	\N
149847	tähtaegani	?tähtaegani =ani  (SgP  >täht+aeg+ani !17_S	et	f	\N
149848	tähtaegani	?tähtaegani =aegani  (SgG  >täht+aegan !02_S	et	f	\N
149869	mereneitsi	mereneitsi =neitsi  (SgN  >mere+neitsi !01_S	et	f	\N
149870	mereneitsi	mereneitsi =neitsi  (SgG  >mere+neitsi !01_S	et	f	\N
149880	võimalikest	võimalikest =võimalike  (PlEl  >võimalik !25_A	et	f	\N
149881	võimalikest	võimalikest =malikes  (SgP  >või+malike !12_S	et	f	\N
149882	võimalikest	"või+malike %mali  )KE_dS  <või+mali ;17_S	et	f	\N
149883	võimalikest	võimalikest =malikes  (SgP  >või+malikene !12_S	et	f	\N
149884	võimalikest	"või+malikene %mali  )KENE_dS  <või+mali ;17_S	et	f	\N
149885	turistitee	turistitee =tee  (SgN  >turisti+tee !26_S	et	f	\N
149886	turistitee	turistitee =tee  (SgG  >turisti+tee !26_S	et	f	\N
149905	muinsuskaitsenõukogu	muinsuskaitsenõukogu =kogu  (SgN  >muinsus+kaitse+nõu+kogu !17_S	et	f	\N
149906	muinsuskaitsenõukogu	muinsuskaitsenõukogu =kogu  (SgG  >muinsus+kaitse+nõu+kogu !17_S	et	f	\N
149907	muinsuskaitsenõukogu	muinsuskaitsenõukogu =kogu  (SgP  >muinsus+kaitse+nõu+kogu !17_S	et	f	\N
149924	linnapilti	linnapilti =pilti  (SgP  >linna+pilt !22_S	et	f	\N
149925	linnapilti	linnapilti =pilti  (SgAdt  >linna+pilt !22_S	et	f	\N
149931	valimine	valimine =valimine  (SgN  >valimine !12_S	et	f	\N
149932	valimine	"valimine %vali  )MINE_vS  <valima ;27_V	et	f	\N
149933	tõestus	tõestus =tõestu  (IndIpfSg3  >tõestuma !27_V	et	f	\N
149934	tõestus	tõestus =tõestus  (SgN  >tõestus !11~09_S	et	f	\N
149935	tõestus	"tõestus %tõesta  )US_vS  <tõestama ;27_V	et	f	\N
149964	mönikord	?mönikord =mönikord  (SgN  >mönikord !22_S	et	f	\N
149970	töölöni	?töölöni =töölöni  (SgN  >töölöni !01_S	et	f	\N
149971	töölöni	?töölöni =töölöni  (SgG  >töölöni !01_S	et	f	\N
149972	töölöni	?töölöni =töölöni  (SgG  >töölön !02_S	et	f	\N
149973	töölöni	?töölöni =öni  (SgN  >tööl+öni !17_S	et	f	\N
149974	töölöni	?töölöni =öni  (SgG  >tööl+öni !17_S	et	f	\N
149975	töölöni	?töölöni =öni  (SgP  >tööl+öni !17_S	et	f	\N
149976	töölöni	?töölöni =löni  (SgN  >töö+löni !17_S	et	f	\N
149977	töölöni	?töölöni =löni  (SgG  >töö+löni !17_S	et	f	\N
149978	töölöni	?töölöni =löni  (SgP  >töö+löni !17_S	et	f	\N
149984	aastla	?aastla =aastla  (SgN  >aastla !01_S	et	f	\N
149985	aastla	?aastla =aastla  (SgG  >aastla !01_S	et	f	\N
149986	aastla	?aastla =aastla  (IndPrPs_  >aastlama !29_V	et	f	\N
149987	aastla	?aastla =aastla  (ImpPrSg2  >aastlama !29_V	et	f	\N
150024	parkano	?parkano =parkano  (SgN  >parkano !01_S	et	f	\N
150025	parkano	?parkano =parkano  (SgG  >parkano !01_S	et	f	\N
150026	parkano	?parkano =ano  (SgN  >park+ano !17~16_S	et	f	\N
150027	parkano	?parkano =ano  (SgG  >park+ano !17~16_S	et	f	\N
150028	parkano	?parkano =ano  (SgP  >park+ano !17_S	et	f	\N
150036	politseininikke	### politseininikke	et	f	\N
150037	jäädvustatud	jäädvustatud =jäädvusta  (PtsPtIps  >jäädvustama !27_V	et	f	\N
150038	jäädvustatud	jäädvustatud =jäädvustatu  (PlN  >jäädvustatu !01_S	et	f	\N
150039	jäädvustatud	"jäädvustatu %jäädvusta  )TU1_vS  <jäädvustama ;27_V	et	f	\N
150040	jäädvustatud	jäädvustatud =jäädvustatud  (ID  >jäädvustatud !41_A	et	f	\N
150041	jäädvustatud	"jäädvustatud %jäädvusta  )TUD_vA  <jäädvustama ;27_V	et	f	\N
150042	näost	näost =näo  (SgEl  >nägu !18_S	et	f	\N
150043	näost	näost =näos  (SgP  >näone !10_A	et	f	\N
150048	pikant	?pikant =pikant  (SgN  >pikant !22_S	et	f	\N
150055	tänäpäeva	?tänäpäeva =tänäpäeva  (SgN  >tänäpäeva !16_S	et	f	\N
150056	tänäpäeva	?tänäpäeva =tänäpäeva  (SgG  >tänäpäeva !16_S	et	f	\N
150057	protokolli	protokolli =protokolli  (SgG  >protokoll !22_S	et	f	\N
150058	protokolli	protokolli =protokolli  (SgP  >protokoll !22_S	et	f	\N
150059	protokolli	protokolli =protokolli  (SgAdt  >protokoll !22_S	et	f	\N
150060	protokolli	protokolli =protokolli  (IndPrPs_  >protokollima !28_V	et	f	\N
150061	protokolli	protokolli =protokolli  (ImpPrSg2  >protokollima !28_V	et	f	\N
150062	protokolli	protokolli =kolli  (SgG  >proto+koll !22_S	et	f	\N
150063	protokolli	protokolli =kolli  (SgP  >proto+koll !22_S	et	f	\N
150064	protokolli	protokolli =kolli  (SgAdt  >proto+koll !22_S	et	f	\N
150065	fotograafia	fotograafia =fotograafia  (SgN  >fotograafia !01_S	et	f	\N
150066	fotograafia	fotograafia =fotograafia  (SgG  >fotograafia !01_S	et	f	\N
150067	linnamiljööt	?linnamiljööt =linnamiljööt  (SgN  >linnamiljööt !22_S	et	f	\N
150068	linnamiljööt	?linnamiljööt =miljööt  (SgN  >linna+miljööt !22_S	et	f	\N
149825	uudishimulikkust	uudishimulikkust =himulikkus  (SgP  >uudis+himulikkus !11~09_S	et	f	\N
149826	uudishimulikkust	"uudis+himulikkus %himulikku  )US_aS  <uudis+himulik ;25_A	et	f	\N
149831	pildistustegevuse	?pildistustegevuse =pildistustegevuse  (SgG  >pildistustegevus !11?09_S	et	f	\N
149832	pildistustegevuse	?pildistustegevuse =stustegevuse  (SgG  >pildi+stustegevus !11?09_S	et	f	\N
149836	psühiatrilisse	?psühiatrilisse =psühiatrili  (SgIll  >psühiatril !02_S	et	f	\N
149837	psühiatrilisse	?psühiatrilisse =psühiatrilis  (SgAdt  >psühiatriline !12_A	et	f	\N
149838	psühiatrilisse	?psühiatrilisse =psühiatrilisse  (SgG  >psühiatrilisne !02_A	et	f	\N
149839	psühiatrilisse	?psühiatrilisse =psühiatrilisse  (PlP  >psühiatriliss !22_S	et	f	\N
149849	memoriaalikompleks	### memoriaalikompleks	et	f	\N
149864	kavatsusel	kavatsusel =kavatsuse  (SgAd  >kavatsus !11_S	et	f	\N
149865	kavatsusel	"kavatsus %kavatse  )US_vS  <kavatsema ;27_V	et	f	\N
149866	kopenhaagenist	?kopenhaagenist =kopenhaageni  (SgEl  >kopenhaagen !02_S	et	f	\N
149867	kopenhaagenist	?kopenhaagenist =kopenhaagenis  (SgP  >kopenhaagenis !09_S	et	f	\N
149868	kopenhaagenist	?kopenhaagenist =kopenhaagenist  (SgN  >kopenhaagenist !22_S	et	f	\N
149871	maaarjamäe	?maaarjamäe =maaarjamäe  (SgN  >maaarjamäe !26_S	et	f	\N
149872	maaarjamäe	?maaarjamäe =maaarjamäe  (SgG  >maaarjamäe !26_S	et	f	\N
149873	maaarjamäe	?maaarjamäe =arjamäe  (SgN  >maa+arjamäe !26_S	et	f	\N
149874	maaarjamäe	?maaarjamäe =arjamäe  (SgG  >maa+arjamäe !26_S	et	f	\N
149887	inimkuju	inimkuju =kuju  (SgN  >inim+kuju !17_S	et	f	\N
149888	inimkuju	inimkuju =kuju  (SgG  >inim+kuju !17_S	et	f	\N
149889	inimkuju	inimkuju =kuju  (SgP  >inim+kuju !17_S	et	f	\N
149893	kõrgetest	kõrgetest =kõrge  (PlEl  >kõrge !01_A	et	f	\N
149894	kõrgetest	kõrgetest =test  (SgN  >kõrge+test !22_S	et	f	\N
149895	kõrgetest	kõrgetest =e  (PlEl  >kõrg+esi !15_S	et	f	\N
149900	skulptuuriürituse	?skulptuuriürituse =skulptuuriürituse  (SgG  >skulptuuriüritus !11?09_S	et	f	\N
149901	tuleval	tuleval =tuleva  (SgAd  >tulev !02_A	et	f	\N
149902	tuleval	"tulev %tule  )V_vA  <tulema ;36_V	et	f	\N
149910	ajavahemikul	ajavahemikul =miku  (SgAd  >aja+vahe+mikk !22_S	et	f	\N
149911	ajavahemikul	ajavahemikul =vahemiku  (SgAd  >aja+vahemik !25_S	et	f	\N
149912	piltiarhiivi	?piltiarhiivi =piltiarhiivi  (SgN  >piltiarhiivi !16_S	et	f	\N
149913	piltiarhiivi	?piltiarhiivi =piltiarhiivi  (SgG  >piltiarhiivi !16_S	et	f	\N
149914	piltiarhiivi	?piltiarhiivi =piltiarhiivi  (SgG  >piltiarhiiv !22_S	et	f	\N
149915	piltiarhiivi	?piltiarhiivi =piltiarhiivi  (SgP  >piltiarhiiv !22_S	et	f	\N
149916	piltiarhiivi	?piltiarhiivi =piltiarhiivi  (SgAdt  >piltiarhiiv !22_S	et	f	\N
149917	piltiarhiivi	?piltiarhiivi =piltiarhiivi  (IndPrPs_  >piltiarhiivima !28_V	et	f	\N
149918	piltiarhiivi	?piltiarhiivi =piltiarhiivi  (ImpPrSg2  >piltiarhiivima !28_V	et	f	\N
149939	joonistamiseöpetajaks	?joonistamiseöpetajaks =joonistamiseöpetaja  (SgTr  >joonistamiseöpetaja !01_S	et	f	\N
149940	joonistamiseöpetajaks	?joonistamiseöpetajaks =joonistamiseöpetaja  (SgTr  >joonistamiseöpetajas !02_A	et	f	\N
149941	joonistamiseöpetajaks	?joonistamiseöpetajaks =tamiseöpetaja  (SgTr  >joonis+tamiseöpetaja !01_S	et	f	\N
149942	joonistamiseöpetajaks	?joonistamiseöpetajaks =tamiseöpetaja  (SgTr  >joonis+tamiseöpetajas !02_A	et	f	\N
149956	pildistanud	pildistanud =pildista  (PtsPtPs  >pildistama !27_V	et	f	\N
149957	pildistanud	pildistanud =pildistanu  (PlN  >pildistanu !01_S	et	f	\N
149958	pildistanud	"pildistanu %pildista  )NU_vS  <pildistama ;27_V	et	f	\N
149959	pildistanud	pildistanud =pildistanud  (ID  >pildistanud !41_A	et	f	\N
149960	pildistanud	"pildistanud %pildista  )NUD_vA  <pildistama ;27_V	et	f	\N
149963	enemik	?enemik =enemik  (SgN  >enemik !25_S	et	f	\N
149981	tundmatuks	tundmatuks =tundmatu  (SgTr  >tundmatu !01_AS	et	f	\N
149982	tundmatuks	"tundmatu %tund  )MATU_vA  <tundma ;34_V	et	f	\N
149983	tundmatuks	tundmatuks =tuks  (SgN  >tundma+tuks !22_S	et	f	\N
149994	hoo	hoo =hoo  (ID  >hoo !41_I	et	f	\N
149995	hoo	hoo =hoo  (SgG  >hoog !22_S	et	f	\N
150003	blanco	?blanco =blanco  (SgN  >blanco !16_S	et	f	\N
150004	blanco	?blanco =blanco  (SgG  >blanco !16_S	et	f	\N
150010	linnavaate	linnavaate =vaate  (SgG  >linna+vaade !06_S	et	f	\N
150011	linnavaate	linnavaate =vaate  (PlP  >linna+vaat !22_S	et	f	\N
150012	juhatajana	juhatajana =juhataja  (SgEs  >juhataja !01_S	et	f	\N
150013	juhatajana	"juhataja %juhata  )JA_vS  <juhatama ;27_V	et	f	\N
150020	eirat	?eirat =eira  (SgP  >eira !16_S	et	f	\N
150021	eirat	?eirat =eirat  (SgN  >eirat !02_S	et	f	\N
150022	endal	endal =enda  (SgAd  >enda !00_P	et	f	\N
150023	endal	endal =enda  (SgAd  >ise !00_P	et	f	\N
150044	heatujuliste	heatujuliste =tujulis  (PlG  >hea+tujuline !12_A	et	f	\N
150045	heatujuliste	"hea+tujuline %tuju  )LINE_aA  <hea+tuju ;17_S	et	f	\N
150073	1950aastatel	aastatel =aasta  (PlAd  >aasta !01_S	et	f	\N
150074	1950aastatel	aastatel =tate  (PlAd  >aas+tatt !22_S	et	f	\N
150077	hingelisest	hingelisest =hingelise  (SgEl  >hingeline !12_SA	et	f	\N
150078	hingelisest	"hingeline %hinge  )LINE_aA  <hing ;22_S	et	f	\N
150087	hiiglaslikku	hiiglaslikku =hiiglaslikku  (SgP  >hiiglaslik !25_A	et	f	\N
150088	hiiglaslikku	hiiglaslikku =hiiglaslikku  (SgAdt  >hiiglaslik !25_A	et	f	\N
150108	kuulsusega	kuulsusega =kuulsuse  (SgKom  >kuulsus !11~09_S	et	f	\N
150109	kuulsusega	"kuulsus %kuulsa  )US_aS  <kuulus ;02_A	et	f	\N
150052	uurimisretkesse	"uurimis+retkene %retke  )NE_aA  <uurimis+retk ;22_S	et	f	\N
150053	lõunapoolsetele	lõunapoolsetele =sete  (PlAll  >lõuna+pool+sett !22_S	et	f	\N
150054	lõunapoolsetele	lõunapoolsetele =poolse  (PlAll  >lõuna+poolne !02_A	et	f	\N
150089	elumajakõrgune	elumajakõrgune =une  (SgG  >elu+maja+kõrg+uni !20_S	et	f	\N
150090	elumajakõrgune	elumajakõrgune =kõrgune  (SgN  >elu+maja+kõrgune !10~12_A	et	f	\N
150099	lähedusse	lähedusse =lähedus  (SgAdt  >lähedus !11_S	et	f	\N
150100	lähedusse	"lähedus %läheda  )US_aS  <läheda ;02_A	et	f	\N
150102	erapooletuks	erapooletuks =erapooletu  (SgTr  >erapooletu !01_A	et	f	\N
150103	erapooletuks	erapooletuks =tuks  (SgN  >era+poole+tuks !22_S	et	f	\N
150104	erapooletuks	erapooletuks =pooletu  (SgTr  >era+pooletu !01_A	et	f	\N
150111	90ndate	?ndate =ndate  (SgN  >ndate !06_S	et	f	\N
150112	90ndate	?ndate =ndate  (IndPrPs_  >ndatema !27_V	et	f	\N
150113	90ndate	?ndate =ndate  (ImpPrSg2  >ndatema !27_V	et	f	\N
150120	marsruuti	marsruuti =marsruuti  (SgP  >marsruut !22_S	et	f	\N
150121	marsruuti	marsruuti =marsruuti  (SgAdt  >marsruut !22_S	et	f	\N
150132	pooldanud	pooldanud =poolda  (PtsPtPs  >pooldama !27_V	et	f	\N
150133	pooldanud	pooldanud =pooldanu  (PlN  >pooldanu !01_S	et	f	\N
150134	pooldanud	"pooldanu %poolda  )NU_vS  <pooldama ;27_V	et	f	\N
150135	pooldanud	pooldanud =pooldanud  (ID  >pooldanud !41_A	et	f	\N
150136	pooldanud	"pooldanud %poolda  )NUD_vA  <pooldama ;27_V	et	f	\N
150137	kõrghooneid	kõrghooneid =neid  (SgN  >kõrg+hoo+neid !22_S	et	f	\N
150138	kõrghooneid	kõrghooneid =hoone  (PlP  >kõrg+hoone !06_S	et	f	\N
150139	kõrghooneid	"kõrg+hoone %hoo  )NE_aA  <kõrg+hoog ;22_S	et	f	\N
150157	randtee	randtee =tee  (SgN  >rand+tee !26_S	et	f	\N
150158	randtee	randtee =tee  (SgG  >rand+tee !26_S	et	f	\N
150166	idée	### idée	et	f	\N
150170	vaieltav	?vaieltav =vaieltav  (SgN  >vaieltav !02_A	et	f	\N
150171	kangro40	?kangro =kangro  (SgN  >kangro !01_S	et	f	\N
150172	kangro40	?kangro =kangro  (SgG  >kangro !01_S	et	f	\N
150175	nda	### nda	et	f	\N
150186	sight-seeingi	?sight-seeingi =seeingi  (SgG  >sight-seeing !02_S	et	f	\N
150187	sight-seeingi	?sight-seeingi =seeingi  (SgG  >sight-seeink !22_S	et	f	\N
150188	sight-seeingi	?sight-seeingi =seeingi  (IndPrPs_  >sight-seeinkima !28_V	et	f	\N
150189	sight-seeingi	?sight-seeingi =seeingi  (ImpPrSg2  >sight-seeinkima !28_V	et	f	\N
150190	sight-seeingi	?sight-seeingi =ingi  (SgG  >sight-see+ink !22_S	et	f	\N
150191	sight-seeingi	?sight-seeingi =ingi  (SgP  >sight-see+ing !22_S	et	f	\N
150192	sight-seeingi	?sight-seeingi =ingi  (SgAdt  >sight-see+ing !22_S	et	f	\N
150193	sight-seeingi	?sight-seeingi =seein  (SgN^  >sight-seein !02_S	et	f	\N
150197	gallerias	?gallerias =galleria  (SgIn  >galleria !01_S	et	f	\N
150198	gallerias	?gallerias =gallerias  (SgN  >gallerias !11_S	et	f	\N
150218	vveel	?vveel =vvee  (SgAd  >vvee !26_S	et	f	\N
150219	vveel	?vveel =vveel  (SgN  >vveel !22_S	et	f	\N
150220	inimkogu	inimkogu =kogu  (SgN  >inim+kogu !17_S	et	f	\N
150221	inimkogu	inimkogu =kogu  (SgG  >inim+kogu !17_S	et	f	\N
150222	inimkogu	inimkogu =kogu  (SgP  >inim+kogu !17_S	et	f	\N
150229	mõjuvõimsaim	mõjuvõimsaim =võimsaim  (SgN  >mõju+võimsaim !02_A	et	f	\N
150230	mõjuvõimsaim	"mõju+võimsaim %võimsa  )IM_sA  <mõju+võimas ;03_A	et	f	\N
150231	mõjuvõimsaim	"mõju+võimsaim %võimsa  )IM_sA  <mõju+võimas ;05_A	et	f	\N
150255	osalenud	osalenud =osale  (PtsPtPs  >osalema !27_V	et	f	\N
150256	osalenud	osalenud =osalenu  (PlN  >osalenu !01_S	et	f	\N
150257	osalenud	"osalenu %osale  )NU_vS  <osalema ;27_V	et	f	\N
150258	osalenud	osalenud =osalenud  (ID  >osalenud !41_A	et	f	\N
150259	osalenud	"osalenud %osale  )NUD_vA  <osalema ;27_V	et	f	\N
150265	muistsuskaitsekomisjoni	?muistsuskaitsekomisjoni =muistsuskaitsekomisjo  (SgTer  >muistsuskaitsekomisjo !16_S	et	f	\N
150266	muistsuskaitsekomisjoni	?muistsuskaitsekomisjoni =muistsuskaitsekomisjoni  (SgG  >muistsuskaitsekomisjon !02_S	et	f	\N
150269	sajast	sajast =saja  (SgEl  >sajas !02_O	et	f	\N
150270	sajast	sajast =saja  (SgEl  >sada !18_N	et	f	\N
150271	sajast	sajast =sajas  (SgP  >sajane !10_AS	et	f	\N
150272	sajast	"sajane %saja  )NE_aA  <sada ;18_N	et	f	\N
150283	linnaplaani	linnaplaani =plaani  (SgG  >linna+plaan !22_S	et	f	\N
150284	linnaplaani	linnaplaani =plaani  (SgP  >linna+plaan !22_S	et	f	\N
150285	linnaplaani	linnaplaani =plaani  (SgAdt  >linna+plaan !22_S	et	f	\N
150304	pilditel	?pilditel =pildite  (PlAd  >pilditt !22_S	et	f	\N
150334	möisasid	?möisasid =möisa  (PlP  >möisa !16_S	et	f	\N
150335	möisasid	?möisasid =möisa  (IndIpfSg2  >möisama !29_V	et	f	\N
150336	möisasid	?möisasid =möisa  (IndIpfPl3  >möisama !29_V	et	f	\N
150337	glaukooma	?glaukooma =glaukooma  (SgN  >glaukooma !16_S	et	f	\N
150338	glaukooma	?glaukooma =glaukooma  (SgG  >glaukooma !16_S	et	f	\N
150367	kritiseerivad	kritiseerivad =kritiseeri  (IndPrPl3  >kritiseerima !28_V	et	f	\N
150368	kritiseerivad	kritiseerivad =kritiseeriva  (PlN  >kritiseeriv !02_A	et	f	\N
150369	kritiseerivad	"kritiseeriv %kritiseeri  )V_vA  <kritiseerima ;28_V	et	f	\N
150399	pystitada	?pystitada =pystita  (Inf  >pystitama !27_V	et	f	\N
150408	esmaspäevaseks	esmaspäevaseks =seks  (SgN  >esmas+päeva+seks !22_S	et	f	\N
150409	esmaspäevaseks	esmaspäevaseks =päevase  (SgTr  >esmas+päevane !10_A	et	f	\N
150069	linnamiljööt	?linnamiljööt =amiljööt  (SgN  >linn+amiljööt !22_S	et	f	\N
150079	a1943	### a1943	et	f	\N
150080	kunstikeliidud	?kunstikeliidud =kunstikeliidu  (IndPrSg2  >kunstikeliiduma !27_V	et	f	\N
150081	kunstikeliidud	?kunstikeliidud =kunstikeliidud  (ID  >kunstikeliidud !41_A	et	f	\N
150082	kunstikeliidud	?kunstikeliidud =keliidu  (PlN  >kunsti+keliidu !01_S	et	f	\N
150083	võõrastavad	võõrastavad =võõrasta  (IndPrPl3  >võõrastama !27_V	et	f	\N
150084	võõrastavad	võõrastavad =võõrastava  (PlN  >võõrastav !02_A	et	f	\N
150085	võõrastavad	"võõrastav %võõrasta  )V_vA  <võõrastama ;27_V	et	f	\N
150086	võõrastavad	võõrastavad =tava  (PlN  >võõras+tava !17_S	et	f	\N
150101	32a	### 32a	et	f	\N
150124	innustunult	innustunult =innustunu  (SgAbl  >innustunu !01_S	et	f	\N
150125	innustunult	"innustunu %innustu  )NU_vS  <innustuma ;27_V	et	f	\N
150126	innustunult	innustunult =innustunult  (ID  >innustunult !41_D	et	f	\N
150127	innustunult	"innustunult %innustu  )NULT_mD  <innustuma ;27_V	et	f	\N
150177	rinnastatav	rinnastatav =rinnasta  (PtsPrIps  >rinnastama !27_V	et	f	\N
150178	rinnastatav	rinnastatav =rinnastatav  (SgN  >rinnastatav !02_A	et	f	\N
150179	rinnastatav	"rinnastatav %rinnasta  )TAV_vAS  <rinnastama ;27_V	et	f	\N
150202	prontsist	?prontsist =prontsi  (SgEl  >pronts !22_S	et	f	\N
150203	prontsist	?prontsist =prontsis  (SgP  >prontsis !09_S	et	f	\N
150204	prontsist	?prontsist =prontsist  (SgN  >prontsist !22_S	et	f	\N
150207	symboliseerib	?symboliseerib =symboliseeri  (IndPrSg3  >symboliseerima !28_V	et	f	\N
150223	skulptoride	### skulptoride	et	f	\N
150235	ennemki	?ennemki =ennemki  (SgP  >ennemk !22_S	et	f	\N
150236	ennemki	?ennemki =ennemki  (SgAdt  >ennemk !22_S	et	f	\N
150249	vägistamisele	vägistamisele =vägistamise  (SgAll  >vägistamine !12_S	et	f	\N
150250	vägistamisele	"vägistamine %vägista  )MINE_vS  <vägistama ;27_V	et	f	\N
150251	võitlusest	võitlusest =võitluse  (SgEl  >võitlus !11~09_S	et	f	\N
150252	võitlusest	võitlusest =võitluses  (SgP  >võitlusene !12_A	et	f	\N
150253	võitlusest	"võitlusene %võitluse  )NE_aA  <võitlus ;09_S	et	f	\N
150254	võitlusest	"võitlusene %võitluse  )NE_aA  <võitlus ;11_S	et	f	\N
150262	püsditatakse	?püsditatakse =püsdita  (IndPrIps  >püsditama !27_V	et	f	\N
150263	püsditatakse	?püsditatakse =püsditatakse  (SgG  >püsditatakne !02_A	et	f	\N
150264	püsditatakse	?püsditatakse =püsditatakse  (PlP  >püsditataks !22_S	et	f	\N
150267	laiaulatuslikkuks	?laiaulatuslikkuks =laiaulatuslikku  (KndPrPs  >laiaulatuslikkuma !27_V	et	f	\N
150268	laiaulatuslikkuks	?laiaulatuslikkuks =tuslikku  (SgTr  >lai+aula+tuslikku !01_S	et	f	\N
150287	muudus	"muudu %muu  )TU1_vS  <muuma ;27_V	et	f	\N
150288	muudus	muudus =muudu  (SgIn  >muut !22_S	et	f	\N
150289	muudus	"muudus %muu  )TUS1_aS  <muuma ;27_V	et	f	\N
150294	1800-aastade	?-aastade =tade  (SgN  >-aas+tade !16_S	et	f	\N
150295	1800-aastade	?-aastade =tade  (SgG  >-aas+tade !16_S	et	f	\N
150299	algelises	algelises =algelise  (SgIn  >algeline !12_A	et	f	\N
150300	algelises	"algeline %alge  )LINE_aA  <alge ;06_S	et	f	\N
150344	ühishauta	?ühishauta =ühishau  (SgAb  >ühishau !26_S	et	f	\N
150345	ühishauta	?ühishauta =ühishauta  (IndPrPs_  >ühishautama !27_V	et	f	\N
150346	ühishauta	?ühishauta =ühishauta  (ImpPrSg2  >ühishautama !27_V	et	f	\N
150347	ühishauta	?ühishauta =hau  (SgAb  >ühis+hau !26_S	et	f	\N
150348	ühishauta	?ühishauta =hauta  (SgN  >ühis+hauta !16_S	et	f	\N
150349	ühishauta	?ühishauta =hauta  (SgG  >ühis+hauta !16_S	et	f	\N
150356	monumendikompleksiga	### monumendikompleksiga	et	f	\N
150357	algpärase	algpärase =pärase  (SgG  >alg+pärane !10_A	et	f	\N
150358	algpärase	"alg+pärane %pära  )NE_aA  <alg+pära ;17_S	et	f	\N
150362	võrdsustuv	võrdsustuv =võrdsustu  (PtsPrPs  >võrdsustuma !27_V	et	f	\N
150363	võrdsustuv	võrdsustuv =võrdsustuv  (SgN  >võrdsustuv !02_A	et	f	\N
150364	võrdsustuv	"võrdsustuv %võrdsustu  )V_vA  <võrdsustuma ;27_V	et	f	\N
150385	kujundanud	kujundanud =kujunda  (PtsPtPs  >kujundama !27_V	et	f	\N
150386	kujundanud	kujundanud =kujundanu  (PlN  >kujundanu !01_S	et	f	\N
150387	kujundanud	"kujundanu %kujunda  )NU_vS  <kujundama ;27_V	et	f	\N
150388	kujundanud	kujundanud =kujundanud  (ID  >kujundanud !41_A	et	f	\N
150389	kujundanud	"kujundanud %kujunda  )NUD_vA  <kujundama ;27_V	et	f	\N
150392	varju	varju =varju  (ID  >varju !41_K	et	f	\N
150393	varju	varju =varju  (SgG  >vari !24_S	et	f	\N
150394	varju	varju =varju  (SgP  >vari !24_S	et	f	\N
150395	varju	varju =varju  (SgAdt  >vari !24_S	et	f	\N
150396	varju	varju =varju  (PlP  >vari !24_S	et	f	\N
150397	varju	varju =varju  (IndPrPs_  >varjuma !27_V	et	f	\N
150398	varju	varju =varju  (ImpPrSg2  >varjuma !27_V	et	f	\N
150404	körge	?körge =körge  (SgN  >körge !06_S	et	f	\N
150405	körge	?körge =körge  (PlP  >körg !22_S	et	f	\N
150406	körge	?körge =körge  (IndPrPs_  >körgema !27_V	et	f	\N
150407	körge	?körge =körge  (ImpPrSg2  >körgema !27_V	et	f	\N
150411	nöukogude	### nöukogude	et	f	\N
150420	ametivöimude	?ametivöimude =vöimu  (PlG  >ameti+vöimu !16_S	et	f	\N
150438	tutvustamist	tutvustamist =tutvustamis  (SgP  >tutvustamine !12_S	et	f	\N
150439	tutvustamist	"tutvustamine %tutvusta  )MINE_vS  <tutvustama ;27_V	et	f	\N
150110	40a	### 40a	et	f	\N
150114	kööpenhaageni	?kööpenhaageni =kööpenhaage  (SgTer  >kööpenhaage !16_S	et	f	\N
150115	kööpenhaageni	?kööpenhaageni =kööpenhaageni  (SgG  >kööpenhaagen !02_S	et	f	\N
150116	pikkust	pikkust =pikkus  (SgP  >pikkus !11~09_S	et	f	\N
150117	pikkust	"pikkus %pikk  )US_aS  <pikk ;22_AS	et	f	\N
150118	pikkust	pikkust =pikkus  (SgP  >pikkune !12~10_A	et	f	\N
150119	pikkust	pikkust =us  (SgP  >pikk+uks !14_S	et	f	\N
150140	pikalt	pikalt =pika  (SgAbl  >pikk !22_S	et	f	\N
150141	pikalt	pikalt =pika  (SgAbl  >pikk !22_AS	et	f	\N
150142	pikalt	pikalt =pikalt  (ID  >pikalt !41_D	et	f	\N
150143	pikalt	"pikalt %pika  )LT_mD  <pikk ;22_AS	et	f	\N
150149	hiidlastniku	?hiidlastniku =hiidlastniku  (SgG  >hiidlastnik !25_S	et	f	\N
150150	hiidlastniku	?hiidlastniku =hiidlastniku  (IndPrPs_  >hiidlastnikuma !27_V	et	f	\N
150151	hiidlastniku	?hiidlastniku =hiidlastniku  (ImpPrSg2  >hiidlastnikuma !27_V	et	f	\N
150152	hiidlastniku	?hiidlastniku =lastniku  (SgN  >hiid+lastniku !01_S	et	f	\N
150153	hiidlastniku	?hiidlastniku =lastniku  (SgG  >hiid+lastniku !01_S	et	f	\N
150154	hiidlastniku	?hiidlastniku =lastniku  (SgG  >hiid+lastnik !25_S	et	f	\N
150168	ametiisikulisusele	ametiisikulisusele =isikulisuse  (SgAll  >ameti+isikulisus !11?09_S	et	f	\N
150169	ametiisikulisusele	"ameti+isikulisus %isiku  )LISUS_aS  <ameti+isik ;02_S	et	f	\N
150180	symbool	?symbool =symboo  (SgAd  >symboo !26_S	et	f	\N
150181	symbool	?symbool =symbool  (SgN  >symbool !22_S	et	f	\N
150182	mereneits	?mereneits =mereneits  (SgN  >mereneits !22_S	et	f	\N
150183	mereneits	?mereneits =neits  (SgN  >mere+neits !22_S	et	f	\N
150199	innukas	innukas =innuka  (SgIn  >innukas !02_A	et	f	\N
150200	innukas	innukas =innukas  (SgN  >innukas !02_A	et	f	\N
150201	esidles	?esidles =esidle  (IndIpfSg3  >esidlema !27_V	et	f	\N
150205	kaleviporg	?kaleviporg =kaleviporg  (SgN  >kaleviporg !22_S	et	f	\N
150206	kaleviporg	?kaleviporg =porg  (SgN  >kalevi+porg !22_S	et	f	\N
150210	rändanud	?rändanud =rända  (PtsPtPs  >räntama !29_V	et	f	\N
150211	rändanud	?rändanud =rändanu  (PlN  >rändanu !01_S	et	f	\N
150212	rändanud	?rändanud =rändanu  (IndPrSg2  >rändanuma !27_V	et	f	\N
150213	rändanud	?rändanud =rändanud  (ID  >rändanud !41_A	et	f	\N
150214	rändanud	?rändanud =anu  (PlN  >ränd+anu !17_S	et	f	\N
150232	riidu	riidu =riidu  (ID  >riidu !41_D	et	f	\N
150233	riidu	riidu =riidu  (SgP  >riid !22_S	et	f	\N
150234	riidu	riidu =riidu  (SgAdt  >riid !22_S	et	f	\N
150241	püstitamise	püstitamise =püstitamise  (SgG  >püstitamine !12_S	et	f	\N
150242	püstitamise	"püstitamine %püstita  )MINE_vS  <püstitama ;27_V	et	f	\N
150244	erakonnaga	erakonnaga =erakonna  (SgKom  >erakond !22_S	et	f	\N
150245	erakonnaga	erakonnaga =konna  (SgKom  >era+konn !22_S	et	f	\N
150246	muisnaisjuttu	?muisnaisjuttu =muisnaisjuttu  (IndPrPs_  >muisnaisjuttuma !27_V	et	f	\N
150247	muisnaisjuttu	?muisnaisjuttu =muisnaisjuttu  (ImpPrSg2  >muisnaisjuttuma !27_V	et	f	\N
150248	kivedega	?kivedega =kive  (PlKom  >kive !16_S	et	f	\N
150273	parimast	parimast =parima  (SgEl  >parim !02_A	et	f	\N
150274	parimast	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
150286	ootada	### ootada	et	f	\N
150290	kohinaga	kohinaga =kohina  (SgKom  >kohin !02_S	et	f	\N
150291	kohinaga	kohinaga =naga  (SgN  >kohi+naga !17_S	et	f	\N
150292	kohinaga	kohinaga =naga  (SgG  >kohi+naga !17_S	et	f	\N
150293	kohinaga	kohinaga =naga  (SgP  >kohi+naga !17_S	et	f	\N
150301	andekalt	andekalt =andeka  (SgAbl  >andekas !02_A	et	f	\N
150302	andekalt	andekalt =andekalt  (ID  >andekalt !41_D	et	f	\N
150303	andekalt	"andekalt %andeka  )LT_mD  <andekas ;02_A	et	f	\N
150305	sagelienamasti	?sagelienamasti =sagelienamasti  (ID  >sagelienamasti !41_D	et	f	\N
150306	sagelienamasti	?sagelienamasti =sagelienamasti  (IndPrPs_  >sagelienamastima !28_V	et	f	\N
150307	sagelienamasti	?sagelienamasti =sagelienamasti  (ImpPrSg2  >sagelienamastima !28_V	et	f	\N
150310	trammi	trammi =trammi  (ID  >trammi !41_D	et	f	\N
150311	trammi	trammi =trammi  (SgG  >tramm !22_S	et	f	\N
150312	trammi	trammi =trammi  (SgP  >tramm !22_S	et	f	\N
150313	trammi	trammi =trammi  (SgAdt  >tramm !22_S	et	f	\N
150316	korraldadud	?korraldadud =korraldadu  (IndPrSg2  >korraldaduma !27_V	et	f	\N
150317	korraldadud	?korraldadud =korraldadud  (ID  >korraldadud !41_A	et	f	\N
150320	kruunuhaku	?kruunuhaku =kruunuhaku  (IndPrPs_  >kruunuhakuma !27_V	et	f	\N
150321	kruunuhaku	?kruunuhaku =kruunuhaku  (ImpPrSg2  >kruunuhakuma !27_V	et	f	\N
150350	kalevipoeg-sambale	kalevipoeg-sambale =samba  (SgAll  >kalevipoeg-sammas !07_S	et	f	\N
150351	kalevipoeg-sambale	kalevipoeg-sambale =samba  (SgAll  >kalevipoeg-samba !16_S	et	f	\N
150352	tornmaja	tornmaja =maja  (SgN  >torn+maja !17_S	et	f	\N
150353	tornmaja	tornmaja =maja  (SgG  >torn+maja !17_S	et	f	\N
150354	tornmaja	tornmaja =maja  (SgP  >torn+maja !17_S	et	f	\N
150359	1990-ndate	?-ndate =ndate  (SgN  >-ndate !06_S	et	f	\N
150360	1990-ndate	?-ndate =ndate  (IndPrPs_  >-ndatema !27_V	et	f	\N
150361	1990-ndate	?-ndate =ndate  (ImpPrSg2  >-ndatema !27_V	et	f	\N
150375	suurust	suurust =suurus  (SgP  >suurus !11~09_S	et	f	\N
150376	suurust	"suurus %suur  )US_aS  <suur ;13_A	et	f	\N
150377	suurust	suurust =suurus  (SgP  >suurune !10~12_A	et	f	\N
150155	mitmekorrusellise	?mitmekorrusellise =mitmekorrusellise  (SgG  >mitmekorruselline !12_A	et	f	\N
150156	mitmekorrusellise	?mitmekorrusellise =korrusellise  (SgG  >mitme+korruselline !12_A	et	f	\N
150160	obeliski	obeliski =obeliski  (SgG  >obelisk !22_S	et	f	\N
150161	obeliski	obeliski =obeliski  (SgP  >obelisk !22_S	et	f	\N
150162	obeliski	obeliski =obeliski  (SgAdt  >obelisk !22_S	et	f	\N
150163	skulptoriühingu	?skulptoriühingu =skulptoriühingu  (SgG  >skulptoriühing !02_S	et	f	\N
150164	skulptoriühingu	?skulptoriühingu =skulptoriühingu  (IndPrPs_  >skulptoriühinguma !27_V	et	f	\N
150165	skulptoriühingu	?skulptoriühingu =skulptoriühingu  (ImpPrSg2  >skulptoriühinguma !27_V	et	f	\N
150184	asetäitja	asetäitja =täitja  (SgN  >ase+täitja !01_S	et	f	\N
150185	asetäitja	asetäitja =täitja  (SgG  >ase+täitja !01_S	et	f	\N
150194	sanatooriumi	sanatooriumi =sanatooriumi  (SgG  >sanatoorium !19~02_S	et	f	\N
150195	sanatooriumi	sanatooriumi =sanatooriumi  (SgP  >sanatoorium !19_S	et	f	\N
150196	sanatooriumi	sanatooriumi =sanatooriumi  (SgAdt  >sanatoorium !19_S	et	f	\N
150208	sammas	sammas =samma  (SgIn  >samb !22_S	et	f	\N
150209	sammas	sammas =sammas  (SgN  >sammas !07_S	et	f	\N
150237	kohda	?kohda =kohda  (SgN  >kohda !16_S	et	f	\N
150238	kohda	?kohda =kohda  (SgG  >kohda !16_S	et	f	\N
150239	kohda	?kohda =kohda  (IndPrPs_  >kohdama !29_V	et	f	\N
150240	kohda	?kohda =kohda  (ImpPrSg2  >kohdama !29_V	et	f	\N
150260	näituseks	näituseks =näituse  (SgTr  >näitus !11~09_S	et	f	\N
150261	näituseks	näituseks =use  (PlTr  >näit+usk !22_S	et	f	\N
150275	teemalisest	teemalisest =teemalise  (SgEl  >teemaline !12_A	et	f	\N
150276	teemalisest	"teemaline %teema  )LINE_aA  <teema ;16_S	et	f	\N
150277	teemalisest	teemalisest =malise  (SgEl  >tee+maline !10_A	et	f	\N
150278	teemalisest	"tee+maline %mali  )NE_aA  <tee+mali ;17_S	et	f	\N
150281	muistsuskaitsekomisjonis	?muistsuskaitsekomisjonis =muistsuskaitsekomisjoni  (SgIn  >muistsuskaitsekomisjon !02_S	et	f	\N
150282	muistsuskaitsekomisjonis	?muistsuskaitsekomisjonis =muistsuskaitsekomisjonis  (SgN  >muistsuskaitsekomisjonis !09_S	et	f	\N
150296	portree	portree =portree  (SgN  >portree !26_S	et	f	\N
150297	portree	portree =portree  (SgG  >portree !26_S	et	f	\N
150298	portree	portree =ree  (SgG  >port+regi !21_S	et	f	\N
150324	linnlastele	linnlastele =las  (PlAll  >linn+laps !14_S	et	f	\N
150325	linnlastele	linnlastele =laste  (PlAll  >linn+last !22_S	et	f	\N
150333	lopetas	?lopetas =lopeta  (IndIpfSg3  >lopetama !27_V	et	f	\N
150379	osakaalu	osakaalu =kaalu  (SgG  >osa+kaal !22_S	et	f	\N
150380	osakaalu	osakaalu =kaalu  (SgP  >osa+kaal !22_S	et	f	\N
150381	osakaalu	osakaalu =kaalu  (SgAdt  >osa+kaal !22_S	et	f	\N
150412	pystitatud	?pystitatud =pystita  (PtsPtIps  >pystitama !27_V	et	f	\N
150413	pystitatud	?pystitatud =pystitatu  (PlN  >pystitatu !01_S	et	f	\N
150414	pystitatud	?pystitatud =pystitatu  (IndPrSg2  >pystitatuma !27_V	et	f	\N
150415	pystitatud	?pystitatud =pystitatud  (ID  >pystitatud !41_A	et	f	\N
150417	sygisehakul	?sygisehakul =sygisehakul  (SgN  >sygisehakul !19_S	et	f	\N
150440	löpus	?löpus =löpu  (SgIn  >löpu !16_S	et	f	\N
150441	löpus	?löpus =löpu  (IndIpfSg3  >löpuma !27_V	et	f	\N
150442	löpus	?löpus =löpus  (SgN  >löpus !09_S	et	f	\N
150464	visualiseerimise	?visualiseerimise =visualiseerimise  (SgG  >visualiseerimine !12_S	et	f	\N
150474	innustav	innustav =innusta  (PtsPrPs  >innustama !27_V	et	f	\N
150475	innustav	innustav =innustav  (SgN  >innustav !02_A	et	f	\N
150476	innustav	"innustav %innusta  )V_vA  <innustama ;27_V	et	f	\N
150482	käeline	käeline =käeline  (SgN  >käeline !12?10_A	et	f	\N
150483	käeline	"käeline %käe  )LINE_aA  <käsi ;15_S	et	f	\N
150484	möni	?möni =möni  (SgN  >möni !17_S	et	f	\N
150485	möni	?möni =möni  (SgG  >möni !17_S	et	f	\N
150486	möni	?möni =möni  (SgP  >möni !17_S	et	f	\N
150487	möni	?möni =möni  (IndPrPs_  >mönima !27_V	et	f	\N
150488	möni	?möni =möni  (ImpPrSg2  >mönima !27_V	et	f	\N
150489	symboliseerivad	?symboliseerivad =symboliseeri  (IndPrPl3  >symboliseerima !28_V	et	f	\N
150490	symboliseerivad	?symboliseerivad =symboliseeriva  (PlN  >symboliseeriv !02_A	et	f	\N
150491	symboliseerivad	?symboliseerivad =symboliseeriva  (PlN  >symboliseeriva !16_S	et	f	\N
150492	yhendusele	?yhendusele =yhenduse  (SgAll  >yhendus !11_S	et	f	\N
150494	köige	?köige =köige  (SgN  >köige !06_S	et	f	\N
150495	köige	?köige =köige  (PlP  >köig !22_S	et	f	\N
150496	köige	?köige =köige  (IndPrPs_  >köigema !27_V	et	f	\N
150497	köige	?köige =köige  (ImpPrSg2  >köigema !27_V	et	f	\N
150516	mötiskletud	?mötiskletud =mötiskle  (PtsPtIps  >mötisklema !27_V	et	f	\N
150517	mötiskletud	?mötiskletud =mötiskletu  (PlN  >mötiskletu !01_S	et	f	\N
150518	mötiskletud	?mötiskletud =mötiskletu  (IndPrSg2  >mötiskletuma !27_V	et	f	\N
150519	mötiskletud	?mötiskletud =mötiskletud  (ID  >mötiskletud !41_A	et	f	\N
150525	vöistlustöödest	?vöistlustöödest =vöistlustöö  (PlEl  >vöistlustöö !26_S	et	f	\N
150526	vöistlustöödest	?vöistlustöödest =vöistlustööde  (SgEl  >vöistlustööde !16_S	et	f	\N
150527	vöistlustöödest	?vöistlustöödest =vöistlustööde  (PlEl  >vöistlustööt !22_S	et	f	\N
150528	vöistlustöödest	?vöistlustöödest =vöistlustöödes  (SgP  >vöistlustöödene !10_A	et	f	\N
150545	palvinud	?palvinud =palvi  (PtsPtPs  >palvima !28_V	et	f	\N
150167	arhitektite	?arhitektite =arhitekti  (IndPrPl2  >arhitektima !28_V	et	f	\N
150173	kavatsust	kavatsust =kavatsus  (SgP  >kavatsus !11_S	et	f	\N
150174	kavatsust	"kavatsus %kavatse  )US_vS  <kavatsema ;27_V	et	f	\N
150176	idéeks	### idéeks	et	f	\N
150215	vaatevinkelist	vaatevinkelist =vinkeli  (SgEl  >vaate+vinkel !02_S	et	f	\N
150216	vaatevinkelist	vaatevinkelist =vinkelis  (SgP  >vaate+vinkeline !12_A	et	f	\N
150217	vaatevinkelist	"vaate+vinkeline %vinkeli  )NE_aA  <vaate+vinkel ;02_S	et	f	\N
150224	samba	samba =samba  (SgN  >samba !16_S	et	f	\N
150225	samba	samba =samba  (SgG  >sammas !07_S	et	f	\N
150226	samba	samba =samba  (SgG  >samba !16_S	et	f	\N
150227	samba	samba =samba  (SgP  >samb !22_S	et	f	\N
150228	samba	samba =samba  (SgAdt  >samb !22_S	et	f	\N
150243	idéet	### idéet	et	f	\N
150279	aastade	?aastade =tade  (SgN  >aas+tade !16_S	et	f	\N
150280	aastade	?aastade =tade  (SgG  >aas+tade !16_S	et	f	\N
150308	linnlaste	linnlaste =las  (PlG  >linn+laps !14_S	et	f	\N
150309	linnlaste	linnlaste =laste  (PlP  >linn+last !22_S	et	f	\N
150314	möödev	?möödev =mööde  (PtsPrPs  >möödema !27_V	et	f	\N
150315	möödev	?möödev =möödev  (SgN  >möödev !02_A	et	f	\N
150318	uurimisretkel	uurimisretkel =retke  (SgAd  >uurimis+retk !22_S	et	f	\N
150319	uurimisretkel	uurimisretkel =retke  (PlAd  >uurimis+retk !22_S	et	f	\N
150322	vaatepilti	vaatepilti =pilti  (SgP  >vaate+pilt !22_S	et	f	\N
150323	vaatepilti	vaatepilti =pilti  (SgAdt  >vaate+pilt !22_S	et	f	\N
150326	protokollist	protokollist =protokolli  (SgEl  >protokoll !22_S	et	f	\N
150327	protokollist	protokollist =protokollis  (SgP  >protokolline !12_A	et	f	\N
150328	protokollist	"protokolline %protokolli  )NE_aA  <protokoll ;22_S	et	f	\N
150329	protokollist	protokollist =kolli  (SgEl  >proto+koll !22_S	et	f	\N
150330	protokollist	protokollist =kolli  (PlEl  >proto+kold !22_S	et	f	\N
150331	protokollist	protokollist =kollis  (SgP  >proto+kolline !10_A	et	f	\N
150332	protokollist	"proto+kolline %kolli  )NE_aA  <proto+koll ;22_S	et	f	\N
150339	põhinenud	põhinenud =põhine  (PtsPtPs  >põhinema !27_V	et	f	\N
150340	põhinenud	põhinenud =põhinenu  (PlN  >põhinenu !01_S	et	f	\N
150341	põhinenud	"põhinenu %põhine  )NU_vS  <põhinema ;27_V	et	f	\N
150342	põhinenud	põhinenud =põhinenud  (ID  >põhinenud !41_A	et	f	\N
150343	põhinenud	"põhinenud %põhine  )NUD_vA  <põhinema ;27_V	et	f	\N
150355	monumendikompleks	### monumendikompleks	et	f	\N
150365	algpärases	algpärases =pärase  (SgIn  >alg+pärane !10_A	et	f	\N
150366	algpärases	"alg+pärane %pära  )NE_aA  <alg+pära ;17_S	et	f	\N
150370	pakkumist	pakkumist =pakkumis  (SgP  >pakkumine !12_S	et	f	\N
150371	pakkumist	"pakkumine %pakku  )MINE_vS  <pakkuma ;28_V	et	f	\N
150372	monumentaalskulptuuri	monumentaalskulptuuri =skulptuuri  (SgG  >monumentaal+skulptuur !22_S	et	f	\N
150373	monumentaalskulptuuri	monumentaalskulptuuri =skulptuuri  (SgP  >monumentaal+skulptuur !22_S	et	f	\N
150374	monumentaalskulptuuri	monumentaalskulptuuri =skulptuuri  (SgAdt  >monumentaal+skulptuur !22_S	et	f	\N
150403	21m	### 21m	et	f	\N
150418	zyriist	?zyriist =zyrii  (SgEl  >zyrii !26_S	et	f	\N
150419	zyriist	?zyriist =zyriist  (SgN  >zyriist !22_S	et	f	\N
150421	zyrii	?zyrii =zyrii  (SgN  >zyrii !26_S	et	f	\N
150422	zyrii	?zyrii =zyrii  (SgG  >zyrii !26_S	et	f	\N
150428	söltumatu	?söltumatu =söltumatu  (SgN  >söltumatu !01_A	et	f	\N
150429	söltumatu	?söltumatu =söltumatu  (SgG  >söltumatu !01_A	et	f	\N
150430	söltumatu	?söltumatu =söltumatu  (IndPrPs_  >söltumatuma !27_V	et	f	\N
150431	söltumatu	?söltumatu =söltumatu  (ImpPrSg2  >söltumatuma !27_V	et	f	\N
150446	luau	### luau	et	f	\N
150457	päraselt	päraselt =pärase  (SgAbl  >pärane !10_A	et	f	\N
150458	päraselt	"pärane %pära  )NE_aA  <pära ;17_S	et	f	\N
150459	päraselt	päraselt =päraselt  (ID  >päraselt !41_D	et	f	\N
150460	päraselt	"päraselt %pära  )SELT_mD  <pära ;17_S	et	f	\N
150461	päraselt	"päraselt %pärase  )LT_mD  <pärane ;10_A	et	f	\N
150466	sötnik	?sötnik =sötnik  (SgN  >sötnik !25_S	et	f	\N
150467	sötniku	?sötniku =sötniku  (SgN  >sötniku !01_S	et	f	\N
150468	sötniku	?sötniku =sötniku  (SgG  >sötniku !01_S	et	f	\N
150469	sötniku	?sötniku =sötniku  (SgG  >sötnik !25_S	et	f	\N
150470	sötniku	?sötniku =sötniku  (IndPrPs_  >sötnikuma !27_V	et	f	\N
150471	sötniku	?sötniku =sötniku  (ImpPrSg2  >sötnikuma !27_V	et	f	\N
150493	möjuvöimas	### möjuvöimas	et	f	\N
150498	vöimu	?vöimu =vöimu  (SgN  >vöimu !16_S	et	f	\N
150500	vöimu	?vöimu =vöimu  (SgG  >vöimu !16_S	et	f	\N
150501	vöimu	?vöimu =vöimu  (IndPrPs_  >vöimuma !27_V	et	f	\N
150502	vöimu	?vöimu =vöimu  (ImpPrSg2  >vöimuma !27_V	et	f	\N
150541	meeldumust	meeldumust =meeldumus  (SgP  >meeldumus !11_S	et	f	\N
150542	meeldumust	"meeldumus %meeldu  )MUS_vS  <meelduma ;27_V	et	f	\N
150556	paet	?paet =paet  (SgN  >paet !22_S	et	f	\N
150560	eli	?eli =eli  (SgN  >eli !17_S	et	f	\N
150561	eli	?eli =eli  (SgG  >eli !17_S	et	f	\N
150562	eli	?eli =eli  (SgP  >eli !17_S	et	f	\N
150563	eli	?eli =eli  (IndPrPs_  >elima !27_V	et	f	\N
150564	eli	?eli =eli  (ImpPrSg2  >elima !27_V	et	f	\N
150378	suurust	suurust =us  (SgP  >suur+uks !14_S	et	f	\N
150382	töötavas	töötavas =töötava  (SgIn  >töötav !02_A	et	f	\N
150383	töötavas	"töötav %tööta  )V_vA  <töötama ;27_V	et	f	\N
150384	töötavas	töötavas =tava  (SgIn  >töö+tava !17_S	et	f	\N
150390	heida	heida =heida  (IndPrPs_  >heitma !34_V	et	f	\N
150391	heida	heida =heida  (ImpPrSg2  >heitma !34_V	et	f	\N
150400	vöistlustööd	?vöistlustööd =vöistlustöö  (PlN  >vöistlustöö !26_S	et	f	\N
150401	vöistlustööd	?vöistlustööd =vöistlustöö  (SgP  >vöistlustöö !26_S	et	f	\N
150402	vöistlustööd	?vöistlustööd =vöistlustööd  (SgN  >vöistlustööd !22_S	et	f	\N
150432	tekitanud	tekitanud =tekita  (PtsPtPs  >tekitama !27_V	et	f	\N
150433	tekitanud	tekitanud =tekitanu  (PlN  >tekitanu !01_S	et	f	\N
150434	tekitanud	"tekitanu %tekita  )NU_vS  <tekitama ;27_V	et	f	\N
150435	tekitanud	tekitanud =tekitanud  (ID  >tekitanud !41_A	et	f	\N
150436	tekitanud	"tekitanud %tekita  )NUD_vA  <tekitama ;27_V	et	f	\N
150437	tekitanud	tekitanud =tanu  (PlN  >teki+tanu !17_S	et	f	\N
150448	kopenhaagenis	?kopenhaagenis =kopenhaageni  (SgIn  >kopenhaagen !02_S	et	f	\N
150449	kopenhaagenis	?kopenhaagenis =kopenhaagenis  (SgN  >kopenhaagenis !09_S	et	f	\N
150452	esialse	?esialse =esialse  (SgG  >esialne !02_A	et	f	\N
150453	esialse	?esialse =esialse  (PlP  >esials !22_S	et	f	\N
150454	esialse	?esialse =alse  (SgN  >esi+alse !06_S	et	f	\N
150455	esialse	?esialse =alse  (SgG  >esi+alne !02_A	et	f	\N
150456	esialse	?esialse =alse  (PlP  >esi+als !22_S	et	f	\N
150462	14m	### 14m	et	f	\N
150477	kyll	?kyll =kyll  (SgN  >kyll !22_S	et	f	\N
150478	kannustavalt	kannustavalt =kannustava  (SgAbl  >kannustav !02_A	et	f	\N
150479	kannustavalt	"kannustav %kannusta  )V_vA  <kannustama ;27_V	et	f	\N
150480	kannustavalt	kannustavalt =kannustavalt  (ID  >kannustavalt !41_D	et	f	\N
150481	kannustavalt	"kannustavalt %kannusta  )VALT_mD  <kannustama ;27_V	et	f	\N
150499	keskerakonnal	keskerakonnal =konna  (SgAd  >kesk+era+konn !22_S	et	f	\N
150503	keskerakonnal	keskerakonnal =erakonna  (SgAd  >kesk+erakond !22_S	et	f	\N
150520	yle	?yle =yle  (SgN  >yle !16_S	et	f	\N
150521	yle	?yle =yle  (SgG  >yle !16_S	et	f	\N
150522	yle	?yle =yle  (IndPrPs_  >ylema !27_V	et	f	\N
150523	yle	?yle =yle  (ImpPrSg2  >ylema !27_V	et	f	\N
150524	vöistluse	?vöistluse =vöistluse  (SgG  >vöistlus !11~09_S	et	f	\N
150529	sönul	?sönul =sönu  (SgAd  >sönu !17_S	et	f	\N
150530	sönul	?sönul =sönul  (SgN  >sönul !02_S	et	f	\N
150533	rattase	rattase =rattase  (SgG  >rattane !12~10_A	et	f	\N
150534	rattase	"rattane %ratta  )NE_aA  <ratas ;07_S	et	f	\N
150535	turistite	?turistite =turisti  (PlG  >turisti !01_S	et	f	\N
150536	turistite	?turistite =turisti  (IndPrPl2  >turistima !28_V	et	f	\N
150543	kõrghoonete	kõrghoonete =hoone  (PlG  >kõrg+hoone !06_S	et	f	\N
150544	kõrghoonete	"kõrg+hoone %hoo  )NE_aA  <kõrg+hoog ;22_S	et	f	\N
150570	loode-venemaal	loode-venemaal =maa  (SgAd  >loode-vene+maa !26_S	et	f	\N
150571	loode-venemaal	loode-venemaal =maal  (SgN  >loode-vene+maal !22_S	et	f	\N
150572	tugevdamine	tugevdamine =tugevdamine  (SgN  >tugevdamine !12_S	et	f	\N
150573	tugevdamine	"tugevdamine %tugevda  )MINE_vS  <tugevdama ;27_V	et	f	\N
150574	stabiilsuse	stabiilsuse =stabiilsuse  (SgG  >stabiilsus !11~09_S	et	f	\N
150575	stabiilsuse	"stabiilsus %stabiilse  )US_aS  <stabiilne ;02_A	et	f	\N
150578	islandi	?islandi =islandi  (SgN  >islandi !01_S	et	f	\N
150579	islandi	?islandi =islandi  (SgG  >islandi !01_S	et	f	\N
150580	islandi	?islandi =islandi  (SgG  >island !02_S	et	f	\N
150581	islandi	?islandi =islandi  (SgG  >islant !22_S	et	f	\N
150582	islandi	?islandi =islandi  (IndPrPs_  >islantima !28_V	et	f	\N
150583	islandi	?islandi =islandi  (ImpPrSg2  >islantima !28_V	et	f	\N
150591	barentsi	?barentsi =barentsi  (SgN  >barentsi !01_S	et	f	\N
150592	barentsi	?barentsi =barentsi  (SgG  >barentsi !01_S	et	f	\N
150593	barentsi	?barentsi =barentsi  (SgG  >barents !22_S	et	f	\N
150594	barentsi	?barentsi =barentsi  (SgP  >barents !22_S	et	f	\N
150595	barentsi	?barentsi =barentsi  (SgAdt  >barents !22_S	et	f	\N
150596	barentsi	?barentsi =barentsi  (IndPrPs_  >barentsima !28_V	et	f	\N
150597	barentsi	?barentsi =barentsi  (ImpPrSg2  >barentsima !28_V	et	f	\N
150611	õigus-	õigus- =õigus  (SgN  >õigus !11~09_S	et	f	\N
150612	õigus-	"õigus %õige  )US_aS  <õige ;01_A	et	f	\N
150618	konkresetes	?konkresetes =konkresete  (PlIn  >konkresett !22_S	et	f	\N
150627	tuumajäätmete	tuumajäätmete =me  (PlG  >tuuma+jäät+mesi !15_S	et	f	\N
150628	tuumajäätmete	tuumajäätmete =jäätme  (PlG  >tuuma+jääde !05_S	et	f	\N
150681	vähenenud	vähenenud =vähene  (PtsPtPs  >vähenema !27_V	et	f	\N
150682	vähenenud	vähenenud =vähenenu  (PlN  >vähenenu !01_S	et	f	\N
150683	vähenenud	"vähenenu %vähene  )NU_vS  <vähenema ;27_V	et	f	\N
150684	vähenenud	vähenenud =vähenenud  (ID  >vähenenud !41_A	et	f	\N
150685	vähenenud	"vähenenud %vähene  )NUD_vA  <vähenema ;27_V	et	f	\N
150696	dimensiooni	dimensiooni =dimensiooni  (SgG  >dimensioon !22_S	et	f	\N
150698	dimensiooni	dimensiooni =dimensiooni  (SgP  >dimensioon !22_S	et	f	\N
150700	dimensiooni	dimensiooni =dimensiooni  (SgAdt  >dimensioon !22_S	et	f	\N
150410	esmaspäevaseks	"esmas+päevane %päeva  )NE_aA  <esmas+päev ;22_S	et	f	\N
150416	yhenduse	?yhenduse =yhenduse  (SgG  >yhendus !11_S	et	f	\N
150423	jyri	?jyri =jyri  (SgN  >jyri !17_S	et	f	\N
150424	jyri	?jyri =jyri  (SgG  >jyri !17_S	et	f	\N
150425	jyri	?jyri =jyri  (SgP  >jyri !17_S	et	f	\N
150426	jyri	?jyri =jyri  (IndPrPs_  >jyrima !27_V	et	f	\N
150427	jyri	?jyri =jyri  (ImpPrSg2  >jyrima !27_V	et	f	\N
150450	symbol	?symbol =symbo  (SgAd  >symbo !16_S	et	f	\N
150451	symbol	?symbol =symbol  (SgN  >symbol !02_S	et	f	\N
150463	körgust	?körgust =körgus  (SgP  >körgus !11~09_S	et	f	\N
150465	pöhjendab	?pöhjendab =pöhjenda  (IndPrSg3  >pöhjendama !27_V	et	f	\N
150472	botaanika-aeda	botaanika-aeda =aeda  (SgP  >botaanika-aed !22_S	et	f	\N
150473	botaanika-aeda	botaanika-aeda =aeda  (SgAdt  >botaanika-aed !22_S	et	f	\N
150531	konkurssile	?konkurssile =konkurssi  (SgAll  >konkurssi !01_S	et	f	\N
150537	linnavalitsushoone	linnavalitsushoone =hoone  (SgN  >linna+valitsus+hoone !06_S	et	f	\N
150538	linnavalitsushoone	"linna+valitsus+hoone %hoo  )NE_aA  <linna+valitsus+hoog ;22_S	et	f	\N
150539	linnavalitsushoone	linnavalitsushoone =hoone  (SgG  >linna+valitsus+hoone !06_S	et	f	\N
150540	linnavalitsushoone	linnavalitsushoone =hoone  (PlP  >linna+valitsus+hoon !22_A	et	f	\N
150552	mõõdet	mõõdet =mõõde  (SgP  >mõõde !05_S	et	f	\N
150553	mõõdet	mõõdet =mõõde  (SgP  >mõõde !06_S	et	f	\N
150557	tuomioja	?tuomioja =tuomioja  (SgN  >tuomioja !01_S	et	f	\N
150558	tuomioja	?tuomioja =tuomioja  (SgG  >tuomioja !01_S	et	f	\N
150559	tuomioja	?tuomioja =tuomioja  (SgG  >tuomiojas !02_A	et	f	\N
150567	välispoliitika	välispoliitika =poliitika  (SgN  >välis+poliitika !01_S	et	f	\N
150568	välispoliitika	välispoliitika =poliitika  (SgG  >välis+poliitika !01_S	et	f	\N
150576	lisamiseks	lisamiseks =lisamise  (SgTr  >lisamine !12_S	et	f	\N
150577	lisamiseks	"lisamine %lisa  )MINE_vS  <lisama ;27_V	et	f	\N
150584	vaadlejariigid	?vaadlejariigid =vaadlejariigi  (PlN  >vaadlejariigi !16_S	et	f	\N
150585	vaadlejariigid	?vaadlejariigid =vaadlejariigi  (PlN  >vaadlejariik !22_S	et	f	\N
150586	vaadlejariigid	?vaadlejariigid =vaadlejariigi  (IndPrSg2  >vaadlejariikima !28_V	et	f	\N
150599	ministrinõukogu	ministrinõukogu =kogu  (SgN  >ministri+nõu+kogu !17_S	et	f	\N
150600	ministrinõukogu	ministrinõukogu =kogu  (SgG  >ministri+nõu+kogu !17_S	et	f	\N
150601	ministrinõukogu	ministrinõukogu =kogu  (SgP  >ministri+nõu+kogu !17_S	et	f	\N
150613	kirde-euroopa	kirde-euroopa =euroopa  (ID  >kirde-euroopa !41_G	et	f	\N
150614	kirde-euroopa	kirde-euroopa =euroopa  (SgN  >kirde-euroopa !01_H	et	f	\N
150615	kirde-euroopa	kirde-euroopa =euroopa  (SgG  >kirde-euroopa !01_H	et	f	\N
150616	avamiseks	avamiseks =avamise  (SgTr  >avamine !12_S	et	f	\N
150617	avamiseks	"avamine %ava  )MINE_vS  <avama ;27_V	et	f	\N
150619	sotsiaal-	?sotsiaal- =sotsiaa  (SgAd  >sotsiaa !26_S	et	f	\N
150620	sotsiaal-	?sotsiaal- =sotsiaal  (SgN  >sotsiaal !22_S	et	f	\N
150621	puhastamine	puhastamine =puhastamine  (SgN  >puhastamine !12_S	et	f	\N
150622	puhastamine	"puhastamine %puhasta  )MINE_vS  <puhastama ;27_V	et	f	\N
150633	lisatakse	lisatakse =lisa  (IndPrIps  >lisama !27_V	et	f	\N
150634	lisatakse	lisatakse =takse  (PlP  >lisa+taks !22_S	et	f	\N
150643	summaga	summaga =summa  (SgKom  >summa !16_S	et	f	\N
150644	summaga	summaga =summa  (SgKom  >summ !22_S	et	f	\N
150645	summaga	summaga =summa  (SgKom  >sumb !22_S	et	f	\N
150659	peaosa	peaosa =osa  (SgN  >pea+osa !17_S	et	f	\N
150660	peaosa	peaosa =osa  (SgG  >pea+osa !17_S	et	f	\N
150661	peaosa	peaosa =osa  (SgP  >pea+osa !17_S	et	f	\N
150672	rahvusvahelistelt	rahvusvahelistelt =vahelis  (PlAbl  >rahvus+vaheline !12_A	et	f	\N
150673	rahvusvahelistelt	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
150705	pöhja	?pöhja =pöhja  (SgN  >pöhja !16_S	et	f	\N
150706	pöhja	?pöhja =pöhja  (SgG  >pöhjas !02_A	et	f	\N
150707	pöhja	?pöhja =pöhja  (SgG  >pöhja !16_S	et	f	\N
150708	pöhja	?pöhja =pöhja  (IndPrPs_  >pöhjama !29_V	et	f	\N
150709	pöhja	?pöhja =pöhja  (ImpPrSg2  >pöhjama !29_V	et	f	\N
150742	pöhialad	?pöhialad =pöhiala  (PlN  >pöhiala !01_S	et	f	\N
150743	öigus	?öigus =öigu  (SgIn  >öigu !16_S	et	f	\N
150744	öigus	?öigus =öigu  (IndIpfSg3  >öiguma !27_V	et	f	\N
150745	öigus	?öigus =öigus  (SgN  >öigus !11~09_S	et	f	\N
150748	vöib	?vöib =vöib  (SgN  >vöib !22_S	et	f	\N
150749	körgema	?körgema =körge  (Sup  >körgema !27_V	et	f	\N
150750	körgema	?körgema =körgema  (SgG  >körgem !02_A	et	f	\N
150753	avamisel	avamisel =avamise  (SgAd  >avamine !12_S	et	f	\N
150754	avamisel	"avamine %ava  )MINE_vS  <avama ;27_V	et	f	\N
150759	kaasamine	kaasamine =kaasamine  (SgN  >kaasamine !12_S	et	f	\N
150760	kaasamine	"kaasamine %kaasa  )MINE_vS  <kaasama ;29_V	et	f	\N
150768	jäätmete	jäätmete =jäätme  (PlG  >jääde !05_S	et	f	\N
150769	jäätmete	jäätmete =me  (PlG  >jäät+mesi !15_S	et	f	\N
150776	turvalisemasse	turvalisemasse =turvalisema  (SgIll  >turvalisem !02_A	et	f	\N
150777	turvalisemasse	"turvalisem %turva  )LISEM_cA  <turb ;22_SA	et	f	\N
150778	turvalisemasse	"turvalisem %turva  )LISEM_cA  <turv ;22_S	et	f	\N
150779	turvalisemasse	"turvalisem %turvalise  )M_cA  <turvaline ;12_A	et	f	\N
150443	tallinnassa	?tallinnassa =tallinnassa  (SgN  >tallinnassa !16_S	et	f	\N
150444	tallinnassa	?tallinnassa =tallinnassa  (SgG  >tallinnassa !16_S	et	f	\N
150445	tallinnassa	?tallinnassa =assa  (SgN  >tallinn+assa !16_S	et	f	\N
150447	tallinnassa	?tallinnassa =assa  (SgG  >tallinn+assa !16_S	et	f	\N
150504	körgete	?körgete =körge  (PlG  >körge !06_S	et	f	\N
150505	körgete	?körgete =körge  (IndPrPl2  >körgema !27_V	et	f	\N
150506	tutvustanud	tutvustanud =tutvusta  (PtsPtPs  >tutvustama !27_V	et	f	\N
150507	tutvustanud	tutvustanud =tutvustanu  (PlN  >tutvustanu !01_S	et	f	\N
150508	tutvustanud	"tutvustanu %tutvusta  )NU_vS  <tutvustama ;27_V	et	f	\N
150509	tutvustanud	tutvustanud =tutvustanud  (ID  >tutvustanud !41_A	et	f	\N
150510	tutvustanud	"tutvustanud %tutvusta  )NUD_vA  <tutvustama ;27_V	et	f	\N
150511	tutvustanud	tutvustanud =tanu  (PlN  >tutvus+tanu !17_S	et	f	\N
150512	yhe	?yhe =yhe  (SgN  >yhe !16_S	et	f	\N
150513	yhe	?yhe =yhe  (SgG  >yhe !16_S	et	f	\N
150514	yhe	?yhe =yhe  (IndPrPs_  >yhema !27_V	et	f	\N
150515	yhe	?yhe =yhe  (ImpPrSg2  >yhema !27_V	et	f	\N
150532	ametnikute	?ametnikute =ametniku  (IndPrPl2  >ametnikuma !27_V	et	f	\N
150565	mõõde	mõõde =mõõde  (SgN  >mõõde !05_S	et	f	\N
150566	mõõde	mõõde =mõõde  (SgN  >mõõde !06_S	et	f	\N
150569	elil	?elil =eli  (SgAd  >eli !17_S	et	f	\N
150602	ministrinõukogu	ministrinõukogu =kogu  (SgN  >ministri+nõu+kogu !17_S	et	f	\N
150603	ministrinõukogu	ministrinõukogu =kogu  (SgG  >ministri+nõu+kogu !17_S	et	f	\N
150604	ministrinõukogu	ministrinõukogu =kogu  (SgP  >ministri+nõu+kogu !17_S	et	f	\N
150629	turvalisemale	turvalisemale =turvalisema  (SgAll  >turvalisem !02_A	et	f	\N
150630	turvalisemale	"turvalisem %turva  )LISEM_cA  <turb ;22_SA	et	f	\N
150631	turvalisemale	"turvalisem %turva  )LISEM_cA  <turv ;22_S	et	f	\N
150632	turvalisemale	"turvalisem %turvalise  )M_cA  <turvaline ;12_A	et	f	\N
150635	esialgselt	esialgselt =algse  (SgAbl  >esi+algne !02_A	et	f	\N
150636	esialgselt	"esi+algselt %algse  )LT_mD  <esi+algne ;02_A	et	f	\N
150651	elile	?elile =eli  (SgAll  >eli !17_S	et	f	\N
150652	elile	?elile =elile  (IndPrPs_  >elilema !27_V	et	f	\N
150653	elile	?elile =elile  (ImpPrSg2  >elilema !27_V	et	f	\N
150654	annetanud	annetanud =anneta  (PtsPtPs  >annetama !27_V	et	f	\N
150655	annetanud	annetanud =annetanu  (PlN  >annetanu !01_S	et	f	\N
150656	annetanud	"annetanu %anneta  )NU_vS  <annetama ;27_V	et	f	\N
150657	annetanud	annetanud =annetanud  (ID  >annetanud !41_A	et	f	\N
150658	annetanud	"annetanud %anneta  )NUD_vA  <annetama ;27_V	et	f	\N
150667	annetus	annetus =annetu  (SgIn  >annetu !01_A	et	f	\N
150669	annetus	annetus =annetus  (SgN  >annetus !11_S	et	f	\N
150670	annetus	"annetus %anneta  )US_vS  <annetama ;27_V	et	f	\N
150676	valminud	valminud =valmi  (PtsPtPs  >valmima !27_V	et	f	\N
150677	valminud	valminud =valminu  (PlN  >valminu !01_S	et	f	\N
150678	valminud	"valminu %valmi  )NU_vS  <valmima ;27_V	et	f	\N
150679	valminud	valminud =valminud  (ID  >valminud !41_A	et	f	\N
150680	valminud	"valminud %valmi  )NUD_vA  <valmima ;27_V	et	f	\N
150688	murmanski	?murmanski =murmanski  (SgG  >murmansk !02_S	et	f	\N
150689	murmanski	?murmanski =murmanski  (IndPrPs_  >murmanskima !28_V	et	f	\N
150690	murmanski	?murmanski =murmanski  (ImpPrSg2  >murmanskima !28_V	et	f	\N
150691	murmanski	?murmanski =murmans  (SgN^  >murmans !02_S	et	f	\N
150710	möte	?möte =möte  (SgN  >möte !06_S	et	f	\N
150711	möte	?möte =möte  (IndPrPs_  >mötema !27_V	et	f	\N
150712	möte	?möte =möte  (ImpPrSg2  >mötema !27_V	et	f	\N
150721	kagu-euuropas	?kagu-euuropas =euuropa  (SgIn  >kagu-euuropa !16_S	et	f	\N
150723	komissjon	?komissjon =komissjon  (SgN  >komissjon !02_S	et	f	\N
150724	komissjon	?komissjon =issjon  (SgN  >kom+issjon !02_S	et	f	\N
150730	nöukogu	?nöukogu =nöukogu  (IndPrPs_  >nöukoguma !27_V	et	f	\N
150731	nöukogu	?nöukogu =nöukogu  (ImpPrSg2  >nöukoguma !27_V	et	f	\N
150751	könedes	?könedes =köne  (PlIn  >köne !16_S	et	f	\N
150752	könedes	?könedes =köne  (Ger  >könema !27_V	et	f	\N
150755	väljendu	väljendu =väljendu  (IndPrPs_  >väljenduma !27_V	et	f	\N
150756	väljendu	väljendu =väljendu  (ImpPrSg2  >väljenduma !27_V	et	f	\N
150766	tahkete	tahkete =tahke  (PlG  >tahke !01_A	et	f	\N
150767	tahkete	tahkete =e  (PlG  >tahk+esi !15_S	et	f	\N
150786	lähipiirkonnas	lähipiirkonnas =konna  (SgIn  >lähi+piir+konn !22_S	et	f	\N
150787	lähipiirkonnas	lähipiirkonnas =piirkonna  (SgIn  >lähi+piirkond !22_S	et	f	\N
150793	liskas	?liskas =liska  (SgIn  >liska !16_S	et	f	\N
150794	liskas	?liskas =liska  (IndIpfSg3  >liskama !29_V	et	f	\N
150795	liskas	?liskas =liskas  (SgN  >liskas !07_S	et	f	\N
150810	vöetakse	?vöetakse =vöetakse  (SgG  >vöetakne !02_A	et	f	\N
150817	ettevötetest	?ettevötetest =ettevötete  (PlEl  >ettevötett !22_S	et	f	\N
150818	ettevötetest	?ettevötetest =ettevötetes  (SgP  >ettevötetene !12_A	et	f	\N
150819	ettevötetest	?ettevötetest =vöte  (PlEl  >ette+vöte !06_S	et	f	\N
150820	ettevötetest	?ettevötetest =vötete  (PlEl  >ette+vötett !22_S	et	f	\N
150821	ettevötetest	?ettevötetest =vötetes  (SgP  >ette+vötetene !12_A	et	f	\N
150835	kordineerida	?kordineerida =kordineeri  (Inf  >kordineerima !28_V	et	f	\N
150546	palvinud	?palvinud =palvinu  (PlN  >palvinu !01_S	et	f	\N
150547	palvinud	?palvinud =palvinu  (IndPrSg2  >palvinuma !27_V	et	f	\N
150548	palvinud	?palvinud =palvinud  (ID  >palvinud !41_A	et	f	\N
150549	hiigelkuju	hiigelkuju =kuju  (SgN  >hiigel+kuju !17_S	et	f	\N
150550	hiigelkuju	hiigelkuju =kuju  (SgG  >hiigel+kuju !17_S	et	f	\N
150551	hiigelkuju	hiigelkuju =kuju  (SgP  >hiigel+kuju !17_S	et	f	\N
150554	teostusele	teostusele =teostuse  (SgAll  >teostus !11~09_S	et	f	\N
150555	teostusele	"teostus %teosta  )US_vS  <teostama ;27_V	et	f	\N
150587	tegutsejaid	tegutsejaid =tegutseja  (PlP  >tegutseja !01_S	et	f	\N
150588	tegutsejaid	"tegutseja %tegutse  )JA_vS  <tegutsema ;27_V	et	f	\N
150605	rahvusvahelised	rahvusvahelised =vahelise  (PlN  >rahvus+vaheline !12_A	et	f	\N
150606	rahvusvahelised	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
150623	käitlemine	käitlemine =käitlemine  (SgN  >käitlemine !12_S	et	f	\N
150624	käitlemine	"käitlemine %käitle  )MINE_vS  <käitlema ;30_V	et	f	\N
150637	kogusumma	kogusumma =summa  (SgN  >kogu+summa !16_S	et	f	\N
150638	kogusumma	kogusumma =summa  (SgG  >kogu+summa !16_S	et	f	\N
150639	kogusumma	kogusumma =summa  (SgG  >kogu+summ !22_S	et	f	\N
150640	kogusumma	kogusumma =summa  (SgG  >kogu+sumb !22_S	et	f	\N
150641	kogusumma	kogusumma =summa  (SgP  >kogu+summ !22_S	et	f	\N
150642	kogusumma	kogusumma =summa  (SgAdt  >kogu+summ !22_S	et	f	\N
150646	soomele	?soomele =soome  (PlAll  >soom !22_S	et	f	\N
150647	soomele	?soomele =soomele  (IndPrPs_  >soomelema !31~27_V	et	f	\N
150648	soomele	?soomele =soomele  (ImpPrSg2  >soomelema !31~27_V	et	f	\N
150649	soomele	?soomele =mele  (SgN  >soo+mele !16_S	et	f	\N
150650	soomele	?soomele =mele  (SgG  >soo+mele !16_S	et	f	\N
150662	finantsrahast	finantsrahast =raha  (SgEl  >finants+raha !17_S	et	f	\N
150663	finantsrahast	finantsrahast =raha  (SgEl  >finants+rahk !22_S	et	f	\N
150664	finantsrahast	finantsrahast =rahas  (SgP  >finants+rahane !10_A	et	f	\N
150665	finantsrahast	"finants+rahane %raha  )NE_aA  <finants+raha ;17_S	et	f	\N
150666	finantsrahast	"finants+rahane %raha  )NE_aA  <finants+rahk ;22_S	et	f	\N
150674	laen	laen =lae  (IndPrSg1  >laadima !28_V	et	f	\N
150675	laen	laen =laen  (SgN  >laen !22_S	et	f	\N
150719	stabiilsust	stabiilsust =stabiilsus  (SgP  >stabiilsus !11~09_S	et	f	\N
150720	stabiilsust	"stabiilsus %stabiilse  )US_aS  <stabiilne ;02_A	et	f	\N
150732	arktika	?arktika =arktika  (SgN  >arktika !01_S	et	f	\N
150733	arktika	?arktika =arktika  (SgG  >arktika !01_S	et	f	\N
150734	arktika	?arktika =arktika  (SgG  >arktikas !02_S	et	f	\N
150764	öhupuhastus	?öhupuhastus =öhupuhastu  (IndIpfSg3  >öhupuhastuma !27_V	et	f	\N
150765	öhupuhastus	?öhupuhastus =öhupuhastus  (SgN  >öhupuhastus !11~09_S	et	f	\N
150774	paigaldus	paigaldus =paigaldus  (SgN  >paigaldus !11_S	et	f	\N
150775	paigaldus	"paigaldus %paigalda  )US_vS  <paigaldama ;27_V	et	f	\N
150780	keskkonnapartnerlusprojekti	keskkonnapartnerlusprojekti =projekti  (SgG  >kesk+konna+partnerlus+projekt !22_S	et	f	\N
150781	keskkonnapartnerlusprojekti	keskkonnapartnerlusprojekti =projekti  (SgP  >kesk+konna+partnerlus+projekt !22_S	et	f	\N
150782	keskkonnapartnerlusprojekti	keskkonnapartnerlusprojekti =projekti  (SgAdt  >kesk+konna+partnerlus+projekt !22_S	et	f	\N
150792	saadaksetuleb	### saadaksetuleb	et	f	\N
150806	investeeringuraha	investeeringuraha =raha  (SgN  >investeeringu+raha !17_S	et	f	\N
150807	investeeringuraha	investeeringuraha =raha  (SgG  >investeeringu+raha !17_S	et	f	\N
150808	investeeringuraha	investeeringuraha =raha  (SgG  >investeeringu+rahk !22_S	et	f	\N
150809	investeeringuraha	investeeringuraha =raha  (SgP  >investeeringu+raha !17_S	et	f	\N
150833	gremihi	?gremihi =gremihi  (SgN  >gremihi !01_S	et	f	\N
150834	gremihi	?gremihi =gremihi  (SgG  >gremihi !01_S	et	f	\N
150860	baltimaadesse	baltimaadesse =maa  (PlIll  >balti+maa !26_S	et	f	\N
150861	baltimaadesse	baltimaadesse =maade  (PlIll  >balti+maat !22_S	et	f	\N
150869	köikidele	?köikidele =köiki  (PlAll  >köik !22_S	et	f	\N
150884	põhjadimensiooni	põhjadimensiooni =dimensiooni  (SgG  >põhja+dimensioon !22_S	et	f	\N
150885	põhjadimensiooni	põhjadimensiooni =dimensiooni  (SgP  >põhja+dimensioon !22_S	et	f	\N
150886	põhjadimensiooni	põhjadimensiooni =dimensiooni  (SgAdt  >põhja+dimensioon !22_S	et	f	\N
150889	lõikavad	lõikavad =lõika  (IndPrPl3  >lõikama !29_V	et	f	\N
150890	lõikavad	lõikavad =lõikava  (PlN  >lõikav !02_A	et	f	\N
150891	lõikavad	"lõikav %lõika  )V_vA  <lõikama ;29_V	et	f	\N
150907	tähtsusetu	tähtsusetu =tähtsusetu  (SgN  >tähtsusetu !01_A	et	f	\N
150908	tähtsusetu	"tähtsusetu %tähtsuse  )TU2_kA  <tähtsus ;09_S	et	f	\N
150909	tähtsusetu	"tähtsusetu %tähtsuse  )TU2_kA  <tähtsus ;11_S	et	f	\N
150910	tähtsusetu	tähtsusetu =tähtsusetu  (SgG  >tähtsusetu !01_A	et	f	\N
150925	finantseeringutest	?finantseeringutest =finantseeringu  (PlEl  >finantseering !02_S	et	f	\N
150926	finantseeringutest	?finantseeringutest =finantseeringute  (PlEl  >finantseeringutt !22_S	et	f	\N
150927	finantseeringutest	?finantseeringutest =finantseeringutes  (SgP  >finantseeringutene !12_A	et	f	\N
150928	finantseeringutest	?finantseeringutest =eeringu  (PlEl  >finants+eeringu !01_S	et	f	\N
150929	finantseeringutest	?finantseeringutest =eeringu  (PlEl  >finants+eering !02_S	et	f	\N
150930	finantseeringutest	?finantseeringutest =eeringute  (PlEl  >finants+eeringutt !22_S	et	f	\N
150589	artika	?artika =artika  (SgN  >artika !01_S	et	f	\N
150590	artika	?artika =artika  (SgG  >artika !01_S	et	f	\N
150598	artika	?artika =artika  (SgG  >artikas !02_S	et	f	\N
150607	peapiirkondi	peapiirkondi =kondi  (SgG  >pea+piir+kont !22_S	et	f	\N
150608	peapiirkondi	peapiirkondi =piirkondi  (SgP  >pea+piirkond !22_S	et	f	\N
150609	peapiirkondi	peapiirkondi =piirkondi  (SgAdt  >pea+piirkond !22_S	et	f	\N
150610	peapiirkondi	peapiirkondi =piirkondi  (PlP  >pea+piirkond !22_S	et	f	\N
150625	keskkonnasõbralikumaks	keskkonnasõbralikumaks =sõbralikuma  (SgTr  >kesk+konna+sõbralikum !02_A	et	f	\N
150626	keskkonnasõbralikumaks	"kesk+konna+sõbralikum %sõbraliku  )M_cA  <kesk+konna+sõbralik ;25_A	et	f	\N
150668	laen	laen =lae  (IndPrSg1  >laadima !28_V	et	f	\N
150671	laen	laen =laen  (SgN  >laen !22_S	et	f	\N
150686	gremiha	?gremiha =gremiha  (SgN  >gremiha !01_S	et	f	\N
150687	gremiha	?gremiha =gremiha  (SgG  >gremiha !01_S	et	f	\N
150692	valmisolekusüsteemi	valmisolekusüsteemi =süsteemi  (SgG  >valmis+oleku+süsteem !22_S	et	f	\N
150693	valmisolekusüsteemi	valmisolekusüsteemi =süsteemi  (SgP  >valmis+oleku+süsteem !22_S	et	f	\N
150694	valmisolekusüsteemi	valmisolekusüsteemi =süsteemi  (SgAdt  >valmis+oleku+süsteem !22_S	et	f	\N
150695	pöhja	?pöhja =pöhja  (SgN  >pöhja !16_S	et	f	\N
150697	pöhja	?pöhja =pöhja  (SgG  >pöhjas !02_A	et	f	\N
150699	pöhja	?pöhja =pöhja  (SgG  >pöhja !16_S	et	f	\N
150701	pöhja	?pöhja =pöhja  (IndPrPs_  >pöhjama !29_V	et	f	\N
150703	pöhja	?pöhja =pöhja  (ImpPrSg2  >pöhjama !29_V	et	f	\N
150713	mölematele	?mölematele =mölema  (PlAll  >mölem !02_A	et	f	\N
150714	mölematele	?mölematele =mölemate  (PlAll  >mölematt !22_S	et	f	\N
150715	mölematele	?mölematele =mölematele  (IndPrPs_  >mölematelema !36_V	et	f	\N
150716	mölematele	?mölematele =mölematele  (ImpPrSg2  >mölematelema !36_V	et	f	\N
150725	island	?island =island  (SgN  >island !02_S	et	f	\N
150735	pöhjamaade	?pöhjamaade =pöhjamaa  (PlG  >pöhjamaa !26_S	et	f	\N
150736	pöhjamaade	?pöhjamaade =pöhjamaade  (SgN  >pöhjamaade !16_S	et	f	\N
150737	pöhjamaade	?pöhjamaade =pöhjamaade  (SgG  >pöhjamaade !16_S	et	f	\N
150738	pöhjamaade	?pöhjamaade =pöhjamaade  (PlP  >pöhjamaad !22_S	et	f	\N
150739	tegutsemisprogrammi	tegutsemisprogrammi =programmi  (SgG  >tegutsemis+programm !22_S	et	f	\N
150740	tegutsemisprogrammi	tegutsemisprogrammi =programmi  (SgP  >tegutsemis+programm !22_S	et	f	\N
150741	tegutsemisprogrammi	tegutsemisprogrammi =programmi  (SgAdt  >tegutsemis+programm !22_S	et	f	\N
150746	körgemal	?körgemal =körgema  (SgAd  >körgem !02_A	et	f	\N
150747	körgemal	?körgemal =körgemal  (ID  >körgemal !41_D	et	f	\N
150761	vöimalused	?vöimalused =vöimaluse  (PlN  >vöimalus !11_S	et	f	\N
150770	keskkonnasöbralik	?keskkonnasöbralik =keskkonnasöbralik  (SgN  >keskkonnasöbralik !25_A	et	f	\N
150771	keskkonnasöbralik	?keskkonnasöbralik =söbralik  (SgN  >kesk+konna+söbralik !25_A	et	f	\N
150796	investeerinud	investeerinud =investeeri  (PtsPtPs  >investeerima !28_V	et	f	\N
150797	investeerinud	investeerinud =investeerinu  (PlN  >investeerinu !01_S	et	f	\N
150798	investeerinud	"investeerinu %investeeri  )NU_vS  <investeerima ;28_V	et	f	\N
150799	investeerinud	investeerinud =investeerinud  (ID  >investeerinud !41_A	et	f	\N
150800	investeerinud	"investeerinud %investeeri  )NUD_vA  <investeerima ;28_V	et	f	\N
150811	rahvusvahelistest	rahvusvahelistest =vahelis  (PlEl  >rahvus+vaheline !12_A	et	f	\N
150812	rahvusvahelistest	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
150829	löunaosa	?löunaosa =löunaosa  (SgN  >löunaosa !01_S	et	f	\N
150830	löunaosa	?löunaosa =löunaosa  (SgG  >löunaosa !01_S	et	f	\N
150844	loode-venemaa	loode-venemaa =maa  (SgN  >loode-vene+maa !26_S	et	f	\N
150845	loode-venemaa	loode-venemaa =maa  (SgG  >loode-vene+maa !26_S	et	f	\N
150854	koostöölepinguga	koostöölepinguga =pingu  (SgKom  >koos+tööle+ping !22_S	et	f	\N
150855	koostöölepinguga	koostöölepinguga =lepingu  (SgKom  >koos+töö+leping !02_S	et	f	\N
150866	logistikast	logistikast =logistika  (SgEl  >logistika !01_S	et	f	\N
150867	logistikast	logistikast =logistikas  (SgP  >logistikane !12_A	et	f	\N
150868	logistikast	"logistikane %logistika  )NE_aA  <logistika ;01_S	et	f	\N
150877	tollitöö	tollitöö =töö  (SgN  >tolli+töö !26_S	et	f	\N
150878	tollitöö	tollitöö =töö  (SgG  >tolli+töö !26_S	et	f	\N
150895	tegutsejad	tegutsejad =tegutseja  (PlN  >tegutseja !01_S	et	f	\N
150896	tegutsejad	"tegutseja %tegutse  )JA_vS  <tegutsema ;27_V	et	f	\N
150905	alajaotused	alajaotused =jaotuse  (PlN  >ala+jaotus !11~09_S	et	f	\N
150906	alajaotused	"ala+jaotus %jao  )TUS2_aS  <ala+jagu ;18_S	et	f	\N
150943	asutused	asutused =asutuse  (PlN  >asutus !11_S	et	f	\N
150944	asutused	"asutus %asuta  )US_vS  <asutama ;27_V	et	f	\N
150945	asutused	"asutus %asu  )TUS1_aS  <asuma ;27_V	et	f	\N
150946	asutused	"asutus %asu  )TUS2_aS  <asu ;17_S	et	f	\N
150956	gremihha	?gremihha =gremihha  (SgN  >gremihha !01_S	et	f	\N
150957	gremihha	?gremihha =gremihha  (SgG  >gremihha !01_S	et	f	\N
150963	paistev	paistev =paist  (PtsPrPs  >paistma !34_V	et	f	\N
150964	paistev	paistev =paistev  (SgN  >paistev !02_A	et	f	\N
150965	paistev	"paistev %paist  )V_vA  <paistma ;34_V	et	f	\N
150966	massimõrva	massimõrva =mõrva  (SgG  >massi+mõrv !22_S	et	f	\N
150967	massimõrva	massimõrva =mõrva  (SgP  >massi+mõrv !22_S	et	f	\N
150702	dimensiooni	dimensiooni =dimensiooni  (IndPrPs_  >dimensioonima !28_V	et	f	\N
150704	dimensiooni	dimensiooni =dimensiooni  (ImpPrSg2  >dimensioonima !28_V	et	f	\N
150717	lisamaks	lisamaks =lisa  (SupTr  >lisama !27_V	et	f	\N
150718	lisamaks	lisamaks =maks  (SgN  >lisa+maks !22_S	et	f	\N
150722	osapoolteks	?osapoolteks =poolte  (SgTr  >osa+poolde !06_S	et	f	\N
150726	vaatlejariigid	?vaatlejariigid =vaatlejariigi  (PlN  >vaatlejariigi !16_S	et	f	\N
150727	vaatlejariigid	?vaatlejariigid =vaatlejariigi  (PlN  >vaatlejariik !22_S	et	f	\N
150728	vaatlejariigid	?vaatlejariigid =vaatlejariigi  (IndPrSg2  >vaatlejariikima !28_V	et	f	\N
150729	nöukogud	?nöukogud =nöukogu  (IndPrSg2  >nöukoguma !27_V	et	f	\N
150757	argielus	argielus =elu  (SgIn  >argi+elu !17_S	et	f	\N
150758	argielus	argielus =elus  (SgN  >argi+elus !02_A	et	f	\N
150762	vöivad	?vöivad =vöiva  (PlN  >vöiva !16_S	et	f	\N
150763	vöivad	?vöivad =vöiva  (IndPrSg2  >vöivama !29_V	et	f	\N
150772	käsitlemine	käsitlemine =käsitlemine  (SgN  >käsitlemine !12_S	et	f	\N
150773	käsitlemine	"käsitlemine %käsitle  )MINE_vS  <käsitlema ;27_V	et	f	\N
150783	miljr	?miljr =miljr  (SgN  >miljr !22_S	et	f	\N
150784	väärtuseks	väärtuseks =väärtuse  (SgTr  >väärtus !11~09_S	et	f	\N
150785	väärtuseks	väärtuseks =use  (PlTr  >väärt+usk !22_S	et	f	\N
150801	rahastusest	?rahastusest =rahastuse  (SgEl  >rahastus !11_S	et	f	\N
150802	rahastusest	?rahastusest =rahastuses  (SgP  >rahastusene !12_A	et	f	\N
150803	rahastusest	?rahastusest =stuse  (SgEl  >raha+stuse !16_S	et	f	\N
150804	rahastusest	?rahastusest =stuses  (SgP  >raha+stuses !09_S	et	f	\N
150805	rahastusest	?rahastusest =stuses  (SgP  >raha+stusene !10_A	et	f	\N
150822	piirkondlikust	piirkondlikust =piirkondliku  (SgEl  >piirkondlik !25_A	et	f	\N
150823	piirkondlikust	piirkondlikust =piirkondlikus  (SgP  >piirkondlikus !11?09_S	et	f	\N
150824	piirkondlikust	"piirkondlikus %piirkondliku  )US_aS  <piirkondlik ;25_A	et	f	\N
150836	töhustada	?töhustada =töhusta  (Inf  >töhustama !27_V	et	f	\N
150842	haiguste	haiguste =haigus  (PlG  >haigus !11~09_S	et	f	\N
150843	haiguste	"haigus %haige  )US_aS  <haige ;01_AS	et	f	\N
150846	alustanud	alustanud =alusta  (PtsPtPs  >alustama !27_V	et	f	\N
150847	alustanud	alustanud =alustanu  (PlN  >alustanu !01_S	et	f	\N
150848	alustanud	"alustanu %alusta  )NU_vS  <alustama ;27_V	et	f	\N
150849	alustanud	alustanud =alustanud  (ID  >alustanud !41_A	et	f	\N
150850	alustanud	"alustanud %alusta  )NUD_vA  <alustama ;27_V	et	f	\N
150851	alustanud	alustanud =tanu  (PlN  >alus+tanu !17_S	et	f	\N
150856	hiv-	### hiv-	et	f	\N
150876	logistikavörkude	### logistikavörkude	et	f	\N
150881	turavlisuse	?turavlisuse =turavlisuse  (SgG  >turavlisus !11?09_S	et	f	\N
150882	lisamine	lisamine =lisamine  (SgN  >lisamine !12_S	et	f	\N
150883	lisamine	"lisamine %lisa  )MINE_vS  <lisama ;27_V	et	f	\N
150887	tegemiseks	tegemiseks =tegemise  (SgTr  >tegemine !12_S	et	f	\N
150888	tegemiseks	"tegemine %tege  )MINE_vS  <tegema ;28_V	et	f	\N
150897	põhjala	põhjala =põhjala  (SgN  >põhjala !01_S	et	f	\N
150898	põhjala	põhjala =põhjala  (SgG  >põhjala !01_S	et	f	\N
150911	avaldu	avaldu =avaldu  (IndPrPs_  >avalduma !27_V	et	f	\N
150912	avaldu	avaldu =avaldu  (ImpPrSg2  >avalduma !27_V	et	f	\N
150938	laenud	laenud =laenu  (PlN  >laen !22_S	et	f	\N
150939	laenud	laenud =laenu  (IndPrSg2  >laenuma !27_V	et	f	\N
150949	käivitunud	käivitunud =käivitu  (PtsPtPs  >käivituma !27_V	et	f	\N
150950	käivitunud	käivitunud =käivitunu  (PlN  >käivitunu !01_S	et	f	\N
150951	käivitunud	"käivitunu %käivitu  )NU_vS  <käivituma ;27_V	et	f	\N
150952	käivitunud	käivitunud =käivitunud  (ID  >käivitunud !41_A	et	f	\N
150953	käivitunud	"käivitunud %käivitu  )NUD_vA  <käivituma ;27_V	et	f	\N
150971	käsitlemise	käsitlemise =käsitlemise  (SgG  >käsitlemine !12_S	et	f	\N
150973	käsitlemise	"käsitlemine %käsitle  )MINE_vS  <käsitlema ;27_V	et	f	\N
150979	rõhumise	rõhumise =rõhumise  (SgG  >rõhumine !12_S	et	f	\N
150980	rõhumise	"rõhumine %rõhu  )MINE_vS  <rõhuma ;27_V	et	f	\N
151004	tradititsioonist	?tradititsioonist =tradititsiooni  (SgEl  >tradititsiooni !16_S	et	f	\N
151005	tradititsioonist	?tradititsioonist =tradititsiooni  (SgEl  >tradititsioon !22_S	et	f	\N
151006	tradititsioonist	?tradititsioonist =tradititsioonis  (SgP  >tradititsioonis !09_S	et	f	\N
151012	aastatest	aastatest =aasta  (PlEl  >aasta !01_S	et	f	\N
151013	aastatest	aastatest =test  (SgN  >aasta+test !22_S	et	f	\N
151015	aastatest	aastatest =tate  (PlEl  >aas+tatt !22_S	et	f	\N
151028	narratiivi	?narratiivi =narratiivi  (SgN  >narratiivi !16_S	et	f	\N
151029	narratiivi	?narratiivi =narratiivi  (SgG  >narratiivi !16_S	et	f	\N
151030	narratiivi	?narratiivi =narratiivi  (SgG  >narratiiv !22_S	et	f	\N
151031	narratiivi	?narratiivi =narratiivi  (SgP  >narratiiv !22_S	et	f	\N
151032	narratiivi	?narratiivi =narratiivi  (SgAdt  >narratiiv !22_S	et	f	\N
151033	narratiivi	?narratiivi =narratiivi  (IndPrPs_  >narratiivima !28_V	et	f	\N
151034	narratiivi	?narratiivi =narratiivi  (ImpPrSg2  >narratiivima !28_V	et	f	\N
151054	liitumine	liitumine =liitumine  (SgN  >liitumine !12_S	et	f	\N
151055	liitumine	"liitumine %liitu  )MINE_vS  <liituma ;27_V	et	f	\N
151068	nooruse	nooruse =nooruse  (SgG  >noorus !11~09_S	et	f	\N
150788	rahastatakse	?rahastatakse =rahasta  (IndPrIps  >rahastama !27_V	et	f	\N
150789	rahastatakse	?rahastatakse =rahastatakse  (SgG  >rahastatakne !02_A	et	f	\N
150790	rahastatakse	?rahastatakse =rahastatakse  (PlP  >rahastataks !22_S	et	f	\N
150791	rahastatakse	?rahastatakse =statakse  (SgG  >raha+statakne !02_A	et	f	\N
150813	ettevötetelt	?ettevötetelt =ettevötete  (PlAbl  >ettevötett !22_S	et	f	\N
150814	ettevötetelt	?ettevötetelt =ettevötetelt  (ID  >ettevötetelt !41_D	et	f	\N
150815	ettevötetelt	?ettevötetelt =vöte  (PlAbl  >ette+vöte !06_S	et	f	\N
150816	ettevötetelt	?ettevötetelt =vötete  (PlAbl  >ette+vötett !22_S	et	f	\N
150825	valitsusest	valitsusest =valitsuse  (SgEl  >valitsus !11_S	et	f	\N
150826	valitsusest	"valitsus %valitse  )US_vS  <valitsema ;27_V	et	f	\N
150827	valitsusest	valitsusest =valitsuses  (SgP  >valitsusene !12_A	et	f	\N
150828	valitsusest	"valitsusene %valitsuse  )NE_aA  <valitsus ;11_S	et	f	\N
150831	märkimisväärselt	märkimisväärselt =väärse  (SgAbl  >märki+mis+väärne !02_A	et	f	\N
150832	märkimisväärselt	"märki+mis+väärselt %väärse  )LT_mD  <märki+mis+väärne ;02_A	et	f	\N
150837	nakkushaiguste	nakkushaiguste =haigus  (PlG  >nakkus+haigus !11~09_S	et	f	\N
150838	nakkushaiguste	"nakkus+haigus %haige  )US_aS  <nakkus+haige ;01_AS	et	f	\N
150857	aidsiprogrammi	aidsiprogrammi =programmi  (SgG  >aidsi+programm !22_S	et	f	\N
150858	aidsiprogrammi	aidsiprogrammi =programmi  (SgP  >aidsi+programm !22_S	et	f	\N
150859	aidsiprogrammi	aidsiprogrammi =programmi  (SgAdt  >aidsi+programm !22_S	et	f	\N
150862	liiklusest	liiklusest =liikluse  (SgEl  >liiklus !11~09_S	et	f	\N
150863	liiklusest	liiklusest =liikluses  (SgP  >liiklusene !12_A	et	f	\N
150864	liiklusest	"liiklusene %liikluse  )NE_aA  <liiklus ;09_S	et	f	\N
150865	liiklusest	"liiklusene %liikluse  )NE_aA  <liiklus ;11_S	et	f	\N
150870	muutuks	muutuks =muutu  (SgTr  >muutu !01_A	et	f	\N
150871	muutuks	"muutu %muu  )TU2_kA  <muu ;26_S	et	f	\N
150872	muutuks	muutuks =muutu  (KndPrPs  >muutuma !27_V	et	f	\N
150873	muutuks	muutuks =tuks  (SgN  >muu+tuks !22_S	et	f	\N
150874	vöiksid	?vöiksid =vöiksi  (PlN  >vöiks !22_S	et	f	\N
150875	vöiksid	?vöiksid =vöiksi  (IndPrSg2  >vöiksima !28_V	et	f	\N
150879	lihtsustamine	lihtsustamine =lihtsustamine  (SgN  >lihtsustamine !12_S	et	f	\N
150880	lihtsustamine	"lihtsustamine %lihtsusta  )MINE_vS  <lihtsustama ;27_V	et	f	\N
150892	osapooled	?osapooled =osapoole  (PlN  >osapoole !16_S	et	f	\N
150893	vaatlejad	vaatlejad =vaatleja  (PlN  >vaatleja !01_S	et	f	\N
150894	vaatlejad	"vaatleja %vaatle  )JA_vS  <vaatlema ;30_V	et	f	\N
150899	euro-arktika	?euro-arktika =arktika  (SgN  >euro-arktika !01_S	et	f	\N
150900	euro-arktika	?euro-arktika =arktika  (SgG  >euro-arktika !01_S	et	f	\N
150901	euro-arktika	?euro-arktika =arktika  (SgG  >euro-arktikas !02_S	et	f	\N
150915	ladustamine	ladustamine =ladustamine  (SgN  >ladustamine !12_S	et	f	\N
150916	ladustamine	"ladustamine %ladusta  )MINE_vS  <ladustama ;27_V	et	f	\N
150919	seemneraha	seemneraha =raha  (SgN  >seemne+raha !17_S	et	f	\N
150920	seemneraha	seemneraha =raha  (SgG  >seemne+raha !17_S	et	f	\N
150921	seemneraha	seemneraha =raha  (SgG  >seemne+rahk !22_S	et	f	\N
150922	seemneraha	seemneraha =raha  (SgP  >seemne+raha !17_S	et	f	\N
150940	finantsasutustelt	finantsasutustelt =tuste  (PlAbl  >finants+asu+tust !22_S	et	f	\N
150941	finantsasutustelt	finantsasutustelt =asutus  (PlAbl  >finants+asutus !11_S	et	f	\N
150942	finantsasutustelt	"finants+asutus %asu  )TUS2_aS  <finants+asu ;17_S	et	f	\N
150954	tuumajäätmete-alased	tuumajäätmete-alased =alase  (PlN  >tuumajäätmete-alane !10_AS	et	f	\N
150955	tuumajäätmete-alased	"tuumajäätmete-alane %ala  )NE_aA  <tuumajäätmete-ala ;17_S	et	f	\N
150960	kiirreageerimissüsteemi	kiirreageerimissüsteemi =süsteemi  (SgG  >kiir+reageerimis+süsteem !22_S	et	f	\N
150961	kiirreageerimissüsteemi	kiirreageerimissüsteemi =süsteemi  (SgP  >kiir+reageerimis+süsteem !22_S	et	f	\N
150962	kiirreageerimissüsteemi	kiirreageerimissüsteemi =süsteemi  (SgAdt  >kiir+reageerimis+süsteem !22_S	et	f	\N
150969	holokausti	?holokausti =holokausti  (ID  >holokausti !41_D	et	f	\N
150970	holokausti	?holokausti =holokausti  (IndPrPs_  >holokaustima !28_V	et	f	\N
150972	holokausti	?holokausti =holokausti  (ImpPrSg2  >holokaustima !28_V	et	f	\N
150986	paju	paju =paju  (SgN  >paju !17_S	et	f	\N
150987	paju	paju =paju  (SgG  >paju !17_S	et	f	\N
150988	paju	paju =paju  (SgP  >paju !17_S	et	f	\N
150999	laiast	laiast =laia  (SgEl  >laid !22_S	et	f	\N
151000	laiast	laiast =laia  (SgEl  >lai !22_A	et	f	\N
151001	laiast	laiast =laias  (SgP  >laiane !10_A	et	f	\N
151002	laiast	"laiane %laia  )NE_aA  <laid ;22_S	et	f	\N
151003	laiast	laiast =ast  (SgN  >lai+ast !22_S	et	f	\N
151017	shoa	?shoa =shoa  (SgN  >shoa !26_S	et	f	\N
151018	shoa	?shoa =shoa  (SgG  >shoa !26_S	et	f	\N
151038	liita	liita =lii  (SgAb  >lii !26_S	et	f	\N
151039	liita	liita =liit  (Inf  >liitma !34_V	et	f	\N
151045	humoristlikusse	humoristlikusse =humoristliku  (SgIll  >humoristlik !25_A	et	f	\N
151046	humoristlikusse	humoristlikusse =humoristlikus  (SgAdt  >humoristlikus !11_S	et	f	\N
151047	humoristlikusse	"humoristlikus %humoristliku  )US_aS  <humoristlik ;25_A	et	f	\N
151056	populäärsus	?populäärsus =populäärsu  (IndIpfSg3  >populäärsuma !27_V	et	f	\N
151057	populäärsus	?populäärsus =populäärsus  (SgN  >populäärsus !11~09_S	et	f	\N
150839	eluviisiga	eluviisiga =iga  (SgN  >elu+viis+iga !18_S	et	f	\N
150840	eluviisiga	eluviisiga =iga  (SgP  >elu+viis+iga !18_S	et	f	\N
150841	eluviisiga	eluviisiga =viisi  (SgKom  >elu+viis !22_S	et	f	\N
150852	piirkonnavahelise	piirkonnavahelise =vahelise  (SgG  >piir+konna+vaheline !12_A	et	f	\N
150853	piirkonnavahelise	"piir+konna+vaheline %vahe  )LINE_aA  <piir+konna+vahe ;16_S	et	f	\N
150902	tegevuskava	tegevuskava =kava  (SgN  >tegevus+kava !17_S	et	f	\N
150903	tegevuskava	tegevuskava =kava  (SgG  >tegevus+kava !17_S	et	f	\N
150904	tegevuskava	tegevuskava =kava  (SgP  >tegevus+kava !17_S	et	f	\N
150913	keskkonnasõbralikum	keskkonnasõbralikum =sõbralikum  (SgN  >kesk+konna+sõbralikum !02_A	et	f	\N
150914	keskkonnasõbralikum	"kesk+konna+sõbralikum %sõbraliku  )M_cA  <kesk+konna+sõbralik ;25_A	et	f	\N
150917	kavandatavate	kavandatavate =kavandatava  (PlG  >kavandatav !02_A	et	f	\N
150918	kavandatavate	"kavandatav %kavanda  )TAV_vAS  <kavandama ;27_V	et	f	\N
150923	annetusi	annetusi =annetusi  (PlP  >annetus !11_S	et	f	\N
150924	annetusi	"annetus %anneta  )US_vS  <annetama ;27_V	et	f	\N
150932	pärine	pärine =pärine  (IndPrPs_  >pärinema !27_V	et	f	\N
150933	pärine	pärine =pärine  (ImpPrSg2  >pärinema !27_V	et	f	\N
150947	võtjateks	võtjateks =võtja  (PlTr  >võtja !01_S	et	f	\N
150948	võtjateks	"võtja %võt  )JA_vS  <võtma ;35_V	et	f	\N
150958	ladustamist	ladustamist =ladustamis  (SgP  >ladustamine !12_S	et	f	\N
150959	ladustamist	"ladustamine %ladusta  )MINE_vS  <ladustama ;27_V	et	f	\N
150974	käivitumisele	käivitumisele =käivitumise  (SgAll  >käivitumine !12_S	et	f	\N
150975	käivitumisele	"käivitumine %käivitu  )MINE_vS  <käivituma ;27_V	et	f	\N
150981	enckell	?enckell =enckell  (SgN  >enckell !22_S	et	f	\N
150989	tõrjutud	tõrjutud =tõrju  (PtsPtIps  >tõrjuma !28_V	et	f	\N
150990	tõrjutud	tõrjutud =tõrjutu  (PlN  >tõrjutu !01_AS	et	f	\N
150991	tõrjutud	"tõrjutu %tõrju  )TU1_vS  <tõrjuma ;28_V	et	f	\N
150992	tõrjutud	tõrjutud =tõrjutud  (ID  >tõrjutud !41_A	et	f	\N
150993	tõrjutud	"tõrjutud %tõrju  )TUD_vA  <tõrjuma ;28_V	et	f	\N
151011	40-ndatest	?-ndatest =ndate  (PlEl  >-ndatt !22_S	et	f	\N
151014	40-ndatest	?-ndatest =ndates  (SgP  >-ndates !09_S	et	f	\N
151016	40-ndatest	?-ndatest =ndates  (SgP  >-ndatene !10_A	et	f	\N
151023	rahvate	?rahvate =rahva  (IndPrPl2  >rahvama !29_V	et	f	\N
151060	tagatud	tagatud =taga  (PtsPtIps  >tagama !27_V	et	f	\N
151061	tagatud	tagatud =tagatu  (PlN  >tagatu !01_AS	et	f	\N
151062	tagatud	"tagatu %taga  )TU1_vS  <tagama ;27_V	et	f	\N
151063	tagatud	tagatud =tagatud  (ID  >tagatud !41_A	et	f	\N
151064	tagatud	"tagatud %taga  )TUD_vA  <tagama ;27_V	et	f	\N
151070	mustaks	mustaks =musta  (SgTr  >must !22_AS	et	f	\N
151071	mustaks	mustaks =musta  (KndPrPs  >mustama !29_V	et	f	\N
151109	käsitlenud	käsitlenud =käsitle  (PtsPtPs  >käsitlema !27_V	et	f	\N
151110	käsitlenud	käsitlenud =käsitlenu  (PlN  >käsitlenu !01_S	et	f	\N
151111	käsitlenud	"käsitlenu %käsitle  )NU_vS  <käsitlema ;27_V	et	f	\N
151112	käsitlenud	käsitlenud =käsitlenud  (ID  >käsitlenud !41_A	et	f	\N
151113	käsitlenud	"käsitlenud %käsitle  )NUD_vA  <käsitlema ;27_V	et	f	\N
151122	mötetes	?mötetes =möte  (PlIn  >möte !06_S	et	f	\N
151123	mötetes	?mötetes =mötete  (PlIn  >mötett !22_S	et	f	\N
151132	selgitamisprotsessi	?selgitamisprotsessi =selgitamisprotsessi  (SgG  >selgitamisprotsess !22_S	et	f	\N
151133	selgitamisprotsessi	?selgitamisprotsessi =selgitamisprotsessi  (SgP  >selgitamisprotsess !22_S	et	f	\N
151134	selgitamisprotsessi	?selgitamisprotsessi =selgitamisprotsessi  (SgAdt  >selgitamisprotsess !22_S	et	f	\N
151135	selgitamisprotsessi	?selgitamisprotsessi =selgitamisprotsessi  (IndPrPs_  >selgitamisprotsessima !28_V	et	f	\N
151136	selgitamisprotsessi	?selgitamisprotsessi =selgitamisprotsessi  (ImpPrSg2  >selgitamisprotsessima !28_V	et	f	\N
151137	selgitamisprotsessi	?selgitamisprotsessi =itamisprotsessi  (SgG  >selg+itamisprotsess !22_S	et	f	\N
151138	selgitamisprotsessi	?selgitamisprotsessi =itamisprotsessi  (SgP  >selg+itamisprotsess !22_S	et	f	\N
151139	selgitamisprotsessi	?selgitamisprotsessi =itamisprotsessi  (SgAdt  >selg+itamisprotsess !22_S	et	f	\N
151157	törjutud	?törjutud =törju  (PtsPtIps  >törjuma !27_V	et	f	\N
151158	törjutud	?törjutud =törjutu  (PlN  >törjutu !01_AS	et	f	\N
151159	törjutud	?törjutud =törjutu  (IndPrSg2  >törjutuma !27_V	et	f	\N
151160	törjutud	?törjutud =törjutud  (ID  >törjutud !41_A	et	f	\N
151170	vöetud	?vöetud =vöetu  (PlN  >vöetu !01_A	et	f	\N
151171	vöetud	?vöetud =vöetu  (IndPrSg2  >vöetuma !27_V	et	f	\N
151172	vöetud	?vöetud =vöetud  (ID  >vöetud !41_A	et	f	\N
151194	nostalgilist	?nostalgilist =nostalgilis  (SgP  >nostalgilis !09_S	et	f	\N
151195	nostalgilist	?nostalgilist =nostalgilis  (SgP  >nostalgiline !12_A	et	f	\N
151196	nostalgilist	?nostalgilist =nostalgilist  (SgN  >nostalgilist !22_S	et	f	\N
151197	zanriks	?zanriks =zanri  (SgTr  >zanri !16_S	et	f	\N
151198	zanriks	?zanriks =zanri  (SgTr  >zanr !22_S	et	f	\N
151199	zanriks	?zanriks =zanri  (KndPrPs  >zanrima !28_V	et	f	\N
151200	idanostalgia	idanostalgia =nostalgia  (SgN  >ida+nostalgia !01_S	et	f	\N
151202	idanostalgia	idanostalgia =nostalgia  (SgG  >ida+nostalgia !01_S	et	f	\N
151204	lugejaskonnast	lugejaskonnast =lugejaskonna  (SgEl  >lugejaskond !22_S	et	f	\N
151205	lugejaskonnast	lugejaskonnast =lugejaskonnas  (SgP  >lugejaskonnane !12_A	et	f	\N
150931	finantseeringutest	?finantseeringutest =eeringutes  (SgP  >finants+eeringutene !12_A	et	f	\N
150934	laenuraha	laenuraha =raha  (SgN  >laenu+raha !17_S	et	f	\N
150935	laenuraha	laenuraha =raha  (SgG  >laenu+raha !17_S	et	f	\N
150936	laenuraha	laenuraha =raha  (SgG  >laenu+rahk !22_S	et	f	\N
150937	laenuraha	laenuraha =raha  (SgP  >laenu+raha !17_S	et	f	\N
150977	aastait	?aastait =aastait  (SgN  >aastait !22_S	et	f	\N
150978	aastait	?aastait =tait  (SgN  >aas+tait !22_S	et	f	\N
150983	imbi	imbi =imbi  (SgP  >imb !22_S	et	f	\N
150984	imbi	imbi =imbi  (SgAdt  >imb !22_S	et	f	\N
150985	imbi	imbi =imbi  (PlP  >imb !22_S	et	f	\N
151007	biibel	?biibel =biibe  (PlAd  >biip !22_S	et	f	\N
151008	biibel	?biibel =biibel  (SgN  >biibel !02_S	et	f	\N
151019	holokaustist	?holokaustist =holokaustis  (SgP  >holokaustis !09_S	et	f	\N
151020	holokaustist	?holokaustist =holokaustist  (SgN  >holokaustist !22_S	et	f	\N
151025	90-ndatel	?-ndatel =ndate  (PlAd  >-ndatt !22_S	et	f	\N
151027	90-ndatel	?-ndatel =ndatel  (SgN  >-ndatel !02_S	et	f	\N
151040	genre	?genre =genre  (SgN  >genre !06_S	et	f	\N
151041	genre	?genre =genre  (SgG  >genre !06_S	et	f	\N
151042	genre	?genre =genre  (PlP  >genr !22_S	et	f	\N
151043	genre	?genre =genre  (IndPrPs_  >genrema !27_V	et	f	\N
151044	genre	?genre =genre  (ImpPrSg2  >genrema !27_V	et	f	\N
151048	ostalgiasse	?ostalgiasse =ostalgia  (SgIll  >ostalgia !01_S	et	f	\N
151049	ostalgiasse	?ostalgiasse =ostalgias  (SgAdt  >ostalgias !11_S	et	f	\N
151050	ostalgiasse	?ostalgiasse =ostalgiasse  (SgG  >ostalgiasne !02_A	et	f	\N
151051	ostalgiasse	?ostalgiasse =ostalgiasse  (PlP  >ostalgiass !22_S	et	f	\N
151052	liigiks	liigiks =liigi  (SgTr  >liik !22_S	et	f	\N
151053	liigiks	liigiks =iks  (SgN  >liig+iks !22_S	et	f	\N
151065	sõbralikult	sõbralikult =sõbraliku  (SgAbl  >sõbralik !25_A	et	f	\N
151066	sõbralikult	sõbralikult =sõbralikult  (ID  >sõbralikult !41_D	et	f	\N
151067	sõbralikult	"sõbralikult %sõbraliku  )LT_mD  <sõbralik ;25_A	et	f	\N
151072	kullatud	kullatud =kulla  (PtsPtIps  >kuldama !29_V	et	f	\N
151073	kullatud	kullatud =kullatu  (PlN  >kullatu !01_AS	et	f	\N
151074	kullatud	"kullatu %kulla  )TU1_vS  <kuldama ;29_V	et	f	\N
151075	kullatud	"kullatu %kulla  )TU2_kA  <kuld ;22_S	et	f	\N
151076	kullatud	kullatud =kullatud  (ID  >kullatud !41_A	et	f	\N
151077	kullatud	"kullatud %kulla  )TUD_vA  <kuldama ;29_V	et	f	\N
151081	meediale	meediale =meedia  (SgAll  >meedia !01_S	et	f	\N
151083	meediale	meediale =dia  (SgAll  >mee+dia !26_S	et	f	\N
151086	sahalinist	?sahalinist =sahalini  (SgEl  >sahalin !19_S	et	f	\N
151087	sahalinist	?sahalinist =sahalinis  (SgP  >sahalinis !09_S	et	f	\N
151088	sahalinist	?sahalinist =sahalinist  (SgN  >sahalinist !22_S	et	f	\N
151101	tegud	?tegud =tegu  (IndPrSg2  >teguma !27_V	et	f	\N
151114	lugematud	lugematud =lugematu  (PlN  >lugematu !01_A	et	f	\N
151115	lugematud	"lugematu %luge  )MATU_vA  <lugema ;28_V	et	f	\N
151116	lugematud	"lugematu %lugema  )TU2_kA  <lugem ;02_S	et	f	\N
151117	kaotanud	kaotanud =kaota  (PtsPtPs  >kaotama !27_V	et	f	\N
151118	kaotanud	kaotanud =kaotanu  (PlN  >kaotanu !01_S	et	f	\N
151119	kaotanud	"kaotanu %kaota  )NU_vS  <kaotama ;27_V	et	f	\N
151120	kaotanud	kaotanud =kaotanud  (ID  >kaotanud !41_A	et	f	\N
151121	kaotanud	"kaotanud %kaota  )NUD_vA  <kaotama ;27_V	et	f	\N
151140	käivitumisel	käivitumisel =käivitumise  (SgAd  >käivitumine !12_S	et	f	\N
151141	käivitumisel	"käivitumine %käivitu  )MINE_vS  <käivituma ;27_V	et	f	\N
151161	mäelstused	?mäelstused =mäelstuse  (PlN  >mäelstus !11~09_S	et	f	\N
151167	üleüldiselt	üleüldiselt =üldise  (SgAbl  >üle+üldine !10~12_A	et	f	\N
151168	üleüldiselt	"üle+üldiselt %üldise  )LT_mD  <üle+üldine ;10_A	et	f	\N
151169	üleüldiselt	"üle+üldiselt %üldise  )LT_mD  <üle+üldine ;12_A	et	f	\N
151175	1990-aastatel	-aastatel =aasta  (PlAd  >-aasta !01_S	et	f	\N
151176	1990-aastatel	-aastatel =tate  (PlAd  >-aas+tatt !22_S	et	f	\N
151207	rahvusvahelisel	rahvusvahelisel =vahelise  (SgAd  >rahvus+vaheline !12_A	et	f	\N
151208	rahvusvahelisel	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
151227	käsitlev	käsitlev =käsitle  (PtsPrPs  >käsitlema !27_V	et	f	\N
151228	käsitlev	käsitlev =käsitlev  (SgN  >käsitlev !02_A	et	f	\N
151229	käsitlev	"käsitlev %käsitle  )V_vA  <käsitlema ;27_V	et	f	\N
151232	sahalin	?sahalin =sahalin  (SgN  >sahalin !19_S	et	f	\N
151244	arvukates	arvukates =arvuka  (PlIn  >arvukas !02_A	et	f	\N
151245	arvukates	arvukates =kate  (PlIn  >arvu+katt !22_S	et	f	\N
151253	natsiliku	?natsiliku =natsiliku  (SgG  >natsilik !25_A	et	f	\N
151254	natsiliku	?natsiliku =natsiliku  (IndPrPs_  >natsilikuma !27_V	et	f	\N
151255	natsiliku	?natsiliku =natsiliku  (ImpPrSg2  >natsilikuma !27_V	et	f	\N
151256	natsiliku	?natsiliku =iliku  (SgN  >nats+iliku !01_S	et	f	\N
151257	natsiliku	?natsiliku =iliku  (SgG  >nats+iliku !01_S	et	f	\N
151258	natsiliku	?natsiliku =iliku  (SgG  >nats+ilik !02_S	et	f	\N
151259	lahendusprotsessi	lahendusprotsessi =protsessi  (SgG  >lahendus+protsess !22_S	et	f	\N
151260	lahendusprotsessi	lahendusprotsessi =protsessi  (SgP  >lahendus+protsess !22_S	et	f	\N
151261	lahendusprotsessi	lahendusprotsessi =protsessi  (SgAdt  >lahendus+protsess !22_S	et	f	\N
150968	massimõrva	massimõrva =mõrva  (SgAdt  >massi+mõrv !22_S	et	f	\N
150976	1940-ndeit	?-ndeit =ndeit  (SgN  >-ndeit !22_S	et	f	\N
150982	märkib	### märkib	et	f	\N
150994	antisemitismi	?antisemitismi =antisemitismi  (SgG  >antisemitism !22_S	et	f	\N
150995	antisemitismi	?antisemitismi =antisemitismi  (SgP  >antisemitism !22_S	et	f	\N
150996	antisemitismi	?antisemitismi =antisemitismi  (SgAdt  >antisemitism !22_S	et	f	\N
150997	antisemitismi	?antisemitismi =antisemitismi  (IndPrPs_  >antisemitismima !28_V	et	f	\N
150998	antisemitismi	?antisemitismi =antisemitismi  (ImpPrSg2  >antisemitismima !28_V	et	f	\N
151009	kaasaarvatult	kaasaarvatult =atu  (SgAbl  >kaasa+arv+att !22_S	et	f	\N
151010	kaasaarvatult	kaasaarvatult =arvatu  (SgAbl  >kaasa+arvatu !01_AS	et	f	\N
151021	elanute	elanute =elanu  (PlG  >elanu !01_S	et	f	\N
151022	elanute	"elanu %ela  )NU_vS  <elama ;27_V	et	f	\N
151024	küüditamisteks	küüditamisteks =küüditamis  (PlTr  >küüditamine !12_S	et	f	\N
151026	küüditamisteks	"küüditamine %küüdita  )MINE_vS  <küüditama ;27_V	et	f	\N
151035	käsitlevat	käsitlevat =käsitle  (KvtPrPs  >käsitlema !27_V	et	f	\N
151036	käsitlevat	käsitlevat =käsitleva  (SgP  >käsitlev !02_A	et	f	\N
151037	käsitlevat	"käsitlev %käsitle  )V_vA  <käsitlema ;27_V	et	f	\N
151078	ostalgia	?ostalgia =ostalgia  (SgN  >ostalgia !01_S	et	f	\N
151079	ostalgia	?ostalgia =ostalgia  (SgG  >ostalgia !01_S	et	f	\N
151089	võitjate	võitjate =võitja  (PlG  >võitja !01_S	et	f	\N
151090	võitjate	"võitja %võit  )JA_vS  <võitma ;34_V	et	f	\N
151126	massimörva	?massimörva =massimörva  (SgN  >massimörva !16_S	et	f	\N
151127	massimörva	?massimörva =massimörva  (SgG  >massimörva !16_S	et	f	\N
151128	massimörva	?massimörva =mörva  (SgN  >massi+mörva !16_S	et	f	\N
151129	massimörva	?massimörva =mörva  (SgG  >massi+mörva !16_S	et	f	\N
151130	massimörva	?massimörva =imörva  (SgN  >mass+imörva !01_S	et	f	\N
151131	massimörva	?massimörva =imörva  (SgG  >mass+imörva !01_S	et	f	\N
151145	tapa	tapa =tapa  (SgG  >tapp !22_S	et	f	\N
151146	tapa	tapa =tapa  (IndPrPs_  >tapma !35_V	et	f	\N
151147	tapa	tapa =tapa  (ImpPrSg2  >tapma !35_V	et	f	\N
151151	kannatusi	kannatusi =kannatusi  (PlP  >kannatus !11_S	et	f	\N
151153	kannatusi	"kannatus %kannata  )US_vS  <kannatama ;27_V	et	f	\N
151155	kannatusi	"kannatus %kanna  )TUS2_aS  <kanna ;16_S	et	f	\N
151156	kannatusi	"kannatus %kanna  )TUS2_aS  <kand ;22_S	et	f	\N
151182	käsitlevaid	käsitlevaid =käsitleva  (PlP  >käsitlev !02_A	et	f	\N
151183	käsitlevaid	"käsitlev %käsitle  )V_vA  <käsitlema ;27_V	et	f	\N
151216	rüvetatud	rüvetatud =rüveta  (PtsPtIps  >rüvetama !27_V	et	f	\N
151217	rüvetatud	rüvetatud =rüvetatu  (PlN  >rüvetatu !01_S	et	f	\N
151218	rüvetatud	"rüvetatu %rüveta  )TU1_vS  <rüvetama ;27_V	et	f	\N
151219	rüvetatud	rüvetatud =rüvetatud  (ID  >rüvetatud !41_A	et	f	\N
151220	rüvetatud	"rüvetatud %rüveta  )TUD_vA  <rüvetama ;27_V	et	f	\N
151224	juhitavam	juhitavam =juhitavam  (SgN  >juhitavam !02_A	et	f	\N
151225	juhitavam	"juhitavam %juhi  )TAVAM_cA  <juhtima ;28_V	et	f	\N
151226	juhitavam	"juhitavam %juhitava  )M_cA  <juhitav ;02_A	et	f	\N
151251	vormid	vormid =vormi  (PlN  >vorm !22_S	et	f	\N
151252	vormid	vormid =vormi  (IndPrSg2  >vormima !28_V	et	f	\N
151280	shoah	?shoah =shoah  (ID  >shoah !41_I	et	f	\N
151283	teadvustatud	teadvustatud =teadvusta  (PtsPtIps  >teadvustama !27_V	et	f	\N
151285	teadvustatud	teadvustatud =teadvustatu  (PlN  >teadvustatu !01_S	et	f	\N
151286	teadvustatud	"teadvustatu %teadvusta  )TU1_vS  <teadvustama ;27_V	et	f	\N
151287	teadvustatud	teadvustatud =teadvustatud  (ID  >teadvustatud !41_A	et	f	\N
151288	teadvustatud	"teadvustatud %teadvusta  )TUD_vA  <teadvustama ;27_V	et	f	\N
151298	terrorismi	terrorismi =terrorismi  (SgG  >terrorism !22_S	et	f	\N
151299	terrorismi	terrorismi =terrorismi  (SgP  >terrorism !22_S	et	f	\N
151300	terrorismi	terrorismi =terrorismi  (SgAdt  >terrorism !22_S	et	f	\N
151319	prii	prii =prii  (SgN  >prii !26_A	et	f	\N
151320	prii	prii =prii  (SgG  >prii !26_A	et	f	\N
151326	kullatakse	kullatakse =kulla  (IndPrIps  >kuldama !29_V	et	f	\N
151327	kullatakse	kullatakse =takse  (PlP  >kulla+taks !22_S	et	f	\N
151334	saarest	saarest =saare  (SgEl  >saar !13_S	et	f	\N
151337	saarest	saarest =saares  (SgP  >saarene !10_A	et	f	\N
151339	saarest	"saarene %saare  )NE_aA  <saar ;13_S	et	f	\N
151342	kuriteod	kuriteod =teo  (PlN  >kuri+tegu !18_S	et	f	\N
151343	kuriteod	kuriteod =teo  (PlN  >kuri+tigu !18_S	et	f	\N
151347	lugematutes	lugematutes =lugematu  (PlIn  >lugematu !01_A	et	f	\N
151348	lugematutes	"lugematu %luge  )MATU_vA  <lugema ;28_V	et	f	\N
151349	lugematutes	"lugematu %lugema  )TU2_kA  <lugem ;02_S	et	f	\N
151356	pädevusega	pädevusega =pädevuse  (SgKom  >pädevus !11_S	et	f	\N
151357	pädevusega	"pädevus %pädeva  )US_aS  <pädev ;02_A	et	f	\N
151386	aastadest	?aastadest =aastades  (SgP  >aastadene !12_A	et	f	\N
151387	aastadest	?aastadest =tade  (SgEl  >aas+tade !16_S	et	f	\N
151388	aastadest	?aastadest =tades  (SgP  >aas+tades !09_S	et	f	\N
151389	aastadest	?aastadest =tades  (SgP  >aas+tadene !10_A	et	f	\N
151390	okupeeriutd	?okupeeriutd =okupeeriutd  (SgN  >okupeeriutd !22_S	et	f	\N
151394	nostalgilise	?nostalgilise =nostalgilise  (SgG  >nostalgiline !12_A	et	f	\N
151058	populäärsus	?populäärsus =uläärsu  (SgIn  >pop+uläärsu !01_S	et	f	\N
151059	populäärsus	?populäärsus =uläärsus  (SgN  >pop+uläärsus !11~09_S	et	f	\N
151080	atraktiivsem	?atraktiivsem =atraktiivsem  (SgN  >atraktiivsem !02_A	et	f	\N
151091	kaotanute	kaotanute =kaotanu  (PlG  >kaotanu !01_S	et	f	\N
151092	kaotanute	"kaotanu %kaota  )NU_vS  <kaotama ;27_V	et	f	\N
151093	suudetud	suudetud =suude  (PtsPtIps  >suutma !34_V	et	f	\N
151094	suudetud	suudetud =suudetu  (PlN  >suudetu !01_AS	et	f	\N
151095	suudetud	"suudetu %suude  )TU1_vS  <suutma ;34_V	et	f	\N
151096	suudetud	suudetud =suudetud  (ID  >suudetud !41_A	et	f	\N
151097	suudetud	"suudetud %suude  )TUD_vA  <suutma ;34_V	et	f	\N
151124	jubeduse	jubeduse =jubeduse  (SgG  >jubedus !11_S	et	f	\N
151125	jubeduse	"jubedus %jubeda  )US_aS  <jube ;02_A	et	f	\N
151148	kaasnenud	kaasnenud =kaasne  (PtsPtPs  >kaasnema !27_V	et	f	\N
151149	kaasnenud	kaasnenud =kaasnenu  (PlN  >kaasnenu !01_S	et	f	\N
151150	kaasnenud	"kaasnenu %kaasne  )NU_vS  <kaasnema ;27_V	et	f	\N
151152	kaasnenud	kaasnenud =kaasnenud  (ID  >kaasnenud !41_A	et	f	\N
151154	kaasnenud	"kaasnenud %kaasne  )NUD_vA  <kaasnema ;27_V	et	f	\N
151162	1940-aastatest	-aastatest =aasta  (PlEl  >-aasta !01_S	et	f	\N
151163	1940-aastatest	-aastatest =test  (SgN  >-aasta+test !22_S	et	f	\N
151164	1940-aastatest	-aastatest =tate  (PlEl  >-aas+tatt !22_S	et	f	\N
151177	läänemaades	läänemaades =maa  (PlIn  >lääne+maa !26_S	et	f	\N
151178	läänemaades	läänemaades =maade  (PlIn  >lääne+maat !22_S	et	f	\N
151184	pölvkonna	?pölvkonna =pölvkonna  (SgN  >pölvkonna !16_S	et	f	\N
151185	pölvkonna	?pölvkonna =pölvkonna  (SgG  >pölvkonna !16_S	et	f	\N
151186	pölvkonna	?pölvkonna =pölvkonna  (SgG  >pölvkond !22_S	et	f	\N
151187	zanri	?zanri =zanri  (SgN  >zanri !16_S	et	f	\N
151188	zanri	?zanri =zanri  (SgG  >zanri !16_S	et	f	\N
151189	zanri	?zanri =zanri  (SgG  >zanr !22_S	et	f	\N
151190	zanri	?zanri =zanri  (SgP  >zanr !22_S	et	f	\N
151191	zanri	?zanri =zanri  (SgAdt  >zanr !22_S	et	f	\N
151192	zanri	?zanri =zanri  (IndPrPs_  >zanrima !28_V	et	f	\N
151193	zanri	?zanri =zanri  (ImpPrSg2  >zanrima !28_V	et	f	\N
151201	idamaades	idamaades =maa  (PlIn  >ida+maa !26_S	et	f	\N
151203	idamaades	idamaades =maade  (PlIn  >ida+maat !22_S	et	f	\N
151209	suhtunud	suhtunud =suhtu  (PtsPtPs  >suhtuma !27_V	et	f	\N
151210	suhtunud	suhtunud =suhtunu  (PlN  >suhtunu !01_S	et	f	\N
151211	suhtunud	"suhtunu %suhtu  )NU_vS  <suhtuma ;27_V	et	f	\N
151212	suhtunud	suhtunud =suhtunud  (ID  >suhtunud !41_A	et	f	\N
151213	suhtunud	"suhtunud %suhtu  )NUD_vA  <suhtuma ;27_V	et	f	\N
151238	kaotajate	kaotajate =kaotaja  (PlG  >kaotaja !01_S	et	f	\N
151239	kaotajate	"kaotaja %kaota  )JA_vS  <kaotama ;27_V	et	f	\N
151240	möistetud	?möistetud =möiste  (PtsPtIps  >möistema !27_V	et	f	\N
151241	möistetud	?möistetud =möistetu  (PlN  >möistetu !01_AS	et	f	\N
151242	möistetud	?möistetud =möistetu  (IndPrSg2  >möistetuma !27_V	et	f	\N
151243	möistetud	?möistetud =möistetud  (ID  >möistetud !41_A	et	f	\N
151249	vöitlema	?vöitlema =vöitle  (Sup  >vöitlema !30_V	et	f	\N
151250	vöitlema	?vöitlema =vöitlema  (SgG  >vöitlem !02_A	et	f	\N
151265	tarditsiooni	?tarditsiooni =tarditsioo  (SgTer  >tarditsioo !26_S	et	f	\N
151267	tarditsiooni	?tarditsiooni =tarditsiooni  (SgN  >tarditsiooni !16_S	et	f	\N
151268	tarditsiooni	?tarditsiooni =tarditsiooni  (SgG  >tarditsiooni !16_S	et	f	\N
151269	tarditsiooni	?tarditsiooni =tarditsiooni  (SgG  >tarditsioon !22_S	et	f	\N
151270	tarditsiooni	?tarditsiooni =tarditsiooni  (SgP  >tarditsioon !22_S	et	f	\N
151271	tarditsiooni	?tarditsiooni =tarditsiooni  (SgAdt  >tarditsioon !22_S	et	f	\N
151272	tarditsiooni	?tarditsiooni =tarditsiooni  (IndPrPs_  >tarditsioonima !28_V	et	f	\N
151273	tarditsiooni	?tarditsiooni =tarditsiooni  (ImpPrSg2  >tarditsioonima !28_V	et	f	\N
151274	tarditsiooni	?tarditsiooni =itsioo  (SgTer  >tard+itsioo !26_S	et	f	\N
151275	tarditsiooni	?tarditsiooni =itsiooni  (SgN  >tard+itsiooni !16_S	et	f	\N
151276	tarditsiooni	?tarditsiooni =itsiooni  (SgG  >tard+itsiooni !16_S	et	f	\N
151277	tarditsiooni	?tarditsiooni =itsiooni  (SgG  >tard+itsioon !22_S	et	f	\N
151278	tarditsiooni	?tarditsiooni =itsiooni  (SgP  >tard+itsioon !22_S	et	f	\N
151279	tarditsiooni	?tarditsiooni =itsiooni  (SgAdt  >tard+itsioon !22_S	et	f	\N
151291	asumisele	asumisele =asumise  (SgAll  >asumine !12_S	et	f	\N
151292	asumisele	"asumine %asu  )MINE_vS  <asuma ;27_V	et	f	\N
151293	asumisele	"asumine %asumi  )NE_aA  <asum ;02_S	et	f	\N
151306	nostalgia	nostalgia =nostalgia  (SgN  >nostalgia !01_S	et	f	\N
151307	nostalgia	nostalgia =nostalgia  (SgG  >nostalgia !01_S	et	f	\N
151316	suhtuv	suhtuv =suhtu  (PtsPrPs  >suhtuma !27_V	et	f	\N
151317	suhtuv	suhtuv =suhtuv  (SgN  >suhtuv !02_A	et	f	\N
151318	suhtuv	"suhtuv %suhtu  )V_vA  <suhtuma ;27_V	et	f	\N
151328	kaasakiskuvam	kaasakiskuvam =kiskuvam  (SgN  >kaasa+kiskuvam !02_A	et	f	\N
151329	kaasakiskuvam	"kaasa+kiskuvam %kiskuva  )M_cA  <kaasa+kiskuv ;02_A	et	f	\N
151330	sahhalini	?sahhalini =sahhali  (SgTer  >sahhal !02_S	et	f	\N
151331	sahhalini	?sahhalini =sahhalini  (SgG  >sahhalin !19_S	et	f	\N
151333	sahhalini	?sahhalini =sahhalini  (SgP  >sahhalin !19_S	et	f	\N
151335	sahhalini	?sahhalini =sahhalini  (SgAdt  >sahhalin !19_S	et	f	\N
151069	nooruse	"noorus %noor  )US_aS  <noor ;13_AS	et	f	\N
151082	ahvatlevam	ahvatlevam =ahvatlevam  (SgN  >ahvatlevam !02_A	et	f	\N
151084	ahvatlevam	"ahvatlevam %ahvatle  )VAM_cA  <ahvatlema ;27_V	et	f	\N
151085	ahvatlevam	"ahvatlevam %ahvatleva  )M_cA  <ahvatlev ;02_A	et	f	\N
151098	hitleri	?hitleri =hitleri  (SgN  >hitleri !01_S	et	f	\N
151099	hitleri	?hitleri =hitleri  (SgG  >hitleri !01_S	et	f	\N
151100	hitleri	?hitleri =hitleri  (SgG  >hitler !02_S	et	f	\N
151102	mõistetud	mõistetud =mõiste  (PtsPtIps  >mõistma !34_V	et	f	\N
151103	mõistetud	mõistetud =mõistetu  (PlN  >mõistetu !01_S	et	f	\N
151104	mõistetud	"mõistetu %mõiste  )TU1_vS  <mõistma ;34_V	et	f	\N
151105	mõistetud	"mõistetu %mõiste  )TU2_kA  <mõiste ;06_S	et	f	\N
151106	mõistetud	mõistetud =mõistetu  (PlN  >mõistetu !01_A	et	f	\N
151107	mõistetud	mõistetud =mõistetud  (ID  >mõistetud !41_A	et	f	\N
151108	mõistetud	"mõistetud %mõiste  )TUD_vA  <mõistma ;34_V	et	f	\N
151142	1940-ndaid	?-ndaid =ndai  (PlN  >-ndai !26_S	et	f	\N
151143	1940-ndaid	?-ndaid =ndai  (SgP  >-ndai !26_S	et	f	\N
151144	1940-ndaid	?-ndaid =ndaid  (SgN  >-ndaid !22_S	et	f	\N
151165	holokaust	?holokaust =holokau  (SgEl  >holokau !26_S	et	f	\N
151166	holokaust	?holokaust =holokaus  (SgP  >holokaus !11_S	et	f	\N
151173	küüditamiseks	küüditamiseks =küüditamise  (SgTr  >küüditamine !12_S	et	f	\N
151174	küüditamiseks	"küüditamine %küüdita  )MINE_vS  <küüditama ;27_V	et	f	\N
151179	rohkelt	rohkelt =rohke  (SgAbl  >rohke !01_A	et	f	\N
151180	rohkelt	rohkelt =rohkelt  (ID  >rohkelt !41_D	et	f	\N
151181	rohkelt	"rohkelt %rohke  )LT_mD  <rohke ;01_A	et	f	\N
151214	söbralikult	?söbralikult =söbraliku  (SgAbl  >söbralik !25_A	et	f	\N
151215	söbralikult	?söbralikult =söbralikult  (ID  >söbralikult !41_D	et	f	\N
151230	tsehhovi	?tsehhovi =tsehhovi  (ID  >tsehhovi !41_D	et	f	\N
151231	tsehhovi	?tsehhovi =tsehhovi  (SgG  >tsehhov !02_A	et	f	\N
151234	vöitjamaade	?vöitjamaade =vöitjamaa  (PlG  >vöitjamaa !26_S	et	f	\N
151235	vöitjamaade	?vöitjamaade =vöitjamaade  (SgN  >vöitjamaade !16_S	et	f	\N
151236	vöitjamaade	?vöitjamaade =vöitjamaade  (SgG  >vöitjamaade !16_S	et	f	\N
151237	vöitjamaade	?vöitjamaade =vöitjamaade  (PlP  >vöitjamaad !22_S	et	f	\N
151304	käsitleva	käsitleva =käsitleva  (SgG  >käsitlev !02_A	et	f	\N
151305	käsitleva	"käsitlev %käsitle  )V_vA  <käsitlema ;27_V	et	f	\N
151308	rõhutava	rõhutava =rõhutava  (SgG  >rõhutav !02_A	et	f	\N
151309	rõhutava	"rõhutav %rõhu  )TAV_vAS  <rõhuma ;27_V	et	f	\N
151310	rõhutava	"rõhutav %rõhuta  )V_vA  <rõhutama ;27_V	et	f	\N
151311	rõhutava	rõhutava =tava  (SgN  >rõhu+tava !17_S	et	f	\N
151312	rõhutava	rõhutava =tava  (SgG  >rõhu+tava !17_S	et	f	\N
151313	rõhutava	rõhutava =tava  (SgP  >rõhu+tava !17_S	et	f	\N
151321	ebameeldivuse	ebameeldivuse =meeldivuse  (SgG  >eba+meeldivus !11_S	et	f	\N
151322	ebameeldivuse	"eba+meeldivus %meeldiva  )US_aS  <eba+meeldiv ;02_A	et	f	\N
151384	biiblipärane	?biiblipärane =biiblipärane  (SgN  >biiblipärane !12_A	et	f	\N
151385	biiblipärane	?biiblipärane =biiblipärane  (PlP  >biiblipäran !19_S	et	f	\N
151399	seondumise	seondumise =seondumise  (SgG  >seondumine !12_S	et	f	\N
151400	seondumise	"seondumine %seondu  )MINE_vS  <seonduma ;27_V	et	f	\N
151418	raamatudes	?raamatudes =raamatu  (Ger  >raamatuma !27_V	et	f	\N
151419	raamatudes	?raamatudes =atu  (PlIn  >raam+atu !16_S	et	f	\N
151431	aastatuh	?aastatuh =aastatuh  (ID  >aastatuh !41_I	et	f	\N
151452	sirpi	sirpi =sirpi  (SgP  >sirp !22_S	et	f	\N
151453	sirpi	sirpi =sirpi  (SgAdt  >sirp !22_S	et	f	\N
151476	maase	?maase =maase  (SgN  >maase !06_S	et	f	\N
151477	maase	?maase =maase  (SgG  >maase !06_S	et	f	\N
151478	maase	?maase =maase  (SgG  >maane !10_A	et	f	\N
151479	maase	?maase =maase  (IndPrPs_  >maasema !28_V	et	f	\N
151480	maase	?maase =maase  (ImpPrSg2  >maasema !28_V	et	f	\N
151489	muinas	?muinas =muina  (SgIn  >muina !16_S	et	f	\N
151490	muinas	?muinas =muina  (IndIpfSg3  >muinama !29_V	et	f	\N
151491	muinas	?muinas =muinas  (SgN  >muinas !07_S	et	f	\N
151504	koristamist	koristamist =koristamis  (SgP  >koristamine !12_S	et	f	\N
151505	koristamist	"koristamine %korista  )MINE_vS  <koristama ;27_V	et	f	\N
151520	kudus	kudus =kudu  (SgIn  >kudu !17_S	et	f	\N
151521	kudus	kudus =kudu  (IndIpfSg3  >kuduma !28_V	et	f	\N
151540	meeskonnatöö	meeskonnatöö =töö  (SgN  >mees+konna+töö !26_S	et	f	\N
151541	meeskonnatöö	meeskonnatöö =töö  (SgG  >mees+konna+töö !26_S	et	f	\N
151558	ametikohale	ametikohale =koha  (SgAll  >ameti+koha !17_S	et	f	\N
151559	ametikohale	ametikohale =koha  (SgAll  >ameti+koht !22_S	et	f	\N
151588	käesin	?käesin =käesi  (IndPrSg1  >käesima !28_V	et	f	\N
151589	käesin	?käesin =käesin  (SgN  >käesin !02_S	et	f	\N
151596	töökohale	töökohale =koha  (SgAll  >töö+koha !17_S	et	f	\N
151597	töökohale	töökohale =koha  (SgAll  >töö+koht !22_S	et	f	\N
151624	popova	?popova =popova  (SgN  >popova !01_S	et	f	\N
151626	popova	?popova =popova  (SgG  >popova !01_S	et	f	\N
151627	popova	?popova =popova  (SgG  >popov !02_A	et	f	\N
151628	popova	?popova =ova  (SgN  >pop+ova !17_S	et	f	\N
151629	popova	?popova =ova  (SgG  >pop+ova !17_S	et	f	\N
151206	lugejaskonnast	"lugejaskonnane %lugejaskonna  )NE_aA  <lugejaskond ;22_S	et	f	\N
151221	köitvam	köitvam =köitvam  (SgN  >köitvam !02_A	et	f	\N
151222	köitvam	"köitvam %köit  )VAM_cA  <köitma ;34_V	et	f	\N
151223	köitvam	"köitvam %köitva  )M_cA  <köitev ;02_A	et	f	\N
151233	töestab	?töestab =töesta  (IndPrSg3  >töestama !27_V	et	f	\N
151246	kaotaja	kaotaja =kaotaja  (SgN  >kaotaja !01_S	et	f	\N
151247	kaotaja	"kaotaja %kaota  )JA_vS  <kaotama ;27_V	et	f	\N
151248	kaotaja	kaotaja =kaotaja  (SgG  >kaotaja !01_S	et	f	\N
151262	nördimust	nördimust =nördimus  (SgP  >nördimus !11_S	et	f	\N
151263	nördimust	"nördimus %nördi  )MUS_vS  <nördima ;27_V	et	f	\N
151281	laialdaselt	laialdaselt =laialdase  (SgAbl  >laialdane !12_A	et	f	\N
151282	laialdaselt	laialdaselt =laialdaselt  (ID  >laialdaselt !41_D	et	f	\N
151284	laialdaselt	"laialdaselt %laialdase  )LT_mD  <laialdane ;12_A	et	f	\N
151289	kogenute	kogenute =kogenu  (PlG  >kogenu !01_S	et	f	\N
151290	kogenute	"kogenu %koge  )NU_vS  <kogema ;27_V	et	f	\N
151294	90aastatel	aastatel =aasta  (PlAd  >aasta !01_S	et	f	\N
151295	90aastatel	aastatel =tate  (PlAd  >aas+tatt !22_S	et	f	\N
151301	generatsiooni	generatsiooni =generatsiooni  (SgG  >generatsioon !22_S	et	f	\N
151302	generatsiooni	generatsiooni =generatsiooni  (SgP  >generatsioon !22_S	et	f	\N
151303	generatsiooni	generatsiooni =generatsiooni  (SgAdt  >generatsioon !22_S	et	f	\N
151314	sõbralikkusega	sõbralikkusega =sõbralikkuse  (SgKom  >sõbralikkus !11~09_S	et	f	\N
151315	sõbralikkusega	"sõbralikkus %sõbralikku  )US_aS  <sõbralik ;25_A	et	f	\N
151323	tundest	tundest =tunde  (SgEl  >tunne !06_S	et	f	\N
151324	tundest	tundest =tundes  (SgP  >tundene !12~10_A	et	f	\N
151325	tundest	"tundene %tunde  )NE_aA  <tunne ;06_S	et	f	\N
151341	vaikidakse	?vaikidakse =vaikidakse  (SgG  >vaikidakne !02_A	et	f	\N
151344	vaikidakse	?vaikidakse =idakse  (SgG  >vaik+idakne !02_A	et	f	\N
151358	ohtralt	ohtralt =ohtra  (SgAbl  >ohter !02_A	et	f	\N
151359	ohtralt	ohtralt =ohtralt  (ID  >ohtralt !41_D	et	f	\N
151360	ohtralt	"ohtralt %ohtra  )LT_mD  <ohter ;02_A	et	f	\N
151361	selgitusprotsessi	selgitusprotsessi =protsessi  (SgG  >selgitus+protsess !22_S	et	f	\N
151362	selgitusprotsessi	selgitusprotsessi =protsessi  (SgP  >selgitus+protsess !22_S	et	f	\N
151363	selgitusprotsessi	selgitusprotsessi =protsessi  (SgAdt  >selgitus+protsess !22_S	et	f	\N
151366	eksisteeriv	eksisteeriv =eksisteeri  (PtsPrPs  >eksisteerima !28_V	et	f	\N
151367	eksisteeriv	eksisteeriv =eksisteeriv  (SgN  >eksisteeriv !02_A	et	f	\N
151368	eksisteeriv	"eksisteeriv %eksisteeri  )V_vA  <eksisteerima ;28_V	et	f	\N
151373	enckel	?enckel =encke  (SgAd  >encke !06_S	et	f	\N
151374	enckel	?enckel =encke  (PlAd  >enck !22_S	et	f	\N
151375	enckel	?enckel =enckel  (SgN  >enckel !02_S	et	f	\N
151376	laiemast	laiemast =laiema  (SgEl  >laiem !02_A	et	f	\N
151377	laiemast	"laiem %laie  )M_cA  <lai ;22_A	et	f	\N
151378	laiemast	laiemast =ema  (SgEl  >lai+ema !17_S	et	f	\N
151379	laiemast	laiemast =emas  (SgP  >lai+emane !10_AS	et	f	\N
151380	laiemast	"lai+emane %ema  )NE_aA  <lai+ema ;17_S	et	f	\N
151391	ajalookontseptsiooni	ajalookontseptsiooni =kontseptsiooni  (SgG  >aja+loo+kontseptsioon !22_S	et	f	\N
151392	ajalookontseptsiooni	ajalookontseptsiooni =kontseptsiooni  (SgP  >aja+loo+kontseptsioon !22_S	et	f	\N
151393	ajalookontseptsiooni	ajalookontseptsiooni =kontseptsiooni  (SgAdt  >aja+loo+kontseptsioon !22_S	et	f	\N
151395	ida-saksa	ida-saksa =saksa  (ID  >ida-saksa !41_G	et	f	\N
151396	ida-saksa	ida-saksa =saksa  (SgG  >ida-saks !23?22_S	et	f	\N
151397	ida-saksa	ida-saksa =saksa  (SgP  >ida-saks !23?22_S	et	f	\N
151398	ida-saksa	ida-saksa =saksa  (SgAdt  >ida-saks !23?22_S	et	f	\N
151406	kindlam	kindlam =kindlam  (SgN  >kindlam !02_A	et	f	\N
151407	kindlam	"kindlam %kindla  )M_cA  <kindel ;02_A	et	f	\N
151420	kaotajaks	kaotajaks =kaotaja  (SgTr  >kaotaja !01_S	et	f	\N
151421	kaotajaks	"kaotaja %kaota  )JA_vS  <kaotama ;27_V	et	f	\N
151422	kiiruga	kiiruga =kiiru  (SgKom  >kiird !22_S	et	f	\N
151423	kiiruga	kiiruga =kiiru  (SgKom  >kiir !22_S	et	f	\N
151424	kulda	kulda =kulda  (SgP  >kuld !22_S	et	f	\N
151425	kulda	kulda =kulda  (SgAdt  >kuld !22_S	et	f	\N
151426	kulda	kulda =kulda  (IndPrPs_  >kuldama !29_V	et	f	\N
151427	kulda	kulda =kulda  (ImpPrSg2  >kuldama !29_V	et	f	\N
151456	käsikivi	käsikivi =kivi  (SgN  >käsi+kivi !17_S	et	f	\N
151457	käsikivi	käsikivi =kivi  (SgG  >käsi+kivi !17_S	et	f	\N
151458	käsikivi	käsikivi =kivi  (SgP  >käsi+kivi !17_S	et	f	\N
151462	hakkaid	?hakkaid =hakkai  (PlN  >hakkai !26_S	et	f	\N
151463	hakkaid	?hakkaid =hakkai  (SgP  >hakkai !26_S	et	f	\N
151464	hakkaid	?hakkaid =hakkaid  (SgN  >hakkaid !22_S	et	f	\N
151465	hakkaid	?hakkaid =aid  (SgN  >hakk+aid !22_S	et	f	\N
151486	savi	savi =savi  (SgN  >savi !17_S	et	f	\N
151487	savi	savi =savi  (SgG  >savi !17_S	et	f	\N
151488	savi	savi =savi  (SgP  >savi !17_S	et	f	\N
151493	taratega	### taratega	et	f	\N
151506	hapukapsasuppi	hapukapsasuppi =suppi  (SgP  >hapu+kapsa+supp !22_S	et	f	\N
151507	hapukapsasuppi	hapukapsasuppi =suppi  (SgAdt  >hapu+kapsa+supp !22_S	et	f	\N
151508	lõunaks	lõunaks =lõuna  (SgTr  >lõuna !06_S	et	f	\N
151509	lõunaks	lõunaks =naks  (SgN  >lõu+naks !22_S	et	f	\N
151264	ulatuslikku	ulatuslikku =ulatuslikku  (SgP  >ulatuslik !25_A	et	f	\N
151266	ulatuslikku	ulatuslikku =ulatuslikku  (SgAdt  >ulatuslik !25_A	et	f	\N
151296	idablokimaades	idablokimaades =maa  (PlIn  >ida+bloki+maa !26_S	et	f	\N
151297	idablokimaades	idablokimaades =maade  (PlIn  >ida+bloki+maat !22_S	et	f	\N
151332	ajalooga-	ajalooga- =loo  (SgKom  >aja+lugu !18_S	et	f	\N
151336	ajalooga-	ajalooga- =loo  (SgKom  >aja+loog !22_S	et	f	\N
151338	ajalooga-	ajalooga- =loo  (SgKom  >aja+lood !22_S	et	f	\N
151340	ajalooga-	ajalooga- =looga  (SgG  >aja+look !22_S	et	f	\N
151345	kajastust	kajastust =kajastus  (SgP  >kajastus !11_S	et	f	\N
151346	kajastust	"kajastus %kajasta  )US_vS  <kajastama ;27_V	et	f	\N
151364	lähtekohad	lähtekohad =koha  (PlN  >lähte+koha !17_S	et	f	\N
151365	lähtekohad	lähtekohad =koha  (PlN  >lähte+koht !22_S	et	f	\N
151371	represseerimise	represseerimise =represseerimise  (SgG  >represseerimine !12_S	et	f	\N
151372	represseerimise	"represseerimine %represseeri  )MINE_vS  <represseerima ;28_V	et	f	\N
151381	kaasaarvatud	kaasaarvatud =atu  (PlN  >kaasa+arv+att !22_S	et	f	\N
151382	kaasaarvatud	kaasaarvatud =arva  (PtsPtIps  >kaasa+_arvama !29_V	et	f	\N
151383	kaasaarvatud	kaasaarvatud =arvatu  (PlN  >kaasa+arvatu !01_AS	et	f	\N
151428	sealsete	sealsete =sealse  (PlG  >sealne !02_A	et	f	\N
151430	sealsete	sealsete =sete  (SgN  >seal+sete !06_S	et	f	\N
151432	intensiivselt	intensiivselt =intensiivse  (SgAbl  >intensiivne !02_A	et	f	\N
151433	intensiivselt	intensiivselt =intensiivselt  (ID  >intensiivselt !41_D	et	f	\N
151434	intensiivselt	"intensiivselt %intensiivse  )LT_mD  <intensiivne ;02_A	et	f	\N
151438	lamastele	?lamastele =lamas  (PlAll  >lamas !09_S	et	f	\N
151442	lamastele	?lamastele =lamas  (PlAll  >lamane !10_A	et	f	\N
151444	lamastele	?lamastele =lamastele  (IndPrPs_  >lamastelema !36_V	et	f	\N
151445	lamastele	?lamastele =lamastele  (ImpPrSg2  >lamastelema !36_V	et	f	\N
151446	maakogestamis	?maakogestamis =maakogestami  (SgIn  >maakogestam !02_A	et	f	\N
151447	maakogestamis	?maakogestamis =maakogestamis  (SgN  >maakogestamis !09_S	et	f	\N
151448	maakogestamis	?maakogestamis =kogestami  (SgIn  >maa+kogestam !02_A	et	f	\N
151449	maakogestamis	?maakogestamis =kogestamis  (SgN  >maa+kogestamis !09_S	et	f	\N
151466	rasva	rasva =rasva  (ID  >rasva !41_D	et	f	\N
151467	rasva	rasva =rasva  (SgG  >rasv !22_S	et	f	\N
151468	rasva	rasva =rasva  (SgP  >rasv !22_S	et	f	\N
151469	rasva	rasva =rasva  (SgAdt  >rasv !22_S	et	f	\N
151470	rasva	rasva =rasva  (IndPrPs_  >rasvama !29_V	et	f	\N
151471	rasva	rasva =rasva  (ImpPrSg2  >rasvama !29_V	et	f	\N
151512	sõbratari	sõbratari =sõbratari  (SgG  >sõbratar !19_S	et	f	\N
151513	sõbratari	sõbratari =sõbratari  (SgP  >sõbratar !19_S	et	f	\N
151514	sõbratari	sõbratari =sõbratari  (SgAdt  >sõbratar !19_S	et	f	\N
151515	sõbratari	sõbratari =tari  (SgN  >sõbra+tari !24_S	et	f	\N
151531	sobivam	sobivam =sobivam  (SgN  >sobivam !02_A	et	f	\N
151532	sobivam	"sobivam %sobi  )VAM_cA  <sobima ;27_V	et	f	\N
151533	sobivam	"sobivam %sobiva  )M_cA  <sobiv ;02_A	et	f	\N
151537	tunistus	?tunistus =tunistu  (SgIn  >tunistu !01_S	et	f	\N
151538	tunistus	?tunistus =tunistu  (IndIpfSg3  >tunistuma !27_V	et	f	\N
151539	tunistus	?tunistus =tunistus  (SgN  >tunistus !11_S	et	f	\N
151549	pakkute	### pakkute	et	f	\N
151572	juhatajad	juhatajad =juhataja  (PlN  >juhataja !01_S	et	f	\N
151573	juhatajad	"juhataja %juhata  )JA_vS  <juhatama ;27_V	et	f	\N
151577	liisaks	?liisaks =liisa  (SgTr  >liisa !16_S	et	f	\N
151578	liisaks	?liisaks =liisa  (KndPrPs  >liisama !29_V	et	f	\N
151585	vestlev	vestlev =vestle  (PtsPrPs  >vestlema !30_V	et	f	\N
151586	vestlev	vestlev =vestlev  (SgN  >vestlev !02_A	et	f	\N
151587	vestlev	"vestlev %vestle  )V_vA  <vestlema ;30_V	et	f	\N
151590	gruuppides	?gruuppides =gruuppi  (PlIn  >gruupp !22_S	et	f	\N
151591	gruuppides	?gruuppides =gruuppi  (Ger  >gruuppima !28_V	et	f	\N
151598	täiendkoolitusel	täiendkoolitusel =koolituse  (SgAd  >täiend+koolitus !11_S	et	f	\N
151599	täiendkoolitusel	"täiend+koolitus %kooli  )TUS2_aS  <täiend+kool ;22_S	et	f	\N
151601	vastavaid	vastavaid =vastava  (PlP  >vastav !02_A	et	f	\N
151602	vastavaid	"vastav %vasta  )V_vA  <vastama ;29_V	et	f	\N
151607	avalduse	avalduse =avalduse  (SgG  >avaldus !11_S	et	f	\N
151608	avalduse	"avaldus %avalda  )US_vS  <avaldama ;27_V	et	f	\N
151609	konkurssis	?konkurssis =konkurssi  (SgIn  >konkurssi !01_S	et	f	\N
151610	konkurssis	?konkurssis =konkurssi  (IndIpfSg3  >konkurssima !28_V	et	f	\N
151611	konkurssis	?konkurssis =konkurssis  (SgN  >konkurssis !11_S	et	f	\N
151636	saatkonna	saatkonna =saatkonna  (SgG  >saatkond !22_S	et	f	\N
151637	saatkonna	saatkonna =konna  (SgG  >saat+konn !22_S	et	f	\N
151638	saatkonna	saatkonna =konna  (SgP  >saat+konn !22_S	et	f	\N
151639	saatkonna	saatkonna =konna  (SgAdt  >saat+konn !22_S	et	f	\N
151641	üheltpoolt	?üheltpoolt =üheltpoo  (SgAbl  >üheltpoo !26_S	et	f	\N
151648	suurbritaannia	?suurbritaannia =suurbritaannia  (SgN  >suurbritaannia !01_S	et	f	\N
151649	suurbritaannia	?suurbritaannia =suurbritaannia  (SgG  >suurbritaannia !01_S	et	f	\N
151650	suurbritaannia	?suurbritaannia =britaannia  (SgN  >suur+britaannia !01_S	et	f	\N
151651	suurbritaannia	?suurbritaannia =britaannia  (SgG  >suur+britaannia !01_S	et	f	\N
151350	kannatanud	kannatanud =kannata  (PtsPtPs  >kannatama !27_V	et	f	\N
151351	kannatanud	kannatanud =kannatanu  (PlN  >kannatanu !01_S	et	f	\N
151352	kannatanud	"kannatanu %kannata  )NU_vS  <kannatama ;27_V	et	f	\N
151353	kannatanud	kannatanud =kannatanud  (ID  >kannatanud !41_A	et	f	\N
151354	kannatanud	"kannatanud %kannata  )NUD_vA  <kannatama ;27_V	et	f	\N
151355	kannatanud	kannatanud =tanu  (PlN  >kanna+tanu !17_S	et	f	\N
151369	kaasatoodud	kaasatoodud =too  (PtsPtIps  >kaasa+_tooma !38_V	et	f	\N
151370	kaasatoodud	kaasatoodud =toodu  (PlN  >kaasa+toodu !01_S	et	f	\N
151401	laiema	laiema =laiema  (SgG  >laiem !02_A	et	f	\N
151402	laiema	"laiem %laie  )M_cA  <lai ;22_A	et	f	\N
151403	laiema	laiema =ema  (SgN  >lai+ema !17_S	et	f	\N
151404	laiema	laiema =ema  (SgG  >lai+ema !17_S	et	f	\N
151405	laiema	laiema =ema  (SgP  >lai+ema !17_S	et	f	\N
151408	määritud	määritud =määri  (PtsPtIps  >määrima !28_V	et	f	\N
151409	määritud	määritud =määritu  (PlN  >määritu !01_AS	et	f	\N
151410	määritud	"määritu %määri  )TU1_vS  <määrima ;28_V	et	f	\N
151411	määritud	"määritu %määri  )TU2_kA  <määr ;22_S	et	f	\N
151412	määritud	määritud =määritud  (ID  >määritud !41_A	et	f	\N
151413	määritud	"määritud %määri  )TUD_vA  <määrima ;28_V	et	f	\N
151429	asuniketega	?asuniketega =nike  (PlKom  >asu+nike !06_S	et	f	\N
151435	äres	?äres =äre  (IndIpfSg3  >ärema !27_V	et	f	\N
151436	äres	?äres =äres  (SgN  >äres !09_S	et	f	\N
151437	kitsetele	?kitsetele =kitse  (PlAll  >kitne !02_A	et	f	\N
151439	kitsetele	?kitsetele =kitse  (PlAll  >kitse !06_S	et	f	\N
151440	kitsetele	?kitsetele =kitsete  (PlAll  >kitsett !22_S	et	f	\N
151441	kitsetele	?kitsetele =kitsetele  (IndPrPs_  >kitsetelema !36_V	et	f	\N
151443	kitsetele	?kitsetele =kitsetele  (ImpPrSg2  >kitsetelema !36_V	et	f	\N
151450	lõigata	lõigata =lõiga  (Inf  >lõikama !29_V	et	f	\N
151451	lõigata	lõigata =lõiga  (IndPrIps_  >lõikama !29_V	et	f	\N
151454	jahutati	jahutati =jahuta  (IndIpfIps  >jahutama !27_V	et	f	\N
151455	jahutati	jahutati =tati  (SgG  >jahu+tatt !22_S	et	f	\N
151473	valmistamiseks	valmistamiseks =valmistamise  (SgTr  >valmistamine !12_S	et	f	\N
151474	valmistamiseks	"valmistamine %valmista  )MINE_vS  <valmistama ;27_V	et	f	\N
151492	müüritega	### müüritega	et	f	\N
151494	kontakteerisid	?kontakteerisid =kontakteeri  (PlP  >kontakteeri !16_S	et	f	\N
151495	kontakteerisid	?kontakteerisid =kontakteeri  (PlP  >kontakteer !22_S	et	f	\N
151496	kontakteerisid	?kontakteerisid =kontakteeri  (IndIpfSg2  >kontakteerima !28_V	et	f	\N
151497	kontakteerisid	?kontakteerisid =kontakteeri  (IndIpfPl3  >kontakteerima !28_V	et	f	\N
151498	kontakteerisid	?kontakteerisid =eeri  (PlP  >kontakt+eeri !16_S	et	f	\N
151499	kontakteerisid	?kontakteerisid =eeri  (PlP  >kontakt+eer !22_S	et	f	\N
151516	triikida	triikida =triiki  (Inf  >triikima !28_V	et	f	\N
151517	triikida	triikida =ida  (SgN  >triik+ida !17_S	et	f	\N
151518	triikida	triikida =ida  (SgG  >triik+ida !17_S	et	f	\N
151519	triikida	triikida =ida  (SgP  >triik+ida !17_S	et	f	\N
151522	kaheksateistkümneks	?kaheksateistkümneks =kaheksateistkümne  (PlTr  >kaheksateistkümn !22_S	et	f	\N
151523	kaheksateistkümneks	?kaheksateistkümneks =kümne  (PlTr  >kaheksa+teist+kümn !22_S	et	f	\N
151524	kaheksateistkümneks	?kaheksateistkümneks =teistkümne  (PlTr  >kaheksa+teistkümn !22_S	et	f	\N
151525	kaheksateistkümneks	?kaheksateistkümneks =ksateistkümne  (PlTr  >kahe+ksateistkümn !22_S	et	f	\N
151530	kandidat	### kandidat	et	f	\N
151542	problemi	?problemi =problemi  (SgN  >problemi !01_S	et	f	\N
151543	problemi	?problemi =problemi  (SgG  >problemi !01_S	et	f	\N
151544	problemi	?problemi =problemi  (SgG  >problem !02_A	et	f	\N
151546	personalosakonna	?personalosakonna =personalosakonna  (SgN  >personalosakonna !16_S	et	f	\N
151547	personalosakonna	?personalosakonna =personalosakonna  (SgG  >personalosakonna !16_S	et	f	\N
151548	personalosakonna	?personalosakonna =personalosakonna  (SgG  >personalosakond !22_S	et	f	\N
151552	teaduskonnas	teaduskonnas =teaduskonna  (SgIn  >teaduskond !22_S	et	f	\N
151553	teaduskonnas	teaduskonnas =konna  (SgIn  >teadus+konn !22_S	et	f	\N
151570	ametikohal	ametikohal =koha  (SgAd  >ameti+koha !17_S	et	f	\N
151571	ametikohal	ametikohal =koha  (SgAd  >ameti+koht !22_S	et	f	\N
151579	komunikaabilne	?komunikaabilne =komunikaabilne  (SgN  >komunikaabilne !02_A	et	f	\N
151580	komunikaabilne	?komunikaabilne =komunikaabilne  (PlP  >komunikaabiln !22_S	et	f	\N
151581	komunikaabilne	?komunikaabilne =kaabilne  (SgN  >kom+uni+kaabilne !02_A	et	f	\N
151582	komunikaabilne	?komunikaabilne =kaabilne  (PlP  >kom+uni+kaabiln !22_S	et	f	\N
151583	komunikaabilne	?komunikaabilne =unikaabilne  (SgN  >kom+unikaabilne !02_A	et	f	\N
151584	komunikaabilne	?komunikaabilne =unikaabilne  (PlP  >kom+unikaabiln !22_S	et	f	\N
151592	meeskonna	meeskonna =meeskonna  (SgG  >meeskond !22_S	et	f	\N
151593	meeskonna	meeskonna =konna  (SgG  >mees+konn !22_S	et	f	\N
151594	meeskonna	meeskonna =konna  (SgP  >mees+konn !22_S	et	f	\N
151595	meeskonna	meeskonna =konna  (SgAdt  >mees+konn !22_S	et	f	\N
151612	rekomendatsiooni	?rekomendatsiooni =rekomendatsioo  (SgTer  >rekomendatsioo !26_S	et	f	\N
151613	rekomendatsiooni	?rekomendatsiooni =rekomendatsiooni  (SgN  >rekomendatsiooni !16_S	et	f	\N
151614	rekomendatsiooni	?rekomendatsiooni =rekomendatsiooni  (SgG  >rekomendatsiooni !16_S	et	f	\N
151414	meediaga	meediaga =meedia  (SgKom  >meedia !01_S	et	f	\N
151415	meediaga	meediaga =dia  (SgKom  >mee+dia !26_S	et	f	\N
151416	natsism	natsism =natsism  (SgN  >natsism !22_S	et	f	\N
151417	natsism	natsism =ism  (SgN  >nats+ism !22_S	et	f	\N
151459	kooti	kooti =koo  (IndIpfIps  >kuduma !28_V	et	f	\N
151460	kooti	kooti =kooti  (SgP  >koot !22_S	et	f	\N
151461	kooti	kooti =kooti  (SgAdt  >koot !22_S	et	f	\N
151472	küünlate	?küünlate =küünla  (PlG  >küünla !01_S	et	f	\N
151475	küünlate	?küünlate =küünla  (IndPrPl2  >küünlama !29_V	et	f	\N
151481	kaivama	?kaivama =kaiva  (Sup  >kaivama !29_V	et	f	\N
151482	kaivama	?kaivama =kaivama  (SgG  >kaivam !02_A	et	f	\N
151483	kaivama	?kaivama =vama  (SgN  >kai+vama !17_S	et	f	\N
151484	kaivama	?kaivama =vama  (SgG  >kai+vama !17_S	et	f	\N
151485	kaivama	?kaivama =vama  (SgP  >kai+vama !17_S	et	f	\N
151500	volga	?volga =volga  (SgN  >volga !16_S	et	f	\N
151501	volga	?volga =volga  (SgG  >volga !16_S	et	f	\N
151502	volga	?volga =volga  (IndPrPs_  >volgama !29_V	et	f	\N
151503	volga	?volga =volga  (ImpPrSg2  >volgama !29_V	et	f	\N
151526	personaliosakonna	personaliosakonna =konna  (SgG  >personali+osa+konn !22_S	et	f	\N
151527	personaliosakonna	personaliosakonna =konna  (SgP  >personali+osa+konn !22_S	et	f	\N
151528	personaliosakonna	personaliosakonna =konna  (SgAdt  >personali+osa+konn !22_S	et	f	\N
151529	personaliosakonna	personaliosakonna =osakonna  (SgG  >personali+osakond !22_S	et	f	\N
151534	kinnitav	kinnitav =kinnita  (PtsPrPs  >kinnitama !27_V	et	f	\N
151535	kinnitav	kinnitav =kinnitav  (SgN  >kinnitav !02_A	et	f	\N
151536	kinnitav	"kinnitav %kinnita  )V_vA  <kinnitama ;27_V	et	f	\N
151545	allik	?allik =allik  (SgN  >allik !02_S	et	f	\N
151550	praaegu	?praaegu =praaegu  (IndPrPs_  >praaeguma !27_V	et	f	\N
151551	praaegu	?praaegu =praaegu  (ImpPrSg2  >praaeguma !27_V	et	f	\N
151556	vaastust	?vaastust =vaastu  (SgEl  >vaastu !01_S	et	f	\N
151557	vaastust	?vaastust =vaastus  (SgP  >vaastus !11~09_S	et	f	\N
151560	venekeel	venekeel =kee  (SgAd  >vene+kesi !15_S	et	f	\N
151561	venekeel	venekeel =kee  (SgAd  >vene+kee !26_S	et	f	\N
151562	venekeel	venekeel =keel  (SgN  >vene+keel !13_S	et	f	\N
151568	tunnistus	tunnistus =tunnistus  (SgN  >tunnistus !11_S	et	f	\N
151569	tunnistus	"tunnistus %tunnista  )US_vS  <tunnistama ;27_V	et	f	\N
151600	kandidadile	?kandidadile =dadi  (SgAll  >kandi+dadi !17_S	et	f	\N
151620	müümise-ostu	müümise-ostu =ostu  (SgG  >müümise-ost !22_S	et	f	\N
151621	müümise-ostu	müümise-ostu =ostu  (SgP  >müümise-ost !22_S	et	f	\N
151622	müümise-ostu	müümise-ostu =ostu  (SgAdt  >müümise-ost !22_S	et	f	\N
151640	tn	### tn	et	f	\N
151642	international	?international =international  (SgN  >international !02_S	et	f	\N
151643	international	?international =national  (SgN  >inter+national !02_S	et	f	\N
151652	virgiinia	?virgiinia =virgiinia  (SgN  >virgiinia !01_S	et	f	\N
151653	virgiinia	?virgiinia =virgiinia  (SgG  >virgiinia !01_S	et	f	\N
151654	registreerutud	registreerutud =registreeru  (PtsPtIps  >registreeruma !27_V	et	f	\N
151655	registreerutud	registreerutud =registreerutu  (PlN  >registreerutu !01_A	et	f	\N
151656	registreerutud	"registreerutu %registreeru  )TU1_vS  <registreeruma ;27_V	et	f	\N
151657	registreerutud	registreerutud =registreerutud  (ID  >registreerutud !41_A	et	f	\N
151658	registreerutud	"registreerutud %registreeru  )TUD_vA  <registreeruma ;27_V	et	f	\N
151665	virgin	?virgin =virgi  (IndPrSg1  >virkima !28_V	et	f	\N
151666	virgin	?virgin =virgin  (SgN  >virgin !02_S	et	f	\N
151672	sõlminud	sõlminud =sõlmi  (PtsPtPs  >sõlmima !28_V	et	f	\N
151673	sõlminud	sõlminud =sõlminu  (PlN  >sõlminu !01_S	et	f	\N
151674	sõlminud	"sõlminu %sõlmi  )NU_vS  <sõlmima ;28_V	et	f	\N
151675	sõlminud	sõlminud =sõlminud  (ID  >sõlminud !41_A	et	f	\N
151676	sõlminud	"sõlminud %sõlmi  )NUD_vA  <sõlmima ;28_V	et	f	\N
151685	16112007a	### 16112007a	et	f	\N
151692	isikust	isikust =isiku  (SgEl  >isik !02_S	et	f	\N
151693	isikust	isikust =us  (SgP  >isik+uks !14_S	et	f	\N
151694	rollins	?rollins =rollins  (SgN  >rollins !02_S	et	f	\N
151696	rollins	?rollins =ins  (SgN  >roll+ins !22_S	et	f	\N
151704	asukohaga	asukohaga =koha  (SgKom  >asu+koha !17_S	et	f	\N
151705	asukohaga	asukohaga =koha  (SgKom  >asu+koht !22_S	et	f	\N
151732	tükki	tükki =tükki  (ID  >tükki !41_D	et	f	\N
151733	tükki	tükki =tükki  (SgP  >tükk !22_S	et	f	\N
151734	tükki	tükki =tükki  (SgAdt  >tükk !22_S	et	f	\N
151757	britanni	?britanni =britanni  (SgN  >britanni !01_S	et	f	\N
151758	britanni	?britanni =britanni  (SgG  >britanni !01_S	et	f	\N
151759	britanni	?britanni =britanni  (SgG  >britann !22_S	et	f	\N
151760	britanni	?britanni =britanni  (SgP  >britann !22_S	et	f	\N
151761	britanni	?britanni =britanni  (SgAdt  >britann !22_S	et	f	\N
151762	britanni	?britanni =britanni  (IndPrPs_  >britannima !28_V	et	f	\N
151763	britanni	?britanni =britanni  (ImpPrSg2  >britannima !28_V	et	f	\N
151766	tegelev	tegelev =tegele  (PtsPrPs  >tegelema !31~27_V	et	f	\N
151767	tegelev	tegelev =tegelev  (SgN  >tegelev !02_A	et	f	\N
151768	tegelev	"tegelev %tegele  )V_vA  <tegelema ;27_V	et	f	\N
151510	pesi	pesi =pes  (IndIpfSg3  >pesema !36_V	et	f	\N
151511	pesi	pesi =pesi  (PlP  >pesa !17_S	et	f	\N
151554	nõudmistele	nõudmistele =nõudmis  (PlAll  >nõudmine !12?10_S	et	f	\N
151555	nõudmistele	"nõudmine %nõud  )MINE_vS  <nõudma ;34_V	et	f	\N
151563	sooritanud	sooritanud =soorita  (PtsPtPs  >sooritama !27_V	et	f	\N
151564	sooritanud	sooritanud =sooritanu  (PlN  >sooritanu !01_S	et	f	\N
151565	sooritanud	"sooritanu %soorita  )NU_vS  <sooritama ;27_V	et	f	\N
151566	sooritanud	sooritanud =sooritanud  (ID  >sooritanud !41_A	et	f	\N
151567	sooritanud	"sooritanud %soorita  )NUD_vA  <sooritama ;27_V	et	f	\N
151574	triin	?triin =triin  (SgN  >triin !22_S	et	f	\N
151575	personalikond	?personalikond =personalikond  (SgN  >personalikond !22_S	et	f	\N
151576	kandidad	### kandidad	et	f	\N
151603	ajakirjanuslevi	?ajakirjanuslevi =ajakirjanuslevi  (ID  >ajakirjanuslevi !41_D	et	f	\N
151604	ajakirjanuslevi	?ajakirjanuslevi =ajakirjanuslevi  (SgG  >ajakirjanuslev !02_A	et	f	\N
151605	ajakirjanuslevi	?ajakirjanuslevi =nuslevi  (SgG  >aja+kirja+nuslev !02_A	et	f	\N
151606	ajakirjanuslevi	?ajakirjanuslevi =kirjanuslevi  (SgG  >aja+kirjanuslev !02_A	et	f	\N
151623	tatjana	?tatjana =tatja  (SgEs  >tatja !01_S	et	f	\N
151625	tatjana	?tatjana =tatja  (SgEs  >tatjas !02_A	et	f	\N
151644	commertional	?commertional =commertional  (SgN  >commertional !02_S	et	f	\N
151647	inustments	?inustments =inustments  (SgN  >inustments !22_S	et	f	\N
151661	box	### box	et	f	\N
151662	tortola	?tortola =tortola  (SgN  >tortola !01_S	et	f	\N
151663	tortola	?tortola =tortola  (SgG  >tortola !01_S	et	f	\N
151689	föderatsiooni	föderatsiooni =föderatsiooni  (SgG  >föderatsioon !22_S	et	f	\N
151690	föderatsiooni	föderatsiooni =föderatsiooni  (SgP  >föderatsioon !22_S	et	f	\N
151691	föderatsiooni	föderatsiooni =föderatsiooni  (SgAdt  >föderatsioon !22_S	et	f	\N
151709	ostjale	ostjale =ostja  (SgAll  >ostja !01_S	et	f	\N
151710	ostjale	"ostja %ost  )JA_vS  <ostma ;34_V	et	f	\N
151713	kohustustest	kohustustest =kohustus  (PlEl  >kohustus !11_S	et	f	\N
151714	kohustustest	"kohustus %kohusta  )US_vS  <kohustama ;27_V	et	f	\N
151715	edastatud	edastatud =edasta  (PtsPtIps  >edastama !27_V	et	f	\N
151716	edastatud	edastatud =edastatu  (PlN  >edastatu !01_S	et	f	\N
151717	edastatud	"edastatu %edasta  )TU1_vS  <edastama ;27_V	et	f	\N
151718	edastatud	edastatud =edastatud  (ID  >edastatud !41_A	et	f	\N
151719	edastatud	"edastatud %edasta  )TUD_vA  <edastama ;27_V	et	f	\N
151720	paberitest	paberitest =paberi  (PlEl  >paber !02_S	et	f	\N
151721	paberitest	paberitest =test  (SgN  >paberi+test !22_S	et	f	\N
151730	aktsia	aktsia =aktsia  (SgN  >aktsia !01_S	et	f	\N
151731	aktsia	aktsia =aktsia  (SgG  >aktsia !01_S	et	f	\N
151748	investments	?investments =investments  (SgN  >investments !22_S	et	f	\N
151786	registreerija	registreerija =registreerija  (SgN  >registreerija !01_S	et	f	\N
151787	registreerija	"registreerija %registreeri  )JA_vS  <registreerima ;28_V	et	f	\N
151788	registreerija	registreerija =registreerija  (SgG  >registreerija !01_S	et	f	\N
151793	isikuks	isikuks =isiku  (SgTr  >isik !02_S	et	f	\N
151794	isikuks	isikuks =uks  (SgN  >isik+uks !14_S	et	f	\N
151800	kantud	kantud =kan  (PtsPtIps  >kandma !34_V	et	f	\N
151801	kantud	kantud =kantu  (PlN  >kantu !01_S	et	f	\N
151802	kantud	"kantu %kan  )TU1_vS  <kandma ;34_V	et	f	\N
151803	kantud	kantud =kantud  (ID  >kantud !41_A	et	f	\N
151804	kantud	"kantud %kan  )TUD_vA  <kandma ;34_V	et	f	\N
151812	snd	### snd	et	f	\N
151821	helt	?helt =helt  (SgN  >helt !22_S	et	f	\N
151828	virhiinia	?virhiinia =virhiinia  (SgN  >virhiinia !01_S	et	f	\N
151829	virhiinia	?virhiinia =virhiinia  (SgG  >virhiinia !01_S	et	f	\N
151861	kehtiv	kehtiv =kehti  (PtsPrPs  >kehtima !27_V	et	f	\N
151862	kehtiv	kehtiv =kehtiv  (SgN  >kehtiv !02_A	et	f	\N
151863	kehtiv	"kehtiv %kehti  )V_vA  <kehtima ;27_V	et	f	\N
151865	kompanii	kompanii =kompanii  (SgN  >kompanii !26_S	et	f	\N
151866	kompanii	kompanii =kompanii  (SgG  >kompanii !26_S	et	f	\N
151870	po	### po	et	f	\N
151871	ostjat	ostjat =ostja  (SgP  >ostja !01_S	et	f	\N
151872	ostjat	"ostja %ost  )JA_vS  <ostma ;34_V	et	f	\N
151899	vastavuses	vastavuses =vastavuse  (SgIn  >vastavus !11_S	et	f	\N
151900	vastavuses	"vastavus %vasta  )VUS_aS  <vastama ;29_V	et	f	\N
151901	vastavuses	"vastavus %vastava  )US_aS  <vastav ;02_A	et	f	\N
151907	investmente	?investmente =investmente  (PlP  >investment !22_S	et	f	\N
151918	tõestajale	tõestajale =tõestaja  (SgAll  >tõestaja !01_S	et	f	\N
151919	tõestajale	"tõestaja %tõesta  )JA_vS  <tõestama ;27_V	et	f	\N
151945	hüppanud	?hüppanud =hüppanu  (PlN  >hüppanu !01_S	et	f	\N
151946	hüppanud	?hüppanud =hüppanu  (IndPrSg2  >hüppanuma !27_V	et	f	\N
151947	hüppanud	?hüppanud =hüppanud  (ID  >hüppanud !41_A	et	f	\N
151970	talvise	talvise =talvise  (SgG  >talvine !10_A	et	f	\N
151971	talvise	"talvine %talvi  )NE_aA  <talv ;22_S	et	f	\N
152000	suurhalli	suurhalli =halli  (SgG  >suur+hall !22_S	et	f	\N
152001	suurhalli	suurhalli =halli  (SgG  >suur+hall !22_AS	et	f	\N
152002	suurhalli	suurhalli =halli  (SgP  >suur+hall !22_S	et	f	\N
152003	suurhalli	suurhalli =halli  (SgP  >suur+hall !22_AS	et	f	\N
151615	rekomendatsiooni	?rekomendatsiooni =rekomendatsiooni  (SgG  >rekomendatsioon !22_S	et	f	\N
151616	rekomendatsiooni	?rekomendatsiooni =rekomendatsiooni  (SgP  >rekomendatsioon !22_S	et	f	\N
151617	rekomendatsiooni	?rekomendatsiooni =rekomendatsiooni  (SgAdt  >rekomendatsioon !22_S	et	f	\N
151618	rekomendatsiooni	?rekomendatsiooni =rekomendatsiooni  (IndPrPs_  >rekomendatsioonima !28_V	et	f	\N
151619	rekomendatsiooni	?rekomendatsiooni =rekomendatsiooni  (ImpPrSg2  >rekomendatsioonima !28_V	et	f	\N
151631	semjonova	?semjonova =semjonova  (SgN  >semjonova !16_S	et	f	\N
151632	semjonova	?semjonova =semjonova  (SgG  >semjonov !02_A	et	f	\N
151633	semjonova	?semjonova =semjonova  (SgG  >semjonova !16_S	et	f	\N
151634	väljaantud	väljaantud =an  (PtsPtIps  >välja+_andma !34_V	et	f	\N
151635	väljaantud	väljaantud =antu  (PlN  >välja+antu !01_S	et	f	\N
151645	company	### company	et	f	\N
151667	islands	?islands =islands  (SgN  >islands !22_S	et	f	\N
151679	omandusele	omandusele =omanduse  (SgAll  >omandus !11_S	et	f	\N
151680	omandusele	"omandus %omanda  )US_vS  <omandama ;27_V	et	f	\N
151681	1938a	### 1938a	et	f	\N
151682	väljastatud	väljastatud =väljasta  (PtsPtIps  >väljastama !27_V	et	f	\N
151683	väljastatud	väljastatud =väljastatu  (PlN  >väljastatu !01_S	et	f	\N
151684	väljastatud	"väljastatu %väljasta  )TU1_vS  <väljastama ;27_V	et	f	\N
151686	väljastatud	väljastatud =väljastatud  (ID  >väljastatud !41_A	et	f	\N
151687	väljastatud	"väljastatud %väljasta  )TUD_vA  <väljastama ;27_V	et	f	\N
151688	väljastatud	väljastatud =atu  (PlN  >väljast+att !22_S	et	f	\N
151695	investment	?investment =investment  (SgN  >investment !22_S	et	f	\N
151697	virgihi	?virgihi =virgihi  (SgN  >virgihi !01_S	et	f	\N
151698	virgihi	?virgihi =virgihi  (SgG  >virgihi !01_S	et	f	\N
151701	tegeleva	tegeleva =tegeleva  (SgG  >tegelev !02_A	et	f	\N
151702	tegeleva	"tegelev %tegele  )V_vA  <tegelema ;27_V	et	f	\N
151703	tegeleva	"tegelev %tegele  )V_vA  <tegelema ;31_V	et	f	\N
151706	tegutsev	tegutsev =tegutse  (PtsPrPs  >tegutsema !27_V	et	f	\N
151707	tegutsev	tegutsev =tegutsev  (SgN  >tegutsev !02_A	et	f	\N
151708	tegutsev	"tegutsev %tegutse  )V_vA  <tegutsema ;27_V	et	f	\N
151711	kuuluvaid	kuuluvaid =kuuluva  (PlP  >kuuluv !02_A	et	f	\N
151712	kuuluvaid	"kuuluv %kuulu  )V_vA  <kuuluma ;27_V	et	f	\N
151722	emitent	?emitent =emitent  (SgN  >emitent !22_S	et	f	\N
151727	rubla	rubla =rubla  (SgN  >rubla !16~17_S	et	f	\N
151728	rubla	rubla =rubla  (SgG  >rubla !16~17_S	et	f	\N
151729	rubla	rubla =rubla  (SgP  >rubla !17_S	et	f	\N
151750	asutav	asutav =asu  (PtsPrIps  >asuma !27_V	et	f	\N
151752	asutav	asutav =asuta  (PtsPrPs  >asutama !27_V	et	f	\N
151754	asutav	asutav =asutav  (SgN  >asutav !02_A	et	f	\N
151755	asutav	"asutav %asu  )TAV_vAS  <asuma ;27_V	et	f	\N
151756	asutav	"asutav %asuta  )V_vA  <asutama ;27_V	et	f	\N
151765	pobox	### pobox	et	f	\N
151791	semjonovna	?semjonovna =semjonovna  (SgN  >semjonovna !16_S	et	f	\N
151792	semjonovna	?semjonovna =semjonovna  (SgG  >semjonovna !16_S	et	f	\N
151795	rigistri	?rigistri =rigistri  (SgN  >rigistri !01_S	et	f	\N
151796	rigistri	?rigistri =rigistri  (SgG  >rigistri !01_S	et	f	\N
151797	rigistri	?rigistri =rigistri  (SgG  >rigister !02_S	et	f	\N
151798	rigistri	?rigistri =rigistri  (IndPrPs_  >rigistrima !28_V	et	f	\N
151799	rigistri	?rigistri =rigistri  (ImpPrSg2  >rigistrima !28_V	et	f	\N
151808	08041938a	### 08041938a	et	f	\N
151825	ksimuste	?ksimuste =ksimus  (PlG  >ksimus !09_S	et	f	\N
151841	phikirjaga	?phikirjaga =phikirja  (SgKom  >phikirjas !02_A	et	f	\N
151842	phikirjaga	?phikirjaga =phikirja  (SgKom  >phikirja !16_S	et	f	\N
151848	müügi	müügi =müügi  (SgG  >müük !22_S	et	f	\N
151849	müügi	müügi =müü  (SgN^  >müü !26_S	et	f	\N
151850	müügi	müügi =müü  (SgG^  >müü !26_S	et	f	\N
151851	müügi	müügi =müü  (IndPrPs_^  >müüma !38_V	et	f	\N
151852	müügi	müügi =müü  (ImpPrSg2^  >müüma !38_V	et	f	\N
151853	teostatud	teostatud =teosta  (PtsPtIps  >teostama !27_V	et	f	\N
151854	teostatud	teostatud =teostatu  (PlN  >teostatu !01_S	et	f	\N
151855	teostatud	"teostatu %teosta  )TU1_vS  <teostama ;27_V	et	f	\N
151856	teostatud	teostatud =teostatud  (ID  >teostatud !41_A	et	f	\N
151857	teostatud	"teostatud %teosta  )TUD_vA  <teostama ;27_V	et	f	\N
151864	kosskõlas	?kosskõlas =kosskõla  (SgIn  >kosskõla !01_S	et	f	\N
151881	punktides	punktides =punkti  (PlIn  >punkt !22_S	et	f	\N
151882	punktides	punktides =punkti  (Ger  >punktima !28_V	et	f	\N
151883	investmens	?investmens =investmens  (SgN  >investmens !22_S	et	f	\N
151887	vf	### vf	et	f	\N
151890	fillmahni	?fillmahni =fillmahni  (SgN  >fillmahni !01_S	et	f	\N
151891	fillmahni	?fillmahni =fillmahni  (SgG  >fillmahni !01_S	et	f	\N
151892	fillmahni	?fillmahni =fillmahni  (SgG  >fillmahn !22_S	et	f	\N
151893	fillmahni	?fillmahni =fillmahni  (SgP  >fillmahn !22_S	et	f	\N
151894	fillmahni	?fillmahni =fillmahni  (SgAdt  >fillmahn !22_S	et	f	\N
151895	fillmahni	?fillmahni =fillmahni  (IndPrPs_  >fillmahnima !28_V	et	f	\N
151896	fillmahni	?fillmahni =fillmahni  (ImpPrSg2  >fillmahnima !28_V	et	f	\N
151897	britannia	?britannia =britannia  (SgN  >britannia !01_S	et	f	\N
151630	popova	?popova =ova  (SgP  >pop+ova !17_S	et	f	\N
151646	rollinz	### rollinz	et	f	\N
151664	british	?british =british  (SgN  >british !22_S	et	f	\N
151669	põhikirja	põhikirja =kirja  (SgG  >põhi+kiri !24_S	et	f	\N
151670	põhikirja	põhikirja =kirja  (SgP  >põhi+kiri !24_S	et	f	\N
151671	põhikirja	põhikirja =kirja  (SgAdt  >põhi+kiri !24_S	et	f	\N
151700	korporatiiv	?korporatiiv =korporatiiv  (SgN  >korporatiiv !22_S	et	f	\N
151724	10302161a	### 10302161a	et	f	\N
151725	nominaal	?nominaal =nominaa  (SgAd  >nominaa !26_S	et	f	\N
151726	nominaal	?nominaal =nominaal  (SgN  >nominaal !22_S	et	f	\N
151737	felmanni	?felmanni =felmanni  (SgN  >felmanni !01_S	et	f	\N
151738	felmanni	?felmanni =felmanni  (SgG  >felmanni !01_S	et	f	\N
151739	felmanni	?felmanni =felmanni  (SgG  >felmann !22_S	et	f	\N
151740	felmanni	?felmanni =felmanni  (SgP  >felmann !22_S	et	f	\N
151741	felmanni	?felmanni =felmanni  (SgAdt  >felmann !22_S	et	f	\N
151742	felmanni	?felmanni =felmanni  (IndPrPs_  >felmannima !28_V	et	f	\N
151743	felmanni	?felmanni =felmanni  (ImpPrSg2  >felmannima !28_V	et	f	\N
151744	kompania	?kompania =kompania  (SgN  >kompania !01_S	et	f	\N
151745	kompania	?kompania =kompania  (SgG  >kompania !01_S	et	f	\N
151746	kompania	?kompania =pania  (SgN  >kom+pania !01_S	et	f	\N
151747	kompania	?kompania =pania  (SgG  >kom+pania !01_S	et	f	\N
151749	realiseeruv	realiseeruv =realiseeru  (PtsPrPs  >realiseeruma !27_V	et	f	\N
151751	realiseeruv	realiseeruv =realiseeruv  (SgN  >realiseeruv !02_A	et	f	\N
151753	realiseeruv	"realiseeruv %realiseeru  )V_vA  <realiseeruma ;27_V	et	f	\N
151764	virgiinisaarte	?virgiinisaarte =virgiinisaarte  (PlP  >virgiinisaart !22_S	et	f	\N
151773	suursaatkonnas	suursaatkonnas =konna  (SgIn  >suur+saat+konn !22_S	et	f	\N
151774	suursaatkonnas	suursaatkonnas =saatkonna  (SgIn  >suur+saatkond !22_S	et	f	\N
151782	kommertskompanii	kommertskompanii =kompanii  (SgN  >kommerts+kompanii !26_S	et	f	\N
151783	kommertskompanii	kommertskompanii =kompanii  (SgG  >kommerts+kompanii !26_S	et	f	\N
151805	teiseltpoolt	?teiseltpoolt =teiseltpoo  (SgAbl  >teiseltpoo !26_S	et	f	\N
151806	teiseltpoolt	?teiseltpoolt =poo  (SgAbl  >teiselt+poo !26_S	et	f	\N
151807	teiseltpoolt	?teiseltpoolt =eltpoo  (SgAbl  >teis+eltpoo !26_S	et	f	\N
151845	ostu	ostu =ostu  (SgG  >ost !22_S	et	f	\N
151846	ostu	ostu =ostu  (SgP  >ost !22_S	et	f	\N
151847	ostu	ostu =ostu  (SgAdt  >ost !22_S	et	f	\N
151859	purima	?purima =puri  (Sup  >purima !27_V	et	f	\N
151860	purima	?purima =purima  (SgG  >purim !02_A	et	f	\N
151867	teostav	teostav =teosta  (PtsPrPs  >teostama !27_V	et	f	\N
151868	teostav	teostav =teostav  (SgN  >teostav !02_A	et	f	\N
151869	teostav	"teostav %teosta  )V_vA  <teostama ;27_V	et	f	\N
151886	britisch	?britisch =britisch  (SgN  >britisch !22_S	et	f	\N
151888	tallin	?tallin =talli  (IndPrSg1  >tallima !28_V	et	f	\N
151889	tallin	?tallin =tallin  (SgN  >tallin !02_S	et	f	\N
151928	müügi-ostu	müügi-ostu =ostu  (SgG  >müügi-ost !22_S	et	f	\N
151929	müügi-ostu	müügi-ostu =ostu  (SgP  >müügi-ost !22_S	et	f	\N
151930	müügi-ostu	müügi-ostu =ostu  (SgAdt  >müügi-ost !22_S	et	f	\N
151938	kalendritalve	kalendritalve =talve  (SgG  >kalendri+talv !22_S	et	f	\N
151939	kalendritalve	kalendritalve =talve  (SgG  >kalendri+tali !24_S	et	f	\N
151940	kalendritalve	kalendritalve =talve  (SgP  >kalendri+talv !22_S	et	f	\N
151941	kalendritalve	kalendritalve =talve  (SgP  >kalendri+tali !24_S	et	f	\N
151942	kalendritalve	kalendritalve =talve  (SgAdt  >kalendri+talv !22_S	et	f	\N
151943	kalendritalve	kalendritalve =talve  (SgAdt  >kalendri+tali !24_S	et	f	\N
151944	kalendritalve	kalendritalve =talve  (PlP  >kalendri+talv !22_S	et	f	\N
151948	õnnest	õnnest =õnne  (SgEl  >õnn !22_S	et	f	\N
151949	õnnest	õnnest =õnne  (PlEl  >õnn !22_S	et	f	\N
151950	õnnest	õnnest =õnnes  (SgP  >õnnene !10_A	et	f	\N
151951	õnnest	"õnnene %õnne  )NE_aA  <õnn ;22_S	et	f	\N
151954	puisates	?puisates =puisa  (Ger  >puisama !29_V	et	f	\N
151955	puisates	?puisates =puisate  (PlIn  >puisatt !22_S	et	f	\N
151956	hingasid	hingasid =hinga  (IndIpfSg2  >hingama !29_V	et	f	\N
151958	hingasid	hingasid =hinga  (IndIpfPl3  >hingama !29_V	et	f	\N
151968	pakasest	pakasest =pakase  (SgEl  >pakane !10_S	et	f	\N
151969	pakasest	pakasest =pakases  (SgP  >pakasene !12_A	et	f	\N
151977	kiiruse	kiiruse =kiiruse  (SgG  >kiirus !11~09_S	et	f	\N
151979	kiiruse	"kiirus %kiire  )US_aS  <kiire ;01_A	et	f	\N
151985	lärmata	lärmata =lärma  (Inf  >lärmama !29_V	et	f	\N
151986	lärmata	lärmata =lärma  (IndPrIps_  >lärmama !29_V	et	f	\N
151990	armastajaid	armastajaid =armastaja  (PlP  >armastaja !01_S	et	f	\N
151991	armastajaid	"armastaja %armasta  )JA_vS  <armastama ;27_V	et	f	\N
152008	raskemuusika	raskemuusika =muusika  (SgN  >raske+muusika !01_S	et	f	\N
152009	raskemuusika	raskemuusika =muusika  (SgG  >raske+muusika !01_S	et	f	\N
152010	bändi	bändi =bändi  (SgN  >bändi !16_S	et	f	\N
152011	bändi	bändi =bändi  (SgG  >bändi !16_S	et	f	\N
152012	bändi	bändi =bändi  (SgG  >bänd !22_S	et	f	\N
152013	bändi	bändi =bändi  (SgP  >bänd !22_S	et	f	\N
152014	bändi	bändi =bändi  (SgAdt  >bänd !22_S	et	f	\N
152018	külastasid	külastasid =külasta  (IndIpfSg2  >külastama !27_V	et	f	\N
151659	virginia	?virginia =virginia  (SgN  >virginia !01_S	et	f	\N
151660	virginia	?virginia =virginia  (SgG  >virginia !01_S	et	f	\N
151668	purim	?purim =purim  (SgN  >purim !02_A	et	f	\N
151677	järgnevas	järgnevas =järgneva  (SgIn  >järgnev !02_A	et	f	\N
151678	järgnevas	"järgnev %järgne  )V_vA  <järgnema ;27_V	et	f	\N
151699	2007a	### 2007a	et	f	\N
151723	sovstrah	?sovstrah =sovstrah  (ID  >sovstrah !41_I	et	f	\N
151735	saatkonnaga	saatkonnaga =saatkonna  (SgKom  >saatkond !22_S	et	f	\N
151736	saatkonnaga	saatkonnaga =konna  (SgKom  >saat+konn !22_S	et	f	\N
151775	faelhmanni	?faelhmanni =faelhmanni  (SgN  >faelhmanni !01_S	et	f	\N
151776	faelhmanni	?faelhmanni =faelhmanni  (SgG  >faelhmanni !01_S	et	f	\N
151777	faelhmanni	?faelhmanni =faelhmanni  (SgG  >faelhmann !22_S	et	f	\N
151778	faelhmanni	?faelhmanni =faelhmanni  (SgP  >faelhmann !22_S	et	f	\N
151779	faelhmanni	?faelhmanni =faelhmanni  (SgAdt  >faelhmann !22_S	et	f	\N
151780	faelhmanni	?faelhmanni =faelhmanni  (IndPrPs_  >faelhmannima !28_V	et	f	\N
151781	faelhmanni	?faelhmanni =faelhmanni  (ImpPrSg2  >faelhmannima !28_V	et	f	\N
151784	reg	### reg	et	f	\N
151789	omandiõigusega	omandiõigusega =õiguse  (SgKom  >omandi+õigus !11~09_S	et	f	\N
151790	omandiõigusega	"omandi+õigus %õige  )US_aS  <omandi+õige ;01_A	et	f	\N
151809	rollings	?rollings =rollings  (SgN  >rollings !22_S	et	f	\N
151810	rollings	?rollings =ings  (SgN  >roll+ings !22_S	et	f	\N
151811	ostu-mgi	### ostu-mgi	et	f	\N
151822	koosklas	?koosklas =kooskla  (SgIn  >kooskla !01_S	et	f	\N
151823	koosklas	?koosklas =kooskla  (IndIpfSg3  >koosklama !29_V	et	f	\N
151824	koosklas	?koosklas =koosklas  (SgN  >koosklas !07_S	et	f	\N
151826	korporatiivse	?korporatiivse =korporatiivse  (SgG  >korporatiivne !02_A	et	f	\N
151827	korporatiivse	?korporatiivse =korporatiivse  (PlP  >korporatiivs !22_S	et	f	\N
151873	purimaa	?purimaa =purimaa  (SgN  >purimaa !26_S	et	f	\N
151874	purimaa	?purimaa =purimaa  (SgG  >purimaa !26_S	et	f	\N
151875	sõlmitud	sõlmitud =sõlmi  (PtsPtIps  >sõlmima !28_V	et	f	\N
151876	sõlmitud	sõlmitud =sõlmitu  (PlN  >sõlmitu !01_AS	et	f	\N
151877	sõlmitud	"sõlmitu %sõlmi  )TU1_vS  <sõlmima ;28_V	et	f	\N
151878	sõlmitud	"sõlmitu %sõlmi  )TU2_kA  <sõlm ;22_S	et	f	\N
151879	sõlmitud	sõlmitud =sõlmitud  (ID  >sõlmitud !41_A	et	f	\N
151880	sõlmitud	"sõlmitud %sõlmi  )TUD_vA  <sõlmima ;28_V	et	f	\N
151884	britti	britti =britti  (SgP  >britt !22_S	et	f	\N
151885	britti	britti =britti  (SgAdt  >britt !22_S	et	f	\N
151908	briiti	?briiti =briiti  (ID  >briiti !41_D	et	f	\N
151909	briiti	?briiti =briiti  (SgP  >briit !22_S	et	f	\N
151910	briiti	?briiti =briiti  (SgAdt  >briit !22_S	et	f	\N
151920	valdustesse	valdustesse =valdus  (PlIll  >valdus !11~09_S	et	f	\N
151921	valdustesse	valdustesse =us  (PlIll  >vald+uks !14_S	et	f	\N
151925	sovfraht	?sovfraht =sovfraht  (SgN  >sovfraht !22_S	et	f	\N
151927	1-03-02161-a	### 1-03-02161-a	et	f	\N
151952	öistel	öistel =öis  (PlAd  >öine !10_A	et	f	\N
151953	öistel	"öine %öi  )NE_aA  <öö ;26_S	et	f	\N
151963	kaugetest	kaugetest =kauge  (PlEl  >kauge !01_A	et	f	\N
151964	kaugetest	kaugetest =test  (SgN  >kauge+test !22_S	et	f	\N
151965	kaugetest	kaugetest =e  (PlEl  >kaug+esi !15_S	et	f	\N
151976	vaikida	vaikida =vaiki  (Inf  >vaikima !27_V	et	f	\N
151978	vaikida	vaikida =ida  (SgN  >vaik+ida !17_S	et	f	\N
151980	vaikida	vaikida =ida  (SgG  >vaik+ida !17_S	et	f	\N
151981	vaikida	vaikida =ida  (SgP  >vaik+ida !17_S	et	f	\N
151987	asuv	asuv =asu  (PtsPrPs  >asuma !27_V	et	f	\N
151988	asuv	asuv =asuv  (SgN  >asuv !02_A	et	f	\N
151989	asuv	"asuv %asu  )V_vA  <asuma ;27_V	et	f	\N
151992	uisutamise	uisutamise =uisutamise  (SgG  >uisutamine !12_S	et	f	\N
151993	uisutamise	"uisutamine %uisuta  )MINE_vS  <uisutama ;27_V	et	f	\N
152006	kaliforinia	?kaliforinia =kaliforinia  (SgN  >kaliforinia !01_S	et	f	\N
152007	kaliforinia	?kaliforinia =kaliforinia  (SgG  >kaliforinia !01_S	et	f	\N
152022	turnee	turnee =turnee  (SgN  >turnee !26_S	et	f	\N
152023	turnee	turnee =turnee  (SgG  >turnee !26_S	et	f	\N
152026	dublinist	?dublinist =dublini  (SgEl  >dublin !02_S	et	f	\N
152027	dublinist	?dublinist =dublinis  (SgP  >dublinis !11_S	et	f	\N
152028	dublinist	?dublinist =dublinist  (SgN  >dublinist !22_S	et	f	\N
152029	plaadi	plaadi =plaadi  (SgG  >plaat !22_S	et	f	\N
152030	plaadi	plaadi =plaadi  (IndPrPs_  >plaatima !28_V	et	f	\N
152032	plaadi	plaadi =plaadi  (ImpPrSg2  >plaatima !28_V	et	f	\N
152040	glaskow	### glaskow	et	f	\N
152045	milaano	?milaano =milaano  (SgN  >milaano !16_S	et	f	\N
152046	milaano	?milaano =milaano  (SgG  >milaano !16_S	et	f	\N
152053	korni	korni =korni  (IndPrPs_  >kornima !28_V	et	f	\N
152054	korni	korni =korni  (ImpPrSg2  >kornima !28_V	et	f	\N
152062	ümbritsenud	ümbritsenud =ümbritse  (PtsPtPs  >ümbritsema !27_V	et	f	\N
152063	ümbritsenud	ümbritsenud =ümbritsenu  (PlN  >ümbritsenu !01_S	et	f	\N
152065	ümbritsenud	"ümbritsenu %ümbritse  )NU_vS  <ümbritsema ;27_V	et	f	\N
152067	ümbritsenud	ümbritsenud =ümbritsenud  (ID  >ümbritsenud !41_A	et	f	\N
152068	ümbritsenud	"ümbritsenud %ümbritse  )NUD_vA  <ümbritsema ;27_V	et	f	\N
151769	tegelev	"tegelev %tegele  )V_vA  <tegelema ;31_V	et	f	\N
151770	sõlmisid	sõlmisid =sõlmi  (PlP  >sõlm !22_S	et	f	\N
151771	sõlmisid	sõlmisid =sõlmi  (IndIpfSg2  >sõlmima !28_V	et	f	\N
151772	sõlmisid	sõlmisid =sõlmi  (IndIpfPl3  >sõlmima !28_V	et	f	\N
151785	24112000a	### 24112000a	et	f	\N
151813	fderatsiooni	?fderatsiooni =fderatsioo  (SgTer  >fderatsioo !26_S	et	f	\N
151814	fderatsiooni	?fderatsiooni =fderatsiooni  (SgN  >fderatsiooni !16_S	et	f	\N
151815	fderatsiooni	?fderatsiooni =fderatsiooni  (SgG  >fderatsiooni !16_S	et	f	\N
151816	fderatsiooni	?fderatsiooni =fderatsiooni  (SgG  >fderatsioon !22_S	et	f	\N
151817	fderatsiooni	?fderatsiooni =fderatsiooni  (SgP  >fderatsioon !22_S	et	f	\N
151818	fderatsiooni	?fderatsiooni =fderatsiooni  (SgAdt  >fderatsioon !22_S	et	f	\N
151819	fderatsiooni	?fderatsiooni =fderatsiooni  (IndPrPs_  >fderatsioonima !28_V	et	f	\N
151820	fderatsiooni	?fderatsiooni =fderatsiooni  (ImpPrSg2  >fderatsioonima !28_V	et	f	\N
151830	virgiini	?virgiini =virgii  (SgTer  >virgii !26_S	et	f	\N
151831	virgiini	?virgiini =virgiini  (SgN  >virgiini !16_S	et	f	\N
151832	virgiini	?virgiini =virgiini  (SgG  >virgiini !16_S	et	f	\N
151833	virgiini	?virgiini =virgiini  (SgG  >virgiin !22_S	et	f	\N
151834	virgiini	?virgiini =virgiini  (SgP  >virgiin !22_S	et	f	\N
151835	virgiini	?virgiini =virgiini  (SgAdt  >virgiin !22_S	et	f	\N
151836	virgiini	?virgiini =virgiini  (IndPrPs_  >virgiinima !28_V	et	f	\N
151837	virgiini	?virgiini =virgiini  (ImpPrSg2  >virgiinima !28_V	et	f	\N
151838	tegutsevat	tegutsevat =tegutse  (KvtPrPs  >tegutsema !27_V	et	f	\N
151839	tegutsevat	tegutsevat =tegutseva  (SgP  >tegutsev !02_A	et	f	\N
151840	tegutsevat	"tegutsev %tegutse  )V_vA  <tegutsema ;27_V	et	f	\N
151843	slmisid	?slmisid =slmisi  (PlN  >slmisi !17_S	et	f	\N
151844	slmisid	?slmisid =slmisi  (IndPrSg2  >slmisima !27_V	et	f	\N
151858	virgiinite	?virgiinite =virgiini  (IndPrPl2  >virgiinima !28_V	et	f	\N
151902	korporatiivküsimuste	korporatiivküsimuste =muste  (PlP  >korporatiiv+küsi+must !22_AS	et	f	\N
151903	korporatiivküsimuste	korporatiivküsimuste =küsimus  (PlG  >korporatiiv+küsimus !11_S	et	f	\N
151913	esindajana	esindajana =esindaja  (SgEs  >esindaja !01_S	et	f	\N
151914	esindajana	"esindaja %esinda  )JA_vS  <esindama ;27_V	et	f	\N
151922	omalt	omalt =oma  (SgAbl  >oma !17_A	et	f	\N
151923	omalt	omalt =omalt  (ID  >omalt !41_D	et	f	\N
151924	omalt	"omalt %oma  )LT_mD  <oma ;17_A	et	f	\N
151926	väljalase	?väljalase =väljalase  (SgG  >väljalane !12_S	et	f	\N
151934	lumine	lumine =lumine  (SgN  >lumine !10_A	et	f	\N
151935	lumine	"lumine %lumi  )NE_aA  <lumi ;20_S	et	f	\N
151966	valgest	valgest =valge  (SgEl  >valge !01_AS	et	f	\N
151967	valgest	valgest =valge  (PlEl  >valk !22_S	et	f	\N
151982	mõnu	mõnu =mõnu  (SgN  >mõnu !17_S	et	f	\N
151983	mõnu	mõnu =mõnu  (SgG  >mõnu !17_S	et	f	\N
151984	mõnu	mõnu =mõnu  (SgP  >mõnu !17_S	et	f	\N
151994	värisesid	värisesid =värise  (IndIpfSg2  >värisema !27_V	et	f	\N
151995	värisesid	värisesid =värise  (IndIpfPl3  >värisema !27_V	et	f	\N
152015	korn-i	korn-i =korn  (SgG  >korn !xx_Q	et	f	\N
152016	korn-i	korn-i =korn  (SgP  >korn !xx_Q	et	f	\N
152017	korn-i	korn-i =korn  (SgAdt  >korn !xx_Q	et	f	\N
152020	bitch	?bitch =bitch  (SgN  >bitch !22_S	et	f	\N
152031	untitled	?untitled =untitle  (IndPrSg2  >untitlema !27_V	et	f	\N
152042	birmingham	?birmingham =birmingham  (SgN  >birmingham !02_A	et	f	\N
152044	sankt-peterburg	?sankt-peterburg =peterburg  (SgN  >sankt-peterburg !22_S	et	f	\N
152080	jeaffer	?jeaffer =jeaffer  (SgN  >jeaffer !02_S	et	f	\N
152083	rob	### rob	et	f	\N
152085	oter	?oter =oter  (SgN  >oter !02_S	et	f	\N
152088	pausi	pausi =pausi  (SgG  >paus !22_S	et	f	\N
152089	pausi	pausi =pausi  (SgP  >paus !22_S	et	f	\N
152090	pausi	pausi =pausi  (SgAdt  >paus !22_S	et	f	\N
152094	instrumentaalpala	instrumentaalpala =pala  (SgN  >instrumentaal+pala !17_S	et	f	\N
152095	instrumentaalpala	instrumentaalpala =pala  (SgG  >instrumentaal+pala !17_S	et	f	\N
152096	instrumentaalpala	instrumentaalpala =pala  (SgP  >instrumentaal+pala !17_S	et	f	\N
152101	edukam	edukam =edukam  (SgN  >edukam !02_A	et	f	\N
152102	edukam	"edukam %eduka  )M_cA  <edukas ;02_A	et	f	\N
152134	tetsmann	?tetsmann =tetsmann  (SgN  >tetsmann !22_S	et	f	\N
152158	stirling	?stirling =stirling  (SgN  >stirling !02_S	et	f	\N
152168	sõidas	?sõidas =sõida  (SgIn  >sõida !16_S	et	f	\N
152169	sõidas	?sõidas =sõida  (IndIpfSg3  >sõidama !29_V	et	f	\N
152170	sõidas	?sõidas =sõidas  (SgN  >sõidas !07_S	et	f	\N
152189	gaeli	gaeli =gaeli  (SgG  >gael !22_S	et	f	\N
152190	gaeli	gaeli =gaeli  (SgP  >gael !22_S	et	f	\N
152191	gaeli	gaeli =gaeli  (SgAdt  >gael !22_S	et	f	\N
152196	trahvid	trahvid =trahvi  (PlN  >trahv !22_S	et	f	\N
152197	trahvid	trahvid =trahvi  (IndPrSg2  >trahvima !28_V	et	f	\N
152210	õeti	?õeti =õeti  (ID  >õeti !41_D	et	f	\N
152211	õeti	?õeti =õeti  (SgP  >õet !22_S	et	f	\N
152212	õeti	?õeti =õeti  (SgAdt  >õet !22_S	et	f	\N
152233	tooded	?tooded =toode  (IndPrSg2  >toodema !27_V	et	f	\N
152240	bmw	### bmw	et	f	\N
152247	progressivses	?progressivses =progressivse  (SgIn  >progressivne !02_A	et	f	\N
151898	britannia	?britannia =britannia  (SgG  >britannia !01_S	et	f	\N
151904	lepinguaine	lepinguaine =aine  (SgN  >lepingu+aine !06_S	et	f	\N
151905	lepinguaine	lepinguaine =aine  (SgG  >lepingu+aine !06_S	et	f	\N
151906	lepinguaine	lepinguaine =aine  (PlP  >lepingu+ain !22_S	et	f	\N
151911	registreerimisekoht	?registreerimisekoht =registreerimisekoht  (SgN  >registreerimisekoht !22_S	et	f	\N
151912	registreerimisekoht	?registreerimisekoht =ekoht  (SgN  >registreerimis+ekoht !22_S	et	f	\N
151915	volikirja	volikirja =kirja  (SgG  >voli+kiri !24_S	et	f	\N
151916	volikirja	volikirja =kirja  (SgP  >voli+kiri !24_S	et	f	\N
151917	volikirja	volikirja =kirja  (SgAdt  >voli+kiri !24_S	et	f	\N
151931	semjenova	?semjenova =semjenova  (SgN  >semjenova !16_S	et	f	\N
151932	semjenova	?semjenova =semjenova  (SgG  >semjenov !02_A	et	f	\N
151933	semjenova	?semjenova =semjenova  (SgG  >semjenova !16_S	et	f	\N
151936	tuligi	tuligi =tul  (IndIpfSg3^  >tulema !36_V	et	f	\N
151937	tuligi	tuligi =tuli  (SgN^  >tuli !20_S	et	f	\N
151957	soda	?soda =soda  (SgN  >soda !17_S	et	f	\N
151959	soda	?soda =soda  (SgG  >soda !17_S	et	f	\N
151960	soda	?soda =soda  (SgP  >soda !17_S	et	f	\N
151961	soda	?soda =soda  (IndPrPs_  >sodama !27_V	et	f	\N
151962	soda	?soda =soda  (ImpPrSg2  >sodama !27_V	et	f	\N
151972	värskele	?värskele =värske  (SgAll  >värske !01_AS	et	f	\N
151973	värskele	?värskele =värske  (PlAll  >värsk !22_S	et	f	\N
151974	värskele	?värskele =värskele  (IndPrPs_  >värskelema !27_V	et	f	\N
151975	värskele	?värskele =värskele  (ImpPrSg2  >värskelema !27_V	et	f	\N
151996	saku	?saku =saku  (SgN  >saku !16_S	et	f	\N
151997	saku	?saku =saku  (SgG  >saku !16_S	et	f	\N
151998	saku	?saku =saku  (IndPrPs_  >sakuma !27_V	et	f	\N
151999	saku	?saku =saku  (ImpPrSg2  >sakuma !27_V	et	f	\N
152033	toetuseks	toetuseks =toetuse  (SgTr  >toetus !11~09_S	et	f	\N
152034	toetuseks	"toetus %toeta  )US_vS  <toetama ;27_V	et	f	\N
152035	toetuseks	"toetus %toe  )TUS2_aS  <tugi ;21_S	et	f	\N
152039	korn	?korn =korn  (SgN  >korn !22_S	et	f	\N
152041	amsterdam	?amsterdam =amsterdam  (SgN  >amsterdam !02_A	et	f	\N
152049	kokkulepitud	kokkulepitud =lepi  (PtsPtIps  >kokku+_leppima !28_V	et	f	\N
152050	kokkulepitud	kokkulepitud =lepitu  (PlN  >kokku+lepitu !01_AS	et	f	\N
152051	kokkulepitud	"kokku+lepitu %lepi  )TU2_kA  <kokku+lepp ;22_S	et	f	\N
152052	kokkulepitud	"kokku+lepitu %lepi  )TU2_kA  <kokku+lepp ;22_SA	et	f	\N
152055	kamoflaazist	?kamoflaazist =kamoflaazi  (SgEl  >kamoflaazi !16_S	et	f	\N
152056	kamoflaazist	?kamoflaazist =kamoflaazis  (SgP  >kamoflaazis !09_S	et	f	\N
152070	juurdepääsu	juurdepääsu =pääsu  (SgN  >juurde+pääsu !16_S	et	f	\N
152071	juurdepääsu	juurdepääsu =pääsu  (SgG  >juurde+pääsu !16_S	et	f	\N
152072	juurdepääsu	juurdepääsu =pääsu  (SgG  >juurde+pääs !22_S	et	f	\N
152073	juurdepääsu	juurdepääsu =pääsu  (SgP  >juurde+pääs !22_S	et	f	\N
152074	juurdepääsu	juurdepääsu =pääsu  (SgAdt  >juurde+pääs !22_S	et	f	\N
152075	kitarrist	kitarrist =kitarri  (SgEl  >kitarr !22_S	et	f	\N
152076	kitarrist	kitarrist =kitarrist  (SgN  >kitarrist !22_S	et	f	\N
152086	silveria	?silveria =silveria  (SgN  >silveria !01_S	et	f	\N
152087	silveria	?silveria =silveria  (SgG  >silveria !01_S	et	f	\N
152103	metall-punk	?metall-punk =punk  (SgN  >metall-punk !22_S	et	f	\N
152110	plaati	plaati =plaati  (SgP  >plaat !22_S	et	f	\N
152111	plaati	plaati =plaati  (SgAdt  >plaat !22_S	et	f	\N
152117	järgiv	järgiv =järgi  (PtsPrPs  >järgima !27_V	et	f	\N
152118	järgiv	järgiv =järgiv  (SgN  >järgiv !02_A	et	f	\N
152119	järgiv	"järgiv %järgi  )V_vA  <järgima ;27_V	et	f	\N
152122	valvurimajakeses	valvurimajakeses =majakese  (SgIn  >valvuri+majake !12_S	et	f	\N
152123	valvurimajakeses	"valvuri+majake %maja  )KE_dS  <valvuri+maja ;17_S	et	f	\N
152124	valvurimajakeses	valvurimajakeses =majakese  (SgIn  >valvuri+majakene !12_S	et	f	\N
152125	valvurimajakeses	"valvuri+majakene %maja  )KENE_dS  <valvuri+maja ;17_S	et	f	\N
152126	jõululaati	jõululaati =laati  (SgP  >jõulu+laat !22_S	et	f	\N
152127	jõululaati	jõululaati =laati  (SgAdt  >jõulu+laat !22_S	et	f	\N
152141	jalge	jalge =jalge  (PlG  >jalg !22_S	et	f	\N
152144	jalge	jalge =jalge  (PlP  >jalg !22_S	et	f	\N
152152	edinburgh	### edinburgh	et	f	\N
152166	ajaluga	ajaluga =luga  (SgN  >aja+luga !18_S	et	f	\N
152167	ajaluga	ajaluga =luga  (SgP  >aja+luga !18_S	et	f	\N
152175	kandnud	kandnud =kand  (PtsPtPs  >kandma !34_V	et	f	\N
152176	kandnud	kandnud =kandnu  (PlN  >kandnu !01_S	et	f	\N
152177	kandnud	"kandnu %kand  )NU_vS  <kandma ;34_V	et	f	\N
152178	kandnud	kandnud =kandnud  (ID  >kandnud !41_A	et	f	\N
152179	kandnud	"kandnud %kand  )NUD_vA  <kandma ;34_V	et	f	\N
152180	suhkreta	?suhkreta =suhkre  (SgAb  >suhkre !06_S	et	f	\N
152181	suhkreta	?suhkreta =suhkre  (IndPrIps_  >suhkrema !27_V	et	f	\N
152182	suhkreta	?suhkreta =suhkreta  (IndPrPs_  >suhkretama !27_V	et	f	\N
152183	suhkreta	?suhkreta =suhkreta  (ImpPrSg2  >suhkretama !27_V	et	f	\N
152193	kummend	?kummend =kummend  (SgN  >kummend !02_S	et	f	\N
152198	püstool	?püstool =püstoo  (SgAd  >püstoo !26_S	et	f	\N
152199	püstool	?püstool =püstool  (SgN  >püstool !22_S	et	f	\N
152200	püstool	?püstool =ool  (SgN  >püst+ool !22_S	et	f	\N
152004	suurhalli	suurhalli =halli  (SgAdt  >suur+hall !22_S	et	f	\N
152005	suurhalli	suurhalli =halli  (SgAdt  >suur+hall !22_AS	et	f	\N
152036	nimetu	nimetu =nimetu  (SgN  >nimetu !01_A	et	f	\N
152037	nimetu	"nimetu %nime  )TU2_kA  <nimi ;20_S	et	f	\N
152038	nimetu	nimetu =nimetu  (SgG  >nimetu !01_A	et	f	\N
152047	lissabon	?lissabon =lissabon  (SgN  >lissabon !19_S	et	f	\N
152057	metsikult	metsikult =metsiku  (SgAbl  >metsik !02_AS	et	f	\N
152058	metsikult	metsikult =metsikult  (ID  >metsikult !41_D	et	f	\N
152059	metsikult	"metsikult %metsiku  )LT_mD  <metsik ;02_AS	et	f	\N
152084	patterson	?patterson =patterson  (SgN  >patterson !19_S	et	f	\N
152097	mirror	?mirror =mirror  (SgN  >mirror !02_S	et	f	\N
152113	kuuel	kuuel =kuue  (SgAd  >kuus !14_N	et	f	\N
152114	kuuel	kuuel =kuue  (SgAd  >kuub !22_S	et	f	\N
152120	kuuluvas	kuuluvas =kuuluva  (SgIn  >kuuluv !02_A	et	f	\N
152121	kuuluvas	"kuuluv %kuulu  )V_vA  <kuuluma ;27_V	et	f	\N
152130	ehitusfirma	ehitusfirma =firma  (SgN  >ehitus+firma !16_S	et	f	\N
152131	ehitusfirma	ehitusfirma =firma  (SgG  >ehitus+firma !16_S	et	f	\N
152145	suukrata	?suukrata =suukra  (SgAb  >suukra !01_S	et	f	\N
152146	suukrata	?suukrata =suukra  (Inf  >suukrama !29_V	et	f	\N
152147	suukrata	?suukrata =suukra  (IndPrIps_  >suukrama !29_V	et	f	\N
152148	suukrata	?suukrata =suukrata  (IndPrPs_  >suukratama !27_V	et	f	\N
152149	suukrata	?suukrata =suukrata  (ImpPrSg2  >suukratama !27_V	et	f	\N
152150	suukrata	?suukrata =krata  (SgN  >suu+krata !16_S	et	f	\N
152151	suukrata	?suukrata =krata  (SgG  >suu+krata !16_S	et	f	\N
152155	edinburghis	?edinburghis =edinburghi  (IndIpfSg3  >edinburghima !28_V	et	f	\N
152156	edinburghis	?edinburghis =edinburghis  (SgN  >edinburghis !09_S	et	f	\N
152159	forthi	?forthi =forthi  (SgN  >forthi !01_S	et	f	\N
152160	forthi	?forthi =forthi  (SgG  >forthi !01_S	et	f	\N
152161	forthi	?forthi =forthi  (SgG  >forth !22_S	et	f	\N
152162	forthi	?forthi =forthi  (SgP  >forth !22_S	et	f	\N
152163	forthi	?forthi =forthi  (SgAdt  >forth !22_S	et	f	\N
152164	forthi	?forthi =forthi  (IndPrPs_  >forthima !28_V	et	f	\N
152165	forthi	?forthi =forthi  (ImpPrSg2  >forthima !28_V	et	f	\N
152171	kiievi	?kiievi =kiievi  (ID  >kiievi !41_D	et	f	\N
152172	kiievi	?kiievi =kiievi  (SgG  >kiiev !02_S	et	f	\N
152173	kiievi	?kiievi =kiievi  (IndPrPs_  >kiievima !28_V	et	f	\N
152174	kiievi	?kiievi =kiievi  (ImpPrSg2  >kiievima !28_V	et	f	\N
152203	kasvaks	kasvaks =kasva  (KndPrPs  >kasvama !28_V	et	f	\N
152204	kasvaks	kasvaks =vaks  (SgN  >kas+vaks !22_S	et	f	\N
152239	volkswagen	?volkswagen =volkswagen  (SgN  >volkswagen !19_S	et	f	\N
152249	kasutajad	kasutajad =kasutaja  (PlN  >kasutaja !01_S	et	f	\N
152250	kasutajad	"kasutaja %kasuta  )JA_vS  <kasutama ;27_V	et	f	\N
152259	kapitalist	kapitalist =kapitali  (SgEl  >kapital !19_S	et	f	\N
152260	kapitalist	kapitalist =kapitalis  (SgP  >kapitaline !12_A	et	f	\N
152261	kapitalist	"kapitaline %kapitali  )NE_aA  <kapital ;19_S	et	f	\N
152262	kapitalist	kapitalist =kapitalist  (SgN  >kapitalist !22_S	et	f	\N
152263	kapitalist	kapitalist =tali  (SgEl  >kapi+tali !17_S	et	f	\N
152264	kapitalist	kapitalist =talis  (SgP  >kapi+taline !10_A	et	f	\N
152265	kapitalist	"kapi+taline %tali  )NE_aA  <kapi+tali ;24_S	et	f	\N
152266	kapitalist	"kapi+taline %tali  )NE_aA  <kapi+tali ;17_S	et	f	\N
152276	seadest	seadest =seade  (SgEl  >seade !06_S	et	f	\N
152277	seadest	seadest =seade  (PlEl  >sead !22_S	et	f	\N
152278	seadest	seadest =seades  (SgP  >seadene !10_A	et	f	\N
152279	seadest	"seadene %seade  )NE_aA  <seade ;06_S	et	f	\N
152296	toite	toite =toite  (SgG  >toide !06_S	et	f	\N
152297	toite	toite =toite  (PlP  >toit !22_S	et	f	\N
152300	maole	maole =mao  (SgAll  >madu !18_S	et	f	\N
152301	maole	maole =mao  (SgAll  >magu !18_S	et	f	\N
152308	töötus	töötus =töötu  (SgIn  >töötu !01_AS	et	f	\N
152309	töötus	"töötu %töö  )TU2_kA  <töö ;26_S	et	f	\N
152310	töötus	töötus =töötus  (SgN  >töötus !11~09_S	et	f	\N
152311	töötus	"töötus %tööta  )US_vS  <töötama ;27_V	et	f	\N
152312	töötus	"töötus %töö  )TUS2_aS  <töö ;26_S	et	f	\N
152317	kiirus	kiirus =kiiru  (SgIn  >kiird !22_S	et	f	\N
152318	kiirus	kiirus =kiiru  (SgIn  >kiir !22_S	et	f	\N
152319	kiirus	kiirus =kiirus  (SgN  >kiirus !11~09_S	et	f	\N
152320	kiirus	"kiirus %kiire  )US_aS  <kiire ;01_A	et	f	\N
152321	meelelahutusi	meelelahutusi =lahutusi  (PlP  >meele+lahutus !11_S	et	f	\N
152322	meelelahutusi	"meele+lahutus %lahu  )TUS2_aS  <meele+lahk ;22_S	et	f	\N
152326	koostööpartneritest	koostööpartneritest =test  (SgN  >koos+töö+partneri+test !22_S	et	f	\N
152327	koostööpartneritest	koostööpartneritest =partneri  (PlEl  >koos+töö+partner !02_S	et	f	\N
152339	tervislikku	tervislikku =tervislikku  (SgP  >tervislik !25_A	et	f	\N
152340	tervislikku	tervislikku =tervislikku  (SgAdt  >tervislik !25_A	et	f	\N
152341	tarbivad	tarbivad =tarbi  (IndPrPl3  >tarbima !27_V	et	f	\N
152342	tarbivad	tarbivad =tarbiva  (PlN  >tarbiv !02_A	et	f	\N
152343	tarbivad	"tarbiv %tarbi  )V_vA  <tarbima ;27_V	et	f	\N
152364	tavaliset	### tavaliset	et	f	\N
152460	protsenti	protsenti =protsenti  (SgP  >protsent !22_S	et	f	\N
152019	külastasid	külastasid =külasta  (IndIpfPl3  >külastama !27_V	et	f	\N
152021	got	### got	et	f	\N
152024	turnee	turnee =turnee  (SgN  >turnee !26_S	et	f	\N
152025	turnee	turnee =turnee  (SgG  >turnee !26_S	et	f	\N
152043	kopenhagen	?kopenhagen =kopenhagen  (SgN  >kopenhagen !19_S	et	f	\N
152048	genf	?genf =genf  (SgN  >genf !22_S	et	f	\N
152060	röökivate	röökivate =röökiva  (PlG  >röökiv !02_A	et	f	\N
152061	röökivate	"röökiv %rööki  )V_vA  <röökima ;28_V	et	f	\N
152064	lava	lava =lava  (SgN  >lava !17_S	et	f	\N
152066	lava	lava =lava  (SgG  >lava !17_S	et	f	\N
152069	lava	lava =lava  (SgP  >lava !17_S	et	f	\N
152079	munky	### munky	et	f	\N
152081	haigestumise	haigestumise =haigestumise  (SgG  >haigestumine !12_S	et	f	\N
152082	haigestumise	"haigestumine %haigestu  )MINE_vS  <haigestuma ;27_V	et	f	\N
152091	muusikalises	muusikalises =muusikalise  (SgIn  >muusikaline !12_A	et	f	\N
152092	muusikalises	"muusikaline %muusika  )LINE_aA  <muusika ;01_S	et	f	\N
152093	muusikalises	"muusikaline %muusikali  )NE_aA  <muusikal ;19_S	et	f	\N
152104	viieteistkümnel	?viieteistkümnel =viieteistkümne  (PlAd  >viieteistkümn !22_S	et	f	\N
152105	viieteistkümnel	?viieteistkümnel =viieteistkümnel  (SgN  >viieteistkümnel !02_S	et	f	\N
152106	viieteistkümnel	?viieteistkümnel =kümne  (PlAd  >viie+teist+kümn !22_S	et	f	\N
152107	viieteistkümnel	?viieteistkümnel =kümnel  (SgN  >viie+teist+kümnel !02_S	et	f	\N
152108	viieteistkümnel	?viieteistkümnel =teistkümne  (PlAd  >viie+teistkümn !22_S	et	f	\N
152109	viieteistkümnel	?viieteistkümnel =teistkümnel  (SgN  >viie+teistkümnel !02_S	et	f	\N
152115	grammy	### grammy	et	f	\N
152128	sisetööd	sisetööd =töö  (PlN  >sise+töö !26_S	et	f	\N
152129	sisetööd	sisetööd =töö  (SgP  >sise+töö !26_S	et	f	\N
152132	kentel	?kentel =kente  (SgAd  >kende !06_S	et	f	\N
152133	kentel	?kentel =kentel  (SgN  >kentel !02_S	et	f	\N
152135	tarbatuks	?tarbatuks =tarba  (KndPtIps  >tarpama !29_V	et	f	\N
152136	tarbatuks	?tarbatuks =tarbatu  (SgTr  >tarbatu !01_AS	et	f	\N
152137	tarbatuks	?tarbatuks =tarbatu  (KndPrPs  >tarbatuma !27_V	et	f	\N
152142	pannen	?pannen =panne  (IndPrSg1  >pannema !27_V	et	f	\N
152143	pannen	?pannen =pannen  (SgN  >pannen !02_S	et	f	\N
152157	stirling	?stirling =stirling  (SgN  >stirling !02_S	et	f	\N
152192	million	?million =million  (SgN  >million !19~02_S	et	f	\N
152194	irismaa	irismaa =maa  (SgN  >iris+maa !26_S	et	f	\N
152195	irismaa	irismaa =maa  (SgG  >iris+maa !26_S	et	f	\N
152213	suhtest	suhtest =suhte  (SgEl  >suhe !06_S	et	f	\N
152214	suhtest	suhtest =suhtes  (SgP  >suhtene !12~10_A	et	f	\N
152215	suhtest	"suhtene %suhte  )NE_aA  <suhe ;06_S	et	f	\N
152219	saavusest	saavusest =saavuse  (SgEl  >saavus !11~09_S	et	f	\N
152220	saavusest	"saavus %saa  )VUS_aS  <saama ;37_V	et	f	\N
152221	saavusest	"saavus %saava  )US_aS  <saav ;02_A	et	f	\N
152222	saavusest	saavusest =saavuses  (SgP  >saavusene !12_A	et	f	\N
152223	saavusest	"saavusene %saavuse  )NE_aA  <saavus ;09_S	et	f	\N
152224	saavusest	"saavusene %saavuse  )NE_aA  <saavus ;11_S	et	f	\N
152225	pliiti	pliiti =pliiti  (SgP  >pliit !22_S	et	f	\N
152226	pliiti	pliiti =pliiti  (SgAdt  >pliit !22_S	et	f	\N
152284	juhatus	juhatus =juhatu  (SgIn  >juhatu !01_AS	et	f	\N
152285	juhatus	"juhatu %juha  )TU2_kA  <juha ;17_S	et	f	\N
152286	juhatus	juhatus =juhatus  (SgN  >juhatus !11_S	et	f	\N
152287	juhatus	"juhatus %juhata  )US_vS  <juhatama ;27_V	et	f	\N
152288	juhatus	"juhatus %juha  )TUS2_aS  <juha ;17_S	et	f	\N
152323	nõuatakse	?nõuatakse =nõuatakse  (SgG  >nõuatakne !02_A	et	f	\N
152324	nõuatakse	?nõuatakse =nõuatakse  (PlP  >nõuataks !22_S	et	f	\N
152325	nõuatakse	?nõuatakse =atakse  (SgG  >nõu+atakne !02_A	et	f	\N
152337	kindlusta	kindlusta =kindlusta  (IndPrPs_  >kindlustama !27_V	et	f	\N
152338	kindlusta	kindlusta =kindlusta  (ImpPrSg2  >kindlustama !27_V	et	f	\N
152347	meelelahutus	meelelahutus =lahutu  (SgIn  >meele+lahutu !01_AS	et	f	\N
152348	meelelahutus	"meele+lahutu %lahu  )TU2_kA  <meele+lahk ;22_S	et	f	\N
152349	meelelahutus	meelelahutus =lahutus  (SgN  >meele+lahutus !11_S	et	f	\N
152350	meelelahutus	"meele+lahutus %lahu  )TUS2_aS  <meele+lahk ;22_S	et	f	\N
152351	parkimisplatsi	parkimisplatsi =platsi  (SgG  >parkimis+plats !22_S	et	f	\N
152353	parkimisplatsi	parkimisplatsi =platsi  (SgP  >parkimis+plats !22_S	et	f	\N
152355	parkimisplatsi	parkimisplatsi =platsi  (SgAdt  >parkimis+plats !22_S	et	f	\N
152356	lapsedel	lapsedel =ede  (SgAd  >laps+ede !16_S	et	f	\N
152357	lapsedel	lapsedel =edel  (SgN  >laps+edel !02_S	et	f	\N
152360	gaasirelvi	gaasirelvi =relvi  (SgG  >gaasi+relv !22_S	et	f	\N
152361	gaasirelvi	gaasirelvi =relvi  (SgP  >gaasi+relv !22_S	et	f	\N
152362	gaasirelvi	gaasirelvi =relvi  (SgAdt  >gaasi+relv !22_S	et	f	\N
152363	gaasirelvi	gaasirelvi =relvi  (PlP  >gaasi+relv !22_S	et	f	\N
152370	intervjuueerijale	?intervjuueerijale =intervjuueerija  (SgAll  >intervjuueerija !01_S	et	f	\N
152371	intervjuueerijale	?intervjuueerijale =intervjuueerija  (SgAll  >intervjuueerijas !02_A	et	f	\N
152372	intervjuueerijale	?intervjuueerijale =intervjuueerijale  (PlP  >intervjuueerijal !19_S	et	f	\N
152373	intervjuueerijale	?intervjuueerijale =eerija  (SgAll  >intervjuu+eerija !01_S	et	f	\N
152077	täiskoosseisus	täiskoosseisus =seisu  (SgIn  >täis+koos+seis !22_S	et	f	\N
152078	täiskoosseisus	täiskoosseisus =seisus  (SgN  >täis+koos+seisus !11~09_S	et	f	\N
152098	liigkõva	liigkõva =kõva  (SgN  >liig+kõva !17_A	et	f	\N
152099	liigkõva	liigkõva =kõva  (SgG  >liig+kõva !17_A	et	f	\N
152100	liigkõva	liigkõva =kõva  (SgP  >liig+kõva !17_A	et	f	\N
152112	billboard	?billboard =billboard  (SgN  >billboard !02_S	et	f	\N
152116	nominent	?nominent =nominent  (SgN  >nominent !22_S	et	f	\N
152138	dorpatiks	?dorpatiks =dorpati  (SgTr  >dorpat !02_S	et	f	\N
152139	dorpatiks	?dorpatiks =dorpati  (SgTr  >dorpatt !22_S	et	f	\N
152140	dorpatiks	?dorpatiks =dorpati  (KndPrPs  >dorpattima !28_V	et	f	\N
152153	edinburgh	### edinburgh	et	f	\N
152154	kuussada	### kuussada	et	f	\N
152184	tena	?tena =tena  (SgN  >tena !17_S	et	f	\N
152185	tena	?tena =tena  (SgG  >tena !17_S	et	f	\N
152186	tena	?tena =tena  (SgP  >tena !17_S	et	f	\N
152187	tena	?tena =tena  (IndPrPs_  >tenama !27_V	et	f	\N
152188	tena	?tena =tena  (ImpPrSg2  >tenama !27_V	et	f	\N
152201	kasuline	kasuline =kasuline  (SgN  >kasuline !12_A	et	f	\N
152202	kasuline	"kasuline %kasu  )LINE_aA  <kasu ;17_S	et	f	\N
152209	programmitega	?programmitega =programmi  (PlKom  >programmi !01_S	et	f	\N
152216	suhtest	suhtest =suhte  (SgEl  >suhe !06_S	et	f	\N
152217	suhtest	suhtest =suhtes  (SgP  >suhtene !12~10_A	et	f	\N
152218	suhtest	"suhtene %suhte  )NE_aA  <suhe ;06_S	et	f	\N
152227	trikkraud	?trikkraud =trikkrau  (PlN  >trikkrau !26_S	et	f	\N
152228	trikkraud	?trikkraud =trikkrau  (SgP  >trikkrau !26_S	et	f	\N
152229	trikkraud	?trikkraud =trikkraud  (SgN  >trikkraud !22_S	et	f	\N
152230	külmkappis	?külmkappis =külmkappi  (SgIn  >külmkappi !01_S	et	f	\N
152231	külmkappis	?külmkappis =külmkappi  (IndIpfSg3  >külmkappima !28_V	et	f	\N
152232	külmkappis	?külmkappis =külmkappis  (SgN  >külmkappis !11_S	et	f	\N
152237	julged	julged =julge  (PlN  >julge !01_A	et	f	\N
152238	julged	julged =julge  (IndPrSg2  >julgema !27_V	et	f	\N
152253	juhtkonnast	juhtkonnast =juhtkonna  (SgEl  >juhtkond !22_S	et	f	\N
152254	juhtkonnast	juhtkonnast =juhtkonnas  (SgP  >juhtkonnane !12_A	et	f	\N
152255	juhtkonnast	"juhtkonnane %juhtkonna  )NE_aA  <juhtkond ;22_S	et	f	\N
152256	juhtkonnast	juhtkonnast =konna  (SgEl  >juht+konn !22_S	et	f	\N
152257	juhtkonnast	juhtkonnast =konnas  (SgP  >juht+konnane !10_A	et	f	\N
152258	juhtkonnast	"juht+konnane %konna  )NE_aA  <juht+konn ;22_S	et	f	\N
152270	äriplanist	?äriplanist =äriplani  (SgEl  >äriplan !19_S	et	f	\N
152271	äriplanist	?äriplanist =äriplanis  (SgP  >äriplanis !09_S	et	f	\N
152272	äriplanist	?äriplanist =äriplanist  (SgN  >äriplanist !22_S	et	f	\N
152273	äriplanist	?äriplanist =plani  (SgEl  >äri+plani !17_S	et	f	\N
152274	äriplanist	?äriplanist =planis  (SgP  >äri+planis !09_S	et	f	\N
152275	äriplanist	?äriplanist =planist  (SgN  >äri+planist !22_S	et	f	\N
152292	vanaemalvanaisal	?vanaemalvanaisal =vanaemalvanaisa  (SgAd  >vanaemalvanaisa !16_S	et	f	\N
152293	vanaemalvanaisal	?vanaemalvanaisal =vanaemalvanaisal  (SgN  >vanaemalvanaisal !02_S	et	f	\N
152294	vanaemalvanaisal	?vanaemalvanaisal =emalvanaisa  (SgAd  >vana+emalvanaisa !16_S	et	f	\N
152295	vanaemalvanaisal	?vanaemalvanaisal =emalvanaisal  (SgN  >vana+emalvanaisal !02_S	et	f	\N
152313	bmw-d	bmw-d =bmw  (SgP  >bmw !xx_Q	et	f	\N
152314	bmw-d	bmw-d =bmw  (PlN  >bmw !xx_Q	et	f	\N
152315	tumedadega	?tumedadega =dade  (SgKom  >tume+dade !16_S	et	f	\N
152352	jalgrattastele	jalgrattastele =rattas  (PlAll  >jalg+rattane !12~10_A	et	f	\N
152354	jalgrattastele	"jalg+rattane %ratta  )NE_aA  <jalg+ratas ;07_S	et	f	\N
152358	dzjudot	?dzjudot =dzjudo  (SgP  >dzjudo !16_S	et	f	\N
152359	dzjudot	?dzjudot =dzjudot  (SgN  >dzjudot !02_S	et	f	\N
152378	horoskopi	?horoskopi =horoskopi  (SgG  >horoskopp !22_S	et	f	\N
152379	horoskopi	?horoskopi =horoskopi  (IndPrPs_  >horoskoppima !28_V	et	f	\N
152380	horoskopi	?horoskopi =horoskopi  (ImpPrSg2  >horoskoppima !28_V	et	f	\N
152388	lobimisest	?lobimisest =lobimise  (SgEl  >lobimine !12_S	et	f	\N
152389	konspekteerivad	konspekteerivad =konspekteeri  (IndPrPl3  >konspekteerima !28_V	et	f	\N
152390	konspekteerivad	konspekteerivad =konspekteeriva  (PlN  >konspekteeriv !02_A	et	f	\N
152391	konspekteerivad	"konspekteeriv %konspekteeri  )V_vA  <konspekteerima ;28_V	et	f	\N
152411	soovitust	soovitust =soovitu  (SgEl  >soovitu !01_AS	et	f	\N
152412	soovitust	"soovitu %soovi  )TU1_vS  <soovima ;28_V	et	f	\N
152413	soovitust	"soovitu %soovi  )TU2_kA  <soov ;22_S	et	f	\N
152414	soovitust	soovitust =soovitus  (SgP  >soovitus !11_S	et	f	\N
152415	soovitust	"soovitus %soovita  )US_vS  <soovitama ;27_V	et	f	\N
152416	soovitust	"soovitus %soovi  )TUS1_aS  <soovima ;28_V	et	f	\N
152417	soovitust	"soovitus %soovi  )TUS2_aS  <soov ;22_S	et	f	\N
152418	soovitust	soovitust =tust  (SgN  >soovi+tust !22_S	et	f	\N
152421	fönni	?fönni =fönni  (SgN  >fönni !16_S	et	f	\N
152422	fönni	?fönni =fönni  (SgG  >fönni !16_S	et	f	\N
152423	fönni	?fönni =fönni  (SgG  >fönn !22_S	et	f	\N
152424	fönni	?fönni =fönni  (SgP  >fönn !22_S	et	f	\N
152425	fönni	?fönni =fönni  (SgAdt  >fönn !22_S	et	f	\N
152426	fönni	?fönni =fönni  (IndPrPs_  >fönnima !28_V	et	f	\N
152205	mõistav	?mõistav =mõista  (PtsPrPs  >mõistama !27_V	et	f	\N
152206	mõistav	?mõistav =mõistav  (SgN  >mõistav !02_A	et	f	\N
152207	arvutitega	arvutitega =arvuti  (PlKom  >arvuti !01_S	et	f	\N
152208	arvutitega	arvutitega =tite  (SgKom  >arvu+titt !22_S	et	f	\N
152234	kuritegevust	kuritegevust =us  (SgP  >kuri+tegev+uks !14_S	et	f	\N
152235	kuritegevust	kuritegevust =tegevus  (SgP  >kuri+tegevus !11_S	et	f	\N
152236	kuritegevust	"kuri+tegevus %tegeva  )US_aS  <kuri+tegev ;02_A	et	f	\N
152241	prestiizhikas	?prestiizhikas =prestiizhika  (SgIn  >prestiizhika !01_S	et	f	\N
152242	prestiizhikas	?prestiizhikas =prestiizhika  (SgIn  >prestiizhikas !02_A	et	f	\N
152243	prestiizhikas	?prestiizhikas =prestiizhikas  (SgN  >prestiizhikas !02_A	et	f	\N
152244	prestiizhikas	?prestiizhikas =stiizhika  (SgIn  >pre+stiizhika !01_S	et	f	\N
152245	prestiizhikas	?prestiizhikas =stiizhika  (SgIn  >pre+stiizhikas !02_S	et	f	\N
152246	prestiizhikas	?prestiizhikas =stiizhikas  (SgN  >pre+stiizhikas !02_S	et	f	\N
152267	personaalist	personaalist =personaali  (SgEl  >personaal !22_S	et	f	\N
152268	personaalist	personaalist =personaalis  (SgP  >personaaline !12?10_A	et	f	\N
152269	personaalist	"personaaline %personaali  )NE_aA  <personaal ;22_S	et	f	\N
152289	pärilikust	pärilikust =päriliku  (SgEl  >pärilik !25_A	et	f	\N
152290	pärilikust	pärilikust =pärilikus  (SgP  >pärilikus !11?09_S	et	f	\N
152291	pärilikust	"pärilikus %päriliku  )US_aS  <pärilik ;25_A	et	f	\N
152298	kasulikum	kasulikum =kasulikum  (SgN  >kasulikum !02_A	et	f	\N
152299	kasulikum	"kasulikum %kasuliku  )M_cA  <kasulik ;25_A	et	f	\N
152306	patruleerima	?patruleerima =patruleeri  (Sup  >patruleerima !28_V	et	f	\N
152307	patruleerima	?patruleerima =patruleerima  (SgG  >patruleerim !02_A	et	f	\N
152316	aknadega	### aknadega	et	f	\N
152344	jalgrattast	jalgrattast =ratta  (SgEl  >jalg+ratas !07_S	et	f	\N
152345	jalgrattast	jalgrattast =rattas  (SgP  >jalg+rattane !12~10_A	et	f	\N
152346	jalgrattast	"jalg+rattane %ratta  )NE_aA  <jalg+ratas ;07_S	et	f	\N
152381	intervjuueerija	?intervjuueerija =intervjuueerija  (SgN  >intervjuueerija !01_S	et	f	\N
152382	intervjuueerija	?intervjuueerija =intervjuueerija  (SgG  >intervjuueerija !01_S	et	f	\N
152383	intervjuueerija	?intervjuueerija =intervjuueerija  (SgG  >intervjuueerijas !02_A	et	f	\N
152384	intervjuueerija	?intervjuueerija =eerija  (SgN  >intervjuu+eerija !01_S	et	f	\N
152385	intervjuueerija	?intervjuueerija =eerija  (SgG  >intervjuu+eerija !01_S	et	f	\N
152386	intervjuueerija	?intervjuueerija =eerija  (SgG  >intervjuu+eerijas !02_A	et	f	\N
152392	luuletust	luuletust =luuletu  (SgEl  >luuletu !01_A	et	f	\N
152393	luuletust	"luuletu %luule  )TU2_kA  <luule ;06_S	et	f	\N
152394	luuletust	luuletust =luuletus  (SgP  >luuletus !11_S	et	f	\N
152395	luuletust	"luuletus %luuleta  )US_vS  <luuletama ;27_V	et	f	\N
152396	luuletust	"luuletus %luule  )TUS2_aS  <luule ;06_S	et	f	\N
152397	luuletust	luuletust =tust  (SgN  >luule+tust !22_S	et	f	\N
152398	luuletust	luuletust =letu  (SgEl  >luu+letu !16_S	et	f	\N
152399	tavalisel	tavalisel =tavalise  (SgAd  >tavaline !12_A	et	f	\N
152400	tavalisel	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
152403	ülesanneid	?ülesanneid =ülesannei  (PlN  >ülesannei !26_S	et	f	\N
152404	ülesanneid	?ülesanneid =ülesannei  (SgP  >ülesannei !26_S	et	f	\N
152405	ülesanneid	?ülesanneid =annei  (PlN  >üles+annei !26_S	et	f	\N
152406	ülesanneid	?ülesanneid =annei  (SgP  >üles+annei !26_S	et	f	\N
152407	ülesanneid	?ülesanneid =anneid  (SgN  >üles+anneid !22_S	et	f	\N
152408	ülesanneid	?ülesanneid =sannei  (PlN  >üle+sannei !26_S	et	f	\N
152409	ülesanneid	?ülesanneid =sannei  (SgP  >üle+sannei !26_S	et	f	\N
152410	ülesanneid	?ülesanneid =sanneid  (SgN  >üle+sanneid !22_S	et	f	\N
152428	tänavat	tänavat =täna  (KvtPrPs  >tänama !27_V	et	f	\N
152429	tänavat	tänavat =tänava  (SgP  >tänav !02_A	et	f	\N
152430	tänavat	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
152431	tänavat	tänavat =tänava  (SgP  >tänav !02_S	et	f	\N
152457	tööandjadele	### tööandjadele	et	f	\N
152466	jaluta	jaluta =jalu  (PlAb  >jalg !22_S	et	f	\N
152467	jaluta	jaluta =jaluta  (IndPrPs_  >jalutama !27_V	et	f	\N
152468	jaluta	jaluta =jaluta  (ImpPrSg2  >jalutama !27_V	et	f	\N
152471	paigaldatud	paigaldatud =paigalda  (PtsPtIps  >paigaldama !27_V	et	f	\N
152472	paigaldatud	paigaldatud =paigaldatu  (PlN  >paigaldatu !01_S	et	f	\N
152473	paigaldatud	"paigaldatu %paigalda  )TU1_vS  <paigaldama ;27_V	et	f	\N
152474	paigaldatud	paigaldatud =paigaldatud  (ID  >paigaldatud !41_A	et	f	\N
152475	paigaldatud	"paigaldatud %paigalda  )TUD_vA  <paigaldama ;27_V	et	f	\N
152485	halbad	?halbad =halba  (PlN  >halba !16_S	et	f	\N
152486	halbad	?halbad =halba  (IndPrSg2  >halbama !29_V	et	f	\N
152487	kormus	?kormus =kormu  (SgIn  >kormu !16_S	et	f	\N
152488	kormus	?kormus =kormu  (IndIpfSg3  >kormuma !27_V	et	f	\N
152489	kormus	?kormus =kormus  (SgN  >kormus !11~09_S	et	f	\N
152496	õpetajadel	### õpetajadel	et	f	\N
152528	lülitama	lülitama =lüli  (SupIps  >lülima !27_V	et	f	\N
152529	lülitama	lülitama =lülita  (Sup  >lülitama !27_V	et	f	\N
152550	sõitab	?sõitab =sõita  (IndPrSg3  >sõitama !27_V	et	f	\N
152564	oalju	?oalju =oalju  (SgN  >oalju !01_S	et	f	\N
152565	oalju	?oalju =oalju  (SgG  >oalju !01_S	et	f	\N
152248	progressivses	?progressivses =progressivse  (PlIn  >progressivs !22_S	et	f	\N
152251	edukus	edukus =edukus  (SgN  >edukus !11_S	et	f	\N
152252	edukus	"edukus %eduka  )US_aS  <edukas ;02_A	et	f	\N
152280	eelarvest	eelarvest =arve  (SgEl  >eel+arve !06_S	et	f	\N
152281	eelarvest	eelarvest =arve  (PlEl  >eel+arv !22_S	et	f	\N
152282	eelarvest	eelarvest =arves  (SgP  >eel+arvene !10_A	et	f	\N
152283	eelarvest	"eel+arvene %arve  )NE_aA  <eel+arve ;06_S	et	f	\N
152302	tolmuimeja	tolmuimeja =imeja  (SgN  >tolmu+imeja !01_S	et	f	\N
152303	tolmuimeja	tolmuimeja =imeja  (SgG  >tolmu+imeja !01_S	et	f	\N
152304	veekeetja	veekeetja =keetja  (SgN  >vee+keetja !01_S	et	f	\N
152305	veekeetja	veekeetja =keetja  (SgG  >vee+keetja !01_S	et	f	\N
152328	reklaamikampania	?reklaamikampania =reklaamikampania  (SgN  >reklaamikampania !01_S	et	f	\N
152329	reklaamikampania	?reklaamikampania =reklaamikampania  (SgG  >reklaamikampania !01_S	et	f	\N
152330	reklaamikampania	?reklaamikampania =kampania  (SgN  >reklaami+kampania !01_S	et	f	\N
152331	reklaamikampania	?reklaamikampania =kampania  (SgG  >reklaami+kampania !01_S	et	f	\N
152332	reklaamikampania	?reklaamikampania =ikampania  (SgN  >reklaam+ikampania !01_S	et	f	\N
152333	reklaamikampania	?reklaamikampania =ikampania  (SgG  >reklaam+ikampania !01_S	et	f	\N
152334	edukust	edukust =edukus  (SgP  >edukus !11_S	et	f	\N
152335	edukust	"edukus %eduka  )US_aS  <edukas ;02_A	et	f	\N
152336	edukust	edukust =kus  (SgP  >edu+kusi !20_S	et	f	\N
152365	parfüümi	parfüümi =parfüümi  (SgG  >parfüüm !22_S	et	f	\N
152366	parfüümi	parfüümi =parfüümi  (SgP  >parfüüm !22_S	et	f	\N
152367	parfüümi	parfüümi =parfüümi  (SgAdt  >parfüüm !22_S	et	f	\N
152368	parfüümi	parfüümi =parfüümi  (IndPrPs_  >parfüümima !28_V	et	f	\N
152369	parfüümi	parfüümi =parfüümi  (ImpPrSg2  >parfüümima !28_V	et	f	\N
152387	väldida	?väldida =väldi  (Inf  >väldima !28_V	et	f	\N
152432	laske	laske =las  (ImpPrPl2  >laskma !34_V	et	f	\N
152433	laske	laske =laske  (SgG  >lase !06_S	et	f	\N
152434	laske	laske =laske  (PlP  >lask !22_S	et	f	\N
152441	lahkute	lahkute =lahku  (IndPrPl2  >lahkuma !27_V	et	f	\N
152442	lahkute	lahkute =ute  (SgG  >lahk+utt !22_S	et	f	\N
152443	pistikupesast	?pistikupesast =pistikupesa  (SgEl  >pistikupesa !16_S	et	f	\N
152444	pistikupesast	?pistikupesast =pistikupesas  (SgP  >pistikupesane !12_A	et	f	\N
152445	pistikupesast	?pistikupesast =ikupesa  (SgEl  >pist+ikupesa !16_S	et	f	\N
152446	pistikupesast	?pistikupesast =ikupesas  (SgP  >pist+ikupesane !12_A	et	f	\N
152447	seadmet	?seadmet =seadme  (SgP  >seadme !06_S	et	f	\N
152448	profesionaali	?profesionaali =profesionaali  (SgN  >profesionaali !16_S	et	f	\N
152449	profesionaali	?profesionaali =profesionaali  (SgG  >profesionaali !16_S	et	f	\N
152450	profesionaali	?profesionaali =profesionaali  (SgG  >profesionaal !22_S	et	f	\N
152451	profesionaali	?profesionaali =profesionaali  (SgP  >profesionaal !22_S	et	f	\N
152452	profesionaali	?profesionaali =profesionaali  (SgAdt  >profesionaal !22_S	et	f	\N
152453	profesionaali	?profesionaali =profesionaali  (IndPrPs_  >profesionaalima !28_V	et	f	\N
152454	profesionaali	?profesionaali =profesionaali  (ImpPrSg2  >profesionaalima !28_V	et	f	\N
152462	protsenti	protsenti =protsenti  (SgP  >protsent !22_S	et	f	\N
152463	protsenti	protsenti =protsenti  (SgAdt  >protsent !22_S	et	f	\N
152499	suletada	?suletada =suleta  (Inf  >suletama !27_V	et	f	\N
152500	suletada	?suletada =tada  (SgN  >sule+tada !17_S	et	f	\N
152501	suletada	?suletada =tada  (SgG  >sule+tada !17_S	et	f	\N
152502	suletada	?suletada =tada  (SgP  >sule+tada !17_S	et	f	\N
152515	maunu	?maunu =maunu  (SgN  >maunu !16_S	et	f	\N
152517	maunu	?maunu =maunu  (SgG  >maunu !16_S	et	f	\N
152519	maunu	?maunu =maunu  (IndPrPs_  >maunuma !28_V	et	f	\N
152520	maunu	?maunu =maunu  (ImpPrSg2  >maunuma !28_V	et	f	\N
152521	mõtleda	### mõtleda	et	f	\N
152524	kerulised	?kerulised =kerulise  (PlN  >keruline !12_A	et	f	\N
152551	meert	?meert =meert  (SgN  >meert !22_S	et	f	\N
152562	paigaldamine	paigaldamine =paigaldamine  (SgN  >paigaldamine !12_S	et	f	\N
152563	paigaldamine	"paigaldamine %paigalda  )MINE_vS  <paigaldama ;27_V	et	f	\N
152585	puurivad	puurivad =puuri  (IndPrPl3  >puurima !28_V	et	f	\N
152586	puurivad	puurivad =puuriva  (PlN  >puuriv !02_A	et	f	\N
152587	puurivad	"puuriv %puuri  )V_vA  <puurima ;28_V	et	f	\N
152588	puurivad	puurivad =iva  (PlN  >puur+iva !17_S	et	f	\N
152592	keelustavad	keelustavad =keelusta  (IndPrPl3  >keelustama !27_V	et	f	\N
152593	keelustavad	keelustavad =keelustava  (PlN  >keelustav !02_A	et	f	\N
152594	keelustavad	"keelustav %keelusta  )V_vA  <keelustama ;27_V	et	f	\N
152595	keelustavad	keelustavad =ustava  (PlN  >keel+ustav !02_A	et	f	\N
152614	tervishoidust	?tervishoidust =tervishoidus  (SgP  >tervishoidus !11~09_S	et	f	\N
152615	tervishoidust	?tervishoidust =hoidu  (SgEl  >tervis+hoidu !16_S	et	f	\N
152616	tervishoidust	?tervishoidust =hoidus  (SgP  >tervis+hoidus !11~09_S	et	f	\N
152618	kergendavad	kergendavad =kergenda  (IndPrPl3  >kergendama !27_V	et	f	\N
152619	kergendavad	kergendavad =kergendava  (PlN  >kergendav !02_A	et	f	\N
152620	kergendavad	"kergendav %kergenda  )V_vA  <kergendama ;27_V	et	f	\N
152661	üleujutused	üleujutused =ujutuse  (PlN  >üle+ujutus !11_S	et	f	\N
152374	intervjuueerijale	?intervjuueerijale =eerija  (SgAll  >intervjuu+eerijas !02_A	et	f	\N
152375	intervjuueerijale	?intervjuueerijale =eerijale  (PlP  >intervjuu+eerijal !19_S	et	f	\N
152376	avalduses	avalduses =avalduse  (SgIn  >avaldus !11_S	et	f	\N
152377	avalduses	"avaldus %avalda  )US_vS  <avaldama ;27_V	et	f	\N
152401	koduseid	koduseid =koduse  (PlP  >kodune !10_A	et	f	\N
152402	koduseid	"kodune %kodu  )NE_aA  <kodu ;17_S	et	f	\N
152419	töötavate	töötavate =töötava  (PlG  >töötav !02_A	et	f	\N
152420	töötavate	"töötav %tööta  )V_vA  <töötama ;27_V	et	f	\N
152455	avaldused	avaldused =avalduse  (PlN  >avaldus !11_S	et	f	\N
152456	avaldused	"avaldus %avalda  )US_vS  <avaldama ;27_V	et	f	\N
152458	kuuskümmend	?kuuskümmend =kuuskümmend  (SgN  >kuuskümmend !22_S	et	f	\N
152459	kuuskümmend	?kuuskümmend =skümmend  (SgN  >kuu+skümmend !02_S	et	f	\N
152476	signalizatsioon	?signalizatsioon =signalizatsioon  (SgN  >signalizatsioon !22_S	et	f	\N
152477	tööintervjuuk	?tööintervjuuk =tööintervjuuk  (SgN  >tööintervjuuk !22_S	et	f	\N
152478	tööintervjuuk	?tööintervjuuk =intervjuuk  (SgN  >töö+intervjuuk !22_S	et	f	\N
152481	seelises	?seelises =seelise  (SgIn  >seeline !10_A	et	f	\N
152482	seelises	?seelises =seelise  (IndIpfSg3  >seelisema !27_V	et	f	\N
152490	kodunetööd	?kodunetööd =kodunetöö  (PlN  >kodunetöö !26_S	et	f	\N
152491	kodunetööd	?kodunetööd =kodunetöö  (SgP  >kodunetöö !26_S	et	f	\N
152492	kodunetööd	?kodunetööd =kodunetööd  (SgN  >kodunetööd !22_S	et	f	\N
152493	kodunetööd	?kodunetööd =netöö  (PlN  >kodu+netöö !26_S	et	f	\N
152494	kodunetööd	?kodunetööd =netöö  (SgP  >kodu+netöö !26_S	et	f	\N
152495	kodunetööd	?kodunetööd =netööd  (SgN  >kodu+netööd !22_S	et	f	\N
152503	küsimusest	küsimusest =küsimuse  (SgEl  >küsimus !11_S	et	f	\N
152504	küsimusest	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
152505	küsimusest	küsimusest =küsimuses  (SgP  >küsimusene !12_A	et	f	\N
152506	küsimusest	"küsimusene %küsimuse  )NE_aA  <küsimus ;11_S	et	f	\N
152508	riietused	riietused =riietuse  (PlN  >riietus !11_S	et	f	\N
152509	riietused	"riietus %riieta  )US_vS  <riietama ;27_V	et	f	\N
152511	tööintervjuuerijad	?tööintervjuuerijad =tööintervjuuerija  (PlN  >tööintervjuuerija !01_S	et	f	\N
152512	tööintervjuuerijad	?tööintervjuuerijad =tööintervjuuerija  (PlN  >tööintervjuuerijas !02_A	et	f	\N
152513	tööintervjuuerijad	?tööintervjuuerijad =erija  (PlN  >töö+intervjuu+erija !01_S	et	f	\N
152514	tööintervjuuerijad	?tööintervjuuerijad =erija  (PlN  >töö+intervjuu+erijas !02_A	et	f	\N
152516	tööintervjuuerijad	?tööintervjuuerijad =intervjuuerija  (PlN  >töö+intervjuuerija !01_S	et	f	\N
152518	tööintervjuuerijad	?tööintervjuuerijad =intervjuuerija  (PlN  >töö+intervjuuerijas !02_A	et	f	\N
152530	veesi	?veesi =veesi  (SgN  >veesi !16_S	et	f	\N
152531	veesi	?veesi =veesi  (SgG  >veesi !16_S	et	f	\N
152532	veesi	?veesi =veesi  (SgG  >vees !22_S	et	f	\N
152533	veesi	?veesi =veesi  (SgP  >vees !22_S	et	f	\N
152534	veesi	?veesi =veesi  (SgAdt  >vees !22_S	et	f	\N
152535	veesi	?veesi =veesi  (IndPrPs_  >veesima !28_V	et	f	\N
152536	veesi	?veesi =veesi  (ImpPrSg2  >veesima !28_V	et	f	\N
152552	valikogu	?valikogu =valikogu  (IndPrPs_  >valikoguma !27_V	et	f	\N
152553	valikogu	?valikogu =valikogu  (ImpPrSg2  >valikoguma !27_V	et	f	\N
152554	valikogu	?valikogu =ogu  (SgN  >valik+ogu !17_S	et	f	\N
152555	valikogu	?valikogu =ogu  (SgG  >valik+ogu !17_S	et	f	\N
152556	valikogu	?valikogu =ogu  (SgP  >valik+ogu !17_S	et	f	\N
152557	rahastan	?rahastan =rahasta  (IndPrSg1  >rahastama !27_V	et	f	\N
152558	rahastan	?rahastan =rahastan  (SgN  >rahastan !19_S	et	f	\N
152568	trükkimine	trükkimine =trükkimine  (SgN  >trükkimine !12_S	et	f	\N
152569	trükkimine	"trükkimine %trükki  )MINE_vS  <trükkima ;28_V	et	f	\N
152572	meiel	meiel =meie  (SgAd  >meie !16_S	et	f	\N
152573	meiel	meiel =meie  (PlAd  >meig !22_S	et	f	\N
152574	looduskaitsealasid	looduskaitsealasid =ala  (PlP  >loodus+kaitse+ala !17_S	et	f	\N
152575	looduskaitsealasid	looduskaitsealasid =alasi  (PlN  >loodus+kaitse+alasi !01_S	et	f	\N
152600	remondi	remondi =remondi  (SgG  >remont !22_S	et	f	\N
152601	remondi	remondi =remondi  (IndPrPs_  >remontima !28_V	et	f	\N
152602	remondi	remondi =remondi  (ImpPrSg2  >remontima !28_V	et	f	\N
152605	keemilisi	keemilisi =keemilisi  (PlP  >keemiline !12_A	et	f	\N
152606	keemilisi	"keemiline %keemi  )LINE_aA  <keem ;22_S	et	f	\N
152613	omat	?omat =omat  (SgN  >omat !02_S	et	f	\N
152631	pindu	pindu =pindu  (SgP  >pind !22_S	et	f	\N
152632	pindu	pindu =pindu  (SgAdt  >pind !22_S	et	f	\N
152633	pindu	pindu =pindu  (PlP  >pind !22_S	et	f	\N
152639	mõneid	?mõneid =mõnei  (PlN  >mõnei !26_S	et	f	\N
152640	mõneid	?mõneid =mõnei  (SgP  >mõnei !26_S	et	f	\N
152641	mõneid	?mõneid =mõneid  (SgN  >mõneid !22_S	et	f	\N
152646	mikrobe	### mikrobe	et	f	\N
152648	keemilis	?keemilis =keemilis  (SgN  >keemilis !11_S	et	f	\N
152652	minnusi	?minnusi =minnusi  (ID  >minnusi !41_D	et	f	\N
152660	tüuseb	?tüuseb =tüuse  (IndPrSg3  >tüusema !28_V	et	f	\N
152663	kuumalained	kuumalained =ine  (PlN  >kuum+ala+ine !16_S	et	f	\N
152664	kuumalained	kuumalained =laine  (PlN  >kuuma+laine !06_S	et	f	\N
152675	tarkuse	tarkuse =tarkuse  (SgG  >tarkus !11~09_S	et	f	\N
152427	fönni	?fönni =fönni  (ImpPrSg2  >fönnima !28_V	et	f	\N
152435	lukku	lukku =lukku  (ID  >lukku !41_D	et	f	\N
152436	lukku	lukku =lukku  (SgP  >lukk !22_S	et	f	\N
152437	lukku	lukku =lukku  (SgAdt  >lugu !18_S	et	f	\N
152438	lukku	lukku =lukku  (SgAdt  >lukk !22_S	et	f	\N
152439	lukku	lukku =lukku  (IndPrPs_  >lukkuma !27_V	et	f	\N
152440	lukku	lukku =lukku  (ImpPrSg2  >lukkuma !27_V	et	f	\N
152469	suhtle	suhtle =suhtle  (IndPrPs_  >suhtlema !30_V	et	f	\N
152470	suhtle	suhtle =suhtle  (ImpPrSg2  >suhtlema !30_V	et	f	\N
152483	tööintervjuu	tööintervjuu =intervjuu  (SgN  >töö+intervjuu !26_S	et	f	\N
152484	tööintervjuu	tööintervjuu =intervjuu  (SgG  >töö+intervjuu !26_S	et	f	\N
152507	lugeb	### lugeb	et	f	\N
152522	suitsamine	?suitsamine =suitsamine  (SgN  >suitsamine !12_S	et	f	\N
152523	suitsamine	?suitsamine =suitsamine  (PlP  >suitsamin !19_S	et	f	\N
152540	tanaval	?tanaval =tanava  (SgAd  >tanava !01_S	et	f	\N
152541	tanaval	?tanaval =tanava  (SgAd  >tanav !02_A	et	f	\N
152542	tanaval	?tanaval =tanaval  (SgN  >tanaval !19_S	et	f	\N
152546	lemmikspordihuvi	lemmikspordihuvi =huvi  (SgN  >lemmik+spordi+huvi !17_S	et	f	\N
152547	lemmikspordihuvi	lemmikspordihuvi =huvi  (SgG  >lemmik+spordi+huvi !17_S	et	f	\N
152548	lemmikspordihuvi	lemmikspordihuvi =huvi  (SgP  >lemmik+spordi+huvi !17_S	et	f	\N
152570	loodussõbraline	loodussõbraline =sõbraline  (SgN  >loodus+sõbraline !12_A	et	f	\N
152571	loodussõbraline	"loodus+sõbraline %sõbra  )LINE_aA  <loodus+sõber ;24_S	et	f	\N
152589	summutavad	summutavad =summuta  (IndPrPl3  >summutama !27_V	et	f	\N
152590	summutavad	summutavad =summutava  (PlN  >summutav !02_A	et	f	\N
152591	summutavad	"summutav %summuta  )V_vA  <summutama ;27_V	et	f	\N
152603	summutavaid	summutavaid =summutava  (PlP  >summutav !02_A	et	f	\N
152604	summutavaid	"summutav %summuta  )V_vA  <summutama ;27_V	et	f	\N
152610	täppu	?täppu =täppu  (ID  >täppu !41_D	et	f	\N
152611	täppu	?täppu =täppu  (IndPrPs_  >täppuma !27_V	et	f	\N
152612	täppu	?täppu =täppu  (ImpPrSg2  >täppuma !27_V	et	f	\N
152624	keemindid	?keemindid =keemindi  (PlN  >keemindi !01_S	et	f	\N
152625	keemindid	?keemindid =keemindi  (PlN  >keemind !02_S	et	f	\N
152626	keemindid	?keemindid =keemindi  (PlN  >keemint !22_S	et	f	\N
152627	keemindid	?keemindid =keemindi  (IndPrSg2  >keemintima !28_V	et	f	\N
152634	auto-	auto- =auto  (SgN  >auto !16_S	et	f	\N
152635	auto-	auto- =auto  (SgG  >auto !16_S	et	f	\N
152644	produtserivad	?produtserivad =produtseriva  (PlN  >produtseriv !02_A	et	f	\N
152645	produtserivad	?produtserivad =produtseriva  (PlN  >produtseriva !16_S	et	f	\N
152647	kahulik	?kahulik =kahulik  (SgN  >kahulik !25_A	et	f	\N
152649	kummikindades	?kummikindades =kummikinda  (PlIn  >kummikinda !16_S	et	f	\N
152650	kummikindades	?kummikindades =kummikinda  (Ger  >kummikindama !27_V	et	f	\N
152651	kummikindades	?kummikindades =kinda  (PlIn  >kummi+kinda !16_S	et	f	\N
152672	tõusuks	tõusuks =tõusu  (SgTr  >tõus !22_S	et	f	\N
152673	tõusuks	tõusuks =suks  (SgN  >tõu+suks !22_S	et	f	\N
152678	ideead	?ideead =ideea  (PlN  >ideea !26_S	et	f	\N
152679	ideead	?ideead =ideea  (SgP  >ideea !26_S	et	f	\N
152680	ideead	?ideead =ideead  (SgN  >ideead !22_S	et	f	\N
152685	ebbaktiivsem	?ebbaktiivsem =ebbaktiivsem  (SgN  >ebbaktiivsem !02_A	et	f	\N
152690	otsiksid	otsiksid =otsi  (KndPrSg2  >otsima !28_V	et	f	\N
152691	otsiksid	otsiksid =otsi  (KndPrPl3  >otsima !28_V	et	f	\N
152692	otsiksid	otsiksid =iksi  (PlN  >ots+iks !22_S	et	f	\N
152697	skeemi	skeemi =skeemi  (SgG  >skeem !22_S	et	f	\N
152698	skeemi	skeemi =skeemi  (SgP  >skeem !22_S	et	f	\N
152699	skeemi	skeemi =skeemi  (SgAdt  >skeem !22_S	et	f	\N
152728	proekte	?proekte =proekte  (SgN  >proekte !06_S	et	f	\N
152729	proekte	?proekte =proekte  (SgG  >proekte !06_S	et	f	\N
152730	proekte	?proekte =proekte  (PlP  >proekt !22_S	et	f	\N
152731	proekte	?proekte =proekte  (IndPrPs_  >proektema !27_V	et	f	\N
152732	proekte	?proekte =proekte  (ImpPrSg2  >proektema !27_V	et	f	\N
152738	peama	?peama =peama  (SgN  >peama !16_S	et	f	\N
152739	peama	?peama =peama  (SgG  >peama !16_S	et	f	\N
152740	peama	?peama =peama  (IndPrPs_  >peamama !29_V	et	f	\N
152741	peama	?peama =peama  (ImpPrSg2  >peamama !29_V	et	f	\N
152750	suheldas	?suheldas =suhelda  (IndIpfSg3  >suheldama !27_V	et	f	\N
152757	erineval	erineval =erineva  (SgAd  >erinev !02_A	et	f	\N
152758	erineval	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
152759	kristiinekeskuses	?kristiinekeskuses =kristiinekeskuse  (SgIn  >kristiinekeskus !11~09_S	et	f	\N
152766	võrdselt	võrdselt =võrdse  (SgAbl  >võrdne !02_A	et	f	\N
152767	võrdselt	võrdselt =võrdselt  (ID  >võrdselt !41_D	et	f	\N
152768	võrdselt	"võrdselt %võrdse  )LT_mD  <võrdne ;02_A	et	f	\N
152781	andmist	andmist =andmis  (SgP  >andmine !12?10_S	et	f	\N
152782	andmist	"andmine %and  )MINE_vS  <andma ;34_V	et	f	\N
152785	ülikooliks	ülikooliks =iks  (SgN  >üli+kool+iks !22_S	et	f	\N
152786	ülikooliks	ülikooliks =kooli  (SgTr  >üli+kool !22_S	et	f	\N
152787	ülikooliks	ülikooliks =kooli  (PlTr  >üli+kool !22_S	et	f	\N
152804	lõpemese	?lõpemese =lõpemese  (SgG  >lõpemene !12_A	et	f	\N
152826	harimatust	harimatust =harimatu  (SgEl  >harimatu !01_A	et	f	\N
152461	protsenti	protsenti =protsenti  (SgAdt  >protsent !22_S	et	f	\N
152464	õppetajatega	?õppetajatega =õppetaja  (PlKom  >õppetaja !01_S	et	f	\N
152465	õppetajatega	?õppetajatega =õppetaja  (PlKom  >õppetajas !02_A	et	f	\N
152479	vastuvõttu	vastuvõttu =võttu  (SgP  >vastu+võtt !22_S	et	f	\N
152480	vastuvõttu	vastuvõttu =võttu  (SgAdt  >vastu+võtt !22_S	et	f	\N
152497	kormusest	?kormusest =kormuse  (SgEl  >kormus !11~09_S	et	f	\N
152498	kormusest	?kormusest =kormuses  (SgP  >kormusene !12_A	et	f	\N
152510	sõldub	?sõldub =sõldu  (IndPrSg3  >sõlduma !27_V	et	f	\N
152525	õppekud	?õppekud =õppeku  (PlN  >õppeku !01_S	et	f	\N
152526	õppekud	?õppekud =õppeku  (PlN  >õppek !02_S	et	f	\N
152527	õppekud	?õppekud =õppeku  (IndPrSg2  >õppekuma !27_V	et	f	\N
152537	kolmaks	?kolmaks =kolma  (SgTr  >kolma !16_S	et	f	\N
152538	kolmaks	?kolmaks =kolma  (KndPrPs  >kolmama !29_V	et	f	\N
152539	kolmaks	?kolmaks =aks  (SgN  >kolm+aks !22_S	et	f	\N
152543	suveastaeg	?suveastaeg =suveastaeg  (SgN  >suveastaeg !22_S	et	f	\N
152544	suveastaeg	?suveastaeg =astaeg  (SgN  >suve+astaeg !22_S	et	f	\N
152545	veetab	?veetab =veeta  (IndPrSg3  >veetama !27_V	et	f	\N
152549	puhatab	?puhatab =puhata  (IndPrSg3  >puhatama !27_V	et	f	\N
152559	kaistide	?kaistide =kaisti  (PlG  >kaist !22_S	et	f	\N
152560	kaistide	?kaistide =stide  (SgN  >kai+stide !16_S	et	f	\N
152561	kaistide	?kaistide =stide  (SgG  >kai+stide !16_S	et	f	\N
152576	säilitama	säilitama =säili  (SupIps  >säilima !28_V	et	f	\N
152577	säilitama	säilitama =säilita  (Sup  >säilitama !27_V	et	f	\N
152583	remonti	remonti =remonti  (SgP  >remont !22_S	et	f	\N
152584	remonti	remonti =remonti  (SgAdt  >remont !22_S	et	f	\N
152596	piiravad	piiravad =piira  (IndPrPl3  >piirama !29_V	et	f	\N
152597	piiravad	piiravad =piirava  (PlN  >piirav !02_A	et	f	\N
152598	piiravad	"piirav %piira  )V_vA  <piirama ;29_V	et	f	\N
152599	piiravad	piiravad =ava  (PlN  >piir+ava !17_S	et	f	\N
152621	aidavad	?aidavad =aida  (IndPrPl3  >aidama !29_V	et	f	\N
152622	aidavad	?aidavad =aidava  (PlN  >aidava !01_S	et	f	\N
152623	aidavad	?aidavad =aidava  (PlN  >aidav !02_A	et	f	\N
152642	spetsialiselt	?spetsialiselt =spetsialise  (SgAbl  >spetsialine !12_A	et	f	\N
152643	spetsialiselt	?spetsialiselt =spetsialiselt  (ID  >spetsialiselt !41_D	et	f	\N
152655	jäämed	?jäämed =jääme  (PlN  >jääme !06_S	et	f	\N
152657	jäämed	?jäämed =jääme  (IndPrSg2  >jäämema !27_V	et	f	\N
152665	bioloogilise	bioloogilise =bioloogilise  (SgG  >bioloogiline !12_A	et	f	\N
152666	bioloogilise	"bioloogiline %bioloogi  )LINE_aA  <bioloog ;22_S	et	f	\N
152667	bioloogilise	bioloogilise =loogilise  (SgG  >bio+loogiline !12_A	et	f	\N
152668	bioloogilise	"bio+loogiline %loogi  )LINE_aA  <bio+loog ;22_S	et	f	\N
152674	cm	### cm	et	f	\N
152700	minne	?minne =minne  (SgN  >minne !06_S	et	f	\N
152701	minne	?minne =minne  (PlP  >minn !22_S	et	f	\N
152702	minne	?minne =minne  (IndPrPs_  >minnema !27_V	et	f	\N
152703	minne	?minne =minne  (ImpPrSg2  >minnema !27_V	et	f	\N
152706	enampopulaarsem	enampopulaarsem =populaarsem  (SgN  >enam+populaarsem !02_A	et	f	\N
152707	enampopulaarsem	"enam+populaarsem %populaarse  )M_cA  <enam+populaarne ;02_A	et	f	\N
152711	proektis	?proektis =proekti  (SgIn  >proekt !22_S	et	f	\N
152712	proektis	?proektis =proekti  (IndIpfSg3  >proektima !28_V	et	f	\N
152713	proektis	?proektis =proektis  (SgN  >proektis !09_S	et	f	\N
152723	reklaamiv	reklaamiv =reklaami  (PtsPrPs  >reklaamima !28_V	et	f	\N
152724	reklaamiv	reklaamiv =reklaamiv  (SgN  >reklaamiv !02_A	et	f	\N
152725	reklaamiv	"reklaamiv %reklaami  )V_vA  <reklaamima ;28_V	et	f	\N
152733	puhastamise	puhastamise =puhastamise  (SgG  >puhastamine !12_S	et	f	\N
152734	puhastamise	"puhastamine %puhasta  )MINE_vS  <puhastama ;27_V	et	f	\N
152735	palavuses	palavuses =palavuse  (SgIn  >palavus !11_S	et	f	\N
152736	palavuses	"palavus %pala  )VUS_aS  <palama ;27_V	et	f	\N
152737	palavuses	"palavus %palava  )US_aS  <palav ;02_A	et	f	\N
152751	eenglise	?eenglise =eenglise  (SgG  >eengline !12~10_A	et	f	\N
152752	eenglise	?eenglise =eenglise  (IndPrPs_  >eenglisema !27_V	et	f	\N
152753	eenglise	?eenglise =eenglise  (ImpPrSg2  >eenglisema !27_V	et	f	\N
152760	peipsi-järve	peipsi-järve =järve  (SgG  >peipsi-järv !22_S	et	f	\N
152761	peipsi-järve	peipsi-järve =järve  (SgP  >peipsi-järv !22_S	et	f	\N
152762	peipsi-järve	peipsi-järve =järve  (SgAdt  >peipsi-järv !22_S	et	f	\N
152763	peipsi-järve	peipsi-järve =järve  (PlP  >peipsi-järv !22_S	et	f	\N
152764	leenal	?leenal =leena  (SgAd  >leena !16_S	et	f	\N
152765	leenal	?leenal =leenal  (SgN  >leenal !02_S	et	f	\N
152783	asutamisele	asutamisele =asutamise  (SgAll  >asutamine !12_S	et	f	\N
152784	asutamisele	"asutamine %asuta  )MINE_vS  <asutama ;27_V	et	f	\N
152788	vaesemate	vaesemate =vaesema  (PlG  >vaesem !02_A	et	f	\N
152789	vaesemate	"vaesem %vae  )SEM_cA  <vaag ;22_S	et	f	\N
152790	vaesemate	"vaesem %vaese  )M_cA  <vaene ;10_AS	et	f	\N
152791	vaesemate	vaesemate =mate  (SgN  >vaese+mate !16_S	et	f	\N
152792	vaesemate	vaesemate =mate  (SgG  >vaese+mate !16_S	et	f	\N
152797	andreas	?andreas =andrea  (SgIn  >andrea !26_S	et	f	\N
152798	andreas	?andreas =andreas  (SgN  >andreas !22_S	et	f	\N
152566	oalju	?oalju =oalju  (IndPrPs_  >oaljuma !27_V	et	f	\N
152567	oalju	?oalju =oalju  (ImpPrSg2  >oaljuma !27_V	et	f	\N
152578	seellepärast	?seellepärast =seellepära  (SgEl  >seellepära !16_S	et	f	\N
152579	seellepärast	?seellepärast =seellepäras  (SgP  >seellepärane !12_A	et	f	\N
152580	tõsisem	tõsisem =tõsisem  (SgN  >tõsisem !02_A	et	f	\N
152581	tõsisem	"tõsisem %tõsise  )M_cA  <tõsine ;10_A	et	f	\N
152582	rahuses	?rahuses =rahuse  (SgIn  >rahus !09_S	et	f	\N
152607	pori	pori =pori  (SgN  >pori !17_S	et	f	\N
152608	pori	pori =pori  (SgG  >pori !17_S	et	f	\N
152609	pori	pori =pori  (SgP  >pori !17_S	et	f	\N
152617	pulbert	?pulbert =pulbert  (SgN  >pulbert !22_S	et	f	\N
152628	valgendavad	valgendavad =valgenda  (IndPrPl3  >valgendama !27_V	et	f	\N
152629	valgendavad	valgendavad =valgendava  (PlN  >valgendav !02_A	et	f	\N
152630	valgendavad	"valgendav %valgenda  )V_vA  <valgendama ;27_V	et	f	\N
152636	mööblipindu	mööblipindu =pindu  (SgP  >mööbli+pind !22_S	et	f	\N
152637	mööblipindu	mööblipindu =pindu  (SgAdt  >mööbli+pind !22_S	et	f	\N
152638	mööblipindu	mööblipindu =pindu  (PlP  >mööbli+pind !22_S	et	f	\N
152653	kliimamuutuse	kliimamuutuse =muutuse  (SgG  >kliima+muutus !11~09_S	et	f	\N
152654	kliimamuutuse	"kliima+muutus %muu  )TUS2_aS  <kliima+muu ;26_S	et	f	\N
152656	sulavad	sulavad =sula  (IndPrPl3  >sulama !27_V	et	f	\N
152658	sulavad	sulavad =sulava  (PlN  >sulav !02_A	et	f	\N
152659	sulavad	"sulav %sula  )V_vA  <sulama ;27_V	et	f	\N
152688	kirjutaksid	kirjutaksid =kirjuta  (KndPrSg2  >kirjutama !27_V	et	f	\N
152689	kirjutaksid	kirjutaksid =kirjuta  (KndPrPl3  >kirjutama !27_V	et	f	\N
152754	kasumiseks	kasumiseks =kasumise  (SgTr  >kasumine !12_S	et	f	\N
152755	kasumiseks	"kasumine %kasumi  )NE_aA  <kasum ;02_S	et	f	\N
152756	kasumiseks	kasumiseks =seks  (SgN  >kasumi+seks !22_S	et	f	\N
152779	linnakoolis	linnakoolis =kooli  (SgIn  >linna+kool !22_S	et	f	\N
152780	linnakoolis	linnakoolis =kooli  (PlIn  >linna+kool !22_S	et	f	\N
152801	majandamiseks	majandamiseks =majandamise  (SgTr  >majandamine !12_S	et	f	\N
152802	majandamiseks	"majandamine %majanda  )MINE_vS  <majandama ;27_V	et	f	\N
152805	dokumenti	dokumenti =dokumenti  (SgP  >dokument !22_S	et	f	\N
152806	dokumenti	dokumenti =dokumenti  (SgAdt  >dokument !22_S	et	f	\N
152813	õppemaksu	õppemaksu =maksu  (SgG  >õppe+maks !22_S	et	f	\N
152814	õppemaksu	õppemaksu =maksu  (SgP  >õppe+maks !22_S	et	f	\N
152815	õppemaksu	õppemaksu =maksu  (SgAdt  >õppe+maks !22_S	et	f	\N
152816	õppemaksu	õppemaksu =maksu  (PlP  >õppe+maks !22_S	et	f	\N
152823	piltlikult	piltlikult =piltliku  (SgAbl  >piltlik !25_A	et	f	\N
152824	piltlikult	piltlikult =piltlikult  (ID  >piltlikult !41_D	et	f	\N
152825	piltlikult	"piltlikult %piltliku  )LT_mD  <piltlik ;25_A	et	f	\N
152855	tinu	?tinu =tinu  (SgN  >tinu !17_S	et	f	\N
152856	tinu	?tinu =tinu  (SgG  >tinu !17_S	et	f	\N
152857	tinu	?tinu =tinu  (SgP  >tinu !17_S	et	f	\N
152858	tinu	?tinu =tinu  (IndPrPs_  >tinuma !27_V	et	f	\N
152859	tinu	?tinu =tinu  (ImpPrSg2  >tinuma !27_V	et	f	\N
152862	tõlgi	tõlgi =tõlgi  (SgG  >tõlk !22_S	et	f	\N
152864	tõlgi	tõlgi =tõlgi  (IndPrPs_  >tõlkima !28_V	et	f	\N
152866	tõlgi	tõlgi =tõlgi  (ImpPrSg2  >tõlkima !28_V	et	f	\N
152868	1630a	### 1630a	et	f	\N
152873	1632a	### 1632a	et	f	\N
152879	arstiteaduskonnas	arstiteaduskonnas =konna  (SgIn  >arsti+teadus+konn !22_S	et	f	\N
152880	arstiteaduskonnas	arstiteaduskonnas =teaduskonna  (SgIn  >arsti+teaduskond !22_S	et	f	\N
152884	trk	### trk	et	f	\N
152885	19a	### 19a	et	f	\N
152908	perekonnanimesi	?perekonnanimesi =perekonnanimesi  (PlP  >perekonnanimene !12_A	et	f	\N
152910	perekonnanimesi	?perekonnanimesi =konnanimesi  (PlP  >pere+konnanimene !12_A	et	f	\N
152919	koguvada	koguvada =vada  (SgN  >kogu+vada !17_S	et	f	\N
152920	koguvada	koguvada =vada  (SgG  >kogu+vada !17_S	et	f	\N
152921	koguvada	koguvada =vada  (SgP  >kogu+vada !17_S	et	f	\N
152926	põllumaj	### põllumaj	et	f	\N
152939	cimze	?cimze =cimze  (SgN  >cimze !06_S	et	f	\N
152940	cimze	?cimze =cimze  (SgG  >cimze !06_S	et	f	\N
152941	valka	?valka =valka  (SgN  >valka !16_S	et	f	\N
152942	valka	?valka =valka  (SgG  >valka !16_S	et	f	\N
152943	valka	?valka =valka  (IndPrPs_  >valkama !29_V	et	f	\N
152944	valka	?valka =valka  (ImpPrSg2  >valkama !29_V	et	f	\N
152945	kirjastamine	kirjastamine =kirjastamine  (SgN  >kirjastamine !12_S	et	f	\N
152946	kirjastamine	"kirjastamine %kirjasta  )MINE_vS  <kirjastama ;27_V	et	f	\N
152961	härmat	?härmat =härmat  (SgN  >härmat !02_S	et	f	\N
152999	kõlblust	kõlblust =kõlblus  (SgP  >kõlblus !11~09_S	et	f	\N
153000	kõlblust	"kõlblus %kõlbla  )US_aS  <kõlblas ;02_A	et	f	\N
153005	edenemist	edenemist =edenemis  (SgP  >edenemine !12_S	et	f	\N
153006	edenemist	"edenemine %edene  )MINE_vS  <edenema ;27_V	et	f	\N
153007	asda	?asda =asda  (SgN  >asda !16_S	et	f	\N
153008	asda	?asda =asda  (SgG  >asda !16_S	et	f	\N
153009	asda	?asda =asda  (IndPrPs_  >asdama !29_V	et	f	\N
153010	asda	?asda =asda  (ImpPrSg2  >asdama !29_V	et	f	\N
153068	ristikujulisi	ristikujulisi =ujulisi  (PlP  >ristik+ujuline !12_A	et	f	\N
152662	üleujutused	"üle+ujutus %uju  )TUS2_aS  <üle+uju ;17_S	et	f	\N
152669	mutmekesisuse	?mutmekesisuse =mutmekesisuse  (SgG  >mutmekesisus !11?09_S	et	f	\N
152670	vähenemine	vähenemine =vähenemine  (SgN  >vähenemine !12_S	et	f	\N
152671	vähenemine	"vähenemine %vähene  )MINE_vS  <vähenema ;27_V	et	f	\N
152681	muutada	?muutada =muuta  (Inf  >muutama !27_V	et	f	\N
152682	muutada	?muutada =tada  (SgN  >muu+tada !17_S	et	f	\N
152683	muutada	?muutada =tada  (SgG  >muu+tada !17_S	et	f	\N
152684	muutada	?muutada =tada  (SgP  >muu+tada !17_S	et	f	\N
152693	kodutööid	?kodutööid =kodutööi  (PlN  >kodutööi !26_S	et	f	\N
152694	kodutööid	?kodutööid =kodutööi  (SgP  >kodutööi !26_S	et	f	\N
152695	kodutööid	?kodutööid =kodutööid  (SgN  >kodutööid !22_S	et	f	\N
152696	kodutööid	?kodutööid =tööid  (SgN  >kodu+tööid !02_S	et	f	\N
152704	noortest	noortest =noor  (PlEl  >noor !13_AS	et	f	\N
152705	noortest	noortest =test  (SgN  >noor+test !22_S	et	f	\N
152717	nõudepesu	nõudepesu =pesu  (SgN  >nõude+pesu !17_S	et	f	\N
152718	nõudepesu	nõudepesu =pesu  (SgG  >nõude+pesu !17_S	et	f	\N
152719	nõudepesu	nõudepesu =pesu  (SgP  >nõude+pesu !17_S	et	f	\N
152720	küüriv	küüriv =küüri  (PtsPrPs  >küürima !28_V	et	f	\N
152721	küüriv	küüriv =küüriv  (SgN  >küüriv !02_A	et	f	\N
152722	küüriv	"küüriv %küüri  )V_vA  <küürima ;28_V	et	f	\N
152742	istutama	istutama =istu  (SupIps  >istuma !28_V	et	f	\N
152743	istutama	istutama =istuta  (Sup  >istutama !27_V	et	f	\N
152769	adolfi	?adolfi =adolfi  (SgN  >adolfi !01_S	et	f	\N
152770	adolfi	?adolfi =adolfi  (SgG  >adolfi !01_S	et	f	\N
152771	adolfi	?adolfi =adolfi  (SgG  >adolf !22_S	et	f	\N
152772	adolfi	?adolfi =adolfi  (SgP  >adolf !22_S	et	f	\N
152773	adolfi	?adolfi =adolfi  (SgAdt  >adolf !22_S	et	f	\N
152793	skytre	?skytre =skytre  (SgN  >skytre !06_S	et	f	\N
152794	skytre	?skytre =skytre  (SgG  >skydre !06_S	et	f	\N
152795	skytre	?skytre =skytre  (IndPrPs_  >skytrema !27_V	et	f	\N
152796	skytre	?skytre =skytre  (ImpPrSg2  >skytrema !27_V	et	f	\N
152817	depositsioon	?depositsioon =depositsioon  (SgN  >depositsioon !22_S	et	f	\N
152831	harinud	harinud =hari  (PtsPtPs  >harima !27_V	et	f	\N
152832	harinud	harinud =harinu  (PlN  >harinu !01_S	et	f	\N
152833	harinud	"harinu %hari  )NU_vS  <harima ;27_V	et	f	\N
152834	harinud	harinud =harinud  (ID  >harinud !41_A	et	f	\N
152835	harinud	"harinud %hari  )NUD_vA  <harima ;27_V	et	f	\N
152841	tõrva	tõrva =tõrva  (SgG  >tõrv !22_S	et	f	\N
152842	tõrva	tõrva =tõrva  (SgP  >tõrv !22_S	et	f	\N
152843	tõrva	tõrva =tõrva  (SgAdt  >tõrv !22_S	et	f	\N
152844	tõrva	tõrva =tõrva  (IndPrPs_  >tõrvama !29_V	et	f	\N
152845	tõrva	tõrva =tõrva  (ImpPrSg2  >tõrvama !29_V	et	f	\N
152849	vaimalik	?vaimalik =vaimalik  (SgN  >vaimalik !25_A	et	f	\N
152850	vaimalik	?vaimalik =alik  (SgN  >vaim+alik !02_S	et	f	\N
152852	kingseppad	?kingseppad =kingseppa  (PlN  >kingseppa !01_S	et	f	\N
152860	1583a	### 1583a	et	f	\N
152877	õigusteaduskonnas	õigusteaduskonnas =konna  (SgIn  >õigus+teadus+konn !22_S	et	f	\N
152878	õigusteaduskonnas	õigusteaduskonnas =teaduskonna  (SgIn  >õigus+teaduskond !22_S	et	f	\N
152888	toetusele	toetusele =toetuse  (SgAll  >toetus !11~09_S	et	f	\N
152889	toetusele	"toetus %toeta  )US_vS  <toetama ;27_V	et	f	\N
152890	toetusele	"toetus %toe  )TUS2_aS  <tugi ;21_S	et	f	\N
152903	protessorid	?protessorid =protessori  (PlN  >protessor !02_S	et	f	\N
152913	nutikamad	nutikamad =nutikama  (PlN  >nutikam !02_A	et	f	\N
152914	nutikamad	"nutikam %nutika  )M_cA  <nutikas ;02_A	et	f	\N
152915	19saj	### 19saj	et	f	\N
152953	türnpuu	türnpuu =puu  (SgN  >türn+puu !26_S	et	f	\N
152956	türnpuu	türnpuu =puu  (SgG  >türn+puu !26_S	et	f	\N
152984	kirikuisa	kirikuisa =isa  (SgN  >kiriku+isa !17_S	et	f	\N
152985	kirikuisa	kirikuisa =isa  (SgG  >kiriku+isa !17_S	et	f	\N
152986	kirikuisa	kirikuisa =isa  (SgP  >kiriku+isa !17_S	et	f	\N
153034	kannatuse	kannatuse =kannatuse  (SgG  >kannatus !11_S	et	f	\N
153035	kannatuse	"kannatus %kannata  )US_vS  <kannatama ;27_V	et	f	\N
153036	kannatuse	"kannatus %kanna  )TUS2_aS  <kanna ;16_S	et	f	\N
153037	kannatuse	"kannatus %kanna  )TUS2_aS  <kand ;22_S	et	f	\N
153038	hakksid	?hakksid =hakksi  (PlN  >hakks !22_S	et	f	\N
153039	hakksid	?hakksid =hakksi  (IndPrSg2  >hakksima !28_V	et	f	\N
153047	põlludel	?põlludel =põllu  (PlAd  >põllu !16_S	et	f	\N
153059	loodusjõud	loodusjõud =jõu  (PlN  >loodus+jõud !22_S	et	f	\N
153060	loodusjõud	loodusjõud =jõud  (SgN  >loodus+jõud !22_S	et	f	\N
153066	esivanemaid	esivanemaid =vanema  (PlP  >esi+vanem !02_AS	et	f	\N
153067	esivanemaid	"esi+vanem %vane  )M_cA  <esi+vana ;17_AS	et	f	\N
153072	tervendavatesse	tervendavatesse =tervendava  (PlIll  >tervendav !02_A	et	f	\N
153074	tervendavatesse	"tervendav %tervenda  )V_vA  <tervendama ;27_V	et	f	\N
153095	auke	auke =auke  (SgN  >auke !12?10_S	et	f	\N
153097	auke	"auke %au  )KE_dS  <au ;26_S	et	f	\N
153098	auke	auke =auke  (PlP  >auk !22_S	et	f	\N
153111	levitajatelt	levitajatelt =levitaja  (PlAbl  >levitaja !01_S	et	f	\N
153113	levitajatelt	"levitaja %levita  )JA_vS  <levitama ;27_V	et	f	\N
152676	tarkuse	"tarkus %tark  )US_aS  <tark ;22_AS	et	f	\N
152677	tarkuse	tarkuse =tarkuse  (SgG  >tarkune !12~10_A	et	f	\N
152686	riides	riides =riide  (SgIn  >riie !06_S	et	f	\N
152687	riides	riides =riides  (ID  >riides !41_DA	et	f	\N
152708	venelastega	venelastega =venelas  (PlKom  >venelane !12_S	et	f	\N
152709	venelastega	venelastega =las  (PlKom  >vene+laps !14_S	et	f	\N
152710	venalasi	?venalasi =venalasi  (PlP  >venalane !12_S	et	f	\N
152714	proektile	?proektile =proekti  (SgAll  >proekt !22_S	et	f	\N
152715	proektile	?proektile =proektile  (IndPrPs_  >proektilema !27_V	et	f	\N
152716	proektile	?proektile =proektile  (ImpPrSg2  >proektilema !27_V	et	f	\N
152726	shampoonil	?shampoonil =shampooni  (SgAd  >shampooni !16_S	et	f	\N
152727	shampoonil	?shampoonil =shampooni  (SgAd  >shampoon !22_S	et	f	\N
152744	mitmekesist	?mitmekesist =mitmekesi  (PlEl  >mitmeke !12_S	et	f	\N
152745	mitmekesist	?mitmekesist =mitmekesi  (PlEl  >mitmekene !12_S	et	f	\N
152746	mitmekesist	?mitmekesist =mitmekesis  (SgP  >mitmekesis !09_S	et	f	\N
152747	mitmekesist	?mitmekesist =mitmekesist  (SgN  >mitmekesist !22_S	et	f	\N
152748	teatrikaaslastega	teatrikaaslastega =las  (PlKom  >teatri+kaas+laps !14_S	et	f	\N
152749	teatrikaaslastega	teatrikaaslastega =kaaslas  (PlKom  >teatri+kaaslane !12?10_S	et	f	\N
152774	gümnaasiumisi	?gümnaasiumisi =gümnaasiumisi  (ID  >gümnaasiumisi !41_D	et	f	\N
152775	triviaalkoolis	?triviaalkoolis =triviaalkooli  (SgIn  >triviaalkooli !16_S	et	f	\N
152776	triviaalkoolis	?triviaalkoolis =triviaalkooli  (SgIn  >triviaalkool !22_S	et	f	\N
152777	triviaalkoolis	?triviaalkoolis =triviaalkooli  (IndIpfSg3  >triviaalkoolima !28_V	et	f	\N
152778	triviaalkoolis	?triviaalkoolis =triviaalkoolis  (SgN  >triviaalkoolis !09_S	et	f	\N
152807	nõutud	nõutud =nõu  (PtsPtIps  >nõudma !34_V	et	f	\N
152808	nõutud	nõutud =nõutu  (PlN  >nõutu !01_AS	et	f	\N
152809	nõutud	"nõutu %nõu  )TU1_vS  <nõudma ;34_V	et	f	\N
152810	nõutud	"nõutu %nõu  )TU2_kA  <nõu ;26_S	et	f	\N
152811	nõutud	nõutud =nõutud  (ID  >nõutud !41_A	et	f	\N
152812	nõutud	"nõutud %nõu  )TUD_vA  <nõudma ;34_V	et	f	\N
152818	rebaseks	rebaseks =rebase  (SgTr  >rebane !10_S	et	f	\N
152819	rebaseks	"rebane %reba  )NE_aA  <reba ;17_S	et	f	\N
152836	üliõpilas	?üliõpilas =üliõpila  (SgIn  >üliõpila !01_S	et	f	\N
152837	üliõpilas	?üliõpilas =õpila  (SgIn  >üli+õpila !01_S	et	f	\N
152846	meremeeste	meremeeste =mees  (PlG  >mere+meene !10_A	et	f	\N
152847	meremeeste	"mere+meene %mee  )NE_aA  <mere+mesi ;15_S	et	f	\N
152848	meremeeste	meremeeste =mees  (PlG  >mere+mees !13_S	et	f	\N
152891	stependiumi	?stependiumi =stependiumi  (SgN  >stependiumi !16_S	et	f	\N
152892	stependiumi	?stependiumi =stependiumi  (SgG  >stependium !19~02_S	et	f	\N
152893	stependiumi	?stependiumi =stependiumi  (SgG  >stependiumi !16_S	et	f	\N
152894	stependiumi	?stependiumi =stependiumi  (SgP  >stependium !19_S	et	f	\N
152895	stependiumi	?stependiumi =stependiumi  (SgAdt  >stependium !19_S	et	f	\N
152896	stependiumi	?stependiumi =stependiumi  (IndPrPs_  >stependiumima !28_V	et	f	\N
152897	stependiumi	?stependiumi =stependiumi  (ImpPrSg2  >stependiumima !28_V	et	f	\N
152898	stependiumi	?stependiumi =endiumi  (SgN  >step+endiumi !16_S	et	f	\N
152899	stependiumi	?stependiumi =endiumi  (SgG  >step+endium !19~02_S	et	f	\N
152900	stependiumi	?stependiumi =endiumi  (SgG  >step+endiumi !16_S	et	f	\N
152901	stependiumi	?stependiumi =endiumi  (SgP  >step+endium !19_S	et	f	\N
152902	stependiumi	?stependiumi =endiumi  (SgAdt  >step+endium !19_S	et	f	\N
152906	1816a	### 1816a	et	f	\N
152907	pandma	?pandma =pandma  (IndPrPs_  >pandmama !29_V	et	f	\N
152909	pandma	?pandma =pandma  (ImpPrSg2  >pandmama !29_V	et	f	\N
152923	1860a-	### 1860a-	et	f	\N
152947	silmatorkavamad	silmatorkavamad =torkavama  (PlN  >silma+torkavam !02_A	et	f	\N
152948	silmatorkavamad	"silma+torkavam %torkava  )M_cA  <silma+torkav ;02_A	et	f	\N
152949	ahrensit	?ahrensit =ahrensi  (SgP  >ahrensi !01_S	et	f	\N
152950	ahrensit	?ahrensit =ahrensi  (SgP  >ahrens !02_S	et	f	\N
152962	koostaja	koostaja =koostaja  (SgN  >koostaja !01_S	et	f	\N
152963	koostaja	"koostaja %koosta  )JA_vS  <koostama ;27_V	et	f	\N
152964	koostaja	koostaja =koostaja  (SgG  >koostaja !01_S	et	f	\N
152967	õnnele	õnnele =õnne  (SgAll  >õnn !22_S	et	f	\N
152968	õnnele	õnnele =õnne  (PlAll  >õnn !22_S	et	f	\N
152978	romantismi	romantismi =romantismi  (SgG  >romantism !22_S	et	f	\N
152979	romantismi	romantismi =romantismi  (SgP  >romantism !22_S	et	f	\N
152980	romantismi	romantismi =romantismi  (SgAdt  >romantism !22_S	et	f	\N
152981	radikaalseim	radikaalseim =radikaalseim  (SgN  >radikaalseim !02_A	et	f	\N
152982	radikaalseim	"radikaalseim %radikaalse  )IM_sA  <radikaalne ;02_A	et	f	\N
152983	radikaalseim	radikaalseim =seim  (SgN  >radikaal+seim !22_S	et	f	\N
152987	jakobsoniga	?jakobsoniga =jakobsoni  (SgKom  >jakobson !19_S	et	f	\N
152988	kunileid	?kunileid =kunilei  (PlN  >kunilei !26_S	et	f	\N
152989	kunileid	?kunileid =kunilei  (SgP  >kunilei !26_S	et	f	\N
152990	luuletuste	luuletuste =luuletus  (PlG  >luuletus !11_S	et	f	\N
152991	luuletuste	"luuletus %luuleta  )US_vS  <luuletama ;27_V	et	f	\N
152992	luuletuste	"luuletus %luule  )TUS2_aS  <luule ;06_S	et	f	\N
152993	luuletuste	luuletuste =tuste  (PlP  >luule+tust !22_S	et	f	\N
152799	saagist	saagist =saagi  (SgEl  >saak !22_S	et	f	\N
152800	saagist	saagist =saagis  (SgP  >saagis !09_S	et	f	\N
152803	paasil	?paasil =paasi  (SgAd  >paasi !16_S	et	f	\N
152820	löömine	löömine =löömine  (SgN  >löömine !12?10_S	et	f	\N
152821	löömine	"löömine %löö  )MINE_vS  <lööma ;38_V	et	f	\N
152822	löömine	"löömine %löömi  )NE_aA  <lööm ;22_S	et	f	\N
152838	valdavaks	valdavaks =valdava  (SgTr  >valdav !02_A	et	f	\N
152839	valdavaks	"valdav %valda  )V_vA  <valdama ;29_V	et	f	\N
152840	valdavaks	valdavaks =ava  (SgTr  >vald+ava !17_S	et	f	\N
152869	anoloogne	?anoloogne =anoloogne  (SgN  >anoloogne !02_A	et	f	\N
152870	anoloogne	?anoloogne =anoloogne  (PlP  >anoloogn !22_S	et	f	\N
152872	klassilis	?klassilis =klassilis  (SgN  >klassilis !11_S	et	f	\N
152874	pidulikult	pidulikult =piduliku  (SgAbl  >pidulik !25_A	et	f	\N
152875	pidulikult	pidulikult =pidulikult  (ID  >pidulikult !41_D	et	f	\N
152876	pidulikult	"pidulikult %piduliku  )LT_mD  <pidulik ;25_A	et	f	\N
152883	1680a	### 1680a	et	f	\N
152916	kartulist	kartulist =kartuli  (SgEl  >kartul !02_S	et	f	\N
152917	kartulist	kartulist =kartulis  (SgP  >kartuline !12_A	et	f	\N
152918	kartulist	"kartuline %kartuli  )NE_aA  <kartul ;02_S	et	f	\N
152922	1840a	### 1840a	et	f	\N
152924	tikke	tikke =tikke  (SgG  >tike !06_S	et	f	\N
152925	tikke	tikke =tikke  (PlP  >tikk !22_S	et	f	\N
152929	vahetanud	vahetanud =vaheta  (PtsPtPs  >vahetama !27_V	et	f	\N
152930	vahetanud	vahetanud =vahetanu  (PlN  >vahetanu !01_S	et	f	\N
152931	vahetanud	"vahetanu %vaheta  )NU_vS  <vahetama ;27_V	et	f	\N
152932	vahetanud	vahetanud =vahetanud  (ID  >vahetanud !41_A	et	f	\N
152933	vahetanud	"vahetanud %vaheta  )NUD_vA  <vahetama ;27_V	et	f	\N
152934	vahetanud	vahetanud =tanu  (PlN  >vahe+tanu !17_S	et	f	\N
152935	ilmalikuteks	?ilmalikuteks =ilmalikute  (PlTr  >ilmalikutt !22_S	et	f	\N
152936	ilmalikuteks	?ilmalikuteks =aliku  (PlTr  >ilm+aliku !01_S	et	f	\N
152937	ilmalikuteks	?ilmalikuteks =aliku  (PlTr  >ilm+alik !02_S	et	f	\N
152938	ilmalikuteks	?ilmalikuteks =alikute  (PlTr  >ilm+alikutt !22_S	et	f	\N
152951	kunileud	?kunileud =kunileu  (PlN  >kunileu !26_S	et	f	\N
152955	kunileud	?kunileud =kunileu  (SgP  >kunileu !26_S	et	f	\N
152958	kunileud	?kunileud =kunileud  (SgN  >kunileud !22_S	et	f	\N
152965	ellujäämisele	ellujäämisele =jäämise  (SgAll  >ellu+jäämine !12?10_S	et	f	\N
152966	ellujäämisele	"ellu+jäämine %jäämi  )NE_aA  <ellu+jääm ;22_S	et	f	\N
152976	tähtsamate	tähtsamate =tähtsama  (PlG  >tähtsam !02_A	et	f	\N
152977	tähtsamate	"tähtsam %tähtsa  )M_cA  <tähtis ;02_A	et	f	\N
152994	wiedelmann	?wiedelmann =wiedelmann  (SgN  >wiedelmann !22_S	et	f	\N
153001	võrdlust	võrdlust =võrdlus  (SgP  >võrdlus !11~09_S	et	f	\N
153002	võrdlust	võrdlust =lust  (SgN  >võrd+lust !22_S	et	f	\N
153048	sapiens	?sapiens =sapiens  (SgN  >sapiens !22_S	et	f	\N
153049	sapiens	?sapiens =ens  (SgN  >sapi+ens !22_S	et	f	\N
153053	arheoloogilised	arheoloogilised =arheoloogilise  (PlN  >arheoloogiline !12_A	et	f	\N
153054	arheoloogilised	"arheoloogiline %arheoloogi  )LINE_aA  <arheoloog ;22_S	et	f	\N
153077	tervendava	tervendava =tervendava  (SgG  >tervendav !02_A	et	f	\N
153078	tervendava	"tervendav %tervenda  )V_vA  <tervendama ;27_V	et	f	\N
153106	rändavatelt	rändavatelt =rändava  (PlAbl  >rändav !02_A	et	f	\N
153108	rändavatelt	"rändav %rända  )V_vA  <rändama ;29_V	et	f	\N
153130	viljast	viljast =vilja  (SgEl  >vili !24_S	et	f	\N
153131	viljast	viljast =viljas  (SgP  >viljane !10_A	et	f	\N
153132	viljast	"viljane %vilja  )NE_aA  <vili ;24_S	et	f	\N
153140	suverukkist	suverukkist =rukki  (SgEl  >suve+rukis !07_S	et	f	\N
153141	suverukkist	suverukkist =rukkis  (SgP  >suve+rukkine !12~10_A	et	f	\N
153142	suverukkist	"suve+rukkine %rukki  )NE_aA  <suve+rukis ;07_S	et	f	\N
153153	õpitaja	?õpitaja =õpitaja  (SgN  >õpitaja !01_S	et	f	\N
153154	õpitaja	?õpitaja =õpitaja  (SgG  >õpitaja !01_S	et	f	\N
153155	õpitaja	?õpitaja =õpitaja  (SgG  >õpitajas !02_A	et	f	\N
153156	õpitaja	?õpitaja =taja  (SgN  >õpi+taja !17_S	et	f	\N
153157	õpitaja	?õpitaja =taja  (SgG  >õpi+taja !17_S	et	f	\N
153158	õpitaja	?õpitaja =taja  (SgP  >õpi+taja !17_S	et	f	\N
153160	elukutselt	elukutselt =kutse  (SgAbl  >elu+kutse !06_S	et	f	\N
153161	elukutselt	elukutselt =kutse  (PlAbl  >elu+kuts !22_S	et	f	\N
153167	sündind	?sündind =sündind  (SgN  >sündind !02_S	et	f	\N
153171	juhusest	juhusest =juhuse  (SgEl  >juhus !09_S	et	f	\N
153172	juhusest	juhusest =juhuses  (SgP  >juhusene !12_A	et	f	\N
153173	juhusest	"juhusene %juhuse  )NE_aA  <juhus ;09_S	et	f	\N
153174	tulevikut	?tulevikut =iku  (SgP  >tulev+iku !16_S	et	f	\N
153175	tulevikut	?tulevikut =ikut  (SgN  >tulev+ikut !02_S	et	f	\N
153176	tulevikut	?tulevikut =viku  (SgP  >tule+viku !16_S	et	f	\N
153177	tulevikut	?tulevikut =vikut  (SgN  >tule+vikut !02_S	et	f	\N
153188	tehnikumist	tehnikumist =tehnikumi  (SgEl  >tehnikum !19_S	et	f	\N
153189	tehnikumist	tehnikumist =tehnikumis  (SgP  >tehnikumine !12_S	et	f	\N
153190	tehnikumist	"tehnikumine %tehnikumi  )NE_aA  <tehnikum ;19_S	et	f	\N
153202	xxxxxxxxxx	### xxxxxxxxxx	et	f	\N
153206	rokkmuusika	rokkmuusika =muusika  (SgN  >rokk+muusika !01_S	et	f	\N
152827	harimatust	"harimatu %hari  )MATU_vA  <harima ;27_V	et	f	\N
152828	harimatust	harimatust =harimatus  (SgP  >harimatus !11?09_S	et	f	\N
152829	harimatust	"harimatus %hari  )MATUS_aS  <harima ;27_V	et	f	\N
152830	harimatust	harimatust =matus  (SgP  >hari+matus !09_S	et	f	\N
152851	mõisnikukule	?mõisnikukule =mõisnikukule  (PlP  >mõisnikukul !19_S	et	f	\N
152853	värvimine	värvimine =värvimine  (SgN  >värvimine !12_S	et	f	\N
152854	värvimine	"värvimine %värvi  )MINE_vS  <värvima ;28_V	et	f	\N
152861	kolitada	?kolitada =kolita  (Inf  >kolitama !27_V	et	f	\N
152863	kolitada	?kolitada =tada  (SgN  >koli+tada !17_S	et	f	\N
152865	kolitada	?kolitada =tada  (SgG  >koli+tada !17_S	et	f	\N
152867	kolitada	?kolitada =tada  (SgP  >koli+tada !17_S	et	f	\N
152871	3-	### 3-	et	f	\N
152881	usuteaduskonnas	usuteaduskonnas =konna  (SgIn  >usu+teadus+konn !22_S	et	f	\N
152882	usuteaduskonnas	usuteaduskonnas =teaduskonna  (SgIn  >usu+teaduskond !22_S	et	f	\N
152886	maksmisele	maksmisele =maksmise  (SgAll  >maksmine !12?10_S	et	f	\N
152887	maksmisele	"maksmine %maks  )MINE_vS  <maksma ;32_V	et	f	\N
152904	rebaste	rebaste =rebas  (PlG  >rebane !10_S	et	f	\N
152905	rebaste	"rebane %reba  )NE_aA  <reba ;17_S	et	f	\N
152911	mõisnukule	?mõisnukule =mõisnuku  (SgAll  >mõisnuku !01_S	et	f	\N
152912	mõisnukule	?mõisnukule =mõisnukule  (PlP  >mõisnukul !19_S	et	f	\N
152927	poed	poed =poe  (PlN  >pood !22_S	et	f	\N
152928	poed	poed =poe  (IndPrSg2  >pugema !28_V	et	f	\N
152952	wiedemanni	?wiedemanni =wiedemanni  (SgG  >wiedemann !22_S	et	f	\N
152954	wiedemanni	?wiedemanni =wiedemanni  (SgP  >wiedemann !22_S	et	f	\N
152957	wiedemanni	?wiedemanni =wiedemanni  (SgAdt  >wiedemann !22_S	et	f	\N
152959	wiedemanni	?wiedemanni =wiedemanni  (IndPrPs_  >wiedemannima !28_V	et	f	\N
152960	wiedemanni	?wiedemanni =wiedemanni  (ImpPrSg2  >wiedemannima !28_V	et	f	\N
152969	inspireerija	inspireerija =inspireerija  (SgN  >inspireerija !01_S	et	f	\N
152970	inspireerija	"inspireerija %inspireeri  )JA_vS  <inspireerima ;28_V	et	f	\N
152971	inspireerija	inspireerija =inspireerija  (SgG  >inspireerija !01_S	et	f	\N
152972	ühendaja	ühendaja =ühendaja  (SgN  >ühendaja !01_S	et	f	\N
152973	ühendaja	"ühendaja %ühenda  )JA_vS  <ühendama ;27_V	et	f	\N
152974	ühendaja	ühendaja =ühendaja  (SgG  >ühendaja !01_S	et	f	\N
152975	ühendaja	ühendaja =aja  (SgG  >ühend+aeg !22_S	et	f	\N
152995	vennastekoguduste	vennastekoguduste =duste  (PlP  >vennaste+kogu+dust !22_S	et	f	\N
152996	vennastekoguduste	vennastekoguduste =kogudus  (PlG  >vennaste+kogudus !11_S	et	f	\N
153003	valgustamine	valgustamine =valgustamine  (SgN  >valgustamine !12_S	et	f	\N
153004	valgustamine	"valgustamine %valgusta  )MINE_vS  <valgustama ;27_V	et	f	\N
153011	sdas	### sdas	et	f	\N
153018	kivikalmedesse	?kivikalmedesse =kivikalmedes  (SgAdt  >kivikalmedene !12_A	et	f	\N
153019	kivikalmedesse	?kivikalmedesse =kivikalmedesse  (SgG  >kivikalmedesne !02_A	et	f	\N
153020	kivikalmedesse	?kivikalmedesse =kivikalmedesse  (PlP  >kivikalmedess !22_S	et	f	\N
153021	kivikalmedesse	?kivikalmedesse =kalmedes  (SgAdt  >kivi+kalmedene !12_A	et	f	\N
153022	kivikalmedesse	?kivikalmedesse =kalmedesse  (SgG  >kivi+kalmedesne !02_A	et	f	\N
153023	kivikalmedesse	?kivikalmedesse =kalmedesse  (PlP  >kivi+kalmedess !22_S	et	f	\N
153027	allikavesi	allikavesi =vesi  (SgN  >allika+vesi !15_S	et	f	\N
153028	allikavesi	allikavesi =vesi  (PlP  >allika+vesi !15_S	et	f	\N
153051	arheoloogilisi	arheoloogilisi =arheoloogilisi  (PlP  >arheoloogiline !12_A	et	f	\N
153052	arheoloogilisi	"arheoloogiline %arheoloogi  )LINE_aA  <arheoloog ;22_S	et	f	\N
153055	võhandu	?võhandu =võhandu  (SgN  >võhandu !01_S	et	f	\N
153056	võhandu	?võhandu =võhandu  (SgG  >võhandu !01_S	et	f	\N
153057	võhandu	?võhandu =võhandu  (IndPrPs_  >võhanduma !27_V	et	f	\N
153058	võhandu	?võhandu =võhandu  (ImpPrSg2  >võhanduma !27_V	et	f	\N
153061	iseloomustavaks	iseloomustavaks =vaks  (SgN  >ise+loo+musta+vaks !22_S	et	f	\N
153062	iseloomustavaks	iseloomustavaks =ava  (SgTr  >ise+loo+must+ava !17_S	et	f	\N
153063	iseloomustavaks	iseloomustavaks =ustava  (SgTr  >ise+loom+ustav !02_A	et	f	\N
153064	iseloomustavaks	iseloomustavaks =mustava  (SgTr  >ise+loo+mustav !02_A	et	f	\N
153065	iseloomustavaks	iseloomustavaks =loomustava  (SgTr  >ise+loomustav !02_A	et	f	\N
153073	maagilistesse	maagilistesse =maagilis  (PlIll  >maagiline !12_A	et	f	\N
153075	maagilistesse	"maagiline %maagi  )LINE_aA  <maag ;22_S	et	f	\N
153076	maagilistesse	"maagiline %maagi  )LINE_aA  <maak ;22_S	et	f	\N
153107	mungadelt	?mungadelt =munga  (PlAbl  >munga !16_S	et	f	\N
153109	mungadelt	?mungadelt =mungadelt  (ID  >mungadelt !41_D	et	f	\N
153127	toitusid	toitusid =toitu  (PlP  >toit !22_S	et	f	\N
153128	toitusid	toitusid =toitu  (IndIpfSg2  >toituma !27_V	et	f	\N
153129	toitusid	toitusid =toitu  (IndIpfPl3  >toituma !27_V	et	f	\N
153133	jahtimisest	jahtimisest =jahtimise  (SgEl  >jahtimine !12_S	et	f	\N
153134	jahtimisest	"jahtimine %jahti  )MINE_vS  <jahtima ;28_V	et	f	\N
153143	talverukkist	talverukkist =rukki  (SgEl  >talve+rukis !07_S	et	f	\N
153144	talverukkist	talverukkist =rukkis  (SgP  >talve+rukkine !12~10_A	et	f	\N
153145	talverukkist	"talve+rukkine %rukki  )NE_aA  <talve+rukis ;07_S	et	f	\N
153147	kasvatatud	kasvatatud =kasvata  (PtsPtIps  >kasvatama !27_V	et	f	\N
153148	kasvatatud	kasvatatud =kasvatatu  (PlN  >kasvatatu !01_S	et	f	\N
152997	alandlikkust	alandlikkust =alandlikkus  (SgP  >alandlikkus !11~09_S	et	f	\N
152998	alandlikkust	"alandlikkus %alandlikku  )US_aS  <alandlik ;25_A	et	f	\N
153012	13saj	### 13saj	et	f	\N
153013	ohverdanud	ohverdanud =ohverda  (PtsPtPs  >ohverdama !27_V	et	f	\N
153014	ohverdanud	ohverdanud =ohverdanu  (PlN  >ohverdanu !01_S	et	f	\N
153015	ohverdanud	"ohverdanu %ohverda  )NU_vS  <ohverdama ;27_V	et	f	\N
153016	ohverdanud	ohverdanud =ohverdanud  (ID  >ohverdanud !41_A	et	f	\N
153017	ohverdanud	"ohverdanud %ohverda  )NUD_vA  <ohverdama ;27_V	et	f	\N
153024	millesegi	?millesegi =millese  (SgG^  >millene !10_A	et	f	\N
153025	puhasvesi	puhasvesi =vesi  (SgN  >puhas+vesi !15_S	et	f	\N
153026	puhasvesi	puhasvesi =vesi  (PlP  >puhas+vesi !15_S	et	f	\N
153029	ristist	ristist =risti  (SgEl  >risti !16_S	et	f	\N
153030	ristist	ristist =risti  (SgEl  >rist !22_S	et	f	\N
153031	ristist	ristist =ristis  (SgP  >ristine !12~10_A	et	f	\N
153032	ristist	"ristine %risti  )NE_aA  <risti ;16_S	et	f	\N
153033	ristist	"ristine %risti  )NE_aA  <rist ;22_S	et	f	\N
153040	rajuti	?rajuti =raju  (IndIpfIps  >rajuma !27_V	et	f	\N
153041	rajuti	?rajuti =rajuti  (SgN  >rajuti !01_S	et	f	\N
153042	rajuti	?rajuti =rajuti  (SgG  >rajuti !01_S	et	f	\N
153043	rajuti	?rajuti =rajuti  (SgG  >rajut !02_S	et	f	\N
153044	rajuti	?rajuti =rajuti  (SgG  >rajutt !22_S	et	f	\N
153045	rajuti	?rajuti =rajuti  (IndPrPs_  >rajuttima !28_V	et	f	\N
153046	rajuti	?rajuti =rajuti  (ImpPrSg2  >rajuttima !28_V	et	f	\N
153050	religiosusega	?religiosusega =religiosuse  (SgKom  >religiosus !11~09_S	et	f	\N
153178	aaaaaa	?aaaaaa =aaaaaa  (SgN  >aaaaaa !26_S	et	f	\N
153179	aaaaaa	?aaaaaa =aaaaaa  (SgG  >aaaaaa !26_S	et	f	\N
153181	ahtme	?ahtme =ahtme  (SgN  >ahtme !06_S	et	f	\N
153182	ahtme	?ahtme =ahtme  (SgG  >ahtme !06_S	et	f	\N
153183	ahtme	?ahtme =ahtme  (PlP  >ahtm !22_S	et	f	\N
153184	ahtme	?ahtme =ahtme  (IndPrPs_  >ahtmema !27_V	et	f	\N
153185	ahtme	?ahtme =ahtme  (ImpPrSg2  >ahtmema !27_V	et	f	\N
153186	kuulamisega	kuulamisega =kuulamise  (SgKom  >kuulamine !12_S	et	f	\N
153187	kuulamisega	"kuulamine %kuula  )MINE_vS  <kuulama ;29_V	et	f	\N
153191	xxxxxx	### xxxxxx	et	f	\N
153192	xxxxx	### xxxxx	et	f	\N
153193	arutluseid	?arutluseid =arutlusei  (PlN  >arutlusei !26_S	et	f	\N
153194	arutluseid	?arutluseid =arutlusei  (SgP  >arutlusei !26_S	et	f	\N
153195	arutluseid	?arutluseid =eid  (SgN  >arutlus+eid !22_S	et	f	\N
153203	filosofia	?filosofia =filosofia  (SgN  >filosofia !01_S	et	f	\N
153204	filosofia	?filosofia =filosofia  (SgG  >filosofia !01_S	et	f	\N
153229	rariot	?rariot =rario  (SgP  >rario !01_S	et	f	\N
153230	rariot	?rariot =rariot  (SgN  >rariot !22_S	et	f	\N
153242	rahus	rahus =rahu  (SgIn  >rahu !17_S	et	f	\N
153243	rahus	rahus =rahu  (PlIn  >rahk !22_S	et	f	\N
153274	luuletajal	luuletajal =luuletaja  (SgAd  >luuletaja !01_S	et	f	\N
153275	luuletajal	"luuletaja %luuleta  )JA_vS  <luuletama ;27_V	et	f	\N
153282	kohtumisi	kohtumisi =kohtumisi  (PlP  >kohtumine !12_S	et	f	\N
153283	kohtumisi	"kohtumine %kohtu  )MINE_vS  <kohtuma ;27_V	et	f	\N
153300	pangas	pangas =panga  (SgIn  >pank !22_S	et	f	\N
153301	pangas	pangas =pangas  (SgN  >pangas !07_S	et	f	\N
153312	vanus	vanus =vanu  (PlIn  >vana !17_AS	et	f	\N
153313	vanus	vanus =vanu  (IndIpfSg3  >vanuma !27_V	et	f	\N
153314	vanus	vanus =vanus  (SgN  >vanus !09_S	et	f	\N
153315	ebatähtsam	ebatähtsam =tähtsam  (SgN  >eba+tähtsam !02_A	et	f	\N
153316	ebatähtsam	"eba+tähtsam %tähtsa  )M_cA  <eba+tähtis ;02_A	et	f	\N
153318	igaüksi	igaüksi =üksi  (SgG  >iga+üks !22_P	et	f	\N
153319	igaüksi	igaüksi =üksi  (SgP  >iga+üks !22_P	et	f	\N
153320	igaüksi	igaüksi =üksi  (SgAdt  >iga+üks !22_P	et	f	\N
153321	igaüksi	igaüksi =üksi  (PlP  >iga+üks !22_P	et	f	\N
153329	rääkimisega	rääkimisega =rääkimise  (SgKom  >rääkimine !12_S	et	f	\N
153330	rääkimisega	"rääkimine %rääki  )MINE_vS  <rääkima ;28_V	et	f	\N
153333	inspiraatsion	?inspiraatsion =inspiraatsion  (SgN  >inspiraatsion !19~02_S	et	f	\N
153337	lugelda	?lugelda =lugel  (Inf  >lugelema !31_V	et	f	\N
153338	lugelda	?lugelda =lugel  (IndPrIps_  >lugelema !31_V	et	f	\N
153339	lugelda	?lugelda =lugelda  (IndPrPs_  >lugeldama !27_V	et	f	\N
153340	lugelda	?lugelda =lugelda  (ImpPrSg2  >lugeldama !27_V	et	f	\N
153356	pesu-	pesu- =pesu  (SgN  >pesu !17_S	et	f	\N
153357	pesu-	pesu- =pesu  (SgG  >pesu !17_S	et	f	\N
153358	pesu-	pesu- =pesu  (SgP  >pesu !17_S	et	f	\N
153371	kuivada	kuivada =kuiva  (Inf  >kuivama !28_V	et	f	\N
153372	kuivada	kuivada =vada  (SgN  >kui+vada !17_S	et	f	\N
153373	kuivada	kuivada =vada  (SgG  >kui+vada !17_S	et	f	\N
153374	kuivada	kuivada =vada  (SgP  >kui+vada !17_S	et	f	\N
153381	valitsevad	valitsevad =valitse  (IndPrPl3  >valitsema !27_V	et	f	\N
153382	valitsevad	valitsevad =valitseva  (PlN  >valitsev !02_A	et	f	\N
153383	valitsevad	"valitsev %valitse  )V_vA  <valitsema ;27_V	et	f	\N
153405	tahtetu	tahtetu =tahtetu  (SgN  >tahtetu !01_A	et	f	\N
153406	tahtetu	"tahtetu %tahte  )TU2_kA  <tahe ;06_S	et	f	\N
153407	tahtetu	tahtetu =tahtetu  (SgG  >tahtetu !01_A	et	f	\N
153069	ristikujulisi	"ristik+ujuline %uju  )LINE_aA  <ristik+uju ;17_S	et	f	\N
153070	ristikujulisi	ristikujulisi =kujulisi  (PlP  >risti+kujuline !12_A	et	f	\N
153071	ristikujulisi	"risti+kujuline %kuju  )LINE_aA  <risti+kuju ;17_S	et	f	\N
153079	maavälisse	?maavälisse =maaväli  (SgIll  >maaväli !01_S	et	f	\N
153080	maavälisse	?maavälisse =maaväli  (SgIll  >maaväl !02_S	et	f	\N
153081	maavälisse	?maavälisse =maavälis  (SgAdt  >maavälis !11_S	et	f	\N
153082	maavälisse	?maavälisse =maavälis  (SgAdt  >maaväline !12_A	et	f	\N
153083	maavälisse	?maavälisse =maavälisse  (SgG  >maavälisne !02_A	et	f	\N
153084	maavälisse	?maavälisse =maavälisse  (PlP  >maaväliss !22_S	et	f	\N
153085	maavälisse	?maavälisse =välisse  (SgG  >maa+välisne !02_A	et	f	\N
153086	maavälisse	?maavälisse =välisse  (PlP  >maa+väliss !22_S	et	f	\N
153087	millestesse	?millestesse =milles  (PlIll  >milles !09_S	et	f	\N
153088	millestesse	?millestesse =milles  (PlIll  >millene !10_A	et	f	\N
153089	millestesse	?millestesse =millestes  (SgAdt  >millestene !12_A	et	f	\N
153090	millestesse	?millestesse =millestesse  (SgG  >millestesne !02_A	et	f	\N
153091	millestesse	?millestesse =millestesse  (PlP  >millestess !22_S	et	f	\N
153092	millestesse	?millestesse =stesse  (SgN  >mille+stesse !06_S	et	f	\N
153093	millestesse	?millestesse =stesse  (SgG  >mille+stesne !02_A	et	f	\N
153094	millestesse	?millestesse =stesse  (SgG  >mille+stesse !06_S	et	f	\N
153096	millestesse	?millestesse =stesse  (PlP  >mille+stess !22_S	et	f	\N
153099	vikingi	?vikingi =vikingi  (SgG  >viking !02_S	et	f	\N
153100	vikingi	?vikingi =vikingi  (SgG  >vikink !22_S	et	f	\N
153101	vikingi	?vikingi =vikingi  (IndPrPs_  >vikinkima !28_V	et	f	\N
153102	vikingi	?vikingi =vikingi  (ImpPrSg2  >vikinkima !28_V	et	f	\N
153103	vikingi	?vikingi =viki  (IndPrSg1^  >vikima !27_V	et	f	\N
153104	vikingi	?vikingi =viki  (IndPrSg1^  >vikkima !28_V	et	f	\N
153105	vikingi	?vikingi =vikin  (SgN^  >vikin !02_S	et	f	\N
153110	religiooni	religiooni =religiooni  (SgG  >religioon !22_S	et	f	\N
153112	religiooni	religiooni =religiooni  (SgP  >religioon !22_S	et	f	\N
153114	religiooni	religiooni =religiooni  (SgAdt  >religioon !22_S	et	f	\N
153122	ehtimine	ehtimine =ehtimine  (SgN  >ehtimine !12_S	et	f	\N
153123	ehtimine	"ehtimine %ehti  )MINE_vS  <ehtima ;27_V	et	f	\N
153124	ehtimine	"ehtimine %ehti  )MINE_vS  <ehtima ;28_V	et	f	\N
153135	jaotatud	jaotatud =jaota  (PtsPtIps  >jaotama !27_V	et	f	\N
153136	jaotatud	jaotatud =jaotatu  (PlN  >jaotatu !01_S	et	f	\N
153137	jaotatud	"jaotatu %jaota  )TU1_vS  <jaotama ;27_V	et	f	\N
153138	jaotatud	jaotatud =jaotatud  (ID  >jaotatud !41_A	et	f	\N
153139	jaotatud	"jaotatud %jaota  )TUD_vA  <jaotama ;27_V	et	f	\N
153146	osat	?osat =osat  (SgN  >osat !02_S	et	f	\N
153169	sünnikohta	sünnikohta =kohta  (SgP  >sünni+koht !22_S	et	f	\N
153170	sünnikohta	sünnikohta =kohta  (SgAdt  >sünni+koht !22_S	et	f	\N
153180	xxxxxxxx	### xxxxxxxx	et	f	\N
153197	soldino	?soldino =soldino  (SgN  >soldino !01_S	et	f	\N
153198	soldino	?soldino =soldino  (SgG  >soldino !01_S	et	f	\N
153199	oluliseim	?oluliseim =oluliseim  (SgN  >oluliseim !02_A	et	f	\N
153205	xxxxxxxxxxxxx	### xxxxxxxxxxxxx	et	f	\N
153240	faktorei	?faktorei =faktorei  (SgN  >faktorei !26_S	et	f	\N
153241	faktorei	?faktorei =faktorei  (SgG  >faktorei !26_S	et	f	\N
153245	mutuks	?mutuks =mutu  (SgTr  >mutu !16_S	et	f	\N
153246	mutuks	?mutuks =mutu  (KndPrPs  >mutuma !27_V	et	f	\N
153257	lõpetaseks	?lõpetaseks =lõpetase  (SgTr  >lõpetane !12_A	et	f	\N
153264	müüjaga	müüjaga =müüja  (SgKom  >müüja !01_S	et	f	\N
153265	müüjaga	"müüja %müü  )JA_vS  <müüma ;38_V	et	f	\N
153266	potile	potile =poti  (SgAll  >poti !16_S	et	f	\N
153267	potile	potile =poti  (SgAll  >pott !22_S	et	f	\N
153276	loominguliseid	?loominguliseid =loomingulisei  (PlN  >loomingulisei !26_S	et	f	\N
153277	loominguliseid	?loominguliseid =loomingulisei  (SgP  >loomingulisei !26_S	et	f	\N
153278	loominguliseid	?loominguliseid =ingulisei  (PlN  >loom+ingulisei !26_S	et	f	\N
153279	loominguliseid	?loominguliseid =ingulisei  (SgP  >loom+ingulisei !26_S	et	f	\N
153280	loominguliseid	?loominguliseid =mingulisei  (PlN  >loo+mingulisei !26_S	et	f	\N
153281	loominguliseid	?loominguliseid =mingulisei  (SgP  >loo+mingulisei !26_S	et	f	\N
153284	tagasihoidlikku	tagasihoidlikku =hoidlikku  (SgP  >tagasi+hoidlik !25_A	et	f	\N
153285	tagasihoidlikku	tagasihoidlikku =hoidlikku  (SgAdt  >tagasi+hoidlik !25_A	et	f	\N
153286	puudujääki	puudujääki =jääki  (SgP  >puudu+jääk !22_S	et	f	\N
153287	puudujääki	puudujääki =jääki  (SgAdt  >puudu+jääk !22_S	et	f	\N
153296	külalisse	külalisse =külalis  (SgAdt  >külaline !12_S	et	f	\N
153297	külalisse	"külaline %küla  )LINE_aA  <küla ;17_S	et	f	\N
153332	tasel	?tasel =tasel  (SgN  >tasel !02_S	et	f	\N
153347	1pange	pange =pan  (ImpPrPl2  >panema !36_V	et	f	\N
153348	1pange	pange =pange  (SgG  >pang !22_S	et	f	\N
153349	1pange	pange =pange  (SgP  >pang !22_S	et	f	\N
153350	1pange	pange =pange  (SgAdt  >pang !22_S	et	f	\N
153351	1pange	pange =pange  (PlP  >pang !22_S	et	f	\N
153361	seinakontakti	seinakontakti =kontakti  (SgG  >seina+kontakt !22_S	et	f	\N
153362	seinakontakti	seinakontakti =kontakti  (SgP  >seina+kontakt !22_S	et	f	\N
153115	ümbritsetud	ümbritsetud =ümbritse  (PtsPtIps  >ümbritsema !27_V	et	f	\N
153116	ümbritsetud	ümbritsetud =ümbritsetu  (PlN  >ümbritsetu !01_S	et	f	\N
153117	ümbritsetud	"ümbritsetu %ümbritse  )TU1_vS  <ümbritsema ;27_V	et	f	\N
153118	ümbritsetud	ümbritsetud =ümbritsetud  (ID  >ümbritsetud !41_A	et	f	\N
153119	ümbritsetud	"ümbritsetud %ümbritse  )TUD_vA  <ümbritsema ;27_V	et	f	\N
153120	muistseestlaste	?muistseestlaste =muistseestlas  (PlG  >muistseestlane !12?10_S	et	f	\N
153121	muistseestlaste	?muistseestlaste =muistseestlaste  (PlP  >muistseestlast !22_S	et	f	\N
153125	paeladega	paeladega =paela  (PlKom  >pael !22_S	et	f	\N
153126	paeladega	paeladega =la  (PlKom  >pae+la !26_S	et	f	\N
153162	kohtla-jarve	?kohtla-jarve =jarve  (SgN  >kohtla-jarve !06_S	et	f	\N
153163	kohtla-jarve	?kohtla-jarve =jarve  (SgG  >kohtla-jarve !06_S	et	f	\N
153164	kohtla-jarve	?kohtla-jarve =jarve  (PlP  >kohtla-jarv !22_S	et	f	\N
153165	kohtla-jarve	?kohtla-jarve =jarve  (IndPrPs_  >kohtla-jarvema !27_V	et	f	\N
153166	kohtla-jarve	?kohtla-jarve =jarve  (ImpPrSg2  >kohtla-jarvema !27_V	et	f	\N
153168	selstkond	?selstkond =selstkond  (SgN  >selstkond !22_S	et	f	\N
153196	xxxxxxx	### xxxxxxx	et	f	\N
153200	teadmiseid	teadmiseid =teadmise  (PlP  >teadmine !10_S	et	f	\N
153201	teadmiseid	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
153209	vääga	?vääga =vää  (SgKom  >vää !26_S	et	f	\N
153211	vääga	?vääga =vääga  (SgN  >vääga !16_S	et	f	\N
153213	vääga	?vääga =vääga  (SgG  >vääga !16_S	et	f	\N
153215	vääga	?vääga =vääga  (IndPrPs_  >väägama !29_V	et	f	\N
153217	vääga	?vääga =vääga  (ImpPrSg2  >väägama !29_V	et	f	\N
153220	mara	?mara =mara  (SgN  >mara !17_S	et	f	\N
153221	mara	?mara =mara  (SgG  >mara !17_S	et	f	\N
153222	mara	?mara =mara  (SgP  >mara !17_S	et	f	\N
153223	mara	?mara =mara  (IndPrPs_  >marama !27_V	et	f	\N
153224	mara	?mara =mara  (ImpPrSg2  >marama !27_V	et	f	\N
153226	horoskopid	?horoskopid =horoskopi  (PlN  >horoskopp !22_S	et	f	\N
153227	horoskopid	?horoskopid =horoskopi  (IndPrSg2  >horoskoppima !28_V	et	f	\N
153268	kaane	kaane =kaane  (SgG  >kaas !14_S	et	f	\N
153269	kaane	kaane =kaane  (PlP  >kaan !22_S	et	f	\N
153288	hilinejad	hilinejad =hilineja  (PlN  >hilineja !01_S	et	f	\N
153289	hilinejad	"hilineja %hiline  )JA_vS  <hilinema ;27_V	et	f	\N
153290	keeruliseid	?keeruliseid =keerulisei  (PlN  >keerulisei !26_S	et	f	\N
153291	keeruliseid	?keeruliseid =keerulisei  (SgP  >keerulisei !26_S	et	f	\N
153307	saatuses	saatuses =saatuse  (SgIn  >saatus !11~09_S	et	f	\N
153308	saatuses	saatuses =use  (PlIn  >saat+usk !22_S	et	f	\N
153310	süüniaeg	?süüniaeg =süüniaeg  (SgN  >süüniaeg !22_S	et	f	\N
153311	süüniaeg	?süüniaeg =niaeg  (SgN  >süü+niaeg !02_S	et	f	\N
153324	om	### om	et	f	\N
153325	tutvastega	?tutvastega =tutvas  (PlKom  >tutvas !07_S	et	f	\N
153326	tutvastega	?tutvastega =tutvas  (PlKom  >tutvane !12~10_A	et	f	\N
153327	rääkimisega	rääkimisega =rääkimise  (SgKom  >rääkimine !12_S	et	f	\N
153328	rääkimisega	"rääkimine %rääki  )MINE_vS  <rääkima ;28_V	et	f	\N
153344	kastavad	kastavad =kasta  (IndPrPl3  >kastma !34_V	et	f	\N
153345	kastavad	kastavad =ava  (PlN  >kast+ava !17_S	et	f	\N
153346	kastavad	kastavad =tava  (PlN  >kas+tava !17_S	et	f	\N
153376	saatud	?saatud =saatu  (PlN  >saatu !01_A	et	f	\N
153377	saatud	?saatud =saatu  (IndPrSg2  >saatuma !27_V	et	f	\N
153378	saatud	?saatud =saatud  (ID  >saatud !41_A	et	f	\N
153393	äga	äga =äga  (IndPrPs_  >ägama !27_V	et	f	\N
153394	äga	äga =äga  (ImpPrSg2  >ägama !27_V	et	f	\N
153395	ümbritsevate	ümbritsevate =ümbritseva  (PlG  >ümbritsev !02_A	et	f	\N
153396	ümbritsevate	"ümbritsev %ümbritse  )V_vA  <ümbritsema ;27_V	et	f	\N
153397	toetus	toetus =toetu  (SgIn  >toetu !01_A	et	f	\N
153398	toetus	"toetu %toe  )TU2_kA  <tugi ;21_S	et	f	\N
153399	toetus	toetus =toetu  (IndIpfSg3  >toetuma !27_V	et	f	\N
153400	toetus	toetus =toetus  (SgN  >toetus !11~09_S	et	f	\N
153401	toetus	"toetus %toeta  )US_vS  <toetama ;27_V	et	f	\N
153402	toetus	"toetus %toe  )TUS2_aS  <tugi ;21_S	et	f	\N
153440	keeleseadus	keeleseadus =seadu  (SgIn  >keele+sead !22_S	et	f	\N
153441	keeleseadus	keeleseadus =seadus  (SgN  >keele+seadus !11~09_S	et	f	\N
153444	järgnesid	järgnesid =järgne  (IndIpfSg2  >järgnema !27_V	et	f	\N
153445	järgnesid	järgnesid =järgne  (IndIpfPl3  >järgnema !27_V	et	f	\N
153448	parei	?parei =parei  (SgN  >parei !26_S	et	f	\N
153449	parei	?parei =parei  (SgG  >parei !26_S	et	f	\N
153469	rohelust	rohelust =rohelus  (SgP  >rohelus !11_S	et	f	\N
153470	rohelust	rohelust =lust  (SgN  >rohe+lust !22_S	et	f	\N
153474	sõidutee	sõidutee =tee  (SgN  >sõidu+tee !26_S	et	f	\N
153475	sõidutee	sõidutee =tee  (SgG  >sõidu+tee !26_S	et	f	\N
153484	gimnasiuumis	?gimnasiuumis =gimnasiuumi  (SgIn  >gimnasiuumi !16_S	et	f	\N
153485	gimnasiuumis	?gimnasiuumis =gimnasiuumi  (SgIn  >gimnasiuum !22_S	et	f	\N
153486	gimnasiuumis	?gimnasiuumis =gimnasiuumi  (IndIpfSg3  >gimnasiuumima !28_V	et	f	\N
153487	gimnasiuumis	?gimnasiuumis =gimnasiuumis  (SgN  >gimnasiuumis !09_S	et	f	\N
153561	arvutilauda	arvutilauda =lauda  (SgG  >arvuti+laut !22_S	et	f	\N
153149	kasvatatud	"kasvatatu %kasvata  )TU1_vS  <kasvatama ;27_V	et	f	\N
153150	kasvatatud	kasvatatud =kasvatatud  (ID  >kasvatatud !41_A	et	f	\N
153151	kasvatatud	"kasvatatud %kasvata  )TUD_vA  <kasvatama ;27_V	et	f	\N
153152	jahut	?jahut =jahut  (SgN  >jahut !02_S	et	f	\N
153159	xxxxxxxxx	### xxxxxxxxx	et	f	\N
153208	vääga	?vääga =vää  (SgKom  >vää !26_S	et	f	\N
153210	vääga	?vääga =vääga  (SgN  >vääga !16_S	et	f	\N
153212	vääga	?vääga =vääga  (SgG  >vääga !16_S	et	f	\N
153214	vääga	?vääga =vääga  (IndPrPs_  >väägama !29_V	et	f	\N
153216	vääga	?vääga =vääga  (ImpPrSg2  >väägama !29_V	et	f	\N
153225	polütehniküm	?polütehniküm =polütehniküm  (SgN  >polütehniküm !19_S	et	f	\N
153228	anekdootid	?anekdootid =anekdooti  (PlN  >anekdooti !16_S	et	f	\N
153231	nashe	?nashe =nashe  (SgN  >nashe !06_S	et	f	\N
153232	nashe	?nashe =nashe  (SgG  >nashe !06_S	et	f	\N
153233	nashe	?nashe =nashe  (PlP  >nash !22_S	et	f	\N
153234	nashe	?nashe =nashe  (IndPrPs_  >nashema !27_V	et	f	\N
153235	nashe	?nashe =nashe  (ImpPrSg2  >nashema !27_V	et	f	\N
153244	inemesele	?inemesele =inemese  (SgAll  >inemene !12_A	et	f	\N
153253	ringkonnas	ringkonnas =ringkonna  (SgIn  >ringkond !22_S	et	f	\N
153254	ringkonnas	ringkonnas =konna  (SgIn  >ring+konn !22_S	et	f	\N
153258	edusammu	edusammu =sammu  (SgG  >edu+samm !22_S	et	f	\N
153259	edusammu	edusammu =sammu  (SgP  >edu+samm !22_S	et	f	\N
153260	edusammu	edusammu =sammu  (SgAdt  >edu+samm !22_S	et	f	\N
153270	mahtu	mahtu =mahtu  (SgP  >maht !22_S	et	f	\N
153271	mahtu	mahtu =mahtu  (SgAdt  >maht !22_S	et	f	\N
153302	leebe	leebe =leebe  (SgN  >leebe !01_A	et	f	\N
153303	leebe	leebe =leebe  (SgG  >leebe !01_A	et	f	\N
153304	tähtkuju	tähtkuju =kuju  (SgN  >täht+kuju !17_S	et	f	\N
153305	tähtkuju	tähtkuju =kuju  (SgG  >täht+kuju !17_S	et	f	\N
153306	tähtkuju	tähtkuju =kuju  (SgP  >täht+kuju !17_S	et	f	\N
153322	sull	?sull =sull  (SgN  >sull !22_S	et	f	\N
153331	ütlege	### ütlege	et	f	\N
153334	polütehnikumi	polütehnikumi =polütehnikumi  (SgG  >polütehnikum !19_S	et	f	\N
153335	polütehnikumi	polütehnikumi =polütehnikumi  (SgP  >polütehnikum !19_S	et	f	\N
153336	polütehnikumi	polütehnikumi =polütehnikumi  (SgAdt  >polütehnikum !19_S	et	f	\N
153352	masinasse	masinasse =masina  (SgIll  >masin !02_S	et	f	\N
153353	masinasse	masinasse =masinas  (SgAdt  >masinane !12_A	et	f	\N
153354	masinasse	"masinane %masina  )NE_aA  <masin ;02_S	et	f	\N
153355	masinasse	masinasse =asse  (PlP  >masin+ass !22_S	et	f	\N
153359	loputusvahendid	?loputusvahendid =loputusvahendi  (PlN  >loputusvahent !22_S	et	f	\N
153360	loputusvahendid	?loputusvahendid =loputusvahendi  (IndPrSg2  >loputusvahentima !28_V	et	f	\N
153368	paariks	paariks =paari  (SgTr  >paar !22_NS	et	f	\N
153369	paariks	paariks =paari  (KndPrPs  >paarima !28_V	et	f	\N
153370	paariks	paariks =iks  (SgN  >paar+iks !22_S	et	f	\N
153388	naeratavad	naeratavad =naerata  (IndPrPl3  >naeratama !27_V	et	f	\N
153389	naeratavad	naeratavad =naeratava  (PlN  >naeratav !02_A	et	f	\N
153390	naeratavad	"naeratav %naerata  )V_vA  <naeratama ;27_V	et	f	\N
153403	elukls	?elukls =elukls  (SgN  >elukls !22_S	et	f	\N
153404	inemesel	?inemesel =inemese  (SgAd  >inemene !12_A	et	f	\N
153414	sõnumidega	### sõnumidega	et	f	\N
153425	muutuvatest	muutuvatest =muutuva  (PlEl  >muutuv !02_A	et	f	\N
153426	muutuvatest	"muutuv %muutu  )V_vA  <muutuma ;27_V	et	f	\N
153427	muutuvatest	muutuvatest =vate  (PlEl  >muutu+vatt !22_S	et	f	\N
153436	vasti	?vasti =vasti  (SgN  >vasti !16_S	et	f	\N
153437	vasti	?vasti =vasti  (SgG  >vasti !16_S	et	f	\N
153438	vasti	?vasti =vasti  (IndPrPs_  >vastima !28_V	et	f	\N
153439	vasti	?vasti =vasti  (ImpPrSg2  >vastima !28_V	et	f	\N
153451	lennart	?lennart =lennart  (SgN  >lennart !22_S	et	f	\N
153452	presidendiks	presidendiks =presidendi  (SgTr  >president !22_S	et	f	\N
153453	presidendiks	presidendiks =sidendi  (SgTr  >pre+sidend !02_S	et	f	\N
153467	kivimajas	kivimajas =aja  (SgIn  >kivim+aeg !22_S	et	f	\N
153468	kivimajas	kivimajas =maja  (SgIn  >kivi+maja !17_S	et	f	\N
153478	bussipeatus	bussipeatus =peatu  (SgIn  >bussi+peatu !01_A	et	f	\N
153479	bussipeatus	"bussi+peatu %pea  )TU2_kA  <bussi+pea ;26_S	et	f	\N
153480	bussipeatus	bussipeatus =peatus  (SgN  >bussi+peatus !11~09_S	et	f	\N
153481	bussipeatus	"bussi+peatus %pea  )TUS2_aS  <bussi+pea ;26_S	et	f	\N
153488	juuksla	juuksla =juuksla  (SgN  >juuksla !01_S	et	f	\N
153489	juuksla	juuksla =juuksla  (SgG  >juuksla !01_S	et	f	\N
153492	neljatoalises	neljatoalises =toalise  (SgIn  >nelja+toaline !12?10_A	et	f	\N
153493	neljatoalises	"nelja+toaline %toa  )LINE_aA  <nelja+tuba ;18_S	et	f	\N
153498	välisuksest	välisuksest =ukse  (SgEl  >välis+uks !14_S	et	f	\N
153499	välisuksest	välisuksest =ukses  (SgP  >välis+uksene !10_A	et	f	\N
153500	välisuksest	"välis+uksene %ukse  )NE_aA  <välis+uks ;14_S	et	f	\N
153501	välisuksest	välisuksest =sukse  (SgEl  >väli+suks !22_S	et	f	\N
153502	välisuksest	välisuksest =sukse  (PlEl  >väli+suks !22_S	et	f	\N
153503	välisuksest	välisuksest =sukses  (SgP  >väli+suksene !10_A	et	f	\N
153504	välisuksest	"väli+suksene %sukse  )NE_aA  <väli+suks ;22_S	et	f	\N
153207	rokkmuusika	rokkmuusika =muusika  (SgG  >rokk+muusika !01_S	et	f	\N
153218	neiust	neiust =neiu  (SgEl  >neiu !16_S	et	f	\N
153219	neiust	neiust =neiu  (SgEl  >neid !22_S	et	f	\N
153236	radiot	?radiot =radio  (SgP  >radio !01_S	et	f	\N
153237	radiot	?radiot =radiot  (SgN  >radiot !22_S	et	f	\N
153238	harjumus	harjumus =harjumus  (SgN  >harjumus !11_S	et	f	\N
153239	harjumus	"harjumus %harju  )MUS_vS  <harjuma ;27_V	et	f	\N
153247	kasvatavad	kasvatavad =kasvata  (IndPrPl3  >kasvatama !27_V	et	f	\N
153248	kasvatavad	kasvatavad =kasvatava  (PlN  >kasvatav !02_A	et	f	\N
153249	kasvatavad	"kasvatav %kasva  )TAV_vAS  <kasvama ;28_V	et	f	\N
153250	kasvatavad	"kasvatav %kasvata  )V_vA  <kasvatama ;27_V	et	f	\N
153251	pahaks	pahaks =paha  (SgTr  >paha !17_AS	et	f	\N
153252	pahaks	pahaks =paha  (SgTr  >pahk !22_S	et	f	\N
153255	politehnikumis	?politehnikumis =politehnikumi  (SgIn  >politehnikum !19_S	et	f	\N
153256	politehnikumis	?politehnikumis =politehnikumis  (SgN  >politehnikumis !09_S	et	f	\N
153261	keskkonnakaitse	keskkonnakaitse =kaitse  (SgN  >kesk+konna+kaitse !05_S	et	f	\N
153262	keskkonnakaitse	keskkonnakaitse =kaitse  (SgN  >kesk+konna+kaitse !06_S	et	f	\N
153263	keskkonnakaitse	keskkonnakaitse =kaitse  (SgG  >kesk+konna+kaitse !06_S	et	f	\N
153272	kahtlus	kahtlus =kahtlus  (SgN  >kahtlus !11~09_S	et	f	\N
153273	kahtlus	"kahtlus %kahtlase  )US_aS  <kahtlane ;12_A	et	f	\N
153292	juhusti	?juhusti =juhusti  (SgN  >juhusti !01_S	et	f	\N
153293	juhusti	?juhusti =juhusti  (SgG  >juhusti !01_S	et	f	\N
153294	juhusti	?juhusti =juhusti  (IndPrPs_  >juhustima !28_V	et	f	\N
153295	juhusti	?juhusti =juhusti  (ImpPrSg2  >juhustima !28_V	et	f	\N
153298	hooltult	?hooltult =hooltu  (SgAbl  >hooltu !01_S	et	f	\N
153299	hooltult	?hooltult =hooltult  (ID  >hooltult !41_D	et	f	\N
153309	inemesed	?inemesed =inemese  (PlN  >inemene !12_A	et	f	\N
153317	rukkub	?rukkub =rukku  (IndPrSg3  >rukkuma !27_V	et	f	\N
153323	piiratad	?piiratad =piirata  (IndPrSg2  >piiratama !27_V	et	f	\N
153341	suhtleda	?suhtleda =leda  (SgN  >suht+leda !17_S	et	f	\N
153342	suhtleda	?suhtleda =leda  (SgG  >suht+leda !17_S	et	f	\N
153343	suhtleda	?suhtleda =leda  (SgP  >suht+leda !17_S	et	f	\N
153379	ebaedukas	ebaedukas =eduka  (SgIn  >eba+edukas !02_A	et	f	\N
153380	ebaedukas	ebaedukas =edukas  (SgN  >eba+edukas !02_A	et	f	\N
153384	õu	õu =õu  (SgN  >õu !22_S	et	f	\N
153385	õu	õu =õu  (SgG  >õud !22_S	et	f	\N
153391	ründemängija	ründemängija =mängija  (SgN  >ründe+mängija !01_S	et	f	\N
153392	ründemängija	ründemängija =mängija  (SgG  >ründe+mängija !01_S	et	f	\N
153408	tahtsad	?tahtsad =tahtsa  (PlN  >tahtsa !01_S	et	f	\N
153409	tahtsad	?tahtsad =tahtsa  (IndPrSg2  >tahtsama !29_V	et	f	\N
153415	taastatuks	taastatuks =taasta  (KndPtIps  >taastama !27_V	et	f	\N
153416	taastatuks	taastatuks =taastatu  (SgTr  >taastatu !01_S	et	f	\N
153417	taastatuks	"taastatu %taasta  )TU1_vS  <taastama ;27_V	et	f	\N
153418	eelnesid	eelnesid =eelne  (IndIpfSg2  >eelnema !27_V	et	f	\N
153419	eelnesid	eelnesid =eelne  (IndIpfPl3  >eelnema !27_V	et	f	\N
153428	taasisesisvunud	?taasisesisvunud =taasisesisvu  (PtsPtPs  >taasisesisvuma !27_V	et	f	\N
153429	taasisesisvunud	?taasisesisvunud =taasisesisvunu  (PlN  >taasisesisvunu !01_S	et	f	\N
153430	taasisesisvunud	?taasisesisvunud =taasisesisvunu  (IndPrSg2  >taasisesisvunuma !27_V	et	f	\N
153431	taasisesisvunud	?taasisesisvunud =taasisesisvunud  (ID  >taasisesisvunud !41_A	et	f	\N
153432	taasisesisvunud	?taasisesisvunud =sisvunu  (PlN  >taas+ise+sisvunu !01_S	et	f	\N
153433	taasisesisvunud	?taasisesisvunud =isesisvu  (PtsPtPs  >taas+isesisvuma !27_V	et	f	\N
153434	taasisesisvunud	?taasisesisvunud =isesisvunu  (PlN  >taas+isesisvunu !01_S	et	f	\N
153435	taasisesisvunud	?taasisesisvunud =isesisvunu  (IndPrSg2  >taas+isesisvunuma !27_V	et	f	\N
153442	muudatus	muudatus =muudatus  (SgN  >muudatus !11_S	et	f	\N
153443	muudatus	muudatus =atu  (SgIn  >muud+att !22_S	et	f	\N
153463	maakonnas	maakonnas =maakonna  (SgIn  >maakond !22_S	et	f	\N
153464	maakonnas	maakonnas =konna  (SgIn  >maa+konn !22_S	et	f	\N
153506	paremal	paremal =parema  (SgAd  >parem !02_A	et	f	\N
153508	paremal	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
153510	paremal	paremal =paremal  (ID  >paremal !41_D	et	f	\N
153522	diivanvoodi	?diivanvoodi =diivanvoodi  (SgN  >diivanvoodi !16_S	et	f	\N
153523	diivanvoodi	?diivanvoodi =diivanvoodi  (SgG  >diivanvoodi !16_S	et	f	\N
153524	diivanvoodi	?diivanvoodi =diivanvoodi  (SgG  >diivanvoot !22_S	et	f	\N
153525	diivanvoodi	?diivanvoodi =diivanvoodi  (SgP  >diivanvood !22_S	et	f	\N
153526	diivanvoodi	?diivanvoodi =diivanvoodi  (SgAdt  >diivanvood !22_S	et	f	\N
153527	diivanvoodi	?diivanvoodi =diivanvoodi  (IndPrPs_  >diivanvootima !28_V	et	f	\N
153528	diivanvoodi	?diivanvoodi =diivanvoodi  (ImpPrSg2  >diivanvootima !28_V	et	f	\N
153531	pruunikas	pruunikas =pruunika  (SgIn  >pruunikas !02_A	et	f	\N
153532	pruunikas	pruunikas =pruunikas  (SgN  >pruunikas !02_A	et	f	\N
153555	magnitofon	?magnitofon =magnitofon  (SgN  >magnitofon !19_S	et	f	\N
153572	avaja	avaja =avaja  (SgN  >avaja !01_S	et	f	\N
153573	avaja	"avaja %ava  )JA_vS  <avama ;27_V	et	f	\N
153574	avaja	avaja =avaja  (SgG  >avaja !01_S	et	f	\N
153577	leivanuga	leivanuga =nuga  (SgN  >leiva+nuga !18_S	et	f	\N
153578	leivanuga	leivanuga =nuga  (SgP  >leiva+nuga !18_S	et	f	\N
153363	seinakontakti	seinakontakti =kontakti  (SgAdt  >seina+kontakt !22_S	et	f	\N
153364	masinast	masinast =masina  (SgEl  >masin !02_S	et	f	\N
153365	masinast	masinast =masinas  (SgP  >masinane !12_A	et	f	\N
153366	masinast	"masinane %masina  )NE_aA  <masin ;02_S	et	f	\N
153367	masinast	masinast =ast  (SgN  >masin+ast !22_S	et	f	\N
153375	nb	### nb	et	f	\N
153386	õu	õu =õu  (SgN  >õu !22_S	et	f	\N
153387	õu	õu =õu  (SgG  >õud !22_S	et	f	\N
153413	luletused	?luletused =luletuse  (PlN  >luletus !11_S	et	f	\N
153454	poliitiliselt	poliitiliselt =poliitilise  (SgAbl  >poliitiline !12_A	et	f	\N
153455	poliitiliselt	poliitiliselt =poliitiliselt  (ID  >poliitiliselt !41_D	et	f	\N
153456	poliitiliselt	"poliitiliselt %poliitilise  )LT_mD  <poliitiline ;12_A	et	f	\N
153461	astumisest	astumisest =astumise  (SgEl  >astumine !12_S	et	f	\N
153462	astumisest	"astumine %astu  )MINE_vS  <astuma ;28_V	et	f	\N
153476	kõnnitee	kõnnitee =tee  (SgN  >kõnni+tee !26_S	et	f	\N
153477	kõnnitee	kõnnitee =tee  (SgG  >kõnni+tee !26_S	et	f	\N
153482	pähklimääe	?pähklimääe =pähklimääe  (SgN  >pähklimääe !26_S	et	f	\N
153483	pähklimääe	?pähklimääe =pähklimääe  (SgG  >pähklimääe !26_S	et	f	\N
153490	üheksakorruselises	üheksakorruselises =korruselise  (SgIn  >üheksa+korruseline !12_A	et	f	\N
153491	üheksakorruselises	"üheksa+korruseline %korruse  )LINE_aA  <üheksa+korrus ;09_S	et	f	\N
153494	kaabeltelevisioon	kaabeltelevisioon =visioon  (SgN  >kaabel+tele+visioon !22_S	et	f	\N
153495	kaabeltelevisioon	kaabeltelevisioon =televisioon  (SgN  >kaabel+televisioon !22_S	et	f	\N
153496	mõõturi	mõõturi =mõõturi  (SgG  >mõõtur !02_S	et	f	\N
153497	mõõturi	mõõturi =uri  (SgN  >mõõt+uri !24_S	et	f	\N
153514	diivanilaud	?diivanilaud =diivanilau  (PlN  >diivanilau !26_S	et	f	\N
153515	diivanilaud	?diivanilaud =diivanilau  (SgP  >diivanilau !26_S	et	f	\N
153516	diivanilaud	?diivanilaud =diivanilaud  (SgN  >diivanilaud !22_S	et	f	\N
153518	riiul	riiul =riiu  (SgAd  >riid !22_S	et	f	\N
153519	riiul	riiul =riiul  (SgN  >riiul !02_S	et	f	\N
153551	vaipkate	?vaipkate =vaipka  (PlG  >vaipka !01_S	et	f	\N
153552	vaipkate	?vaipkate =vaipka  (IndPrPl2  >vaipkama !29_V	et	f	\N
153559	arvutilaud	arvutilaud =lau  (PlN  >arvuti+laug !22_SA	et	f	\N
153560	arvutilaud	arvutilaud =laud  (SgN  >arvuti+laud !22_S	et	f	\N
153570	potid	potid =poti  (PlN  >poti !16_S	et	f	\N
153571	potid	potid =poti  (PlN  >pott !22_S	et	f	\N
153575	dessertlusikat	?dessertlusikat =dessertlusika  (SgP  >dessertlusika !01_S	et	f	\N
153576	dessertlusikat	?dessertlusikat =dessertlusika  (SgP  >dessertlusikas !02_A	et	f	\N
153581	kohah	?kohah =kohah  (ID  >kohah !41_I	et	f	\N
153584	mikrolaineahu	mikrolaineahu =ahu  (SgN  >mikro+laine+ahu !17_S	et	f	\N
153585	mikrolaineahu	mikrolaineahu =ahu  (SgG  >mikro+laine+ahu !17_S	et	f	\N
153586	mikrolaineahu	mikrolaineahu =ahu  (SgP  >mikro+laine+ahu !17_S	et	f	\N
153590	hoovis	hoovis =hoovi  (SgIn  >hoov !22_S	et	f	\N
153591	hoovis	hoovis =hoovi  (PlIn  >hoob !22_S	et	f	\N
153597	välisuks	välisuks =uks  (SgN  >välis+uks !14_S	et	f	\N
153598	välisuks	välisuks =suks  (SgN  >väli+suks !22_S	et	f	\N
153609	palitud	palitud =palitu  (PlN  >palitu !01_S	et	f	\N
153611	palitud	"palitu %pali  )TU2_kA  <pali ;17_S	et	f	\N
153613	ummargune	?ummargune =ummargune  (SgN  >ummargune !12_A	et	f	\N
153614	ummargune	?ummargune =ummargune  (PlP  >ummargun !19_S	et	f	\N
153615	kraanikaus	?kraanikaus =kraanikau  (SgIn  >kraanikau !26_S	et	f	\N
153616	kraanikaus	?kraanikaus =kraanikaus  (SgN  >kraanikaus !11_S	et	f	\N
153617	kraanikaus	?kraanikaus =kau  (SgIn  >kraani+kau !26_S	et	f	\N
153618	kraanikaus	?kraanikaus =kaus  (SgN  >kraani+kaus !22_S	et	f	\N
153627	vahetult	vahetult =vahetu  (SgAbl  >vahetu !01_A	et	f	\N
153629	vahetult	"vahetu %vahe  )TU2_kA  <vahe ;16_S	et	f	\N
153630	vahetult	vahetult =vahetult  (ID  >vahetult !41_D	et	f	\N
153631	vahetult	"vahetult %vahe  )TULT2_mD  <vahe ;16_S	et	f	\N
153632	vahetult	"vahetult %vahetu  )LT_mD  <vahetu ;01_A	et	f	\N
153645	tumepunane	tumepunane =punane  (SgN  >tume+punane !10_AS	et	f	\N
153646	tumepunane	"tume+punane %puna  )NE_aA  <tume+puna ;17_S	et	f	\N
153648	komndopunkt	### komndopunkt	et	f	\N
153651	eesemesel	?eesemesel =eesemese  (SgAd  >eesemene !12_A	et	f	\N
153652	eesemesel	?eesemesel =emese  (SgAd  >ees+emene !10_A	et	f	\N
153653	eesemesel	?eesemesel =emesel  (SgN  >ees+emesel !19_S	et	f	\N
153654	ol	### ol	et	f	\N
153659	pesemine	pesemine =pesemine  (SgN  >pesemine !12_S	et	f	\N
153660	pesemine	"pesemine %pese  )MINE_vS  <pesema ;36_V	et	f	\N
153661	tüllkardinad	### tüllkardinad	et	f	\N
153673	armsam	armsam =armsam  (SgN  >armsam !02_AS	et	f	\N
153674	armsam	"armsam %armsa  )M_cA  <armas ;03_A	et	f	\N
153675	armsam	"armsam %armsa  )M_cA  <armas ;05_A	et	f	\N
153679	sepoolne	?sepoolne =sepoolne  (SgN  >sepoolne !02_A	et	f	\N
153680	sepoolne	?sepoolne =sepoolne  (PlP  >sepooln !22_S	et	f	\N
153687	aluspesu	aluspesu =pesu  (SgN  >alus+pesu !17_S	et	f	\N
153688	aluspesu	aluspesu =pesu  (SgG  >alus+pesu !17_S	et	f	\N
153689	aluspesu	aluspesu =pesu  (SgP  >alus+pesu !17_S	et	f	\N
153694	kulgmine	?kulgmine =kulgmine  (SgN  >kulgmine !12?10_A	et	f	\N
153410	raskuseid	raskuseid =raskuse  (PlP  >raskus !09_S	et	f	\N
153411	raskuseid	"raskus %raske  )US_aS  <raske ;01_A	et	f	\N
153412	raskuseid	raskuseid =raskuse  (PlP  >raskune !10_A	et	f	\N
153420	liikumised	liikumised =liikumise  (PlN  >liikumine !12_S	et	f	\N
153421	liikumised	"liikumine %liiku  )MINE_vS  <liikuma ;28_V	et	f	\N
153422	tiitma	?tiitma =tiit  (Sup  >tiitma !34_V	et	f	\N
153423	tiitma	?tiitma =tiitma  (IndPrPs_  >tiitmama !29_V	et	f	\N
153424	tiitma	?tiitma =tiitma  (ImpPrSg2  >tiitmama !29_V	et	f	\N
153446	enim	enim =enim  (ID  >enim !41_D	et	f	\N
153447	enim	enim =enim  (SgN  >enim !02_A	et	f	\N
153450	lennart	?lennart =lennart  (SgN  >lennart !22_S	et	f	\N
153457	ürosse	?ürosse =üro  (SgIll  >üro !17~16_S	et	f	\N
153458	ürosse	?ürosse =üros  (SgAdt  >üros !11_S	et	f	\N
153459	ürosse	?ürosse =ürosse  (SgG  >ürosne !02_A	et	f	\N
153460	ürosse	?ürosse =ürosse  (PlP  >üross !22_S	et	f	\N
153465	äärelinnas	äärelinnas =linna  (SgIn  >ääre+linn !22_S	et	f	\N
153466	äärelinnas	äärelinnas =linnas  (SgN  >ääre+linnas !09_S	et	f	\N
153471	muru	muru =muru  (SgN  >muru !17_S	et	f	\N
153472	muru	muru =muru  (SgG  >muru !17_S	et	f	\N
153473	muru	muru =muru  (SgP  >muru !17_S	et	f	\N
153511	diivanilaud	?diivanilaud =diivanilau  (PlN  >diivanilau !26_S	et	f	\N
153512	diivanilaud	?diivanilaud =diivanilau  (SgP  >diivanilau !26_S	et	f	\N
153513	diivanilaud	?diivanilaud =diivanilaud  (SgN  >diivanilaud !22_S	et	f	\N
153529	kirjutuslaud	kirjutuslaud =lau  (PlN  >kirjutus+laug !22_SA	et	f	\N
153530	kirjutuslaud	kirjutuslaud =laud  (SgN  >kirjutus+laud !22_S	et	f	\N
153536	kummuti	kummuti =kummu  (IndIpfIps  >kummuma !27_V	et	f	\N
153537	kummuti	kummuti =kummuti  (SgG  >kummut !02_S	et	f	\N
153550	külgkardinat	### külgkardinat	et	f	\N
153553	telelaud	telelaud =lau  (PlN  >tele+laug !22_SA	et	f	\N
153554	telelaud	telelaud =laud  (SgN  >tele+laud !22_S	et	f	\N
153592	liivakast	liivakast =liivaka  (SgEl  >liivakas !02_A	et	f	\N
153593	liivakast	liivakast =kast  (SgN  >liiva+kast !22_S	et	f	\N
153594	liivakast	liivakast =aka  (SgEl  >liiv+aka !16_S	et	f	\N
153595	liivakast	liivakast =akas  (SgP  >liiv+akane !10_A	et	f	\N
153596	liivakast	"liiv+akane %aka  )NE_aA  <liiv+aka ;16_S	et	f	\N
153612	vaib	?vaib =vaib  (SgN  >vaib !22_S	et	f	\N
153621	hambaharid	?hambaharid =hambahari  (PlN  >hambahar !19_S	et	f	\N
153625	saunalina	saunalina =lina  (SgN  >sauna+lina !17_S	et	f	\N
153626	saunalina	saunalina =lina  (SgG  >sauna+lina !17_S	et	f	\N
153628	saunalina	saunalina =lina  (SgP  >sauna+lina !17_S	et	f	\N
153638	põrandall	?põrandall =põrandall  (SgN  >põrandall !22_S	et	f	\N
153639	tualetti	tualetti =tualetti  (SgP  >tualett !22_S	et	f	\N
153640	tualetti	tualetti =tualetti  (SgAdt  >tualett !22_S	et	f	\N
153649	kulmutuskapp	?kulmutuskapp =kulmutuskapp  (SgN  >kulmutuskapp !22_S	et	f	\N
153650	kulmutuskapp	?kulmutuskapp =tuskapp  (SgN  >kulmu+tuskapp !22_S	et	f	\N
153662	kardinaild	?kardinaild =kardinaild  (SgN  >kardinaild !22_S	et	f	\N
153663	kardinaild	?kardinaild =ild  (SgN  >kardina+ild !22_S	et	f	\N
153664	kardinaild	?kardinaild =naild  (SgN  >kardi+naild !22_S	et	f	\N
153683	riiuled	?riiuled =riiule  (IndPrSg2  >riiulema !27_V	et	f	\N
153702	lampi	lampi =lampi  (SgP  >lamp !22_SA	et	f	\N
153703	lampi	lampi =lampi  (SgAdt  >lamp !22_SA	et	f	\N
153705	voodipesu	voodipesu =pesu  (SgN  >voodi+pesu !17_S	et	f	\N
153706	voodipesu	voodipesu =pesu  (SgG  >voodi+pesu !17_S	et	f	\N
153707	voodipesu	voodipesu =pesu  (SgP  >voodi+pesu !17_S	et	f	\N
153722	melhiorikahvlid	?melhiorikahvlid =melhiorikahvli  (PlN  >melhiorikahvel !02_S	et	f	\N
153723	melhiorikahvlid	?melhiorikahvlid =melhiorikahvli  (IndPrSg2  >melhiorikahvlima !28_V	et	f	\N
153735	kruvid	kruvid =kruvi  (PlN  >kruvi !17_S	et	f	\N
153736	kruvid	kruvid =kruvi  (IndPrSg2  >kruvima !27_V	et	f	\N
153739	kaheksasada	### kaheksasada	et	f	\N
153747	kolmekorruselised	kolmekorruselised =korruselise  (PlN  >kolme+korruseline !12_A	et	f	\N
153748	kolmekorruselised	"kolme+korruseline %korruse  )LINE_aA  <kolme+korrus ;09_S	et	f	\N
153752	väikesem	väikesem =väikesem  (SgN  >väikesem !02_A	et	f	\N
153753	väikesem	"väikesem %väikese  )M_cA  <väike ;10_A	et	f	\N
153754	väikesem	"väikesem %väikese  )M_cA  <väikene ;10_A	et	f	\N
153755	väikesem	"väikesem %väikese  )M_cA  <väike ;12_A	et	f	\N
153756	väikesem	"väikesem %väikese  )M_cA  <väikene ;12_A	et	f	\N
153803	valgusküllasem	valgusküllasem =küllasem  (SgN  >valgus+küllasem !02_A	et	f	\N
153804	valgusküllasem	"valgus+küllasem %külla  )SEM_cA  <valgus+küll ;22_S	et	f	\N
153805	valgusküllasem	"valgus+küllasem %küllase  )M_cA  <valgus+küllane ;10_A	et	f	\N
153810	laulakell	?laulakell =laulakell  (SgN  >laulakell !22_S	et	f	\N
153811	laulakell	?laulakell =lakell  (SgN  >lau+lakell !22_S	et	f	\N
153812	köögikappi	köögikappi =kappi  (SgP  >köögi+kapp !22_S	et	f	\N
153813	köögikappi	köögikappi =kappi  (SgAdt  >köögi+kapp !22_S	et	f	\N
153816	hari	hari =hari  (SgN  >hari !24_S	et	f	\N
153817	hari	hari =hari  (IndPrPs_  >harima !27_V	et	f	\N
153818	hari	hari =hari  (ImpPrSg2  >harima !27_V	et	f	\N
153819	laias	laias =laia  (SgIn  >laid !22_S	et	f	\N
153505	uksest	uksest =ukse  (SgEl  >uks !14_S	et	f	\N
153507	uksest	uksest =ukses  (SgP  >uksene !10_A	et	f	\N
153509	uksest	"uksene %ukse  )NE_aA  <uks ;14_S	et	f	\N
153517	sektsioonkapp	?sektsioonkapp =sektsioonkapp  (SgN  >sektsioonkapp !22_S	et	f	\N
153520	valamu	valamu =valamu  (SgN  >valamu !01_S	et	f	\N
153521	valamu	valamu =valamu  (SgG  >valamu !01_S	et	f	\N
153533	prunnikas	?prunnikas =prunnika  (SgIn  >prunnika !01_S	et	f	\N
153534	prunnikas	?prunnikas =prunnika  (SgIn  >prunnikas !02_S	et	f	\N
153535	prunnikas	?prunnikas =prunnikas  (SgN  >prunnikas !02_S	et	f	\N
153538	tugitoolvoodi	?tugitoolvoodi =tugitoolvoodi  (SgN  >tugitoolvoodi !16_S	et	f	\N
153539	tugitoolvoodi	?tugitoolvoodi =tugitoolvoodi  (SgG  >tugitoolvoodi !16_S	et	f	\N
153540	tugitoolvoodi	?tugitoolvoodi =tugitoolvoodi  (SgG  >tugitoolvoot !22_S	et	f	\N
153541	tugitoolvoodi	?tugitoolvoodi =tugitoolvoodi  (SgP  >tugitoolvood !22_S	et	f	\N
153542	tugitoolvoodi	?tugitoolvoodi =tugitoolvoodi  (SgAdt  >tugitoolvood !22_S	et	f	\N
153543	tugitoolvoodi	?tugitoolvoodi =tugitoolvoodi  (IndPrPs_  >tugitoolvootima !28_V	et	f	\N
153544	tugitoolvoodi	?tugitoolvoodi =tugitoolvoodi  (ImpPrSg2  >tugitoolvootima !28_V	et	f	\N
153545	tugitoolvoodi	?tugitoolvoodi =toolvoodi  (SgN  >tugi+toolvoodi !16_S	et	f	\N
153546	tugitoolvoodi	?tugitoolvoodi =toolvoodi  (SgG  >tugi+toolvoodi !16_S	et	f	\N
153547	tugitoolvoodi	?tugitoolvoodi =toolvoodi  (SgG  >tugi+toolvoot !22_S	et	f	\N
153548	tugitoolvoodi	?tugitoolvoodi =toolvoodi  (SgP  >tugi+toolvood !22_S	et	f	\N
153549	tugitoolvoodi	?tugitoolvoodi =toolvoodi  (SgAdt  >tugi+toolvood !22_S	et	f	\N
153556	laserplaadimängija	laserplaadimängija =mängija  (SgN  >laser+plaadi+mängija !01_S	et	f	\N
153557	laserplaadimängija	laserplaadimängija =mängija  (SgG  >laser+plaadi+mängija !01_S	et	f	\N
153558	riipub	?riipub =riipu  (IndPrSg3  >riipuma !27_V	et	f	\N
153565	marki	marki =marki  (SgP  >mark !22_S	et	f	\N
153566	marki	marki =marki  (SgAdt  >mark !22_S	et	f	\N
153567	samsung	?samsung =samsung  (SgN  >samsung !02_S	et	f	\N
153606	nagi	nagi =nagi  (SgN  >nagi !17_S	et	f	\N
153607	nagi	nagi =nagi  (SgG  >nagi !17_S	et	f	\N
153608	nagi	nagi =nagi  (SgP  >nagi !17_S	et	f	\N
153610	nagi	nagi =na  (ID^  >na !41_D	et	f	\N
153623	seep	seep =seep  (ID  >seep !41_X	et	f	\N
153624	seep	seep =seep  (SgN  >seep !22_S	et	f	\N
153633	laeni	laeni =lae  (SgTer  >lagi !21_S	et	f	\N
153634	laeni	laeni =lae  (SgTer  >laad !22_S	et	f	\N
153635	laeni	laeni =laeni  (SgG  >laen !22_S	et	f	\N
153636	laeni	laeni =laeni  (SgP  >laen !22_S	et	f	\N
153637	laeni	laeni =laeni  (SgAdt  >laen !22_S	et	f	\N
153671	aknalaud	aknalaud =lau  (PlN  >akna+laug !22_SA	et	f	\N
153672	aknalaud	aknalaud =laud  (SgN  >akna+laud !22_S	et	f	\N
153676	neeli	neeli =neeli  (SgG  >neel !22_S	et	f	\N
153677	neeli	neeli =neeli  (SgP  >neel !22_S	et	f	\N
153678	neeli	neeli =neeli  (SgAdt  >neel !22_S	et	f	\N
153681	valgusküllane	valgusküllane =küllane  (SgN  >valgus+küllane !10_A	et	f	\N
153682	valgusküllane	"valgus+küllane %külla  )NE_aA  <valgus+küll ;22_S	et	f	\N
153690	neljandl	?neljandl =neljandl  (SgN  >neljandl !22_S	et	f	\N
153691	seinalampi	seinalampi =lampi  (SgP  >seina+lamp !22_SA	et	f	\N
153692	seinalampi	seinalampi =lampi  (SgAdt  >seina+lamp !22_SA	et	f	\N
153697	võõrastetuba	võõrastetuba =tuba  (SgN  >võõraste+tuba !18_S	et	f	\N
153698	võõrastetuba	võõrastetuba =tuba  (SgP  >võõraste+tuba !18_S	et	f	\N
153726	rõdele	?rõdele =rõde  (SgAll  >rõde !16_S	et	f	\N
153727	rõdele	?rõdele =rõdele  (IndPrPs_  >rõdelema !31~27_V	et	f	\N
153729	rõdele	?rõdele =rõdele  (ImpPrSg2  >rõdelema !31~27_V	et	f	\N
153778	pimedavõitu	?pimedavõitu =pimedavõitu  (SgN  >pimedavõitu !01_A	et	f	\N
153779	pimedavõitu	?pimedavõitu =pimedavõitu  (SgG  >pimedavõitu !01_A	et	f	\N
153780	pimedavõitu	?pimedavõitu =pimedavõitu  (IndPrPs_  >pimedavõituma !27_V	et	f	\N
153781	pimedavõitu	?pimedavõitu =pimedavõitu  (ImpPrSg2  >pimedavõituma !27_V	et	f	\N
153782	pimedavõitu	?pimedavõitu =davõitu  (SgN  >pime+davõitu !01_AS	et	f	\N
153783	pimedavõitu	?pimedavõitu =davõitu  (SgG  >pime+davõitu !01_AS	et	f	\N
153793	televiisorikapp	?televiisorikapp =televiisorikapp  (SgN  >televiisorikapp !22_S	et	f	\N
153794	televiisorikapp	?televiisorikapp =orikapp  (SgN  >tele+viis+orikapp !22_S	et	f	\N
153795	televiisorikapp	?televiisorikapp =viisorikapp  (SgN  >tele+viisorikapp !22_S	et	f	\N
153800	heledavärvi	heledavärvi =värvi  (SgG  >heleda+värv !22_S	et	f	\N
153801	heledavärvi	heledavärvi =värvi  (SgP  >heleda+värv !22_S	et	f	\N
153802	heledavärvi	heledavärvi =värvi  (SgAdt  >heleda+värv !22_S	et	f	\N
153808	laulalamp	?laulalamp =laulalamp  (SgN  >laulalamp !22_S	et	f	\N
153809	laulalamp	?laulalamp =lalamp  (SgN  >lau+lalamp !22_S	et	f	\N
153836	ripplaed	ripplaed =lae  (PlN  >ripp+lagi !21_S	et	f	\N
153837	ripplaed	ripplaed =lae  (PlN  >ripp+laad !22_S	et	f	\N
153842	ülemiste	ülemiste =ülemis  (PlG  >ülemine !12_A	et	f	\N
153843	ülemiste	ülemiste =iste  (SgN  >ülem+iste !05_S	et	f	\N
153844	ülemiste	ülemiste =iste  (SgN  >ülem+iste !06_S	et	f	\N
153845	ülemiste	ülemiste =iste  (SgG  >ülem+iste !06_S	et	f	\N
153846	ülemiste	ülemiste =iste  (PlP  >ülem+ist !22_S	et	f	\N
153562	arvutilauda	arvutilauda =lauda  (SgP  >arvuti+laud !22_S	et	f	\N
153563	arvutilauda	arvutilauda =lauda  (SgAdt  >arvuti+laud !22_S	et	f	\N
153564	kollektioon	?kollektioon =kollektioon  (SgN  >kollektioon !22_S	et	f	\N
153568	tassid	tassid =tassi  (PlN  >tass !22_S	et	f	\N
153569	tassid	tassid =tassi  (IndPrSg2  >tassima !28_V	et	f	\N
153579	kapid	kapid =kapi  (PlN  >kapp !22_S	et	f	\N
153580	kapid	kapid =kapi  (IndPrSg2  >kappima !28_V	et	f	\N
153582	kohviveski	kohviveski =veski  (SgN  >kohvi+veski !01_S	et	f	\N
153583	kohviveski	kohviveski =veski  (SgG  >kohvi+veski !01_S	et	f	\N
153587	söögilaud	söögilaud =lau  (PlN  >söögi+laug !22_SA	et	f	\N
153588	söögilaud	söögilaud =laud  (SgN  >söögi+laud !22_S	et	f	\N
153599	erastatud	erastatud =erasta  (PtsPtIps  >erastama !27_V	et	f	\N
153600	erastatud	erastatud =erastatu  (PlN  >erastatu !01_S	et	f	\N
153601	erastatud	"erastatu %erasta  )TU1_vS  <erastama ;27_V	et	f	\N
153602	erastatud	erastatud =erastatud  (ID  >erastatud !41_A	et	f	\N
153603	erastatud	"erastatud %erasta  )TUD_vA  <erastama ;27_V	et	f	\N
153641	tualettitoa	?tualettitoa =tualettitoa  (SgN  >tualettitoa !26_S	et	f	\N
153642	tualettitoa	?tualettitoa =tualettitoa  (SgG  >tualettitoa !26_S	et	f	\N
153643	tualettitoa	?tualettitoa =itoa  (SgN  >tualett+itoa !26_S	et	f	\N
153644	tualettitoa	?tualettitoa =itoa  (SgG  >tualett+itoa !26_S	et	f	\N
153647	väib	?väib =väib  (SgN  >väib !22_S	et	f	\N
153684	komandal	?komandal =komanda  (SgAd  >komanda !01_S	et	f	\N
153685	komandal	?komandal =anda  (SgAd  >kom+anda !16_S	et	f	\N
153686	komandal	?komandal =andal  (SgN  >kom+andal !02_S	et	f	\N
153693	kardinad	### kardinad	et	f	\N
153701	riidekap	### riidekap	et	f	\N
153713	veniklaasid	?veniklaasid =veniklaa  (PlP  >veniklaa !26_S	et	f	\N
153714	veniklaasid	?veniklaasid =veniklaasi  (PlN  >veniklaasi !16_S	et	f	\N
153715	veniklaasid	?veniklaasid =veniklaasi  (PlN  >veniklaas !22_S	et	f	\N
153716	veniklaasid	?veniklaasid =veniklaasi  (IndPrSg2  >veniklaasima !28_V	et	f	\N
153720	melhiorilusikad	?melhiorilusikad =melhiorilusika  (PlN  >melhiorilusika !01_S	et	f	\N
153721	melhiorilusikad	?melhiorilusikad =melhiorilusika  (PlN  >melhiorilusikas !02_A	et	f	\N
153762	kitsas	kitsas =kitsa  (SgIn  >kitsas !07_A	et	f	\N
153763	kitsas	kitsas =kitsas  (SgN  >kitsas !07_A	et	f	\N
153767	riiuliga	riiuliga =riiuli  (SgKom  >riiul !02_S	et	f	\N
153769	riiuliga	riiuliga =liga  (SgN  >riiu+liga !17_S	et	f	\N
153770	riiuliga	riiuliga =liga  (SgG  >riiu+liga !17_S	et	f	\N
153771	riiuliga	riiuliga =liga  (SgP  >riiu+liga !17_S	et	f	\N
153797	terrakota	terrakota =terrakota  (SgN  >terrakota !16_S	et	f	\N
153798	terrakota	terrakota =terrakota  (SgG  >terrakota !16_S	et	f	\N
153806	kompuuter	?kompuuter =kompuuter  (SgN  >kompuuter !02_S	et	f	\N
153807	kompuuter	?kompuuter =puuter  (SgN  >kom+puuter !02_S	et	f	\N
153823	avajad	avajad =avaja  (PlN  >avaja !01_S	et	f	\N
153824	avajad	"avaja %ava  )JA_vS  <avama ;27_V	et	f	\N
153828	bokaalid	?bokaalid =bokaali  (PlN  >bokaali !16_S	et	f	\N
153829	bokaalid	?bokaalid =bokaali  (PlN  >bokaal !22_S	et	f	\N
153830	bokaalid	?bokaalid =bokaali  (IndPrSg2  >bokaalima !28_V	et	f	\N
153847	kappides	kappides =kappi  (PlIn  >kapp !22_S	et	f	\N
153848	kappides	kappides =kappi  (Ger  >kappima !28_V	et	f	\N
153865	väiksevõitu	väiksevõitu =võitu  (ID  >väikse+võitu !41_A	et	f	\N
153866	väiksevõitu	väiksevõitu =võitu  (SgP  >väikse+võit !22_S	et	f	\N
153867	väiksevõitu	väiksevõitu =võitu  (SgAdt  >väikse+võit !22_S	et	f	\N
153868	punasekirju	punasekirju =kirju  (SgN  >punase+kirju !01_A	et	f	\N
153869	punasekirju	punasekirju =kirju  (SgN  >punase+kirju !16_A	et	f	\N
153870	punasekirju	punasekirju =kirju  (SgG  >punase+kirju !01_A	et	f	\N
153871	punasekirju	punasekirju =kirju  (SgG  >punase+kirju !16_A	et	f	\N
153872	punasekirju	punasekirju =kirju  (PlP  >punase+kiri !24_S	et	f	\N
153888	rohelist	rohelist =rohelis  (SgP  >roheline !12_A	et	f	\N
153889	rohelist	"roheline %rohe  )LINE_aA  <rohe ;16_S	et	f	\N
153914	paliu	?paliu =paliu  (SgN  >paliu !01_S	et	f	\N
153915	paliu	?paliu =paliu  (SgG  >paliu !01_S	et	f	\N
153942	balsam	?balsam =balsam  (SgN  >balsam !02_A	et	f	\N
153947	laes	laes =lae  (SgIn  >lagi !21_S	et	f	\N
153948	laes	laes =lae  (SgIn  >laad !22_S	et	f	\N
153955	kummil	kummil =kummi  (SgAd  >kummi !16_S	et	f	\N
153956	kummil	kummil =kummi  (SgAd  >kumm !22_S	et	f	\N
153957	kummil	kummil =kummi  (PlAd  >kumb !22_P	et	f	\N
153964	lilline	lilline =lilline  (SgN  >lilline !10_A	et	f	\N
153965	lilline	"lilline %lilli  )NE_aA  <lill ;22_S	et	f	\N
153966	lilline	lilline =ine  (SgN  >lill+ine !16_S	et	f	\N
153967	lilline	lilline =ine  (SgG  >lill+ine !16_S	et	f	\N
153983	keedis	keedis =keedi  (SgIn  >keet !22_S	et	f	\N
153984	keedis	keedis =keedis  (SgN  >keedis !09_S	et	f	\N
153993	seinikapid	?seinikapid =seinikapi  (PlN  >seinikapp !22_S	et	f	\N
153994	seinikapid	?seinikapid =seinikapi  (IndPrSg2  >seinikappima !28_V	et	f	\N
154002	kraani	kraani =kraani  (SgG  >kraan !22_S	et	f	\N
154003	kraani	kraani =kraani  (SgP  >kraan !22_S	et	f	\N
154004	kraani	kraani =kraani  (SgAdt  >kraan !22_S	et	f	\N
153589	aptek	?aptek =aptek  (SgN  >aptek !02_S	et	f	\N
153604	valjas	valjas =valja  (SgIn  >valjas !07_S	et	f	\N
153605	valjas	valjas =valjas  (SgN  >valjas !07_S	et	f	\N
153619	kranikaus	?kranikaus =kranikau  (SgIn  >kranikau !26_S	et	f	\N
153620	kranikaus	?kranikaus =kranikaus  (SgN  >kranikaus !11_S	et	f	\N
153622	sampoon	?sampoon =sampoon  (SgN  >sampoon !22_S	et	f	\N
153655	alustassit	?alustassit =tassi  (SgP  >alus+tassi !16_S	et	f	\N
153656	alustassit	?alustassit =tassit  (SgN  >alus+tassit !02_S	et	f	\N
153657	alustassit	?alustassit =stassi  (SgP  >alu+stassi !16_S	et	f	\N
153658	alustassit	?alustassit =stassit  (SgN  >alu+stassit !02_S	et	f	\N
153665	eldse	?eldse =eldse  (SgN  >eldse !06_S	et	f	\N
153666	eldse	?eldse =eldse  (SgG  >eldne !02_A	et	f	\N
153667	eldse	?eldse =eldse  (SgG  >eldse !06_S	et	f	\N
153668	eldse	?eldse =eldse  (PlP  >elds !22_S	et	f	\N
153669	eldse	?eldse =eldse  (IndPrPs_  >eldsema !27_V	et	f	\N
153670	eldse	?eldse =eldse  (ImpPrSg2  >eldsema !27_V	et	f	\N
153699	võõrastetuba	võõrastetuba =tuba  (SgN  >võõraste+tuba !18_S	et	f	\N
153700	võõrastetuba	võõrastetuba =tuba  (SgP  >võõraste+tuba !18_S	et	f	\N
153712	siktsioon	?siktsioon =siktsioon  (SgN  >siktsioon !22_S	et	f	\N
153725	toliga	?toliga =toli  (SgKom  >toli !17_S	et	f	\N
153728	klaasitud	klaasitud =klaasi  (PtsPtIps  >klaasima !28_V	et	f	\N
153730	klaasitud	klaasitud =klaasitu  (PlN  >klaasitu !01_AS	et	f	\N
153731	klaasitud	"klaasitu %klaasi  )TU1_vS  <klaasima ;28_V	et	f	\N
153732	klaasitud	"klaasitu %klaasi  )TU2_kA  <klaas ;22_S	et	f	\N
153733	klaasitud	klaasitud =klaasitud  (ID  >klaasitud !41_A	et	f	\N
153734	klaasitud	"klaasitud %klaasi  )TUD_vA  <klaasima ;28_V	et	f	\N
153740	välisuksed	välisuksed =ukse  (PlN  >välis+uks !14_S	et	f	\N
153741	välisuksed	välisuksed =sukse  (PlN  >väli+suks !22_S	et	f	\N
153742	keskkütte	keskkütte =kütte  (SgG  >kesk+küte !06_S	et	f	\N
153743	keskkütte	keskkütte =kütte  (PlP  >kesk+kütt !22_S	et	f	\N
153744	narova	?narova =narova  (SgN  >narova !01_S	et	f	\N
153745	narova	?narova =narova  (SgG  >narova !01_S	et	f	\N
153746	narova	?narova =narova  (SgG  >narov !02_A	et	f	\N
153749	linaosa	linaosa =osa  (SgN  >lina+osa !17_S	et	f	\N
153750	linaosa	linaosa =osa  (SgG  >lina+osa !17_S	et	f	\N
153751	linaosa	linaosa =osa  (SgP  >lina+osa !17_S	et	f	\N
153764	seinanagi	seinanagi =nagi  (SgN  >seina+nagi !17_S	et	f	\N
153765	seinanagi	seinanagi =nagi  (SgG  >seina+nagi !17_S	et	f	\N
153766	seinanagi	seinanagi =nagi  (SgP  >seina+nagi !17_S	et	f	\N
153768	seinanagi	seinanagi =seina  (SgEs^  >sein !23?22_S	et	f	\N
153776	lael	lael =lae  (SgAd  >lagi !21_S	et	f	\N
153777	lael	lael =lae  (SgAd  >laad !22_S	et	f	\N
153784	kahekohaline	kahekohaline =ine  (SgN  >kahe+kohal+ine !16_S	et	f	\N
153785	kahekohaline	kahekohaline =ine  (SgG  >kahe+kohal+ine !16_S	et	f	\N
153786	kahekohaline	kahekohaline =kohaline  (SgN  >kahe+kohaline !12_A	et	f	\N
153787	kahekohaline	"kahe+kohaline %koha  )LINE_aA  <kahe+koha ;17_S	et	f	\N
153788	kahekohaline	"kahe+kohaline %koha  )LINE_aA  <kahe+koht ;22_S	et	f	\N
153799	beezid	?beezid =beezi  (PlN  >beezi !16_S	et	f	\N
153814	taburetti	taburetti =taburetti  (SgP  >taburet !22_S	et	f	\N
153815	taburetti	taburetti =taburetti  (SgAdt  >taburet !22_S	et	f	\N
153821	riivid	riivid =riivi  (PlN  >riiv !22_S	et	f	\N
153822	riivid	riivid =riivi  (IndPrSg2  >riivima !28_V	et	f	\N
153859	fonolukk	?fonolukk =fonolukk  (SgN  >fonolukk !22_S	et	f	\N
153875	riiuleid	riiuleid =riiule  (PlP  >riiul !02_S	et	f	\N
153876	riiuleid	riiuleid =lei  (PlN  >riiu+lei !26_S	et	f	\N
153877	riiuleid	riiuleid =lei  (SgP  >riiu+lei !26_S	et	f	\N
153878	riiuleid	riiuleid =leid  (SgN  >riiu+leid !22_S	et	f	\N
153890	sissekäiku	sissekäiku =käiku  (SgP  >sisse+käik !22_S	et	f	\N
153891	sissekäiku	sissekäiku =käiku  (SgAdt  >sisse+käik !22_S	et	f	\N
153901	lahtikäiv	lahtikäiv =käi  (PtsPrPs  >lahti+_käima !38_V	et	f	\N
153902	lahtikäiv	lahtikäiv =käiv  (SgN  >lahti+käiv !02_A	et	f	\N
153912	näikesepoolne	?näikesepoolne =näikesepoolne  (SgN  >näikesepoolne !02_A	et	f	\N
153913	näikesepoolne	?näikesepoolne =näikesepoolne  (PlP  >näikesepooln !22_S	et	f	\N
153929	külgkärdinad	### külgkärdinad	et	f	\N
153930	taldrukud	?taldrukud =taldruku  (PlN  >taldruku !01_S	et	f	\N
153931	taldrukud	?taldrukud =taldruku  (IndPrSg2  >taldrukuma !27_V	et	f	\N
153943	nari	nari =nari  (SgN  >nari !17_S	et	f	\N
153944	nari	nari =nari  (SgG  >nari !17_S	et	f	\N
153945	nari	nari =nari  (SgP  >nari !17_S	et	f	\N
153990	söögituba	söögituba =tuba  (SgN  >söögi+tuba !18_S	et	f	\N
153991	söögituba	söögituba =tuba  (SgP  >söögi+tuba !18_S	et	f	\N
153995	gasipliit	?gasipliit =gasipliit  (SgN  >gasipliit !22_S	et	f	\N
154017	liiva	liiva =liiva  (SgG  >liiv !22_S	et	f	\N
154019	liiva	liiva =liiva  (SgP  >liiv !22_S	et	f	\N
154021	liiva	liiva =liiva  (SgAdt  >liiv !22_S	et	f	\N
154022	leivakombinat	?leivakombinat =binat  (SgN  >leiva+kom+binat !02_S	et	f	\N
154045	lamid	?lamid =lami  (PlN  >lami !17_S	et	f	\N
154048	lamid	?lamid =lami  (IndPrSg2  >lamima !27_V	et	f	\N
153695	kulgmine	?kulgmine =kulgmine  (IndPrPs_  >kulgminema !27_V	et	f	\N
153696	kulgmine	?kulgmine =kulgmine  (ImpPrSg2  >kulgminema !27_V	et	f	\N
153704	esemesel	?esemesel =esemese  (SgAd  >esemene !12_A	et	f	\N
153708	kohviseerviis	?kohviseerviis =kohviseervii  (SgIn  >kohviseervii !26_S	et	f	\N
153709	kohviseerviis	?kohviseerviis =kohviseerviis  (SgN  >kohviseerviis !22_S	et	f	\N
153710	kohviseerviis	?kohviseerviis =seervii  (SgIn  >kohvi+seervii !26_S	et	f	\N
153711	kohviseerviis	?kohviseerviis =seerviis  (SgN  >kohvi+seerviis !22_S	et	f	\N
153717	melhiorinoad	?melhiorinoad =melhiorinoa  (PlN  >melhiorinoa !26_S	et	f	\N
153718	melhiorinoad	?melhiorinoad =melhiorinoa  (SgP  >melhiorinoa !26_S	et	f	\N
153719	melhiorinoad	?melhiorinoad =melhiorinoad  (SgN  >melhiorinoad !22_S	et	f	\N
153724	rullkardinad	### rullkardinad	et	f	\N
153737	valtsid	valtsid =valtsi  (PlN  >valts !22_S	et	f	\N
153738	valtsid	valtsid =valtsi  (IndPrSg2  >valtsima !28_V	et	f	\N
153757	välisukse	välisukse =ukse  (SgG  >välis+uks !14_S	et	f	\N
153758	välisukse	välisukse =sukse  (SgG  >väli+suks !22_S	et	f	\N
153759	välisukse	välisukse =sukse  (SgP  >väli+suks !22_S	et	f	\N
153760	välisukse	välisukse =sukse  (SgAdt  >väli+suks !22_S	et	f	\N
153761	välisukse	välisukse =sukse  (PlP  >väli+suks !22_S	et	f	\N
153772	jalatsiriiul	jalatsiriiul =riiu  (SgAd  >jalatsi+riid !22_S	et	f	\N
153773	jalatsiriiul	jalatsiriiul =riiul  (SgN  >jalatsi+riiul !02_S	et	f	\N
153774	kandiline	kandiline =kandiline  (SgN  >kandiline !12_A	et	f	\N
153775	kandiline	"kandiline %kandi  )LINE_aA  <kant ;22_S	et	f	\N
153789	kujukesed	kujukesed =kujukese  (PlN  >kujuke !12_S	et	f	\N
153790	kujukesed	"kujuke %kuju  )KE_dS  <kuju ;17_S	et	f	\N
153791	kujukesed	kujukesed =kujukese  (PlN  >kujukene !12_S	et	f	\N
153792	kujukesed	"kujukene %kuju  )KENE_dS  <kuju ;17_S	et	f	\N
153796	külgkardinad	### külgkardinad	et	f	\N
153825	peeniksed	?peeniksed =peenikse  (PlN  >peenikne !02_A	et	f	\N
153826	peeniksed	?peeniksed =ikse  (PlN  >peen+ikne !02_A	et	f	\N
153827	peeniksed	?peeniksed =ikse  (PlN  >peen+ikse !06_S	et	f	\N
153831	kõrges	kõrges =kõrge  (SgIn  >kõrge !01_A	et	f	\N
153832	kõrges	kõrges =kõrge  (PlIn  >kõrk !22_A	et	f	\N
153833	kõrges	kõrges =kõrges  (SgN  >kõrges !09_S	et	f	\N
153834	purgid	purgid =purgi  (PlN  >purk !22_S	et	f	\N
153835	purgid	purgid =purgi  (IndPrSg2  >purkima !28_V	et	f	\N
153838	ribikardinad	### ribikardinad	et	f	\N
153851	puhastusevahendid	?puhastusevahendid =puhastusevahendi  (PlN  >puhastusevahent !22_S	et	f	\N
153852	puhastusevahendid	?puhastusevahendid =puhastusevahendi  (IndPrSg2  >puhastusevahentima !28_V	et	f	\N
153853	puhastusevahendid	?puhastusevahendid =evahendi  (PlN  >puhastus+evahent !22_S	et	f	\N
153854	puhastusevahendid	?puhastusevahendid =usevahendi  (PlN  >puhast+usevahent !22_S	et	f	\N
153855	puhastusevahendid	?puhastusevahendid =tusevahendi  (PlN  >puhas+tusevahent !22_S	et	f	\N
153856	välisuksel	välisuksel =ukse  (SgAd  >välis+uks !14_S	et	f	\N
153857	välisuksel	välisuksel =sukse  (SgAd  >väli+suks !22_S	et	f	\N
153858	välisuksel	välisuksel =sukse  (PlAd  >väli+suks !22_S	et	f	\N
153863	maalid	maalid =maali  (PlN  >maal !22_S	et	f	\N
153864	maalid	maalid =maali  (IndPrSg2  >maalima !28_V	et	f	\N
153879	videomagnitofon	?videomagnitofon =videomagnitofon  (SgN  >videomagnitofon !19_S	et	f	\N
153880	videomagnitofon	?videomagnitofon =magnitofon  (SgN  >video+magnitofon !19_S	et	f	\N
153884	sahtris	?sahtris =sahtri  (SgIn  >sahtri !01_S	et	f	\N
153885	sahtris	?sahtris =sahtri  (SgIn  >sahter !02_S	et	f	\N
153886	sahtris	?sahtris =sahtri  (IndIpfSg3  >sahtrima !28_V	et	f	\N
153887	sahtris	?sahtris =sahtris  (SgN  >sahtris !09_S	et	f	\N
153926	tüllkärdin	?tüllkärdin =tüllkärdi  (IndPrSg1  >tüllkärtima !28_V	et	f	\N
153927	tüllkärdin	?tüllkärdin =tüllkärdin  (SgN  >tüllkärdin !19_S	et	f	\N
153928	tüllkärdin	?tüllkärdin =kärdin  (SgN  >tüll+kärdin !02_S	et	f	\N
153938	ukset	?ukset =ukse  (SgP  >ukne !02_A	et	f	\N
153939	ukset	?ukset =ukse  (SgP  >ukse !06_S	et	f	\N
153940	valisuksest	?valisuksest =valisukse  (SgEl  >valisukne !02_A	et	f	\N
153941	valisuksest	?valisuksest =valisukses  (SgP  >valisuksene !12_A	et	f	\N
153952	voogiga	voogiga =voogi  (SgKom  >voog !22_S	et	f	\N
153953	voogiga	voogiga =iga  (SgN  >voog+iga !18_S	et	f	\N
153954	voogiga	voogiga =iga  (SgP  >voog+iga !18_S	et	f	\N
153968	kreemiga	kreemiga =kreemi  (SgKom  >kreem !22_SA	et	f	\N
153969	kreemiga	kreemiga =iga  (SgN  >kreem+iga !18_S	et	f	\N
153970	kreemiga	kreemiga =iga  (SgP  >kreem+iga !18_S	et	f	\N
153985	marineeritudseenid	?marineeritudseenid =marineeritudseeni  (PlN  >marineeritudseeni !16_S	et	f	\N
153986	marineeritudseenid	?marineeritudseenid =marineeritudseeni  (PlN  >marineeritudseen !22_S	et	f	\N
153987	marineeritudseenid	?marineeritudseenid =marineeritudseeni  (IndPrSg2  >marineeritudseenima !28_V	et	f	\N
153988	marineeritudseenid	?marineeritudseenid =neeritudseeni  (PlN  >mari+neeritudseeni !16_S	et	f	\N
153989	marineeritudseenid	?marineeritudseenid =neeritudseeni  (PlN  >mari+neeritudseen !22_S	et	f	\N
153992	nurgdiivan	?nurgdiivan =nurgdiivan  (SgN  >nurgdiivan !02_S	et	f	\N
153998	käteratik	?käteratik =käteratik  (SgN  >käteratik !02_S	et	f	\N
153999	käteratik	?käteratik =ratik  (SgN  >käte+ratik !02_S	et	f	\N
153820	laias	laias =laia  (SgIn  >lai !22_A	et	f	\N
153839	kahhelkivi	kahhelkivi =kivi  (SgN  >kahhel+kivi !17_S	et	f	\N
153840	kahhelkivi	kahhelkivi =kivi  (SgG  >kahhel+kivi !17_S	et	f	\N
153841	kahhelkivi	kahhelkivi =kivi  (SgP  >kahhel+kivi !17_S	et	f	\N
153849	kosmeetika-	kosmeetika- =kosmeetika  (SgN  >kosmeetika !01_S	et	f	\N
153850	kosmeetika-	kosmeetika- =kosmeetika  (SgG  >kosmeetika !01_S	et	f	\N
153860	geneva	?geneva =geneva  (SgN  >geneva !01_S	et	f	\N
153861	geneva	?geneva =geneva  (SgG  >geneva !01_S	et	f	\N
153862	geneva	?geneva =geneva  (SgG  >genev !02_A	et	f	\N
153881	küldkardinad	### küldkardinad	et	f	\N
153882	hakkalihamasin	?hakkalihamasin =hakkalihamasin  (SgN  >hakkalihamasin !19_S	et	f	\N
153883	hakkalihamasin	?hakkalihamasin =alihamasin  (SgN  >hakk+alihamasin !19_S	et	f	\N
153892	ripplae	ripplae =lae  (SgG  >ripp+lagi !21_S	et	f	\N
153893	ripplae	ripplae =lae  (SgG  >ripp+laad !22_S	et	f	\N
153907	elutubas	?elutubas =elutuba  (SgIn  >elutuba !16_S	et	f	\N
153908	elutubas	?elutubas =tubas  (SgN  >elu+tubas !07_S	et	f	\N
153909	villanevaip	?villanevaip =villanevaip  (SgN  >villanevaip !22_S	et	f	\N
153910	villanevaip	?villanevaip =nevaip  (SgN  >villa+nevaip !22_S	et	f	\N
153911	villanevaip	?villanevaip =anevaip  (SgN  >vill+anevaip !22_S	et	f	\N
153935	esikupõrand	?esikupõrand =esikupõrand  (SgN  >esikupõrand !22_S	et	f	\N
153936	esikupõrand	?esikupõrand =upõrand  (SgN  >esik+upõrand !22_S	et	f	\N
153937	esikupõrand	?esikupõrand =kupõrand  (SgN  >esi+kupõrand !22_S	et	f	\N
153949	roosidega	roosidega =roosi  (PlKom  >roos !22_S	et	f	\N
153950	roosidega	roosidega =si  (PlKom  >roo+si !26_S	et	f	\N
153951	roosidega	roosidega =side  (SgKom  >roo+side !16_S	et	f	\N
153960	jüüres	?jüüres =jüüre  (SgIn  >jüüre !06_S	et	f	\N
153961	jüüres	?jüüres =jüüre  (PlIn  >jüür !22_S	et	f	\N
153962	jüüres	?jüüres =jüüre  (IndIpfSg3  >jüürema !27_V	et	f	\N
153963	jüüres	?jüüres =jüüres  (SgN  >jüüres !09_S	et	f	\N
153996	üksega	?üksega =ükse  (SgKom  >ükne !02_A	et	f	\N
153997	üksega	?üksega =ükse  (SgKom  >ükse !06_S	et	f	\N
154000	metallvalamu	metallvalamu =valamu  (SgN  >metall+valamu !01_S	et	f	\N
154001	metallvalamu	metallvalamu =valamu  (SgG  >metall+valamu !01_S	et	f	\N
154008	vallisriided	?vallisriided =vallisriide  (PlN  >vallisriide !16_S	et	f	\N
154011	ripu	ripu =ripu  (IndPrPs_  >rippuma !28_V	et	f	\N
154012	ripu	ripu =ripu  (ImpPrSg2  >rippuma !28_V	et	f	\N
154013	kahelkiviga	?kahelkiviga =kahelkivi  (SgKom  >kahelkiv !02_A	et	f	\N
154023	gaarazid	?gaarazid =gaarazi  (PlN  >gaarazi !01_S	et	f	\N
154029	gaaz	### gaaz	et	f	\N
154072	kannus	kannus =kannu  (SgIn  >kann !22_S	et	f	\N
154073	kannus	kannus =kannu  (PlIn  >kand !22_S	et	f	\N
154074	kannus	kannus =kannus  (SgN  >kannus !09_S	et	f	\N
154118	ideoloogiatöö	ideoloogiatöö =töö  (SgN  >ideo+loogia+töö !26_S	et	f	\N
154119	ideoloogiatöö	ideoloogiatöö =töö  (SgG  >ideo+loogia+töö !26_S	et	f	\N
154124	lugemiseks	lugemiseks =lugemise  (SgTr  >lugemine !12_S	et	f	\N
154125	lugemiseks	"lugemine %luge  )MINE_vS  <lugema ;28_V	et	f	\N
154126	lugemiseks	"lugemine %lugemi  )NE_aA  <lugem ;02_S	et	f	\N
154153	1929a	### 1929a	et	f	\N
154176	nägis	?nägis =nägi  (SgIn  >nägi !17_S	et	f	\N
154177	nägis	?nägis =nägi  (IndIpfSg3  >nägima !27_V	et	f	\N
154178	nägis	?nägis =nägis  (SgN  >nägis !09_S	et	f	\N
154196	vatamise	?vatamise =vatamise  (SgG  >vatamine !12_S	et	f	\N
154199	suviselt	suviselt =suvise  (SgAbl  >suvine !10_A	et	f	\N
154200	suviselt	"suvine %suvi  )NE_aA  <suvi ;20_S	et	f	\N
154201	suviselt	suviselt =suviselt  (ID  >suviselt !41_D	et	f	\N
154202	suviselt	"suviselt %suvise  )LT_mD  <suvine ;10_A	et	f	\N
154209	mahlasemalt	mahlasemalt =mahlasema  (SgAbl  >mahlasem !02_A	et	f	\N
154210	mahlasemalt	"mahlasem %mahla  )SEM_cA  <mahl ;22_S	et	f	\N
154211	mahlasemalt	"mahlasem %mahlase  )M_cA  <mahlane ;10_A	et	f	\N
154212	mahlasemalt	mahlasemalt =mahlasemalt  (ID  >mahlasemalt !41_D	et	f	\N
154213	mahlasemalt	"mahlasemalt %mahla  )SEMALT_mD  <mahl ;22_S	et	f	\N
154214	mahlasemalt	"mahlasemalt %mahlase  )MALT_mD  <mahlane ;10_A	et	f	\N
154225	mehelikkuks	?mehelikkuks =mehelikku  (KndPrPs  >mehelikkuma !27_V	et	f	\N
154231	söömisele	söömisele =söömise  (SgAll  >söömine !12?10_S	et	f	\N
154232	söömisele	"söömine %söö  )MINE_vS  <sööma ;38_V	et	f	\N
154233	söömisele	"söömine %söömi  )NE_aA  <sööm ;22_S	et	f	\N
154241	hardi	?hardi =hardi  (ID  >hardi !41_D	et	f	\N
154242	hardi	?hardi =hardi  (SgG  >hart !22_S	et	f	\N
154243	hardi	?hardi =hardi  (SgP  >hard !22_S	et	f	\N
154244	hardi	?hardi =hardi  (SgAdt  >hard !22_S	et	f	\N
154245	hardi	?hardi =hardi  (IndPrPs_  >hartima !28_V	et	f	\N
154246	hardi	?hardi =hardi  (ImpPrSg2  >hartima !28_V	et	f	\N
154249	rezhisöör	?rezhisöör =rezhisöör  (SgN  >rezhisöör !22_S	et	f	\N
154256	eerik	?eerik =eerik  (SgN  >eerik !02_S	et	f	\N
154263	lubasid	lubasid =luba  (PlP  >luba !18_S	et	f	\N
154264	lubasid	lubasid =luba  (IndIpfSg2  >lubama !27_V	et	f	\N
154265	lubasid	lubasid =luba  (IndIpfPl3  >lubama !27_V	et	f	\N
154273	lastud	lastud =las  (PtsPtIps  >laskma !34_V	et	f	\N
153873	sektsioonkapis	?sektsioonkapis =sektsioonkapi  (SgIn  >sektsioonkapp !22_S	et	f	\N
153874	sektsioonkapis	?sektsioonkapis =sektsioonkapis  (SgN  >sektsioonkapis !09_S	et	f	\N
153894	diivanilaual	?diivanilaual =diivanilaua  (SgAd  >diivanilaua !01_S	et	f	\N
153895	diivanilaual	?diivanilaual =diivanilaual  (SgN  >diivanilaual !19_S	et	f	\N
153896	lapselaud	lapselaud =lau  (PlN  >lapse+laug !22_SA	et	f	\N
153897	lapselaud	lapselaud =laud  (SgN  >lapse+laud !22_S	et	f	\N
153898	sektsioonkapi	?sektsioonkapi =sektsioonkapi  (SgG  >sektsioonkapp !22_S	et	f	\N
153899	sektsioonkapi	?sektsioonkapi =sektsioonkapi  (IndPrPs_  >sektsioonkappima !28_V	et	f	\N
153900	sektsioonkapi	?sektsioonkapi =sektsioonkapi  (ImpPrSg2  >sektsioonkappima !28_V	et	f	\N
153903	raamatlaua	?raamatlaua =raamatlaua  (SgN  >raamatlaua !01_S	et	f	\N
153904	raamatlaua	?raamatlaua =raamatlaua  (SgG  >raamatlaua !01_S	et	f	\N
153905	raamatlaua	?raamatlaua =atlaua  (SgN  >raam+atlaua !01_S	et	f	\N
153906	raamatlaua	?raamatlaua =atlaua  (SgG  >raam+atlaua !01_S	et	f	\N
153916	lastemänguasjaid	?lastemänguasjaid =lastemänguasja  (PlP  >lastemänguasjas !02_A	et	f	\N
153917	lastemänguasjaid	?lastemänguasjaid =lastemänguasjai  (PlN  >lastemänguasjai !26_S	et	f	\N
153918	lastemänguasjaid	?lastemänguasjaid =lastemänguasjai  (SgP  >lastemänguasjai !26_S	et	f	\N
153919	lastemänguasjaid	?lastemänguasjaid =asja  (PlP  >laste+mängu+asjas !02_A	et	f	\N
153920	lastemänguasjaid	?lastemänguasjaid =asjai  (PlN  >laste+mängu+asjai !26_S	et	f	\N
153921	lastemänguasjaid	?lastemänguasjaid =asjai  (SgP  >laste+mängu+asjai !26_S	et	f	\N
153922	lastemänguasjaid	?lastemänguasjaid =asjaid  (SgN  >laste+mängu+asjaid !22_S	et	f	\N
153923	lastemänguasjaid	?lastemänguasjaid =mänguasja  (PlP  >laste+mänguasjas !02_A	et	f	\N
153924	lastemänguasjaid	?lastemänguasjaid =mänguasjai  (PlN  >laste+mänguasjai !26_S	et	f	\N
153925	lastemänguasjaid	?lastemänguasjaid =mänguasjai  (SgP  >laste+mänguasjai !26_S	et	f	\N
153932	gaasimõõdur	?gaasimõõdur =gaasimõõdur  (SgN  >gaasimõõdur !02_S	et	f	\N
153933	gaasimõõdur	?gaasimõõdur =mõõdur  (SgN  >gaasi+mõõdur !02_S	et	f	\N
153934	gaasimõõdur	?gaasimõõdur =imõõdur  (SgN  >gaas+imõõdur !02_S	et	f	\N
153946	holitseb	?holitseb =holitse  (IndPrSg3  >holitsema !27_V	et	f	\N
153958	vanaegkell	?vanaegkell =vanaegkell  (SgN  >vanaegkell !22_S	et	f	\N
153959	vanaegkell	?vanaegkell =egkell  (SgN  >vana+egkell !22_S	et	f	\N
153971	televiisarilaud	?televiisarilaud =televiisarilau  (PlN  >televiisarilau !26_S	et	f	\N
153972	televiisarilaud	?televiisarilaud =televiisarilau  (SgP  >televiisarilau !26_S	et	f	\N
153973	televiisarilaud	?televiisarilaud =televiisarilaud  (SgN  >televiisarilaud !22_S	et	f	\N
153974	televiisarilaud	?televiisarilaud =rilau  (PlN  >tele+viisa+rilau !26_S	et	f	\N
153975	televiisarilaud	?televiisarilaud =rilau  (SgP  >tele+viisa+rilau !26_S	et	f	\N
153976	televiisarilaud	?televiisarilaud =rilaud  (SgN  >tele+viisa+rilaud !22_S	et	f	\N
153977	televiisarilaud	?televiisarilaud =arilau  (PlN  >tele+viis+arilau !26_S	et	f	\N
153978	televiisarilaud	?televiisarilaud =arilau  (SgP  >tele+viis+arilau !26_S	et	f	\N
153979	televiisarilaud	?televiisarilaud =arilaud  (SgN  >tele+viis+arilaud !22_S	et	f	\N
153980	televiisarilaud	?televiisarilaud =viisarilau  (PlN  >tele+viisarilau !26_S	et	f	\N
153981	televiisarilaud	?televiisarilaud =viisarilau  (SgP  >tele+viisarilau !26_S	et	f	\N
153982	televiisarilaud	?televiisarilaud =viisarilaud  (SgN  >tele+viisarilaud !22_S	et	f	\N
154006	sahtlised	sahtlised =sahtlise  (PlN  >sahtline !12~10_A	et	f	\N
154007	sahtlised	"sahtline %sahtli  )NE_aA  <sahtel ;02_S	et	f	\N
154024	neste	neste =neste  (SgN  >neste !06_S	et	f	\N
154025	neste	neste =neste  (SgG  >neste !06_S	et	f	\N
154026	keskkute	?keskkute =keskku  (PlG  >keskku !01_S	et	f	\N
154027	keskkute	?keskkute =keskku  (IndPrPl2  >keskkuma !27_V	et	f	\N
154028	keskkute	?keskkute =kute  (SgN  >kesk+kute !06_S	et	f	\N
154044	põpandal	?põpandal =põpanda  (SgAd  >põpanda !01_S	et	f	\N
154057	pikal	pikal =pika  (SgAd  >pikk !22_S	et	f	\N
154058	pikal	pikal =pika  (SgAd  >pikk !22_AS	et	f	\N
154075	voim	?voim =voim  (SgN  >voim !22_S	et	f	\N
154081	rahvuseks	rahvuseks =rahvuse  (SgTr  >rahvus !11~09_S	et	f	\N
154083	rahvuseks	rahvuseks =seks  (SgN  >rahvu+seks !22_S	et	f	\N
154085	nõukogulikku	nõukogulikku =kogulikku  (SgP  >nõu+kogulik !25_A	et	f	\N
154086	nõukogulikku	nõukogulikku =kogulikku  (SgAdt  >nõu+kogulik !25_A	et	f	\N
154090	vares-barbaruse	?vares-barbaruse =barbaruse  (SgG  >vares-barbarus !11_S	et	f	\N
154104	kattuvad	kattuvad =kattu  (IndPrPl3  >kattuma !27_V	et	f	\N
154105	kattuvad	kattuvad =kattuva  (PlN  >kattuv !02_A	et	f	\N
154106	kattuvad	"kattuv %kattu  )V_vA  <kattuma ;27_V	et	f	\N
154115	k-ehitaja	k-ehitaja =ehitaja  (SgN  >k-ehitaja !01_S	et	f	\N
154116	k-ehitaja	"k-ehitaja %ehita  )JA_vS  <k-ehitama ;27_V	et	f	\N
154117	k-ehitaja	k-ehitaja =ehitaja  (SgG  >k-ehitaja !01_S	et	f	\N
154130	võtmine	võtmine =võtmine  (SgN  >võtmine !12?10_S	et	f	\N
154131	võtmine	"võtmine %võt  )MINE_vS  <võtma ;35_V	et	f	\N
154142	lõpetadi	### lõpetadi	et	f	\N
154145	täätajad	?täätajad =täätaja  (PlN  >täätaja !01_S	et	f	\N
154146	täätajad	?täätajad =täätaja  (PlN  >täätajas !02_A	et	f	\N
154166	sihilist	sihilist =sihilis  (SgP  >sihiline !12_A	et	f	\N
154167	sihilist	"sihiline %sihi  )LINE_aA  <siht ;22_S	et	f	\N
154005	esiks	?esiks =esi  (KndPrPs  >esima !27_V	et	f	\N
154009	veedelseep	?veedelseep =veedelseep  (SgN  >veedelseep !22_S	et	f	\N
154010	veedelseep	?veedelseep =delseep  (SgN  >vee+delseep !22_S	et	f	\N
154018	tanavas	?tanavas =tanava  (SgIn  >tanava !01_S	et	f	\N
154020	tanavas	?tanavas =tanava  (SgIn  >tanav !02_A	et	f	\N
154030	sisseköigus	?sisseköigus =sisseköigu  (IndIpfSg3  >sisseköiguma !27_V	et	f	\N
154031	sisseköigus	?sisseköigus =sisseköigus  (SgN  >sisseköigus !11~09_S	et	f	\N
154032	sisseköigus	?sisseköigus =köigu  (SgIn  >sisse+köigu !16_S	et	f	\N
154033	sisseköigus	?sisseköigus =köigus  (SgN  >sisse+köigus !11~09_S	et	f	\N
154036	riidekappid	### riidekappid	et	f	\N
154038	weel	?weel =wee  (SgAd  >wee !26_S	et	f	\N
154039	weel	?weel =weel  (SgN  >weel !22_S	et	f	\N
154040	sektsioonkappis	?sektsioonkappis =sektsioonkappi  (IndIpfSg3  >sektsioonkappima !28_V	et	f	\N
154041	sektsioonkappis	?sektsioonkappis =sektsioonkappis  (SgN  >sektsioonkappis !09_S	et	f	\N
154042	komputer	?komputer =komputer  (SgN  >komputer !19_S	et	f	\N
154043	komputer	?komputer =puter  (SgN  >kom+puter !02_S	et	f	\N
154046	televisor	?televisor =televisor  (SgN  >televisor !02_S	et	f	\N
154047	televisor	?televisor =visor  (SgN  >tele+visor !02_S	et	f	\N
154049	limmonad	### limmonad	et	f	\N
154082	kasvamise	kasvamise =kasvamise  (SgG  >kasvamine !12_S	et	f	\N
154084	kasvamise	"kasvamine %kasva  )MINE_vS  <kasvama ;28_V	et	f	\N
154087	unustamise	unustamise =unustamise  (SgG  >unustamine !12_S	et	f	\N
154088	unustamise	"unustamine %unusta  )MINE_vS  <unustama ;27_V	et	f	\N
154097	rahvagruppi	rahvagruppi =gruppi  (SgP  >rahva+grupp !22_S	et	f	\N
154098	rahvagruppi	rahvagruppi =gruppi  (SgAdt  >rahva+grupp !22_S	et	f	\N
154108	komunismiehitajad	?komunismiehitajad =komunismiehitaja  (PlN  >komunismiehitaja !01_S	et	f	\N
154110	komunismiehitajad	?komunismiehitajad =komunismiehitaja  (PlN  >komunismiehitajas !02_A	et	f	\N
154111	komunismiehitajad	?komunismiehitajad =smiehitaja  (PlN  >kom+uni+smiehitaja !01_S	et	f	\N
154112	komunismiehitajad	?komunismiehitajad =smiehitaja  (PlN  >kom+uni+smiehitajas !02_A	et	f	\N
154113	komunismiehitajad	?komunismiehitajad =unismiehitaja  (PlN  >kom+unismiehitaja !01_S	et	f	\N
154114	komunismiehitajad	?komunismiehitajad =unismiehitaja  (PlN  >kom+unismiehitajas !02_A	et	f	\N
154122	tootmine	tootmine =tootmine  (SgN  >tootmine !12?10_S	et	f	\N
154123	tootmine	"tootmine %toot  )MINE_vS  <tootma ;34_V	et	f	\N
154147	korralikku	korralikku =korralikku  (SgP  >korralik !25_A	et	f	\N
154148	korralikku	korralikku =korralikku  (SgAdt  >korralik !25_A	et	f	\N
154149	teineteisst	?teineteisst =teisst  (SgN  >teine+teisst !22_S	et	f	\N
154154	sihitud	sihitud =sihi  (PtsPtIps  >sihtima !28_V	et	f	\N
154155	sihitud	sihitud =sihitu  (PlN  >sihitu !01_AS	et	f	\N
154156	sihitud	"sihitu %sihi  )TU1_vS  <sihtima ;28_V	et	f	\N
154157	sihitud	"sihitu %sihi  )TU2_kA  <siht ;22_S	et	f	\N
154158	sihitud	sihitud =sihitud  (ID  >sihitud !41_A	et	f	\N
154159	sihitud	"sihitud %sihi  )TUD_vA  <sihtima ;28_V	et	f	\N
154162	sihitu	sihitu =sihitu  (SgN  >sihitu !01_AS	et	f	\N
154163	sihitu	"sihitu %sihi  )TU1_vS  <sihtima ;28_V	et	f	\N
154164	sihitu	"sihitu %sihi  )TU2_kA  <siht ;22_S	et	f	\N
154165	sihitu	sihitu =sihitu  (SgG  >sihitu !01_AS	et	f	\N
154168	pikenenud	pikenenud =pikene  (PtsPtPs  >pikenema !27_V	et	f	\N
154169	pikenenud	pikenenud =pikenenu  (PlN  >pikenenu !01_S	et	f	\N
154170	pikenenud	"pikenenu %pikene  )NU_vS  <pikenema ;27_V	et	f	\N
154171	pikenenud	pikenenud =pikenenud  (ID  >pikenenud !41_A	et	f	\N
154172	pikenenud	"pikenenud %pikene  )NUD_vA  <pikenema ;27_V	et	f	\N
154173	looduskeskkonda	looduskeskkonda =keskkonda  (SgP  >loodus+keskkond !22_S	et	f	\N
154174	looduskeskkonda	looduskeskkonda =keskkonda  (SgAdt  >loodus+keskkond !22_S	et	f	\N
154179	korriliku	?korriliku =korriliku  (SgG  >korrilik !25_A	et	f	\N
154180	korriliku	?korriliku =korriliku  (IndPrPs_  >korrilikuma !27_V	et	f	\N
154181	korriliku	?korriliku =korriliku  (ImpPrSg2  >korrilikuma !27_V	et	f	\N
154194	tekkides	tekkides =tekki  (PlIn  >tekk !22_S	et	f	\N
154195	tekkides	tekkides =tekki  (Ger  >tekkima !27~28_V	et	f	\N
154205	sele	?sele =sele  (SgN  >sele !16_S	et	f	\N
154206	sele	?sele =sele  (SgG  >sele !16_S	et	f	\N
154207	sele	?sele =sele  (IndPrPs_  >selema !27_V	et	f	\N
154208	sele	?sele =sele  (ImpPrSg2  >selema !27_V	et	f	\N
154215	kolmsaja	?kolmsaja =kolmsaja  (SgN  >kolmsaja !01_S	et	f	\N
154216	kolmsaja	?kolmsaja =kolmsaja  (SgG  >kolmsaja !01_S	et	f	\N
154217	kolmsaja	?kolmsaja =kolmsaja  (SgG  >kolmsajas !02_A	et	f	\N
154218	kolmsaja	?kolmsaja =saja  (SgN  >kolm+saja !17_S	et	f	\N
154219	kolmsaja	?kolmsaja =saja  (SgG  >kolm+saja !17_S	et	f	\N
154220	kolmsaja	?kolmsaja =saja  (SgP  >kolm+saja !17_S	et	f	\N
154234	vanemale	vanemale =vanema  (SgAll  >vanem !02_AS	et	f	\N
154235	vanemale	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
154236	vanemale	vanemale =ale  (SgN  >vanem+ale !16_S	et	f	\N
154237	vanemale	vanemale =ale  (SgG  >vanem+ale !16_S	et	f	\N
154247	hormer	?hormer =hormer  (SgN  >hormer !02_S	et	f	\N
154248	mõtisklemiseks	mõtisklemiseks =mõtisklemise  (SgTr  >mõtisklemine !12_S	et	f	\N
154250	mõtisklemiseks	"mõtisklemine %mõtiskle  )MINE_vS  <mõtisklema ;27_V	et	f	\N
154014	iimanraikastaja	?iimanraikastaja =iimanraikastaja  (SgN  >iimanraikastaja !01_S	et	f	\N
154015	iimanraikastaja	?iimanraikastaja =iimanraikastaja  (SgG  >iimanraikastaja !01_S	et	f	\N
154016	iimanraikastaja	?iimanraikastaja =iimanraikastaja  (SgG  >iimanraikastajas !02_A	et	f	\N
154034	sadakaheksa	?sadakaheksa =sadakaheksa  (SgN  >sadakaheksa !16_S	et	f	\N
154035	sadakaheksa	?sadakaheksa =sadakaheksa  (SgG  >sadakaheksa !16_S	et	f	\N
154037	lampid	### lampid	et	f	\N
154070	potis	potis =poti  (SgIn  >poti !16_S	et	f	\N
154071	potis	potis =poti  (SgIn  >pott !22_S	et	f	\N
154076	kohanemine	kohanemine =kohanemine  (SgN  >kohanemine !12_S	et	f	\N
154077	kohanemine	"kohanemine %kohane  )MINE_vS  <kohanema ;27_V	et	f	\N
154099	tääkohti	?tääkohti =tääkohti  (ID  >tääkohti !41_D	et	f	\N
154100	tääkohti	?tääkohti =tääkohti  (SgP  >tääkoht !22_S	et	f	\N
154101	tääkohti	?tääkohti =tääkohti  (SgAdt  >tääkoht !22_S	et	f	\N
154107	propaganda	propaganda =propaganda  (SgN  >propaganda !16_S	et	f	\N
154109	propaganda	propaganda =propaganda  (SgG  >propaganda !16_S	et	f	\N
154120	kasvatamise	kasvatamise =kasvatamise  (SgG  >kasvatamine !12_S	et	f	\N
154121	kasvatamise	"kasvatamine %kasvata  )MINE_vS  <kasvatama ;27_V	et	f	\N
154136	parteikomitee	parteikomitee =komitee  (SgN  >part+ei+komitee !26_S	et	f	\N
154137	parteikomitee	parteikomitee =komitee  (SgG  >part+ei+komitee !26_S	et	f	\N
154160	sihilised	sihilised =sihilise  (PlN  >sihiline !12_A	et	f	\N
154161	sihilised	"sihiline %sihi  )LINE_aA  <siht ;22_S	et	f	\N
154182	külapoodist	?külapoodist =külapoodi  (SgEl  >külapoodi !16_S	et	f	\N
154183	külapoodist	?külapoodist =külapoodi  (SgEl  >külapoot !22_S	et	f	\N
154184	külapoodist	?külapoodist =külapoodis  (SgP  >külapoodis !09_S	et	f	\N
154185	külapoodist	?külapoodist =poodi  (SgEl  >küla+poodi !16_S	et	f	\N
154186	külapoodist	?külapoodist =poodis  (SgP  >küla+poodis !09_S	et	f	\N
154187	külapoodist	?külapoodist =poodist  (SgN  >küla+poodist !22_S	et	f	\N
154223	naiselikkuks	?naiselikkuks =naiselikku  (KndPrPs  >naiselikkuma !27_V	et	f	\N
154224	naiselikkuks	?naiselikkuks =elikku  (SgTr  >nais+elikku !01_S	et	f	\N
154229	valmistusele	valmistusele =valmistuse  (SgAll  >valmistus !11_S	et	f	\N
154230	valmistusele	"valmistus %valmista  )US_vS  <valmistama ;27_V	et	f	\N
154257	piirituse	piirituse =piirituse  (SgG  >piiritus !11_S	et	f	\N
154258	piirituse	"piiritus %piiri  )TUS2_aS  <piir ;22_S	et	f	\N
154270	ebarahulikumaks	ebarahulikumaks =rahulikuma  (SgTr  >eba+rahulikum !02_A	et	f	\N
154271	ebarahulikumaks	"eba+rahulikum %rahuliku  )M_cA  <eba+rahulik ;25_A	et	f	\N
154282	äikest	äikest =äikes  (SgP  >äike !12?10_S	et	f	\N
154283	äikest	äikest =äikes  (SgP  >äikene !12?10_S	et	f	\N
154291	töötaksid	töötaksid =tööta  (KndPrSg2  >töötama !27_V	et	f	\N
154292	töötaksid	töötaksid =tööta  (KndPrPl3  >töötama !27_V	et	f	\N
154293	töötaksid	töötaksid =taksi  (PlN  >töö+taks !22_S	et	f	\N
154300	maksaks	maksaks =maksa  (SgTr  >maks !22_S	et	f	\N
154301	maksaks	maksaks =maksa  (KndPrPs  >maksma !32_V	et	f	\N
154315	mandrijää	mandrijää =jää  (SgN  >mandri+jää !26_S	et	f	\N
154316	mandrijää	mandrijää =jää  (SgG  >mandri+jää !26_S	et	f	\N
154332	mesoliitikumi	mesoliitikumi =mesoliitikumi  (SgG  >mesoliitikum !19_S	et	f	\N
154334	mesoliitikumi	mesoliitikumi =mesoliitikumi  (SgP  >mesoliitikum !19_S	et	f	\N
154336	mesoliitikumi	mesoliitikumi =mesoliitikumi  (SgAdt  >mesoliitikum !19_S	et	f	\N
154341	mesoliitikumist	mesoliitikumist =mesoliitikumi  (SgEl  >mesoliitikum !19_S	et	f	\N
154342	mesoliitikumist	mesoliitikumist =mesoliitikumis  (SgP  >mesoliitikumine !12_S	et	f	\N
154343	mesoliitikumist	"mesoliitikumine %mesoliitikumi  )NE_aA  <mesoliitikum ;19_S	et	f	\N
154368	hilis	?hilis =hili  (SgIn  >hili !17_S	et	f	\N
154369	hilis	?hilis =hili  (IndIpfSg3  >hilima !27_V	et	f	\N
154370	hilis	?hilis =hilis  (SgN  >hilis !09_S	et	f	\N
154376	sead	sead =sea  (PlN  >siga !18_SA	et	f	\N
154377	sead	sead =sea  (IndPrSg2  >seadma !34_V	et	f	\N
154378	sead	sead =sead  (SgN  >sead !22_S	et	f	\N
154397	jahimeeste	jahimeeste =mees  (PlG  >jahi+meene !10_A	et	f	\N
154398	jahimeeste	"jahi+meene %mee  )NE_aA  <jahi+mesi ;15_S	et	f	\N
154399	jahimeeste	jahimeeste =mees  (PlG  >jahi+mees !13_S	et	f	\N
154420	kodukondadega	?kodukondadega =kodukonda  (PlKom  >kodukonda !16_S	et	f	\N
154421	kodukondadega	?kodukondadega =kodukonda  (PlKom  >kodukond !22_S	et	f	\N
154422	kodukondadega	?kodukondadega =konda  (PlKom  >kodu+konda !16_S	et	f	\N
154423	kodukondadega	?kodukondadega =konda  (PlKom  >kodu+kond !22_S	et	f	\N
154431	päikesekivist	päikesekivist =kivi  (SgEl  >päikese+kivi !17_S	et	f	\N
154432	päikesekivist	päikesekivist =kivis  (SgP  >päikese+kivine !10_A	et	f	\N
154433	päikesekivist	"päikese+kivine %kivi  )NE_aA  <päikese+kivi ;17_S	et	f	\N
154441	pajad	pajad =paja  (PlN  >paja !17_S	et	f	\N
154443	pajad	pajad =paja  (PlN  >pada !18_S	et	f	\N
154444	venekirveste	venekirveste =kirves  (PlG  >vene+kirves !07_S	et	f	\N
154445	venekirveste	venekirveste =kirves  (PlG  >vene+kirvene !10_A	et	f	\N
154446	venekirveste	"vene+kirvene %kirve  )NE_aA  <vene+kirves ;07_S	et	f	\N
154447	venekirvestel	venekirvestel =kirves  (PlAd  >vene+kirves !07_S	et	f	\N
154448	venekirvestel	venekirvestel =kirves  (PlAd  >vene+kirvene !10_A	et	f	\N
154050	krenholmi	?krenholmi =krenholmi  (SgN  >krenholmi !01_S	et	f	\N
154051	krenholmi	?krenholmi =krenholmi  (SgG  >krenholmi !01_S	et	f	\N
154052	krenholmi	?krenholmi =krenholmi  (SgG  >krenholm !22_S	et	f	\N
154053	krenholmi	?krenholmi =krenholmi  (SgP  >krenholm !22_S	et	f	\N
154054	krenholmi	?krenholmi =krenholmi  (SgAdt  >krenholm !22_S	et	f	\N
154055	krenholmi	?krenholmi =krenholmi  (IndPrPs_  >krenholmima !28_V	et	f	\N
154056	krenholmi	?krenholmi =krenholmi  (ImpPrSg2  >krenholmima !28_V	et	f	\N
154059	viisteistkümmnes	?viisteistkümmnes =kümmne  (PlIn  >viis+teist+kümmn !22_S	et	f	\N
154060	viisteistkümmnes	?viisteistkümmnes =kümmnes  (SgN  >viis+teist+kümmnes !09_S	et	f	\N
154061	viisteistkümmnes	?viisteistkümmnes =teistkümmne  (PlIn  >viis+teistkümmn !22_S	et	f	\N
154062	raamatlaud	?raamatlaud =raamatlau  (PlN  >raamatlau !26_S	et	f	\N
154063	raamatlaud	?raamatlaud =raamatlau  (SgP  >raamatlau !26_S	et	f	\N
154064	raamatlaud	?raamatlaud =raamatlaud  (SgN  >raamatlaud !22_S	et	f	\N
154065	raamatlaud	?raamatlaud =atlau  (PlN  >raam+atlau !26_S	et	f	\N
154066	raamatlaud	?raamatlaud =atlau  (SgP  >raam+atlau !26_S	et	f	\N
154067	raamatlaud	?raamatlaud =atlaud  (SgN  >raam+atlaud !22_S	et	f	\N
154068	öökappi	öökappi =kappi  (SgP  >öö+kapp !22_S	et	f	\N
154069	öökappi	öökappi =kappi  (SgAdt  >öö+kapp !22_S	et	f	\N
154078	kirjeldavad	kirjeldavad =kirjelda  (IndPrPl3  >kirjeldama !27_V	et	f	\N
154079	kirjeldavad	kirjeldavad =kirjeldava  (PlN  >kirjeldav !02_A	et	f	\N
154080	kirjeldavad	"kirjeldav %kirjelda  )V_vA  <kirjeldama ;27_V	et	f	\N
154089	informante	?informante =informante  (PlP  >informant !22_S	et	f	\N
154091	vaesema	vaesema =vaesema  (SgG  >vaesem !02_A	et	f	\N
154092	vaesema	"vaesem %vae  )SEM_cA  <vaag ;22_S	et	f	\N
154093	vaesema	"vaesem %vaese  )M_cA  <vaene ;10_AS	et	f	\N
154094	vaesema	vaesema =ema  (SgN  >vaes+ema !17_S	et	f	\N
154095	vaesema	vaesema =ema  (SgG  >vaes+ema !17_S	et	f	\N
154096	vaesema	vaesema =ema  (SgP  >vaes+ema !17_S	et	f	\N
154102	inividuaalne	?inividuaalne =inividuaalne  (SgN  >inividuaalne !02_A	et	f	\N
154103	inividuaalne	?inividuaalne =inividuaalne  (PlP  >inividuaaln !22_S	et	f	\N
154127	komsomoli-	komsomoli- =komsomoli  (SgG  >komsomol !19_S	et	f	\N
154128	komsomoli-	komsomoli- =komsomoli  (SgP  >komsomol !19_S	et	f	\N
154129	komsomoli-	komsomoli- =komsomoli  (SgAdt  >komsomol !19_S	et	f	\N
154132	aaluda	?aaluda =aalu  (Inf  >aaluma !28_V	et	f	\N
154133	ajakirjanduslikus	ajakirjanduslikus =kirjandusliku  (SgIn  >aja+kirjanduslik !25_A	et	f	\N
154134	ajakirjanduslikus	ajakirjanduslikus =kirjanduslikus  (SgN  >aja+kirjanduslikus !11?09_S	et	f	\N
154135	ajakirjanduslikus	"aja+kirjanduslikus %kirjandusliku  )US_aS  <aja+kirjanduslik ;25_A	et	f	\N
154138	toimetajat	toimetajat =toimetaja  (SgP  >toimetaja !01_S	et	f	\N
154139	toimetajat	"toimetaja %toimeta  )JA_vS  <toimetama ;27_V	et	f	\N
154140	klapiks	klapiks =klapi  (SgTr  >klapp !22_S	et	f	\N
154141	klapiks	klapiks =klapi  (KndPrPs  >klappima !28_V	et	f	\N
154143	pruukimine	pruukimine =pruukimine  (SgN  >pruukimine !12_S	et	f	\N
154144	pruukimine	"pruukimine %pruuki  )MINE_vS  <pruukima ;28_V	et	f	\N
154150	lahus	lahus =lahu  (SgIn  >lahk !22_S	et	f	\N
154151	lahus	lahus =lahus  (ID  >lahus !41_D	et	f	\N
154152	lahus	lahus =lahus  (SgN  >lahus !09_S	et	f	\N
154175	muutab	?muutab =muuta  (IndPrSg3  >muutama !27_V	et	f	\N
154197	kõikis	?kõikis =kõiki  (IndIpfSg3  >kõikima !28_V	et	f	\N
154198	kõikis	?kõikis =kõikis  (SgN  >kõikis !11~09_S	et	f	\N
154203	päikelt	?päikelt =päike  (SgAbl  >päige !06_S	et	f	\N
154204	päikelt	?päikelt =päikelt  (ID  >päikelt !41_D	et	f	\N
154221	naeratamine	naeratamine =naeratamine  (SgN  >naeratamine !12_S	et	f	\N
154222	naeratamine	"naeratamine %naerata  )MINE_vS  <naeratama ;27_V	et	f	\N
154226	kogumine	kogumine =kogumine  (SgN  >kogumine !12_S	et	f	\N
154227	kogumine	"kogumine %kogu  )MINE_vS  <koguma ;27_V	et	f	\N
154228	kogumine	"kogumine %kogumi  )NE_aA  <kogum ;02_S	et	f	\N
154238	püksi	püksi =püksi  (SgG  >püks !23?22_S	et	f	\N
154239	püksi	püksi =püksi  (SgP  >püks !23?22_S	et	f	\N
154240	püksi	püksi =püksi  (SgAdt  >püks !23?22_S	et	f	\N
154251	müümine	müümine =müümine  (SgN  >müümine !12?10_S	et	f	\N
154252	müümine	"müümine %müü  )MINE_vS  <müüma ;38_V	et	f	\N
154259	leitenant	?leitenant =leitenant  (SgN  >leitenant !22_S	et	f	\N
154260	leitenant	?leitenant =enant  (SgN  >leit+enant !22_S	et	f	\N
154266	sissetoomist	sissetoomist =toomi  (SgEl  >sisse+toom !22_S	et	f	\N
154267	sissetoomist	sissetoomist =toomi  (PlEl  >sisse+toom !22_S	et	f	\N
154268	sissetoomist	sissetoomist =toomis  (SgP  >sisse+toomine !12?10_S	et	f	\N
154269	sissetoomist	"sisse+toomine %toomi  )NE_aA  <sisse+toom ;22_S	et	f	\N
154284	karistust	karistust =karistus  (SgP  >karistus !11_S	et	f	\N
154285	karistust	"karistus %karista  )US_vS  <karistama ;27_V	et	f	\N
154286	ausust	ausust =ausus  (SgP  >ausus !11~09_S	et	f	\N
154287	ausust	"ausus %au  )SUS_aS  <au ;26_S	et	f	\N
154288	ausust	"ausus %ausa  )US_aS  <aus ;02_A	et	f	\N
154302	narkootikumite	### narkootikumite	et	f	\N
154320	pulli	pulli =pulli  (SgG  >pull !22_S	et	f	\N
154321	pulli	pulli =pulli  (SgG  >pull !22_SA	et	f	\N
154188	mehedmehelikumaks	?mehedmehelikumaks =mehedmeheliku  (SupTr  >mehedmehelikuma !27_V	et	f	\N
154189	mehedmehelikumaks	?mehedmehelikumaks =mehedmehelikuma  (SgTr  >mehedmehelikum !02_A	et	f	\N
154190	mehedmehelikumaks	?mehedmehelikumaks =dmehelikuma  (SgTr  >mehe+dmehelikum !02_A	et	f	\N
154191	tooda	tooda =too  (IndPrIps_  >tooma !38_V	et	f	\N
154192	tooda	tooda =tooda  (IndPrPs_  >tootma !34_V	et	f	\N
154193	tooda	tooda =tooda  (ImpPrSg2  >tootma !34_V	et	f	\N
154253	salakaubandusest	salakaubandusest =kaubanduse  (SgEl  >sala+kaubandus !11_S	et	f	\N
154254	salakaubandusest	salakaubandusest =kaubanduses  (SgP  >sala+kaubandusene !12_A	et	f	\N
154255	salakaubandusest	"sala+kaubandusene %kaubanduse  )NE_aA  <sala+kaubandus ;11_S	et	f	\N
154272	võitleda	### võitleda	et	f	\N
154278	hirmud	hirmud =hirmu  (PlN  >hirm !22_S	et	f	\N
154279	hirmud	hirmud =hirmu  (IndPrSg2  >hirmuma !27_V	et	f	\N
154296	iseenna	?iseenna =iseenna  (SgN  >iseenna !16_S	et	f	\N
154297	iseenna	?iseenna =iseenna  (SgG  >iseenna !16_S	et	f	\N
154298	iseenna	?iseenna =enna  (SgN  >ise+enna !16_S	et	f	\N
154299	iseenna	?iseenna =enna  (SgG  >ise+enna !16_S	et	f	\N
154308	lastekoju	?lastekoju =lastekoju  (IndPrPs_  >lastekojuma !27_V	et	f	\N
154309	lastekoju	?lastekoju =lastekoju  (ImpPrSg2  >lastekojuma !27_V	et	f	\N
154312	ausus	ausus =ausus  (SgN  >ausus !11~09_S	et	f	\N
154313	ausus	"ausus %au  )SUS_aS  <au ;26_S	et	f	\N
154314	ausus	"ausus %ausa  )US_aS  <aus ;02_A	et	f	\N
154318	at	### at	et	f	\N
154328	küttimine	küttimine =küttimine  (SgN  >küttimine !12_S	et	f	\N
154329	küttimine	"küttimine %kütti  )MINE_vS  <küttima ;28_V	et	f	\N
154333	korjamine	korjamine =korjamine  (SgN  >korjamine !12_S	et	f	\N
154335	korjamine	"korjamine %korja  )MINE_vS  <korjama ;29_V	et	f	\N
154344	soo	soo =soo  (ID  >soo !41_I	et	f	\N
154345	soo	soo =soo  (SgN  >soo !26_S	et	f	\N
154346	soo	soo =soo  (SgG  >sugu !18_S	et	f	\N
154347	soo	soo =soo  (SgG  >soo !26_S	et	f	\N
154350	kalastajate	kalastajate =kalastaja  (PlG  >kalastaja !01_S	et	f	\N
154351	kalastajate	"kalastaja %kalasta  )JA_vS  <kalastama ;27_V	et	f	\N
154364	geomeetrilisi	geomeetrilisi =geomeetrilisi  (PlP  >geomeetriline !12_A	et	f	\N
154365	geomeetrilisi	"geomeetriline %geomeetri  )LINE_aA  <geomeeter ;02_S	et	f	\N
154366	geomeetrilisi	geomeetrilisi =meetrilisi  (PlP  >geo+meetriline !12_A	et	f	\N
154367	geomeetrilisi	"geo+meetriline %meetri  )LINE_aA  <geo+meeter ;02_S	et	f	\N
154371	nööri	nööri =nööri  (SgG  >nöör !22_S	et	f	\N
154372	nööri	nööri =nööri  (SgP  >nöör !22_S	et	f	\N
154373	nööri	nööri =nööri  (SgAdt  >nöör !22_S	et	f	\N
154374	nööri	nööri =nööri  (IndPrPs_  >nöörima !28_V	et	f	\N
154375	nööri	nööri =nööri  (ImpPrSg2  >nöörima !28_V	et	f	\N
154394	nahka	nahka =nahka  (ID  >nahka !41_D	et	f	\N
154395	nahka	nahka =nahka  (SgP  >nahk !22_S	et	f	\N
154396	nahka	nahka =nahka  (SgAdt  >nahk !22_S	et	f	\N
154403	kalanimetused	kalanimetused =nimetuse  (PlN  >kala+nimetus !11_S	et	f	\N
154404	kalanimetused	"kala+nimetus %nime  )TUS2_aS  <kala+nimi ;20_S	et	f	\N
154411	kobrast	kobrast =kobra  (SgEl  >kobra !16_S	et	f	\N
154412	kobrast	kobrast =kobras  (SgP  >kobras !07_S	et	f	\N
154413	kobrast	kobrast =kobras  (SgP  >kobrane !10_A	et	f	\N
154414	kobrast	"kobrane %kobra  )NE_aA  <kobra ;16_S	et	f	\N
154434	kiviputru	kiviputru =putru  (SgP  >kivi+puder !24_S	et	f	\N
154435	kiviputru	kiviputru =putru  (SgAdt  >kivi+puder !24_S	et	f	\N
154454	subtitreerimine	?subtitreerimine =subtitreerimine  (SgN  >subtitreerimine !12_S	et	f	\N
154455	subtitreerimine	?subtitreerimine =subtitreerimine  (PlP  >subtitreerimin !19_S	et	f	\N
154456	subtitreerimine	?subtitreerimine =titreerimine  (SgN  >sub+titreerimine !12_S	et	f	\N
154457	subtitreerimine	?subtitreerimine =titreerimine  (PlP  >sub+titreerimin !19_S	et	f	\N
154461	buschmann	?buschmann =buschmann  (SgN  >buschmann !22_S	et	f	\N
154464	poolitatud	poolitatud =poolita  (PtsPtIps  >poolitama !27_V	et	f	\N
154465	poolitatud	poolitatud =poolitatu  (PlN  >poolitatu !01_S	et	f	\N
154466	poolitatud	"poolitatu %poolita  )TU1_vS  <poolitama ;27_V	et	f	\N
154467	poolitatud	poolitatud =poolitatud  (ID  >poolitatud !41_A	et	f	\N
154468	poolitatud	"poolitatud %poolita  )TUD_vA  <poolitama ;27_V	et	f	\N
154474	tõlgimata	?tõlgimata =tõlgi  (SupAb  >tõlgima !28_V	et	f	\N
154475	tõlgimata	?tõlgimata =tõlgima  (SgAb  >tõlgim !02_A	et	f	\N
154476	tõlgimata	?tõlgimata =tõlgimata  (ID  >tõlgimata !41_A	et	f	\N
154477	tõlgimata	?tõlgimata =tõlgimata  (IndPrPs_  >tõlgimatama !27_V	et	f	\N
154478	tõlgimata	?tõlgimata =tõlgimata  (ImpPrSg2  >tõlgimatama !27_V	et	f	\N
154482	joey	### joey	et	f	\N
154485	subtiiter	subtiiter =subtiiter  (SgN  >subtiiter !02_S	et	f	\N
154486	subtiiter	subtiiter =tiiter  (SgN  >sub+tiiter !02_S	et	f	\N
154493	huck	?huck =huck  (SgN  >huck !22_S	et	f	\N
154501	lõpupunkti	lõpupunkti =punkti  (SgG  >lõpu+punkt !22_S	et	f	\N
154502	lõpupunkti	lõpupunkti =punkti  (SgP  >lõpu+punkt !22_S	et	f	\N
154503	lõpupunkti	lõpupunkti =punkti  (SgAdt  >lõpu+punkt !22_S	et	f	\N
154507	say	### say	et	f	\N
154515	lugemiskiirus	lugemiskiirus =kiiru  (SgIn  >lugemis+kiird !22_S	et	f	\N
154261	ülemused	ülemused =ülemuse  (PlN  >ülemus !11_S	et	f	\N
154262	ülemused	"ülemus %ülema  )US_aS  <ülem ;02_AS	et	f	\N
154280	karti	karti =karti  (SgP  >kart !22_S	et	f	\N
154281	karti	karti =karti  (SgAdt  >kart !22_S	et	f	\N
154289	väärtustati	väärtustati =väärtusta  (IndIpfIps  >väärtustama !27_V	et	f	\N
154290	väärtustati	väärtustati =tati  (SgG  >väärtus+tatt !22_S	et	f	\N
154294	ausaks	ausaks =ausa  (SgTr  >aus !02_A	et	f	\N
154295	ausaks	ausaks =saks  (SgN  >au+saks !23?22_S	et	f	\N
154303	levimisega	levimisega =levimise  (SgKom  >levimine !12_S	et	f	\N
154304	levimisega	"levimine %levi  )MINE_vS  <levima ;27_V	et	f	\N
154305	seadust	seadust =seadu  (SgEl  >sead !22_S	et	f	\N
154306	seadust	seadust =seadus  (SgP  >seadus !11~09_S	et	f	\N
154307	seadust	seadust =dust  (SgN  >sea+dust !22_S	et	f	\N
154317	ix	### ix	et	f	\N
154326	kütid	kütid =küti  (PlN  >kütt !22_S	et	f	\N
154327	kütid	kütid =küti  (IndPrSg2  >küttima !28_V	et	f	\N
154337	sirgete	sirgete =sirge  (PlG  >sirge !01_AS	et	f	\N
154339	sirgete	sirgete =e  (PlG  >sirg+esi !15_S	et	f	\N
154352	elamiskohti	elamiskohti =kohti  (SgP  >elamis+koht !22_S	et	f	\N
154353	elamiskohti	elamiskohti =kohti  (SgAdt  >elamis+koht !22_S	et	f	\N
154354	elamiskohti	elamiskohti =kohti  (PlP  >elamis+koht !22_S	et	f	\N
154357	kammi	kammi =kammi  (SgG  >kamm !22_S	et	f	\N
154358	kammi	kammi =kammi  (SgP  >kamm !22_S	et	f	\N
154359	kammi	kammi =kammi  (SgAdt  >kamm !22_S	et	f	\N
154360	kammi	kammi =kammi  (IndPrPs_  >kammima !28_V	et	f	\N
154361	kammi	kammi =kammi  (ImpPrSg2  >kammima !28_V	et	f	\N
154379	jälge	jälge =jälge  (SgP  >jälg !22_S	et	f	\N
154380	jälge	jälge =jälge  (SgAdt  >jälg !22_S	et	f	\N
154381	jälge	jälge =jälge  (PlP  >jälg !22_S	et	f	\N
154382	matmiskomme	matmiskomme =komme  (SgN  >matmis+komme !06_S	et	f	\N
154383	matmiskomme	matmiskomme =komme  (PlP  >matmis+komm !22_S	et	f	\N
154402	õitsenguaeg	?õitsenguaeg =õitsenguaeg  (SgN  >õitsenguaeg !22_S	et	f	\N
154405	hauk	?hauk =hauk  (SgN  >hauk !22_S	et	f	\N
154424	hoolisid	hoolisid =hooli  (IndIpfSg2  >hoolima !28_V	et	f	\N
154425	hoolisid	hoolisid =hooli  (IndIpfPl3  >hoolima !28_V	et	f	\N
154430	amuletidel	### amuletidel	et	f	\N
154458	grosberg	?grosberg =grosberg  (SgN  >grosberg !02_S	et	f	\N
154469	loetav	loetav =loe  (PtsPrIps  >lugema !28_V	et	f	\N
154470	loetav	loetav =loeta  (PtsPrPs  >loetama !27_V	et	f	\N
154471	loetav	loetav =loetav  (SgN  >loetav !02_AS	et	f	\N
154472	loetav	"loetav %loe  )TAV_vAS  <lugema ;28_V	et	f	\N
154473	loetav	"loetav %loeta  )V_vA  <loetama ;27_V	et	f	\N
154479	pöördas	?pöördas =pöörda  (SgIn  >pöörda !01_S	et	f	\N
154480	pöördas	?pöördas =pöörda  (IndIpfSg3  >pöördama !27_V	et	f	\N
154481	pöördas	?pöördas =pöördas  (SgN  >pöördas !07_S	et	f	\N
154491	kuzmina	?kuzmina =kuzmi  (SgEs  >kuzmi !16_S	et	f	\N
154492	kuzmina	?kuzmina =kuzmi  (SgEs  >kuzm !22_S	et	f	\N
154495	loogiliselt	loogiliselt =loogilise  (SgAbl  >loogiline !12_A	et	f	\N
154496	loogiliselt	"loogiline %loogi  )LINE_aA  <loog ;22_S	et	f	\N
154497	loogiliselt	loogiliselt =loogiliselt  (ID  >loogiliselt !41_D	et	f	\N
154498	loogiliselt	"loogiliselt %loogi  )LISELT_mD  <loog ;22_S	et	f	\N
154499	loogiliselt	"loogiliselt %loogilise  )LT_mD  <loogiline ;12_A	et	f	\N
154506	mrs	### mrs	et	f	\N
154508	please	?please =please  (SgN  >please !06_S	et	f	\N
154509	please	?please =please  (SgG  >please !06_S	et	f	\N
154510	please	?please =please  (SgG  >pleane !10_A	et	f	\N
154511	please	?please =please  (PlP  >pleas !22_S	et	f	\N
154513	please	?please =please  (IndPrPs_  >pleasema !28_V	et	f	\N
154514	please	?please =please  (ImpPrSg2  >pleasema !28_V	et	f	\N
154531	salapiirituse	salapiirituse =piirituse  (SgG  >sala+piiritus !11_S	et	f	\N
154532	salapiirituse	"sala+piiritus %piiri  )TUS2_aS  <sala+piir ;22_S	et	f	\N
154542	juhtuski	juhtuski =uski  (SgG  >juht+usk !22_S	et	f	\N
154543	juhtuski	juhtuski =uski  (SgP  >juht+usk !22_S	et	f	\N
154544	juhtuski	juhtuski =uski  (SgAdt  >juht+usk !22_S	et	f	\N
154545	juhtuski	juhtuski =juhtu  (IndIpfSg3^  >juhtuma !27_V	et	f	\N
154572	saatusest	saatusest =saatuse  (SgEl  >saatus !11~09_S	et	f	\N
154573	saatusest	saatusest =saatuses  (SgP  >saatusene !12_A	et	f	\N
154574	saatusest	"saatusene %saatuse  )NE_aA  <saatus ;09_S	et	f	\N
154575	saatusest	"saatusene %saatuse  )NE_aA  <saatus ;11_S	et	f	\N
154576	saatusest	saatusest =use  (PlEl  >saat+usk !22_S	et	f	\N
154603	polel	?polel =pole  (SgAd  >pole !16_S	et	f	\N
154604	polel	?polel =polel  (SgN  >polel !02_S	et	f	\N
154612	hakas	?hakas =haka  (SgIn  >haka !16_S	et	f	\N
154613	hakas	?hakas =haka  (IndIpfSg3  >hakama !27_V	et	f	\N
154614	hakas	?hakas =hakas  (SgN  >hakas !07_S	et	f	\N
154645	margusesse	?margusesse =marguse  (SgIll  >margus !11~09_S	et	f	\N
154646	margusesse	?margusesse =marguses  (SgAdt  >margusene !12_A	et	f	\N
154647	margusesse	?margusesse =margusesse  (SgG  >margusesne !02_A	et	f	\N
154648	margusesse	?margusesse =margusesse  (PlP  >margusess !22_S	et	f	\N
154649	tiinaga	?tiinaga =tiina  (SgKom  >tiina !16_S	et	f	\N
154274	lastud	lastud =lastu  (PlN  >lastu !01_S	et	f	\N
154275	lastud	"lastu %las  )TU1_vS  <laskma ;34_V	et	f	\N
154276	lastud	lastud =lastud  (ID  >lastud !41_A	et	f	\N
154277	lastud	"lastud %las  )TUD_vA  <laskma ;34_V	et	f	\N
154310	avaldamine	avaldamine =avaldamine  (SgN  >avaldamine !12_S	et	f	\N
154311	avaldamine	"avaldamine %avalda  )MINE_vS  <avaldama ;27_V	et	f	\N
154319	at	### at	et	f	\N
154330	metshobused	metshobused =hobuse  (PlN  >mets+hobune !10_S	et	f	\N
154331	metshobused	"mets+hobune %hobu  )NE_aA  <mets+hobu ;17_S	et	f	\N
154338	tumedama	tumedama =tumedama  (SgG  >tumedam !02_A	et	f	\N
154340	tumedama	"tumedam %tumeda  )M_cA  <tume ;02_A	et	f	\N
154362	kujuline	kujuline =kujuline  (SgN  >kujuline !12_A	et	f	\N
154363	kujuline	"kujuline %kuju  )LINE_aA  <kuju ;17_S	et	f	\N
154384	püstkoda	püstkoda =koda  (SgN  >püst+koda !18_S	et	f	\N
154385	püstkoda	püstkoda =koda  (SgP  >püst+koda !18_S	et	f	\N
154400	korjajate	korjajate =korjaja  (PlG  >korjaja !01_S	et	f	\N
154401	korjajate	"korjaja %korja  )JA_vS  <korjama ;29_V	et	f	\N
154408	küttisid	küttisid =kütti  (PlP  >kütt !22_S	et	f	\N
154409	küttisid	küttisid =kütti  (IndIpfSg2  >küttima !28_V	et	f	\N
154410	küttisid	küttisid =kütti  (IndIpfPl3  >küttima !28_V	et	f	\N
154426	loomakujukesi	loomakujukesi =kujukesi  (PlP  >looma+kujuke !12_S	et	f	\N
154427	loomakujukesi	"looma+kujuke %kuju  )KE_dS  <looma+kuju ;17_S	et	f	\N
154428	loomakujukesi	loomakujukesi =kujukesi  (PlP  >looma+kujukene !12_S	et	f	\N
154429	loomakujukesi	"looma+kujukene %kuju  )KENE_dS  <looma+kuju ;17_S	et	f	\N
154436	keraamikatüüp	?keraamikatüüp =keraamikatüüp  (SgN  >keraamikatüüp !22_S	et	f	\N
154437	keraamikatüüp	?keraamikatüüp =amikatüüp  (SgN  >kera+amikatüüp !22_S	et	f	\N
154438	geomeetriliste	geomeetriliste =geomeetrilis  (PlG  >geomeetriline !12_A	et	f	\N
154439	geomeetriliste	"geomeetriline %geomeetri  )LINE_aA  <geomeeter ;02_S	et	f	\N
154440	geomeetriliste	geomeetriliste =meetrilis  (PlG  >geo+meetriline !12_A	et	f	\N
154442	geomeetriliste	"geo+meetriline %meetri  )LINE_aA  <geo+meeter ;02_S	et	f	\N
154450	arheoloogiliste	arheoloogiliste =arheoloogilis  (PlG  >arheoloogiline !12_A	et	f	\N
154451	arheoloogiliste	"arheoloogiline %arheoloogi  )LINE_aA  <arheoloog ;22_S	et	f	\N
154494	leemets	?leemets =leemets  (SgN  >leemets !02_S	et	f	\N
154500	grammatilst	### grammatilst	et	f	\N
154504	sir	### sir	et	f	\N
154522	laitmatu	laitmatu =laitmatu  (SgN  >laitmatu !01_A	et	f	\N
154523	laitmatu	"laitmatu %lait  )MATU_vA  <laitma ;34_V	et	f	\N
154524	laitmatu	laitmatu =laitmatu  (SgG  >laitmatu !01_A	et	f	\N
154539	rääkid	### rääkid	et	f	\N
154546	aleksist	?aleksist =aleksi  (SgEl  >aleksi !01_S	et	f	\N
154547	aleksist	?aleksist =aleksis  (SgP  >aleksis !11_S	et	f	\N
154548	aleksist	?aleksist =aleksist  (SgN  >aleksist !22_S	et	f	\N
154549	aleksist	?aleksist =ksist  (SgN  >ale+ksist !22_S	et	f	\N
154555	peategelanna	?peategelanna =peategelanna  (SgN  >peategelanna !16_S	et	f	\N
154556	peategelanna	?peategelanna =peategelanna  (SgG  >peategelanna !16_S	et	f	\N
154557	peategelanna	?peategelanna =tegelanna  (SgN  >pea+tegelanna !16_S	et	f	\N
154558	peategelanna	?peategelanna =tegelanna  (SgG  >pea+tegelanna !16_S	et	f	\N
154562	koormust	koormust =koormus  (SgP  >koormus !11~09_S	et	f	\N
154563	koormust	koormust =must  (SgN  >koor+must !22_AS	et	f	\N
154590	teeninud	teeninud =teeni  (PtsPtPs  >teenima !28_V	et	f	\N
154591	teeninud	teeninud =teeninu  (PlN  >teeninu !01_S	et	f	\N
154592	teeninud	"teeninu %teeni  )NU_vS  <teenima ;28_V	et	f	\N
154593	teeninud	teeninud =teeninud  (ID  >teeninud !41_A	et	f	\N
154594	teeninud	"teeninud %teeni  )NUD_vA  <teenima ;28_V	et	f	\N
154595	talvine	talvine =talvine  (SgN  >talvine !10_A	et	f	\N
154596	talvine	"talvine %talvi  )NE_aA  <talv ;22_S	et	f	\N
154608	saai	### saai	et	f	\N
154615	kitzbergi	?kitzbergi =kitzbergi  (SgG  >kitzberg !02_S	et	f	\N
154616	kitzbergi	?kitzbergi =kitzbergi  (SgG  >kitzberk !22_S	et	f	\N
154617	kitzbergi	?kitzbergi =kitzbergi  (IndPrPs_  >kitzberkima !28_V	et	f	\N
154618	kitzbergi	?kitzbergi =kitzbergi  (ImpPrSg2  >kitzberkima !28_V	et	f	\N
154619	kitzbergi	?kitzbergi =kitzber  (SgN^  >kitzber !02_S	et	f	\N
154620	peetuna	peetuna =peetu  (SgEs  >peetu !01_SA	et	f	\N
154621	peetuna	"peetu %pee  )TU1_vS  <pidama ;28_V	et	f	\N
154627	tüdrukon	?tüdrukon =tüdrukon  (SgN  >tüdrukon !19_S	et	f	\N
154631	tiinat	?tiinat =tiina  (SgP  >tiina !16_S	et	f	\N
154632	tiinat	?tiinat =tiinat  (SgN  >tiinat !02_S	et	f	\N
154635	käitumist	käitumist =käitumis  (SgP  >käitumine !12_S	et	f	\N
154636	käitumist	"käitumine %käitu  )MINE_vS  <käituma ;27_V	et	f	\N
154655	professionaalsemaks	professionaalsemaks =professionaalsema  (SgTr  >professionaalsem !02_A	et	f	\N
154656	professionaalsemaks	"professionaalsem %professionaalse  )M_cA  <professionaalne ;02_A	et	f	\N
154669	läänepoolsemat	läänepoolsemat =poolsema  (SgP  >lääne+poolsem !02_A	et	f	\N
154670	läänepoolsemat	"lääne+poolsem %poolse  )M_cA  <lääne+poolne ;02_A	et	f	\N
154672	beatles	?beatles =beatle  (SgIn  >beatle !06_S	et	f	\N
154673	beatles	?beatles =beatle  (IndIpfSg3  >beatlema !30_V	et	f	\N
154674	beatles	?beatles =beatles  (SgN  >beatles !09_S	et	f	\N
154322	pulli	pulli =pulli  (SgP  >pull !22_S	et	f	\N
154323	pulli	pulli =pulli  (SgP  >pull !22_SA	et	f	\N
154324	pulli	pulli =pulli  (SgAdt  >pull !22_S	et	f	\N
154325	pulli	pulli =pulli  (SgAdt  >pull !22_SA	et	f	\N
154348	osalevamaks	osalevamaks =osalevama  (SgTr  >osalevam !02_A	et	f	\N
154349	osalevamaks	"osalevam %osale  )VAM_cA  <osalema ;27_V	et	f	\N
154355	lõke	lõke =lõke  (SgN  >lõke !05_S	et	f	\N
154356	lõke	lõke =lõke  (SgN  >lõke !06_S	et	f	\N
154386	sindi	?sindi =sindi  (SgN  >sindi !16_S	et	f	\N
154387	sindi	?sindi =sindi  (SgG  >sindi !16_S	et	f	\N
154388	sindi	?sindi =sindi  (SgG  >sint !22_S	et	f	\N
154389	sindi	?sindi =sindi  (SgP  >sind !22_S	et	f	\N
154390	sindi	?sindi =sindi  (SgAdt  >sind !22_S	et	f	\N
154391	sindi	?sindi =sindi  (IndPrPs_  >sintima !28_V	et	f	\N
154392	sindi	?sindi =sindi  (ImpPrSg2  >sintima !28_V	et	f	\N
154393	põhjapõtraküttid	### põhjapõtraküttid	et	f	\N
154406	põhjapõtra	põhjapõtra =põtra  (SgP  >põhja+põder !24_S	et	f	\N
154407	põhjapõtra	põhjapõtra =põtra  (SgAdt  >põhja+põder !24_S	et	f	\N
154415	väiksemaid	väiksemaid =väiksema  (PlP  >väiksem !02_A	et	f	\N
154416	väiksemaid	"väiksem %väikse  )M_cA  <väike ;10_A	et	f	\N
154417	väiksemaid	väiksemaid =ma  (PlP  >väikse+maa !26_S	et	f	\N
154418	väiksemaid	väiksemaid =mai  (PlN  >väikse+mai !26_S	et	f	\N
154419	väiksemaid	väiksemaid =mai  (SgP  >väikse+mai !26_S	et	f	\N
154483	subtiiter	subtiiter =subtiiter  (SgN  >subtiiter !02_S	et	f	\N
154484	subtiiter	subtiiter =tiiter  (SgN  >sub+tiiter !02_S	et	f	\N
154487	punktiga	punktiga =punkti  (SgKom  >punkt !22_S	et	f	\N
154488	punktiga	punktiga =iga  (SgN  >punkt+iga !18_S	et	f	\N
154489	punktiga	punktiga =iga  (SgP  >punkt+iga !18_S	et	f	\N
154512	thank	?thank =thank  (SgN  >thank !22_S	et	f	\N
154525	volmeri	?volmeri =volmeri  (SgN  >volmeri !01_S	et	f	\N
154526	volmeri	?volmeri =volmeri  (SgG  >volmeri !01_S	et	f	\N
154527	volmeri	?volmeri =volmeri  (SgG  >volmer !02_S	et	f	\N
154528	1920-ndate	?-ndate =ndate  (SgN  >-ndate !06_S	et	f	\N
154529	1920-ndate	?-ndate =ndate  (IndPrPs_  >-ndatema !27_V	et	f	\N
154530	1920-ndate	?-ndate =ndate  (ImpPrSg2  >-ndatema !27_V	et	f	\N
154536	mõru	mõru =mõru  (SgN  >mõru !17_A	et	f	\N
154537	mõru	mõru =mõru  (SgG  >mõru !17_A	et	f	\N
154538	mõru	mõru =mõru  (SgP  >mõru !17_A	et	f	\N
154564	peabki	peabki =pea  (IndPrSg3^  >pida !40_V	et	f	\N
154565	peabki	peabki =pea  (IndPrSg3^  >pidama !28_V	et	f	\N
154581	aususe	aususe =aususe  (SgG  >ausus !11~09_S	et	f	\N
154582	aususe	"ausus %au  )SUS_aS  <au ;26_S	et	f	\N
154583	aususe	"ausus %ausa  )US_aS  <aus ;02_A	et	f	\N
154628	tammaru	tammaru =aru  (SgN  >tamm+aru !17_S	et	f	\N
154629	tammaru	tammaru =aru  (SgG  >tamm+aru !17_S	et	f	\N
154630	tammaru	tammaru =aru  (SgP  >tamm+aru !17_S	et	f	\N
154650	19601970ndatel	?ndatel =ndate  (PlAd  >ndatt !22_S	et	f	\N
154651	19601970ndatel	?ndatel =ndatel  (SgN  >ndatel !02_S	et	f	\N
154660	komissarov	?komissarov =komissarov  (SgN  >komissarov !02_A	et	f	\N
154661	komissarov	?komissarov =issarov  (SgN  >kom+issarov !02_A	et	f	\N
154680	rüivad	?rüivad =rüiva  (PlN  >rüiva !16_S	et	f	\N
154681	rüivad	?rüivad =rüiva  (IndPrSg2  >rüivama !29_V	et	f	\N
154689	vabadusena	vabadusena =vabaduse  (SgEs  >vabadus !11_S	et	f	\N
154691	vabadusena	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
154706	teadvustanud	teadvustanud =teadvusta  (PtsPtPs  >teadvustama !27_V	et	f	\N
154707	teadvustanud	teadvustanud =teadvustanu  (PlN  >teadvustanu !01_S	et	f	\N
154708	teadvustanud	"teadvustanu %teadvusta  )NU_vS  <teadvustama ;27_V	et	f	\N
154709	teadvustanud	teadvustanud =teadvustanud  (ID  >teadvustanud !41_A	et	f	\N
154710	teadvustanud	"teadvustanud %teadvusta  )NUD_vA  <teadvustama ;27_V	et	f	\N
154711	teadvustanud	teadvustanud =tanu  (PlN  >teadvus+tanu !17_S	et	f	\N
154733	sisustus	sisustus =sisustus  (SgN  >sisustus !11_S	et	f	\N
154734	sisustus	"sisustus %sisusta  )US_vS  <sisustama ;27_V	et	f	\N
154751	iseseisav	?iseseisav =iseseisav  (SgN  >iseseisav !02_A	et	f	\N
154752	iseseisav	?iseseisav =seisav  (SgN  >ise+seisav !02_A	et	f	\N
154756	läkin	?läkin =läki  (IndPrSg1  >läkima !27_V	et	f	\N
154757	läkin	?läkin =läki  (IndPrSg1  >läkkima !28_V	et	f	\N
154758	läkin	?läkin =läkin  (SgN  >läkin !02_S	et	f	\N
154811	sotsialistliku-realismi	sotsialistliku-realismi =realismi  (SgG  >sotsialistliku-realism !22_S	et	f	\N
154812	sotsialistliku-realismi	sotsialistliku-realismi =realismi  (SgP  >sotsialistliku-realism !22_S	et	f	\N
154813	sotsialistliku-realismi	sotsialistliku-realismi =realismi  (SgAdt  >sotsialistliku-realism !22_S	et	f	\N
154837	avatumaks	avatumaks =avatuma  (SgTr  >avatum !02_A	et	f	\N
154838	avatumaks	"avatum %ava  )TUM1_cA  <avama ;27_V	et	f	\N
154839	avatumaks	"avatum %ava  )TUM2_cA  <ava ;17_S	et	f	\N
154848	apärt	?apärt =apärt  (SgN  >apärt !22_S	et	f	\N
154858	uuris	uuris =uuri  (SgIn  >uur !22_S	et	f	\N
154859	uuris	uuris =uuri  (IndIpfSg3  >uurima !28_V	et	f	\N
154860	uuris	uuris =uuris  (SgN  >uuris !09_S	et	f	\N
154883	paremuse	paremuse =paremuse  (SgG  >paremus !11_S	et	f	\N
154449	venekirvestel	"vene+kirvene %kirve  )NE_aA  <vene+kirves ;07_S	et	f	\N
154452	kaevandamiste	kaevandamiste =kaevandamis  (PlG  >kaevandamine !12_S	et	f	\N
154453	kaevandamiste	"kaevandamine %kaevanda  )MINE_vS  <kaevandama ;27_V	et	f	\N
154459	janno	?janno =janno  (SgN  >janno !16_S	et	f	\N
154460	janno	?janno =janno  (SgG  >janno !16_S	et	f	\N
154462	loogilises	loogilises =loogilise  (SgIn  >loogiline !12_A	et	f	\N
154463	loogilises	"loogiline %loogi  )LINE_aA  <loog ;22_S	et	f	\N
154490	pbk	### pbk	et	f	\N
154505	mr	### mr	et	f	\N
154533	halastamatu	halastamatu =halastamatu  (SgN  >halastamatu !01_A	et	f	\N
154534	halastamatu	"halastamatu %halasta  )MATU_vA  <halastama ;27_V	et	f	\N
154535	halastamatu	halastamatu =halastamatu  (SgG  >halastamatu !01_A	et	f	\N
154540	rikkuvad	rikkuvad =rikkuva  (PlN  >rikkuv !02_A	et	f	\N
154541	rikkuvad	"rikkuv %rikku  )V_vA  <rikkuma ;28_V	et	f	\N
154559	tõelises	tõelises =tõelise  (SgIn  >tõeline !12?10_A	et	f	\N
154560	tõelises	"tõeline %tõe  )LINE_aA  <tõsi ;15_S	et	f	\N
154561	tõelises	"tõeline %tõe  )LINE_aA  <tõde ;18_S	et	f	\N
154577	vihata	vihata =viha  (SgAb  >viha !17_SA	et	f	\N
154578	vihata	vihata =viha  (SgAb  >viht !22_S	et	f	\N
154579	vihata	vihata =viha  (Inf  >vihkama !29_V	et	f	\N
154580	vihata	vihata =viha  (IndPrIps_  >vihkama !29_V	et	f	\N
154584	võivaletada	?võivaletada =võivaleta  (Inf  >võivaletama !27_V	et	f	\N
154585	võivaletada	?võivaletada =tada  (SgN  >või+vale+tada !17_S	et	f	\N
154586	võivaletada	?võivaletada =tada  (SgG  >või+vale+tada !17_S	et	f	\N
154587	võivaletada	?võivaletada =tada  (SgP  >või+vale+tada !17_S	et	f	\N
154588	valetamist	valetamist =valetamis  (SgP  >valetamine !12_S	et	f	\N
154589	valetamist	"valetamine %valeta  )MINE_vS  <valetama ;27_V	et	f	\N
154600	kooksis	?kooksis =kooksi  (SgIn  >kooks !22_S	et	f	\N
154601	kooksis	?kooksis =kooksi  (IndIpfSg3  >kooksima !28_V	et	f	\N
154602	kooksis	?kooksis =kooksis  (SgN  >kooksis !09_S	et	f	\N
154609	traumid	?traumid =traumi  (PlN  >traumi !16_S	et	f	\N
154610	traumid	?traumid =traumi  (PlN  >traum !22_S	et	f	\N
154611	traumid	?traumid =traumi  (IndPrSg2  >traumima !28_V	et	f	\N
154622	hukatud	hukatud =huka  (PtsPtIps  >hukkama !29_V	et	f	\N
154623	hukatud	hukatud =hukatu  (PlN  >hukatu !01_S	et	f	\N
154624	hukatud	"hukatu %huka  )TU1_vS  <hukkama ;29_V	et	f	\N
154625	hukatud	hukatud =hukatud  (ID  >hukatud !41_A	et	f	\N
154626	hukatud	"hukatud %huka  )TUD_vA  <hukkama ;29_V	et	f	\N
154633	süüdistasid	süüdistasid =süüdista  (IndIpfSg2  >süüdistama !27_V	et	f	\N
154634	süüdistasid	süüdistasid =süüdista  (IndIpfPl3  >süüdistama !27_V	et	f	\N
154637	margusest	?margusest =marguse  (SgEl  >margus !11~09_S	et	f	\N
154638	margusest	?margusest =marguses  (SgP  >margusene !12_A	et	f	\N
154642	elavam	elavam =elavam  (SgN  >elavam !02_A	et	f	\N
154643	elavam	"elavam %ela  )VAM_cA  <elama ;27_V	et	f	\N
154644	elavam	"elavam %elava  )M_cA  <elav ;02_A	et	f	\N
154668	jõnn	?jõnn =jõnn  (SgN  >jõnn !22_S	et	f	\N
154677	realismi	realismi =realismi  (SgG  >realism !22_S	et	f	\N
154678	realismi	realismi =realismi  (SgP  >realism !22_S	et	f	\N
154679	realismi	realismi =realismi  (SgAdt  >realism !22_S	et	f	\N
154684	haarimiseks	?haarimiseks =haarimise  (SgTr  >haarimine !12_S	et	f	\N
154693	omanikutele	omanikutele =ute  (SgAll  >omanik+utt !22_S	et	f	\N
154694	omanikutele	omanikutele =ute  (PlAll  >omanik+utt !22_S	et	f	\N
154700	demoraatlikud	?demoraatlikud =demoraatliku  (PlN  >demoraatlik !25_A	et	f	\N
154701	demoraatlikud	?demoraatlikud =demoraatliku  (IndPrSg2  >demoraatlikuma !27_V	et	f	\N
154726	tollaegse	?tollaegse =tollaegse  (SgG  >tollaegne !02_A	et	f	\N
154727	tollaegse	?tollaegse =tollaegse  (PlP  >tollaegs !22_S	et	f	\N
154728	rezhisööril	?rezhisööril =rezhisööri  (SgAd  >rezhisööri !16_S	et	f	\N
154729	rezhisööril	?rezhisööril =rezhisööri  (SgAd  >rezhisöör !22_S	et	f	\N
154730	rezhisööril	?rezhisööril =rezhisööril  (SgN  >rezhisööril !02_S	et	f	\N
154739	põgenevad	põgenevad =põgene  (IndPrPl3  >põgenema !27_V	et	f	\N
154740	põgenevad	põgenevad =põgeneva  (PlN  >põgenev !02_A	et	f	\N
154741	põgenevad	"põgenev %põgene  )V_vA  <põgenema ;27_V	et	f	\N
154742	kulminatsiooniline	kulminatsiooniline =kulminatsiooniline  (SgN  >kulminatsiooniline !12_A	et	f	\N
154743	kulminatsiooniline	"kulminatsiooniline %kulminatsiooni  )LINE_aA  <kulminatsioon ;22_S	et	f	\N
154744	rünnatamine	?rünnatamine =rünnatamine  (SgN  >rünnatamine !12_S	et	f	\N
154745	rünnatamine	?rünnatamine =rünnatamine  (PlP  >rünnatamin !19_S	et	f	\N
154792	hrushtshov	?hrushtshov =hrushtshov  (SgN  >hrushtshov !02_A	et	f	\N
154800	rängalt	rängalt =ränga  (SgAbl  >ränk !22_A	et	f	\N
154801	rängalt	rängalt =rängalt  (ID  >rängalt !41_D	et	f	\N
154802	rängalt	"rängalt %ränga  )LT_mD  <ränk ;22_A	et	f	\N
154814	kontakti	kontakti =kontakti  (SgG  >kontakt !22_S	et	f	\N
154815	kontakti	kontakti =kontakti  (SgP  >kontakt !22_S	et	f	\N
154816	kontakti	kontakti =kontakti  (SgAdt  >kontakt !22_S	et	f	\N
154820	jviiding	?jviiding =jviiding  (SgN  >jviiding !02_S	et	f	\N
154840	nähti	nähti =näh  (IndIpfIps  >nägema !28_V	et	f	\N
154841	nähti	nähti =nähti  (SgP  >näht !22_S	et	f	\N
154516	lugemiskiirus	lugemiskiirus =kiiru  (SgIn  >lugemis+kiir !22_S	et	f	\N
154517	lugemiskiirus	lugemiskiirus =kiirus  (SgN  >lugemis+kiirus !11~09_S	et	f	\N
154518	lugemiskiirus	"lugemis+kiirus %kiire  )US_aS  <lugemis+kiire ;01_A	et	f	\N
154519	sirgjoonelise	sirgjoonelise =joonelise  (SgG  >sirg+jooneline !12_A	et	f	\N
154520	sirgjoonelise	"sirg+jooneline %joone  )LINE_aA  <sirg+joon ;13_S	et	f	\N
154521	sirgjoonelise	"sirg+jooneline %jooneli  )NE_aA  <sirg+joonel ;02_S	et	f	\N
154550	hildast	?hildast =hilda  (SgEl  >hilda !16_S	et	f	\N
154551	hildast	?hildast =hildas  (SgP  >hildas !07_S	et	f	\N
154552	hildast	?hildast =hildas  (SgP  >hildane !10_A	et	f	\N
154553	vedajaid	vedajaid =vedaja  (PlP  >vedaja !01_S	et	f	\N
154554	vedajaid	"vedaja %veda  )JA_vS  <vedama ;28_V	et	f	\N
154566	aususest	aususest =aususe  (SgEl  >ausus !11~09_S	et	f	\N
154567	aususest	"ausus %au  )SUS_aS  <au ;26_S	et	f	\N
154568	aususest	"ausus %ausa  )US_aS  <aus ;02_A	et	f	\N
154569	aususest	aususest =aususes  (SgP  >aususene !12_A	et	f	\N
154570	aususest	"aususene %aususe  )NE_aA  <ausus ;09_S	et	f	\N
154571	aususest	"aususene %aususe  )NE_aA  <ausus ;11_S	et	f	\N
154597	lumene	?lumene =lumene  (SgN  >lumene !10_A	et	f	\N
154598	lumene	?lumene =lumene  (IndPrPs_  >lumenema !27_V	et	f	\N
154599	lumene	?lumene =lumene  (ImpPrSg2  >lumenema !27_V	et	f	\N
154605	kuulsis	?kuulsis =kuulsi  (SgIn  >kuuls !22_S	et	f	\N
154606	kuulsis	?kuulsis =kuulsi  (IndIpfSg3  >kuulsima !28_V	et	f	\N
154607	kuulsis	?kuulsis =kuulsis  (SgN  >kuulsis !09_S	et	f	\N
154639	tiinale	?tiinale =tiina  (SgAll  >tiina !16_S	et	f	\N
154640	tiinale	?tiinale =tiinale  (IndPrPs_  >tiinalema !27_V	et	f	\N
154641	tiinale	?tiinale =tiinale  (ImpPrSg2  >tiinalema !27_V	et	f	\N
154652	vaiksoo	vaiksoo =soo  (SgN  >vaik+soo !26_S	et	f	\N
154653	vaiksoo	vaiksoo =soo  (SgG  >vaik+sugu !18_S	et	f	\N
154654	vaiksoo	vaiksoo =soo  (SgG  >vaik+soo !26_S	et	f	\N
154657	nõutis	?nõutis =nõut  (IndIpfSg3  >nõutma !34_V	et	f	\N
154658	nõutis	?nõutis =nõuti  (IndIpfSg3  >nõutima !28_V	et	f	\N
154659	nõutis	?nõutis =nõutis  (SgN  >nõutis !11~09_S	et	f	\N
154662	filmirezhisöörina	?filmirezhisöörina =filmirezhisööri  (SgEs  >filmirezhisööri !16_S	et	f	\N
154663	filmirezhisöörina	?filmirezhisöörina =filmirezhisööri  (SgEs  >filmirezhisöör !22_S	et	f	\N
154664	filmirezhisöörina	?filmirezhisöörina =filmirezhisöörina  (SgG  >filmirezhisöörin !02_S	et	f	\N
154665	filmirezhisöörina	?filmirezhisöörina =rezhisööri  (SgEs  >filmi+rezhisööri !16_S	et	f	\N
154666	filmirezhisöörina	?filmirezhisöörina =rezhisööri  (SgEs  >filmi+rezhisöör !22_S	et	f	\N
154667	filmirezhisöörina	?filmirezhisöörina =rezhisöörina  (SgG  >filmi+rezhisöörin !02_S	et	f	\N
154671	rokkn	?rokkn =rokkn  (SgN  >rokkn !22_S	et	f	\N
154685	valistsus	?valistsus =valistsu  (SgIn  >valistsu !01_S	et	f	\N
154686	valistsus	?valistsus =valistsu  (IndIpfSg3  >valistsuma !27_V	et	f	\N
154687	valistsus	?valistsus =valistsus  (SgN  >valistsus !11~09_S	et	f	\N
154702	sofhoosid	?sofhoosid =sofhoo  (PlP  >sofhoo !26_S	et	f	\N
154703	sofhoosid	?sofhoosid =sofhoosi  (PlN  >sofhoosi !16_S	et	f	\N
154704	sofhoosid	?sofhoosid =sofhoosi  (PlN  >sofhoos !22_S	et	f	\N
154705	sofhoosid	?sofhoosid =sofhoosi  (IndPrSg2  >sofhoosima !28_V	et	f	\N
154712	eksistensionaalsed	?eksistensionaalsed =eksistensionaalse  (PlN  >eksistensionaalne !02_A	et	f	\N
154713	eksistensionaalsed	?eksistensionaalsed =stensionaalse  (PlN  >eksi+stensionaalne !02_A	et	f	\N
154714	eksistensionaalsed	?eksistensionaalsed =istensionaalse  (PlN  >eks+istensionaalne !02_A	et	f	\N
154737	dokumentaalkaadritest	dokumentaalkaadritest =test  (SgN  >dokumentaal+kaadri+test !22_S	et	f	\N
154738	dokumentaalkaadritest	dokumentaalkaadritest =kaadri  (PlEl  >dokumentaal+kaader !02_S	et	f	\N
154749	rohkemus	rohkemus =rohkemus  (SgN  >rohkemus !11_S	et	f	\N
154750	rohkemus	"rohkemus %rohkema  )US_aS  <rohkem ;02_A	et	f	\N
154753	tolajal	?tolajal =tolaja  (SgAd  >tolaja !01_S	et	f	\N
154754	tolajal	?tolajal =tolaja  (SgAd  >tolajas !02_A	et	f	\N
154755	tolajal	?tolajal =tolajal  (SgN  >tolajal !19_S	et	f	\N
154762	televiisori	televiisori =televiisori  (SgG  >televiisor !02_S	et	f	\N
154763	televiisori	televiisori =ori  (SgN  >tele+viis+ori !24_S	et	f	\N
154772	paelast	paelast =paela  (SgEl  >pael !23?22_S	et	f	\N
154773	paelast	paelast =paelas  (SgP  >paelane !12?10_S	et	f	\N
154774	paelast	"paelane %paela  )NE_aA  <pael ;22_S	et	f	\N
154775	paelast	"paelane %paela  )NE_aA  <pael ;23_S	et	f	\N
154776	paelast	paelast =ast  (SgN  >pael+ast !22_S	et	f	\N
154777	paelast	paelast =la  (SgEl  >pae+la !26_S	et	f	\N
154778	paelast	paelast =las  (SgP  >pae+laps !14_S	et	f	\N
154779	paelast	paelast =last  (SgN  >pae+last !22_S	et	f	\N
154780	gediminasest	?gediminasest =gediminase  (SgEl  >gediminane !12_A	et	f	\N
154781	gediminasest	?gediminasest =gediminases  (SgP  >gediminasene !12_A	et	f	\N
154786	luuletuses	luuletuses =luuletuse  (SgIn  >luuletus !11_S	et	f	\N
154787	luuletuses	"luuletus %luuleta  )US_vS  <luuletama ;27_V	et	f	\N
154788	luuletuses	"luuletus %luule  )TUS2_aS  <luule ;06_S	et	f	\N
154795	valitsesid	valitsesid =valitse  (IndIpfSg2  >valitsema !27_V	et	f	\N
154796	valitsesid	valitsesid =valitse  (IndIpfPl3  >valitsema !27_V	et	f	\N
154675	kassettide	kassettide =kassetti  (PlG  >kassett !22_S	et	f	\N
154676	kassettide	kassettide =setti  (PlG  >kas+sett !22_S	et	f	\N
154682	valuuta	valuuta =valuuta  (SgN  >valuuta !16_S	et	f	\N
154683	valuuta	valuuta =valuuta  (SgG  >valuuta !16_S	et	f	\N
154688	ümberõppima	?ümberõppima =ümberõppi  (Sup  >ümberõppima !28_V	et	f	\N
154690	ümberõppima	?ümberõppima =ümberõppima  (SgG  >ümberõppim !02_A	et	f	\N
154692	ümberõppima	?ümberõppima =õppima  (SgG  >ümber+õppim !02_A	et	f	\N
154695	tiitme	?tiitme =tiitme  (SgN  >tiitme !06_S	et	f	\N
154696	tiitme	?tiitme =tiitme  (SgG  >tiitme !06_S	et	f	\N
154697	tiitme	?tiitme =tiitme  (PlP  >tiitm !22_S	et	f	\N
154698	tiitme	?tiitme =tiitme  (IndPrPs_  >tiitmema !27_V	et	f	\N
154699	tiitme	?tiitme =tiitme  (ImpPrSg2  >tiitmema !27_V	et	f	\N
154731	tollaegne	?tollaegne =tollaegne  (SgN  >tollaegne !02_A	et	f	\N
154732	tollaegne	?tollaegne =tollaegne  (PlP  >tollaegn !22_S	et	f	\N
154735	kuulsid	kuulsid =kuul  (IndIpfSg2  >kuulma !33_V	et	f	\N
154736	kuulsid	kuulsid =kuul  (IndIpfPl3  >kuulma !33_V	et	f	\N
154747	hääletamine	hääletamine =hääletamine  (SgN  >hääletamine !12_S	et	f	\N
154748	hääletamine	"hääletamine %hääleta  )MINE_vS  <hääletama ;27_V	et	f	\N
154764	sulaperioodi	sulaperioodi =perioodi  (SgG  >sula+periood !22_S	et	f	\N
154765	sulaperioodi	sulaperioodi =perioodi  (SgP  >sula+periood !22_S	et	f	\N
154766	sulaperioodi	sulaperioodi =perioodi  (SgAdt  >sula+periood !22_S	et	f	\N
154767	aima	aima =aima  (SgG  >aim !22_S	et	f	\N
154768	aima	aima =aima  (SgP  >aim !22_S	et	f	\N
154769	aima	aima =aima  (SgAdt  >aim !22_S	et	f	\N
154770	aima	aima =aima  (IndPrPs_  >aimama !29_V	et	f	\N
154771	aima	aima =aima  (ImpPrSg2  >aimama !29_V	et	f	\N
154782	paimla	?paimla =paimla  (SgN  >paimla !01_S	et	f	\N
154783	paimla	?paimla =paimla  (SgG  >paimla !01_S	et	f	\N
154784	paimla	?paimla =paimla  (IndPrPs_  >paimlama !29_V	et	f	\N
154785	paimla	?paimla =paimla  (ImpPrSg2  >paimlama !29_V	et	f	\N
154793	liberaalsemate	liberaalsemate =liberaalsema  (PlG  >liberaalsem !02_A	et	f	\N
154794	liberaalsemate	"liberaalsem %liberaalse  )M_cA  <liberaalne ;02_A	et	f	\N
154803	elurõõmu	elurõõmu =rõõmu  (SgG  >elu+rõõm !22_S	et	f	\N
154804	elurõõmu	elurõõmu =rõõmu  (SgP  >elu+rõõm !22_S	et	f	\N
154805	elurõõmu	elurõõmu =rõõmu  (SgAdt  >elu+rõõm !22_S	et	f	\N
154821	mtraat	?mtraat =mtraat  (SgN  >mtraat !22_S	et	f	\N
154846	muusikud	muusikud =muusiku  (PlN  >muusik !02_S	et	f	\N
154847	muusikud	muusikud =siku  (PlN  >muu+sikk !22_S	et	f	\N
154868	kunstiajaloos	kunstiajaloos =loo  (SgIn  >kunsti+aja+lugu !18_S	et	f	\N
154869	kunstiajaloos	kunstiajaloos =loo  (SgIn  >kunsti+aja+loog !22_S	et	f	\N
154870	kunstiajaloos	kunstiajaloos =loo  (SgIn  >kunsti+aja+lood !22_S	et	f	\N
154871	kunstiajaloos	kunstiajaloos =loos  (SgN  >kunsti+aja+loos !22_S	et	f	\N
154872	küberneetika	küberneetika =küberneetika  (SgN  >küberneetika !01_S	et	f	\N
154873	küberneetika	küberneetika =küberneetika  (SgG  >küberneetika !01_S	et	f	\N
154895	käsi-käest	käsi-käest =käe  (SgEl  >käsi-käsi !15_S	et	f	\N
154896	käsi-käest	käsi-käest =käes  (SgP  >käsi-käene !10_A	et	f	\N
154897	käsi-käest	"käsi-käene %käe  )NE_aA  <käsi-käsi ;15_S	et	f	\N
154898	käsi-käest	käsi-käest =käest  (ID  >käsi-käest !41_DK	et	f	\N
154908	selgemaks	selgemaks =selgema  (SgTr  >selgem !02_A	et	f	\N
154909	selgemaks	"selgem %selge  )M_cA  <selge ;01_A	et	f	\N
154910	selgemaks	selgemaks =maks  (SgN  >selge+maks !22_S	et	f	\N
154911	selgemaks	selgemaks =ema  (SgTr  >selg+ema !17_S	et	f	\N
154923	gailiti	?gailiti =gaili  (IndIpfIps  >gailima !28_V	et	f	\N
154925	gailiti	?gailiti =gailiti  (ID  >gailiti !41_D	et	f	\N
154927	gailiti	?gailiti =gailiti  (SgG  >gailit !02_S	et	f	\N
154929	gailiti	?gailiti =gailiti  (SgG  >gailitt !22_S	et	f	\N
154931	gailiti	?gailiti =gailiti  (IndPrPs_  >gailittima !28_V	et	f	\N
154932	gailiti	?gailiti =gailiti  (ImpPrSg2  >gailittima !28_V	et	f	\N
154933	enesest	enesest =enese  (SgEl  >enese !00_P	et	f	\N
154934	enesest	enesest =enese  (SgEl  >ise !00_P	et	f	\N
154976	transiitmaa	transiitmaa =maa  (SgN  >transiit+maa !26_S	et	f	\N
154977	transiitmaa	transiitmaa =maa  (SgG  >transiit+maa !26_S	et	f	\N
155011	paide	paide =pai  (PlG  >pai !26_AS	et	f	\N
155012	paide	paide =paide  (SgN  >paide !01_H	et	f	\N
155013	paide	paide =paide  (SgG  >paide !01_H	et	f	\N
155033	piires	piires =piire  (PlIn  >piir !22_S	et	f	\N
155034	piires	piires =piires  (ID  >piires !41_K	et	f	\N
155069	väikevendiga	?väikevendiga =väikevendi  (SgKom  >väikevent !22_S	et	f	\N
155070	väikevendiga	?väikevendiga =vendi  (SgKom  >väike+vendi !16_S	et	f	\N
155071	väikevendiga	?väikevendiga =vendi  (SgKom  >väike+vent !22_S	et	f	\N
155072	väikevendiga	?väikevendiga =kevendi  (SgKom  >väi+kevendi !01_S	et	f	\N
155073	väikevendiga	?väikevendiga =kevendi  (SgKom  >väi+kevend !02_S	et	f	\N
155074	väikevendiga	?väikevendiga =kevendi  (SgKom  >väi+kevent !22_S	et	f	\N
155079	rockstar	?rockstar =rockstar  (SgN  >rockstar !02_S	et	f	\N
155082	dhead	?dhead =dhea  (PlN  >dhea !26_S	et	f	\N
155083	dhead	?dhead =dhea  (SgP  >dhea !26_S	et	f	\N
154715	sotsialismi-realismi	sotsialismi-realismi =realismi  (SgG  >sotsialismi-realism !22_S	et	f	\N
154716	sotsialismi-realismi	sotsialismi-realismi =realismi  (SgP  >sotsialismi-realism !22_S	et	f	\N
154717	sotsialismi-realismi	sotsialismi-realismi =realismi  (SgAdt  >sotsialismi-realism !22_S	et	f	\N
154718	paremasse	paremasse =parema  (SgIll  >parem !02_A	et	f	\N
154719	paremasse	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
154720	paremasse	paremasse =asse  (PlP  >parem+ass !22_S	et	f	\N
154721	erialse	?erialse =erialse  (SgG  >erialne !02_A	et	f	\N
154722	erialse	?erialse =erialse  (PlP  >erials !22_S	et	f	\N
154723	erialse	?erialse =alse  (SgN  >eri+alse !06_S	et	f	\N
154724	erialse	?erialse =alse  (SgG  >eri+alne !02_A	et	f	\N
154725	erialse	?erialse =alse  (PlP  >eri+als !22_S	et	f	\N
154746	tekstesines	?tekstesines =tekstesine  (PlIn  >tekstesin !19_S	et	f	\N
154759	emaja	?emaja =emaja  (SgN  >emaja !01_S	et	f	\N
154760	emaja	?emaja =emaja  (SgG  >emaja !01_S	et	f	\N
154761	emaja	?emaja =emaja  (SgG  >emajas !02_A	et	f	\N
154789	loengutes	loengutes =loengu  (PlIn  >loeng !02_S	et	f	\N
154790	loengutes	loengutes =ute  (SgIn  >loeng+utt !22_S	et	f	\N
154791	loengutes	loengutes =ute  (PlIn  >loeng+utt !22_S	et	f	\N
154822	nõrgenenud	nõrgenenud =nõrgene  (PtsPtPs  >nõrgenema !27_V	et	f	\N
154823	nõrgenenud	nõrgenenud =nõrgenenu  (PlN  >nõrgenenu !01_S	et	f	\N
154824	nõrgenenud	"nõrgenenu %nõrgene  )NU_vS  <nõrgenema ;27_V	et	f	\N
154825	nõrgenenud	nõrgenenud =nõrgenenud  (ID  >nõrgenenud !41_A	et	f	\N
154826	nõrgenenud	"nõrgenenud %nõrgene  )NUD_vA  <nõrgenema ;27_V	et	f	\N
154830	puhtast	puhtast =puhta  (SgEl  >puhas !07_A	et	f	\N
154831	puhtast	puhtast =ast  (SgN  >puht+ast !22_S	et	f	\N
154835	muutmisele	muutmisele =muutmise  (SgAll  >muutmine !12?10_S	et	f	\N
154836	muutmisele	"muutmine %muut  )MINE_vS  <muutma ;34_V	et	f	\N
154844	vabavärssi	vabavärssi =värssi  (SgP  >vaba+värss !22_S	et	f	\N
154845	vabavärssi	vabavärssi =värssi  (SgAdt  >vaba+värss !22_S	et	f	\N
154853	epresley	### epresley	et	f	\N
154856	pariste	?pariste =paris  (PlG  >paris !09_S	et	f	\N
154857	pariste	?pariste =pariste  (PlP  >parist !22_S	et	f	\N
154861	moora	?moora =moora  (SgN  >moora !16_S	et	f	\N
154862	moora	?moora =moora  (SgG  >moora !16_S	et	f	\N
154863	moora	?moora =moora  (IndPrPs_  >moorama !29_V	et	f	\N
154864	moora	?moora =moora  (ImpPrSg2  >moorama !29_V	et	f	\N
154879	60ndateks	?ndateks =ndate  (PlTr  >ndatt !22_S	et	f	\N
154880	60ndateks	?ndateks =ndate  (KndPrPs  >ndatema !27_V	et	f	\N
154893	ilmselgelt	ilmselgelt =selge  (SgAbl  >ilm+selge !01_A	et	f	\N
154894	ilmselgelt	"ilm+selgelt %selge  )LT_mD  <ilm+selge ;01_A	et	f	\N
154920	nipernaadi	?nipernaadi =nipernaadi  (SgN  >nipernaadi !16_S	et	f	\N
154921	nipernaadi	?nipernaadi =nipernaadi  (SgG  >nipernaadi !16_S	et	f	\N
154922	nipernaadi	?nipernaadi =nipernaadi  (SgG  >nipernaat !22_S	et	f	\N
154924	nipernaadi	?nipernaadi =nipernaadi  (SgP  >nipernaad !22_S	et	f	\N
154926	nipernaadi	?nipernaadi =nipernaadi  (SgAdt  >nipernaad !22_S	et	f	\N
154928	nipernaadi	?nipernaadi =nipernaadi  (IndPrPs_  >nipernaatima !28_V	et	f	\N
154930	nipernaadi	?nipernaadi =nipernaadi  (ImpPrSg2  >nipernaatima !28_V	et	f	\N
154950	ütelnud	ütelnud =ütel  (PtsPtPs  >ütlema !30_V	et	f	\N
154951	ütelnud	ütelnud =ütelnu  (PlN  >ütelnu !01_S	et	f	\N
154952	ütelnud	"ütelnu %ütel  )NU_vS  <ütlema ;30_V	et	f	\N
154953	ütelnud	ütelnud =ütelnud  (ID  >ütelnud !41_A	et	f	\N
154954	ütelnud	"ütelnud %ütel  )NUD_vA  <ütlema ;30_V	et	f	\N
154960	emotsiooni	emotsiooni =emotsiooni  (SgG  >emotsioon !22_S	et	f	\N
154961	emotsiooni	emotsiooni =emotsiooni  (SgP  >emotsioon !22_S	et	f	\N
154962	emotsiooni	emotsiooni =emotsiooni  (SgAdt  >emotsioon !22_S	et	f	\N
154996	vene-liivi	vene-liivi =liivi  (SgG  >vene-liiv !22_S	et	f	\N
154997	vene-liivi	vene-liivi =liivi  (SgP  >vene-liiv !22_S	et	f	\N
154998	vene-liivi	vene-liivi =liivi  (SgAdt  >vene-liiv !22_S	et	f	\N
155000	rikad	?rikad =rika  (PlN  >rika !16_S	et	f	\N
155001	rikad	?rikad =rika  (IndPrSg2  >rikama !27_V	et	f	\N
155004	uhkeid	uhkeid =uhke  (PlP  >uhke !01_A	et	f	\N
155005	uhkeid	uhkeid =uhke  (PlP  >uhe !06_S	et	f	\N
155008	rapla	?rapla =rapla  (ID  >rapla !41_D	et	f	\N
155009	rapla	?rapla =rapla  (IndPrPs_  >raplama !29_V	et	f	\N
155010	rapla	?rapla =rapla  (ImpPrSg2  >raplama !29_V	et	f	\N
155025	vähemaks	vähemaks =vähema  (SgTr  >vähem !02_A	et	f	\N
155026	vähemaks	"vähem %vähe  )M_cA  <väike ;10_A	et	f	\N
155027	vähemaks	vähemaks =maks  (SgN  >vähe+maks !22_S	et	f	\N
155037	maahärra	maahärra =härra  (SgN  >maa+härra !16_S	et	f	\N
155038	maahärra	maahärra =härra  (SgG  >maa+härra !16_S	et	f	\N
155045	kanepitaimi	?kanepitaimi =kanepitaimi  (SgN  >kanepitaimi !16_S	et	f	\N
155046	kanepitaimi	?kanepitaimi =kanepitaimi  (SgG  >kanepitaim !02_A	et	f	\N
155047	kanepitaimi	?kanepitaimi =kanepitaimi  (SgG  >kanepitaimi !16_S	et	f	\N
155048	kanepitaimi	?kanepitaimi =kanepitaimi  (IndPrPs_  >kanepitaimima !28_V	et	f	\N
155049	kanepitaimi	?kanepitaimi =kanepitaimi  (ImpPrSg2  >kanepitaimima !28_V	et	f	\N
155050	linnaelu	linnaelu =elu  (SgN  >linna+elu !17_S	et	f	\N
154797	loomeinimesi	loomeinimesi =esi  (SgN  >loome+inim+esi !15_S	et	f	\N
154798	loomeinimesi	loomeinimesi =esi  (PlP  >loome+inim+esi !15_S	et	f	\N
154799	loomeinimesi	loomeinimesi =inimesi  (PlP  >loome+inimene !12_S	et	f	\N
154806	järginud	järginud =järgi  (PtsPtPs  >järgima !27_V	et	f	\N
154807	järginud	järginud =järginu  (PlN  >järginu !01_S	et	f	\N
154808	järginud	"järginu %järgi  )NU_vS  <järgima ;27_V	et	f	\N
154809	järginud	järginud =järginud  (ID  >järginud !41_A	et	f	\N
154810	järginud	"järginud %järgi  )NUD_vA  <järgima ;27_V	et	f	\N
154817	põliste	põliste =põlis  (PlG  >põline !10_A	et	f	\N
154818	põliste	"põline %põli  )NE_aA  <põli ;24_S	et	f	\N
154819	eniit	?eniit =eniit  (SgN  >eniit !22_S	et	f	\N
154827	süzheed	?süzheed =süzhee  (PlN  >süzhee !26_S	et	f	\N
154828	süzheed	?süzheed =süzhee  (SgP  >süzhee !26_S	et	f	\N
154829	süzheed	?süzheed =süzheed  (SgN  >süzheed !22_S	et	f	\N
154832	psüühikasse	psüühikasse =psüühika  (SgIll  >psüühika !01_S	et	f	\N
154833	psüühikasse	psüühikasse =psüühikas  (SgAdt  >psüühikane !12_A	et	f	\N
154834	psüühikasse	"psüühikane %psüühika  )NE_aA  <psüühika ;01_S	et	f	\N
154849	läänelikku	?läänelikku =läänelikku  (SgP  >läänelik !25_A	et	f	\N
154850	läänelikku	?läänelikku =läänelikku  (SgAdt  >läänelik !25_A	et	f	\N
154851	läänelikku	?läänelikku =läänelikku  (IndPrPs_  >läänelikkuma !27_V	et	f	\N
154852	läänelikku	?läänelikku =läänelikku  (ImpPrSg2  >läänelikkuma !27_V	et	f	\N
154877	sotsioloogia	sotsioloogia =sotsioloogia  (SgN  >sotsioloogia !01_S	et	f	\N
154878	sotsioloogia	sotsioloogia =sotsioloogia  (SgG  >sotsioloogia !01_S	et	f	\N
154885	keskküla	keskküla =küla  (SgN  >kesk+küla !17_S	et	f	\N
154886	keskküla	keskküla =küla  (SgG  >kesk+küla !17_S	et	f	\N
154887	keskküla	keskküla =küla  (SgP  >kesk+küla !17_S	et	f	\N
154888	linastus	linastus =linastu  (IndIpfSg3  >linastuma !27_V	et	f	\N
154889	linastus	linastus =linastus  (SgN  >linastus !11_S	et	f	\N
154890	linastus	"linastus %linasta  )US_vS  <linastama ;27_V	et	f	\N
154892	60ndad	### 60ndad	et	f	\N
154914	ukuaru	ukuaru =aru  (SgN  >uku+aru !17_S	et	f	\N
154915	ukuaru	ukuaru =aru  (SgG  >uku+aru !17_S	et	f	\N
154916	ukuaru	ukuaru =aru  (SgP  >uku+aru !17_S	et	f	\N
154943	loov	loov =loo  (PtsPrPs  >looma !38_V	et	f	\N
154944	loov	loov =loov  (SgN  >loov !02_A	et	f	\N
154945	loov	"loov %loo  )V_vA  <looma ;38_V	et	f	\N
154948	margit	?margit =margit  (SgN  >margit !02_S	et	f	\N
154965	augustiputsh	?augustiputsh =putsh  (SgN  >augusti+putsh !22_S	et	f	\N
154966	augustiputsh	?augustiputsh =stiputsh  (SgN  >augu+stiputsh !22_S	et	f	\N
154980	baltimaades	baltimaades =maa  (PlIn  >balti+maa !26_S	et	f	\N
154981	baltimaades	baltimaades =maade  (PlIn  >balti+maat !22_S	et	f	\N
154987	palvesid	?palvesid =palve  (IndIpfSg2  >palvema !27_V	et	f	\N
154988	palvesid	?palvesid =palve  (IndIpfPl3  >palvema !27_V	et	f	\N
154994	kristlus	kristlus =kristlus  (SgN  >kristlus !11~09_S	et	f	\N
154995	kristlus	"kristlus %kristlase  )US_aS  <kristlane ;12_S	et	f	\N
155002	rikalt	?rikalt =rika  (SgAbl  >rika !16_S	et	f	\N
155003	rikalt	?rikalt =rikalt  (ID  >rikalt !41_D	et	f	\N
155018	mündistama	?mündistama =mündista  (Sup  >mündistama !27_V	et	f	\N
155019	mündistama	?mündistama =mündistama  (SgG  >mündistam !02_A	et	f	\N
155020	mündistama	?mündistama =stama  (SgN  >mündi+stama !17_S	et	f	\N
155021	mündistama	?mündistama =stama  (SgG  >mündi+stama !17_S	et	f	\N
155022	mündistama	?mündistama =stama  (SgP  >mündi+stama !17_S	et	f	\N
155035	põldu	põldu =põldu  (SgP  >põld !22_S	et	f	\N
155036	põldu	põldu =põldu  (SgAdt  >põld !22_S	et	f	\N
155058	takkistavad	?takkistavad =takkista  (IndPrPl3  >takkistama !27_V	et	f	\N
155059	takkistavad	?takkistavad =takkistava  (PlN  >takkistav !02_A	et	f	\N
155060	takkistavad	?takkistavad =takkistava  (PlN  >takkistava !16_S	et	f	\N
155068	xxs	### xxs	et	f	\N
155075	brasiliast	?brasiliast =brasilia  (SgEl  >brasilia !01_S	et	f	\N
155076	brasiliast	?brasiliast =brasilias  (SgP  >brasilias !11_S	et	f	\N
155088	absolutselt	?absolutselt =absolutse  (SgAbl  >absolutne !02_A	et	f	\N
155089	absolutselt	?absolutselt =absolutse  (PlAbl  >absoluts !22_S	et	f	\N
155090	absolutselt	?absolutselt =absolutselt  (ID  >absolutselt !41_D	et	f	\N
155115	kaitsetud	kaitsetud =kaitse  (PtsPtIps  >kaitsema !28_V	et	f	\N
155116	kaitsetud	kaitsetud =kaitsetu  (PlN  >kaitsetu !01_A	et	f	\N
155117	kaitsetud	"kaitsetu %kaitse  )TU1_vS  <kaitsema ;28_V	et	f	\N
155118	kaitsetud	"kaitsetu %kaitse  )TU2_kA  <kaitse ;06_S	et	f	\N
155119	kaitsetud	kaitsetud =kaitsetud  (ID  >kaitsetud !41_A	et	f	\N
155120	kaitsetud	"kaitsetud %kaitse  )TUD_vA  <kaitsema ;28_V	et	f	\N
155128	mugavusi	mugavusi =mugavusi  (PlP  >mugavus !11_S	et	f	\N
155132	mugavusi	"mugavus %mugava  )US_aS  <mugav ;02_A	et	f	\N
155133	kaitsmisest	kaitsmisest =kaitsmise  (SgEl  >kaitsmine !12?10_S	et	f	\N
155134	kaitsmisest	"kaitsmine %kaits  )MINE_vS  <kaitsma ;32_V	et	f	\N
155135	jätku	jätku =jät  (ImpPrPs  >jätma !35_V	et	f	\N
155136	jätku	jätku =jätku  (ID  >jätku !41_I	et	f	\N
155137	jätku	jätku =jätku  (SgG  >jätk !22_S	et	f	\N
154842	nähti	nähti =nähti  (SgAdt  >näht !22_S	et	f	\N
154843	dodekafoon	?dodekafoon =dodekafoon  (SgN  >dodekafoon !22_S	et	f	\N
154854	hipi	hipi =hipi  (SgN  >hipi !16_S	et	f	\N
154855	hipi	hipi =hipi  (SgG  >hipi !16_S	et	f	\N
154865	taastaja	taastaja =taastaja  (SgN  >taastaja !01_S	et	f	\N
154866	taastaja	"taastaja %taasta  )JA_vS  <taastama ;27_V	et	f	\N
154867	taastaja	taastaja =taastaja  (SgG  >taastaja !01_S	et	f	\N
154874	60ndate	?ndate =ndate  (SgN  >ndate !06_S	et	f	\N
154875	60ndate	?ndate =ndate  (IndPrPs_  >ndatema !27_V	et	f	\N
154876	60ndate	?ndate =ndate  (ImpPrSg2  >ndatema !27_V	et	f	\N
154881	kuldseteks	kuldseteks =kuldse  (PlTr  >kuldne !02_A	et	f	\N
154882	kuldseteks	kuldseteks =sete  (PlTr  >kuld+sett !22_S	et	f	\N
154899	inimkett	inimkett =ke  (SgP  >inim+kesi !15_S	et	f	\N
154900	inimkett	inimkett =kett  (SgN  >inim+kett !22_S	et	f	\N
154940	ühendav	ühendav =ühenda  (PtsPrPs  >ühendama !27_V	et	f	\N
154941	ühendav	ühendav =ühendav  (SgN  >ühendav !02_A	et	f	\N
154942	ühendav	"ühendav %ühenda  )V_vA  <ühendama ;27_V	et	f	\N
154946	ajaloo-allikas	ajaloo-allikas =allika  (SgIn  >ajaloo-allikas !02_S	et	f	\N
154947	ajaloo-allikas	ajaloo-allikas =allikas  (SgN  >ajaloo-allikas !02_S	et	f	\N
154949	tõnson	?tõnson =tõnson  (SgN  >tõnson !02_S	et	f	\N
154955	korrastamiseks	korrastamiseks =korrastamise  (SgTr  >korrastamine !12_S	et	f	\N
154956	korrastamiseks	"korrastamine %korrasta  )MINE_vS  <korrastama ;27_V	et	f	\N
154967	20081991a	### 20081991a	et	f	\N
154969	patrotism	?patrotism =patrotism  (SgN  >patrotism !22_S	et	f	\N
154973	nahku	nahku =nahku  (PlP  >nahk !22_S	et	f	\N
154974	nahku	nahku =nahku  (IndPrPs_  >nahkuma !27_V	et	f	\N
154975	nahku	nahku =nahku  (ImpPrSg2  >nahkuma !27_V	et	f	\N
154982	kirikuid	kirikuid =kiriku  (PlP  >kirik !02_S	et	f	\N
154983	kirikuid	kirikuid =ui  (PlN  >kirik+ui !26_S	et	f	\N
154984	kirikuid	kirikuid =ui  (SgP  >kirik+ui !26_S	et	f	\N
154985	kirikuid	kirikuid =uid  (SgN  >kirik+uid !22_S	et	f	\N
154986	kirikuid	kirikuid =ku  (PlP  >kiri+kuu !26_S	et	f	\N
154992	levitati	levitati =levita  (IndIpfIps  >levitama !27_V	et	f	\N
154993	levitati	levitati =tati  (SgG  >levi+tatt !22_S	et	f	\N
155006	väiksemat	väiksemat =väiksema  (SgP  >väiksem !02_A	et	f	\N
155007	väiksemat	"väiksem %väikse  )M_cA  <väike ;10_A	et	f	\N
155014	raad	raad =raa  (PlN  >raag !22_S	et	f	\N
155015	raad	raad =raa  (PlN  >raa !26_S	et	f	\N
155016	raad	raad =raa  (SgP  >raa !26_S	et	f	\N
155017	raad	raad =raad  (SgN  >raad !22_S	et	f	\N
155023	tahtjais	tahtjais =tahtja  (PlIn  >tahtja !01_S	et	f	\N
155024	tahtjais	"tahtja %taht  )JA_vS  <tahtma ;34_V	et	f	\N
155039	rukkist	rukkist =rukki  (SgEl  >rukis !07_S	et	f	\N
155040	rukkist	rukkist =rukkis  (SgP  >rukkine !12~10_A	et	f	\N
155041	rukkist	"rukkine %rukki  )NE_aA  <rukis ;07_S	et	f	\N
155053	etevaatlikus	?etevaatlikus =etevaatliku  (SgIn  >etevaatlik !25_A	et	f	\N
155054	etevaatlikus	?etevaatlikus =etevaatliku  (IndIpfSg3  >etevaatlikuma !27_V	et	f	\N
155055	etevaatlikus	?etevaatlikus =etevaatlikus  (SgN  >etevaatlikus !11?09_S	et	f	\N
155077	kaido	?kaido =kaido  (SgN  >kaido !16_S	et	f	\N
155078	kaido	?kaido =kaido  (SgG  >kaido !16_S	et	f	\N
155080	aalstat	?aalstat =aalsta  (SgP  >aalsta !01_S	et	f	\N
155081	aalstat	?aalstat =aalstat  (SgN  >aalstat !02_S	et	f	\N
155091	kirgelt	?kirgelt =kirge  (PlAbl  >kirk !22_S	et	f	\N
155092	kirgelt	?kirgelt =kirgelt  (ID  >kirgelt !41_D	et	f	\N
155099	kaoksid	kaoksid =kao  (KndPrSg2  >kaduma !28_V	et	f	\N
155100	kaoksid	kaoksid =kao  (KndPrPl3  >kaduma !28_V	et	f	\N
155142	kõnekeelt	kõnekeelt =kee  (SgAbl  >kõne+kesi !15_S	et	f	\N
155143	kõnekeelt	kõnekeelt =kee  (SgAbl  >kõne+kee !26_S	et	f	\N
155144	kõnekeelt	kõnekeelt =keel  (SgP  >kõne+keel !13_S	et	f	\N
155155	tulegi	tulegi =tule  (SgG^  >tuli !20_S	et	f	\N
155156	tulegi	tulegi =tule  (IndPrPs_^  >tulema !36_V	et	f	\N
155157	tulegi	tulegi =tule  (ImpPrSg2^  >tulema !36_V	et	f	\N
155173	teenitud	teenitud =teeni  (PtsPtIps  >teenima !28_V	et	f	\N
155174	teenitud	teenitud =teenitu  (PlN  >teenitu !01_AS	et	f	\N
155175	teenitud	"teenitu %teeni  )TU1_vS  <teenima ;28_V	et	f	\N
155176	teenitud	teenitud =teenitud  (ID  >teenitud !41_A	et	f	\N
155177	teenitud	"teenitud %teeni  )TUD_vA  <teenima ;28_V	et	f	\N
155196	urisev	urisev =urise  (PtsPrPs  >urisema !27_V	et	f	\N
155197	urisev	urisev =urisev  (SgN  >urisev !02_A	et	f	\N
155198	urisev	"urisev %urise  )V_vA  <urisema ;27_V	et	f	\N
155199	elektrikarjus	elektrikarjus =karju  (PlIn  >elektri+kari !24_S	et	f	\N
155200	elektrikarjus	elektrikarjus =karjus  (SgN  >elektri+karjus !09_S	et	f	\N
155218	võimetumaks	võimetumaks =võimetuma  (SgTr  >võimetum !02_A	et	f	\N
155219	võimetumaks	"võimetum %võime  )TUM2_cA  <võime ;06_S	et	f	\N
155220	võimetumaks	"võimetum %võimetu  )M_cA  <võimetu ;01_A	et	f	\N
155232	mõtetud	?mõtetud =mõte  (PtsPtIps  >mõtema !27_V	et	f	\N
155233	mõtetud	?mõtetud =mõtetu  (PlN  >mõtetu !01_A	et	f	\N
155234	mõtetud	?mõtetud =mõtetu  (IndPrSg2  >mõtetuma !27_V	et	f	\N
155235	mõtetud	?mõtetud =mõtetud  (ID  >mõtetud !41_A	et	f	\N
154884	paremuse	"paremus %parema  )US_aS  <parem ;02_A	et	f	\N
154891	kokkuvõttek	?kokkuvõttek =võttek  (SgN  >kokku+võttek !02_S	et	f	\N
154901	asta	?asta =asta  (SgN  >asta !16_S	et	f	\N
154902	asta	?asta =asta  (SgG  >asta !16_S	et	f	\N
154903	asta	?asta =asta  (IndPrPs_  >astama !29_V	et	f	\N
154904	asta	?asta =asta  (ImpPrSg2  >astama !29_V	et	f	\N
154905	endid	endid =end  (PlP  >enda !00_P	et	f	\N
154906	endid	endid =end  (PlP  >enese !00_P	et	f	\N
154907	endid	endid =end  (PlP  >ise !00_P	et	f	\N
154912	tunnetasid	tunnetasid =tunneta  (IndIpfSg2  >tunnetama !27_V	et	f	\N
154913	tunnetasid	tunnetasid =tunneta  (IndIpfPl3  >tunnetama !27_V	et	f	\N
154917	olu	olu =olu  (SgN  >olu !17_S	et	f	\N
154918	olu	olu =olu  (SgG  >olu !17_S	et	f	\N
154919	olu	olu =olu  (SgP  >olu !17_S	et	f	\N
154935	tähendusrikas	?tähendusrikas =tähendusrika  (SgIn  >tähendusrika !01_S	et	f	\N
154936	tähendusrikas	?tähendusrikas =tähendusrika  (SgIn  >tähendusrikas !02_A	et	f	\N
154937	tähendusrikas	?tähendusrikas =tähendusrikas  (SgN  >tähendusrikas !02_A	et	f	\N
154938	tähendusrikas	?tähendusrikas =rika  (SgIn  >tähendus+rika !16_S	et	f	\N
154939	tähendusrikas	?tähendusrikas =rikas  (SgN  >tähendus+rikas !07_A	et	f	\N
154957	ideaalselt	ideaalselt =ideaalse  (SgAbl  >ideaalne !02_A	et	f	\N
154958	ideaalselt	ideaalselt =ideaalselt  (ID  >ideaalselt !41_D	et	f	\N
154959	ideaalselt	"ideaalselt %ideaalse  )LT_mD  <ideaalne ;02_A	et	f	\N
154963	kahtlused	kahtlused =kahtluse  (PlN  >kahtlus !11~09_S	et	f	\N
154964	kahtlused	"kahtlus %kahtlase  )US_aS  <kahtlane ;12_A	et	f	\N
154968	ilmar	?ilmar =ilmar  (SgN  >ilmar !02_S	et	f	\N
154970	5-8saj	### 5-8saj	et	f	\N
154971	majajärku	majajärku =järku  (SgP  >maja+järk !22_S	et	f	\N
154972	majajärku	majajärku =järku  (SgAdt  >maja+järk !22_S	et	f	\N
154978	kasvataminehobused	?kasvataminehobused =kasvataminehobuse  (PlN  >kasvataminehobus !11?09_S	et	f	\N
154979	kasvataminehobused	?kasvataminehobused =vataminehobuse  (PlN  >kas+vataminehobus !11?09_S	et	f	\N
154989	jaid	?jaid =jai  (PlN  >jai !26_S	et	f	\N
154990	jaid	?jaid =jai  (SgP  >jai !26_S	et	f	\N
154991	jaid	?jaid =jaid  (SgN  >jaid !22_S	et	f	\N
154999	saksalased	?saksalased =saksalase  (PlN  >saksalane !12_S	et	f	\N
155028	katkenud	katkenud =katke  (PtsPtPs  >katkema !27_V	et	f	\N
155029	katkenud	katkenud =katkenu  (PlN  >katkenu !01_S	et	f	\N
155030	katkenud	"katkenu %katke  )NU_vS  <katkema ;27_V	et	f	\N
155031	katkenud	katkenud =katkenud  (ID  >katkenud !41_A	et	f	\N
155032	katkenud	"katkenud %katke  )NUD_vA  <katkema ;27_V	et	f	\N
155042	ehituseks	ehituseks =ehituse  (SgTr  >ehitus !11_S	et	f	\N
155043	ehituseks	"ehitus %ehita  )US_vS  <ehitama ;27_V	et	f	\N
155044	ehituseks	"ehitus %ehi  )TUS1_aS  <ehtima ;28_V	et	f	\N
155056	algatamiseks	algatamiseks =algatamise  (SgTr  >algatamine !12_S	et	f	\N
155057	algatamiseks	"algatamine %algata  )MINE_vS  <algatama ;27_V	et	f	\N
155061	kaubelda	kaubelda =kaubel  (Inf  >kauplema !30_V	et	f	\N
155062	kaubelda	kaubelda =kaubel  (IndPrIps_  >kauplema !30_V	et	f	\N
155063	tulemast	tulemast =tule  (SupEl  >tulema !36_V	et	f	\N
155064	tulemast	tulemast =tulema  (SgEl  >tulem !02_S	et	f	\N
155065	tulemast	tulemast =tulemas  (SgP  >tulemane !12_A	et	f	\N
155066	tulemast	"tulemane %tulema  )NE_aA  <tulem ;02_S	et	f	\N
155067	tulemast	tulemast =mast  (SgN  >tule+mast !22_S	et	f	\N
155123	võimukam	võimukam =võimukam  (SgN  >võimukam !02_A	et	f	\N
155124	võimukam	"võimukam %võimuka  )M_cA  <võimukas ;02_A	et	f	\N
155125	ohutust	ohutust =ohutu  (SgEl  >ohutu !01_A	et	f	\N
155126	ohutust	"ohutu %ohu  )TU2_kA  <oht ;22_S	et	f	\N
155127	ohutust	ohutust =ohutus  (SgP  >ohutus !11_S	et	f	\N
155129	ohutust	"ohutus %ohuta  )US_vS  <ohutama ;27_V	et	f	\N
155130	ohutust	"ohutus %ohu  )TUS2_aS  <oht ;22_S	et	f	\N
155131	ohutust	ohutust =tust  (SgN  >ohu+tust !22_S	et	f	\N
155145	purustustega	purustustega =purustus  (PlKom  >purustus !11_S	et	f	\N
155146	purustustega	"purustus %purusta  )US_vS  <purustama ;27_V	et	f	\N
155153	nähtusele	nähtusele =nähtuse  (SgAll  >nähtus !11~09_S	et	f	\N
155154	nähtusele	"nähtus %näh  )TUS1_aS  <nägema ;28_V	et	f	\N
155158	raputavad	raputavad =raputa  (IndPrPl3  >raputama !27_V	et	f	\N
155159	raputavad	raputavad =raputava  (PlN  >raputav !02_A	et	f	\N
155160	raputavad	"raputav %rapu  )TAV_vAS  <rappuma ;28_V	et	f	\N
155161	raputavad	"raputav %raputa  )V_vA  <raputama ;27_V	et	f	\N
155178	mõistnud	mõistnud =mõist  (PtsPtPs  >mõistma !34_V	et	f	\N
155179	mõistnud	mõistnud =mõistnu  (PlN  >mõistnu !01_S	et	f	\N
155180	mõistnud	"mõistnu %mõist  )NU_vS  <mõistma ;34_V	et	f	\N
155181	mõistnud	mõistnud =mõistnud  (ID  >mõistnud !41_A	et	f	\N
155182	mõistnud	"mõistnud %mõist  )NUD_vA  <mõistma ;34_V	et	f	\N
155192	igapäevaselt	igapäevaselt =päevase  (SgAbl  >iga+päevane !10_A	et	f	\N
155193	igapäevaselt	"iga+päevane %päeva  )NE_aA  <iga+päev ;22_S	et	f	\N
155194	igapäevaselt	"iga+päevaselt %päeva  )SELT_mD  <iga+päev ;22_S	et	f	\N
155195	igapäevaselt	"iga+päevaselt %päevase  )LT_mD  <iga+päevane ;10_A	et	f	\N
155204	löö	löö =löö  (IndPrPs_  >lööma !38_V	et	f	\N
155051	linnaelu	linnaelu =elu  (SgG  >linna+elu !17_S	et	f	\N
155052	linnaelu	linnaelu =elu  (SgP  >linna+elu !17_S	et	f	\N
155085	marie	?marie =marie  (SgN  >marie !01_S	et	f	\N
155086	marie	?marie =marie  (SgG  >marie !01_S	et	f	\N
155093	tundedest	?tundedest =tundedes  (SgP  >tundedene !12_A	et	f	\N
155094	luuletusele	luuletusele =luuletuse  (SgAll  >luuletus !11_S	et	f	\N
155095	luuletusele	"luuletus %luuleta  )US_vS  <luuletama ;27_V	et	f	\N
155096	luuletusele	"luuletus %luule  )TUS2_aS  <luule ;06_S	et	f	\N
155098	momentid	?momentid =momenti  (PlN  >momenti !01_S	et	f	\N
155101	teistelt	teistelt =teis  (PlAbl  >teine !12_OP	et	f	\N
155102	teistelt	teistelt =teis  (PlAbl  >teise !12_P	et	f	\N
155103	teistelt	teistelt =teiste  (PlAbl  >teist !22_S	et	f	\N
155107	heidikuteks	heidikuteks =heidiku  (PlTr  >heidik !02_S	et	f	\N
155108	heidikuteks	heidikuteks =ute  (SgTr  >heidik+utt !22_S	et	f	\N
155109	heidikuteks	heidikuteks =ute  (PlTr  >heidik+utt !22_S	et	f	\N
155110	vaeva	vaeva =vaeva  (SgG  >vaev !22_S	et	f	\N
155111	vaeva	vaeva =vaeva  (SgP  >vaev !22_S	et	f	\N
155112	vaeva	vaeva =vaeva  (SgAdt  >vaev !22_S	et	f	\N
155113	vaeva	vaeva =vaeva  (IndPrPs_  >vaevama !29_V	et	f	\N
155114	vaeva	vaeva =vaeva  (ImpPrSg2  >vaevama !29_V	et	f	\N
155147	kaasnevaid	kaasnevaid =kaasneva  (PlP  >kaasnev !02_A	et	f	\N
155148	kaasnevaid	"kaasnev %kaasne  )V_vA  <kaasnema ;27_V	et	f	\N
155151	sellisele	sellisele =sellise  (SgAll  >selline !10_P	et	f	\N
155152	sellisele	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
155170	krabisevat	krabisevat =krabise  (KvtPrPs  >krabisema !27_V	et	f	\N
155171	krabisevat	krabisevat =krabiseva  (SgP  >krabisev !02_A	et	f	\N
155172	krabisevat	"krabisev %krabise  )V_vA  <krabisema ;27_V	et	f	\N
155245	maakohas	maakohas =koha  (SgIn  >maa+koha !17_S	et	f	\N
155246	maakohas	maakohas =koha  (SgIn  >maa+koht !22_S	et	f	\N
155249	jäälahmakas	jäälahmakas =lahmaka  (SgIn  >jää+lahmakas !02_SA	et	f	\N
155250	jäälahmakas	jäälahmakas =lahmakas  (SgN  >jää+lahmakas !02_SA	et	f	\N
155253	koledmaks	?koledmaks =koledma  (SgTr  >koledma !01_S	et	f	\N
155316	väitnud	väitnud =väit  (PtsPtPs  >väitma !34_V	et	f	\N
155317	väitnud	väitnud =väitnu  (PlN  >väitnu !01_S	et	f	\N
155318	väitnud	"väitnu %väit  )NU_vS  <väitma ;34_V	et	f	\N
155319	väitnud	väitnud =väitnud  (ID  >väitnud !41_A	et	f	\N
155320	väitnud	"väitnud %väit  )NUD_vA  <väitma ;34_V	et	f	\N
155344	paratamatult	paratamatult =paratamatu  (SgAbl  >paratamatu !01_A	et	f	\N
155345	paratamatult	paratamatult =paratamatult  (ID  >paratamatult !41_D	et	f	\N
155346	paratamatult	"paratamatult %paratamatu  )LT_mD  <paratamatu ;01_A	et	f	\N
155347	hävitavamad	hävitavamad =hävitavama  (PlN  >hävitavam !02_A	et	f	\N
155348	hävitavamad	"hävitavam %hävi  )TAVAM_cA  <hävima ;27_V	et	f	\N
155349	hävitavamad	"hävitavam %hävita  )VAM_cA  <hävitama ;27_V	et	f	\N
155350	hävitavamad	"hävitavam %hävitava  )M_cA  <hävitav ;02_A	et	f	\N
155356	lähenevast	lähenevast =läheneva  (SgEl  >lähenev !02_A	et	f	\N
155357	lähenevast	"lähenev %lähene  )V_vA  <lähenema ;27_V	et	f	\N
155358	telekast	telekast =teleka  (SgEl  >telekas !02_S	et	f	\N
155359	telekast	telekast =telekas  (SgP  >telekane !12_A	et	f	\N
155360	telekast	"telekane %teleka  )NE_aA  <telekas ;02_S	et	f	\N
155361	telekast	telekast =kast  (SgN  >tele+kast !22_S	et	f	\N
155370	puhkuspaigad	### puhkuspaigad	et	f	\N
155373	pommiplahvatustest	pommiplahvatustest =test  (SgN  >pommi+plahvatus+test !22_S	et	f	\N
155374	pommiplahvatustest	pommiplahvatustest =plahvatus  (PlEl  >pommi+plahvatus !11_S	et	f	\N
155394	kassaapparat	?kassaapparat =kassaappara  (SgP  >kassaappara !16_S	et	f	\N
155395	kassaapparat	?kassaapparat =appara  (SgP  >kassa+appara !01_S	et	f	\N
155396	kassaapparat	?kassaapparat =saappara  (SgP  >kas+saappara !01_S	et	f	\N
155397	müüjatel	müüjatel =müüja  (PlAd  >müüja !01_S	et	f	\N
155398	müüjatel	"müüja %müü  )JA_vS  <müüma ;38_V	et	f	\N
155403	täpsus	täpsus =täpsus  (SgN  >täpsus !11~09_S	et	f	\N
155404	täpsus	"täpsus %täpsa  )US_aS  <täppis ;02_A	et	f	\N
155405	täpsus	"täpsus %täpse  )US_aS  <täpne ;02_A	et	f	\N
155408	inimisena	?inimisena =inimise  (SgEs  >inimine !12_S	et	f	\N
155412	helkurit	?helkurit =helkuri  (SgP  >helkuri !01_S	et	f	\N
155413	helkurit	?helkurit =helkuri  (SgP  >helkur !02_S	et	f	\N
155414	radaar	?radaar =radaar  (SgN  >radaar !22_S	et	f	\N
155429	zaura	?zaura =zaura  (SgN  >zaura !16_S	et	f	\N
155430	zaura	?zaura =zaura  (SgG  >zaura !16_S	et	f	\N
155431	zaura	?zaura =zaura  (IndPrPs_  >zaurama !29_V	et	f	\N
155432	zaura	?zaura =zaura  (ImpPrSg2  >zaurama !29_V	et	f	\N
155436	puustusmaa	puustusmaa =maa  (SgN  >puustus+maa !26_S	et	f	\N
155437	puustusmaa	puustusmaa =maa  (SgG  >puustus+maa !26_S	et	f	\N
155443	põrsast	põrsast =põrsa  (SgEl  >põrsas !07_S	et	f	\N
155444	põrsast	põrsast =põrsas  (SgP  >põrsas !07_S	et	f	\N
155445	põrsast	põrsast =põrsas  (SgP  >põrsane !10_A	et	f	\N
155446	põrsast	"põrsane %põrsa  )NE_aA  <põrsas ;07_S	et	f	\N
155449	triibulised	triibulised =triibulise  (PlN  >triibuline !12_A	et	f	\N
155450	triibulised	"triibuline %triibu  )LINE_aA  <triip ;22_S	et	f	\N
155084	dhead	?dhead =dhead  (SgN  >dhead !22_S	et	f	\N
155087	under	?under =under  (SgN  >under !02_S	et	f	\N
155097	pingelik	?pingelik =pingelik  (SgN  >pingelik !25_A	et	f	\N
155104	kaasajal	kaasajal =kaasaja  (SgAd  >kaasaja !01_S	et	f	\N
155105	kaasajal	"kaasaja %kaasa  )JA_vS  <kaasama ;29_V	et	f	\N
155106	kaasajal	kaasajal =aja  (SgAd  >kaas+aeg !22_S	et	f	\N
155121	abitud	abitud =abitu  (PlN  >abitu !01_A	et	f	\N
155122	abitud	"abitu %abi  )TU2_kA  <abi ;17_S	et	f	\N
155166	mõtlemine	mõtlemine =mõtlemine  (SgN  >mõtlemine !12_S	et	f	\N
155167	mõtlemine	"mõtlemine %mõtle  )MINE_vS  <mõtlema ;30_V	et	f	\N
155168	piisavas	piisavas =piisava  (SgIn  >piisav !02_A	et	f	\N
155169	piisavas	"piisav %piisa  )V_vA  <piisama ;29_V	et	f	\N
155183	saagi	saagi =saagi  (SgG  >saak !22_S	et	f	\N
155184	saagi	saagi =saagi  (SgP  >saag !22_S	et	f	\N
155185	saagi	saagi =saagi  (SgAdt  >saag !22_S	et	f	\N
155186	saagi	saagi =saa  (IndPrPs_^  >saama !37_V	et	f	\N
155187	saagi	saagi =saa  (ImpPrSg2^  >saama !37_V	et	f	\N
155206	äpardusest	äpardusest =äparduse  (SgEl  >äpardus !11_S	et	f	\N
155207	äpardusest	"äpardus %äparda  )US_vS  <äpardama ;27_V	et	f	\N
155208	äpardusest	äpardusest =äparduses  (SgP  >äpardusene !12_A	et	f	\N
155209	äpardusest	"äpardusene %äparduse  )NE_aA  <äpardus ;11_S	et	f	\N
155223	mugavusest	mugavusest =mugavuse  (SgEl  >mugavus !11_S	et	f	\N
155224	mugavusest	"mugavus %mugava  )US_aS  <mugav ;02_A	et	f	\N
155225	mugavusest	mugavusest =mugavuses  (SgP  >mugavusene !12_A	et	f	\N
155226	mugavusest	"mugavusene %mugavuse  )NE_aA  <mugavus ;11_S	et	f	\N
155240	põnevusetta	?põnevusetta =põnevusetta  (SgN  >põnevusetta !16_S	et	f	\N
155241	põnevusetta	?põnevusetta =põnevusetta  (SgG  >põnevusetta !16_S	et	f	\N
155254	sulav	sulav =sula  (PtsPrPs  >sulama !27_V	et	f	\N
155255	sulav	sulav =sulav  (SgN  >sulav !02_A	et	f	\N
155256	sulav	"sulav %sula  )V_vA  <sulama ;27_V	et	f	\N
155257	totaalselt	totaalselt =totaalse  (SgAbl  >totaalne !02_A	et	f	\N
155258	totaalselt	totaalselt =totaalselt  (ID  >totaalselt !41_D	et	f	\N
155259	totaalselt	"totaalselt %totaalse  )LT_mD  <totaalne ;02_A	et	f	\N
155270	säravad	säravad =sära  (IndPrPl3  >särama !27_V	et	f	\N
155271	säravad	säravad =särava  (PlN  >särav !02_A	et	f	\N
155272	säravad	"särav %sära  )V_vA  <särama ;27_V	et	f	\N
155285	madalale	madalale =madala  (SgAll  >madal !02_AS	et	f	\N
155286	madalale	madalale =madalale  (ID  >madalale !41_D	et	f	\N
155287	madalale	madalale =ale  (SgN  >madal+ale !16_S	et	f	\N
155288	madalale	madalale =ale  (SgG  >madal+ale !16_S	et	f	\N
155307	kaasatundma	?kaasatundma =kaasatundma  (SgN  >kaasatundma !16_S	et	f	\N
155308	kaasatundma	?kaasatundma =kaasatundma  (SgG  >kaasatundma !16_S	et	f	\N
155309	kaasatundma	?kaasatundma =atundma  (SgN  >kaas+atundma !01_S	et	f	\N
155310	kaasatundma	?kaasatundma =atundma  (SgG  >kaas+atundma !01_S	et	f	\N
155321	pürgimine	pürgimine =pürgimine  (SgN  >pürgimine !12_S	et	f	\N
155322	pürgimine	"pürgimine %pürgi  )MINE_vS  <pürgima ;27_V	et	f	\N
155323	pürgimine	"pürgimine %pürgi  )MINE_vS  <pürgima ;28_V	et	f	\N
155327	naerda	naerda =naer  (Inf  >naerma !33_V	et	f	\N
155328	naerda	naerda =naer  (IndPrIps_  >naerma !33_V	et	f	\N
155337	hukkunud	hukkunud =hukku  (PtsPtPs  >hukkuma !27~28_V	et	f	\N
155338	hukkunud	hukkunud =hukkunu  (PlN  >hukkunu !01_S	et	f	\N
155339	hukkunud	"hukkunu %hukku  )NU_vS  <hukkuma ;27_V	et	f	\N
155340	hukkunud	"hukkunu %hukku  )NU_vS  <hukkuma ;28_V	et	f	\N
155341	hukkunud	hukkunud =hukkunud  (ID  >hukkunud !41_A	et	f	\N
155342	hukkunud	"hukkunud %hukku  )NUD_vA  <hukkuma ;27_V	et	f	\N
155343	hukkunud	"hukkunud %hukku  )NUD_vA  <hukkuma ;28_V	et	f	\N
155351	teatatud	teatatud =teata  (PtsPtIps  >teatama !27_V	et	f	\N
155352	teatatud	teatatud =teatatu  (PlN  >teatatu !01_S	et	f	\N
155353	teatatud	"teatatu %teata  )TU1_vS  <teatama ;27_V	et	f	\N
155354	teatatud	teatatud =teatatud  (ID  >teatatud !41_A	et	f	\N
155355	teatatud	"teatatud %teata  )TUD_vA  <teatama ;27_V	et	f	\N
155375	pruugigi	pruugigi =pruugi  (SgG^  >pruuk !22_S	et	f	\N
155376	pruugigi	pruugigi =pruugi  (IndPrPs_^  >pruukima !28_V	et	f	\N
155377	pruugigi	pruugigi =pruugi  (ImpPrSg2^  >pruukima !28_V	et	f	\N
155380	kuueni	kuueni =kuue  (SgTer  >kuus !14_N	et	f	\N
155381	kuueni	kuueni =kuue  (SgTer  >kuub !22_S	et	f	\N
155382	ehitajal	ehitajal =ehitaja  (SgAd  >ehitaja !01_S	et	f	\N
155383	ehitajal	"ehitaja %ehita  )JA_vS  <ehitama ;27_V	et	f	\N
155384	purkides	purkides =purki  (PlIn  >purk !22_S	et	f	\N
155385	purkides	purkides =purki  (Ger  >purkima !28_V	et	f	\N
155401	iseloomuomadus	iseloomuomadus =omadus  (SgN  >ise+loomu+omadus !11_S	et	f	\N
155402	iseloomuomadus	"ise+loomu+omadus %oma  )US_aS  <ise+loomu+oma ;17_A	et	f	\N
155415	iseloomuomadused	iseloomuomadused =omaduse  (PlN  >ise+loomu+omadus !11_S	et	f	\N
155416	iseloomuomadused	"ise+loomu+omadus %oma  )US_aS  <ise+loomu+oma ;17_A	et	f	\N
155419	klienditeenindaja	klienditeenindaja =teenindaja  (SgN  >kliendi+teenindaja !01_S	et	f	\N
155420	klienditeenindaja	klienditeenindaja =teenindaja  (SgG  >kliendi+teenindaja !01_S	et	f	\N
155426	nätas	?nätas =näta  (SgIn  >näta !16_S	et	f	\N
155138	jätku	jätku =jätku  (SgP  >jätk !22_S	et	f	\N
155139	jätku	jätku =jätku  (SgAdt  >jätk !22_S	et	f	\N
155140	jätku	jätku =jätku  (IndPrPs_  >jätkuma !27_V	et	f	\N
155141	jätku	jätku =jätku  (ImpPrSg2  >jätkuma !27_V	et	f	\N
155149	endalt	endalt =enda  (SgAbl  >enda !00_P	et	f	\N
155150	endalt	endalt =enda  (SgAbl  >ise !00_P	et	f	\N
155162	laastavad	laastavad =laasta  (IndPrPl3  >laastama !29~27_V	et	f	\N
155163	laastavad	laastavad =laastava  (PlN  >laastav !02_A	et	f	\N
155164	laastavad	"laastav %laasta  )V_vA  <laastama ;27_V	et	f	\N
155165	laastavad	"laastav %laasta  )V_vA  <laastama ;29_V	et	f	\N
155188	silmitsi	silmitsi =silmitsi  (ID  >silmitsi !41_D	et	f	\N
155189	silmitsi	silmitsi =itsi  (SgG  >silm+its !22_S	et	f	\N
155190	silmitsi	silmitsi =itsi  (SgP  >silm+its !22_S	et	f	\N
155191	silmitsi	silmitsi =itsi  (SgAdt  >silm+its !22_S	et	f	\N
155201	pruugi	pruugi =pruugi  (SgG  >pruuk !22_S	et	f	\N
155202	pruugi	pruugi =pruugi  (IndPrPs_  >pruukima !28_V	et	f	\N
155203	pruugi	pruugi =pruugi  (ImpPrSg2  >pruukima !28_V	et	f	\N
155236	lõppe	lõppe =lõppe  (SgG  >lõpe !06_S	et	f	\N
155237	lõppe	lõppe =lõppe  (PlP  >lõpp !22_SA	et	f	\N
155238	lõppe	lõppe =lõppe  (IndPrPs_  >lõppema !27_V	et	f	\N
155239	lõppe	lõppe =lõppe  (ImpPrSg2  >lõppema !27_V	et	f	\N
155242	hooli	hooli =hool  (PlP  >hool !13_S	et	f	\N
155243	hooli	hooli =hooli  (IndPrPs_  >hoolima !28_V	et	f	\N
155244	hooli	hooli =hooli  (ImpPrSg2  >hoolima !28_V	et	f	\N
155247	kilomeetrit	kilomeetrit =kilomeetri  (SgP  >kilomeeter !02_S	et	f	\N
155248	kilomeetrit	kilomeetrit =meetri  (SgP  >kilo+meeter !02_S	et	f	\N
155280	sajad	sajad =saja  (PlN  >sajas !02_O	et	f	\N
155281	sajad	sajad =saja  (PlN  >sada !18_N	et	f	\N
155282	sajad	sajad =saja  (IndPrSg2  >sadama !28_V	et	f	\N
155289	tehnoloogia	tehnoloogia =tehnoloogia  (SgN  >tehnoloogia !01_S	et	f	\N
155290	tehnoloogia	tehnoloogia =tehnoloogia  (SgG  >tehnoloogia !01_S	et	f	\N
155300	üleelama	?üleelama =üleelama  (SgG  >üleelam !02_A	et	f	\N
155301	eluvaldkonnas	eluvaldkonnas =konna  (SgIn  >elu+vald+konn !22_S	et	f	\N
155302	eluvaldkonnas	eluvaldkonnas =valdkonna  (SgIn  >elu+valdkond !22_S	et	f	\N
155329	kaasatunda	?kaasatunda =kaasatunda  (SgN  >kaasatunda !16_S	et	f	\N
155330	kaasatunda	?kaasatunda =kaasatunda  (SgG  >kaasatunda !16_S	et	f	\N
155331	kaasatunda	?kaasatunda =kaasatunda  (IndPrPs_  >kaasatundama !27_V	et	f	\N
155332	kaasatunda	?kaasatunda =kaasatunda  (ImpPrSg2  >kaasatundama !27_V	et	f	\N
155333	kaasatunda	?kaasatunda =tunda  (SgN  >kaasa+tunda !16_S	et	f	\N
155334	kaasatunda	?kaasatunda =tunda  (SgG  >kaasa+tunda !16_S	et	f	\N
155335	kaasatunda	?kaasatunda =atunda  (SgN  >kaas+atunda !01_S	et	f	\N
155336	kaasatunda	?kaasatunda =atunda  (SgG  >kaas+atunda !01_S	et	f	\N
155378	ohjeldamisega	ohjeldamisega =ohjeldamise  (SgKom  >ohjeldamine !12_S	et	f	\N
155379	ohjeldamisega	"ohjeldamine %ohjelda  )MINE_vS  <ohjeldama ;27_V	et	f	\N
155390	pastapliats	?pastapliats =pastapliats  (SgN  >pastapliats !22_S	et	f	\N
155391	pastapliats	?pastapliats =pliats  (SgN  >pasta+pliats !22_S	et	f	\N
155433	metsakas	metsakas =metsaka  (SgIn  >metsakas !02_A	et	f	\N
155434	metsakas	metsakas =metsakas  (SgN  >metsakas !02_A	et	f	\N
155435	metsakas	metsakas =aka  (SgIn  >mets+aka !16_S	et	f	\N
155439	shokeeris	?shokeeris =shokeeri  (SgIn  >shokeeri !16_S	et	f	\N
155440	shokeeris	?shokeeris =shokeeri  (SgIn  >shokeer !22_S	et	f	\N
155441	shokeeris	?shokeeris =shokeeri  (IndIpfSg3  >shokeerima !28_V	et	f	\N
155442	shokeeris	?shokeeris =shokeeris  (SgN  >shokeeris !09_S	et	f	\N
155447	zaural	?zaural =zaura  (SgAd  >zaura !16_S	et	f	\N
155448	zaural	?zaural =zaural  (SgN  >zaural !02_S	et	f	\N
155451	triibulised	triibulised =triibulise  (PlN  >triibuline !12_A	et	f	\N
155452	triibulised	"triibuline %triibu  )LINE_aA  <triip ;22_S	et	f	\N
155456	maitseb	maitseb =maitse  (IndPrSg3  >maitsema !28_V	et	f	\N
155457	maitseb	maitseb =maitse  (IndPrSg3  >maitsma !32_V	et	f	\N
155474	silli	?silli =silli  (SgN  >silli !16_S	et	f	\N
155475	silli	?silli =silli  (SgG  >silli !16_S	et	f	\N
155476	silli	?silli =silli  (SgG  >sill !22_S	et	f	\N
155477	silli	?silli =silli  (SgP  >sill !22_S	et	f	\N
155478	silli	?silli =silli  (SgAdt  >sill !22_S	et	f	\N
155479	silli	?silli =silli  (IndPrPs_  >sillima !28_V	et	f	\N
155480	silli	?silli =silli  (ImpPrSg2  >sillima !28_V	et	f	\N
155514	hädast	hädast =häda  (SgEl  >häda !17_S	et	f	\N
155515	hädast	hädast =hädas  (SgP  >hädane !10_A	et	f	\N
155516	hädast	"hädane %häda  )NE_aA  <häda ;17_S	et	f	\N
155521	lühifilmi	lühifilmi =filmi  (SgG  >lühi+film !22_S	et	f	\N
155522	lühifilmi	lühifilmi =filmi  (SgP  >lühi+film !22_S	et	f	\N
155523	lühifilmi	lühifilmi =filmi  (SgAdt  >lühi+film !22_S	et	f	\N
155546	esinemise	esinemise =esinemise  (SgG  >esinemine !12_S	et	f	\N
155547	esinemise	"esinemine %esine  )MINE_vS  <esinema ;27_V	et	f	\N
155552	presentatsiooni	?presentatsiooni =presentatsioo  (SgTer  >presentatsioo !26_S	et	f	\N
155553	presentatsiooni	?presentatsiooni =presentatsiooni  (SgN  >presentatsiooni !16_S	et	f	\N
155554	presentatsiooni	?presentatsiooni =presentatsiooni  (SgG  >presentatsiooni !16_S	et	f	\N
155205	löö	löö =löö  (ImpPrSg2  >lööma !38_V	et	f	\N
155210	algkoolist	algkoolist =kooli  (SgEl  >alg+kool !22_S	et	f	\N
155211	algkoolist	algkoolist =kooli  (PlEl  >alg+kool !22_S	et	f	\N
155212	algkoolist	algkoolist =koolis  (SgP  >alg+kooline !10_A	et	f	\N
155213	algkoolist	"alg+kooline %koo  )LINE_aA  <alg+kubu ;18_S	et	f	\N
155214	algkoolist	"alg+kooline %kooli  )NE_aA  <alg+kool ;22_S	et	f	\N
155215	õpigi	õpigi =õpi  (SgG^  >õpp !22_S	et	f	\N
155216	õpigi	õpigi =õpi  (IndPrPs_^  >õppima !28_V	et	f	\N
155217	õpigi	õpigi =õpi  (ImpPrSg2^  >õppima !28_V	et	f	\N
155221	jõuetus	jõuetus =jõuetu  (SgIn  >jõuetu !01_A	et	f	\N
155222	jõuetus	jõuetus =jõuetus  (SgN  >jõuetus !11_S	et	f	\N
155227	kogemusest	kogemusest =kogemuse  (SgEl  >kogemus !11_S	et	f	\N
155228	kogemusest	kogemusest =kogemuses  (SgP  >kogemusene !12_A	et	f	\N
155229	kogemusest	"kogemusene %kogemuse  )NE_aA  <kogemus ;11_S	et	f	\N
155230	nööpi	nööpi =nööpi  (SgP  >nööp !22_S	et	f	\N
155231	nööpi	nööpi =nööpi  (SgAdt  >nööp !22_S	et	f	\N
155251	vajuks	vajuks =vaju  (PlTr  >vaja !17_S	et	f	\N
155252	vajuks	vajuks =vaju  (KndPrPs  >vajuma !27_V	et	f	\N
155263	ravitavad	ravitavad =ravitava  (PlN  >ravitav !02_A	et	f	\N
155264	ravitavad	"ravitav %ravi  )TAV_vAS  <ravima ;27_V	et	f	\N
155265	ravitavad	ravitavad =tava  (PlN  >ravi+tava !17_S	et	f	\N
155266	ettegi	ettegi =e  (SgAdt^  >esi !15_S	et	f	\N
155267	ettegi	ettegi =ette  (ID^  >ette !41_DK	et	f	\N
155273	tõsisemaid	tõsisemaid =tõsisema  (PlP  >tõsisem !02_A	et	f	\N
155274	tõsisemaid	"tõsisem %tõsise  )M_cA  <tõsine ;10_A	et	f	\N
155296	lühikese	lühikese =lühikese  (SgG  >lühike !12_A	et	f	\N
155297	lühikese	"lühike %lühi  )KE_dS  <lüht ;22_S	et	f	\N
155298	lühikese	lühikese =lühikese  (SgG  >lühikene !12_S	et	f	\N
155299	lühikese	"lühikene %lühi  )KENE_dS  <lüht ;22_S	et	f	\N
155303	pereelus	pereelus =elu  (SgIn  >pere+elu !17_S	et	f	\N
155304	pereelus	pereelus =elus  (SgN  >pere+elus !02_A	et	f	\N
155305	vastupidiselt	vastupidiselt =pidise  (SgAbl  >vastu+pidine !10_A	et	f	\N
155306	vastupidiselt	"vastu+pidiselt %pidise  )LT_mD  <vastu+pidine ;10_A	et	f	\N
155311	austagi	austagi =austa  (IndPrPs_^  >austama !27_V	et	f	\N
155312	austagi	austagi =austa  (ImpPrSg2^  >austama !27_V	et	f	\N
155364	külmuvaid	külmuvaid =külmuva  (PlP  >külmuv !02_A	et	f	\N
155365	külmuvaid	"külmuv %külmu  )V_vA  <külmuma ;27_V	et	f	\N
155366	linnukesi	linnukesi =linnukesi  (PlP  >linnuke !12_S	et	f	\N
155367	linnukesi	"linnuke %linnu  )KE_dS  <lind ;22_S	et	f	\N
155368	linnukesi	linnukesi =linnukesi  (PlP  >linnukene !12_S	et	f	\N
155369	linnukesi	"linnukene %linnu  )KENE_dS  <lind ;22_S	et	f	\N
155371	tihedatest	tihedatest =tiheda  (PlEl  >tihe !02_A	et	f	\N
155372	tihedatest	tihedatest =test  (SgN  >tiheda+test !22_S	et	f	\N
155386	legaalselt	legaalselt =legaalse  (SgAbl  >legaalne !02_A	et	f	\N
155387	legaalselt	legaalselt =legaalselt  (ID  >legaalselt !41_D	et	f	\N
155388	legaalselt	"legaalselt %legaalse  )LT_mD  <legaalne ;02_A	et	f	\N
155389	lõun	?lõun =lõun  (SgN  >lõun !22_S	et	f	\N
155392	humorimeel	?humorimeel =humorimee  (SgAd  >humorimee !26_S	et	f	\N
155393	humorimeel	?humorimeel =humorimeel  (SgN  >humorimeel !22_S	et	f	\N
155406	suhtlejana	suhtlejana =suhtleja  (SgEs  >suhtleja !01_S	et	f	\N
155407	suhtlejana	"suhtleja %suhtle  )JA_vS  <suhtlema ;30_V	et	f	\N
155438	origamimind	?origamimind =origamimind  (SgN  >origamimind !22_S	et	f	\N
155466	küls	?küls =küls  (SgN  >küls !22_S	et	f	\N
155472	hobusel	hobusel =hobuse  (SgAd  >hobune !10_S	et	f	\N
155473	hobusel	"hobune %hobu  )NE_aA  <hobu ;17_S	et	f	\N
155486	klassikaaslaste	klassikaaslaste =las  (PlG  >klassi+kaas+laps !14_S	et	f	\N
155487	klassikaaslaste	klassikaaslaste =laste  (PlP  >klassi+kaas+last !22_S	et	f	\N
155488	klassikaaslaste	klassikaaslaste =kaaslas  (PlG  >klassi+kaaslane !12?10_S	et	f	\N
155517	mälestustes	mälestustes =mälestus  (PlIn  >mälestus !11_S	et	f	\N
155518	mälestustes	"mälestus %mälesta  )US_vS  <mälestama ;27_V	et	f	\N
155519	vaatamist	vaatamist =vaatamis  (SgP  >vaatamine !12_S	et	f	\N
155520	vaatamist	"vaatamine %vaata  )MINE_vS  <vaatama ;29_V	et	f	\N
155524	ettevalmistatud	ettevalmistatud =valmista  (PtsPtIps  >ette+_valmistama !27_V	et	f	\N
155525	ettevalmistatud	ettevalmistatud =valmistatu  (PlN  >ette+valmistatu !01_S	et	f	\N
155530	rühmas	rühmas =rühma  (SgIn  >rühm !22_S	et	f	\N
155531	rühmas	rühmas =rühma  (IndIpfSg3  >rühmama !29_V	et	f	\N
155532	ravimtaimedest	ravimtaimedest =ede  (SgEl  >ravim+taim+ede !16_S	et	f	\N
155533	ravimtaimedest	ravimtaimedest =edes  (SgP  >ravim+taim+edene !10_A	et	f	\N
155534	ravimtaimedest	"ravim+taim+edene %ede  )NE_aA  <ravim+taim+ede ;16_S	et	f	\N
155535	ravimtaimedest	ravimtaimedest =taime  (PlEl  >ravim+taim !22_S	et	f	\N
155539	igaühest	igaühest =ühe  (SgEl  >iga+üks !22_P	et	f	\N
155540	igaühest	igaühest =ühes  (SgP  >iga+ühene !10_AS	et	f	\N
155541	presentatsioon	?presentatsioon =presentatsioon  (SgN  >presentatsioon !22_S	et	f	\N
155542	presentatsioon	?presentatsioon =atsioon  (SgN  >present+atsioon !22_S	et	f	\N
155543	presentatsioon	?presentatsioon =sentatsioon  (SgN  >pre+sentatsioon !22_S	et	f	\N
155260	ohustavad	ohustavad =ohusta  (IndPrPl3  >ohustama !27_V	et	f	\N
155261	ohustavad	ohustavad =ohustava  (PlN  >ohustav !02_A	et	f	\N
155262	ohustavad	"ohustav %ohusta  )V_vA  <ohustama ;27_V	et	f	\N
155268	jookseks	jookseks =jookse  (PlTr  >jooks !22_S	et	f	\N
155269	jookseks	jookseks =jookse  (KndPrPs  >jooksma !32_V	et	f	\N
155275	abirahast	abirahast =raha  (SgEl  >abi+raha !17_S	et	f	\N
155276	abirahast	abirahast =raha  (SgEl  >abi+rahk !22_S	et	f	\N
155277	abirahast	abirahast =rahas  (SgP  >abi+rahane !10_A	et	f	\N
155278	abirahast	"abi+rahane %raha  )NE_aA  <abi+raha ;17_S	et	f	\N
155279	abirahast	"abi+rahane %raha  )NE_aA  <abi+rahk ;22_S	et	f	\N
155283	kroonid	kroonid =krooni  (PlN  >kroon !22_S	et	f	\N
155284	kroonid	kroonid =krooni  (IndPrSg2  >kroonima !28_V	et	f	\N
155291	eksisteerinud	eksisteerinud =eksisteeri  (PtsPtPs  >eksisteerima !28_V	et	f	\N
155292	eksisteerinud	eksisteerinud =eksisteerinu  (PlN  >eksisteerinu !01_S	et	f	\N
155293	eksisteerinud	"eksisteerinu %eksisteeri  )NU_vS  <eksisteerima ;28_V	et	f	\N
155294	eksisteerinud	eksisteerinud =eksisteerinud  (ID  >eksisteerinud !41_A	et	f	\N
155295	eksisteerinud	"eksisteerinud %eksisteeri  )NUD_vA  <eksisteerima ;28_V	et	f	\N
155313	tunnegi	tunnegi =tunne  (SgN^  >tunne !06_S	et	f	\N
155314	tunnegi	tunnegi =tunne  (IndPrPs_^  >tundma !34_V	et	f	\N
155315	tunnegi	tunnegi =tunne  (ImpPrSg2^  >tundma !34_V	et	f	\N
155324	kulul	kulul =kulu  (SgAd  >kulu !17_S	et	f	\N
155325	kulul	kulul =kulu  (SgAd  >kulg !22_S	et	f	\N
155326	kulul	kulul =kulul  (ID  >kulul !41_K	et	f	\N
155362	naftaseid	naftaseid =naftase  (PlP  >naftane !10_A	et	f	\N
155363	naftaseid	"naftane %nafta  )NE_aA  <nafta ;16_S	et	f	\N
155399	laol	laol =lao  (SgAd  >ladu !18_S	et	f	\N
155400	laol	laol =lao  (SgAd  >lagu !18_S	et	f	\N
155409	valvuda	?valvuda =valvu  (Inf  >valvuma !27_V	et	f	\N
155410	moblad	?moblad =mobla  (PlN  >mobla !16_S	et	f	\N
155411	moblad	?moblad =mobla  (IndPrSg2  >moblama !27_V	et	f	\N
155417	pangatöötaja	pangatöötaja =töötaja  (SgN  >panga+töötaja !01_S	et	f	\N
155418	pangatöötaja	pangatöötaja =töötaja  (SgG  >panga+töötaja !01_S	et	f	\N
155421	suhtlemisvaba	suhtlemisvaba =vaba  (SgN  >suhtlemis+vaba !17_A	et	f	\N
155422	suhtlemisvaba	suhtlemisvaba =vaba  (SgG  >suhtlemis+vaba !17_A	et	f	\N
155423	suhtlemisvaba	suhtlemisvaba =vaba  (SgP  >suhtlemis+vaba !17_A	et	f	\N
155424	ebatavalisse	ebatavalisse =tavalis  (SgAdt  >eba+tavaline !12_A	et	f	\N
155425	ebatavalisse	"eba+tavaline %tava  )LINE_aA  <eba+tava ;17_S	et	f	\N
155458	küpsis	küpsis =küpsi  (SgIn  >küps !02_A	et	f	\N
155459	küpsis	küpsis =küpsis  (SgN  >küpsis !09_S	et	f	\N
155491	iseloomustada	?iseloomustada =iseloomusta  (Inf  >iseloomustama !27_V	et	f	\N
155492	iseloomustada	?iseloomustada =ada  (SgN  >ise+loo+must+ada !17_S	et	f	\N
155493	iseloomustada	?iseloomustada =ada  (SgG  >ise+loo+must+ada !17_S	et	f	\N
155494	iseloomustada	?iseloomustada =ada  (SgP  >ise+loo+must+ada !17_S	et	f	\N
155495	iseloomustada	?iseloomustada =stada  (SgN  >ise+loomu+stada !17_S	et	f	\N
155496	iseloomustada	?iseloomustada =stada  (SgG  >ise+loomu+stada !17_S	et	f	\N
155497	iseloomustada	?iseloomustada =stada  (SgP  >ise+loomu+stada !17_S	et	f	\N
155498	iseloomustada	?iseloomustada =loomusta  (Inf  >ise+loomustama !27_V	et	f	\N
155504	mängufilmi	mängufilmi =filmi  (SgG  >mängu+film !22_S	et	f	\N
155505	mängufilmi	mängufilmi =filmi  (SgP  >mängu+film !22_S	et	f	\N
155506	mängufilmi	mängufilmi =filmi  (SgAdt  >mängu+film !22_S	et	f	\N
155511	ebaedu	ebaedu =edu  (SgN  >eba+edu !17_S	et	f	\N
155512	ebaedu	ebaedu =edu  (SgG  >eba+edu !17_S	et	f	\N
155513	ebaedu	ebaedu =edu  (SgP  >eba+edu !17_S	et	f	\N
155536	nas	### nas	et	f	\N
155548	tundmatud	tundmatud =tundmatu  (PlN  >tundmatu !01_AS	et	f	\N
155549	tundmatud	"tundmatu %tund  )MATU_vA  <tundma ;34_V	et	f	\N
155603	juhtida	juhtida =juhti  (Inf  >juhtima !28_V	et	f	\N
155604	juhtida	juhtida =ida  (SgN  >juht+ida !17_S	et	f	\N
155605	juhtida	juhtida =ida  (SgG  >juht+ida !17_S	et	f	\N
155606	juhtida	juhtida =ida  (SgP  >juht+ida !17_S	et	f	\N
155624	soiseks	soiseks =soise  (SgTr  >soine !10_A	et	f	\N
155625	soiseks	"soine %soi  )NE_aA  <soo ;26_S	et	f	\N
155626	ekosüsteemi	?ekosüsteemi =ekosüsteemi  (SgN  >ekosüsteemi !16_S	et	f	\N
155627	ekosüsteemi	?ekosüsteemi =ekosüsteemi  (SgG  >ekosüsteemi !16_S	et	f	\N
155628	ekosüsteemi	?ekosüsteemi =ekosüsteemi  (SgG  >ekosüsteem !22_S	et	f	\N
155629	ekosüsteemi	?ekosüsteemi =ekosüsteemi  (SgP  >ekosüsteem !22_S	et	f	\N
155630	ekosüsteemi	?ekosüsteemi =ekosüsteemi  (SgAdt  >ekosüsteem !22_S	et	f	\N
155631	ekosüsteemi	?ekosüsteemi =ekosüsteemi  (IndPrPs_  >ekosüsteemima !28_V	et	f	\N
155632	ekosüsteemi	?ekosüsteemi =ekosüsteemi  (ImpPrSg2  >ekosüsteemima !28_V	et	f	\N
155642	suhtlemiseks	suhtlemiseks =suhtlemise  (SgTr  >suhtlemine !12_S	et	f	\N
155643	suhtlemiseks	"suhtlemine %suhtle  )MINE_vS  <suhtlema ;30_V	et	f	\N
155675	oodus	?oodus =oodu  (SgIn  >oodu !16_S	et	f	\N
155676	oodus	?oodus =oodu  (IndIpfSg3  >ooduma !27_V	et	f	\N
155677	oodus	?oodus =oodus  (SgN  >oodus !09_S	et	f	\N
155752	renoveerima	?renoveerima =renoveeri  (Sup  >renoveerima !28_V	et	f	\N
155427	nätas	?nätas =näta  (IndIpfSg3  >nätama !27_V	et	f	\N
155428	nätas	?nätas =nätas  (SgN  >nätas !07_S	et	f	\N
155453	söögist	söögist =söögi  (SgEl  >söök !22_S	et	f	\N
155454	söögist	söögist =söögis  (SgP  >söögine !10_A	et	f	\N
155455	söögist	"söögine %söögi  )NE_aA  <söök ;22_S	et	f	\N
155460	kastes	kastes =kast  (Ger  >kastma !34_V	et	f	\N
155461	kastes	kastes =kaste  (SgIn  >kaste !06_S	et	f	\N
155462	kastes	kastes =kaste  (PlIn  >kast !22_S	et	f	\N
155470	valgel	valgel =valge  (SgAd  >valge !01_AS	et	f	\N
155471	valgel	valgel =valge  (PlAd  >valk !22_S	et	f	\N
155481	metsakale	metsakale =metsaka  (SgAll  >metsakas !02_A	et	f	\N
155482	metsakale	metsakale =kale  (SgN  >metsa+kale !02_A	et	f	\N
155483	metsakale	metsakale =kale  (SgN  >metsa+kale !16_S	et	f	\N
155484	metsakale	metsakale =kale  (SgG  >metsa+kale !16_S	et	f	\N
155485	metsakale	metsakale =aka  (SgAll  >mets+aka !16_S	et	f	\N
155499	haigust	haigust =haigu  (SgEl  >haik !22_S	et	f	\N
155500	haigust	haigust =haigus  (SgP  >haigus !11~09_S	et	f	\N
155501	haigust	"haigus %haige  )US_aS  <haige ;01_AS	et	f	\N
155507	moto	moto =moto  (SgN  >moto !16_S	et	f	\N
155508	moto	moto =moto  (SgG  >moto !16_S	et	f	\N
155526	ekspromt	?ekspromt =ekspromt  (SgN  >ekspromt !22_S	et	f	\N
155527	ekspromt	?ekspromt =promt  (SgN  >eks+promt !22_S	et	f	\N
155537	valisid	valisid =vali  (IndIpfSg2  >valima !27_V	et	f	\N
155538	valisid	valisid =vali  (IndIpfPl3  >valima !27_V	et	f	\N
155588	jahjuks	?jahjuks =jahju  (SgTr  >jahju !16_S	et	f	\N
155589	jahjuks	?jahjuks =jahju  (KndPrPs  >jahjuma !27_V	et	f	\N
155595	laagnas	?laagnas =laagna  (SgIn  >laagna !01_S	et	f	\N
155596	laagnas	?laagnas =laagna  (IndIpfSg3  >laagnama !29_V	et	f	\N
155597	laagnas	?laagnas =laagnas  (SgN  >laagnas !07_S	et	f	\N
155607	lõket	lõket =lõke  (SgP  >lõke !05_S	et	f	\N
155608	lõket	lõket =lõke  (SgP  >lõke !06_S	et	f	\N
155609	teenindamisest	teenindamisest =teenindamise  (SgEl  >teenindamine !12_S	et	f	\N
155610	teenindamisest	"teenindamine %teeninda  )MINE_vS  <teenindama ;27_V	et	f	\N
155617	reostatud	reostatud =reosta  (PtsPtIps  >reostama !27_V	et	f	\N
155618	reostatud	reostatud =reostatu  (PlN  >reostatu !01_S	et	f	\N
155619	reostatud	"reostatu %reosta  )TU1_vS  <reostama ;27_V	et	f	\N
155620	reostatud	reostatud =reostatud  (ID  >reostatud !41_A	et	f	\N
155621	reostatud	"reostatud %reosta  )TUD_vA  <reostama ;27_V	et	f	\N
155633	veekogu	veekogu =kogu  (SgN  >vee+kogu !17_S	et	f	\N
155634	veekogu	veekogu =kogu  (SgG  >vee+kogu !17_S	et	f	\N
155635	veekogu	veekogu =kogu  (SgP  >vee+kogu !17_S	et	f	\N
155652	põlvadele	?põlvadele =põlva  (PlAll  >põlva !16_S	et	f	\N
155653	põlvadele	?põlvadele =ade  (SgAll  >põlv+ade !16_S	et	f	\N
155654	prügikaste	prügikaste =kaste  (SgN  >prügi+kaste !05_S	et	f	\N
155655	prügikaste	prügikaste =kaste  (SgN  >prügi+kaste !06_S	et	f	\N
155656	prügikaste	prügikaste =kaste  (SgG  >prügi+kaste !06_S	et	f	\N
155657	prügikaste	prügikaste =kaste  (PlP  >prügi+kast !22_S	et	f	\N
155691	autolikluse	?autolikluse =autolikluse  (SgG  >autoliklus !11~09_S	et	f	\N
155692	autolikluse	?autolikluse =tolikluse  (SgG  >au+toliklus !11_S	et	f	\N
155695	ummikuid	ummikuid =ummiku  (PlP  >ummik !02_S	et	f	\N
155696	ummikuid	ummikuid =ui  (PlN  >ummik+ui !26_S	et	f	\N
155697	ummikuid	ummikuid =ui  (SgP  >ummik+ui !26_S	et	f	\N
155698	ummikuid	ummikuid =uid  (SgN  >ummik+uid !22_S	et	f	\N
155713	tugevatoimelised	tugevatoimelised =toimelise  (PlN  >tugeva+toimeline !12_A	et	f	\N
155714	tugevatoimelised	"tugeva+toimeline %toime  )LINE_aA  <tugeva+toime ;06_S	et	f	\N
155715	tugevatoimelised	"tugeva+toimeline %toime  )LINE_aA  <tugeva+toim ;22_S	et	f	\N
155718	dushigeeliga	?dushigeeliga =dushigeeli  (SgKom  >dushigeeli !16_S	et	f	\N
155719	dushigeeliga	?dushigeeliga =dushigeeli  (SgKom  >dushigeel !22_S	et	f	\N
155789	köögijäätmetest	köögijäätmetest =test  (SgN  >köögi+jäätme+test !22_S	et	f	\N
155790	köögijäätmetest	köögijäätmetest =me  (PlEl  >köögi+jäät+mesi !15_S	et	f	\N
155791	köögijäätmetest	köögijäätmetest =mete  (PlEl  >köögi+jäät+mett !22_S	et	f	\N
155792	köögijäätmetest	köögijäätmetest =jäätme  (PlEl  >köögi+jääde !05_S	et	f	\N
155809	tavalistele	tavalistele =tavalis  (PlAll  >tavaline !12_A	et	f	\N
155810	tavalistele	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
155817	kohtumiste	kohtumiste =kohtumis  (PlG  >kohtumine !12_S	et	f	\N
155818	kohtumiste	"kohtumine %kohtu  )MINE_vS  <kohtuma ;27_V	et	f	\N
155821	sillutataud	?sillutataud =sillutatau  (PlN  >sillutatau !26_S	et	f	\N
155822	sillutataud	?sillutataud =sillutatau  (SgP  >sillutatau !26_S	et	f	\N
155823	sillutataud	?sillutataud =sillutataud  (SgN  >sillutataud !22_S	et	f	\N
155861	cd-	### cd-	et	f	\N
155882	tevad	?tevad =teva  (PlN  >teva !17_S	et	f	\N
155883	tevad	?tevad =teva  (IndPrSg2  >tevama !27_V	et	f	\N
155886	sarnaseks	sarnaseks =sarnase  (SgTr  >sarnane !10_A	et	f	\N
155887	sarnaseks	"sarnane %sarna  )NE_aA  <sarn ;22_S	et	f	\N
155904	kutluuriajaloos	?kutluuriajaloos =kutluuriajaloo  (SgIn  >kutluuriajaloo !26_S	et	f	\N
155905	kutluuriajaloos	?kutluuriajaloos =kutluuriajaloos  (SgN  >kutluuriajaloos !22_S	et	f	\N
155463	heledada	?heledada =dada  (SgN  >hele+dada !17_S	et	f	\N
155464	heledada	?heledada =dada  (SgG  >hele+dada !17_S	et	f	\N
155465	heledada	?heledada =dada  (SgP  >hele+dada !17_S	et	f	\N
155467	printsi	printsi =printsi  (SgG  >prints !22_S	et	f	\N
155468	printsi	printsi =printsi  (SgP  >prints !22_S	et	f	\N
155469	printsi	printsi =printsi  (SgAdt  >prints !22_S	et	f	\N
155489	esinemist	esinemist =esinemis  (SgP  >esinemine !12_S	et	f	\N
155490	esinemist	"esinemine %esine  )MINE_vS  <esinema ;27_V	et	f	\N
155502	jutustamist	jutustamist =jutustamis  (SgP  >jutustamine !12_S	et	f	\N
155503	jutustamist	"jutustamine %jutusta  )MINE_vS  <jutustama ;27_V	et	f	\N
155509	südavale	südavale =vale  (SgN  >süda+vale !16_SA	et	f	\N
155510	südavale	südavale =vale  (SgG  >süda+vale !16_SA	et	f	\N
155528	takerdusid	takerdusid =takerdu  (IndIpfSg2  >takerduma !27_V	et	f	\N
155529	takerdusid	takerdusid =takerdu  (IndIpfPl3  >takerduma !27_V	et	f	\N
155550	egav	?egav =ega  (PtsPrPs  >egama !27_V	et	f	\N
155551	egav	?egav =egav  (SgN  >egav !02_A	et	f	\N
155574	reklaamis	reklaamis =reklaami  (SgIn  >reklaam !22_S	et	f	\N
155575	reklaamis	reklaamis =reklaami  (IndIpfSg3  >reklaamima !28_V	et	f	\N
155579	e-mailile	?e-mailile =maili  (SgAll  >e-maili !16_S	et	f	\N
155580	e-mailile	?e-mailile =maili  (SgAll  >e-mail !22_S	et	f	\N
155581	e-mailile	?e-mailile =mailile  (IndPrPs_  >e-maililema !27_V	et	f	\N
155582	e-mailile	?e-mailile =mailile  (ImpPrSg2  >e-maililema !27_V	et	f	\N
155583	e-mailile	?e-mailile =lile  (SgN  >e-mai+lile !16_S	et	f	\N
155584	e-mailile	?e-mailile =lile  (SgG  >e-mai+lile !16_S	et	f	\N
155587	pover	?pover =pover  (SgN  >pover !02_S	et	f	\N
155611	baarmenina	?baarmenina =baarmeni  (SgEs  >baarmen !02_S	et	f	\N
155612	baarmenina	?baarmenina =baarmenina  (SgG  >baarmenin !19_S	et	f	\N
155613	baarmenina	?baarmenina =baarmenina  (SgP  >baarmenin !19_S	et	f	\N
155614	baarmenina	?baarmenina =baarmenina  (SgAdt  >baarmenin !19_S	et	f	\N
155615	baarmenina	?baarmenina =meni  (SgEs  >baar+meni !17_S	et	f	\N
155616	baarmenina	?baarmenina =menina  (SgG  >baar+menin !02_S	et	f	\N
155644	kaunist	kaunist =kauni  (SgEl  >kaunis !05~07_A	et	f	\N
155645	kaunist	kaunist =kauni  (SgEl  >kaun !22_S	et	f	\N
155646	kaunist	kaunist =kauni  (PlEl  >kaun !22_S	et	f	\N
155647	kaunist	kaunist =kaunis  (SgP  >kaunis !05~07_A	et	f	\N
155672	ülapool	ülapool =pool  (ID  >üla+pool !41_DK	et	f	\N
155673	ülapool	ülapool =pool  (SgN  >üla+pool !13_NS	et	f	\N
155674	ülapool	ülapool =pool  (SgN  >üla+pool !22_S	et	f	\N
155685	jalgrattateed	jalgrattateed =tee  (PlN  >jalg+ratta+tee !26_S	et	f	\N
155686	jalgrattateed	jalgrattateed =tee  (SgP  >jalg+ratta+tee !26_S	et	f	\N
155687	avariid	avariid =avari  (PlP  >avar !02_A	et	f	\N
155688	avariid	avariid =avarii  (PlN  >avarii !26_S	et	f	\N
155689	avariid	avariid =avarii  (SgP  >avarii !26_S	et	f	\N
155690	avariid	avariid =riid  (SgN  >ava+riid !22_S	et	f	\N
155703	puhastamis-	?puhastamis- =puhastami  (SgIn  >puhastam !02_A	et	f	\N
155704	puhastamis-	?puhastamis- =puhastamis  (SgN  >puhastamis !09_S	et	f	\N
155706	puhastamis-	?puhastamis- =ami  (SgIn  >puhast+ami !17_S	et	f	\N
155707	puhastamis-	?puhastamis- =amis  (SgN  >puhast+amis !09_S	et	f	\N
155708	puhastamis-	?puhastamis- =tami  (SgIn  >puhas+tami !17_S	et	f	\N
155709	puhastamis-	?puhastamis- =tamis  (SgN  >puhas+tamis !09_S	et	f	\N
155720	meigivad	?meigivad =meigi  (IndPrPl3  >meikima !28_V	et	f	\N
155724	meigivad	?meigivad =meigiva  (PlN  >meigiva !01_S	et	f	\N
155725	meigivad	?meigivad =meigiva  (PlN  >meigiv !02_A	et	f	\N
155726	kaunilt	kaunilt =kauni  (SgAbl  >kaunis !05~07_A	et	f	\N
155727	kaunilt	kaunilt =kauni  (SgAbl  >kaun !22_S	et	f	\N
155728	kaunilt	kaunilt =kauni  (PlAbl  >kaun !22_S	et	f	\N
155729	kaunilt	kaunilt =kaunilt  (ID  >kaunilt !41_D	et	f	\N
155730	kaunilt	"kaunilt %kauni  )LT_mD  <kaunis ;05_A	et	f	\N
155731	kaunilt	"kaunilt %kauni  )LT_mD  <kaunis ;07_A	et	f	\N
155735	keemiliste	keemiliste =keemilis  (PlG  >keemiline !12_A	et	f	\N
155736	keemiliste	"keemiline %keemi  )LINE_aA  <keem ;22_S	et	f	\N
155742	kasutamisega	kasutamisega =kasutamise  (SgKom  >kasutamine !12_S	et	f	\N
155743	kasutamisega	"kasutamine %kasuta  )MINE_vS  <kasutama ;27_V	et	f	\N
155750	suurtest	suurtest =suur  (PlEl  >suur !13_A	et	f	\N
155751	suurtest	suurtest =test  (SgN  >suur+test !22_S	et	f	\N
155754	ohutum	ohutum =ohutum  (SgN  >ohutum !02_A	et	f	\N
155755	ohutum	"ohutum %ohu  )TUM2_cA  <oht ;22_S	et	f	\N
155756	ohutum	"ohutum %ohutu  )M_cA  <ohutu ;01_A	et	f	\N
155775	ökoloogiline	ökoloogiline =ökoloogiline  (SgN  >ökoloogiline !12_A	et	f	\N
155776	ökoloogiline	"ökoloogiline %ökoloogi  )LINE_aA  <ökoloog ;22_S	et	f	\N
155777	ökoloogiline	ökoloogiline =loogiline  (SgN  >öko+loogiline !12_A	et	f	\N
155778	ökoloogiline	"öko+loogiline %loogi  )LINE_aA  <öko+loog ;22_S	et	f	\N
155787	lagunevatest	lagunevatest =laguneva  (PlEl  >lagunev !02_A	et	f	\N
155788	lagunevatest	"lagunev %lagune  )V_vA  <lagunema ;27_V	et	f	\N
155804	taaskasutatavat	taaskasutatavat =kasuta  (KvtPrIps  >taas+kasutama !27_V	et	f	\N
155805	taaskasutatavat	"taas+kasutatav %kasuta  )TAV_vAS  <taas+kasutama ;27_V	et	f	\N
155840	reisimise	reisimise =reisimise  (SgG  >reisimine !12_S	et	f	\N
155544	jätav	?jätav =jäta  (PtsPrPs  >jätama !27_V	et	f	\N
155545	jätav	?jätav =jätav  (SgN  >jätav !02_A	et	f	\N
155572	tüüdrukud	?tüüdrukud =tüüdruku  (PlN  >tüüdruku !01_S	et	f	\N
155573	tüüdrukud	?tüüdrukud =tüüdruku  (IndPrSg2  >tüüdrukuma !27_V	et	f	\N
155590	arkadi	?arkadi =arkadi  (SgN  >arkadi !01_S	et	f	\N
155591	arkadi	?arkadi =arkadi  (SgG  >arkadi !01_S	et	f	\N
155592	kohtadesmina	?kohtadesmina =kohtadesmi  (SgEs  >kohtadesm !22_S	et	f	\N
155593	kohtadesmina	?kohtadesmina =adesmi  (SgEs  >koht+adesmi !01_S	et	f	\N
155594	kohtadesmina	?kohtadesmina =adesmi  (SgEs  >koht+adesm !22_S	et	f	\N
155598	püüelsid	?püüelsid =püüelsi  (PlN  >püüelsi !01_S	et	f	\N
155599	püüelsid	?püüelsid =püüelsi  (PlN  >püüels !22_S	et	f	\N
155600	püüelsid	?püüelsid =püüelsi  (IndPrSg2  >püüelsima !28_V	et	f	\N
155648	tulevastele	tulevastele =tulevas  (PlAll  >tulevane !12_AS	et	f	\N
155649	tulevastele	tulevastele =aste  (SgAll  >tulev+aste !06_S	et	f	\N
155650	tulevastele	tulevastele =aste  (PlAll  >tulev+ast !22_S	et	f	\N
155651	tulevastele	tulevastele =vaste  (SgAll  >tule+vaste !06_S	et	f	\N
155658	puhtam	puhtam =puhtam  (SgN  >puhtam !02_A	et	f	\N
155659	puhtam	"puhtam %puhta  )M_cA  <puhas ;07_A	et	f	\N
155660	eelised	eelised =eelise  (PlN  >eelis !09_S	et	f	\N
155661	eelised	eelised =eelise  (PlN  >eeline !10_A	et	f	\N
155662	eelised	"eeline %ee  )LINE_aA  <esi ;15_S	et	f	\N
155665	turvaliselt	turvaliselt =turvalise  (SgAbl  >turvaline !12_A	et	f	\N
155666	turvaliselt	"turvaline %turva  )LINE_aA  <turb ;22_SA	et	f	\N
155667	turvaliselt	"turvaline %turva  )LINE_aA  <turv ;22_S	et	f	\N
155668	turvaliselt	turvaliselt =turvaliselt  (ID  >turvaliselt !41_D	et	f	\N
155669	turvaliselt	"turvaliselt %turva  )LISELT_mD  <turb ;22_SA	et	f	\N
155670	turvaliselt	"turvaliselt %turva  )LISELT_mD  <turv ;22_S	et	f	\N
155671	turvaliselt	"turvaliselt %turvalise  )LT_mD  <turvaline ;12_A	et	f	\N
155693	piiramist	piiramist =piiramis  (SgP  >piiramine !12_S	et	f	\N
155694	piiramist	"piiramine %piira  )MINE_vS  <piirama ;29_V	et	f	\N
155699	igalpoolpraktiliselt	igalpoolpraktiliselt =praktilise  (SgAbl  >igal+pool+praktiline !12_A	et	f	\N
155700	igalpoolpraktiliselt	"igal+pool+praktiliselt %praktilise  )LT_mD  <igal+pool+praktiline ;12_A	et	f	\N
155701	pesemis-	?pesemis- =pesemi  (SgIn  >pesemi !01_S	et	f	\N
155702	pesemis-	?pesemis- =pesemi  (SgIn  >pesem !02_A	et	f	\N
155705	pesemis-	?pesemis- =pesemis  (SgN  >pesemis !11_S	et	f	\N
155710	sisaldavad	sisaldavad =sisalda  (IndPrPl3  >sisaldama !27_V	et	f	\N
155711	sisaldavad	sisaldavad =sisaldava  (PlN  >sisaldav !02_A	et	f	\N
155712	sisaldavad	"sisaldav %sisalda  )V_vA  <sisaldama ;27_V	et	f	\N
155716	shampooniga	?shampooniga =shampooni  (SgKom  >shampooni !16_S	et	f	\N
155717	shampooniga	?shampooniga =shampooni  (SgKom  >shampoon !22_S	et	f	\N
155732	kuivaks	kuivaks =kuiva  (SgTr  >kuiv !22_AS	et	f	\N
155733	kuivaks	kuivaks =kuiva  (KndPrPs  >kuivama !28_V	et	f	\N
155734	kuivaks	kuivaks =vaks  (SgN  >kui+vaks !22_S	et	f	\N
155737	koristajad	koristajad =koristaja  (PlN  >koristaja !01_S	et	f	\N
155738	koristajad	"koristaja %korista  )JA_vS  <koristama ;27_V	et	f	\N
155748	ebakord	ebakord =kord  (ID  >eba+kord !41_D	et	f	\N
155749	ebakord	ebakord =kord  (SgN  >eba+kord !22_S	et	f	\N
155760	saastatud	saastatud =saasta  (PtsPtIps  >saastama !29~27_V	et	f	\N
155761	saastatud	saastatud =saastatu  (PlN  >saastatu !01_S	et	f	\N
155762	saastatud	"saastatu %saasta  )TU1_vS  <saastama ;27_V	et	f	\N
155763	saastatud	"saastatu %saasta  )TU1_vS  <saastama ;29_V	et	f	\N
155764	saastatud	"saastatu %saasta  )TU2_kA  <saast ;22_S	et	f	\N
155765	saastatud	saastatud =saastatud  (ID  >saastatud !41_A	et	f	\N
155766	saastatud	"saastatud %saasta  )TUD_vA  <saastama ;27_V	et	f	\N
155767	saastatud	"saastatud %saasta  )TUD_vA  <saastama ;29_V	et	f	\N
155768	koduümbuuses	?koduümbuuses =koduümbuuse  (SgIn  >koduümbuuse !16_S	et	f	\N
155769	koduümbuuses	?koduümbuuses =koduümbuuse  (PlIn  >koduümbuus !22_S	et	f	\N
155770	koduümbuuses	?koduümbuuses =ümbuuse  (SgIn  >kodu+ümbuuse !16_S	et	f	\N
155771	koduümbuuses	?koduümbuuses =ümbuuse  (PlIn  >kodu+ümbuus !22_S	et	f	\N
155781	resursse	?resursse =resursse  (SgG  >resursne !02_A	et	f	\N
155782	resursse	?resursse =resursse  (PlP  >resurss !22_S	et	f	\N
155819	vaatamiseks	vaatamiseks =vaatamise  (SgTr  >vaatamine !12_S	et	f	\N
155820	vaatamiseks	"vaatamine %vaata  )MINE_vS  <vaatama ;29_V	et	f	\N
155824	tänavate	tänavate =tänava  (PlG  >tänav !02_A	et	f	\N
155825	tänavate	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
155826	tänavate	tänavate =tänava  (PlG  >tänav !02_S	et	f	\N
155829	pildidl	?pildidl =pildidl  (SgN  >pildidl !22_S	et	f	\N
155833	efektiivselt	efektiivselt =efektiivse  (SgAbl  >efektiivne !02_A	et	f	\N
155834	efektiivselt	efektiivselt =efektiivselt  (ID  >efektiivselt !41_D	et	f	\N
155835	efektiivselt	"efektiivselt %efektiivse  )LT_mD  <efektiivne ;02_A	et	f	\N
155836	lahendasid	lahendasid =lahenda  (IndIpfSg2  >lahendama !27_V	et	f	\N
155837	lahendasid	lahendasid =lahenda  (IndIpfPl3  >lahendama !27_V	et	f	\N
155838	välismaad	välismaad =maa  (PlN  >välis+maa !26_S	et	f	\N
155839	välismaad	välismaad =maa  (SgP  >välis+maa !26_S	et	f	\N
155852	soobivat	?soobivat =soobi  (KvtPrPs  >soobima !27_V	et	f	\N
155555	presentatsiooni	?presentatsiooni =presentatsiooni  (SgG  >presentatsioon !22_S	et	f	\N
155556	presentatsiooni	?presentatsiooni =presentatsiooni  (SgP  >presentatsioon !22_S	et	f	\N
155557	presentatsiooni	?presentatsiooni =presentatsiooni  (SgAdt  >presentatsioon !22_S	et	f	\N
155558	presentatsiooni	?presentatsiooni =presentatsiooni  (IndPrPs_  >presentatsioonima !28_V	et	f	\N
155559	presentatsiooni	?presentatsiooni =presentatsiooni  (ImpPrSg2  >presentatsioonima !28_V	et	f	\N
155560	presentatsiooni	?presentatsiooni =atsioo  (SgTer  >present+atsioo !26_S	et	f	\N
155561	presentatsiooni	?presentatsiooni =atsiooni  (SgN  >present+atsiooni !16_S	et	f	\N
155562	presentatsiooni	?presentatsiooni =atsiooni  (SgG  >present+atsiooni !16_S	et	f	\N
155563	presentatsiooni	?presentatsiooni =atsiooni  (SgG  >present+atsioon !22_S	et	f	\N
155564	presentatsiooni	?presentatsiooni =atsiooni  (SgP  >present+atsioon !22_S	et	f	\N
155565	presentatsiooni	?presentatsiooni =atsiooni  (SgAdt  >present+atsioon !22_S	et	f	\N
155566	presentatsiooni	?presentatsiooni =sentatsioo  (SgTer  >pre+sentatsioo !26_S	et	f	\N
155567	presentatsiooni	?presentatsiooni =sentatsiooni  (SgN  >pre+sentatsiooni !16_S	et	f	\N
155568	presentatsiooni	?presentatsiooni =sentatsiooni  (SgG  >pre+sentatsiooni !16_S	et	f	\N
155569	presentatsiooni	?presentatsiooni =sentatsiooni  (SgG  >pre+sentatsioon !22_S	et	f	\N
155570	presentatsiooni	?presentatsiooni =sentatsiooni  (SgP  >pre+sentatsioon !22_S	et	f	\N
155571	presentatsiooni	?presentatsiooni =sentatsiooni  (SgAdt  >pre+sentatsioon !22_S	et	f	\N
155576	a-i	a-i =a  (SgG  >a !xx_Q	et	f	\N
155577	a-i	a-i =a  (SgP  >a !xx_Q	et	f	\N
155578	a-i	a-i =a  (SgAdt  >a !xx_Q	et	f	\N
155585	pointis	?pointis =pointi  (IndIpfSg3  >pointima !28_V	et	f	\N
155586	pointis	?pointis =pointis  (ID  >pointis !41_DA	et	f	\N
155601	välismaalastega	välismaalastega =las  (PlKom  >välis+maa+laps !14_S	et	f	\N
155602	välismaalastega	välismaalastega =maalas  (PlKom  >välis+maalane !12?10_S	et	f	\N
155622	õitseb	õitseb =õitse  (IndPrSg3  >õitsema !28_V	et	f	\N
155623	õitseb	õitseb =õitse  (IndPrSg3  >õitsma !32_V	et	f	\N
155636	supelda	supelda =supel  (Inf  >suplema !30_V	et	f	\N
155637	supelda	supelda =supel  (IndPrIps_  >suplema !30_V	et	f	\N
155638	lastemaänguväljakute	?lastemaänguväljakute =lastemaänguväljaku  (IndPrPl2  >lastemaänguväljakuma !27_V	et	f	\N
155639	kasvaksid	kasvaksid =kasva  (KndPrSg2  >kasvama !28_V	et	f	\N
155640	kasvaksid	kasvaksid =kasva  (KndPrPl3  >kasvama !28_V	et	f	\N
155641	kasvaksid	kasvaksid =vaksi  (PlN  >kas+vaks !22_S	et	f	\N
155663	suurlinnas	suurlinnas =linna  (SgIn  >suur+linn !22_S	et	f	\N
155664	suurlinnas	suurlinnas =linnas  (SgN  >suur+linnas !09_S	et	f	\N
155678	taimede	taimede =taime  (PlG  >taim !22_S	et	f	\N
155679	taimede	taimede =ede  (SgN  >taim+ede !16_S	et	f	\N
155680	taimede	taimede =ede  (SgG  >taim+ede !16_S	et	f	\N
155681	majaümbuuses	?majaümbuuses =majaümbuuse  (SgIn  >majaümbuuse !16_S	et	f	\N
155682	majaümbuuses	?majaümbuuses =majaümbuuse  (PlIn  >majaümbuus !22_S	et	f	\N
155683	majaümbuuses	?majaümbuuses =ümbuuse  (SgIn  >maja+ümbuuse !16_S	et	f	\N
155684	majaümbuuses	?majaümbuuses =ümbuuse  (PlIn  >maja+ümbuus !22_S	et	f	\N
155721	lõhnastavad	lõhnastavad =lõhnasta  (IndPrPl3  >lõhnastama !27_V	et	f	\N
155722	lõhnastavad	lõhnastavad =lõhnastava  (PlN  >lõhnastav !02_A	et	f	\N
155723	lõhnastavad	"lõhnastav %lõhnasta  )V_vA  <lõhnastama ;27_V	et	f	\N
155739	laboratooriumi	laboratooriumi =laboratooriumi  (SgG  >laboratoorium !19~02_S	et	f	\N
155740	laboratooriumi	laboratooriumi =laboratooriumi  (SgP  >laboratoorium !19_S	et	f	\N
155741	laboratooriumi	laboratooriumi =laboratooriumi  (SgAdt  >laboratoorium !19_S	et	f	\N
155744	wwwaktiivsednooredee	?wwwaktiivsednooredee =wwwaktiivsednooredee  (SgN  >wwwaktiivsednooredee !26_S	et	f	\N
155745	wwwaktiivsednooredee	?wwwaktiivsednooredee =wwwaktiivsednooredee  (SgG  >wwwaktiivsednooredee !26_S	et	f	\N
155746	lahenduste	lahenduste =lahendus  (PlG  >lahendus !11_S	et	f	\N
155747	lahenduste	"lahendus %lahenda  )US_vS  <lahendama ;27_V	et	f	\N
155773	parimate	parimate =parima  (PlG  >parim !02_A	et	f	\N
155774	parimate	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
155779	klaastaara	klaastaara =taara  (SgN  >klaas+taara !16_S	et	f	\N
155780	klaastaara	klaastaara =taara  (SgG  >klaas+taara !16_S	et	f	\N
155793	komposti	komposti =komposti  (SgG  >kompost !22_S	et	f	\N
155794	komposti	komposti =komposti  (SgP  >kompost !22_S	et	f	\N
155795	komposti	komposti =komposti  (SgAdt  >kompost !22_S	et	f	\N
155796	komposti	komposti =komposti  (IndPrPs_  >kompostima !28_V	et	f	\N
155797	komposti	komposti =komposti  (ImpPrSg2  >kompostima !28_V	et	f	\N
155798	komposti	komposti =posti  (SgG  >kom+post !22_S	et	f	\N
155799	komposti	komposti =posti  (SgP  >kom+post !22_S	et	f	\N
155800	komposti	komposti =posti  (SgAdt  >kom+post !22_S	et	f	\N
155811	väiksedele	?väiksedele =ksede  (SgAll  >väi+ksede !16_S	et	f	\N
155827	praktiseerimine	praktiseerimine =praktiseerimine  (SgN  >praktiseerimine !12_S	et	f	\N
155828	praktiseerimine	"praktiseerimine %praktiseeri  )MINE_vS  <praktiseerima ;28_V	et	f	\N
155848	emotsiooneid	?emotsiooneid =emotsioonei  (PlN  >emotsioonei !26_S	et	f	\N
155849	emotsiooneid	?emotsiooneid =emotsioonei  (SgP  >emotsioonei !26_S	et	f	\N
155888	tähtpäevi	tähtpäevi =päevi  (SgG  >täht+päev !22_S	et	f	\N
155889	tähtpäevi	tähtpäevi =päevi  (SgP  >täht+päev !22_S	et	f	\N
155753	renoveerima	?renoveerima =renoveerima  (SgG  >renoveerim !02_A	et	f	\N
155757	kuritegevuste	kuritegevuste =us  (PlG  >kuri+tegev+uks !14_S	et	f	\N
155758	kuritegevuste	kuritegevuste =tegevus  (PlG  >kuri+tegevus !11_S	et	f	\N
155759	kuritegevuste	"kuri+tegevus %tegeva  )US_aS  <kuri+tegev ;02_A	et	f	\N
155772	aidate	?aidate =aida  (IndPrPl2  >aidama !29_V	et	f	\N
155783	bioloogiline	bioloogiline =bioloogiline  (SgN  >bioloogiline !12_A	et	f	\N
155784	bioloogiline	"bioloogiline %bioloogi  )LINE_aA  <bioloog ;22_S	et	f	\N
155785	bioloogiline	bioloogiline =loogiline  (SgN  >bio+loogiline !12_A	et	f	\N
155786	bioloogiline	"bio+loogiline %loogi  )LINE_aA  <bio+loog ;22_S	et	f	\N
155801	kilekotti	kilekotti =kotti  (SgP  >kile+kott !22_S	et	f	\N
155802	kilekotti	kilekotti =kotti  (SgAdt  >kile+kott !22_S	et	f	\N
155803	kilekotti	kilekotti =kotti  (PlP  >kile+kott !22_S	et	f	\N
155806	kogumispunkti	kogumispunkti =punkti  (SgG  >kogu+mis+punkt !22_S	et	f	\N
155807	kogumispunkti	kogumispunkti =punkti  (SgP  >kogu+mis+punkt !22_S	et	f	\N
155808	kogumispunkti	kogumispunkti =punkti  (SgAdt  >kogu+mis+punkt !22_S	et	f	\N
155812	probleemist	probleemist =probleemi  (SgEl  >probleem !22_S	et	f	\N
155813	probleemist	probleemist =probleemis  (SgP  >probleemine !10_A	et	f	\N
155814	probleemist	"probleemine %probleemi  )NE_aA  <probleem ;22_S	et	f	\N
155815	puhkamine	puhkamine =puhkamine  (SgN  >puhkamine !12_S	et	f	\N
155816	puhkamine	"puhkamine %puhka  )MINE_vS  <puhkama ;29_V	et	f	\N
155830	raid	raid =rai  (PlN  >rai !26_S	et	f	\N
155831	raid	raid =rai  (SgP  >rai !26_S	et	f	\N
155832	probleemed	?probleemed =probleeme  (PlN  >probleeme !16_S	et	f	\N
155842	soovitustest	soovitustest =soovitus  (PlEl  >soovitus !11_S	et	f	\N
155843	soovitustest	"soovitus %soovita  )US_vS  <soovitama ;27_V	et	f	\N
155844	soovitustest	"soovitus %soovi  )TUS1_aS  <soovima ;28_V	et	f	\N
155845	soovitustest	"soovitus %soovi  )TUS2_aS  <soov ;22_S	et	f	\N
155846	soovitustest	soovitustest =test  (SgN  >soovitus+test !22_S	et	f	\N
155847	soovitustest	soovitustest =tuste  (PlEl  >soovi+tust !22_S	et	f	\N
155864	jäta	jäta =jäta  (IndPrPs_  >jätma !35_V	et	f	\N
155865	jäta	jäta =jäta  (ImpPrSg2  >jätma !35_V	et	f	\N
155875	suitsuvad	suitsuvad =suitsu  (IndPrPl3  >suitsuma !27_V	et	f	\N
155876	suitsuvad	suitsuvad =suitsuva  (PlN  >suitsuv !02_A	et	f	\N
155877	suitsuvad	"suitsuv %suitsu  )V_vA  <suitsuma ;27_V	et	f	\N
155894	tunnetuslikult	tunnetuslikult =tunnetusliku  (SgAbl  >tunnetuslik !25_A	et	f	\N
155895	tunnetuslikult	tunnetuslikult =tunnetuslikult  (ID  >tunnetuslikult !41_D	et	f	\N
155896	tunnetuslikult	"tunnetuslikult %tunnetusliku  )LT_mD  <tunnetuslik ;25_A	et	f	\N
155914	eraomandiõigus	eraomandiõigus =õigus  (SgN  >era+omandi+õigus !11~09_S	et	f	\N
155915	eraomandiõigus	"era+omandi+õigus %õige  )US_aS  <era+omandi+õige ;01_A	et	f	\N
155944	külvata	külvata =külva  (Inf  >külvama !29_V	et	f	\N
155945	külvata	külvata =külva  (IndPrIps_  >külvama !29_V	et	f	\N
155948	ilmastikku	ilmastikku =ilmastikku  (SgP  >ilmastik !25_S	et	f	\N
155949	ilmastikku	ilmastikku =ilmastikku  (SgAdt  >ilmastik !25_S	et	f	\N
155976	taunitav	taunitav =tauni  (PtsPrIps  >taunima !28_V	et	f	\N
155977	taunitav	taunitav =taunitav  (SgN  >taunitav !02_A	et	f	\N
155978	taunitav	"taunitav %tauni  )TAV_vAS  <taunima ;28_V	et	f	\N
155994	parteisus	parteisus =parteisus  (SgN  >parteisus !11_S	et	f	\N
155995	parteisus	"parteisus %partei  )SUS_aS  <partei ;26_S	et	f	\N
156001	ülemvõi	ülemvõi =või  (SgN  >ülem+või !26_S	et	f	\N
156002	ülemvõi	ülemvõi =või  (SgG  >ülem+või !26_S	et	f	\N
156038	paljastamisega	paljastamisega =paljastamise  (SgKom  >paljastamine !12_S	et	f	\N
156039	paljastamisega	"paljastamine %paljasta  )MINE_vS  <paljastama ;27_V	et	f	\N
156069	saabumisest	saabumisest =saabumise  (SgEl  >saabumine !12_S	et	f	\N
156070	saabumisest	"saabumine %saabu  )MINE_vS  <saabuma ;27_V	et	f	\N
156071	kaotuseni	kaotuseni =kaotuse  (SgTer  >kaotus !11~09_S	et	f	\N
156072	kaotuseni	"kaotus %kaota  )US_vS  <kaotama ;27_V	et	f	\N
156073	kaotuseni	"kaotus %kao  )TUS1_aS  <kaduma ;28_V	et	f	\N
156074	kaotuseni	"kaotus %kao  )TUS2_aS  <kabu ;18_S	et	f	\N
156075	kaotuseni	"kaotus %kao  )TUS2_aS  <kadu ;18_S	et	f	\N
156087	patriarhaarne	?patriarhaarne =patriarhaarne  (SgN  >patriarhaarne !02_A	et	f	\N
156088	patriarhaarne	?patriarhaarne =patriarhaarne  (PlP  >patriarhaarn !22_S	et	f	\N
156092	koristamine	koristamine =koristamine  (SgN  >koristamine !12_S	et	f	\N
156093	koristamine	"koristamine %korista  )MINE_vS  <koristama ;27_V	et	f	\N
156103	väetamist	väetamist =väetamis  (SgP  >väetamine !12_S	et	f	\N
156104	väetamist	"väetamine %väeta  )MINE_vS  <väetama ;27_V	et	f	\N
156128	algusesse	algusesse =alguse  (SgIll  >algus !11~09_S	et	f	\N
156129	algusesse	algusesse =alguses  (SgAdt  >algusene !12_A	et	f	\N
156130	algusesse	"algusene %alguse  )NE_aA  <algus ;09_S	et	f	\N
156132	algusesse	"algusene %alguse  )NE_aA  <algus ;11_S	et	f	\N
156134	algusesse	algusesse =sesse  (PlP  >algu+sess !22_S	et	f	\N
156135	algusesse	algusesse =use  (PlIll  >alg+usk !22_S	et	f	\N
156155	ühiskonnakriitika	ühiskonnakriitika =kriitika  (SgN  >ühis+konna+kriitika !01_S	et	f	\N
156156	ühiskonnakriitika	ühiskonnakriitika =kriitika  (SgG  >ühis+konna+kriitika !01_S	et	f	\N
155841	reisimise	"reisimine %reisi  )MINE_vS  <reisima ;28_V	et	f	\N
155850	oma-moodi	oma-moodi =moodi  (SgP  >oma-mood !22_S	et	f	\N
155851	oma-moodi	oma-moodi =moodi  (SgAdt  >oma-mood !22_S	et	f	\N
155856	teeneid	teeneid =teene  (PlP  >teene !06_S	et	f	\N
155857	teeneid	"teene %tee  )NE_aA  <tee ;26_S	et	f	\N
155858	teeneid	teeneid =neid  (SgN  >tee+neid !22_S	et	f	\N
155862	ilusaloong	?ilusaloong =ilusaloong  (SgN  >ilusaloong !02_S	et	f	\N
155863	ilusaloong	?ilusaloong =saloong  (SgN  >ilu+saloong !22_S	et	f	\N
155871	tarbimine	tarbimine =tarbimine  (SgN  >tarbimine !12_S	et	f	\N
155872	tarbimine	"tarbimine %tarbi  )MINE_vS  <tarbima ;27_V	et	f	\N
155873	alaealised	alaealised =ealise  (PlN  >ala+ealine !12?10_A	et	f	\N
155874	alaealised	"ala+ealine %ea  )LINE_aA  <ala+iga ;18_S	et	f	\N
155897	thailandisse	?thailandisse =thailandi  (SgIll  >thailandi !01_S	et	f	\N
155898	thailandisse	?thailandisse =thailandi  (SgIll  >thailand !02_S	et	f	\N
155899	thailandisse	?thailandisse =thailandi  (SgIll  >thailant !22_S	et	f	\N
155900	thailandisse	?thailandisse =thailandis  (SgAdt  >thailandis !11_S	et	f	\N
155901	thailandisse	?thailandisse =thailandisse  (SgG  >thailandisne !02_A	et	f	\N
155902	thailandisse	?thailandisse =thailandisse  (PlP  >thailandiss !22_S	et	f	\N
155903	allveemaskega	?allveemaskega =maske  (SgKom  >all+vee+maske !01_A	et	f	\N
155906	reziim	?reziim =reziim  (SgN  >reziim !22_S	et	f	\N
155907	paljusus	?paljusus =paljusu  (SgIn  >paljusu !01_S	et	f	\N
155908	paljusus	?paljusus =paljusu  (IndIpfSg3  >paljusuma !27_V	et	f	\N
155909	paljusus	?paljusus =paljusus  (SgN  >paljusus !11_S	et	f	\N
155913	votsialistlik	?votsialistlik =votsialistlik  (SgN  >votsialistlik !25_A	et	f	\N
155927	teelikult	?teelikult =teeliku  (SgAbl  >teeliku !01_S	et	f	\N
155928	teelikult	?teelikult =teeliku  (SgAbl  >teelik !02_S	et	f	\N
155929	teelikult	?teelikult =teelikult  (ID  >teelikult !41_D	et	f	\N
155960	astujaid	astujaid =astuja  (PlP  >astuja !01_S	et	f	\N
155961	astujaid	"astuja %astu  )JA_vS  <astuma ;28_V	et	f	\N
155962	represseriti	?represseriti =represseriti  (ID  >represseriti !41_D	et	f	\N
155963	represseriti	?represseriti =represseriti  (SgG  >represseritt !22_S	et	f	\N
155964	represseriti	?represseriti =represseriti  (IndPrPs_  >represserittima !28_V	et	f	\N
155965	represseriti	?represseriti =represseriti  (ImpPrSg2  >represserittima !28_V	et	f	\N
155972	surumise	surumise =surumise  (SgG  >surumine !12_S	et	f	\N
155973	surumise	"surumine %suru  )MINE_vS  <suruma ;27_V	et	f	\N
155974	tegijaid	tegijaid =tegija  (PlP  >tegija !01_S	et	f	\N
155975	tegijaid	"tegija %tegi  )JA_vS  <tegema ;28_V	et	f	\N
155992	usustunnistuse	?usustunnistuse =usustunnistuse  (SgG  >usustunnistus !11~09_S	et	f	\N
155993	usustunnistuse	?usustunnistuse =stunnistuse  (SgG  >usu+stunnistus !11_S	et	f	\N
155998	konstitutsiooni	konstitutsiooni =konstitutsiooni  (SgG  >konstitutsioon !22_S	et	f	\N
155999	konstitutsiooni	konstitutsiooni =konstitutsiooni  (SgP  >konstitutsioon !22_S	et	f	\N
156000	konstitutsiooni	konstitutsiooni =konstitutsiooni  (SgAdt  >konstitutsioon !22_S	et	f	\N
156008	pätsi	pätsi =pätsi  (SgG  >päts !22_S	et	f	\N
156009	pätsi	pätsi =pätsi  (SgP  >päts !22_S	et	f	\N
156010	pätsi	pätsi =pätsi  (SgAdt  >päts !22_S	et	f	\N
156011	pätsi	pätsi =pätsi  (IndPrPs_  >pätsima !28_V	et	f	\N
156012	pätsi	pätsi =pätsi  (ImpPrSg2  >pätsima !28_V	et	f	\N
156013	vahemusrahvaste	?vahemusrahvaste =vahemusrahvas  (PlG  >vahemusrahvane !12_A	et	f	\N
156014	vahemusrahvaste	?vahemusrahvaste =musrahvas  (PlG  >vahe+musrahvane !12_A	et	f	\N
156019	algharidust	algharidust =dust  (SgN  >alg+hari+dust !22_S	et	f	\N
156020	algharidust	algharidust =haridus  (SgP  >alg+haridus !11_S	et	f	\N
156040	rehabiliteerimist	rehabiliteerimist =rehabiliteerimis  (SgP  >rehabiliteerimine !12_S	et	f	\N
156041	rehabiliteerimist	"rehabiliteerimine %rehabiliteeri  )MINE_vS  <rehabiliteerima ;28_V	et	f	\N
156048	tugevnesid	tugevnesid =tugevne  (IndIpfSg2  >tugevnema !27_V	et	f	\N
156049	tugevnesid	tugevnesid =tugevne  (IndIpfPl3  >tugevnema !27_V	et	f	\N
156062	lääneliku	?lääneliku =lääneliku  (SgG  >läänelik !25_A	et	f	\N
156063	lääneliku	?lääneliku =lääneliku  (IndPrPs_  >läänelikuma !27_V	et	f	\N
156064	lääneliku	?lääneliku =lääneliku  (ImpPrSg2  >läänelikuma !27_V	et	f	\N
156079	künnipõlendus	?künnipõlendus =künnipõlendu  (IndIpfSg3  >künnipõlenduma !27_V	et	f	\N
156080	künnipõlendus	?künnipõlendus =künnipõlendus  (SgN  >künnipõlendus !11_S	et	f	\N
156082	künnipõlendus	?künnipõlendus =põlendu  (SgIn  >künni+põlendu !01_S	et	f	\N
156084	künnipõlendus	?künnipõlendus =põlendus  (SgN  >künni+põlendus !11_S	et	f	\N
156105	maaveljelus	?maaveljelus =maaveljelu  (SgIn  >maaveljelu !17_S	et	f	\N
156106	maaveljelus	?maaveljelus =maaveljelu  (IndIpfSg3  >maaveljeluma !27_V	et	f	\N
156107	maaveljelus	?maaveljelus =maaveljelus  (SgN  >maaveljelus !11?09_S	et	f	\N
156109	maaveljelus	?maaveljelus =veljelu  (SgIn  >maa+veljelu !17_S	et	f	\N
156110	maaveljelus	?maaveljelus =veljelus  (SgN  >maa+veljelus !11_S	et	f	\N
156120	hobused	hobused =hobuse  (PlN  >hobune !10_S	et	f	\N
156121	hobused	"hobune %hobu  )NE_aA  <hobu ;17_S	et	f	\N
156131	kuuluva	kuuluva =kuuluva  (SgG  >kuuluv !02_A	et	f	\N
156133	kuuluva	"kuuluv %kuulu  )V_vA  <kuuluma ;27_V	et	f	\N
156143	elulisel	elulisel =elulise  (SgAd  >eluline !12_A	et	f	\N
155853	soobivat	?soobivat =soobiva  (SgP  >soobiva !01_S	et	f	\N
155854	soobivat	?soobivat =soobiva  (SgP  >soobiv !02_A	et	f	\N
155855	soobivat	?soobivat =bivat  (SgN  >soo+bivat !02_S	et	f	\N
155859	juukselõikla	juukselõikla =lõikla  (SgN  >juukse+lõikla !01_S	et	f	\N
155860	juukselõikla	juukselõikla =lõikla  (SgG  >juukse+lõikla !01_S	et	f	\N
155866	mängunurka	mängunurka =nurka  (SgP  >mängu+nurk !22_S	et	f	\N
155867	mängunurka	mängunurka =nurka  (SgAdt  >mängu+nurk !22_S	et	f	\N
155868	saadaval	saadaval =saadava  (SgAd  >saadav !02_A	et	f	\N
155869	saadaval	"saadav %saa  )TAV_vAS  <saama ;37_V	et	f	\N
155870	saadaval	saadaval =saadaval  (ID  >saadaval !41_D	et	f	\N
155878	täisealisena	täisealisena =ealise  (SgEs  >täis+ealine !12?10_A	et	f	\N
155879	täisealisena	"täis+ealine %ea  )LINE_aA  <täis+iga ;18_S	et	f	\N
155880	täisealisena	täisealisena =sealise  (SgEs  >täi+sealine !12?10_A	et	f	\N
155881	täisealisena	"täi+sealine %sea  )LINE_aA  <täi+siga ;18_SA	et	f	\N
155884	alaealisel	alaealisel =ealise  (SgAd  >ala+ealine !12?10_A	et	f	\N
155885	alaealisel	"ala+ealine %ea  )LINE_aA  <ala+iga ;18_S	et	f	\N
155892	muretut	muretut =muretu  (SgP  >muretu !01_A	et	f	\N
155893	muretut	"muretu %mure  )TU2_kA  <mure ;16_S	et	f	\N
155925	võrdsetes	võrdsetes =võrdse  (PlIn  >võrdne !02_A	et	f	\N
155926	võrdsetes	võrdsetes =sete  (PlIn  >võrd+sett !22_S	et	f	\N
155939	pooleks	pooleks =poole  (SgTr  >pool !13_NS	et	f	\N
155940	pooleks	pooleks =poole  (PlTr  >pool !22_S	et	f	\N
155941	pooleks	pooleks =pooleks  (ID  >pooleks !41_D	et	f	\N
155946	siinsete	siinsete =siinse  (PlG  >siinne !02_A	et	f	\N
155947	siinsete	siinsete =sete  (SgN  >siin+sete !06_S	et	f	\N
155953	vähegi	vähegi =vähegi  (ID  >vähegi !41_D	et	f	\N
155954	vähegi	vähegi =vähe  (ID^  >vähe !41_D	et	f	\N
155968	rehva	?rehva =rehva  (SgN  >rehva !16_S	et	f	\N
155969	rehva	?rehva =rehva  (SgG  >rehva !16_S	et	f	\N
155970	rehva	?rehva =rehva  (IndPrPs_  >rehvama !29_V	et	f	\N
155971	rehva	?rehva =rehva  (ImpPrSg2  >rehvama !29_V	et	f	\N
155981	korraldus	korraldus =korraldu  (IndIpfSg3  >korralduma !27_V	et	f	\N
155982	korraldus	korraldus =korraldus  (SgN  >korraldus !11_S	et	f	\N
155983	korraldus	"korraldus %korralda  )US_vS  <korraldama ;27_V	et	f	\N
155984	alustel	alustel =alus  (PlAd  >alus !09_S	et	f	\N
155985	alustel	alustel =alus  (PlAd  >alune !10_AS	et	f	\N
155986	alustel	"alune %alu  )NE_aA  <alg ;22_S	et	f	\N
155989	valitsev	valitsev =valitse  (PtsPrPs  >valitsema !27_V	et	f	\N
155990	valitsev	valitsev =valitsev  (SgN  >valitsev !02_A	et	f	\N
155991	valitsev	"valitsev %valitse  )V_vA  <valitsema ;27_V	et	f	\N
156050	suurenesid	suurenesid =suurene  (IndIpfSg2  >suurenema !27_V	et	f	\N
156051	suurenesid	suurenesid =suurene  (IndIpfPl3  >suurenema !27_V	et	f	\N
156052	suurenesid	suurenesid =rene  (PlP  >suu+rene !16_S	et	f	\N
156053	suurenesid	"suu+rene %re  )NE_aA  <suu+re ;26_S	et	f	\N
156056	margarita	?margarita =margari  (SgAb  >margari !01_S	et	f	\N
156057	margarita	?margarita =margari  (SgAb  >margar !02_S	et	f	\N
156058	margarita	?margarita =margarita  (IndPrPs_  >margaritama !27_V	et	f	\N
156059	margarita	?margarita =margarita  (ImpPrSg2  >margaritama !27_V	et	f	\N
156060	margarita	?margarita =rita  (SgN  >marga+rita !16_S	et	f	\N
156061	margarita	?margarita =rita  (SgG  >marga+rita !16_S	et	f	\N
156065	kuulamise	kuulamise =kuulamise  (SgG  >kuulamine !12_S	et	f	\N
156066	kuulamise	"kuulamine %kuula  )MINE_vS  <kuulama ;29_V	et	f	\N
156076	annastavalt	?annastavalt =annastava  (SgAbl  >annastav !02_A	et	f	\N
156077	annastavalt	?annastavalt =annastava  (SgAbl  >annastava !16_S	et	f	\N
156078	annastavalt	?annastavalt =annastavalt  (ID  >annastavalt !41_D	et	f	\N
156081	alepõlendus	?alepõlendus =alepõlendu  (IndIpfSg3  >alepõlenduma !27_V	et	f	\N
156083	alepõlendus	?alepõlendus =alepõlendus  (SgN  >alepõlendus !11_S	et	f	\N
156085	alepõlendus	?alepõlendus =põlendu  (SgIn  >ale+põlendu !01_S	et	f	\N
156086	alepõlendus	?alepõlendus =põlendus  (SgN  >ale+põlendus !11_S	et	f	\N
156096	viimistletud	viimistletud =viimistle  (PtsPtIps  >viimistlema !27_V	et	f	\N
156097	viimistletud	viimistletud =viimistletu  (PlN  >viimistletu !01_S	et	f	\N
156098	viimistletud	"viimistletu %viimistle  )TU1_vS  <viimistlema ;27_V	et	f	\N
156099	viimistletud	viimistletud =viimistletud  (ID  >viimistletud !41_A	et	f	\N
156100	viimistletud	"viimistletud %viimistle  )TUD_vA  <viimistlema ;27_V	et	f	\N
156101	siinsetel	siinsetel =siinse  (PlAd  >siinne !02_A	et	f	\N
156102	siinsetel	siinsetel =sete  (PlAd  >siin+sett !22_S	et	f	\N
156108	matmiskommetest	matmiskommetest =me  (PlEl  >matmis+kom+mesi !15_S	et	f	\N
156111	matmiskommetest	matmiskommetest =mete  (PlEl  >matmis+kom+mett !22_S	et	f	\N
156112	matmiskommetest	matmiskommetest =komme  (PlEl  >matmis+komme !06_S	et	f	\N
156116	sulata	sulata =sula  (SgAb  >sula !17_AS	et	f	\N
156117	sulata	sulata =sula  (IndPrIps_  >sulama !27_V	et	f	\N
156118	sulata	sulata =sulata  (IndPrPs_  >sulatama !27_V	et	f	\N
156119	sulata	sulata =sulata  (ImpPrSg2  >sulatama !27_V	et	f	\N
156136	inimkonnale	inimkonnale =inimkonna  (SgAll  >inimkond !22_S	et	f	\N
156137	inimkonnale	inimkonnale =konna  (SgAll  >inim+konn !22_S	et	f	\N
155890	tähtpäevi	tähtpäevi =päevi  (SgAdt  >täht+päev !22_S	et	f	\N
155891	tähtpäevi	tähtpäevi =päevi  (PlP  >täht+päev !22_S	et	f	\N
155910	koondus	koondus =koondu  (IndIpfSg3  >koonduma !27_V	et	f	\N
155911	koondus	koondus =koondus  (SgN  >koondus !11~09_S	et	f	\N
155912	koondus	"koondus %koonda  )US_vS  <koondama ;27_V	et	f	\N
155917	väärtust	väärtust =väärtus  (SgP  >väärtus !11~09_S	et	f	\N
155918	väärtust	väärtust =us  (SgP  >väärt+uks !14_S	et	f	\N
155919	väärtust	väärtust =tust  (SgN  >väär+tust !22_S	et	f	\N
155920	nomenklatuuri	nomenklatuuri =nomenklatuuri  (SgG  >nomenklatuur !22_S	et	f	\N
155921	nomenklatuuri	nomenklatuuri =nomenklatuuri  (SgP  >nomenklatuur !22_S	et	f	\N
155922	nomenklatuuri	nomenklatuuri =nomenklatuuri  (SgAdt  >nomenklatuur !22_S	et	f	\N
155923	kommunistlikku	kommunistlikku =kommunistlikku  (SgP  >kommunistlik !25_A	et	f	\N
155924	kommunistlikku	kommunistlikku =kommunistlikku  (SgAdt  >kommunistlik !25_A	et	f	\N
155930	jätkus	jätkus =jätku  (SgIn  >jätk !22_S	et	f	\N
155931	jätkus	jätkus =jätku  (IndIpfSg3  >jätkuma !27_V	et	f	\N
155932	pakutavaid	pakutavaid =pakutava  (PlP  >pakutav !02_A	et	f	\N
155933	pakutavaid	"pakutav %paku  )TAV_vAS  <pakkuma ;28_V	et	f	\N
155934	pakutavaid	"pakutav %pakuta  )V_vA  <pakutama ;27_V	et	f	\N
155942	sohvooside	?sohvooside =sohvoosi  (PlG  >sohvoosi !16_S	et	f	\N
155943	sohvooside	?sohvooside =sohvoosi  (PlG  >sohvoos !22_S	et	f	\N
155950	miinimumi	miinimumi =miinimumi  (SgG  >miinimum !19_S	et	f	\N
155951	miinimumi	miinimumi =miinimumi  (SgP  >miinimum !19_S	et	f	\N
155952	miinimumi	miinimumi =miinimumi  (SgAdt  >miinimum !19_S	et	f	\N
155966	korralduses	korralduses =korralduse  (SgIn  >korraldus !11_S	et	f	\N
155967	korralduses	"korraldus %korralda  )US_vS  <korraldama ;27_V	et	f	\N
155979	teretulnud	teretulnud =tulnu  (PlN  >tere+tulnu !01_S	et	f	\N
155980	teretulnud	teretulnud =tulnu  (PlN  >tere+tulnu !06_S	et	f	\N
156005	autritoorse	?autritoorse =autritoorse  (SgG  >autritoorne !02_A	et	f	\N
156006	autritoorse	?autritoorse =autritoorse  (PlP  >autritoors !22_S	et	f	\N
156007	autritoorse	?autritoorse =tritoorse  (SgG  >au+tritoorne !02_A	et	f	\N
156017	vahemusrahvastel	?vahemusrahvastel =vahemusrahvas  (PlAd  >vahemusrahvane !12_A	et	f	\N
156018	vahemusrahvastel	?vahemusrahvastel =musrahvas  (PlAd  >vahe+musrahvane !12_A	et	f	\N
156028	surud	surud =suru  (PlN  >suru !17_S	et	f	\N
156029	surud	surud =suru  (IndPrSg2  >suruma !27_V	et	f	\N
156034	kultuuriloos	kultuuriloos =loo  (SgIn  >kultuuri+lugu !18_S	et	f	\N
156035	kultuuriloos	kultuuriloos =loo  (SgIn  >kultuuri+loog !22_S	et	f	\N
156036	kultuuriloos	kultuuriloos =loo  (SgIn  >kultuuri+lood !22_S	et	f	\N
156037	kultuuriloos	kultuuriloos =loos  (SgN  >kultuuri+loos !22_S	et	f	\N
156067	ajajärku	ajajärku =järku  (SgP  >aja+järk !22_S	et	f	\N
156068	ajajärku	ajajärku =järku  (SgAdt  >aja+järk !22_S	et	f	\N
156089	tegevusega	tegevusega =tegevuse  (SgKom  >tegevus !11_S	et	f	\N
156090	tegevusega	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
156091	tegevusega	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
156094	tehtudpronksist	?tehtudpronksist =tehtudpronksis  (SgP  >tehtudpronksis !09_S	et	f	\N
156095	tehtudpronksist	?tehtudpronksist =tehtudpronksist  (SgN  >tehtudpronksist !22_S	et	f	\N
156113	6saj	### 6saj	et	f	\N
156125	rauast	rauast =raua  (SgEl  >raud !22_S	et	f	\N
156126	rauast	rauast =rauas  (SgP  >rauane !10_A	et	f	\N
156127	rauast	"rauane %raua  )NE_aA  <raud ;22_S	et	f	\N
156151	laiuse	laiuse =laiuse  (SgG  >laius !11~09_S	et	f	\N
156152	laiuse	"laius %lai  )US_aS  <lai ;22_A	et	f	\N
156153	laiuse	laiuse =laiuse  (SgG  >laiune !10~12_A	et	f	\N
156154	laiuse	"laiune %laiu  )NE_aA  <laid ;22_S	et	f	\N
156166	pärast-proosa	pärast-proosa =proosa  (SgN  >pärast-proosa !16_S	et	f	\N
156167	pärast-proosa	pärast-proosa =proosa  (SgG  >pärast-proosa !16_S	et	f	\N
156171	tihenesid	tihenesid =tihene  (IndIpfSg2  >tihenema !27_V	et	f	\N
156172	tihenesid	tihenesid =tihene  (IndIpfPl3  >tihenema !27_V	et	f	\N
156200	seans	?seans =seans  (SgN  >seans !02_S	et	f	\N
156211	kahekümme	?kahekümme =kahekümme  (PlP  >kahekümm !22_S	et	f	\N
156212	kahekümme	?kahekümme =kümme  (PlP  >kahe+kümm !22_S	et	f	\N
156244	kolmeteistkümne	?kolmeteistkümne =kolmeteistkümne  (SgN  >kolmeteistkümne !02_A	et	f	\N
156245	kolmeteistkümne	?kolmeteistkümne =kolmeteistkümne  (PlP  >kolmeteistkümn !22_S	et	f	\N
156246	kolmeteistkümne	?kolmeteistkümne =kümne  (SgN  >kolme+teist+kümne !02_A	et	f	\N
156247	kolmeteistkümne	?kolmeteistkümne =kümne  (PlP  >kolme+teist+kümn !22_S	et	f	\N
156248	kolmeteistkümne	?kolmeteistkümne =teistkümne  (SgN  >kolme+teistkümne !02_A	et	f	\N
156249	kolmeteistkümne	?kolmeteistkümne =teistkümne  (PlP  >kolme+teistkümn !22_S	et	f	\N
156250	kolmeteistkümne	?kolmeteistkümne =eteistkümne  (SgN  >kolm+eteistkümne !02_A	et	f	\N
156251	kolmeteistkümne	?kolmeteistkümne =eteistkümne  (PlP  >kolm+eteistkümn !22_S	et	f	\N
156253	viie-kümne	viie-kümne =kümne  (SgG  >viie-kümmend !05_N	et	f	\N
156255	viie-kümne	viie-kümne =kümne  (SgG  >viie-kümme !05_N	et	f	\N
156283	polteist	?polteist =polte  (PlEl  >polde !06_S	et	f	\N
156284	polteist	?polteist =poltei  (SgEl  >poltei !26_S	et	f	\N
156285	polteist	?polteist =polteist  (SgN  >polteist !22_S	et	f	\N
155916	omandisk	?omandisk =omandisk  (SgN  >omandisk !22_S	et	f	\N
155935	vaevaga	vaevaga =vaeva  (SgKom  >vaev !22_S	et	f	\N
155936	vaevaga	vaevaga =vaga  (SgN  >vae+vaga !17_A	et	f	\N
155937	vaevaga	vaevaga =vaga  (SgG  >vae+vaga !17_A	et	f	\N
155938	vaevaga	vaevaga =vaga  (SgP  >vae+vaga !17_A	et	f	\N
155955	tahetud	tahetud =tahe  (PtsPtIps  >tahtma !34_V	et	f	\N
155956	tahetud	tahetud =tahetu  (PlN  >tahetu !01_S	et	f	\N
155957	tahetud	"tahetu %tahe  )TU1_vS  <tahtma ;34_V	et	f	\N
155958	tahetud	tahetud =tahetud  (ID  >tahetud !41_A	et	f	\N
155959	tahetud	"tahetud %tahe  )TUD_vA  <tahtma ;34_V	et	f	\N
155987	tööstust	tööstust =tööstus  (SgP  >tööstus !11~09_S	et	f	\N
155988	tööstust	tööstust =tust  (SgN  >töös+tust !22_S	et	f	\N
155996	võimukandja	võimukandja =kandja  (SgN  >võimu+kandja !01_S	et	f	\N
155997	võimukandja	võimukandja =kandja  (SgG  >võimu+kandja !01_S	et	f	\N
156003	asjaajamiskeeleks	asjaajamiskeeleks =keele  (SgTr  >asja+aja+mis+keel !13_S	et	f	\N
156004	asjaajamiskeeleks	asjaajamiskeeleks =keele  (PlTr  >asja+aja+mis+keeld !22_S	et	f	\N
156015	kultuuriautonoomia	kultuuriautonoomia =autonoomia  (SgN  >kultuuri+autonoomia !01_S	et	f	\N
156016	kultuuriautonoomia	kultuuriautonoomia =autonoomia  (SgG  >kultuuri+autonoomia !01_S	et	f	\N
156021	sekkunud	sekkunud =sekku  (PtsPtPs  >sekkuma !27_V	et	f	\N
156022	sekkunud	sekkunud =sekkunu  (PlN  >sekkunu !01_S	et	f	\N
156023	sekkunud	"sekkunu %sekku  )NU_vS  <sekkuma ;27_V	et	f	\N
156024	sekkunud	sekkunud =sekkunud  (ID  >sekkunud !41_A	et	f	\N
156025	sekkunud	"sekkunud %sekku  )NUD_vA  <sekkuma ;27_V	et	f	\N
156026	täiendamiseks	täiendamiseks =täiendamise  (SgTr  >täiendamine !12_S	et	f	\N
156027	täiendamiseks	"täiendamine %täienda  )MINE_vS  <täiendama ;27_V	et	f	\N
156030	ideoloogilist	ideoloogilist =ideoloogilis  (SgP  >ideoloogiline !12_A	et	f	\N
156031	ideoloogilist	"ideoloogiline %ideoloogi  )LINE_aA  <ideoloog ;22_S	et	f	\N
156032	ideoloogilist	ideoloogilist =loogilis  (SgP  >ideo+loogiline !12_A	et	f	\N
156033	ideoloogilist	"ideo+loogiline %loogi  )LINE_aA  <ideo+loog ;22_S	et	f	\N
156042	kulu	kulu =kulu  (SgN  >kulu !17_S	et	f	\N
156043	kulu	kulu =kulu  (SgG  >kulu !17_S	et	f	\N
156044	kulu	kulu =kulu  (SgG  >kulg !22_S	et	f	\N
156045	kulu	kulu =kulu  (SgP  >kulu !17_S	et	f	\N
156046	kulu	kulu =kulu  (IndPrPs_  >kuluma !27_V	et	f	\N
156047	kulu	kulu =kulu  (ImpPrSg2  >kuluma !27_V	et	f	\N
156054	bulkakovi	?bulkakovi =bulkakovi  (ID  >bulkakovi !41_D	et	f	\N
156055	bulkakovi	?bulkakovi =bulkakovi  (SgG  >bulkakov !02_A	et	f	\N
156114	soomaagist	soomaagist =maagi  (SgEl  >soo+maag !22_S	et	f	\N
156115	soomaagist	soomaagist =maagi  (SgEl  >soo+maak !22_S	et	f	\N
156122	söömisest	söömisest =söömise  (SgEl  >söömine !12?10_S	et	f	\N
156123	söömisest	"söömine %söö  )MINE_vS  <sööma ;38_V	et	f	\N
156124	söömisest	"söömine %söömi  )NE_aA  <sööm ;22_S	et	f	\N
156145	animalistlik	?animalistlik =animalistlik  (SgN  >animalistlik !25_A	et	f	\N
156146	animalistlik	?animalistlik =listlik  (SgN  >anima+listlik !25_A	et	f	\N
156147	majanduslikud-kultuurilised	majanduslikud-kultuurilised =kultuurilise  (PlN  >majanduslikud-kultuuriline !12_A	et	f	\N
156148	majanduslikud-kultuurilised	"majanduslikud-kultuuriline %kultuuri  )LINE_aA  <majanduslikud-kultuur ;22_S	et	f	\N
156159	õitsesid	õitsesid =õitse  (IndIpfSg2  >õitsma !32_V	et	f	\N
156160	õitsesid	õitsesid =õitse  (IndIpfPl3  >õitsma !32_V	et	f	\N
156161	õitsesid	õitsesid =õitse  (IndIpfSg2  >õitsema !28_V	et	f	\N
156163	õitsesid	õitsesid =õitse  (IndIpfPl3  >õitsema !28_V	et	f	\N
156165	multufilmidega	?multufilmidega =multufilmi  (PlKom  >multufilm !22_S	et	f	\N
156173	dzässi	?dzässi =dzässi  (SgN  >dzässi !16_S	et	f	\N
156174	dzässi	?dzässi =dzässi  (SgG  >dzässi !16_S	et	f	\N
156175	dzässi	?dzässi =dzässi  (SgG  >dzäss !22_S	et	f	\N
156176	dzässi	?dzässi =dzässi  (SgP  >dzäss !22_S	et	f	\N
156178	dzässi	?dzässi =dzässi  (SgAdt  >dzäss !22_S	et	f	\N
156179	dzässi	?dzässi =dzässi  (IndPrPs_  >dzässima !28_V	et	f	\N
156180	dzässi	?dzässi =dzässi  (ImpPrSg2  >dzässima !28_V	et	f	\N
156188	eestimuusika	eestimuusika =muusika  (SgN  >eesti+muusika !01_S	et	f	\N
156189	eestimuusika	eestimuusika =muusika  (SgG  >eesti+muusika !01_S	et	f	\N
156205	helistasid	helistasid =helista  (IndIpfSg2  >helistama !27_V	et	f	\N
156206	helistasid	helistasid =helista  (IndIpfPl3  >helistama !27_V	et	f	\N
156215	verand	?verand =verand  (SgN  >verand !02_S	et	f	\N
156223	stocmanisse	?stocmanisse =stocmani  (SgIll  >stocman !02_S	et	f	\N
156225	stocmanisse	?stocmanisse =stocmanis  (SgAdt  >stocmanis !11_S	et	f	\N
156227	stocmanisse	?stocmanisse =stocmanisse  (SgG  >stocmanisne !02_A	et	f	\N
156228	stocmanisse	?stocmanisse =stocmanisse  (PlP  >stocmaniss !22_S	et	f	\N
156238	kaheteistkümne	?kaheteistkümne =kaheteistkümne  (SgN  >kaheteistkümne !02_A	et	f	\N
156239	kaheteistkümne	?kaheteistkümne =kaheteistkümne  (PlP  >kaheteistkümn !22_S	et	f	\N
156240	kaheteistkümne	?kaheteistkümne =kümne  (SgN  >kahe+teist+kümne !02_A	et	f	\N
156241	kaheteistkümne	?kaheteistkümne =kümne  (PlP  >kahe+teist+kümn !22_S	et	f	\N
156242	kaheteistkümne	?kaheteistkümne =teistkümne  (SgN  >kahe+teistkümne !02_A	et	f	\N
156243	kaheteistkümne	?kaheteistkümne =teistkümne  (PlP  >kahe+teistkümn !22_S	et	f	\N
156138	lüli	lüli =lüli  (SgN  >lüli !17_S	et	f	\N
156139	lüli	lüli =lüli  (SgG  >lüli !17_S	et	f	\N
156140	lüli	lüli =lüli  (SgP  >lüli !17_S	et	f	\N
156141	lüli	lüli =lüli  (IndPrPs_  >lülima !27_V	et	f	\N
156142	lüli	lüli =lüli  (ImpPrSg2  >lülima !27_V	et	f	\N
156186	välismuusika	välismuusika =muusika  (SgN  >välis+muusika !01_S	et	f	\N
156187	välismuusika	välismuusika =muusika  (SgG  >välis+muusika !01_S	et	f	\N
156191	bsej	### bsej	et	f	\N
156256	kooselek	?kooselek =elek  (SgN  >koos+elek !02_S	et	f	\N
156257	üheksateistkümneks	?üheksateistkümneks =üheksateistkümne  (PlTr  >üheksateistkümn !22_S	et	f	\N
156258	üheksateistkümneks	?üheksateistkümneks =kümne  (PlTr  >üheksa+teist+kümn !22_S	et	f	\N
156259	üheksateistkümneks	?üheksateistkümneks =teistkümne  (PlTr  >üheksa+teistkümn !22_S	et	f	\N
156260	üheksateistkümneks	?üheksateistkümneks =ateistkümne  (PlTr  >üheks+ateistkümn !22_S	et	f	\N
156261	üheksateistkümneks	?üheksateistkümneks =ksateistkümne  (PlTr  >ühe+ksateistkümn !22_S	et	f	\N
156270	killer	?killer =killer  (SgN  >killer !02_S	et	f	\N
156329	kättesaid	?kättesaid =kättesa  (PlP  >kättesa !01_S	et	f	\N
156330	kättesaid	?kättesaid =kättesai  (PlN  >kättesai !26_S	et	f	\N
156331	kättesaid	?kättesaid =kättesai  (SgP  >kättesai !26_S	et	f	\N
156332	kättesaid	?kättesaid =said  (SgN  >kätte+said !22_S	et	f	\N
156333	kättesaid	?kättesaid =esai  (PlN  >kätt+esai !26_S	et	f	\N
156334	kättesaid	?kättesaid =esai  (SgP  >kätt+esai !26_S	et	f	\N
156335	kättesaid	?kättesaid =esaid  (SgN  >kätt+esaid !22_S	et	f	\N
156339	külalisena	külalisena =külalise  (SgEs  >külaline !12_S	et	f	\N
156340	külalisena	"külaline %küla  )LINE_aA  <küla ;17_S	et	f	\N
156355	olevast	olevast =oleva  (SgEl  >olev !02_A	et	f	\N
156356	olevast	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
156357	tüürimees	tüürimees =mee  (SgIn  >tüüri+mesi !15_S	et	f	\N
156358	tüürimees	tüürimees =mees  (SgN  >tüüri+mees !13_S	et	f	\N
156359	juhtimiseks	juhtimiseks =juhtimise  (SgTr  >juhtimine !12_S	et	f	\N
156360	juhtimiseks	"juhtimine %juhti  )MINE_vS  <juhtima ;28_V	et	f	\N
156383	silmapilguks	silmapilguks =pilgu  (SgTr  >silma+pilk !22_S	et	f	\N
156384	silmapilguks	silmapilguks =pilgu  (PlTr  >silma+pilk !22_S	et	f	\N
156389	korrapärases	korrapärases =pärase  (SgIn  >korra+pärane !10_A	et	f	\N
156391	korrapärases	"korra+pärane %pära  )NE_aA  <korra+pära ;17_S	et	f	\N
156393	mitukümmend	?mitukümmend =mitukümmend  (SgN  >mitukümmend !22_S	et	f	\N
156397	ülesvedada	### ülesvedada	et	f	\N
156407	püdsid	?püdsid =püdsi  (PlN  >püdsi !16_S	et	f	\N
156408	püdsid	?püdsid =püdsi  (PlN  >püds !22_S	et	f	\N
156409	püdsid	?püdsid =püdsi  (IndPrSg2  >püdsima !28_V	et	f	\N
156424	kirjelda	kirjelda =kirjelda  (IndPrPs_  >kirjeldama !27_V	et	f	\N
156425	kirjelda	kirjelda =kirjelda  (ImpPrSg2  >kirjeldama !27_V	et	f	\N
156426	seenemaja	seenemaja =maja  (SgN  >seene+maja !17_S	et	f	\N
156427	seenemaja	seenemaja =maja  (SgG  >seene+maja !17_S	et	f	\N
156428	seenemaja	seenemaja =maja  (SgP  >seene+maja !17_S	et	f	\N
156429	kukusit	### kukusit	et	f	\N
156449	sõidanut	?sõidanut =sõidanu  (SgP  >sõidanu !01_S	et	f	\N
156461	seksioonkapis	?seksioonkapis =seksioonkapi  (SgIn  >seksioonkapp !22_S	et	f	\N
156462	seksioonkapis	?seksioonkapis =seksioonkapis  (SgN  >seksioonkapis !09_S	et	f	\N
156463	seksioonkapis	?seksioonkapis =oonkapi  (SgIn  >seksi+oonkapi !01_S	et	f	\N
156464	seksioonkapis	?seksioonkapis =oonkapi  (SgIn  >seksi+oonkap !02_S	et	f	\N
156465	seksioonkapis	?seksioonkapis =oonkapi  (SgIn  >seksi+oonkapp !22_S	et	f	\N
156466	seksioonkapis	?seksioonkapis =oonkapis  (SgN  >seksi+oonkapis !11_S	et	f	\N
156467	seksioonkapis	?seksioonkapis =ioonkapi  (SgIn  >seks+ioonkapp !22_S	et	f	\N
156468	seksioonkapis	?seksioonkapis =ioonkapis  (SgN  >seks+ioonkapis !09_S	et	f	\N
156471	jures	?jures =jure  (SgIn  >jure !16_S	et	f	\N
156472	jures	?jures =jure  (IndIpfSg3  >jurema !27_V	et	f	\N
156473	jures	?jures =jures  (SgN  >jures !09_S	et	f	\N
156479	xx-al	### xx-al	et	f	\N
156480	kiievis	?kiievis =kiievi  (SgIn  >kiiev !02_S	et	f	\N
156481	kiievis	?kiievis =kiievi  (IndIpfSg3  >kiievima !28_V	et	f	\N
156482	kiievis	?kiievis =kiievis  (SgN  >kiievis !09_S	et	f	\N
156487	olis	?olis =oli  (SgIn  >oli !17_S	et	f	\N
156488	olis	?olis =oli  (IndIpfSg3  >olima !27_V	et	f	\N
156489	olis	?olis =olis  (SgN  >olis !09_S	et	f	\N
156499	ramatukapi	?ramatukapi =ramatukapi  (SgG  >ramatukapp !22_S	et	f	\N
156500	ramatukapi	?ramatukapi =ramatukapi  (IndPrPs_  >ramatukappima !28_V	et	f	\N
156501	ramatukapi	?ramatukapi =ramatukapi  (ImpPrSg2  >ramatukappima !28_V	et	f	\N
156508	sektsioonikapis	?sektsioonikapis =sektsioonikapi  (SgIn  >sektsioonikapp !22_S	et	f	\N
156509	sektsioonikapis	?sektsioonikapis =sektsioonikapis  (SgN  >sektsioonikapis !09_S	et	f	\N
156514	valdis	?valdis =valdi  (SgIn  >valt !22_S	et	f	\N
156515	valdis	?valdis =valdi  (IndIpfSg3  >valdima !28_V	et	f	\N
156516	valdis	?valdis =valdis  (SgN  >valdis !09_S	et	f	\N
156523	metrid	?metrid =metri  (PlN  >metter !02_S	et	f	\N
156528	tervitus	tervitus =tervitus  (SgN  >tervitus !11_S	et	f	\N
156529	tervitus	"tervitus %tervita  )US_vS  <tervitama ;27_V	et	f	\N
156144	elulisel	"eluline %elu  )LINE_aA  <elu ;17_S	et	f	\N
156149	1970ndatel	?ndatel =ndate  (PlAd  >ndatt !22_S	et	f	\N
156150	1970ndatel	?ndatel =ndatel  (SgN  >ndatel !02_S	et	f	\N
156157	1970-ndatel	?-ndatel =ndate  (PlAd  >-ndatt !22_S	et	f	\N
156158	1970-ndatel	?-ndatel =ndatel  (SgN  >-ndatel !02_S	et	f	\N
156162	multufilmid	?multufilmid =multufilmi  (PlN  >multufilm !22_S	et	f	\N
156164	multufilmid	?multufilmid =multufilmi  (IndPrSg2  >multufilmima !28_V	et	f	\N
156168	väliseestlaste	väliseestlaste =las  (PlG  >väli+seest+laps !14_S	et	f	\N
156169	väliseestlaste	väliseestlaste =laste  (PlP  >väli+seest+last !22_S	et	f	\N
156170	väliseestlaste	väliseestlaste =eestlas  (PlG  >välis+eestlane !12?10_S	et	f	\N
156182	baletti	?baletti =baletti  (SgN  >baletti !01_S	et	f	\N
156183	baletti	?baletti =baletti  (SgG  >baletti !01_S	et	f	\N
156184	baletti	?baletti =baletti  (SgP  >balett !22_S	et	f	\N
156185	baletti	?baletti =baletti  (SgAdt  >balett !22_S	et	f	\N
156198	võrdsust	võrdsust =võrdsus  (SgP  >võrdsus !11~09_S	et	f	\N
156199	võrdsust	"võrdsus %võrdse  )US_aS  <võrdne ;02_A	et	f	\N
156207	kuuest	kuuest =kuue  (SgEl  >kuus !14_N	et	f	\N
156208	kuuest	kuuest =kuue  (SgEl  >kuub !22_S	et	f	\N
156209	kuuest	kuuest =kuues  (SgP  >kuuene !10_A	et	f	\N
156210	kuuest	"kuuene %kuue  )NE_aA  <kuus ;14_N	et	f	\N
156213	kellaks	kellaks =kella  (SgTr  >kell !22_S	et	f	\N
156214	kellaks	kellaks =kella  (KndPrPs  >kellama !29_V	et	f	\N
156216	kümnest	kümnest =kümne  (SgEl  >kümmend !05_N	et	f	\N
156217	kümnest	kümnest =kümne  (SgEl  >kümme !05_N	et	f	\N
156218	kümnest	kümnest =kümnes  (SgP  >kümnene !10~12_AS	et	f	\N
156219	kümnest	"kümnene %kümne  )NE_aA  <kümme ;05_N	et	f	\N
156230	kümneni	kümneni =kümne  (SgTer  >kümmend !05_N	et	f	\N
156231	kümneni	kümneni =kümne  (SgTer  >kümme !05_N	et	f	\N
156264	kümne-viieteistkümne	?kümne-viieteistkümne =viieteistkümne  (SgN  >kümne-viieteistkümne !02_A	et	f	\N
156265	kümne-viieteistkümne	?kümne-viieteistkümne =viieteistkümne  (PlP  >kümne-viieteistkümn !22_S	et	f	\N
156266	kümne-viieteistkümne	?kümne-viieteistkümne =kümne  (SgN  >kümne-viie+teist+kümne !02_A	et	f	\N
156267	kümne-viieteistkümne	?kümne-viieteistkümne =kümne  (PlP  >kümne-viie+teist+kümn !22_S	et	f	\N
156268	kümne-viieteistkümne	?kümne-viieteistkümne =teistkümne  (SgN  >kümne-viie+teistkümne !02_A	et	f	\N
156269	kümne-viieteistkümne	?kümne-viieteistkümne =teistkümne  (PlP  >kümne-viie+teistkümn !22_S	et	f	\N
156313	pantima	pantima =panti  (Sup  >pantima !28_V	et	f	\N
156314	pantima	pantima =ima  (SgN  >pant+ima !17_S	et	f	\N
156315	pantima	pantima =ima  (SgG  >pant+ima !17_S	et	f	\N
156316	pantima	pantima =ima  (SgP  >pant+ima !17_S	et	f	\N
156341	väljast	väljast =välja  (SgEl  >väli !24_S	et	f	\N
156342	väljast	väljast =väljas  (SgP  >väljane !10_A	et	f	\N
156343	väljast	"väljane %välja  )NE_aA  <väli ;24_S	et	f	\N
156344	väljast	väljast =väljast  (ID  >väljast !41_D	et	f	\N
156345	talumeest	talumeest =mee  (SgEl  >talu+mesi !15_S	et	f	\N
156346	talumeest	talumeest =mees  (SgP  >talu+meene !10_A	et	f	\N
156347	talumeest	"talu+meene %mee  )NE_aA  <talu+mesi ;15_S	et	f	\N
156348	talumeest	talumeest =mees  (SgP  >talu+mees !13_S	et	f	\N
156361	3igaaastane	igaaastane =aastane  (SgN  >iga+aastane !12~10_A	et	f	\N
156362	3igaaastane	"iga+aastane %aasta  )NE_aA  <iga+aasta ;01_S	et	f	\N
156363	teemaline	teemaline =teemaline  (SgN  >teemaline !12_A	et	f	\N
156364	teemaline	"teemaline %teema  )LINE_aA  <teema ;16_S	et	f	\N
156365	teemaline	teemaline =maline  (SgN  >tee+maline !10_A	et	f	\N
156366	teemaline	"tee+maline %mali  )NE_aA  <tee+mali ;17_S	et	f	\N
156372	metslooma	metslooma =looma  (SgG  >mets+loom !22_S	et	f	\N
156374	metslooma	metslooma =looma  (SgP  >mets+loom !22_S	et	f	\N
156376	metslooma	metslooma =looma  (SgAdt  >mets+loom !22_S	et	f	\N
156412	kadriorgu	kadriorgu =orgu  (SgP  >kadri+org !22_S	et	f	\N
156413	kadriorgu	kadriorgu =orgu  (SgAdt  >kadri+org !22_S	et	f	\N
156414	trahvi	trahvi =trahvi  (SgG  >trahv !22_S	et	f	\N
156415	trahvi	trahvi =trahvi  (SgP  >trahv !22_S	et	f	\N
156416	trahvi	trahvi =trahvi  (SgAdt  >trahv !22_S	et	f	\N
156417	trahvi	trahvi =trahvi  (IndPrPs_  >trahvima !28_V	et	f	\N
156418	trahvi	trahvi =trahvi  (ImpPrSg2  >trahvima !28_V	et	f	\N
156419	ajalehi	?ajalehi =lehi  (SgN  >aja+lehi !17_S	et	f	\N
156420	ajalehi	?ajalehi =lehi  (SgG  >aja+lehi !17_S	et	f	\N
156421	ajalehi	?ajalehi =lehi  (SgP  >aja+lehi !17_S	et	f	\N
156422	jalgrattadega	### jalgrattadega	et	f	\N
156431	päkkapikk	### päkkapikk	et	f	\N
156435	külmund	külmund =un  (SgP  >külm+uni !20_S	et	f	\N
156436	külmund	külmund =und  (SgN  >külm+und !22_S	et	f	\N
156454	praamuga	?praamuga =praamu  (SgKom  >praamu !16_S	et	f	\N
156455	praamuga	?praamuga =uga  (SgN  >praam+uga !17_S	et	f	\N
156456	praamuga	?praamuga =uga  (SgG  >praam+uga !17_S	et	f	\N
156458	praamuga	?praamuga =uga  (SgP  >praam+uga !17_S	et	f	\N
156474	kelled	?kelled =kelle  (IndPrSg2  >kellema !30_V	et	f	\N
156494	suppi	suppi =suppi  (SgP  >supp !22_S	et	f	\N
156495	suppi	suppi =suppi  (SgAdt  >supp !22_S	et	f	\N
156518	autotee	autotee =tee  (SgN  >auto+tee !26_S	et	f	\N
156177	festivall	?festivall =festivall  (SgN  >festivall !22_S	et	f	\N
156181	pärts	?pärts =pärts  (SgN  >pärts !22_S	et	f	\N
156190	soojuselektrijaama	soojuselektrijaama =jaama  (SgG  >soojus+elektri+jaam !22_S	et	f	\N
156192	soojuselektrijaama	soojuselektrijaama =jaama  (SgP  >soojus+elektri+jaam !22_S	et	f	\N
156193	soojuselektrijaama	soojuselektrijaama =jaama  (SgAdt  >soojus+elektri+jaam !22_S	et	f	\N
156194	tehtnuud	?tehtnuud =tehtnuu  (PlN  >tehtnuu !26_S	et	f	\N
156195	tehtnuud	?tehtnuud =tehtnuu  (SgP  >tehtnuu !26_S	et	f	\N
156196	tehtnuud	?tehtnuud =tehtnuud  (SgN  >tehtnuud !22_S	et	f	\N
156197	üskkõik	?üskkõik =üskkõik  (SgN  >üskkõik !22_S	et	f	\N
156201	kolmverand	?kolmverand =kolmverand  (SgN  >kolmverand !22_S	et	f	\N
156202	kolmverand	?kolmverand =verand  (SgN  >kolm+verand !02_S	et	f	\N
156203	studioos	?studioos =studioo  (SgIn  >studioo !26_S	et	f	\N
156204	studioos	?studioos =studioos  (SgN  >studioos !22_S	et	f	\N
156220	klienditele	?klienditele =kliendi  (PlAll  >kliendi !01_S	et	f	\N
156221	klienditele	?klienditele =kliendi  (PlAll  >kliend !02_S	et	f	\N
156222	klienditele	?klienditele =kliendite  (PlAll  >klienditt !22_S	et	f	\N
156224	klienditele	?klienditele =klienditele  (IndPrPs_  >klienditelema !36_V	et	f	\N
156226	klienditele	?klienditele =klienditele  (ImpPrSg2  >klienditelema !36_V	et	f	\N
156229	peeavad	?peeavad =peeava  (PlN  >peeava !01_S	et	f	\N
156232	kaheteistkümne	?kaheteistkümne =kaheteistkümne  (SgN  >kaheteistkümne !02_A	et	f	\N
156233	kaheteistkümne	?kaheteistkümne =kaheteistkümne  (PlP  >kaheteistkümn !22_S	et	f	\N
156234	kaheteistkümne	?kaheteistkümne =kümne  (SgN  >kahe+teist+kümne !02_A	et	f	\N
156235	kaheteistkümne	?kaheteistkümne =kümne  (PlP  >kahe+teist+kümn !22_S	et	f	\N
156236	kaheteistkümne	?kaheteistkümne =teistkümne  (SgN  >kahe+teistkümne !02_A	et	f	\N
156237	kaheteistkümne	?kaheteistkümne =teistkümne  (PlP  >kahe+teistkümn !22_S	et	f	\N
156262	serial	?serial =seria  (SgAd  >seria !01_S	et	f	\N
156263	serial	?serial =serial  (SgN  >serial !19_S	et	f	\N
156277	neljateistkümne	?neljateistkümne =neljateistkümne  (SgN  >neljateistkümne !02_A	et	f	\N
156278	neljateistkümne	?neljateistkümne =neljateistkümne  (PlP  >neljateistkümn !22_S	et	f	\N
156279	neljateistkümne	?neljateistkümne =kümne  (SgN  >nelja+teist+kümne !02_A	et	f	\N
156280	neljateistkümne	?neljateistkümne =kümne  (PlP  >nelja+teist+kümn !22_S	et	f	\N
156281	neljateistkümne	?neljateistkümne =teistkümne  (SgN  >nelja+teistkümne !02_A	et	f	\N
156282	neljateistkümne	?neljateistkümne =teistkümne  (PlP  >nelja+teistkümn !22_S	et	f	\N
156289	goriot	?goriot =gorio  (SgP  >gorio !01_S	et	f	\N
156290	goriot	?goriot =goriot  (SgN  >goriot !22_S	et	f	\N
156295	seadis	seadis =sead  (IndIpfSg3  >seadma !34_V	et	f	\N
156296	seadis	seadis =seadis  (SgN  >seadis !09_S	et	f	\N
156317	rikkus	rikkus =rikku  (IndIpfSg3  >rikkuma !28_V	et	f	\N
156318	rikkus	rikkus =rikkus  (SgN  >rikkus !11~09_S	et	f	\N
156321	gorioti	?gorioti =gorioti  (SgN  >gorioti !16_S	et	f	\N
156322	gorioti	?gorioti =gorioti  (SgG  >gorioti !16_S	et	f	\N
156323	gorioti	?gorioti =gorioti  (SgP  >goriot !22_S	et	f	\N
156324	gorioti	?gorioti =gorioti  (SgAdt  >goriot !22_S	et	f	\N
156369	tagaaetavat	?tagaaetavat =tagaaeta  (KvtPrPs  >tagaaetama !27_V	et	f	\N
156370	tagaaetavat	?tagaaetavat =tagaaetava  (SgP  >tagaaetav !02_A	et	f	\N
156371	tagaaetavat	?tagaaetavat =tagaaetava  (SgP  >tagaaetava !16_S	et	f	\N
156373	tagaaetavat	?tagaaetavat =aetava  (SgP  >taga+aetava !01_S	et	f	\N
156375	tagaaetavat	?tagaaetavat =aetava  (SgP  >taga+aetav !02_AS	et	f	\N
156401	lugen	?lugen =lugen  (SgN  >lugen !02_S	et	f	\N
156410	ristmiku	ristmiku =ristmiku  (SgG  >ristmik !25_S	et	f	\N
156411	ristmiku	ristmiku =miku  (SgG  >rist+mikk !22_S	et	f	\N
156437	makama	?makama =maka  (Sup  >makama !27_V	et	f	\N
156438	makama	?makama =makama  (SgG  >makam !02_A	et	f	\N
156469	väiked	?väiked =väike  (PlN  >väige !06_S	et	f	\N
156470	väiked	?väiked =väike  (IndPrSg2  >väikema !27_V	et	f	\N
156476	tasuv	tasuv =tasu  (PtsPrPs  >tasuma !27_V	et	f	\N
156477	tasuv	tasuv =tasuv  (SgN  >tasuv !02_A	et	f	\N
156478	tasuv	"tasuv %tasu  )V_vA  <tasuma ;27_V	et	f	\N
156483	puhkepäevast	puhkepäevast =ast  (SgN  >puhke+päev+ast !22_S	et	f	\N
156484	puhkepäevast	puhkepäevast =päeva  (SgEl  >puhke+päev !22_S	et	f	\N
156485	puhkepäevast	puhkepäevast =päevas  (SgP  >puhke+päevane !10_A	et	f	\N
156486	puhkepäevast	"puhke+päevane %päeva  )NE_aA  <puhke+päev ;22_S	et	f	\N
156493	süüasime	?süüasime =süüasi  (IndPrPl1  >süüasima !28_V	et	f	\N
156496	sektsioonikapi	?sektsioonikapi =sektsioonikapi  (SgG  >sektsioonikapp !22_S	et	f	\N
156497	sektsioonikapi	?sektsioonikapi =sektsioonikapi  (IndPrPs_  >sektsioonikappima !28_V	et	f	\N
156498	sektsioonikapi	?sektsioonikapi =sektsioonikapi  (ImpPrSg2  >sektsioonikappima !28_V	et	f	\N
156512	kahekorruselises	kahekorruselises =korruselise  (SgIn  >kahe+korruseline !12_A	et	f	\N
156513	kahekorruselises	"kahe+korruseline %korruse  )LINE_aA  <kahe+korrus ;09_S	et	f	\N
156517	lähetal	?lähetal =lähetal  (SgN  >lähetal !19_S	et	f	\N
156520	xx-alle	?xx-alle =alle  (SgN  >xx-alle !06_S	et	f	\N
156521	xx-alle	?xx-alle =alle  (IndPrPs_  >xx-allema !30_V	et	f	\N
156522	xx-alle	?xx-alle =alle  (ImpPrSg2  >xx-allema !30_V	et	f	\N
156530	xx-alt	xx-alt =alt  (ID  >xx-alt !41_DK	et	f	\N
156252	minutiks	minutiks =minuti  (SgTr  >minut !02_S	et	f	\N
156254	minutiks	minutiks =tiks  (SgN  >minu+tiks !22_S	et	f	\N
156271	neljateistkümne	?neljateistkümne =neljateistkümne  (SgN  >neljateistkümne !02_A	et	f	\N
156272	neljateistkümne	?neljateistkümne =neljateistkümne  (PlP  >neljateistkümn !22_S	et	f	\N
156273	neljateistkümne	?neljateistkümne =kümne  (SgN  >nelja+teist+kümne !02_A	et	f	\N
156274	neljateistkümne	?neljateistkümne =kümne  (PlP  >nelja+teist+kümn !22_S	et	f	\N
156275	neljateistkümne	?neljateistkümne =teistkümne  (SgN  >nelja+teistkümne !02_A	et	f	\N
156276	neljateistkümne	?neljateistkümne =teistkümne  (PlP  >nelja+teistkümn !22_S	et	f	\N
156291	goriot	?goriot =gorio  (SgP  >gorio !01_S	et	f	\N
156292	goriot	?goriot =goriot  (SgN  >goriot !22_S	et	f	\N
156325	kaasavara	kaasavara =vara  (SgN  >kaasa+vara !17_S	et	f	\N
156326	kaasavara	kaasavara =vara  (SgG  >kaasa+vara !17_S	et	f	\N
156327	kaasavara	kaasavara =vara  (SgP  >kaasa+vara !17_S	et	f	\N
156328	kaasavara	kaasavara =avara  (SgG  >kaas+avar !02_A	et	f	\N
156349	otsaseina	otsaseina =seina  (SgG  >otsa+sein !23?22_S	et	f	\N
156350	otsaseina	otsaseina =seina  (SgP  >otsa+sein !23?22_S	et	f	\N
156351	otsaseina	otsaseina =seina  (SgAdt  >otsa+sein !23?22_S	et	f	\N
156367	uurimistööd	uurimistööd =töö  (PlN  >uurimis+töö !26_S	et	f	\N
156368	uurimistööd	uurimistööd =töö  (SgP  >uurimis+töö !26_S	et	f	\N
156377	metsast	metsast =metsa  (SgEl  >mets !22_S	et	f	\N
156378	metsast	metsast =metsas  (SgP  >metsane !10_A	et	f	\N
156379	metsast	"metsane %metsa  )NE_aA  <mets ;22_S	et	f	\N
156380	metsast	metsast =ast  (SgN  >mets+ast !22_S	et	f	\N
156387	lendavad	lendavad =lenda  (IndPrPl3  >lendama !29_V	et	f	\N
156388	lendavad	lendavad =lendava  (PlN  >lendav !02_A	et	f	\N
156390	lendavad	"lendav %lenda  )V_vA  <lendama ;29_V	et	f	\N
156392	lendavad	lendavad =ava  (PlN  >lend+ava !17_S	et	f	\N
156402	büroose	?büroose =büroose  (SgN  >büroose !16_S	et	f	\N
156403	büroose	?büroose =büroose  (SgG  >büroose !16_S	et	f	\N
156404	büroose	?büroose =büroose  (PlP  >büroos !22_S	et	f	\N
156423	pähklidega	### pähklidega	et	f	\N
156430	lehekeset	### lehekeset	et	f	\N
156432	ussike	ussike =ussike  (SgN  >ussike !12_S	et	f	\N
156433	ussike	"ussike %ussi  )KE_dS  <uss ;22_S	et	f	\N
156434	ussike	ussike =ike  (SgN  >uss+ike !06_S	et	f	\N
156450	haapsalu	?haapsalu =haapsalu  (SgN  >haapsalu !01_S	et	f	\N
156451	haapsalu	?haapsalu =haapsalu  (SgG  >haapsalu !01_S	et	f	\N
156452	haapsalu	?haapsalu =haapsalu  (IndPrPs_  >haapsaluma !27_V	et	f	\N
156453	haapsalu	?haapsalu =haapsalu  (ImpPrSg2  >haapsaluma !27_V	et	f	\N
156504	ramatud	?ramatud =rama  (PtsPtIps  >ramama !27_V	et	f	\N
156505	ramatud	?ramatud =ramatu  (PlN  >ramatu !01_A	et	f	\N
156506	ramatud	?ramatud =ramatu  (IndPrSg2  >ramatuma !27_V	et	f	\N
156507	ramatud	?ramatud =ramatud  (ID  >ramatud !41_A	et	f	\N
156532	kahekoruselises	?kahekoruselises =kahekoruselise  (SgIn  >kahekoruseline !12_A	et	f	\N
156533	kahekoruselises	?kahekoruselises =koruselise  (SgIn  >kahe+koruseline !12_A	et	f	\N
156557	toetaks	toetaks =toeta  (KndPrPs  >toetama !27_V	et	f	\N
156558	toetaks	toetaks =taks  (SgN  >toe+taks !22_S	et	f	\N
156563	finantsiliselt	finantsiliselt =finantsilise  (SgAbl  >finantsiline !12_A	et	f	\N
156564	finantsiliselt	"finantsiline %finantsi  )LINE_aA  <finants ;22_S	et	f	\N
156565	finantsiliselt	finantsiliselt =finantsiliselt  (ID  >finantsiliselt !41_D	et	f	\N
156566	finantsiliselt	"finantsiliselt %finantsi  )LISELT_mD  <finants ;22_S	et	f	\N
156567	finantsiliselt	"finantsiliselt %finantsilise  )LT_mD  <finantsiline ;12_A	et	f	\N
156573	sõltusid	sõltusid =sõltu  (IndIpfSg2  >sõltuma !27_V	et	f	\N
156574	sõltusid	sõltusid =sõltu  (IndIpfPl3  >sõltuma !27_V	et	f	\N
156599	seistse	?seistse =seistse  (SgN  >seistse !06_S	et	f	\N
156600	seistse	?seistse =seistse  (SgG  >seistne !02_A	et	f	\N
156601	seistse	?seistse =seistse  (SgG  >seistse !06_S	et	f	\N
156602	seistse	?seistse =seistse  (PlP  >seists !22_S	et	f	\N
156603	seistse	?seistse =seistse  (IndPrPs_  >seistsema !27_V	et	f	\N
156604	seistse	?seistse =seistse  (ImpPrSg2  >seistsema !27_V	et	f	\N
156618	iisraelis	?iisraelis =iisraeli  (SgIn  >iisraeli !01_S	et	f	\N
156619	iisraelis	?iisraelis =iisraeli  (SgIn  >iisrael !22_S	et	f	\N
156620	iisraelis	?iisraelis =iisraeli  (IndIpfSg3  >iisraelima !28_V	et	f	\N
156621	iisraelis	?iisraelis =iisraelis  (SgN  >iisraelis !09_S	et	f	\N
156624	nädalalõpeksi	?nädalalõpeksi =nädalalõpeksi  (IndPrPs_  >nädalalõpeksima !28_V	et	f	\N
156625	nädalalõpeksi	?nädalalõpeksi =nädalalõpeksi  (ImpPrSg2  >nädalalõpeksima !28_V	et	f	\N
156626	nädalalõpeksi	?nädalalõpeksi =lõpeksi  (SgN  >nädala+lõpeksi !01_S	et	f	\N
156627	nädalalõpeksi	?nädalalõpeksi =lõpeksi  (SgG  >nädala+lõpeksi !01_S	et	f	\N
156630	söökde	?söökde =söökde  (SgN  >söökde !06_S	et	f	\N
156631	söökde	?söökde =söökde  (SgG  >söökde !06_S	et	f	\N
156632	söökde	?söökde =söökde  (PlP  >söökd !22_S	et	f	\N
156633	söökde	?söökde =söökde  (IndPrPs_  >söökdema !27_V	et	f	\N
156634	söökde	?söökde =söökde  (ImpPrSg2  >söökdema !27_V	et	f	\N
156645	jaapansse	?jaapansse =jaapansse  (SgG  >jaapansne !02_A	et	f	\N
156286	täelikult	?täelikult =täeliku  (SgAbl  >täeliku !01_S	et	f	\N
156287	täelikult	?täelikult =täeliku  (SgAbl  >täelik !02_S	et	f	\N
156288	täelikult	?täelikult =täelikult  (ID  >täelikult !41_D	et	f	\N
156293	vaeses	vaeses =vaese  (SgIn  >vaene !10_AS	et	f	\N
156294	vaeses	"vaene %vae  )NE_aA  <vaag ;22_S	et	f	\N
156297	kõrgseldskonda	?kõrgseldskonda =kõrgseldskonda  (SgN  >kõrgseldskonda !16_S	et	f	\N
156298	kõrgseldskonda	?kõrgseldskonda =kõrgseldskonda  (SgG  >kõrgseldskonda !16_S	et	f	\N
156299	kõrgseldskonda	?kõrgseldskonda =kõrgseldskonda  (SgP  >kõrgseldskond !22_S	et	f	\N
156300	kõrgseldskonda	?kõrgseldskonda =kõrgseldskonda  (SgAdt  >kõrgseldskond !22_S	et	f	\N
156301	kõrgseldskonda	?kõrgseldskonda =kõrgseldskonda  (IndPrPs_  >kõrgseldskondama !27_V	et	f	\N
156302	kõrgseldskonda	?kõrgseldskonda =kõrgseldskonda  (ImpPrSg2  >kõrgseldskondama !27_V	et	f	\N
156303	kõrgseldskonda	?kõrgseldskonda =seldskonda  (SgN  >kõrg+seldskonda !01_S	et	f	\N
156304	kõrgseldskonda	?kõrgseldskonda =seldskonda  (SgG  >kõrg+seldskonda !01_S	et	f	\N
156305	kõrgseldskonda	?kõrgseldskonda =seldskonda  (SgP  >kõrg+seldskond !22_S	et	f	\N
156306	kõrgseldskonda	?kõrgseldskonda =seldskonda  (SgAdt  >kõrg+seldskond !22_S	et	f	\N
156307	goriotil	?goriotil =gorioti  (SgAd  >gorioti !16_S	et	f	\N
156308	goriotil	?goriotil =goriotil  (SgN  >goriotil !02_S	et	f	\N
156309	piilikus	?piilikus =piiliku  (SgIn  >piiliku !01_S	et	f	\N
156310	piilikus	?piilikus =piiliku  (SgIn  >piilik !02_S	et	f	\N
156311	piilikus	?piilikus =piiliku  (IndIpfSg3  >piilikuma !27_V	et	f	\N
156312	piilikus	?piilikus =piilikus  (SgN  >piilikus !11_S	et	f	\N
156319	häbenesid	häbenesid =häbene  (IndIpfSg2  >häbenema !27_V	et	f	\N
156320	häbenesid	häbenesid =häbene  (IndIpfPl3  >häbenema !27_V	et	f	\N
156336	isast	isast =isa  (SgEl  >isa !17_S	et	f	\N
156337	isast	isast =isas  (SgP  >isane !10_AS	et	f	\N
156338	isast	"isane %isa  )NE_aA  <isa ;17_S	et	f	\N
156352	raudtoru	raudtoru =toru  (SgN  >raud+toru !17_S	et	f	\N
156353	raudtoru	raudtoru =toru  (SgG  >raud+toru !17_S	et	f	\N
156354	raudtoru	raudtoru =toru  (SgP  >raud+toru !17_S	et	f	\N
156381	joostes	joostes =joos  (Ger  >jooksma !32_V	et	f	\N
156382	joostes	joostes =joostes  (ID  >joostes !41_D	et	f	\N
156385	hallid	hallid =halli  (PlN  >hall !22_S	et	f	\N
156386	hallid	hallid =halli  (PlN  >hall !22_AS	et	f	\N
156394	sillast	sillast =silla  (SgEl  >sild !22_S	et	f	\N
156395	sillast	sillast =sillas  (SgP  >sillane !10_A	et	f	\N
156396	sillast	"sillane %silla  )NE_aA  <sild ;22_S	et	f	\N
156398	haodpuud	?haodpuud =haodpuu  (PlN  >haodpuu !26_S	et	f	\N
156399	haodpuud	?haodpuud =haodpuu  (SgP  >haodpuu !26_S	et	f	\N
156400	haodpuud	?haodpuud =haodpuud  (SgN  >haodpuud !22_S	et	f	\N
156405	kellaseppale	kellaseppale =ale  (SgN  >kella+sepp+ale !16_S	et	f	\N
156406	kellaseppale	kellaseppale =ale  (SgG  >kella+sepp+ale !16_S	et	f	\N
156439	sipelgas	sipelgas =sipelga  (SgIn  >sipelgas !02_S	et	f	\N
156440	sipelgas	sipelgas =sipelgas  (SgN  >sipelgas !02_S	et	f	\N
156441	tõtas	?tõtas =tõta  (SgIn  >tõta !16_S	et	f	\N
156442	tõtas	?tõtas =tõta  (IndIpfSg3  >tõtama !27_V	et	f	\N
156443	tõtas	?tõtas =tõtas  (SgN  >tõtas !07_S	et	f	\N
156444	joonitud	joonitud =jooni  (PtsPtIps  >joonima !28_V	et	f	\N
156445	joonitud	joonitud =joonitu  (PlN  >joonitu !01_AS	et	f	\N
156446	joonitud	"joonitu %jooni  )TU1_vS  <joonima ;28_V	et	f	\N
156447	joonitud	joonitud =joonitud  (ID  >joonitud !41_A	et	f	\N
156448	joonitud	"joonitud %jooni  )TUD_vA  <joonima ;28_V	et	f	\N
156457	haapsalust	?haapsalust =haapsalu  (SgEl  >haapsalu !01_S	et	f	\N
156459	haapsalust	?haapsalust =haapsalus  (SgP  >haapsalus !11_S	et	f	\N
156460	x-al	### x-al	et	f	\N
156475	xxx-es	### xxx-es	et	f	\N
156490	jogil	?jogil =jogi  (SgAd  >jogi !17_S	et	f	\N
156491	kojus	?kojus =koju  (IndIpfSg3  >kojuma !27_V	et	f	\N
156492	kojus	?kojus =kojus  (SgN  >kojus !09_S	et	f	\N
156502	elektriraadiator	?elektriraadiator =elektriraadiator  (SgN  >elektriraadiator !02_S	et	f	\N
156503	elektriraadiator	?elektriraadiator =raadiator  (SgN  >elektri+raadiator !02_S	et	f	\N
156510	laelampi	laelampi =lampi  (SgP  >lae+lamp !22_SA	et	f	\N
156511	laelampi	laelampi =lampi  (SgAdt  >lae+lamp !22_SA	et	f	\N
156524	valitus	valitus =valitu  (SgIn  >valitu !01_S	et	f	\N
156525	valitus	"valitu %vali  )TU1_vS  <valima ;27_V	et	f	\N
156526	valitus	valitus =valitus  (SgN  >valitus !11_S	et	f	\N
156527	valitus	"valitus %vali  )TUS1_aS  <valima ;27_V	et	f	\N
156545	petersburgisse	?petersburgisse =petersburgi  (SgIll  >petersburk !22_S	et	f	\N
156546	petersburgisse	?petersburgisse =petersburgisse  (SgG  >petersburgisne !02_A	et	f	\N
156547	petersburgisse	?petersburgisse =petersburgisse  (PlP  >petersburgiss !22_S	et	f	\N
156568	tegeks	?tegeks =tege  (SgTr  >tege !16_S	et	f	\N
156572	jõulisedest	?jõulisedest =jõulisedes  (SgP  >jõulisedene !12_A	et	f	\N
156617	mägiga	### mägiga	et	f	\N
156622	televiisiorist	televiisiorist =oris  (SgP  >tele+viisi+orine !10_A	et	f	\N
156623	televiisiorist	"tele+viisi+orine %ori  )NE_aA  <tele+viisi+ori ;24_S	et	f	\N
156636	muusiku	muusiku =muusiku  (SgG  >muusik !02_S	et	f	\N
156637	muusiku	muusiku =siku  (SgG  >muu+sikk !22_S	et	f	\N
156519	autotee	autotee =tee  (SgG  >auto+tee !26_S	et	f	\N
156536	kabineti	kabineti =kabineti  (SgG  >kabinet !22_S	et	f	\N
156537	kabineti	kabineti =kabineti  (SgP  >kabinet !22_S	et	f	\N
156538	kabineti	kabineti =kabineti  (SgAdt  >kabinet !22_S	et	f	\N
156561	kultuuriselt	kultuuriselt =kultuuriselt  (ID  >kultuuriselt !41_D	et	f	\N
156562	kultuuriselt	"kultuuriselt %kultuuri  )SELT_mD  <kultuur ;22_S	et	f	\N
156591	naapre	?naapre =naapre  (SgN  >naapre !06_S	et	f	\N
156592	naapre	?naapre =naapre  (SgG  >naapre !06_S	et	f	\N
156593	naapre	?naapre =naapre  (IndPrPs_  >naaprema !27_V	et	f	\N
156594	naapre	?naapre =naapre  (ImpPrSg2  >naaprema !27_V	et	f	\N
156612	aidsi-abi	aidsi-abi =abi  (SgN  >aidsi-abi !17_S	et	f	\N
156613	aidsi-abi	aidsi-abi =abi  (SgG  >aidsi-abi !17_S	et	f	\N
156614	aidsi-abi	aidsi-abi =abi  (SgP  >aidsi-abi !17_S	et	f	\N
156648	muusikatid	?muusikatid =muusikati  (PlN  >muusikatt !22_S	et	f	\N
156649	muusikatid	?muusikatid =muusikati  (IndPrSg2  >muusikattima !28_V	et	f	\N
156650	muusikatid	?muusikatid =sikati  (PlN  >muu+sikat !02_S	et	f	\N
156651	muusikatid	?muusikatid =sikati  (PlN  >muu+sikatt !22_S	et	f	\N
156659	kohvit	?kohvit =kohvi  (SgP  >kohvi !16_S	et	f	\N
156660	kohvit	?kohvit =kohvit  (SgN  >kohvit !02_S	et	f	\N
156670	nädälalt	?nädälalt =nädäla  (SgAbl  >nädäla !01_S	et	f	\N
156671	nädälalt	?nädälalt =nädälalt  (ID  >nädälalt !41_D	et	f	\N
156675	voodisid	?voodisid =voodi  (PlP  >vood !22_S	et	f	\N
156676	voodisid	?voodisid =voodi  (IndIpfSg2  >voodima !28_V	et	f	\N
156677	voodisid	?voodisid =voodi  (IndIpfPl3  >voodima !28_V	et	f	\N
156678	voodisid	?voodisid =disi  (PlN  >voo+disi !17_S	et	f	\N
156687	rigas	?rigas =riga  (SgIn  >riga !17_S	et	f	\N
156688	rigas	?rigas =riga  (IndIpfSg3  >rigama !27_V	et	f	\N
156689	rigas	?rigas =rigas  (SgN  >rigas !07_S	et	f	\N
156690	sõbriga	?sõbriga =sõbri  (SgKom  >sõbri !16_S	et	f	\N
156695	matkajate	matkajate =matkaja  (PlG  >matkaja !01_S	et	f	\N
156696	matkajate	"matkaja %matka  )JA_vS  <matkama ;29_V	et	f	\N
156702	porandal	?porandal =poranda  (SgAd  >poranda !01_S	et	f	\N
156707	tundasi	?tundasi =tundasi  (ID  >tundasi !41_D	et	f	\N
156714	pelmeeni	pelmeeni =pelmeeni  (SgG  >pelmeen !22_S	et	f	\N
156715	pelmeeni	pelmeeni =pelmeeni  (SgP  >pelmeen !22_S	et	f	\N
156716	pelmeeni	pelmeeni =pelmeeni  (SgAdt  >pelmeen !22_S	et	f	\N
156717	jõululaatis	?jõululaatis =jõululaati  (SgIn  >jõululaati !16_S	et	f	\N
156718	jõululaatis	?jõululaatis =jõululaati  (IndIpfSg3  >jõululaatima !28_V	et	f	\N
156719	jõululaatis	?jõululaatis =jõululaatis  (SgN  >jõululaatis !09_S	et	f	\N
156720	jõululaatis	?jõululaatis =laatis  (SgN  >jõulu+laatis !11~09_S	et	f	\N
156721	jõululaatis	?jõululaatis =lulaati  (SgIn  >jõu+lulaati !16_S	et	f	\N
156722	jõululaatis	?jõululaatis =lulaatis  (SgN  >jõu+lulaatis !11_S	et	f	\N
156760	janele	?janele =jane  (SgAll  >jane !16_S	et	f	\N
156761	janele	?janele =janele  (IndPrPs_  >janelema !31~27_V	et	f	\N
156762	janele	?janele =janele  (ImpPrSg2  >janelema !31~27_V	et	f	\N
156779	hommikuukohvi	?hommikuukohvi =hommikuukohvi  (SgG  >hommikuukohv !22_S	et	f	\N
156780	hommikuukohvi	?hommikuukohvi =hommikuukohvi  (SgP  >hommikuukohv !22_S	et	f	\N
156781	hommikuukohvi	?hommikuukohvi =hommikuukohvi  (SgAdt  >hommikuukohv !22_S	et	f	\N
156782	hommikuukohvi	?hommikuukohvi =hommikuukohvi  (IndPrPs_  >hommikuukohvima !28_V	et	f	\N
156783	hommikuukohvi	?hommikuukohvi =hommikuukohvi  (ImpPrSg2  >hommikuukohvima !28_V	et	f	\N
156785	hommikuukohvi	?hommikuukohvi =ohvi  (SgN  >hommik+uuk+ohvi !16_S	et	f	\N
156786	hommikuukohvi	?hommikuukohvi =ohvi  (SgG  >hommik+uuk+ohvi !16_S	et	f	\N
156787	hommikuukohvi	?hommikuukohvi =ohvi  (SgG  >hommik+uuk+ohv !22_S	et	f	\N
156788	hommikuukohvi	?hommikuukohvi =ohvi  (SgP  >hommik+uuk+ohv !22_S	et	f	\N
156789	hommikuukohvi	?hommikuukohvi =ohvi  (SgAdt  >hommik+uuk+ohv !22_S	et	f	\N
156790	hommikuukohvi	?hommikuukohvi =ukohvi  (SgN  >hommiku+ukohvi !01_S	et	f	\N
156791	hommikuukohvi	?hommikuukohvi =ukohvi  (SgG  >hommiku+ukohvi !01_S	et	f	\N
156793	hommikuukohvi	?hommikuukohvi =ukohvi  (SgG  >hommiku+ukohv !22_S	et	f	\N
156794	hommikuukohvi	?hommikuukohvi =ukohvi  (SgP  >hommiku+ukohv !22_S	et	f	\N
156795	hommikuukohvi	?hommikuukohvi =ukohvi  (SgAdt  >hommiku+ukohv !22_S	et	f	\N
156796	hommikuukohvi	?hommikuukohvi =uukohvi  (SgN  >hommik+uukohvi !01_S	et	f	\N
156797	hommikuukohvi	?hommikuukohvi =uukohvi  (SgG  >hommik+uukohvi !01_S	et	f	\N
156798	hommikuukohvi	?hommikuukohvi =uukohvi  (SgG  >hommik+uukohv !22_S	et	f	\N
156799	hommikuukohvi	?hommikuukohvi =uukohvi  (SgP  >hommik+uukohv !22_S	et	f	\N
156800	hommikuukohvi	?hommikuukohvi =uukohvi  (SgAdt  >hommik+uukohv !22_S	et	f	\N
156806	hommikuusööki	hommikuusööki =ööki  (SgP  >hommik+uus+öök !22_S	et	f	\N
156807	hommikuusööki	hommikuusööki =ööki  (SgAdt  >hommik+uus+öök !22_S	et	f	\N
156826	kakskümmendil	?kakskümmendil =kakskümmendi  (SgAd  >kakskümment !22_S	et	f	\N
156827	kakskümmendil	?kakskümmendil =kakskümmendil  (SgN  >kakskümmendil !02_S	et	f	\N
156828	kakskümmendil	?kakskümmendil =kümmendi  (SgAd  >kaks+kümmendi !01_S	et	f	\N
156829	kakskümmendil	?kakskümmendil =kümmendi  (SgAd  >kaks+kümment !22_S	et	f	\N
156843	hinnatõusu	hinnatõusu =tõusu  (SgG  >hinna+tõus !22_S	et	f	\N
156844	hinnatõusu	hinnatõusu =tõusu  (SgP  >hinna+tõus !22_S	et	f	\N
156531	xx-alt	xx-alt =alt  (SgN  >xx-alt !22_S	et	f	\N
156534	magatuba	?magatuba =magatuba  (SgN  >magatuba !16_S	et	f	\N
156535	magatuba	?magatuba =magatuba  (SgG  >magatuba !16_S	et	f	\N
156540	toolle	?toolle =toolle  (SgN  >toolle !06_S	et	f	\N
156541	toolle	?toolle =toolle  (SgG  >toolle !06_S	et	f	\N
156542	toolle	?toolle =toolle  (PlP  >tooll !22_S	et	f	\N
156543	toolle	?toolle =toolle  (IndPrPs_  >toollema !30_V	et	f	\N
156544	toolle	?toolle =toolle  (ImpPrSg2  >toollema !30_V	et	f	\N
156551	muuseumpat	?muuseumpat =muuseumpa  (SgP  >muuseumpa !16_S	et	f	\N
156552	muuseumpat	?muuseumpat =seumpa  (SgP  >muu+seumpa !01_S	et	f	\N
156553	muuseumpat	?muuseumpat =seumpat  (SgN  >muu+seumpat !02_S	et	f	\N
156555	sõbralikad	?sõbralikad =sõbralika  (PlN  >sõbralika !01_S	et	f	\N
156556	sõbralikad	?sõbralikad =sõbralika  (PlN  >sõbralikas !02_A	et	f	\N
156559	poliitiselt	?poliitiselt =poliitise  (SgAbl  >poliitis !11_S	et	f	\N
156560	poliitiselt	?poliitiselt =poliitiselt  (ID  >poliitiselt !41_D	et	f	\N
156575	naaberdest	?naaberdest =naaberde  (PlEl  >naabert !22_S	et	f	\N
156576	naaberdest	?naaberdest =naaberdes  (SgP  >naaberdene !12_A	et	f	\N
156577	naaberdest	?naaberdest =berde  (SgEl  >naa+berre !06_S	et	f	\N
156578	naaberdest	?naaberdest =berde  (PlEl  >naa+bert !22_S	et	f	\N
156579	naaberdest	?naaberdest =berdes  (SgP  >naa+berdes !09_S	et	f	\N
156580	naaberdest	?naaberdest =berdes  (SgP  >naa+berdene !12~10_A	et	f	\N
156588	oeleksin	?oeleksin =oele  (KndPrSg1  >oelema !27_V	et	f	\N
156589	oeleksin	?oeleksin =oeleksi  (IndPrSg1  >oeleksima !28_V	et	f	\N
156590	oeleksin	?oeleksin =oeleksin  (SgN  >oeleksin !19_S	et	f	\N
156605	karli	?karli =karli  (SgN  >karli !16_S	et	f	\N
156606	karli	?karli =karli  (SgG  >karli !16_S	et	f	\N
156607	karli	?karli =karli  (SgG  >karl !22_S	et	f	\N
156608	karli	?karli =karli  (SgP  >karl !22_S	et	f	\N
156609	karli	?karli =karli  (SgAdt  >karl !22_S	et	f	\N
156610	karli	?karli =karli  (IndPrPs_  >karlima !28_V	et	f	\N
156611	karli	?karli =karli  (ImpPrSg2  >karlima !28_V	et	f	\N
156635	raakime	### raakime	et	f	\N
156638	sõberist	?sõberist =sõberi  (SgEl  >sõberi !01_S	et	f	\N
156639	sõberist	?sõberist =sõberis  (SgP  >sõberis !11_S	et	f	\N
156640	sõberist	?sõberist =sõberist  (SgN  >sõberist !22_S	et	f	\N
156647	sõbõ	### sõbõ	et	f	\N
156652	jouluturu	?jouluturu =jouluturu  (IndPrPs_  >jouluturuma !27_V	et	f	\N
156653	jouluturu	?jouluturu =jouluturu  (ImpPrSg2  >jouluturuma !27_V	et	f	\N
156654	louna	?louna =lou  (SgEs  >lou !26_S	et	f	\N
156655	louna	?louna =louna  (SgN  >louna !16_S	et	f	\N
156656	louna	?louna =louna  (SgG  >louna !16_S	et	f	\N
156657	louna	?louna =louna  (IndPrPs_  >lounama !29_V	et	f	\N
156658	louna	?louna =louna  (ImpPrSg2  >lounama !29_V	et	f	\N
156685	laskin	?laskin =laski  (IndPrSg1  >laskima !28_V	et	f	\N
156686	laskin	?laskin =laskin  (SgN  >laskin !02_S	et	f	\N
156691	reval	?reval =reva  (SgAd  >reva !17_S	et	f	\N
156692	reval	?reval =reval  (SgN  >reval !02_S	et	f	\N
156700	õlud	?õlud =õlu  (IndPrSg2  >õluma !27_V	et	f	\N
156710	vasinud	?vasinud =vasi  (PtsPtPs  >vasima !27_V	et	f	\N
156711	vasinud	?vasinud =vasinu  (PlN  >vasinu !01_S	et	f	\N
156712	vasinud	?vasinud =vasinu  (IndPrSg2  >vasinuma !27_V	et	f	\N
156713	vasinud	?vasinud =vasinud  (ID  >vasinud !41_A	et	f	\N
156724	muusiumus	?muusiumus =muusiumu  (IndIpfSg3  >muusiumuma !27_V	et	f	\N
156725	muusiumus	?muusiumus =muusiumus  (SgN  >muusiumus !11~09_S	et	f	\N
156726	muusiumus	?muusiumus =siumu  (SgIn  >muu+siumu !16_S	et	f	\N
156727	muusiumus	?muusiumus =siumus  (SgN  >muu+siumus !11~09_S	et	f	\N
156728	muusium	?muusium =muusium  (SgN  >muusium !19~02_S	et	f	\N
156729	muusium	?muusium =sium  (SgN  >muu+sium !22_S	et	f	\N
156743	villased	villased =villase  (PlN  >villane !10_A	et	f	\N
156744	villased	"villane %villa  )NE_aA  <villa ;16_S	et	f	\N
156745	villased	"villane %villa  )NE_aA  <vill ;22_S	et	f	\N
156773	kümmendneli	?kümmendneli =kümmendneli  (SgG  >kümmendnel !02_S	et	f	\N
156805	söin	?söin =söin  (SgN  >söin !22_S	et	f	\N
156819	puhib	puhib =puhi  (IndPrSg3  >puhtima !28_V	et	f	\N
156820	puhib	puhib =puhi  (IndPrSg3  >puhkima !28_V	et	f	\N
156839	laienemine	laienemine =laienemine  (SgN  >laienemine !12_S	et	f	\N
156840	laienemine	"laienemine %laiene  )MINE_vS  <laienema ;27_V	et	f	\N
156841	compiegne	?compiegne =compiegne  (SgN  >compiegne !02_A	et	f	\N
156842	compiegne	?compiegne =compiegne  (PlP  >compiegn !22_S	et	f	\N
156846	embrioloogia	?embrioloogia =embrioloogia  (SgN  >embrioloogia !01_S	et	f	\N
156847	embrioloogia	?embrioloogia =embrioloogia  (SgG  >embrioloogia !01_S	et	f	\N
156855	parimasse	parimasse =parima  (SgIll  >parim !02_A	et	f	\N
156856	parimasse	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
156876	glasnostji	?glasnostji =glasnostji  (SgN  >glasnostji !01_S	et	f	\N
156877	glasnostji	?glasnostji =glasnostji  (SgG  >glasnostji !01_S	et	f	\N
156878	glasnostji	?glasnostji =glasnostji  (IndPrPs_  >glasnostjima !28_V	et	f	\N
156879	glasnostji	?glasnostji =glasnostji  (ImpPrSg2  >glasnostjima !28_V	et	f	\N
156946	kehastus	kehastus =kehastu  (IndIpfSg3  >kehastuma !27_V	et	f	\N
156539	lähadal	?lähadal =lähadal  (SgN  >lähadal !19_S	et	f	\N
156548	petersburgis	?petersburgis =petersburgi  (SgIn  >petersburk !22_S	et	f	\N
156549	petersburgis	?petersburgis =petersburgi  (IndIpfSg3  >petersburgima !28_V	et	f	\N
156550	petersburgis	?petersburgis =petersburgis  (SgN  >petersburgis !09_S	et	f	\N
156554	petersburg	?petersburg =petersburg  (SgN  >petersburg !22_S	et	f	\N
156569	rahvusedest	rahvusedest =ede  (SgEl  >rahvus+ede !16_S	et	f	\N
156570	rahvusedest	rahvusedest =edes  (SgP  >rahvus+edene !10_A	et	f	\N
156571	rahvusedest	"rahvus+edene %ede  )NE_aA  <rahvus+ede ;16_S	et	f	\N
156581	viisa	viisa =viisa  (SgN  >viisa !16_S	et	f	\N
156582	viisa	viisa =viisa  (SgG  >viisas !07_A	et	f	\N
156583	viisa	viisa =viisa  (SgG  >viisa !16_S	et	f	\N
156584	viisa	viisa =viisa  (IndPrPs_  >viisama !29_V	et	f	\N
156585	viisa	viisa =viisa  (ImpPrSg2  >viisama !29_V	et	f	\N
156586	lihtsemaks	lihtsemaks =lihtsema  (SgTr  >lihtsem !02_A	et	f	\N
156587	lihtsemaks	"lihtsem %lihtse  )M_cA  <lihtne ;02_A	et	f	\N
156595	nädalalõpuksis	?nädalalõpuksis =nädalalõpuksi  (IndIpfSg3  >nädalalõpuksima !28_V	et	f	\N
156596	nädalalõpuksis	?nädalalõpuksis =nädalalõpuksis  (SgN  >nädalalõpuksis !09_S	et	f	\N
156597	nädalalõpuksis	?nädalalõpuksis =lõpuksi  (SgIn  >nädala+lõpuksi !01_S	et	f	\N
156598	nädalalõpuksis	?nädalalõpuksis =lõpuksis  (SgN  >nädala+lõpuksis !11_S	et	f	\N
156615	kontsertit	?kontsertit =kontserti  (SgP  >kontserti !01_S	et	f	\N
156616	kontsertit	?kontsertit =sertit  (SgN  >kont+sertit !02_S	et	f	\N
156628	sõberi	?sõberi =sõberi  (SgN  >sõberi !01_S	et	f	\N
156629	sõberi	?sõberi =sõberi  (SgG  >sõberi !01_S	et	f	\N
156641	tuleksi	?tuleksi =tuleksi  (SgN  >tuleksi !01_S	et	f	\N
156642	tuleksi	?tuleksi =tuleksi  (SgG  >tuleksi !01_S	et	f	\N
156643	tuleksi	?tuleksi =tuleksi  (IndPrPs_  >tuleksima !28_V	et	f	\N
156644	tuleksi	?tuleksi =tuleksi  (ImpPrSg2  >tuleksima !28_V	et	f	\N
156664	koik	?koik =koik  (SgN  >koik !22_S	et	f	\N
156684	restaurans	?restaurans =restaurans  (SgN  >restaurans !22_S	et	f	\N
156708	sigala	sigala =sigala  (SgN  >sigala !01_S	et	f	\N
156709	sigala	sigala =sigala  (SgG  >sigala !01_S	et	f	\N
156731	mõtlenud	?mõtlenud =mõtlenu  (PlN  >mõtlenu !01_S	et	f	\N
156732	mõtlenud	?mõtlenud =mõtlenu  (IndPrSg2  >mõtlenuma !27_V	et	f	\N
156733	mõtlenud	?mõtlenud =mõtlenud  (ID  >mõtlenud !41_A	et	f	\N
156736	skypega	### skypega	et	f	\N
156746	kangast	kangast =kanga  (SgEl  >kangas !07_S	et	f	\N
156747	kangast	kangast =kangas  (SgP  >kangas !07_S	et	f	\N
156748	kangast	kangast =kangas  (SgP  >kangane !10_A	et	f	\N
156749	kangast	"kangane %kanga  )NE_aA  <kangas ;07_S	et	f	\N
156752	veina	?veina =vei  (SgEs  >vei !26_S	et	f	\N
156753	veina	?veina =veina  (SgN  >veina !16_S	et	f	\N
156754	veina	?veina =veina  (SgG  >veina !16_S	et	f	\N
156755	veina	?veina =veina  (IndPrPs_  >veinama !29_V	et	f	\N
156756	veina	?veina =veina  (ImpPrSg2  >veinama !29_V	et	f	\N
156774	rongega	### rongega	et	f	\N
156775	oppisin	?oppisin =oppi  (IndIpfSg1  >oppima !28_V	et	f	\N
156776	oppisin	?oppisin =oppisin  (SgN  >oppisin !19_S	et	f	\N
156777	seel	?seel =seel  (SgN  >seel !22_S	et	f	\N
156803	ärasin	?ärasin =ära  (IndIpfSg1  >ärama !27_V	et	f	\N
156804	ärasin	?ärasin =ärasin  (SgN  >ärasin !19_S	et	f	\N
156821	monumentid	### monumentid	et	f	\N
156830	latvija	?latvija =latvija  (SgN  >latvija !01_S	et	f	\N
156831	latvija	?latvija =latvija  (SgG  >latvija !01_S	et	f	\N
156832	latvija	?latvija =latvija  (SgG  >latvijas !02_A	et	f	\N
156833	hotelis	?hotelis =hoteli  (SgIn  >hottel !02_S	et	f	\N
156834	hotelis	?hotelis =hotelis  (SgN  >hotelis !11_S	et	f	\N
156848	kn	### kn	et	f	\N
156869	enesekindlamaks	enesekindlamaks =maks  (SgN  >enese+kindla+maks !22_S	et	f	\N
156870	enesekindlamaks	enesekindlamaks =kindlama  (SgTr  >enese+kindlam !02_A	et	f	\N
156871	enesekindlamaks	"enese+kindlam %kindla  )M_cA  <enese+kindel ;02_A	et	f	\N
156884	leninid	?leninid =lenini  (PlN  >lenin !02_S	et	f	\N
156893	lennini	?lennini =lenni  (SgTer  >lenni !16_S	et	f	\N
156894	lennini	?lennini =lenni  (SgTer  >lenn !22_S	et	f	\N
156895	lennini	?lennini =lennini  (SgG  >lennin !02_S	et	f	\N
156896	lenenile	?lenenile =leneni  (SgAll  >lenen !02_S	et	f	\N
156899	hakkaksid	hakkaksid =hakka  (KndPrSg2  >hakkama !29_V	et	f	\N
156900	hakkaksid	hakkaksid =hakka  (KndPrPl3  >hakkama !29_V	et	f	\N
156901	aitamise	aitamise =aitamise  (SgG  >aitamine !12_S	et	f	\N
156902	aitamise	"aitamine %aita  )MINE_vS  <aitama ;29_V	et	f	\N
156905	aleksender	?aleksender =aleksender  (SgN  >aleksender !02_S	et	f	\N
156906	aleksender	?aleksender =ksender  (SgN  >ale+ksender !02_S	et	f	\N
156909	lenini	?lenini =leni  (SgTer  >leni !17_S	et	f	\N
156910	lenini	?lenini =lenini  (SgG  >lenin !02_S	et	f	\N
156917	vanja	?vanja =vanja  (SgN  >vanja !16_S	et	f	\N
156918	vanja	?vanja =vanja  (SgG  >vanjas !02_A	et	f	\N
156919	vanja	?vanja =vanja  (SgG  >vanja !16_S	et	f	\N
156920	vanja	?vanja =vanja  (IndPrPs_  >vanjama !29_V	et	f	\N
156921	vanja	?vanja =vanja  (ImpPrSg2  >vanjama !29_V	et	f	\N
156646	jaapansse	?jaapansse =jaapansse  (PlP  >jaapanss !22_S	et	f	\N
156665	sanoma	?sanoma =sanoma  (SgN  >sanoma !01_S	et	f	\N
156666	sanoma	?sanoma =sanoma  (SgG  >sanoma !01_S	et	f	\N
156672	erasmus	?erasmus =erasmu  (SgIn  >erasmu !01_S	et	f	\N
156673	erasmus	?erasmus =erasmu  (IndIpfSg3  >erasmuma !27_V	et	f	\N
156674	erasmus	?erasmus =erasmus  (SgN  >erasmus !11_S	et	f	\N
156682	rias	?rias =ria  (SgIn  >ria !26_S	et	f	\N
156683	rias	?rias =rias  (SgN  >rias !22_S	et	f	\N
156693	magin	?magin =magi  (IndPrSg1  >magima !27_V	et	f	\N
156694	magin	?magin =magin  (SgN  >magin !02_S	et	f	\N
156699	sobraga	?sobraga =sobra  (SgKom  >sobra !16_S	et	f	\N
156723	läupäeval	?läupäeval =läupäeva  (SgAd  >läupäeva !01_S	et	f	\N
156730	väikem	?väikem =väikem  (SgN  >väikem !02_A	et	f	\N
156757	juustu-hakkliha	juustu-hakkliha =liha  (SgN  >juustu-hakk+liha !17_S	et	f	\N
156758	juustu-hakkliha	juustu-hakkliha =liha  (SgG  >juustu-hakk+liha !17_S	et	f	\N
156759	juustu-hakkliha	juustu-hakkliha =liha  (SgP  >juustu-hakk+liha !17_S	et	f	\N
156763	sauest	sauest =saue  (SgEl  >sau !22_S	et	f	\N
156764	sauest	sauest =saues  (SgP  >sauene !10_A	et	f	\N
156765	sauest	"sauene %saue  )NE_aA  <sau ;22_S	et	f	\N
156778	join	?join =join  (SgN  >join !22_S	et	f	\N
156808	mö	### mö	et	f	\N
156814	laupaval	?laupaval =laupava  (SgAd  >laupava !01_S	et	f	\N
156815	laupaval	?laupaval =laupava  (SgAd  >laupav !02_A	et	f	\N
156816	laupaval	?laupaval =laupaval  (SgN  >laupaval !19_S	et	f	\N
156817	laupaval	?laupaval =pava  (SgAd  >lau+pava !17_S	et	f	\N
156818	laupaval	?laupaval =paval  (SgN  >lau+paval !02_S	et	f	\N
156822	jõima	?jõima =jõima  (SgN  >jõima !16_S	et	f	\N
156823	jõima	?jõima =jõima  (SgG  >jõima !16_S	et	f	\N
156824	jõima	?jõima =jõima  (IndPrPs_  >jõimama !29_V	et	f	\N
156825	jõima	?jõima =jõima  (ImpPrSg2  >jõimama !29_V	et	f	\N
156837	lubatidemokraatlikke	?lubatidemokraatlikke =lubatidemokraatlikke  (PlP  >lubatidemokraatlik !25_A	et	f	\N
156838	lubatidemokraatlikke	?lubatidemokraatlikke =tidemokraatlikke  (PlP  >luba+tidemokraatlik !25_A	et	f	\N
156850	etaapil	?etaapil =etaapi  (SgAd  >etaapi !16_S	et	f	\N
156883	leninid	?leninid =lenini  (PlN  >lenin !02_S	et	f	\N
156885	tsarismi	tsarismi =tsarismi  (SgG  >tsarism !22_S	et	f	\N
156886	tsarismi	tsarismi =tsarismi  (SgP  >tsarism !22_S	et	f	\N
156887	tsarismi	tsarismi =tsarismi  (SgAdt  >tsarism !22_S	et	f	\N
156890	suudas	?suudas =suuda  (SgIn  >suuda !16_S	et	f	\N
156891	suudas	?suudas =suuda  (IndIpfSg3  >suudama !29_V	et	f	\N
156892	suudas	?suudas =suudas  (SgN  >suudas !07_S	et	f	\N
156903	lenin	?lenin =leni  (IndPrSg1  >lenima !27_V	et	f	\N
156904	lenin	?lenin =lenin  (SgN  >lenin !02_S	et	f	\N
156913	kavatsegi	kavatsegi =kavatse  (IndPrPs_^  >kavatsema !27_V	et	f	\N
156914	kavatsegi	kavatsegi =kavatse  (ImpPrSg2^  >kavatsema !27_V	et	f	\N
156924	name	?name =name  (SgN  >name !16_S	et	f	\N
156925	name	?name =name  (SgG  >name !16_S	et	f	\N
156926	name	?name =name  (IndPrPs_  >namema !27_V	et	f	\N
156927	name	?name =name  (ImpPrSg2  >namema !27_V	et	f	\N
156930	isamaa-armastus	isamaa-armastus =armastus  (SgN  >isamaa-armastus !11_S	et	f	\N
156931	isamaa-armastus	"isamaa-armastus %armasta  )US_vS  <isamaa-armastama ;27_V	et	f	\N
156939	taktitundetu	taktitundetu =tundetu  (SgN  >takti+tundetu !01_A	et	f	\N
156940	taktitundetu	"takti+tundetu %tunde  )TU2_kA  <takti+tunne ;06_S	et	f	\N
156941	taktitundetu	taktitundetu =tundetu  (SgG  >takti+tundetu !01_A	et	f	\N
156942	lõbutudrukud	?lõbutudrukud =lõbutudruku  (IndPrSg2  >lõbutudrukuma !27_V	et	f	\N
156943	lõbutudrukud	?lõbutudrukud =tudruku  (PlN  >lõbu+tudruku !01_S	et	f	\N
156949	olidki	olidki =ol  (IndIpfSg2^  >olema !36_V	et	f	\N
156950	olidki	olidki =ol  (IndIpfPl3^  >olema !36_V	et	f	\N
156994	kapitalismi	kapitalismi =kapitalismi  (SgG  >kapitalism !22_S	et	f	\N
156995	kapitalismi	kapitalismi =kapitalismi  (SgP  >kapitalism !22_S	et	f	\N
156996	kapitalismi	kapitalismi =kapitalismi  (SgAdt  >kapitalism !22_S	et	f	\N
157000	osalised	osalised =osalise  (PlN  >osaline !12_SA	et	f	\N
157001	osalised	"osaline %osa  )LINE_aA  <osa ;17_S	et	f	\N
157008	teadmisis	teadmisis =teadmisi  (PlIn  >teadmine !12_S	et	f	\N
157009	teadmisis	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
157041	pingeline	pingeline =pingeline  (SgN  >pingeline !12_A	et	f	\N
157042	pingeline	"pingeline %pinge  )LINE_aA  <pinge ;06_S	et	f	\N
157050	sünnad	?sünnad =sünna  (PlN  >sünna !16_S	et	f	\N
157051	sünnad	?sünnad =sünna  (IndPrSg2  >sünnama !29_V	et	f	\N
157052	tavalisedes	### tavalisedes	et	f	\N
157054	enneks	?enneks =enne  (PlTr  >enn !22_S	et	f	\N
157055	enneks	?enneks =enne  (KndPrPs  >ennema !27_V	et	f	\N
157058	kohustusi	kohustusi =kohustusi  (PlP  >kohustus !11_S	et	f	\N
157059	kohustusi	"kohustus %kohusta  )US_vS  <kohustama ;27_V	et	f	\N
157065	treeningume	?treeningume =treeningu  (IndPrPl1  >treeninguma !27_V	et	f	\N
157066	treeningume	?treeningume =treeningume  (PlP  >treeningum !19_S	et	f	\N
157067	treeningume	?treeningume =ume  (SgN  >treening+ume !16_S	et	f	\N
157068	treeningume	?treeningume =ume  (SgG  >treening+ume !16_S	et	f	\N
157075	interneetiga	?interneetiga =interneeti  (SgKom  >interneeti !16_S	et	f	\N
156661	tramis	?tramis =trami  (SgIn  >trami !17_S	et	f	\N
156662	tramis	?tramis =trami  (IndIpfSg3  >tramima !27_V	et	f	\N
156663	tramis	?tramis =tramis  (SgN  >tramis !09_S	et	f	\N
156667	mõõdunudassilt	?mõõdunudassilt =mõõdunudassi  (SgAbl  >mõõdunudass !22_S	et	f	\N
156668	mõõdunudassilt	?mõõdunudassilt =nudassi  (SgAbl  >mõõdu+nudassi !01_S	et	f	\N
156669	mõõdunudassilt	?mõõdunudassilt =nudassi  (SgAbl  >mõõdu+nudass !22_S	et	f	\N
156679	busika	?busika =busika  (SgN  >busika !01_S	et	f	\N
156680	busika	?busika =busika  (SgG  >busika !01_S	et	f	\N
156681	busika	?busika =busika  (SgG  >busikas !02_S	et	f	\N
156697	jazzi	?jazzi =jazzi  (SgN  >jazzi !16_S	et	f	\N
156698	jazzi	?jazzi =jazzi  (SgG  >jazzi !16_S	et	f	\N
156701	müürseppid	?müürseppid =müürseppi  (PlN  >müürseppi !01_S	et	f	\N
156703	parandasid	parandasid =paranda  (IndIpfSg2  >parandama !27_V	et	f	\N
156704	parandasid	parandasid =paranda  (IndIpfPl3  >parandama !27_V	et	f	\N
156705	räpase	räpase =räpase  (SgG  >räpane !10_A	et	f	\N
156706	räpase	"räpane %räpa  )NE_aA  <räpp ;22_S	et	f	\N
156734	ühiselamusse	ühiselamusse =elamu  (SgIll  >ühis+elamu !01_S	et	f	\N
156735	ühiselamusse	ühiselamusse =elamus  (SgAdt  >ühis+elamus !11_S	et	f	\N
156737	hõõgveini	hõõgveini =veini  (SgG  >hõõg+vein !22_S	et	f	\N
156738	hõõgveini	hõõgveini =veini  (SgP  >hõõg+vein !22_S	et	f	\N
156739	hõõgveini	hõõgveini =veini  (SgAdt  >hõõg+vein !22_S	et	f	\N
156740	uid	uid =ui  (PlN  >ui !26_S	et	f	\N
156741	uid	uid =ui  (SgP  >ui !26_S	et	f	\N
156742	uid	uid =uid  (SgN  >uid !22_S	et	f	\N
156750	pannkogid	?pannkogid =pannkogi  (PlN  >pannkog !02_S	et	f	\N
156751	pannkogid	?pannkogid =kogi  (PlN  >pann+kogi !17_S	et	f	\N
156766	tallinnani	?tallinnani =tallinna  (SgTer  >tallinna !16_S	et	f	\N
156767	tallinnani	?tallinnani =tallinnani  (SgG  >tallinnan !19_S	et	f	\N
156768	tallinnani	?tallinnani =tallinnani  (SgP  >tallinnan !19_S	et	f	\N
156769	tallinnani	?tallinnani =tallinnani  (SgAdt  >tallinnan !19_S	et	f	\N
156770	tallinnani	?tallinnani =ani  (SgN  >tallinn+ani !17_S	et	f	\N
156771	tallinnani	?tallinnani =ani  (SgG  >tallinn+ani !17_S	et	f	\N
156772	tallinnani	?tallinnani =ani  (SgP  >tallinn+ani !17_S	et	f	\N
156784	öhtupoolikul	?öhtupoolikul =öhtupooliku  (SgAd  >öhtupoolik !25_A	et	f	\N
156792	öhtupoolikul	?öhtupoolikul =öhtupoolikul  (SgN  >öhtupoolikul !19_S	et	f	\N
156801	öhtul	?öhtul =öhtu  (SgAd  >öhtu !01_S	et	f	\N
156802	öhtul	?öhtul =öhtul  (SgN  >öhtul !02_S	et	f	\N
156809	riiasse	?riiasse =riia  (SgIll  >riia !16_S	et	f	\N
156810	riiasse	?riiasse =riiasse  (SgG  >riiasne !02_A	et	f	\N
156811	riiasse	?riiasse =riiasse  (PlP  >riiass !22_S	et	f	\N
156812	kesklinnasse	kesklinnasse =asse  (PlP  >kesk+linn+ass !22_S	et	f	\N
156813	kesklinnasse	kesklinnasse =linna  (SgIll  >kesk+linn !22_S	et	f	\N
156835	püühapaeval	?püühapaeval =püühapaeva  (SgAd  >püühapaeva !16_S	et	f	\N
156836	püühapaeval	?püühapaeval =püühapaeval  (SgN  >püühapaeval !02_S	et	f	\N
156851	eelmiselkümnendal	?eelmiselkümnendal =eelmiselkümnenda  (SgAd  >eelmiselkümnenda !16_S	et	f	\N
156852	eelmiselkümnendal	?eelmiselkümnendal =eelmiselkümnendal  (SgN  >eelmiselkümnendal !02_S	et	f	\N
156853	eelmiselkümnendal	?eelmiselkümnendal =elkümnenda  (SgAd  >eel+mis+elkümnenda !16_S	et	f	\N
156854	eelmiselkümnendal	?eelmiselkümnendal =elkümnendal  (SgN  >eel+mis+elkümnendal !02_S	et	f	\N
156857	heeliloomingu	?heeliloomingu =heeliloomingu  (SgG  >heelilooming !02_S	et	f	\N
156858	heeliloomingu	?heeliloomingu =heeliloomingu  (IndPrPs_  >heeliloominguma !27_V	et	f	\N
156859	heeliloomingu	?heeliloomingu =heeliloomingu  (ImpPrSg2  >heeliloominguma !27_V	et	f	\N
156865	julgemaks	julgemaks =julge  (SupTr  >julgema !27_V	et	f	\N
156866	julgemaks	julgemaks =julgema  (SgTr  >julgem !02_A	et	f	\N
156867	julgemaks	"julgem %julge  )M_cA  <julge ;01_A	et	f	\N
156868	julgemaks	julgemaks =maks  (SgN  >julge+maks !22_S	et	f	\N
156873	kritiliste	?kritiliste =kritilis  (PlG  >kritilis !11_S	et	f	\N
156874	kritiliste	?kritiliste =kritilis  (PlG  >kritiline !12_A	et	f	\N
156875	kritiliste	?kritiliste =kritiliste  (PlP  >kritilist !22_S	et	f	\N
156897	sotsiaaldemokraatid	?sotsiaaldemokraatid =sotsiaaldemokraati  (PlN  >sotsiaaldemokraati !16_S	et	f	\N
156898	sotsiaaldemokraatid	?sotsiaaldemokraatid =demokraati  (PlN  >sotsiaal+demokraati !16_S	et	f	\N
156907	kaitsmise	kaitsmise =kaitsmise  (SgG  >kaitsmine !12?10_S	et	f	\N
156908	kaitsmise	"kaitsmine %kaits  )MINE_vS  <kaitsma ;32_V	et	f	\N
156922	riskis	riskis =riski  (SgIn  >risk !22_S	et	f	\N
156923	riskis	riskis =riski  (IndIpfSg3  >riskima !28_V	et	f	\N
156932	sünnimaa	sünnimaa =maa  (SgN  >sünni+maa !26_S	et	f	\N
156933	sünnimaa	sünnimaa =maa  (SgG  >sünni+maa !26_S	et	f	\N
156936	häbenevad	häbenevad =häbene  (IndPrPl3  >häbenema !27_V	et	f	\N
156937	häbenevad	häbenevad =häbeneva  (PlN  >häbenev !02_A	et	f	\N
156938	häbenevad	"häbenev %häbene  )V_vA  <häbenema ;27_V	et	f	\N
156944	madalamad	madalamad =madalama  (PlN  >madalam !02_A	et	f	\N
156945	madalamad	"madalam %madala  )M_cA  <madal ;02_AS	et	f	\N
156953	näitlejal	näitlejal =näitleja  (SgAd  >näitleja !01_S	et	f	\N
156954	näitlejal	"näitleja %näitle  )JA_vS  <näitlema ;30_V	et	f	\N
156979	161k	### 161k	et	f	\N
156845	hinnatõusu	hinnatõusu =tõusu  (SgAdt  >hinna+tõus !22_S	et	f	\N
156849	fg	### fg	et	f	\N
156860	kujutava	kujutava =kujutava  (SgG  >kujutav !02_A	et	f	\N
156861	kujutava	"kujutav %kujuta  )V_vA  <kujutama ;27_V	et	f	\N
156862	kujutava	kujutava =tava  (SgN  >kuju+tava !17_S	et	f	\N
156863	kujutava	kujutava =tava  (SgG  >kuju+tava !17_S	et	f	\N
156864	kujutava	kujutava =tava  (SgP  >kuju+tava !17_S	et	f	\N
156872	istalin	?istalin =istalin  (SgN  >istalin !19_S	et	f	\N
156880	arvustus	arvustus =arvustus  (SgN  >arvustus !11_S	et	f	\N
156881	arvustus	"arvustus %arvusta  )US_vS  <arvustama ;27_V	et	f	\N
156882	arvustus	arvustus =ustu  (SgIn  >arv+ustu !01_S	et	f	\N
156888	sotsiaaldemokraatia	sotsiaaldemokraatia =demokraatia  (SgN  >sotsiaal+demokraatia !01_S	et	f	\N
156889	sotsiaaldemokraatia	sotsiaaldemokraatia =demokraatia  (SgG  >sotsiaal+demokraatia !01_S	et	f	\N
156911	mõistis	mõistis =mõist  (IndIpfSg3  >mõistma !34_V	et	f	\N
156912	mõistis	mõistis =mõisti  (SgIn  >mõist !22_S	et	f	\N
156915	sõltumatuse	sõltumatuse =sõltumatuse  (SgG  >sõltumatus !11?09_S	et	f	\N
156916	sõltumatuse	"sõltumatus %sõltu  )MATUS_aS  <sõltuma ;27_V	et	f	\N
156934	tanapäevases	?tanapäevases =tanapäevase  (SgIn  >tanapäevane !12_A	et	f	\N
156935	nil	### nil	et	f	\N
156951	mängival	mängival =mängiva  (SgAd  >mängiv !02_A	et	f	\N
156952	mängival	"mängiv %mängi  )V_vA  <mängima ;28_V	et	f	\N
156968	episoodi	episoodi =episoodi  (SgG  >episood !22_S	et	f	\N
156969	episoodi	episoodi =episoodi  (SgP  >episood !22_S	et	f	\N
156970	episoodi	episoodi =episoodi  (SgAdt  >episood !22_S	et	f	\N
156971	lenenis	?lenenis =leneni  (SgIn  >lenen !02_S	et	f	\N
156972	lenenis	?lenenis =lenenis  (SgN  >lenenis !11_S	et	f	\N
156973	teisikku	?teisikku =teisikku  (SgN  >teisikku !01_S	et	f	\N
156974	teisikku	?teisikku =teisikku  (SgG  >teisikku !01_S	et	f	\N
156975	teisikku	?teisikku =teisikku  (IndPrPs_  >teisikkuma !27_V	et	f	\N
156976	teisikku	?teisikku =teisikku  (ImpPrSg2  >teisikkuma !27_V	et	f	\N
156977	teisikku	?teisikku =ikku  (SgP  >teis+ikk !22_S	et	f	\N
156978	teisikku	?teisikku =ikku  (SgAdt  >teis+ikk !22_S	et	f	\N
156987	sünnimaad	sünnimaad =maa  (PlN  >sünni+maa !26_S	et	f	\N
156988	sünnimaad	sünnimaad =maa  (SgP  >sünni+maa !26_S	et	f	\N
157002	nooremate	nooremate =noorema  (PlG  >noorem !02_A	et	f	\N
157003	nooremate	"noorem %noore  )M_cA  <noor ;13_AS	et	f	\N
157004	nooremate	nooremate =mate  (SgN  >noore+mate !16_S	et	f	\N
157005	nooremate	nooremate =mate  (SgG  >noore+mate !16_S	et	f	\N
157012	valdkonnast	valdkonnast =valdkonna  (SgEl  >valdkond !22_S	et	f	\N
157013	valdkonnast	valdkonnast =valdkonnas  (SgP  >valdkonnane !12_A	et	f	\N
157014	valdkonnast	"valdkonnane %valdkonna  )NE_aA  <valdkond ;22_S	et	f	\N
157015	valdkonnast	valdkonnast =konna  (SgEl  >vald+konn !22_S	et	f	\N
157016	valdkonnast	valdkonnast =konnas  (SgP  >vald+konnane !10_A	et	f	\N
157017	valdkonnast	"vald+konnane %konna  )NE_aA  <vald+konn ;22_S	et	f	\N
157019	kasvatamisviisi	?kasvatamisviisi =kasvatamisviisi  (SgN  >kasvatamisviisi !16_S	et	f	\N
157021	kasvatamisviisi	?kasvatamisviisi =kasvatamisviisi  (SgG  >kasvatamisviisi !16_S	et	f	\N
157023	kasvatamisviisi	?kasvatamisviisi =kasvatamisviisi  (SgG  >kasvatamisviis !22_S	et	f	\N
157024	kasvatamisviisi	?kasvatamisviisi =kasvatamisviisi  (SgP  >kasvatamisviis !22_S	et	f	\N
157025	kasvatamisviisi	?kasvatamisviisi =kasvatamisviisi  (SgAdt  >kasvatamisviis !22_S	et	f	\N
157026	kasvatamisviisi	?kasvatamisviisi =kasvatamisviisi  (IndPrPs_  >kasvatamisviisima !28_V	et	f	\N
157027	kasvatamisviisi	?kasvatamisviisi =kasvatamisviisi  (ImpPrSg2  >kasvatamisviisima !28_V	et	f	\N
157028	kasvatamisviisi	?kasvatamisviisi =vatamisviisi  (SgN  >kas+vatamisviisi !16_S	et	f	\N
157029	kasvatamisviisi	?kasvatamisviisi =vatamisviisi  (SgG  >kas+vatamisviisi !16_S	et	f	\N
157030	kasvatamisviisi	?kasvatamisviisi =vatamisviisi  (SgG  >kas+vatamisviis !22_S	et	f	\N
157031	kasvatamisviisi	?kasvatamisviisi =vatamisviisi  (SgP  >kas+vatamisviis !22_S	et	f	\N
157032	kasvatamisviisi	?kasvatamisviisi =vatamisviisi  (SgAdt  >kas+vatamisviis !22_S	et	f	\N
157039	värvides	värvides =värvi  (PlIn  >värv !22_S	et	f	\N
157040	värvides	värvides =värvi  (Ger  >värvima !28_V	et	f	\N
157048	lillei	?lillei =lillei  (SgN  >lillei !26_S	et	f	\N
157049	lillei	?lillei =lillei  (SgG  >lillei !26_S	et	f	\N
157060	vastutuslik	?vastutuslik =vastutuslik  (SgN  >vastutuslik !25_A	et	f	\N
157061	vastutuslik	?vastutuslik =tuslik  (SgN  >vastu+tuslik !25_A	et	f	\N
157062	vastutuslik	?vastutuslik =utuslik  (SgN  >vast+utuslik !25_A	et	f	\N
157072	trennin	?trennin =trenni  (IndPrSg1  >trennima !28_V	et	f	\N
157073	trennin	?trennin =trennin  (SgN  >trennin !02_S	et	f	\N
157074	sõ	### sõ	et	f	\N
157087	nägud	?nägud =nägu  (IndPrSg2  >näguma !27_V	et	f	\N
157091	söö	söö =söö  (IndPrPs_  >sööma !38_V	et	f	\N
157092	söö	söö =söö  (ImpPrSg2  >sööma !38_V	et	f	\N
157096	erisuguselt	erisuguselt =suguse  (SgAbl  >eri+sugune !10_A	et	f	\N
157097	erisuguselt	"eri+suguselt %suguse  )LT_mD  <eri+sugune ;10_A	et	f	\N
157117	pankoogid	?pankoogid =pankoogi  (PlN  >pankoogi !16_S	et	f	\N
157118	pankoogid	?pankoogid =pankoogi  (PlN  >pankoog !22_S	et	f	\N
157119	pankoogid	?pankoogid =pankoogi  (IndPrSg2  >pankoogima !28_V	et	f	\N
156928	omakasupüüdlematu	omakasupüüdlematu =püüdlematu  (SgN  >oma+kasu+püüdlematu !01_A	et	f	\N
156929	omakasupüüdlematu	omakasupüüdlematu =püüdlematu  (SgG  >oma+kasu+püüdlematu !01_A	et	f	\N
156960	tähtsusetust	tähtsusetust =tähtsusetu  (SgEl  >tähtsusetu !01_A	et	f	\N
156961	tähtsusetust	"tähtsusetu %tähtsuse  )TU2_kA  <tähtsus ;09_S	et	f	\N
156962	tähtsusetust	"tähtsusetu %tähtsuse  )TU2_kA  <tähtsus ;11_S	et	f	\N
156963	tähtsusetust	tähtsusetust =tähtsusetus  (SgP  >tähtsusetus !11?09_S	et	f	\N
156964	tähtsusetust	"tähtsusetus %tähtsuse  )TUS2_aS  <tähtsus ;09_S	et	f	\N
156965	tähtsusetust	"tähtsusetus %tähtsuse  )TUS2_aS  <tähtsus ;11_S	et	f	\N
156966	käitumises	käitumises =käitumise  (SgIn  >käitumine !12_S	et	f	\N
156967	käitumises	"käitumine %käitu  )MINE_vS  <käituma ;27_V	et	f	\N
156997	hundiseaduste	hundiseaduste =duste  (PlP  >hundi+sea+dust !22_S	et	f	\N
156998	hundiseaduste	hundiseaduste =seadus  (PlG  >hundi+seadus !11~09_S	et	f	\N
157053	sõberpalub	?sõberpalub =sõberpalu  (IndPrSg3  >sõberpaluma !27_V	et	f	\N
157056	sellistesse	sellistesse =sellis  (PlIll  >selline !10_P	et	f	\N
157057	sellistesse	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
157080	väisamine	väisamine =väisamine  (SgN  >väisamine !12_S	et	f	\N
157081	väisamine	"väisamine %väisa  )MINE_vS  <väisama ;29_V	et	f	\N
157084	õetütrelega	?õetütrelega =lega  (SgN  >õe+tütre+lega !17_S	et	f	\N
157085	õetütrelega	?õetütrelega =lega  (SgG  >õe+tütre+lega !17_S	et	f	\N
157086	õetütrelega	?õetütrelega =lega  (SgP  >õe+tütre+lega !17_S	et	f	\N
157095	suppid	### suppid	et	f	\N
157106	hingelise	hingelise =hingelise  (SgG  >hingeline !12_SA	et	f	\N
157107	hingelise	"hingeline %hinge  )LINE_aA  <hing ;22_S	et	f	\N
157157	tunnistust	tunnistust =tunnistus  (SgP  >tunnistus !11_S	et	f	\N
157158	tunnistust	"tunnistus %tunnista  )US_vS  <tunnistama ;27_V	et	f	\N
157159	tunnistust	tunnistust =tust  (SgN  >tunnis+tust !22_S	et	f	\N
157166	koostajatelt	koostajatelt =koostaja  (PlAbl  >koostaja !01_S	et	f	\N
157167	koostajatelt	"koostaja %koosta  )JA_vS  <koostama ;27_V	et	f	\N
157168	rsid	### rsid	et	f	\N
157169	erip	?erip =erip  (SgN  >erip !02_S	et	f	\N
157175	ü	### ü	et	f	\N
157197	nd	### nd	et	f	\N
157211	nekeeles	?nekeeles =nekeele  (SgIn  >nekeele !16_S	et	f	\N
157212	nekeeles	?nekeeles =nekeele  (PlIn  >nekeel !22_S	et	f	\N
157213	nekeeles	?nekeeles =nekeele  (IndIpfSg3  >nekeelema !27_V	et	f	\N
157249	gu	### gu	et	f	\N
157254	lba	### lba	et	f	\N
157255	rk	### rk	et	f	\N
157267	nnetust	?nnetust =nnetu  (SgEl  >nnetu !16_S	et	f	\N
157268	nnetust	?nnetust =nnetus  (SgP  >nnetus !09_S	et	f	\N
157272	lastada	### lastada	et	f	\N
157276	ndinule	?ndinule =ndinu  (SgAll  >ndinu !17_S	et	f	\N
157277	ndinule	?ndinule =ndinule  (IndPrPs_  >ndinulema !27_V	et	f	\N
157278	ndinule	?ndinule =ndinule  (ImpPrSg2  >ndinulema !27_V	et	f	\N
157285	liselanikelt	?liselanikelt =liselanikelt  (ID  >liselanikelt !41_D	et	f	\N
157290	naberk	?naberk =naberk  (SgN  >naberk !22_S	et	f	\N
157294	summary	### summary	et	f	\N
157303	hilisemal	hilisemal =hilisema  (SgAd  >hilisem !02_A	et	f	\N
157304	hilisemal	"hilisem %hilise  )M_cA  <hiline ;10_A	et	f	\N
157305	hilisemal	hilisemal =ema  (SgAd  >hilis+ema !17_S	et	f	\N
157319	jälgisid	jälgisid =jälgi  (PlP  >jälg !22_S	et	f	\N
157320	jälgisid	jälgisid =jälgi  (IndIpfSg2  >jälgima !27_V	et	f	\N
157321	jälgisid	jälgisid =jälgi  (IndIpfPl3  >jälgima !27_V	et	f	\N
157333	õnenstub	?õnenstub =õnenstu  (IndPrSg3  >õnenstuma !27_V	et	f	\N
157350	taasavamine	taasavamine =avamine  (SgN  >taas+avamine !12_S	et	f	\N
157351	taasavamine	"taas+avamine %ava  )MINE_vS  <taas+avama ;27_V	et	f	\N
157352	hakasid	?hakasid =haka  (PlP  >haka !16_S	et	f	\N
157353	hakasid	?hakasid =haka  (IndIpfSg2  >hakama !27_V	et	f	\N
157354	hakasid	?hakasid =haka  (IndIpfPl3  >hakama !27_V	et	f	\N
157375	päriseks	päriseks =päriseks  (ID  >päriseks !41_D	et	f	\N
157376	päriseks	päriseks =seks  (SgN  >päri+seks !22_S	et	f	\N
157381	ketramismasinad	?ketramismasinad =ketramismasina  (PlN  >ketramismasin !19_S	et	f	\N
157416	fonoloogia	fonoloogia =fonoloogia  (SgN  >fonoloogia !01_S	et	f	\N
157417	fonoloogia	fonoloogia =fonoloogia  (SgG  >fonoloogia !01_S	et	f	\N
157433	vastlapäeva	vastlapäeva =päeva  (SgG  >vastla+päev !22_S	et	f	\N
157434	vastlapäeva	vastlapäeva =päeva  (SgP  >vastla+päev !22_S	et	f	\N
157435	vastlapäeva	vastlapäeva =päeva  (SgAdt  >vastla+päev !22_S	et	f	\N
157516	protsessiooni	protsessiooni =protsessiooni  (SgG  >protsessioon !22_S	et	f	\N
157517	protsessiooni	protsessiooni =protsessiooni  (SgP  >protsessioon !22_S	et	f	\N
157518	protsessiooni	protsessiooni =protsessiooni  (SgAdt  >protsessioon !22_S	et	f	\N
157539	rataga	?rataga =rata  (SgKom  >rata !16_S	et	f	\N
157540	ehitamiseks	ehitamiseks =ehitamise  (SgTr  >ehitamine !12_S	et	f	\N
157541	ehitamiseks	"ehitamine %ehita  )MINE_vS  <ehitama ;27_V	et	f	\N
157542	erksam	erksam =erksam  (SgN  >erksam !02_A	et	f	\N
157543	erksam	"erksam %erksa  )M_cA  <ergas ;03_A	et	f	\N
157544	erksam	"erksam %erksa  )M_cA  <ergas ;05_A	et	f	\N
156947	kehastus	kehastus =kehastus  (SgN  >kehastus !11_S	et	f	\N
156948	kehastus	"kehastus %kehasta  )US_vS  <kehastama ;27_V	et	f	\N
156955	abitust	abitust =abitu  (SgEl  >abitu !01_A	et	f	\N
156956	abitust	"abitu %abi  )TU2_kA  <abi ;17_S	et	f	\N
156957	abitust	abitust =abitus  (SgP  >abitus !11_S	et	f	\N
156958	abitust	"abitus %abi  )TUS2_aS  <abi ;17_S	et	f	\N
156959	abitust	abitust =tust  (SgN  >abi+tust !22_S	et	f	\N
156980	hingesse	hingesse =hinge  (SgIll  >hing !22_S	et	f	\N
156981	hingesse	hingesse =hinge  (PlIll  >hink !22_S	et	f	\N
156982	hingesse	hingesse =hinges  (SgAdt  >hingene !12_A	et	f	\N
156983	hingesse	"hingene %hinge  )NE_aA  <hing ;22_S	et	f	\N
156989	monopolijate	?monopolijate =monopolija  (PlG  >monopolija !01_S	et	f	\N
156990	monopolijate	?monopolijate =monopolija  (PlG  >monopolijas !02_A	et	f	\N
156991	monopolijate	?monopolijate =jate  (SgN  >monopoli+jate !06_S	et	f	\N
156992	monopolijate	?monopolijate =polija  (PlG  >mono+polija !01_S	et	f	\N
156993	monopolijate	?monopolijate =polija  (PlG  >mono+polijas !02_A	et	f	\N
156999	arkitektuur	?arkitektuur =arkitektuur  (SgN  >arkitektuur !22_S	et	f	\N
157006	kasvatamine	kasvatamine =kasvatamine  (SgN  >kasvatamine !12_S	et	f	\N
157007	kasvatamine	"kasvatamine %kasvata  )MINE_vS  <kasvatama ;27_V	et	f	\N
157033	sünnist	sünnist =sünni  (SgEl  >sünd !22_S	et	f	\N
157034	sünnist	sünnist =sünnis  (SgP  >sünnis !05_A	et	f	\N
157035	tüüpilisem	tüüpilisem =tüüpilisem  (SgN  >tüüpilisem !02_A	et	f	\N
157036	tüüpilisem	"tüüpilisem %tüüpilise  )M_cA  <tüüpiline ;12_A	et	f	\N
157045	tuttaval	tuttaval =tuttava  (SgAd  >tuttav !02_AS	et	f	\N
157046	tuttaval	tuttaval =ava  (SgAd  >tutt+ava !17_S	et	f	\N
157047	tuttaval	tuttaval =aval  (SgN  >tutt+aval !02_A	et	f	\N
157069	maadleja	maadleja =maadleja  (SgN  >maadleja !01_S	et	f	\N
157070	maadleja	"maadleja %maadle  )JA_vS  <maadlema ;30_V	et	f	\N
157071	maadleja	maadleja =maadleja  (SgG  >maadleja !01_S	et	f	\N
157088	abikaasale	abikaasale =ale  (SgN  >abi+kaas+ale !16_S	et	f	\N
157089	abikaasale	abikaasale =ale  (SgG  >abi+kaas+ale !16_S	et	f	\N
157090	abikaasale	abikaasale =kaasa  (SgAll  >abi+kaasa !16_S	et	f	\N
157110	pirukadega	### pirukadega	et	f	\N
157123	ristmikusel	?ristmikusel =ristmikuse  (SgAd  >ristmikus !11_S	et	f	\N
157124	ristmikusel	?ristmikusel =mikuse  (SgAd  >rist+mikus !09_S	et	f	\N
157125	ristmikusel	?ristmikusel =mikusel  (SgN  >rist+mikusel !19_S	et	f	\N
157128	vanaususulised	vanaususulised =sulise  (PlN  >vana+usu+suline !10_A	et	f	\N
157129	vanaususulised	"vana+usu+suline %suli  )NE_aA  <vana+usu+suli ;17_S	et	f	\N
157143	elatusallikast	elatusallikast =ast  (SgN  >elatus+allik+ast !22_S	et	f	\N
157144	elatusallikast	elatusallikast =allika  (SgEl  >elatus+allikas !02_S	et	f	\N
157145	elatusallikast	elatusallikast =allikas  (SgP  >elatus+allikane !12_A	et	f	\N
157146	elatusallikast	"elatus+allikane %allika  )NE_aA  <elatus+allikas ;02_S	et	f	\N
157147	vanausulistele	vanausulistele =usulis  (PlAll  >vana+usuline !12_A	et	f	\N
157148	vanausulistele	"vana+usuline %usu  )LINE_aA  <vana+usk ;22_S	et	f	\N
157154	lasumisest	lasumisest =lasumise  (SgEl  >lasumine !12_S	et	f	\N
157155	lasumisest	"lasumine %lasu  )MINE_vS  <lasuma ;27_V	et	f	\N
157156	lasumisest	"lasumine %lasumi  )NE_aA  <lasum ;02_S	et	f	\N
157173	kalendriaasta	kalendriaasta =aasta  (SgN  >kalendri+aasta !01_S	et	f	\N
157174	kalendriaasta	kalendriaasta =aasta  (SgG  >kalendri+aasta !01_S	et	f	\N
157176	nnitus-ristimise	nnitus-ristimise =ristimise  (SgG  >nnitus-ristimine !12_S	et	f	\N
157177	nnitus-ristimise	"nnitus-ristimine %risti  )MINE_vS  <nnitus-ristima ;28_V	et	f	\N
157185	rimused	?rimused =rimuse  (PlN  >rimus !09_S	et	f	\N
157194	ras	### ras	et	f	\N
157199	lastefolkloor	lastefolkloor =loor  (SgN  >laste+folk+loor !22_S	et	f	\N
157200	lastefolkloor	lastefolkloor =folkloor  (SgN  >laste+folkloor !22_S	et	f	\N
157210	sti	### sti	et	f	\N
157215	laens	?laens =laens  (SgN  >laens !22_S	et	f	\N
157217	nede	?nede =nede  (SgN  >nede !16_S	et	f	\N
157218	nede	?nede =nede  (SgG  >nede !16_S	et	f	\N
157219	nede	?nede =nede  (IndPrPs_  >nedema !27_V	et	f	\N
157220	nede	?nede =nede  (ImpPrSg2  >nedema !27_V	et	f	\N
157230	igis	?igis =igi  (SgIn  >igi !17_S	et	f	\N
157231	igis	?igis =igi  (IndIpfSg3  >igima !27_V	et	f	\N
157232	igis	?igis =igis  (SgN  >igis !09_S	et	f	\N
157242	etud	?etud =etu  (PlN  >etu !16_S	et	f	\N
157243	etud	?etud =etu  (IndPrSg2  >etuma !27_V	et	f	\N
157247	ht	### ht	et	f	\N
157251	keskp	?keskp =keskp  (SgN  >keskp !22_S	et	f	\N
157252	eval	?eval =eva  (SgAd  >eva !17_S	et	f	\N
157253	eval	?eval =eval  (SgN  >eval !02_S	et	f	\N
157279	listatud	?listatud =lista  (PtsPtIps  >listama !29_V	et	f	\N
157280	listatud	?listatud =listatu  (PlN  >listatu !01_S	et	f	\N
157281	listatud	?listatud =listatu  (IndPrSg2  >listatuma !27_V	et	f	\N
157282	listatud	?listatud =listatud  (ID  >listatud !41_A	et	f	\N
157286	rdusid	?rdusid =rdusi  (PlN  >rdusi !17_S	et	f	\N
157287	rdusid	?rdusid =rdusi  (IndPrSg2  >rdusima !27_V	et	f	\N
157298	kiviajast	kiviajast =aja  (SgEl  >kivi+aeg !22_S	et	f	\N
157299	kiviajast	kiviajast =ajas  (SgP  >kivi+ajane !10_A	et	f	\N
156984	lavastaja	lavastaja =lavastaja  (SgN  >lavastaja !01_S	et	f	\N
156985	lavastaja	"lavastaja %lavasta  )JA_vS  <lavastama ;27_V	et	f	\N
156986	lavastaja	lavastaja =lavastaja  (SgG  >lavastaja !01_S	et	f	\N
157010	ühestvõi	ühestvõi =või  (SgN  >ühest+või !26_S	et	f	\N
157011	ühestvõi	ühestvõi =või  (SgG  >ühest+või !26_S	et	f	\N
157018	käitumisviisi	käitumisviisi =viisi  (SgG  >käitumis+viis !22_S	et	f	\N
157020	käitumisviisi	käitumisviisi =viisi  (SgP  >käitumis+viis !22_S	et	f	\N
157022	käitumisviisi	käitumisviisi =viisi  (SgAdt  >käitumis+viis !22_S	et	f	\N
157037	mulgi	mulgi =mulgi  (SgG  >mulk !22_S	et	f	\N
157038	mulgi	mulgi =mu  (SgAd^  >ma !00_P	et	f	\N
157043	pöördan	?pöördan =pöörda  (IndPrSg1  >pöördama !27_V	et	f	\N
157044	pöördan	?pöördan =pöördan  (SgN  >pöördan !02_S	et	f	\N
157063	aidatan	?aidatan =aidata  (IndPrSg1  >aidatama !27_V	et	f	\N
157064	aidatan	?aidatan =aidatan  (SgN  >aidatan !19_S	et	f	\N
157076	hetki	hetki =hetki  (SgG  >hetk !22_S	et	f	\N
157077	hetki	hetki =hetki  (SgP  >hetk !22_S	et	f	\N
157078	hetki	hetki =hetki  (SgAdt  >hetk !22_S	et	f	\N
157079	hetki	hetki =hetki  (PlP  >hetk !22_S	et	f	\N
157082	väisamiseks	väisamiseks =väisamise  (SgTr  >väisamine !12_S	et	f	\N
157083	väisamiseks	"väisamine %väisa  )MINE_vS  <väisama ;29_V	et	f	\N
157093	standardikohase	?standardikohase =standardikohase  (SgG  >standardikohane !12_A	et	f	\N
157094	standardikohase	?standardikohase =ikohase  (SgG  >standard+ikohane !12_A	et	f	\N
157098	kookid	### kookid	et	f	\N
157126	uurimustöö	uurimustöö =töö  (SgN  >uurimus+töö !26_S	et	f	\N
157127	uurimustöö	uurimustöö =töö  (SgG  >uurimus+töö !26_S	et	f	\N
157130	talletatud	talletatud =talleta  (PtsPtIps  >talletama !27_V	et	f	\N
157131	talletatud	talletatud =talletatu  (PlN  >talletatu !01_S	et	f	\N
157132	talletatud	"talletatu %talleta  )TU1_vS  <talletama ;27_V	et	f	\N
157133	talletatud	talletatud =talletatud  (ID  >talletatud !41_A	et	f	\N
157134	talletatud	"talletatud %talleta  )TUD_vA  <talletama ;27_V	et	f	\N
157139	pajatustega	pajatustega =pajatus  (PlKom  >pajatus !11_S	et	f	\N
157140	pajatustega	"pajatus %pajata  )US_vS  <pajatama ;27_V	et	f	\N
157141	pajatustega	"pajatus %paja  )TUS2_aS  <paja ;17_S	et	f	\N
157142	pajatustega	"pajatus %paja  )TUS2_aS  <pada ;18_S	et	f	\N
157160	järjepidevusest	järjepidevusest =pidevuse  (SgEl  >järje+pidevus !11_S	et	f	\N
157161	järjepidevusest	"järje+pidevus %pideva  )US_aS  <järje+pidev ;02_A	et	f	\N
157162	järjepidevusest	järjepidevusest =pidevuses  (SgP  >järje+pidevusene !12_A	et	f	\N
157163	järjepidevusest	"järje+pidevusene %pidevuse  )NE_aA  <järje+pidevus ;11_S	et	f	\N
157178	matusetalitus	matusetalitus =talitu  (SgIn  >matuse+talitu !01_AS	et	f	\N
157179	matusetalitus	"matuse+talitu %tali  )TU2_kA  <matuse+tali ;17_S	et	f	\N
157180	matusetalitus	matusetalitus =talitus  (SgN  >matuse+talitus !11_S	et	f	\N
157181	matusetalitus	"matuse+talitus %tali  )TUS2_aS  <matuse+tali ;17_S	et	f	\N
157186	toloogilised	?toloogilised =toloogilise  (PlN  >toloogiline !12_A	et	f	\N
157190	posimine	posimine =posimine  (SgN  >posimine !12_S	et	f	\N
157191	posimine	"posimine %posi  )MINE_vS  <posima ;27_V	et	f	\N
157196	nek	### nek	et	f	\N
157198	istatused	?istatused =istatuse  (PlN  >istatus !11_S	et	f	\N
157208	ppinud	?ppinud =ppinu  (PlN  >ppinu !17_S	et	f	\N
157209	ppinud	?ppinud =ppinu  (IndPrSg2  >ppinuma !27_V	et	f	\N
157214	pris	### pris	et	f	\N
157216	nu	### nu	et	f	\N
157225	paptist	?paptist =papti  (SgEl  >papti !16_S	et	f	\N
157226	paptist	?paptist =papti  (SgEl  >papt !22_S	et	f	\N
157227	paptist	?paptist =paptis  (SgP  >paptis !09_S	et	f	\N
157228	paptist	?paptist =paptist  (SgN  >paptist !22_S	et	f	\N
157256	htune	?htune =htune  (SgN  >htune !16_S	et	f	\N
157257	htune	?htune =htune  (SgG  >htune !16_S	et	f	\N
157258	htune	?htune =htune  (IndPrPs_  >htunema !27_V	et	f	\N
157259	htune	?htune =htune  (ImpPrSg2  >htunema !27_V	et	f	\N
157260	tshehhi	?tshehhi =tshehhi  (SgN  >tshehhi !16_S	et	f	\N
157261	tshehhi	?tshehhi =tshehhi  (SgG  >tshehhi !16_S	et	f	\N
157262	tshehhi	?tshehhi =tshehhi  (SgG  >tshehh !22_S	et	f	\N
157263	tshehhi	?tshehhi =tshehhi  (SgP  >tshehh !22_S	et	f	\N
157264	tshehhi	?tshehhi =tshehhi  (SgAdt  >tshehh !22_S	et	f	\N
157265	tshehhi	?tshehhi =tshehhi  (IndPrPs_  >tshehhima !28_V	et	f	\N
157266	tshehhi	?tshehhi =tshehhi  (ImpPrSg2  >tshehhima !28_V	et	f	\N
157273	nnitajat	?nnitajat =nnitaja  (SgP  >nnitaja !01_S	et	f	\N
157274	nnitajat	?nnitajat =nnitaja  (SgP  >nnitajas !02_A	et	f	\N
157284	tnud	### tnud	et	f	\N
157288	gitud	?gitud =gitu  (PlN  >gitu !16_S	et	f	\N
157289	gitud	?gitud =gitu  (IndPrSg2  >gituma !27_V	et	f	\N
157295	varasemast	varasemast =varasema  (SgEl  >varasem !02_A	et	f	\N
157296	varasemast	"varasem %vara  )SEM_cA  <vara ;17_S	et	f	\N
157297	varasemast	"varasem %varase  )M_cA  <varane ;10_A	et	f	\N
157306	aastatuhandel	?aastatuhandel =aastatuhande  (PlAd  >aastatuhant !22_S	et	f	\N
157307	aastatuhandel	?aastatuhandel =tuhande  (PlAd  >aasta+tuhant !22_S	et	f	\N
157308	aastatuhandel	?aastatuhandel =tatuhande  (PlAd  >aas+tatuhant !22_S	et	f	\N
157099	sealalati	?sealalati =sealalati  (SgG  >sealalatt !22_S	et	f	\N
157100	sealalati	?sealalati =sealalati  (IndPrPs_  >sealalattima !28_V	et	f	\N
157101	sealalati	?sealalati =sealalati  (ImpPrSg2  >sealalattima !28_V	et	f	\N
157102	sealalati	?sealalati =alati  (SgG  >seal+alat !02_S	et	f	\N
157103	sealalati	?sealalati =alati  (SgG  >seal+alatt !22_S	et	f	\N
157104	sealalati	?sealalati =lalati  (SgG  >sea+lalat !02_S	et	f	\N
157105	sealalati	?sealalati =lalati  (SgG  >sea+lalatt !22_S	et	f	\N
157108	koogidega	?koogidega =koogi  (PlKom  >koogi !16_S	et	f	\N
157109	koogidega	?koogidega =koogi  (PlKom  >koog !22_S	et	f	\N
157111	gruppinaabridega	### gruppinaabridega	et	f	\N
157112	maksmisest	maksmisest =maksmise  (SgEl  >maksmine !12?10_S	et	f	\N
157113	maksmisest	"maksmine %maks  )MINE_vS  <maksma ;32_V	et	f	\N
157114	maitsvad	maitsvad =maitsva  (PlN  >maitsev !02_A	et	f	\N
157115	maitsvad	"maitsev %maits  )V_vA  <maitsma ;32_V	et	f	\N
157116	maitsvad	"maitsev %maitse  )V_vA  <maitsema ;28_V	et	f	\N
157149	meditsiinipärimusest	meditsiinipärimusest =pärimuse  (SgEl  >meditsiini+pärimus !11_S	et	f	\N
157150	meditsiinipärimusest	meditsiinipärimusest =pärimuses  (SgP  >meditsiini+pärimusene !12_A	et	f	\N
157151	meditsiinipärimusest	"meditsiini+pärimusene %pärimuse  )NE_aA  <meditsiini+pärimus ;11_S	et	f	\N
157164	mõistatusd	?mõistatusd =mõistatusd  (SgN  >mõistatusd !22_S	et	f	\N
157165	mõistatusd	?mõistatusd =tusd  (SgN  >mõista+tusd !22_S	et	f	\N
157171	kalastus	kalastus =kalastus  (SgN  >kalastus !11_S	et	f	\N
157172	kalastus	"kalastus %kalasta  )US_vS  <kalastama ;27_V	et	f	\N
157182	lestustavad	?lestustavad =lestusta  (IndPrPl3  >lestustama !27_V	et	f	\N
157183	lestustavad	?lestustavad =lestustava  (PlN  >lestustav !02_A	et	f	\N
157184	lestustavad	?lestustavad =lestustava  (PlN  >lestustava !16_S	et	f	\N
157187	rgid	### rgid	et	f	\N
157192	ias	?ias =ia  (SgIn  >ia !26_S	et	f	\N
157193	ias	?ias =ias  (SgN  >ias !22_S	et	f	\N
157195	namisest	?namisest =namise  (SgEl  >namine !10_A	et	f	\N
157201	meisterlikkuse	meisterlikkuse =meisterlikkuse  (SgG  >meisterlikkus !11~09_S	et	f	\N
157202	meisterlikkuse	"meisterlikkus %meisterlikku  )US_aS  <meisterlik ;25_A	et	f	\N
157203	erirõivastes	erirõivastes =rõivas  (PlIn  >eri+rõivas !07_S	et	f	\N
157204	erirõivastes	erirõivastes =rõivas  (PlIn  >eri+rõivane !10_A	et	f	\N
157205	erirõivastes	"eri+rõivane %rõiva  )NE_aA  <eri+rõivas ;07_S	et	f	\N
157206	ldjuhul	?ldjuhul =ldjuhu  (SgAd  >ldjuhu !17_S	et	f	\N
157207	ldjuhul	?ldjuhul =ldjuhul  (SgN  >ldjuhul !02_S	et	f	\N
157229	bi	### bi	et	f	\N
157233	rimusjutt	?rimusjutt =rimusjutt  (SgN  >rimusjutt !22_S	et	f	\N
157236	mnes	### mnes	et	f	\N
157237	putu	?putu =putu  (SgN  >putu !16_S	et	f	\N
157238	putu	?putu =putu  (SgG  >putu !16_S	et	f	\N
157239	putu	?putu =putu  (IndPrPs_  >putuma !27_V	et	f	\N
157240	putu	?putu =putu  (ImpPrSg2  >putuma !27_V	et	f	\N
157241	le	### le	et	f	\N
157245	hjusel	?hjusel =hjuse  (SgAd  >hjuse !16_S	et	f	\N
157246	hjusel	?hjusel =hjusel  (SgN  >hjusel !02_S	et	f	\N
157250	nneks	?nneks =nneks  (SgN  >nneks !22_S	et	f	\N
157283	ilitada	?ilitada =ilita  (Inf  >ilitama !27_V	et	f	\N
157309	aastatuhandel	?aastatuhandel =aastatuhande  (PlAd  >aastatuhant !22_S	et	f	\N
157310	aastatuhandel	?aastatuhandel =tuhande  (PlAd  >aasta+tuhant !22_S	et	f	\N
157311	aastatuhandel	?aastatuhandel =tatuhande  (PlAd  >aas+tatuhant !22_S	et	f	\N
157329	taevast	taevast =taeva  (SgEl  >taevas !07_S	et	f	\N
157330	taevast	taevast =taevas  (SgP  >taevas !07_S	et	f	\N
157331	taevast	taevast =taevas  (SgP  >taevane !10~12_A	et	f	\N
157332	taevast	"taevane %taeva  )NE_aA  <taevas ;07_S	et	f	\N
157336	baikaalilt	?baikaalilt =baikaali  (SgAbl  >baikaali !16_S	et	f	\N
157337	baikaalilt	?baikaalilt =baikaali  (SgAbl  >baikaal !22_S	et	f	\N
157339	leidude	leidude =leidu  (PlG  >leid !22_S	et	f	\N
157340	leidude	leidude =ude  (SgN  >leid+ude !04_S	et	f	\N
157348	venestuspoliitika	venestuspoliitika =poliitika  (SgN  >venestus+poliitika !01_S	et	f	\N
157349	venestuspoliitika	venestuspoliitika =poliitika  (SgG  >venestus+poliitika !01_S	et	f	\N
157355	palgatöölisteks	palgatöölisteks =iste  (SgTr  >palga+tööl+iste !06_S	et	f	\N
157356	palgatöölisteks	palgatöölisteks =iste  (PlTr  >palga+tööl+ist !22_S	et	f	\N
157357	palgatöölisteks	palgatöölisteks =töölis  (PlTr  >palga+tööline !12?10_S	et	f	\N
157380	schwartz	### schwartz	et	f	\N
157387	mõisnikutele	?mõisnikutele =mõisniku  (PlAll  >mõisniku !01_S	et	f	\N
157388	mõisnikutele	?mõisnikutele =mõisnikute  (PlAll  >mõisnikutt !22_S	et	f	\N
157389	mõisnikutele	?mõisnikutele =mõisnikutele  (IndPrPs_  >mõisnikutelema !36_V	et	f	\N
157390	mõisnikutele	?mõisnikutele =mõisnikutele  (ImpPrSg2  >mõisnikutelema !36_V	et	f	\N
157392	abistasid	abistasid =abista  (IndIpfSg2  >abistama !27_V	et	f	\N
157393	abistasid	abistasid =abista  (IndIpfPl3  >abistama !27_V	et	f	\N
157398	usu-	usu- =usu  (SgG  >usk !22_S	et	f	\N
157399	usu-	usu- =usu  (IndPrPs_  >uskuma !28_V	et	f	\N
157400	usu-	usu- =usu  (ImpPrSg2  >uskuma !28_V	et	f	\N
157403	trs	### trs	et	f	\N
157406	häälikuline	häälikuline =häälikuline  (SgN  >häälikuline !12_A	et	f	\N
157120	keskplatsi	keskplatsi =platsi  (SgG  >kesk+plats !22_S	et	f	\N
157121	keskplatsi	keskplatsi =platsi  (SgP  >kesk+plats !22_S	et	f	\N
157122	keskplatsi	keskplatsi =platsi  (SgAdt  >kesk+plats !22_S	et	f	\N
157135	arhiveeritud	?arhiveeritud =arhiveeri  (PtsPtIps  >arhiveerima !28_V	et	f	\N
157136	arhiveeritud	?arhiveeritud =arhiveeritu  (PlN  >arhiveeritu !01_S	et	f	\N
157137	arhiveeritud	?arhiveeritud =arhiveeritu  (IndPrSg2  >arhiveerituma !27_V	et	f	\N
157138	arhiveeritud	?arhiveeritud =arhiveeritud  (ID  >arhiveeritud !41_A	et	f	\N
157152	lausujatest	lausujatest =lausuja  (PlEl  >lausuja !01_S	et	f	\N
157153	lausujatest	"lausuja %lausu  )JA_vS  <lausuma ;28_V	et	f	\N
157170	ra	### ra	et	f	\N
157188	olme	olme =olme  (SgN  >olme !06_S	et	f	\N
157189	olme	olme =olme  (SgG  >olme !06_S	et	f	\N
157221	nade	?nade =nade  (SgN  >nade !16_S	et	f	\N
157222	nade	?nade =nade  (SgG  >nade !16_S	et	f	\N
157223	nade	?nade =nade  (IndPrPs_  >nadema !27_V	et	f	\N
157224	nade	?nade =nade  (ImpPrSg2  >nadema !27_V	et	f	\N
157234	kaheteisk	?kaheteisk =kaheteisk  (SgN  >kaheteisk !22_S	et	f	\N
157235	kaheteisk	?kaheteisk =teisk  (SgN  >kahe+teisk !22_S	et	f	\N
157244	imalik	?imalik =imalik  (SgN  >imalik !25_A	et	f	\N
157248	htul	### htul	et	f	\N
157269	igus	?igus =igu  (SgIn  >igu !17_S	et	f	\N
157270	igus	?igus =igu  (IndIpfSg3  >iguma !27_V	et	f	\N
157271	igus	?igus =igus  (SgN  >igus !02_A	et	f	\N
157275	vasts	?vasts =vasts  (SgN  >vasts !22_S	et	f	\N
157291	sikirjas	?sikirjas =sikirja  (SgIn  >sikirjas !02_A	et	f	\N
157292	sikirjas	?sikirjas =sikirja  (SgIn  >sikirja !16_S	et	f	\N
157293	sikirjas	?sikirjas =sikirjas  (SgN  >sikirjas !02_A	et	f	\N
157301	eesvanemad	eesvanemad =vanema  (PlN  >ees+vanem !02_AS	et	f	\N
157302	eesvanemad	"ees+vanem %vane  )M_cA  <ees+vana ;17_AS	et	f	\N
157316	surnul	surnul =surnu  (SgAd  >surnu !01_S	et	f	\N
157317	surnul	"surnu %sur  )NU_vS  <surema ;36_V	et	f	\N
157318	surnul	surnul =surnu  (SgAd  >surnu !06_S	et	f	\N
157334	volgalt	?volgalt =volga  (SgAbl  >volga !16_S	et	f	\N
157335	volgalt	?volgalt =volgalt  (ID  >volgalt !41_D	et	f	\N
157338	inimgruppile	### inimgruppile	et	f	\N
157358	mõisadel	?mõisadel =mõisa  (PlAd  >mõisa !16_S	et	f	\N
157391	seminaar	?seminaar =seminaar  (SgN  >seminaar !22_S	et	f	\N
157404	foneetika	foneetika =foneetika  (SgN  >foneetika !01_S	et	f	\N
157405	foneetika	foneetika =foneetika  (SgG  >foneetika !01_S	et	f	\N
157412	ode	?ode =ode  (SgN  >ode !16_S	et	f	\N
157413	ode	?ode =ode  (SgG  >ode !16_S	et	f	\N
157414	ode	?ode =ode  (IndPrPs_  >odema !27_V	et	f	\N
157415	ode	?ode =ode  (ImpPrSg2  >odema !27_V	et	f	\N
157427	morfoloogia	morfoloogia =morfoloogia  (SgN  >morfoloogia !01_S	et	f	\N
157428	morfoloogia	morfoloogia =morfoloogia  (SgG  >morfoloogia !01_S	et	f	\N
157458	muutes	muutes =muut  (Ger  >muutma !34_V	et	f	\N
157460	muutes	muutes =muute  (SgIn  >muude !06_S	et	f	\N
157478	pannkooke	pannkooke =kooke  (SgN  >pann+kooke !12?10_S	et	f	\N
157479	pannkooke	"pann+kooke %koo  )KE_dS  <pann+kubu ;18_S	et	f	\N
157480	pannkooke	pannkooke =kooke  (PlP  >pann+kook !22_S	et	f	\N
157481	sümboliksoli	?sümboliksoli =sümboliksoli  (SgG  >sümboliksol !02_S	et	f	\N
157482	sümboliksoli	?sümboliksoli =oli  (SgN  >sümbol+iks+oli !17_S	et	f	\N
157483	sümboliksoli	?sümboliksoli =oli  (SgG  >sümbol+iks+oli !17_S	et	f	\N
157484	sümboliksoli	?sümboliksoli =oli  (SgP  >sümbol+iks+oli !17_S	et	f	\N
157485	sümboliksoli	?sümboliksoli =ksoli  (SgN  >sümboli+ksoli !17_S	et	f	\N
157486	sümboliksoli	?sümboliksoli =ksoli  (SgG  >sümboli+ksoli !17_S	et	f	\N
157487	sümboliksoli	?sümboliksoli =ksoli  (SgP  >sümboli+ksoli !17_S	et	f	\N
157489	sümboliksoli	?sümboliksoli =iksoli  (SgG  >sümbol+iksol !02_S	et	f	\N
157513	osalejatega	osalejatega =osaleja  (PlKom  >osaleja !01_S	et	f	\N
157514	osalejatega	"osaleja %osale  )JA_vS  <osalema ;27_V	et	f	\N
157547	kolkja	?kolkja =kolkja  (SgN  >kolkja !01_S	et	f	\N
157548	kolkja	?kolkja =kolkja  (SgG  >kolkja !01_S	et	f	\N
157549	kolkja	?kolkja =kolkja  (SgG  >kolkjas !02_A	et	f	\N
157550	kolkja	?kolkja =kolkja  (IndPrPs_  >kolkjama !29_V	et	f	\N
157551	kolkja	?kolkja =kolkja  (ImpPrSg2  >kolkjama !29_V	et	f	\N
157552	avdejeva	?avdejeva =avdejeva  (SgN  >avdejeva !16_S	et	f	\N
157553	avdejeva	?avdejeva =avdejeva  (SgG  >avdejev !02_A	et	f	\N
157554	avdejeva	?avdejeva =avdejeva  (SgG  >avdejeva !16_S	et	f	\N
157567	anzhelika	?anzhelika =anzhelika  (SgN  >anzhelika !01_S	et	f	\N
157572	anzhelika	?anzhelika =anzhelika  (SgG  >anzhelika !01_S	et	f	\N
157573	anzhelika	?anzhelika =anzhelika  (SgG  >anzhelikas !02_A	et	f	\N
157621	märgiks	märgiks =märgi  (SgTr  >märk !22_S	et	f	\N
157622	märgiks	märgiks =märgi  (KndPrPs  >märkima !28_V	et	f	\N
157629	xv-vxii	?xv-vxii =vxii  (SgN  >xv-vxii !26_S	et	f	\N
157630	xv-vxii	?xv-vxii =vxii  (SgG  >xv-vxii !26_S	et	f	\N
157631	kristus-lapsukesel	kristus-lapsukesel =lapsukese  (SgAd  >kristus-lapsuke !12_S	et	f	\N
157632	kristus-lapsukesel	"kristus-lapsuke %lapsu  )KE_dS  <kristus-laps ;22_S	et	f	\N
157633	kristus-lapsukesel	kristus-lapsukesel =lapsukese  (SgAd  >kristus-lapsukene !12_S	et	f	\N
157300	kiviajast	"kivi+ajane %aja  )NE_aA  <kivi+aeg ;22_S	et	f	\N
157314	ehti	ehti =ehti  (IndPrPs_  >ehtima !27_V	et	f	\N
157315	ehti	ehti =ehti  (ImpPrSg2  >ehtima !27_V	et	f	\N
157322	smmuti	?smmuti =smmuti  (SgN  >smmuti !16_S	et	f	\N
157323	smmuti	?smmuti =smmuti  (SgG  >smmuti !16_S	et	f	\N
157324	smmuti	?smmuti =smmuti  (SgG  >smmutt !22_S	et	f	\N
157325	smmuti	?smmuti =smmuti  (IndPrPs_  >smmutima !27_V	et	f	\N
157326	smmuti	?smmuti =smmuti  (IndPrPs_  >smmuttima !28_V	et	f	\N
157327	smmuti	?smmuti =smmuti  (ImpPrSg2  >smmutima !27_V	et	f	\N
157328	smmuti	?smmuti =smmuti  (ImpPrSg2  >smmuttima !28_V	et	f	\N
157347	margenstern	?margenstern =margenstern  (SgN  >margenstern !22_S	et	f	\N
157359	vabanenud	vabanenud =vabane  (PtsPtPs  >vabanema !27_V	et	f	\N
157360	vabanenud	vabanenud =vabanenu  (PlN  >vabanenu !01_S	et	f	\N
157361	vabanenud	"vabanenu %vabane  )NU_vS  <vabanema ;27_V	et	f	\N
157362	vabanenud	vabanenud =vabanenud  (ID  >vabanenud !41_A	et	f	\N
157363	vabanenud	"vabanenud %vabane  )NUD_vA  <vabanema ;27_V	et	f	\N
157366	rahasumma	rahasumma =summa  (SgN  >raha+summa !16_S	et	f	\N
157367	rahasumma	rahasumma =summa  (SgG  >raha+summa !16_S	et	f	\N
157368	rahasumma	rahasumma =summa  (SgG  >raha+summ !22_S	et	f	\N
157369	rahasumma	rahasumma =summa  (SgG  >raha+sumb !22_S	et	f	\N
157370	rahasumma	rahasumma =summa  (SgP  >raha+summ !22_S	et	f	\N
157371	rahasumma	rahasumma =summa  (SgAdt  >raha+summ !22_S	et	f	\N
157372	palgata	palgata =palga  (SgAb  >palk !22_S	et	f	\N
157373	palgata	palgata =palga  (Inf  >palkama !29_V	et	f	\N
157374	palgata	palgata =palga  (IndPrIps_  >palkama !29_V	et	f	\N
157378	potsepaks	?potsepaks =potsepa  (SgTr  >potsepa !01_S	et	f	\N
157382	põllum	?põllum =põllum  (SgN  >põllum !02_S	et	f	\N
157384	aerulaevad	?aerulaevad =aerulaeva  (PlN  >aerulaeva !16_S	et	f	\N
157385	vabaks1819a	?vabaksa =vabaksa  (SgN  >vabaksa !01_S	et	f	\N
157386	vabaks1819a	?vabaksa =vabaksa  (SgG  >vabaksa !01_S	et	f	\N
157401	arstiteadust	arstiteadust =teadu  (SgEl  >arsti+tead !22_S	et	f	\N
157402	arstiteadust	arstiteadust =teadus  (SgP  >arsti+teadus !11~09_S	et	f	\N
157421	kombineerivad	kombineerivad =kombineeri  (IndPrPl3  >kombineerima !28_V	et	f	\N
157422	kombineerivad	kombineerivad =kombineeriva  (PlN  >kombineeriv !02_A	et	f	\N
157423	kombineerivad	"kombineeriv %kombineeri  )V_vA  <kombineerima ;28_V	et	f	\N
157429	semantika	semantika =semantika  (SgN  >semantika !01_S	et	f	\N
157431	semantika	semantika =semantika  (SgG  >semantika !01_S	et	f	\N
157436	hernehirmutis	hernehirmutis =uti  (SgIn  >herne+hirm+utt !22_S	et	f	\N
157437	hernehirmutis	hernehirmutis =uti  (PlIn  >herne+hirm+utt !22_S	et	f	\N
157438	hernehirmutis	hernehirmutis =hirmutis  (SgN  >herne+hirmutis !11_S	et	f	\N
157439	heinast	heinast =heina  (SgEl  >hein !23?22_S	et	f	\N
157440	heinast	heinast =heinas  (SgP  >heinane !10_A	et	f	\N
157441	heinast	"heinane %heina  )NE_aA  <hein ;22_S	et	f	\N
157442	heinast	"heinane %heina  )NE_aA  <hein ;23_S	et	f	\N
157443	heinast	heinast =ast  (SgN  >hein+ast !22_S	et	f	\N
157444	nukku	nukku =nukku  (SgP  >nukk !22_S	et	f	\N
157445	nukku	nukku =nukku  (SgAdt  >nukk !22_S	et	f	\N
157446	nukku	nukku =nukku  (IndPrPs_  >nukkuma !27_V	et	f	\N
157447	nukku	nukku =nukku  (ImpPrSg2  >nukkuma !27_V	et	f	\N
157450	rebinud	rebinud =rebi  (PtsPtPs  >rebima !27_V	et	f	\N
157451	rebinud	rebinud =rebinu  (PlN  >rebinu !01_S	et	f	\N
157452	rebinud	"rebinu %rebi  )NU_vS  <rebima ;27_V	et	f	\N
157453	rebinud	rebinud =rebinud  (ID  >rebinud !41_A	et	f	\N
157454	rebinud	"rebinud %rebi  )NUD_vA  <rebima ;27_V	et	f	\N
157469	panniga	panniga =panni  (SgKom  >pann !22_S	et	f	\N
157470	panniga	panniga =iga  (SgN  >pann+iga !18_S	et	f	\N
157471	panniga	panniga =iga  (SgP  >pann+iga !18_S	et	f	\N
157476	küpsetaks	küpsetaks =küpse  (KndPrIps  >küpsema !28_V	et	f	\N
157477	küpsetaks	küpsetaks =küpseta  (KndPrPs  >küpsetama !27_V	et	f	\N
157495	rebitud	rebitud =rebi  (PtsPtIps  >rebima !27_V	et	f	\N
157496	rebitud	rebitud =rebitu  (PlN  >rebitu !01_AS	et	f	\N
157497	rebitud	"rebitu %rebi  )TU1_vS  <rebima ;27_V	et	f	\N
157498	rebitud	rebitud =rebitud  (ID  >rebitud !41_A	et	f	\N
157499	rebitud	"rebitud %rebi  )TUD_vA  <rebima ;27_V	et	f	\N
157504	arvukate	arvukate =arvuka  (PlG  >arvukas !02_A	et	f	\N
157505	arvukate	arvukate =kate  (SgN  >arvu+kate !06_S	et	f	\N
157506	fantastiliselt	fantastiliselt =fantastilise  (SgAbl  >fantastiline !12_A	et	f	\N
157507	fantastiliselt	"fantastiline %fantasti  )LINE_aA  <fantast ;22_S	et	f	\N
157508	fantastiliselt	fantastiliselt =fantastiliselt  (ID  >fantastiliselt !41_D	et	f	\N
157509	fantastiliselt	"fantastiliselt %fantasti  )LISELT_mD  <fantast ;22_S	et	f	\N
157510	fantastiliselt	"fantastiliselt %fantastilise  )LT_mD  <fantastiline ;12_A	et	f	\N
157537	korjasid	korjasid =korja  (IndIpfSg2  >korjama !29_V	et	f	\N
157538	korjasid	korjasid =korja  (IndIpfPl3  >korjama !29_V	et	f	\N
157556	selushinskaja	?selushinskaja =selushinskaja  (SgN  >selushinskaja !01_S	et	f	\N
157557	selushinskaja	?selushinskaja =selushinskaja  (SgG  >selushinskaja !01_S	et	f	\N
157558	selushinskaja	?selushinskaja =selushinskaja  (SgG  >selushinskajas !02_A	et	f	\N
157312	venekirves	venekirves =kirve  (SgIn  >vene+kirves !07_S	et	f	\N
157313	venekirves	venekirves =kirves  (SgN  >vene+kirves !07_S	et	f	\N
157341	erialasid	erialasid =ala  (PlP  >eri+ala !17_S	et	f	\N
157342	erialasid	erialasid =alasi  (PlN  >eri+alasi !01_S	et	f	\N
157343	tüs	### tüs	et	f	\N
157344	ülikoole	ülikoole =koo  (SgAll  >üli+kubu !18_S	et	f	\N
157345	ülikoole	ülikoole =koole  (SgN  >üli+koole !05_S	et	f	\N
157346	ülikoole	ülikoole =koole  (PlP  >üli+kool !22_S	et	f	\N
157364	vallutajatest	vallutajatest =vallutaja  (PlEl  >vallutaja !01_S	et	f	\N
157365	vallutajatest	"vallutaja %valluta  )JA_vS  <vallutama ;27_V	et	f	\N
157377	1860a	### 1860a	et	f	\N
157379	falck	?falck =falck  (SgN  >falck !22_S	et	f	\N
157383	1810a	### 1810a	et	f	\N
157394	gümnaasiumist	gümnaasiumist =gümnaasiumi  (SgEl  >gümnaasium !19~02_S	et	f	\N
157395	gümnaasiumist	gümnaasiumist =gümnaasiumis  (SgP  >gümnaasiumine !10_A	et	f	\N
157396	gümnaasiumist	"gümnaasiumine %gümnaasiumi  )NE_aA  <gümnaasium ;02_S	et	f	\N
157397	gümnaasiumist	"gümnaasiumine %gümnaasiumi  )NE_aA  <gümnaasium ;19_S	et	f	\N
157418	foneemi	foneemi =foneemi  (SgG  >foneem !22_S	et	f	\N
157419	foneemi	foneemi =foneemi  (SgP  >foneem !22_S	et	f	\N
157420	foneemi	foneemi =foneemi  (SgAdt  >foneem !22_S	et	f	\N
157430	liksikoloogia	?liksikoloogia =liksikoloogia  (SgN  >liksikoloogia !01_S	et	f	\N
157432	liksikoloogia	?liksikoloogia =liksikoloogia  (SgG  >liksikoloogia !01_S	et	f	\N
157455	kasukas	kasukas =kasuka  (SgIn  >kasukas !02_S	et	f	\N
157456	kasukas	kasukas =kasukas  (SgN  >kasukas !02_S	et	f	\N
157472	pannkoogidega	?pannkoogidega =pannkoogi  (PlKom  >pannkoogi !16_S	et	f	\N
157473	pannkoogidega	?pannkoogidega =pannkoogi  (PlKom  >pannkoog !22_S	et	f	\N
157474	pannkoogidega	?pannkoogidega =koogi  (PlKom  >pann+koogi !16_S	et	f	\N
157475	pannkoogidega	?pannkoogidega =koogi  (PlKom  >pann+koog !22_S	et	f	\N
157488	õlest	õlest =õle  (SgEl  >õlg !22_S	et	f	\N
157490	õlest	õlest =õles  (SgP  >õlene !10_A	et	f	\N
157491	õlest	"õlene %õle  )NE_aA  <õlg ;22_S	et	f	\N
157492	spetsiaalselt	spetsiaalselt =spetsiaalse  (SgAbl  >spetsiaalne !02_A	et	f	\N
157493	spetsiaalselt	spetsiaalselt =spetsiaalselt  (ID  >spetsiaalselt !41_D	et	f	\N
157494	spetsiaalselt	"spetsiaalselt %spetsiaalse  )LT_mD  <spetsiaalne ;02_A	et	f	\N
157500	rõivadesse	?rõivadesse =rõiva  (PlIll  >rõiva !16_S	et	f	\N
157501	rõivadesse	?rõivadesse =rõivades  (SgAdt  >rõivadene !12_A	et	f	\N
157502	rõivadesse	?rõivadesse =rõivadesse  (SgG  >rõivadesne !02_A	et	f	\N
157503	rõivadesse	?rõivadesse =rõivadesse  (PlP  >rõivadess !22_S	et	f	\N
157515	naases	?naases =naase  (SgIn  >naane !10_A	et	f	\N
157519	naases	?naases =naase  (SgIn  >naase !16_S	et	f	\N
157520	naases	?naases =naase  (PlIn  >naas !22_S	et	f	\N
157521	naases	?naases =naase  (IndIpfSg3  >naasema !28_V	et	f	\N
157522	naases	?naases =naases  (SgN  >naases !09_S	et	f	\N
157532	vihad	vihad =viha  (PlN  >viha !17_SA	et	f	\N
157533	vihad	vihad =viha  (PlN  >viht !22_S	et	f	\N
157534	kolu	kolu =kolu  (SgN  >kolu !17_S	et	f	\N
157535	kolu	kolu =kolu  (SgG  >kolu !17_S	et	f	\N
157536	kolu	kolu =kolu  (SgP  >kolu !17_S	et	f	\N
157563	lastekoori	lastekoori =koor  (PlP  >laste+koor !13_S	et	f	\N
157564	lastekoori	lastekoori =koori  (SgG  >laste+koor !22_S	et	f	\N
157565	lastekoori	lastekoori =koori  (SgP  >laste+koor !22_S	et	f	\N
157566	lastekoori	lastekoori =koori  (SgAdt  >laste+koor !22_S	et	f	\N
157574	tantsupeol	tantsupeol =peo  (SgAd  >tantsu+pidu !18_S	et	f	\N
157575	tantsupeol	tantsupeol =peo  (SgAd  >tantsu+peo !26_S	et	f	\N
157582	tarsan	?tarsan =tarsa  (IndPrSg1  >tarsama !29_V	et	f	\N
157583	tarsan	?tarsan =tarsan  (SgN  >tarsan !02_S	et	f	\N
157584	vallavanema	vallavanema =vanema  (SgG  >valla+vanem !02_AS	et	f	\N
157585	vallavanema	"valla+vanem %vane  )M_cA  <valla+vana ;17_AS	et	f	\N
157591	palvela	palvela =palvela  (SgN  >palvela !01_S	et	f	\N
157593	palvela	palvela =palvela  (SgG  >palvela !01_S	et	f	\N
157705	varakristluse	varakristluse =kristluse  (SgG  >vara+kristlus !11~09_S	et	f	\N
157707	varakristluse	"vara+kristlus %kristlase  )US_aS  <vara+kristlane ;12_S	et	f	\N
157721	tundusid	tundusid =tundu  (IndIpfSg2  >tunduma !27_V	et	f	\N
157722	tundusid	tundusid =tundu  (IndIpfPl3  >tunduma !27_V	et	f	\N
157738	igapäevaelust	igapäevaelust =elu  (SgEl  >iga+päeva+elu !17_S	et	f	\N
157739	igapäevaelust	igapäevaelust =aelus  (SgP  >iga+päev+aelus !11~09_S	et	f	\N
157750	pedagoogi	pedagoogi =pedagoogi  (SgG  >pedagoog !22_S	et	f	\N
157751	pedagoogi	pedagoogi =pedagoogi  (SgP  >pedagoog !22_S	et	f	\N
157752	pedagoogi	pedagoogi =pedagoogi  (SgAdt  >pedagoog !22_S	et	f	\N
157762	saalides	saalides =saali  (PlIn  >saal !22_S	et	f	\N
157763	saalides	saalides =saali  (Ger  >saalima !28_V	et	f	\N
157767	ekabpilsis	?ekabpilsis =ekabpilsi  (IndIpfSg3  >ekabpilsima !28_V	et	f	\N
157768	ekabpilsis	?ekabpilsis =ekabpilsis  (SgN  >ekabpilsis !09_S	et	f	\N
157780	suvalkas	?suvalkas =suvalka  (SgIn  >suvalka !16_S	et	f	\N
157786	usukaaslastele	usukaaslastele =las  (PlAll  >usu+kaas+laps !14_S	et	f	\N
157787	usukaaslastele	usukaaslastele =laste  (PlAll  >usu+kaas+last !22_S	et	f	\N
157407	häälikuline	"häälikuline %hääliku  )LINE_aA  <häälik ;02_S	et	f	\N
157408	haaldatakse	?haaldatakse =haalda  (IndPrIps  >haaldama !27_V	et	f	\N
157409	haaldatakse	?haaldatakse =haalda  (IndPrIps  >haaltama !29_V	et	f	\N
157410	haaldatakse	?haaldatakse =haaldatakse  (SgG  >haaldatakne !02_A	et	f	\N
157411	haaldatakse	?haaldatakse =haaldatakse  (PlP  >haaldataks !22_S	et	f	\N
157424	gramatika	?gramatika =gramatika  (SgN  >gramatika !01_S	et	f	\N
157425	gramatika	?gramatika =gramatika  (SgG  >gramatika !01_S	et	f	\N
157426	gramatika	?gramatika =gramatika  (SgG  >gramatikas !02_A	et	f	\N
157448	riietumine	riietumine =riietumine  (SgN  >riietumine !12_S	et	f	\N
157449	riietumine	"riietumine %riietu  )MINE_vS  <riietuma ;27_V	et	f	\N
157457	hernrhirmutist	?hernrhirmutist =hernrhirmuti  (SgEl  >hernrhirmutt !22_S	et	f	\N
157459	hernrhirmutist	?hernrhirmutist =hernrhirmutis  (SgP  >hernrhirmutis !09_S	et	f	\N
157461	hernrhirmutist	?hernrhirmutist =hernrhirmutist  (SgN  >hernrhirmutist !22_S	et	f	\N
157462	hernehirmutisest	hernehirmutisest =hirmutise  (SgEl  >herne+hirmutis !11_S	et	f	\N
157463	hernehirmutisest	hernehirmutisest =hirmutises  (SgP  >herne+hirmutisene !12_A	et	f	\N
157464	hernehirmutisest	"herne+hirmutisene %hirmutise  )NE_aA  <herne+hirmutis ;11_S	et	f	\N
157465	joonistati	joonistati =joonista  (IndIpfIps  >joonistama !27_V	et	f	\N
157466	joonistati	joonistati =tati  (SgG  >joonis+tatt !22_S	et	f	\N
157467	pidulikude	pidulikude =piduliku  (PlG  >pidulik !25_A	et	f	\N
157468	pidulikude	pidulikude =ude  (SgN  >pidulik+ude !04_S	et	f	\N
157511	tavalistesse	tavalistesse =tavalis  (PlIll  >tavaline !12_A	et	f	\N
157512	tavalistesse	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
157523	kütmiseks	kütmiseks =kütmise  (SgTr  >kütmine !12?10_S	et	f	\N
157524	kütmiseks	"kütmine %küt  )MINE_vS  <kütma ;35_V	et	f	\N
157525	ratad	?ratad =rata  (PlN  >rata !16_S	et	f	\N
157526	ratad	?ratad =rata  (IndPrSg2  >ratama !27_V	et	f	\N
157527	korjatud	korjatud =korja  (PtsPtIps  >korjama !29_V	et	f	\N
157528	korjatud	korjatud =korjatu  (PlN  >korjatu !01_AS	et	f	\N
157529	korjatud	"korjatu %korja  )TU1_vS  <korjama ;29_V	et	f	\N
157530	korjatud	korjatud =korjatud  (ID  >korjatud !41_A	et	f	\N
157531	korjatud	"korjatud %korja  )TUD_vA  <korjama ;29_V	et	f	\N
157559	marima	?marima =mari  (Sup  >marima !27_V	et	f	\N
157560	marima	?marima =marima  (SgG  >marim !02_A	et	f	\N
157561	rutenia	?rutenia =rutenia  (SgN  >rutenia !01_S	et	f	\N
157562	rutenia	?rutenia =rutenia  (SgG  >rutenia !01_S	et	f	\N
157576	etteaste	etteaste =aste  (SgN  >ette+aste !05_S	et	f	\N
157577	etteaste	etteaste =aste  (SgN  >ette+aste !06_S	et	f	\N
157578	etteaste	etteaste =aste  (SgG  >ette+aste !06_S	et	f	\N
157579	etteaste	etteaste =aste  (PlP  >ette+ast !22_S	et	f	\N
157590	koorilaulja	koorilaulja =laulja  (SgN  >koori+laulja !01_S	et	f	\N
157592	koorilaulja	koorilaulja =laulja  (SgG  >koori+laulja !01_S	et	f	\N
157596	avdejevale	?avdejevale =avdejeva  (SgAll  >avdejev !02_A	et	f	\N
157597	avdejevale	?avdejevale =avdejeva  (SgAll  >avdejeva !16_S	et	f	\N
157598	avdejevale	?avdejevale =avdejevale  (PlP  >avdejeval !19_S	et	f	\N
157602	vanavene	vanavene =vene  (ID  >vana+vene !41_G	et	f	\N
157603	vanavene	vanavene =vene  (SgN  >vana+vene !16_S	et	f	\N
157604	vanavene	vanavene =vene  (SgG  >vana+vene !16_S	et	f	\N
157605	kolmainsuse	kolmainsuse =ainsuse  (SgG  >kolm+ainsus !11~09_S	et	f	\N
157606	kolmainsuse	"kolm+ainsus %ainsa  )US_aS  <kolm+ainus ;03_AS	et	f	\N
157613	kuulajate	kuulajate =kuulaja  (PlG  >kuulaja !01_S	et	f	\N
157614	kuulajate	"kuulaja %kuula  )JA_vS  <kuulama ;29_V	et	f	\N
157635	vanausukoor	vanausukoor =koor  (SgN  >vana+usu+koor !13_S	et	f	\N
157636	vanausukoor	vanausukoor =koor  (SgN  >vana+usu+koor !22_S	et	f	\N
157648	rimshi	?rimshi =rimshi  (SgN  >rimshi !01_S	et	f	\N
157649	rimshi	?rimshi =rimshi  (SgG  >rimshi !01_S	et	f	\N
157650	rimshi	?rimshi =rimshi  (SgG  >rimsh !22_S	et	f	\N
157651	rimshi	?rimshi =rimshi  (SgP  >rimsh !22_S	et	f	\N
157652	rimshi	?rimshi =rimshi  (SgAdt  >rimsh !22_S	et	f	\N
157653	rimshi	?rimshi =rimshi  (IndPrPs_  >rimshima !28_V	et	f	\N
157654	rimshi	?rimshi =rimshi  (ImpPrSg2  >rimshima !28_V	et	f	\N
157664	linnukesest	linnukesest =linnukese  (SgEl  >linnuke !12_S	et	f	\N
157665	linnukesest	"linnuke %linnu  )KE_dS  <lind ;22_S	et	f	\N
157666	linnukesest	linnukesest =linnukese  (SgEl  >linnukene !12_S	et	f	\N
157667	linnukesest	"linnukene %linnu  )KENE_dS  <lind ;22_S	et	f	\N
157674	kangelasteost	kangelasteost =ost  (SgN  >kange+laste+ost !22_S	et	f	\N
157675	kangelasteost	kangelasteost =teo  (SgEl  >kangelas+tegu !18_S	et	f	\N
157676	kangelasteost	kangelasteost =teo  (SgEl  >kangelas+tigu !18_S	et	f	\N
157677	kangelasteost	kangelasteost =teos  (SgP  >kangelas+teos !09_S	et	f	\N
157684	kahetsustundest	kahetsustundest =tunde  (SgEl  >kahetsus+tunne !06_S	et	f	\N
157685	kahetsustundest	kahetsustundest =tundes  (SgP  >kahetsus+tundene !12~10_A	et	f	\N
157686	kahetsustundest	"kahetsus+tundene %tunde  )NE_aA  <kahetsus+tunne ;06_S	et	f	\N
157692	avvakumi	?avvakumi =avvakumi  (SgG  >avvakum !19_S	et	f	\N
157693	avvakumi	?avvakumi =avvakumi  (SgP  >avvakum !19_S	et	f	\N
157694	avvakumi	?avvakumi =avvakumi  (SgAdt  >avvakum !19_S	et	f	\N
157715	kodused	kodused =koduse  (PlN  >kodune !10_A	et	f	\N
157545	vanausumuusika	vanausumuusika =muusika  (SgN  >vana+usu+muusika !01_S	et	f	\N
157546	vanausumuusika	vanausumuusika =muusika  (SgG  >vana+usu+muusika !01_S	et	f	\N
157555	grezn	?grezn =grezn  (SgN  >grezn !22_S	et	f	\N
157568	akulenko	?akulenko =akulenko  (SgN  >akulenko !16_S	et	f	\N
157569	akulenko	?akulenko =akulenko  (SgG  >akulenko !16_S	et	f	\N
157570	akulenko	?akulenko =lenko  (SgN  >aku+lenko !16_S	et	f	\N
157571	akulenko	?akulenko =lenko  (SgG  >aku+lenko !16_S	et	f	\N
157599	xv	### xv	et	f	\N
157611	100-aasta	-aasta =aasta  (SgN  >-aasta !01_S	et	f	\N
157612	100-aasta	-aasta =aasta  (SgG  >-aasta !01_S	et	f	\N
157619	vallutasid	vallutasid =valluta  (IndIpfSg2  >vallutama !27_V	et	f	\N
157620	vallutasid	vallutasid =valluta  (IndIpfPl3  >vallutama !27_V	et	f	\N
157623	traditsioonilist	traditsioonilist =traditsioonilis  (SgP  >traditsiooniline !12_A	et	f	\N
157624	traditsioonilist	"traditsiooniline %traditsiooni  )LINE_aA  <traditsioon ;22_S	et	f	\N
157641	kauni	kauni =kauni  (SgG  >kaunis !05~07_A	et	f	\N
157642	kauni	kauni =kauni  (SgG  >kaun !22_S	et	f	\N
157643	kauni	kauni =kauni  (SgP  >kaun !22_S	et	f	\N
157644	kauni	kauni =kauni  (SgAdt  >kaun !22_S	et	f	\N
157645	kauni	kauni =kauni  (PlP  >kaun !22_S	et	f	\N
157659	lihaste	lihaste =lihas  (PlG  >lihas !09_S	et	f	\N
157660	lihaste	lihaste =lihas  (PlG  >lihane !10_A	et	f	\N
157661	lihaste	"lihane %liha  )NE_aA  <liha ;17_S	et	f	\N
157662	süzhee	?süzhee =süzhee  (SgN  >süzhee !26_S	et	f	\N
157663	süzhee	?süzhee =süzhee  (SgG  >süzhee !26_S	et	f	\N
157680	aadliseisusest	aadliseisusest =seisuse  (SgEl  >aadli+seisus !11~09_S	et	f	\N
157681	aadliseisusest	aadliseisusest =seisuses  (SgP  >aadli+seisusene !12_A	et	f	\N
157682	aadliseisusest	"aadli+seisusene %seisuse  )NE_aA  <aadli+seisus ;09_S	et	f	\N
157683	aadliseisusest	"aadli+seisusene %seisuse  )NE_aA  <aadli+seisus ;11_S	et	f	\N
157695	kannatustest	kannatustest =kannatus  (PlEl  >kannatus !11_S	et	f	\N
157696	kannatustest	"kannatus %kannata  )US_vS  <kannatama ;27_V	et	f	\N
157697	kannatustest	"kannatus %kanna  )TUS2_aS  <kanna ;16_S	et	f	\N
157698	kannatustest	"kannatus %kanna  )TUS2_aS  <kand ;22_S	et	f	\N
157699	kannatustest	kannatustest =test  (SgN  >kannatus+test !22_S	et	f	\N
157700	kannatustest	kannatustest =tuste  (PlEl  >kanna+tust !22_S	et	f	\N
157703	daurias	?daurias =dauria  (SgIn  >dauria !01_S	et	f	\N
157704	daurias	?daurias =daurias  (SgN  >daurias !11_S	et	f	\N
157717	värside	?värside =värsi  (PlG  >värsi !16_S	et	f	\N
157718	värside	?värside =värsi  (PlG  >värs !22_S	et	f	\N
157719	reipust	reipust =reipus  (SgP  >reipus !11~09_S	et	f	\N
157720	reipust	"reipus %reipa  )US_aS  <reibas ;07_A	et	f	\N
157728	süzheedel	?süzheedel =süzhee  (PlAd  >süzhee !26_S	et	f	\N
157729	süzheedel	?süzheedel =süzheede  (SgAd  >süzheede !16_S	et	f	\N
157730	süzheedel	?süzheedel =süzheede  (PlAd  >süzheet !22_S	et	f	\N
157733	mõtisklused	mõtisklused =mõtiskluse  (PlN  >mõtisklus !11_S	et	f	\N
157734	mõtisklused	"mõtisklus %mõtiskle  )US_vS  <mõtisklema ;27_V	et	f	\N
157758	grebenschikovi	?grebenschikovi =grebenschikovi  (ID  >grebenschikovi !41_D	et	f	\N
157759	grebenschikovi	?grebenschikovi =grebenschikovi  (SgG  >grebenschikov !02_A	et	f	\N
157774	borissovis	?borissovis =borissovi  (SgIn  >borissov !02_A	et	f	\N
157775	borissovis	?borissovis =borissovis  (SgN  >borissovis !09_S	et	f	\N
157782	gabrovy	### gabrovy	et	f	\N
157792	täiendub	?täiendub =täiendu  (IndPrSg3  >täienduma !27_V	et	f	\N
157812	asutajateks	asutajateks =asutaja  (PlTr  >asutaja !01_S	et	f	\N
157813	asutajateks	"asutaja %asuta  )JA_vS  <asutama ;27_V	et	f	\N
157845	juhatuse	juhatuse =juhatuse  (SgG  >juhatus !11_S	et	f	\N
157846	juhatuse	"juhatus %juhata  )US_vS  <juhatama ;27_V	et	f	\N
157848	juhatuse	"juhatus %juha  )TUS2_aS  <juha ;17_S	et	f	\N
157852	puhtasime	?puhtasime =puhta  (IndIpfPl1  >puhtama !29_V	et	f	\N
157853	bootanikaajas	?bootanikaajas =bootanikaaja  (SgIn  >bootanikaajas !02_A	et	f	\N
157854	bootanikaajas	?bootanikaajas =bootanikaaja  (SgIn  >bootanikaaja !16_S	et	f	\N
157855	bootanikaajas	?bootanikaajas =bootanikaajas  (SgN  >bootanikaajas !02_A	et	f	\N
157880	harjus	harjus =harju  (PlIn  >hari !24_S	et	f	\N
157881	harjus	harjus =harju  (IndIpfSg3  >harjuma !27_V	et	f	\N
157882	harjus	harjus =harjus  (SgN  >harjus !09_S	et	f	\N
157886	hannese	?hannese =hannese  (SgG  >hannene !10_A	et	f	\N
157900	kuuetundi	kuuetundi =tundi  (SgP  >kuue+tund !22_S	et	f	\N
157901	kuuetundi	kuuetundi =tundi  (SgAdt  >kuue+tund !22_S	et	f	\N
157929	korteriühisyu	?korteriühisyu =korteriühisyu  (SgN  >korteriühisyu !26_S	et	f	\N
157930	korteriühisyu	?korteriühisyu =korteriühisyu  (SgG  >korteriühisyu !26_S	et	f	\N
157931	korteriühisyu	?korteriühisyu =ühisyu  (SgN  >korteri+ühisyu !26_S	et	f	\N
157932	korteriühisyu	?korteriühisyu =ühisyu  (SgG  >korteri+ühisyu !26_S	et	f	\N
157933	käimatoime	käimatoime =toime  (SgN  >käima+toime !06_S	et	f	\N
157934	käimatoime	käimatoime =toime  (SgG  >käima+toime !06_S	et	f	\N
157935	käimatoime	käimatoime =toime  (SgG  >käima+toim !22_S	et	f	\N
157936	käimatoime	käimatoime =toime  (SgP  >käima+toim !22_S	et	f	\N
157937	käimatoime	käimatoime =toime  (SgAdt  >käima+toim !22_S	et	f	\N
157580	piirisaarel	piirisaarel =aare  (PlAd  >piiris+aar !22_S	et	f	\N
157581	piirisaarel	piirisaarel =saare  (SgAd  >piiri+saar !13_S	et	f	\N
157586	baranina	?baranina =barani  (SgEs  >baran !02_S	et	f	\N
157587	baranina	?baranina =baranina  (SgG  >baranin !19_S	et	f	\N
157588	baranina	?baranina =baranina  (SgP  >baranin !19_S	et	f	\N
157589	baranina	?baranina =baranina  (SgAdt  >baranin !19_S	et	f	\N
157594	kutkina	?kutkina =kutki  (SgEs  >kutki !16_S	et	f	\N
157595	kutkina	?kutkina =kutki  (SgEs  >kutk !22_S	et	f	\N
157600	xvii	?xvii =xvii  (SgN  >xvii !26_S	et	f	\N
157601	xvii	?xvii =xvii  (SgG  >xvii !26_S	et	f	\N
157607	70-aasta	-aasta =aasta  (SgN  >-aasta !01_S	et	f	\N
157608	70-aasta	-aasta =aasta  (SgG  >-aasta !01_S	et	f	\N
157609	õnnistuse	õnnistuse =õnnistuse  (SgG  >õnnistus !11_S	et	f	\N
157610	õnnistuse	"õnnistus %õnnista  )US_vS  <õnnistama ;27_V	et	f	\N
157615	norrast	?norrast =norras  (SgP  >norras !07_S	et	f	\N
157616	norrast	?norrast =norras  (SgP  >norrane !10_A	et	f	\N
157617	2005aasta	aasta =aasta  (SgN  >aasta !01_S	et	f	\N
157618	2005aasta	aasta =aasta  (SgG  >aasta !01_S	et	f	\N
157625	liturgiavälist	?liturgiavälist =liturgiaväli  (SgEl  >liturgiaväl !19_S	et	f	\N
157626	liturgiavälist	?liturgiavälist =liturgiavälis  (SgP  >liturgiavälis !09_S	et	f	\N
157627	liturgiavälist	?liturgiavälist =liturgiavälis  (SgP  >liturgiaväline !12_A	et	f	\N
157628	liturgiavälist	?liturgiavälist =liturgiavälist  (SgN  >liturgiavälist !22_S	et	f	\N
157646	zavoloko	?zavoloko =zavoloko  (SgN  >zavoloko !16_S	et	f	\N
157647	zavoloko	?zavoloko =zavoloko  (SgG  >zavoloko !16_S	et	f	\N
157655	orjaks	orjaks =orja  (SgTr  >ori !24_S	et	f	\N
157656	orjaks	orjaks =orja  (KndPrPs  >orjama !29_V	et	f	\N
157668	voinovo	?voinovo =voinovo  (SgN  >voinovo !01_S	et	f	\N
157669	voinovo	?voinovo =voinovo  (SgG  >voinovo !01_S	et	f	\N
157670	igatsusest	igatsusest =igatsuse  (SgEl  >igatsus !11_S	et	f	\N
157671	igatsusest	"igatsus %igatse  )US_vS  <igatsema ;27_V	et	f	\N
157672	igatsusest	igatsusest =igatsuses  (SgP  >igatsusene !12_A	et	f	\N
157673	igatsusest	"igatsusene %igatsuse  )NE_aA  <igatsus ;11_S	et	f	\N
157678	loobumisest	loobumisest =loobumise  (SgEl  >loobumine !12_S	et	f	\N
157679	loobumisest	"loobumine %loobu  )MINE_vS  <loobuma ;27_V	et	f	\N
157688	paguluses	paguluses =paguluse  (SgIn  >pagulus !11_S	et	f	\N
157689	paguluses	"pagulus %pagulase  )US_aS  <pagulane ;12_S	et	f	\N
157701	pagenduses	pagenduses =pagenduse  (SgIn  >pagendus !11_S	et	f	\N
157702	pagenduses	"pagendus %pagenda  )US_vS  <pagendama ;27_V	et	f	\N
157706	vanesse	?vanesse =vane  (SgIll  >vane !16_S	et	f	\N
157708	vanesse	?vanesse =vanesse  (SgG  >vanesne !02_A	et	f	\N
157709	vanesse	?vanesse =vanesse  (PlP  >vaness !22_S	et	f	\N
157710	põlanud	põlanud =põla  (PtsPtPs  >põlgama !29_V	et	f	\N
157711	põlanud	põlanud =põlanu  (PlN  >põlanu !01_S	et	f	\N
157712	põlanud	"põlanu %põla  )NU_vS  <põlgama ;29_V	et	f	\N
157713	põlanud	põlanud =põlanud  (ID  >põlanud !41_A	et	f	\N
157714	põlanud	"põlanud %põla  )NUD_vA  <põlgama ;29_V	et	f	\N
157723	ajaloolistel	ajaloolistel =loolis  (PlAd  >aja+looline !12?10_A	et	f	\N
157724	ajaloolistel	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
157725	ajaloolistel	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
157726	ajaloolistel	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
157727	ajaloolistel	ajaloolistel =loolis  (PlAd  >aja+looline !12?10_S	et	f	\N
157735	inimelu	inimelu =elu  (SgN  >inim+elu !17_S	et	f	\N
157736	inimelu	inimelu =elu  (SgG  >inim+elu !17_S	et	f	\N
157737	inimelu	inimelu =elu  (SgP  >inim+elu !17_S	et	f	\N
157743	tagakuisamisest	?tagakuisamisest =tagakuisamise  (SgEl  >tagakuisamine !12_S	et	f	\N
157744	tagakuisamisest	?tagakuisamisest =samise  (SgEl  >taga+kui+samine !10_A	et	f	\N
157745	tagakuisamisest	?tagakuisamisest =kuisamise  (SgEl  >taga+kuisamine !12_S	et	f	\N
157753	muinasloo	muinasloo =loo  (SgG  >muinas+lugu !18_S	et	f	\N
157754	muinasloo	muinasloo =loo  (SgG  >muinas+loog !22_S	et	f	\N
157755	muinasloo	muinasloo =loo  (SgG  >muinas+lood !22_S	et	f	\N
157760	esinduslikumaid	esinduslikumaid =esinduslikuma  (PlP  >esinduslikum !02_A	et	f	\N
157761	esinduslikumaid	"esinduslikum %esindusliku  )M_cA  <esinduslik ;25_A	et	f	\N
157764	daugavpilsis	?daugavpilsis =daugavpilsi  (IndIpfSg3  >daugavpilsima !28_V	et	f	\N
157765	daugavpilsis	?daugavpilsis =daugavpilsis  (SgN  >daugavpilsis !09_S	et	f	\N
157793	esitusele	esitusele =esituse  (SgAll  >esitus !11_S	et	f	\N
157794	esitusele	"esitus %esita  )US_vS  <esitama ;27_V	et	f	\N
157798	liimed	?liimed =liime  (PlN  >liime !06_S	et	f	\N
157799	liimed	?liimed =liime  (IndPrSg2  >liimema !27_V	et	f	\N
157800	kirjastanud	kirjastanud =kirjasta  (PtsPtPs  >kirjastama !27_V	et	f	\N
157801	kirjastanud	kirjastanud =kirjastanu  (PlN  >kirjastanu !01_S	et	f	\N
157802	kirjastanud	"kirjastanu %kirjasta  )NU_vS  <kirjastama ;27_V	et	f	\N
157803	kirjastanud	kirjastanud =kirjastanud  (ID  >kirjastanud !41_A	et	f	\N
157804	kirjastanud	"kirjastanud %kirjasta  )NUD_vA  <kirjastama ;27_V	et	f	\N
157838	haruldaselt	haruldaselt =haruldase  (SgAbl  >haruldane !12_A	et	f	\N
157839	haruldaselt	haruldaselt =haruldaselt  (ID  >haruldaselt !41_D	et	f	\N
157634	kristus-lapsukesel	"kristus-lapsukene %lapsu  )KENE_dS  <kristus-laps ;22_S	et	f	\N
157637	samaarialanna	?samaarialanna =samaarialanna  (SgN  >samaarialanna !16_S	et	f	\N
157638	samaarialanna	?samaarialanna =samaarialanna  (SgG  >samaarialanna !16_S	et	f	\N
157639	samaarialanna	?samaarialanna =arialanna  (SgN  >sama+arialanna !16_S	et	f	\N
157640	samaarialanna	?samaarialanna =arialanna  (SgG  >sama+arialanna !16_S	et	f	\N
157657	andmisest	andmisest =andmise  (SgEl  >andmine !12?10_S	et	f	\N
157658	andmisest	"andmine %and  )MINE_vS  <andma ;34_V	et	f	\N
157687	avvakum	?avvakum =avvakum  (SgN  >avvakum !19_S	et	f	\N
157690	ülempreester	ülempreester =ester  (SgN  >ülem+pre+ester !02_S	et	f	\N
157691	ülempreester	ülempreester =preester  (SgN  >ülem+preester !02_S	et	f	\N
157731	filosoofilised	filosoofilised =filosoofilise  (PlN  >filosoofiline !12_A	et	f	\N
157732	filosoofilised	"filosoofiline %filosoofi  )LINE_aA  <filosoof ;22_S	et	f	\N
157741	vaimus	vaimus =vaimu  (SgIn  >vaim !22_S	et	f	\N
157742	vaimus	vaimus =vaimu  (PlIn  >vaim !22_S	et	f	\N
157746	ahistamisest	ahistamisest =ahistamise  (SgEl  >ahistamine !12_S	et	f	\N
157747	ahistamisest	"ahistamine %ahista  )MINE_vS  <ahistama ;27_V	et	f	\N
157748	30-aastatel	-aastatel =aasta  (PlAd  >-aasta !01_S	et	f	\N
157749	30-aastatel	-aastatel =tate  (PlAd  >-aas+tatt !22_S	et	f	\N
157769	moskvino	?moskvino =moskvino  (SgN  >moskvino !01_S	et	f	\N
157770	moskvino	?moskvino =moskvino  (SgG  >moskvino !01_S	et	f	\N
157771	bobruiskis	?bobruiskis =bobruiski  (SgIn  >bobruisk !02_S	et	f	\N
157772	bobruiskis	?bobruiskis =bobruiski  (IndIpfSg3  >bobruiskima !28_V	et	f	\N
157773	bobruiskis	?bobruiskis =bobruiskis  (SgN  >bobruiskis !11_S	et	f	\N
157781	voinovos	?voinovos =voinovo  (SgIn  >voinovo !01_S	et	f	\N
157795	muusikakultuuri	muusikakultuuri =kultuuri  (SgG  >muusika+kultuur !22_S	et	f	\N
157796	muusikakultuuri	muusikakultuuri =kultuuri  (SgP  >muusika+kultuur !22_S	et	f	\N
157797	muusikakultuuri	muusikakultuuri =kultuuri  (SgAdt  >muusika+kultuur !22_S	et	f	\N
157819	nazarov	?nazarov =nazarov  (SgN  >nazarov !02_A	et	f	\N
157827	znamennõi	?znamennõi =znamennõi  (SgN  >znamennõi !26_S	et	f	\N
157829	znamennõi	?znamennõi =znamennõi  (SgG  >znamennõi !26_S	et	f	\N
157862	troika	troika =troika  (SgN  >troika !16_S	et	f	\N
157863	troika	troika =troika  (SgG  >troika !16_S	et	f	\N
157864	märge	märge =märge  (SgN  >märge !05_S	et	f	\N
157865	märge	märge =märge  (SgN  >märge !06_S	et	f	\N
157866	märge	märge =märge  (PlP  >märg !22_AS	et	f	\N
157877	hannes	?hannes =hanne  (PlIn  >hann !22_S	et	f	\N
157878	hannes	?hannes =hanne  (IndIpfSg3  >hannema !27_V	et	f	\N
157879	hannes	?hannes =hannes  (SgN  >hannes !09_S	et	f	\N
157891	des-vormi	des-vormi =vormi  (SgG  >des-vorm !22_S	et	f	\N
157892	des-vormi	des-vormi =vormi  (SgP  >des-vorm !22_S	et	f	\N
157893	des-vormi	des-vormi =vormi  (SgAdt  >des-vorm !22_S	et	f	\N
157894	des-vormi	des-vormi =vormi  (IndPrPs_  >des-vormima !28_V	et	f	\N
157895	des-vormi	des-vormi =vormi  (ImpPrSg2  >des-vormima !28_V	et	f	\N
157898	pakkumisi	pakkumisi =pakkumisi  (PlP  >pakkumine !12_S	et	f	\N
157899	pakkumisi	"pakkumine %pakku  )MINE_vS  <pakkuma ;28_V	et	f	\N
157918	vi	### vi	et	f	\N
157939	eksitavad	eksitavad =eksita  (IndPrPl3  >eksitama !27_V	et	f	\N
157940	eksitavad	eksitavad =eksitava  (PlN  >eksitav !02_A	et	f	\N
157941	eksitavad	"eksitav %eksi  )TAV_vAS  <eksima ;28_V	et	f	\N
157942	eksitavad	"eksitav %eksita  )V_vA  <eksitama ;27_V	et	f	\N
157943	eksitavad	eksitavad =tava  (PlN  >eksi+tava !17_S	et	f	\N
157961	käitus	käitus =käitu  (IndIpfSg3  >käituma !27_V	et	f	\N
157962	käitus	käitus =käitus  (SgN  >käitus !11~09_S	et	f	\N
157963	käitus	"käitus %käita  )US_vS  <käitama ;27_V	et	f	\N
157974	isuäratavalt	isuäratavalt =tava  (SgAbl  >isu+ära+tava !17_S	et	f	\N
157975	isuäratavalt	isuäratavalt =äratava  (SgAbl  >isu+äratav !02_A	et	f	\N
157976	isuäratavalt	"isu+äratavalt %äratava  )LT_mD  <isu+äratav ;02_A	et	f	\N
157990	viieliikmeline	viieliikmeline =liikmeline  (SgN  >viie+liikmeline !12_A	et	f	\N
157991	viieliikmeline	"viie+liikmeline %liikme  )LINE_aA  <viie+liige ;05_S	et	f	\N
158013	sadaviiekrooniline	?sadaviiekrooniline =sadaviiekrooniline  (SgN  >sadaviiekrooniline !12_A	et	f	\N
158014	sadaviiekrooniline	?sadaviiekrooniline =sadaviiekrooniline  (PlP  >sadaviiekroonilin !19_S	et	f	\N
158015	nõudeti	?nõudeti =nõude  (IndIpfIps  >nõudema !27_V	et	f	\N
158016	nõudeti	?nõudeti =nõudeti  (ID  >nõudeti !41_D	et	f	\N
158017	nõudeti	?nõudeti =nõudeti  (SgG  >nõudett !22_S	et	f	\N
158018	nõudeti	?nõudeti =nõudeti  (IndPrPs_  >nõudettima !28_V	et	f	\N
158019	nõudeti	?nõudeti =nõudeti  (ImpPrSg2  >nõudettima !28_V	et	f	\N
158020	nõudeti	?nõudeti =deti  (SgN  >nõu+deti !16_S	et	f	\N
158021	nõudeti	?nõudeti =deti  (SgG  >nõu+deti !16_S	et	f	\N
158023	nõudeti	?nõudeti =deti  (SgG  >nõu+dett !22_S	et	f	\N
158033	lagunevad	lagunevad =lagune  (IndPrPl3  >lagunema !27_V	et	f	\N
158034	lagunevad	lagunevad =laguneva  (PlN  >lagunev !02_A	et	f	\N
158035	lagunevad	"lagunev %lagune  )V_vA  <lagunema ;27_V	et	f	\N
158065	pakkutud	?pakkutud =pakkutu  (PlN  >pakkutu !01_AS	et	f	\N
158066	pakkutud	?pakkutud =pakkutu  (IndPrSg2  >pakkutuma !27_V	et	f	\N
157716	kodused	"kodune %kodu  )NE_aA  <kodu ;17_S	et	f	\N
157740	znamennõj	### znamennõj	et	f	\N
157756	hoidjate	hoidjate =hoidja  (PlG  >hoidja !01_S	et	f	\N
157757	hoidjate	"hoidja %hoid  )JA_vS  <hoidma ;34_V	et	f	\N
157766	rezeknes	?rezeknes =rezekne  (PlIn  >rezekn !22_S	et	f	\N
157776	minskis	?minskis =minski  (SgIn  >minski !01_S	et	f	\N
157777	minskis	?minskis =minski  (SgIn  >minsk !22_S	et	f	\N
157778	minskis	?minskis =minski  (IndIpfSg3  >minskima !28_V	et	f	\N
157779	minskis	?minskis =minskis  (SgN  >minskis !09_S	et	f	\N
157783	grondas	?grondas =gronda  (SgIn  >gronda !16_S	et	f	\N
157784	grondas	?grondas =gronda  (IndIpfSg3  >grondama !29_V	et	f	\N
157785	grondas	?grondas =grondas  (SgN  >grondas !07_S	et	f	\N
157815	jevlampi	?jevlampi =jevlampi  (SgN  >jevlampi !01_S	et	f	\N
157816	jevlampi	?jevlampi =jevlampi  (SgG  >jevlampi !01_S	et	f	\N
157817	jevlampi	?jevlampi =jevlampi  (SgP  >jevlamp !22_S	et	f	\N
157818	jevlampi	?jevlampi =jevlampi  (SgAdt  >jevlamp !22_S	et	f	\N
157820	grebenshikovi	?grebenshikovi =grebenshikovi  (ID  >grebenshikovi !41_D	et	f	\N
157821	grebenshikovi	?grebenshikovi =grebenshikovi  (SgG  >grebenshikov !02_A	et	f	\N
157830	vaimiliku	?vaimiliku =vaimiliku  (SgG  >vaimilik !25_A	et	f	\N
157831	vaimiliku	?vaimiliku =vaimiliku  (IndPrPs_  >vaimilikuma !27_V	et	f	\N
157832	vaimiliku	?vaimiliku =vaimiliku  (ImpPrSg2  >vaimilikuma !27_V	et	f	\N
157833	vaimiliku	?vaimiliku =iliku  (SgN  >vaim+iliku !01_S	et	f	\N
157834	vaimiliku	?vaimiliku =iliku  (SgG  >vaim+iliku !01_S	et	f	\N
157835	vaimiliku	?vaimiliku =iliku  (SgG  >vaim+ilik !02_S	et	f	\N
157847	aseesimees	aseesimees =mee  (SgIn  >ase+esi+mesi !15_S	et	f	\N
157849	aseesimees	aseesimees =mees  (SgN  >ase+esi+mees !13_S	et	f	\N
157869	a-ruutu	a-ruutu =ruutu  (SgN  >a-ruutu !16_S	et	f	\N
157870	a-ruutu	a-ruutu =ruutu  (SgG  >a-ruutu !16_S	et	f	\N
157871	a-ruutu	a-ruutu =ruutu  (SgP  >a-ruut !22_S	et	f	\N
157872	a-ruutu	a-ruutu =ruutu  (SgAdt  >a-ruut !22_S	et	f	\N
157873	b-ruutu	b-ruutu =ruutu  (SgN  >b-ruutu !16_S	et	f	\N
157874	b-ruutu	b-ruutu =ruutu  (SgG  >b-ruutu !16_S	et	f	\N
157875	b-ruutu	b-ruutu =ruutu  (SgP  >b-ruut !22_S	et	f	\N
157876	b-ruutu	b-ruutu =ruutu  (SgAdt  >b-ruut !22_S	et	f	\N
157897	lähedes	?lähedes =lähe  (Ger  >lähema !27_V	et	f	\N
157907	kahekümnendaruutmetri	?kahekümnendaruutmetri =kahekümnendaruutmetri  (SgG  >kahekümnendaruutmetter !02_S	et	f	\N
157908	kahekümnendaruutmetri	?kahekümnendaruutmetri =utmetri  (SgN  >kahe+kümnend+aru+utmetri !01_S	et	f	\N
157909	kahekümnendaruutmetri	?kahekümnendaruutmetri =utmetri  (SgG  >kahe+kümnend+aru+utmetri !01_S	et	f	\N
157910	kahekümnendaruutmetri	?kahekümnendaruutmetri =utmetri  (SgG  >kahe+kümnend+aru+utmetter !02_S	et	f	\N
157911	kahekümnendaruutmetri	?kahekümnendaruutmetri =utmetri  (SgG  >kahe+kümnend+aru+utmeter !19_S	et	f	\N
157912	kahekümnendaruutmetri	?kahekümnendaruutmetri =utmetri  (SgP  >kahe+kümnend+aru+utmeter !19_S	et	f	\N
157913	kahekümnendaruutmetri	?kahekümnendaruutmetri =utmetri  (SgAdt  >kahe+kümnend+aru+utmeter !19_S	et	f	\N
157914	kahekümnendaruutmetri	?kahekümnendaruutmetri =aruutmetri  (SgG  >kahe+kümnend+aruutmetter !02_S	et	f	\N
157915	kahekümnendaruutmetri	?kahekümnendaruutmetri =kümnendaruutmetri  (SgG  >kahe+kümnendaruutmetter !02_S	et	f	\N
157926	katalogi	?katalogi =katalo  (SgN^  >katalo !01_S	et	f	\N
157927	katalogi	?katalogi =katalo  (SgG^  >katalo !01_S	et	f	\N
157928	kerkibkaasneb	### kerkibkaasneb	et	f	\N
157946	mainet	mainet =maine  (SgP  >maine !06_S	et	f	\N
157947	mainet	"maine %mai  )NE_aA  <maa ;26_S	et	f	\N
157964	väljakutsuvalt	väljakutsuvalt =kutsuva  (SgAbl  >välja+kutsuv !02_A	et	f	\N
157965	väljakutsuvalt	"välja+kutsuvalt %kutsuva  )LT_mD  <välja+kutsuv ;02_A	et	f	\N
157977	jubedamaks	jubedamaks =jubedama  (SgTr  >jubedam !02_A	et	f	\N
157978	jubedamaks	"jubedam %jubeda  )M_cA  <jube ;02_A	et	f	\N
157984	sõlmides	sõlmides =sõlmi  (PlIn  >sõlm !22_S	et	f	\N
157985	sõlmides	sõlmides =sõlmi  (Ger  >sõlmima !28_V	et	f	\N
157988	kuuetunnine	kuuetunnine =tunnine  (SgN  >kuue+tunnine !10_A	et	f	\N
157989	kuuetunnine	"kuue+tunnine %tunni  )NE_aA  <kuue+tund ;22_S	et	f	\N
158000	oleti	?oleti =oleti  (ID  >oleti !41_D	et	f	\N
158001	oleti	?oleti =oleti  (SgG  >olett !22_S	et	f	\N
158002	oleti	?oleti =oleti  (IndPrPs_  >olettima !28_V	et	f	\N
158003	oleti	?oleti =oleti  (ImpPrSg2  >olettima !28_V	et	f	\N
158004	kataloogi	kataloogi =kataloogi  (SgG  >kataloog !22_S	et	f	\N
158005	kataloogi	kataloogi =kataloogi  (SgP  >kataloog !22_S	et	f	\N
158006	kataloogi	kataloogi =kataloogi  (SgAdt  >kataloog !22_S	et	f	\N
158007	kataloogi	kataloogi =kataloogi  (IndPrPs_  >kataloogima !28_V	et	f	\N
158008	kataloogi	kataloogi =kataloogi  (ImpPrSg2  >kataloogima !28_V	et	f	\N
158038	tulemaligi	tulemaligi =mali  (SgN^  >tule+mali !17_S	et	f	\N
158039	tulemaligi	tulemaligi =mali  (SgG^  >tule+mali !17_S	et	f	\N
158040	tulemaligi	tulemaligi =mali  (SgP^  >tule+mali !17_S	et	f	\N
158043	pooleteistmeetrine	pooleteistmeetrine =meetrine  (SgN  >poole+teist+meetrine !12~10_A	et	f	\N
158044	pooleteistmeetrine	"poole+teist+meetrine %meetri  )NE_aA  <poole+teist+meeter ;02_S	et	f	\N
158062	kaubadel	### kaubadel	et	f	\N
158076	poolteisemeetrine	poolteisemeetrine =meetrine  (SgN  >pool+teise+meetrine !12~10_A	et	f	\N
157788	usukaaslastele	usukaaslastele =kaaslas  (PlAll  >usu+kaaslane !12?10_S	et	f	\N
157789	kontsertrepertuaari	kontsertrepertuaari =repertuaari  (SgG  >kontsert+repertuaar !22_S	et	f	\N
157790	kontsertrepertuaari	kontsertrepertuaari =repertuaari  (SgP  >kontsert+repertuaar !22_S	et	f	\N
157791	kontsertrepertuaari	kontsertrepertuaari =repertuaari  (SgAdt  >kontsert+repertuaar !22_S	et	f	\N
157805	kogumikku	kogumikku =kogumikku  (SgP  >kogumik !25_S	et	f	\N
157806	kogumikku	kogumikku =kogumikku  (SgAdt  >kogumik !25_S	et	f	\N
157807	kogumikku	kogumikku =mikku  (SgP  >kogu+mikk !22_S	et	f	\N
157808	kogumikku	kogumikku =mikku  (SgAdt  >kogu+mikk !22_S	et	f	\N
157809	nimvanausuliste	?nimvanausuliste =nimvanausulis  (PlG  >nimvanausulis !09_S	et	f	\N
157810	nimvanausuliste	?nimvanausuliste =nimvanausulis  (PlG  >nimvanausuline !12_A	et	f	\N
157811	nimvanausuliste	?nimvanausuliste =nimvanausuliste  (PlP  >nimvanausulist !22_S	et	f	\N
157814	koorilikmed	### koorilikmed	et	f	\N
157822	kirikukoori	kirikukoori =koor  (PlP  >kiriku+koor !13_S	et	f	\N
157823	kirikukoori	kirikukoori =koori  (SgG  >kiriku+koor !22_S	et	f	\N
157824	kirikukoori	kirikukoori =koori  (SgP  >kiriku+koor !22_S	et	f	\N
157825	kirikukoori	kirikukoori =koori  (SgAdt  >kiriku+koor !22_S	et	f	\N
157826	ustavschik	?ustavschik =ustavschik  (SgN  >ustavschik !02_S	et	f	\N
157828	neumade	?neumade =neuma  (PlG  >neuma !16_S	et	f	\N
157836	tundmine	tundmine =tundmine  (SgN  >tundmine !12?10_S	et	f	\N
157837	tundmine	"tundmine %tund  )MINE_vS  <tundma ;34_V	et	f	\N
157841	kaunistuse	kaunistuse =kaunistuse  (SgG  >kaunistus !11_S	et	f	\N
157842	kaunistuse	"kaunistus %kaunista  )US_vS  <kaunistama ;27_V	et	f	\N
157843	nimelise	nimelise =nimelise  (SgG  >nimeline !12_A	et	f	\N
157844	nimelise	"nimeline %nime  )LINE_aA  <nimi ;20_S	et	f	\N
157850	kutsekool	kutsekool =koo  (SgAd  >kutse+kubu !18_S	et	f	\N
157851	kutsekool	kutsekool =kool  (SgN  >kutse+kool !22_S	et	f	\N
157867	tehke	tehke =teh  (ImpPrPl2  >tegema !28_V	et	f	\N
157868	tehke	tehke =tehke  (SgG  >tehe !06_S	et	f	\N
157904	sajaviiekrooni	sajaviiekrooni =krooni  (SgG  >saja+viie+kroon !22_S	et	f	\N
157905	sajaviiekrooni	sajaviiekrooni =krooni  (SgP  >saja+viie+kroon !22_S	et	f	\N
157906	sajaviiekrooni	sajaviiekrooni =krooni  (SgAdt  >saja+viie+kroon !22_S	et	f	\N
157916	ühesõnalised	ühesõnalised =sõnalise  (PlN  >ühe+sõnaline !12_A	et	f	\N
157917	ühesõnalised	"ühe+sõnaline %sõna  )LINE_aA  <ühe+sõna ;17_S	et	f	\N
157923	purunevad	purunevad =purune  (IndPrPl3  >purunema !27_V	et	f	\N
157924	purunevad	purunevad =puruneva  (PlN  >purunev !02_A	et	f	\N
157925	purunevad	"purunev %purune  )V_vA  <purunema ;27_V	et	f	\N
157944	kahjustasid	kahjustasid =kahjusta  (IndIpfSg2  >kahjustama !27_V	et	f	\N
157945	kahjustasid	kahjustasid =kahjusta  (IndIpfPl3  >kahjustama !27_V	et	f	\N
157954	maitsetult	maitsetult =maitsetu  (SgAbl  >maitsetu !01_A	et	f	\N
157955	maitsetult	"maitsetu %maitse  )TU1_vS  <maitsema ;28_V	et	f	\N
157956	maitsetult	"maitsetu %maitse  )TU2_kA  <maitse ;06_S	et	f	\N
157957	maitsetult	maitsetult =maitsetult  (ID  >maitsetult !41_D	et	f	\N
157958	maitsetult	"maitsetult %maitse  )TULT1_mD  <maitsema ;28_V	et	f	\N
157959	maitsetult	"maitsetult %maitse  )TULT2_mD  <maitse ;06_S	et	f	\N
157960	maitsetult	"maitsetult %maitsetu  )LT_mD  <maitsetu ;01_A	et	f	\N
157986	pooleteisemeetrine	pooleteisemeetrine =meetrine  (SgN  >poole+teise+meetrine !12~10_A	et	f	\N
157987	pooleteisemeetrine	"poole+teise+meetrine %meetri  )NE_aA  <poole+teise+meeter ;02_S	et	f	\N
158041	hirmuslik	?hirmuslik =hirmuslik  (SgN  >hirmuslik !25_A	et	f	\N
158042	hirmuslik	?hirmuslik =uslik  (SgN  >hirm+uslik !25_A	et	f	\N
158049	nõudi	?nõudi =nõudi  (SgN  >nõudi !16_S	et	f	\N
158050	nõudi	?nõudi =nõudi  (SgG  >nõudi !16_S	et	f	\N
158051	nõudi	?nõudi =nõudi  (SgG  >nõut !22_S	et	f	\N
158052	nõudi	?nõudi =nõudi  (SgP  >nõud !22_S	et	f	\N
158053	nõudi	?nõudi =nõudi  (SgAdt  >nõud !22_S	et	f	\N
158054	nõudi	?nõudi =nõudi  (IndPrPs_  >nõutima !28_V	et	f	\N
158055	nõudi	?nõudi =nõudi  (ImpPrSg2  >nõutima !28_V	et	f	\N
158078	viieliigeline	?viieliigeline =viieliigeline  (SgN  >viieliigeline !12_A	et	f	\N
158079	viieliigeline	?viieliigeline =viieliigeline  (PlP  >viieliigelin !19_S	et	f	\N
158080	viieliigeline	?viieliigeline =eline  (SgN  >viie+liig+eline !10_A	et	f	\N
158081	viieliigeline	?viieliigeline =liigeline  (SgN  >viie+liigeline !12_A	et	f	\N
158082	viieliigeline	?viieliigeline =liigeline  (PlP  >viie+liigelin !19_S	et	f	\N
158087	kiresti	?kiresti =kiresti  (ID  >kiresti !41_D	et	f	\N
158088	kiresti	?kiresti =kiresti  (IndPrPs_  >kirestima !28_V	et	f	\N
158089	kiresti	?kiresti =kiresti  (ImpPrSg2  >kirestima !28_V	et	f	\N
158119	kahekümmeruutmeetrine	kahekümmeruutmeetrine =meetrine  (SgN  >kahe+kümme+ruut+meetrine !12~10_A	et	f	\N
158120	kahekümmeruutmeetrine	"kahe+kümme+ruut+meetrine %meetri  )NE_aA  <kahe+kümme+ruut+meeter ;02_S	et	f	\N
158126	oledes	?oledes =ole  (PlIn  >ole !16_S	et	f	\N
158142	korglusse	?korglusse =korglu  (SgIll  >korglu !01_S	et	f	\N
158143	korglusse	?korglusse =korglus  (SgAdt  >korglus !11_S	et	f	\N
158144	korglusse	?korglusse =korglusse  (SgG  >korglusne !02_A	et	f	\N
158145	korglusse	?korglusse =korglusse  (PlP  >korgluss !22_S	et	f	\N
158172	hirmune	hirmune =hirmune  (SgN  >hirmune !10_A	et	f	\N
157840	haruldaselt	"haruldaselt %haruldase  )LT_mD  <haruldane ;12_A	et	f	\N
157856	luulekava	luulekava =kava  (SgN  >luule+kava !17_S	et	f	\N
157857	luulekava	luulekava =kava  (SgG  >luule+kava !17_S	et	f	\N
157858	luulekava	luulekava =kava  (SgP  >luule+kava !17_S	et	f	\N
157859	jõgeva	?jõgeva =jõgeva  (SgN  >jõgeva !01_S	et	f	\N
157860	jõgeva	?jõgeva =jõgeva  (SgG  >jõgeva !01_S	et	f	\N
157861	jõgeva	?jõgeva =jõgeva  (SgG  >jõgev !02_A	et	f	\N
157883	hannes	?hannes =hanne  (PlIn  >hann !22_S	et	f	\N
157884	hannes	?hannes =hanne  (IndIpfSg3  >hannema !27_V	et	f	\N
157885	hannes	?hannes =hannes  (SgN  >hannes !09_S	et	f	\N
157887	sundima	sundima =sundi  (Sup  >sundima !28_V	et	f	\N
157888	sundima	sundima =ima  (SgN  >sund+ima !17_S	et	f	\N
157889	sundima	sundima =ima  (SgG  >sund+ima !17_S	et	f	\N
157890	sundima	sundima =ima  (SgP  >sund+ima !17_S	et	f	\N
157896	solmites	?solmites =solmite  (PlIn  >solmitt !22_S	et	f	\N
157902	viieliige	viieliige =liige  (SgN  >viie+liige !05_S	et	f	\N
157903	viieliige	viieliige =liige  (PlP  >viie+liig !22_S	et	f	\N
157919	tootedetel	?tootedetel =tootedete  (PlAd  >tootedett !22_S	et	f	\N
157920	tootedetel	?tootedetel =dete  (PlAd  >toote+dett !22_S	et	f	\N
157921	tootedetel	?tootedetel =detel  (SgN  >toote+detel !02_S	et	f	\N
157922	tootedetel	?tootedetel =tedete  (PlAd  >too+tedett !22_S	et	f	\N
157969	lõhnas	lõhnas =lõhna  (SgIn  >lõhn !22_S	et	f	\N
157970	lõhnas	lõhnas =lõhna  (IndIpfSg3  >lõhnama !29_V	et	f	\N
157979	ootamatult	ootamatult =ootamatu  (SgAbl  >ootamatu !01_A	et	f	\N
157980	ootamatult	"ootamatu %oota  )MATU_vA  <ootama ;29_V	et	f	\N
157981	ootamatult	ootamatult =ootamatult  (ID  >ootamatult !41_D	et	f	\N
157982	ootamatult	"ootamatult %oota  )MATULT_mD  <ootama ;29_V	et	f	\N
157983	ootamatult	"ootamatult %ootamatu  )LT_mD  <ootamatu ;01_A	et	f	\N
157992	sajaviiekroonine	sajaviiekroonine =ine  (SgN  >saja+viie+kroon+ine !16_S	et	f	\N
157993	sajaviiekroonine	sajaviiekroonine =ine  (SgG  >saja+viie+kroon+ine !16_S	et	f	\N
157994	sajaviiekroonine	sajaviiekroonine =kroonine  (SgN  >saja+viie+kroonine !10_AS	et	f	\N
157995	sajaviiekroonine	"saja+viie+kroonine %krooni  )NE_aA  <saja+viie+kroon ;22_S	et	f	\N
157998	liisama	?liisama =liisa  (Sup  >liisama !29_V	et	f	\N
157999	liisama	?liisama =liisama  (SgG  >liisam !02_A	et	f	\N
158009	lahtiselt	lahtiselt =lahtise  (SgAbl  >lahtine !12~10_A	et	f	\N
158010	lahtiselt	lahtiselt =lahtiselt  (ID  >lahtiselt !41_D	et	f	\N
158011	lahtiselt	"lahtiselt %lahtise  )LT_mD  <lahtine ;10_A	et	f	\N
158012	lahtiselt	"lahtiselt %lahtise  )LT_mD  <lahtine ;12_A	et	f	\N
158022	laseti	?laseti =lase  (IndIpfIps  >lasema !27_V	et	f	\N
158024	laseti	?laseti =laseti  (ID  >laseti !41_D	et	f	\N
158025	laseti	?laseti =laseti  (SgG  >lasett !22_S	et	f	\N
158026	laseti	?laseti =laseti  (IndPrPs_  >lasettima !28_V	et	f	\N
158027	laseti	?laseti =laseti  (ImpPrSg2  >lasettima !28_V	et	f	\N
158036	korteriühistu	korteriühistu =ühistu  (SgN  >korteri+ühistu !01_S	et	f	\N
158037	korteriühistu	korteriühistu =ühistu  (SgG  >korteri+ühistu !01_S	et	f	\N
158056	ostati	?ostati =osta  (IndIpfIps  >ostama !29_V	et	f	\N
158057	ostati	?ostati =ostati  (ID  >ostati !41_D	et	f	\N
158058	ostati	?ostati =ostati  (SgG  >ostat !02_S	et	f	\N
158059	ostati	?ostati =ostati  (SgG  >ostatt !22_S	et	f	\N
158060	ostati	?ostati =ostati  (IndPrPs_  >ostattima !28_V	et	f	\N
158061	ostati	?ostati =ostati  (ImpPrSg2  >ostattima !28_V	et	f	\N
158083	ruutmeetriline	ruutmeetriline =meetriline  (SgN  >ruut+meetriline !12_A	et	f	\N
158084	ruutmeetriline	"ruut+meetriline %meetri  )LINE_aA  <ruut+meeter ;02_S	et	f	\N
158100	sajaviiekrooniline	sajaviiekrooniline =krooniline  (SgN  >saja+viie+krooniline !12_A	et	f	\N
158101	sajaviiekrooniline	"saja+viie+krooniline %krooni  )LINE_aA  <saja+viie+kroon ;22_S	et	f	\N
158115	sajaviie	?sajaviie =sajaviie  (SgN  >sajaviie !01_S	et	f	\N
158116	sajaviie	?sajaviie =sajaviie  (SgG  >sajaviie !01_S	et	f	\N
158117	sajaviie	?sajaviie =viie  (SgN  >saja+viie !06_S	et	f	\N
158118	sajaviie	?sajaviie =viie  (SgG  >saja+viie !06_S	et	f	\N
158124	olgedes	?olgedes =olge  (Ger  >olgema !27_V	et	f	\N
158127	remoni	?remoni =remo  (SgTer  >remo !17~16_S	et	f	\N
158128	remoni	?remoni =remoni  (SgG  >remon !02_S	et	f	\N
158132	ostas	?ostas =osta  (SgIn  >osta !16_S	et	f	\N
158133	ostas	?ostas =osta  (IndIpfSg3  >ostama !29_V	et	f	\N
158134	ostas	?ostas =ostas  (SgN  >ostas !07_S	et	f	\N
158135	kerkibkaasnebhaldab	?kerkibkaasnebhaldab =kerkibkaasnebhalda  (IndPrSg3  >kerkibkaasnebhaldama !27_V	et	f	\N
158166	eksitavadkehtivad	?eksitavadkehtivad =eksitavadkehtiva  (PlN  >eksitavadkehtiv !02_A	et	f	\N
158167	eksitavadkehtivad	?eksitavadkehtivad =eksitavadkehtiva  (PlN  >eksitavadkehtiva !16_S	et	f	\N
158168	eksitavadkehtivad	?eksitavadkehtivad =tavadkehtiva  (PlN  >eksi+tavadkehtiv !02_A	et	f	\N
158169	eksitavadkehtivad	?eksitavadkehtivad =tavadkehtiva  (PlN  >eksi+tavadkehtiva !16_S	et	f	\N
158170	eksitavadkehtivad	?eksitavadkehtivad =itavadkehtiva  (PlN  >eks+itavadkehtiv !02_A	et	f	\N
158171	eksitavadkehtivad	?eksitavadkehtivad =itavadkehtiva  (PlN  >eks+itavadkehtiva !16_S	et	f	\N
158178	vaatades	?vaatades =vaata  (PlIn  >vaata !16_S	et	f	\N
158179	suhtlemides	?suhtlemides =lemi  (PlIn  >suht+lemi !17_S	et	f	\N
157938	käimatoime	käimatoime =toime  (PlP  >käima+toim !22_S	et	f	\N
157948	puänti	puänti =puänti  (SgP  >puänt !22_S	et	f	\N
157949	puänti	puänti =puänti  (SgAdt  >puänt !22_S	et	f	\N
157950	tüdinult	tüdinult =tüdinu  (SgAbl  >tüdinu !01_S	et	f	\N
157951	tüdinult	"tüdinu %tüdi  )NU_vS  <tüdima ;27_V	et	f	\N
157952	tüdinult	tüdinult =tüdinult  (ID  >tüdinult !41_D	et	f	\N
157953	tüdinult	"tüdinult %tüdi  )NULT_mD  <tüdima ;27_V	et	f	\N
157966	pealetükkivalt	pealetükkivalt =iva  (SgAbl  >peale+tükk+iva !17_S	et	f	\N
157967	pealetükkivalt	pealetükkivalt =tükkiva  (SgAbl  >peale+tükkiv !02_A	et	f	\N
157968	pealetükkivalt	"peale+tükkivalt %tükkiva  )LT_mD  <peale+tükkiv ;02_A	et	f	\N
157971	isuäratavalt	isuäratavalt =tava  (SgAbl  >isu+ära+tava !17_S	et	f	\N
157972	isuäratavalt	isuäratavalt =äratava  (SgAbl  >isu+äratav !02_A	et	f	\N
157973	isuäratavalt	"isu+äratavalt %äratava  )LT_mD  <isu+äratav ;02_A	et	f	\N
157996	kahekümneruutmeetrine	kahekümneruutmeetrine =meetrine  (SgN  >kahe+kümne+ruut+meetrine !12~10_A	et	f	\N
157997	kahekümneruutmeetrine	"kahe+kümne+ruut+meetrine %meetri  )NE_aA  <kahe+kümne+ruut+meeter ;02_S	et	f	\N
158028	lasteti	?lasteti =laste  (IndIpfIps  >lastema !27_V	et	f	\N
158029	lasteti	?lasteti =lasteti  (ID  >lasteti !41_D	et	f	\N
158030	lasteti	?lasteti =lasteti  (SgG  >lastett !22_S	et	f	\N
158031	lasteti	?lasteti =lasteti  (IndPrPs_  >lastettima !28_V	et	f	\N
158032	lasteti	?lasteti =lasteti  (ImpPrSg2  >lastettima !28_V	et	f	\N
158045	kroonine	kroonine =kroonine  (SgN  >kroonine !10_AS	et	f	\N
158046	kroonine	"kroonine %krooni  )NE_aA  <kroon ;22_S	et	f	\N
158047	kroonine	kroonine =ine  (SgN  >kroon+ine !16_S	et	f	\N
158048	kroonine	kroonine =ine  (SgG  >kroon+ine !16_S	et	f	\N
158063	hülgima	?hülgima =hülgi  (Sup  >hülgima !28_V	et	f	\N
158064	hülgima	?hülgima =hülgima  (SgG  >hülgim !02_A	et	f	\N
158068	oldud	oldud =ol  (PtsPtIps  >olema !36_V	et	f	\N
158069	oldud	oldud =oldud  (ID  >oldud !41_A	et	f	\N
158070	oldud	"oldud %ol  )TUD_vA  <olema ;36_V	et	f	\N
158093	piinlikult	piinlikult =piinliku  (SgAbl  >piinlik !25_A	et	f	\N
158094	piinlikult	piinlikult =piinlikult  (ID  >piinlikult !41_D	et	f	\N
158095	piinlikult	"piinlikult %piinliku  )LT_mD  <piinlik ;25_A	et	f	\N
158096	pooleteistmeetriline	pooleteistmeetriline =meetriline  (SgN  >poole+teist+meetriline !12_A	et	f	\N
158097	pooleteistmeetriline	"poole+teist+meetriline %meetri  )LINE_aA  <poole+teist+meeter ;02_S	et	f	\N
158098	kahekümnemeetriline	kahekümnemeetriline =meetriline  (SgN  >kahe+kümne+meetriline !12_A	et	f	\N
158099	kahekümnemeetriline	"kahe+kümne+meetriline %meetri  )LINE_aA  <kahe+kümne+meeter ;02_S	et	f	\N
158106	püsivatel	püsivatel =püsiva  (PlAd  >püsiv !02_A	et	f	\N
158107	püsivatel	"püsiv %püsi  )V_vA  <püsima ;27_V	et	f	\N
158108	püsivatel	püsivatel =vate  (PlAd  >püsi+vatt !22_S	et	f	\N
158111	poolteistmeetrine	poolteistmeetrine =meetrine  (SgN  >pool+teist+meetrine !12~10_A	et	f	\N
158112	poolteistmeetrine	"pool+teist+meetrine %meetri  )NE_aA  <pool+teist+meeter ;02_S	et	f	\N
158121	kehva	kehva =kehva  (SgG  >kehv !22_A	et	f	\N
158122	kehva	kehva =kehva  (SgP  >kehv !22_A	et	f	\N
158123	kehva	kehva =kehva  (SgAdt  >kehv !22_A	et	f	\N
158136	mainetpuänti	?mainetpuänti =mainetpuänti  (SgP  >mainetpuänt !22_S	et	f	\N
158137	mainetpuänti	?mainetpuänti =mainetpuänti  (SgAdt  >mainetpuänt !22_S	et	f	\N
158138	mainetpuänti	?mainetpuänti =netpuänti  (SgN  >mai+netpuänti !01_S	et	f	\N
158139	mainetpuänti	?mainetpuänti =netpuänti  (SgG  >mai+netpuänti !01_S	et	f	\N
158140	mainetpuänti	?mainetpuänti =netpuänti  (SgP  >mai+netpuänt !22_S	et	f	\N
158141	mainetpuänti	?mainetpuänti =netpuänti  (SgAdt  >mai+netpuänt !22_S	et	f	\N
158146	ootades	?ootades =oota  (PlIn  >oota !16_S	et	f	\N
158149	selgitama	selgitama =selgi  (SupIps  >selgima !27_V	et	f	\N
158150	selgitama	selgitama =selgita  (Sup  >selgitama !27_V	et	f	\N
158159	ollati	?ollati =olla  (IndIpfIps  >oldama !29_V	et	f	\N
158161	ollati	?ollati =ollati  (ID  >ollati !41_D	et	f	\N
158162	ollati	?ollati =ollati  (SgG  >ollat !02_S	et	f	\N
158163	ollati	?ollati =ollati  (SgG  >ollatt !22_S	et	f	\N
158164	ollati	?ollati =ollati  (IndPrPs_  >ollattima !28_V	et	f	\N
158165	ollati	?ollati =ollati  (ImpPrSg2  >ollattima !28_V	et	f	\N
158192	mikroraioni	?mikroraioni =mikroraio  (SgTer  >mikroraio !01_S	et	f	\N
158193	mikroraioni	?mikroraioni =mikroraioni  (SgN  >mikroraioni !16_S	et	f	\N
158194	mikroraioni	?mikroraioni =mikroraioni  (SgG  >mikroraioni !16_S	et	f	\N
158195	mikroraioni	?mikroraioni =mikroraioni  (SgG  >mikroraion !19_S	et	f	\N
158196	mikroraioni	?mikroraioni =mikroraioni  (SgP  >mikroraion !19_S	et	f	\N
158197	mikroraioni	?mikroraioni =mikroraioni  (SgAdt  >mikroraion !19_S	et	f	\N
158198	mikroraioni	?mikroraioni =mikroraioni  (IndPrPs_  >mikroraionima !28_V	et	f	\N
158199	mikroraioni	?mikroraioni =mikroraioni  (ImpPrSg2  >mikroraionima !28_V	et	f	\N
158200	mikroraioni	?mikroraioni =raioni  (SgG  >mikro+raion !02_S	et	f	\N
158211	jüurvili	?jüurvili =jüurvili  (ID  >jüurvili !41_D	et	f	\N
158226	elektroonika	elektroonika =elektroonika  (SgN  >elektroonika !01_S	et	f	\N
158227	elektroonika	elektroonika =elektroonika  (SgG  >elektroonika !01_S	et	f	\N
158248	kioskus	?kioskus =kiosku  (SgIn  >kiosku !01_S	et	f	\N
158067	pakkutud	?pakkutud =pakkutud  (ID  >pakkutud !41_A	et	f	\N
158071	üleolevadeksitavad	?üleolevadeksitavad =üleolevadeksita  (IndPrPl3  >üleolevadeksitama !27_V	et	f	\N
158072	üleolevadeksitavad	?üleolevadeksitavad =üleolevadeksitava  (PlN  >üleolevadeksitav !02_A	et	f	\N
158073	üleolevadeksitavad	?üleolevadeksitavad =üleolevadeksitava  (PlN  >üleolevadeksitava !16_S	et	f	\N
158074	üleolevadeksitavad	?üleolevadeksitavad =olevadeksitava  (PlN  >üle+olevadeksitav !02_A	et	f	\N
158075	üleolevadeksitavad	?üleolevadeksitavad =olevadeksitava  (PlN  >üle+olevadeksitava !16_S	et	f	\N
158085	tootedel	?tootedel =tede  (SgAd  >too+tede !16_S	et	f	\N
158086	tootedel	?tootedel =tedel  (SgN  >too+tedel !02_S	et	f	\N
158090	hirmuv	hirmuv =hirmu  (PtsPrPs  >hirmuma !27_V	et	f	\N
158091	hirmuv	hirmuv =hirmuv  (SgN  >hirmuv !02_A	et	f	\N
158092	hirmuv	"hirmuv %hirmu  )V_vA  <hirmuma ;27_V	et	f	\N
158104	kvaliteeti	kvaliteeti =kvaliteeti  (SgP  >kvaliteet !22_S	et	f	\N
158105	kvaliteeti	kvaliteeti =kvaliteeti  (SgAdt  >kvaliteet !22_S	et	f	\N
158109	pakkumise	pakkumise =pakkumise  (SgG  >pakkumine !12_S	et	f	\N
158110	pakkumise	"pakkumine %pakku  )MINE_vS  <pakkuma ;28_V	et	f	\N
158113	viieliikmene	viieliikmene =liikmene  (SgN  >viie+liikmene !12~10_A	et	f	\N
158114	viieliikmene	"viie+liikmene %liikme  )NE_aA  <viie+liige ;05_S	et	f	\N
158125	võtkedes	?võtkedes =võtke  (Ger  >võtkema !27_V	et	f	\N
158129	pakkumis	?pakkumis =pakkumi  (SgIn  >pakkumi !01_S	et	f	\N
158130	pakkumis	?pakkumis =pakkumi  (SgIn  >pakkum !02_S	et	f	\N
158131	pakkumis	?pakkumis =pakkumis  (SgN  >pakkumis !11_S	et	f	\N
158147	tehades	?tehades =teha  (PlIn  >teha !17_S	et	f	\N
158148	tehades	?tehades =teha  (Ger  >tehama !27_V	et	f	\N
158157	osti	osti =osti  (SgG  >ost !22_S	et	f	\N
158158	osti	osti =osti  (SgP  >ost !22_S	et	f	\N
158160	osti	osti =osti  (SgAdt  >ost !22_S	et	f	\N
158201	vieeni	?vieeni =viee  (SgTer  >viee !26_S	et	f	\N
158202	vieeni	?vieeni =vieeni  (SgN  >vieeni !16_S	et	f	\N
158203	vieeni	?vieeni =vieeni  (SgG  >vieeni !16_S	et	f	\N
158204	vieeni	?vieeni =vieeni  (SgG  >vieen !22_S	et	f	\N
158205	vieeni	?vieeni =vieeni  (SgP  >vieen !22_S	et	f	\N
158206	vieeni	?vieeni =vieeni  (SgAdt  >vieen !22_S	et	f	\N
158207	vieeni	?vieeni =vieeni  (IndPrPs_  >vieenima !28_V	et	f	\N
158208	vieeni	?vieeni =vieeni  (ImpPrSg2  >vieenima !28_V	et	f	\N
158213	kirjiuta	?kirjiuta =kirjiu  (SgAb  >kirjiu !01_S	et	f	\N
158214	kirjiuta	?kirjiuta =kirjiuta  (IndPrPs_  >kirjiutama !27_V	et	f	\N
158215	kirjiuta	?kirjiuta =kirjiuta  (ImpPrSg2  >kirjiutama !27_V	et	f	\N
158233	välik	?välik =välik  (SgN  >välik !02_S	et	f	\N
158236	laheme	?laheme =lahe  (IndPrPl1  >lahema !27_V	et	f	\N
158259	osakonded	?osakonded =konde  (PlN  >osa+konne !06_S	et	f	\N
158278	kirje	kirje =kirje  (SgN  >kirje !06_S	et	f	\N
158279	kirje	kirje =kirje  (SgG  >kirje !06_S	et	f	\N
158294	kohvikeetja	kohvikeetja =keetja  (SgN  >kohvi+keetja !01_S	et	f	\N
158296	kohvikeetja	kohvikeetja =keetja  (SgG  >kohvi+keetja !01_S	et	f	\N
158304	müüaks	?müüaks =müüa  (SgTr  >müüa !16_S	et	f	\N
158305	müüaks	?müüaks =müüaks  (SgN  >müüaks !22_S	et	f	\N
158306	viieaastane	viieaastane =aastane  (SgN  >viie+aastane !12~10_A	et	f	\N
158307	viieaastane	"viie+aastane %aasta  )NE_aA  <viie+aasta ;01_S	et	f	\N
158326	helisema	helisema =helise  (Sup  >helisema !27_V	et	f	\N
158327	helisema	helisema =helisema  (SgG  >helisem !02_A	et	f	\N
158328	helisema	"helisem %heli  )SEM_cA  <heli ;17_S	et	f	\N
158334	sadama	sadama =sada  (Sup  >sadama !28_V	et	f	\N
158335	sadama	sadama =sadama  (SgG  >sadam !02_S	et	f	\N
158349	päevatamine	?päevatamine =päevatamine  (SgN  >päevatamine !12_S	et	f	\N
158350	päevatamine	?päevatamine =päevatamine  (PlP  >päevatamin !19_S	et	f	\N
158351	päevatamine	?päevatamine =tamine  (SgN  >päeva+tamine !10_A	et	f	\N
158352	päevatamine	?päevatamine =atamine  (SgN  >päev+atamine !12_S	et	f	\N
158353	päevatamine	?päevatamine =atamine  (PlP  >päev+atamin !19_S	et	f	\N
158354	laheb	?laheb =lahe  (IndPrSg3  >lahema !27_V	et	f	\N
158363	oovin	?oovin =oovi  (IndPrSg1  >oovima !28_V	et	f	\N
158364	oovin	?oovin =oovin  (SgN  >oovin !02_S	et	f	\N
158375	jarve	?jarve =jarve  (SgN  >jarve !06_S	et	f	\N
158376	jarve	?jarve =jarve  (SgG  >jarve !06_S	et	f	\N
158377	jarve	?jarve =jarve  (PlP  >jarv !22_S	et	f	\N
158378	jarve	?jarve =jarve  (IndPrPs_  >jarvema !27_V	et	f	\N
158379	jarve	?jarve =jarve  (ImpPrSg2  >jarvema !27_V	et	f	\N
158380	päivitame	?päivitame =päivita  (IndPrPl1  >päivitama !27_V	et	f	\N
158387	katja	katja =katja  (SgN  >katja !01_S	et	f	\N
158388	katja	"katja %kat  )JA_vS  <katma ;35_V	et	f	\N
158389	katja	katja =katja  (SgG  >katja !01_S	et	f	\N
158401	tehnoloog	tehnoloog =tehnoloog  (SgN  >tehnoloog !22_S	et	f	\N
158402	tehnoloog	tehnoloog =loog  (SgN  >tehno+loog !22_S	et	f	\N
158439	nv	### nv	et	f	\N
158458	abc	?abc =abc  (SgN  >abc !22_S	et	f	\N
158465	keskallee	keskallee =allee  (SgN  >kesk+allee !26_S	et	f	\N
158466	keskallee	keskallee =allee  (SgG  >kesk+allee !26_S	et	f	\N
158479	01061977a	### 01061977a	et	f	\N
158486	jänku	jänku =jänku  (SgN  >jänku !16_S	et	f	\N
158077	poolteisemeetrine	"pool+teise+meetrine %meetri  )NE_aA  <pool+teise+meeter ;02_S	et	f	\N
158102	kahekümneruutmeetriline	kahekümneruutmeetriline =meetriline  (SgN  >kahe+kümne+ruut+meetriline !12_A	et	f	\N
158103	kahekümneruutmeetriline	"kahe+kümne+ruut+meetriline %meetri  )LINE_aA  <kahe+kümne+ruut+meeter ;02_S	et	f	\N
158151	lahtima	?lahtima =lahti  (Sup  >lahtima !28_V	et	f	\N
158152	lahtima	?lahtima =lahtima  (SgG  >lahtim !02_A	et	f	\N
158153	lugeti	?lugeti =lugeti  (ID  >lugeti !41_D	et	f	\N
158154	lugeti	?lugeti =lugeti  (SgG  >lugett !22_S	et	f	\N
158155	lugeti	?lugeti =lugeti  (IndPrPs_  >lugettima !28_V	et	f	\N
158156	lugeti	?lugeti =lugeti  (ImpPrSg2  >lugettima !28_V	et	f	\N
158186	olti	?olti =olti  (ID  >olti !41_D	et	f	\N
158187	olti	?olti =olti  (SgP  >olt !22_S	et	f	\N
158188	olti	?olti =olti  (SgAdt  >olt !22_S	et	f	\N
158189	fhdurjkv	?fhdurjkv =fhdurjkv  (SgN  >fhdurjkv !22_S	et	f	\N
158216	kohalen	?kohalen =kohale  (IndPrSg1  >kohalema !27_V	et	f	\N
158217	kohalen	?kohalen =kohalen  (SgN  >kohalen !19_S	et	f	\N
158218	taega	?taega =tae  (SgKom  >tae !26_S	et	f	\N
158219	taega	?taega =taega  (SgN  >taega !16_S	et	f	\N
158220	taega	?taega =taega  (SgG  >taega !16_S	et	f	\N
158221	taega	?taega =taega  (IndPrPs_  >taegama !29_V	et	f	\N
158222	taega	?taega =taega  (ImpPrSg2  >taegama !29_V	et	f	\N
158234	sõidma	?sõidma =sõidma  (IndPrPs_  >sõidmama !29_V	et	f	\N
158235	sõidma	?sõidma =sõidma  (ImpPrSg2  >sõidmama !29_V	et	f	\N
158244	kuulukse	kuulukse =kuulukse  (ID  >kuulukse !41_X	et	f	\N
158245	kuulukse	kuulukse =ukse  (SgG  >kuul+uks !14_S	et	f	\N
158246	kuulukse	kuulukse =lukse  (PlP  >kuu+luks !22_S	et	f	\N
158247	kuulukse	kuulukse =lukse  (PlP  >kuu+luks !22_SA	et	f	\N
158282	osakonnast	osakonnast =osakonna  (SgEl  >osakond !22_S	et	f	\N
158283	osakonnast	osakonnast =osakonnas  (SgP  >osakonnane !12_A	et	f	\N
158284	osakonnast	"osakonnane %osakonna  )NE_aA  <osakond ;22_S	et	f	\N
158285	osakonnast	osakonnast =konna  (SgEl  >osa+konn !22_S	et	f	\N
158286	osakonnast	osakonnast =konnas  (SgP  >osa+konnane !10_A	et	f	\N
158287	osakonnast	"osa+konnane %konna  )NE_aA  <osa+konn ;22_S	et	f	\N
158291	kingitusse	kingitusse =kingitu  (SgIll  >kingitu !01_AS	et	f	\N
158292	kingitusse	"kingitu %kingi  )TU1_vS  <kinkima ;28_V	et	f	\N
158293	kingitusse	"kingitu %kingi  )TU2_kA  <kink ;22_S	et	f	\N
158295	kingitusse	kingitusse =kingitus  (SgAdt  >kingitus !11_S	et	f	\N
158297	kingitusse	"kingitus %kingi  )TUS1_aS  <kinkima ;28_V	et	f	\N
158298	kingitusse	"kingitus %kingi  )TUS2_aS  <kink ;22_S	et	f	\N
158299	kingitusse	kingitusse =tusse  (PlP  >kingi+tuss !22_S	et	f	\N
158308	müüana	?müüana =müüa  (SgEs  >müüa !16_S	et	f	\N
158311	tähtsamalt	tähtsamalt =tähtsama  (SgAbl  >tähtsam !02_A	et	f	\N
158312	tähtsamalt	"tähtsam %tähtsa  )M_cA  <tähtis ;02_A	et	f	\N
158313	tähtsamalt	tähtsamalt =tähtsamalt  (ID  >tähtsamalt !41_D	et	f	\N
158314	tähtsamalt	"tähtsamalt %tähtsa  )MALT_mD  <tähtis ;02_A	et	f	\N
158325	murphy	### murphy	et	f	\N
158346	lapsiga	lapsiga =lapsi  (SgKom  >laps !22_S	et	f	\N
158347	lapsiga	lapsiga =iga  (SgN  >laps+iga !18_S	et	f	\N
158348	lapsiga	lapsiga =iga  (SgP  >laps+iga !18_S	et	f	\N
158356	õppib	### õppib	et	f	\N
158372	sooe	### sooe	et	f	\N
158382	ramatuid	?ramatuid =ramatu  (PlP  >ramatu !01_A	et	f	\N
158383	ramatuid	?ramatuid =ramatui  (PlN  >ramatui !26_S	et	f	\N
158384	ramatuid	?ramatuid =ramatui  (SgP  >ramatui !26_S	et	f	\N
158386	gümnaasiums	?gümnaasiums =gümnaasiums  (SgN  >gümnaasiums !22_S	et	f	\N
158390	juuni-juuli	juuni-juuli =juuli  (SgN  >juuni-juuli !16_S	et	f	\N
158391	juuni-juuli	juuni-juuli =juuli  (SgG  >juuni-juuli !16_S	et	f	\N
158392	mel	### mel	et	f	\N
158397	nr2	### nr2	et	f	\N
158398	sugu	sugu =sugu  (ID  >sugu !41_DA	et	f	\N
158399	sugu	sugu =sugu  (SgN  >sugu !18_S	et	f	\N
158400	sugu	sugu =sugu  (SgP  >sugu !18_S	et	f	\N
158405	kesk-eri	kesk-eri =eri  (ID  >kesk-eri !41_A	et	f	\N
158406	kesk-eri	kesk-eri =eri  (SgN  >kesk-eri !17_S	et	f	\N
158407	kesk-eri	kesk-eri =eri  (SgG  >kesk-eri !17_S	et	f	\N
158408	kesk-eri	kesk-eri =eri  (SgP  >kesk-eri !17_S	et	f	\N
158432	olesja	?olesja =olesja  (SgN  >olesja !01_S	et	f	\N
158433	olesja	?olesja =olesja  (SgG  >olesja !01_S	et	f	\N
158434	olesja	?olesja =olesja  (SgG  >olesjas !02_A	et	f	\N
158467	3keskool	?keskool =keskoo  (SgAd  >keskoo !26_S	et	f	\N
158468	3keskool	?keskool =keskool  (SgN  >keskool !22_S	et	f	\N
158469	3keskool	?keskool =ool  (SgN  >kesk+ool !22_S	et	f	\N
158470	eestonia	?eestonia =eestonia  (SgN  >eestonia !01_S	et	f	\N
158471	eestonia	?eestonia =eestonia  (SgG  >eestonia !01_S	et	f	\N
158472	eestonia	?eestonia =onia  (SgN  >eest+onia !01_S	et	f	\N
158473	eestonia	?eestonia =onia  (SgG  >eest+onia !01_S	et	f	\N
158474	eestonia	?eestonia =tonia  (SgN  >ees+tonia !01_S	et	f	\N
158475	eestonia	?eestonia =tonia  (SgG  >ees+tonia !01_S	et	f	\N
158476	õkauplus	?õkauplus =õkauplu  (SgIn  >õkauplu !01_S	et	f	\N
158477	õkauplus	?õkauplus =õkauplu  (IndIpfSg3  >õkaupluma !27_V	et	f	\N
158478	õkauplus	?õkauplus =õkauplus  (SgN  >õkauplus !11_S	et	f	\N
158173	hirmune	"hirmune %hirmu  )NE_aA  <hirm ;22_S	et	f	\N
158174	hirmune	hirmune =une  (SgG  >hirm+uni !20_S	et	f	\N
158175	sõlmites	?sõlmites =sõlmite  (PlIn  >sõlmitt !22_S	et	f	\N
158176	sõlmites	?sõlmites =ite  (PlIn  >sõlm+itt !22_S	et	f	\N
158177	sõlmites	?sõlmites =ites  (SgN  >sõlm+ites !09_S	et	f	\N
158190	kristina	?kristina =kristi  (SgEs  >kristi !16_S	et	f	\N
158191	kristina	?kristina =kristi  (SgEs  >krist !22_S	et	f	\N
158209	ostima	?ostima =osti  (Sup  >ostima !28_V	et	f	\N
158210	ostima	?ostima =ostima  (SgG  >ostim !02_A	et	f	\N
158230	kantseleiklaubad	?kantseleiklaubad =kantseleiklauba  (PlN  >kantseleiklauba !16_S	et	f	\N
158231	kantseleiklaubad	?kantseleiklaubad =klauba  (PlN  >kantselei+klauba !16_S	et	f	\N
158232	kantseleiklaubad	?kantseleiklaubad =seleiklauba  (PlN  >kant+seleiklauba !16_S	et	f	\N
158239	taiga	taiga =tai  (SgKom  >tai !26_S	et	f	\N
158240	taiga	taiga =taiga  (SgN  >taiga !16_S	et	f	\N
158241	taiga	taiga =taiga  (SgG  >taiga !16_S	et	f	\N
158242	taiga	taiga =taiga  (SgP  >taig !22_S	et	f	\N
158243	taiga	taiga =taiga  (SgAdt  >taig !22_S	et	f	\N
158271	nind	?nind =nind  (SgN  >nind !22_S	et	f	\N
158280	kauplussers	?kauplussers =kauplussers  (SgN  >kauplussers !22_S	et	f	\N
158281	kauplussers	?kauplussers =lussers  (SgN  >kaup+lussers !02_S	et	f	\N
158288	külasti	?külasti =külasti  (ID  >külasti !41_D	et	f	\N
158289	külasti	?külasti =külasti  (IndPrPs_  >külastima !28_V	et	f	\N
158290	külasti	?külasti =külasti  (ImpPrSg2  >külastima !28_V	et	f	\N
158300	kijra	?kijra =kijra  (SgN  >kijra !16_S	et	f	\N
158301	kijra	?kijra =kijra  (SgG  >kijra !16_S	et	f	\N
158302	kijra	?kijra =kijra  (IndPrPs_  >kijrama !29_V	et	f	\N
158303	kijra	?kijra =kijra  (ImpPrSg2  >kijrama !29_V	et	f	\N
158309	load	load =loa  (PlN  >luba !18_S	et	f	\N
158310	load	load =loa  (PlN  >luga !18_S	et	f	\N
158320	tähistatud	tähistatud =tähista  (PtsPtIps  >tähistama !27_V	et	f	\N
158321	tähistatud	tähistatud =tähistatu  (PlN  >tähistatu !01_S	et	f	\N
158322	tähistatud	"tähistatu %tähista  )TU1_vS  <tähistama ;27_V	et	f	\N
158323	tähistatud	tähistatud =tähistatud  (ID  >tähistatud !41_A	et	f	\N
158324	tähistatud	"tähistatud %tähista  )TUD_vA  <tähistama ;27_V	et	f	\N
158340	valutama	valutama =valu  (SupIps  >valuma !27_V	et	f	\N
158341	valutama	valutama =valuta  (Sup  >valutama !27_V	et	f	\N
158357	kirijutan	?kirijutan =kirijuta  (IndPrSg1  >kirijutama !27_V	et	f	\N
158358	kirijutan	?kirijutan =kirijutan  (SgN  >kirijutan !19_S	et	f	\N
158359	kirijutan	?kirijutan =jutan  (SgN  >kiri+jutan !02_S	et	f	\N
158365	oltan	?oltan =olta  (IndPrSg1  >oltama !29_V	et	f	\N
158366	oltan	?oltan =oltan  (SgN  >oltan !02_S	et	f	\N
158381	lugeme	### lugeme	et	f	\N
158385	tutar	?tutar =tutar  (SgN  >tutar !02_S	et	f	\N
158404	torhocet	### torhocet	et	f	\N
158414	sompa2	sompa =sompa  (IndPrPs_  >sompama !29_V	et	f	\N
158415	sompa2	sompa =sompa  (ImpPrSg2  >sompama !29_V	et	f	\N
158419	aleksandra	?aleksandra =aleksandra  (SgN  >aleksandra !16_S	et	f	\N
158420	aleksandra	?aleksandra =aleksandra  (SgG  >aleksandra !16_S	et	f	\N
158421	aleksandra	?aleksandra =ksandra  (SgN  >ale+ksandra !01_S	et	f	\N
158422	aleksandra	?aleksandra =ksandra  (SgG  >ale+ksandra !01_S	et	f	\N
158423	valaline	?valaline =valaline  (SgN  >valaline !12_A	et	f	\N
158424	valaline	?valaline =valaline  (PlP  >valalin !19_S	et	f	\N
158435	neine	?neine =neine  (SgN  >neine !10_A	et	f	\N
158436	neine	?neine =neine  (PlP  >nein !22_S	et	f	\N
158437	neine	?neine =neine  (IndPrPs_  >neinema !27_V	et	f	\N
158438	neine	?neine =neine  (ImpPrSg2  >neinema !27_V	et	f	\N
158488	ls	### ls	et	f	\N
158523	äitah	?äitah =äitah  (ID  >äitah !41_I	et	f	\N
158533	ostminest	?ostminest =ostmines  (SgP  >ostminene !12_A	et	f	\N
158544	provisid	?provisid =provi  (PlP  >provi !17_S	et	f	\N
158545	provisid	?provisid =provi  (IndIpfSg2  >provima !27_V	et	f	\N
158546	provisid	?provisid =provi  (IndIpfPl3  >provima !27_V	et	f	\N
158549	nadalil	?nadalil =nadali  (SgAd  >nadal !02_S	et	f	\N
158557	esti	?esti =esti  (SgN  >esti !16_S	et	f	\N
158558	esti	?esti =esti  (SgG  >esti !16_S	et	f	\N
158559	esti	?esti =esti  (SgG  >est !22_S	et	f	\N
158560	esti	?esti =esti  (SgP  >est !22_S	et	f	\N
158561	esti	?esti =esti  (SgAdt  >est !22_S	et	f	\N
158562	esti	?esti =esti  (IndPrPs_  >estima !28_V	et	f	\N
158563	esti	?esti =esti  (ImpPrSg2  >estima !28_V	et	f	\N
158572	aruanne	aruanne =anne  (SgN  >aru+anne !05_S	et	f	\N
158573	aruanne	aruanne =anne  (SgN  >aru+anne !06_S	et	f	\N
158578	ari	?ari =ari  (SgN  >ari !17_S	et	f	\N
158579	ari	?ari =ari  (SgG  >ari !17_S	et	f	\N
158580	ari	?ari =ari  (SgP  >ari !17_S	et	f	\N
158581	ari	?ari =ari  (IndPrPs_  >arima !27_V	et	f	\N
158582	ari	?ari =ari  (ImpPrSg2  >arima !27_V	et	f	\N
158593	aluset	### aluset	et	f	\N
158617	arvutil	arvutil =arvuti  (SgAd  >arvuti !01_S	et	f	\N
158618	arvutil	arvutil =uti  (SgAd  >arv+utt !22_S	et	f	\N
158619	arvutil	arvutil =uti  (PlAd  >arv+utt !22_S	et	f	\N
158624	pikemalt	pikemalt =pikema  (SgAbl  >pikem !02_A	et	f	\N
158180	nõudti	?nõudti =nõudti  (ID  >nõudti !41_D	et	f	\N
158181	nõudti	?nõudti =nõudti  (SgG  >nõudt !22_S	et	f	\N
158182	nõudti	?nõudti =nõudti  (SgP  >nõudt !22_S	et	f	\N
158183	nõudti	?nõudti =nõudti  (SgAdt  >nõudt !22_S	et	f	\N
158184	nõudti	?nõudti =nõudti  (IndPrPs_  >nõudtima !28_V	et	f	\N
158185	nõudti	?nõudti =nõudti  (ImpPrSg2  >nõudtima !28_V	et	f	\N
158212	jüurvilid	### jüurvilid	et	f	\N
158223	kätta	?kätta =kätta  (ID  >kätta !41_D	et	f	\N
158224	kätta	?kätta =kätta  (IndPrPs_  >kättama !29_V	et	f	\N
158225	kätta	?kätta =kätta  (ImpPrSg2  >kättama !29_V	et	f	\N
158228	parfümeeria	parfümeeria =parfümeeria  (SgN  >parfümeeria !01_S	et	f	\N
158229	parfümeeria	parfümeeria =parfümeeria  (SgG  >parfümeeria !01_S	et	f	\N
158237	vatad	?vatad =vata  (PlN  >vata !16_S	et	f	\N
158238	vatad	?vatad =vata  (IndPrSg2  >vatama !27_V	et	f	\N
158266	poma	?poma =poma  (SgN  >poma !17_S	et	f	\N
158267	poma	?poma =poma  (SgG  >poma !17_S	et	f	\N
158268	poma	?poma =poma  (SgP  >poma !17_S	et	f	\N
158269	poma	?poma =poma  (IndPrPs_  >pomama !27_V	et	f	\N
158270	poma	?poma =poma  (ImpPrSg2  >pomama !27_V	et	f	\N
158273	lija	?lija =lija  (SgN  >lija !17_S	et	f	\N
158274	lija	?lija =lija  (SgG  >lija !17_S	et	f	\N
158275	lija	?lija =lija  (SgP  >lija !17_S	et	f	\N
158276	lija	?lija =lija  (IndPrPs_  >lijama !27_V	et	f	\N
158277	lija	?lija =lija  (ImpPrSg2  >lijama !27_V	et	f	\N
158336	vihmavari	vihmavari =vari  (SgN  >vihma+vari !17_S	et	f	\N
158337	vihmavari	vihmavari =vari  (SgN  >vihma+vari !24_S	et	f	\N
158338	vihmavari	vihmavari =vari  (SgG  >vihma+vari !17_S	et	f	\N
158339	vihmavari	vihmavari =vari  (SgP  >vihma+vari !17_S	et	f	\N
158344	koolus	koolus =koolu  (SgIn  >koold !22_S	et	f	\N
158345	koolus	koolus =koolu  (SgIn  >kool !22_S	et	f	\N
158360	pansed	?pansed =panse  (IndPrSg2  >pansema !27_V	et	f	\N
158369	sober	?sober =sober  (SgN  >sober !02_S	et	f	\N
158373	olusad	?olusad =olusa  (PlN  >olusa !01_S	et	f	\N
158394	praktikast	praktikast =praktika  (SgEl  >praktika !01_S	et	f	\N
158395	praktikast	praktikast =praktikas  (SgP  >praktikane !12_A	et	f	\N
158396	praktikast	"praktikane %praktika  )NE_aA  <praktika ;01_S	et	f	\N
158403	oü	### oü	et	f	\N
158409	tehnik-tehnoloog	tehnik-tehnoloog =tehnoloog  (SgN  >tehnik-tehnoloog !22_S	et	f	\N
158410	tehnik-tehnoloog	tehnik-tehnoloog =loog  (SgN  >tehnik-tehno+loog !22_S	et	f	\N
158416	kaevandus	kaevandus =kaevandu  (IndIpfSg3  >kaevanduma !27_V	et	f	\N
158417	kaevandus	kaevandus =kaevandus  (SgN  >kaevandus !11_S	et	f	\N
158418	kaevandus	"kaevandus %kaevanda  )US_vS  <kaevandama ;27_V	et	f	\N
158428	uniform	?uniform =uniform  (SgN  >uniform !22_S	et	f	\N
158429	uniform	?uniform =form  (SgN  >uni+form !22_S	et	f	\N
158441	kohtla-jarvel	?kohtla-jarvel =jarve  (SgAd  >kohtla-jarve !06_S	et	f	\N
158442	kohtla-jarvel	?kohtla-jarvel =jarve  (PlAd  >kohtla-jarv !22_S	et	f	\N
158443	kohtla-jarvel	?kohtla-jarvel =jarvel  (SgN  >kohtla-jarvel !02_S	et	f	\N
158446	tuuslari	?tuuslari =tuuslari  (SgN  >tuuslari !01_S	et	f	\N
158447	tuuslari	?tuuslari =tuuslari  (SgG  >tuuslari !01_S	et	f	\N
158448	tuuslari	?tuuslari =tuuslari  (SgG  >tuuslar !02_S	et	f	\N
158449	tanja	?tanja =tanja  (SgN  >tanja !16_S	et	f	\N
158450	tanja	?tanja =tanja  (SgG  >tanjas !02_A	et	f	\N
158451	tanja	?tanja =tanja  (SgG  >tanja !16_S	et	f	\N
158452	tanja	?tanja =tanja  (IndPrPs_  >tanjama !29_V	et	f	\N
158453	tanja	?tanja =tanja  (ImpPrSg2  >tanjama !29_V	et	f	\N
158460	meditsinikool	?meditsinikool =meditsinikoo  (SgAd  >meditsinikoo !26_S	et	f	\N
158461	meditsinikool	?meditsinikool =meditsinikool  (SgN  >meditsinikool !22_S	et	f	\N
158462	meditsinikool	?meditsinikool =itsinikoo  (SgAd  >med+itsinikoo !26_S	et	f	\N
158463	meditsinikool	?meditsinikool =itsinikool  (SgN  >med+itsinikool !22_S	et	f	\N
158480	lõpputunnistus	?lõpputunnistus =lõpputunnistu  (IndIpfSg3  >lõpputunnistuma !27_V	et	f	\N
158481	lõpputunnistus	?lõpputunnistus =lõpputunnistus  (SgN  >lõpputunnistus !11~09_S	et	f	\N
158482	lõpputunnistus	?lõpputunnistus =utunnistus  (SgN  >lõpp+utunnistus !11~09_S	et	f	\N
158484	lahutatut	lahutatut =lahutatu  (SgP  >lahutatu !01_S	et	f	\N
158485	lahutatut	"lahutatu %lahuta  )TU1_vS  <lahutama ;27_V	et	f	\N
158502	vanemaa	?vanemaa =vanemaa  (SgN  >vanemaa !26_S	et	f	\N
158503	vanemaa	?vanemaa =vanemaa  (SgG  >vanemaa !26_S	et	f	\N
158516	evas	?evas =eva  (SgIn  >eva !17_S	et	f	\N
158517	evas	?evas =eva  (IndIpfSg3  >evama !27_V	et	f	\N
158518	evas	?evas =evas  (SgN  >evas !09_S	et	f	\N
158530	müüjakse	?müüjakse =müüjakse  (SgG  >müüjakne !02_A	et	f	\N
158536	vallime	?vallime =valli  (IndPrPl1  >vallima !28_V	et	f	\N
158594	õppiada	### õppiada	et	f	\N
158604	nulis	?nulis =nuli  (SgIn  >nuli !17_S	et	f	\N
158605	nulis	?nulis =nuli  (IndIpfSg3  >nulima !27_V	et	f	\N
158606	nulis	?nulis =nulis  (SgN  >nulis !09_S	et	f	\N
158607	müügisekretäri	müügisekretäri =sekretäri  (SgG  >müügi+sekretär !19_S	et	f	\N
158608	müügisekretäri	müügisekretäri =sekretäri  (SgP  >müügi+sekretär !19_S	et	f	\N
158609	müügisekretäri	müügisekretäri =sekretäri  (SgAdt  >müügi+sekretär !19_S	et	f	\N
158249	kioskus	?kioskus =kiosku  (IndIpfSg3  >kioskuma !27_V	et	f	\N
158250	kioskus	?kioskus =kioskus  (SgN  >kioskus !11~09_S	et	f	\N
158251	vieni	?vieni =vie  (SgTer  >vie !26_S	et	f	\N
158252	vieni	?vieni =vieni  (SgN  >vieni !16_S	et	f	\N
158253	vieni	?vieni =vieni  (SgG  >vieni !16_S	et	f	\N
158254	vieni	?vieni =vieni  (SgG  >vien !22_S	et	f	\N
158255	vieni	?vieni =vieni  (SgP  >vien !22_S	et	f	\N
158256	vieni	?vieni =vieni  (SgAdt  >vien !22_S	et	f	\N
158257	vieni	?vieni =vieni  (IndPrPs_  >vienima !28_V	et	f	\N
158258	vieni	?vieni =vieni  (ImpPrSg2  >vienima !28_V	et	f	\N
158260	kodutexnika	?kodutexnika =kodutexnika  (SgN  >kodutexnika !01_S	et	f	\N
158261	kodutexnika	?kodutexnika =kodutexnika  (SgG  >kodutexnika !01_S	et	f	\N
158262	kodutexnika	?kodutexnika =kodutexnika  (SgG  >kodutexnikas !02_A	et	f	\N
158263	kodutexnika	?kodutexnika =texnika  (SgN  >kodu+texnika !01_S	et	f	\N
158264	kodutexnika	?kodutexnika =texnika  (SgG  >kodu+texnika !01_S	et	f	\N
158265	kodutexnika	?kodutexnika =texnika  (SgG  >kodu+texnikas !02_S	et	f	\N
158272	260903a	### 260903a	et	f	\N
158315	telefoninimber	?telefoninimber =telefoninimber  (SgN  >telefoninimber !02_S	et	f	\N
158316	telefoninimber	?telefoninimber =nimber  (SgN  >telefoni+nimber !02_S	et	f	\N
158317	telefoninimber	?telefoninimber =inimber  (SgN  >telefon+inimber !02_S	et	f	\N
158318	telefoninimber	?telefoninimber =foninimber  (SgN  >tele+foninimber !02_S	et	f	\N
158319	ga	### ga	et	f	\N
158329	helisenud	helisenud =helise  (PtsPtPs  >helisema !27_V	et	f	\N
158330	helisenud	helisenud =helisenu  (PlN  >helisenu !01_S	et	f	\N
158331	helisenud	"helisenu %helise  )NU_vS  <helisema ;27_V	et	f	\N
158332	helisenud	helisenud =helisenud  (ID  >helisenud !41_A	et	f	\N
158333	helisenud	"helisenud %helise  )NUD_vA  <helisema ;27_V	et	f	\N
158342	lõppetab	?lõppetab =lõppeta  (IndPrSg3  >lõppetama !27_V	et	f	\N
158343	mrphy	### mrphy	et	f	\N
158355	õppib	### õppib	et	f	\N
158361	öötan	?öötan =ööta  (IndPrSg1  >öötama !27_V	et	f	\N
158362	öötan	?öötan =öötan  (SgN  >öötan !02_S	et	f	\N
158367	eksamin	?eksamin =eksamin  (SgN  >eksamin !19_S	et	f	\N
158368	eksamin	?eksamin =amin  (SgN  >eks+amin !02_S	et	f	\N
158370	venemeeale	venemeeale =ale  (SgN  >vene+mee+ale !16_S	et	f	\N
158371	venemeeale	venemeeale =ale  (SgG  >vene+mee+ale !16_S	et	f	\N
158374	korjutame	?korjutame =korjuta  (IndPrPl1  >korjutama !27_V	et	f	\N
158393	nr1	### nr1	et	f	\N
158411	töötatu	töötatu =töötatu  (SgN  >töötatu !01_S	et	f	\N
158412	töötatu	"töötatu %tööta  )TU1_vS  <töötama ;27_V	et	f	\N
158413	töötatu	töötatu =töötatu  (SgG  >töötatu !01_S	et	f	\N
158425	pärna	pärna =pärna  (SgG  >pärn !22_S	et	f	\N
158426	pärna	pärna =pärna  (SgP  >pärn !22_S	et	f	\N
158427	pärna	pärna =pärna  (SgAdt  >pärn !22_S	et	f	\N
158430	kommunnalteenustes	?kommunnalteenustes =kommunnalteenus  (PlIn  >kommunnalteenus !11~09_S	et	f	\N
158431	kommunnalteenustes	?kommunnalteenustes =munnalteenus  (PlIn  >kom+munnalteenus !11~09_S	et	f	\N
158440	jelena	?jelena =jele  (SgEs  >jele !16_S	et	f	\N
158444	olevi	olevi =olevi  (SgG  >olev !02_A	et	f	\N
158445	olevi	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
158454	puru	puru =puru  (ID  >puru !41_D	et	f	\N
158455	puru	puru =puru  (SgN  >puru !17_S	et	f	\N
158456	puru	puru =puru  (SgG  >puru !17_S	et	f	\N
158457	puru	puru =puru  (SgP  >puru !17_S	et	f	\N
158459	valentina	?valentina =valenti  (SgEs  >valenti !01_S	et	f	\N
158464	06101969a	### 06101969a	et	f	\N
158490	orti	?orti =orti  (ID  >orti !41_D	et	f	\N
158491	orti	?orti =orti  (SgP  >ort !22_S	et	f	\N
158492	orti	?orti =orti  (SgAdt  >ort !22_S	et	f	\N
158508	ene	?ene =ene  (SgN  >ene !16_S	et	f	\N
158509	ene	?ene =ene  (SgG  >ene !16_S	et	f	\N
158510	ene	?ene =ene  (IndPrPs_  >enema !27_V	et	f	\N
158511	ene	?ene =ene  (ImpPrSg2  >enema !27_V	et	f	\N
158512	läin	?läin =läin  (SgN  >läin !22_S	et	f	\N
158521	lobisemisest	lobisemisest =lobisemise  (SgEl  >lobisemine !12_S	et	f	\N
158522	lobisemisest	"lobisemine %lobise  )MINE_vS  <lobisema ;27_V	et	f	\N
158524	müügisekretar	?müügisekretar =müügisekretar  (SgN  >müügisekretar !19_S	et	f	\N
158525	müügisekretar	?müügisekretar =sekretar  (SgN  >müügi+sekretar !19_S	et	f	\N
158526	esmaabi	esmaabi =abi  (SgN  >esma+abi !17_S	et	f	\N
158527	esmaabi	esmaabi =abi  (SgG  >esma+abi !17_S	et	f	\N
158528	esmaabi	esmaabi =abi  (SgP  >esma+abi !17_S	et	f	\N
158529	õppitas	?õppitas =õppita  (IndIpfSg3  >õppitama !27_V	et	f	\N
158541	sekretar	?sekretar =sekretar  (SgN  >sekretar !19_S	et	f	\N
158554	õppetadi	?õppetadi =tadi  (SgN  >õppe+tadi !17_S	et	f	\N
158555	õppetadi	?õppetadi =tadi  (SgG  >õppe+tadi !17_S	et	f	\N
158556	õppetadi	?õppetadi =tadi  (SgP  >õppe+tadi !17_S	et	f	\N
158571	reklamerima	?reklamerima =reklamerima  (SgG  >reklamerim !02_A	et	f	\N
158577	akkame	?akkame =akka  (IndPrPl1  >akkama !29_V	et	f	\N
158583	es	### es	et	f	\N
158628	suunati	suunati =suuna  (IndIpfIps  >suunama !29_V	et	f	\N
158629	suunati	suunati =nati  (SgG  >suu+natt !22_S	et	f	\N
158483	onega	?onega =one  (SgKom  >one !16_S	et	f	\N
158489	29082003a	### 29082003a	et	f	\N
158493	eetevõtja	?eetevõtja =eetevõtja  (SgN  >eetevõtja !16_S	et	f	\N
158494	eetevõtja	?eetevõtja =eetevõtja  (SgG  >eetevõtjas !02_A	et	f	\N
158495	eetevõtja	?eetevõtja =eetevõtja  (SgG  >eetevõtja !16_S	et	f	\N
158499	iktorika	?iktorika =iktorika  (SgN  >iktorika !01_S	et	f	\N
158500	iktorika	?iktorika =iktorika  (SgG  >iktorika !01_S	et	f	\N
158501	iktorika	?iktorika =iktorika  (SgG  >iktorikas !02_A	et	f	\N
158504	eiole	?eiole =eiole  (IndPrPs_  >eiolema !27_V	et	f	\N
158505	eiole	?eiole =eiole  (ImpPrSg2  >eiolema !27_V	et	f	\N
158506	eiole	?eiole =ole  (SgN  >ei+ole !16_S	et	f	\N
158507	eiole	?eiole =ole  (SgG  >ei+ole !16_S	et	f	\N
158514	asjaajamise	asjaajamise =ajamise  (SgG  >asja+ajamine !12_S	et	f	\N
158515	asjaajamise	"asja+ajamine %ajami  )NE_aA  <asja+ajam ;02_S	et	f	\N
158531	ostjaga	ostjaga =ostja  (SgKom  >ostja !01_S	et	f	\N
158532	ostjaga	"ostja %ost  )JA_vS  <ostma ;34_V	et	f	\N
158547	esi	esi =esi  (SgN  >esi !15_S	et	f	\N
158548	esi	esi =esi  (PlP  >esi !15_S	et	f	\N
158564	töötal	?töötal =tööta  (SgAd  >tööta !16_S	et	f	\N
158565	töötal	?töötal =töötal  (SgN  >töötal !02_S	et	f	\N
158566	valmistavad	valmistavad =valmista  (IndPrPl3  >valmistama !27_V	et	f	\N
158567	valmistavad	valmistavad =valmistava  (PlN  >valmistav !02_A	et	f	\N
158568	valmistavad	"valmistav %valmista  )V_vA  <valmistama ;27_V	et	f	\N
158569	valmistavad	valmistavad =tava  (PlN  >valmis+tava !17_S	et	f	\N
158584	lõpetavad	lõpetavad =lõpeta  (IndPrPl3  >lõpetama !27_V	et	f	\N
158585	lõpetavad	lõpetavad =lõpetava  (PlN  >lõpetav !02_A	et	f	\N
158586	lõpetavad	"lõpetav %lõpe  )TAV_vAS  <lõppema ;28_V	et	f	\N
158587	lõpetavad	"lõpetav %lõpe  )TAV_vAS  <lõpma ;35_V	et	f	\N
158588	lõpetavad	"lõpetav %lõpeta  )V_vA  <lõpetama ;27_V	et	f	\N
158589	õppetatakse	?õppetatakse =õppeta  (IndPrIps  >õppetama !27_V	et	f	\N
158590	õppetatakse	?õppetatakse =õppetatakse  (SgG  >õppetatakne !02_A	et	f	\N
158591	õppetatakse	?õppetatakse =õppetatakse  (PlP  >õppetataks !22_S	et	f	\N
158592	õppetatakse	?õppetatakse =tatakse  (SgG  >õppe+tatakne !02_A	et	f	\N
158595	hulgiladusse	?hulgiladusse =hulgiladus  (SgAdt  >hulgiladus !11_S	et	f	\N
158596	hulgiladusse	?hulgiladusse =hulgiladusse  (SgG  >hulgiladusne !02_A	et	f	\N
158597	hulgiladusse	?hulgiladusse =hulgiladusse  (PlP  >hulgiladuss !22_S	et	f	\N
158598	hulgiladusse	?hulgiladusse =ladusse  (SgG  >hulgi+ladusne !02_A	et	f	\N
158599	hulgiladusse	?hulgiladusse =ladusse  (PlP  >hulgi+laduss !22_S	et	f	\N
158613	müüjaosakonna	müüjaosakonna =konna  (SgG  >müüja+osa+konn !22_S	et	f	\N
158614	müüjaosakonna	müüjaosakonna =konna  (SgP  >müüja+osa+konn !22_S	et	f	\N
158615	müüjaosakonna	müüjaosakonna =konna  (SgAdt  >müüja+osa+konn !22_S	et	f	\N
158616	müüjaosakonna	müüjaosakonna =osakonna  (SgG  >müüja+osakond !22_S	et	f	\N
158630	müügisekretarina	?müügisekretarina =müügisekretari  (SgEs  >müügisekretar !19_S	et	f	\N
158631	müügisekretarina	?müügisekretarina =müügisekretarina  (SgG  >müügisekretarin !19_S	et	f	\N
158632	müügisekretarina	?müügisekretarina =müügisekretarina  (SgP  >müügisekretarin !19_S	et	f	\N
158633	müügisekretarina	?müügisekretarina =müügisekretarina  (SgAdt  >müügisekretarin !19_S	et	f	\N
158634	müügisekretarina	?müügisekretarina =sekretari  (SgEs  >müügi+sekretar !19_S	et	f	\N
158635	müügisekretarina	?müügisekretarina =sekretarina  (SgG  >müügi+sekretarin !19_S	et	f	\N
158636	müügisekretarina	?müügisekretarina =sekretarina  (SgP  >müügi+sekretarin !19_S	et	f	\N
158637	müügisekretarina	?müügisekretarina =sekretarina  (SgAdt  >müügi+sekretarin !19_S	et	f	\N
158638	korralgamine	?korralgamine =korralgamine  (SgN  >korralgamine !12_S	et	f	\N
158639	korralgamine	?korralgamine =korralgamine  (PlP  >korralgamin !19_S	et	f	\N
158645	võtte	võtte =võtte  (SgG  >võte !06_S	et	f	\N
158646	võtte	võtte =võtte  (PlP  >võtt !22_S	et	f	\N
158661	ladule	?ladule =ladule  (IndPrPs_  >ladulema !27_V	et	f	\N
158662	ladule	?ladule =ladule  (ImpPrSg2  >ladulema !27_V	et	f	\N
158706	erakoolis	erakoolis =kooli  (SgIn  >era+kool !22_S	et	f	\N
158708	erakoolis	erakoolis =kooli  (PlIn  >era+kool !22_S	et	f	\N
158721	eeksam	?eeksam =eeksam  (SgN  >eeksam !02_A	et	f	\N
158722	imilikult	?imilikult =imiliku  (SgAbl  >imilik !25_A	et	f	\N
158723	imilikult	?imilikult =imilikult  (ID  >imilikult !41_D	et	f	\N
158725	kursetöö	?kursetöö =kursetöö  (SgN  >kursetöö !26_S	et	f	\N
158726	kursetöö	?kursetöö =kursetöö  (SgG  >kursetöö !26_S	et	f	\N
158740	kursusest	kursusest =kursuse  (SgEl  >kursus !11~09_S	et	f	\N
158741	kursusest	kursusest =kursuses  (SgP  >kursusene !12_A	et	f	\N
158742	kursusest	"kursusene %kursuse  )NE_aA  <kursus ;09_S	et	f	\N
158743	kursusest	"kursusene %kursuse  )NE_aA  <kursus ;11_S	et	f	\N
158744	eettevõtluse	?eettevõtluse =eettevõtluse  (SgG  >eettevõtlus !11~09_S	et	f	\N
158757	kulturimaja	?kulturimaja =kulturimaja  (SgN  >kulturimaja !01_S	et	f	\N
158758	kulturimaja	?kulturimaja =kulturimaja  (SgG  >kulturimaja !01_S	et	f	\N
158759	kulturimaja	?kulturimaja =kulturimaja  (SgG  >kulturimajas !02_A	et	f	\N
158760	psühologu	?psühologu =psühologu  (IndPrPs_  >psühologuma !27_V	et	f	\N
158487	jänku	jänku =jänku  (SgG  >jänku !16_S	et	f	\N
158496	maniküüriane	?maniküüriane =maniküüriane  (SgN  >maniküüriane !16_S	et	f	\N
158497	maniküüriane	?maniküüriane =maniküüriane  (SgG  >maniküüriane !16_S	et	f	\N
158498	maniküüriane	?maniküüriane =maniküüriane  (PlP  >maniküürian !19_S	et	f	\N
158513	õppeaised	?õppeaised =aise  (PlN  >õppe+aise !06_S	et	f	\N
158519	leidan	?leidan =leida  (IndPrSg1  >leidama !29_V	et	f	\N
158520	leidan	?leidan =leidan  (SgN  >leidan !02_S	et	f	\N
158534	tulle	tulle =tulle  (SgAdt  >tuli !20_S	et	f	\N
158535	tulle	tulle =tulle  (PlP  >tull !22_S	et	f	\N
158537	marta	?marta =marta  (SgN  >marta !16_S	et	f	\N
158538	marta	?marta =marta  (SgG  >marta !16_S	et	f	\N
158539	marta	?marta =marta  (IndPrPs_  >martama !29_V	et	f	\N
158540	marta	?marta =marta  (ImpPrSg2  >martama !29_V	et	f	\N
158542	õppetunde	õppetunde =tunde  (SgG  >õppe+tunne !06_S	et	f	\N
158543	õppetunde	õppetunde =tunde  (PlP  >õppe+tund !22_S	et	f	\N
158550	pussijaama	?pussijaama =pussijaama  (SgN  >pussijaama !16_S	et	f	\N
158551	pussijaama	?pussijaama =pussijaama  (SgG  >pussijaama !16_S	et	f	\N
158552	pussijaama	?pussijaama =ijaama  (SgN  >puss+ijaama !16_S	et	f	\N
158553	pussijaama	?pussijaama =ijaama  (SgG  >puss+ijaama !16_S	et	f	\N
158570	tellimuise	?tellimuise =tellimuise  (PlP  >tellimuis !22_S	et	f	\N
158574	perast	?perast =pera  (SgEl  >pera !17_S	et	f	\N
158575	perast	?perast =peras  (SgP  >peras !09_S	et	f	\N
158576	perast	?perast =peras  (SgP  >perane !10_A	et	f	\N
158600	hülgimüük	?hülgimüük =hülgimüük  (SgN  >hülgimüük !22_S	et	f	\N
158601	õpetavad	õpetavad =õpeta  (IndPrPl3  >õpetama !27_V	et	f	\N
158602	õpetavad	õpetavad =õpetava  (PlN  >õpetav !02_A	et	f	\N
158603	õpetavad	"õpetav %õpeta  )V_vA  <õpetama ;27_V	et	f	\N
158620	word	?word =word  (SgN  >word !22_S	et	f	\N
158621	excel	?excel =exce  (SgAd  >exce !06_S	et	f	\N
158622	excel	?excel =exce  (PlAd  >exc !22_S	et	f	\N
158623	excel	?excel =excel  (SgN  >excel !02_S	et	f	\N
158640	vormistamine	vormistamine =vormistamine  (SgN  >vormistamine !12_S	et	f	\N
158641	vormistamine	"vormistamine %vormista  )MINE_vS  <vormistama ;27_V	et	f	\N
158651	mettlli	?mettlli =mettlli  (SgN  >mettlli !01_S	et	f	\N
158652	mettlli	?mettlli =mettlli  (SgG  >mettlli !01_S	et	f	\N
158653	mettlli	?mettlli =mettlli  (SgG  >mettll !22_S	et	f	\N
158654	mettlli	?mettlli =mettlli  (SgP  >mettll !22_S	et	f	\N
158655	mettlli	?mettlli =mettlli  (SgAdt  >mettll !22_S	et	f	\N
158656	mettlli	?mettlli =mettlli  (IndPrPs_  >mettllima !28_V	et	f	\N
158657	mettlli	?mettlli =mettlli  (ImpPrSg2  >mettllima !28_V	et	f	\N
158666	tööbtsimine	?tööbtsimine =tööbtsimine  (SgN  >tööbtsimine !12_S	et	f	\N
158667	tööbtsimine	?tööbtsimine =tööbtsimine  (PlP  >tööbtsimin !19_S	et	f	\N
158668	elektoskandia	?elektoskandia =elektoskandia  (SgN  >elektoskandia !01_S	et	f	\N
158669	elektoskandia	?elektoskandia =elektoskandia  (SgG  >elektoskandia !01_S	et	f	\N
158673	kondisionerid	?kondisionerid =kondisioneri  (PlN  >kondisioner !02_S	et	f	\N
158674	kondisionerid	?kondisionerid =sioneri  (PlN  >kondi+sioneri !01_S	et	f	\N
158675	kondisionerid	?kondisionerid =sioneri  (PlN  >kondi+sioner !02_S	et	f	\N
158681	hiljutu	hiljutu =hiljutu  (SgN  >hiljutu !01_AS	et	f	\N
158682	hiljutu	"hiljutu %hilju  )TU1_vS  <hiljuma ;28_V	et	f	\N
158683	hiljutu	hiljutu =hiljutu  (SgG  >hiljutu !01_AS	et	f	\N
158688	taali	?taali =taali  (SgN  >taali !16_S	et	f	\N
158689	taali	?taali =taali  (SgG  >taali !16_S	et	f	\N
158690	taali	?taali =taali  (SgG  >taal !22_S	et	f	\N
158691	taali	?taali =taali  (SgP  >taal !22_S	et	f	\N
158692	taali	?taali =taali  (SgAdt  >taal !22_S	et	f	\N
158693	taali	?taali =taali  (IndPrPs_  >taalima !28_V	et	f	\N
158694	taali	?taali =taali  (ImpPrSg2  >taalima !28_V	et	f	\N
158704	kurs	?kurs =kurs  (SgN  >kurs !22_S	et	f	\N
158707	kea	?kea =kea  (SgN  >kea !26_S	et	f	\N
158709	kea	?kea =kea  (SgG  >kea !26_S	et	f	\N
158727	ehitusmaterjaalid	?ehitusmaterjaalid =ehitusmaterjaali  (PlN  >ehitusmaterjaali !16_S	et	f	\N
158728	ehitusmaterjaalid	?ehitusmaterjaalid =ehitusmaterjaali  (PlN  >ehitusmaterjaal !22_S	et	f	\N
158729	ehitusmaterjaalid	?ehitusmaterjaalid =ehitusmaterjaali  (IndPrSg2  >ehitusmaterjaalima !28_V	et	f	\N
158730	ehitusmaterjaalid	?ehitusmaterjaalid =materjaali  (PlN  >ehitus+materjaali !16_S	et	f	\N
158731	ehitusmaterjaalid	?ehitusmaterjaalid =materjaali  (PlN  >ehitus+materjaal !22_S	et	f	\N
158732	tapeedit	?tapeedit =tapeedi  (SgP  >tapeedi !16_S	et	f	\N
158753	süsisel	?süsisel =süsise  (SgAd  >süsis !09_S	et	f	\N
158754	süsisel	?süsisel =süsisel  (SgN  >süsisel !19_S	et	f	\N
158767	kokkupuuteid	kokkupuuteid =te  (PlP  >kokku+puu+tee !26_S	et	f	\N
158768	kokkupuuteid	kokkupuuteid =puute  (PlP  >kokku+puude !06_S	et	f	\N
158770	kaubandusalaseid	kaubandusalaseid =alase  (PlP  >kaubandus+alasi !01_S	et	f	\N
158771	kaubandusalaseid	kaubandusalaseid =alase  (PlP  >kaubandus+alane !10_AS	et	f	\N
158772	kaubandusalaseid	"kaubandus+alane %ala  )NE_aA  <kaubandus+ala ;17_S	et	f	\N
158802	kohanul	kohanul =kohanu  (SgAd  >kohanu !01_S	et	f	\N
158803	kohanul	"kohanu %koha  )NU_vS  <kohama ;27_V	et	f	\N
158610	majapidamisinventari	majapidamisinventari =inventari  (SgG  >maja+pidamis+inventar !19_S	et	f	\N
158611	majapidamisinventari	majapidamisinventari =inventari  (SgP  >maja+pidamis+inventar !19_S	et	f	\N
158612	majapidamisinventari	majapidamisinventari =inventari  (SgAdt  >maja+pidamis+inventar !19_S	et	f	\N
158642	töökaitse	töökaitse =kaitse  (SgN  >töö+kaitse !05_S	et	f	\N
158643	töökaitse	töökaitse =kaitse  (SgN  >töö+kaitse !06_S	et	f	\N
158644	töökaitse	töökaitse =kaitse  (SgG  >töö+kaitse !06_S	et	f	\N
158663	toimen	?toimen =toime  (IndPrSg1  >toimema !27_V	et	f	\N
158664	toimen	?toimen =toimen  (SgN  >toimen !02_S	et	f	\N
158665	loenged	?loenged =loenge  (IndPrSg2  >loengema !27_V	et	f	\N
158678	monika	?monika =monika  (SgN  >monika !01_S	et	f	\N
158679	monika	?monika =monika  (SgG  >monika !01_S	et	f	\N
158680	monika	?monika =monika  (SgG  >monikas !02_S	et	f	\N
158684	õnnitlemise	õnnitlemise =õnnitlemise  (SgG  >õnnitlemine !12_S	et	f	\N
158685	õnnitlemise	"õnnitlemine %õnnitle  )MINE_vS  <õnnitlema ;27_V	et	f	\N
158710	psüholoogija	?psüholoogija =psüholoogija  (SgN  >psüholoogija !01_S	et	f	\N
158711	psüholoogija	?psüholoogija =psüholoogija  (SgG  >psüholoogija !01_S	et	f	\N
158712	psüholoogija	?psüholoogija =psüholoogija  (SgG  >psüholoogijas !02_A	et	f	\N
158733	plaadit	?plaadit =plaadi  (SgP  >plaadi !16_S	et	f	\N
158734	plaadit	?plaadit =plaadit  (SgN  >plaadit !02_S	et	f	\N
158738	lambid	lambid =lambi  (PlN  >lamp !22_SA	et	f	\N
158739	lambid	lambid =lambi  (IndPrSg2  >lampima !28_V	et	f	\N
158745	maksedokumenti	maksedokumenti =dokumenti  (SgP  >makse+dokument !22_S	et	f	\N
158746	maksedokumenti	maksedokumenti =dokumenti  (SgAdt  >makse+dokument !22_S	et	f	\N
158755	müügisekretäär	?müügisekretäär =müügisekretäär  (SgN  >müügisekretäär !22_S	et	f	\N
158756	müügisekretäär	?müügisekretäär =sekretäär  (SgN  >müügi+sekretäär !22_S	et	f	\N
158765	voorimees	voorimees =mee  (SgIn  >voori+mesi !15_S	et	f	\N
158766	voorimees	voorimees =mees  (SgN  >voori+mees !13_S	et	f	\N
158775	börsi	börsi =börsi  (SgG  >börs !22_S	et	f	\N
158776	börsi	börsi =börsi  (SgP  >börs !22_S	et	f	\N
158777	börsi	börsi =börsi  (SgAdt  >börs !22_S	et	f	\N
158780	zepter	?zepter =zepter  (SgN  >zepter !02_S	et	f	\N
158781	müügika	?müügika =müügika  (SgN  >müügika !01_S	et	f	\N
158782	müügika	?müügika =müügika  (SgG  >müügika !01_S	et	f	\N
158783	müügika	?müügika =müügika  (SgG  >müügikas !02_S	et	f	\N
158798	rohken	?rohken =rohke  (IndPrSg1  >rohkema !27_V	et	f	\N
158799	rohken	?rohken =rohken  (SgN  >rohken !02_S	et	f	\N
158805	värsti	?värsti =värsti  (SgN  >värsti !01_S	et	f	\N
158806	värsti	?värsti =värsti  (SgG  >värsti !01_S	et	f	\N
158807	värsti	?värsti =värsti  (SgG  >värst !22_S	et	f	\N
158808	värsti	?värsti =värsti  (SgP  >värst !22_S	et	f	\N
158809	värsti	?värsti =värsti  (SgAdt  >värst !22_S	et	f	\N
158810	värsti	?värsti =värsti  (IndPrPs_  >värstima !28_V	et	f	\N
158811	värsti	?värsti =värsti  (ImpPrSg2  >värstima !28_V	et	f	\N
158905	õppilases	?õppilases =õppilase  (SgIn  >õppilane !12_S	et	f	\N
158919	vitali	?vitali =vitali  (ID  >vitali !41_D	et	f	\N
158920	vitali	?vitali =vitali  (SgG  >vital !02_S	et	f	\N
158926	konsultatsiooni	konsultatsiooni =konsultatsiooni  (SgG  >konsultatsioon !22_S	et	f	\N
158927	konsultatsiooni	konsultatsiooni =konsultatsiooni  (SgP  >konsultatsioon !22_S	et	f	\N
158928	konsultatsiooni	konsultatsiooni =konsultatsiooni  (SgAdt  >konsultatsioon !22_S	et	f	\N
158972	peeter-pauli	?peeter-pauli =pauli  (SgN  >peeter-pauli !16_S	et	f	\N
158973	peeter-pauli	?peeter-pauli =pauli  (SgG  >peeter-pauli !16_S	et	f	\N
158974	peeter-pauli	?peeter-pauli =pauli  (SgG  >peeter-paul !22_S	et	f	\N
158975	peeter-pauli	?peeter-pauli =pauli  (SgP  >peeter-paul !22_S	et	f	\N
158976	peeter-pauli	?peeter-pauli =pauli  (SgAdt  >peeter-paul !22_S	et	f	\N
158977	peeter-pauli	?peeter-pauli =pauli  (IndPrPs_  >peeter-paulima !28_V	et	f	\N
158978	peeter-pauli	?peeter-pauli =pauli  (ImpPrSg2  >peeter-paulima !28_V	et	f	\N
158982	ettendusel	?ettendusel =ettenduse  (SgAd  >ettendus !11_S	et	f	\N
159002	valetamine	valetamine =valetamine  (SgN  >valetamine !12_S	et	f	\N
159003	valetamine	"valetamine %valeta  )MINE_vS  <valetama ;27_V	et	f	\N
159062	kolimine	kolimine =kolimine  (SgN  >kolimine !12_S	et	f	\N
159063	kolimine	"kolimine %koli  )MINE_vS  <kolima ;27_V	et	f	\N
159070	kirjutamistest	kirjutamistest =kirjutamis  (PlEl  >kirjutamine !12_S	et	f	\N
159071	kirjutamistest	"kirjutamine %kirjuta  )MINE_vS  <kirjutama ;27_V	et	f	\N
159072	kirjutamistest	kirjutamistest =test  (SgN  >kirjutamis+test !22_S	et	f	\N
159080	katriin	?katriin =katriin  (SgN  >katriin !22_S	et	f	\N
159096	spordiklubi	spordiklubi =klubi  (SgN  >spordi+klubi !17_S	et	f	\N
159097	spordiklubi	spordiklubi =klubi  (SgG  >spordi+klubi !17_S	et	f	\N
159098	spordiklubi	spordiklubi =klubi  (SgP  >spordi+klubi !17_S	et	f	\N
159099	ants	?ants =ants  (SgN  >ants !22_S	et	f	\N
159118	e-r	### e-r	et	f	\N
159138	koolil	koolil =kooli  (SgAd  >kool !22_S	et	f	\N
159139	koolil	koolil =kooli  (PlAd  >kool !22_S	et	f	\N
159150	reisikava	reisikava =kava  (SgN  >reisi+kava !17_S	et	f	\N
159151	reisikava	reisikava =kava  (SgG  >reisi+kava !17_S	et	f	\N
158625	pikemalt	"pikem %pike  )M_cA  <pikk ;22_AS	et	f	\N
158626	pikemalt	pikemalt =pikemalt  (ID  >pikemalt !41_D	et	f	\N
158627	pikemalt	"pikemalt %pikema  )LT_mD  <pikem ;02_A	et	f	\N
158647	universal	?universal =universa  (SgAd  >universa !16_S	et	f	\N
158648	universal	?universal =universal  (SgN  >universal !02_S	et	f	\N
158649	universal	?universal =versa  (SgAd  >uni+versa !16_S	et	f	\N
158650	universal	?universal =versal  (SgN  >uni+versal !02_S	et	f	\N
158658	firmast	firmast =firma  (SgEl  >firma !16_S	et	f	\N
158659	firmast	firmast =firmas  (SgP  >firmane !10_A	et	f	\N
158660	firmast	"firmane %firma  )NE_aA  <firma ;16_S	et	f	\N
158670	müüd	müüd =müü  (PlN  >müü !26_S	et	f	\N
158671	müüd	müüd =müü  (SgP  >müü !26_S	et	f	\N
158672	müüd	müüd =müü  (IndPrSg2  >müüma !38_V	et	f	\N
158686	andesta	andesta =andesta  (IndPrPs_  >andestama !27_V	et	f	\N
158687	andesta	andesta =andesta  (ImpPrSg2  >andestama !27_V	et	f	\N
158695	majakabu	majakabu =kabu  (SgN  >maja+kabu !17_S	et	f	\N
158696	majakabu	majakabu =kabu  (SgN  >maja+kabu !18_S	et	f	\N
158697	majakabu	majakabu =kabu  (SgG  >maja+kabu !17_S	et	f	\N
158698	majakabu	majakabu =kabu  (SgP  >maja+kabu !17_S	et	f	\N
158699	majakabu	majakabu =kabu  (SgP  >maja+kabu !18_S	et	f	\N
158700	psühhologia	?psühhologia =psühhologia  (SgN  >psühhologia !01_S	et	f	\N
158701	psühhologia	?psühhologia =psühhologia  (SgG  >psühhologia !01_S	et	f	\N
158702	psühhologia	?psühhologia =logia  (SgN  >psühho+logia !01_S	et	f	\N
158703	psühhologia	?psühhologia =logia  (SgG  >psühho+logia !01_S	et	f	\N
158713	novembis	?novembis =novembi  (SgIn  >novembi !01_S	et	f	\N
158714	novembis	?novembis =novembi  (SgIn  >novemb !02_S	et	f	\N
158715	novembis	?novembis =novembi  (SgIn  >novemp !22_S	et	f	\N
158716	novembis	?novembis =novembi  (IndIpfSg3  >novembima !28_V	et	f	\N
158717	novembis	?novembis =novembis  (SgN  >novembis !11_S	et	f	\N
158735	santehnika	?santehnika =santehnika  (SgN  >santehnika !01_S	et	f	\N
158736	santehnika	?santehnika =santehnika  (SgG  >santehnika !01_S	et	f	\N
158737	santehnika	?santehnika =santehnika  (SgG  >santehnikas !02_A	et	f	\N
158749	suhtluseb	### suhtluseb	et	f	\N
158778	hääldamine	hääldamine =hääldamine  (SgN  >hääldamine !12_S	et	f	\N
158779	hääldamine	"hääldamine %häälda  )MINE_vS  <hääldama ;27_V	et	f	\N
158793	jällenägemiseni	jällenägemiseni =jällenägemiseni  (ID  >jälle+nägemiseni !41_I	et	f	\N
158794	jällenägemiseni	jällenägemiseni =nägemise  (SgTer  >jälle+nägemine !12_S	et	f	\N
158797	vell	?vell =vell  (SgN  >vell !22_S	et	f	\N
158822	ettevõetluses	?ettevõetluses =ettevõetluse  (SgIn  >ettevõetlus !11~09_S	et	f	\N
158823	ettevõetluses	?ettevõetluses =võetluse  (SgIn  >ette+võetlus !11~09_S	et	f	\N
158851	seele	?seele =seele  (SgN  >seele !06_S	et	f	\N
158852	seele	?seele =seele  (SgG  >seele !06_S	et	f	\N
158853	seele	?seele =seele  (PlP  >seel !22_S	et	f	\N
158854	seele	?seele =seele  (IndPrPs_  >seelema !27_V	et	f	\N
158855	seele	?seele =seele  (ImpPrSg2  >seelema !27_V	et	f	\N
158856	osastav	osastav =osasta  (PtsPrPs  >osastama !27_V	et	f	\N
158857	osastav	osastav =osastav  (SgN  >osastav !02_A	et	f	\N
158858	osastav	"osastav %osasta  )V_vA  <osastama ;27_V	et	f	\N
158867	suudledes	?suudledes =dlede  (SgIn  >suu+dlede !16_S	et	f	\N
158868	suudledes	?suudledes =dledes  (SgN  >suu+dledes !09_S	et	f	\N
158871	arvitioski	?arvitioski =arvitioski  (SgG  >arvitiosk !22_S	et	f	\N
158872	arvitioski	?arvitioski =arvitioski  (SgP  >arvitiosk !22_S	et	f	\N
158873	arvitioski	?arvitioski =arvitioski  (SgAdt  >arvitiosk !22_S	et	f	\N
158874	arvitioski	?arvitioski =arvitioski  (IndPrPs_  >arvitioskima !28_V	et	f	\N
158875	arvitioski	?arvitioski =arvitioski  (ImpPrSg2  >arvitioskima !28_V	et	f	\N
158876	arvitioski	?arvitioski =itioski  (SgG  >arv+itiosk !22_S	et	f	\N
158877	arvitioski	?arvitioski =itioski  (SgP  >arv+itiosk !22_S	et	f	\N
158878	arvitioski	?arvitioski =itioski  (SgAdt  >arv+itiosk !22_S	et	f	\N
158879	arvitioski	?arvitioski =arvitio  (SgIn^  >arvitio !01_S	et	f	\N
158880	arvitioski	?arvitioski =arvitios  (SgN^  >arvitios !22_S	et	f	\N
158881	arvitioski	?arvitioski =itio  (SgIn^  >arv+itio !01_S	et	f	\N
158882	arvitioski	?arvitioski =itios  (SgN^  >arv+itios !22_S	et	f	\N
158906	õppilane	?õppilane =õppilane  (SgN  >õppilane !12_S	et	f	\N
158907	õppilane	?õppilane =õppilane  (PlP  >õppilan !19_S	et	f	\N
158923	unistav	unistav =unista  (PtsPrPs  >unistama !27_V	et	f	\N
158924	unistav	unistav =unistav  (SgN  >unistav !02_A	et	f	\N
158925	unistav	"unistav %unista  )V_vA  <unistama ;27_V	et	f	\N
158932	postemes	?postemes =eme  (SgIn  >post+eme !16_S	et	f	\N
158933	postemes	?postemes =emes  (SgN  >post+emes !09_S	et	f	\N
158955	õppimisiks	õppimisiks =õppimisi  (PlTr  >õppimine !12_S	et	f	\N
158956	õppimisiks	"õppimine %õppi  )MINE_vS  <õppima ;28_V	et	f	\N
158957	õppimisiks	õppimisiks =iks  (SgN  >õppimis+iks !22_S	et	f	\N
158964	kursustest	kursustest =kursus  (PlEl  >kursus !11~09_S	et	f	\N
158965	kursustest	kursustest =test  (SgN  >kursus+test !22_S	et	f	\N
158983	grupivanem	grupivanem =vanem  (SgN  >grupi+vanem !02_AS	et	f	\N
158984	grupivanem	"grupi+vanem %vane  )M_cA  <grupi+vana ;17_AS	et	f	\N
158676	4-d	-d =  (SgP  > !xx_Q	et	f	\N
158677	4-d	-d =  (PlN  > !xx_Q	et	f	\N
158705	kulturikeskuses	?kulturikeskuses =kulturikeskuse  (SgIn  >kulturikeskus !11~09_S	et	f	\N
158718	kvalifikatsiooni	kvalifikatsiooni =kvalifikatsiooni  (SgG  >kvalifikatsioon !22_S	et	f	\N
158719	kvalifikatsiooni	kvalifikatsiooni =kvalifikatsiooni  (SgP  >kvalifikatsioon !22_S	et	f	\N
158720	kvalifikatsiooni	kvalifikatsiooni =kvalifikatsiooni  (SgAdt  >kvalifikatsioon !22_S	et	f	\N
158724	enn	?enn =enn  (SgN  >enn !22_S	et	f	\N
158747	müügisekretarile	?müügisekretarile =müügisekretari  (SgAll  >müügisekretar !19_S	et	f	\N
158748	müügisekretarile	?müügisekretarile =sekretari  (SgAll  >müügi+sekretar !19_S	et	f	\N
158750	saatja	saatja =saatja  (SgN  >saatja !01_S	et	f	\N
158751	saatja	"saatja %saat  )JA_vS  <saatma ;34_V	et	f	\N
158752	saatja	saatja =saatja  (SgG  >saatja !01_S	et	f	\N
158769	kaebandusega	?kaebandusega =kaebanduse  (SgKom  >kaebandus !11_S	et	f	\N
158773	eelduse	eelduse =eelduse  (SgG  >eeldus !11~09_S	et	f	\N
158774	eelduse	"eeldus %eelda  )US_vS  <eeldama ;27_V	et	f	\N
158784	terviseselulaad	?terviseselulaad =terviseselulaa  (PlN  >terviseselulaa !26_S	et	f	\N
158785	terviseselulaad	?terviseselulaad =terviseselulaa  (SgP  >terviseselulaa !26_S	et	f	\N
158786	terviseselulaad	?terviseselulaad =terviseselulaad  (SgN  >terviseselulaad !22_S	et	f	\N
158787	terviseselulaad	?terviseselulaad =selulaa  (PlN  >tervise+selulaa !26_S	et	f	\N
158788	terviseselulaad	?terviseselulaad =selulaa  (SgP  >tervise+selulaa !26_S	et	f	\N
158789	terviseselulaad	?terviseselulaad =selulaad  (SgN  >tervise+selulaad !22_S	et	f	\N
158790	terviseselulaad	?terviseselulaad =eselulaa  (PlN  >tervis+eselulaa !26_S	et	f	\N
158791	terviseselulaad	?terviseselulaad =eselulaa  (SgP  >tervis+eselulaa !26_S	et	f	\N
158792	terviseselulaad	?terviseselulaad =eselulaad  (SgN  >tervis+eselulaad !22_S	et	f	\N
158817	akkan	?akkan =akka  (IndPrSg1  >akkama !29_V	et	f	\N
158818	akkan	?akkan =akkan  (SgN  >akkan !02_S	et	f	\N
158819	tegelab	### tegelab	et	f	\N
158824	arvutiõpelus	?arvutiõpelus =arvutiõpelu  (SgIn  >arvutiõpelu !17_S	et	f	\N
158825	arvutiõpelus	?arvutiõpelus =arvutiõpelu  (IndIpfSg3  >arvutiõpeluma !27_V	et	f	\N
158826	arvutiõpelus	?arvutiõpelus =arvutiõpelus  (SgN  >arvutiõpelus !11?09_S	et	f	\N
158827	arvutiõpelus	?arvutiõpelus =õpelu  (SgIn  >arvuti+õpelu !17_S	et	f	\N
158828	arvutiõpelus	?arvutiõpelus =õpelus  (SgN  >arvuti+õpelus !11_S	et	f	\N
158829	arvutiõpelus	?arvutiõpelus =tiõpelu  (SgIn  >arvu+tiõpelu !17_S	et	f	\N
158830	arvutiõpelus	?arvutiõpelus =tiõpelus  (SgN  >arvu+tiõpelus !11_S	et	f	\N
158831	arvutiõpelus	?arvutiõpelus =utiõpelu  (SgIn  >arv+utiõpelu !17_S	et	f	\N
158832	arvutiõpelus	?arvutiõpelus =utiõpelus  (SgN  >arv+utiõpelus !11?09_S	et	f	\N
158833	klientiga	?klientiga =klienti  (SgKom  >klienti !01_S	et	f	\N
158834	lahen	?lahen =lahe  (IndPrSg1  >lahema !27_V	et	f	\N
158835	lahen	?lahen =lahen  (SgN  >lahen !02_S	et	f	\N
158843	paberiga	paberiga =paberi  (SgKom  >paber !02_S	et	f	\N
158844	paberiga	paberiga =iga  (SgN  >paber+iga !18_S	et	f	\N
158845	paberiga	paberiga =iga  (SgP  >paber+iga !18_S	et	f	\N
158860	õppinu	õppinu =õppinu  (SgN  >õppinu !01_S	et	f	\N
158861	õppinu	"õppinu %õppi  )NU_vS  <õppima ;28_V	et	f	\N
158862	õppinu	õppinu =õppinu  (SgG  >õppinu !01_S	et	f	\N
158864	mulle-	mulle- =mu  (SgAll  >ma !00_P	et	f	\N
158865	mulle-	mulle- =mulle  (SgN  >mulle !06_S	et	f	\N
158866	mulle-	mulle- =mulle  (PlP  >mull !22_S	et	f	\N
158869	anena	?anena =ane  (SgEs  >ane !16_S	et	f	\N
158870	börsikursule	?börsikursule =kursu  (SgAll  >börsi+kursu !16_S	et	f	\N
158897	huvitat	### huvitat	et	f	\N
158914	lehti-maja	lehti-maja =maja  (SgN  >lehti-maja !17_S	et	f	\N
158915	lehti-maja	lehti-maja =maja  (SgG  >lehti-maja !17_S	et	f	\N
158916	lehti-maja	lehti-maja =maja  (SgP  >lehti-maja !17_S	et	f	\N
158944	pöördus	pöördus =pöördu  (IndIpfSg3  >pöörduma !27_V	et	f	\N
158945	pöördus	pöördus =pöördus  (SgN  >pöördus !11~09_S	et	f	\N
158968	lgp	### lgp	et	f	\N
158979	aidake	aidake =aida  (ImpPrPl2  >aitama !29_V	et	f	\N
158980	aidake	aidake =aidake  (SgN  >aidake !12_S	et	f	\N
158981	aidake	"aidake %aida  )KE_dS  <ait ;22_S	et	f	\N
158985	luurajaks	luurajaks =luuraja  (SgTr  >luuraja !01_S	et	f	\N
158986	luurajaks	"luuraja %luura  )JA_vS  <luurama ;29_V	et	f	\N
158987	luurajaks	luurajaks =raja  (SgTr  >luu+raja !17_S	et	f	\N
158988	luurajaks	luurajaks =raja  (SgTr  >luu+rada !18_S	et	f	\N
159012	pööraseim	pööraseim =pööraseim  (SgN  >pööraseim !02_A	et	f	\N
159013	pööraseim	"pööraseim %pöörase  )IM_sA  <pöörane ;10_A	et	f	\N
159018	natukenegi	natukenegi =natukene  (ID^  >natukene !41_D	et	f	\N
159019	natukenegi	natukenegi =natukene  (SgN^  >natukene !12_S	et	f	\N
159045	lõpunu	?lõpunu =lõpunu  (SgN  >lõpunu !01_S	et	f	\N
159046	lõpunu	?lõpunu =lõpunu  (SgG  >lõpunu !01_S	et	f	\N
159047	lõpunu	?lõpunu =lõpunu  (IndPrPs_  >lõpunuma !27_V	et	f	\N
159048	lõpunu	?lõpunu =lõpunu  (ImpPrSg2  >lõpunuma !27_V	et	f	\N
159076	kodakonsus	?kodakonsus =kodakonsu  (IndIpfSg3  >kodakonsuma !27_V	et	f	\N
159077	kodakonsus	?kodakonsus =kodakonsus  (SgN  >kodakonsus !11~09_S	et	f	\N
158761	psühologu	?psühologu =psühologu  (ImpPrSg2  >psühologuma !27_V	et	f	\N
158762	kursussel	?kursussel =kursusse  (SgAd  >kursusne !02_A	et	f	\N
158763	kursussel	?kursussel =kursusse  (PlAd  >kursuss !22_S	et	f	\N
158764	kursussel	?kursussel =kursussel  (SgN  >kursussel !02_S	et	f	\N
158795	õpen	?õpen =õpe  (IndPrSg1  >õpema !27_V	et	f	\N
158796	õpen	?õpen =õpen  (SgN  >õpen !02_S	et	f	\N
158800	mööblad	?mööblad =mööbla  (PlN  >mööbla !01_S	et	f	\N
158801	mööblad	?mööblad =mööbla  (IndPrSg2  >mööblama !29_V	et	f	\N
158812	prägu	?prägu =prägu  (SgN  >prägu !17_S	et	f	\N
158813	prägu	?prägu =prägu  (SgG  >prägu !17_S	et	f	\N
158814	prägu	?prägu =prägu  (SgP  >prägu !17_S	et	f	\N
158815	prägu	?prägu =prägu  (IndPrPs_  >präguma !27_V	et	f	\N
158816	prägu	?prägu =prägu  (ImpPrSg2  >präguma !27_V	et	f	\N
158836	liimid	liimid =liimi  (PlN  >liim !22_S	et	f	\N
158837	liimid	liimid =liimi  (IndPrSg2  >liimima !28_V	et	f	\N
158840	tööitama	?tööitama =tööita  (Sup  >tööitama !27_V	et	f	\N
158841	tööitama	?tööitama =tööitama  (SgG  >tööitam !02_A	et	f	\N
158842	tööitama	?tööitama =itama  (SgG  >töö+itam !02_A	et	f	\N
158863	affen	?affen =affen  (SgN  >affen !02_S	et	f	\N
158883	raamatupidamis	?raamatupidamis =raamatupidami  (SgIn  >raamatupidam !02_A	et	f	\N
158884	raamatupidamis	?raamatupidamis =raamatupidamis  (SgN  >raamatupidamis !09_S	et	f	\N
158885	raamatupidamis	?raamatupidamis =pidami  (SgIn  >raamatu+pidami !01_S	et	f	\N
158886	raamatupidamis	?raamatupidamis =pidami  (SgIn  >raamatu+pidam !02_A	et	f	\N
158887	raamatupidamis	?raamatupidamis =pidamis  (SgN  >raamatu+pidamis !11_S	et	f	\N
158888	raamatupidamis	?raamatupidamis =atupidami  (SgIn  >raam+atupidam !02_A	et	f	\N
158889	raamatupidamis	?raamatupidamis =atupidamis  (SgN  >raam+atupidamis !09_S	et	f	\N
158892	lõppevadki	lõppevadki =lõppe  (IndPrPl3^  >lõppema !27_V	et	f	\N
158893	lõppevadki	lõppevadki =lõppeva  (PlN^  >lõppev !02_A	et	f	\N
158894	lõppevadki	"lõppev %lõpp  )V_vA^  <lõpma ;35_V	et	f	\N
158895	lõppevadki	"lõppev %lõppe  )V_vA^  <lõppema ;27_V	et	f	\N
158896	lõppevadki	"lõppev %lõppe  )V_vA^  <lõppema ;28_V	et	f	\N
158901	irma	?irma =irma  (SgN  >irma !16_S	et	f	\N
158902	irma	?irma =irma  (SgG  >irma !16_S	et	f	\N
158903	irma	?irma =irma  (IndPrPs_  >irmama !29_V	et	f	\N
158904	irma	?irma =irma  (ImpPrSg2  >irmama !29_V	et	f	\N
158908	eestikeelles	?eestikeelles =eestikeelle  (PlIn  >eestikeell !22_S	et	f	\N
158909	eestikeelles	?eestikeelles =keelle  (SgIn  >eesti+keelle !06_S	et	f	\N
158910	eestikeelles	?eestikeelles =keelle  (PlIn  >eesti+keell !22_S	et	f	\N
158911	eestikeelles	?eestikeelles =keelles  (SgN  >eesti+keelles !09_S	et	f	\N
158912	eestikeelles	?eestikeelles =ikeelle  (PlIn  >eest+ikeell !22_S	et	f	\N
158913	eestikeelles	?eestikeelles =tikeelle  (PlIn  >ees+tikeell !22_S	et	f	\N
158917	vitalial	?vitalial =vitalia  (SgAd  >vitalia !01_S	et	f	\N
158918	vitalial	?vitalial =vitalial  (SgN  >vitalial !19_S	et	f	\N
158921	vahendus	vahendus =vahendus  (SgN  >vahendus !11_S	et	f	\N
158922	vahendus	"vahendus %vahenda  )US_vS  <vahendama ;27_V	et	f	\N
158931	kiilinag	### kiilinag	et	f	\N
158934	kulutust	kulutust =kulutu  (SgEl  >kulutu !01_AS	et	f	\N
158935	kulutust	"kulutu %kulu  )TU1_vS  <kuluma ;27_V	et	f	\N
158936	kulutust	"kulutu %kulu  )TU2_kA  <kulu ;17_S	et	f	\N
158937	kulutust	"kulutu %kulu  )TU2_kA  <kulg ;22_S	et	f	\N
158938	kulutust	kulutust =kulutus  (SgP  >kulutus !11_S	et	f	\N
158939	kulutust	"kulutus %kuluta  )US_vS  <kulutama ;27_V	et	f	\N
158940	kulutust	"kulutus %kulu  )TUS1_aS  <kuluma ;27_V	et	f	\N
158941	kulutust	"kulutus %kulu  )TUS2_aS  <kulu ;17_S	et	f	\N
158942	kulutust	"kulutus %kulu  )TUS2_aS  <kulg ;22_S	et	f	\N
158943	kulutust	kulutust =tust  (SgN  >kulu+tust !22_S	et	f	\N
158949	kooleegidega	?kooleegidega =kooleegi  (PlKom  >kooleegi !16_S	et	f	\N
158950	kooleegidega	?kooleegidega =kooleegi  (PlKom  >kooleeg !22_S	et	f	\N
158951	kooleegidega	?kooleegidega =eegi  (PlKom  >kool+eegi !16_S	et	f	\N
158952	kooleegidega	?kooleegidega =eegi  (PlKom  >kool+eeg !22_S	et	f	\N
158960	pakutavad	pakutavad =pakuta  (IndPrPl3  >pakutama !27_V	et	f	\N
158961	pakutavad	pakutavad =pakutava  (PlN  >pakutav !02_A	et	f	\N
158962	pakutavad	"pakutav %paku  )TAV_vAS  <pakkuma ;28_V	et	f	\N
158963	pakutavad	"pakutav %pakuta  )V_vA  <pakutama ;27_V	et	f	\N
158992	eritsooni	eritsooni =tsooni  (SgG  >eri+tsoon !22_S	et	f	\N
158993	eritsooni	eritsooni =tsooni  (SgP  >eri+tsoon !22_S	et	f	\N
158994	eritsooni	eritsooni =tsooni  (SgAdt  >eri+tsoon !22_S	et	f	\N
159014	vasknarva	?vasknarva =vasknarva  (SgN  >vasknarva !01_S	et	f	\N
159015	vasknarva	?vasknarva =vasknarva  (SgG  >vasknarva !01_S	et	f	\N
159016	vasknarva	?vasknarva =narva  (SgN  >vask+narva !16_S	et	f	\N
159017	vasknarva	?vasknarva =narva  (SgG  >vask+narva !16_S	et	f	\N
159026	tugevaimaks	tugevaimaks =tugevaima  (SgTr  >tugevaim !02_A	et	f	\N
159027	tugevaimaks	"tugevaim %tugeva  )IM_sA  <tugev ;02_A	et	f	\N
159028	tugevaimaks	tugevaimaks =ima  (SgTr  >tugeva+ima !17_S	et	f	\N
159031	loete	loete =loe  (PlG  >loe !06_S	et	f	\N
159032	loete	loete =loe  (IndPrPl2  >lugema !28_V	et	f	\N
158804	kohanul	"kohanu %koha  )NU_vS  <kohtama ;29_V	et	f	\N
158820	büroo	büroo =büroo  (SgN  >büroo !26_S	et	f	\N
158821	büroo	büroo =büroo  (SgG  >büroo !26_S	et	f	\N
158838	praktikase	praktikase =praktikase  (SgG  >praktikane !12_A	et	f	\N
158839	praktikase	"praktikane %praktika  )NE_aA  <praktika ;01_S	et	f	\N
158846	eitja	?eitja =eitja  (SgN  >eitja !01_S	et	f	\N
158847	eitja	?eitja =eitja  (SgG  >eitja !01_S	et	f	\N
158848	eitja	?eitja =eitja  (SgG  >eitjas !02_A	et	f	\N
158849	eitja	?eitja =eitja  (IndPrPs_  >eitjama !29_V	et	f	\N
158850	eitja	?eitja =eitja  (ImpPrSg2  >eitjama !29_V	et	f	\N
158859	kulturimajsse	?kulturimajsse =kulturimajsse  (SgG  >kulturimajsne !02_A	et	f	\N
158890	kuuaega	kuuaega =aega  (SgP  >kuu+aeg !22_S	et	f	\N
158891	kuuaega	kuuaega =aega  (SgAdt  >kuu+aeg !22_S	et	f	\N
158898	õppeaine	õppeaine =aine  (SgN  >õppe+aine !06_S	et	f	\N
158899	õppeaine	õppeaine =aine  (SgG  >õppe+aine !06_S	et	f	\N
158900	õppeaine	õppeaine =aine  (PlP  >õppe+ain !22_S	et	f	\N
158929	okkei	?okkei =okkei  (SgN  >okkei !26_S	et	f	\N
158930	okkei	?okkei =okkei  (SgG  >okkei !26_S	et	f	\N
158946	soovimaks	soovimaks =soovi  (SupTr  >soovima !28_V	et	f	\N
158947	soovimaks	soovimaks =maks  (SgN  >soovi+maks !22_S	et	f	\N
158948	soovimaks	soovimaks =ima  (SgTr  >soov+ima !17_S	et	f	\N
158953	meiepooleseks	meiepooleseks =seks  (SgN  >meie+poole+seks !22_S	et	f	\N
158954	meiepooleseks	meiepooleseks =poolese  (SgTr  >meie+poolene !10_A	et	f	\N
158958	teilt	teilt =te  (PlAbl  >sa !00_P	et	f	\N
158959	teilt	teilt =te  (PlAbl  >tee !26_S	et	f	\N
158966	meeldivale	meeldivale =meeldiva  (SgAll  >meeldiv !02_A	et	f	\N
158967	meeldivale	"meeldiv %meeldi  )V_vA  <meeldima ;27_V	et	f	\N
158969	giidi	giidi =giidi  (SgG  >giid !22_S	et	f	\N
158970	giidi	giidi =giidi  (SgP  >giid !22_S	et	f	\N
158971	giidi	giidi =giidi  (SgAdt  >giid !22_S	et	f	\N
159004	petnud	petnud =pet  (PtsPtPs  >petma !35_V	et	f	\N
159005	petnud	petnud =petnu  (PlN  >petnu !01_S	et	f	\N
159006	petnud	"petnu %pet  )NU_vS  <petma ;35_V	et	f	\N
159007	petnud	petnud =petnud  (ID  >petnud !41_A	et	f	\N
159008	petnud	"petnud %pet  )NUD_vA  <petma ;35_V	et	f	\N
159020	öökulli	öökulli =kulli  (SgG  >öö+kull !22_S	et	f	\N
159021	öökulli	öökulli =kulli  (SgP  >öö+kull !22_S	et	f	\N
159022	öökulli	öökulli =kulli  (SgAdt  >öö+kull !22_S	et	f	\N
159038	intervjueeritav	intervjueeritav =intervjueeri  (PtsPrIps  >intervjueerima !28_V	et	f	\N
159039	intervjueeritav	intervjueeritav =intervjueeritav  (SgN  >intervjueeritav !02_A	et	f	\N
159040	intervjueeritav	"intervjueeritav %intervjueeri  )TAV_vAS  <intervjueerima ;28_V	et	f	\N
159043	valitsuses	valitsuses =valitsuse  (SgIn  >valitsus !11_S	et	f	\N
159044	valitsuses	"valitsus %valitse  )US_vS  <valitsema ;27_V	et	f	\N
159049	puhkusreisile	?puhkusreisile =puhkusreisi  (SgAll  >puhkusreisi !16_S	et	f	\N
159050	puhkusreisile	?puhkusreisile =puhkusreisi  (SgAll  >puhkusreis !22_S	et	f	\N
159051	puhkusreisile	?puhkusreisile =usreisi  (SgAll  >puhk+usreis !22_S	et	f	\N
159054	minejeva	?minejeva =minejeva  (SgN  >minejeva !16_S	et	f	\N
159055	minejeva	?minejeva =minejeva  (SgG  >minejev !02_A	et	f	\N
159056	minejeva	?minejeva =minejeva  (SgG  >minejeva !16_S	et	f	\N
159057	kolinud	kolinud =koli  (PtsPtPs  >kolima !27_V	et	f	\N
159058	kolinud	kolinud =kolinu  (PlN  >kolinu !01_S	et	f	\N
159059	kolinud	"kolinu %koli  )NU_vS  <kolima ;27_V	et	f	\N
159060	kolinud	kolinud =kolinud  (ID  >kolinud !41_A	et	f	\N
159061	kolinud	"kolinud %koli  )NUD_vA  <kolima ;27_V	et	f	\N
159069	kirjadiv	?kirjadiv =kirjadiv  (SgN  >kirjadiv !02_A	et	f	\N
159073	maspanova	?maspanova =maspanova  (SgN  >maspanova !16_S	et	f	\N
159074	maspanova	?maspanova =maspanova  (SgG  >maspanov !02_A	et	f	\N
159075	maspanova	?maspanova =maspanova  (SgG  >maspanova !16_S	et	f	\N
159081	abivad	?abivad =abi  (IndPrPl3  >abima !27_V	et	f	\N
159082	abivad	?abivad =abiva  (PlN  >abiva !01_S	et	f	\N
159083	abivad	?abivad =abiva  (PlN  >abiv !02_A	et	f	\N
159089	uudel	?uudel =uude  (PlAd  >uut !22_S	et	f	\N
159090	uudel	?uudel =uudel  (SgN  >uudel !02_S	et	f	\N
159091	kortirisse	?kortirisse =kortiri  (SgIll  >kortiri !01_S	et	f	\N
159092	kortirisse	?kortirisse =kortiri  (SgIll  >kortir !02_S	et	f	\N
159093	kortirisse	?kortirisse =kortiris  (SgAdt  >kortiris !11_S	et	f	\N
159094	kortirisse	?kortirisse =kortirisse  (SgG  >kortirisne !02_A	et	f	\N
159095	kortirisse	?kortirisse =kortirisse  (PlP  >kortiriss !22_S	et	f	\N
159112	küsimustekaart	küsimustekaart =kaar  (SgP  >küsimuste+kaar !13_S	et	f	\N
159113	küsimustekaart	küsimustekaart =kaart  (SgN  >küsimuste+kaart !22_S	et	f	\N
159120	plaadi-	plaadi- =plaadi  (SgG  >plaat !22_S	et	f	\N
159121	plaadi-	plaadi- =plaadi  (IndPrPs_  >plaatima !28_V	et	f	\N
159122	plaadi-	plaadi- =plaadi  (ImpPrSg2  >plaatima !28_V	et	f	\N
159140	toetanud	toetanud =toeta  (PtsPtPs  >toetama !27_V	et	f	\N
159141	toetanud	toetanud =toetanu  (PlN  >toetanu !01_S	et	f	\N
159142	toetanud	"toetanu %toeta  )NU_vS  <toetama ;27_V	et	f	\N
159143	toetanud	toetanud =toetanud  (ID  >toetanud !41_A	et	f	\N
159144	toetanud	"toetanud %toeta  )NUD_vA  <toetama ;27_V	et	f	\N
158989	dessantväelastest	dessantväelastest =las  (PlEl  >dessant+väe+laps !14_S	et	f	\N
158990	dessantväelastest	dessantväelastest =laste  (PlEl  >dessant+väe+last !22_S	et	f	\N
158991	dessantväelastest	dessantväelastest =väelas  (PlEl  >dessant+väelane !12?10_S	et	f	\N
158995	samasuguseks	samasuguseks =seks  (SgN  >sama+sugu+seks !22_S	et	f	\N
158996	samasuguseks	samasuguseks =suguse  (SgTr  >sama+sugune !10_P	et	f	\N
158997	reeturlus	?reeturlus =reeturlu  (SgIn  >reeturlu !01_S	et	f	\N
158998	reeturlus	?reeturlus =reeturlu  (IndIpfSg3  >reeturluma !27_V	et	f	\N
158999	reeturlus	?reeturlus =reeturlus  (SgN  >reeturlus !11_S	et	f	\N
159000	reeturlus	?reeturlus =turlu  (SgIn  >ree+turlu !16_S	et	f	\N
159001	reeturlus	?reeturlus =turlus  (SgN  >ree+turlus !11~09_S	et	f	\N
159009	puutumast	puutumast =puutu  (SupEl  >puutuma !27_V	et	f	\N
159010	puutumast	puutumast =puutuma  (SgEl  >puutum !02_A	et	f	\N
159011	puutumast	"puutum %puu  )TUM2_cA  <puu ;26_S	et	f	\N
159023	omadust	omadust =omadus  (SgP  >omadus !11_S	et	f	\N
159024	omadust	"omadus %oma  )US_aS  <oma ;17_A	et	f	\N
159025	omadust	omadust =dust  (SgN  >oma+dust !22_S	et	f	\N
159029	järjekindlus	järjekindlus =kindlus  (SgN  >järje+kindlus !11~09_S	et	f	\N
159030	järjekindlus	"järje+kindlus %kindla  )US_aS  <järje+kindel ;02_A	et	f	\N
159033	huvitu	huvitu =huvitu  (SgN  >huvitu !01_A	et	f	\N
159034	huvitu	"huvitu %huvi  )TU2_kA  <huvi ;17_S	et	f	\N
159035	huvitu	huvitu =huvitu  (SgG  >huvitu !01_A	et	f	\N
159036	huvitu	huvitu =huvitu  (IndPrPs_  >huvituma !27_V	et	f	\N
159037	huvitu	huvitu =huvitu  (ImpPrSg2  >huvituma !27_V	et	f	\N
159041	advokat	?advokat =advoka  (SgP  >advoka !01_S	et	f	\N
159042	advokat	?advokat =advoka  (SgP  >advokas !02_A	et	f	\N
159052	norrasse	?norrasse =norrasse  (SgG  >norrasne !02_A	et	f	\N
159053	norrasse	?norrasse =norrasse  (PlP  >norrass !22_S	et	f	\N
159066	mahtuvad	mahtuvad =mahtuva  (PlN  >mahtuv !02_A	et	f	\N
159067	mahtuvad	"mahtuv %mahtu  )V_vA  <mahtuma ;28_V	et	f	\N
159068	pankaautomaat	?pankaautomaat =pankaautomaat  (SgN  >pankaautomaat !22_S	et	f	\N
159119	min	### min	et	f	\N
159126	kuulu	kuulu =kuulu  (SgG  >kuuld !22_S	et	f	\N
159127	kuulu	kuulu =kuulu  (IndPrPs_  >kuuluma !27_V	et	f	\N
159128	kuulu	kuulu =kuulu  (ImpPrSg2  >kuuluma !27_V	et	f	\N
159134	tasumine	tasumine =tasumine  (SgN  >tasumine !12_S	et	f	\N
159135	tasumine	"tasumine %tasu  )MINE_vS  <tasuma ;27_V	et	f	\N
159153	reisibüroo	reisibüroo =büroo  (SgN  >reisi+büroo !26_S	et	f	\N
159154	reisibüroo	reisibüroo =büroo  (SgG  >reisi+büroo !26_S	et	f	\N
159180	teadmisega	teadmisega =teadmise  (SgKom  >teadmine !12?10_S	et	f	\N
159181	teadmisega	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
159205	tagasihoidlikkus	tagasihoidlikkus =hoidlikkus  (SgN  >tagasi+hoidlikkus !11~09_S	et	f	\N
159206	tagasihoidlikkus	"tagasi+hoidlikkus %hoidlikku  )US_aS  <tagasi+hoidlik ;25_A	et	f	\N
159211	autojuhiluba	autojuhiluba =luba  (SgN  >auto+juhi+luba !18_S	et	f	\N
159212	autojuhiluba	autojuhiluba =luba  (SgP  >auto+juhi+luba !18_S	et	f	\N
159221	leidmiseks	leidmiseks =leidmise  (SgTr  >leidmine !12?10_S	et	f	\N
159222	leidmiseks	"leidmine %leid  )MINE_vS  <leidma ;34_V	et	f	\N
159228	windows	?windows =windows  (SgN  >windows !22_S	et	f	\N
159262	kottasemine	?kottasemine =kottasemine  (SgN  >kottasemine !12_S	et	f	\N
159263	kottasemine	?kottasemine =kottasemine  (PlP  >kottasemin !19_S	et	f	\N
159264	kottasemine	?kottasemine =asemine  (SgN  >kott+asemine !12_S	et	f	\N
159265	kottasemine	?kottasemine =asemine  (PlP  >kott+asemin !19_S	et	f	\N
159275	puhkul	?puhkul =puhkul  (SgN  >puhkul !02_S	et	f	\N
159279	juhatajaks	juhatajaks =juhataja  (SgTr  >juhataja !01_S	et	f	\N
159280	juhatajaks	"juhataja %juhata  )JA_vS  <juhatama ;27_V	et	f	\N
159283	kutsekooli	kutsekooli =kooli  (SgG  >kutse+kool !22_S	et	f	\N
159284	kutsekooli	kutsekooli =kooli  (SgP  >kutse+kool !22_S	et	f	\N
159285	kutsekooli	kutsekooli =kooli  (SgAdt  >kutse+kool !22_S	et	f	\N
159286	kutsekooli	kutsekooli =kooli  (PlP  >kutse+kool !22_S	et	f	\N
159288	mat	### mat	et	f	\N
159293	old	?old =old  (SgN  >old !22_S	et	f	\N
159298	ar	### ar	et	f	\N
159330	passiivsuse	passiivsuse =passiivsuse  (SgG  >passiivsus !11~09_S	et	f	\N
159331	passiivsuse	"passiivsus %passiivse  )US_aS  <passiivne ;02_A	et	f	\N
159339	tähendusest	tähendusest =tähenduse  (SgEl  >tähendus !11_S	et	f	\N
159340	tähendusest	"tähendus %tähenda  )US_vS  <tähendama ;27_V	et	f	\N
159341	tähendusest	tähendusest =tähenduses  (SgP  >tähendusene !12_A	et	f	\N
159342	tähendusest	"tähendusene %tähenduse  )NE_aA  <tähendus ;11_S	et	f	\N
159347	faktoritest	faktoritest =faktori  (PlEl  >faktor !02_S	et	f	\N
159348	faktoritest	faktoritest =test  (SgN  >faktori+test !22_S	et	f	\N
159354	sagedamini	sagedamini =sagedami  (SgTer  >sagedam !02_A	et	f	\N
159355	sagedamini	"sagedam %sageda  )M_cA  <sage ;02_A	et	f	\N
159356	sagedamini	sagedamini =sagedamini  (ID  >sagedamini !41_D	et	f	\N
159368	esmajärjekorras	esmajärjekorras =esmajärjekorras  (ID  >esma+järje+korras !41_D	et	f	\N
159369	esmajärjekorras	esmajärjekorras =korra  (SgIn  >esma+järje+kord !22_S	et	f	\N
159382	võrdlevad	võrdlevad =võrdle  (IndPrPl3  >võrdlema !30_V	et	f	\N
159383	võrdlevad	võrdlevad =võrdleva  (PlN  >võrdlev !02_A	et	f	\N
159064	elukohas	elukohas =koha  (SgIn  >elu+koha !17_S	et	f	\N
159065	elukohas	elukohas =koha  (SgIn  >elu+koht !22_S	et	f	\N
159084	kolisivad	?kolisivad =kolisiva  (PlN  >kolisiv !02_A	et	f	\N
159085	kolisivad	?kolisivad =kolisiva  (PlN  >kolisiva !16_S	et	f	\N
159100	moderniseeritud	moderniseeritud =moderniseeri  (PtsPtIps  >moderniseerima !28_V	et	f	\N
159101	moderniseeritud	moderniseeritud =moderniseeritu  (PlN  >moderniseeritu !01_S	et	f	\N
159102	moderniseeritud	"moderniseeritu %moderniseeri  )TU1_vS  <moderniseerima ;28_V	et	f	\N
159103	moderniseeritud	moderniseeritud =moderniseeritud  (ID  >moderniseeritud !41_A	et	f	\N
159104	moderniseeritud	"moderniseeritud %moderniseeri  )TUD_vA  <moderniseerima ;28_V	et	f	\N
159105	moderniseeritud	moderniseeritud =eritu  (PlN  >modern+ise+eritu !01_AS	et	f	\N
159106	moderniseeritud	"modern+ise+eritu %eri  )TU2_kA  <modern+ise+eri ;17_S	et	f	\N
159107	moderniseeritud	moderniseeritud =seeritu  (PlN  >moderni+seeritu !01_AS	et	f	\N
159114	vastustekaart	vastustekaart =kaar  (SgP  >vast+uste+kaar !13_S	et	f	\N
159116	vastustekaart	vastustekaart =kaart  (SgN  >vast+uste+kaart !22_S	et	f	\N
159156	teatrireisi	teatrireisi =reis  (PlP  >teatri+reis !14_S	et	f	\N
159157	teatrireisi	teatrireisi =reisi  (SgG  >teatri+reis !22_S	et	f	\N
159158	teatrireisi	teatrireisi =reisi  (SgP  >teatri+reis !22_S	et	f	\N
159159	teatrireisi	teatrireisi =reisi  (SgAdt  >teatri+reis !22_S	et	f	\N
159163	osavõtusoovist	osavõtusoovist =vist  (SgN  >osa+võtu+soo+vist !22_S	et	f	\N
159164	osavõtusoovist	osavõtusoovist =soovi  (SgEl  >osa+võtu+soov !22_S	et	f	\N
159169	tellisid	tellisid =telli  (IndIpfSg2  >tellima !28_V	et	f	\N
159170	tellisid	tellisid =telli  (IndIpfPl3  >tellima !28_V	et	f	\N
159171	ermitaazi	?ermitaazi =ermitaazi  (SgN  >ermitaazi !16_S	et	f	\N
159172	ermitaazi	?ermitaazi =ermitaazi  (SgG  >ermitaazi !16_S	et	f	\N
159186	hommikku-	?hommikku- =hommikku  (SgN  >hommikku !01_S	et	f	\N
159187	hommikku-	?hommikku- =hommikku  (SgG  >hommikku !01_S	et	f	\N
159188	hommikku-	?hommikku- =hommikku  (IndPrPs_  >hommikkuma !27_V	et	f	\N
159189	hommikku-	?hommikku- =hommikku  (ImpPrSg2  >hommikkuma !27_V	et	f	\N
159190	gruppivanem	?gruppivanem =gruppivanem  (SgN  >gruppivanem !02_A	et	f	\N
159193	cwb	### cwb	et	f	\N
159195	majandusteaduskonnas	majandusteaduskonnas =konna  (SgIn  >majandus+teadus+konn !22_S	et	f	\N
159196	majandusteaduskonnas	majandusteaduskonnas =teaduskonna  (SgIn  >majandus+teaduskond !22_S	et	f	\N
159202	stockman	?stockman =stockma  (IndPrSg1  >stockmama !29_V	et	f	\N
159203	stockman	?stockman =stockman  (SgN  >stockman !02_S	et	f	\N
159207	ettevõtlikkus	ettevõtlikkus =võtlikkus  (SgN  >ette+võtlikkus !11~09_S	et	f	\N
159208	ettevõtlikkus	"ette+võtlikkus %võtlikku  )US_aS  <ette+võtlik ;25_A	et	f	\N
159215	jäädes	jäädes =jää  (PlIn  >jää !26_S	et	f	\N
159216	jäädes	jäädes =jää  (Ger  >jääma !37_V	et	f	\N
159220	tietopuhelin	?tietopuhelin =tietopuhelin  (SgN  >tietopuhelin !19_S	et	f	\N
159225	kompuutril	?kompuutril =kompuutri  (SgAd  >kompuutri !01_S	et	f	\N
159226	kompuutril	?kompuutril =kompuutri  (SgAd  >kompuuter !02_S	et	f	\N
159227	kompuutril	?kompuutril =puutri  (SgAd  >kom+puuter !02_S	et	f	\N
159267	anja	?anja =anja  (SgN  >anja !16_S	et	f	\N
159268	anja	?anja =anja  (SgG  >anjas !02_A	et	f	\N
159269	anja	?anja =anja  (SgG  >anja !16_S	et	f	\N
159270	anja	?anja =anja  (IndPrPs_  >anjama !29_V	et	f	\N
159271	anja	?anja =anja  (ImpPrSg2  >anjama !29_V	et	f	\N
159272	tütriga	?tütriga =tütri  (SgKom  >tütter !02_S	et	f	\N
159296	ml	### ml	et	f	\N
159304	fjodorova	?fjodorova =fjodorova  (SgN  >fjodorova !16_S	et	f	\N
159305	fjodorova	?fjodorova =fjodorova  (SgG  >fjodorov !02_A	et	f	\N
159306	fjodorova	?fjodorova =fjodorova  (SgG  >fjodorova !16_S	et	f	\N
159307	ev-31	### ev-31	et	f	\N
159308	juhendaja	juhendaja =juhendaja  (SgN  >juhendaja !01_S	et	f	\N
159309	juhendaja	"juhendaja %juhenda  )JA_vS  <juhendama ;27_V	et	f	\N
159310	juhendaja	juhendaja =juhendaja  (SgG  >juhendaja !01_S	et	f	\N
159311	juhendaja	juhendaja =aja  (SgG  >juhend+aeg !22_S	et	f	\N
159313	kõrvutavalt	kõrvutavalt =kõrvutava  (SgAbl  >kõrvutav !02_A	et	f	\N
159314	kõrvutavalt	"kõrvutav %kõrvuta  )V_vA  <kõrvutama ;27_V	et	f	\N
159315	kõrvutavalt	kõrvutavalt =kõrvutavalt  (ID  >kõrvutavalt !41_D	et	f	\N
159316	kõrvutavalt	"kõrvutavalt %kõrvuta  )VALT_mD  <kõrvutama ;27_V	et	f	\N
159317	kõrvutavalt	kõrvutavalt =tava  (SgAbl  >kõrvu+tava !17_S	et	f	\N
159323	kasutust	kasutust =kasutu  (SgEl  >kasutu !01_A	et	f	\N
159325	kasutust	"kasutu %kasu  )TU2_kA  <kasu ;17_S	et	f	\N
159326	kasutust	kasutust =kasutus  (SgP  >kasutus !11_S	et	f	\N
159327	kasutust	"kasutus %kasuta  )US_vS  <kasutama ;27_V	et	f	\N
159328	kasutust	"kasutus %kasu  )TUS2_aS  <kasu ;17_S	et	f	\N
159329	kasutust	kasutust =tust  (SgN  >kasu+tust !22_S	et	f	\N
159349	sagedus	sagedus =sagedus  (SgN  >sagedus !11_S	et	f	\N
159350	sagedus	"sagedus %sageda  )US_aS  <sage ;02_A	et	f	\N
159351	interferentsi	interferentsi =interferentsi  (SgG  >interferents !22_S	et	f	\N
159352	interferentsi	interferentsi =interferentsi  (SgP  >interferents !22_S	et	f	\N
159353	interferentsi	interferentsi =interferentsi  (SgAdt  >interferents !22_S	et	f	\N
159359	omandamisel	omandamisel =omandamise  (SgAd  >omandamine !12_S	et	f	\N
159078	kodakonsus	?kodakonsus =konsu  (SgIn  >koda+konsu !16_S	et	f	\N
159079	kodakonsus	?kodakonsus =konsus  (SgN  >koda+konsus !11~09_S	et	f	\N
159086	korterissel	?korterissel =korterisse  (SgAd  >korterisne !02_A	et	f	\N
159087	korterissel	?korterissel =korterisse  (PlAd  >korteriss !22_S	et	f	\N
159088	korterissel	?korterissel =korterissel  (SgN  >korterissel !02_S	et	f	\N
159108	liimonaadiga	?liimonaadiga =liimonaadi  (SgKom  >liimonaadi !16_S	et	f	\N
159109	liimonaadiga	?liimonaadiga =liimonaadi  (SgKom  >liimonaat !22_S	et	f	\N
159110	liimonaadiga	?liimonaadiga =onaadi  (SgKom  >liim+onaadi !16_S	et	f	\N
159111	liimonaadiga	?liimonaadiga =onaadi  (SgKom  >liim+onaat !22_S	et	f	\N
159115	linnaujula	linnaujula =ujula  (SgN  >linna+ujula !01_S	et	f	\N
159117	linnaujula	linnaujula =ujula  (SgG  >linna+ujula !01_S	et	f	\N
159123	lindikogu	lindikogu =kogu  (SgN  >lindi+kogu !17_S	et	f	\N
159124	lindikogu	lindikogu =kogu  (SgG  >lindi+kogu !17_S	et	f	\N
159125	lindikogu	lindikogu =kogu  (SgP  >lindi+kogu !17_S	et	f	\N
159129	pühkepäevati	?pühkepäevati =pühkepäevati  (SgG  >pühkepäevatt !22_S	et	f	\N
159130	pühkepäevati	?pühkepäevati =pühkepäevati  (IndPrPs_  >pühkepäevattima !28_V	et	f	\N
159131	pühkepäevati	?pühkepäevati =pühkepäevati  (ImpPrSg2  >pühkepäevattima !28_V	et	f	\N
159132	gsm	### gsm	et	f	\N
159133	kollegidega	### kollegidega	et	f	\N
159136	koolikaaslastega	koolikaaslastega =las  (PlKom  >kooli+kaas+laps !14_S	et	f	\N
159137	koolikaaslastega	koolikaaslastega =kaaslas  (PlKom  >kooli+kaaslane !12?10_S	et	f	\N
159146	toetusraha	toetusraha =raha  (SgN  >toetus+raha !17_S	et	f	\N
159147	toetusraha	toetusraha =raha  (SgG  >toetus+raha !17_S	et	f	\N
159148	toetusraha	toetusraha =raha  (SgG  >toetus+rahk !22_S	et	f	\N
159149	toetusraha	toetusraha =raha  (SgP  >toetus+raha !17_S	et	f	\N
159175	tekkimisele	tekkimisele =tekkimise  (SgAll  >tekkimine !12_S	et	f	\N
159176	tekkimisele	"tekkimine %tekki  )MINE_vS  <tekkima ;27_V	et	f	\N
159177	tekkimisele	"tekkimine %tekki  )MINE_vS  <tekkima ;28_V	et	f	\N
159192	cwb	### cwb	et	f	\N
159204	sellesed	?sellesed =sellese  (PlN  >sellene !10_A	et	f	\N
159213	töötasuks	töötasuks =suks  (SgN  >tööta+suks !22_S	et	f	\N
159214	töötasuks	töötasuks =tasu  (SgTr  >töö+tasu !17_S	et	f	\N
159217	14032002a	### 14032002a	et	f	\N
159235	veetan	?veetan =veeta  (IndPrSg1  >veetama !27_V	et	f	\N
159236	veetan	?veetan =veetan  (SgN  >veetan !02_S	et	f	\N
159240	sõbratega	### sõbratega	et	f	\N
159241	aeroobikasse	aeroobikasse =aeroobika  (SgIll  >aeroobika !01_S	et	f	\N
159242	aeroobikasse	aeroobikasse =aeroobikas  (SgAdt  >aeroobikane !12_A	et	f	\N
159243	aeroobikasse	"aeroobikane %aeroobika  )NE_aA  <aeroobika ;01_S	et	f	\N
159248	teinnen	?teinnen =teinne  (IndPrSg1  >teinnema !27_V	et	f	\N
159249	teinnen	?teinnen =teinnen  (SgN  >teinnen !02_S	et	f	\N
159253	matkavad	matkavad =matka  (IndPrPl3  >matkama !29_V	et	f	\N
159254	matkavad	matkavad =matkava  (PlN  >matkav !02_A	et	f	\N
159255	matkavad	"matkav %matka  )V_vA  <matkama ;29_V	et	f	\N
159256	lumesõda	lumesõda =sõda  (SgN  >lume+sõda !18_S	et	f	\N
159257	lumesõda	lumesõda =sõda  (SgP  >lume+sõda !18_S	et	f	\N
159273	vatame	?vatame =vata  (IndPrPl1  >vatama !27_V	et	f	\N
159274	muultik	?muultik =muultik  (SgN  >muultik !02_S	et	f	\N
159281	kehalise	kehalise =kehalise  (SgG  >kehaline !12_A	et	f	\N
159282	kehalise	"kehaline %keha  )LINE_aA  <keha ;17_S	et	f	\N
159287	ple	### ple	et	f	\N
159292	pl	### pl	et	f	\N
159299	darja	?darja =darja  (SgN  >darja !16_S	et	f	\N
159300	darja	?darja =darja  (SgG  >darjas !02_A	et	f	\N
159301	darja	?darja =darja  (SgG  >darja !16_S	et	f	\N
159302	darja	?darja =darja  (IndPrPs_  >darjama !29_V	et	f	\N
159303	darja	?darja =darja  (ImpPrSg2  >darjama !29_V	et	f	\N
159312	verschik	?verschik =verschik  (SgN  >verschik !02_S	et	f	\N
159343	käändevormide	?käändevormide =käändevormi  (PlG  >käändevorm !22_S	et	f	\N
159344	käändevormide	?käändevormide =evormi  (PlG  >käänd+evorm !22_S	et	f	\N
159365	õnelejel	### õnelejel	et	f	\N
159372	kõrvutav	kõrvutav =kõrvuta  (PtsPrPs  >kõrvutama !27_V	et	f	\N
159373	kõrvutav	kõrvutav =kõrvutav  (SgN  >kõrvutav !02_A	et	f	\N
159374	kõrvutav	"kõrvutav %kõrvuta  )V_vA  <kõrvutama ;27_V	et	f	\N
159376	ainukesed	ainukesed =ainukese  (PlN  >ainuke !12_AS	et	f	\N
159377	ainukesed	"ainuke %ainu  )KE_dS  <ainu ;16_S	et	f	\N
159378	ainukesed	"ainuke %ainu  )KE_dA  <ainus ;07_AS	et	f	\N
159379	ainukesed	ainukesed =ainukese  (PlN  >ainukene !12_S	et	f	\N
159380	ainukesed	"ainukene %ainu  )KENE_dS  <ainu ;16_S	et	f	\N
159381	ainukesed	"ainukene %ainu  )KENE_dA  <ainus ;07_AS	et	f	\N
159392	sügavamalt	sügavamalt =sügavama  (SgAbl  >sügavam !02_A	et	f	\N
159393	sügavamalt	"sügavam %süga  )VAM_cA  <sügama ;27_V	et	f	\N
159394	sügavamalt	"sügavam %sügava  )M_cA  <sügav ;02_A	et	f	\N
159395	sügavamalt	sügavamalt =sügavamalt  (ID  >sügavamalt !41_D	et	f	\N
159396	sügavamalt	"sügavamalt %süga  )VAMALT_mD  <sügama ;27_V	et	f	\N
159397	sügavamalt	"sügavamalt %sügava  )MALT_mD  <sügav ;02_A	et	f	\N
159428	kõrvutamine	kõrvutamine =kõrvutamine  (SgN  >kõrvutamine !12_S	et	f	\N
159145	toetanud	toetanud =tanu  (PlN  >toe+tanu !17_S	et	f	\N
159165	otsusta	otsusta =otsusta  (IndPrPs_  >otsustama !27_V	et	f	\N
159166	otsusta	otsusta =otsusta  (ImpPrSg2  >otsustama !27_V	et	f	\N
159167	pihvo	?pihvo =pihvo  (SgN  >pihvo !16_S	et	f	\N
159168	pihvo	?pihvo =pihvo  (SgG  >pihvo !16_S	et	f	\N
159197	amerikas	?amerikas =amerika  (SgIn  >amerika !01_S	et	f	\N
159198	amerikas	?amerikas =amerika  (SgIn  >amerikas !02_A	et	f	\N
159199	amerikas	?amerikas =amerikas  (SgN  >amerikas !02_A	et	f	\N
159218	lp	### lp	et	f	\N
159229	klaasikamuusikat	?klaasikamuusikat =klaasikamuusika  (SgP  >klaasikamuusika !01_S	et	f	\N
159230	klaasikamuusikat	?klaasikamuusikat =klaasikamuusika  (SgP  >klaasikamuusikas !02_A	et	f	\N
159231	klaasikamuusikat	?klaasikamuusikat =kamuusika  (SgP  >klaasi+kamuusika !01_S	et	f	\N
159232	klaasikamuusikat	?klaasikamuusikat =kamuusika  (SgP  >klaasi+kamuusikas !02_A	et	f	\N
159233	klaasikamuusikat	?klaasikamuusikat =ikamuusika  (SgP  >klaas+ikamuusika !01_S	et	f	\N
159234	klaasikamuusikat	?klaasikamuusikat =ikamuusika  (SgP  >klaas+ikamuusikas !02_A	et	f	\N
159237	huvialased	huvialased =alase  (PlN  >huvi+alane !10_AS	et	f	\N
159238	huvialased	"huvi+alane %ala  )NE_aA  <huvi+ala ;17_S	et	f	\N
159244	jõustiga	?jõustiga =jõusti  (SgKom  >jõust !22_S	et	f	\N
159245	jõustiga	?jõustiga =stiga  (SgN  >jõu+stiga !17_S	et	f	\N
159246	jõustiga	?jõustiga =stiga  (SgG  >jõu+stiga !17_S	et	f	\N
159247	jõustiga	?jõustiga =stiga  (SgP  >jõu+stiga !17_S	et	f	\N
159258	lumememme	lumememme =memme  (SgG  >lume+memm !22_S	et	f	\N
159259	lumememme	lumememme =memme  (SgP  >lume+memm !22_S	et	f	\N
159260	lumememme	lumememme =memme  (SgAdt  >lume+memm !22_S	et	f	\N
159261	lumememme	lumememme =memme  (PlP  >lume+memm !22_S	et	f	\N
159276	kompjutriga	?kompjutriga =kompjutri  (SgKom  >kompjutri !01_S	et	f	\N
159277	kompjutriga	?kompjutriga =kompjutri  (SgKom  >kompjutter !02_S	et	f	\N
159278	kompjutriga	?kompjutriga =kompjutri  (SgKom  >kompjuter !19_S	et	f	\N
159297	mn	### mn	et	f	\N
159318	lubavad	lubavad =luba  (IndPrPl3  >lubama !27_V	et	f	\N
159319	lubavad	lubavad =lubava  (PlN  >lubav !02_A	et	f	\N
159320	lubavad	"lubav %luba  )V_vA  <lubama ;27_V	et	f	\N
159345	sotsiolingvistilistest	sotsiolingvistilistest =lingvistilis  (PlEl  >sotsio+lingvistiline !12_A	et	f	\N
159346	sotsiolingvistilistest	"sotsio+lingvistiline %lingvisti  )LINE_aA  <sotsio+lingvist ;22_S	et	f	\N
159361	universaalsete	universaalsete =universaalse  (PlG  >universaalne !02_A	et	f	\N
159362	universaalsete	universaalsete =sete  (SgN  >universaal+sete !06_S	et	f	\N
159375	uurimisväärt	?uurimisväärt =uurimisväärt  (SgN  >uurimisväärt !22_S	et	f	\N
159404	eesti-vene	eesti-vene =vene  (ID  >eesti-vene !41_G	et	f	\N
159405	eesti-vene	eesti-vene =vene  (SgN  >eesti-vene !16_S	et	f	\N
159406	eesti-vene	eesti-vene =vene  (SgG  >eesti-vene !16_S	et	f	\N
159426	sarnasusi	sarnasusi =sarnasusi  (PlP  >sarnasus !11_S	et	f	\N
159427	sarnasusi	"sarnasus %sarna  )SUS_aS  <sarn ;22_S	et	f	\N
159432	sarnasustele	sarnasustele =sarnasus  (PlAll  >sarnasus !11_S	et	f	\N
159433	sarnasustele	"sarnasus %sarna  )SUS_aS  <sarn ;22_S	et	f	\N
159441	kaalutustel	kaalutustel =kaalutus  (PlAd  >kaalutus !11_S	et	f	\N
159442	kaalutustel	"kaalutus %kaalu  )TUS1_aS  <kaaluma ;28_V	et	f	\N
159443	kaalutustel	"kaalutus %kaalu  )TUS2_aS  <kaal ;22_S	et	f	\N
159444	kaalutustel	kaalutustel =tuste  (PlAd  >kaalu+tust !22_S	et	f	\N
159473	sageduse	sageduse =sageduse  (SgG  >sagedus !11_S	et	f	\N
159474	sageduse	"sagedus %sageda  )US_aS  <sage ;02_A	et	f	\N
159486	tõhusamateks	tõhusamateks =tõhusama  (PlTr  >tõhusam !02_A	et	f	\N
159487	tõhusamateks	"tõhusam %tõhusa  )M_cA  <tõhus ;02_A	et	f	\N
159497	infinitiivvormid	?infinitiivvormid =infinitiivvormi  (PlN  >infinitiivvorm !22_S	et	f	\N
159498	infinitiivvormid	?infinitiivvormid =infinitiivvormi  (IndPrSg2  >infinitiivvormima !28_V	et	f	\N
159517	täpsemaid	täpsemaid =täpsema  (PlP  >täpsem !02_A	et	f	\N
159518	täpsemaid	"täpsem %täpse  )M_cA  <täpne ;02_A	et	f	\N
159519	njuansse	?njuansse =njuansse  (SgN  >njuansse !06_S	et	f	\N
159520	njuansse	?njuansse =njuansse  (SgG  >njuansne !02_A	et	f	\N
159521	njuansse	?njuansse =njuansse  (SgG  >njuansse !06_S	et	f	\N
159522	njuansse	?njuansse =njuansse  (PlP  >njuanss !22_S	et	f	\N
159523	njuansse	?njuansse =njuansse  (IndPrPs_  >njuanssema !27_V	et	f	\N
159524	njuansse	?njuansse =njuansse  (ImpPrSg2  >njuanssema !27_V	et	f	\N
159535	ühistest	ühistest =ühis  (PlEl  >ühine !10_A	et	f	\N
159536	ühistest	ühistest =test  (SgN  >ühis+test !22_S	et	f	\N
159539	predikaatverbidega	?predikaatverbidega =predikaatverbi  (PlKom  >predikaatverb !22_S	et	f	\N
159541	predikaatverbidega	?predikaatverbidega =dikaatverbi  (PlKom  >pre+dikaatverb !22_S	et	f	\N
159553	olemist	olemist =olemi  (SgEl  >olem !02_S	et	f	\N
159554	olemist	olemist =olemis  (SgP  >olemine !12_S	et	f	\N
159555	olemist	"olemine %ole  )MINE_vS  <olema ;36_V	et	f	\N
159556	olemist	"olemine %olemi  )NE_aA  <olem ;02_S	et	f	\N
159569	lubatavat	lubatavat =luba  (KvtPrIps  >lubama !27_V	et	f	\N
159571	lubatavat	lubatavat =lubatava  (SgP  >lubatav !02_A	et	f	\N
159573	lubatavat	"lubatav %luba  )TAV_vAS  <lubama ;27_V	et	f	\N
159578	teonime	teonime =nime  (SgG  >teo+nimi !20_S	et	f	\N
159152	reisikava	reisikava =kava  (SgP  >reisi+kava !17_S	et	f	\N
159155	ellenring	?ellenring =ellenring  (SgN  >ellenring !02_S	et	f	\N
159160	lisatasu	lisatasu =tasu  (SgN  >lisa+tasu !17_S	et	f	\N
159161	lisatasu	lisatasu =tasu  (SgG  >lisa+tasu !17_S	et	f	\N
159162	lisatasu	lisatasu =tasu  (SgP  >lisa+tasu !17_S	et	f	\N
159173	omakoolitunde	omakoolitunde =tunde  (SgG  >oma+kooli+tunne !06_S	et	f	\N
159174	omakoolitunde	omakoolitunde =tunde  (PlP  >oma+kooli+tund !22_S	et	f	\N
159178	laiad	laiad =laia  (PlN  >laid !22_S	et	f	\N
159179	laiad	laiad =laia  (PlN  >lai !22_A	et	f	\N
159182	kuulutuses	kuulutuses =kuulutuse  (SgIn  >kuulutus !11_S	et	f	\N
159183	kuulutuses	"kuulutus %kuuluta  )US_vS  <kuulutama ;27_V	et	f	\N
159184	kuulutuses	"kuulutus %kuulu  )TUS1_aS  <kuuluma ;27_V	et	f	\N
159185	kuulutuses	"kuulutus %kuulu  )TUS2_aS  <kuuld ;22_S	et	f	\N
159191	mnt13	### mnt13	et	f	\N
159194	tta	### tta	et	f	\N
159200	müügitöö	müügitöö =töö  (SgN  >müügi+töö !26_S	et	f	\N
159201	müügitöö	müügitöö =töö  (SgG  >müügi+töö !26_S	et	f	\N
159209	taibukas	taibukas =taibuka  (SgIn  >taibukas !02_A	et	f	\N
159210	taibukas	taibukas =taibukas  (SgN  >taibukas !02_A	et	f	\N
159219	kondideerida	?kondideerida =kondideeri  (Inf  >kondideerima !28_V	et	f	\N
159223	ekspress	ekspress =ekspress  (SgN  >ekspress !22_S	et	f	\N
159224	ekspress	ekspress =press  (SgN  >eks+press !22_S	et	f	\N
159239	ael	?ael =ael  (SgN  >ael !22_S	et	f	\N
159250	eedenevad	?eedenevad =eedene  (IndPrPl3  >eedenema !27_V	et	f	\N
159251	eedenevad	?eedenevad =eedeneva  (PlN  >eedenev !02_A	et	f	\N
159252	eedenevad	?eedenevad =eedeneva  (PlN  >eedeneva !16_S	et	f	\N
159266	ber	### ber	et	f	\N
159289	fondi	fondi =fondi  (SgG  >fond !22_S	et	f	\N
159290	fondi	fondi =fondi  (SgP  >fond !22_S	et	f	\N
159291	fondi	fondi =fondi  (SgAdt  >fond !22_S	et	f	\N
159294	viibimise	viibimise =viibimise  (SgG  >viibimine !12_S	et	f	\N
159295	viibimise	"viibimine %viibi  )MINE_vS  <viibima ;27_V	et	f	\N
159321	da-infinitiivi	da-infinitiivi =infinitiivi  (SgG  >da-infinitiiv !22_S	et	f	\N
159322	da-infinitiivi	da-infinitiivi =infinitiivi  (SgP  >da-infinitiiv !22_S	et	f	\N
159324	da-infinitiivi	da-infinitiivi =infinitiivi  (SgAdt  >da-infinitiiv !22_S	et	f	\N
159332	aktiivsuse	aktiivsuse =aktiivsuse  (SgG  >aktiivsus !11~09_S	et	f	\N
159333	aktiivsuse	"aktiivsus %aktiivse  )US_aS  <aktiivne ;02_A	et	f	\N
159334	laiendatud	laiendatud =laienda  (PtsPtIps  >laiendama !27_V	et	f	\N
159335	laiendatud	laiendatud =laiendatu  (PlN  >laiendatu !01_S	et	f	\N
159336	laiendatud	"laiendatu %laienda  )TU1_vS  <laiendama ;27_V	et	f	\N
159337	laiendatud	laiendatud =laiendatud  (ID  >laiendatud !41_A	et	f	\N
159338	laiendatud	"laiendatud %laienda  )TUD_vA  <laiendama ;27_V	et	f	\N
159357	esinevaid	esinevaid =esineva  (PlP  >esinev !02_A	et	f	\N
159358	esinevaid	"esinev %esine  )V_vA  <esinema ;27_V	et	f	\N
159363	õppijaid	õppijaid =õppija  (PlP  >õppija !01_S	et	f	\N
159364	õppijaid	"õppija %õppi  )JA_vS  <õppima ;28_V	et	f	\N
159370	üksteisest	üksteisest =teise  (SgEl  >üks+teise !12_P	et	f	\N
159371	üksteisest	üksteisest =teises  (SgP  >üks+teisene !10_A	et	f	\N
159402	õppijate	õppijate =õppija  (PlG  >õppija !01_S	et	f	\N
159403	õppijate	"õppija %õppi  )JA_vS  <õppima ;28_V	et	f	\N
159448	käändelisi	käändelisi =käändelisi  (PlP  >käändeline !12_A	et	f	\N
159449	käändelisi	"käändeline %käände  )LINE_aA  <kääne ;06_S	et	f	\N
159450	detailselt	detailselt =detailse  (SgAbl  >detailne !02_A	et	f	\N
159451	detailselt	detailselt =detailselt  (ID  >detailselt !41_D	et	f	\N
159452	detailselt	"detailselt %detailse  )LT_mD  <detailne ;02_A	et	f	\N
159453	veaanalüüsiga	?veaanalüüsiga =veaanalüüsi  (SgKom  >veaanalüüsi !16_S	et	f	\N
159454	veaanalüüsiga	?veaanalüüsiga =veaanalüüsi  (SgKom  >veaanalüüs !22_S	et	f	\N
159457	läbivaadatud	läbivaadatud =vaada  (PtsPtIps  >läbi+_vaatama !29_V	et	f	\N
159458	läbivaadatud	läbivaadatud =vaadatu  (PlN  >läbi+vaadatu !01_S	et	f	\N
159462	allikatest	allikatest =allika  (PlEl  >allikas !02_S	et	f	\N
159463	allikatest	allikatest =test  (SgN  >allika+test !22_S	et	f	\N
159464	allikatest	allikatest =ate  (PlEl  >allik+att !22_S	et	f	\N
159465	õliõpilaste	õliõpilaste =las  (PlG  >õli+õpi+laps !14_S	et	f	\N
159466	õliõpilaste	õliõpilaste =laste  (PlP  >õli+õpi+last !22_S	et	f	\N
159467	õliõpilaste	õliõpilaste =õpilas  (PlG  >õli+õpilane !12_S	et	f	\N
159470	kõrvutavat	kõrvutavat =kõrvuta  (KvtPrPs  >kõrvutama !27_V	et	f	\N
159471	kõrvutavat	kõrvutavat =kõrvutava  (SgP  >kõrvutav !02_A	et	f	\N
159472	kõrvutavat	"kõrvutav %kõrvuta  )V_vA  <kõrvutama ;27_V	et	f	\N
159477	metoodeid	?metoodeid =metoodei  (PlN  >metoodei !26_S	et	f	\N
159478	metoodeid	?metoodeid =metoodei  (SgP  >metoodei !26_S	et	f	\N
159511	soole	soole =soo  (SgAll  >sugu !18_S	et	f	\N
159512	soole	soole =soo  (SgAll  >soo !26_S	et	f	\N
159513	soole	soole =soole  (SgG  >sool !13_S	et	f	\N
159514	soole	soole =soole  (PlP  >sool !22_S	et	f	\N
159540	seostuvad	seostuvad =seostu  (IndPrPl3  >seostuma !27_V	et	f	\N
159542	seostuvad	seostuvad =seostuva  (PlN  >seostuv !02_A	et	f	\N
159360	omandamisel	"omandamine %omanda  )MINE_vS  <omandama ;27_V	et	f	\N
159366	kirjutajal	kirjutajal =kirjutaja  (SgAd  >kirjutaja !01_S	et	f	\N
159367	kirjutajal	"kirjutaja %kirjuta  )JA_vS  <kirjutama ;27_V	et	f	\N
159398	teadlikumalt	teadlikumalt =teadlikuma  (SgAbl  >teadlikum !02_A	et	f	\N
159399	teadlikumalt	"teadlikum %teadliku  )M_cA  <teadlik ;25_A	et	f	\N
159400	teadlikumalt	teadlikumalt =teadlikumalt  (ID  >teadlikumalt !41_D	et	f	\N
159401	teadlikumalt	"teadlikumalt %teadliku  )MALT_mD  <teadlik ;25_A	et	f	\N
159423	kõnelejad	kõnelejad =kõneleja  (PlN  >kõneleja !01_S	et	f	\N
159424	kõnelejad	"kõneleja %kõnele  )JA_vS  <kõnelema ;27_V	et	f	\N
159425	kõnelejad	"kõneleja %kõnele  )JA_vS  <kõnelema ;31_V	et	f	\N
159430	otstarbekas	otstarbekas =tarbeka  (SgIn  >ots+tarbekas !02_A	et	f	\N
159431	otstarbekas	otstarbekas =tarbekas  (SgN  >ots+tarbekas !02_A	et	f	\N
159434	erinevustele	erinevustele =erinevus  (PlAll  >erinevus !11?09_S	et	f	\N
159435	erinevustele	"erinevus %erine  )VUS_aS  <erinema ;27_V	et	f	\N
159436	erinevustele	"erinevus %erineva  )US_aS  <erinev ;02_A	et	f	\N
159479	keeleõppinguid	?keeleõppinguid =keeleõppingu  (PlP  >keeleõpping !02_S	et	f	\N
159480	keeleõppinguid	?keeleõppinguid =keeleõppingui  (PlN  >keeleõppingui !26_S	et	f	\N
159481	keeleõppinguid	?keeleõppinguid =keeleõppingui  (SgP  >keeleõppingui !26_S	et	f	\N
159482	keeleõppinguid	?keeleõppinguid =õppingu  (PlP  >keele+õppingu !01_S	et	f	\N
159483	keeleõppinguid	?keeleõppinguid =õppingu  (PlP  >keele+õpping !02_S	et	f	\N
159484	keeleõppinguid	?keeleõppinguid =õppingui  (PlN  >keele+õppingui !26_S	et	f	\N
159485	keeleõppinguid	?keeleõppinguid =õppingui  (SgP  >keele+õppingui !26_S	et	f	\N
159494	õrvutavalt	?õrvutavalt =õrvutava  (SgAbl  >õrvutav !02_A	et	f	\N
159495	õrvutavalt	?õrvutavalt =õrvutava  (SgAbl  >õrvutava !16_S	et	f	\N
159496	õrvutavalt	?õrvutavalt =õrvutavalt  (ID  >õrvutavalt !41_D	et	f	\N
159525	verbifraasi	?verbifraasi =verbifraasi  (SgN  >verbifraasi !16_S	et	f	\N
159526	verbifraasi	?verbifraasi =verbifraasi  (SgG  >verbifraasi !16_S	et	f	\N
159527	verbifraasi	?verbifraasi =verbifraasi  (SgG  >verbifraas !22_S	et	f	\N
159528	verbifraasi	?verbifraasi =verbifraasi  (SgP  >verbifraas !22_S	et	f	\N
159529	verbifraasi	?verbifraasi =verbifraasi  (SgAdt  >verbifraas !22_S	et	f	\N
159530	verbifraasi	?verbifraasi =verbifraasi  (IndPrPs_  >verbifraasima !28_V	et	f	\N
159531	verbifraasi	?verbifraasi =verbifraasi  (ImpPrSg2  >verbifraasima !28_V	et	f	\N
159547	liikumist	liikumist =liikumis  (SgP  >liikumine !12_S	et	f	\N
159548	liikumist	"liikumine %liiku  )MINE_vS  <liikuma ;28_V	et	f	\N
159549	alustamist	alustamist =alustamis  (SgP  >alustamine !12_S	et	f	\N
159550	alustamist	"alustamine %alusta  )MINE_vS  <alustama ;27_V	et	f	\N
159563	predikaatverbina	?predikaatverbina =predikaatverbi  (SgEs  >predikaatverp !22_S	et	f	\N
159564	predikaatverbina	?predikaatverbina =dikaatverbi  (SgEs  >pre+dikaatverp !22_S	et	f	\N
159565	objektilise	objektilise =objektilise  (SgG  >objektiline !12_A	et	f	\N
159566	objektilise	"objektiline %objekti  )LINE_aA  <objekt ;22_S	et	f	\N
159589	predikaatverbi	?predikaatverbi =predikaatverbi  (SgG  >predikaatverp !22_S	et	f	\N
159590	predikaatverbi	?predikaatverbi =predikaatverbi  (SgP  >predikaatverb !22_S	et	f	\N
159591	predikaatverbi	?predikaatverbi =predikaatverbi  (SgAdt  >predikaatverb !22_S	et	f	\N
159592	predikaatverbi	?predikaatverbi =predikaatverbi  (IndPrPs_  >predikaatverpima !28_V	et	f	\N
159593	predikaatverbi	?predikaatverbi =predikaatverbi  (ImpPrSg2  >predikaatverpima !28_V	et	f	\N
159594	predikaatverbi	?predikaatverbi =dikaatverbi  (SgG  >pre+dikaatverp !22_S	et	f	\N
159595	predikaatverbi	?predikaatverbi =dikaatverbi  (SgP  >pre+dikaatverb !22_S	et	f	\N
159596	predikaatverbi	?predikaatverbi =dikaatverbi  (SgAdt  >pre+dikaatverb !22_S	et	f	\N
159623	prepositsiooniga	prepositsiooniga =prepositsiooni  (SgKom  >prepositsioon !22_S	et	f	\N
159624	prepositsiooniga	prepositsiooniga =positsiooni  (SgKom  >pre+positsioon !22_S	et	f	\N
159638	vajalikkust	vajalikkust =vajalikkus  (SgP  >vajalikkus !11~09_S	et	f	\N
159639	vajalikkust	"vajalikkus %vajalikku  )US_aS  <vajalik ;25_A	et	f	\N
159665	järgnevat	järgnevat =järgne  (KvtPrPs  >järgnema !27_V	et	f	\N
159666	järgnevat	järgnevat =järgneva  (SgP  >järgnev !02_A	et	f	\N
159667	järgnevat	"järgnev %järgne  )V_vA  <järgnema ;27_V	et	f	\N
159677	tüdrukuid	tüdrukuid =tüdruku  (PlP  >tüdruk !02_S	et	f	\N
159678	tüdrukuid	tüdrukuid =ui  (PlN  >tüdruk+ui !26_S	et	f	\N
159679	tüdrukuid	tüdrukuid =ui  (SgP  >tüdruk+ui !26_S	et	f	\N
159680	tüdrukuid	tüdrukuid =uid  (SgN  >tüdruk+uid !22_S	et	f	\N
159683	eelnenud	eelnenud =eelne  (PtsPtPs  >eelnema !27_V	et	f	\N
159684	eelnenud	eelnenud =eelnenu  (PlN  >eelnenu !01_S	et	f	\N
159685	eelnenud	"eelnenu %eelne  )NU_vS  <eelnema ;27_V	et	f	\N
159686	eelnenud	eelnenud =eelnenud  (ID  >eelnenud !41_A	et	f	\N
159687	eelnenud	"eelnenud %eelne  )NUD_vA  <eelnema ;27_V	et	f	\N
159690	lakkamise	lakkamise =lakkamise  (SgG  >lakkamine !12_S	et	f	\N
159691	lakkamise	"lakkamine %lakka  )MINE_vS  <lakkama ;29_V	et	f	\N
159711	varakul	?varakul =varaku  (SgAd  >varak !02_S	et	f	\N
159712	varakul	?varakul =varakul  (SgN  >varakul !19_S	et	f	\N
159721	sõltuvusmäärusena	?sõltuvusmäärusena =sõltuvusmääruse  (SgEs  >sõltuvusmäärus !11~09_S	et	f	\N
159725	gerundiivi	?gerundiivi =gerundiivi  (SgN  >gerundiivi !16_S	et	f	\N
159384	võrdlevad	"võrdlev %võrdle  )V_vA  <võrdlema ;30_V	et	f	\N
159385	põhjalikku	põhjalikku =põhjalikku  (SgP  >põhjalik !25_A	et	f	\N
159386	põhjalikku	põhjalikku =põhjalikku  (SgAdt  >põhjalik !25_A	et	f	\N
159387	kõrvutava	kõrvutava =kõrvutava  (SgG  >kõrvutav !02_A	et	f	\N
159388	kõrvutava	"kõrvutav %kõrvuta  )V_vA  <kõrvutama ;27_V	et	f	\N
159389	kõrvutava	kõrvutava =tava  (SgN  >kõrvu+tava !17_S	et	f	\N
159390	kõrvutava	kõrvutava =tava  (SgG  >kõrvu+tava !17_S	et	f	\N
159391	kõrvutava	kõrvutava =tava  (SgP  >kõrvu+tava !17_S	et	f	\N
159407	kontrastiivse	?kontrastiivse =kontrastiivse  (SgG  >kontrastiivne !02_A	et	f	\N
159408	kontrastiivse	?kontrastiivse =kontrastiivse  (PlP  >kontrastiivs !22_S	et	f	\N
159409	kontrastiivse	?kontrastiivse =ivse  (SgN  >kontrasti+ivse !06_S	et	f	\N
159410	kontrastiivse	?kontrastiivse =ivse  (SgG  >kontrasti+ivne !02_A	et	f	\N
159411	kontrastiivse	?kontrastiivse =ivse  (SgG  >kontrasti+ivse !06_S	et	f	\N
159412	kontrastiivse	?kontrastiivse =ivse  (PlP  >kontrasti+ivs !22_S	et	f	\N
159413	kontrastiivse	?kontrastiivse =iivse  (SgN  >kontrast+iivse !06_S	et	f	\N
159414	kontrastiivse	?kontrastiivse =iivse  (SgG  >kontrast+iivne !02_A	et	f	\N
159415	kontrastiivse	?kontrastiivse =iivse  (SgG  >kontrast+iivse !06_S	et	f	\N
159416	kontrastiivse	?kontrastiivse =iivse  (PlP  >kontrast+iivs !22_S	et	f	\N
159417	kontrastiivse	?kontrastiivse =stiivse  (SgN  >kontra+stiivse !06_S	et	f	\N
159418	kontrastiivse	?kontrastiivse =stiivse  (SgG  >kontra+stiivne !02_A	et	f	\N
159419	kontrastiivse	?kontrastiivse =stiivse  (SgG  >kontra+stiivse !06_S	et	f	\N
159420	kontrastiivse	?kontrastiivse =stiivse  (PlP  >kontra+stiivs !22_S	et	f	\N
159421	kontrastiivse	?kontrastiivse =rastiivse  (SgG  >kont+rastiivne !02_A	et	f	\N
159422	kontrastiivse	?kontrastiivse =rastiivse  (PlP  >kont+rastiivs !22_S	et	f	\N
159437	psühholoogilistel	psühholoogilistel =psühholoogilis  (PlAd  >psühholoogiline !12_A	et	f	\N
159438	psühholoogilistel	"psühholoogiline %psühholoogi  )LINE_aA  <psühholoog ;22_S	et	f	\N
159439	psühholoogilistel	psühholoogilistel =loogilis  (PlAd  >psühho+loogiline !12_A	et	f	\N
159440	psühholoogilistel	"psühho+loogiline %loogi  )LINE_aA  <psühho+loog ;22_S	et	f	\N
159455	esinemissageduse	esinemissageduse =sageduse  (SgG  >esinemis+sagedus !11_S	et	f	\N
159456	esinemissageduse	"esinemis+sagedus %sageda  )US_aS  <esinemis+sage ;02_A	et	f	\N
159459	veaohtlikest	?veaohtlikest =veaohtlike  (PlEl  >veaohtlik !25_A	et	f	\N
159460	veaohtlikest	?veaohtlikest =veaohtlikes  (SgP  >veaohtlike !12_S	et	f	\N
159461	veaohtlikest	?veaohtlikest =veaohtlikes  (SgP  >veaohtlikene !12_S	et	f	\N
159499	verbikategoriaalset	?verbikategoriaalset =verbikategoriaalse  (SgP  >verbikategoriaalne !02_A	et	f	\N
159505	väljenda	väljenda =väljenda  (IndPrPs_  >väljendama !27_V	et	f	\N
159506	väljenda	väljenda =väljenda  (ImpPrSg2  >väljendama !27_V	et	f	\N
159507	viida	viida =vii  (IndPrIps_  >viima !38_V	et	f	\N
159508	viida	viida =viida  (SgG  >viit !22_S	et	f	\N
159509	viida	viida =viida  (IndPrPs_  >viitma !34_V	et	f	\N
159510	viida	viida =viida  (ImpPrSg2  >viitma !34_V	et	f	\N
159537	kõrvutamist	kõrvutamist =kõrvutamis  (SgP  >kõrvutamine !12_S	et	f	\N
159538	kõrvutamist	"kõrvutamine %kõrvuta  )MINE_vS  <kõrvutama ;27_V	et	f	\N
159544	väljendavad	väljendavad =väljenda  (IndPrPl3  >väljendama !27_V	et	f	\N
159545	väljendavad	väljendavad =väljendava  (PlN  >väljendav !02_A	et	f	\N
159546	väljendavad	"väljendav %väljenda  )V_vA  <väljendama ;27_V	et	f	\N
159567	soovitavat	soovitavat =soovi  (KvtPrIps  >soovima !28_V	et	f	\N
159568	soovitavat	soovitavat =soovita  (KvtPrPs  >soovitama !27_V	et	f	\N
159570	soovitavat	soovitavat =soovitava  (SgP  >soovitav !02_A	et	f	\N
159572	soovitavat	"soovitav %soovi  )TAV_vAS  <soovima ;28_V	et	f	\N
159574	soovitavat	"soovitav %soovita  )V_vA  <soovitama ;27_V	et	f	\N
159580	käändevormid	?käändevormid =käändevormi  (PlN  >käändevorm !22_S	et	f	\N
159581	käändevormid	?käändevormid =käändevormi  (IndPrSg2  >käändevormima !28_V	et	f	\N
159582	käändevormid	?käändevormid =evormi  (PlN  >käänd+evormi !01_S	et	f	\N
159583	käändevormid	?käändevormid =evormi  (PlN  >käänd+evorm !22_S	et	f	\N
159584	puuduvate	puuduvate =puuduva  (PlG  >puuduv !02_A	et	f	\N
159585	puuduvate	"puuduv %puudu  )V_vA  <puuduma ;27_V	et	f	\N
159655	algvormi	algvormi =vormi  (SgG  >alg+vorm !22_S	et	f	\N
159656	algvormi	algvormi =vormi  (SgP  >alg+vorm !22_S	et	f	\N
159657	algvormi	algvormi =vormi  (SgAdt  >alg+vorm !22_S	et	f	\N
159663	translatiiv	translatiiv =translatiiv  (SgN  >translatiiv !22_S	et	f	\N
159664	translatiiv	translatiiv =latiiv  (SgN  >trans+latiiv !22_S	et	f	\N
159681	mingile	mingile =mingi  (SgAll  >mingi !01_P	et	f	\N
159682	mingile	mingile =mingi  (SgAll  >mink !22_S	et	f	\N
159698	mast-vormiga	mast-vormiga =vormi  (SgKom  >mast-vorm !22_S	et	f	\N
159699	mast-vormiga	mast-vormiga =iga  (SgN  >mast-vorm+iga !18_S	et	f	\N
159700	mast-vormiga	mast-vormiga =iga  (SgP  >mast-vorm+iga !18_S	et	f	\N
159744	härga	härga =härga  (SgP  >härg !22_S	et	f	\N
159745	härga	härga =härga  (SgAdt  >härg !22_S	et	f	\N
159779	võimatust	võimatust =võimatu  (SgEl  >võimatu !01_A	et	f	\N
159780	võimatust	"võimatu %või  )MATU_vA  <võima ;37_V	et	f	\N
159781	võimatust	võimatust =võimatus  (SgP  >võimatus !11_S	et	f	\N
159429	kõrvutamine	"kõrvutamine %kõrvuta  )MINE_vS  <kõrvutama ;27_V	et	f	\N
159445	maksimaalselt	maksimaalselt =maksimaalse  (SgAbl  >maksimaalne !02_A	et	f	\N
159446	maksimaalselt	maksimaalselt =maksimaalselt  (ID  >maksimaalselt !41_D	et	f	\N
159447	maksimaalselt	"maksimaalselt %maksimaalse  )LT_mD  <maksimaalne ;02_A	et	f	\N
159468	arvulisi	arvulisi =arvulisi  (PlP  >arvuline !12_A	et	f	\N
159469	arvulisi	"arvuline %arvu  )LINE_aA  <arv ;22_S	et	f	\N
159475	seaduspärasuste	seaduspärasuste =pärasus  (PlG  >seadus+pärasus !11_S	et	f	\N
159476	seaduspärasuste	"seadus+pärasus %pära  )SUS_aS  <seadus+pära ;17_S	et	f	\N
159488	tulemusrikkamateks	?tulemusrikkamateks =tulemusrikkama  (PlTr  >tulemusrikkam !02_A	et	f	\N
159489	tulemusrikkamateks	?tulemusrikkamateks =tulemusrikkamate  (PlTr  >tulemusrikkamatt !22_S	et	f	\N
159490	tulemusrikkamateks	?tulemusrikkamateks =rikkama  (PlTr  >tulemus+rikkam !02_A	et	f	\N
159491	tulemusrikkamateks	?tulemusrikkamateks =rikkamate  (PlTr  >tulemus+rikkamatt !22_S	et	f	\N
159492	tulemusrikkamateks	?tulemusrikkamateks =musrikkama  (PlTr  >tule+musrikkam !02_A	et	f	\N
159493	tulemusrikkamateks	?tulemusrikkamateks =musrikkamate  (PlTr  >tule+musrikkamatt !22_S	et	f	\N
159500	kanna	kanna =kanna  (SgN  >kanna !16_S	et	f	\N
159501	kanna	kanna =kanna  (SgG  >kanna !16_S	et	f	\N
159502	kanna	kanna =kanna  (SgG  >kand !22_S	et	f	\N
159503	kanna	kanna =kanna  (IndPrPs_  >kandma !34_V	et	f	\N
159504	kanna	kanna =kanna  (ImpPrSg2  >kandma !34_V	et	f	\N
159515	edasta	edasta =edasta  (IndPrPs_  >edastama !27_V	et	f	\N
159516	edasta	edasta =edasta  (ImpPrSg2  >edastama !27_V	et	f	\N
159532	liitvormi	liitvormi =vormi  (SgG  >liit+vorm !22_S	et	f	\N
159533	liitvormi	liitvormi =vormi  (SgP  >liit+vorm !22_S	et	f	\N
159534	liitvormi	liitvormi =vormi  (SgAdt  >liit+vorm !22_S	et	f	\N
159609	tähistava	tähistava =tähistava  (SgG  >tähistav !02_A	et	f	\N
159610	tähistava	"tähistav %tähista  )V_vA  <tähistama ;27_V	et	f	\N
159611	tähistava	tähistava =tava  (SgN  >tähis+tava !17_S	et	f	\N
159612	tähistava	tähistava =tava  (SgG  >tähis+tava !17_S	et	f	\N
159613	tähistava	tähistava =tava  (SgP  >tähis+tava !17_S	et	f	\N
159614	loed	loed =loe  (PlN  >lood !22_S	et	f	\N
159615	loed	loed =loe  (IndPrSg2  >lugema !28_V	et	f	\N
159625	verbikonstruktsiooni	?verbikonstruktsiooni =verbikonstruktsioo  (SgTer  >verbikonstruktsioo !26_S	et	f	\N
159626	verbikonstruktsiooni	?verbikonstruktsiooni =verbikonstruktsiooni  (SgN  >verbikonstruktsiooni !16_S	et	f	\N
159627	verbikonstruktsiooni	?verbikonstruktsiooni =verbikonstruktsiooni  (SgG  >verbikonstruktsiooni !16_S	et	f	\N
159628	verbikonstruktsiooni	?verbikonstruktsiooni =verbikonstruktsiooni  (SgG  >verbikonstruktsioon !22_S	et	f	\N
159629	verbikonstruktsiooni	?verbikonstruktsiooni =verbikonstruktsiooni  (SgP  >verbikonstruktsioon !22_S	et	f	\N
159630	verbikonstruktsiooni	?verbikonstruktsiooni =verbikonstruktsiooni  (SgAdt  >verbikonstruktsioon !22_S	et	f	\N
159631	verbikonstruktsiooni	?verbikonstruktsiooni =verbikonstruktsiooni  (IndPrPs_  >verbikonstruktsioonima !28_V	et	f	\N
159632	verbikonstruktsiooni	?verbikonstruktsiooni =verbikonstruktsiooni  (ImpPrSg2  >verbikonstruktsioonima !28_V	et	f	\N
159647	jagunevad	jagunevad =jagune  (IndPrPl3  >jagunema !27_V	et	f	\N
159648	jagunevad	jagunevad =jaguneva  (PlN  >jagunev !02_A	et	f	\N
159649	jagunevad	"jagunev %jagune  )V_vA  <jagunema ;27_V	et	f	\N
159658	käändelist	käändelist =käändelis  (SgP  >käändeline !12_A	et	f	\N
159659	käändelist	"käändeline %käände  )LINE_aA  <kääne ;06_S	et	f	\N
159660	mas-	### mas-	et	f	\N
159672	ma-infinitiivi	ma-infinitiivi =infinitiivi  (SgG  >ma-infinitiiv !22_S	et	f	\N
159673	ma-infinitiivi	ma-infinitiivi =infinitiivi  (SgP  >ma-infinitiiv !22_S	et	f	\N
159674	ma-infinitiivi	ma-infinitiivi =infinitiivi  (SgAdt  >ma-infinitiiv !22_S	et	f	\N
159688	loobumise	loobumise =loobumise  (SgG  >loobumine !12_S	et	f	\N
159689	loobumise	"loobumine %loobu  )MINE_vS  <loobuma ;27_V	et	f	\N
159692	niitmast	niitmast =niit  (SupEl  >niitma !34_V	et	f	\N
159693	niitmast	niitmast =mast  (SgN  >niit+mast !22_S	et	f	\N
159701	söömast	söömast =söö  (SupEl  >sööma !38_V	et	f	\N
159702	söömast	söömast =sööma  (SgEl  >sööm !22_S	et	f	\N
159703	söömast	söömast =söömas  (SgP  >söömane !10_A	et	f	\N
159704	söömast	"söömane %sööma  )NE_aA  <sööm ;22_S	et	f	\N
159726	eitav	eitav =eita  (PtsPrPs  >eitama !27_V	et	f	\N
159728	eitav	eitav =eitav  (SgN  >eitav !02_A	et	f	\N
159730	eitav	"eitav %eita  )V_vA  <eitama ;27_V	et	f	\N
159735	niitmata	niitmata =niit  (SupAb  >niitma !34_V	et	f	\N
159736	niitmata	niitmata =niitmata  (ID  >niitmata !41_A	et	f	\N
159737	niitmata	"niitmata %niit  )MATA_vA  <niitma ;34_V	et	f	\N
159762	väljendamist	väljendamist =väljendamis  (SgP  >väljendamine !12_S	et	f	\N
159763	väljendamist	"väljendamine %väljenda  )MINE_vS  <väljendama ;27_V	et	f	\N
159768	paratamatust	paratamatust =paratamatu  (SgEl  >paratamatu !01_A	et	f	\N
159769	paratamatust	paratamatust =paratamatus  (SgP  >paratamatus !11?09_S	et	f	\N
159770	aimamata	aimamata =aima  (SupAb  >aimama !29_V	et	f	\N
159771	aimamata	aimamata =aimamata  (ID  >aimamata !41_A	et	f	\N
159772	aimamata	"aimamata %aima  )MATA_vA  <aimama ;29_V	et	f	\N
159802	gerundiiv	?gerundiiv =gerundiiv  (SgN  >gerundiiv !22_S	et	f	\N
159809	nimisõnalise	nimisõnalise =sõnalise  (SgG  >nimi+sõnaline !12_A	et	f	\N
159543	seostuvad	"seostuv %seostu  )V_vA  <seostuma ;27_V	et	f	\N
159551	jätkamist	jätkamist =jätkamis  (SgP  >jätkamine !12_S	et	f	\N
159552	jätkamist	"jätkamine %jätka  )MINE_vS  <jätkama ;29_V	et	f	\N
159557	palutud	palutud =palu  (PtsPtIps  >paluma !27_V	et	f	\N
159558	palutud	palutud =palutu  (PlN  >palutu !01_AS	et	f	\N
159559	palutud	"palutu %palu  )TU1_vS  <paluma ;27_V	et	f	\N
159560	palutud	"palutu %palu  )TU2_kA  <palu ;17_S	et	f	\N
159561	palutud	palutud =palutud  (ID  >palutud !41_A	et	f	\N
159562	palutud	"palutud %palu  )TUD_vA  <paluma ;27_V	et	f	\N
159575	vajatavad	vajatavad =vajatava  (PlN  >vajatav !02_A	et	f	\N
159576	vajatavad	"vajatav %vaja  )TAV_vAS  <vajama ;27_V	et	f	\N
159577	vajatavad	vajatavad =tava  (PlN  >vaja+tava !17_S	et	f	\N
159597	pöördeline	pöördeline =pöördeline  (SgN  >pöördeline !12_A	et	f	\N
159598	pöördeline	"pöördeline %pöörde  )LINE_aA  <pööre ;06_S	et	f	\N
159606	verbi	verbi =verbi  (SgG  >verb !22_S	et	f	\N
159607	verbi	verbi =verbi  (SgP  >verb !22_S	et	f	\N
159608	verbi	verbi =verbi  (SgAdt  >verb !22_S	et	f	\N
159618	tuletatud	tuletatud =tuleta  (PtsPtIps  >tuletama !27_V	et	f	\N
159619	tuletatud	tuletatud =tuletatu  (PlN  >tuletatu !01_S	et	f	\N
159620	tuletatud	"tuletatu %tuleta  )TU1_vS  <tuletama ;27_V	et	f	\N
159621	tuletatud	tuletatud =tuletatud  (ID  >tuletatud !41_A	et	f	\N
159622	tuletatud	"tuletatud %tuleta  )TUD_vA  <tuletama ;27_V	et	f	\N
159633	põhivormi	põhivormi =vormi  (SgG  >põhi+vorm !22_S	et	f	\N
159634	põhivormi	põhivormi =vormi  (SgP  >põhi+vorm !22_S	et	f	\N
159635	põhivormi	põhivormi =vormi  (SgAdt  >põhi+vorm !22_S	et	f	\N
159640	soovitatavust	soovitatavust =soovitatavus  (SgP  >soovitatavus !11?09_S	et	f	\N
159641	soovitatavust	"soovitatavus %soovita  )TAVUS_aS  <soovitama ;27_V	et	f	\N
159642	soovitatavust	"soovitatavus %soovitatava  )US_aS  <soovitatav ;02_A	et	f	\N
159643	tegevusse	tegevusse =tegevus  (SgAdt  >tegevus !11_S	et	f	\N
159644	tegevusse	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
159645	tegevusse	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
159646	tegevusse	tegevusse =usse  (PlP  >tegev+uss !22_S	et	f	\N
159661	mata-	mata- =mata  (IndPrPs_  >matma !35_V	et	f	\N
159662	mata-	mata- =mata  (ImpPrSg2  >matma !35_V	et	f	\N
159668	suhtelist	suhtelist =suhtelis  (SgP  >suhteline !12_A	et	f	\N
159669	suhtelist	"suhteline %suhte  )LINE_aA  <suhe ;06_S	et	f	\N
159675	viibimist	viibimist =viibimis  (SgP  >viibimine !12_S	et	f	\N
159676	viibimist	"viibimine %viibi  )MINE_vS  <viibima ;27_V	et	f	\N
159705	pikemate	pikemate =pikema  (PlG  >pikem !02_A	et	f	\N
159706	pikemate	"pikem %pike  )M_cA  <pikk ;22_AS	et	f	\N
159707	töötamaks	töötamaks =tööta  (SupTr  >töötama !27_V	et	f	\N
159708	töötamaks	töötamaks =maks  (SgN  >tööta+maks !22_S	et	f	\N
159709	leidmaks	leidmaks =leid  (SupTr  >leidma !34_V	et	f	\N
159710	leidmaks	leidmaks =maks  (SgN  >leid+maks !22_S	et	f	\N
159713	istekohta	istekohta =kohta  (SgP  >iste+koht !22_S	et	f	\N
159714	istekohta	istekohta =kohta  (SgAdt  >iste+koht !22_S	et	f	\N
159718	puuduvat	puuduvat =puudu  (KvtPrPs  >puuduma !27_V	et	f	\N
159719	puuduvat	puuduvat =puuduva  (SgP  >puuduv !02_A	et	f	\N
159720	puuduvat	"puuduv %puudu  )V_vA  <puuduma ;27_V	et	f	\N
159722	koristamata	koristamata =korista  (SupAb  >koristama !27_V	et	f	\N
159723	koristamata	koristamata =koristamata  (ID  >koristamata !41_A	et	f	\N
159724	koristamata	"koristamata %korista  )MATA_vA  <koristama ;27_V	et	f	\N
159738	kutsumata	kutsumata =kutsu  (SupAb  >kutsuma !28_V	et	f	\N
159739	kutsumata	kutsumata =kutsumata  (ID  >kutsumata !41_A	et	f	\N
159740	kutsumata	"kutsumata %kutsu  )MATA_vA  <kutsuma ;28_V	et	f	\N
159741	aitamata	aitamata =aita  (SupAb  >aitama !29_V	et	f	\N
159742	aitamata	aitamata =aitamata  (ID  >aitamata !41_A	et	f	\N
159743	aitamata	"aitamata %aita  )MATA_vA  <aitama ;29_V	et	f	\N
159747	ühenduvad	ühenduvad =ühendu  (IndPrPl3  >ühenduma !27_V	et	f	\N
159748	ühenduvad	ühenduvad =ühenduva  (PlN  >ühenduv !02_A	et	f	\N
159749	ühenduvad	"ühenduv %ühendu  )V_vA  <ühenduma ;27_V	et	f	\N
159758	meele	meele =mee  (SgAll  >mesi !15_S	et	f	\N
159759	meele	meele =meele  (SgG  >meel !13_S	et	f	\N
159766	meelitas	meelitas =meelita  (IndIpfSg3  >meelitama !27_V	et	f	\N
159767	meelitas	meelitas =lita  (SgIn  >mee+lita !16_S	et	f	\N
159784	jäksama	?jäksama =jäksa  (Sup  >jäksama !29_V	et	f	\N
159785	jäksama	?jäksama =jäksama  (SgG  >jäksam !02_A	et	f	\N
159790	tahtelist	tahtelist =tahtelis  (SgP  >tahteline !12_A	et	f	\N
159791	tahtelist	"tahteline %tahte  )LINE_aA  <tahe ;06_S	et	f	\N
159806	käändelised	käändelised =käändelise  (PlN  >käändeline !12_A	et	f	\N
159807	käändelised	"käändeline %käände  )LINE_aA  <kääne ;06_S	et	f	\N
159816	katsu	katsu =katsu  (SgG  >kats !22_S	et	f	\N
159817	katsu	katsu =katsu  (SgP  >kats !22_S	et	f	\N
159818	katsu	katsu =katsu  (SgAdt  >kats !22_S	et	f	\N
159819	katsu	katsu =katsu  (IndPrPs_  >katsuma !28_V	et	f	\N
159820	katsu	katsu =katsu  (ImpPrSg2  >katsuma !28_V	et	f	\N
159839	tegelikkusega	tegelikkusega =tegelikkuse  (SgKom  >tegelikkus !11~09_S	et	f	\N
159579	teonime	teonime =nime  (SgP  >teo+nimi !20_S	et	f	\N
159586	leksikaalselt	leksikaalselt =leksikaalse  (SgAbl  >leksikaalne !02_A	et	f	\N
159587	leksikaalselt	leksikaalselt =leksikaalselt  (ID  >leksikaalselt !41_D	et	f	\N
159588	leksikaalselt	"leksikaalselt %leksikaalse  )LT_mD  <leksikaalne ;02_A	et	f	\N
159599	moodustatud	moodustatud =moodusta  (PtsPtIps  >moodustama !27_V	et	f	\N
159600	moodustatud	moodustatud =moodustatu  (PlN  >moodustatu !01_S	et	f	\N
159601	moodustatud	"moodustatu %moodusta  )TU1_vS  <moodustama ;27_V	et	f	\N
159602	moodustatud	moodustatud =moodustatud  (ID  >moodustatud !41_A	et	f	\N
159603	moodustatud	"moodustatud %moodusta  )TUD_vA  <moodustama ;27_V	et	f	\N
159604	pistis	pistis =pist  (IndIpfSg3  >pistma !34_V	et	f	\N
159605	pistis	pistis =pistis  (SgN  >pistis !09_S	et	f	\N
159616	venekeelseks	venekeelseks =seks  (SgN  >vene+keel+seks !22_S	et	f	\N
159617	venekeelseks	venekeelseks =keelse  (SgTr  >vene+keelne !02_A	et	f	\N
159636	võimalikkust	võimalikkust =võimalikkus  (SgP  >võimalikkus !11~09_S	et	f	\N
159637	võimalikkust	"võimalikkus %võimalikku  )US_aS  <võimalik ;25_A	et	f	\N
159650	sõltuvalt	sõltuvalt =sõltuva  (SgAbl  >sõltuv !02_A	et	f	\N
159651	sõltuvalt	"sõltuv %sõltu  )V_vA  <sõltuma ;27_V	et	f	\N
159652	sõltuvalt	sõltuvalt =sõltuvalt  (ID  >sõltuvalt !41_D	et	f	\N
159653	sõltuvalt	"sõltuvalt %sõltu  )VALT_mD  <sõltuma ;27_V	et	f	\N
159654	sõltuvalt	"sõltuvalt %sõltuva  )LT_mD  <sõltuv ;02_A	et	f	\N
159670	olevikku	olevikku =olevikku  (SgP  >olevik !25_S	et	f	\N
159671	olevikku	olevikku =olevikku  (SgAdt  >olevik !25_S	et	f	\N
159694	sadamast	sadamast =sada  (SupEl  >sadama !28_V	et	f	\N
159695	sadamast	sadamast =sadama  (SgEl  >sadam !02_S	et	f	\N
159696	sadamast	sadamast =sadamas  (SgP  >sadamane !12_A	et	f	\N
159697	sadamast	"sadamane %sadama  )NE_aA  <sadam ;02_S	et	f	\N
159715	toimumata	toimumata =toimu  (SupAb  >toimuma !27_V	et	f	\N
159716	toimumata	toimumata =toimumata  (ID  >toimumata !41_A	et	f	\N
159717	toimumata	"toimumata %toimu  )MATA_vA  <toimuma ;27_V	et	f	\N
159746	erelt	?erelt =erelt  (ID  >erelt !41_D	et	f	\N
159750	asutust	asutust =asutu  (SgEl  >asutu !01_AS	et	f	\N
159751	asutust	"asutu %asu  )TU1_vS  <asuma ;27_V	et	f	\N
159752	asutust	"asutu %asu  )TU2_kA  <asu ;17_S	et	f	\N
159753	asutust	asutust =asutus  (SgP  >asutus !11_S	et	f	\N
159754	asutust	"asutus %asuta  )US_vS  <asutama ;27_V	et	f	\N
159755	asutust	"asutus %asu  )TUS1_aS  <asuma ;27_V	et	f	\N
159756	asutust	"asutus %asu  )TUS2_aS  <asu ;17_S	et	f	\N
159757	asutust	asutust =tust  (SgN  >asu+tust !22_S	et	f	\N
159764	veenmine	veenmine =veenmine  (SgN  >veenmine !12?10_S	et	f	\N
159765	veenmine	"veenmine %veen  )MINE_vS  <veenma ;33_V	et	f	\N
159773	pääsema	pääsema =pääse  (Sup  >pääsema !28_V	et	f	\N
159774	pääsema	pääsema =ema  (SgN  >pääs+ema !17_S	et	f	\N
159775	pääsema	pääsema =ema  (SgG  >pääs+ema !17_S	et	f	\N
159776	pääsema	pääsema =ema  (SgP  >pääs+ema !17_S	et	f	\N
159777	varianti	varianti =varianti  (SgP  >variant !22_S	et	f	\N
159778	varianti	varianti =varianti  (SgAdt  >variant !22_S	et	f	\N
159786	tundelist	tundelist =tundeli  (SgEl  >tundel !02_S	et	f	\N
159787	tundelist	tundelist =tundelis  (SgP  >tundeline !12_A	et	f	\N
159788	tundelist	"tundeline %tunde  )LINE_aA  <tunne ;06_S	et	f	\N
159789	tundelist	"tundeline %tundeli  )NE_aA  <tundel ;02_S	et	f	\N
159796	julgima	?julgima =julgi  (Sup  >julgima !28_V	et	f	\N
159797	julgima	?julgima =julgima  (SgG  >julgim !02_A	et	f	\N
159808	tahes	tahes =tahe  (PlIn  >tahk !22_S	et	f	\N
159810	tahes	tahes =tahe  (PlIn  >taht !22_S	et	f	\N
159812	tahes	tahes =tahes  (ID  >tahes !41_D	et	f	\N
159841	kõneviisi	kõneviisi =viisi  (ID  >kõne+viisi !41_D	et	f	\N
159842	kõneviisi	kõneviisi =viisi  (SgG  >kõne+viis !22_S	et	f	\N
159843	kõneviisi	kõneviisi =viisi  (SgP  >kõne+viis !22_S	et	f	\N
159844	kõneviisi	kõneviisi =viisi  (SgAdt  >kõne+viis !22_S	et	f	\N
159878	tõlkides	tõlkides =tõlki  (PlIn  >tõlk !22_S	et	f	\N
159879	tõlkides	tõlkides =tõlki  (Ger  >tõlkima !28_V	et	f	\N
159891	morfoloogiline	morfoloogiline =morfoloogiline  (SgN  >morfoloogiline !12_A	et	f	\N
159892	morfoloogiline	"morfoloogiline %morfoloogi  )LINE_aA  <morfoloog ;22_S	et	f	\N
159914	tähenduse	tähenduse =tähenduse  (SgG  >tähendus !11_S	et	f	\N
159915	tähenduse	"tähendus %tähenda  )US_vS  <tähendama ;27_V	et	f	\N
159923	tähistavate	tähistavate =tähistava  (PlG  >tähistav !02_A	et	f	\N
159924	tähistavate	"tähistav %tähista  )V_vA  <tähistama ;27_V	et	f	\N
159943	jooksim	?jooksim =jooksim  (SgN  >jooksim !02_A	et	f	\N
159957	nimisõnast	nimisõnast =sõna  (SgEl  >nimi+sõna !17_S	et	f	\N
159958	nimisõnast	nimisõnast =sõnas  (SgP  >nimi+sõnane !10_A	et	f	\N
159959	nimisõnast	"nimi+sõnane %sõna  )NE_aA  <nimi+sõna ;17_S	et	f	\N
159966	pihlak	?pihlak =pihlak  (SgN  >pihlak !02_S	et	f	\N
159979	prepositsioon	prepositsioon =prepositsioon  (SgN  >prepositsioon !22_S	et	f	\N
159980	prepositsioon	prepositsioon =positsioon  (SgN  >pre+positsioon !22_S	et	f	\N
160017	liidub	?liidub =liidu  (IndPrSg3  >liiduma !27_V	et	f	\N
160018	suutlikkustvõimetust	?suutlikkustvõimetust =suutlikkustvõimetu  (SgEl  >suutlikkustvõimetu !01_A	et	f	\N
159727	gerundiivi	?gerundiivi =gerundiivi  (SgG  >gerundiivi !16_S	et	f	\N
159729	gerundiivi	?gerundiivi =gerundiivi  (SgG  >gerundiiv !22_S	et	f	\N
159731	gerundiivi	?gerundiivi =gerundiivi  (SgP  >gerundiiv !22_S	et	f	\N
159732	gerundiivi	?gerundiivi =gerundiivi  (SgAdt  >gerundiiv !22_S	et	f	\N
159733	gerundiivi	?gerundiivi =gerundiivi  (IndPrPs_  >gerundiivima !28_V	et	f	\N
159734	gerundiivi	?gerundiivi =gerundiivi  (ImpPrSg2  >gerundiivima !28_V	et	f	\N
159760	tahte	tahte =tahte  (SgG  >tahe !06_S	et	f	\N
159761	tahte	tahte =tahte  (PlP  >taht !22_S	et	f	\N
159792	käskima	käskima =käski  (Sup  >käskima !28_V	et	f	\N
159793	käskima	käskima =ima  (SgN  >käsk+ima !17_S	et	f	\N
159794	käskima	käskima =ima  (SgG  >käsk+ima !17_S	et	f	\N
159795	käskima	käskima =ima  (SgP  >käsk+ima !17_S	et	f	\N
159856	vokaali	vokaali =vokaali  (SgG  >vokaal !22_S	et	f	\N
159857	vokaali	vokaali =vokaali  (SgP  >vokaal !22_S	et	f	\N
159858	vokaali	vokaali =vokaali  (SgAdt  >vokaal !22_S	et	f	\N
159859	sisaldavate	sisaldavate =sisaldava  (PlG  >sisaldav !02_A	et	f	\N
159860	sisaldavate	"sisaldav %sisalda  )V_vA  <sisaldama ;27_V	et	f	\N
159870	tõlgija	?tõlgija =tõlgija  (SgN  >tõlgija !01_S	et	f	\N
159871	tõlgija	?tõlgija =tõlgija  (SgG  >tõlgija !01_S	et	f	\N
159872	tõlgija	?tõlgija =tõlgija  (SgG  >tõlgijas !02_A	et	f	\N
159882	kõnelejale	kõnelejale =kõneleja  (SgAll  >kõneleja !01_S	et	f	\N
159883	kõnelejale	"kõneleja %kõnele  )JA_vS  <kõnelema ;27_V	et	f	\N
159884	kõnelejale	"kõneleja %kõnele  )JA_vS  <kõnelema ;31_V	et	f	\N
159885	tähendustes	tähendustes =tähendus  (PlIn  >tähendus !11_S	et	f	\N
159886	tähendustes	"tähendus %tähenda  )US_vS  <tähendama ;27_V	et	f	\N
159889	üldistamine	üldistamine =üldistamine  (SgN  >üldistamine !12_S	et	f	\N
159890	üldistamine	"üldistamine %üldista  )MINE_vS  <üldistama ;27_V	et	f	\N
159898	konstruktsiooni	konstruktsiooni =konstruktsiooni  (SgG  >konstruktsioon !22_S	et	f	\N
159899	konstruktsiooni	konstruktsiooni =konstruktsiooni  (SgP  >konstruktsioon !22_S	et	f	\N
159900	konstruktsiooni	konstruktsiooni =konstruktsiooni  (SgAdt  >konstruktsioon !22_S	et	f	\N
159903	verbikonstruktsiooniga	?verbikonstruktsiooniga =verbikonstruktsiooni  (SgKom  >verbikonstruktsiooni !16_S	et	f	\N
159904	verbikonstruktsiooniga	?verbikonstruktsiooniga =verbikonstruktsiooni  (SgKom  >verbikonstruktsioon !22_S	et	f	\N
159908	põimlause	?põimlause =põimlause  (PlP  >põimlaus !22_S	et	f	\N
159919	ühilduvad	ühilduvad =ühildu  (IndPrPl3  >ühilduma !27_V	et	f	\N
159920	ühilduvad	ühilduvad =ühilduva  (PlN  >ühilduv !02_A	et	f	\N
159921	ühilduvad	"ühilduv %ühildu  )V_vA  <ühilduma ;27_V	et	f	\N
159944	sattumist	sattumist =sattumis  (SgP  >sattumine !12_S	et	f	\N
159945	sattumist	"sattumine %sattu  )MINE_vS  <sattuma ;27_V	et	f	\N
159946	sattumist	"sattumine %sattu  )MINE_vS  <sattuma ;28_V	et	f	\N
159947	vahetusega	vahetusega =vahetuse  (SgKom  >vahetus !11_S	et	f	\N
159948	vahetusega	"vahetus %vaheta  )US_vS  <vahetama ;27_V	et	f	\N
159949	vahetusega	"vahetus %vahe  )TUS2_aS  <vahe ;16_S	et	f	\N
159954	täistähenduslikust	täistähenduslikust =tähendusliku  (SgEl  >täis+tähenduslik !25_A	et	f	\N
159955	täistähenduslikust	täistähenduslikust =tähenduslikus  (SgP  >täis+tähenduslikus !11?09_S	et	f	\N
159956	täistähenduslikust	"täis+tähenduslikus %tähendusliku  )US_aS  <täis+tähenduslik ;25_A	et	f	\N
159974	sisaldav	sisaldav =sisalda  (PtsPrPs  >sisaldama !27_V	et	f	\N
159975	sisaldav	sisaldav =sisaldav  (SgN  >sisaldav !02_A	et	f	\N
159976	sisaldav	"sisaldav %sisalda  )V_vA  <sisaldama ;27_V	et	f	\N
159984	faasiverbid	?faasiverbid =faasiverbi  (PlN  >faasiverp !22_S	et	f	\N
159985	faasiverbid	?faasiverbid =faasiverbi  (IndPrSg2  >faasiverpima !28_V	et	f	\N
159993	modaalverbidega	?modaalverbidega =modaalverbi  (PlKom  >modaalverb !22_S	et	f	\N
159999	sunnitust	sunnitust =sunnitu  (SgEl  >sunnitu !01_AS	et	f	\N
160000	sunnitust	"sunnitu %sunni  )TU1_vS  <sundima ;28_V	et	f	\N
160001	sunnitust	"sunnitu %sunni  )TU2_kA  <sund ;22_S	et	f	\N
160002	sunnitust	sunnitust =sunnitus  (SgP  >sunnitus !11_S	et	f	\N
160003	sunnitust	"sunnitus %sunni  )TUS1_aS  <sundima ;28_V	et	f	\N
160004	sunnitust	"sunnitus %sunni  )TUS2_aS  <sund ;22_S	et	f	\N
160005	sunnitust	sunnitust =tust  (SgN  >sunni+tust !22_S	et	f	\N
160077	lõppenuid	lõppenuid =lõppenu  (PlP  >lõppenu !01_S	et	f	\N
160078	lõppenuid	"lõppenu %lõppe  )NU_vS  <lõppema ;27_V	et	f	\N
160079	lõppenuid	"lõppenu %lõppe  )NU_vS  <lõppema ;28_V	et	f	\N
160085	rädisema	rädisema =rädisema  (SgG  >rädisem !02_A	et	f	\N
160086	rädisema	"rädisem %rädi  )SEM_cA  <rädi ;17_S	et	f	\N
160087	rädisema	"rädisem %rädise  )M_cA  <rädine ;10_A	et	f	\N
160096	andmata	andmata =and  (SupAb  >andma !34_V	et	f	\N
160097	andmata	andmata =andmata  (ID  >andmata !41_A	et	f	\N
160098	andmata	"andmata %and  )MATA_vA  <andma ;34_V	et	f	\N
160104	põhiverbi	põhiverbi =verbi  (SgG  >põhi+verb !22_S	et	f	\N
160105	põhiverbi	põhiverbi =verbi  (SgP  >põhi+verb !22_S	et	f	\N
160106	põhiverbi	põhiverbi =verbi  (SgAdt  >põhi+verb !22_S	et	f	\N
160109	mitmekesises	?mitmekesises =mitmekesise  (SgIn  >mitmekesis !09_S	et	f	\N
160124	modaalverb	?modaalverb =modaalverb  (SgN  >modaalverb !22_S	et	f	\N
160125	mitmele	mitmele =mitme  (SgAll  >mitu !05_P	et	f	\N
159782	võimatust	"võimatus %või  )MATUS_aS  <võima ;37_V	et	f	\N
159783	võimatust	võimatust =matus  (SgP  >või+matus !09_S	et	f	\N
159798	mõttelist	mõttelist =mõttelis  (SgP  >mõtteline !12_A	et	f	\N
159799	mõttelist	"mõtteline %mõtte  )LINE_aA  <mõte ;06_S	et	f	\N
159800	kaalutlevas-kavandavas	kaalutlevas-kavandavas =kavandava  (SgIn  >kaalutlevas-kavandav !02_A	et	f	\N
159801	kaalutlevas-kavandavas	"kaalutlevas-kavandav %kavanda  )V_vA  <kaalutlevas-kavandama ;27_V	et	f	\N
159803	samaaegselt	samaaegselt =aegse  (SgAbl  >sama+aegne !02_A	et	f	\N
159804	samaaegselt	"sama+aegselt %aegse  )LT_mD  <sama+aegne ;02_A	et	f	\N
159805	lõunasime	?lõunasime =lõuna  (IndIpfPl1  >lõunama !29_V	et	f	\N
159813	alusena	alusena =aluse  (SgEs  >alus !09_S	et	f	\N
159814	alusena	alusena =aluse  (SgEs  >alune !10_AS	et	f	\N
159815	alusena	"alune %alu  )NE_aA  <alg ;22_S	et	f	\N
159834	määra	määra =määra  (SgG  >määr !22_S	et	f	\N
159835	määra	määra =määra  (SgP  >määr !22_S	et	f	\N
159836	määra	määra =määra  (SgAdt  >määr !22_S	et	f	\N
159837	määra	määra =määra  (IndPrPs_  >määrama !29_V	et	f	\N
159838	määra	määra =määra  (ImpPrSg2  >määrama !29_V	et	f	\N
159861	raskemaks	raskemaks =raskema  (SgTr  >raskem !02_A	et	f	\N
159862	raskemaks	"raskem %raske  )M_cA  <raske ;01_A	et	f	\N
159863	raskemaks	raskemaks =maks  (SgN  >raske+maks !22_S	et	f	\N
159911	fraasi	fraasi =fraasi  (SgG  >fraas !22_S	et	f	\N
159912	fraasi	fraasi =fraasi  (SgP  >fraas !22_S	et	f	\N
159913	fraasi	fraasi =fraasi  (SgAdt  >fraas !22_S	et	f	\N
159916	kandjaks	kandjaks =kandja  (SgTr  >kandja !01_S	et	f	\N
159917	kandjaks	"kandja %kand  )JA_vS  <kandma ;34_V	et	f	\N
159928	määravad	määravad =määra  (IndPrPl3  >määrama !29_V	et	f	\N
159929	määravad	määravad =määrava  (PlN  >määrav !02_A	et	f	\N
159930	määravad	"määrav %määra  )V_vA  <määrama ;29_V	et	f	\N
159931	väljendamine	väljendamine =väljendamine  (SgN  >väljendamine !12_S	et	f	\N
159932	väljendamine	"väljendamine %väljenda  )MINE_vS  <väljendama ;27_V	et	f	\N
159937	prepositsiooni	prepositsiooni =prepositsiooni  (SgG  >prepositsioon !22_S	et	f	\N
159938	prepositsiooni	prepositsiooni =prepositsiooni  (SgP  >prepositsioon !22_S	et	f	\N
159939	prepositsiooni	prepositsiooni =prepositsiooni  (SgAdt  >prepositsioon !22_S	et	f	\N
159940	prepositsiooni	prepositsiooni =positsiooni  (SgG  >pre+positsioon !22_S	et	f	\N
159941	prepositsiooni	prepositsiooni =positsiooni  (SgP  >pre+positsioon !22_S	et	f	\N
159942	prepositsiooni	prepositsiooni =positsiooni  (SgAdt  >pre+positsioon !22_S	et	f	\N
159960	omadussõnast	omadussõnast =sõna  (SgEl  >omadus+sõna !17_S	et	f	\N
159961	omadussõnast	omadussõnast =sõnas  (SgP  >omadus+sõnane !10_A	et	f	\N
159962	omadussõnast	"omadus+sõnane %sõna  )NE_aA  <omadus+sõna ;17_S	et	f	\N
159964	raagu	raagu =raagu  (ID  >raagu !41_D	et	f	\N
159965	raagu	raagu =raagu  (SgP  >raag !22_S	et	f	\N
159967	raagu	raagu =raagu  (SgAdt  >raag !22_S	et	f	\N
159968	raagu	raagu =raagu  (PlP  >raag !22_S	et	f	\N
159969	raagu	raagu =raagu  (IndPrPs_  >raaguma !27_V	et	f	\N
159970	raagu	raagu =raagu  (ImpPrSg2  >raaguma !27_V	et	f	\N
159977	verbifraas	?verbifraas =verbifraa  (SgIn  >verbifraa !26_S	et	f	\N
159978	verbifraas	?verbifraas =verbifraas  (SgN  >verbifraas !22_S	et	f	\N
159986	suitsetama	suitsetama =suitse  (SupIps  >suitsema !28_V	et	f	\N
159987	suitsetama	suitsetama =suitseta  (Sup  >suitsetama !27_V	et	f	\N
159988	faasiverbi	?faasiverbi =faasiverbi  (SgG  >faasiverp !22_S	et	f	\N
159989	faasiverbi	?faasiverbi =faasiverbi  (SgP  >faasiverb !22_S	et	f	\N
159990	faasiverbi	?faasiverbi =faasiverbi  (SgAdt  >faasiverb !22_S	et	f	\N
159991	faasiverbi	?faasiverbi =faasiverbi  (IndPrPs_  >faasiverpima !28_V	et	f	\N
159992	faasiverbi	?faasiverbi =faasiverbi  (ImpPrSg2  >faasiverpima !28_V	et	f	\N
159994	harvem	harvem =harvem  (ID  >harvem !41_D	et	f	\N
159995	harvem	"harvem %harve  )M_cA  <harv ;22_A	et	f	\N
159996	harvem	harvem =harvem  (SgN  >harvem !02_A	et	f	\N
160011	harjumust	harjumust =harjumus  (SgP  >harjumus !11_S	et	f	\N
160012	harjumust	"harjumus %harju  )MUS_vS  <harjuma ;27_V	et	f	\N
160013	harjumust	harjumust =must  (SgN  >harju+must !22_AS	et	f	\N
160014	näivust	näivust =näivus  (SgP  >näivus !11~09_S	et	f	\N
160015	näivust	"näivus %näi  )VUS_aS  <näima ;37_V	et	f	\N
160016	näivust	"näivus %näiva  )US_aS  <näiv ;02_A	et	f	\N
160020	püüdu	püüdu =püüdu  (SgP  >püüd !22_S	et	f	\N
160021	püüdu	püüdu =püüdu  (SgAdt  >püüd !22_S	et	f	\N
160026	lubamist	lubamist =lubamis  (SgP  >lubamine !12_S	et	f	\N
160027	lubamist	"lubamine %luba  )MINE_vS  <lubama ;27_V	et	f	\N
160056	laiemad	laiemad =laiema  (PlN  >laiem !02_A	et	f	\N
160057	laiemad	"laiem %laie  )M_cA  <lai ;22_A	et	f	\N
160058	laiemad	laiemad =ema  (PlN  >lai+ema !17_S	et	f	\N
160088	stiililiselt	stiililiselt =stiililise  (SgAbl  >stiililine !12_A	et	f	\N
160089	stiililiselt	"stiililine %stiili  )LINE_aA  <stiil ;22_S	et	f	\N
160090	stiililiselt	stiililiselt =stiililiselt  (ID  >stiililiselt !41_D	et	f	\N
160091	stiililiselt	"stiililiselt %stiili  )LISELT_mD  <stiil ;22_S	et	f	\N
160092	stiililiselt	"stiililiselt %stiililise  )LT_mD  <stiililine ;12_A	et	f	\N
159811	nimisõnalise	"nimi+sõnaline %sõna  )LINE_aA  <nimi+sõna ;17_S	et	f	\N
159821	öeldistäietena	?öeldistäietena =öeldistäie  (PlEs  >öeldistäie !01_S	et	f	\N
159822	täiedina	?täiedina =täiedi  (SgEs  >täiedi !01_S	et	f	\N
159823	täiedina	?täiedina =täiedi  (SgEs  >täied !02_S	et	f	\N
159824	täiedina	?täiedina =täiedina  (SgG  >täiedin !02_S	et	f	\N
159825	täiedina	?täiedina =dina  (SgN  >täie+dina !17_S	et	f	\N
159826	täiedina	?täiedina =dina  (SgG  >täie+dina !17_S	et	f	\N
159827	täiedina	?täiedina =dina  (SgP  >täie+dina !17_S	et	f	\N
159828	täiedina	?täiedina =edi  (SgEs  >täi+edi !17_S	et	f	\N
159829	täiedina	?täiedina =edina  (SgG  >täi+edin !02_S	et	f	\N
159830	plehku	?plehku =plehku  (ID  >plehku !41_D	et	f	\N
159831	plehku	?plehku =plehku  (IndPrPs_  >plehkuma !27_V	et	f	\N
159832	plehku	?plehku =plehku  (ImpPrSg2  >plehkuma !27_V	et	f	\N
159833	verbivorm	?verbivorm =verbivorm  (SgN  >verbivorm !22_S	et	f	\N
159848	intrasitiivne	?intrasitiivne =intrasitiivne  (SgN  >intrasitiivne !02_A	et	f	\N
159849	intrasitiivne	?intrasitiivne =intrasitiivne  (PlP  >intrasitiivn !22_S	et	f	\N
159875	leidmata	leidmata =leid  (SupAb  >leidma !34_V	et	f	\N
159876	leidmata	leidmata =leidmata  (ID  >leidmata !41_A	et	f	\N
159877	leidmata	"leidmata %leid  )MATA_vA  <leidma ;34_V	et	f	\N
159880	käändevorme	?käändevorme =käändevorme  (PlP  >käändevorm !22_S	et	f	\N
159881	käändevorme	?käändevorme =evorme  (PlP  >käänd+evorm !22_S	et	f	\N
159887	kasutamises	kasutamises =kasutamise  (SgIn  >kasutamine !12_S	et	f	\N
159888	kasutamises	"kasutamine %kasuta  )MINE_vS  <kasutama ;27_V	et	f	\N
159893	süntaktiliselt	süntaktiliselt =süntaktilise  (SgAbl  >süntaktiline !12_A	et	f	\N
159894	süntaktiliselt	süntaktiliselt =süntaktiliselt  (ID  >süntaktiliselt !41_D	et	f	\N
159895	süntaktiliselt	"süntaktiliselt %süntaktilise  )LT_mD  <süntaktiline ;12_A	et	f	\N
159901	infintiiviga	?infintiiviga =infintiivi  (SgKom  >infintiivi !16_S	et	f	\N
159902	infintiiviga	?infintiiviga =infintiivi  (SgKom  >infintiiv !22_S	et	f	\N
159909	tõlgitakse	tõlgitakse =tõlgi  (IndPrIps  >tõlkima !28_V	et	f	\N
159910	tõlgitakse	tõlgitakse =takse  (PlP  >tõlgi+taks !22_S	et	f	\N
159918	eslon	?eslon =eslon  (SgN  >eslon !02_S	et	f	\N
159922	modaalverbide	?modaalverbide =modaalverbi  (PlG  >modaalverb !22_S	et	f	\N
159935	suunitluse	suunitluse =suunitluse  (SgG  >suunitlus !11_S	et	f	\N
159936	suunitluse	"suunitlus %suunitle  )US_vS  <suunitlema ;27_V	et	f	\N
159951	vormist	vormist =vormi  (SgEl  >vorm !22_S	et	f	\N
159952	vormist	vormist =vormis  (SgP  >vormine !10_A	et	f	\N
159953	vormist	"vormine %vormi  )NE_aA  <vorm ;22_S	et	f	\N
159963	määrsõnast	?määrsõnast =määrsõnas  (SgP  >määrsõnane !12_A	et	f	\N
159972	väljendavate	väljendavate =väljendava  (PlG  >väljendav !02_A	et	f	\N
159973	väljendavate	"väljendav %väljenda  )V_vA  <väljendama ;27_V	et	f	\N
159981	lahknevused	lahknevused =lahknevuse  (PlN  >lahknevus !11_S	et	f	\N
159982	lahknevused	"lahknevus %lahkne  )VUS_aS  <lahknema ;27_V	et	f	\N
159983	lahknevused	"lahknevus %lahkneva  )US_aS  <lahknev ;02_A	et	f	\N
160006	sundisid	sundisid =sundi  (PlP  >sund !22_S	et	f	\N
160007	sundisid	sundisid =sundi  (IndIpfSg2  >sundima !28_V	et	f	\N
160008	sundisid	sundisid =sundi  (IndIpfPl3  >sundima !28_V	et	f	\N
160024	rabelda	rabelda =rabel  (Inf  >rabelema !31_V	et	f	\N
160025	rabelda	rabelda =rabel  (IndPrIps_  >rabelema !31_V	et	f	\N
160028	keeldu	keeldu =keeldu  (SgP  >keeld !22_S	et	f	\N
160029	keeldu	keeldu =keeldu  (SgAdt  >keeld !22_S	et	f	\N
160030	keeldu	keeldu =keeldu  (IndPrPs_  >keelduma !27_V	et	f	\N
160031	keeldu	keeldu =keeldu  (ImpPrSg2  >keelduma !27_V	et	f	\N
160035	kohustatus	kohustatus =kohustatu  (SgIn  >kohustatu !01_S	et	f	\N
160036	kohustatus	"kohustatu %kohusta  )TU1_vS  <kohustama ;27_V	et	f	\N
160037	kohustatus	kohustatus =kohustatus  (SgN  >kohustatus !11?09_S	et	f	\N
160038	kohustatus	"kohustatus %kohusta  )TUS1_aS  <kohustama ;27_V	et	f	\N
160039	erilistest	erilistest =erilis  (PlEl  >eriline !12_A	et	f	\N
160040	erilistest	"eriline %eri  )LINE_aA  <eri ;17_S	et	f	\N
160043	lõpust	lõpust =lõpu  (SgEl  >lõpp !22_SA	et	f	\N
160044	lõpust	lõpust =lõpus  (SgP  >lõpus !09_S	et	f	\N
160047	predikaatverbis	?predikaatverbis =predikaatverbi  (SgIn  >predikaatverp !22_S	et	f	\N
160048	predikaatverbis	?predikaatverbis =predikaatverbi  (IndIpfSg3  >predikaatverbima !28_V	et	f	\N
160049	predikaatverbis	?predikaatverbis =predikaatverbis  (SgN  >predikaatverbis !09_S	et	f	\N
160050	predikaatverbis	?predikaatverbis =dikaatverbi  (SgIn  >pre+dikaatverp !22_S	et	f	\N
160051	predikaatverbis	?predikaatverbis =dikaatverbis  (SgN  >pre+dikaatverbis !09_S	et	f	\N
160063	1985b	### 1985b	et	f	\N
160066	intensiivsuse	intensiivsuse =intensiivsuse  (SgG  >intensiivsus !11~09_S	et	f	\N
160067	intensiivsuse	"intensiivsus %intensiivse  )US_aS  <intensiivne ;02_A	et	f	\N
160080	kõnehetkeks	kõnehetkeks =hetke  (SgTr  >kõne+hetk !22_S	et	f	\N
160081	kõnehetkeks	kõnehetkeks =hetke  (PlTr  >kõne+hetk !22_S	et	f	\N
160082	kiledalt	kiledalt =kileda  (SgAbl  >kile !02_A	et	f	\N
160083	kiledalt	kiledalt =kiledalt  (ID  >kiledalt !41_D	et	f	\N
160084	kiledalt	"kiledalt %kileda  )LT_mD  <kile ;02_A	et	f	\N
159840	tegelikkusega	"tegelikkus %tegelikku  )US_aS  <tegelik ;25_A	et	f	\N
159845	aspekti	aspekti =aspekti  (SgG  >aspekt !22_S	et	f	\N
159846	aspekti	aspekti =aspekti  (SgP  >aspekt !22_S	et	f	\N
159847	aspekti	aspekti =aspekti  (SgAdt  >aspekt !22_S	et	f	\N
159850	tihedamini	tihedamini =tihedami  (SgTer  >tihedam !02_A	et	f	\N
159851	tihedamini	"tihedam %tiheda  )M_cA  <tihe ;02_A	et	f	\N
159852	tihedamini	tihedamini =mi  (SgTer  >tiheda+mi !26_S	et	f	\N
159853	tihedamini	tihedamini =mini  (SgN  >tiheda+mini !17~16_S	et	f	\N
159854	tihedamini	tihedamini =mini  (SgG  >tiheda+mini !17~16_S	et	f	\N
159855	tihedamini	tihedamini =mini  (SgP  >tiheda+mini !17_S	et	f	\N
159864	sügavamaid	sügavamaid =sügavama  (PlP  >sügavam !02_A	et	f	\N
159865	sügavamaid	"sügavam %süga  )VAM_cA  <sügama ;27_V	et	f	\N
159866	sügavamaid	"sügavam %sügava  )M_cA  <sügav ;02_A	et	f	\N
159867	sügavamaid	sügavamaid =ma  (PlP  >sügava+maa !26_S	et	f	\N
159868	sügavamaid	sügavamaid =mai  (PlN  >sügava+mai !26_S	et	f	\N
159869	sügavamaid	sügavamaid =mai  (SgP  >sügava+mai !26_S	et	f	\N
159873	kumba	kumba =kumba  (SgP  >kumb !22_P	et	f	\N
159874	kumba	kumba =kumba  (SgAdt  >kumb !22_P	et	f	\N
159896	sisaldava	sisaldava =sisaldava  (SgG  >sisaldav !02_A	et	f	\N
159897	sisaldava	"sisaldav %sisalda  )V_vA  <sisaldama ;27_V	et	f	\N
159905	küsimustes	küsimustes =küsimus  (PlIn  >küsimus !11_S	et	f	\N
159906	küsimustes	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
159907	küsimustes	küsimustes =muste  (PlIn  >küsi+must !22_AS	et	f	\N
159925	faasiverbidega	?faasiverbidega =faasiverbi  (PlKom  >faasiverb !22_S	et	f	\N
159926	aspektuaalne	?aspektuaalne =aspektuaalne  (SgN  >aspektuaalne !02_A	et	f	\N
159927	aspektuaalne	?aspektuaalne =aspektuaalne  (PlP  >aspektuaaln !22_S	et	f	\N
159933	väljendamiseks	väljendamiseks =väljendamise  (SgTr  >väljendamine !12_S	et	f	\N
159934	väljendamiseks	"väljendamine %väljenda  )MINE_vS  <väljendama ;27_V	et	f	\N
159950	sedasama	?sedasama =sedasama  (SgG  >sedasam !02_A	et	f	\N
159971	1991b	### 1991b	et	f	\N
159997	kohustust	kohustust =kohustus  (SgP  >kohustus !11_S	et	f	\N
159998	kohustust	"kohustus %kohusta  )US_vS  <kohustama ;27_V	et	f	\N
160009	valmistusid	valmistusid =valmistu  (IndIpfSg2  >valmistuma !27_V	et	f	\N
160010	valmistusid	valmistusid =valmistu  (IndIpfPl3  >valmistuma !27_V	et	f	\N
160032	soovitatavat	soovitatavat =soovita  (KvtPrIps  >soovitama !27_V	et	f	\N
160033	soovitatavat	soovitatavat =soovitatava  (SgP  >soovitatav !02_A	et	f	\N
160034	soovitatavat	"soovitatav %soovita  )TAV_vAS  <soovitama ;27_V	et	f	\N
160052	vahetundidel	vahetundidel =undi  (PlAd  >vahet+und !22_S	et	f	\N
160053	vahetundidel	vahetundidel =tundi  (PlAd  >vahe+tund !22_S	et	f	\N
160059	pihlaku	?pihlaku =pihla  (ImpPrPs  >pihlama !29_V	et	f	\N
160060	pihlaku	?pihlaku =pihlaku  (SgG  >pihlak !02_S	et	f	\N
160061	pihlaku	?pihlaku =pihlaku  (IndPrPs_  >pihlakuma !27_V	et	f	\N
160062	pihlaku	?pihlaku =pihlaku  (ImpPrSg2  >pihlakuma !27_V	et	f	\N
160068	njuanssi	?njuanssi =njuanssi  (ID  >njuanssi !41_D	et	f	\N
160069	njuanssi	?njuanssi =njuanssi  (SgG  >njuanss !22_S	et	f	\N
160070	njuanssi	?njuanssi =njuanssi  (SgP  >njuanss !22_S	et	f	\N
160071	njuanssi	?njuanssi =njuanssi  (SgAdt  >njuanss !22_S	et	f	\N
160072	njuanssi	?njuanssi =njuanssi  (IndPrPs_  >njuanssima !28_V	et	f	\N
160073	njuanssi	?njuanssi =njuanssi  (ImpPrSg2  >njuanssima !28_V	et	f	\N
160110	tuumverbideks	### tuumverbideks	et	f	\N
160138	kahelda	kahelda =kahel  (Inf  >kahtlema !30_V	et	f	\N
160139	kahelda	kahelda =kahel  (IndPrIps_  >kahtlema !30_V	et	f	\N
160144	mitteterviklikkusele	mitteterviklikkusele =terviklikkuse  (SgAll  >mitte+terviklikkus !11~09_S	et	f	\N
160145	mitteterviklikkusele	"mitte+terviklikkus %terviklikku  )US_aS  <mitte+terviklik ;25_A	et	f	\N
160151	korduvusele	korduvusele =korduvuse  (SgAll  >korduvus !11_S	et	f	\N
160152	korduvusele	"korduvus %kordu  )VUS_aS  <korduma ;27_V	et	f	\N
160153	korduvusele	"korduvus %korduva  )US_aS  <korduv ;02_A	et	f	\N
160154	korduvusele	korduvusele =use  (PlAll  >korduv+usk !22_S	et	f	\N
160157	piiritletusele	piiritletusele =piiritletuse  (SgAll  >piiritletus !11?09_S	et	f	\N
160158	piiritletusele	"piiritletus %piiritle  )TUS1_aS  <piiritlema ;27_V	et	f	\N
160165	prefiksaalsõnade	### prefiksaalsõnade	et	f	\N
160178	le-	### le-	et	f	\N
160182	puhkes	puhkes =puhke  (SgIn  >puhe !06_S	et	f	\N
160183	puhkes	puhkes =puhke  (IndIpfSg3  >puhkema !27_V	et	f	\N
160187	abimäärsõnast	?abimäärsõnast =abimäärsõnas  (SgP  >abimäärsõnane !12_A	et	f	\N
160188	abimäärsõnast	?abimäärsõnast =määrsõnas  (SgP  >abi+määrsõnane !12_A	et	f	\N
160196	vrd	### vrd	et	f	\N
160197	keelekeskuses	keelekeskuses =use  (PlIn  >keele+kesk+usk !22_S	et	f	\N
160198	keelekeskuses	keelekeskuses =keskuse  (SgIn  >keele+keskus !11~09_S	et	f	\N
160201	kõnelejatele	kõnelejatele =kõneleja  (PlAll  >kõneleja !01_S	et	f	\N
160202	kõnelejatele	"kõneleja %kõnele  )JA_vS  <kõnelema ;27_V	et	f	\N
160203	kõnelejatele	"kõneleja %kõnele  )JA_vS  <kõnelema ;31_V	et	f	\N
160211	korratakordama	?korratakordama =korratakorda  (Sup  >korratakordama !27_V	et	f	\N
160212	korratakordama	?korratakordama =korratakordama  (SgG  >korratakordam !02_A	et	f	\N
160019	suutlikkustvõimetust	?suutlikkustvõimetust =suutlikkustvõimetus  (SgP  >suutlikkustvõimetus !11?09_S	et	f	\N
160022	katsus	katsus =katsu  (SgIn  >kats !22_S	et	f	\N
160023	katsus	katsus =katsu  (IndIpfSg3  >katsuma !28_V	et	f	\N
160041	tähendusnjuanssidest	?tähendusnjuanssidest =tähendusnjuanssi  (PlEl  >tähendusnjuanss !22_S	et	f	\N
160042	tähendusnjuanssidest	?tähendusnjuanssidest =tähendusnjuanssides  (SgP  >tähendusnjuanssidene !12_A	et	f	\N
160045	tarvitse	tarvitse =tarvitse  (IndPrPs_  >tarvitsema !27_V	et	f	\N
160046	tarvitse	tarvitse =tarvitse  (ImpPrSg2  >tarvitsema !27_V	et	f	\N
160054	aspektuaalse	?aspektuaalse =aspektuaalse  (SgG  >aspektuaalne !02_A	et	f	\N
160055	aspektuaalse	?aspektuaalse =aspektuaalse  (PlP  >aspektuaals !22_S	et	f	\N
160064	esloni	?esloni =eslo  (SgTer  >eslo !16_S	et	f	\N
160065	esloni	?esloni =esloni  (SgG  >eslon !02_S	et	f	\N
160074	hõõgus	hõõgus =hõõgu  (SgIn  >hõõg !22_S	et	f	\N
160075	hõõgus	hõõgus =hõõgu  (IndIpfSg3  >hõõguma !27_V	et	f	\N
160076	hõõgus	hõõgus =hõõgus  (SgN  >hõõgus !11~09_S	et	f	\N
160111	morfoloogiliselt	morfoloogiliselt =morfoloogilise  (SgAbl  >morfoloogiline !12_A	et	f	\N
160112	morfoloogiliselt	"morfoloogiline %morfoloogi  )LINE_aA  <morfoloog ;22_S	et	f	\N
160113	morfoloogiliselt	morfoloogiliselt =morfoloogiliselt  (ID  >morfoloogiliselt !41_D	et	f	\N
160114	morfoloogiliselt	"morfoloogiliselt %morfoloogi  )LISELT_mD  <morfoloog ;22_S	et	f	\N
160115	morfoloogiliselt	"morfoloogiliselt %morfoloogilise  )LT_mD  <morfoloogiline ;12_A	et	f	\N
160116	põhisõnavara	põhisõnavara =vara  (SgN  >põhi+sõna+vara !17_S	et	f	\N
160117	põhisõnavara	põhisõnavara =vara  (SgG  >põhi+sõna+vara !17_S	et	f	\N
160118	põhisõnavara	põhisõnavara =vara  (SgP  >põhi+sõna+vara !17_S	et	f	\N
160120	kohustuslikkust	kohustuslikkust =kohustuslikkus  (SgP  >kohustuslikkus !11~09_S	et	f	\N
160121	kohustuslikkust	"kohustuslikkus %kohustuslikku  )US_aS  <kohustuslik ;25_A	et	f	\N
160122	modaalverbid	?modaalverbid =modaalverbi  (PlN  >modaalverp !22_S	et	f	\N
160123	modaalverbid	?modaalverbid =modaalverbi  (IndPrSg2  >modaalverpima !28_V	et	f	\N
160142	piiritlematusele	piiritlematusele =piiritlematuse  (SgAll  >piiritlematus !11?09_S	et	f	\N
160143	piiritlematusele	"piiritlematus %piiritle  )MATUS_aS  <piiritlema ;27_V	et	f	\N
160149	bondarenko	?bondarenko =bondarenko  (SgN  >bondarenko !16_S	et	f	\N
160150	bondarenko	?bondarenko =bondarenko  (SgG  >bondarenko !16_S	et	f	\N
160163	terviklikkusele	terviklikkusele =terviklikkuse  (SgAll  >terviklikkus !11~09_S	et	f	\N
160164	terviklikkusele	"terviklikkus %terviklikku  )US_aS  <terviklik ;25_A	et	f	\N
160166	eritüveliste	eritüveliste =tüvelis  (PlG  >eri+tüveline !12_A	et	f	\N
160167	eritüveliste	"eri+tüveline %tüve  )LINE_aA  <eri+tüvi ;20_S	et	f	\N
160169	aspektikategooria	?aspektikategooria =aspektikategooria  (SgN  >aspektikategooria !01_S	et	f	\N
160170	aspektikategooria	?aspektikategooria =aspektikategooria  (SgG  >aspektikategooria !01_S	et	f	\N
160175	ata-	ata- =ata  (ID  >ata !41_I	et	f	\N
160176	ata-	ata- =ata  (IndPrPs_  >atma !35_V	et	f	\N
160177	ata-	ata- =ata  (ImpPrSg2  >atma !35_V	et	f	\N
160190	tegusõnast	tegusõnast =sõna  (SgEl  >tegu+sõna !17_S	et	f	\N
160191	tegusõnast	tegusõnast =sõnas  (SgP  >tegu+sõnane !10_A	et	f	\N
160192	tegusõnast	"tegu+sõnane %sõna  )NE_aA  <tegu+sõna ;17_S	et	f	\N
160232	pealause	pealause =lause  (SgN  >pea+lause !06_S	et	f	\N
160233	pealause	pealause =lause  (SgG  >pea+lause !06_S	et	f	\N
160241	verbivormist	?verbivormist =verbivormi  (SgEl  >verbivorm !22_S	et	f	\N
160242	verbivormist	?verbivormist =verbivormis  (SgP  >verbivormis !09_S	et	f	\N
160243	verbivormist	?verbivormist =verbivormis  (SgP  >verbivormine !12_A	et	f	\N
160244	verbivormist	?verbivormist =verbivormist  (SgN  >verbivormist !22_S	et	f	\N
160272	käändevormi	?käändevormi =käändevormi  (SgG  >käändevorm !22_S	et	f	\N
160273	käändevormi	?käändevormi =käändevormi  (SgP  >käändevorm !22_S	et	f	\N
160274	käändevormi	?käändevormi =käändevormi  (SgAdt  >käändevorm !22_S	et	f	\N
160275	käändevormi	?käändevormi =käändevormi  (IndPrPs_  >käändevormima !28_V	et	f	\N
160276	käändevormi	?käändevormi =käändevormi  (ImpPrSg2  >käändevormima !28_V	et	f	\N
160277	käändevormi	?käändevormi =evormi  (SgN  >käänd+evormi !01_S	et	f	\N
160278	käändevormi	?käändevormi =evormi  (SgG  >käänd+evormi !01_S	et	f	\N
160279	käändevormi	?käändevormi =evormi  (SgG  >käänd+evorm !22_S	et	f	\N
160280	käändevormi	?käändevormi =evormi  (SgP  >käänd+evorm !22_S	et	f	\N
160281	käändevormi	?käändevormi =evormi  (SgAdt  >käänd+evorm !22_S	et	f	\N
160284	sagedusega	sagedusega =sageduse  (SgKom  >sagedus !11_S	et	f	\N
160285	sagedusega	"sagedus %sageda  )US_aS  <sage ;02_A	et	f	\N
160288	pedagoogikaülikool	pedagoogikaülikool =koo  (SgAd  >pedagoogika+üli+kubu !18_S	et	f	\N
160289	pedagoogikaülikool	pedagoogikaülikool =kool  (SgN  >pedagoogika+üli+kool !22_S	et	f	\N
160299	perifrastilised	?perifrastilised =perifrastilise  (PlN  >perifrastiline !12_A	et	f	\N
160380	keeleõppija	keeleõppija =õppija  (SgN  >keele+õppija !01_S	et	f	\N
160381	keeleõppija	keeleõppija =õppija  (SgG  >keele+õppija !01_S	et	f	\N
160384	sihtkeelde	sihtkeelde =keel  (SgAdt  >siht+keel !13_S	et	f	\N
160385	sihtkeelde	sihtkeelde =keelde  (PlP  >siht+keeld !22_S	et	f	\N
160394	väärisid	väärisid =vääri  (PlP  >väär !22_S	et	f	\N
160093	ekspressiivselt	ekspressiivselt =ekspressiivse  (SgAbl  >ekspressiivne !02_A	et	f	\N
160094	ekspressiivselt	ekspressiivselt =ekspressiivselt  (ID  >ekspressiivselt !41_D	et	f	\N
160095	ekspressiivselt	"ekspressiivselt %ekspressiivse  )LT_mD  <ekspressiivne ;02_A	et	f	\N
160101	semantikast	semantikast =semantika  (SgEl  >semantika !01_S	et	f	\N
160102	semantikast	semantikast =semantikas  (SgP  >semantikane !12_A	et	f	\N
160103	semantikast	"semantikane %semantika  )NE_aA  <semantika ;01_S	et	f	\N
160107	kasutatavaid	kasutatavaid =kasutatava  (PlP  >kasutatav !02_A	et	f	\N
160108	kasutatavaid	"kasutatav %kasuta  )TAV_vAS  <kasutama ;27_V	et	f	\N
160129	prepositsioonide	prepositsioonide =prepositsiooni  (PlG  >prepositsioon !22_S	et	f	\N
160130	prepositsioonide	prepositsioonide =positsiooni  (PlG  >pre+positsioon !22_S	et	f	\N
160131	jama	jama =jama  (SgN  >jama !17_S	et	f	\N
160132	jama	jama =jama  (SgG  >jama !17_S	et	f	\N
160133	jama	jama =jama  (SgP  >jama !17_S	et	f	\N
160134	jama	jama =jama  (IndPrPs_  >jamama !27_V	et	f	\N
160135	jama	jama =jama  (ImpPrSg2  >jamama !27_V	et	f	\N
160136	õmblejal	õmblejal =õmbleja  (SgAd  >õmbleja !01_S	et	f	\N
160137	õmblejal	"õmbleja %õmble  )JA_vS  <õmblema ;30_V	et	f	\N
160140	õpetamatusele	õpetamatusele =õpetamatuse  (SgAll  >õpetamatus !11?09_S	et	f	\N
160141	õpetamatusele	"õpetamatus %õpeta  )MATUS_aS  <õpetama ;27_V	et	f	\N
160146	kestvusele	kestvusele =kestvuse  (SgAll  >kestvus !11~09_S	et	f	\N
160147	kestvusele	"kestvus %kest  )VUS_aS  <kestma ;34_V	et	f	\N
160148	kestvusele	"kestvus %kestva  )US_aS  <kestev ;02_A	et	f	\N
160159	lõpetatusele	lõpetatusele =lõpetatuse  (SgAll  >lõpetatus !11?09_S	et	f	\N
160160	lõpetatusele	"lõpetatus %lõpeta  )TUS1_aS  <lõpetama ;27_V	et	f	\N
160161	ühekordsusele	ühekordsusele =kordsuse  (SgAll  >ühe+kordsus !11~09_S	et	f	\N
160162	ühekordsusele	"ühe+kordsus %kordse  )US_aS  <ühe+kordne ;02_AS	et	f	\N
160179	skle-	### skle-	et	f	\N
160185	muutvast	muutvast =muutva  (SgEl  >muutev !02_A	et	f	\N
160186	muutvast	"muutev %muut  )V_vA  <muutma ;34_V	et	f	\N
160195	1985a	### 1985a	et	f	\N
160208	liitumast	liitumast =liitu  (SupEl  >liituma !27_V	et	f	\N
160209	liitumast	liitumast =liituma  (SgEl  >liitum !02_A	et	f	\N
160210	liitumast	"liitum %lii  )TUM2_cA  <lii ;26_S	et	f	\N
160234	äite	?äite =äite  (SgN  >äite !06_S	et	f	\N
160235	äite	?äite =äite  (SgG  >äide !06_S	et	f	\N
160236	äite	?äite =äite  (PlP  >äit !22_S	et	f	\N
160237	äite	?äite =äite  (IndPrPs_  >äitema !27_V	et	f	\N
160238	äite	?äite =äite  (ImpPrSg2  >äitema !27_V	et	f	\N
160248	panev	panev =pane  (PtsPrPs  >panema !36_V	et	f	\N
160249	panev	panev =panev  (SgN  >panev !02_A	et	f	\N
160250	panev	"panev %pane  )V_vA  <panema ;36_V	et	f	\N
160254	õppijatele	õppijatele =õppija  (PlAll  >õppija !01_S	et	f	\N
160255	õppijatele	"õppija %õppi  )JA_vS  <õppima ;28_V	et	f	\N
160259	välismaalastele	välismaalastele =las  (PlAll  >välis+maa+laps !14_S	et	f	\N
160260	välismaalastele	välismaalastele =laste  (PlAll  >välis+maa+last !22_S	et	f	\N
160261	välismaalastele	välismaalastele =maalas  (PlAll  >välis+maalane !12?10_S	et	f	\N
160262	köiteta	köiteta =köi  (PlAb  >köis !14_S	et	f	\N
160263	köiteta	köiteta =köite  (SgAb  >köide !06_S	et	f	\N
160297	terminatiivsusest	terminatiivsusest =terminatiivsuse  (SgEl  >terminatiivsus !11~09_S	et	f	\N
160298	terminatiivsusest	"terminatiivsus %terminatiivse  )US_aS  <terminatiivne ;02_A	et	f	\N
160336	tegedes	?tegedes =tege  (PlIn  >tege !16_S	et	f	\N
160348	kuule	kuule =kuu  (SgAll  >kuu !26_S	et	f	\N
160349	kuule	kuule =kuule  (SgN  >kuule !05_S	et	f	\N
160350	kuule	kuule =kuule  (SgN  >kuule !06_S	et	f	\N
160351	kuule	kuule =kuule  (PlP  >kuul !22_S	et	f	\N
160352	kuule	kuule =kuule  (IndPrPs_  >kuulma !33_V	et	f	\N
160353	kuule	kuule =kuule  (ImpPrSg2  >kuulma !33_V	et	f	\N
160356	etendusele	etendusele =etenduse  (SgAll  >etendus !11_S	et	f	\N
160357	etendusele	"etendus %etenda  )US_vS  <etendama ;27_V	et	f	\N
160360	jooksta	?jooksta =jooksta  (SgN  >jooksta !01_S	et	f	\N
160361	jooksta	?jooksta =jooksta  (SgG  >jooksta !01_S	et	f	\N
160362	jooksta	?jooksta =jooksta  (IndPrPs_  >jookstama !29_V	et	f	\N
160363	jooksta	?jooksta =jooksta  (ImpPrSg2  >jookstama !29_V	et	f	\N
160372	põhipraktika	põhipraktika =praktika  (SgN  >põhi+praktika !01_S	et	f	\N
160373	põhipraktika	põhipraktika =praktika  (SgG  >põhi+praktika !01_S	et	f	\N
160382	moodusta	moodusta =moodusta  (IndPrPs_  >moodustama !27_V	et	f	\N
160383	moodusta	moodusta =moodusta  (ImpPrSg2  >moodustama !27_V	et	f	\N
160386	sihtkeeles	sihtkeeles =keele  (SgIn  >siht+keel !13_S	et	f	\N
160387	sihtkeeles	sihtkeeles =keele  (PlIn  >siht+keeld !22_S	et	f	\N
160434	osastava	osastava =osastava  (SgG  >osastav !02_A	et	f	\N
160435	osastava	"osastav %osasta  )V_vA  <osastama ;27_V	et	f	\N
160445	suhtetest	suhtetest =test  (SgN  >suhte+test !22_S	et	f	\N
160446	suhtetest	suhtetest =e  (PlEl  >suht+esi !15_S	et	f	\N
160462	romantiliseid	?romantiliseid =romantilisei  (PlN  >romantilisei !26_S	et	f	\N
160463	romantiliseid	?romantiliseid =romantilisei  (SgP  >romantilisei !26_S	et	f	\N
160486	verbirektsioon	?verbirektsioon =verbirektsioon  (SgN  >verbirektsioon !22_S	et	f	\N
160099	hinnangulisust	hinnangulisust =hinnangulisus  (SgP  >hinnangulisus !11?09_S	et	f	\N
160100	hinnangulisust	"hinnangulisus %hinnangu  )LISUS_aS  <hinnang ;02_S	et	f	\N
160119	modaalverbe	?modaalverbe =modaalverbe  (PlP  >modaalverb !22_S	et	f	\N
160168	häälikuvahelduse	?häälikuvahelduse =häälikuvahelduse  (SgG  >häälikuvaheldus !11_S	et	f	\N
160173	ahta-	ahta- =aht  (Inf  >ahtma !34_V	et	f	\N
160174	ahta-	ahta- =ahta  (SgG  >ahas !07_A	et	f	\N
160193	prefiksaalverbide	?prefiksaalverbide =prefiksaalverbi  (PlG  >prefiksaalverb !22_S	et	f	\N
160194	prefiksaalverbide	?prefiksaalverbide =fiksaalverbi  (PlG  >pre+fiksaalverb !22_S	et	f	\N
160199	sooritajat	sooritajat =sooritaja  (SgP  >sooritaja !01_S	et	f	\N
160200	sooritajat	"sooritaja %soorita  )JA_vS  <sooritama ;27_V	et	f	\N
160204	sügavaid	sügavaid =sügava  (PlP  >sügav !02_A	et	f	\N
160205	sügavaid	"sügav %süga  )V_vA  <sügama ;27_V	et	f	\N
160206	käändevorm	?käändevorm =käändevorm  (SgN  >käändevorm !22_S	et	f	\N
160207	käändevorm	?käändevorm =evorm  (SgN  >käänd+evorm !22_S	et	f	\N
160214	kordamast	kordamast =korda  (SupEl  >kordama !29_V	et	f	\N
160215	kordamast	kordamast =mast  (SgN  >korda+mast !22_S	et	f	\N
160216	vajagi	vajagi =vaja  (ID^  >vaja !41_D	et	f	\N
160217	vajagi	vajagi =vaja  (SgN^  >vaja !17_S	et	f	\N
160218	vajagi	vajagi =vaja  (SgG^  >vaja !17_S	et	f	\N
160219	vajagi	vajagi =vaja  (SgP^  >vaja !17_S	et	f	\N
160220	vajagi	vajagi =vaja  (IndPrPs_^  >vajama !27_V	et	f	\N
160221	vajagi	vajagi =vaja  (ImpPrSg2^  >vajama !27_V	et	f	\N
160264	tolla	?tolla =tolla  (SgN  >tolla !16_S	et	f	\N
160265	tolla	?tolla =tolla  (SgG  >tolla !16_S	et	f	\N
160266	tolla	?tolla =tolla  (IndPrPs_  >tollama !29_V	et	f	\N
160267	tolla	?tolla =tolla  (ImpPrSg2  >tollama !29_V	et	f	\N
160270	statistika	statistika =statistika  (SgN  >statistika !01_S	et	f	\N
160271	statistika	statistika =statistika  (SgG  >statistika !01_S	et	f	\N
160293	kursiivsusest	?kursiivsusest =kursiivsuse  (SgEl  >kursiivsus !11~09_S	et	f	\N
160294	kursiivsusest	?kursiivsusest =kursiivsuses  (SgP  >kursiivsusene !12_A	et	f	\N
160295	kursiivsusest	?kursiivsusest =ivsuse  (SgEl  >kursi+ivsus !11~09_S	et	f	\N
160296	kursiivsusest	?kursiivsusest =ivsuses  (SgP  >kursi+ivsusene !12_A	et	f	\N
160301	väljendajana	väljendajana =väljendaja  (SgEs  >väljendaja !01_S	et	f	\N
160302	väljendajana	"väljendaja %väljenda  )JA_vS  <väljendama ;27_V	et	f	\N
160311	kontrastiivsest	?kontrastiivsest =kontrastiivse  (SgEl  >kontrastiivne !02_A	et	f	\N
160312	kontrastiivsest	?kontrastiivsest =kontrastiivse  (PlEl  >kontrastiivs !22_S	et	f	\N
160313	kontrastiivsest	?kontrastiivsest =kontrastiivses  (SgP  >kontrastiivsene !12~10_A	et	f	\N
160314	kontrastiivsest	?kontrastiivsest =ivse  (SgEl  >kontrasti+ivne !02_A	et	f	\N
160315	kontrastiivsest	?kontrastiivsest =ivse  (SgEl  >kontrasti+ivse !06_S	et	f	\N
160316	kontrastiivsest	?kontrastiivsest =ivse  (PlEl  >kontrasti+ivs !22_S	et	f	\N
160317	kontrastiivsest	?kontrastiivsest =ivses  (SgP  >kontrasti+ivses !09_S	et	f	\N
160318	kontrastiivsest	?kontrastiivsest =ivses  (SgP  >kontrasti+ivsene !10_A	et	f	\N
160319	kontrastiivsest	?kontrastiivsest =iivse  (SgEl  >kontrast+iivne !02_A	et	f	\N
160320	kontrastiivsest	?kontrastiivsest =iivse  (SgEl  >kontrast+iivse !06_S	et	f	\N
160321	kontrastiivsest	?kontrastiivsest =iivse  (PlEl  >kontrast+iivs !22_S	et	f	\N
160322	kontrastiivsest	?kontrastiivsest =iivses  (SgP  >kontrast+iivses !09_S	et	f	\N
160323	kontrastiivsest	?kontrastiivsest =iivses  (SgP  >kontrast+iivsene !12~10_A	et	f	\N
160324	kontrastiivsest	?kontrastiivsest =stiivse  (SgEl  >kontra+stiivne !02_A	et	f	\N
160325	kontrastiivsest	?kontrastiivsest =stiivse  (SgEl  >kontra+stiivse !06_S	et	f	\N
160326	kontrastiivsest	?kontrastiivsest =stiivse  (PlEl  >kontra+stiivs !22_S	et	f	\N
160327	kontrastiivsest	?kontrastiivsest =stiivses  (SgP  >kontra+stiivses !09_S	et	f	\N
160328	kontrastiivsest	?kontrastiivsest =stiivses  (SgP  >kontra+stiivsene !12~10_A	et	f	\N
160329	kontrastiivsest	?kontrastiivsest =rastiivse  (SgEl  >kont+rastiivne !02_A	et	f	\N
160330	kontrastiivsest	?kontrastiivsest =rastiivse  (PlEl  >kont+rastiivs !22_S	et	f	\N
160331	kontrastiivsest	?kontrastiivsest =rastiivses  (SgP  >kont+rastiivsene !12~10_A	et	f	\N
160337	harjutust	harjutust =harjutu  (SgEl  >harjutu !01_AS	et	f	\N
160338	harjutust	"harjutu %harju  )TU1_vS  <harjuma ;27_V	et	f	\N
160339	harjutust	harjutust =harjutus  (SgP  >harjutus !11_S	et	f	\N
160340	harjutust	"harjutus %harjuta  )US_vS  <harjutama ;27_V	et	f	\N
160341	harjutust	"harjutus %harju  )TUS1_aS  <harjuma ;27_V	et	f	\N
160342	harjutust	harjutust =tust  (SgN  >harju+tust !22_S	et	f	\N
160347	miksida	?miksida =miksi  (Inf  >miksima !28_V	et	f	\N
160354	kaamera	kaamera =kaamera  (SgN  >kaamera !01_S	et	f	\N
160355	kaamera	kaamera =kaamera  (SgG  >kaamera !01_S	et	f	\N
160358	näitlejate	näitlejate =näitleja  (PlG  >näitleja !01_S	et	f	\N
160359	näitlejate	"näitleja %näitle  )JA_vS  <näitlema ;30_V	et	f	\N
160364	toetuse	toetuse =toetuse  (SgG  >toetus !11~09_S	et	f	\N
160365	toetuse	"toetus %toeta  )US_vS  <toetama ;27_V	et	f	\N
160366	toetuse	"toetus %toe  )TUS2_aS  <tugi ;21_S	et	f	\N
160391	ühildumisvead	?ühildumisvead =ühildumisvea  (PlN  >ühildumisvea !26_S	et	f	\N
160392	ühildumisvead	?ühildumisvead =ühildumisvea  (SgP  >ühildumisvea !26_S	et	f	\N
160126	mitmele	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
160127	põhjustamise	põhjustamise =põhjustamise  (SgG  >põhjustamine !12_S	et	f	\N
160128	põhjustamise	"põhjustamine %põhjusta  )MINE_vS  <põhjustama ;27_V	et	f	\N
160155	resultatiivsusele	resultatiivsusele =resultatiivsuse  (SgAll  >resultatiivsus !11~09_S	et	f	\N
160156	resultatiivsusele	"resultatiivsus %resultatiivse  )US_aS  <resultatiivne ;02_A	et	f	\N
160171	väljendverbid	?väljendverbid =väljendverbi  (PlN  >väljendverp !22_S	et	f	\N
160172	väljendverbid	?väljendverbid =väljendverbi  (IndPrSg2  >väljendverpima !28_V	et	f	\N
160180	alustamise	alustamise =alustamise  (SgG  >alustamine !12_S	et	f	\N
160181	alustamise	"alustamine %alusta  )MINE_vS  <alustama ;27_V	et	f	\N
160184	vaiss	?vaiss =vaiss  (SgN  >vaiss !22_S	et	f	\N
160189	väljendtegusõnad	### väljendtegusõnad	et	f	\N
160222	varahommikust	varahommikust =us  (SgP  >vara+hommik+uks !14_S	et	f	\N
160223	varahommikust	varahommikust =hommiku  (SgEl  >vara+hommik !02_S	et	f	\N
160224	varahommikust	varahommikust =hommikus  (SgP  >vara+hommikune !12_A	et	f	\N
160225	varahommikust	"vara+hommikune %hommiku  )NE_aA  <vara+hommik ;02_S	et	f	\N
160226	esinev	esinev =esine  (PtsPrPs  >esinema !27_V	et	f	\N
160227	esinev	esinev =esinev  (SgN  >esinev !02_A	et	f	\N
160228	esinev	"esinev %esine  )V_vA  <esinema ;27_V	et	f	\N
160229	kuulates	kuulates =kuula  (Ger  >kuulama !29_V	et	f	\N
160230	kuulates	kuulates =ate  (PlIn  >kuul+att !22_S	et	f	\N
160231	kuulates	kuulates =late  (PlIn  >kuu+latt !22_S	et	f	\N
160239	kõrvallause	kõrvallause =lause  (SgN  >kõrval+lause !06_S	et	f	\N
160240	kõrvallause	kõrvallause =lause  (SgG  >kõrval+lause !06_S	et	f	\N
160251	pühalikult	pühalikult =pühaliku  (SgAbl  >pühalik !25_A	et	f	\N
160252	pühalikult	pühalikult =pühalikult  (ID  >pühalikult !41_D	et	f	\N
160253	pühalikult	"pühalikult %pühaliku  )LT_mD  <pühalik ;25_A	et	f	\N
160256	omandamata	omandamata =omanda  (SupAb  >omandama !27_V	et	f	\N
160257	omandamata	omandamata =omandamata  (ID  >omandamata !41_A	et	f	\N
160258	omandamata	"omandamata %omanda  )MATA_vA  <omandama ;27_V	et	f	\N
160268	riskides	riskides =riski  (PlIn  >risk !22_S	et	f	\N
160269	riskides	riskides =riski  (Ger  >riskima !28_V	et	f	\N
160303	võõrkeelest	võõrkeelest =keele  (SgEl  >võõr+keel !13_S	et	f	\N
160304	võõrkeelest	võõrkeelest =keele  (PlEl  >võõr+keeld !22_S	et	f	\N
160305	võõrkeelest	võõrkeelest =keeles  (SgP  >võõr+keelene !10_A	et	f	\N
160306	võõrkeelest	"võõr+keelene %keele  )NE_aA  <võõr+keel ;13_S	et	f	\N
160307	vahekeelest	vahekeelest =keele  (SgEl  >vahe+keel !13_S	et	f	\N
160308	vahekeelest	vahekeelest =keele  (PlEl  >vahe+keeld !22_S	et	f	\N
160309	vahekeelest	vahekeelest =keeles  (SgP  >vahe+keelene !10_A	et	f	\N
160310	vahekeelest	"vahe+keelene %keele  )NE_aA  <vahe+keel ;13_S	et	f	\N
160343	loodusse	loodusse =loodu  (SgIll  >loodu !01_S	et	f	\N
160344	loodusse	"loodu %loo  )TU1_vS  <looma ;38_V	et	f	\N
160345	loodusse	loodusse =loodus  (SgAdt  >loodus !11_S	et	f	\N
160346	loodusse	"loodus %loo  )TUS1_aS  <looma ;38_V	et	f	\N
160369	ev-51	### ev-51	et	f	\N
160374	paktiliselt	paktiliselt =paktilise  (SgAbl  >paktiline !12_A	et	f	\N
160375	paktiliselt	"paktiline %pakti  )LINE_aA  <pakt ;22_S	et	f	\N
160376	paktiliselt	paktiliselt =paktiliselt  (ID  >paktiliselt !41_D	et	f	\N
160377	paktiliselt	"paktiliselt %pakti  )LISELT_mD  <pakt ;22_S	et	f	\N
160378	rühmitamisel	rühmitamisel =rühmitamise  (SgAd  >rühmitamine !12_S	et	f	\N
160379	rühmitamisel	"rühmitamine %rühmita  )MINE_vS  <rühmitama ;27_V	et	f	\N
160409	astmevaheldusele	?astmevaheldusele =astmevahelduse  (SgAll  >astmevaheldus !11_S	et	f	\N
160413	kasutamisel	kasutamisel =kasutamise  (SgAd  >kasutamine !12_S	et	f	\N
160414	kasutamisel	"kasutamine %kasuta  )MINE_vS  <kasutama ;27_V	et	f	\N
160423	käändevead	?käändevead =käändevea  (PlN  >käändevea !26_S	et	f	\N
160424	käändevead	?käändevead =käändevea  (SgP  >käändevea !26_S	et	f	\N
160425	käändevead	?käändevead =käändevead  (SgN  >käändevead !22_S	et	f	\N
160426	käändevead	?käändevead =evea  (PlN  >käänd+evea !26_S	et	f	\N
160427	käändevead	?käändevead =evea  (SgP  >käänd+evea !26_S	et	f	\N
160428	käändevead	?käändevead =evead  (SgN  >käänd+evead !22_S	et	f	\N
160432	eelda	eelda =eelda  (IndPrPs_  >eeldama !27_V	et	f	\N
160433	eelda	eelda =eelda  (ImpPrSg2  >eeldama !27_V	et	f	\N
160450	omastavast	omastavast =omastava  (SgEl  >omastav !02_A	et	f	\N
160451	omastavast	"omastav %omasta  )V_vA  <omastama ;27_V	et	f	\N
160494	arvamis	?arvamis =arvami  (SgIn  >arvami !01_S	et	f	\N
160495	arvamis	?arvamis =arvami  (SgIn  >arvam !02_A	et	f	\N
160496	arvamis	?arvamis =arvamis  (SgN  >arvamis !11_S	et	f	\N
160497	arvamis	?arvamis =ami  (SgIn  >arv+ami !17_S	et	f	\N
160498	arvamis	?arvamis =amis  (SgN  >arv+amis !09_S	et	f	\N
160502	abielutud	abielutud =elutu  (PlN  >abi+elutu !01_A	et	f	\N
160503	abielutud	"abi+elutu %elu  )TU2_kA  <abi+elu ;17_S	et	f	\N
160508	rahulolu	rahulolu =olu  (SgN  >rahul+olu !17_S	et	f	\N
160509	rahulolu	rahulolu =olu  (SgG  >rahul+olu !17_S	et	f	\N
160510	rahulolu	rahulolu =olu  (SgP  >rahul+olu !17_S	et	f	\N
160521	pelakirjad	?pelakirjad =pelakirja  (PlN  >pelakirjas !02_A	et	f	\N
160213	korratakordama	?korratakordama =takordama  (SgG  >korra+takordam !02_A	et	f	\N
160245	lekseemi	lekseemi =lekseemi  (SgG  >lekseem !22_S	et	f	\N
160246	lekseemi	lekseemi =lekseemi  (SgP  >lekseem !22_S	et	f	\N
160247	lekseemi	lekseemi =lekseemi  (SgAdt  >lekseem !22_S	et	f	\N
160282	tabelitest	tabelitest =tabeli  (PlEl  >tabel !02_S	et	f	\N
160283	tabelitest	tabelitest =test  (SgN  >tabeli+test !22_S	et	f	\N
160286	põhiarvust	põhiarvust =us  (SgP  >põhi+arv+uks !14_S	et	f	\N
160287	põhiarvust	põhiarvust =arvu  (SgEl  >põhi+arv !22_S	et	f	\N
160290	pedagoogikainstitut	?pedagoogikainstitut =pedagoogikainstitu  (SgP  >pedagoogikainstitu !01_A	et	f	\N
160291	pedagoogikainstitut	?pedagoogikainstitut =institu  (SgP  >pedagoogika+institu !01_AS	et	f	\N
160292	pedagoogikainstitut	?pedagoogikainstitut =kainstitu  (SgP  >pedagoogi+kainstitu !01_AS	et	f	\N
160300	aspektitähenduse	?aspektitähenduse =aspektitähenduse  (SgG  >aspektitähendus !11_S	et	f	\N
160332	kõnelejate	kõnelejate =kõneleja  (PlG  >kõneleja !01_S	et	f	\N
160333	kõnelejate	"kõneleja %kõnele  )JA_vS  <kõnelema ;27_V	et	f	\N
160334	kõnelejate	"kõneleja %kõnele  )JA_vS  <kõnelema ;31_V	et	f	\N
160335	flmi	### flmi	et	f	\N
160367	veaanalüüs	?veaanalüüs =veaanalüü  (SgIn  >veaanalüü !26_S	et	f	\N
160368	veaanalüüs	?veaanalüüs =veaanalüüs  (SgN  >veaanalüüs !22_S	et	f	\N
160370	arvestustöö	arvestustöö =töö  (SgN  >arvestus+töö !26_S	et	f	\N
160371	arvestustöö	arvestustöö =töö  (SgG  >arvestus+töö !26_S	et	f	\N
160388	rektsioonivead	?rektsioonivead =rektsioonivea  (PlN  >rektsioonivea !26_S	et	f	\N
160389	rektsioonivead	?rektsioonivead =rektsioonivea  (SgP  >rektsioonivea !26_S	et	f	\N
160390	rektsioonivead	?rektsioonivead =rektsioonivead  (SgN  >rektsioonivead !22_S	et	f	\N
160405	kokka	kokka =kokka  (SgP  >kokk !22_S	et	f	\N
160406	kokka	kokka =kokka  (SgAdt  >kokk !22_S	et	f	\N
160431	ostakse	?ostakse =ostakse  (SgG  >ostakne !02_A	et	f	\N
160456	moodustamisel	moodustamisel =moodustamise  (SgAd  >moodustamine !12_S	et	f	\N
160457	moodustamisel	"moodustamine %moodusta  )MINE_vS  <moodustama ;27_V	et	f	\N
160467	moodustusvead	?moodustusvead =moodustusvea  (PlN  >moodustusvea !26_S	et	f	\N
160468	moodustusvead	?moodustusvead =moodustusvea  (SgP  >moodustusvea !26_S	et	f	\N
160469	moodustusvead	?moodustusvead =moodustusvead  (SgN  >moodustusvead !22_S	et	f	\N
160471	võida	võida =või  (Inf  >võima !37_V	et	f	\N
160472	võida	võida =või  (IndPrIps_  >võima !37_V	et	f	\N
160473	võida	võida =võid  (Inf  >võidma !34_V	et	f	\N
160474	võida	võida =võida  (IndPrPs_  >võitma !34_V	et	f	\N
160475	võida	võida =võida  (ImpPrSg2  >võitma !34_V	et	f	\N
160479	aetud	aetud =ae  (PtsPtIps  >ajama !27_V	et	f	\N
160480	aetud	aetud =aetu  (PlN  >aetu !01_S	et	f	\N
160481	aetud	"aetu %ae  )TU1_vS  <ajama ;27_V	et	f	\N
160482	aetud	"aetud %ae  )TUD_vA  <ajama ;27_V	et	f	\N
160487	tundmatus	tundmatus =tundmatu  (SgIn  >tundmatu !01_AS	et	f	\N
160488	tundmatus	"tundmatu %tund  )MATU_vA  <tundma ;34_V	et	f	\N
160489	tundmatus	tundmatus =tundmatus  (SgN  >tundmatus !11_S	et	f	\N
160490	tundmatus	"tundmatus %tund  )MATUS_aS  <tundma ;34_V	et	f	\N
160518	juhtivad	juhtivad =juhtiva  (PlN  >juhtiv !02_A	et	f	\N
160519	juhtivad	"juhtiv %juhti  )V_vA  <juhtima ;28_V	et	f	\N
160520	juhtivad	juhtivad =iva  (PlN  >juht+iva !17_S	et	f	\N
160536	pelkirjad	?pelkirjad =pelkirja  (PlN  >pelkirjas !02_A	et	f	\N
160537	pelkirjad	?pelkirjad =pelkirja  (PlN  >pelkirja !16_S	et	f	\N
160571	lühemaks	lühemaks =lühema  (SgTr  >lühem !02_A	et	f	\N
160572	lühemaks	"lühem %lühe  )M_cA  <lühike ;12_A	et	f	\N
160585	antiikvakiri	?antiikvakiri =antiikvakiri  (SgG  >antiikvakir !19_S	et	f	\N
160587	antiikvakiri	?antiikvakiri =antiikvakiri  (SgP  >antiikvakir !19_S	et	f	\N
160588	antiikvakiri	?antiikvakiri =antiikvakiri  (SgAdt  >antiikvakir !19_S	et	f	\N
160589	antiikvakiri	?antiikvakiri =vakiri  (SgN  >antiik+vakiri !01_S	et	f	\N
160590	antiikvakiri	?antiikvakiri =vakiri  (SgG  >antiik+vakiri !01_S	et	f	\N
160591	antiikvakiri	?antiikvakiri =vakiri  (SgG  >antiik+vakir !02_S	et	f	\N
160607	formaalsema	formaalsema =formaalsema  (SgG  >formaalsem !02_A	et	f	\N
160608	formaalsema	"formaalsem %formaalse  )M_cA  <formaalne ;02_A	et	f	\N
160617	plokk-kirjas	plokk-kirjas =kirja  (SgIn  >plokk-kiri !24_S	et	f	\N
160618	plokk-kirjas	plokk-kirjas =kirja  (IndIpfSg3  >plokk-kirjama !29_V	et	f	\N
160650	liigendamine	liigendamine =liigendamine  (SgN  >liigendamine !12_S	et	f	\N
160651	liigendamine	"liigendamine %liigenda  )MINE_vS  <liigendama ;27_V	et	f	\N
160655	akustika	akustika =akustika  (SgN  >akustika !01_S	et	f	\N
160656	akustika	akustika =akustika  (SgG  >akustika !01_S	et	f	\N
160664	lõigud	lõigud =lõigu  (PlN  >lõik !22_S	et	f	\N
160665	lõigud	lõigud =lõigu  (IndPrSg2  >lõikuma !28_V	et	f	\N
160671	laiemas	laiemas =laiema  (SgIn  >laiem !02_A	et	f	\N
160672	laiemas	"laiem %laie  )M_cA  <lai ;22_A	et	f	\N
160673	laiemas	laiemas =ema  (SgIn  >lai+ema !17_S	et	f	\N
160685	põhiteksti	põhiteksti =teksti  (SgG  >põhi+tekst !22_S	et	f	\N
160686	põhiteksti	põhiteksti =teksti  (SgP  >põhi+tekst !22_S	et	f	\N
160687	põhiteksti	põhiteksti =teksti  (SgAdt  >põhi+tekst !22_S	et	f	\N
160692	veeru	veeru =veeru  (SgG  >veerg !22_S	et	f	\N
160393	ühildumisvead	?ühildumisvead =ühildumisvead  (SgN  >ühildumisvead !22_S	et	f	\N
160398	ühildumisvigu	?ühildumisvigu =ühildumisvi  (ImpPrPs  >ühildumisvima !28_V	et	f	\N
160399	ühildumisvigu	?ühildumisvigu =ühildumisvigu  (IndPrPs_  >ühildumisviguma !27_V	et	f	\N
160400	ühildumisvigu	?ühildumisvigu =ühildumisvigu  (ImpPrSg2  >ühildumisviguma !27_V	et	f	\N
160401	saastad	saastad =saasta  (PlN  >saast !22_S	et	f	\N
160402	saastad	saastad =saasta  (IndPrSg2  >saastama !29~27_V	et	f	\N
160407	alluvad	alluvad =allu  (IndPrPl3  >alluma !27_V	et	f	\N
160408	alluvad	alluvad =alluva  (PlN  >alluv !02_AS	et	f	\N
160410	alluvad	"alluv %allu  )V_vA  <alluma ;27_V	et	f	\N
160429	tervele	tervele =terve  (SgAll  >terve !01_AS	et	f	\N
160430	tervele	tervele =terve  (SgAll  >terve !06_AS	et	f	\N
160436	vormimoodustusvead	?vormimoodustusvead =vormimoodustusvea  (PlN  >vormimoodustusvea !26_S	et	f	\N
160437	vormimoodustusvead	?vormimoodustusvead =vormimoodustusvea  (SgP  >vormimoodustusvea !26_S	et	f	\N
160438	vormimoodustusvead	?vormimoodustusvead =vormimoodustusvead  (SgN  >vormimoodustusvead !22_S	et	f	\N
160439	vormimoodustusvead	?vormimoodustusvead =moodustusvea  (PlN  >vormi+moodustusvea !26_S	et	f	\N
160440	vormimoodustusvead	?vormimoodustusvead =moodustusvea  (SgP  >vormi+moodustusvea !26_S	et	f	\N
160441	vormimoodustusvead	?vormimoodustusvead =moodustusvead  (SgN  >vormi+moodustusvead !22_S	et	f	\N
160442	vormimoodustusvead	?vormimoodustusvead =imoodustusvea  (PlN  >vorm+imoodustusvea !26_S	et	f	\N
160443	vormimoodustusvead	?vormimoodustusvead =imoodustusvea  (SgP  >vorm+imoodustusvea !26_S	et	f	\N
160444	vormimoodustusvead	?vormimoodustusvead =imoodustusvead  (SgN  >vorm+imoodustusvead !22_S	et	f	\N
160447	omastav	omastav =omasta  (PtsPrPs  >omastama !27_V	et	f	\N
160448	omastav	omastav =omastav  (SgN  >omastav !02_A	et	f	\N
160449	omastav	"omastav %omasta  )V_vA  <omastama ;27_V	et	f	\N
160452	rahakottisse	?rahakottisse =rahakottisse  (SgG  >rahakottisne !02_A	et	f	\N
160453	rahakottisse	?rahakottisse =rahakottisse  (PlP  >rahakottiss !22_S	et	f	\N
160454	rahakottisse	?rahakottisse =kottisse  (SgG  >raha+kottisne !02_A	et	f	\N
160455	rahakottisse	?rahakottisse =kottisse  (PlP  >raha+kottiss !22_S	et	f	\N
160476	lotereejas	?lotereejas =lotereeja  (SgIn  >lotereejas !02_A	et	f	\N
160477	lotereejas	?lotereejas =lotereeja  (SgIn  >lotereeja !16_S	et	f	\N
160478	lotereejas	?lotereejas =lotereejas  (SgN  >lotereejas !02_A	et	f	\N
160483	korvpalli	korvpalli =palli  (SgG  >korv+pall !22_S	et	f	\N
160484	korvpalli	korvpalli =palli  (SgP  >korv+pall !22_S	et	f	\N
160485	korvpalli	korvpalli =palli  (SgAdt  >korv+pall !22_S	et	f	\N
160491	verbirektsioonid	?verbirektsioonid =verbirektsiooni  (PlN  >verbirektsiooni !16_S	et	f	\N
160492	verbirektsioonid	?verbirektsioonid =verbirektsiooni  (PlN  >verbirektsioon !22_S	et	f	\N
160493	verbirektsioonid	?verbirektsioonid =verbirektsiooni  (IndPrSg2  >verbirektsioonima !28_V	et	f	\N
160504	omadussõna	omadussõna =sõna  (SgN  >omadus+sõna !17_S	et	f	\N
160505	omadussõna	omadussõna =sõna  (SgG  >omadus+sõna !17_S	et	f	\N
160506	omadussõna	omadussõna =sõna  (SgP  >omadus+sõna !17_S	et	f	\N
160538	raskemini	raskemini =raskemi  (SgTer  >raskem !02_A	et	f	\N
160539	raskemini	"raskem %raske  )M_cA  <raske ;01_A	et	f	\N
160540	raskemini	raskemini =mi  (SgTer  >raske+mi !26_S	et	f	\N
160541	raskemini	raskemini =mini  (SgN  >raske+mini !17~16_S	et	f	\N
160542	raskemini	raskemini =mini  (SgG  >raske+mini !17~16_S	et	f	\N
160543	raskemini	raskemini =mini  (SgP  >raske+mini !17_S	et	f	\N
160553	ülipikk	ülipikk =pikk  (SgN  >üli+pikk !22_S	et	f	\N
160554	ülipikk	ülipikk =pikk  (SgN  >üli+pikk !22_AS	et	f	\N
160563	peakse	?peakse =peakse  (SgN  >peakse !06_S	et	f	\N
160564	peakse	?peakse =peakse  (SgG  >peakne !02_A	et	f	\N
160565	peakse	?peakse =peakse  (SgG  >peakse !06_S	et	f	\N
160566	peakse	?peakse =peakse  (PlP  >peaks !22_S	et	f	\N
160567	peakse	?peakse =peakse  (IndPrPs_  >peaksema !27_V	et	f	\N
160568	peakse	?peakse =peakse  (ImpPrSg2  >peaksema !27_V	et	f	\N
160605	isikupärasust	isikupärasust =pärasus  (SgP  >isiku+pärasus !11_S	et	f	\N
160606	isikupärasust	"isiku+pärasus %pära  )SUS_aS  <isiku+pära ;17_S	et	f	\N
160609	eristamine	eristamine =eristamine  (SgN  >eristamine !12_S	et	f	\N
160610	eristamine	"eristamine %erista  )MINE_vS  <eristama ;27_V	et	f	\N
160616	kiriga	### kiriga	et	f	\N
160621	tõsisemate	tõsisemate =tõsisema  (PlG  >tõsisem !02_A	et	f	\N
160622	tõsisemate	"tõsisem %tõsise  )M_cA  <tõsine ;10_A	et	f	\N
160636	sundimatu	sundimatu =sundimatu  (SgN  >sundimatu !01_A	et	f	\N
160637	sundimatu	"sundimatu %sundi  )MATU_vA  <sundima ;28_V	et	f	\N
160638	sundimatu	sundimatu =sundimatu  (SgG  >sundimatu !01_A	et	f	\N
160639	sundimatu	sundimatu =imatu  (SgN  >sund+imatu !01_A	et	f	\N
160640	sundimatu	"sund+imatu %ima  )TU2_kA  <sund+ima ;17_S	et	f	\N
160641	sundimatu	sundimatu =imatu  (SgG  >sund+imatu !01_A	et	f	\N
160652	pikaveerulised	pikaveerulised =veerulise  (PlN  >pika+veeruline !12_A	et	f	\N
160653	pikaveerulised	"pika+veeruline %veeru  )LINE_aA  <pika+veerg ;22_S	et	f	\N
160654	pikaveerulised	"pika+veeruline %veeru  )LINE_aA  <pika+veer ;22_S	et	f	\N
160657	modernseimale	modernseimale =modernseima  (SgAll  >modernseim !02_A	et	f	\N
160658	modernseimale	"modernseim %modernse  )IM_sA  <modernne ;02_A	et	f	\N
160395	väärisid	väärisid =vääri  (PlP  >väär !22_A	et	f	\N
160396	väärisid	väärisid =vääri  (IndIpfSg2  >väärima !28_V	et	f	\N
160397	väärisid	väärisid =vääri  (IndIpfPl3  >väärima !28_V	et	f	\N
160403	astmevaheldus	?astmevaheldus =astmevaheldu  (IndIpfSg3  >astmevahelduma !27_V	et	f	\N
160404	astmevaheldus	?astmevaheldus =astmevaheldus  (SgN  >astmevaheldus !11_S	et	f	\N
160411	omastava	omastava =omastava  (SgG  >omastav !02_A	et	f	\N
160412	omastava	"omastav %omasta  )V_vA  <omastama ;27_V	et	f	\N
160415	nevski	?nevski =nevski  (SgN  >nevski !01_S	et	f	\N
160416	nevski	?nevski =nevski  (SgG  >nevski !01_S	et	f	\N
160417	nevski	?nevski =nevski  (SgG  >nevsk !22_S	et	f	\N
160418	nevski	?nevski =nevski  (SgP  >nevsk !22_S	et	f	\N
160419	nevski	?nevski =nevski  (SgAdt  >nevsk !22_S	et	f	\N
160420	nevski	?nevski =nevski  (IndPrPs_  >nevskima !28_V	et	f	\N
160421	nevski	?nevski =nevski  (ImpPrSg2  >nevskima !28_V	et	f	\N
160422	nevski	?nevski =nevs  (SgN^  >nevs !22_S	et	f	\N
160458	asjaid	?asjaid =asja  (PlP  >asjas !02_A	et	f	\N
160459	asjaid	?asjaid =asjai  (PlN  >asjai !26_S	et	f	\N
160460	asjaid	?asjaid =asjai  (SgP  >asjai !26_S	et	f	\N
160461	asjaid	?asjaid =asjaid  (SgN  >asjaid !22_S	et	f	\N
160464	filmesid	?filmesid =filme  (IndIpfSg2  >filmema !27_V	et	f	\N
160465	filmesid	?filmesid =filme  (IndIpfPl3  >filmema !27_V	et	f	\N
160466	verbivormide	?verbivormide =verbivormi  (PlG  >verbivorm !22_S	et	f	\N
160470	läksida	?läksida =läksi  (Inf  >läksima !28_V	et	f	\N
160507	pakup	?pakup =pakup  (SgN  >pakup !02_S	et	f	\N
160514	kujundusest	kujundusest =kujunduse  (SgEl  >kujundus !11_S	et	f	\N
160515	kujundusest	"kujundus %kujunda  )US_vS  <kujundama ;27_V	et	f	\N
160516	kujundusest	kujundusest =kujunduses  (SgP  >kujundusene !12_A	et	f	\N
160517	kujundusest	"kujundusene %kujunduse  )NE_aA  <kujundus ;11_S	et	f	\N
160551	moonilahus	moonilahus =lahu  (SgIn  >mooni+lahk !22_S	et	f	\N
160552	moonilahus	moonilahus =lahus  (SgN  >mooni+lahus !09_S	et	f	\N
160586	baskerville	?baskerville =baskerville  (PlP  >baskervill !22_S	et	f	\N
160592	väljendusrikkad	?väljendusrikkad =väljendusrikka  (PlN  >väljendusrikka !16_S	et	f	\N
160593	väljendusrikkad	?väljendusrikkad =rikka  (PlN  >väljendus+rikas !07_A	et	f	\N
160598	antiikva	antiikva =antiikva  (SgN  >antiikva !16_S	et	f	\N
160599	antiikva	antiikva =antiikva  (SgG  >antiikva !16_S	et	f	\N
160600	teataja	teataja =teataja  (SgN  >teataja !01_S	et	f	\N
160601	teataja	"teataja %teata  )JA_vS  <teatama ;27_V	et	f	\N
160602	teataja	teataja =teataja  (SgG  >teataja !01_S	et	f	\N
160623	kriminaalkroonika	kriminaalkroonika =kroonika  (SgN  >kriminaal+kroonika !01_S	et	f	\N
160624	kriminaalkroonika	kriminaalkroonika =kroonika  (SgG  >kriminaal+kroonika !01_S	et	f	\N
160627	plokk-kirjad	plokk-kirjad =kirja  (PlN  >plokk-kiri !24_S	et	f	\N
160628	plokk-kirjad	plokk-kirjad =kirja  (IndPrSg2  >plokk-kirjama !29_V	et	f	\N
160629	paigutamine	paigutamine =paigutamine  (SgN  >paigutamine !12_S	et	f	\N
160630	paigutamine	"paigutamine %paiguta  )MINE_vS  <paigutama ;27_V	et	f	\N
160642	pikkusega	pikkusega =pikkuse  (SgKom  >pikkus !11~09_S	et	f	\N
160643	pikkusega	"pikkus %pikk  )US_aS  <pikk ;22_AS	et	f	\N
160644	pikkusega	pikkusega =pikkuse  (SgKom  >pikkune !12~10_A	et	f	\N
160667	pikkuse	pikkuse =pikkuse  (SgG  >pikkus !11~09_S	et	f	\N
160668	pikkuse	"pikkus %pikk  )US_aS  <pikk ;22_AS	et	f	\N
160669	pikkuse	pikkuse =pikkuse  (SgG  >pikkune !12~10_A	et	f	\N
160670	artiikel	?artiikel =artiikel  (SgN  >artiikel !02_S	et	f	\N
160674	veergus	?veergus =veergu  (SgIn  >veergu !01_S	et	f	\N
160675	veergus	?veergus =veergu  (IndIpfSg3  >veerguma !27_V	et	f	\N
160676	veergus	?veergus =veergus  (SgN  >veergus !11~09_S	et	f	\N
160697	teatajas	teatajas =teataja  (SgIn  >teataja !01_S	et	f	\N
160698	teatajas	"teataja %teata  )JA_vS  <teatama ;27_V	et	f	\N
160721	põhireksi	?põhireksi =põhireksi  (IndPrPs_  >põhireksima !28_V	et	f	\N
160722	põhireksi	?põhireksi =põhireksi  (ImpPrSg2  >põhireksima !28_V	et	f	\N
160723	põhireksi	?põhireksi =reksi  (SgN  >põhi+reksi !16_S	et	f	\N
160724	põhireksi	?põhireksi =reksi  (SgG  >põhi+reksi !16_S	et	f	\N
160725	põhireksi	?põhireksi =reksi  (SgG  >põhi+reks !22_S	et	f	\N
160726	põhireksi	?põhireksi =reksi  (SgP  >põhi+reks !22_S	et	f	\N
160727	põhireksi	?põhireksi =reksi  (SgAdt  >põhi+reks !22_S	et	f	\N
160737	kasutus	kasutus =kasutu  (SgIn  >kasutu !01_A	et	f	\N
160738	kasutus	"kasutu %kasu  )TU2_kA  <kasu ;17_S	et	f	\N
160739	kasutus	kasutus =kasutus  (SgN  >kasutus !11_S	et	f	\N
160740	kasutus	"kasutus %kasuta  )US_vS  <kasutama ;27_V	et	f	\N
160741	kasutus	"kasutus %kasu  )TUS2_aS  <kasu ;17_S	et	f	\N
160761	terviklikku	terviklikku =terviklikku  (SgP  >terviklik !25_A	et	f	\N
160762	terviklikku	terviklikku =terviklikku  (SgAdt  >terviklik !25_A	et	f	\N
160771	veergu	veergu =veergu  (SgP  >veerg !22_S	et	f	\N
160772	veergu	veergu =veergu  (SgAdt  >veerg !22_S	et	f	\N
160779	märgatavad	märgatavad =märgatava  (PlN  >märgatav !02_A	et	f	\N
160780	märgatavad	"märgatav %märga  )TAV_vAS  <märkama ;29_V	et	f	\N
160787	kristel	?kristel =kriste  (SgAd  >kriste !06_S	et	f	\N
160789	kristel	?kristel =kriste  (PlAd  >krist !22_S	et	f	\N
160499	arvamine	arvamine =arvamine  (SgN  >arvamine !12_S	et	f	\N
160500	arvamine	"arvamine %arva  )MINE_vS  <arvama ;29_V	et	f	\N
160501	shower	?shower =shower  (SgN  >shower !02_S	et	f	\N
160511	lisapealkirja	lisapealkirja =kirja  (SgG  >lisa+peal+kiri !24_S	et	f	\N
160512	lisapealkirja	lisapealkirja =kirja  (SgP  >lisa+peal+kiri !24_S	et	f	\N
160513	lisapealkirja	lisapealkirja =kirja  (SgAdt  >lisa+peal+kiri !24_S	et	f	\N
160526	liigendavad	liigendavad =liigenda  (IndPrPl3  >liigendama !27_V	et	f	\N
160527	liigendavad	liigendavad =liigendava  (PlN  >liigendav !02_A	et	f	\N
160528	liigendavad	"liigendav %liigenda  )V_vA  <liigendama ;27_V	et	f	\N
160533	pelkirja	?pelkirja =pelkirja  (SgN  >pelkirja !16_S	et	f	\N
160534	pelkirja	?pelkirja =pelkirja  (SgG  >pelkirjas !02_A	et	f	\N
160535	pelkirja	?pelkirja =pelkirja  (SgG  >pelkirja !16_S	et	f	\N
160557	teravuse	teravuse =teravuse  (SgG  >teravus !11_S	et	f	\N
160558	teravuse	"teravus %terava  )US_aS  <terav ;02_A	et	f	\N
160569	jõhvit	?jõhvit =jõhvi  (SgP  >jõhvi !16_S	et	f	\N
160570	jõhvit	?jõhvit =jõhvit  (SgN  >jõhvit !02_S	et	f	\N
160573	pelkirjafraasid	?pelkirjafraasid =pelkirjafraa  (PlP  >pelkirjafraa !26_S	et	f	\N
160574	pelkirjafraasid	?pelkirjafraasid =pelkirjafraasi  (PlN  >pelkirjafraasi !16_S	et	f	\N
160575	pelkirjafraasid	?pelkirjafraasid =pelkirjafraasi  (PlN  >pelkirjafraas !22_S	et	f	\N
160576	pelkirjafraasid	?pelkirjafraasid =pelkirjafraasi  (IndPrSg2  >pelkirjafraasima !28_V	et	f	\N
160577	kaherealised	kaherealised =realise  (PlN  >kahe+realine !12?10_A	et	f	\N
160578	kaherealised	"kahe+realine %rea  )LINE_aA  <kahe+rida ;18_S	et	f	\N
160579	ulatavad	ulatavad =ulata  (IndPrPl3  >ulatama !27_V	et	f	\N
160580	ulatavad	ulatavad =ulatava  (PlN  >ulatav !02_A	et	f	\N
160581	ulatavad	"ulatav %ula  )TAV_vAS  <ulama ;27_V	et	f	\N
160582	ulatavad	"ulatav %ulata  )V_vA  <ulatama ;27_V	et	f	\N
160603	halvetica	?halvetica =halvetica  (SgN  >halvetica !16_S	et	f	\N
160604	halvetica	?halvetica =halvetica  (SgG  >halvetica !16_S	et	f	\N
160613	lisat	?lisat =lisat  (SgN  >lisat !02_S	et	f	\N
160645	artikklite	?artikklite =artikkli  (PlG  >artikkli !01_S	et	f	\N
160646	artikklite	?artikklite =artikkli  (IndPrPl2  >artikklima !28_V	et	f	\N
160677	vormistatud	vormistatud =vormista  (PtsPtIps  >vormistama !27_V	et	f	\N
160678	vormistatud	vormistatud =vormistatu  (PlN  >vormistatu !01_S	et	f	\N
160679	vormistatud	"vormistatu %vormista  )TU1_vS  <vormistama ;27_V	et	f	\N
160680	vormistatud	vormistatud =vormistatud  (ID  >vormistatud !41_A	et	f	\N
160681	vormistatud	"vormistatud %vormista  )TUD_vA  <vormistama ;27_V	et	f	\N
160717	eristavad	eristavad =erista  (IndPrPl3  >eristama !27_V	et	f	\N
160718	eristavad	eristavad =eristava  (PlN  >eristav !02_A	et	f	\N
160719	eristavad	"eristav %erista  )V_vA  <eristama ;27_V	et	f	\N
160720	eristavad	eristavad =tava  (PlN  >eris+tava !17_S	et	f	\N
160760	suurs	?suurs =suurs  (SgN  >suurs !22_S	et	f	\N
160763	optimaalselt	optimaalselt =optimaalse  (SgAbl  >optimaalne !02_A	et	f	\N
160764	optimaalselt	optimaalselt =optimaalselt  (ID  >optimaalselt !41_D	et	f	\N
160765	optimaalselt	"optimaalselt %optimaalse  )LT_mD  <optimaalne ;02_A	et	f	\N
160786	maalmani	?maalmani =maalmani  (SgG  >maalman !02_S	et	f	\N
160824	asjakohane	asjakohane =kohane  (SgN  >asja+kohane !10_A	et	f	\N
160825	asjakohane	"asja+kohane %koha  )NE_aA  <asja+koha ;17_S	et	f	\N
160826	asjakohane	"asja+kohane %koha  )NE_aA  <asja+koht ;22_S	et	f	\N
160827	pealkijaga	?pealkijaga =pealkija  (SgKom  >pealkija !01_S	et	f	\N
160828	pealkijaga	?pealkijaga =pealkija  (SgKom  >pealkijas !02_A	et	f	\N
160829	pealkijaga	?pealkijaga =kija  (SgKom  >peal+kija !17_S	et	f	\N
160835	huvitavust	huvitavust =huvitavus  (SgP  >huvitavus !11?09_S	et	f	\N
160836	huvitavust	"huvitavus %huvita  )VUS_aS  <huvitama ;27_V	et	f	\N
160837	huvitavust	"huvitavus %huvitava  )US_aS  <huvitav ;02_A	et	f	\N
160851	fotodeallkirjad	?fotodeallkirjad =fotodeallkirja  (PlN  >fotodeallkirjas !02_A	et	f	\N
160852	fotodeallkirjad	?fotodeallkirjad =fotodeallkirja  (PlN  >fotodeallkirja !16_S	et	f	\N
160853	fotodeallkirjad	?fotodeallkirjad =deallkirja  (PlN  >foto+deallkirjas !02_A	et	f	\N
160854	fotodeallkirjad	?fotodeallkirjad =deallkirja  (PlN  >foto+deallkirja !16_S	et	f	\N
160867	paksema	paksema =paksema  (SgG  >paksem !02_A	et	f	\N
160868	paksema	"paksem %pakse  )M_cA  <paks ;22_AS	et	f	\N
160869	paksema	paksema =ema  (SgN  >paks+ema !17_S	et	f	\N
160870	paksema	paksema =ema  (SgG  >paks+ema !17_S	et	f	\N
160871	paksema	paksema =ema  (SgP  >paks+ema !17_S	et	f	\N
160884	pisiinfo	pisiinfo =info  (SgN  >pisi+info !16_S	et	f	\N
160885	pisiinfo	pisiinfo =info  (SgG  >pisi+info !16_S	et	f	\N
160897	kuulutused	kuulutused =kuulutuse  (PlN  >kuulutus !11_S	et	f	\N
160898	kuulutused	"kuulutus %kuuluta  )US_vS  <kuulutama ;27_V	et	f	\N
160899	kuulutused	"kuulutus %kuulu  )TUS1_aS  <kuuluma ;27_V	et	f	\N
160900	kuulutused	"kuulutus %kuulu  )TUS2_aS  <kuuld ;22_S	et	f	\N
160923	veerulaiuse	veerulaiuse =laiuse  (SgG  >veeru+laius !11~09_S	et	f	\N
160924	veerulaiuse	"veeru+laius %lai  )US_aS  <veeru+lai ;22_A	et	f	\N
160925	veerulaiuse	veerulaiuse =laiuse  (SgG  >veeru+laiune !10~12_A	et	f	\N
160926	veerulaiuse	"veeru+laiune %laiu  )NE_aA  <veeru+laid ;22_S	et	f	\N
160933	pilgu	pilgu =pilgu  (SgG  >pilk !22_S	et	f	\N
160522	pelakirjad	?pelakirjad =pelakirja  (PlN  >pelakirja !16_S	et	f	\N
160523	lehekülgede	lehekülgede =ede  (SgN  >lehe+külg+ede !16_S	et	f	\N
160524	lehekülgede	lehekülgede =ede  (SgG  >lehe+külg+ede !16_S	et	f	\N
160525	lehekülgede	lehekülgede =külge  (PlG  >lehe+külg !22_S	et	f	\N
160529	väiksemateks	väiksemateks =väiksema  (PlTr  >väiksem !02_A	et	f	\N
160530	väiksemateks	"väiksem %väikse  )M_cA  <väike ;10_A	et	f	\N
160531	väiksemateks	väiksemateks =mate  (SgTr  >väikse+mate !16_S	et	f	\N
160532	väiksemateks	väiksemateks =mate  (PlTr  >väikse+matt !22_SA	et	f	\N
160544	loetavad	loetavad =loeta  (IndPrPl3  >loetama !27_V	et	f	\N
160545	loetavad	loetavad =loetava  (PlN  >loetav !02_AS	et	f	\N
160546	loetavad	"loetav %loe  )TAV_vAS  <lugema ;28_V	et	f	\N
160547	loetavad	"loetav %loeta  )V_vA  <loetama ;27_V	et	f	\N
160548	pelkiri	?pelkiri =pelkiri  (SgN  >pelkiri !01_S	et	f	\N
160549	pelkiri	?pelkiri =pelkiri  (SgG  >pelkiri !01_S	et	f	\N
160550	pelkiri	?pelkiri =pelkiri  (SgG  >pelkir !02_S	et	f	\N
160555	ilmekuse	ilmekuse =ilmekuse  (SgG  >ilmekus !11_S	et	f	\N
160556	ilmekuse	"ilmekus %ilmeka  )US_aS  <ilmekas ;02_A	et	f	\N
160559	kohtla-järvest	kohtla-järvest =järve  (SgEl  >kohtla-järv !22_S	et	f	\N
160560	kohtla-järvest	kohtla-järvest =järve  (PlEl  >kohtla-järv !22_S	et	f	\N
160561	kohtla-järvest	kohtla-järvest =järves  (SgP  >kohtla-järvene !10_A	et	f	\N
160562	kohtla-järvest	"kohtla-järvene %järve  )NE_aA  <kohtla-järv ;22_S	et	f	\N
160583	veerud	veerud =veeru  (PlN  >veerg !22_S	et	f	\N
160584	veerud	veerud =veeru  (PlN  >veer !22_S	et	f	\N
160594	domineerivalt	domineerivalt =domineeriva  (SgAbl  >domineeriv !02_A	et	f	\N
160595	domineerivalt	"domineeriv %domineeri  )V_vA  <domineerima ;28_V	et	f	\N
160596	domineerivalt	domineerivalt =domineerivalt  (ID  >domineerivalt !41_D	et	f	\N
160597	domineerivalt	"domineerivalt %domineeri  )VALT_mD  <domineerima ;28_V	et	f	\N
160611	põhjendatut	põhjendatut =põhjendatu  (SgP  >põhjendatu !01_S	et	f	\N
160612	põhjendatut	"põhjendatu %põhjenda  )TU1_vS  <põhjendama ;27_V	et	f	\N
160614	jätkamine	jätkamine =jätkamine  (SgN  >jätkamine !12_S	et	f	\N
160615	jätkamine	"jätkamine %jätka  )MINE_vS  <jätkama ;29_V	et	f	\N
160619	rangete	rangete =range  (PlG  >range !01_A	et	f	\N
160620	rangete	rangete =e  (PlG  >rang+esi !15_S	et	f	\N
160625	allajoonistavad	allajoonistavad =tava  (PlN  >alla+joonis+tava !17_S	et	f	\N
160626	allajoonistavad	allajoonistavad =joonistava  (PlN  >alla+joonistav !02_A	et	f	\N
160631	joondatud	joondatud =joonda  (PtsPtIps  >joondama !27_V	et	f	\N
160632	joondatud	joondatud =joondatu  (PlN  >joondatu !01_S	et	f	\N
160633	joondatud	"joondatu %joonda  )TU1_vS  <joondama ;27_V	et	f	\N
160634	joondatud	joondatud =joondatud  (ID  >joondatud !41_A	et	f	\N
160635	joondatud	"joondatud %joonda  )TUD_vA  <joondama ;27_V	et	f	\N
160647	paksemas	paksemas =paksema  (SgIn  >paksem !02_A	et	f	\N
160648	paksemas	"paksem %pakse  )M_cA  <paks ;22_AS	et	f	\N
160649	paksemas	paksemas =ema  (SgIn  >paks+ema !17_S	et	f	\N
160666	ülipikkad	?ülipikkad =ülipikka  (PlN  >ülipikka !16_S	et	f	\N
160682	lugemisel	lugemisel =lugemise  (SgAd  >lugemine !12_S	et	f	\N
160683	lugemisel	"lugemine %luge  )MINE_vS  <lugema ;28_V	et	f	\N
160684	lugemisel	"lugemine %lugemi  )NE_aA  <lugem ;02_S	et	f	\N
160696	kol	### kol	et	f	\N
160704	kasutatu	kasutatu =kasutatu  (SgN  >kasutatu !01_S	et	f	\N
160705	kasutatu	"kasutatu %kasuta  )TU1_vS  <kasutama ;27_V	et	f	\N
160706	kasutatu	kasutatu =kasutatu  (SgG  >kasutatu !01_S	et	f	\N
160742	artikklit	?artikklit =artikkli  (SgP  >artikkli !01_S	et	f	\N
160747	ülemise	ülemise =ülemise  (SgG  >ülemine !12_A	et	f	\N
160749	ülemise	ülemise =ise  (ID  >ülem+ise !41_DA	et	f	\N
160750	reavahe	reavahe =vahe  (SgN  >rea+vahe !02_A	et	f	\N
160751	reavahe	reavahe =vahe  (SgN  >rea+vahe !16_S	et	f	\N
160752	reavahe	reavahe =vahe  (SgG  >rea+vahe !16_S	et	f	\N
160756	veerus	veerus =veeru  (SgIn  >veerg !22_S	et	f	\N
160757	veerus	veerus =veeru  (SgIn  >veer !22_S	et	f	\N
160759	cic	### cic	et	f	\N
160784	keeruliseks	keeruliseks =keerulise  (SgTr  >keeruline !12_A	et	f	\N
160785	keeruliseks	"keeruline %keeru  )LINE_aA  <keerd ;22_SA	et	f	\N
160794	paiguta-tud	### paiguta-tud	et	f	\N
160838	lehekälg	?lehekälg =lehekälg  (SgN  >lehekälg !22_S	et	f	\N
160839	lehekälg	?lehekälg =kälg  (SgN  >lehe+kälg !22_S	et	f	\N
160846	liigutav	liigutav =liigu  (PtsPrIps  >liikuma !28_V	et	f	\N
160847	liigutav	liigutav =liiguta  (PtsPrPs  >liigutama !27_V	et	f	\N
160848	liigutav	liigutav =liigutav  (SgN  >liigutav !02_A	et	f	\N
160849	liigutav	"liigutav %liigu  )TAV_vAS  <liikuma ;28_V	et	f	\N
160850	liigutav	"liigutav %liiguta  )V_vA  <liigutama ;27_V	et	f	\N
160889	pisiinfo	pisiinfo =info  (SgN  >pisi+info !16_S	et	f	\N
160890	pisiinfo	pisiinfo =info  (SgG  >pisi+info !16_S	et	f	\N
160942	kirevaks	kirevaks =kireva  (SgTr  >kirev !02_A	et	f	\N
160943	kirevaks	"kirev %kire  )V_vA  <kirema ;27_V	et	f	\N
160944	kirevaks	kirevaks =vaks  (SgN  >kire+vaks !22_S	et	f	\N
160956	likool	?likool =likoo  (SgAd  >likoo !26_S	et	f	\N
160957	likool	?likool =likool  (SgN  >likool !22_S	et	f	\N
160659	modernseimale	modernseimale =seima  (SgAll  >modern+seim !22_S	et	f	\N
160660	kitsamate	kitsamate =kitsama  (PlG  >kitsam !02_A	et	f	\N
160661	kitsamate	"kitsam %kitsa  )M_cA  <kitsas ;07_A	et	f	\N
160662	kitsamate	kitsamate =mate  (SgN  >kitsa+mate !16_S	et	f	\N
160663	kitsamate	kitsamate =mate  (SgG  >kitsa+mate !16_S	et	f	\N
160688	artikklis	?artikklis =artikkli  (SgIn  >artikkli !01_S	et	f	\N
160689	artikklis	?artikklis =artikkli  (SgIn  >artikkl !22_S	et	f	\N
160690	artikklis	?artikklis =artikkli  (IndIpfSg3  >artikklima !28_V	et	f	\N
160691	artikklis	?artikklis =artikklis  (SgN  >artikklis !11_S	et	f	\N
160699	vahepealkirju	vahepealkirju =kirju  (SgN  >vahe+peal+kirju !01_A	et	f	\N
160700	vahepealkirju	vahepealkirju =kirju  (SgN  >vahe+peal+kirju !16_A	et	f	\N
160701	vahepealkirju	vahepealkirju =kirju  (SgG  >vahe+peal+kirju !01_A	et	f	\N
160702	vahepealkirju	vahepealkirju =kirju  (SgG  >vahe+peal+kirju !16_A	et	f	\N
160703	vahepealkirju	vahepealkirju =kirju  (PlP  >vahe+peal+kiri !24_S	et	f	\N
160707	tähekesed	tähekesed =tähekese  (PlN  >täheke !12_S	et	f	\N
160708	tähekesed	"täheke %tähe  )KE_dS  <täht ;22_S	et	f	\N
160709	tähekesed	tähekesed =tähekese  (PlN  >tähekene !12_S	et	f	\N
160710	tähekesed	"tähekene %tähe  )KENE_dS  <täht ;22_S	et	f	\N
160716	ühs	?ühs =ühs  (SgN  >ühs !22_S	et	f	\N
160743	torkiv	torkiv =torki  (PtsPrPs  >torkima !28_V	et	f	\N
160744	torkiv	torkiv =torkiv  (SgN  >torkiv !02_A	et	f	\N
160745	torkiv	"torkiv %torki  )V_vA  <torkima ;28_V	et	f	\N
160766	mahutatud	mahutatud =mahuta  (PtsPtIps  >mahutama !27_V	et	f	\N
160767	mahutatud	mahutatud =mahutatu  (PlN  >mahutatu !01_S	et	f	\N
160768	mahutatud	"mahutatu %mahuta  )TU1_vS  <mahutama ;27_V	et	f	\N
160769	mahutatud	mahutatud =mahutatud  (ID  >mahutatud !41_A	et	f	\N
160770	mahutatud	"mahutatud %mahuta  )TUD_vA  <mahutama ;27_V	et	f	\N
160773	veerukesed	veerukesed =veerukese  (PlN  >veeruke !12_S	et	f	\N
160774	veerukesed	"veeruke %veeru  )KE_dS  <veerg ;22_S	et	f	\N
160775	veerukesed	"veeruke %veeru  )KE_dS  <veer ;22_S	et	f	\N
160776	veerukesed	veerukesed =veerukese  (PlN  >veerukene !12_S	et	f	\N
160777	veerukesed	"veerukene %veeru  )KENE_dS  <veerg ;22_S	et	f	\N
160778	veerukesed	"veerukene %veeru  )KENE_dS  <veer ;22_S	et	f	\N
160781	kätte-saamine	kätte-saamine =saamine  (SgN  >kätte-saamine !12?10_S	et	f	\N
160782	kätte-saamine	"kätte-saamine %saa  )MINE_vS  <kätte-saama ;37_V	et	f	\N
160783	kätte-saamine	"kätte-saamine %saami  )NE_aA  <kätte-saam ;22_S	et	f	\N
160788	menetluses	menetluses =menetluse  (SgIn  >menetlus !11_S	et	f	\N
160790	menetluses	"menetlus %menetle  )US_vS  <menetlema ;27_V	et	f	\N
160795	põhiartikkli	?põhiartikkli =põhiartikkli  (IndPrPs_  >põhiartikklima !28_V	et	f	\N
160796	põhiartikkli	?põhiartikkli =põhiartikkli  (ImpPrSg2  >põhiartikklima !28_V	et	f	\N
160797	põhiartikkli	?põhiartikkli =artikkli  (SgN  >põhi+artikkli !01_S	et	f	\N
160798	põhiartikkli	?põhiartikkli =artikkli  (SgG  >põhi+artikkli !01_S	et	f	\N
160799	põhiartikkli	?põhiartikkli =artikkli  (SgG  >põhi+artikkl !22_S	et	f	\N
160800	põhiartikkli	?põhiartikkli =artikkli  (SgP  >põhi+artikkl !22_S	et	f	\N
160801	põhiartikkli	?põhiartikkli =artikkli  (SgAdt  >põhi+artikkl !22_S	et	f	\N
160802	lõpetamatuse	lõpetamatuse =lõpetamatuse  (SgG  >lõpetamatus !11?09_S	et	f	\N
160803	lõpetamatuse	"lõpetamatus %lõpe  )TAMATUS_aS  <lõppema ;28_V	et	f	\N
160804	lõpetamatuse	"lõpetamatus %lõpe  )TAMATUS_aS  <lõpma ;35_V	et	f	\N
160805	lõpetamatuse	"lõpetamatus %lõpeta  )MATUS_aS  <lõpetama ;27_V	et	f	\N
160806	ülesse	?ülesse =ülesse  (SgG  >ülesne !02_A	et	f	\N
160807	ülesse	?ülesse =ülesse  (PlP  >üless !22_S	et	f	\N
160814	rahulikum	rahulikum =rahulikum  (SgN  >rahulikum !02_A	et	f	\N
160815	rahulikum	"rahulikum %rahuliku  )M_cA  <rahulik ;25_A	et	f	\N
160816	muutuvas	muutuvas =muutuva  (SgIn  >muutuv !02_A	et	f	\N
160817	muutuvas	"muutuv %muutu  )V_vA  <muutuma ;27_V	et	f	\N
160822	suuus	?suuus =suuu  (SgIn  >suuu !26_S	et	f	\N
160823	suuus	?suuus =suuus  (SgN  >suuus !22_S	et	f	\N
160830	köitab	?köitab =köita  (IndPrSg3  >köitama !27_V	et	f	\N
160840	portreefotoline	portreefotoline =ine  (SgN  >port+ree+fotol+ine !16_S	et	f	\N
160841	portreefotoline	portreefotoline =ine  (SgG  >port+ree+fotol+ine !16_S	et	f	\N
160842	portreefotoline	portreefotoline =fotoline  (SgN  >port+ree+fotoline !12_A	et	f	\N
160843	portreefotoline	"port+ree+fotoline %foto  )LINE_aA  <port+ree+foto ;16_S	et	f	\N
160855	pikat	?pikat =pika  (SgP  >pika !16_S	et	f	\N
160856	pikat	?pikat =pikat  (SgN  >pikat !02_S	et	f	\N
160877	kitsamalt	kitsamalt =kitsama  (SgAbl  >kitsam !02_A	et	f	\N
160878	kitsamalt	"kitsam %kitsa  )M_cA  <kitsas ;07_A	et	f	\N
160879	kitsamalt	kitsamalt =kitsamalt  (ID  >kitsamalt !41_D	et	f	\N
160880	kitsamalt	"kitsamalt %kitsa  )MALT_mD  <kitsas ;07_A	et	f	\N
160916	veerulaius	veerulaius =laiu  (SgIn  >veeru+laid !22_S	et	f	\N
160917	veerulaius	veerulaius =laiu  (PlIn  >veeru+laid !22_S	et	f	\N
160918	veerulaius	veerulaius =laiu  (PlIn  >veeru+lai !22_A	et	f	\N
160919	veerulaius	veerulaius =laius  (SgN  >veeru+laius !11~09_S	et	f	\N
160920	veerulaius	"veeru+laius %lai  )US_aS  <veeru+lai ;22_A	et	f	\N
160693	veeru	veeru =veeru  (SgG  >veer !22_S	et	f	\N
160694	veeru	veeru =veeru  (SgP  >veer !22_S	et	f	\N
160695	veeru	veeru =veeru  (SgAdt  >veer !22_S	et	f	\N
160711	artikklid	?artikklid =artikkli  (PlN  >artikkli !01_S	et	f	\N
160712	artikklid	?artikklid =artikkli  (PlN  >artikkl !22_S	et	f	\N
160713	artikklid	?artikklid =artikkli  (IndPrSg2  >artikklima !28_V	et	f	\N
160714	mahuks	mahuks =mahu  (SgTr  >maht !22_S	et	f	\N
160715	mahuks	mahuks =mahu  (KndPrPs  >mahtuma !28_V	et	f	\N
160728	legejatest	?legejatest =legeja  (PlEl  >legeja !01_S	et	f	\N
160729	legejatest	?legejatest =legeja  (PlEl  >legejas !02_A	et	f	\N
160730	legejatest	?legejatest =legejate  (PlEl  >legejatt !22_S	et	f	\N
160731	legejatest	?legejatest =legejates  (SgP  >legejatene !12_A	et	f	\N
160732	plokk-kirja	plokk-kirja =kirja  (SgG  >plokk-kiri !24_S	et	f	\N
160733	plokk-kirja	plokk-kirja =kirja  (SgP  >plokk-kiri !24_S	et	f	\N
160734	plokk-kirja	plokk-kirja =kirja  (SgAdt  >plokk-kiri !24_S	et	f	\N
160735	plokk-kirja	plokk-kirja =kirja  (IndPrPs_  >plokk-kirjama !29_V	et	f	\N
160736	plokk-kirja	plokk-kirja =kirja  (ImpPrSg2  >plokk-kirjama !29_V	et	f	\N
160746	nurka	nurka =nurka  (SgP  >nurk !22_S	et	f	\N
160748	nurka	nurka =nurka  (SgAdt  >nurk !22_S	et	f	\N
160753	arktikas	?arktikas =arktika  (SgIn  >arktika !01_S	et	f	\N
160754	arktikas	?arktikas =arktika  (SgIn  >arktikas !02_S	et	f	\N
160755	arktikas	?arktikas =arktikas  (SgN  >arktikas !02_S	et	f	\N
160758	artikklitset	?artikklitset =artikklitse  (SgP  >artikklitne !02_A	et	f	\N
160792	välja-nõudmist	välja-nõudmist =nõudmis  (SgP  >välja-nõudmine !12?10_S	et	f	\N
160793	välja-nõudmist	"välja-nõudmine %nõud  )MINE_vS  <välja-nõudma ;34_V	et	f	\N
160810	veeulaius	?veeulaius =veeulaiu  (SgIn  >veeulaiu !01_S	et	f	\N
160811	veeulaius	?veeulaius =veeulaius  (SgN  >veeulaius !11_S	et	f	\N
160812	veeulaius	?veeulaius =ulaiu  (SgIn  >vee+ulaiu !01_S	et	f	\N
160813	veeulaius	?veeulaius =ulaius  (SgN  >vee+ulaius !11_S	et	f	\N
160818	dokumentaal	?dokumentaal =dokumentaa  (SgAd  >dokumentaa !26_S	et	f	\N
160819	dokumentaal	?dokumentaal =dokumentaal  (SgN  >dokumentaal !22_S	et	f	\N
160820	dokumentaal	?dokumentaal =umentaa  (SgAd  >dok+umentaa !26_S	et	f	\N
160821	dokumentaal	?dokumentaal =umentaal  (SgN  >dok+umentaal !22_S	et	f	\N
160831	liikuvust	liikuvust =liikuvus  (SgP  >liikuvus !11_S	et	f	\N
160832	liikuvust	"liikuvus %liiku  )VUS_aS  <liikuma ;28_V	et	f	\N
160833	liikuvust	"liikuvus %liikuva  )US_aS  <liikuv ;02_A	et	f	\N
160834	liikuvust	liikuvust =us  (SgP  >liikuv+uks !14_S	et	f	\N
160844	stampfotolised	stampfotolised =fotolise  (PlN  >stamp+fotoline !12_A	et	f	\N
160845	stampfotolised	"stamp+fotoline %foto  )LINE_aA  <stamp+foto ;16_S	et	f	\N
160857	allkirja	allkirja =kirja  (SgG  >all+kiri !24_S	et	f	\N
160858	allkirja	allkirja =kirja  (SgP  >all+kiri !24_S	et	f	\N
160859	allkirja	allkirja =kirja  (SgAdt  >all+kiri !24_S	et	f	\N
160886	pöhjaranniku	?pöhjaranniku =pöhjaranniku  (SgG  >pöhjarannik !02_S	et	f	\N
160887	pöhjaranniku	?pöhjaranniku =pöhjaranniku  (IndPrPs_  >pöhjarannikuma !27_V	et	f	\N
160888	pöhjaranniku	?pöhjaranniku =pöhjaranniku  (ImpPrSg2  >pöhjarannikuma !27_V	et	f	\N
160896	mitmekesisem	?mitmekesisem =mitmekesisem  (SgN  >mitmekesisem !02_A	et	f	\N
160907	võtmesõna	võtmesõna =sõna  (SgN  >võtme+sõna !17_S	et	f	\N
160908	võtmesõna	võtmesõna =sõna  (SgG  >võtme+sõna !17_S	et	f	\N
160909	võtmesõna	võtmesõna =sõna  (SgP  >võtme+sõna !17_S	et	f	\N
160929	korrastavad	korrastavad =korrasta  (IndPrPl3  >korrastama !27_V	et	f	\N
160930	korrastavad	korrastavad =korrastava  (PlN  >korrastav !02_A	et	f	\N
160931	korrastavad	"korrastav %korrasta  )V_vA  <korrastama ;27_V	et	f	\N
160932	korrastavad	korrastavad =tava  (PlN  >korras+tava !17_S	et	f	\N
160936	takistavad	takistavad =takista  (IndPrPl3  >takistama !27_V	et	f	\N
160938	takistavad	takistavad =takistava  (PlN  >takistav !02_A	et	f	\N
160940	takistavad	"takistav %takista  )V_vA  <takistama ;27_V	et	f	\N
160945	laikude	laikude =laiku  (PlG  >laik !22_S	et	f	\N
160947	laikude	laikude =ude  (SgN  >laik+ude !04_S	et	f	\N
160949	laikude	laikude =kude  (SgN  >lai+kude !18_S	et	f	\N
160950	laikude	laikude =kude  (SgP  >lai+kude !18_S	et	f	\N
160984	ersa	?ersa =ersa  (SgN  >ersa !16_S	et	f	\N
160985	ersa	?ersa =ersa  (SgG  >ersa !16_S	et	f	\N
160986	ersa	?ersa =ersa  (IndPrPs_  >ersama !29_V	et	f	\N
160987	ersa	?ersa =ersa  (ImpPrSg2  >ersama !29_V	et	f	\N
160995	lühemad	lühemad =lühema  (PlN  >lühem !02_A	et	f	\N
160996	lühemad	"lühem %lühe  )M_cA  <lühike ;12_A	et	f	\N
160999	olulisusega	olulisusega =olulisuse  (SgKom  >olulisus !11?09_S	et	f	\N
161000	olulisusega	"olulisus %olu  )LISUS_aS  <olu ;17_S	et	f	\N
161004	hooletusega	hooletusega =hooletuse  (SgKom  >hooletus !11_S	et	f	\N
161005	hooletusega	"hooletus %hoole  )TUS2_aS  <hool ;13_S	et	f	\N
161015	sarnastes	sarnastes =sarnas  (PlIn  >sarnane !10_A	et	f	\N
161016	sarnastes	"sarnane %sarna  )NE_aA  <sarn ;22_S	et	f	\N
161032	üllatavalt	üllatavalt =üllatava  (SgAbl  >üllatav !02_A	et	f	\N
161033	üllatavalt	"üllatav %üllata  )V_vA  <üllatama ;27_V	et	f	\N
161034	üllatavalt	üllatavalt =üllatavalt  (ID  >üllatavalt !41_D	et	f	\N
160791	kristel	?kristel =kristel  (SgN  >kristel !02_S	et	f	\N
160808	öelad	?öelad =öela  (PlN  >öela !16_S	et	f	\N
160809	öelad	?öelad =öela  (IndPrSg2  >öelama !29_V	et	f	\N
160860	viitsita	viitsita =viitsi  (IndPrIps_  >viitsima !28_V	et	f	\N
160861	viitsita	viitsita =si  (SgAb  >viit+si !26_S	et	f	\N
160862	viitsita	viitsita =sita  (SgG  >viit+sitt !22_SA	et	f	\N
160863	allkitjad	?allkitjad =allkitja  (PlN  >allkitja !01_S	et	f	\N
160864	allkitjad	?allkitjad =allkitja  (PlN  >allkitjas !02_A	et	f	\N
160865	allkitjad	?allkitjad =kitja  (PlN  >all+kitja !01_S	et	f	\N
160866	allkitjad	?allkitjad =kitja  (PlN  >all+kitjas !02_A	et	f	\N
160872	ladunud	ladunud =ladu  (PtsPtPs  >laduma !28_V	et	f	\N
160873	ladunud	ladunud =ladunu  (PlN  >ladunu !01_S	et	f	\N
160874	ladunud	"ladunu %ladu  )NU_vS  <laduma ;28_V	et	f	\N
160875	ladunud	ladunud =ladunud  (ID  >ladunud !41_A	et	f	\N
160876	ladunud	"ladunud %ladu  )NUD_vA  <laduma ;28_V	et	f	\N
160881	allkirjast	allkirjast =kirja  (SgEl  >all+kiri !24_S	et	f	\N
160882	allkirjast	allkirjast =kirjas  (SgP  >all+kirjane !10_A	et	f	\N
160883	allkirjast	"all+kirjane %kirja  )NE_aA  <all+kiri ;24_S	et	f	\N
160891	kuulutuste	kuulutuste =kuulutus  (PlG  >kuulutus !11_S	et	f	\N
160892	kuulutuste	"kuulutus %kuuluta  )US_vS  <kuulutama ;27_V	et	f	\N
160893	kuulutuste	"kuulutus %kuulu  )TUS1_aS  <kuuluma ;27_V	et	f	\N
160894	kuulutuste	"kuulutus %kuulu  )TUS2_aS  <kuuld ;22_S	et	f	\N
160895	kuulutuste	kuulutuste =tuste  (PlP  >kuulu+tust !22_S	et	f	\N
160901	eristuskirjaga	?eristuskirjaga =eristuskirja  (SgKom  >eristuskirjas !02_A	et	f	\N
160902	eristuskirjaga	?eristuskirjaga =eristuskirja  (SgKom  >eristuskirja !16_S	et	f	\N
160903	eristuskirjaga	?eristuskirjaga =tuskirja  (SgKom  >eris+tuskirjas !02_A	et	f	\N
160904	eristuskirjaga	?eristuskirjaga =tuskirja  (SgKom  >eris+tuskirja !16_S	et	f	\N
160905	eristuskirjaga	?eristuskirjaga =stuskirja  (SgKom  >eri+stuskirjas !02_A	et	f	\N
160906	eristuskirjaga	?eristuskirjaga =stuskirja  (SgKom  >eri+stuskirja !16_S	et	f	\N
160910	eristuskirjaseeria	?eristuskirjaseeria =eristuskirjaseeria  (SgN  >eristuskirjaseeria !01_S	et	f	\N
160911	eristuskirjaseeria	?eristuskirjaseeria =eristuskirjaseeria  (SgG  >eristuskirjaseeria !01_S	et	f	\N
160912	eristuskirjaseeria	?eristuskirjaseeria =tuskirjaseeria  (SgN  >eris+tuskirjaseeria !01_S	et	f	\N
160913	eristuskirjaseeria	?eristuskirjaseeria =tuskirjaseeria  (SgG  >eris+tuskirjaseeria !01_S	et	f	\N
160914	eristuskirjaseeria	?eristuskirjaseeria =stuskirjaseeria  (SgN  >eri+stuskirjaseeria !01_S	et	f	\N
160915	eristuskirjaseeria	?eristuskirjaseeria =stuskirjaseeria  (SgG  >eri+stuskirjaseeria !01_S	et	f	\N
160921	nõua	nõua =nõua  (IndPrPs_  >nõudma !34_V	et	f	\N
160922	nõua	nõua =nõua  (ImpPrSg2  >nõudma !34_V	et	f	\N
160954	keelekasutuses	keelekasutuses =kasutuse  (SgIn  >keele+kasutus !11_S	et	f	\N
160955	keelekasutuses	"keele+kasutus %kasu  )TUS2_aS  <keele+kasu ;17_S	et	f	\N
160973	veaanalüüsi	?veaanalüüsi =veaanalüüsi  (SgN  >veaanalüüsi !16_S	et	f	\N
160974	veaanalüüsi	?veaanalüüsi =veaanalüüsi  (SgG  >veaanalüüsi !16_S	et	f	\N
160975	veaanalüüsi	?veaanalüüsi =veaanalüüsi  (SgG  >veaanalüüs !22_S	et	f	\N
160976	veaanalüüsi	?veaanalüüsi =veaanalüüsi  (SgP  >veaanalüüs !22_S	et	f	\N
160977	veaanalüüsi	?veaanalüüsi =veaanalüüsi  (SgAdt  >veaanalüüs !22_S	et	f	\N
160978	veaanalüüsi	?veaanalüüsi =veaanalüüsi  (IndPrPs_  >veaanalüüsima !28_V	et	f	\N
160979	veaanalüüsi	?veaanalüüsi =veaanalüüsi  (ImpPrSg2  >veaanalüüsima !28_V	et	f	\N
161017	referat	?referat =refera  (SgP  >refera !01_S	et	f	\N
161028	sujuvam	sujuvam =sujuvam  (SgN  >sujuvam !02_A	et	f	\N
161029	sujuvam	"sujuvam %suju  )VAM_cA  <sujuma ;27_V	et	f	\N
161030	sujuvam	"sujuvam %sujuva  )M_cA  <sujuv ;02_A	et	f	\N
161083	käändelõpp	?käändelõpp =käändelõpp  (SgN  >käändelõpp !22_S	et	f	\N
161084	käändelõpp	?käändelõpp =elõpp  (SgN  >käänd+elõpp !22_S	et	f	\N
161092	valmistanud	valmistanud =valmista  (PtsPtPs  >valmistama !27_V	et	f	\N
161093	valmistanud	valmistanud =valmistanu  (PlN  >valmistanu !01_S	et	f	\N
161094	valmistanud	"valmistanu %valmista  )NU_vS  <valmistama ;27_V	et	f	\N
161095	valmistanud	valmistanud =valmistanud  (ID  >valmistanud !41_A	et	f	\N
161096	valmistanud	"valmistanud %valmista  )NUD_vA  <valmistama ;27_V	et	f	\N
161097	valmistanud	valmistanud =tanu  (PlN  >valmis+tanu !17_S	et	f	\N
161104	ühildu	ühildu =ühildu  (IndPrPs_  >ühilduma !27_V	et	f	\N
161105	ühildu	ühildu =ühildu  (ImpPrSg2  >ühilduma !27_V	et	f	\N
161110	elutee	elutee =tee  (SgN  >elu+tee !26_S	et	f	\N
161111	elutee	elutee =tee  (SgG  >elu+tee !26_S	et	f	\N
161117	ühildumist	ühildumist =ühildumis  (SgP  >ühildumine !12_S	et	f	\N
161118	ühildumist	"ühildumine %ühildu  )MINE_vS  <ühilduma ;27_V	et	f	\N
161145	õpitavaid	õpitavaid =õpitava  (PlP  >õpitav !02_A	et	f	\N
161146	õpitavaid	"õpitav %õpi  )TAV_vAS  <õppima ;28_V	et	f	\N
161149	ekslikult	ekslikult =eksliku  (SgAbl  >ekslik !25_A	et	f	\N
161150	ekslikult	ekslikult =ekslikult  (ID  >ekslikult !41_D	et	f	\N
161151	ekslikult	"ekslikult %eksliku  )LT_mD  <ekslik ;25_A	et	f	\N
161173	sarnasus	sarnasus =sarnasus  (SgN  >sarnasus !11_S	et	f	\N
161174	sarnasus	"sarnasus %sarna  )SUS_aS  <sarn ;22_S	et	f	\N
161185	paljuski	paljuski =palju  (SgIn^  >palju !16_P	et	f	\N
160927	haaratavad	haaratavad =haaratava  (PlN  >haaratav !02_A	et	f	\N
160928	haaratavad	"haaratav %haara  )TAV_vAS  <haarama ;29_V	et	f	\N
160951	kaksiklehekülgede	kaksiklehekülgede =ede  (SgN  >kaksik+lehe+külg+ede !16_S	et	f	\N
160952	kaksiklehekülgede	kaksiklehekülgede =ede  (SgG  >kaksik+lehe+külg+ede !16_S	et	f	\N
160953	kaksiklehekülgede	kaksiklehekülgede =külge  (PlG  >kaksik+lehe+külg !22_S	et	f	\N
160958	kontrastiivlingvistika	?kontrastiivlingvistika =kontrastiivlingvistika  (SgN  >kontrastiivlingvistika !01_S	et	f	\N
160959	kontrastiivlingvistika	?kontrastiivlingvistika =kontrastiivlingvistika  (SgG  >kontrastiivlingvistika !01_S	et	f	\N
160960	kontrastiivlingvistika	?kontrastiivlingvistika =kontrastiivlingvistika  (SgG  >kontrastiivlingvistikas !02_A	et	f	\N
160961	kontrastiivlingvistika	?kontrastiivlingvistika =ivlingvistika  (SgN  >kontrasti+ivlingvistika !01_S	et	f	\N
160962	kontrastiivlingvistika	?kontrastiivlingvistika =ivlingvistika  (SgG  >kontrasti+ivlingvistika !01_S	et	f	\N
160963	kontrastiivlingvistika	?kontrastiivlingvistika =ivlingvistika  (SgG  >kontrasti+ivlingvistikas !02_A	et	f	\N
160964	kontrastiivlingvistika	?kontrastiivlingvistika =iivlingvistika  (SgN  >kontrast+iivlingvistika !01_S	et	f	\N
160965	kontrastiivlingvistika	?kontrastiivlingvistika =iivlingvistika  (SgG  >kontrast+iivlingvistika !01_S	et	f	\N
160966	kontrastiivlingvistika	?kontrastiivlingvistika =iivlingvistika  (SgG  >kontrast+iivlingvistikas !02_A	et	f	\N
160967	kontrastiivlingvistika	?kontrastiivlingvistika =stiivlingvistika  (SgN  >kontra+stiivlingvistika !01_S	et	f	\N
160968	kontrastiivlingvistika	?kontrastiivlingvistika =stiivlingvistika  (SgG  >kontra+stiivlingvistika !01_S	et	f	\N
160969	kontrastiivlingvistika	?kontrastiivlingvistika =stiivlingvistika  (SgG  >kontra+stiivlingvistikas !02_A	et	f	\N
160970	kontrastiivlingvistika	?kontrastiivlingvistika =rastiivlingvistika  (SgN  >kont+rastiivlingvistika !01_S	et	f	\N
160971	kontrastiivlingvistika	?kontrastiivlingvistika =rastiivlingvistika  (SgG  >kont+rastiivlingvistika !01_S	et	f	\N
160972	kontrastiivlingvistika	?kontrastiivlingvistika =rastiivlingvistika  (SgG  >kont+rastiivlingvistikas !02_A	et	f	\N
160982	moksad	?moksad =moksa  (PlN  >moksa !16_S	et	f	\N
160983	moksad	?moksad =moksa  (IndPrSg2  >moksama !29_V	et	f	\N
161011	mõjutusel	mõjutusel =mõjutuse  (SgAd  >mõjutus !11_S	et	f	\N
161012	mõjutusel	"mõjutus %mõjuta  )US_vS  <mõjutama ;27_V	et	f	\N
161013	mõjutusel	"mõjutus %mõju  )TUS1_aS  <mõjuma ;27_V	et	f	\N
161014	mõjutusel	"mõjutus %mõju  )TUS2_aS  <mõju ;17_S	et	f	\N
161020	pensioner	?pensioner =pensioner  (SgN  >pensioner !02_S	et	f	\N
161021	pensioner	?pensioner =oner  (SgN  >pensi+oner !02_S	et	f	\N
161039	objektivead	?objektivead =objektivea  (PlN  >objektivea !26_S	et	f	\N
161040	objektivead	?objektivead =objektivea  (SgP  >objektivea !26_S	et	f	\N
161041	objektivead	?objektivead =objektivead  (SgN  >objektivead !22_S	et	f	\N
161055	sõnalõpuline	sõnalõpuline =lõpuline  (SgN  >sõna+lõpuline !12_A	et	f	\N
161056	sõnalõpuline	"sõna+lõpuline %lõpu  )LINE_aA  <sõna+lõpp ;22_SA	et	f	\N
161057	omastavas	omastavas =omastava  (SgIn  >omastav !02_A	et	f	\N
161058	omastavas	"omastav %omasta  )V_vA  <omastama ;27_V	et	f	\N
161066	kreemukooki	?kreemukooki =kreemukooki  (SgN  >kreemukooki !16_S	et	f	\N
161067	kreemukooki	?kreemukooki =kreemukooki  (SgG  >kreemukooki !16_S	et	f	\N
161068	kreemukooki	?kreemukooki =kreemukooki  (SgP  >kreemukook !22_S	et	f	\N
161069	kreemukooki	?kreemukooki =kreemukooki  (SgAdt  >kreemukook !22_S	et	f	\N
161070	kreemukooki	?kreemukooki =ukooki  (SgN  >kreem+ukooki !16_S	et	f	\N
161071	kreemukooki	?kreemukooki =ukooki  (SgG  >kreem+ukooki !16_S	et	f	\N
161072	kreemukooki	?kreemukooki =ukooki  (SgP  >kreem+ukook !22_S	et	f	\N
161073	kreemukooki	?kreemukooki =ukooki  (SgAdt  >kreem+ukook !22_S	et	f	\N
161074	peretubas	?peretubas =peretuba  (SgIn  >peretuba !16_S	et	f	\N
161075	peretubas	?peretubas =tubas  (SgN  >pere+tubas !07_S	et	f	\N
161081	jaolt	jaolt =jao  (SgAbl  >jagu !18_S	et	f	\N
161082	jaolt	jaolt =jaolt  (ID  >jaolt !41_D	et	f	\N
161101	tehtav	tehtav =teh  (PtsPrIps  >tegema !28_V	et	f	\N
161102	tehtav	"tehtav %teh  )TAV_vAS  <tegema ;28_V	et	f	\N
161122	käändsõna	käändsõna =sõna  (SgN  >käänd+sõna !17_S	et	f	\N
161123	käändsõna	käändsõna =sõna  (SgG  >käänd+sõna !17_S	et	f	\N
161124	käändsõna	käändsõna =sõna  (SgP  >käänd+sõna !17_S	et	f	\N
161134	verbivormi	?verbivormi =verbivormi  (SgG  >verbivorm !22_S	et	f	\N
161135	verbivormi	?verbivormi =verbivormi  (SgP  >verbivorm !22_S	et	f	\N
161136	verbivormi	?verbivormi =verbivormi  (SgAdt  >verbivorm !22_S	et	f	\N
161137	verbivormi	?verbivormi =verbivormi  (IndPrPs_  >verbivormima !28_V	et	f	\N
161138	verbivormi	?verbivormi =verbivormi  (ImpPrSg2  >verbivormima !28_V	et	f	\N
161166	etendused	etendused =etenduse  (PlN  >etendus !11_S	et	f	\N
161167	etendused	"etendus %etenda  )US_vS  <etendama ;27_V	et	f	\N
161205	metsanainest	?metsanainest =metsanaine  (SgEl  >metsanaine !16_S	et	f	\N
161206	metsanainest	?metsanainest =metsanaine  (PlEl  >metsanain !19_S	et	f	\N
161207	metsanainest	?metsanainest =metsanaines  (SgP  >metsanainene !12_A	et	f	\N
161208	metsanainest	?metsanainest =naine  (PlEl  >metsa+nain !22_S	et	f	\N
161209	metsanainest	?metsanainest =naines  (SgP  >metsa+naines !09_S	et	f	\N
161210	metsanainest	?metsanainest =naines  (SgP  >metsa+nainene !10_A	et	f	\N
161211	metsanainest	?metsanainest =anaine  (PlEl  >mets+anain !22_S	et	f	\N
160934	pilgu	pilgu =pilgu  (IndPrPs_  >pilkuma !28_V	et	f	\N
160935	pilgu	pilgu =pilgu  (ImpPrSg2  >pilkuma !28_V	et	f	\N
160937	lehtedel	lehtedel =lehte  (PlAd  >leht !22_S	et	f	\N
160939	lehtedel	lehtedel =ede  (SgAd  >leht+ede !16_S	et	f	\N
160941	lehtedel	lehtedel =edel  (SgN  >leht+edel !02_S	et	f	\N
160946	kogumiks	kogumiks =kogumi  (SgTr  >kogum !02_S	et	f	\N
160948	kogumiks	kogumiks =mi  (SgTr  >kogu+mi !26_S	et	f	\N
160980	ersad	?ersad =ersa  (PlN  >ersa !16_S	et	f	\N
160981	ersad	?ersad =ersa  (IndPrSg2  >ersama !29_V	et	f	\N
160993	kuuldes	kuuldes =kuul  (Ger  >kuulma !33_V	et	f	\N
160994	kuuldes	kuuldes =kuulde  (SgIn  >kuule !06_S	et	f	\N
160997	grupeerimise	grupeerimise =grupeerimise  (SgG  >grupeerimine !12_S	et	f	\N
160998	grupeerimise	"grupeerimine %grupeeri  )MINE_vS  <grupeerima ;28_V	et	f	\N
161001	hääldus	hääldus =hääldu  (IndIpfSg3  >häälduma !27_V	et	f	\N
161002	hääldus	hääldus =hääldus  (SgN  >hääldus !11~09_S	et	f	\N
161003	hääldus	"hääldus %häälda  )US_vS  <hääldama ;27_V	et	f	\N
161006	kordunud	kordunud =kordu  (PtsPtPs  >korduma !27_V	et	f	\N
161007	kordunud	kordunud =kordunu  (PlN  >kordunu !01_S	et	f	\N
161008	kordunud	"kordunu %kordu  )NU_vS  <korduma ;27_V	et	f	\N
161009	kordunud	kordunud =kordunud  (ID  >kordunud !41_A	et	f	\N
161010	kordunud	"kordunud %kordu  )NUD_vA  <korduma ;27_V	et	f	\N
161018	pastet	?pastet =paste  (SgP  >paste !06_S	et	f	\N
161031	astmevahelduse	?astmevahelduse =astmevahelduse  (SgG  >astmevaheldus !11_S	et	f	\N
161044	käändevigu	?käändevigu =käändevigu  (IndPrPs_  >käändeviguma !27_V	et	f	\N
161045	käändevigu	?käändevigu =käändevigu  (ImpPrSg2  >käändeviguma !27_V	et	f	\N
161060	käändelõpu	?käändelõpu =käändelõpu  (IndPrPs_  >käändelõpuma !27_V	et	f	\N
161061	käändelõpu	?käändelõpu =käändelõpu  (ImpPrSg2  >käändelõpuma !27_V	et	f	\N
161062	käändelõpu	?käändelõpu =elõpu  (SgN  >käänd+elõpu !01_S	et	f	\N
161063	käändelõpu	?käändelõpu =elõpu  (SgG  >käänd+elõpu !01_S	et	f	\N
161064	ostsid	ostsid =ost  (IndIpfSg2  >ostma !34_V	et	f	\N
161065	ostsid	ostsid =ost  (IndIpfPl3  >ostma !34_V	et	f	\N
161076	suuremalt	suuremalt =suurema  (SgAbl  >suurem !02_A	et	f	\N
161077	suuremalt	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
161078	suuremalt	suuremalt =suuremalt  (ID  >suuremalt !41_D	et	f	\N
161079	suuremalt	"suuremalt %suure  )MALT_mD  <suur ;13_A	et	f	\N
161080	suuremalt	suuremalt =ema  (SgAbl  >suur+ema !17_S	et	f	\N
161087	teisalt	teisalt =teisalt  (ID  >teisalt !41_D	et	f	\N
161088	teisalt	teisalt =alt  (SgN  >teis+alt !22_S	et	f	\N
161098	laiendav	laiendav =laienda  (PtsPrPs  >laiendama !27_V	et	f	\N
161099	laiendav	laiendav =laiendav  (SgN  >laiendav !02_A	et	f	\N
161100	laiendav	"laiendav %laienda  )V_vA  <laiendama ;27_V	et	f	\N
161106	ühildumisvigade	### ühildumisvigade	et	f	\N
161127	metsale	metsale =metsa  (SgAll  >mets !22_S	et	f	\N
161128	metsale	metsale =ale  (SgN  >mets+ale !16_S	et	f	\N
161129	metsale	metsale =ale  (SgG  >mets+ale !16_S	et	f	\N
161139	lihtsamini	lihtsamini =lihtsami  (SgTer  >lihtsam !02_A	et	f	\N
161140	lihtsamini	"lihtsam %lihtsa  )M_cA  <lihtne ;02_A	et	f	\N
161141	lihtsamini	lihtsamini =mi  (SgTer  >lihtsa+mi !26_S	et	f	\N
161142	lihtsamini	lihtsamini =mini  (SgN  >lihtsa+mini !17~16_S	et	f	\N
161143	lihtsamini	lihtsamini =mini  (SgG  >lihtsa+mini !17~16_S	et	f	\N
161144	lihtsamini	lihtsamini =mini  (SgP  >lihtsa+mini !17_S	et	f	\N
161152	kasutatus	kasutatus =kasutatu  (SgIn  >kasutatu !01_S	et	f	\N
161153	kasutatus	"kasutatu %kasuta  )TU1_vS  <kasutama ;27_V	et	f	\N
161154	kasutatus	kasutatus =kasutatus  (SgN  >kasutatus !11?09_S	et	f	\N
161155	kasutatus	"kasutatus %kasuta  )TUS1_aS  <kasutama ;27_V	et	f	\N
161168	kingid	kingid =kingi  (PlN  >kink !22_S	et	f	\N
161169	kingid	kingid =kingi  (IndPrSg2  >kinkima !28_V	et	f	\N
161175	kasutavat	kasutavat =kasuta  (KvtPrPs  >kasutama !27_V	et	f	\N
161176	kasutavat	kasutavat =kasutava  (SgP  >kasutav !02_A	et	f	\N
161177	kasutavat	"kasutav %kasuta  )V_vA  <kasutama ;27_V	et	f	\N
161196	osakondas	?osakondas =osakonda  (SgIn  >osakonda !16_S	et	f	\N
161197	osakondas	?osakondas =osakonda  (IndIpfSg3  >osakondama !27_V	et	f	\N
161198	osakondas	?osakondas =konda  (SgIn  >osa+konda !16_S	et	f	\N
161199	osakondas	?osakondas =kondas  (SgN  >osa+kondas !07_S	et	f	\N
161213	võileivaid	?võileivaid =võileiva  (PlP  >võileiva !01_S	et	f	\N
161214	võileivaid	?võileivaid =võileivai  (PlN  >võileivai !26_S	et	f	\N
161215	võileivaid	?võileivaid =võileivai  (SgP  >võileivai !26_S	et	f	\N
161216	võileivaid	?võileivaid =leivai  (PlN  >või+leivai !26_S	et	f	\N
161217	võileivaid	?võileivaid =leivai  (SgP  >või+leivai !26_S	et	f	\N
161218	võileivaid	?võileivaid =leivaid  (SgN  >või+leivaid !22_S	et	f	\N
161225	rühmitamine	rühmitamine =rühmitamine  (SgN  >rühmitamine !12_S	et	f	\N
161226	rühmitamine	"rühmitamine %rühmita  )MINE_vS  <rühmitama ;27_V	et	f	\N
161234	keeleviga	keeleviga =viga  (SgN  >keele+viga !18_S	et	f	\N
161235	keeleviga	keeleviga =viga  (SgP  >keele+viga !18_S	et	f	\N
161249	arusaamatuse	arusaamatuse =saamatuse  (SgG  >aru+saamatus !11_S	et	f	\N
161250	arusaamatuse	"aru+saamatus %saama  )TUS2_aS  <aru+saam ;22_S	et	f	\N
160988	keelekasutust	keelekasutust =tust  (SgN  >keele+kasu+tust !22_S	et	f	\N
160989	keelekasutust	keelekasutust =kasutu  (SgEl  >keele+kasutu !01_A	et	f	\N
160990	keelekasutust	"keele+kasutu %kasu  )TU2_kA  <keele+kasu ;17_S	et	f	\N
160991	keelekasutust	keelekasutust =kasutus  (SgP  >keele+kasutus !11_S	et	f	\N
160992	keelekasutust	"keele+kasutus %kasu  )TUS2_aS  <keele+kasu ;17_S	et	f	\N
161019	sokolad	?sokolad =sokola  (PlN  >sokola !01_S	et	f	\N
161022	kaubamajjas	?kaubamajjas =kaubamajja  (SgIn  >kaubamajjas !02_A	et	f	\N
161023	kaubamajjas	?kaubamajjas =kaubamajja  (SgIn  >kaubamajja !16_S	et	f	\N
161024	kaubamajjas	?kaubamajjas =kaubamajjas  (SgN  >kaubamajjas !02_A	et	f	\N
161025	kaubamajjas	?kaubamajjas =majja  (SgIn  >kauba+majjas !02_A	et	f	\N
161026	kaubamajjas	?kaubamajjas =majja  (SgIn  >kauba+majja !16_S	et	f	\N
161027	kaubamajjas	?kaubamajjas =majjas  (SgN  >kauba+majjas !02_A	et	f	\N
161037	enamgi	enamgi =enam  (ID^  >enam !41_D	et	f	\N
161038	enamgi	enamgi =enam  (SgN^  >enam !02_A	et	f	\N
161052	puutud	puutud =puutu  (PlN  >puutu !01_A	et	f	\N
161053	puutud	"puutu %puu  )TU2_kA  <puu ;26_S	et	f	\N
161054	puutud	puutud =puutu  (IndPrSg2  >puutuma !27_V	et	f	\N
161059	nainevanemad	?nainevanemad =nainevanema  (PlN  >nainevanem !02_A	et	f	\N
161085	ortograafia	ortograafia =ortograafia  (SgN  >ortograafia !01_S	et	f	\N
161086	ortograafia	ortograafia =ortograafia  (SgG  >ortograafia !01_S	et	f	\N
161089	rektsioonivigade	### rektsioonivigade	et	f	\N
161103	ninataga	### ninataga	et	f	\N
161112	kaheteistkümneks	?kaheteistkümneks =kaheteistkümne  (PlTr  >kaheteistkümn !22_S	et	f	\N
161113	kaheteistkümneks	?kaheteistkümneks =kümne  (PlTr  >kahe+teist+kümn !22_S	et	f	\N
161114	kaheteistkümneks	?kaheteistkümneks =teistkümne  (PlTr  >kahe+teistkümn !22_S	et	f	\N
161156	tingivat	tingivat =tingi  (KvtPrPs  >tingima !28_V	et	f	\N
161157	tingivat	tingivat =tingiva  (SgP  >tingiv !02_A	et	f	\N
161158	tingivat	"tingiv %tingi  )V_vA  <tingima ;28_V	et	f	\N
161159	enneminevikku	enneminevikku =minevikku  (SgP  >enne+minevik !25_S	et	f	\N
161160	enneminevikku	enneminevikku =minevikku  (SgAdt  >enne+minevik !25_S	et	f	\N
161161	jätkuv	jätkuv =jätku  (PtsPrPs  >jätkuma !27_V	et	f	\N
161162	jätkuv	jätkuv =jätkuv  (SgN  >jätkuv !02_A	et	f	\N
161163	jätkuv	"jätkuv %jätku  )V_vA  <jätkuma ;27_V	et	f	\N
161164	naited	?naited =naite  (PlN  >naide !06_S	et	f	\N
161165	naited	?naited =naite  (IndPrSg2  >naitema !27_V	et	f	\N
161170	elanikuarv	?elanikuarv =elanikuarv  (SgN  >elanikuarv !22_S	et	f	\N
161171	ortograafiline	?ortograafiline =ortograafiline  (SgN  >ortograafiline !12_A	et	f	\N
161172	ortograafiline	?ortograafiline =ortograafiline  (PlP  >ortograafilin !19_S	et	f	\N
161182	kokkuvote	?kokkuvote =kokkuvo  (PlG  >kokkuvo !01_S	et	f	\N
161183	kokkuvote	?kokkuvote =vote  (SgN  >kokku+vote !06_S	et	f	\N
161184	emakeelemõjutustest	emakeelemõjutustest =test  (SgN  >ema+keele+mõjutus+test !22_S	et	f	\N
161186	emakeelemõjutustest	emakeelemõjutustest =tuste  (PlEl  >ema+keele+mõju+tust !22_S	et	f	\N
161188	emakeelemõjutustest	emakeelemõjutustest =mõjutus  (PlEl  >ema+keele+mõjutus !11_S	et	f	\N
161189	emakeelemõjutustest	"ema+keele+mõjutus %mõju  )TUS2_aS  <ema+keele+mõju ;17_S	et	f	\N
161242	eksitus	eksitus =eksitu  (SgIn  >eksitu !01_AS	et	f	\N
161244	eksitus	"eksitu %eksi  )TU1_vS  <eksima ;28_V	et	f	\N
161246	eksitus	eksitus =eksitus  (SgN  >eksitus !11_S	et	f	\N
161247	eksitus	"eksitus %eksita  )US_vS  <eksitama ;27_V	et	f	\N
161248	eksitus	"eksitus %eksi  )TUS1_aS  <eksima ;28_V	et	f	\N
161256	eksimist	eksimist =eksimis  (SgP  >eksimine !12_S	et	f	\N
161257	eksimist	"eksimine %eksi  )MINE_vS  <eksima ;28_V	et	f	\N
161262	kõrvaldatav	kõrvaldatav =kõrvalda  (PtsPrIps  >kõrvaldama !27_V	et	f	\N
161263	kõrvaldatav	kõrvaldatav =kõrvaldatav  (SgN  >kõrvaldatav !02_AS	et	f	\N
161264	kõrvaldatav	"kõrvaldatav %kõrvalda  )TAV_vAS  <kõrvaldama ;27_V	et	f	\N
161269	hindamisel	hindamisel =hindamise  (SgAd  >hindamine !12_S	et	f	\N
161270	hindamisel	"hindamine %hinda  )MINE_vS  <hindama ;29_V	et	f	\N
161284	algaja	algaja =algaja  (SgN  >algaja !01_S	et	f	\N
161285	algaja	"algaja %alga  )JA_vS  <algama ;29_V	et	f	\N
161286	algaja	algaja =algaja  (SgG  >algaja !01_S	et	f	\N
161287	algaja	algaja =aja  (SgG  >alg+aeg !22_S	et	f	\N
161293	hullemaks	hullemaks =hullema  (SgTr  >hullem !02_A	et	f	\N
161294	hullemaks	"hullem %hulle  )M_cA  <hull ;22_AS	et	f	\N
161295	hullemaks	hullemaks =ema  (SgTr  >hull+ema !17_S	et	f	\N
161300	õppija	õppija =õppija  (SgN  >õppija !01_S	et	f	\N
161301	õppija	"õppija %õppi  )JA_vS  <õppima ;28_V	et	f	\N
161302	õppija	õppija =õppija  (SgG  >õppija !01_S	et	f	\N
161312	kuuldav	kuuldav =kuul  (PtsPrIps  >kuulma !33_V	et	f	\N
161313	kuuldav	kuuldav =kuuldav  (SgN  >kuuldav !02_A	et	f	\N
161314	kuuldav	"kuuldav %kuul  )TAV_vAS  <kuulma ;33_V	et	f	\N
161315	omadus	omadus =omadus  (SgN  >omadus !11_S	et	f	\N
161316	omadus	"omadus %oma  )US_aS  <oma ;17_A	et	f	\N
161321	kirjalikku	kirjalikku =kirjalikku  (SgP  >kirjalik !25_A	et	f	\N
161322	kirjalikku	kirjalikku =kirjalikku  (SgAdt  >kirjalik !25_A	et	f	\N
161335	ansablid	?ansablid =ansabli  (PlN  >ansabli !01_S	et	f	\N
161336	ansablid	?ansablid =ansabli  (IndPrSg2  >ansaplima !28_V	et	f	\N
161035	üllatavalt	"üllatavalt %üllata  )VALT_mD  <üllatama ;27_V	et	f	\N
161036	üllatavalt	üllatavalt =tava  (SgAbl  >ülla+tava !17_S	et	f	\N
161042	käändevalik	?käändevalik =käändevalik  (SgN  >käändevalik !25_A	et	f	\N
161043	käändevalik	?käändevalik =evalik  (SgN  >käänd+evalik !25_A	et	f	\N
161046	käände	käände =käände  (SgG  >kääne !06_S	et	f	\N
161047	käände	käände =käände  (PlP  >käänd !22_S	et	f	\N
161048	etenduseid	?etenduseid =etendusei  (PlN  >etendusei !26_S	et	f	\N
161049	etenduseid	?etenduseid =etendusei  (SgP  >etendusei !26_S	et	f	\N
161050	kasutamist	kasutamist =kasutamis  (SgP  >kasutamine !12_S	et	f	\N
161051	kasutamist	"kasutamine %kasuta  )MINE_vS  <kasutama ;27_V	et	f	\N
161090	ühildumine	ühildumine =ühildumine  (SgN  >ühildumine !12_S	et	f	\N
161091	ühildumine	"ühildumine %ühildu  )MINE_vS  <ühilduma ;27_V	et	f	\N
161107	mordvas	?mordvas =mordva  (SgIn  >mordev !02_A	et	f	\N
161108	mordvas	?mordvas =mordva  (IndIpfSg3  >mordvama !29_V	et	f	\N
161109	mordvas	?mordvas =mordvas  (SgN  >mordvas !07_S	et	f	\N
161115	vältimiseks	vältimiseks =vältimise  (SgTr  >vältimine !12_S	et	f	\N
161116	vältimiseks	"vältimine %välti  )MINE_vS  <vältima ;28_V	et	f	\N
161119	rektsiooni	rektsiooni =rektsiooni  (SgG  >rektsioon !22_S	et	f	\N
161120	rektsiooni	rektsiooni =rektsiooni  (SgP  >rektsioon !22_S	et	f	\N
161121	rektsiooni	rektsiooni =rektsiooni  (SgAdt  >rektsioon !22_S	et	f	\N
161125	estraadimuusika	estraadimuusika =muusika  (SgN  >estraadi+muusika !01_S	et	f	\N
161126	estraadimuusika	estraadimuusika =muusika  (SgG  >estraadi+muusika !01_S	et	f	\N
161130	viiv	viiv =vii  (PtsPrPs  >viima !38_V	et	f	\N
161131	viiv	viiv =viiv  (SgN  >viiv !02_A	et	f	\N
161132	viiv	"viiv %vii  )V_vA  <viima ;38_V	et	f	\N
161133	viiv	viiv =viiv  (SgN  >viiv !22_S	et	f	\N
161147	lihtminevikku	lihtminevikku =minevikku  (SgP  >liht+minevik !25_S	et	f	\N
161148	lihtminevikku	lihtminevikku =minevikku  (SgAdt  >liht+minevik !25_S	et	f	\N
161178	järgmiselt	järgmiselt =järgmise  (SgAbl  >järgmine !12?10_A	et	f	\N
161179	järgmiselt	järgmiselt =järgmiselt  (ID  >järgmiselt !41_D	et	f	\N
161180	järgmiselt	"järgmiselt %järgmise  )LT_mD  <järgmine ;10_A	et	f	\N
161181	järgmiselt	"järgmiselt %järgmise  )LT_mD  <järgmine ;12_A	et	f	\N
161191	jana	?jana =jana  (SgN  >jana !17_S	et	f	\N
161192	jana	?jana =jana  (SgG  >jana !17_S	et	f	\N
161193	jana	?jana =jana  (SgP  >jana !17_S	et	f	\N
161194	jana	?jana =jana  (IndPrPs_  >janama !27_V	et	f	\N
161195	jana	?jana =jana  (ImpPrSg2  >janama !27_V	et	f	\N
161223	registreerimine	registreerimine =registreerimine  (SgN  >registreerimine !12_S	et	f	\N
161224	registreerimine	"registreerimine %registreeri  )MINE_vS  <registreerima ;28_V	et	f	\N
161231	normist	normist =normi  (SgEl  >norm !22_S	et	f	\N
161232	normist	normist =normis  (SgP  >normine !10_A	et	f	\N
161233	normist	"normine %normi  )NE_aA  <norm ;22_S	et	f	\N
161251	defineerinud	defineerinud =defineeri  (PtsPtPs  >defineerima !28_V	et	f	\N
161252	defineerinud	defineerinud =defineerinu  (PlN  >defineerinu !01_S	et	f	\N
161253	defineerinud	"defineerinu %defineeri  )NU_vS  <defineerima ;28_V	et	f	\N
161254	defineerinud	defineerinud =defineerinud  (ID  >defineerinud !41_A	et	f	\N
161255	defineerinud	"defineerinud %defineeri  )NUD_vA  <defineerima ;28_V	et	f	\N
161260	eksimus	eksimus =eksimus  (SgN  >eksimus !11_S	et	f	\N
161261	eksimus	eksimus =imu  (SgIn  >eks+imu !17_S	et	f	\N
161271	kõnelemisel	kõnelemisel =kõnelemise  (SgAd  >kõnelemine !12_S	et	f	\N
161272	kõnelemisel	"kõnelemine %kõnele  )MINE_vS  <kõnelema ;27_V	et	f	\N
161273	kõnelemisel	"kõnelemine %kõnele  )MINE_vS  <kõnelema ;31_V	et	f	\N
161277	kasutamisele	kasutamisele =kasutamise  (SgAll  >kasutamine !12_S	et	f	\N
161278	kasutamisele	"kasutamine %kasuta  )MINE_vS  <kasutama ;27_V	et	f	\N
161281	uurimismaterjali	uurimismaterjali =materjali  (SgG  >uurimis+materjal !19_S	et	f	\N
161282	uurimismaterjali	uurimismaterjali =materjali  (SgP  >uurimis+materjal !19_S	et	f	\N
161283	uurimismaterjali	uurimismaterjali =materjali  (SgAdt  >uurimis+materjal !19_S	et	f	\N
161290	ebaloogilised	ebaloogilised =loogilise  (PlN  >eba+loogiline !12_A	et	f	\N
161292	ebaloogilised	"eba+loogiline %loogi  )LINE_aA  <eba+loog ;22_S	et	f	\N
161303	sõnatuks	sõnatuks =sõna  (KndPtIps  >sõnama !27_V	et	f	\N
161304	sõnatuks	sõnatuks =sõnatu  (SgTr  >sõnatu !01_AS	et	f	\N
161305	sõnatuks	"sõnatu %sõna  )TU1_vS  <sõnama ;27_V	et	f	\N
161306	sõnatuks	"sõnatu %sõna  )TU2_kA  <sõna ;17_S	et	f	\N
161307	sõnatuks	sõnatuks =tuks  (SgN  >sõna+tuks !22_S	et	f	\N
161331	vanamuusika	vanamuusika =muusika  (SgN  >vana+muusika !01_S	et	f	\N
161332	vanamuusika	vanamuusika =muusika  (SgG  >vana+muusika !01_S	et	f	\N
161344	liitsõna	liitsõna =sõna  (SgN  >liit+sõna !17_S	et	f	\N
161345	liitsõna	liitsõna =sõna  (SgG  >liit+sõna !17_S	et	f	\N
161346	liitsõna	liitsõna =sõna  (SgP  >liit+sõna !17_S	et	f	\N
161363	kurjus	kurjus =kurju  (IndIpfSg3  >kurjuma !27_V	et	f	\N
161364	kurjus	kurjus =kurjus  (SgN  >kurjus !11~09_S	et	f	\N
161365	kurjus	"kurjus %kurj  )US_aS  <kuri ;24_A	et	f	\N
161390	paksum	?paksum =paksum  (SgN  >paksum !02_S	et	f	\N
161401	truuim	?truuim =truuim  (SgN  >truuim !02_S	et	f	\N
161187	paljuski	paljuski =paljus  (SgN^  >paljus !11~09_S	et	f	\N
161190	paljuski	"paljus %palja  )US_aS^  <paljas ;07_A	et	f	\N
161200	jutustatkse	?jutustatkse =jutustatkse  (SgG  >jutustatkne !02_A	et	f	\N
161201	jutustatkse	?jutustatkse =statkse  (SgN  >jutu+statkse !06_S	et	f	\N
161202	jutustatkse	?jutustatkse =statkse  (SgG  >jutu+statkne !02_A	et	f	\N
161203	jutustatkse	?jutustatkse =statkse  (SgG  >jutu+statkse !06_S	et	f	\N
161204	jutustatkse	?jutustatkse =statkse  (PlP  >jutu+statks !22_S	et	f	\N
161227	seletamine	seletamine =seletamine  (SgN  >seletamine !12_S	et	f	\N
161228	seletamine	"seletamine %seleta  )MINE_vS  <seletama ;27_V	et	f	\N
161265	raskusastet	raskusastet =aste  (SgP  >raskus+aste !05_S	et	f	\N
161266	raskusastet	raskusastet =aste  (SgP  >raskus+aste !06_S	et	f	\N
161323	petajad	?petajad =petaja  (PlN  >petaja !01_S	et	f	\N
161324	petajad	?petajad =petaja  (PlN  >petajas !02_A	et	f	\N
161325	kõigidest	?kõigidest =kõigi  (PlEl  >kõigi !16_S	et	f	\N
161326	kõigidest	?kõigidest =kõigi  (PlEl  >kõig !22_S	et	f	\N
161327	kõigidest	?kõigidest =kõigides  (SgP  >kõigidene !12_A	et	f	\N
161333	vanamuusika	vanamuusika =muusika  (SgN  >vana+muusika !01_S	et	f	\N
161334	vanamuusika	vanamuusika =muusika  (SgG  >vana+muusika !01_S	et	f	\N
161337	parem-mulle	parem-mulle =mu  (SgAll  >parem-ma !00_P	et	f	\N
161338	parem-mulle	parem-mulle =mulle  (SgN  >parem-mulle !06_S	et	f	\N
161339	parem-mulle	parem-mulle =mulle  (PlP  >parem-mull !22_S	et	f	\N
161358	sihiliste	sihiliste =sihilis  (PlG  >sihiline !12_A	et	f	\N
161359	sihiliste	"sihiline %sihi  )LINE_aA  <siht ;22_S	et	f	\N
161362	mitmussõnade	### mitmussõnade	et	f	\N
161368	ainsuses	ainsuses =ainsuse  (SgIn  >ainsus !11~09_S	et	f	\N
161369	ainsuses	"ainsus %ainsa  )US_aS  <ainus ;03_AS	et	f	\N
161378	suurtem	?suurtem =suurtem  (SgN  >suurtem !02_A	et	f	\N
161388	paksem	paksem =paksem  (SgN  >paksem !02_A	et	f	\N
161389	paksem	"paksem %pakse  )M_cA  <paks ;22_AS	et	f	\N
161408	aastaarve	aastaarve =arve  (SgN  >aasta+arve !06_S	et	f	\N
161409	aastaarve	aastaarve =arve  (SgG  >aasta+arve !06_S	et	f	\N
161410	aastaarve	aastaarve =arve  (PlP  >aasta+arv !22_S	et	f	\N
161421	söömaega	?söömaega =söömae  (SgKom  >söömae !26_S	et	f	\N
161427	lõhkemiseni	lõhkemiseni =lõhkemise  (SgTer  >lõhkemine !12_S	et	f	\N
161428	lõhkemiseni	"lõhkemine %lõhke  )MINE_vS  <lõhkema ;27_V	et	f	\N
161459	enesekohases	enesekohases =kohase  (SgIn  >enese+kohane !10_A	et	f	\N
161460	enesekohases	"enese+kohane %koha  )NE_aA  <enese+koha ;17_S	et	f	\N
161461	enesekohases	"enese+kohane %koha  )NE_aA  <enese+koht ;22_S	et	f	\N
161469	enesel	enesel =enese  (SgAd  >enese !00_P	et	f	\N
161470	enesel	enesel =enese  (SgAd  >ise !00_P	et	f	\N
161474	ühiskeeles	ühiskeeles =keele  (SgIn  >ühis+keel !13_S	et	f	\N
161475	ühiskeeles	ühiskeeles =keele  (PlIn  >ühis+keeld !22_S	et	f	\N
161493	morfeemvarianti	?morfeemvarianti =morfeemvarianti  (SgP  >morfeemvariant !22_S	et	f	\N
161494	morfeemvarianti	?morfeemvarianti =morfeemvarianti  (SgAdt  >morfeemvariant !22_S	et	f	\N
161499	emat	?emat =emat  (SgN  >emat !02_S	et	f	\N
161501	sid	sid =si  (PlN  >si !26_S	et	f	\N
161502	sid	sid =si  (SgP  >si !26_S	et	f	\N
161523	pestaksin	?pestaksin =pesta  (KndPrSg1  >pestama !29_V	et	f	\N
161524	pestaksin	?pestaksin =pestaksi  (IndPrSg1  >pestaksima !28_V	et	f	\N
161525	pestaksin	?pestaksin =pestaksin  (SgN  >pestaksin !19_S	et	f	\N
161575	toodakse	?toodakse =toodakse  (SgG  >toodakne !02_A	et	f	\N
161578	raskematest	raskematest =raskema  (PlEl  >raskem !02_A	et	f	\N
161579	raskematest	"raskem %raske  )M_cA  <raske ;01_A	et	f	\N
161580	raskematest	raskematest =mate  (SgEl  >raske+mate !16_S	et	f	\N
161581	raskematest	raskematest =mate  (PlEl  >raske+matt !22_SA	et	f	\N
161582	raskematest	raskematest =mates  (SgP  >raske+matene !10_A	et	f	\N
161583	raskematest	"raske+matene %mate  )NE_aA  <raske+mate ;16_S	et	f	\N
161599	olümpia	olümpia =olümpia  (SgN  >olümpia !01_S	et	f	\N
161600	olümpia	olümpia =olümpia  (SgG  >olümpia !01_S	et	f	\N
161601	viistuhat	?viistuhat =viistuha  (SgP  >viistuha !01_S	et	f	\N
161602	kümmend	kümmend =kümmend  (SgP  >kümmend !05_N	et	f	\N
161603	kümmend	kümmend =kümmend  (SgN  >kümmend !05_N	et	f	\N
161608	poolemiljardik	?poolemiljardik =poolemiljardik  (SgN  >poolemiljardik !25_S	et	f	\N
161609	poolemiljardik	?poolemiljardik =emiljardik  (SgN  >pool+emiljardik !25_S	et	f	\N
161618	olevaks	olevaks =oleva  (SgTr  >olev !02_A	et	f	\N
161619	olevaks	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
161629	ühildumise	ühildumise =ühildumise  (SgG  >ühildumine !12_S	et	f	\N
161630	ühildumise	"ühildumine %ühildu  )MINE_vS  <ühilduma ;27_V	et	f	\N
161637	tangid	tangid =tangi  (PlN  >tang !22_S	et	f	\N
161638	tangid	tangid =tangi  (IndPrSg2  >tankima !28_V	et	f	\N
161641	õpiksid	õpiksid =õpi  (KndPrSg2  >õppima !28_V	et	f	\N
161642	õpiksid	õpiksid =õpi  (KndPrPl3  >õppima !28_V	et	f	\N
161684	kuulajutud	kuulajutud =ajutu  (PlN  >kuul+ajutu !01_AS	et	f	\N
161685	kuulajutud	"kuul+ajutu %aju  )TU2_kA  <kuul+aju ;17_S	et	f	\N
161686	kuulajutud	kuulajutud =lajutu  (PlN  >kuu+lajutu !01_AS	et	f	\N
161687	kuulajutud	"kuu+lajutu %laju  )TU2_kA  <kuu+laju ;17_S	et	f	\N
161212	metsanainest	?metsanainest =anaines  (SgP  >mets+anainene !12_A	et	f	\N
161219	kirjaid	?kirjaid =kirja  (PlP  >kirjas !02_A	et	f	\N
161220	kirjaid	?kirjaid =kirjai  (PlN  >kirjai !26_S	et	f	\N
161221	kirjaid	?kirjaid =kirjai  (SgP  >kirjai !26_S	et	f	\N
161222	kirjaid	?kirjaid =kirjaid  (SgN  >kirjaid !22_S	et	f	\N
161229	kehtivast	kehtivast =kehtiva  (SgEl  >kehtiv !02_A	et	f	\N
161230	kehtivast	"kehtiv %kehti  )V_vA  <kehtima ;27_V	et	f	\N
161236	vääratus	vääratus =vääratu  (SgIn  >vääratu !01_AS	et	f	\N
161237	vääratus	"vääratu %väära  )TU1_vS  <väärama ;29_V	et	f	\N
161238	vääratus	"vääratu %väära  )TU2_kA  <väär ;22_S	et	f	\N
161239	vääratus	vääratus =vääratus  (SgN  >vääratus !11_S	et	f	\N
161240	vääratus	"vääratus %väärata  )US_vS  <vääratama ;27_V	et	f	\N
161241	vääratus	"vääratus %väära  )TUS1_aS  <väärama ;29_V	et	f	\N
161243	vääratus	"vääratus %väära  )TUS2_aS  <väär ;22_S	et	f	\N
161245	vääratus	vääratus =atu  (SgIn  >väär+att !22_S	et	f	\N
161258	puudumisele	puudumisele =puudumise  (SgAll  >puudumine !12_S	et	f	\N
161259	puudumisele	"puudumine %puudu  )MINE_vS  <puuduma ;27_V	et	f	\N
161267	lihtsamad	lihtsamad =lihtsama  (PlN  >lihtsam !02_A	et	f	\N
161268	lihtsamad	"lihtsam %lihtsa  )M_cA  <lihtne ;02_A	et	f	\N
161274	hälbiva	hälbiva =hälbiva  (SgG  >hälbiv !02_A	et	f	\N
161275	hälbiva	"hälbiv %hälbi  )V_vA  <hälbima ;27_V	et	f	\N
161276	hälbiva	"hälbiv %hälbi  )V_vA  <hälbima ;28_V	et	f	\N
161279	juhendajat	juhendajat =juhendaja  (SgP  >juhendaja !01_S	et	f	\N
161280	juhendajat	"juhendaja %juhenda  )JA_vS  <juhendama ;27_V	et	f	\N
161288	arusaamatutel	arusaamatutel =tute  (PlAd  >aru+saama+tutt !22_S	et	f	\N
161289	arusaamatutel	arusaamatutel =saamatu  (PlAd  >aru+saamatu !01_A	et	f	\N
161291	arusaamatutel	"aru+saamatu %saama  )TU2_kA  <aru+saam ;22_S	et	f	\N
161317	nelja-kolme	nelja-kolme =kolme  (SgG  >nelja-kolm !22_N	et	f	\N
161318	nelja-kolme	nelja-kolme =kolme  (SgP  >nelja-kolm !22_N	et	f	\N
161319	nelja-kolme	nelja-kolme =kolme  (SgAdt  >nelja-kolm !22_N	et	f	\N
161320	nelja-kolme	nelja-kolme =kolme  (PlP  >nelja-kolm !22_N	et	f	\N
161328	ebaselge	ebaselge =selge  (SgN  >eba+selge !01_A	et	f	\N
161329	ebaselge	ebaselge =selge  (SgG  >eba+selge !01_A	et	f	\N
161330	ebaselge	ebaselge =selge  (PlP  >eba+selg !22_S	et	f	\N
161340	vigaseid	vigaseid =vigase  (PlP  >vigane !10_AS	et	f	\N
161341	vigaseid	"vigane %viga  )NE_aA  <viga ;18_S	et	f	\N
161360	ainsus-	ainsus- =ainsus  (SgN  >ainsus !11~09_S	et	f	\N
161361	ainsus-	"ainsus %ainsa  )US_aS  <ainus ;03_AS	et	f	\N
161366	headus	headus =headus  (SgN  >headus !11~09_S	et	f	\N
161367	headus	"headus %hea  )US_aS  <hea ;26_A	et	f	\N
161382	korralikem	korralikem =korralikem  (SgN  >korralikem !02_A	et	f	\N
161383	korralikem	"korralikem %korralike  )IM_sA  <korralik ;25_A	et	f	\N
161391	kurjem	kurjem =kurjem  (SgN  >kurjem !02_A	et	f	\N
161392	kurjem	"kurjem %kurje  )M_cA  <kuri ;24_A	et	f	\N
161396	kalliim	?kalliim =kalliim  (SgN  >kalliim !22_S	et	f	\N
161402	truim	truim =truim  (SgN  >truim !02_A	et	f	\N
161403	truim	"truim %tru  )IM_sA  <truu ;26_A	et	f	\N
161424	määramäärsõna	### määramäärsõna	et	f	\N
161429	rajava	rajava =rajava  (SgG  >rajav !02_A	et	f	\N
161430	rajava	"rajav %raja  )V_vA  <rajama ;27_V	et	f	\N
161433	paradigmaatiliselt	paradigmaatiliselt =paradigmaatilise  (SgAbl  >paradigmaatiline !12_A	et	f	\N
161434	paradigmaatiliselt	paradigmaatiliselt =paradigmaatiliselt  (ID  >paradigmaatiliselt !41_D	et	f	\N
161435	paradigmaatiliselt	"paradigmaatiliselt %paradigmaatilise  )LT_mD  <paradigmaatiline ;12_A	et	f	\N
161455	keerulises	keerulises =keerulise  (SgIn  >keeruline !12_A	et	f	\N
161456	keerulises	"keeruline %keeru  )LINE_aA  <keerd ;22_SA	et	f	\N
161464	asendamine	asendamine =asendamine  (SgN  >asendamine !12_S	et	f	\N
161465	asendamine	"asendamine %asenda  )MINE_vS  <asendama ;27_V	et	f	\N
161466	enesekohasustähendusele	?enesekohasustähendusele =enesekohasustähenduse  (SgAll  >enesekohasustähendus !11_S	et	f	\N
161467	enesekohasustähendusele	?enesekohasustähendusele =sustähenduse  (SgAll  >enese+koha+sustähendus !11_S	et	f	\N
161468	enesekohasustähendusele	?enesekohasustähendusele =kohasustähenduse  (SgAll  >enese+kohasustähendus !11_S	et	f	\N
161496	suuret	?suuret =suure  (SgP  >suure !06_S	et	f	\N
161500	kahet	?kahet =kahe  (SgP  >kahe !16_S	et	f	\N
161503	siileid	?siileid =siile  (PlP  >siile !06_S	et	f	\N
161504	siileid	?siileid =siilei  (PlN  >siilei !26_S	et	f	\N
161505	siileid	?siileid =siilei  (SgP  >siilei !26_S	et	f	\N
161506	siileid	?siileid =siileid  (SgN  >siileid !22_S	et	f	\N
161511	sõpraid	?sõpraid =sõprai  (PlN  >sõprai !26_S	et	f	\N
161512	sõpraid	?sõpraid =sõprai  (SgP  >sõprai !26_S	et	f	\N
161513	sõpraid	?sõpraid =sõpraid  (SgN  >sõpraid !22_S	et	f	\N
161526	puhaksime	?puhaksime =puha  (KndPrPl1  >puhama !27_V	et	f	\N
161527	puhaksime	?puhaksime =puhaksi  (IndPrPl1  >puhaksima !28_V	et	f	\N
161540	segadust	segadust =segadus  (SgP  >segadus !11_S	et	f	\N
161541	segadust	segadust =dust  (SgN  >sega+dust !22_S	et	f	\N
161544	tahakse	?tahakse =tahakse  (SgG  >tahakne !02_A	et	f	\N
161573	söödakse	?söödakse =söödakse  (SgG  >söödakne !02_A	et	f	\N
161296	kõnelev	kõnelev =kõnele  (PtsPrPs  >kõnelema !31~27_V	et	f	\N
161297	kõnelev	kõnelev =kõnelev  (SgN  >kõnelev !02_A	et	f	\N
161298	kõnelev	"kõnelev %kõnele  )V_vA  <kõnelema ;27_V	et	f	\N
161299	kõnelev	"kõnelev %kõnele  )V_vA  <kõnelema ;31_V	et	f	\N
161308	kirjakeelest	kirjakeelest =keele  (SgEl  >kirja+keel !13_S	et	f	\N
161309	kirjakeelest	kirjakeelest =keele  (PlEl  >kirja+keeld !22_S	et	f	\N
161310	kirjakeelest	kirjakeelest =keeles  (SgP  >kirja+keelene !10_A	et	f	\N
161311	kirjakeelest	"kirja+keelene %keele  )NE_aA  <kirja+keel ;13_S	et	f	\N
161342	sagedasem	sagedasem =sagedasem  (SgN  >sagedasem !02_A	et	f	\N
161343	sagedasem	"sagedasem %sagedase  )M_cA  <sagedane ;12_A	et	f	\N
161347	siirdistutama	?siirdistutama =siirdistu  (SupIps  >siirdistuma !27_V	et	f	\N
161348	siirdistutama	?siirdistutama =siirdistuta  (Sup  >siirdistutama !27_V	et	f	\N
161349	siirdistutama	?siirdistutama =siirdistutama  (SgG  >siirdistutam !02_A	et	f	\N
161351	allaandma	?allaandma =allaandma  (SgN  >allaandma !01_S	et	f	\N
161352	allaandma	?allaandma =allaandma  (SgG  >allaandma !01_S	et	f	\N
161355	enesekohaste	enesekohaste =kohas  (PlG  >enese+kohane !10_A	et	f	\N
161356	enesekohaste	"enese+kohane %koha  )NE_aA  <enese+koha ;17_S	et	f	\N
161357	enesekohaste	"enese+kohane %koha  )NE_aA  <enese+koht ;22_S	et	f	\N
161370	omaduss	?omaduss =omaduss  (SgN  >omaduss !22_S	et	f	\N
161371	omaduss	?omaduss =duss  (SgN  >oma+duss !22_S	et	f	\N
161372	määrsõnade	### määrsõnade	et	f	\N
161373	halvemini	halvemini =halvemi  (SgTer  >halvem !02_A	et	f	\N
161374	halvemini	"halvem %halve  )M_cA  <halb ;22_A	et	f	\N
161379	kauunisam	?kauunisam =kauunisam  (SgN  >kauunisam !02_A	et	f	\N
161387	pikam	?pikam =pikam  (SgN  >pikam !02_A	et	f	\N
161393	kurjam	?kurjam =kurjam  (SgN  >kurjam !02_A	et	f	\N
161394	i-ülivõrre	i-ülivõrre =võrre  (SgN  >i-üli+võrre !06_S	et	f	\N
161395	i-ülivõrre	i-ülivõrre =võrre  (PlP  >i-üli+võrr !22_S	et	f	\N
161400	kalliim	?kalliim =kalliim  (SgN  >kalliim !22_S	et	f	\N
161422	lõhkemiseni	lõhkemiseni =lõhkemise  (SgTer  >lõhkemine !12_S	et	f	\N
161423	lõhkemiseni	"lõhkemine %lõhke  )MINE_vS  <lõhkema ;27_V	et	f	\N
161445	tüve	tüve =tüve  (SgG  >tüvi !20_S	et	f	\N
161446	tüve	tüve =tüve  (SgP  >tüvi !20_S	et	f	\N
161478	kaassõna	kaassõna =sõna  (SgN  >kaas+sõna !17_S	et	f	\N
161479	kaassõna	kaassõna =sõna  (SgG  >kaas+sõna !17_S	et	f	\N
161480	kaassõna	kaassõna =sõna  (SgP  >kaas+sõna !17_S	et	f	\N
161481	sidesõna	sidesõna =sõna  (SgN  >side+sõna !17_S	et	f	\N
161482	sidesõna	sidesõna =sõna  (SgG  >side+sõna !17_S	et	f	\N
161483	sidesõna	sidesõna =sõna  (SgP  >side+sõna !17_S	et	f	\N
161497	küünlat	?küünlat =küünla  (SgP  >küünla !01_S	et	f	\N
161498	küünlat	?küünlat =küünlat  (SgN  >küünlat !02_S	et	f	\N
161507	sõprusid	?sõprusid =sõpru  (IndIpfSg2  >sõpruma !27_V	et	f	\N
161508	sõprusid	?sõprusid =sõpru  (IndIpfPl3  >sõpruma !27_V	et	f	\N
161509	koeraid	koeraid =rai  (PlN  >koe+rai !26_S	et	f	\N
161510	koeraid	koeraid =rai  (SgP  >koe+rai !26_S	et	f	\N
161514	täisminevikku	täisminevikku =minevikku  (SgP  >täis+minevik !25_S	et	f	\N
161515	täisminevikku	täisminevikku =minevikku  (SgAdt  >täis+minevik !25_S	et	f	\N
161516	tingiv	tingiv =tingi  (PtsPrPs  >tingima !28_V	et	f	\N
161517	tingiv	tingiv =tingiv  (SgN  >tingiv !02_A	et	f	\N
161518	tingiv	"tingiv %tingi  )V_vA  <tingima ;28_V	et	f	\N
161519	laadivaheldus	?laadivaheldus =laadivaheldu  (IndIpfSg3  >laadivahelduma !27_V	et	f	\N
161520	laadivaheldus	?laadivaheldus =laadivaheldus  (SgN  >laadivaheldus !11_S	et	f	\N
161521	tegiksime	?tegiksime =tegi  (KndPrPl1  >tegima !27_V	et	f	\N
161522	tegiksime	?tegiksime =tegiksi  (IndPrPl1  >tegiksima !28_V	et	f	\N
161533	tehnud	?tehnud =tehnu  (PlN  >tehnu !01_S	et	f	\N
161534	tehnud	?tehnud =tehnu  (IndPrSg2  >tehnuma !27_V	et	f	\N
161535	tehnud	?tehnud =tehnud  (ID  >tehnud !41_A	et	f	\N
161562	akse	?akse =akse  (SgN  >akse !06_S	et	f	\N
161564	akse	?akse =akse  (SgG  >akse !06_S	et	f	\N
161566	akse	?akse =akse  (PlP  >aks !22_S	et	f	\N
161568	akse	?akse =akse  (IndPrPs_  >aksema !27_V	et	f	\N
161569	akse	?akse =akse  (ImpPrSg2  >aksema !27_V	et	f	\N
161574	löödakse	?löödakse =löödakse  (SgG  >löödakne !02_A	et	f	\N
161584	kuulatama	kuulatama =kuula  (SupIps  >kuulama !29_V	et	f	\N
161585	kuulatama	kuulatama =kuulata  (Sup  >kuulatama !27_V	et	f	\N
161586	kelles	kelles =kelle  (SgIn  >kes !00_P	et	f	\N
161587	kelles	kelles =kelle  (PlIn  >kell !22_S	et	f	\N
161590	erista	erista =erista  (IndPrPs_  >eristama !27_V	et	f	\N
161591	erista	erista =erista  (ImpPrSg2  >eristama !27_V	et	f	\N
161592	üksikjuhtimiga	?üksikjuhtimiga =üksikjuhtimi  (SgKom  >üksikjuhtim !02_A	et	f	\N
161593	üksikjuhtimiga	?üksikjuhtimiga =imi  (SgKom  >üksik+juht+imi !17_S	et	f	\N
161594	üksikjuhtimiga	?üksikjuhtimiga =juhtimi  (SgKom  >üksik+juhtimi !01_S	et	f	\N
161595	üksikjuhtimiga	?üksikjuhtimiga =juhtimi  (SgKom  >üksik+juhtim !02_A	et	f	\N
161596	üksikjuhtimiga	?üksikjuhtimiga =ikjuhtimi  (SgKom  >üks+ikjuhtim !02_A	et	f	\N
161610	koolimajast	koolimajast =maja  (SgEl  >kooli+maja !17_S	et	f	\N
161350	siird	?siird =siird  (SgN  >siird !22_S	et	f	\N
161353	mahamagama	?mahamagama =mahamagama  (SgG  >mahamagam !02_A	et	f	\N
161354	mahamagama	?mahamagama =magama  (SgG  >maha+magam !02_A	et	f	\N
161375	ohtlikult	ohtlikult =ohtliku  (SgAbl  >ohtlik !25_A	et	f	\N
161376	ohtlikult	ohtlikult =ohtlikult  (ID  >ohtlikult !41_D	et	f	\N
161377	ohtlikult	"ohtlikult %ohtliku  )LT_mD  <ohtlik ;25_A	et	f	\N
161380	korralikum	korralikum =korralikum  (SgN  >korralikum !02_A	et	f	\N
161381	korralikum	"korralikum %korraliku  )M_cA  <korralik ;25_A	et	f	\N
161384	vokaaliteisendus	?vokaaliteisendus =vokaaliteisendu  (IndIpfSg3  >vokaaliteisenduma !27_V	et	f	\N
161385	vokaaliteisendus	?vokaaliteisendus =vokaaliteisendus  (SgN  >vokaaliteisendus !11_S	et	f	\N
161386	vokaaliteisendus	?vokaaliteisendus =iteisendus  (SgN  >vokaal+iteisendus !11_S	et	f	\N
161397	kalleim	kalleim =kalleim  (SgN  >kalleim !02_A	et	f	\N
161398	kalleim	"kalleim %kalle  )IM_sA  <kallis ;05_A	et	f	\N
161399	kalleim	"kalleim %kalle  )IM_sA  <kallis ;07_A	et	f	\N
161404	kuupäevi	kuupäevi =päevi  (SgG  >kuu+päev !22_S	et	f	\N
161405	kuupäevi	kuupäevi =päevi  (SgP  >kuu+päev !22_S	et	f	\N
161406	kuupäevi	kuupäevi =päevi  (SgAdt  >kuu+päev !22_S	et	f	\N
161407	kuupäevi	kuupäevi =päevi  (PlP  >kuu+päev !22_S	et	f	\N
161411	vastamisel	vastamisel =vastamise  (SgAd  >vastamine !12_S	et	f	\N
161412	vastamisel	"vastamine %vasta  )MINE_vS  <vastama ;29_V	et	f	\N
161415	emakeeleski	emakeeleski =keele  (SgIn^  >ema+keel !13_S	et	f	\N
161416	emakeeleski	emakeeleski =keele  (PlIn^  >ema+keeld !22_S	et	f	\N
161420	määrsõnaga	### määrsõnaga	et	f	\N
161425	pungil	pungil =pungi  (PlAd  >pung !22_S	et	f	\N
161426	pungil	pungil =pungil  (ID  >pungil !41_D	et	f	\N
161431	määrsõnavormid	?määrsõnavormid =määrsõnavormi  (PlN  >määrsõnavorm !22_S	et	f	\N
161432	määrsõnavormid	?määrsõnavormid =määrsõnavormi  (IndPrSg2  >määrsõnavormima !28_V	et	f	\N
161447	lukkus	lukkus =lukku  (IndIpfSg3  >lukkuma !27_V	et	f	\N
161448	lukkus	lukkus =lukkus  (ID  >lukkus !41_DA	et	f	\N
161449	tohutus	tohutus =tohutu  (SgIn  >tohutu !01_A	et	f	\N
161450	tohutus	"tohutu %tohu  )TU2_kA  <tohu ;17_S	et	f	\N
161451	tohutus	"tohutu %tohu  )TU2_kA  <toht ;22_S	et	f	\N
161452	tohutus	tohutus =tohutus  (SgN  >tohutus !11_S	et	f	\N
161453	tohutus	"tohutus %tohu  )TUS2_aS  <tohu ;17_S	et	f	\N
161454	tohutus	"tohutus %tohu  )TUS2_aS  <toht ;22_S	et	f	\N
161462	enese-enda	enese-enda =enda  (SgG  >enese-enda !00_P	et	f	\N
161463	enese-enda	enese-enda =enda  (SgG  >enese-ise !00_P	et	f	\N
161484	sisseütlev	sisseütlev =ütle  (PtsPrPs  >sisse+_ütlema !30_V	et	f	\N
161485	sisseütlev	sisseütlev =ütlev  (SgN  >sisse+ütlev !02_A	et	f	\N
161486	metsasse	metsasse =metsa  (SgIll  >mets !22_S	et	f	\N
161487	metsasse	metsasse =asse  (PlP  >mets+ass !22_S	et	f	\N
161488	lõpetatud	lõpetatud =lõpeta  (PtsPtIps  >lõpetama !27_V	et	f	\N
161489	lõpetatud	lõpetatud =lõpetatu  (PlN  >lõpetatu !01_S	et	f	\N
161490	lõpetatud	"lõpetatu %lõpeta  )TU1_vS  <lõpetama ;27_V	et	f	\N
161491	lõpetatud	lõpetatud =lõpetatud  (ID  >lõpetatud !41_A	et	f	\N
161492	lõpetatud	"lõpetatud %lõpeta  )TUD_vA  <lõpetama ;27_V	et	f	\N
161495	kollaset	### kollaset	et	f	\N
161531	umbisikuline	umbisikuline =isikuline  (SgN  >umb+isikuline !12_A	et	f	\N
161532	umbisikuline	"umb+isikuline %isiku  )LINE_aA  <umb+isik ;02_S	et	f	\N
161538	kordus	kordus =kordu  (IndIpfSg3  >korduma !27_V	et	f	\N
161539	kordus	kordus =kordus  (SgN  >kordus !11~09_S	et	f	\N
161549	pöördkonna	pöördkonna =pöördkonna  (SgG  >pöördkond !22_S	et	f	\N
161550	pöördkonna	pöördkonna =konna  (SgG  >pöörd+konn !22_S	et	f	\N
161551	pöördkonna	pöördkonna =konna  (SgP  >pöörd+konn !22_S	et	f	\N
161552	pöördkonna	pöördkonna =konna  (SgAdt  >pöörd+konn !22_S	et	f	\N
161572	joodakse	?joodakse =joodakse  (SgG  >joodakne !02_A	et	f	\N
161597	kingsepatöökoda	kingsepatöökoda =koda  (SgN  >king+sepa+töö+koda !18_S	et	f	\N
161598	kingsepatöökoda	kingsepatöökoda =koda  (SgP  >king+sepa+töö+koda !18_S	et	f	\N
161606	kolmmiljonit	### kolmmiljonit	et	f	\N
161622	infiniitverbi	?infiniitverbi =infiniitverbi  (SgG  >infiniitverp !22_S	et	f	\N
161623	infiniitverbi	?infiniitverbi =infiniitverbi  (SgP  >infiniitverb !22_S	et	f	\N
161624	infiniitverbi	?infiniitverbi =infiniitverbi  (SgAdt  >infiniitverb !22_S	et	f	\N
161625	infiniitverbi	?infiniitverbi =infiniitverbi  (IndPrPs_  >infiniitverpima !28_V	et	f	\N
161626	infiniitverbi	?infiniitverbi =infiniitverbi  (ImpPrSg2  >infiniitverpima !28_V	et	f	\N
161631	öeldistäite	?öeldistäite =öeldistäite  (PlP  >öeldistäit !22_S	et	f	\N
161647	vestlejatena	vestlejatena =vestleja  (PlEs  >vestleja !01_S	et	f	\N
161649	vestlejatena	"vestleja %vestle  )JA_vS  <vestlema ;30_V	et	f	\N
161650	ihkavad	ihkavad =ihka  (IndPrPl3  >ihkama !29_V	et	f	\N
161651	ihkavad	ihkavad =ihkava  (PlN  >ihkav !02_A	et	f	\N
161652	ihkavad	"ihkav %ihka  )V_vA  <ihkama ;29_V	et	f	\N
161667	jacks	?jacks =jacks  (SgN  >jacks !22_S	et	f	\N
161671	kosmosest	kosmosest =kosmose  (SgEl  >kosmos !11~09_S	et	f	\N
161672	kosmosest	kosmosest =kosmoses  (SgP  >kosmosene !12_A	et	f	\N
161673	kosmosest	"kosmosene %kosmose  )NE_aA  <kosmos ;09_S	et	f	\N
161413	kirjutamisel	kirjutamisel =kirjutamise  (SgAd  >kirjutamine !12_S	et	f	\N
161414	kirjutamisel	"kirjutamine %kirjuta  )MINE_vS  <kirjutama ;27_V	et	f	\N
161417	käändevormiga	?käändevormiga =käändevormi  (SgKom  >käändevorm !22_S	et	f	\N
161418	käändevormiga	?käändevormiga =evormi  (SgKom  >käänd+evormi !01_S	et	f	\N
161419	käändevormiga	?käändevormiga =evormi  (SgKom  >käänd+evorm !22_S	et	f	\N
161436	käändevormist	?käändevormist =käändevormi  (SgEl  >käändevorm !22_S	et	f	\N
161437	käändevormist	?käändevormist =käändevormis  (SgP  >käändevormis !09_S	et	f	\N
161438	käändevormist	?käändevormist =käändevormis  (SgP  >käändevormine !12_A	et	f	\N
161439	käändevormist	?käändevormist =käändevormist  (SgN  >käändevormist !22_S	et	f	\N
161440	käändevormist	?käändevormist =evormi  (SgEl  >käänd+evormi !01_S	et	f	\N
161441	käändevormist	?käändevormist =evormi  (SgEl  >käänd+evorm !22_S	et	f	\N
161442	käändevormist	?käändevormist =evormis  (SgP  >käänd+evormis !11_S	et	f	\N
161443	käändevormist	?käändevormist =evormis  (SgP  >käänd+evormine !12_A	et	f	\N
161444	käändevormist	?käändevormist =evormist  (SgN  >käänd+evormist !22_S	et	f	\N
161457	pahaendelist	pahaendelist =endelis  (SgP  >paha+endeline !12_A	et	f	\N
161458	pahaendelist	"paha+endeline %ende  )LINE_aA  <paha+enne ;06_S	et	f	\N
161471	asesõna	asesõna =sõna  (SgN  >ase+sõna !17_S	et	f	\N
161472	asesõna	asesõna =sõna  (SgG  >ase+sõna !17_S	et	f	\N
161473	asesõna	asesõna =sõna  (SgP  >ase+sõna !17_S	et	f	\N
161476	arusaamatused	arusaamatused =saamatuse  (PlN  >aru+saamatus !11_S	et	f	\N
161477	arusaamatused	"aru+saamatus %saama  )TUS2_aS  <aru+saam ;22_S	et	f	\N
161528	õmmeldaksin	?õmmeldaksin =õmmelda  (KndPrSg1  >õmmeldama !27_V	et	f	\N
161529	õmmeldaksin	?õmmeldaksin =õmmeldaksi  (IndPrSg1  >õmmeldaksima !28_V	et	f	\N
161530	õmmeldaksin	?õmmeldaksin =õmmeldaksin  (SgN  >õmmeldaksin !02_S	et	f	\N
161536	umbisikulise	umbisikulise =isikulise  (SgG  >umb+isikuline !12_A	et	f	\N
161537	umbisikulise	"umb+isikuline %isiku  )LINE_aA  <umb+isik ;02_S	et	f	\N
161542	veetakse	veetakse =vee  (IndPrIps  >vedama !28_V	et	f	\N
161543	veetakse	veetakse =takse  (PlP  >vee+taks !22_S	et	f	\N
161545	murdatakse	?murdatakse =murda  (IndPrIps  >murtama !29_V	et	f	\N
161546	murdatakse	?murdatakse =murdatakse  (SgG  >murdatakne !02_A	et	f	\N
161547	murdatakse	?murdatakse =murdatakse  (PlP  >murdataks !22_S	et	f	\N
161548	murdatakse	?murdatakse =atakse  (SgG  >murd+atakne !02_A	et	f	\N
161553	formatiivi	?formatiivi =formatiivi  (SgN  >formatiivi !16_S	et	f	\N
161554	formatiivi	?formatiivi =formatiivi  (SgG  >formatiivi !16_S	et	f	\N
161555	formatiivi	?formatiivi =formatiivi  (SgG  >formatiiv !22_S	et	f	\N
161556	formatiivi	?formatiivi =formatiivi  (SgP  >formatiiv !22_S	et	f	\N
161557	formatiivi	?formatiivi =formatiivi  (SgAdt  >formatiiv !22_S	et	f	\N
161558	formatiivi	?formatiivi =formatiivi  (IndPrPs_  >formatiivima !28_V	et	f	\N
161559	formatiivi	?formatiivi =formatiivi  (ImpPrSg2  >formatiivima !28_V	et	f	\N
161560	formatiivi	?formatiivi =atiivi  (SgN  >form+atiivi !16_S	et	f	\N
161561	formatiivi	?formatiivi =atiivi  (SgG  >form+atiivi !16_S	et	f	\N
161563	formatiivi	?formatiivi =atiivi  (SgG  >form+atiiv !22_S	et	f	\N
161565	formatiivi	?formatiivi =atiivi  (SgP  >form+atiiv !22_S	et	f	\N
161567	formatiivi	?formatiivi =atiivi  (SgAdt  >form+atiiv !22_S	et	f	\N
161570	öö-üü	?öö-üü =üü  (SgN  >öö-üü !26_S	et	f	\N
161571	öö-üü	?öö-üü =üü  (SgG  >öö-üü !26_S	et	f	\N
161576	tegevusnime	tegevusnime =nime  (SgG  >tegevus+nimi !20_S	et	f	\N
161577	tegevusnime	tegevusnime =nime  (SgP  >tegevus+nimi !20_S	et	f	\N
161604	kahetuhandes	?kahetuhandes =kahetuhande  (PlIn  >kahetuhant !22_S	et	f	\N
161605	kahetuhandes	?kahetuhandes =tuhande  (PlIn  >kahe+tuhant !22_S	et	f	\N
161632	alusega	alusega =aluse  (SgKom  >alus !09_S	et	f	\N
161633	alusega	alusega =aluse  (SgKom  >alune !10_AS	et	f	\N
161634	alusega	"alune %alu  )NE_aA  <alg ;22_S	et	f	\N
161635	öeldistäide	?öeldistäide =öeldistäi  (PlG  >öeldistäi !26_S	et	f	\N
161636	öeldistäide	?öeldistäide =öeldistäide  (PlP  >öeldistäid !22_S	et	f	\N
161639	elina	?elina =eli  (SgEs  >eli !17_S	et	f	\N
161640	elina	?elina =elina  (SgG  >elin !02_S	et	f	\N
161643	vilunud	vilunud =vilu  (PtsPtPs  >viluma !27_V	et	f	\N
161644	vilunud	vilunud =vilunu  (PlN  >vilunu !01_S	et	f	\N
161645	vilunud	"vilunu %vilu  )NU_vS  <viluma ;27_V	et	f	\N
161646	vilunud	vilunud =vilunud  (ID  >vilunud !41_A	et	f	\N
161648	vilunud	"vilunud %vilu  )NUD_vA  <viluma ;27_V	et	f	\N
161653	turvalist	turvalist =turvalis  (SgP  >turvaline !12_A	et	f	\N
161654	turvalist	"turvaline %turva  )LINE_aA  <turb ;22_SA	et	f	\N
161655	turvalist	"turvaline %turva  )LINE_aA  <turv ;22_S	et	f	\N
161656	määratleminetallinn	?määratleminetallinn =määratleminetallinn  (SgN  >määratleminetallinn !22_S	et	f	\N
161662	meelitava	meelitava =meelitava  (SgG  >meelitav !02_A	et	f	\N
161663	meelitava	"meelitav %meelita  )V_vA  <meelitama ;27_V	et	f	\N
161664	meelitava	meelitava =tava  (SgN  >meeli+tava !17_S	et	f	\N
161665	meelitava	meelitava =tava  (SgG  >meeli+tava !17_S	et	f	\N
161666	meelitava	meelitava =tava  (SgP  >meeli+tava !17_S	et	f	\N
161695	probeemile	?probeemile =probeemi  (SgAll  >probeemi !16_S	et	f	\N
161588	interpunktsioonis	interpunktsioonis =interpunktsiooni  (SgIn  >interpunktsioon !22_S	et	f	\N
161589	interpunktsioonis	interpunktsioonis =punktsiooni  (SgIn  >inter+punktsioon !22_S	et	f	\N
161607	poolmiljardit	?poolmiljardit =miljardi  (SgP  >pool+miljardi !01_S	et	f	\N
161614	koolimajast	koolimajast =maja  (SgEl  >kooli+maja !17_S	et	f	\N
161615	koolimajast	koolimajast =majas  (SgP  >kooli+majane !10_A	et	f	\N
161616	koolimajast	"kooli+majane %maja  )NE_aA  <kooli+maja ;17_S	et	f	\N
161617	koolimajast	koolimajast =imaja  (SgEl  >kool+imaja !01_S	et	f	\N
161657	pealkirju	pealkirju =kirju  (SgN  >peal+kirju !01_A	et	f	\N
161658	pealkirju	pealkirju =kirju  (SgN  >peal+kirju !16_A	et	f	\N
161659	pealkirju	pealkirju =kirju  (SgG  >peal+kirju !01_A	et	f	\N
161660	pealkirju	pealkirju =kirju  (SgG  >peal+kirju !16_A	et	f	\N
161661	pealkirju	pealkirju =kirju  (PlP  >peal+kiri !24_S	et	f	\N
161668	kõõlas	?kõõlas =kõõla  (SgIn  >kõõla !16_S	et	f	\N
161669	kõõlas	?kõõlas =kõõla  (IndIpfSg3  >kõõlama !29_V	et	f	\N
161670	kõõlas	?kõõlas =kõõlas  (SgN  >kõõlas !07_S	et	f	\N
161678	ajakirjast	ajakirjast =kirja  (SgEl  >aja+kiri !24_S	et	f	\N
161679	ajakirjast	ajakirjast =kirjas  (SgP  >aja+kirjane !10_A	et	f	\N
161680	ajakirjast	"aja+kirjane %kirja  )NE_aA  <aja+kiri ;24_S	et	f	\N
161681	valisest	?valisest =valise  (SgEl  >valine !10_A	et	f	\N
161682	lugejaid	lugejaid =lugeja  (PlP  >lugeja !01_S	et	f	\N
161683	lugejaid	"lugeja %luge  )JA_vS  <lugema ;28_V	et	f	\N
161694	tõsisele	tõsisele =tõsise  (SgAll  >tõsine !10_A	et	f	\N
161697	tõsisele	"tõsine %tõsi  )NE_aA  <tõsi ;15_S	et	f	\N
161703	fun	### fun	et	f	\N
161710	pakkuks	### pakkuks	et	f	\N
161727	autorideta	?autorideta =autorideta  (IndPrPs_  >autoridetama !27_V	et	f	\N
161728	autorideta	?autorideta =autorideta  (ImpPrSg2  >autoridetama !27_V	et	f	\N
161729	autorideta	?autorideta =ride  (SgAb  >auto+ride !16_S	et	f	\N
161730	autorideta	?autorideta =tori  (PlAb  >au+tori !17_S	et	f	\N
161731	meelepaha	meelepaha =paha  (SgN  >meele+paha !17_AS	et	f	\N
161732	meelepaha	meelepaha =paha  (SgG  >meele+paha !17_AS	et	f	\N
161733	meelepaha	meelepaha =paha  (SgG  >meele+pahk !22_S	et	f	\N
161734	meelepaha	meelepaha =paha  (SgP  >meele+paha !17_AS	et	f	\N
161738	rahasummad	rahasummad =summa  (PlN  >raha+summa !16_S	et	f	\N
161740	rahasummad	rahasummad =summa  (PlN  >raha+summ !22_S	et	f	\N
161742	rahasummad	rahasummad =summa  (PlN  >raha+sumb !22_S	et	f	\N
161756	lõikidestsissejuhatus-1ne	### lõikidestsissejuhatus-1ne	et	f	\N
161761	külmaks	külmaks =külma  (SgTr  >külm !22_AS	et	f	\N
161762	külmaks	külmaks =külma  (KndPrPs  >külmama !29_V	et	f	\N
161767	nissi	?nissi =nissi  (SgN  >nissi !16_S	et	f	\N
161768	nissi	?nissi =nissi  (SgG  >nissi !16_S	et	f	\N
161769	nissi	?nissi =nissi  (SgG  >niss !22_S	et	f	\N
161770	nissi	?nissi =nissi  (SgP  >niss !22_S	et	f	\N
161771	nissi	?nissi =nissi  (SgAdt  >niss !22_S	et	f	\N
161772	nissi	?nissi =nissi  (IndPrPs_  >nissima !28_V	et	f	\N
161773	nissi	?nissi =nissi  (ImpPrSg2  >nissima !28_V	et	f	\N
161775	rüütlimõisast	rüütlimõisast =mõisa  (SgEl  >rüütli+mõis !02_S	et	f	\N
161776	rüütlimõisast	rüütlimõisast =mõisas  (SgP  >rüütli+mõisane !10_A	et	f	\N
161777	rüütlimõisast	"rüütli+mõisane %mõisa  )NE_aA  <rüütli+mõis ;02_S	et	f	\N
161783	janiko	?janiko =janiko  (SgN  >janiko !16_S	et	f	\N
161784	janiko	?janiko =janiko  (SgG  >janiko !16_S	et	f	\N
161786	lehetu	lehetu =lehetu  (SgN  >lehetu !01_A	et	f	\N
161787	lehetu	"lehetu %lehe  )TU2_kA  <leht ;22_S	et	f	\N
161788	lehetu	lehetu =lehetu  (SgG  >lehetu !01_A	et	f	\N
161789	lehhet	?lehhet =lehhe  (SgP  >lehhe !06_S	et	f	\N
161801	põlli	põlli =põlli  (SgG  >põll !22_S	et	f	\N
161802	põlli	põlli =põlli  (SgP  >põll !22_S	et	f	\N
161803	põlli	põlli =põlli  (SgAdt  >põll !22_S	et	f	\N
161804	põlli	põlli =põlli  (PlP  >põll !22_S	et	f	\N
161812	riesenberg	?riesenberg =riesenberg  (SgN  >riesenberg !22_S	et	f	\N
161818	russal	?russal =russa  (SgAd  >russa !16_S	et	f	\N
161820	russal	?russal =russal  (SgN  >russal !02_S	et	f	\N
161823	schwarzen	?schwarzen =schwarzen  (SgN  >schwarzen !02_S	et	f	\N
161840	jääv	jääv =jää  (PtsPrPs  >jääma !37_V	et	f	\N
161841	jääv	jääv =jääv  (SgN  >jääv !02_A	et	f	\N
161842	jääv	"jääv %jää  )V_vA  <jääma ;37_V	et	f	\N
161846	kernu	?kernu =kernu  (SgN  >kernu !01_S	et	f	\N
161847	kernu	?kernu =kernu  (SgG  >kernu !01_S	et	f	\N
161848	kernu	?kernu =kernu  (IndPrPs_  >kernuma !27_V	et	f	\N
161849	kernu	?kernu =kernu  (ImpPrSg2  >kernuma !27_V	et	f	\N
161850	kaguosa	kaguosa =osa  (SgN  >kagu+osa !17_S	et	f	\N
161851	kaguosa	kaguosa =osa  (SgG  >kagu+osa !17_S	et	f	\N
161852	kaguosa	kaguosa =osa  (SgP  >kagu+osa !17_S	et	f	\N
161881	suuluselt	suuluselt =suuluse  (SgAbl  >suulus !11~09_S	et	f	\N
161882	suuluselt	"suulus %suulase  )US_aS  <suulane ;12_S	et	f	\N
161883	suuluselt	"suulus %suula  )US_aS  <suulas ;07_A	et	f	\N
161884	suuluselt	suuluselt =suuluselt  (ID  >suuluselt !41_D	et	f	\N
161885	suuluselt	"suuluselt %suulu  )SELT_mD  <suulu ;16_S	et	f	\N
161611	koolimajast	koolimajast =majas  (SgP  >kooli+majane !10_A	et	f	\N
161612	koolimajast	"kooli+majane %maja  )NE_aA  <kooli+maja ;17_S	et	f	\N
161613	koolimajast	koolimajast =imaja  (SgEl  >kool+imaja !01_S	et	f	\N
161620	verbilaiendiks	?verbilaiendiks =verbilaiendi  (SgTr  >verbilaient !22_S	et	f	\N
161621	verbilaiendiks	?verbilaiendiks =verbilaiendi  (KndPrPs  >verbilaientima !28_V	et	f	\N
161627	laiendeil	laiendeil =laiende  (PlAd  >laiend !02_S	et	f	\N
161628	laiendeil	laiendeil =ende  (PlAd  >lai+enne !06_S	et	f	\N
161675	teaduslikust	teaduslikust =teadusliku  (SgEl  >teaduslik !25_A	et	f	\N
161676	teaduslikust	teaduslikust =teaduslikus  (SgP  >teaduslikus !11?09_S	et	f	\N
161677	teaduslikust	"teaduslikus %teadusliku  )US_aS  <teaduslik ;25_A	et	f	\N
161688	auton	?auton =auton  (SgN  >auton !02_S	et	f	\N
161701	lõdvestamiseks	lõdvestamiseks =lõdvestamise  (SgTr  >lõdvestamine !12_S	et	f	\N
161702	lõdvestamiseks	"lõdvestamine %lõdvesta  )MINE_vS  <lõdvestama ;27_V	et	f	\N
161719	zanrile	?zanrile =zanri  (SgAll  >zanri !16_S	et	f	\N
161720	zanrile	?zanrile =zanri  (SgAll  >zanr !22_S	et	f	\N
161721	zanrile	?zanrile =zanrile  (IndPrPs_  >zanrilema !27_V	et	f	\N
161722	zanrile	?zanrile =zanrile  (ImpPrSg2  >zanrilema !27_V	et	f	\N
161735	külaliste	külaliste =külalis  (PlG  >külaline !12_S	et	f	\N
161736	külaliste	"külaline %küla  )LINE_aA  <küla ;17_S	et	f	\N
161758	iõigud	?iõigud =iõigu  (IndPrSg2  >iõiguma !27_V	et	f	\N
161790	munnalas	?munnalas =munnala  (SgIn  >munnala !01_S	et	f	\N
161807	pernama	?pernama =perna  (Sup  >pernama !29_V	et	f	\N
161808	pernama	?pernama =pernama  (SgG  >pernam !02_A	et	f	\N
161809	neu-riesenberg	?neu-riesenberg =riesenberg  (SgN  >neu-riesenberg !22_S	et	f	\N
161827	kolmveerandi	kolmveerandi =andi  (SgP  >kolm+veer+and !22_S	et	f	\N
161828	kolmveerandi	kolmveerandi =andi  (SgAdt  >kolm+veer+and !22_S	et	f	\N
161829	kolmveerandi	kolmveerandi =veerandi  (SgG  >kolm+veerand !02_N	et	f	\N
161838	raplamaale	raplamaale =maa  (SgAll  >rapla+maa !26_S	et	f	\N
161839	raplamaale	raplamaale =maale  (PlP  >rapla+maal !22_S	et	f	\N
161863	ebateadlikult	ebateadlikult =teadliku  (SgAbl  >eba+teadlik !25_A	et	f	\N
161864	ebateadlikult	ebateadlikult =teadlikult  (ID  >eba+teadlikult !41_D	et	f	\N
161865	ebateadlikult	"eba+teadlikult %teadliku  )LT_mD  <eba+teadlik ;25_A	et	f	\N
161871	vastuvõtja	vastuvõtja =võtja  (SgN  >vastu+võtja !01_S	et	f	\N
161872	vastuvõtja	vastuvõtja =võtja  (SgG  >vastu+võtja !01_S	et	f	\N
161876	töötava	töötava =töötava  (SgG  >töötav !02_A	et	f	\N
161877	töötava	"töötav %tööta  )V_vA  <töötama ;27_V	et	f	\N
161878	töötava	töötava =tava  (SgN  >töö+tava !17_S	et	f	\N
161879	töötava	töötava =tava  (SgG  >töö+tava !17_S	et	f	\N
161880	töötava	töötava =tava  (SgP  >töö+tava !17_S	et	f	\N
161904	12rahvaluule	rahvaluule =luu  (SgAll  >rahva+luu !26_S	et	f	\N
161905	12rahvaluule	rahvaluule =luule  (SgN  >rahva+luule !06_S	et	f	\N
161906	12rahvaluule	rahvaluule =luule  (SgG  >rahva+luule !06_S	et	f	\N
161907	12rahvaluule	rahvaluule =luule  (PlP  >rahva+luul !22_S	et	f	\N
161928	1842a	### 1842a	et	f	\N
161935	tippu	tippu =tippu  (SgP  >tipp !22_S	et	f	\N
161936	tippu	tippu =tippu  (SgAdt  >tipp !22_S	et	f	\N
161945	1871a	### 1871a	et	f	\N
161951	korgaeg	?korgaeg =korgaeg  (SgN  >korgaeg !22_S	et	f	\N
161969	editeerimisele	?editeerimisele =editeerimise  (SgAll  >editeerimine !12_S	et	f	\N
161970	topograafilise-tüpoloogilise	?topograafilise-tüpoloogilise =tüpoloogilise  (SgG  >topograafilise-tüpoloogiline !12_A	et	f	\N
161975	rohkearvulistes	rohkearvulistes =arvulis  (PlIn  >rohke+arvuline !12_A	et	f	\N
161976	rohkearvulistes	"rohke+arvuline %arvu  )LINE_aA  <rohke+arv ;22_S	et	f	\N
162003	vahendusel	vahendusel =vahenduse  (SgAd  >vahendus !11_S	et	f	\N
162004	vahendusel	"vahendus %vahenda  )US_vS  <vahendama ;27_V	et	f	\N
162019	asutustesse	asutustesse =asutus  (PlIll  >asutus !11_S	et	f	\N
162020	asutustesse	"asutus %asuta  )US_vS  <asutama ;27_V	et	f	\N
162021	asutustesse	"asutus %asu  )TUS1_aS  <asuma ;27_V	et	f	\N
162022	asutustesse	"asutus %asu  )TUS2_aS  <asu ;17_S	et	f	\N
162023	asutustesse	asutustesse =tuste  (PlIll  >asu+tust !22_S	et	f	\N
162028	eestiseltsi	eestiseltsi =seltsi  (SgG  >eesti+selts !22_S	et	f	\N
162029	eestiseltsi	eestiseltsi =seltsi  (SgP  >eesti+selts !22_S	et	f	\N
162030	eestiseltsi	eestiseltsi =seltsi  (SgAdt  >eesti+selts !22_S	et	f	\N
162049	koguje	### koguje	et	f	\N
162056	järelkogumisele	järelkogumisele =kogumise  (SgAll  >järel+kogumine !12_S	et	f	\N
162057	järelkogumisele	"järel+kogumine %kogumi  )NE_aA  <järel+kogum ;02_S	et	f	\N
162063	selgitaja	selgitaja =selgitaja  (SgN  >selgitaja !01_S	et	f	\N
162064	selgitaja	"selgitaja %selgita  )JA_vS  <selgitama ;27_V	et	f	\N
162065	selgitaja	selgitaja =selgitaja  (SgG  >selgitaja !01_S	et	f	\N
162092	tühimike	tühimike =tühimike  (PlG  >tühimik !25_S	et	f	\N
162093	tühimike	tühimike =mike  (SgN  >tühi+mike !06_S	et	f	\N
162094	tühimike	"tühi+mike %mi  )KE_dS  <tühi+mi ;26_S	et	f	\N
162097	kahasse	kahasse =kaha  (SgIll  >kaha !17_S	et	f	\N
162098	kahasse	kahasse =kahasse  (ID  >kahasse !41_D	et	f	\N
162119	väljendamisoskust	?väljendamisoskust =väljendamisoskus  (SgP  >väljendamisoskus !11~09_S	et	f	\N
161674	kosmosest	"kosmosene %kosmose  )NE_aA  <kosmos ;11_S	et	f	\N
161704	pulomade	### pulomade	et	f	\N
161705	pensionäärid	?pensionäärid =pensionääri  (PlN  >pensionääri !16_S	et	f	\N
161706	pensionäärid	?pensionäärid =pensionääri  (PlN  >pensionäär !22_S	et	f	\N
161707	pensionäärid	?pensionäärid =pensionääri  (IndPrSg2  >pensionäärima !28_V	et	f	\N
161708	pensionäärid	?pensionäärid =onääri  (PlN  >pensi+onääri !16_S	et	f	\N
161709	pensionäärid	?pensionäärid =onääri  (PlN  >pensi+onäär !22_S	et	f	\N
161757	4jas	### 4jas	et	f	\N
161763	diplomitöö	diplomitöö =töö  (SgN  >diplomi+töö !26_S	et	f	\N
161764	diplomitöö	diplomitöö =töö  (SgG  >diplomi+töö !26_S	et	f	\N
161774	valikulut	?valikulut =ulut  (SgN  >valik+ulut !02_S	et	f	\N
161785	laitz	### laitz	et	f	\N
161795	nurms	?nurms =nurms  (SgN  >nurms !22_S	et	f	\N
161800	poll	?poll =poll  (SgN  >poll !22_S	et	f	\N
161813	russalu	?russalu =russalu  (SgN  >russalu !01_S	et	f	\N
161814	russalu	?russalu =russalu  (SgG  >russalu !01_S	et	f	\N
161815	russalu	?russalu =russalu  (IndPrPs_  >russaluma !27_V	et	f	\N
161816	russalu	?russalu =russalu  (ImpPrSg2  >russaluma !27_V	et	f	\N
161821	saida	saida =saida  (SgN  >saida !16_S	et	f	\N
161822	saida	saida =saida  (SgG  >saida !16_S	et	f	\N
161824	vana-riisipere	vana-riisipere =pere  (SgN  >vana-riisi+pere !16_S	et	f	\N
161826	vana-riisipere	vana-riisipere =pere  (SgG  >vana-riisi+pere !16_S	et	f	\N
161835	harjumaale	harjumaale =maa  (SgAll  >harju+maa !26_S	et	f	\N
161836	harjumaale	harjumaale =maale  (PlP  >harju+maal !22_S	et	f	\N
161855	märjamaa	märjamaa =maa  (SgN  >märja+maa !26_S	et	f	\N
161856	märjamaa	märjamaa =maa  (SgG  >märja+maa !26_S	et	f	\N
161859	11rahvaluule	rahvaluule =luu  (SgAll  >rahva+luu !26_S	et	f	\N
161860	11rahvaluule	rahvaluule =luule  (SgN  >rahva+luule !06_S	et	f	\N
161861	11rahvaluule	rahvaluule =luule  (SgG  >rahva+luule !06_S	et	f	\N
161862	11rahvaluule	rahvaluule =luule  (PlP  >rahva+luul !22_S	et	f	\N
161892	aineks	aineks =aine  (SgTr  >aine !06_S	et	f	\N
161893	aineks	aineks =aine  (PlTr  >ain !22_S	et	f	\N
161894	pajatused	pajatused =pajatuse  (PlN  >pajatus !11_S	et	f	\N
161895	pajatused	"pajatus %pajata  )US_vS  <pajatama ;27_V	et	f	\N
161896	pajatused	"pajatus %paja  )TUS2_aS  <paja ;17_S	et	f	\N
161897	pajatused	"pajatus %paja  )TUS2_aS  <pada ;18_S	et	f	\N
161910	1830-ndatel	?-ndatel =ndate  (PlAd  >-ndatt !22_S	et	f	\N
161911	1830-ndatel	?-ndatel =ndatel  (SgN  >-ndatel !02_S	et	f	\N
161914	ajaloostja	?ajaloostja =ajaloostja  (SgN  >ajaloostja !16_S	et	f	\N
161915	ajaloostja	?ajaloostja =ajaloostja  (SgG  >ajaloostjas !02_A	et	f	\N
161916	ajaloostja	?ajaloostja =ajaloostja  (SgG  >ajaloostja !16_S	et	f	\N
161917	ajaloostja	?ajaloostja =loostja  (SgN  >aja+loostja !01_S	et	f	\N
161918	ajaloostja	?ajaloostja =loostja  (SgG  >aja+loostja !01_S	et	f	\N
161919	ajaloostja	?ajaloostja =loostja  (SgG  >aja+loostjas !02_A	et	f	\N
161921	dhjürgenson	?dhjürgenson =dhjürgenson  (SgN  >dhjürgenson !19_S	et	f	\N
161931	avardus	avardus =avardu  (IndIpfSg3  >avarduma !27_V	et	f	\N
161932	avardus	avardus =avardus  (SgN  >avardus !11_S	et	f	\N
161933	avardus	"avardus %avarda  )US_vS  <avardama ;27_V	et	f	\N
161947	ilmusidki	ilmusidki =ilmu  (IndIpfSg2^  >ilmuma !27_V	et	f	\N
161948	ilmusidki	ilmusidki =ilmu  (IndIpfPl3^  >ilmuma !27_V	et	f	\N
161958	läbitöötatud	läbitöötatud =tööta  (PtsPtIps  >läbi+_töötama !27_V	et	f	\N
161959	läbitöötatud	läbitöötatud =töötatu  (PlN  >läbi+töötatu !01_S	et	f	\N
161971	matthias	?matthias =matthia  (SgIn  >matthia !01_S	et	f	\N
161972	matthias	?matthias =matthias  (SgN  >matthias !11_S	et	f	\N
161973	matthias	?matthias =hia  (SgIn  >matt+hia !26_S	et	f	\N
161974	matthias	?matthias =hias  (SgN  >matt+hias !22_S	et	f	\N
161980	teerajaja	teerajaja =rajaja  (SgN  >tee+rajaja !01_S	et	f	\N
161981	teerajaja	teerajaja =rajaja  (SgG  >tee+rajaja !01_S	et	f	\N
161988	ainelist	ainelist =ainelis  (SgP  >aineline !12_A	et	f	\N
161989	ainelist	"aineline %aine  )LINE_aA  <aine ;06_S	et	f	\N
161993	viires	viires =viire  (SgIn  >viires !07_S	et	f	\N
161994	viires	viires =viire  (PlIn  >viirg !22_S	et	f	\N
161995	viires	viires =viire  (PlIn  >viir !22_S	et	f	\N
161996	viires	viires =viires  (SgN  >viires !07_S	et	f	\N
161999	omariikluse	omariikluse =riikluse  (SgG  >oma+riiklus !11~09_S	et	f	\N
162000	omariikluse	"oma+riiklus %riiklase  )US_aS  <oma+riiklane ;12_S	et	f	\N
162013	eesri	?eesri =eesri  (ID  >eesri !41_D	et	f	\N
162014	eesri	?eesri =eesri  (SgG  >eeser !02_S	et	f	\N
162015	eesri	?eesri =eesri  (IndPrPs_  >eesrima !28_V	et	f	\N
162016	eesri	?eesri =eesri  (ImpPrSg2  >eesrima !28_V	et	f	\N
162036	kijameeste	### kijameeste	et	f	\N
162038	säilitamiseks	säilitamiseks =säilitamise  (SgTr  >säilitamine !12_S	et	f	\N
162039	säilitamiseks	"säilitamine %säilita  )MINE_vS  <säilitama ;27_V	et	f	\N
162047	mjeiseni	?mjeiseni =mjeise  (SgTer  >mjeise !06_S	et	f	\N
162048	mjeiseni	?mjeiseni =mjeiseni  (SgG  >mjeisen !02_S	et	f	\N
162050	omanimelist	omanimelist =nimelis  (SgP  >oma+nimeline !12_A	et	f	\N
162051	omanimelist	"oma+nimeline %nime  )LINE_aA  <oma+nimi ;20_S	et	f	\N
161689	lehekülgedelt	lehekülgedelt =ede  (SgAbl  >lehe+külg+ede !16_S	et	f	\N
161690	lehekülgedelt	lehekülgedelt =külge  (PlAbl  >lehe+külg !22_S	et	f	\N
161691	viita	viita =viit  (Inf  >viitma !34_V	et	f	\N
161692	viita	viita =viita  (SgG  >viidas !07_S	et	f	\N
161693	viita	viita =viita  (SgP  >viit !22_S	et	f	\N
161696	viita	viita =viita  (SgAdt  >viit !22_S	et	f	\N
161699	viita	viita =viita  (IndPrPs_  >viitama !29_V	et	f	\N
161700	viita	viita =viita  (ImpPrSg2  >viitama !29_V	et	f	\N
161711	ärimeestele	ärimeestele =mees  (PlAll  >äri+meene !10_A	et	f	\N
161712	ärimeestele	"äri+meene %mee  )NE_aA  <äri+mesi ;15_S	et	f	\N
161713	ärimeestele	ärimeestele =mees  (PlAll  >äri+mees !13_S	et	f	\N
161714	iugemist	?iugemist =iugemi  (SgEl  >iugemi !01_S	et	f	\N
161715	iugemist	?iugemist =iugemi  (SgEl  >iugem !02_A	et	f	\N
161716	iugemist	?iugemist =iugemis  (SgP  >iugemis !11_S	et	f	\N
161717	iugemist	?iugemist =iugemis  (SgP  >iugemine !12_S	et	f	\N
161718	iugemist	?iugemist =iugemist  (SgN  >iugemist !22_S	et	f	\N
161723	loos	loos =loo  (SgIn  >lugu !18_S	et	f	\N
161724	loos	loos =loo  (SgIn  >loog !22_S	et	f	\N
161725	loos	loos =loo  (SgIn  >lood !22_S	et	f	\N
161726	loos	loos =loos  (SgN  >loos !22_S	et	f	\N
161753	ülesehitusest	ülesehitusest =ehituse  (SgEl  >üles+ehitus !11_S	et	f	\N
161754	ülesehitusest	ülesehitusest =ehituses  (SgP  >üles+ehitusene !12_A	et	f	\N
161755	ülesehitusest	"üles+ehitusene %ehituse  )NE_aA  <üles+ehitus ;11_S	et	f	\N
161759	lõpp-5es	### lõpp-5es	et	f	\N
161760	mõõjutada	?mõõjutada =mõõjuta  (Inf  >mõõjutama !27_V	et	f	\N
161796	pajaka	?pajaka =pajaka  (SgN  >pajaka !01_S	et	f	\N
161797	pajaka	?pajaka =pajaka  (SgG  >pajaka !01_S	et	f	\N
161798	pajaka	?pajaka =pajaka  (SgG  >pajakas !02_A	et	f	\N
161805	pärnamaa	pärnamaa =maa  (SgN  >pärna+maa !26_S	et	f	\N
161806	pärnamaa	pärnamaa =maa  (SgG  >pärna+maa !26_S	et	f	\N
161810	riisipere	riisipere =pere  (SgN  >riisi+pere !16_S	et	f	\N
161811	riisipere	riisipere =pere  (SgG  >riisi+pere !16_S	et	f	\N
161825	alt-riesenberg	?alt-riesenberg =riesenberg  (SgN  >alt-riesenberg !22_S	et	f	\N
161837	harrien	?harrien =harrien  (SgN  >harrien !19_S	et	f	\N
161843	kirdeosa	kirdeosa =osa  (SgN  >kirde+osa !17_S	et	f	\N
161844	kirdeosa	kirdeosa =osa  (SgG  >kirde+osa !17_S	et	f	\N
161845	kirdeosa	kirdeosa =osa  (SgP  >kirde+osa !17_S	et	f	\N
161853	lähikonnas	lähikonnas =lähikonna  (SgIn  >lähikond !22_S	et	f	\N
161854	lähikonnas	lähikonnas =konna  (SgIn  >lähi+konn !22_S	et	f	\N
161868	andja	andja =andja  (SgN  >andja !01_S	et	f	\N
161869	andja	"andja %and  )JA_vS  <andma ;34_V	et	f	\N
161870	andja	andja =andja  (SgG  >andja !01_S	et	f	\N
161890	folkloristika	folkloristika =folkloristika  (SgN  >folkloristika !01_S	et	f	\N
161891	folkloristika	folkloristika =folkloristika  (SgG  >folkloristika !01_S	et	f	\N
161912	huvitatumate	huvitatumate =huvitatuma  (PlG  >huvitatum !02_A	et	f	\N
161913	huvitatumate	"huvitatum %huvita  )TUM1_cA  <huvitama ;27_V	et	f	\N
161920	frrfaehlmann	?frrfaehlmann =frrfaehlmann  (SgN  >frrfaehlmann !22_S	et	f	\N
161927	frkreutzwald	?frkreutzwald =frkreutzwald  (SgN  >frkreutzwald !02_S	et	f	\N
161952	1888aastast	aastast =aasta  (SgEl  >aasta !01_S	et	f	\N
161953	1888aastast	aastast =aastas  (SgP  >aastane !12~10_A	et	f	\N
161954	1888aastast	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
161982	axel	?axel =axe  (SgAd  >axe !06_S	et	f	\N
161983	axel	?axel =axel  (SgN  >axel !02_S	et	f	\N
162017	koondati	koondati =koonda  (IndIpfIps  >koondama !27_V	et	f	\N
162018	koondati	koondati =ati  (SgG  >koond+att !22_S	et	f	\N
162024	eravaldusse	eravaldusse =usse  (PlP  >era+vald+uss !22_S	et	f	\N
162025	eravaldusse	eravaldusse =valdus  (SgAdt  >era+valdus !11_S	et	f	\N
162033	viisikogu	viisikogu =kogu  (SgN  >viisi+kogu !17_S	et	f	\N
162034	viisikogu	viisikogu =kogu  (SgG  >viisi+kogu !17_S	et	f	\N
162035	viisikogu	viisikogu =kogu  (SgP  >viisi+kogu !17_S	et	f	\N
162045	äratoomiseni	äratoomiseni =toomise  (SgTer  >ära+toomine !12?10_S	et	f	\N
162046	äratoomiseni	"ära+toomine %toomi  )NE_aA  <ära+toom ;22_S	et	f	\N
162058	kaastöölistega	kaastöölistega =iste  (SgKom  >kaas+tööl+iste !06_S	et	f	\N
162059	kaastöölistega	kaastöölistega =töölis  (PlKom  >kaas+tööline !12?10_S	et	f	\N
162071	õlul	õlul =õlu  (PlAd  >õlg !22_S	et	f	\N
162072	õlul	õlul =õlul  (ID  >õlul !41_K	et	f	\N
162080	ettevaatlikult	ettevaatlikult =vaatliku  (SgAbl  >ette+vaatlik !25_A	et	f	\N
162081	ettevaatlikult	"ette+vaatlikult %vaatliku  )LT_mD  <ette+vaatlik ;25_A	et	f	\N
162112	suunata	suunata =suuna  (SgAb  >suund !22_S	et	f	\N
162113	suunata	suunata =suuna  (Inf  >suunama !29_V	et	f	\N
162114	suunata	suunata =suuna  (IndPrIps_  >suunama !29_V	et	f	\N
162115	suunata	suunata =nata  (SgG  >suu+natt !22_S	et	f	\N
162124	rahvaluulelist	rahvaluulelist =luulelis  (SgP  >rahva+luuleline !12_A	et	f	\N
162125	rahvaluulelist	"rahva+luuleline %luule  )LINE_aA  <rahva+luule ;06_S	et	f	\N
162126	rviidalepp	?rviidalepp =rviidalepp  (SgN  >rviidalepp !22_S	et	f	\N
162135	sündmustikuga	sündmustikuga =sündmustiku  (SgKom  >sündmustik !25_S	et	f	\N
162136	sündmustikuga	sündmustikuga =tiku  (SgKom  >sündmus+tikk !22_S	et	f	\N
161698	probeemile	?probeemile =probeemi  (SgAll  >probeem !22_S	et	f	\N
161737	tohutud	tohutud =tohutu  (PlN  >tohutu !01_A	et	f	\N
161739	tohutud	"tohutu %tohu  )TU2_kA  <tohu ;17_S	et	f	\N
161741	tohutud	"tohutu %tohu  )TU2_kA  <toht ;22_S	et	f	\N
161743	kindalsti	?kindalsti =kindalsti  (SgN  >kindalsti !01_S	et	f	\N
161744	kindalsti	?kindalsti =kindalsti  (SgG  >kindalsti !01_S	et	f	\N
161745	kindalsti	?kindalsti =kindalsti  (SgG  >kindalst !22_S	et	f	\N
161746	kindalsti	?kindalsti =kindalsti  (SgP  >kindalst !22_S	et	f	\N
161747	kindalsti	?kindalsti =kindalsti  (SgAdt  >kindalst !22_S	et	f	\N
161748	kindalsti	?kindalsti =kindalsti  (IndPrPs_  >kindalstima !28_V	et	f	\N
161749	kindalsti	?kindalsti =kindalsti  (ImpPrSg2  >kindalstima !28_V	et	f	\N
161750	stiilist	stiilist =stiili  (SgEl  >stiil !22_S	et	f	\N
161751	stiilist	stiilist =stiilis  (SgP  >stiiline !10_A	et	f	\N
161752	stiilist	"stiiline %stiili  )NE_aA  <stiil ;22_S	et	f	\N
161765	diplomitöö	diplomitöö =töö  (SgN  >diplomi+töö !26_S	et	f	\N
161766	diplomitöö	diplomitöö =töö  (SgG  >diplomi+töö !26_S	et	f	\N
161778	jaanika	?jaanika =jaanika  (SgN  >jaanika !01_S	et	f	\N
161779	jaanika	?jaanika =jaanika  (SgG  >jaanika !01_S	et	f	\N
161780	jaanika	?jaanika =jaanika  (SgG  >jaanikas !02_S	et	f	\N
161781	jaanika	?jaanika =ika  (SgN  >jaan+ika !16_S	et	f	\N
161782	jaanika	?jaanika =ika  (SgG  >jaan+ika !16_S	et	f	\N
161791	nurme	nurme =nurme  (SgG  >nurm !22_S	et	f	\N
161792	nurme	nurme =nurme  (SgP  >nurm !22_S	et	f	\N
161793	nurme	nurme =nurme  (SgAdt  >nurm !22_S	et	f	\N
161794	nurme	nurme =nurme  (PlP  >nurm !22_S	et	f	\N
161799	pajak	?pajak =pajak  (SgN  >pajak !02_S	et	f	\N
161817	saida	saida =saida  (SgN  >saida !16_S	et	f	\N
161819	saida	saida =saida  (SgG  >saida !16_S	et	f	\N
161830	ajaloolisse	ajaloolisse =loolis  (SgAdt  >aja+looline !12_A	et	f	\N
161831	ajaloolisse	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
161832	ajaloolisse	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
161833	ajaloolisse	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
161834	ajaloolisse	ajaloolisse =loolis  (SgAdt  >aja+looline !12_S	et	f	\N
161857	raplamaal	raplamaal =maa  (SgAd  >rapla+maa !26_S	et	f	\N
161858	raplamaal	raplamaal =maal  (SgN  >rapla+maal !22_S	et	f	\N
161866	usundilistes	usundilistes =usundilis  (PlIn  >usundiline !12_A	et	f	\N
161867	usundilistes	"usundiline %usundi  )LINE_aA  <usund ;02_S	et	f	\N
161873	kohandakse	?kohandakse =kohandakse  (SgG  >kohandakne !02_A	et	f	\N
161874	muutumisega	muutumisega =muutumise  (SgKom  >muutumine !12_S	et	f	\N
161875	muutumisega	"muutumine %muutu  )MINE_vS  <muutuma ;27_V	et	f	\N
161886	levimise	levimise =levimise  (SgG  >levimine !12_S	et	f	\N
161887	levimise	"levimine %levi  )MINE_vS  <levima ;27_V	et	f	\N
161898	folkliristika	?folkliristika =folkliristika  (SgN  >folkliristika !01_S	et	f	\N
161899	folkliristika	?folkliristika =folkliristika  (SgG  >folkliristika !01_S	et	f	\N
161900	folkliristika	?folkliristika =folkliristika  (SgG  >folkliristikas !02_A	et	f	\N
161901	folkliristika	?folkliristika =liristika  (SgN  >folk+liristika !01_S	et	f	\N
161902	folkliristika	?folkliristika =liristika  (SgG  >folk+liristika !01_S	et	f	\N
161903	folkliristika	?folkliristika =liristika  (SgG  >folk+liristikas !02_A	et	f	\N
161926	1839a	### 1839a	et	f	\N
161929	mõistmine	mõistmine =mõistmine  (SgN  >mõistmine !12?10_S	et	f	\N
161930	mõistmine	"mõistmine %mõist  )MINE_vS  <mõistma ;34_V	et	f	\N
161937	rahvaluulekogumisega	rahvaluulekogumisega =kogumise  (SgKom  >rahva+luule+kogumine !12_S	et	f	\N
161938	rahvaluulekogumisega	"rahva+luule+kogumine %kogumi  )NE_aA  <rahva+luule+kogum ;02_S	et	f	\N
161944	tagavus	tagavus =tagavus  (SgN  >tagavus !11_S	et	f	\N
161946	tagavus	"tagavus %taga  )VUS_aS  <tagama ;27_V	et	f	\N
161960	palvid	?palvid =palvi  (PlN  >palvi !16_S	et	f	\N
161961	palvid	?palvid =palvi  (PlN  >palv !22_S	et	f	\N
161962	palvid	?palvid =palvi  (IndPrSg2  >palvima !28_V	et	f	\N
161966	kirjameeste	kirjameeste =mees  (PlG  >kirja+meene !10_A	et	f	\N
161967	kirjameeste	"kirja+meene %mee  )NE_aA  <kirja+mesi ;15_S	et	f	\N
161968	kirjameeste	kirjameeste =mees  (PlG  >kirja+mees !13_S	et	f	\N
161977	odavates	odavates =odava  (PlIn  >odav !02_A	et	f	\N
161978	odavates	odavates =ate  (PlIn  >odav+att !22_S	et	f	\N
161979	odavates	odavates =vate  (PlIn  >oda+vatt !22_S	et	f	\N
161984	heikel	?heikel =heike  (SgAd  >heige !06_S	et	f	\N
161985	heikel	?heikel =heikel  (SgN  >heikel !02_S	et	f	\N
161997	institutsioonilised	institutsioonilised =institutsioonilise  (PlN  >institutsiooniline !12_A	et	f	\N
161998	institutsioonilised	"institutsiooniline %institutsiooni  )LINE_aA  <institutsioon ;22_S	et	f	\N
162026	kogud	kogud =kogu  (PlN  >kogu !17_S	et	f	\N
162027	kogud	kogud =kogu  (IndPrSg2  >koguma !27_V	et	f	\N
162066	töötajatest	töötajatest =töötaja  (PlEl  >töötaja !01_S	et	f	\N
162067	töötajatest	"töötaja %tööta  )JA_vS  <töötama ;27_V	et	f	\N
162068	töötajatest	töötajatest =test  (SgN  >töötaja+test !22_S	et	f	\N
162069	viidalepp	viidalepp =lepp  (SgN  >viida+lepp !22_S	et	f	\N
162070	viidalepp	viidalepp =lepp  (SgN  >viida+lepp !22_SA	et	f	\N
162075	võimalikesse	võimalikesse =võimalike  (PlIll  >võimalik !25_A	et	f	\N
161888	rahvaluuleteadus	rahvaluuleteadus =teadu  (SgIn  >rahva+luule+tead !22_S	et	f	\N
161889	rahvaluuleteadus	rahvaluuleteadus =teadus  (SgN  >rahva+luule+teadus !11~09_S	et	f	\N
161908	teadlikku	teadlikku =teadlikku  (SgP  >teadlik !25_A	et	f	\N
161909	teadlikku	teadlikku =teadlikku  (SgAdt  >teadlik !25_A	et	f	\N
161922	ettevalmistava	ettevalmistava =tava  (SgN  >ette+valmis+tava !17_S	et	f	\N
161923	ettevalmistava	ettevalmistava =tava  (SgG  >ette+valmis+tava !17_S	et	f	\N
161924	ettevalmistava	ettevalmistava =tava  (SgP  >ette+valmis+tava !17_S	et	f	\N
161925	ettevalmistava	ettevalmistava =valmistava  (SgG  >ette+valmistav !02_A	et	f	\N
161934	19s	### 19s	et	f	\N
161939	rahvaluulekogumisega	rahvaluulekogumisega =kogumise  (SgKom  >rahva+luule+kogumine !12_S	et	f	\N
161940	rahvaluulekogumisega	"rahva+luule+kogumine %kogumi  )NE_aA  <rahva+luule+kogum ;02_S	et	f	\N
161941	ligidadi	?ligidadi =dadi  (SgN  >ligi+dadi !17_S	et	f	\N
161942	ligidadi	?ligidadi =dadi  (SgG  >ligi+dadi !17_S	et	f	\N
161943	ligidadi	?ligidadi =dadi  (SgP  >ligi+dadi !17_S	et	f	\N
161949	kodu-uurimislikud	?kodu-uurimislikud =uurimisliku  (PlN  >kodu-uurimislik !25_A	et	f	\N
161950	kodu-uurimislikud	?kodu-uurimislikud =uurimisliku  (IndPrSg2  >kodu-uurimislikuma !27_V	et	f	\N
161955	metoodiliselt	metoodiliselt =metoodilise  (SgAbl  >metoodiline !12_A	et	f	\N
161956	metoodiliselt	metoodiliselt =metoodiliselt  (ID  >metoodiliselt !41_D	et	f	\N
161957	metoodiliselt	"metoodiliselt %metoodilise  )LT_mD  <metoodiline ;12_A	et	f	\N
161963	ärksamaile	ärksamaile =ärksama  (PlAll  >ärksam !02_A	et	f	\N
161964	ärksamaile	"ärksam %ärksa  )M_cA  <ärgas ;03_A	et	f	\N
161965	ärksamaile	"ärksam %ärksa  )M_cA  <ärgas ;05_A	et	f	\N
161986	olai	?olai =olai  (SgN  >olai !26_S	et	f	\N
161987	olai	?olai =olai  (SgG  >olai !26_S	et	f	\N
161990	käsitlevad	käsitlevad =käsitle  (IndPrPl3  >käsitlema !27_V	et	f	\N
161991	käsitlevad	käsitlevad =käsitleva  (PlN  >käsitlev !02_A	et	f	\N
161992	käsitlevad	"käsitlev %käsitle  )V_vA  <käsitlema ;27_V	et	f	\N
162001	kodumistöö	kodumistöö =töö  (SgN  >kodu+mis+töö !26_S	et	f	\N
162002	kodumistöö	kodumistöö =töö  (SgG  >kodu+mis+töö !26_S	et	f	\N
162005	harudusministeeriumilt	?harudusministeeriumilt =harudusministeeriumi  (SgAbl  >harudusministeerium !19~02_S	et	f	\N
162006	harudusministeeriumilt	?harudusministeeriumilt =harudusministeeriumi  (SgAbl  >harudusministeeriumi !16_S	et	f	\N
162007	harudusministeeriumilt	?harudusministeeriumilt =dusministeeriumi  (SgAbl  >haru+dusministeerium !19~02_S	et	f	\N
162008	harudusministeeriumilt	?harudusministeeriumilt =dusministeeriumi  (SgAbl  >haru+dusministeeriumi !16_S	et	f	\N
162009	kogumist	kogumist =kogumi  (SgEl  >kogum !02_S	et	f	\N
162010	kogumist	kogumist =kogumis  (SgP  >kogumine !12_S	et	f	\N
162011	kogumist	"kogumine %kogu  )MINE_vS  <koguma ;27_V	et	f	\N
162012	kogumist	"kogumine %kogumi  )NE_aA  <kogum ;02_S	et	f	\N
162031	kogud	kogud =kogu  (PlN  >kogu !17_S	et	f	\N
162032	kogud	kogud =kogu  (IndPrSg2  >koguma !27_V	et	f	\N
162037	kkrohn	?kkrohn =kkrohn  (SgN  >kkrohn !22_S	et	f	\N
162040	katalogiseeriti	?katalogiseeriti =katalogiseeri  (IndIpfIps  >katalogiseerima !28_V	et	f	\N
162041	katalogiseeriti	?katalogiseeriti =katalogiseeriti  (ID  >katalogiseeriti !41_D	et	f	\N
162042	katalogiseeriti	?katalogiseeriti =katalogiseeriti  (SgG  >katalogiseeritt !22_S	et	f	\N
162043	katalogiseeriti	?katalogiseeriti =katalogiseeriti  (IndPrPs_  >katalogiseerittima !28_V	et	f	\N
162044	katalogiseeriti	?katalogiseeriti =katalogiseeriti  (ImpPrSg2  >katalogiseerittima !28_V	et	f	\N
162054	korrastamisele	korrastamisele =korrastamise  (SgAll  >korrastamine !12_S	et	f	\N
162055	korrastamisele	"korrastamine %korrasta  )MINE_vS  <korrastama ;27_V	et	f	\N
162073	alguspäevil	alguspäevil =päevi  (SgAd  >algus+päev !22_S	et	f	\N
162074	alguspäevil	alguspäevil =päevi  (PlAd  >algus+päev !22_S	et	f	\N
162082	veedumuseni	?veedumuseni =veedumuse  (SgTer  >veedumus !11_S	et	f	\N
162083	veedumuseni	?veedumuseni =veedumuseni  (SgG  >veedumusen !19_S	et	f	\N
162084	veedumuseni	?veedumuseni =veedumuseni  (SgP  >veedumusen !19_S	et	f	\N
162085	veedumuseni	?veedumuseni =veedumuseni  (SgAdt  >veedumusen !19_S	et	f	\N
162086	veedumuseni	?veedumuseni =dumuse  (SgTer  >vee+dumus !09_S	et	f	\N
162087	veedumuseni	?veedumuseni =dumuseni  (SgG  >vee+dumusen !19_S	et	f	\N
162088	veedumuseni	?veedumuseni =dumuseni  (SgP  >vee+dumusen !19_S	et	f	\N
162089	veedumuseni	?veedumuseni =dumuseni  (SgAdt  >vee+dumusen !19_S	et	f	\N
162095	etnograafidega	etnograafidega =etnograafi  (PlKom  >etnograaf !22_S	et	f	\N
162096	etnograafidega	etnograafidega =graafi  (PlKom  >etno+graaf !22_S	et	f	\N
162099	kooliõpilaste	kooliõpilaste =las  (PlG  >kooli+õpi+laps !14_S	et	f	\N
162100	kooliõpilaste	kooliõpilaste =laste  (PlP  >kooli+õpi+last !22_S	et	f	\N
162101	kooliõpilaste	kooliõpilaste =õpilas  (PlG  >kooli+õpilane !12_S	et	f	\N
162108	köidet	köidet =köide  (SgP  >köide !05_S	et	f	\N
162109	köidet	köidet =köide  (SgP  >köide !06_S	et	f	\N
162120	rahvapärimusi	rahvapärimusi =musi  (SgN  >rahva+päri+musi !17_S	et	f	\N
162121	rahvapärimusi	rahvapärimusi =musi  (SgG  >rahva+päri+musi !17_S	et	f	\N
162122	rahvapärimusi	rahvapärimusi =musi  (SgP  >rahva+päri+musi !17_S	et	f	\N
162123	rahvapärimusi	rahvapärimusi =pärimusi  (PlP  >rahva+pärimus !11_S	et	f	\N
162130	rahvaluuleliigiga	rahvaluuleliigiga =iga  (SgN  >rahva+luule+liig+iga !18_S	et	f	\N
162052	sihipärasele	sihipärasele =pärase  (SgAll  >sihi+pärane !10_A	et	f	\N
162053	sihipärasele	"sihi+pärane %pära  )NE_aA  <sihi+pära ;17_S	et	f	\N
162060	infobülletääni	infobülletääni =bülletääni  (SgG  >info+bülletään !22_S	et	f	\N
162061	infobülletääni	infobülletääni =bülletääni  (SgP  >info+bülletään !22_S	et	f	\N
162062	infobülletääni	infobülletääni =bülletääni  (SgAdt  >info+bülletään !22_S	et	f	\N
162104	tulemusei	?tulemusei =tulemusei  (SgN  >tulemusei !26_S	et	f	\N
162105	tulemusei	?tulemusei =tulemusei  (SgG  >tulemusei !26_S	et	f	\N
162106	tulemusei	?tulemusei =musei  (SgN  >tule+musei !26_S	et	f	\N
162107	tulemusei	?tulemusei =musei  (SgG  >tule+musei !26_S	et	f	\N
162110	pedagoogiliseks	pedagoogiliseks =pedagoogilise  (SgTr  >pedagoogiline !12_A	et	f	\N
162111	pedagoogiliseks	"pedagoogiline %pedagoogi  )LINE_aA  <pedagoog ;22_S	et	f	\N
162116	kodukohta	kodukohta =kohta  (SgP  >kodu+koht !22_S	et	f	\N
162117	kodukohta	kodukohta =kohta  (SgAdt  >kodu+koht !22_S	et	f	\N
162118	jälgimisvõimet	### jälgimisvõimet	et	f	\N
162133	jutustajaid	jutustajaid =jutustaja  (PlP  >jutustaja !01_S	et	f	\N
162134	jutustajaid	"jutustaja %jutusta  )JA_vS  <jutustama ;27_V	et	f	\N
162142	ühis-	?ühis- =ühi  (SgIn  >ühi !17_S	et	f	\N
162143	ühis-	?ühis- =ühi  (IndIpfSg3  >ühima !27_V	et	f	\N
162144	ühis-	?ühis- =ühis  (SgN  >ühis !09_S	et	f	\N
162147	korjaja	korjaja =korjaja  (SgN  >korjaja !01_S	et	f	\N
162148	korjaja	"korjaja %korja  )JA_vS  <korjama ;29_V	et	f	\N
162149	korjaja	korjaja =korjaja  (SgG  >korjaja !01_S	et	f	\N
162157	terminoloogia	terminoloogia =terminoloogia  (SgN  >terminoloogia !01_S	et	f	\N
162158	terminoloogia	terminoloogia =terminoloogia  (SgG  >terminoloogia !01_S	et	f	\N
162168	märget	märget =märge  (SgP  >märge !05_S	et	f	\N
162169	märget	märget =märge  (SgP  >märge !06_S	et	f	\N
162218	kirjeldusi	kirjeldusi =kirjeldusi  (PlP  >kirjeldus !11_S	et	f	\N
162219	kirjeldusi	"kirjeldus %kirjelda  )US_vS  <kirjeldama ;27_V	et	f	\N
162235	hiidude	hiidude =hiidu  (PlG  >hiid !22_S	et	f	\N
162236	hiidude	hiidude =ude  (SgN  >hiid+ude !04_S	et	f	\N
162239	seletuseks	seletuseks =seletuse  (SgTr  >seletus !11_S	et	f	\N
162240	seletuseks	"seletus %seleta  )US_vS  <seletama ;27_V	et	f	\N
162243	staatilisem	staatilisem =staatilisem  (SgN  >staatilisem !02_A	et	f	\N
162244	staatilisem	"staatilisem %staatilise  )M_cA  <staatiline ;12_A	et	f	\N
162284	isikliki	?isikliki =isikliki  (IndPrPs_  >isiklikkima !28_V	et	f	\N
162285	isikliki	?isikliki =isikliki  (ImpPrSg2  >isiklikkima !28_V	et	f	\N
162294	kuulajat	kuulajat =kuulaja  (SgP  >kuulaja !01_S	et	f	\N
162296	kuulajat	"kuulaja %kuula  )JA_vS  <kuulama ;29_V	et	f	\N
162304	usundilised	usundilised =usundilise  (PlN  >usundiline !12_A	et	f	\N
162305	usundilised	"usundiline %usundi  )LINE_aA  <usund ;02_S	et	f	\N
162309	kohamuisendite	?kohamuisendite =kohamuisendi  (IndPrPl2  >kohamuisentima !28_V	et	f	\N
162310	kohamuisendite	?kohamuisendite =muisendi  (PlG  >koha+muisendi !01_S	et	f	\N
162311	kohamuisendite	?kohamuisendite =muisendi  (PlG  >koha+muisend !02_S	et	f	\N
162326	rkm	### rkm	et	f	\N
162341	maa-alustest	maa-alustest =alus  (PlEl  >maa-alus !09_S	et	f	\N
162342	maa-alustest	maa-alustest =alus  (PlEl  >maa-alune !10_AS	et	f	\N
162343	maa-alustest	"maa-alune %alu  )NE_aA  <maa-alg ;22_S	et	f	\N
162344	maa-alustest	maa-alustest =test  (SgN  >maa-alus+test !22_S	et	f	\N
162355	palivere	?palivere =palivere  (PlP  >paliver !19_S	et	f	\N
162379	ellamaale	?ellamaale =ellamaa  (SgAll  >ellamaa !26_S	et	f	\N
162380	ellamaale	?ellamaale =ellamaale  (SgN  >ellamaale !16_S	et	f	\N
162381	ellamaale	?ellamaale =ellamaale  (SgG  >ellamaale !16_S	et	f	\N
162382	ellamaale	?ellamaale =ellamaale  (PlP  >ellamaal !22_S	et	f	\N
162389	kadi	?kadi =kadi  (SgN  >kadi !17_S	et	f	\N
162390	kadi	?kadi =kadi  (SgG  >kadi !17_S	et	f	\N
162391	kadi	?kadi =kadi  (SgP  >kadi !17_S	et	f	\N
162392	kadi	?kadi =kadi  (IndPrPs_  >kadima !27_V	et	f	\N
162393	kadi	?kadi =kadi  (ImpPrSg2  >kadima !27_V	et	f	\N
162398	1922a	### 1922a	et	f	\N
162409	agnes	?agnes =agne  (PlIn  >agn !22_S	et	f	\N
162410	agnes	?agnes =agne  (IndIpfSg3  >agnema !27_V	et	f	\N
162411	agnes	?agnes =agnes  (SgN  >agnes !09_S	et	f	\N
162443	turvaste	turvaste =turvas  (PlG  >turvas !07_S	et	f	\N
162444	turvaste	turvaste =turvas  (PlG  >turvane !10_A	et	f	\N
162445	turvaste	"turvane %turva  )NE_aA  <turb ;22_SA	et	f	\N
162446	turvaste	"turvane %turva  )NE_aA  <turv ;22_S	et	f	\N
162450	1908a	### 1908a	et	f	\N
162490	kabli	kabli =kabli  (SgN  >kabli !16_S	et	f	\N
162491	kabli	kabli =kabli  (SgG  >kabli !16_S	et	f	\N
162492	kabli	kabli =kabli  (IndPrPs_  >kablima !27_V	et	f	\N
162493	kabli	kabli =kabli  (ImpPrSg2  >kablima !27_V	et	f	\N
162494	kiiboja	?kiiboja =kiiboja  (SgN  >kiiboja !01_S	et	f	\N
162495	kiiboja	?kiiboja =kiiboja  (SgG  >kiiboja !01_S	et	f	\N
162496	kiiboja	?kiiboja =kiiboja  (SgG  >kiibojas !02_A	et	f	\N
162497	olnd	?olnd =olnd  (SgN  >olnd !22_S	et	f	\N
162515	helene	helene =helene  (IndPrPs_  >helenema !27_V	et	f	\N
162516	helene	helene =helene  (ImpPrSg2  >helenema !27_V	et	f	\N
162076	võimalikesse	võimalikesse =malikes  (SgAdt  >või+malike !12_S	et	f	\N
162077	võimalikesse	"või+malike %mali  )KE_dS  <või+mali ;17_S	et	f	\N
162078	võimalikesse	võimalikesse =malikes  (SgAdt  >või+malikene !12_S	et	f	\N
162079	võimalikesse	"või+malikene %mali  )KENE_dS  <või+mali ;17_S	et	f	\N
162090	olevate	olevate =oleva  (PlG  >olev !02_A	et	f	\N
162091	olevate	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
162102	võistluskogumine	võistluskogumine =kogumine  (SgN  >võistlus+kogumine !12_S	et	f	\N
162103	võistluskogumine	"võistlus+kogumine %kogumi  )NE_aA  <võistlus+kogum ;02_S	et	f	\N
162127	jõukohane	jõukohane =kohane  (SgN  >jõu+kohane !10_A	et	f	\N
162128	jõukohane	"jõu+kohane %koha  )NE_aA  <jõu+koha ;17_S	et	f	\N
162129	jõukohane	"jõu+kohane %koha  )NE_aA  <jõu+koht ;22_S	et	f	\N
162153	murdelisemaks	murdelisemaks =murdelisema  (SgTr  >murdelisem !02_A	et	f	\N
162154	murdelisemaks	"murdelisem %murde  )LISEM_cA  <murre ;06_S	et	f	\N
162155	murdelisemaks	"murdelisem %murdeli  )SEM_cA  <murdel ;02_S	et	f	\N
162156	murdelisemaks	"murdelisem %murdelise  )M_cA  <murdeline ;12_A	et	f	\N
162170	soovitusega	soovitusega =soovituse  (SgKom  >soovitus !11_S	et	f	\N
162171	soovitusega	"soovitus %soovita  )US_vS  <soovitama ;27_V	et	f	\N
162172	soovitusega	"soovitus %soovi  )TUS1_aS  <soovima ;28_V	et	f	\N
162173	soovitusega	"soovitus %soovi  )TUS2_aS  <soov ;22_S	et	f	\N
162182	lähtuvalt	lähtuvalt =lähtuva  (SgAbl  >lähtuv !02_A	et	f	\N
162183	lähtuvalt	"lähtuv %lähtu  )V_vA  <lähtuma ;27_V	et	f	\N
162184	lähtuvalt	lähtuvalt =lähtuvalt  (ID  >lähtuvalt !41_D	et	f	\N
162185	lähtuvalt	"lähtuvalt %lähtu  )VALT_mD  <lähtuma ;27_V	et	f	\N
162198	koostati	koostati =koosta  (IndIpfIps  >koostama !27_V	et	f	\N
162199	koostati	koostati =tati  (SgG  >koos+tatt !22_S	et	f	\N
162213	täiendanud	täiendanud =täienda  (PtsPtPs  >täiendama !27_V	et	f	\N
162214	täiendanud	täiendanud =täiendanu  (PlN  >täiendanu !01_S	et	f	\N
162215	täiendanud	"täiendanu %täienda  )NU_vS  <täiendama ;27_V	et	f	\N
162216	täiendanud	täiendanud =täiendanud  (ID  >täiendanud !41_A	et	f	\N
162217	täiendanud	"täiendanud %täienda  )NUD_vA  <täiendama ;27_V	et	f	\N
162232	algupära	algupära =pära  (SgN  >algu+pära !17_S	et	f	\N
162233	algupära	algupära =pära  (SgG  >algu+pära !17_S	et	f	\N
162234	algupära	algupära =pära  (SgP  >algu+pära !17_S	et	f	\N
162241	lühem	lühem =lühem  (SgN  >lühem !02_A	et	f	\N
162242	lühem	"lühem %lühe  )M_cA  <lühike ;12_A	et	f	\N
162249	ühtainust	ühtainust =ainu  (SgEl  >üht+ainus !07_AS	et	f	\N
162250	ühtainust	ühtainust =ainu  (SgEl  >üht+ainu !16_S	et	f	\N
162251	ühtainust	ühtainust =ainu  (PlEl  >üht+ain !22_S	et	f	\N
162252	ühtainust	ühtainust =ainus  (SgP  >üht+ainus !05_AS	et	f	\N
162253	ühtainust	ühtainust =ainus  (SgP  >üht+ainus !07_AS	et	f	\N
162263	jutustav	jutustav =jutusta  (PtsPrPs  >jutustama !27_V	et	f	\N
162264	jutustav	jutustav =jutustav  (SgN  >jutustav !02_A	et	f	\N
162265	jutustav	"jutustav %jutusta  )V_vA  <jutustama ;27_V	et	f	\N
162268	näidatav	näidatav =näida  (PtsPrIps  >näitama !29_V	et	f	\N
162269	näidatav	näidatav =näidatav  (SgN  >näidatav !02_A	et	f	\N
162270	näidatav	"näidatav %näida  )TAV_vAS  <näitama ;29_V	et	f	\N
162276	jutustuse	jutustuse =jutustuse  (SgG  >jutustus !11_S	et	f	\N
162277	jutustuse	"jutustus %jutusta  )US_vS  <jutustama ;27_V	et	f	\N
162290	konkreetsuse	konkreetsuse =konkreetsuse  (SgG  >konkreetsus !11~09_S	et	f	\N
162291	konkreetsuse	"konkreetsus %konkreetse  )US_aS  <konkreetne ;02_A	et	f	\N
162298	viite	viite =vii  (PlG  >viis !14_N	et	f	\N
162299	viite	viite =vii  (IndPrPl2  >viima !38_V	et	f	\N
162300	viite	viite =viite  (SgG  >viide !06_S	et	f	\N
162301	viite	viite =viite  (PlP  >viit !22_S	et	f	\N
162306	vägilasmuistendid	?vägilasmuistendid =vägilasmuistendi  (PlN  >vägilasmuistent !22_S	et	f	\N
162307	vägilasmuistendid	?vägilasmuistendid =vägilasmuistendi  (IndPrSg2  >vägilasmuistentima !28_V	et	f	\N
162308	vägilasmuistendid	?vägilasmuistendid =lasmuistendi  (PlN  >vägi+lasmuistent !22_S	et	f	\N
162319	paigas	paigas =paiga  (SgIn  >paik !22_S	et	f	\N
162320	paigas	paigas =paigas  (SgN  >paigas !09_S	et	f	\N
162321	rändrahnude	rändrahnude =ude  (SgN  >ränd+rahn+ude !04_S	et	f	\N
162322	rändrahnude	rändrahnude =rahnu  (PlG  >ränd+rahn !22_S	et	f	\N
162337	vanavaras	vanavaras =vara  (SgIn  >vana+vara !17_S	et	f	\N
162338	vanavaras	vanavaras =varas  (SgN  >vana+varas !07_S	et	f	\N
162353	sooniste	sooniste =soonis  (PlG  >soonis !09_S	et	f	\N
162354	sooniste	sooniste =soonis  (PlG  >soonine !10_A	et	f	\N
162375	turvas	turvas =turva  (SgIn  >turb !22_SA	et	f	\N
162376	turvas	turvas =turva  (SgIn  >turv !22_S	et	f	\N
162377	turvas	turvas =turva  (IndIpfSg3  >turvama !29_V	et	f	\N
162378	turvas	turvas =turvas  (SgN  >turvas !07_S	et	f	\N
162383	freesiturvast	?freesiturvast =freesiturva  (SgEl  >freesiturva !16_S	et	f	\N
162384	freesiturvast	?freesiturvast =freesiturvas  (SgP  >freesiturvane !12_A	et	f	\N
162385	freesiturvast	?freesiturvast =iturva  (SgEl  >frees+iturva !01_S	et	f	\N
162386	freesiturvast	?freesiturvast =iturvas  (SgP  >frees+iturvane !12_A	et	f	\N
162387	kullamaa	kullamaa =maa  (SgN  >kulla+maa !26_S	et	f	\N
162131	rahvaluuleliigiga	rahvaluuleliigiga =iga  (SgP  >rahva+luule+liig+iga !18_S	et	f	\N
162132	rahvaluuleliigiga	rahvaluuleliigiga =liigi  (SgKom  >rahva+luule+liik !22_S	et	f	\N
162137	keelelisele	keelelisele =keelelise  (SgAll  >keeleline !12_A	et	f	\N
162138	keelelisele	"keeleline %keele  )LINE_aA  <keel ;13_S	et	f	\N
162150	sihilikult	sihilikult =sihiliku  (SgAbl  >sihilik !25_A	et	f	\N
162151	sihilikult	sihilikult =sihilikult  (ID  >sihilikult !41_D	et	f	\N
162152	sihilikult	"sihilikult %sihiliku  )LT_mD  <sihilik ;25_A	et	f	\N
162176	temaatilisena	temaatilisena =temaatilise  (SgEs  >temaatiline !12_A	et	f	\N
162177	temaatilisena	temaatilisena =atilise  (SgEs  >tema+atiline !12_A	et	f	\N
162178	temaatilisena	"tema+atiline %ati  )LINE_aA  <tema+att ;22_S	et	f	\N
162195	asustusajaloo	asustusajaloo =loo  (SgG  >asustus+aja+lugu !18_S	et	f	\N
162196	asustusajaloo	asustusajaloo =loo  (SgG  >asustus+aja+loog !22_S	et	f	\N
162197	asustusajaloo	asustusajaloo =loo  (SgG  >asustus+aja+lood !22_S	et	f	\N
162201	kogujaile	kogujaile =koguja  (PlAll  >koguja !01_S	et	f	\N
162202	kogujaile	"koguja %kogu  )JA_vS  <koguma ;27_V	et	f	\N
162211	jutudest	?jutudest =jutu  (PlEl  >jutu !16_S	et	f	\N
162212	jutudest	?jutudest =jutudes  (SgP  >jutudene !12_A	et	f	\N
162237	viskamise	viskamise =viskamise  (SgG  >viskamine !12_S	et	f	\N
162238	viskamise	"viskamine %viska  )MINE_vS  <viskama ;29_V	et	f	\N
162245	asjalikum	asjalikum =asjalikum  (SgN  >asjalikum !02_A	et	f	\N
162246	asjalikum	"asjalikum %asjaliku  )M_cA  <asjalik ;25_A	et	f	\N
162278	harulikut	### harulikut	et	f	\N
162281	värvivaesem	värvivaesem =vaesem  (SgN  >värvi+vaesem !02_A	et	f	\N
162282	värvivaesem	"värvi+vaesem %vae  )SEM_cA  <värvi+vaag ;22_S	et	f	\N
162283	värvivaesem	"värvi+vaesem %vaese  )M_cA  <värvi+vaene ;10_AS	et	f	\N
162289	muistendrühmas	?muistendrühmas =muistendrühma  (SgIn  >muistendrühma !16_S	et	f	\N
162313	moodustumist	moodustumist =moodustumis  (SgP  >moodustumine !12_S	et	f	\N
162314	moodustumist	"moodustumine %moodustu  )MINE_vS  <moodustuma ;27_V	et	f	\N
162327	kihelkonnast	kihelkonnast =kihelkonna  (SgEl  >kihelkond !22_S	et	f	\N
162328	kihelkonnast	kihelkonnast =kihelkonnas  (SgP  >kihelkonnane !12_A	et	f	\N
162329	kihelkonnast	"kihelkonnane %kihelkonna  )NE_aA  <kihelkond ;22_S	et	f	\N
162330	vaadelda	vaadelda =vaadel  (Inf  >vaatlema !30_V	et	f	\N
162331	vaadelda	vaadelda =vaadel  (IndPrIps_  >vaatlema !30_V	et	f	\N
162339	varbolast	?varbolast =varbola  (SgEl  >varbola !01_S	et	f	\N
162340	varbolast	?varbolast =varbolas  (SgP  >varbolane !12_S	et	f	\N
162345	turba	turba =turba  (SgG  >turvas !07_S	et	f	\N
162346	turba	turba =turba  (SgG  >turp !22_S	et	f	\N
162347	turba	turba =turba  (SgP  >turb !22_SA	et	f	\N
162349	turba	turba =turba  (SgAdt  >turb !22_SA	et	f	\N
162356	jaagna	?jaagna =jaagna  (SgN  >jaagna !01_S	et	f	\N
162357	jaagna	?jaagna =jaagna  (SgG  >jaagna !01_S	et	f	\N
162358	jaagna	?jaagna =jaagna  (IndPrPs_  >jaagnama !29_V	et	f	\N
162359	jaagna	?jaagna =jaagna  (ImpPrSg2  >jaagnama !29_V	et	f	\N
162404	viruküla	viruküla =küla  (SgN  >viru+küla !17_S	et	f	\N
162405	viruküla	viruküla =küla  (SgG  >viru+küla !17_S	et	f	\N
162406	viruküla	viruküla =küla  (SgP  >viru+küla !17_S	et	f	\N
162415	khk	### khk	et	f	\N
162421	varbola	?varbola =varbola  (SgN  >varbola !01_S	et	f	\N
162422	varbola	?varbola =varbola  (SgG  >varbola !01_S	et	f	\N
162437	1907a	### 1907a	et	f	\N
162449	korb	?korb =korb  (SgN  >korb !22_S	et	f	\N
162453	urgeta	?urgeta =urge  (IndPrIps_  >urgema !27_V	et	f	\N
162454	urgeta	?urgeta =urgeta  (IndPrPs_  >urgetama !27_V	et	f	\N
162455	urgeta	?urgeta =urgeta  (ImpPrSg2  >urgetama !27_V	et	f	\N
162461	lurichiga	?lurichiga =lurichi  (SgKom  >lurichi !01_S	et	f	\N
162462	lurichiga	?lurichiga =lurichi  (SgKom  >lurich !22_S	et	f	\N
162465	päärson	?päärson =päärson  (SgN  >päärson !02_S	et	f	\N
162467	põldotsa	põldotsa =otsa  (SgG  >põld+ots !23?22_S	et	f	\N
162468	põldotsa	põldotsa =otsa  (SgP  >põld+ots !23?22_S	et	f	\N
162469	põldotsa	põldotsa =otsa  (SgAdt  >põld+ots !23?22_S	et	f	\N
162470	terjatu	?terjatu =terjatu  (SgN  >terjatu !01_AS	et	f	\N
162471	terjatu	?terjatu =terjatu  (SgG  >terjatu !01_AS	et	f	\N
162472	terjatu	?terjatu =terjatu  (IndPrPs_  >terjatuma !27_V	et	f	\N
162473	terjatu	?terjatu =terjatu  (ImpPrSg2  >terjatuma !27_V	et	f	\N
162483	teerajatu	teerajatu =rajatu  (SgN  >tee+rajatu !01_AS	et	f	\N
162484	teerajatu	"tee+rajatu %raja  )TU2_kA  <tee+raja ;17_S	et	f	\N
162485	teerajatu	"tee+rajatu %raja  )TU2_kA  <tee+rada ;18_S	et	f	\N
162486	teerajatu	teerajatu =rajatu  (SgG  >tee+rajatu !01_AS	et	f	\N
162498	rautatud	rautatud =rauta  (PtsPtIps  >rautama !27_V	et	f	\N
162499	rautatud	rautatud =rautatu  (PlN  >rautatu !01_S	et	f	\N
162500	rautatud	"rautatu %rauta  )TU1_vS  <rautama ;27_V	et	f	\N
162501	rautatud	rautatud =rautatud  (ID  >rautatud !41_A	et	f	\N
162502	rautatud	"rautatud %rauta  )TUD_vA  <rautama ;27_V	et	f	\N
162506	kiigealune	kiigealune =alune  (SgN  >kiige+alune !10_AS	et	f	\N
162507	kiigealune	"kiige+alune %alu  )NE_aA  <kiige+alg ;22_S	et	f	\N
162508	kibuna	kibuna =kibu  (SgEs  >kibu !17_S	et	f	\N
162509	kibuna	kibuna =kibuna  (SgG  >kibun !02_S	et	f	\N
162139	murdekeel	murdekeel =kee  (SgAd  >murde+kesi !15_S	et	f	\N
162140	murdekeel	murdekeel =kee  (SgAd  >murde+kee !26_S	et	f	\N
162141	murdekeel	murdekeel =keel  (SgN  >murde+keel !13_S	et	f	\N
162145	ebajärjekindlusi	ebajärjekindlusi =kindlusi  (PlP  >eba+järje+kindlus !11_S	et	f	\N
162146	ebajärjekindlusi	"eba+järje+kindlus %kindla  )US_aS  <eba+järje+kindel ;02_A	et	f	\N
162161	jutustajale	jutustajale =jutustaja  (SgAll  >jutustaja !01_S	et	f	\N
162162	jutustajale	"jutustaja %jutusta  )JA_vS  <jutustama ;27_V	et	f	\N
162163	sõjatee	sõjatee =tee  (SgN  >sõja+tee !26_S	et	f	\N
162164	sõjatee	sõjatee =tee  (SgG  >sõja+tee !26_S	et	f	\N
162179	objektikesksena	?objektikesksena =objektikeskse  (SgEs  >objektikeskne !02_A	et	f	\N
162186	väla	?väla =väla  (SgN  >väla !17_S	et	f	\N
162187	väla	?väla =väla  (SgG  >väla !17_S	et	f	\N
162188	väla	?väla =väla  (SgP  >väla !17_S	et	f	\N
162189	väla	?väla =väla  (IndPrPs_  >välama !27_V	et	f	\N
162190	väla	?väla =väla  (ImpPrSg2  >välama !27_V	et	f	\N
162200	muistendivalimik	?muistendivalimik =muistendivalimik  (SgN  >muistendivalimik !02_S	et	f	\N
162223	kohapärimustest	kohapärimustest =muste  (PlEl  >koha+päri+must !22_AS	et	f	\N
162224	kohapärimustest	kohapärimustest =pärimus  (PlEl  >koha+pärimus !11_S	et	f	\N
162257	kokkusurutud	kokkusurutud =suru  (PtsPtIps  >kokku+_suruma !27_V	et	f	\N
162258	kokkusurutud	kokkusurutud =surutu  (PlN  >kokku+surutu !01_AS	et	f	\N
162259	kokkusurutud	"kokku+surutu %suru  )TU2_kA  <kokku+suru ;17_S	et	f	\N
162266	märkimisega	märkimisega =märkimise  (SgKom  >märkimine !12_S	et	f	\N
162267	märkimisega	"märkimine %märki  )MINE_vS  <märkima ;28_V	et	f	\N
162295	jutustatut	jutustatut =jutustatu  (SgP  >jutustatu !01_S	et	f	\N
162297	jutustatut	"jutustatu %jutusta  )TU1_vS  <jutustama ;27_V	et	f	\N
162312	püüävad	?püüävad =püüäva  (PlN  >püüäva !01_S	et	f	\N
162315	saamist	saamist =saami  (SgEl  >saam !22_S	et	f	\N
162316	saamist	saamist =saamis  (SgP  >saamine !12?10_S	et	f	\N
162317	saamist	"saamine %saa  )MINE_vS  <saama ;37_V	et	f	\N
162318	saamist	"saamine %saami  )NE_aA  <saam ;22_S	et	f	\N
162323	materjalist	materjalist =materjali  (SgEl  >materjal !19_S	et	f	\N
162324	materjalist	materjalist =materjalis  (SgP  >materjaline !12_A	et	f	\N
162325	materjalist	"materjaline %materjali  )NE_aA  <materjal ;19_S	et	f	\N
162334	seletavaid	seletavaid =seletava  (PlP  >seletav !02_A	et	f	\N
162336	seletavaid	"seletav %seleta  )V_vA  <seletama ;27_V	et	f	\N
162360	kõverikus	?kõverikus =kõveriku  (SgIn  >kõverik !25_SA	et	f	\N
162361	kõverikus	?kõverikus =kõveriku  (IndIpfSg3  >kõverikuma !27_V	et	f	\N
162362	kõverikus	?kõverikus =kõverikus  (SgN  >kõverikus !11?09_S	et	f	\N
162363	kõverikus	?kõverikus =iku  (SgIn  >kõver+iku !16_S	et	f	\N
162364	kõverikus	?kõverikus =iku  (SgIn  >kõver+ikk !22_S	et	f	\N
162365	kõverikus	?kõverikus =ikus  (SgN  >kõver+ikus !09_S	et	f	\N
162394	paulmann	?paulmann =paulmann  (SgN  >paulmann !22_S	et	f	\N
162407	põltsamaa	põltsamaa =maa  (SgN  >põltsa+maa !26_S	et	f	\N
162408	põltsamaa	põltsamaa =maa  (SgG  >põltsa+maa !26_S	et	f	\N
162417	linnapa	?linnapa =linnapa  (SgN  >linnapa !01_S	et	f	\N
162418	linnapa	?linnapa =linnapa  (SgG  >linnapa !01_S	et	f	\N
162419	linnapa	?linnapa =apa  (SgN  >linn+apa !16_S	et	f	\N
162420	linnapa	?linnapa =apa  (SgG  >linn+apa !16_S	et	f	\N
162423	manivald	?manivald =manivald  (SgN  >manivald !22_S	et	f	\N
162424	peamees	peamees =mee  (SgIn  >pea+mesi !15_S	et	f	\N
162425	peamees	peamees =mees  (SgN  >pea+mees !13_S	et	f	\N
162428	linmese	?linmese =linmese  (SgG  >linmene !10_A	et	f	\N
162432	kiige	kiige =kiige  (SgN  >kiige !06_S	et	f	\N
162435	kiige	kiige =kiige  (SgG  >kiik !22_S	et	f	\N
162436	nurmbek	?nurmbek =nurmbek  (SgN  >nurmbek !02_S	et	f	\N
162447	anu	anu =anu  (IndPrPs_  >anuma !27_V	et	f	\N
162448	anu	anu =anu  (ImpPrSg2  >anuma !27_V	et	f	\N
162451	luuri	luuri =luuri  (IndPrPs_  >luurima !28_V	et	f	\N
162452	luuri	luuri =luuri  (ImpPrSg2  >luurima !28_V	et	f	\N
162477	pandigi	pandigi =pan  (IndIpfIps^  >panema !36_V	et	f	\N
162478	pandigi	pandigi =pandi  (SgG^  >pant !22_S	et	f	\N
162479	pandigi	pandigi =pandi  (SgP^  >pand !22_S	et	f	\N
162480	pandigi	pandigi =pandi  (SgAdt^  >pand !22_S	et	f	\N
162481	pandigi	pandigi =pandi  (IndPrPs_^  >pantima !28_V	et	f	\N
162482	pandigi	pandigi =pandi  (ImpPrSg2^  >pantima !28_V	et	f	\N
162536	dets	?dets =dets  (SgN  >dets !22_S	et	f	\N
162540	nuudi	nuudi =nuudi  (SgG  >nuut !22_S	et	f	\N
162541	nuudi	nuudi =nuudi  (IndPrPs_  >nuutima !28_V	et	f	\N
162542	nuudi	nuudi =nuudi  (ImpPrSg2  >nuutima !28_V	et	f	\N
162544	kupjale	kupjale =kupja  (SgAll  >kupjas !02_A	et	f	\N
162545	kupjale	kupjale =kupja  (SgAll  >kubjas !07_S	et	f	\N
162556	akkas	?akkas =akka  (IndIpfSg3  >akkama !29_V	et	f	\N
162557	akkas	?akkas =akkas  (SgN  >akkas !07_S	et	f	\N
162586	pühkind	?pühkind =pühkind  (SgN  >pühkind !02_S	et	f	\N
162592	nisuke	nisuke =nisuke  (SgN  >nisuke !12_P	et	f	\N
162593	nisuke	"nisuke %nisu  )KE_dS  <nisu ;17_S	et	f	\N
162594	vanarahvas	vanarahvas =rahva  (SgIn  >vana+rahvas !07_S	et	f	\N
162159	kohapealsete	kohapealsete =sete  (SgN  >koha+peal+sete !06_S	et	f	\N
162160	kohapealsete	kohapealsete =pealse  (PlG  >koha+pealne !02_AS	et	f	\N
162165	ohvrikivi	ohvrikivi =kivi  (SgN  >ohvri+kivi !17_S	et	f	\N
162166	ohvrikivi	ohvrikivi =kivi  (SgG  >ohvri+kivi !17_S	et	f	\N
162167	ohvrikivi	ohvrikivi =kivi  (SgP  >ohvri+kivi !17_S	et	f	\N
162174	esineva	esineva =esineva  (SgG  >esinev !02_A	et	f	\N
162175	esineva	"esinev %esine  )V_vA  <esinema ;27_V	et	f	\N
162180	tüübikesksest	?tüübikesksest =tüübikeskse  (SgEl  >tüübikeskne !02_A	et	f	\N
162181	tüübikesksest	?tüübikesksest =tüübikeskses  (SgP  >tüübikesksene !12_A	et	f	\N
162191	looduslikiu	?looduslikiu =looduslikiu  (SgN  >looduslikiu !01_S	et	f	\N
162192	looduslikiu	?looduslikiu =looduslikiu  (SgG  >looduslikiu !01_S	et	f	\N
162193	looduslikiu	?looduslikiu =duslikiu  (SgN  >loo+duslikiu !01_S	et	f	\N
162194	looduslikiu	?looduslikiu =duslikiu  (SgG  >loo+duslikiu !01_S	et	f	\N
162203	raamatukeses	raamatukeses =raamatukese  (SgIn  >raamatuke !12_S	et	f	\N
162204	raamatukeses	"raamatuke %raamatu  )KE_dS  <raamat ;02_S	et	f	\N
162205	raamatukeses	raamatukeses =raamatukese  (SgIn  >raamatukene !12_S	et	f	\N
162206	raamatukeses	"raamatukene %raamatu  )KENE_dS  <raamat ;02_S	et	f	\N
162207	raamatukeses	raamatukeses =atukese  (SgIn  >raam+atuke !12_S	et	f	\N
162208	raamatukeses	"raam+atuke %atu  )KE_dS  <raam+att ;22_S	et	f	\N
162209	raamatukeses	raamatukeses =atukese  (SgIn  >raam+atukene !12_S	et	f	\N
162210	raamatukeses	"raam+atukene %atu  )KENE_dS  <raam+att ;22_S	et	f	\N
162220	töötajaks	töötajaks =töötaja  (SgTr  >töötaja !01_S	et	f	\N
162221	töötajaks	"töötaja %tööta  )JA_vS  <töötama ;27_V	et	f	\N
162222	töötajaks	töötajaks =jaks  (SgN  >tööta+jaks !22_S	et	f	\N
162225	rahvajutuliigi	rahvajutuliigi =liigi  (SgG  >rahva+jutu+liik !22_S	et	f	\N
162226	rahvajutuliigi	rahvajutuliigi =liigi  (SgP  >rahva+jutu+liig !22_S	et	f	\N
162227	rahvajutuliigi	rahvajutuliigi =liigi  (SgAdt  >rahva+jutu+liig !22_S	et	f	\N
162228	rahvajutuliigi	rahvajutuliigi =lii  (SgN^  >rahva+jutu+lii !26_S	et	f	\N
162229	rahvajutuliigi	rahvajutuliigi =lii  (SgG^  >rahva+jutu+lii !26_S	et	f	\N
162230	rahvuvahelile	?rahvuvahelile =lile  (SgN  >rahvu+vahe+lile !16_S	et	f	\N
162231	rahvuvahelile	?rahvuvahelile =lile  (SgG  >rahvu+vahe+lile !16_S	et	f	\N
162247	konstanteeruv	?konstanteeruv =konstanteeru  (PtsPrPs  >konstanteeruma !27_V	et	f	\N
162248	konstanteeruv	?konstanteeruv =konstanteeruv  (SgN  >konstanteeruv !02_A	et	f	\N
162254	pidav	pidav =pida  (PtsPrPs  >pidama !28_V	et	f	\N
162255	pidav	pidav =pidav  (SgN  >pidav !02_A	et	f	\N
162256	pidav	"pidav %pida  )V_vA  <pidama ;28_V	et	f	\N
162260	kirjeldav	kirjeldav =kirjelda  (PtsPrPs  >kirjeldama !27_V	et	f	\N
162261	kirjeldav	kirjeldav =kirjeldav  (SgN  >kirjeldav !02_A	et	f	\N
162262	kirjeldav	"kirjeldav %kirjelda  )V_vA  <kirjeldama ;27_V	et	f	\N
162271	tunnistatud	tunnistatud =tunnista  (PtsPtIps  >tunnistama !27_V	et	f	\N
162272	tunnistatud	tunnistatud =tunnistatu  (PlN  >tunnistatu !01_S	et	f	\N
162273	tunnistatud	"tunnistatu %tunnista  )TU1_vS  <tunnistama ;27_V	et	f	\N
162274	tunnistatud	tunnistatud =tunnistatud  (ID  >tunnistatud !41_A	et	f	\N
162275	tunnistatud	"tunnistatud %tunnista  )TUD_vA  <tunnistama ;27_V	et	f	\N
162279	seletavaks	seletavaks =seletava  (SgTr  >seletav !02_A	et	f	\N
162280	seletavaks	"seletav %seleta  )V_vA  <seletama ;27_V	et	f	\N
162286	usaldatavuse	usaldatavuse =usaldatavuse  (SgG  >usaldatavus !11?09_S	et	f	\N
162287	usaldatavuse	"usaldatavus %usalda  )TAVUS_aS  <usaldama ;27_V	et	f	\N
162288	usaldatavuse	"usaldatavus %usaldatava  )US_aS  <usaldatav ;02_A	et	f	\N
162292	veenda	veenda =veen  (Inf  >veenma !33_V	et	f	\N
162293	veenda	veenda =veen  (IndPrIps_  >veenma !33_V	et	f	\N
162302	tekke-	tekke- =tekke  (SgG  >teke !06_S	et	f	\N
162303	tekke-	tekke- =tekke  (PlP  >tekk !22_S	et	f	\N
162332	tekkimisest	tekkimisest =tekkimise  (SgEl  >tekkimine !12_S	et	f	\N
162333	tekkimisest	"tekkimine %tekki  )MINE_vS  <tekkima ;27_V	et	f	\N
162335	tekkimisest	"tekkimine %tekki  )MINE_vS  <tekkima ;28_V	et	f	\N
162348	turba	turba =turba  (SgG  >turvas !07_S	et	f	\N
162350	turba	turba =turba  (SgG  >turp !22_S	et	f	\N
162351	turba	turba =turba  (SgP  >turb !22_SA	et	f	\N
162352	turba	turba =turba  (SgAdt  >turb !22_SA	et	f	\N
162366	teemulde	teemulde =mulde  (SgG  >tee+mulle !06_S	et	f	\N
162367	teemulde	teemulde =mulde  (PlP  >tee+muld !22_S	et	f	\N
162368	elamaa	?elamaa =elamaa  (SgN  >elamaa !26_S	et	f	\N
162369	elamaa	?elamaa =elamaa  (SgG  >elamaa !26_S	et	f	\N
162370	turbasse	turbasse =turba  (SgIll  >turvas !07_S	et	f	\N
162371	turbasse	turbasse =turba  (SgIll  >turp !22_S	et	f	\N
162372	turbasse	turbasse =turbas  (SgAdt  >turbane !12_A	et	f	\N
162373	turbasse	"turbane %turba  )NE_aA  <turvas ;07_S	et	f	\N
162374	turbasse	"turbane %turba  )NE_aA  <turp ;22_S	et	f	\N
162412	saliste	?saliste =salis  (PlG  >salis !09_S	et	f	\N
162413	saliste	?saliste =salis  (PlG  >saline !10_A	et	f	\N
162414	saliste	?saliste =saliste  (PlP  >salist !22_S	et	f	\N
162440	piirsalu	piirsalu =salu  (SgN  >piir+salu !17_S	et	f	\N
162441	piirsalu	piirsalu =salu  (SgG  >piir+salu !17_S	et	f	\N
162442	piirsalu	piirsalu =salu  (SgP  >piir+salu !17_S	et	f	\N
162388	kullamaa	kullamaa =maa  (SgG  >kulla+maa !26_S	et	f	\N
162395	matsu	matsu =matsu  (SgG  >mats !22_S	et	f	\N
162396	matsu	matsu =matsu  (SgG  >mats !22_SA	et	f	\N
162397	matsu	matsu =matsu  (SgP  >mats !22_S	et	f	\N
162399	matsu	matsu =matsu  (SgP  >mats !22_SA	et	f	\N
162400	matsu	matsu =matsu  (SgAdt  >mats !22_S	et	f	\N
162401	matsu	matsu =matsu  (SgAdt  >mats !22_SA	et	f	\N
162402	matsu	matsu =matsu  (IndPrPs_  >matsuma !28_V	et	f	\N
162403	matsu	matsu =matsu  (ImpPrSg2  >matsuma !28_V	et	f	\N
162416	1923a	### 1923a	et	f	\N
162426	soine	soine =soine  (SgN  >soine !10_A	et	f	\N
162427	soine	"soine %soi  )NE_aA  <soo ;26_S	et	f	\N
162429	ehitanud	ehitanud =ehita  (PtsPtPs  >ehitama !27_V	et	f	\N
162430	ehitanud	ehitanud =ehitanu  (PlN  >ehitanu !01_S	et	f	\N
162431	ehitanud	"ehitanu %ehita  )NU_vS  <ehitama ;27_V	et	f	\N
162433	ehitanud	ehitanud =ehitanud  (ID  >ehitanud !41_A	et	f	\N
162434	ehitanud	"ehitanud %ehita  )NUD_vA  <ehitama ;27_V	et	f	\N
162438	ellamaa	?ellamaa =ellamaa  (SgN  >ellamaa !26_S	et	f	\N
162439	ellamaa	?ellamaa =ellamaa  (SgG  >ellamaa !26_S	et	f	\N
162466	1910a	### 1910a	et	f	\N
162487	linroos	?linroos =linroo  (SgIn  >linroo !26_S	et	f	\N
162488	linroos	?linroos =linroos  (SgN  >linroos !22_S	et	f	\N
162503	jaagujüri	?jaagujüri =jaagujüri  (SgG  >jaagujür !19_S	et	f	\N
162504	jaagujüri	?jaagujüri =jaagujüri  (SgP  >jaagujür !19_S	et	f	\N
162505	jaagujüri	?jaagujüri =jaagujüri  (SgAdt  >jaagujür !19_S	et	f	\N
162517	1917a	### 1917a	et	f	\N
162525	kustas	?kustas =kusta  (SgIn  >kusta !16_S	et	f	\N
162526	kustas	?kustas =kusta  (IndIpfSg3  >kustama !29_V	et	f	\N
162527	kustas	?kustas =kustas  (SgN  >kustas !07_S	et	f	\N
162537	1904a	### 1904a	et	f	\N
162538	võdlemisi	?võdlemisi =võdlemisi  (ID  >võdlemisi !41_D	et	f	\N
162539	võdlemisi	?võdlemisi =võdlemisi  (PlP  >võdlemine !12_S	et	f	\N
162548	vainu	vainu =vainu  (SgN  >vainu !01_S	et	f	\N
162549	vainu	vainu =vainu  (SgG  >vainu !01_S	et	f	\N
162551	mõisaaegas	?mõisaaegas =aegas  (SgN  >mõisa+aegas !07_S	et	f	\N
162564	luud	luud =luu  (PlN  >luu !26_S	et	f	\N
162565	luud	luud =luu  (SgP  >luu !26_S	et	f	\N
162566	luud	luud =luud  (SgN  >luud !22_S	et	f	\N
162577	tütretütat	?tütretütat =tüta  (SgP  >tütre+tüta !16_S	et	f	\N
162578	tütretütat	?tütretütat =tütat  (SgN  >tütre+tütat !02_S	et	f	\N
162579	abordi	abordi =abordi  (SgG  >abort !22_S	et	f	\N
162580	abordi	abordi =abordi  (IndPrPs_  >abortima !28_V	et	f	\N
162581	abordi	abordi =abordi  (ImpPrSg2  >abortima !28_V	et	f	\N
162589	70aastatel	aastatel =aasta  (PlAd  >aasta !01_S	et	f	\N
162590	70aastatel	aastatel =tate  (PlAd  >aas+tatt !22_S	et	f	\N
162596	odolemma	?odolemma =odolemma  (SgN  >odolemma !16_S	et	f	\N
162597	odolemma	?odolemma =odolemma  (SgG  >odolemma !16_S	et	f	\N
162603	mare	?mare =mare  (SgN  >mare !16_S	et	f	\N
162604	mare	?mare =mare  (SgG  >mare !16_S	et	f	\N
162605	mare	?mare =mare  (IndPrPs_  >marema !27_V	et	f	\N
162606	mare	?mare =mare  (ImpPrSg2  >marema !27_V	et	f	\N
162615	smagnus	?smagnus =smagnu  (SgIn  >smagnu !01_S	et	f	\N
162616	smagnus	?smagnus =smagnu  (IndIpfSg3  >smagnuma !27_V	et	f	\N
162617	smagnus	?smagnus =smagnus  (SgN  >smagnus !11~09_S	et	f	\N
162624	maalinnast	maalinnast =ast  (SgN  >maa+linn+ast !22_S	et	f	\N
162625	maalinnast	maalinnast =linna  (SgEl  >maa+linn !22_S	et	f	\N
162626	maalinnast	maalinnast =linnas  (SgP  >maa+linnas !09_S	et	f	\N
162627	maalinnast	maalinnast =linnas  (SgP  >maa+linnane !10_A	et	f	\N
162628	maalinnast	"maa+linnane %linna  )NE_aA  <maa+linn ;22_S	et	f	\N
162636	heinamaa	heinamaa =maa  (SgN  >heina+maa !26_S	et	f	\N
162637	heinamaa	heinamaa =maa  (SgG  >heina+maa !26_S	et	f	\N
162646	kaev	kaev =kae  (PtsPrPs  >kaema !27_V	et	f	\N
162647	kaev	kaev =kaev  (SgN  >kaev !22_S	et	f	\N
162648	kaev	"kaev %kae  )V_vA  <kaema ;27_V	et	f	\N
162649	müürid	müürid =müüri  (PlN  >müür !22_S	et	f	\N
162650	müürid	müürid =müüri  (IndPrSg2  >müürima !28_V	et	f	\N
162674	veetõusmest	veetõusmest =tõusme  (SgEl  >vee+tõuse !05_S	et	f	\N
162675	veetõusmest	veetõusmest =tõusmes  (SgP  >vee+tõusmene !12~10_A	et	f	\N
162676	veetõusmest	"vee+tõusmene %tõusme  )NE_aA  <vee+tõuse ;05_S	et	f	\N
162686	aali	?aali =aali  (SgN  >aali !16_S	et	f	\N
162687	aali	?aali =aali  (SgG  >aali !16_S	et	f	\N
162688	aali	?aali =aali  (SgG  >aal !22_S	et	f	\N
162689	aali	?aali =aali  (SgP  >aal !22_S	et	f	\N
162690	aali	?aali =aali  (SgAdt  >aal !22_S	et	f	\N
162691	aali	?aali =aali  (IndPrPs_  >aalima !28_V	et	f	\N
162692	aali	?aali =aali  (ImpPrSg2  >aalima !28_V	et	f	\N
162693	lehtme	?lehtme =lehtme  (SgN  >lehtme !06_S	et	f	\N
162694	lehtme	?lehtme =lehtme  (SgG  >lehtme !06_S	et	f	\N
162695	lehtme	?lehtme =lehtme  (PlP  >lehtm !22_S	et	f	\N
162696	lehtme	?lehtme =lehtme  (IndPrPs_  >lehtmema !27_V	et	f	\N
162697	lehtme	?lehtme =lehtme  (ImpPrSg2  >lehtmema !27_V	et	f	\N
162704	ehrpais	?ehrpais =ehrpa  (PlIn  >ehrpa !01_S	et	f	\N
162705	ehrpais	?ehrpais =ehrpai  (SgIn  >ehrpai !26_S	et	f	\N
162456	talumees	talumees =mee  (SgIn  >talu+mesi !15_S	et	f	\N
162457	talumees	talumees =mees  (SgN  >talu+mees !13_S	et	f	\N
162458	seosest	seosest =seose  (SgEl  >seos !09_S	et	f	\N
162459	seosest	seosest =seoses  (SgP  >seosene !10_A	et	f	\N
162460	seosest	"seosene %seose  )NE_aA  <seos ;09_S	et	f	\N
162463	feliks	?feliks =feli  (SgTr  >feli !17_S	et	f	\N
162464	feliks	?feliks =feli  (KndPrPs  >felima !27_V	et	f	\N
162474	igavene	igavene =igavene  (SgN  >igavene !12_A	et	f	\N
162475	igavene	igavene =vene  (SgN  >iga+vene !16_S	et	f	\N
162476	igavene	igavene =vene  (SgG  >iga+vene !16_S	et	f	\N
162489	1924a	### 1924a	et	f	\N
162510	jaaguri	?jaaguri =jaaguri  (SgN  >jaaguri !01_S	et	f	\N
162511	jaaguri	?jaaguri =jaaguri  (SgG  >jaaguri !01_S	et	f	\N
162512	jaaguri	?jaaguri =jaaguri  (SgG  >jaagur !02_S	et	f	\N
162524	ploompuu	ploompuu =puu  (SgN  >ploom+puu !26_S	et	f	\N
162528	ploompuu	ploompuu =puu  (SgG  >ploom+puu !26_S	et	f	\N
162529	otsari	?otsari =otsari  (SgN  >otsari !01_S	et	f	\N
162530	otsari	?otsari =otsari  (SgG  >otsari !01_S	et	f	\N
162531	otsari	?otsari =otsari  (SgG  >otsar !02_S	et	f	\N
162532	otsari	?otsari =ari  (SgN  >ots+ari !17_S	et	f	\N
162533	otsari	?otsari =ari  (SgG  >ots+ari !17_S	et	f	\N
162534	otsari	?otsari =ari  (SgP  >ots+ari !17_S	et	f	\N
162546	nuuti	nuuti =nuuti  (SgP  >nuut !22_S	et	f	\N
162547	nuuti	nuuti =nuuti  (SgAdt  >nuut !22_S	et	f	\N
162550	1926a	### 1926a	et	f	\N
162552	29dets	?dets =dets  (SgN  >dets !22_S	et	f	\N
162553	väljaotsa	väljaotsa =otsa  (SgG  >välja+ots !23?22_S	et	f	\N
162554	väljaotsa	väljaotsa =otsa  (SgP  >välja+ots !23?22_S	et	f	\N
162555	väljaotsa	väljaotsa =otsa  (SgAdt  >välja+ots !23?22_S	et	f	\N
162582	matis	matis =mati  (SgIn  >mati !16_S	et	f	\N
162583	matis	matis =mati  (SgIn  >matt !22_SA	et	f	\N
162584	juhani	juhani =juha  (SgTer  >juha !17_S	et	f	\N
162585	juhani	juhani =juhani  (SgG  >juhan !02_S	et	f	\N
162587	põles	põles =põle  (PlIn  >põlg !22_S	et	f	\N
162588	põles	põles =põle  (IndIpfSg3  >põlema !27_V	et	f	\N
162598	jaanijüri	jaanijüri =jüri  (SgN  >jaani+jüri !17~16_S	et	f	\N
162599	jaanijüri	jaanijüri =jüri  (SgG  >jaani+jüri !17~16_S	et	f	\N
162600	jaanijüri	jaanijüri =jüri  (SgP  >jaani+jüri !17_S	et	f	\N
162607	janneste	?janneste =jannes  (PlG  >jannes !09_S	et	f	\N
162608	janneste	?janneste =jannes  (PlG  >jannene !10_A	et	f	\N
162618	niinemaa	niinemaa =maa  (SgN  >niine+maa !26_S	et	f	\N
162619	niinemaa	niinemaa =maa  (SgG  >niine+maa !26_S	et	f	\N
162633	kristjani	?kristjani =kristja  (SgTer  >kristja !01_S	et	f	\N
162634	kristjani	?kristjani =kristja  (SgTer  >kristjas !02_A	et	f	\N
162635	kristjani	?kristjani =kristjani  (SgG  >kristjan !02_S	et	f	\N
162642	riidetükikesi	riidetükikesi =tükikesi  (PlP  >riide+tükike !12_S	et	f	\N
162643	riidetükikesi	"riide+tükike %tüki  )KE_dS  <riide+tükk ;22_S	et	f	\N
162644	riidetükikesi	riidetükikesi =tükikesi  (PlP  >riide+tükikene !12_S	et	f	\N
162645	riidetükikesi	"riide+tükikene %tüki  )KENE_dS  <riide+tükk ;22_S	et	f	\N
162668	kollu	?kollu =kollu  (SgN  >kollu !16_S	et	f	\N
162669	kollu	?kollu =kollu  (SgG  >kollu !16_S	et	f	\N
162670	kollu	?kollu =kollu  (IndPrPs_  >kolluma !27_V	et	f	\N
162671	kollu	?kollu =kollu  (ImpPrSg2  >kolluma !27_V	et	f	\N
162698	1919a	### 1919a	et	f	\N
162702	82a	### 82a	et	f	\N
162715	ohukotsa	?ohukotsa =ohukotsa  (SgN  >ohukotsa !16_S	et	f	\N
162716	ohukotsa	?ohukotsa =ohukotsa  (SgG  >ohukotsa !16_S	et	f	\N
162717	ohukotsa	?ohukotsa =kotsa  (SgN  >ohu+kotsa !16_S	et	f	\N
162718	ohukotsa	?ohukotsa =kotsa  (SgG  >ohu+kotsa !16_S	et	f	\N
162734	ligidalt	ligidalt =ligida  (SgAbl  >ligida !02_A	et	f	\N
162735	ligidalt	ligidalt =ligidalt  (ID  >ligidalt !41_DK	et	f	\N
162736	ligidalt	"ligidalt %ligida  )LT_mD  <ligida ;02_A	et	f	\N
162737	surnukonta	?surnukonta =surnukonta  (SgN  >surnukonta !16_S	et	f	\N
162738	surnukonta	?surnukonta =surnukonta  (SgG  >surnukonta !16_S	et	f	\N
162739	surnukonta	?surnukonta =konta  (SgN  >surnu+konta !16_S	et	f	\N
162740	surnukonta	?surnukonta =konta  (SgG  >surnu+konta !16_S	et	f	\N
162758	kl	### kl	et	f	\N
162782	isikutega	isikutega =isiku  (PlKom  >isik !02_S	et	f	\N
162783	isikutega	isikutega =ute  (SgKom  >isik+utt !22_S	et	f	\N
162791	sõjaröövlitest	sõjaröövlitest =test  (SgN  >sõja+röövli+test !22_S	et	f	\N
162792	sõjaröövlitest	sõjaröövlitest =röövli  (PlEl  >sõja+röövel !02_S	et	f	\N
162795	katkihaldjas	katkihaldjas =haldja  (SgIn  >katki+haldjas !02_S	et	f	\N
162796	katkihaldjas	katkihaldjas =haldjas  (SgN  >katki+haldjas !02_S	et	f	\N
162799	magajaid	magajaid =magaja  (PlP  >magaja !01_S	et	f	\N
162800	magajaid	"magaja %maga  )JA_vS  <magama ;27_V	et	f	\N
162808	olijad	olijad =olija  (PlN  >olija !01_S	et	f	\N
162809	olijad	"olija %oli  )JA_vS  <olema ;36_V	et	f	\N
162823	ligidusse	ligidusse =ligidus  (SgAdt  >ligidus !11_S	et	f	\N
162825	ligidusse	"ligidus %ligida  )US_aS  <ligida ;02_A	et	f	\N
162837	saatmises	saatmises =saatmise  (SgIn  >saatmine !12?10_S	et	f	\N
162513	oras	oras =ora  (SgIn  >ora !17_S	et	f	\N
162514	oras	oras =oras  (SgN  >oras !09_S	et	f	\N
162520	materi	?materi =materi  (SgN  >materi !01_S	et	f	\N
162521	materi	?materi =materi  (SgG  >materi !01_S	et	f	\N
162522	materi	?materi =materi  (SgG  >matter !02_S	et	f	\N
162523	kivrjuna	?kivrjuna =kivrju  (SgEs  >kivrju !01_S	et	f	\N
162543	kõvarad	?kõvarad =kõvara  (PlN  >kõvara !01_S	et	f	\N
162560	vundamendi	vundamendi =vundamendi  (SgG  >vundament !22_S	et	f	\N
162561	vundamendi	vundamendi =vundamendi  (IndPrPs_  >vundamentima !28_V	et	f	\N
162562	vundamendi	vundamendi =vundamendi  (ImpPrSg2  >vundamentima !28_V	et	f	\N
162563	tulnd	?tulnd =tulnd  (SgN  >tulnd !22_S	et	f	\N
162571	väepealik	väepealik =pealik  (SgN  >väe+pealik !02_S	et	f	\N
162572	väepealik	väepealik =pealik  (SgN  >väe+pealik !25_S	et	f	\N
162573	tammepuudest	tammepuudest =puu  (PlEl  >tamme+puu !26_S	et	f	\N
162574	tammepuudest	tammepuudest =puude  (SgEl  >tamme+puue !06_S	et	f	\N
162575	tammepuudest	tammepuudest =puudes  (SgP  >tamme+puudene !10_A	et	f	\N
162576	tammepuudest	"tamme+puudene %puude  )NE_aA  <tamme+puue ;06_S	et	f	\N
162591	ülesehitada	?ülesehitada =ülesehita  (Inf  >ülesehitama !27_V	et	f	\N
162610	aliide	?aliide =alii  (PlG  >alii !26_S	et	f	\N
162612	aliide	?aliide =aliide  (SgN  >aliide !16_S	et	f	\N
162613	aliide	?aliide =aliide  (SgG  >aliide !16_S	et	f	\N
162614	aliide	?aliide =aliide  (PlP  >aliid !22_S	et	f	\N
162651	põrutasid	põrutasid =põruta  (IndIpfSg2  >põrutama !27_V	et	f	\N
162652	põrutasid	põrutasid =põruta  (IndIpfPl3  >põrutama !27_V	et	f	\N
162653	varisend	?varisend =varisend  (SgN  >varisend !22_S	et	f	\N
162654	varisend	?varisend =send  (SgN  >vari+send !22_S	et	f	\N
162662	käiku	käiku =käiku  (SgP  >käik !22_S	et	f	\N
162663	käiku	käiku =käiku  (SgAdt  >käik !22_S	et	f	\N
162681	neli-viis	neli-viis =vii  (IndIpfSg3  >neli-viima !38_V	et	f	\N
162682	neli-viis	neli-viis =viis  (SgN  >neli-viis !14_N	et	f	\N
162683	neli-viis	neli-viis =viis  (SgN  >neli-viis !22_S	et	f	\N
162699	kolovere	?kolovere =kolovere  (PlP  >kolover !19_S	et	f	\N
162703	varbolas	?varbolas =varbola  (SgIn  >varbola !01_S	et	f	\N
162719	umistand	?umistand =umistand  (SgN  >umistand !22_S	et	f	\N
162731	kõrtsu	?kõrtsu =kõrtsu  (ID  >kõrtsu !41_D	et	f	\N
162732	kõrtsu	?kõrtsu =kõrtsu  (IndPrPs_  >kõrtsuma !28_V	et	f	\N
162733	kõrtsu	?kõrtsu =kõrtsu  (ImpPrSg2  >kõrtsuma !28_V	et	f	\N
162741	kolju	kolju =kolju  (SgN  >kolju !16_S	et	f	\N
162742	kolju	kolju =kolju  (SgG  >kolju !16_S	et	f	\N
162747	kooljast	kooljast =koolja  (SgEl  >koolja !01_S	et	f	\N
162748	kooljast	"koolja %kool  )JA_vS  <koolma ;33_V	et	f	\N
162749	kooljast	kooljast =koolja  (SgEl  >kooljas !02_S	et	f	\N
162750	kooljast	kooljast =kooljas  (SgP  >kooljane !12~10_A	et	f	\N
162751	kooljast	"kooljane %koolja  )NE_aA  <koolja ;01_S	et	f	\N
162752	kooljast	"kooljane %koolja  )NE_aA  <kooljas ;02_S	et	f	\N
162759	evald	?evald =evald  (SgN  >evald !02_S	et	f	\N
162768	odaotsi	odaotsi =otsi  (SgG  >oda+ots !22_S	et	f	\N
162769	odaotsi	odaotsi =otsi  (SgP  >oda+ots !22_S	et	f	\N
162770	odaotsi	odaotsi =otsi  (SgAdt  >oda+ots !22_S	et	f	\N
162771	odaotsi	odaotsi =otsi  (PlP  >oda+ots !23?22_S	et	f	\N
162806	magajad	magajad =magaja  (PlN  >magaja !01_S	et	f	\N
162807	magajad	"magaja %maga  )JA_vS  <magama ;27_V	et	f	\N
162810	katkuhaldjas	katkuhaldjas =haldja  (SgIn  >katku+haldjas !02_S	et	f	\N
162811	katkuhaldjas	katkuhaldjas =haldjas  (SgN  >katku+haldjas !02_S	et	f	\N
162812	siirdumisega	siirdumisega =siirdumise  (SgKom  >siirdumine !12_S	et	f	\N
162813	siirdumisega	"siirdumine %siirdu  )MINE_vS  <siirduma ;27_V	et	f	\N
162859	katkuaegas	?katkuaegas =aegas  (SgN  >katku+aegas !07_S	et	f	\N
162881	ann	?ann =ann  (SgN  >ann !22_S	et	f	\N
162886	arbas	?arbas =arba  (SgIn  >arba !16_S	et	f	\N
162887	arbas	?arbas =arba  (IndIpfSg3  >arbama !29_V	et	f	\N
162888	arbas	?arbas =arbas  (SgN  >arbas !07_S	et	f	\N
162900	külvavad	külvavad =külva  (IndPrPl3  >külvama !29_V	et	f	\N
162901	külvavad	külvavad =külvava  (PlN  >külvav !02_A	et	f	\N
162902	külvavad	"külvav %külva  )V_vA  <külvama ;29_V	et	f	\N
162908	sirgu	sirgu =sirgu  (ID  >sirgu !41_D	et	f	\N
162909	sirgu	sirgu =sirgu  (SgG  >sirk !22_S	et	f	\N
162910	sirgu	sirgu =sirgu  (IndPrPs_  >sirguma !27_V	et	f	\N
162911	sirgu	sirgu =sirgu  (ImpPrSg2  >sirguma !27_V	et	f	\N
162917	vanaste	?vanaste =vanas  (PlG  >vanas !09_S	et	f	\N
162918	vanaste	?vanaste =vanas  (PlG  >vanane !10_A	et	f	\N
162924	käind	?käind =käind  (SgN  >käind !02_S	et	f	\N
162928	nägemisele	nägemisele =nägemise  (SgAll  >nägemine !12_S	et	f	\N
162929	nägemisele	"nägemine %näge  )MINE_vS  <nägema ;28_V	et	f	\N
162972	kuulmisele	kuulmisele =kuulmise  (SgAll  >kuulmine !12?10_S	et	f	\N
162973	kuulmisele	"kuulmine %kuul  )MINE_vS  <kuulma ;33_V	et	f	\N
162993	laastav	laastav =laasta  (PtsPrPs  >laastama !29~27_V	et	f	\N
162994	laastav	laastav =laastav  (SgN  >laastav !02_A	et	f	\N
162995	laastav	"laastav %laasta  )V_vA  <laastama ;27_V	et	f	\N
162996	laastav	"laastav %laasta  )V_vA  <laastama ;29_V	et	f	\N
162518	keskpaigas	keskpaigas =paiga  (SgIn  >kesk+paik !22_S	et	f	\N
162519	keskpaigas	keskpaigas =paigas  (SgN  >kesk+paigas !09_S	et	f	\N
162535	järvlepp	?järvlepp =järvlepp  (SgN  >järvlepp !22_S	et	f	\N
162558	korstna	korstna =korstna  (SgG  >korsten !02_S	et	f	\N
162559	korstna	korstna =korstna  (SgG  >korsten !08_S	et	f	\N
162567	ehitasid	ehitasid =ehita  (IndIpfSg2  >ehitama !27_V	et	f	\N
162568	ehitasid	ehitasid =ehita  (IndIpfPl3  >ehitama !27_V	et	f	\N
162569	sääl	?sääl =sää  (SgAd  >sää !26_S	et	f	\N
162570	sääl	?sääl =sääl  (SgN  >sääl !22_S	et	f	\N
162601	miilima	?miilima =miili  (Sup  >miilima !28_V	et	f	\N
162602	miilima	?miilima =miilima  (SgG  >miilim !02_A	et	f	\N
162620	liidia	?liidia =liidia  (SgN  >liidia !01_S	et	f	\N
162621	liidia	?liidia =liidia  (SgG  >liidia !01_S	et	f	\N
162622	maa-alune	maa-alune =alune  (SgN  >maa-alune !10_AS	et	f	\N
162623	maa-alune	"maa-alune %alu  )NE_aA  <maa-alg ;22_S	et	f	\N
162638	eestalaste	eestalaste =alas  (PlG  >eest+alane !10_AS	et	f	\N
162639	eestalaste	"eest+alane %ala  )NE_aA  <eest+ala ;17_S	et	f	\N
162640	eestalaste	eestalaste =talas  (PlG  >ees+talane !10_A	et	f	\N
162641	eestalaste	"ees+talane %tala  )NE_aA  <ees+tala ;17_S	et	f	\N
162655	alfred	?alfred =alfre  (PlN  >alfre !06_S	et	f	\N
162656	alfred	?alfred =alfre  (IndPrSg2  >alfrema !27_V	et	f	\N
162657	maa-alust	maa-alust =alu  (SgEl  >maa-alg !22_S	et	f	\N
162658	maa-alust	maa-alust =alu  (PlEl  >maa-ala !17_S	et	f	\N
162659	maa-alust	maa-alust =alus  (SgP  >maa-alus !09_S	et	f	\N
162660	maa-alust	maa-alust =alus  (SgP  >maa-alune !10_AS	et	f	\N
162661	maa-alust	"maa-alune %alu  )NE_aA  <maa-alg ;22_S	et	f	\N
162664	kollu	?kollu =kollu  (SgN  >kollu !16_S	et	f	\N
162665	kollu	?kollu =kollu  (SgG  >kollu !16_S	et	f	\N
162666	kollu	?kollu =kollu  (IndPrPs_  >kolluma !27_V	et	f	\N
162667	kollu	?kollu =kollu  (ImpPrSg2  >kolluma !27_V	et	f	\N
162680	aall	?aall =aall  (SgN  >aall !22_S	et	f	\N
162684	pealuu	pealuu =luu  (SgN  >pea+luu !26_S	et	f	\N
162685	pealuu	pealuu =luu  (SgG  >pea+luu !26_S	et	f	\N
162709	kantsi	kantsi =kantsi  (SgG  >kants !22_S	et	f	\N
162710	kantsi	kantsi =kantsi  (SgP  >kants !22_S	et	f	\N
162711	kantsi	kantsi =kantsi  (SgAdt  >kants !22_S	et	f	\N
162712	maaalused	maaalused =aluse  (PlN  >maa+alus !09_S	et	f	\N
162713	maaalused	maaalused =aluse  (PlN  >maa+alune !10_AS	et	f	\N
162714	maaalused	"maa+alune %alu  )NE_aA  <maa+alg ;22_S	et	f	\N
162721	rpõldmäe	?rpõldmäe =rpõldmäe  (SgN  >rpõldmäe !26_S	et	f	\N
162722	rpõldmäe	?rpõldmäe =rpõldmäe  (SgG  >rpõldmäe !26_S	et	f	\N
162764	lehetus	lehetus =lehetu  (SgIn  >lehetu !01_A	et	f	\N
162765	lehetus	"lehetu %lehe  )TU2_kA  <leht ;22_S	et	f	\N
162766	lehetus	lehetus =lehetus  (SgN  >lehetus !11_S	et	f	\N
162767	lehetus	"lehetus %lehe  )TUS2_aS  <leht ;22_S	et	f	\N
162772	püksivärvlist	püksivärvlist =värvli  (SgEl  >püksi+värvel !02_S	et	f	\N
162773	püksivärvlist	püksivärvlist =värvlis  (SgP  >püksi+värvline !12~10_A	et	f	\N
162774	püksivärvlist	"püksi+värvline %värvli  )NE_aA  <püksi+värvel ;02_S	et	f	\N
162777	hoolitud	hoolitud =hooli  (PtsPtIps  >hoolima !28_V	et	f	\N
162778	hoolitud	hoolitud =hoolitu  (PlN  >hoolitu !01_AS	et	f	\N
162779	hoolitud	"hoolitu %hooli  )TU1_vS  <hoolima ;28_V	et	f	\N
162780	hoolitud	hoolitud =hoolitud  (ID  >hoolitud !41_A	et	f	\N
162781	hoolitud	"hoolitud %hooli  )TUD_vA  <hoolima ;28_V	et	f	\N
162789	mahukamaid	mahukamaid =mahukama  (PlP  >mahukam !02_A	et	f	\N
162790	mahukamaid	"mahukam %mahuka  )M_cA  <mahukas ;02_A	et	f	\N
162824	nakust	?nakust =naku  (SgEl  >naku !16_S	et	f	\N
162826	nakust	?nakust =nakus  (SgP  >nakus !09_S	et	f	\N
162829	rõõska	rõõska =rõõska  (SgP  >rõõsk !22_A	et	f	\N
162830	rõõska	rõõska =rõõska  (SgAdt  >rõõsk !22_A	et	f	\N
162831	rõõska	rõõska =rõõska  (IndPrPs_  >rõõskama !29_V	et	f	\N
162832	rõõska	rõõska =rõõska  (ImpPrSg2  >rõõskama !29_V	et	f	\N
162842	kihvtiandjatena	?kihvtiandjatena =kihvtiandja  (PlEs  >kihvtiandjas !02_A	et	f	\N
162848	tekitevat	?tekitevat =tekiteva  (SgP  >tekitev !02_A	et	f	\N
162849	tekitevat	?tekitevat =tekiteva  (SgP  >tekiteva !16_S	et	f	\N
162850	tekitevat	?tekitevat =tevat  (SgN  >teki+tevat !02_S	et	f	\N
162857	koleera	?koleera =koleera  (SgN  >koleera !16_S	et	f	\N
162858	koleera	?koleera =koleera  (SgG  >koleera !16_S	et	f	\N
162871	süia	?süia =süia  (SgN  >süia !16_S	et	f	\N
162872	süia	?süia =süia  (SgG  >süia !16_S	et	f	\N
162873	süia	?süia =süia  (IndPrPs_  >süiama !29_V	et	f	\N
162874	süia	?süia =süia  (ImpPrSg2  >süiama !29_V	et	f	\N
162903	kihvtitegijad	?kihvtitegijad =kihvtitegija  (PlN  >kihvtitegija !01_S	et	f	\N
162904	kihvtitegijad	?kihvtitegijad =kihvtitegija  (PlN  >kihvtitegijas !02_A	et	f	\N
162905	koleerat	?koleerat =koleera  (SgP  >koleera !16_S	et	f	\N
162906	lk114	### lk114	et	f	\N
162931	kaevule	kaevule =kaevu  (SgAll  >kaev !22_S	et	f	\N
162932	kaevule	"kaev %kae  )V_vA  <kaema ;27_V	et	f	\N
162962	lehvinud	lehvinud =lehvi  (PtsPtPs  >lehvima !28_V	et	f	\N
162963	lehvinud	lehvinud =lehvinu  (PlN  >lehvinu !01_S	et	f	\N
162595	vanarahvas	vanarahvas =rahvas  (SgN  >vana+rahvas !07_S	et	f	\N
162609	niinemaa	niinemaa =maa  (SgN  >niine+maa !26_S	et	f	\N
162611	niinemaa	niinemaa =maa  (SgG  >niine+maa !26_S	et	f	\N
162629	hageri	?hageri =hageri  (SgN  >hageri !01_S	et	f	\N
162630	hageri	?hageri =hageri  (SgG  >hageri !01_S	et	f	\N
162631	hageri	?hageri =hageri  (SgG  >hager !02_S	et	f	\N
162632	läind	?läind =läind  (SgN  >läind !02_S	et	f	\N
162672	kollust	?kollust =kollu  (SgEl  >kollu !16_S	et	f	\N
162673	kollust	?kollust =kollus  (SgP  >kollus !11~09_S	et	f	\N
162677	kõrva	kõrva =kõrva  (SgG  >kõrv !22_S	et	f	\N
162678	kõrva	kõrva =kõrva  (SgP  >kõrv !22_S	et	f	\N
162679	kõrva	kõrva =kõrva  (SgAdt  >kõrv !22_S	et	f	\N
162700	salatee	salatee =tee  (SgN  >sala+tee !26_S	et	f	\N
162701	salatee	salatee =tee  (SgG  >sala+tee !26_S	et	f	\N
162707	röövimas	röövimas =röövi  (SupIn  >röövima !28_V	et	f	\N
162708	röövimas	röövimas =ima  (SgIn  >rööv+ima !17_S	et	f	\N
162723	jaagup	?jaagup =jaagup  (SgN  >jaagup !02_S	et	f	\N
162743	koolja	koolja =koolja  (SgN  >koolja !01_S	et	f	\N
162744	koolja	"koolja %kool  )JA_vS  <koolma ;33_V	et	f	\N
162745	koolja	koolja =koolja  (SgG  >koolja !01_S	et	f	\N
162746	koolja	koolja =koolja  (SgG  >kooljas !02_S	et	f	\N
162775	kaevamine	kaevamine =kaevamine  (SgN  >kaevamine !12_S	et	f	\N
162776	kaevamine	"kaevamine %kaeva  )MINE_vS  <kaevama ;29_V	et	f	\N
162784	ajaloolistest	ajaloolistest =loolis  (PlEl  >aja+looline !12?10_A	et	f	\N
162785	ajaloolistest	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
162786	ajaloolistest	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
162787	ajaloolistest	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
162788	ajaloolistest	ajaloolistest =loolis  (PlEl  >aja+looline !12?10_S	et	f	\N
162797	habemiku	habemiku =habemiku  (SgG  >habemik !25_AS	et	f	\N
162798	habemiku	habemiku =miku  (SgG  >habe+mikk !22_S	et	f	\N
162827	sõnamaagia	sõnamaagia =maagia  (SgN  >sõna+maagia !01_S	et	f	\N
162828	sõnamaagia	sõnamaagia =maagia  (SgG  >sõna+maagia !01_S	et	f	\N
162833	mõisnikevastase	?mõisnikevastase =mõisnikevastase  (SgG  >mõisnikevastane !12_A	et	f	\N
162834	kahtlustati	kahtlustati =kahtlusta  (IndIpfIps  >kahtlustama !27_V	et	f	\N
162835	kahtlustati	kahtlustati =ati  (SgG  >kahtlust+att !22_S	et	f	\N
162836	kahtlustati	kahtlustati =tati  (SgG  >kahtlus+tatt !22_S	et	f	\N
162839	liikuvat	liikuvat =liiku  (KvtPrPs  >liikuma !28_V	et	f	\N
162840	liikuvat	liikuvat =liikuva  (SgP  >liikuv !02_A	et	f	\N
162841	liikuvat	"liikuv %liiku  )V_vA  <liikuma ;28_V	et	f	\N
162853	seotuid	seotuid =seotu  (PlP  >seotu !01_A	et	f	\N
162854	seotuid	"seotu %seo  )TU1_vS  <siduma ;28_V	et	f	\N
162867	kästud	kästud =käs  (PtsPtIps  >käskima !28_V	et	f	\N
162868	kästud	kästud =kästu  (PlN  >kästu !01_S	et	f	\N
162869	kästud	"kästu %käs  )TU1_vS  <käskima ;28_V	et	f	\N
162870	kästud	"kästud %käs  )TUD_vA  <käskima ;28_V	et	f	\N
162882	lk96	### lk96	et	f	\N
162885	kihvti	kihvti =kihvti  (SgG  >kihvt !22_SA	et	f	\N
162889	kihvti	kihvti =kihvti  (SgP  >kihvt !22_SA	et	f	\N
162890	kihvti	kihvti =kihvti  (SgAdt  >kihvt !22_SA	et	f	\N
162895	loomakatku	loomakatku =katku  (SgG  >looma+katk !22_S	et	f	\N
162896	loomakatku	loomakatku =katku  (SgP  >looma+katk !22_S	et	f	\N
162897	loomakatku	loomakatku =katku  (SgAdt  >looma+katk !22_S	et	f	\N
162912	sirgu	sirgu =sirgu  (ID  >sirgu !41_D	et	f	\N
162913	sirgu	sirgu =sirgu  (SgG  >sirk !22_S	et	f	\N
162914	sirgu	sirgu =sirgu  (IndPrPs_  >sirguma !27_V	et	f	\N
162915	sirgu	sirgu =sirgu  (ImpPrSg2  >sirguma !27_V	et	f	\N
162927	lk117	### lk117	et	f	\N
162930	60e	### 60e	et	f	\N
162939	kukkunud	kukkunud =kukku  (PtsPtPs  >kukkuma !28_V	et	f	\N
162940	kukkunud	kukkunud =kukkunu  (PlN  >kukkunu !01_S	et	f	\N
162941	kukkunud	"kukkunu %kukku  )NU_vS  <kukkuma ;28_V	et	f	\N
162942	kukkunud	kukkunud =kukkunud  (ID  >kukkunud !41_A	et	f	\N
162943	kukkunud	"kukkunud %kukku  )NUD_vA  <kukkuma ;28_V	et	f	\N
162952	hüüdnud	hüüdnud =hüüd  (PtsPtPs  >hüüdma !34_V	et	f	\N
162953	hüüdnud	hüüdnud =hüüdnu  (PlN  >hüüdnu !01_S	et	f	\N
162954	hüüdnud	"hüüdnu %hüüd  )NU_vS  <hüüdma ;34_V	et	f	\N
162955	hüüdnud	hüüdnud =hüüdnud  (ID  >hüüdnud !41_A	et	f	\N
162956	hüüdnud	"hüüdnud %hüüd  )NUD_vA  <hüüdma ;34_V	et	f	\N
162969	eniinepuu	?eniinepuu =eniinepuu  (SgN  >eniinepuu !26_S	et	f	\N
162970	eniinepuu	?eniinepuu =eniinepuu  (SgG  >eniinepuu !26_S	et	f	\N
162974	katkud	katkud =katku  (PlN  >katk !22_S	et	f	\N
162975	katkud	katkud =katku  (IndPrSg2  >katkuma !28_V	et	f	\N
162988	pääsenud	pääsenud =pääse  (PtsPtPs  >pääsema !28_V	et	f	\N
162989	pääsenud	pääsenud =pääsenu  (PlN  >pääsenu !01_S	et	f	\N
162990	pääsenud	"pääsenu %pääse  )NU_vS  <pääsema ;28_V	et	f	\N
162991	pääsenud	pääsenud =pääsenud  (ID  >pääsenud !41_A	et	f	\N
162992	pääsenud	"pääsenud %pääse  )NUD_vA  <pääsema ;28_V	et	f	\N
163002	tui	tui =tui  (SgN  >tui !26_S	et	f	\N
163004	tui	tui =tui  (SgG  >tui !26_S	et	f	\N
163029	soan	?soan =soan  (SgN  >soan !22_S	et	f	\N
162706	ehrpais	?ehrpais =ehrpais  (SgN  >ehrpais !22_S	et	f	\N
162720	vndk	### vndk	et	f	\N
162724	70a	### 70a	et	f	\N
162725	kalmekoht	?kalmekoht =kalmekoht  (SgN  >kalmekoht !22_S	et	f	\N
162726	kivisäkk	?kivisäkk =kivisäkk  (SgN  >kivisäkk !22_S	et	f	\N
162727	kivisäkk	?kivisäkk =säkk  (SgN  >kivi+säkk !22_S	et	f	\N
162728	olevatki	olevatki =ole  (KvtPrPs^  >olema !36_V	et	f	\N
162729	olevatki	olevatki =oleva  (SgP^  >olev !02_A	et	f	\N
162730	olevatki	"olev %ole  )V_vA^  <olema ;36_V	et	f	\N
162753	kooljas	kooljas =koolja  (SgIn  >koolja !01_S	et	f	\N
162754	kooljas	"koolja %kool  )JA_vS  <koolma ;33_V	et	f	\N
162755	kooljas	kooljas =koolja  (SgIn  >kooljas !02_S	et	f	\N
162756	kooljas	kooljas =kooljas  (SgN  >kooljas !02_S	et	f	\N
162757	vld	### vld	et	f	\N
162760	66a	### 66a	et	f	\N
162761	lehtmetsa	lehtmetsa =metsa  (SgG  >leht+mets !22_S	et	f	\N
162762	lehtmetsa	lehtmetsa =metsa  (SgP  >leht+mets !22_S	et	f	\N
162763	lehtmetsa	lehtmetsa =metsa  (SgAdt  >leht+mets !22_S	et	f	\N
162793	tekitajaks	tekitajaks =tekitaja  (SgTr  >tekitaja !01_S	et	f	\N
162794	tekitajaks	"tekitaja %tekita  )JA_vS  <tekitama ;27_V	et	f	\N
162801	nägemisest	nägemisest =nägemise  (SgEl  >nägemine !12_S	et	f	\N
162802	nägemisest	"nägemine %näge  )MINE_vS  <nägema ;28_V	et	f	\N
162803	langevad	langevad =lange  (IndPrPl3  >langema !27_V	et	f	\N
162804	langevad	langevad =langeva  (PlN  >langev !02_A	et	f	\N
162805	langevad	"langev %lange  )V_vA  <langema ;27_V	et	f	\N
162814	toomingapõõsasse	?toomingapõõsasse =toomingapõõsa  (SgIll  >toomingapõõsa !16_S	et	f	\N
162815	toomingapõõsasse	?toomingapõõsasse =toomingapõõsasse  (SgG  >toomingapõõsasne !02_A	et	f	\N
162816	toomingapõõsasse	?toomingapõõsasse =toomingapõõsasse  (PlP  >toomingapõõsass !22_S	et	f	\N
162817	toomingapõõsasse	?toomingapõõsasse =ingapõõsa  (SgIll  >toom+ingapõõsa !16_S	et	f	\N
162818	toomingapõõsasse	?toomingapõõsasse =ingapõõsasse  (SgG  >toom+ingapõõsasne !02_A	et	f	\N
162819	toomingapõõsasse	?toomingapõõsasse =ingapõõsasse  (PlP  >toom+ingapõõsass !22_S	et	f	\N
162820	toomingapõõsasse	?toomingapõõsasse =mingapõõsa  (SgIll  >too+mingapõõsa !16_S	et	f	\N
162821	toomingapõõsasse	?toomingapõõsasse =mingapõõsasse  (SgG  >too+mingapõõsasne !02_A	et	f	\N
162822	toomingapõõsasse	?toomingapõõsasse =mingapõõsasse  (PlP  >too+mingapõõsass !22_S	et	f	\N
162851	hävitamisega	hävitamisega =hävitamise  (SgKom  >hävitamine !12_S	et	f	\N
162852	hävitamisega	"hävitamine %hävita  )MINE_vS  <hävitama ;27_V	et	f	\N
162855	rahvapärased	rahvapärased =pärase  (PlN  >rahva+pärane !10_A	et	f	\N
162856	rahvapärased	"rahva+pärane %pära  )NE_aA  <rahva+pära ;17_S	et	f	\N
162860	soolast	soolast =soola  (SgEl  >sool !22_S	et	f	\N
162861	soolast	soolast =soolas  (SgP  >soolane !10_A	et	f	\N
162862	soolast	"soolane %soola  )NE_aA  <sool ;22_S	et	f	\N
162863	soolast	soolast =ast  (SgN  >sool+ast !22_S	et	f	\N
162864	soolast	soolast =la  (SgEl  >soo+la !26_S	et	f	\N
162865	soolast	soolast =las  (SgP  >soo+laps !14_S	et	f	\N
162866	soolast	soolast =last  (SgN  >soo+last !22_S	et	f	\N
162883	katkukülvaja	katkukülvaja =külvaja  (SgN  >katku+külvaja !01_S	et	f	\N
162884	katkukülvaja	katkukülvaja =külvaja  (SgG  >katku+külvaja !01_S	et	f	\N
162907	24a	### 24a	et	f	\N
162922	kihiandjad	?kihiandjad =kihiandja  (PlN  >kihiandjas !02_A	et	f	\N
162923	kihiandjad	?kihiandjad =kihiandja  (PlN  >kihiandja !16_S	et	f	\N
162933	kaevu	kaevu =kaevu  (SgG  >kaev !22_S	et	f	\N
162934	kaevu	"kaev %kae  )V_vA  <kaema ;27_V	et	f	\N
162935	kaevu	kaevu =kaevu  (SgP  >kaev !22_S	et	f	\N
162936	kaevu	kaevu =kaevu  (SgAdt  >kaev !22_S	et	f	\N
162937	kaevu	kaevu =kaevu  (IndPrPs_  >kaevuma !27_V	et	f	\N
162938	kaevu	kaevu =kaevu  (ImpPrSg2  >kaevuma !27_V	et	f	\N
162946	surnult	surnult =surnu  (SgAbl  >surnu !01_S	et	f	\N
162948	surnult	"surnu %sur  )NU_vS  <surema ;36_V	et	f	\N
162949	surnult	surnult =surnu  (SgAbl  >surnu !06_S	et	f	\N
162950	surnult	surnult =surnult  (ID  >surnult !41_D	et	f	\N
162951	surnult	"surnult %sur  )NULT_mD  <surema ;36_V	et	f	\N
162986	sial	?sial =sia  (SgAd  >sia !26_S	et	f	\N
162987	sial	?sial =sial  (SgN  >sial !22_S	et	f	\N
162999	tulipunane	tulipunane =punane  (SgN  >tuli+punane !10_AS	et	f	\N
163000	tulipunane	"tuli+punane %puna  )NE_aA  <tuli+puna ;17_S	et	f	\N
163007	lk151	### lk151	et	f	\N
163008	puudutusest	puudutusest =puudutuse  (SgEl  >puudutus !11_S	et	f	\N
163009	puudutusest	"puudutus %puuduta  )US_vS  <puudutama ;27_V	et	f	\N
163010	puudutusest	"puudutus %puudu  )TUS1_aS  <puuduma ;27_V	et	f	\N
163011	puudutusest	puudutusest =puudutuses  (SgP  >puudutusene !12_A	et	f	\N
163012	puudutusest	"puudutusene %puudutuse  )NE_aA  <puudutus ;11_S	et	f	\N
163020	kudas	?kudas =kuda  (SgIn  >kuda !17_S	et	f	\N
163021	kudas	?kudas =kuda  (IndIpfSg3  >kudama !27_V	et	f	\N
163022	kudas	?kudas =kudas  (SgN  >kudas !07_S	et	f	\N
163023	üteld	?üteld =üteld  (SgN  >üteld !02_S	et	f	\N
163027	koa	?koa =koa  (SgN  >koa !26_S	et	f	\N
163028	koa	?koa =koa  (SgG  >koa !26_S	et	f	\N
163047	surmata	surmata =surma  (SgAb  >surm !22_S	et	f	\N
162838	saatmises	"saatmine %saat  )MINE_vS  <saatma ;34_V	et	f	\N
162843	puistanud	puistanud =puista  (PtsPtPs  >puistama !29_V	et	f	\N
162844	puistanud	puistanud =puistanu  (PlN  >puistanu !01_S	et	f	\N
162845	puistanud	"puistanu %puista  )NU_vS  <puistama ;29_V	et	f	\N
162846	puistanud	puistanud =puistanud  (ID  >puistanud !41_A	et	f	\N
162847	puistanud	"puistanud %puista  )NUD_vA  <puistama ;29_V	et	f	\N
162875	söönd	?söönd =söönd  (SgN  >söönd !22_S	et	f	\N
162876	aidanud	aidanud =aida  (PtsPtPs  >aitama !29_V	et	f	\N
162877	aidanud	aidanud =aidanu  (PlN  >aidanu !01_S	et	f	\N
162878	aidanud	"aidanu %aida  )NU_vS  <aitama ;29_V	et	f	\N
162879	aidanud	aidanud =aidanud  (ID  >aidanud !41_A	et	f	\N
162880	aidanud	"aidanud %aida  )NUD_vA  <aitama ;29_V	et	f	\N
162891	välla	?välla =välla  (SgN  >välla !16_S	et	f	\N
162892	välla	?välla =välla  (SgG  >välla !16_S	et	f	\N
162893	välla	?välla =välla  (IndPrPs_  >vällama !29_V	et	f	\N
162894	välla	?välla =välla  (ImpPrSg2  >vällama !29_V	et	f	\N
162898	lk109	### lk109	et	f	\N
162899	einberg	?einberg =einberg  (SgN  >einberg !02_S	et	f	\N
162916	teind	?teind =teind  (SgN  >teind !02_S	et	f	\N
162919	kihiandja	?kihiandja =kihiandja  (SgN  >kihiandja !16_S	et	f	\N
162920	kihiandja	?kihiandja =kihiandja  (SgG  >kihiandjas !02_A	et	f	\N
162921	kihiandja	?kihiandja =kihiandja  (SgG  >kihiandja !16_S	et	f	\N
162925	toond	?toond =toond  (SgN  >toond !22_S	et	f	\N
162926	petoffer	?petoffer =petoffer  (SgN  >petoffer !02_S	et	f	\N
162944	muist	muist =mu  (PlEl  >muu !26_S	et	f	\N
162945	muist	muist =mu  (PlEl  >muu !26_P	et	f	\N
162947	muist	muist =muist  (ID  >muist !41_P	et	f	\N
162957	hävitanud	hävitanud =hävita  (PtsPtPs  >hävitama !27_V	et	f	\N
162958	hävitanud	hävitanud =hävitanu  (PlN  >hävitanu !01_S	et	f	\N
162959	hävitanud	"hävitanu %hävita  )NU_vS  <hävitama ;27_V	et	f	\N
162960	hävitanud	hävitanud =hävitanud  (ID  >hävitanud !41_A	et	f	\N
162961	hävitanud	"hävitanud %hävita  )NUD_vA  <hävitama ;27_V	et	f	\N
162971	lk147	### lk147	et	f	\N
162981	lennanud	lennanud =lenna  (PtsPtPs  >lendama !29_V	et	f	\N
162982	lennanud	lennanud =lennanu  (PlN  >lennanu !01_S	et	f	\N
162983	lennanud	"lennanu %lenna  )NU_vS  <lendama ;29_V	et	f	\N
162984	lennanud	lennanud =lennanud  (ID  >lennanud !41_A	et	f	\N
162985	lennanud	"lennanud %lenna  )NUD_vA  <lendama ;29_V	et	f	\N
163013	poisikesed	poisikesed =poisikese  (PlN  >poisike !12_S	et	f	\N
163014	poisikesed	"poisike %poisi  )KE_dS  <poiss ;22_S	et	f	\N
163015	poisikesed	"poisike %poisi  )KE_dS  <poiss ;23_S	et	f	\N
163016	poisikesed	poisikesed =poisikese  (PlN  >poisikene !12_S	et	f	\N
163017	poisikesed	"poisikene %poisi  )KENE_dS  <poiss ;22_S	et	f	\N
163018	poisikesed	"poisikene %poisi  )KENE_dS  <poiss ;23_S	et	f	\N
163024	einakõrreks	?einakõrreks =einakõrre  (PlTr  >einakõrr !22_S	et	f	\N
163025	einakõrreks	?einakõrreks =nakõrre  (PlTr  >ei+nakõrr !22_S	et	f	\N
163033	emaema	emaema =ema  (SgN  >ema+ema !17_S	et	f	\N
163034	emaema	emaema =ema  (SgG  >ema+ema !17_S	et	f	\N
163035	emaema	emaema =ema  (SgP  >ema+ema !17_S	et	f	\N
163037	katsund	?katsund =katsund  (SgN  >katsund !02_S	et	f	\N
163080	surd	?surd =surd  (SgN  >surd !22_S	et	f	\N
163082	lk196	### lk196	et	f	\N
163083	möllanud	möllanud =mölla  (PtsPtPs  >möllama !29_V	et	f	\N
163084	möllanud	möllanud =möllanu  (PlN  >möllanu !01_S	et	f	\N
163085	möllanud	"möllanu %mölla  )NU_vS  <möllama ;29_V	et	f	\N
163086	möllanud	möllanud =möllanud  (ID  >möllanud !41_A	et	f	\N
163087	möllanud	"möllanud %mölla  )NUD_vA  <möllama ;29_V	et	f	\N
163089	siblinud	siblinud =sibli  (PtsPtPs  >siblima !27_V	et	f	\N
163090	siblinud	siblinud =siblinu  (PlN  >siblinu !01_S	et	f	\N
163091	siblinud	"siblinu %sibli  )NU_vS  <siblima ;27_V	et	f	\N
163092	siblinud	siblinud =siblinud  (ID  >siblinud !41_A	et	f	\N
163093	siblinud	"siblinud %sibli  )NUD_vA  <siblima ;27_V	et	f	\N
163094	külaliseks	külaliseks =külalise  (SgTr  >külaline !12_S	et	f	\N
163095	külaliseks	"külaline %küla  )LINE_aA  <küla ;17_S	et	f	\N
163107	karjatanud	karjatanud =karjata  (PtsPtPs  >karjatama !27_V	et	f	\N
163108	karjatanud	karjatanud =karjatanu  (PlN  >karjatanu !01_S	et	f	\N
163109	karjatanud	"karjatanu %karjata  )NU_vS  <karjatama ;27_V	et	f	\N
163110	karjatanud	karjatanud =karjatanud  (ID  >karjatanud !41_A	et	f	\N
163111	karjatanud	"karjatanud %karjata  )NUD_vA  <karjatama ;27_V	et	f	\N
163112	karjatanud	karjatanud =tanu  (PlN  >karja+tanu !17_S	et	f	\N
163118	uimaseks	uimaseks =uimase  (SgTr  >uimane !10_A	et	f	\N
163119	uimaseks	"uimane %uima  )NE_aA  <uim ;22_S	et	f	\N
163120	uimaseks	uimaseks =seks  (SgN  >uima+seks !22_S	et	f	\N
163128	piitsa	piitsa =piitsa  (SgG  >piits !22_S	et	f	\N
163130	piitsa	piitsa =piitsa  (SgP  >piits !22_S	et	f	\N
163131	piitsa	piitsa =piitsa  (SgAdt  >piits !22_S	et	f	\N
163151	matjaid	matjaid =matja  (PlP  >matja !01_S	et	f	\N
163152	matjaid	"matja %mat  )JA_vS  <matma ;35_V	et	f	\N
163164	reinu	?reinu =reinu  (SgN  >reinu !16_S	et	f	\N
162964	lehvinud	"lehvinu %lehvi  )NU_vS  <lehvima ;28_V	et	f	\N
162965	lehvinud	lehvinud =lehvinud  (ID  >lehvinud !41_A	et	f	\N
162966	lehvinud	"lehvinud %lehvi  )NUD_vA  <lehvima ;28_V	et	f	\N
162967	mustu	mustu =mustu  (IndPrPs_  >mustuma !27_V	et	f	\N
162968	mustu	mustu =mustu  (ImpPrSg2  >mustuma !27_V	et	f	\N
162976	kolanud	kolanud =kola  (PtsPtPs  >kolama !27_V	et	f	\N
162977	kolanud	kolanud =kolanu  (PlN  >kolanu !01_S	et	f	\N
162978	kolanud	"kolanu %kola  )NU_vS  <kolama ;27_V	et	f	\N
162979	kolanud	kolanud =kolanud  (ID  >kolanud !41_A	et	f	\N
162980	kolanud	"kolanud %kola  )NUD_vA  <kolama ;27_V	et	f	\N
162997	rahvasuu	rahvasuu =suu  (SgN  >rahva+suu !26_S	et	f	\N
162998	rahvasuu	rahvasuu =suu  (SgG  >rahva+suu !26_S	et	f	\N
163001	õpilhtillemann	?õpilhtillemann =õpilhtillemann  (SgN  >õpilhtillemann !22_S	et	f	\N
163032	lk169	### lk169	et	f	\N
163036	näind	?näind =näind  (SgN  >näind !02_S	et	f	\N
163042	lk174	### lk174	et	f	\N
163046	saand	?saand =saand  (SgN  >saand !22_S	et	f	\N
163050	inime	?inime =ini  (IndPrPl1  >inima !27_V	et	f	\N
163055	sedasiöö	?sedasiöö =sedasiöö  (SgN  >sedasiöö !26_S	et	f	\N
163056	sedasiöö	?sedasiöö =sedasiöö  (SgG  >sedasiöö !26_S	et	f	\N
163057	sedasiöö	?sedasiöö =siöö  (SgN  >seda+siöö !26_S	et	f	\N
163058	sedasiöö	?sedasiöö =siöö  (SgG  >seda+siöö !26_S	et	f	\N
163064	turgand	?turgand =turgand  (SgN  >turgand !02_S	et	f	\N
163067	liisa	?liisa =liisa  (SgN  >liisa !16_S	et	f	\N
163068	liisa	?liisa =liisa  (SgG  >liisa !16_S	et	f	\N
163069	liisa	?liisa =liisa  (IndPrPs_  >liisama !29_V	et	f	\N
163070	liisa	?liisa =liisa  (ImpPrSg2  >liisama !29_V	et	f	\N
163121	poisikene	poisikene =poisikene  (SgN  >poisikene !12_S	et	f	\N
163122	poisikene	"poisikene %poisi  )KENE_dS  <poiss ;22_S	et	f	\N
163124	poisikene	"poisikene %poisi  )KENE_dS  <poiss ;23_S	et	f	\N
163127	plaksutanud	plaksutanud =plaksuta  (PtsPtPs  >plaksutama !27_V	et	f	\N
163129	plaksutanud	plaksutanud =plaksutanu  (PlN  >plaksutanu !01_S	et	f	\N
163132	plaksutanud	"plaksutanu %plaksuta  )NU_vS  <plaksutama ;27_V	et	f	\N
163133	plaksutanud	plaksutanud =plaksutanud  (ID  >plaksutanud !41_A	et	f	\N
163134	plaksutanud	"plaksutanud %plaksuta  )NUD_vA  <plaksutama ;27_V	et	f	\N
163142	puusärgitegijäid	?puusärgitegijäid =puusärgitegijäi  (PlN  >puusärgitegijäi !26_S	et	f	\N
163143	puusärgitegijäid	?puusärgitegijäid =puusärgitegijäi  (SgP  >puusärgitegijäi !26_S	et	f	\N
163144	puusärgitegijäid	?puusärgitegijäid =puusärgitegijäid  (SgN  >puusärgitegijäid !22_S	et	f	\N
163145	puusärgitegijäid	?puusärgitegijäid =tegijäi  (PlN  >puu+särgi+tegijäi !26_S	et	f	\N
163146	puusärgitegijäid	?puusärgitegijäid =tegijäi  (SgP  >puu+särgi+tegijäi !26_S	et	f	\N
163147	puusärgitegijäid	?puusärgitegijäid =tegijäid  (SgN  >puu+särgi+tegijäid !22_S	et	f	\N
163148	puusärgitegijäid	?puusärgitegijäid =särgitegijäi  (PlN  >puu+särgitegijäi !26_S	et	f	\N
163149	puusärgitegijäid	?puusärgitegijäid =särgitegijäi  (SgP  >puu+särgitegijäi !26_S	et	f	\N
163150	puusärgitegijäid	?puusärgitegijäid =särgitegijäid  (SgN  >puu+särgitegijäid !22_S	et	f	\N
163168	kindral	kindral =kindra  (SgAd  >kinner !08_S	et	f	\N
163169	kindral	kindral =kindral  (SgN  >kindral !02_S	et	f	\N
163183	johreemets	?johreemets =johreemets  (SgN  >johreemets !02_S	et	f	\N
163188	samlas	?samlas =samla  (SgIn  >samla !16_S	et	f	\N
163189	samlas	?samlas =samla  (IndIpfSg3  >samlama !29_V	et	f	\N
163190	samlas	?samlas =samlas  (SgN  >samlas !07_S	et	f	\N
163238	kole	kole =kole  (ID  >kole !41_D	et	f	\N
163239	kole	kole =kole  (SgN  >kole !02_A	et	f	\N
163251	vasalemma	?vasalemma =vasalemma  (SgN  >vasalemma !16_S	et	f	\N
163252	vasalemma	?vasalemma =vasalemma  (SgG  >vasalemma !16_S	et	f	\N
163263	katkust	katkust =katku  (SgEl  >katk !22_S	et	f	\N
163265	katkust	katkust =katkus  (SgP  >katkune !10_A	et	f	\N
163266	katkust	"katkune %katku  )NE_aA  <katk ;22_S	et	f	\N
163281	lee	lee =lee  (SgN  >lee !26_S	et	f	\N
163282	lee	lee =lee  (SgG  >lee !26_S	et	f	\N
163283	lee	lee =lee  (IndPrPs_  >leema !37_V	et	f	\N
163284	lee	lee =lee  (ImpPrSg2  >leema !37_V	et	f	\N
163299	lk258	### lk258	et	f	\N
163305	kivikalme	kivikalme =kalme  (SgN  >kivi+kalme !06_S	et	f	\N
163306	kivikalme	kivikalme =kalme  (SgG  >kivi+kalme !06_S	et	f	\N
163307	kivikalme	kivikalme =kalme  (PlP  >kivi+kalm !22_S	et	f	\N
163324	lk98	### lk98	et	f	\N
163331	estnische	?estnische =estnische  (PlP  >estnisch !22_S	et	f	\N
163334	lk209	### lk209	et	f	\N
163353	ruilas	?ruilas =ruila  (SgIn  >ruila !16_S	et	f	\N
163354	ruilas	?ruilas =ruila  (IndIpfSg3  >ruilama !29_V	et	f	\N
163355	ruilas	?ruilas =ruilas  (SgN  >ruilas !07_S	et	f	\N
163387	rahvausundilisteks	rahvausundilisteks =usundilis  (PlTr  >rahva+usundiline !12_A	et	f	\N
163388	rahvausundilisteks	"rahva+usundiline %usundi  )LINE_aA  <rahva+usund ;02_S	et	f	\N
163405	algupärasem	algupärasem =pärasem  (SgN  >algu+pärasem !02_A	et	f	\N
163406	algupärasem	"algu+pärasem %pära  )SEM_cA  <algu+pära ;17_S	et	f	\N
163407	algupärasem	"algu+pärasem %pärase  )M_cA  <algu+pärane ;10_A	et	f	\N
163426	hobuse	hobuse =hobuse  (SgG  >hobune !10_S	et	f	\N
163003	kaarel	kaarel =kaare  (SgAd  >kaar !13_S	et	f	\N
163005	kaarel	kaarel =kaare  (PlAd  >kaard !22_S	et	f	\N
163006	kaarel	kaarel =kaarel  (SgN  >kaarel !02_S	et	f	\N
163019	rääkind	?rääkind =rääkind  (SgN  >rääkind !02_S	et	f	\N
163026	aab	?aab =aab  (SgN  >aab !22_S	et	f	\N
163030	põle	põle =põle  (IndPrPs_  >põlema !27_V	et	f	\N
163031	põle	põle =põle  (ImpPrSg2  >põlema !27_V	et	f	\N
163044	valvel	valvel =valve  (SgAd  >valve !06_S	et	f	\N
163045	valvel	valvel =valvel  (ID  >valvel !41_DA	et	f	\N
163065	rahula	rahula =rahula  (SgN  >rahula !01_S	et	f	\N
163066	rahula	rahula =rahula  (SgG  >rahula !01_S	et	f	\N
163071	lk188	### lk188	et	f	\N
163077	turkind	?turkind =turkind  (SgN  >turkind !02_S	et	f	\N
163081	julgend	?julgend =julgend  (SgN  >julgend !02_S	et	f	\N
163088	mitmet	?mitmet =mitme  (SgP  >mitme !06_S	et	f	\N
163096	ähvardanud	ähvardanud =ähvarda  (PtsPtPs  >ähvardama !27_V	et	f	\N
163097	ähvardanud	ähvardanud =ähvardanu  (PlN  >ähvardanu !01_S	et	f	\N
163098	ähvardanud	"ähvardanu %ähvarda  )NU_vS  <ähvardama ;27_V	et	f	\N
163099	ähvardanud	ähvardanud =ähvardanud  (ID  >ähvardanud !41_A	et	f	\N
163100	ähvardanud	"ähvardanud %ähvarda  )NUD_vA  <ähvardama ;27_V	et	f	\N
163160	peremeest	peremeest =mee  (SgEl  >pere+mesi !15_S	et	f	\N
163161	peremeest	peremeest =mees  (SgP  >pere+meene !10_A	et	f	\N
163162	peremeest	"pere+meene %mee  )NE_aA  <pere+mesi ;15_S	et	f	\N
163163	peremeest	peremeest =mees  (SgP  >pere+mees !13_S	et	f	\N
163182	õpilhreemets	?õpilhreemets =õpilhreemets  (SgN  >õpilhreemets !02_S	et	f	\N
163186	helju	helju =helju  (IndPrPs_  >heljuma !28_V	et	f	\N
163187	helju	helju =helju  (ImpPrSg2  >heljuma !28_V	et	f	\N
163195	leheroo	leheroo =roo  (SgN  >lehe+roo !26_S	et	f	\N
163196	leheroo	leheroo =roo  (SgG  >lehe+rood !22_S	et	f	\N
163197	leheroo	leheroo =roo  (SgG  >lehe+roog !22_S	et	f	\N
163198	leheroo	leheroo =roo  (SgG  >lehe+roo !26_S	et	f	\N
163201	vaimusi	?vaimusi =vaimusi  (ID  >vaimusi !41_D	et	f	\N
163202	vaimusi	?vaimusi =vaimusi  (PlP  >vaimus !11_S	et	f	\N
163203	vaimusi	?vaimusi =usi  (SgN  >vaim+usi !17_S	et	f	\N
163204	vaimusi	?vaimusi =usi  (SgG  >vaim+usi !17_S	et	f	\N
163205	vaimusi	?vaimusi =usi  (SgP  >vaim+usi !17_S	et	f	\N
163212	akanud	?akanud =aka  (PtsPtPs  >akama !27_V	et	f	\N
163213	akanud	?akanud =aka  (PtsPtPs  >akkama !29_V	et	f	\N
163214	akanud	?akanud =akanu  (PlN  >akanu !01_S	et	f	\N
163215	akanud	?akanud =akanu  (IndPrSg2  >akanuma !27_V	et	f	\N
163216	akanud	?akanud =akanud  (ID  >akanud !41_A	et	f	\N
163230	keeranud	keeranud =keera  (PtsPtPs  >keerama !29_V	et	f	\N
163231	keeranud	keeranud =keeranu  (PlN  >keeranu !01_S	et	f	\N
163232	keeranud	"keeranu %keera  )NU_vS  <keerama ;29_V	et	f	\N
163233	keeranud	keeranud =keeranud  (ID  >keeranud !41_A	et	f	\N
163234	keeranud	"keeranud %keera  )NUD_vA  <keerama ;29_V	et	f	\N
163249	vindised	?vindised =vindise  (PlN  >vindis !09_S	et	f	\N
163250	vindised	?vindised =vindise  (IndPrSg2  >vindisema !27_V	et	f	\N
163261	lk245	### lk245	et	f	\N
163275	kuda	?kuda =kuda  (SgN  >kuda !17_S	et	f	\N
163276	kuda	?kuda =kuda  (SgG  >kuda !17_S	et	f	\N
163277	kuda	?kuda =kuda  (SgP  >kuda !17_S	et	f	\N
163278	kuda	?kuda =kuda  (IndPrPs_  >kudama !27_V	et	f	\N
163279	kuda	?kuda =kuda  (ImpPrSg2  >kudama !27_V	et	f	\N
163300	magajate	magajate =magaja  (PlG  >magaja !01_S	et	f	\N
163301	magajate	"magaja %maga  )JA_vS  <magama ;27_V	et	f	\N
163308	kraavi	kraavi =kraavi  (SgG  >kraav !22_S	et	f	\N
163309	kraavi	kraavi =kraavi  (SgP  >kraav !22_S	et	f	\N
163310	kraavi	kraavi =kraavi  (SgAdt  >kraav !22_S	et	f	\N
163315	annud	?annud =annu  (PlN  >annu !16_S	et	f	\N
163316	annud	?annud =annu  (IndPrSg2  >annuma !27_V	et	f	\N
163317	annud	?annud =annud  (ID  >annud !41_A	et	f	\N
163336	viidatud	viidatud =viida  (PtsPtIps  >viitama !29_V	et	f	\N
163337	viidatud	viidatud =viidatu  (PlN  >viidatu !01_S	et	f	\N
163338	viidatud	"viidatu %viida  )TU1_vS  <viitama ;29_V	et	f	\N
163339	viidatud	"viidatu %viida  )TU2_kA  <viit ;22_S	et	f	\N
163340	viidatud	viidatud =viidatud  (ID  >viidatud !41_A	et	f	\N
163341	viidatud	"viidatud %viida  )TUD_vA  <viitama ;29_V	et	f	\N
163347	tulnudki	tulnudki =tul  (PtsPtPs^  >tulema !36_V	et	f	\N
163348	tulnudki	tulnudki =tulnu  (PlN^  >tulnu !01_S	et	f	\N
163349	tulnudki	"tulnu %tul  )NU_vS^  <tulema ;36_V	et	f	\N
163350	tulnudki	tulnudki =tulnu  (PlN^  >tulnu !06_S	et	f	\N
163351	tulnudki	tulnudki =tulnud  (ID^  >tulnud !41_A	et	f	\N
163352	tulnudki	"tulnud %tul  )NUD_vA^  <tulema ;36_V	et	f	\N
163373	lk423	### lk423	et	f	\N
163381	muistendilise	muistendilise =muistendilise  (SgG  >muistendiline !12_A	et	f	\N
163382	muistendilise	"muistendiline %muistendi  )LINE_aA  <muistend ;02_S	et	f	\N
163399	parteigänger	?parteigänger =parteigänger  (SgN  >parteigänger !02_S	et	f	\N
163400	parteigänger	?parteigänger =gänger  (SgN  >part+ei+gänger !02_S	et	f	\N
163476	õeldnetu	?õeldnetu =õeldnetu  (SgN  >õeldnetu !01_A	et	f	\N
163477	õeldnetu	?õeldnetu =õeldnetu  (SgG  >õeldnetu !01_A	et	f	\N
163038	jäänd	?jäänd =jäänd  (SgN  >jäänd !22_S	et	f	\N
163039	aal	?aal =aal  (SgN  >aal !22_S	et	f	\N
163040	vihman	?vihman =vihma  (IndPrSg1  >vihmama !29_V	et	f	\N
163041	vihman	?vihman =vihman  (SgN  >vihman !02_S	et	f	\N
163043	magand	?magand =magand  (SgN  >magand !02_S	et	f	\N
163051	kedervarre	?kedervarre =kedervarre  (PlP  >kedervarr !22_S	et	f	\N
163059	lävi	lävi =lävi  (SgN  >lävi !20_S	et	f	\N
163060	lävi	lävi =lävi  (IndPrPs_  >lävima !27_V	et	f	\N
163061	lävi	lävi =lävi  (ImpPrSg2  >lävima !27_V	et	f	\N
163072	omiku	?omiku =omiku  (SgN  >omiku !01_S	et	f	\N
163073	omiku	?omiku =omiku  (SgG  >omiku !01_S	et	f	\N
163074	omiku	?omiku =omiku  (SgG  >omik !02_S	et	f	\N
163075	omiku	?omiku =omiku  (IndPrPs_  >omikuma !27_V	et	f	\N
163076	omiku	?omiku =omiku  (ImpPrSg2  >omikuma !27_V	et	f	\N
163078	katkuhaigeks	katkuhaigeks =haige  (SgTr  >katku+haige !01_AS	et	f	\N
163079	katkuhaigeks	katkuhaigeks =haige  (PlTr  >katku+haik !22_S	et	f	\N
163101	löönud	löönud =löö  (PtsPtPs  >lööma !38_V	et	f	\N
163102	löönud	löönud =löönu  (PlN  >löönu !01_S	et	f	\N
163103	löönud	"löönu %löö  )NU_vS  <lööma ;38_V	et	f	\N
163104	löönud	löönud =löönu  (PlN  >löönu !06_S	et	f	\N
163105	löönud	löönud =löönud  (ID  >löönud !41_A	et	f	\N
163106	löönud	"löönud %löö  )NUD_vA  <lööma ;38_V	et	f	\N
163140	hommikuks	hommikuks =hommiku  (SgTr  >hommik !02_S	et	f	\N
163141	hommikuks	hommikuks =uks  (SgN  >hommik+uks !14_S	et	f	\N
163153	söömata	söömata =söö  (SupAb  >sööma !38_V	et	f	\N
163154	söömata	söömata =sööma  (SgAb  >sööm !22_S	et	f	\N
163155	söömata	söömata =söömata  (ID  >söömata !41_A	et	f	\N
163156	söömata	"söömata %söö  )MATA_vA  <sööma ;38_V	et	f	\N
163193	mhiiemäe	?mhiiemäe =mhiiemäe  (SgN  >mhiiemäe !26_S	et	f	\N
163194	mhiiemäe	?mhiiemäe =mhiiemäe  (SgG  >mhiiemäe !26_S	et	f	\N
163226	jookse	jookse =jookse  (SgN  >jookse !05_S	et	f	\N
163227	jookse	jookse =jookse  (PlP  >jooks !22_S	et	f	\N
163228	jookse	jookse =jookse  (IndPrPs_  >jooksma !32_V	et	f	\N
163229	jookse	jookse =jookse  (ImpPrSg2  >jooksma !32_V	et	f	\N
163257	saatla	?saatla =saatla  (SgN  >saatla !01_S	et	f	\N
163258	saatla	?saatla =saatla  (SgG  >saatla !01_S	et	f	\N
163259	saatla	?saatla =saatla  (IndPrPs_  >saatlama !29_V	et	f	\N
163260	saatla	?saatla =saatla  (ImpPrSg2  >saatlama !29_V	et	f	\N
163262	pääsemine	pääsemine =pääsemine  (SgN  >pääsemine !12_S	et	f	\N
163264	pääsemine	"pääsemine %pääse  )MINE_vS  <pääsema ;28_V	et	f	\N
163280	istund	?istund =istund  (SgN  >istund !02_S	et	f	\N
163288	lõsna	lõsna =lõsna  (SgG  >lõsn !22_S	et	f	\N
163289	lõsna	lõsna =lõsna  (SgP  >lõsn !22_S	et	f	\N
163290	lõsna	lõsna =lõsna  (SgAdt  >lõsn !22_S	et	f	\N
163296	varas	varas =vara  (SgIn  >vara !17_S	et	f	\N
163297	varas	varas =varas  (SgN  >varas !07_S	et	f	\N
163302	surnd	?surnd =surnd  (SgN  >surnd !22_S	et	f	\N
163304	lk310	### lk310	et	f	\N
163318	jjung	?jjung =jjung  (SgN  >jjung !22_S	et	f	\N
163325	nr5	### nr5	et	f	\N
163327	cstern	?cstern =cstern  (SgN  >cstern !22_S	et	f	\N
163343	ellujäänute	ellujäänute =jäänu  (PlG  >ellu+jäänu !01_S	et	f	\N
163344	ellujäänute	ellujäänute =jäänu  (PlG  >ellu+jäänu !06_S	et	f	\N
163356	lk406	### lk406	et	f	\N
163362	suurekasvuline	suurekasvuline =kasvuline  (SgN  >suure+kasvuline !12_A	et	f	\N
163363	suurekasvuline	"suure+kasvuline %kasvu  )LINE_aA  <suure+kasv ;22_S	et	f	\N
163366	õpileniinepuu	?õpileniinepuu =õpileniinepuu  (SgN  >õpileniinepuu !26_S	et	f	\N
163367	õpileniinepuu	?õpileniinepuu =õpileniinepuu  (SgG  >õpileniinepuu !26_S	et	f	\N
163369	õpileniinepuu	?õpileniinepuu =leniinepuu  (SgN  >õpi+leniinepuu !26_S	et	f	\N
163371	õpileniinepuu	?õpileniinepuu =leniinepuu  (SgG  >õpi+leniinepuu !26_S	et	f	\N
163374	koledustega	koledustega =koledus  (PlKom  >koledus !11_S	et	f	\N
163375	koledustega	"koledus %koleda  )US_aS  <kole ;02_A	et	f	\N
163376	kohutavaid	kohutavaid =kohutava  (PlP  >kohutav !02_A	et	f	\N
163377	kohutavaid	"kohutav %kohu  )TAV_vAS  <kohuma ;27_V	et	f	\N
163378	kohutavaid	"kohutav %kohuta  )V_vA  <kohutama ;27_V	et	f	\N
163386	koerkoonlaste	?koerkoonlaste =koerkoonlas  (PlG  >koerkoonlane !12?10_S	et	f	\N
163408	rahvapärimustes	rahvapärimustes =muste  (PlIn  >rahva+päri+must !22_AS	et	f	\N
163409	rahvapärimustes	rahvapärimustes =pärimus  (PlIn  >rahva+pärimus !11_S	et	f	\N
163414	varastatud	varastatud =varasta  (PtsPtIps  >varastama !27_V	et	f	\N
163415	varastatud	varastatud =varastatu  (PlN  >varastatu !01_S	et	f	\N
163416	varastatud	"varastatu %varasta  )TU1_vS  <varastama ;27_V	et	f	\N
163417	varastatud	varastatud =varastatud  (ID  >varastatud !41_A	et	f	\N
163418	varastatud	"varastatud %varasta  )TUD_vA  <varastama ;27_V	et	f	\N
163428	villenthal	?villenthal =villentha  (SgAd  >villentha !01_S	et	f	\N
163429	villenthal	?villenthal =entha  (SgAd  >vill+entha !01_S	et	f	\N
163430	villenthal	?villenthal =enthal  (SgN  >vill+enthal !02_S	et	f	\N
163439	maanteed	maanteed =tee  (PlN  >maan+tee !26_S	et	f	\N
163440	maanteed	maanteed =tee  (SgP  >maan+tee !26_S	et	f	\N
163048	surmata	surmata =surma  (Inf  >surmama !29_V	et	f	\N
163049	surmata	surmata =surma  (IndPrIps_  >surmama !29_V	et	f	\N
163052	lõngakera	lõngakera =kera  (SgN  >lõnga+kera !17_S	et	f	\N
163053	lõngakera	lõngakera =kera  (SgG  >lõnga+kera !17_S	et	f	\N
163054	lõngakera	lõngakera =kera  (SgP  >lõnga+kera !17_S	et	f	\N
163062	peasend	?peasend =peasend  (SgN  >peasend !02_S	et	f	\N
163063	peasend	?peasend =send  (SgN  >pea+send !22_S	et	f	\N
163113	valvanud	valvanud =valva  (PtsPtPs  >valvama !29_V	et	f	\N
163114	valvanud	valvanud =valvanu  (PlN  >valvanu !01_S	et	f	\N
163115	valvanud	"valvanu %valva  )NU_vS  <valvama ;29_V	et	f	\N
163116	valvanud	valvanud =valvanud  (ID  >valvanud !41_A	et	f	\N
163117	valvanud	"valvanud %valva  )NUD_vA  <valvama ;29_V	et	f	\N
163123	ulnus	?ulnus =ulnu  (SgIn  >ulnu !01_S	et	f	\N
163125	ulnus	?ulnus =ulnu  (IndIpfSg3  >ulnuma !27_V	et	f	\N
163126	ulnus	?ulnus =ulnus  (SgN  >ulnus !11~09_S	et	f	\N
163135	kiljatanud	kiljatanud =kiljata  (PtsPtPs  >kiljatama !27_V	et	f	\N
163136	kiljatanud	kiljatanud =kiljatanu  (PlN  >kiljatanu !01_S	et	f	\N
163137	kiljatanud	"kiljatanu %kiljata  )NU_vS  <kiljatama ;27_V	et	f	\N
163138	kiljatanud	kiljatanud =kiljatanud  (ID  >kiljatanud !41_A	et	f	\N
163139	kiljatanud	"kiljatanud %kiljata  )NUD_vA  <kiljatama ;27_V	et	f	\N
163157	lüpsmata	lüpsmata =lüps  (SupAb  >lüpsma !32_V	et	f	\N
163158	lüpsmata	lüpsmata =lüpsmata  (ID  >lüpsmata !41_A	et	f	\N
163159	lüpsmata	"lüpsmata %lüps  )MATA_vA  <lüpsma ;32_V	et	f	\N
163171	taru	taru =taru  (SgN  >taru !17_S	et	f	\N
163172	taru	taru =taru  (SgG  >taru !17_S	et	f	\N
163173	taru	taru =taru  (SgP  >taru !17_S	et	f	\N
163174	ümbrusest	ümbrusest =ümbruse  (SgEl  >ümbrus !11~09_S	et	f	\N
163175	ümbrusest	ümbrusest =ümbruses  (SgP  >ümbrusene !12_A	et	f	\N
163176	ümbrusest	"ümbrusene %ümbruse  )NE_aA  <ümbrus ;09_S	et	f	\N
163177	ümbrusest	"ümbrusene %ümbruse  )NE_aA  <ümbrus ;11_S	et	f	\N
163184	lk200	### lk200	et	f	\N
163185	akorb	?akorb =akorb  (SgN  >akorb !22_S	et	f	\N
163191	madila	?madila =madila  (SgN  >madila !01_S	et	f	\N
163192	madila	?madila =madila  (SgG  >madila !01_S	et	f	\N
163217	obuse	?obuse =obuse  (SgG  >obus !02_A	et	f	\N
163220	istu	istu =istu  (ID  >istu !41_D	et	f	\N
163221	istu	istu =istu  (SgG  >ist !22_S	et	f	\N
163222	istu	istu =istu  (SgP  >ist !22_S	et	f	\N
163223	istu	istu =istu  (SgAdt  >ist !22_S	et	f	\N
163224	istu	istu =istu  (IndPrPs_  >istuma !28_V	et	f	\N
163225	istu	istu =istu  (ImpPrSg2  >istuma !28_V	et	f	\N
163235	sie	?sie =sie  (SgN  >sie !26_S	et	f	\N
163236	sie	?sie =sie  (SgG  >sie !26_S	et	f	\N
163255	vilhelmine	?vilhelmine =vilhelmine  (SgN  >vilhelmine !12_A	et	f	\N
163256	vilhelmine	?vilhelmine =vilhelmine  (PlP  >vilhelmin !19_S	et	f	\N
163273	sõjajuttu	sõjajuttu =juttu  (SgP  >sõja+jutt !22_S	et	f	\N
163274	sõjajuttu	sõjajuttu =juttu  (SgAdt  >sõja+jutt !22_S	et	f	\N
163287	vahtind	?vahtind =vahtind  (SgN  >vahtind !02_S	et	f	\N
163291	isa-ema	isa-ema =ema  (SgN  >isa-ema !17_S	et	f	\N
163292	isa-ema	isa-ema =ema  (SgG  >isa-ema !17_S	et	f	\N
163293	isa-ema	isa-ema =ema  (SgP  >isa-ema !17_S	et	f	\N
163333	volkssagen	?volkssagen =volkssagen  (SgN  >volkssagen !19_S	et	f	\N
163335	nr281	### nr281	et	f	\N
163345	mainimine	mainimine =mainimine  (SgN  >mainimine !12_S	et	f	\N
163346	mainimine	"mainimine %maini  )MINE_vS  <mainima ;28_V	et	f	\N
163360	ümberasumised	ümberasumised =asumise  (PlN  >ümber+asumine !12_S	et	f	\N
163361	ümberasumised	"ümber+asumine %asumi  )NE_aA  <ümber+asum ;02_S	et	f	\N
163372	anette	?anette =anette  (PlP  >anett !22_S	et	f	\N
163379	riisumise	riisumise =riisumise  (SgG  >riisumine !12_S	et	f	\N
163380	riisumise	"riisumine %riisu  )MINE_vS  <riisuma ;28_V	et	f	\N
163397	rahvaetümoloogiline	rahvaetümoloogiline =etümoloogiline  (SgN  >rahva+etümoloogiline !12_A	et	f	\N
163398	rahvaetümoloogiline	"rahva+etümoloogiline %etümoloogi  )LINE_aA  <rahva+etümoloog ;22_S	et	f	\N
163403	olulisim	olulisim =olulisim  (SgN  >olulisim !02_A	et	f	\N
163404	olulisim	"olulisim %olulisi  )IM_sA  <oluline ;12_A	et	f	\N
163412	kohanimetusega	kohanimetusega =nimetuse  (SgKom  >koha+nimetus !11_S	et	f	\N
163413	kohanimetusega	"koha+nimetus %nime  )TUS2_aS  <koha+nimi ;20_S	et	f	\N
163419	röövel	röövel =rööve  (PlAd  >rööv !22_S	et	f	\N
163420	röövel	röövel =röövel  (SgN  >röövel !02_S	et	f	\N
163431	ellujäänust	ellujäänust =jäänu  (SgEl  >ellu+jäänu !01_S	et	f	\N
163432	ellujäänust	ellujäänust =jäänu  (SgEl  >ellu+jäänu !06_S	et	f	\N
163433	ellujäänust	ellujäänust =jäänus  (SgP  >ellu+jäänus !09_S	et	f	\N
163441	ajanud	ajanud =aja  (PtsPtPs  >ajama !27_V	et	f	\N
163442	ajanud	ajanud =ajanu  (PlN  >ajanu !01_S	et	f	\N
163443	ajanud	"ajanu %aja  )NU_vS  <ajama ;27_V	et	f	\N
163444	ajanud	ajanud =ajanud  (ID  >ajanud !41_A	et	f	\N
163445	ajanud	"ajanud %aja  )NUD_vA  <ajama ;27_V	et	f	\N
163461	põhjasja	?põhjasja =põhjasja  (SgN  >põhjasja !01_S	et	f	\N
163462	põhjasja	?põhjasja =põhjasja  (SgG  >põhjasja !01_S	et	f	\N
163463	põhjasja	?põhjasja =põhjasja  (SgG  >põhjasjas !02_A	et	f	\N
163165	reinu	?reinu =reinu  (SgG  >reinu !16_S	et	f	\N
163166	reinu	?reinu =reinu  (IndPrPs_  >reinuma !28_V	et	f	\N
163167	reinu	?reinu =reinu  (ImpPrSg2  >reinuma !28_V	et	f	\N
163170	meiendorf	?meiendorf =meiendorf  (SgN  >meiendorf !22_S	et	f	\N
163178	ambla	?ambla =ambla  (SgN  >ambla !01_S	et	f	\N
163179	ambla	?ambla =ambla  (SgG  >ambla !01_S	et	f	\N
163180	ambla	?ambla =ambla  (IndPrPs_  >amblama !29_V	et	f	\N
163181	ambla	?ambla =ambla  (ImpPrSg2  >amblama !29_V	et	f	\N
163199	lk228	### lk228	et	f	\N
163200	vasalemmas	?vasalemmas =vasalemma  (SgIn  >vasalemma !16_S	et	f	\N
163206	nied	?nied =nie  (PlN  >nie !26_S	et	f	\N
163207	nied	?nied =nie  (SgP  >nie !26_S	et	f	\N
163208	nied	?nied =nied  (SgN  >nied !22_S	et	f	\N
163209	juurdes	?juurdes =juurde  (PlIn  >juurt !22_S	et	f	\N
163210	juurdes	?juurdes =juurde  (IndIpfSg3  >juurdema !27_V	et	f	\N
163211	juurdes	?juurdes =juurdes  (SgN  >juurdes !09_S	et	f	\N
163218	viel	?viel =vie  (SgAd  >vie !26_S	et	f	\N
163219	viel	?viel =viel  (SgN  >viel !22_S	et	f	\N
163237	akand	?akand =akand  (SgN  >akand !02_S	et	f	\N
163240	krabistanud	krabistanud =krabista  (PtsPtPs  >krabistama !27_V	et	f	\N
163241	krabistanud	krabistanud =krabistanu  (PlN  >krabistanu !01_S	et	f	\N
163242	krabistanud	"krabistanu %krabista  )NU_vS  <krabistama ;27_V	et	f	\N
163243	krabistanud	krabistanud =krabistanud  (ID  >krabistanud !41_A	et	f	\N
163244	krabistanud	"krabistanud %krabista  )NUD_vA  <krabistama ;27_V	et	f	\N
163245	valgeks	valgeks =valge  (SgTr  >valge !01_AS	et	f	\N
163246	valgeks	valgeks =valge  (PlTr  >valk !22_S	et	f	\N
163247	vindine	vindine =vindine  (SgN  >vindine !10_A	et	f	\N
163248	vindine	"vindine %vindi  )NE_aA  <vint ;22_S	et	f	\N
163253	joras	joras =jora  (SgIn  >jora !17_S	et	f	\N
163254	joras	joras =jora  (IndIpfSg3  >jorama !27_V	et	f	\N
163267	katku-	katku- =kat  (ImpPrPs  >katma !35_V	et	f	\N
163268	katku-	katku- =katku  (SgG  >katk !22_S	et	f	\N
163269	katku-	katku- =katku  (SgP  >katk !22_S	et	f	\N
163270	katku-	katku- =katku  (SgAdt  >katk !22_S	et	f	\N
163271	katku-	katku- =katku  (IndPrPs_  >katkuma !28_V	et	f	\N
163272	katku-	katku- =katku  (ImpPrSg2  >katkuma !28_V	et	f	\N
163285	läätseleent	?läätseleent =läätseleent  (SgN  >läätseleent !22_S	et	f	\N
163286	läätseleent	?läätseleent =eleent  (SgN  >lääts+eleent !22_S	et	f	\N
163294	üheteise	?üheteise =üheteise  (PlP  >üheteis !22_S	et	f	\N
163295	üheteise	?üheteise =teise  (PlP  >ühe+teis !22_S	et	f	\N
163298	koland	?koland =koland  (SgN  >koland !02_S	et	f	\N
163303	90a	### 90a	et	f	\N
163311	jalajälgi	jalajälgi =jälgi  (SgG  >jala+jälk !22_A	et	f	\N
163312	jalajälgi	jalajälgi =jälgi  (SgP  >jala+jälg !22_S	et	f	\N
163313	jalajälgi	jalajälgi =jälgi  (SgAdt  >jala+jälg !22_S	et	f	\N
163314	jalajälgi	jalajälgi =jälgi  (PlP  >jala+jälg !22_S	et	f	\N
163319	eestlste	?eestlste =eestlste  (SgN  >eestlste !06_S	et	f	\N
163320	eestlste	?eestlste =eestlste  (SgG  >eestlste !06_S	et	f	\N
163321	eestlste	?eestlste =eestlste  (PlP  >eestlst !22_S	et	f	\N
163322	eestlste	?eestlste =eestlste  (IndPrPs_  >eestlstema !27_V	et	f	\N
163323	eestlste	?eestlste =eestlste  (ImpPrSg2  >eestlstema !27_V	et	f	\N
163326	ajohanni	?ajohanni =ajohanni  (SgG  >ajohann !22_S	et	f	\N
163328	ajohanni	?ajohanni =ajohanni  (SgP  >ajohann !22_S	et	f	\N
163329	ajohanni	?ajohanni =ajohanni  (SgAdt  >ajohann !22_S	et	f	\N
163330	ajohanni	?ajohanni =ajohanni  (IndPrPs_  >ajohannima !28_V	et	f	\N
163332	ajohanni	?ajohanni =ajohanni  (ImpPrSg2  >ajohannima !28_V	et	f	\N
163342	lk373	### lk373	et	f	\N
163357	edasine	edasine =edasine  (SgN  >edasine !12_A	et	f	\N
163358	edasine	edasine =ine  (SgN  >edas+ine !16_S	et	f	\N
163359	edasine	edasine =ine  (SgG  >edas+ine !16_S	et	f	\N
163364	taluks	taluks =talu  (SgTr  >talu !17_S	et	f	\N
163365	taluks	taluks =talu  (KndPrPs  >taluma !27_V	et	f	\N
163368	niinepuu	niinepuu =puu  (SgN  >niine+puu !26_S	et	f	\N
163370	niinepuu	niinepuu =puu  (SgG  >niine+puu !26_S	et	f	\N
163383	koerakoonlasestest	?koerakoonlasestest =koerakoonlasestes  (SgP  >koerakoonlasestene !12_A	et	f	\N
163384	koerakoonlasestest	?koerakoonlasestest =koonlasestes  (SgP  >koera+koonlasestene !12_A	et	f	\N
163385	koerakoonlasestest	?koerakoonlasestest =rakoonlasestes  (SgP  >koe+rakoonlasestene !12_A	et	f	\N
163389	künokefaalid	?künokefaalid =künokefaali  (PlN  >künokefaali !16_S	et	f	\N
163390	künokefaalid	?künokefaalid =künokefaali  (PlN  >künokefaal !22_S	et	f	\N
163391	künokefaalid	?künokefaalid =künokefaali  (IndPrSg2  >künokefaalima !28_V	et	f	\N
163392	segunenud	segunenud =segune  (PtsPtPs  >segunema !27_V	et	f	\N
163393	segunenud	segunenud =segunenu  (PlN  >segunenu !01_S	et	f	\N
163394	segunenud	"segunenu %segune  )NU_vS  <segunema ;27_V	et	f	\N
163395	segunenud	segunenud =segunenud  (ID  >segunenud !41_A	et	f	\N
163396	segunenud	"segunenud %segune  )NUD_vA  <segunema ;27_V	et	f	\N
163401	kajastused	kajastused =kajastuse  (PlN  >kajastus !11_S	et	f	\N
163402	kajastused	"kajastus %kajasta  )US_vS  <kajastama ;27_V	et	f	\N
163410	röövlitest	röövlitest =röövli  (PlEl  >röövel !02_S	et	f	\N
163411	röövlitest	röövlitest =test  (SgN  >röövli+test !22_S	et	f	\N
163421	norinud	norinud =nori  (PtsPtPs  >norima !27_V	et	f	\N
163422	norinud	norinud =norinu  (PlN  >norinu !01_S	et	f	\N
163423	norinud	"norinu %nori  )NU_vS  <norima ;27_V	et	f	\N
163424	norinud	norinud =norinud  (ID  >norinud !41_A	et	f	\N
163425	norinud	"norinud %nori  )NUD_vA  <norima ;27_V	et	f	\N
163455	sünnitanud	sünnitanud =sünnita  (PtsPtPs  >sünnitama !27_V	et	f	\N
163456	sünnitanud	sünnitanud =sünnitanu  (PlN  >sünnitanu !01_S	et	f	\N
163457	sünnitanud	"sünnitanu %sünnita  )NU_vS  <sünnitama ;27_V	et	f	\N
163458	sünnitanud	sünnitanud =sünnitanud  (ID  >sünnitanud !41_A	et	f	\N
163459	sünnitanud	"sünnitanud %sünnita  )NUD_vA  <sünnitama ;27_V	et	f	\N
163460	sünnitanud	sünnitanud =tanu  (PlN  >sünni+tanu !17_S	et	f	\N
163486	küüne	küüne =küüne  (SgG  >küüs !14_S	et	f	\N
163487	küüne	küüne =küüne  (PlP  >küün !22_S	et	f	\N
163522	kangem	kangem =kangem  (SgN  >kangem !02_A	et	f	\N
163523	kangem	"kangem %kange  )M_cA  <kange ;01_A	et	f	\N
163530	84a	### 84a	et	f	\N
163539	kuivanud	kuivanud =kuiva  (PtsPtPs  >kuivama !28_V	et	f	\N
163540	kuivanud	kuivanud =kuivanu  (PlN  >kuivanu !01_S	et	f	\N
163541	kuivanud	"kuivanu %kuiva  )NU_vS  <kuivama ;28_V	et	f	\N
163542	kuivanud	kuivanud =kuivanud  (ID  >kuivanud !41_A	et	f	\N
163543	kuivanud	"kuivanud %kuiva  )NUD_vA  <kuivama ;28_V	et	f	\N
163561	sirle	?sirle =sirle  (SgN  >sirle !06_S	et	f	\N
163562	sirle	?sirle =sirle  (SgG  >sirle !06_S	et	f	\N
163563	sirle	?sirle =sirle  (PlP  >sirl !22_S	et	f	\N
163564	sirle	?sirle =sirle  (IndPrPs_  >sirlema !30_V	et	f	\N
163565	sirle	?sirle =sirle  (ImpPrSg2  >sirlema !30_V	et	f	\N
163567	78a	### 78a	et	f	\N
163572	liivimaalaste	liivimaalaste =las  (PlG  >liivi+maa+laps !14_S	et	f	\N
163573	liivimaalaste	liivimaalaste =laste  (PlP  >liivi+maa+last !22_S	et	f	\N
163574	liivimaalaste	liivimaalaste =maalas  (PlG  >liivi+maalane !12?10_S	et	f	\N
163587	taimedele	taimedele =taime  (PlAll  >taim !22_S	et	f	\N
163588	taimedele	taimedele =ede  (SgAll  >taim+ede !16_S	et	f	\N
163591	tajus	tajus =taju  (SgIn  >taju !17_S	et	f	\N
163592	tajus	tajus =taju  (IndIpfSg3  >tajuma !27_V	et	f	\N
163625	rajujat	?rajujat =rajuja  (SgP  >rajuja !01_S	et	f	\N
163626	rajujat	?rajujat =rajuja  (SgP  >rajujas !02_A	et	f	\N
163651	jõukeskuseks	jõukeskuseks =use  (PlTr  >jõu+kesk+usk !22_S	et	f	\N
163652	jõukeskuseks	jõukeskuseks =keskuse  (SgTr  >jõu+keskus !11~09_S	et	f	\N
163668	puisniit	?puisniit =puisniit  (SgN  >puisniit !22_S	et	f	\N
163721	kraabitud	kraabitud =kraabi  (PtsPtIps  >kraapima !28_V	et	f	\N
163722	kraabitud	kraabitud =kraabitu  (PlN  >kraabitu !01_AS	et	f	\N
163723	kraabitud	"kraabitu %kraabi  )TU1_vS  <kraapima ;28_V	et	f	\N
163724	kraabitud	"kraabitu %kraabi  )TU2_kA  <kraap ;22_S	et	f	\N
163725	kraabitud	kraabitud =kraabitud  (ID  >kraabitud !41_A	et	f	\N
163726	kraabitud	"kraabitud %kraabi  )TUD_vA  <kraapima ;28_V	et	f	\N
163736	alvine	?alvine =alvine  (SgN  >alvine !10_A	et	f	\N
163738	alvine	?alvine =alvine  (IndPrPs_  >alvinema !27_V	et	f	\N
163739	alvine	?alvine =alvine  (ImpPrSg2  >alvinema !27_V	et	f	\N
163741	uppund	?uppund =uppund  (SgN  >uppund !02_S	et	f	\N
163748	sodiseks	sodiseks =sodise  (SgTr  >sodine !10_A	et	f	\N
163750	sodiseks	"sodine %sodi  )NE_aA  <sodi ;17_S	et	f	\N
163756	lehtla	lehtla =lehtla  (SgN  >lehtla !01_S	et	f	\N
163757	lehtla	lehtla =lehtla  (SgG  >lehtla !01_S	et	f	\N
163758	76a	### 76a	et	f	\N
163816	leismann	?leismann =leismann  (SgN  >leismann !22_S	et	f	\N
163871	hanekaginat	?hanekaginat =kagina  (SgP  >hane+kagin !02_S	et	f	\N
163878	meetrise	meetrise =meetrise  (SgG  >meetrine !12~10_A	et	f	\N
163879	meetrise	"meetrine %meetri  )NE_aA  <meeter ;02_S	et	f	\N
163888	kultuurmaastikus	kultuurmaastikus =tiku  (SgIn  >kultuur+maas+tikk !22_S	et	f	\N
163889	kultuurmaastikus	kultuurmaastikus =tiku  (PlIn  >kultuur+maas+tikk !22_S	et	f	\N
163890	kultuurmaastikus	kultuurmaastikus =maastiku  (SgIn  >kultuur+maastik !25_S	et	f	\N
163891	heinamaal	heinamaal =maa  (SgAd  >heina+maa !26_S	et	f	\N
163892	heinamaal	heinamaal =maal  (SgN  >heina+maal !22_S	et	f	\N
163900	akitsik	?akitsik =akitsik  (SgN  >akitsik !02_S	et	f	\N
163913	sinn	?sinn =sinn  (SgN  >sinn !22_S	et	f	\N
163946	õeldi	?õeldi =õeldi  (ID  >õeldi !41_D	et	f	\N
163947	õeldi	?õeldi =õeldi  (SgG  >õelt !22_S	et	f	\N
163948	õeldi	?õeldi =õeldi  (SgP  >õeld !22_S	et	f	\N
163949	õeldi	?õeldi =õeldi  (SgAdt  >õeld !22_S	et	f	\N
163950	õeldi	?õeldi =õeldi  (IndPrPs_  >õeltima !28_V	et	f	\N
163951	õeldi	?õeldi =õeldi  (ImpPrSg2  >õeltima !28_V	et	f	\N
163964	karusmaa	karusmaa =maa  (SgN  >karus+maa !26_S	et	f	\N
163965	karusmaa	karusmaa =maa  (SgG  >karus+maa !26_S	et	f	\N
163985	mõnuste	### mõnuste	et	f	\N
164000	teeharu	teeharu =haru  (SgN  >tee+haru !17_S	et	f	\N
164001	teeharu	teeharu =haru  (SgG  >tee+haru !17_S	et	f	\N
164002	teeharu	teeharu =haru  (SgP  >tee+haru !17_S	et	f	\N
164013	tied	?tied =tie  (PlN  >tie !26_S	et	f	\N
164014	tied	?tied =tie  (SgP  >tie !26_S	et	f	\N
163427	hobuse	"hobune %hobu  )NE_aA  <hobu ;17_S	et	f	\N
163434	põlenud	põlenud =põle  (PtsPtPs  >põlema !27_V	et	f	\N
163435	põlenud	põlenud =põlenu  (PlN  >põlenu !01_S	et	f	\N
163436	põlenud	"põlenu %põle  )NU_vS  <põlema ;27_V	et	f	\N
163437	põlenud	põlenud =põlenud  (ID  >põlenud !41_A	et	f	\N
163438	põlenud	"põlenud %põle  )NUD_vA  <põlema ;27_V	et	f	\N
163446	seljast	seljast =selja  (SgEl  >selg !22_S	et	f	\N
163447	seljast	seljast =seljas  (SgP  >seljane !10_A	et	f	\N
163448	seljast	"seljane %selja  )NE_aA  <selg ;22_S	et	f	\N
163449	seljast	seljast =seljast  (ID  >seljast !41_D	et	f	\N
163450	varjanud	varjanud =varja  (PtsPtPs  >varjama !29_V	et	f	\N
163451	varjanud	varjanud =varjanu  (PlN  >varjanu !01_S	et	f	\N
163452	varjanud	"varjanu %varja  )NU_vS  <varjama ;29_V	et	f	\N
163453	varjanud	varjanud =varjanud  (ID  >varjanud !41_A	et	f	\N
163454	varjanud	"varjanud %varja  )NUD_vA  <varjama ;29_V	et	f	\N
163464	neti	?neti =neti  (SgN  >neti !16_S	et	f	\N
163465	neti	?neti =neti  (SgG  >neti !16_S	et	f	\N
163466	neti	?neti =neti  (SgG  >nett !22_AS	et	f	\N
163467	neti	?neti =neti  (IndPrPs_  >netima !27_V	et	f	\N
163468	neti	?neti =neti  (IndPrPs_  >nettima !28_V	et	f	\N
163469	neti	?neti =neti  (ImpPrSg2  >netima !27_V	et	f	\N
163470	neti	?neti =neti  (ImpPrSg2  >nettima !28_V	et	f	\N
163480	öeldma	?öeldma =öeldma  (IndPrPs_  >öeldmama !29_V	et	f	\N
163481	öeldma	?öeldma =öeldma  (ImpPrSg2  >öeldmama !29_V	et	f	\N
163488	ütlend	?ütlend =ütlend  (SgN  >ütlend !02_S	et	f	\N
163489	netu	?netu =netu  (SgN  >netu !16_S	et	f	\N
163490	netu	?netu =netu  (SgG  >netu !16_S	et	f	\N
163491	netu	?netu =netu  (IndPrPs_  >netuma !27_V	et	f	\N
163492	netu	?netu =netu  (ImpPrSg2  >netuma !27_V	et	f	\N
163493	imestusega	imestusega =imestuse  (SgKom  >imestus !11_S	et	f	\N
163494	imestusega	"imestus %imesta  )US_vS  <imestama ;27_V	et	f	\N
163513	81a	### 81a	et	f	\N
163537	1939a	### 1939a	et	f	\N
163547	vigalas	?vigalas =vigala  (SgIn  >vigala !01_S	et	f	\N
163566	pent	?pent =pent  (SgN  >pent !22_S	et	f	\N
163568	innocentius	?innocentius =innocentiu  (SgIn  >innocentiu !01_S	et	f	\N
163569	innocentius	?innocentius =innocentius  (SgN  >innocentius !11_S	et	f	\N
163582	selgetele	selgetele =selge  (PlAll  >selge !01_A	et	f	\N
163584	selgetele	selgetele =e  (PlAll  >selg+esi !15_S	et	f	\N
163589	panteistlikke	?panteistlikke =panteistlikke  (PlP  >panteistlik !25_A	et	f	\N
163590	panteistlikke	?panteistlikke =eistlikke  (PlP  >pant+eistlik !25_A	et	f	\N
163596	hiiepuud	hiiepuud =puu  (PlN  >hiie+puu !26_S	et	f	\N
163597	hiiepuud	hiiepuud =puu  (SgP  >hiie+puu !26_S	et	f	\N
163598	hiiepuud	hiiepuud =puud  (SgN  >hiie+puud !22_S	et	f	\N
163599	tammi	tammi =tammi  (SgG  >tamm !22_S	et	f	\N
163600	tammi	tammi =tammi  (SgP  >tamm !22_S	et	f	\N
163601	tammi	tammi =tammi  (SgAdt  >tamm !22_S	et	f	\N
163602	tammi	tammi =tammi  (PlP  >tamm !22_S	et	f	\N
163606	kaski	kaski =kaski  (SgG  >kask !22_S	et	f	\N
163607	kaski	kaski =kaski  (SgP  >kask !22_S	et	f	\N
163608	kaski	kaski =kaski  (SgAdt  >kask !22_S	et	f	\N
163609	kaski	kaski =kaski  (PlP  >kask !22_S	et	f	\N
163611	kaski	kaski =kas  (ID^  >kas !41_D	et	f	\N
163627	niidetud	niidetud =niide  (PtsPtIps  >niitma !34_V	et	f	\N
163628	niidetud	niidetud =niidetu  (PlN  >niidetu !01_AS	et	f	\N
163629	niidetud	"niidetu %niide  )TU1_vS  <niitma ;34_V	et	f	\N
163630	niidetud	niidetud =niidetud  (ID  >niidetud !41_A	et	f	\N
163631	niidetud	"niidetud %niide  )TUD_vA  <niitma ;34_V	et	f	\N
163632	nopitud	nopitud =nopi  (PtsPtIps  >noppima !28_V	et	f	\N
163633	nopitud	nopitud =nopitu  (PlN  >nopitu !01_AS	et	f	\N
163634	nopitud	"nopitu %nopi  )TU1_vS  <noppima ;28_V	et	f	\N
163635	nopitud	nopitud =nopitud  (ID  >nopitud !41_A	et	f	\N
163636	nopitud	"nopitud %nopi  )TUD_vA  <noppima ;28_V	et	f	\N
163641	asuvat	asuvat =asu  (KvtPrPs  >asuma !27_V	et	f	\N
163642	asuvat	asuvat =asuva  (SgP  >asuv !02_A	et	f	\N
163643	asuvat	"asuv %asu  )V_vA  <asuma ;27_V	et	f	\N
163649	punaseid	punaseid =punase  (PlP  >punane !10_AS	et	f	\N
163650	punaseid	"punane %puna  )NE_aA  <puna ;17_S	et	f	\N
163658	soosalu	soosalu =salu  (SgN  >soo+salu !17_S	et	f	\N
163659	soosalu	soosalu =salu  (SgG  >soo+salu !17_S	et	f	\N
163660	soosalu	soosalu =salu  (SgP  >soo+salu !17_S	et	f	\N
163674	hiietammestik	?hiietammestik =hiietammestik  (SgN  >hiietammestik !25_S	et	f	\N
163675	hiietammestik	?hiietammestik =estik  (SgN  >hiie+tamm+estik !02_S	et	f	\N
163676	hiietammestik	?hiietammestik =tammestik  (SgN  >hiie+tammestik !25_S	et	f	\N
163683	1949a	### 1949a	et	f	\N
163697	ravi-	ravi- =ravi  (SgN  >ravi !17_S	et	f	\N
163698	ravi-	ravi- =ravi  (SgG  >ravi !17_S	et	f	\N
163699	ravi-	ravi- =ravi  (SgP  >ravi !17_S	et	f	\N
163700	ravi-	ravi- =ravi  (IndPrPs_  >ravima !27_V	et	f	\N
163701	ravi-	ravi- =ravi  (ImpPrSg2  >ravima !27_V	et	f	\N
163714	allikatesse	allikatesse =allika  (PlIll  >allikas !02_S	et	f	\N
163715	allikatesse	allikatesse =ate  (PlIll  >allik+att !22_S	et	f	\N
163732	tampere	### tampere	et	f	\N
163471	tõmmanud	tõmmanud =tõmma  (PtsPtPs  >tõmbama !29_V	et	f	\N
163472	tõmmanud	tõmmanud =tõmmanu  (PlN  >tõmmanu !01_S	et	f	\N
163473	tõmmanud	"tõmmanu %tõmma  )NU_vS  <tõmbama ;29_V	et	f	\N
163474	tõmmanud	tõmmanud =tõmmanud  (ID  >tõmmanud !41_A	et	f	\N
163475	tõmmanud	"tõmmanud %tõmma  )NUD_vA  <tõmbama ;29_V	et	f	\N
163482	peitu	peitu =peitu  (SgP  >peit !22_S	et	f	\N
163483	peitu	peitu =peitu  (SgAdt  >peit !22_S	et	f	\N
163484	peitu	peitu =peitu  (IndPrPs_  >peituma !27_V	et	f	\N
163485	peitu	peitu =peitu  (ImpPrSg2  >peituma !27_V	et	f	\N
163524	haiba	?haiba =haiba  (SgN  >haiba !16_S	et	f	\N
163525	haiba	?haiba =haiba  (SgG  >haiba !16_S	et	f	\N
163526	haiba	?haiba =haiba  (IndPrPs_  >haibama !29_V	et	f	\N
163527	haiba	?haiba =haiba  (ImpPrSg2  >haibama !29_V	et	f	\N
163533	vahemetsa	vahemetsa =metsa  (SgG  >vahe+mets !22_S	et	f	\N
163534	vahemetsa	vahemetsa =metsa  (SgP  >vahe+mets !22_S	et	f	\N
163535	vahemetsa	vahemetsa =metsa  (SgAdt  >vahe+mets !22_S	et	f	\N
163544	vaaatasin	?vaaatasin =vaaata  (IndIpfSg1  >vaaatama !27_V	et	f	\N
163545	vaaatasin	?vaaatasin =vaaatasin  (SgN  >vaaatasin !19_S	et	f	\N
163546	muistendipärimust	?muistendipärimust =muistendipärimus  (SgP  >muistendipärimus !11?09_S	et	f	\N
163548	rääkimisest	rääkimisest =rääkimise  (SgEl  >rääkimine !12_S	et	f	\N
163549	rääkimisest	"rääkimine %rääki  )MINE_vS  <rääkima ;28_V	et	f	\N
163553	tapetud	tapetud =tape  (PtsPtIps  >tapma !35_V	et	f	\N
163554	tapetud	tapetud =tapetu  (PlN  >tapetu !01_S	et	f	\N
163555	tapetud	"tapetu %tape  )TU1_vS  <tapma ;35_V	et	f	\N
163556	tapetud	tapetud =tapetud  (ID  >tapetud !41_A	et	f	\N
163557	tapetud	"tapetud %tape  )TUD_vA  <tapma ;35_V	et	f	\N
163570	1119aasta	aasta =aasta  (SgN  >aasta !01_S	et	f	\N
163571	1119aasta	aasta =aasta  (SgG  >aasta !01_S	et	f	\N
163585	haljendavatele	haljendavatele =haljendava  (PlAll  >haljendav !02_A	et	f	\N
163586	haljendavatele	"haljendav %haljenda  )V_vA  <haljendama ;27_V	et	f	\N
163593	pühadust	pühadust =pühadus  (SgP  >pühadus !11_S	et	f	\N
163594	pühadust	"pühadus %püha  )US_aS  <püha ;17_SA	et	f	\N
163595	pühadust	pühadust =dust  (SgN  >püha+dust !22_S	et	f	\N
163603	harvemini	harvemini =harvemi  (SgTer  >harvem !02_A	et	f	\N
163604	harvemini	"harvem %harve  )M_cA  <harv ;22_A	et	f	\N
163605	harvemini	harvemini =harvemini  (ID  >harvemini !41_D	et	f	\N
163610	kuuski	kuuski =kuuski  (SgG  >kuusk !22_S	et	f	\N
163612	kuuski	kuuski =kuuski  (SgP  >kuusk !22_S	et	f	\N
163613	kuuski	kuuski =kuuski  (SgAdt  >kuusk !22_S	et	f	\N
163616	kuuski	kuuski =kuuski  (PlP  >kuusk !22_S	et	f	\N
163618	kuuski	kuuski =kuu  (SgIn^  >kuu !26_S	et	f	\N
163619	kuuski	kuuski =kuus  (SgN^  >kuus !14_N	et	f	\N
163637	üleloomulikku	üleloomulikku =loomulikku  (SgP  >üle+loomulik !25_A	et	f	\N
163638	üleloomulikku	üleloomulikku =loomulikku  (SgAdt  >üle+loomulik !25_A	et	f	\N
163669	rabast	rabast =raba  (SgEl  >raba !17_S	et	f	\N
163670	rabast	rabast =rabas  (SgP  >rabane !10_A	et	f	\N
163671	rabast	"rabane %raba  )NE_aA  <raba ;17_S	et	f	\N
163677	kuldkingaa	?kuldkingaa =kuldkingaa  (SgN  >kuldkingaa !26_S	et	f	\N
163678	kuldkingaa	?kuldkingaa =kuldkingaa  (SgG  >kuldkingaa !26_S	et	f	\N
163679	kuldkingaa	?kuldkingaa =kingaa  (SgN  >kuld+kingaa !26_S	et	f	\N
163680	kuldkingaa	?kuldkingaa =kingaa  (SgG  >kuld+kingaa !26_S	et	f	\N
163687	kilomeeter	kilomeeter =kilomeeter  (SgN  >kilomeeter !02_S	et	f	\N
163688	kilomeeter	kilomeeter =meeter  (SgN  >kilo+meeter !02_S	et	f	\N
163692	arvukama	arvukama =arvukama  (SgG  >arvukam !02_A	et	f	\N
163693	arvukama	"arvukam %arvuka  )M_cA  <arvukas ;02_A	et	f	\N
163694	arvukama	arvukama =kama  (SgN  >arvu+kama !17_S	et	f	\N
163695	arvukama	arvukama =kama  (SgG  >arvu+kama !17_S	et	f	\N
163696	arvukama	arvukama =kama  (SgP  >arvu+kama !17_S	et	f	\N
163707	funktsiooni	funktsiooni =funktsiooni  (SgG  >funktsioon !22_S	et	f	\N
163708	funktsiooni	funktsiooni =funktsiooni  (SgP  >funktsioon !22_S	et	f	\N
163709	funktsiooni	funktsiooni =funktsiooni  (SgAdt  >funktsioon !22_S	et	f	\N
163727	hõbedapuru	hõbedapuru =puru  (SgN  >hõbeda+puru !17_S	et	f	\N
163728	hõbedapuru	hõbedapuru =puru  (SgG  >hõbeda+puru !17_S	et	f	\N
163729	hõbedapuru	hõbedapuru =puru  (SgP  >hõbeda+puru !17_S	et	f	\N
163733	erna	?erna =erna  (SgN  >erna !16_S	et	f	\N
163734	erna	?erna =erna  (SgG  >erna !16_S	et	f	\N
163735	erna	?erna =erna  (IndPrPs_  >ernama !29_V	et	f	\N
163737	erna	?erna =erna  (ImpPrSg2  >ernama !29_V	et	f	\N
163745	tirisid	tirisid =tiri  (PlP  >tiri !17_S	et	f	\N
163746	tirisid	tirisid =tiri  (IndIpfSg2  >tirima !27_V	et	f	\N
163747	tirisid	tirisid =tiri  (IndIpfPl3  >tirima !27_V	et	f	\N
163754	maantee	maantee =tee  (SgN  >maan+tee !26_S	et	f	\N
163755	maantee	maantee =tee  (SgG  >maan+tee !26_S	et	f	\N
163778	allikast	allikast =allika  (SgEl  >allikas !02_S	et	f	\N
163779	allikast	allikast =allikas  (SgP  >allikane !12_A	et	f	\N
163780	allikast	"allikane %allika  )NE_aA  <allikas ;02_S	et	f	\N
163781	allikast	allikast =ast  (SgN  >allik+ast !22_S	et	f	\N
163794	aupa	?aupa =aupa  (SgN  >aupa !16_S	et	f	\N
163478	õeldnetu	?õeldnetu =õeldnetu  (IndPrPs_  >õeldnetuma !27_V	et	f	\N
163479	õeldnetu	?õeldnetu =õeldnetu  (ImpPrSg2  >õeldnetuma !27_V	et	f	\N
163495	mahtunud	mahtunud =mahtu  (PtsPtPs  >mahtuma !28_V	et	f	\N
163496	mahtunud	mahtunud =mahtunu  (PlN  >mahtunu !01_S	et	f	\N
163497	mahtunud	"mahtunu %mahtu  )NU_vS  <mahtuma ;28_V	et	f	\N
163498	mahtunud	mahtunud =mahtunud  (ID  >mahtunud !41_A	et	f	\N
163499	mahtunud	"mahtunud %mahtu  )NUD_vA  <mahtuma ;28_V	et	f	\N
163514	seostuvaib	?seostuvaib =seostuvaib  (SgN  >seostuvaib !22_S	et	f	\N
163515	kuningast	kuningast =kuninga  (SgEl  >kuningas !02_S	et	f	\N
163516	kuningast	kuningast =kuningas  (SgP  >kuningane !12_A	et	f	\N
163517	kuningast	"kuningane %kuninga  )NE_aA  <kuningas ;02_S	et	f	\N
163518	kuningast	kuningast =ast  (SgN  >kuning+ast !22_S	et	f	\N
163519	kaheteistkümnes	?kaheteistkümnes =kaheteistkümne  (PlIn  >kaheteistkümn !22_S	et	f	\N
163520	kaheteistkümnes	?kaheteistkümnes =kümne  (PlIn  >kahe+teist+kümn !22_S	et	f	\N
163521	kaheteistkümnes	?kaheteistkümnes =teistkümne  (PlIn  >kahe+teistkümn !22_S	et	f	\N
163528	toomberg	?toomberg =toomberg  (SgN  >toomberg !02_S	et	f	\N
163529	toomberg	?toomberg =berg  (SgN  >toom+berg !22_S	et	f	\N
163538	istutand	?istutand =istutand  (SgN  >istutand !22_S	et	f	\N
163550	unrehti	?unrehti =unrehti  (ID  >unrehti !41_D	et	f	\N
163551	unrehti	?unrehti =unrehti  (SgP  >unreht !22_S	et	f	\N
163552	unrehti	?unrehti =unrehti  (SgAdt  >unreht !22_S	et	f	\N
163575	kuuluvat	kuuluvat =kuulu  (KvtPrPs  >kuuluma !27_V	et	f	\N
163576	kuuluvat	kuuluvat =kuuluva  (SgP  >kuuluv !02_A	et	f	\N
163577	kuuluvat	"kuuluv %kuulu  )V_vA  <kuuluma ;27_V	et	f	\N
163581	lehtpuudele	lehtpuudele =puu  (PlAll  >leht+puu !26_S	et	f	\N
163583	lehtpuudele	lehtpuudele =puude  (SgAll  >leht+puue !06_S	et	f	\N
163614	leppi	leppi =leppi  (SgP  >lepp !22_S	et	f	\N
163615	leppi	leppi =leppi  (SgP  >lepp !22_SA	et	f	\N
163617	leppi	leppi =leppi  (SgAdt  >lepp !22_S	et	f	\N
163620	leppi	leppi =leppi  (SgAdt  >lepp !22_SA	et	f	\N
163622	leppi	leppi =leppi  (PlP  >lepp !22_S	et	f	\N
163624	leppi	leppi =leppi  (PlP  >lepp !22_SA	et	f	\N
163639	hiis	hiis =hii  (SgIn  >hii !26_S	et	f	\N
163640	hiis	hiis =hiis  (SgN  >hiis !14_S	et	f	\N
163684	maalinna	maalinna =linna  (SgG  >maa+linn !22_S	et	f	\N
163685	maalinna	maalinna =linna  (SgP  >maa+linn !22_S	et	f	\N
163686	maalinna	maalinna =linna  (SgAdt  >maa+linn !22_S	et	f	\N
163702	silma-	silma- =silma  (SgG  >silm !22_S	et	f	\N
163703	silma-	silma- =silma  (SgP  >silm !22_S	et	f	\N
163704	silma-	silma- =silma  (SgAdt  >silm !22_S	et	f	\N
163705	silma-	silma- =silma  (IndPrPs_  >silmama !29_V	et	f	\N
163706	silma-	silma- =silma  (ImpPrSg2  >silmama !29_V	et	f	\N
163742	sonisid	sonisid =soni  (PlP  >soni !17_S	et	f	\N
163743	sonisid	sonisid =soni  (IndIpfSg2  >sonima !27_V	et	f	\N
163744	sonisid	sonisid =soni  (IndIpfPl3  >sonima !27_V	et	f	\N
163753	koerakingumägi	### koerakingumägi	et	f	\N
163761	tabara	?tabara =tabara  (SgN  >tabara !01_S	et	f	\N
163762	tabara	?tabara =tabara  (SgG  >tabara !01_S	et	f	\N
163773	jooksid	jooksid =joo  (KndPrSg2  >jooma !38_V	et	f	\N
163774	jooksid	jooksid =joo  (KndPrPl3  >jooma !38_V	et	f	\N
163775	jooksid	jooksid =jooks  (IndIpfSg2  >jooksma !32_V	et	f	\N
163776	jooksid	jooksid =jooks  (IndIpfPl3  >jooksma !32_V	et	f	\N
163777	jooksid	jooksid =jooksi  (PlN  >jooks !22_S	et	f	\N
163782	vsdamas	?vsdamas =vsdama  (SgIn  >vsdama !17_S	et	f	\N
163783	vsdamas	?vsdamas =vsdama  (IndIpfSg3  >vsdamama !27_V	et	f	\N
163784	vsdamas	?vsdamas =vsdamas  (SgN  >vsdamas !09_S	et	f	\N
163812	veetõusmesse	veetõusmesse =tõusme  (SgIll  >vee+tõuse !05_S	et	f	\N
163813	veetõusmesse	veetõusmesse =tõusmes  (SgAdt  >vee+tõusmene !12_A	et	f	\N
163814	veetõusmesse	"vee+tõusmene %tõusme  )NE_aA  <vee+tõuse ;05_S	et	f	\N
163817	valgejärve	valgejärve =järve  (SgG  >valge+järv !22_S	et	f	\N
163818	valgejärve	valgejärve =järve  (SgP  >valge+järv !22_S	et	f	\N
163819	valgejärve	valgejärve =järve  (SgAdt  >valge+järv !22_S	et	f	\N
163820	valgejärve	valgejärve =järve  (PlP  >valge+järv !22_S	et	f	\N
163826	raba	raba =raba  (SgN  >raba !17_S	et	f	\N
163827	raba	raba =raba  (SgG  >raba !17_S	et	f	\N
163828	raba	raba =raba  (SgP  >raba !17_S	et	f	\N
163829	raba	raba =raba  (IndPrPs_  >rabama !27_V	et	f	\N
163830	raba	raba =raba  (ImpPrSg2  >rabama !27_V	et	f	\N
163831	sillasoo	sillasoo =soo  (SgN  >silla+soo !26_S	et	f	\N
163832	sillasoo	sillasoo =soo  (SgG  >silla+sugu !18_S	et	f	\N
163833	sillasoo	sillasoo =soo  (SgG  >silla+soo !26_S	et	f	\N
163834	järveotsa	järveotsa =otsa  (SgG  >järve+ots !23?22_S	et	f	\N
163835	järveotsa	järveotsa =otsa  (SgP  >järve+ots !23?22_S	et	f	\N
163836	järveotsa	järveotsa =otsa  (SgAdt  >järve+ots !23?22_S	et	f	\N
163846	tussud	?tussud =tussu  (PlN  >tussu !16_S	et	f	\N
163847	tussud	?tussud =tussu  (IndPrSg2  >tussuma !27_V	et	f	\N
163851	paljas	paljas =palja  (SgIn  >paljas !07_A	et	f	\N
163852	paljas	paljas =paljas  (SgN  >paljas !07_A	et	f	\N
163865	kuristikuga	kuristikuga =kuristiku  (SgKom  >kuristik !25_S	et	f	\N
163500	küüni	küüni =küü  (SgTer  >küü !26_S	et	f	\N
163501	küüni	küüni =küüni  (SgG  >küün !22_S	et	f	\N
163502	küüni	küüni =küüni  (SgP  >küün !22_S	et	f	\N
163503	küüni	küüni =küüni  (SgAdt  >küün !22_S	et	f	\N
163504	küüni	küüni =küüni  (IndPrPs_  >küündima !28_V	et	f	\N
163505	küüni	küüni =küüni  (ImpPrSg2  >küündima !28_V	et	f	\N
163506	liisi	?liisi =liisi  (SgN  >liisi !16_S	et	f	\N
163507	liisi	?liisi =liisi  (SgG  >liisi !16_S	et	f	\N
163508	liisi	?liisi =liisi  (SgG  >liis !22_S	et	f	\N
163509	liisi	?liisi =liisi  (SgP  >liis !22_S	et	f	\N
163510	liisi	?liisi =liisi  (SgAdt  >liis !22_S	et	f	\N
163511	liisi	?liisi =liisi  (IndPrPs_  >liisima !28_V	et	f	\N
163512	liisi	?liisi =liisi  (ImpPrSg2  >liisima !28_V	et	f	\N
163531	kadakas	kadakas =kadaka  (SgIn  >kadakas !02_S	et	f	\N
163532	kadakas	kadakas =kadakas  (SgN  >kadakas !02_S	et	f	\N
163536	karotamm	?karotamm =karotamm  (SgN  >karotamm !22_S	et	f	\N
163558	sissi	sissi =sissi  (SgG  >siss !22_S	et	f	\N
163559	sissi	sissi =sissi  (SgP  >siss !22_S	et	f	\N
163560	sissi	sissi =sissi  (SgAdt  >siss !22_S	et	f	\N
163578	osutavad	osutavad =osuta  (IndPrPl3  >osutama !27_V	et	f	\N
163579	osutavad	osutavad =osutava  (PlN  >osutav !02_A	et	f	\N
163580	osutavad	"osutav %osuta  )V_vA  <osutama ;27_V	et	f	\N
163621	hiiepuu	hiiepuu =puu  (SgN  >hiie+puu !26_S	et	f	\N
163623	hiiepuu	hiiepuu =puu  (SgG  >hiie+puu !26_S	et	f	\N
163644	aoleariuse	?aoleariuse =aoleariuse  (SgG  >aolearius !11_S	et	f	\N
163645	aoleariuse	?aoleariuse =leariuse  (SgG  >ao+learius !11_S	et	f	\N
163646	karsivad	?karsivad =karsi  (IndPrPl3  >karssima !28_V	et	f	\N
163647	karsivad	?karsivad =karsiva  (PlN  >karsiva !01_S	et	f	\N
163648	karsivad	?karsivad =karsiva  (PlN  >karsiv !02_A	et	f	\N
163653	arstimas	arstimas =arsti  (SupIn  >arstima !28_V	et	f	\N
163654	arstimas	arstimas =arstima  (SgIn  >arstim !02_S	et	f	\N
163655	arstimas	arstimas =ima  (SgIn  >arst+ima !17_S	et	f	\N
163656	heinamaad	heinamaad =maa  (PlN  >heina+maa !26_S	et	f	\N
163657	heinamaad	heinamaad =maa  (SgP  >heina+maa !26_S	et	f	\N
163661	taime	taime =taime  (SgG  >taim !22_S	et	f	\N
163662	taime	taime =taime  (SgP  >taim !22_S	et	f	\N
163663	taime	taime =taime  (SgAdt  >taim !22_S	et	f	\N
163664	taime	taime =taime  (PlP  >taim !22_S	et	f	\N
163665	tunnud	?tunnud =tunnu  (PlN  >tunnu !16_S	et	f	\N
163666	tunnud	?tunnud =tunnu  (IndPrSg2  >tunnuma !27_V	et	f	\N
163667	tunnud	?tunnud =tunnud  (ID  >tunnud !41_A	et	f	\N
163672	vundamendikohad	vundamendikohad =koha  (PlN  >vundamendi+koha !17_S	et	f	\N
163673	vundamendikohad	vundamendikohad =koha  (PlN  >vundamendi+koht !22_S	et	f	\N
163681	jänesekäppa	jänesekäppa =käppa  (SgP  >jänese+käpp !22_S	et	f	\N
163682	jänesekäppa	jänesekäppa =käppa  (SgAdt  >jänese+käpp !22_S	et	f	\N
163689	valli	valli =valli  (SgG  >vall !22_S	et	f	\N
163690	valli	valli =valli  (SgP  >vall !22_S	et	f	\N
163691	valli	valli =valli  (SgAdt  >vall !22_S	et	f	\N
163710	tamla	?tamla =tamla  (SgN  >tamla !16_S	et	f	\N
163711	tamla	?tamla =tamla  (SgG  >tamla !16_S	et	f	\N
163712	tamla	?tamla =tamla  (IndPrPs_  >tamlama !29_V	et	f	\N
163713	tamla	?tamla =tamla  (ImpPrSg2  >tamlama !29_V	et	f	\N
163716	ohverdatud	ohverdatud =ohverda  (PtsPtIps  >ohverdama !27_V	et	f	\N
163717	ohverdatud	ohverdatud =ohverdatu  (PlN  >ohverdatu !01_S	et	f	\N
163718	ohverdatud	"ohverdatu %ohverda  )TU1_vS  <ohverdama ;27_V	et	f	\N
163719	ohverdatud	ohverdatud =ohverdatud  (ID  >ohverdatud !41_A	et	f	\N
163720	ohverdatud	"ohverdatud %ohverda  )TUD_vA  <ohverdama ;27_V	et	f	\N
163730	raviks	raviks =ravi  (SgTr  >ravi !17_S	et	f	\N
163731	raviks	raviks =ravi  (KndPrPs  >ravima !27_V	et	f	\N
163740	83a	### 83a	et	f	\N
163749	kaitseks	kaitseks =kaitse  (SgTr  >kaitse !06_S	et	f	\N
163751	kaitseks	kaitseks =kaitse  (KndPrPs  >kaitsema !28_V	et	f	\N
163752	kaitseks	kaitseks =kaitse  (KndPrPs  >kaitsma !32_V	et	f	\N
163759	soovitati	soovitati =soovita  (IndIpfIps  >soovitama !27_V	et	f	\N
163760	soovitati	soovitati =tati  (SgG  >soovi+tatt !22_S	et	f	\N
163763	alma	?alma =alma  (SgN  >alma !16_S	et	f	\N
163764	alma	?alma =alma  (SgG  >alma !16_S	et	f	\N
163765	alma	?alma =alma  (IndPrPs_  >almama !29_V	et	f	\N
163766	alma	?alma =alma  (ImpPrSg2  >almama !29_V	et	f	\N
163769	1915a	### 1915a	et	f	\N
163785	ravimõju	ravimõju =mõju  (SgN  >ravi+mõju !17_S	et	f	\N
163786	ravimõju	ravimõju =mõju  (SgG  >ravi+mõju !17_S	et	f	\N
163787	ravimõju	ravimõju =mõju  (SgP  >ravi+mõju !17_S	et	f	\N
163788	pesemiseks	pesemiseks =pesemise  (SgTr  >pesemine !12_S	et	f	\N
163789	pesemiseks	"pesemine %pese  )MINE_vS  <pesema ;36_V	et	f	\N
163790	aupa	?aupa =aupa  (SgN  >aupa !16_S	et	f	\N
163791	aupa	?aupa =aupa  (SgG  >aupa !16_S	et	f	\N
163792	aupa	?aupa =aupa  (IndPrPs_  >aupama !29_V	et	f	\N
163793	aupa	?aupa =aupa  (ImpPrSg2  >aupama !29_V	et	f	\N
163800	praedugi	?praedugi =dugi  (SgN  >prae+dugi !17_S	et	f	\N
163801	praedugi	?praedugi =dugi  (SgG  >prae+dugi !17_S	et	f	\N
163767	põldma	?põldma =põldma  (IndPrPs_  >põldmama !29_V	et	f	\N
163768	põldma	?põldma =põldma  (ImpPrSg2  >põldmama !29_V	et	f	\N
163770	järvatse	?järvatse =järvatse  (SgG  >järvatne !02_A	et	f	\N
163771	järvatse	?järvatse =järvatse  (IndPrPs_  >järvatsema !27_V	et	f	\N
163772	järvatse	?järvatse =järvatse  (ImpPrSg2  >järvatsema !27_V	et	f	\N
163853	luukere	luukere =ere  (SgN  >luuk+ere !02_A	et	f	\N
163854	luukere	luukere =kere  (SgN  >luu+kere !16_S	et	f	\N
163855	luukere	luukere =kere  (SgG  >luu+kere !16_S	et	f	\N
163856	kiva	?kiva =kiva  (SgN  >kiva !17_S	et	f	\N
163857	kiva	?kiva =kiva  (SgG  >kiva !17_S	et	f	\N
163858	kiva	?kiva =kiva  (SgP  >kiva !17_S	et	f	\N
163859	kiva	?kiva =kiva  (IndPrPs_  >kivama !27_V	et	f	\N
163860	kiva	?kiva =kiva  (ImpPrSg2  >kivama !27_V	et	f	\N
163861	viidiauk	?viidiauk =viidiauk  (SgN  >viidiauk !22_S	et	f	\N
163882	ravitud	ravitud =ravi  (PtsPtIps  >ravima !27_V	et	f	\N
163883	ravitud	ravitud =ravitu  (PlN  >ravitu !01_AS	et	f	\N
163884	ravitud	"ravitu %ravi  )TU1_vS  <ravima ;27_V	et	f	\N
163885	ravitud	"ravitu %ravi  )TU2_kA  <ravi ;17_S	et	f	\N
163886	ravitud	ravitud =ravitud  (ID  >ravitud !41_A	et	f	\N
163887	ravitud	"ravitud %ravi  )TUD_vA  <ravima ;27_V	et	f	\N
163901	aadul	?aadul =aadu  (SgAd  >aadu !16_S	et	f	\N
163902	aadul	?aadul =aadul  (SgN  >aadul !02_S	et	f	\N
163916	pärimuses	pärimuses =pärimuse  (SgIn  >pärimus !11_S	et	f	\N
163917	pärimuses	"pärimus %päri  )MUS_vS  <pärima ;27_V	et	f	\N
163928	umbluu	umbluu =luu  (SgN  >umb+luu !26_S	et	f	\N
163929	umbluu	umbluu =luu  (SgG  >umb+luu !26_S	et	f	\N
163935	jooksu	jooksu =jooksu  (SgG  >jooks !22_S	et	f	\N
163936	jooksu	jooksu =jooksu  (SgP  >jooks !22_S	et	f	\N
163937	jooksu	jooksu =jooksu  (SgAdt  >jooks !22_S	et	f	\N
163941	rahvausundiliste	rahvausundiliste =usundilis  (PlG  >rahva+usundiline !12_A	et	f	\N
163942	rahvausundiliste	"rahva+usundiline %usundi  )LINE_aA  <rahva+usund ;02_S	et	f	\N
163958	natalja	?natalja =natalja  (SgN  >natalja !16_S	et	f	\N
163959	natalja	?natalja =natalja  (SgG  >nataljas !02_A	et	f	\N
163960	natalja	?natalja =natalja  (SgG  >natalja !16_S	et	f	\N
163961	kivivare	kivivare =vare  (SgN  >kivi+vare !04_S	et	f	\N
163962	kivivare	kivivare =vare  (SgN  >kivi+vare !16_S	et	f	\N
163963	kivivare	kivivare =vare  (SgG  >kivi+vare !16_S	et	f	\N
163969	koppelmaa	?koppelmaa =koppelmaa  (SgN  >koppelmaa !26_S	et	f	\N
163970	koppelmaa	?koppelmaa =koppelmaa  (SgG  >koppelmaa !26_S	et	f	\N
163976	pudelise	pudelise =pudelise  (SgG  >pudeline !12_A	et	f	\N
163977	pudelise	"pudeline %pudeli  )NE_aA  <pudel ;02_S	et	f	\N
163979	rahnimägi	### rahnimägi	et	f	\N
163982	pohla	pohla =pohla  (SgG  >pohl !22_S	et	f	\N
163983	pohla	pohla =pohla  (SgP  >pohl !22_S	et	f	\N
163984	pohla	pohla =pohla  (SgAdt  >pohl !22_S	et	f	\N
163986	pikassalu	?pikassalu =pikassalu  (IndPrPs_  >pikassaluma !27_V	et	f	\N
163987	pikassalu	?pikassalu =pikassalu  (ImpPrSg2  >pikassaluma !27_V	et	f	\N
163996	kroosu	?kroosu =kroosu  (SgN  >kroosu !16_S	et	f	\N
163997	kroosu	?kroosu =kroosu  (SgG  >kroosu !16_S	et	f	\N
163998	kroosu	?kroosu =kroosu  (IndPrPs_  >kroosuma !27_V	et	f	\N
163999	kroosu	?kroosu =kroosu  (ImpPrSg2  >kroosuma !27_V	et	f	\N
164022	kerstu	?kerstu =kerstu  (SgN  >kerstu !01_S	et	f	\N
164023	kerstu	?kerstu =kerstu  (SgG  >kerstu !01_S	et	f	\N
164024	kerstu	?kerstu =kerstu  (IndPrPs_  >kerstuma !27_V	et	f	\N
164025	kerstu	?kerstu =kerstu  (ImpPrSg2  >kerstuma !27_V	et	f	\N
164039	moad	?moad =moa  (PlN  >moa !26_S	et	f	\N
164040	moad	?moad =moa  (SgP  >moa !26_S	et	f	\N
164041	moad	?moad =moad  (SgN  >moad !22_S	et	f	\N
164051	pagan	pagan =pagan  (ID  >pagan !41_I	et	f	\N
164052	pagan	pagan =pagan  (SgN  >pagan !02_S	et	f	\N
164060	paemurdu	paemurdu =murdu  (SgP  >pae+murd !22_S	et	f	\N
164061	paemurdu	paemurdu =murdu  (SgAdt  >pae+murd !22_S	et	f	\N
164075	pattu	pattu =pattu  (SgP  >patt !22_S	et	f	\N
164076	pattu	pattu =pattu  (SgAdt  >patt !22_S	et	f	\N
164093	nüid	?nüid =nüi  (PlN  >nüi !26_S	et	f	\N
164094	nüid	?nüid =nüi  (SgP  >nüi !26_S	et	f	\N
164095	nüid	?nüid =nüid  (SgN  >nüid !22_S	et	f	\N
164100	nüssen	?nüssen =nüsse  (IndPrSg1  >nüssema !27_V	et	f	\N
164101	nüssen	?nüssen =nüssen  (SgN  >nüssen !02_S	et	f	\N
164121	viind	?viind =viind  (SgN  >viind !22_S	et	f	\N
164135	palmse	?palmse =palmse  (SgN  >palmse !06_S	et	f	\N
164137	palmse	?palmse =palmse  (SgG  >palmne !02_A	et	f	\N
164139	palmse	?palmse =palmse  (SgG  >palmse !06_S	et	f	\N
164140	palmse	?palmse =palmse  (PlP  >palms !22_S	et	f	\N
164141	palmse	?palmse =palmse  (IndPrPs_  >palmsema !27_V	et	f	\N
164142	palmse	?palmse =palmse  (ImpPrSg2  >palmsema !27_V	et	f	\N
164149	surnuaiale	surnuaiale =aia  (SgAll  >surnu+aed !22_S	et	f	\N
164150	surnuaiale	surnuaiale =aia  (SgAll  >surnu+ai !22_S	et	f	\N
164151	kivitammi	kivitammi =tammi  (SgG  >kivi+tamm !22_S	et	f	\N
164152	kivitammi	kivitammi =tammi  (SgP  >kivi+tamm !22_S	et	f	\N
164153	kivitammi	kivitammi =tammi  (SgAdt  >kivi+tamm !22_S	et	f	\N
163795	aupa	?aupa =aupa  (SgG  >aupa !16_S	et	f	\N
163796	aupa	?aupa =aupa  (IndPrPs_  >aupama !29_V	et	f	\N
163797	aupa	?aupa =aupa  (ImpPrSg2  >aupama !29_V	et	f	\N
163798	silmaallikas	silmaallikas =allika  (SgIn  >silma+allikas !02_S	et	f	\N
163799	silmaallikas	silmaallikas =allikas  (SgN  >silma+allikas !02_S	et	f	\N
163807	kuristikust	kuristikust =kuristiku  (SgEl  >kuristik !25_S	et	f	\N
163808	kuristikust	kuristikust =kuristikus  (SgP  >kuristikune !10?12_A	et	f	\N
163809	kuristikust	"kuristikune %kuristiku  )NE_aA  <kuristik ;25_S	et	f	\N
163810	kuristikust	kuristikust =tiku  (SgEl  >kuris+tikk !22_S	et	f	\N
163811	kuristikust	kuristikust =tiku  (PlEl  >kuris+tikk !22_S	et	f	\N
163821	muda	muda =muda  (SgN  >muda !17_S	et	f	\N
163822	muda	muda =muda  (SgG  >muda !17_S	et	f	\N
163823	muda	muda =muda  (SgP  >muda !17_S	et	f	\N
163824	ellamaal	?ellamaal =ellamaa  (SgAd  >ellamaa !26_S	et	f	\N
163825	ellamaal	?ellamaal =ellamaal  (SgN  >ellamaal !22_S	et	f	\N
163848	kuristikus	kuristikus =kuristiku  (SgIn  >kuristik !25_S	et	f	\N
163849	kuristikus	kuristikus =tiku  (SgIn  >kuris+tikk !22_S	et	f	\N
163850	kuristikus	kuristikus =tiku  (PlIn  >kuris+tikk !22_S	et	f	\N
163862	maa-aluse	maa-aluse =aluse  (SgG  >maa-alus !09_S	et	f	\N
163863	maa-aluse	maa-aluse =aluse  (SgG  >maa-alune !10_AS	et	f	\N
163864	maa-aluse	"maa-alune %alu  )NE_aA  <maa-alg ;22_S	et	f	\N
163872	väljatse	?väljatse =väljatse  (SgG  >väljatne !02_A	et	f	\N
163873	väljatse	?väljatse =väljatse  (IndPrPs_  >väljatsema !27_V	et	f	\N
163874	väljatse	?väljatse =väljatse  (ImpPrSg2  >väljatsema !27_V	et	f	\N
163877	pühakspidamiseks	?pühakspidamiseks =pühakspidamise  (SgTr  >pühakspidamine !12_S	et	f	\N
163880	süvenditega	süvenditega =süvendi  (PlKom  >süvendi !01_S	et	f	\N
163881	süvenditega	süvenditega =süvendi  (PlKom  >süvend !02_S	et	f	\N
163911	ohverdamisest	ohverdamisest =ohverdamise  (SgEl  >ohverdamine !12_S	et	f	\N
163912	ohverdamisest	"ohverdamine %ohverda  )MINE_vS  <ohverdama ;27_V	et	f	\N
163914	risune	risune =risune  (SgN  >risune !10_A	et	f	\N
163915	risune	"risune %risu  )NE_aA  <risu ;17_S	et	f	\N
163921	sääreluud	sääreluud =luu  (PlN  >sääre+luu !26_S	et	f	\N
163922	sääreluud	sääreluud =luu  (SgP  >sääre+luu !26_S	et	f	\N
163923	sääreluud	sääreluud =luud  (SgN  >sääre+luud !22_S	et	f	\N
163924	ajand	?ajand =ajand  (SgN  >ajand !02_S	et	f	\N
163930	umbluu	umbluu =luu  (SgN  >umb+luu !26_S	et	f	\N
163931	umbluu	umbluu =luu  (SgG  >umb+luu !26_S	et	f	\N
163932	aram	?aram =aram  (SgN  >aram !02_A	et	f	\N
163938	katuvad	?katuvad =katu  (IndPrPl3  >katuma !27_V	et	f	\N
163939	katuvad	?katuvad =katuva  (PlN  >katuva !01_S	et	f	\N
163940	katuvad	?katuvad =katuva  (PlN  >katuv !02_A	et	f	\N
163972	karupuhkamisemägi	### karupuhkamisemägi	et	f	\N
163978	kõrtsumägi	### kõrtsumägi	et	f	\N
163993	keabaste	?keabaste =keabas  (PlG  >keabas !07_S	et	f	\N
163994	keabaste	?keabaste =keabas  (PlG  >keabane !10_A	et	f	\N
164008	karjatatud	karjatatud =karjata  (PtsPtIps  >karjatama !27_V	et	f	\N
164009	karjatatud	karjatatud =karjatatu  (PlN  >karjatatu !01_S	et	f	\N
164010	karjatatud	"karjatatu %karjata  )TU1_vS  <karjatama ;27_V	et	f	\N
164011	karjatatud	karjatatud =karjatatud  (ID  >karjatatud !41_A	et	f	\N
164012	karjatatud	"karjatatud %karjata  )TUD_vA  <karjatama ;27_V	et	f	\N
164030	ruuna	ruuna =ruuna  (SgG  >ruun !22_S	et	f	\N
164031	ruuna	ruuna =ruuna  (SgP  >ruun !22_S	et	f	\N
164032	ruuna	ruuna =ruuna  (SgAdt  >ruun !22_S	et	f	\N
164033	ruuna	ruuna =ruuna  (IndPrPs_  >ruunama !29_V	et	f	\N
164034	ruuna	ruuna =ruuna  (ImpPrSg2  >ruunama !29_V	et	f	\N
164044	kultuurilised	kultuurilised =kultuurilise  (PlN  >kultuuriline !12_A	et	f	\N
164045	kultuurilised	"kultuuriline %kultuuri  )LINE_aA  <kultuur ;22_S	et	f	\N
164049	kernult	?kernult =kernu  (SgAbl  >kernu !01_S	et	f	\N
164050	kernult	?kernult =kernult  (ID  >kernult !41_D	et	f	\N
164053	vedasid	vedasid =veda  (PlP  >veda !17_S	et	f	\N
164054	vedasid	vedasid =veda  (IndIpfSg2  >vedama !28_V	et	f	\N
164055	vedasid	vedasid =veda  (IndIpfPl3  >vedama !28_V	et	f	\N
164062	käijad	käijad =käija  (PlN  >käija !01_S	et	f	\N
164063	käijad	"käija %käi  )JA_vS  <käima ;38_V	et	f	\N
164073	raskeste	?raskeste =raskes  (PlG  >raskes !09_S	et	f	\N
164074	raskeste	?raskeste =raskes  (PlG  >raskene !12~10_A	et	f	\N
164081	kloostres	?kloostres =kloostre  (SgIn  >kloostre !06_S	et	f	\N
164082	kloostres	?kloostres =kloostre  (IndIpfSg3  >kloostrema !27_V	et	f	\N
164083	kloostres	?kloostres =kloostres  (SgN  >kloostres !09_S	et	f	\N
164102	alune	alune =alune  (SgN  >alune !10_AS	et	f	\N
164103	alune	"alune %alu  )NE_aA  <alg ;22_S	et	f	\N
164110	lollakas	lollakas =lollaka  (SgIn  >lollakas !02_AS	et	f	\N
164111	lollakas	lollakas =lollakas  (SgN  >lollakas !02_AS	et	f	\N
164112	lollakas	lollakas =aka  (SgIn  >loll+aka !16_S	et	f	\N
164143	tohvri	?tohvri =tohvri  (SgN  >tohvri !01_S	et	f	\N
164144	tohvri	?tohvri =tohvri  (SgG  >tohvri !01_S	et	f	\N
164145	tohvri	?tohvri =tohvri  (SgG  >tohver !02_S	et	f	\N
164146	tohvri	?tohvri =tohvri  (IndPrPs_  >tohvrima !28_V	et	f	\N
163802	praedugi	?praedugi =dugi  (SgP  >prae+dugi !17_S	et	f	\N
163803	praedugi	?praedugi =praedu  (SgN^  >praedu !16_S	et	f	\N
163804	praedugi	?praedugi =praedu  (SgG^  >praedu !16_S	et	f	\N
163805	praedugi	?praedugi =praedu  (IndPrPs_^  >praeduma !27_V	et	f	\N
163806	praedugi	?praedugi =praedu  (ImpPrSg2^  >praeduma !27_V	et	f	\N
163815	jutapere	?jutapere =jutapere  (PlP  >jutaper !19_S	et	f	\N
163837	vajunud	vajunud =vaju  (PtsPtPs  >vajuma !27_V	et	f	\N
163838	vajunud	vajunud =vajunu  (PlN  >vajunu !01_S	et	f	\N
163839	vajunud	"vajunu %vaju  )NU_vS  <vajuma ;27_V	et	f	\N
163840	vajunud	vajunud =vajunud  (ID  >vajunud !41_A	et	f	\N
163841	vajunud	"vajunud %vaju  )NUD_vA  <vajuma ;27_V	et	f	\N
163842	tussu	?tussu =tussu  (SgN  >tussu !16_S	et	f	\N
163843	tussu	?tussu =tussu  (SgG  >tussu !16_S	et	f	\N
163844	tussu	?tussu =tussu  (IndPrPs_  >tussuma !27_V	et	f	\N
163845	tussu	?tussu =tussu  (ImpPrSg2  >tussuma !27_V	et	f	\N
163867	äärest	äärest =ääre  (SgEl  >äär !13_S	et	f	\N
163868	äärest	äärest =ääres  (SgP  >äärene !10_A	et	f	\N
163869	äärest	"äärene %ääre  )NE_aA  <äär ;13_S	et	f	\N
163870	äärest	äärest =äärest  (ID  >äärest !41_K	et	f	\N
163875	ohvriande	ohvriande =ande  (SgG  >ohvri+anne !06_S	et	f	\N
163876	ohvriande	ohvriande =ande  (PlP  >ohvri+and !22_S	et	f	\N
163893	karja-	karja- =karja  (SgG  >kari !24_S	et	f	\N
163894	karja-	karja- =karja  (SgP  >kari !24_S	et	f	\N
163895	karja-	karja- =karja  (SgAdt  >kari !24_S	et	f	\N
163907	nokkima	nokkima =nokki  (Sup  >nokkima !28_V	et	f	\N
163908	nokkima	nokkima =ima  (SgN  >nokk+ima !17_S	et	f	\N
163909	nokkima	nokkima =ima  (SgG  >nokk+ima !17_S	et	f	\N
163910	nokkima	nokkima =ima  (SgP  >nokk+ima !17_S	et	f	\N
163918	ligemal	ligemal =ligema  (SgAd  >ligem !02_A	et	f	\N
163919	ligemal	"ligem %lige  )M_cA  <ligida ;02_A	et	f	\N
163920	ligemal	ligemal =ligemal  (ID  >ligemal !41_D	et	f	\N
163925	vahtu	vahtu =vahtu  (SgP  >vaht !22_S	et	f	\N
163926	vahtu	vahtu =vahtu  (SgAdt  >vaht !22_S	et	f	\N
163943	varandusest	varandusest =varanduse  (SgEl  >varandus !11_S	et	f	\N
163944	varandusest	varandusest =varanduses  (SgP  >varandusene !12_A	et	f	\N
163945	varandusest	"varandusene %varanduse  )NE_aA  <varandus ;11_S	et	f	\N
163952	rehetuba	rehetuba =tuba  (SgN  >rehe+tuba !18_S	et	f	\N
163953	rehetuba	rehetuba =tuba  (SgP  >rehe+tuba !18_S	et	f	\N
163954	kaevata	kaevata =kaeva  (Inf  >kaebama !29_V	et	f	\N
163955	kaevata	kaevata =kaeva  (Inf  >kaevama !29_V	et	f	\N
163956	kaevata	kaevata =kaeva  (IndPrIps_  >kaebama !29_V	et	f	\N
163957	kaevata	kaevata =kaeva  (IndPrIps_  >kaevama !29_V	et	f	\N
163971	1933a	### 1933a	et	f	\N
163980	talukohad	talukohad =koha  (PlN  >talu+koha !17_S	et	f	\N
163981	talukohad	talukohad =koha  (PlN  >talu+koht !22_S	et	f	\N
163992	1916a	### 1916a	et	f	\N
163995	kääpamägi	### kääpamägi	et	f	\N
164003	neljapäeva	neljapäeva =päeva  (SgG  >nelja+päev !22_S	et	f	\N
164004	neljapäeva	neljapäeva =päeva  (SgP  >nelja+päev !22_S	et	f	\N
164005	neljapäeva	neljapäeva =päeva  (SgAdt  >nelja+päev !22_S	et	f	\N
164006	härgemäe	?härgemäe =härgemäe  (SgN  >härgemäe !26_S	et	f	\N
164007	härgemäe	?härgemäe =härgemäe  (SgG  >härgemäe !26_S	et	f	\N
164016	28dets	?dets =dets  (SgN  >dets !22_S	et	f	\N
164046	nähtuste	nähtuste =nähtus  (PlG  >nähtus !11~09_S	et	f	\N
164047	nähtuste	"nähtus %näh  )TUS1_aS  <nägema ;28_V	et	f	\N
164048	vedand	?vedand =vedand  (SgN  >vedand !02_S	et	f	\N
164056	ligemalt	ligemalt =ligema  (SgAbl  >ligem !02_A	et	f	\N
164057	ligemalt	"ligem %lige  )M_cA  <ligida ;02_A	et	f	\N
164058	ligemalt	ligemalt =ligemalt  (ID  >ligemalt !41_D	et	f	\N
164059	ligemalt	"ligemalt %ligema  )LT_mD  <ligem ;02_A	et	f	\N
164084	palund	?palund =palund  (SgN  >palund !02_S	et	f	\N
164085	ehitaks	ehitaks =ehi  (KndPrIps  >ehtima !28_V	et	f	\N
164086	ehitaks	ehitaks =ehita  (KndPrPs  >ehitama !27_V	et	f	\N
164091	akatud	akatud =akatu  (PlN  >akatu !01_AS	et	f	\N
164092	akatud	"akatu %aka  )TU2_kA  <aka ;16_S	et	f	\N
164114	leind	?leind =leind  (SgN  >leind !02_S	et	f	\N
164115	kirikuärra	?kirikuärra =kirikuärra  (SgN  >kirikuärra !16_S	et	f	\N
164116	kirikuärra	?kirikuärra =kirikuärra  (SgG  >kirikuärra !16_S	et	f	\N
164117	kirikuärra	?kirikuärra =ärra  (SgN  >kiriku+ärra !16_S	et	f	\N
164118	kirikuärra	?kirikuärra =ärra  (SgG  >kiriku+ärra !16_S	et	f	\N
164119	kirikuärra	?kirikuärra =kuärra  (SgN  >kiri+kuärra !01_S	et	f	\N
164120	kirikuärra	?kirikuärra =kuärra  (SgG  >kiri+kuärra !01_S	et	f	\N
164122	kaheksas	kaheksas =kaheksa  (SgIn  >kaheksa !01_N	et	f	\N
164123	kaheksas	kaheksas =kaheksas  (SgN  >kaheksas !02_O	et	f	\N
164124	länevad	?länevad =läne  (IndPrPl3  >länema !27_V	et	f	\N
164125	länevad	?länevad =läneva  (PlN  >läneva !01_S	et	f	\N
164126	länevad	?länevad =läneva  (PlN  >länev !02_A	et	f	\N
164156	suuremaid	suuremaid =suurema  (PlP  >suurem !02_A	et	f	\N
164157	suuremaid	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
164158	suuremaid	suuremaid =ma  (PlP  >suure+maa !26_S	et	f	\N
164159	suuremaid	suuremaid =mai  (PlN  >suure+mai !26_S	et	f	\N
163866	kuristikuga	kuristikuga =tiku  (SgKom  >kuris+tikk !22_S	et	f	\N
163896	rahvapäraselt	rahvapäraselt =pärase  (SgAbl  >rahva+pärane !10_A	et	f	\N
163897	rahvapäraselt	"rahva+pärane %pära  )NE_aA  <rahva+pära ;17_S	et	f	\N
163898	rahvapäraselt	"rahva+päraselt %pära  )SELT_mD  <rahva+pära ;17_S	et	f	\N
163899	rahvapäraselt	"rahva+päraselt %pärase  )LT_mD  <rahva+pärane ;10_A	et	f	\N
163903	aadu	?aadu =aadu  (SgN  >aadu !16_S	et	f	\N
163904	aadu	?aadu =aadu  (SgG  >aadu !16_S	et	f	\N
163905	aadu	?aadu =aadu  (IndPrPs_  >aaduma !27_V	et	f	\N
163906	aadu	?aadu =aadu  (ImpPrSg2  >aaduma !27_V	et	f	\N
163927	karjund	?karjund =karjund  (SgN  >karjund !02_S	et	f	\N
163933	arama	?arama =ara  (Sup  >arama !27_V	et	f	\N
163934	arama	?arama =arama  (SgG  >aram !02_A	et	f	\N
163966	vanaküla	vanaküla =küla  (SgN  >vana+küla !17_S	et	f	\N
163967	vanaküla	vanaküla =küla  (SgG  >vana+küla !17_S	et	f	\N
163968	vanaküla	vanaküla =küla  (SgP  >vana+küla !17_S	et	f	\N
163973	arugi	arugi =aru  (SgN^  >aru !17_S	et	f	\N
163974	arugi	arugi =aru  (SgG^  >aru !17_S	et	f	\N
163975	arugi	arugi =aru  (SgP^  >aru !17_S	et	f	\N
163988	pauliine	?pauliine =pauliine  (SgN  >pauliine !12~10_A	et	f	\N
163989	pauliine	?pauliine =pauliine  (PlP  >pauliin !22_S	et	f	\N
163990	pauliine	?pauliine =pauliine  (IndPrPs_  >pauliinema !27_V	et	f	\N
163991	pauliine	?pauliine =pauliine  (ImpPrSg2  >pauliinema !27_V	et	f	\N
164018	lupja	lupja =lupja  (SgP  >lubi !24_S	et	f	\N
164019	lupja	lupja =lupja  (SgAdt  >lubi !24_S	et	f	\N
164020	lupja	lupja =lupja  (IndPrPs_  >lupjama !29_V	et	f	\N
164021	lupja	lupja =lupja  (ImpPrSg2  >lupjama !29_V	et	f	\N
164026	miiu	?miiu =miiu  (SgN  >miiu !16_S	et	f	\N
164027	miiu	?miiu =miiu  (SgG  >miiu !16_S	et	f	\N
164028	miiu	?miiu =miiu  (IndPrPs_  >miiuma !27_V	et	f	\N
164029	miiu	?miiu =miiu  (ImpPrSg2  >miiuma !27_V	et	f	\N
164042	kodila	?kodila =kodila  (SgN  >kodila !01_S	et	f	\N
164043	kodila	?kodila =kodila  (SgG  >kodila !01_S	et	f	\N
164066	nissis	?nissis =nissi  (SgIn  >nissi !16_S	et	f	\N
164067	nissis	?nissis =nissi  (SgIn  >niss !22_S	et	f	\N
164068	nissis	?nissis =nissi  (IndIpfSg3  >nissima !28_V	et	f	\N
164069	nissis	?nissis =nissis  (ID  >nissis !41_DA	et	f	\N
164087	pääsend	?pääsend =pääsend  (SgN  >pääsend !02_S	et	f	\N
164088	pääsend	?pääsend =end  (SgN  >pääs+end !22_S	et	f	\N
164089	pääsend	?pääsend =send  (SgN  >pää+send !22_S	et	f	\N
164090	ehitand	?ehitand =ehitand  (SgN  >ehitand !22_S	et	f	\N
164104	balsameerutud	?balsameerutud =balsameeru  (PtsPtIps  >balsameeruma !27_V	et	f	\N
164105	balsameerutud	?balsameerutud =balsameerutu  (PlN  >balsameerutu !01_A	et	f	\N
164106	balsameerutud	?balsameerutud =balsameerutu  (IndPrSg2  >balsameerutuma !27_V	et	f	\N
164107	balsameerutud	?balsameerutud =balsameerutud  (ID  >balsameerutud !41_A	et	f	\N
164108	laadatud	laadatud =laadatu  (PlN  >laadatu !01_S	et	f	\N
164109	laadatud	"laadatu %laada  )TU2_kA  <laat ;22_S	et	f	\N
164113	russvere	### russvere	et	f	\N
164131	palmse	?palmse =palmse  (SgN  >palmse !06_S	et	f	\N
164132	palmse	?palmse =palmse  (SgG  >palmne !02_A	et	f	\N
164133	palmse	?palmse =palmse  (SgG  >palmse !06_S	et	f	\N
164134	palmse	?palmse =palmse  (PlP  >palms !22_S	et	f	\N
164136	palmse	?palmse =palmse  (IndPrPs_  >palmsema !27_V	et	f	\N
164138	palmse	?palmse =palmse  (ImpPrSg2  >palmsema !27_V	et	f	\N
164155	alt-riiesenberg	?alt-riiesenberg =riiesenberg  (SgN  >alt-riiesenberg !22_S	et	f	\N
164187	kuulsuse	kuulsuse =kuulsuse  (SgG  >kuulsus !11~09_S	et	f	\N
164189	kuulsuse	"kuulsus %kuulsa  )US_aS  <kuulus ;02_A	et	f	\N
164196	peafassaadi	peafassaadi =fassaadi  (SgG  >pea+fassaad !22_S	et	f	\N
164197	peafassaadi	peafassaadi =fassaadi  (SgP  >pea+fassaad !22_S	et	f	\N
164198	peafassaadi	peafassaadi =fassaadi  (SgAdt  >pea+fassaad !22_S	et	f	\N
164203	vestibüüli	vestibüüli =vestibüüli  (SgG  >vestibüül !22_S	et	f	\N
164204	vestibüüli	vestibüüli =vestibüüli  (SgP  >vestibüül !22_S	et	f	\N
164205	vestibüüli	vestibüüli =vestibüüli  (SgAdt  >vestibüül !22_S	et	f	\N
164223	dekoratiivdetailidmõisahoonetes	?dekoratiivdetailidmõisahoonetes =dekoratiivdetailidmõisahoonete  (PlIn  >dekoratiivdetailidmõisahoonett !22_S	et	f	\N
164224	dekoratiivdetailidmõisahoonetes	?dekoratiivdetailidmõisahoonetes =dmõisahoonete  (PlIn  >dekoratiiv+detaili+dmõisahoonett !22_S	et	f	\N
164225	dekoratiivdetailidmõisahoonetes	?dekoratiivdetailidmõisahoonetes =idmõisahoonete  (PlIn  >dekoratiiv+detail+idmõisahoonett !22_S	et	f	\N
164226	dekoratiivdetailidmõisahoonetes	?dekoratiivdetailidmõisahoonetes =detailidmõisahoonete  (PlIn  >dekoratiiv+detailidmõisahoonett !22_S	et	f	\N
164263	toatüdrukuks	toatüdrukuks =uks  (SgN  >toa+tüdruk+uks !14_S	et	f	\N
164264	toatüdrukuks	toatüdrukuks =tüdruku  (SgTr  >toa+tüdruk !02_S	et	f	\N
164298	1921a	### 1921a	et	f	\N
164308	löönd	?löönd =löönd  (SgN  >löönd !22_S	et	f	\N
164312	mõtelnd	?mõtelnd =mõtelnd  (SgN  >mõtelnd !02_S	et	f	\N
164317	peatuse	peatuse =peatuse  (SgG  >peatus !11~09_S	et	f	\N
164318	peatuse	"peatus %peata  )US_vS  <peatama ;27_V	et	f	\N
164319	peatuse	"peatus %pea  )TUS2_aS  <pea ;26_S	et	f	\N
164345	küsimule	?küsimule =küsimu  (SgAll  >küsimu !01_S	et	f	\N
164015	tied	?tied =tied  (SgN  >tied !22_S	et	f	\N
164017	904a	### 904a	et	f	\N
164035	lao	lao =lao  (SgG  >ladu !18_S	et	f	\N
164036	lao	lao =lao  (SgG  >lagu !18_S	et	f	\N
164037	lao	lao =lao  (IndPrPs_  >laduma !28_V	et	f	\N
164038	lao	lao =lao  (ImpPrSg2  >laduma !28_V	et	f	\N
164064	senna	senna =senna  (SgN  >senna !16_S	et	f	\N
164065	senna	senna =senna  (SgG  >senna !16_S	et	f	\N
164070	puukabel	puukabel =kabe  (SgAd  >puu+kabe !16_S	et	f	\N
164071	puukabel	puukabel =kabel  (SgN  >puu+kabel !02_S	et	f	\N
164072	puukabel	puukabel =kabel  (SgN  >puu+kabel !24_S	et	f	\N
164077	ärra	?ärra =ärra  (SgN  >ärra !16_S	et	f	\N
164078	ärra	?ärra =ärra  (SgG  >ärra !16_S	et	f	\N
164079	ärra	?ärra =ärra  (IndPrPs_  >ärrama !29_V	et	f	\N
164080	ärra	?ärra =ärra  (ImpPrSg2  >ärrama !29_V	et	f	\N
164096	ehitamisega	ehitamisega =ehitamise  (SgKom  >ehitamine !12_S	et	f	\N
164097	ehitamisega	"ehitamine %ehita  )MINE_vS  <ehitama ;27_V	et	f	\N
164098	palkimets	?palkimets =palkimets  (SgN  >palkimets !22_S	et	f	\N
164099	palkimets	?palkimets =imets  (SgN  >palk+imets !02_S	et	f	\N
164127	selma	?selma =selma  (SgN  >selma !16_S	et	f	\N
164128	selma	?selma =selma  (SgG  >selma !16_S	et	f	\N
164129	selma	?selma =selma  (IndPrPs_  >selmama !29_V	et	f	\N
164130	selma	?selma =selma  (ImpPrSg2  >selmama !29_V	et	f	\N
164178	klassitsitliku	?klassitsitliku =klassitsitliku  (SgG  >klassitsitlik !25_A	et	f	\N
164179	klassitsitliku	?klassitsitliku =klassitsitliku  (IndPrPs_  >klassitsitlikuma !27_V	et	f	\N
164180	klassitsitliku	?klassitsitliku =klassitsitliku  (ImpPrSg2  >klassitsitlikuma !27_V	et	f	\N
164181	klassitsitliku	?klassitsitliku =tsitliku  (SgN  >klassi+tsitliku !01_S	et	f	\N
164182	klassitsitliku	?klassitsitliku =tsitliku  (SgG  >klassi+tsitliku !01_S	et	f	\N
164183	klassitsitliku	?klassitsitliku =tsitliku  (SgG  >klassi+tsitlik !25_A	et	f	\N
164191	sammasportikus	?sammasportikus =sammasportiku  (SgIn  >sammasportik !02_S	et	f	\N
164192	sammasportikus	?sammasportikus =sammasportiku  (IndIpfSg3  >sammasportikuma !27_V	et	f	\N
164193	sammasportikus	?sammasportikus =sammasportikus  (SgN  >sammasportikus !11?09_S	et	f	\N
164208	perekonnaportreed	perekonnaportreed =ree  (PlN  >pere+konna+port+regi !21_S	et	f	\N
164209	perekonnaportreed	perekonnaportreed =portree  (PlN  >pere+konna+portree !26_S	et	f	\N
164210	perekonnaportreed	perekonnaportreed =portree  (SgP  >pere+konna+portree !26_S	et	f	\N
164216	lae-	lae- =lae  (SgG  >lagi !21_S	et	f	\N
164217	lae-	lae- =lae  (SgG  >laad !22_S	et	f	\N
164218	lae-	lae- =lae  (IndPrPs_  >laadima !28_V	et	f	\N
164219	lae-	lae- =lae  (ImpPrSg2  >laadima !28_V	et	f	\N
164247	imelikku	imelikku =imelikku  (SgP  >imelik !25_A	et	f	\N
164248	imelikku	imelikku =imelikku  (SgAdt  >imelik !25_A	et	f	\N
164250	neljateiskümne	?neljateiskümne =neljateiskümne  (SgN  >neljateiskümne !02_A	et	f	\N
164252	neljateiskümne	?neljateiskümne =neljateiskümne  (PlP  >neljateiskümn !22_S	et	f	\N
164254	neljateiskümne	?neljateiskümne =kümne  (SgN  >nelja+teis+kümne !02_A	et	f	\N
164256	neljateiskümne	?neljateiskümne =kümne  (PlP  >nelja+teis+kümn !22_S	et	f	\N
164258	neljateiskümne	?neljateiskümne =teiskümne  (SgN  >nelja+teiskümne !02_A	et	f	\N
164260	neljateiskümne	?neljateiskümne =teiskümne  (PlP  >nelja+teiskümn !22_S	et	f	\N
164272	äälega	?äälega =ääle  (SgKom  >ääle !06_S	et	f	\N
164279	kata	kata =kata  (SgN  >kata !16_S	et	f	\N
164280	kata	kata =kata  (SgG  >kata !16_S	et	f	\N
164281	kata	kata =kata  (IndPrPs_  >katma !35_V	et	f	\N
164282	kata	kata =kata  (ImpPrSg2  >katma !35_V	et	f	\N
164296	kellegile	### kellegile	et	f	\N
164311	sadand	?sadand =sadand  (SgN  >sadand !02_S	et	f	\N
164313	ligemale	ligemale =ligema  (SgAll  >ligem !02_A	et	f	\N
164314	ligemale	"ligem %lige  )M_cA  <ligida ;02_A	et	f	\N
164315	ligemale	ligemale =ligemale  (ID  >ligemale !41_D	et	f	\N
164340	endor	?endor =endor  (SgN  >endor !02_S	et	f	\N
164342	ipane	?ipane =ipane  (SgN  >ipane !10_A	et	f	\N
164343	ipane	?ipane =ipane  (IndPrPs_  >ipanema !27_V	et	f	\N
164344	ipane	?ipane =ipane  (ImpPrSg2  >ipanema !27_V	et	f	\N
164353	tüdrukusse	tüdrukusse =tüdruku  (SgIll  >tüdruk !02_S	et	f	\N
164354	tüdrukusse	tüdrukusse =usse  (PlP  >tüdruk+uss !22_S	et	f	\N
164380	millepa	?millepa =millepa  (SgN  >millepa !01_S	et	f	\N
164381	millepa	?millepa =millepa  (SgG  >millepa !01_S	et	f	\N
164394	üheksakümnekaheksas	?üheksakümnekaheksas =üheksakümnekaheksa  (SgIn  >üheksakümnekaheksa !16_S	et	f	\N
164395	üheksakümnekaheksas	?üheksakümnekaheksas =kümnekaheksa  (SgIn  >üheksa+kümnekaheksa !16_S	et	f	\N
164396	üheksakümnekaheksas	?üheksakümnekaheksas =akümnekaheksa  (SgIn  >üheks+akümnekaheksa !16_S	et	f	\N
164397	üheksakümnekaheksas	?üheksakümnekaheksas =ksakümnekaheksa  (SgIn  >ühe+ksakümnekaheksa !16_S	et	f	\N
164405	neljasaja	?neljasaja =neljasaja  (SgN  >neljasaja !01_S	et	f	\N
164406	neljasaja	?neljasaja =neljasaja  (SgG  >neljasaja !01_S	et	f	\N
164407	neljasaja	?neljasaja =neljasaja  (SgG  >neljasajas !02_A	et	f	\N
164408	neljasaja	?neljasaja =saja  (SgN  >nelja+saja !17_S	et	f	\N
164409	neljasaja	?neljasaja =saja  (SgG  >nelja+saja !17_S	et	f	\N
164410	neljasaja	?neljasaja =saja  (SgP  >nelja+saja !17_S	et	f	\N
164147	tohvri	?tohvri =tohvri  (ImpPrSg2  >tohvrima !28_V	et	f	\N
164148	tohver	?tohver =tohver  (SgN  >tohver !02_S	et	f	\N
164167	uue-riisipere	uue-riisipere =pere  (SgN  >uue-riisi+pere !16_S	et	f	\N
164168	uue-riisipere	uue-riisipere =pere  (SgG  >uue-riisi+pere !16_S	et	f	\N
164169	kohapärimusre	?kohapärimusre =kohapärimusre  (PlP  >kohapärimusr !22_S	et	f	\N
164170	kohapärimusre	?kohapärimusre =musre  (SgN  >koha+päri+musre !06_S	et	f	\N
164171	kohapärimusre	?kohapärimusre =musre  (SgG  >koha+päri+musre !06_S	et	f	\N
164173	kohapärimusre	?kohapärimusre =musre  (PlP  >koha+päri+musr !22_S	et	f	\N
164175	kohapärimusre	?kohapärimusre =pärimusre  (PlP  >koha+pärimusr !22_S	et	f	\N
164184	ehitusstiili	ehitusstiili =stiili  (SgG  >ehitus+stiil !22_S	et	f	\N
164185	ehitusstiili	ehitusstiili =stiili  (SgP  >ehitus+stiil !22_S	et	f	\N
164186	ehitusstiili	ehitusstiili =stiili  (SgAdt  >ehitus+stiil !22_S	et	f	\N
164194	sambaga	sambaga =samba  (SgKom  >sammas !07_S	et	f	\N
164195	sambaga	sambaga =samba  (SgKom  >samba !16_S	et	f	\N
164200	keskvestibüülist	keskvestibüülist =vestibüüli  (SgEl  >kesk+vestibüül !22_S	et	f	\N
164201	keskvestibüülist	keskvestibüülist =vestibüülis  (SgP  >kesk+vestibüüline !12?10_A	et	f	\N
164202	keskvestibüülist	"kesk+vestibüüline %vestibüüli  )NE_aA  <kesk+vestibüül ;22_S	et	f	\N
164206	asetsesid	asetsesid =asetse  (IndIpfSg2  >asetsema !27_V	et	f	\N
164207	asetsesid	asetsesid =asetse  (IndIpfPl3  >asetsema !27_V	et	f	\N
164229	sammassaali	?sammassaali =sammassaali  (SgN  >sammassaali !16_S	et	f	\N
164230	sammassaali	?sammassaali =sammassaali  (SgG  >sammassaali !16_S	et	f	\N
164231	sammassaali	?sammassaali =sammassaali  (SgG  >sammassaal !22_S	et	f	\N
164232	sammassaali	?sammassaali =sammassaali  (SgP  >sammassaal !22_S	et	f	\N
164234	sammassaali	?sammassaali =sammassaali  (SgAdt  >sammassaal !22_S	et	f	\N
164236	sammassaali	?sammassaali =sammassaali  (IndPrPs_  >sammassaalima !28_V	et	f	\N
164237	sammassaali	?sammassaali =sammassaali  (ImpPrSg2  >sammassaalima !28_V	et	f	\N
164274	küsinud	küsinud =küsi  (PtsPtPs  >küsima !27_V	et	f	\N
164275	küsinud	küsinud =küsinu  (PlN  >küsinu !01_S	et	f	\N
164276	küsinud	"küsinu %küsi  )NU_vS  <küsima ;27_V	et	f	\N
164277	küsinud	küsinud =küsinud  (ID  >küsinud !41_A	et	f	\N
164278	küsinud	"küsinud %küsi  )NUD_vA  <küsima ;27_V	et	f	\N
164283	preoli	?preoli =preoli  (SgN  >preoli !16_S	et	f	\N
164284	preoli	?preoli =preoli  (SgG  >preoli !16_S	et	f	\N
164285	preoli	?preoli =preoli  (SgG  >preol !22_S	et	f	\N
164286	preoli	?preoli =preoli  (SgP  >preol !22_S	et	f	\N
164287	preoli	?preoli =preoli  (SgAdt  >preol !22_S	et	f	\N
164288	preoli	?preoli =preoli  (IndPrPs_  >preolima !28_V	et	f	\N
164289	preoli	?preoli =preoli  (ImpPrSg2  >preolima !28_V	et	f	\N
164290	preoli	?preoli =oli  (SgN  >pre+oli !17_S	et	f	\N
164291	preoli	?preoli =oli  (SgG  >pre+oli !17_S	et	f	\N
164292	preoli	?preoli =oli  (SgP  >pre+oli !17_S	et	f	\N
164293	tõsisekskas	?tõsisekskas =tõsisekska  (SgIn  >tõsisekska !16_S	et	f	\N
164294	tõsisekskas	?tõsisekskas =sekska  (SgIn  >tõsi+sekska !01_S	et	f	\N
164295	tõsisekskas	?tõsisekskas =sekskas  (SgN  >tõsi+sekskas !07_S	et	f	\N
164299	veeltere	### veeltere	et	f	\N
164309	traktorist	traktorist =traktori  (SgEl  >traktor !02_S	et	f	\N
164310	traktorist	traktorist =traktorist  (SgN  >traktorist !22_S	et	f	\N
164325	riisenberk	?riisenberk =riisenberk  (SgN  >riisenberk !22_S	et	f	\N
164326	riisenberk	?riisenberk =enberk  (SgN  >riis+enberk !22_S	et	f	\N
164330	helmi	?helmi =helmi  (SgN  >helmi !16_S	et	f	\N
164332	helmi	?helmi =helmi  (SgG  >helmi !16_S	et	f	\N
164334	helmi	?helmi =helmi  (SgG  >helm !22_S	et	f	\N
164336	helmi	?helmi =helmi  (SgP  >helm !22_S	et	f	\N
164337	helmi	?helmi =helmi  (SgAdt  >helm !22_S	et	f	\N
164338	helmi	?helmi =helmi  (IndPrPs_  >helmima !28_V	et	f	\N
164339	helmi	?helmi =helmi  (ImpPrSg2  >helmima !28_V	et	f	\N
164378	säin	?säin =säin  (SgN  >säin !22_S	et	f	\N
164411	viiekümnekolmas	?viiekümnekolmas =viiekümnekolma  (SgIn  >viiekümnekolma !16_S	et	f	\N
164412	viiekümnekolmas	?viiekümnekolmas =kolma  (SgIn  >viie+kümne+kolma !16_S	et	f	\N
164413	viiekümnekolmas	?viiekümnekolmas =kümnekolma  (SgIn  >viie+kümnekolma !16_S	et	f	\N
164434	keskvõrre	keskvõrre =võrre  (SgN  >kesk+võrre !06_S	et	f	\N
164435	keskvõrre	keskvõrre =võrre  (PlP  >kesk+võrr !22_S	et	f	\N
164436	da-infinitiv	?da-infinitiv =infinitiv  (SgN  >da-infinitiv !02_A	et	f	\N
164448	grammaatika	?grammaatika =grammaatika  (SgN  >grammaatika !01_S	et	f	\N
164449	grammaatika	?grammaatika =grammaatika  (SgG  >grammaatika !01_S	et	f	\N
164450	grammaatika	?grammaatika =grammaatika  (SgG  >grammaatikas !02_A	et	f	\N
164473	juhtumust	juhtumust =juhtumus  (SgP  >juhtumus !11_S	et	f	\N
164474	juhtumust	"juhtumus %juhtu  )MUS_vS  <juhtuma ;27_V	et	f	\N
164479	purskkaevaga	?purskkaevaga =purskkaeva  (SgKom  >purskkaeva !01_S	et	f	\N
164480	purskkaevaga	?purskkaevaga =kaeva  (SgKom  >pursk+kaeva !16_S	et	f	\N
164496	õppijale	õppijale =õppija  (SgAll  >õppija !01_S	et	f	\N
164497	õppijale	"õppija %õppi  )JA_vS  <õppima ;28_V	et	f	\N
164512	häälikutasandil	?häälikutasandil =häälikutasandi  (SgAd  >häälikutasant !22_S	et	f	\N
164154	kivitammi	kivitammi =tammi  (PlP  >kivi+tamm !22_S	et	f	\N
164161	huvitavamaid	huvitavamaid =huvitavama  (PlP  >huvitavam !02_A	et	f	\N
164162	huvitavamaid	"huvitavam %huvita  )VAM_cA  <huvitama ;27_V	et	f	\N
164163	huvitavamaid	"huvitavam %huvitava  )M_cA  <huvitav ;02_A	et	f	\N
164164	huvitavamaid	huvitavamaid =ma  (PlP  >huvi+tava+maa !26_S	et	f	\N
164165	huvitavamaid	huvitavamaid =mai  (PlN  >huvi+tava+mai !26_S	et	f	\N
164166	huvitavamaid	huvitavamaid =mai  (SgP  >huvi+tava+mai !26_S	et	f	\N
164172	jutuaineks	jutuaineks =aine  (SgTr  >jutu+aine !06_S	et	f	\N
164174	jutuaineks	jutuaineks =aine  (PlTr  >jutu+ain !22_S	et	f	\N
164233	kunstiväärtustega	kunstiväärtustega =us  (PlKom  >kunsti+väärt+uks !14_S	et	f	\N
164235	kunstiväärtustega	kunstiväärtustega =väärtus  (PlKom  >kunsti+väärtus !11~09_S	et	f	\N
164242	kasitleda	?kasitleda =kasitle  (Inf  >kasitlema !27_V	et	f	\N
164245	isikulist	isikulist =isikulis  (SgP  >isikuline !12_A	et	f	\N
164246	isikulist	"isikuline %isiku  )LINE_aA  <isik ;02_S	et	f	\N
164265	lõunalauda	lõunalauda =lauda  (SgG  >lõuna+laut !22_S	et	f	\N
164266	lõunalauda	lõunalauda =lauda  (SgP  >lõuna+laud !22_S	et	f	\N
164267	lõunalauda	lõunalauda =lauda  (SgAdt  >lõuna+laud !22_S	et	f	\N
164268	imestunud	imestunud =imestu  (PtsPtPs  >imestuma !27_V	et	f	\N
164269	imestunud	imestunud =imestunu  (PlN  >imestunu !01_S	et	f	\N
164270	imestunud	"imestunu %imestu  )NU_vS  <imestuma ;27_V	et	f	\N
164271	imestunud	imestunud =imestunud  (ID  >imestunud !41_A	et	f	\N
164273	imestunud	"imestunud %imestu  )NUD_vA  <imestuma ;27_V	et	f	\N
164302	jälgade	?jälgade =jälga  (PlG  >jälga !16_S	et	f	\N
164303	64a	### 64a	et	f	\N
164304	kivitamme	kivitamme =tamme  (SgG  >kivi+tamm !22_S	et	f	\N
164305	kivitamme	kivitamme =tamme  (SgP  >kivi+tamm !22_S	et	f	\N
164306	kivitamme	kivitamme =tamme  (SgAdt  >kivi+tamm !22_S	et	f	\N
164307	kivitamme	kivitamme =tamme  (PlP  >kivi+tamm !22_S	et	f	\N
164316	kadund	?kadund =kadund  (SgN  >kadund !02_S	et	f	\N
164327	tähendavat	tähendavat =tähenda  (KvtPrPs  >tähendama !27_V	et	f	\N
164328	tähendavat	tähendavat =tähendava  (SgP  >tähendav !02_A	et	f	\N
164329	tähendavat	"tähendav %tähenda  )V_vA  <tähendama ;27_V	et	f	\N
164349	come	?come =come  (SgN  >come !16_S	et	f	\N
164350	come	?come =come  (SgG  >come !16_S	et	f	\N
164351	come	?come =come  (IndPrPs_  >comema !27_V	et	f	\N
164352	come	?come =come  (ImpPrSg2  >comema !27_V	et	f	\N
164358	täis-	täis- =täi  (SgIn  >täi !26_S	et	f	\N
164359	täis-	täis- =täi  (IndIpfSg3  >täima !27_V	et	f	\N
164360	täis-	täis- =täis  (ID  >täis !41_DA	et	f	\N
164361	täis-	täis- =täis  (SgN  >täis !14_AS	et	f	\N
164382	ees-	ees- =ee  (SgIn  >esi !15_S	et	f	\N
164383	ees-	ees- =ees  (ID  >ees !41_DK	et	f	\N
164441	1emakeele	emakeele =kee  (SgAll  >ema+kesi !15_S	et	f	\N
164442	1emakeele	emakeele =kee  (SgAll  >ema+kee !26_S	et	f	\N
164443	1emakeele	emakeele =keele  (SgG  >ema+keel !13_S	et	f	\N
164445	amerika	?amerika =amerika  (SgN  >amerika !01_S	et	f	\N
164446	amerika	?amerika =amerika  (SgG  >amerika !01_S	et	f	\N
164447	amerika	?amerika =amerika  (SgG  >amerikas !02_A	et	f	\N
164469	õppikuid	?õppikuid =õppiku  (PlP  >õppiku !01_S	et	f	\N
164470	õppikuid	?õppikuid =õppiku  (PlP  >õppik !02_S	et	f	\N
164471	õppikuid	?õppikuid =õppikui  (PlN  >õppikui !26_S	et	f	\N
164472	õppikuid	?õppikuid =õppikui  (SgP  >õppikui !26_S	et	f	\N
164476	luuan	?luuan =luuan  (SgN  >luuan !02_S	et	f	\N
164482	südamlised	?südamlised =südamlise  (PlN  >südamline !12_A	et	f	\N
164514	ortograafiavead	?ortograafiavead =ortograafiavea  (PlN  >ortograafiavea !26_S	et	f	\N
164515	ortograafiavead	?ortograafiavead =ortograafiavea  (SgP  >ortograafiavea !26_S	et	f	\N
164516	ortograafiavead	?ortograafiavead =ortograafiavead  (SgN  >ortograafiavead !22_S	et	f	\N
164579	teere	?teere =teere  (SgN  >teere !06_S	et	f	\N
164580	teere	?teere =teere  (SgG  >teere !06_S	et	f	\N
164581	teere	?teere =teere  (PlP  >teer !22_S	et	f	\N
164582	teere	?teere =teere  (IndPrPs_  >teerema !27_V	et	f	\N
164583	teere	?teere =teere  (ImpPrSg2  >teerema !27_V	et	f	\N
164591	ebamääraseks	ebamääraseks =määrase  (SgTr  >eba+määrane !10_A	et	f	\N
164592	ebamääraseks	"eba+määrane %määra  )NE_aA  <eba+määr ;22_S	et	f	\N
164596	tähtede	tähtede =tähte  (PlG  >täht !22_S	et	f	\N
164597	tähtede	tähtede =ede  (SgN  >täht+ede !16_S	et	f	\N
164598	tähtede	tähtede =ede  (SgG  >täht+ede !16_S	et	f	\N
164658	laiendanud	laiendanud =laienda  (PtsPtPs  >laiendama !27_V	et	f	\N
164659	laiendanud	laiendanud =laiendanu  (PlN  >laiendanu !01_S	et	f	\N
164660	laiendanud	"laiendanu %laienda  )NU_vS  <laiendama ;27_V	et	f	\N
164661	laiendanud	laiendanud =laiendanud  (ID  >laiendanud !41_A	et	f	\N
164662	laiendanud	"laiendanud %laienda  )NUD_vA  <laiendama ;27_V	et	f	\N
164668	tüvevalikuvigu	?tüvevalikuvigu =tüvevalikuvigu  (IndPrPs_  >tüvevalikuviguma !27_V	et	f	\N
164669	tüvevalikuvigu	?tüvevalikuvigu =tüvevalikuvigu  (ImpPrSg2  >tüvevalikuviguma !27_V	et	f	\N
164690	õpisib	### õpisib	et	f	\N
164694	segunemise	segunemise =segunemise  (SgG  >segunemine !12_S	et	f	\N
164160	suuremaid	suuremaid =mai  (SgP  >suure+mai !26_S	et	f	\N
164176	mõisahoonega	mõisahoonega =hoone  (SgKom  >mõisa+hoone !06_S	et	f	\N
164177	mõisahoonega	"mõisa+hoone %hoo  )NE_aA  <mõisa+hoog ;22_S	et	f	\N
164188	kõnelesid	kõnelesid =kõnele  (IndIpfSg2  >kõnelema !31~27_V	et	f	\N
164190	kõnelesid	kõnelesid =kõnele  (IndIpfPl3  >kõnelema !31~27_V	et	f	\N
164199	rotundikujulisest	?rotundikujulisest =rotundikujulise  (SgEl  >rotundikujuline !12_A	et	f	\N
164211	saali	saali =saali  (SgG  >saal !22_S	et	f	\N
164212	saali	saali =saali  (SgP  >saal !22_S	et	f	\N
164213	saali	saali =saali  (SgAdt  >saal !22_S	et	f	\N
164214	saali	saali =saali  (IndPrPs_  >saalima !28_V	et	f	\N
164215	saali	saali =saali  (ImpPrSg2  >saalima !28_V	et	f	\N
164220	leiduvad	leiduvad =leidu  (IndPrPl3  >leiduma !27_V	et	f	\N
164221	leiduvad	leiduvad =leiduva  (PlN  >leiduv !02_A	et	f	\N
164222	leiduvad	"leiduv %leidu  )V_vA  <leiduma ;27_V	et	f	\N
164227	põhikool	põhikool =koo  (SgAd  >põhi+kubu !18_S	et	f	\N
164228	põhikool	põhikool =kool  (SgN  >põhi+kool !22_S	et	f	\N
164238	taastamist	taastamist =taastamis  (SgP  >taastamine !12_S	et	f	\N
164239	taastamist	"taastamine %taasta  )MINE_vS  <taastama ;27_V	et	f	\N
164240	kohapärimusteks	kohapärimusteks =muste  (PlTr  >koha+päri+must !22_AS	et	f	\N
164241	kohapärimusteks	kohapärimusteks =pärimus  (PlTr  >koha+pärimus !11_S	et	f	\N
164243	memoraatidena	?memoraatidena =memoraati  (PlEs  >memoraati !16_S	et	f	\N
164244	memoraatidena	?memoraatidena =memoraati  (PlEs  >memoraat !22_S	et	f	\N
164249	aastaselt	aastaselt =aastase  (SgAbl  >aastane !12~10_A	et	f	\N
164251	aastaselt	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
164253	aastaselt	aastaselt =aastaselt  (ID  >aastaselt !41_D	et	f	\N
164255	aastaselt	"aastaselt %aasta  )SELT_mD  <aasta ;01_S	et	f	\N
164257	aastaselt	"aastaselt %aastase  )LT_mD  <aastane ;10_A	et	f	\N
164259	aastaselt	"aastaselt %aastase  )LT_mD  <aastane ;12_A	et	f	\N
164261	stakelbergid	?stakelbergid =stakelbergi  (PlN  >stakelberk !22_S	et	f	\N
164262	stakelbergid	?stakelbergid =stakelbergi  (IndPrSg2  >stakelberkima !28_V	et	f	\N
164297	kraut	?kraut =kraut  (SgN  >kraut !22_S	et	f	\N
164300	pesutüdrukuks	pesutüdrukuks =uks  (SgN  >pesu+tüdruk+uks !14_S	et	f	\N
164301	pesutüdrukuks	pesutüdrukuks =tüdruku  (SgTr  >pesu+tüdruk !02_S	et	f	\N
164320	jutustanud	jutustanud =jutusta  (PtsPtPs  >jutustama !27_V	et	f	\N
164321	jutustanud	jutustanud =jutustanu  (PlN  >jutustanu !01_S	et	f	\N
164322	jutustanud	"jutustanu %jutusta  )NU_vS  <jutustama ;27_V	et	f	\N
164323	jutustanud	jutustanud =jutustanud  (ID  >jutustanud !41_A	et	f	\N
164324	jutustanud	"jutustanud %jutusta  )NUD_vA  <jutustama ;27_V	et	f	\N
164331	veeroja	veeroja =oja  (SgN  >veer+oja !17_S	et	f	\N
164333	veeroja	veeroja =oja  (SgG  >veer+oja !17_S	et	f	\N
164335	veeroja	veeroja =oja  (SgP  >veer+oja !17_S	et	f	\N
164341	1914a	### 1914a	et	f	\N
164362	lugi	?lugi =lugi  (SgN  >lugi !17_S	et	f	\N
164363	lugi	?lugi =lugi  (SgG  >lugi !17_S	et	f	\N
164364	lugi	?lugi =lugi  (SgP  >lugi !17_S	et	f	\N
164365	lugi	?lugi =lugi  (IndPrPs_  >lugima !27_V	et	f	\N
164366	lugi	?lugi =lugi  (ImpPrSg2  >lugima !27_V	et	f	\N
164367	söönud	söönud =söö  (PtsPtPs  >sööma !38_V	et	f	\N
164368	söönud	söönud =söönu  (PlN  >söönu !01_S	et	f	\N
164369	söönud	"söönu %söö  )NU_vS  <sööma ;38_V	et	f	\N
164370	söönud	söönud =söönu  (PlN  >söönu !06_S	et	f	\N
164371	söönud	söönud =söönud  (ID  >söönud !41_A	et	f	\N
164372	söönud	"söönud %söö  )NUD_vA  <sööma ;38_V	et	f	\N
164386	7tule	tule =tule  (SgG  >tuli !20_S	et	f	\N
164387	7tule	tule =tule  (IndPrPs_  >tulema !36_V	et	f	\N
164388	7tule	tule =tule  (ImpPrSg2  >tulema !36_V	et	f	\N
164389	ärde	?ärde =ärde  (SgN  >ärde !06_S	et	f	\N
164390	ärde	?ärde =ärde  (SgG  >ärre !06_S	et	f	\N
164391	ärde	?ärde =ärde  (PlP  >ärd !22_S	et	f	\N
164392	ärde	?ärde =ärde  (IndPrPs_  >ärdema !27_V	et	f	\N
164393	ärde	?ärde =ärde  (ImpPrSg2  >ärdema !27_V	et	f	\N
164415	kahesaja	?kahesaja =kahesaja  (SgN  >kahesaja !01_S	et	f	\N
164416	kahesaja	?kahesaja =kahesaja  (SgG  >kahesaja !01_S	et	f	\N
164417	kahesaja	?kahesaja =kahesaja  (SgG  >kahesajas !02_A	et	f	\N
164418	kahesaja	?kahesaja =saja  (SgN  >kahe+saja !17_S	et	f	\N
164419	kahesaja	?kahesaja =saja  (SgG  >kahe+saja !17_S	et	f	\N
164420	kahesaja	?kahesaja =saja  (SgP  >kahe+saja !17_S	et	f	\N
164431	mas	### mas	et	f	\N
164437	vigase	vigase =vigase  (SgG  >vigane !10_AS	et	f	\N
164438	vigase	"vigane %viga  )NE_aA  <viga ;18_S	et	f	\N
164451	hääldusalusest	hääldusalusest =aluse  (SgEl  >hääldus+alus !09_S	et	f	\N
164452	hääldusalusest	hääldusalusest =aluse  (SgEl  >hääldus+alune !10_AS	et	f	\N
164453	hääldusalusest	"hääldus+alune %alu  )NE_aA  <hääldus+alg ;22_S	et	f	\N
164454	hääldusalusest	hääldusalusest =aluses  (SgP  >hääldus+alusene !12_A	et	f	\N
164455	hääldusalusest	"hääldus+alusene %aluse  )NE_aA  <hääldus+alus ;09_S	et	f	\N
164463	ekoloogiline	?ekoloogiline =ekoloogiline  (SgN  >ekoloogiline !12_A	et	f	\N
164464	ekoloogiline	?ekoloogiline =ekoloogiline  (PlP  >ekoloogilin !19_S	et	f	\N
164346	küsimule	?küsimule =küsimule  (PlP  >küsimul !19_S	et	f	\N
164347	küsimule	?küsimule =mule  (SgN  >küsi+mule !16_S	et	f	\N
164348	küsimule	?küsimule =mule  (SgG  >küsi+mule !16_S	et	f	\N
164355	imperfekti	imperfekti =imperfekti  (SgG  >imperfekt !22_S	et	f	\N
164356	imperfekti	imperfekti =imperfekti  (SgP  >imperfekt !22_S	et	f	\N
164357	imperfekti	imperfekti =imperfekti  (SgAdt  >imperfekt !22_S	et	f	\N
164373	lahkunud	lahkunud =lahku  (PtsPtPs  >lahkuma !27_V	et	f	\N
164374	lahkunud	lahkunud =lahkunu  (PlN  >lahkunu !01_S	et	f	\N
164375	lahkunud	"lahkunu %lahku  )NU_vS  <lahkuma ;27_V	et	f	\N
164376	lahkunud	lahkunud =lahkunud  (ID  >lahkunud !41_A	et	f	\N
164377	lahkunud	"lahkunud %lahku  )NUD_vA  <lahkuma ;27_V	et	f	\N
164379	mix	### mix	et	f	\N
164384	6ta	ta =ta  (SgG  >ta !00_P	et	f	\N
164385	6ta	ta =ta  (SgN  >ta !00_P	et	f	\N
164398	kuuekümneviies	?kuuekümneviies =kuuekümneviie  (SgIn  >kuuekümneviie !01_S	et	f	\N
164399	kuuekümneviies	?kuuekümneviies =kuuekümneviies  (SgN  >kuuekümneviies !11_S	et	f	\N
164400	kuuekümneviies	?kuuekümneviies =viie  (SgIn  >kuue+kümne+viie !06_S	et	f	\N
164401	kuuekümneviies	?kuuekümneviies =kümneviie  (SgIn  >kuue+kümneviie !01_S	et	f	\N
164402	kuuekümneviies	?kuuekümneviies =kümneviies  (SgN  >kuue+kümneviies !11_S	et	f	\N
164403	kuuekümneviies	?kuuekümneviies =ekümneviie  (SgIn  >kuu+ekümneviie !01_S	et	f	\N
164404	kuuekümneviies	?kuuekümneviies =ekümneviies  (SgN  >kuu+ekümneviies !11_S	et	f	\N
164414	1987a	### 1987a	et	f	\N
164421	esimendal	?esimendal =esimenda  (SgAd  >esimenda !16_S	et	f	\N
164422	esimendal	?esimendal =esimendal  (SgN  >esimendal !02_S	et	f	\N
164423	esimendal	?esimendal =menda  (SgAd  >esi+menda !16_S	et	f	\N
164424	esimendal	?esimendal =mendal  (SgN  >esi+mendal !02_S	et	f	\N
164439	keelekasutuse	keelekasutuse =kasutuse  (SgG  >keele+kasutus !11_S	et	f	\N
164440	keelekasutuse	"keele+kasutus %kasu  )TUS2_aS  <keele+kasu ;17_S	et	f	\N
164460	ü-i	ü-i =ü  (SgG  >ü !xx_Q	et	f	\N
164461	ü-i	ü-i =ü  (SgP  >ü !xx_Q	et	f	\N
164462	ü-i	ü-i =ü  (SgAdt  >ü !xx_Q	et	f	\N
164465	meelsesti	?meelsesti =meelsesti  (ID  >meelsesti !41_D	et	f	\N
164466	meelsesti	?meelsesti =meelsesti  (IndPrPs_  >meelsestima !28_V	et	f	\N
164467	meelsesti	?meelsesti =meelsesti  (ImpPrSg2  >meelsestima !28_V	et	f	\N
164477	mitukorruseline	mitukorruseline =korruseline  (SgN  >mitu+korruseline !12_A	et	f	\N
164478	mitukorruseline	"mitu+korruseline %korruse  )LINE_aA  <mitu+korrus ;09_S	et	f	\N
164488	veenduma	veenduma =veendu  (Sup  >veenduma !27_V	et	f	\N
164489	veenduma	veenduma =veenduma  (SgG  >veendum !02_A	et	f	\N
164490	veenduma	"veendum %veen  )TUM1_cA  <veenma ;33_V	et	f	\N
164494	tundra	tundra =tundra  (SgN  >tundra !01_S	et	f	\N
164495	tundra	tundra =tundra  (SgG  >tundra !01_S	et	f	\N
164504	saavutustest	saavutustest =saavutus  (PlEl  >saavutus !11_S	et	f	\N
164505	saavutustest	"saavutus %saavuta  )US_vS  <saavutama ;27_V	et	f	\N
164506	saavutustest	saavutustest =test  (SgN  >saavutus+test !22_S	et	f	\N
164519	veatüübid	?veatüübid =veatüübi  (PlN  >veatüübi !16_S	et	f	\N
164520	veatüübid	?veatüübid =veatüübi  (PlN  >veatüüp !22_S	et	f	\N
164521	veatüübid	?veatüübid =veatüübi  (IndPrSg2  >veatüüpima !28_V	et	f	\N
164524	tuletusliite	tuletusliite =liite  (SgG  >tuletus+liide !06_S	et	f	\N
164525	tuletusliite	tuletusliite =liite  (PlP  >tuletus+liit !22_S	et	f	\N
164537	keelendeid	keelendeid =keelende  (PlP  >keelend !02_S	et	f	\N
164538	keelendeid	keelendeid =ende  (PlP  >keel+enne !06_S	et	f	\N
164549	sarnaselt	sarnaselt =sarnase  (SgAbl  >sarnane !10_A	et	f	\N
164550	sarnaselt	"sarnane %sarna  )NE_aA  <sarn ;22_S	et	f	\N
164551	sarnaselt	sarnaselt =sarnaselt  (ID  >sarnaselt !41_D	et	f	\N
164552	sarnaselt	"sarnaselt %sarna  )SELT_mD  <sarn ;22_S	et	f	\N
164553	sarnaselt	"sarnaselt %sarnase  )LT_mD  <sarnane ;10_A	et	f	\N
164585	järgsilbi	?järgsilbi =järgsilbi  (SgN  >järgsilbi !01_S	et	f	\N
164586	järgsilbi	?järgsilbi =järgsilbi  (SgG  >järgsilbi !01_S	et	f	\N
164587	järgsilbi	?järgsilbi =järgsilbi  (SgG  >järgsilb !02_S	et	f	\N
164588	järgsilbi	?järgsilbi =järgsilbi  (SgG  >järgsilp !22_S	et	f	\N
164589	järgsilbi	?järgsilbi =järgsilbi  (IndPrPs_  >järgsilpima !28_V	et	f	\N
164590	järgsilbi	?järgsilbi =järgsilbi  (ImpPrSg2  >järgsilpima !28_V	et	f	\N
164605	sagedasemad	sagedasemad =sagedasema  (PlN  >sagedasem !02_A	et	f	\N
164606	sagedasemad	"sagedasem %sagedase  )M_cA  <sagedane ;12_A	et	f	\N
164612	sihitisekäändeid	?sihitisekäändeid =sihitisekäändei  (PlN  >sihitisekäändei !26_S	et	f	\N
164613	sihitisekäändeid	?sihitisekäändeid =sihitisekäändei  (SgP  >sihitisekäändei !26_S	et	f	\N
164614	sihitisekäändeid	?sihitisekäändeid =tisekäändei  (PlN  >sihi+tisekäändei !26_S	et	f	\N
164615	sihitisekäändeid	?sihitisekäändeid =tisekäändei  (SgP  >sihi+tisekäändei !26_S	et	f	\N
164616	alaltütleva	?alaltütleva =alaltütleva  (SgN  >alaltütleva !16_S	et	f	\N
164617	alaltütleva	?alaltütleva =alaltütleva  (SgG  >alaltütlev !02_A	et	f	\N
164618	alaltütleva	?alaltütleva =alaltütleva  (SgG  >alaltütleva !16_S	et	f	\N
164619	alaltütleva	?alaltütleva =tütleva  (SgN  >alal+tütleva !01_S	et	f	\N
164620	alaltütleva	?alaltütleva =tütleva  (SgG  >alal+tütleva !01_S	et	f	\N
164425	seitsmesaja	?seitsmesaja =seitsmesaja  (SgN  >seitsmesaja !01_S	et	f	\N
164426	seitsmesaja	?seitsmesaja =seitsmesaja  (SgG  >seitsmesaja !01_S	et	f	\N
164427	seitsmesaja	?seitsmesaja =seitsmesaja  (SgG  >seitsmesajas !02_A	et	f	\N
164428	seitsmesaja	?seitsmesaja =saja  (SgN  >seitsme+saja !17_S	et	f	\N
164429	seitsmesaja	?seitsmesaja =saja  (SgG  >seitsme+saja !17_S	et	f	\N
164430	seitsmesaja	?seitsmesaja =saja  (SgP  >seitsme+saja !17_S	et	f	\N
164432	mata	mata =mata  (IndPrPs_  >matma !35_V	et	f	\N
164433	mata	mata =mata  (ImpPrSg2  >matma !35_V	et	f	\N
164444	reliigion	?reliigion =reliigion  (SgN  >reliigion !19~02_S	et	f	\N
164456	tingitult	tingitult =tingitu  (SgAbl  >tingitu !01_AS	et	f	\N
164457	tingitult	"tingitu %tingi  )TU1_vS  <tingima ;28_V	et	f	\N
164458	tingitult	tingitult =tingitult  (ID  >tingitult !41_D	et	f	\N
164459	tingitult	"tingitult %tingi  )TULT1_mD  <tingima ;28_V	et	f	\N
164468	tööid	?tööid =tööid  (SgN  >tööid !02_S	et	f	\N
164481	nainega	### nainega	et	f	\N
164483	sinisega	?sinisega =sinise  (SgKom  >sinis !09_S	et	f	\N
164484	sinisega	?sinisega =sinise  (SgKom  >sinine !10_AS	et	f	\N
164485	sinisega	?sinisega =sega  (SgN  >sini+sega !17_S	et	f	\N
164486	sinisega	?sinisega =sega  (SgG  >sini+sega !17_S	et	f	\N
164487	sinisega	?sinisega =sega  (SgP  >sini+sega !17_S	et	f	\N
164500	keeleoskusest	keeleoskusest =oskuse  (SgEl  >keele+oskus !11~09_S	et	f	\N
164501	keeleoskusest	keeleoskusest =oskuses  (SgP  >keele+oskusene !12_A	et	f	\N
164502	keeleoskusest	"keele+oskusene %oskuse  )NE_aA  <keele+oskus ;09_S	et	f	\N
164503	keeleoskusest	"keele+oskusene %oskuse  )NE_aA  <keele+oskus ;11_S	et	f	\N
164507	rühmitatud	rühmitatud =rühmita  (PtsPtIps  >rühmitama !27_V	et	f	\N
164508	rühmitatud	rühmitatud =rühmitatu  (PlN  >rühmitatu !01_S	et	f	\N
164509	rühmitatud	"rühmitatu %rühmita  )TU1_vS  <rühmitama ;27_V	et	f	\N
164510	rühmitatud	rühmitatud =rühmitatud  (ID  >rühmitatud !41_A	et	f	\N
164511	rühmitatud	"rühmitatud %rühmita  )TUD_vA  <rühmitama ;27_V	et	f	\N
164517	hääldusviga	hääldusviga =viga  (SgN  >hääldus+viga !18_S	et	f	\N
164518	hääldusviga	hääldusviga =viga  (SgP  >hääldus+viga !18_S	et	f	\N
164544	ortograafiavigadest	?ortograafiavigadest =ortograafiavigades  (SgP  >ortograafiavigadene !12_A	et	f	\N
164545	häälduse	häälduse =häälduse  (SgG  >hääldus !11~09_S	et	f	\N
164546	häälduse	"hääldus %häälda  )US_vS  <hääldama ;27_V	et	f	\N
164547	pensionäär	?pensionäär =pensionäär  (SgN  >pensionäär !22_S	et	f	\N
164548	pensionäär	?pensionäär =onäär  (SgN  >pensi+onäär !22_S	et	f	\N
164568	tüütter	?tüütter =tüütter  (SgN  >tüütter !02_S	et	f	\N
164571	eema	?eema =eema  (SgN  >eema !16_S	et	f	\N
164573	eema	?eema =eema  (SgG  >eema !16_S	et	f	\N
164575	eema	?eema =eema  (IndPrPs_  >eemama !29_V	et	f	\N
164577	eema	?eema =eema  (ImpPrSg2  >eemama !29_V	et	f	\N
164602	kaebur	?kaebur =kaebur  (SgN  >kaebur !02_S	et	f	\N
164603	takista	takista =takista  (IndPrPs_  >takistama !27_V	et	f	\N
164604	takista	takista =takista  (ImpPrSg2  >takistama !27_V	et	f	\N
164622	hulgafraasi	?hulgafraasi =hulgafraasi  (SgN  >hulgafraasi !16_S	et	f	\N
164623	hulgafraasi	?hulgafraasi =hulgafraasi  (SgG  >hulgafraasi !16_S	et	f	\N
164624	hulgafraasi	?hulgafraasi =hulgafraasi  (SgG  >hulgafraas !22_S	et	f	\N
164625	hulgafraasi	?hulgafraasi =hulgafraasi  (SgP  >hulgafraas !22_S	et	f	\N
164626	hulgafraasi	?hulgafraasi =hulgafraasi  (SgAdt  >hulgafraas !22_S	et	f	\N
164627	hulgafraasi	?hulgafraasi =hulgafraasi  (IndPrPs_  >hulgafraasima !28_V	et	f	\N
164628	hulgafraasi	?hulgafraasi =hulgafraasi  (ImpPrSg2  >hulgafraasima !28_V	et	f	\N
164633	mitmusesse	mitmusesse =mitmuse  (SgIll  >mitmus !11~09_S	et	f	\N
164634	mitmusesse	mitmusesse =mitmuses  (SgAdt  >mitmusene !12_A	et	f	\N
164635	mitmusesse	"mitmusene %mitmuse  )NE_aA  <mitmus ;09_S	et	f	\N
164636	mitmusesse	"mitmusene %mitmuse  )NE_aA  <mitmus ;11_S	et	f	\N
164640	sellistes	sellistes =sellis  (PlIn  >selline !10_P	et	f	\N
164641	sellistes	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
164650	ainuslikku	?ainuslikku =ainuslikku  (SgP  >ainuslik !25_A	et	f	\N
164651	ainuslikku	?ainuslikku =ainuslikku  (SgAdt  >ainuslik !25_A	et	f	\N
164652	ainuslikku	?ainuslikku =ainuslikku  (IndPrPs_  >ainuslikkuma !27_V	et	f	\N
164653	ainuslikku	?ainuslikku =ainuslikku  (ImpPrSg2  >ainuslikkuma !27_V	et	f	\N
164654	ainuslikku	?ainuslikku =slikku  (SgP  >ainu+slikk !22_S	et	f	\N
164655	ainuslikku	?ainuslikku =slikku  (SgAdt  >ainu+slikk !22_S	et	f	\N
164666	tüvevalikuvigu	?tüvevalikuvigu =tüvevalikuvigu  (IndPrPs_  >tüvevalikuviguma !27_V	et	f	\N
164667	tüvevalikuvigu	?tüvevalikuvigu =tüvevalikuvigu  (ImpPrSg2  >tüvevalikuviguma !27_V	et	f	\N
164674	ortograafiaviga	?ortograafiaviga =ortograafiavi  (SgKom  >ortograafiavi !16_S	et	f	\N
164675	ortograafiaviga	?ortograafiaviga =ortograafiavi  (SgKom  >ortograafiav !22_S	et	f	\N
164681	tüvevalikuviga	?tüvevalikuviga =tüvevalikuvi  (SgKom  >tüvevalikuv !02_A	et	f	\N
164698	vysokij	### vysokij	et	f	\N
164700	enesekohase	enesekohase =kohase  (SgG  >enese+kohane !10_A	et	f	\N
164701	enesekohase	"enese+kohane %koha  )NE_aA  <enese+koha ;17_S	et	f	\N
164702	enesekohase	"enese+kohane %koha  )NE_aA  <enese+koht ;22_S	et	f	\N
164708	töötud	töötud =töötu  (PlN  >töötu !01_AS	et	f	\N
164475	käside	### käside	et	f	\N
164491	osmussaarel	?osmussaarel =osmussaare  (SgAd  >osmussaare !16_S	et	f	\N
164492	osmussaarel	?osmussaarel =osmussaare  (PlAd  >osmussaar !22_S	et	f	\N
164493	osmussaarel	?osmussaarel =osmussaarel  (SgN  >osmussaarel !02_S	et	f	\N
164498	tagasisidet	tagasisidet =side  (SgP  >tagasi+side !04_S	et	f	\N
164499	tagasisidet	tagasisidet =side  (SgP  >tagasi+side !16_S	et	f	\N
164530	intralingvaalseteks	?intralingvaalseteks =intralingvaalse  (PlTr  >intralingvaalne !02_A	et	f	\N
164531	intralingvaalseteks	?intralingvaalseteks =intralingvaalsete  (PlTr  >intralingvaalsett !22_S	et	f	\N
164532	õpitava	õpitava =õpitava  (SgG  >õpitav !02_A	et	f	\N
164533	õpitava	"õpitav %õpi  )TAV_vAS  <õppima ;28_V	et	f	\N
164534	õpitava	õpitava =tava  (SgN  >õpi+tava !17_S	et	f	\N
164535	õpitava	õpitava =tava  (SgG  >õpi+tava !17_S	et	f	\N
164536	õpitava	õpitava =tava  (SgP  >õpi+tava !17_S	et	f	\N
164539	häälikutasandi	?häälikutasandi =häälikutasandi  (SgG  >häälikutasant !22_S	et	f	\N
164540	häälikutasandi	?häälikutasandi =häälikutasandi  (SgP  >häälikutasand !22_S	et	f	\N
164541	häälikutasandi	?häälikutasandi =häälikutasandi  (SgAdt  >häälikutasand !22_S	et	f	\N
164542	häälikutasandi	?häälikutasandi =häälikutasandi  (IndPrPs_  >häälikutasantima !28_V	et	f	\N
164543	häälikutasandi	?häälikutasandi =häälikutasandi  (ImpPrSg2  >häälikutasantima !28_V	et	f	\N
164554	ehtima	ehtima =ehti  (Sup  >ehtima !27_V	et	f	\N
164555	ehtima	ehtima =ehti  (Sup  >ehtima !28_V	et	f	\N
164556	ehtima	ehtima =ima  (SgN  >eht+ima !17_S	et	f	\N
164557	ehtima	ehtima =ima  (SgG  >eht+ima !17_S	et	f	\N
164558	ehtima	ehtima =ima  (SgP  >eht+ima !17_S	et	f	\N
164559	lühikeste	lühikeste =lühikes  (PlG  >lühike !12_A	et	f	\N
164560	lühikeste	"lühike %lühi  )KE_dS  <lüht ;22_S	et	f	\N
164561	lühikeste	lühikeste =lühikes  (PlG  >lühikene !12_S	et	f	\N
164562	lühikeste	"lühikene %lühi  )KENE_dS  <lüht ;22_S	et	f	\N
164563	lühikeste	lühikeste =keste  (SgN  >lühi+keste !06_S	et	f	\N
164564	lühikeste	lühikeste =keste  (SgG  >lühi+keste !06_S	et	f	\N
164566	lühikeste	lühikeste =keste  (PlP  >lühi+kest !22_S	et	f	\N
164569	kirjutuse	kirjutuse =kirjutuse  (SgG  >kirjutus !11_S	et	f	\N
164570	kirjutuse	"kirjutus %kirjuta  )US_vS  <kirjutama ;27_V	et	f	\N
164572	iisa	?iisa =iisa  (SgN  >iisa !16_S	et	f	\N
164574	iisa	?iisa =iisa  (SgG  >iisa !16_S	et	f	\N
164576	iisa	?iisa =iisa  (IndPrPs_  >iisama !29_V	et	f	\N
164578	iisa	?iisa =iisa  (ImpPrSg2  >iisama !29_V	et	f	\N
164593	ortograafiavigu	?ortograafiavigu =ortograafiavi  (ImpPrPs  >ortograafiavima !28_V	et	f	\N
164594	ortograafiavigu	?ortograafiavigu =ortograafiavigu  (IndPrPs_  >ortograafiaviguma !27_V	et	f	\N
164595	ortograafiavigu	?ortograafiavigu =ortograafiavigu  (ImpPrSg2  >ortograafiaviguma !27_V	et	f	\N
164607	sihitisekäände	?sihitisekäände =sihitisekäände  (PlP  >sihitisekäänd !22_S	et	f	\N
164608	sihitisekäände	?sihitisekäände =tisekäände  (PlP  >sihi+tisekäänd !22_S	et	f	\N
164609	nominatiivi	nominatiivi =nominatiivi  (SgG  >nominatiiv !22_S	et	f	\N
164610	nominatiivi	nominatiivi =nominatiivi  (SgP  >nominatiiv !22_S	et	f	\N
164611	nominatiivi	nominatiivi =nominatiivi  (SgAdt  >nominatiiv !22_S	et	f	\N
164637	käändesse	käändesse =käände  (SgIll  >kääne !06_S	et	f	\N
164638	käändesse	käändesse =käändes  (SgAdt  >käändene !12_A	et	f	\N
164639	käändesse	"käändene %käände  )NE_aA  <kääne ;06_S	et	f	\N
164663	vormimoodustusvigadest	?vormimoodustusvigadest =vormimoodustusvigades  (SgP  >vormimoodustusvigadene !12_A	et	f	\N
164664	vormimoodustusvigadest	?vormimoodustusvigadest =moodustusvigades  (SgP  >vormi+moodustusvigadene !12_A	et	f	\N
164665	vormimoodustusvigadest	?vormimoodustusvigadest =imoodustusvigades  (SgP  >vorm+imoodustusvigadene !12_A	et	f	\N
164670	koolikottis	?koolikottis =koolikotti  (IndIpfSg3  >koolikottima !28_V	et	f	\N
164671	koolikottis	?koolikottis =koolikottis  (SgN  >koolikottis !09_S	et	f	\N
164672	koolikottis	?koolikottis =ikotti  (SgIn  >kool+ikotti !01_S	et	f	\N
164673	koolikottis	?koolikottis =ikottis  (SgN  >kool+ikottis !11_S	et	f	\N
164676	hääldusest	hääldusest =häälduse  (SgEl  >hääldus !11~09_S	et	f	\N
164677	hääldusest	"hääldus %häälda  )US_vS  <hääldama ;27_V	et	f	\N
164678	hääldusest	hääldusest =häälduses  (SgP  >hääldusene !12_A	et	f	\N
164679	hääldusest	"hääldusene %häälduse  )NE_aA  <hääldus ;09_S	et	f	\N
164680	hääldusest	"hääldusene %häälduse  )NE_aA  <hääldus ;11_S	et	f	\N
164699	dlinnyj	### dlinnyj	et	f	\N
164703	töötinimesed	?töötinimesed =töötinimese  (PlN  >töötinimene !12_A	et	f	\N
164704	töötinimesed	?töötinimesed =tinimese  (PlN  >töö+tinimene !12_A	et	f	\N
164707	analoogia	analoogia =analoogia  (SgN  >analoogia !01_S	et	f	\N
164709	analoogia	analoogia =analoogia  (SgG  >analoogia !01_S	et	f	\N
164716	moodustanud	moodustanud =moodusta  (PtsPtPs  >moodustama !27_V	et	f	\N
164717	moodustanud	moodustanud =moodustanu  (PlN  >moodustanu !01_S	et	f	\N
164718	moodustanud	"moodustanu %moodusta  )NU_vS  <moodustama ;27_V	et	f	\N
164719	moodustanud	moodustanud =moodustanud  (ID  >moodustanud !41_A	et	f	\N
164720	moodustanud	"moodustanud %moodusta  )NUD_vA  <moodustama ;27_V	et	f	\N
164739	zoos	?zoos =zoo  (SgIn  >zoo !26_S	et	f	\N
164740	zoos	?zoos =zoos  (SgN  >zoos !22_S	et	f	\N
164513	häälikutasandil	?häälikutasandil =häälikutasandil  (SgN  >häälikutasandil !02_S	et	f	\N
164522	segunemine	segunemine =segunemine  (SgN  >segunemine !12_S	et	f	\N
164523	segunemine	"segunemine %segune  )MINE_vS  <segunema ;27_V	et	f	\N
164526	uusmoodustis	uusmoodustis =moodusti  (SgIn  >uus+moodusti !01_S	et	f	\N
164527	uusmoodustis	uusmoodustis =moodustis  (SgN  >uus+moodustis !11_S	et	f	\N
164528	kirjeldamisel	kirjeldamisel =kirjeldamise  (SgAd  >kirjeldamine !12_S	et	f	\N
164529	kirjeldamisel	"kirjeldamine %kirjelda  )MINE_vS  <kirjeldama ;27_V	et	f	\N
164565	pikkade	pikkade =pikka  (PlG  >pikk !22_S	et	f	\N
164567	pikkade	pikkade =pikka  (PlG  >pikk !22_AS	et	f	\N
164584	jts	### jts	et	f	\N
164599	tähti	tähti =tähti  (SgP  >täht !22_S	et	f	\N
164600	tähti	tähti =tähti  (SgAdt  >täht !22_S	et	f	\N
164601	tähti	tähti =tähti  (PlP  >täht !22_S	et	f	\N
164629	käändevaliku	?käändevaliku =käändevaliku  (SgG  >käändevalik !25_A	et	f	\N
164630	käändevaliku	?käändevaliku =käändevaliku  (IndPrPs_  >käändevalikuma !27_V	et	f	\N
164631	käändevaliku	?käändevaliku =käändevaliku  (ImpPrSg2  >käändevalikuma !27_V	et	f	\N
164632	käändevaliku	?käändevaliku =evaliku  (SgG  >käänd+evalik !25_A	et	f	\N
164645	kinnistunud	kinnistunud =kinnistu  (PtsPtPs  >kinnistuma !27_V	et	f	\N
164646	kinnistunud	kinnistunud =kinnistunu  (PlN  >kinnistunu !01_S	et	f	\N
164647	kinnistunud	"kinnistunu %kinnistu  )NU_vS  <kinnistuma ;27_V	et	f	\N
164648	kinnistunud	kinnistunud =kinnistunud  (ID  >kinnistunud !41_A	et	f	\N
164649	kinnistunud	"kinnistunud %kinnistu  )NUD_vA  <kinnistuma ;27_V	et	f	\N
164682	lasteaijasse	?lasteaijasse =lasteaija  (SgIll  >lasteaija !01_S	et	f	\N
164683	lasteaijasse	?lasteaijasse =lasteaija  (SgIll  >lasteaijas !02_A	et	f	\N
164684	lasteaijasse	?lasteaijasse =lasteaijas  (SgAdt  >lasteaijane !12_A	et	f	\N
164685	lasteaijasse	?lasteaijasse =lasteaijasse  (SgG  >lasteaijasne !02_A	et	f	\N
164686	lasteaijasse	?lasteaijasse =lasteaijasse  (PlP  >lasteaijass !22_S	et	f	\N
164687	lasteaijasse	?lasteaijasse =aija  (SgIll  >laste+aija !01_S	et	f	\N
164688	lasteaijasse	?lasteaijasse =aijasse  (SgG  >laste+aijasne !02_A	et	f	\N
164689	lasteaijasse	?lasteaijasse =aijasse  (PlP  >laste+aijass !22_S	et	f	\N
164692	sarnase	sarnase =sarnase  (SgG  >sarnane !10_A	et	f	\N
164693	sarnase	"sarnane %sarna  )NE_aA  <sarn ;22_S	et	f	\N
164705	liitmisel	liitmisel =liitmise  (SgAd  >liitmine !12?10_S	et	f	\N
164706	liitmisel	"liitmine %liit  )MINE_vS  <liitma ;34_V	et	f	\N
164711	liitumise	liitumise =liitumise  (SgG  >liitumine !12_S	et	f	\N
164712	liitumise	"liitumine %liitu  )MINE_vS  <liituma ;27_V	et	f	\N
164724	elefant	?elefant =elefant  (SgN  >elefant !22_S	et	f	\N
164741	zoo	?zoo =zoo  (SgN  >zoo !26_S	et	f	\N
164742	zoo	?zoo =zoo  (SgG  >zoo !26_S	et	f	\N
164752	seleta	seleta =seleta  (IndPrPs_  >seletama !27_V	et	f	\N
164753	seleta	seleta =seleta  (ImpPrSg2  >seletama !27_V	et	f	\N
164767	loomulikus	loomulikus =loomuliku  (SgIn  >loomulik !25_A	et	f	\N
164768	loomulikus	loomulikus =loomulikus  (SgN  >loomulikus !11?09_S	et	f	\N
164769	loomulikus	"loomulikus %loomuliku  )US_aS  <loomulik ;25_A	et	f	\N
164776	võimaldanud	võimaldanud =võimalda  (PtsPtPs  >võimaldama !27_V	et	f	\N
164777	võimaldanud	võimaldanud =võimaldanu  (PlN  >võimaldanu !01_S	et	f	\N
164778	võimaldanud	"võimaldanu %võimalda  )NU_vS  <võimaldama ;27_V	et	f	\N
164779	võimaldanud	võimaldanud =võimaldanud  (ID  >võimaldanud !41_A	et	f	\N
164780	võimaldanud	"võimaldanud %võimalda  )NUD_vA  <võimaldama ;27_V	et	f	\N
164781	õ-d	õ-d =õ  (SgP  >õ !xx_Q	et	f	\N
164782	õ-d	õ-d =õ  (PlN  >õ !xx_Q	et	f	\N
164788	lohakuse	lohakuse =lohakuse  (SgG  >lohakus !11_S	et	f	\N
164789	lohakuse	"lohakus %lohaka  )US_aS  <lohakas ;02_A	et	f	\N
164790	pil	### pil	et	f	\N
164793	ama	?ama =ama  (SgN  >ama !17_S	et	f	\N
164794	ama	?ama =ama  (SgG  >ama !17_S	et	f	\N
164795	ama	?ama =ama  (SgP  >ama !17_S	et	f	\N
164796	ama	?ama =ama  (IndPrPs_  >amama !27_V	et	f	\N
164797	ama	?ama =ama  (ImpPrSg2  >amama !27_V	et	f	\N
164798	amiseks	?amiseks =amise  (SgTr  >amine !10_A	et	f	\N
164799	amiseks	?amiseks =amise  (KndPrPs  >amisema !27_V	et	f	\N
164810	tu	### tu	et	f	\N
164816	amisele	?amisele =amise  (SgAll  >amine !10_A	et	f	\N
164817	amisele	?amisele =amisele  (PlP  >amisel !19_S	et	f	\N
164821	jä	### jä	et	f	\N
164826	loppuni	?loppuni =loppuni  (SgG  >loppun !02_S	et	f	\N
164829	asti	asti =asti  (SgG  >ast !22_S	et	f	\N
164830	asti	asti =asti  (SgP  >ast !22_S	et	f	\N
164831	asti	asti =asti  (SgAdt  >ast !22_S	et	f	\N
164854	kort	?kort =kort  (SgN  >kort !22_S	et	f	\N
164873	pildisdamiseks	?pildisdamiseks =pildisdamise  (SgTr  >pildisdamine !12_S	et	f	\N
164896	työstä	### työstä	et	f	\N
164912	materiaali	?materiaali =materiaali  (SgN  >materiaali !16_S	et	f	\N
164913	materiaali	?materiaali =materiaali  (SgG  >materiaali !16_S	et	f	\N
164914	materiaali	?materiaali =materiaali  (SgG  >materiaal !22_S	et	f	\N
164915	materiaali	?materiaali =materiaali  (SgP  >materiaal !22_S	et	f	\N
164916	materiaali	?materiaali =materiaali  (SgAdt  >materiaal !22_S	et	f	\N
164621	alaltütleva	?alaltütleva =tütleva  (SgG  >alal+tütlev !02_A	et	f	\N
164642	genitiivi	genitiivi =genitiivi  (SgG  >genitiiv !22_S	et	f	\N
164643	genitiivi	genitiivi =genitiivi  (SgP  >genitiiv !22_S	et	f	\N
164644	genitiivi	genitiivi =genitiivi  (SgAdt  >genitiiv !22_S	et	f	\N
164656	linnuses	linnuses =linnuse  (SgIn  >linnus !09_S	et	f	\N
164657	linnuses	linnuses =use  (PlIn  >linn+usk !22_S	et	f	\N
164691	tüvevariant	?tüvevariant =tüvevariant  (SgN  >tüvevariant !22_S	et	f	\N
164696	sõnavalikuviga	sõnavalikuviga =viga  (SgN  >sõna+valiku+viga !18_S	et	f	\N
164697	sõnavalikuviga	sõnavalikuviga =viga  (SgP  >sõna+valiku+viga !18_S	et	f	\N
164725	tekke	tekke =tekke  (SgG  >teke !06_S	et	f	\N
164726	tekke	tekke =tekke  (PlP  >tekk !22_S	et	f	\N
164736	keelekeskkonnast	keelekeskkonnast =keskkonna  (SgEl  >keele+keskkond !22_S	et	f	\N
164737	keelekeskkonnast	keelekeskkonnast =keskkonnas  (SgP  >keele+keskkonnane !12_A	et	f	\N
164738	keelekeskkonnast	"keele+keskkonnane %keskkonna  )NE_aA  <keele+keskkond ;22_S	et	f	\N
164743	loomaaia	loomaaia =aia  (SgG  >looma+aed !22_S	et	f	\N
164744	loomaaia	loomaaia =aia  (SgG  >looma+ai !22_S	et	f	\N
164745	loomaaia	loomaaia =aia  (SgP  >looma+ai !22_S	et	f	\N
164746	loomaaia	loomaaia =aia  (SgAdt  >looma+ai !22_S	et	f	\N
164754	paljalt	paljalt =palja  (SgAbl  >paljas !07_A	et	f	\N
164755	paljalt	paljalt =paljalt  (ID  >paljalt !41_D	et	f	\N
164756	paljalt	"paljalt %palja  )LT_mD  <paljas ;07_A	et	f	\N
164757	paranduste	paranduste =parandus  (PlG  >parandus !11_S	et	f	\N
164758	paranduste	"parandus %paranda  )US_vS  <parandama ;27_V	et	f	\N
164765	kaasüliõpilastega	kaasüliõpilastega =las  (PlKom  >kaas+üli+õpi+laps !14_S	et	f	\N
164766	kaasüliõpilastega	kaasüliõpilastega =õpilas  (PlKom  >kaas+üli+õpilane !12_S	et	f	\N
164783	veatult	veatult =veatu  (SgAbl  >veatu !01_A	et	f	\N
164784	veatult	"veatu %vea  )TU2_kA  <viga ;18_S	et	f	\N
164785	veatult	veatult =veatult  (ID  >veatult !41_D	et	f	\N
164786	veatult	"veatult %vea  )TULT2_mD  <viga ;18_S	et	f	\N
164787	veatult	"veatult %veatu  )LT_mD  <veatu ;01_A	et	f	\N
164808	lo	### lo	et	f	\N
164813	ilmu	ilmu =ilmu  (PlP  >ilm !22_S	et	f	\N
164814	ilmu	ilmu =ilmu  (IndPrPs_  >ilmuma !27_V	et	f	\N
164815	ilmu	ilmu =ilmu  (ImpPrSg2  >ilmuma !27_V	et	f	\N
164823	ilt	?ilt =ilt  (SgN  >ilt !22_S	et	f	\N
164828	loppuun	?loppuun =loppuun  (SgN  >loppuun !22_S	et	f	\N
164848	sõnalõpuliste	sõnalõpuliste =lõpulis  (PlG  >sõna+lõpuline !12_A	et	f	\N
164849	sõnalõpuliste	"sõna+lõpuline %lõpu  )LINE_aA  <sõna+lõpp ;22_SA	et	f	\N
164850	ainul	ainul =ainu  (SgAd  >ainus !07_AS	et	f	\N
164851	ainul	ainul =ainu  (SgAd  >ainu !16_S	et	f	\N
164852	ainul	ainul =ainu  (PlAd  >ain !22_S	et	f	\N
164855	juhuslikku	juhuslikku =juhuslikku  (SgP  >juhuslik !25_A	et	f	\N
164856	juhuslikku	juhuslikku =juhuslikku  (SgAdt  >juhuslik !25_A	et	f	\N
164864	hooletusvigadega	### hooletusvigadega	et	f	\N
164876	20ndal	### 20ndal	et	f	\N
164885	käändevalikuga	?käändevalikuga =käändevaliku  (SgKom  >käändevalik !25_A	et	f	\N
164886	käändevalikuga	?käändevalikuga =evaliku  (SgKom  >käänd+evalik !25_A	et	f	\N
164894	diil	?diil =dii  (SgAd  >dii !26_S	et	f	\N
164895	diil	?diil =diil  (SgN  >diil !22_S	et	f	\N
164898	sellistel	sellistel =sellis  (PlAd  >selline !10_P	et	f	\N
164899	sellistel	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
164902	kordumine	kordumine =kordumine  (SgN  >kordumine !12_S	et	f	\N
164903	kordumine	"kordumine %kordu  )MINE_vS  <korduma ;27_V	et	f	\N
164945	üllatav	üllatav =üllata  (PtsPrPs  >üllatama !27_V	et	f	\N
164946	üllatav	üllatav =üllatav  (SgN  >üllatav !02_A	et	f	\N
164947	üllatav	"üllatav %üllata  )V_vA  <üllatama ;27_V	et	f	\N
164971	ilmuttamisele	?ilmuttamisele =ilmuttamise  (SgAll  >ilmuttamine !12_S	et	f	\N
164972	ilmuttamisele	?ilmuttamisele =uttamise  (SgAll  >ilm+uttamine !12_S	et	f	\N
164977	voiks	?voiks =voi  (SgTr  >voi !26_S	et	f	\N
164978	voiks	?voiks =voiks  (SgN  >voiks !22_S	et	f	\N
164994	suhten	?suhten =suhte  (IndPrSg1  >suhtema !27_V	et	f	\N
164995	suhten	?suhten =suhten  (SgN  >suhten !02_S	et	f	\N
165029	lõpmatu	lõpmatu =lõpmatu  (SgN  >lõpmatu !01_A	et	f	\N
165030	lõpmatu	"lõpmatu %lõp  )MATU_vA  <lõpma ;35_V	et	f	\N
165031	lõpmatu	lõpmatu =lõpmatu  (SgG  >lõpmatu !01_A	et	f	\N
165032	loojad	loojad =looja  (PlN  >looja !01_S	et	f	\N
165033	loojad	"looja %loo  )JA_vS  <looma ;38_V	et	f	\N
165041	tehnliine	?tehnliine =tehnliine  (SgN  >tehnliine !12~10_A	et	f	\N
165042	tehnliine	?tehnliine =tehnliine  (PlP  >tehnliin !22_S	et	f	\N
165043	tehnliine	?tehnliine =tehnliine  (IndPrPs_  >tehnliinema !27_V	et	f	\N
165044	tehnliine	?tehnliine =tehnliine  (ImpPrSg2  >tehnliinema !27_V	et	f	\N
165048	omapärast	omapärast =pära  (SgEl  >oma+pära !17_S	et	f	\N
165049	omapärast	omapärast =päras  (SgP  >oma+pärane !10_A	et	f	\N
165050	omapärast	"oma+pärane %pära  )NE_aA  <oma+pära ;17_S	et	f	\N
165065	meilgi	meilgi =me  (PlAd^  >ma !00_P	et	f	\N
165066	meilgi	meilgi =meil  (SgN^  >meil !22_S	et	f	\N
165085	põlvesse	põlvesse =põlve  (SgIll  >põlv !22_S	et	f	\N
165086	põlvesse	põlvesse =põlve  (SgIll  >põli !24_S	et	f	\N
164695	segunemise	"segunemine %segune  )MINE_vS  <segunema ;27_V	et	f	\N
164713	nimetavalist	nimetavalist =nimetavalis  (SgP  >nimetavaline !12_A	et	f	\N
164714	nimetavalist	nimetavalist =tavalis  (SgP  >nime+tavaline !12_A	et	f	\N
164715	nimetavalist	"nime+tavaline %tava  )LINE_aA  <nime+tava ;17_S	et	f	\N
164721	igrat	?igrat =igra  (SgP  >igra !16_S	et	f	\N
164722	igrat	?igrat =igrat  (SgN  >igrat !02_S	et	f	\N
164727	kummitused	kummitused =kummituse  (PlN  >kummitus !11_S	et	f	\N
164728	kummitused	"kummitus %kummita  )US_vS  <kummitama ;27_V	et	f	\N
164729	kummitused	"kummitus %kummi  )TUS1_aS  <kummima ;28_V	et	f	\N
164730	kummitused	"kummitus %kummi  )TUS2_aS  <kummi ;16_S	et	f	\N
164731	kummitused	"kummitus %kummi  )TUS2_aS  <kumm ;22_S	et	f	\N
164734	haruldasemat	haruldasemat =haruldasema  (SgP  >haruldasem !02_A	et	f	\N
164735	haruldasemat	"haruldasem %haruldase  )M_cA  <haruldane ;12_A	et	f	\N
164759	kolmel	kolmel =kolme  (SgAd  >kolm !22_N	et	f	\N
164760	kolmel	kolmel =kolme  (PlAd  >kolm !22_N	et	f	\N
164763	kunstiakadeemia	kunstiakadeemia =akadeemia  (SgN  >kunsti+akadeemia !01_S	et	f	\N
164764	kunstiakadeemia	kunstiakadeemia =akadeemia  (SgG  >kunsti+akadeemia !01_S	et	f	\N
164800	hooletusest	hooletusest =hooletuse  (SgEl  >hooletus !11_S	et	f	\N
164801	hooletusest	"hooletus %hoole  )TUS2_aS  <hool ;13_S	et	f	\N
164802	hooletusest	hooletusest =hooletuses  (SgP  >hooletusene !12_A	et	f	\N
164803	hooletusest	"hooletusene %hooletuse  )NE_aA  <hooletus ;11_S	et	f	\N
164806	asuvate	asuvate =asuva  (PlG  >asuv !02_A	et	f	\N
164807	asuvate	"asuv %asu  )V_vA  <asuma ;27_V	et	f	\N
164818	prin	### prin	et	f	\N
164827	sm	### sm	et	f	\N
164839	kusgilt	?kusgilt =kusgi  (SgAbl  >kusgi !16_S	et	f	\N
164840	kusgilt	?kusgilt =kusgi  (SgAbl  >kusg !22_S	et	f	\N
164841	kusgilt	?kusgilt =gilt  (SgN  >kus+gilt !22_S	et	f	\N
164853	kor	### kor	et	f	\N
164860	lipsata	lipsata =lipsa  (Inf  >lipsama !29_V	et	f	\N
164861	lipsata	lipsata =lipsa  (IndPrIps_  >lipsama !29_V	et	f	\N
164862	lipsata	lipsata =lipsata  (IndPrPs_  >lipsatama !27_V	et	f	\N
164863	lipsata	lipsata =lipsata  (ImpPrSg2  >lipsatama !27_V	et	f	\N
164882	õigekirjaviga	õigekirjaviga =viga  (SgN  >õige+kirja+viga !18_S	et	f	\N
164883	õigekirjaviga	õigekirjaviga =viga  (SgP  >õige+kirja+viga !18_S	et	f	\N
164884	õigekirjaviga	õigekirjaviga =kirjavi  (SgKom  >õige+kirjav !02_A	et	f	\N
164888	abimäärsõna	### abimäärsõna	et	f	\N
164900	juhuslikkuse	juhuslikkuse =juhuslikkuse  (SgG  >juhuslikkus !11~09_S	et	f	\N
164901	juhuslikkuse	"juhuslikkus %juhuslikku  )US_aS  <juhuslik ;25_A	et	f	\N
164904	eksitud	eksitud =eksi  (PtsPtIps  >eksima !28_V	et	f	\N
164905	eksitud	eksitud =eksitu  (PlN  >eksitu !01_AS	et	f	\N
164906	eksitud	"eksitu %eksi  )TU1_vS  <eksima ;28_V	et	f	\N
164907	eksitud	eksitud =eksitud  (ID  >eksitud !41_A	et	f	\N
164908	eksitud	"eksitud %eksi  )TUD_vA  <eksima ;28_V	et	f	\N
164909	vaibast	vaibast =vaiba  (SgEl  >vaip !22_S	et	f	\N
164910	vaibast	vaibast =vaibas  (SgP  >vaibane !10_A	et	f	\N
164911	vaibast	"vaibane %vaiba  )NE_aA  <vaip ;22_S	et	f	\N
164919	käiva	käiva =käiva  (SgG  >käiv !02_A	et	f	\N
164920	käiva	"käiv %käi  )V_vA  <käima ;38_V	et	f	\N
164928	voimatu	?voimatu =voimatu  (SgN  >voimatu !01_A	et	f	\N
164929	voimatu	?voimatu =voimatu  (SgG  >voimatu !01_A	et	f	\N
164930	voimatu	?voimatu =voimatu  (IndPrPs_  >voimatuma !27_V	et	f	\N
164931	voimatu	?voimatu =voimatu  (ImpPrSg2  >voimatuma !27_V	et	f	\N
164951	motlen	?motlen =motle  (IndPrSg1  >motlema !30_V	et	f	\N
164952	motlen	?motlen =motlen  (SgN  >motlen !02_S	et	f	\N
164956	ytleme	?ytleme =ytle  (IndPrPl1  >ytlema !30_V	et	f	\N
164973	ytle	?ytle =ytle  (SgN  >ytle !06_S	et	f	\N
164974	ytle	?ytle =ytle  (IndPrPs_  >ytlema !30_V	et	f	\N
164975	ytle	?ytle =ytle  (ImpPrSg2  >ytlema !30_V	et	f	\N
164996	kontroltöös	?kontroltöös =kontroltöö  (SgIn  >kontroltöö !26_S	et	f	\N
164997	kontroltöös	?kontroltöös =kontroltöös  (SgN  >kontroltöös !22_S	et	f	\N
164998	kontroltöös	?kontroltöös =roltöö  (SgIn  >kont+roltöö !26_S	et	f	\N
164999	kontroltöös	?kontroltöös =roltöös  (SgN  >kont+roltöös !22_S	et	f	\N
165000	õppetus	õppetus =õppetu  (SgIn  >õppetu !01_A	et	f	\N
165001	õppetus	"õppetu %õppe  )TU2_kA  <õpe ;06_S	et	f	\N
165002	õppetus	õppetus =õppetus  (SgN  >õppetus !11_S	et	f	\N
165003	õppetus	"õppetus %õppe  )TUS2_aS  <õpe ;06_S	et	f	\N
165017	teatuid	teatuid =teatu  (PlP  >teatu !01_S	et	f	\N
165018	teatuid	"teatu %tea  )TU1_vS  <teadma ;34_V	et	f	\N
165019	rahuldavat	rahuldavat =rahulda  (KvtPrPs  >rahuldama !27_V	et	f	\N
165020	rahuldavat	rahuldavat =rahuldava  (SgP  >rahuldav !02_A	et	f	\N
165021	rahuldavat	"rahuldav %rahulda  )V_vA  <rahuldama ;27_V	et	f	\N
165022	pöördusin	pöördusin =pöördu  (IndIpfSg1  >pöörduma !27_V	et	f	\N
165023	pöördusin	pöördusin =usin  (SgN  >pöörd+usin !02_A	et	f	\N
165026	võõrasemale	võõrasemale =male  (SgN  >võõr+ase+male !16_S	et	f	\N
165027	võõrasemale	võõrasemale =male  (SgG  >võõr+ase+male !16_S	et	f	\N
165028	võõrasemale	võõrasemale =ema  (SgAll  >võõras+ema !17_S	et	f	\N
165074	kodu-	kodu- =kodu  (ID  >kodu !41_D	et	f	\N
164710	töötud	"töötu %töö  )TU2_kA  <töö ;26_S	et	f	\N
164723	elefantid	### elefantid	et	f	\N
164732	peleta	peleta =peleta  (IndPrPs_  >peletama !27_V	et	f	\N
164733	peleta	peleta =peleta  (ImpPrSg2  >peletama !27_V	et	f	\N
164747	sõnakasutust	sõnakasutust =tust  (SgN  >sõna+kasu+tust !22_S	et	f	\N
164748	sõnakasutust	sõnakasutust =kasutu  (SgEl  >sõna+kasutu !01_A	et	f	\N
164749	sõnakasutust	"sõna+kasutu %kasu  )TU2_kA  <sõna+kasu ;17_S	et	f	\N
164750	sõnakasutust	sõnakasutust =kasutus  (SgP  >sõna+kasutus !11_S	et	f	\N
164751	sõnakasutust	"sõna+kasutus %kasu  )TUS2_aS  <sõna+kasu ;17_S	et	f	\N
164761	27-aastane	-aastane =aastane  (SgN  >-aastane !12~10_A	et	f	\N
164762	27-aastane	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
164770	informaalse	?informaalse =informaalse  (SgG  >informaalne !02_A	et	f	\N
164771	informaalse	?informaalse =informaalse  (PlP  >informaals !22_S	et	f	\N
164774	õ-kasutamine	õ-kasutamine =kasutamine  (SgN  >õ-kasutamine !12_S	et	f	\N
164775	õ-kasutamine	"õ-kasutamine %kasuta  )MINE_vS  <õ-kasutama ;27_V	et	f	\N
164791	pildistamisele	pildistamisele =pildistamise  (SgAll  >pildistamine !12_S	et	f	\N
164792	pildistamisele	"pildistamine %pildista  )MINE_vS  <pildistama ;27_V	et	f	\N
164804	põhjustatuteks	põhjustatuteks =põhjustatu  (PlTr  >põhjustatu !01_S	et	f	\N
164805	põhjustatuteks	"põhjustatu %põhjusta  )TU1_vS  <põhjustama ;27_V	et	f	\N
164809	pp	### pp	et	f	\N
164819	imisele	?imisele =imise  (SgAll  >imine !10_A	et	f	\N
164820	imisele	?imisele =imisele  (PlP  >imisel !19_S	et	f	\N
164832	vigane	vigane =vigane  (SgN  >vigane !10_AS	et	f	\N
164833	vigane	"vigane %viga  )NE_aA  <viga ;18_S	et	f	\N
164834	printtimisele	?printtimisele =printtimise  (SgAll  >printtimine !12_S	et	f	\N
164835	kirjapilti	kirjapilti =pilti  (SgP  >kirja+pilt !22_S	et	f	\N
164836	kirjapilti	kirjapilti =pilti  (SgAdt  >kirja+pilt !22_S	et	f	\N
164837	segaseks	segaseks =segase  (SgTr  >segane !10_A	et	f	\N
164838	segaseks	segaseks =seks  (SgN  >sega+seks !22_S	et	f	\N
164845	klusiili	klusiili =klusiili  (SgG  >klusiil !22_S	et	f	\N
164846	klusiili	klusiili =klusiili  (SgP  >klusiil !22_S	et	f	\N
164847	klusiili	klusiili =klusiili  (SgAdt  >klusiil !22_S	et	f	\N
164857	enamuses	enamuses =enamuse  (SgIn  >enamus !11_S	et	f	\N
164858	enamuses	"enamus %enama  )US_aS  <enam ;02_A	et	f	\N
164859	enamuses	enamuses =use  (PlIn  >enam+usk !22_S	et	f	\N
164868	käsits	?käsits =käsits  (SgN  >käsits !02_S	et	f	\N
164869	märkima	märkima =märki  (Sup  >märkima !28_V	et	f	\N
164870	märkima	märkima =ima  (SgN  >märk+ima !17_S	et	f	\N
164871	märkima	märkima =ima  (SgG  >märk+ima !17_S	et	f	\N
164872	märkima	märkima =ima  (SgP  >märk+ima !17_S	et	f	\N
164874	kirjutajat	kirjutajat =kirjutaja  (SgP  >kirjutaja !01_S	et	f	\N
164875	kirjutajat	"kirjutaja %kirjuta  )JA_vS  <kirjutama ;27_V	et	f	\N
164877	kõnekeele	kõnekeele =kee  (SgAll  >kõne+kesi !15_S	et	f	\N
164878	kõnekeele	kõnekeele =kee  (SgAll  >kõne+kee !26_S	et	f	\N
164879	kõnekeele	kõnekeele =keele  (SgG  >kõne+keel !13_S	et	f	\N
164880	käsitse	käsitse =käsitse  (IndPrPs_  >käsitsema !27_V	et	f	\N
164881	käsitse	käsitse =käsitse  (ImpPrSg2  >käsitsema !27_V	et	f	\N
164891	kõnekeel	kõnekeel =kee  (SgAd  >kõne+kesi !15_S	et	f	\N
164892	kõnekeel	kõnekeel =kee  (SgAd  >kõne+kee !26_S	et	f	\N
164893	kõnekeel	kõnekeel =keel  (SgN  >kõne+keel !13_S	et	f	\N
164953	piltistan	?piltistan =piltista  (IndPrSg1  >piltistama !27_V	et	f	\N
164954	piltistan	?piltistan =piltistan  (SgN  >piltistan !19_S	et	f	\N
164955	piltistan	?piltistan =istan  (SgN  >pilt+istan !02_S	et	f	\N
164965	fimi	?fimi =fimi  (SgN  >fimi !17_S	et	f	\N
164966	fimi	?fimi =fimi  (SgG  >fimi !17_S	et	f	\N
164967	fimi	?fimi =fimi  (SgP  >fimi !17_S	et	f	\N
164968	fimi	?fimi =fimi  (IndPrPs_  >fimima !27_V	et	f	\N
164969	fimi	?fimi =fimi  (ImpPrSg2  >fimima !27_V	et	f	\N
164976	pildisdama	?pildisdama =pildisdama  (SgG  >pildisdam !02_A	et	f	\N
164979	miksima	?miksima =miksi  (Sup  >miksima !28_V	et	f	\N
164980	miksima	?miksima =miksima  (SgG  >miksim !02_A	et	f	\N
164983	jättaks	?jättaks =jätta  (KndPrPs  >jättama !29_V	et	f	\N
164990	kätlini	?kätlini =kätli  (SgTer  >kättel !02_S	et	f	\N
164991	kätlini	?kätlini =kätlini  (SgG  >kätlin !02_S	et	f	\N
165012	tunnega	### tunnega	et	f	\N
165045	rahvastele	rahvastele =rahvas  (PlAll  >rahvas !07_S	et	f	\N
165046	rahvastele	rahvastele =rahvas  (PlAll  >rahvane !10_A	et	f	\N
165047	rahvastele	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
165051	arhaiiist	?arhaiiist =arhaiii  (SgEl  >arhaiii !26_S	et	f	\N
165052	arhaiiist	?arhaiiist =arhaiiist  (SgN  >arhaiiist !22_S	et	f	\N
165053	rahvatoidust	rahvatoidust =toidu  (SgEl  >rahva+toit !22_S	et	f	\N
165054	rahvatoidust	rahvatoidust =toidus  (SgP  >rahva+toidus !09_S	et	f	\N
165055	rahvatoidust	rahvatoidust =toidus  (SgP  >rahva+toidune !10_A	et	f	\N
165056	rahvatoidust	"rahva+toidune %toidu  )NE_aA  <rahva+toit ;22_S	et	f	\N
165078	vastsündinu	vastsündinu =sündinu  (SgN  >vast+sündinu !01_S	et	f	\N
165079	vastsündinu	vastsündinu =sündinu  (SgG  >vast+sündinu !01_S	et	f	\N
165099	reegivärss	?reegivärss =givärss  (SgN  >ree+givärss !22_S	et	f	\N
164772	kõnekeelele	kõnekeelele =keele  (SgAll  >kõne+keel !13_S	et	f	\N
164773	kõnekeelele	kõnekeelele =keele  (PlAll  >kõne+keeld !22_S	et	f	\N
164811	avatele	avatele =avatele  (IndPrPs_  >avatelema !36_V	et	f	\N
164812	avatele	avatele =avatele  (ImpPrSg2  >avatelema !36_V	et	f	\N
164822	jä	### jä	et	f	\N
164824	ebakindlusel	ebakindlusel =kindluse  (SgAd  >eba+kindlus !11~09_S	et	f	\N
164825	ebakindlusel	"eba+kindlus %kindla  )US_aS  <eba+kindel ;02_A	et	f	\N
164842	hooletusveaga	?hooletusveaga =hooletusvea  (SgKom  >hooletusvea !26_S	et	f	\N
164843	hooletusveaga	?hooletusveaga =tusvea  (SgKom  >hoole+tusvea !26_S	et	f	\N
164844	hooletusveaga	?hooletusveaga =letusvea  (SgKom  >hoo+letusvea !26_S	et	f	\N
164865	algu	algu =algu  (SgG  >alg !22_S	et	f	\N
164866	algu	algu =algu  (SgP  >alg !22_S	et	f	\N
164867	algu	algu =algu  (SgAdt  >alg !22_S	et	f	\N
164887	abimäärsõnade	### abimäärsõnade	et	f	\N
164889	t-d	t-d =t  (SgP  >t !xx_Q	et	f	\N
164890	t-d	t-d =t  (PlN  >t !xx_Q	et	f	\N
164897	työ	### työ	et	f	\N
164921	kõnekeelest	kõnekeelest =keele  (SgEl  >kõne+keel !13_S	et	f	\N
164922	kõnekeelest	kõnekeelest =keele  (PlEl  >kõne+keeld !22_S	et	f	\N
164923	kõnekeelest	kõnekeelest =keeles  (SgP  >kõne+keelene !10_A	et	f	\N
164924	kõnekeelest	"kõne+keelene %keele  )NE_aA  <kõne+keel ;13_S	et	f	\N
164925	võimalikust	võimalikust =võimaliku  (SgEl  >võimalik !25_A	et	f	\N
164926	võimalikust	võimalikust =võimalikus  (SgP  >võimalikus !11?09_S	et	f	\N
164927	võimalikust	"võimalikus %võimaliku  )US_aS  <võimalik ;25_A	et	f	\N
164939	hooletusvea	?hooletusvea =hooletusvea  (SgN  >hooletusvea !26_S	et	f	\N
164940	hooletusvea	?hooletusvea =hooletusvea  (SgG  >hooletusvea !26_S	et	f	\N
164941	hooletusvea	?hooletusvea =tusvea  (SgN  >hoole+tusvea !26_S	et	f	\N
164942	hooletusvea	?hooletusvea =tusvea  (SgG  >hoole+tusvea !26_S	et	f	\N
164943	hooletusvea	?hooletusvea =letusvea  (SgN  >hoo+letusvea !26_S	et	f	\N
164944	hooletusvea	?hooletusvea =letusvea  (SgG  >hoo+letusvea !26_S	et	f	\N
164981	kahtteist	kahtteist =te  (PlEl  >kaht+tee !26_S	et	f	\N
164982	kahtteist	kahtteist =teist  (SgN  >kaht+teist !22_S	et	f	\N
164986	onju	?onju =onju  (SgN  >onju !16_S	et	f	\N
164987	onju	?onju =onju  (SgG  >onju !16_S	et	f	\N
164988	onju	?onju =onju  (IndPrPs_  >onjuma !27_V	et	f	\N
164989	onju	?onju =onju  (ImpPrSg2  >onjuma !27_V	et	f	\N
164992	joua	?joua =joua  (SgN  >joua !16_S	et	f	\N
164993	joua	?joua =joua  (SgG  >joua !16_S	et	f	\N
165004	kontroltööle	?kontroltööle =kontroltöö  (SgAll  >kontroltöö !26_S	et	f	\N
165005	kontroltööle	?kontroltööle =kontroltööle  (SgN  >kontroltööle !16_S	et	f	\N
165006	kontroltööle	?kontroltööle =kontroltööle  (SgG  >kontroltööle !16_S	et	f	\N
165007	kontroltööle	?kontroltööle =kontroltööle  (PlP  >kontroltööl !22_S	et	f	\N
165008	kontroltööle	?kontroltööle =roltöö  (SgAll  >kont+roltöö !26_S	et	f	\N
165009	kontroltööle	?kontroltööle =roltööle  (SgN  >kont+roltööle !16_S	et	f	\N
165010	kontroltööle	?kontroltööle =roltööle  (SgG  >kont+roltööle !16_S	et	f	\N
165011	kontroltööle	?kontroltööle =roltööle  (PlP  >kont+roltööl !22_S	et	f	\N
165013	ülepingutan	?ülepingutan =ülepinguta  (IndPrSg1  >ülepingutama !27_V	et	f	\N
165014	ülepingutan	?ülepingutan =ülepingutan  (SgN  >ülepingutan !19_S	et	f	\N
165015	ülepingutan	?ülepingutan =utan  (SgN  >üle+ping+utan !02_S	et	f	\N
165016	ülepingutan	?ülepingutan =pingutan  (SgN  >üle+pingutan !19_S	et	f	\N
165024	vaenelaps	?vaenelaps =vaenelaps  (SgN  >vaenelaps !22_S	et	f	\N
165025	vaenelaps	?vaenelaps =nelaps  (SgN  >vae+nelaps !02_S	et	f	\N
165034	päevasse	päevasse =päeva  (SgIll  >päev !22_S	et	f	\N
165035	päevasse	päevasse =asse  (PlP  >päev+ass !22_S	et	f	\N
165036	toome	toome =too  (IndPrPl1  >tooma !38_V	et	f	\N
165037	toome	toome =toome  (SgG  >toom !22_S	et	f	\N
165038	toome	toome =toome  (SgP  >toom !22_S	et	f	\N
165039	toome	toome =toome  (SgAdt  >toom !22_S	et	f	\N
165040	toome	toome =toome  (PlP  >toom !22_S	et	f	\N
165057	pitsaid	?pitsaid =pitsai  (PlN  >pitsai !26_S	et	f	\N
165058	pitsaid	?pitsaid =pitsai  (SgP  >pitsai !26_S	et	f	\N
165059	pitsaid	?pitsaid =pitsaid  (SgN  >pitsaid !22_S	et	f	\N
165060	pitsaid	?pitsaid =aid  (SgN  >pits+aid !22_S	et	f	\N
165063	itaaliast	?itaaliast =itaalia  (SgEl  >itaalia !01_S	et	f	\N
165064	itaaliast	?itaaliast =itaalias  (SgP  >itaalias !11_S	et	f	\N
165071	ammusest	ammusest =ammuse  (SgEl  >ammune !10_A	et	f	\N
165072	ammusest	"ammune %ammu  )NE_aA  <amb ;22_S	et	f	\N
165090	üldlaulupeol	üldlaulupeol =peo  (SgAd  >üld+laulu+pidu !18_S	et	f	\N
165091	üldlaulupeol	üldlaulupeol =peo  (SgAd  >üld+laulu+peo !26_S	et	f	\N
165110	rahvuslilkku	?rahvuslilkku =rahvuslilkku  (IndPrPs_  >rahvuslilkkuma !27_V	et	f	\N
165111	rahvuslilkku	?rahvuslilkku =rahvuslilkku  (ImpPrSg2  >rahvuslilkkuma !27_V	et	f	\N
165112	rahvuslilkku	?rahvuslilkku =lilkku  (SgN  >rahvus+lilkku !01_S	et	f	\N
165113	rahvuslilkku	?rahvuslilkku =lilkku  (SgG  >rahvus+lilkku !01_S	et	f	\N
165114	rahvuslilkku	?rahvuslilkku =slilkku  (SgN  >rahvu+slilkku !01_S	et	f	\N
165115	rahvuslilkku	?rahvuslilkku =slilkku  (SgG  >rahvu+slilkku !01_S	et	f	\N
164917	materiaali	?materiaali =materiaali  (IndPrPs_  >materiaalima !28_V	et	f	\N
164918	materiaali	?materiaali =materiaali  (ImpPrSg2  >materiaalima !28_V	et	f	\N
164932	mõjutatud	mõjutatud =mõjuta  (PtsPtIps  >mõjutama !27_V	et	f	\N
164933	mõjutatud	mõjutatud =mõjutatu  (PlN  >mõjutatu !01_S	et	f	\N
164934	mõjutatud	"mõjutatu %mõjuta  )TU1_vS  <mõjutama ;27_V	et	f	\N
164935	mõjutatud	mõjutatud =mõjutatud  (ID  >mõjutatud !41_A	et	f	\N
164936	mõjutatud	"mõjutatud %mõjuta  )TUD_vA  <mõjutama ;27_V	et	f	\N
164937	muuten	?muuten =muute  (IndPrSg1  >muutema !27_V	et	f	\N
164938	muuten	?muuten =muuten  (SgN  >muuten !02_S	et	f	\N
164948	korrektselt	korrektselt =korrektse  (SgAbl  >korrektne !02_A	et	f	\N
164949	korrektselt	korrektselt =korrektselt  (ID  >korrektselt !41_D	et	f	\N
164950	korrektselt	"korrektselt %korrektse  )LT_mD  <korrektne ;02_A	et	f	\N
164957	printi	?printi =printi  (ID  >printi !41_D	et	f	\N
164958	printi	?printi =printi  (SgP  >print !22_S	et	f	\N
164959	printi	?printi =printi  (SgAdt  >print !22_S	et	f	\N
164960	tutavatele	?tutavatele =tutava  (PlAll  >tutava !01_S	et	f	\N
164961	tutavatele	?tutavatele =tutava  (PlAll  >tutav !02_A	et	f	\N
164962	tutavatele	?tutavatele =tutavate  (PlAll  >tutavatt !22_S	et	f	\N
164963	tutavatele	?tutavatele =tutavatele  (IndPrPs_  >tutavatelema !36_V	et	f	\N
164964	tutavatele	?tutavatele =tutavatele  (ImpPrSg2  >tutavatelema !36_V	et	f	\N
164970	yks	?yks =yks  (SgN  >yks !22_S	et	f	\N
164984	jättan	?jättan =jätta  (IndPrSg1  >jättama !29_V	et	f	\N
164985	jättan	?jättan =jättan  (SgN  >jättan !02_S	et	f	\N
165061	pitsa	pitsa =pitsa  (SgN  >pitsa !16_S	et	f	\N
165062	pitsa	pitsa =pitsa  (SgG  >pitsa !16_S	et	f	\N
165067	selekteerimine	selekteerimine =selekteerimine  (SgN  >selekteerimine !12_S	et	f	\N
165068	selekteerimine	"selekteerimine %selekteeri  )MINE_vS  <selekteerima ;28_V	et	f	\N
165069	õigeusulised	õigeusulised =usulise  (PlN  >õige+usuline !12_A	et	f	\N
165070	õigeusulised	"õige+usuline %usu  )LINE_aA  <õige+usk ;22_S	et	f	\N
165073	ninq	?ninq =ninq  (SgN  >ninq !22_S	et	f	\N
165080	ilmale	ilmale =ilma  (SgAll  >ilm !22_S	et	f	\N
165081	ilmale	ilmale =ale  (SgN  >ilm+ale !16_S	et	f	\N
165082	ilmale	ilmale =ale  (SgG  >ilm+ale !16_S	et	f	\N
165083	l869a	la =la  (SgN  >la !26_S	et	f	\N
165084	l869a	la =la  (SgG  >la !26_S	et	f	\N
165092	4esti	?esti =esti  (SgN  >esti !16_S	et	f	\N
165093	4esti	?esti =esti  (SgG  >esti !16_S	et	f	\N
165094	4esti	?esti =esti  (SgG  >est !22_S	et	f	\N
165095	4esti	?esti =esti  (SgP  >est !22_S	et	f	\N
165096	4esti	?esti =esti  (SgAdt  >est !22_S	et	f	\N
165097	4esti	?esti =esti  (IndPrPs_  >estima !28_V	et	f	\N
165098	4esti	?esti =esti  (ImpPrSg2  >estima !28_V	et	f	\N
165100	rahvusärkami	?rahvusärkami =rahvusärkami  (SgG  >rahvusärkam !02_A	et	f	\N
165101	rahvusärkami	?rahvusärkami =ärkami  (SgN  >rahvus+ärkami !01_S	et	f	\N
165102	rahvusärkami	?rahvusärkami =ärkami  (SgG  >rahvus+ärkami !01_S	et	f	\N
165103	rahvusärkami	?rahvusärkami =ärkami  (SgG  >rahvus+ärkam !02_A	et	f	\N
165104	rahvusärkami	?rahvusärkami =särkami  (SgN  >rahvu+särkami !01_S	et	f	\N
165105	rahvusärkami	?rahvusärkami =särkami  (SgG  >rahvu+särkami !01_S	et	f	\N
165106	rahvusärkami	?rahvusärkami =särkami  (SgG  >rahvu+särkam !02_A	et	f	\N
165118	taassündi	taassündi =sündi  (SgP  >taas+sünd !22_S	et	f	\N
165119	taassündi	taassündi =sündi  (SgAdt  >taas+sünd !22_S	et	f	\N
165131	võõrapäraseid	võõrapäraseid =pärase  (PlP  >võõra+pärane !10_A	et	f	\N
165135	võõrapäraseid	"võõra+pärane %pära  )NE_aA  <võõra+pära ;17_S	et	f	\N
165152	popkultuuri	popkultuuri =kultuuri  (SgG  >pop+kultuur !22_S	et	f	\N
165153	popkultuuri	popkultuuri =kultuuri  (SgP  >pop+kultuur !22_S	et	f	\N
165154	popkultuuri	popkultuuri =kultuuri  (SgAdt  >pop+kultuur !22_S	et	f	\N
165164	ste	### ste	et	f	\N
165167	luli	?luli =luli  (SgN  >luli !17_S	et	f	\N
165168	luli	?luli =luli  (SgG  >luli !17_S	et	f	\N
165169	luli	?luli =luli  (SgP  >luli !17_S	et	f	\N
165170	luli	?luli =luli  (IndPrPs_  >lulima !27_V	et	f	\N
165171	luli	?luli =luli  (ImpPrSg2  >lulima !27_V	et	f	\N
165173	ulii	?ulii =ulii  (SgN  >ulii !26_S	et	f	\N
165174	ulii	?ulii =ulii  (SgG  >ulii !26_S	et	f	\N
165197	iiv	?iiv =iiv  (SgN  >iiv !22_S	et	f	\N
165205	hi	### hi	et	f	\N
165206	ndr	### ndr	et	f	\N
165228	tege	?tege =tege  (SgN  >tege !16_S	et	f	\N
165229	tege	?tege =tege  (SgG  >tege !16_S	et	f	\N
165233	ts	### ts	et	f	\N
165235	lühik	?lühik =lühik  (SgN  >lühik !02_S	et	f	\N
165250	gab	### gab	et	f	\N
165291	pik	### pik	et	f	\N
165297	viim	?viim =viim  (SgN  >viim !22_S	et	f	\N
165347	eets	?eets =eets  (SgN  >eets !22_S	et	f	\N
165352	tõ	### tõ	et	f	\N
165354	oog	?oog =oog  (SgN  >oog !22_S	et	f	\N
165374	õppetööd	õppetööd =töö  (PlN  >õppe+töö !26_S	et	f	\N
165375	õppetööd	õppetööd =töö  (SgP  >õppe+töö !26_S	et	f	\N
165384	30-aastasena	-aastasena =aastase  (SgEs  >-aastane !12~10_A	et	f	\N
165385	30-aastasena	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
165075	kodu-	kodu- =kodu  (SgN  >kodu !17_S	et	f	\N
165076	kodu-	kodu- =kodu  (SgG  >kodu !17_S	et	f	\N
165077	kodu-	kodu- =kodu  (SgP  >kodu !17_S	et	f	\N
165088	toimuval	toimuval =toimuva  (SgAd  >toimuv !02_A	et	f	\N
165089	toimuval	"toimuv %toimu  )V_vA  <toimuma ;27_V	et	f	\N
165107	taasiseisvuse	?taasiseisvuse =taasiseisvuse  (SgG  >taasiseisvus !11~09_S	et	f	\N
165108	taasiseisvuse	?taasiseisvuse =isvuse  (SgG  >taas+ise+isvus !11~09_S	et	f	\N
165109	taasiseisvuse	?taasiseisvuse =iseisvuse  (SgG  >taas+iseisvus !11_S	et	f	\N
165127	esimestes	esimestes =esimes  (PlIn  >esimene !12_OP	et	f	\N
165128	esimestes	esimestes =meste  (PlIn  >esi+mest !22_S	et	f	\N
165129	eriliseid	?eriliseid =erilisei  (PlN  >erilisei !26_S	et	f	\N
165130	eriliseid	?eriliseid =erilisei  (SgP  >erilisei !26_S	et	f	\N
165137	euroviisionil	?euroviisionil =euroviisioni  (SgAd  >euroviision !19~02_S	et	f	\N
165138	euroviisionil	?euroviisionil =euroviisioni  (SgAd  >euroviisioni !16_S	et	f	\N
165139	euroviisionil	?euroviisionil =euroviisionil  (SgN  >euroviisionil !02_S	et	f	\N
165140	euroviisionil	?euroviisionil =oni  (SgAd  >euro+viisi+oni !17_S	et	f	\N
165141	euroviisionil	?euroviisionil =ioni  (SgAd  >euro+viis+ioni !16_S	et	f	\N
165142	euroviisionil	?euroviisionil =ioni  (SgAd  >euro+viis+ion !22_S	et	f	\N
165143	euroviisionil	?euroviisionil =viisioni  (SgAd  >euro+viision !19~02_S	et	f	\N
165144	euroviisionil	?euroviisionil =viisioni  (SgAd  >euro+viisioni !16_S	et	f	\N
165145	euroviisionil	?euroviisionil =viisionil  (SgN  >euro+viisionil !02_S	et	f	\N
165157	essed	?essed =esse  (PlN  >esne !02_A	et	f	\N
165158	essed	?essed =esse  (PlN  >esse !06_S	et	f	\N
165159	essed	?essed =esse  (IndPrSg2  >essema !27_V	et	f	\N
165165	du	### du	et	f	\N
165176	mi	mi =mi  (SgN  >mi !26_S	et	f	\N
165177	mi	mi =mi  (SgG  >mi !26_S	et	f	\N
165178	unnu	?unnu =unnu  (SgN  >unnu !16_S	et	f	\N
165179	unnu	?unnu =unnu  (SgG  >unnu !16_S	et	f	\N
165180	unnu	?unnu =unnu  (IndPrPs_  >unnuma !27_V	et	f	\N
165181	unnu	?unnu =unnu  (ImpPrSg2  >unnuma !27_V	et	f	\N
165184	muin	?muin =muin  (SgN  >muin !22_S	et	f	\N
165187	li	### li	et	f	\N
165189	ud	### ud	et	f	\N
165191	iku	?iku =iku  (SgN  >iku !16_S	et	f	\N
165192	iku	?iku =iku  (SgG  >iku !16_S	et	f	\N
165193	iku	?iku =iku  (SgG  >ikk !22_S	et	f	\N
165194	iku	?iku =iku  (IndPrPs_  >ikuma !27_V	et	f	\N
165195	iku	?iku =iku  (ImpPrSg2  >ikuma !27_V	et	f	\N
165196	pri	### pri	et	f	\N
165202	aso	?aso =aso  (SgN  >aso !17~16_S	et	f	\N
165203	aso	?aso =aso  (SgG  >aso !17~16_S	et	f	\N
165204	aso	?aso =aso  (SgP  >aso !17_S	et	f	\N
165207	hnud	### hnud	et	f	\N
165212	satt	?satt =satt  (SgN  >satt !22_S	et	f	\N
165214	ündmu	?ündmu =ündmu  (SgN  >ündmu !01_S	et	f	\N
165215	ündmu	?ündmu =ündmu  (SgG  >ündmu !01_S	et	f	\N
165216	ündmu	?ündmu =ündmu  (IndPrPs_  >ündmuma !27_V	et	f	\N
165217	ündmu	?ündmu =ündmu  (ImpPrSg2  >ündmuma !27_V	et	f	\N
165220	ili	?ili =ili  (SgN  >ili !17_S	et	f	\N
165221	ili	?ili =ili  (SgG  >ili !17_S	et	f	\N
165222	ili	?ili =ili  (SgP  >ili !17_S	et	f	\N
165223	ili	?ili =ili  (IndPrPs_  >ilima !27_V	et	f	\N
165224	ili	?ili =ili  (ImpPrSg2  >ilima !27_V	et	f	\N
165234	ükk	?ükk =ükk  (SgN  >ükk !22_S	et	f	\N
165247	hk	### hk	et	f	\N
165251	tä	### tä	et	f	\N
165262	tul	### tul	et	f	\N
165280	juh	?juh =juh  (ID  >juh !41_I	et	f	\N
165292	pili	?pili =pili  (SgN  >pili !17_S	et	f	\N
165293	pili	?pili =pili  (SgG  >pili !17_S	et	f	\N
165294	pili	?pili =pili  (SgP  >pili !17_S	et	f	\N
165295	pili	?pili =pili  (IndPrPs_  >pilima !27_V	et	f	\N
165296	pili	?pili =pili  (ImpPrSg2  >pilima !27_V	et	f	\N
165303	ikpil	?ikpil =ikpi  (SgAd  >ikpi !16_S	et	f	\N
165304	ikpil	?ikpil =ikpi  (SgAd  >ikp !22_S	et	f	\N
165321	nilin	?nilin =nili  (IndPrSg1  >nilima !27_V	et	f	\N
165322	nilin	?nilin =nilin  (SgN  >nilin !02_S	et	f	\N
165325	ttava	?ttava =ttava  (SgN  >ttava !17_S	et	f	\N
165326	ttava	?ttava =ttava  (SgG  >ttava !17_S	et	f	\N
165327	ttava	?ttava =ttava  (SgP  >ttava !17_S	et	f	\N
165328	ttava	?ttava =ttava  (IndPrPs_  >ttavama !27_V	et	f	\N
165329	ttava	?ttava =ttava  (ImpPrSg2  >ttavama !27_V	et	f	\N
165346	lli	### lli	et	f	\N
165351	kum	### kum	et	f	\N
165401	sõnaraamutu	sõnaraamutu =raamutu  (SgN  >sõna+raamutu !01_AS	et	f	\N
165402	sõnaraamutu	sõnaraamutu =raamutu  (SgG  >sõna+raamutu !01_AS	et	f	\N
165432	häälikuühendid	?häälikuühendid =häälikuühendi  (PlN  >häälikuühent !22_S	et	f	\N
165433	häälikuühendid	?häälikuühendid =häälikuühendi  (IndPrSg2  >häälikuühentima !28_V	et	f	\N
165451	jõudne	?jõudne =jõudne  (SgN  >jõudne !02_A	et	f	\N
165452	jõudne	?jõudne =jõudne  (PlP  >jõudn !22_S	et	f	\N
165453	jõudne	?jõudne =jõudne  (IndPrPs_  >jõudnema !27_V	et	f	\N
165454	jõudne	?jõudne =jõudne  (ImpPrSg2  >jõudnema !27_V	et	f	\N
165466	valgas	?valgas =valga  (SgIn  >valga !16_S	et	f	\N
165087	põlvesse	põlvesse =põlve  (PlIll  >põlv !22_S	et	f	\N
165125	põliseid	põliseid =põlise  (PlP  >põline !10_A	et	f	\N
165126	põliseid	"põline %põli  )NE_aA  <põli ;24_S	et	f	\N
165136	lauljade	### lauljade	et	f	\N
165146	üldistamisega	üldistamisega =üldistamise  (SgKom  >üldistamine !12_S	et	f	\N
165147	üldistamisega	"üldistamine %üldista  )MINE_vS  <üldistama ;27_V	et	f	\N
165148	traditsioonilise	traditsioonilise =traditsioonilise  (SgG  >traditsiooniline !12_A	et	f	\N
165149	traditsioonilise	"traditsiooniline %traditsiooni  )LINE_aA  <traditsioon ;22_S	et	f	\N
165160	arvestuse	arvestuse =arvestuse  (SgG  >arvestus !11_S	et	f	\N
165161	arvestuse	"arvestus %arvesta  )US_vS  <arvestama ;27_V	et	f	\N
165162	uisten	?uisten =uiste  (IndPrSg1  >uistema !27_V	et	f	\N
165163	uisten	?uisten =uisten  (SgN  >uisten !02_S	et	f	\N
165166	stab	### stab	et	f	\N
165186	up	### up	et	f	\N
165198	liikud	?liikud =liiku  (PlN  >liiku !16_S	et	f	\N
165199	ndi	### ndi	et	f	\N
165201	pü	### pü	et	f	\N
165208	hiidud	?hiidud =hiidu  (PlN  >hiidu !16_S	et	f	\N
165209	hiidud	?hiidud =hiidu  (IndPrSg2  >hiiduma !27_V	et	f	\N
165210	hiidud	?hiidud =hiidud  (ID  >hiidud !41_A	et	f	\N
165218	lüh	?lüh =lüh  (ID  >lüh !41_I	et	f	\N
165227	üh	?üh =üh  (ID  >üh !41_I	et	f	\N
165232	rv	### rv	et	f	\N
165244	pid	### pid	et	f	\N
165252	rkimi	?rkimi =rkimi  (SgN  >rkimi !17_S	et	f	\N
165253	rkimi	?rkimi =rkimi  (SgG  >rkimi !17_S	et	f	\N
165254	rkimi	?rkimi =rkimi  (SgP  >rkimi !17_S	et	f	\N
165255	rkimi	?rkimi =rkimi  (IndPrPs_  >rkimima !27_V	et	f	\N
165256	rkimi	?rkimi =rkimi  (ImpPrSg2  >rkimima !27_V	et	f	\N
165264	nkr	### nkr	et	f	\N
165265	eetselt	?eetselt =eetse  (SgAbl  >eetne !02_A	et	f	\N
165266	eetselt	?eetselt =eetse  (SgAbl  >eetse !06_S	et	f	\N
165267	eetselt	?eetselt =eetse  (PlAbl  >eets !22_S	et	f	\N
165268	eetselt	?eetselt =eetselt  (ID  >eetselt !41_D	et	f	\N
165290	llalt	?llalt =llalt  (SgN  >llalt !22_S	et	f	\N
165298	er	### er	et	f	\N
165299	rulikul	?rulikul =ruliku  (SgAd  >ruliku !01_S	et	f	\N
165300	rulikul	?rulikul =ruliku  (SgAd  >rulik !02_S	et	f	\N
165301	rulikul	?rulikul =rulikul  (SgN  >rulikul !19_S	et	f	\N
165306	ääb	?ääb =ääb  (SgN  >ääb !22_S	et	f	\N
165307	ikk	?ikk =ikk  (SgN  >ikk !22_S	et	f	\N
165308	etava	?etava =etava  (SgN  >etava !01_S	et	f	\N
165309	etava	?etava =etava  (SgG  >etava !01_S	et	f	\N
165310	etava	?etava =etava  (SgG  >etav !02_A	et	f	\N
165314	rviv	### rviv	et	f	\N
165320	lm	### lm	et	f	\N
165335	tvaata	?tvaata =tvaa  (SgAb  >tvaa !26_S	et	f	\N
165336	tvaata	?tvaata =tvaat  (Inf  >tvaatma !34_V	et	f	\N
165337	tvaata	?tvaata =tvaata  (SgN  >tvaata !16_S	et	f	\N
165338	tvaata	?tvaata =tvaata  (SgG  >tvaata !16_S	et	f	\N
165339	tvaata	?tvaata =tvaata  (IndPrPs_  >tvaatama !27_V	et	f	\N
165340	tvaata	?tvaata =tvaata  (ImpPrSg2  >tvaatama !27_V	et	f	\N
165343	ilmn	?ilmn =ilmn  (SgN  >ilmn !22_S	et	f	\N
165353	mü	### mü	et	f	\N
165372	langetamisele	langetamisele =langetamise  (SgAll  >langetamine !12_S	et	f	\N
165373	langetamisele	"langetamine %langeta  )MINE_vS  <langetama ;27_V	et	f	\N
165376	iseloomustus	iseloomustus =ustu  (SgIn  >ise+loom+ustu !01_S	et	f	\N
165377	iseloomustus	iseloomustus =mustus  (SgN  >ise+loo+mustus !11~09_S	et	f	\N
165378	iseloomustus	"ise+loo+mustus %must  )US_aS  <ise+loo+must ;22_AS	et	f	\N
165379	iseloomustus	iseloomustus =loomustus  (SgN  >ise+loomustus !11_S	et	f	\N
165380	47-aastane	-aastane =aastane  (SgN  >-aastane !12~10_A	et	f	\N
165381	47-aastane	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
165413	tellijatest	tellijatest =tellija  (PlEl  >tellija !01_S	et	f	\N
165414	tellijatest	"tellija %telli  )JA_vS  <tellima ;28_V	et	f	\N
165415	ühildumis-	?ühildumis- =ühildumi  (SgIn  >ühildum !02_A	et	f	\N
165416	ühildumis-	?ühildumis- =ühildumis  (SgN  >ühildumis !09_S	et	f	\N
165461	tööline	tööline =tööline  (SgN  >tööline !12?10_S	et	f	\N
165462	tööline	tööline =ine  (SgN  >tööl+ine !16_S	et	f	\N
165463	tööline	tööline =ine  (SgG  >tööl+ine !16_S	et	f	\N
165464	lammutama	lammutama =lammu  (SupIps  >lammuma !27_V	et	f	\N
165465	lammutama	lammutama =lammuta  (Sup  >lammutama !27_V	et	f	\N
165477	püüdsi	?püüdsi =püüdsi  (ID  >püüdsi !41_D	et	f	\N
165478	püüdsi	?püüdsi =püüdsi  (SgG  >püüds !22_S	et	f	\N
165479	püüdsi	?püüdsi =püüdsi  (SgP  >püüds !22_S	et	f	\N
165480	püüdsi	?püüdsi =püüdsi  (SgAdt  >püüds !22_S	et	f	\N
165481	püüdsi	?püüdsi =püüdsi  (IndPrPs_  >püüdsima !28_V	et	f	\N
165482	püüdsi	?püüdsi =püüdsi  (ImpPrSg2  >püüdsima !28_V	et	f	\N
165508	poijari	?poijari =poijari  (SgN  >poijari !01_S	et	f	\N
165509	poijari	?poijari =poijari  (SgG  >poijari !01_S	et	f	\N
165510	poijari	?poijari =poijari  (SgG  >poijar !02_S	et	f	\N
165511	kompveki	kompveki =kompveki  (SgG  >kompvek !22_S	et	f	\N
165512	kompveki	kompveki =kompveki  (SgP  >kompvek !22_S	et	f	\N
165513	kompveki	kompveki =kompveki  (SgAdt  >kompvek !22_S	et	f	\N
165116	iseisvuse	?iseisvuse =iseisvuse  (SgG  >iseisvus !11_S	et	f	\N
165117	iseisvuse	?iseisvuse =isvuse  (SgG  >ise+isvus !11~09_S	et	f	\N
165122	saamisega	saamisega =saamise  (SgKom  >saamine !12?10_S	et	f	\N
165123	saamisega	"saamine %saa  )MINE_vS  <saama ;37_V	et	f	\N
165124	saamisega	"saamine %saami  )NE_aA  <saam ;22_S	et	f	\N
165132	nimetusi	nimetusi =nimetusi  (PlP  >nimetus !11_S	et	f	\N
165133	nimetusi	"nimetus %nimeta  )US_vS  <nimetama ;27_V	et	f	\N
165134	nimetusi	"nimetus %nime  )TUS2_aS  <nimi ;20_S	et	f	\N
165172	hv	### hv	et	f	\N
165182	rin	### rin	et	f	\N
165190	võ	### võ	et	f	\N
165200	ku	### ku	et	f	\N
165211	ul	### ul	et	f	\N
165213	ik	### ik	et	f	\N
165225	tsa	### tsa	et	f	\N
165226	likum	?likum =likum  (SgN  >likum !02_S	et	f	\N
165230	asega	### asega	et	f	\N
165231	og	### og	et	f	\N
165237	ruv	### ruv	et	f	\N
165238	inu	?inu =inu  (SgN  >inu !17_S	et	f	\N
165239	inu	?inu =inu  (SgG  >inu !17_S	et	f	\N
165240	inu	?inu =inu  (SgP  >inu !17_S	et	f	\N
165241	inu	?inu =inu  (IndPrPs_  >inuma !27_V	et	f	\N
165242	inu	?inu =inu  (ImpPrSg2  >inuma !27_V	et	f	\N
165243	rki	### rki	et	f	\N
165245	rn	### rn	et	f	\N
165248	kir	### kir	et	f	\N
165260	sii	?sii =sii  (SgN  >sii !26_S	et	f	\N
165261	sii	?sii =sii  (SgG  >sii !26_S	et	f	\N
165263	ll	### ll	et	f	\N
165289	kü	### kü	et	f	\N
165305	ag	### ag	et	f	\N
165313	vä	### vä	et	f	\N
165315	aese	?aese =aese  (SgN  >aese !06_S	et	f	\N
165316	aese	?aese =aese  (SgG  >aese !06_S	et	f	\N
165317	aese	?aese =aese  (SgG  >aene !10_A	et	f	\N
165318	aese	?aese =aese  (IndPrPs_  >aesema !28_V	et	f	\N
165319	aese	?aese =aese  (ImpPrSg2  >aesema !28_V	et	f	\N
165324	tõs	### tõs	et	f	\N
165330	vu	### vu	et	f	\N
165331	ikliki	?ikliki =ikliki  (SgN  >ikliki !01_S	et	f	\N
165332	ikliki	?ikliki =ikliki  (SgG  >ikliki !01_S	et	f	\N
165333	ikliki	?ikliki =ikliki  (IndPrPs_  >iklikkima !28_V	et	f	\N
165334	ikliki	?ikliki =ikliki  (ImpPrSg2  >iklikkima !28_V	et	f	\N
165341	toet	?toet =toet  (SgN  >toet !22_S	et	f	\N
165345	llik	### llik	et	f	\N
165370	ai	ai =ai  (ID  >ai !41_I	et	f	\N
165371	ai	ai =ai  (SgN  >ai !22_S	et	f	\N
165396	mõistmisel	mõistmisel =mõistmise  (SgAd  >mõistmine !12?10_S	et	f	\N
165397	mõistmisel	"mõistmine %mõist  )MINE_vS  <mõistma ;34_V	et	f	\N
165408	tellijatega	tellijatega =tellija  (PlKom  >tellija !01_S	et	f	\N
165409	tellijatega	"tellija %telli  )JA_vS  <tellima ;28_V	et	f	\N
165410	andetu	andetu =andetu  (SgN  >andetu !01_A	et	f	\N
165411	andetu	"andetu %ande  )TU2_kA  <anne ;06_S	et	f	\N
165412	andetu	andetu =andetu  (SgG  >andetu !01_A	et	f	\N
165417	rektsioonivigu	?rektsioonivigu =rektsioonivigu  (IndPrPs_  >rektsiooniviguma !27_V	et	f	\N
165418	rektsioonivigu	?rektsioonivigu =rektsioonivigu  (ImpPrSg2  >rektsiooniviguma !27_V	et	f	\N
165434	õu-	õu- =õu  (SgN  >õu !22_S	et	f	\N
165435	õu-	õu- =õu  (SgG  >õud !22_S	et	f	\N
165436	eesmaspäeval	?eesmaspäeval =eesmaspäeva  (SgAd  >eesmaspäeva !16_S	et	f	\N
165437	eesmaspäeval	?eesmaspäeval =eesmaspäeval  (SgN  >eesmaspäeval !02_S	et	f	\N
165438	eesmaspäeval	?eesmaspäeval =maspäeva  (SgAd  >ees+maspäeva !01_S	et	f	\N
165447	plitka	?plitka =plitka  (SgN  >plitka !16_S	et	f	\N
165448	plitka	?plitka =plitka  (SgG  >plitka !16_S	et	f	\N
165449	plitka	?plitka =plitka  (IndPrPs_  >plitkama !29_V	et	f	\N
165450	plitka	?plitka =plitka  (ImpPrSg2  >plitkama !29_V	et	f	\N
165469	la	la =la  (SgN  >la !26_S	et	f	\N
165470	la	la =la  (SgG  >la !26_S	et	f	\N
165473	lapimaa	lapimaa =maa  (SgN  >lapi+maa !26_S	et	f	\N
165474	lapimaa	lapimaa =maa  (SgG  >lapi+maa !26_S	et	f	\N
165483	lootsin	lootsin =loot  (IndIpfSg1  >lootma !34_V	et	f	\N
165484	lootsin	lootsin =lootsi  (IndPrSg1  >lootsima !28_V	et	f	\N
165492	kaheteistkümneni	?kaheteistkümneni =kaheteistkümneni  (SgG  >kaheteistkümnen !02_S	et	f	\N
165493	kaheteistkümneni	?kaheteistkümneni =kümneni  (SgG  >kahe+teist+kümnen !02_S	et	f	\N
165494	kaheteistkümneni	?kaheteistkümneni =teistkümneni  (SgG  >kahe+teistkümnen !19_S	et	f	\N
165495	kaheteistkümneni	?kaheteistkümneni =teistkümneni  (SgP  >kahe+teistkümnen !19_S	et	f	\N
165496	kaheteistkümneni	?kaheteistkümneni =teistkümneni  (SgAdt  >kahe+teistkümnen !19_S	et	f	\N
165524	vepsad	?vepsad =vepsa  (PlN  >vepsa !16_S	et	f	\N
165525	vepsad	?vepsad =vepsa  (IndPrSg2  >vepsama !29_V	et	f	\N
165526	talvised	talvised =talvise  (PlN  >talvine !10_A	et	f	\N
165527	talvised	"talvine %talvi  )NE_aA  <talv ;22_S	et	f	\N
165530	häälikuühendite	?häälikuühendite =häälikuühendi  (IndPrPl2  >häälikuühentima !28_V	et	f	\N
165539	smaspäeval	?smaspäeval =smaspäeva  (SgAd  >smaspäeva !01_S	et	f	\N
165542	korduv	korduv =kordu  (PtsPrPs  >korduma !27_V	et	f	\N
165543	korduv	korduv =korduv  (SgN  >korduv !02_A	et	f	\N
165544	korduv	"korduv %kordu  )V_vA  <korduma ;27_V	et	f	\N
165120	iseseivumise	?iseseivumise =iseseivumise  (SgG  >iseseivumine !12_S	et	f	\N
165121	iseseivumise	?iseseivumise =seivumise  (SgG  >ise+seivumine !12_S	et	f	\N
165150	reegivärsilise	?reegivärsilise =reegivärsilise  (SgG  >reegivärsiline !12_A	et	f	\N
165151	reegivärsilise	?reegivärsilise =givärsilise  (SgG  >ree+givärsiline !12_A	et	f	\N
165155	haigusega	haigusega =haiguse  (SgKom  >haigus !11~09_S	et	f	\N
165156	haigusega	"haigus %haige  )US_aS  <haige ;01_AS	et	f	\N
165175	ab	### ab	et	f	\N
165183	eb	### eb	et	f	\N
165185	hvu	### hvu	et	f	\N
165188	seot	?seot =seot  (SgN  >seot !22_S	et	f	\N
165219	staat	?staat =staat  (SgN  >staat !22_S	et	f	\N
165236	sta	### sta	et	f	\N
165246	kku	### kku	et	f	\N
165249	ld	### ld	et	f	\N
165257	imu	imu =imu  (SgN  >imu !17_S	et	f	\N
165258	imu	imu =imu  (SgG  >imu !17_S	et	f	\N
165259	imu	imu =imu  (SgP  >imu !17_S	et	f	\N
165269	ata	ata =ata  (ID  >ata !41_I	et	f	\N
165270	ata	ata =ata  (IndPrPs_  >atma !35_V	et	f	\N
165271	ata	ata =ata  (ImpPrSg2  >atma !35_V	et	f	\N
165272	unni	?unni =unni  (SgN  >unni !16_S	et	f	\N
165273	unni	?unni =unni  (SgG  >unni !16_S	et	f	\N
165274	unni	?unni =unni  (SgG  >unn !22_S	et	f	\N
165275	unni	?unni =unni  (SgP  >unn !22_S	et	f	\N
165276	unni	?unni =unni  (SgAdt  >unn !22_S	et	f	\N
165277	unni	?unni =unni  (IndPrPs_  >unnima !28_V	et	f	\N
165278	unni	?unni =unni  (ImpPrSg2  >unnima !28_V	et	f	\N
165279	stat	### stat	et	f	\N
165281	pikku	pikku =pikku  (ID  >pikku !41_DK	et	f	\N
165282	pikku	pikku =pikku  (SgP  >pikk !22_S	et	f	\N
165283	pikku	pikku =pikku  (SgP  >pikk !22_AS	et	f	\N
165284	pikku	pikku =pikku  (SgAdt  >pikk !22_S	et	f	\N
165285	pikku	pikku =pikku  (SgAdt  >pikk !22_AS	et	f	\N
165286	pikku	pikku =pikku  (PlP  >pikk !22_S	et	f	\N
165287	pikku	pikku =pikku  (PlP  >pikk !22_AS	et	f	\N
165288	ri	### ri	et	f	\N
165302	ük	### ük	et	f	\N
165311	seetõtt	seetõtt =tõ  (SgP  >see+tõsi !15_S	et	f	\N
165312	seetõtt	seetõtt =tõtt  (SgN  >see+tõtt !22_S	et	f	\N
165323	tte	### tte	et	f	\N
165342	ndrühm	?ndrühm =ndrühm  (SgN  >ndrühm !22_S	et	f	\N
165344	äg	### äg	et	f	\N
165348	udu	udu =udu  (SgN  >udu !17_S	et	f	\N
165349	udu	udu =udu  (SgG  >udu !17_S	et	f	\N
165350	udu	udu =udu  (SgP  >udu !17_S	et	f	\N
165355	kontrastiivlingvistikas	?kontrastiivlingvistikas =kontrastiivlingvistika  (SgIn  >kontrastiivlingvistika !01_S	et	f	\N
165356	kontrastiivlingvistikas	?kontrastiivlingvistikas =kontrastiivlingvistika  (SgIn  >kontrastiivlingvistikas !02_A	et	f	\N
165357	kontrastiivlingvistikas	?kontrastiivlingvistikas =kontrastiivlingvistikas  (SgN  >kontrastiivlingvistikas !02_A	et	f	\N
165358	kontrastiivlingvistikas	?kontrastiivlingvistikas =ivlingvistika  (SgIn  >kontrasti+ivlingvistika !01_S	et	f	\N
165359	kontrastiivlingvistikas	?kontrastiivlingvistikas =ivlingvistika  (SgIn  >kontrasti+ivlingvistikas !02_A	et	f	\N
165360	kontrastiivlingvistikas	?kontrastiivlingvistikas =ivlingvistikas  (SgN  >kontrasti+ivlingvistikas !02_A	et	f	\N
165361	kontrastiivlingvistikas	?kontrastiivlingvistikas =iivlingvistika  (SgIn  >kontrast+iivlingvistika !01_S	et	f	\N
165362	kontrastiivlingvistikas	?kontrastiivlingvistikas =iivlingvistika  (SgIn  >kontrast+iivlingvistikas !02_A	et	f	\N
165363	kontrastiivlingvistikas	?kontrastiivlingvistikas =iivlingvistikas  (SgN  >kontrast+iivlingvistikas !02_A	et	f	\N
165364	kontrastiivlingvistikas	?kontrastiivlingvistikas =stiivlingvistika  (SgIn  >kontra+stiivlingvistika !01_S	et	f	\N
165365	kontrastiivlingvistikas	?kontrastiivlingvistikas =stiivlingvistika  (SgIn  >kontra+stiivlingvistikas !02_A	et	f	\N
165366	kontrastiivlingvistikas	?kontrastiivlingvistikas =stiivlingvistikas  (SgN  >kontra+stiivlingvistikas !02_A	et	f	\N
165367	kontrastiivlingvistikas	?kontrastiivlingvistikas =rastiivlingvistika  (SgIn  >kont+rastiivlingvistika !01_S	et	f	\N
165368	kontrastiivlingvistikas	?kontrastiivlingvistikas =rastiivlingvistika  (SgIn  >kont+rastiivlingvistikas !02_A	et	f	\N
165369	kontrastiivlingvistikas	?kontrastiivlingvistikas =rastiivlingvistikas  (SgN  >kont+rastiivlingvistikas !02_A	et	f	\N
165382	23-aastasena	-aastasena =aastase  (SgEs  >-aastane !12~10_A	et	f	\N
165383	23-aastasena	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
165386	tööpäeviti	?tööpäeviti =tööpäevi  (IndIpfIps  >tööpäevima !28_V	et	f	\N
165387	tööpäeviti	?tööpäeviti =tööpäeviti  (ID  >tööpäeviti !41_D	et	f	\N
165388	tööpäeviti	?tööpäeviti =tööpäeviti  (SgG  >tööpäevitt !22_S	et	f	\N
165389	tööpäeviti	?tööpäeviti =tööpäeviti  (IndPrPs_  >tööpäevittima !28_V	et	f	\N
165390	tööpäeviti	?tööpäeviti =tööpäeviti  (ImpPrSg2  >tööpäevittima !28_V	et	f	\N
165391	tööpäeviti	?tööpäeviti =iti  (SgN  >töö+päev+iti !16_S	et	f	\N
165392	tööpäeviti	?tööpäeviti =iti  (SgG  >töö+päev+iti !16_S	et	f	\N
165393	tööpäeviti	?tööpäeviti =iti  (SgG  >töö+päev+itt !22_S	et	f	\N
165394	tööpäeviti	?tööpäeviti =päeviti  (SgG  >töö+päevit !02_S	et	f	\N
165395	tööpäeviti	?tööpäeviti =päeviti  (SgG  >töö+päevitt !22_S	et	f	\N
165398	prossumi	?prossumi =prossumi  (SgN  >prossumi !01_S	et	f	\N
165399	prossumi	?prossumi =prossumi  (SgG  >prossumi !01_S	et	f	\N
165400	prossumi	?prossumi =prossumi  (SgG  >prossum !02_S	et	f	\N
165403	sobinud	sobinud =sobi  (PtsPtPs  >sobima !27_V	et	f	\N
165404	sobinud	sobinud =sobinu  (PlN  >sobinu !01_S	et	f	\N
165405	sobinud	"sobinu %sobi  )NU_vS  <sobima ;27_V	et	f	\N
165406	sobinud	sobinud =sobinud  (ID  >sobinud !41_A	et	f	\N
165407	sobinud	"sobinud %sobi  )NUD_vA  <sobima ;27_V	et	f	\N
165421	kõnele	kõnele =kõne  (SgAll  >kõne !16_S	et	f	\N
165422	kõnele	kõnele =kõnele  (IndPrPs_  >kõnelema !31~27_V	et	f	\N
165423	kõnele	kõnele =kõnele  (ImpPrSg2  >kõnelema !31~27_V	et	f	\N
165424	kõlaliselt	kõlaliselt =kõlalise  (SgAbl  >kõlaline !12_A	et	f	\N
165425	kõlaliselt	"kõlaline %kõla  )LINE_aA  <kõla ;17_S	et	f	\N
165426	kõlaliselt	kõlaliselt =kõlaliselt  (ID  >kõlaliselt !41_D	et	f	\N
165427	kõlaliselt	"kõlaliselt %kõla  )LISELT_mD  <kõla ;17_S	et	f	\N
165428	kõlaliselt	"kõlaliselt %kõlalise  )LT_mD  <kõlaline ;12_A	et	f	\N
165446	keeraamiplitkaga	?keeraamiplitkaga =keeraamiplitka  (SgKom  >keeraamiplitka !16_S	et	f	\N
165455	lammutavad	lammutavad =lammuta  (IndPrPl3  >lammutama !27_V	et	f	\N
165456	lammutavad	lammutavad =lammutava  (PlN  >lammutav !02_A	et	f	\N
165457	lammutavad	"lammutav %lammu  )TAV_vAS  <lammuma ;27_V	et	f	\N
165458	lammutavad	"lammutav %lammuta  )V_vA  <lammutama ;27_V	et	f	\N
165475	passis	passis =passi  (SgIn  >pass !22_S	et	f	\N
165476	passis	passis =passi  (IndIpfSg3  >passima !28_V	et	f	\N
165490	paroomiga	?paroomiga =paroomi  (SgKom  >paroomi !16_S	et	f	\N
165491	paroomiga	?paroomiga =paroomi  (SgKom  >paroom !22_S	et	f	\N
165501	klausi	?klausi =klausi  (SgN  >klausi !16_S	et	f	\N
165502	klausi	?klausi =klausi  (SgG  >klausi !16_S	et	f	\N
165503	klausi	?klausi =klausi  (SgG  >klaus !22_S	et	f	\N
165504	klausi	?klausi =klausi  (SgP  >klaus !22_S	et	f	\N
165505	klausi	?klausi =klausi  (SgAdt  >klaus !22_S	et	f	\N
165506	klausi	?klausi =klausi  (IndPrPs_  >klausima !28_V	et	f	\N
165507	klausi	?klausi =klausi  (ImpPrSg2  >klausima !28_V	et	f	\N
165514	kuueteistkümneni	?kuueteistkümneni =kuueteistkümneni  (SgG  >kuueteistkümnen !02_S	et	f	\N
165515	kuueteistkümneni	?kuueteistkümneni =kümneni  (SgG  >kuue+teist+kümnen !02_S	et	f	\N
165516	kuueteistkümneni	?kuueteistkümneni =teistkümneni  (SgG  >kuue+teistkümnen !19_S	et	f	\N
165517	kuueteistkümneni	?kuueteistkümneni =teistkümneni  (SgP  >kuue+teistkümnen !19_S	et	f	\N
165518	kuueteistkümneni	?kuueteistkümneni =teistkümneni  (SgAdt  >kuue+teistkümnen !19_S	et	f	\N
165519	kuueteistkümneni	?kuueteistkümneni =eteistkümneni  (SgG  >kuu+eteistkümnen !02_S	et	f	\N
165522	lapimaal	lapimaal =maa  (SgAd  >lapi+maa !26_S	et	f	\N
165523	lapimaal	lapimaal =maal  (SgN  >lapi+maal !22_S	et	f	\N
165533	kirjapildi	kirjapildi =pildi  (SgG  >kirja+pilt !22_S	et	f	\N
165534	kirjapildi	kirjapildi =pildi  (SgP  >kirja+pild !22_S	et	f	\N
165535	kirjapildi	kirjapildi =pildi  (SgAdt  >kirja+pild !22_S	et	f	\N
165545	venela	?venela =venela  (SgN  >venela !01_S	et	f	\N
165546	venela	?venela =venela  (SgG  >venela !01_S	et	f	\N
165555	kahesilbiliste	kahesilbiliste =silbilis  (PlG  >kahe+silbiline !12_A	et	f	\N
165556	kahesilbiliste	"kahe+silbiline %silbi  )LINE_aA  <kahe+silp ;22_S	et	f	\N
165567	lühiajaline	lühiajaline =ajaline  (SgN  >lühi+ajaline !12_A	et	f	\N
165568	lühiajaline	"lühi+ajaline %aja  )LINE_aA  <lühi+aeg ;22_S	et	f	\N
165573	absolutiseerimine	absolutiseerimine =absolutiseerimine  (SgN  >absolutiseerimine !12_S	et	f	\N
165574	absolutiseerimine	"absolutiseerimine %absolutiseeri  )MINE_vS  <absolutiseerima ;28_V	et	f	\N
165594	infinitiivivorm	?infinitiivivorm =infinitiivivorm  (SgN  >infinitiivivorm !22_S	et	f	\N
165600	eitava	eitava =eitava  (SgG  >eitav !02_A	et	f	\N
165601	eitava	"eitav %eita  )V_vA  <eitama ;27_V	et	f	\N
165602	eitava	eitava =tava  (SgN  >ei+tava !17_S	et	f	\N
165603	eitava	eitava =tava  (SgG  >ei+tava !17_S	et	f	\N
165604	eitava	eitava =tava  (SgP  >ei+tava !17_S	et	f	\N
165638	keraamiplitkaga	?keraamiplitkaga =keraamiplitka  (SgKom  >keraamiplitka !16_S	et	f	\N
165639	keraamiplitkaga	?keraamiplitkaga =amiplitka  (SgKom  >kera+amiplitka !16_S	et	f	\N
165680	lalmainitud	?lalmainitud =lalmaini  (PtsPtIps  >lalmainima !28_V	et	f	\N
165681	lalmainitud	?lalmainitud =lalmainitu  (PlN  >lalmainitu !01_A	et	f	\N
165682	lalmainitud	?lalmainitud =lalmainitu  (IndPrSg2  >lalmainituma !27_V	et	f	\N
165683	lalmainitud	?lalmainitud =lalmainitud  (ID  >lalmainitud !41_A	et	f	\N
165692	lühikejuksed	?lühikejuksed =lühikejukse  (PlN  >lühikejukne !02_A	et	f	\N
165694	lühikejuksed	?lühikejuksed =kejukse  (PlN  >lühi+kejukne !02_A	et	f	\N
165695	ühildumisviga	?ühildumisviga =ühildumisvi  (SgKom  >ühildumisv !22_S	et	f	\N
165734	ndevead	?ndevead =ndevea  (PlN  >ndevea !26_S	et	f	\N
165735	ndevead	?ndevead =ndevea  (SgP  >ndevea !26_S	et	f	\N
165736	ndevead	?ndevead =ndevead  (SgN  >ndevead !22_S	et	f	\N
165743	vastusel	vastusel =vastuse  (SgAd  >vastus !09_S	et	f	\N
165744	vastusel	vastusel =use  (PlAd  >vast+usk !22_S	et	f	\N
165749	märgi	märgi =märgi  (SgG  >märk !22_S	et	f	\N
165750	märgi	märgi =märgi  (SgP  >märg !22_AS	et	f	\N
165751	märgi	märgi =märgi  (SgAdt  >märg !22_AS	et	f	\N
165752	märgi	märgi =märgi  (PlP  >märg !22_AS	et	f	\N
165754	märgi	märgi =märgi  (IndPrPs_  >märkima !28_V	et	f	\N
165756	märgi	märgi =märgi  (ImpPrSg2  >märkima !28_V	et	f	\N
165419	interferentsivigu	?interferentsivigu =interferentsivigu  (IndPrPs_  >interferentsiviguma !27_V	et	f	\N
165420	interferentsivigu	?interferentsivigu =interferentsivigu  (ImpPrSg2  >interferentsiviguma !27_V	et	f	\N
165429	paronüümivead	?paronüümivead =paronüümivea  (PlN  >paronüümivea !26_S	et	f	\N
165430	paronüümivead	?paronüümivead =paronüümivea  (SgP  >paronüümivea !26_S	et	f	\N
165431	paronüümivead	?paronüümivead =paronüümivead  (SgN  >paronüümivead !22_S	et	f	\N
165439	kuueks	kuueks =kuue  (SgTr  >kuus !14_N	et	f	\N
165440	kuueks	kuueks =kuue  (SgTr  >kuub !22_S	et	f	\N
165441	võimlast	võimlast =võimla  (SgEl  >võimla !01_S	et	f	\N
165442	võimlast	võimlast =võimlas  (SgP  >võimlane !12?10_S	et	f	\N
165443	võimlast	"võimlane %võimla  )NE_aA  <võimla ;01_S	et	f	\N
165444	santehnikud	?santehnikud =santehniku  (PlN  >santehnik !25_S	et	f	\N
165445	santehnikud	?santehnikud =santehniku  (IndPrSg2  >santehnikuma !27_V	et	f	\N
165459	õudu	õudu =õudu  (SgP  >õud !22_S	et	f	\N
165460	õudu	õudu =õudu  (SgAdt  >õud !22_S	et	f	\N
165485	reklaamteksti	reklaamteksti =teksti  (SgG  >reklaam+tekst !22_S	et	f	\N
165486	reklaamteksti	reklaamteksti =teksti  (SgP  >reklaam+tekst !22_S	et	f	\N
165487	reklaamteksti	reklaamteksti =teksti  (SgAdt  >reklaam+tekst !22_S	et	f	\N
165547	eestla	?eestla =eestla  (SgN  >eestla !01_S	et	f	\N
165548	eestla	?eestla =eestla  (SgG  >eestla !01_S	et	f	\N
165549	eestla	?eestla =eestla  (IndPrPs_  >eestlama !29_V	et	f	\N
165550	eestla	?eestla =eestla  (ImpPrSg2  >eestlama !29_V	et	f	\N
165551	aste	aste =aste  (SgN  >aste !05_S	et	f	\N
165552	aste	aste =aste  (SgN  >aste !06_S	et	f	\N
165553	aste	aste =aste  (SgG  >aste !06_S	et	f	\N
165554	aste	aste =aste  (PlP  >ast !22_S	et	f	\N
165557	nimetavas	nimetavas =nimetava  (SgIn  >nimetav !02_A	et	f	\N
165558	nimetavas	"nimetav %nimeta  )V_vA  <nimetama ;27_V	et	f	\N
165559	nimetavas	nimetavas =tava  (SgIn  >nime+tava !17_S	et	f	\N
165569	väljasõit	väljasõit =õi  (SgP  >väljas+õis !14_S	et	f	\N
165570	väljasõit	väljasõit =sõit  (SgN  >välja+sõit !22_S	et	f	\N
165577	kolmandast	kolmandast =kolmanda  (SgEl  >kolmas !02_O	et	f	\N
165578	kolmandast	kolmandast =kolmandas  (SgP  >kolmandane !12_A	et	f	\N
165587	tingiva	tingiva =tingiva  (SgG  >tingiv !02_A	et	f	\N
165588	tingiva	"tingiv %tingi  )V_vA  <tingima ;28_V	et	f	\N
165589	tingiva	tingiva =iva  (SgN  >ting+iva !17_S	et	f	\N
165590	tingiva	tingiva =iva  (SgG  >ting+iva !17_S	et	f	\N
165591	tingiva	tingiva =iva  (SgP  >ting+iva !17_S	et	f	\N
165605	moodustamisega	moodustamisega =moodustamise  (SgKom  >moodustamine !12_S	et	f	\N
165606	moodustamisega	"moodustamine %moodusta  )MINE_vS  <moodustama ;27_V	et	f	\N
165607	keraamiplitka	?keraamiplitka =keraamiplitka  (SgN  >keraamiplitka !16_S	et	f	\N
165608	keraamiplitka	?keraamiplitka =keraamiplitka  (SgG  >keraamiplitka !16_S	et	f	\N
165609	keraamiplitka	?keraamiplitka =amiplitka  (SgN  >kera+amiplitka !16_S	et	f	\N
165610	keraamiplitka	?keraamiplitka =amiplitka  (SgG  >kera+amiplitka !16_S	et	f	\N
165616	võrut	?võrut =võrut  (SgN  >võrut !02_S	et	f	\N
165626	parafaasia	?parafaasia =parafaasia  (SgN  >parafaasia !01_S	et	f	\N
165627	parafaasia	?parafaasia =parafaasia  (SgG  >parafaasia !01_S	et	f	\N
165628	parafaasia	?parafaasia =faasia  (SgN  >para+faasia !01_S	et	f	\N
165629	parafaasia	?parafaasia =faasia  (SgG  >para+faasia !01_S	et	f	\N
165645	tehaparata	?tehaparata =tehapara  (SgAb  >tehapara !16_S	et	f	\N
165646	tehaparata	?tehaparata =tehaparata  (IndPrPs_  >tehaparatama !27_V	et	f	\N
165647	tehaparata	?tehaparata =tehaparata  (ImpPrSg2  >tehaparatama !27_V	et	f	\N
165654	kirjanditest	kirjanditest =kirjandi  (PlEl  >kirjand !02_S	et	f	\N
165655	kirjanditest	kirjanditest =test  (SgN  >kirjandi+test !22_S	et	f	\N
165659	16-aastased	-aastased =aastase  (PlN  >-aastane !12~10_A	et	f	\N
165660	16-aastased	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
165664	sedaet	?sedaet =sedaet  (SgN  >sedaet !22_S	et	f	\N
165672	panda	panda =pan  (IndPrIps_  >panema !36_V	et	f	\N
165673	panda	panda =panda  (SgN  >panda !16_S	et	f	\N
165674	panda	panda =panda  (SgG  >panda !16_S	et	f	\N
165675	panda	panda =panda  (SgP  >pand !22_S	et	f	\N
165676	panda	panda =panda  (SgAdt  >pand !22_S	et	f	\N
165690	teatr	?teatr =teatr  (SgN  >teatr !22_S	et	f	\N
165723	peatusest	peatusest =peatuse  (SgEl  >peatus !11~09_S	et	f	\N
165724	peatusest	"peatus %peata  )US_vS  <peatama ;27_V	et	f	\N
165725	peatusest	"peatus %pea  )TUS2_aS  <pea ;26_S	et	f	\N
165726	peatusest	peatusest =peatuses  (SgP  >peatusene !12_A	et	f	\N
165727	peatusest	"peatusene %peatuse  )NE_aA  <peatus ;09_S	et	f	\N
165728	peatusest	"peatusene %peatuse  )NE_aA  <peatus ;11_S	et	f	\N
165729	käändeviga	?käändeviga =käändevi  (SgKom  >käändev !02_A	et	f	\N
165730	käändeviga	?käändeviga =evi  (SgKom  >käänd+evi !17_S	et	f	\N
165739	välis-	?välis- =väli  (IndIpfSg3  >välima !27_V	et	f	\N
165740	välis-	?välis- =välis  (SgN  >välis !09_S	et	f	\N
165758	moodustusega	moodustusega =moodustuse  (SgKom  >moodustus !11_S	et	f	\N
165759	moodustusega	"moodustus %moodusta  )US_vS  <moodustama ;27_V	et	f	\N
165786	heme	?heme =heme  (SgN  >heme !16_S	et	f	\N
165467	valgas	?valgas =valga  (IndIpfSg3  >valgama !29_V	et	f	\N
165468	valgas	?valgas =valgas  (SgN  >valgas !07_S	et	f	\N
165471	pimaa	?pimaa =pimaa  (SgN  >pimaa !26_S	et	f	\N
165472	pimaa	?pimaa =pimaa  (SgG  >pimaa !26_S	et	f	\N
165488	väljumine	väljumine =väljumine  (SgN  >väljumine !12_S	et	f	\N
165489	väljumine	"väljumine %välju  )MINE_vS  <väljuma ;27_V	et	f	\N
165497	santa	?santa =santa  (SgN  >santa !16_S	et	f	\N
165498	santa	?santa =santa  (SgG  >santa !16_S	et	f	\N
165499	santa	?santa =santa  (IndPrPs_  >santama !29_V	et	f	\N
165500	santa	?santa =santa  (ImpPrSg2  >santama !29_V	et	f	\N
165520	ükskoik	?ükskoik =ükskoik  (SgN  >ükskoik !22_S	et	f	\N
165521	ükskoik	?ükskoik =koik  (SgN  >üks+koik !22_S	et	f	\N
165528	hmitamine	?hmitamine =hmitamine  (SgN  >hmitamine !12_S	et	f	\N
165529	hmitamine	?hmitamine =hmitamine  (PlP  >hmitamin !19_S	et	f	\N
165531	segiajamine	segiajamine =ajamine  (SgN  >segi+ajamine !12_S	et	f	\N
165532	segiajamine	"segi+ajamine %ajami  )NE_aA  <segi+ajam ;02_S	et	f	\N
165540	interferentsiviga	?interferentsiviga =interferentsivi  (SgKom  >interferentsiv !02_A	et	f	\N
165541	interferentsiviga	?interferentsiviga =ferentsivi  (SgKom  >inter+ferentsiv !02_A	et	f	\N
165571	saabumine	saabumine =saabumine  (SgN  >saabumine !12_S	et	f	\N
165572	saabumine	"saabumine %saabu  )MINE_vS  <saabuma ;27_V	et	f	\N
165575	kaheksandake	?kaheksandake =kaheksandake  (SgN  >kaheksandake !12_S	et	f	\N
165576	kaheksandake	?kaheksandake =ksandake  (SgN  >kahe+ksandake !12_S	et	f	\N
165579	arvsõna	arvsõna =sõna  (SgN  >arv+sõna !17_S	et	f	\N
165580	arvsõna	arvsõna =sõna  (SgG  >arv+sõna !17_S	et	f	\N
165581	arvsõna	arvsõna =sõna  (SgP  >arv+sõna !17_S	et	f	\N
165586	järgarvsõna	### järgarvsõna	et	f	\N
165611	poljari	?poljari =poljari  (SgN  >poljari !01_S	et	f	\N
165612	poljari	?poljari =poljari  (SgG  >poljari !01_S	et	f	\N
165613	poljari	?poljari =poljari  (SgG  >poljar !02_S	et	f	\N
165614	homonüümia	homonüümia =homonüümia  (SgN  >homonüümia !01_S	et	f	\N
165615	homonüümia	homonüümia =homonüümia  (SgG  >homonüümia !01_S	et	f	\N
165617	taga-	taga- =ta  (SgKom  >ta !00_P	et	f	\N
165618	taga-	taga- =taga  (ID  >taga !41_DK	et	f	\N
165619	taga-	taga- =taga  (IndPrPs_  >tagama !27_V	et	f	\N
165620	taga-	taga- =taga  (ImpPrSg2  >tagama !27_V	et	f	\N
165621	eessõna	eessõna =sõna  (SgN  >ees+sõna !17_S	et	f	\N
165622	eessõna	eessõna =sõna  (SgG  >ees+sõna !17_S	et	f	\N
165623	eessõna	eessõna =sõna  (SgP  >ees+sõna !17_S	et	f	\N
165642	pragmaatikavead	?pragmaatikavead =pragmaatikavea  (PlN  >pragmaatikavea !26_S	et	f	\N
165643	pragmaatikavead	?pragmaatikavead =pragmaatikavea  (SgP  >pragmaatikavea !26_S	et	f	\N
165644	pragmaatikavead	?pragmaatikavead =pragmaatikavead  (SgN  >pragmaatikavead !22_S	et	f	\N
165670	loovaid	loovaid =loova  (PlP  >loov !02_A	et	f	\N
165671	loovaid	"loov %loo  )V_vA  <looma ;38_V	et	f	\N
165677	kahtlastest	kahtlastest =kahtlas  (PlEl  >kahtlane !12?10_A	et	f	\N
165678	kahtlastest	kahtlastest =las  (PlEl  >kaht+laps !14_S	et	f	\N
165679	kahtlastest	kahtlastest =laste  (PlEl  >kaht+last !22_S	et	f	\N
165684	veaanalüüsiks	?veaanalüüsiks =veaanalüüsi  (SgTr  >veaanalüüsi !16_S	et	f	\N
165685	veaanalüüsiks	?veaanalüüsiks =veaanalüüsi  (SgTr  >veaanalüüs !22_S	et	f	\N
165686	veaanalüüsiks	?veaanalüüsiks =veaanalüüsi  (KndPrPs  >veaanalüüsima !28_V	et	f	\N
165689	ortograafilised	?ortograafilised =ortograafilise  (PlN  >ortograafiline !12_A	et	f	\N
165698	pikkuselt	pikkuselt =pikkuse  (SgAbl  >pikkus !11~09_S	et	f	\N
165699	pikkuselt	"pikkus %pikk  )US_aS  <pikk ;22_AS	et	f	\N
165700	pikkuselt	pikkuselt =pikkuse  (SgAbl  >pikkune !12~10_A	et	f	\N
165701	pikkuselt	pikkuselt =pikkuselt  (ID  >pikkuselt !41_D	et	f	\N
165702	pikkuselt	"pikkuselt %pikkuse  )LT_mD  <pikkune ;10_A	et	f	\N
165703	pikkuselt	"pikkuselt %pikkuse  )LT_mD  <pikkune ;12_A	et	f	\N
165704	pikkuselt	pikkuselt =use  (PlAbl  >pikk+usk !22_S	et	f	\N
165708	jääniööl	?jääniööl =jääniöö  (SgAd  >jääniöö !26_S	et	f	\N
165709	jääniööl	?jääniööl =jääniööl  (SgN  >jääniööl !22_S	et	f	\N
165711	jääniööl	?jääniööl =niöö  (SgAd  >jää+niöö !26_S	et	f	\N
165713	jääniööl	?jääniööl =niööl  (SgN  >jää+niööl !22_S	et	f	\N
165737	pargus	?pargus =pargu  (IndIpfSg3  >parguma !27_V	et	f	\N
165738	pargus	?pargus =pargus  (SgN  >pargus !11~09_S	et	f	\N
165741	segiajamisest	segiajamisest =ajamise  (SgEl  >segi+ajamine !12_S	et	f	\N
165742	segiajamisest	"segi+ajamine %ajami  )NE_aA  <segi+ajam ;02_S	et	f	\N
165745	lähtealuseks	lähtealuseks =seks  (SgN  >lähte+alu+seks !22_S	et	f	\N
165746	lähtealuseks	lähtealuseks =aluse  (SgTr  >lähte+alus !09_S	et	f	\N
165747	lähtealuseks	lähtealuseks =aluse  (SgTr  >lähte+alune !10_AS	et	f	\N
165748	lähtealuseks	"lähte+alune %alu  )NE_aA  <lähte+alg ;22_S	et	f	\N
165753	kleebi	kleebi =kleebi  (SgG  >kleep !22_S	et	f	\N
165755	kleebi	kleebi =kleebi  (IndPrPs_  >kleepima !28_V	et	f	\N
165757	kleebi	kleebi =kleebi  (ImpPrSg2  >kleepima !28_V	et	f	\N
165765	ühildatud	ühildatud =ühilda  (PtsPtIps  >ühildama !27_V	et	f	\N
165766	ühildatud	ühildatud =ühildatu  (PlN  >ühildatu !01_S	et	f	\N
165536	kõnelejal	kõnelejal =kõneleja  (SgAd  >kõneleja !01_S	et	f	\N
165537	kõnelejal	"kõneleja %kõnele  )JA_vS  <kõnelema ;27_V	et	f	\N
165538	kõnelejal	"kõneleja %kõnele  )JA_vS  <kõnelema ;31_V	et	f	\N
165560	osastavas	osastavas =osastava  (SgIn  >osastav !02_A	et	f	\N
165561	osastavas	"osastav %osasta  )V_vA  <osastama ;27_V	et	f	\N
165565	veenäidud	veenäidud =näidu  (PlN  >vee+näidu !16_S	et	f	\N
165566	veenäidud	veenäidud =näidu  (PlN  >vee+näit !22_S	et	f	\N
165582	unustamine	unustamine =unustamine  (SgN  >unustamine !12_S	et	f	\N
165583	unustamine	"unustamine %unusta  )MINE_vS  <unustama ;27_V	et	f	\N
165584	käänamine	käänamine =käänamine  (SgN  >käänamine !12_S	et	f	\N
165585	käänamine	"käänamine %kääna  )MINE_vS  <käänama ;29_V	et	f	\N
165592	kõlalise	kõlalise =kõlalise  (SgG  >kõlaline !12_A	et	f	\N
165593	kõlalise	"kõlaline %kõla  )LINE_aA  <kõla ;17_S	et	f	\N
165640	rongireis	rongireis =reis  (SgN  >rongi+reis !14_S	et	f	\N
165641	rongireis	rongireis =reis  (SgN  >rongi+reis !22_S	et	f	\N
165661	eelisteks	eelisteks =eelis  (PlTr  >eelis !09_S	et	f	\N
165662	eelisteks	eelisteks =eelis  (PlTr  >eeline !10_A	et	f	\N
165663	eelisteks	"eeline %ee  )LINE_aA  <esi ;15_S	et	f	\N
165665	eelisteks	eelisteks =iste  (SgTr  >eel+iste !06_S	et	f	\N
165666	eelisteks	eelisteks =iste  (PlTr  >eel+ist !22_S	et	f	\N
165667	sihtkeelt	sihtkeelt =kee  (SgAbl  >siht+kesi !15_S	et	f	\N
165668	sihtkeelt	sihtkeelt =kee  (SgAbl  >siht+kee !26_S	et	f	\N
165669	sihtkeelt	sihtkeelt =keel  (SgP  >siht+keel !13_S	et	f	\N
165714	kirjutamises	kirjutamises =kirjutamise  (SgIn  >kirjutamine !12_S	et	f	\N
165715	kirjutamises	"kirjutamine %kirjuta  )MINE_vS  <kirjutama ;27_V	et	f	\N
165719	trahvimaksmast	?trahvimaksmast =trahvimaksma  (SgEl  >trahvimaksma !16_S	et	f	\N
165720	trahvimaksmast	?trahvimaksmast =trahvimaksmas  (SgP  >trahvimaksmane !12_A	et	f	\N
165721	trahvimaksmast	?trahvimaksmast =maksmas  (SgP  >trahvi+maksmas !07_S	et	f	\N
165722	trahvimaksmast	?trahvimaksmast =maksmas  (SgP  >trahvi+maksmane !12~10_A	et	f	\N
165779	koostisosa	koostisosa =osa  (SgN  >koostis+osa !17_S	et	f	\N
165780	koostisosa	koostisosa =osa  (SgG  >koostis+osa !17_S	et	f	\N
165781	koostisosa	koostisosa =osa  (SgP  >koostis+osa !17_S	et	f	\N
165807	konkretses	?konkretses =konkretse  (SgIn  >konkretne !02_A	et	f	\N
165808	konkretses	?konkretses =konkretse  (IndIpfSg3  >konkretsema !27_V	et	f	\N
165809	rajonis	?rajonis =rajoni  (SgIn  >rajon !02_S	et	f	\N
165810	rajonis	?rajonis =rajonis  (SgN  >rajonis !11_S	et	f	\N
165834	adjektiivi	adjektiivi =adjektiivi  (SgG  >adjektiiv !22_S	et	f	\N
165835	adjektiivi	adjektiivi =adjektiivi  (SgP  >adjektiiv !22_S	et	f	\N
165836	adjektiivi	adjektiivi =adjektiivi  (SgAdt  >adjektiiv !22_S	et	f	\N
165839	targemateks	targemateks =targema  (PlTr  >targem !02_A	et	f	\N
165840	targemateks	"targem %targe  )M_cA  <tark ;22_AS	et	f	\N
165851	hendavad	?hendavad =henda  (IndPrPl3  >hendama !29_V	et	f	\N
165852	hendavad	?hendavad =hendava  (PlN  >hendava !01_S	et	f	\N
165853	hendavad	?hendavad =hendava  (PlN  >hendav !02_A	et	f	\N
165870	mallist	mallist =malli  (SgEl  >mall !22_S	et	f	\N
165871	mallist	mallist =mallis  (SgP  >malline !10_A	et	f	\N
165872	mallist	"malline %malli  )NE_aA  <mall ;22_S	et	f	\N
165877	stiili-	stiili- =stiili  (SgG  >stiil !22_S	et	f	\N
165878	stiili-	stiili- =stiili  (SgP  >stiil !22_S	et	f	\N
165879	stiili-	stiili- =stiili  (SgAdt  >stiil !22_S	et	f	\N
165880	stiili-	stiili- =stiili  (IndPrPs_  >stiilima !28_V	et	f	\N
165881	stiili-	stiili- =stiili  (ImpPrSg2  >stiilima !28_V	et	f	\N
165887	kordamine	kordamine =kordamine  (SgN  >kordamine !12_S	et	f	\N
165888	kordamine	"kordamine %korda  )MINE_vS  <kordama ;29_V	et	f	\N
165894	tallinnat	?tallinnat =tallinna  (SgP  >tallinna !16_S	et	f	\N
165926	etteütlusest	etteütlusest =ütluse  (SgEl  >ette+ütlus !11~09_S	et	f	\N
165927	etteütlusest	etteütlusest =ütluses  (SgP  >ette+ütlusene !12_A	et	f	\N
165928	etteütlusest	"ette+ütlusene %ütluse  )NE_aA  <ette+ütlus ;09_S	et	f	\N
165929	etteütlusest	"ette+ütlusene %ütluse  )NE_aA  <ette+ütlus ;11_S	et	f	\N
165963	gesti	?gesti =gesti  (SgN  >gesti !16_S	et	f	\N
165964	gesti	?gesti =gesti  (SgG  >gesti !16_S	et	f	\N
165965	gesti	?gesti =gesti  (SgG  >gest !22_S	et	f	\N
165966	gesti	?gesti =gesti  (SgP  >gest !22_S	et	f	\N
165967	gesti	?gesti =gesti  (SgAdt  >gest !22_S	et	f	\N
165968	gesti	?gesti =gesti  (IndPrPs_  >gestima !28_V	et	f	\N
165969	gesti	?gesti =gesti  (ImpPrSg2  >gestima !28_V	et	f	\N
165981	lumeta	lumeta =lume  (SgAb  >lumi !20_S	et	f	\N
165982	lumeta	lumeta =lumeta  (IndPrPs_  >lumetama !27_V	et	f	\N
165983	lumeta	lumeta =lumeta  (ImpPrSg2  >lumetama !27_V	et	f	\N
165984	kapsad	kapsad =kapsa  (PlN  >kapsas !07_S	et	f	\N
165986	kapsad	kapsad =kapsa  (IndPrSg2  >kapsama !29_V	et	f	\N
165989	kahendal	?kahendal =kahenda  (SgAd  >kahenda !01_S	et	f	\N
165995	paiknevale	paiknevale =paikneva  (SgAll  >paiknev !02_A	et	f	\N
165996	paiknevale	"paiknev %paikne  )V_vA  <paiknema ;27_V	et	f	\N
166005	ksi	### ksi	et	f	\N
166030	ge	### ge	et	f	\N
166031	ate	?ate =ate  (SgN  >ate !06_S	et	f	\N
165562	käbi	käbi =käbi  (SgN  >käbi !17_S	et	f	\N
165563	käbi	käbi =käbi  (SgG  >käbi !17_S	et	f	\N
165564	käbi	käbi =käbi  (SgP  >käbi !17_S	et	f	\N
165595	moodustamisvead	?moodustamisvead =moodustamisvea  (PlN  >moodustamisvea !26_S	et	f	\N
165596	moodustamisvead	?moodustamisvead =moodustamisvea  (SgP  >moodustamisvea !26_S	et	f	\N
165597	moodustamisvead	?moodustamisvead =moodustamisvead  (SgN  >moodustamisvead !22_S	et	f	\N
165598	jaatava	jaatava =jaatava  (SgG  >jaatav !02_A	et	f	\N
165599	jaatava	"jaatav %jaata  )V_vA  <jaatama ;27_V	et	f	\N
165624	3paronüümia	?paronüümia =paronüümia  (SgN  >paronüümia !01_S	et	f	\N
165625	3paronüümia	?paronüümia =paronüümia  (SgG  >paronüümia !01_S	et	f	\N
165630	üht-teist	üht-teist =te  (PlEl  >üht-sa !00_P	et	f	\N
165631	üht-teist	üht-teist =teist  (SgG  >üht-teist !05_N	et	f	\N
165632	üht-teist	üht-teist =teis  (SgP  >üht-teist !05_N	et	f	\N
165633	üht-teist	üht-teist =teis  (SgP  >üht-teine !12_OP	et	f	\N
165634	üht-teist	üht-teist =teis  (SgP  >üht-teise !12_P	et	f	\N
165635	üht-teist	üht-teist =te  (PlEl  >üht-tee !26_S	et	f	\N
165636	üht-teist	üht-teist =teist  (SgN  >üht-teist !05_N	et	f	\N
165637	üht-teist	üht-teist =teist  (SgN  >üht-teist !22_S	et	f	\N
165648	interferentsivead	?interferentsivead =interferentsivea  (PlN  >interferentsivea !26_S	et	f	\N
165649	interferentsivead	?interferentsivead =interferentsivea  (SgP  >interferentsivea !26_S	et	f	\N
165650	interferentsivead	?interferentsivead =interferentsivead  (SgN  >interferentsivead !22_S	et	f	\N
165651	interferentsivead	?interferentsivead =ferentsivea  (PlN  >inter+ferentsivea !26_S	et	f	\N
165652	interferentsivead	?interferentsivead =ferentsivea  (SgP  >inter+ferentsivea !26_S	et	f	\N
165653	interferentsivead	?interferentsivead =ferentsivead  (SgN  >inter+ferentsivead !22_S	et	f	\N
165656	uurimisrühma	uurimisrühma =rühma  (SgG  >uurimis+rühm !22_S	et	f	\N
165657	uurimisrühma	uurimisrühma =rühma  (SgP  >uurimis+rühm !22_S	et	f	\N
165658	uurimisrühma	uurimisrühma =rühma  (SgAdt  >uurimis+rühm !22_S	et	f	\N
165687	korduvate	korduvate =korduva  (PlG  >korduv !02_A	et	f	\N
165688	korduvate	"korduv %kordu  )V_vA  <korduma ;27_V	et	f	\N
165691	sirge	sirge =sirge  (SgN  >sirge !01_AS	et	f	\N
165693	sirge	sirge =sirge  (SgG  >sirge !01_AS	et	f	\N
165696	õppijal	õppijal =õppija  (SgAd  >õppija !01_S	et	f	\N
165697	õppijal	"õppija %õppi  )JA_vS  <õppima ;28_V	et	f	\N
165705	koosnev	koosnev =koosne  (PtsPrPs  >koosnema !27_V	et	f	\N
165706	koosnev	koosnev =koosnev  (SgN  >koosnev !02_A	et	f	\N
165707	koosnev	"koosnev %koosne  )V_vA  <koosnema ;27_V	et	f	\N
165710	jäänituld	?jäänituld =jäänituld  (SgN  >jäänituld !22_S	et	f	\N
165712	jäänituld	?jäänituld =nituld  (SgN  >jää+nituld !02_S	et	f	\N
165716	keelduvad	keelduvad =keeldu  (IndPrPl3  >keelduma !27_V	et	f	\N
165717	keelduvad	keelduvad =keelduva  (PlN  >keelduv !02_A	et	f	\N
165718	keelduvad	"keelduv %keeldu  )V_vA  <keelduma ;27_V	et	f	\N
165731	peatuses	peatuses =peatuse  (SgIn  >peatus !11~09_S	et	f	\N
165732	peatuses	"peatus %peata  )US_vS  <peatama ;27_V	et	f	\N
165733	peatuses	"peatus %pea  )TUS2_aS  <pea ;26_S	et	f	\N
165764	moodustusviga	?moodustusviga =moodustusvi  (SgKom  >moodustusv !22_S	et	f	\N
165776	ühendverbi	ühendverbi =verbi  (SgG  >ühend+verb !22_S	et	f	\N
165777	ühendverbi	ühendverbi =verbi  (SgP  >ühend+verb !22_S	et	f	\N
165778	ühendverbi	ühendverbi =verbi  (SgAdt  >ühend+verb !22_S	et	f	\N
165782	nepe-	?nepe- =nepe  (SgN  >nepe !06_S	et	f	\N
165783	nepe-	?nepe- =nepe  (IndPrPs_  >nepema !27_V	et	f	\N
165784	nepe-	?nepe- =nepe  (ImpPrSg2  >nepema !27_V	et	f	\N
165805	tuunen	?tuunen =tuune  (IndPrSg1  >tuunema !27_V	et	f	\N
165806	tuunen	?tuunen =tuunen  (SgN  >tuunen !02_S	et	f	\N
165813	lebi	?lebi =lebi  (SgN  >lebi !17_S	et	f	\N
165814	lebi	?lebi =lebi  (SgG  >lebi !17_S	et	f	\N
165815	lebi	?lebi =lebi  (SgP  >lebi !17_S	et	f	\N
165816	lebi	?lebi =lebi  (IndPrPs_  >lebima !27_V	et	f	\N
165817	lebi	?lebi =lebi  (ImpPrSg2  >lebima !27_V	et	f	\N
165847	stiiliviga	stiiliviga =stiilivi  (SgKom  >stiiliv !02_A	et	f	\N
165848	stiiliviga	"stiiliv %stiili  )V_vA  <stiilima ;28_V	et	f	\N
165849	stiiliviga	stiiliviga =viga  (SgN  >stiili+viga !18_S	et	f	\N
165850	stiiliviga	stiiliviga =viga  (SgP  >stiili+viga !18_S	et	f	\N
165854	rektsiooniviga	?rektsiooniviga =rektsioonivi  (SgKom  >rektsiooniv !02_A	et	f	\N
165857	keerulisi	keerulisi =keerulisi  (PlP  >keeruline !12_A	et	f	\N
165858	keerulisi	"keeruline %keeru  )LINE_aA  <keerd ;22_SA	et	f	\N
165862	keerulisemad	keerulisemad =keerulisema  (PlN  >keerulisem !02_A	et	f	\N
165863	keerulisemad	"keerulisem %keeru  )LISEM_cA  <keerd ;22_SA	et	f	\N
165864	keerulisemad	"keerulisem %keerulise  )M_cA  <keeruline ;12_A	et	f	\N
165884	tarbetu	tarbetu =tarbetu  (SgN  >tarbetu !01_A	et	f	\N
165885	tarbetu	"tarbetu %tarbe  )TU2_kA  <tarve ;06_S	et	f	\N
165886	tarbetu	tarbetu =tarbetu  (SgG  >tarbetu !01_A	et	f	\N
165902	määratlemise	määratlemise =määratlemise  (SgG  >määratlemine !12_S	et	f	\N
165903	määratlemise	"määratlemine %määratle  )MINE_vS  <määratlema ;27_V	et	f	\N
165909	kahtlusi	kahtlusi =kahtlusi  (PlP  >kahtlus !11_S	et	f	\N
165760	käänata	käänata =kääna  (Inf  >käänama !29_V	et	f	\N
165761	käänata	käänata =kääna  (IndPrIps_  >käänama !29_V	et	f	\N
165762	kleebis	kleebis =kleebi  (SgIn  >kleep !22_S	et	f	\N
165763	kleebis	kleebis =kleebis  (SgN  >kleebis !09_S	et	f	\N
165775	ülelugeda	### ülelugeda	et	f	\N
165790	eristamisel	eristamisel =eristamise  (SgAd  >eristamine !12_S	et	f	\N
165791	eristamisel	"eristamine %erista  )MINE_vS  <eristama ;27_V	et	f	\N
165792	lähema	lähema =lähema  (SgG  >lähem !02_A	et	f	\N
165793	lähema	"lähem %lähe  )M_cA  <lähike ;12_A	et	f	\N
165794	moodustusveaga	?moodustusveaga =moodustusvea  (SgKom  >moodustusvea !26_S	et	f	\N
165800	sõnaühendiga	sõnaühendiga =iga  (SgN  >sõna+ühend+iga !18_S	et	f	\N
165801	sõnaühendiga	sõnaühendiga =iga  (SgP  >sõna+ühend+iga !18_S	et	f	\N
165802	sõnaühendiga	sõnaühendiga =ühendi  (SgKom  >sõna+ühend !02_S	et	f	\N
165822	kuulmise	kuulmise =kuulmise  (SgG  >kuulmine !12?10_S	et	f	\N
165823	kuulmise	"kuulmine %kuul  )MINE_vS  <kuulma ;33_V	et	f	\N
165841	lgitud	?lgitud =lgitu  (PlN  >lgitu !16_S	et	f	\N
165842	lgitud	?lgitud =lgitu  (IndPrSg2  >lgituma !27_V	et	f	\N
165843	üü	?üü =üü  (SgN  >üü !26_S	et	f	\N
165844	üü	?üü =üü  (SgG  >üü !26_S	et	f	\N
165882	erilisused	erilisused =erilisuse  (PlN  >erilisus !11?09_S	et	f	\N
165883	erilisused	"erilisus %eri  )LISUS_aS  <eri ;17_S	et	f	\N
165891	põhinev	põhinev =põhine  (PtsPrPs  >põhinema !27_V	et	f	\N
165892	põhinev	põhinev =põhinev  (SgN  >põhinev !02_A	et	f	\N
165893	põhinev	"põhinev %põhine  )V_vA  <põhinema ;27_V	et	f	\N
165899	kehaosa	kehaosa =osa  (SgN  >keha+osa !17_S	et	f	\N
165900	kehaosa	kehaosa =osa  (SgG  >keha+osa !17_S	et	f	\N
165901	kehaosa	kehaosa =osa  (SgP  >keha+osa !17_S	et	f	\N
165904	probleemiga	probleemiga =probleemi  (SgKom  >probleem !22_S	et	f	\N
165905	probleemiga	probleemiga =iga  (SgN  >probleem+iga !18_S	et	f	\N
165906	probleemiga	probleemiga =iga  (SgP  >probleem+iga !18_S	et	f	\N
165907	õppijatel	õppijatel =õppija  (PlAd  >õppija !01_S	et	f	\N
165908	õppijatel	"õppija %õppi  )JA_vS  <õppima ;28_V	et	f	\N
165921	toodetud	toodetud =toode  (PtsPtIps  >tootma !34_V	et	f	\N
165922	toodetud	toodetud =toodetu  (PlN  >toodetu !01_AS	et	f	\N
165923	toodetud	"toodetu %toode  )TU1_vS  <tootma ;34_V	et	f	\N
165924	toodetud	toodetud =toodetud  (ID  >toodetud !41_A	et	f	\N
165925	toodetud	"toodetud %toode  )TUD_vA  <tootma ;34_V	et	f	\N
165930	kahtlust	kahtlust =kahtlus  (SgP  >kahtlus !11~09_S	et	f	\N
165931	kahtlust	"kahtlus %kahtlase  )US_aS  <kahtlane ;12_A	et	f	\N
165932	kahtlust	kahtlust =lust  (SgN  >kaht+lust !22_S	et	f	\N
165988	kaunisam	?kaunisam =kaunisam  (SgN  >kaunisam !02_A	et	f	\N
166018	tibades	tibades =tiba  (PlIn  >tiba !17_S	et	f	\N
166019	tibades	tibades =tiba  (Ger  >tibama !27_V	et	f	\N
166021	andu	andu =andu  (IndPrPs_  >anduma !27_V	et	f	\N
166022	andu	andu =andu  (ImpPrSg2  >anduma !27_V	et	f	\N
166023	th	### th	et	f	\N
166029	tat	### tat	et	f	\N
166038	tsko	### tsko	et	f	\N
166054	im	### im	et	f	\N
166057	tata	?tata =tata  (SgN  >tata !16_S	et	f	\N
166058	tata	?tata =tata  (SgG  >tata !16_S	et	f	\N
166059	tata	?tata =tata  (IndPrPs_  >tatama !27_V	et	f	\N
166060	tata	?tata =tata  (ImpPrSg2  >tatama !27_V	et	f	\N
166066	llu	### llu	et	f	\N
166068	stata	?stata =stata  (SgN  >stata !16_S	et	f	\N
166069	stata	?stata =stata  (SgG  >stata !16_S	et	f	\N
166070	stata	?stata =stata  (IndPrPs_  >statama !27_V	et	f	\N
166071	stata	?stata =stata  (ImpPrSg2  >statama !27_V	et	f	\N
166105	mill	?mill =mill  (SgN  >mill !22_S	et	f	\N
166108	il	### il	et	f	\N
166118	lgas	### lgas	et	f	\N
166120	kim	### kim	et	f	\N
166149	tõetruult	tõetruult =truu  (SgAbl  >tõe+truu !26_A	et	f	\N
166150	tõetruult	"tõe+truult %truu  )LT_mD  <tõe+truu ;26_A	et	f	\N
166156	valitsejad	valitsejad =valitseja  (PlN  >valitseja !01_S	et	f	\N
166158	valitsejad	"valitseja %valitse  )JA_vS  <valitsema ;27_V	et	f	\N
166180	haosest	?haosest =haose  (SgEl  >haose !06_S	et	f	\N
166181	haosest	?haosest =haoses  (SgP  >haoses !09_S	et	f	\N
166182	haosest	?haosest =haoses  (SgP  >haosene !10_A	et	f	\N
166183	ahastavam	ahastavam =ahastavam  (SgN  >ahastavam !02_A	et	f	\N
166184	ahastavam	"ahastavam %ahasta  )VAM_cA  <ahastama ;27_V	et	f	\N
166187	kommertskooli	kommertskooli =kooli  (SgG  >kommerts+kool !22_S	et	f	\N
166188	kommertskooli	kommertskooli =kooli  (SgP  >kommerts+kool !22_S	et	f	\N
166189	kommertskooli	kommertskooli =kooli  (SgAdt  >kommerts+kool !22_S	et	f	\N
166190	kommertskooli	kommertskooli =kooli  (PlP  >kommerts+kool !22_S	et	f	\N
166191	henn	?henn =henn  (SgN  >henn !22_S	et	f	\N
166192	ahase	ahase =ahase  (SgG  >ahane !10_A	et	f	\N
166193	ahase	"ahane %aha  )NE_aA  <ahk ;22_S	et	f	\N
166202	aatelisus	aatelisus =aatelisus  (SgN  >aatelisus !11?09_S	et	f	\N
166203	aatelisus	"aatelisus %aate  )LISUS_aS  <aade ;06_S	et	f	\N
166211	teisigi	teisigi =teisi  (PlP^  >teine !12_OP	et	f	\N
166212	teisigi	teisigi =teisi  (PlP^  >teise !12_P	et	f	\N
165767	ühildatud	"ühildatu %ühilda  )TU1_vS  <ühildama ;27_V	et	f	\N
165768	ühildatud	ühildatud =ühildatud  (ID  >ühildatud !41_A	et	f	\N
165769	ühildatud	"ühildatud %ühilda  )TUD_vA  <ühildama ;27_V	et	f	\N
165770	arvatatakse	?arvatatakse =arvata  (IndPrIps  >arvatama !27_V	et	f	\N
165771	arvatatakse	?arvatatakse =arvatatakse  (SgG  >arvatatakne !02_A	et	f	\N
165772	arvatatakse	?arvatatakse =arvatatakse  (PlP  >arvatataks !22_S	et	f	\N
165773	arvatatakse	?arvatatakse =atatakse  (SgG  >arv+atatakne !02_A	et	f	\N
165774	arvatatakse	?arvatatakse =atatakse  (PlP  >arv+atataks !22_S	et	f	\N
165785	ühildumisveaga	?ühildumisveaga =ühildumisvea  (SgKom  >ühildumisvea !26_S	et	f	\N
165803	alaleütlev	?alaleütlev =alaleütlev  (SgN  >alaleütlev !02_A	et	f	\N
165804	alaleütlev	?alaleütlev =leütlev  (SgN  >ala+leütlev !02_A	et	f	\N
165811	kaupluss	?kaupluss =kaupluss  (SgN  >kaupluss !22_S	et	f	\N
165812	kaupluss	?kaupluss =luss  (SgN  >kaup+luss !22_S	et	f	\N
165818	lepi	lepi =lepi  (SgG  >lepp !22_S	et	f	\N
165819	lepi	lepi =lepi  (SgG  >lepp !22_SA	et	f	\N
165820	lepi	lepi =lepi  (IndPrPs_  >leppima !28_V	et	f	\N
165821	lepi	lepi =lepi  (ImpPrSg2  >leppima !28_V	et	f	\N
165831	adverbi	adverbi =adverbi  (SgG  >adverb !22_S	et	f	\N
165832	adverbi	adverbi =adverbi  (SgP  >adverb !22_S	et	f	\N
165833	adverbi	adverbi =adverbi  (SgAdt  >adverb !22_S	et	f	\N
165837	parimateks	parimateks =parima  (PlTr  >parim !02_A	et	f	\N
165838	parimateks	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
165845	avad	avad =ava  (PlN  >ava !17_S	et	f	\N
165846	avad	avad =ava  (IndPrSg2  >avama !27_V	et	f	\N
165859	keelesttavaliselt	?keelesttavaliselt =keelesttavalise  (SgAbl  >keelesttavaline !12_A	et	f	\N
165860	keelesttavaliselt	?keelesttavaliselt =keelesttavaliselt  (ID  >keelesttavaliselt !41_D	et	f	\N
165861	keelesttavaliselt	?keelesttavaliselt =esttavalise  (SgAbl  >keel+esttavaline !12_A	et	f	\N
165867	ebakorrektselt	ebakorrektselt =korrektse  (SgAbl  >eba+korrektne !02_A	et	f	\N
165868	ebakorrektselt	ebakorrektselt =korrektselt  (ID  >eba+korrektselt !41_D	et	f	\N
165869	ebakorrektselt	"eba+korrektselt %korrektse  )LT_mD  <eba+korrektne ;02_A	et	f	\N
165895	riietusest	riietusest =riietuse  (SgEl  >riietus !11_S	et	f	\N
165896	riietusest	"riietus %riieta  )US_vS  <riietama ;27_V	et	f	\N
165897	riietusest	riietusest =riietuses  (SgP  >riietusene !12_A	et	f	\N
165898	riietusest	"riietusene %riietuse  )NE_aA  <riietus ;11_S	et	f	\N
165913	amortiseerunud	amortiseerunud =amortiseeru  (PtsPtPs  >amortiseeruma !27_V	et	f	\N
165914	amortiseerunud	amortiseerunud =amortiseerunu  (PlN  >amortiseerunu !01_S	et	f	\N
165915	amortiseerunud	"amortiseerunu %amortiseeru  )NU_vS  <amortiseeruma ;27_V	et	f	\N
165916	amortiseerunud	amortiseerunud =amortiseerunud  (ID  >amortiseerunud !41_A	et	f	\N
165917	amortiseerunud	"amortiseerunud %amortiseeru  )NUD_vA  <amortiseeruma ;27_V	et	f	\N
165918	ennes	?ennes =enne  (PlIn  >enn !22_S	et	f	\N
165919	ennes	?ennes =enne  (IndIpfSg3  >ennema !27_V	et	f	\N
165920	ennes	?ennes =ennes  (SgN  >ennes !09_S	et	f	\N
165935	sihtlkeelde	### sihtlkeelde	et	f	\N
165937	sihtkeele	sihtkeele =kee  (SgAll  >siht+kesi !15_S	et	f	\N
165938	sihtkeele	sihtkeele =kee  (SgAll  >siht+kee !26_S	et	f	\N
165940	sihtkeele	sihtkeele =keele  (SgG  >siht+keel !13_S	et	f	\N
165943	verbirektsiooni	?verbirektsiooni =verbirektsioo  (SgTer  >verbirektsioo !26_S	et	f	\N
165944	verbirektsiooni	?verbirektsiooni =verbirektsiooni  (SgN  >verbirektsiooni !16_S	et	f	\N
165945	verbirektsiooni	?verbirektsiooni =verbirektsiooni  (SgG  >verbirektsiooni !16_S	et	f	\N
165946	verbirektsiooni	?verbirektsiooni =verbirektsiooni  (SgG  >verbirektsioon !22_S	et	f	\N
165947	verbirektsiooni	?verbirektsiooni =verbirektsiooni  (SgP  >verbirektsioon !22_S	et	f	\N
165948	verbirektsiooni	?verbirektsiooni =verbirektsiooni  (SgAdt  >verbirektsioon !22_S	et	f	\N
165949	verbirektsiooni	?verbirektsiooni =verbirektsiooni  (IndPrPs_  >verbirektsioonima !28_V	et	f	\N
165950	verbirektsiooni	?verbirektsiooni =verbirektsiooni  (ImpPrSg2  >verbirektsioonima !28_V	et	f	\N
165970	analüüsimisele	analüüsimisele =analüüsimise  (SgAll  >analüüsimine !12_S	et	f	\N
165971	analüüsimisele	"analüüsimine %analüüsi  )MINE_vS  <analüüsima ;28_V	et	f	\N
165975	tegijale	tegijale =tegija  (SgAll  >tegija !01_S	et	f	\N
165976	tegijale	"tegija %tegi  )JA_vS  <tegema ;28_V	et	f	\N
165977	põhjustamist	põhjustamist =põhjustamis  (SgP  >põhjustamine !12_S	et	f	\N
165978	põhjustamist	"põhjustamine %põhjusta  )MINE_vS  <põhjustama ;27_V	et	f	\N
166008	isminevikus	?isminevikus =ismineviku  (SgIn  >isminevik !02_S	et	f	\N
166009	isminevikus	?isminevikus =ismineviku  (IndIpfSg3  >isminevikuma !27_V	et	f	\N
166010	isminevikus	?isminevikus =isminevikus  (SgN  >isminevikus !11?09_S	et	f	\N
166011	analuüüs	?analuüüs =analuüü  (SgIn  >analuüü !26_S	et	f	\N
166012	analuüüs	?analuüüs =analuüüs  (SgN  >analuüüs !22_S	et	f	\N
166015	2kerge	kerge =kerge  (SgN  >kerge !01_A	et	f	\N
166016	2kerge	kerge =kerge  (SgN  >kerge !06_S	et	f	\N
166017	2kerge	kerge =kerge  (SgG  >kerge !01_A	et	f	\N
166024	co	### co	et	f	\N
166026	ldud	### ldud	et	f	\N
166040	ikli	?ikli =ikli  (ID  >ikli !41_D	et	f	\N
166041	ikli	?ikli =ikli  (SgG  >ikkel !02_S	et	f	\N
166055	eses	?eses =ese  (IndIpfSg3  >esema !27_V	et	f	\N
165787	heme	?heme =heme  (SgG  >heme !16_S	et	f	\N
165788	heme	?heme =heme  (IndPrPs_  >hemema !27_V	et	f	\N
165789	heme	?heme =heme  (ImpPrSg2  >hemema !27_V	et	f	\N
165795	lisiku	?lisiku =lisiku  (SgN  >lisiku !01_S	et	f	\N
165796	lisiku	?lisiku =lisiku  (SgG  >lisiku !01_S	et	f	\N
165797	lisiku	?lisiku =lisiku  (SgG  >lisik !02_S	et	f	\N
165798	lisiku	?lisiku =lisiku  (IndPrPs_  >lisikuma !27_V	et	f	\N
165799	lisiku	?lisiku =lisiku  (ImpPrSg2  >lisikuma !27_V	et	f	\N
165824	priti	?priti =priti  (SgN  >priti !16_S	et	f	\N
165825	priti	?priti =priti  (SgG  >priti !16_S	et	f	\N
165826	priti	?priti =priti  (SgG  >pritt !22_S	et	f	\N
165827	priti	?priti =priti  (IndPrPs_  >pritima !27_V	et	f	\N
165828	priti	?priti =priti  (IndPrPs_  >prittima !28_V	et	f	\N
165829	priti	?priti =priti  (ImpPrSg2  >pritima !27_V	et	f	\N
165830	priti	?priti =priti  (ImpPrSg2  >prittima !28_V	et	f	\N
165855	pakuks	pakuks =paku  (SgTr  >pakk !22_S	et	f	\N
165856	pakuks	pakuks =paku  (KndPrPs  >pakkuma !28_V	et	f	\N
165865	kõlaks	kõlaks =kõla  (SgTr  >kõla !17_S	et	f	\N
165866	kõlaks	kõlaks =kõla  (KndPrPs  >kõlama !27_V	et	f	\N
165873	sünonüümi	sünonüümi =sünonüümi  (SgG  >sünonüüm !22_S	et	f	\N
165874	sünonüümi	sünonüümi =sünonüümi  (SgP  >sünonüüm !22_S	et	f	\N
165875	sünonüümi	sünonüümi =sünonüümi  (SgAdt  >sünonüüm !22_S	et	f	\N
165876	lausemoodustusvigade	### lausemoodustusvigade	et	f	\N
165889	rikkaks	?rikkaks =rikka  (SgTr  >rikas !07_A	et	f	\N
165890	rikkaks	?rikkaks =rikka  (KndPrPs  >rikkama !29_V	et	f	\N
165936	arvesta	arvesta =arvesta  (IndPrPs_  >arvestama !27_V	et	f	\N
165939	arvesta	arvesta =arvesta  (ImpPrSg2  >arvestama !27_V	et	f	\N
165951	sise-	?sise- =sise  (SgN  >sise !16_S	et	f	\N
165952	sise-	?sise- =sise  (SgG  >sise !16_S	et	f	\N
165953	sise-	?sise- =sise  (IndPrPs_  >sisema !27_V	et	f	\N
165954	sise-	?sise- =sise  (ImpPrSg2  >sisema !27_V	et	f	\N
165957	esinevate	esinevate =esineva  (PlG  >esinev !02_A	et	f	\N
165958	esinevate	"esinev %esine  )V_vA  <esinema ;27_V	et	f	\N
165959	õppimisstrateegia	õppimisstrateegia =strateegia  (SgN  >õppimis+strateegia !01_S	et	f	\N
165960	õppimisstrateegia	õppimisstrateegia =strateegia  (SgG  >õppimis+strateegia !01_S	et	f	\N
165972	enesekohased	enesekohased =kohase  (PlN  >enese+kohane !10_A	et	f	\N
165973	enesekohased	"enese+kohane %koha  )NE_aA  <enese+koha ;17_S	et	f	\N
165974	enesekohased	"enese+kohane %koha  )NE_aA  <enese+koht ;22_S	et	f	\N
165985	maasikas	maasikas =maasika  (SgIn  >maasikas !02_S	et	f	\N
165987	maasikas	maasikas =maasikas  (SgN  >maasikas !02_S	et	f	\N
165997	petaja	?petaja =petaja  (SgN  >petaja !01_S	et	f	\N
165998	petaja	?petaja =petaja  (SgG  >petaja !01_S	et	f	\N
165999	petaja	?petaja =petaja  (SgG  >petajas !02_A	et	f	\N
166013	määratlemine	määratlemine =määratlemine  (SgN  >määratlemine !12_S	et	f	\N
166014	määratlemine	"määratlemine %määratle  )MINE_vS  <määratlema ;27_V	et	f	\N
166028	hu	### hu	et	f	\N
166034	si	si =si  (SgN  >si !26_S	et	f	\N
166035	si	si =si  (SgG  >si !26_S	et	f	\N
166037	pi	### pi	et	f	\N
166042	ko	### ko	et	f	\N
166043	lkiri	?lkiri =lkiri  (SgN  >lkiri !17_S	et	f	\N
166044	lkiri	?lkiri =lkiri  (SgG  >lkiri !17_S	et	f	\N
166045	lkiri	?lkiri =lkiri  (SgP  >lkiri !17_S	et	f	\N
166046	lkiri	?lkiri =lkiri  (IndPrPs_  >lkirima !27_V	et	f	\N
166047	lkiri	?lkiri =lkiri  (ImpPrSg2  >lkirima !27_V	et	f	\N
166067	ääg	?ääg =ääg  (SgN  >ääg !22_S	et	f	\N
166072	tag	### tag	et	f	\N
166098	ru	### ru	et	f	\N
166107	ip	### ip	et	f	\N
166112	kk	### kk	et	f	\N
166114	äta	?äta =äta  (SgN  >äta !16_S	et	f	\N
166115	äta	?äta =äta  (SgG  >äta !16_S	et	f	\N
166116	äta	?äta =äta  (IndPrPs_  >ätama !27_V	et	f	\N
166117	äta	?äta =äta  (ImpPrSg2  >ätama !27_V	et	f	\N
166134	kirjandusteos	kirjandusteos =teo  (SgIn  >kirjandus+tegu !18_S	et	f	\N
166135	kirjandusteos	kirjandusteos =teo  (SgIn  >kirjandus+tigu !18_S	et	f	\N
166136	kirjandusteos	kirjandusteos =teos  (SgN  >kirjandus+teos !09_S	et	f	\N
166159	võimetud	võimetud =võimetu  (PlN  >võimetu !01_A	et	f	\N
166160	võimetud	"võimetu %võime  )TU2_kA  <võime ;06_S	et	f	\N
166170	lömitamise	lömitamise =lömitamise  (SgG  >lömitamine !12_S	et	f	\N
166171	lömitamise	"lömitamine %lömita  )MINE_vS  <lömitama ;27_V	et	f	\N
166172	vihkamise	vihkamise =vihkamise  (SgG  >vihkamine !12_S	et	f	\N
166173	vihkamise	"vihkamine %vihka  )MINE_vS  <vihkama ;29_V	et	f	\N
166174	ristis	ristis =risti  (SgIn  >risti !16_S	et	f	\N
166175	ristis	ristis =risti  (SgIn  >rist !22_S	et	f	\N
166177	ristis	ristis =risti  (IndIpfSg3  >ristima !28_V	et	f	\N
166179	ristis	ristis =ristis  (ID  >ristis !41_DA	et	f	\N
166185	öeldule	öeldule =öeldu  (SgAll  >öeldu !01_S	et	f	\N
166186	öeldule	"öeldu %öel  )TU1_vS  <ütlema ;30_V	et	f	\N
166206	ennastsalgavus	ennastsalgavus =salgavus  (SgN  >ennast+salgavus !11_S	et	f	\N
166207	ennastsalgavus	"ennast+salgavus %salgava  )US_aS  <ennast+salgav ;02_A	et	f	\N
165910	kahtlusi	"kahtlus %kahtlase  )US_aS  <kahtlane ;12_A	et	f	\N
165911	segiajamisega	segiajamisega =ajamise  (SgKom  >segi+ajamine !12_S	et	f	\N
165912	segiajamisega	"segi+ajamine %ajami  )NE_aA  <segi+ajam ;02_S	et	f	\N
165933	tähtsuseta	tähtsuseta =tähtsuse  (SgAb  >tähtsus !11~09_S	et	f	\N
165934	tähtsuseta	"tähtsus %tähtsa  )US_aS  <tähtis ;02_A	et	f	\N
165941	eripärasustega	eripärasustega =pärasus  (PlKom  >eri+pärasus !11_S	et	f	\N
165942	eripärasustega	"eri+pärasus %pära  )SUS_aS  <eri+pära ;17_S	et	f	\N
165955	võrdlemisel	võrdlemisel =võrdlemise  (SgAd  >võrdlemine !12_S	et	f	\N
165956	võrdlemisel	"võrdlemine %võrdle  )MINE_vS  <võrdlema ;30_V	et	f	\N
165961	õi	?õi =õi  (SgN  >õi !26_S	et	f	\N
165962	õi	?õi =õi  (SgG  >õi !26_S	et	f	\N
165979	kutsumist	kutsumist =kutsumis  (SgP  >kutsumine !12_S	et	f	\N
165980	kutsumist	"kutsumine %kutsu  )MINE_vS  <kutsuma ;28_V	et	f	\N
165990	kõnelejast	kõnelejast =kõneleja  (SgEl  >kõneleja !01_S	et	f	\N
165991	kõnelejast	"kõneleja %kõnele  )JA_vS  <kõnelema ;27_V	et	f	\N
165992	kõnelejast	"kõneleja %kõnele  )JA_vS  <kõnelema ;31_V	et	f	\N
165993	kõnelejast	kõnelejast =kõnelejas  (SgP  >kõnelejane !12_A	et	f	\N
165994	kõnelejast	"kõnelejane %kõneleja  )NE_aA  <kõneleja ;01_S	et	f	\N
166000	mittesõpraid	?mittesõpraid =mittesõprai  (PlN  >mittesõprai !26_S	et	f	\N
166001	mittesõpraid	?mittesõpraid =mittesõprai  (SgP  >mittesõprai !26_S	et	f	\N
166002	mittesõpraid	?mittesõpraid =sõprai  (PlN  >mitte+sõprai !26_S	et	f	\N
166003	mittesõpraid	?mittesõpraid =sõprai  (SgP  >mitte+sõprai !26_S	et	f	\N
166004	mittesõpraid	?mittesõpraid =sõpraid  (SgN  >mitte+sõpraid !22_S	et	f	\N
166006	mbleksin	?mbleksin =mbleksi  (IndPrSg1  >mbleksima !28_V	et	f	\N
166007	mbleksin	?mbleksin =mbleksin  (SgN  >mbleksin !02_S	et	f	\N
166020	maj	### maj	et	f	\N
166025	nin	### nin	et	f	\N
166027	ndu	### ndu	et	f	\N
166039	ir	### ir	et	f	\N
166049	best	?best =best  (SgN  >best !22_S	et	f	\N
166065	teg	### teg	et	f	\N
166074	ärri	?ärri =ärri  (SgN  >ärri !16_S	et	f	\N
166075	ärri	?ärri =ärri  (SgG  >ärri !16_S	et	f	\N
166076	ärri	?ärri =ärri  (SgG  >ärr !22_S	et	f	\N
166077	ärri	?ärri =ärri  (SgP  >ärr !22_S	et	f	\N
166078	ärri	?ärri =ärri  (SgAdt  >ärr !22_S	et	f	\N
166079	ärri	?ärri =ärri  (IndPrPs_  >ärrima !28_V	et	f	\N
166080	ärri	?ärri =ärri  (ImpPrSg2  >ärrima !28_V	et	f	\N
166090	õte	?õte =õte  (SgN  >õte !06_S	et	f	\N
166091	õte	?õte =õte  (IndPrPs_  >õtema !27_V	et	f	\N
166092	õte	?õte =õte  (ImpPrSg2  >õtema !27_V	et	f	\N
166095	likul	?likul =liku  (SgAd  >liku !16_S	et	f	\N
166096	likul	?likul =liku  (SgAd  >likk !22_S	et	f	\N
166097	likul	?likul =likul  (SgN  >likul !02_S	et	f	\N
166099	vesta	vesta =vest  (Inf  >vestma !34_V	et	f	\N
166100	vesta	vesta =vesta  (IndPrPs_  >vestma !34_V	et	f	\N
166101	vesta	vesta =vesta  (ImpPrSg2  >vestma !34_V	et	f	\N
166104	nud	### nud	et	f	\N
166106	eg	### eg	et	f	\N
166110	ikup	?ikup =ikup  (SgN  >ikup !02_S	et	f	\N
166121	ba	### ba	et	f	\N
166123	albert	?albert =albert  (SgN  >albert !22_S	et	f	\N
166151	tolleaegsete	tolleaegsete =sete  (SgN  >tolle+aeg+sete !06_S	et	f	\N
166152	tolleaegsete	tolleaegsete =aegse  (PlG  >tolle+aegne !02_A	et	f	\N
166153	maailmapilti	maailmapilti =pilti  (SgP  >maa+ilma+pilt !22_S	et	f	\N
166154	maailmapilti	maailmapilti =pilti  (SgAdt  >maa+ilma+pilt !22_S	et	f	\N
166155	keskpärased	keskpärased =pärase  (PlN  >kesk+pärane !10_A	et	f	\N
166157	keskpärased	"kesk+pärane %pära  )NE_aA  <kesk+pära ;17_S	et	f	\N
166204	vaprus	vaprus =vaprus  (SgN  >vaprus !11~09_S	et	f	\N
166205	vaprus	"vaprus %vapra  )US_aS  <vapper ;02_A	et	f	\N
166220	patriatismini	?patriatismini =patriatismi  (SgTer  >patriatism !22_S	et	f	\N
166221	patriatismini	?patriatismini =patriatismini  (ID  >patriatismini !41_D	et	f	\N
166223	patriatismini	?patriatismini =patriatismini  (SgG  >patriatismin !02_S	et	f	\N
166235	kohlapuusid	?kohlapuusid =kohlapuu  (PlP  >kohlapuu !26_S	et	f	\N
166236	kohlapuusid	?kohlapuusid =kohlapuusi  (PlN  >kohlapuusi !16_S	et	f	\N
166237	kohlapuusid	?kohlapuusid =kohlapuusi  (PlN  >kohlapuus !22_S	et	f	\N
166238	kohlapuusid	?kohlapuusid =kohlapuusi  (IndPrSg2  >kohlapuusima !28_V	et	f	\N
166252	margo	?margo =margo  (SgN  >margo !16_S	et	f	\N
166253	margo	?margo =margo  (SgG  >margo !16_S	et	f	\N
166270	kinosaalist	kinosaalist =saali  (SgEl  >kino+saal !22_S	et	f	\N
166271	kinosaalist	kinosaalist =saalis  (SgP  >kino+saaline !10_A	et	f	\N
166273	kinosaalist	"kino+saaline %saali  )NE_aA  <kino+saal ;22_S	et	f	\N
166277	lugejaile	lugejaile =lugeja  (PlAll  >lugeja !01_S	et	f	\N
166278	lugejaile	"lugeja %luge  )JA_vS  <lugema ;28_V	et	f	\N
166279	paneksid	paneksid =pane  (KndPrSg2  >panema !36_V	et	f	\N
166280	paneksid	paneksid =pane  (KndPrPl3  >panema !36_V	et	f	\N
166284	uhkusest	uhkusest =uhkuse  (SgEl  >uhkus !11~09_S	et	f	\N
166285	uhkusest	"uhkus %uhke  )US_aS  <uhke ;01_A	et	f	\N
166286	uhkusest	uhkusest =uhkuses  (SgP  >uhkusene !12_A	et	f	\N
166287	uhkusest	"uhkusene %uhkuse  )NE_aA  <uhkus ;09_S	et	f	\N
166032	ate	?ate =ate  (IndPrPs_  >atema !27_V	et	f	\N
166033	ate	?ate =ate  (ImpPrSg2  >atema !27_V	et	f	\N
166036	tab	### tab	et	f	\N
166048	stis	### stis	et	f	\N
166050	iest	?iest =ie  (SgEl  >ie !26_S	et	f	\N
166051	iest	?iest =ies  (SgP  >ies !09_S	et	f	\N
166052	iest	?iest =ies  (SgP  >iene !10_A	et	f	\N
166053	iest	?iest =iest  (SgN  >iest !22_S	et	f	\N
166081	uvii	?uvii =uvii  (SgN  >uvii !26_S	et	f	\N
166082	uvii	?uvii =uvii  (SgG  >uvii !26_S	et	f	\N
166083	ldu	### ldu	et	f	\N
166093	lih	?lih =lih  (ID  >lih !41_I	et	f	\N
166094	oil	?oil =oil  (SgN  >oil !22_S	et	f	\N
166102	paa	paa =paa  (SgN  >paa !26_SA	et	f	\N
166103	paa	paa =paa  (SgG  >paa !26_SA	et	f	\N
166111	rr	### rr	et	f	\N
166119	iklik	?iklik =iklik  (SgN  >iklik !25_A	et	f	\N
166126	nüganeni	?nüganeni =nüganeni  (SgG  >nüganen !19_S	et	f	\N
166127	nüganeni	?nüganeni =nüganeni  (SgP  >nüganen !19_S	et	f	\N
166128	nüganeni	?nüganeni =nüganeni  (SgAdt  >nüganen !19_S	et	f	\N
166137	eestimaalaste	eestimaalaste =las  (PlG  >eesti+maa+laps !14_S	et	f	\N
166138	eestimaalaste	eestimaalaste =laste  (PlP  >eesti+maa+last !22_S	et	f	\N
166139	eestimaalaste	eestimaalaste =maalas  (PlG  >eesti+maalane !12?10_S	et	f	\N
166142	akivikase	?akivikase =akivikase  (SgG  >akivikane !12_A	et	f	\N
166143	kontrastiks	kontrastiks =kontrasti  (SgTr  >kontrast !22_S	et	f	\N
166144	kontrastiks	kontrastiks =kontrasti  (KndPrPs  >kontrastima !28_V	et	f	\N
166145	kontrastiks	kontrastiks =iks  (SgN  >kontrast+iks !22_S	et	f	\N
166146	enüganeni	?enüganeni =enüganeni  (SgG  >enüganen !19_S	et	f	\N
166147	enüganeni	?enüganeni =enüganeni  (SgP  >enüganen !19_S	et	f	\N
166148	enüganeni	?enüganeni =enüganeni  (SgAdt  >enüganen !19_S	et	f	\N
166161	veenva	veenva =veenva  (SgG  >veenev !02_A	et	f	\N
166162	veenva	"veenev %veen  )V_vA  <veenma ;33_V	et	f	\N
166168	jõetul	jõetul =jõetu  (SgAd  >jõetu !01_A	et	f	\N
166169	jõetul	"jõetu %jõe  )TU2_kA  <jõgi ;21_S	et	f	\N
166176	tagusid	tagusid =tagu  (IndIpfSg2  >taguma !28_V	et	f	\N
166178	tagusid	tagusid =tagu  (IndIpfPl3  >taguma !28_V	et	f	\N
166194	võitlevate	võitlevate =võitleva  (PlG  >võitlev !02_A	et	f	\N
166195	võitlevate	"võitlev %võitle  )V_vA  <võitlema ;30_V	et	f	\N
166222	jõutakse	jõutakse =jõu  (IndPrIps  >jõudma !34_V	et	f	\N
166224	jõutakse	jõutakse =takse  (PlP  >jõu+taks !22_S	et	f	\N
166246	originaalteos	originaalteos =teo  (SgIn  >originaal+tegu !18_S	et	f	\N
166247	originaalteos	originaalteos =teo  (SgIn  >originaal+tigu !18_S	et	f	\N
166248	originaalteos	originaalteos =teos  (SgN  >originaal+teos !09_S	et	f	\N
166249	romantiliselt	romantiliselt =romantilise  (SgAbl  >romantiline !12_A	et	f	\N
166250	romantiliselt	romantiliselt =romantiliselt  (ID  >romantiliselt !41_D	et	f	\N
166251	romantiliselt	"romantiliselt %romantilise  )LT_mD  <romantiline ;12_A	et	f	\N
166256	hennu	?hennu =hennu  (SgN  >hennu !16_S	et	f	\N
166258	hennu	?hennu =hennu  (SgG  >hennu !16_S	et	f	\N
166260	hennu	?hennu =hennu  (IndPrPs_  >hennuma !27_V	et	f	\N
166262	hennu	?hennu =hennu  (ImpPrSg2  >hennuma !27_V	et	f	\N
166272	kinnituse	kinnituse =kinnituse  (SgG  >kinnitus !11_S	et	f	\N
166274	kinnituse	"kinnitus %kinnita  )US_vS  <kinnitama ;27_V	et	f	\N
166275	vaatajaile	vaatajaile =vaataja  (PlAll  >vaataja !01_S	et	f	\N
166276	vaatajaile	"vaataja %vaata  )JA_vS  <vaatama ;29_V	et	f	\N
166299	vallapästetud	?vallapästetud =vallapästetu  (PlN  >vallapästetu !01_A	et	f	\N
166300	vallapästetud	?vallapästetud =vallapästetu  (IndPrSg2  >vallapästetuma !27_V	et	f	\N
166301	vallapästetud	?vallapästetud =vallapästetud  (ID  >vallapästetud !41_A	et	f	\N
166302	vallapästetud	?vallapästetud =päste  (PtsPtIps  >valla+_pästema !27_V	et	f	\N
166303	vallapästetud	?vallapästetud =pästetu  (PlN  >valla+pästetu !01_AS	et	f	\N
166304	haibil	?haibil =haibi  (SgAd  >haibi !16_S	et	f	\N
166305	haibil	?haibil =haibi  (SgAd  >haip !22_S	et	f	\N
166306	kodumaist	kodumaist =ma  (PlEl  >kodu+maa !26_S	et	f	\N
166307	kodumaist	kodumaist =mai  (SgEl  >kodu+mai !26_S	et	f	\N
166308	kodumaist	kodumaist =mais  (SgP  >kodu+maine !10_A	et	f	\N
166309	kodumaist	"kodu+maine %mai  )NE_aA  <kodu+maa ;26_S	et	f	\N
166324	mõttetöö	mõttetöö =töö  (SgN  >mõtte+töö !26_S	et	f	\N
166325	mõttetöö	mõttetöö =töö  (SgG  >mõtte+töö !26_S	et	f	\N
166360	julgema	julgema =julge  (Sup  >julgema !27_V	et	f	\N
166361	julgema	julgema =julgema  (SgG  >julgem !02_A	et	f	\N
166362	julgema	"julgem %julge  )M_cA  <julge ;01_A	et	f	\N
166379	lapselaps	lapselaps =laps  (SgN  >lapse+laps !14_S	et	f	\N
166380	lapselaps	lapselaps =laps  (SgN  >lapse+laps !22_S	et	f	\N
166381	häbene	häbene =häbene  (IndPrPs_  >häbenema !27_V	et	f	\N
166382	häbene	häbene =häbene  (ImpPrSg2  >häbenema !27_V	et	f	\N
166395	kristikivi	?kristikivi =kristikivi  (ID  >kristikivi !41_D	et	f	\N
166396	kristikivi	?kristikivi =kristikivi  (SgG  >kristikiv !02_A	et	f	\N
166400	jlaatan	?jlaatan =jlaata  (IndPrSg1  >jlaatama !27_V	et	f	\N
166401	jlaatan	?jlaatan =jlaatan  (SgN  >jlaatan !02_S	et	f	\N
166406	ukaruks	?ukaruks =ukaru  (SgTr  >ukaru !01_S	et	f	\N
166056	eses	?eses =eses  (SgN  >eses !09_S	et	f	\N
166061	mini	mini =mi  (SgTer  >mi !26_S	et	f	\N
166062	mini	mini =mini  (SgN  >mini !17~16_S	et	f	\N
166063	mini	mini =mini  (SgG  >mini !17~16_S	et	f	\N
166064	mini	mini =mini  (SgP  >mini !17_S	et	f	\N
166073	rd	### rd	et	f	\N
166084	otsese	otsese =otsese  (SgG  >otsene !10_A	et	f	\N
166085	otsese	otsese =ese  (SgN  >ots+ese !04_S	et	f	\N
166086	seg	### seg	et	f	\N
166087	lii	lii =lii  (SgN  >lii !26_S	et	f	\N
166088	lii	lii =lii  (SgG  >lii !26_S	et	f	\N
166089	num	### num	et	f	\N
166109	ln	### ln	et	f	\N
166113	kindl	?kindl =kindl  (SgN  >kindl !22_S	et	f	\N
166122	riikid	### riikid	et	f	\N
166124	elmo	?elmo =elmo  (SgN  >elmo !16_S	et	f	\N
166125	elmo	?elmo =elmo  (SgG  >elmo !16_S	et	f	\N
166129	lavastatud	lavastatud =lavasta  (PtsPtIps  >lavastama !27_V	et	f	\N
166130	lavastatud	lavastatud =lavastatu  (PlN  >lavastatu !01_S	et	f	\N
166131	lavastatud	"lavastatu %lavasta  )TU1_vS  <lavastama ;27_V	et	f	\N
166132	lavastatud	lavastatud =lavastatud  (ID  >lavastatud !41_A	et	f	\N
166133	lavastatud	"lavastatud %lavasta  )TUD_vA  <lavastama ;27_V	et	f	\N
166140	sünniaega	sünniaega =aega  (SgP  >sünni+aeg !22_S	et	f	\N
166141	sünniaega	sünniaega =aega  (SgAdt  >sünni+aeg !22_S	et	f	\N
166163	nurjunud	nurjunud =nurju  (PtsPtPs  >nurjuma !27_V	et	f	\N
166164	nurjunud	nurjunud =nurjunu  (PlN  >nurjunu !01_S	et	f	\N
166165	nurjunud	"nurjunu %nurju  )NU_vS  <nurjuma ;27_V	et	f	\N
166166	nurjunud	nurjunud =nurjunud  (ID  >nurjunud !41_A	et	f	\N
166167	nurjunud	"nurjunud %nurju  )NUD_vA  <nurjuma ;27_V	et	f	\N
166196	koolivelide	?koolivelide =kooliveli  (PlG  >koolivel !19_S	et	f	\N
166197	kõlanud	kõlanud =kõla  (PtsPtPs  >kõlama !27_V	et	f	\N
166198	kõlanud	kõlanud =kõlanu  (PlN  >kõlanu !01_S	et	f	\N
166199	kõlanud	"kõlanu %kõla  )NU_vS  <kõlama ;27_V	et	f	\N
166200	kõlanud	kõlanud =kõlanud  (ID  >kõlanud !41_A	et	f	\N
166201	kõlanud	"kõlanud %kõla  )NUD_vA  <kõlama ;27_V	et	f	\N
166208	isamaalisuse	isamaalisuse =maalisuse  (SgG  >isa+maalisus !11_S	et	f	\N
166209	isamaalisuse	"isa+maalisus %maa  )LISUS_aS  <isa+maa ;26_S	et	f	\N
166210	isamaalisuse	"isa+maalisus %maali  )SUS_aS  <isa+maal ;22_S	et	f	\N
166213	noorpõlve	noorpõlve =põlve  (SgG  >noor+põlv !22_S	et	f	\N
166214	noorpõlve	noorpõlve =põlve  (SgG  >noor+põli !24_S	et	f	\N
166215	noorpõlve	noorpõlve =põlve  (SgP  >noor+põlv !22_S	et	f	\N
166216	noorpõlve	noorpõlve =põlve  (SgP  >noor+põli !24_S	et	f	\N
166217	noorpõlve	noorpõlve =põlve  (SgAdt  >noor+põlv !22_S	et	f	\N
166218	noorpõlve	noorpõlve =põlve  (SgAdt  >noor+põli !24_S	et	f	\N
166219	noorpõlve	noorpõlve =põlve  (PlP  >noor+põlv !22_S	et	f	\N
166229	tääkereid	?tääkereid =tääkere  (PlP  >tääkeri !01_S	et	f	\N
166230	tääkereid	?tääkereid =tääkere  (PlP  >tääker !02_S	et	f	\N
166231	tääkereid	?tääkereid =tääkerei  (PlN  >tääkerei !26_S	et	f	\N
166232	tääkereid	?tääkereid =tääkerei  (SgP  >tääkerei !26_S	et	f	\N
166242	raskepäraselt	raskepäraselt =pärase  (SgAbl  >raske+pärane !10_A	et	f	\N
166243	raskepäraselt	"raske+pärane %pära  )NE_aA  <raske+pära ;17_S	et	f	\N
166244	raskepäraselt	"raske+päraselt %pära  )SELT_mD  <raske+pära ;17_S	et	f	\N
166245	raskepäraselt	"raske+päraselt %pärase  )LT_mD  <raske+pärane ;10_A	et	f	\N
166264	tugevaks	tugevaks =tugeva  (SgTr  >tugev !02_A	et	f	\N
166265	tugevaks	"tugev %tuge  )V_vA  <tugema ;27_V	et	f	\N
166289	toimekus	toimekus =toimekus  (SgN  >toimekus !11_S	et	f	\N
166290	toimekus	"toimekus %toimeka  )US_aS  <toimekas ;02_A	et	f	\N
166291	2003a	### 2003a	et	f	\N
166292	sõjadraama	sõjadraama =draama  (SgN  >sõja+draama !16_S	et	f	\N
166293	sõjadraama	sõjadraama =draama  (SgG  >sõja+draama !16_S	et	f	\N
166296	koolikaslaste	koolikaslaste =las  (PlG  >kooli+kas+laps !14_S	et	f	\N
166297	koolikaslaste	koolikaslaste =laste  (PlP  >kooli+kas+last !22_S	et	f	\N
166298	koolikaslaste	koolikaslaste =kaslas  (PlG  >kooli+kaslane !12?10_S	et	f	\N
166310	massiivselt	massiivselt =massiivse  (SgAbl  >massiivne !02_A	et	f	\N
166312	massiivselt	massiivselt =massiivselt  (ID  >massiivselt !41_D	et	f	\N
166314	massiivselt	"massiivselt %massiivse  )LT_mD  <massiivne ;02_A	et	f	\N
166328	minagi	minagi =mina  (SgN^  >mina !00_P	et	f	\N
166329	minagi	minagi =mi  (SgEs^  >mi !26_S	et	f	\N
166330	minagi	minagi =mina  (SgN^  >mina !17_S	et	f	\N
166331	minagi	minagi =mina  (SgG^  >mina !17_S	et	f	\N
166332	minagi	minagi =mina  (SgP^  >mina !17_S	et	f	\N
166344	vaevaks	vaevaks =vaeva  (SgTr  >vaev !22_S	et	f	\N
166345	vaevaks	vaevaks =vaeva  (KndPrPs  >vaevama !29_V	et	f	\N
166346	vaevaks	vaevaks =vaks  (SgN  >vae+vaks !22_S	et	f	\N
166347	selgete	selgete =selge  (PlG  >selge !01_A	et	f	\N
166348	selgete	selgete =e  (PlG  >selg+esi !15_S	et	f	\N
166349	meeldetuletust	meeldetuletust =tust  (SgN  >meelde+tule+tust !22_S	et	f	\N
166350	meeldetuletust	meeldetuletust =tuletu  (SgEl  >meelde+tuletu !01_AS	et	f	\N
166351	meeldetuletust	"meelde+tuletu %tule  )TU2_kA  <meelde+tuli ;20_S	et	f	\N
166225	käspereid	?käspereid =käspere  (PlP  >käsperi !01_S	et	f	\N
166226	käspereid	?käspereid =käspere  (PlP  >käsper !02_S	et	f	\N
166227	käspereid	?käspereid =käsperei  (PlN  >käsperei !26_S	et	f	\N
166228	käspereid	?käspereid =käsperei  (SgP  >käsperei !26_S	et	f	\N
166233	ahaseid	ahaseid =ahase  (PlP  >ahane !10_A	et	f	\N
166234	ahaseid	"ahane %aha  )NE_aA  <ahk ;22_S	et	f	\N
166239	hukkumist	hukkumist =hukkumis  (SgP  >hukkumine !12_S	et	f	\N
166240	hukkumist	"hukkumine %hukku  )MINE_vS  <hukkuma ;27_V	et	f	\N
166241	hukkumist	"hukkumine %hukku  )MINE_vS  <hukkuma ;28_V	et	f	\N
166254	põimitud	põimitud =põimi  (PtsPtIps  >põimima !28_V	et	f	\N
166255	põimitud	põimitud =põimitu  (PlN  >põimitu !01_AS	et	f	\N
166257	põimitud	"põimitu %põimi  )TU1_vS  <põimima ;28_V	et	f	\N
166259	põimitud	"põimitu %põimi  )TU2_kA  <põim ;22_S	et	f	\N
166261	põimitud	põimitud =põimitud  (ID  >põimitud !41_A	et	f	\N
166263	põimitud	"põimitud %põimi  )TUD_vA  <põimima ;28_V	et	f	\N
166266	tõmmaks	?tõmmaks =tõmma  (SgTr  >tõmma !16_S	et	f	\N
166267	tõmmaks	?tõmmaks =tõmma  (KndPrPs  >tõmmama !29_V	et	f	\N
166333	tunnetanud	tunnetanud =tunneta  (PtsPtPs  >tunnetama !27_V	et	f	\N
166334	tunnetanud	tunnetanud =tunnetanu  (PlN  >tunnetanu !01_S	et	f	\N
166335	tunnetanud	"tunnetanu %tunneta  )NU_vS  <tunnetama ;27_V	et	f	\N
166336	tunnetanud	tunnetanud =tunnetanud  (ID  >tunnetanud !41_A	et	f	\N
166337	tunnetanud	"tunnetanud %tunneta  )NUD_vA  <tunnetama ;27_V	et	f	\N
166363	koolipoisid	koolipoisid =poi  (PlP  >kooli+poi !26_S	et	f	\N
166364	koolipoisid	koolipoisid =poisi  (PlN  >kooli+poiss !23?22_S	et	f	\N
166369	tõidki	tõidki =tõ  (IndIpfSg2^  >tooma !38_V	et	f	\N
166370	tõidki	tõidki =tõ  (IndIpfPl3^  >tooma !38_V	et	f	\N
166389	konfrontatsioon	?konfrontatsioon =konfrontatsioon  (SgN  >konfrontatsioon !22_S	et	f	\N
166394	pagulas	?pagulas =pagula  (SgIn  >pagula !01_S	et	f	\N
166398	fgrünthal	?fgrünthal =fgrüntha  (SgAd  >fgrüntha !01_S	et	f	\N
166399	fgrünthal	?fgrünthal =fgrünthal  (SgN  >fgrünthal !02_S	et	f	\N
166416	02021918a	### 02021918a	et	f	\N
166425	kaugenemine	kaugenemine =kaugenemine  (SgN  >kaugenemine !12_S	et	f	\N
166426	kaugenemine	"kaugenemine %kaugene  )MINE_vS  <kaugenema ;27_V	et	f	\N
166476	haarasid	haarasid =haara  (PlP  >haar !22_S	et	f	\N
166477	haarasid	haarasid =haara  (IndIpfSg2  >haarama !29_V	et	f	\N
166478	haarasid	haarasid =haara  (IndIpfPl3  >haarama !29_V	et	f	\N
166491	eksisteerimiseks	eksisteerimiseks =eksisteerimise  (SgTr  >eksisteerimine !12_S	et	f	\N
166492	eksisteerimiseks	"eksisteerimine %eksisteeri  )MINE_vS  <eksisteerima ;28_V	et	f	\N
166493	eksisteerimiseks	eksisteerimiseks =erimise  (SgTr  >eks+iste+erimine !12_S	et	f	\N
166494	eksisteerimiseks	"eks+iste+erimine %erimi  )NE_aA  <eks+iste+erim ;02_S	et	f	\N
166511	seadnud	seadnud =sead  (PtsPtPs  >seadma !34_V	et	f	\N
166512	seadnud	seadnud =seadnu  (PlN  >seadnu !01_S	et	f	\N
166513	seadnud	"seadnu %sead  )NU_vS  <seadma ;34_V	et	f	\N
166514	seadnud	seadnud =seadnud  (ID  >seadnud !41_A	et	f	\N
166515	seadnud	"seadnud %sead  )NUD_vA  <seadma ;34_V	et	f	\N
166518	sõjalistesse	sõjalistesse =sõjalis  (PlIll  >sõjaline !12_A	et	f	\N
166519	sõjalistesse	"sõjaline %sõja  )LINE_aA  <sõda ;18_S	et	f	\N
166528	madalapalgaline	madalapalgaline =palgaline  (SgN  >madala+palgaline !12_SA	et	f	\N
166529	madalapalgaline	"madala+palgaline %palga  )LINE_aA  <madala+palk ;22_S	et	f	\N
166530	armee	armee =armee  (SgN  >armee !26_S	et	f	\N
166532	armee	armee =armee  (SgG  >armee !26_S	et	f	\N
166534	laiskusest	laiskusest =laiskuse  (SgEl  >laiskus !11~09_S	et	f	\N
166535	laiskusest	"laiskus %laisk  )US_aS  <laisk ;22_A	et	f	\N
166536	laiskusest	laiskusest =laiskuses  (SgP  >laiskusene !12_A	et	f	\N
166537	laiskusest	"laiskusene %laiskuse  )NE_aA  <laiskus ;09_S	et	f	\N
166538	laiskusest	"laiskusene %laiskuse  )NE_aA  <laiskus ;11_S	et	f	\N
166539	laiskusest	laiskusest =use  (PlEl  >laisk+usk !22_S	et	f	\N
166547	kiirusel	kiirusel =kiiruse  (SgAd  >kiirus !11~09_S	et	f	\N
166548	kiirusel	"kiirus %kiire  )US_aS  <kiire ;01_A	et	f	\N
166549	kiirusel	kiirusel =use  (PlAd  >kiir+usk !22_S	et	f	\N
166566	kivikas	?kivikas =kivika  (SgIn  >kivika !01_S	et	f	\N
166567	kivikas	?kivikas =kivika  (SgIn  >kivikas !02_S	et	f	\N
166568	kivikas	?kivikas =kivikas  (SgN  >kivikas !02_S	et	f	\N
166605	1948a	### 1948a	et	f	\N
166624	ühekülgsuse	ühekülgsuse =külgsuse  (SgG  >ühe+külgsus !11~09_S	et	f	\N
166625	ühekülgsuse	"ühe+külgsus %külgse  )US_aS  <ühe+külgne ;02_A	et	f	\N
166626	filminimetus	filminimetus =nimetu  (SgIn  >filmi+nimetu !01_A	et	f	\N
166627	filminimetus	"filmi+nimetu %nime  )TU2_kA  <filmi+nimi ;20_S	et	f	\N
166628	filminimetus	filminimetus =nimetus  (SgN  >filmi+nimetus !11_S	et	f	\N
166629	filminimetus	"filmi+nimetus %nime  )TUS2_aS  <filmi+nimi ;20_S	et	f	\N
166641	antsi	?antsi =antsi  (ID  >antsi !41_D	et	f	\N
166642	antsi	?antsi =antsi  (SgG  >ants !22_S	et	f	\N
166643	antsi	?antsi =antsi  (SgP  >ants !22_S	et	f	\N
166644	antsi	?antsi =antsi  (SgAdt  >ants !22_S	et	f	\N
166645	antsi	?antsi =antsi  (IndPrPs_  >antsima !28_V	et	f	\N
166646	antsi	?antsi =antsi  (ImpPrSg2  >antsima !28_V	et	f	\N
166268	põlvkonnal	põlvkonnal =põlvkonna  (SgAd  >põlvkond !22_S	et	f	\N
166269	põlvkonnal	põlvkonnal =konna  (SgAd  >põlv+konn !22_S	et	f	\N
166281	rahvuslikust	rahvuslikust =rahvusliku  (SgEl  >rahvuslik !25_A	et	f	\N
166282	rahvuslikust	rahvuslikust =rahvuslikus  (SgP  >rahvuslikus !11?09_S	et	f	\N
166283	rahvuslikust	"rahvuslikus %rahvusliku  )US_aS  <rahvuslik ;25_A	et	f	\N
166318	nüganen	?nüganen =nügane  (IndPrSg1  >nüganema !27_V	et	f	\N
166319	nüganen	?nüganen =nüganen  (SgN  >nüganen !19_S	et	f	\N
166320	loomiseks	loomiseks =loomise  (SgTr  >loomis !09_S	et	f	\N
166321	loomiseks	loomiseks =loomise  (SgTr  >loomine !12?10_S	et	f	\N
166322	loomiseks	"loomine %loo  )MINE_vS  <looma ;38_V	et	f	\N
166323	loomiseks	"loomine %loomi  )NE_aA  <loom ;22_S	et	f	\N
166342	kangelastegu	kangelastegu =tegu  (SgN  >kangelas+tegu !18_S	et	f	\N
166343	kangelastegu	kangelastegu =tegu  (SgP  >kangelas+tegu !18_S	et	f	\N
166367	julgesid	julgesid =julge  (IndIpfSg2  >julgema !27_V	et	f	\N
166368	julgesid	julgesid =julge  (IndIpfPl3  >julgema !27_V	et	f	\N
166371	viletsamad	viletsamad =viletsama  (PlN  >viletsam !02_A	et	f	\N
166372	viletsamad	"viletsam %viletsa  )M_cA  <vilets ;02_A	et	f	\N
166412	arenev	arenev =arene  (PtsPrPs  >arenema !27_V	et	f	\N
166413	arenev	arenev =arenev  (SgN  >arenev !02_A	et	f	\N
166414	arenev	"arenev %arene  )V_vA  <arenema ;27_V	et	f	\N
166427	malatov	?malatov =malatov  (SgN  >malatov !02_A	et	f	\N
166431	mõjusfääri	mõjusfääri =sfääri  (SgG  >mõju+sfäär !22_S	et	f	\N
166432	mõjusfääri	mõjusfääri =sfääri  (SgP  >mõju+sfäär !22_S	et	f	\N
166433	mõjusfääri	mõjusfääri =sfääri  (SgAdt  >mõju+sfäär !22_S	et	f	\N
166444	14061941a	### 14061941a	et	f	\N
166445	korjamiseks	korjamiseks =korjamise  (SgTr  >korjamine !12_S	et	f	\N
166446	korjamiseks	"korjamine %korja  )MINE_vS  <korjama ;29_V	et	f	\N
166452	lõppemist	lõppemist =lõppemis  (SgP  >lõppemine !12_S	et	f	\N
166453	lõppemist	"lõppemine %lõppe  )MINE_vS  <lõppema ;27_V	et	f	\N
166454	lõppemist	"lõppemine %lõppe  )MINE_vS  <lõppema ;28_V	et	f	\N
166455	lõppemist	lõppemist =emis  (SgP  >lõpp+emis !09_S	et	f	\N
166463	eesotsa	eesotsa =otsa  (SgG  >ees+ots !23?22_S	et	f	\N
166464	eesotsa	eesotsa =otsa  (SgP  >ees+ots !23?22_S	et	f	\N
166465	eesotsa	eesotsa =otsa  (SgAdt  >ees+ots !23?22_S	et	f	\N
166466	vabam	vabam =vabam  (SgN  >vabam !02_A	et	f	\N
166467	vabam	"vabam %vaba  )M_cA  <vaba ;17_A	et	f	\N
166468	sõltuvatel	sõltuvatel =sõltuva  (PlAd  >sõltuv !02_A	et	f	\N
166469	sõltuvatel	"sõltuv %sõltu  )V_vA  <sõltuma ;27_V	et	f	\N
166486	faktiliselt	faktiliselt =faktilise  (SgAbl  >faktiline !12_A	et	f	\N
166487	faktiliselt	"faktiline %fakti  )LINE_aA  <fakt ;22_S	et	f	\N
166488	faktiliselt	faktiliselt =faktiliselt  (ID  >faktiliselt !41_D	et	f	\N
166489	faktiliselt	"faktiliselt %fakti  )LISELT_mD  <fakt ;22_S	et	f	\N
166490	faktiliselt	"faktiliselt %faktilise  )LT_mD  <faktiline ;12_A	et	f	\N
166495	kõrgemaiks	kõrgemaiks =kõrgema  (PlTr  >kõrgem !02_A	et	f	\N
166496	kõrgemaiks	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
166497	kõrgemaiks	kõrgemaiks =iks  (SgN  >kõrg+ema+iks !22_S	et	f	\N
166498	kõrgemaiks	kõrgemaiks =ma  (PlTr  >kõrge+maa !26_S	et	f	\N
166499	kõrgemaiks	kõrgemaiks =mai  (SgTr  >kõrge+mai !26_S	et	f	\N
166505	eksisteerimise	eksisteerimise =eksisteerimise  (SgG  >eksisteerimine !12_S	et	f	\N
166506	eksisteerimise	"eksisteerimine %eksisteeri  )MINE_vS  <eksisteerima ;28_V	et	f	\N
166507	eksisteerimise	eksisteerimise =erimise  (SgG  >eks+iste+erimine !12_S	et	f	\N
166508	eksisteerimise	"eks+iste+erimine %erimi  )NE_aA  <eks+iste+erim ;02_S	et	f	\N
166522	eksisteerimine	eksisteerimine =eksisteerimine  (SgN  >eksisteerimine !12_S	et	f	\N
166523	eksisteerimine	"eksisteerimine %eksisteeri  )MINE_vS  <eksisteerima ;28_V	et	f	\N
166524	eksisteerimine	eksisteerimine =erimine  (SgN  >eks+iste+erimine !12_S	et	f	\N
166525	eksisteerimine	"eks+iste+erimine %erimi  )NE_aA  <eks+iste+erim ;02_S	et	f	\N
166570	suur-jaani	suur-jaani =jaani  (SgG  >suur-jaan !22_S	et	f	\N
166571	suur-jaani	suur-jaani =jaani  (SgP  >suur-jaan !22_S	et	f	\N
166573	suur-jaani	suur-jaani =jaani  (SgAdt  >suur-jaan !22_S	et	f	\N
166576	sännu	?sännu =sännu  (SgN  >sännu !16_S	et	f	\N
166577	sännu	?sännu =sännu  (SgG  >sännu !16_S	et	f	\N
166578	sännu	?sännu =sännu  (IndPrPs_  >sännuma !27_V	et	f	\N
166579	sännu	?sännu =sännu  (ImpPrSg2  >sännuma !27_V	et	f	\N
166582	tõõtas	?tõõtas =tõõta  (SgIn  >tõõta !16_S	et	f	\N
166583	tõõtas	?tõõtas =tõõta  (IndIpfSg3  >tõõtama !27_V	et	f	\N
166584	tõõtas	?tõõtas =tõõtas  (SgN  >tõõtas !07_S	et	f	\N
166585	kongruna	?kongruna =kongru  (SgEs  >kongru !01_S	et	f	\N
166586	palgast	palgast =palga  (SgEl  >palk !22_S	et	f	\N
166587	palgast	palgast =palgas  (SgP  >palgane !10_A	et	f	\N
166588	palgast	"palgane %palga  )NE_aA  <palk ;22_S	et	f	\N
166589	taganesid	taganesid =tagane  (IndIpfSg2  >taganema !27_V	et	f	\N
166590	taganesid	taganesid =tagane  (IndIpfPl3  >taganema !27_V	et	f	\N
166591	ahas	ahas =aha  (SgIn  >ahk !22_S	et	f	\N
166592	ahas	ahas =ahas  (SgN  >ahas !07_A	et	f	\N
166595	ründasid	ründasid =ründa  (IndIpfSg2  >ründama !29_V	et	f	\N
166288	uhkusest	"uhkusene %uhkuse  )NE_aA  <uhkus ;11_S	et	f	\N
166294	vestlusteemaks	vestlusteemaks =maks  (SgN  >vestlus+tee+maks !22_S	et	f	\N
166295	vestlusteemaks	vestlusteemaks =teema  (SgTr  >vestlus+teema !16_S	et	f	\N
166311	tutvustatud	tutvustatud =tutvusta  (PtsPtIps  >tutvustama !27_V	et	f	\N
166313	tutvustatud	tutvustatud =tutvustatu  (PlN  >tutvustatu !01_S	et	f	\N
166315	tutvustatud	"tutvustatu %tutvusta  )TU1_vS  <tutvustama ;27_V	et	f	\N
166316	tutvustatud	tutvustatud =tutvustatud  (ID  >tutvustatud !41_A	et	f	\N
166317	tutvustatud	"tutvustatud %tutvusta  )TUD_vA  <tutvustama ;27_V	et	f	\N
166326	tundu	tundu =tundu  (IndPrPs_  >tunduma !27_V	et	f	\N
166327	tundu	tundu =tundu  (ImpPrSg2  >tunduma !27_V	et	f	\N
166338	teravalt	teravalt =terava  (SgAbl  >terav !02_A	et	f	\N
166339	teravalt	teravalt =teravalt  (ID  >teravalt !41_D	et	f	\N
166340	teravalt	"teravalt %terava  )LT_mD  <terav ;02_A	et	f	\N
166341	teravalt	teravalt =alt  (SgN  >terav+alt !22_S	et	f	\N
166378	marmortahvlilpeamõte	### marmortahvlilpeamõte	et	f	\N
166383	saavutatud	saavutatud =saavuta  (PtsPtIps  >saavutama !27_V	et	f	\N
166384	saavutatud	saavutatud =saavutatu  (PlN  >saavutatu !01_S	et	f	\N
166385	saavutatud	"saavutatu %saavuta  )TU1_vS  <saavutama ;27_V	et	f	\N
166386	saavutatud	saavutatud =saavutatud  (ID  >saavutatud !41_A	et	f	\N
166387	saavutatud	"saavutatud %saavuta  )TUD_vA  <saavutama ;27_V	et	f	\N
166391	1eesti	eesti =eesti  (ID  >eesti !41_G	et	f	\N
166392	1eesti	eesti =eesti  (SgN  >eesti !16_H	et	f	\N
166393	1eesti	eesti =eesti  (SgG  >eesti !16_H	et	f	\N
166397	klepik	?klepik =klepik  (SgN  >klepik !02_S	et	f	\N
166402	paguluseks	paguluseks =paguluse  (SgTr  >pagulus !11_S	et	f	\N
166403	paguluseks	"pagulus %pagulase  )US_aS  <pagulane ;12_S	et	f	\N
166404	iivaste	?iivaste =iivas  (PlG  >iivas !07_S	et	f	\N
166405	iivaste	?iivaste =iivas  (PlG  >iivane !10_A	et	f	\N
166408	järjepidevuse	järjepidevuse =pidevuse  (SgG  >järje+pidevus !11_S	et	f	\N
166409	järjepidevuse	"järje+pidevus %pideva  )US_aS  <järje+pidev ;02_A	et	f	\N
166415	demokratlik	?demokratlik =demokratlik  (SgN  >demokratlik !25_A	et	f	\N
166419	endla	?endla =endla  (SgN  >endla !01_S	et	f	\N
166420	endla	?endla =endla  (SgG  >endla !01_S	et	f	\N
166421	endla	?endla =endla  (IndPrPs_  >endlama !29_V	et	f	\N
166422	endla	?endla =endla  (ImpPrSg2  >endlama !29_V	et	f	\N
166423	valimiseni	valimiseni =valimise  (SgTer  >valimine !12_S	et	f	\N
166424	valimiseni	"valimine %vali  )MINE_vS  <valima ;27_V	et	f	\N
166434	marssisid	marssisid =marssi  (PlP  >marss !22_S	et	f	\N
166435	marssisid	marssisid =marssi  (IndIpfSg2  >marssima !28_V	et	f	\N
166436	marssisid	marssisid =marssi  (IndIpfPl3  >marssima !28_V	et	f	\N
166450	sõdisid	sõdisid =sõdi  (IndIpfSg2  >sõdima !27_V	et	f	\N
166451	sõdisid	sõdisid =sõdi  (IndIpfPl3  >sõdima !27_V	et	f	\N
166470	tegusid	tegusid =tegu  (PlP  >tegu !18_S	et	f	\N
166471	tegusid	tegusid =tegusi  (PlN  >tegus !02_A	et	f	\N
166472	tõed	tõed =tõe  (PlN  >tõsi !15_S	et	f	\N
166473	tõed	tõed =tõe  (PlN  >tõde !18_S	et	f	\N
166474	mõttevahetused	mõttevahetused =vahetuse  (PlN  >mõtte+vahetus !11_S	et	f	\N
166475	mõttevahetused	"mõtte+vahetus %vahe  )TUS2_aS  <mõtte+vahe ;16_S	et	f	\N
166484	jätkuks	jätkuks =jätku  (SgTr  >jätk !22_S	et	f	\N
166485	jätkuks	jätkuks =jätku  (KndPrPs  >jätkuma !27_V	et	f	\N
166500	liikmeline	liikmeline =liikmeline  (SgN  >liikmeline !12_A	et	f	\N
166501	liikmeline	"liikmeline %liikme  )LINE_aA  <liige ;05_S	et	f	\N
166509	eelduseks	eelduseks =eelduse  (SgTr  >eeldus !11~09_S	et	f	\N
166510	eelduseks	"eeldus %eelda  )US_vS  <eeldama ;27_V	et	f	\N
166516	nato	?nato =nato  (SgN  >nato !16_S	et	f	\N
166517	nato	?nato =nato  (SgG  >nato !16_S	et	f	\N
166526	eluvaldkonnad	eluvaldkonnad =konna  (PlN  >elu+vald+konn !22_S	et	f	\N
166527	eluvaldkonnad	eluvaldkonnad =valdkonna  (PlN  >elu+valdkond !22_S	et	f	\N
166559	edukamalt	edukamalt =edukama  (SgAbl  >edukam !02_A	et	f	\N
166560	edukamalt	"edukam %eduka  )M_cA  <edukas ;02_A	et	f	\N
166561	edukamalt	edukamalt =edukamalt  (ID  >edukamalt !41_D	et	f	\N
166562	edukamalt	"edukamalt %eduka  )MALT_mD  <edukas ;02_A	et	f	\N
166563	edukamalt	edukamalt =kama  (SgAbl  >edu+kama !17_S	et	f	\N
166575	olustvere	### olustvere	et	f	\N
166597	reaalsuse	reaalsuse =reaalsuse  (SgG  >reaalsus !11~09_S	et	f	\N
166599	reaalsuse	"reaalsus %reaalse  )US_aS  <reaalne ;02_A	et	f	\N
166612	rühmituses	rühmituses =rühmituse  (SgIn  >rühmitus !11_S	et	f	\N
166613	rühmituses	"rühmitus %rühmita  )US_vS  <rühmitama ;27_V	et	f	\N
166614	rühmituses	"rühmitus %rühmi  )TUS2_aS  <rühm ;22_S	et	f	\N
166633	apolitiline	?apolitiline =apolitiline  (SgN  >apolitiline !12_A	et	f	\N
166634	apolitiline	?apolitiline =apolitiline  (PlP  >apolitilin !19_S	et	f	\N
166657	richardiga	?richardiga =richardi  (SgKom  >richardi !01_S	et	f	\N
166658	richardiga	?richardiga =richardi  (SgKom  >richard !02_S	et	f	\N
166659	richardiga	?richardiga =richardi  (SgKom  >richart !22_S	et	f	\N
166683	näitanud	?näitanud =näitanu  (PlN  >näitanu !01_S	et	f	\N
166684	näitanud	?näitanud =näitanu  (IndPrSg2  >näitanuma !27_V	et	f	\N
166352	meeldetuletust	meeldetuletust =tuletus  (SgP  >meelde+tuletus !11_S	et	f	\N
166353	meeldetuletust	"meelde+tuletus %tule  )TUS2_aS  <meelde+tuli ;20_S	et	f	\N
166354	võidetud	võidetud =võide  (PtsPtIps  >võitma !34_V	et	f	\N
166355	võidetud	võidetud =võidetu  (PlN  >võidetu !01_S	et	f	\N
166356	võidetud	"võidetu %võide  )TU1_vS  <võitma ;34_V	et	f	\N
166357	võidetud	"võidetu %võide  )TU2_kA  <võie ;06_S	et	f	\N
166358	võidetud	võidetud =võidetud  (ID  >võidetud !41_A	et	f	\N
166359	võidetud	"võidetud %võide  )TUD_vA  <võitma ;34_V	et	f	\N
166365	tugevale	tugevale =tugeva  (SgAll  >tugev !02_A	et	f	\N
166366	tugevale	"tugev %tuge  )V_vA  <tugema ;27_V	et	f	\N
166373	nihkunud	nihkunud =nihku  (PtsPtPs  >nihkuma !27_V	et	f	\N
166374	nihkunud	nihkunud =nihkunu  (PlN  >nihkunu !01_S	et	f	\N
166375	nihkunud	"nihkunu %nihku  )NU_vS  <nihkuma ;27_V	et	f	\N
166376	nihkunud	nihkunud =nihkunud  (ID  >nihkunud !41_A	et	f	\N
166377	nihkunud	"nihkunud %nihku  )NUD_vA  <nihkuma ;27_V	et	f	\N
166388	eksiilis	eksiilis =eksiili  (SgIn  >eksiil !22_S	et	f	\N
166390	eksiilis	eksiilis =iili  (SgIn  >eks+iil !22_S	et	f	\N
166410	ajajärgus	ajajärgus =järgu  (SgIn  >aja+järk !22_S	et	f	\N
166411	ajajärgus	ajajärgus =järgus  (SgN  >aja+järgus !11~09_S	et	f	\N
166417	kuulutati	kuulutati =kuuluta  (IndIpfIps  >kuulutama !27_V	et	f	\N
166418	kuulutati	kuulutati =tati  (SgG  >kuulu+tatt !22_S	et	f	\N
166439	vastastikuse	vastastikuse =vastastikuse  (SgG  >vastastikune !10?12_A	et	f	\N
166440	vastastikuse	vastastikuse =astikuse  (SgG  >vast+astikune !10?12_A	et	f	\N
166441	vastastikuse	"vast+astikune %astiku  )NE_aA  <vast+astik ;02_S	et	f	\N
166442	alustamiseks	alustamiseks =alustamise  (SgTr  >alustamine !12_S	et	f	\N
166443	alustamiseks	"alustamine %alusta  )MINE_vS  <alustama ;27_V	et	f	\N
166456	võiduga	võiduga =võidu  (SgKom  >võidu !01_S	et	f	\N
166457	võiduga	"võidu %või  )TU1_vS  <võima ;37_V	et	f	\N
166458	võiduga	võiduga =võidu  (SgKom  >võit !22_S	et	f	\N
166459	osatähtsus	osatähtsus =tähtsus  (SgN  >osa+tähtsus !11~09_S	et	f	\N
166460	osatähtsus	"osa+tähtsus %tähtsa  )US_aS  <osa+tähtis ;02_A	et	f	\N
166479	juunikuised	juunikuised =kuise  (PlN  >juuni+kuine !10_A	et	f	\N
166480	juunikuised	"juuni+kuine %kui  )NE_aA  <juuni+kuu ;26_S	et	f	\N
166520	ainuõige	ainuõige =õige  (SgN  >ainu+õige !01_A	et	f	\N
166521	ainuõige	ainuõige =õige  (SgG  >ainu+õige !01_A	et	f	\N
166531	töötute	töötute =töötu  (PlG  >töötu !01_AS	et	f	\N
166533	töötute	"töötu %töö  )TU2_kA  <töö ;26_S	et	f	\N
166540	liiguta	liiguta =liigu  (SgAb  >liik !22_S	et	f	\N
166541	liiguta	liiguta =liigu  (IndPrIps_  >liikuma !28_V	et	f	\N
166542	liiguta	liiguta =liiguta  (IndPrPs_  >liigutama !27_V	et	f	\N
166543	liiguta	liiguta =liiguta  (ImpPrSg2  >liigutama !27_V	et	f	\N
166580	teenijana	teenijana =teenija  (SgEs  >teenija !01_S	et	f	\N
166581	teenijana	"teenija %teeni  )JA_vS  <teenima ;28_V	et	f	\N
166593	valutasid	valutasid =valuta  (IndIpfSg2  >valutama !27_V	et	f	\N
166594	valutasid	valutasid =valuta  (IndIpfPl3  >valutama !27_V	et	f	\N
166648	antsit	?antsit =antsit  (SgN  >antsit !02_S	et	f	\N
166662	sood	sood =soo  (PlN  >sugu !18_S	et	f	\N
166663	sood	sood =soo  (PlN  >soo !26_S	et	f	\N
166664	sood	sood =soo  (SgP  >soo !26_S	et	f	\N
166665	haavatuteks	haavatuteks =haavatu  (PlTr  >haavatu !01_S	et	f	\N
166666	haavatuteks	"haavatu %haava  )TU1_vS  <haavama ;29_V	et	f	\N
166667	haavatuteks	"haavatu %haava  )TU2_kA  <haab ;22_S	et	f	\N
166668	haavatuteks	"haavatu %haava  )TU2_kA  <haav ;22_S	et	f	\N
166669	haavatuteks	haavatuteks =tute  (PlTr  >haava+tutt !22_S	et	f	\N
166675	vabastajate	vabastajate =vabastaja  (PlG  >vabastaja !01_S	et	f	\N
166676	vabastajate	"vabastaja %vabasta  )JA_vS  <vabastama ;27_V	et	f	\N
166677	jõudsam	jõudsam =jõudsam  (SgN  >jõudsam !02_A	et	f	\N
166678	jõudsam	"jõudsam %jõudsa  )M_cA  <jõudus ;02_A	et	f	\N
166679	armaspoeg	?armaspoeg =armaspoeg  (SgN  >armaspoeg !22_S	et	f	\N
166682	prof	### prof	et	f	\N
166712	intelligentid	### intelligentid	et	f	\N
166717	teadust	teadust =teadu  (SgEl  >tead !22_S	et	f	\N
166718	teadust	teadust =teadus  (SgP  >teadus !11~09_S	et	f	\N
166725	korrusest	korrusest =korruse  (SgEl  >korrus !09_S	et	f	\N
166726	korrusest	korrusest =korruses  (SgP  >korrusene !12_A	et	f	\N
166727	korrusest	"korrusene %korruse  )NE_aA  <korrus ;09_S	et	f	\N
166732	antsule	?antsule =antsule  (IndPrPs_  >antsulema !27_V	et	f	\N
166733	antsule	?antsule =antsule  (ImpPrSg2  >antsulema !27_V	et	f	\N
166740	kuivatamise	kuivatamise =kuivatamise  (SgG  >kuivatamine !12_S	et	f	\N
166741	kuivatamise	"kuivatamine %kuivata  )MINE_vS  <kuivatama ;27_V	et	f	\N
166750	miinase	?miinase =miinase  (SgG  >miinane !10_A	et	f	\N
166751	põrkasid	põrkasid =põrka  (PlP  >põrk !22_S	et	f	\N
166752	põrkasid	põrkasid =põrka  (IndIpfSg2  >põrkama !29_V	et	f	\N
166753	põrkasid	põrkasid =põrka  (IndIpfPl3  >põrkama !29_V	et	f	\N
166768	riikluse	riikluse =riikluse  (SgG  >riiklus !11~09_S	et	f	\N
166769	riikluse	"riiklus %riiklase  )US_aS  <riiklane ;12_S	et	f	\N
166770	viiekroonilisel	viiekroonilisel =kroonilise  (SgAd  >viie+krooniline !12_A	et	f	\N
166407	ukaruks	?ukaruks =ukaru  (KndPrPs  >ukaruma !27_V	et	f	\N
166428	ribbendropi	?ribbendropi =ribbendropi  (SgG  >ribbendropp !22_S	et	f	\N
166429	ribbendropi	?ribbendropi =ribbendropi  (IndPrPs_  >ribbendroppima !28_V	et	f	\N
166430	ribbendropi	?ribbendropi =ribbendropi  (ImpPrSg2  >ribbendroppima !28_V	et	f	\N
166437	sõjajõud	sõjajõud =jõu  (PlN  >sõja+jõud !22_S	et	f	\N
166438	sõjajõud	sõjajõud =jõud  (SgN  >sõja+jõud !22_S	et	f	\N
166447	leeri	leeri =leeri  (SgG  >leer !22_S	et	f	\N
166448	leeri	leeri =leeri  (SgP  >leer !22_S	et	f	\N
166449	leeri	leeri =leeri  (SgAdt  >leer !22_S	et	f	\N
166461	kompartei	kompartei =partei  (SgN  >kom+partei !26_S	et	f	\N
166462	kompartei	kompartei =partei  (SgG  >kom+partei !26_S	et	f	\N
166481	öölaulupeod	öölaulupeod =peo  (PlN  >öö+laulu+pidu !18_S	et	f	\N
166482	öölaulupeod	öölaulupeod =peo  (PlN  >öö+laulu+peo !26_S	et	f	\N
166483	öölaulupeod	öölaulupeod =peo  (SgP  >öö+laulu+peo !26_S	et	f	\N
166502	kohtu-	kohtu- =kohtu  (SgG  >kohus !05_S	et	f	\N
166503	kohtu-	kohtu- =kohtu  (IndPrPs_  >kohtuma !27_V	et	f	\N
166504	kohtu-	kohtu- =kohtu  (ImpPrSg2  >kohtuma !27_V	et	f	\N
166544	meeletul	meeletul =meeletu  (SgAd  >meeletu !01_A	et	f	\N
166545	meeletul	"meeletu %meele  )TU2_kA  <meel ;13_S	et	f	\N
166546	meeletul	meeletul =letu  (SgAd  >mee+letu !16_S	et	f	\N
166550	millestki	millestki =mille  (SgEl  >miski !00_P	et	f	\N
166551	millestki	millestki =mille  (SgEl^  >mis !00_P	et	f	\N
166552	õpitust	õpitust =õpitu  (SgEl  >õpitu !01_S	et	f	\N
166553	õpitust	"õpitu %õpi  )TU1_vS  <õppima ;28_V	et	f	\N
166554	õpitust	"õpitu %õpi  )TU2_kA  <õpp ;22_S	et	f	\N
166555	õpitust	õpitust =õpitus  (SgP  >õpitus !11_S	et	f	\N
166556	õpitust	"õpitus %õpi  )TUS1_aS  <õppima ;28_V	et	f	\N
166557	õpitust	"õpitus %õpi  )TUS2_aS  <õpp ;22_S	et	f	\N
166558	õpitust	õpitust =tust  (SgN  >õpi+tust !22_S	et	f	\N
166564	tõetruu	tõetruu =truu  (SgN  >tõe+truu !26_A	et	f	\N
166565	tõetruu	tõetruu =truu  (SgG  >tõe+truu !26_A	et	f	\N
166569	1898a	### 1898a	et	f	\N
166572	põhja-viljandimaal	põhja-viljandimaal =maa  (SgAd  >põhja-viljandi+maa !26_S	et	f	\N
166574	põhja-viljandimaal	põhja-viljandimaal =maal  (SgN  >põhja-viljandi+maal !22_S	et	f	\N
166598	karmi	karmi =karmi  (SgG  >karm !22_S	et	f	\N
166600	karmi	karmi =karmi  (SgG  >karm !22_A	et	f	\N
166601	karmi	karmi =karmi  (SgP  >karm !22_S	et	f	\N
166602	karmi	karmi =karmi  (SgP  >karm !22_A	et	f	\N
166603	karmi	karmi =karmi  (SgAdt  >karm !22_S	et	f	\N
166604	karmi	karmi =karmi  (SgAdt  >karm !22_A	et	f	\N
166608	langenute	langenute =langenu  (PlG  >langenu !01_S	et	f	\N
166609	langenute	"langenu %lange  )NU_vS  <langema ;27_V	et	f	\N
166615	siurut	?siurut =siuru  (SgP  >siuru !16_S	et	f	\N
166616	siurut	?siurut =siurut  (SgN  >siurut !02_S	et	f	\N
166622	urooninalik	?urooninalik =urooninalik  (SgN  >urooninalik !25_A	et	f	\N
166623	stililise	?stililise =stililise  (SgG  >stililine !12_A	et	f	\N
166630	tungimisega	tungimisega =tungimise  (SgKom  >tungimine !12_S	et	f	\N
166631	tungimisega	"tungimine %tungi  )MINE_vS  <tungima ;28_V	et	f	\N
166632	miilase	?miilase =miilase  (SgG  >miilane !12?10_S	et	f	\N
166640	ralf	?ralf =ralf  (SgN  >ralf !22_S	et	f	\N
166647	ant	?ant =ant  (SgN  >ant !22_S	et	f	\N
166660	sõjaväelastega	sõjaväelastega =las  (PlKom  >sõja+väe+laps !14_S	et	f	\N
166661	sõjaväelastega	sõjaväelastega =väelas  (PlKom  >sõja+väelane !12?10_S	et	f	\N
166670	vabastatud	vabastatud =vabasta  (PtsPtIps  >vabastama !27_V	et	f	\N
166671	vabastatud	vabastatud =vabastatu  (PlN  >vabastatu !01_S	et	f	\N
166672	vabastatud	"vabastatu %vabasta  )TU1_vS  <vabastama ;27_V	et	f	\N
166673	vabastatud	vabastatud =vabastatud  (ID  >vabastatud !41_A	et	f	\N
166674	vabastatud	"vabastatud %vabasta  )TUD_vA  <vabastama ;27_V	et	f	\N
166687	näitljaid	?näitljaid =näitlja  (PlP  >näitlja !01_S	et	f	\N
166688	näitljaid	?näitljaid =näitlja  (PlP  >näitljas !02_A	et	f	\N
166689	näitljaid	?näitljaid =näitljai  (PlN  >näitljai !26_S	et	f	\N
166690	näitljaid	?näitljaid =näitljai  (SgP  >näitljai !26_S	et	f	\N
166691	näitljaid	?näitljaid =näitljaid  (SgN  >näitljaid !22_S	et	f	\N
166756	väärilisteks	väärilisteks =väärilis  (PlTr  >vääriline !12_A	et	f	\N
166757	väärilisteks	"vääriline %vääri  )LINE_aA  <väär ;22_S	et	f	\N
166777	konkreetsem	konkreetsem =konkreetsem  (SgN  >konkreetsem !02_A	et	f	\N
166778	konkreetsem	"konkreetsem %konkreetse  )M_cA  <konkreetne ;02_A	et	f	\N
166779	püsi	püsi =püsi  (SgN  >püsi !17_S	et	f	\N
166780	püsi	püsi =püsi  (SgG  >püsi !17_S	et	f	\N
166781	püsi	püsi =püsi  (SgP  >püsi !17_S	et	f	\N
166782	püsi	püsi =püsi  (IndPrPs_  >püsima !27_V	et	f	\N
166783	püsi	püsi =püsi  (ImpPrSg2  >püsima !27_V	et	f	\N
166792	segalasteaiad	segalasteaiad =aia  (PlN  >sega+laste+aed !22_S	et	f	\N
166793	segalasteaiad	segalasteaiad =aia  (PlN  >sega+laste+ai !22_S	et	f	\N
166794	1980a	### 1980a	et	f	\N
166797	kaitstumatuid	?kaitstumatuid =kaitstumatu  (PlP  >kaitstumatu !01_A	et	f	\N
166798	kaitstumatuid	?kaitstumatuid =kaitstumatui  (PlN  >kaitstumatui !26_S	et	f	\N
166596	ründasid	ründasid =ründa  (IndIpfPl3  >ründama !29_V	et	f	\N
166606	paranemise	paranemise =paranemise  (SgG  >paranemine !12_S	et	f	\N
166607	paranemise	"paranemine %parane  )MINE_vS  <paranema ;27_V	et	f	\N
166610	tegutsevas	tegutsevas =tegutseva  (SgIn  >tegutsev !02_A	et	f	\N
166611	tegutsevas	"tegutsev %tegutse  )V_vA  <tegutsema ;27_V	et	f	\N
166617	kõide	?kõide =kõi  (PlG  >kõi !26_S	et	f	\N
166618	kõide	?kõide =kõide  (SgN  >kõide !06_S	et	f	\N
166619	kõide	?kõide =kõide  (PlP  >kõid !22_S	et	f	\N
166620	kõide	?kõide =kõide  (IndPrPs_  >kõidema !27_V	et	f	\N
166621	kõide	?kõide =kõide  (ImpPrSg2  >kõidema !27_V	et	f	\N
166635	eva	?eva =eva  (SgN  >eva !17_S	et	f	\N
166636	eva	?eva =eva  (SgG  >eva !17_S	et	f	\N
166637	eva	?eva =eva  (SgP  >eva !17_S	et	f	\N
166638	eva	?eva =eva  (IndPrPs_  >evama !27_V	et	f	\N
166639	eva	?eva =eva  (ImpPrSg2  >evama !27_V	et	f	\N
166680	pojas	pojas =poja  (SgIn  >poja !17_S	et	f	\N
166681	pojas	pojas =poja  (SgIn  >poeg !22_S	et	f	\N
166696	läbiotsivad	läbiotsivad =iva  (PlN  >läbi+ots+iva !17_S	et	f	\N
166697	läbiotsivad	läbiotsivad =otsiva  (PlN  >läbi+otsiv !02_A	et	f	\N
166701	antsile	?antsile =antsi  (SgAll  >ants !22_S	et	f	\N
166702	antsile	?antsile =antsile  (IndPrPs_  >antsilema !27_V	et	f	\N
166703	antsile	?antsile =antsile  (ImpPrSg2  >antsilema !27_V	et	f	\N
166706	luuletajaga	luuletajaga =luuletaja  (SgKom  >luuletaja !01_S	et	f	\N
166707	luuletajaga	"luuletaja %luuleta  )JA_vS  <luuletama ;27_V	et	f	\N
166713	vennapoja	vennapoja =poja  (SgN  >venna+poja !17_S	et	f	\N
166714	vennapoja	vennapoja =poja  (SgG  >venna+poja !17_S	et	f	\N
166715	vennapoja	vennapoja =poja  (SgG  >venna+poeg !22_S	et	f	\N
166716	vennapoja	vennapoja =poja  (SgP  >venna+poja !17_S	et	f	\N
166736	konfiskeerisid	konfiskeerisid =konfiskeeri  (IndIpfSg2  >konfiskeerima !28_V	et	f	\N
166737	konfiskeerisid	konfiskeerisid =konfiskeeri  (IndIpfPl3  >konfiskeerima !28_V	et	f	\N
166739	sander	?sander =sander  (SgN  >sander !02_S	et	f	\N
166748	ükskõikseteks	ükskõikseteks =sete  (PlTr  >üks+kõik+sett !22_S	et	f	\N
166749	ükskõikseteks	ükskõikseteks =kõikse  (PlTr  >üks+kõikne !02_A	et	f	\N
166758	korratus	korratus =korratu  (SgIn  >korratu !01_AS	et	f	\N
166759	korratus	"korratu %korra  )TU1_vS  <kordama ;29_V	et	f	\N
166760	korratus	"korratu %korra  )TU2_kA  <kord ;22_S	et	f	\N
166761	korratus	korratus =korratus  (SgN  >korratus !11_S	et	f	\N
166762	korratus	"korratus %korra  )TUS1_aS  <kordama ;29_V	et	f	\N
166763	korratus	"korratus %korra  )TUS2_aS  <kord ;22_S	et	f	\N
166764	19701980ndate	?ndate =ndate  (SgN  >ndate !06_S	et	f	\N
166765	19701980ndate	?ndate =ndate  (IndPrPs_  >ndatema !27_V	et	f	\N
166766	19701980ndate	?ndate =ndate  (ImpPrSg2  >ndatema !27_V	et	f	\N
166767	nation	?nation =nation  (SgN  >nation !19_S	et	f	\N
166784	elupaika	elupaika =paika  (SgP  >elu+paik !22_S	et	f	\N
166787	elupaika	elupaika =paika  (SgAdt  >elu+paik !22_S	et	f	\N
166834	ähmased	ähmased =ähmase  (PlN  >ähmane !10_A	et	f	\N
166835	ähmased	"ähmane %ähma  )NE_aA  <ähm ;22_S	et	f	\N
166836	määratlemiseks	määratlemiseks =määratlemise  (SgTr  >määratlemine !12_S	et	f	\N
166837	määratlemiseks	"määratlemine %määratle  )MINE_vS  <määratlema ;27_V	et	f	\N
166840	organiseeri	organiseeri =organiseeri  (IndPrPs_  >organiseerima !28_V	et	f	\N
166841	organiseeri	organiseeri =organiseeri  (ImpPrSg2  >organiseerima !28_V	et	f	\N
166846	külastati	külastati =külasta  (IndIpfIps  >külastama !27_V	et	f	\N
166847	külastati	külastati =tati  (SgG  >külas+tatt !22_S	et	f	\N
166848	ausamblite	?ausamblite =ausambli  (PlG  >ausambli !01_S	et	f	\N
166849	ausamblite	?ausamblite =ausambli  (PlG  >ausambel !02_S	et	f	\N
166850	ausamblite	?ausamblite =ausambli  (IndPrPl2  >ausamblima !28_V	et	f	\N
166855	ausamblite	?ausamblite =sambli  (PlG  >au+sambli !01_S	et	f	\N
166856	ausamblite	?ausamblite =sambli  (PlG  >au+sambel !02_S	et	f	\N
166868	mitteeestlaste	mitteeestlaste =las  (PlG  >mitte+eest+laps !14_S	et	f	\N
166869	mitteeestlaste	mitteeestlaste =laste  (PlP  >mitte+eest+last !22_S	et	f	\N
166870	mitteeestlaste	mitteeestlaste =eestlas  (PlG  >mitte+eestlane !12?10_S	et	f	\N
166872	orienteeritud	orienteeritud =orienteeri  (PtsPtIps  >orienteerima !28_V	et	f	\N
166873	orienteeritud	orienteeritud =orienteeritu  (PlN  >orienteeritu !01_S	et	f	\N
166874	orienteeritud	"orienteeritu %orienteeri  )TU1_vS  <orienteerima ;28_V	et	f	\N
166875	orienteeritud	orienteeritud =orienteeritud  (ID  >orienteeritud !41_A	et	f	\N
166876	orienteeritud	"orienteeritud %orienteeri  )TUD_vA  <orienteerima ;28_V	et	f	\N
166887	kaitsmine	kaitsmine =kaitsmine  (SgN  >kaitsmine !12?10_S	et	f	\N
166888	kaitsmine	"kaitsmine %kaits  )MINE_vS  <kaitsma ;32_V	et	f	\N
166894	agraarimiskord	?agraarimiskord =agraarimiskord  (SgN  >agraarimiskord !22_S	et	f	\N
166895	agraarimiskord	?agraarimiskord =imiskord  (SgN  >agraar+imiskord !22_S	et	f	\N
166900	käen	?käen =käen  (SgN  >käen !22_S	et	f	\N
166901	saamisest	saamisest =saamise  (SgEl  >saamine !12?10_S	et	f	\N
166902	saamisest	"saamine %saa  )MINE_vS  <saama ;37_V	et	f	\N
166903	saamisest	"saamine %saami  )NE_aA  <saam ;22_S	et	f	\N
166934	avaldasid	avaldasid =avalda  (IndIpfSg2  >avaldama !27_V	et	f	\N
166649	armanud	?armanud =arma  (PtsPtPs  >armama !29_V	et	f	\N
166650	armanud	?armanud =armanu  (PlN  >armanu !01_S	et	f	\N
166651	armanud	?armanud =armanu  (IndPrSg2  >armanuma !27_V	et	f	\N
166652	armanud	?armanud =armanud  (ID  >armanud !41_A	et	f	\N
166653	silmapilgust	silmapilgust =pilgu  (SgEl  >silma+pilk !22_S	et	f	\N
166654	silmapilgust	silmapilgust =pilgu  (PlEl  >silma+pilk !22_S	et	f	\N
166655	vennapojaga	vennapojaga =poja  (SgKom  >venna+poja !17_S	et	f	\N
166656	vennapojaga	vennapojaga =poja  (SgKom  >venna+poeg !22_S	et	f	\N
166692	eeva	?eeva =eeva  (SgN  >eeva !16_S	et	f	\N
166693	eeva	?eeva =eeva  (SgG  >eeva !16_S	et	f	\N
166694	eeva	?eeva =eeva  (IndPrPs_  >eevama !29_V	et	f	\N
166695	eeva	?eeva =eeva  (ImpPrSg2  >eevama !29_V	et	f	\N
166704	pommid	pommid =pommi  (PlN  >pomm !22_S	et	f	\N
166705	pommid	pommid =pommi  (IndPrSg2  >pommima !28_V	et	f	\N
166708	luuletajale	luuletajale =luuletaja  (SgAll  >luuletaja !01_S	et	f	\N
166709	luuletajale	"luuletaja %luuleta  )JA_vS  <luuletama ;27_V	et	f	\N
166710	vaimule	vaimule =vaimu  (SgAll  >vaim !22_S	et	f	\N
166711	vaimule	vaimule =vaimu  (PlAll  >vaim !22_S	et	f	\N
166738	sp	### sp	et	f	\N
166742	miinas	?miinas =miina  (SgIn  >miina !16_S	et	f	\N
166743	miinas	?miinas =miina  (IndIpfSg3  >miinama !29_V	et	f	\N
166744	miinas	?miinas =miinas  (SgN  >miinas !07_S	et	f	\N
166745	muretsevad	muretsevad =muretse  (IndPrPl3  >muretsema !27_V	et	f	\N
166746	muretsevad	muretsevad =muretseva  (PlN  >muretsev !02_A	et	f	\N
166747	muretsevad	"muretsev %muretse  )V_vA  <muretsema ;27_V	et	f	\N
166785	1970ndate	?ndate =ndate  (SgN  >ndate !06_S	et	f	\N
166786	1970ndate	?ndate =ndate  (IndPrPs_  >ndatema !27_V	et	f	\N
166788	1970ndate	?ndate =ndate  (ImpPrSg2  >ndatema !27_V	et	f	\N
166795	1980-ndatel	?-ndatel =ndate  (PlAd  >-ndatt !22_S	et	f	\N
166796	1980-ndatel	?-ndatel =ndatel  (SgN  >-ndatel !02_S	et	f	\N
166804	dotseeritud	dotseeritud =dotseeri  (PtsPtIps  >dotseerima !28_V	et	f	\N
166805	dotseeritud	dotseeritud =dotseeritu  (PlN  >dotseeritu !01_S	et	f	\N
166806	dotseeritud	"dotseeritu %dotseeri  )TU1_vS  <dotseerima ;28_V	et	f	\N
166807	dotseeritud	dotseeritud =dotseeritud  (ID  >dotseeritud !41_A	et	f	\N
166808	dotseeritud	"dotseeritud %dotseeri  )TUD_vA  <dotseerima ;28_V	et	f	\N
166809	ideaaliks	ideaaliks =ideaali  (SgTr  >ideaal !22_S	et	f	\N
166810	ideaaliks	ideaaliks =iks  (SgN  >ideaal+iks !22_S	et	f	\N
166811	1988a	### 1988a	et	f	\N
166896	konstrueerimiseks	konstrueerimiseks =konstrueerimise  (SgTr  >konstrueerimine !12_S	et	f	\N
166897	konstrueerimiseks	"konstrueerimine %konstrueeri  )MINE_vS  <konstrueerima ;28_V	et	f	\N
166909	õppinguraamatule	?õppinguraamatule =õppinguraamatu  (SgAll  >õppinguraamatu !01_A	et	f	\N
166910	õppinguraamatule	?õppinguraamatule =õppinguraamatule  (PlP  >õppinguraamatul !19_S	et	f	\N
166919	2004a	### 2004a	et	f	\N
166924	tavalisest	tavalisest =tavalise  (SgEl  >tavaline !12_A	et	f	\N
166925	tavalisest	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
166929	tegelikkusest	tegelikkusest =tegelikkuse  (SgEl  >tegelikkus !11~09_S	et	f	\N
166930	tegelikkusest	"tegelikkus %tegelikku  )US_aS  <tegelik ;25_A	et	f	\N
166931	tegelikkusest	tegelikkusest =tegelikkuses  (SgP  >tegelikkusene !12_A	et	f	\N
166932	tegelikkusest	"tegelikkusene %tegelikkuse  )NE_aA  <tegelikkus ;09_S	et	f	\N
166933	tegelikkusest	"tegelikkusene %tegelikkuse  )NE_aA  <tegelikkus ;11_S	et	f	\N
166941	muutumisest	muutumisest =muutumise  (SgEl  >muutumine !12_S	et	f	\N
166942	muutumisest	"muutumine %muutu  )MINE_vS  <muutuma ;27_V	et	f	\N
166944	vaadanud	vaadanud =vaada  (PtsPtPs  >vaatama !29_V	et	f	\N
166945	vaadanud	vaadanud =vaadanu  (PlN  >vaadanu !01_S	et	f	\N
166946	vaadanud	"vaadanu %vaada  )NU_vS  <vaatama ;29_V	et	f	\N
166947	vaadanud	vaadanud =vaadanud  (ID  >vaadanud !41_A	et	f	\N
166948	vaadanud	"vaadanud %vaada  )NUD_vA  <vaatama ;29_V	et	f	\N
166979	samanimelisele	samanimelisele =nimelise  (SgAll  >sama+nimeline !12_A	et	f	\N
166980	samanimelisele	"sama+nimeline %nime  )LINE_aA  <sama+nimi ;20_S	et	f	\N
166981	rungegeorg	?rungegeorg =rungegeorg  (SgN  >rungegeorg !22_S	et	f	\N
166986	kurvestiga	### kurvestiga	et	f	\N
167003	töölisrahvast	töölisrahvast =rahva  (SgEl  >töölis+rahvas !07_S	et	f	\N
167004	töölisrahvast	töölisrahvast =rahvas  (SgP  >töölis+rahvas !07_S	et	f	\N
167005	töölisrahvast	töölisrahvast =rahvas  (SgP  >töölis+rahvane !10_A	et	f	\N
167006	töölisrahvast	"töölis+rahvane %rahva  )NE_aA  <töölis+rahvas ;07_S	et	f	\N
167038	lootused	lootused =lootuse  (PlN  >lootus !11~09_S	et	f	\N
167039	lootused	"lootus %loo  )TUS2_aS  <lugu ;18_S	et	f	\N
167040	lootused	"lootus %loo  )TUS2_aS  <loog ;22_S	et	f	\N
167041	lootused	"lootus %loo  )TUS2_aS  <lood ;22_S	et	f	\N
167051	ahnus	ahnus =ahnus  (SgN  >ahnus !11~09_S	et	f	\N
167052	ahnus	"ahnus %ahne  )US_aS  <ahne ;01_A	et	f	\N
167059	märkamatult	märkamatult =märkamatu  (SgAbl  >märkamatu !01_A	et	f	\N
167060	märkamatult	"märkamatu %märka  )MATU_vA  <märkama ;29_V	et	f	\N
167061	märkamatult	märkamatult =märkamatult  (ID  >märkamatult !41_D	et	f	\N
167062	märkamatult	"märkamatult %märka  )MATULT_mD  <märkama ;29_V	et	f	\N
167063	märkamatult	"märkamatult %märkamatu  )LT_mD  <märkamatu ;01_A	et	f	\N
166685	näitanud	?näitanud =näitanud  (ID  >näitanud !41_A	et	f	\N
166686	näitanud	?näitanud =anu  (PlN  >näit+anu !17_S	et	f	\N
166698	jämedalt	jämedalt =jämeda  (SgAbl  >jäme !02_A	et	f	\N
166699	jämedalt	jämedalt =jämedalt  (ID  >jämedalt !41_D	et	f	\N
166700	jämedalt	"jämedalt %jämeda  )LT_mD  <jäme ;02_A	et	f	\N
166719	haavatuid	haavatuid =haavatu  (PlP  >haavatu !01_S	et	f	\N
166720	haavatuid	"haavatu %haava  )TU1_vS  <haavama ;29_V	et	f	\N
166721	haavatuid	"haavatu %haava  )TU2_kA  <haab ;22_S	et	f	\N
166722	haavatuid	"haavatu %haava  )TU2_kA  <haav ;22_S	et	f	\N
166723	haavatuid	haavatuid =tui  (PlN  >haava+tui !26_S	et	f	\N
166724	haavatuid	haavatuid =tui  (SgP  >haava+tui !26_S	et	f	\N
166728	haavatute	haavatute =haavatu  (PlG  >haavatu !01_S	et	f	\N
166729	haavatute	"haavatu %haava  )TU1_vS  <haavama ;29_V	et	f	\N
166730	haavatute	"haavatu %haava  )TU2_kA  <haab ;22_S	et	f	\N
166731	haavatute	"haavatu %haava  )TU2_kA  <haav ;22_S	et	f	\N
166734	ralfil	?ralfil =ralfi  (SgAd  >ralfi !16_S	et	f	\N
166735	ralfil	?ralfil =ralfi  (SgAd  >ralf !22_S	et	f	\N
166754	tapmiseni	tapmiseni =tapmise  (SgTer  >tapmine !12?10_S	et	f	\N
166755	tapmiseni	"tapmine %tap  )MINE_vS  <tapma ;35_V	et	f	\N
166775	1teisel	teisel =teise  (SgAd  >teine !12_OP	et	f	\N
166776	1teisel	teisel =teise  (SgAd  >teise !12_P	et	f	\N
166800	suuresti	suuresti =suuresti  (ID  >suuresti !41_D	et	f	\N
166801	suuresti	suuresti =resti  (SgG  >suu+rest !22_S	et	f	\N
166802	suuresti	suuresti =resti  (SgP  >suu+rest !22_S	et	f	\N
166803	suuresti	suuresti =resti  (SgAdt  >suu+rest !22_S	et	f	\N
166814	avaldakse	?avaldakse =avaldakse  (SgG  >avaldakne !02_A	et	f	\N
166830	sakalas	?sakalas =sakala  (SgIn  >sakala !01_S	et	f	\N
166838	etnosi	?etnosi =etnosi  (ID  >etnosi !41_D	et	f	\N
166839	etnosi	?etnosi =etnosi  (PlP  >etnos !11_S	et	f	\N
166857	differentsiooni	?differentsiooni =differentsioo  (SgTer  >differentsioo !26_S	et	f	\N
166858	differentsiooni	?differentsiooni =differentsiooni  (SgN  >differentsiooni !16_S	et	f	\N
166859	differentsiooni	?differentsiooni =differentsiooni  (SgG  >differentsiooni !16_S	et	f	\N
166860	differentsiooni	?differentsiooni =differentsiooni  (SgG  >differentsioon !22_S	et	f	\N
166861	differentsiooni	?differentsiooni =differentsiooni  (SgP  >differentsioon !22_S	et	f	\N
166862	differentsiooni	?differentsiooni =differentsiooni  (SgAdt  >differentsioon !22_S	et	f	\N
166863	differentsiooni	?differentsiooni =differentsiooni  (IndPrPs_  >differentsioonima !28_V	et	f	\N
166864	differentsiooni	?differentsiooni =differentsiooni  (ImpPrSg2  >differentsioonima !28_V	et	f	\N
166879	tekkimisel	tekkimisel =tekkimise  (SgAd  >tekkimine !12_S	et	f	\N
166880	tekkimisel	"tekkimine %tekki  )MINE_vS  <tekkima ;27_V	et	f	\N
166881	tekkimisel	"tekkimine %tekki  )MINE_vS  <tekkima ;28_V	et	f	\N
166886	etnoste	?etnoste =etnos  (PlG  >etnos !11~09_S	et	f	\N
166889	liigendatud	liigendatud =liigenda  (PtsPtIps  >liigendama !27_V	et	f	\N
166890	liigendatud	liigendatud =liigendatu  (PlN  >liigendatu !01_S	et	f	\N
166891	liigendatud	"liigendatu %liigenda  )TU1_vS  <liigendama ;27_V	et	f	\N
166892	liigendatud	liigendatud =liigendatud  (ID  >liigendatud !41_A	et	f	\N
166893	liigendatud	"liigendatud %liigenda  )TUD_vA  <liigendama ;27_V	et	f	\N
166904	pavlenko	?pavlenko =pavlenko  (SgN  >pavlenko !16_S	et	f	\N
166906	pavlenko	?pavlenko =pavlenko  (SgG  >pavlenko !16_S	et	f	\N
166907	härra	härra =härra  (SgN  >härra !16_S	et	f	\N
166908	härra	härra =härra  (SgG  >härra !16_S	et	f	\N
166911	jekaterina	?jekaterina =jekateri  (SgEs  >jekatter !02_S	et	f	\N
166912	jekaterina	?jekaterina =jekateri  (SgEs  >jekater !19_S	et	f	\N
166913	jekaterina	?jekaterina =jekaterina  (SgG  >jekaterin !19_S	et	f	\N
166914	jekaterina	?jekaterina =jekaterina  (SgP  >jekaterin !19_S	et	f	\N
166915	jekaterina	?jekaterina =jekaterina  (SgAdt  >jekaterin !19_S	et	f	\N
166916	novikova	?novikova =novikova  (SgN  >novikova !16_S	et	f	\N
166917	novikova	?novikova =novikova  (SgG  >novikov !02_A	et	f	\N
166918	novikova	?novikova =novikova  (SgG  >novikova !16_S	et	f	\N
166920	valmimise	valmimise =valmimise  (SgG  >valmimine !12_S	et	f	\N
166921	valmimise	"valmimine %valmi  )MINE_vS  <valmima ;27_V	et	f	\N
166926	vaimust	vaimust =vaimu  (SgEl  >vaim !22_S	et	f	\N
166927	vaimust	vaimust =vaimu  (PlEl  >vaim !22_S	et	f	\N
166928	vaimust	vaimust =us  (SgP  >vaim+uks !14_S	et	f	\N
166936	inimestevaheliste	inimestevaheliste =vahelis  (PlG  >inimeste+vaheline !12_A	et	f	\N
166937	inimestevaheliste	"inimeste+vaheline %vahe  )LINE_aA  <inimeste+vahe ;16_S	et	f	\N
166960	miks-	miks- =mi  (SgTr  >mi !26_S	et	f	\N
166961	miks-	miks- =miks  (ID  >miks !41_D	et	f	\N
166962	viletsus	viletsus =viletsus  (SgN  >viletsus !11_S	et	f	\N
166963	viletsus	"viletsus %viletsa  )US_aS  <vilets ;02_A	et	f	\N
166964	võõramaiste	võõramaiste =mais  (PlG  >võõra+maine !10_A	et	f	\N
166965	võõramaiste	"võõra+maine %mai  )NE_aA  <võõra+maa ;26_S	et	f	\N
166982	semidor	?semidor =semidor  (SgN  >semidor !19_S	et	f	\N
166989	samaaegselt-	samaaegselt- =aegse  (SgAbl  >sama+aegne !02_A	et	f	\N
166990	samaaegselt-	"sama+aegselt %aegse  )LT_mD  <sama+aegne ;02_A	et	f	\N
166992	stalinliku	?stalinliku =stalinliku  (SgG  >stalinlik !25_A	et	f	\N
166771	viiekroonilisel	"viie+krooniline %krooni  )LINE_aA  <viie+kroon ;22_S	et	f	\N
166772	kerest	kerest =kere  (SgEl  >kere !16_S	et	f	\N
166773	kerest	kerest =keres  (SgP  >kerene !10_A	et	f	\N
166774	kerest	"kerene %kere  )NE_aA  <kere ;16_S	et	f	\N
166789	propagandeeritakse	?propagandeeritakse =propagandeeri  (IndPrIps  >propagandeerima !28_V	et	f	\N
166790	propagandeeritakse	?propagandeeritakse =propagandeeritakse  (SgG  >propagandeeritakne !02_A	et	f	\N
166791	propagandeeritakse	?propagandeeritakse =propagandeeritakse  (PlP  >propagandeeritaks !22_S	et	f	\N
166812	lippu	lippu =lippu  (SgP  >lipp !22_S	et	f	\N
166813	lippu	lippu =lippu  (SgAdt  >lipp !22_S	et	f	\N
166817	maaleja	?maaleja =maaleja  (SgN  >maaleja !01_S	et	f	\N
166818	maaleja	?maaleja =maaleja  (SgG  >maaleja !01_S	et	f	\N
166819	maaleja	?maaleja =maaleja  (SgG  >maalejas !02_A	et	f	\N
166820	maaleja	?maaleja =leja  (SgN  >maa+leja !17_S	et	f	\N
166821	maaleja	?maaleja =leja  (SgG  >maa+leja !17_S	et	f	\N
166822	maaleja	?maaleja =leja  (SgP  >maa+leja !17_S	et	f	\N
166823	maalemiskunsti	maalemiskunsti =kunsti  (SgG  >maale+mis+kunst !22_S	et	f	\N
166824	maalemiskunsti	maalemiskunsti =kunsti  (SgP  >maale+mis+kunst !22_S	et	f	\N
166825	maalemiskunsti	maalemiskunsti =kunsti  (SgAdt  >maale+mis+kunst !22_S	et	f	\N
166826	rahvadele	?rahvadele =rahva  (PlAll  >rahva !16_S	et	f	\N
166827	uudissõna	uudissõna =sõna  (SgN  >uudis+sõna !17_S	et	f	\N
166828	uudissõna	uudissõna =sõna  (SgG  >uudis+sõna !17_S	et	f	\N
166829	uudissõna	uudissõna =sõna  (SgP  >uudis+sõna !17_S	et	f	\N
166831	tavakeele	tavakeele =kee  (SgAll  >tava+kesi !15_S	et	f	\N
166832	tavakeele	tavakeele =kee  (SgAll  >tava+kee !26_S	et	f	\N
166833	tavakeele	tavakeele =keele  (SgG  >tava+keel !13_S	et	f	\N
166842	1kultuuritarbimisetunnused	?kultuuritarbimisetunnused =kultuuritarbimisetunnuse  (PlN  >kultuuritarbimisetunnus !11~09_S	et	f	\N
166843	1kultuuritarbimisetunnused	?kultuuritarbimisetunnused =etunnuse  (PlN  >kultuuri+tarbimis+etunnus !11_S	et	f	\N
166844	1kultuuritarbimisetunnused	?kultuuritarbimisetunnused =tarbimisetunnuse  (PlN  >kultuuri+tarbimisetunnus !11~09_S	et	f	\N
166845	1kultuuritarbimisetunnused	?kultuuritarbimisetunnused =itarbimisetunnuse  (PlN  >kultuur+itarbimisetunnus !11~09_S	et	f	\N
166871	teatridest	?teatridest =teatrides  (SgP  >teatridene !12_A	et	f	\N
166877	olulisimaks	olulisimaks =olulisima  (SgTr  >olulisim !02_A	et	f	\N
166878	olulisimaks	"olulisim %olulisi  )IM_sA  <oluline ;12_A	et	f	\N
166882	interpreteerimisel	interpreteerimisel =interpreteerimise  (SgAd  >interpreteerimine !12_S	et	f	\N
166883	interpreteerimisel	"interpreteerimine %interpreteeri  )MINE_vS  <interpreteerima ;28_V	et	f	\N
166898	esteetika	esteetika =esteetika  (SgN  >esteetika !01_S	et	f	\N
166899	esteetika	esteetika =esteetika  (SgG  >esteetika !01_S	et	f	\N
166922	agiteerimine	agiteerimine =agiteerimine  (SgN  >agiteerimine !12_S	et	f	\N
166923	agiteerimine	"agiteerimine %agiteeri  )MINE_vS  <agiteerima ;28_V	et	f	\N
166938	elulaadi	elulaadi =laadi  (SgG  >elu+laad !22_S	et	f	\N
166939	elulaadi	elulaadi =laadi  (SgP  >elu+laad !22_S	et	f	\N
166940	elulaadi	elulaadi =laadi  (SgAdt  >elu+laad !22_S	et	f	\N
166973	algallikale-	algallikale- =ale  (SgN  >alg+allik+ale !16_S	et	f	\N
166974	algallikale-	algallikale- =ale  (SgG  >alg+allik+ale !16_S	et	f	\N
166975	algallikale-	algallikale- =allika  (SgAll  >alg+allikas !02_S	et	f	\N
166976	leberechti	?leberechti =leberechti  (ID  >leberechti !41_D	et	f	\N
166977	leberechti	?leberechti =leberechti  (IndPrPs_  >leberechtima !28_V	et	f	\N
166978	leberechti	?leberechti =leberechti  (ImpPrSg2  >leberechtima !28_V	et	f	\N
166983	teiseks-	teiseks- =teise  (SgTr  >teine !12_OP	et	f	\N
166984	teiseks-	teiseks- =teise  (SgTr  >teise !12_P	et	f	\N
166985	teiseks-	teiseks- =teiseks  (ID  >teiseks !41_D	et	f	\N
166987	põletamisega	põletamisega =põletamise  (SgKom  >põletamine !12_S	et	f	\N
166988	põletamisega	"põletamine %põleta  )MINE_vS  <põletama ;27_V	et	f	\N
166996	mustvalgelt	?mustvalgelt =mustvalge  (PlAbl  >mustvalk !22_S	et	f	\N
166997	mustvalgelt	?mustvalgelt =mustvalgelt  (ID  >mustvalgelt !41_D	et	f	\N
167042	sitkust	sitkust =sitkus  (SgP  >sitkus !11~09_S	et	f	\N
167043	sitkust	"sitkus %sitke  )US_aS  <sitke ;01_A	et	f	\N
167049	kõrkus	kõrkus =kõrkus  (SgN  >kõrkus !11~09_S	et	f	\N
167050	kõrkus	"kõrkus %kõrk  )US_aS  <kõrk ;22_A	et	f	\N
167055	isoleeritus	isoleeritus =isoleeritu  (SgIn  >isoleeritu !01_S	et	f	\N
167056	isoleeritus	"isoleeritu %isoleeri  )TU1_vS  <isoleerima ;28_V	et	f	\N
167057	isoleeritus	isoleeritus =isoleeritus  (SgN  >isoleeritus !11_S	et	f	\N
167058	isoleeritus	"isoleeritus %isoleeri  )TUS1_aS  <isoleerima ;28_V	et	f	\N
167076	liitumisega	liitumisega =liitumise  (SgKom  >liitumine !12_S	et	f	\N
167077	liitumisega	"liitumine %liitu  )MINE_vS  <liituma ;27_V	et	f	\N
167078	rajamisel	rajamisel =rajamise  (SgAd  >rajamine !12_S	et	f	\N
167079	rajamisel	"rajamine %raja  )MINE_vS  <rajama ;27_V	et	f	\N
167090	eestluse	eestluse =eestluse  (SgG  >eestlus !11~09_S	et	f	\N
167091	eestluse	"eestlus %eestlase  )US_aS  <eestlane ;12_S	et	f	\N
167111	kuuluksid	kuuluksid =kuulu  (KndPrSg2  >kuuluma !27_V	et	f	\N
167112	kuuluksid	kuuluksid =kuulu  (KndPrPl3  >kuuluma !27_V	et	f	\N
167113	kuuluksid	kuuluksid =luksi  (PlN  >kuu+luks !22_S	et	f	\N
167114	kuuluksid	kuuluksid =luksi  (PlN  >kuu+luks !22_SA	et	f	\N
166799	kaitstumatuid	?kaitstumatuid =kaitstumatui  (SgP  >kaitstumatui !26_S	et	f	\N
166815	toetamist	toetamist =toetamis  (SgP  >toetamine !12_S	et	f	\N
166816	toetamist	"toetamine %toeta  )MINE_vS  <toetama ;27_V	et	f	\N
166851	massmeedia	massmeedia =dia  (SgN  >mass+mee+dia !26_S	et	f	\N
166852	massmeedia	massmeedia =dia  (SgG  >mass+mee+dia !26_S	et	f	\N
166853	massmeedia	massmeedia =meedia  (SgN  >mass+meedia !01_S	et	f	\N
166854	massmeedia	massmeedia =meedia  (SgG  >mass+meedia !01_S	et	f	\N
166865	sügavnemine	?sügavnemine =sügavnemine  (SgN  >sügavnemine !12_S	et	f	\N
166866	sügavnemine	?sügavnemine =sügavnemine  (PlP  >sügavnemin !19_S	et	f	\N
166867	sügavnemine	?sügavnemine =nemine  (SgN  >sügav+nemine !10_A	et	f	\N
166884	eelmodernsete	eelmodernsete =sete  (SgN  >eel+modern+sete !06_S	et	f	\N
166885	eelmodernsete	eelmodernsete =modernse  (PlG  >eel+modernne !02_A	et	f	\N
166905	22042004a	### 22042004a	et	f	\N
166949	olevat-	olevat- =ole  (KvtPrPs  >olema !36_V	et	f	\N
166950	olevat-	olevat- =oleva  (SgP  >olev !02_A	et	f	\N
166951	olevat-	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
166958	süzeest	?süzeest =süzee  (SgEl  >süzee !26_S	et	f	\N
166959	süzeest	?süzeest =süzees  (SgP  >süzeene !12~10_A	et	f	\N
166966	raamatugi	raamatugi =raamatu  (SgG^  >raamat !02_S	et	f	\N
166967	raamatugi	raamatugi =atu  (SgG^  >raam+att !22_S	et	f	\N
166968	süzee	?süzee =süzee  (SgN  >süzee !26_S	et	f	\N
166969	süzee	?süzee =süzee  (SgG  >süzee !26_S	et	f	\N
166991	tulise	tulise =tulise  (SgG  >tuline !10_A	et	f	\N
166993	tulise	"tuline %tuli  )NE_aA  <tuli ;20_S	et	f	\N
167013	käsilastest	käsilastest =käsilas  (PlEl  >käsilane !12_S	et	f	\N
167014	käsilastest	käsilastest =aste  (SgEl  >käsil+aste !06_S	et	f	\N
167015	käsilastest	käsilastest =aste  (PlEl  >käsil+ast !22_S	et	f	\N
167016	käsilastest	käsilastest =astes  (SgP  >käsil+astene !12~10_A	et	f	\N
167017	käsilastest	"käsil+astene %aste  )NE_aA  <käsil+aste ;06_S	et	f	\N
167018	käsilastest	käsilastest =las  (PlEl  >käsi+laps !14_S	et	f	\N
167019	käsilastest	käsilastest =laste  (PlEl  >käsi+last !22_S	et	f	\N
167020	määrinud	määrinud =määri  (PtsPtPs  >määrima !28_V	et	f	\N
167021	määrinud	määrinud =määrinu  (PlN  >määrinu !01_S	et	f	\N
167022	määrinud	"määrinu %määri  )NU_vS  <määrima ;28_V	et	f	\N
167023	määrinud	määrinud =määrinud  (ID  >määrinud !41_A	et	f	\N
167024	määrinud	"määrinud %määri  )NUD_vA  <määrima ;28_V	et	f	\N
167064	siiski-	siiski- =siiski  (ID  >siiski !41_D	et	f	\N
167065	siiski-	siiski- =siis  (ID^  >siis !41_D	et	f	\N
167066	püüdleti	?püüdleti =püüdleti  (ID  >püüdleti !41_D	et	f	\N
167067	püüdleti	?püüdleti =püüdleti  (SgG  >püüdlett !22_S	et	f	\N
167068	püüdleti	?püüdleti =püüdleti  (IndPrPs_  >püüdlettima !28_V	et	f	\N
167069	püüdleti	?püüdleti =püüdleti  (ImpPrSg2  >püüdlettima !28_V	et	f	\N
167080	karja	karja =karja  (SgG  >kari !24_S	et	f	\N
167081	karja	karja =karja  (SgP  >kari !24_S	et	f	\N
167082	karja	karja =karja  (SgAdt  >kari !24_S	et	f	\N
167083	sibergi	?sibergi =sibergi  (SgG  >siberg !02_S	et	f	\N
167084	sibergi	?sibergi =sibergi  (SgG  >siberk !22_S	et	f	\N
167085	sibergi	?sibergi =sibergi  (IndPrPs_  >siberkima !28_V	et	f	\N
167086	sibergi	?sibergi =sibergi  (ImpPrSg2  >siberkima !28_V	et	f	\N
167087	sibergi	?sibergi =siber  (SgN^  >siber !02_S	et	f	\N
167088	talupere	talupere =pere  (SgN  >talu+pere !16_S	et	f	\N
167089	talupere	talupere =pere  (SgG  >talu+pere !16_S	et	f	\N
167092	võrsunud	võrsunud =võrsu  (PtsPtPs  >võrsuma !27_V	et	f	\N
167093	võrsunud	võrsunud =võrsunu  (PlN  >võrsunu !01_S	et	f	\N
167094	võrsunud	"võrsunu %võrsu  )NU_vS  <võrsuma ;27_V	et	f	\N
167095	võrsunud	võrsunud =võrsunud  (ID  >võrsunud !41_A	et	f	\N
167096	võrsunud	"võrsunud %võrsu  )NUD_vA  <võrsuma ;27_V	et	f	\N
167097	täitnud	täitnud =täit  (PtsPtPs  >täitma !34_V	et	f	\N
167098	täitnud	täitnud =täitnu  (PlN  >täitnu !01_S	et	f	\N
167099	täitnud	"täitnu %täit  )NU_vS  <täitma ;34_V	et	f	\N
167100	täitnud	täitnud =täitnud  (ID  >täitnud !41_A	et	f	\N
167101	täitnud	"täitnud %täit  )NUD_vA  <täitma ;34_V	et	f	\N
167102	üliolulist	üliolulist =olulis  (SgP  >üli+oluline !12_A	et	f	\N
167103	üliolulist	"üli+oluline %olu  )LINE_aA  <üli+olu ;17_S	et	f	\N
167104	tagaja	tagaja =tagaja  (SgN  >tagaja !01_S	et	f	\N
167105	tagaja	"tagaja %taga  )JA_vS  <tagama ;27_V	et	f	\N
167106	tagaja	tagaja =tagaja  (SgG  >tagaja !01_S	et	f	\N
167130	sugulasperekonnast	sugulasperekonnast =konna  (SgEl  >sugulas+pere+konn !22_S	et	f	\N
167131	sugulasperekonnast	sugulasperekonnast =konnas  (SgP  >sugulas+pere+konnane !10_A	et	f	\N
167132	sugulasperekonnast	"sugulas+pere+konnane %konna  )NE_aA  <sugulas+pere+konn ;22_S	et	f	\N
167133	sugulasperekonnast	sugulasperekonnast =perekonna  (SgEl  >sugulas+perekond !22_S	et	f	\N
167135	sugulasperekonnast	sugulasperekonnast =perekonnas  (SgP  >sugulas+perekonnane !12_A	et	f	\N
167137	sugulasperekonnast	"sugulas+perekonnane %perekonna  )NE_aA  <sugulas+perekond ;22_S	et	f	\N
167152	tootmis-	?tootmis- =tootmi  (SgIn  >tootm !22_S	et	f	\N
167154	tootmis-	?tootmis- =tootmi  (IndIpfSg3  >tootmima !28_V	et	f	\N
166935	avaldasid	avaldasid =avalda  (IndIpfPl3  >avaldama !27_V	et	f	\N
166943	leberecht	### leberecht	et	f	\N
166952	jäänudki	jäänudki =jää  (PtsPtPs^  >jääma !37_V	et	f	\N
166953	jäänudki	jäänudki =jäänu  (PlN^  >jäänu !01_S	et	f	\N
166954	jäänudki	"jäänu %jää  )NU_vS^  <jääma ;37_V	et	f	\N
166955	jäänudki	jäänudki =jäänu  (PlN^  >jäänu !06_S	et	f	\N
166956	jäänudki	jäänudki =jäänud  (ID^  >jäänud !41_A	et	f	\N
166957	jäänudki	"jäänud %jää  )NUD_vA^  <jääma ;37_V	et	f	\N
166970	paljus	paljus =palju  (SgIn  >palju !16_P	et	f	\N
166971	paljus	paljus =paljus  (SgN  >paljus !11~09_S	et	f	\N
166972	paljus	"paljus %palja  )US_aS  <paljas ;07_A	et	f	\N
167007	põlastusväärseistinimestest	?põlastusväärseistinimestest =põlastusväärseistinimes  (PlEl  >põlastusväärseistinimene !12_A	et	f	\N
167008	põlastusväärseistinimestest	?põlastusväärseistinimestest =põlastusväärseistinimestes  (SgP  >põlastusväärseistinimestene !12_A	et	f	\N
167009	põlastusväärseistinimestest	?põlastusväärseistinimestest =seistinimes  (PlEl  >põlastus+väär+seistinimene !12_A	et	f	\N
167010	põlastusväärseistinimestest	?põlastusväärseistinimestest =seistinimestes  (SgP  >põlastus+väär+seistinimestene !12_A	et	f	\N
167011	põlastusväärseistinimestest	?põlastusväärseistinimestest =väärseistinimes  (PlEl  >põlastus+väärseistinimene !12_A	et	f	\N
167012	põlastusväärseistinimestest	?põlastusväärseistinimestest =väärseistinimestes  (SgP  >põlastus+väärseistinimestene !12_A	et	f	\N
167030	voitkad	?voitkad =voitka  (PlN  >voitka !01_S	et	f	\N
167031	voitkad	?voitkad =voitka  (IndPrSg2  >voitkama !29_V	et	f	\N
167032	ilmekalt	ilmekalt =ilmeka  (SgAbl  >ilmekas !02_A	et	f	\N
167033	ilmekalt	ilmekalt =ilmekalt  (ID  >ilmekalt !41_D	et	f	\N
167034	ilmekalt	"ilmekalt %ilmeka  )LT_mD  <ilmekas ;02_A	et	f	\N
167035	elu-olu	elu-olu =olu  (SgN  >elu-olu !17_S	et	f	\N
167036	elu-olu	elu-olu =olu  (SgG  >elu-olu !17_S	et	f	\N
167037	elu-olu	elu-olu =olu  (SgP  >elu-olu !17_S	et	f	\N
167053	valelikkus	valelikkus =valelikkus  (SgN  >valelikkus !11~09_S	et	f	\N
167054	valelikkus	"valelikkus %valelikku  )US_aS  <valelik ;25_A	et	f	\N
167109	elaksid	elaksid =ela  (KndPrSg2  >elama !27_V	et	f	\N
167110	elaksid	elaksid =ela  (KndPrPl3  >elama !27_V	et	f	\N
167125	laienenud	laienenud =laiene  (PtsPtPs  >laienema !27_V	et	f	\N
167126	laienenud	laienenud =laienenu  (PlN  >laienenu !01_S	et	f	\N
167127	laienenud	"laienenu %laiene  )NU_vS  <laienema ;27_V	et	f	\N
167128	laienenud	laienenud =laienenud  (ID  >laienenud !41_A	et	f	\N
167129	laienenud	"laienenud %laiene  )NUD_vA  <laienema ;27_V	et	f	\N
167160	põimusid	põimusid =põimu  (PlP  >põim !22_S	et	f	\N
167161	põimusid	põimusid =põimu  (IndIpfSg2  >põimuma !27_V	et	f	\N
167162	põimusid	põimusid =põimu  (IndIpfPl3  >põimuma !27_V	et	f	\N
167167	perekondi	perekondi =perekondi  (SgP  >perekond !22_S	et	f	\N
167168	perekondi	perekondi =perekondi  (SgAdt  >perekond !22_S	et	f	\N
167169	perekondi	perekondi =perekondi  (PlP  >perekond !22_S	et	f	\N
167170	perekondi	perekondi =kondi  (SgG  >pere+kont !22_S	et	f	\N
167177	metsa-	metsa- =metsa  (SgG  >mets !22_S	et	f	\N
167178	metsa-	metsa- =metsa  (SgP  >mets !22_S	et	f	\N
167179	metsa-	metsa- =metsa  (SgAdt  >mets !22_S	et	f	\N
167186	kalastushooaegadel	### kalastushooaegadel	et	f	\N
167204	kõrvu	kõrvu =kõrvu  (ID  >kõrvu !41_D	et	f	\N
167205	kõrvu	kõrvu =kõrvu  (PlP  >kõrv !22_S	et	f	\N
167219	püsisid	püsisid =püsi  (PlP  >püsi !17_S	et	f	\N
167220	püsisid	püsisid =püsi  (IndIpfSg2  >püsima !27_V	et	f	\N
167221	püsisid	püsisid =püsi  (IndIpfPl3  >püsima !27_V	et	f	\N
167222	majanduslikust	majanduslikust =majandusliku  (SgEl  >majanduslik !25_A	et	f	\N
167223	majanduslikust	majanduslikust =majanduslikus  (SgP  >majanduslikus !11?09_S	et	f	\N
167224	majanduslikust	"majanduslikus %majandusliku  )US_aS  <majanduslik ;25_A	et	f	\N
167225	lahedamad	lahedamad =lahedama  (PlN  >lahedam !02_A	et	f	\N
167226	lahedamad	"lahedam %laheda  )M_cA  <lahe ;02_A	et	f	\N
167235	halvenemine	halvenemine =halvenemine  (SgN  >halvenemine !12_S	et	f	\N
167236	halvenemine	"halvenemine %halvene  )MINE_vS  <halvenema ;27_V	et	f	\N
167237	varasemad	varasemad =varasema  (PlN  >varasem !02_A	et	f	\N
167238	varasemad	"varasem %vara  )SEM_cA  <vara ;17_S	et	f	\N
167239	varasemad	"varasem %varase  )M_cA  <varane ;10_A	et	f	\N
167252	surelikkus	surelikkus =surelikkus  (SgN  >surelikkus !11~09_S	et	f	\N
167253	surelikkus	"surelikkus %surelikku  )US_aS  <surelik ;25_AS	et	f	\N
167263	elamise	elamise =elamise  (SgG  >elamine !12_S	et	f	\N
167264	elamise	"elamine %ela  )MINE_vS  <elama ;27_V	et	f	\N
167265	pärijaks	pärijaks =pärija  (SgTr  >pärija !01_S	et	f	\N
167266	pärijaks	"pärija %päri  )JA_vS  <pärima ;27_V	et	f	\N
167267	pärijaks	pärijaks =jaks  (SgN  >päri+jaks !22_S	et	f	\N
167276	teadvustaksid	teadvustaksid =teadvusta  (KndPrSg2  >teadvustama !27_V	et	f	\N
167277	teadvustaksid	teadvustaksid =teadvusta  (KndPrPl3  >teadvustama !27_V	et	f	\N
167278	teadvustaksid	teadvustaksid =taksi  (PlN  >teadvus+taks !22_S	et	f	\N
167307	omandaksid	omandaksid =omanda  (KndPrSg2  >omandama !27_V	et	f	\N
167308	omandaksid	omandaksid =omanda  (KndPrPl3  >omandama !27_V	et	f	\N
166994	stalinliku	?stalinliku =stalinliku  (IndPrPs_  >stalinlikuma !27_V	et	f	\N
166995	stalinliku	?stalinliku =stalinliku  (ImpPrSg2  >stalinlikuma !27_V	et	f	\N
166998	liigitatud-	liigitatud- =liigita  (PtsPtIps  >liigitama !27_V	et	f	\N
166999	liigitatud-	liigitatud- =liigitatu  (PlN  >liigitatu !01_S	et	f	\N
167000	liigitatud-	"liigitatu %liigita  )TU1_vS  <liigitama ;27_V	et	f	\N
167001	liigitatud-	liigitatud- =liigitatud  (ID  >liigitatud !41_A	et	f	\N
167002	liigitatud-	"liigitatud %liigita  )TUD_vA  <liigitama ;27_V	et	f	\N
167025	muutunud-	muutunud- =muutu  (PtsPtPs  >muutuma !27_V	et	f	\N
167026	muutunud-	muutunud- =muutunu  (PlN  >muutunu !01_S	et	f	\N
167027	muutunud-	"muutunu %muutu  )NU_vS  <muutuma ;27_V	et	f	\N
167028	muutunud-	muutunud- =muutunud  (ID  >muutunud !41_A	et	f	\N
167029	muutunud-	"muutunud %muutu  )NUD_vA  <muutuma ;27_V	et	f	\N
167044	uusrikaste	?uusrikaste =uusrikas  (PlG  >uusrikane !12_A	et	f	\N
167045	uusrikaste	?uusrikaste =rikas  (PlG  >uus+rikas !07_A	et	f	\N
167046	uusrikaste	?uusrikaste =rikas  (PlG  >uus+rikane !10_A	et	f	\N
167047	jõukate	jõukate =jõuka  (PlG  >jõukas !02_A	et	f	\N
167048	jõukate	jõukate =kate  (SgN  >jõu+kate !06_S	et	f	\N
167107	vahelisi	vahelisi =vahelisi  (PlP  >vaheline !12_A	et	f	\N
167108	vahelisi	"vaheline %vahe  )LINE_aA  <vahe ;16_S	et	f	\N
167153	tarbimis-	?tarbimis- =tarbimi  (SgIn  >tarbimi !01_S	et	f	\N
167155	tarbimis-	?tarbimis- =tarbimi  (SgIn  >tarbim !02_A	et	f	\N
167157	tarbimis-	?tarbimis- =tarbimis  (SgN  >tarbimis !11_S	et	f	\N
167173	tööjaotus	tööjaotus =jaotu  (SgIn  >töö+jaotu !01_A	et	f	\N
167174	tööjaotus	"töö+jaotu %jao  )TU2_kA  <töö+jagu ;18_S	et	f	\N
167175	tööjaotus	tööjaotus =jaotus  (SgN  >töö+jaotus !11~09_S	et	f	\N
167176	tööjaotus	"töö+jaotus %jao  )TUS2_aS  <töö+jagu ;18_S	et	f	\N
167181	talitasid	talitasid =talita  (IndIpfSg2  >talitama !27_V	et	f	\N
167183	talitasid	talitasid =talita  (IndIpfPl3  >talitama !27_V	et	f	\N
167193	karjatasid	karjatasid =karjata  (IndIpfSg2  >karjatama !27_V	et	f	\N
167194	karjatasid	karjatasid =karjata  (IndIpfPl3  >karjatama !27_V	et	f	\N
167206	püsinud	püsinud =püsi  (PtsPtPs  >püsima !27_V	et	f	\N
167207	püsinud	püsinud =püsinu  (PlN  >püsinu !01_S	et	f	\N
167208	püsinud	"püsinu %püsi  )NU_vS  <püsima ;27_V	et	f	\N
167209	püsinud	püsinud =püsinud  (ID  >püsinud !41_A	et	f	\N
167210	püsinud	"püsinud %püsi  )NUD_vA  <püsima ;27_V	et	f	\N
167211	sulaseks	sulaseks =sulase  (SgTr  >sulane !10_S	et	f	\N
167212	sulaseks	sulaseks =seks  (SgN  >sula+seks !22_S	et	f	\N
167216	pärija	pärija =pärija  (SgN  >pärija !01_S	et	f	\N
167217	pärija	"pärija %päri  )JA_vS  <pärima ;27_V	et	f	\N
167218	pärija	pärija =pärija  (SgG  >pärija !01_S	et	f	\N
167229	raskemate	raskemate =raskema  (PlG  >raskem !02_A	et	f	\N
167230	raskemate	"raskem %raske  )M_cA  <raske ;01_A	et	f	\N
167231	raskemate	raskemate =mate  (SgN  >raske+mate !16_S	et	f	\N
167232	raskemate	raskemate =mate  (SgG  >raske+mate !16_S	et	f	\N
167250	mittearenenud	mittearenenud =arenenu  (PlN  >mitte+arenenu !01_S	et	f	\N
167251	mittearenenud	mittearenenud =arenenud  (ID  >mitte+arenenud !41_A	et	f	\N
167261	sünniks	sünniks =sünni  (SgTr  >sünd !22_S	et	f	\N
167262	sünniks	sünniks =sünni  (KndPrPs  >sündima !28_V	et	f	\N
167283	kasvatusele	kasvatusele =kasvatuse  (SgAll  >kasvatus !11_S	et	f	\N
167284	kasvatusele	"kasvatus %kasvata  )US_vS  <kasvatama ;27_V	et	f	\N
167285	kasvatusele	"kasvatus %kasva  )TUS1_aS  <kasvama ;28_V	et	f	\N
167286	kodustes	kodustes =kodus  (PlIn  >kodune !10_A	et	f	\N
167287	kodustes	"kodune %kodu  )NE_aA  <kodu ;17_S	et	f	\N
167311	valmistaksid	valmistaksid =valmista  (KndPrSg2  >valmistama !27_V	et	f	\N
167312	valmistaksid	valmistaksid =valmista  (KndPrPl3  >valmistama !27_V	et	f	\N
167313	valmistaksid	valmistaksid =taksi  (PlN  >valmis+taks !22_S	et	f	\N
167345	bioloogilistele	bioloogilistele =bioloogilis  (PlAll  >bioloogiline !12_A	et	f	\N
167346	bioloogilistele	"bioloogiline %bioloogi  )LINE_aA  <bioloog ;22_S	et	f	\N
167347	bioloogilistele	bioloogilistele =loogilis  (PlAll  >bio+loogiline !12_A	et	f	\N
167348	bioloogilistele	"bio+loogiline %loogi  )LINE_aA  <bio+loog ;22_S	et	f	\N
167354	suvilates	suvilates =suvila  (PlIn  >suvila !01_S	et	f	\N
167355	suvilates	suvilates =late  (PlIn  >suvi+latt !22_S	et	f	\N
167356	pöördumist	pöördumist =pöördumis  (SgP  >pöördumine !12_S	et	f	\N
167357	pöördumist	"pöördumine %pöördu  )MINE_vS  <pöörduma ;27_V	et	f	\N
167389	õhkkonnas	õhkkonnas =õhkkonna  (SgIn  >õhkkond !22_S	et	f	\N
167390	õhkkonnas	õhkkonnas =konna  (SgIn  >õhk+konn !22_S	et	f	\N
167391	vaatajat	vaatajat =vaataja  (SgP  >vaataja !01_S	et	f	\N
167392	vaatajat	"vaataja %vaata  )JA_vS  <vaatama ;29_V	et	f	\N
167393	teadvuslikult	teadvuslikult =teadvusliku  (SgAbl  >teadvuslik !25_A	et	f	\N
167394	teadvuslikult	teadvuslikult =teadvuslikult  (ID  >teadvuslikult !41_D	et	f	\N
167396	teadvuslikult	"teadvuslikult %teadvusliku  )LT_mD  <teadvuslik ;25_A	et	f	\N
167429	linnusest	linnusest =linnuse  (SgEl  >linnus !09_S	et	f	\N
167430	linnusest	linnusest =linnuses  (SgP  >linnusene !12_A	et	f	\N
167431	linnusest	"linnusene %linnuse  )NE_aA  <linnus ;09_S	et	f	\N
167070	keskpärast	keskpärast =pära  (SgEl  >kesk+pära !17_S	et	f	\N
167071	keskpärast	keskpärast =päras  (SgP  >kesk+pärane !10_A	et	f	\N
167072	keskpärast	"kesk+pärane %pära  )NE_aA  <kesk+pära ;17_S	et	f	\N
167073	saavutavad	saavutavad =saavuta  (IndPrPl3  >saavutama !27_V	et	f	\N
167074	saavutavad	saavutavad =saavutava  (PlN  >saavutav !02_A	et	f	\N
167075	saavutavad	"saavutav %saavuta  )V_vA  <saavutama ;27_V	et	f	\N
167115	esivanemad	esivanemad =vanema  (PlN  >esi+vanem !02_AS	et	f	\N
167116	esivanemad	"esi+vanem %vane  )M_cA  <esi+vana ;17_AS	et	f	\N
167134	teatav	teatav =tea  (PtsPrIps  >teadma !34_V	et	f	\N
167136	teatav	teatav =teata  (PtsPrPs  >teatama !27_V	et	f	\N
167138	teatav	teatav =teatav  (SgN  >teatav !02_A	et	f	\N
167139	teatav	"teatav %tea  )TAV_vAS  <teadma ;34_V	et	f	\N
167140	teatav	"teatav %teata  )V_vA  <teatama ;27_V	et	f	\N
167146	riietuse	riietuse =riietuse  (SgG  >riietus !11_S	et	f	\N
167147	riietuse	"riietus %riieta  )US_vS  <riietama ;27_V	et	f	\N
167240	maatöölisteks	maatöölisteks =iste  (SgTr  >maa+tööl+iste !06_S	et	f	\N
167241	maatöölisteks	maatöölisteks =iste  (PlTr  >maa+tööl+ist !22_S	et	f	\N
167242	maatöölisteks	maatöölisteks =töölis  (PlTr  >maa+tööline !12?10_S	et	f	\N
167243	sünnitasid	sünnitasid =sünnita  (IndIpfSg2  >sünnitama !27_V	et	f	\N
167244	sünnitasid	sünnitasid =sünnita  (IndIpfPl3  >sünnitama !27_V	et	f	\N
167281	koolile	koolile =kooli  (SgAll  >kool !22_S	et	f	\N
167282	koolile	koolile =kooli  (PlAll  >kool !22_S	et	f	\N
167292	järeldus	järeldus =järeldu  (IndIpfSg3  >järelduma !27_V	et	f	\N
167293	järeldus	järeldus =järeldus  (SgN  >järeldus !11_S	et	f	\N
167294	järeldus	"järeldus %järelda  )US_vS  <järeldama ;27_V	et	f	\N
167295	kaotavad	kaotavad =kaota  (IndPrPl3  >kaotama !27_V	et	f	\N
167296	kaotavad	kaotavad =kaotava  (PlN  >kaotav !02_A	et	f	\N
167297	kaotavad	"kaotav %kao  )TAV_vAS  <kaduma ;28_V	et	f	\N
167298	kaotavad	"kaotav %kaota  )V_vA  <kaotama ;27_V	et	f	\N
167301	käiksid	käiksid =käi  (KndPrSg2  >käima !38_V	et	f	\N
167302	käiksid	käiksid =käi  (KndPrPl3  >käima !38_V	et	f	\N
167339	vabamalt	vabamalt =vabama  (SgAbl  >vabam !02_A	et	f	\N
167340	vabamalt	"vabam %vaba  )M_cA  <vaba ;17_A	et	f	\N
167341	vabamalt	vabamalt =vabamalt  (ID  >vabamalt !41_D	et	f	\N
167342	vabamalt	"vabamalt %vaba  )MALT_mD  <vaba ;17_A	et	f	\N
167365	eksisteeri	eksisteeri =eksisteeri  (IndPrPs_  >eksisteerima !28_V	et	f	\N
167366	eksisteeri	eksisteeri =eksisteeri  (ImpPrSg2  >eksisteerima !28_V	et	f	\N
167367	eksisteeri	eksisteeri =eri  (SgN  >eks+iste+eri !17_S	et	f	\N
167368	eksisteeri	eksisteeri =eri  (SgG  >eks+iste+eri !17_S	et	f	\N
167369	eksisteeri	eksisteeri =eri  (SgP  >eks+iste+eri !17_S	et	f	\N
167370	eksisteeri	eksisteeri =steeri  (SgG  >eksi+steer !22_S	et	f	\N
167371	eksisteeri	eksisteeri =steeri  (SgP  >eksi+steer !22_S	et	f	\N
167372	eksisteeri	eksisteeri =steeri  (SgAdt  >eksi+steer !22_S	et	f	\N
167373	noorpaarid	?noorpaarid =noorpaari  (PlN  >noorpaari !16_S	et	f	\N
167374	noorpaarid	?noorpaarid =noorpaari  (PlN  >noorpaar !22_S	et	f	\N
167375	noorpaarid	?noorpaarid =noorpaari  (IndPrSg2  >noorpaarima !28_V	et	f	\N
167382	ristivad	ristivad =risti  (IndPrPl3  >ristima !28_V	et	f	\N
167383	ristivad	ristivad =ristiva  (PlN  >ristiv !02_A	et	f	\N
167384	ristivad	"ristiv %risti  )V_vA  <ristima ;28_V	et	f	\N
167385	ristivad	ristivad =iva  (PlN  >rist+iva !17_S	et	f	\N
167403	vaataja	vaataja =vaataja  (SgN  >vaataja !01_S	et	f	\N
167404	vaataja	"vaataja %vaata  )JA_vS  <vaatama ;29_V	et	f	\N
167405	vaataja	vaataja =vaataja  (SgG  >vaataja !01_S	et	f	\N
167420	istud	istud =istu  (PlN  >ist !22_S	et	f	\N
167421	istud	istud =istu  (IndPrSg2  >istuma !28_V	et	f	\N
167443	häiri	häiri =häiri  (IndPrPs_  >häirima !28_V	et	f	\N
167444	häiri	häiri =häiri  (ImpPrSg2  >häirima !28_V	et	f	\N
167449	ajastusse	ajastusse =ajastu  (SgIll  >ajastu !01_S	et	f	\N
167450	ajastusse	ajastusse =ajastus  (SgAdt  >ajastus !11_S	et	f	\N
167451	ajastusse	"ajastus %ajasta  )US_vS  <ajastama ;27_V	et	f	\N
167452	rõhutavad	rõhutavad =rõhuta  (IndPrPl3  >rõhutama !27_V	et	f	\N
167453	rõhutavad	rõhutavad =rõhutava  (PlN  >rõhutav !02_A	et	f	\N
167454	rõhutavad	"rõhutav %rõhu  )TAV_vAS  <rõhuma ;27_V	et	f	\N
167455	rõhutavad	"rõhutav %rõhuta  )V_vA  <rõhutama ;27_V	et	f	\N
167456	rõhutavad	rõhutavad =tava  (PlN  >rõhu+tava !17_S	et	f	\N
167457	arfimuusika	?arfimuusika =arfimuusika  (SgN  >arfimuusika !01_S	et	f	\N
167458	arfimuusika	?arfimuusika =arfimuusika  (SgG  >arfimuusika !01_S	et	f	\N
167459	arfimuusika	?arfimuusika =arfimuusika  (SgG  >arfimuusikas !02_A	et	f	\N
167460	atmosfääri	atmosfääri =atmosfääri  (SgG  >atmosfäär !22_S	et	f	\N
167461	atmosfääri	atmosfääri =atmosfääri  (SgP  >atmosfäär !22_S	et	f	\N
167462	atmosfääri	atmosfääri =atmosfääri  (SgAdt  >atmosfäär !22_S	et	f	\N
167463	püsivat	püsivat =püsi  (KvtPrPs  >püsima !27_V	et	f	\N
167464	püsivat	püsivat =püsiva  (SgP  >püsiv !02_A	et	f	\N
167465	püsivat	"püsiv %püsi  )V_vA  <püsima ;27_V	et	f	\N
167487	mõõtjast	mõõtjast =mõõtja  (SgEl  >mõõtja !01_S	et	f	\N
167488	mõõtjast	"mõõtja %mõõt  )JA_vS  <mõõtma ;34_V	et	f	\N
167117	abielupaar	?abielupaar =abielupaar  (SgN  >abielupaar !22_S	et	f	\N
167118	abielupaar	?abielupaar =elupaar  (SgN  >abi+elupaar !22_S	et	f	\N
167119	perekonnast	perekonnast =perekonna  (SgEl  >perekond !22_S	et	f	\N
167120	perekonnast	perekonnast =perekonnas  (SgP  >perekonnane !12_A	et	f	\N
167121	perekonnast	"perekonnane %perekonna  )NE_aA  <perekond ;22_S	et	f	\N
167122	perekonnast	perekonnast =konna  (SgEl  >pere+konn !22_S	et	f	\N
167123	perekonnast	perekonnast =konnas  (SgP  >pere+konnane !10_A	et	f	\N
167124	perekonnast	"pere+konnane %konna  )NE_aA  <pere+konn ;22_S	et	f	\N
167141	tooraine	tooraine =aine  (SgN  >toor+aine !06_S	et	f	\N
167142	tooraine	tooraine =aine  (SgG  >toor+aine !06_S	et	f	\N
167143	tooraine	tooraine =aine  (PlP  >toor+ain !22_S	et	f	\N
167144	tooraine	tooraine =raine  (SgN  >too+raine !10_A	et	f	\N
167145	tooraine	"too+raine %rai  )NE_aA  <too+rai ;26_S	et	f	\N
167148	virgus	virgus =virgu  (PlIn  >virk !22_A	et	f	\N
167149	virgus	virgus =virgu  (IndIpfSg3  >virguma !27_V	et	f	\N
167150	virgus	virgus =virgus  (SgN  >virgus !11~09_S	et	f	\N
167151	virgus	"virgus %virge  )US_aS  <virge ;01_A	et	f	\N
167163	naistetööd	naistetööd =töö  (PlN  >naiste+töö !26_S	et	f	\N
167164	naistetööd	naistetööd =töö  (SgP  >naiste+töö !26_S	et	f	\N
167171	perekonnad	perekonnad =perekonna  (PlN  >perekond !22_S	et	f	\N
167172	perekonnad	perekonnad =konna  (PlN  >pere+konn !22_S	et	f	\N
167187	6-7-aastaselt	--aastaselt =aastase  (SgAbl  >--aastane !12~10_A	et	f	\N
167188	6-7-aastaselt	"--aastane %aasta  )NE_aA  <--aasta ;01_S	et	f	\N
167189	6-7-aastaselt	--aastaselt =aastaselt  (ID  >--aastaselt !41_D	et	f	\N
167190	6-7-aastaselt	"--aastaselt %aasta  )SELT_mD  <--aasta ;01_S	et	f	\N
167191	6-7-aastaselt	"--aastaselt %aastase  )LT_mD  <--aastane ;10_A	et	f	\N
167192	6-7-aastaselt	"--aastaselt %aastase  )LT_mD  <--aastane ;12_A	et	f	\N
167195	palgalised	palgalised =palgalise  (PlN  >palgaline !12_SA	et	f	\N
167196	palgalised	"palgaline %palga  )LINE_aA  <palk ;22_S	et	f	\N
167197	püsivad	püsivad =püsi  (IndPrPl3  >püsima !27_V	et	f	\N
167198	püsivad	püsivad =püsiva  (PlN  >püsiv !02_A	et	f	\N
167199	püsivad	"püsiv %püsi  )V_vA  <püsima ;27_V	et	f	\N
167213	püsivamad	püsivamad =püsivama  (PlN  >püsivam !02_A	et	f	\N
167214	püsivamad	"püsivam %püsi  )VAM_cA  <püsima ;27_V	et	f	\N
167215	püsivamad	"püsivam %püsiva  )M_cA  <püsiv ;02_A	et	f	\N
167233	vabastamist	vabastamist =vabastamis  (SgP  >vabastamine !12_S	et	f	\N
167234	vabastamist	"vabastamine %vabasta  )MINE_vS  <vabastama ;27_V	et	f	\N
167245	sünnitavad	sünnitavad =sünnita  (IndPrPl3  >sünnitama !27_V	et	f	\N
167246	sünnitavad	sünnitavad =sünnitava  (PlN  >sünnitav !02_A	et	f	\N
167247	sünnitavad	"sünnitav %sünni  )TAV_vAS  <sündima ;28_V	et	f	\N
167248	sünnitavad	"sünnitav %sünnita  )V_vA  <sünnitama ;27_V	et	f	\N
167249	sünnitavad	sünnitavad =tava  (PlN  >sünni+tava !17_S	et	f	\N
167254	lastesse	lastesse =las  (PlIll  >laps !14_S	et	f	\N
167255	lastesse	lastesse =laste  (PlIll  >last !22_S	et	f	\N
167256	kujutletud	kujutletud =kujutle  (PtsPtIps  >kujutlema !27_V	et	f	\N
167257	kujutletud	kujutletud =kujutletu  (PlN  >kujutletu !01_S	et	f	\N
167258	kujutletud	"kujutletu %kujutle  )TU1_vS  <kujutlema ;27_V	et	f	\N
167259	kujutletud	kujutletud =kujutletud  (ID  >kujutletud !41_A	et	f	\N
167260	kujutletud	"kujutletud %kujutle  )TUD_vA  <kujutlema ;27_V	et	f	\N
167279	soodusta	soodusta =soodusta  (IndPrPs_  >soodustama !27_V	et	f	\N
167280	soodusta	soodusta =soodusta  (ImpPrSg2  >soodustama !27_V	et	f	\N
167288	samastasid	samastasid =samasta  (IndIpfSg2  >samastama !27_V	et	f	\N
167289	samastasid	samastasid =samasta  (IndIpfPl3  >samastama !27_V	et	f	\N
167290	teadvustamise	teadvustamise =teadvustamise  (SgG  >teadvustamine !12_S	et	f	\N
167291	teadvustamise	"teadvustamine %teadvusta  )MINE_vS  <teadvustama ;27_V	et	f	\N
167299	teadvustamist	teadvustamist =teadvustamis  (SgP  >teadvustamine !12_S	et	f	\N
167300	teadvustamist	"teadvustamine %teadvusta  )MINE_vS  <teadvustama ;27_V	et	f	\N
167303	üritustest	üritustest =üritus  (PlEl  >üritus !11_S	et	f	\N
167304	üritustest	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
167305	osaleksid	osaleksid =osale  (KndPrSg2  >osalema !27_V	et	f	\N
167306	osaleksid	osaleksid =osale  (KndPrPl3  >osalema !27_V	et	f	\N
167309	traditsioonilisi	traditsioonilisi =traditsioonilisi  (PlP  >traditsiooniline !12_A	et	f	\N
167310	traditsioonilisi	"traditsiooniline %traditsiooni  )LINE_aA  <traditsioon ;22_S	et	f	\N
167314	maitseksid	maitseksid =maitse  (KndPrSg2  >maitsema !28_V	et	f	\N
167315	maitseksid	maitseksid =maitse  (KndPrSg2  >maitsma !32_V	et	f	\N
167316	maitseksid	maitseksid =maitse  (KndPrPl3  >maitsema !28_V	et	f	\N
167317	maitseksid	maitseksid =maitse  (KndPrPl3  >maitsma !32_V	et	f	\N
167376	laulatus	laulatus =laulatus  (SgN  >laulatus !11_S	et	f	\N
167377	laulatus	"laulatus %laulata  )US_vS  <laulatama ;27_V	et	f	\N
167378	laulatus	laulatus =latu  (SgIn  >lau+latu !16_S	et	f	\N
167379	laulatus	"lau+latu %la  )TU2_kA  <lau+la ;26_S	et	f	\N
167380	laulatus	laulatus =latus  (SgN  >lau+latus !09_S	et	f	\N
167381	laulatus	"lau+latus %la  )TUS2_aS  <lau+la ;26_S	et	f	\N
167386	rahvameditsiini	rahvameditsiini =meditsiini  (SgG  >rahva+meditsiin !22_S	et	f	\N
167156	tootmis-	?tootmis- =tootmis  (SgN  >tootmis !09_S	et	f	\N
167158	sugulus-	sugulus- =sugulus  (SgN  >sugulus !11_S	et	f	\N
167159	sugulus-	"sugulus %sugulase  )US_aS  <sugulane ;12_S	et	f	\N
167165	terveid	terveid =terve  (PlP  >terve !01_AS	et	f	\N
167166	terveid	terveid =terve  (PlP  >terve !06_AS	et	f	\N
167180	kariloomi	kariloomi =loomi  (SgG  >kari+loom !22_S	et	f	\N
167182	kariloomi	kariloomi =loomi  (SgP  >kari+loom !22_S	et	f	\N
167184	kariloomi	kariloomi =loomi  (SgAdt  >kari+loom !22_S	et	f	\N
167185	kariloomi	kariloomi =loomi  (PlP  >kari+loom !22_S	et	f	\N
167200	teenijatüdrukuid	teenijatüdrukuid =ui  (PlN  >teenija+tüdruk+ui !26_S	et	f	\N
167201	teenijatüdrukuid	teenijatüdrukuid =ui  (SgP  >teenija+tüdruk+ui !26_S	et	f	\N
167202	teenijatüdrukuid	teenijatüdrukuid =uid  (SgN  >teenija+tüdruk+uid !22_S	et	f	\N
167203	teenijatüdrukuid	teenijatüdrukuid =tüdruku  (PlP  >teenija+tüdruk !02_S	et	f	\N
167227	meessoost	meessoost =soo  (SgEl  >mees+sugu !18_S	et	f	\N
167228	meessoost	meessoost =soo  (SgEl  >mees+soo !26_S	et	f	\N
167268	eelistused	eelistused =eelistuse  (PlN  >eelistus !11_S	et	f	\N
167269	eelistused	"eelistus %eelista  )US_vS  <eelistama ;27_V	et	f	\N
167270	esindajatena	esindajatena =esindaja  (PlEs  >esindaja !01_S	et	f	\N
167271	esindajatena	"esindaja %esinda  )JA_vS  <esindama ;27_V	et	f	\N
167272	vastutavad	vastutavad =vastuta  (IndPrPl3  >vastutama !27_V	et	f	\N
167273	vastutavad	vastutavad =vastutava  (PlN  >vastutav !02_A	et	f	\N
167274	vastutavad	"vastutav %vastuta  )V_vA  <vastutama ;27_V	et	f	\N
167275	vastutavad	vastutavad =tava  (PlN  >vastu+tava !17_S	et	f	\N
167327	traditsioonilisel	traditsioonilisel =traditsioonilise  (SgAd  >traditsiooniline !12_A	et	f	\N
167328	traditsioonilisel	"traditsiooniline %traditsiooni  )LINE_aA  <traditsioon ;22_S	et	f	\N
167337	küsitluste	küsitluste =küsitlus  (PlG  >küsitlus !11_S	et	f	\N
167338	küsitluste	"küsitlus %küsitle  )US_vS  <küsitlema ;27_V	et	f	\N
167343	kinnises	kinnises =kinnise  (SgIn  >kinnis !09_S	et	f	\N
167344	kinnises	kinnises =kinnise  (SgIn  >kinnine !10~12_A	et	f	\N
167351	kompenseerivad	kompenseerivad =kompenseeri  (IndPrPl3  >kompenseerima !28_V	et	f	\N
167352	kompenseerivad	kompenseerivad =kompenseeriva  (PlN  >kompenseeriv !02_A	et	f	\N
167353	kompenseerivad	"kompenseeriv %kompenseeri  )V_vA  <kompenseerima ;28_V	et	f	\N
167358	esindajaks	esindajaks =esindaja  (SgTr  >esindaja !01_S	et	f	\N
167359	esindajaks	"esindaja %esinda  )JA_vS  <esindama ;27_V	et	f	\N
167360	raskemaid	raskemaid =raskema  (PlP  >raskem !02_A	et	f	\N
167361	raskemaid	"raskem %raske  )M_cA  <raske ;01_A	et	f	\N
167362	raskemaid	raskemaid =ma  (PlP  >raske+maa !26_S	et	f	\N
167363	raskemaid	raskemaid =mai  (PlN  >raske+mai !26_S	et	f	\N
167364	raskemaid	raskemaid =mai  (SgP  >raske+mai !26_S	et	f	\N
167398	mürarikas	?mürarikas =mürarika  (SgIn  >mürarika !01_S	et	f	\N
167399	mürarikas	?mürarikas =mürarika  (SgIn  >mürarikas !02_A	et	f	\N
167400	mürarikas	?mürarikas =mürarikas  (SgN  >mürarikas !02_A	et	f	\N
167401	mürarikas	?mürarikas =rika  (SgIn  >müra+rika !16_S	et	f	\N
167402	mürarikas	?mürarikas =rikas  (SgN  >müra+rikas !07_A	et	f	\N
167406	satu	satu =satu  (IndPrPs_  >sattuma !28_V	et	f	\N
167407	satu	satu =satu  (ImpPrSg2  >sattuma !28_V	et	f	\N
167418	värvikas	värvikas =värvika  (SgIn  >värvikas !02_A	et	f	\N
167419	värvikas	värvikas =värvikas  (SgN  >värvikas !02_A	et	f	\N
167493	mõttehiiglus	mõttehiiglus =hiiglus  (SgN  >mõtte+hiiglus !11~09_S	et	f	\N
167494	mõttehiiglus	"mõtte+hiiglus %hiiglase  )US_aS  <mõtte+hiiglane ;12_S	et	f	\N
167501	tegelikkuses	tegelikkuses =tegelikkuse  (SgIn  >tegelikkus !11~09_S	et	f	\N
167502	tegelikkuses	"tegelikkus %tegelikku  )US_aS  <tegelik ;25_A	et	f	\N
167510	miilasel	?miilasel =miilase  (SgAd  >miilane !12?10_S	et	f	\N
167511	miilasel	?miilasel =miilasel  (SgN  >miilasel !19_S	et	f	\N
167515	tsitadelli	tsitadelli =tsitadelli  (SgG  >tsitadell !22_S	et	f	\N
167516	tsitadelli	tsitadelli =tsitadelli  (SgP  >tsitadell !22_S	et	f	\N
167517	tsitadelli	tsitadelli =tsitadelli  (SgAdt  >tsitadell !22_S	et	f	\N
167525	vangistus	vangistus =vangistus  (SgN  >vangistus !11_S	et	f	\N
167526	vangistus	"vangistus %vangista  )US_vS  <vangistama ;27_V	et	f	\N
167538	kiirrongi	kiirrongi =rongi  (SgG  >kiir+rong !22_S	et	f	\N
167539	kiirrongi	kiirrongi =rongi  (SgP  >kiir+rong !22_S	et	f	\N
167540	kiirrongi	kiirrongi =rongi  (SgAdt  >kiir+rong !22_S	et	f	\N
167541	tänavapilti	tänavapilti =pilti  (SgP  >tänava+pilt !22_S	et	f	\N
167542	tänavapilti	tänavapilti =pilti  (SgAdt  >tänava+pilt !22_S	et	f	\N
167616	lõpupäevil	lõpupäevil =päevi  (SgAd  >lõpu+päev !22_S	et	f	\N
167617	lõpupäevil	lõpupäevil =päevi  (PlAd  >lõpu+päev !22_S	et	f	\N
167656	kohtumine	kohtumine =kohtumine  (SgN  >kohtumine !12_S	et	f	\N
167657	kohtumine	"kohtumine %kohtu  )MINE_vS  <kohtuma ;27_V	et	f	\N
167658	teineteisest	teineteisest =teise  (SgEl  >teine+teise !12_P	et	f	\N
167659	teineteisest	teineteisest =teises  (SgP  >teine+teisene !10_A	et	f	\N
167664	havatuid	?havatuid =havatu  (PlP  >havatu !01_AS	et	f	\N
167665	havatuid	?havatuid =havatui  (PlN  >havatui !26_S	et	f	\N
167666	havatuid	?havatuid =havatui  (SgP  >havatui !26_S	et	f	\N
167671	golovin	?golovin =golovin  (SgN  >golovin !19_S	et	f	\N
167318	rahvatoitu	rahvatoitu =toitu  (SgN  >rahva+toitu !01_A	et	f	\N
167319	rahvatoitu	"rahva+toitu %toi  )TU2_kA  <rahva+toi ;26_S	et	f	\N
167320	rahvatoitu	rahvatoitu =toitu  (SgG  >rahva+toitu !01_A	et	f	\N
167321	rahvatoitu	rahvatoitu =toitu  (SgP  >rahva+toit !22_S	et	f	\N
167322	rahvatoitu	rahvatoitu =toitu  (SgAdt  >rahva+toit !22_S	et	f	\N
167323	esindajat	esindajat =esindaja  (SgP  >esindaja !01_S	et	f	\N
167324	esindajat	"esindaja %esinda  )JA_vS  <esindama ;27_V	et	f	\N
167325	abielluvad	abielluvad =ellu  (IndPrPl3  >abi+elluma !27_V	et	f	\N
167326	abielluvad	abielluvad =elluva  (PlN  >abi+elluv !02_A	et	f	\N
167329	mahajäänud	mahajäänud =jää  (PtsPtPs  >maha+_jääma !37_V	et	f	\N
167330	mahajäänud	mahajäänud =jäänu  (PlN  >maha+jäänu !01_S	et	f	\N
167331	mahajäänud	mahajäänud =jäänu  (PlN  >maha+jäänu !06_S	et	f	\N
167332	elektrivalgus	elektrivalgus =valgu  (SgIn  >elektri+valk !22_S	et	f	\N
167333	elektrivalgus	elektrivalgus =valgus  (SgN  >elektri+valgus !11~09_S	et	f	\N
167334	elektrivalgus	"elektri+valgus %valge  )US_aS  <elektri+valge ;01_AS	et	f	\N
167335	looduslikku	looduslikku =looduslikku  (SgP  >looduslik !25_A	et	f	\N
167336	looduslikku	looduslikku =looduslikku  (SgAdt  >looduslik !25_A	et	f	\N
167349	vajadustele	vajadustele =vajadus  (PlAll  >vajadus !11_S	et	f	\N
167350	vajadustele	vajadustele =duste  (PlAll  >vaja+dust !22_S	et	f	\N
167411	unustutud	?unustutud =unustu  (PtsPtIps  >unustuma !27_V	et	f	\N
167412	unustutud	?unustutud =unustutu  (PlN  >unustutu !01_A	et	f	\N
167414	unustutud	?unustutud =unustutu  (IndPrSg2  >unustutuma !27_V	et	f	\N
167415	unustutud	?unustutud =unustutud  (ID  >unustutud !41_A	et	f	\N
167438	taastatud	taastatud =taasta  (PtsPtIps  >taastama !27_V	et	f	\N
167439	taastatud	taastatud =taastatu  (PlN  >taastatu !01_S	et	f	\N
167440	taastatud	"taastatu %taasta  )TU1_vS  <taastama ;27_V	et	f	\N
167441	taastatud	taastatud =taastatud  (ID  >taastatud !41_A	et	f	\N
167442	taastatud	"taastatud %taasta  )TUD_vA  <taastama ;27_V	et	f	\N
167445	ettekujutusi	ettekujutusi =kujutusi  (PlP  >ette+kujutus !11_S	et	f	\N
167446	ettekujutusi	"ette+kujutus %kuju  )TUS2_aS  <ette+kuju ;17_S	et	f	\N
167447	lennuke	lennuke =lennuke  (SgN  >lennuke !12_S	et	f	\N
167448	lennuke	"lennuke %lennu  )KE_dS  <lend ;22_S	et	f	\N
167476	talitatigi	talitatigi =talita  (IndIpfIps^  >talitama !27_V	et	f	\N
167477	talitatigi	talitatigi =tati  (SgG^  >tali+tatt !22_S	et	f	\N
167478	sõjaolukorrast	sõjaolukorrast =korra  (SgEl  >sõja+olu+kord !22_S	et	f	\N
167479	sõjaolukorrast	sõjaolukorrast =korras  (SgP  >sõja+olu+korrane !10_A	et	f	\N
167480	sõjaolukorrast	"sõja+olu+korrane %korra  )NE_aA  <sõja+olu+kord ;22_S	et	f	\N
167497	puutumatuse	puutumatuse =puutumatuse  (SgG  >puutumatus !11?09_S	et	f	\N
167498	puutumatuse	"puutumatus %puutu  )MATUS_aS  <puutuma ;27_V	et	f	\N
167533	kurikael	kurikael =kae  (SgAd  >kuri+kae !26_S	et	f	\N
167534	kurikael	kurikael =kael  (SgN  >kuri+kael !23?22_S	et	f	\N
167543	laadapalagani	laadapalagani =palagani  (SgG  >laada+palagan !19_S	et	f	\N
167544	laadapalagani	laadapalagani =palagani  (SgP  >laada+palagan !19_S	et	f	\N
167545	laadapalagani	laadapalagani =palagani  (SgAdt  >laada+palagan !19_S	et	f	\N
167558	kiitust	kiitust =kiitu  (SgEl  >kiitu !01_A	et	f	\N
167559	kiitust	"kiitu %kii  )TU2_kA  <kii ;26_S	et	f	\N
167561	kiitust	kiitust =kiitus  (SgP  >kiitus !11~09_S	et	f	\N
167563	kiitust	"kiitus %kii  )TUS2_aS  <kii ;26_S	et	f	\N
167565	kajastamisega	kajastamisega =kajastamise  (SgKom  >kajastamine !12_S	et	f	\N
167566	kajastamisega	"kajastamine %kajasta  )MINE_vS  <kajastama ;27_V	et	f	\N
167570	poeetika	poeetika =poeetika  (SgN  >poeetika !01_S	et	f	\N
167571	poeetika	poeetika =poeetika  (SgG  >poeetika !01_S	et	f	\N
167576	arvukas	arvukas =arvuka  (SgIn  >arvukas !02_A	et	f	\N
167578	arvukas	arvukas =arvukas  (SgN  >arvukas !02_A	et	f	\N
167591	1950-ndateks	?-ndateks =ndate  (PlTr  >-ndatt !22_S	et	f	\N
167592	1950-ndateks	?-ndateks =ndate  (KndPrPs  >-ndatema !27_V	et	f	\N
167593	karastus	karastus =karastu  (IndIpfSg3  >karastuma !27_V	et	f	\N
167594	karastus	karastus =karastus  (SgN  >karastus !11_S	et	f	\N
167595	karastus	"karastus %karasta  )US_vS  <karastama ;27_V	et	f	\N
167604	kaidu	?kaidu =kaidu  (SgN  >kaidu !16_S	et	f	\N
167605	kaidu	?kaidu =kaidu  (SgG  >kaidu !16_S	et	f	\N
167606	kaidu	?kaidu =kaidu  (IndPrPs_  >kaiduma !27_V	et	f	\N
167607	kaidu	?kaidu =kaidu  (ImpPrSg2  >kaiduma !27_V	et	f	\N
167608	ibsenliku	?ibsenliku =ibsenliku  (SgG  >ibsenlik !25_A	et	f	\N
167609	ibsenliku	?ibsenliku =ibsenliku  (IndPrPs_  >ibsenlikuma !27_V	et	f	\N
167610	ibsenliku	?ibsenliku =ibsenliku  (ImpPrSg2  >ibsenlikuma !27_V	et	f	\N
167613	tuglast	?tuglast =tugla  (SgEl  >tugla !16_S	et	f	\N
167614	tuglast	?tuglast =tuglas  (SgP  >tuglas !07_S	et	f	\N
167615	tuglast	?tuglast =tuglas  (SgP  >tuglane !10_A	et	f	\N
167629	võimendatuna	võimendatuna =võimendatu  (SgEs  >võimendatu !01_S	et	f	\N
167630	võimendatuna	"võimendatu %võimenda  )TU1_vS  <võimendama ;27_V	et	f	\N
167672	miilasest	?miilasest =miilase  (SgEl  >miilane !12?10_S	et	f	\N
167673	saklastest	?saklastest =saklas  (PlEl  >saklas !07_S	et	f	\N
167674	saklastest	?saklastest =saklas  (PlEl  >saklane !12?10_S	et	f	\N
167387	rahvameditsiini	rahvameditsiini =meditsiini  (SgP  >rahva+meditsiin !22_S	et	f	\N
167388	rahvameditsiini	rahvameditsiini =meditsiini  (SgAdt  >rahva+meditsiin !22_S	et	f	\N
167395	kujutluses	kujutluses =kujutluse  (SgIn  >kujutlus !11_S	et	f	\N
167397	kujutluses	"kujutlus %kujutle  )US_vS  <kujutlema ;27_V	et	f	\N
167408	vaadatavat	vaadatavat =vaada  (KvtPrIps  >vaatama !29_V	et	f	\N
167409	vaadatavat	vaadatavat =vaadatava  (SgP  >vaadatav !02_A	et	f	\N
167410	vaadatavat	"vaadatav %vaada  )TAV_vAS  <vaatama ;29_V	et	f	\N
167413	kurbus	kurbus =kurbu  (IndIpfSg3  >kurbuma !27_V	et	f	\N
167416	kurbus	kurbus =kurbus  (SgN  >kurbus !11~09_S	et	f	\N
167417	kurbus	"kurbus %kurb  )US_aS  <kurb ;22_A	et	f	\N
167422	ibroska	?ibroska =ibroska  (SgN  >ibroska !01_S	et	f	\N
167423	ibroska	?ibroska =ibroska  (SgG  >ibroska !01_S	et	f	\N
167424	kindlusest	kindlusest =kindluse  (SgEl  >kindlus !11~09_S	et	f	\N
167425	kindlusest	"kindlus %kindla  )US_aS  <kindel ;02_A	et	f	\N
167426	kindlusest	kindlusest =kindluses  (SgP  >kindlusene !12_A	et	f	\N
167427	kindlusest	"kindlusene %kindluse  )NE_aA  <kindlus ;09_S	et	f	\N
167428	kindlusest	"kindlusene %kindluse  )NE_aA  <kindlus ;11_S	et	f	\N
167433	väravast	väravast =värava  (SgEl  >värav !02_S	et	f	\N
167434	väravast	väravast =väravas  (SgP  >väravane !12_A	et	f	\N
167435	väravast	"väravane %värava  )NE_aA  <värav ;02_S	et	f	\N
167436	huvitavuseprintsiip	?huvitavuseprintsiip =huvitavuseprintsiip  (SgN  >huvitavuseprintsiip !22_S	et	f	\N
167437	huvitavuseprintsiip	?huvitavuseprintsiip =tavuseprintsiip  (SgN  >huvi+tavuseprintsiip !22_S	et	f	\N
167466	kaitsvat	kaitsvat =kaits  (KvtPrPs  >kaitsma !32_V	et	f	\N
167467	kaitsvat	kaitsvat =kaitsva  (SgP  >kaitsev !02_A	et	f	\N
167468	kaitsvat	"kaitsev %kaits  )V_vA  <kaitsma ;32_V	et	f	\N
167469	kaitsvat	"kaitsev %kaitse  )V_vA  <kaitsema ;28_V	et	f	\N
167472	enesele	enesele =enese  (SgAll  >enese !00_P	et	f	\N
167473	enesele	enesele =enese  (SgAll  >ise !00_P	et	f	\N
167481	positiivsuse	positiivsuse =positiivsuse  (SgG  >positiivsus !11~09_S	et	f	\N
167482	positiivsuse	"positiivsus %positiivse  )US_aS  <positiivne ;02_A	et	f	\N
167485	mõõdupuu	mõõdupuu =puu  (SgN  >mõõdu+puu !26_S	et	f	\N
167486	mõõdupuu	mõõdupuu =puu  (SgG  >mõõdu+puu !26_S	et	f	\N
167499	kindlustamine	kindlustamine =kindlustamine  (SgN  >kindlustamine !12_S	et	f	\N
167500	kindlustamine	"kindlustamine %kindlusta  )MINE_vS  <kindlustama ;27_V	et	f	\N
167518	külgedest	külgedest =külge  (PlEl  >külg !22_S	et	f	\N
167522	külgedest	külgedest =ede  (SgEl  >külg+ede !16_S	et	f	\N
167523	külgedest	külgedest =edes  (SgP  >külg+edene !10_A	et	f	\N
167524	külgedest	"külg+edene %ede  )NE_aA  <külg+ede ;16_S	et	f	\N
167529	ebameeldivamat	ebameeldivamat =meeldivama  (SgP  >eba+meeldivam !02_A	et	f	\N
167530	ebameeldivamat	"eba+meeldivam %meeldiva  )M_cA  <eba+meeldiv ;02_A	et	f	\N
167567	sünkroonselt	sünkroonselt =sünkroonse  (SgAbl  >sünkroonne !02_A	et	f	\N
167568	sünkroonselt	sünkroonselt =sünkroonselt  (ID  >sünkroonselt !41_D	et	f	\N
167569	sünkroonselt	"sünkroonselt %sünkroonse  )LT_mD  <sünkroonne ;02_A	et	f	\N
167586	kirjeldused	kirjeldused =kirjelduse  (PlN  >kirjeldus !11_S	et	f	\N
167587	kirjeldused	"kirjeldus %kirjelda  )US_vS  <kirjeldama ;27_V	et	f	\N
167603	epp	?epp =epp  (SgN  >epp !22_S	et	f	\N
167618	väliseid	väliseid =välise  (PlP  >väline !10_A	et	f	\N
167619	väliseid	"väline %väli  )NE_aA  <väli ;24_S	et	f	\N
167623	erapooletus	erapooletus =erapooletu  (SgIn  >erapooletu !01_A	et	f	\N
167624	erapooletus	erapooletus =pooletu  (SgIn  >era+pooletu !01_A	et	f	\N
167625	erapooletus	erapooletus =pooletus  (SgN  >era+pooletus !11_S	et	f	\N
167631	jälgiksid	jälgiksid =jälgi  (KndPrSg2  >jälgima !27_V	et	f	\N
167632	jälgiksid	jälgiksid =jälgi  (KndPrPl3  >jälgima !27_V	et	f	\N
167650	guslapi	?guslapi =guslapi  (SgN  >guslapi !01_S	et	f	\N
167651	guslapi	?guslapi =guslapi  (SgG  >guslapi !01_S	et	f	\N
167652	guslapi	?guslapi =guslapi  (SgG  >guslap !02_S	et	f	\N
167653	guslapi	?guslapi =guslapi  (SgG  >guslapp !22_S	et	f	\N
167654	guslapi	?guslapi =guslapi  (IndPrPs_  >guslappima !28_V	et	f	\N
167655	guslapi	?guslapi =guslapi  (ImpPrSg2  >guslappima !28_V	et	f	\N
167660	tähelepanulik	?tähelepanulik =tähelepanulik  (SgN  >tähelepanulik !25_A	et	f	\N
167661	tähelepanulik	?tähelepanulik =nulik  (SgN  >tähe+lepa+nulik !02_S	et	f	\N
167662	tähelepanulik	?tähelepanulik =panulik  (SgN  >tähele+panulik !25_A	et	f	\N
167663	tähelepanulik	?tähelepanulik =lepanulik  (SgN  >tähe+lepanulik !25_A	et	f	\N
167729	õnnelikust	õnnelikust =õnneliku  (SgEl  >õnnelik !25_A	et	f	\N
167731	õnnelikust	õnnelikust =õnnelikus  (SgP  >õnnelikus !11?09_S	et	f	\N
167732	õnnelikust	"õnnelikus %õnneliku  )US_aS  <õnnelik ;25_A	et	f	\N
167738	ebaõiglus	ebaõiglus =õiglus  (SgN  >eba+õiglus !11~09_S	et	f	\N
167740	ebaõiglus	"eba+õiglus %õiglase  )US_aS  <eba+õiglane ;12_A	et	f	\N
167794	lühikised	?lühikised =lühikise  (PlN  >lühikis !11_S	et	f	\N
167819	reeglist	reeglist =reegli  (SgEl  >reegel !02_S	et	f	\N
167820	reeglist	reeglist =reeglis  (SgP  >reegline !12~10_A	et	f	\N
167821	reeglist	"reegline %reegli  )NE_aA  <reegel ;02_S	et	f	\N
167835	spordifoto	spordifoto =foto  (SgN  >spordi+foto !16_S	et	f	\N
167432	linnusest	linnusest =use  (PlEl  >linn+usk !22_S	et	f	\N
167470	mõttekam	mõttekam =mõttekam  (SgN  >mõttekam !02_A	et	f	\N
167471	mõttekam	"mõttekam %mõtteka  )M_cA  <mõttekas ;02_A	et	f	\N
167474	kindlusega	kindlusega =kindluse  (SgKom  >kindlus !11~09_S	et	f	\N
167475	kindlusega	"kindlus %kindla  )US_aS  <kindel ;02_A	et	f	\N
167483	negatiivsuse	negatiivsuse =negatiivsuse  (SgG  >negatiivsus !11~09_S	et	f	\N
167484	negatiivsuse	"negatiivsus %negatiivse  )US_aS  <negatiivne ;02_A	et	f	\N
167495	rolliks	rolliks =rolli  (SgTr  >roll !22_S	et	f	\N
167496	rolliks	rolliks =iks  (SgN  >roll+iks !22_S	et	f	\N
167503	nähtu	nähtu =nähtu  (SgN  >nähtu !01_S	et	f	\N
167504	nähtu	"nähtu %näh  )TU1_vS  <nägema ;28_V	et	f	\N
167505	nähtu	nähtu =nähtu  (SgG  >nähtu !01_S	et	f	\N
167506	nähtu	nähtu =nähtu  (SgP  >näht !22_S	et	f	\N
167507	nähtu	nähtu =nähtu  (SgAdt  >näht !22_S	et	f	\N
167508	nähtu	nähtu =nähtu  (IndPrPs_  >nähtuma !27_V	et	f	\N
167509	nähtu	nähtu =nähtu  (ImpPrSg2  >nähtuma !27_V	et	f	\N
167548	1951a	### 1951a	et	f	\N
167549	lenfilmi	?lenfilmi =lenfilmi  (SgN  >lenfilmi !01_S	et	f	\N
167550	lenfilmi	?lenfilmi =lenfilmi  (SgG  >lenfilmi !01_S	et	f	\N
167551	lenfilmi	?lenfilmi =lenfilmi  (SgG  >lenfilm !22_S	et	f	\N
167552	lenfilmi	?lenfilmi =lenfilmi  (SgP  >lenfilm !22_S	et	f	\N
167553	lenfilmi	?lenfilmi =lenfilmi  (SgAdt  >lenfilm !22_S	et	f	\N
167554	lenfilmi	?lenfilmi =lenfilmi  (IndPrPs_  >lenfilmima !28_V	et	f	\N
167555	lenfilmi	?lenfilmi =lenfilmi  (ImpPrSg2  >lenfilmima !28_V	et	f	\N
167556	eeskujuandvalt	eeskujuandvalt =andva  (SgAbl  >ees+kuju+andev !02_A	et	f	\N
167557	eeskujuandvalt	"ees+kuju+andvalt %andva  )LT_mD  <ees+kuju+andev ;02_A	et	f	\N
167582	monoloogid	monoloogid =monoloogi  (PlN  >monoloog !22_S	et	f	\N
167585	monoloogid	monoloogid =loogi  (PlN  >mono+loog !22_S	et	f	\N
167588	jakobsonliku	?jakobsonliku =jakobsonliku  (SgG  >jakobsonlik !25_A	et	f	\N
167589	jakobsonliku	?jakobsonliku =jakobsonliku  (IndPrPs_  >jakobsonlikuma !27_V	et	f	\N
167590	jakobsonliku	?jakobsonliku =jakobsonliku  (ImpPrSg2  >jakobsonlikuma !27_V	et	f	\N
167599	semperi	?semperi =semperi  (SgN  >semperi !01_S	et	f	\N
167600	semperi	?semperi =semperi  (SgG  >semperi !01_S	et	f	\N
167601	semperi	?semperi =semperi  (SgG  >semper !02_S	et	f	\N
167602	lav	### lav	et	f	\N
167611	perekonnadraama	perekonnadraama =draama  (SgN  >pere+konna+draama !16_S	et	f	\N
167612	perekonnadraama	perekonnadraama =draama  (SgG  >pere+konna+draama !16_S	et	f	\N
167620	püüd	püüd =püü  (PlN  >püü !26_S	et	f	\N
167621	püüd	püüd =püü  (SgP  >püü !26_S	et	f	\N
167622	püüd	püüd =püüd  (SgN  >püüd !22_S	et	f	\N
167635	guslap	?guslap =guslap  (SgN  >guslap !02_S	et	f	\N
167645	pühendanud	pühendanud =pühenda  (PtsPtPs  >pühendama !27_V	et	f	\N
167646	pühendanud	pühendanud =pühendanu  (PlN  >pühendanu !01_S	et	f	\N
167647	pühendanud	"pühendanu %pühenda  )NU_vS  <pühendama ;27_V	et	f	\N
167648	pühendanud	pühendanud =pühendanud  (ID  >pühendanud !41_A	et	f	\N
167649	pühendanud	"pühendanud %pühenda  )NUD_vA  <pühendama ;27_V	et	f	\N
167667	havatud	?havatud =hava  (PtsPtIps  >havama !27_V	et	f	\N
167668	havatud	?havatud =havatu  (PlN  >havatu !01_AS	et	f	\N
167669	havatud	?havatud =havatu  (IndPrSg2  >havatuma !27_V	et	f	\N
167670	havatud	?havatud =havatud  (ID  >havatud !41_A	et	f	\N
167681	otsustuse	otsustuse =otsustuse  (SgG  >otsustus !11_S	et	f	\N
167682	otsustuse	"otsustus %otsusta  )US_vS  <otsustama ;27_V	et	f	\N
167696	väljakannatamatult	väljakannatamatult =kannatamatu  (SgAbl  >välja+kannatamatu !01_A	et	f	\N
167697	väljakannatamatult	"välja+kannatamatult %kannatamatu  )LT_mD  <välja+kannatamatu ;01_A	et	f	\N
167698	peategelastest	peategelastest =test  (SgN  >pea+tegelas+test !22_S	et	f	\N
167699	peategelastest	peategelastest =tegelas  (PlEl  >pea+tegelane !12_S	et	f	\N
167700	tema-	tema- =tema  (SgG  >tema !00_P	et	f	\N
167701	tema-	tema- =tema  (SgN  >tema !00_P	et	f	\N
167707	lõhutud	lõhutud =lõhu  (PtsPtIps  >lõhkuma !28_V	et	f	\N
167708	lõhutud	lõhutud =lõhutu  (PlN  >lõhutu !01_AS	et	f	\N
167709	lõhutud	"lõhutu %lõhu  )TU1_vS  <lõhkuma ;28_V	et	f	\N
167710	lõhutud	"lõhutu %lõhu  )TU2_kA  <lõhk ;22_S	et	f	\N
167711	lõhutud	lõhutud =lõhutud  (ID  >lõhutud !41_A	et	f	\N
167712	lõhutud	"lõhutud %lõhu  )TUD_vA  <lõhkuma ;28_V	et	f	\N
167722	pojast	pojast =poja  (SgEl  >poja !17_S	et	f	\N
167723	pojast	pojast =poja  (SgEl  >poeg !22_S	et	f	\N
167724	pojast	pojast =pojas  (SgP  >pojane !10_A	et	f	\N
167725	pojast	"pojane %poja  )NE_aA  <poja ;17_S	et	f	\N
167726	pojast	"pojane %poja  )NE_aA  <poeg ;22_S	et	f	\N
167727	unistavad	unistavad =unista  (IndPrPl3  >unistama !27_V	et	f	\N
167728	unistavad	unistavad =unistava  (PlN  >unistav !02_A	et	f	\N
167730	unistavad	"unistav %unista  )V_vA  <unistama ;27_V	et	f	\N
167735	ebavõrdsus	ebavõrdsus =võrdsus  (SgN  >eba+võrdsus !11~09_S	et	f	\N
167736	ebavõrdsus	"eba+võrdsus %võrdse  )US_aS  <eba+võrdne ;02_A	et	f	\N
167742	kujunduses	kujunduses =kujunduse  (SgIn  >kujundus !11_S	et	f	\N
167743	kujunduses	"kujundus %kujunda  )US_vS  <kujundama ;27_V	et	f	\N
167489	mõõtjast	mõõtjast =mõõtjas  (SgP  >mõõtjane !12~10_A	et	f	\N
167490	mõõtjast	"mõõtjane %mõõtja  )NE_aA  <mõõtja ;01_S	et	f	\N
167491	headuse	headuse =headuse  (SgG  >headus !11~09_S	et	f	\N
167492	headuse	"headus %hea  )US_aS  <hea ;26_A	et	f	\N
167512	professoristaatuse	?professoristaatuse =professoristaatuse  (SgG  >professoristaatus !11~09_S	et	f	\N
167513	reetmist	reetmist =reetmis  (SgP  >reetmine !12?10_S	et	f	\N
167514	reetmist	"reetmine %reet  )MINE_vS  <reetma ;34_V	et	f	\N
167519	esimena	?esimena =mena  (SgN  >esi+mena !17_S	et	f	\N
167520	esimena	?esimena =mena  (SgG  >esi+mena !17_S	et	f	\N
167521	esimena	?esimena =mena  (SgP  >esi+mena !17_S	et	f	\N
167527	ahistatuse	ahistatuse =ahistatuse  (SgG  >ahistatus !11?09_S	et	f	\N
167528	ahistatuse	"ahistatus %ahista  )TUS1_aS  <ahistama ;27_V	et	f	\N
167531	kakspoolsus	kakspoolsus =poolsus  (SgN  >kaks+poolsus !11~09_S	et	f	\N
167532	kakspoolsus	"kaks+poolsus %poolse  )US_aS  <kaks+poolne ;02_A	et	f	\N
167535	sensatsiooni	sensatsiooni =sensatsiooni  (SgG  >sensatsioon !22_S	et	f	\N
167536	sensatsiooni	sensatsiooni =sensatsiooni  (SgP  >sensatsioon !22_S	et	f	\N
167537	sensatsiooni	sensatsiooni =sensatsiooni  (SgAdt  >sensatsioon !22_S	et	f	\N
167546	kinostuudio	kinostuudio =stuudio  (SgN  >kino+stuudio !01_S	et	f	\N
167547	kinostuudio	kinostuudio =stuudio  (SgG  >kino+stuudio !01_S	et	f	\N
167560	nõutavate	nõutavate =nõutava  (PlG  >nõutav !02_A	et	f	\N
167562	nõutavate	"nõutav %nõu  )TAV_vAS  <nõudma ;34_V	et	f	\N
167564	nõutavate	"nõutav %nõuta  )V_vA  <nõutama ;27_V	et	f	\N
167572	jutustusteks	jutustusteks =jutustus  (PlTr  >jutustus !11_S	et	f	\N
167573	jutustusteks	"jutustus %jutusta  )US_vS  <jutustama ;27_V	et	f	\N
167574	hargnevad	hargnevad =hargne  (IndPrPl3  >hargnema !27_V	et	f	\N
167575	hargnevad	hargnevad =hargneva  (PlN  >hargnev !02_A	et	f	\N
167577	hargnevad	"hargnev %hargne  )V_vA  <hargnema ;27_V	et	f	\N
167579	kommenteerivad	kommenteerivad =kommenteeri  (IndPrPl3  >kommenteerima !28_V	et	f	\N
167580	kommenteerivad	kommenteerivad =kommenteeriva  (PlN  >kommenteeriv !02_A	et	f	\N
167581	kommenteerivad	"kommenteeriv %kommenteeri  )V_vA  <kommenteerima ;28_V	et	f	\N
167583	proosapärased	proosapärased =pärase  (PlN  >proosa+pärane !10_A	et	f	\N
167584	proosapärased	"proosa+pärane %pära  )NE_aA  <proosa+pära ;17_S	et	f	\N
167596	hugo	?hugo =hugo  (SgN  >hugo !17~16_S	et	f	\N
167597	hugo	?hugo =hugo  (SgG  >hugo !17~16_S	et	f	\N
167598	hugo	?hugo =hugo  (SgP  >hugo !17_S	et	f	\N
167626	püüd	püüd =püü  (PlN  >püü !26_S	et	f	\N
167627	püüd	püüd =püü  (SgP  >püü !26_S	et	f	\N
167628	püüd	püüd =püüd  (SgN  >püüd !22_S	et	f	\N
167633	koduabiline	koduabiline =abiline  (SgN  >kodu+abiline !12_S	et	f	\N
167634	koduabiline	"kodu+abiline %abi  )LINE_aA  <kodu+abi ;17_S	et	f	\N
167636	sõjategevuse	sõjategevuse =tegevuse  (SgG  >sõja+tegevus !11_S	et	f	\N
167637	sõjategevuse	"sõja+tegevus %tegeva  )US_aS  <sõja+tegev ;02_A	et	f	\N
167638	erutanud	erutanud =eruta  (PtsPtPs  >erutama !27_V	et	f	\N
167639	erutanud	erutanud =erutanu  (PlN  >erutanu !01_S	et	f	\N
167640	erutanud	"erutanu %eruta  )NU_vS  <erutama ;27_V	et	f	\N
167641	erutanud	erutanud =erutanud  (ID  >erutanud !41_A	et	f	\N
167642	erutanud	"erutanud %eruta  )NUD_vA  <erutama ;27_V	et	f	\N
167643	erutanud	erutanud =tanu  (PlN  >eru+tanu !17_S	et	f	\N
167644	rihard	?rihard =rihard  (SgN  >rihard !02_S	et	f	\N
167676	külalistega	külalistega =külalis  (PlKom  >külaline !12_S	et	f	\N
167677	külalistega	"külaline %küla  )LINE_aA  <küla ;17_S	et	f	\N
167678	kodanikukohuks	?kodanikukohuks =kodanikukohu  (KndPrPs  >kodanikukohuma !27_V	et	f	\N
167679	kodanikukohuks	?kodanikukohuks =kohu  (SgTr  >kodaniku+kohu !17_S	et	f	\N
167680	kodanikukohuks	?kodanikukohuks =ukohu  (SgTr  >kodanik+ukohu !01_S	et	f	\N
167719	täituvad	täituvad =täitu  (IndPrPl3  >täituma !27_V	et	f	\N
167720	täituvad	täituvad =täituva  (PlN  >täituv !02_A	et	f	\N
167721	täituvad	"täituv %täitu  )V_vA  <täituma ;27_V	et	f	\N
167733	naabritele	naabritele =naabri  (PlAll  >naaber !02_S	et	f	\N
167734	naabritele	naabritele =brite  (PlAll  >naa+britt !22_S	et	f	\N
167737	vihkamine	vihkamine =vihkamine  (SgN  >vihkamine !12_S	et	f	\N
167739	vihkamine	"vihkamine %vihka  )MINE_vS  <vihkama ;29_V	et	f	\N
167746	toimetuse	toimetuse =toimetuse  (SgG  >toimetus !11_S	et	f	\N
167747	toimetuse	"toimetus %toimeta  )US_vS  <toimetama ;27_V	et	f	\N
167748	toimetuse	"toimetus %toime  )TUS2_aS  <toime ;06_S	et	f	\N
167749	toimetuse	"toimetus %toime  )TUS2_aS  <toim ;22_S	et	f	\N
167755	asuvadki	asuvadki =asu  (IndPrPl3^  >asuma !27_V	et	f	\N
167756	asuvadki	asuvadki =asuva  (PlN^  >asuv !02_A	et	f	\N
167757	asuvadki	"asuv %asu  )V_vA^  <asuma ;27_V	et	f	\N
167760	neljandaks	neljandaks =neljanda  (SgTr  >neljas !02_O	et	f	\N
167761	neljandaks	neljandaks =neljandaks  (ID  >neljandaks !41_D	et	f	\N
167770	kultuurosakonda	kultuurosakonda =osakonda  (SgP  >kultuur+osakond !22_S	et	f	\N
167771	kultuurosakonda	kultuurosakonda =osakonda  (SgAdt  >kultuur+osakond !22_S	et	f	\N
167775	kultuurosakonnas	kultuurosakonnas =konna  (SgIn  >kultuur+osa+konn !22_S	et	f	\N
167776	kultuurosakonnas	kultuurosakonnas =osakonna  (SgIn  >kultuur+osakond !22_S	et	f	\N
167675	saklastest	?saklastest =saklastes  (SgP  >saklastene !12_A	et	f	\N
167704	sõjaväelasse	sõjaväelasse =la  (SgIll  >sõja+väe+la !26_S	et	f	\N
167705	sõjaväelasse	sõjaväelasse =lasse  (PlP  >sõja+väe+lass !22_S	et	f	\N
167706	sõjaväelasse	sõjaväelasse =väelas  (SgAdt  >sõja+väelane !12_S	et	f	\N
167713	saanudki	saanudki =saa  (PtsPtPs^  >saama !37_V	et	f	\N
167714	saanudki	saanudki =saanu  (PlN^  >saanu !01_S	et	f	\N
167715	saanudki	"saanu %saa  )NU_vS^  <saama ;37_V	et	f	\N
167716	saanudki	saanudki =saanu  (PlN^  >saanu !06_S	et	f	\N
167717	saanudki	saanudki =saanud  (ID^  >saanud !41_A	et	f	\N
167718	saanudki	"saanud %saa  )NUD_vA^  <saama ;37_V	et	f	\N
167762	kuumade	kuumade =kuuma  (PlG  >kuum !22_AS	et	f	\N
167763	kuumade	kuumade =made  (SgN  >kuu+made !04_S	et	f	\N
167785	neljaveerulises	neljaveerulises =veerulise  (SgIn  >nelja+veeruline !12_A	et	f	\N
167786	neljaveerulises	"nelja+veeruline %veeru  )LINE_aA  <nelja+veerg ;22_S	et	f	\N
167787	neljaveerulises	"nelja+veeruline %veeru  )LINE_aA  <nelja+veer ;22_S	et	f	\N
167791	kuueveerulises	kuueveerulises =veerulise  (SgIn  >kuue+veeruline !12_A	et	f	\N
167792	kuueveerulises	"kuue+veeruline %veeru  )LINE_aA  <kuue+veerg ;22_S	et	f	\N
167793	kuueveerulises	"kuue+veeruline %veeru  )LINE_aA  <kuue+veer ;22_S	et	f	\N
167806	black	?black =black  (SgN  >black !22_S	et	f	\N
167825	politseikroonika	politseikroonika =kroonika  (SgN  >politsei+kroonika !01_S	et	f	\N
167826	politseikroonika	politseikroonika =kroonika  (SgG  >politsei+kroonika !01_S	et	f	\N
167827	portreefoto	portreefoto =foto  (SgN  >port+ree+foto !16_S	et	f	\N
167828	portreefoto	portreefoto =foto  (SgG  >port+ree+foto !16_S	et	f	\N
167857	kirjatatud	?kirjatatud =kirjata  (PtsPtIps  >kirjatama !27_V	et	f	\N
167858	kirjatatud	?kirjatatud =kirjatatu  (PlN  >kirjatatu !01_S	et	f	\N
167859	kirjatatud	?kirjatatud =kirjatatu  (IndPrSg2  >kirjatatuma !27_V	et	f	\N
167860	kirjatatud	?kirjatatud =kirjatatud  (ID  >kirjatatud !41_A	et	f	\N
167861	kirjatatud	?kirjatatud =tatu  (PlN  >kirja+tatu !16_S	et	f	\N
167862	jõukohases	jõukohases =kohase  (SgIn  >jõu+kohane !10_A	et	f	\N
167863	jõukohases	"jõu+kohane %koha  )NE_aA  <jõu+koha ;17_S	et	f	\N
167864	jõukohases	"jõu+kohane %koha  )NE_aA  <jõu+koht ;22_S	et	f	\N
167884	põhjaraanik	?põhjaraanik =põhjaraanik  (SgN  >põhjaraanik !02_S	et	f	\N
167885	põhjaraanik	?põhjaraanik =raanik  (SgN  >põhja+raanik !02_S	et	f	\N
167892	paiguldada	?paiguldada =paigulda  (Inf  >paiguldama !27_V	et	f	\N
167903	kirjatüüpi	kirjatüüpi =tüüpi  (SgP  >kirja+tüüp !22_S	et	f	\N
167904	kirjatüüpi	kirjatüüpi =tüüpi  (SgAdt  >kirja+tüüp !22_S	et	f	\N
167920	reaklaamid	?reaklaamid =reaklaami  (PlN  >reaklaami !16_S	et	f	\N
167921	reaklaamid	?reaklaamid =reaklaami  (PlN  >reaklaam !22_S	et	f	\N
167922	reaklaamid	?reaklaamid =reaklaami  (IndPrSg2  >reaklaamima !28_V	et	f	\N
167923	reaklaamid	?reaklaamid =klaami  (PlN  >rea+klaami !16_S	et	f	\N
167925	reaklaamid	?reaklaamid =klaami  (PlN  >rea+klaam !22_S	et	f	\N
167930	alaosakonnad	alaosakonnad =konna  (PlN  >ala+osa+konn !22_S	et	f	\N
167931	alaosakonnad	alaosakonnad =osakonna  (PlN  >ala+osakond !22_S	et	f	\N
167938	illustratsiionidega	?illustratsiionidega =illustratsiioni  (PlKom  >illustratsiioni !16_S	et	f	\N
167939	illustratsiionidega	?illustratsiionidega =illustratsiioni  (PlKom  >illustratsiion !19_S	et	f	\N
167940	paigulada	### paigulada	et	f	\N
167963	alaosakondeid	?alaosakondeid =alaosakondei  (PlN  >alaosakondei !26_S	et	f	\N
167964	alaosakondeid	?alaosakondeid =alaosakondei  (SgP  >alaosakondei !26_S	et	f	\N
167965	alaosakondeid	?alaosakondeid =konde  (PlP  >ala+osa+konne !06_S	et	f	\N
167966	alaosakondeid	?alaosakondeid =kondei  (PlN  >ala+osa+kondei !26_S	et	f	\N
167967	alaosakondeid	?alaosakondeid =kondei  (SgP  >ala+osa+kondei !26_S	et	f	\N
167968	alaosakondeid	?alaosakondeid =kondeid  (SgN  >ala+osa+kondeid !22_S	et	f	\N
167969	alaosakondeid	?alaosakondeid =osakondei  (PlN  >ala+osakondei !26_S	et	f	\N
167970	alaosakondeid	?alaosakondeid =osakondei  (SgP  >ala+osakondei !26_S	et	f	\N
168028	lühesteks	?lühesteks =lühes  (PlTr  >lühes !09_S	et	f	\N
168029	lühesteks	?lühesteks =lühes  (PlTr  >lühene !10_A	et	f	\N
168046	grammaatiline	?grammaatiline =grammaatiline  (SgN  >grammaatiline !12_A	et	f	\N
168047	grammaatiline	?grammaatiline =grammaatiline  (PlP  >grammaatilin !19_S	et	f	\N
168048	lausekujulised	lausekujulised =kujulise  (PlN  >lause+kujuline !12_A	et	f	\N
168049	lausekujulised	"lause+kujuline %kuju  )LINE_aA  <lause+kuju ;17_S	et	f	\N
168050	kujunduselementid	### kujunduselementid	et	f	\N
168054	päistmes	?päistmes =päistme  (SgIn  >päistme !06_S	et	f	\N
168055	päistmes	?päistmes =päistme  (PlIn  >päistm !22_S	et	f	\N
168056	päistmes	?päistmes =päistme  (IndIpfSg3  >päistmema !27_V	et	f	\N
168057	päistmes	?päistmes =päistmes  (SgN  >päistmes !09_S	et	f	\N
168063	nenede	?nenede =nene  (PlG  >nene !16_S	et	f	\N
168071	piltedest	piltedest =ede  (SgEl  >pilt+ede !16_S	et	f	\N
168072	piltedest	piltedest =edes  (SgP  >pilt+edene !10_A	et	f	\N
168073	piltedest	"pilt+edene %ede  )NE_aA  <pilt+ede ;16_S	et	f	\N
168081	spordiosakonna	spordiosakonna =konna  (SgG  >spordi+osa+konn !22_S	et	f	\N
168082	spordiosakonna	spordiosakonna =konna  (SgP  >spordi+osa+konn !22_S	et	f	\N
167683	tülitsevad	tülitsevad =tülitse  (IndPrPl3  >tülitsema !27_V	et	f	\N
167684	tülitsevad	tülitsevad =tülitseva  (PlN  >tülitsev !02_A	et	f	\N
167685	tülitsevad	"tülitsev %tülitse  )V_vA  <tülitsema ;27_V	et	f	\N
167686	ralfi	?ralfi =ralfi  (SgN  >ralfi !16_S	et	f	\N
167687	ralfi	?ralfi =ralfi  (SgG  >ralfi !16_S	et	f	\N
167688	ralfi	?ralfi =ralfi  (SgG  >ralf !22_S	et	f	\N
167689	ralfi	?ralfi =ralfi  (SgP  >ralf !22_S	et	f	\N
167690	ralfi	?ralfi =ralfi  (SgAdt  >ralf !22_S	et	f	\N
167691	ralfi	?ralfi =ralfi  (IndPrPs_  >ralfima !28_V	et	f	\N
167692	ralfi	?ralfi =ralfi  (ImpPrSg2  >ralfima !28_V	et	f	\N
167693	puuduta	puuduta =puudu  (IndPrIps_  >puuduma !27_V	et	f	\N
167694	puuduta	puuduta =puuduta  (IndPrPs_  >puudutama !27_V	et	f	\N
167695	puuduta	puuduta =puuduta  (ImpPrSg2  >puudutama !27_V	et	f	\N
167702	dramaatilisemaid	dramaatilisemaid =dramaatilisema  (PlP  >dramaatilisem !02_A	et	f	\N
167703	dramaatilisemaid	"dramaatilisem %dramaatilise  )M_cA  <dramaatiline ;12_A	et	f	\N
167741	xx-xx	### xx-xx	et	f	\N
167753	lääne-virumaal	lääne-virumaal =maa  (SgAd  >lääne-viru+maa !26_S	et	f	\N
167754	lääne-virumaal	lääne-virumaal =maal  (SgN  >lääne-viru+maal !22_S	et	f	\N
167766	esilehele	esilehele =hele  (SgN  >esile+hele !02_A	et	f	\N
167767	esilehele	esilehele =lehe  (SgAll  >esi+leht !22_S	et	f	\N
167768	mõistlikum	mõistlikum =mõistlikum  (SgN  >mõistlikum !02_A	et	f	\N
167769	mõistlikum	"mõistlikum %mõistliku  )M_cA  <mõistlik ;25_A	et	f	\N
167781	kolme-	kolme- =kolme  (SgG  >kolm !22_N	et	f	\N
167782	kolme-	kolme- =kolme  (SgP  >kolm !22_N	et	f	\N
167783	kolme-	kolme- =kolme  (SgAdt  >kolm !22_N	et	f	\N
167784	kolme-	kolme- =kolme  (PlP  >kolm !22_N	et	f	\N
167795	keerukamaks	keerukamaks =keerukama  (SgTr  >keerukam !02_A	et	f	\N
167796	keerukamaks	"keerukam %keeruka  )M_cA  <keerukas ;02_A	et	f	\N
167801	päismik	?päismik =päismik  (SgN  >päismik !25_S	et	f	\N
167804	vahelpealkirjad	?vahelpealkirjad =vahelpealkirja  (PlN  >vahelpealkirjas !02_A	et	f	\N
167805	vahelpealkirjad	?vahelpealkirjad =vahelpealkirja  (PlN  >vahelpealkirja !16_S	et	f	\N
167822	vahelpealkirja	?vahelpealkirja =vahelpealkirja  (SgN  >vahelpealkirja !16_S	et	f	\N
167823	vahelpealkirja	?vahelpealkirja =vahelpealkirja  (SgG  >vahelpealkirjas !02_A	et	f	\N
167824	vahelpealkirja	?vahelpealkirja =vahelpealkirja  (SgG  >vahelpealkirja !16_S	et	f	\N
167829	draamatilises	?draamatilises =draamatilise  (SgIn  >draamatiline !12_A	et	f	\N
167830	draamatilises	?draamatilises =tilise  (SgIn  >draama+tiline !10_A	et	f	\N
167839	spordiosakonnale	spordiosakonnale =konna  (SgAll  >spordi+osa+konn !22_S	et	f	\N
167840	spordiosakonnale	spordiosakonnale =osakonna  (SgAll  >spordi+osakond !22_S	et	f	\N
167847	visuaalselt	visuaalselt =visuaalse  (SgAbl  >visuaalne !02_A	et	f	\N
167848	visuaalselt	visuaalselt =visuaalselt  (ID  >visuaalselt !41_D	et	f	\N
167849	visuaalselt	"visuaalselt %visuaalse  )LT_mD  <visuaalne ;02_A	et	f	\N
167853	keelekasutus	keelekasutus =kasutu  (SgIn  >keele+kasutu !01_A	et	f	\N
167854	keelekasutus	"keele+kasutu %kasu  )TU2_kA  <keele+kasu ;17_S	et	f	\N
167855	keelekasutus	keelekasutus =kasutus  (SgN  >keele+kasutus !11_S	et	f	\N
167856	keelekasutus	"keele+kasutus %kasu  )TUS2_aS  <keele+kasu ;17_S	et	f	\N
167865	informaalses	?informaalses =informaalse  (SgIn  >informaalne !02_A	et	f	\N
167866	informaalses	?informaalses =informaalse  (PlIn  >informaals !22_S	et	f	\N
167867	naljakalt	naljakalt =naljaka  (SgAbl  >naljakas !02_A	et	f	\N
167868	naljakalt	naljakalt =naljakalt  (ID  >naljakalt !41_D	et	f	\N
167869	naljakalt	"naljakalt %naljaka  )LT_mD  <naljakas ;02_A	et	f	\N
167870	jpt	### jpt	et	f	\N
167871	meelelahutuseks	meelelahutuseks =lahutuse  (SgTr  >meele+lahutus !11_S	et	f	\N
167872	meelelahutuseks	"meele+lahutus %lahu  )TUS2_aS  <meele+lahk ;22_S	et	f	\N
167875	reportaazh	?reportaazh =reportaazh  (SgN  >reportaazh !22_S	et	f	\N
167876	küljendaja	küljendaja =küljendaja  (SgN  >küljendaja !01_S	et	f	\N
167877	küljendaja	"küljendaja %küljenda  )JA_vS  <küljendama ;27_V	et	f	\N
167878	küljendaja	küljendaja =küljendaja  (SgG  >küljendaja !01_S	et	f	\N
167890	rasvases	rasvases =rasvase  (SgIn  >rasvane !10_A	et	f	\N
167891	rasvases	"rasvane %rasva  )NE_aA  <rasv ;22_S	et	f	\N
167913	töökuulutused	töökuulutused =kuulutuse  (PlN  >töö+kuulutus !11_S	et	f	\N
167914	töökuulutused	"töö+kuulutus %kuulu  )TUS2_aS  <töö+kuuld ;22_S	et	f	\N
167941	intrigeerivaid	intrigeerivaid =intrigeeriva  (PlP  >intrigeeriv !02_A	et	f	\N
167942	intrigeerivaid	"intrigeeriv %intrigeeri  )V_vA  <intrigeerima ;28_V	et	f	\N
167943	ärataks	ärataks =ärata  (KndPrPs  >äratama !27_V	et	f	\N
167944	ärataks	ärataks =taks  (SgN  >ära+taks !22_S	et	f	\N
167950	kasutatakase	?kasutatakase =kasutatakase  (SgG  >kasutatakane !12_A	et	f	\N
167951	kasutatakase	?kasutatakase =tatakase  (SgG  >kasu+tatakane !12_A	et	f	\N
167952	kasutatakase	?kasutatakase =utatakase  (SgG  >kas+utatakane !12_A	et	f	\N
167992	alaosakonna	alaosakonna =konna  (SgG  >ala+osa+konn !22_S	et	f	\N
167993	alaosakonna	alaosakonna =konna  (SgP  >ala+osa+konn !22_S	et	f	\N
167994	alaosakonna	alaosakonna =konna  (SgAdt  >ala+osa+konn !22_S	et	f	\N
167995	alaosakonna	alaosakonna =osakonna  (SgG  >ala+osakond !22_S	et	f	\N
167996	komplitseeritud	komplitseeritud =komplitseeri  (PtsPtIps  >komplitseerima !28_V	et	f	\N
167744	osakonnad	osakonnad =osakonna  (PlN  >osakond !22_S	et	f	\N
167745	osakonnad	osakonnad =konna  (PlN  >osa+konn !22_S	et	f	\N
167750	naistelehte	naistelehte =lehte  (SgP  >naiste+leht !22_S	et	f	\N
167751	naistelehte	naistelehte =lehte  (SgAdt  >naiste+leht !22_S	et	f	\N
167752	naistelehte	naistelehte =lehte  (PlP  >naiste+leht !22_S	et	f	\N
167758	esiplaanil	esiplaanil =esiplaanil  (ID  >esi+plaanil !41_D	et	f	\N
167759	esiplaanil	esiplaanil =plaani  (SgAd  >esi+plaan !22_S	et	f	\N
167764	ilmateadet	ilmateadet =teade  (SgP  >ilma+teade !05_S	et	f	\N
167765	ilmateadet	ilmateadet =teade  (SgP  >ilma+teade !06_S	et	f	\N
167772	mõttetu	mõttetu =mõttetu  (SgN  >mõttetu !01_A	et	f	\N
167773	mõttetu	"mõttetu %mõtte  )TU2_kA  <mõte ;06_S	et	f	\N
167774	mõttetu	mõttetu =mõttetu  (SgG  >mõttetu !01_A	et	f	\N
167777	kuulutustega	kuulutustega =kuulutus  (PlKom  >kuulutus !11_S	et	f	\N
167778	kuulutustega	"kuulutus %kuuluta  )US_vS  <kuulutama ;27_V	et	f	\N
167779	kuulutustega	"kuulutus %kuulu  )TUS1_aS  <kuuluma ;27_V	et	f	\N
167780	kuulutustega	"kuulutus %kuulu  )TUS2_aS  <kuuld ;22_S	et	f	\N
167797	antiikvakirjas	?antiikvakirjas =antiikvakirja  (SgIn  >antiikvakirjas !02_A	et	f	\N
167798	antiikvakirjas	?antiikvakirjas =antiikvakirja  (SgIn  >antiikvakirja !16_S	et	f	\N
167799	antiikvakirjas	?antiikvakirjas =antiikvakirjas  (SgN  >antiikvakirjas !02_A	et	f	\N
167800	antiikvakirjas	?antiikvakirjas =vakirja  (SgIn  >antiik+vakirjas !02_A	et	f	\N
167802	antiikvakirjas	?antiikvakirjas =vakirja  (SgIn  >antiik+vakirja !16_S	et	f	\N
167803	antiikvakirjas	?antiikvakirjas =vakirjas  (SgN  >antiik+vakirjas !02_A	et	f	\N
167807	play-off	?play-off =off  (SgN  >play-off !22_S	et	f	\N
167808	paksus	paksus =paksu  (SgIn  >paks !22_AS	et	f	\N
167809	paksus	paksus =paksus  (SgN  >paksus !11~09_S	et	f	\N
167810	paksus	"paksus %paks  )US_aS  <paks ;22_AS	et	f	\N
167811	jäädud	jäädud =jää  (PtsPtIps  >jääma !37_V	et	f	\N
167812	jäädud	jäädud =jäädu  (PlN  >jäädu !16_S	et	f	\N
167813	jäädud	"jäädu %jää  )TU1_vS  <jääma ;37_V	et	f	\N
167814	jäädud	jäädud =jäädud  (ID  >jäädud !41_A	et	f	\N
167815	jäädud	"jäädud %jää  )TUD_vA  <jääma ;37_V	et	f	\N
167831	igavana	igavana =igava  (SgEs  >igav !02_A	et	f	\N
167832	igavana	igavana =vana  (SgN  >iga+vana !17_AS	et	f	\N
167833	igavana	igavana =vana  (SgG  >iga+vana !17_AS	et	f	\N
167834	igavana	igavana =vana  (SgP  >iga+vana !17_AS	et	f	\N
167881	mõndasid	?mõndasid =mõnda  (PlP  >mõnda !16_S	et	f	\N
167882	mõndasid	?mõndasid =mõnda  (IndIpfSg2  >mõndama !29_V	et	f	\N
167883	mõndasid	?mõndasid =mõnda  (IndIpfPl3  >mõndama !29_V	et	f	\N
167886	päistmikus	?päistmikus =päistmiku  (SgIn  >päistmik !25_S	et	f	\N
167887	päistmikus	?päistmikus =päistmiku  (SgIn  >päistmiku !01_S	et	f	\N
167888	päistmikus	?päistmikus =päistmiku  (IndIpfSg3  >päistmikuma !27_V	et	f	\N
167889	päistmikus	?päistmikus =päistmikus  (SgN  >päistmikus !11_S	et	f	\N
167893	osakonasse	?osakonasse =osakonas  (SgAdt  >osakonane !12_A	et	f	\N
167894	osakonasse	?osakonasse =osakonasse  (SgG  >osakonasne !02_A	et	f	\N
167895	osakonasse	?osakonasse =osakonasse  (PlP  >osakonass !22_S	et	f	\N
167896	osakonasse	?osakonasse =kona  (SgIll  >osa+kona !17_S	et	f	\N
167897	osakonasse	?osakonasse =konasse  (SgG  >osa+konasne !02_A	et	f	\N
167898	osakonasse	?osakonasse =konasse  (PlP  >osa+konass !22_S	et	f	\N
167899	erinavate	?erinavate =erinava  (PlG  >erinav !02_A	et	f	\N
167900	ajalehtede	ajalehtede =ede  (SgN  >aja+leht+ede !16_S	et	f	\N
167901	ajalehtede	ajalehtede =ede  (SgG  >aja+leht+ede !16_S	et	f	\N
167902	ajalehtede	ajalehtede =lehte  (PlG  >aja+leht !22_S	et	f	\N
167924	paiguldatud	?paiguldatud =paigulda  (PtsPtIps  >paiguldama !27_V	et	f	\N
167926	paiguldatud	?paiguldatud =paiguldatu  (PlN  >paiguldatu !01_S	et	f	\N
167927	paiguldatud	?paiguldatud =paiguldatu  (IndPrSg2  >paiguldatuma !27_V	et	f	\N
167928	paiguldatud	?paiguldatud =paiguldatud  (ID  >paiguldatud !41_A	et	f	\N
167929	paiguldatud	?paiguldatud =guldatu  (PlN  >pai+guldatu !01_S	et	f	\N
167945	lugejate	lugejate =lugeja  (PlG  >lugeja !01_S	et	f	\N
167946	lugejate	"lugeja %luge  )JA_vS  <lugema ;28_V	et	f	\N
167971	tabloo	tabloo =tabloo  (SgN  >tabloo !26_S	et	f	\N
167972	tabloo	tabloo =tabloo  (SgG  >tabloo !26_S	et	f	\N
167975	standartne	?standartne =standartne  (SgN  >standartne !02_A	et	f	\N
167976	standartne	?standartne =standartne  (PlP  >standartn !22_S	et	f	\N
167977	kirjasuurus	kirjasuurus =suurus  (SgN  >kirja+suurus !11~09_S	et	f	\N
167978	kirjasuurus	"kirja+suurus %suur  )US_aS  <kirja+suur ;13_A	et	f	\N
167979	pealirju	?pealirju =pealirju  (SgN  >pealirju !01_S	et	f	\N
167980	pealirju	?pealirju =pealirju  (SgG  >pealirju !01_S	et	f	\N
167981	pealirju	?pealirju =pealirju  (IndPrPs_  >pealirjuma !27_V	et	f	\N
167982	pealirju	?pealirju =pealirju  (ImpPrSg2  >pealirjuma !27_V	et	f	\N
167983	pealirju	?pealirju =irju  (SgN  >peal+irju !16_S	et	f	\N
167984	pealirju	?pealirju =irju  (SgG  >peal+irju !16_S	et	f	\N
167985	pealirju	?pealirju =lirju  (SgN  >pea+lirju !16_S	et	f	\N
167986	pealirju	?pealirju =lirju  (SgG  >pea+lirju !16_S	et	f	\N
168003	keskenduvad	keskenduvad =keskendu  (IndPrPl3  >keskenduma !27_V	et	f	\N
168004	keskenduvad	keskenduvad =keskenduva  (PlN  >keskenduv !02_A	et	f	\N
167788	kuueveerulises	kuueveerulises =veerulise  (SgIn  >kuue+veeruline !12_A	et	f	\N
167789	kuueveerulises	"kuue+veeruline %veeru  )LINE_aA  <kuue+veerg ;22_S	et	f	\N
167790	kuueveerulises	"kuue+veeruline %veeru  )LINE_aA  <kuue+veer ;22_S	et	f	\N
167816	intrigeerivad	intrigeerivad =intrigeeri  (IndPrPl3  >intrigeerima !28_V	et	f	\N
167817	intrigeerivad	intrigeerivad =intrigeeriva  (PlN  >intrigeeriv !02_A	et	f	\N
167818	intrigeerivad	"intrigeeriv %intrigeeri  )V_vA  <intrigeerima ;28_V	et	f	\N
167837	stampfoto	stampfoto =foto  (SgN  >stamp+foto !16_S	et	f	\N
167838	stampfoto	stampfoto =foto  (SgG  >stamp+foto !16_S	et	f	\N
167841	väiksemaks	väiksemaks =väiksema  (SgTr  >väiksem !02_A	et	f	\N
167842	väiksemaks	"väiksem %väikse  )M_cA  <väike ;10_A	et	f	\N
167843	väiksemaks	väiksemaks =maks  (SgN  >väikse+maks !22_S	et	f	\N
167850	põhjendavad	põhjendavad =põhjenda  (IndPrPl3  >põhjendama !27_V	et	f	\N
167851	põhjendavad	põhjendavad =põhjendava  (PlN  >põhjendav !02_A	et	f	\N
167852	põhjendavad	"põhjendav %põhjenda  )V_vA  <põhjendama ;27_V	et	f	\N
167873	tõsiseid	tõsiseid =tõsise  (PlP  >tõsine !10_A	et	f	\N
167874	tõsiseid	"tõsine %tõsi  )NE_aA  <tõsi ;15_S	et	f	\N
167905	rasvasemad	rasvasemad =rasvasema  (PlN  >rasvasem !02_A	et	f	\N
167906	rasvasemad	"rasvasem %rasva  )SEM_cA  <rasv ;22_S	et	f	\N
167907	rasvasemad	"rasvasem %rasvase  )M_cA  <rasvane ;10_A	et	f	\N
167908	torkavad	torkavad =torka  (IndPrPl3  >torkama !29_V	et	f	\N
167909	torkavad	torkavad =torkava  (PlN  >torkav !02_A	et	f	\N
167910	torkavad	"torkav %torka  )V_vA  <torkama ;29_V	et	f	\N
167911	varieeru	varieeru =varieeru  (IndPrPs_  >varieeruma !27_V	et	f	\N
167912	varieeru	varieeru =varieeru  (ImpPrSg2  >varieeruma !27_V	et	f	\N
167932	kulutuste	kulutuste =kulutus  (PlG  >kulutus !11_S	et	f	\N
167933	kulutuste	"kulutus %kuluta  )US_vS  <kulutama ;27_V	et	f	\N
167934	kulutuste	"kulutus %kulu  )TUS1_aS  <kuluma ;27_V	et	f	\N
167935	kulutuste	"kulutus %kulu  )TUS2_aS  <kulu ;17_S	et	f	\N
167936	kulutuste	"kulutus %kulu  )TUS2_aS  <kulg ;22_S	et	f	\N
167937	kulutuste	kulutuste =tuste  (PlP  >kulu+tust !22_S	et	f	\N
167953	jaotud	jaotud =jaotu  (PlN  >jaotu !01_A	et	f	\N
167954	jaotud	"jaotu %jao  )TU2_kA  <jagu ;18_S	et	f	\N
167955	jaotud	jaotud =jaotu  (IndPrSg2  >jaotuma !27_V	et	f	\N
167987	pealugu	pealugu =lugu  (SgN  >pea+lugu !18_S	et	f	\N
167988	pealugu	pealugu =lugu  (SgP  >pea+lugu !18_S	et	f	\N
167989	rasvased	rasvased =rasvase  (PlN  >rasvane !10_A	et	f	\N
167990	rasvased	"rasvane %rasva  )NE_aA  <rasv ;22_S	et	f	\N
167991	block	?block =block  (SgN  >block !22_S	et	f	\N
168006	kirjeldamisele	kirjeldamisele =kirjeldamise  (SgAll  >kirjeldamine !12_S	et	f	\N
168007	kirjeldamisele	"kirjeldamine %kirjelda  )MINE_vS  <kirjeldama ;27_V	et	f	\N
168034	rikkumine	rikkumine =rikkumine  (SgN  >rikkumine !12_S	et	f	\N
168035	rikkumine	"rikkumine %rikku  )MINE_vS  <rikkuma ;28_V	et	f	\N
168036	sentimetri	?sentimetri =sentimetri  (SgG  >sentimetter !02_S	et	f	\N
168037	sentimetri	?sentimetri =metri  (SgG  >senti+metter !02_S	et	f	\N
168038	vasakult	vasakult =vasaku  (SgAbl  >vasak !02_A	et	f	\N
168039	vasakult	vasakult =vasakult  (ID  >vasakult !41_D	et	f	\N
168040	vasakult	"vasakult %vasaku  )LT_mD  <vasak ;02_A	et	f	\N
168041	tähtsusest	tähtsusest =tähtsuse  (SgEl  >tähtsus !11~09_S	et	f	\N
168042	tähtsusest	"tähtsus %tähtsa  )US_aS  <tähtis ;02_A	et	f	\N
168043	tähtsusest	tähtsusest =tähtsuses  (SgP  >tähtsusene !12_A	et	f	\N
168044	tähtsusest	"tähtsusene %tähtsuse  )NE_aA  <tähtsus ;09_S	et	f	\N
168045	tähtsusest	"tähtsusene %tähtsuse  )NE_aA  <tähtsus ;11_S	et	f	\N
168062	tärnikesed	tärnikesed =tärnikese  (PlN  >tärnike !12_S	et	f	\N
168064	tärnikesed	"tärnike %tärni  )KE_dS  <tärn ;22_S	et	f	\N
168065	tärnikesed	tärnikesed =tärnikese  (PlN  >tärnikene !12_S	et	f	\N
168066	tärnikesed	"tärnikene %tärni  )KENE_dS  <tärn ;22_S	et	f	\N
168079	arusaadavalt	arusaadavalt =saadava  (SgAbl  >aru+saadav !02_A	et	f	\N
168080	arusaadavalt	"aru+saadavalt %saadava  )LT_mD  <aru+saadav ;02_A	et	f	\N
168085	seismest	?seismest =seisme  (SgEl  >seisme !06_S	et	f	\N
168086	seismest	?seismest =seisme  (PlEl  >seism !22_S	et	f	\N
168087	seismest	?seismest =seismes  (SgP  >seismes !09_S	et	f	\N
168088	seismest	?seismest =seismes  (SgP  >seismene !12~10_A	et	f	\N
168089	ebaolulist	ebaolulist =olulis  (SgP  >eba+oluline !12_A	et	f	\N
168090	ebaolulist	"eba+oluline %olu  )LINE_aA  <eba+olu ;17_S	et	f	\N
168095	tähtsamates	tähtsamates =tähtsama  (PlIn  >tähtsam !02_A	et	f	\N
168096	tähtsamates	"tähtsam %tähtsa  )M_cA  <tähtis ;02_A	et	f	\N
168099	parandused	parandused =paranduse  (PlN  >parandus !11_S	et	f	\N
168100	parandused	"parandus %paranda  )US_vS  <parandama ;27_V	et	f	\N
168106	lingvistika	lingvistika =lingvistika  (SgN  >lingvistika !01_S	et	f	\N
168108	lingvistika	lingvistika =lingvistika  (SgG  >lingvistika !01_S	et	f	\N
168126	kontrolltööd	kontrolltööd =töö  (PlN  >kont+roll+töö !26_S	et	f	\N
168127	kontrolltööd	kontrolltööd =töö  (SgP  >kont+roll+töö !26_S	et	f	\N
168131	1h	### 1h	et	f	\N
168135	mene	?mene =mene  (SgN  >mene !16_S	et	f	\N
168136	mene	?mene =mene  (SgG  >mene !16_S	et	f	\N
168137	mene	?mene =mene  (IndPrPs_  >menema !27_V	et	f	\N
167836	spordifoto	spordifoto =foto  (SgG  >spordi+foto !16_S	et	f	\N
167844	asjakohased	asjakohased =kohase  (PlN  >asja+kohane !10_A	et	f	\N
167845	asjakohased	"asja+kohane %koha  )NE_aA  <asja+koha ;17_S	et	f	\N
167846	asjakohased	"asja+kohane %koha  )NE_aA  <asja+koht ;22_S	et	f	\N
167879	küljendajad	küljendajad =küljendaja  (PlN  >küljendaja !01_S	et	f	\N
167880	küljendajad	"küljendaja %küljenda  )JA_vS  <küljendama ;27_V	et	f	\N
167915	asutuste	asutuste =asutus  (PlG  >asutus !11_S	et	f	\N
167916	asutuste	"asutus %asuta  )US_vS  <asutama ;27_V	et	f	\N
167917	asutuste	"asutus %asu  )TUS1_aS  <asuma ;27_V	et	f	\N
167918	asutuste	"asutus %asu  )TUS2_aS  <asu ;17_S	et	f	\N
167919	asutuste	asutuste =tuste  (PlP  >asu+tust !22_S	et	f	\N
167947	sektsiooni	sektsiooni =sektsiooni  (SgG  >sektsioon !22_S	et	f	\N
167948	sektsiooni	sektsiooni =sektsiooni  (SgP  >sektsioon !22_S	et	f	\N
167949	sektsiooni	sektsiooni =sektsiooni  (SgAdt  >sektsioon !22_S	et	f	\N
167956	köidetud	köidetud =köide  (PtsPtIps  >köitma !34_V	et	f	\N
167957	köidetud	köidetud =köidetu  (PlN  >köidetu !01_AS	et	f	\N
167958	köidetud	"köidetu %köide  )TU1_vS  <köitma ;34_V	et	f	\N
167959	köidetud	köidetud =köidetud  (ID  >köidetud !41_A	et	f	\N
167960	köidetud	"köidetud %köide  )TUD_vA  <köitma ;34_V	et	f	\N
167961	päevalause	päevalause =lause  (SgN  >päeva+lause !06_S	et	f	\N
167962	päevalause	päevalause =lause  (SgG  >päeva+lause !06_S	et	f	\N
167973	kirjud	kirjud =kirju  (PlN  >kirju !01_A	et	f	\N
167974	kirjud	kirjud =kirju  (PlN  >kirju !16_A	et	f	\N
168001	artiklitest	artiklitest =artikli  (PlEl  >artikkel !02_S	et	f	\N
168002	artiklitest	artiklitest =test  (SgN  >artikli+test !22_S	et	f	\N
168013	majandusosakonna	majandusosakonna =konna  (SgG  >majandus+osa+konn !22_S	et	f	\N
168014	majandusosakonna	majandusosakonna =konna  (SgP  >majandus+osa+konn !22_S	et	f	\N
168015	majandusosakonna	majandusosakonna =konna  (SgAdt  >majandus+osa+konn !22_S	et	f	\N
168016	majandusosakonna	majandusosakonna =osakonna  (SgG  >majandus+osakond !22_S	et	f	\N
168058	rohem	?rohem =rohem  (SgN  >rohem !02_A	et	f	\N
168076	statiistika	?statiistika =statiistika  (SgN  >statiistika !01_S	et	f	\N
168077	statiistika	?statiistika =statiistika  (SgG  >statiistika !01_S	et	f	\N
168078	statiistika	?statiistika =statiistika  (SgG  >statiistikas !02_A	et	f	\N
168113	kontrastiivne	?kontrastiivne =kontrastiivne  (SgN  >kontrastiivne !02_A	et	f	\N
168114	kontrastiivne	?kontrastiivne =kontrastiivne  (PlP  >kontrastiivn !22_S	et	f	\N
168115	kontrastiivne	?kontrastiivne =ivne  (SgN  >kontrasti+ivne !02_A	et	f	\N
168116	kontrastiivne	?kontrastiivne =ivne  (PlP  >kontrasti+ivn !22_S	et	f	\N
168117	kontrastiivne	?kontrastiivne =iivne  (SgN  >kontrast+iivne !02_A	et	f	\N
168118	kontrastiivne	?kontrastiivne =iivne  (PlP  >kontrast+iivn !22_S	et	f	\N
168119	kontrastiivne	?kontrastiivne =stiivne  (SgN  >kontra+stiivne !02_A	et	f	\N
168120	kontrastiivne	?kontrastiivne =stiivne  (PlP  >kontra+stiivn !22_S	et	f	\N
168121	kontrastiivne	?kontrastiivne =rastiivne  (SgN  >kont+rastiivne !02_A	et	f	\N
168122	kontrastiivne	?kontrastiivne =rastiivne  (PlP  >kont+rastiivn !22_S	et	f	\N
168132	ldus	### ldus	et	f	\N
168139	hääldavad	hääldavad =häälda  (IndPrPl3  >hääldama !27_V	et	f	\N
168140	hääldavad	hääldavad =hääldava  (PlN  >hääldav !02_A	et	f	\N
168141	hääldavad	"hääldav %häälda  )V_vA  <hääldama ;27_V	et	f	\N
168149	radel	?radel =rade  (SgAd  >rade !16_S	et	f	\N
168150	radel	?radel =radel  (SgN  >radel !02_S	et	f	\N
168156	sõbradsõbrade	?sõbradsõbrade =sõbradsõbra  (PlG  >sõbradsõbra !16_S	et	f	\N
168157	sõbradsõbrade	?sõbradsõbrade =dsõbra  (PlG  >sõbra+dsõbra !16_S	et	f	\N
168174	mm	### mm	et	f	\N
168180	hääldamisel	hääldamisel =hääldamise  (SgAd  >hääldamine !12_S	et	f	\N
168181	hääldamisel	"hääldamine %häälda  )MINE_vS  <hääldama ;27_V	et	f	\N
168209	poolaka	poolaka =poolaka  (SgG  >poolakas !02_S	et	f	\N
168210	poolaka	poolaka =aka  (SgN  >pool+aka !16_S	et	f	\N
168211	poolaka	poolaka =aka  (SgG  >pool+aka !16_S	et	f	\N
168231	tajuta	tajuta =taju  (SgAb  >taju !17_S	et	f	\N
168232	tajuta	tajuta =taju  (IndPrIps_  >tajuma !27_V	et	f	\N
168233	avst	?avst =avst  (SgN  >avst !22_S	et	f	\N
168237	pesa	pesa =pesa  (SgN  >pesa !17_S	et	f	\N
168238	pesa	pesa =pesa  (SgG  >pesa !17_S	et	f	\N
168239	pesa	pesa =pesa  (SgP  >pesa !17_S	et	f	\N
168251	jalgratta	jalgratta =ratta  (SgG  >jalg+ratas !07_S	et	f	\N
168252	jalgratta	jalgratta =ratta  (SgAdt  >jalg+rada !18_S	et	f	\N
168266	järgarvsõnu	?järgarvsõnu =järgarvsõnu  (IndPrPs_  >järgarvsõnuma !27_V	et	f	\N
168267	järgarvsõnu	?järgarvsõnu =järgarvsõnu  (ImpPrSg2  >järgarvsõnuma !27_V	et	f	\N
168272	kolma	?kolma =kolma  (SgN  >kolma !16_S	et	f	\N
168273	kolma	?kolma =kolma  (SgG  >kolma !16_S	et	f	\N
168274	kolma	?kolma =kolma  (IndPrPs_  >kolmama !29_V	et	f	\N
168275	kolma	?kolma =kolma  (ImpPrSg2  >kolmama !29_V	et	f	\N
168304	sõnajärj	### sõnajärj	et	f	\N
168322	hoolitsemisega	hoolitsemisega =hoolitsemise  (SgKom  >hoolitsemine !12_S	et	f	\N
168323	hoolitsemisega	"hoolitsemine %hoolitse  )MINE_vS  <hoolitsema ;27_V	et	f	\N
168324	hoolitsemisega	hoolitsemisega =emise  (SgKom  >hoo+lits+emis !09_S	et	f	\N
167997	komplitseeritud	komplitseeritud =komplitseeritu  (PlN  >komplitseeritu !01_S	et	f	\N
167998	komplitseeritud	"komplitseeritu %komplitseeri  )TU1_vS  <komplitseerima ;28_V	et	f	\N
167999	komplitseeritud	komplitseeritud =komplitseeritud  (ID  >komplitseeritud !41_A	et	f	\N
168000	komplitseeritud	"komplitseeritud %komplitseeri  )TUD_vA  <komplitseerima ;28_V	et	f	\N
168008	juhtunu	juhtunu =juhtunu  (SgN  >juhtunu !01_S	et	f	\N
168009	juhtunu	"juhtunu %juhtu  )NU_vS  <juhtuma ;27_V	et	f	\N
168011	juhtunu	juhtunu =juhtunu  (SgG  >juhtunu !01_S	et	f	\N
168017	formaalsem	formaalsem =formaalsem  (SgN  >formaalsem !02_A	et	f	\N
168018	formaalsem	"formaalsem %formaalse  )M_cA  <formaalne ;02_A	et	f	\N
168019	veerude	veerude =veeru  (PlG  >veer !22_S	et	f	\N
168020	veerude	veerude =ude  (SgN  >veer+ude !04_S	et	f	\N
168021	üheveerulises	üheveerulises =veerulise  (SgIn  >ühe+veeruline !12_A	et	f	\N
168022	üheveerulises	"ühe+veeruline %veeru  )LINE_aA  <ühe+veerg ;22_S	et	f	\N
168023	üheveerulises	"ühe+veeruline %veeru  )LINE_aA  <ühe+veer ;22_S	et	f	\N
168059	tärni	tärni =tärni  (SgG  >tärn !22_S	et	f	\N
168060	tärni	tärni =tärni  (SgP  >tärn !22_S	et	f	\N
168061	tärni	tärni =tärni  (SgAdt  >tärn !22_S	et	f	\N
168074	majandusosakonnas	majandusosakonnas =konna  (SgIn  >majandus+osa+konn !22_S	et	f	\N
168075	majandusosakonnas	majandusosakonnas =osakonna  (SgIn  >majandus+osakond !22_S	et	f	\N
168133	pedagoo	?pedagoo =pedagoo  (SgN  >pedagoo !26_S	et	f	\N
168134	pedagoo	?pedagoo =pedagoo  (SgG  >pedagoo !26_S	et	f	\N
168148	alistussidendite	?alistussidendite =alistussidendi  (IndPrPl2  >alistussidentima !28_V	et	f	\N
168151	moodustamist	moodustamist =moodustamis  (SgP  >moodustamine !12_S	et	f	\N
168152	moodustamist	"moodustamine %moodusta  )MINE_vS  <moodustama ;27_V	et	f	\N
168173	nim	### nim	et	f	\N
168188	perfektiivsusadverb	?perfektiivsusadverb =perfektiivsusadverb  (SgN  >perfektiivsusadverb !22_S	et	f	\N
168202	kohtlajärve	kohtlajärve =järve  (SgG  >kohtla+järv !22_S	et	f	\N
168203	kohtlajärve	kohtlajärve =järve  (SgP  >kohtla+järv !22_S	et	f	\N
168204	kohtlajärve	kohtlajärve =järve  (SgAdt  >kohtla+järv !22_S	et	f	\N
168205	kohtlajärve	kohtlajärve =järve  (PlP  >kohtla+järv !22_S	et	f	\N
168234	mos	### mos	et	f	\N
168235	õpila	?õpila =õpila  (SgN  >õpila !01_S	et	f	\N
168236	õpila	?õpila =õpila  (SgG  >õpila !01_S	et	f	\N
168240	ed	### ed	et	f	\N
168261	ikese	?ikese =ikese  (SgG  >ikene !10_A	et	f	\N
168264	teisendal	?teisendal =teisenda  (SgAd  >teisenda !01_S	et	f	\N
168265	teisendal	?teisendal =endal  (SgN  >teis+endal !02_S	et	f	\N
168276	teisenda	teisenda =teisenda  (IndPrPs_  >teisendama !27_V	et	f	\N
168277	teisenda	teisenda =teisenda  (ImpPrSg2  >teisendama !27_V	et	f	\N
168279	neljal	neljal =nelja  (SgAd  >neljas !02_O	et	f	\N
168280	neljal	neljal =nelja  (SgAd  >neli !24_N	et	f	\N
168282	nimisõnafraasi	nimisõnafraasi =fraasi  (SgG  >nimi+sõna+fraas !22_S	et	f	\N
168283	nimisõnafraasi	nimisõnafraasi =fraasi  (SgP  >nimi+sõna+fraas !22_S	et	f	\N
168284	nimisõnafraasi	nimisõnafraasi =fraasi  (SgAdt  >nimi+sõna+fraas !22_S	et	f	\N
168308	kar	### kar	et	f	\N
168316	si-	si- =si  (SgN  >si !26_S	et	f	\N
168317	si-	si- =si  (SgG  >si !26_S	et	f	\N
168330	liide	liide =lii  (PlG  >lii !26_S	et	f	\N
168331	liide	liide =liide  (SgN  >liide !06_S	et	f	\N
168341	lõ	### lõ	et	f	\N
168354	lge	### lge	et	f	\N
168355	kellestmillest	?kellestmillest =kellestmille  (PlEl  >kellestmill !22_S	et	f	\N
168356	kellestmillest	?kellestmillest =kellestmilles  (SgP  >kellestmillene !12_A	et	f	\N
168357	verbirektsioone	?verbirektsioone =verbirektsioone  (SgN  >verbirektsioone !16_S	et	f	\N
168358	verbirektsioone	?verbirektsioone =verbirektsioone  (SgG  >verbirektsioone !16_S	et	f	\N
168359	verbirektsioone	?verbirektsioone =verbirektsioone  (PlP  >verbirektsioon !22_S	et	f	\N
168374	veatüüpi	?veatüüpi =veatüüpi  (SgN  >veatüüpi !16_S	et	f	\N
168375	veatüüpi	?veatüüpi =veatüüpi  (SgG  >veatüüpi !16_S	et	f	\N
168376	veatüüpi	?veatüüpi =veatüüpi  (SgP  >veatüüp !22_S	et	f	\N
168377	veatüüpi	?veatüüpi =veatüüpi  (SgAdt  >veatüüp !22_S	et	f	\N
168382	kõnelevatel	kõnelevatel =kõneleva  (PlAd  >kõnelev !02_A	et	f	\N
168383	kõnelevatel	"kõnelev %kõnele  )V_vA  <kõnelema ;27_V	et	f	\N
168384	kõnelevatel	"kõnelev %kõnele  )V_vA  <kõnelema ;31_V	et	f	\N
168391	määrsona	?määrsona =määrso  (SgEs  >määrso !16_S	et	f	\N
168413	jõutagi	jõutagi =tagi  (SgN  >jõu+tagi !17_S	et	f	\N
168414	jõutagi	jõutagi =tagi  (SgG  >jõu+tagi !17_S	et	f	\N
168415	jõutagi	jõutagi =tagi  (SgP  >jõu+tagi !17_S	et	f	\N
168416	jõutagi	jõutagi =jõu  (SgAb^  >jõud !22_S	et	f	\N
168417	jõutagi	jõutagi =jõu  (IndPrIps_^  >jõudma !34_V	et	f	\N
168418	jõutagi	jõutagi =jõuta  (IndPrPs_^  >jõutama !27_V	et	f	\N
168419	jõutagi	jõutagi =jõuta  (ImpPrSg2^  >jõutama !27_V	et	f	\N
168427	analüüsitava	analüüsitava =analüüsitava  (SgG  >analüüsitav !02_A	et	f	\N
168428	analüüsitava	"analüüsitav %analüüsi  )TAV_vAS  <analüüsima ;28_V	et	f	\N
168429	analüüsitava	analüüsitava =tava  (SgN  >analüüsi+tava !17_S	et	f	\N
168430	analüüsitava	analüüsitava =tava  (SgG  >analüüsi+tava !17_S	et	f	\N
168005	keskenduvad	"keskenduv %keskendu  )V_vA  <keskenduma ;27_V	et	f	\N
168010	hindamisele	hindamisele =hindamise  (SgAll  >hindamine !12_S	et	f	\N
168012	hindamisele	"hindamine %hinda  )MINE_vS  <hindama ;29_V	et	f	\N
168024	joondetud	?joondetud =joonde  (PtsPtIps  >joondema !27_V	et	f	\N
168025	joondetud	?joondetud =joondetu  (PlN  >joondetu !01_A	et	f	\N
168026	joondetud	?joondetud =joondetu  (IndPrSg2  >joondetuma !27_V	et	f	\N
168027	joondetud	?joondetud =joondetud  (ID  >joondetud !41_A	et	f	\N
168030	mõnungad	?mõnungad =mõnunga  (PlN  >mõnunga !01_S	et	f	\N
168031	mõnungad	?mõnungad =mõnunga  (PlN  >mõnungas !02_S	et	f	\N
168032	kujunduse	kujunduse =kujunduse  (SgG  >kujundus !11_S	et	f	\N
168033	kujunduse	"kujundus %kujunda  )US_vS  <kujundama ;27_V	et	f	\N
168051	jooneid	?jooneid =joonei  (PlN  >joonei !26_S	et	f	\N
168052	jooneid	?jooneid =joonei  (SgP  >joonei !26_S	et	f	\N
168053	jooneid	?jooneid =jooneid  (SgN  >jooneid !22_S	et	f	\N
168067	õnnitluste	õnnitluste =õnnitlus  (PlG  >õnnitlus !11_S	et	f	\N
168068	õnnitluste	"õnnitlus %õnnitle  )US_vS  <õnnitlema ;27_V	et	f	\N
168069	ornamendid	ornamendid =ornamendi  (PlN  >ornament !22_S	et	f	\N
168070	ornamendid	ornamendid =ornamendi  (IndPrSg2  >ornamentima !28_V	et	f	\N
168101	kontrastiivne	?kontrastiivne =kontrastiivne  (SgN  >kontrastiivne !02_A	et	f	\N
168102	kontrastiivne	?kontrastiivne =kontrastiivne  (PlP  >kontrastiivn !22_S	et	f	\N
168103	kontrastiivne	?kontrastiivne =ivne  (SgN  >kontrasti+ivne !02_A	et	f	\N
168104	kontrastiivne	?kontrastiivne =ivne  (PlP  >kontrasti+ivn !22_S	et	f	\N
168105	kontrastiivne	?kontrastiivne =iivne  (SgN  >kontrast+iivne !02_A	et	f	\N
168107	kontrastiivne	?kontrastiivne =iivne  (PlP  >kontrast+iivn !22_S	et	f	\N
168109	kontrastiivne	?kontrastiivne =stiivne  (SgN  >kontra+stiivne !02_A	et	f	\N
168110	kontrastiivne	?kontrastiivne =stiivne  (PlP  >kontra+stiivn !22_S	et	f	\N
168111	kontrastiivne	?kontrastiivne =rastiivne  (SgN  >kont+rastiivne !02_A	et	f	\N
168112	kontrastiivne	?kontrastiivne =rastiivne  (PlP  >kont+rastiivn !22_S	et	f	\N
168142	ntrolltöö	?ntrolltöö =ntrolltöö  (SgN  >ntrolltöö !26_S	et	f	\N
168143	ntrolltöö	?ntrolltöö =ntrolltöö  (SgG  >ntrolltöö !26_S	et	f	\N
168153	nimetav	nimetav =nimeta  (PtsPrPs  >nimetama !27_V	et	f	\N
168154	nimetav	nimetav =nimetav  (SgN  >nimetav !02_A	et	f	\N
168155	nimetav	"nimetav %nimeta  )V_vA  <nimetama ;27_V	et	f	\N
168160	av	### av	et	f	\N
168161	ad	### ad	et	f	\N
168168	astmevahelduses	?astmevahelduses =astmevahelduse  (SgIn  >astmevaheldus !11_S	et	f	\N
168169	mosastav	?mosastav =mosasta  (PtsPrPs  >mosastama !27_V	et	f	\N
168170	mosastav	?mosastav =mosastav  (SgN  >mosastav !02_A	et	f	\N
168175	amosha	?amosha =amosha  (SgN  >amosha !01_S	et	f	\N
168176	amosha	?amosha =amosha  (SgG  >amosha !01_S	et	f	\N
168177	aid	?aid =aid  (SgN  >aid !22_S	et	f	\N
168182	omastavat	omastavat =omasta  (KvtPrPs  >omastama !27_V	et	f	\N
168183	omastavat	omastavat =omastava  (SgP  >omastav !02_A	et	f	\N
168184	omastavat	"omastav %omasta  )V_vA  <omastama ;27_V	et	f	\N
168206	poolakas	poolakas =poolaka  (SgIn  >poolakas !02_S	et	f	\N
168207	poolakas	poolakas =poolakas  (SgN  >poolakas !02_S	et	f	\N
168208	poolakas	poolakas =aka  (SgIn  >pool+aka !16_S	et	f	\N
168223	jalgrata	?jalgrata =jalgra  (SgAb  >jalgra !01_S	et	f	\N
168224	jalgrata	?jalgrata =jalgra  (Inf  >jalgrama !29_V	et	f	\N
168225	jalgrata	?jalgrata =jalgra  (IndPrIps_  >jalgrama !29_V	et	f	\N
168226	jalgrata	?jalgrata =jalgrata  (IndPrPs_  >jalgratama !27_V	et	f	\N
168227	jalgrata	?jalgrata =jalgrata  (ImpPrSg2  >jalgratama !27_V	et	f	\N
168228	jalgrata	?jalgrata =rata  (SgN  >jalg+rata !16_S	et	f	\N
168229	jalgrata	?jalgrata =rata  (SgG  >jalg+rata !16_S	et	f	\N
168241	armastu	?armastu =armastu  (SgN  >armastu !01_S	et	f	\N
168242	armastu	?armastu =armastu  (SgG  >armastu !01_S	et	f	\N
168243	armastu	?armastu =armastu  (IndPrPs_  >armastuma !27_V	et	f	\N
168244	armastu	?armastu =armastu  (ImpPrSg2  >armastuma !27_V	et	f	\N
168247	vormikasutus	vormikasutus =kasutu  (SgIn  >vormi+kasutu !01_A	et	f	\N
168248	vormikasutus	"vormi+kasutu %kasu  )TU2_kA  <vormi+kasu ;17_S	et	f	\N
168249	vormikasutus	vormikasutus =kasutus  (SgN  >vormi+kasutus !11_S	et	f	\N
168250	vormikasutus	"vormi+kasutus %kasu  )TUS2_aS  <vormi+kasu ;17_S	et	f	\N
168258	õpitav	õpitav =õpi  (PtsPrIps  >õppima !28_V	et	f	\N
168259	õpitav	õpitav =õpitav  (SgN  >õpitav !02_A	et	f	\N
168260	õpitav	"õpitav %õpi  )TAV_vAS  <õppima ;28_V	et	f	\N
168262	lap	### lap	et	f	\N
168268	kolma	?kolma =kolma  (SgN  >kolma !16_S	et	f	\N
168269	kolma	?kolma =kolma  (SgG  >kolma !16_S	et	f	\N
168270	kolma	?kolma =kolma  (IndPrPs_  >kolmama !29_V	et	f	\N
168271	kolma	?kolma =kolma  (ImpPrSg2  >kolmama !29_V	et	f	\N
168281	hulgasõna	### hulgasõna	et	f	\N
168288	koerat	?koerat =koera  (SgP  >koera !16_S	et	f	\N
168289	koerat	?koerat =koerat  (SgN  >koerat !02_S	et	f	\N
168309	ma-inf	?ma-inf =inf  (SgN  >ma-inf !22_S	et	f	\N
168310	vormimoodustusviga	?vormimoodustusviga =vormimoodustusvi  (SgKom  >vormimoodustusv !22_S	et	f	\N
168311	vormimoodustusviga	?vormimoodustusviga =moodustusvi  (SgKom  >vormi+moodustusv !22_S	et	f	\N
168083	spordiosakonna	spordiosakonna =konna  (SgAdt  >spordi+osa+konn !22_S	et	f	\N
168084	spordiosakonna	spordiosakonna =osakonna  (SgG  >spordi+osakond !22_S	et	f	\N
168091	ilmumispiirkonna	ilmumispiirkonna =konna  (SgG  >ilmumis+piir+konn !22_S	et	f	\N
168092	ilmumispiirkonna	ilmumispiirkonna =konna  (SgP  >ilmumis+piir+konn !22_S	et	f	\N
168093	ilmumispiirkonna	ilmumispiirkonna =konna  (SgAdt  >ilmumis+piir+konn !22_S	et	f	\N
168094	ilmumispiirkonna	ilmumispiirkonna =piirkonna  (SgG  >ilmumis+piirkond !22_S	et	f	\N
168097	uudistest	uudistest =uudis  (PlEl  >uudis !09_S	et	f	\N
168098	uudistest	uudistest =test  (SgN  >uudis+test !22_S	et	f	\N
168123	volkova	?volkova =volkova  (SgN  >volkova !01_S	et	f	\N
168124	volkova	?volkova =volkova  (SgG  >volkova !01_S	et	f	\N
168125	volkova	?volkova =volkova  (SgG  >volkov !02_A	et	f	\N
168128	tajuvad	tajuvad =taju  (IndPrPl3  >tajuma !27_V	et	f	\N
168129	tajuvad	tajuvad =tajuva  (PlN  >tajuv !02_A	et	f	\N
168130	tajuvad	"tajuv %taju  )V_vA  <tajuma ;27_V	et	f	\N
168144	rika	?rika =rika  (SgN  >rika !16_S	et	f	\N
168145	rika	?rika =rika  (SgG  >rika !16_S	et	f	\N
168146	rika	?rika =rika  (IndPrPs_  >rikama !27_V	et	f	\N
168147	rika	?rika =rika  (ImpPrSg2  >rikama !27_V	et	f	\N
168158	õm	### õm	et	f	\N
168159	ble	### ble	et	f	\N
168162	vormimoodustusveaks	?vormimoodustusveaks =vormimoodustusvea  (SgTr  >vormimoodustusvea !26_S	et	f	\N
168163	vormimoodustusveaks	?vormimoodustusveaks =moodustusvea  (SgTr  >vormi+moodustusvea !26_S	et	f	\N
168164	vormimoodustusveaks	?vormimoodustusveaks =imoodustusvea  (SgTr  >vorm+imoodustusvea !26_S	et	f	\N
168165	hammasid	?hammasid =hamma  (PlP  >hamma !16_S	et	f	\N
168166	hammasid	?hammasid =hamma  (IndIpfSg2  >hammama !29_V	et	f	\N
168167	hammasid	?hammasid =hamma  (IndIpfPl3  >hammama !29_V	et	f	\N
168189	pu	### pu	et	f	\N
168253	itma	?itma =itma  (IndPrPs_  >itmama !29_V	et	f	\N
168254	itma	?itma =itma  (ImpPrSg2  >itmama !29_V	et	f	\N
168255	pronoomenivead	?pronoomenivead =pronoomenivea  (PlN  >pronoomenivea !26_S	et	f	\N
168256	pronoomenivead	?pronoomenivead =pronoomenivea  (SgP  >pronoomenivea !26_S	et	f	\N
168257	pronoomenivead	?pronoomenivead =pronoomenivead  (SgN  >pronoomenivead !22_S	et	f	\N
168263	mnim	### mnim	et	f	\N
168290	predikatsioon	?predikatsioon =predikatsioon  (SgN  >predikatsioon !22_S	et	f	\N
168291	predikatsioon	?predikatsioon =dikatsioon  (SgN  >pre+dikatsioon !22_S	et	f	\N
168293	kasutus-	kasutus- =kasutu  (SgIn  >kasutu !01_A	et	f	\N
168294	kasutus-	"kasutu %kasu  )TU2_kA  <kasu ;17_S	et	f	\N
168295	kasutus-	kasutus- =kasutus  (SgN  >kasutus !11_S	et	f	\N
168296	kasutus-	"kasutus %kasuta  )US_vS  <kasutama ;27_V	et	f	\N
168297	kasutus-	"kasutus %kasu  )TUS2_aS  <kasu ;17_S	et	f	\N
168302	kur	### kur	et	f	\N
168303	os	### os	et	f	\N
168305	evead	?evead =evea  (PlN  >evea !26_S	et	f	\N
168306	evead	?evead =evea  (SgP  >evea !26_S	et	f	\N
168307	evead	?evead =evead  (SgN  >evead !22_S	et	f	\N
168319	isikuline	isikuline =isikuline  (SgN  >isikuline !12_A	et	f	\N
168320	isikuline	"isikuline %isiku  )LINE_aA  <isik ;02_S	et	f	\N
168321	nlapäeval	?nlapäeval =nlapäeva  (SgAd  >nlapäeva !01_S	et	f	\N
168325	pes	### pes	et	f	\N
168326	tö	### tö	et	f	\N
168328	rohe	rohe =rohe  (SgN  >rohe !16_S	et	f	\N
168329	rohe	rohe =rohe  (SgG  >rohe !16_S	et	f	\N
168342	etas	?etas =eta  (SgIn  >eta !16_S	et	f	\N
168343	etas	?etas =eta  (IndIpfSg3  >etama !27_V	et	f	\N
168344	etas	?etas =etas  (SgN  >etas !07_S	et	f	\N
168378	jälgitav	jälgitav =jälgi  (PtsPrIps  >jälgima !27_V	et	f	\N
168379	jälgitav	jälgitav =jälgitav  (SgN  >jälgitav !02_A	et	f	\N
168380	jälgitav	"jälgitav %jälgi  )TAV_vAS  <jälgima ;27_V	et	f	\N
168405	mõtleja	mõtleja =mõtleja  (SgN  >mõtleja !01_S	et	f	\N
168406	mõtleja	"mõtleja %mõtle  )JA_vS  <mõtlema ;30_V	et	f	\N
168407	mõtleja	mõtleja =mõtleja  (SgG  >mõtleja !01_S	et	f	\N
168409	sõnajärjeviga	sõnajärjeviga =viga  (SgN  >sõna+järje+viga !18_S	et	f	\N
168410	sõnajärjeviga	sõnajärjeviga =viga  (SgP  >sõna+järje+viga !18_S	et	f	\N
168412	märkusedtähelepanekud	?märkusedtähelepanekud =märkusedtähelepaneku  (IndPrSg2  >märkusedtähelepanekuma !27_V	et	f	\N
168422	vigukõnet	### vigukõnet	et	f	\N
168432	kirjeldust	kirjeldust =kirjeldus  (SgP  >kirjeldus !11_S	et	f	\N
168433	kirjeldust	"kirjeldus %kirjelda  )US_vS  <kirjeldama ;27_V	et	f	\N
168445	asjatuntlikult	?asjatuntlikult =asjatuntliku  (SgAbl  >asjatuntlik !25_A	et	f	\N
168446	asjatuntlikult	?asjatuntlikult =asjatuntlikult  (ID  >asjatuntlikult !41_D	et	f	\N
168447	asjatuntlikult	?asjatuntlikult =tuntliku  (SgAbl  >asja+tuntlik !25_A	et	f	\N
168448	asjatuntlikult	?asjatuntlikult =tuntliku  (SgAbl  >asja+tuntliku !01_S	et	f	\N
168471	astmevaheldusvead	?astmevaheldusvead =astmevaheldusvea  (PlN  >astmevaheldusvea !26_S	et	f	\N
168472	astmevaheldusvead	?astmevaheldusvead =astmevaheldusvea  (SgP  >astmevaheldusvea !26_S	et	f	\N
168473	astmevaheldusvead	?astmevaheldusvead =astmevaheldusvead  (SgN  >astmevaheldusvead !22_S	et	f	\N
168475	helilisena	helilisena =helilise  (SgEs  >heliline !12_A	et	f	\N
168476	helilisena	"heliline %heli  )LINE_aA  <heli ;17_S	et	f	\N
168479	eesvokaaliks	eesvokaaliks =iks  (SgN  >ees+vokaal+iks !22_S	et	f	\N
168138	mene	?mene =mene  (ImpPrSg2  >menema !27_V	et	f	\N
168171	tugevas	tugevas =tugeva  (SgIn  >tugev !02_A	et	f	\N
168172	tugevas	"tugev %tuge  )V_vA  <tugema ;27_V	et	f	\N
168178	algperiooldil	?algperiooldil =algperiooldil  (SgN  >algperiooldil !02_S	et	f	\N
168179	algperiooldil	?algperiooldil =periooldil  (SgN  >alg+periooldil !02_S	et	f	\N
168185	osastavat	osastavat =osasta  (KvtPrPs  >osastama !27_V	et	f	\N
168186	osastavat	osastavat =osastava  (SgP  >osastav !02_A	et	f	\N
168187	osastavat	"osastav %osasta  )V_vA  <osastama ;27_V	et	f	\N
168190	interferentne	?interferentne =interferentne  (SgN  >interferentne !02_A	et	f	\N
168191	interferentne	?interferentne =ferentne  (SgN  >inter+ferentne !02_A	et	f	\N
168192	interferentne	?interferentne =ferentne  (PlP  >inter+ferentn !22_S	et	f	\N
168193	näitusesse	näitusesse =näituse  (SgIll  >näitus !11~09_S	et	f	\N
168194	näitusesse	näitusesse =näituses  (SgAdt  >näitusene !12_A	et	f	\N
168195	näitusesse	"näitusene %näituse  )NE_aA  <näitus ;09_S	et	f	\N
168196	näitusesse	"näitusene %näituse  )NE_aA  <näitus ;11_S	et	f	\N
168197	näitusesse	näitusesse =use  (PlIll  >näit+usk !22_S	et	f	\N
168198	väliskoha-	väliskoha- =koha  (SgN  >välis+koha !17_S	et	f	\N
168199	väliskoha-	väliskoha- =koha  (SgG  >välis+koha !17_S	et	f	\N
168200	väliskoha-	väliskoha- =koha  (SgG  >välis+koht !22_S	et	f	\N
168201	väliskoha-	väliskoha- =koha  (SgP  >välis+koha !17_S	et	f	\N
168212	küsimu	?küsimu =küsimu  (SgN  >küsimu !01_S	et	f	\N
168213	küsimu	?küsimu =küsimu  (SgG  >küsimu !01_S	et	f	\N
168214	küsimu	?küsimu =küsimu  (IndPrPs_  >küsimuma !27_V	et	f	\N
168215	küsimu	?küsimu =küsimu  (ImpPrSg2  >küsimuma !27_V	et	f	\N
168216	jalgrata	?jalgrata =jalgra  (SgAb  >jalgra !01_S	et	f	\N
168217	jalgrata	?jalgrata =jalgra  (Inf  >jalgrama !29_V	et	f	\N
168218	jalgrata	?jalgrata =jalgra  (IndPrIps_  >jalgrama !29_V	et	f	\N
168219	jalgrata	?jalgrata =jalgrata  (IndPrPs_  >jalgratama !27_V	et	f	\N
168220	jalgrata	?jalgrata =jalgrata  (ImpPrSg2  >jalgratama !27_V	et	f	\N
168221	jalgrata	?jalgrata =rata  (SgN  >jalg+rata !16_S	et	f	\N
168222	jalgrata	?jalgrata =rata  (SgG  >jalg+rata !16_S	et	f	\N
168230	gru	### gru	et	f	\N
168245	ühildumisveaks	?ühildumisveaks =ühildumisvea  (SgTr  >ühildumisvea !26_S	et	f	\N
168246	vormimoodustusvigade	### vormimoodustusvigade	et	f	\N
168278	7-	### 7-	et	f	\N
168285	põhisõna	põhisõna =sõna  (SgN  >põhi+sõna !17_S	et	f	\N
168286	põhisõna	põhisõna =sõna  (SgG  >põhi+sõna !17_S	et	f	\N
168287	põhisõna	põhisõna =sõna  (SgP  >põhi+sõna !17_S	et	f	\N
168292	nägeb	### nägeb	et	f	\N
168298	modustusvead	?modustusvead =modustusvea  (PlN  >modustusvea !26_S	et	f	\N
168299	modustusvead	?modustusvead =modustusvea  (SgP  >modustusvea !26_S	et	f	\N
168300	modustusvead	?modustusvead =modustusvead  (SgN  >modustusvead !22_S	et	f	\N
168301	kedamida	### kedamida	et	f	\N
168313	jaatav	jaatav =jaata  (PtsPrPs  >jaatama !27_V	et	f	\N
168314	jaatav	jaatav =jaatav  (SgN  >jaatav !02_A	et	f	\N
168315	jaatav	"jaatav %jaata  )V_vA  <jaatama ;27_V	et	f	\N
168318	inf	?inf =inf  (SgN  >inf !22_S	et	f	\N
168333	omk	?omk =omk  (SgN  >omk !22_S	et	f	\N
168347	ajavad	ajavad =aja  (IndPrPl3  >ajama !27_V	et	f	\N
168348	ajavad	ajavad =ajava  (PlN  >ajav !02_A	et	f	\N
168349	ajavad	"ajav %aja  )V_vA  <ajama ;27_V	et	f	\N
168381	v2	### v2	et	f	\N
168385	lausedsõnaühendid	?lausedsõnaühendid =lausedsõnaühendi  (PlN  >lausedsõnaühent !22_S	et	f	\N
168386	lausedsõnaühendid	?lausedsõnaühendid =lausedsõnaühendi  (IndPrSg2  >lausedsõnaühentima !28_V	et	f	\N
168387	lausedsõnaühendid	?lausedsõnaühendid =dsõnaühendi  (PlN  >lause+dsõnaühent !22_S	et	f	\N
168388	lausedsõnaühendid	?lausedsõnaühendid =edsõnaühendi  (PlN  >laus+edsõnaühent !22_S	et	f	\N
168389	lausedsõnaühendid	?lausedsõnaühendid =sedsõnaühendi  (PlN  >lau+sedsõnaühent !22_S	et	f	\N
168392	hommes	?hommes =homme  (PlIn  >homm !22_S	et	f	\N
168393	hommes	?hommes =homme  (IndIpfSg3  >hommema !27_V	et	f	\N
168394	hommes	?hommes =hommes  (SgN  >hommes !09_S	et	f	\N
168399	raado	?raado =raado  (SgN  >raado !16_S	et	f	\N
168400	raado	?raado =raado  (SgG  >raado !16_S	et	f	\N
168411	pronoomeniviga	?pronoomeniviga =pronoomenivi  (SgKom  >pronoomeniv !02_A	et	f	\N
168420	foneetikasfonoloogias	?foneetikasfonoloogias =foneetikasfonoloogia  (SgIn  >foneetikasfonoloogia !01_S	et	f	\N
168421	foneetikasfonoloogias	?foneetikasfonoloogias =foneetikasfonoloogias  (SgN  >foneetikasfonoloogias !11_S	et	f	\N
168423	anal	?anal =ana  (SgAd  >ana !17_S	et	f	\N
168424	anal	?anal =anal  (SgN  >anal !02_S	et	f	\N
168425	korraldatava	korraldatava =korraldatava  (SgG  >korraldatav !02_A	et	f	\N
168426	korraldatava	"korraldatav %korralda  )TAV_vAS  <korraldama ;27_V	et	f	\N
168437	restoranin	?restoranin =restoranin  (SgN  >restoranin !19_S	et	f	\N
168440	bildil	?bildil =bildi  (SgAd  >bilt !22_S	et	f	\N
168455	veineja	?veineja =veineja  (SgN  >veineja !01_S	et	f	\N
168456	veineja	?veineja =veineja  (SgG  >veineja !01_S	et	f	\N
168457	veineja	?veineja =veineja  (SgG  >veinejas !02_A	et	f	\N
168458	kõku	?kõku =kõku  (SgN  >kõku !16_S	et	f	\N
168459	kõku	?kõku =kõku  (SgG  >kõku !16_S	et	f	\N
168312	vormimoodustusviga	?vormimoodustusviga =imoodustusvi  (SgKom  >vorm+imoodustusv !22_S	et	f	\N
168345	etama	?etama =eta  (Sup  >etama !27_V	et	f	\N
168346	etama	?etama =etama  (SgG  >etam !02_A	et	f	\N
168350	lle	### lle	et	f	\N
168351	otset	?otset =otse  (SgP  >otne !02_A	et	f	\N
168352	otset	?otset =otse  (SgP  >otse !06_S	et	f	\N
168353	otset	?otset =otse  (SgP  >otse !16_A	et	f	\N
168434	omapoolsete	omapoolsete =sete  (SgN  >oma+pool+sete !06_S	et	f	\N
168435	omapoolsete	omapoolsete =poolse  (PlG  >oma+poolne !02_A	et	f	\N
168441	koku	?koku =koku  (SgN  >koku !16_S	et	f	\N
168442	koku	?koku =koku  (SgG  >koku !16_S	et	f	\N
168443	koku	?koku =koku  (IndPrPs_  >kokuma !27_V	et	f	\N
168444	koku	?koku =koku  (ImpPrSg2  >kokuma !27_V	et	f	\N
168465	hääldus-	hääldus- =hääldu  (IndIpfSg3  >häälduma !27_V	et	f	\N
168466	hääldus-	hääldus- =hääldus  (SgN  >hääldus !11~09_S	et	f	\N
168467	hääldus-	"hääldus %häälda  )US_vS  <hääldama ;27_V	et	f	\N
168481	vokaalharmoonia	vokaalharmoonia =harmoonia  (SgN  >vokaal+harmoonia !01_S	et	f	\N
168482	vokaalharmoonia	vokaalharmoonia =harmoonia  (SgG  >vokaal+harmoonia !01_S	et	f	\N
168493	dd	### dd	et	f	\N
168504	hääldatuna	hääldatuna =hääldatu  (SgEs  >hääldatu !01_S	et	f	\N
168505	hääldatuna	"hääldatu %häälda  )TU1_vS  <hääldama ;27_V	et	f	\N
168509	õks	?õks =õks  (SgN  >õks !22_S	et	f	\N
168519	nõutu	nõutu =nõutu  (SgN  >nõutu !01_AS	et	f	\N
168520	nõutu	"nõutu %nõu  )TU1_vS  <nõudma ;34_V	et	f	\N
168521	nõutu	"nõutu %nõu  )TU2_kA  <nõu ;26_S	et	f	\N
168522	nõutu	nõutu =nõutu  (SgG  >nõutu !01_AS	et	f	\N
168532	ühtu	?ühtu =ühtu  (SgN  >ühtu !01_S	et	f	\N
168533	ühtu	?ühtu =ühtu  (SgG  >ühtu !01_S	et	f	\N
168534	ühtu	?ühtu =ühtu  (IndPrPs_  >ühtuma !27_V	et	f	\N
168535	ühtu	?ühtu =ühtu  (ImpPrSg2  >ühtuma !27_V	et	f	\N
168540	punktis	punktis =punkti  (SgIn  >punkt !22_S	et	f	\N
168541	punktis	punktis =punkti  (IndIpfSg3  >punktima !28_V	et	f	\N
168546	asesõnast	asesõnast =sõna  (SgEl  >ase+sõna !17_S	et	f	\N
168547	asesõnast	asesõnast =sõnas  (SgP  >ase+sõnane !10_A	et	f	\N
168548	asesõnast	"ase+sõnane %sõna  )NE_aA  <ase+sõna ;17_S	et	f	\N
168553	võõrtüvelise	võõrtüvelise =tüvelise  (SgG  >võõr+tüveline !12_A	et	f	\N
168554	võõrtüvelise	"võõr+tüveline %tüve  )LINE_aA  <võõr+tüvi ;20_S	et	f	\N
168555	tüvevariandi	?tüvevariandi =tüvevariandi  (SgG  >tüvevariant !22_S	et	f	\N
168556	tüvevariandi	?tüvevariandi =tüvevariandi  (SgP  >tüvevariand !22_S	et	f	\N
168557	tüvevariandi	?tüvevariandi =tüvevariandi  (SgAdt  >tüvevariand !22_S	et	f	\N
168558	tüvevariandi	?tüvevariandi =tüvevariandi  (IndPrPs_  >tüvevariantima !28_V	et	f	\N
168559	tüvevariandi	?tüvevariandi =tüvevariandi  (ImpPrSg2  >tüvevariantima !28_V	et	f	\N
168566	kiirrestoraniga	kiirrestoraniga =iga  (SgN  >kiir+restoran+iga !18_S	et	f	\N
168567	kiirrestoraniga	kiirrestoraniga =iga  (SgP  >kiir+restoran+iga !18_S	et	f	\N
168568	kiirrestoraniga	kiirrestoraniga =restorani  (SgKom  >kiir+restoran !19_S	et	f	\N
168599	vaatamamida	### vaatamamida	et	f	\N
168600	leidlikkus	leidlikkus =leidlikkus  (SgN  >leidlikkus !11~09_S	et	f	\N
168601	leidlikkus	"leidlikkus %leidlikku  )US_aS  <leidlik ;25_A	et	f	\N
168617	moju	?moju =moju  (SgN  >moju !17_S	et	f	\N
168618	moju	?moju =moju  (SgG  >moju !17_S	et	f	\N
168619	moju	?moju =moju  (SgP  >moju !17_S	et	f	\N
168620	moju	?moju =moju  (IndPrPs_  >mojuma !27_V	et	f	\N
168621	moju	?moju =moju  (ImpPrSg2  >mojuma !27_V	et	f	\N
168622	minuutit	?minuutit =minuuti  (SgP  >minuuti !16_S	et	f	\N
168623	minuutit	?minuutit =uti  (SgP  >minu+uti !16_S	et	f	\N
168624	minuutit	?minuutit =utit  (SgN  >minu+utit !02_S	et	f	\N
168627	tekisid	?tekisid =teki  (PlP  >teki !16_S	et	f	\N
168628	tekisid	?tekisid =teki  (IndIpfSg2  >tekima !27_V	et	f	\N
168629	tekisid	?tekisid =teki  (IndIpfPl3  >tekima !27_V	et	f	\N
168666	katjaga	katjaga =katja  (SgKom  >katja !01_S	et	f	\N
168667	katjaga	"katja %kat  )JA_vS  <katma ;35_V	et	f	\N
168682	sõbrustavad	sõbrustavad =sõbrusta  (IndPrPl3  >sõbrustama !27_V	et	f	\N
168683	sõbrustavad	sõbrustavad =sõbrustava  (PlN  >sõbrustav !02_A	et	f	\N
168684	sõbrustavad	"sõbrustav %sõbrusta  )V_vA  <sõbrustama ;27_V	et	f	\N
168685	ebaõnnetu	ebaõnnetu =õnnetu  (SgN  >eba+õnnetu !01_A	et	f	\N
168686	ebaõnnetu	"eba+õnnetu %õnne  )TU2_kA  <eba+õnn ;22_S	et	f	\N
168687	ebaõnnetu	ebaõnnetu =õnnetu  (SgG  >eba+õnnetu !01_A	et	f	\N
168690	loovus	loovus =loovus  (SgN  >loovus !11~09_S	et	f	\N
168691	loovus	"loovus %loo  )VUS_aS  <looma ;38_V	et	f	\N
168692	loovus	"loovus %loova  )US_aS  <loov ;02_A	et	f	\N
168699	sõnamoodustusvead	?sõnamoodustusvead =sõnamoodustusvea  (PlN  >sõnamoodustusvea !26_S	et	f	\N
168700	sõnamoodustusvead	?sõnamoodustusvead =sõnamoodustusvea  (SgP  >sõnamoodustusvea !26_S	et	f	\N
168701	sõnamoodustusvead	?sõnamoodustusvead =sõnamoodustusvead  (SgN  >sõnamoodustusvead !22_S	et	f	\N
168703	sõnamoodustusvead	?sõnamoodustusvead =moodustusvea  (PlN  >sõna+moodustusvea !26_S	et	f	\N
168705	sõnamoodustusvead	?sõnamoodustusvead =moodustusvea  (SgP  >sõna+moodustusvea !26_S	et	f	\N
168327	ö	### ö	et	f	\N
168332	püh	?püh =püh  (ID  >püh !41_I	et	f	\N
168334	hirmu-	hirmu- =hirmu  (SgG  >hirm !22_S	et	f	\N
168335	hirmu-	hirmu- =hirmu  (SgP  >hirm !22_S	et	f	\N
168336	hirmu-	hirmu- =hirmu  (SgAdt  >hirm !22_S	et	f	\N
168337	hirmu-	hirmu- =hirmu  (IndPrPs_  >hirmuma !27_V	et	f	\N
168338	hirmu-	hirmu- =hirmu  (ImpPrSg2  >hirmuma !27_V	et	f	\N
168339	meeiga	meeiga =iga  (SgN  >mee+iga !18_S	et	f	\N
168340	meeiga	meeiga =iga  (SgP  >mee+iga !18_S	et	f	\N
168360	interferentsiooni	?interferentsiooni =interferentsioo  (SgTer  >interferentsioo !26_S	et	f	\N
168361	interferentsiooni	?interferentsiooni =interferentsiooni  (SgN  >interferentsiooni !16_S	et	f	\N
168362	interferentsiooni	?interferentsiooni =interferentsiooni  (SgG  >interferentsiooni !16_S	et	f	\N
168363	interferentsiooni	?interferentsiooni =interferentsiooni  (SgG  >interferentsioon !22_S	et	f	\N
168364	interferentsiooni	?interferentsiooni =interferentsiooni  (SgP  >interferentsioon !22_S	et	f	\N
168365	interferentsiooni	?interferentsiooni =interferentsiooni  (SgAdt  >interferentsioon !22_S	et	f	\N
168366	interferentsiooni	?interferentsiooni =interferentsiooni  (IndPrPs_  >interferentsioonima !28_V	et	f	\N
168367	interferentsiooni	?interferentsiooni =interferentsiooni  (ImpPrSg2  >interferentsioonima !28_V	et	f	\N
168368	interferentsiooni	?interferentsiooni =ferentsioo  (SgTer  >inter+ferentsioo !26_S	et	f	\N
168369	interferentsiooni	?interferentsiooni =ferentsiooni  (SgN  >inter+ferentsiooni !16_S	et	f	\N
168370	interferentsiooni	?interferentsiooni =ferentsiooni  (SgG  >inter+ferentsiooni !16_S	et	f	\N
168371	interferentsiooni	?interferentsiooni =ferentsiooni  (SgG  >inter+ferentsioon !22_S	et	f	\N
168372	interferentsiooni	?interferentsiooni =ferentsiooni  (SgP  >inter+ferentsioon !22_S	et	f	\N
168373	interferentsiooni	?interferentsiooni =ferentsiooni  (SgAdt  >inter+ferentsioon !22_S	et	f	\N
168390	lt	### lt	et	f	\N
168395	maardust	?maardust =maardu  (SgEl  >maardu !01_S	et	f	\N
168396	maardust	?maardust =maardus  (SgP  >maardus !11~09_S	et	f	\N
168397	tihedus	tihedus =tihedus  (SgN  >tihedus !11_S	et	f	\N
168398	tihedus	"tihedus %tiheda  )US_aS  <tihe ;02_A	et	f	\N
168401	liigutuste	liigutuste =liigutus  (PlG  >liigutus !11_S	et	f	\N
168402	liigutuste	"liigutus %liiguta  )US_vS  <liigutama ;27_V	et	f	\N
168403	liigutuste	"liigutus %liigu  )TUS1_aS  <liikuma ;28_V	et	f	\N
168404	liigutuste	"liigutus %liigu  )TUS2_aS  <liik ;22_S	et	f	\N
168408	pronoomenivigaõige	?pronoomenivigaõige =pronoomenivigaõige  (PlP  >pronoomenivigaõig !22_S	et	f	\N
168450	itaaliapäraseid	itaaliapäraseid =pärase  (PlP  >itaalia+pärane !10_A	et	f	\N
168451	itaaliapäraseid	"itaalia+pärane %pära  )NE_aA  <itaalia+pära ;17_S	et	f	\N
168453	italialaasia	?italialaasia =italialaasia  (SgN  >italialaasia !01_S	et	f	\N
168454	italialaasia	?italialaasia =italialaasia  (SgG  >italialaasia !01_S	et	f	\N
168462	lauta	lauta =lau  (SgAb  >laug !22_SA	et	f	\N
168463	lauta	lauta =lauta  (SgP  >laut !22_S	et	f	\N
168464	lauta	lauta =lauta  (SgAdt  >laut !22_S	et	f	\N
168468	õigekirja-	õigekirja- =kirja  (SgG  >õige+kiri !24_S	et	f	\N
168469	õigekirja-	õigekirja- =kirja  (SgP  >õige+kiri !24_S	et	f	\N
168470	õigekirja-	õigekirja- =kirja  (SgAdt  >õige+kiri !24_S	et	f	\N
168491	helituna	helituna =helitu  (SgEs  >helitu !01_A	et	f	\N
168492	helituna	"helitu %heli  )TU2_kA  <heli ;17_S	et	f	\N
168506	keskkõrge	keskkõrge =kõrge  (SgN  >kesk+kõrge !01_A	et	f	\N
168507	keskkõrge	keskkõrge =kõrge  (SgN  >kesk+kõrge !05_S	et	f	\N
168508	keskkõrge	keskkõrge =kõrge  (SgG  >kesk+kõrge !01_A	et	f	\N
168515	tga	### tga	et	f	\N
168516	td	### td	et	f	\N
168542	alaltütlev	?alaltütlev =alaltütlev  (SgN  >alaltütlev !02_A	et	f	\N
168543	alaltütlev	?alaltütlev =tütlev  (SgN  >alal+tütlev !02_A	et	f	\N
168544	lähtekohta	lähtekohta =kohta  (SgP  >lähte+koht !22_S	et	f	\N
168545	lähtekohta	lähtekohta =kohta  (SgAdt  >lähte+koht !22_S	et	f	\N
168584	itaalialaasia	?itaalialaasia =itaalialaasia  (SgN  >itaalialaasia !01_S	et	f	\N
168585	itaalialaasia	?itaalialaasia =itaalialaasia  (SgG  >itaalialaasia !01_S	et	f	\N
168586	itaalialaasia	?itaalialaasia =laasia  (SgN  >itaalia+laasia !01_S	et	f	\N
168587	itaalialaasia	?itaalialaasia =laasia  (SgG  >itaalia+laasia !01_S	et	f	\N
168590	veaanal	?veaanal =veaana  (SgAd  >veaana !16_S	et	f	\N
168591	ülikooliõpilastest	ülikooliõpilastest =test  (SgN  >üli+kooli+õpilas+test !22_S	et	f	\N
168592	ülikooliõpilastest	ülikooliõpilastest =las  (PlEl  >üli+kooli+õpi+laps !14_S	et	f	\N
168593	ülikooliõpilastest	ülikooliõpilastest =laste  (PlEl  >üli+kooli+õpi+last !22_S	et	f	\N
168594	ülikooliõpilastest	ülikooliõpilastest =õpilas  (PlEl  >üli+kooli+õpilane !12_S	et	f	\N
168602	ebaõige	ebaõige =õige  (ID  >eba+õige !41_D	et	f	\N
168603	ebaõige	ebaõige =õige  (SgN  >eba+õige !01_A	et	f	\N
168604	ebaõige	ebaõige =õige  (SgG  >eba+õige !01_A	et	f	\N
168615	kanaale	kanaale =ale  (SgN  >kana+ale !16_S	et	f	\N
168616	kanaale	kanaale =ale  (SgG  >kana+ale !16_S	et	f	\N
168633	rezisöörina	?rezisöörina =rezisööri  (SgEs  >rezisööri !16_S	et	f	\N
168636	rezisöörina	?rezisöörina =rezisööri  (SgEs  >rezisöör !22_S	et	f	\N
168637	rezisöörina	?rezisöörina =rezisöörina  (SgG  >rezisöörin !02_S	et	f	\N
168648	lülitanud	lülitanud =lülita  (PtsPtPs  >lülitama !27_V	et	f	\N
168431	analüüsitava	analüüsitava =tava  (SgP  >analüüsi+tava !17_S	et	f	\N
168436	tallinnan	?tallinnan =tallinnan  (SgN  >tallinnan !19_S	et	f	\N
168438	amadeus	?amadeus =amadeu  (SgIn  >amadeu !26_S	et	f	\N
168439	amadeus	?amadeus =amadeus  (SgN  >amadeus !11_S	et	f	\N
168449	leitub	?leitub =leitu  (IndPrSg3  >leituma !27_V	et	f	\N
168452	veinkelder	?veinkelder =veinkelder  (SgN  >veinkelder !02_S	et	f	\N
168477	kõrgeks	kõrgeks =kõrge  (SgTr  >kõrge !01_A	et	f	\N
168478	kõrgeks	kõrgeks =kõrge  (PlTr  >kõrk !22_A	et	f	\N
168494	kasutusest	kasutusest =kasutuse  (SgEl  >kasutus !11_S	et	f	\N
168495	kasutusest	"kasutus %kasuta  )US_vS  <kasutama ;27_V	et	f	\N
168496	kasutusest	"kasutus %kasu  )TUS2_aS  <kasu ;17_S	et	f	\N
168497	kasutusest	kasutusest =kasutuses  (SgP  >kasutusene !12_A	et	f	\N
168498	kasutusest	"kasutusene %kasutuse  )NE_aA  <kasutus ;11_S	et	f	\N
168501	tempokalt	tempokalt =tempoka  (SgAbl  >tempokas !02_A	et	f	\N
168502	tempokalt	tempokalt =tempokalt  (ID  >tempokalt !41_D	et	f	\N
168503	tempokalt	"tempokalt %tempoka  )LT_mD  <tempokas ;02_A	et	f	\N
168510	heliline	heliline =heliline  (SgN  >heliline !12_A	et	f	\N
168511	heliline	"heliline %heli  )LINE_aA  <heli ;17_S	et	f	\N
168512	helitu	helitu =helitu  (SgN  >helitu !01_A	et	f	\N
168513	helitu	"helitu %heli  )TU2_kA  <heli ;17_S	et	f	\N
168514	helitu	helitu =helitu  (SgG  >helitu !01_A	et	f	\N
168527	partitiivverbiga	?partitiivverbiga =partitiivverbi  (SgKom  >partitiivverp !22_S	et	f	\N
168528	partitiivverbiga	?partitiivverbiga =itiivverbi  (SgKom  >part+itiivverp !22_S	et	f	\N
168529	kogemata	kogemata =koge  (SupAb  >kogema !27_V	et	f	\N
168530	kogemata	kogemata =kogemata  (ID  >kogemata !41_D	et	f	\N
168531	kogemata	"kogemata %koge  )MATA_vA  <kogema ;27_V	et	f	\N
168551	õigem	õigem =õigem  (SgN  >õigem !02_A	et	f	\N
168552	õigem	"õigem %õige  )M_cA  <õige ;01_A	et	f	\N
168597	eitus	eitus =eitus  (SgN  >eitus !11~09_S	et	f	\N
168598	eitus	"eitus %eita  )US_vS  <eitama ;27_V	et	f	\N
168625	häälduspärane	häälduspärane =pärane  (SgN  >hääldus+pärane !10_A	et	f	\N
168626	häälduspärane	"hääldus+pärane %pära  )NE_aA  <hääldus+pära ;17_S	et	f	\N
168638	õbraid	?õbraid =õbrai  (PlN  >õbrai !26_S	et	f	\N
168639	õbraid	?õbraid =õbrai  (SgP  >õbrai !26_S	et	f	\N
168640	õbraid	?õbraid =õbraid  (SgN  >õbraid !22_S	et	f	\N
168641	õudsalt	?õudsalt =õudsa  (SgAbl  >õudsa !01_S	et	f	\N
168642	õudsalt	?õudsalt =õudsalt  (ID  >õudsalt !41_D	et	f	\N
168664	eita	eita =eita  (IndPrPs_  >eitama !27_V	et	f	\N
168665	eita	eita =eita  (ImpPrSg2  >eitama !27_V	et	f	\N
168677	köetma	?köetma =köet  (Sup  >köetma !34_V	et	f	\N
168678	köetma	?köetma =köetma  (IndPrPs_  >köetmama !29_V	et	f	\N
168679	köetma	?köetma =köetma  (ImpPrSg2  >köetmama !29_V	et	f	\N
168693	hulluks	hulluks =hullu  (SgTr  >hull !22_AS	et	f	\N
168694	hulluks	hulluks =hullu  (KndPrPs  >hulluma !27_V	et	f	\N
168695	hulluks	hulluks =uks  (SgN  >hull+uks !14_S	et	f	\N
168702	neljajalguline	?neljajalguline =neljajalguline  (SgN  >neljajalguline !12_A	et	f	\N
168704	neljajalguline	?neljajalguline =neljajalguline  (PlP  >neljajalgulin !19_S	et	f	\N
168706	neljajalguline	?neljajalguline =uline  (SgN  >nelja+jalg+uline !10_A	et	f	\N
168708	neljajalguline	?neljajalguline =jalguline  (SgN  >nelja+jalguline !12_A	et	f	\N
168709	neljajalguline	?neljajalguline =jalguline  (PlP  >nelja+jalgulin !19_S	et	f	\N
168711	kummagil	### kummagil	et	f	\N
168714	nähtuse	nähtuse =nähtuse  (SgG  >nähtus !11~09_S	et	f	\N
168715	nähtuse	"nähtus %näh  )TUS1_aS  <nägema ;28_V	et	f	\N
168744	kutsekoolis	kutsekoolis =kooli  (SgIn  >kutse+kool !22_S	et	f	\N
168745	kutsekoolis	kutsekoolis =kooli  (PlIn  >kutse+kool !22_S	et	f	\N
168762	õigekirja	õigekirja =kirja  (SgG  >õige+kiri !24_S	et	f	\N
168763	õigekirja	õigekirja =kirja  (SgP  >õige+kiri !24_S	et	f	\N
168764	õigekirja	õigekirja =kirja  (SgAdt  >õige+kiri !24_S	et	f	\N
168774	automaler	?automaler =automaler  (SgN  >automaler !02_S	et	f	\N
168776	automaler	?automaler =maler  (SgN  >auto+maler !02_S	et	f	\N
168778	automaler	?automaler =tomaler  (SgN  >au+tomaler !19_S	et	f	\N
168791	saija	?saija =saija  (SgN  >saija !01_S	et	f	\N
168792	saija	?saija =saija  (SgG  >saija !01_S	et	f	\N
168793	saija	?saija =saija  (IndPrPs_  >saijama !29_V	et	f	\N
168794	saija	?saija =saija  (ImpPrSg2  >saijama !29_V	et	f	\N
168813	lemik	?lemik =lemik  (SgN  >lemik !02_S	et	f	\N
168815	taivas	?taivas =taiva  (SgIn  >taiva !16_S	et	f	\N
168816	taivas	?taivas =taiva  (IndIpfSg3  >taivama !29_V	et	f	\N
168817	taivas	?taivas =taivas  (SgN  >taivas !07_S	et	f	\N
168818	poliklinika	?poliklinika =poliklinika  (SgN  >poliklinika !01_S	et	f	\N
168819	poliklinika	?poliklinika =poliklinika  (SgG  >poliklinika !01_S	et	f	\N
168820	poliklinika	?poliklinika =poliklinika  (SgG  >poliklinikas !02_A	et	f	\N
168827	pööramisel	pööramisel =pööramise  (SgAd  >pööramine !12_S	et	f	\N
168828	pööramisel	"pööramine %pööra  )MINE_vS  <pöörama ;29_V	et	f	\N
168833	teged	?teged =tege  (PlN  >tege !16_S	et	f	\N
168836	sihitisest	sihitisest =sihitise  (SgEl  >sihitis !11_S	et	f	\N
168837	sihitisest	sihitisest =sihitises  (SgP  >sihitisene !12_A	et	f	\N
168460	kõku	?kõku =kõku  (IndPrPs_  >kõkuma !27_V	et	f	\N
168461	kõku	?kõku =kõku  (ImpPrSg2  >kõkuma !27_V	et	f	\N
168474	pd	### pd	et	f	\N
168523	punktuatsioonivigu	?punktuatsioonivigu =punktuatsioonivigu  (IndPrPs_  >punktuatsiooniviguma !27_V	et	f	\N
168524	punktuatsioonivigu	?punktuatsioonivigu =punktuatsioonivigu  (ImpPrSg2  >punktuatsiooniviguma !27_V	et	f	\N
168525	etmenüüst	?etmenüüst =etmenüü  (SgEl  >etmenüü !26_S	et	f	\N
168526	etmenüüst	?etmenüüst =etmenüüst  (SgN  >etmenüüst !22_S	et	f	\N
168536	sõnamoodustusviis	?sõnamoodustusviis =sõnamoodustusvii  (SgIn  >sõnamoodustusvii !26_S	et	f	\N
168537	sõnamoodustusviis	?sõnamoodustusviis =sõnamoodustusviis  (SgN  >sõnamoodustusviis !22_S	et	f	\N
168538	sõnamoodustusviis	?sõnamoodustusviis =moodustusvii  (SgIn  >sõna+moodustusvii !26_S	et	f	\N
168539	sõnamoodustusviis	?sõnamoodustusviis =moodustusviis  (SgN  >sõna+moodustusviis !22_S	et	f	\N
168569	osatud	osatud =osa  (PtsPtIps  >oskama !29_V	et	f	\N
168570	osatud	osatud =osatu  (PlN  >osatu !01_AS	et	f	\N
168571	osatud	"osatu %osa  )TU1_vS  <oskama ;29_V	et	f	\N
168572	osatud	"osatu %osa  )TU2_kA  <osa ;17_S	et	f	\N
168573	osatud	osatud =osatud  (ID  >osatud !41_A	et	f	\N
168574	osatud	"osatud %osa  )TUD_vA  <oskama ;29_V	et	f	\N
168595	ainsus	ainsus =ainsus  (SgN  >ainsus !11~09_S	et	f	\N
168596	ainsus	"ainsus %ainsa  )US_aS  <ainus ;03_AS	et	f	\N
168608	hooletusviga	?hooletusviga =hooletusvi  (SgKom  >hooletusv !22_S	et	f	\N
168609	hooletusviga	?hooletusviga =tusvi  (SgKom  >hoole+tusvi !16_S	et	f	\N
168610	hooletusviga	?hooletusviga =tusvi  (SgKom  >hoole+tusv !22_S	et	f	\N
168611	hooletusviga	?hooletusviga =letusvi  (SgKom  >hoo+letusvi !01_S	et	f	\N
168612	hooletusviga	?hooletusviga =letusvi  (SgKom  >hoo+letusv !22_S	et	f	\N
168672	tähenduselt	tähenduselt =tähenduse  (SgAbl  >tähendus !11_S	et	f	\N
168673	tähenduselt	"tähendus %tähenda  )US_vS  <tähendama ;27_V	et	f	\N
168696	hulluks	hulluks =hullu  (SgTr  >hull !22_AS	et	f	\N
168697	hulluks	hulluks =hullu  (KndPrPs  >hulluma !27_V	et	f	\N
168698	hulluks	hulluks =uks  (SgN  >hull+uks !14_S	et	f	\N
168712	eluline	eluline =eluline  (SgN  >eluline !12_A	et	f	\N
168713	eluline	"eluline %elu  )LINE_aA  <elu ;17_S	et	f	\N
168729	kreativsele	?kreativsele =kreativse  (SgAll  >kreativne !02_A	et	f	\N
168730	kreativsele	?kreativsele =kreativse  (PlAll  >kreativs !22_S	et	f	\N
168746	tütarlapsi	tütarlapsi =laps  (PlP  >tütar+laps !14_S	et	f	\N
168747	tütarlapsi	tütarlapsi =lapsi  (SgG  >tütar+laps !22_S	et	f	\N
168748	tütarlapsi	tütarlapsi =lapsi  (SgP  >tütar+laps !22_S	et	f	\N
168749	tütarlapsi	tütarlapsi =lapsi  (SgAdt  >tütar+laps !22_S	et	f	\N
168755	poisse	poisse =poi  (SgIll  >poi !26_S	et	f	\N
168756	poisse	poisse =poisse  (SgG  >poise !06_S	et	f	\N
168757	poisse	poisse =poisse  (PlP  >poiss !23?22_S	et	f	\N
168775	kevitaja	?kevitaja =kevitaja  (SgN  >kevitaja !01_S	et	f	\N
168777	kevitaja	?kevitaja =kevitaja  (SgG  >kevitaja !01_S	et	f	\N
168779	kevitaja	?kevitaja =kevitaja  (SgG  >kevitajas !02_A	et	f	\N
168780	gimnasium	?gimnasium =gimnasium  (SgN  >gimnasium !19_S	et	f	\N
168781	saksamal	?saksamal =saksama  (SgAd  >saksam !02_A	et	f	\N
168782	saksamal	?saksamal =saksamal  (ID  >saksamal !41_D	et	f	\N
168809	remontib	### remontib	et	f	\N
168829	olvikus	?olvikus =olviku  (SgIn  >olviku !01_S	et	f	\N
168830	olvikus	?olvikus =olviku  (SgIn  >olvik !02_S	et	f	\N
168831	olvikus	?olvikus =olviku  (IndIpfSg3  >olvikuma !27_V	et	f	\N
168832	olvikus	?olvikus =olvikus  (SgN  >olvikus !11_S	et	f	\N
168834	näged	?näged =näge  (PlN  >näge !16_S	et	f	\N
168839	muulastele	muulastele =muulas  (PlAll  >muulane !12?10_S	et	f	\N
168840	muulastele	"muulane %muula  )NE_aA  <muul ;22_S	et	f	\N
168841	muulastele	muulastele =las  (PlAll  >muu+laps !14_S	et	f	\N
168842	muulastele	muulastele =laste  (PlAll  >muu+last !22_S	et	f	\N
168843	nimetavat	nimetavat =nimeta  (KvtPrPs  >nimetama !27_V	et	f	\N
168844	nimetavat	nimetavat =nimetava  (SgP  >nimetav !02_A	et	f	\N
168845	nimetavat	"nimetav %nimeta  )V_vA  <nimetama ;27_V	et	f	\N
168846	kurjategejad	?kurjategejad =kurjategeja  (PlN  >kurjategeja !01_S	et	f	\N
168847	kurjategejad	?kurjategejad =kurjategeja  (PlN  >kurjategejas !02_A	et	f	\N
168848	kurjategejad	?kurjategejad =tegeja  (PlN  >kurja+tegeja !01_S	et	f	\N
168849	kurjategejad	?kurjategejad =tegeja  (PlN  >kurja+tegejas !02_A	et	f	\N
168858	diskosse	?diskosse =disko  (SgIll  >disko !16_S	et	f	\N
168859	diskosse	?diskosse =diskos  (SgAdt  >diskos !11_S	et	f	\N
168860	diskosse	?diskosse =diskosse  (SgG  >diskosne !02_A	et	f	\N
168861	diskosse	?diskosse =diskosse  (PlP  >diskoss !22_S	et	f	\N
168900	sünniaasta	sünniaasta =aasta  (SgN  >sünni+aasta !01_S	et	f	\N
168901	sünniaasta	sünniaasta =aasta  (SgG  >sünni+aasta !01_S	et	f	\N
168918	nelja-	nelja- =nelja  (SgG  >neljas !02_O	et	f	\N
168919	nelja-	nelja- =nelja  (SgG  >neli !24_N	et	f	\N
168920	nelja-	nelja- =nelja  (SgP  >neli !24_N	et	f	\N
168921	nelja-	nelja- =nelja  (SgAdt  >neli !24_N	et	f	\N
168922	kahekümmne	?kahekümmne =kahekümmne  (SgN  >kahekümmne !02_A	et	f	\N
168923	kahekümmne	?kahekümmne =kümmne  (SgN  >kahe+kümmne !02_A	et	f	\N
168924	kahekümmne	?kahekümmne =kümmne  (PlP  >kahe+kümmn !22_S	et	f	\N
168480	eesvokaaliks	eesvokaaliks =vokaali  (SgTr  >ees+vokaal !22_S	et	f	\N
168483	põhjendatav	põhjendatav =põhjenda  (PtsPrIps  >põhjendama !27_V	et	f	\N
168484	põhjendatav	põhjendatav =põhjendatav  (SgN  >põhjendatav !02_A	et	f	\N
168485	põhjendatav	"põhjendatav %põhjenda  )TAV_vAS  <põhjendama ;27_V	et	f	\N
168486	hoolimatusega	hoolimatusega =hoolimatuse  (SgKom  >hoolimatus !11?09_S	et	f	\N
168487	hoolimatusega	"hoolimatus %hooli  )MATUS_aS  <hoolima ;28_V	et	f	\N
168488	hoolimatusega	hoolimatusega =limatuse  (SgKom  >hoo+limatus !11_S	et	f	\N
168489	hoolimatusega	"hoo+limatus %lima  )TUS2_aS  <hoo+lima ;17_S	et	f	\N
168490	gd	### gd	et	f	\N
168499	helilise	helilise =helilise  (SgG  >heliline !12_A	et	f	\N
168500	helilise	"heliline %heli  )LINE_aA  <heli ;17_S	et	f	\N
168517	peegeldu	peegeldu =peegeldu  (IndPrPs_  >peegelduma !27_V	et	f	\N
168518	peegeldu	peegeldu =peegeldu  (ImpPrSg2  >peegelduma !27_V	et	f	\N
168549	topelt	topelt =tope  (PlAbl  >topp !22_S	et	f	\N
168550	topelt	topelt =topelt  (ID  >topelt !41_D	et	f	\N
168560	tsementima	tsementima =tsementi  (Sup  >tsementima !28_V	et	f	\N
168561	tsementima	tsementima =ima  (SgN  >tsement+ima !17_S	et	f	\N
168562	tsementima	tsementima =ima  (SgG  >tsement+ima !17_S	et	f	\N
168563	tsementima	tsementima =ima  (SgP  >tsement+ima !17_S	et	f	\N
168564	ähmaseks	ähmaseks =ähmase  (SgTr  >ähmane !10_A	et	f	\N
168565	ähmaseks	"ähmane %ähma  )NE_aA  <ähm ;22_S	et	f	\N
168575	liitmise	liitmise =liitmise  (SgG  >liitmine !12?10_S	et	f	\N
168576	liitmise	"liitmine %liit  )MINE_vS  <liitma ;34_V	et	f	\N
168577	kergema	kergema =kergema  (SgG  >kergem !02_A	et	f	\N
168578	kergema	"kergem %kerge  )M_cA  <kerge ;01_A	et	f	\N
168579	kergema	kergema =ema  (SgN  >kerg+ema !17_S	et	f	\N
168580	kergema	kergema =ema  (SgG  >kerg+ema !17_S	et	f	\N
168581	kergema	kergema =ema  (SgP  >kerg+ema !17_S	et	f	\N
168582	lõigatuna	lõigatuna =lõigatu  (SgEs  >lõigatu !01_AS	et	f	\N
168583	lõigatuna	"lõigatu %lõiga  )TU1_vS  <lõikama ;29_V	et	f	\N
168588	ülesehitatud	ülesehitatud =ehita  (PtsPtIps  >üles+_ehitama !27_V	et	f	\N
168589	ülesehitatud	ülesehitatud =ehitatu  (PlN  >üles+ehitatu !01_S	et	f	\N
168605	substantiivi	substantiivi =substantiivi  (SgG  >substantiiv !22_S	et	f	\N
168606	substantiivi	substantiivi =substantiivi  (SgP  >substantiiv !22_S	et	f	\N
168607	substantiivi	substantiivi =substantiivi  (SgAdt  >substantiiv !22_S	et	f	\N
168613	uhtus	uhtus =uhtu  (IndIpfSg3  >uhtuma !27_V	et	f	\N
168614	uhtus	uhtus =uhtu  (IndIpfSg3  >uhtuma !28_V	et	f	\N
168630	astmevaheldusviga	?astmevaheldusviga =astmevaheldusvi  (SgKom  >astmevaheldusv !22_S	et	f	\N
168631	asjatega	?asjatega =asja  (PlKom  >asjas !02_A	et	f	\N
168632	proffessorid	?proffessorid =proffessori  (PlN  >proffessor !02_S	et	f	\N
168634	kutsuta	kutsuta =kutsu  (SgAb  >kutsu !16_S	et	f	\N
168635	kutsuta	kutsuta =kutsu  (IndPrIps_  >kutsuma !28_V	et	f	\N
168643	kokku-lahku	kokku-lahku =lahku  (ID  >kokku-lahku !41_D	et	f	\N
168644	kokku-lahku	kokku-lahku =lahku  (SgP  >kokku-lahk !22_S	et	f	\N
168645	kokku-lahku	kokku-lahku =lahku  (SgAdt  >kokku-lahk !22_S	et	f	\N
168646	kokku-lahku	kokku-lahku =lahku  (IndPrPs_  >kokku-lahkuma !27_V	et	f	\N
168647	kokku-lahku	kokku-lahku =lahku  (ImpPrSg2  >kokku-lahkuma !27_V	et	f	\N
168680	ruumid	ruumid =ruumi  (PlN  >ruum !22_S	et	f	\N
168681	ruumid	ruumid =ruumi  (IndPrSg2  >ruumima !28_V	et	f	\N
168710	kumbkil	?kumbkil =kumbki  (SgAd  >kumbk !22_S	et	f	\N
168727	ainsust	ainsust =ainsus  (SgP  >ainsus !11~09_S	et	f	\N
168728	ainsust	"ainsus %ainsa  )US_aS  <ainus ;03_AS	et	f	\N
168736	l0ja	### l0ja	et	f	\N
168737	lklassist	?lklassist =lklassi  (SgEl  >lklassi !16_S	et	f	\N
168738	lklassist	?lklassist =lklassi  (SgEl  >lklass !22_S	et	f	\N
168739	lklassist	?lklassist =lklassist  (SgN  >lklassist !22_S	et	f	\N
168742	grammatika-	grammatika- =grammatika  (SgN  >grammatika !01_S	et	f	\N
168743	grammatika-	grammatika- =grammatika  (SgG  >grammatika !01_S	et	f	\N
168758	neidki	neidki =ne  (PlP^  >see !00_P	et	f	\N
168759	neidki	neidki =ne  (PlP^  >ta !00_P	et	f	\N
168760	neidki	neidki =ne  (PlP^  >tema !00_P	et	f	\N
168761	neidki	neidki =neid  (SgN^  >neid !22_S	et	f	\N
168786	saarema	saarema =ema  (SgN  >saar+ema !17_S	et	f	\N
168787	saarema	saarema =ema  (SgG  >saar+ema !17_S	et	f	\N
168788	saarema	saarema =ema  (SgP  >saar+ema !17_S	et	f	\N
168789	arbus	arbus =arbu  (SgIn  >arp !22_S	et	f	\N
168790	arbus	arbus =arbu  (IndIpfSg3  >arbuma !28_V	et	f	\N
168795	pastaplijats	?pastaplijats =pastaplijats  (SgN  >pastaplijats !22_S	et	f	\N
168796	pastaplijats	?pastaplijats =plijats  (SgN  >pasta+plijats !02_S	et	f	\N
168804	akken	?akken =akke  (IndPrSg1  >akkema !27_V	et	f	\N
168805	akken	?akken =akken  (SgN  >akken !02_S	et	f	\N
168806	mehannika	?mehannika =mehannika  (SgN  >mehannika !01_S	et	f	\N
168807	mehannika	?mehannika =mehannika  (SgG  >mehannika !01_S	et	f	\N
168808	mehannika	?mehannika =mehannika  (SgG  >mehannikas !02_A	et	f	\N
168810	perekonanimi	?perekonanimi =perekonanimi  (SgG  >perekonanim !02_A	et	f	\N
168811	perekonanimi	?perekonanimi =konanimi  (SgG  >pere+konanim !02_A	et	f	\N
168821	ekskursiole	?ekskursiole =ekskursio  (SgAll  >ekskursio !01_S	et	f	\N
168649	lülitanud	lülitanud =lülitanu  (PlN  >lülitanu !01_S	et	f	\N
168650	lülitanud	"lülitanu %lülita  )NU_vS  <lülitama ;27_V	et	f	\N
168651	lülitanud	lülitanud =lülitanud  (ID  >lülitanud !41_A	et	f	\N
168652	lülitanud	"lülitanud %lülita  )NUD_vA  <lülitama ;27_V	et	f	\N
168653	lülitanud	lülitanud =tanu  (PlN  >lüli+tanu !17_S	et	f	\N
168654	eituse	eituse =eituse  (SgG  >eitus !11~09_S	et	f	\N
168655	eituse	"eitus %eita  )US_vS  <eitama ;27_V	et	f	\N
168656	partitiivivormi	?partitiivivormi =partitiivivormi  (SgG  >partitiivivorm !22_S	et	f	\N
168657	partitiivivormi	?partitiivivormi =partitiivivormi  (SgP  >partitiivivorm !22_S	et	f	\N
168658	partitiivivormi	?partitiivivormi =partitiivivormi  (SgAdt  >partitiivivorm !22_S	et	f	\N
168659	partitiivivormi	?partitiivivormi =partitiivivormi  (IndPrPs_  >partitiivivormima !28_V	et	f	\N
168660	partitiivivormi	?partitiivivormi =partitiivivormi  (ImpPrSg2  >partitiivivormima !28_V	et	f	\N
168661	partitiivivormi	?partitiivivormi =itiivivormi  (SgG  >part+itiivivorm !22_S	et	f	\N
168662	partitiivivormi	?partitiivivormi =itiivivormi  (SgP  >part+itiivivorm !22_S	et	f	\N
168663	partitiivivormi	?partitiivivormi =itiivivormi  (SgAdt  >part+itiivivorm !22_S	et	f	\N
168668	eksivad	eksivad =eksi  (IndPrPl3  >eksima !28_V	et	f	\N
168669	eksivad	eksivad =eksiva  (PlN  >eksiv !02_A	et	f	\N
168670	eksivad	"eksiv %eksi  )V_vA  <eksima ;28_V	et	f	\N
168671	eksivad	eksivad =iva  (PlN  >eks+iva !17_S	et	f	\N
168674	andaksin	?andaksin =anda  (KndPrSg1  >andama !29_V	et	f	\N
168675	andaksin	?andaksin =andaksi  (IndPrSg1  >andaksima !28_V	et	f	\N
168676	andaksin	?andaksin =andaksin  (SgN  >andaksin !19_S	et	f	\N
168688	sõna-sõnaline	sõna-sõnaline =sõnaline  (SgN  >sõna-sõnaline !12_A	et	f	\N
168689	sõna-sõnaline	"sõna-sõnaline %sõna  )LINE_aA  <sõna-sõna ;17_S	et	f	\N
168723	fantastiline	fantastiline =fantastiline  (SgN  >fantastiline !12_A	et	f	\N
168724	fantastiline	"fantastiline %fantasti  )LINE_aA  <fantast ;22_S	et	f	\N
168750	viis-kuus	viis-kuus =kuu  (SgIn  >viis-kuu !26_S	et	f	\N
168751	viis-kuus	viis-kuus =kuus  (SgN  >viis-kuus !14_N	et	f	\N
168765	konsonantühendi	?konsonantühendi =konsonantühendi  (SgG  >konsonantühent !22_S	et	f	\N
168766	konsonantühendi	?konsonantühendi =konsonantühendi  (SgP  >konsonantühend !22_S	et	f	\N
168767	konsonantühendi	?konsonantühendi =konsonantühendi  (SgAdt  >konsonantühend !22_S	et	f	\N
168768	konsonantühendi	?konsonantühendi =konsonantühendi  (IndPrPs_  >konsonantühentima !28_V	et	f	\N
168769	konsonantühendi	?konsonantühendi =konsonantühendi  (ImpPrSg2  >konsonantühentima !28_V	et	f	\N
168772	suret	?suret =sure  (SgP  >sure !16_S	et	f	\N
168773	rägib	?rägib =rägi  (IndPrSg3  >rägima !27_V	et	f	\N
168800	hammbad	?hammbad =hammba  (PlN  >hammba !01_S	et	f	\N
168801	hammbad	?hammbad =hammba  (IndPrSg2  >hammbama !29_V	et	f	\N
168814	sinnililled	### sinnililled	et	f	\N
168850	lihtsamates	lihtsamates =lihtsama  (PlIn  >lihtsam !02_A	et	f	\N
168851	lihtsamates	"lihtsam %lihtsa  )M_cA  <lihtne ;02_A	et	f	\N
168852	lihtsamates	lihtsamates =mate  (SgIn  >lihtsa+mate !16_S	et	f	\N
168853	lihtsamates	lihtsamates =mate  (PlIn  >lihtsa+matt !22_SA	et	f	\N
168866	klaasist	klaasist =klaasi  (SgEl  >klaas !22_S	et	f	\N
168867	klaasist	klaasist =klaasis  (SgP  >klaasine !10_A	et	f	\N
168868	klaasist	"klaasine %klaasi  )NE_aA  <klaas ;22_S	et	f	\N
168871	lapst	?lapst =lapst  (SgN  >lapst !22_S	et	f	\N
168877	käändest	käändest =käände  (SgEl  >kääne !06_S	et	f	\N
168878	käändest	käändest =käändes  (SgP  >käändene !12~10_A	et	f	\N
168879	käändest	"käändene %käände  )NE_aA  <kääne ;06_S	et	f	\N
168898	lillekimpedes	### lillekimpedes	et	f	\N
168913	korruselises	korruselises =korruselise  (SgIn  >korruseline !12_A	et	f	\N
168915	korruselises	"korruseline %korruse  )LINE_aA  <korrus ;09_S	et	f	\N
168928	kiirena	kiirena =kiire  (SgEs  >kiire !01_A	et	f	\N
168929	kiirena	kiirena =kiire  (SgEs  >kiire !06_S	et	f	\N
168930	kiirena	kiirena =kiire  (SgEs  >kiire !06_AS	et	f	\N
168931	kiirena	kiirena =kiire  (SgEs  >kiir !13_S	et	f	\N
168942	tegeb	### tegeb	et	f	\N
168953	kellesse	kellesse =kelle  (SgIll  >kes !00_P	et	f	\N
168954	kellesse	kellesse =kelle  (PlIll  >kell !22_S	et	f	\N
168968	ains	?ains =ains  (SgN  >ains !22_S	et	f	\N
168969	reformatsioni	?reformatsioni =reformatsio  (SgTer  >reformatsio !01_S	et	f	\N
168970	reformatsioni	?reformatsioni =reformatsioni  (SgN  >reformatsioni !16_S	et	f	\N
168971	reformatsioni	?reformatsioni =reformatsioni  (SgG  >reformatsion !19~02_S	et	f	\N
168972	reformatsioni	?reformatsioni =reformatsioni  (SgG  >reformatsioni !16_S	et	f	\N
168973	reformatsioni	?reformatsioni =reformatsioni  (SgP  >reformatsion !19_S	et	f	\N
168974	reformatsioni	?reformatsioni =reformatsioni  (SgAdt  >reformatsion !19_S	et	f	\N
168975	reformatsioni	?reformatsioni =reformatsioni  (IndPrPs_  >reformatsionima !28_V	et	f	\N
168976	reformatsioni	?reformatsioni =reformatsioni  (ImpPrSg2  >reformatsionima !28_V	et	f	\N
168977	reformatsioni	?reformatsioni =atsio  (SgTer  >reform+atsio !01_S	et	f	\N
168978	reformatsioni	?reformatsioni =atsioni  (SgN  >reform+atsioni !16_S	et	f	\N
168979	reformatsioni	?reformatsioni =atsioni  (SgG  >reform+atsion !19~02_S	et	f	\N
168980	reformatsioni	?reformatsioni =atsioni  (SgG  >reform+atsioni !16_S	et	f	\N
168707	sõnamoodustusvead	?sõnamoodustusvead =moodustusvead  (SgN  >sõna+moodustusvead !22_S	et	f	\N
168716	petmist-	petmist- =petmis  (SgP  >petmine !12?10_S	et	f	\N
168717	petmist-	"petmine %pet  )MINE_vS  <petma ;35_V	et	f	\N
168718	enesekohast	enesekohast =koha  (SgEl  >enese+koha !17_S	et	f	\N
168719	enesekohast	enesekohast =koha  (SgEl  >enese+koht !22_S	et	f	\N
168720	enesekohast	enesekohast =kohas  (SgP  >enese+kohane !10_A	et	f	\N
168721	enesekohast	"enese+kohane %koha  )NE_aA  <enese+koha ;17_S	et	f	\N
168722	enesekohast	"enese+kohane %koha  )NE_aA  <enese+koht ;22_S	et	f	\N
168725	pöördelõppu	pöördelõppu =lõppu  (SgP  >pöörde+lõpp !22_SA	et	f	\N
168726	pöördelõppu	pöördelõppu =lõppu  (SgAdt  >pöörde+lõpp !22_SA	et	f	\N
168731	arvestatud-mõeldud	arvestatud-mõeldud =mõel  (PtsPtIps  >arvestatud-mõtlema !30_V	et	f	\N
168732	arvestatud-mõeldud	arvestatud-mõeldud =mõeldu  (PlN  >arvestatud-mõeldu !01_S	et	f	\N
168733	arvestatud-mõeldud	"arvestatud-mõeldu %mõel  )TU1_vS  <arvestatud-mõtlema ;30_V	et	f	\N
168734	arvestatud-mõeldud	arvestatud-mõeldud =mõeldud  (ID  >arvestatud-mõeldud !41_A	et	f	\N
168735	arvestatud-mõeldud	"arvestatud-mõeldud %mõel  )TUD_vA  <arvestatud-mõtlema ;30_V	et	f	\N
168740	tugevate	tugevate =tugeva  (PlG  >tugev !02_A	et	f	\N
168741	tugevate	"tugev %tuge  )V_vA  <tugema ;27_V	et	f	\N
168752	tuldud	tuldud =tul  (PtsPtIps  >tulema !36_V	et	f	\N
168753	tuldud	tuldud =tuldud  (ID  >tuldud !41_A	et	f	\N
168754	tuldud	"tuldud %tul  )TUD_vA  <tulema ;36_V	et	f	\N
168770	spetsialne	?spetsialne =spetsialne  (SgN  >spetsialne !02_A	et	f	\N
168771	spetsialne	?spetsialne =spetsialne  (PlP  >spetsialn !22_S	et	f	\N
168783	juksed	?juksed =jukse  (PlN  >jukne !02_A	et	f	\N
168784	juksed	?juksed =jukse  (PlN  >jukse !06_S	et	f	\N
168785	juksed	?juksed =jukse  (IndPrSg2  >juksema !28_V	et	f	\N
168797	müja	?müja =müja  (SgN  >müja !17_S	et	f	\N
168798	müja	?müja =müja  (SgG  >müja !17_S	et	f	\N
168799	müja	?müja =müja  (SgP  >müja !17_S	et	f	\N
168802	müja	?müja =müja  (IndPrPs_  >müjama !27_V	et	f	\N
168803	müja	?müja =müja  (ImpPrSg2  >müjama !27_V	et	f	\N
168812	aprilis	?aprilis =aprilis  (SgN  >aprilis !11_S	et	f	\N
168835	sokkid	### sokkid	et	f	\N
168854	lilleosakonnasse	lilleosakonnasse =konna  (SgIll  >lille+osa+konn !22_S	et	f	\N
168855	lilleosakonnasse	lilleosakonnasse =osakonna  (SgIll  >lille+osakond !22_S	et	f	\N
168856	lilleosakonnasse	lilleosakonnasse =osakonnas  (SgAdt  >lille+osakonnane !12_A	et	f	\N
168857	lilleosakonnasse	"lille+osakonnane %osakonna  )NE_aA  <lille+osakond ;22_S	et	f	\N
168862	tallinast	?tallinast =tallinas  (SgP  >tallinane !12_A	et	f	\N
168863	tallinast	?tallinast =nast  (SgN  >talli+nast !22_S	et	f	\N
168872	töötajasse	töötajasse =töötaja  (SgIll  >töötaja !01_S	et	f	\N
168873	töötajasse	"töötaja %tööta  )JA_vS  <töötama ;27_V	et	f	\N
168874	töötajasse	töötajasse =töötajas  (SgAdt  >töötajane !12_A	et	f	\N
168875	töötajasse	"töötajane %töötaja  )NE_aA  <töötaja ;01_S	et	f	\N
168876	nimetavst	?nimetavst =tavst  (SgN  >nime+tavst !22_S	et	f	\N
168880	terast	terast =tera  (SgEl  >tera !17_S	et	f	\N
168881	terast	terast =teras  (SgP  >teras !09_S	et	f	\N
168882	terast	terast =teras  (SgP  >terane !10_A	et	f	\N
168883	terast	"terane %tera  )NE_aA  <tera ;17_S	et	f	\N
168884	terasest	terasest =terase  (SgEl  >teras !09_S	et	f	\N
168885	terasest	terasest =terase  (SgEl  >terane !10_A	et	f	\N
168886	terasest	"terane %tera  )NE_aA  <tera ;17_S	et	f	\N
168887	terasest	terasest =terases  (SgP  >terasene !12_A	et	f	\N
168888	terasest	"terasene %terase  )NE_aA  <teras ;09_S	et	f	\N
168889	kurbusse	kurbusse =kurbus  (SgAdt  >kurbus !11_S	et	f	\N
168890	kurbusse	"kurbus %kurb  )US_aS  <kurb ;22_A	et	f	\N
168891	kurbusse	kurbusse =usse  (PlP  >kurb+uss !22_S	et	f	\N
168905	esmast-ühekseni	?esmast-ühekseni =ühekse  (SgTer  >esmast-ühekne !02_A	et	f	\N
168906	esmast-ühekseni	?esmast-ühekseni =ühekseni  (SgG  >esmast-üheksen !19_S	et	f	\N
168907	esmast-ühekseni	?esmast-ühekseni =ühekseni  (SgP  >esmast-üheksen !19_S	et	f	\N
168908	esmast-ühekseni	?esmast-ühekseni =ühekseni  (SgAdt  >esmast-üheksen !19_S	et	f	\N
168909	esmast-ühekseni	?esmast-ühekseni =kseni  (SgN  >esmast-ühe+kseni !17_S	et	f	\N
168910	esmast-ühekseni	?esmast-ühekseni =kseni  (SgG  >esmast-ühe+kseni !17_S	et	f	\N
168911	esmast-ühekseni	?esmast-ühekseni =kseni  (SgP  >esmast-ühe+kseni !17_S	et	f	\N
168938	käändelõputa	?käändelõputa =käändelõpu  (IndPrIps_  >käändelõpuma !27_V	et	f	\N
168939	käändelõputa	?käändelõputa =käändelõputa  (IndPrPs_  >käändelõputama !27_V	et	f	\N
168940	käändelõputa	?käändelõputa =käändelõputa  (ImpPrSg2  >käändelõputama !27_V	et	f	\N
168941	käändelõputa	?käändelõputa =elõpu  (SgAb  >käänd+elõpu !01_S	et	f	\N
168949	kirjutasib	### kirjutasib	et	f	\N
168965	football	?football =football  (SgN  >football !22_S	et	f	\N
168966	hamb	?hamb =hamb  (SgN  >hamb !22_S	et	f	\N
168984	astmevahelduslik	?astmevahelduslik =astmevahelduslik  (SgN  >astmevahelduslik !25_A	et	f	\N
168985	mitteeeslaste	mitteeeslaste =las  (PlG  >mitte+ees+laps !14_S	et	f	\N
168986	mitteeeslaste	mitteeeslaste =laste  (PlP  >mitte+ees+last !22_S	et	f	\N
168989	ilvaanias	?ilvaanias =ilvaania  (SgIn  >ilvaania !01_S	et	f	\N
168822	ekskursiole	?ekskursiole =ekskursiole  (PlP  >ekskursiol !19_S	et	f	\N
168823	ekskursiole	?ekskursiole =ole  (SgN  >eks+kursi+ole !16_S	et	f	\N
168824	ekskursiole	?ekskursiole =ole  (SgG  >eks+kursi+ole !16_S	et	f	\N
168825	ekskursiole	?ekskursiole =kursio  (SgAll  >eks+kursio !01_S	et	f	\N
168826	ekskursiole	?ekskursiole =kursiole  (PlP  >eks+kursiol !19_S	et	f	\N
168892	kurbusesse	kurbusesse =kurbuse  (SgIll  >kurbus !11~09_S	et	f	\N
168893	kurbusesse	"kurbus %kurb  )US_aS  <kurb ;22_A	et	f	\N
168894	kurbusesse	kurbusesse =kurbuses  (SgAdt  >kurbusene !12_A	et	f	\N
168895	kurbusesse	"kurbusene %kurbuse  )NE_aA  <kurbus ;09_S	et	f	\N
168896	kurbusesse	"kurbusene %kurbuse  )NE_aA  <kurbus ;11_S	et	f	\N
168897	kurbusesse	kurbusesse =use  (PlIll  >kurb+usk !22_S	et	f	\N
168899	detsembrul	?detsembrul =detsembru  (SgAd  >detsembru !01_S	et	f	\N
168925	ühildamises	ühildamises =ühildamise  (SgIn  >ühildamine !12_S	et	f	\N
168926	ühildamises	"ühildamine %ühilda  )MINE_vS  <ühildama ;27_V	et	f	\N
168927	tiit	?tiit =tiit  (SgN  >tiit !22_S	et	f	\N
168950	pidamistarvete	pidamistarvete =e  (PlG  >pidamist+arv+esi !15_S	et	f	\N
168951	pidamistarvete	pidamistarvete =arve  (PlG  >pidamist+arve !06_S	et	f	\N
168952	pidamistarvete	pidamistarvete =tarve  (PlG  >pidamis+tarve !06_S	et	f	\N
168988	ss	### ss	et	f	\N
168993	transilvaanias	?transilvaanias =transilvaania  (SgIn  >transilvaania !01_S	et	f	\N
168994	transilvaanias	?transilvaanias =transilvaanias  (SgN  >transilvaanias !11_S	et	f	\N
168995	transilvaanias	?transilvaanias =ilvaania  (SgIn  >trans+ilvaania !01_S	et	f	\N
168996	transilvaanias	?transilvaanias =ilvaanias  (SgN  >trans+ilvaanias !11_S	et	f	\N
169012	morfoloogilised	morfoloogilised =morfoloogilise  (PlN  >morfoloogiline !12_A	et	f	\N
169013	morfoloogilised	"morfoloogiline %morfoloogi  )LINE_aA  <morfoloog ;22_S	et	f	\N
169029	laulmikudes	?laulmikudes =laulmiku  (PlIn  >laulmik !25_S	et	f	\N
169030	laulmikudes	?laulmikudes =laulmiku  (Ger  >laulmikuma !27_V	et	f	\N
169034	väidenud	?väidenud =väide  (PtsPtPs  >väidema !27_V	et	f	\N
169035	väidenud	?väidenud =väidenu  (PlN  >väidenu !01_S	et	f	\N
169036	väidenud	?väidenud =väidenu  (IndPrSg2  >väidenuma !27_V	et	f	\N
169037	väidenud	?väidenud =väidenud  (ID  >väidenud !41_A	et	f	\N
169038	väidenud	?väidenud =denu  (PlN  >väi+denu !17_S	et	f	\N
169039	võidis	võidis =võid  (IndIpfSg3  >võidma !34_V	et	f	\N
169040	võidis	võidis =võidi  (SgIn  >võit !22_S	et	f	\N
169041	võidis	võidis =võidis  (SgN  >võidis !09_S	et	f	\N
169052	jälgis	jälgis =jälgi  (SgIn  >jälk !22_A	et	f	\N
169053	jälgis	jälgis =jälgi  (IndIpfSg3  >jälgima !27_V	et	f	\N
169057	pretsedenditu	pretsedenditu =pretsedenditu  (SgN  >pretsedenditu !01_A	et	f	\N
169058	pretsedenditu	"pretsedenditu %pretsedendi  )TU2_kA  <pretsedent ;22_S	et	f	\N
169065	pretsedenditu	pretsedenditu =pretsedenditu  (SgG  >pretsedenditu !01_A	et	f	\N
169070	reformaatorlik	?reformaatorlik =reformaatorlik  (SgN  >reformaatorlik !25_A	et	f	\N
169071	reformaatorlik	?reformaatorlik =aatorlik  (SgN  >reform+aatorlik !25_A	et	f	\N
169074	lõpevad	lõpevad =lõpe  (IndPrPl3  >lõppema !28_V	et	f	\N
169076	lõpevad	lõpevad =lõpe  (IndPrPl3  >lõpma !35_V	et	f	\N
169094	osastavaga	osastavaga =osastava  (SgKom  >osastav !02_A	et	f	\N
169095	osastavaga	"osastav %osasta  )V_vA  <osastama ;27_V	et	f	\N
169096	elektrat	?elektrat =elektra  (SgP  >elektra !01_S	et	f	\N
169097	elektra	?elektra =elektra  (SgN  >elektra !01_S	et	f	\N
169098	elektra	?elektra =elektra  (SgG  >elektra !01_S	et	f	\N
169111	kohakäände	kohakäände =käände  (SgG  >koha+kääne !06_S	et	f	\N
169112	kohakäände	kohakäände =käände  (PlP  >koha+käänd !22_S	et	f	\N
169128	transilvaania	?transilvaania =transilvaania  (SgN  >transilvaania !01_S	et	f	\N
169129	transilvaania	?transilvaania =transilvaania  (SgG  >transilvaania !01_S	et	f	\N
169130	transilvaania	?transilvaania =ilvaania  (SgN  >trans+ilvaania !01_S	et	f	\N
169131	transilvaania	?transilvaania =ilvaania  (SgG  >trans+ilvaania !01_S	et	f	\N
169137	periodi	?periodi =periodi  (SgN  >periodi !16_S	et	f	\N
169138	periodi	?periodi =periodi  (SgG  >periodi !16_S	et	f	\N
169139	periodi	?periodi =periodi  (SgG  >periot !22_S	et	f	\N
169140	periodi	?periodi =periodi  (SgP  >period !22_S	et	f	\N
169141	periodi	?periodi =periodi  (SgAdt  >period !22_S	et	f	\N
169142	periodi	?periodi =periodi  (IndPrPs_  >periotima !28_V	et	f	\N
169143	periodi	?periodi =periodi  (ImpPrSg2  >periotima !28_V	et	f	\N
169154	õppikud	?õppikud =õppiku  (PlN  >õppiku !01_S	et	f	\N
169155	õppikud	?õppikud =õppiku  (PlN  >õppik !02_S	et	f	\N
169156	õppikud	?õppikud =õppiku  (IndPrSg2  >õppikuma !27_V	et	f	\N
169158	infinitiivivead	?infinitiivivead =infinitiivivea  (PlN  >infinitiivivea !26_S	et	f	\N
169159	infinitiivivead	?infinitiivivead =infinitiivivea  (SgP  >infinitiivivea !26_S	et	f	\N
169160	infinitiivivead	?infinitiivivead =infinitiivivead  (SgN  >infinitiivivead !22_S	et	f	\N
169174	kirikuorganisatsiooni	kirikuorganisatsiooni =organisatsiooni  (SgG  >kiriku+organisatsioon !22_S	et	f	\N
169175	kirikuorganisatsiooni	kirikuorganisatsiooni =organisatsiooni  (SgP  >kiriku+organisatsioon !22_S	et	f	\N
169176	kirikuorganisatsiooni	kirikuorganisatsiooni =organisatsiooni  (SgAdt  >kiriku+organisatsioon !22_S	et	f	\N
169185	ballassi	?ballassi =ballassi  (SgN  >ballassi !01_S	et	f	\N
168838	sihitisest	"sihitisene %sihitise  )NE_aA  <sihitis ;11_S	et	f	\N
168864	esimestel	esimestel =esimes  (PlAd  >esimene !12_OP	et	f	\N
168865	esimestel	esimestel =meste  (PlAd  >esi+mest !22_S	et	f	\N
168869	keevitajaks	keevitajaks =keevitaja  (SgTr  >keevitaja !01_S	et	f	\N
168870	keevitajaks	"keevitaja %keevita  )JA_vS  <keevitama ;27_V	et	f	\N
168902	üheksasaia	üheksasaia =saia  (SgG  >üheksa+sai !22_S	et	f	\N
168903	üheksasaia	üheksasaia =saia  (SgP  >üheksa+sai !22_S	et	f	\N
168904	üheksasaia	üheksasaia =saia  (SgAdt  >üheksa+sai !22_S	et	f	\N
168912	nelji	?nelji =nelji  (SgN  >nelji !16_S	et	f	\N
168914	nelji	?nelji =nelji  (SgG  >nelji !16_S	et	f	\N
168916	nelji	?nelji =nelji  (IndPrPs_  >neljima !28_V	et	f	\N
168917	nelji	?nelji =nelji  (ImpPrSg2  >neljima !28_V	et	f	\N
168955	juhtkonda	juhtkonda =juhtkonda  (SgP  >juhtkond !22_S	et	f	\N
168956	juhtkonda	juhtkonda =juhtkonda  (SgAdt  >juhtkond !22_S	et	f	\N
168959	mustamää	?mustamää =mustamää  (SgN  >mustamää !26_S	et	f	\N
168960	mustamää	?mustamää =mustamää  (SgG  >mustamää !26_S	et	f	\N
168961	mustamää	?mustamää =amää  (SgN  >must+amää !26_S	et	f	\N
168962	mustamää	?mustamää =amää  (SgG  >must+amää !26_S	et	f	\N
168963	kuulduse	kuulduse =kuulduse  (SgG  >kuuldus !11~09_S	et	f	\N
168964	kuulduse	"kuuldus %kuul  )TUS1_aS  <kuulma ;33_V	et	f	\N
168997	transsilvaania	?transsilvaania =transsilvaania  (SgN  >transsilvaania !01_S	et	f	\N
168998	transsilvaania	?transsilvaania =transsilvaania  (SgG  >transsilvaania !01_S	et	f	\N
168999	transsilvaania	?transsilvaania =silvaania  (SgN  >trans+silvaania !01_S	et	f	\N
169000	transsilvaania	?transsilvaania =silvaania  (SgG  >trans+silvaania !01_S	et	f	\N
169021	eelnevaga	eelnevaga =eelneva  (SgKom  >eelnev !02_A	et	f	\N
169022	eelnevaga	"eelnev %eelne  )V_vA  <eelnema ;27_V	et	f	\N
169031	m-i	m-i =m  (SgG  >m !xx_Q	et	f	\N
169032	m-i	m-i =m  (SgP  >m !xx_Q	et	f	\N
169033	m-i	m-i =m  (SgAdt  >m !xx_Q	et	f	\N
169056	religiooslik	?religiooslik =religiooslik  (SgN  >religiooslik !25_A	et	f	\N
169059	tagakiusatamine	?tagakiusatamine =tagakiusatamine  (SgN  >tagakiusatamine !12_S	et	f	\N
169060	tagakiusatamine	?tagakiusatamine =tagakiusatamine  (PlP  >tagakiusatamin !19_S	et	f	\N
169061	tagakiusatamine	?tagakiusatamine =atamine  (SgN  >taga+kius+atamine !12_S	et	f	\N
169062	tagakiusatamine	?tagakiusatamine =atamine  (PlP  >taga+kius+atamin !19_S	et	f	\N
169063	tagakiusatamine	?tagakiusatamine =kiusatamine  (SgN  >taga+kiusatamine !12_S	et	f	\N
169064	tagakiusatamine	?tagakiusatamine =kiusatamine  (PlP  >taga+kiusatamin !19_S	et	f	\N
169075	sga	### sga	et	f	\N
169087	eksemplari	eksemplari =eksemplari  (SgG  >eksemplar !19_S	et	f	\N
169088	eksemplari	eksemplari =eksemplari  (SgP  >eksemplar !19_S	et	f	\N
169089	eksemplari	eksemplari =eksemplari  (SgAdt  >eksemplar !19_S	et	f	\N
169100	omistasid	omistasid =omista  (IndIpfSg2  >omistama !27_V	et	f	\N
169101	omistasid	omistasid =omista  (IndIpfPl3  >omistama !27_V	et	f	\N
169116	belgiumi	?belgiumi =belgiumi  (SgN  >belgiumi !16_S	et	f	\N
169117	belgiumi	?belgiumi =belgiumi  (SgG  >belgium !19~02_S	et	f	\N
169118	belgiumi	?belgiumi =belgiumi  (SgG  >belgiumi !16_S	et	f	\N
169119	belgiumi	?belgiumi =belgiumi  (SgP  >belgium !19_S	et	f	\N
169120	belgiumi	?belgiumi =belgiumi  (SgAdt  >belgium !19_S	et	f	\N
169121	belgiumi	?belgiumi =belgiumi  (IndPrPs_  >belgiumima !28_V	et	f	\N
169122	belgiumi	?belgiumi =belgiumi  (ImpPrSg2  >belgiumima !28_V	et	f	\N
169125	religiosse	?religiosse =religio  (SgIll  >religio !01_S	et	f	\N
169126	religiosse	?religiosse =religiosse  (SgG  >religiosne !02_A	et	f	\N
169127	religiosse	?religiosse =religiosse  (PlP  >religioss !22_S	et	f	\N
169167	vangistatud	vangistatud =vangista  (PtsPtIps  >vangistama !27_V	et	f	\N
169168	vangistatud	vangistatud =vangistatu  (PlN  >vangistatu !01_S	et	f	\N
169169	vangistatud	"vangistatu %vangista  )TU1_vS  <vangistama ;27_V	et	f	\N
169170	vangistatud	vangistatud =vangistatud  (ID  >vangistatud !41_A	et	f	\N
169171	vangistatud	"vangistatud %vangista  )TUD_vA  <vangistama ;27_V	et	f	\N
169177	transilvaaniasse	?transilvaaniasse =transilvaania  (SgIll  >transilvaania !01_S	et	f	\N
169178	transilvaaniasse	?transilvaaniasse =transilvaanias  (SgAdt  >transilvaanias !11_S	et	f	\N
169179	transilvaaniasse	?transilvaaniasse =transilvaaniasse  (SgG  >transilvaaniasne !02_A	et	f	\N
169180	transilvaaniasse	?transilvaaniasse =transilvaaniasse  (PlP  >transilvaaniass !22_S	et	f	\N
169181	transilvaaniasse	?transilvaaniasse =ilvaania  (SgIll  >trans+ilvaania !01_S	et	f	\N
169182	transilvaaniasse	?transilvaaniasse =ilvaanias  (SgAdt  >trans+ilvaanias !11_S	et	f	\N
169183	transilvaaniasse	?transilvaaniasse =ilvaaniasse  (SgG  >trans+ilvaaniasne !02_A	et	f	\N
169184	transilvaaniasse	?transilvaaniasse =ilvaaniasse  (PlP  >trans+ilvaaniass !22_S	et	f	\N
169194	parandusi	parandusi =parandusi  (PlP  >parandus !11_S	et	f	\N
169195	parandusi	"parandus %paranda  )US_vS  <parandama ;27_V	et	f	\N
169216	eksimusi	eksimusi =eksimusi  (PlP  >eksimus !11_S	et	f	\N
169217	eksimusi	eksimusi =musi  (SgN  >eksi+musi !17_S	et	f	\N
169218	eksimusi	eksimusi =musi  (SgG  >eksi+musi !17_S	et	f	\N
169219	eksimusi	eksimusi =musi  (SgP  >eksi+musi !17_S	et	f	\N
169220	inimesd	?inimesd =inimesd  (SgN  >inimesd !22_S	et	f	\N
169221	inimesd	?inimesd =esd  (SgN  >inim+esd !22_S	et	f	\N
168932	puudutava	puudutava =puudutava  (SgG  >puudutav !02_A	et	f	\N
168933	puudutava	"puudutav %puudu  )TAV_vAS  <puuduma ;27_V	et	f	\N
168934	puudutava	"puudutav %puuduta  )V_vA  <puudutama ;27_V	et	f	\N
168935	puudutava	puudutava =tava  (SgN  >puudu+tava !17_S	et	f	\N
168936	puudutava	puudutava =tava  (SgG  >puudu+tava !17_S	et	f	\N
168937	puudutava	puudutava =tava  (SgP  >puudu+tava !17_S	et	f	\N
168943	rootsis-vastavalt	rootsis-vastavalt =vastava  (SgAbl  >rootsis-vastav !02_A	et	f	\N
168944	rootsis-vastavalt	"rootsis-vastav %vasta  )V_vA  <rootsis-vastama ;29_V	et	f	\N
168945	rootsis-vastavalt	rootsis-vastavalt =vastavalt  (ID  >rootsis-vastavalt !41_D	et	f	\N
168946	rootsis-vastavalt	"rootsis-vastavalt %vasta  )VALT_mD  <rootsis-vastama ;29_V	et	f	\N
168947	rootsis-vastavalt	"rootsis-vastavalt %vastava  )LT_mD  <rootsis-vastav ;02_A	et	f	\N
168948	rootsis-vastavalt	rootsis-vastavalt =ava  (SgAbl  >rootsis-vast+ava !17_S	et	f	\N
168957	kasumita	kasumita =kasumi  (SgAb  >kasum !02_S	et	f	\N
168958	kasumita	kasumita =mi  (SgAb  >kasu+mi !26_S	et	f	\N
168967	viip	?viip =viip  (SgN  >viip !22_S	et	f	\N
168987	tran	### tran	et	f	\N
168991	valitsemisest	valitsemisest =valitsemise  (SgEl  >valitsemine !12_S	et	f	\N
168992	valitsemisest	"valitsemine %valitse  )MINE_vS  <valitsema ;27_V	et	f	\N
169016	teode	?teode =teo  (PlG  >teo !26_S	et	f	\N
169017	teode	?teode =teode  (SgN  >teode !06_S	et	f	\N
169018	teode	?teode =teode  (PlP  >teod !22_S	et	f	\N
169019	teode	?teode =teode  (IndPrPs_  >teodema !27_V	et	f	\N
169020	teode	?teode =teode  (ImpPrSg2  >teodema !27_V	et	f	\N
169023	hankiti	?hankiti =hankiti  (ID  >hankiti !41_D	et	f	\N
169024	hankiti	?hankiti =hankiti  (SgG  >hankit !02_S	et	f	\N
169025	hankiti	?hankiti =hankiti  (SgG  >hankitt !22_S	et	f	\N
169026	hankiti	?hankiti =hankiti  (IndPrPs_  >hankittima !28_V	et	f	\N
169027	hankiti	?hankiti =hankiti  (ImpPrSg2  >hankittima !28_V	et	f	\N
169028	sõjadega	?sõjadega =sõja  (PlKom  >sõja !17_S	et	f	\N
169042	despooti	despooti =despooti  (SgP  >despoot !22_S	et	f	\N
169043	despooti	despooti =despooti  (SgAdt  >despoot !22_S	et	f	\N
169044	reformatoorite	?reformatoorite =reformatoori  (IndPrPl2  >reformatoorima !28_V	et	f	\N
169090	piible	?piible =piible  (SgN  >piible !06_S	et	f	\N
169091	piible	?piible =piible  (SgG  >piible !06_S	et	f	\N
169092	piible	?piible =piible  (IndPrPs_  >piiblema !30_V	et	f	\N
169093	piible	?piible =piible  (ImpPrSg2  >piiblema !30_V	et	f	\N
169132	trükkitud	?trükkitud =trükkitu  (PlN  >trükkitu !01_AS	et	f	\N
169133	trükkitud	?trükkitud =trükkitu  (IndPrSg2  >trükkituma !27_V	et	f	\N
169134	trükkitud	?trükkitud =trükkitud  (ID  >trükkitud !41_A	et	f	\N
169148	trükikoda	trükikoda =koda  (SgN  >trüki+koda !18_S	et	f	\N
169149	trükikoda	trükikoda =koda  (SgP  >trüki+koda !18_S	et	f	\N
169157	trükimise	?trükimise =trükimise  (SgG  >trükimine !12_S	et	f	\N
169196	veaanlüüs	?veaanlüüs =veaanlüü  (SgIn  >veaanlüü !26_S	et	f	\N
169197	veaanlüüs	?veaanlüüs =veaanlüüs  (SgN  >veaanlüüs !22_S	et	f	\N
169201	kaheteistkümnendate	?kaheteistkümnendate =kaheteistkümnenda  (IndPrPl2  >kaheteistkümnendama !27_V	et	f	\N
169202	kaheteistkümnendate	?kaheteistkümnendate =ate  (SgN  >kahe+teist+kümnend+ate !06_S	et	f	\N
169203	kaheteistkümnendate	?kaheteistkümnendate =kümnenda  (PlG  >kahe+teist+kümnenda !01_S	et	f	\N
169206	arutluseks	arutluseks =arutluse  (SgTr  >arutlus !11_S	et	f	\N
169207	arutluseks	"arutlus %arutle  )US_vS  <arutlema ;27_V	et	f	\N
169247	kolmandasse	kolmandasse =kolmanda  (SgIll  >kolmas !02_O	et	f	\N
169248	kolmandasse	kolmandasse =kolmandas  (SgAdt  >kolmandane !12_A	et	f	\N
169262	orjusest	orjusest =orjuse  (SgEl  >orjus !11~09_S	et	f	\N
169263	orjusest	orjusest =orjuses  (SgP  >orjusene !12_A	et	f	\N
169264	orjusest	"orjusene %orjuse  )NE_aA  <orjus ;09_S	et	f	\N
169265	orjusest	"orjusene %orjuse  )NE_aA  <orjus ;11_S	et	f	\N
169269	luuletustes	luuletustes =luuletus  (PlIn  >luuletus !11_S	et	f	\N
169270	luuletustes	"luuletus %luuleta  )US_vS  <luuletama ;27_V	et	f	\N
169271	luuletustes	"luuletus %luule  )TUS2_aS  <luule ;06_S	et	f	\N
169272	luuletustes	luuletustes =tuste  (PlIn  >luule+tust !22_S	et	f	\N
169275	ülestõusust	ülestõusust =tõusu  (SgEl  >üles+tõus !22_S	et	f	\N
169276	ülestõusust	ülestõusust =tõusus  (SgP  >üles+tõusus !11~09_S	et	f	\N
169277	ülestõusust	"üles+tõusus %tõu  )SUS_aS  <üles+tõug ;22_S	et	f	\N
169278	ülestõusust	"üles+tõusus %tõu  )SUS_aS  <üles+tõu ;26_S	et	f	\N
169282	grammatikasse	grammatikasse =grammatika  (SgIll  >grammatika !01_S	et	f	\N
169283	grammatikasse	grammatikasse =grammatikas  (SgAdt  >grammatikane !12_A	et	f	\N
169284	grammatikasse	"grammatikane %grammatika  )NE_aA  <grammatika ;01_S	et	f	\N
169285	pöörasid	pöörasid =pööra  (PlP  >pöör !22_S	et	f	\N
169286	pöörasid	pöörasid =pööra  (IndIpfSg2  >pöörama !29_V	et	f	\N
169287	pöörasid	pöörasid =pööra  (IndIpfPl3  >pöörama !29_V	et	f	\N
169334	käima-verbi	käima-verbi =verbi  (SgG  >käima-verb !22_S	et	f	\N
169335	käima-verbi	käima-verbi =verbi  (SgP  >käima-verb !22_S	et	f	\N
169336	käima-verbi	käima-verbi =verbi  (SgAdt  >käima-verb !22_S	et	f	\N
169344	põõrama	?põõrama =põõra  (Sup  >põõrama !29_V	et	f	\N
168981	reformatsioni	?reformatsioni =atsioni  (SgP  >reform+atsion !19_S	et	f	\N
168982	reformatsioni	?reformatsioni =atsioni  (SgAdt  >reform+atsion !19_S	et	f	\N
168983	objektiviga	?objektiviga =objektivi  (SgKom  >objektiv !02_A	et	f	\N
169001	vaidluslehte	vaidluslehte =lehte  (SgP  >vaidlus+leht !22_S	et	f	\N
169002	vaidluslehte	vaidluslehte =lehte  (SgAdt  >vaidlus+leht !22_S	et	f	\N
169003	vaidluslehte	vaidluslehte =lehte  (PlP  >vaidlus+leht !22_S	et	f	\N
169009	lausesõnajärjest	lausesõnajärjest =järje  (SgEl  >lause+sõna+järg !22_S	et	f	\N
169010	lausesõnajärjest	lausesõnajärjest =järjes  (SgP  >lause+sõna+järjene !10_A	et	f	\N
169011	lausesõnajärjest	"lause+sõna+järjene %järje  )NE_aA  <lause+sõna+järg ;22_S	et	f	\N
169066	reformatoorne	?reformatoorne =reformatoorne  (SgN  >reformatoorne !02_A	et	f	\N
169067	reformatoorne	?reformatoorne =reformatoorne  (PlP  >reformatoorn !22_S	et	f	\N
169068	reformatoorne	?reformatoorne =atoorne  (SgN  >reform+atoorne !02_A	et	f	\N
169069	reformatoorne	?reformatoorne =atoorne  (PlP  >reform+atoorn !22_S	et	f	\N
169078	reeglipärane	reeglipärane =pärane  (SgN  >reegli+pärane !10_A	et	f	\N
169079	reeglipärane	"reegli+pärane %pära  )NE_aA  <reegli+pära ;17_S	et	f	\N
169086	uust	?uust =uust  (SgN  >uust !22_S	et	f	\N
169099	sylvesteri	?sylvesteri =sylvesteri  (SgG  >sylvester !02_S	et	f	\N
169144	mistitsism	?mistitsism =mistitsism  (SgN  >mistitsism !22_S	et	f	\N
169145	mistitsism	?mistitsism =titsism  (SgN  >mis+titsism !22_S	et	f	\N
169146	trükkikoda	trükkikoda =koda  (SgN  >trükki+koda !18_S	et	f	\N
169147	trükkikoda	trükkikoda =koda  (SgP  >trükki+koda !18_S	et	f	\N
169210	läbiviidud	läbiviidud =vii  (PtsPtIps  >läbi+_viima !38_V	et	f	\N
169211	läbiviidud	läbiviidud =viidu  (PlN  >läbi+viidu !01_S	et	f	\N
169212	kinnita	kinnita =kinnita  (IndPrPs_  >kinnitama !27_V	et	f	\N
169213	kinnita	kinnita =kinnita  (ImpPrSg2  >kinnitama !27_V	et	f	\N
169214	kasin	kasin =kasi  (IndPrSg1  >kasima !27_V	et	f	\N
169215	kasin	kasin =kasin  (SgN  >kasin !02_A	et	f	\N
169222	täisminevikulisi	täisminevikulisi =minevikulisi  (PlP  >täis+minevikuline !12_A	et	f	\N
169223	täisminevikulisi	"täis+minevikuline %mineviku  )LINE_aA  <täis+minevik ;25_S	et	f	\N
169224	kulli	kulli =kulli  (SgG  >kull !22_S	et	f	\N
169225	kulli	kulli =kulli  (SgP  >kull !22_S	et	f	\N
169226	kulli	kulli =kulli  (SgAdt  >kull !22_S	et	f	\N
169239	eksisid	eksisid =eksi  (IndIpfSg2  >eksima !28_V	et	f	\N
169240	eksisid	eksisid =eksi  (IndIpfPl3  >eksima !28_V	et	f	\N
169241	depresioonisse	?depresioonisse =depresiooni  (SgIll  >depresiooni !16_S	et	f	\N
169242	depresioonisse	?depresioonisse =depresiooni  (SgIll  >depresioon !22_S	et	f	\N
169243	depresioonisse	?depresioonisse =depresioonisse  (SgG  >depresioonisne !02_A	et	f	\N
169244	depresioonisse	?depresioonisse =depresioonisse  (PlP  >depresiooniss !22_S	et	f	\N
169266	venekeele	venekeele =kee  (SgAll  >vene+kesi !15_S	et	f	\N
169267	venekeele	venekeele =kee  (SgAll  >vene+kee !26_S	et	f	\N
169268	venekeele	venekeele =keele  (SgG  >vene+keel !13_S	et	f	\N
169299	kirjalikkest	?kirjalikkest =kirjalikkes  (SgP  >kirjalikkene !12_S	et	f	\N
169305	süüti	?süüti =süüti  (ID  >süüti !41_D	et	f	\N
169306	süüti	?süüti =süüti  (SgP  >süüt !22_S	et	f	\N
169307	süüti	?süüti =süüti  (SgAdt  >süüt !22_S	et	f	\N
169333	aknat	?aknat =aknat  (SgN  >aknat !02_S	et	f	\N
169339	kakskümmendaastane	?kakskümmendaastane =kakskümmendaastane  (SgN  >kakskümmendaastane !12~10_A	et	f	\N
169340	kakskümmendaastane	?kakskümmendaastane =kümmendaastane  (SgN  >kaks+kümmendaastane !12~10_A	et	f	\N
169346	ilmnevad	ilmnevad =ilmne  (IndPrPl3  >ilmnema !27_V	et	f	\N
169347	ilmnevad	ilmnevad =ilmneva  (PlN  >ilmnev !02_A	et	f	\N
169348	ilmnevad	"ilmnev %ilmne  )V_vA  <ilmnema ;27_V	et	f	\N
169351	hapnim	?hapnim =hapnim  (SgN  >hapnim !02_A	et	f	\N
169354	astmevahelduseta	?astmevahelduseta =astmevahelduse  (SgAb  >astmevaheldus !11_S	et	f	\N
169355	astmevahelduseta	?astmevahelduseta =astmevahelduseta  (IndPrPs_  >astmevaheldusetama !27_V	et	f	\N
169356	astmevahelduseta	?astmevahelduseta =astmevahelduseta  (ImpPrSg2  >astmevaheldusetama !27_V	et	f	\N
169358	tõlkin	?tõlkin =tõlkin  (SgN  >tõlkin !02_S	et	f	\N
169368	kordustrükkis	?kordustrükkis =kordustrükki  (IndIpfSg3  >kordustrükkima !28_V	et	f	\N
169369	kordustrükkis	?kordustrükkis =kordustrükkis  (SgN  >kordustrükkis !09_S	et	f	\N
169370	kordustrükkis	?kordustrükkis =ustrükkis  (SgN  >kord+ustrükkis !11_S	et	f	\N
169375	uhineb	?uhineb =uhine  (IndPrSg3  >uhinema !27_V	et	f	\N
169405	moksadega	?moksadega =moksa  (PlKom  >moksa !16_S	et	f	\N
169406	uldse	?uldse =uldse  (SgN  >uldse !06_S	et	f	\N
169407	uldse	?uldse =uldse  (SgG  >uldne !02_A	et	f	\N
169408	uldse	?uldse =uldse  (SgG  >uldse !06_S	et	f	\N
169409	uldse	?uldse =uldse  (PlP  >ulds !22_S	et	f	\N
169410	uldse	?uldse =uldse  (IndPrPs_  >uldsema !27_V	et	f	\N
169411	uldse	?uldse =uldse  (ImpPrSg2  >uldsema !27_V	et	f	\N
169414	tanapaevani	?tanapaevani =tanapaeva  (SgTer  >tanapaeva !16_S	et	f	\N
169415	tanapaevani	?tanapaevani =tanapaevani  (SgG  >tanapaevan !02_S	et	f	\N
169416	keelepruuki	keelepruuki =pruuki  (SgP  >keele+pruuk !22_S	et	f	\N
169417	keelepruuki	keelepruuki =pruuki  (SgAdt  >keele+pruuk !22_S	et	f	\N
169426	mordens	?mordens =mordens  (SgN  >mordens !02_S	et	f	\N
168990	ilvaanias	?ilvaanias =ilvaanias  (SgN  >ilvaanias !11_S	et	f	\N
169004	religioonivabadust	religioonivabadust =dust  (SgN  >religiooni+vaba+dust !22_S	et	f	\N
169005	religioonivabadust	religioonivabadust =vabadus  (SgP  >religiooni+vabadus !11_S	et	f	\N
169006	religioonivabadust	"religiooni+vabadus %vaba  )US_aS  <religiooni+vaba ;17_A	et	f	\N
169007	religioonivabaduse	religioonivabaduse =vabaduse  (SgG  >religiooni+vabadus !11_S	et	f	\N
169008	religioonivabaduse	"religiooni+vabadus %vaba  )US_aS  <religiooni+vaba ;17_A	et	f	\N
169014	määramiseks	määramiseks =määramise  (SgTr  >määramine !12_S	et	f	\N
169015	määramiseks	"määramine %määra  )MINE_vS  <määrama ;29_V	et	f	\N
169045	nimetavast	nimetavast =nimetava  (SgEl  >nimetav !02_A	et	f	\N
169046	nimetavast	"nimetav %nimeta  )V_vA  <nimetama ;27_V	et	f	\N
169047	nimetavast	nimetavast =tava  (SgEl  >nime+tava !17_S	et	f	\N
169048	nimetavast	nimetavast =tavas  (SgP  >nime+tavane !10_A	et	f	\N
169049	nimetavast	"nime+tavane %tava  )NE_aA  <nime+tava ;17_S	et	f	\N
169050	järgis	järgis =järgi  (SgIn  >järk !22_S	et	f	\N
169051	järgis	järgis =järgi  (IndIpfSg3  >järgima !27_V	et	f	\N
169054	mõndavõrra	?mõndavõrra =mõndavõrra  (SgN  >mõndavõrra !16_S	et	f	\N
169055	mõndavõrra	?mõndavõrra =mõndavõrra  (SgG  >mõndavõrra !16_S	et	f	\N
169072	istvan	?istvan =istva  (IndPrSg1  >istvama !29_V	et	f	\N
169073	istvan	?istvan =istvan  (SgN  >istvan !02_S	et	f	\N
169077	rumeenialased	?rumeenialased =rumeenialase  (PlN  >rumeenialane !12_S	et	f	\N
169080	vaimulikuid	?vaimulikuid =vaimulikui  (PlN  >vaimulikui !26_S	et	f	\N
169081	vaimulikuid	?vaimulikuid =vaimulikui  (SgP  >vaimulikui !26_S	et	f	\N
169082	vaimulikuid	?vaimulikuid =uliku  (PlP  >vaim+uliku !01_S	et	f	\N
169083	vaimulikuid	?vaimulikuid =uliku  (PlP  >vaim+ulik !02_S	et	f	\N
169084	vaimulikuid	?vaimulikuid =ulikui  (PlN  >vaim+ulikui !26_S	et	f	\N
169085	vaimulikuid	?vaimulikuid =ulikui  (SgP  >vaim+ulikui !26_S	et	f	\N
169102	kiirsti	?kiirsti =kiirsti  (SgN  >kiirsti !01_S	et	f	\N
169103	kiirsti	?kiirsti =kiirsti  (SgG  >kiirsti !01_S	et	f	\N
169104	kiirsti	?kiirsti =kiirsti  (SgG  >kiirst !22_S	et	f	\N
169105	kiirsti	?kiirsti =kiirsti  (SgP  >kiirst !22_S	et	f	\N
169106	kiirsti	?kiirsti =kiirsti  (SgAdt  >kiirst !22_S	et	f	\N
169107	kiirsti	?kiirsti =kiirsti  (IndPrPs_  >kiirstima !28_V	et	f	\N
169108	kiirsti	?kiirsti =kiirsti  (ImpPrSg2  >kiirstima !28_V	et	f	\N
169109	trükkimise	trükkimise =trükkimise  (SgG  >trükkimine !12_S	et	f	\N
169110	trükkimise	"trükkimine %trükki  )MINE_vS  <trükkima ;28_V	et	f	\N
169113	luuletuse	luuletuse =luuletuse  (SgG  >luuletus !11_S	et	f	\N
169114	luuletuse	"luuletus %luuleta  )US_vS  <luuletama ;27_V	et	f	\N
169115	luuletuse	"luuletus %luule  )TUS2_aS  <luule ;06_S	et	f	\N
169123	reformatsion	?reformatsion =reformatsion  (SgN  >reformatsion !19~02_S	et	f	\N
169124	reformatsion	?reformatsion =atsion  (SgN  >reform+atsion !19~02_S	et	f	\N
169135	rietusid	?rietusid =rietu  (IndIpfSg2  >rietuma !27_V	et	f	\N
169136	rietusid	?rietusid =rietu  (IndIpfPl3  >rietuma !27_V	et	f	\N
169150	krakkovis	?krakkovis =krakkovi  (SgIn  >krakkov !02_A	et	f	\N
169151	krakkovis	?krakkovis =krakkovis  (SgN  >krakkovis !11_S	et	f	\N
169152	krackovis	?krackovis =krackovi  (SgIn  >krackov !02_A	et	f	\N
169153	krackovis	?krackovis =krackovis  (SgN  >krackovis !11_S	et	f	\N
169161	valikuid	valikuid =valiku  (PlP  >valik !02_S	et	f	\N
169162	valikuid	valikuid =ui  (PlN  >valik+ui !26_S	et	f	\N
169163	valikuid	valikuid =ui  (SgP  >valik+ui !26_S	et	f	\N
169164	valikuid	valikuid =uid  (SgN  >valik+uid !22_S	et	f	\N
169165	levitajatest	levitajatest =levitaja  (PlEl  >levitaja !01_S	et	f	\N
169166	levitajatest	"levitaja %levita  )JA_vS  <levitama ;27_V	et	f	\N
169172	vangistati	vangistati =vangista  (IndIpfIps  >vangistama !27_V	et	f	\N
169173	vangistati	vangistati =tati  (SgG  >vangis+tatt !22_S	et	f	\N
169192	bakalaurustöös	?bakalaurustöös =bakalaurustöö  (SgIn  >bakalaurustöö !26_S	et	f	\N
169193	bakalaurustöös	?bakalaurustöös =bakalaurustöös  (SgN  >bakalaurustöös !22_S	et	f	\N
169198	analüüsivateks	analüüsivateks =analüüsiva  (PlTr  >analüüsiv !02_A	et	f	\N
169199	analüüsivateks	"analüüsiv %analüüsi  )V_vA  <analüüsima ;28_V	et	f	\N
169200	analüüsivateks	analüüsivateks =vate  (PlTr  >analüüsi+vatt !22_S	et	f	\N
169208	praktiseerimise	praktiseerimise =praktiseerimise  (SgG  >praktiseerimine !12_S	et	f	\N
169209	praktiseerimise	"praktiseerimine %praktiseeri  )MINE_vS  <praktiseerima ;28_V	et	f	\N
169227	liigitamisega	liigitamisega =liigitamise  (SgKom  >liigitamine !12_S	et	f	\N
169228	liigitamisega	"liigitamine %liigita  )MINE_vS  <liigitama ;27_V	et	f	\N
169229	kolmekümneüheksa	?kolmekümneüheksa =kolmekümneüheksa  (SgN  >kolmekümneüheksa !16_S	et	f	\N
169230	kolmekümneüheksa	?kolmekümneüheksa =kolmekümneüheksa  (SgG  >kolmekümneüheksa !16_S	et	f	\N
169231	kolmekümneüheksa	?kolmekümneüheksa =kümneüheksa  (SgN  >kolme+kümneüheksa !16_S	et	f	\N
169232	kolmekümneüheksa	?kolmekümneüheksa =kümneüheksa  (SgG  >kolme+kümneüheksa !16_S	et	f	\N
169233	kolmekümneüheksa	?kolmekümneüheksa =ekümneüheksa  (SgN  >kolm+ekümneüheksa !16_S	et	f	\N
169234	kolmekümneüheksa	?kolmekümneüheksa =ekümneüheksa  (SgG  >kolm+ekümneüheksa !16_S	et	f	\N
169235	keelepraktika	keelepraktika =praktika  (SgN  >keele+praktika !01_S	et	f	\N
169186	ballassi	?ballassi =ballassi  (SgG  >ballassi !01_S	et	f	\N
169187	ballassi	?ballassi =ballassi  (SgG  >ballass !22_S	et	f	\N
169188	ballassi	?ballassi =ballassi  (SgP  >ballass !22_S	et	f	\N
169189	ballassi	?ballassi =ballassi  (SgAdt  >ballass !22_S	et	f	\N
169190	ballassi	?ballassi =ballassi  (IndPrPs_  >ballassima !28_V	et	f	\N
169191	ballassi	?ballassi =ballassi  (ImpPrSg2  >ballassima !28_V	et	f	\N
169204	lühikjandid	?lühikjandid =lühikjandi  (PlN  >lühikjant !22_S	et	f	\N
169205	lühikjandid	?lühikjandid =lühikjandi  (IndPrSg2  >lühikjantima !28_V	et	f	\N
169237	eestikeelsetesse	eestikeelsetesse =sete  (PlIll  >eesti+keel+sett !22_S	et	f	\N
169238	eestikeelsetesse	eestikeelsetesse =keelse  (PlIll  >eesti+keelne !02_A	et	f	\N
169255	tõlkesõna	tõlkesõna =sõna  (SgN  >tõlke+sõna !17_S	et	f	\N
169256	tõlkesõna	tõlkesõna =sõna  (SgG  >tõlke+sõna !17_S	et	f	\N
169257	tõlkesõna	tõlkesõna =sõna  (SgP  >tõlke+sõna !17_S	et	f	\N
169288	kontrastiiv	?kontrastiiv =kontrastiiv  (SgN  >kontrastiiv !22_S	et	f	\N
169289	kontrastiiv	?kontrastiiv =iiv  (SgN  >kontrast+iiv !22_S	et	f	\N
169290	kontrastiiv	?kontrastiiv =stiiv  (SgN  >kontra+stiiv !22_S	et	f	\N
169291	kontrastiiv	?kontrastiiv =rastiiv  (SgN  >kont+rastiiv !22_S	et	f	\N
169292	veaanalüüsis	?veaanalüüsis =veaanalüüsi  (SgIn  >veaanalüüsi !16_S	et	f	\N
169293	veaanalüüsis	?veaanalüüsis =veaanalüüsi  (SgIn  >veaanalüüs !22_S	et	f	\N
169294	veaanalüüsis	?veaanalüüsis =veaanalüüsi  (IndIpfSg3  >veaanalüüsima !28_V	et	f	\N
169295	veaanalüüsis	?veaanalüüsis =veaanalüüsis  (SgN  >veaanalüüsis !09_S	et	f	\N
169300	suulistest	suulistest =suulis  (PlEl  >suuline !12?10_AS	et	f	\N
169303	suulistest	"suuline %suu  )LINE_aA  <suu ;26_S	et	f	\N
169313	jalksi	?jalksi =jalksi  (ID  >jalksi !41_D	et	f	\N
169314	jalksi	?jalksi =jalksi  (SgG  >jalks !22_S	et	f	\N
169315	jalksi	?jalksi =jalksi  (SgP  >jalks !22_S	et	f	\N
169316	jalksi	?jalksi =jalksi  (SgAdt  >jalks !22_S	et	f	\N
169317	jalksi	?jalksi =jalksi  (IndPrPs_  >jalksima !28_V	et	f	\N
169318	jalksi	?jalksi =jalksi  (ImpPrSg2  >jalksima !28_V	et	f	\N
169323	aadresi	?aadresi =aadresi  (ID  >aadresi !41_D	et	f	\N
169324	aadresi	?aadresi =aadresi  (PlP  >aadrene !12_A	et	f	\N
169331	keskturgu	keskturgu =turgu  (SgP  >kesk+turg !22_S	et	f	\N
169332	keskturgu	keskturgu =turgu  (SgAdt  >kesk+turg !22_S	et	f	\N
169337	esita	esita =esita  (IndPrPs_  >esitama !27_V	et	f	\N
169338	esita	esita =esita  (ImpPrSg2  >esitama !27_V	et	f	\N
169352	hapum	hapum =hapum  (SgN  >hapum !02_A	et	f	\N
169353	hapum	"hapum %hapu  )M_cA  <hapu ;16_A	et	f	\N
169359	ilmnenud	ilmnenud =ilmne  (PtsPtPs  >ilmnema !27_V	et	f	\N
169360	ilmnenud	ilmnenud =ilmnenu  (PlN  >ilmnenu !01_S	et	f	\N
169361	ilmnenud	"ilmnenu %ilmne  )NU_vS  <ilmnema ;27_V	et	f	\N
169362	ilmnenud	ilmnenud =ilmnenud  (ID  >ilmnenud !41_A	et	f	\N
169363	ilmnenud	"ilmnenud %ilmne  )NUD_vA  <ilmnema ;27_V	et	f	\N
169402	ersasid	?ersasid =ersa  (PlP  >ersa !16_S	et	f	\N
169403	ersasid	?ersasid =ersa  (IndIpfSg2  >ersama !29_V	et	f	\N
169404	ersasid	?ersasid =ersa  (IndIpfPl3  >ersama !29_V	et	f	\N
169421	rahvasteks	rahvasteks =rahvas  (PlTr  >rahvas !07_S	et	f	\N
169422	rahvasteks	rahvasteks =rahvas  (PlTr  >rahvane !10_A	et	f	\N
169423	rahvasteks	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
169442	foderatsioonis	?foderatsioonis =foderatsiooni  (SgIn  >foderatsiooni !16_S	et	f	\N
169443	foderatsioonis	?foderatsioonis =foderatsiooni  (SgIn  >foderatsioon !22_S	et	f	\N
169444	foderatsioonis	?foderatsioonis =foderatsiooni  (IndIpfSg3  >foderatsioonima !28_V	et	f	\N
169445	foderatsioonis	?foderatsioonis =foderatsioonis  (SgN  >foderatsioonis !09_S	et	f	\N
169456	ardani	?ardani =arda  (SgTer  >arda !16_S	et	f	\N
169457	ardani	?ardani =ardani  (SgG  >ardan !02_S	et	f	\N
169461	rubruquis	?rubruquis =rubruqu  (PlIn  >rubruqu !01_S	et	f	\N
169462	rubruquis	?rubruquis =rubruqui  (SgIn  >rubruqui !26_S	et	f	\N
169463	rubruquis	?rubruquis =rubruquis  (SgN  >rubruquis !22_S	et	f	\N
169478	tunduvat	tunduvat =tundu  (KvtPrPs  >tunduma !27_V	et	f	\N
169479	tunduvat	tunduvat =tunduva  (SgP  >tunduv !02_A	et	f	\N
169480	tunduvat	"tunduv %tundu  )V_vA  <tunduma ;27_V	et	f	\N
169481	pkirillov	?pkirillov =pkirillov  (SgN  >pkirillov !02_A	et	f	\N
169485	naideks	?naideks =nai  (PlTr  >nai !26_S	et	f	\N
169486	naideks	?naideks =naide  (PlTr  >nait !22_S	et	f	\N
169487	naideks	?naideks =naide  (KndPrPs  >naidema !27_V	et	f	\N
169493	nuud	?nuud =nuu  (PlN  >nuu !26_S	et	f	\N
169494	nuud	?nuud =nuu  (SgP  >nuu !26_S	et	f	\N
169495	nuud	?nuud =nuud  (SgN  >nuud !22_S	et	f	\N
169518	jakb	?jakb =jakb  (SgN  >jakb !22_S	et	f	\N
169522	rahvuskongressi	rahvuskongressi =kongressi  (SgG  >rahvus+kongress !22_S	et	f	\N
169523	rahvuskongressi	rahvuskongressi =kongressi  (SgP  >rahvus+kongress !22_S	et	f	\N
169524	rahvuskongressi	rahvuskongressi =kongressi  (SgAdt  >rahvus+kongress !22_S	et	f	\N
169538	keeliks	keeliks =keeli  (PlTr  >keel !13_S	et	f	\N
169539	keeliks	keeliks =iks  (SgN  >keel+iks !22_S	et	f	\N
169547	saarased	?saarased =saarase  (PlN  >saarane !10_A	et	f	\N
169548	motted	?motted =motte  (PlN  >mote !06_S	et	f	\N
169549	motted	?motted =motte  (IndPrSg2  >mottema !27_V	et	f	\N
169236	keelepraktika	keelepraktika =praktika  (SgG  >keele+praktika !01_S	et	f	\N
169245	vaheldumist	vaheldumist =vaheldumis  (SgP  >vaheldumine !12_S	et	f	\N
169246	vaheldumist	"vaheldumine %vaheldu  )MINE_vS  <vahelduma ;27_V	et	f	\N
169258	mäletamisest	mäletamisest =mäletamise  (SgEl  >mäletamine !12_S	et	f	\N
169259	mäletamisest	"mäletamine %mäleta  )MINE_vS  <mäletama ;27_V	et	f	\N
169273	jüriöö	jüriöö =öö  (SgN  >jüri+öö !26_S	et	f	\N
169274	jüriöö	jüriöö =öö  (SgG  >jüri+öö !26_S	et	f	\N
169279	kvantorsõna	### kvantorsõna	et	f	\N
169301	vastustest	vastustest =vastus  (PlEl  >vastus !09_S	et	f	\N
169302	vastustest	vastustest =test  (SgN  >vastus+test !22_S	et	f	\N
169304	vastustest	vastustest =us  (PlEl  >vast+uks !14_S	et	f	\N
169319	loomuliikult	?loomuliikult =loomuliikult  (ID  >loomuliikult !41_D	et	f	\N
169320	loomuliikult	?loomuliikult =liiku  (SgAbl  >loomu+liiku !16_S	et	f	\N
169321	loomuliikult	?loomuliikult =uliiku  (SgAbl  >loom+uliiku !01_S	et	f	\N
169322	loomuliikult	?loomuliikult =muliiku  (SgAbl  >loo+muliiku !01_S	et	f	\N
169330	treppikodaga	### treppikodaga	et	f	\N
169350	i-ülivõr	?i-ülivõr =ülivõr  (SgN  >i-ülivõr !19_S	et	f	\N
169364	arvestust	arvestust =arvestus  (SgP  >arvestus !11_S	et	f	\N
169365	arvestust	"arvestus %arvesta  )US_vS  <arvestama ;27_V	et	f	\N
169380	utlevad	?utlevad =utle  (IndPrPl3  >utlema !30_V	et	f	\N
169381	utlevad	?utlevad =utleva  (PlN  >utleva !01_S	et	f	\N
169382	utlevad	?utlevad =utleva  (PlN  >utlev !02_A	et	f	\N
169395	pooletuhande	?pooletuhande =pooletuhande  (PlP  >pooletuhand !22_S	et	f	\N
169396	pooletuhande	?pooletuhande =etuhande  (PlP  >pool+etuhand !22_S	et	f	\N
169397	kuunib	?kuunib =kuuni  (IndPrSg3  >kuunima !28_V	et	f	\N
169412	lahknesid	lahknesid =lahkne  (IndIpfSg2  >lahknema !27_V	et	f	\N
169413	lahknesid	lahknesid =lahkne  (IndIpfPl3  >lahknema !27_V	et	f	\N
169427	butsantsi	?butsantsi =butsantsi  (SgN  >butsantsi !01_S	et	f	\N
169428	butsantsi	?butsantsi =butsantsi  (SgG  >butsantsi !01_S	et	f	\N
169429	butsantsi	?butsantsi =butsantsi  (SgG  >butsants !22_S	et	f	\N
169431	butsantsi	?butsantsi =butsantsi  (SgP  >butsants !22_S	et	f	\N
169432	butsantsi	?butsantsi =butsantsi  (SgAdt  >butsants !22_S	et	f	\N
169433	butsantsi	?butsantsi =butsantsi  (IndPrPs_  >butsantsima !28_V	et	f	\N
169434	butsantsi	?butsantsi =butsantsi  (ImpPrSg2  >butsantsima !28_V	et	f	\N
169452	segeli	?segeli =segeli  (ID  >segeli !41_D	et	f	\N
169453	segeli	?segeli =segeli  (SgG  >segel !02_S	et	f	\N
169469	kal	### kal	et	f	\N
169515	kudusid	kudusid =kudu  (PlP  >kudu !17_S	et	f	\N
169516	kudusid	kudusid =kudu  (IndIpfSg2  >kuduma !28_V	et	f	\N
169517	kudusid	kudusid =kudu  (IndIpfPl3  >kuduma !28_V	et	f	\N
169519	reaktsionaar	?reaktsionaar =reaktsionaar  (SgN  >reaktsionaar !22_S	et	f	\N
169540	ennestusele	?ennestusele =ennestuse  (SgAll  >ennestus !11_S	et	f	\N
169541	ennestusele	?ennestusele =stuse  (SgAll  >enne+stuse !16_S	et	f	\N
169550	1992a	### 1992a	et	f	\N
169553	streigi	streigi =streigi  (SgG  >streik !22_S	et	f	\N
169554	streigi	streigi =streigi  (IndPrPs_  >streikima !28_V	et	f	\N
169555	streigi	streigi =streigi  (ImpPrSg2  >streikima !28_V	et	f	\N
169569	moordva	?moordva =moordva  (SgN  >moordva !01_S	et	f	\N
169571	moordva	?moordva =moordva  (SgG  >moordva !01_S	et	f	\N
169573	moordva	?moordva =moordva  (SgG  >moordev !02_A	et	f	\N
169575	moordva	?moordva =moordva  (IndPrPs_  >moordvama !29_V	et	f	\N
169576	moordva	?moordva =moordva  (ImpPrSg2  >moordvama !29_V	et	f	\N
169582	prozes	?prozes =proze  (SgIn  >proze !16_S	et	f	\N
169585	prozes	?prozes =prozes  (SgN  >prozes !09_S	et	f	\N
169590	markas	?markas =marka  (SgIn  >marka !16_S	et	f	\N
169591	markas	?markas =marka  (IndIpfSg3  >markama !29_V	et	f	\N
169592	markas	?markas =markas  (SgN  >markas !07_S	et	f	\N
169593	kulastaja	?kulastaja =kulastaja  (SgN  >kulastaja !01_S	et	f	\N
169594	kulastaja	?kulastaja =kulastaja  (SgG  >kulastaja !01_S	et	f	\N
169595	kulastaja	?kulastaja =kulastaja  (SgG  >kulastajas !02_A	et	f	\N
169596	1995a	### 1995a	et	f	\N
169611	moksaersakeelne	?moksaersakeelne =moksaersakeelne  (SgN  >moksaersakeelne !02_A	et	f	\N
169612	moksaersakeelne	?moksaersakeelne =moksaersakeelne  (PlP  >moksaersakeeln !22_S	et	f	\N
169618	uritused	?uritused =urituse  (PlN  >uritus !11_S	et	f	\N
169643	diasporaa	?diasporaa =diasporaa  (SgN  >diasporaa !26_S	et	f	\N
169644	diasporaa	?diasporaa =diasporaa  (SgG  >diasporaa !26_S	et	f	\N
169661	1994a	### 1994a	et	f	\N
169665	vottis	?vottis =votti  (IndIpfSg3  >vottima !28_V	et	f	\N
169666	vottis	?vottis =vottis  (ID  >vottis !41_DA	et	f	\N
169676	jargnes	?jargnes =jargne  (PlIn  >jargn !22_S	et	f	\N
169677	jargnes	?jargnes =jargne  (IndIpfSg3  >jargnema !27_V	et	f	\N
169678	jargnes	?jargnes =jargnes  (SgN  >jargnes !09_S	et	f	\N
169681	polisrahva	?polisrahva =polisrahva  (SgN  >polisrahva !16_S	et	f	\N
169682	polisrahva	?polisrahva =polisrahva  (SgG  >polisrahva !16_S	et	f	\N
169684	koigist	?koigist =koigi  (SgEl  >koigi !16_S	et	f	\N
169685	koigist	?koigist =koigi  (SgEl  >koik !22_S	et	f	\N
169686	koigist	?koigist =koigis  (SgP  >koigis !09_S	et	f	\N
169249	grammatuikale	?grammatuikale =grammatuika  (SgAll  >grammatuikas !02_A	et	f	\N
169250	grammatuikale	?grammatuikale =grammatuika  (SgAll  >grammatuika !16_S	et	f	\N
169251	vanavanematest	vanavanematest =test  (SgN  >vana+vanema+test !22_S	et	f	\N
169252	vanavanematest	vanavanematest =ate  (PlEl  >vana+vanem+att !22_S	et	f	\N
169253	vanavanematest	vanavanematest =vanema  (PlEl  >vana+vanem !02_AS	et	f	\N
169254	vanavanematest	"vana+vanem %vane  )M_cA  <vana+vana ;17_AS	et	f	\N
169260	ahaava	?ahaava =ahaava  (SgN  >ahaava !16_S	et	f	\N
169261	ahaava	?ahaava =ahaava  (SgG  >ahaava !16_S	et	f	\N
169280	elusid	elusid =elu  (PlP  >elu !17_S	et	f	\N
169281	elusid	elusid =elusi  (PlN  >elus !02_A	et	f	\N
169296	koolipraktikast	koolipraktikast =praktika  (SgEl  >kooli+praktika !01_S	et	f	\N
169297	koolipraktikast	koolipraktikast =praktikas  (SgP  >kooli+praktikane !12_A	et	f	\N
169298	koolipraktikast	"kooli+praktikane %praktika  )NE_aA  <kooli+praktika ;01_S	et	f	\N
169308	süja	?süja =süja  (SgN  >süja !17_S	et	f	\N
169309	süja	?süja =süja  (SgG  >süja !17_S	et	f	\N
169310	süja	?süja =süja  (SgP  >süja !17_S	et	f	\N
169311	süja	?süja =süja  (IndPrPs_  >süjama !27_V	et	f	\N
169312	süja	?süja =süja  (ImpPrSg2  >süjama !27_V	et	f	\N
169325	vedanud	vedanud =veda  (PtsPtPs  >vedama !28_V	et	f	\N
169326	vedanud	vedanud =vedanu  (PlN  >vedanu !01_S	et	f	\N
169327	vedanud	"vedanu %veda  )NU_vS  <vedama ;28_V	et	f	\N
169328	vedanud	vedanud =vedanud  (ID  >vedanud !41_A	et	f	\N
169329	vedanud	"vedanud %veda  )NUD_vA  <vedama ;28_V	et	f	\N
169341	viisteiskümnes	?viisteiskümnes =viisteiskümne  (PlIn  >viisteiskümn !22_S	et	f	\N
169342	viisteiskümnes	?viisteiskümnes =kümne  (PlIn  >viis+teis+kümn !22_S	et	f	\N
169343	viisteiskümnes	?viisteiskümnes =teiskümne  (PlIn  >viis+teiskümn !22_S	et	f	\N
169349	soojam	?soojam =soojam  (SgN  >soojam !02_A	et	f	\N
169418	votnud	?votnud =votnu  (PlN  >votnu !01_S	et	f	\N
169419	votnud	?votnud =votnu  (IndPrSg2  >votnuma !27_V	et	f	\N
169420	votnud	?votnud =votnud  (ID  >votnud !41_A	et	f	\N
169430	konstantinos	?konstantinos =konstantino  (SgIn  >konstantino !16_S	et	f	\N
169435	porphyrogennetor	?porphyrogennetor =porphyrogennetor  (SgN  >porphyrogennetor !02_S	et	f	\N
169464	moxel	?moxel =moxe  (SgAd  >moxe !06_S	et	f	\N
169465	moxel	?moxel =moxel  (SgN  >moxel !02_S	et	f	\N
169475	tolketeosed	### tolketeosed	et	f	\N
169491	tolked	?tolked =tolke  (PlN  >tolge !06_S	et	f	\N
169492	tolked	?tolked =tolke  (IndPrSg2  >tolkema !27_V	et	f	\N
169503	kasitsi	kasitsi =itsi  (SgG  >kas+its !22_S	et	f	\N
169504	kasitsi	kasitsi =itsi  (SgP  >kas+its !22_S	et	f	\N
169505	kasitsi	kasitsi =itsi  (SgAdt  >kas+its !22_S	et	f	\N
169506	kulvati	?kulvati =kulva  (IndIpfIps  >kulvama !29_V	et	f	\N
169507	kulvati	?kulvati =kulvati  (ID  >kulvati !41_D	et	f	\N
169508	kulvati	?kulvati =kulvati  (SgG  >kulvat !02_S	et	f	\N
169509	kulvati	?kulvati =kulvati  (SgG  >kulvatt !22_S	et	f	\N
169510	kulvati	?kulvati =kulvati  (IndPrPs_  >kulvattima !28_V	et	f	\N
169511	kulvati	?kulvati =kulvati  (ImpPrSg2  >kulvattima !28_V	et	f	\N
169525	rahaliselt	rahaliselt =rahalise  (SgAbl  >rahaline !12_A	et	f	\N
169526	rahaliselt	"rahaline %raha  )LINE_aA  <raha ;17_S	et	f	\N
169527	rahaliselt	"rahaline %raha  )LINE_aA  <rahk ;22_S	et	f	\N
169528	rahaliselt	rahaliselt =rahaliselt  (ID  >rahaliselt !41_D	et	f	\N
169529	rahaliselt	"rahaliselt %raha  )LISELT_mD  <raha ;17_S	et	f	\N
169530	rahaliselt	"rahaliselt %raha  )LISELT_mD  <rahk ;22_S	et	f	\N
169531	rahaliselt	"rahaliselt %rahalise  )LT_mD  <rahaline ;12_A	et	f	\N
169534	koigi	koigi =koi  (SgN^  >koi !26_S	et	f	\N
169535	koigi	koigi =koi  (SgG^  >koi !26_S	et	f	\N
169563	poliskultuurile	?poliskultuurile =poliskultuuri  (SgAll  >poliskultuuri !16_S	et	f	\N
169566	poliskultuurile	?poliskultuurile =poliskultuuri  (SgAll  >poliskultuur !22_S	et	f	\N
169580	nadalas	?nadalas =nadala  (SgIn  >nadala !01_S	et	f	\N
169587	saranskis	?saranskis =saranski  (SgIn  >saransk !02_S	et	f	\N
169588	saranskis	?saranskis =saranski  (IndIpfSg3  >saranskima !28_V	et	f	\N
169589	saranskis	?saranskis =saranskis  (SgN  >saranskis !11_S	et	f	\N
169599	silti	silti =silti  (SgP  >silt !22_S	et	f	\N
169600	silti	silti =silti  (SgAdt  >silt !22_S	et	f	\N
169605	ersakeelset	?ersakeelset =ersakeelse  (SgP  >ersakeelne !02_A	et	f	\N
169606	opet	?opet =ope  (SgP  >ope !06_S	et	f	\N
169613	ope	?ope =ope  (SgN  >ope !06_S	et	f	\N
169614	ope	?ope =ope  (IndPrPs_  >opema !27_V	et	f	\N
169615	ope	?ope =ope  (ImpPrSg2  >opema !27_V	et	f	\N
169635	noudis	?noudis =noudi  (SgIn  >noudi !16_S	et	f	\N
169636	noudis	?noudis =noudi  (SgIn  >nout !22_S	et	f	\N
169637	noudis	?noudis =noudi  (IndIpfSg3  >noudima !28_V	et	f	\N
169638	noudis	?noudis =noudis  (SgN  >noudis !09_S	et	f	\N
169646	vormiliselt	vormiliselt =vormilise  (SgAbl  >vormiline !12_A	et	f	\N
169647	vormiliselt	"vormiline %vormi  )LINE_aA  <vorm ;22_S	et	f	\N
169649	vormiliselt	vormiliselt =vormiliselt  (ID  >vormiliselt !41_D	et	f	\N
169651	vormiliselt	"vormiliselt %vormi  )LISELT_mD  <vorm ;22_S	et	f	\N
169652	vormiliselt	"vormiliselt %vormilise  )LT_mD  <vormiline ;12_A	et	f	\N
169345	põõrama	?põõrama =põõrama  (SgG  >põõram !02_A	et	f	\N
169357	õmbleda	### õmbleda	et	f	\N
169366	eelneval	eelneval =eelneva  (SgAd  >eelnev !02_A	et	f	\N
169367	eelneval	"eelnev %eelne  )V_vA  <eelnema ;27_V	et	f	\N
169371	eessona	?eessona =eesso  (SgEs  >eesso !16_S	et	f	\N
169372	eessona	?eessona =sona  (SgN  >ees+sona !17_S	et	f	\N
169373	eessona	?eessona =sona  (SgG  >ees+sona !17_S	et	f	\N
169374	eessona	?eessona =sona  (SgP  >ees+sona !17_S	et	f	\N
169376	moksa	?moksa =moksa  (SgN  >moksa !16_S	et	f	\N
169377	moksa	?moksa =moksa  (SgG  >moksa !16_S	et	f	\N
169378	moksa	?moksa =moksa  (IndPrPs_  >moksama !29_V	et	f	\N
169379	moksa	?moksa =moksa  (ImpPrSg2  >moksama !29_V	et	f	\N
169383	uhe	uhe =uhe  (SgN  >uhe !05_S	et	f	\N
169384	uhe	uhe =uhe  (SgN  >uhe !06_S	et	f	\N
169385	laanepoolseim	laanepoolseim =seim  (SgN  >laane+pool+seim !22_S	et	f	\N
169386	laanepoolseim	laanepoolseim =poolseim  (SgN  >laane+poolseim !02_A	et	f	\N
169387	laanepoolseim	"laane+poolseim %poolse  )IM_sA  <laane+poolne ;02_A	et	f	\N
169388	volgasoome	?volgasoome =volgasoome  (SgN  >volgasoome !16_S	et	f	\N
169389	volgasoome	?volgasoome =volgasoome  (SgG  >volgasoome !16_S	et	f	\N
169390	volgasoome	?volgasoome =volgasoome  (PlP  >volgasoom !22_S	et	f	\N
169391	volgasoome	?volgasoome =soome  (PlP  >volga+soom !22_S	et	f	\N
169392	sailitada	?sailitada =sailita  (Inf  >sailitama !27_V	et	f	\N
169393	omanaolise	omanaolise =naolise  (SgG  >oma+naoline !12?10_A	et	f	\N
169394	omanaolise	"oma+naoline %nao  )LINE_aA  <oma+nadu ;18_S	et	f	\N
169398	ale	ale =ale  (SgN  >ale !16_S	et	f	\N
169399	ale	ale =ale  (SgG  >ale !16_S	et	f	\N
169400	mordvamaal	?mordvamaal =mordvamaa  (SgAd  >mordvamaa !26_S	et	f	\N
169401	mordvamaal	?mordvamaal =mordvamaal  (SgN  >mordvamaal !22_S	et	f	\N
169424	jordanis	?jordanis =jordani  (SgIn  >jordan !02_S	et	f	\N
169425	jordanis	?jordanis =jordanis  (SgN  >jordanis !11_S	et	f	\N
169436	mordia	?mordia =mordia  (SgN  >mordia !01_S	et	f	\N
169437	mordia	?mordia =mordia  (SgG  >mordia !01_S	et	f	\N
169438	kroonikais	kroonikais =kroonika  (PlIn  >kroonika !01_S	et	f	\N
169439	kroonikais	kroonikais =kai  (SgIn  >krooni+kai !26_S	et	f	\N
169440	uhed	?uhed =uhe  (IndPrSg2  >uhema !27_V	et	f	\N
169448	etnonuumi	etnonuumi =nuumi  (SgG  >etno+nuum !22_S	et	f	\N
169449	etnonuumi	etnonuumi =nuumi  (SgP  >etno+nuum !22_S	et	f	\N
169450	etnonuumi	etnonuumi =nuumi  (SgAdt  >etno+nuum !22_S	et	f	\N
169451	etnonuumi	etnonuumi =nuumi  (PlP  >etno+nuum !22_S	et	f	\N
169454	allikais	allikais =allika  (PlIn  >allikas !02_S	et	f	\N
169455	allikais	allikais =ais  (SgN  >allik+ais !23?22_S	et	f	\N
169458	arsaija	?arsaija =arsaija  (SgN  >arsaija !01_S	et	f	\N
169459	arsaija	?arsaija =arsaija  (SgG  >arsaija !01_S	et	f	\N
169460	arsaija	?arsaija =arsaija  (SgG  >arsaijas !02_A	et	f	\N
169470	malestised	?malestised =malestise  (PlN  >malestis !11_S	et	f	\N
169471	malestised	?malestised =stise  (PlN  >male+stise !16_S	et	f	\N
169483	tkirdjashkin	?tkirdjashkin =tkirdjashki  (IndPrSg1  >tkirdjashkima !28_V	et	f	\N
169484	tkirdjashkin	?tkirdjashkin =tkirdjashkin  (SgN  >tkirdjashkin !02_S	et	f	\N
169496	tekti	?tekti =tekti  (SgN  >tekti !16_S	et	f	\N
169497	tekti	?tekti =tekti  (SgG  >tekti !16_S	et	f	\N
169498	tekti	?tekti =tekti  (SgG  >tekt !22_S	et	f	\N
169499	tekti	?tekti =tekti  (SgP  >tekt !22_S	et	f	\N
169500	tekti	?tekti =tekti  (SgAdt  >tekt !22_S	et	f	\N
169501	tekti	?tekti =tekti  (IndPrPs_  >tektima !28_V	et	f	\N
169502	tekti	?tekti =tekti  (ImpPrSg2  >tektima !28_V	et	f	\N
169512	ketrasid	ketrasid =ketra  (PlP  >keder !24_S	et	f	\N
169513	ketrasid	ketrasid =ketra  (IndIpfSg2  >ketrama !29_V	et	f	\N
169514	ketrasid	ketrasid =ketra  (IndIpfPl3  >ketrama !29_V	et	f	\N
169532	oigustades	?oigustades =oigusta  (Ger  >oigustama !27_V	et	f	\N
169536	surevaiks	surevaiks =sureva  (PlTr  >surev !02_A	et	f	\N
169537	surevaiks	"surev %sure  )V_vA  <surema ;36_V	et	f	\N
169556	salo	?salo =salo  (SgN  >salo !17~16_S	et	f	\N
169557	salo	?salo =salo  (SgG  >salo !17~16_S	et	f	\N
169558	salo	?salo =salo  (SgP  >salo !17_S	et	f	\N
169559	moningaid	?moningaid =moninga  (PlP  >moninga !01_S	et	f	\N
169561	moningaid	?moningaid =moninga  (PlP  >moningas !02_S	et	f	\N
169562	moningaid	?moningaid =moningai  (PlN  >moningai !26_S	et	f	\N
169565	moningaid	?moningaid =moningai  (SgP  >moningai !26_S	et	f	\N
169584	1995c	### 1995c	et	f	\N
169598	leiv	?leiv =leiv  (SgN  >leiv !22_S	et	f	\N
169607	fenno-ugria	?fenno-ugria =ugria  (SgN  >fenno-ugria !01_S	et	f	\N
169608	fenno-ugria	?fenno-ugria =ugria  (SgG  >fenno-ugria !01_S	et	f	\N
169610	taielik	?taielik =taielik  (SgN  >taielik !25_A	et	f	\N
169616	kultuurialased	kultuurialased =alase  (PlN  >kultuuri+alane !10_AS	et	f	\N
169617	kultuurialased	"kultuuri+alane %ala  )NE_aA  <kultuuri+ala ;17_S	et	f	\N
169628	arvukamalt	arvukamalt =arvukama  (SgAbl  >arvukam !02_A	et	f	\N
169629	arvukamalt	"arvukam %arvuka  )M_cA  <arvukas ;02_A	et	f	\N
169630	arvukamalt	arvukamalt =arvukamalt  (ID  >arvukamalt !41_D	et	f	\N
169631	arvukamalt	"arvukamalt %arvuka  )MALT_mD  <arvukas ;02_A	et	f	\N
169441	ersalasi	?ersalasi =ersalasi  (PlP  >ersalane !12_S	et	f	\N
169446	mordovias	?mordovias =mordovia  (SgIn  >mordovia !01_S	et	f	\N
169447	mordovias	?mordovias =mordovias  (SgN  >mordovias !11_S	et	f	\N
169466	erzan	?erzan =erzan  (SgN  >erzan !02_S	et	f	\N
169467	moksan	?moksan =moksa  (IndPrSg1  >moksama !29_V	et	f	\N
169468	moksan	?moksan =moksan  (SgN  >moksan !02_S	et	f	\N
169472	parinevad	?parinevad =parine  (IndPrPl3  >parinema !27_V	et	f	\N
169473	parinevad	?parinevad =parineva  (PlN  >parinev !02_A	et	f	\N
169474	parinevad	?parinevad =parineva  (PlN  >parineva !16_S	et	f	\N
169476	kujunemisele	kujunemisele =kujunemise  (SgAll  >kujunemine !12_S	et	f	\N
169477	kujunemisele	"kujunemine %kujune  )MINE_vS  <kujunema ;27_V	et	f	\N
169482	mbezborodov	?mbezborodov =mbezborodov  (SgN  >mbezborodov !02_A	et	f	\N
169488	jargmise	?jargmise =jargmise  (SgG  >jargmine !12?10_A	et	f	\N
169489	jargmise	?jargmise =jargmise  (IndPrPs_  >jargmisema !27_V	et	f	\N
169490	jargmise	?jargmise =jargmise  (ImpPrSg2  >jargmisema !27_V	et	f	\N
169520	moksaersa	?moksaersa =moksaersa  (SgN  >moksaersa !01_S	et	f	\N
169521	moksaersa	?moksaersa =moksaersa  (SgG  >moksaersa !01_S	et	f	\N
169533	vaitega	?vaitega =vaite  (SgKom  >vaide !06_S	et	f	\N
169542	kaasagi	kaasagi =kaasa  (ID^  >kaasa !41_D	et	f	\N
169543	kaasagi	kaasagi =kaasa  (SgN^  >kaasa !16_S	et	f	\N
169544	kaasagi	kaasagi =kaasa  (SgG^  >kaasa !16_S	et	f	\N
169545	kaasagi	kaasagi =kaasa  (IndPrPs_^  >kaasama !29_V	et	f	\N
169546	kaasagi	kaasagi =kaasa  (ImpPrSg2^  >kaasama !29_V	et	f	\N
169551	nadalapikkuse	?nadalapikkuse =nadalapikkuse  (SgG  >nadalapikkus !11~09_S	et	f	\N
169567	piiritletud	piiritletud =piiritle  (PtsPtIps  >piiritlema !27_V	et	f	\N
169568	piiritletud	piiritletud =piiritletu  (PlN  >piiritletu !01_S	et	f	\N
169570	piiritletud	"piiritletu %piiritle  )TU1_vS  <piiritlema ;27_V	et	f	\N
169572	piiritletud	piiritletud =piiritletud  (ID  >piiritletud !41_A	et	f	\N
169574	piiritletud	"piiritletud %piiritle  )TUD_vA  <piiritlema ;27_V	et	f	\N
169581	paevas	?paevas =paeva  (SgIn  >paeva !16_S	et	f	\N
169583	paevas	?paevas =paeva  (IndIpfSg3  >paevama !29_V	et	f	\N
169586	paevas	?paevas =paevas  (SgN  >paevas !07_S	et	f	\N
169619	keeleharu	keeleharu =haru  (SgN  >keele+haru !17_S	et	f	\N
169620	keeleharu	keeleharu =haru  (SgG  >keele+haru !17_S	et	f	\N
169621	keeleharu	keeleharu =haru  (SgP  >keele+haru !17_S	et	f	\N
169622	voiksid	?voiksid =voiksi  (PlN  >voiks !22_S	et	f	\N
169623	voiksid	?voiksid =voiksi  (IndPrSg2  >voiksima !28_V	et	f	\N
169640	kultuurivajaduste	kultuurivajaduste =duste  (PlP  >kultuuri+vaja+dust !22_S	et	f	\N
169642	kultuurivajaduste	kultuurivajaduste =vajadus  (PlG  >kultuuri+vajadus !11_S	et	f	\N
169645	ersalik	?ersalik =ersalik  (SgN  >ersalik !25_A	et	f	\N
169648	ilid	?ilid =ili  (PlN  >ili !17_S	et	f	\N
169650	ilid	?ilid =ili  (IndPrSg2  >ilima !27_V	et	f	\N
169659	301iiget	?iiget =iige  (SgP  >iige !06_S	et	f	\N
169694	pohiseadusist	?pohiseadusist =pohiseadusi  (PlEl  >pohiseadus !11_S	et	f	\N
169695	pohiseadusist	?pohiseadusist =pohiseadusis  (SgP  >pohiseadusis !09_S	et	f	\N
169696	pohiseadusist	?pohiseadusist =pohiseadusist  (SgN  >pohiseadusist !22_S	et	f	\N
169698	jareldusi	?jareldusi =jareldusi  (PlP  >jareldus !11_S	et	f	\N
169714	pohja	?pohja =pohja  (SgN  >pohja !16_S	et	f	\N
169715	pohja	?pohja =pohja  (SgG  >pohjas !02_A	et	f	\N
169716	pohja	?pohja =pohja  (SgG  >pohja !16_S	et	f	\N
169717	pohja	?pohja =pohja  (IndPrPs_  >pohjama !29_V	et	f	\N
169718	pohja	?pohja =pohja  (ImpPrSg2  >pohjama !29_V	et	f	\N
169720	wwerzia	?wwerzia =wwerzia  (SgN  >wwerzia !01_S	et	f	\N
169721	wwerzia	?wwerzia =wwerzia  (SgG  >wwerzia !01_S	et	f	\N
169723	ttpwww	### ttpwww	et	f	\N
169728	skal	### skal	et	f	\N
169741	voitlus	?voitlus =voitlu  (SgIn  >voitlu !01_S	et	f	\N
169743	voitlus	?voitlus =voitlu  (IndIpfSg3  >voitluma !27_V	et	f	\N
169745	voitlus	?voitlus =voitlus  (SgN  >voitlus !11~09_S	et	f	\N
169746	paastmise	?paastmise =paastmise  (SgG  >paastmine !12?10_S	et	f	\N
169747	paastmise	?paastmise =paastmise  (IndPrPs_  >paastmisema !27_V	et	f	\N
169748	paastmise	?paastmise =paastmise  (ImpPrSg2  >paastmisema !27_V	et	f	\N
169749	mastor	?mastor =mastor  (SgN  >mastor !02_S	et	f	\N
169752	juhtkonnale	juhtkonnale =juhtkonna  (SgAll  >juhtkond !22_S	et	f	\N
169753	juhtkonnale	juhtkonnale =konna  (SgAll  >juht+konn !22_S	et	f	\N
169784	mitmedki	mitmedki =mitme  (PlN^  >mitu !05_P	et	f	\N
169785	mitmedki	"mitu %mi  )TU2_kA^  <mi ;26_S	et	f	\N
169796	kultuurikeeliks	kultuurikeeliks =iks  (SgN  >kultuuri+keel+iks !22_S	et	f	\N
169797	kultuurikeeliks	kultuurikeeliks =keeli  (PlTr  >kultuuri+keel !13_S	et	f	\N
169800	hoimurahvast	?hoimurahvast =hoimurahva  (SgEl  >hoimurahva !16_S	et	f	\N
169801	hoimurahvast	?hoimurahvast =hoimurahvas  (SgP  >hoimurahvane !12_A	et	f	\N
169804	mastorava	?mastorava =mastorava  (SgN  >mastorava !16_S	et	f	\N
169805	mastorava	?mastorava =mastorava  (SgG  >mastorav !02_A	et	f	\N
169806	mastorava	?mastorava =mastorava  (SgG  >mastorava !16_S	et	f	\N
169819	lahutamatuteks	lahutamatuteks =lahutamatu  (PlTr  >lahutamatu !01_A	et	f	\N
169820	lahutamatuteks	"lahutamatu %lahuta  )MATU_vA  <lahutama ;27_V	et	f	\N
169552	uliopilaste	?uliopilaste =uliopilas  (PlG  >uliopilane !12_S	et	f	\N
169560	jarelandmisi	?jarelandmisi =jarelandmisi  (ID  >jarelandmisi !41_D	et	f	\N
169564	jarelandmisi	?jarelandmisi =jarelandmisi  (PlP  >jarelandmine !12_A	et	f	\N
169577	1990a	### 1990a	et	f	\N
169578	moksersa	?moksersa =moksersa  (SgN  >moksersa !01_S	et	f	\N
169579	moksersa	?moksersa =moksersa  (SgG  >moksersa !01_S	et	f	\N
169597	poliskeelset	?poliskeelset =poliskeelse  (SgP  >poliskeelne !02_A	et	f	\N
169601	matuseburoo	?matuseburoo =matuseburoo  (SgN  >matuseburoo !26_S	et	f	\N
169602	matuseburoo	?matuseburoo =matuseburoo  (SgG  >matuseburoo !26_S	et	f	\N
169603	matuseburoo	?matuseburoo =buroo  (SgN  >matuse+buroo !26_S	et	f	\N
169604	matuseburoo	?matuseburoo =buroo  (SgG  >matuse+buroo !26_S	et	f	\N
169609	nr3	### nr3	et	f	\N
169624	nouda	?nouda =nouda  (SgN  >nouda !16_S	et	f	\N
169625	nouda	?nouda =nouda  (SgG  >nouda !16_S	et	f	\N
169626	nouda	?nouda =nouda  (IndPrPs_  >noudama !29_V	et	f	\N
169627	nouda	?nouda =nouda  (ImpPrSg2  >noudama !29_V	et	f	\N
169633	erslasi	?erslasi =erslasi  (ID  >erslasi !41_D	et	f	\N
169634	erslasi	?erslasi =erslasi  (PlP  >erslane !12_S	et	f	\N
169653	mokserslased	?mokserslased =mokserslase  (PlN  >mokserslane !12_S	et	f	\N
169656	ulegi	?ulegi =ule  (SgN^  >ule !16_S	et	f	\N
169657	ulegi	?ulegi =ule  (SgG^  >ule !16_S	et	f	\N
169658	ulegi	?ulegi =ule  (IndPrPs_^  >ulema !27_V	et	f	\N
169660	ulegi	?ulegi =ule  (ImpPrSg2^  >ulema !27_V	et	f	\N
169662	denatsionaliseeritudmordviinidest	?denatsionaliseeritudmordviinidest =denatsionaliseeritudmordviini  (PlEl  >denatsionaliseeritudmordviini !16_S	et	f	\N
169663	denatsionaliseeritudmordviinidest	?denatsionaliseeritudmordviinidest =denatsionaliseeritudmordviini  (PlEl  >denatsionaliseeritudmordviin !22_S	et	f	\N
169664	denatsionaliseeritudmordviinidest	?denatsionaliseeritudmordviinidest =denatsionaliseeritudmordviinides  (SgP  >denatsionaliseeritudmordviinidene !12_A	et	f	\N
169669	humni	?humni =humni  (SgN  >humni !16_S	et	f	\N
169670	humni	?humni =humni  (SgG  >humni !16_S	et	f	\N
169671	humni	?humni =humni  (SgG  >humn !22_S	et	f	\N
169672	humni	?humni =humni  (SgP  >humn !22_S	et	f	\N
169673	humni	?humni =humni  (SgAdt  >humn !22_S	et	f	\N
169674	humni	?humni =humni  (IndPrPs_  >humnima !28_V	et	f	\N
169675	humni	?humni =humni  (ImpPrSg2  >humnima !28_V	et	f	\N
169683	oiguste	?oiguste =oigus  (PlG  >oigus !11~09_S	et	f	\N
169689	vabariige	?vabariige =vabariige  (SgN  >vabariige !16_S	et	f	\N
169690	vabariige	?vabariige =vabariige  (SgG  >vabariige !16_S	et	f	\N
169691	vabariige	?vabariige =vabariige  (PlP  >vabariig !22_S	et	f	\N
169692	vabariige	?vabariige =riige  (SgN  >vaba+riige !06_S	et	f	\N
169693	vabariige	?vabariige =riige  (PlP  >vaba+riig !22_S	et	f	\N
169699	tapsustatud	?tapsustatud =tapsusta  (PtsPtIps  >tapsustama !27_V	et	f	\N
169700	tapsustatud	?tapsustatud =tapsustatu  (PlN  >tapsustatu !01_S	et	f	\N
169701	tapsustatud	?tapsustatud =tapsustatu  (IndPrSg2  >tapsustatuma !27_V	et	f	\N
169702	tapsustatud	?tapsustatud =tapsustatud  (ID  >tapsustatud !41_A	et	f	\N
169707	palmeos	?palmeos =palmeo  (SgIn  >palmeo !01_S	et	f	\N
169708	palmeos	?palmeos =palmeos  (SgN  >palmeos !22_S	et	f	\N
169733	tulevikuvaljavaated	?tulevikuvaljavaated =tulevikuvaljavaate  (PlN  >tulevikuvaljavaate !16_S	et	f	\N
169734	tulevikuvaljavaated	?tulevikuvaljavaated =valjavaate  (PlN  >tuleviku+valjavaate !16_S	et	f	\N
169735	tulevikuvaljavaated	?tulevikuvaljavaated =ikuvaljavaate  (PlN  >tulev+ikuvaljavaate !16_S	et	f	\N
169736	tulevikuvaljavaated	?tulevikuvaljavaated =vikuvaljavaate  (PlN  >tule+vikuvaljavaate !16_S	et	f	\N
169762	ersadega	?ersadega =ersa  (PlKom  >ersa !16_S	et	f	\N
169791	saarnased	?saarnased =saarnase  (PlN  >saarnane !12~10_A	et	f	\N
169793	saarnased	?saarnased =nase  (PlN  >saar+nase !16_S	et	f	\N
169798	eirata	eirata =eira  (Inf  >eirama !29_V	et	f	\N
169799	eirata	eirata =eira  (IndPrIps_  >eirama !29_V	et	f	\N
169810	uhingu	?uhingu =uhingu  (SgN  >uhingu !01_S	et	f	\N
169811	uhingu	?uhingu =uhingu  (SgG  >uhingu !01_S	et	f	\N
169812	uhingu	?uhingu =uhingu  (SgG  >uhing !02_S	et	f	\N
169813	uhingu	?uhingu =uhingu  (IndPrPs_  >uhinguma !27_V	et	f	\N
169814	uhingu	?uhingu =uhingu  (ImpPrSg2  >uhinguma !27_V	et	f	\N
169830	ersat	?ersat =ersa  (SgP  >ersa !16_S	et	f	\N
169832	ersat	?ersat =ersat  (SgN  >ersat !02_S	et	f	\N
169834	erslaseks	?erslaseks =erslase  (SgTr  >erslane !12?10_S	et	f	\N
169837	minetanud	minetanud =mineta  (PtsPtPs  >minetama !27_V	et	f	\N
169838	minetanud	minetanud =minetanu  (PlN  >minetanu !01_S	et	f	\N
169839	minetanud	"minetanu %mineta  )NU_vS  <minetama ;27_V	et	f	\N
169840	minetanud	minetanud =minetanud  (ID  >minetanud !41_A	et	f	\N
169841	minetanud	"minetanud %mineta  )NUD_vA  <minetama ;27_V	et	f	\N
169849	etnost	?etnost =etno  (SgEl  >etno !16_S	et	f	\N
169850	etnost	?etnost =etnos  (SgP  >etnos !11~09_S	et	f	\N
169851	olemasmordva	?olemasmordva =olemasmordva  (SgN  >olemasmordva !16_S	et	f	\N
169852	olemasmordva	?olemasmordva =olemasmordva  (SgG  >olemasmordev !02_A	et	f	\N
169853	olemasmordva	?olemasmordva =olemasmordva  (SgG  >olemasmordva !16_S	et	f	\N
169854	olemasmordva	?olemasmordva =mordva  (SgG  >olemas+mordev !02_A	et	f	\N
169857	venestamise	venestamise =venestamise  (SgG  >venestamine !12_S	et	f	\N
169632	arvukamalt	arvukamalt =kama  (SgAbl  >arvu+kama !17_S	et	f	\N
169639	diasporaa	?diasporaa =diasporaa  (SgN  >diasporaa !26_S	et	f	\N
169641	diasporaa	?diasporaa =diasporaa  (SgG  >diasporaa !26_S	et	f	\N
169654	ulemnoukogus	?ulemnoukogus =ulemnoukogu  (IndIpfSg3  >ulemnoukoguma !27_V	et	f	\N
169655	ulemnoukogus	?ulemnoukogus =ulemnoukogus  (SgN  >ulemnoukogus !11?09_S	et	f	\N
169667	ulemnoukogu	?ulemnoukogu =ulemnoukogu  (IndPrPs_  >ulemnoukoguma !27_V	et	f	\N
169668	ulemnoukogu	?ulemnoukogu =ulemnoukogu  (ImpPrSg2  >ulemnoukoguma !27_V	et	f	\N
169679	pohiseadus	?pohiseadus =pohiseadu  (IndIpfSg3  >pohiseaduma !27_V	et	f	\N
169680	pohiseadus	?pohiseadus =pohiseadus  (SgN  >pohiseadus !11~09_S	et	f	\N
169697	norgim	?norgim =norgim  (SgN  >norgim !02_A	et	f	\N
169712	seilenthal	?seilenthal =seilentha  (SgAd  >seilentha !01_S	et	f	\N
169719	httpw	### httpw	et	f	\N
169722	saranskr	?saranskr =saranskr  (SgN  >saranskr !22_S	et	f	\N
169726	traks	traks =traks  (SgN  >traks !22_S	et	f	\N
169727	traks	traks =traks  (SgN  >traks !22_A	et	f	\N
169731	tadaze	### tadaze	et	f	\N
169732	nuudiskusimused	?nuudiskusimused =nuudiskusimuse  (PlN  >nuudiskusimus !11?09_S	et	f	\N
169739	ruhma	?ruhma =ruhma  (SgN  >ruhma !16_S	et	f	\N
169740	ruhma	?ruhma =ruhma  (SgG  >ruhma !16_S	et	f	\N
169742	ruhma	?ruhma =ruhma  (IndPrPs_  >ruhmama !29_V	et	f	\N
169744	ruhma	?ruhma =ruhma  (ImpPrSg2  >ruhmama !29_V	et	f	\N
169759	motlevate	?motlevate =motleva  (PlG  >motleva !01_S	et	f	\N
169761	motlevate	?motlevate =motleva  (PlG  >motlev !02_A	et	f	\N
169763	lahtuvad	lahtuvad =lahtu  (IndPrPl3  >lahtuma !27_V	et	f	\N
169764	lahtuvad	lahtuvad =lahtuva  (PlN  >lahtuv !02_A	et	f	\N
169765	lahtuvad	"lahtuv %lahtu  )V_vA  <lahtuma ;27_V	et	f	\N
169769	foderatsiooni	?foderatsiooni =foderatsioo  (SgTer  >foderatsioo !26_S	et	f	\N
169770	foderatsiooni	?foderatsiooni =foderatsiooni  (SgN  >foderatsiooni !16_S	et	f	\N
169771	foderatsiooni	?foderatsiooni =foderatsiooni  (SgG  >foderatsiooni !16_S	et	f	\N
169772	foderatsiooni	?foderatsiooni =foderatsiooni  (SgG  >foderatsioon !22_S	et	f	\N
169773	foderatsiooni	?foderatsiooni =foderatsiooni  (SgP  >foderatsioon !22_S	et	f	\N
169774	foderatsiooni	?foderatsiooni =foderatsiooni  (SgAdt  >foderatsioon !22_S	et	f	\N
169775	foderatsiooni	?foderatsiooni =foderatsiooni  (IndPrPs_  >foderatsioonima !28_V	et	f	\N
169776	foderatsiooni	?foderatsiooni =foderatsiooni  (ImpPrSg2  >foderatsioonima !28_V	et	f	\N
169777	voimu	?voimu =voimu  (SgN  >voimu !16_S	et	f	\N
169778	voimu	?voimu =voimu  (SgG  >voimu !16_S	et	f	\N
169779	voimu	?voimu =voimu  (IndPrPs_  >voimuma !27_V	et	f	\N
169781	voimu	?voimu =voimu  (ImpPrSg2  >voimuma !27_V	et	f	\N
169807	maaema	maaema =ema  (SgN  >maa+ema !17_S	et	f	\N
169808	maaema	maaema =ema  (SgG  >maa+ema !17_S	et	f	\N
169809	maaema	maaema =ema  (SgP  >maa+ema !17_S	et	f	\N
169815	dmitri	?dmitri =dmitri  (ID  >dmitri !41_D	et	f	\N
169816	dmitri	?dmitri =dmitri  (SgG  >dmitter !02_S	et	f	\N
169817	nadkin	?nadkin =nadki  (IndPrSg1  >nadkima !28_V	et	f	\N
169818	nadkin	?nadkin =nadkin  (SgN  >nadkin !02_S	et	f	\N
169821	kaksikuteks	kaksikuteks =kaksiku  (PlTr  >kaksik !02_SA	et	f	\N
169822	kaksikuteks	kaksikuteks =ute  (SgTr  >kaksik+utt !22_S	et	f	\N
169823	kaksikuteks	kaksikuteks =ute  (PlTr  >kaksik+utt !22_S	et	f	\N
169829	konelevad	?konelevad =konele  (IndPrPl3  >konelema !31~27_V	et	f	\N
169831	konelevad	?konelevad =koneleva  (PlN  >konelev !02_A	et	f	\N
169833	konelevad	?konelevad =koneleva  (PlN  >koneleva !16_S	et	f	\N
169847	chetvergovi	?chetvergovi =chetvergovi  (ID  >chetvergovi !41_D	et	f	\N
169848	chetvergovi	?chetvergovi =chetvergovi  (SgG  >chetvergov !02_A	et	f	\N
169855	ulitohus	?ulitohus =ulitohu  (IndIpfSg3  >ulitohuma !27_V	et	f	\N
169856	ulitohus	?ulitohus =ulitohus  (SgN  >ulitohus !11?09_S	et	f	\N
169858	katalusaator	?katalusaator =katalusaator  (SgN  >katalusaator !02_S	et	f	\N
169860	tseremissid	?tseremissid =tseremissi  (PlN  >tseremiss !22_S	et	f	\N
169861	tseremissid	?tseremissid =tseremissi  (IndPrSg2  >tseremissima !28_V	et	f	\N
169862	omakeelstega	?omakeelstega =stega  (SgN  >oma+keel+stega !17_S	et	f	\N
169863	omakeelstega	?omakeelstega =stega  (SgG  >oma+keel+stega !17_S	et	f	\N
169864	omakeelstega	?omakeelstega =stega  (SgP  >oma+keel+stega !17_S	et	f	\N
169865	omakeelstega	?omakeelstega =keelste  (SgKom  >oma+keelste !06_S	et	f	\N
169875	vordlus	?vordlus =vordlu  (SgIn  >vordlu !01_S	et	f	\N
169876	vordlus	?vordlus =vordlu  (IndIpfSg3  >vordluma !27_V	et	f	\N
169877	vordlus	?vordlus =vordlus  (SgN  >vordlus !11~09_S	et	f	\N
169883	eelnou	?eelnou =eelnou  (SgN  >eelnou !26_S	et	f	\N
169884	eelnou	?eelnou =eelnou  (SgG  >eelnou !26_S	et	f	\N
169885	eelnou	?eelnou =nou  (SgN  >eel+nou !26_S	et	f	\N
169886	eelnou	?eelnou =nou  (SgG  >eel+nou !26_S	et	f	\N
169897	kargin	?kargin =kargi  (IndPrSg1  >karkima !28_V	et	f	\N
169898	kargin	?kargin =kargin  (SgN  >kargin !02_S	et	f	\N
169913	vassili	?vassili =vassili  (ID  >vassili !41_D	et	f	\N
169915	majanduskusimustes	?majanduskusimustes =majanduskusimus  (PlIn  >majanduskusimus !11?09_S	et	f	\N
169916	majanduskusimustes	?majanduskusimustes =imus  (PlIn  >majandus+kus+imus !09_S	et	f	\N
169917	majanduskusimustes	?majanduskusimustes =kusimus  (PlIn  >majandus+kusimus !11_S	et	f	\N
169687	koigist	?koigist =koigist  (SgN  >koigist !22_S	et	f	\N
169688	koigist	?koigist =gist  (SgN  >koi+gist !22_S	et	f	\N
169724	a-olkloreee	?a-olkloreee =olkloreee  (SgN  >a-olkloreee !26_S	et	f	\N
169725	a-olkloreee	?a-olkloreee =olkloreee  (SgG  >a-olkloreee !26_S	et	f	\N
169729	aavai	?aavai =aavai  (SgN  >aavai !26_S	et	f	\N
169730	aavai	?aavai =aavai  (SgG  >aavai !26_S	et	f	\N
169750	loomas	loomas =loo  (SupIn  >looma !38_V	et	f	\N
169751	loomas	loomas =looma  (SgIn  >loom !22_S	et	f	\N
169766	pohjalt	?pohjalt =pohja  (SgAbl  >pohjas !02_A	et	f	\N
169767	pohjalt	?pohjalt =pohja  (SgAbl  >pohja !16_S	et	f	\N
169768	pohjalt	?pohjalt =pohjalt  (ID  >pohjalt !41_D	et	f	\N
169788	usna	?usna =usna  (SgN  >usna !16_S	et	f	\N
169789	usna	?usna =usna  (SgG  >usna !16_S	et	f	\N
169790	usna	?usna =usna  (IndPrPs_  >usnama !29_V	et	f	\N
169792	usna	?usna =usna  (ImpPrSg2  >usnama !29_V	et	f	\N
169794	erinevaiks	erinevaiks =erineva  (PlTr  >erinev !02_A	et	f	\N
169795	erinevaiks	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
169802	ettekandes	ettekandes =kande  (SgIn  >ette+kanne !06_S	et	f	\N
169803	ettekandes	ettekandes =kande  (PlIn  >ette+kant !22_S	et	f	\N
169826	oeldes	?oeldes =oelde  (PlIn  >oelt !22_S	et	f	\N
169827	oeldes	?oeldes =oelde  (IndIpfSg3  >oeldema !27_V	et	f	\N
169828	oeldes	?oeldes =oeldes  (SgN  >oeldes !09_S	et	f	\N
169842	mastori	?mastori =mastori  (SgN  >mastori !01_S	et	f	\N
169843	mastori	?mastori =mastori  (SgG  >mastori !01_S	et	f	\N
169844	mastori	?mastori =mastori  (SgG  >mastor !02_S	et	f	\N
169868	riigipoliitika	riigipoliitika =poliitika  (SgN  >riigi+poliitika !01_S	et	f	\N
169869	riigipoliitika	riigipoliitika =poliitika  (SgG  >riigi+poliitika !01_S	et	f	\N
169887	lugemises	lugemises =lugemise  (SgIn  >lugemine !12_S	et	f	\N
169888	lugemises	"lugemine %luge  )MINE_vS  <lugema ;28_V	et	f	\N
169889	lugemises	"lugemine %lugemi  )NE_aA  <lugem ;02_S	et	f	\N
169914	gusljannikov	?gusljannikov =gusljannikov  (SgN  >gusljannikov !02_A	et	f	\N
169924	zanrides	?zanrides =zanri  (PlIn  >zanri !16_S	et	f	\N
169925	zanrides	?zanrides =zanri  (PlIn  >zanr !22_S	et	f	\N
169926	zanrides	?zanrides =zanri  (Ger  >zanrima !28_V	et	f	\N
169931	etnograf	### etnograf	et	f	\N
169942	lapi	lapi =lapi  (SgG  >lapp !22_S	et	f	\N
169943	lapi	lapi =lapi  (IndPrPs_  >lappima !28_V	et	f	\N
169944	lapi	lapi =lapi  (ImpPrSg2  >lappima !28_V	et	f	\N
169946	omaparad	?omaparad =omapara  (PlN  >omapara !16_S	et	f	\N
169947	omaparad	?omaparad =para  (PlN  >oma+para !17_S	et	f	\N
169973	nimisonul	?nimisonul =nimisonu  (SgAd  >nimisonu !01_S	et	f	\N
169974	nimisonul	?nimisonul =nimisonul  (SgN  >nimisonul !19_S	et	f	\N
169975	nimisonul	?nimisonul =sonu  (SgAd  >nimi+sonu !17_S	et	f	\N
169976	nimisonul	?nimisonul =sonul  (SgN  >nimi+sonul !02_S	et	f	\N
169978	rohkemgi	rohkemgi =rohkem  (ID^  >rohkem !41_D	et	f	\N
169979	rohkemgi	"rohkem %rohke  )M_cA^  <rohke ;01_A	et	f	\N
169980	rohkemgi	rohkemgi =rohkem  (SgN^  >rohkem !02_A	et	f	\N
169983	deklinatsiooni	deklinatsiooni =deklinatsiooni  (SgG  >deklinatsioon !22_S	et	f	\N
169984	deklinatsiooni	deklinatsiooni =deklinatsiooni  (SgP  >deklinatsioon !22_S	et	f	\N
169985	deklinatsiooni	deklinatsiooni =deklinatsiooni  (SgAdt  >deklinatsioon !22_S	et	f	\N
169996	nimisona	?nimisona =nimiso  (SgEs  >nimiso !01_S	et	f	\N
169997	nimisona	?nimisona =sona  (SgN  >nimi+sona !17_S	et	f	\N
169998	nimisona	?nimisona =sona  (SgG  >nimi+sona !17_S	et	f	\N
169999	nimisona	?nimisona =sona  (SgP  >nimi+sona !17_S	et	f	\N
170009	kindle	?kindle =kindle  (SgN  >kindle !06_S	et	f	\N
170010	kindle	?kindle =kindle  (SgG  >kindle !06_S	et	f	\N
170011	kindle	?kindle =kindle  (IndPrPs_  >kindlema !30_V	et	f	\N
170015	kindle	?kindle =kindle  (ImpPrSg2  >kindlema !30_V	et	f	\N
170021	eitussona	?eitussona =eitusso  (SgEs  >eitusso !16_S	et	f	\N
170023	eitussona	?eitussona =tusso  (SgEs  >ei+tusso !16_S	et	f	\N
170032	kudosan	?kudosan =kudosan  (SgN  >kudosan !19_S	et	f	\N
170043	motet	?motet =mote  (SgP  >mote !06_S	et	f	\N
170046	voimalikkusest	?voimalikkusest =voimalikkuse  (SgEl  >voimalikkus !11~09_S	et	f	\N
170049	voimalikkusest	?voimalikkusest =voimalikkuses  (SgP  >voimalikkusene !12_A	et	f	\N
170087	pents	?pents =pents  (SgN  >pents !22_S	et	f	\N
170114	ajakirjandusteksti	ajakirjandusteksti =teksti  (SgG  >aja+kirjandus+tekst !22_S	et	f	\N
170115	ajakirjandusteksti	ajakirjandusteksti =teksti  (SgP  >aja+kirjandus+tekst !22_S	et	f	\N
170116	ajakirjandusteksti	ajakirjandusteksti =teksti  (SgAdt  >aja+kirjandus+tekst !22_S	et	f	\N
170120	tavalisele	tavalisele =tavalise  (SgAll  >tavaline !12_A	et	f	\N
170121	tavalisele	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
170125	olemaslugu	olemaslugu =lugu  (SgN  >olemas+lugu !18_S	et	f	\N
170126	olemaslugu	olemaslugu =lugu  (SgP  >olemas+lugu !18_S	et	f	\N
170129	hirmutavast	hirmutavast =hirmutava  (SgEl  >hirmutav !02_A	et	f	\N
170130	hirmutavast	"hirmutav %hirmu  )TAV_vAS  <hirmuma ;27_V	et	f	\N
170131	hirmutavast	"hirmutav %hirmuta  )V_vA  <hirmutama ;27_V	et	f	\N
170132	hirmutavast	hirmutavast =tava  (SgEl  >hirmu+tava !17_S	et	f	\N
170133	hirmutavast	hirmutavast =tavas  (SgP  >hirmu+tavane !10_A	et	f	\N
169703	taagepera	?taagepera =taagepera  (SgN  >taagepera !16_S	et	f	\N
169704	taagepera	?taagepera =taagepera  (SgG  >taagepera !16_S	et	f	\N
169705	kunnapago	?kunnapago =kunnapago  (SgN  >kunnapago !16_S	et	f	\N
169706	kunnapago	?kunnapago =kunnapago  (SgG  >kunnapago !16_S	et	f	\N
169709	paula	?paula =paula  (SgN  >paula !16_S	et	f	\N
169710	paula	?paula =paula  (SgG  >paula !16_S	et	f	\N
169711	paula	?paula =paula  (IndPrPs_  >paulama !29_V	et	f	\N
169713	paula	?paula =paula  (ImpPrSg2  >paulama !29_V	et	f	\N
169737	loova	loova =loova  (SgG  >loov !02_A	et	f	\N
169738	loova	"loov %loo  )V_vA  <looma ;38_V	et	f	\N
169754	seisvad	seisvad =seisva  (PlN  >seisev !02_A	et	f	\N
169755	seisvad	"seisev %seis  )V_vA  <seisma ;32_V	et	f	\N
169756	reaalpolotiliselt	?reaalpolotiliselt =reaalpolotilise  (SgAbl  >reaalpolotiline !12_A	et	f	\N
169757	reaalpolotiliselt	?reaalpolotiliselt =reaalpolotiliselt  (ID  >reaalpolotiliselt !41_D	et	f	\N
169758	reaalpolotiliselt	?reaalpolotiliselt =polotilise  (SgAbl  >reaal+polotiline !12_A	et	f	\N
169760	reaalpolotiliselt	?reaalpolotiliselt =alpolotilise  (SgAbl  >rea+alpolotiline !12_A	et	f	\N
169780	psuholoogiline	?psuholoogiline =psuholoogiline  (SgN  >psuholoogiline !12_A	et	f	\N
169782	psuholoogiline	?psuholoogiline =psuholoogiline  (PlP  >psuholoogilin !19_S	et	f	\N
169783	uletab	?uletab =uleta  (IndPrSg3  >uletama !27_V	et	f	\N
169786	pohisonavara	?pohisonavara =pohisonavara  (SgN  >pohisonavara !16_S	et	f	\N
169787	pohisonavara	?pohisonavara =pohisonavara  (SgG  >pohisonavara !16_S	et	f	\N
169835	makslateks	?makslateks =maksla  (PlTr  >maksla !01_S	et	f	\N
169836	makslateks	?makslateks =makslate  (PlTr  >makslatt !22_S	et	f	\N
169845	jevgeni	?jevgeni =jevge  (SgTer  >jevge !06_S	et	f	\N
169846	jevgeni	?jevgeni =jevgeni  (SgG  >jevgen !02_S	et	f	\N
169866	pokuv	?pokuv =poku  (PtsPrPs  >pokuma !27_V	et	f	\N
169867	pokuv	?pokuv =pokuv  (SgN  >pokuv !02_A	et	f	\N
169870	uemnoukogu	?uemnoukogu =uemnoukogu  (IndPrPs_  >uemnoukoguma !27_V	et	f	\N
169871	uemnoukogu	?uemnoukogu =uemnoukogu  (ImpPrSg2  >uemnoukoguma !27_V	et	f	\N
169872	formaalselt	formaalselt =formaalse  (SgAbl  >formaalne !02_A	et	f	\N
169873	formaalselt	formaalselt =formaalselt  (ID  >formaalselt !41_D	et	f	\N
169874	formaalselt	"formaalselt %formaalse  )LT_mD  <formaalne ;02_A	et	f	\N
169881	rakendava	rakendava =rakendava  (SgG  >rakendav !02_A	et	f	\N
169882	rakendava	"rakendav %rakenda  )V_vA  <rakendama ;27_V	et	f	\N
169890	sattele	?sattele =satte  (SgAll  >sate !06_S	et	f	\N
169891	sattele	?sattele =sattele  (IndPrPs_  >sattelema !27_V	et	f	\N
169892	sattele	?sattele =sattele  (ImpPrSg2  >sattelema !27_V	et	f	\N
169937	karjala	?karjala =karjala  (SgN  >karjala !01_S	et	f	\N
169938	karjala	?karjala =karjala  (SgG  >karjala !01_S	et	f	\N
169951	haalikuuhendeid	?haalikuuhendeid =haalikuuhendei  (PlN  >haalikuuhendei !26_S	et	f	\N
169952	haalikuuhendeid	?haalikuuhendeid =haalikuuhendei  (SgP  >haalikuuhendei !26_S	et	f	\N
169963	peenendet	?peenendet =ende  (SgP  >peen+ende !06_S	et	f	\N
169995	omadussonad	?omadussonad =sona  (PlN  >omadus+sona !17_S	et	f	\N
170000	kaandu	?kaandu =kaandu  (SgN  >kaandu !01_S	et	f	\N
170001	kaandu	?kaandu =kaandu  (SgG  >kaandu !01_S	et	f	\N
170002	kaandu	?kaandu =kaandu  (IndPrPs_  >kaanduma !27_V	et	f	\N
170003	kaandu	?kaandu =kaandu  (ImpPrSg2  >kaanduma !27_V	et	f	\N
170014	koneviis	?koneviis =konevi  (PlIn  >konev !02_A	et	f	\N
170016	koneviis	?koneviis =konevii  (SgIn  >konevii !26_S	et	f	\N
170017	koneviis	?koneviis =koneviis  (SgN  >koneviis !22_S	et	f	\N
170029	nimisonule	?nimisonule =nimisonu  (SgAll  >nimisonu !01_S	et	f	\N
170030	nimisonule	?nimisonule =nimisonule  (PlP  >nimisonul !19_S	et	f	\N
170031	nimisonule	?nimisonule =sonu  (SgAll  >nimi+sonu !17_S	et	f	\N
170034	ersade	?ersade =ersa  (PlG  >ersa !16_S	et	f	\N
170036	juurutakse	?juurutakse =juuru  (IndPrIps  >juuruma !27_V	et	f	\N
170039	juurutakse	?juurutakse =juurutakse  (SgG  >juurutakne !02_A	et	f	\N
170041	juurutakse	?juurutakse =juurutakse  (PlP  >juurutaks !22_S	et	f	\N
170042	juurutakse	?juurutakse =utakse  (SgG  >juur+utakne !02_A	et	f	\N
170045	ulemineku	?ulemineku =ulemineku  (IndPrPs_  >uleminekuma !27_V	et	f	\N
170047	ulemineku	?ulemineku =ulemineku  (ImpPrSg2  >uleminekuma !27_V	et	f	\N
170062	ulesanne	?ulesanne =ulesanne  (SgN  >ulesanne !02_A	et	f	\N
170063	ulesanne	?ulesanne =ulesanne  (PlP  >ulesann !22_S	et	f	\N
170064	kaisolev	?kaisolev =kaisole  (PtsPrPs  >kaisolema !27_V	et	f	\N
170066	kaisolev	?kaisolev =kaisolev  (SgN  >kaisolev !02_A	et	f	\N
170067	kaisolev	?kaisolev =solev  (SgN  >kai+solev !02_A	et	f	\N
170068	molemat	?molemat =molema  (SgP  >molem !02_A	et	f	\N
170071	tootada	?tootada =toota  (Inf  >tootama !27_V	et	f	\N
170072	tootada	?tootada =tada  (SgN  >too+tada !17_S	et	f	\N
170073	tootada	?tootada =tada  (SgG  >too+tada !17_S	et	f	\N
170074	tootada	?tootada =tada  (SgP  >too+tada !17_S	et	f	\N
170082	ljam	### ljam	et	f	\N
170097	vaenlikult	?vaenlikult =vaenliku  (SgAbl  >vaenlik !25_A	et	f	\N
170098	vaenlikult	?vaenlikult =vaenliku  (SgAbl  >vaenliku !01_S	et	f	\N
170099	vaenlikult	?vaenlikult =vaenlikult  (ID  >vaenlikult !41_D	et	f	\N
170103	püsimata	püsimata =püsi  (SupAb  >püsima !27_V	et	f	\N
169824	mordovia	?mordovia =mordovia  (SgN  >mordovia !01_S	et	f	\N
169825	mordovia	?mordovia =mordovia  (SgG  >mordovia !01_S	et	f	\N
169893	koigis	?koigis =koigi  (SgIn  >koigi !16_S	et	f	\N
169894	koigis	?koigis =koigi  (SgIn  >koik !22_S	et	f	\N
169895	koigis	?koigis =koigi  (IndIpfSg3  >koigima !28_V	et	f	\N
169896	koigis	?koigis =koigis  (SgN  >koigis !09_S	et	f	\N
169927	ersakeelsed	?ersakeelsed =ersakeelse  (PlN  >ersakeelne !02_A	et	f	\N
169929	moksakeelne	?moksakeelne =moksakeelne  (SgN  >moksakeelne !02_A	et	f	\N
169930	moksakeelne	?moksakeelne =moksakeelne  (PlP  >moksakeeln !22_S	et	f	\N
169932	jevsevjev1864	?jevsevjev =jevsevjev  (SgN  >jevsevjev !02_A	et	f	\N
169948	jargmised	?jargmised =jargmise  (PlN  >jargmine !12?10_A	et	f	\N
169949	jargmised	?jargmised =jargmise  (IndPrSg2  >jargmisema !27_V	et	f	\N
169953	sona	?sona =sona  (SgN  >sona !17_S	et	f	\N
169954	sona	?sona =sona  (SgG  >sona !17_S	et	f	\N
169955	sona	?sona =sona  (SgP  >sona !17_S	et	f	\N
169956	sona	?sona =sona  (IndPrPs_  >sonama !27_V	et	f	\N
169957	sona	?sona =sona  (ImpPrSg2  >sonama !27_V	et	f	\N
169958	uhendeid	?uhendeid =uhende  (PlP  >uhendi !01_S	et	f	\N
169959	uhendeid	?uhendeid =uhende  (PlP  >uhend !02_S	et	f	\N
169961	uhendeid	?uhendeid =uhendei  (PlN  >uhendei !26_S	et	f	\N
169962	uhendeid	?uhendeid =uhendei  (SgP  >uhendei !26_S	et	f	\N
169992	maaratud	maaratud =maaratu  (PlN  >maaratu !01_AS	et	f	\N
169993	maaratud	"maaratu %maara  )TU2_kA  <maara ;16_S	et	f	\N
170006	koneviise	?koneviise =koneviise  (SgN  >koneviise !16_S	et	f	\N
170007	koneviise	?koneviise =koneviise  (SgG  >koneviise !16_S	et	f	\N
170008	koneviise	?koneviise =koneviise  (PlP  >koneviis !22_S	et	f	\N
170019	koneviisi	?koneviisi =koneviisi  (SgN  >koneviisi !16_S	et	f	\N
170020	koneviisi	?koneviisi =koneviisi  (SgG  >koneviisi !16_S	et	f	\N
170022	koneviisi	?koneviisi =koneviisi  (SgG  >koneviis !22_S	et	f	\N
170024	koneviisi	?koneviisi =koneviisi  (SgP  >koneviis !22_S	et	f	\N
170025	koneviisi	?koneviisi =koneviisi  (SgAdt  >koneviis !22_S	et	f	\N
170026	koneviisi	?koneviisi =koneviisi  (IndPrPs_  >koneviisima !28_V	et	f	\N
170027	koneviisi	?koneviisi =koneviisi  (ImpPrSg2  >koneviisima !28_V	et	f	\N
170033	kudosat	?kudosat =kudosa  (SgP  >kudosa !01_S	et	f	\N
170035	teadvusse	teadvusse =teadvus  (SgAdt  >teadvus !11_S	et	f	\N
170037	teadvusse	"teadvus %tead  )VUS_aS  <teadma ;34_V	et	f	\N
170040	teadvusse	"teadvus %teadva  )US_aS  <teadev ;02_A	et	f	\N
170056	uhtse	?uhtse =uhtse  (SgN  >uhtse !06_S	et	f	\N
170057	uhtse	?uhtse =uhtse  (SgG  >uhtne !02_A	et	f	\N
170058	uhtse	?uhtse =uhtse  (SgG  >uhtse !06_S	et	f	\N
170059	uhtse	?uhtse =uhtse  (PlP  >uhts !22_S	et	f	\N
170060	uhtse	?uhtse =uhtse  (IndPrPs_  >uhtsema !27_V	et	f	\N
170061	uhtse	?uhtse =uhtse  (ImpPrSg2  >uhtsema !27_V	et	f	\N
170070	basil	?basil =basi  (SgAd  >basi !17_S	et	f	\N
170078	normid	normid =normi  (PlN  >norm !22_S	et	f	\N
170079	normid	normid =normi  (IndPrSg2  >normima !28_V	et	f	\N
170081	jam	### jam	et	f	\N
170092	pingulik	?pingulik =pingulik  (SgN  >pingulik !25_A	et	f	\N
170093	pingulik	?pingulik =ulik  (SgN  >ping+ulik !02_S	et	f	\N
170106	distabiliseerimine	?distabiliseerimine =distabiliseerimine  (SgN  >distabiliseerimine !12_S	et	f	\N
170107	distabiliseerimine	?distabiliseerimine =distabiliseerimine  (PlP  >distabiliseerimin !19_S	et	f	\N
170117	alapealkirjast	alapealkirjast =kirja  (SgEl  >ala+peal+kiri !24_S	et	f	\N
170118	alapealkirjast	alapealkirjast =kirjas  (SgP  >ala+peal+kirjane !10_A	et	f	\N
170119	alapealkirjast	"ala+peal+kirjane %kirja  )NE_aA  <ala+peal+kiri ;24_S	et	f	\N
170127	kompositsioon	kompositsioon =kompositsioon  (SgN  >kompositsioon !22_S	et	f	\N
170128	kompositsioon	kompositsioon =positsioon  (SgN  >kom+positsioon !22_S	et	f	\N
170140	suunatakse	suunatakse =suuna  (IndPrIps  >suunama !29_V	et	f	\N
170141	suunatakse	suunatakse =takse  (PlP  >suuna+taks !22_S	et	f	\N
170145	negatiivselt	negatiivselt =negatiivse  (SgAbl  >negatiivne !02_A	et	f	\N
170146	negatiivselt	negatiivselt =negatiivselt  (ID  >negatiivselt !41_D	et	f	\N
170147	negatiivselt	"negatiivselt %negatiivse  )LT_mD  <negatiivne ;02_A	et	f	\N
170180	silmapilgudest	?silmapilgudest =silmapilgudes  (SgP  >silmapilgudene !12_A	et	f	\N
170181	silmapilgudest	?silmapilgudest =pilgudes  (SgP  >silma+pilgudene !12_A	et	f	\N
170183	silmapilgudest	?silmapilgudest =apilgudes  (SgP  >silm+apilgudene !12_A	et	f	\N
170185	parimal	parimal =parima  (SgAd  >parim !02_A	et	f	\N
170186	parimal	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
170200	musti	musti =musti  (SgG  >must !22_AS	et	f	\N
170201	musti	musti =musti  (SgP  >must !22_AS	et	f	\N
170202	musti	musti =musti  (SgAdt  >must !22_AS	et	f	\N
170203	musti	musti =musti  (PlP  >must !22_AS	et	f	\N
170213	selik	?selik =selik  (SgN  >selik !02_S	et	f	\N
170239	emper	?emper =emper  (SgN  >emper !02_S	et	f	\N
170264	mejed	?mejed =meje  (PlN  >meje !16_S	et	f	\N
170265	mejed	?mejed =meje  (IndPrSg2  >mejema !27_V	et	f	\N
170290	päeava	?päeava =päeava  (SgN  >päeava !01_S	et	f	\N
170291	päeava	?päeava =päeava  (SgG  >päeava !01_S	et	f	\N
170292	kauplusedes	?kauplusedes =luse  (PlIn  >kaup+luse !16_S	et	f	\N
169859	venestamise	"venestamine %venesta  )MINE_vS  <venestama ;27_V	et	f	\N
169878	joudnud	?joudnud =joudnu  (PlN  >joudnu !01_S	et	f	\N
169879	joudnud	?joudnud =joudnu  (IndPrSg2  >joudnuma !27_V	et	f	\N
169880	joudnud	?joudnud =joudnud  (ID  >joudnud !41_A	et	f	\N
169899	kuulutanud	kuulutanud =kuuluta  (PtsPtPs  >kuulutama !27_V	et	f	\N
169900	kuulutanud	kuulutanud =kuulutanu  (PlN  >kuulutanu !01_S	et	f	\N
169901	kuulutanud	"kuulutanu %kuuluta  )NU_vS  <kuulutama ;27_V	et	f	\N
169902	kuulutanud	kuulutanud =kuulutanud  (ID  >kuulutanud !41_A	et	f	\N
169903	kuulutanud	"kuulutanud %kuuluta  )NUD_vA  <kuulutama ;27_V	et	f	\N
169904	kuulutanud	kuulutanud =tanu  (PlN  >kuulu+tanu !17_S	et	f	\N
169905	suveraanseks	?suveraanseks =suveraanse  (SgTr  >suveraanne !02_A	et	f	\N
169906	suveraanseks	?suveraanseks =suveraanse  (PlTr  >suveraans !22_S	et	f	\N
169907	suveraanseks	?suveraanseks =raanse  (SgTr  >suve+raanne !02_A	et	f	\N
169908	suveraanseks	?suveraanseks =raanse  (SgTr  >suve+raanse !06_S	et	f	\N
169909	suveraanseks	?suveraanseks =raanse  (PlTr  >suve+raans !22_S	et	f	\N
169910	voitis	?voitis =voit  (IndIpfSg3  >voitma !34_V	et	f	\N
169911	voitis	?voitis =voiti  (IndIpfSg3  >voitima !28_V	et	f	\N
169912	voitis	?voitis =voitis  (SgN  >voitis !11~09_S	et	f	\N
169928	erzjanj	### erzjanj	et	f	\N
169933	keelelt	keelelt =keele  (SgAbl  >keel !13_S	et	f	\N
169934	keelelt	keelelt =keele  (PlAbl  >keeld !22_S	et	f	\N
169939	saami	saami =saami  (SgG  >saam !22_S	et	f	\N
169940	saami	saami =saami  (SgP  >saam !22_S	et	f	\N
169941	saami	saami =saami  (SgAdt  >saam !22_S	et	f	\N
169945	ligemadmoned	### ligemadmoned	et	f	\N
169950	sonarohk	?sonarohk =sonarohk  (SgN  >sonarohk !22_S	et	f	\N
169964	kaashaalikuid	?kaashaalikuid =kaashaalikui  (PlN  >kaashaalikui !26_S	et	f	\N
169965	kaashaalikuid	?kaashaalikuid =kaashaalikui  (SgP  >kaashaalikui !26_S	et	f	\N
169966	kaashaalikuid	?kaashaalikuid =haaliku  (PlP  >kaas+haaliku !01_S	et	f	\N
169967	kaashaalikuid	?kaashaalikuid =haaliku  (PlP  >kaas+haalik !02_S	et	f	\N
169968	kaashaalikuid	?kaashaalikuid =haalikui  (PlN  >kaas+haalikui !26_S	et	f	\N
169969	kaashaalikuid	?kaashaalikuid =haalikui  (SgP  >kaas+haalikui !26_S	et	f	\N
169970	moksas	?moksas =moksa  (SgIn  >moksa !16_S	et	f	\N
169971	moksas	?moksas =moksa  (IndIpfSg3  >moksama !29_V	et	f	\N
169972	moksas	?moksas =moksas  (SgN  >moksas !07_S	et	f	\N
169977	kaanet	### kaanet	et	f	\N
169994	possessivdeklinatsioon	?possessivdeklinatsioon =possessivdeklinatsioon  (SgN  >possessivdeklinatsioon !22_S	et	f	\N
170004	ungarile	?ungarile =ungari  (SgAll  >ungari !01_S	et	f	\N
170005	ungarile	?ungarile =ungari  (SgAll  >ungar !02_S	et	f	\N
170028	poordeloppe	?poordeloppe =poordeloppe  (PlP  >poordelopp !22_S	et	f	\N
170038	moksade	?moksade =moksa  (PlG  >moksa !16_S	et	f	\N
170075	uhtsed	?uhtsed =uhtse  (PlN  >uhtne !02_A	et	f	\N
170076	uhtsed	?uhtsed =uhtse  (PlN  >uhtse !06_S	et	f	\N
170077	uhtsed	?uhtsed =uhtse  (IndPrSg2  >uhtsema !27_V	et	f	\N
170089	vanematelt	vanematelt =vanema  (PlAbl  >vanem !02_AS	et	f	\N
170090	vanematelt	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
170091	vanematelt	vanematelt =ate  (PlAbl  >vanem+att !22_S	et	f	\N
170094	kalduvad	kalduvad =kaldu  (IndPrPl3  >kalduma !27_V	et	f	\N
170095	kalduvad	kalduvad =kalduva  (PlN  >kalduv !02_A	et	f	\N
170096	kalduvad	"kalduv %kaldu  )V_vA  <kalduma ;27_V	et	f	\N
170156	tv-programmides	tv-programmides =programmi  (PlIn  >tv-programm !22_S	et	f	\N
170157	tv-programmides	tv-programmides =programmi  (Ger  >tv-programmima !28_V	et	f	\N
170158	nähtust	nähtust =nähtu  (SgEl  >nähtu !01_S	et	f	\N
170159	nähtust	"nähtu %näh  )TU1_vS  <nägema ;28_V	et	f	\N
170160	nähtust	nähtust =nähtus  (SgP  >nähtus !11~09_S	et	f	\N
170161	nähtust	"nähtus %näh  )TUS1_aS  <nägema ;28_V	et	f	\N
170167	kaasakõrvalmõjusid	kaasakõrvalmõjusid =mõju  (PlP  >kaasa+kõrval+mõju !17_S	et	f	\N
170168	kaasakõrvalmõjusid	kaasakõrvalmõjusid =mõjusi  (PlN  >kaasa+kõrval+mõjus !02_A	et	f	\N
170179	vihastest	vihastest =vihas  (PlEl  >vihane !10_A	et	f	\N
170182	vihastest	"vihane %viha  )NE_aA  <viha ;17_SA	et	f	\N
170184	vihastest	"vihane %viha  )NE_aA  <viht ;22_S	et	f	\N
170196	vastutav	vastutav =vastuta  (PtsPrPs  >vastutama !27_V	et	f	\N
170197	vastutav	vastutav =vastutav  (SgN  >vastutav !02_A	et	f	\N
170198	vastutav	"vastutav %vastuta  )V_vA  <vastutama ;27_V	et	f	\N
170204	õpitajatele	?õpitajatele =õpitaja  (PlAll  >õpitaja !01_S	et	f	\N
170205	õpitajatele	?õpitajatele =õpitaja  (PlAll  >õpitajas !02_A	et	f	\N
170206	õpitajatele	?õpitajatele =õpitajate  (PlAll  >õpitajatt !22_S	et	f	\N
170207	õpitajatele	?õpitajatele =õpitajatele  (IndPrPs_  >õpitajatelema !36_V	et	f	\N
170209	õpitajatele	?õpitajatele =õpitajatele  (ImpPrSg2  >õpitajatelema !36_V	et	f	\N
170211	õpitajatele	?õpitajatele =tajate  (PlAll  >õpi+tajatt !22_S	et	f	\N
170214	meresinine	meresinine =inine  (SgN  >meres+inine !10_A	et	f	\N
170215	meresinine	"meres+inine %ini  )NE_aA  <meres+ini ;17_S	et	f	\N
170224	koolilaste	koolilaste =las  (PlG  >kooli+laps !14_S	et	f	\N
170225	koolilaste	koolilaste =laste  (PlP  >kooli+last !22_S	et	f	\N
170226	koolilaste	koolilaste =ilas  (PlG  >kool+ilane !10_A	et	f	\N
169918	rahvuskusimustes	?rahvuskusimustes =rahvuskusimus  (PlIn  >rahvuskusimus !11?09_S	et	f	\N
169919	rahvuskusimustes	?rahvuskusimustes =imus  (PlIn  >rahvus+kus+imus !09_S	et	f	\N
169920	rahvuskusimustes	?rahvuskusimustes =kusimus  (PlIn  >rahvus+kusimus !11_S	et	f	\N
169921	rahvuskusimustes	?rahvuskusimustes =skusimus  (PlIn  >rahvu+skusimus !11_S	et	f	\N
169922	paevil	?paevil =paevi  (SgAd  >paevi !16_S	et	f	\N
169923	paevil	?paevil =paevi  (SgAd  >paev !22_S	et	f	\N
169935	lahedased	?lahedased =lahedase  (PlN  >lahedane !12_A	et	f	\N
169936	lahedased	?lahedased =dase  (PlN  >lahe+dase !16_S	et	f	\N
169960	ksni	### ksni	et	f	\N
169981	jargsonad	### jargsonad	et	f	\N
169982	nimisonadega	?nimisonadega =sona  (PlKom  >nimi+sona !17_S	et	f	\N
169986	maaramata	?maaramata =maara  (SupAb  >maarama !29_V	et	f	\N
169987	maaramata	?maaramata =maarama  (SgAb  >maaram !02_A	et	f	\N
169988	maaramata	?maaramata =maaramata  (ID  >maaramata !41_A	et	f	\N
169989	maaramata	?maaramata =maaramata  (IndPrPs_  >maaramatama !27_V	et	f	\N
169990	maaramata	?maaramata =maaramata  (ImpPrSg2  >maaramatama !27_V	et	f	\N
169991	maaramata	?maaramata =rama  (SgAb  >maa+rama !17_S	et	f	\N
170012	kaskiv	?kaskiv =kaski  (PtsPrPs  >kaskima !28_V	et	f	\N
170013	kaskiv	?kaskiv =kaskiv  (SgN  >kaskiv !02_A	et	f	\N
170018	soovov	?soovov =soovov  (SgN  >soovov !02_A	et	f	\N
170044	uhismordva	?uhismordva =uhismordva  (SgN  >uhismordva !16_S	et	f	\N
170048	uhismordva	?uhismordva =uhismordva  (SgG  >uhismordev !02_A	et	f	\N
170050	uhismordva	?uhismordva =uhismordva  (SgG  >uhismordva !16_S	et	f	\N
170051	uhismordva	?uhismordva =smordva  (SgN  >uhi+smordva !01_S	et	f	\N
170052	uhismordva	?uhismordva =smordva  (SgG  >uhi+smordva !01_S	et	f	\N
170053	uhismordva	?uhismordva =smordva  (SgG  >uhi+smordev !02_A	et	f	\N
170054	pooldajad	pooldajad =pooldaja  (PlN  >pooldaja !01_S	et	f	\N
170055	pooldajad	"pooldaja %poolda  )JA_vS  <pooldama ;27_V	et	f	\N
170065	polvkond	?polvkond =polvkond  (SgN  >polvkond !22_S	et	f	\N
170069	opetada	?opetada =opeta  (Inf  >opetama !27_V	et	f	\N
170080	pohjenduseks	?pohjenduseks =pohjenduse  (SgTr  >pohjendus !11_S	et	f	\N
170083	kutsju	?kutsju =kutsju  (SgN  >kutsju !01_S	et	f	\N
170084	kutsju	?kutsju =kutsju  (SgG  >kutsju !01_S	et	f	\N
170085	kutsju	?kutsju =kutsju  (IndPrPs_  >kutsjuma !27_V	et	f	\N
170086	kutsju	?kutsju =kutsju  (ImpPrSg2  >kutsjuma !27_V	et	f	\N
170088	alkhoholism	?alkhoholism =alkhoholism  (SgN  >alkhoholism !22_S	et	f	\N
170100	nukreim	nukreim =nukreim  (SgN  >nukreim !02_A	et	f	\N
170101	nukreim	"nukreim %nukre  )IM_sA  <nukker ;02_A	et	f	\N
170102	nukreim	"nukreim %nukre  )IM_sA  <nugris ;07_A	et	f	\N
170110	minimaalseks	minimaalseks =minimaalse  (SgTr  >minimaalne !02_A	et	f	\N
170112	minimaalseks	minimaalseks =seks  (SgN  >minimaal+seks !22_S	et	f	\N
170134	näitest	näitest =näite  (SgEl  >näide !06_S	et	f	\N
170136	näitest	näitest =näites  (SgP  >näitene !12~10_A	et	f	\N
170137	näitest	"näitene %näite  )NE_aA  <näide ;06_S	et	f	\N
170162	hirmutav	hirmutav =hirmu  (PtsPrIps  >hirmuma !27_V	et	f	\N
170163	hirmutav	hirmutav =hirmuta  (PtsPrPs  >hirmutama !27_V	et	f	\N
170164	hirmutav	hirmutav =hirmutav  (SgN  >hirmutav !02_A	et	f	\N
170165	hirmutav	"hirmutav %hirmu  )TAV_vAS  <hirmuma ;27_V	et	f	\N
170166	hirmutav	"hirmutav %hirmuta  )V_vA  <hirmutama ;27_V	et	f	\N
170216	lubuv	?lubuv =lubu  (PtsPrPs  >lubuma !27_V	et	f	\N
170217	lubuv	?lubuv =lubuv  (SgN  >lubuv !02_A	et	f	\N
170230	sureuks	?sureuks =sureu  (SgTr  >sureu !26_S	et	f	\N
170231	sureuks	?sureuks =sureuks  (SgN  >sureuks !22_S	et	f	\N
170232	inetu	inetu =inetu  (SgN  >inetu !01_A	et	f	\N
170233	inetu	"inetu %ine  )TU2_kA  <ine ;16_S	et	f	\N
170234	inetu	inetu =inetu  (SgG  >inetu !01_A	et	f	\N
170235	riidest	riidest =riide  (SgEl  >riie !06_S	et	f	\N
170236	riidest	riidest =riides  (SgP  >riidene !10_A	et	f	\N
170237	riidest	"riidene %riide  )NE_aA  <riie ;06_S	et	f	\N
170238	riidest	riidest =riidest  (ID  >riidest !41_D	et	f	\N
170262	tumedam	tumedam =tumedam  (SgN  >tumedam !02_A	et	f	\N
170263	tumedam	"tumedam %tumeda  )M_cA  <tume ;02_A	et	f	\N
170275	andress	?andress =andress  (SgN  >andress !22_S	et	f	\N
170287	torni	torni =torni  (SgG  >torn !22_S	et	f	\N
170288	torni	torni =torni  (SgP  >torn !22_S	et	f	\N
170289	torni	torni =torni  (SgAdt  >torn !22_S	et	f	\N
170296	itatsen	?itatsen =itatse  (IndPrSg1  >itatsema !27_V	et	f	\N
170297	itatsen	?itatsen =itatsen  (SgN  >itatsen !19_S	et	f	\N
170306	elunäitab	?elunäitab =elunäita  (IndPrSg3  >elunäitama !27_V	et	f	\N
170328	täiuslikult	täiuslikult =täiusliku  (SgAbl  >täiuslik !25_A	et	f	\N
170329	täiuslikult	täiuslikult =täiuslikult  (ID  >täiuslikult !41_D	et	f	\N
170330	täiuslikult	"täiuslikult %täiusliku  )LT_mD  <täiuslik ;25_A	et	f	\N
170362	harjutuste	harjutuste =harjutus  (PlG  >harjutus !11_S	et	f	\N
170363	harjutuste	"harjutus %harjuta  )US_vS  <harjutama ;27_V	et	f	\N
170364	harjutuste	"harjutus %harju  )TUS1_aS  <harjuma ;27_V	et	f	\N
170365	harjutuste	harjutuste =tuste  (PlP  >harju+tust !22_S	et	f	\N
170370	harjutustega	harjutustega =harjutus  (PlKom  >harjutus !11_S	et	f	\N
170371	harjutustega	"harjutus %harjuta  )US_vS  <harjutama ;27_V	et	f	\N
170104	püsimata	püsimata =püsimata  (ID  >püsimata !41_A	et	f	\N
170105	püsimata	"püsimata %püsi  )MATA_vA  <püsima ;27_V	et	f	\N
170108	vähetatakse	?vähetatakse =väheta  (IndPrIps  >vähetama !27_V	et	f	\N
170109	vähetatakse	?vähetatakse =vähetatakse  (SgG  >vähetatakne !02_A	et	f	\N
170111	vähetatakse	?vähetatakse =vähetatakse  (PlP  >vähetataks !22_S	et	f	\N
170113	vähetatakse	?vähetatakse =tatakse  (SgG  >vähe+tatakne !02_A	et	f	\N
170122	publitsistlikus	publitsistlikus =publitsistliku  (SgIn  >publitsistlik !25_A	et	f	\N
170123	publitsistlikus	publitsistlikus =publitsistlikus  (SgN  >publitsistlikus !11?09_S	et	f	\N
170124	publitsistlikus	"publitsistlikus %publitsistliku  )US_aS  <publitsistlik ;25_A	et	f	\N
170142	julges	julges =julge  (SgIn  >julge !01_A	et	f	\N
170143	julges	julges =julge  (PlIn  >julk !22_S	et	f	\N
170144	julges	julges =julge  (IndIpfSg3  >julgema !27_V	et	f	\N
170148	jälgitavad	jälgitavad =jälgitava  (PlN  >jälgitav !02_A	et	f	\N
170149	jälgitavad	"jälgitav %jälgi  )TAV_vAS  <jälgima ;27_V	et	f	\N
170152	liiasust	liiasust =liiasus  (SgP  >liiasus !11_S	et	f	\N
170153	liiasust	"liiasus %liia  )SUS_aS  <liig ;22_S	et	f	\N
170154	deklaratiivsust	deklaratiivsust =deklaratiivsus  (SgP  >deklaratiivsus !11~09_S	et	f	\N
170155	deklaratiivsust	"deklaratiivsus %deklaratiivse  )US_aS  <deklaratiivne ;02_A	et	f	\N
170187	tegelevadki	tegelevadki =tegele  (IndPrPl3^  >tegelema !31~27_V	et	f	\N
170188	tegelevadki	tegelevadki =tegeleva  (PlN^  >tegelev !02_A	et	f	\N
170189	tegelevadki	"tegelev %tegele  )V_vA^  <tegelema ;27_V	et	f	\N
170190	tegelevadki	"tegelev %tegele  )V_vA^  <tegelema ;31_V	et	f	\N
170199	tahistada	?tahistada =tahista  (Inf  >tahistama !27_V	et	f	\N
170208	tüdrukutel	tüdrukutel =tüdruku  (PlAd  >tüdruk !02_S	et	f	\N
170210	tüdrukutel	tüdrukutel =ute  (SgAd  >tüdruk+utt !22_S	et	f	\N
170212	tüdrukutel	tüdrukutel =ute  (PlAd  >tüdruk+utt !22_S	et	f	\N
170218	moodsalt	moodsalt =moodsa  (SgAbl  >moodne !02_A	et	f	\N
170219	moodsalt	moodsalt =moodsalt  (ID  >moodsalt !41_D	et	f	\N
170220	moodsalt	"moodsalt %moodsa  )LT_mD  <moodne ;02_A	et	f	\N
170221	koolivormiga	koolivormiga =iga  (SgN  >kooli+vorm+iga !18_S	et	f	\N
170222	koolivormiga	koolivormiga =iga  (SgP  >kooli+vorm+iga !18_S	et	f	\N
170223	koolivormiga	koolivormiga =vormi  (SgKom  >kooli+vorm !22_S	et	f	\N
170252	norras	?norras =norra  (IndIpfSg3  >norrama !29_V	et	f	\N
170253	norras	?norras =norras  (SgN  >norras !07_S	et	f	\N
170276	viiga	?viiga =vii  (SgKom  >vii !26_S	et	f	\N
170277	viiga	?viiga =viiga  (SgN  >viiga !16_S	et	f	\N
170278	viiga	?viiga =viiga  (SgG  >viiga !16_S	et	f	\N
170279	viiga	?viiga =viiga  (IndPrPs_  >viigama !29_V	et	f	\N
170280	viiga	?viiga =viiga  (ImpPrSg2  >viigama !29_V	et	f	\N
170282	eiffeli	?eiffeli =eiffeli  (ID  >eiffeli !41_D	et	f	\N
170283	eiffeli	?eiffeli =eiffeli  (SgG  >eiffel !02_S	et	f	\N
170284	eiffeli	?eiffeli =ffeli  (SgN  >ei+ffeli !17_S	et	f	\N
170285	eiffeli	?eiffeli =ffeli  (SgG  >ei+ffeli !17_S	et	f	\N
170286	eiffeli	?eiffeli =ffeli  (SgP  >ei+ffeli !17_S	et	f	\N
170300	sõbrannamees	sõbrannamees =mee  (SgIn  >sõbranna+mesi !15_S	et	f	\N
170301	sõbrannamees	sõbrannamees =mees  (SgN  >sõbranna+mees !13_S	et	f	\N
170302	jõukas	jõukas =jõuka  (SgIn  >jõukas !02_A	et	f	\N
170303	jõukas	jõukas =jõukas  (SgN  >jõukas !02_A	et	f	\N
170309	kodutu	kodutu =kodutu  (SgN  >kodutu !01_AS	et	f	\N
170310	kodutu	"kodutu %kodu  )TU2_kA  <kodu ;17_S	et	f	\N
170311	kodutu	kodutu =kodutu  (SgG  >kodutu !01_AS	et	f	\N
170331	looja	looja =looja  (ID  >looja !41_D	et	f	\N
170332	looja	"looja %loo  )JA_vS  <looma ;38_V	et	f	\N
170333	looja	looja =looja  (SgN  >looja !01_S	et	f	\N
170334	looja	looja =looja  (SgG  >looja !01_S	et	f	\N
170337	eikellgiks	?eikellgiks =eikellgi  (SgTr  >eikellg !02_S	et	f	\N
170338	eikellgiks	?eikellgiks =eikellgi  (KndPrPs  >eikellgima !28_V	et	f	\N
170339	eikellgiks	?eikellgiks =kellgi  (SgTr  >ei+kellgi !01_S	et	f	\N
170340	eikellgiks	?eikellgiks =kellgi  (SgTr  >ei+kellg !22_S	et	f	\N
170344	raskematele	raskematele =raskema  (PlAll  >raskem !02_A	et	f	\N
170346	raskematele	"raskem %raske  )M_cA  <raske ;01_A	et	f	\N
170347	raskematele	raskematele =mate  (SgAll  >raske+mate !16_S	et	f	\N
170348	raskematele	raskematele =mate  (PlAll  >raske+matt !22_SA	et	f	\N
170349	otsimisel	otsimisel =otsimise  (SgAd  >otsimine !12_S	et	f	\N
170350	otsimisel	"otsimine %otsi  )MINE_vS  <otsima ;28_V	et	f	\N
170355	kavalust	kavalust =kavalus  (SgP  >kavalus !11_S	et	f	\N
170356	kavalust	"kavalus %kavala  )US_aS  <kaval ;02_A	et	f	\N
170357	kavalust	kavalust =us  (SgP  >kaval+uks !14_S	et	f	\N
170358	kavalust	kavalust =lust  (SgN  >kava+lust !22_S	et	f	\N
170366	viit	viit =vii  (SgP  >viis !14_N	et	f	\N
170367	viit	viit =viit  (SgN  >viit !22_S	et	f	\N
170368	sagedasemate	sagedasemate =sagedasema  (PlG  >sagedasem !02_A	et	f	\N
170369	sagedasemate	"sagedasem %sagedase  )M_cA  <sagedane ;12_A	et	f	\N
170385	põhjus-	põhjus- =põhju  (PlIn  >põhi !24_S	et	f	\N
170386	põhjus-	põhjus- =põhjus  (SgN  >põhjus !11~09_S	et	f	\N
170387	äe	?äe =äe  (SgN  >äe !26_S	et	f	\N
170388	äe	?äe =äe  (SgG  >äe !26_S	et	f	\N
170135	hirmutavast	"hirmu+tavane %tava  )NE_aA  <hirmu+tava ;17_S	et	f	\N
170138	arendus	arendus =arendus  (SgN  >arendus !11_S	et	f	\N
170139	arendus	"arendus %arenda  )US_vS  <arendama ;27_V	et	f	\N
170150	lünklikkust	lünklikkust =lünklikkus  (SgP  >lünklikkus !11~09_S	et	f	\N
170151	lünklikkust	"lünklikkus %lünklikku  )US_aS  <lünklik ;25_A	et	f	\N
170169	tüliti	?tüliti =tüli  (IndIpfIps  >tülima !27_V	et	f	\N
170170	tüliti	?tüliti =tüliti  (ID  >tüliti !41_D	et	f	\N
170171	tüliti	?tüliti =tüliti  (SgG  >tülit !02_S	et	f	\N
170172	tüliti	?tüliti =tüliti  (SgG  >tülitt !22_S	et	f	\N
170173	tüliti	?tüliti =tüliti  (IndPrPs_  >tülittima !28_V	et	f	\N
170174	tüliti	?tüliti =tüliti  (ImpPrSg2  >tülittima !28_V	et	f	\N
170175	kaasnähtusest	kaasnähtusest =nähtuse  (SgEl  >kaas+nähtus !11~09_S	et	f	\N
170176	kaasnähtusest	kaasnähtusest =nähtuses  (SgP  >kaas+nähtusene !12_A	et	f	\N
170177	kaasnähtusest	"kaas+nähtusene %nähtuse  )NE_aA  <kaas+nähtus ;09_S	et	f	\N
170178	kaasnähtusest	"kaas+nähtusene %nähtuse  )NE_aA  <kaas+nähtus ;11_S	et	f	\N
170191	puutunud	puutunud =puutu  (PtsPtPs  >puutuma !27_V	et	f	\N
170192	puutunud	puutunud =puutunu  (PlN  >puutunu !01_S	et	f	\N
170193	puutunud	"puutunu %puutu  )NU_vS  <puutuma ;27_V	et	f	\N
170194	puutunud	puutunud =puutunud  (ID  >puutunud !41_A	et	f	\N
170195	puutunud	"puutunud %puutu  )NUD_vA  <puutuma ;27_V	et	f	\N
170254	helena	### helena	et	f	\N
170255	vanalinnast	vanalinnast =ast  (SgN  >vana+linn+ast !22_S	et	f	\N
170256	vanalinnast	vanalinnast =linna  (SgEl  >vana+linn !22_S	et	f	\N
170257	vanalinnast	vanalinnast =linnas  (SgP  >vana+linnas !09_S	et	f	\N
170258	vanalinnast	vanalinnast =linnas  (SgP  >vana+linnane !10_A	et	f	\N
170259	vanalinnast	"vana+linnane %linna  )NE_aA  <vana+linn ;22_S	et	f	\N
170266	läheduse	läheduse =läheduse  (SgG  >lähedus !11_S	et	f	\N
170267	läheduse	"lähedus %läheda  )US_aS  <läheda ;02_A	et	f	\N
170268	küljem	?küljem =küljem  (SgN  >küljem !02_A	et	f	\N
170269	koolivahetusel	koolivahetusel =use  (PlAd  >kooli+vahet+usk !22_S	et	f	\N
170270	koolivahetusel	koolivahetusel =vahetuse  (SgAd  >kooli+vahetus !11_S	et	f	\N
170271	koolivahetusel	"kooli+vahetus %vahe  )TUS2_aS  <kooli+vahe ;16_S	et	f	\N
170274	kalliss	?kalliss =kalliss  (SgN  >kalliss !22_S	et	f	\N
170316	propogerivad	?propogerivad =propogeriva  (PlN  >propogeriv !02_A	et	f	\N
170317	propogerivad	?propogerivad =propogeriva  (PlN  >propogeriva !16_S	et	f	\N
170321	keeltte	?keeltte =keeltte  (SgN  >keeltte !06_S	et	f	\N
170322	keeltte	?keeltte =keeltte  (SgG  >keeltte !06_S	et	f	\N
170323	keeltte	?keeltte =keeltte  (PlP  >keeltt !22_S	et	f	\N
170324	keeltte	?keeltte =keeltte  (IndPrPs_  >keelttema !27_V	et	f	\N
170325	keeltte	?keeltte =keeltte  (ImpPrSg2  >keelttema !27_V	et	f	\N
170341	tavaliseks	tavaliseks =tavalise  (SgTr  >tavaline !12_A	et	f	\N
170342	tavaliseks	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
170360	tegelt	?tegelt =tege  (SgAbl  >tege !16_S	et	f	\N
170361	tegelt	?tegelt =tegelt  (ID  >tegelt !41_D	et	f	\N
170376	elgulinna	?elgulinna =elgulinna  (SgN  >elgulinna !16_S	et	f	\N
170377	elgulinna	?elgulinna =elgulinna  (SgG  >elgulinna !16_S	et	f	\N
170382	hääldamise	hääldamise =hääldamise  (SgG  >hääldamine !12_S	et	f	\N
170383	hääldamise	"hääldamine %häälda  )MINE_vS  <hääldama ;27_V	et	f	\N
170384	lasnam	?lasnam =lasnam  (SgN  >lasnam !02_A	et	f	\N
170401	tütrest	tütrest =tütre  (SgEl  >tütar !08_S	et	f	\N
170402	tütrest	tütrest =tütres  (SgP  >tütrene !12~10_A	et	f	\N
170403	tütrest	"tütrene %tütre  )NE_aA  <tütar ;08_S	et	f	\N
170427	ruumilisi	ruumilisi =ruumilisi  (PlP  >ruumiline !12_A	et	f	\N
170428	ruumilisi	"ruumiline %ruumi  )LINE_aA  <ruum ;22_S	et	f	\N
170434	valjendamiseks	valjendamiseks =valjendamise  (SgTr  >valjendamine !12_S	et	f	\N
170435	valjendamiseks	"valjendamine %valjenda  )MINE_vS  <valjendama ;27_V	et	f	\N
170436	illatiivi	illatiivi =illatiivi  (SgG  >illatiiv !22_S	et	f	\N
170437	illatiivi	illatiivi =illatiivi  (SgP  >illatiiv !22_S	et	f	\N
170438	illatiivi	illatiivi =illatiivi  (SgAdt  >illatiiv !22_S	et	f	\N
170463	lõkkesse	lõkkesse =lõkke  (SgIll  >lõke !06_S	et	f	\N
170464	lõkkesse	lõkkesse =lõkkes  (SgAdt  >lõkkene !12_A	et	f	\N
170465	lõkkesse	"lõkkene %lõkke  )NE_aA  <lõke ;06_S	et	f	\N
170466	õudesse	?õudesse =õudesse  (SgG  >õudesne !02_A	et	f	\N
170467	õudesse	?õudesse =õudesse  (PlP  >õudess !22_S	et	f	\N
170487	pesesse60	?pesesse =pese  (SgIll  >pese !16_S	et	f	\N
170488	pesesse60	?pesesse =pesesse  (SgG  >pesesne !02_A	et	f	\N
170489	pesesse60	?pesesse =pesesse  (PlP  >pesess !22_S	et	f	\N
170499	tütrast	?tütrast =tütras  (SgP  >tütras !07_S	et	f	\N
170500	tütrast	?tütrast =tütras  (SgP  >tütrane !12~10_A	et	f	\N
170506	käänetetähendused	?käänetetähendused =käänetetähenduse  (PlN  >käänetetähendus !11_S	et	f	\N
170543	kahekes	?kahekes =kaheke  (PlIn  >kahekk !22_S	et	f	\N
170569	sea	sea =sea  (SgG  >siga !18_SA	et	f	\N
170570	sea	sea =sea  (IndPrPs_  >seadma !34_V	et	f	\N
170571	sea	sea =sea  (ImpPrSg2  >seadma !34_V	et	f	\N
170599	uju	uju =uju  (SgN  >uju !17_S	et	f	\N
170600	uju	uju =uju  (SgG  >uju !17_S	et	f	\N
170227	koolilaste	"kool+ilane %ila  )NE_aA  <kool+ila ;17_S	et	f	\N
170228	aktiivsus	aktiivsus =aktiivsus  (SgN  >aktiivsus !11~09_S	et	f	\N
170229	aktiivsus	"aktiivsus %aktiivse  )US_aS  <aktiivne ;02_A	et	f	\N
170240	mästmine	?mästmine =mästmine  (SgN  >mästmine !12?10_S	et	f	\N
170241	mästmine	?mästmine =mästmine  (IndPrPs_  >mästminema !27_V	et	f	\N
170242	mästmine	?mästmine =mästmine  (ImpPrSg2  >mästminema !27_V	et	f	\N
170243	toetusest	toetusest =toetuse  (SgEl  >toetus !11~09_S	et	f	\N
170244	toetusest	"toetus %toeta  )US_vS  <toetama ;27_V	et	f	\N
170245	toetusest	"toetus %toe  )TUS2_aS  <tugi ;21_S	et	f	\N
170246	toetusest	toetusest =toetuses  (SgP  >toetusene !12_A	et	f	\N
170247	toetusest	"toetusene %toetuse  )NE_aA  <toetus ;09_S	et	f	\N
170248	toetusest	"toetusene %toetuse  )NE_aA  <toetus ;11_S	et	f	\N
170249	sõbrannast	sõbrannast =sõbranna  (SgEl  >sõbranna !16_S	et	f	\N
170250	sõbrannast	sõbrannast =sõbrannas  (SgP  >sõbrannane !12_A	et	f	\N
170251	sõbrannast	"sõbrannane %sõbranna  )NE_aA  <sõbranna ;16_S	et	f	\N
170260	rangem	rangem =rangem  (SgN  >rangem !02_A	et	f	\N
170261	rangem	"rangem %range  )M_cA  <range ;01_A	et	f	\N
170272	tervitusi	tervitusi =tervitusi  (PlP  >tervitus !11_S	et	f	\N
170273	tervitusi	"tervitus %tervita  )US_vS  <tervitama ;27_V	et	f	\N
170281	elimesel	?elimesel =elimese  (SgAd  >elimene !12_A	et	f	\N
170293	kolivahe	kolivahe =vahe  (SgN  >koli+vahe !02_A	et	f	\N
170294	kolivahe	kolivahe =vahe  (SgN  >koli+vahe !16_S	et	f	\N
170295	kolivahe	kolivahe =vahe  (SgG  >koli+vahe !16_S	et	f	\N
170307	tuttaialt	tuttaialt =aia  (SgAbl  >tutt+aed !22_S	et	f	\N
170308	tuttaialt	tuttaialt =aia  (SgAbl  >tutt+ai !22_S	et	f	\N
170312	ülikooliharidust	ülikooliharidust =dust  (SgN  >üli+kooli+hari+dust !22_S	et	f	\N
170313	ülikooliharidust	ülikooliharidust =haridus  (SgP  >üli+kooli+haridus !11_S	et	f	\N
170318	leitmine	?leitmine =leitmine  (SgN  >leitmine !12?10_S	et	f	\N
170319	leitmine	?leitmine =leitmine  (IndPrPs_  >leitminema !27_V	et	f	\N
170320	leitmine	?leitmine =leitmine  (ImpPrSg2  >leitminema !27_V	et	f	\N
170326	valdamist	valdamist =valdamis  (SgP  >valdamine !12_S	et	f	\N
170327	valdamist	"valdamine %valda  )MINE_vS  <valdama ;29_V	et	f	\N
170335	targemaiks	targemaiks =targema  (PlTr  >targem !02_A	et	f	\N
170336	targemaiks	"targem %targe  )M_cA  <tark ;22_AS	et	f	\N
170343	male	male =male  (SgN  >male !16_S	et	f	\N
170345	male	male =male  (SgG  >male !16_S	et	f	\N
170351	resursiks	?resursiks =resursi  (SgTr  >resursi !01_S	et	f	\N
170352	resursiks	?resursiks =resursi  (SgTr  >resurs !02_S	et	f	\N
170353	resursiks	?resursiks =resursi  (SgTr  >resurss !22_S	et	f	\N
170354	resursiks	?resursiks =resursi  (KndPrPs  >resurssima !28_V	et	f	\N
170378	oonis	?oonis =ooni  (SgIn  >ooni !16_S	et	f	\N
170379	oonis	?oonis =ooni  (SgIn  >oon !22_S	et	f	\N
170380	oonis	?oonis =ooni  (IndIpfSg3  >oonima !28_V	et	f	\N
170381	oonis	?oonis =oonis  (SgN  >oonis !09_S	et	f	\N
170394	hak	### hak	et	f	\N
170395	suh	?suh =suh  (ID  >suh !41_I	et	f	\N
170396	tle	### tle	et	f	\N
170397	kolmekorruseli	?kolmekorruseli =korruseli  (SgG  >kolme+korrusel !19_S	et	f	\N
170398	kolmekorruseli	?kolmekorruseli =korruseli  (SgP  >kolme+korrusel !19_S	et	f	\N
170399	kolmekorruseli	?kolmekorruseli =korruseli  (SgAdt  >kolme+korrusel !19_S	et	f	\N
170400	tütr	?tütr =tütr  (SgN  >tütr !22_S	et	f	\N
170404	kul	### kul	et	f	\N
170410	0m	### 0m	et	f	\N
170419	mnimvene	?mnimvene =mnimvene  (SgN  >mnimvene !10_A	et	f	\N
170420	mnimvene	?mnimvene =mnimvene  (IndPrPs_  >mnimvenema !27_V	et	f	\N
170422	mnimvene	?mnimvene =mnimvene  (ImpPrSg2  >mnimvenema !27_V	et	f	\N
170439	raskemateks	raskemateks =raskema  (PlTr  >raskem !02_A	et	f	\N
170440	raskemateks	"raskem %raske  )M_cA  <raske ;01_A	et	f	\N
170441	raskemateks	raskemateks =mate  (SgTr  >raske+mate !16_S	et	f	\N
170442	raskemateks	raskemateks =mate  (PlTr  >raske+matt !22_SA	et	f	\N
170459	tundisse	?tundisse =tundi  (SgIll  >tundi !16_S	et	f	\N
170460	tundisse	?tundisse =tundi  (SgIll  >tunt !22_S	et	f	\N
170461	tundisse	?tundisse =tundisse  (SgG  >tundisne !02_A	et	f	\N
170462	tundisse	?tundisse =tundisse  (PlP  >tundiss !22_S	et	f	\N
170470	märkmikku	märkmikku =märkmikku  (SgP  >märkmik !25_S	et	f	\N
170471	märkmikku	märkmikku =märkmikku  (SgAdt  >märkmik !25_S	et	f	\N
170472	märkmikku	märkmikku =mikku  (SgP  >märk+mikk !22_S	et	f	\N
170473	märkmikku	märkmikku =mikku  (SgAdt  >märk+mikk !22_S	et	f	\N
170490	kinnasse	?kinnasse =kinna  (SgIll  >kinna !16_S	et	f	\N
170491	kinnasse	?kinnasse =kinnasse  (SgG  >kinnasne !02_A	et	f	\N
170492	kinnasse	?kinnasse =kinnasse  (PlP  >kinnass !22_S	et	f	\N
170510	abessiivi	abessiivi =abessiivi  (SgG  >abessiiv !22_S	et	f	\N
170511	abessiivi	abessiivi =abessiivi  (SgP  >abessiiv !22_S	et	f	\N
170512	abessiivi	abessiivi =abessiivi  (SgAdt  >abessiiv !22_S	et	f	\N
170517	kakskümmen	?kakskümmen =kakskümmen  (SgN  >kakskümmen !19_S	et	f	\N
170518	kakskümmen	?kakskümmen =kümmen  (SgN  >kaks+kümmen !02_S	et	f	\N
170550	lähedte	?lähedte =lähedte  (PlP  >lähedt !22_S	et	f	\N
170559	õnni	õnni =õnni  (SgG  >õnn !22_S	et	f	\N
170298	sõbrades	?sõbrades =sõbra  (PlIn  >sõbra !16_S	et	f	\N
170299	sõbrades	?sõbrades =sõbra  (Ger  >sõbrama !27_V	et	f	\N
170304	ärimees	ärimees =mee  (SgIn  >äri+mesi !15_S	et	f	\N
170305	ärimees	ärimees =mees  (SgN  >äri+mees !13_S	et	f	\N
170314	savad	?savad =sava  (PlN  >sava !17_S	et	f	\N
170315	savad	?savad =sava  (IndPrSg2  >savama !27_V	et	f	\N
170359	aristootel	?aristootel =aristoote  (SgAd  >aristoote !16_S	et	f	\N
170391	vaneid	?vaneid =vanei  (PlN  >vanei !26_S	et	f	\N
170392	vaneid	?vaneid =vanei  (SgP  >vanei !26_S	et	f	\N
170393	vaneid	?vaneid =vaneid  (SgN  >vaneid !22_S	et	f	\N
170418	tapeedid	tapeedid =tapeedi  (PlN  >tapeet !22_S	et	f	\N
170421	tapeedid	tapeedid =tapeedi  (IndPrSg2  >tapeetima !28_V	et	f	\N
170424	nete	?nete =nete  (SgN  >nete !06_S	et	f	\N
170425	nete	?nete =nete  (IndPrPs_  >netema !27_V	et	f	\N
170426	nete	?nete =nete  (ImpPrSg2  >netema !27_V	et	f	\N
170430	alatiiv	?alatiiv =alatiiv  (SgN  >alatiiv !22_S	et	f	\N
170431	alatiiv	?alatiiv =tiiv  (SgN  >ala+tiiv !22_S	et	f	\N
170445	rohkearvuliste	rohkearvuliste =arvulis  (PlG  >rohke+arvuline !12_A	et	f	\N
170446	rohkearvuliste	"rohke+arvuline %arvu  )LINE_aA  <rohke+arv ;22_S	et	f	\N
170495	pirukases	pirukases =pirukase  (SgIn  >pirukane !12_A	et	f	\N
170496	pirukases	"pirukane %piruka  )NE_aA  <pirukas ;02_S	et	f	\N
170497	pirukas	pirukas =piruka  (SgIn  >pirukas !02_S	et	f	\N
170498	pirukas	pirukas =pirukas  (SgN  >pirukas !02_S	et	f	\N
170502	kinnost	?kinnost =kinno  (SgEl  >kinno !16_S	et	f	\N
170503	kinnost	?kinnost =kinnos  (SgP  >kinnos !11~09_S	et	f	\N
170527	sed	### sed	et	f	\N
170528	1amp	?amp =amp  (SgN  >amp !22_S	et	f	\N
170530	mkaasaütl	?mkaasaütl =mkaasaütl  (SgN  >mkaasaütl !22_S	et	f	\N
170531	pronoomenivigu	?pronoomenivigu =pronoomenivigu  (IndPrPs_  >pronoomeniviguma !27_V	et	f	\N
170532	pronoomenivigu	?pronoomenivigu =pronoomenivigu  (ImpPrSg2  >pronoomeniviguma !27_V	et	f	\N
170534	esinevatest	esinevatest =esineva  (PlEl  >esinev !02_A	et	f	\N
170535	esinevatest	"esinev %esine  )V_vA  <esinema ;27_V	et	f	\N
170553	mä	### mä	et	f	\N
170554	elda	?elda =elda  (SgN  >elda !16_S	et	f	\N
170555	elda	?elda =elda  (SgG  >elda !16_S	et	f	\N
170556	elda	?elda =elda  (IndPrPs_  >eldama !29_V	et	f	\N
170557	elda	?elda =elda  (ImpPrSg2  >eldama !29_V	et	f	\N
170558	remon	?remon =remon  (SgN  >remon !02_S	et	f	\N
170562	del	### del	et	f	\N
170567	seata	seata =sea  (SgAb  >siga !18_SA	et	f	\N
170568	seata	seata =sea  (IndPrIps_  >seadma !34_V	et	f	\N
170583	äalja	?äalja =äalja  (SgN  >äalja !01_S	et	f	\N
170584	äalja	?äalja =äalja  (SgG  >äalja !01_S	et	f	\N
170585	äalja	?äalja =äalja  (SgG  >äaljas !02_A	et	f	\N
170586	äalja	?äalja =äalja  (IndPrPs_  >äaljama !29_V	et	f	\N
170587	äalja	?äalja =äalja  (ImpPrSg2  >äaljama !29_V	et	f	\N
170588	võtada	?võtada =võta  (Inf  >võtama !27_V	et	f	\N
170589	õnnidelda	?õnnidelda =õnnidelda  (SgN  >õnnidelda !16_S	et	f	\N
170590	õnnidelda	?õnnidelda =õnnidelda  (SgG  >õnnidelda !16_S	et	f	\N
170591	õnnidelda	?õnnidelda =õnnidelda  (IndPrPs_  >õnnideldama !27_V	et	f	\N
170592	õnnidelda	?õnnidelda =õnnidelda  (ImpPrSg2  >õnnideldama !27_V	et	f	\N
170598	l3	### l3	et	f	\N
170604	korja	korja =korja  (IndPrPs_  >korjama !29_V	et	f	\N
170605	korja	korja =korja  (ImpPrSg2  >korjama !29_V	et	f	\N
170606	pese	pese =pese  (IndPrPs_  >pesema !36_V	et	f	\N
170607	pese	pese =pese  (ImpPrSg2  >pesema !36_V	et	f	\N
170608	täi	täi =täi  (SgN  >täi !26_S	et	f	\N
170609	täi	täi =täi  (SgG  >täi !26_S	et	f	\N
170610	täi	täi =täi  (IndPrPs_  >täima !27_V	et	f	\N
170611	täi	täi =täi  (ImpPrSg2  >täima !27_V	et	f	\N
170641	kabeltelevisioon	?kabeltelevisioon =kabeltelevisioon  (SgN  >kabeltelevisioon !22_S	et	f	\N
170666	suvalised	suvalised =suvalise  (PlN  >suvaline !12_A	et	f	\N
170667	suvalised	"suvaline %suva  )LINE_aA  <suva ;17_S	et	f	\N
170693	meeldivamat	meeldivamat =meeldivama  (SgP  >meeldivam !02_A	et	f	\N
170694	meeldivamat	"meeldivam %meeldi  )VAM_cA  <meeldima ;27_V	et	f	\N
170695	meeldivamat	"meeldivam %meeldiva  )M_cA  <meeldiv ;02_A	et	f	\N
170710	poesid	?poesid =poe  (PlP  >poe !26_S	et	f	\N
170711	poesid	?poesid =poesi  (PlN  >poesi !16_S	et	f	\N
170712	poesid	?poesid =poesi  (IndPrSg2  >poesima !28_V	et	f	\N
170713	peitunud	peitunud =peitu  (PtsPtPs  >peituma !27_V	et	f	\N
170714	peitunud	peitunud =peitunu  (PlN  >peitunu !01_S	et	f	\N
170715	peitunud	"peitunu %peitu  )NU_vS  <peituma ;27_V	et	f	\N
170716	peitunud	peitunud =peitunud  (ID  >peitunud !41_A	et	f	\N
170717	peitunud	"peitunud %peitu  )NUD_vA  <peituma ;27_V	et	f	\N
170761	nähtamatu	nähtamatu =nähtamatu  (SgN  >nähtamatu !01_AS	et	f	\N
170762	nähtamatu	"nähtamatu %näh  )TAMATU_vA  <nägema ;28_V	et	f	\N
170763	nähtamatu	nähtamatu =nähtamatu  (SgG  >nähtamatu !01_AS	et	f	\N
170776	ronnida	?ronnida =ronni  (Inf  >ronnima !28_V	et	f	\N
170795	jahtida	jahtida =jahti  (Inf  >jahtima !28_V	et	f	\N
170796	jahtida	jahtida =ida  (SgN  >jaht+ida !17_S	et	f	\N
170797	jahtida	jahtida =ida  (SgG  >jaht+ida !17_S	et	f	\N
170372	harjutustega	"harjutus %harju  )TUS1_aS  <harjuma ;27_V	et	f	\N
170373	hälbivate	hälbivate =hälbiva  (PlG  >hälbiv !02_A	et	f	\N
170374	hälbivate	"hälbiv %hälbi  )V_vA  <hälbima ;27_V	et	f	\N
170375	hälbivate	"hälbiv %hälbi  )V_vA  <hälbima ;28_V	et	f	\N
170405	keeleski	keeleski =keele  (SgIn^  >keel !13_S	et	f	\N
170406	keeleski	keeleski =keele  (PlIn^  >keeld !22_S	et	f	\N
170429	innessiiv	?innessiiv =innessiiv  (SgN  >innessiiv !22_S	et	f	\N
170432	ruumiliste	ruumiliste =ruumilis  (PlG  >ruumiline !12_A	et	f	\N
170433	ruumiliste	"ruumiline %ruumi  )LINE_aA  <ruum ;22_S	et	f	\N
170443	osutasid	osutasid =osuta  (IndIpfSg2  >osutama !27_V	et	f	\N
170444	osutasid	osutasid =osuta  (IndIpfPl3  >osutama !27_V	et	f	\N
170447	väljendamises	väljendamises =väljendamise  (SgIn  >väljendamine !12_S	et	f	\N
170448	väljendamises	"väljendamine %väljenda  )MINE_vS  <väljendama ;27_V	et	f	\N
170474	jaami	jaami =jaami  (SgG  >jaam !22_S	et	f	\N
170475	jaami	jaami =jaami  (SgP  >jaam !22_S	et	f	\N
170476	jaami	jaami =jaami  (SgAdt  >jaam !22_S	et	f	\N
170477	raekotta	raekotta =kotta  (SgP  >rae+kott !22_S	et	f	\N
170478	raekotta	raekotta =kotta  (SgAdt  >rae+koda !18_S	et	f	\N
170479	raekotta	raekotta =kotta  (SgAdt  >rae+kott !22_S	et	f	\N
170485	pestesa	?pestesa =pestesa  (SgN  >pestesa !01_S	et	f	\N
170486	pestesa	?pestesa =pestesa  (SgG  >pestesa !01_S	et	f	\N
170493	haiglases	haiglases =haiglase  (SgIn  >haiglane !12?10_A	et	f	\N
170494	haiglases	"haiglane %haigla  )NE_aA  <haigla ;01_S	et	f	\N
170513	lõunata	lõunata =lõuna  (SgAb  >lõuna !06_S	et	f	\N
170514	lõunata	lõunata =lõunata  (IndPrPs_  >lõunatama !27_V	et	f	\N
170515	lõunata	lõunata =lõunata  (ImpPrSg2  >lõunatama !27_V	et	f	\N
170516	lõunata	lõunata =nata  (SgG  >lõu+natt !22_S	et	f	\N
170529	radega	?radega =rade  (SgKom  >rade !16_S	et	f	\N
170536	mõ	### mõ	et	f	\N
170539	asesõna-	asesõna- =sõna  (SgN  >ase+sõna !17_S	et	f	\N
170541	asesõna-	asesõna- =sõna  (SgG  >ase+sõna !17_S	et	f	\N
170542	asesõna-	asesõna- =sõna  (SgP  >ase+sõna !17_S	et	f	\N
170544	ele	?ele =ele  (SgN  >ele !16_S	et	f	\N
170545	ele	?ele =ele  (SgG  >ele !16_S	et	f	\N
170546	ele	?ele =ele  (IndPrPs_  >elema !27_V	et	f	\N
170547	ele	?ele =ele  (ImpPrSg2  >elema !27_V	et	f	\N
170564	sea	sea =sea  (SgG  >siga !18_SA	et	f	\N
170565	sea	sea =sea  (IndPrPs_  >seadma !34_V	et	f	\N
170566	sea	sea =sea  (ImpPrSg2  >seadma !34_V	et	f	\N
170579	tõlkimise	tõlkimise =tõlkimise  (SgG  >tõlkimine !12_S	et	f	\N
170580	tõlkimise	"tõlkimine %tõlki  )MINE_vS  <tõlkima ;28_V	et	f	\N
170612	võt	### võt	et	f	\N
170628	kat	### kat	et	f	\N
170659	võileibi	võileibi =leibi  (SgP  >või+leib !22_S	et	f	\N
170660	võileibi	võileibi =leibi  (SgAdt  >või+leib !22_S	et	f	\N
170664	lastest	lastest =las  (PlEl  >laps !14_S	et	f	\N
170665	lastest	lastest =laste  (PlEl  >last !22_S	et	f	\N
170671	hobust	hobust =hobu  (SgEl  >hobu !17_S	et	f	\N
170672	hobust	hobust =hobus  (SgP  >hobune !10_S	et	f	\N
170673	hobust	"hobune %hobu  )NE_aA  <hobu ;17_S	et	f	\N
170674	ratsuta	ratsuta =ratsu  (SgAb  >ratsu !16_S	et	f	\N
170675	ratsuta	ratsuta =ratsuta  (IndPrPs_  >ratsutama !27_V	et	f	\N
170676	ratsuta	ratsuta =ratsuta  (ImpPrSg2  >ratsutama !27_V	et	f	\N
170718	teisid	?teisid =tei  (PlP  >tei !26_S	et	f	\N
170719	teisid	?teisid =teisi  (PlN  >teisi !16_S	et	f	\N
170720	teisid	?teisid =teisi  (PlN  >teis !22_S	et	f	\N
170721	teisid	?teisid =teisi  (IndPrSg2  >teisima !28_V	et	f	\N
170724	tahaksinud	?tahaksinud =tahaksi  (PtsPtPs  >tahaksima !28_V	et	f	\N
170725	tahaksinud	?tahaksinud =tahaksinu  (PlN  >tahaksinu !01_S	et	f	\N
170726	tahaksinud	?tahaksinud =tahaksinu  (IndPrSg2  >tahaksinuma !27_V	et	f	\N
170727	tahaksinud	?tahaksinud =tahaksinud  (ID  >tahaksinud !41_A	et	f	\N
170728	tahaksinud	?tahaksinud =ksinu  (PlN  >taha+ksinu !17_S	et	f	\N
170754	joonistavad	joonistavad =joonista  (IndPrPl3  >joonistama !27_V	et	f	\N
170755	joonistavad	joonistavad =joonistava  (PlN  >joonistav !02_A	et	f	\N
170756	joonistavad	"joonistav %joonista  )V_vA  <joonistama ;27_V	et	f	\N
170757	joonistavad	joonistavad =tava  (PlN  >joonis+tava !17_S	et	f	\N
170758	hüppavad	hüppavad =hüppa  (IndPrPl3  >hüppama !29_V	et	f	\N
170759	hüppavad	hüppavad =hüppava  (PlN  >hüppav !02_A	et	f	\N
170760	hüppavad	"hüppav %hüppa  )V_vA  <hüppama ;29_V	et	f	\N
170777	korvi	korvi =korvi  (SgG  >korv !22_S	et	f	\N
170778	korvi	korvi =korvi  (SgP  >korv !22_S	et	f	\N
170779	korvi	korvi =korvi  (SgAdt  >korv !22_S	et	f	\N
170785	valvamisega	valvamisega =valvamise  (SgKom  >valvamine !12_S	et	f	\N
170786	valvamisega	"valvamine %valva  )MINE_vS  <valvama ;29_V	et	f	\N
170815	haukub	### haukub	et	f	\N
170816	piknikku	?piknikku =piknikku  (SgN  >piknikku !01_S	et	f	\N
170817	piknikku	?piknikku =piknikku  (SgG  >piknikku !01_S	et	f	\N
170818	piknikku	?piknikku =piknikku  (IndPrPs_  >piknikkuma !27_V	et	f	\N
170819	piknikku	?piknikku =piknikku  (ImpPrSg2  >piknikkuma !27_V	et	f	\N
170820	eredalt	eredalt =ereda  (SgAbl  >ere !02_A	et	f	\N
170389	vanituba	?vanituba =vanituba  (SgN  >vanituba !16_S	et	f	\N
170390	vanituba	?vanituba =vanituba  (SgG  >vanituba !16_S	et	f	\N
170407	omvene	?omvene =omvene  (SgN  >omvene !10_A	et	f	\N
170408	omvene	?omvene =omvene  (IndPrPs_  >omvenema !27_V	et	f	\N
170409	omvene	?omvene =omvene  (ImpPrSg2  >omvenema !27_V	et	f	\N
170411	vannitubaos	?vannitubaos =vannitubao  (SgIn  >vannitubao !26_S	et	f	\N
170412	vannitubaos	?vannitubaos =vannitubaos  (SgN  >vannitubaos !22_S	et	f	\N
170413	vannitubaos	?vannitubaos =tubao  (SgIn  >vanni+tubao !26_S	et	f	\N
170414	vannitubaos	?vannitubaos =tubaos  (SgN  >vanni+tubaos !22_S	et	f	\N
170415	mosvene	?mosvene =mosvene  (SgN  >mosvene !10_A	et	f	\N
170416	mosvene	?mosvene =mosvene  (IndPrPs_  >mosvenema !27_V	et	f	\N
170417	mosvene	?mosvene =mosvene  (ImpPrSg2  >mosvenema !27_V	et	f	\N
170423	kohak	?kohak =kohak  (SgN  >kohak !02_S	et	f	\N
170449	innessiivi	?innessiivi =innessiivi  (SgN  >innessiivi !16_S	et	f	\N
170450	innessiivi	?innessiivi =innessiivi  (SgG  >innessiivi !16_S	et	f	\N
170451	innessiivi	?innessiivi =innessiivi  (SgG  >innessiiv !22_S	et	f	\N
170452	innessiivi	?innessiivi =innessiivi  (SgP  >innessiiv !22_S	et	f	\N
170453	innessiivi	?innessiivi =innessiivi  (SgAdt  >innessiiv !22_S	et	f	\N
170454	innessiivi	?innessiivi =innessiivi  (IndPrPs_  >innessiivima !28_V	et	f	\N
170455	innessiivi	?innessiivi =innessiivi  (ImpPrSg2  >innessiivima !28_V	et	f	\N
170456	elatiivi	elatiivi =elatiivi  (SgG  >elatiiv !22_S	et	f	\N
170457	elatiivi	elatiivi =elatiivi  (SgP  >elatiiv !22_S	et	f	\N
170458	elatiivi	elatiivi =elatiivi  (SgAdt  >elatiiv !22_S	et	f	\N
170468	märkmiku	märkmiku =märkmiku  (SgG  >märkmik !25_S	et	f	\N
170469	märkmiku	märkmiku =miku  (SgG  >märk+mikk !22_S	et	f	\N
170480	veete	?veete =veete  (SgN  >veete !06_S	et	f	\N
170481	veete	?veete =veete  (SgG  >veede !06_S	et	f	\N
170482	veete	?veete =veete  (PlP  >veet !22_S	et	f	\N
170483	veete	?veete =veete  (IndPrPs_  >veetema !27_V	et	f	\N
170484	veete	?veete =veete  (ImpPrSg2  >veetema !27_V	et	f	\N
170501	tehasest	tehasest =tehase  (SgEl  >tehas !09_S	et	f	\N
170504	tehasest	tehasest =tehases  (SgP  >tehasene !12_A	et	f	\N
170505	tehasest	"tehasene %tehase  )NE_aA  <tehas ;09_S	et	f	\N
170507	terminatiivi	terminatiivi =terminatiivi  (SgG  >terminatiiv !22_S	et	f	\N
170508	terminatiivi	terminatiivi =terminatiivi  (SgP  >terminatiiv !22_S	et	f	\N
170509	terminatiivi	terminatiivi =terminatiivi  (SgAdt  >terminatiiv !22_S	et	f	\N
170519	alias	?alias =alia  (SgIn  >alia !01_S	et	f	\N
170520	alias	?alias =alias  (SgN  >alias !11_S	et	f	\N
170521	arid	?arid =ari  (PlN  >ari !17_S	et	f	\N
170522	arid	?arid =ari  (IndPrSg2  >arima !27_V	et	f	\N
170523	mugavu	?mugavu =mugavu  (SgN  >mugavu !01_S	et	f	\N
170524	mugavu	?mugavu =mugavu  (SgG  >mugavu !01_S	et	f	\N
170525	mugavu	?mugavu =mugavu  (IndPrPs_  >mugavuma !27_V	et	f	\N
170526	mugavu	?mugavu =mugavu  (ImpPrSg2  >mugavuma !27_V	et	f	\N
170533	ldse	### ldse	et	f	\N
170537	enesekohane	enesekohane =kohane  (SgN  >enese+kohane !10_A	et	f	\N
170538	enesekohane	"enese+kohane %koha  )NE_aA  <enese+koha ;17_S	et	f	\N
170540	enesekohane	"enese+kohane %koha  )NE_aA  <enese+koht ;22_S	et	f	\N
170548	hajameelsus	hajameelsus =meelsus  (SgN  >haja+meelsus !11~09_S	et	f	\N
170549	hajameelsus	"haja+meelsus %meelse  )US_aS  <haja+meelne ;02_A	et	f	\N
170551	pilaste	pilaste =pilas  (PlG  >pilane !10_A	et	f	\N
170552	pilaste	"pilane %pila  )NE_aA  <pila ;17_S	et	f	\N
170572	infinitiivivormi	?infinitiivivormi =infinitiivivormi  (SgG  >infinitiivivorm !22_S	et	f	\N
170573	infinitiivivormi	?infinitiivivormi =infinitiivivormi  (SgP  >infinitiivivorm !22_S	et	f	\N
170574	infinitiivivormi	?infinitiivivormi =infinitiivivormi  (SgAdt  >infinitiivivorm !22_S	et	f	\N
170575	infinitiivivormi	?infinitiivivormi =infinitiivivormi  (IndPrPs_  >infinitiivivormima !28_V	et	f	\N
170576	infinitiivivormi	?infinitiivivormi =infinitiivivormi  (ImpPrSg2  >infinitiivivormima !28_V	et	f	\N
170577	rääkivatel	rääkivatel =rääkiva  (PlAd  >rääkiv !02_A	et	f	\N
170578	rääkivatel	"rääkiv %rääki  )V_vA  <rääkima ;28_V	et	f	\N
170581	suhtlemisel	suhtlemisel =suhtlemise  (SgAd  >suhtlemine !12_S	et	f	\N
170582	suhtlemisel	"suhtlemine %suhtle  )MINE_vS  <suhtlema ;30_V	et	f	\N
170595	päevita	päevita =päevi  (SgAb  >päev !22_S	et	f	\N
170596	päevita	päevita =päevita  (IndPrPs_  >päevitama !27_V	et	f	\N
170597	päevita	päevita =päevita  (ImpPrSg2  >päevitama !27_V	et	f	\N
170613	õppi	õppi =õppi  (SgP  >õpp !22_S	et	f	\N
170614	õppi	õppi =õppi  (SgAdt  >õpp !22_S	et	f	\N
170615	data	?data =data  (SgN  >data !16_S	et	f	\N
170616	data	?data =data  (SgG  >data !16_S	et	f	\N
170617	data	?data =data  (IndPrPs_  >datama !27_V	et	f	\N
170618	data	?data =data  (ImpPrSg2  >datama !27_V	et	f	\N
170629	delda	?delda =delda  (SgN  >delda !16_S	et	f	\N
170630	delda	?delda =delda  (SgG  >delda !16_S	et	f	\N
170631	delda	?delda =delda  (IndPrPs_  >deldama !29_V	et	f	\N
170632	delda	?delda =delda  (ImpPrSg2  >deldama !29_V	et	f	\N
170639	tervitustega	tervitustega =tervitus  (PlKom  >tervitus !11_S	et	f	\N
170640	tervitustega	"tervitus %tervita  )US_vS  <tervitama ;27_V	et	f	\N
170646	haapsalus	?haapsalus =haapsalu  (SgIn  >haapsalu !01_S	et	f	\N
170560	õnni	õnni =õnni  (SgP  >õnn !22_S	et	f	\N
170561	õnni	õnni =õnni  (SgAdt  >õnn !22_S	et	f	\N
170563	õnni	õnni =õnni  (PlP  >õnn !22_S	et	f	\N
170593	viibi	viibi =viibi  (IndPrPs_  >viibima !27_V	et	f	\N
170594	viibi	viibi =viibi  (ImpPrSg2  >viibima !27_V	et	f	\N
170626	rääki	rääki =rääki  (SgP  >rääk !22_S	et	f	\N
170627	rääki	rääki =rääki  (SgAdt  >rääk !22_S	et	f	\N
170633	näeta	?näeta =näe  (SgAb  >näe !26_S	et	f	\N
170634	näeta	?näeta =näet  (Inf  >näetma !34_V	et	f	\N
170635	näeta	?näeta =näeta  (SgN  >näeta !16_S	et	f	\N
170636	näeta	?näeta =näeta  (SgG  >näeta !16_S	et	f	\N
170637	näeta	?näeta =näeta  (IndPrPs_  >näetama !27_V	et	f	\N
170638	näeta	?näeta =näeta  (ImpPrSg2  >näetama !27_V	et	f	\N
170661	vintpüssi	vintpüssi =püssi  (SgG  >vint+püss !22_S	et	f	\N
170662	vintpüssi	vintpüssi =püssi  (SgP  >vint+püss !22_S	et	f	\N
170663	vintpüssi	vintpüssi =püssi  (SgAdt  >vint+püss !22_S	et	f	\N
170680	meeldivalt	meeldivalt =meeldiva  (SgAbl  >meeldiv !02_A	et	f	\N
170681	meeldivalt	"meeldiv %meeldi  )V_vA  <meeldima ;27_V	et	f	\N
170682	meeldivalt	meeldivalt =meeldivalt  (ID  >meeldivalt !41_D	et	f	\N
170683	meeldivalt	"meeldivalt %meeldi  )VALT_mD  <meeldima ;27_V	et	f	\N
170684	meeldivalt	"meeldivalt %meeldiva  )LT_mD  <meeldiv ;02_A	et	f	\N
170691	hermani	?hermani =herma  (SgTer  >herma !16_S	et	f	\N
170692	hermani	?hermani =hermani  (SgG  >herman !02_S	et	f	\N
170698	garantiit	?garantiit =garantiit  (SgN  >garantiit !22_S	et	f	\N
170701	jogi	?jogi =jogi  (SgN  >jogi !17_S	et	f	\N
170702	jogi	?jogi =jogi  (SgG  >jogi !17_S	et	f	\N
170703	jogi	?jogi =jogi  (SgP  >jogi !17_S	et	f	\N
170704	jogi	?jogi =jogi  (IndPrPs_  >jogima !27_V	et	f	\N
170705	jogi	?jogi =jogi  (ImpPrSg2  >jogima !27_V	et	f	\N
170706	jälgsid	?jälgsid =jälgsi  (PlN  >jälgs !22_S	et	f	\N
170707	jälgsid	?jälgsid =jälgsi  (IndPrSg2  >jälgsima !28_V	et	f	\N
170729	sallepärast	?sallepärast =sallepära  (SgEl  >sallepära !16_S	et	f	\N
170730	sallepärast	?sallepärast =sallepäras  (SgP  >sallepärane !12_A	et	f	\N
170731	sallepärast	?sallepärast =epära  (SgEl  >sall+epära !01_S	et	f	\N
170732	sallepärast	?sallepärast =epäras  (SgP  >sall+epärane !12_A	et	f	\N
170733	tudruk	?tudruk =tudruk  (SgN  >tudruk !02_S	et	f	\N
170734	näeras	?näeras =näera  (SgIn  >näera !16_S	et	f	\N
170735	näeras	?näeras =näera  (IndIpfSg3  >näerama !29_V	et	f	\N
170736	näeras	?näeras =näeras  (SgN  >näeras !07_S	et	f	\N
170748	poisu	poisu =poisu  (SgN  >poisu !16_S	et	f	\N
170749	poisu	poisu =poisu  (SgG  >poisu !16_S	et	f	\N
170752	ronisivad	?ronisivad =ronisiva  (PlN  >ronisiv !02_A	et	f	\N
170753	ronisivad	?ronisivad =ronisiva  (PlN  >ronisiva !16_S	et	f	\N
170780	haugus	?haugus =haugu  (SgIn  >haugu !16_S	et	f	\N
170781	haugus	?haugus =haugu  (IndIpfSg3  >hauguma !27_V	et	f	\N
170782	haugus	?haugus =haugus  (SgN  >haugus !11~09_S	et	f	\N
170787	linnusid	?linnusid =linnu  (PlP  >linnu !16_S	et	f	\N
170788	linnusid	?linnusid =linnu  (IndIpfSg2  >linnuma !27_V	et	f	\N
170789	linnusid	?linnusid =linnu  (IndIpfPl3  >linnuma !27_V	et	f	\N
170790	linnusid	?linnusid =usi  (PlN  >linn+usi !17_S	et	f	\N
170801	moodis	?moodis =moodi  (SgIn  >moot !22_S	et	f	\N
170802	moodis	?moodis =moodi  (IndIpfSg3  >moodima !28_V	et	f	\N
170803	moodis	?moodis =moodis  (SgN  >moodis !09_S	et	f	\N
170804	jagida	?jagida =jagi  (Inf  >jagima !27_V	et	f	\N
170831	piilus	piilus =piilu  (SgIn  >piilu !16_S	et	f	\N
170832	piilus	piilus =piilu  (IndIpfSg3  >piiluma !28_V	et	f	\N
170836	hälega	?hälega =häle  (SgKom  >häle !16_S	et	f	\N
170849	järdmisel	?järdmisel =järdmise  (SgAd  >järdmine !12?10_A	et	f	\N
170850	järdmisel	?järdmisel =järdmisel  (SgN  >järdmisel !19_S	et	f	\N
170881	tervisekaitseinspektsiooni	tervisekaitseinspektsiooni =inspektsiooni  (SgG  >tervise+kaitse+inspektsioon !22_S	et	f	\N
170882	tervisekaitseinspektsiooni	tervisekaitseinspektsiooni =inspektsiooni  (SgP  >tervise+kaitse+inspektsioon !22_S	et	f	\N
170883	tervisekaitseinspektsiooni	tervisekaitseinspektsiooni =inspektsiooni  (SgAdt  >tervise+kaitse+inspektsioon !22_S	et	f	\N
170899	tav-	### tav-	et	f	\N
170906	puhastatav	puhastatav =puhasta  (PtsPrIps  >puhastama !27_V	et	f	\N
170907	puhastatav	puhastatav =puhastatav  (SgN  >puhastatav !02_A	et	f	\N
170908	puhastatav	"puhastatav %puhasta  )TAV_vAS  <puhastama ;27_V	et	f	\N
170916	võidavad	võidavad =võida  (IndPrPl3  >võitma !34_V	et	f	\N
170917	võidavad	võidavad =võidava  (PlN  >võidav !02_A	et	f	\N
170918	võidavad	"võidav %või  )TAV_vAS  <võima ;37_V	et	f	\N
170921	lisatavate	lisatavate =lisatava  (PlG  >lisatav !02_A	et	f	\N
170922	lisatavate	"lisatav %lisa  )TAV_vAS  <lisama ;27_V	et	f	\N
170931	pestav	pestav =pes  (PtsPrIps  >pesema !36_V	et	f	\N
170932	pestav	"pestav %pes  )TAV_vAS  <pesema ;36_V	et	f	\N
170938	retsepti	retsepti =retsepti  (SgG  >retsept !22_S	et	f	\N
170939	retsepti	retsepti =retsepti  (SgP  >retsept !22_S	et	f	\N
170940	retsepti	retsepti =retsepti  (SgAdt  >retsept !22_S	et	f	\N
170941	lausesse	lausesse =lause  (SgIll  >lause !06_S	et	f	\N
170942	lausesse	lausesse =sesse  (PlP  >lau+sess !22_S	et	f	\N
170601	uju	uju =uju  (SgP  >uju !17_S	et	f	\N
170602	uju	uju =uju  (IndPrPs_  >ujuma !27_V	et	f	\N
170603	uju	uju =uju  (ImpPrSg2  >ujuma !27_V	et	f	\N
170619	telegramm	telegramm =telegramm  (SgN  >telegramm !22_S	et	f	\N
170620	telegramm	telegramm =gramm  (SgN  >tele+gramm !22_S	et	f	\N
170621	ada	?ada =ada  (SgN  >ada !17_S	et	f	\N
170622	ada	?ada =ada  (SgG  >ada !17_S	et	f	\N
170623	ada	?ada =ada  (SgP  >ada !17_S	et	f	\N
170624	ada	?ada =ada  (IndPrPs_  >adama !27_V	et	f	\N
170625	ada	?ada =ada  (ImpPrSg2  >adama !27_V	et	f	\N
170642	kutsunimi	?kutsunimi =kutsunimi  (SgG  >kutsunim !02_A	et	f	\N
170643	esikusse	esikusse =esiku  (SgIll  >esik !02_S	et	f	\N
170644	esikusse	esikusse =usse  (PlP  >esik+uss !22_S	et	f	\N
170645	esikusse	esikusse =kusse  (SgAdt  >esi+kusi !20_S	et	f	\N
170649	roninud	roninud =roni  (PtsPtPs  >ronima !27_V	et	f	\N
170650	roninud	roninud =roninu  (PlN  >roninu !01_S	et	f	\N
170651	roninud	"roninu %roni  )NU_vS  <ronima ;27_V	et	f	\N
170652	roninud	roninud =roninud  (ID  >roninud !41_A	et	f	\N
170653	roninud	"roninud %roni  )NUD_vA  <ronima ;27_V	et	f	\N
170654	kaklevad	kaklevad =kakle  (IndPrPl3  >kaklema !30_V	et	f	\N
170655	kaklevad	kaklevad =kakleva  (PlN  >kaklev !02_A	et	f	\N
170656	kaklevad	"kaklev %kakle  )V_vA  <kaklema ;30_V	et	f	\N
170657	rahulikumad	rahulikumad =rahulikuma  (PlN  >rahulikum !02_A	et	f	\N
170658	rahulikumad	"rahulikum %rahuliku  )M_cA  <rahulik ;25_A	et	f	\N
170677	lehvivad	lehvivad =lehvi  (IndPrPl3  >lehvima !28_V	et	f	\N
170678	lehvivad	lehvivad =lehviva  (PlN  >lehviv !02_A	et	f	\N
170679	lehvivad	"lehviv %lehvi  )V_vA  <lehvima ;28_V	et	f	\N
170696	sunnitakse	sunnitakse =sunni  (IndPrIps  >sundima !28_V	et	f	\N
170697	sunnitakse	sunnitakse =takse  (PlP  >sunni+taks !22_S	et	f	\N
170708	õmblesis	?õmblesis =õmblesi  (PlIn  >õmblene !12_A	et	f	\N
170709	õmblesis	?õmblesis =õmblesis  (SgN  >õmblesis !11_S	et	f	\N
170739	teegi	teegi =teegi  (SgG  >teek !22_S	et	f	\N
170740	teegi	teegi =tee  (SgN^  >tee !26_S	et	f	\N
170741	teegi	teegi =tee  (SgG^  >tee !26_S	et	f	\N
170742	teegi	teegi =tee  (IndPrPs_^  >tegema !28_V	et	f	\N
170743	teegi	teegi =tee  (ImpPrSg2^  >tegema !28_V	et	f	\N
170746	uskusivad	?uskusivad =uskusiva  (PlN  >uskusiv !02_A	et	f	\N
170747	uskusivad	?uskusivad =uskusiva  (PlN  >uskusiva !16_S	et	f	\N
170750	mangisivad	?mangisivad =mangisiva  (PlN  >mangisiv !02_A	et	f	\N
170751	mangisivad	?mangisivad =mangisiva  (PlN  >mangisiva !16_S	et	f	\N
170764	õesid	?õesid =õesi  (PlN  >õesi !16_S	et	f	\N
170765	õesid	?õesid =õesi  (IndPrSg2  >õesima !28_V	et	f	\N
170766	näerivad	?näerivad =näeri  (IndPrPl3  >näerima !28_V	et	f	\N
170767	näerivad	?näerivad =näeriva  (PlN  >näeriva !01_S	et	f	\N
170768	näerivad	?näerivad =näeriva  (PlN  >näeriv !02_A	et	f	\N
170769	küüasin	?küüasin =küüasi  (IndPrSg1  >küüasima !28_V	et	f	\N
170770	küüasin	?küüasin =küüasin  (SgN  >küüasin !02_S	et	f	\N
170771	selpäeval	?selpäeval =selpäeva  (SgAd  >selpäeva !01_S	et	f	\N
170772	parti	parti =parti  (SgP  >part !22_S	et	f	\N
170773	parti	parti =parti  (SgAdt  >part !22_S	et	f	\N
170793	paigale	paigale =paiga  (SgAll  >paik !22_S	et	f	\N
170794	paigale	paigale =paigale  (ID  >paigale !41_D	et	f	\N
170799	parte	parte =par  (PlG  >pars !14_S	et	f	\N
170800	parte	parte =parte  (PlP  >part !22_S	et	f	\N
170808	peitab	?peitab =peita  (IndPrSg3  >peitama !27_V	et	f	\N
170827	väsind	?väsind =väsind  (SgN  >väsind !02_S	et	f	\N
170833	anedega	?anedega =ane  (PlKom  >ane !16_S	et	f	\N
170839	kooke	kooke =kooke  (SgN  >kooke !12?10_S	et	f	\N
170840	kooke	"kooke %koo  )KE_dS  <kubu ;18_S	et	f	\N
170841	kooke	kooke =kooke  (PlP  >kook !22_S	et	f	\N
170842	lähegi	lähegi =lähe  (IndPrPs_^  >minema !36_V	et	f	\N
170843	lähegi	lähegi =lähe  (SgN^  >lähe !06_S	et	f	\N
170844	ratsutasid	ratsutasid =ratsuta  (IndIpfSg2  >ratsutama !27_V	et	f	\N
170845	ratsutasid	ratsutasid =ratsuta  (IndIpfPl3  >ratsutama !27_V	et	f	\N
170854	niisutav	niisutav =niisuta  (PtsPrPs  >niisutama !27_V	et	f	\N
170855	niisutav	niisutav =niisutav  (SgN  >niisutav !02_A	et	f	\N
170856	niisutav	"niisutav %niisuta  )V_vA  <niisutama ;27_V	et	f	\N
170874	toimega	toimega =toime  (SgKom  >toime !06_S	et	f	\N
170875	toimega	toimega =toime  (SgKom  >toim !22_S	et	f	\N
170884	jäätmekäitlusfirma	?jäätmekäitlusfirma =jäätmekäitlusfirma  (SgN  >jäätmekäitlusfirma !16_S	et	f	\N
170885	jäätmekäitlusfirma	?jäätmekäitlusfirma =jäätmekäitlusfirma  (SgG  >jäätmekäitlusfirma !16_S	et	f	\N
170886	jäätmekäitlusfirma	?jäätmekäitlusfirma =käitlusfirma  (SgN  >jäätme+käitlusfirma !16_S	et	f	\N
170887	jäätmekäitlusfirma	?jäätmekäitlusfirma =käitlusfirma  (SgG  >jäätme+käitlusfirma !16_S	et	f	\N
170888	jäätmekäitlusfirma	?jäätmekäitlusfirma =mekäitlusfirma  (SgN  >jäät+mekäitlusfirma !16_S	et	f	\N
170889	jäätmekäitlusfirma	?jäätmekäitlusfirma =mekäitlusfirma  (SgG  >jäät+mekäitlusfirma !16_S	et	f	\N
170900	kesksõna	kesksõna =sõna  (SgN  >kesk+sõna !17_S	et	f	\N
170901	kesksõna	kesksõna =sõna  (SgG  >kesk+sõna !17_S	et	f	\N
170647	haapsalus	?haapsalus =haapsalu  (IndIpfSg3  >haapsaluma !27_V	et	f	\N
170648	haapsalus	?haapsalus =haapsalus  (SgN  >haapsalus !11_S	et	f	\N
170668	imetlevad	imetlevad =imetle  (IndPrPl3  >imetlema !27_V	et	f	\N
170669	imetlevad	imetlevad =imetleva  (PlN  >imetlev !02_A	et	f	\N
170670	imetlevad	"imetlev %imetle  )V_vA  <imetlema ;27_V	et	f	\N
170685	päikeselt	päikeselt =päikese  (SgAbl  >päike !12?10_S	et	f	\N
170686	päikeselt	päikeselt =päikese  (SgAbl  >päikene !12?10_S	et	f	\N
170687	ununevad	ununevad =unune  (IndPrPl3  >ununema !27_V	et	f	\N
170688	ununevad	ununevad =ununeva  (PlN  >ununev !02_A	et	f	\N
170689	ununevad	"ununev %unune  )V_vA  <ununema ;27_V	et	f	\N
170690	kõidab	?kõidab =kõida  (IndPrSg3  >kõidama !29_V	et	f	\N
170699	kisavaid	kisavaid =kisava  (PlP  >kisav !02_A	et	f	\N
170700	kisavaid	"kisav %kisa  )V_vA  <kisama ;27_V	et	f	\N
170722	kõikele	?kõikele =kõikele  (IndPrPs_  >kõikelema !27_V	et	f	\N
170723	kõikele	?kõikele =kõikele  (ImpPrSg2  >kõikelema !27_V	et	f	\N
170737	ya	?ya =ya  (SgN  >ya !26_S	et	f	\N
170738	ya	?ya =ya  (SgG  >ya !26_S	et	f	\N
170744	venndad	?venndad =vennda  (PlN  >vennda !01_S	et	f	\N
170745	venndad	?venndad =vennda  (IndPrSg2  >venndama !29_V	et	f	\N
170774	tammepuu	tammepuu =puu  (SgN  >tamme+puu !26_S	et	f	\N
170775	tammepuu	tammepuu =puu  (SgG  >tamme+puu !26_S	et	f	\N
170783	tita	tita =tita  (SgN  >tita !16_S	et	f	\N
170784	tita	tita =tita  (SgG  >tita !16_S	et	f	\N
170791	ilusale	ilusale =ilusa  (SgAll  >ilus !02_A	et	f	\N
170792	ilusale	ilusale =sale  (SgN  >ilu+sale !02_A	et	f	\N
170805	tipusid	?tipusid =tipu  (PlP  >tipu !16_S	et	f	\N
170806	tipusid	?tipusid =tipu  (IndIpfSg2  >tipuma !27_V	et	f	\N
170807	tipusid	?tipusid =tipu  (IndIpfPl3  >tipuma !27_V	et	f	\N
170809	pikksilma	pikksilma =silma  (SgG  >pikk+silm !22_S	et	f	\N
170810	pikksilma	pikksilma =silma  (SgP  >pikk+silm !22_S	et	f	\N
170811	pikksilma	pikksilma =silma  (SgAdt  >pikk+silm !22_S	et	f	\N
170812	võitlevad	võitlevad =võitle  (IndPrPl3  >võitlema !30_V	et	f	\N
170813	võitlevad	võitlevad =võitleva  (PlN  >võitlev !02_A	et	f	\N
170814	võitlevad	"võitlev %võitle  )V_vA  <võitlema ;30_V	et	f	\N
170823	önneks	?önneks =önne  (PlTr  >önn !22_S	et	f	\N
170824	önneks	?önneks =önne  (KndPrPs  >önnema !27_V	et	f	\N
170828	mürasid	mürasid =müra  (PlP  >müra !17_S	et	f	\N
170829	mürasid	mürasid =müra  (IndIpfSg2  >mürama !27_V	et	f	\N
170830	mürasid	mürasid =müra  (IndIpfPl3  >mürama !27_V	et	f	\N
170860	kõvenenud	kõvenenud =kõvene  (PtsPtPs  >kõvenema !27_V	et	f	\N
170861	kõvenenud	kõvenenud =kõvenenu  (PlN  >kõvenenu !01_S	et	f	\N
170862	kõvenenud	"kõvenenu %kõvene  )NU_vS  <kõvenema ;27_V	et	f	\N
170863	kõvenenud	kõvenenud =kõvenenud  (ID  >kõvenenud !41_A	et	f	\N
170864	kõvenenud	"kõvenenud %kõvene  )NUD_vA  <kõvenema ;27_V	et	f	\N
170867	higistavatele	higistavatele =higistava  (PlAll  >higistav !02_A	et	f	\N
170868	higistavatele	"higistav %higista  )V_vA  <higistama ;27_V	et	f	\N
170872	antibakteriaalse	?antibakteriaalse =antibakteriaalse  (SgG  >antibakteriaalne !02_A	et	f	\N
170873	antibakteriaalse	?antibakteriaalse =antibakteriaalse  (PlP  >antibakteriaals !22_S	et	f	\N
170890	jäätmetele	jäätmetele =jäätme  (PlAll  >jääde !05_S	et	f	\N
170891	jäätmetele	jäätmetele =me  (PlAll  >jäät+mesi !15_S	et	f	\N
170892	jäätmetele	jäätmetele =mete  (PlAll  >jäät+mett !22_S	et	f	\N
170909	avatava	avatava =avatava  (SgG  >avatav !02_A	et	f	\N
170910	avatava	"avatav %ava  )TAV_vAS  <avama ;27_V	et	f	\N
170911	avatava	avatava =tava  (SgN  >ava+tava !17_S	et	f	\N
170912	avatava	avatava =tava  (SgG  >ava+tava !17_S	et	f	\N
170913	avatava	avatava =tava  (SgP  >ava+tava !17_S	et	f	\N
170923	umbusklikult	umbusklikult =uskliku  (SgAbl  >umb+usklik !25_AS	et	f	\N
170924	umbusklikult	"umb+usklikult %uskliku  )LT_mD  <umb+usklik ;25_AS	et	f	\N
170927	umusklikult	?umusklikult =umuskliku  (SgAbl  >umusklik !25_A	et	f	\N
170928	umusklikult	?umusklikult =umusklikult  (ID  >umusklikult !41_D	et	f	\N
170929	müüdavaid	müüdavaid =müüdava  (PlP  >müüdav !02_A	et	f	\N
170930	müüdavaid	"müüdav %müü  )TAV_vAS  <müüma ;38_V	et	f	\N
170951	reostamise	reostamise =reostamise  (SgG  >reostamine !12_S	et	f	\N
170952	reostamise	"reostamine %reosta  )MINE_vS  <reostama ;27_V	et	f	\N
170958	skännima	?skännima =skänni  (Sup  >skännima !28_V	et	f	\N
170959	skännima	?skännima =skännima  (SgG  >skännim !02_A	et	f	\N
170960	kibuvitsapõõsale	?kibuvitsapõõsale =kibuvitsapõõsa  (SgAll  >kibuvitsapõõsa !16_S	et	f	\N
170961	mahedalt	mahedalt =maheda  (SgAbl  >mahe !02_A	et	f	\N
170962	mahedalt	mahedalt =mahedalt  (ID  >mahedalt !41_D	et	f	\N
170963	mahedalt	"mahedalt %maheda  )LT_mD  <mahe ;02_A	et	f	\N
170987	1-b	### 1-b	et	f	\N
171001	ettevalmistuste	ettevalmistuste =tuste  (PlP  >ette+valmis+tust !22_S	et	f	\N
171002	ettevalmistuste	ettevalmistuste =valmistus  (PlG  >ette+valmistus !11_S	et	f	\N
171003	teenijannat	?teenijannat =teenijanna  (SgP  >teenijanna !16_S	et	f	\N
171004	teenijannat	?teenijannat =nijanna  (SgP  >tee+nijanna !16_S	et	f	\N
171010	gatesile	### gatesile	et	f	\N
171036	muutud	muutud =muutu  (PlN  >muutu !01_A	et	f	\N
170798	jahtida	jahtida =ida  (SgP  >jaht+ida !17_S	et	f	\N
170825	lõpude-lõpuks	lõpude-lõpuks =lõpu  (SgTr  >lõpude-lõpp !22_SA	et	f	\N
170826	lõpude-lõpuks	lõpude-lõpuks =lõpuks  (ID  >lõpude-lõpuks !41_D	et	f	\N
170837	binookliga	?binookliga =binookli  (SgKom  >binookli !01_S	et	f	\N
170838	binookliga	?binookliga =binookli  (SgKom  >binookel !02_S	et	f	\N
170857	toitev	toitev =toit  (PtsPrPs  >toitma !34_V	et	f	\N
170858	toitev	toitev =toitev  (SgN  >toitev !02_A	et	f	\N
170859	toitev	"toitev %toit  )V_vA  <toitma ;34_V	et	f	\N
170893	riiklikult	riiklikult =riikliku  (SgAbl  >riiklik !25_A	et	f	\N
170894	riiklikult	riiklikult =riiklikult  (ID  >riiklikult !41_D	et	f	\N
170895	riiklikult	"riiklikult %riikliku  )LT_mD  <riiklik ;25_A	et	f	\N
170919	hinnalisi	hinnalisi =hinnalisi  (PlP  >hinnaline !12_A	et	f	\N
170920	hinnalisi	"hinnaline %hinna  )LINE_aA  <hind ;22_S	et	f	\N
170933	parandust	parandust =parandus  (SgP  >parandus !11_S	et	f	\N
170934	parandust	"parandus %paranda  )US_vS  <parandama ;27_V	et	f	\N
170953	r-liitelisi	r-liitelisi =liitelisi  (PlP  >r-liiteline !12_A	et	f	\N
170954	r-liitelisi	"r-liiteline %liite  )LINE_aA  <r-liide ;06_S	et	f	\N
170972	ahjusoe	ahjusoe =soe  (SgN  >ahju+soe !24_AS	et	f	\N
170973	ahjusoe	ahjusoe =soe  (SgG  >ahju+susi !15_S	et	f	\N
170980	toetuma	toetuma =toetu  (Sup  >toetuma !27_V	et	f	\N
170981	toetuma	toetuma =toetuma  (SgG  >toetum !02_A	et	f	\N
170982	toetuma	"toetum %toe  )TUM2_cA  <tugi ;21_S	et	f	\N
170988	2-d	-d =  (SgP  > !xx_Q	et	f	\N
170989	2-d	-d =  (PlN  > !xx_Q	et	f	\N
171005	ämma	ämma =ämma  (SgG  >ämm !22_S	et	f	\N
171007	ämma	ämma =ämma  (SgP  >ämm !22_S	et	f	\N
171009	ämma	ämma =ämma  (SgAdt  >ämm !22_S	et	f	\N
171023	postkompuutriajastusse	postkompuutriajastusse =ajastu  (SgIll  >post+kompuutri+ajastu !01_S	et	f	\N
171024	postkompuutriajastusse	postkompuutriajastusse =ajastus  (SgAdt  >post+kompuutri+ajastus !11_S	et	f	\N
171025	joonde	joonde =joon  (SgAdt  >joon !13_S	et	f	\N
171026	joonde	joonde =joonde  (ID  >joonde !41_D	et	f	\N
171030	kastmise	kastmise =kastmise  (SgG  >kastmine !12?10_S	et	f	\N
171031	kastmise	"kastmine %kast  )MINE_vS  <kastma ;34_V	et	f	\N
171032	saavas	saavas =saava  (SgIn  >saav !02_A	et	f	\N
171033	saavas	"saav %saa  )V_vA  <saama ;37_V	et	f	\N
171034	jagunesid	jagunesid =jagune  (IndIpfSg2  >jagunema !27_V	et	f	\N
171035	jagunesid	jagunesid =jagune  (IndIpfPl3  >jagunema !27_V	et	f	\N
171047	elektrikulud	elektrikulud =kulu  (PlN  >elektri+kulu !17_S	et	f	\N
171048	elektrikulud	elektrikulud =kulu  (PlN  >elektri+kulg !22_S	et	f	\N
171056	elektrikulu	elektrikulu =kulu  (SgN  >elektri+kulu !17_S	et	f	\N
171057	elektrikulu	elektrikulu =kulu  (SgG  >elektri+kulu !17_S	et	f	\N
171058	elektrikulu	elektrikulu =kulu  (SgG  >elektri+kulg !22_S	et	f	\N
171059	elektrikulu	elektrikulu =kulu  (SgP  >elektri+kulu !17_S	et	f	\N
171067	täitumas	täitumas =täitu  (SupIn  >täituma !27_V	et	f	\N
171068	täitumas	täitumas =täituma  (SgIn  >täitum !02_A	et	f	\N
171069	täitumas	"täitum %täi  )TUM1_cA  <täima ;27_V	et	f	\N
171070	täitumas	"täitum %täi  )TUM2_cA  <täi ;26_S	et	f	\N
171073	valvekaamera	valvekaamera =kaamera  (SgN  >valve+kaamera !01_S	et	f	\N
171074	valvekaamera	valvekaamera =kaamera  (SgG  >valve+kaamera !01_S	et	f	\N
171078	tõmmata	tõmmata =tõmma  (Inf  >tõmbama !29_V	et	f	\N
171079	tõmmata	tõmmata =tõmma  (IndPrIps_  >tõmbama !29_V	et	f	\N
171114	maapõhja	maapõhja =põhja  (SgG  >maa+põhi !24_S	et	f	\N
171115	maapõhja	maapõhja =põhja  (SgP  >maa+põhi !24_S	et	f	\N
171116	maapõhja	maapõhja =põhja  (SgAdt  >maa+põhi !24_S	et	f	\N
171120	6-b	### 6-b	et	f	\N
171127	mutrivõti	mutrivõti =võti  (SgN  >mutri+võti !05_S	et	f	\N
171128	mutrivõti	mutrivõti =võti  (SgG  >mutri+võtt !22_S	et	f	\N
171130	4-f	### 4-f	et	f	\N
171132	tõusete	tõusete =tõuse  (IndPrPl2  >tõusma !32_V	et	f	\N
171133	tõusete	tõusete =sete  (SgN  >tõu+sete !06_S	et	f	\N
171148	angetama	?angetama =ange  (SupIps  >angema !27_V	et	f	\N
171149	angetama	?angetama =angeta  (Sup  >angetama !27_V	et	f	\N
171150	angetama	?angetama =angetama  (SgG  >angetam !02_A	et	f	\N
171153	vitae	?vitae =vitae  (SgN  >vitae !26_S	et	f	\N
171154	vitae	?vitae =vitae  (SgG  >vitae !26_S	et	f	\N
171176	gagra	?gagra =gagra  (SgN  >gagra !16_S	et	f	\N
171177	gagra	?gagra =gagra  (SgG  >gagra !16_S	et	f	\N
171178	gagra	?gagra =gagra  (IndPrPs_  >gagrama !27_V	et	f	\N
171179	gagra	?gagra =gagra  (ImpPrSg2  >gagrama !27_V	et	f	\N
171182	30042003a	### 30042003a	et	f	\N
171264	põnevamaks	põnevamaks =põnevama  (SgTr  >põnevam !02_A	et	f	\N
171265	põnevamaks	"põnevam %põneva  )M_cA  <põnev ;02_A	et	f	\N
171323	pajatanud	pajatanud =pajata  (PtsPtPs  >pajatama !27_V	et	f	\N
171324	pajatanud	pajatanud =pajatanu  (PlN  >pajatanu !01_S	et	f	\N
171325	pajatanud	"pajatanu %pajata  )NU_vS  <pajatama ;27_V	et	f	\N
171326	pajatanud	pajatanud =pajatanud  (ID  >pajatanud !41_A	et	f	\N
171327	pajatanud	"pajatanud %pajata  )NUD_vA  <pajatama ;27_V	et	f	\N
171328	pajatanud	pajatanud =tanu  (PlN  >paja+tanu !17_S	et	f	\N
170821	eredalt	eredalt =eredalt  (ID  >eredalt !41_D	et	f	\N
170822	eredalt	"eredalt %ereda  )LT_mD  <ere ;02_A	et	f	\N
170834	kaklesid	kaklesid =kakle  (IndIpfSg2  >kaklema !30_V	et	f	\N
170835	kaklesid	kaklesid =kakle  (IndIpfPl3  >kaklema !30_V	et	f	\N
170846	meelege	?meelege =meele  (ImpPrPl2  >meelema !27_V	et	f	\N
170847	meelege	?meelege =lege  (SgN  >mee+lege !16_S	et	f	\N
170848	meelege	?meelege =lege  (SgG  >mee+lege !16_S	et	f	\N
170851	määritav	määritav =määri  (PtsPrIps  >määrima !28_V	et	f	\N
170852	määritav	määritav =määritav  (SgN  >määritav !02_A	et	f	\N
170853	määritav	"määritav %määri  )TAV_vAS  <määrima ;28_V	et	f	\N
170865	eemaldatavaks	eemaldatavaks =eemaldatava  (SgTr  >eemaldatav !02_A	et	f	\N
170866	eemaldatavaks	"eemaldatav %eemalda  )TAV_vAS  <eemaldama ;27_V	et	f	\N
170869	kreemi	kreemi =kreemi  (SgG  >kreem !22_SA	et	f	\N
170870	kreemi	kreemi =kreemi  (SgP  >kreem !22_SA	et	f	\N
170871	kreemi	kreemi =kreemi  (SgAdt  >kreem !22_SA	et	f	\N
170876	soovitatud	soovitatud =soovita  (PtsPtIps  >soovitama !27_V	et	f	\N
170877	soovitatud	soovitatud =soovitatu  (PlN  >soovitatu !01_S	et	f	\N
170878	soovitatud	"soovitatu %soovita  )TU1_vS  <soovitama ;27_V	et	f	\N
170879	soovitatud	soovitatud =soovitatud  (ID  >soovitatud !41_A	et	f	\N
170880	soovitatud	"soovitatud %soovita  )TUD_vA  <soovitama ;27_V	et	f	\N
170896	lauseosa	lauseosa =osa  (SgN  >lause+osa !17_S	et	f	\N
170897	lauseosa	lauseosa =osa  (SgG  >lause+osa !17_S	et	f	\N
170898	lauseosa	lauseosa =osa  (SgP  >lause+osa !17_S	et	f	\N
170903	pöörake	pöörake =pööra  (ImpPrPl2  >pöörama !29_V	et	f	\N
170904	pöörake	pöörake =pöörake  (SgN  >pöörake !12_S	et	f	\N
170905	pöörake	"pöörake %pööra  )KE_dS  <pöör ;22_S	et	f	\N
170914	toodetavatele	toodetavatele =toodetava  (PlAll  >toodetav !02_A	et	f	\N
170915	toodetavatele	"toodetav %toode  )TAV_vAS  <tootma ;34_V	et	f	\N
170948	rangemad	rangemad =rangema  (PlN  >rangem !02_A	et	f	\N
170949	rangemad	"rangem %range  )M_cA  <range ;01_A	et	f	\N
170950	rangemad	rangemad =ema  (PlN  >rang+ema !17_S	et	f	\N
170957	skänner	?skänner =skänner  (SgN  >skänner !02_S	et	f	\N
170983	tekitama	tekitama =teki  (SupIps  >tekkima !28_V	et	f	\N
170984	tekitama	tekitama =tekita  (Sup  >tekitama !27_V	et	f	\N
170992	5-c	### 5-c	et	f	\N
170995	elustiilist	elustiilist =stiili  (SgEl  >elu+stiil !22_S	et	f	\N
170996	elustiilist	elustiilist =stiilis  (SgP  >elu+stiiline !10_A	et	f	\N
170997	elustiilist	"elu+stiiline %stiili  )NE_aA  <elu+stiil ;22_S	et	f	\N
171000	2-a	### 2-a	et	f	\N
171006	virka	virka =virka  (SgP  >virk !22_A	et	f	\N
171008	virka	virka =virka  (SgAdt  >virk !22_A	et	f	\N
171011	andrew	### andrew	et	f	\N
171020	kübermaailma	kübermaailma =ilma  (SgG  >küber+maa+ilm !22_S	et	f	\N
171021	kübermaailma	kübermaailma =ilma  (SgP  >küber+maa+ilm !22_S	et	f	\N
171022	kübermaailma	kübermaailma =ilma  (SgAdt  >küber+maa+ilm !22_S	et	f	\N
171027	hommikukohvi	hommikukohvi =kohvi  (SgG  >hommiku+kohv !22_S	et	f	\N
171028	hommikukohvi	hommikukohvi =kohvi  (SgP  >hommiku+kohv !22_S	et	f	\N
171029	hommikukohvi	hommikukohvi =kohvi  (SgAdt  >hommiku+kohv !22_S	et	f	\N
171039	toredamaks	toredamaks =toredama  (SgTr  >toredam !02_A	et	f	\N
171040	toredamaks	"toredam %toreda  )M_cA  <tore ;02_A	et	f	\N
171100	jahuta	jahuta =jahu  (SgAb  >jahu !17_S	et	f	\N
171101	jahuta	jahuta =jahuta  (IndPrPs_  >jahutama !27_V	et	f	\N
171102	jahuta	jahuta =jahuta  (ImpPrSg2  >jahutama !27_V	et	f	\N
171108	tarvitamisel	tarvitamisel =tarvitamise  (SgAd  >tarvitamine !12_S	et	f	\N
171109	tarvitamisel	"tarvitamine %tarvita  )MINE_vS  <tarvitama ;27_V	et	f	\N
171129	3-a	### 3-a	et	f	\N
171134	hapu	hapu =hapu  (SgN  >hapu !16_A	et	f	\N
171135	hapu	hapu =hapu  (SgG  >hapu !16_A	et	f	\N
171138	pikendanud	pikendanud =pikenda  (PtsPtPs  >pikendama !27_V	et	f	\N
171139	pikendanud	pikendanud =pikendanu  (PlN  >pikendanu !01_S	et	f	\N
171140	pikendanud	"pikendanu %pikenda  )NU_vS  <pikendama ;27_V	et	f	\N
171141	pikendanud	pikendanud =pikendanud  (ID  >pikendanud !41_A	et	f	\N
171142	pikendanud	"pikendanud %pikenda  )NUD_vA  <pikendama ;27_V	et	f	\N
171143	helkur	?helkur =helkur  (SgN  >helkur !02_S	et	f	\N
171146	alvendama	?alvendama =alvenda  (Sup  >alvendama !27_V	et	f	\N
171147	alvendama	?alvendama =alvendama  (SgG  >alvendam !02_A	et	f	\N
171159	curriculum	?curriculum =curriculum  (SgN  >curriculum !19_S	et	f	\N
171175	2000-2002a	### 2000-2002a	et	f	\N
171204	külmaverelisi	külmaverelisi =verelisi  (PlP  >külma+vereline !12_A	et	f	\N
171205	külmaverelisi	"külma+vereline %vere  )LINE_aA  <külma+veri ;20_S	et	f	\N
171209	jai	?jai =jai  (SgN  >jai !26_S	et	f	\N
171210	jai	?jai =jai  (SgG  >jai !26_S	et	f	\N
171223	keerulisesse	keerulisesse =keerulise  (SgIll  >keeruline !12_A	et	f	\N
171224	keerulisesse	"keeruline %keeru  )LINE_aA  <keerd ;22_SA	et	f	\N
171237	sündimise	sündimise =sündimise  (SgG  >sündimine !12_S	et	f	\N
171238	sündimise	"sündimine %sündi  )MINE_vS  <sündima ;28_V	et	f	\N
171239	tagamaid	tagamaid =ma  (PlP  >taga+maa !26_S	et	f	\N
171240	tagamaid	tagamaid =mai  (PlN  >taga+mai !26_S	et	f	\N
170902	kesksõna	kesksõna =sõna  (SgP  >kesk+sõna !17_S	et	f	\N
170925	reklaamitavatesse	reklaamitavatesse =reklaamitava  (PlIll  >reklaamitav !02_A	et	f	\N
170926	reklaamitavatesse	"reklaamitav %reklaami  )TAV_vAS  <reklaamima ;28_V	et	f	\N
170935	nakkav	nakkav =nakka  (PtsPrPs  >nakkama !29_V	et	f	\N
170936	nakkav	nakkav =nakkav  (SgN  >nakkav !02_A	et	f	\N
170937	nakkav	"nakkav %nakka  )V_vA  <nakkama ;29_V	et	f	\N
170943	sobimatud	sobimatud =sobimatu  (PlN  >sobimatu !01_A	et	f	\N
170944	sobimatud	"sobimatu %sobi  )MATU_vA  <sobima ;27_V	et	f	\N
170974	kosutama	kosutama =kosu  (SupIps  >kosuma !27_V	et	f	\N
170975	kosutama	kosutama =kosuta  (Sup  >kosutama !27_V	et	f	\N
170985	äraaetud	äraaetud =ae  (PtsPtIps  >ära+_ajama !27_V	et	f	\N
170986	äraaetud	äraaetud =aetu  (PlN  >ära+aetu !01_S	et	f	\N
171012	grove	?grove =grove  (SgN  >grove !16_S	et	f	\N
171013	grove	?grove =grove  (SgG  >grove !16_S	et	f	\N
171014	grove	?grove =grove  (IndPrPs_  >grovema !27_V	et	f	\N
171015	grove	?grove =grove  (ImpPrSg2  >grovema !27_V	et	f	\N
171016	ile	?ile =ile  (SgN  >ile !16_S	et	f	\N
171017	ile	?ile =ile  (SgG  >ile !16_S	et	f	\N
171018	ile	?ile =ile  (IndPrPs_  >ilema !27_V	et	f	\N
171019	ile	?ile =ile  (ImpPrSg2  >ilema !27_V	et	f	\N
171049	elektritööd	elektritööd =töö  (PlN  >elektri+töö !26_S	et	f	\N
171050	elektritööd	elektritööd =töö  (SgP  >elektri+töö !26_S	et	f	\N
171053	mobiiltelefooni	mobiiltelefooni =fooni  (SgG  >mobiil+tele+foon !22_S	et	f	\N
171054	mobiiltelefooni	mobiiltelefooni =fooni  (SgP  >mobiil+tele+foon !22_S	et	f	\N
171055	mobiiltelefooni	mobiiltelefooni =fooni  (SgAdt  >mobiil+tele+foon !22_S	et	f	\N
171065	voolumõõtja	voolumõõtja =mõõtja  (SgN  >voolu+mõõtja !01_S	et	f	\N
171066	voolumõõtja	voolumõõtja =mõõtja  (SgG  >voolu+mõõtja !01_S	et	f	\N
171106	pulssi	pulssi =pulssi  (SgP  >pulss !22_S	et	f	\N
171107	pulssi	pulssi =pulssi  (SgAdt  >pulss !22_S	et	f	\N
171117	1-c	### 1-c	et	f	\N
171121	muruvõti	muruvõti =võti  (SgN  >muru+võti !05_S	et	f	\N
171122	muruvõti	muruvõti =võti  (SgG  >muru+võtt !22_S	et	f	\N
171123	jootekolb	?jootekolb =jootekolb  (SgN  >jootekolb !22_S	et	f	\N
171124	jootekolb	?jootekolb =ekolb  (SgN  >joot+ekolb !22_S	et	f	\N
171136	tõmbu	tõmbu =tõmbu  (IndPrPs_  >tõmbuma !27_V	et	f	\N
171137	tõmbu	tõmbu =tõmbu  (ImpPrSg2  >tõmbuma !27_V	et	f	\N
171144	lühis	lühis =lühi  (SgIn  >lüht !22_S	et	f	\N
171145	lühis	lühis =lühis  (SgN  >lühis !09_S	et	f	\N
171161	gruusia	?gruusia =gruusia  (SgN  >gruusia !01_S	et	f	\N
171162	gruusia	?gruusia =gruusia  (SgG  >gruusia !01_S	et	f	\N
171163	marikatpuee	?marikatpuee =marikatpuee  (SgN  >marikatpuee !26_S	et	f	\N
171164	marikatpuee	?marikatpuee =marikatpuee  (SgG  >marikatpuee !26_S	et	f	\N
171165	marikatpuee	?marikatpuee =katpuee  (SgN  >mari+katpuee !26_S	et	f	\N
171166	marikatpuee	?marikatpuee =katpuee  (SgG  >mari+katpuee !26_S	et	f	\N
171171	mediciinitehnikakool	?mediciinitehnikakool =mediciinitehnikakoo  (SgAd  >mediciinitehnikakoo !26_S	et	f	\N
171172	mediciinitehnikakool	?mediciinitehnikakool =mediciinitehnikakool  (SgN  >mediciinitehnikakool !22_S	et	f	\N
171173	mediciinitehnikakool	?mediciinitehnikakool =iciinitehnikakoo  (SgAd  >med+iciinitehnikakoo !26_S	et	f	\N
171174	mediciinitehnikakool	?mediciinitehnikakool =iciinitehnikakool  (SgN  >med+iciinitehnikakool !22_S	et	f	\N
171180	kuulamine	kuulamine =kuulamine  (SgN  >kuulamine !12_S	et	f	\N
171181	kuulamine	"kuulamine %kuula  )MINE_vS  <kuulama ;29_V	et	f	\N
171185	linastuseid	?linastuseid =linastusei  (PlN  >linastusei !26_S	et	f	\N
171186	linastuseid	?linastuseid =linastusei  (SgP  >linastusei !26_S	et	f	\N
171187	linastuseid	?linastuseid =stusei  (PlN  >lina+stusei !26_S	et	f	\N
171188	linastuseid	?linastuseid =stusei  (SgP  >lina+stusei !26_S	et	f	\N
171189	linastuseid	?linastuseid =stuseid  (SgN  >lina+stuseid !22_S	et	f	\N
171195	kohustusest	kohustusest =kohustuse  (SgEl  >kohustus !11_S	et	f	\N
171196	kohustusest	"kohustus %kohusta  )US_vS  <kohustama ;27_V	et	f	\N
171197	kohustusest	kohustusest =kohustuses  (SgP  >kohustusene !12_A	et	f	\N
171198	kohustusest	"kohustusene %kohustuse  )NE_aA  <kohustus ;11_S	et	f	\N
171202	lemmikteoseks	lemmikteoseks =seks  (SgN  >lemmik+teo+seks !22_S	et	f	\N
171203	lemmikteoseks	lemmikteoseks =teose  (SgTr  >lemmik+teos !09_S	et	f	\N
171216	sõdivad	sõdivad =sõdi  (IndPrPl3  >sõdima !27_V	et	f	\N
171217	sõdivad	sõdivad =sõdiva  (PlN  >sõdiv !02_A	et	f	\N
171218	sõdivad	"sõdiv %sõdi  )V_vA  <sõdima ;27_V	et	f	\N
171242	valikutest	valikutest =valiku  (PlEl  >valik !02_S	et	f	\N
171243	valikutest	valikutest =test  (SgN  >valiku+test !22_S	et	f	\N
171244	valikutest	valikutest =ute  (SgEl  >valik+utt !22_S	et	f	\N
171245	valikutest	valikutest =ute  (PlEl  >valik+utt !22_S	et	f	\N
171246	valikutest	valikutest =utes  (SgP  >valik+utene !10_A	et	f	\N
171247	valikutest	"valik+utene %ute  )NE_aA  <valik+utt ;22_S	et	f	\N
171254	vaimselt	vaimselt =vaimse  (SgAbl  >vaimne !02_A	et	f	\N
171255	vaimselt	vaimselt =vaimselt  (ID  >vaimselt !41_D	et	f	\N
171256	vaimselt	"vaimselt %vaimse  )LT_mD  <vaimne ;02_A	et	f	\N
171260	gümnaasiumipoisid	gümnaasiumipoisid =poi  (PlP  >gümnaasiumi+poi !26_S	et	f	\N
170945	visake	visake =visa  (ImpPrPl2  >viskama !29_V	et	f	\N
170946	visake	visake =visake  (SgN  >visake !12_S	et	f	\N
170947	visake	"visake %visa  )KE_dA  <visa ;17_A	et	f	\N
170955	kuvama	?kuvama =kuva  (Sup  >kuvama !27_V	et	f	\N
170956	kuvama	?kuvama =kuvama  (SgG  >kuvam !02_A	et	f	\N
170964	süüdatud	süüdatud =süüda  (PtsPtIps  >süütama !29_V	et	f	\N
170965	süüdatud	süüdatud =süüdatu  (PlN  >süüdatu !01_S	et	f	\N
170966	süüdatud	"süüdatu %süüda  )TU1_vS  <süütama ;29_V	et	f	\N
170967	süüdatud	süüdatud =süüdatud  (ID  >süüdatud !41_A	et	f	\N
170968	süüdatud	"süüdatud %süüda  )TUD_vA  <süütama ;29_V	et	f	\N
170969	hõrgutav	hõrgutav =hõrguta  (PtsPrPs  >hõrgutama !27_V	et	f	\N
170970	hõrgutav	hõrgutav =hõrgutav  (SgN  >hõrgutav !02_A	et	f	\N
170971	hõrgutav	"hõrgutav %hõrguta  )V_vA  <hõrgutama ;27_V	et	f	\N
170976	langetama	langetama =lange  (SupIps  >langema !27_V	et	f	\N
170977	langetama	langetama =langeta  (Sup  >langetama !27_V	et	f	\N
170978	venitama	venitama =veni  (SupIps  >venima !27_V	et	f	\N
170979	venitama	venitama =venita  (Sup  >venitama !27_V	et	f	\N
170990	3-f	### 3-f	et	f	\N
170991	4-a	### 4-a	et	f	\N
170993	ravis	ravis =ravi  (SgIn  >ravi !17_S	et	f	\N
170994	ravis	ravis =ravi  (IndIpfSg3  >ravima !27_V	et	f	\N
170998	nakkatama	?nakkatama =nakkata  (Sup  >nakkatama !27_V	et	f	\N
170999	nakkatama	?nakkatama =nakkatama  (SgG  >nakkatam !02_A	et	f	\N
171041	osale	osale =osa  (SgAll  >osa !17_S	et	f	\N
171042	osale	osale =osale  (IndPrPs_  >osalema !27_V	et	f	\N
171043	osale	osale =osale  (ImpPrSg2  >osalema !27_V	et	f	\N
171051	halvemaks	halvemaks =halvema  (SgTr  >halvem !02_A	et	f	\N
171052	halvemaks	"halvem %halve  )M_cA  <halb ;22_A	et	f	\N
171060	rahutuks	rahutuks =rahutu  (SgTr  >rahutu !01_A	et	f	\N
171061	rahutuks	"rahutu %rahu  )TU2_kA  <rahu ;17_S	et	f	\N
171062	rahutuks	rahutuks =tuks  (SgN  >rahu+tuks !22_S	et	f	\N
171063	kurdiks	kurdiks =kurdi  (SgTr  >kurd !22_S	et	f	\N
171064	kurdiks	kurdiks =kurdi  (SgTr  >kurt !22_AS	et	f	\N
171071	valgustuse	valgustuse =valgustuse  (SgG  >valgustus !11_S	et	f	\N
171072	valgustuse	"valgustus %valgusta  )US_vS  <valgustama ;27_V	et	f	\N
171075	toatemperatuuri	toatemperatuuri =temperatuuri  (SgG  >toa+temperatuur !22_S	et	f	\N
171076	toatemperatuuri	toatemperatuuri =temperatuuri  (SgP  >toa+temperatuur !22_S	et	f	\N
171077	toatemperatuuri	toatemperatuuri =temperatuuri  (SgAdt  >toa+temperatuur !22_S	et	f	\N
171110	lihast	lihast =liha  (SgEl  >liha !17_S	et	f	\N
171111	lihast	lihast =lihas  (SgP  >lihas !09_S	et	f	\N
171112	lihast	lihast =lihas  (SgP  >lihane !10_A	et	f	\N
171113	lihast	"lihane %liha  )NE_aA  <liha ;17_S	et	f	\N
171118	5-d	-d =  (SgP  > !xx_Q	et	f	\N
171119	5-d	-d =  (PlN  > !xx_Q	et	f	\N
171131	jukseföön	?jukseföön =jukseföön  (SgN  >jukseföön !22_S	et	f	\N
171160	23061980a	### 23061980a	et	f	\N
171167	17-68a-3	### 17-68a-3	et	f	\N
171206	meesteks	meesteks =mees  (PlTr  >meene !10_A	et	f	\N
171207	meesteks	"meene %mee  )NE_aA  <mesi ;15_S	et	f	\N
171208	meesteks	meesteks =mees  (PlTr  >mees !13_S	et	f	\N
171211	raskeima	raskeima =raskeima  (SgG  >raskeim !02_A	et	f	\N
171212	raskeima	"raskeim %raske  )IM_sA  <raske ;01_A	et	f	\N
171213	raskeima	raskeima =ima  (SgN  >raske+ima !17_S	et	f	\N
171214	raskeima	raskeima =ima  (SgG  >raske+ima !17_S	et	f	\N
171215	raskeima	raskeima =ima  (SgP  >raske+ima !17_S	et	f	\N
171225	otsusest	otsusest =otsuse  (SgEl  >otsus !09_S	et	f	\N
171226	otsusest	otsusest =otsuses  (SgP  >otsusene !12_A	et	f	\N
171227	otsusest	"otsusene %otsuse  )NE_aA  <otsus ;09_S	et	f	\N
171228	otsusest	otsusest =use  (PlEl  >ots+usk !22_S	et	f	\N
171229	hajus	hajus =haju  (IndIpfSg3  >hajuma !27_V	et	f	\N
171230	hajus	hajus =hajus  (SgN  >hajus !02_A	et	f	\N
171262	üritasid	üritasid =ürita  (IndIpfSg2  >üritama !27_V	et	f	\N
171263	üritasid	üritasid =ürita  (IndIpfPl3  >üritama !27_V	et	f	\N
171287	dramatiseeritud	dramatiseeritud =dramatiseeri  (PtsPtIps  >dramatiseerima !28_V	et	f	\N
171288	dramatiseeritud	dramatiseeritud =dramatiseeritu  (PlN  >dramatiseeritu !01_S	et	f	\N
171289	dramatiseeritud	"dramatiseeritu %dramatiseeri  )TU1_vS  <dramatiseerima ;28_V	et	f	\N
171290	dramatiseeritud	dramatiseeritud =dramatiseeritud  (ID  >dramatiseeritud !41_A	et	f	\N
171291	dramatiseeritud	"dramatiseeritud %dramatiseeri  )TUD_vA  <dramatiseerima ;28_V	et	f	\N
171292	harimiseks	harimiseks =harimise  (SgTr  >harimine !12_S	et	f	\N
171293	harimiseks	"harimine %hari  )MINE_vS  <harima ;27_V	et	f	\N
171296	õrna	õrna =õrna  (SgG  >õrn !22_A	et	f	\N
171297	õrna	õrna =õrna  (SgP  >õrn !22_A	et	f	\N
171298	õrna	õrna =õrna  (SgAdt  >õrn !22_A	et	f	\N
171308	kivika	?kivika =kivika  (SgN  >kivika !01_S	et	f	\N
171309	kivika	?kivika =kivika  (SgG  >kivika !01_S	et	f	\N
171310	kivika	?kivika =kivika  (SgG  >kivikas !02_S	et	f	\N
171311	suure-jaani	suure-jaani =jaani  (SgG  >suure-jaan !22_S	et	f	\N
171312	suure-jaani	suure-jaani =jaani  (SgP  >suure-jaan !22_S	et	f	\N
171313	suure-jaani	suure-jaani =jaani  (SgAdt  >suure-jaan !22_S	et	f	\N
171037	muutud	"muutu %muu  )TU2_kA  <muu ;26_S	et	f	\N
171038	muutud	muutud =muutu  (IndPrSg2  >muutuma !27_V	et	f	\N
171044	bensiini	bensiini =bensiini  (SgG  >bensiin !22_S	et	f	\N
171045	bensiini	bensiini =bensiini  (SgP  >bensiin !22_S	et	f	\N
171046	bensiini	bensiini =bensiini  (SgAdt  >bensiin !22_S	et	f	\N
171080	õhukonditsioneeri	?õhukonditsioneeri =õhukonditsioneeri  (SgN  >õhukonditsioneeri !16_S	et	f	\N
171081	õhukonditsioneeri	?õhukonditsioneeri =õhukonditsioneeri  (SgG  >õhukonditsioneeri !16_S	et	f	\N
171082	õhukonditsioneeri	?õhukonditsioneeri =õhukonditsioneeri  (SgG  >õhukonditsioneer !22_S	et	f	\N
171083	õhukonditsioneeri	?õhukonditsioneeri =õhukonditsioneeri  (SgP  >õhukonditsioneer !22_S	et	f	\N
171084	õhukonditsioneeri	?õhukonditsioneeri =õhukonditsioneeri  (SgAdt  >õhukonditsioneer !22_S	et	f	\N
171085	õhukonditsioneeri	?õhukonditsioneeri =õhukonditsioneeri  (IndPrPs_  >õhukonditsioneerima !28_V	et	f	\N
171086	õhukonditsioneeri	?õhukonditsioneeri =õhukonditsioneeri  (ImpPrSg2  >õhukonditsioneerima !28_V	et	f	\N
171087	õhukonditsioneeri	?õhukonditsioneeri =tsioneeri  (SgN  >õhu+kondi+tsioneeri !16_S	et	f	\N
171088	õhukonditsioneeri	?õhukonditsioneeri =tsioneeri  (SgG  >õhu+kondi+tsioneeri !16_S	et	f	\N
171089	õhukonditsioneeri	?õhukonditsioneeri =tsioneeri  (SgG  >õhu+kondi+tsioneer !22_S	et	f	\N
171090	õhukonditsioneeri	?õhukonditsioneeri =tsioneeri  (SgP  >õhu+kondi+tsioneer !22_S	et	f	\N
171091	õhukonditsioneeri	?õhukonditsioneeri =tsioneeri  (SgAdt  >õhu+kondi+tsioneer !22_S	et	f	\N
171092	õhukonditsioneeri	?õhukonditsioneeri =konditsioneeri  (SgN  >õhu+konditsioneeri !16_S	et	f	\N
171093	õhukonditsioneeri	?õhukonditsioneeri =konditsioneeri  (SgG  >õhu+konditsioneeri !16_S	et	f	\N
171094	õhukonditsioneeri	?õhukonditsioneeri =konditsioneeri  (SgG  >õhu+konditsioneer !22_S	et	f	\N
171095	õhukonditsioneeri	?õhukonditsioneeri =konditsioneeri  (SgP  >õhu+konditsioneer !22_S	et	f	\N
171096	õhukonditsioneeri	?õhukonditsioneeri =konditsioneeri  (SgAdt  >õhu+konditsioneer !22_S	et	f	\N
171097	väljendav	väljendav =väljenda  (PtsPrPs  >väljendama !27_V	et	f	\N
171098	väljendav	väljendav =väljendav  (SgN  >väljendav !02_A	et	f	\N
171099	väljendav	"väljendav %väljenda  )V_vA  <väljendama ;27_V	et	f	\N
171103	teosammul	teosammul =teosammul  (ID  >teo+sammul !41_D	et	f	\N
171104	teosammul	teosammul =sammu  (SgAd  >teo+samm !22_S	et	f	\N
171105	teosammul	teosammul =sammu  (PlAd  >teo+samb !22_S	et	f	\N
171125	akulaadija	akulaadija =laadija  (SgN  >aku+laadija !01_S	et	f	\N
171126	akulaadija	akulaadija =laadija  (SgG  >aku+laadija !01_S	et	f	\N
171151	õõgastama	?õõgastama =õõgasta  (Sup  >õõgastama !27_V	et	f	\N
171152	õõgastama	?õõgastama =õõgastama  (SgG  >õõgastam !02_A	et	f	\N
171155	curriculum	?curriculum =curriculum  (SgN  >curriculum !19_S	et	f	\N
171156	tanvel	?tanvel =tanve  (SgAd  >tanve !06_S	et	f	\N
171157	tanvel	?tanvel =tanve  (PlAd  >tanv !22_S	et	f	\N
171158	tanvel	?tanvel =tanvel  (SgN  >tanvel !02_S	et	f	\N
171168	veltsker	?veltsker =veltsker  (SgN  >veltsker !02_S	et	f	\N
171169	2002a	### 2002a	et	f	\N
171170	1997-2000a	### 1997-2000a	et	f	\N
171183	tolle	tolle =tolle  (SgG  >too !00_P	et	f	\N
171184	tolle	tolle =tolle  (PlP  >toll !22_S	et	f	\N
171190	ühtsusest	ühtsusest =ühtsuse  (SgEl  >ühtsus !11~09_S	et	f	\N
171191	ühtsusest	"ühtsus %ühtse  )US_aS  <ühtne ;02_A	et	f	\N
171192	ühtsusest	ühtsusest =ühtsuses  (SgP  >ühtsusene !12_A	et	f	\N
171193	ühtsusest	"ühtsusene %ühtsuse  )NE_aA  <ühtsus ;09_S	et	f	\N
171194	ühtsusest	"ühtsusene %ühtsuse  )NE_aA  <ühtsus ;11_S	et	f	\N
171199	esitaksid	esitaksid =esita  (KndPrSg2  >esitama !27_V	et	f	\N
171200	esitaksid	esitaksid =esita  (KndPrPl3  >esitama !27_V	et	f	\N
171201	esitaksid	esitaksid =taksi  (PlN  >esi+taks !22_S	et	f	\N
171219	tekkitab	?tekkitab =tekkita  (IndPrSg3  >tekkitama !27_V	et	f	\N
171220	jatta	?jatta =jatta  (ID  >jatta !41_D	et	f	\N
171221	jatta	?jatta =jatta  (IndPrPs_  >jattama !29_V	et	f	\N
171222	jatta	?jatta =jatta  (ImpPrSg2  >jattama !29_V	et	f	\N
171231	reaalsust	reaalsust =reaalsus  (SgP  >reaalsus !11~09_S	et	f	\N
171232	reaalsust	"reaalsus %reaalse  )US_aS  <reaalne ;02_A	et	f	\N
171233	sulest	sulest =sule  (SgEl  >sulg !22_S	et	f	\N
171234	sulest	sulest =sule  (PlEl  >sulg !22_S	et	f	\N
171235	sulest	sulest =sules  (SgP  >sulene !10_A	et	f	\N
171236	sulest	"sulene %sule  )NE_aA  <sulg ;22_S	et	f	\N
171250	hukatusse	hukatusse =hukatu  (SgIll  >hukatu !01_S	et	f	\N
171251	hukatusse	"hukatu %huka  )TU1_vS  <hukkama ;29_V	et	f	\N
171252	hukatusse	hukatusse =hukatus  (SgAdt  >hukatus !11_S	et	f	\N
171253	hukatusse	"hukatus %huka  )TUS1_aS  <hukkama ;29_V	et	f	\N
171257	keerulisem	keerulisem =keerulisem  (SgN  >keerulisem !02_A	et	f	\N
171258	keerulisem	"keerulisem %keeru  )LISEM_cA  <keerd ;22_SA	et	f	\N
171259	keerulisem	"keerulisem %keerulise  )M_cA  <keeruline ;12_A	et	f	\N
171266	kaasahaaravamaks	kaasahaaravamaks =haaravama  (SgTr  >kaasa+haaravam !02_A	et	f	\N
171267	kaasahaaravamaks	"kaasa+haaravam %haarava  )M_cA  <kaasa+haarav ;02_A	et	f	\N
171279	punaarmeelaste	punaarmeelaste =las  (PlG  >puna+armee+laps !14_S	et	f	\N
171280	punaarmeelaste	punaarmeelaste =laste  (PlP  >puna+armee+last !22_S	et	f	\N
171281	punaarmeelaste	punaarmeelaste =armeelas  (PlG  >puna+armeelane !12?10_S	et	f	\N
171241	tagamaid	tagamaid =mai  (SgP  >taga+mai !26_S	et	f	\N
171248	tolleaegsetel	tolleaegsetel =sete  (PlAd  >tolle+aeg+sett !22_S	et	f	\N
171249	tolleaegsetel	tolleaegsetel =aegse  (PlAd  >tolle+aegne !02_A	et	f	\N
171270	martast	?martast =marta  (SgEl  >marta !16_S	et	f	\N
171271	martast	?martast =martas  (SgP  >martas !07_S	et	f	\N
171272	martast	?martast =martas  (SgP  >martane !12~10_A	et	f	\N
171273	teadukohaselt	teadukohaselt =kohase  (SgAbl  >teadu+kohane !10_A	et	f	\N
171274	teadukohaselt	"teadu+kohane %koha  )NE_aA  <teadu+koha ;17_S	et	f	\N
171275	teadukohaselt	"teadu+kohane %koha  )NE_aA  <teadu+koht ;22_S	et	f	\N
171276	teadukohaselt	"teadu+kohaselt %koha  )SELT_mD  <teadu+koha ;17_S	et	f	\N
171277	teadukohaselt	"teadu+kohaselt %koha  )SELT_mD  <teadu+koht ;22_S	et	f	\N
171278	teadukohaselt	"teadu+kohaselt %kohase  )LT_mD  <teadu+kohane ;10_A	et	f	\N
171294	õppijail	õppijail =õppija  (PlAd  >õppija !01_S	et	f	\N
171295	õppijail	"õppija %õppi  )JA_vS  <õppima ;28_V	et	f	\N
171305	võõrale	võõrale =võõra  (SgAll  >võõras !07_AS	et	f	\N
171306	võõrale	võõrale =ale  (SgN  >võõr+ale !16_S	et	f	\N
171307	võõrale	võõrale =ale  (SgG  >võõr+ale !16_S	et	f	\N
171349	rannu	?rannu =rannu  (SgN  >rannu !16_S	et	f	\N
171350	rannu	?rannu =rannu  (SgG  >rannu !16_S	et	f	\N
171351	rannu	?rannu =rannu  (IndPrPs_  >rannuma !27_V	et	f	\N
171352	rannu	?rannu =rannu  (ImpPrSg2  >rannuma !27_V	et	f	\N
171358	indu	indu =indu  (SgP  >ind !22_S	et	f	\N
171359	indu	indu =indu  (SgAdt  >ind !22_S	et	f	\N
171360	indu	indu =indu  (PlP  >ind !22_S	et	f	\N
171384	lavastajana	lavastajana =lavastaja  (SgEs  >lavastaja !01_S	et	f	\N
171385	lavastajana	"lavastaja %lavasta  )JA_vS  <lavastama ;27_V	et	f	\N
171422	puhkema	puhkema =puhke  (Sup  >puhkema !27_V	et	f	\N
171423	puhkema	puhkema =ema  (SgN  >puhk+ema !17_S	et	f	\N
171424	puhkema	puhkema =ema  (SgG  >puhk+ema !17_S	et	f	\N
171425	puhkema	puhkema =ema  (SgP  >puhk+ema !17_S	et	f	\N
171439	hetkelise	hetkelise =hetkelise  (SgG  >hetkeline !12_A	et	f	\N
171440	hetkelise	"hetkeline %hetke  )LINE_aA  <hetk ;22_S	et	f	\N
171450	rahvalemmikuks	rahvalemmikuks =uks  (SgN  >rahva+lemmik+uks !14_S	et	f	\N
171451	rahvalemmikuks	rahvalemmikuks =lemmiku  (SgTr  >rahva+lemmik !02_S	et	f	\N
171452	täheldanud	täheldanud =tähelda  (PtsPtPs  >täheldama !27_V	et	f	\N
171453	täheldanud	täheldanud =täheldanu  (PlN  >täheldanu !01_S	et	f	\N
171454	täheldanud	"täheldanu %tähelda  )NU_vS  <täheldama ;27_V	et	f	\N
171455	täheldanud	täheldanud =täheldanud  (ID  >täheldanud !41_A	et	f	\N
171456	täheldanud	"täheldanud %tähelda  )NUD_vA  <täheldama ;27_V	et	f	\N
171460	asjatult	asjatult =asjatu  (SgAbl  >asjatu !01_A	et	f	\N
171461	asjatult	"asjatu %asja  )TU2_kA  <asi ;24_S	et	f	\N
171462	asjatult	asjatult =asjatult  (ID  >asjatult !41_D	et	f	\N
171463	asjatult	"asjatult %asja  )TULT2_mD  <asi ;24_S	et	f	\N
171464	asjatult	"asjatult %asjatu  )LT_mD  <asjatu ;01_A	et	f	\N
171470	populaarsust	populaarsust =populaarsus  (SgP  >populaarsus !11~09_S	et	f	\N
171471	populaarsust	"populaarsus %populaarse  )US_aS  <populaarne ;02_A	et	f	\N
171472	meediakära	meediakära =kära  (SgN  >meedia+kära !17_S	et	f	\N
171473	meediakära	meediakära =kära  (SgG  >meedia+kära !17_S	et	f	\N
171474	meediakära	meediakära =kära  (SgP  >meedia+kära !17_S	et	f	\N
171483	vahelt	vahelt =vahe  (SgAbl  >vahe !16_S	et	f	\N
171484	vahelt	vahelt =vahe  (PlAbl  >vahk !22_S	et	f	\N
171485	vahelt	vahelt =vahe  (PlAbl  >vaht !22_S	et	f	\N
171486	vahelt	vahelt =vahelt  (ID  >vahelt !41_DK	et	f	\N
171515	korvavad	korvavad =korva  (IndPrPl3  >korvama !29_V	et	f	\N
171516	korvavad	korvavad =korvava  (PlN  >korvav !02_A	et	f	\N
171517	korvavad	"korvav %korva  )V_vA  <korvama ;29_V	et	f	\N
171518	korvavad	korvavad =ava  (PlN  >korv+ava !17_S	et	f	\N
171541	arenguloo	arenguloo =loo  (SgG  >arengu+lugu !18_S	et	f	\N
171542	arenguloo	arenguloo =loo  (SgG  >arengu+loog !22_S	et	f	\N
171543	arenguloo	arenguloo =loo  (SgG  >arengu+lood !22_S	et	f	\N
171554	argo	?argo =argo  (SgN  >argo !16_S	et	f	\N
171555	argo	?argo =argo  (SgG  >argo !16_S	et	f	\N
171557	aardam	?aardam =aardam  (SgN  >aardam !02_A	et	f	\N
171563	alo	?alo =alo  (SgN  >alo !17~16_S	et	f	\N
171564	alo	?alo =alo  (SgG  >alo !17~16_S	et	f	\N
171565	alo	?alo =alo  (SgP  >alo !17_S	et	f	\N
171574	rahvusriiki	rahvusriiki =riiki  (SgP  >rahvus+riik !22_S	et	f	\N
171575	rahvusriiki	rahvusriiki =riiki  (SgAdt  >rahvus+riik !22_S	et	f	\N
171590	mõttetud	mõttetud =mõttetu  (PlN  >mõttetu !01_A	et	f	\N
171591	mõttetud	"mõttetu %mõtte  )TU2_kA  <mõte ;06_S	et	f	\N
171596	inimen	?inimen =inimen  (SgN  >inimen !19_S	et	f	\N
171620	teadmatust	teadmatust =teadmatu  (SgEl  >teadmatu !01_A	et	f	\N
171621	teadmatust	"teadmatu %tead  )MATU_vA  <teadma ;34_V	et	f	\N
171622	teadmatust	teadmatust =teadmatus  (SgP  >teadmatus !11_S	et	f	\N
171623	teadmatust	"teadmatus %tead  )MATUS_aS  <teadma ;34_V	et	f	\N
171624	teadmatust	teadmatust =tust  (SgN  >teadma+tust !22_S	et	f	\N
171639	julgemad	julgemad =julgema  (PlN  >julgem !02_A	et	f	\N
171640	julgemad	"julgem %julge  )M_cA  <julge ;01_A	et	f	\N
171261	gümnaasiumipoisid	gümnaasiumipoisid =poisi  (PlN  >gümnaasiumi+poiss !23?22_S	et	f	\N
171268	intrigeerivamaks	intrigeerivamaks =intrigeerivama  (SgTr  >intrigeerivam !02_A	et	f	\N
171269	intrigeerivamaks	"intrigeerivam %intrigeeri  )VAM_cA  <intrigeerima ;28_V	et	f	\N
171282	meeleheitest	meeleheitest =heite  (SgEl  >meele+heide !06_S	et	f	\N
171283	meeleheitest	meeleheitest =heites  (SgP  >meele+heitene !12~10_A	et	f	\N
171284	meeleheitest	"meele+heitene %heite  )NE_aA  <meele+heide ;06_S	et	f	\N
171285	tekitasid	tekitasid =tekita  (IndIpfSg2  >tekitama !27_V	et	f	\N
171286	tekitasid	tekitasid =tekita  (IndIpfPl3  >tekitama !27_V	et	f	\N
171320	löögisalu	löögisalu =salu  (SgN  >löögi+salu !17_S	et	f	\N
171321	löögisalu	löögisalu =salu  (SgG  >löögi+salu !17_S	et	f	\N
171322	löögisalu	löögisalu =salu  (SgP  >löögi+salu !17_S	et	f	\N
171329	1936a	### 1936a	et	f	\N
171330	kujutav	kujutav =kujuta  (PtsPrPs  >kujutama !27_V	et	f	\N
171331	kujutav	kujutav =kujutav  (SgN  >kujutav !02_A	et	f	\N
171332	kujutav	"kujutav %kujuta  )V_vA  <kujutama ;27_V	et	f	\N
171333	veenev	veenev =veen  (PtsPrPs  >veenma !33_V	et	f	\N
171334	veenev	veenev =veenev  (SgN  >veenev !02_A	et	f	\N
171335	veenev	"veenev %veen  )V_vA  <veenma ;33_V	et	f	\N
171340	võrtsjärve	võrtsjärve =järve  (SgG  >võrts+järv !22_S	et	f	\N
171341	võrtsjärve	võrtsjärve =järve  (SgP  >võrts+järv !22_S	et	f	\N
171342	võrtsjärve	võrtsjärve =järve  (SgAdt  >võrts+järv !22_S	et	f	\N
171343	võrtsjärve	võrtsjärve =järve  (PlP  >võrts+järv !22_S	et	f	\N
171361	kogemustest	kogemustest =kogemus  (PlEl  >kogemus !11_S	et	f	\N
171362	kogemustest	kogemustest =test  (SgN  >kogemus+test !22_S	et	f	\N
171379	kodumaarmastuse	?kodumaarmastuse =kodumaarmastuse  (SgG  >kodumaarmastus !11~09_S	et	f	\N
171380	kodumaarmastuse	?kodumaarmastuse =maarmastuse  (SgG  >kodu+maarmastus !11_S	et	f	\N
171381	1954a	### 1954a	et	f	\N
171395	klassiruumi	klassiruumi =ruumi  (SgG  >klassi+ruum !22_S	et	f	\N
171396	klassiruumi	klassiruumi =ruumi  (SgP  >klassi+ruum !22_S	et	f	\N
171397	klassiruumi	klassiruumi =ruumi  (SgAdt  >klassi+ruum !22_S	et	f	\N
171410	häiriv	häiriv =häiri  (PtsPrPs  >häirima !28_V	et	f	\N
171411	häiriv	häiriv =häiriv  (SgN  >häiriv !02_A	et	f	\N
171412	häiriv	"häiriv %häiri  )V_vA  <häirima ;28_V	et	f	\N
171415	köitev	köitev =köit  (PtsPrPs  >köitma !34_V	et	f	\N
171416	köitev	köitev =köitev  (SgN  >köitev !02_A	et	f	\N
171417	köitev	"köitev %köit  )V_vA  <köitma ;34_V	et	f	\N
171420	tormasid	tormasid =torma  (IndIpfSg2  >tormama !29_V	et	f	\N
171421	tormasid	tormasid =torma  (IndIpfPl3  >tormama !29_V	et	f	\N
171426	vastast	vastast =vastas  (SgP  >vastane !10_AS	et	f	\N
171427	vastast	vastast =vastast  (ID  >vastast !41_DK	et	f	\N
171428	vastast	vastast =ast  (SgN  >vast+ast !22_S	et	f	\N
171432	pikemana	pikemana =pikema  (SgEs  >pikem !02_A	et	f	\N
171433	pikemana	"pikem %pike  )M_cA  <pikk ;22_AS	et	f	\N
171434	toimunudki	toimunudki =toimu  (PtsPtPs^  >toimuma !27_V	et	f	\N
171435	toimunudki	toimunudki =toimunu  (PlN^  >toimunu !01_S	et	f	\N
171436	toimunudki	"toimunu %toimu  )NU_vS^  <toimuma ;27_V	et	f	\N
171437	toimunudki	toimunudki =toimunud  (ID^  >toimunud !41_A	et	f	\N
171438	toimunudki	"toimunud %toimu  )NUD_vA^  <toimuma ;27_V	et	f	\N
171443	ebatäpsusi	ebatäpsusi =täpsusi  (PlP  >eba+täpsus !11_S	et	f	\N
171444	ebatäpsusi	"eba+täpsus %täpsa  )US_aS  <eba+täppis ;02_A	et	f	\N
171445	ebatäpsusi	"eba+täpsus %täpse  )US_aS  <eba+täpne ;02_A	et	f	\N
171465	koormata	koormata =koorma  (SgAb  >koorem !02_S	et	f	\N
171466	koormata	koormata =koorma  (Inf  >koormama !29_V	et	f	\N
171467	koormata	koormata =koorma  (IndPrIps_  >koormama !29_V	et	f	\N
171496	pealetungiga	pealetungiga =iga  (SgN  >peale+tung+iga !18_S	et	f	\N
171497	pealetungiga	pealetungiga =iga  (SgP  >peale+tung+iga !18_S	et	f	\N
171498	pealetungiga	pealetungiga =tungi  (SgKom  >peale+tung !22_S	et	f	\N
171504	iseseisvunud	iseseisvunud =seisvu  (PtsPtPs  >ise+seisvuma !27_V	et	f	\N
171505	iseseisvunud	iseseisvunud =seisvunu  (PlN  >ise+seisvunu !01_S	et	f	\N
171513	filmidki	filmidki =filmi  (PlN^  >film !22_S	et	f	\N
171514	filmidki	filmidki =filmi  (IndPrSg2^  >filmima !28_V	et	f	\N
171528	faktitruult	faktitruult =truu  (SgAbl  >fakti+truu !26_A	et	f	\N
171529	faktitruult	"fakti+truult %truu  )LT_mD  <fakti+truu ;26_A	et	f	\N
171535	keskkooliõpilastest	keskkooliõpilastest =test  (SgN  >kesk+kooli+õpilas+test !22_S	et	f	\N
171536	keskkooliõpilastest	keskkooliõpilastest =las  (PlEl  >kesk+kooli+õpi+laps !14_S	et	f	\N
171537	keskkooliõpilastest	keskkooliõpilastest =laste  (PlEl  >kesk+kooli+õpi+last !22_S	et	f	\N
171538	keskkooliõpilastest	keskkooliõpilastest =õpilas  (PlEl  >kesk+kooli+õpilane !12_S	et	f	\N
171545	kivikat	?kivikat =kivika  (SgP  >kivika !01_S	et	f	\N
171546	kivikat	?kivikat =kivika  (SgP  >kivikas !02_S	et	f	\N
171547	astahov	?astahov =astahov  (SgN  >astahov !02_A	et	f	\N
171560	karol	?karol =karo  (SgAd  >karo !17~16_S	et	f	\N
171562	karol	?karol =karol  (SgN  >karol !02_S	et	f	\N
171578	truudus	truudus =truudus  (SgN  >truudus !11~09_S	et	f	\N
171579	truudus	"truudus %truu  )US_aS  <truu ;26_A	et	f	\N
171592	vääriline	vääriline =vääriline  (SgN  >vääriline !12_A	et	f	\N
171299	aimugi	aimugi =aimu  (SgG^  >aim !22_S	et	f	\N
171300	aimugi	aimugi =aimu  (SgP^  >aim !22_S	et	f	\N
171301	aimugi	aimugi =aimu  (SgAdt^  >aim !22_S	et	f	\N
171302	aimugi	aimugi =aimu  (PlP^  >aim !22_S	et	f	\N
171303	aimugi	aimugi =aimu  (IndPrPs_^  >aimuma !27_V	et	f	\N
171304	aimugi	aimugi =aimu  (ImpPrSg2^  >aimuma !27_V	et	f	\N
171314	nooremal	nooremal =noorema  (SgAd  >noorem !02_A	et	f	\N
171315	nooremal	"noorem %noore  )M_cA  <noor ;13_AS	et	f	\N
171316	nooremal	nooremal =ema  (SgAd  >noor+ema !17_S	et	f	\N
171317	noorsoo	noorsoo =soo  (SgN  >noor+soo !26_S	et	f	\N
171318	noorsoo	noorsoo =soo  (SgG  >noor+sugu !18_S	et	f	\N
171319	noorsoo	noorsoo =soo  (SgG  >noor+soo !26_S	et	f	\N
171336	teenitult	teenitult =teenitu  (SgAbl  >teenitu !01_AS	et	f	\N
171337	teenitult	"teenitu %teeni  )TU1_vS  <teenima ;28_V	et	f	\N
171338	teenitult	teenitult =teenitult  (ID  >teenitult !41_D	et	f	\N
171339	teenitult	"teenitult %teeni  )TULT1_mD  <teenima ;28_V	et	f	\N
171353	valgutas	?valgutas =valguta  (IndIpfSg3  >valgutama !27_V	et	f	\N
171354	valgutas	?valgutas =uta  (SgIn  >valg+uta !16_S	et	f	\N
171355	valgutas	?valgutas =utas  (SgN  >valg+utas !07_S	et	f	\N
171371	argusest	argusest =arguse  (SgEl  >argus !11~09_S	et	f	\N
171372	argusest	"argus %arg  )US_aS  <arg ;22_A	et	f	\N
171373	argusest	argusest =arguses  (SgP  >argusene !12_A	et	f	\N
171374	argusest	"argusene %arguse  )NE_aA  <argus ;09_S	et	f	\N
171375	argusest	"argusene %arguse  )NE_aA  <argus ;11_S	et	f	\N
171376	argusest	argusest =use  (PlEl  >arg+usk !22_S	et	f	\N
171386	kriitilisem	kriitilisem =kriitilisem  (SgN  >kriitilisem !02_A	et	f	\N
171387	kriitilisem	"kriitilisem %kriitilise  )M_cA  <kriitiline ;12_A	et	f	\N
171388	paneks	paneks =pane  (PlTr  >pan !19_S	et	f	\N
171389	paneks	paneks =pane  (KndPrPs  >panema !36_V	et	f	\N
171407	noormeeste	noormeeste =mees  (PlG  >noor+meene !10_A	et	f	\N
171408	noormeeste	"noor+meene %mee  )NE_aA  <noor+mesi ;15_S	et	f	\N
171409	noormeeste	noormeeste =mees  (PlG  >noor+mees !13_S	et	f	\N
171429	iva	iva =iva  (SgN  >iva !17_S	et	f	\N
171430	iva	iva =iva  (SgG  >iva !17_S	et	f	\N
171431	iva	iva =iva  (SgP  >iva !17_S	et	f	\N
171468	tulevikuta	tulevikuta =tuleviku  (SgAb  >tulevik !25_S	et	f	\N
171469	tulevikuta	tulevikuta =viku  (SgAb  >tule+vikk !22_S	et	f	\N
171481	vaatamisel	vaatamisel =vaatamise  (SgAd  >vaatamine !12_S	et	f	\N
171482	vaatamisel	"vaatamine %vaata  )MINE_vS  <vaatama ;29_V	et	f	\N
171487	klassiuksest	klassiuksest =ukse  (SgEl  >klassi+uks !14_S	et	f	\N
171488	klassiuksest	klassiuksest =ukses  (SgP  >klassi+uksene !10_A	et	f	\N
171489	klassiuksest	"klassi+uksene %ukse  )NE_aA  <klassi+uks ;14_S	et	f	\N
171506	populaarsusele	populaarsusele =populaarsuse  (SgAll  >populaarsus !11~09_S	et	f	\N
171507	populaarsusele	"populaarsus %populaarse  )US_aS  <populaarne ;02_A	et	f	\N
171511	elutempo	elutempo =tempo  (SgN  >elu+tempo !16_S	et	f	\N
171512	elutempo	elutempo =tempo  (SgG  >elu+tempo !16_S	et	f	\N
171523	erilisel	erilisel =erilise  (SgAd  >eriline !12_A	et	f	\N
171524	erilisel	"eriline %eri  )LINE_aA  <eri ;17_S	et	f	\N
171570	käsper	?käsper =käsper  (SgN  >käsper !02_S	et	f	\N
171573	tääker	?tääker =tääker  (SgN  >tääker !02_S	et	f	\N
171580	ustavus	ustavus =ustavus  (SgN  >ustavus !11_S	et	f	\N
171581	ustavus	"ustavus %us  )TAVUS_aS  <uskuma ;28_V	et	f	\N
171582	ustavus	"ustavus %ustava  )US_aS  <ustav ;02_A	et	f	\N
171594	heasüdamlikkus	heasüdamlikkus =südamlikkus  (SgN  >hea+südamlikkus !11~09_S	et	f	\N
171595	heasüdamlikkus	"hea+südamlikkus %südamlikku  )US_aS  <hea+südamlik ;25_A	et	f	\N
171597	võigemas	?võigemas =võige  (SupIn  >võigema !27_V	et	f	\N
171598	võigemas	?võigemas =võigema  (SgIn  >võigem !02_A	et	f	\N
171599	võigemas	?võigemas =gema  (SgIn  >või+gema !17_S	et	f	\N
171600	võigemas	?võigemas =gemas  (SgN  >või+gemas !09_S	et	f	\N
171601	andekas	andekas =andeka  (SgIn  >andekas !02_A	et	f	\N
171602	andekas	andekas =andekas  (SgN  >andekas !02_A	et	f	\N
171603	vabadusel	vabadusel =vabaduse  (SgAd  >vabadus !11_S	et	f	\N
171604	vabadusel	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
171609	maeterlinck	### maeterlinck	et	f	\N
171613	varjutud	varjutud =varju  (PtsPtIps  >varjuma !27_V	et	f	\N
171614	varjutud	varjutud =varjutu  (PlN  >varjutu !01_AS	et	f	\N
171615	varjutud	"varjutu %varju  )TU1_vS  <varjuma ;27_V	et	f	\N
171616	varjutud	"varjutu %varju  )TU2_kA  <vari ;24_S	et	f	\N
171617	varjutud	varjutud =varjutu  (IndPrSg2  >varjutuma !27_V	et	f	\N
171618	varjutud	varjutud =varjutud  (ID  >varjutud !41_A	et	f	\N
171619	varjutud	"varjutud %varju  )TUD_vA  <varjuma ;27_V	et	f	\N
171633	muljedest	?muljedest =muljedes  (SgP  >muljedene !12_A	et	f	\N
171657	isamaale	isamaale =maa  (SgAll  >isa+maa !26_S	et	f	\N
171658	isamaale	isamaale =maale  (PlP  >isa+maal !22_S	et	f	\N
171676	hõngu	hõngu =hõngu  (SgG  >hõng !22_S	et	f	\N
171677	hõngu	hõngu =hõngu  (SgP  >hõng !22_S	et	f	\N
171678	hõngu	hõngu =hõngu  (SgAdt  >hõng !22_S	et	f	\N
171679	hõngu	hõngu =hõngu  (IndPrPs_  >hõnguma !27_V	et	f	\N
171680	hõngu	hõngu =hõngu  (ImpPrSg2  >hõnguma !27_V	et	f	\N
171344	punaarmeed	punaarmeed =armee  (PlN  >puna+armee !26_S	et	f	\N
171345	punaarmeed	punaarmeed =armee  (SgP  >puna+armee !26_S	et	f	\N
171356	jaanuarikuul	jaanuarikuul =kuu  (SgAd  >jaanuari+kuu !26_S	et	f	\N
171357	jaanuarikuul	jaanuarikuul =kuul  (SgN  >jaanuari+kuul !22_S	et	f	\N
171363	julgusest	julgusest =julguse  (SgEl  >julgus !11~09_S	et	f	\N
171364	julgusest	"julgus %julge  )US_aS  <julge ;01_A	et	f	\N
171365	julgusest	julgusest =julguses  (SgP  >julgusene !12_A	et	f	\N
171366	julgusest	"julgusene %julguse  )NE_aA  <julgus ;09_S	et	f	\N
171367	julgusest	"julgusene %julguse  )NE_aA  <julgus ;11_S	et	f	\N
171382	südamelähedasem	südamelähedasem =lähedasem  (SgN  >südame+lähedasem !02_A	et	f	\N
171383	südamelähedasem	"südame+lähedasem %lähedase  )M_cA  <südame+lähedane ;12_AS	et	f	\N
171393	sisenemine	sisenemine =sisenemine  (SgN  >sisenemine !12_S	et	f	\N
171394	sisenemine	"sisenemine %sisene  )MINE_vS  <sisenema ;27_V	et	f	\N
171413	taustamuusika	taustamuusika =muusika  (SgN  >tausta+muusika !01_S	et	f	\N
171414	taustamuusika	taustamuusika =muusika  (SgG  >tausta+muusika !01_S	et	f	\N
171448	maadriiki	maadriiki =riiki  (SgP  >maad+riik !22_S	et	f	\N
171449	maadriiki	maadriiki =riiki  (SgAdt  >maad+riik !22_S	et	f	\N
171475	ammutanud	ammutanud =ammuta  (PtsPtPs  >ammutama !27_V	et	f	\N
171476	ammutanud	ammutanud =ammutanu  (PlN  >ammutanu !01_S	et	f	\N
171477	ammutanud	"ammutanu %ammuta  )NU_vS  <ammutama ;27_V	et	f	\N
171478	ammutanud	ammutanud =ammutanud  (ID  >ammutanud !41_A	et	f	\N
171479	ammutanud	"ammutanud %ammuta  )NUD_vA  <ammutama ;27_V	et	f	\N
171480	ammutanud	ammutanud =tanu  (PlN  >ammu+tanu !17_S	et	f	\N
171492	kadedustunne	kadedustunne =unne  (SgAdt  >kadedust+uni !20_S	et	f	\N
171493	kadedustunne	kadedustunne =tunne  (SgN  >kadedus+tunne !06_S	et	f	\N
171502	verehinda	verehinda =hinda  (SgP  >vere+hind !22_S	et	f	\N
171503	verehinda	verehinda =hinda  (SgAdt  >vere+hind !22_S	et	f	\N
171521	viljakamaid	viljakamaid =viljakama  (PlP  >viljakam !02_A	et	f	\N
171522	viljakamaid	"viljakam %viljaka  )M_cA  <viljakas ;02_A	et	f	\N
171525	peateos	peateos =teo  (SgIn  >pea+tegu !18_S	et	f	\N
171526	peateos	peateos =teo  (SgIn  >pea+tigu !18_S	et	f	\N
171527	peateos	peateos =teos  (SgN  >pea+teos !09_S	et	f	\N
171533	lahinguteed	lahinguteed =tee  (PlN  >lahingu+tee !26_S	et	f	\N
171534	lahinguteed	lahinguteed =tee  (SgP  >lahingu+tee !26_S	et	f	\N
171544	murdab	?murdab =murda  (IndPrSg3  >murdama !29_V	et	f	\N
171548	võigemast	?võigemast =võige  (SupEl  >võigema !27_V	et	f	\N
171549	võigemast	?võigemast =võigema  (SgEl  >võigem !02_A	et	f	\N
171550	võigemast	?võigemast =võigemas  (SgP  >võigemane !12_A	et	f	\N
171551	võigemast	?võigemast =gema  (SgEl  >või+gema !17_S	et	f	\N
171552	võigemast	?võigemast =gemas  (SgP  >või+gemas !09_S	et	f	\N
171553	võigemast	?võigemast =gemas  (SgP  >või+gemane !10_A	et	f	\N
171558	kohlapuu	?kohlapuu =kohlapuu  (SgN  >kohlapuu !26_S	et	f	\N
171559	kohlapuu	?kohlapuu =kohlapuu  (SgG  >kohlapuu !26_S	et	f	\N
171576	kavalus	kavalus =kavalus  (SgN  >kavalus !11_S	et	f	\N
171577	kavalus	"kavalus %kavala  )US_aS  <kaval ;02_A	et	f	\N
171583	ebakindlus	ebakindlus =kindlus  (SgN  >eba+kindlus !11~09_S	et	f	\N
171584	ebakindlus	"eba+kindlus %kindla  )US_aS  <eba+kindel ;02_A	et	f	\N
171608	maurice	### maurice	et	f	\N
171611	alistumine	alistumine =alistumine  (SgN  >alistumine !12_S	et	f	\N
171612	alistumine	"alistumine %alistu  )MINE_vS  <alistuma ;27_V	et	f	\N
171634	idealiseeritud	idealiseeritud =idealiseeri  (PtsPtIps  >idealiseerima !28_V	et	f	\N
171635	idealiseeritud	idealiseeritud =idealiseeritu  (PlN  >idealiseeritu !01_S	et	f	\N
171636	idealiseeritud	"idealiseeritu %idealiseeri  )TU1_vS  <idealiseerima ;28_V	et	f	\N
171637	idealiseeritud	idealiseeritud =idealiseeritud  (ID  >idealiseeritud !41_A	et	f	\N
171638	idealiseeritud	"idealiseeritud %idealiseeri  )TUD_vA  <idealiseerima ;28_V	et	f	\N
171641	kartmatud	kartmatud =kartmatu  (PlN  >kartmatu !01_A	et	f	\N
171642	kartmatud	"kartmatu %kart  )MATU_vA  <kartma ;34_V	et	f	\N
171661	helde	helde =helde  (SgN  >helde !01_A	et	f	\N
171662	helde	helde =helde  (SgG  >helde !01_A	et	f	\N
171696	kallima	kallima =kallima  (SgG  >kallim !02_AS	et	f	\N
171697	kallima	"kallim %kalli  )M_cA  <kallis ;05_A	et	f	\N
171698	kallima	"kallim %kalli  )M_cA  <kallis ;07_A	et	f	\N
171706	eelkäiatest	?eelkäiatest =eelkäiates  (SgP  >eelkäiatene !12_A	et	f	\N
171707	eelkäiatest	?eelkäiatest =käiates  (SgP  >eel+käiatene !12_A	et	f	\N
171712	haarata	haarata =haara  (SgAb  >haar !22_S	et	f	\N
171713	haarata	haarata =haara  (Inf  >haarama !29_V	et	f	\N
171714	haarata	haarata =haara  (IndPrIps_  >haarama !29_V	et	f	\N
171715	noorelt	noorelt =noore  (SgAbl  >noor !13_AS	et	f	\N
171716	noorelt	noorelt =noorelt  (ID  >noorelt !41_D	et	f	\N
171717	noorelt	"noorelt %noore  )LT_mD  <noor ;13_AS	et	f	\N
171718	otsides	otsides =otsi  (PlIn  >ots !22_S	et	f	\N
171719	otsides	otsides =otsi  (Ger  >otsima !28_V	et	f	\N
171725	samanimelisel	samanimelisel =nimelise  (SgAd  >sama+nimeline !12_A	et	f	\N
171726	samanimelisel	"sama+nimeline %nime  )LINE_aA  <sama+nimi ;20_S	et	f	\N
171727	sõjasosalenute	?sõjasosalenute =sõjasosalenu  (PlG  >sõjasosalenu !01_S	et	f	\N
171346	lahingutesse	lahingutesse =lahingu  (PlIll  >lahing !02_S	et	f	\N
171347	lahingutesse	lahingutesse =ute  (SgIll  >lahing+utt !22_S	et	f	\N
171348	lahingutesse	lahingutesse =ute  (PlIll  >lahing+utt !22_S	et	f	\N
171368	lahingutes	lahingutes =lahingu  (PlIn  >lahing !02_S	et	f	\N
171369	lahingutes	lahingutes =ute  (SgIn  >lahing+utt !22_S	et	f	\N
171370	lahingutes	lahingutes =ute  (PlIn  >lahing+utt !22_S	et	f	\N
171377	rinda	rinda =rinda  (SgP  >rind !22_S	et	f	\N
171378	rinda	rinda =rinda  (SgAdt  >rind !22_S	et	f	\N
171390	eelnenu	eelnenu =eelnenu  (SgN  >eelnenu !01_S	et	f	\N
171391	eelnenu	"eelnenu %eelne  )NU_vS  <eelnema ;27_V	et	f	\N
171392	eelnenu	eelnenu =eelnenu  (SgG  >eelnenu !01_S	et	f	\N
171398	kaotust	kaotust =kaotu  (SgEl  >kaotu !01_A	et	f	\N
171399	kaotust	"kaotu %kao  )TU1_vS  <kaduma ;28_V	et	f	\N
171400	kaotust	"kaotu %kao  )TU2_kA  <kabu ;18_S	et	f	\N
171401	kaotust	"kaotu %kao  )TU2_kA  <kadu ;18_S	et	f	\N
171402	kaotust	kaotust =kaotus  (SgP  >kaotus !11~09_S	et	f	\N
171403	kaotust	"kaotus %kaota  )US_vS  <kaotama ;27_V	et	f	\N
171404	kaotust	"kaotus %kao  )TUS1_aS  <kaduma ;28_V	et	f	\N
171405	kaotust	"kaotus %kao  )TUS2_aS  <kabu ;18_S	et	f	\N
171406	kaotust	"kaotus %kao  )TUS2_aS  <kadu ;18_S	et	f	\N
171418	kohana	kohana =koha  (SgEs  >koha !17_S	et	f	\N
171419	kohana	kohana =koha  (SgEs  >koht !22_S	et	f	\N
171441	lahingust	lahingust =lahingu  (SgEl  >lahing !02_S	et	f	\N
171442	lahingust	lahingust =us  (SgP  >lahing+uks !14_S	et	f	\N
171446	nautitav	?nautitav =nautita  (PtsPrPs  >nautitama !27_V	et	f	\N
171447	nautitav	?nautitav =nautitav  (SgN  >nautitav !02_A	et	f	\N
171457	huvituvad	huvituvad =huvitu  (IndPrPl3  >huvituma !27_V	et	f	\N
171458	huvituvad	huvituvad =huvituva  (PlN  >huvituv !02_A	et	f	\N
171459	huvituvad	"huvituv %huvitu  )V_vA  <huvituma ;27_V	et	f	\N
171490	mõistmatuks	mõistmatuks =mõistmatu  (SgTr  >mõistmatu !01_A	et	f	\N
171491	mõistmatuks	"mõistmatu %mõist  )MATU_vA  <mõistma ;34_V	et	f	\N
171494	punaarmee	punaarmee =armee  (SgN  >puna+armee !26_S	et	f	\N
171495	punaarmee	punaarmee =armee  (SgG  >puna+armee !26_S	et	f	\N
171499	maksid	maksid =maks  (IndIpfSg2  >maksma !32_V	et	f	\N
171500	maksid	maksid =maks  (IndIpfPl3  >maksma !32_V	et	f	\N
171501	maksid	maksid =maksi  (PlN  >maks !22_S	et	f	\N
171508	rezissöörid	?rezissöörid =rezissööri  (PlN  >rezissööri !16_S	et	f	\N
171509	rezissöörid	?rezissöörid =rezissööri  (PlN  >rezissöör !22_S	et	f	\N
171510	rezissöörid	?rezissöörid =rezissööri  (IndPrSg2  >rezissöörima !28_V	et	f	\N
171519	teadmatuse	teadmatuse =teadmatuse  (SgG  >teadmatus !11_S	et	f	\N
171520	teadmatuse	"teadmatus %tead  )MATUS_aS  <teadma ;34_V	et	f	\N
171530	pataljoni	pataljoni =pataljoni  (SgG  >pataljon !19_S	et	f	\N
171531	pataljoni	pataljoni =pataljoni  (SgP  >pataljon !19_S	et	f	\N
171532	pataljoni	pataljoni =pataljoni  (SgAdt  >pataljon !19_S	et	f	\N
171539	vaprust	vaprust =vaprus  (SgP  >vaprus !11~09_S	et	f	\N
171540	vaprust	"vaprus %vapra  )US_aS  <vapper ;02_A	et	f	\N
171556	konsap	?konsap =konsap  (SgN  >konsap !02_S	et	f	\N
171561	martinson	?martinson =martinson  (SgN  >martinson !19_S	et	f	\N
171566	kõrve	kõrve =kõrve  (SgN  >kõrve !06_S	et	f	\N
171567	kõrve	kõrve =kõrve  (SgG  >kõrb !22_S	et	f	\N
171568	kõrve	kõrve =kõrve  (SgG  >kõrb !22_SA	et	f	\N
171569	kõrve	kõrve =kõrve  (PlP  >kõrv !22_S	et	f	\N
171571	reinthal	?reinthal =reintha  (SgAd  >reintha !01_S	et	f	\N
171572	reinthal	?reinthal =reinthal  (SgN  >reinthal !02_S	et	f	\N
171585	relvastatud	relvastatud =relvasta  (PtsPtIps  >relvastama !27_V	et	f	\N
171586	relvastatud	relvastatud =relvastatu  (PlN  >relvastatu !01_S	et	f	\N
171587	relvastatud	"relvastatu %relvasta  )TU1_vS  <relvastama ;27_V	et	f	\N
171588	relvastatud	relvastatud =relvastatud  (ID  >relvastatud !41_A	et	f	\N
171589	relvastatud	"relvastatud %relvasta  )TUD_vA  <relvastama ;27_V	et	f	\N
171625	võimetust	võimetust =võimetu  (SgEl  >võimetu !01_A	et	f	\N
171626	võimetust	"võimetu %võime  )TU2_kA  <võime ;06_S	et	f	\N
171627	võimetust	võimetust =võimetus  (SgP  >võimetus !11_S	et	f	\N
171628	võimetust	"võimetus %võime  )TUS2_aS  <võime ;06_S	et	f	\N
171629	võimetust	võimetust =tust  (SgN  >võime+tust !22_S	et	f	\N
171650	varustust	varustust =varustus  (SgP  >varustus !11_S	et	f	\N
171651	varustust	"varustus %varusta  )US_vS  <varustama ;27_V	et	f	\N
171659	isamaad	isamaad =maa  (PlN  >isa+maa !26_S	et	f	\N
171660	isamaad	isamaad =maa  (SgP  >isa+maa !26_S	et	f	\N
171674	kaasõpilastega	kaasõpilastega =las  (PlKom  >kaas+õpi+laps !14_S	et	f	\N
171675	kaasõpilastega	kaasõpilastega =õpilas  (PlKom  >kaas+õpilane !12_S	et	f	\N
171694	jõusse	jõusse =jõu  (SgIll  >jõud !22_S	et	f	\N
171695	jõusse	jõusse =jõusse  (ID  >jõusse !41_D	et	f	\N
171704	väiksegi	väiksegi =väikse  (SgG^  >väike !10_A	et	f	\N
171705	väiksegi	"väike %väi  )KE_dS^  <väi ;26_S	et	f	\N
171743	linateos	linateos =teo  (SgIn  >lina+tegu !18_S	et	f	\N
171744	linateos	linateos =teo  (SgIn  >lina+tigu !18_S	et	f	\N
171745	linateos	linateos =teos  (SgN  >lina+teos !09_S	et	f	\N
171593	vääriline	"vääriline %vääri  )LINE_aA  <väär ;22_S	et	f	\N
171605	tasuks	tasuks =tasu  (SgTr  >tasu !17_S	et	f	\N
171606	tasuks	tasuks =tasu  (KndPrPs  >tasuma !27_V	et	f	\N
171607	mõtlemiseks	mõtlemiseks =mõtlemise  (SgTr  >mõtlemine !12_S	et	f	\N
171610	mõtlemiseks	"mõtlemine %mõtle  )MINE_vS  <mõtlema ;30_V	et	f	\N
171630	laiskust	laiskust =laiskus  (SgP  >laiskus !11~09_S	et	f	\N
171631	laiskust	"laiskus %laisk  )US_aS  <laisk ;22_A	et	f	\N
171632	laiskust	laiskust =us  (SgP  >laisk+uks !14_S	et	f	\N
171645	vaprusstseenid	?vaprusstseenid =vaprusstseeni  (PlN  >vaprusstseeni !16_S	et	f	\N
171646	vaprusstseenid	?vaprusstseenid =vaprusstseeni  (PlN  >vaprusstseen !22_S	et	f	\N
171647	vaprusstseenid	?vaprusstseenid =vaprusstseeni  (IndPrSg2  >vaprusstseenima !28_V	et	f	\N
171648	ajel	ajel =aje  (SgAd  >aje !16_S	et	f	\N
171649	ajel	ajel =ajel  (ID  >ajel !41_K	et	f	\N
171652	põimuvad	põimuvad =põimu  (IndPrPl3  >põimuma !27_V	et	f	\N
171653	põimuvad	põimuvad =põimuva  (PlN  >põimuv !02_A	et	f	\N
171654	põimuvad	"põimuv %põimu  )V_vA  <põimuma ;27_V	et	f	\N
171655	neiule	neiule =neiu  (SgAll  >neiu !16_S	et	f	\N
171656	neiule	neiule =neiu  (SgAll  >neid !22_S	et	f	\N
171663	kahetsenud	kahetsenud =kahetse  (PtsPtPs  >kahetsema !27_V	et	f	\N
171664	kahetsenud	kahetsenud =kahetsenu  (PlN  >kahetsenu !01_S	et	f	\N
171665	kahetsenud	"kahetsenu %kahetse  )NU_vS  <kahetsema ;27_V	et	f	\N
171666	kahetsenud	kahetsenud =kahetsenud  (ID  >kahetsenud !41_A	et	f	\N
171667	kahetsenud	"kahetsenud %kahetse  )NUD_vA  <kahetsema ;27_V	et	f	\N
171708	tollaaegsed	?tollaaegsed =tollaaegse  (PlN  >tollaaegne !02_A	et	f	\N
171736	kiidavad	kiidavad =kiida  (IndPrPl3  >kiitma !34_V	et	f	\N
171737	kiidavad	kiidavad =ava  (PlN  >kiid+ava !17_S	et	f	\N
171787	klassitäis	klassitäis =täi  (SgIn  >klassi+täi !26_S	et	f	\N
171788	klassitäis	klassitäis =täis  (SgN  >klassi+täis !14_AS	et	f	\N
171791	hiljemlugedes	### hiljemlugedes	et	f	\N
171794	vaesest	vaesest =vaese  (SgEl  >vaene !10_AS	et	f	\N
171795	vaesest	"vaene %vae  )NE_aA  <vaag ;22_S	et	f	\N
171796	rikaste	?rikaste =rikas  (PlG  >rikas !07_A	et	f	\N
171797	rikaste	?rikaste =rikas  (PlG  >rikane !10_A	et	f	\N
171806	hukkunute	hukkunute =hukkunu  (PlG  >hukkunu !01_S	et	f	\N
171807	hukkunute	"hukkunu %hukku  )NU_vS  <hukkuma ;27_V	et	f	\N
171808	hukkunute	"hukkunu %hukku  )NU_vS  <hukkuma ;28_V	et	f	\N
171809	selgitavat	selgitavat =selgi  (KvtPrIps  >selgima !27_V	et	f	\N
171810	selgitavat	selgitavat =selgita  (KvtPrPs  >selgitama !27_V	et	f	\N
171811	selgitavat	selgitavat =selgitava  (SgP  >selgitav !02_A	et	f	\N
171812	selgitavat	"selgitav %selgi  )TAV_vAS  <selgima ;27_V	et	f	\N
171813	selgitavat	"selgitav %selgita  )V_vA  <selgitama ;27_V	et	f	\N
171821	story	### story	et	f	\N
171822	avaldajatele	avaldajatele =avaldaja  (PlAll  >avaldaja !01_S	et	f	\N
171823	avaldajatele	"avaldaja %avalda  )JA_vS  <avaldama ;27_V	et	f	\N
171854	tedmine	?tedmine =tedmine  (SgN  >tedmine !10_A	et	f	\N
171855	tedmine	?tedmine =tedmine  (IndPrPs_  >tedminema !27_V	et	f	\N
171856	tedmine	?tedmine =tedmine  (ImpPrSg2  >tedminema !27_V	et	f	\N
171857	punasevõitu	punasevõitu =võitu  (ID  >punase+võitu !41_A	et	f	\N
171858	punasevõitu	punasevõitu =võitu  (SgP  >punase+võit !22_S	et	f	\N
171859	punasevõitu	punasevõitu =võitu  (SgAdt  >punase+võit !22_S	et	f	\N
171888	antsu	?antsu =antsu  (ID  >antsu !41_D	et	f	\N
171889	antsu	?antsu =antsu  (IndPrPs_  >antsuma !28_V	et	f	\N
171890	antsu	?antsu =antsu  (ImpPrSg2  >antsuma !28_V	et	f	\N
171893	üksmeelselt	üksmeelselt =meelse  (SgAbl  >üks+meelne !02_A	et	f	\N
171894	üksmeelselt	"üks+meelselt %meelse  )LT_mD  <üks+meelne ;02_A	et	f	\N
171895	arrmutult	?arrmutult =arrmutu  (SgAbl  >arrmutu !01_AS	et	f	\N
171896	arrmutult	?arrmutult =arrmutult  (ID  >arrmutult !41_D	et	f	\N
171915	sobimatute	sobimatute =sobimatu  (PlG  >sobimatu !01_A	et	f	\N
171916	sobimatute	"sobimatu %sobi  )MATU_vA  <sobima ;27_V	et	f	\N
171917	vääratusi	vääratusi =vääratusi  (PlP  >vääratus !11_S	et	f	\N
171918	vääratusi	"vääratus %väärata  )US_vS  <vääratama ;27_V	et	f	\N
171919	vääratusi	"vääratus %väära  )TUS1_aS  <väärama ;29_V	et	f	\N
171920	vääratusi	"vääratus %väära  )TUS2_aS  <väär ;22_S	et	f	\N
171927	vaatajas	vaatajas =vaataja  (SgIn  >vaataja !01_S	et	f	\N
171928	vaatajas	"vaataja %vaata  )JA_vS  <vaatama ;29_V	et	f	\N
171970	laastava	laastava =laastava  (SgG  >laastav !02_A	et	f	\N
171971	laastava	"laastav %laasta  )V_vA  <laastama ;27_V	et	f	\N
171972	laastava	"laastav %laasta  )V_vA  <laastama ;29_V	et	f	\N
171973	toimiks	toimiks =toimi  (SgTr  >toim !22_S	et	f	\N
171974	toimiks	toimiks =toimi  (PlTr  >toim !22_S	et	f	\N
171975	toimiks	toimiks =toimi  (KndPrPs  >toimima !28_V	et	f	\N
171982	kuuluv	kuuluv =kuulu  (PtsPrPs  >kuuluma !27_V	et	f	\N
171983	kuuluv	kuuluv =kuuluv  (SgN  >kuuluv !02_A	et	f	\N
171984	kuuluv	"kuuluv %kuulu  )V_vA  <kuuluma ;27_V	et	f	\N
171991	kohustuslikus	kohustuslikus =kohustusliku  (SgIn  >kohustuslik !25_A	et	f	\N
171992	kohustuslikus	kohustuslikus =kohustuslikus  (SgN  >kohustuslikus !11?09_S	et	f	\N
171993	kohustuslikus	"kohustuslikus %kohustusliku  )US_aS  <kohustuslik ;25_A	et	f	\N
171643	heroiseeri	heroiseeri =heroiseeri  (IndPrPs_  >heroiseerima !28_V	et	f	\N
171644	heroiseeri	heroiseeri =heroiseeri  (ImpPrSg2  >heroiseerima !28_V	et	f	\N
171668	pensiooniealistel	?pensiooniealistel =pensiooniealis  (PlAd  >pensiooniealis !09_S	et	f	\N
171669	pensiooniealistel	?pensiooniealistel =pensiooniealis  (PlAd  >pensiooniealine !12_A	et	f	\N
171670	pensiooniealistel	?pensiooniealistel =pensiooniealiste  (PlAd  >pensiooniealist !22_S	et	f	\N
171671	pensiooniealistel	?pensiooniealistel =ooniealis  (PlAd  >pensi+ooniealis !09_S	et	f	\N
171672	pensiooniealistel	?pensiooniealistel =ooniealis  (PlAd  >pensi+ooniealine !12_A	et	f	\N
171673	pensiooniealistel	?pensiooniealistel =ooniealiste  (PlAd  >pensi+ooniealist !22_S	et	f	\N
171684	võimetesse	võimetesse =võime  (PlIll  >võime !06_S	et	f	\N
171685	võimetesse	võimetesse =me  (PlIll  >või+mesi !15_S	et	f	\N
171686	võimetesse	võimetesse =mete  (PlIll  >või+mett !22_S	et	f	\N
171687	suhtesse	suhtesse =suhte  (SgIll  >suhe !06_S	et	f	\N
171688	suhtesse	suhtesse =suhtes  (SgAdt  >suhtene !12_A	et	f	\N
171689	suhtesse	"suhtene %suhte  )NE_aA  <suhe ;06_S	et	f	\N
171702	vaatamisele	vaatamisele =vaatamise  (SgAll  >vaatamine !12_S	et	f	\N
171703	vaatamisele	"vaatamine %vaata  )MINE_vS  <vaatama ;29_V	et	f	\N
171730	jutuksoleva	?jutuksoleva =jutuksoleva  (SgN  >jutuksoleva !16_S	et	f	\N
171731	jutuksoleva	?jutuksoleva =jutuksoleva  (SgG  >jutuksolev !02_A	et	f	\N
171732	jutuksoleva	?jutuksoleva =jutuksoleva  (SgG  >jutuksoleva !16_S	et	f	\N
171733	jutuksoleva	?jutuksoleva =ksoleva  (SgN  >jutu+ksoleva !01_S	et	f	\N
171734	jutuksoleva	?jutuksoleva =ksoleva  (SgG  >jutu+ksoleva !01_S	et	f	\N
171735	jutuksoleva	?jutuksoleva =ksoleva  (SgG  >jutu+ksolev !02_A	et	f	\N
171738	materdavad	materdavad =materda  (IndPrPl3  >materdama !27_V	et	f	\N
171739	materdavad	materdavad =materdava  (PlN  >materdav !02_A	et	f	\N
171740	materdavad	"materdav %materda  )V_vA  <materdama ;27_V	et	f	\N
171754	pealetungil	pealetungil =tungi  (SgAd  >peale+tung !22_S	et	f	\N
171755	pealetungil	pealetungil =tungi  (PlAd  >peale+tung !22_S	et	f	\N
171756	soomusrogi	?soomusrogi =rogi  (SgN  >soomus+rogi !17_S	et	f	\N
171757	soomusrogi	?soomusrogi =rogi  (SgG  >soomus+rogi !17_S	et	f	\N
171758	soomusrogi	?soomusrogi =rogi  (SgP  >soomus+rogi !17_S	et	f	\N
171759	soomusrogi	?soomusrogi =musrogi  (SgG  >soo+musrog !02_S	et	f	\N
171760	soomusrogi	?soomusrogi =soomusro  (SgN^  >soomusro !16_S	et	f	\N
171761	soomusrogi	?soomusrogi =soomusro  (SgG^  >soomusro !16_S	et	f	\N
171762	soomusrogi	?soomusrogi =musro  (SgN^  >soo+musro !16_S	et	f	\N
171763	soomusrogi	?soomusrogi =musro  (SgG^  >soo+musro !16_S	et	f	\N
171772	sümboliseerida	sümboliseerida =sümboliseeri  (Inf  >sümboliseerima !28_V	et	f	\N
171773	sümboliseerida	sümboliseerida =rida  (SgN  >sümboli+see+rida !18_S	et	f	\N
171774	sümboliseerida	sümboliseerida =rida  (SgP  >sümboli+see+rida !18_S	et	f	\N
171789	ekraaniaega	ekraaniaega =aega  (SgP  >ekraani+aeg !22_S	et	f	\N
171790	ekraaniaega	ekraaniaega =aega  (SgAdt  >ekraani+aeg !22_S	et	f	\N
171814	patriotistlikult	?patriotistlikult =patriotistliku  (SgAbl  >patriotistlik !25_A	et	f	\N
171815	patriotistlikult	?patriotistlikult =patriotistlikult  (ID  >patriotistlikult !41_D	et	f	\N
171828	sõjafilmi	sõjafilmi =filmi  (SgG  >sõja+film !22_S	et	f	\N
171829	sõjafilmi	sõjafilmi =filmi  (SgP  >sõja+film !22_S	et	f	\N
171830	sõjafilmi	sõjafilmi =filmi  (SgAdt  >sõja+film !22_S	et	f	\N
171831	väida	väida =väida  (IndPrPs_  >väitma !34_V	et	f	\N
171832	väida	väida =väida  (ImpPrSg2  >väitma !34_V	et	f	\N
171848	dramaatiiiselt	?dramaatiiiselt =dramaatiiise  (SgAbl  >dramaatiiise !16_S	et	f	\N
171849	dramaatiiiselt	?dramaatiiiselt =dramaatiiise  (PlAbl  >dramaatiiis !22_S	et	f	\N
171850	dramaatiiiselt	?dramaatiiiselt =dramaatiiiselt  (ID  >dramaatiiiselt !41_D	et	f	\N
171851	lohutav	lohutav =lohuta  (PtsPrPs  >lohutama !27_V	et	f	\N
171852	lohutav	lohutav =lohutav  (SgN  >lohutav !02_A	et	f	\N
171853	lohutav	"lohutav %lohuta  )V_vA  <lohutama ;27_V	et	f	\N
171862	lahingusse	lahingusse =lahingu  (SgIll  >lahing !02_S	et	f	\N
171863	lahingusse	lahingusse =usse  (PlP  >lahing+uss !22_S	et	f	\N
171871	omariiklust	omariiklust =lust  (SgN  >oma+riik+lust !22_S	et	f	\N
171872	omariiklust	omariiklust =riiklus  (SgP  >oma+riiklus !11~09_S	et	f	\N
171873	omariiklust	"oma+riiklus %riiklase  )US_aS  <oma+riiklane ;12_S	et	f	\N
171883	uskuvad	uskuvad =uskuva  (PlN  >uskuv !02_A	et	f	\N
171884	uskuvad	"uskuv %usku  )V_vA  <uskuma ;28_V	et	f	\N
171885	lõpuosast	lõpuosast =osa  (SgEl  >lõpu+osa !17_S	et	f	\N
171886	lõpuosast	lõpuosast =osas  (SgP  >lõpu+osane !10_A	et	f	\N
171887	lõpuosast	"lõpu+osane %osa  )NE_aA  <lõpu+osa ;17_S	et	f	\N
171899	kahjutuks	kahjutuks =kahjutu  (SgTr  >kahjutu !01_A	et	f	\N
171900	kahjutuks	"kahjutu %kahju  )TU2_kA  <kahju ;16_S	et	f	\N
171901	kahjutuks	"kahjutu %kahju  )TU2_kA  <kahju ;17_S	et	f	\N
171902	kahjutuks	"kahjutu %kahju  )TU2_kA  <kahi ;24_S	et	f	\N
171903	kahjutuks	kahjutuks =tuks  (SgN  >kahju+tuks !22_S	et	f	\N
171931	meelelahutusega	meelelahutusega =lahutuse  (SgKom  >meele+lahutus !11_S	et	f	\N
171932	meelelahutusega	"meele+lahutus %lahu  )TUS2_aS  <meele+lahk ;22_S	et	f	\N
171964	filmiski	filmiski =filmi  (SgIn^  >film !22_S	et	f	\N
171965	filmiski	filmiski =filmi  (IndIpfSg3^  >filmima !28_V	et	f	\N
171681	hullemasse	hullemasse =hullema  (SgIll  >hullem !02_A	et	f	\N
171682	hullemasse	"hullem %hulle  )M_cA  <hull ;22_AS	et	f	\N
171683	hullemasse	hullemasse =ema  (SgIll  >hull+ema !17_S	et	f	\N
171690	martasse	?martasse =marta  (SgIll  >marta !16_S	et	f	\N
171691	martasse	?martasse =martas  (SgAdt  >martane !12_A	et	f	\N
171692	martasse	?martasse =martasse  (SgG  >martasne !02_A	et	f	\N
171693	martasse	?martasse =martasse  (PlP  >martass !22_S	et	f	\N
171699	ühti	ühti =ühti  (ID  >ühti !41_D	et	f	\N
171700	ühti	ühti =ühti  (IndPrPs_  >ühtima !27_V	et	f	\N
171701	ühti	ühti =ühti  (ImpPrSg2  >ühtima !27_V	et	f	\N
171709	erinevamad	erinevamad =erinevama  (PlN  >erinevam !02_A	et	f	\N
171710	erinevamad	"erinevam %erine  )VAM_cA  <erinema ;27_V	et	f	\N
171711	erinevamad	"erinevam %erineva  )M_cA  <erinev ;02_A	et	f	\N
171720	siin-	siin- =siin  (ID  >siin !41_D	et	f	\N
171721	siin-	siin- =siin  (SgN  >siin !22_S	et	f	\N
171722	versus	?versus =versu  (SgIn  >versu !16_S	et	f	\N
171723	versus	?versus =versu  (IndIpfSg3  >versuma !27_V	et	f	\N
171724	versus	?versus =versus  (SgN  >versus !11~09_S	et	f	\N
171742	vaadatuim	?vaadatuim =vaadatuim  (SgN  >vaadatuim !02_A	et	f	\N
171746	teostusel	teostusel =teostuse  (SgAd  >teostus !11~09_S	et	f	\N
171747	teostusel	"teostus %teosta  )US_vS  <teostama ;27_V	et	f	\N
171748	ajamomenti	ajamomenti =momenti  (SgP  >aja+moment !22_S	et	f	\N
171749	ajamomenti	ajamomenti =momenti  (SgAdt  >aja+moment !22_S	et	f	\N
171752	teostuses	teostuses =teostuse  (SgIn  >teostus !11~09_S	et	f	\N
171753	teostuses	"teostus %teosta  )US_vS  <teostama ;27_V	et	f	\N
171777	ainüksi	?ainüksi =ainüksi  (SgN  >ainüksi !01_S	et	f	\N
171778	ainüksi	?ainüksi =ainüksi  (SgG  >ainüksi !01_S	et	f	\N
171779	ainüksi	?ainüksi =ainüksi  (SgG  >ainüks !02_S	et	f	\N
171780	ainüksi	?ainüksi =ainüksi  (IndPrPs_  >ainüksima !28_V	et	f	\N
171781	ainüksi	?ainüksi =ainüksi  (ImpPrSg2  >ainüksima !28_V	et	f	\N
171833	hollywoodlikuks	?hollywoodlikuks =hollywoodliku  (SgTr  >hollywoodlik !25_A	et	f	\N
171834	hollywoodlikuks	?hollywoodlikuks =hollywoodliku  (KndPrPs  >hollywoodlikuma !27_V	et	f	\N
171835	topitud	topitud =topi  (PtsPtIps  >toppima !28_V	et	f	\N
171836	topitud	topitud =topitu  (PlN  >topitu !01_AS	et	f	\N
171837	topitud	"topitu %topi  )TU1_vS  <toppima ;28_V	et	f	\N
171838	topitud	"topitu %topi  )TU2_kA  <topp ;22_S	et	f	\N
171839	topitud	topitud =topitud  (ID  >topitud !41_A	et	f	\N
171840	topitud	"topitud %topi  )TUD_vA  <toppima ;28_V	et	f	\N
171846	nõretavaid	nõretavaid =nõretava  (PlP  >nõretav !02_A	et	f	\N
171847	nõretavaid	"nõretav %nõreta  )V_vA  <nõretama ;27_V	et	f	\N
171860	vahelises	vahelises =vahelise  (SgIn  >vaheline !12_A	et	f	\N
171861	vahelises	"vaheline %vahe  )LINE_aA  <vahe ;16_S	et	f	\N
171869	sõdijatel	sõdijatel =sõdija  (PlAd  >sõdija !01_S	et	f	\N
171870	sõdijatel	"sõdija %sõdi  )JA_vS  <sõdima ;27_V	et	f	\N
171877	headusesse	headusesse =headuse  (SgIll  >headus !11~09_S	et	f	\N
171878	headusesse	"headus %hea  )US_aS  <hea ;26_A	et	f	\N
171879	headusesse	headusesse =headuses  (SgAdt  >headusene !12_A	et	f	\N
171880	headusesse	"headusene %headuse  )NE_aA  <headus ;09_S	et	f	\N
171881	headusesse	"headusene %headuse  )NE_aA  <headus ;11_S	et	f	\N
171882	headusesse	headusesse =use  (PlIll  >head+usk !22_S	et	f	\N
171891	seiskamise	seiskamise =seiskamise  (SgG  >seiskamine !12_S	et	f	\N
171892	seiskamise	"seiskamine %seiska  )MINE_vS  <seiskama ;29_V	et	f	\N
171897	vennalikkust	vennalikkust =vennalikkus  (SgP  >vennalikkus !11~09_S	et	f	\N
171898	vennalikkust	"vennalikkus %vennalikku  )US_aS  <vennalik ;25_A	et	f	\N
171904	fiimitegijatele	?fiimitegijatele =fiimitegija  (PlAll  >fiimitegija !01_S	et	f	\N
171905	fiimitegijatele	?fiimitegijatele =fiimitegija  (PlAll  >fiimitegijas !02_A	et	f	\N
171906	fiimitegijatele	?fiimitegijatele =fiimitegijate  (PlAll  >fiimitegijatt !22_S	et	f	\N
171907	fiimitegijatele	?fiimitegijatele =fiimitegijatele  (IndPrPs_  >fiimitegijatelema !36_V	et	f	\N
171908	fiimitegijatele	?fiimitegijatele =fiimitegijatele  (ImpPrSg2  >fiimitegijatelema !36_V	et	f	\N
171909	heidetud	heidetud =heide  (PtsPtIps  >heitma !34_V	et	f	\N
171910	heidetud	heidetud =heidetu  (PlN  >heidetu !01_S	et	f	\N
171911	heidetud	"heidetu %heide  )TU1_vS  <heitma ;34_V	et	f	\N
171912	heidetud	"heidetu %heide  )TU2_kA  <heie ;06_S	et	f	\N
171913	heidetud	heidetud =heidetud  (ID  >heidetud !41_A	et	f	\N
171914	heidetud	"heidetud %heide  )TUD_vA  <heitma ;34_V	et	f	\N
171921	nimetanud	nimetanud =nimeta  (PtsPtPs  >nimetama !27_V	et	f	\N
171922	nimetanud	nimetanud =nimetanu  (PlN  >nimetanu !01_S	et	f	\N
171923	nimetanud	"nimetanu %nimeta  )NU_vS  <nimetama ;27_V	et	f	\N
171924	nimetanud	nimetanud =nimetanud  (ID  >nimetanud !41_A	et	f	\N
171925	nimetanud	"nimetanud %nimeta  )NUD_vA  <nimetama ;27_V	et	f	\N
171926	nimetanud	nimetanud =tanu  (PlN  >nime+tanu !17_S	et	f	\N
171940	vaatajani	vaatajani =vaataja  (SgTer  >vaataja !01_S	et	f	\N
171941	vaatajani	"vaataja %vaata  )JA_vS  <vaatama ;29_V	et	f	\N
171942	kirjutist	kirjutist =kirjuti  (SgEl  >kirjuti !01_S	et	f	\N
171943	kirjutist	kirjutist =kirjutis  (SgP  >kirjutis !11_S	et	f	\N
171728	sõjasosalenute	?sõjasosalenute =sõjasosalenu  (IndPrPl2  >sõjasosalenuma !27_V	et	f	\N
171729	sõjasosalenute	?sõjasosalenute =sosalenu  (PlG  >sõja+sosalenu !01_S	et	f	\N
171741	titanicu	### titanicu	et	f	\N
171769	nä	### nä	et	f	\N
171784	tutvustust	tutvustust =tutvustus  (SgP  >tutvustus !11_S	et	f	\N
171785	tutvustust	"tutvustus %tutvusta  )US_vS  <tutvustama ;27_V	et	f	\N
171786	tutvustust	tutvustust =tust  (SgN  >tutvus+tust !22_S	et	f	\N
171792	järjekordselt	järjekordselt =kordse  (SgAbl  >järje+kordne !02_AS	et	f	\N
171793	järjekordselt	"järje+kordselt %kordse  )LT_mD  <järje+kordne ;02_AS	et	f	\N
171816	julgemata	julgemata =julge  (SupAb  >julgema !27_V	et	f	\N
171817	julgemata	julgemata =julgema  (SgAb  >julgem !02_A	et	f	\N
171818	julgemata	"julgem %julge  )M_cA  <julge ;01_A	et	f	\N
171819	julgemata	julgemata =julgemata  (ID  >julgemata !41_A	et	f	\N
171820	julgemata	"julgemata %julge  )MATA_vA  <julgema ;27_V	et	f	\N
171824	poogitust	poogitust =poogitu  (SgEl  >poogitu !01_AS	et	f	\N
171825	poogitust	"poogitu %poogi  )TU1_vS  <pookima ;28_V	et	f	\N
171826	poogitust	poogitust =poogitus  (SgP  >poogitus !11_S	et	f	\N
171827	poogitust	"poogitus %poogi  )TUS1_aS  <pookima ;28_V	et	f	\N
171843	läänelikke	?läänelikke =läänelikke  (PlP  >läänelik !25_A	et	f	\N
171874	okupeerija	okupeerija =okupeerija  (SgN  >okupeerija !01_S	et	f	\N
171875	okupeerija	"okupeerija %okupeeri  )JA_vS  <okupeerima ;28_V	et	f	\N
171876	okupeerija	okupeerija =okupeerija  (SgG  >okupeerija !01_S	et	f	\N
171933	üksikutele	üksikutele =üksiku  (PlAll  >üksik !02_A	et	f	\N
171934	üksikutele	üksikutele =ute  (SgAll  >üksik+utt !22_S	et	f	\N
171935	üksikutele	üksikutele =ute  (PlAll  >üksik+utt !22_S	et	f	\N
171936	raarnatu	?raarnatu =raarnatu  (SgN  >raarnatu !01_AS	et	f	\N
171937	raarnatu	?raarnatu =raarnatu  (SgG  >raarnatu !01_AS	et	f	\N
171938	raarnatu	?raarnatu =raarnatu  (IndPrPs_  >raarnatuma !27_V	et	f	\N
171939	raarnatu	?raarnatu =raarnatu  (ImpPrSg2  >raarnatuma !27_V	et	f	\N
171985	koolilastes	koolilastes =las  (PlIn  >kooli+laps !14_S	et	f	\N
171986	koolilastes	koolilastes =laste  (PlIn  >kooli+last !22_S	et	f	\N
171987	koolilastes	koolilastes =ilas  (PlIn  >kool+ilane !10_A	et	f	\N
171988	koolilastes	"kool+ilane %ila  )NE_aA  <kool+ila ;17_S	et	f	\N
171989	alateadlikku	alateadlikku =teadlikku  (SgP  >ala+teadlik !25_A	et	f	\N
171990	alateadlikku	alateadlikku =teadlikku  (SgAdt  >ala+teadlik !25_A	et	f	\N
171994	loetavat	loetavat =loe  (KvtPrIps  >lugema !28_V	et	f	\N
171995	loetavat	loetavat =loeta  (KvtPrPs  >loetama !27_V	et	f	\N
171996	loetavat	loetavat =loetava  (SgP  >loetav !02_AS	et	f	\N
171997	loetavat	"loetav %loe  )TAV_vAS  <lugema ;28_V	et	f	\N
171998	loetavat	"loetav %loeta  )V_vA  <loetama ;27_V	et	f	\N
172004	jä11e	?jäe =jäe  (SgN  >jäe !26_S	et	f	\N
172005	jä11e	?jäe =jäe  (SgG  >jäe !26_S	et	f	\N
172017	käsitletava	käsitletava =käsitletava  (SgG  >käsitletav !02_A	et	f	\N
172018	käsitletava	"käsitletav %käsitle  )TAV_vAS  <käsitlema ;27_V	et	f	\N
172019	erandiks	erandiks =erandi  (SgTr  >erand !02_S	et	f	\N
172020	erandiks	erandiks =iks  (SgN  >erand+iks !22_S	et	f	\N
172058	kommunisti	kommunisti =kommunisti  (SgG  >kommunist !22_S	et	f	\N
172059	kommunisti	kommunisti =kommunisti  (SgP  >kommunist !22_S	et	f	\N
172060	kommunisti	kommunisti =kommunisti  (SgAdt  >kommunist !22_S	et	f	\N
172061	käsperi	?käsperi =käsperi  (SgN  >käsperi !01_S	et	f	\N
172062	käsperi	?käsperi =käsperi  (SgG  >käsperi !01_S	et	f	\N
172063	käsperi	?käsperi =käsperi  (SgG  >käsper !02_S	et	f	\N
172081	novebril	?novebril =novebri  (SgAd  >novebri !01_S	et	f	\N
172175	puruks	puruks =puru  (SgTr  >puru !17_S	et	f	\N
172176	puruks	puruks =puruks  (ID  >puruks !41_D	et	f	\N
172177	landeswehri	?landeswehri =landeswehri  (SgG  >landeswehr !22_S	et	f	\N
172178	landeswehri	?landeswehri =landeswehri  (SgP  >landeswehr !22_S	et	f	\N
172179	landeswehri	?landeswehri =landeswehri  (SgAdt  >landeswehr !22_S	et	f	\N
172180	landeswehri	?landeswehri =landeswehri  (IndPrPs_  >landeswehrima !28_V	et	f	\N
172181	landeswehri	?landeswehri =landeswehri  (ImpPrSg2  >landeswehrima !28_V	et	f	\N
172182	kooliopisid	?kooliopisid =kooliopi  (PlP  >kooliopi !16_S	et	f	\N
172183	kooliopisid	?kooliopisid =kooliopi  (PlP  >kooliop !22_S	et	f	\N
172184	kooliopisid	?kooliopisid =kooliopi  (IndIpfSg2  >kooliopima !28_V	et	f	\N
172185	kooliopisid	?kooliopisid =kooliopi  (IndIpfPl3  >kooliopima !28_V	et	f	\N
172186	kooliopisid	?kooliopisid =opi  (PlP  >kooli+opi !16_S	et	f	\N
172187	kooliopisid	?kooliopisid =iopi  (PlP  >kool+iop !22_S	et	f	\N
172196	kaitseliitu	kaitseliitu =liitu  (SgN  >kaitse+liitu !01_A	et	f	\N
172197	kaitseliitu	"kaitse+liitu %lii  )TU2_kA  <kaitse+lii ;26_S	et	f	\N
172198	kaitseliitu	kaitseliitu =liitu  (SgG  >kaitse+liitu !01_A	et	f	\N
172199	kaitseliitu	kaitseliitu =liitu  (SgP  >kaitse+liit !22_S	et	f	\N
172200	kaitseliitu	kaitseliitu =liitu  (SgAdt  >kaitse+liit !22_S	et	f	\N
172218	toel	toel =toe  (SgAd  >tugi !21_S	et	f	\N
172219	toel	toel =toel  (ID  >toel !41_K	et	f	\N
172232	saabuvad	saabuvad =saabu  (IndPrPl3  >saabuma !27_V	et	f	\N
172233	saabuvad	saabuvad =saabuva  (PlN  >saabuv !02_A	et	f	\N
172234	saabuvad	"saabuv %saabu  )V_vA  <saabuma ;27_V	et	f	\N
171750	kirjeldava	kirjeldava =kirjeldava  (SgG  >kirjeldav !02_A	et	f	\N
171751	kirjeldava	"kirjeldav %kirjelda  )V_vA  <kirjeldama ;27_V	et	f	\N
171764	ronivad	ronivad =roni  (IndPrPl3  >ronima !27_V	et	f	\N
171765	ronivad	ronivad =roniva  (PlN  >roniv !02_A	et	f	\N
171766	ronivad	"roniv %roni  )V_vA  <ronima ;27_V	et	f	\N
171767	olnuks	olnuks =ol  (KndPtPs  >olema !36_V	et	f	\N
171768	olnuks	olnuks =olnu  (SgTr  >olnu !01_S	et	f	\N
171770	olnuks	"olnu %ol  )NU_vS  <olema ;36_V	et	f	\N
171771	olnuks	olnuks =olnu  (SgTr  >olnu !06_S	et	f	\N
171775	piisaks	piisaks =piisa  (SgTr  >piisk !22_S	et	f	\N
171776	piisaks	piisaks =piisa  (KndPrPs  >piisama !29_V	et	f	\N
171782	klassivenda	klassivenda =venda  (SgP  >klassi+vend !22_S	et	f	\N
171783	klassivenda	klassivenda =venda  (SgAdt  >klassi+vend !22_S	et	f	\N
171798	kodutare	kodutare =tare  (SgN  >kodu+tare !16_S	et	f	\N
171799	kodutare	kodutare =tare  (SgG  >kodu+tare !16_S	et	f	\N
171800	kinnitanud	kinnitanud =kinnita  (PtsPtPs  >kinnitama !27_V	et	f	\N
171801	kinnitanud	kinnitanud =kinnitanu  (PlN  >kinnitanu !01_S	et	f	\N
171802	kinnitanud	"kinnitanu %kinnita  )NU_vS  <kinnitama ;27_V	et	f	\N
171803	kinnitanud	kinnitanud =kinnitanud  (ID  >kinnitanud !41_A	et	f	\N
171804	kinnitanud	"kinnitanud %kinnita  )NUD_vA  <kinnitama ;27_V	et	f	\N
171805	kinnitanud	kinnitanud =tanu  (PlN  >kinni+tanu !17_S	et	f	\N
171841	tiiüpilisi	?tiiüpilisi =tiiüpilisi  (PlP  >tiiüpiline !12_A	et	f	\N
171842	pisaratest	pisaratest =pisara  (PlEl  >pisar !02_S	et	f	\N
171844	pisaratest	pisaratest =test  (SgN  >pisara+test !22_S	et	f	\N
171845	pisaratest	pisaratest =ate  (PlEl  >pisar+att !22_S	et	f	\N
171864	1äbi	?äbi =äbi  (SgN  >äbi !17_S	et	f	\N
171865	1äbi	?äbi =äbi  (SgG  >äbi !17_S	et	f	\N
171866	1äbi	?äbi =äbi  (SgP  >äbi !17_S	et	f	\N
171867	1äbi	?äbi =äbi  (IndPrPs_  >äbima !27_V	et	f	\N
171868	1äbi	?äbi =äbi  (ImpPrSg2  >äbima !27_V	et	f	\N
171929	seika	seika =seika  (SgP  >seik !22_S	et	f	\N
171930	seika	seika =seika  (SgAdt  >seik !22_S	et	f	\N
171947	tekitaks	tekitaks =teki  (KndPrIps  >tekkima !28_V	et	f	\N
171948	tekitaks	tekitaks =tekita  (KndPrPs  >tekitama !27_V	et	f	\N
171949	tekitaks	tekitaks =taks  (SgN  >teki+taks !22_S	et	f	\N
171959	neiti	?neiti =neiti  (ID  >neiti !41_D	et	f	\N
171960	neiti	?neiti =neiti  (SgP  >neit !22_S	et	f	\N
171961	neiti	?neiti =neiti  (SgAdt  >neit !22_S	et	f	\N
171962	igavates	igavates =igava  (PlIn  >igav !02_A	et	f	\N
171963	igavates	igavates =vate  (PlIn  >iga+vatt !22_S	et	f	\N
171966	hiljeni	?hiljeni =hilje  (SgTer  >hilje !06_S	et	f	\N
171967	hiljeni	?hiljeni =hiljeni  (SgG  >hiljen !02_S	et	f	\N
172003	registreerimaraamat	?registreerimaraamat =registreerimaraama  (SgP  >registreerimaraama !16_S	et	f	\N
172033	asetleidnud	asetleidnud =leid  (PtsPtPs  >aset+_leidma !34_V	et	f	\N
172034	asetleidnud	asetleidnud =leidnu  (PlN  >aset+leidnu !01_S	et	f	\N
172049	tungiva	tungiva =tungiva  (SgG  >tungiv !02_A	et	f	\N
172050	tungiva	"tungiv %tungi  )V_vA  <tungima ;28_V	et	f	\N
172051	tungiva	tungiva =iva  (SgN  >tung+iva !17_S	et	f	\N
172052	tungiva	tungiva =iva  (SgG  >tung+iva !17_S	et	f	\N
172053	tungiva	tungiva =iva  (SgP  >tung+iva !17_S	et	f	\N
172064	lahknevusel	lahknevusel =lahknevuse  (SgAd  >lahknevus !11_S	et	f	\N
172065	lahknevusel	"lahknevus %lahkne  )VUS_aS  <lahknema ;27_V	et	f	\N
172066	lahknevusel	"lahknevus %lahkneva  )US_aS  <lahknev ;02_A	et	f	\N
172070	saabumist	saabumist =saabumis  (SgP  >saabumine !12_S	et	f	\N
172071	saabumist	"saabumine %saabu  )MINE_vS  <saabuma ;27_V	et	f	\N
172085	maailmarevolutsiooni	maailmarevolutsiooni =revolutsiooni  (SgG  >maa+ilma+revolutsioon !22_S	et	f	\N
172086	maailmarevolutsiooni	maailmarevolutsiooni =revolutsiooni  (SgP  >maa+ilma+revolutsioon !22_S	et	f	\N
172087	maailmarevolutsiooni	maailmarevolutsiooni =revolutsiooni  (SgAdt  >maa+ilma+revolutsioon !22_S	et	f	\N
172093	tõmbus	tõmbus =tõmbu  (IndIpfSg3  >tõmbuma !27_V	et	f	\N
172094	tõmbus	tõmbus =tõmbus  (SgN  >tõmbus !11~09_S	et	f	\N
172095	kaotustega	kaotustega =kaotus  (PlKom  >kaotus !11~09_S	et	f	\N
172096	kaotustega	"kaotus %kaota  )US_vS  <kaotama ;27_V	et	f	\N
172097	kaotustega	"kaotus %kao  )TUS1_aS  <kaduma ;28_V	et	f	\N
172098	kaotustega	"kaotus %kao  )TUS2_aS  <kabu ;18_S	et	f	\N
172099	kaotustega	"kaotus %kao  )TUS2_aS  <kadu ;18_S	et	f	\N
172119	anvelti	?anvelti =anvelti  (SgN  >anvelti !01_S	et	f	\N
172120	anvelti	?anvelti =anvelti  (SgG  >anvelti !01_S	et	f	\N
172125	va1ga	vaga =vaga  (SgN  >vaga !17_A	et	f	\N
172126	va1ga	vaga =vaga  (SgG  >vaga !17_A	et	f	\N
172127	va1ga	vaga =vaga  (SgP  >vaga !17_A	et	f	\N
172128	paistati	?paistati =paista  (IndIpfIps  >paistama !27_V	et	f	\N
172129	paistati	?paistati =paistati  (ID  >paistati !41_D	et	f	\N
172130	paistati	?paistati =paistati  (SgG  >paistat !02_S	et	f	\N
172131	paistati	?paistati =paistati  (SgG  >paistatt !22_S	et	f	\N
172132	paistati	?paistati =paistati  (IndPrPs_  >paistattima !28_V	et	f	\N
172133	paistati	?paistati =paistati  (ImpPrSg2  >paistattima !28_V	et	f	\N
172134	paistati	?paistati =stati  (SgN  >pai+stati !16_S	et	f	\N
172135	paistati	?paistati =stati  (SgG  >pai+stati !16_S	et	f	\N
171944	nooruspõlves	nooruspõlves =põlve  (SgIn  >noorus+põlv !22_S	et	f	\N
171945	nooruspõlves	nooruspõlves =põlve  (SgIn  >noorus+põli !24_S	et	f	\N
171946	nooruspõlves	nooruspõlves =põlve  (PlIn  >noorus+põlv !22_S	et	f	\N
171950	tekkest	tekkest =tekke  (SgEl  >teke !06_S	et	f	\N
171951	tekkest	tekkest =tekkes  (SgP  >tekkene !12~10_A	et	f	\N
171952	tekkest	"tekkene %tekke  )NE_aA  <teke ;06_S	et	f	\N
171953	leiutanud	leiutanud =leiuta  (PtsPtPs  >leiutama !27_V	et	f	\N
171954	leiutanud	leiutanud =leiutanu  (PlN  >leiutanu !01_S	et	f	\N
171955	leiutanud	"leiutanu %leiuta  )NU_vS  <leiutama ;27_V	et	f	\N
171956	leiutanud	leiutanud =leiutanud  (ID  >leiutanud !41_A	et	f	\N
171957	leiutanud	"leiutanud %leiuta  )NUD_vA  <leiutama ;27_V	et	f	\N
171958	leiutanud	leiutanud =tanu  (PlN  >leiu+tanu !17_S	et	f	\N
171976	toosama	?toosama =toosa  (Sup  >toosama !29_V	et	f	\N
171977	toosama	?toosama =toosama  (SgG  >toosam !02_A	et	f	\N
172001	laenutamiseks	laenutamiseks =laenutamise  (SgTr  >laenutamine !12_S	et	f	\N
172002	laenutamiseks	"laenutamine %laenuta  )MINE_vS  <laenutama ;27_V	et	f	\N
172021	lõppemisega	lõppemisega =lõppemise  (SgKom  >lõppemine !12_S	et	f	\N
172022	lõppemisega	"lõppemine %lõppe  )MINE_vS  <lõppema ;27_V	et	f	\N
172023	lõppemisega	"lõppemine %lõppe  )MINE_vS  <lõppema ;28_V	et	f	\N
172024	lõppemisega	lõppemisega =emise  (SgKom  >lõpp+emis !09_S	et	f	\N
172054	raamatuna	raamatuna =raamatu  (SgEs  >raamat !02_S	et	f	\N
172055	raamatuna	raamatuna =atu  (SgEs  >raam+att !22_S	et	f	\N
172075	päästekomitee	päästekomitee =komitee  (SgN  >pääste+komitee !26_S	et	f	\N
172076	päästekomitee	päästekomitee =komitee  (SgG  >pääste+komitee !26_S	et	f	\N
172082	pealetungiks	pealetungiks =iks  (SgN  >peale+tung+iks !22_S	et	f	\N
172083	pealetungiks	pealetungiks =tungi  (SgTr  >peale+tung !22_S	et	f	\N
172084	pealetungiks	pealetungiks =tungi  (PlTr  >peale+tung !22_S	et	f	\N
172107	valgarakvere	?valgarakvere =kvere  (SgN  >valg+ara+kvere !16_S	et	f	\N
172108	valgarakvere	?valgarakvere =kvere  (SgG  >valg+ara+kvere !16_S	et	f	\N
172123	peatati	peatati =peata  (IndIpfIps  >peatama !27_V	et	f	\N
172124	peatati	peatati =tati  (SgG  >pea+tatt !22_S	et	f	\N
172157	ülemjuhataja	ülemjuhataja =juhataja  (SgN  >ülem+juhataja !01_S	et	f	\N
172158	ülemjuhataja	ülemjuhataja =juhataja  (SgG  >ülem+juhataja !01_S	et	f	\N
172188	omakaitsesse	omakaitsesse =kaitse  (SgIll  >oma+kaitse !06_S	et	f	\N
172189	omakaitsesse	omakaitsesse =kaitses  (SgAdt  >oma+kaitsene !12_A	et	f	\N
172190	omakaitsesse	"oma+kaitsene %kaitse  )NE_aA  <oma+kaitse ;06_S	et	f	\N
172191	kommertskoolis	kommertskoolis =kooli  (SgIn  >kommerts+kool !22_S	et	f	\N
172192	kommertskoolis	kommertskoolis =kooli  (PlIn  >kommerts+kool !22_S	et	f	\N
172208	vallutavad	vallutavad =valluta  (IndPrPl3  >vallutama !27_V	et	f	\N
172209	vallutavad	vallutavad =vallutava  (PlN  >vallutav !02_A	et	f	\N
172210	vallutavad	"vallutav %valluta  )V_vA  <vallutama ;27_V	et	f	\N
172253	püsimajäämise	püsimajäämise =jäämise  (SgG  >püsima+jäämine !12?10_S	et	f	\N
172254	püsimajäämise	"püsima+jäämine %jäämi  )NE_aA  <püsima+jääm ;22_S	et	f	\N
172262	kingita	kingita =kingi  (SgAb  >kink !22_S	et	f	\N
172263	kingita	kingita =kingi  (IndPrIps_  >kinkima !28_V	et	f	\N
172273	valla-	valla- =valla  (ID  >valla !41_D	et	f	\N
172274	valla-	valla- =valla  (SgG  >vald !22_S	et	f	\N
172275	ajutiselt	ajutiselt =ajutise  (SgAbl  >ajutine !12_A	et	f	\N
172276	ajutiselt	ajutiselt =ajutiselt  (ID  >ajutiselt !41_D	et	f	\N
172277	ajutiselt	"ajutiselt %ajutise  )LT_mD  <ajutine ;12_A	et	f	\N
172289	hoobi	hoobi =hoobi  (SgG  >hoop !22_S	et	f	\N
172291	hoobi	hoobi =hoobi  (SgP  >hoob !22_S	et	f	\N
172293	hoobi	hoobi =hoobi  (SgAdt  >hoob !22_S	et	f	\N
172295	hoobi	hoobi =hoobi  (PlP  >hoob !22_S	et	f	\N
172305	tähsust	?tähsust =tähsu  (SgEl  >tähsu !16_S	et	f	\N
172309	tähsust	?tähsust =tähsus  (SgP  >tähsus !11~09_S	et	f	\N
172328	langenuile	langenuile =langenu  (PlAll  >langenu !01_S	et	f	\N
172329	langenuile	"langenu %lange  )NU_vS  <langema ;27_V	et	f	\N
172330	võitle	võitle =võitle  (IndPrPs_  >võitlema !30_V	et	f	\N
172331	võitle	võitle =võitle  (ImpPrSg2  >võitlema !30_V	et	f	\N
172337	lahknemist	lahknemist =lahknemis  (SgP  >lahknemine !12_S	et	f	\N
172338	lahknemist	"lahknemine %lahkne  )MINE_vS  <lahknema ;27_V	et	f	\N
172353	arenguloos	arenguloos =loo  (SgIn  >arengu+lugu !18_S	et	f	\N
172356	arenguloos	arenguloos =loo  (SgIn  >arengu+loog !22_S	et	f	\N
172358	arenguloos	arenguloos =loo  (SgIn  >arengu+lood !22_S	et	f	\N
172359	arenguloos	arenguloos =loos  (SgN  >arengu+loos !22_S	et	f	\N
172360	makst	?makst =makst  (SgN  >makst !22_S	et	f	\N
172361	jätis	jätis =jäti  (SgIn  >jätt !22_S	et	f	\N
172362	jätis	jätis =jätis  (SgN  >jätis !09_S	et	f	\N
172373	kaitsmises	kaitsmises =kaitsmise  (SgIn  >kaitsmine !12?10_S	et	f	\N
172374	kaitsmises	"kaitsmine %kaits  )MINE_vS  <kaitsma ;32_V	et	f	\N
172384	armsama	armsama =armsama  (SgG  >armsam !02_AS	et	f	\N
172385	armsama	"armsam %armsa  )M_cA  <armas ;03_A	et	f	\N
172386	armsama	"armsam %armsa  )M_cA  <armas ;05_A	et	f	\N
172387	astuvad	astuvad =astu  (IndPrPl3  >astuma !28_V	et	f	\N
171968	purunesid	purunesid =purune  (IndIpfSg2  >purunema !27_V	et	f	\N
171969	purunesid	purunesid =purune  (IndIpfPl3  >purunema !27_V	et	f	\N
171978	telcita	?telcita =telci  (SgAb  >telci !16_S	et	f	\N
171979	telcita	?telcita =telci  (SgAb  >telc !22_S	et	f	\N
171980	telcita	?telcita =telcita  (IndPrPs_  >telcitama !27_V	et	f	\N
171981	telcita	?telcita =telcita  (ImpPrSg2  >telcitama !27_V	et	f	\N
171999	raamatukogust	raamatukogust =kogu  (SgEl  >raamatu+kogu !17_S	et	f	\N
172000	raamatukogust	raamatukogust =kogus  (SgP  >raamatu+kogus !09_S	et	f	\N
172009	äratamine	äratamine =äratamine  (SgN  >äratamine !12_S	et	f	\N
172010	äratamine	"äratamine %ärata  )MINE_vS  <äratama ;27_V	et	f	\N
172015	kinoskäinutest	kinoskäinutest =käinu  (PlEl  >kinos+käinu !01_S	et	f	\N
172016	kinoskäinutest	kinoskäinutest =käinu  (PlEl  >kinos+käinu !06_S	et	f	\N
172025	okupeerimiseni	okupeerimiseni =okupeerimise  (SgTer  >okupeerimine !12_S	et	f	\N
172026	okupeerimiseni	"okupeerimine %okupeeri  )MINE_vS  <okupeerima ;28_V	et	f	\N
172030	hoiduvad	hoiduvad =hoidu  (IndPrPl3  >hoiduma !27_V	et	f	\N
172031	hoiduvad	hoiduvad =hoiduva  (PlN  >hoiduv !02_A	et	f	\N
172032	hoiduvad	"hoiduv %hoidu  )V_vA  <hoiduma ;27_V	et	f	\N
172038	taustast	taustast =tausta  (SgEl  >taust !22_S	et	f	\N
172039	taustast	taustast =taustas  (SgP  >taustane !12~10_A	et	f	\N
172040	taustast	"taustane %tausta  )NE_aA  <taust ;22_S	et	f	\N
172041	taustast	taustast =ast  (SgN  >taust+ast !22_S	et	f	\N
172056	rängemad	rängemad =rängema  (PlN  >rängem !02_A	et	f	\N
172057	rängemad	"rängem %ränge  )M_cA  <ränk ;22_A	et	f	\N
172072	enamlastelt	enamlastelt =enamlas  (PlAbl  >enamlane !12_S	et	f	\N
172073	enamlastelt	enamlastelt =las  (PlAbl  >enam+laps !14_S	et	f	\N
172074	enamlastelt	enamlastelt =laste  (PlAbl  >enam+last !22_S	et	f	\N
172078	toimunu	toimunu =toimunu  (SgN  >toimunu !01_S	et	f	\N
172079	toimunu	"toimunu %toimu  )NU_vS  <toimuma ;27_V	et	f	\N
172080	toimunu	toimunu =toimunu  (SgG  >toimunu !01_S	et	f	\N
172088	vallandamine	vallandamine =vallandamine  (SgN  >vallandamine !12_S	et	f	\N
172089	vallandamine	"vallandamine %vallanda  )MINE_vS  <vallandama ;27_V	et	f	\N
172090	baltimaid	baltimaid =ma  (PlP  >balti+maa !26_S	et	f	\N
172091	baltimaid	baltimaid =mai  (PlN  >balti+mai !26_S	et	f	\N
172092	baltimaid	baltimaid =mai  (SgP  >balti+mai !26_S	et	f	\N
172100	aastavahetuseks	aastavahetuseks =use  (PlTr  >aasta+vahet+usk !22_S	et	f	\N
172101	aastavahetuseks	aastavahetuseks =vahetuse  (SgTr  >aasta+vahetus !11_S	et	f	\N
172102	aastavahetuseks	"aasta+vahetus %vahe  )TUS2_aS  <aasta+vahe ;16_S	et	f	\N
172103	väejuhatus	väejuhatus =juhatu  (SgIn  >väe+juhatu !01_AS	et	f	\N
172104	väejuhatus	"väe+juhatu %juha  )TU2_kA  <väe+juha ;17_S	et	f	\N
172105	väejuhatus	väejuhatus =juhatus  (SgN  >väe+juhatus !11_S	et	f	\N
172106	väejuhatus	"väe+juhatus %juha  )TUS2_aS  <väe+juha ;17_S	et	f	\N
172109	vallutatud	vallutatud =valluta  (PtsPtIps  >vallutama !27_V	et	f	\N
172110	vallutatud	vallutatud =vallutatu  (PlN  >vallutatu !01_S	et	f	\N
172111	vallutatud	"vallutatu %valluta  )TU1_vS  <vallutama ;27_V	et	f	\N
172112	vallutatud	vallutatud =vallutatud  (ID  >vallutatud !41_A	et	f	\N
172113	vallutatud	"vallutatud %valluta  )TUD_vA  <vallutama ;27_V	et	f	\N
172121	ründajatele	ründajatele =ründaja  (PlAll  >ründaja !01_S	et	f	\N
172122	ründajatele	"ründaja %ründa  )JA_vS  <ründama ;29_V	et	f	\N
172139	laidoneri	?laidoneri =laidoneri  (SgG  >laidoner !19_S	et	f	\N
172140	laidoneri	?laidoneri =laidoneri  (SgP  >laidoner !19_S	et	f	\N
172141	laidoneri	?laidoneri =laidoneri  (SgAdt  >laidoner !19_S	et	f	\N
172142	laidoneri	?laidoneri =doneri  (SgN  >lai+doneri !01_S	et	f	\N
172143	laidoneri	?laidoneri =doneri  (SgG  >lai+doneri !01_S	et	f	\N
172144	laidoneri	?laidoneri =doneri  (SgG  >lai+doner !02_S	et	f	\N
172147	varustuse	varustuse =varustuse  (SgG  >varustus !11_S	et	f	\N
172148	varustuse	"varustus %varusta  )US_vS  <varustama ;27_V	et	f	\N
172152	üksi-	üksi- =üksi  (ID  >üksi !41_D	et	f	\N
172153	üksi-	üksi- =üksi  (SgG  >üks !22_NP	et	f	\N
172154	üksi-	üksi- =üksi  (SgP  >üks !22_NP	et	f	\N
172155	üksi-	üksi- =üksi  (SgAdt  >üks !22_NP	et	f	\N
172156	üksi-	üksi- =üksi  (PlP  >üks !22_NP	et	f	\N
172193	koolipoisse	koolipoisse =poi  (SgIll  >kooli+poi !26_S	et	f	\N
172194	koolipoisse	koolipoisse =poisse  (SgG  >kooli+poise !06_S	et	f	\N
172195	koolipoisse	koolipoisse =poisse  (PlP  >kooli+poiss !23?22_S	et	f	\N
172226	helme-tõrva-hummuli	?helme-tõrva-hummuli =hummuli  (ID  >helme-tõrva-hummuli !41_D	et	f	\N
172227	helme-tõrva-hummuli	?helme-tõrva-hummuli =hummuli  (SgG  >helme-tõrva-hummul !02_S	et	f	\N
172240	võitlusesse	võitlusesse =võitluse  (SgIll  >võitlus !11~09_S	et	f	\N
172241	võitlusesse	võitlusesse =võitluses  (SgAdt  >võitlusene !12_A	et	f	\N
172242	võitlusesse	"võitlusene %võitluse  )NE_aA  <võitlus ;09_S	et	f	\N
172243	võitlusesse	"võitlusene %võitluse  )NE_aA  <võitlus ;11_S	et	f	\N
172244	aastasadade	?aastasadade =dade  (SgN  >aas+tasa+dade !16_S	et	f	\N
172245	aastasadade	?aastasadade =dade  (SgG  >aas+tasa+dade !16_S	et	f	\N
172246	sõjamees	sõjamees =mee  (SgIn  >sõja+mesi !15_S	et	f	\N
172247	sõjamees	sõjamees =mees  (SgN  >sõja+mees !13_S	et	f	\N
172006	peakski	peakski =pea  (KndPrPs^  >pida !40_V	et	f	\N
172007	peakski	peakski =pea  (SgTr^  >pea !26_S	et	f	\N
172008	peakski	peakski =pea  (KndPrPs^  >pidama !28_V	et	f	\N
172011	häbiväärselt	häbiväärselt =väärse  (SgAbl  >häbi+väärne !02_A	et	f	\N
172012	häbiväärselt	"häbi+väärselt %väärse  )LT_mD  <häbi+väärne ;02_A	et	f	\N
172013	eneseteadvust	eneseteadvust =teadvus  (SgP  >enese+teadvus !11~09_S	et	f	\N
172014	eneseteadvust	"enese+teadvus %teadva  )US_aS  <enese+teadev ;02_A	et	f	\N
172027	poliitikaelu	poliitikaelu =elu  (SgN  >poliitika+elu !17_S	et	f	\N
172028	poliitikaelu	poliitikaelu =elu  (SgG  >poliitika+elu !17_S	et	f	\N
172029	poliitikaelu	poliitikaelu =elu  (SgP  >poliitika+elu !17_S	et	f	\N
172035	allpoollähemalt	allpoollähemalt =lähema  (SgAbl  >all+pool+lähem !02_A	et	f	\N
172036	allpoollähemalt	"all+pool+lähem %lähe  )M_cA  <all+pool+lähike ;12_A	et	f	\N
172037	allpoollähemalt	"all+pool+lähemalt %lähema  )LT_mD  <all+pool+lähem ;02_A	et	f	\N
172042	lootusetusse	lootusetusse =lootusetu  (SgIll  >lootusetu !01_A	et	f	\N
172043	lootusetusse	"lootusetu %lootuse  )TU2_kA  <lootus ;09_S	et	f	\N
172044	lootusetusse	"lootusetu %lootuse  )TU2_kA  <lootus ;11_S	et	f	\N
172045	lootusetusse	lootusetusse =lootusetus  (SgAdt  >lootusetus !11_S	et	f	\N
172046	lootusetusse	"lootusetus %lootuse  )TUS2_aS  <lootus ;09_S	et	f	\N
172047	lootusetusse	"lootusetus %lootuse  )TUS2_aS  <lootus ;11_S	et	f	\N
172048	lootusetusse	lootusetusse =tusse  (PlP  >lootuse+tuss !22_S	et	f	\N
172067	manifesti	manifesti =manifesti  (SgG  >manifest !22_S	et	f	\N
172068	manifesti	manifesti =manifesti  (SgP  >manifest !22_S	et	f	\N
172069	manifesti	manifesti =manifesti  (SgAdt  >manifest !22_S	et	f	\N
172077	iiksused	?iiksused =iiksuse  (PlN  >iiksus !11~09_S	et	f	\N
172114	kommuni	?kommuni =kommu  (SgTer  >kommu !16_S	et	f	\N
172115	kommuni	?kommuni =kommuni  (SgG  >kommun !02_S	et	f	\N
172116	kommuni	?kommuni =muni  (SgN  >kom+muni !17_S	et	f	\N
172117	kommuni	?kommuni =muni  (SgG  >kom+muni !17_S	et	f	\N
172118	kommuni	?kommuni =muni  (SgP  >kom+muni !17_S	et	f	\N
172137	sundmobilatsioon	?sundmobilatsioon =sundmobilatsioon  (SgN  >sundmobilatsioon !22_S	et	f	\N
172138	sundmobilatsioon	?sundmobilatsioon =mobilatsioon  (SgN  >sund+mobilatsioon !22_S	et	f	\N
172145	nimetamine	nimetamine =nimetamine  (SgN  >nimetamine !12_S	et	f	\N
172146	nimetamine	"nimetamine %nimeta  )MINE_vS  <nimetama ;27_V	et	f	\N
172159	laidoner	?laidoner =laidoner  (SgN  >laidoner !19_S	et	f	\N
172160	laidoner	?laidoner =doner  (SgN  >lai+doner !02_S	et	f	\N
172161	landsveeri	?landsveeri =landsveeri  (SgN  >landsveeri !16_S	et	f	\N
172162	landsveeri	?landsveeri =landsveeri  (SgG  >landsveeri !16_S	et	f	\N
172163	landsveeri	?landsveeri =landsveeri  (SgG  >landsveer !22_S	et	f	\N
172164	landsveeri	?landsveeri =landsveeri  (SgP  >landsveer !22_S	et	f	\N
172165	landsveeri	?landsveeri =landsveeri  (SgAdt  >landsveer !22_S	et	f	\N
172166	landsveeri	?landsveeri =landsveeri  (IndPrPs_  >landsveerima !28_V	et	f	\N
172167	landsveeri	?landsveeri =landsveeri  (ImpPrSg2  >landsveerima !28_V	et	f	\N
172201	murdelahingutes	murdelahingutes =ute  (SgIn  >murde+lahing+utt !22_S	et	f	\N
172202	murdelahingutes	murdelahingutes =ute  (PlIn  >murde+lahing+utt !22_S	et	f	\N
172203	murdelahingutes	murdelahingutes =lahingu  (PlIn  >murde+lahing !02_S	et	f	\N
172204	kärstna	?kärstna =kärstna  (SgN  >kärstna !01_S	et	f	\N
172205	kärstna	?kärstna =kärstna  (SgG  >kärstna !01_S	et	f	\N
172206	kärstna	?kärstna =kärstna  (IndPrPs_  >kärstnama !29_V	et	f	\N
172207	kärstna	?kärstna =kärstna  (ImpPrSg2  >kärstnama !29_V	et	f	\N
172211	valguta	valguta =valgu  (SgAb  >valk !22_S	et	f	\N
172212	valguta	valguta =valgu  (IndPrIps_  >valguma !27_V	et	f	\N
172220	vastase	vastase =vastase  (SgG  >vastane !10_AS	et	f	\N
172221	vastase	vastase =ase  (SgN  >vast+ase !04_S	et	f	\N
172222	vastupealetungi	vastupealetungi =tungi  (SgG  >vastu+peale+tung !22_S	et	f	\N
172223	vastupealetungi	vastupealetungi =tungi  (SgP  >vastu+peale+tung !22_S	et	f	\N
172224	vastupealetungi	vastupealetungi =tungi  (SgAdt  >vastu+peale+tung !22_S	et	f	\N
172225	vastupealetungi	vastupealetungi =tungi  (PlP  >vastu+peale+tung !22_S	et	f	\N
172228	valga	?valga =valga  (SgN  >valga !16_S	et	f	\N
172229	valga	?valga =valga  (SgG  >valga !16_S	et	f	\N
172230	valga	?valga =valga  (IndPrPs_  >valgama !29_V	et	f	\N
172231	valga	?valga =valga  (ImpPrSg2  >valgama !29_V	et	f	\N
172278	korraldamisel	korraldamisel =korraldamise  (SgAd  >korraldamine !12_S	et	f	\N
172279	korraldamisel	"korraldamine %korralda  )MINE_vS  <korraldama ;27_V	et	f	\N
172287	surmava	surmava =surmava  (SgG  >surmav !02_A	et	f	\N
172288	surmava	"surmav %surma  )V_vA  <surmama ;29_V	et	f	\N
172290	surmava	surmava =ava  (SgN  >surm+ava !17_S	et	f	\N
172292	surmava	surmava =ava  (SgG  >surm+ava !17_S	et	f	\N
172294	surmava	surmava =ava  (SgP  >surm+ava !17_S	et	f	\N
172310	alistumise	alistumise =alistumise  (SgG  >alistumine !12_S	et	f	\N
172311	alistumise	"alistumine %alistu  )MINE_vS  <alistuma ;27_V	et	f	\N
172323	aukohal	aukohal =koha  (SgAd  >au+koha !17_S	et	f	\N
172325	aukohal	aukohal =koha  (SgAd  >au+koht !22_S	et	f	\N
172326	ristideta	ristideta =risti  (PlAb  >risti !16_S	et	f	\N
172327	ristideta	ristideta =risti  (PlAb  >rist !22_S	et	f	\N
172136	paistati	?paistati =stati  (SgG  >pai+statt !22_S	et	f	\N
172149	võitlusmoraali	võitlusmoraali =moraali  (SgG  >võitlus+moraal !22_S	et	f	\N
172150	võitlusmoraali	võitlusmoraali =moraali  (SgP  >võitlus+moraal !22_S	et	f	\N
172151	võitlusmoraali	võitlusmoraali =moraali  (SgAdt  >võitlus+moraal !22_S	et	f	\N
172168	eesti-läti	?eesti-läti =läti  (SgN  >eesti-läti !16_S	et	f	\N
172169	eesti-läti	?eesti-läti =läti  (SgG  >eesti-läti !16_S	et	f	\N
172170	eesti-läti	?eesti-läti =läti  (SgG  >eesti-lätt !22_S	et	f	\N
172171	eesti-läti	?eesti-läti =läti  (IndPrPs_  >eesti-lätima !27_V	et	f	\N
172172	eesti-läti	?eesti-läti =läti  (IndPrPs_  >eesti-lättima !28_V	et	f	\N
172173	eesti-läti	?eesti-läti =läti  (ImpPrSg2  >eesti-lätima !27_V	et	f	\N
172174	eesti-läti	?eesti-läti =läti  (ImpPrSg2  >eesti-lättima !28_V	et	f	\N
172213	rõngu	?rõngu =rõngu  (ID  >rõngu !41_D	et	f	\N
172214	rõngu	?rõngu =rõngu  (IndPrPs_  >rõnguma !27_V	et	f	\N
172215	rõngu	?rõngu =rõngu  (IndPrPs_  >rõnkuma !28_V	et	f	\N
172216	rõngu	?rõngu =rõngu  (ImpPrSg2  >rõnguma !27_V	et	f	\N
172217	rõngu	?rõngu =rõngu  (ImpPrSg2  >rõnkuma !28_V	et	f	\N
172238	tegelikkust	tegelikkust =tegelikkus  (SgP  >tegelikkus !11~09_S	et	f	\N
172239	tegelikkust	"tegelikkus %tegelikku  )US_aS  <tegelik ;25_A	et	f	\N
172255	sajanditepikkusest	sajanditepikkusest =use  (PlEl  >sajandite+pikk+usk !22_S	et	f	\N
172256	sajanditepikkusest	sajanditepikkusest =pikkuse  (SgEl  >sajandite+pikkus !11~09_S	et	f	\N
172257	sajanditepikkusest	"sajandite+pikkus %pikk  )US_aS  <sajandite+pikk ;22_AS	et	f	\N
172258	sajanditepikkusest	sajanditepikkusest =pikkuse  (SgEl  >sajandite+pikkune !12~10_A	et	f	\N
172259	sajanditepikkusest	sajanditepikkusest =pikkuses  (SgP  >sajandite+pikkusene !12_A	et	f	\N
172260	sajanditepikkusest	"sajandite+pikkusene %pikkuse  )NE_aA  <sajandite+pikkus ;09_S	et	f	\N
172261	sajanditepikkusest	"sajandite+pikkusene %pikkuse  )NE_aA  <sajandite+pikkus ;11_S	et	f	\N
172264	kallaletungi	kallaletungi =tungi  (SgG  >kallale+tung !22_S	et	f	\N
172265	kallaletungi	kallaletungi =tungi  (SgP  >kallale+tung !22_S	et	f	\N
172266	kallaletungi	kallaletungi =tungi  (SgAdt  >kallale+tung !22_S	et	f	\N
172267	kallaletungi	kallaletungi =tungi  (PlP  >kallale+tung !22_S	et	f	\N
172271	moodustamiseks	moodustamiseks =moodustamise  (SgTr  >moodustamine !12_S	et	f	\N
172272	moodustamiseks	"moodustamine %moodusta  )MINE_vS  <moodustama ;27_V	et	f	\N
172296	tunginud	tunginud =tungi  (PtsPtPs  >tungima !28_V	et	f	\N
172297	tunginud	tunginud =tunginu  (PlN  >tunginu !01_S	et	f	\N
172298	tunginud	"tunginu %tungi  )NU_vS  <tungima ;28_V	et	f	\N
172299	tunginud	tunginud =tunginud  (ID  >tunginud !41_A	et	f	\N
172300	tunginud	"tunginud %tungi  )NUD_vA  <tungima ;28_V	et	f	\N
172301	tunnustati	tunnustati =tunnusta  (IndIpfIps  >tunnustama !27_V	et	f	\N
172302	tunnustati	tunnustati =tati  (SgG  >tunnus+tatt !22_S	et	f	\N
172339	ootav	ootav =oota  (PtsPrPs  >ootama !29_V	et	f	\N
172340	ootav	ootav =ootav  (SgN  >ootav !02_A	et	f	\N
172341	ootav	"ootav %oota  )V_vA  <ootama ;29_V	et	f	\N
172394	päikesevalgust	päikesevalgust =us  (SgP  >päikese+valg+uks !14_S	et	f	\N
172395	päikesevalgust	päikesevalgust =valgu  (SgEl  >päikese+valk !22_S	et	f	\N
172396	päikesevalgust	päikesevalgust =valgus  (SgP  >päikese+valgus !11~09_S	et	f	\N
172397	päikesevalgust	"päikese+valgus %valge  )US_aS  <päikese+valge ;01_AS	et	f	\N
172408	16-	### 16-	et	f	\N
172432	opilased	?opilased =opilase  (PlN  >opilane !12_S	et	f	\N
172433	oppinud	?oppinud =oppi  (PtsPtPs  >oppima !28_V	et	f	\N
172434	oppinud	?oppinud =oppinu  (PlN  >oppinu !01_S	et	f	\N
172435	oppinud	?oppinud =oppinu  (IndPrSg2  >oppinuma !27_V	et	f	\N
172436	oppinud	?oppinud =oppinud  (ID  >oppinud !41_A	et	f	\N
172438	valismaiste	?valismaiste =valismaiste  (PlP  >valismaist !22_S	et	f	\N
172453	holliwuud	?holliwuud =holliwuu  (PlN  >holliwuu !26_S	et	f	\N
172455	holliwuud	?holliwuud =holliwuu  (SgP  >holliwuu !26_S	et	f	\N
172456	holliwuud	?holliwuud =holliwuud  (SgN  >holliwuud !22_S	et	f	\N
172462	haalduse	?haalduse =haalduse  (SgG  >haaldus !11~09_S	et	f	\N
172471	muskitirs	?muskitirs =muskitirs  (SgN  >muskitirs !22_S	et	f	\N
172500	segiajamist	segiajamist =ajami  (SgEl  >segi+ajam !02_S	et	f	\N
172501	segiajamist	segiajamist =ajamis  (SgP  >segi+ajamine !12_S	et	f	\N
172502	segiajamist	"segi+ajamine %ajami  )NE_aA  <segi+ajam ;02_S	et	f	\N
172511	toodavad	toodavad =tooda  (IndPrPl3  >tootma !34_V	et	f	\N
172512	toodavad	toodavad =toodava  (PlN  >toodav !02_A	et	f	\N
172513	toodavad	"toodav %too  )TAV_vAS  <tooma ;38_V	et	f	\N
172573	pohjuseks	?pohjuseks =pohjuse  (SgTr  >pohjus !11~09_S	et	f	\N
172588	sonalopulist	?sonalopulist =sonalopuli  (SgEl  >sonalopul !19_S	et	f	\N
172589	sonalopulist	?sonalopulist =sonalopulis  (SgP  >sonalopulis !09_S	et	f	\N
172590	sonalopulist	?sonalopulist =sonalopulis  (SgP  >sonalopuline !12_A	et	f	\N
172591	sonalopulist	?sonalopulist =sonalopulist  (SgN  >sonalopulist !22_S	et	f	\N
172598	lopud	?lopud =lopu  (PlN  >lopu !16_S	et	f	\N
172599	lopud	?lopud =lopu  (IndPrSg2  >lopuma !27_V	et	f	\N
172611	sormus	?sormus =sormu  (SgIn  >sormu !16_S	et	f	\N
172612	sormus	?sormus =sormu  (IndIpfSg3  >sormuma !27_V	et	f	\N
172613	sormus	?sormus =sormus  (SgN  >sormus !11~09_S	et	f	\N
172235	võitmisessest	?võitmisessest =võitmisesse  (SgEl  >võitmisesne !02_A	et	f	\N
172236	võitmisessest	?võitmisessest =võitmisesse  (PlEl  >võitmisess !22_S	et	f	\N
172237	võitmisessest	?võitmisessest =võitmisesses  (SgP  >võitmisessene !12_A	et	f	\N
172248	võidelnud	võidelnud =võidel  (PtsPtPs  >võitlema !30_V	et	f	\N
172249	võidelnud	võidelnud =võidelnu  (PlN  >võidelnu !01_S	et	f	\N
172250	võidelnud	"võidelnu %võidel  )NU_vS  <võitlema ;30_V	et	f	\N
172251	võidelnud	võidelnud =võidelnud  (ID  >võidelnud !41_A	et	f	\N
172252	võidelnud	"võidelnud %võidel  )NUD_vA  <võitlema ;30_V	et	f	\N
172268	mobilisatsiooni	mobilisatsiooni =mobilisatsiooni  (SgG  >mobilisatsioon !22_S	et	f	\N
172269	mobilisatsiooni	mobilisatsiooni =mobilisatsiooni  (SgP  >mobilisatsioon !22_S	et	f	\N
172270	mobilisatsiooni	mobilisatsiooni =mobilisatsiooni  (SgAdt  >mobilisatsioon !22_S	et	f	\N
172282	löi	?löi =löi  (SgN  >löi !26_S	et	f	\N
172283	löi	?löi =löi  (SgG  >löi !26_S	et	f	\N
172312	laari	laari =laari  (SgG  >laar !22_S	et	f	\N
172313	laari	laari =laari  (SgP  >laar !22_S	et	f	\N
172314	laari	laari =laari  (SgAdt  >laar !22_S	et	f	\N
172332	1920ndatel	?ndatel =ndate  (PlAd  >ndatt !22_S	et	f	\N
172333	1920ndatel	?ndatel =ndatel  (SgN  >ndatel !02_S	et	f	\N
172345	väljakannatamatu	väljakannatamatu =kannatamatu  (SgN  >välja+kannatamatu !01_A	et	f	\N
172346	väljakannatamatu	väljakannatamatu =kannatamatu  (SgG  >välja+kannatamatu !01_A	et	f	\N
172375	puneste	?puneste =punes  (PlG  >punes !09_S	et	f	\N
172376	puneste	?puneste =punes  (PlG  >punene !10_A	et	f	\N
172420	opilaste	?opilaste =opilas  (PlG  >opilane !12_S	et	f	\N
172439	rurk	?rurk =rurk  (SgN  >rurk !22_S	et	f	\N
172441	rourke	?rourke =rourke  (SgN  >rourke !06_S	et	f	\N
172442	rourke	?rourke =rourke  (SgG  >rourge !06_S	et	f	\N
172443	rourke	?rourke =rourke  (PlP  >rourk !22_S	et	f	\N
172444	rourke	?rourke =rourke  (IndPrPs_  >rourkema !27_V	et	f	\N
172445	rourke	?rourke =rourke  (ImpPrSg2  >rourkema !27_V	et	f	\N
172452	cage	?cage =cage  (SgN  >cage !16_S	et	f	\N
172454	cage	?cage =cage  (SgG  >cage !16_S	et	f	\N
172457	cage	?cage =cage  (IndPrPs_  >cagema !27_V	et	f	\N
172458	cage	?cage =cage  (ImpPrSg2  >cagema !27_V	et	f	\N
172463	jargi	?jargi =jargi  (ID  >jargi !41_D	et	f	\N
172464	jargi	?jargi =jargi  (SgG  >jark !22_S	et	f	\N
172465	jargi	?jargi =jargi  (SgP  >jarg !22_S	et	f	\N
172466	jargi	?jargi =jargi  (SgAdt  >jarg !22_S	et	f	\N
172467	jargi	?jargi =jargi  (IndPrPs_  >jarkima !28_V	et	f	\N
172468	jargi	?jargi =jargi  (ImpPrSg2  >jarkima !28_V	et	f	\N
172469	tolgitud	tolgitud =tolgitu  (PlN  >tolgitu !01_AS	et	f	\N
172470	tolgitud	"tolgitu %tolgi  )TU2_kA  <tolk ;22_S	et	f	\N
172475	oskavate	oskavate =oskava  (PlG  >oskav !02_A	et	f	\N
172476	oskavate	"oskav %oska  )V_vA  <oskama ;29_V	et	f	\N
172487	kaind	?kaind =kaind  (SgN  >kaind !02_S	et	f	\N
172514	karjaari	?karjaari =karjaari  (SgN  >karjaari !16_S	et	f	\N
172515	karjaari	?karjaari =karjaari  (SgG  >karjaari !16_S	et	f	\N
172516	karjaari	?karjaari =karjaari  (SgG  >karjaar !22_S	et	f	\N
172517	karjaari	?karjaari =karjaari  (SgP  >karjaar !22_S	et	f	\N
172518	karjaari	?karjaari =karjaari  (SgAdt  >karjaar !22_S	et	f	\N
172519	karjaari	?karjaari =karjaari  (IndPrPs_  >karjaarima !28_V	et	f	\N
172520	karjaari	?karjaari =karjaari  (ImpPrSg2  >karjaarima !28_V	et	f	\N
172521	karjaari	?karjaari =ari  (SgN  >karja+ari !17_S	et	f	\N
172522	karjaari	?karjaari =ari  (SgG  >karja+ari !17_S	et	f	\N
172523	karjaari	?karjaari =ari  (SgP  >karja+ari !17_S	et	f	\N
172534	moelda	?moelda =moelda  (SgN  >moelda !01_S	et	f	\N
172535	moelda	?moelda =moelda  (SgG  >moelda !01_S	et	f	\N
172536	moelda	?moelda =moelda  (IndPrPs_  >moeldama !27_V	et	f	\N
172537	moelda	?moelda =moelda  (ImpPrSg2  >moeldama !27_V	et	f	\N
172548	eksimuste	eksimuste =eksimus  (PlG  >eksimus !11_S	et	f	\N
172549	eksimuste	eksimuste =muste  (PlP  >eksi+must !22_AS	et	f	\N
172562	oiget	?oiget =oige  (SgP  >oige !06_S	et	f	\N
172564	nimetava	nimetava =nimetava  (SgG  >nimetav !02_A	et	f	\N
172565	nimetava	"nimetav %nimeta  )V_vA  <nimetama ;27_V	et	f	\N
172566	nimetava	nimetava =tava  (SgN  >nime+tava !17_S	et	f	\N
172567	nimetava	nimetava =tava  (SgG  >nime+tava !17_S	et	f	\N
172568	nimetava	nimetava =tava  (SgP  >nime+tava !17_S	et	f	\N
172576	valted	?valted =valte  (PlN  >valde !06_S	et	f	\N
172577	valted	?valted =valte  (IndPrSg2  >valtema !27_V	et	f	\N
172600	voimalik	?voimalik =voimalik  (SgN  >voimalik !25_A	et	f	\N
172601	pohistruktuuri	?pohistruktuuri =pohistruktuuri  (SgN  >pohistruktuuri !16_S	et	f	\N
172602	pohistruktuuri	?pohistruktuuri =pohistruktuuri  (SgG  >pohistruktuuri !16_S	et	f	\N
172603	pohistruktuuri	?pohistruktuuri =pohistruktuuri  (SgG  >pohistruktuur !22_S	et	f	\N
172604	pohistruktuuri	?pohistruktuuri =pohistruktuuri  (SgP  >pohistruktuur !22_S	et	f	\N
172605	pohistruktuuri	?pohistruktuuri =pohistruktuuri  (SgAdt  >pohistruktuur !22_S	et	f	\N
172606	pohistruktuuri	?pohistruktuuri =pohistruktuuri  (IndPrPs_  >pohistruktuurima !28_V	et	f	\N
172607	pohistruktuuri	?pohistruktuuri =pohistruktuuri  (ImpPrSg2  >pohistruktuurima !28_V	et	f	\N
172614	mangib	?mangib =mangi  (IndPrSg3  >mankima !28_V	et	f	\N
172280	enesealgatust	enesealgatust =atu  (SgEl  >enese+alg+att !22_S	et	f	\N
172281	enesealgatust	enesealgatust =algatus  (SgP  >enese+algatus !11_S	et	f	\N
172284	enamlaste	enamlaste =enamlas  (PlG  >enamlane !12_S	et	f	\N
172285	enamlaste	enamlaste =las  (PlG  >enam+laps !14_S	et	f	\N
172286	enamlaste	enamlaste =laste  (PlP  >enam+last !22_S	et	f	\N
172303	erlist	?erlist =erli  (SgEl  >erli !16_S	et	f	\N
172304	erlist	?erlist =erli  (SgEl  >erl !22_S	et	f	\N
172306	erlist	?erlist =erlis  (SgP  >erlis !09_S	et	f	\N
172307	erlist	?erlist =erlis  (SgP  >erline !10_A	et	f	\N
172308	erlist	?erlist =erlist  (SgN  >erlist !22_S	et	f	\N
172315	valinute	valinute =valinu  (PlG  >valinu !01_S	et	f	\N
172316	valinute	"valinu %vali  )NU_vS  <valima ;27_V	et	f	\N
172317	raiutud	raiutud =raiu  (PtsPtIps  >raiuma !28_V	et	f	\N
172318	raiutud	raiutud =raiutu  (PlN  >raiutu !01_AS	et	f	\N
172319	raiutud	"raiutu %raiu  )TU1_vS  <raiuma ;28_V	et	f	\N
172320	raiutud	raiutud =raiutud  (ID  >raiutud !41_A	et	f	\N
172321	raiutud	"raiutud %raiu  )TUD_vA  <raiuma ;28_V	et	f	\N
172322	seisvatele	seisvatele =seisva  (PlAll  >seisev !02_A	et	f	\N
172324	seisvatele	"seisev %seis  )V_vA  <seisma ;32_V	et	f	\N
172334	kommertsgümnaasiumi	kommertsgümnaasiumi =gümnaasiumi  (SgG  >kommerts+gümnaasium !19~02_S	et	f	\N
172335	kommertsgümnaasiumi	kommertsgümnaasiumi =gümnaasiumi  (SgP  >kommerts+gümnaasium !19_S	et	f	\N
172336	kommertsgümnaasiumi	kommertsgümnaasiumi =gümnaasiumi  (SgAdt  >kommerts+gümnaasium !19_S	et	f	\N
172342	võitlev	võitlev =võitle  (PtsPrPs  >võitlema !30_V	et	f	\N
172343	võitlev	võitlev =võitlev  (SgN  >võitlev !02_A	et	f	\N
172344	võitlev	"võitlev %võitle  )V_vA  <võitlema ;30_V	et	f	\N
172347	lahingutega	lahingutega =lahingu  (PlKom  >lahing !02_S	et	f	\N
172348	lahingutega	lahingutega =ute  (SgKom  >lahing+utt !22_S	et	f	\N
172349	henni	?henni =henni  (SgN  >henni !16_S	et	f	\N
172350	henni	?henni =henni  (SgG  >henni !16_S	et	f	\N
172351	henni	?henni =henni  (SgG  >henn !22_S	et	f	\N
172352	henni	?henni =henni  (SgP  >henn !22_S	et	f	\N
172354	henni	?henni =henni  (SgAdt  >henn !22_S	et	f	\N
172355	henni	?henni =henni  (IndPrPs_  >hennima !28_V	et	f	\N
172357	henni	?henni =henni  (ImpPrSg2  >hennima !28_V	et	f	\N
172366	maksnud	maksnud =maks  (PtsPtPs  >maksma !32_V	et	f	\N
172367	maksnud	maksnud =maksnu  (PlN  >maksnu !01_S	et	f	\N
172368	maksnud	"maksnu %maks  )NU_vS  <maksma ;32_V	et	f	\N
172369	maksnud	maksnud =maksnud  (ID  >maksnud !41_A	et	f	\N
172370	maksnud	"maksnud %maks  )NUD_vA  <maksma ;32_V	et	f	\N
172371	armastamises	armastamises =armastamise  (SgIn  >armastamine !12_S	et	f	\N
172372	armastamises	"armastamine %armasta  )MINE_vS  <armastama ;27_V	et	f	\N
172377	muidigi	?muidigi =muidi  (SgN^  >muidi !16_S	et	f	\N
172378	muidigi	?muidigi =muidi  (SgG^  >muidi !16_S	et	f	\N
172379	muidigi	?muidigi =muidi  (SgG^  >muit !22_S	et	f	\N
172380	muidigi	?muidigi =muidi  (SgP^  >muid !22_S	et	f	\N
172381	muidigi	?muidigi =muidi  (SgAdt^  >muid !22_S	et	f	\N
172382	muidigi	?muidigi =muidi  (IndPrPs_^  >muitima !28_V	et	f	\N
172383	muidigi	?muidigi =muidi  (ImpPrSg2^  >muitima !28_V	et	f	\N
172404	merekooli	merekooli =kooli  (SgG  >mere+kool !22_S	et	f	\N
172405	merekooli	merekooli =kooli  (SgP  >mere+kool !22_S	et	f	\N
172406	merekooli	merekooli =kooli  (SgAdt  >mere+kool !22_S	et	f	\N
172407	merekooli	merekooli =kooli  (PlP  >mere+kool !22_S	et	f	\N
172409	18aastaste	aastaste =aastas  (PlG  >aastane !12~10_A	et	f	\N
172410	18aastaste	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
172414	lopetanud	?lopetanud =lopeta  (PtsPtPs  >lopetama !27_V	et	f	\N
172416	lopetanud	?lopetanud =lopetanu  (PlN  >lopetanu !01_S	et	f	\N
172418	lopetanud	?lopetanud =lopetanu  (IndPrSg2  >lopetanuma !27_V	et	f	\N
172421	lopetanud	?lopetanud =lopetanud  (ID  >lopetanud !41_A	et	f	\N
172446	bruss	?bruss =bruss  (SgN  >bruss !22_S	et	f	\N
172447	bruce	?bruce =bruce  (SgN  >bruce !06_S	et	f	\N
172448	bruce	?bruce =bruce  (SgG  >bruce !06_S	et	f	\N
172480	mojul	?mojul =moju  (SgAd  >moju !17_S	et	f	\N
172482	mojul	?mojul =mojul  (SgN  >mojul !02_S	et	f	\N
172483	siukest	siukest =siukes  (SgP  >siuke !12?10_S	et	f	\N
172484	siukest	"siuke %siu  )KE_dS  <siug ;22_S	et	f	\N
172485	siukest	siukest =siukes  (SgP  >siukene !12?10_S	et	f	\N
172486	siukest	"siukene %siu  )KENE_dS  <siug ;22_S	et	f	\N
172496	raagitakse	?raagitakse =raagi  (IndPrIps  >raakima !28_V	et	f	\N
172497	raagitakse	?raagitakse =raagitakse  (SgG  >raagitakne !02_A	et	f	\N
172498	raagitakse	?raagitakse =raagitakse  (PlP  >raagitaks !22_S	et	f	\N
172499	raagitakse	?raagitakse =itakse  (SgG  >raag+itakne !02_A	et	f	\N
172555	oigekiri	?oigekiri =oigekiri  (SgG  >oigekir !19_S	et	f	\N
172556	oigekiri	?oigekiri =oigekiri  (SgP  >oigekir !19_S	et	f	\N
172557	oigekiri	?oigekiri =oigekiri  (SgAdt  >oigekir !19_S	et	f	\N
172563	valdet	?valdet =valde  (SgP  >valde !06_S	et	f	\N
172570	mootorataga	### mootorataga	et	f	\N
172571	tekkile	?tekkile =tekkile  (IndPrPs_  >tekkilema !27_V	et	f	\N
172572	tekkile	?tekkile =tekkile  (ImpPrSg2  >tekkilema !27_V	et	f	\N
172363	kustumatu	kustumatu =kustumatu  (SgN  >kustumatu !01_A	et	f	\N
172364	kustumatu	"kustumatu %kustu  )MATU_vA  <kustuma ;28_V	et	f	\N
172365	kustumatu	kustumatu =kustumatu  (SgG  >kustumatu !01_A	et	f	\N
172398	analuusitud	?analuusitud =analuusi  (PtsPtIps  >analuusima !28_V	et	f	\N
172399	analuusitud	?analuusitud =analuusitu  (PlN  >analuusitu !01_A	et	f	\N
172400	analuusitud	?analuusitud =analuusitu  (IndPrSg2  >analuusituma !27_V	et	f	\N
172401	analuusitud	?analuusitud =analuusitud  (ID  >analuusitud !41_A	et	f	\N
172402	mereakadeemia	mereakadeemia =akadeemia  (SgN  >mere+akadeemia !01_S	et	f	\N
172403	mereakadeemia	mereakadeemia =akadeemia  (SgG  >mere+akadeemia !01_S	et	f	\N
172423	sonastusopetuse	?sonastusopetuse =sonastusopetuse  (SgG  >sonastusopetus !11?09_S	et	f	\N
172424	erakooli	erakooli =kooli  (SgG  >era+kool !22_S	et	f	\N
172425	erakooli	erakooli =kooli  (SgP  >era+kool !22_S	et	f	\N
172426	erakooli	erakooli =kooli  (SgAdt  >era+kool !22_S	et	f	\N
172427	erakooli	erakooli =kooli  (PlP  >era+kool !22_S	et	f	\N
172449	nicolaz	### nicolaz	et	f	\N
172450	keidz	### keidz	et	f	\N
172451	nicolas	?nicolas =nicola  (SgIn  >nicola !01_S	et	f	\N
172461	voornimesid	### voornimesid	et	f	\N
172472	musketari	?musketari =musketari  (SgG  >musketar !19_S	et	f	\N
172473	musketari	?musketari =musketari  (SgP  >musketar !19_S	et	f	\N
172474	musketari	?musketari =musketari  (SgAdt  >musketar !19_S	et	f	\N
172477	konekeele	?konekeele =konekee  (SgAll  >konekee !26_S	et	f	\N
172478	konekeele	?konekeele =konekeele  (SgN  >konekeele !16_S	et	f	\N
172479	konekeele	?konekeele =konekeele  (SgG  >konekeele !16_S	et	f	\N
172481	konekeele	?konekeele =konekeele  (PlP  >konekeel !22_S	et	f	\N
172491	ekslikust	ekslikust =eksliku  (SgEl  >ekslik !25_A	et	f	\N
172492	ekslikust	ekslikust =ekslikus  (SgP  >ekslikus !11_S	et	f	\N
172493	ekslikust	"ekslikus %eksliku  )US_aS  <ekslik ;25_A	et	f	\N
172494	koike	koike =koike  (SgN  >koike !12?10_S	et	f	\N
172495	koike	"koike %koi  )KE_dS  <koi ;26_S	et	f	\N
172503	lemmiknaitlejaid	?lemmiknaitlejaid =lemmiknaitleja  (PlP  >lemmiknaitleja !01_S	et	f	\N
172504	lemmiknaitlejaid	?lemmiknaitlejaid =lemmiknaitleja  (PlP  >lemmiknaitlejas !02_A	et	f	\N
172505	lemmiknaitlejaid	?lemmiknaitlejaid =lemmiknaitlejai  (PlN  >lemmiknaitlejai !26_S	et	f	\N
172506	lemmiknaitlejaid	?lemmiknaitlejaid =lemmiknaitlejai  (SgP  >lemmiknaitlejai !26_S	et	f	\N
172507	lemmiknaitlejaid	?lemmiknaitlejaid =naitleja  (PlP  >lemmik+naitleja !01_S	et	f	\N
172508	lemmiknaitlejaid	?lemmiknaitlejaid =naitleja  (PlP  >lemmik+naitlejas !02_A	et	f	\N
172509	lemmiknaitlejaid	?lemmiknaitlejaid =naitlejai  (PlN  >lemmik+naitlejai !26_S	et	f	\N
172510	lemmiknaitlejaid	?lemmiknaitlejaid =naitlejai  (SgP  >lemmik+naitlejai !26_S	et	f	\N
172526	asendamist	asendamist =asendamis  (SgP  >asendamine !12_S	et	f	\N
172527	asendamist	"asendamine %asenda  )MINE_vS  <asendama ;27_V	et	f	\N
172528	opitakse	?opitakse =opi  (IndPrIps  >opima !27_V	et	f	\N
172529	opitakse	?opitakse =opi  (IndPrIps  >oppima !28_V	et	f	\N
172530	opitakse	?opitakse =opitakse  (SgG  >opitakne !02_A	et	f	\N
172531	opitakse	?opitakse =opitakse  (PlP  >opitaks !22_S	et	f	\N
172532	vois	?vois =voi  (SgIn  >voi !26_S	et	f	\N
172533	vois	?vois =vois  (SgN  >vois !22_S	et	f	\N
172545	nouab	?nouab =nouab  (SgN  >nouab !02_S	et	f	\N
172569	konsonantuhendite	?konsonantuhendite =konsonantuhendi  (IndPrPl2  >konsonantuhentima !28_V	et	f	\N
172574	voivad	?voivad =voiva  (PlN  >voiva !16_S	et	f	\N
172575	voivad	?voivad =voiva  (IndPrSg2  >voivama !29_V	et	f	\N
172579	lopu	?lopu =lopu  (SgN  >lopu !16_S	et	f	\N
172580	lopu	?lopu =lopu  (SgG  >lopu !16_S	et	f	\N
172581	lopu	?lopu =lopu  (IndPrPs_  >lopuma !27_V	et	f	\N
172582	lopu	?lopu =lopu  (ImpPrSg2  >lopuma !27_V	et	f	\N
172594	sonavormid	?sonavormid =sonavormi  (PlN  >sonavorm !22_S	et	f	\N
172595	sonavormid	?sonavormid =sonavormi  (IndPrSg2  >sonavormima !28_V	et	f	\N
172625	vmt	### vmt	et	f	\N
172634	oskamatus	oskamatus =oskamatu  (SgIn  >oskamatu !01_A	et	f	\N
172635	oskamatus	"oskamatu %oska  )MATU_vA  <oskama ;29_V	et	f	\N
172636	oskamatus	oskamatus =oskamatus  (SgN  >oskamatus !11?09_S	et	f	\N
172637	oskamatus	"oskamatus %oska  )MATUS_aS  <oskama ;29_V	et	f	\N
172661	kaandes	?kaandes =kaande  (PlIn  >kaant !22_S	et	f	\N
172662	kaandes	?kaandes =kaande  (IndIpfSg3  >kaandema !27_V	et	f	\N
172663	kaandes	?kaandes =kaandes  (SgN  >kaandes !09_S	et	f	\N
172689	eessonad	?eessonad =sona  (PlN  >ees+sona !17_S	et	f	\N
172720	sobivaks	sobivaks =sobiva  (SgTr  >sobiv !02_A	et	f	\N
172721	sobivaks	"sobiv %sobi  )V_vA  <sobima ;27_V	et	f	\N
172762	felerit	?felerit =feleri  (SgP  >feleri !01_S	et	f	\N
172763	felerit	?felerit =feleri  (SgP  >feler !02_S	et	f	\N
172776	oppijal	?oppijal =oppija  (SgAd  >oppija !01_S	et	f	\N
172780	oppijal	?oppijal =oppija  (SgAd  >oppijas !02_A	et	f	\N
172782	oppijal	?oppijal =oppijal  (SgN  >oppijal !19_S	et	f	\N
172800	parasiitsona	?parasiitsona =parasiitso  (SgEs  >parasiitso !16_S	et	f	\N
172801	parasiitsona	?parasiitsona =sona  (SgN  >para+siit+sona !17_S	et	f	\N
172802	parasiitsona	?parasiitsona =sona  (SgG  >para+siit+sona !17_S	et	f	\N
172803	parasiitsona	?parasiitsona =sona  (SgP  >para+siit+sona !17_S	et	f	\N
172388	astuvad	astuvad =astuva  (PlN  >astuv !02_A	et	f	\N
172389	astuvad	"astuv %astu  )V_vA  <astuma ;28_V	et	f	\N
172390	autobiograafiline	autobiograafiline =graafiline  (SgN  >auto+bio+graafiline !12_A	et	f	\N
172391	autobiograafiline	"auto+bio+graafiline %graafi  )LINE_aA  <auto+bio+graaf ;22_S	et	f	\N
172392	autobiograafiline	autobiograafiline =biograafiline  (SgN  >auto+biograafiline !12_A	et	f	\N
172393	autobiograafiline	"auto+biograafiline %biograafi  )LINE_aA  <auto+biograaf ;22_S	et	f	\N
172411	pohikooli	?pohikooli =pohikooli  (SgN  >pohikooli !16_S	et	f	\N
172412	pohikooli	?pohikooli =pohikooli  (SgG  >pohikooli !16_S	et	f	\N
172413	pohikooli	?pohikooli =pohikooli  (SgG  >pohikool !22_S	et	f	\N
172415	pohikooli	?pohikooli =pohikooli  (SgP  >pohikool !22_S	et	f	\N
172417	pohikooli	?pohikooli =pohikooli  (SgAdt  >pohikool !22_S	et	f	\N
172419	pohikooli	?pohikooli =pohikooli  (IndPrPs_  >pohikoolima !28_V	et	f	\N
172422	pohikooli	?pohikooli =pohikooli  (ImpPrSg2  >pohikoolima !28_V	et	f	\N
172428	multilingua	multilingua =lingua  (SgN  >multi+lingua !01_S	et	f	\N
172429	multilingua	multilingua =lingua  (SgG  >multi+lingua !01_S	et	f	\N
172430	algajate	algajate =algaja  (PlG  >algaja !01_S	et	f	\N
172431	algajate	"algaja %alga  )JA_vS  <algama ;29_V	et	f	\N
172437	opilastel	?opilastel =opilas  (PlAd  >opilane !12_S	et	f	\N
172440	mickey	### mickey	et	f	\N
172459	mojust	?mojust =moju  (SgEl  >moju !17_S	et	f	\N
172460	mojust	?mojust =mojus  (SgP  >mojus !09_S	et	f	\N
172488	toenaoliselt	toenaoliselt =naolise  (SgAbl  >toe+naoline !12?10_A	et	f	\N
172489	toenaoliselt	"toe+naoline %nao  )LINE_aA  <toe+nadu ;18_S	et	f	\N
172490	toenaoliselt	"toe+naoliselt %nao  )LISELT_mD  <toe+nadu ;18_S	et	f	\N
172524	opilane	?opilane =opilane  (SgN  >opilane !12_S	et	f	\N
172525	opilane	?opilane =opilane  (PlP  >opilan !19_S	et	f	\N
172538	uhtviisi	?uhtviisi =uhtviisi  (SgN  >uhtviisi !16_S	et	f	\N
172539	uhtviisi	?uhtviisi =uhtviisi  (SgG  >uhtviisi !16_S	et	f	\N
172540	uhtviisi	?uhtviisi =uhtviisi  (SgG  >uhtviis !22_S	et	f	\N
172541	uhtviisi	?uhtviisi =uhtviisi  (SgP  >uhtviis !22_S	et	f	\N
172542	uhtviisi	?uhtviisi =uhtviisi  (SgAdt  >uhtviis !22_S	et	f	\N
172543	uhtviisi	?uhtviisi =uhtviisi  (IndPrPs_  >uhtviisima !28_V	et	f	\N
172544	uhtviisi	?uhtviisi =uhtviisi  (ImpPrSg2  >uhtviisima !28_V	et	f	\N
172546	tuupiline	?tuupiline =tuupiline  (SgN  >tuupiline !12_A	et	f	\N
172547	tuupiline	?tuupiline =tuupiline  (PlP  >tuupilin !19_S	et	f	\N
172550	tugevamate	tugevamate =tugevama  (PlG  >tugevam !02_A	et	f	\N
172551	tugevamate	"tugevam %tuge  )VAM_cA  <tugema ;27_V	et	f	\N
172552	tugevamate	"tugevam %tugeva  )M_cA  <tugev ;02_A	et	f	\N
172553	tugevamate	tugevamate =mate  (SgN  >tugeva+mate !16_S	et	f	\N
172554	tugevamate	tugevamate =mate  (SgG  >tugeva+mate !16_S	et	f	\N
172558	igaiihele	?igaiihele =igaiihe  (SgAll  >igaiihe !16_S	et	f	\N
172559	igaiihele	?igaiihele =iihe  (SgAll  >iga+iihe !06_S	et	f	\N
172560	sobra	sobra =sobra  (IndPrPs_  >sobrama !27_V	et	f	\N
172561	sobra	sobra =sobra  (ImpPrSg2  >sobrama !27_V	et	f	\N
172587	opilase	?opilase =opilase  (SgG  >opilane !12_S	et	f	\N
172592	d-d	d-d =d  (SgP  >d !xx_Q	et	f	\N
172593	d-d	d-d =d  (PlN  >d !xx_Q	et	f	\N
172596	riiva	riiva =riiva  (IndPrPs_  >riivama !29_V	et	f	\N
172597	riiva	riiva =riiva  (ImpPrSg2  >riivama !29_V	et	f	\N
172615	sonajarg	?sonajarg =sonajarg  (SgN  >sonajarg !22_S	et	f	\N
172621	bantided	### bantided	et	f	\N
172648	tootad	?tootad =toota  (PlN  >toota !16_S	et	f	\N
172649	tootad	?tootad =toota  (IndPrSg2  >tootama !27_V	et	f	\N
172659	opetusest	?opetusest =opetuse  (SgEl  >opetus !11_S	et	f	\N
172660	opetusest	?opetusest =opetuses  (SgP  >opetusene !12_A	et	f	\N
172666	kohakaanete	### kohakaanete	et	f	\N
172670	sisse-	sisse- =si  (SgIll  >si !26_S	et	f	\N
172671	sisse-	sisse- =sisse  (ID  >sisse !41_DK	et	f	\N
172672	sisse-	sisse- =sisse  (PlP  >siss !22_S	et	f	\N
172682	lahme	?lahme =lahme  (SgN  >lahme !06_S	et	f	\N
172683	lahme	?lahme =lahme  (SgG  >lahme !06_S	et	f	\N
172684	lahme	?lahme =lahme  (PlP  >lahm !22_S	et	f	\N
172685	lahme	?lahme =lahme  (IndPrPs_  >lahmema !27_V	et	f	\N
172686	lahme	?lahme =lahme  (ImpPrSg2  >lahmema !27_V	et	f	\N
172694	sonatasandi	?sonatasandi =sonatasandi  (SgG  >sonatasant !22_S	et	f	\N
172695	sonatasandi	?sonatasandi =sonatasandi  (SgP  >sonatasand !22_S	et	f	\N
172696	sonatasandi	?sonatasandi =sonatasandi  (SgAdt  >sonatasand !22_S	et	f	\N
172697	sonatasandi	?sonatasandi =sonatasandi  (IndPrPs_  >sonatasantima !28_V	et	f	\N
172698	sonatasandi	?sonatasandi =sonatasandi  (ImpPrSg2  >sonatasantima !28_V	et	f	\N
172713	kaiakse	?kaiakse =kaiakse  (SgG  >kaiakne !02_A	et	f	\N
172714	kaiakse	?kaiakse =kaiakse  (PlP  >kaiaks !22_S	et	f	\N
172744	verbivalikuvead	?verbivalikuvead =verbivalikuvea  (PlN  >verbivalikuvea !26_S	et	f	\N
172745	verbivalikuvead	?verbivalikuvead =verbivalikuvea  (SgP  >verbivalikuvea !26_S	et	f	\N
172746	verbivalikuvead	?verbivalikuvead =verbivalikuvead  (SgN  >verbivalikuvead !22_S	et	f	\N
172756	jargmisi	?jargmisi =jargmisi  (ID  >jargmisi !41_D	et	f	\N
172757	jargmisi	?jargmisi =jargmisi  (PlP  >jargmine !12_A	et	f	\N
172578	kaandevorm	?kaandevorm =kaandevorm  (SgN  >kaandevorm !22_S	et	f	\N
172583	lopu	?lopu =lopu  (SgN  >lopu !16_S	et	f	\N
172584	lopu	?lopu =lopu  (SgG  >lopu !16_S	et	f	\N
172585	lopu	?lopu =lopu  (IndPrPs_  >lopuma !27_V	et	f	\N
172586	lopu	?lopu =lopu  (ImpPrSg2  >lopuma !27_V	et	f	\N
172608	sonajarje	### sonajarje	et	f	\N
172609	kaes	kaes =kae  (SgIn  >kae !26_S	et	f	\N
172610	kaes	kaes =kae  (IndIpfSg3  >kaema !27_V	et	f	\N
172616	kehvema	kehvema =kehvema  (SgG  >kehvem !02_A	et	f	\N
172617	kehvema	"kehvem %kehve  )M_cA  <kehv ;22_A	et	f	\N
172618	kehvema	kehvema =ema  (SgN  >kehv+ema !17_S	et	f	\N
172619	kehvema	kehvema =ema  (SgG  >kehv+ema !17_S	et	f	\N
172620	kehvema	kehvema =ema  (SgP  >kehv+ema !17_S	et	f	\N
172630	pohikoolis	?pohikoolis =pohikooli  (SgIn  >pohikooli !16_S	et	f	\N
172631	pohikoolis	?pohikoolis =pohikooli  (SgIn  >pohikool !22_S	et	f	\N
172632	pohikoolis	?pohikoolis =pohikooli  (IndIpfSg3  >pohikoolima !28_V	et	f	\N
172633	pohikoolis	?pohikoolis =pohikoolis  (SgN  >pohikoolis !09_S	et	f	\N
172641	raagib	?raagib =raagi  (IndPrSg3  >raakima !28_V	et	f	\N
172642	lahevad	?lahevad =lahe  (IndPrPl3  >lahema !27_V	et	f	\N
172645	lahevad	?lahevad =laheva  (PlN  >laheva !01_S	et	f	\N
172647	lahevad	?lahevad =laheva  (PlN  >lahev !02_A	et	f	\N
172655	arajaanud	?arajaanud =arajaanu  (PlN  >arajaanu !01_S	et	f	\N
172656	arajaanud	?arajaanud =arajaanu  (IndPrSg2  >arajaanuma !27_V	et	f	\N
172657	arajaanud	?arajaanud =arajaanud  (ID  >arajaanud !41_A	et	f	\N
172658	arajaanud	?arajaanud =jaanu  (PlN  >ara+jaanu !16_S	et	f	\N
172673	seesutleva	?seesutleva =seesutleva  (SgN  >seesutleva !16_S	et	f	\N
172674	seesutleva	?seesutleva =seesutleva  (SgG  >seesutlev !02_A	et	f	\N
172675	seesutleva	?seesutleva =seesutleva  (SgG  >seesutleva !16_S	et	f	\N
172676	seesutleva	?seesutleva =utleva  (SgN  >sees+utleva !01_S	et	f	\N
172677	seesutleva	?seesutleva =utleva  (SgG  >sees+utleva !01_S	et	f	\N
172678	seesutleva	?seesutleva =utleva  (SgG  >sees+utlev !02_A	et	f	\N
172679	seesutleva	?seesutleva =sutleva  (SgN  >see+sutleva !01_S	et	f	\N
172680	seesutleva	?seesutleva =sutleva  (SgG  >see+sutleva !01_S	et	f	\N
172681	seesutleva	?seesutleva =sutleva  (SgG  >see+sutlev !02_A	et	f	\N
172690	vaaratusi	vaaratusi =vaaratusi  (PlP  >vaaratus !11_S	et	f	\N
172691	vaaratusi	"vaaratus %vaara  )TUS2_aS  <vaar ;22_S	et	f	\N
172692	verbivalikul	?verbivalikul =verbivaliku  (SgAd  >verbivalik !25_A	et	f	\N
172693	verbivalikul	?verbivalikul =verbivalikul  (SgN  >verbivalikul !19_S	et	f	\N
172722	tegusonaks	?tegusonaks =sona  (SgTr  >tegu+sona !17_S	et	f	\N
172725	moni	?moni =moni  (SgN  >moni !17_S	et	f	\N
172727	moni	?moni =moni  (SgG  >moni !17_S	et	f	\N
172729	moni	?moni =moni  (SgP  >moni !17_S	et	f	\N
172730	moni	?moni =moni  (IndPrPs_  >monima !27_V	et	f	\N
172731	moni	?moni =moni  (ImpPrSg2  >monima !27_V	et	f	\N
172732	selgitusteta	selgitusteta =selgitus  (PlAb  >selgitus !11_S	et	f	\N
172733	selgitusteta	"selgitus %selgita  )US_vS  <selgitama ;27_V	et	f	\N
172734	selgitusteta	"selgitus %selgi  )TUS1_aS  <selgima ;27_V	et	f	\N
172747	kohakaanetevead	?kohakaanetevead =kohakaanetevea  (PlN  >kohakaanetevea !26_S	et	f	\N
172748	kohakaanetevead	?kohakaanetevead =kohakaanetevea  (SgP  >kohakaanetevea !26_S	et	f	\N
172749	kohakaanetevead	?kohakaanetevead =kohakaanetevead  (SgN  >kohakaanetevead !22_S	et	f	\N
172750	kohakaanetevead	?kohakaanetevead =tevea  (PlN  >koha+kaane+tevea !26_S	et	f	\N
172751	kohakaanetevead	?kohakaanetevead =tevea  (SgP  >koha+kaane+tevea !26_S	et	f	\N
172752	kohakaanetevead	?kohakaanetevead =tevead  (SgN  >koha+kaane+tevead !22_S	et	f	\N
172753	kohakaanetevead	?kohakaanetevead =kaanetevea  (PlN  >koha+kaanetevea !26_S	et	f	\N
172754	kohakaanetevead	?kohakaanetevead =kaanetevea  (SgP  >koha+kaanetevea !26_S	et	f	\N
172755	kohakaanetevead	?kohakaanetevead =kaanetevead  (SgN  >koha+kaanetevead !22_S	et	f	\N
172760	da-tegevusnime	da-tegevusnime =nime  (SgG  >da-tegevus+nimi !20_S	et	f	\N
172761	da-tegevusnime	da-tegevusnime =nime  (SgP  >da-tegevus+nimi !20_S	et	f	\N
172783	tuupilisem	?tuupilisem =tuupilisem  (SgN  >tuupilisem !02_A	et	f	\N
172824	ainukesest	ainukesest =ainukese  (SgEl  >ainuke !12_AS	et	f	\N
172825	ainukesest	"ainuke %ainu  )KE_dS  <ainu ;16_S	et	f	\N
172827	ainukesest	"ainuke %ainu  )KE_dA  <ainus ;07_AS	et	f	\N
172829	ainukesest	ainukesest =ainukese  (SgEl  >ainukene !12_S	et	f	\N
172831	ainukesest	"ainukene %ainu  )KENE_dS  <ainu ;16_S	et	f	\N
172833	ainukesest	"ainukene %ainu  )KENE_dA  <ainus ;07_AS	et	f	\N
172845	parit	?parit =parit  (SgN  >parit !02_S	et	f	\N
172846	opilasel	?opilasel =opilase  (SgAd  >opilane !12_S	et	f	\N
172847	oppin	?oppin =oppin  (SgN  >oppin !02_S	et	f	\N
172852	tunnetust	tunnetust =tunnetus  (SgP  >tunnetus !11_S	et	f	\N
172853	tunnetust	"tunnetus %tunneta  )US_vS  <tunnetama ;27_V	et	f	\N
172863	poordelopu	?poordelopu =poordelopu  (IndPrPs_  >poordelopuma !27_V	et	f	\N
172864	poordelopu	?poordelopu =poordelopu  (ImpPrSg2  >poordelopuma !27_V	et	f	\N
172865	soob	?soob =soob  (SgN  >soob !22_S	et	f	\N
172866	arkad	?arkad =arka  (PlN  >arka !16_S	et	f	\N
172867	arkad	?arkad =arka  (IndPrSg2  >arkama !29_V	et	f	\N
172868	vahene	vahene =vahene  (SgN  >vahene !10_A	et	f	\N
172622	onnestunud	?onnestunud =onnestu  (PtsPtPs  >onnestuma !27_V	et	f	\N
172623	onnestunud	?onnestunud =onnestunu  (PlN  >onnestunu !01_S	et	f	\N
172624	onnestunud	?onnestunud =onnestunu  (IndPrSg2  >onnestunuma !27_V	et	f	\N
172626	onnestunud	?onnestunud =onnestunud  (ID  >onnestunud !41_A	et	f	\N
172638	nimetavaga	nimetavaga =nimetava  (SgKom  >nimetav !02_A	et	f	\N
172639	nimetavaga	"nimetav %nimeta  )V_vA  <nimetama ;27_V	et	f	\N
172640	nimetavaga	nimetavaga =tava  (SgKom  >nime+tava !17_S	et	f	\N
172650	ortografiaviga	?ortografiaviga =ortografiavi  (SgKom  >ortografiavi !16_S	et	f	\N
172651	ortografiaviga	?ortografiaviga =ortografiavi  (SgKom  >ortografiav !22_S	et	f	\N
172664	motlema	?motlema =motle  (Sup  >motlema !30_V	et	f	\N
172665	motlema	?motlema =motlema  (SgG  >motlem !02_A	et	f	\N
172667	segiajamisi	segiajamisi =ajamisi  (PlP  >segi+ajamine !12_S	et	f	\N
172668	segiajamisi	"segi+ajamine %ajami  )NE_aA  <segi+ajam ;02_S	et	f	\N
172669	valiskohakaanete	### valiskohakaanete	et	f	\N
172706	naide	?naide =nai  (PlG  >nai !26_S	et	f	\N
172707	naide	?naide =naide  (SgN  >naide !06_S	et	f	\N
172708	naide	?naide =naide  (PlP  >naid !22_S	et	f	\N
172709	naide	?naide =naide  (IndPrPs_  >naidema !27_V	et	f	\N
172710	naide	?naide =naide  (ImpPrSg2  >naidema !27_V	et	f	\N
172724	konest	konest =kone  (SgEl  >kone !16_S	et	f	\N
172726	konest	konest =kones  (SgP  >konene !10_A	et	f	\N
172728	konest	"konene %kone  )NE_aA  <kone ;16_S	et	f	\N
172741	opilastele	?opilastele =opilas  (PlAll  >opilane !12_S	et	f	\N
172742	opilastele	?opilastele =opilastele  (IndPrPs_  >opilastelema !36_V	et	f	\N
172743	opilastele	?opilastele =opilastele  (ImpPrSg2  >opilastelema !36_V	et	f	\N
172764	eksimised	eksimised =eksimise  (PlN  >eksimine !12_S	et	f	\N
172765	eksimised	"eksimine %eksi  )MINE_vS  <eksima ;28_V	et	f	\N
172770	poora	?poora =poora  (SgN  >poora !16_S	et	f	\N
172771	poora	?poora =poora  (SgG  >poora !16_S	et	f	\N
172772	poora	?poora =poora  (IndPrPs_  >poorama !29_V	et	f	\N
172773	poora	?poora =poora  (ImpPrSg2  >poorama !29_V	et	f	\N
172806	tekkepohjust	?tekkepohjust =tekkepohjus  (SgP  >tekkepohjus !11~09_S	et	f	\N
172807	tekkepohjust	?tekkepohjust =pohju  (SgEl  >tekke+pohju !16_S	et	f	\N
172808	tekkepohjust	?tekkepohjust =pohjus  (SgP  >tekke+pohjus !11~09_S	et	f	\N
172834	oppetundides	?oppetundides =oppetundi  (PlIn  >oppetund !22_S	et	f	\N
172835	oppetundides	?oppetundides =oppetundi  (Ger  >oppetundima !28_V	et	f	\N
172848	pjrit	### pjrit	et	f	\N
172871	kone	kone =kone  (SgN  >kone !16_S	et	f	\N
172872	kone	kone =kone  (SgG  >kone !16_S	et	f	\N
172877	haaldusviga	?haaldusviga =haaldusvi  (SgKom  >haaldusvi !01_S	et	f	\N
172878	haaldusviga	?haaldusviga =haaldusvi  (SgKom  >haaldusv !22_S	et	f	\N
172880	haaldamisel	?haaldamisel =haaldamise  (SgAd  >haaldamine !12_S	et	f	\N
172887	s-i	s-i =s  (SgG  >s !xx_Q	et	f	\N
172888	s-i	s-i =s  (SgP  >s !xx_Q	et	f	\N
172889	s-i	s-i =s  (SgAdt  >s !xx_Q	et	f	\N
172896	haalik	?haalik =haalik  (SgN  >haalik !02_S	et	f	\N
172898	j-uhendina	?j-uhendina =uhendi  (SgEs  >j-uhendi !01_S	et	f	\N
172899	j-uhendina	?j-uhendina =uhendi  (SgEs  >j-uhend !02_S	et	f	\N
172900	j-uhendina	?j-uhendina =uhendi  (SgEs  >j-uhent !22_S	et	f	\N
172907	hjal	### hjal	et	f	\N
172908	e-sarnasena	e-sarnasena =sarnase  (SgEs  >e-sarnane !10_A	et	f	\N
172909	e-sarnasena	"e-sarnane %sarna  )NE_aA  <e-sarn ;22_S	et	f	\N
172910	hesti	?hesti =hesti  (SgN  >hesti !16_S	et	f	\N
172911	hesti	?hesti =hesti  (SgG  >hesti !16_S	et	f	\N
172912	hesti	?hesti =hesti  (SgG  >hest !22_S	et	f	\N
172913	hesti	?hesti =hesti  (SgP  >hest !22_S	et	f	\N
172914	hesti	?hesti =hesti  (SgAdt  >hest !22_S	et	f	\N
172915	hesti	?hesti =hesti  (IndPrPs_  >hestima !28_V	et	f	\N
172916	hesti	?hesti =hesti  (ImpPrSg2  >hestima !28_V	et	f	\N
172917	kolmandavalteliste	?kolmandavalteliste =kolmandavaltelis  (PlG  >kolmandavaltelis !09_S	et	f	\N
172918	kolmandavalteliste	?kolmandavalteliste =kolmandavaltelis  (PlG  >kolmandavalteline !12_A	et	f	\N
172919	kolmandavalteliste	?kolmandavalteliste =kolmandavalteliste  (PlP  >kolmandavaltelist !22_S	et	f	\N
172920	kolmandavalteliste	?kolmandavalteliste =valtelis  (PlG  >kolmanda+valtelis !11_S	et	f	\N
172921	kolmandavalteliste	?kolmandavalteliste =valtelis  (PlG  >kolmanda+valteline !12_A	et	f	\N
172922	kolmandavalteliste	?kolmandavalteliste =valteliste  (PlP  >kolmanda+valtelist !22_S	et	f	\N
172923	kolmandavalteliste	?kolmandavalteliste =andavaltelis  (PlG  >kolm+andavaltelis !09_S	et	f	\N
172924	kolmandavalteliste	?kolmandavalteliste =andavaltelis  (PlG  >kolm+andavalteline !12_A	et	f	\N
172925	kolmandavalteliste	?kolmandavalteliste =andavalteliste  (PlP  >kolm+andavaltelist !22_S	et	f	\N
172934	arajatmine	?arajatmine =arajatmine  (SgN  >arajatmine !12_A	et	f	\N
172935	arajatmine	?arajatmine =jatmine  (SgN  >ara+jatmine !12?10_S	et	f	\N
172939	oppivale	?oppivale =oppiva  (SgAll  >oppiva !01_S	et	f	\N
172940	oppivale	?oppivale =oppiva  (SgAll  >oppiv !02_A	et	f	\N
172941	oppivale	?oppivale =oppivale  (PlP  >oppival !19_S	et	f	\N
172946	motlevad	?motlevad =motle  (IndPrPl3  >motlema !30_V	et	f	\N
172947	motlevad	?motlevad =motleva  (PlN  >motleva !01_S	et	f	\N
172948	motlevad	?motlevad =motleva  (PlN  >motlev !02_A	et	f	\N
172627	keeleopetuse	?keeleopetuse =keeleopetuse  (SgG  >keeleopetus !11?09_S	et	f	\N
172628	keeleopetuse	?keeleopetuse =opetuse  (SgG  >keele+opetus !11_S	et	f	\N
172629	keeleopetuse	?keeleopetuse =eopetuse  (SgG  >keel+eopetus !11_S	et	f	\N
172643	konserdile	?konserdile =konserdi  (SgAll  >konserdi !01_S	et	f	\N
172644	konserdile	?konserdile =konserdi  (SgAll  >konserd !02_S	et	f	\N
172646	konserdile	?konserdile =konserdi  (SgAll  >konsert !22_S	et	f	\N
172652	sonast	?sonast =sona  (SgEl  >sona !17_S	et	f	\N
172653	sonast	?sonast =sonas  (SgP  >sonas !09_S	et	f	\N
172654	sonast	?sonast =sonas  (SgP  >sonane !10_A	et	f	\N
172687	vasteteks	vasteteks =vaste  (PlTr  >vaste !06_S	et	f	\N
172688	vasteteks	vasteteks =e  (PlTr  >vast+esi !15_S	et	f	\N
172699	sonadega	?sonadega =sona  (PlKom  >sona !17_S	et	f	\N
172700	tahenduselt	tahenduselt =tahenduse  (SgAbl  >tahendus !11_S	et	f	\N
172701	tahenduselt	"tahendus %tahenda  )US_vS  <tahendama ;27_V	et	f	\N
172702	jareldanud	?jareldanud =jarelda  (PtsPtPs  >jareldama !27_V	et	f	\N
172703	jareldanud	?jareldanud =jareldanu  (PlN  >jareldanu !01_S	et	f	\N
172704	jareldanud	?jareldanud =jareldanu  (IndPrSg2  >jareldanuma !27_V	et	f	\N
172705	jareldanud	?jareldanud =jareldanud  (ID  >jareldanud !41_A	et	f	\N
172711	eksimisi	eksimisi =eksimisi  (PlP  >eksimine !12_S	et	f	\N
172712	eksimisi	"eksimine %eksi  )MINE_vS  <eksima ;28_V	et	f	\N
172715	javoi	?javoi =javoi  (SgN  >javoi !26_S	et	f	\N
172716	javoi	?javoi =javoi  (SgG  >javoi !26_S	et	f	\N
172717	tahenduslik	?tahenduslik =tahenduslik  (SgN  >tahenduslik !25_A	et	f	\N
172718	kolaline	kolaline =kolaline  (SgN  >kolaline !12_A	et	f	\N
172719	kolaline	"kolaline %kola  )LINE_aA  <kola ;17_S	et	f	\N
172723	enam-vahem	?enam-vahem =vahem  (SgN  >enam-vahem !02_A	et	f	\N
172735	koigile	?koigile =koigi  (SgAll  >koigi !16_S	et	f	\N
172736	koigile	?koigile =koigi  (SgAll  >koik !22_S	et	f	\N
172737	koigile	?koigile =koigile  (IndPrPs_  >koigilema !27_V	et	f	\N
172738	koigile	?koigile =koigile  (ImpPrSg2  >koigilema !27_V	et	f	\N
172739	koigile	?koigile =gile  (SgN  >koi+gile !16_S	et	f	\N
172740	koigile	?koigile =gile  (SgG  >koi+gile !16_S	et	f	\N
172758	infinitiivivigu	?infinitiivivigu =infinitiivivigu  (IndPrPs_  >infinitiiviviguma !27_V	et	f	\N
172759	infinitiivivigu	?infinitiivivigu =infinitiivivigu  (ImpPrSg2  >infinitiiviviguma !27_V	et	f	\N
172766	seetottu	?seetottu =seetottu  (SgN  >seetottu !01_S	et	f	\N
172767	seetottu	?seetottu =seetottu  (SgG  >seetottu !01_S	et	f	\N
172768	seetottu	?seetottu =seetottu  (IndPrPs_  >seetottuma !27_V	et	f	\N
172769	seetottu	?seetottu =seetottu  (ImpPrSg2  >seetottuma !27_V	et	f	\N
172784	poordevormi	?poordevormi =poordevormi  (SgG  >poordevorm !22_S	et	f	\N
172785	poordevormi	?poordevormi =poordevormi  (SgP  >poordevorm !22_S	et	f	\N
172786	poordevormi	?poordevormi =poordevormi  (SgAdt  >poordevorm !22_S	et	f	\N
172787	poordevormi	?poordevormi =poordevormi  (IndPrPs_  >poordevormima !28_V	et	f	\N
172788	poordevormi	?poordevormi =poordevormi  (ImpPrSg2  >poordevormima !28_V	et	f	\N
172789	falle	?falle =falle  (SgN  >falle !06_S	et	f	\N
172790	falle	?falle =falle  (PlP  >fall !22_S	et	f	\N
172791	falle	?falle =falle  (IndPrPs_  >fallema !30_V	et	f	\N
172792	falle	?falle =falle  (ImpPrSg2  >fallema !30_V	et	f	\N
172793	oeldud	?oeldud =oeldu  (PlN  >oeldu !01_S	et	f	\N
172794	oeldud	?oeldud =oeldu  (IndPrSg2  >oelduma !27_V	et	f	\N
172795	oeldud	?oeldud =oeldud  (ID  >oeldud !41_A	et	f	\N
172796	side-	side- =si  (PlG  >si !26_S	et	f	\N
172797	side-	side- =side  (SgN  >side !04_S	et	f	\N
172798	side-	side- =side  (SgN  >side !16_S	et	f	\N
172799	side-	side- =side  (SgG  >side !16_S	et	f	\N
172809	marganud	?marganud =marga  (PtsPtPs  >markama !29_V	et	f	\N
172810	marganud	?marganud =marganu  (PlN  >marganu !01_S	et	f	\N
172811	marganud	?marganud =marganu  (IndPrSg2  >marganuma !27_V	et	f	\N
172812	marganud	?marganud =marganud  (ID  >marganud !41_A	et	f	\N
172814	mojuga	?mojuga =moju  (SgKom  >moju !17_S	et	f	\N
172819	kaesoleval	?kaesoleval =kaesoleva  (SgAd  >kaesolev !02_A	et	f	\N
172820	kaesoleval	?kaesoleval =kaesoleva  (SgAd  >kaesoleva !16_S	et	f	\N
172821	kaesoleval	?kaesoleval =kaesoleval  (SgN  >kaesoleval !19_S	et	f	\N
172822	uhest	?uhest =uhes  (SgP  >uhes !09_S	et	f	\N
172823	uhest	?uhest =uhes  (SgP  >uhene !10_A	et	f	\N
172836	jaanud	?jaanud =jaanu  (PlN  >jaanu !16_S	et	f	\N
172837	jaanud	?jaanud =jaanu  (IndPrSg2  >jaanuma !28_V	et	f	\N
172838	jaanud	?jaanud =jaanud  (ID  >jaanud !41_A	et	f	\N
172849	kusimusele	?kusimusele =kusimuse  (SgAll  >kusimus !11_S	et	f	\N
172850	kusimusele	?kusimusele =imuse  (SgAll  >kus+imus !09_S	et	f	\N
172851	kusimusele	?kusimusele =imusele  (PlP  >kus+imusel !19_S	et	f	\N
172857	utleks	?utleks =utle  (KndPrPs  >utlema !30_V	et	f	\N
172879	sonades	?sonades =sona  (PlIn  >sona !17_S	et	f	\N
172881	sonades	?sonades =sona  (Ger  >sonama !27_V	et	f	\N
172886	haaldub	?haaldub =haaldu  (IndPrSg3  >haalduma !27_V	et	f	\N
172906	haal	?haal =haal  (SgN  >haal !22_S	et	f	\N
172936	janes	?janes =jane  (SgIn  >jane !16_S	et	f	\N
172937	janes	?janes =jane  (IndIpfSg3  >janema !27_V	et	f	\N
172774	parandamisele	parandamisele =parandamise  (SgAll  >parandamine !12_S	et	f	\N
172775	parandamisele	"parandamine %paranda  )MINE_vS  <parandama ;27_V	et	f	\N
172777	jaada	?jaada =jaada  (SgN  >jaada !16_S	et	f	\N
172778	jaada	?jaada =jaada  (SgG  >jaada !16_S	et	f	\N
172779	jaada	?jaada =jaada  (IndPrPs_  >jaadama !29_V	et	f	\N
172781	jaada	?jaada =jaada  (ImpPrSg2  >jaadama !29_V	et	f	\N
172813	konelevate	?konelevate =koneleva  (PlG  >konelev !02_A	et	f	\N
172826	taismineviku	?taismineviku =taismineviku  (SgG  >taisminevik !02_S	et	f	\N
172828	taismineviku	?taismineviku =taismineviku  (IndPrPs_  >taisminevikuma !27_V	et	f	\N
172830	taismineviku	?taismineviku =taismineviku  (ImpPrSg2  >taisminevikuma !27_V	et	f	\N
172832	taismineviku	?taismineviku =smineviku  (SgG  >tai+sminevik !25_S	et	f	\N
172861	tunnetus	tunnetus =tunnetus  (SgN  >tunnetus !11_S	et	f	\N
172862	tunnetus	"tunnetus %tunneta  )US_vS  <tunnetama ;27_V	et	f	\N
172875	konekasutuses	?konekasutuses =konekasutuse  (SgIn  >konekasutus !11?09_S	et	f	\N
172876	mina-poordega	### mina-poordega	et	f	\N
172902	haaldama	?haaldama =haalda  (Sup  >haaldama !27_V	et	f	\N
172903	haaldama	?haaldama =haaldama  (SgG  >haaldam !02_A	et	f	\N
172927	haaldamine	?haaldamine =haaldamine  (SgN  >haaldamine !12_S	et	f	\N
172928	haaldamine	?haaldamine =haaldamine  (PlP  >haaldamin !19_S	et	f	\N
172931	s5pra	### s5pra	et	f	\N
172932	ortograafiaveaks	?ortograafiaveaks =ortograafiavea  (SgTr  >ortograafiavea !26_S	et	f	\N
172933	tapitahtede	### tapitahtede	et	f	\N
173029	tjudruk	?tjudruk =tjudruk  (SgN  >tjudruk !02_S	et	f	\N
173044	tjootan	?tjootan =tjoota  (IndPrSg1  >tjootama !27_V	et	f	\N
173045	tjootan	?tjootan =tjootan  (SgN  >tjootan !02_S	et	f	\N
173050	kontroltoo	?kontroltoo =kontroltoo  (SgN  >kontroltoo !26_S	et	f	\N
173051	kontroltoo	?kontroltoo =kontroltoo  (SgG  >kontroltoo !26_S	et	f	\N
173052	kontroltoo	?kontroltoo =roltoo  (SgN  >kont+roltoo !26_S	et	f	\N
173053	kontroltoo	?kontroltoo =roltoo  (SgG  >kont+roltoo !26_S	et	f	\N
173055	insenar	?insenar =insenar  (SgN  >insenar !19_S	et	f	\N
173057	tutipiline	?tutipiline =tutipiline  (SgN  >tutipiline !12_A	et	f	\N
173058	tutipiline	?tutipiline =tutipiline  (PlP  >tutipilin !19_S	et	f	\N
173081	vordlusastmed	### vordlusastmed	et	f	\N
173090	algvordest	?algvordest =algvorde  (PlEl  >algvort !22_S	et	f	\N
173091	algvordest	?algvordest =algvordes  (SgP  >algvordene !12_A	et	f	\N
173092	algvordest	?algvordest =vorde  (SgEl  >alg+vorre !06_S	et	f	\N
173093	algvordest	?algvordest =vorde  (PlEl  >alg+vort !22_S	et	f	\N
173095	algvordest	?algvordest =vordes  (SgP  >alg+vordes !09_S	et	f	\N
173097	algvordest	?algvordest =vordes  (SgP  >alg+vordene !12~10_A	et	f	\N
173100	jordlusastmeid	?jordlusastmeid =jordlusastmei  (PlN  >jordlusastmei !26_S	et	f	\N
173101	jordlusastmeid	?jordlusastmeid =jordlusastmei  (SgP  >jordlusastmei !26_S	et	f	\N
173116	jargnevad	?jargnevad =jargne  (IndPrPl3  >jargnema !27_V	et	f	\N
173117	jargnevad	?jargnevad =jargneva  (PlN  >jargneva !01_S	et	f	\N
173118	jargnevad	?jargnevad =jargneva  (PlN  >jargnev !02_A	et	f	\N
173119	taiskasvanute	?taiskasvanute =taiskasvanu  (PlG  >taiskasvanu !01_S	et	f	\N
173120	taiskasvanute	?taiskasvanute =taiskasvanu  (IndPrPl2  >taiskasvanuma !27_V	et	f	\N
173121	taiskasvanute	?taiskasvanute =skasvanu  (PlG  >tai+skasvanu !01_S	et	f	\N
173129	igauhe	igauhe =uhe  (SgN  >iga+uhe !05_S	et	f	\N
173130	igauhe	igauhe =uhe  (SgN  >iga+uhe !06_S	et	f	\N
173134	poltsamaal	?poltsamaal =poltsamaa  (SgAd  >poltsamaa !26_S	et	f	\N
173135	poltsamaal	?poltsamaal =poltsamaal  (SgN  >poltsamaal !22_S	et	f	\N
173136	kaandelopp	?kaandelopp =kaandelopp  (SgN  >kaandelopp !22_S	et	f	\N
173157	kadripaev	?kadripaev =kadripaev  (SgN  >kadripaev !22_S	et	f	\N
173158	kadripaev	?kadripaev =paev  (SgN  >kadri+paev !22_S	et	f	\N
173170	kaandub	?kaandub =kaandu  (IndPrSg3  >kaanduma !27_V	et	f	\N
173179	susteemist	?susteemist =susteemi  (SgEl  >susteemi !16_S	et	f	\N
173180	susteemist	?susteemist =susteemi  (SgEl  >susteem !22_S	et	f	\N
173181	susteemist	?susteemist =susteemis  (SgP  >susteemis !09_S	et	f	\N
173182	susteemist	?susteemist =susteemis  (SgP  >susteemine !10_A	et	f	\N
173212	kolmkummenes	?kolmkummenes =kolmkummene  (PlIn  >kolmkummen !19_S	et	f	\N
173216	kolmekumnes	?kolmekumnes =kolmekumne  (PlIn  >kolmekumn !22_S	et	f	\N
173217	kolmekumnes	?kolmekumnes =kumne  (PlIn  >kolme+kumn !22_S	et	f	\N
173218	kolmekumnes	?kolmekumnes =kumnes  (SgN  >kolme+kumnes !09_S	et	f	\N
173219	kolmekumnes	?kolmekumnes =ekumne  (PlIn  >kolm+ekumn !22_S	et	f	\N
173251	aiget	?aiget =aige  (SgP  >aige !06_S	et	f	\N
173261	keskpärase	keskpärase =pärase  (SgG  >kesk+pärane !10_A	et	f	\N
173262	keskpärase	"kesk+pärane %pära  )NE_aA  <kesk+pära ;17_S	et	f	\N
173269	võimetusest	võimetusest =võimetuse  (SgEl  >võimetus !11_S	et	f	\N
173270	võimetusest	"võimetus %võime  )TUS2_aS  <võime ;06_S	et	f	\N
173271	võimetusest	võimetusest =võimetuses  (SgP  >võimetusene !12_A	et	f	\N
173272	võimetusest	"võimetusene %võimetuse  )NE_aA  <võimetus ;11_S	et	f	\N
173287	rahulolematuses	rahulolematuses =olematuse  (SgIn  >rahul+olematus !11?09_S	et	f	\N
173288	rahulolematuses	"rahul+olematus %olema  )TUS2_aS  <rahul+olem ;02_S	et	f	\N
173301	pilisima	pilisima =sima  (SgN  >pili+sima !17_S	et	f	\N
172804	parasiitsona	?parasiitsona =iitso  (SgEs  >paras+iitso !16_S	et	f	\N
172805	parasiitsona	?parasiitsona =siitso  (SgEs  >para+siitso !16_S	et	f	\N
172815	selliselt	selliselt =sellise  (SgAbl  >selline !10_P	et	f	\N
172816	selliselt	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
172817	selliselt	selliselt =selliselt  (ID  >selliselt !41_D	et	f	\N
172818	selliselt	"selliselt %selli  )SELT_mD  <sell ;22_S	et	f	\N
172839	korva	korva =korva  (IndPrPs_  >korvama !29_V	et	f	\N
172840	korva	korva =korva  (ImpPrSg2  >korvama !29_V	et	f	\N
172841	salaparane	?salaparane =salaparane  (SgN  >salaparane !12_A	et	f	\N
172842	salaparane	?salaparane =salaparane  (PlP  >salaparan !19_S	et	f	\N
172843	salaparane	?salaparane =parane  (SgN  >sala+parane !10_A	et	f	\N
172844	kohakaanetega	### kohakaanetega	et	f	\N
172854	intuitiivselt	intuitiivselt =intuitiivse  (SgAbl  >intuitiivne !02_A	et	f	\N
172855	intuitiivselt	intuitiivselt =intuitiivselt  (ID  >intuitiivselt !41_D	et	f	\N
172856	intuitiivselt	"intuitiivselt %intuitiivse  )LT_mD  <intuitiivne ;02_A	et	f	\N
172858	loppu	?loppu =loppu  (ID  >loppu !41_D	et	f	\N
172859	loppu	?loppu =loppu  (IndPrPs_  >loppuma !27_V	et	f	\N
172860	loppu	?loppu =loppu  (ImpPrSg2  >loppuma !27_V	et	f	\N
172897	haaldada	?haaldada =haalda  (Inf  >haaldama !27_V	et	f	\N
172942	tapid	tapid =tapi  (PlN  >tapp !22_S	et	f	\N
172943	tapid	tapid =tapi  (IndPrSg2  >tappima !28_V	et	f	\N
172966	oppijate	?oppijate =oppija  (PlG  >oppija !01_S	et	f	\N
172967	oppijate	?oppijate =oppija  (PlG  >oppijas !02_A	et	f	\N
172980	veaanaliiiisi	?veaanaliiiisi =veaanaliiiisi  (SgN  >veaanaliiiisi !16_S	et	f	\N
172981	veaanaliiiisi	?veaanaliiiisi =veaanaliiiisi  (SgG  >veaanaliiiisi !16_S	et	f	\N
172982	veaanaliiiisi	?veaanaliiiisi =veaanaliiiisi  (SgG  >veaanaliiiis !22_S	et	f	\N
172983	veaanaliiiisi	?veaanaliiiisi =veaanaliiiisi  (SgP  >veaanaliiiis !22_S	et	f	\N
172985	veaanaliiiisi	?veaanaliiiisi =veaanaliiiisi  (SgAdt  >veaanaliiiis !22_S	et	f	\N
172986	veaanaliiiisi	?veaanaliiiisi =veaanaliiiisi  (IndPrPs_  >veaanaliiiisima !28_V	et	f	\N
172988	veaanaliiiisi	?veaanaliiiisi =veaanaliiiisi  (ImpPrSg2  >veaanaliiiisima !28_V	et	f	\N
172994	halbiva	?halbiva =halbiva  (SgN  >halbiva !01_S	et	f	\N
172995	halbiva	?halbiva =halbiva  (SgG  >halbiva !01_S	et	f	\N
172996	halbiva	?halbiva =halbiva  (SgG  >halbiv !02_A	et	f	\N
173000	tahelepanekud	?tahelepanekud =tahelepaneku  (IndPrSg2  >tahelepanekuma !27_V	et	f	\N
173001	tahelepanekud	?tahelepanekud =neku  (PlN  >tahe+lepa+neku !16_S	et	f	\N
173005	opetan	?opetan =opeta  (IndPrSg1  >opetama !27_V	et	f	\N
173006	opetan	?opetan =opetan  (SgN  >opetan !19_S	et	f	\N
173013	naiteid	?naiteid =naite  (PlP  >naide !06_S	et	f	\N
173014	naiteid	?naiteid =naitei  (PlN  >naitei !26_S	et	f	\N
173015	naiteid	?naiteid =naitei  (SgP  >naitei !26_S	et	f	\N
173016	naiteid	?naiteid =naiteid  (SgN  >naiteid !22_S	et	f	\N
173018	moningates	?moningates =moninga  (PlIn  >moninga !01_S	et	f	\N
173019	moningates	?moningates =moninga  (PlIn  >moningas !02_S	et	f	\N
173020	moningates	?moningates =moningate  (PlIn  >moningatt !22_S	et	f	\N
173021	iihes	?iihes =iihe  (SgIn  >iihe !06_S	et	f	\N
173022	iihes	?iihes =iihe  (IndIpfSg3  >iihema !27_V	et	f	\N
173023	iihes	?iihes =iihes  (SgN  >iihes !09_S	et	f	\N
173026	haaldus	?haaldus =haaldu  (SgIn  >haaldu !01_S	et	f	\N
173027	haaldus	?haaldus =haaldu  (IndIpfSg3  >haalduma !27_V	et	f	\N
173028	haaldus	?haaldus =haaldus  (SgN  >haaldus !11~09_S	et	f	\N
173030	tjapselt	?tjapselt =tjapse  (SgAbl  >tjapne !02_A	et	f	\N
173031	tjapselt	?tjapselt =tjapse  (SgAbl  >tjapse !06_S	et	f	\N
173032	tjapselt	?tjapselt =tjapse  (PlAbl  >tjaps !22_S	et	f	\N
173033	tjapselt	?tjapselt =tjapselt  (ID  >tjapselt !41_D	et	f	\N
173046	kantrolltoo	?kantrolltoo =kantrolltoo  (SgN  >kantrolltoo !26_S	et	f	\N
173047	kantrolltoo	?kantrolltoo =kantrolltoo  (SgG  >kantrolltoo !26_S	et	f	\N
173048	kantrolltoo	?kantrolltoo =rolltoo  (SgN  >kant+rolltoo !26_S	et	f	\N
173049	kantrolltoo	?kantrolltoo =rolltoo  (SgG  >kant+rolltoo !26_S	et	f	\N
173065	lugeksite	?lugeksite =lugeksi  (PlG  >lugeksi !01_S	et	f	\N
173066	lugeksite	?lugeksite =lugeksi  (IndPrPl2  >lugeksima !28_V	et	f	\N
173067	tubasse	?tubasse =tubasse  (SgG  >tubasne !02_A	et	f	\N
173068	tubasse	?tubasse =tubasse  (PlP  >tubass !22_S	et	f	\N
173085	kordava	kordava =kordava  (SgG  >kordav !02_A	et	f	\N
173086	kordava	"kordav %korda  )V_vA  <kordama ;29_V	et	f	\N
173087	kordava	kordava =ava  (SgN  >kord+ava !17_S	et	f	\N
173088	kordava	kordava =ava  (SgG  >kord+ava !17_S	et	f	\N
173089	kordava	kordava =ava  (SgP  >kord+ava !17_S	et	f	\N
173104	jiykue	?jiykue =jiykue  (SgN  >jiykue !01_S	et	f	\N
173105	jiykue	?jiykue =jiykue  (SgG  >jiykue !01_S	et	f	\N
173106	heam	heam =heam  (SgN  >heam !22_S	et	f	\N
173107	heam	"heam %hea  )M_cA  <hea ;26_AS	et	f	\N
173122	keelekasutusest	keelekasutusest =kasutuse  (SgEl  >keele+kasutus !11_S	et	f	\N
173123	keelekasutusest	"keele+kasutus %kasu  )TUS2_aS  <keele+kasu ;17_S	et	f	\N
173124	keelekasutusest	keelekasutusest =kasutuses  (SgP  >keele+kasutusene !12_A	et	f	\N
173125	keelekasutusest	"keele+kasutusene %kasutuse  )NE_aA  <keele+kasutus ;11_S	et	f	\N
173142	kohtla-jarves	?kohtla-jarves =jarve  (SgIn  >kohtla-jarve !06_S	et	f	\N
172869	vahene	"vahene %vahe  )NE_aA  <vahe ;16_S	et	f	\N
172870	sonalopul	?sonalopul =sonalopul  (SgN  >sonalopul !19_S	et	f	\N
172873	poordeloppu	?poordeloppu =poordeloppu  (IndPrPs_  >poordeloppuma !27_V	et	f	\N
172874	poordeloppu	?poordeloppu =poordeloppu  (ImpPrSg2  >poordeloppuma !27_V	et	f	\N
172882	sooma	?sooma =sooma  (SgN  >sooma !16_S	et	f	\N
172883	sooma	?sooma =sooma  (SgG  >sooma !16_S	et	f	\N
172884	sooma	?sooma =sooma  (IndPrPs_  >soomama !29_V	et	f	\N
172885	sooma	?sooma =sooma  (ImpPrSg2  >soomama !29_V	et	f	\N
172890	ig	### ig	et	f	\N
172891	sjoma	?sjoma =sjoma  (SgN  >sjoma !17_S	et	f	\N
172892	sjoma	?sjoma =sjoma  (SgG  >sjoma !17_S	et	f	\N
172893	sjoma	?sjoma =sjoma  (SgP  >sjoma !17_S	et	f	\N
172894	sjoma	?sjoma =sjoma  (IndPrPs_  >sjomama !27_V	et	f	\N
172895	sjoma	?sjoma =sjoma  (ImpPrSg2  >sjomama !27_V	et	f	\N
172901	ro	### ro	et	f	\N
172904	a-d	a-d =a  (SgP  >a !xx_Q	et	f	\N
172905	a-d	a-d =a  (PlN  >a !xx_Q	et	f	\N
172926	sonade	?sonade =sona  (PlG  >sona !17_S	et	f	\N
172929	katte	katte =katte  (SgG  >kate !06_S	et	f	\N
172930	katte	katte =katte  (PlP  >katt !22_S	et	f	\N
172973	keeleopetus	?keeleopetus =keeleopetu  (SgIn  >keeleopetu !01_A	et	f	\N
172974	keeleopetus	?keeleopetus =keeleopetu  (IndIpfSg3  >keeleopetuma !27_V	et	f	\N
172975	keeleopetus	?keeleopetus =keeleopetus  (SgN  >keeleopetus !11?09_S	et	f	\N
172976	keeleopetus	?keeleopetus =opetu  (SgIn  >keele+opetu !01_A	et	f	\N
172977	keeleopetus	?keeleopetus =opetus  (SgN  >keele+opetus !11_S	et	f	\N
172978	keeleopetus	?keeleopetus =eopetu  (SgIn  >keel+eopetu !01_A	et	f	\N
172979	keeleopetus	?keeleopetus =eopetus  (SgN  >keel+eopetus !11_S	et	f	\N
172989	maret	?maret =mare  (SgP  >mare !16_S	et	f	\N
172997	kone-	kone- =kone  (SgN  >kone !16_S	et	f	\N
172998	kone-	kone- =kone  (SgG  >kone !16_S	et	f	\N
173069	taba	taba =taba  (SgN  >taba !17_S	et	f	\N
173070	taba	taba =taba  (SgG  >taba !17_S	et	f	\N
173071	taba	taba =taba  (SgP  >taba !17_S	et	f	\N
173072	taba	taba =taba  (IndPrPs_  >tabama !27_V	et	f	\N
173073	taba	taba =taba  (ImpPrSg2  >tabama !27_V	et	f	\N
173102	xopomo	?xopomo =xopomo  (SgN  >xopomo !01_S	et	f	\N
173103	xopomo	?xopomo =xopomo  (SgG  >xopomo !01_S	et	f	\N
173109	halbem	?halbem =halbem  (SgN  >halbem !02_A	et	f	\N
173111	maitsavam	?maitsavam =maitsavam  (SgN  >maitsavam !02_A	et	f	\N
173112	maitsavam	?maitsavam =tsavam  (SgN  >mai+tsavam !02_A	et	f	\N
173131	lopus	?lopus =lopu  (SgIn  >lopu !16_S	et	f	\N
173132	lopus	?lopus =lopu  (IndIpfSg3  >lopuma !27_V	et	f	\N
173133	lopus	?lopus =lopus  (SgN  >lopus !09_S	et	f	\N
173137	secia	?secia =secia  (SgN  >secia !01_S	et	f	\N
173138	secia	?secia =secia  (SgG  >secia !01_S	et	f	\N
173149	ronobe	### ronobe	et	f	\N
173156	lihsam	?lihsam =lihsam  (SgN  >lihsam !02_A	et	f	\N
173159	oigesti	?oigesti =oigesti  (ID  >oigesti !41_D	et	f	\N
173160	oigesti	?oigesti =oigesti  (IndPrPs_  >oigestima !28_V	et	f	\N
173162	oigesti	?oigesti =oigesti  (ImpPrSg2  >oigestima !28_V	et	f	\N
173183	abaauatb	?abaauatb =abaauatb  (SgN  >abaauatb !02_S	et	f	\N
173184	abaauatb	?abaauatb =atb  (SgN  >aba+au+atb !22_S	et	f	\N
173185	abaauatb	?abaauatb =auatb  (SgN  >aba+auatb !02_S	et	f	\N
173196	kumne	?kumne =kumne  (SgN  >kumne !02_A	et	f	\N
173197	kumne	?kumne =kumne  (PlP  >kumn !22_S	et	f	\N
173198	kumne	?kumne =kumne  (IndPrPs_  >kumnema !27_V	et	f	\N
173199	kumne	?kumne =kumne  (ImpPrSg2  >kumnema !27_V	et	f	\N
173213	kusida	kusida =ida  (SgN  >kus+ida !17_S	et	f	\N
173214	kusida	kusida =ida  (SgG  >kus+ida !17_S	et	f	\N
173215	kusida	kusida =ida  (SgP  >kus+ida !17_S	et	f	\N
173230	tahendus	tahendus =tahendus  (SgN  >tahendus !11_S	et	f	\N
173231	tahendus	"tahendus %tahenda  )US_vS  <tahendama ;27_V	et	f	\N
173232	ilusalt	ilusalt =ilusa  (SgAbl  >ilus !02_A	et	f	\N
173233	ilusalt	ilusalt =ilusalt  (ID  >ilusalt !41_D	et	f	\N
173234	ilusalt	"ilusalt %ilusa  )LT_mD  <ilus ;02_A	et	f	\N
173245	harjutamine	harjutamine =harjutamine  (SgN  >harjutamine !12_S	et	f	\N
173246	harjutamine	"harjutamine %harjuta  )MINE_vS  <harjutama ;27_V	et	f	\N
173249	koostamiseks	koostamiseks =koostamise  (SgTr  >koostamine !12_S	et	f	\N
173250	koostamiseks	"koostamine %koosta  )MINE_vS  <koostama ;27_V	et	f	\N
173254	pingutust	pingutust =pingutu  (SgEl  >pingutu !01_AS	et	f	\N
173255	pingutust	"pingutu %pingu  )TU2_kA  <ping ;22_S	et	f	\N
173256	pingutust	pingutust =pingutus  (SgP  >pingutus !11_S	et	f	\N
173257	pingutust	"pingutus %pinguta  )US_vS  <pingutama ;27_V	et	f	\N
173258	pingutust	"pingutus %pingu  )TUS2_aS  <ping ;22_S	et	f	\N
173276	kiriutada	?kiriutada =kiriuta  (Inf  >kiriutama !27_V	et	f	\N
173279	eakohaseid	eakohaseid =kohase  (PlP  >ea+kohane !10_A	et	f	\N
173283	eakohaseid	"ea+kohane %koha  )NE_aA  <ea+koha ;17_S	et	f	\N
173284	eakohaseid	"ea+kohane %koha  )NE_aA  <ea+koht ;22_S	et	f	\N
173289	rigieksamite	?rigieksamite =rigieksami  (PlG  >rigieksam !02_A	et	f	\N
173304	rnängima	?rnängima =rnängi  (Sup  >rnängima !28_V	et	f	\N
173305	rnängima	?rnängima =rnängima  (SgG  >rnängim !02_A	et	f	\N
172938	janes	?janes =janes  (SgN  >janes !09_S	et	f	\N
172944	endile	endile =end  (PlAll  >enda !00_P	et	f	\N
172945	endile	endile =end  (PlAll  >ise !00_P	et	f	\N
172949	oppides	?oppides =oppi  (PlIn  >opp !22_S	et	f	\N
172950	oppides	?oppides =oppi  (Ger  >oppima !28_V	et	f	\N
172951	kriipsukesi	kriipsukesi =kriipsukesi  (PlP  >kriipsuke !12_S	et	f	\N
172952	kriipsukesi	"kriipsuke %kriipsu  )KE_dS  <kriips ;22_S	et	f	\N
172953	kriipsukesi	kriipsukesi =kriipsukesi  (PlP  >kriipsukene !12_S	et	f	\N
172954	kriipsukesi	"kriipsukene %kriipsu  )KENE_dS  <kriips ;22_S	et	f	\N
172963	analuusist	?analuusist =analuusi  (SgEl  >analuusi !16_S	et	f	\N
172964	analuusist	?analuusist =analuusi  (SgEl  >analuus !22_S	et	f	\N
172965	analuusist	?analuusist =analuusis  (SgP  >analuusis !09_S	et	f	\N
172968	pohjustavad	?pohjustavad =pohjusta  (IndPrPl3  >pohjustama !27_V	et	f	\N
172969	pohjustavad	?pohjustavad =pohjustava  (PlN  >pohjustav !02_A	et	f	\N
172970	pohjustavad	?pohjustavad =pohjustava  (PlN  >pohjustava !16_S	et	f	\N
172971	konekeel	?konekeel =konekee  (SgAd  >konekee !26_S	et	f	\N
172972	konekeel	?konekeel =konekeel  (SgN  >konekeel !22_S	et	f	\N
173017	par	### par	et	f	\N
173024	lohakusena	lohakusena =lohakuse  (SgEs  >lohakus !11_S	et	f	\N
173025	lohakusena	"lohakus %lohaka  )US_aS  <lohakas ;02_A	et	f	\N
173034	sija	?sija =sija  (SgN  >sija !17_S	et	f	\N
173035	sija	?sija =sija  (SgG  >sija !17_S	et	f	\N
173036	sija	?sija =sija  (SgP  >sija !17_S	et	f	\N
173037	sija	?sija =sija  (IndPrPs_  >sijama !27_V	et	f	\N
173038	sija	?sija =sija  (ImpPrSg2  >sijama !27_V	et	f	\N
173054	vis	### vis	et	f	\N
173079	omadussona	?omadussona =omadusso  (SgEs  >omadusso !16_S	et	f	\N
173080	omadussona	?omadussona =sona  (SgN  >omadus+sona !17_S	et	f	\N
173082	omadussona	?omadussona =sona  (SgG  >omadus+sona !17_S	et	f	\N
173083	omadussona	?omadussona =sona  (SgP  >omadus+sona !17_S	et	f	\N
173084	omadussona	?omadussona =dusso  (SgEs  >oma+dusso !16_S	et	f	\N
173110	kulmim	?kulmim =kulmim  (SgN  >kulmim !02_A	et	f	\N
173126	pohjus	?pohjus =pohju  (SgIn  >pohju !16_S	et	f	\N
173127	pohjus	?pohjus =pohju  (IndIpfSg3  >pohjuma !27_V	et	f	\N
173128	pohjus	?pohjus =pohjus  (SgN  >pohjus !11~09_S	et	f	\N
173148	miits	?miits =miits  (SgN  >miits !22_S	et	f	\N
173150	arvsona	?arvsona =arvso  (SgEs  >arvso !16_S	et	f	\N
173152	arvsona	?arvsona =sona  (SgN  >arv+sona !17_S	et	f	\N
173154	arvsona	?arvsona =sona  (SgG  >arv+sona !17_S	et	f	\N
173155	arvsona	?arvsona =sona  (SgP  >arv+sona !17_S	et	f	\N
173161	oeldakse	?oeldakse =oeldakse  (SgG  >oeldakne !02_A	et	f	\N
173163	kahekummend	?kahekummend =kahekummend  (SgN  >kahekummend !22_S	et	f	\N
173164	kahekummend	?kahekummend =kummend  (SgN  >kahe+kummend !02_S	et	f	\N
173168	novemril	?novemril =novemri  (SgAd  >novemri !01_S	et	f	\N
173169	novemril	?novemril =novemri  (SgAd  >novemr !22_S	et	f	\N
173171	keeruliselt	keeruliselt =keerulise  (SgAbl  >keeruline !12_A	et	f	\N
173172	keeruliselt	"keeruline %keeru  )LINE_aA  <keerd ;22_SA	et	f	\N
173173	keeruliselt	keeruliselt =keeruliselt  (ID  >keeruliselt !41_D	et	f	\N
173174	keeruliselt	"keeruliselt %keeru  )LISELT_mD  <keerd ;22_SA	et	f	\N
173175	keeruliselt	"keeruliselt %keerulise  )LT_mD  <keeruline ;12_A	et	f	\N
173188	xorbpu	?xorbpu =xorbpu  (SgN  >xorbpu !01_S	et	f	\N
173189	xorbpu	?xorbpu =xorbpu  (SgG  >xorbpu !01_S	et	f	\N
173190	xorbpu	?xorbpu =xorbpu  (IndPrPs_  >xorbpuma !27_V	et	f	\N
173191	xorbpu	?xorbpu =xorbpu  (ImpPrSg2  >xorbpuma !27_V	et	f	\N
173192	utlemisega	?utlemisega =utlemise  (SgKom  >utlemine !12_S	et	f	\N
173224	nepbbzn	?nepbbzn =nepbbzn  (SgN  >nepbbzn !22_S	et	f	\N
173263	aimu	aimu =aimu  (SgG  >aim !22_S	et	f	\N
173264	aimu	aimu =aimu  (SgP  >aim !22_S	et	f	\N
173265	aimu	aimu =aimu  (SgAdt  >aim !22_S	et	f	\N
173266	aimu	aimu =aimu  (PlP  >aim !22_S	et	f	\N
173267	aimu	aimu =aimu  (IndPrPs_  >aimuma !27_V	et	f	\N
173268	aimu	aimu =aimu  (ImpPrSg2  >aimuma !27_V	et	f	\N
173273	huvituta	huvituta =huvitu  (SgAb  >huvitu !01_A	et	f	\N
173274	huvituta	"huvitu %huvi  )TU2_kA  <huvi ;17_S	et	f	\N
173275	huvituta	huvituta =huvitu  (IndPrIps_  >huvituma !27_V	et	f	\N
173277	rõõmusta	rõõmusta =rõõmusta  (IndPrPs_  >rõõmustama !27_V	et	f	\N
173278	rõõmusta	rõõmusta =rõõmusta  (ImpPrSg2  >rõõmustama !27_V	et	f	\N
173280	nurisevad	nurisevad =nurise  (IndPrPl3  >nurisema !27_V	et	f	\N
173281	nurisevad	nurisevad =nuriseva  (PlN  >nurisev !02_A	et	f	\N
173282	nurisevad	"nurisev %nurise  )V_vA  <nurisema ;27_V	et	f	\N
173285	parandamine	parandamine =parandamine  (SgN  >parandamine !12_S	et	f	\N
173286	parandamine	"parandamine %paranda  )MINE_vS  <parandama ;27_V	et	f	\N
173290	harjutama	harjutama =harju  (SupIps  >harjuma !27_V	et	f	\N
173291	harjutama	harjutama =harjuta  (Sup  >harjutama !27_V	et	f	\N
173292	ladusamalt	ladusamalt =ladusama  (SgAbl  >ladusam !02_A	et	f	\N
173293	ladusamalt	"ladusam %ladusa  )M_cA  <ladus ;02_A	et	f	\N
173294	ladusamalt	ladusamalt =ladusamalt  (ID  >ladusamalt !41_D	et	f	\N
173295	ladusamalt	"ladusamalt %ladusa  )MALT_mD  <ladus ;02_A	et	f	\N
173329	põnevamad	põnevamad =põnevama  (PlN  >põnevam !02_A	et	f	\N
172955	konksukesi	konksukesi =konksukesi  (PlP  >konksuke !12_S	et	f	\N
172956	konksukesi	"konksuke %konksu  )KE_dS  <konks ;22_S	et	f	\N
172957	konksukesi	konksukesi =konksukesi  (PlP  >konksukene !12_S	et	f	\N
172958	konksukesi	"konksukene %konksu  )KENE_dS  <konks ;22_S	et	f	\N
172959	vaikesest	?vaikesest =vaikese  (SgEl  >vaike !12?10_S	et	f	\N
172960	vaikesest	?vaikesest =vaikese  (SgEl  >vaikene !12?10_S	et	f	\N
172961	vaikesest	?vaikesest =eses  (SgP  >vaik+eses !09_S	et	f	\N
172962	vaikesest	?vaikesest =eses  (SgP  >vaik+esene !10_A	et	f	\N
172984	kodutoo	?kodutoo =kodutoo  (SgN  >kodutoo !26_S	et	f	\N
172987	kodutoo	?kodutoo =kodutoo  (SgG  >kodutoo !26_S	et	f	\N
172990	bligzna	?bligzna =bligzna  (SgN  >bligzna !01_S	et	f	\N
172991	bligzna	?bligzna =bligzna  (SgG  >bligzna !01_S	et	f	\N
172992	bligzna	?bligzna =bligzna  (IndPrPs_  >bligznama !29_V	et	f	\N
172993	bligzna	?bligzna =bligzna  (ImpPrSg2  >bligznama !29_V	et	f	\N
172999	kirjakeeiest	?kirjakeeiest =kirjakeeie  (SgEl  >kirjakeeie !01_S	et	f	\N
173002	kirjakeeiest	?kirjakeeiest =kirjakeeies  (SgP  >kirjakeeies !11_S	et	f	\N
173003	kirjakeeiest	?kirjakeeiest =keeie  (SgEl  >kirja+keeie !01_S	et	f	\N
173004	kirjakeeiest	?kirjakeeiest =keeies  (SgP  >kirja+keeies !11_S	et	f	\N
173007	taiskasvanutele	?taiskasvanutele =taiskasvanu  (PlAll  >taiskasvanu !01_S	et	f	\N
173008	taiskasvanutele	?taiskasvanutele =taiskasvanute  (PlAll  >taiskasvanutt !22_S	et	f	\N
173009	taiskasvanutele	?taiskasvanutele =taiskasvanutele  (IndPrPs_  >taiskasvanutelema !36_V	et	f	\N
173010	taiskasvanutele	?taiskasvanutele =taiskasvanutele  (ImpPrSg2  >taiskasvanutelema !36_V	et	f	\N
173011	taiskasvanutele	?taiskasvanutele =skasvanu  (PlAll  >tai+skasvanu !01_S	et	f	\N
173012	taiskasvanutele	?taiskasvanutele =skasvanute  (PlAll  >tai+skasvanutt !22_S	et	f	\N
173039	tjana	?tjana =tjana  (SgN  >tjana !17_S	et	f	\N
173040	tjana	?tjana =tjana  (SgG  >tjana !17_S	et	f	\N
173041	tjana	?tjana =tjana  (SgP  >tjana !17_S	et	f	\N
173042	tjana	?tjana =tjana  (IndPrPs_  >tjanama !27_V	et	f	\N
173043	tjana	?tjana =tjana  (ImpPrSg2  >tjanama !27_V	et	f	\N
173056	inseneer	?inseneer =inseneer  (SgN  >inseneer !22_S	et	f	\N
173059	opinud	?opinud =opi  (PtsPtPs  >opima !27_V	et	f	\N
173060	opinud	?opinud =opinu  (PlN  >opinu !01_S	et	f	\N
173061	opinud	?opinud =opinu  (IndPrSg2  >opinuma !27_V	et	f	\N
173062	opinud	?opinud =opinud  (ID  >opinud !41_A	et	f	\N
173063	hiipan	?hiipan =hiipa  (IndPrSg1  >hiipama !29_V	et	f	\N
173064	hiipan	?hiipan =hiipan  (SgN  >hiipan !02_S	et	f	\N
173074	muutust	muutust =muutu  (SgEl  >muutu !01_A	et	f	\N
173075	muutust	"muutu %muu  )TU2_kA  <muu ;26_S	et	f	\N
173076	muutust	muutust =muutus  (SgP  >muutus !11~09_S	et	f	\N
173077	muutust	"muutus %muu  )TUS2_aS  <muu ;26_S	et	f	\N
173078	muutust	muutust =tust  (SgN  >muu+tust !22_S	et	f	\N
173094	keskvorde	?keskvorde =keskvorde  (PlP  >keskvord !22_S	et	f	\N
173096	keskvorde	?keskvorde =vorde  (SgN  >kesk+vorde !06_S	et	f	\N
173098	keskvorde	?keskvorde =vorde  (SgG  >kesk+vorre !06_S	et	f	\N
173099	keskvorde	?keskvorde =vorde  (PlP  >kesk+vord !22_S	et	f	\N
173108	tarkem	?tarkem =tarkem  (SgN  >tarkem !02_A	et	f	\N
173113	kaandevead	?kaandevead =kaandevea  (PlN  >kaandevea !26_S	et	f	\N
173114	kaandevead	?kaandevead =kaandevea  (SgP  >kaandevea !26_S	et	f	\N
173115	kaandevead	?kaandevead =kaandevead  (SgN  >kaandevead !22_S	et	f	\N
173139	utleb	?utleb =utle  (IndPrSg3  >utlema !30_V	et	f	\N
173140	keeievaist	?keeievaist =keeievai  (SgEl  >keeievai !26_S	et	f	\N
173141	keeievaist	?keeievaist =keeievaist  (SgN  >keeievaist !22_S	et	f	\N
173146	noes	?noes =noe  (SgIn  >noe !26_S	et	f	\N
173147	noes	?noes =noes  (SgN  >noes !09_S	et	f	\N
173165	kakskumnendal	?kakskumnendal =kakskumnenda  (SgAd  >kakskumnenda !16_S	et	f	\N
173166	kakskumnendal	?kakskumnendal =kakskumnendal  (SgN  >kakskumnendal !02_S	et	f	\N
173167	kakskumnendal	?kakskumnendal =kumnenda  (SgAd  >kaks+kumnenda !01_S	et	f	\N
173176	koikvoimalikke	?koikvoimalikke =koikvoimalikke  (PlP  >koikvoimalik !25_A	et	f	\N
173177	koikvoimalikke	?koikvoimalikke =voimalikke  (PlP  >koik+voimalik !25_A	et	f	\N
173178	koikvoimalikke	?koikvoimalikke =kvoimalikke  (PlP  >koi+kvoimalik !25_A	et	f	\N
173186	nutoro	?nutoro =nutoro  (SgN  >nutoro !01_S	et	f	\N
173187	nutoro	?nutoro =nutoro  (SgG  >nutoro !01_S	et	f	\N
173200	mxe	### mxe	et	f	\N
173202	iet	?iet =iet  (SgN  >iet !22_S	et	f	\N
173204	kuupaeva	?kuupaeva =kuupaeva  (SgN  >kuupaeva !01_S	et	f	\N
173205	kuupaeva	?kuupaeva =kuupaeva  (SgG  >kuupaeva !01_S	et	f	\N
173206	kuupaeva	?kuupaeva =aeva  (SgN  >kuup+aeva !16_S	et	f	\N
173208	kuupaeva	?kuupaeva =aeva  (SgG  >kuup+aeva !16_S	et	f	\N
173210	kuupaeva	?kuupaeva =paeva  (SgN  >kuu+paeva !16_S	et	f	\N
173211	kuupaeva	?kuupaeva =paeva  (SgG  >kuu+paeva !16_S	et	f	\N
173220	kuupaevaga	kuupaevaga =vaga  (SgN  >kuu+pae+vaga !17_A	et	f	\N
173221	kuupaevaga	kuupaevaga =vaga  (SgG  >kuu+pae+vaga !17_A	et	f	\N
173222	kuupaevaga	kuupaevaga =vaga  (SgP  >kuu+pae+vaga !17_A	et	f	\N
173228	uhtlasi	?uhtlasi =uhtlasi  (ID  >uhtlasi !41_D	et	f	\N
173229	uhtlasi	?uhtlasi =uhtlasi  (PlP  >uhtlane !12_S	et	f	\N
173235	kokkuvotteks	?kokkuvotteks =votte  (SgTr  >kokku+vote !06_S	et	f	\N
173143	kohtla-jarves	?kohtla-jarves =jarve  (PlIn  >kohtla-jarv !22_S	et	f	\N
173144	kohtla-jarves	?kohtla-jarves =jarve  (IndIpfSg3  >kohtla-jarvema !27_V	et	f	\N
173145	kohtla-jarves	?kohtla-jarves =jarves  (SgN  >kohtla-jarves !09_S	et	f	\N
173151	kaanamine	?kaanamine =kaanamine  (SgN  >kaanamine !12_S	et	f	\N
173153	kaanamine	?kaanamine =kaanamine  (PlP  >kaanamin !19_S	et	f	\N
173193	vanust	vanust =vanu  (PlEl  >vana !17_AS	et	f	\N
173194	vanust	vanust =vanus  (SgP  >vanus !09_S	et	f	\N
173195	vanust	vanust =vanus  (SgP  >vanune !10_A	et	f	\N
173201	aecat	?aecat =aeca  (SgP  >aeca !16_S	et	f	\N
173203	aecat	?aecat =aecat  (SgN  >aecat !02_S	et	f	\N
173207	utlemine	?utlemine =utlemine  (SgN  >utlemine !12_S	et	f	\N
173209	utlemine	?utlemine =utlemine  (PlP  >utlemin !19_S	et	f	\N
173223	oaxx	?oaxx =oaxx  (SgN  >oaxx !22_S	et	f	\N
173225	uhildumisvead	?uhildumisvead =uhildumisvea  (PlN  >uhildumisvea !26_S	et	f	\N
173226	uhildumisvead	?uhildumisvead =uhildumisvea  (SgP  >uhildumisvea !26_S	et	f	\N
173227	uhildumisvead	?uhildumisvead =uhildumisvead  (SgN  >uhildumisvead !22_S	et	f	\N
173236	kaanded	?kaanded =kaande  (IndPrSg2  >kaandema !27_V	et	f	\N
173240	poorata	?poorata =poora  (SgAb  >poora !16_S	et	f	\N
173241	poorata	?poorata =poora  (Inf  >poorama !29_V	et	f	\N
173242	poorata	?poorata =poora  (IndPrIps_  >poorama !29_V	et	f	\N
173243	poorata	?poorata =poorata  (IndPrPs_  >pooratama !27_V	et	f	\N
173244	poorata	?poorata =poorata  (ImpPrSg2  >pooratama !27_V	et	f	\N
173252	istumine	istumine =istumine  (SgN  >istumine !12_S	et	f	\N
173253	istumine	"istumine %istu  )MINE_vS  <istuma ;28_V	et	f	\N
173342	jaksa	jaksa =jaksa  (IndPrPs_  >jaksama !29_V	et	f	\N
173343	jaksa	jaksa =jaksa  (ImpPrSg2  >jaksama !29_V	et	f	\N
173347	vigased	vigased =vigase  (PlN  >vigane !10_AS	et	f	\N
173348	vigased	"vigane %viga  )NE_aA  <viga ;18_S	et	f	\N
173353	jaõi	### jaõi	et	f	\N
173364	suutelised	suutelised =suutelise  (PlN  >suuteline !12_A	et	f	\N
173365	suutelised	"suuteline %suute  )LINE_aA  <suude ;06_S	et	f	\N
173415	da-tegevusm	?da-tegevusm =tegevusm  (SgN  >da-tegevusm !22_S	et	f	\N
173416	da-tegevusm	?da-tegevusm =usm  (SgN  >da-tegev+usm !22_S	et	f	\N
173421	nõudes	nõudes =nõu  (PlIn  >nõu !26_S	et	f	\N
173422	nõudes	nõudes =nõud  (Ger  >nõudma !34_V	et	f	\N
173423	nõudes	nõudes =nõude  (SgIn  >nõue !06_S	et	f	\N
173428	esimestest	esimestest =esimes  (PlEl  >esimene !12_OP	et	f	\N
173429	esimestest	esimestest =meste  (PlEl  >esi+mest !22_S	et	f	\N
173430	proovides	proovides =proovi  (PlIn  >proov !22_S	et	f	\N
173431	proovides	proovides =proovi  (Ger  >proovima !28_V	et	f	\N
173476	küsip	?küsip =küsip  (SgN  >küsip !02_S	et	f	\N
173477	rebaseld	?rebaseld =rebaseld  (SgN  >rebaseld !22_S	et	f	\N
173481	mõnnda	?mõnnda =mõnnda  (SgN  >mõnnda !01_S	et	f	\N
173482	mõnnda	?mõnnda =mõnnda  (SgG  >mõnnda !01_S	et	f	\N
173483	mõnnda	?mõnnda =mõnnda  (IndPrPs_  >mõnndama !29_V	et	f	\N
173484	mõnnda	?mõnnda =mõnnda  (ImpPrSg2  >mõnndama !29_V	et	f	\N
173492	vaadan	?vaadan =vaada  (IndPrSg1  >vaadama !29_V	et	f	\N
173493	vaadan	?vaadan =vaadan  (SgN  >vaadan !02_S	et	f	\N
173494	silmat	?silmat =silma  (SgP  >silma !16_S	et	f	\N
173495	silmat	?silmat =silmat  (SgN  >silmat !02_S	et	f	\N
173505	muiduki	?muiduki =muiduki  (SgN  >muiduki !01_S	et	f	\N
173506	muiduki	?muiduki =muiduki  (SgG  >muiduki !01_S	et	f	\N
173507	muiduki	?muiduki =muiduki  (SgG  >muiduk !02_S	et	f	\N
173508	muiduki	?muiduki =muiduki  (SgG  >muidukk !22_S	et	f	\N
173509	muiduki	?muiduki =muiduki  (IndPrPs_  >muidukkima !28_V	et	f	\N
173510	muiduki	?muiduki =muiduki  (ImpPrSg2  >muidukkima !28_V	et	f	\N
173559	lotused	?lotused =lotuse  (PlN  >lotus !09_S	et	f	\N
173560	vastavata	vastavata =vastava  (SgAb  >vastav !02_A	et	f	\N
173561	vastavata	"vastav %vasta  )V_vA  <vastama ;29_V	et	f	\N
173562	vastavata	vastavata =ava  (SgAb  >vast+ava !17_S	et	f	\N
173566	keelata	keelata =keela  (Inf  >keelama !29_V	et	f	\N
173567	keelata	keelata =keela  (IndPrIps_  >keelama !29_V	et	f	\N
173597	vedab	### vedab	et	f	\N
173602	kõikil	### kõikil	et	f	\N
173611	purunemist	purunemist =purunemis  (SgP  >purunemine !12_S	et	f	\N
173613	purunemist	"purunemine %purune  )MINE_vS  <purunema ;27_V	et	f	\N
173617	selgusele	selgusele =selguse  (SgAll  >selgus !11~09_S	et	f	\N
173618	selgusele	"selgus %selge  )US_aS  <selge ;01_A	et	f	\N
173619	selgusele	selgusele =use  (PlAll  >selg+usk !22_S	et	f	\N
173632	metateks-	?metateks- =metate  (PlTr  >metatt !22_S	et	f	\N
173654	taotluse	taotluse =taotluse  (SgG  >taotlus !11~09_S	et	f	\N
173655	taotluse	"taotlus %taotle  )US_vS  <taotlema ;27_V	et	f	\N
173678	tubad	?tubad =tuba  (IndPrSg2  >tubama !27_V	et	f	\N
173706	jalgratasega	?jalgratasega =jalgratase  (SgKom  >jalgratane !12_A	et	f	\N
173707	jalgratasega	?jalgratasega =ratase  (SgKom  >jalg+ratane !10_A	et	f	\N
173732	põhisona	?põhisona =põhiso  (SgEs  >põhiso !01_S	et	f	\N
173733	põhisona	?põhisona =sona  (SgN  >põhi+sona !17_S	et	f	\N
173734	põhisona	?põhisona =sona  (SgG  >põhi+sona !17_S	et	f	\N
173735	põhisona	?põhisona =sona  (SgP  >põhi+sona !17_S	et	f	\N
173237	pohiliseks	?pohiliseks =pohilise  (SgTr  >pohiline !12_A	et	f	\N
173238	valjapool	?valjapool =valjapoo  (SgAd  >valjapoo !26_S	et	f	\N
173239	valjapool	?valjapool =valjapool  (SgN  >valjapool !22_S	et	f	\N
173247	kujutamisega	kujutamisega =kujutamise  (SgKom  >kujutamine !12_S	et	f	\N
173248	kujutamisega	"kujutamine %kujuta  )MINE_vS  <kujutama ;27_V	et	f	\N
173259	kirjutatuga	kirjutatuga =kirjutatu  (SgKom  >kirjutatu !01_S	et	f	\N
173260	kirjutatuga	"kirjutatu %kirjuta  )TU1_vS  <kirjutama ;27_V	et	f	\N
173296	hobutsema	?hobutsema =hobutse  (Sup  >hobutsema !27_V	et	f	\N
173297	hobutsema	?hobutsema =hobutsema  (SgG  >hobutsem !02_A	et	f	\N
173298	hobutsema	?hobutsema =tsema  (SgN  >hobu+tsema !17_S	et	f	\N
173299	hobutsema	?hobutsema =tsema  (SgG  >hobu+tsema !17_S	et	f	\N
173300	hobutsema	?hobutsema =tsema  (SgP  >hobu+tsema !17_S	et	f	\N
173325	tötades	?tötades =töta  (PlIn  >töta !16_S	et	f	\N
173326	tötades	?tötades =töta  (Ger  >tötama !27_V	et	f	\N
173332	looderdanud	looderdanud =looderda  (PtsPtPs  >looderdama !27_V	et	f	\N
173333	looderdanud	looderdanud =looderdanu  (PlN  >looderdanu !01_S	et	f	\N
173335	looderdanud	"looderdanu %looderda  )NU_vS  <looderdama ;27_V	et	f	\N
173337	looderdanud	looderdanud =looderdanud  (ID  >looderdanud !41_A	et	f	\N
173339	looderdanud	"looderdanud %looderda  )NUD_vA  <looderdama ;27_V	et	f	\N
173362	emakeelde	emakeelde =keel  (SgAdt  >ema+keel !13_S	et	f	\N
173363	emakeelde	emakeelde =keelde  (PlP  >ema+keeld !22_S	et	f	\N
173378	tulernust	?tulernust =tulernu  (SgEl  >tulernu !01_S	et	f	\N
173379	tulernust	?tulernust =tulernus  (SgP  >tulernus !11_S	et	f	\N
173382	minikontrolltöö	minikontrolltöö =töö  (SgN  >mini+kont+roll+töö !26_S	et	f	\N
173383	minikontrolltöö	minikontrolltöö =töö  (SgG  >mini+kont+roll+töö !26_S	et	f	\N
173384	aeliitklassi	?aeliitklassi =aeliitklassi  (SgG  >aeliitklass !22_S	et	f	\N
173385	aeliitklassi	?aeliitklassi =aeliitklassi  (SgP  >aeliitklass !22_S	et	f	\N
173386	aeliitklassi	?aeliitklassi =aeliitklassi  (SgAdt  >aeliitklass !22_S	et	f	\N
173387	aeliitklassi	?aeliitklassi =aeliitklassi  (IndPrPs_  >aeliitklassima !28_V	et	f	\N
173388	aeliitklassi	?aeliitklassi =aeliitklassi  (ImpPrSg2  >aeliitklassima !28_V	et	f	\N
173400	paljunduse	paljunduse =paljunduse  (SgG  >paljundus !11_S	et	f	\N
173401	paljunduse	"paljundus %paljunda  )US_vS  <paljundama ;27_V	et	f	\N
173406	märkamata	märkamata =märka  (SupAb  >märkama !29_V	et	f	\N
173407	märkamata	märkamata =märkamata  (ID  >märkamata !41_A	et	f	\N
173408	märkamata	"märkamata %märka  )MATA_vA  <märkama ;29_V	et	f	\N
173417	iiks	?iiks =ii  (SgTr  >ii !26_S	et	f	\N
173418	iiks	?iiks =iiks  (SgN  >iiks !22_S	et	f	\N
173461	näitlikusele	näitlikusele =näitlikuse  (SgAll  >näitlikus !11_S	et	f	\N
173462	näitlikusele	"näitlikus %näitliku  )US_aS  <näitlik ;25_A	et	f	\N
173480	takasi	?takasi =takasi  (ID  >takasi !41_D	et	f	\N
173489	vasstas	?vasstas =vassta  (SgIn  >vassta !01_S	et	f	\N
173490	vasstas	?vasstas =vassta  (IndIpfSg3  >vasstama !29_V	et	f	\N
173491	vasstas	?vasstas =vasstas  (SgN  >vasstas !07_S	et	f	\N
173511	ald	?ald =ald  (SgN  >ald !22_S	et	f	\N
173515	hüpada	?hüpada =hüpa  (Inf  >hüpama !27_V	et	f	\N
173520	tplt	### tplt	et	f	\N
173542	emakeeleks	emakeeleks =keele  (SgTr  >ema+keel !13_S	et	f	\N
173543	emakeeleks	emakeeleks =keele  (PlTr  >ema+keeld !22_S	et	f	\N
173556	kirj	### kirj	et	f	\N
173563	tegevuseta	tegevuseta =tegevuse  (SgAb  >tegevus !11_S	et	f	\N
173564	tegevuseta	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
173565	tegevuseta	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
173571	tunnusta	tunnusta =tunnusta  (IndPrPs_  >tunnustama !27_V	et	f	\N
173572	tunnusta	tunnusta =tunnusta  (ImpPrSg2  >tunnustama !27_V	et	f	\N
173580	ametikooli	ametikooli =kooli  (SgG  >ameti+kool !22_S	et	f	\N
173581	ametikooli	ametikooli =kooli  (SgP  >ameti+kool !22_S	et	f	\N
173582	ametikooli	ametikooli =kooli  (SgAdt  >ameti+kool !22_S	et	f	\N
173583	ametikooli	ametikooli =kooli  (PlP  >ameti+kool !22_S	et	f	\N
173590	problemideta	?problemideta =problemideta  (IndPrPs_  >problemidetama !27_V	et	f	\N
173592	problemideta	?problemideta =problemideta  (ImpPrSg2  >problemidetama !27_V	et	f	\N
173603	tehapassivne	?tehapassivne =tehapassivne  (SgN  >tehapassivne !02_A	et	f	\N
173604	tehapassivne	?tehapassivne =tehapassivne  (PlP  >tehapassivn !22_S	et	f	\N
173614	alahinnata	alahinnata =hinna  (SgAb  >ala+hind !22_S	et	f	\N
173615	alahinnata	alahinnata =hinna  (Inf  >ala+hindama !29_V	et	f	\N
173616	alahinnata	alahinnata =hinna  (IndPrIps_  >ala+hindama !29_V	et	f	\N
173636	ekst	?ekst =ekst  (SgN  >ekst !22_S	et	f	\N
173640	tuaalne	?tuaalne =tuaalne  (SgN  >tuaalne !02_A	et	f	\N
173644	tuaalne	?tuaalne =tuaalne  (PlP  >tuaaln !22_S	et	f	\N
173646	tnlge	### tnlge	et	f	\N
173647	qon	### qon	et	f	\N
173649	psiihholoogiline	?psiihholoogiline =psiihholoogiline  (SgN  >psiihholoogiline !12_A	et	f	\N
173651	psiihholoogiline	?psiihholoogiline =psiihholoogiline  (PlP  >psiihholoogilin !19_S	et	f	\N
173672	afrika	?afrika =afrika  (SgN  >afrika !01_S	et	f	\N
173673	afrika	?afrika =afrika  (SgG  >afrika !01_S	et	f	\N
173674	afrika	?afrika =afrika  (SgG  >afrikas !02_S	et	f	\N
173302	pilisima	pilisima =sima  (SgG  >pili+sima !17_S	et	f	\N
173303	pilisima	pilisima =sima  (SgP  >pili+sima !17_S	et	f	\N
173310	neljantas	?neljantas =neljanta  (SgIn  >neljanta !01_S	et	f	\N
173316	tomingas	?tomingas =tominga  (SgIn  >tominga !01_S	et	f	\N
173317	tomingas	?tomingas =tominga  (SgIn  >tomingas !02_S	et	f	\N
173318	tomingas	?tomingas =tomingas  (SgN  >tomingas !02_S	et	f	\N
173323	ühekahe	?ühekahe =kahe  (SgN  >ühe+kahe !16_S	et	f	\N
173324	ühekahe	?ühekahe =kahe  (SgG  >ühe+kahe !16_S	et	f	\N
173331	poolpaeva	?poolpaeva =poolpaeva  (SgN  >poolpaeva !01_S	et	f	\N
173334	poolpaeva	?poolpaeva =poolpaeva  (SgG  >poolpaeva !01_S	et	f	\N
173336	poolpaeva	?poolpaeva =paeva  (SgN  >pool+paeva !16_S	et	f	\N
173338	poolpaeva	?poolpaeva =paeva  (SgG  >pool+paeva !16_S	et	f	\N
173344	absaluutselt	?absaluutselt =absaluutse  (SgAbl  >absaluutne !02_A	et	f	\N
173345	absaluutselt	?absaluutselt =absaluutse  (PlAbl  >absaluuts !22_S	et	f	\N
173346	absaluutselt	?absaluutselt =absaluutselt  (ID  >absaluutselt !41_D	et	f	\N
173354	tublim	tublim =tublim  (SgN  >tublim !02_A	et	f	\N
173355	tublim	"tublim %tubli  )M_cA  <tubli ;16_A	et	f	\N
173374	kontrollides	kontrollides =kontrolli  (PlIn  >kontroll !22_S	et	f	\N
173375	kontrollides	kontrollides =kontrolli  (Ger  >kontrollima !28_V	et	f	\N
173402	lahenduseks	lahenduseks =lahenduse  (SgTr  >lahendus !11_S	et	f	\N
173403	lahenduseks	"lahendus %lahenda  )US_vS  <lahendama ;27_V	et	f	\N
173404	kalasid	kalasid =kala  (PlP  >kala !17_S	et	f	\N
173405	kalasid	kalasid =kalasi  (PlN  >kalasi !01_S	et	f	\N
173419	omandamisega	omandamisega =omandamise  (SgKom  >omandamine !12_S	et	f	\N
173420	omandamisega	"omandamine %omanda  )MINE_vS  <omandama ;27_V	et	f	\N
173432	muutumatuna	muutumatuna =muutumatu  (SgEs  >muutumatu !01_A	et	f	\N
173433	muutumatuna	"muutumatu %muutu  )MATU_vA  <muutuma ;27_V	et	f	\N
173447	tõsisemad	tõsisemad =tõsisema  (PlN  >tõsisem !02_A	et	f	\N
173448	tõsisemad	"tõsisem %tõsise  )M_cA  <tõsine ;10_A	et	f	\N
173468	jäänes	?jäänes =jääne  (PlIn  >jään !22_S	et	f	\N
173469	jäänes	?jäänes =jääne  (IndIpfSg3  >jäänema !27_V	et	f	\N
173470	jäänes	?jäänes =jäänes  (SgN  >jäänes !09_S	et	f	\N
173478	aladi	?aladi =aladi  (SgN  >aladi !01_S	et	f	\N
173479	aladi	?aladi =aladi  (SgG  >aladi !01_S	et	f	\N
173487	rehane	rehane =rehane  (SgN  >rehane !10_A	et	f	\N
173488	rehane	"rehane %reha  )NE_aA  <reha ;17_S	et	f	\N
173497	ika	?ika =ika  (SgN  >ika !16_S	et	f	\N
173498	ika	?ika =ika  (SgG  >ika !16_S	et	f	\N
173499	ika	?ika =ika  (IndPrPs_  >ikama !27_V	et	f	\N
173500	ika	?ika =ika  (ImpPrSg2  >ikama !27_V	et	f	\N
173501	hüpad	?hüpad =hüpa  (PlN  >hüpa !16_S	et	f	\N
173502	hüpad	?hüpad =hüpa  (IndPrSg2  >hüpama !27_V	et	f	\N
173544	astmevahelduslike	?astmevahelduslike =astmevahelduslike  (SgN  >astmevahelduslike !12_S	et	f	\N
173545	astmevahelduslike	?astmevahelduslike =astmevahelduslike  (PlG  >astmevahelduslik !25_A	et	f	\N
173557	teadlikumaks	teadlikumaks =teadlikuma  (SgTr  >teadlikum !02_A	et	f	\N
173558	teadlikumaks	"teadlikum %teadliku  )M_cA  <teadlik ;25_A	et	f	\N
173573	realsusega	?realsusega =realsuse  (SgKom  >realsus !11~09_S	et	f	\N
173584	keskharidust	keskharidust =dust  (SgN  >kesk+hari+dust !22_S	et	f	\N
173585	keskharidust	keskharidust =haridus  (SgP  >kesk+haridus !11_S	et	f	\N
173586	vaevata	vaevata =vaeva  (SgAb  >vaev !22_S	et	f	\N
173587	vaevata	vaevata =vaeva  (Inf  >vaevama !29_V	et	f	\N
173588	vaevata	vaevata =vaeva  (IndPrIps_  >vaevama !29_V	et	f	\N
173589	materialseteta	?materialseteta =materialse  (PlAb  >materialne !02_A	et	f	\N
173591	materialseteta	?materialseteta =materialseteta  (IndPrPs_  >materialsetetama !27_V	et	f	\N
173593	materialseteta	?materialseteta =materialseteta  (ImpPrSg2  >materialsetetama !27_V	et	f	\N
173600	tegevusvaldkonda	tegevusvaldkonda =valdkonda  (SgP  >tegevus+valdkond !22_S	et	f	\N
173601	tegevusvaldkonda	tegevusvaldkonda =valdkonda  (SgAdt  >tegevus+valdkond !22_S	et	f	\N
173607	lootuste	lootuste =lootus  (PlG  >lootus !11~09_S	et	f	\N
173608	lootuste	"lootus %loo  )TUS2_aS  <lugu ;18_S	et	f	\N
173609	lootuste	"lootus %loo  )TUS2_aS  <loog ;22_S	et	f	\N
173610	lootuste	"lootus %loo  )TUS2_aS  <lood ;22_S	et	f	\N
173612	lootuste	lootuste =tuste  (PlP  >loo+tust !22_S	et	f	\N
173629	teksti-	teksti- =teksti  (SgG  >tekst !22_S	et	f	\N
173630	teksti-	teksti- =teksti  (SgP  >tekst !22_S	et	f	\N
173631	teksti-	teksti- =teksti  (SgAdt  >tekst !22_S	et	f	\N
173637	rateks	?rateks =rate  (PlTr  >ratt !22_S	et	f	\N
173638	rateks	?rateks =rate  (KndPrPs  >ratema !27_V	et	f	\N
173643	tuaalne	?tuaalne =tuaalne  (SgN  >tuaalne !02_A	et	f	\N
173645	tuaalne	?tuaalne =tuaalne  (PlP  >tuaaln !22_S	et	f	\N
173664	tolkija	?tolkija =tolkija  (SgN  >tolkija !01_S	et	f	\N
173665	tolkija	?tolkija =tolkija  (SgG  >tolkija !01_S	et	f	\N
173666	tolkija	?tolkija =tolkija  (SgG  >tolkijas !02_A	et	f	\N
173667	lugea	?lugea =lugea  (SgN  >lugea !26_S	et	f	\N
173668	lugea	?lugea =lugea  (SgG  >lugea !26_S	et	f	\N
173670	kantrolltöö	kantrolltöö =töö  (SgN  >kant+roll+töö !26_S	et	f	\N
173671	kantrolltöö	kantrolltöö =töö  (SgG  >kant+roll+töö !26_S	et	f	\N
173306	joonlautu	?joonlautu =joonlautu  (SgN  >joonlautu !01_AS	et	f	\N
173307	joonlautu	?joonlautu =joonlautu  (SgG  >joonlautu !01_AS	et	f	\N
173308	joonlautu	?joonlautu =joonlautu  (IndPrPs_  >joonlautuma !27_V	et	f	\N
173309	joonlautu	?joonlautu =joonlautu  (ImpPrSg2  >joonlautuma !27_V	et	f	\N
173311	pinkis	?pinkis =pinki  (IndIpfSg3  >pinkima !28_V	et	f	\N
173312	pinkis	?pinkis =pinkis  (ID  >pinkis !41_DA	et	f	\N
173313	kusk	?kusk =kusk  (SgN  >kusk !22_S	et	f	\N
173314	vatan	?vatan =vata  (IndPrSg1  >vatama !27_V	et	f	\N
173315	vatan	?vatan =vatan  (SgN  >vatan !02_S	et	f	\N
173319	toomingas	toomingas =toominga  (SgIn  >toomingas !02_S	et	f	\N
173320	toomingas	toomingas =toomingas  (SgN  >toomingas !02_S	et	f	\N
173321	sabloonilauseid	?sabloonilauseid =sabloonilausei  (PlN  >sabloonilausei !26_S	et	f	\N
173322	sabloonilauseid	?sabloonilauseid =sabloonilausei  (SgP  >sabloonilausei !26_S	et	f	\N
173327	praovin	?praovin =praovi  (IndPrSg1  >praovima !28_V	et	f	\N
173328	praovin	?praovin =praovin  (SgN  >praovin !02_S	et	f	\N
173340	väsinuna	väsinuna =väsinu  (SgEs  >väsinu !01_S	et	f	\N
173341	väsinuna	"väsinu %väsi  )NU_vS  <väsima ;27_V	et	f	\N
173349	lähtudest	?lähtudest =lähtudes  (SgP  >lähtudene !12_A	et	f	\N
173350	matetjalist	?matetjalist =matetjalis  (SgP  >matetjalis !09_S	et	f	\N
173351	matetjalist	?matetjalist =matetjalis  (SgP  >matetjaline !12_A	et	f	\N
173352	matetjalist	?matetjalist =matetjalist  (SgN  >matetjalist !22_S	et	f	\N
173366	sõna-sõnaliselt	sõna-sõnaliselt =sõnalise  (SgAbl  >sõna-sõnaline !12_A	et	f	\N
173367	sõna-sõnaliselt	"sõna-sõnaline %sõna  )LINE_aA  <sõna-sõna ;17_S	et	f	\N
173368	sõna-sõnaliselt	sõna-sõnaliselt =sõnaliselt  (ID  >sõna-sõnaliselt !41_D	et	f	\N
173369	sõna-sõnaliselt	"sõna-sõnaliselt %sõna  )LISELT_mD  <sõna-sõna ;17_S	et	f	\N
173370	sõna-sõnaliselt	"sõna-sõnaliselt %sõnalise  )LT_mD  <sõna-sõnaline ;12_A	et	f	\N
173371	kalambuuri	kalambuuri =kalambuuri  (SgG  >kalambuur !22_S	et	f	\N
173372	kalambuuri	kalambuuri =kalambuuri  (SgP  >kalambuur !22_S	et	f	\N
173373	kalambuuri	kalambuuri =kalambuuri  (SgAdt  >kalambuur !22_S	et	f	\N
173389	nõrgemad	nõrgemad =nõrgema  (PlN  >nõrgem !02_A	et	f	\N
173390	nõrgemad	"nõrgem %nõrge  )M_cA  <nõrk ;22_A	et	f	\N
173395	ülesandest	ülesandest =ande  (SgEl  >üles+anne !06_S	et	f	\N
173396	ülesandest	ülesandest =andes  (SgP  >üles+andene !12~10_A	et	f	\N
173397	ülesandest	"üles+andene %ande  )NE_aA  <üles+anne ;06_S	et	f	\N
173398	ülesandest	ülesandest =sande  (PlEl  >üle+sand !22_S	et	f	\N
173399	ülesandest	ülesandest =sande  (PlEl  >üle+sant !22_SA	et	f	\N
173409	parandamata	parandamata =paranda  (SupAb  >parandama !27_V	et	f	\N
173410	parandamata	parandamata =parandamata  (ID  >parandamata !41_A	et	f	\N
173411	parandamata	"parandamata %paranda  )MATA_vA  <parandama ;27_V	et	f	\N
173412	järjekorrast	järjekorrast =korra  (SgEl  >järje+kord !22_S	et	f	\N
173413	järjekorrast	järjekorrast =korras  (SgP  >järje+korrane !10_A	et	f	\N
173414	järjekorrast	"järje+korrane %korra  )NE_aA  <järje+kord ;22_S	et	f	\N
173451	eksida	eksida =eksi  (Inf  >eksima !28_V	et	f	\N
173452	eksida	eksida =ida  (SgN  >eks+ida !17_S	et	f	\N
173453	eksida	eksida =ida  (SgG  >eks+ida !17_S	et	f	\N
173454	eksida	eksida =ida  (SgP  >eks+ida !17_S	et	f	\N
173455	viisakam	viisakam =viisakam  (SgN  >viisakam !02_A	et	f	\N
173456	viisakam	"viisakam %viisaka  )M_cA  <viisakas ;02_A	et	f	\N
173459	tegijat	tegijat =tegija  (SgP  >tegija !01_S	et	f	\N
173460	tegijat	"tegija %tegi  )JA_vS  <tegema ;28_V	et	f	\N
173465	repane	?repane =repane  (SgN  >repane !10_A	et	f	\N
173466	repane	?repane =repane  (IndPrPs_  >repanema !27_V	et	f	\N
173467	repane	?repane =repane  (ImpPrSg2  >repanema !27_V	et	f	\N
173471	möda	?möda =möda  (SgN  >möda !17_S	et	f	\N
173472	möda	?möda =möda  (SgG  >möda !17_S	et	f	\N
173473	möda	?möda =möda  (SgP  >möda !17_S	et	f	\N
173474	möda	?möda =möda  (IndPrPs_  >mödama !27_V	et	f	\N
173475	möda	?möda =möda  (ImpPrSg2  >mödama !27_V	et	f	\N
173485	kuled	?kuled =kule  (PlN  >kule !16_S	et	f	\N
173486	kuled	?kuled =kule  (IndPrSg2  >kulema !27_V	et	f	\N
173526	pedagoogikaiilikool	?pedagoogikaiilikool =pedagoogikaiilikoo  (SgAd  >pedagoogikaiilikoo !26_S	et	f	\N
173527	pedagoogikaiilikool	?pedagoogikaiilikool =pedagoogikaiilikool  (SgN  >pedagoogikaiilikool !22_S	et	f	\N
173528	pedagoogikaiilikool	?pedagoogikaiilikool =ilikoo  (SgAd  >pedagoogi+kai+ilikoo !26_S	et	f	\N
173529	pedagoogikaiilikool	?pedagoogikaiilikool =ilikool  (SgN  >pedagoogi+kai+ilikool !22_S	et	f	\N
173530	pedagoogikaiilikool	?pedagoogikaiilikool =iilikoo  (SgAd  >pedagoogika+iilikoo !26_S	et	f	\N
173531	pedagoogikaiilikool	?pedagoogikaiilikool =iilikool  (SgN  >pedagoogika+iilikool !22_S	et	f	\N
173532	pedagoogikaiilikool	?pedagoogikaiilikool =kaiilikoo  (SgAd  >pedagoogi+kaiilikoo !26_S	et	f	\N
173533	pedagoogikaiilikool	?pedagoogikaiilikool =kaiilikool  (SgN  >pedagoogi+kaiilikool !22_S	et	f	\N
173534	mitte-eestlastest	mitte-eestlastest =eestlas  (PlEl  >mitte-eestlane !12?10_S	et	f	\N
173535	mitte-eestlastest	mitte-eestlastest =las  (PlEl  >mitte-eest+laps !14_S	et	f	\N
173536	mitte-eestlastest	mitte-eestlastest =laste  (PlEl  >mitte-eest+last !22_S	et	f	\N
173330	põnevamad	"põnevam %põneva  )M_cA  <põnev ;02_A	et	f	\N
173356	kohatava	kohatava =kohatava  (SgG  >kohatav !02_A	et	f	\N
173357	kohatava	"kohatav %koha  )TAV_vAS  <kohama ;27_V	et	f	\N
173358	kohatava	"kohatav %koha  )TAV_vAS  <kohtama ;29_V	et	f	\N
173359	kohatava	kohatava =tava  (SgN  >koha+tava !17_S	et	f	\N
173360	kohatava	kohatava =tava  (SgG  >koha+tava !17_S	et	f	\N
173361	kohatava	kohatava =tava  (SgP  >koha+tava !17_S	et	f	\N
173376	paranduse	paranduse =paranduse  (SgG  >parandus !11_S	et	f	\N
173377	paranduse	"parandus %paranda  )US_vS  <parandama ;27_V	et	f	\N
173380	analoogiliste	analoogiliste =analoogilis  (PlG  >analoogiline !12_A	et	f	\N
173381	analoogiliste	"analoogiline %analoogi  )LINE_aA  <analoog ;22_S	et	f	\N
173391	tantsimisest	tantsimisest =tantsimise  (SgEl  >tantsimine !12_S	et	f	\N
173392	tantsimisest	"tantsimine %tantsi  )MINE_vS  <tantsima ;28_V	et	f	\N
173393	huvitatuse	huvitatuse =huvitatuse  (SgG  >huvitatus !11?09_S	et	f	\N
173394	huvitatuse	"huvitatus %huvita  )TUS1_aS  <huvitama ;27_V	et	f	\N
173424	hääldusele	hääldusele =häälduse  (SgAll  >hääldus !11~09_S	et	f	\N
173425	hääldusele	"hääldus %häälda  )US_vS  <hääldama ;27_V	et	f	\N
173426	tuttavam	tuttavam =tuttavam  (SgN  >tuttavam !02_A	et	f	\N
173427	tuttavam	"tuttavam %tuttava  )M_cA  <tuttav ;02_AS	et	f	\N
173434	algvorrnis	?algvorrnis =algvorrni  (SgIn  >algvorrni !01_S	et	f	\N
173435	algvorrnis	?algvorrnis =algvorrni  (SgIn  >algvorrn !22_S	et	f	\N
173436	algvorrnis	?algvorrnis =algvorrni  (IndIpfSg3  >algvorrnima !28_V	et	f	\N
173437	algvorrnis	?algvorrnis =algvorrnis  (SgN  >algvorrnis !11_S	et	f	\N
173438	algvorrnis	?algvorrnis =vorrni  (SgIn  >alg+vorrni !01_S	et	f	\N
173439	algvorrnis	?algvorrnis =vorrni  (SgIn  >alg+vorrn !22_S	et	f	\N
173440	algvorrnis	?algvorrnis =vorrnis  (SgN  >alg+vorrnis !09_S	et	f	\N
173441	variandi	variandi =variandi  (SgG  >variant !22_S	et	f	\N
173442	variandi	variandi =andi  (SgP  >vari+and !22_S	et	f	\N
173443	variandi	variandi =andi  (SgAdt  >vari+and !22_S	et	f	\N
173444	taipavad	taipavad =taipa  (IndPrPl3  >taipama !29_V	et	f	\N
173445	taipavad	taipavad =taipava  (PlN  >taipav !02_A	et	f	\N
173446	taipavad	"taipav %taipa  )V_vA  <taipama ;29_V	et	f	\N
173449	keelepädevus	keelepädevus =pädevus  (SgN  >keele+pädevus !11_S	et	f	\N
173450	keelepädevus	"keele+pädevus %pädeva  )US_aS  <keele+pädev ;02_A	et	f	\N
173457	tublimatel	tublimatel =tublima  (PlAd  >tublim !02_A	et	f	\N
173458	tublimatel	"tublim %tubli  )M_cA  <tubli ;16_A	et	f	\N
173463	seletamise	seletamise =seletamise  (SgG  >seletamine !12_S	et	f	\N
173464	seletamise	"seletamine %seleta  )MINE_vS  <seletama ;27_V	et	f	\N
173496	nüüt	?nüüt =nüüt  (SgN  >nüüt !22_S	et	f	\N
173503	üppan	?üppan =üppa  (IndPrSg1  >üppama !29_V	et	f	\N
173504	üppan	?üppan =üppan  (SgN  >üppan !02_S	et	f	\N
173512	läpi	?läpi =läpi  (SgN  >läpi !16_S	et	f	\N
173513	läpi	?läpi =läpi  (SgG  >läpi !16_S	et	f	\N
173514	läpi	?läpi =läpi  (SgG  >läpp !22_S	et	f	\N
173516	läpi	?läpi =läpi  (IndPrPs_  >läpima !27_V	et	f	\N
173517	läpi	?läpi =läpi  (IndPrPs_  >läppima !28_V	et	f	\N
173518	läpi	?läpi =läpi  (ImpPrSg2  >läpima !27_V	et	f	\N
173519	läpi	?läpi =läpi  (ImpPrSg2  >läppima !28_V	et	f	\N
173521	kartner	?kartner =kartner  (SgN  >kartner !02_S	et	f	\N
173522	maisla	?maisla =maisla  (SgN  >maisla !01_S	et	f	\N
173523	maisla	?maisla =maisla  (SgG  >maisla !01_S	et	f	\N
173524	maisla	?maisla =maisla  (IndPrPs_  >maislama !29_V	et	f	\N
173525	maisla	?maisla =maisla  (ImpPrSg2  >maislama !29_V	et	f	\N
173539	arvutilehekülge	arvutilehekülge =külge  (SgP  >arvuti+lehe+külg !22_S	et	f	\N
173540	arvutilehekülge	arvutilehekülge =külge  (SgAdt  >arvuti+lehe+külg !22_S	et	f	\N
173541	arvutilehekülge	arvutilehekülge =külge  (PlP  >arvuti+lehe+külg !22_S	et	f	\N
173552	paronüümivigu	?paronüümivigu =paronüümivigu  (IndPrPs_  >paronüümiviguma !27_V	et	f	\N
173553	paronüümivigu	?paronüümivigu =paronüümivigu  (ImpPrSg2  >paronüümiviguma !27_V	et	f	\N
173594	kõrege	?kõrege =kõre  (ImpPrPl2  >kõrema !27_V	et	f	\N
173595	lato	?lato =lato  (SgN  >lato !16_S	et	f	\N
173596	lato	?lato =lato  (SgG  >lato !16_S	et	f	\N
173622	purune	purune =purune  (SgN  >purune !10_A	et	f	\N
173623	purune	"purune %puru  )NE_aA  <puru ;17_S	et	f	\N
173624	purune	purune =purune  (IndPrPs_  >purunema !27_V	et	f	\N
173625	purune	purune =purune  (ImpPrSg2  >purunema !27_V	et	f	\N
173626	nlketuubid	?nlketuubid =nlketuubi  (PlN  >nlketuubi !16_S	et	f	\N
173627	nlketuubid	?nlketuubid =nlketuubi  (PlN  >nlketuup !22_S	et	f	\N
173628	nlketuubid	?nlketuubid =nlketuubi  (IndPrSg2  >nlketuupima !28_V	et	f	\N
173635	interteks-	### interteks-	et	f	\N
173658	iisametatekst	### iisametatekst	et	f	\N
173659	arnetlik	?arnetlik =arnetlik  (SgN  >arnetlik !25_A	et	f	\N
173662	tolkijaisiksus	?tolkijaisiksus =tolkijaisiksu  (IndIpfSg3  >tolkijaisiksuma !27_V	et	f	\N
173663	tolkijaisiksus	?tolkijaisiksus =tolkijaisiksus  (SgN  >tolkijaisiksus !11~09_S	et	f	\N
173669	pedagook	?pedagook =pedagook  (SgN  >pedagook !22_S	et	f	\N
173676	õmbletakse	?õmbletakse =õmbletakse  (SgG  >õmbletakne !02_A	et	f	\N
173537	veaanalüüsitöö	?veaanalüüsitöö =veaanalüüsitöö  (SgN  >veaanalüüsitöö !26_S	et	f	\N
173538	veaanalüüsitöö	?veaanalüüsitöö =veaanalüüsitöö  (SgG  >veaanalüüsitöö !26_S	et	f	\N
173546	pööramine	pööramine =pööramine  (SgN  >pööramine !12_S	et	f	\N
173547	pööramine	"pööramine %pööra  )MINE_vS  <pöörama ;29_V	et	f	\N
173548	eesnim	?eesnim =eesnim  (SgN  >eesnim !02_A	et	f	\N
173549	riigikeele	riigikeele =kee  (SgAll  >riigi+kesi !15_S	et	f	\N
173550	riigikeele	riigikeele =kee  (SgAll  >riigi+kee !26_S	et	f	\N
173551	riigikeele	riigikeele =keele  (SgG  >riigi+keel !13_S	et	f	\N
173554	morfoloogilisi	morfoloogilisi =morfoloogilisi  (PlP  >morfoloogiline !12_A	et	f	\N
173555	morfoloogilisi	"morfoloogiline %morfoloogi  )LINE_aA  <morfoloog ;22_S	et	f	\N
173568	võimetele	võimetele =võime  (PlAll  >võime !06_S	et	f	\N
173569	võimetele	võimetele =me  (PlAll  >või+mesi !15_S	et	f	\N
173570	võimetele	võimetele =mete  (PlAll  >või+mett !22_S	et	f	\N
173574	ametikohaga	ametikohaga =koha  (SgKom  >ameti+koha !17_S	et	f	\N
173575	ametikohaga	ametikohaga =koha  (SgKom  >ameti+koht !22_S	et	f	\N
173576	seoda	?seoda =seoda  (SgN  >seoda !16_S	et	f	\N
173577	seoda	?seoda =seoda  (SgG  >seoda !16_S	et	f	\N
173578	seoda	?seoda =seoda  (IndPrPs_  >seodama !29_V	et	f	\N
173579	seoda	?seoda =seoda  (ImpPrSg2  >seodama !29_V	et	f	\N
173598	iaa	?iaa =iaa  (SgN  >iaa !26_S	et	f	\N
173599	iaa	?iaa =iaa  (SgG  >iaa !26_S	et	f	\N
173605	unistamine	unistamine =unistamine  (SgN  >unistamine !12_S	et	f	\N
173606	unistamine	"unistamine %unista  )MINE_vS  <unistama ;27_V	et	f	\N
173620	suundas	?suundas =suunda  (IndIpfSg3  >suundama !27_V	et	f	\N
173621	suundas	?suundas =suundas  (SgN  >suundas !07_S	et	f	\N
173633	inteks-	?inteks- =inte  (SgTr  >inde !06_S	et	f	\N
173634	inteks-	?inteks- =inte  (KndPrPs  >intema !27_V	et	f	\N
173639	tolge	?tolge =tolge  (SgN  >tolge !06_S	et	f	\N
173641	tolge	?tolge =tolge  (IndPrPs_  >tolgema !27_V	et	f	\N
173642	tolge	?tolge =tolge  (ImpPrSg2  >tolgema !27_V	et	f	\N
173648	geograafiline	geograafiline =geograafiline  (SgN  >geograafiline !12_A	et	f	\N
173650	geograafiline	"geograafiline %geograafi  )LINE_aA  <geograaf ;22_S	et	f	\N
173652	geograafiline	geograafiline =graafiline  (SgN  >geo+graafiline !12_A	et	f	\N
173653	geograafiline	"geo+graafiline %graafi  )LINE_aA  <geo+graaf ;22_S	et	f	\N
173656	valjendus	valjendus =valjendus  (SgN  >valjendus !11_S	et	f	\N
173657	valjendus	"valjendus %valjenda  )US_vS  <valjendama ;27_V	et	f	\N
173660	kirjanduspoliitika	kirjanduspoliitika =poliitika  (SgN  >kirjandus+poliitika !01_S	et	f	\N
173661	kirjanduspoliitika	kirjanduspoliitika =poliitika  (SgG  >kirjandus+poliitika !01_S	et	f	\N
173685	õunavõi	õunavõi =või  (SgN  >õuna+või !26_S	et	f	\N
173686	õunavõi	õunavõi =või  (SgG  >õuna+või !26_S	et	f	\N
173712	kaunisel	?kaunisel =kaunisel  (SgN  >kaunisel !19_S	et	f	\N
173727	jal	### jal	et	f	\N
173750	da-inf	?da-inf =inf  (SgN  >da-inf !22_S	et	f	\N
173752	odavasti	odavasti =odavasti  (ID  >odavasti !41_D	et	f	\N
173753	odavasti	odavasti =asti  (SgG  >odav+ast !22_S	et	f	\N
173754	odavasti	odavasti =asti  (SgP  >odav+ast !22_S	et	f	\N
173755	odavasti	odavasti =asti  (SgAdt  >odav+ast !22_S	et	f	\N
173756	roomusti	roomusti =musti  (SgG  >roo+must !22_AS	et	f	\N
173757	roomusti	roomusti =musti  (SgP  >roo+must !22_AS	et	f	\N
173758	roomusti	roomusti =musti  (SgAdt  >roo+must !22_AS	et	f	\N
173759	roomusti	roomusti =musti  (PlP  >roo+must !22_AS	et	f	\N
173760	rohelisekas	?rohelisekas =roheliseka  (SgIn  >rohelisekas !02_A	et	f	\N
173761	rohelisekas	?rohelisekas =roheliseka  (SgIn  >roheliseka !16_S	et	f	\N
173762	rohelisekas	?rohelisekas =rohelisekas  (SgN  >rohelisekas !02_A	et	f	\N
173767	puhitsema	?puhitsema =puhitse  (Sup  >puhitsema !27_V	et	f	\N
173768	puhitsema	?puhitsema =puhitsema  (SgG  >puhitsem !02_A	et	f	\N
173773	sonauhend	?sonauhend =sonauhend  (SgN  >sonauhend !22_S	et	f	\N
173780	omkadne	?omkadne =omkadne  (SgN  >omkadne !02_A	et	f	\N
173781	omkadne	?omkadne =omkadne  (PlP  >omkadn !22_S	et	f	\N
173784	votsime	?votsime =votsi  (IndPrPl1  >votsima !28_V	et	f	\N
173793	loppetas	?loppetas =loppeta  (IndIpfSg3  >loppetama !27_V	et	f	\N
173796	lopeb	?lopeb =lope  (IndPrSg3  >lopema !27_V	et	f	\N
173799	lopetab	?lopetab =lopeta  (IndPrSg3  >lopetama !27_V	et	f	\N
173825	hue	?hue =hue  (SgN  >hue !26_S	et	f	\N
173826	hue	?hue =hue  (SgG  >hue !26_S	et	f	\N
173838	roomustab	?roomustab =roomusta  (IndPrSg3  >roomustama !27_V	et	f	\N
173851	sonajarjevead	?sonajarjevead =sonajarjevea  (PlN  >sonajarjevea !26_S	et	f	\N
173852	sonajarjevead	?sonajarjevead =sonajarjevea  (SgP  >sonajarjevea !26_S	et	f	\N
173853	sonajarjevead	?sonajarjevead =sonajarjevead  (SgN  >sonajarjevead !22_S	et	f	\N
173867	lausedsonaiihendid	?lausedsonaiihendid =lausedsonaiihendi  (PlN  >lausedsonaiihent !22_S	et	f	\N
173868	lausedsonaiihendid	?lausedsonaiihendid =lausedsonaiihendi  (IndPrSg2  >lausedsonaiihentima !28_V	et	f	\N
173869	lausedsonaiihendid	?lausedsonaiihendid =dsonaiihendi  (PlN  >lause+dsonaiihent !22_S	et	f	\N
173870	lausedsonaiihendid	?lausedsonaiihendid =edsonaiihendi  (PlN  >laus+edsonaiihent !22_S	et	f	\N
173871	lausedsonaiihendid	?lausedsonaiihendid =sedsonaiihendi  (PlN  >lau+sedsonaiihent !22_S	et	f	\N
173675	sõbradel	?sõbradel =sõbra  (PlAd  >sõbra !16_S	et	f	\N
173679	nimhammas	?nimhammas =nimhamma  (SgIn  >nimhamma !01_S	et	f	\N
173718	gruppgruppi	?gruppgruppi =gruppgruppi  (SgN  >gruppgruppi !01_S	et	f	\N
173719	gruppgruppi	?gruppgruppi =gruppgruppi  (SgG  >gruppgruppi !01_S	et	f	\N
173720	gruppgruppi	?gruppgruppi =gruppgruppi  (SgP  >gruppgrupp !22_S	et	f	\N
173721	gruppgruppi	?gruppgruppi =gruppgruppi  (SgAdt  >gruppgrupp !22_S	et	f	\N
173722	õpilanesid	### õpilanesid	et	f	\N
173730	lausu	lausu =lausu  (IndPrPs_  >lausuma !28_V	et	f	\N
173731	lausu	lausu =lausu  (ImpPrSg2  >lausuma !28_V	et	f	\N
173745	nägismõned	### nägismõned	et	f	\N
173791	voetud	voetud =voetu  (PlN  >voetu !01_A	et	f	\N
173792	voetud	"voetu %voe  )TU2_kA  <voos ;14_S	et	f	\N
173820	kdima	?kdima =kdima  (SgN  >kdima !17_S	et	f	\N
173821	kdima	?kdima =kdima  (SgG  >kdima !17_S	et	f	\N
173822	kdima	?kdima =kdima  (SgP  >kdima !17_S	et	f	\N
173823	kdima	?kdima =kdima  (IndPrPs_  >kdimama !27_V	et	f	\N
173824	kdima	?kdima =kdima  (ImpPrSg2  >kdimama !27_V	et	f	\N
173827	nado	?nado =nado  (SgN  >nado !17~16_S	et	f	\N
173828	nado	?nado =nado  (SgG  >nado !17~16_S	et	f	\N
173829	nado	?nado =nado  (SgP  >nado !17_S	et	f	\N
173855	v5ib	### v5ib	et	f	\N
173857	veatiiiipi	?veatiiiipi =veatiiiipi  (SgN  >veatiiiipi !16_S	et	f	\N
173858	veatiiiipi	?veatiiiipi =veatiiiipi  (SgG  >veatiiiipi !16_S	et	f	\N
173859	veatiiiipi	?veatiiiipi =veatiiiipi  (SgP  >veatiiiip !22_S	et	f	\N
173860	veatiiiipi	?veatiiiipi =veatiiiipi  (SgAdt  >veatiiiip !22_S	et	f	\N
173875	uxmepecuo	?uxmepecuo =uxmepecuo  (SgN  >uxmepecuo !01_S	et	f	\N
173877	uxmepecuo	?uxmepecuo =uxmepecuo  (SgG  >uxmepecuo !01_S	et	f	\N
173910	uacmoma	?uacmoma =uacmoma  (SgN  >uacmoma !01_S	et	f	\N
173911	uacmoma	?uacmoma =uacmoma  (SgG  >uacmoma !01_S	et	f	\N
173912	deuotcexuu	?deuotcexuu =deuotcexuu  (SgN  >deuotcexuu !26_S	et	f	\N
173913	deuotcexuu	?deuotcexuu =deuotcexuu  (SgG  >deuotcexuu !26_S	et	f	\N
173939	aosxuxno	?aosxuxno =aosxuxno  (SgN  >aosxuxno !16_S	et	f	\N
173940	aosxuxno	?aosxuxno =aosxuxno  (SgG  >aosxuxno !16_S	et	f	\N
173941	aosxuxno	?aosxuxno =sxuxno  (SgN  >ao+sxuxno !16_S	et	f	\N
173942	aosxuxno	?aosxuxno =sxuxno  (SgG  >ao+sxuxno !16_S	et	f	\N
173943	ntencdy	### ntencdy	et	f	\N
173944	xcexutuxou	?xcexutuxou =xcexutuxou  (SgN  >xcexutuxou !26_S	et	f	\N
173945	xcexutuxou	?xcexutuxou =xcexutuxou  (SgG  >xcexutuxou !26_S	et	f	\N
173946	nayjlcuuxou	?nayjlcuuxou =nayjlcuuxou  (SgN  >nayjlcuuxou !26_S	et	f	\N
173947	nayjlcuuxou	?nayjlcuuxou =nayjlcuuxou  (SgG  >nayjlcuuxou !26_S	et	f	\N
173994	menuüüt	?menuüüt =menuüüt  (SgN  >menuüüt !22_S	et	f	\N
173995	menuüüt	?menuüüt =üüt  (SgN  >menu+üüt !22_S	et	f	\N
174000	analuusis	?analuusis =analuusi  (SgIn  >analuusi !16_S	et	f	\N
174001	analuusis	?analuusis =analuusi  (SgIn  >analuus !22_S	et	f	\N
174002	analuusis	?analuusis =analuusi  (IndIpfSg3  >analuusima !28_V	et	f	\N
174003	analuusis	?analuusis =analuusis  (SgN  >analuusis !09_S	et	f	\N
174008	oppejou	?oppejou =oppejou  (SgN  >oppejou !26_S	et	f	\N
174010	oppejou	?oppejou =oppejou  (SgG  >oppejou !26_S	et	f	\N
174057	jallegi	?jallegi =jalle  (SgN^  >jalle !06_S	et	f	\N
174058	jallegi	?jallegi =jalle  (PlP^  >jall !22_S	et	f	\N
174059	jallegi	?jallegi =jalle  (IndPrPs_^  >jallema !30_V	et	f	\N
174060	jallegi	?jallegi =jalle  (ImpPrSg2^  >jallema !30_V	et	f	\N
174078	taiesti	?taiesti =taiesti  (ID  >taiesti !41_D	et	f	\N
174079	taiesti	?taiesti =taiesti  (IndPrPs_  >taiestima !28_V	et	f	\N
174080	taiesti	?taiesti =taiesti  (ImpPrSg2  >taiestima !28_V	et	f	\N
174081	taiesti	?taiesti =esti  (SgN  >tai+esti !16_S	et	f	\N
174083	taiesti	?taiesti =esti  (SgG  >tai+esti !16_S	et	f	\N
174085	taiesti	?taiesti =esti  (SgG  >tai+est !22_S	et	f	\N
174086	taiesti	?taiesti =esti  (SgP  >tai+est !22_S	et	f	\N
174088	taiesti	?taiesti =esti  (SgAdt  >tai+est !22_S	et	f	\N
174093	kaandevalik	?kaandevalik =kaandevalik  (SgN  >kaandevalik !25_A	et	f	\N
174114	asesonast	?asesonast =asesonas  (SgP  >asesonane !12_A	et	f	\N
174115	asesonast	?asesonast =sona  (SgEl  >ase+sona !17_S	et	f	\N
174116	asesonast	?asesonast =sonas  (SgP  >ase+sonas !09_S	et	f	\N
174117	asesonast	?asesonast =sonas  (SgP  >ase+sonane !10_A	et	f	\N
174122	luhikest	?luhikest =luhikes  (SgP  >luhike !12_S	et	f	\N
174123	luhikest	?luhikest =luhikes  (SgP  >luhikene !12_S	et	f	\N
174139	tuvevariandi	?tuvevariandi =tuvevariandi  (SgG  >tuvevariant !22_S	et	f	\N
174140	tuvevariandi	?tuvevariandi =tuvevariandi  (SgP  >tuvevariand !22_S	et	f	\N
174141	tuvevariandi	?tuvevariandi =tuvevariandi  (SgAdt  >tuvevariand !22_S	et	f	\N
174142	tuvevariandi	?tuvevariandi =tuvevariandi  (IndPrPs_  >tuvevariantima !28_V	et	f	\N
174143	tuvevariandi	?tuvevariandi =tuvevariandi  (ImpPrSg2  >tuvevariantima !28_V	et	f	\N
174144	nous	?nous =nou  (SgIn  >nou !26_S	et	f	\N
174145	nous	?nous =nous  (SgN  >nous !22_S	et	f	\N
174148	analuusida	?analuusida =analuusi  (Inf  >analuusima !28_V	et	f	\N
174151	uldine	?uldine =uldine  (SgN  >uldine !10_A	et	f	\N
174152	uldine	?uldine =uldine  (IndPrPs_  >uldinema !27_V	et	f	\N
174153	uldine	?uldine =uldine  (ImpPrSg2  >uldinema !27_V	et	f	\N
173677	õmbletakse	?õmbletakse =õmbletakse  (PlP  >õmbletaks !22_S	et	f	\N
173687	putru	putru =putru  (SgP  >puder !24_S	et	f	\N
173688	putru	putru =putru  (SgAdt  >puder !24_S	et	f	\N
173689	peatusel	peatusel =peatuse  (SgAd  >peatus !11~09_S	et	f	\N
173690	peatusel	"peatus %peata  )US_vS  <peatama ;27_V	et	f	\N
173691	peatusel	"peatus %pea  )TUS2_aS  <pea ;26_S	et	f	\N
173692	naitusesse	?naitusesse =naituse  (SgIll  >naitus !11~09_S	et	f	\N
173693	naitusesse	?naitusesse =naituses  (SgAdt  >naitusene !12_A	et	f	\N
173694	naitusesse	?naitusesse =naitusesse  (SgG  >naitusesne !02_A	et	f	\N
173695	naitusesse	?naitusesse =naitusesse  (PlP  >naitusess !22_S	et	f	\N
173699	poolakaspoolakase	poolakaspoolakase =kase  (SgG  >poola+kas+poola+kask !22_S	et	f	\N
173701	poolakaspoolakase	poolakaspoolakase =akase  (SgG  >poola+kas+pool+akane !10_A	et	f	\N
173703	poolakaspoolakase	"poola+kas+pool+akane %aka  )NE_aA  <poola+kas+pool+aka ;16_S	et	f	\N
173704	poolakaspoolakase	poolakaspoolakase =poolakase  (SgG  >poola+kas+poolakane !12_A	et	f	\N
173705	poolakaspoolakase	"poola+kas+poolakane %poolaka  )NE_aA  <poola+kas+poolakas ;02_S	et	f	\N
173708	jalgratasjalgratase	?jalgratasjalgratase =jalgratasjalgratase  (SgG  >jalgratasjalgratane !12_A	et	f	\N
173709	jalgratasjalgratase	?jalgratasjalgratase =ratase  (SgG  >jalg+ratas+jalg+ratane !10_A	et	f	\N
173710	jalgratasjalgratase	?jalgratasjalgratase =jalgratase  (SgG  >jalg+ratas+jalgratane !12_A	et	f	\N
173711	jalgratasjalgratase	?jalgratasjalgratase =ratasjalgratase  (SgG  >jalg+ratasjalgratane !12_A	et	f	\N
173715	kaartid	### kaartid	et	f	\N
173716	kaarti	kaarti =kaarti  (SgP  >kaart !22_S	et	f	\N
173717	kaarti	kaarti =kaarti  (SgAdt  >kaart !22_S	et	f	\N
173723	jargarvsonu	?jargarvsonu =jargarvsonu  (SgN  >jargarvsonu !01_S	et	f	\N
173724	jargarvsonu	?jargarvsonu =jargarvsonu  (SgG  >jargarvsonu !01_S	et	f	\N
173725	jargarvsonu	?jargarvsonu =jargarvsonu  (IndPrPs_  >jargarvsonuma !27_V	et	f	\N
173726	jargarvsonu	?jargarvsonu =jargarvsonu  (ImpPrSg2  >jargarvsonuma !27_V	et	f	\N
173739	pidulika	?pidulika =pidulika  (SgN  >pidulika !01_S	et	f	\N
173740	pidulika	?pidulika =pidulika  (SgG  >pidulika !01_S	et	f	\N
173741	pidulika	?pidulika =pidulika  (SgG  >pidulikas !02_A	et	f	\N
173751	tma	### tma	et	f	\N
173763	kas-liide	kas-liide =lii  (PlG  >kas-lii !26_S	et	f	\N
173764	kas-liide	kas-liide =liide  (SgN  >kas-liide !06_S	et	f	\N
173785	tegusonad	?tegusonad =sona  (PlN  >tegu+sona !17_S	et	f	\N
173790	soltub	?soltub =soltu  (IndPrSg3  >soltuma !27_V	et	f	\N
173803	mojus	?mojus =moju  (SgIn  >moju !17_S	et	f	\N
173804	mojus	?mojus =moju  (IndIpfSg3  >mojuma !27_V	et	f	\N
173805	mojus	?mojus =mojus  (SgN  >mojus !09_S	et	f	\N
173806	tegusonu	?tegusonu =tegusonu  (SgN  >tegusonu !01_S	et	f	\N
173807	tegusonu	?tegusonu =tegusonu  (SgG  >tegusonu !01_S	et	f	\N
173808	tegusonu	?tegusonu =tegusonu  (IndPrPs_  >tegusonuma !27_V	et	f	\N
173809	tegusonu	?tegusonu =tegusonu  (ImpPrSg2  >tegusonuma !27_V	et	f	\N
173810	tegusonu	?tegusonu =sonu  (SgN  >tegu+sonu !17_S	et	f	\N
173811	tegusonu	?tegusonu =sonu  (SgG  >tegu+sonu !17_S	et	f	\N
173812	tegusonu	?tegusonu =sonu  (SgP  >tegu+sonu !17_S	et	f	\N
173839	eluroomustama	?eluroomustama =eluroomusta  (Sup  >eluroomustama !27_V	et	f	\N
173840	eluroomustama	?eluroomustama =eluroomustama  (SgG  >eluroomustam !02_A	et	f	\N
173841	eluroomustama	?eluroomustama =ama  (SgN  >elu+roo+must+ama !17_S	et	f	\N
173842	eluroomustama	?eluroomustama =ama  (SgG  >elu+roo+must+ama !17_S	et	f	\N
173843	eluroomustama	?eluroomustama =ama  (SgP  >elu+roo+must+ama !17_S	et	f	\N
173844	eluroomustama	?eluroomustama =mustama  (SgG  >elu+roo+mustam !02_A	et	f	\N
173845	eluroomustama	?eluroomustama =roomustama  (SgG  >elu+roomustam !02_A	et	f	\N
173856	ldhen	### ldhen	et	f	\N
173865	konelevatel	?konelevatel =koneleva  (PlAd  >konelev !02_A	et	f	\N
173866	konelevatel	?konelevatel =konelevate  (PlAd  >konelevatt !22_S	et	f	\N
173876	3mo	### 3mo	et	f	\N
173914	motleja	?motleja =motleja  (SgN  >motleja !01_S	et	f	\N
173915	motleja	?motleja =motleja  (SgG  >motleja !01_S	et	f	\N
173917	motleja	?motleja =motleja  (SgG  >motlejas !02_A	et	f	\N
173924	maarus	?maarus =maaru  (SgIn  >maaru !16_S	et	f	\N
173925	maarus	?maarus =maaru  (IndIpfSg3  >maaruma !27_V	et	f	\N
173926	maarus	?maarus =maarus  (SgN  >maarus !11~09_S	et	f	\N
173938	sudassonajarje-	### sudassonajarje-	et	f	\N
173977	pohjustel	?pohjustel =pohjus  (PlAd  >pohjus !11~09_S	et	f	\N
173992	ülivorret	?ülivorret =vorre  (SgP  >üli+vorre !06_S	et	f	\N
174024	analuiasitava	?analuiasitava =analuiasitava  (SgN  >analuiasitava !16_S	et	f	\N
174025	analuiasitava	?analuiasitava =analuiasitava  (SgG  >analuiasitav !02_A	et	f	\N
174026	analuiasitava	?analuiasitava =analuiasitava  (SgG  >analuiasitava !16_S	et	f	\N
174034	menuult	?menuult =menuu  (SgAbl  >menuu !26_S	et	f	\N
174035	menuult	?menuult =menuult  (ID  >menuult !41_D	et	f	\N
174036	menuult	?menuult =ult  (SgN  >menu+ult !22_S	et	f	\N
174065	oigem	?oigem =oigem  (SgN  >oigem !02_A	et	f	\N
174068	haaldatuna	?haaldatuna =haaldatu  (SgEs  >haaldatu !01_S	et	f	\N
174074	valismaalase	?valismaalase =valismaalase  (SgG  >valismaalane !12?10_S	et	f	\N
174075	vooras	?vooras =voora  (SgIn  >voora !16_S	et	f	\N
173680	hambamoshambaid	?hambamoshambaid =hambamoshambai  (PlN  >hambamoshambai !26_S	et	f	\N
173681	hambamoshambaid	?hambamoshambaid =hambamoshambai  (SgP  >hambamoshambai !26_S	et	f	\N
173682	hambamoshambaid	?hambamoshambaid =moshamba  (PlP  >hamba+moshamba !01_S	et	f	\N
173683	hambamoshambaid	?hambamoshambaid =moshambai  (PlN  >hamba+moshambai !26_S	et	f	\N
173684	hambamoshambaid	?hambamoshambaid =moshambai  (SgP  >hamba+moshambai !26_S	et	f	\N
173696	poolakased	poolakased =poolakase  (PlN  >poolakane !12_A	et	f	\N
173697	poolakased	"poolakane %poolaka  )NE_aA  <poolakas ;02_S	et	f	\N
173698	poolakased	poolakased =kase  (PlN  >poola+kask !22_S	et	f	\N
173700	poolakased	poolakased =akase  (PlN  >pool+akane !10_A	et	f	\N
173702	poolakased	"pool+akane %aka  )NE_aA  <pool+aka ;16_S	et	f	\N
173713	kaunise	?kaunise =kaunise  (IndPrPs_  >kaunisema !27_V	et	f	\N
173714	kaunise	?kaunise =kaunise  (ImpPrSg2  >kaunisema !27_V	et	f	\N
173728	jandal	?jandal =janda  (SgAd  >janda !16_S	et	f	\N
173729	jandal	?jandal =jandal  (SgN  >jandal !02_S	et	f	\N
173736	ndeb	### ndeb	et	f	\N
173737	õnnelikuim	?õnnelikuim =õnnelikuim  (SgN  >õnnelikuim !02_A	et	f	\N
173765	puhama	?puhama =puha  (Sup  >puhama !27_V	et	f	\N
173766	puhama	?puhama =puhama  (SgG  >puham !02_A	et	f	\N
173774	xomxama	### xomxama	et	f	\N
173775	cmpaxa	?cmpaxa =cmpaxa  (SgN  >cmpaxa !16_S	et	f	\N
173776	cmpaxa	?cmpaxa =cmpaxa  (SgG  >cmpaxa !16_S	et	f	\N
173777	xomname	?xomname =xomna  (IndPrPl1  >xomnama !29_V	et	f	\N
173778	ue2o	### ue2o	et	f	\N
173786	tegusona	?tegusona =teguso  (SgEs  >teguso !01_S	et	f	\N
173787	tegusona	?tegusona =sona  (SgN  >tegu+sona !17_S	et	f	\N
173788	tegusona	?tegusona =sona  (SgG  >tegu+sona !17_S	et	f	\N
173789	tegusona	?tegusona =sona  (SgP  >tegu+sona !17_S	et	f	\N
173797	lopetama	?lopetama =lope  (SupIps  >lopema !27_V	et	f	\N
173798	lopetama	?lopetama =lopeta  (Sup  >lopetama !27_V	et	f	\N
173800	lopetama	?lopetama =lopetama  (SgG  >lopetam !02_A	et	f	\N
173801	l5ppetama	?lppetama =lppeta  (Sup  >lppetama !27_V	et	f	\N
173802	l5ppetama	?lppetama =lppetama  (SgG  >lppetam !02_A	et	f	\N
173833	otsetolge	?otsetolge =otsetolge  (PlP  >otsetolg !22_S	et	f	\N
173834	otsetolge	?otsetolge =tolge  (SgN  >otse+tolge !06_S	et	f	\N
173835	otsetolge	?otsetolge =etolge  (PlP  >ots+etolg !22_S	et	f	\N
173836	jtitib	?jtitib =jtiti  (IndPrSg3  >jtitima !27_V	et	f	\N
173837	jtitib	?jtitib =jtiti  (IndPrSg3  >jtittima !28_V	et	f	\N
173846	kaskima	?kaskima =kaski  (Sup  >kaskima !28_V	et	f	\N
173847	kaskima	?kaskima =kaskima  (SgG  >kaskim !02_A	et	f	\N
173848	kaskima	?kaskima =kima  (SgN  >kas+kima !17_S	et	f	\N
173849	kaskima	?kaskima =kima  (SgG  >kas+kima !17_S	et	f	\N
173850	kaskima	?kaskima =kima  (SgP  >kas+kima !17_S	et	f	\N
173861	jalgitav	?jalgitav =jalgi  (PtsPrIps  >jalkima !28_V	et	f	\N
173862	jalgitav	?jalgitav =jalgita  (PtsPrPs  >jalgitama !27_V	et	f	\N
173863	jalgitav	?jalgitav =jalgitav  (SgN  >jalgitav !02_A	et	f	\N
173864	jalgitav	?jalgitav =itav  (SgN  >jalg+itav !02_A	et	f	\N
173872	vdga	### vdga	et	f	\N
173873	6bl70	### 6bl70	et	f	\N
173880	6bano	?bano =bano  (SgN  >bano !17~16_S	et	f	\N
173881	6bano	?bano =bano  (SgG  >bano !17~16_S	et	f	\N
173882	6bano	?bano =bano  (SgP  >bano !17_S	et	f	\N
173887	smo	### smo	et	f	\N
173892	kdin	### kdin	et	f	\N
173902	pohjustatud	?pohjustatud =pohjusta  (PtsPtIps  >pohjustama !27_V	et	f	\N
173903	pohjustatud	?pohjustatud =pohjustatu  (PlN  >pohjustatu !01_S	et	f	\N
173904	pohjustatud	?pohjustatud =pohjustatu  (IndPrSg2  >pohjustatuma !27_V	et	f	\N
173905	pohjustatud	?pohjustatud =pohjustatud  (ID  >pohjustatud !41_A	et	f	\N
173908	paduo	?paduo =paduo  (SgN  >paduo !01_S	et	f	\N
173909	paduo	?paduo =paduo  (SgG  >paduo !01_S	et	f	\N
173916	motleb	?motleb =motle  (IndPrSg3  >motlema !30_V	et	f	\N
173918	tootab	?tootab =toota  (IndPrSg3  >tootama !27_V	et	f	\N
173919	vliga	?vliga =vliga  (SgN  >vliga !17_S	et	f	\N
173920	vliga	?vliga =vliga  (SgG  >vliga !17_S	et	f	\N
173921	vliga	?vliga =vliga  (SgP  >vliga !17_S	et	f	\N
173922	vliga	?vliga =vliga  (IndPrPs_  >vligama !27_V	et	f	\N
173923	vliga	?vliga =vliga  (ImpPrSg2  >vligama !27_V	et	f	\N
173952	opilast	?opilast =opila  (SgEl  >opila !01_S	et	f	\N
173953	opilast	?opilast =opilas  (SgP  >opilane !12_S	et	f	\N
173954	joutagi	?joutagi =jou  (SgAb^  >jou !26_S	et	f	\N
173955	joutagi	?joutagi =jout  (Inf^  >joutma !34_V	et	f	\N
173956	joutagi	?joutagi =jouta  (SgN^  >jouta !16_S	et	f	\N
173957	joutagi	?joutagi =jouta  (SgG^  >jouta !16_S	et	f	\N
173958	joutagi	?joutagi =jouta  (IndPrPs_^  >joutama !27_V	et	f	\N
173960	joutagi	?joutagi =jouta  (ImpPrSg2^  >joutama !27_V	et	f	\N
173963	suntaksis	?suntaksis =suntaksi  (SgIn  >suntaksi !01_S	et	f	\N
173964	suntaksis	?suntaksis =suntaksi  (IndIpfSg3  >suntaksima !28_V	et	f	\N
173965	suntaksis	?suntaksis =suntaksis  (SgN  >suntaksis !11_S	et	f	\N
173970	mote	?mote =mote  (SgN  >mote !06_S	et	f	\N
173971	mote	?mote =mote  (IndPrPs_  >motema !27_V	et	f	\N
173972	mote	?mote =mote  (ImpPrSg2  >motema !27_V	et	f	\N
173979	valte	?valte =valte  (SgN  >valte !06_S	et	f	\N
173738	pidulikam	?pidulikam =pidulikam  (SgN  >pidulikam !02_A	et	f	\N
173742	koera-	koera- =koera  (SgG  >koer !23?22_SA	et	f	\N
173743	koera-	koera- =koera  (SgP  >koer !23?22_SA	et	f	\N
173744	koera-	koera- =koera  (SgAdt  >koer !23?22_SA	et	f	\N
173746	küünladinterferentne	?küünladinterferentne =küünladinterferentne  (SgN  >küünladinterferentne !02_A	et	f	\N
173747	küünladinterferentne	?küünladinterferentne =dinterferentne  (SgN  >küünla+dinterferentne !02_A	et	f	\N
173748	viga-	viga- =viga  (SgN  >viga !18_S	et	f	\N
173749	viga-	viga- =viga  (SgP  >viga !18_S	et	f	\N
173769	liitsona	?liitsona =liitso  (SgEs  >liitso !16_S	et	f	\N
173770	liitsona	?liitsona =sona  (SgN  >liit+sona !17_S	et	f	\N
173771	liitsona	?liitsona =sona  (SgG  >liit+sona !17_S	et	f	\N
173772	liitsona	?liitsona =sona  (SgP  >liit+sona !17_S	et	f	\N
173779	pod	### pod	et	f	\N
173782	t5lge	### t5lge	et	f	\N
173783	vd	### vd	et	f	\N
173794	loppema	?loppema =loppe  (Sup  >loppema !27_V	et	f	\N
173795	loppema	?loppema =loppema  (SgG  >loppem !02_A	et	f	\N
173813	kdisin	?kdisin =kdisi  (IndPrSg1  >kdisima !27_V	et	f	\N
173814	kdisin	?kdisin =kdisin  (SgN  >kdisin !02_S	et	f	\N
173815	kkima	?kkima =kkima  (SgN  >kkima !17_S	et	f	\N
173816	kkima	?kkima =kkima  (SgG  >kkima !17_S	et	f	\N
173817	kkima	?kkima =kkima  (SgP  >kkima !17_S	et	f	\N
173818	kkima	?kkima =kkima  (IndPrPs_  >kkimama !27_V	et	f	\N
173819	kkima	?kkima =kkima  (ImpPrSg2  >kkimama !27_V	et	f	\N
173830	konzy	### konzy	et	f	\N
173831	naue	?naue =naue  (SgN  >naue !06_S	et	f	\N
173832	naue	?naue =naue  (SgG  >naue !06_S	et	f	\N
173854	vkga	### vkga	et	f	\N
173874	ouercb	?ouercb =ouercb  (SgN  >ouercb !02_S	et	f	\N
173883	ouenb	?ouenb =ouenb  (SgN  >ouenb !02_S	et	f	\N
173886	maarsona	?maarsona =maarso  (SgEs  >maarso !16_S	et	f	\N
173893	oue	?oue =oue  (SgN  >oue !06_S	et	f	\N
173894	oue	?oue =oue  (SgG  >oue !06_S	et	f	\N
173897	ptirast	?ptirast =ptira  (SgEl  >ptira !17_S	et	f	\N
173898	ptirast	?ptirast =ptiras  (SgP  >ptiras !09_S	et	f	\N
173899	ptirast	?ptirast =ptiras  (SgP  >ptirane !10_A	et	f	\N
173900	kkisin	?kkisin =kkisi  (IndPrSg1  >kkisima !27_V	et	f	\N
173901	kkisin	?kkisin =kkisin  (SgN  >kkisin !02_S	et	f	\N
173927	uhildumisviga	?uhildumisviga =uhildumisvi  (SgKom  >uhildumisv !22_S	et	f	\N
173928	pronoomenivigaoige	?pronoomenivigaoige =pronoomenivigaoige  (PlP  >pronoomenivigaoig !22_S	et	f	\N
173931	6onbucue	?onbucue =onbucue  (SgN  >onbucue !01_S	et	f	\N
173932	6onbucue	?onbucue =onbucue  (SgG  >onbucue !01_S	et	f	\N
173935	ouepedu	?ouepedu =ouepedu  (IndPrPs_  >ouepeduma !27_V	et	f	\N
173936	ouepedu	?ouepedu =ouepedu  (ImpPrSg2  >ouepeduma !27_V	et	f	\N
173937	votab	?votab =vota  (IndPrSg3  >votama !27_V	et	f	\N
173948	markusedtahelepanekud	?markusedtahelepanekud =markusedtahelepaneku  (IndPrSg2  >markusedtahelepanekuma !27_V	et	f	\N
173949	ruhmas	?ruhmas =ruhma  (SgIn  >ruhma !16_S	et	f	\N
173950	ruhmas	?ruhmas =ruhma  (IndIpfSg3  >ruhmama !29_V	et	f	\N
173951	ruhmas	?ruhmas =ruhmas  (SgN  >ruhmas !07_S	et	f	\N
173959	koiki	?koiki =koiki  (ID  >koiki !41_D	et	f	\N
173961	koiki	?koiki =koiki  (SgP  >koik !22_S	et	f	\N
173962	koiki	?koiki =koiki  (SgAdt  >koik !22_S	et	f	\N
173978	wis	### wis	et	f	\N
173984	mire	?mire =mire  (SgN  >mire !16_S	et	f	\N
173985	mire	?mire =mire  (SgG  >mire !16_S	et	f	\N
173986	mire	?mire =mire  (IndPrPs_  >mirema !27_V	et	f	\N
173987	mire	?mire =mire  (ImpPrSg2  >mirema !27_V	et	f	\N
173988	lahtekohta	?lahtekohta =lahtekohta  (SgN  >lahtekohta !16_S	et	f	\N
173989	lahtekohta	?lahtekohta =lahtekohta  (SgG  >lahtekohta !16_S	et	f	\N
173990	lahtekohta	?lahtekohta =lahtekohta  (IndPrPs_  >lahtekohtama !27_V	et	f	\N
173991	lahtekohta	?lahtekohta =lahtekohta  (ImpPrSg2  >lahtekohtama !27_V	et	f	\N
174027	taiskasvanud	?taiskasvanud =taiskasvanu  (PlN  >taiskasvanu !01_S	et	f	\N
174028	taiskasvanud	?taiskasvanud =taiskasvanu  (IndPrSg2  >taiskasvanuma !27_V	et	f	\N
174029	taiskasvanud	?taiskasvanud =taiskasvanud  (ID  >taiskasvanud !41_A	et	f	\N
174030	taiskasvanud	?taiskasvanud =skasvanu  (PlN  >tai+skasvanu !01_S	et	f	\N
174032	menuu	?menuu =menuu  (SgN  >menuu !26_S	et	f	\N
174033	menuu	?menuu =menuu  (SgG  >menuu !26_S	et	f	\N
174049	mojutas	?mojutas =mojuta  (IndIpfSg3  >mojutama !27_V	et	f	\N
174050	haaldust	?haaldust =haaldu  (SgEl  >haaldu !01_S	et	f	\N
174051	haaldust	?haaldust =haaldus  (SgP  >haaldus !11~09_S	et	f	\N
174056	sidesonaga	?sidesonaga =sona  (SgKom  >side+sona !17_S	et	f	\N
174064	pohjendada	?pohjendada =pohjenda  (Inf  >pohjendama !27_V	et	f	\N
174066	oleksa	?oleksa =oleksa  (SgN  >oleksa !01_S	et	f	\N
174067	oleksa	?oleksa =oleksa  (SgG  >oleksa !01_S	et	f	\N
174072	rohuga	rohuga =rohu  (SgKom  >roht !22_S	et	f	\N
174073	rohuga	rohuga =rohu  (SgKom  >rohi !24_S	et	f	\N
174094	moeldud	?moeldud =moeldu  (PlN  >moeldu !01_S	et	f	\N
174095	moeldud	?moeldud =moeldu  (IndPrSg2  >moelduma !27_V	et	f	\N
174096	moeldud	?moeldud =moeldud  (ID  >moeldud !41_A	et	f	\N
174098	tuupilisi	?tuupilisi =tuupilisi  (PlP  >tuupiline !12_A	et	f	\N
173878	uumamb	?uumamb =uumamb  (SgN  >uumamb !02_S	et	f	\N
173879	mke	### mke	et	f	\N
173884	uhmepecxo	?uhmepecxo =uhmepecxo  (SgN  >uhmepecxo !16_S	et	f	\N
173885	uhmepecxo	?uhmepecxo =uhmepecxo  (SgG  >uhmepecxo !16_S	et	f	\N
173888	oues	?oues =oue  (SgIn  >oue !06_S	et	f	\N
173889	oues	?oues =oues  (SgN  >oues !02_S	et	f	\N
173890	pzieval	?pzieval =pzieva  (SgAd  >pzieva !16_S	et	f	\N
173891	pzieval	?pzieval =pzieval  (SgN  >pzieval !02_S	et	f	\N
173895	kdivad	?kdivad =kdiva  (PlN  >kdiva !17_S	et	f	\N
173896	kdivad	?kdivad =kdiva  (IndPrSg2  >kdivama !27_V	et	f	\N
173906	uacmoma	?uacmoma =uacmoma  (SgN  >uacmoma !01_S	et	f	\N
173907	uacmoma	?uacmoma =uacmoma  (SgG  >uacmoma !01_S	et	f	\N
173929	sonajarjeviga	?sonajarjeviga =sonajarjevi  (SgKom  >sonajarjev !02_A	et	f	\N
173930	jarjekorrad	?jarjekorrad =jarjekorra  (PlN  >jarjekorra !16_S	et	f	\N
173933	dnuxxaae	?dnuxxaae =dnuxxaae  (SgN  >dnuxxaae !26_S	et	f	\N
173934	dnuxxaae	?dnuxxaae =dnuxxaae  (SgG  >dnuxxaae !26_S	et	f	\N
173966	vigukonet	### vigukonet	et	f	\N
173967	jalgima	jalgima =ima  (SgN  >jalg+ima !17_S	et	f	\N
173968	jalgima	jalgima =ima  (SgG  >jalg+ima !17_S	et	f	\N
173969	jalgima	jalgima =ima  (SgP  >jalg+ima !17_S	et	f	\N
173973	korgklassist	?korgklassist =korgklassi  (SgEl  >korgklassi !01_S	et	f	\N
173974	korgklassist	?korgklassist =korgklassi  (SgEl  >korgklass !22_S	et	f	\N
173975	korgklassist	?korgklassist =korgklassis  (SgP  >korgklassis !11_S	et	f	\N
173976	korgklassist	?korgklassist =korgklassist  (SgN  >korgklassist !22_S	et	f	\N
173993	menü	### menü	et	f	\N
173996	analuus	?analuus =analuu  (SgIn  >analuu !26_S	et	f	\N
173997	analuus	?analuus =analuus  (SgN  >analuus !22_S	et	f	\N
174005	pedagoogikaulikooli	?pedagoogikaulikooli =pedagoogikaulikooli  (SgN  >pedagoogikaulikooli !16_S	et	f	\N
174006	pedagoogikaulikooli	?pedagoogikaulikooli =pedagoogikaulikooli  (SgG  >pedagoogikaulikooli !16_S	et	f	\N
174007	pedagoogikaulikooli	?pedagoogikaulikooli =pedagoogikaulikooli  (SgG  >pedagoogikaulikool !22_S	et	f	\N
174009	pedagoogikaulikooli	?pedagoogikaulikooli =pedagoogikaulikooli  (SgP  >pedagoogikaulikool !22_S	et	f	\N
174011	pedagoogikaulikooli	?pedagoogikaulikooli =pedagoogikaulikooli  (SgAdt  >pedagoogikaulikool !22_S	et	f	\N
174012	pedagoogikaulikooli	?pedagoogikaulikooli =pedagoogikaulikooli  (IndPrPs_  >pedagoogikaulikoolima !28_V	et	f	\N
174013	pedagoogikaulikooli	?pedagoogikaulikooli =pedagoogikaulikooli  (ImpPrSg2  >pedagoogikaulikoolima !28_V	et	f	\N
174014	pedagoogikaulikooli	?pedagoogikaulikooli =ulikooli  (SgN  >pedagoogika+ulikooli !16_S	et	f	\N
174015	pedagoogikaulikooli	?pedagoogikaulikooli =ulikooli  (SgG  >pedagoogika+ulikooli !16_S	et	f	\N
174016	pedagoogikaulikooli	?pedagoogikaulikooli =ulikooli  (SgG  >pedagoogika+ulikool !22_S	et	f	\N
174017	pedagoogikaulikooli	?pedagoogikaulikooli =ulikooli  (SgP  >pedagoogika+ulikool !22_S	et	f	\N
174018	pedagoogikaulikooli	?pedagoogikaulikooli =ulikooli  (SgAdt  >pedagoogika+ulikool !22_S	et	f	\N
174019	pedagoogikaulikooli	?pedagoogikaulikooli =kaulikooli  (SgN  >pedagoogi+kaulikooli !16_S	et	f	\N
174020	pedagoogikaulikooli	?pedagoogikaulikooli =kaulikooli  (SgG  >pedagoogi+kaulikooli !16_S	et	f	\N
174021	pedagoogikaulikooli	?pedagoogikaulikooli =kaulikooli  (SgG  >pedagoogi+kaulikool !22_S	et	f	\N
174022	pedagoogikaulikooli	?pedagoogikaulikooli =kaulikooli  (SgP  >pedagoogi+kaulikool !22_S	et	f	\N
174023	pedagoogikaulikooli	?pedagoogikaulikooli =kaulikooli  (SgAdt  >pedagoogi+kaulikool !22_S	et	f	\N
174052	korge	?korge =korge  (SgN  >korge !06_S	et	f	\N
174053	korge	?korge =korge  (PlP  >korg !22_S	et	f	\N
174054	korge	?korge =korge  (IndPrPs_  >korgema !27_V	et	f	\N
174055	korge	?korge =korge  (ImpPrSg2  >korgema !27_V	et	f	\N
174061	pohjendatav	?pohjendatav =pohjenda  (PtsPrIps  >pohjendama !27_V	et	f	\N
174062	pohjendatav	?pohjendatav =pohjendata  (PtsPrPs  >pohjendatama !27_V	et	f	\N
174063	pohjendatav	?pohjendatav =pohjendatav  (SgN  >pohjendatav !02_A	et	f	\N
174069	keskkorge	?keskkorge =keskkorge  (PlP  >keskkorg !22_S	et	f	\N
174070	keskkorge	?keskkorge =korge  (SgN  >kesk+korge !06_S	et	f	\N
174071	keskkorge	?keskkorge =korge  (PlP  >kesk+korg !22_S	et	f	\N
174097	etmenuust	?etmenuust =etmenuu  (SgEl  >etmenuu !26_S	et	f	\N
174099	kaanetes	?kaanetes =kaanete  (PlIn  >kaanett !22_S	et	f	\N
174100	uhildu	?uhildu =uhildu  (SgN  >uhildu !01_S	et	f	\N
174101	uhildu	?uhildu =uhildu  (SgG  >uhildu !01_S	et	f	\N
174102	uhildu	?uhildu =uhildu  (IndPrPs_  >uhilduma !27_V	et	f	\N
174103	uhildu	?uhildu =uhildu  (ImpPrSg2  >uhilduma !27_V	et	f	\N
174111	alalutlev	?alalutlev =alalutlev  (SgN  >alalutlev !02_A	et	f	\N
174112	alalutlev	?alalutlev =utlev  (SgN  >alal+utlev !02_A	et	f	\N
174113	alalutlev	?alalutlev =lutlev  (SgN  >ala+lutlev !02_A	et	f	\N
174124	omadussonadega	?omadussonadega =sona  (PlKom  >omadus+sona !17_S	et	f	\N
174125	tiaupilisi	?tiaupilisi =tiaupilisi  (PlP  >tiaupiline !12_A	et	f	\N
174137	voortuvelise	?voortuvelise =voortuvelise  (SgG  >voortuveline !12_A	et	f	\N
174138	sonaga	?sonaga =sona  (SgKom  >sona !17_S	et	f	\N
174146	pohjendama	?pohjendama =pohjenda  (Sup  >pohjendama !27_V	et	f	\N
174147	pohjendama	?pohjendama =pohjendama  (SgG  >pohjendam !02_A	et	f	\N
174157	pohjustab	?pohjustab =pohjusta  (IndPrSg3  >pohjustama !27_V	et	f	\N
174168	jatab	?jatab =jata  (IndPrSg3  >jatama !27_V	et	f	\N
174176	ulesandeks	?ulesandeks =ulesande  (PlTr  >ulesant !22_S	et	f	\N
173980	valte	?valte =valte  (SgG  >valde !06_S	et	f	\N
173981	valte	?valte =valte  (PlP  >valt !22_S	et	f	\N
173982	valte	?valte =valte  (IndPrPs_  >valtema !27_V	et	f	\N
173983	valte	?valte =valte  (ImpPrSg2  >valtema !27_V	et	f	\N
173998	gibalo	?gibalo =gibalo  (SgN  >gibalo !01_S	et	f	\N
173999	gibalo	?gibalo =gibalo  (SgG  >gibalo !01_S	et	f	\N
174004	parineb	?parineb =parine  (IndPrSg3  >parinema !27_V	et	f	\N
174031	jarelduse	?jarelduse =jarelduse  (SgG  >jareldus !11_S	et	f	\N
174037	tuupilised	?tuupilised =tuupilise  (PlN  >tuupiline !12_A	et	f	\N
174038	nadalad	?nadalad =nadala  (PlN  >nadala !01_S	et	f	\N
174039	haaldus-	?haaldus- =haaldu  (SgIn  >haaldu !01_S	et	f	\N
174040	haaldus-	?haaldus- =haaldu  (IndIpfSg3  >haalduma !27_V	et	f	\N
174041	haaldus-	?haaldus- =haaldus  (SgN  >haaldus !11~09_S	et	f	\N
174042	oigekirja-	?oigekirja- =oigekirja  (SgN  >oigekirja !16_S	et	f	\N
174043	oigekirja-	?oigekirja- =oigekirja  (SgG  >oigekirjas !02_A	et	f	\N
174044	oigekirja-	?oigekirja- =oigekirja  (SgG  >oigekirja !16_S	et	f	\N
174045	sidesona	?sidesona =sideso  (SgEs  >sideso !01_S	et	f	\N
174046	sidesona	?sidesona =sona  (SgN  >side+sona !17_S	et	f	\N
174047	sidesona	?sidesona =sona  (SgG  >side+sona !17_S	et	f	\N
174048	sidesona	?sidesona =sona  (SgP  >side+sona !17_S	et	f	\N
174090	sonamoodustusviis	?sonamoodustusviis =sonamoodustusvii  (SgIn  >sonamoodustusvii !26_S	et	f	\N
174091	sonamoodustusviis	?sonamoodustusviis =sonamoodustusviis  (SgN  >sonamoodustusviis !22_S	et	f	\N
174105	objektikaane	?objektikaane =objektikaane  (SgN  >objektikaane !16_S	et	f	\N
174106	objektikaane	?objektikaane =objektikaane  (SgG  >objektikaane !16_S	et	f	\N
174107	objektikaane	?objektikaane =objektikaane  (PlP  >objektikaan !22_S	et	f	\N
174127	puiadis	?puiadis =puiadi  (SgIn  >puiadi !01_S	et	f	\N
174128	puiadis	?puiadis =puiadi  (SgIn  >puiad !02_S	et	f	\N
174129	puiadis	?puiadis =puiadi  (IndIpfSg3  >puiadima !28_V	et	f	\N
174130	puiadis	?puiadis =puiadis  (SgN  >puiadis !11_S	et	f	\N
174155	korgema	?korgema =korge  (Sup  >korgema !27_V	et	f	\N
174156	korgema	?korgema =korgema  (SgG  >korgem !02_A	et	f	\N
174158	moistmist	?moistmist =moistmi  (SgEl  >moistmi !01_S	et	f	\N
174159	moistmist	?moistmist =moistmi  (SgEl  >moistm !22_S	et	f	\N
174160	moistmist	?moistmist =moistmis  (SgP  >moistmis !09_S	et	f	\N
174161	moistmist	?moistmist =moistmis  (SgP  >moistmine !12?10_S	et	f	\N
174162	moistmist	?moistmist =moistmist  (SgN  >moistmist !22_S	et	f	\N
174167	lopetuseks	?lopetuseks =lopetuse  (SgTr  >lopetus !11_S	et	f	\N
174181	kirjeldumine	?kirjeldumine =kirjeldumine  (SgN  >kirjeldumine !12_S	et	f	\N
174182	kirjeldumine	?kirjeldumine =kirjeldumine  (PlP  >kirjeldumin !19_S	et	f	\N
174209	haigestus	haigestus =haigestu  (IndIpfSg3  >haigestuma !27_V	et	f	\N
174210	haigestus	haigestus =haigestus  (SgN  >haigestus !11_S	et	f	\N
174211	haigestus	"haigestus %haigesta  )US_vS  <haigestama ;27_V	et	f	\N
174226	tahega	### tahega	et	f	\N
174250	fleqarorwyeckwo	?fleqarorwyeckwo =fleqarorwyeckwo  (SgN  >fleqarorwyeckwo !01_S	et	f	\N
174251	fleqarorwyeckwo	?fleqarorwyeckwo =fleqarorwyeckwo  (SgG  >fleqarorwyeckwo !01_S	et	f	\N
174267	voimalikku	?voimalikku =voimalikku  (SgP  >voimalik !25_A	et	f	\N
174268	voimalikku	?voimalikku =voimalikku  (SgAdt  >voimalik !25_A	et	f	\N
174269	voimalikku	?voimalikku =voimalikku  (IndPrPs_  >voimalikkuma !27_V	et	f	\N
174270	voimalikku	?voimalikku =voimalikku  (ImpPrSg2  >voimalikkuma !27_V	et	f	\N
174308	mustiline	?mustiline =mustiline  (SgN  >mustiline !12_A	et	f	\N
174309	mustiline	?mustiline =mustiline  (PlP  >mustilin !19_S	et	f	\N
174310	mustiline	?mustiline =iline  (SgN  >must+iline !10_A	et	f	\N
174311	jargmiselt	?jargmiselt =jargmise  (SgAbl  >jargmine !12?10_A	et	f	\N
174312	jargmiselt	?jargmiselt =jargmiselt  (ID  >jargmiselt !41_D	et	f	\N
174314	vl	### vl	et	f	\N
174320	raakida	?raakida =raaki  (Inf  >raakima !28_V	et	f	\N
174325	referentsete	?referentsete =referentse  (PlG  >referentne !02_A	et	f	\N
174326	referentsete	?referentsete =referentse  (IndPrPl2  >referentsema !27_V	et	f	\N
174329	asesonadega	?asesonadega =sona  (PlKom  >ase+sona !17_S	et	f	\N
174330	oeldis	?oeldis =oeldi  (SgIn  >oelt !22_S	et	f	\N
174331	oeldis	?oeldis =oeldi  (IndIpfSg3  >oeldima !28_V	et	f	\N
174332	oeldis	?oeldis =oeldis  (SgN  >oeldis !09_S	et	f	\N
174341	noctponnm	?noctponnm =noctponnm  (SgN  >noctponnm !22_S	et	f	\N
174358	10tolkelaenud	?tolkelaenud =tolkelaenu  (PlN  >tolkelaenu !01_S	et	f	\N
174359	10tolkelaenud	?tolkelaenud =tolkelaenu  (IndPrSg2  >tolkelaenuma !27_V	et	f	\N
174360	10tolkelaenud	?tolkelaenud =tolkelaenud  (ID  >tolkelaenud !41_A	et	f	\N
174371	cnywan	?cnywan =cnywan  (SgN  >cnywan !02_S	et	f	\N
174380	tiglikult	?tiglikult =tigliku  (SgAbl  >tigliku !01_S	et	f	\N
174381	tiglikult	?tiglikult =tigliku  (SgAbl  >tiglik !02_S	et	f	\N
174382	tiglikult	?tiglikult =tiglikult  (ID  >tiglikult !41_D	et	f	\N
174383	naitas	?naitas =naita  (SgIn  >naita !16_S	et	f	\N
174384	naitas	?naitas =naita  (IndIpfSg3  >naitama !27_V	et	f	\N
174385	naitas	?naitas =naitas  (SgN  >naitas !07_S	et	f	\N
174391	zanrist	?zanrist =zanri  (SgEl  >zanri !16_S	et	f	\N
174392	zanrist	?zanrist =zanri  (SgEl  >zanr !22_S	et	f	\N
174076	vooras	?vooras =voora  (IndIpfSg3  >voorama !29_V	et	f	\N
174077	vooras	?vooras =vooras  (SgN  >vooras !07_S	et	f	\N
174082	noutu	?noutu =noutu  (SgN  >noutu !01_A	et	f	\N
174084	noutu	?noutu =noutu  (SgG  >noutu !01_A	et	f	\N
174087	noutu	?noutu =noutu  (IndPrPs_  >noutuma !27_V	et	f	\N
174089	noutu	?noutu =noutu  (ImpPrSg2  >noutuma !27_V	et	f	\N
174092	sonaviga	?sonaviga =sonavi  (SgKom  >sonav !02_A	et	f	\N
174104	nimisonaga	?nimisonaga =sona  (SgKom  >nimi+sona !17_S	et	f	\N
174163	hire	?hire =hire  (SgN  >hire !16_S	et	f	\N
174164	hire	?hire =hire  (SgG  >hire !16_S	et	f	\N
174165	hire	?hire =hire  (IndPrPs_  >hirema !27_V	et	f	\N
174166	hire	?hire =hire  (ImpPrSg2  >hirema !27_V	et	f	\N
174186	olut	?olut =olut  (SgN  >olut !02_S	et	f	\N
174187	raakidsid	?raakidsid =raakidsi  (PlN  >raakidsi !01_S	et	f	\N
174188	raakidsid	?raakidsid =raakidsi  (PlN  >raakids !22_S	et	f	\N
174189	raakidsid	?raakidsid =raakidsi  (IndPrSg2  >raakidsima !28_V	et	f	\N
174191	opivad	?opivad =opi  (IndPrPl3  >opima !27_V	et	f	\N
174192	opivad	?opivad =opi  (IndPrPl3  >oppima !28_V	et	f	\N
174193	opivad	?opivad =opiva  (PlN  >opiva !01_S	et	f	\N
174195	opivad	?opivad =opiva  (PlN  >opiv !02_A	et	f	\N
174212	marja	marja =marja  (SgG  >mari !24_S	et	f	\N
174213	marja	marja =marja  (SgP  >mari !24_S	et	f	\N
174214	marja	marja =marja  (SgAdt  >mari !24_S	et	f	\N
174215	lauljanna	lauljanna =lauljanna  (SgN  >lauljanna !16_S	et	f	\N
174216	lauljanna	lauljanna =lauljanna  (SgG  >lauljanna !16_S	et	f	\N
174217	kumnendal	?kumnendal =kumnenda  (SgAd  >kumnenda !01_S	et	f	\N
174228	raakisid	?raakisid =raaki  (PlP  >raak !22_S	et	f	\N
174229	raakisid	?raakisid =raaki  (IndIpfSg2  >raakima !28_V	et	f	\N
174230	raakisid	?raakisid =raaki  (IndIpfPl3  >raakima !28_V	et	f	\N
174233	ulkoolis	?ulkoolis =ulkooli  (SgIn  >ulkooli !16_S	et	f	\N
174234	ulkoolis	?ulkoolis =ulkooli  (SgIn  >ulkool !22_S	et	f	\N
174235	ulkoolis	?ulkoolis =ulkooli  (IndIpfSg3  >ulkoolima !28_V	et	f	\N
174236	ulkoolis	?ulkoolis =ulkoolis  (SgN  >ulkoolis !09_S	et	f	\N
174271	pohjendus	?pohjendus =pohjendu  (SgIn  >pohjendu !01_S	et	f	\N
174272	pohjendus	?pohjendus =pohjendu  (IndIpfSg3  >pohjenduma !27_V	et	f	\N
174273	pohjendus	?pohjendus =pohjendus  (SgN  >pohjendus !11_S	et	f	\N
174276	viieteistkumnendal	?viieteistkumnendal =viieteistkumnenda  (SgAd  >viieteistkumnenda !16_S	et	f	\N
174277	viieteistkumnendal	?viieteistkumnendal =viieteistkumnendal  (SgN  >viieteistkumnendal !02_S	et	f	\N
174278	viieteistkumnendal	?viieteistkumnendal =kumnenda  (SgAd  >viie+teist+kumnenda !01_S	et	f	\N
174279	viieteistkumnendal	?viieteistkumnendal =teistkumnenda  (SgAd  >viie+teistkumnenda !16_S	et	f	\N
174280	viieteistkumnendal	?viieteistkumnendal =teistkumnendal  (SgN  >viie+teistkumnendal !02_S	et	f	\N
174301	panemata	panemata =pane  (SupAb  >panema !36_V	et	f	\N
174302	panemata	panemata =panemata  (ID  >panemata !41_A	et	f	\N
174303	panemata	"panemata %pane  )MATA_vA  <panema ;36_V	et	f	\N
174305	imselt	?imselt =imse  (SgAbl  >imne !02_A	et	f	\N
174306	imselt	?imselt =imse  (PlAbl  >imss !22_S	et	f	\N
174307	imselt	?imselt =imselt  (ID  >imselt !41_D	et	f	\N
174322	tanu	tanu =tanu  (SgN  >tanu !17_S	et	f	\N
174323	tanu	tanu =tanu  (SgG  >tanu !17_S	et	f	\N
174324	tanu	tanu =tanu  (SgP  >tanu !17_S	et	f	\N
174337	moodustus-	moodustus- =moodustu  (IndIpfSg3  >moodustuma !27_V	et	f	\N
174338	moodustus-	moodustus- =moodustus  (SgN  >moodustus !11_S	et	f	\N
174339	moodustus-	"moodustus %moodusta  )US_vS  <moodustama ;27_V	et	f	\N
174340	parywy	### parywy	et	f	\N
174342	parywa	?parywa =parywa  (SgN  >parywa !01_S	et	f	\N
174343	parywa	?parywa =parywa  (SgG  >parywa !01_S	et	f	\N
174372	nnonoqeu	?nnonoqeu =nnonoqeu  (SgN  >nnonoqeu !26_S	et	f	\N
174373	nnonoqeu	?nnonoqeu =nnonoqeu  (SgG  >nnonoqeu !26_S	et	f	\N
174395	muinasjutuline	muinasjutuline =jutuline  (SgN  >muinas+jutuline !12_A	et	f	\N
174396	muinasjutuline	"muinas+jutuline %jutu  )LINE_aA  <muinas+jutt ;22_S	et	f	\N
174398	tapsustav	?tapsustav =tapsusta  (PtsPrPs  >tapsustama !27_V	et	f	\N
174399	tapsustav	?tapsustav =tapsustav  (SgN  >tapsustav !02_A	et	f	\N
174404	grammatikast	grammatikast =grammatika  (SgEl  >grammatika !01_S	et	f	\N
174405	grammatikast	grammatikast =grammatikas  (SgP  >grammatikane !12_A	et	f	\N
174406	grammatikast	"grammatikane %grammatika  )NE_aA  <grammatika ;01_S	et	f	\N
174409	muujaga	muujaga =muuja  (SgKom  >muuja !01_S	et	f	\N
174410	muujaga	"muuja %muu  )JA_vS  <muuma ;27_V	et	f	\N
174411	mõtlesidnad	?mõtlesidnad =mõtlesidna  (PlN  >mõtlesidna !16_S	et	f	\N
174417	mulisika	?mulisika =mulisika  (SgN  >mulisika !01_S	et	f	\N
174418	mulisika	?mulisika =mulisika  (SgG  >mulisika !01_S	et	f	\N
174419	mulisika	?mulisika =mulisika  (SgG  >mulisikas !02_A	et	f	\N
174422	veaanaliiiis	?veaanaliiiis =veaanaliiii  (SgIn  >veaanaliiii !26_S	et	f	\N
174423	veaanaliiiis	?veaanaliiiis =veaanaliiiis  (SgN  >veaanaliiiis !22_S	et	f	\N
174431	toeline	toeline =toeline  (SgN  >toeline !12?10_A	et	f	\N
174432	toeline	"toeline %toe  )LINE_aA  <tugi ;21_S	et	f	\N
174438	kaandevormi	?kaandevormi =kaandevormi  (SgG  >kaandevorm !22_S	et	f	\N
174439	kaandevormi	?kaandevormi =kaandevormi  (SgP  >kaandevorm !22_S	et	f	\N
174108	alaltutlev	?alaltutlev =alaltutlev  (SgN  >alaltutlev !02_A	et	f	\N
174109	alaltutlev	?alaltutlev =tutlev  (SgN  >alal+tutlev !02_A	et	f	\N
174110	moeldakse	?moeldakse =moeldakse  (SgG  >moeldakne !02_A	et	f	\N
174118	asesona	?asesona =aseso  (SgEs  >aseso !01_S	et	f	\N
174119	asesona	?asesona =sona  (SgN  >ase+sona !17_S	et	f	\N
174120	asesona	?asesona =sona  (SgG  >ase+sona !17_S	et	f	\N
174121	asesona	?asesona =sona  (SgP  >ase+sona !17_S	et	f	\N
174126	ulivorret	### ulivorret	et	f	\N
174131	nimisonast	?nimisonast =nimisonas  (SgP  >nimisonane !12_A	et	f	\N
174132	nimisonast	?nimisonast =sona  (SgEl  >nimi+sona !17_S	et	f	\N
174133	nimisonast	?nimisonast =sonas  (SgP  >nimi+sonas !09_S	et	f	\N
174134	nimisonast	?nimisonast =sonas  (SgP  >nimi+sonane !10_A	et	f	\N
174135	tahele	tahele =tahe  (PlAll  >tahk !22_S	et	f	\N
174136	tahele	tahele =tahe  (PlAll  >taht !22_S	et	f	\N
174149	ahmaseks	?ahmaseks =ahmase  (SgTr  >ahmane !10_A	et	f	\N
174150	sonamoodustuse	?sonamoodustuse =sonamoodustuse  (SgG  >sonamoodustus !11~09_S	et	f	\N
174173	analuiasitav	?analuiasitav =analuiasi  (PtsPrIps  >analuiasima !28_V	et	f	\N
174174	analuiasitav	?analuiasitav =analuiasita  (PtsPrPs  >analuiasitama !27_V	et	f	\N
174175	analuiasitav	?analuiasitav =analuiasitav  (SgN  >analuiasitav !02_A	et	f	\N
174177	paeva	?paeva =paeva  (SgN  >paeva !16_S	et	f	\N
174178	paeva	?paeva =paeva  (SgG  >paeva !16_S	et	f	\N
174179	paeva	?paeva =paeva  (IndPrPs_  >paevama !29_V	et	f	\N
174180	paeva	?paeva =paeva  (ImpPrSg2  >paevama !29_V	et	f	\N
174190	oppimisest	?oppimisest =oppimise  (SgEl  >oppimine !12_S	et	f	\N
174194	pedagigika	?pedagigika =pedagigika  (SgN  >pedagigika !01_S	et	f	\N
174196	pedagigika	?pedagigika =pedagigika  (SgG  >pedagigika !01_S	et	f	\N
174197	pedagigika	?pedagigika =pedagigika  (SgG  >pedagigikas !02_A	et	f	\N
174222	gi	### gi	et	f	\N
174225	lopp	?lopp =lopp  (SgN  >lopp !22_S	et	f	\N
174227	oigekirjaveaga	?oigekirjaveaga =oigekirjavea  (SgKom  >oigekirjavea !26_S	et	f	\N
174252	yhwbepcmter	?yhwbepcmter =yhwbepcmter  (SgN  >yhwbepcmter !02_S	et	f	\N
174253	algustahega	?algustahega =stahe  (SgKom  >algu+stahe !16_S	et	f	\N
174264	voimaliku	?voimaliku =voimaliku  (SgG  >voimalik !25_A	et	f	\N
174265	voimaliku	?voimaliku =voimaliku  (IndPrPs_  >voimalikuma !27_V	et	f	\N
174266	voimaliku	?voimaliku =voimaliku  (ImpPrSg2  >voimalikuma !27_V	et	f	\N
174286	arvsonu	?arvsonu =arvsonu  (SgN  >arvsonu !01_S	et	f	\N
174287	arvsonu	?arvsonu =arvsonu  (SgG  >arvsonu !01_S	et	f	\N
174288	arvsonu	?arvsonu =arvsonu  (IndPrPs_  >arvsonuma !27_V	et	f	\N
174289	arvsonu	?arvsonu =arvsonu  (ImpPrSg2  >arvsonuma !27_V	et	f	\N
174290	arvsonu	?arvsonu =sonu  (SgN  >arv+sonu !17_S	et	f	\N
174291	arvsonu	?arvsonu =sonu  (SgG  >arv+sonu !17_S	et	f	\N
174292	arvsonu	?arvsonu =sonu  (SgP  >arv+sonu !17_S	et	f	\N
174313	bot	### bot	et	f	\N
174327	moodustajate	moodustajate =moodustaja  (PlG  >moodustaja !01_S	et	f	\N
174328	moodustajate	"moodustaja %moodusta  )JA_vS  <moodustama ;27_V	et	f	\N
174335	laksid	laksid =laksi  (PlN  >laks !22_S	et	f	\N
174336	laksid	laksid =laksi  (IndPrSg2  >laksima !28_V	et	f	\N
174347	milesse	?milesse =mile  (SgIll  >mile !16_S	et	f	\N
174348	milesse	?milesse =milesse  (SgG  >milesne !02_A	et	f	\N
174349	milesse	?milesse =milesse  (PlP  >miless !22_S	et	f	\N
174352	aidsi	?aidsi =aidsi  (ID  >aidsi !41_D	et	f	\N
174353	aidsi	?aidsi =aidsi  (SgG  >aids !22_S	et	f	\N
174354	aidsi	?aidsi =aidsi  (SgP  >aids !22_S	et	f	\N
174355	aidsi	?aidsi =aidsi  (SgAdt  >aids !22_S	et	f	\N
174356	aidsi	?aidsi =aidsi  (IndPrPs_  >aidsima !28_V	et	f	\N
174357	aidsi	?aidsi =aidsi  (ImpPrSg2  >aidsima !28_V	et	f	\N
174363	noronny	### noronny	et	f	\N
174367	yctanw	?yctanw =yctanw  (SgN  >yctanw !22_S	et	f	\N
174368	koheu	?koheu =koheu  (SgN  >koheu !26_S	et	f	\N
174369	koheu	?koheu =koheu  (SgG  >koheu !26_S	et	f	\N
174377	varvikust	?varvikust =varviku  (SgEl  >varviku !01_S	et	f	\N
174378	varvikust	?varvikust =varviku  (SgEl  >varvik !02_S	et	f	\N
174379	varvikust	?varvikust =varvikus  (SgP  >varvikus !11_S	et	f	\N
174400	ajamaarus	?ajamaarus =ajamaaru  (IndIpfSg3  >ajamaaruma !27_V	et	f	\N
174401	ajamaarus	?ajamaarus =ajamaarus  (SgN  >ajamaarus !11~09_S	et	f	\N
174402	ajamaarus	?ajamaarus =maaru  (SgIn  >aja+maaru !16_S	et	f	\N
174403	ajamaarus	?ajamaarus =maarus  (SgN  >aja+maarus !11~09_S	et	f	\N
174407	sonavara	?sonavara =sonavara  (SgN  >sonavara !16_S	et	f	\N
174408	sonavara	?sonavara =sonavara  (SgG  >sonavara !16_S	et	f	\N
174427	sonad	?sonad =sona  (PlN  >sona !17_S	et	f	\N
174428	sonad	?sonad =sona  (IndPrSg2  >sonama !27_V	et	f	\N
174453	haaldusparane	?haaldusparane =haaldusparane  (SgN  >haaldusparane !12_A	et	f	\N
174454	haaldusparane	?haaldusparane =haaldusparane  (PlP  >haaldusparan !19_S	et	f	\N
174455	koiketega	koiketega =e  (PlKom  >koik+esi !15_S	et	f	\N
174456	koiketega	koiketega =ke  (PlKom  >koi+kesi !15_S	et	f	\N
174457	rezisoorina	?rezisoorina =rezisoori  (SgEs  >rezisoori !16_S	et	f	\N
174458	rezisoorina	?rezisoorina =rezisoori  (SgEs  >rezisoor !22_S	et	f	\N
174459	rezisoorina	?rezisoorina =rezisoorina  (SgG  >rezisoorin !02_S	et	f	\N
174154	loigatuna	?loigatuna =loigatu  (SgEs  >loigatu !01_AS	et	f	\N
174169	ulesehitatud	?ulesehitatud =ulesehita  (PtsPtIps  >ulesehitama !27_V	et	f	\N
174170	ulesehitatud	?ulesehitatud =ulesehitatu  (PlN  >ulesehitatu !01_S	et	f	\N
174171	ulesehitatud	?ulesehitatud =ulesehitatu  (IndPrSg2  >ulesehitatuma !27_V	et	f	\N
174172	ulesehitatud	?ulesehitatud =ulesehitatud  (ID  >ulesehitatud !41_A	et	f	\N
174205	madonna	madonna =madonna  (SgN  >madonna !16_S	et	f	\N
174206	madonna	madonna =madonna  (SgG  >madonna !16_S	et	f	\N
174219	restorani	restorani =restorani  (SgG  >restoran !19_S	et	f	\N
174220	restorani	restorani =restorani  (SgP  >restoran !19_S	et	f	\N
174221	restorani	restorani =restorani  (SgAdt  >restoran !19_S	et	f	\N
174223	juutul	?juutul =juutu  (SgAd  >juutu !01_A	et	f	\N
174224	juutul	?juutul =juutul  (SgN  >juutul !02_S	et	f	\N
174231	lohakusega	lohakusega =lohakuse  (SgKom  >lohakus !11_S	et	f	\N
174232	lohakusega	"lohakus %lohaka  )US_aS  <lohakas ;02_A	et	f	\N
174237	pedagoogikaulikool	?pedagoogikaulikool =pedagoogikaulikoo  (SgAd  >pedagoogikaulikoo !26_S	et	f	\N
174238	pedagoogikaulikool	?pedagoogikaulikool =pedagoogikaulikool  (SgN  >pedagoogikaulikool !22_S	et	f	\N
174239	pedagoogikaulikool	?pedagoogikaulikool =ulikoo  (SgAd  >pedagoogika+ulikoo !26_S	et	f	\N
174240	pedagoogikaulikool	?pedagoogikaulikool =ulikool  (SgN  >pedagoogika+ulikool !22_S	et	f	\N
174241	pedagoogikaulikool	?pedagoogikaulikool =kaulikoo  (SgAd  >pedagoogi+kaulikoo !26_S	et	f	\N
174242	pedagoogikaulikool	?pedagoogikaulikool =kaulikool  (SgN  >pedagoogi+kaulikool !22_S	et	f	\N
174243	suudi	?suudi =suudi  (SgN  >suudi !16_S	et	f	\N
174244	suudi	?suudi =suudi  (SgG  >suudi !16_S	et	f	\N
174245	suudi	?suudi =suudi  (SgG  >suut !22_S	et	f	\N
174246	suudi	?suudi =suudi  (SgP  >suud !22_S	et	f	\N
174247	suudi	?suudi =suudi  (SgAdt  >suud !22_S	et	f	\N
174248	suudi	?suudi =suudi  (IndPrPs_  >suutima !28_V	et	f	\N
174249	suudi	?suudi =suudi  (ImpPrSg2  >suutima !28_V	et	f	\N
174254	hajevil	?hajevil =hajevi  (SgAd  >hajev !02_A	et	f	\N
174255	hajevil	?hajevil =hajevil  (ID  >hajevil !41_DA	et	f	\N
174256	lohakas	lohakas =lohaka  (SgIn  >lohakas !02_A	et	f	\N
174257	lohakas	lohakas =lohakas  (SgN  >lohakas !02_A	et	f	\N
174260	kaanamisviisiga	?kaanamisviisiga =kaanamisviisi  (SgKom  >kaanamisviisi !16_S	et	f	\N
174261	kaanamisviisiga	?kaanamisviisiga =kaanamisviisi  (SgKom  >kaanamisviis !22_S	et	f	\N
174262	madoanna	?madoanna =madoanna  (SgN  >madoanna !16_S	et	f	\N
174263	madoanna	?madoanna =madoanna  (SgG  >madoanna !16_S	et	f	\N
174281	kaanata	?kaanata =kaana  (SgAb  >kaana !16_S	et	f	\N
174282	kaanata	?kaanata =kaana  (Inf  >kaanama !29_V	et	f	\N
174283	kaanata	?kaanata =kaana  (IndPrIps_  >kaanama !29_V	et	f	\N
174284	kaanata	?kaanata =kaanata  (IndPrPs_  >kaanatama !27_V	et	f	\N
174285	kaanata	?kaanata =kaanata  (ImpPrSg2  >kaanatama !27_V	et	f	\N
174297	sunnipaev	?sunnipaev =sunnipaev  (SgN  >sunnipaev !22_S	et	f	\N
174298	sunnipaev	?sunnipaev =paev  (SgN  >sunni+paev !22_S	et	f	\N
174299	lohakusviga	lohakusviga =viga  (SgN  >lohakus+viga !18_S	et	f	\N
174300	lohakusviga	lohakusviga =viga  (SgP  >lohakus+viga !18_S	et	f	\N
174304	kirjtab	?kirjtab =kirjta  (IndPrSg3  >kirjtama !29_V	et	f	\N
174315	cka304ke	?ckake =ckake  (SgN  >ckake !06_S	et	f	\N
174316	cka304ke	?ckake =ckake  (IndPrPs_  >ckakema !27_V	et	f	\N
174317	cka304ke	?ckake =ckake  (ImpPrSg2  >ckakema !27_V	et	f	\N
174321	objektiveast	?objektiveast =objektivea  (SgEl  >objektivea !26_S	et	f	\N
174344	noctpoeha	?noctpoeha =noctpoeha  (SgN  >noctpoeha !01_S	et	f	\N
174345	noctpoeha	?noctpoeha =noctpoeha  (SgG  >noctpoeha !01_S	et	f	\N
174346	pooret	?pooret =poore  (SgP  >poore !06_S	et	f	\N
174362	cnatb	?cnatb =cnatb  (SgN  >cnatb !22_S	et	f	\N
174364	yro	?yro =yro  (SgN  >yro !17~16_S	et	f	\N
174365	yro	?yro =yro  (SgG  >yro !17~16_S	et	f	\N
174366	yro	?yro =yro  (SgP  >yro !17_S	et	f	\N
174433	labi	?labi =labi  (SgN  >labi !17_S	et	f	\N
174434	labi	?labi =labi  (SgG  >labi !17_S	et	f	\N
174435	labi	?labi =labi  (SgP  >labi !17_S	et	f	\N
174436	labi	?labi =labi  (IndPrPs_  >labima !27_V	et	f	\N
174437	labi	?labi =labi  (ImpPrSg2  >labima !27_V	et	f	\N
174443	sonavalik	?sonavalik =sonavalik  (SgN  >sonavalik !25_A	et	f	\N
174469	lulitanud	?lulitanud =lulita  (PtsPtPs  >lulitama !27_V	et	f	\N
174470	lulitanud	?lulitanud =lulitanu  (PlN  >lulitanu !01_S	et	f	\N
174471	lulitanud	?lulitanud =lulitanu  (IndPrSg2  >lulitanuma !27_V	et	f	\N
174472	lulitanud	?lulitanud =lulitanud  (ID  >lulitanud !41_A	et	f	\N
174481	vaita	?vaita =vait  (Inf  >vaitma !34_V	et	f	\N
174482	vaita	?vaita =vaita  (SgN  >vaita !16_S	et	f	\N
174483	vaita	?vaita =vaita  (SgG  >vaita !16_S	et	f	\N
174484	vaita	?vaita =vaita  (IndPrPs_  >vaitama !27_V	et	f	\N
174485	vaita	?vaita =vaita  (ImpPrSg2  >vaitama !27_V	et	f	\N
174499	koetma	?koetma =koet  (Sup  >koetma !34_V	et	f	\N
174500	koetma	?koetma =koetma  (IndPrPs_  >koetmama !29_V	et	f	\N
174501	koetma	?koetma =koetma  (ImpPrSg2  >koetmama !29_V	et	f	\N
174502	kutta	?kutta =kutta  (ID  >kutta !41_D	et	f	\N
174503	kutta	?kutta =kutta  (IndPrPs_  >kuttama !29_V	et	f	\N
174504	kutta	?kutta =kutta  (ImpPrSg2  >kuttama !29_V	et	f	\N
174183	joid	?joid =joi  (PlN  >joi !26_S	et	f	\N
174184	joid	?joid =joi  (SgP  >joi !26_S	et	f	\N
174185	joid	?joid =joid  (SgN  >joid !22_S	et	f	\N
174198	kolmendal	?kolmendal =kolmenda  (SgAd  >kolmenda !01_S	et	f	\N
174199	kolmendal	?kolmendal =endal  (SgN  >kolm+endal !02_S	et	f	\N
174200	autoindust	?autoindust =autoindu  (SgEl  >autoindu !01_S	et	f	\N
174201	autoindust	?autoindust =autoindus  (SgP  >autoindus !11_S	et	f	\N
174202	autoindust	?autoindust =indus  (SgP  >auto+indus !11~09_S	et	f	\N
174203	autoindust	?autoindust =toindu  (SgEl  >au+toindu !01_S	et	f	\N
174204	autoindust	?autoindust =toindus  (SgP  >au+toindus !11~09_S	et	f	\N
174207	kontserti	kontserti =kontserti  (SgP  >kontsert !22_S	et	f	\N
174208	kontserti	kontserti =kontserti  (SgAdt  >kontsert !22_S	et	f	\N
174218	sunipaev	?sunipaev =sunipaev  (SgN  >sunipaev !22_S	et	f	\N
174258	seletamatuid	seletamatuid =seletamatu  (PlP  >seletamatu !01_A	et	f	\N
174259	seletamatuid	"seletamatu %seleta  )MATU_vA  <seletama ;27_V	et	f	\N
174274	pikana	pikana =pika  (SgEs  >pikk !22_S	et	f	\N
174275	pikana	pikana =pika  (SgEs  >pikk !22_AS	et	f	\N
174293	sunnipaeva	?sunnipaeva =sunnipaeva  (SgN  >sunnipaeva !16_S	et	f	\N
174294	sunnipaeva	?sunnipaeva =sunnipaeva  (SgG  >sunnipaeva !16_S	et	f	\N
174295	sunnipaeva	?sunnipaeva =paeva  (SgN  >sunni+paeva !16_S	et	f	\N
174296	sunnipaeva	?sunnipaeva =paeva  (SgG  >sunni+paeva !16_S	et	f	\N
174318	kohela	?kohela =kohela  (SgN  >kohela !01_S	et	f	\N
174319	kohela	?kohela =kohela  (SgG  >kohela !01_S	et	f	\N
174333	poordes	poordes =poorde  (PlIn  >poord !22_S	et	f	\N
174334	poordes	poordes =poorde  (PlIn  >poort !22_S	et	f	\N
174350	grippi	grippi =grippi  (SgP  >gripp !22_S	et	f	\N
174351	grippi	grippi =grippi  (SgAdt  >gripp !22_S	et	f	\N
174361	l1qryt	### l1qryt	et	f	\N
174370	kto	### kto	et	f	\N
174374	loppevad	?loppevad =loppe  (IndPrPl3  >loppema !27_V	et	f	\N
174375	loppevad	?loppevad =loppeva  (PlN  >loppeva !01_S	et	f	\N
174376	loppevad	?loppevad =loppeva  (PlN  >loppev !02_A	et	f	\N
174386	sonu	?sonu =sonu  (SgN  >sonu !17_S	et	f	\N
174387	sonu	?sonu =sonu  (SgG  >sonu !17_S	et	f	\N
174388	sonu	?sonu =sonu  (SgP  >sonu !17_S	et	f	\N
174389	sonu	?sonu =sonu  (IndPrPs_  >sonuma !27_V	et	f	\N
174390	sonu	?sonu =sonu  (ImpPrSg2  >sonuma !27_V	et	f	\N
174424	votavad	?votavad =vota  (IndPrPl3  >votama !27_V	et	f	\N
174425	votavad	?votavad =votava  (PlN  >votava !01_S	et	f	\N
174426	votavad	?votavad =votava  (PlN  >votav !02_A	et	f	\N
174429	ulikooliopilastest	?ulikooliopilastest =ulikooliopilas  (PlEl  >ulikooliopilane !12_S	et	f	\N
174430	ulikooliopilastest	?ulikooliopilastest =ulikooliopilastes  (SgP  >ulikooliopilastene !12_A	et	f	\N
174451	mottetes	?mottetes =motte  (PlIn  >motte !06_S	et	f	\N
174452	mottetes	?mottetes =mottete  (PlIn  >mottett !22_S	et	f	\N
174460	obraid	?obraid =obrai  (PlN  >obrai !26_S	et	f	\N
174461	obraid	?obraid =obrai  (SgP  >obrai !26_S	et	f	\N
174462	obraid	?obraid =obraid  (SgN  >obraid !22_S	et	f	\N
174477	lopetatud	?lopetatud =lopeta  (PtsPtIps  >lopetama !27_V	et	f	\N
174478	lopetatud	?lopetatud =lopetatu  (PlN  >lopetatu !01_S	et	f	\N
174479	lopetatud	?lopetatud =lopetatu  (IndPrSg2  >lopetatuma !27_V	et	f	\N
174480	lopetatud	?lopetatud =lopetatud  (ID  >lopetatud !41_A	et	f	\N
174490	motteist	?motteist =motte  (PlEl  >mote !06_S	et	f	\N
174491	motteist	?motteist =mottei  (SgEl  >mottei !26_S	et	f	\N
174492	motteist	?motteist =motteist  (SgN  >motteist !22_S	et	f	\N
174535	voime	?voime =voime  (SgN  >voime !06_S	et	f	\N
174536	voime	?voime =voime  (SgG  >voime !06_S	et	f	\N
174537	voime	?voime =voime  (PlP  >voim !22_S	et	f	\N
174538	voime	?voime =voime  (IndPrPs_  >voimema !27_V	et	f	\N
174539	voime	?voime =voime  (ImpPrSg2  >voimema !27_V	et	f	\N
174540	sonauhendit	### sonauhendit	et	f	\N
174555	nel	### nel	et	f	\N
174563	sonajarievead	?sonajarievead =sonajarievea  (PlN  >sonajarievea !26_S	et	f	\N
174564	sonajarievead	?sonajarievead =sonajarievea  (SgP  >sonajarievea !26_S	et	f	\N
174565	sonajarievead	?sonajarievead =sonajarievead  (SgN  >sonajarievead !22_S	et	f	\N
174570	sonauhendis	?sonauhendis =sonauhendi  (SgIn  >sonauhent !22_S	et	f	\N
174571	sonauhendis	?sonauhendis =sonauhendi  (IndIpfSg3  >sonauhendima !28_V	et	f	\N
174572	sonauhendis	?sonauhendis =sonauhendis  (SgN  >sonauhendis !09_S	et	f	\N
174590	natalj	### natalj	et	f	\N
174591	suhhorukova	?suhhorukova =suhhorukova  (SgN  >suhhorukova !16_S	et	f	\N
174592	suhhorukova	?suhhorukova =suhhorukova  (SgG  >suhhorukov !02_A	et	f	\N
174593	suhhorukova	?suhhorukova =suhhorukova  (SgG  >suhhorukova !16_S	et	f	\N
174594	veaanaluusi	?veaanaluusi =veaanaluusi  (SgN  >veaanaluusi !16_S	et	f	\N
174595	veaanaluusi	?veaanaluusi =veaanaluusi  (SgG  >veaanaluusi !16_S	et	f	\N
174596	veaanaluusi	?veaanaluusi =veaanaluusi  (SgG  >veaanaluus !22_S	et	f	\N
174597	veaanaluusi	?veaanaluusi =veaanaluusi  (SgP  >veaanaluus !22_S	et	f	\N
174598	veaanaluusi	?veaanaluusi =veaanaluusi  (SgAdt  >veaanaluus !22_S	et	f	\N
174599	veaanaluusi	?veaanaluusi =veaanaluusi  (IndPrPs_  >veaanaluusima !28_V	et	f	\N
174600	veaanaluusi	?veaanaluusi =veaanaluusi  (ImpPrSg2  >veaanaluusima !28_V	et	f	\N
174393	zanrist	?zanrist =zanris  (SgP  >zanris !09_S	et	f	\N
174394	zanrist	?zanrist =zanrist  (SgN  >zanrist !22_S	et	f	\N
174397	ulearune	?ulearune =ulearune  (SgN  >ulearune !12_A	et	f	\N
174412	nimisonades	?nimisonades =sona  (PlIn  >nimi+sona !17_S	et	f	\N
174413	sõnalopuline	?sõnalopuline =sõnalopuline  (SgN  >sõnalopuline !12_A	et	f	\N
174414	sõnalopuline	?sõnalopuline =sõnalopuline  (PlP  >sõnalopulin !19_S	et	f	\N
174415	sõnalopuline	?sõnalopuline =lopuline  (SgN  >sõna+lopuline !12_A	et	f	\N
174416	sõnalopuline	?sõnalopuline =lopuline  (PlP  >sõna+lopulin !19_S	et	f	\N
174420	sõjavaelaseks	?sõjavaelaseks =sõjavaelase  (SgTr  >sõjavaelane !12?10_S	et	f	\N
174421	sõjavaelaseks	?sõjavaelaseks =vaelase  (SgTr  >sõja+vaelane !12?10_S	et	f	\N
174474	last-	last- =la  (SgEl  >la !26_S	et	f	\N
174475	last-	last- =las  (SgP  >laps !14_S	et	f	\N
174476	last-	last- =last  (SgN  >last !22_S	et	f	\N
174506	sobrustavad	?sobrustavad =sobrusta  (IndPrPl3  >sobrustama !27_V	et	f	\N
174507	sobrustavad	?sobrustavad =sobrustava  (PlN  >sobrustav !02_A	et	f	\N
174508	sobrustavad	?sobrustavad =sobrustava  (PlN  >sobrustava !16_S	et	f	\N
174509	piihendatud	?piihendatud =piihenda  (PtsPtIps  >piihendama !27_V	et	f	\N
174510	piihendatud	?piihendatud =piihendatu  (PlN  >piihendatu !01_S	et	f	\N
174511	piihendatud	?piihendatud =piihendatu  (IndPrSg2  >piihendatuma !27_V	et	f	\N
174512	piihendatud	?piihendatud =piihendatud  (ID  >piihendatud !41_A	et	f	\N
174516	ebaonnetu	?ebaonnetu =ebaonnetu  (SgN  >ebaonnetu !01_A	et	f	\N
174517	ebaonnetu	?ebaonnetu =ebaonnetu  (SgG  >ebaonnetu !01_A	et	f	\N
174518	ebaonnetu	?ebaonnetu =ebaonnetu  (IndPrPs_  >ebaonnetuma !27_V	et	f	\N
174519	ebaonnetu	?ebaonnetu =ebaonnetu  (ImpPrSg2  >ebaonnetuma !27_V	et	f	\N
174520	ebaonnetu	?ebaonnetu =onnetu  (SgN  >eba+onnetu !01_A	et	f	\N
174521	ebaonnetu	?ebaonnetu =onnetu  (SgG  >eba+onnetu !01_A	et	f	\N
174524	tolkelaen	?tolkelaen =tolkelaen  (SgN  >tolkelaen !19_S	et	f	\N
174532	tin	### tin	et	f	\N
174533	mused	?mused =muse  (PlN  >muse !16_S	et	f	\N
174534	mused	?mused =muse  (IndPrSg2  >musema !27_V	et	f	\N
174544	tira	?tira =tira  (SgN  >tira !17_S	et	f	\N
174545	tira	?tira =tira  (SgG  >tira !17_S	et	f	\N
174546	tira	?tira =tira  (SgP  >tira !17_S	et	f	\N
174547	tira	?tira =tira  (IndPrPs_  >tirama !27_V	et	f	\N
174548	tira	?tira =tira  (ImpPrSg2  >tirama !27_V	et	f	\N
174568	oj	### oj	et	f	\N
174587	sonavalikuvigu	?sonavalikuvigu =sonavalikuvigu  (IndPrPs_  >sonavalikuviguma !27_V	et	f	\N
174588	sonavalikuvigu	?sonavalikuvigu =sonavalikuvigu  (ImpPrSg2  >sonavalikuviguma !27_V	et	f	\N
174603	opetama	?opetama =ope  (SupIps  >opema !27_V	et	f	\N
174604	opetama	?opetama =opeta  (Sup  >opetama !27_V	et	f	\N
174605	opetama	?opetama =opetama  (SgG  >opetam !02_A	et	f	\N
174607	oppetood	?oppetood =oppetoo  (PlN  >oppetoo !26_S	et	f	\N
174608	oppetood	?oppetood =oppetoo  (SgP  >oppetoo !26_S	et	f	\N
174609	oppetood	?oppetood =oppetood  (SgN  >oppetood !22_S	et	f	\N
174617	oppis	?oppis =oppi  (IndIpfSg3  >oppima !28_V	et	f	\N
174618	oppis	?oppis =oppis  (ID  >oppis !41_DA	et	f	\N
174624	iilikooli	?iilikooli =iilikooli  (SgN  >iilikooli !16_S	et	f	\N
174625	iilikooli	?iilikooli =iilikooli  (SgG  >iilikooli !16_S	et	f	\N
174626	iilikooli	?iilikooli =iilikooli  (SgG  >iilikool !22_S	et	f	\N
174627	iilikooli	?iilikooli =iilikooli  (SgP  >iilikool !22_S	et	f	\N
174628	iilikooli	?iilikooli =iilikooli  (SgAdt  >iilikool !22_S	et	f	\N
174629	iilikooli	?iilikooli =iilikooli  (IndPrPs_  >iilikoolima !28_V	et	f	\N
174630	iilikooli	?iilikooli =iilikooli  (ImpPrSg2  >iilikoolima !28_V	et	f	\N
174653	sonul	?sonul =sonu  (SgAd  >sonu !17_S	et	f	\N
174654	sonul	?sonul =sonul  (SgN  >sonul !02_S	et	f	\N
174655	moistmisel	?moistmisel =moistmise  (SgAd  >moistmine !12?10_S	et	f	\N
174656	moistmisel	?moistmisel =moistmisel  (SgN  >moistmisel !19_S	et	f	\N
174657	jargnevatel	?jargnevatel =jargneva  (PlAd  >jargneva !01_S	et	f	\N
174658	jargnevatel	?jargnevatel =jargneva  (PlAd  >jargnev !02_A	et	f	\N
174659	jargnevatel	?jargnevatel =jargnevate  (PlAd  >jargnevatt !22_S	et	f	\N
174694	tanane	?tanane =tanane  (SgN  >tanane !10_A	et	f	\N
174695	tanane	?tanane =tanane  (IndPrPs_  >tananema !27_V	et	f	\N
174697	tanane	?tanane =tanane  (ImpPrSg2  >tananema !27_V	et	f	\N
174729	ule	?ule =ule  (SgN  >ule !16_S	et	f	\N
174730	ule	?ule =ule  (SgG  >ule !16_S	et	f	\N
174731	ule	?ule =ule  (IndPrPs_  >ulema !27_V	et	f	\N
174732	ule	?ule =ule  (ImpPrSg2  >ulema !27_V	et	f	\N
174746	rohk	?rohk =rohk  (SgN  >rohk !22_S	et	f	\N
174768	voimlast	?voimlast =voimla  (SgEl  >voimla !01_S	et	f	\N
174769	voimlast	?voimlast =voimlas  (SgP  >voimlas !07_S	et	f	\N
174770	voimlast	?voimlast =voimlas  (SgP  >voimlane !12?10_S	et	f	\N
174778	votsin	?votsin =votsi  (IndPrSg1  >votsima !28_V	et	f	\N
174780	votsin	?votsin =votsin  (SgN  >votsin !02_S	et	f	\N
174795	oudne	?oudne =oudne  (SgN  >oudne !02_A	et	f	\N
174796	oudne	?oudne =oudne  (PlP  >oudn !22_S	et	f	\N
174797	oudne	?oudne =oudne  (IndPrPs_  >oudnema !27_V	et	f	\N
174798	oudne	?oudne =oudne  (ImpPrSg2  >oudnema !27_V	et	f	\N
174799	hkaldus	?hkaldus =hkaldu  (IndIpfSg3  >hkalduma !27_V	et	f	\N
174440	kaandevormi	?kaandevormi =kaandevormi  (SgAdt  >kaandevorm !22_S	et	f	\N
174441	kaandevormi	?kaandevormi =kaandevormi  (IndPrPs_  >kaandevormima !28_V	et	f	\N
174442	kaandevormi	?kaandevormi =kaandevormi  (ImpPrSg2  >kaandevormima !28_V	et	f	\N
174444	uhildumis-	?uhildumis- =uhildumi  (SgIn  >uhildum !02_A	et	f	\N
174445	uhildumis-	?uhildumis- =uhildumis  (SgN  >uhildumis !09_S	et	f	\N
174446	kusimused	?kusimused =kusimuse  (PlN  >kusimus !11_S	et	f	\N
174447	kusimused	?kusimused =imuse  (PlN  >kus+imus !09_S	et	f	\N
174448	mangivad	?mangivad =mangi  (IndPrPl3  >mankima !28_V	et	f	\N
174449	mangivad	?mangivad =mangiva  (PlN  >mangiva !01_S	et	f	\N
174450	mangivad	?mangivad =mangiva  (PlN  >mangiv !02_A	et	f	\N
174465	soia	?soia =soia  (SgN  >soia !16_S	et	f	\N
174466	soia	?soia =soia  (SgG  >soia !16_S	et	f	\N
174467	soia	?soia =soia  (IndPrPs_  >soiama !29_V	et	f	\N
174468	soia	?soia =soia  (ImpPrSg2  >soiama !29_V	et	f	\N
174473	sunnitab	?sunnitab =sunnita  (IndPrSg3  >sunnitama !27_V	et	f	\N
174486	motteid	?motteid =motte  (PlP  >mote !06_S	et	f	\N
174487	motteid	?motteid =mottei  (PlN  >mottei !26_S	et	f	\N
174488	motteid	?motteid =mottei  (SgP  >mottei !26_S	et	f	\N
174489	motteid	?motteid =motteid  (SgN  >motteid !22_S	et	f	\N
174513	toolt	?toolt =toolt  (SgN  >toolt !22_S	et	f	\N
174530	votma	?votma =votma  (IndPrPs_  >votmama !29_V	et	f	\N
174531	votma	?votma =votma  (ImpPrSg2  >votmama !29_V	et	f	\N
174558	laheks	laheks =lahe  (SgTr  >laht !22_S	et	f	\N
174559	laheks	laheks =lahe  (PlTr  >lahk !22_S	et	f	\N
174573	konepruugis	?konepruugis =konepruugi  (SgIn  >konepruugi !16_S	et	f	\N
174574	konepruugis	?konepruugis =konepruugi  (SgIn  >konepruuk !22_S	et	f	\N
174575	konepruugis	?konepruugis =konepruugi  (IndIpfSg3  >konepruugima !28_V	et	f	\N
174576	konepruugis	?konepruugis =konepruugis  (SgN  >konepruugis !09_S	et	f	\N
174589	veaanalitijs	?veaanalitijs =veaanalitijs  (SgN  >veaanalitijs !22_S	et	f	\N
174614	kundas	?kundas =kunda  (SgIn  >kunda !16_S	et	f	\N
174615	kundas	?kundas =kunda  (IndIpfSg3  >kundama !29_V	et	f	\N
174616	kundas	?kundas =kundas  (SgN  >kundas !07_S	et	f	\N
174665	luhikesi	?luhikesi =luhikesi  (ID  >luhikesi !41_D	et	f	\N
174666	luhikesi	?luhikesi =luhikesi  (PlP  >luhike !12_S	et	f	\N
174667	luhikesi	?luhikesi =luhikesi  (PlP  >luhikene !12_S	et	f	\N
174668	sonaraamutu	?sonaraamutu =sonaraamutu  (SgN  >sonaraamutu !01_A	et	f	\N
174669	sonaraamutu	?sonaraamutu =sonaraamutu  (SgG  >sonaraamutu !01_A	et	f	\N
174670	sonaraamutu	?sonaraamutu =sonaraamutu  (IndPrPs_  >sonaraamutuma !27_V	et	f	\N
174671	sonaraamutu	?sonaraamutu =sonaraamutu  (ImpPrSg2  >sonaraamutuma !27_V	et	f	\N
174678	opetatakse	?opetatakse =opeta  (IndPrIps  >opetama !27_V	et	f	\N
174679	opetatakse	?opetatakse =opetatakse  (SgG  >opetatakne !02_A	et	f	\N
174680	opetatakse	?opetatakse =opetatakse  (PlP  >opetataks !22_S	et	f	\N
174681	raakima	?raakima =raaki  (Sup  >raakima !28_V	et	f	\N
174682	raakima	?raakima =raakima  (SgG  >raakim !02_A	et	f	\N
174698	toopaev	?toopaev =toopaev  (SgN  >toopaev !22_S	et	f	\N
174699	toopaev	?toopaev =paev  (SgN  >too+paev !22_S	et	f	\N
174701	opimotivatsioon	?opimotivatsioon =opimotivatsioon  (SgN  >opimotivatsioon !22_S	et	f	\N
174707	hadasti	?hadasti =hadasti  (ID  >hadasti !41_D	et	f	\N
174708	hadasti	?hadasti =hadasti  (IndPrPs_  >hadastima !28_V	et	f	\N
174709	hadasti	?hadasti =hadasti  (ImpPrSg2  >hadastima !28_V	et	f	\N
174718	parasiitsonu	?parasiitsonu =parasiitsonu  (SgN  >parasiitsonu !01_S	et	f	\N
174719	parasiitsonu	?parasiitsonu =parasiitsonu  (SgG  >parasiitsonu !01_S	et	f	\N
174720	parasiitsonu	?parasiitsonu =parasiitsonu  (IndPrPs_  >parasiitsonuma !27_V	et	f	\N
174721	parasiitsonu	?parasiitsonu =parasiitsonu  (ImpPrSg2  >parasiitsonuma !27_V	et	f	\N
174722	parasiitsonu	?parasiitsonu =sonu  (SgN  >para+siit+sonu !17_S	et	f	\N
174723	parasiitsonu	?parasiitsonu =sonu  (SgG  >para+siit+sonu !17_S	et	f	\N
174724	parasiitsonu	?parasiitsonu =sonu  (SgP  >para+siit+sonu !17_S	et	f	\N
174725	parasiitsonu	?parasiitsonu =iitsonu  (SgN  >paras+iitsonu !01_S	et	f	\N
174726	parasiitsonu	?parasiitsonu =iitsonu  (SgG  >paras+iitsonu !01_S	et	f	\N
174727	parasiitsonu	?parasiitsonu =siitsonu  (SgN  >para+siitsonu !01_S	et	f	\N
174728	parasiitsonu	?parasiitsonu =siitsonu  (SgG  >para+siitsonu !01_S	et	f	\N
174733	paronuumivead	?paronuumivead =paronuumivea  (PlN  >paronuumivea !26_S	et	f	\N
174734	paronuumivead	?paronuumivead =paronuumivea  (SgP  >paronuumivea !26_S	et	f	\N
174735	paronuumivead	?paronuumivead =paronuumivead  (SgN  >paronuumivead !22_S	et	f	\N
174741	jou-	?jou- =jou  (SgN  >jou !26_S	et	f	\N
174742	jou-	?jou- =jou  (SgG  >jou !26_S	et	f	\N
174756	vorru	?vorru =vorru  (SgN  >vorru !16_S	et	f	\N
174757	vorru	?vorru =vorru  (SgG  >vorru !16_S	et	f	\N
174758	vorru	?vorru =vorru  (IndPrPs_  >vorruma !27_V	et	f	\N
174759	vorru	?vorru =vorru  (ImpPrSg2  >vorruma !27_V	et	f	\N
174779	veenaiteid	?veenaiteid =veenaitei  (PlN  >veenaitei !26_S	et	f	\N
174781	veenaiteid	?veenaiteid =veenaitei  (SgP  >veenaitei !26_S	et	f	\N
174782	veenaiteid	?veenaiteid =naite  (PlP  >vee+naide !06_S	et	f	\N
174783	veenaiteid	?veenaiteid =naitei  (PlN  >vee+naitei !26_S	et	f	\N
174784	veenaiteid	?veenaiteid =naitei  (SgP  >vee+naitei !26_S	et	f	\N
174463	oudsalt	?oudsalt =oudsa  (SgAbl  >oudsa !01_S	et	f	\N
174464	oudsalt	?oudsalt =oudsalt  (ID  >oudsalt !41_D	et	f	\N
174493	katiava	?katiava =katiava  (SgN  >katiava !16_S	et	f	\N
174494	katiava	?katiava =katiava  (SgG  >katiava !16_S	et	f	\N
174495	kolaliselt	kolaliselt =kolalise  (SgAbl  >kolaline !12_A	et	f	\N
174496	kolaliselt	"kolaline %kola  )LINE_aA  <kola ;17_S	et	f	\N
174497	kolaliselt	kolaliselt =kolaliselt  (ID  >kolaliselt !41_D	et	f	\N
174498	kolaliselt	"kolaliselt %kola  )LISELT_mD  <kola ;17_S	et	f	\N
174505	soprust	?soprust =soprus  (SgP  >soprus !11~09_S	et	f	\N
174514	uhes	?uhes =uhe  (IndIpfSg3  >uhema !27_V	et	f	\N
174515	uhes	?uhes =uhes  (SgN  >uhes !09_S	et	f	\N
174522	sona-sonaline	?sona-sonaline =sonaline  (SgN  >sona-sonaline !12_A	et	f	\N
174523	sona-sonaline	?sona-sonaline =sonaline  (PlP  >sona-sonalin !19_S	et	f	\N
174541	lkbi	### lkbi	et	f	\N
174549	sonavaliku	?sonavaliku =sonavaliku  (SgG  >sonavalik !25_A	et	f	\N
174550	sonavaliku	?sonavaliku =sonavaliku  (IndPrPs_  >sonavalikuma !27_V	et	f	\N
174551	sonavaliku	?sonavaliku =sonavaliku  (ImpPrSg2  >sonavalikuma !27_V	et	f	\N
174552	sonamoodustusvead	?sonamoodustusvead =sonamoodustusvea  (PlN  >sonamoodustusvea !26_S	et	f	\N
174553	sonamoodustusvead	?sonamoodustusvead =sonamoodustusvea  (SgP  >sonamoodustusvea !26_S	et	f	\N
174554	sonamoodustusvead	?sonamoodustusvead =sonamoodustusvead  (SgN  >sonamoodustusvead !22_S	et	f	\N
174556	aialguline	?aialguline =aialguline  (SgN  >aialguline !12_A	et	f	\N
174557	aialguline	?aialguline =aialguline  (PlP  >aialgulin !19_S	et	f	\N
174566	toepoolest	toepoolest =poole  (PlEl  >toe+pool !22_S	et	f	\N
174567	toepoolest	toepoolest =pooles  (SgP  >toe+poolene !10_A	et	f	\N
174577	arvestatud-moeldud	?arvestatud-moeldud =moeldu  (PlN  >arvestatud-moeldu !01_S	et	f	\N
174578	arvestatud-moeldud	?arvestatud-moeldud =moeldu  (IndPrSg2  >arvestatud-moelduma !27_V	et	f	\N
174579	arvestatud-moeldud	?arvestatud-moeldud =moeldud  (ID  >arvestatud-moeldud !41_A	et	f	\N
174580	gumnaasiumi	?gumnaasiumi =gumnaasiumi  (SgN  >gumnaasiumi !16_S	et	f	\N
174581	gumnaasiumi	?gumnaasiumi =gumnaasiumi  (SgG  >gumnaasium !19~02_S	et	f	\N
174582	gumnaasiumi	?gumnaasiumi =gumnaasiumi  (SgG  >gumnaasiumi !16_S	et	f	\N
174583	gumnaasiumi	?gumnaasiumi =gumnaasiumi  (SgP  >gumnaasium !19_S	et	f	\N
174584	gumnaasiumi	?gumnaasiumi =gumnaasiumi  (SgAdt  >gumnaasium !19_S	et	f	\N
174585	gumnaasiumi	?gumnaasiumi =gumnaasiumi  (IndPrPs_  >gumnaasiumima !28_V	et	f	\N
174586	gumnaasiumi	?gumnaasiumi =gumnaasiumi  (ImpPrSg2  >gumnaasiumima !28_V	et	f	\N
174601	eraopilase	?eraopilase =eraopilase  (SgG  >eraopilane !12_S	et	f	\N
174602	eraopilase	?eraopilase =opilase  (SgG  >era+opilane !12_S	et	f	\N
174606	ruhmitada	?ruhmitada =ruhmita  (Inf  >ruhmitama !27_V	et	f	\N
174610	lopetades	?lopetades =lopeta  (Ger  >lopetama !27_V	et	f	\N
174611	tootas	?tootas =toota  (SgIn  >toota !16_S	et	f	\N
174612	tootas	?tootas =toota  (IndIpfSg3  >tootama !27_V	et	f	\N
174613	tootas	?tootas =tootas  (SgN  >tootas !07_S	et	f	\N
174660	labis	?labis =labi  (SgIn  >labi !17_S	et	f	\N
174661	labis	?labis =labi  (IndIpfSg3  >labima !27_V	et	f	\N
174662	labis	?labis =labis  (SgN  >labis !09_S	et	f	\N
174672	tanavu	?tanavu =tanavu  (SgN  >tanavu !01_S	et	f	\N
174673	tanavu	?tanavu =tanavu  (SgG  >tanavu !01_S	et	f	\N
174674	tanavu	?tanavu =tanavu  (IndPrPs_  >tanavuma !27_V	et	f	\N
174675	tanavu	?tanavu =tanavu  (ImpPrSg2  >tanavuma !27_V	et	f	\N
174676	siigisel	?siigisel =siigise  (SgAd  >siigis !09_S	et	f	\N
174677	siigisel	?siigisel =siigisel  (SgN  >siigisel !19_S	et	f	\N
174700	kusib	?kusib =kusi  (IndPrSg3  >kusima !27_V	et	f	\N
174714	sisekohakaanete	### sisekohakaanete	et	f	\N
174715	sidesonadest	?sidesonadest =sidesonades  (SgP  >sidesonadene !12_A	et	f	\N
174716	sidesonadest	?sidesonadest =sona  (PlEl  >side+sona !17_S	et	f	\N
174717	sidesonadest	?sidesonadest =sonades  (SgP  >side+sonadene !12_A	et	f	\N
174739	haalikuuhendid	?haalikuuhendid =haalikuuhendi  (PlN  >haalikuuhent !22_S	et	f	\N
174740	haalikuuhendid	?haalikuuhendid =haalikuuhendi  (IndPrSg2  >haalikuuhentima !28_V	et	f	\N
174748	eesmaspdeval	?eesmaspdeval =eesmaspdeva  (SgAd  >eesmaspdev !02_A	et	f	\N
174750	eesmaspdeval	?eesmaspdeval =eesmaspdeva  (SgAd  >eesmaspdeva !16_S	et	f	\N
174751	eesmaspdeval	?eesmaspdeval =eesmaspdeval  (SgN  >eesmaspdeval !19_S	et	f	\N
174752	eesmaspdeval	?eesmaspdeval =maspdeva  (SgAd  >ees+maspdeva !01_S	et	f	\N
174753	eesmaspdeval	?eesmaspdeval =maspdeva  (SgAd  >ees+maspdev !02_A	et	f	\N
174754	eesmaspdeval	?eesmaspdeval =maspdeval  (SgN  >ees+maspdeval !19_S	et	f	\N
174776	puudsin	?puudsin =puudsi  (IndPrSg1  >puudsima !28_V	et	f	\N
174777	puudsin	?puudsin =puudsin  (SgN  >puudsin !02_S	et	f	\N
174786	ndud	### ndud	et	f	\N
174787	keeraami	?keeraami =keeraami  (SgN  >keeraami !16_S	et	f	\N
174788	keeraami	?keeraami =keeraami  (SgG  >keeraami !16_S	et	f	\N
174789	keeraami	?keeraami =keeraami  (SgG  >keeraam !22_S	et	f	\N
174790	keeraami	?keeraami =keeraami  (SgP  >keeraam !22_S	et	f	\N
174791	keeraami	?keeraami =keeraami  (SgAdt  >keeraam !22_S	et	f	\N
174792	keeraami	?keeraami =keeraami  (IndPrPs_  >keeraamima !28_V	et	f	\N
174793	keeraami	?keeraami =keeraami  (ImpPrSg2  >keeraamima !28_V	et	f	\N
174828	ijot	?ijot =ijo  (SgP  >ijo !16_S	et	f	\N
174525	sonauhendi	?sonauhendi =sonauhendi  (SgG  >sonauhent !22_S	et	f	\N
174526	sonauhendi	?sonauhendi =sonauhendi  (SgP  >sonauhend !22_S	et	f	\N
174527	sonauhendi	?sonauhendi =sonauhendi  (SgAdt  >sonauhend !22_S	et	f	\N
174528	sonauhendi	?sonauhendi =sonauhendi  (IndPrPs_  >sonauhentima !28_V	et	f	\N
174529	sonauhendi	?sonauhendi =sonauhendi  (ImpPrSg2  >sonauhentima !28_V	et	f	\N
174542	tahenduses	tahenduses =tahenduse  (SgIn  >tahendus !11_S	et	f	\N
174543	tahenduses	"tahendus %tahenda  )US_vS  <tahendama ;27_V	et	f	\N
174560	molemal	?molemal =molema  (SgAd  >molem !02_A	et	f	\N
174561	molemal	?molemal =molemal  (ID  >molemal !41_D	et	f	\N
174562	nahtuse	?nahtuse =nahtuse  (SgG  >nahtus !11~09_S	et	f	\N
174569	kaandeviga	?kaandeviga =kaandevi  (SgKom  >kaandev !02_A	et	f	\N
174631	opiku	?opiku =opiku  (SgN  >opiku !01_S	et	f	\N
174632	opiku	?opiku =opiku  (SgG  >opiku !01_S	et	f	\N
174633	opiku	?opiku =opiku  (SgG  >opik !02_S	et	f	\N
174634	opiku	?opiku =opiku  (IndPrPs_  >opikuma !27_V	et	f	\N
174635	opiku	?opiku =opiku  (ImpPrSg2  >opikuma !27_V	et	f	\N
174663	tolkis	?tolkis =tolki  (IndIpfSg3  >tolkima !28_V	et	f	\N
174664	tolkis	?tolkis =tolkis  (ID  >tolkis !41_DA	et	f	\N
174688	paevade	?paevade =paeva  (PlG  >paeva !16_S	et	f	\N
174690	paevade	?paevade =vade  (SgN  >pae+vade !16_S	et	f	\N
174692	paevade	?paevade =vade  (SgG  >pae+vade !16_S	et	f	\N
174693	laks	laks =la  (SgTr  >la !26_S	et	f	\N
174696	laks	laks =laks  (SgN  >laks !22_S	et	f	\N
174702	aleksandril	?aleksandril =aleksandri  (SgAd  >aleksander !02_S	et	f	\N
174703	aleksandril	?aleksandril =aleksandril  (SgN  >aleksandril !02_S	et	f	\N
174704	aleksandril	?aleksandril =ksandri  (SgAd  >ale+ksandri !01_S	et	f	\N
174705	aleksandril	?aleksandril =ksandri  (SgAd  >ale+ksander !02_S	et	f	\N
174706	oppimise	?oppimise =oppimise  (SgG  >oppimine !12_S	et	f	\N
174710	grammatikaulesandeid	?grammatikaulesandeid =grammatikaulesandei  (PlN  >grammatikaulesandei !26_S	et	f	\N
174711	grammatikaulesandeid	?grammatikaulesandeid =grammatikaulesandei  (SgP  >grammatikaulesandei !26_S	et	f	\N
174712	grammatikaulesandeid	?grammatikaulesandeid =ulesandei  (PlN  >grammatika+ulesandei !26_S	et	f	\N
174713	grammatikaulesandeid	?grammatikaulesandeid =ulesandei  (SgP  >grammatika+ulesandei !26_S	et	f	\N
174736	haaldusvigu	?haaldusvigu =haaldusvi  (ImpPrPs  >haaldusvima !28_V	et	f	\N
174737	haaldusvigu	?haaldusvigu =haaldusvigu  (IndPrPs_  >haaldusviguma !27_V	et	f	\N
174738	haaldusvigu	?haaldusvigu =haaldusvigu  (ImpPrSg2  >haaldusviguma !27_V	et	f	\N
174755	soidame	?soidame =soida  (IndPrPl1  >soidama !29_V	et	f	\N
174760	voru	?voru =voru  (SgN  >voru !17_S	et	f	\N
174761	voru	?voru =voru  (SgG  >voru !17_S	et	f	\N
174762	voru	?voru =voru  (SgP  >voru !17_S	et	f	\N
174763	voru	?voru =voru  (IndPrPs_  >voruma !27_V	et	f	\N
174764	voru	?voru =voru  (ImpPrSg2  >voruma !27_V	et	f	\N
174767	ukskoik	?ukskoik =ukskoik  (SgN  >ukskoik !22_S	et	f	\N
174771	soime	?soime =soime  (SgN  >soime !06_S	et	f	\N
174772	soime	?soime =soime  (SgG  >soime !06_S	et	f	\N
174773	soime	?soime =soime  (PlP  >soim !22_S	et	f	\N
174774	soime	?soime =soime  (IndPrPs_  >soimema !27_V	et	f	\N
174775	soime	?soime =soime  (ImpPrSg2  >soimema !27_V	et	f	\N
174801	joudne	?joudne =joudne  (SgN  >joudne !02_A	et	f	\N
174802	joudne	?joudne =joudne  (PlP  >joudn !22_S	et	f	\N
174803	joudne	?joudne =joudne  (IndPrPs_  >joudnema !27_V	et	f	\N
174804	joudne	?joudne =joudne  (ImpPrSg2  >joudnema !27_V	et	f	\N
174825	pa	### pa	et	f	\N
174857	kainud	?kainud =kainu  (PlN  >kainu !16_S	et	f	\N
174858	kainud	?kainud =kainu  (IndPrSg2  >kainuma !28_V	et	f	\N
174859	kainud	?kainud =kainud  (ID  >kainud !41_A	et	f	\N
174874	soidus	?soidus =soidu  (SgIn  >soidu !16_S	et	f	\N
174875	soidus	?soidus =soidu  (IndIpfSg3  >soiduma !27_V	et	f	\N
174876	soidus	?soidus =soidus  (SgN  >soidus !11~09_S	et	f	\N
174877	hommikusook	?hommikusook =hommikusook  (SgN  >hommikusook !22_S	et	f	\N
174878	hommikusook	?hommikusook =sook  (SgN  >hommiku+sook !22_S	et	f	\N
174879	hommikusook	?hommikusook =usook  (SgN  >hommik+usook !22_S	et	f	\N
174885	kulastamine	?kulastamine =kulastamine  (SgN  >kulastamine !12_S	et	f	\N
174886	kulastamine	?kulastamine =kulastamine  (PlP  >kulastamin !19_S	et	f	\N
174898	helsinki	?helsinki =helsinki  (SgP  >helsink !22_S	et	f	\N
174900	helsinki	?helsinki =helsinki  (SgAdt  >helsink !22_S	et	f	\N
174916	xaaepxoe	?xaaepxoe =xaaepxoe  (SgN  >xaaepxoe !26_S	et	f	\N
174917	xaaepxoe	?xaaepxoe =xaaepxoe  (SgG  >xaaepxoe !26_S	et	f	\N
174954	uhesuguse	?uhesuguse =uhesuguse  (SgG  >uhesugus !11?09_S	et	f	\N
174962	kulastan	?kulastan =kulasta  (IndPrSg1  >kulastama !27_V	et	f	\N
174963	kulastan	?kulastan =kulastan  (SgN  >kulastan !19_S	et	f	\N
174968	bxxxtenbxbw	?bxxxtenbxbw =bxxxtenbxbw  (SgN  >bxxxtenbxbw !22_S	et	f	\N
174972	toolise	toolise =toolise  (SgG  >tooline !10_A	et	f	\N
174973	toolise	"tooline %tooli  )NE_aA  <tool ;22_S	et	f	\N
174982	pidzinkeeltele	### pidzinkeeltele	et	f	\N
174985	sisseutleva	?sisseutleva =sisseutleva  (SgN  >sisseutleva !16_S	et	f	\N
174986	sisseutleva	?sisseutleva =sisseutleva  (SgG  >sisseutlev !02_A	et	f	\N
174987	sisseutleva	?sisseutleva =sisseutleva  (SgG  >sisseutleva !16_S	et	f	\N
174619	lapsepolves	?lapsepolves =lapsepolve  (PlIn  >lapsepolv !22_S	et	f	\N
174620	lapsepolves	?lapsepolves =polve  (SgIn  >lapse+polve !06_S	et	f	\N
174621	lapsepolves	?lapsepolves =polve  (PlIn  >lapse+polv !22_S	et	f	\N
174622	lapsepolves	?lapsepolves =polves  (SgN  >lapse+polves !09_S	et	f	\N
174623	lapsepolves	?lapsepolves =epolve  (PlIn  >laps+epolv !22_S	et	f	\N
174636	opiti	?opiti =opi  (IndIpfIps  >opima !27_V	et	f	\N
174637	opiti	?opiti =opi  (IndIpfIps  >oppima !28_V	et	f	\N
174638	opiti	?opiti =opiti  (ID  >opiti !41_D	et	f	\N
174639	opiti	?opiti =opiti  (SgG  >opit !02_S	et	f	\N
174640	opiti	?opiti =opiti  (SgG  >opitt !22_S	et	f	\N
174641	opiti	?opiti =opiti  (IndPrPs_  >opittima !28_V	et	f	\N
174642	opiti	?opiti =opiti  (ImpPrSg2  >opittima !28_V	et	f	\N
174643	toopaeviti	?toopaeviti =toopaevi  (IndIpfIps  >toopaevima !28_V	et	f	\N
174644	toopaeviti	?toopaeviti =toopaeviti  (ID  >toopaeviti !41_D	et	f	\N
174645	toopaeviti	?toopaeviti =toopaeviti  (SgG  >toopaevitt !22_S	et	f	\N
174646	toopaeviti	?toopaeviti =toopaeviti  (IndPrPs_  >toopaevittima !28_V	et	f	\N
174647	toopaeviti	?toopaeviti =toopaeviti  (ImpPrSg2  >toopaevittima !28_V	et	f	\N
174648	toopaeviti	?toopaeviti =viti  (SgN  >too+pae+viti !16_S	et	f	\N
174649	toopaeviti	?toopaeviti =viti  (SgG  >too+pae+viti !16_S	et	f	\N
174650	toopaeviti	?toopaeviti =viti  (SgG  >too+pae+vitt !22_S	et	f	\N
174651	toopaeviti	?toopaeviti =paeviti  (SgG  >too+paevit !02_S	et	f	\N
174652	toopaeviti	?toopaeviti =paeviti  (SgG  >too+paevitt !22_S	et	f	\N
174683	jargnevalt	?jargnevalt =jargneva  (SgAbl  >jargneva !01_S	et	f	\N
174684	jargnevalt	?jargnevalt =jargneva  (SgAbl  >jargnev !02_A	et	f	\N
174685	jargnevalt	?jargnevalt =jargnevalt  (ID  >jargnevalt !41_D	et	f	\N
174686	moodunud	?moodunud =moodu  (PtsPtPs  >mooduma !27_V	et	f	\N
174687	moodunud	?moodunud =moodunu  (PlN  >moodunu !01_S	et	f	\N
174689	moodunud	?moodunud =moodunu  (IndPrSg2  >moodunuma !27_V	et	f	\N
174691	moodunud	?moodunud =moodunud  (ID  >moodunud !41_A	et	f	\N
174743	ou-	?ou- =ou  (SgN  >ou !26_S	et	f	\N
174744	ou-	?ou- =ou  (SgG  >ou !26_S	et	f	\N
174745	monikord	?monikord =monikord  (SgN  >monikord !22_S	et	f	\N
174747	soiduks	?soiduks =soidu  (SgTr  >soidu !16_S	et	f	\N
174749	soiduks	?soiduks =soidu  (KndPrPs  >soiduma !27_V	et	f	\N
174765	pdrast	?pdrast =pdrast  (SgN  >pdrast !22_S	et	f	\N
174766	jouan	?jouan =jouan  (SgN  >jouan !02_S	et	f	\N
174794	itkaga	?itkaga =itka  (SgKom  >itka !16_S	et	f	\N
174809	joudu	?joudu =joudu  (SgN  >joudu !16_S	et	f	\N
174810	joudu	?joudu =joudu  (SgG  >joudu !16_S	et	f	\N
174811	joudu	?joudu =joudu  (IndPrPs_  >jouduma !27_V	et	f	\N
174812	joudu	?joudu =joudu  (ImpPrSg2  >jouduma !27_V	et	f	\N
174816	oudu	?oudu =oudu  (SgN  >oudu !16_S	et	f	\N
174817	oudu	?oudu =oudu  (SgG  >oudu !16_S	et	f	\N
174818	oudu	?oudu =oudu  (IndPrPs_  >ouduma !27_V	et	f	\N
174819	oudu	?oudu =oudu  (ImpPrSg2  >ouduma !27_V	et	f	\N
174820	tooline	tooline =tooline  (SgN  >tooline !10_A	et	f	\N
174821	tooline	"tooline %tooli  )NE_aA  <tool ;22_S	et	f	\N
174831	utlesin	?utlesin =utle  (IndIpfSg1  >utlema !30_V	et	f	\N
174832	utlesin	?utlesin =utlesin  (SgN  >utlesin !19_S	et	f	\N
174833	hy	### hy	et	f	\N
174835	kanxo	?kanxo =kanxo  (SgN  >kanxo !16_S	et	f	\N
174836	kanxo	?kanxo =kanxo  (SgG  >kanxo !16_S	et	f	\N
174855	sugisel	?sugisel =sugise  (SgAd  >sugis !09_S	et	f	\N
174856	sugisel	?sugisel =sugisel  (SgN  >sugisel !19_S	et	f	\N
174865	iiot	?iiot =iiot  (SgN  >iiot !02_S	et	f	\N
174866	tolgib	?tolgib =tolgi  (IndPrSg3  >tolkima !28_V	et	f	\N
174867	uheksandani	?uheksandani =uheksanda  (SgTer  >uheksanda !16_S	et	f	\N
174868	uheksandani	?uheksandani =uheksandani  (SgG  >uheksandan !02_S	et	f	\N
174873	pdev	### pdev	et	f	\N
174880	kaheteistkumneni	?kaheteistkumneni =kaheteistkumneni  (SgG  >kaheteistkumnen !02_S	et	f	\N
174881	kaheteistkumneni	?kaheteistkumneni =kumneni  (SgG  >kahe+teist+kumnen !02_S	et	f	\N
174882	kaheteistkumneni	?kaheteistkumneni =teistkumneni  (SgG  >kahe+teistkumnen !19_S	et	f	\N
174883	kaheteistkumneni	?kaheteistkumneni =teistkumneni  (SgP  >kahe+teistkumnen !19_S	et	f	\N
174884	kaheteistkumneni	?kaheteistkumneni =teistkumneni  (SgAdt  >kahe+teistkumnen !19_S	et	f	\N
174905	r5hk	### r5hk	et	f	\N
174907	dud	### dud	et	f	\N
174918	ruhmitamine	?ruhmitamine =ruhmitamine  (SgN  >ruhmitamine !12_S	et	f	\N
174919	ruhmitamine	?ruhmitamine =ruhmitamine  (PlP  >ruhmitamin !19_S	et	f	\N
174921	haaldusvead	?haaldusvead =haaldusvea  (PlN  >haaldusvea !26_S	et	f	\N
174922	haaldusvead	?haaldusvead =haaldusvea  (SgP  >haaldusvea !26_S	et	f	\N
174924	haaldusvead	?haaldusvead =haaldusvead  (SgN  >haaldusvead !22_S	et	f	\N
174931	pohjused	?pohjused =pohjuse  (PlN  >pohjus !11~09_S	et	f	\N
174943	eesmaspaeval	?eesmaspaeval =eesmaspaeva  (SgAd  >eesmaspaeva !16_S	et	f	\N
174944	eesmaspaeval	?eesmaspaeval =eesmaspaeval  (SgN  >eesmaspaeval !02_S	et	f	\N
174945	eesmaspaeval	?eesmaspaeval =maspaeva  (SgAd  >ees+maspaeva !01_S	et	f	\N
174948	cbetnaxa	?cbetnaxa =cbetnaxa  (SgN  >cbetnaxa !01_S	et	f	\N
174949	cbetnaxa	?cbetnaxa =cbetnaxa  (SgG  >cbetnaxa !01_S	et	f	\N
174970	kaandega	### kaandega	et	f	\N
174785	veenaiteid	?veenaiteid =naiteid  (SgN  >vee+naiteid !22_S	et	f	\N
174805	loppenud	?loppenud =loppe  (PtsPtPs  >loppema !27_V	et	f	\N
174806	loppenud	?loppenud =loppenu  (PlN  >loppenu !01_S	et	f	\N
174807	loppenud	?loppenud =loppenu  (IndPrSg2  >loppenuma !27_V	et	f	\N
174808	loppenud	?loppenud =loppenud  (ID  >loppenud !41_A	et	f	\N
174813	hadldus	?hadldus =hadldu  (SgIn  >hadldu !01_S	et	f	\N
174814	hadldus	?hadldus =hadldu  (IndIpfSg3  >hadlduma !27_V	et	f	\N
174815	hadldus	?hadldus =hadldus  (SgN  >hadldus !11~09_S	et	f	\N
174822	kil	### kil	et	f	\N
174823	soidan	?soidan =soida  (IndPrSg1  >soidama !29_V	et	f	\N
174824	soidan	?soidan =soidan  (SgN  >soidan !02_S	et	f	\N
174826	ldheb	### ldheb	et	f	\N
174827	nadalat	?nadalat =nadala  (SgP  >nadala !01_S	et	f	\N
174830	naen	?naen =naen  (SgN  >naen !22_S	et	f	\N
174839	nzidagi	?nzidagi =nzida  (SgN^  >nzida !17_S	et	f	\N
174840	nzidagi	?nzidagi =nzida  (SgG^  >nzida !17_S	et	f	\N
174841	nzidagi	?nzidagi =nzida  (SgP^  >nzida !17_S	et	f	\N
174842	nzidagi	?nzidagi =nzida  (IndPrPs_^  >nzidama !27_V	et	f	\N
174843	nzidagi	?nzidagi =nzida  (ImpPrSg2^  >nzidama !27_V	et	f	\N
174871	hels	?hels =hels  (SgN  >hels !22_S	et	f	\N
174892	kuueteistkumneni	?kuueteistkumneni =kuueteistkumneni  (SgG  >kuueteistkumnen !02_S	et	f	\N
174893	kuueteistkumneni	?kuueteistkumneni =kumneni  (SgG  >kuue+teist+kumnen !02_S	et	f	\N
174894	kuueteistkumneni	?kuueteistkumneni =teistkumneni  (SgG  >kuue+teistkumnen !19_S	et	f	\N
174895	kuueteistkumneni	?kuueteistkumneni =teistkumneni  (SgP  >kuue+teistkumnen !19_S	et	f	\N
174896	kuueteistkumneni	?kuueteistkumneni =teistkumneni  (SgAdt  >kuue+teistkumnen !19_S	et	f	\N
174897	kuueteistkumneni	?kuueteistkumneni =eteistkumneni  (SgG  >kuu+eteistkumnen !02_S	et	f	\N
174899	vallumine	?vallumine =vallumine  (SgN  >vallumine !12_S	et	f	\N
174901	vallumine	?vallumine =vallumine  (PlP  >vallumin !19_S	et	f	\N
174906	psa	### psa	et	f	\N
174920	pohjuste	?pohjuste =pohjus  (PlG  >pohjus !11~09_S	et	f	\N
174935	haalikuiihendid	?haalikuiihendid =haalikuiihendi  (PlN  >haalikuiihent !22_S	et	f	\N
174936	haalikuiihendid	?haalikuiihendid =haalikuiihendi  (IndPrSg2  >haalikuiihentima !28_V	et	f	\N
174955	tadi	?tadi =tadi  (SgN  >tadi !17_S	et	f	\N
174956	tadi	?tadi =tadi  (SgG  >tadi !17_S	et	f	\N
174957	tadi	?tadi =tadi  (SgP  >tadi !17_S	et	f	\N
174958	tadi	?tadi =tadi  (IndPrPs_  >tadima !27_V	et	f	\N
174959	tadi	?tadi =tadi  (ImpPrSg2  >tadima !27_V	et	f	\N
174966	jarelikult	?jarelikult =jareliku  (SgAbl  >jarelik !25_A	et	f	\N
174967	jarelikult	?jarelikult =jarelikult  (ID  >jarelikult !41_D	et	f	\N
174971	sxxxteabxbw	?sxxxteabxbw =sxxxteabxbw  (SgN  >sxxxteabxbw !22_S	et	f	\N
174978	moelnud	?moelnud =moelnu  (PlN  >moelnu !01_S	et	f	\N
174979	moelnud	?moelnud =moelnu  (IndPrSg2  >moelnuma !27_V	et	f	\N
174980	moelnud	?moelnud =moelnud  (ID  >moelnud !41_A	et	f	\N
174981	lopetatusele	?lopetatusele =lopetatuse  (SgAll  >lopetatus !11?09_S	et	f	\N
175022	xoaktb	?xoaktb =xoaktb  (SgN  >xoaktb !22_S	et	f	\N
175057	kusis	?kusis =kusi  (IndIpfSg3  >kusima !27_V	et	f	\N
175058	kusis	?kusis =kusis  (SgN  >kusis !09_S	et	f	\N
175065	poahtenxm	?poahtenxm =poahtenxm  (SgN  >poahtenxm !22_S	et	f	\N
175079	puudsi	?puudsi =puudsi  (ID  >puudsi !41_D	et	f	\N
175080	puudsi	?puudsi =puudsi  (SgG  >puuds !22_S	et	f	\N
175081	puudsi	?puudsi =puudsi  (SgP  >puuds !22_S	et	f	\N
175082	puudsi	?puudsi =puudsi  (SgAdt  >puuds !22_S	et	f	\N
175083	puudsi	?puudsi =puudsi  (IndPrPs_  >puudsima !28_V	et	f	\N
175084	puudsi	?puudsi =puudsi  (ImpPrSg2  >puudsima !28_V	et	f	\N
175089	piiiia	?piiiia =piiiia  (SgN  >piiiia !16_S	et	f	\N
175090	piiiia	?piiiia =piiiia  (SgG  >piiiia !16_S	et	f	\N
175110	serlcbi	?serlcbi =serlcbi  (SgN  >serlcbi !01_S	et	f	\N
175111	serlcbi	?serlcbi =serlcbi  (SgG  >serlcbi !01_S	et	f	\N
175112	serlcbi	?serlcbi =serlcbi  (SgG  >serlcb !22_S	et	f	\N
175113	serlcbi	?serlcbi =serlcbi  (SgP  >serlcb !22_S	et	f	\N
175114	serlcbi	?serlcbi =serlcbi  (SgAdt  >serlcb !22_S	et	f	\N
175115	serlcbi	?serlcbi =serlcbi  (IndPrPs_  >serlcbima !28_V	et	f	\N
175116	serlcbi	?serlcbi =serlcbi  (ImpPrSg2  >serlcbima !28_V	et	f	\N
175117	kaimine	kaimine =kaimine  (SgN  >kaimine !10_A	et	f	\N
175118	kaimine	"kaimine %kaimi  )NE_aA  <kaim ;22_S	et	f	\N
175121	xpyr	### xpyr	et	f	\N
175124	vorut	?vorut =vorut  (SgN  >vorut !02_S	et	f	\N
175127	valjume	?valjume =valju  (IndPrPl1  >valjuma !27_V	et	f	\N
175147	hfert	?hfert =hfert  (SgN  >hfert !22_S	et	f	\N
175150	iildse	?iildse =iildse  (SgN  >iildse !06_S	et	f	\N
175151	iildse	?iildse =iildse  (SgG  >iildne !02_A	et	f	\N
175152	iildse	?iildse =iildse  (SgG  >iildse !06_S	et	f	\N
175153	iildse	?iildse =iildse  (PlP  >iilds !22_S	et	f	\N
175154	iildse	?iildse =iildse  (IndPrPs_  >iildsema !27_V	et	f	\N
175155	iildse	?iildse =iildse  (ImpPrSg2  >iildsema !27_V	et	f	\N
175170	etteiitlustest	?etteiitlustest =etteiitlus  (PlEl  >etteiitlus !11~09_S	et	f	\N
175171	etteiitlustest	?etteiitlustest =etteiitluste  (PlEl  >etteiitlust !22_S	et	f	\N
175172	etteiitlustest	?etteiitlustest =etteiitlustes  (SgP  >etteiitlustene !12_A	et	f	\N
175173	etteiitlustest	?etteiitlustest =iitlus  (PlEl  >ette+iitlus !11~09_S	et	f	\N
174800	hkaldus	?hkaldus =hkaldus  (SgN  >hkaldus !11~09_S	et	f	\N
174834	tax	### tax	et	f	\N
174837	hkxax	### hkxax	et	f	\N
174838	npam	### npam	et	f	\N
174860	uhugi	uhugi =uhu  (IndPrPs_^  >uhtuma !28_V	et	f	\N
174861	uhugi	uhugi =uhu  (ImpPrSg2^  >uhtuma !28_V	et	f	\N
174869	valjumine	?valjumine =valjumine  (SgN  >valjumine !12_S	et	f	\N
174870	valjumine	?valjumine =valjumine  (PlP  >valjumin !19_S	et	f	\N
174872	valiumine	?valiumine =valiumine  (SgN  >valiumine !10_A	et	f	\N
174890	uheksateist	?uheksateist =uheksatei  (SgEl  >uheksatei !26_S	et	f	\N
174891	uheksateist	?uheksateist =uheksateist  (SgN  >uheksateist !22_S	et	f	\N
174925	haaldab	?haaldab =haalda  (IndPrSg3  >haaldama !27_V	et	f	\N
174926	au-	au- =au  (SgP  >au !26_S	et	f	\N
174927	au-	au- =au  (SgN  >au !26_S	et	f	\N
174928	au-	au- =au  (SgG  >au !26_S	et	f	\N
174929	voimalikud	?voimalikud =voimaliku  (PlN  >voimalik !25_A	et	f	\N
174930	voimalikud	?voimalikud =voimaliku  (IndPrSg2  >voimalikuma !27_V	et	f	\N
174932	tottu	?tottu =tottu  (ID  >tottu !41_D	et	f	\N
174933	tottu	?tottu =tottu  (IndPrPs_  >tottuma !27_V	et	f	\N
174934	tottu	?tottu =tottu  (ImpPrSg2  >tottuma !27_V	et	f	\N
174964	luhiajaline	?luhiajaline =luhiajaline  (SgN  >luhiajaline !12_A	et	f	\N
174965	luhiajaline	?luhiajaline =luhiajaline  (PlP  >luhiajalin !19_S	et	f	\N
174991	sonadel	?sonadel =sona  (PlAd  >sona !17_S	et	f	\N
175002	kuueteistkiimneni	?kuueteistkiimneni =kuueteistkiimneni  (SgG  >kuueteistkiimnen !02_S	et	f	\N
175003	kuueteistkiimneni	?kuueteistkiimneni =kiimneni  (SgG  >kuue+teist+kiimnen !02_S	et	f	\N
175004	kuueteistkiimneni	?kuueteistkiimneni =teistkiimneni  (SgG  >kuue+teistkiimnen !19_S	et	f	\N
175005	kuueteistkiimneni	?kuueteistkiimneni =teistkiimneni  (SgP  >kuue+teistkiimnen !19_S	et	f	\N
175006	kuueteistkiimneni	?kuueteistkiimneni =teistkiimneni  (SgAdt  >kuue+teistkiimnen !19_S	et	f	\N
175007	kuueteistkiimneni	?kuueteistkiimneni =eteistkiimneni  (SgG  >kuu+eteistkiimnen !02_S	et	f	\N
175028	xoten	?xoten =xote  (IndPrSg1  >xotema !27_V	et	f	\N
175029	xoten	?xoten =xoten  (SgN  >xoten !02_S	et	f	\N
175030	cxasatb	?cxasatb =cxasatb  (SgN  >cxasatb !02_S	et	f	\N
175031	jargarvsona	?jargarvsona =jargarvso  (SgEs  >jargarvso !01_S	et	f	\N
175039	lthildumisvead	?lthildumisvead =lthildumisvea  (PlN  >lthildumisvea !26_S	et	f	\N
175040	lthildumisvead	?lthildumisvead =lthildumisvea  (SgP  >lthildumisvea !26_S	et	f	\N
175041	lthildumisvead	?lthildumisvead =lthildumisvead  (SgN  >lthildumisvead !22_S	et	f	\N
175042	taiendi	?taiendi =taiendi  (SgN  >taiendi !01_S	et	f	\N
175043	taiendi	?taiendi =taiendi  (SgG  >taiendi !01_S	et	f	\N
175044	taiendi	?taiendi =taiendi  (SgG  >taiend !02_S	et	f	\N
175045	taiendi	?taiendi =taiendi  (SgG  >taient !22_S	et	f	\N
175046	taiendi	?taiendi =taiendi  (IndPrPs_  >taientima !28_V	et	f	\N
175047	taiendi	?taiendi =taiendi  (ImpPrSg2  >taientima !28_V	et	f	\N
175048	taiendi	?taiendi =endi  (SgN  >tai+endi !16_S	et	f	\N
175049	taiendi	?taiendi =endi  (SgG  >tai+endi !16_S	et	f	\N
175050	taiendi	?taiendi =endi  (SgP  >tai+end !22_S	et	f	\N
175051	taiendi	?taiendi =endi  (SgAdt  >tai+end !22_S	et	f	\N
175054	oeldise	?oeldise =oeldise  (SgG  >oeldis !09_S	et	f	\N
175055	oeldise	?oeldise =oeldise  (IndPrPs_  >oeldisema !27_V	et	f	\N
175056	oeldise	?oeldise =oeldise  (ImpPrSg2  >oeldisema !27_V	et	f	\N
175059	bxepa	?bxepa =bxepa  (SgN  >bxepa !16_S	et	f	\N
175060	bxepa	?bxepa =bxepa  (SgG  >bxepa !16_S	et	f	\N
175061	bxepa	?bxepa =bxepa  (IndPrPs_  >bxepama !27_V	et	f	\N
175062	bxepa	?bxepa =bxepa  (ImpPrSg2  >bxepama !27_V	et	f	\N
175072	kolalise	kolalise =kolalise  (SgG  >kolaline !12_A	et	f	\N
175073	kolalise	"kolaline %kola  )LINE_aA  <kola ;17_S	et	f	\N
175088	piiiian	?piiiian =piiiian  (SgN  >piiiian !19_S	et	f	\N
175101	tolkelaenud	?tolkelaenud =tolkelaenu  (PlN  >tolkelaenu !01_S	et	f	\N
175102	tolkelaenud	?tolkelaenud =tolkelaenu  (IndPrSg2  >tolkelaenuma !27_V	et	f	\N
175103	tolkelaenud	?tolkelaenud =tolkelaenud  (ID  >tolkelaenud !41_A	et	f	\N
175104	nnhtxa	### nnhtxa	et	f	\N
175119	labime	?labime =labi  (IndPrPl1  >labima !27_V	et	f	\N
175122	homonuumia	?homonuumia =homonuumia  (SgN  >homonuumia !01_S	et	f	\N
175123	homonuumia	?homonuumia =homonuumia  (SgG  >homonuumia !01_S	et	f	\N
175125	paronuumia	?paronuumia =paronuumia  (SgN  >paronuumia !01_S	et	f	\N
175126	paronuumia	?paronuumia =paronuumia  (SgG  >paronuumia !01_S	et	f	\N
175142	xkxero	?xkxero =xkxero  (SgN  >xkxero !17~16_S	et	f	\N
175143	xkxero	?xkxero =xkxero  (SgG  >xkxero !17~16_S	et	f	\N
175144	xkxero	?xkxero =xkxero  (SgP  >xkxero !17_S	et	f	\N
175162	veaanaluus	?veaanaluus =veaanaluu  (SgIn  >veaanaluu !26_S	et	f	\N
175163	veaanaluus	?veaanaluus =veaanaluus  (SgN  >veaanaluus !22_S	et	f	\N
175179	oppisid	?oppisid =oppi  (PlP  >opp !22_S	et	f	\N
175180	oppisid	?oppisid =oppi  (IndIpfSg2  >oppima !28_V	et	f	\N
175181	oppisid	?oppisid =oppi  (IndIpfPl3  >oppima !28_V	et	f	\N
175186	oppimine	?oppimine =oppimine  (SgN  >oppimine !12_S	et	f	\N
175187	oppimine	?oppimine =oppimine  (PlP  >oppimin !19_S	et	f	\N
175201	opilasele	?opilasele =opilase  (SgAll  >opilane !12_S	et	f	\N
175205	voimalusi	?voimalusi =voimalusi  (PlP  >voimalus !11_S	et	f	\N
174829	ijot	?ijot =ijot  (SgN  >ijot !02_S	et	f	\N
174844	oulu	?oulu =oulu  (SgN  >oulu !16_S	et	f	\N
174845	oulu	?oulu =oulu  (SgG  >oulu !16_S	et	f	\N
174846	oulu	?oulu =oulu  (IndPrPs_  >ouluma !28_V	et	f	\N
174847	oulu	?oulu =oulu  (ImpPrSg2  >ouluma !28_V	et	f	\N
174848	udsi	?udsi =udsi  (SgN  >udsi !16_S	et	f	\N
174849	udsi	?udsi =udsi  (SgG  >udsi !16_S	et	f	\N
174850	udsi	?udsi =udsi  (SgG  >uds !22_S	et	f	\N
174851	udsi	?udsi =udsi  (SgP  >uds !22_S	et	f	\N
174852	udsi	?udsi =udsi  (SgAdt  >uds !22_S	et	f	\N
174853	udsi	?udsi =udsi  (IndPrPs_  >udsima !28_V	et	f	\N
174854	udsi	?udsi =udsi  (ImpPrSg2  >udsima !28_V	et	f	\N
174862	soit	?soit =soit  (SgN  >soit !22_S	et	f	\N
174863	bussiqa	?bussiqa =bussiqa  (SgN  >bussiqa !01_S	et	f	\N
174864	bussiqa	?bussiqa =bussiqa  (SgG  >bussiqa !01_S	et	f	\N
174887	kdimine	?kdimine =kdimine  (SgN  >kdimine !10_A	et	f	\N
174888	kdimine	?kdimine =kdimine  (IndPrPs_  >kdiminema !27_V	et	f	\N
174889	kdimine	?kdimine =kdimine  (ImpPrSg2  >kdiminema !27_V	et	f	\N
174902	soidaksin	?soidaksin =soida  (KndPrSg1  >soidama !29_V	et	f	\N
174903	soidaksin	?soidaksin =soidaksi  (IndPrSg1  >soidaksima !28_V	et	f	\N
174904	soidaksin	?soidaksin =soidaksin  (SgN  >soidaksin !19_S	et	f	\N
174908	lapsepolvest	?lapsepolvest =lapsepolve  (PlEl  >lapsepolv !22_S	et	f	\N
174909	lapsepolvest	?lapsepolvest =lapsepolves  (SgP  >lapsepolvene !12_A	et	f	\N
174910	lapsepolvest	?lapsepolvest =polve  (SgEl  >lapse+polve !06_S	et	f	\N
174911	lapsepolvest	?lapsepolvest =polve  (PlEl  >lapse+polv !22_S	et	f	\N
174912	lapsepolvest	?lapsepolvest =polves  (SgP  >lapse+polves !09_S	et	f	\N
174913	lapsepolvest	?lapsepolvest =polves  (SgP  >lapse+polvene !10_A	et	f	\N
174914	lapsepolvest	?lapsepolvest =epolve  (PlEl  >laps+epolv !22_S	et	f	\N
174915	lapsepolvest	?lapsepolvest =epolves  (SgP  >laps+epolvene !12_A	et	f	\N
174923	haalikuuhendite	?haalikuuhendite =haalikuuhendi  (IndPrPl2  >haalikuuhentima !28_V	et	f	\N
174937	konelejal	?konelejal =koneleja  (SgAd  >koneleja !01_S	et	f	\N
174938	konelejal	?konelejal =koneleja  (SgAd  >konelejas !02_A	et	f	\N
174939	konelejal	?konelejal =konelejal  (SgN  >konelejal !19_S	et	f	\N
174940	haalikute	?haalikute =haaliku  (PlG  >haaliku !01_S	et	f	\N
174941	haalikute	?haalikute =haaliku  (PlG  >haalik !02_S	et	f	\N
174942	haalikute	?haalikute =haaliku  (IndPrPl2  >haalikuma !27_V	et	f	\N
174946	pearohk	?pearohk =pearohk  (SgN  >pearohk !22_S	et	f	\N
174947	pearohk	?pearohk =rohk  (SgN  >pea+rohk !22_S	et	f	\N
174950	norga	?norga =norga  (SgN  >norga !16_S	et	f	\N
174951	norga	?norga =norga  (SgG  >norga !16_S	et	f	\N
174952	norga	?norga =norga  (IndPrPs_  >norgama !29_V	et	f	\N
174953	norga	?norga =norga  (ImpPrSg2  >norgama !29_V	et	f	\N
174960	pohjustas	?pohjustas =pohjusta  (SgIn  >pohjusta !01_S	et	f	\N
174961	pohjustas	?pohjustas =pohjusta  (IndIpfSg3  >pohjustama !27_V	et	f	\N
174969	bxxhtenbxbw	?bxxhtenbxbw =bxxhtenbxbw  (SgN  >bxxhtenbxbw !22_S	et	f	\N
174992	valjasoit	?valjasoit =valjasoit  (SgN  >valjasoit !22_S	et	f	\N
175023	xyaa	?xyaa =xyaa  (SgN  >xyaa !26_S	et	f	\N
175024	xyaa	?xyaa =xyaa  (SgG  >xyaa !26_S	et	f	\N
175085	puudnud	?puudnud =puudnu  (PlN  >puudnu !01_S	et	f	\N
175086	puudnud	?puudnud =puudnu  (IndPrSg2  >puudnuma !27_V	et	f	\N
175087	puudnud	?puudnud =puudnud  (ID  >puudnud !41_A	et	f	\N
175091	piiiidsin	?piiiidsin =piiiidsi  (IndPrSg1  >piiiidsima !28_V	et	f	\N
175092	piiiidsin	?piiiidsin =piiiidsin  (SgN  >piiiidsin !02_S	et	f	\N
175107	rlapom	?rlapom =rlapom  (SgN  >rlapom !02_S	et	f	\N
175108	cayxa	?cayxa =cayxa  (SgN  >cayxa !16_S	et	f	\N
175109	cayxa	?cayxa =cayxa  (SgG  >cayxa !16_S	et	f	\N
175120	rlonapxbw	?rlonapxbw =rlonapxbw  (SgN  >rlonapxbw !22_S	et	f	\N
175164	janusevskaja	?janusevskaja =janusevskaja  (SgN  >janusevskaja !01_S	et	f	\N
175165	janusevskaja	?janusevskaja =janusevskaja  (SgG  >janusevskaja !01_S	et	f	\N
175166	janusevskaja	?janusevskaja =janusevskaja  (SgG  >janusevskajas !02_A	et	f	\N
175167	kaesolevas	?kaesolevas =kaesoleva  (SgIn  >kaesolev !02_A	et	f	\N
175168	kaesolevas	?kaesolevas =kaesoleva  (SgIn  >kaesoleva !16_S	et	f	\N
175202	puhendatakse	?puhendatakse =puhenda  (IndPrIps  >puhendama !27_V	et	f	\N
175203	puhendatakse	?puhendatakse =puhendatakse  (SgG  >puhendatakne !02_A	et	f	\N
175204	puhendatakse	?puhendatakse =puhendatakse  (PlP  >puhendataks !22_S	et	f	\N
175218	analuusitakse	?analuusitakse =analuusi  (IndPrIps  >analuusima !28_V	et	f	\N
175219	analuusitakse	?analuusitakse =analuusitakse  (SgG  >analuusitakne !02_A	et	f	\N
175220	analuusitakse	?analuusitakse =analuusitakse  (PlP  >analuusitaks !22_S	et	f	\N
175255	soidukis	?soidukis =soiduki  (SgIn  >soiduki !01_S	et	f	\N
175256	soidukis	?soidukis =soiduki  (SgIn  >soiduk !02_S	et	f	\N
175258	soidukis	?soidukis =soiduki  (SgIn  >soidukk !22_S	et	f	\N
175259	soidukis	?soidukis =soidukis  (SgN  >soidukis !11_S	et	f	\N
175260	molemad	?molemad =molema  (PlN  >molem !02_A	et	f	\N
175265	uhissoiduk	### uhissoiduk	et	f	\N
175268	mpaxcnopm	?mpaxcnopm =mpaxcnopm  (SgN  >mpaxcnopm !22_S	et	f	\N
175303	lahtealuseks	?lahtealuseks =lahtealuse  (SgTr  >lahtealus !11~09_S	et	f	\N
175312	uhildatud	?uhildatud =uhilda  (PtsPtIps  >uhildama !27_V	et	f	\N
174974	bussisoidu	?bussisoidu =bussisoidu  (IndPrPs_  >bussisoiduma !27_V	et	f	\N
174975	bussisoidu	?bussisoidu =bussisoidu  (ImpPrSg2  >bussisoiduma !27_V	et	f	\N
174976	bussisoidu	?bussisoidu =soidu  (SgN  >bussi+soidu !16_S	et	f	\N
174977	bussisoidu	?bussisoidu =soidu  (SgG  >bussi+soidu !16_S	et	f	\N
174983	luhikese	?luhikese =luhikese  (SgG  >luhike !12_S	et	f	\N
174984	luhikese	?luhikese =luhikese  (SgG  >luhikene !12_S	et	f	\N
175008	uheksanda	?uheksanda =uheksanda  (SgN  >uheksanda !16_S	et	f	\N
175009	uheksanda	?uheksanda =uheksanda  (SgG  >uheksanda !16_S	et	f	\N
175010	uheksanda	?uheksanda =uheksanda  (IndPrPs_  >uheksandama !27_V	et	f	\N
175011	uheksanda	?uheksanda =uheksanda  (ImpPrSg2  >uheksandama !27_V	et	f	\N
175018	saxxmatbca	?saxxmatbca =saxxmatbca  (SgN  >saxxmatbca !01_S	et	f	\N
175019	saxxmatbca	?saxxmatbca =saxxmatbca  (SgG  >saxxmatbca !01_S	et	f	\N
175021	asbixe	### asbixe	et	f	\N
175026	bce	### bce	et	f	\N
175027	nto	### nto	et	f	\N
175052	uhildumine	?uhildumine =uhildumine  (SgN  >uhildumine !12_S	et	f	\N
175053	uhildumine	?uhildumine =uhildumine  (PlP  >uhildumin !19_S	et	f	\N
175063	3boxio	?boxio =boxio  (SgN  >boxio !01_S	et	f	\N
175064	3boxio	?boxio =boxio  (SgG  >boxio !01_S	et	f	\N
175066	mama	?mama =mama  (SgN  >mama !17_S	et	f	\N
175067	mama	?mama =mama  (SgG  >mama !17_S	et	f	\N
175069	mama	?mama =mama  (SgP  >mama !17_S	et	f	\N
175070	mama	?mama =mama  (IndPrPs_  >mamama !27_V	et	f	\N
175071	mama	?mama =mama  (ImpPrSg2  >mamama !27_V	et	f	\N
175074	tootama	?tootama =toota  (Sup  >tootama !27_V	et	f	\N
175075	tootama	?tootama =tootama  (SgG  >tootam !02_A	et	f	\N
175076	tootama	?tootama =tama  (SgN  >too+tama !17_S	et	f	\N
175077	tootama	?tootama =tama  (SgG  >too+tama !17_S	et	f	\N
175078	tootama	?tootama =tama  (SgP  >too+tama !17_S	et	f	\N
175132	piiudsin	?piiudsin =piiudsi  (IndPrSg1  >piiudsima !28_V	et	f	\N
175133	piiudsin	?piiudsin =piiudsin  (SgN  >piiudsin !19_S	et	f	\N
175145	noaenaeriib	?noaenaeriib =noaenaeriib  (SgN  >noaenaeriib !22_S	et	f	\N
175146	noaenaeriib	?noaenaeriib =enaeriib  (SgN  >noa+enaeriib !22_S	et	f	\N
175148	3to	### 3to	et	f	\N
175149	wxsxb	### wxsxb	et	f	\N
175156	iildse	?iildse =iildse  (SgN  >iildse !06_S	et	f	\N
175157	iildse	?iildse =iildse  (SgG  >iildne !02_A	et	f	\N
175158	iildse	?iildse =iildse  (SgG  >iildse !06_S	et	f	\N
175159	iildse	?iildse =iildse  (PlP  >iilds !22_S	et	f	\N
175160	iildse	?iildse =iildse  (IndPrPs_  >iildsema !27_V	et	f	\N
175161	iildse	?iildse =iildse  (ImpPrSg2  >iildsema !27_V	et	f	\N
175169	ws	### ws	et	f	\N
175175	uurimisruhma	?uurimisruhma =uurimisruhma  (SgN  >uurimisruhma !16_S	et	f	\N
175176	uurimisruhma	?uurimisruhma =uurimisruhma  (SgG  >uurimisruhma !16_S	et	f	\N
175177	uurimisruhma	?uurimisruhma =ruhma  (SgN  >uurimis+ruhma !16_S	et	f	\N
175178	uurimisruhma	?uurimisruhma =ruhma  (SgG  >uurimis+ruhma !16_S	et	f	\N
175194	nork	?nork =nork  (SgN  >nork !22_S	et	f	\N
175195	markimisvaarselt	?markimisvaarselt =markimisvaarse  (SgAbl  >markimisvaarne !02_A	et	f	\N
175196	markimisvaarselt	?markimisvaarselt =markimisvaarse  (PlAbl  >markimisvaars !22_S	et	f	\N
175197	markimisvaarselt	?markimisvaarselt =markimisvaarselt  (ID  >markimisvaarselt !41_D	et	f	\N
175221	tuupiliste	?tuupiliste =tuupilis  (PlG  >tuupilis !11_S	et	f	\N
175222	tuupiliste	?tuupiliste =tuupilis  (PlG  >tuupiline !12_A	et	f	\N
175223	tuupiliste	?tuupiliste =tuupiliste  (PlP  >tuupilist !22_S	et	f	\N
175236	luhike	?luhike =luhike  (SgN  >luhike !12_S	et	f	\N
175240	uhesugused	?uhesugused =uhesuguse  (PlN  >uhesugus !11?09_S	et	f	\N
175241	xypxocbau	?xypxocbau =xypxocbau  (SgN  >xypxocbau !26_S	et	f	\N
175242	xypxocbau	?xypxocbau =xypxocbau  (SgG  >xypxocbau !26_S	et	f	\N
175249	jdanituld	?jdanituld =jdanituld  (SgN  >jdanituld !22_S	et	f	\N
175253	tahtede	### tahtede	et	f	\N
175257	valjuma	?valjuma =valju  (Sup  >valjuma !27_V	et	f	\N
175261	otxasbibafotca	?otxasbibafotca =otxasbibafotca  (SgN  >otxasbibafotca !16_S	et	f	\N
175262	otxasbibafotca	?otxasbibafotca =otxasbibafotca  (SgG  >otxasbibafotca !16_S	et	f	\N
175264	ucm	?ucm =ucm  (SgN  >ucm !22_S	et	f	\N
175294	tuupilise	?tuupilise =tuupilise  (SgG  >tuupiline !12_A	et	f	\N
175300	kusimusel	?kusimusel =kusimuse  (SgAd  >kusimus !11_S	et	f	\N
175301	kusimusel	?kusimusel =imuse  (SgAd  >kus+imus !09_S	et	f	\N
175302	kusimusel	?kusimusel =imusel  (SgN  >kus+imusel !19_S	et	f	\N
175308	mnsiemca	?mnsiemca =mnsiemca  (SgN  >mnsiemca !01_S	et	f	\N
175309	mnsiemca	?mnsiemca =mnsiemca  (SgG  >mnsiemca !01_S	et	f	\N
175332	hrccla	### hrccla	et	f	\N
175338	iihendverbi	?iihendverbi =iihendverbi  (SgG  >iihendverp !22_S	et	f	\N
175339	iihendverbi	?iihendverbi =iihendverbi  (SgP  >iihendverb !22_S	et	f	\N
175340	iihendverbi	?iihendverbi =iihendverbi  (SgAdt  >iihendverb !22_S	et	f	\N
175341	iihendverbi	?iihendverbi =iihendverbi  (IndPrPs_  >iihendverpima !28_V	et	f	\N
175342	iihendverbi	?iihendverbi =iihendverbi  (ImpPrSg2  >iihendverpima !28_V	et	f	\N
175344	nepeeuumamb	?nepeeuumamb =nepeeuumamb  (SgN  >nepeeuumamb !22_S	et	f	\N
175346	jaetud	?jaetud =jaetu  (PlN  >jaetu !01_A	et	f	\N
175347	jaetud	?jaetud =jaetu  (IndPrSg2  >jaetuma !27_V	et	f	\N
174988	sisseutleva	?sisseutleva =utleva  (SgN  >sisse+utleva !01_S	et	f	\N
174989	sisseutleva	?sisseutleva =utleva  (SgG  >sisse+utleva !01_S	et	f	\N
174990	sisseutleva	?sisseutleva =utleva  (SgG  >sisse+utlev !02_A	et	f	\N
174993	uheteistkumnest	?uheteistkumnest =uheteistkumne  (PlEl  >uheteistkumn !22_S	et	f	\N
174994	uheteistkumnest	?uheteistkumnest =uheteistkumnes  (SgP  >uheteistkumnene !12_A	et	f	\N
174995	neljateistkumnest	?neljateistkumnest =neljateistkumne  (PlEl  >neljateistkumn !22_S	et	f	\N
174996	neljateistkumnest	?neljateistkumnest =neljateistkumnes  (SgP  >neljateistkumnene !12_A	et	f	\N
174997	neljateistkumnest	?neljateistkumnest =kumne  (PlEl  >nelja+teist+kumn !22_S	et	f	\N
174998	neljateistkumnest	?neljateistkumnest =kumnes  (SgP  >nelja+teist+kumnes !09_S	et	f	\N
174999	neljateistkumnest	?neljateistkumnest =kumnes  (SgP  >nelja+teist+kumnene !10_A	et	f	\N
175000	neljateistkumnest	?neljateistkumnest =teistkumne  (PlEl  >nelja+teistkumn !22_S	et	f	\N
175001	neljateistkumnest	?neljateistkumnest =teistkumnes  (SgP  >nelja+teistkumnene !12_A	et	f	\N
175012	kaheksandakeni	?kaheksandakeni =kaheksandakeni  (SgG  >kaheksandaken !19_S	et	f	\N
175013	kaheksandakeni	?kaheksandakeni =kaheksandakeni  (SgP  >kaheksandaken !19_S	et	f	\N
175014	kaheksandakeni	?kaheksandakeni =kaheksandakeni  (SgAdt  >kaheksandaken !19_S	et	f	\N
175015	kaheksandakeni	?kaheksandakeni =ksandakeni  (SgG  >kahe+ksandaken !19_S	et	f	\N
175016	kaheksandakeni	?kaheksandakeni =ksandakeni  (SgP  >kahe+ksandaken !19_S	et	f	\N
175017	kaheksandakeni	?kaheksandakeni =ksandakeni  (SgAdt  >kahe+ksandaken !19_S	et	f	\N
175020	3ctoxcxom	?ctoxcxom =ctoxcxom  (SgN  >ctoxcxom !02_S	et	f	\N
175025	wo	### wo	et	f	\N
175032	iiheteist	?iiheteist =iihetei  (SgEl  >iihetei !26_S	et	f	\N
175033	iiheteist	?iiheteist =iiheteist  (SgN  >iiheteist !22_S	et	f	\N
175034	kaheteistkiimneni	?kaheteistkiimneni =kaheteistkiimneni  (SgG  >kaheteistkiimnen !02_S	et	f	\N
175035	kaheteistkiimneni	?kaheteistkiimneni =kiimneni  (SgG  >kahe+teist+kiimnen !02_S	et	f	\N
175036	kaheteistkiimneni	?kaheteistkiimneni =teistkiimneni  (SgG  >kahe+teistkiimnen !19_S	et	f	\N
175037	kaheteistkiimneni	?kaheteistkiimneni =teistkiimneni  (SgP  >kahe+teistkiimnen !19_S	et	f	\N
175038	kaheteistkiimneni	?kaheteistkiimneni =teistkiimneni  (SgAdt  >kahe+teistkiimnen !19_S	et	f	\N
175068	cxpaiuhsaet	?cxpaiuhsaet =cxpaiuhsaet  (SgN  >cxpaiuhsaet !22_S	et	f	\N
175093	piiiidsi	?piiiidsi =piiiidsi  (SgG  >piiiids !22_S	et	f	\N
175094	piiiidsi	?piiiidsi =piiiidsi  (SgP  >piiiids !22_S	et	f	\N
175095	piiiidsi	?piiiidsi =piiiidsi  (SgAdt  >piiiids !22_S	et	f	\N
175096	piiiidsi	?piiiidsi =piiiidsi  (IndPrPs_  >piiiidsima !28_V	et	f	\N
175097	piiiidsi	?piiiidsi =piiiidsi  (ImpPrSg2  >piiiidsima !28_V	et	f	\N
175098	vorus	?vorus =voru  (SgIn  >voru !17_S	et	f	\N
175099	vorus	?vorus =voru  (IndIpfSg3  >voruma !27_V	et	f	\N
175100	vorus	?vorus =vorus  (SgN  >vorus !09_S	et	f	\N
175105	baxxaa	?baxxaa =baxxaa  (SgN  >baxxaa !26_S	et	f	\N
175106	baxxaa	?baxxaa =baxxaa  (SgG  >baxxaa !26_S	et	f	\N
175128	kasvoi	?kasvoi =kasvoi  (SgN  >kasvoi !26_S	et	f	\N
175129	kasvoi	?kasvoi =kasvoi  (SgG  >kasvoi !26_S	et	f	\N
175130	kasvoi	?kasvoi =voi  (SgN  >kas+voi !26_S	et	f	\N
175131	kasvoi	?kasvoi =voi  (SgG  >kas+voi !26_S	et	f	\N
175134	uht-teist	uht-teist =te  (PlEl  >uht-sa !00_P	et	f	\N
175135	uht-teist	uht-teist =teist  (SgG  >uht-teist !05_N	et	f	\N
175136	uht-teist	uht-teist =teis  (SgP  >uht-teist !05_N	et	f	\N
175137	uht-teist	uht-teist =teis  (SgP  >uht-teine !12_OP	et	f	\N
175138	uht-teist	uht-teist =teis  (SgP  >uht-teise !12_P	et	f	\N
175139	uht-teist	uht-teist =te  (PlEl  >uht-tee !26_S	et	f	\N
175140	uht-teist	uht-teist =teist  (SgN  >uht-teist !05_N	et	f	\N
175141	uht-teist	uht-teist =teist  (SgN  >uht-teist !22_S	et	f	\N
175188	oppijad	?oppijad =oppija  (PlN  >oppija !01_S	et	f	\N
175189	oppijad	?oppijad =oppija  (PlN  >oppijas !02_A	et	f	\N
175190	iisna	?iisna =iisna  (SgN  >iisna !01_S	et	f	\N
175191	iisna	?iisna =iisna  (SgG  >iisna !01_S	et	f	\N
175192	iisna	?iisna =iisna  (IndPrPs_  >iisnama !29_V	et	f	\N
175193	iisna	?iisna =iisna  (ImpPrSg2  >iisnama !29_V	et	f	\N
175198	pohilisteks	?pohilisteks =pohilis  (PlTr  >pohilis !11_S	et	f	\N
175199	pohilisteks	?pohilisteks =pohilis  (PlTr  >pohiline !12_A	et	f	\N
175200	pohilisteks	?pohilisteks =pohiliste  (PlTr  >pohilist !22_S	et	f	\N
175206	ulesandeid	?ulesandeid =ulesandei  (PlN  >ulesandei !26_S	et	f	\N
175207	ulesandeid	?ulesandeid =ulesandei  (SgP  >ulesandei !26_S	et	f	\N
175208	korgem	?korgem =korgem  (SgN  >korgem !02_A	et	f	\N
175214	ulalmainitud	?ulalmainitud =ulalmaini  (PtsPtIps  >ulalmainima !28_V	et	f	\N
175215	ulalmainitud	?ulalmainitud =ulalmainitu  (PlN  >ulalmainitu !01_A	et	f	\N
175216	ulalmainitud	?ulalmainitud =ulalmainitu  (IndPrSg2  >ulalmainituma !27_V	et	f	\N
175217	ulalmainitud	?ulalmainitud =ulalmainitud  (ID  >ulalmainitud !41_A	et	f	\N
175224	teatp	?teatp =teatp  (SgN  >teatp !22_S	et	f	\N
175225	luhikejuksed	?luhikejuksed =luhikejukse  (PlN  >luhikejukne !02_A	et	f	\N
175226	nops	?nops =nops  (SgN  >nops !22_S	et	f	\N
175227	nina-	nina- =nina  (SgN  >nina !17_S	et	f	\N
175228	nina-	nina- =nina  (SgG  >nina !17_S	et	f	\N
175229	nina-	nina- =nina  (SgP  >nina !17_S	et	f	\N
175237	haalikud	?haalikud =haaliku  (PlN  >haaliku !01_S	et	f	\N
175174	etteiitlustest	?etteiitlustest =iitlustes  (SgP  >ette+iitlustene !12_A	et	f	\N
175182	rohutada	?rohutada =rohuta  (Inf  >rohutama !27_V	et	f	\N
175183	rohutada	?rohutada =tada  (SgN  >rohu+tada !17_S	et	f	\N
175184	rohutada	?rohutada =tada  (SgG  >rohu+tada !17_S	et	f	\N
175185	rohutada	?rohutada =tada  (SgP  >rohu+tada !17_S	et	f	\N
175209	korvale	korvale =ale  (SgN  >korv+ale !16_S	et	f	\N
175210	korvale	korvale =ale  (SgG  >korv+ale !16_S	et	f	\N
175243	hoc	### hoc	et	f	\N
175254	jargmisest	?jargmisest =jargmise  (SgEl  >jargmine !12?10_A	et	f	\N
175269	soidukiv	?soidukiv =soidukiv  (SgN  >soidukiv !02_A	et	f	\N
175275	seesutlev	?seesutlev =seesutle  (PtsPrPs  >seesutlema !27_V	et	f	\N
175276	seesutlev	?seesutlev =seesutlev  (SgN  >seesutlev !02_A	et	f	\N
175277	seesutlev	?seesutlev =utlev  (SgN  >sees+utlev !02_A	et	f	\N
175278	seesutlev	?seesutlev =sutlev  (SgN  >see+sutlev !02_A	et	f	\N
175295	kusimuse	?kusimuse =kusimuse  (SgG  >kusimus !11_S	et	f	\N
175296	kusimuse	?kusimuse =imuse  (SgG  >kus+imus !09_S	et	f	\N
175317	jouluajal	?jouluajal =jouluaja  (SgAd  >jouluaja !01_S	et	f	\N
175318	jouluajal	?jouluajal =jouluaja  (SgAd  >jouluajas !02_A	et	f	\N
175319	jouluajal	?jouluajal =jouluajal  (SgN  >jouluajal !02_S	et	f	\N
175326	valjamoeldud	?valjamoeldud =valjamoeldu  (IndPrSg2  >valjamoelduma !27_V	et	f	\N
175327	valjamoeldud	?valjamoeldud =valjamoeldud  (ID  >valjamoeldud !41_A	et	f	\N
175345	uhildumisveaga	?uhildumisveaga =uhildumisvea  (SgKom  >uhildumisvea !26_S	et	f	\N
175356	mangime	?mangime =mangi  (IndPrPl1  >mankima !28_V	et	f	\N
175369	lahetyia	?lahetyia =lahetyia  (SgN  >lahetyia !16_S	et	f	\N
175370	lahetyia	?lahetyia =lahetyia  (SgG  >lahetyia !16_S	et	f	\N
175371	lahetyia	?lahetyia =tyia  (SgN  >lahe+tyia !16_S	et	f	\N
175372	lahetyia	?lahetyia =tyia  (SgG  >lahe+tyia !16_S	et	f	\N
175381	voima	?voima =voima  (SgN  >voima !16_S	et	f	\N
175382	voima	?voima =voima  (SgG  >voima !16_S	et	f	\N
175383	voima	?voima =voima  (IndPrPs_  >voimama !29_V	et	f	\N
175384	voima	?voima =voima  (ImpPrSg2  >voimama !29_V	et	f	\N
175386	ox	### ox	et	f	\N
175397	tuleoevaid	?tuleoevaid =tuleoevai  (PlN  >tuleoevai !26_S	et	f	\N
175398	tuleoevaid	?tuleoevaid =tuleoevai  (SgP  >tuleoevai !26_S	et	f	\N
175399	tuleoevaid	?tuleoevaid =oevai  (PlN  >tule+oevai !26_S	et	f	\N
175400	tuleoevaid	?tuleoevaid =oevai  (SgP  >tule+oevai !26_S	et	f	\N
175401	tuleoevaid	?tuleoevaid =oevaid  (SgN  >tule+oevaid !22_S	et	f	\N
175415	prohlecitaidcsl	### prohlecitaidcsl	et	f	\N
175425	ymo	?ymo =ymo  (SgN  >ymo !17~16_S	et	f	\N
175426	ymo	?ymo =ymo  (SgG  >ymo !17~16_S	et	f	\N
175427	ymo	?ymo =ymo  (SgP  >ymo !17_S	et	f	\N
175432	xon-ry	### xon-ry	et	f	\N
175446	vcasttr	?vcasttr =vcasttr  (SgN  >vcasttr !22_S	et	f	\N
175448	hrrv	### hrrv	et	f	\N
175450	ysxaeams	?ysxaeams =ysxaeams  (SgN  >ysxaeams !22_S	et	f	\N
175470	kolavad	kolavad =kola  (IndPrPl3  >kolama !27_V	et	f	\N
175471	kolavad	kolavad =kolava  (PlN  >kolav !02_A	et	f	\N
175472	kolavad	"kolav %kola  )V_vA  <kolama ;27_V	et	f	\N
175474	kcdcrnikrr	?kcdcrnikrr =kcdcrnikrr  (SgN  >kcdcrnikrr !22_S	et	f	\N
175481	ti	### ti	et	f	\N
175482	donmex	### donmex	et	f	\N
175487	domou	?domou =domou  (SgN  >domou !26_S	et	f	\N
175488	domou	?domou =domou  (SgG  >domou !26_S	et	f	\N
175489	deyu	### deyu	et	f	\N
175495	oppimisega	?oppimisega =oppimise  (SgKom  >oppimine !12_S	et	f	\N
175501	lmrrvitcn	?lmrrvitcn =lmrrvitcn  (SgN  >lmrrvitcn !22_S	et	f	\N
175505	tcrrgernaka	?tcrrgernaka =tcrrgernaka  (SgN  >tcrrgernaka !01_S	et	f	\N
175506	tcrrgernaka	?tcrrgernaka =tcrrgernaka  (SgG  >tcrrgernaka !01_S	et	f	\N
175507	tcrrgernaka	?tcrrgernaka =tcrrgernaka  (SgG  >tcrrgernakas !02_A	et	f	\N
175508	liiknviga	?liiknviga =liiknvi  (SgKom  >liiknvi !01_S	et	f	\N
175509	liiknviga	?liiknviga =liiknvi  (SgKom  >liiknv !22_S	et	f	\N
175510	jarjekord	?jarjekord =jarjekord  (SgN  >jarjekord !22_S	et	f	\N
175513	mo	### mo	et	f	\N
175520	rrra	### rrra	et	f	\N
175526	irrimesleks	?irrimesleks =irrimesle  (PlTr  >irrimesl !22_S	et	f	\N
175534	xam	### xam	et	f	\N
175538	6br	### 6br	et	f	\N
175540	nyuuse	?nyuuse =nyuuse  (SgN  >nyuuse !16_S	et	f	\N
175541	nyuuse	?nyuuse =nyuuse  (SgG  >nyuuse !16_S	et	f	\N
175542	nyuuse	?nyuuse =nyuuse  (PlP  >nyuus !22_S	et	f	\N
175550	tahendavad	tahendavad =tahenda  (IndPrPl3  >tahendama !27_V	et	f	\N
175551	tahendavad	tahendavad =tahendava  (PlN  >tahendav !02_A	et	f	\N
175552	tahendavad	"tahendav %tahenda  )V_vA  <tahendama ;27_V	et	f	\N
175557	traed	?traed =trae  (PlN  >trae !26_S	et	f	\N
175558	traed	?traed =trae  (SgP  >trae !26_S	et	f	\N
175559	traed	?traed =traed  (SgN  >traed !22_S	et	f	\N
175561	oaatatnatcr	### oaatatnatcr	et	f	\N
175565	krrigi	?krrigi =krrigi  (SgN  >krrigi !17_S	et	f	\N
175566	krrigi	?krrigi =krrigi  (SgG  >krrigi !17_S	et	f	\N
175567	krrigi	?krrigi =krrigi  (SgP  >krrigi !17_S	et	f	\N
175568	krrigi	?krrigi =krrigi  (IndPrPs_  >krrigima !27_V	et	f	\N
175569	krrigi	?krrigi =krrigi  (ImpPrSg2  >krrigima !27_V	et	f	\N
175211	veaanaluusiks	?veaanaluusiks =veaanaluusi  (SgTr  >veaanaluusi !16_S	et	f	\N
175212	veaanaluusiks	?veaanaluusiks =veaanaluusi  (SgTr  >veaanaluus !22_S	et	f	\N
175213	veaanaluusiks	?veaanaluusiks =veaanaluusi  (KndPrPs  >veaanaluusima !28_V	et	f	\N
175230	tahelepanematusest	?tahelepanematusest =tahelepanematuse  (SgEl  >tahelepanematus !11?09_S	et	f	\N
175231	tahelepanematusest	?tahelepanematusest =tahelepanematuses  (SgP  >tahelepanematusene !12_A	et	f	\N
175232	tahelepanematusest	?tahelepanematusest =nematuse  (SgEl  >tahe+lepa+nematus !11_S	et	f	\N
175233	tahelepanematusest	?tahelepanematusest =nematuses  (SgP  >tahe+lepa+nematusene !12_A	et	f	\N
175234	tahelepanematusest	?tahelepanematusest =lepanematuse  (SgEl  >tahe+lepanematus !11?09_S	et	f	\N
175235	tahelepanematusest	?tahelepanematusest =lepanematuses  (SgP  >tahe+lepanematusene !12_A	et	f	\N
175286	soidzcki	?soidzcki =soidzcki  (SgN  >soidzcki !01_S	et	f	\N
175287	soidzcki	?soidzcki =soidzcki  (SgG  >soidzcki !01_S	et	f	\N
175288	soidzcki	?soidzcki =soidzcki  (SgG  >soidzck !22_S	et	f	\N
175289	soidzcki	?soidzcki =soidzcki  (SgP  >soidzck !22_S	et	f	\N
175290	soidzcki	?soidzcki =soidzcki  (SgAdt  >soidzck !22_S	et	f	\N
175291	soidzcki	?soidzcki =soidzcki  (IndPrPs_  >soidzckima !28_V	et	f	\N
175292	soidzcki	?soidzcki =soidzcki  (ImpPrSg2  >soidzckima !28_V	et	f	\N
175293	soidzcki	?soidzcki =soidzc  (SgN^  >soidzc !22_S	et	f	\N
175297	lopule	?lopule =lopu  (SgAll  >lopu !16_S	et	f	\N
175298	lopule	?lopule =lopule  (IndPrPs_  >lopulema !27_V	et	f	\N
175299	lopule	?lopule =lopule  (ImpPrSg2  >lopulema !27_V	et	f	\N
175310	xem	### xem	et	f	\N
175343	pohisonaga	### pohisonaga	et	f	\N
175357	tahenduste	tahenduste =tahendus  (PlG  >tahendus !11_S	et	f	\N
175358	tahenduste	"tahendus %tahenda  )US_vS  <tahendama ;27_V	et	f	\N
175359	xodumb	?xodumb =xodumb  (SgN  >xodumb !02_S	et	f	\N
175365	lugenia	?lugenia =lugenia  (SgN  >lugenia !01_S	et	f	\N
175366	lugenia	?lugenia =lugenia  (SgG  >lugenia !01_S	et	f	\N
175367	motlesin	?motlesin =motle  (IndIpfSg1  >motlema !30_V	et	f	\N
175368	motlesin	?motlesin =motlesin  (SgN  >motlesin !19_S	et	f	\N
175375	voimeline	?voimeline =voimeline  (SgN  >voimeline !12_A	et	f	\N
175376	voimeline	?voimeline =voimeline  (PlP  >voimelin !19_S	et	f	\N
175379	voimelirieanaloogia	?voimelirieanaloogia =voimelirieanaloogia  (SgN  >voimelirieanaloogia !01_S	et	f	\N
175380	voimelirieanaloogia	?voimelirieanaloogia =voimelirieanaloogia  (SgG  >voimelirieanaloogia !01_S	et	f	\N
175388	xyda	?xyda =xyda  (SgN  >xyda !17_S	et	f	\N
175389	xyda	?xyda =xyda  (SgG  >xyda !17_S	et	f	\N
175390	xyda	?xyda =xyda  (SgP  >xyda !17_S	et	f	\N
175391	xyda	?xyda =xyda  (IndPrPs_  >xydama !27_V	et	f	\N
175392	xyda	?xyda =xyda  (ImpPrSg2  >xydama !27_V	et	f	\N
175429	c7oaicxocmu	?coaicxocmu =coaicxocmu  (IndPrPs_  >coaicxocmuma !27_V	et	f	\N
175431	c7oaicxocmu	?coaicxocmu =coaicxocmu  (ImpPrSg2  >coaicxocmuma !27_V	et	f	\N
175436	umo	?umo =umo  (SgN  >umo !17~16_S	et	f	\N
175437	umo	?umo =umo  (SgG  >umo !17~16_S	et	f	\N
175438	umo	?umo =umo  (SgP  >umo !17_S	et	f	\N
175449	uxmepecoeamc-q	### uxmepecoeamc-q	et	f	\N
175451	otsetolkena	?otsetolkena =tolke  (SgEs  >otse+tolge !06_S	et	f	\N
175453	xanonauxaen2	?xanonauxaen =xanonauxaen  (SgN  >xanonauxaen !19_S	et	f	\N
175469	maaratleda	?maaratleda =maaratle  (Inf  >maaratlema !27_V	et	f	\N
175477	pearr	?pearr =pearr  (SgN  >pearr !22_S	et	f	\N
175490	kcrks	### kcrks	et	f	\N
175493	emopou	?emopou =emopou  (SgN  >emopou !26_S	et	f	\N
175494	emopou	?emopou =emopou  (SgG  >emopou !26_S	et	f	\N
175502	oppimicega	### oppimicega	et	f	\N
175503	irrirnerae	?irrirnerae =irrirnerae  (SgN  >irrirnerae !26_S	et	f	\N
175504	irrirnerae	?irrirnerae =irrirnerae  (SgG  >irrirnerae !26_S	et	f	\N
175517	piiiicmard	?piiiicmard =piiiicmard  (SgN  >piiiicmard !22_S	et	f	\N
175519	orncxh	?orncxh =orncxh  (SgN  >orncxh !22_S	et	f	\N
175523	clt	### clt	et	f	\N
175525	iaryjernateks	?iaryjernateks =iaryjernate  (PlTr  >iaryjernatt !22_S	et	f	\N
175527	hautu	hautu =hautu  (SgN  >hautu !01_A	et	f	\N
175528	hautu	"hautu %hau  )TU1_vS  <hauduma ;28_V	et	f	\N
175529	hautu	hautu =hautu  (SgG  >hautu !01_A	et	f	\N
175530	mcuraxrrznuabre	### mcuraxrrznuabre	et	f	\N
175537	nouo2jro	?nouojro =nouojro  (SgN  >nouojro !16_S	et	f	\N
175539	nouo2jro	?nouojro =nouojro  (SgG  >nouojro !16_S	et	f	\N
175543	cmama	?cmama =cmama  (SgN  >cmama !17_S	et	f	\N
175544	cmama	?cmama =cmama  (SgG  >cmama !17_S	et	f	\N
175545	cmama	?cmama =cmama  (SgP  >cmama !17_S	et	f	\N
175546	cmama	?cmama =cmama  (IndPrPs_  >cmamama !27_V	et	f	\N
175547	cmama	?cmama =cmama  (ImpPrSg2  >cmamama !27_V	et	f	\N
175553	qmo	### qmo	et	f	\N
175555	ottrcxd	?ottrcxd =ottrcxd  (SgN  >ottrcxd !22_S	et	f	\N
175570	iitclda	?iitclda =iitclda  (SgN  >iitclda !01_S	et	f	\N
175571	iitclda	?iitclda =iitclda  (SgG  >iitclda !01_S	et	f	\N
175572	iitclda	?iitclda =iitclda  (IndPrPs_  >iitcldama !29_V	et	f	\N
175573	iitclda	?iitclda =iitclda  (ImpPrSg2  >iitcldama !29_V	et	f	\N
175584	frtteligi	?frtteligi =frtteli  (SgN^  >frtteli !17_S	et	f	\N
175586	frtteligi	?frtteligi =frtteli  (SgG^  >frtteli !17_S	et	f	\N
175588	frtteligi	?frtteligi =frtteli  (SgP^  >frtteli !17_S	et	f	\N
175238	haalikud	?haalikud =haaliku  (PlN  >haalik !02_S	et	f	\N
175239	haalikud	?haalikud =haaliku  (IndPrSg2  >haalikuma !27_V	et	f	\N
175244	jaaniool	?jaaniool =jaanioo  (SgAd  >jaanioo !26_S	et	f	\N
175245	jaaniool	?jaaniool =jaaniool  (SgN  >jaaniool !22_S	et	f	\N
175246	jaaniool	?jaaniool =ool  (SgN  >jaani+ool !22_S	et	f	\N
175247	jaaniool	?jaaniool =ioo  (SgAd  >jaan+ioo !26_S	et	f	\N
175248	jaaniool	?jaaniool =iool  (SgN  >jaan+iool !22_S	et	f	\N
175250	oppija	?oppija =oppija  (SgN  >oppija !01_S	et	f	\N
175251	oppija	?oppija =oppija  (SgG  >oppija !01_S	et	f	\N
175252	oppija	?oppija =oppija  (SgG  >oppijas !02_A	et	f	\N
175263	ot	?ot =ot  (ID  >ot !41_I	et	f	\N
175266	o6ufecmeexxbau	?oufecmeexxbau =oufecmeexxbau  (SgN  >oufecmeexxbau !26_S	et	f	\N
175267	o6ufecmeexxbau	?oufecmeexxbau =oufecmeexxbau  (SgG  >oufecmeexxbau !26_S	et	f	\N
175270	seestutlev	?seestutlev =seestutle  (PtsPrPs  >seestutlema !27_V	et	f	\N
175271	seestutlev	?seestutlev =seestutlev  (SgN  >seestutlev !02_A	et	f	\N
175272	seestutlev	?seestutlev =utlev  (SgN  >seest+utlev !02_A	et	f	\N
175273	seestutlev	?seestutlev =tutlev  (SgN  >sees+tutlev !02_A	et	f	\N
175274	seestutlev	?seestutlev =stutlev  (SgN  >see+stutlev !02_A	et	f	\N
175279	jargmises	?jargmises =jargmise  (SgIn  >jargmine !12?10_A	et	f	\N
175280	jargmises	?jargmises =jargmise  (IndIpfSg3  >jargmisema !27_V	et	f	\N
175281	peatzrses	?peatzrses =peatzrse  (SgIn  >peatzrne !02_A	et	f	\N
175282	peatzrses	?peatzrses =peatzrse  (SgIn  >peatzrse !06_S	et	f	\N
175283	peatzrses	?peatzrses =peatzrse  (PlIn  >peatzrs !22_S	et	f	\N
175284	peatzrses	?peatzrses =peatzrse  (IndIpfSg3  >peatzrsema !27_V	et	f	\N
175285	peatzrses	?peatzrses =peatzrses  (SgN  >peatzrses !09_S	et	f	\N
175304	motles	?motles =motle  (IndIpfSg3  >motlema !30_V	et	f	\N
175305	motles	?motles =motles  (SgN  >motles !09_S	et	f	\N
175306	opetajaks	?opetajaks =opetaja  (SgTr  >opetaja !01_S	et	f	\N
175307	opetajaks	?opetajaks =opetaja  (SgTr  >opetajas !02_A	et	f	\N
175311	ymumenena	### ymumenena	et	f	\N
175333	uhendverbi	?uhendverbi =uhendverbi  (SgG  >uhendverp !22_S	et	f	\N
175334	uhendverbi	?uhendverbi =uhendverbi  (SgP  >uhendverb !22_S	et	f	\N
175335	uhendverbi	?uhendverbi =uhendverbi  (SgAdt  >uhendverb !22_S	et	f	\N
175336	uhendverbi	?uhendverbi =uhendverbi  (IndPrPs_  >uhendverpima !28_V	et	f	\N
175337	uhendverbi	?uhendverbi =uhendverbi  (ImpPrSg2  >uhendverpima !28_V	et	f	\N
175349	otsetolkes	?otsetolkes =tolke  (SgIn  >otse+tolge !06_S	et	f	\N
175350	otsetolkes	?otsetolkes =tolkes  (SgN  >otse+tolkes !09_S	et	f	\N
175364	moistet	?moistet =moiste  (SgP  >moiste !06_S	et	f	\N
175373	lahema	?lahema =lahe  (Sup  >lahema !27_V	et	f	\N
175374	lahema	?lahema =lahema  (SgG  >lahem !02_A	et	f	\N
175378	sonauhendiga	?sonauhendiga =sonauhendi  (SgKom  >sonauhent !22_S	et	f	\N
175385	kaib	?kaib =kaib  (SgN  >kaib !22_S	et	f	\N
175414	ytrcxsulcjvatcst	### ytrcxsulcjvatcst	et	f	\N
175417	nowoeaem	?nowoeaem =nowoeaem  (SgN  >nowoeaem !02_S	et	f	\N
175419	dpy2	### dpy2	et	f	\N
175423	teaaeu	?teaaeu =teaaeu  (SgN  >teaaeu !26_S	et	f	\N
175424	teaaeu	?teaaeu =teaaeu  (SgG  >teaaeu !26_S	et	f	\N
175428	eo3xuxaloutue	?eoxuxaloutue =eoxuxaloutue  (SgN  >eoxuxaloutue !01_S	et	f	\N
175430	eo3xuxaloutue	?eoxuxaloutue =eoxuxaloutue  (SgG  >eoxuxaloutue !01_S	et	f	\N
175454	tcynbmype	### tcynbmype	et	f	\N
175457	o6blvastx	?oblvastx =oblvastx  (SgN  >oblvastx !22_S	et	f	\N
175479	kojrz	### kojrz	et	f	\N
175483	npuumu	?npuumu =npuumu  (SgN  >npuumu !16_S	et	f	\N
175484	npuumu	?npuumu =npuumu  (SgG  >npuumu !16_S	et	f	\N
175485	npuumu	?npuumu =npuumu  (IndPrPs_  >npuumuma !27_V	et	f	\N
175486	npuumu	?npuumu =npuumu  (ImpPrSg2  >npuumuma !27_V	et	f	\N
175496	oflrridrrgi	?oflrridrrgi =oflrridrrgi  (SgG  >oflrridrrg !02_S	et	f	\N
175497	oflrridrrgi	?oflrridrrgi =oflrridrrgi  (IndPrPs_  >oflrridrrgima !28_V	et	f	\N
175499	oflrridrrgi	?oflrridrrgi =oflrridrrgi  (ImpPrSg2  >oflrridrrgima !28_V	et	f	\N
175500	oflrridrrgi	?oflrridrrgi =oflrridrr  (SgN^  >oflrridrr !22_S	et	f	\N
175512	uxmepecxo	?uxmepecxo =uxmepecxo  (SgN  >uxmepecxo !16_S	et	f	\N
175514	uxmepecxo	?uxmepecxo =uxmepecxo  (SgG  >uxmepecxo !16_S	et	f	\N
175518	arzdcz	### arzdcz	et	f	\N
175531	yuumenr	?yuumenr =yuumenr  (SgN  >yuumenr !22_S	et	f	\N
175577	lcrkrrks	### lcrkrrks	et	f	\N
175582	rahrrlclrr	?rahrrlclrr =rahrrlclrr  (SgN  >rahrrlclrr !22_S	et	f	\N
175602	ttecd	?ttecd =ttecd  (SgN  >ttecd !22_S	et	f	\N
175605	kolaks	kolaks =kola  (SgTr  >kola !17_S	et	f	\N
175606	kolaks	kolaks =kola  (KndPrPs  >kolama !27_V	et	f	\N
175612	tip	### tip	et	f	\N
175613	sellect	?sellect =sellect  (SgN  >sellect !22_S	et	f	\N
175623	ittirarcscrta	?ittirarcscrta =ittirarcscrta  (SgN  >ittirarcscrta !16_S	et	f	\N
175624	ittirarcscrta	?ittirarcscrta =ittirarcscrta  (SgG  >ittirarcscrta !16_S	et	f	\N
175653	seilepit	?seilepit =seilepi  (SgP  >seilepi !01_S	et	f	\N
175654	seilepit	?seilepit =seilepi  (SgP  >seilep !02_S	et	f	\N
175677	scrcrte	### scrcrte	et	f	\N
175679	puuab	?puuab =puuab  (SgN  >puuab !02_S	et	f	\N
175696	eac	?eac =eac  (SgN  >eac !22_S	et	f	\N
175703	6o2amcmeo	?oamcmeo =oamcmeo  (SgN  >oamcmeo !01_S	et	f	\N
175313	uhildatud	?uhildatud =uhildatu  (PlN  >uhildatu !01_S	et	f	\N
175314	uhildatud	?uhildatud =uhildatu  (IndPrSg2  >uhildatuma !27_V	et	f	\N
175315	uhildatud	?uhildatud =uhildatud  (ID  >uhildatud !41_A	et	f	\N
175316	valjuda	?valjuda =valju  (Inf  >valjuma !27_V	et	f	\N
175320	kuunlaid	?kuunlaid =kuunla  (PlP  >kuunla !01_S	et	f	\N
175321	kuunlaid	?kuunlaid =kuunlai  (PlN  >kuunlai !26_S	et	f	\N
175322	kuunlaid	?kuunlaid =kuunlai  (SgP  >kuunlai !26_S	et	f	\N
175323	kuunlaid	?kuunlaid =kuunlaid  (SgN  >kuunlaid !22_S	et	f	\N
175324	4iiscatakse	?iiscatakse =iiscatakse  (SgG  >iiscatakne !02_A	et	f	\N
175325	4iiscatakse	?iiscatakse =iiscatakse  (PlP  >iiscataks !22_S	et	f	\N
175328	ulelugeda	### ulelugeda	et	f	\N
175329	files	?files =file  (SgIn  >file !16_S	et	f	\N
175330	files	?files =file  (IndIpfSg3  >filema !27_V	et	f	\N
175331	files	?files =files  (SgN  >files !09_S	et	f	\N
175351	ce2odxr	?ceodxr =ceodxr  (SgN  >ceodxr !22_S	et	f	\N
175352	yuexn	?yuexn =yuexn  (SgN  >yuexn !22_S	et	f	\N
175387	xodum	?xodum =xodum  (SgN  >xodum !02_A	et	f	\N
175393	uuxorty	### uuxorty	et	f	\N
175394	sisseiitlev	?sisseiitlev =sisseiitlev  (SgN  >sisseiitlev !02_A	et	f	\N
175395	sisseiitlev	?sisseiitlev =iitle  (PtsPrPs  >sisse+_iitlema !30_V	et	f	\N
175396	sisseiitlev	?sisseiitlev =iitlev  (SgN  >sisse+iitlev !02_A	et	f	\N
175402	llc	### llc	et	f	\N
175403	critaote	?critaote =critaote  (PlP  >critaot !22_S	et	f	\N
175404	tcirtcteiit	?tcirtcteiit =tcirtcteiit  (SgN  >tcirtcteiit !22_S	et	f	\N
175409	cale	?cale =cale  (SgN  >cale !16_S	et	f	\N
175411	cale	?cale =cale  (SgG  >cale !16_S	et	f	\N
175412	cale	?cale =cale  (IndPrPs_  >calema !27_V	et	f	\N
175413	cale	?cale =cale  (ImpPrSg2  >calema !27_V	et	f	\N
175418	xonry	### xonry	et	f	\N
175421	ilpeodo	?ilpeodo =ilpeodo  (SgN  >ilpeodo !16_S	et	f	\N
175422	ilpeodo	?ilpeodo =ilpeodo  (SgG  >ilpeodo !16_S	et	f	\N
175433	alaleutlev	?alaleutlev =alaleutlev  (SgN  >alaleutlev !02_A	et	f	\N
175434	alaleutlev	?alaleutlev =eutlev  (SgN  >alal+eutlev !02_A	et	f	\N
175435	alaleutlev	?alaleutlev =leutlev  (SgN  >ala+leutlev !02_A	et	f	\N
175439	mct	### mct	et	f	\N
175440	ltttttcrt	### ltttttcrt	et	f	\N
175441	nottde	?nottde =nottde  (SgN  >nottde !06_S	et	f	\N
175442	nottde	?nottde =nottde  (SgG  >nottde !06_S	et	f	\N
175443	nottde	?nottde =nottde  (PlP  >nottd !22_S	et	f	\N
175444	nottde	?nottde =nottde  (IndPrPs_  >nottdema !27_V	et	f	\N
175445	nottde	?nottde =nottde  (ImpPrSg2  >nottdema !27_V	et	f	\N
175460	xapoda	### xapoda	et	f	\N
175463	iihesugused	?iihesugused =iihesuguse  (PlN  >iihesugus !11?09_S	et	f	\N
175465	valteid	?valteid =valte  (PlP  >valde !06_S	et	f	\N
175466	valteid	?valteid =valtei  (PlN  >valtei !26_S	et	f	\N
175467	valteid	?valteid =valtei  (SgP  >valtei !26_S	et	f	\N
175468	valteid	?valteid =valteid  (SgN  >valteid !22_S	et	f	\N
175475	lia	?lia =lia  (SgN  >lia !26_S	et	f	\N
175476	lia	?lia =lia  (SgG  >lia !26_S	et	f	\N
175478	kcrheks	?kcrheks =kcrheks  (SgN  >kcrheks !22_S	et	f	\N
175498	orr	?orr =orr  (SgN  >orr !22_S	et	f	\N
175511	ouexb	?ouexb =ouexb  (SgN  >ouexb !02_S	et	f	\N
175522	pcxalt	?pcxalt =pcxalt  (SgN  >pcxalt !22_S	et	f	\N
175532	cmaparomcr	### cmaparomcr	et	f	\N
175535	ace	?ace =ace  (SgN  >ace !06_S	et	f	\N
175536	ace	?ace =ace  (SgG  >ace !06_S	et	f	\N
175548	ymxee	?ymxee =ymxee  (SgN  >ymxee !26_S	et	f	\N
175549	ymxee	?ymxee =ymxee  (SgG  >ymxee !26_S	et	f	\N
175554	ncrgu	### ncrgu	et	f	\N
175560	trtt	### trtt	et	f	\N
175562	tneeldib	?tneeldib =tneeldi  (IndPrSg3  >tneeltima !28_V	et	f	\N
175564	oppiratitte	?oppiratitte =oppiratitte  (PlP  >oppiratitt !22_S	et	f	\N
175580	rtmrlle	### rtmrlle	et	f	\N
175592	krri	### krri	et	f	\N
175596	iileccrrtdeid	?iileccrrtdeid =iileccrrtde  (PlP  >iileccrrtdi !01_S	et	f	\N
175597	iileccrrtdeid	?iileccrrtdeid =iileccrrtde  (PlP  >iileccrrtd !02_S	et	f	\N
175598	iileccrrtdeid	?iileccrrtdeid =iileccrrtdei  (PlN  >iileccrrtdei !26_S	et	f	\N
175600	iileccrrtdeid	?iileccrrtdeid =iileccrrtdei  (SgP  >iileccrrtdei !26_S	et	f	\N
175610	airlida	?airlida =airli  (Inf  >airlima !28_V	et	f	\N
175620	trrttdcr	### trrttdcr	et	f	\N
175638	guxumenbubau	?guxumenbubau =guxumenbubau  (SgN  >guxumenbubau !26_S	et	f	\N
175639	guxumenbubau	?guxumenbubau =guxumenbubau  (SgG  >guxumenbubau !26_S	et	f	\N
175650	otncx	?otncx =otncx  (SgN  >otncx !22_S	et	f	\N
175651	ajcrlry7rr	?ajcrlryrr =ajcrlryrr  (SgN  >ajcrlryrr !22_S	et	f	\N
175655	cxst	### cxst	et	f	\N
175659	rtertdegr	?rtertdegr =rtertdegr  (SgN  >rtertdegr !22_S	et	f	\N
175661	kottthed	?kottthed =kottthe  (PlN  >kottthe !06_S	et	f	\N
175662	kottthed	?kottthed =kottthe  (IndPrSg2  >kottthema !27_V	et	f	\N
175664	umeem	?umeem =umeem  (SgN  >umeem !22_S	et	f	\N
175665	ceoto	?ceoto =ceoto  (SgN  >ceoto !16_S	et	f	\N
175666	ceoto	?ceoto =ceoto  (SgG  >ceoto !16_S	et	f	\N
175667	traditsioortid	### traditsioortid	et	f	\N
175672	eestlcrsecl	?eestlcrsecl =eestlcrsecl  (SgN  >eestlcrsecl !22_S	et	f	\N
175348	jaetud	?jaetud =jaetud  (ID  >jaetud !41_A	et	f	\N
175353	ucecmb	?ucecmb =ucecmb  (SgN  >ucecmb !02_S	et	f	\N
175354	ypokoe	?ypokoe =ypokoe  (SgN  >ypokoe !26_S	et	f	\N
175355	ypokoe	?ypokoe =ypokoe  (SgG  >ypokoe !26_S	et	f	\N
175360	uomu	?uomu =uomu  (SgN  >uomu !16_S	et	f	\N
175361	uomu	?uomu =uomu  (SgG  >uomu !16_S	et	f	\N
175362	uomu	?uomu =uomu  (IndPrPs_  >uomuma !27_V	et	f	\N
175363	uomu	?uomu =uomu  (ImpPrSg2  >uomuma !27_V	et	f	\N
175377	rakkida	?rakkida =rakki  (Inf  >rakkima !28_V	et	f	\N
175405	rtittscrcxme	?rtittscrcxme =rtittscrcxme  (SgN  >rtittscrcxme !06_S	et	f	\N
175406	rtittscrcxme	?rtittscrcxme =rtittscrcxme  (SgG  >rtittscrcxme !06_S	et	f	\N
175407	rtittscrcxme	?rtittscrcxme =rtittscrcxme  (PlP  >rtittscrcxm !22_S	et	f	\N
175408	rtittscrcxme	?rtittscrcxme =rtittscrcxme  (IndPrPs_  >rtittscrcxmema !27_V	et	f	\N
175410	rtittscrcxme	?rtittscrcxme =rtittscrcxme  (ImpPrSg2  >rtittscrcxmema !27_V	et	f	\N
175416	mar	### mar	et	f	\N
175420	dpyzy	### dpyzy	et	f	\N
175447	stnrt	### stnrt	et	f	\N
175452	sdecb	?sdecb =sdecb  (SgN  >sdecb !22_S	et	f	\N
175455	ucmopuu	?ucmopuu =ucmopuu  (SgN  >ucmopuu !26_S	et	f	\N
175456	ucmopuu	?ucmopuu =ucmopuu  (SgG  >ucmopuu !26_S	et	f	\N
175458	scmoxcxo2o	?scmoxcxoo =scmoxcxoo  (SgN  >scmoxcxoo !26_S	et	f	\N
175459	scmoxcxo2o	?scmoxcxoo =scmoxcxoo  (SgG  >scmoxcxoo !26_S	et	f	\N
175461	liihikeste	?liihikeste =liihikes  (PlG  >liihike !12_S	et	f	\N
175462	liihikeste	?liihikeste =liihikes  (PlG  >liihikene !12_S	et	f	\N
175464	ci	### ci	et	f	\N
175473	i3rit	?irit =irit  (SgN  >irit !02_S	et	f	\N
175480	jrrrdrna	### jrrrdrna	et	f	\N
175491	dea	?dea =dea  (SgN  >dea !26_S	et	f	\N
175492	dea	?dea =dea  (SgG  >dea !26_S	et	f	\N
175515	opetajad	?opetajad =opetaja  (PlN  >opetaja !01_S	et	f	\N
175516	opetajad	?opetajad =opetaja  (PlN  >opetajas !02_A	et	f	\N
175521	sacrfcirrre	?sacrfcirrre =sacrfcirrre  (PlP  >sacrfcirrr !22_S	et	f	\N
175524	pcxrinrcztcksjcx	?pcxrinrcztcksjcx =pcxrinrcztcksjcx  (SgN  >pcxrinrcztcksjcx !22_S	et	f	\N
175533	damb	?damb =damb  (SgN  >damb !22_S	et	f	\N
175556	rcxsh	### rcxsh	et	f	\N
175563	ntrrlle	### ntrrlle	et	f	\N
175587	rtii	?rtii =rtii  (SgN  >rtii !26_S	et	f	\N
175589	rtii	?rtii =rtii  (SgG  >rtii !26_S	et	f	\N
175595	zcrljrr	### zcrljrr	et	f	\N
175599	voltwcl	?voltwcl =voltwcl  (SgN  >voltwcl !22_S	et	f	\N
175607	irleks	?irleks =irle  (SgTr  >irle !06_S	et	f	\N
175608	irleks	?irleks =irle  (PlTr  >irl !22_S	et	f	\N
175609	irleks	?irleks =irle  (KndPrPs  >irlema !30_V	et	f	\N
175619	eadr	?eadr =eadr  (SgN  >eadr !22_S	et	f	\N
175629	vajd	?vajd =vajd  (SgN  >vajd !22_S	et	f	\N
175637	toocp	?toocp =toocp  (SgN  >toocp !22_S	et	f	\N
175668	sunonuumid	?sunonuumid =sunonuumi  (PlN  >sunonuumi !16_S	et	f	\N
175669	sunonuumid	?sunonuumid =sunonuumi  (PlN  >sunonuum !22_S	et	f	\N
175670	sunonuumid	?sunonuumid =sunonuumi  (IndPrSg2  >sunonuumima !28_V	et	f	\N
175681	eute	?eute =eute  (SgN  >eute !06_S	et	f	\N
175682	eute	?eute =eute  (SgG  >eude !06_S	et	f	\N
175683	eute	?eute =eute  (PlP  >eut !22_S	et	f	\N
175684	eute	?eute =eute  (IndPrPs_  >eutema !27_V	et	f	\N
175685	eute	?eute =eute  (ImpPrSg2  >eutema !27_V	et	f	\N
175689	ecnu	?ecnu =ecnu  (SgN  >ecnu !16_S	et	f	\N
175691	ecnu	?ecnu =ecnu  (SgG  >ecnu !16_S	et	f	\N
175692	ecnu	?ecnu =ecnu  (IndPrPs_  >ecnuma !27_V	et	f	\N
175693	ecnu	?ecnu =ecnu  (ImpPrSg2  >ecnuma !27_V	et	f	\N
175698	y3xm	?yxm =yxm  (SgN  >yxm !22_S	et	f	\N
175711	mooda	?mooda =mooda  (SgN  >mooda !16_S	et	f	\N
175713	mooda	?mooda =mooda  (SgG  >mooda !16_S	et	f	\N
175714	mooda	?mooda =mooda  (IndPrPs_  >moodama !29_V	et	f	\N
175715	mooda	?mooda =mooda  (ImpPrSg2  >moodama !29_V	et	f	\N
175742	ttirtg	?ttirtg =ttirtg  (SgN  >ttirtg !22_S	et	f	\N
175757	mumo	?mumo =mumo  (SgN  >mumo !17~16_S	et	f	\N
175758	mumo	?mumo =mumo  (SgG  >mumo !17~16_S	et	f	\N
175759	mumo	?mumo =mumo  (SgP  >mumo !17_S	et	f	\N
175762	puksid	puksid =puksi  (PlN  >puks !22_S	et	f	\N
175763	puksid	puksid =puksi  (IndPrSg2  >puksima !28_V	et	f	\N
175769	raakides	?raakides =raaki  (PlIn  >raak !22_S	et	f	\N
175770	raakides	?raakides =raaki  (Ger  >raakima !28_V	et	f	\N
175771	markida	?markida =marki  (Inf  >markima !28_V	et	f	\N
175778	jaglal	?jaglal =jagla  (SgAd  >jagla !16_S	et	f	\N
175779	jaglal	?jaglal =jaglal  (SgN  >jaglal !02_S	et	f	\N
175800	rtaeiejcroks	?rtaeiejcroks =rtaeiejcro  (SgTr  >rtaeiejcro !01_S	et	f	\N
175818	tcihtsrrselrr	?tcihtsrrselrr =tcihtsrrselrr  (SgN  >tcihtsrrselrr !22_S	et	f	\N
175830	voorkeele	?voorkeele =voorkee  (SgAll  >voorkee !26_S	et	f	\N
175831	voorkeele	?voorkeele =voorkeele  (SgN  >voorkeele !16_S	et	f	\N
175832	voorkeele	?voorkeele =voorkeele  (SgG  >voorkeele !16_S	et	f	\N
175833	voorkeele	?voorkeele =voorkeele  (PlP  >voorkeel !22_S	et	f	\N
175834	voorkeele	?voorkeele =voorkeele  (IndPrPs_  >voorkeelema !27_V	et	f	\N
175835	voorkeele	?voorkeele =voorkeele  (ImpPrSg2  >voorkeelema !27_V	et	f	\N
175855	valiskohakaanded	### valiskohakaanded	et	f	\N
175574	cxlati	?cxlati =cxlati  (SgN  >cxlati !16_S	et	f	\N
175575	cxlati	?cxlati =cxlati  (SgG  >cxlati !16_S	et	f	\N
175576	cxlati	?cxlati =cxlati  (SgG  >cxlatt !22_S	et	f	\N
175578	cxlati	?cxlati =cxlati  (IndPrPs_  >cxlatima !27_V	et	f	\N
175579	cxlati	?cxlati =cxlati  (IndPrPs_  >cxlattima !28_V	et	f	\N
175581	cxlati	?cxlati =cxlati  (ImpPrSg2  >cxlatima !27_V	et	f	\N
175583	cxlati	?cxlati =cxlati  (ImpPrSg2  >cxlattima !28_V	et	f	\N
175585	otz	### otz	et	f	\N
175593	rtnrllc	### rtnrllc	et	f	\N
175601	kccrulisi	?kccrulisi =kccrulisi  (ID  >kccrulisi !41_D	et	f	\N
175614	acrks	?acrks =acrks  (SgN  >acrks !22_S	et	f	\N
175625	lahtuvalt	lahtuvalt =lahtuva  (SgAbl  >lahtuv !02_A	et	f	\N
175626	lahtuvalt	"lahtuv %lahtu  )V_vA  <lahtuma ;27_V	et	f	\N
175627	lahtuvalt	lahtuvalt =lahtuvalt  (ID  >lahtuvalt !41_D	et	f	\N
175628	lahtuvalt	"lahtuvalt %lahtu  )VALT_mD  <lahtuma ;27_V	et	f	\N
175630	sunonuumi	?sunonuumi =sunonuumi  (SgN  >sunonuumi !16_S	et	f	\N
175631	sunonuumi	?sunonuumi =sunonuumi  (SgG  >sunonuumi !16_S	et	f	\N
175632	sunonuumi	?sunonuumi =sunonuumi  (SgG  >sunonuum !22_S	et	f	\N
175633	sunonuumi	?sunonuumi =sunonuumi  (SgP  >sunonuum !22_S	et	f	\N
175634	sunonuumi	?sunonuumi =sunonuumi  (SgAdt  >sunonuum !22_S	et	f	\N
175635	sunonuumi	?sunonuumi =sunonuumi  (IndPrPs_  >sunonuumima !28_V	et	f	\N
175636	sunonuumi	?sunonuumi =sunonuumi  (ImpPrSg2  >sunonuumima !28_V	et	f	\N
175640	kaandele	?kaandele =kaande  (PlAll  >kaant !22_S	et	f	\N
175641	kaandele	?kaandele =kaandele  (IndPrPs_  >kaandelema !31~27_V	et	f	\N
175642	kaandele	?kaandele =kaandele  (ImpPrSg2  >kaandelema !31~27_V	et	f	\N
175643	koigil	?koigil =koigi  (SgAd  >koigi !16_S	et	f	\N
175644	koigil	?koigil =koigi  (SgAd  >koik !22_S	et	f	\N
175645	rahocxi	?rahocxi =rahocxi  (SgN  >rahocxi !01_S	et	f	\N
175646	rahocxi	?rahocxi =rahocxi  (SgG  >rahocxi !01_S	et	f	\N
175647	rahocxi	?rahocxi =rahocxi  (SgG  >rahocx !22_S	et	f	\N
175648	rahocxi	?rahocxi =rahocxi  (SgP  >rahocx !22_S	et	f	\N
175649	rahocxi	?rahocxi =rahocxi  (SgAdt  >rahocx !22_S	et	f	\N
175658	rting	?rting =rting  (SgN  >rting !22_S	et	f	\N
175660	secotrrd	?secotrrd =secotrrd  (SgN  >secotrrd !02_S	et	f	\N
175663	tuvega	?tuvega =tuve  (SgKom  >tuve !16_S	et	f	\N
175671	r-cicygizw1	?r-cicygizw =cicygizw  (SgN  >r-cicygizw !22_S	et	f	\N
175674	trrnta	### trrnta	et	f	\N
175687	limo	?limo =limo  (SgN  >limo !17~16_S	et	f	\N
175688	limo	?limo =limo  (SgG  >limo !17~16_S	et	f	\N
175690	limo	?limo =limo  (SgP  >limo !17_S	et	f	\N
175708	soitsid	?soitsid =soit  (IndIpfSg2  >soitma !34_V	et	f	\N
175709	soitsid	?soitsid =soit  (IndIpfPl3  >soitma !34_V	et	f	\N
175710	soitsid	?soitsid =soitsi  (PlN  >soits !22_S	et	f	\N
175712	soitsid	?soitsid =soitsi  (IndPrSg2  >soitsima !28_V	et	f	\N
175731	ttcrgrr	### ttcrgrr	et	f	\N
175733	sitcid	?sitcid =sitci  (PlN  >sitci !16_S	et	f	\N
175734	sitcid	?sitcid =sitci  (PlN  >sitc !22_S	et	f	\N
175746	sellepcrrcrst	?sellepcrrcrst =sellepcrrcrst  (SgN  >sellepcrrcrst !22_S	et	f	\N
175749	aemxbau	?aemxbau =aemxbau  (SgN  >aemxbau !26_S	et	f	\N
175750	aemxbau	?aemxbau =aemxbau  (SgG  >aemxbau !26_S	et	f	\N
175780	moiste	?moiste =moiste  (SgN  >moiste !06_S	et	f	\N
175781	moiste	?moiste =moiste  (SgG  >moiste !06_S	et	f	\N
175782	moiste	?moiste =moiste  (PlP  >moist !22_S	et	f	\N
175783	moiste	?moiste =moiste  (IndPrPs_  >moistema !27_V	et	f	\N
175784	moiste	?moiste =moiste  (ImpPrSg2  >moistema !27_V	et	f	\N
175791	toocletrrd	?toocletrrd =toocletrrd  (SgN  >toocletrrd !02_S	et	f	\N
175792	toocletrrd	?toocletrrd =cletrrd  (SgN  >too+cletrrd !22_S	et	f	\N
175809	tekkiiehrsel	?tekkiiehrsel =tekkiiehrse  (SgAd  >tekkiiehrne !02_A	et	f	\N
175810	tekkiiehrsel	?tekkiiehrsel =tekkiiehrsel  (SgN  >tekkiiehrsel !02_S	et	f	\N
175811	firmtra	?firmtra =firmtra  (SgN  >firmtra !01_S	et	f	\N
175812	firmtra	?firmtra =firmtra  (SgG  >firmtra !01_S	et	f	\N
175813	firmtra	?firmtra =firmtra  (IndPrPs_  >firmtrama !29_V	et	f	\N
175814	firmtra	?firmtra =firmtra  (ImpPrSg2  >firmtrama !29_V	et	f	\N
175819	osr	?osr =osr  (SgN  >osr !22_S	et	f	\N
175820	etteutlusest	?etteutlusest =etteutluse  (SgEl  >etteutlus !11_S	et	f	\N
175821	etteutlusest	?etteutlusest =etteutluses  (SgP  >etteutlusene !12_A	et	f	\N
175822	etteutlusest	?etteutlusest =utluse  (SgEl  >ette+utlus !11~09_S	et	f	\N
175823	etteutlusest	?etteutlusest =utluses  (SgP  >ette+utlusene !12_A	et	f	\N
175824	kaesolev	?kaesolev =kaesole  (PtsPrPs  >kaesolema !27_V	et	f	\N
175825	kaesolev	?kaesolev =kaesolev  (SgN  >kaesolev !02_A	et	f	\N
175836	voorkeelt	?voorkeelt =voorkee  (SgAbl  >voorkee !26_S	et	f	\N
175837	voorkeelt	?voorkeelt =voorkeelt  (ID  >voorkeelt !41_D	et	f	\N
175842	tiiiipilised	?tiiiipilised =tiiiipilise  (PlN  >tiiiipiline !12_A	et	f	\N
175844	riga	?riga =riga  (SgN  >riga !17_S	et	f	\N
175845	riga	?riga =riga  (SgG  >riga !17_S	et	f	\N
175846	riga	?riga =riga  (SgP  >riga !17_S	et	f	\N
175847	riga	?riga =riga  (IndPrPs_  >rigama !27_V	et	f	\N
175848	riga	?riga =riga  (ImpPrSg2  >rigama !27_V	et	f	\N
175888	i-ülivorre	?i-ülivorre =ülivorre  (PlP  >i-ülivorr !22_S	et	f	\N
175590	frtteligi	?frtteligi =frtteli  (IndPrPs_^  >frttelima !27_V	et	f	\N
175591	frtteligi	?frtteligi =frtteli  (ImpPrSg2^  >frttelima !27_V	et	f	\N
175594	cxrttcrkse	### cxrttcrkse	et	f	\N
175603	dsiladi	?dsiladi =dsiladi  (SgN  >dsiladi !01_S	et	f	\N
175604	dsiladi	?dsiladi =dsiladi  (SgG  >dsiladi !01_S	et	f	\N
175611	sellirte	?sellirte =sellirte  (PlP  >sellirt !22_S	et	f	\N
175615	tr7icla	?tricla =tricla  (SgN  >tricla !16_S	et	f	\N
175616	tr7icla	?tricla =tricla  (SgG  >tricla !16_S	et	f	\N
175617	tr7icla	?tricla =tricla  (IndPrPs_  >triclama !29_V	et	f	\N
175618	tr7icla	?tricla =tricla  (ImpPrSg2  >triclama !29_V	et	f	\N
175621	ettttart	?ettttart =ettttart  (SgN  >ettttart !22_S	et	f	\N
175622	crjcrliktr	?crjcrliktr =crjcrliktr  (SgN  >crjcrliktr !22_S	et	f	\N
175652	jcz	### jcz	et	f	\N
175656	kcr	### kcr	et	f	\N
175657	cmrad	### cmrad	et	f	\N
175673	teicl	?teicl =teicl  (SgN  >teicl !22_S	et	f	\N
175675	amcr	?amcr =amcr  (SgN  >amcr !22_S	et	f	\N
175676	siic	?siic =siic  (SgN  >siic !22_S	et	f	\N
175694	3cmoxusa	?cmoxusa =cmoxusa  (SgN  >cmoxusa !01_S	et	f	\N
175695	3cmoxusa	?cmoxusa =cmoxusa  (SgG  >cmoxusa !01_S	et	f	\N
175697	xe	### xe	et	f	\N
175700	sttatcombau	?sttatcombau =sttatcombau  (SgN  >sttatcombau !26_S	et	f	\N
175701	sttatcombau	?sttatcombau =sttatcombau  (SgG  >sttatcombau !26_S	et	f	\N
175705	margatav	?margatav =marga  (PtsPrIps  >markama !29_V	et	f	\N
175706	margatav	?margatav =margata  (PtsPrPs  >margatama !27_V	et	f	\N
175707	margatav	?margatav =margatav  (SgN  >margatav !02_A	et	f	\N
175717	annrna	?annrna =annrna  (SgN  >annrna !01_S	et	f	\N
175718	annrna	?annrna =annrna  (SgG  >annrna !01_S	et	f	\N
175719	annrna	?annrna =annrna  (IndPrPs_  >annrnama !29_V	et	f	\N
175720	annrna	?annrna =annrna  (ImpPrSg2  >annrnama !29_V	et	f	\N
175729	ilrts	?ilrts =ilrts  (SgN  >ilrts !22_S	et	f	\N
175740	rrri5oda	?rrrioda =rrrioda  (SgN  >rrrioda !16_S	et	f	\N
175743	rrri5oda	?rrrioda =rrrioda  (SgG  >rrrioda !16_S	et	f	\N
175744	rrri5oda	?rrrioda =rrrioda  (IndPrPs_  >rrriodama !29_V	et	f	\N
175745	rrri5oda	?rrrioda =rrrioda  (ImpPrSg2  >rrriodama !29_V	et	f	\N
175747	crt-ettenrrd	?crt-ettenrrd =ettenrrd  (SgN  >crt-ettenrrd !02_S	et	f	\N
175760	tarututaxd	?tarututaxd =tarututaxd  (SgN  >tarututaxd !22_S	et	f	\N
175761	tarututaxd	?tarututaxd =tutaxd  (SgN  >taru+tutaxd !02_S	et	f	\N
175772	maaratlemise	?maaratlemise =maaratlemise  (SgG  >maaratlemine !12_S	et	f	\N
175773	maaratlemise	?maaratlemise =ratlemise  (SgG  >maa+ratlemine !12_S	et	f	\N
175775	oppijatel	?oppijatel =oppija  (PlAd  >oppija !01_S	et	f	\N
175776	oppijatel	?oppijatel =oppija  (PlAd  >oppijas !02_A	et	f	\N
175777	oppijatel	?oppijatel =oppijate  (PlAd  >oppijatt !22_S	et	f	\N
175807	tahtsust	?tahtsust =tahtsus  (SgP  >tahtsus !11~09_S	et	f	\N
175828	voimaldab	?voimaldab =voimalda  (IndPrSg3  >voimaldama !27_V	et	f	\N
175838	votta	?votta =votta  (ID  >votta !41_D	et	f	\N
175839	votta	?votta =votta  (IndPrPs_  >vottama !29_V	et	f	\N
175840	votta	?votta =votta  (ImpPrSg2  >vottama !29_V	et	f	\N
175860	opitava	?opitava =opitava  (SgN  >opitava !16_S	et	f	\N
175861	opitava	?opitava =opitava  (SgG  >opitav !02_A	et	f	\N
175862	opitava	?opitava =opitava  (SgG  >opitava !16_S	et	f	\N
175863	vordlemisel	?vordlemisel =vordlemise  (SgAd  >vordlemine !12_S	et	f	\N
175864	opetaja	?opetaja =opetaja  (SgN  >opetaja !01_S	et	f	\N
175865	opetaja	?opetaja =opetaja  (SgG  >opetaja !01_S	et	f	\N
175866	opetaja	?opetaja =opetaja  (SgG  >opetajas !02_A	et	f	\N
175869	siastemaatilist	?siastemaatilist =siastemaatili  (SgEl  >siastemaatil !02_S	et	f	\N
175870	siastemaatilist	?siastemaatilist =siastemaatilis  (SgP  >siastemaatilis !09_S	et	f	\N
175871	siastemaatilist	?siastemaatilist =siastemaatilis  (SgP  >siastemaatiline !12_A	et	f	\N
175872	siastemaatilist	?siastemaatilist =siastemaatilist  (SgN  >siastemaatilist !22_S	et	f	\N
175879	algvorde	?algvorde =algvorde  (PlP  >algvord !22_S	et	f	\N
175880	algvorde	?algvorde =vorde  (SgN  >alg+vorde !06_S	et	f	\N
175881	algvorde	?algvorde =vorde  (SgG  >alg+vorre !06_S	et	f	\N
175882	algvorde	?algvorde =vorde  (PlP  >alg+vord !22_S	et	f	\N
175898	põrandavarvimine	?põrandavarvimine =põrandavarvimine  (SgN  >põrandavarvimine !12_S	et	f	\N
175899	põrandavarvimine	?põrandavarvimine =põrandavarvimine  (PlP  >põrandavarvimin !19_S	et	f	\N
175900	põrandavarvimine	?põrandavarvimine =varvimine  (SgN  >põranda+varvimine !12_S	et	f	\N
175901	põrandavarvimine	?põrandavarvimine =varvimine  (PlP  >põranda+varvimin !19_S	et	f	\N
175922	korrektsus	korrektsus =korrektsus  (SgN  >korrektsus !11~09_S	et	f	\N
175923	korrektsus	"korrektsus %korrektse  )US_aS  <korrektne ;02_A	et	f	\N
175929	kaseti	?kaseti =kase  (IndIpfIps  >kasema !27_V	et	f	\N
175931	kaseti	?kaseti =kaseti  (ID  >kaseti !41_D	et	f	\N
175933	kaseti	?kaseti =kaseti  (SgG  >kasett !22_S	et	f	\N
175935	kaseti	?kaseti =kaseti  (IndPrPs_  >kasettima !28_V	et	f	\N
175936	kaseti	?kaseti =kaseti  (ImpPrSg2  >kasettima !28_V	et	f	\N
175937	kaseti	?kaseti =eti  (SgN  >kas+eti !16_S	et	f	\N
175938	kaseti	?kaseti =eti  (SgG  >kas+eti !16_S	et	f	\N
175939	kaseti	?kaseti =eti  (SgG  >kas+ett !22_S	et	f	\N
175943	skulptur	?skulptur =skulptur  (SgN  >skulptur !02_S	et	f	\N
175678	pohinev	?pohinev =pohine  (PtsPrPs  >pohinema !27_V	et	f	\N
175680	pohinev	?pohinev =pohinev  (SgN  >pohinev !02_A	et	f	\N
175686	zogopsam	?zogopsam =zogopsam  (SgN  >zogopsam !02_A	et	f	\N
175699	eaur	?eaur =eaur  (SgN  >eaur !02_S	et	f	\N
175702	npuxecem	?npuxecem =npuxecem  (SgN  >npuxecem !19_S	et	f	\N
175722	oltnri	?oltnri =oltnri  (SgN  >oltnri !01_S	et	f	\N
175723	oltnri	?oltnri =oltnri  (SgG  >oltnri !01_S	et	f	\N
175724	oltnri	?oltnri =oltnri  (SgG  >oltnr !22_S	et	f	\N
175725	oltnri	?oltnri =oltnri  (SgP  >oltnr !22_S	et	f	\N
175726	oltnri	?oltnri =oltnri  (SgAdt  >oltnr !22_S	et	f	\N
175727	oltnri	?oltnri =oltnri  (IndPrPs_  >oltnrima !28_V	et	f	\N
175728	oltnri	?oltnri =oltnri  (ImpPrSg2  >oltnrima !28_V	et	f	\N
175736	hrllirtrrast	?hrllirtrrast =hrllirtrra  (SgEl  >hrllirtrra !01_S	et	f	\N
175738	hrllirtrrast	?hrllirtrrast =hrllirtrras  (SgP  >hrllirtrras !07_S	et	f	\N
175741	hrllirtrrast	?hrllirtrrast =hrllirtrras  (SgP  >hrllirtrrane !12~10_A	et	f	\N
175764	eripara	?eripara =eripara  (SgN  >eripara !16_S	et	f	\N
175765	eripara	?eripara =eripara  (SgG  >eripara !16_S	et	f	\N
175766	eripara	?eripara =para  (SgN  >eri+para !17_S	et	f	\N
175767	eripara	?eripara =para  (SgG  >eri+para !17_S	et	f	\N
175768	eripara	?eripara =para  (SgP  >eri+para !17_S	et	f	\N
175774	iilikond	?iilikond =iilikond  (SgN  >iilikond !22_S	et	f	\N
175793	secpi	?secpi =secpi  (SgN  >secpi !16_S	et	f	\N
175794	secpi	?secpi =secpi  (SgG  >secpi !16_S	et	f	\N
175795	secpi	?secpi =secpi  (SgG  >secp !22_S	et	f	\N
175796	secpi	?secpi =secpi  (SgP  >secp !22_S	et	f	\N
175797	secpi	?secpi =secpi  (SgAdt  >secp !22_S	et	f	\N
175798	secpi	?secpi =secpi  (IndPrPs_  >secpima !28_V	et	f	\N
175799	secpi	?secpi =secpi  (ImpPrSg2  >secpima !28_V	et	f	\N
175801	etteiitlusest	?etteiitlusest =etteiitluse  (SgEl  >etteiitlus !11~09_S	et	f	\N
175802	etteiitlusest	?etteiitlusest =etteiitluses  (SgP  >etteiitlusene !12_A	et	f	\N
175803	etteiitlusest	?etteiitlusest =iitluse  (SgEl  >ette+iitlus !11~09_S	et	f	\N
175804	etteiitlusest	?etteiitlusest =iitluses  (SgP  >ette+iitlusene !12_A	et	f	\N
175808	kcxhllrrst	### kcxhllrrst	et	f	\N
175815	tegevrrsessr4yrrgi	?tegevrrsessryrrgi =tegevrrsessryrrgi  (IndPrPs_  >tegevrrsessryrrgima !28_V	et	f	\N
175816	tegevrrsessr4yrrgi	?tegevrrsessryrrgi =tegevrrsessryrrgi  (ImpPrSg2  >tegevrrsessryrrgima !28_V	et	f	\N
175817	tegevrrsessr4yrrgi	?tegevrrsessryrrgi =tegevrrsessryrr  (SgN^  >tegevrrsessryrr !22_S	et	f	\N
175829	jareldada	?jareldada =jarelda  (Inf  >jareldama !27_V	et	f	\N
175841	otsetolget	?otsetolget =tolge  (SgP  >otse+tolge !06_S	et	f	\N
175854	da-infmitiiv	?da-infmitiiv =infmitiiv  (SgN  >da-infmitiiv !22_S	et	f	\N
175856	uhendverbid	?uhendverbid =uhendverbi  (PlN  >uhendverp !22_S	et	f	\N
175857	uhendverbid	?uhendverbid =uhendverbi  (IndPrSg2  >uhendverpima !28_V	et	f	\N
175859	oppimisel	?oppimisel =oppimise  (SgAd  >oppimine !12_S	et	f	\N
175867	oppimisstrateegia	?oppimisstrateegia =oppimisstrateegia  (SgN  >oppimisstrateegia !01_S	et	f	\N
175868	oppimisstrateegia	?oppimisstrateegia =oppimisstrateegia  (SgG  >oppimisstrateegia !01_S	et	f	\N
175895	uuakse	?uuakse =uuakse  (SgG  >uuakne !02_A	et	f	\N
175896	uuakse	?uuakse =uuakse  (PlP  >uuaks !22_S	et	f	\N
175903	öeldistaide	?öeldistaide =öeldistai  (PlG  >öeldistai !26_S	et	f	\N
175904	maaratlemine	?maaratlemine =maaratlemine  (SgN  >maaratlemine !12_S	et	f	\N
175905	maaratlemine	?maaratlemine =maaratlemine  (PlP  >maaratlemin !19_S	et	f	\N
175906	maaratlemine	?maaratlemine =ratlemine  (SgN  >maa+ratlemine !12_S	et	f	\N
175907	maaratlemine	?maaratlemine =ratlemine  (PlP  >maa+ratlemin !19_S	et	f	\N
175910	väljendamisega	väljendamisega =väljendamise  (SgKom  >väljendamine !12_S	et	f	\N
175911	väljendamisega	"väljendamine %väljenda  )MINE_vS  <väljendama ;27_V	et	f	\N
175914	kõnelevate	kõnelevate =kõneleva  (PlG  >kõnelev !02_A	et	f	\N
175915	kõnelevate	"kõnelev %kõnele  )V_vA  <kõnelema ;27_V	et	f	\N
175916	kõnelevate	"kõnelev %kõnele  )V_vA  <kõnelema ;31_V	et	f	\N
175927	lindistatud	lindistatud =lindista  (PtsPtIps  >lindistama !27_V	et	f	\N
175928	lindistatud	lindistatud =lindistatu  (PlN  >lindistatu !01_S	et	f	\N
175930	lindistatud	"lindistatu %lindista  )TU1_vS  <lindistama ;27_V	et	f	\N
175932	lindistatud	lindistatud =lindistatud  (ID  >lindistatud !41_A	et	f	\N
175934	lindistatud	"lindistatud %lindista  )TUD_vA  <lindistama ;27_V	et	f	\N
175979	malelaud	malelaud =lau  (PlN  >male+laug !22_SA	et	f	\N
175980	malelaud	malelaud =laud  (SgN  >male+laud !22_S	et	f	\N
175995	i-1	### i-1	et	f	\N
176005	partitiivverb	?partitiivverb =partitiivverb  (SgN  >partitiivverb !22_S	et	f	\N
176006	partitiivverb	?partitiivverb =itiivverb  (SgN  >part+itiivverb !22_S	et	f	\N
176011	lõpetamatu	lõpetamatu =lõpetamatu  (SgN  >lõpetamatu !01_A	et	f	\N
176012	lõpetamatu	"lõpetamatu %lõpe  )TAMATU_vA  <lõppema ;28_V	et	f	\N
176013	lõpetamatu	"lõpetamatu %lõpe  )TAMATU_vA  <lõpma ;35_V	et	f	\N
176014	lõpetamatu	"lõpetamatu %lõpeta  )MATU_vA  <lõpetama ;27_V	et	f	\N
176015	lõpetamatu	lõpetamatu =lõpetamatu  (SgG  >lõpetamatu !01_A	et	f	\N
176021	märkivate	märkivate =märkiva  (PlG  >märkiv !02_A	et	f	\N
176022	märkivate	"märkiv %märki  )V_vA  <märkima ;28_V	et	f	\N
176046	olekutseisundit	?olekutseisundit =tseisundi  (SgP  >oleku+tseisundi !01_S	et	f	\N
175704	6o2amcmeo	?oamcmeo =oamcmeo  (SgG  >oamcmeo !01_S	et	f	\N
175716	agcr	?agcr =agcr  (SgN  >agcr !22_S	et	f	\N
175721	7cxllirtrt	?cxllirtrt =cxllirtrt  (SgN  >cxllirtrt !22_S	et	f	\N
175730	ktrrrhrs	### ktrrrhrs	et	f	\N
175732	pracyjtr	?pracyjtr =pracyjtr  (SgN  >pracyjtr !22_S	et	f	\N
175735	karrhctlcreaad	?karrhctlcreaad =karrhctlcreaa  (PlN  >karrhctlcreaa !26_S	et	f	\N
175737	karrhctlcreaad	?karrhctlcreaad =karrhctlcreaa  (SgP  >karrhctlcreaa !26_S	et	f	\N
175739	karrhctlcreaad	?karrhctlcreaad =karrhctlcreaad  (SgN  >karrhctlcreaad !22_S	et	f	\N
175748	tnallrtnlrrs	?tnallrtnlrrs =tnallrtnlrrs  (SgN  >tnallrtnlrrs !22_S	et	f	\N
175751	tallinnatnpoe3manu	?tallinnatnpoemanu =tallinnatnpoemanu  (SgN  >tallinnatnpoemanu !01_S	et	f	\N
175752	tallinnatnpoe3manu	?tallinnatnpoemanu =tallinnatnpoemanu  (SgG  >tallinnatnpoemanu !01_S	et	f	\N
175753	tallinnatnpoe3manu	?tallinnatnpoemanu =tallinnatnpoemanu  (IndPrPs_  >tallinnatnpoemanuma !27_V	et	f	\N
175754	tallinnatnpoe3manu	?tallinnatnpoemanu =tallinnatnpoemanu  (ImpPrSg2  >tallinnatnpoemanuma !27_V	et	f	\N
175755	tallinnatnpoe3manu	?tallinnatnpoemanu =atnpoemanu  (SgN  >tallinn+atnpoemanu !01_S	et	f	\N
175756	tallinnatnpoe3manu	?tallinnatnpoemanu =atnpoemanu  (SgG  >tallinn+atnpoemanu !01_S	et	f	\N
175785	gpalp	?gpalp =gpalp  (SgN  >gpalp !22_S	et	f	\N
175786	eimes	?eimes =eime  (SgIn  >eime !06_S	et	f	\N
175787	eimes	?eimes =eime  (PlIn  >eim !22_S	et	f	\N
175788	eimes	?eimes =eime  (IndIpfSg3  >eimema !27_V	et	f	\N
175789	eimes	?eimes =eimes  (SgN  >eimes !09_S	et	f	\N
175790	jcr	### jcr	et	f	\N
175805	sonadest	?sonadest =sona  (PlEl  >sona !17_S	et	f	\N
175806	sonadest	?sonadest =sonades  (SgP  >sonadene !12_A	et	f	\N
175826	veaanaluiis	?veaanaluiis =veaanaluii  (SgIn  >veaanaluii !26_S	et	f	\N
175827	veaanaluiis	?veaanaluiis =veaanaluiis  (SgN  >veaanaluiis !22_S	et	f	\N
175843	jdrjekord	?jdrjekord =jdrjekord  (SgN  >jdrjekord !22_S	et	f	\N
175849	oppijale	?oppijale =oppija  (SgAll  >oppija !01_S	et	f	\N
175850	oppijale	?oppijale =oppija  (SgAll  >oppijas !02_A	et	f	\N
175851	oppijale	?oppijale =oppijale  (PlP  >oppijal !19_S	et	f	\N
175852	moisted	?moisted =moiste  (PlN  >moiste !06_S	et	f	\N
175853	moisted	?moisted =moiste  (IndPrSg2  >moistema !27_V	et	f	\N
175873	muusikatja	?muusikatja =muusikatja  (SgN  >muusikatja !16_S	et	f	\N
175874	muusikatja	?muusikatja =muusikatja  (SgG  >muusikatjas !02_A	et	f	\N
175875	muusikatja	?muusikatja =muusikatja  (SgG  >muusikatja !16_S	et	f	\N
175876	muusikatja	?muusikatja =sikatja  (SgN  >muu+sikatja !01_S	et	f	\N
175877	muusikatja	?muusikatja =sikatja  (SgG  >muu+sikatja !01_S	et	f	\N
175878	muusikatja	?muusikatja =sikatja  (SgG  >muu+sikatjas !02_A	et	f	\N
175891	ülivorde	?ülivorde =ülivorde  (PlP  >ülivord !22_S	et	f	\N
175892	ülivorde	?ülivorde =vorde  (SgN  >üli+vorde !06_S	et	f	\N
175893	ülivorde	?ülivorde =vorde  (SgG  >üli+vorre !06_S	et	f	\N
175894	ülivorde	?ülivorde =vorde  (PlP  >üli+vord !22_S	et	f	\N
175897	loodakse	?loodakse =loodakse  (SgG  >loodakne !02_A	et	f	\N
175908	vanusele	vanusele =vanuse  (SgAll  >vanus !09_S	et	f	\N
175909	vanusele	vanusele =vanuse  (SgAll  >vanune !10_A	et	f	\N
175924	koorti	?koorti =koorti  (ID  >koorti !41_D	et	f	\N
175925	koorti	?koorti =koorti  (SgP  >koort !22_S	et	f	\N
175926	koorti	?koorti =koorti  (SgAdt  >koort !22_S	et	f	\N
175940	ii-välteline	ii-välteline =välteline  (SgN  >ii-välteline !12_A	et	f	\N
175941	ii-välteline	"ii-välteline %välte  )LINE_aA  <ii-välde ;06_S	et	f	\N
175948	soobin	?soobin =soobi  (IndPrSg1  >soobima !27_V	et	f	\N
175949	soobin	?soobin =soobi  (IndPrSg1  >soopima !28_V	et	f	\N
175950	soobin	?soobin =soobin  (SgN  >soobin !02_S	et	f	\N
175960	venepäraselt	venepäraselt =pärase  (SgAbl  >vene+pärane !10_A	et	f	\N
175961	venepäraselt	"vene+pärane %pära  )NE_aA  <vene+pära ;17_S	et	f	\N
175962	venepäraselt	"vene+päraselt %pära  )SELT_mD  <vene+pära ;17_S	et	f	\N
175963	venepäraselt	"vene+päraselt %pärase  )LT_mD  <vene+pärane ;10_A	et	f	\N
175964	kasamuti	?kasamuti =kasamu  (IndIpfIps  >kasamuma !27_V	et	f	\N
175965	kasamuti	?kasamuti =kasamuti  (SgG  >kasamutt !22_S	et	f	\N
175966	kasamuti	?kasamuti =kasamuti  (IndPrPs_  >kasamuttima !28_V	et	f	\N
175967	kasamuti	?kasamuti =kasamuti  (ImpPrSg2  >kasamuttima !28_V	et	f	\N
175968	kasamuti	?kasamuti =amuti  (SgN  >kas+amuti !01_S	et	f	\N
175969	kasamuti	?kasamuti =amuti  (SgG  >kas+amuti !01_S	et	f	\N
175970	kasamuti	?kasamuti =amuti  (SgG  >kas+amut !02_S	et	f	\N
175971	kasamuti	?kasamuti =amuti  (SgG  >kas+amutt !22_S	et	f	\N
175972	muljeet	?muljeet =muljeet  (SgN  >muljeet !22_S	et	f	\N
175981	analoogiliselt	analoogiliselt =analoogilise  (SgAbl  >analoogiline !12_A	et	f	\N
175982	analoogiliselt	"analoogiline %analoogi  )LINE_aA  <analoog ;22_S	et	f	\N
175983	analoogiliselt	analoogiliselt =analoogiliselt  (ID  >analoogiliselt !41_D	et	f	\N
175984	analoogiliselt	"analoogiliselt %analoogi  )LISELT_mD  <analoog ;22_S	et	f	\N
175985	analoogiliselt	"analoogiliselt %analoogilise  )LT_mD  <analoogiline ;12_A	et	f	\N
175986	vahelduvad	vahelduvad =vaheldu  (IndPrPl3  >vahelduma !27_V	et	f	\N
175987	vahelduvad	vahelduvad =vahelduva  (PlN  >vahelduv !02_A	et	f	\N
175989	vahelduvad	"vahelduv %vaheldu  )V_vA  <vahelduma ;27_V	et	f	\N
175858	tahed	?tahed =tahe  (IndPrSg2  >tahema !27_V	et	f	\N
175883	uga	?uga =uga  (SgN  >uga !17_S	et	f	\N
175884	uga	?uga =uga  (SgG  >uga !17_S	et	f	\N
175885	uga	?uga =uga  (SgP  >uga !17_S	et	f	\N
175886	uga	?uga =uga  (IndPrPs_  >ugama !27_V	et	f	\N
175887	uga	?uga =uga  (ImpPrSg2  >ugama !27_V	et	f	\N
175902	öeldistaite	?öeldistaite =öeldistaite  (PlP  >öeldistait !22_S	et	f	\N
175920	riigikeeleõpetaja	riigikeeleõpetaja =õpetaja  (SgN  >riigi+keele+õpetaja !01_S	et	f	\N
175921	riigikeeleõpetaja	riigikeeleõpetaja =õpetaja  (SgG  >riigi+keele+õpetaja !01_S	et	f	\N
175951	parandatud	parandatud =paranda  (PtsPtIps  >parandama !27_V	et	f	\N
175952	parandatud	parandatud =parandatu  (PlN  >parandatu !01_S	et	f	\N
175953	parandatud	"parandatu %paranda  )TU1_vS  <parandama ;27_V	et	f	\N
175954	parandatud	parandatud =parandatud  (ID  >parandatud !41_A	et	f	\N
175955	parandatud	"parandatud %paranda  )TUD_vA  <parandama ;27_V	et	f	\N
175973	kirjutatavat	kirjutatavat =kirjuta  (KvtPrIps  >kirjutama !27_V	et	f	\N
175974	kirjutatavat	kirjutatavat =kirjutatava  (SgP  >kirjutatav !02_A	et	f	\N
175975	kirjutatavat	"kirjutatav %kirjuta  )TAV_vAS  <kirjutama ;27_V	et	f	\N
176016	viidav	viidav =vii  (PtsPrIps  >viima !38_V	et	f	\N
176017	viidav	viidav =viidav  (SgN  >viidav !02_A	et	f	\N
176018	viidav	"viidav %vii  )TAV_vAS  <viima ;38_V	et	f	\N
176029	sisseütl	?sisseütl =sisseütl  (SgN  >sisseütl !22_S	et	f	\N
176030	sisseütl	?sisseütl =ütl  (SgN  >sisse+ütl !22_S	et	f	\N
176031	tulebsaab	?tulebsaab =tulebsaab  (SgN  >tulebsaab !22_S	et	f	\N
176032	tulebsaab	?tulebsaab =bsaab  (SgN  >tule+bsaab !22_S	et	f	\N
176033	kitsetalli	kitsetalli =talli  (SgG  >kitse+tall !22_S	et	f	\N
176034	kitsetalli	kitsetalli =talli  (SgP  >kitse+tall !22_S	et	f	\N
176035	kitsetalli	kitsetalli =talli  (SgAdt  >kitse+tall !22_S	et	f	\N
176036	kitsetalli	kitsetalli =talli  (PlP  >kitse+tall !22_S	et	f	\N
176037	kellemille	?kellemille =kellemille  (PlP  >kellemill !22_S	et	f	\N
176038	käändelõppu	?käändelõppu =käändelõppu  (IndPrPs_  >käändelõppuma !27_V	et	f	\N
176039	käändelõppu	?käändelõppu =käändelõppu  (ImpPrSg2  >käändelõppuma !27_V	et	f	\N
176040	käändelõppu	?käändelõppu =elõppu  (SgN  >käänd+elõppu !01_S	et	f	\N
176041	käändelõppu	?käändelõppu =elõppu  (SgG  >käänd+elõppu !01_S	et	f	\N
176044	saava	saava =saava  (SgG  >saav !02_A	et	f	\N
176045	saava	"saav %saa  )V_vA  <saama ;37_V	et	f	\N
176053	kaasaütlev	kaasaütlev =ütle  (PtsPrPs  >kaasa+_ütlema !30_V	et	f	\N
176054	kaasaütlev	kaasaütlev =ütlev  (SgN  >kaasa+ütlev !02_A	et	f	\N
176067	sõnatasandivead	?sõnatasandivead =sõnatasandivea  (PlN  >sõnatasandivea !26_S	et	f	\N
176068	sõnatasandivead	?sõnatasandivead =sõnatasandivea  (SgP  >sõnatasandivea !26_S	et	f	\N
176069	sõnatasandivead	?sõnatasandivead =sõnatasandivead  (SgN  >sõnatasandivead !22_S	et	f	\N
176070	sõnatasandivead	?sõnatasandivead =tasandivea  (PlN  >sõna+tasandivea !26_S	et	f	\N
176071	sõnatasandivead	?sõnatasandivead =tasandivea  (SgP  >sõna+tasandivea !26_S	et	f	\N
176072	sõnatasandivead	?sõnatasandivead =tasandivead  (SgN  >sõna+tasandivead !22_S	et	f	\N
176073	sarnassõnad	### sarnassõnad	et	f	\N
176074	näljane	näljane =näljane  (SgN  >näljane !10_A	et	f	\N
176075	näljane	"näljane %nälja  )NE_aA  <nälg ;22_S	et	f	\N
176076	krooku	?krooku =krooku  (SgN  >krooku !16_S	et	f	\N
176077	krooku	?krooku =krooku  (SgG  >krooku !16_S	et	f	\N
176088	kahekümneaastane	kahekümneaastane =aastane  (SgN  >kahe+kümne+aastane !12~10_A	et	f	\N
176089	kahekümneaastane	"kahe+kümne+aastane %aasta  )NE_aA  <kahe+kümne+aasta ;01_S	et	f	\N
176090	lubatav	lubatav =luba  (PtsPrIps  >lubama !27_V	et	f	\N
176091	lubatav	lubatav =lubatav  (SgN  >lubatav !02_A	et	f	\N
176092	lubatav	"lubatav %luba  )TAV_vAS  <lubama ;27_V	et	f	\N
176104	kahesilbiline	kahesilbiline =silbiline  (SgN  >kahe+silbiline !12_A	et	f	\N
176105	kahesilbiline	"kahe+silbiline %silbi  )LINE_aA  <kahe+silp ;22_S	et	f	\N
176114	järgarvud	?järgarvud =järgarvu  (PlN  >järgarvu !01_S	et	f	\N
176115	järgarvud	?järgarvud =järgarvu  (IndPrSg2  >järgarvuma !27_V	et	f	\N
176117	ümberjustuse	?ümberjustuse =ümberjustuse  (SgG  >ümberjustus !11~09_S	et	f	\N
176118	ümberjustuse	?ümberjustuse =use  (SgN  >ümber+just+use !16_S	et	f	\N
176120	ümberjustuse	?ümberjustuse =use  (SgG  >ümber+just+use !16_S	et	f	\N
176122	ümberjustuse	?ümberjustuse =justuse  (SgG  >ümber+justus !11~09_S	et	f	\N
176123	kirjutavat	kirjutavat =kirjuta  (KvtPrPs  >kirjutama !27_V	et	f	\N
176124	kirjutavat	kirjutavat =kirjutava  (SgP  >kirjutav !02_A	et	f	\N
176125	kirjutavat	"kirjutav %kirjuta  )V_vA  <kirjutama ;27_V	et	f	\N
176126	ta-	ta- =ta  (SgG  >ta !00_P	et	f	\N
176127	ta-	ta- =ta  (SgN  >ta !00_P	et	f	\N
176130	aktsepteeri	aktsepteeri =aktsepteeri  (IndPrPs_  >aktsepteerima !28_V	et	f	\N
176131	aktsepteeri	aktsepteeri =aktsepteeri  (ImpPrSg2  >aktsepteerima !28_V	et	f	\N
176134	12kodust	kodust =kodu  (SgEl  >kodu !17_S	et	f	\N
176135	12kodust	kodust =kodus  (SgP  >kodune !10_A	et	f	\N
176136	12kodust	"kodune %kodu  )NE_aA  <kodu ;17_S	et	f	\N
176150	18to	### 18to	et	f	\N
176163	sõltuvadki	sõltuvadki =sõltu  (IndPrPl3^  >sõltuma !27_V	et	f	\N
176164	sõltuvadki	sõltuvadki =sõltuva  (PlN^  >sõltuv !02_A	et	f	\N
175889	i-ülivorre	?i-ülivorre =vorre  (SgN  >i-üli+vorre !06_S	et	f	\N
175890	i-ülivorre	?i-ülivorre =vorre  (PlP  >i-üli+vorr !22_S	et	f	\N
175912	eraõpetaja	eraõpetaja =õpetaja  (SgN  >era+õpetaja !01_S	et	f	\N
175913	eraõpetaja	eraõpetaja =õpetaja  (SgG  >era+õpetaja !01_S	et	f	\N
175917	keeleõpetajast	keeleõpetajast =õpetaja  (SgEl  >keele+õpetaja !01_S	et	f	\N
175918	keeleõpetajast	keeleõpetajast =õpetajas  (SgP  >keele+õpetajane !12_A	et	f	\N
175919	keeleõpetajast	"keele+õpetajane %õpetaja  )NE_aA  <keele+õpetaja ;01_S	et	f	\N
175942	skulptoor	?skulptoor =skulptoor  (SgN  >skulptoor !22_S	et	f	\N
175944	gravur	?gravur =gravur  (SgN  >gravur !02_S	et	f	\N
175945	graviaur	?graviaur =graviaur  (SgN  >graviaur !19_S	et	f	\N
175946	skulpturiga	?skulpturiga =skulpturi  (SgKom  >skulpturi !01_S	et	f	\N
175947	skulpturiga	?skulpturiga =skulpturi  (SgKom  >skulptur !02_S	et	f	\N
175956	rõhuline	rõhuline =rõhuline  (SgN  >rõhuline !12_A	et	f	\N
175957	rõhuline	"rõhuline %rõhu  )LINE_aA  <rõhk ;22_S	et	f	\N
175958	eetikeelse	?eetikeelse =eetikeelse  (SgG  >eetikeelne !02_A	et	f	\N
175959	eetikeelse	?eetikeelse =eetikeelse  (PlP  >eetikeels !22_S	et	f	\N
175976	javõi	?javõi =javõi  (SgN  >javõi !26_S	et	f	\N
175977	javõi	?javõi =javõi  (SgG  >javõi !26_S	et	f	\N
175978	9ndas	### 9ndas	et	f	\N
175994	lippul	?lippul =lippul  (SgN  >lippul !02_S	et	f	\N
176025	ruumiga	ruumiga =ruumi  (SgKom  >ruum !22_S	et	f	\N
176026	ruumiga	ruumiga =iga  (SgN  >ruum+iga !18_S	et	f	\N
176027	ruumiga	ruumiga =iga  (SgP  >ruum+iga !18_S	et	f	\N
176048	rajav	rajav =raja  (PtsPrPs  >rajama !27_V	et	f	\N
176049	rajav	rajav =rajav  (SgN  >rajav !02_A	et	f	\N
176050	rajav	"rajav %raja  )V_vA  <rajama ;27_V	et	f	\N
176055	kohag	### kohag	et	f	\N
176065	rakenda	rakenda =rakenda  (IndPrPs_  >rakendama !27_V	et	f	\N
176066	rakenda	rakenda =rakenda  (ImpPrSg2  >rakendama !27_V	et	f	\N
176153	olee	?olee =olee  (SgN  >olee !26_S	et	f	\N
176154	olee	?olee =olee  (SgG  >olee !26_S	et	f	\N
176170	tulenesid	tulenesid =tulene  (IndIpfSg2  >tulenema !27_V	et	f	\N
176171	tulenesid	tulenesid =tulene  (IndIpfPl3  >tulenema !27_V	et	f	\N
176193	tingimust	tingimust =tingimus  (SgP  >tingimus !11_S	et	f	\N
176194	tingimust	tingimust =imu  (SgEl  >ting+imu !17_S	et	f	\N
176195	ülivõrre	ülivõrre =võrre  (SgN  >üli+võrre !06_S	et	f	\N
176196	ülivõrre	ülivõrre =võrre  (PlP  >üli+võrr !22_S	et	f	\N
176197	testmoodi	testmoodi =moodi  (SgP  >test+mood !22_S	et	f	\N
176199	testmoodi	testmoodi =moodi  (SgAdt  >test+mood !22_S	et	f	\N
176202	kadem	?kadem =kadem  (SgN  >kadem !02_A	et	f	\N
176205	moodustusvigu	?moodustusvigu =moodustusvi  (ImpPrPs  >moodustusvima !28_V	et	f	\N
176206	moodustusvigu	?moodustusvigu =moodustusvigu  (IndPrPs_  >moodustusviguma !27_V	et	f	\N
176207	moodustusvigu	?moodustusvigu =moodustusvigu  (ImpPrSg2  >moodustusviguma !27_V	et	f	\N
176210	ebareeglipäraste	ebareeglipäraste =päras  (PlG  >eba+reegli+pärane !10_A	et	f	\N
176211	ebareeglipäraste	"eba+reegli+pärane %pära  )NE_aA  <eba+reegli+pära ;17_S	et	f	\N
176219	joinud	?joinud =joinu  (PlN  >joinu !16_S	et	f	\N
176220	joinud	?joinud =joinu  (IndPrSg2  >joinuma !28_V	et	f	\N
176221	joinud	?joinud =joinud  (ID  >joinud !41_A	et	f	\N
176222	näiginud	?näiginud =näigi  (PtsPtPs  >näigima !28_V	et	f	\N
176223	näiginud	?näiginud =näiginu  (PlN  >näiginu !01_S	et	f	\N
176224	näiginud	?näiginud =näiginu  (IndPrSg2  >näiginuma !27_V	et	f	\N
176225	näiginud	?näiginud =näiginud  (ID  >näiginud !41_A	et	f	\N
176233	dainfinitiivi	?dainfinitiivi =dainfinitiivi  (SgN  >dainfinitiivi !16_S	et	f	\N
176234	dainfinitiivi	?dainfinitiivi =dainfinitiivi  (SgG  >dainfinitiivi !16_S	et	f	\N
176235	dainfinitiivi	?dainfinitiivi =dainfinitiivi  (SgG  >dainfinitiiv !22_S	et	f	\N
176236	dainfinitiivi	?dainfinitiivi =dainfinitiivi  (SgP  >dainfinitiiv !22_S	et	f	\N
176237	dainfinitiivi	?dainfinitiivi =dainfinitiivi  (SgAdt  >dainfinitiiv !22_S	et	f	\N
176238	dainfinitiivi	?dainfinitiivi =dainfinitiivi  (IndPrPs_  >dainfinitiivima !28_V	et	f	\N
176239	dainfinitiivi	?dainfinitiivi =dainfinitiivi  (ImpPrSg2  >dainfinitiivima !28_V	et	f	\N
176242	lausestruktuuri	lausestruktuuri =struktuuri  (SgG  >lause+struktuur !22_S	et	f	\N
176243	lausestruktuuri	lausestruktuuri =struktuuri  (SgP  >lause+struktuur !22_S	et	f	\N
176244	lausestruktuuri	lausestruktuuri =struktuuri  (SgAdt  >lause+struktuur !22_S	et	f	\N
176250	paronüümsed	?paronüümsed =paronüümse  (PlN  >paronüümne !02_A	et	f	\N
176322	kombineerimisega	kombineerimisega =kombineerimise  (SgKom  >kombineerimine !12_S	et	f	\N
176323	kombineerimisega	"kombineerimine %kombineeri  )MINE_vS  <kombineerima ;28_V	et	f	\N
176329	äpardused	äpardused =äparduse  (PlN  >äpardus !11_S	et	f	\N
176330	äpardused	"äpardus %äparda  )US_vS  <äpardama ;27_V	et	f	\N
176337	ülejaanud	?ülejaanud =ülejaanu  (PlN  >ülejaanu !01_S	et	f	\N
176338	ülejaanud	?ülejaanud =ülejaanu  (IndPrSg2  >ülejaanuma !27_V	et	f	\N
176339	ülejaanud	?ülejaanud =ülejaanud  (ID  >ülejaanud !41_A	et	f	\N
176340	ülejaanud	?ülejaanud =jaanu  (PlN  >üle+jaanu !16_S	et	f	\N
176341	movdustamisega	?movdustamisega =movdustamise  (SgKom  >movdustamine !12_S	et	f	\N
176362	kolmekorruselines	?kolmekorruselines =kolmekorruseline  (PlIn  >kolmekorruselin !19_S	et	f	\N
175988	ruudukesed	ruudukesed =ruudukese  (PlN  >ruuduke !12_S	et	f	\N
175990	ruudukesed	"ruuduke %ruudu  )KE_dS  <ruut ;22_S	et	f	\N
175991	ruudukesed	ruudukesed =ruudukese  (PlN  >ruudukene !12_S	et	f	\N
175992	ruudukesed	"ruudukene %ruudu  )KENE_dS  <ruut ;22_S	et	f	\N
175993	k-ütljalgrattagam	?k-ütljalgrattagam =ütljalgrattagam  (SgN  >k-ütljalgrattagam !02_A	et	f	\N
175996	lippum	?lippum =lippum  (SgN  >lippum !02_S	et	f	\N
175997	rottile	?rottile =rottile  (IndPrPs_  >rottilema !27_V	et	f	\N
175998	rottile	?rottile =rottile  (ImpPrSg2  >rottilema !27_V	et	f	\N
175999	rottim	?rottim =rottim  (SgN  >rottim !02_A	et	f	\N
176007	vares	vares =vare  (SgIn  >vare !16_S	et	f	\N
176008	vares	vares =vares  (SgN  >vares !09_S	et	f	\N
176042	asjata	asjata =asja  (SgAb  >asi !24_S	et	f	\N
176043	asjata	asjata =asjata  (ID  >asjata !41_DA	et	f	\N
176099	järgnevast	järgnevast =järgneva  (SgEl  >järgnev !02_A	et	f	\N
176100	järgnevast	"järgnev %järgne  )V_vA  <järgnema ;27_V	et	f	\N
176101	ntvigade	?ntvigade =ntviga  (PlG  >ntviga !17_S	et	f	\N
176102	parandus	parandus =parandus  (SgN  >parandus !11_S	et	f	\N
176103	parandus	"parandus %paranda  )US_vS  <parandama ;27_V	et	f	\N
176110	kadrioorus	?kadrioorus =kadriooru  (IndIpfSg3  >kadriooruma !27_V	et	f	\N
176111	kadrioorus	?kadrioorus =kadrioorus  (SgN  >kadrioorus !11~09_S	et	f	\N
176112	kadrioorus	?kadrioorus =ooru  (SgIn  >kadri+ooru !16_S	et	f	\N
176113	kadrioorus	?kadrioorus =oorus  (SgN  >kadri+oorus !11~09_S	et	f	\N
176116	ik68	### ik68	et	f	\N
176140	15niimodi	?niimodi =niimodi  (SgN  >niimodi !01_S	et	f	\N
176141	15niimodi	?niimodi =niimodi  (SgG  >niimodi !01_S	et	f	\N
176142	15niimodi	?niimodi =niimodi  (SgG  >niimod !02_S	et	f	\N
176143	15niimodi	?niimodi =modi  (SgN  >nii+modi !17_S	et	f	\N
176144	15niimodi	?niimodi =modi  (SgG  >nii+modi !17_S	et	f	\N
176145	15niimodi	?niimodi =modi  (SgP  >nii+modi !17_S	et	f	\N
176157	käände-	käände- =käände  (SgG  >kääne !06_S	et	f	\N
176158	käände-	käände- =käände  (PlP  >käänd !22_S	et	f	\N
176212	pööret	pööret =pööre  (SgP  >pööre !05_S	et	f	\N
176213	pööret	pööret =pööre  (SgP  >pööre !06_S	et	f	\N
176226	söinud	?söinud =söinu  (PlN  >söinu !16_S	et	f	\N
176227	söinud	?söinud =söinu  (IndPrSg2  >söinuma !28_V	et	f	\N
176228	söinud	?söinud =söinud  (ID  >söinud !41_A	et	f	\N
176259	tõlgituna	tõlgituna =tõlgitu  (SgEs  >tõlgitu !01_AS	et	f	\N
176260	tõlgituna	"tõlgitu %tõlgi  )TU1_vS  <tõlkima ;28_V	et	f	\N
176261	tõlgituna	"tõlgitu %tõlgi  )TU2_kA  <tõlk ;22_S	et	f	\N
176262	arusaamatum	arusaamatum =saamatum  (SgN  >aru+saamatum !02_A	et	f	\N
176263	arusaamatum	"aru+saamatum %saama  )TUM2_cA  <aru+saam ;22_S	et	f	\N
176264	arusaamatum	"aru+saamatum %saamatu  )M_cA  <aru+saamatu ;01_A	et	f	\N
176287	kirjalikus	kirjalikus =kirjaliku  (SgIn  >kirjalik !25_A	et	f	\N
176288	kirjalikus	kirjalikus =kirjalikus  (SgN  >kirjalikus !11?09_S	et	f	\N
176289	kirjalikus	"kirjalikus %kirjaliku  )US_aS  <kirjalik ;25_A	et	f	\N
176301	keerulist	keerulist =keerulis  (SgP  >keeruline !12_A	et	f	\N
176302	keerulist	"keeruline %keeru  )LINE_aA  <keerd ;22_SA	et	f	\N
176303	siihitis	?siihitis =siihiti  (SgIn  >siihit !02_S	et	f	\N
176304	siihitis	?siihitis =siihiti  (SgIn  >siihitt !22_S	et	f	\N
176305	siihitis	?siihitis =siihitis  (SgN  >siihitis !11_S	et	f	\N
176333	konditsionaalsus	konditsionaalsus =konditsionaalsus  (SgN  >konditsionaalsus !11~09_S	et	f	\N
176334	konditsionaalsus	"konditsionaalsus %konditsionaalse  )US_aS  <konditsionaalne ;02_A	et	f	\N
176348	lasnamäil	?lasnamäil =lasnamäi  (SgAd  >lasnamäi !26_S	et	f	\N
176349	lasnamäil	?lasnamäil =lasnamäil  (SgN  >lasnamäil !19_S	et	f	\N
176350	lasnamäil	?lasnamäil =mäi  (SgAd  >lasna+mäi !26_S	et	f	\N
176351	lasnamäil	?lasnamäil =mäil  (SgN  >lasna+mäil !22_S	et	f	\N
176407	tingntud	?tingntud =tingntu  (PlN  >tingntu !01_S	et	f	\N
176408	tingntud	?tingntud =tingntu  (IndPrSg2  >tingntuma !27_V	et	f	\N
176409	tingntud	?tingntud =tingntud  (ID  >tingntud !41_A	et	f	\N
176442	suhtlemisiulgus	?suhtlemisiulgus =suhtlemisiulgu  (IndIpfSg3  >suhtlemisiulguma !27_V	et	f	\N
176443	suhtlemisiulgus	?suhtlemisiulgus =suhtlemisiulgus  (SgN  >suhtlemisiulgus !11~09_S	et	f	\N
176444	suhtlemisiulgus	?suhtlemisiulgus =lemisiulgus  (SgN  >suht+lemisiulgus !11~09_S	et	f	\N
176449	üldistust	üldistust =üldistus  (SgP  >üldistus !11_S	et	f	\N
176450	üldistust	"üldistus %üldista  )US_vS  <üldistama ;27_V	et	f	\N
176451	üldistust	üldistust =istu  (SgEl  >üld+ist !22_S	et	f	\N
176459	kiriutasid	?kiriutasid =kiriuta  (IndIpfSg2  >kiriutama !27_V	et	f	\N
176460	kiriutasid	?kiriutasid =kiriuta  (IndIpfPl3  >kiriutama !27_V	et	f	\N
176461	kiriutasid	?kiriutasid =uta  (PlP  >kiri+uta !16_S	et	f	\N
176462	veaanaliiusi	?veaanaliiusi =veaanaliiusi  (SgN  >veaanaliiusi !16_S	et	f	\N
176463	veaanaliiusi	?veaanaliiusi =veaanaliiusi  (SgG  >veaanaliiusi !16_S	et	f	\N
176464	veaanaliiusi	?veaanaliiusi =veaanaliiusi  (PlP  >veaanaliius !11_S	et	f	\N
176465	veaanaliiusi	?veaanaliiusi =veaanaliiusi  (IndPrPs_  >veaanaliiusima !28_V	et	f	\N
176466	veaanaliiusi	?veaanaliiusi =veaanaliiusi  (ImpPrSg2  >veaanaliiusima !28_V	et	f	\N
176469	suuroja	suuroja =oja  (SgN  >suur+oja !17_S	et	f	\N
176470	suuroja	suuroja =oja  (SgG  >suur+oja !17_S	et	f	\N
176000	alalerotile	?alalerotile =alaleroti  (SgAll  >alalerott !22_S	et	f	\N
176001	alalerotile	?alalerotile =eroti  (SgAll  >alal+erot !02_S	et	f	\N
176002	alalerotile	?alalerotile =eroti  (SgAll  >alal+erott !22_S	et	f	\N
176003	alalerotile	?alalerotile =leroti  (SgAll  >ala+lerot !02_S	et	f	\N
176004	alalerotile	?alalerotile =leroti  (SgAll  >ala+lerott !22_S	et	f	\N
176009	lihatükki	lihatükki =tükki  (SgP  >liha+tükk !22_S	et	f	\N
176010	lihatükki	lihatükki =tükki  (SgAdt  >liha+tükk !22_S	et	f	\N
176019	rotti	rotti =rotti  (SgP  >rott !22_S	et	f	\N
176020	rotti	rotti =rotti  (SgAdt  >rott !22_S	et	f	\N
176023	kinnise	kinnise =kinnise  (SgG  >kinnis !09_S	et	f	\N
176024	kinnise	kinnise =kinnise  (SgG  >kinnine !10~12_A	et	f	\N
176028	rektsioonitegusõna	### rektsioonitegusõna	et	f	\N
176056	juhiluba	juhiluba =luba  (SgN  >juhi+luba !18_S	et	f	\N
176057	juhiluba	juhiluba =luba  (SgP  >juhi+luba !18_S	et	f	\N
176058	varest	varest =vare  (SgEl  >vare !16_S	et	f	\N
176059	varest	varest =vares  (SgP  >vares !09_S	et	f	\N
176060	varest	varest =vares  (SgP  >varene !10_A	et	f	\N
176061	varest	"varene %vare  )NE_aA  <vare ;16_S	et	f	\N
176095	loomadesõber	?loomadesõber =loomadesõber  (SgN  >loomadesõber !02_S	et	f	\N
176096	loomadesõber	?loomadesõber =desõber  (SgN  >looma+desõber !19_S	et	f	\N
176097	loomadesõber	?loomadesõber =adesõber  (SgN  >loom+adesõber !02_S	et	f	\N
176098	loomadesõber	?loomadesõber =madesõber  (SgN  >loo+madesõber !02_S	et	f	\N
176108	terelt	?terelt =terelt  (ID  >terelt !41_D	et	f	\N
176119	trükiviga	trükiviga =viga  (SgN  >trüki+viga !18_S	et	f	\N
176121	trükiviga	trükiviga =viga  (SgP  >trüki+viga !18_S	et	f	\N
176128	10ei	ei =ei  (Neg  >ei !--_V	et	f	\N
176129	10ei	ei =ei  (ID  >ei !41_D	et	f	\N
176137	argikeele	argikeele =kee  (SgAll  >argi+kesi !15_S	et	f	\N
176138	argikeele	argikeele =kee  (SgAll  >argi+kee !26_S	et	f	\N
176139	argikeele	argikeele =keele  (SgG  >argi+keel !13_S	et	f	\N
176146	kitsetallist	kitsetallist =talli  (SgEl  >kitse+tall !22_S	et	f	\N
176147	kitsetallist	kitsetallist =talli  (PlEl  >kitse+tall !22_S	et	f	\N
176148	kitsetallist	kitsetallist =tallis  (SgP  >kitse+talline !10_A	et	f	\N
176149	kitsetallist	"kitse+talline %talli  )NE_aA  <kitse+tall ;22_S	et	f	\N
176155	õpetajalt	õpetajalt =õpetaja  (SgAbl  >õpetaja !01_S	et	f	\N
176156	õpetajalt	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
176177	allliigiks	allliigiks =iks  (SgN  >all+liig+iks !22_S	et	f	\N
176178	allliigiks	allliigiks =liigi  (SgTr  >all+liik !22_S	et	f	\N
176179	ühilduinisvead	?ühilduinisvead =ühilduinisvea  (PlN  >ühilduinisvea !26_S	et	f	\N
176180	ühilduinisvead	?ühilduinisvead =ühilduinisvea  (SgP  >ühilduinisvea !26_S	et	f	\N
176181	ühilduinisvead	?ühilduinisvead =ühilduinisvead  (SgN  >ühilduinisvead !22_S	et	f	\N
176184	kümnete	kümnete =kümne  (PlG  >kümmend !05_N	et	f	\N
176185	kümnete	kümnete =kümne  (PlG  >kümme !05_N	et	f	\N
176186	üheteistkümnendal	?üheteistkümnendal =üheteistkümnenda  (SgAd  >üheteistkümnenda !16_S	et	f	\N
176187	üheteistkümnendal	?üheteistkümnendal =üheteistkümnendal  (SgN  >üheteistkümnendal !02_S	et	f	\N
176188	üheteistkümnendal	?üheteistkümnendal =kümnenda  (SgAd  >ühe+teist+kümnenda !01_S	et	f	\N
176189	üheteistkümnendal	?üheteistkümnendal =teistkümnenda  (SgAd  >ühe+teistkümnenda !16_S	et	f	\N
176190	üheteistkümnendal	?üheteistkümnendal =teistkümnendal  (SgN  >ühe+teistkümnendal !02_S	et	f	\N
176203	nukkrain	?nukkrain =nukkrain  (SgN  >nukkrain !22_S	et	f	\N
176204	nukkrain	?nukkrain =rain  (SgN  >nukk+rain !22_S	et	f	\N
176251	morfeemkoosseisu	?morfeemkoosseisu =morfeemkoosseisu  (IndPrPs_  >morfeemkoosseisuma !27_V	et	f	\N
176252	morfeemkoosseisu	?morfeemkoosseisu =morfeemkoosseisu  (ImpPrSg2  >morfeemkoosseisuma !27_V	et	f	\N
176265	viibimine	viibimine =viibimine  (SgN  >viibimine !12_S	et	f	\N
176266	viibimine	"viibimine %viibi  )MINE_vS  <viibima ;27_V	et	f	\N
176270	line	?line =line  (IndPrPs_  >linema !27_V	et	f	\N
176271	line	?line =line  (ImpPrSg2  >linema !27_V	et	f	\N
176272	väsimuse	väsimuse =väsimuse  (SgG  >väsimus !11_S	et	f	\N
176273	väsimuse	"väsimus %väsi  )MUS_vS  <väsima ;27_V	et	f	\N
176274	alatiharilikult	?alatiharilikult =alatihariliku  (SgAbl  >alatiharilik !25_A	et	f	\N
176275	alatiharilikult	?alatiharilikult =alatiharilikult  (ID  >alatiharilikult !41_D	et	f	\N
176276	alatiharilikult	?alatiharilikult =tihariliku  (SgAbl  >ala+tiharilik !25_A	et	f	\N
176280	tarvitamist	tarvitamist =tarvitamis  (SgP  >tarvitamine !12_S	et	f	\N
176281	tarvitamist	"tarvitamine %tarvita  )MINE_vS  <tarvitama ;27_V	et	f	\N
176290	kirjutatuid	kirjutatuid =kirjutatu  (PlP  >kirjutatu !01_S	et	f	\N
176291	kirjutatuid	"kirjutatu %kirjuta  )TU1_vS  <kirjutama ;27_V	et	f	\N
176324	cira	?cira =cira  (SgN  >cira !17_S	et	f	\N
176325	cira	?cira =cira  (SgG  >cira !17_S	et	f	\N
176326	cira	?cira =cira  (SgP  >cira !17_S	et	f	\N
176327	cira	?cira =cira  (IndPrPs_  >cirama !27_V	et	f	\N
176328	cira	?cira =cira  (ImpPrSg2  >cirama !27_V	et	f	\N
176331	reeglipäraseid	reeglipäraseid =pärase  (PlP  >reegli+pärane !10_A	et	f	\N
176332	reeglipäraseid	"reegli+pärane %pära  )NE_aA  <reegli+pära ;17_S	et	f	\N
176346	karpis	?karpis =karpi  (IndIpfSg3  >karpima !28_V	et	f	\N
176047	olekutseisundit	?olekutseisundit =tseisundi  (SgP  >oleku+tseisund !02_S	et	f	\N
176051	kohani	kohani =koha  (SgTer  >koha !17_S	et	f	\N
176052	kohani	kohani =koha  (SgTer  >koht !22_S	et	f	\N
176062	raskust	raskust =raskus  (SgP  >raskus !11~09_S	et	f	\N
176063	raskust	"raskus %raske  )US_aS  <raske ;01_A	et	f	\N
176064	raskust	raskust =raskus  (SgP  >raskune !12~10_A	et	f	\N
176078	üksiksunrmus	?üksiksunrmus =üksiksunrmu  (IndIpfSg3  >üksiksunrmuma !27_V	et	f	\N
176079	üksiksunrmus	?üksiksunrmus =üksiksunrmus  (SgN  >üksiksunrmus !11~09_S	et	f	\N
176080	üksiksunrmus	?üksiksunrmus =unrmu  (SgIn  >üks+iks+unrmu !01_S	et	f	\N
176081	üksiksunrmus	?üksiksunrmus =unrmus  (SgN  >üks+iks+unrmus !11~09_S	et	f	\N
176082	üksiksunrmus	?üksiksunrmus =sunrmu  (SgIn  >üksik+sunrmu !01_S	et	f	\N
176083	üksiksunrmus	?üksiksunrmus =sunrmus  (SgN  >üksik+sunrmus !11~09_S	et	f	\N
176084	üksiksunrmus	?üksiksunrmus =ksunrmu  (SgIn  >üksi+ksunrmu !01_S	et	f	\N
176085	üksiksunrmus	?üksiksunrmus =ksunrmus  (SgN  >üksi+ksunrmus !11~09_S	et	f	\N
176086	üksiksunrmus	?üksiksunrmus =iksunrmu  (SgIn  >üks+iksunrmu !01_S	et	f	\N
176087	üksiksunrmus	?üksiksunrmus =iksunrmus  (SgN  >üks+iksunrmus !11~09_S	et	f	\N
176093	20-aastane	-aastane =aastane  (SgN  >-aastane !12~10_A	et	f	\N
176094	20-aastane	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
176106	keeltekool	keeltekool =koo  (SgAd  >keelte+kubu !18_S	et	f	\N
176107	keeltekool	keeltekool =kool  (SgN  >keelte+kool !22_S	et	f	\N
176109	ik42	### ik42	et	f	\N
176132	11antut	antut =antu  (SgP  >antu !01_S	et	f	\N
176133	11antut	"antu %an  )TU1_vS  <andma ;34_V	et	f	\N
176151	20ei	ei =ei  (Neg  >ei !--_V	et	f	\N
176152	20ei	ei =ei  (ID  >ei !41_D	et	f	\N
176159	käändevea	?käändevea =käändevea  (SgN  >käändevea !26_S	et	f	\N
176160	käändevea	?käändevea =käändevea  (SgG  >käändevea !26_S	et	f	\N
176161	käändevea	?käändevea =evea  (SgN  >käänd+evea !26_S	et	f	\N
176162	käändevea	?käändevea =evea  (SgG  >käänd+evea !26_S	et	f	\N
176166	õel	õel =õe  (SgAd  >õde !18_S	et	f	\N
176167	õel	õel =õel  (SgN  >õel !02_A	et	f	\N
176168	cnpocu	?cnpocu =cnpocu  (SgN  >cnpocu !16_S	et	f	\N
176169	cnpocu	?cnpocu =cnpocu  (SgG  >cnpocu !16_S	et	f	\N
176172	suvalist	suvalist =suvalis  (SgP  >suvaline !12_A	et	f	\N
176173	suvalist	"suvaline %suva  )LINE_aA  <suva ;17_S	et	f	\N
176191	kümnesed	kümnesed =kümnese  (PlN  >kümnene !10~12_AS	et	f	\N
176192	kümnesed	"kümnene %kümne  )NE_aA  <kümme ;05_N	et	f	\N
176198	tuletatav	tuletatav =tuleta  (PtsPrIps  >tuletama !27_V	et	f	\N
176200	tuletatav	tuletatav =tuletatav  (SgN  >tuletatav !02_A	et	f	\N
176201	tuletatav	"tuletatav %tuleta  )TAV_vAS  <tuletama ;27_V	et	f	\N
176214	lähinenud	?lähinenud =lähine  (PtsPtPs  >lähinema !27_V	et	f	\N
176215	lähinenud	?lähinenud =lähinenu  (PlN  >lähinenu !01_S	et	f	\N
176216	lähinenud	?lähinenud =lähinenu  (IndPrSg2  >lähinenuma !27_V	et	f	\N
176217	lähinenud	?lähinenud =lähinenud  (ID  >lähinenud !41_A	et	f	\N
176218	lähinenud	?lähinenud =nenu  (PlN  >lähi+nenu !17_S	et	f	\N
176229	reeglipärase	reeglipärase =pärase  (SgG  >reegli+pärane !10_A	et	f	\N
176230	reeglipärase	"reegli+pärane %pära  )NE_aA  <reegli+pära ;17_S	et	f	\N
176231	ebareeglipäraseid	ebareeglipäraseid =pärase  (PlP  >eba+reegli+pärane !10_A	et	f	\N
176232	ebareeglipäraseid	"eba+reegli+pärane %pära  )NE_aA  <eba+reegli+pära ;17_S	et	f	\N
176245	kitsemalt	?kitsemalt =kitsema  (SgAbl  >kitsem !02_A	et	f	\N
176246	kitsemalt	?kitsemalt =kitsemalt  (ID  >kitsemalt !41_D	et	f	\N
176247	kitsemalt	?kitsemalt =malt  (SgN  >kitse+malt !22_S	et	f	\N
176277	malli	malli =malli  (SgG  >mall !22_S	et	f	\N
176278	malli	malli =malli  (SgP  >mall !22_S	et	f	\N
176279	malli	malli =malli  (SgAdt  >mall !22_S	et	f	\N
176292	argikeelest	argikeelest =keele  (SgEl  >argi+keel !13_S	et	f	\N
176293	argikeelest	argikeelest =keele  (PlEl  >argi+keeld !22_S	et	f	\N
176294	argikeelest	argikeelest =keeles  (SgP  >argi+keelene !10_A	et	f	\N
176295	argikeelest	"argi+keelene %keele  )NE_aA  <argi+keel ;13_S	et	f	\N
176296	toanaabritelt	toanaabritelt =brite  (PlAbl  >toa+naa+britt !22_S	et	f	\N
176297	toanaabritelt	toanaabritelt =naabri  (PlAbl  >toa+naaber !02_S	et	f	\N
176298	teisti	teisti =teisti  (SgG  >teist !22_S	et	f	\N
176299	teisti	teisti =teisti  (SgP  >teist !22_S	et	f	\N
176300	teisti	teisti =teisti  (SgAdt  >teist !22_S	et	f	\N
176306	täiendeid	täiendeid =täiende  (PlP  >täiend !02_S	et	f	\N
176307	täiendeid	täiendeid =ende  (PlP  >täi+enne !06_S	et	f	\N
176311	vääralt	vääralt =väära  (SgAbl  >väär !02_A	et	f	\N
176312	vääralt	vääralt =väära  (SgAbl  >väär !22_S	et	f	\N
176313	vääralt	vääralt =väära  (SgAbl  >väär !22_A	et	f	\N
176314	vääralt	vääralt =vääralt  (ID  >vääralt !41_D	et	f	\N
176315	vääralt	"vääralt %väära  )LT_mD  <väär ;02_A	et	f	\N
176317	vääralt	"vääralt %väära  )LT_mD  <väär ;22_A	et	f	\N
176318	vääralt	vääralt =alt  (SgN  >väär+alt !22_S	et	f	\N
176342	raioonis	?raioonis =raiooni  (SgIn  >raiooni !16_S	et	f	\N
176343	raioonis	?raioonis =raiooni  (SgIn  >raioon !22_S	et	f	\N
176165	sõltuvadki	"sõltuv %sõltu  )V_vA^  <sõltuma ;27_V	et	f	\N
176174	õpetaja-	õpetaja- =õpetaja  (SgN  >õpetaja !01_S	et	f	\N
176175	õpetaja-	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
176176	õpetaja-	õpetaja- =õpetaja  (SgG  >õpetaja !01_S	et	f	\N
176182	sajased	sajased =sajase  (PlN  >sajane !10_AS	et	f	\N
176183	sajased	"sajane %saja  )NE_aA  <sada ;18_N	et	f	\N
176208	testides	testides =testi  (PlIn  >test !22_S	et	f	\N
176209	testides	testides =testi  (Ger  >testima !28_V	et	f	\N
176240	kõrvaldamiseks	kõrvaldamiseks =kõrvaldamise  (SgTr  >kõrvaldamine !12_S	et	f	\N
176241	kõrvaldamiseks	"kõrvaldamine %kõrvalda  )MINE_vS  <kõrvaldama ;27_V	et	f	\N
176248	sõnasemantika	sõnasemantika =semantika  (SgN  >sõna+semantika !01_S	et	f	\N
176249	sõnasemantika	sõnasemantika =semantika  (SgG  >sõna+semantika !01_S	et	f	\N
176253	ajamist	ajamist =ajami  (SgEl  >ajam !02_S	et	f	\N
176254	ajamist	ajamist =ajamis  (SgP  >ajamine !12_S	et	f	\N
176255	ajamist	"ajamine %aja  )MINE_vS  <ajama ;27_V	et	f	\N
176256	ajamist	"ajamine %ajami  )NE_aA  <ajam ;02_S	et	f	\N
176257	väline	väline =väline  (SgN  >väline !10_A	et	f	\N
176258	väline	"väline %väli  )NE_aA  <väli ;24_S	et	f	\N
176267	kuulmismälu	kuulmismälu =mälu  (SgN  >kuul+mis+mälu !17_S	et	f	\N
176268	kuulmismälu	kuulmismälu =mälu  (SgG  >kuul+mis+mälu !17_S	et	f	\N
176269	kuulmismälu	kuulmismälu =mälu  (SgP  >kuul+mis+mälu !17_S	et	f	\N
176282	lõpetatust	lõpetatust =lõpetatu  (SgEl  >lõpetatu !01_S	et	f	\N
176283	lõpetatust	"lõpetatu %lõpeta  )TU1_vS  <lõpetama ;27_V	et	f	\N
176284	lõpetatust	lõpetatust =lõpetatus  (SgP  >lõpetatus !11?09_S	et	f	\N
176285	lõpetatust	"lõpetatus %lõpeta  )TUS1_aS  <lõpetama ;27_V	et	f	\N
176286	selmet	?selmet =selme  (SgP  >selme !06_S	et	f	\N
176308	polüseeme	?polüseeme =polüseeme  (SgN  >polüseeme !16_S	et	f	\N
176309	polüseeme	?polüseeme =polüseeme  (SgG  >polüseeme !16_S	et	f	\N
176310	polüseeme	?polüseeme =polüseeme  (PlP  >polüseem !22_S	et	f	\N
176316	pruukida	pruukida =pruuki  (Inf  >pruukima !28_V	et	f	\N
176319	pruukida	pruukida =kida  (SgN  >pruu+kida !17_S	et	f	\N
176320	pruukida	pruukida =kida  (SgG  >pruu+kida !17_S	et	f	\N
176321	pruukida	pruukida =kida  (SgP  >pruu+kida !17_S	et	f	\N
176335	kadutöö	?kadutöö =kadutöö  (SgN  >kadutöö !26_S	et	f	\N
176336	kadutöö	?kadutöö =kadutöö  (SgG  >kadutöö !26_S	et	f	\N
176354	üla	?üla =üla  (SgN  >üla !17_S	et	f	\N
176355	üla	?üla =üla  (SgG  >üla !17_S	et	f	\N
176356	üla	?üla =üla  (SgP  >üla !17_S	et	f	\N
176357	üla	?üla =üla  (IndPrPs_  >ülama !27_V	et	f	\N
176358	üla	?üla =üla  (ImpPrSg2  >ülama !27_V	et	f	\N
176391	obiekti	?obiekti =obiekti  (SgG  >obiekt !22_S	et	f	\N
176392	obiekti	?obiekti =obiekti  (SgP  >obiekt !22_S	et	f	\N
176393	obiekti	?obiekti =obiekti  (SgAdt  >obiekt !22_S	et	f	\N
176394	obiekti	?obiekti =obiekti  (IndPrPs_  >obiektima !28_V	et	f	\N
176395	obiekti	?obiekti =obiekti  (ImpPrSg2  >obiektima !28_V	et	f	\N
176398	ühildumisel	ühildumisel =ühildumise  (SgAd  >ühildumine !12_S	et	f	\N
176399	ühildumisel	"ühildumine %ühildu  )MINE_vS  <ühilduma ;27_V	et	f	\N
176435	suvises	suvises =suvise  (SgIn  >suvine !10_A	et	f	\N
176436	suvises	"suvine %suvi  )NE_aA  <suvi ;20_S	et	f	\N
176452	eelnev	eelnev =eelne  (PtsPrPs  >eelnema !27_V	et	f	\N
176453	eelnev	eelnev =eelnev  (SgN  >eelnev !02_A	et	f	\N
176454	eelnev	"eelnev %eelne  )V_vA  <eelnema ;27_V	et	f	\N
176477	oppeaastal	?oppeaastal =oppeaasta  (SgAd  >oppeaasta !16_S	et	f	\N
176478	oppeaastal	?oppeaastal =oppeaastal  (SgN  >oppeaastal !02_S	et	f	\N
176519	monede	?monede =mone  (PlG  >mone !16_S	et	f	\N
176535	inti	?inti =inti  (ID  >inti !41_D	et	f	\N
176536	inti	?inti =inti  (SgP  >int !22_S	et	f	\N
176537	inti	?inti =inti  (SgAdt  >int !22_S	et	f	\N
176543	kin	### kin	et	f	\N
176547	uagu	?uagu =uagu  (SgN  >uagu !16_S	et	f	\N
176548	uagu	?uagu =uagu  (SgG  >uagu !16_S	et	f	\N
176549	uagu	?uagu =uagu  (IndPrPs_  >uaguma !27_V	et	f	\N
176550	uagu	?uagu =uagu  (IndPrPs_  >uakuma !28_V	et	f	\N
176551	uagu	?uagu =uagu  (ImpPrSg2  >uaguma !27_V	et	f	\N
176552	uagu	?uagu =uagu  (ImpPrSg2  >uakuma !28_V	et	f	\N
176571	sonajarjega	### sonajarjega	et	f	\N
176589	obiektivead	?obiektivead =obiektivea  (PlN  >obiektivea !26_S	et	f	\N
176590	obiektivead	?obiektivead =obiektivea  (SgP  >obiektivea !26_S	et	f	\N
176591	obiektivead	?obiektivead =obiektivead  (SgN  >obiektivead !22_S	et	f	\N
176601	kaandevalikuga	?kaandevalikuga =kaandevaliku  (SgKom  >kaandevalik !25_A	et	f	\N
176604	abimaarsonade	### abimaarsonade	et	f	\N
176611	kusimusi	?kusimusi =kusimusi  (PlP  >kusimus !11_S	et	f	\N
176631	naidet	?naidet =naide  (SgP  >naide !06_S	et	f	\N
176635	kulzld	?kulzld =kulzld  (SgN  >kulzld !22_S	et	f	\N
176638	sonatasand	?sonatasand =sonatasand  (SgN  >sonatasand !22_S	et	f	\N
176663	nadalavahetus	?nadalavahetus =nadalavahetu  (SgIn  >nadalavahetu !01_A	et	f	\N
176664	nadalavahetus	?nadalavahetus =nadalavahetu  (IndIpfSg3  >nadalavahetuma !27_V	et	f	\N
176665	nadalavahetus	?nadalavahetus =nadalavahetus  (SgN  >nadalavahetus !11?09_S	et	f	\N
176344	raioonis	?raioonis =raiooni  (IndIpfSg3  >raioonima !28_V	et	f	\N
176345	raioonis	?raioonis =raioonis  (SgN  >raioonis !09_S	et	f	\N
176352	lasnamäelvõib	?lasnamäelvõib =lasnamäelvõib  (SgN  >lasnamäelvõib !22_S	et	f	\N
176353	lasnamäelvõib	?lasnamäelvõib =mäelvõib  (SgN  >lasna+mäelvõib !22_S	et	f	\N
176365	valiskohakaaneteks	?valiskohakaaneteks =valiskohakaanete  (PlTr  >valiskohakaanett !22_S	et	f	\N
176373	ja-da-infinitiivi	ja-da-infinitiivi =infinitiivi  (SgG  >ja-da-infinitiiv !22_S	et	f	\N
176374	ja-da-infinitiivi	ja-da-infinitiivi =infinitiivi  (SgP  >ja-da-infinitiiv !22_S	et	f	\N
176375	ja-da-infinitiivi	ja-da-infinitiivi =infinitiivi  (SgAdt  >ja-da-infinitiiv !22_S	et	f	\N
176376	mõteldu	mõteldu =mõteldu  (SgN  >mõteldu !01_S	et	f	\N
176377	mõteldu	"mõteldu %mõtel  )TU1_vS  <mõtlema ;30_V	et	f	\N
176378	mõteldu	mõteldu =mõteldu  (SgG  >mõteldu !01_S	et	f	\N
176386	ebaõiasus	?ebaõiasus =ebaõiasu  (IndIpfSg3  >ebaõiasuma !27_V	et	f	\N
176387	ebaõiasus	?ebaõiasus =ebaõiasus  (SgN  >ebaõiasus !11~09_S	et	f	\N
176388	ebaõiasus	?ebaõiasus =õiasu  (SgIn  >eba+õiasu !01_S	et	f	\N
176389	ebaõiasus	?ebaõiasus =õiasus  (SgN  >eba+õiasus !11_S	et	f	\N
176415	astmevaheldusreeglite	?astmevaheldusreeglite =astmevaheldusreegli  (PlG  >astmevaheldusreegel !02_S	et	f	\N
176416	astmevaheldusreeglite	?astmevaheldusreeglite =astmevaheldusreegli  (IndPrPl2  >astmevaheldusreeglima !28_V	et	f	\N
176417	mitte-tundmisest	mitte-tundmisest =tundmise  (SgEl  >mitte-tundmine !12?10_S	et	f	\N
176418	mitte-tundmisest	"mitte-tundmine %tund  )MINE_vS  <mitte-tundma ;34_V	et	f	\N
176419	kiriutamise	?kiriutamise =kiriutamise  (SgG  >kiriutamine !12_S	et	f	\N
176420	kiriutamise	?kiriutamise =utamise  (SgG  >kiri+utamine !12_S	et	f	\N
176437	kiriutatud	?kiriutatud =kiriuta  (PtsPtIps  >kiriutama !27_V	et	f	\N
176438	kiriutatud	?kiriutatud =kiriutatu  (PlN  >kiriutatu !01_S	et	f	\N
176439	kiriutatud	?kiriutatud =kiriutatu  (IndPrSg2  >kiriutatuma !27_V	et	f	\N
176440	kiriutatud	?kiriutatud =kiriutatud  (ID  >kiriutatud !41_A	et	f	\N
176441	kiriutatud	?kiriutatud =utatu  (PlN  >kiri+utatu !01_S	et	f	\N
176484	kaasuliopilastega	?kaasuliopilastega =kaasuliopilas  (PlKom  >kaasuliopilane !12_S	et	f	\N
176485	kaasuliopilastega	?kaasuliopilastega =uliopilas  (PlKom  >kaas+uliopilane !12_S	et	f	\N
176486	opitud	?opitud =opi  (PtsPtIps  >opima !27_V	et	f	\N
176487	opitud	?opitud =opi  (PtsPtIps  >oppima !28_V	et	f	\N
176488	opitud	?opitud =opitu  (PlN  >opitu !01_AS	et	f	\N
176489	opitud	?opitud =opitu  (IndPrSg2  >opituma !27_V	et	f	\N
176490	opitud	?opitud =opitud  (ID  >opitud !41_A	et	f	\N
176491	konekeelsed	?konekeelsed =konekeelse  (PlN  >konekeelne !02_A	et	f	\N
176492	konekeelele	?konekeelele =konekeele  (SgAll  >konekeele !16_S	et	f	\N
176493	konekeelele	?konekeelele =konekeele  (PlAll  >konekeel !22_S	et	f	\N
176494	o-kasutamine	o-kasutamine =kasutamine  (SgN  >o-kasutamine !12_S	et	f	\N
176495	o-kasutamine	"o-kasutamine %kasuta  )MINE_vS  <o-kasutama ;27_V	et	f	\N
176508	analuusima	?analuusima =analuusi  (Sup  >analuusima !28_V	et	f	\N
176509	analuusima	?analuusima =analuusima  (SgG  >analuusim !02_A	et	f	\N
176512	mlilje	?mlilje =mlilje  (SgN  >mlilje !06_S	et	f	\N
176513	mlilje	?mlilje =mlilje  (SgG  >mlilje !06_S	et	f	\N
176514	mlilje	?mlilje =mlilje  (IndPrPs_  >mliljema !27_V	et	f	\N
176515	mlilje	?mlilje =mlilje  (ImpPrSg2  >mliljema !27_V	et	f	\N
176520	pohjusi	?pohjusi =pohjusi  (ID  >pohjusi !41_D	et	f	\N
176521	pohjusi	?pohjusi =pohjusi  (PlP  >pohjus !11_S	et	f	\N
176522	valismaalasele	?valismaalasele =valismaalase  (SgAll  >valismaalane !12?10_S	et	f	\N
176528	markinud	?markinud =marki  (PtsPtPs  >markima !28_V	et	f	\N
176529	markinud	?markinud =markinu  (PlN  >markinu !01_S	et	f	\N
176530	markinud	?markinud =markinu  (IndPrSg2  >markinuma !27_V	et	f	\N
176531	markinud	?markinud =markinud  (ID  >markinud !41_A	et	f	\N
176538	vaipczde	?vaipczde =vaipczde  (SgN  >vaipczde !06_S	et	f	\N
176539	vaipczde	?vaipczde =vaipczde  (SgG  >vaipczde !06_S	et	f	\N
176540	vaipczde	?vaipczde =vaipczde  (PlP  >vaipczd !22_S	et	f	\N
176541	vaipczde	?vaipczde =vaipczde  (IndPrPs_  >vaipczdema !27_V	et	f	\N
176542	vaipczde	?vaipczde =vaipczde  (ImpPrSg2  >vaipczdema !27_V	et	f	\N
176544	kokkuvotvalt	?kokkuvotvalt =kokkuvotva  (SgAbl  >kokkuvotva !16_S	et	f	\N
176545	kokkuvotvalt	?kokkuvotvalt =kokkuvotvalt  (ID  >kokkuvotvalt !41_D	et	f	\N
176546	kokkuvotvalt	?kokkuvotvalt =votva  (SgAbl  >kokku+votva !16_S	et	f	\N
176559	oigekirjavead	?oigekirjavead =oigekirjavea  (PlN  >oigekirjavea !26_S	et	f	\N
176560	oigekirjavead	?oigekirjavead =oigekirjavea  (SgP  >oigekirjavea !26_S	et	f	\N
176561	oigekirjavead	?oigekirjavead =oigekirjavead  (SgN  >oigekirjavead !22_S	et	f	\N
176565	votmu	?votmu =votmu  (SgN  >votmu !16_S	et	f	\N
176566	votmu	?votmu =votmu  (SgG  >votmu !16_S	et	f	\N
176567	votmu	?votmu =votmu  (IndPrPs_  >votmuma !27_V	et	f	\N
176568	votmu	?votmu =votmu  (ImpPrSg2  >votmuma !27_V	et	f	\N
176574	uczipade	### uczipade	et	f	\N
176593	kdsitse	?kdsitse =kdsitse  (SgN  >kdsitse !06_S	et	f	\N
176595	kdsitse	?kdsitse =kdsitse  (SgG  >kdsitne !02_A	et	f	\N
176596	kdsitse	?kdsitse =kdsitse  (SgG  >kdsitse !06_S	et	f	\N
176597	kdsitse	?kdsitse =kdsitse  (PlP  >kdsits !22_S	et	f	\N
176598	kdsitse	?kdsitse =kdsitse  (IndPrPs_  >kdsitsema !28_V	et	f	\N
176347	karpis	?karpis =karpis  (ID  >karpis !41_DA	et	f	\N
176359	hakkada	?hakkada =ada  (SgN  >hakk+ada !17_S	et	f	\N
176360	hakkada	?hakkada =ada  (SgG  >hakk+ada !17_S	et	f	\N
176361	hakkada	?hakkada =ada  (SgP  >hakk+ada !17_S	et	f	\N
176366	tenninatiivi	?tenninatiivi =tenninatiivi  (SgN  >tenninatiivi !16_S	et	f	\N
176367	tenninatiivi	?tenninatiivi =tenninatiivi  (SgG  >tenninatiivi !16_S	et	f	\N
176368	tenninatiivi	?tenninatiivi =tenninatiivi  (SgG  >tenninatiiv !22_S	et	f	\N
176369	tenninatiivi	?tenninatiivi =tenninatiivi  (SgP  >tenninatiiv !22_S	et	f	\N
176370	tenninatiivi	?tenninatiivi =tenninatiivi  (SgAdt  >tenninatiiv !22_S	et	f	\N
176371	tenninatiivi	?tenninatiivi =tenninatiivi  (IndPrPs_  >tenninatiivima !28_V	et	f	\N
176372	tenninatiivi	?tenninatiivi =tenninatiivi  (ImpPrSg2  >tenninatiivima !28_V	et	f	\N
176379	koostata	koostata =koosta  (SgAb  >koost !22_S	et	f	\N
176380	koostata	koostata =koosta  (IndPrIps_  >koostama !27_V	et	f	\N
176396	sihilise	sihilise =sihilise  (SgG  >sihiline !12_A	et	f	\N
176397	sihilise	"sihiline %sihi  )LINE_aA  <siht ;22_S	et	f	\N
176404	saamaoskamavõima	### saamaoskamavõima	et	f	\N
176405	vuhul	?vuhul =vuhu  (SgAd  >vuhu !17_S	et	f	\N
176406	vuhul	?vuhul =vuhul  (SgN  >vuhul !02_S	et	f	\N
176410	mõiust	?mõiust =mõiu  (SgEl  >mõiu !16_S	et	f	\N
176411	mõiust	?mõiust =mõius  (SgP  >mõius !11~09_S	et	f	\N
176412	vormimoodustusvigu	?vormimoodustusvigu =vormimoodustusvi  (ImpPrPs  >vormimoodustusvima !28_V	et	f	\N
176413	vormimoodustusvigu	?vormimoodustusvigu =vormimoodustusvigu  (IndPrPs_  >vormimoodustusviguma !27_V	et	f	\N
176414	vormimoodustusvigu	?vormimoodustusvigu =vormimoodustusvigu  (ImpPrSg2  >vormimoodustusviguma !27_V	et	f	\N
176421	vähesusest	?vähesusest =vähesuse  (SgEl  >vähesus !11_S	et	f	\N
176422	vähesusest	?vähesusest =vähesuses  (SgP  >vähesusene !12_A	et	f	\N
176423	vähesusest	?vähesusest =suse  (SgEl  >vähe+suse !16_S	et	f	\N
176424	vähesusest	?vähesusest =suses  (SgP  >vähe+suses !09_S	et	f	\N
176425	vähesusest	?vähesusest =suses  (SgP  >vähe+susene !10_A	et	f	\N
176426	õppiva	õppiva =õppiva  (SgG  >õppiv !02_A	et	f	\N
176427	õppiva	"õppiv %õppi  )V_vA  <õppima ;28_V	et	f	\N
176430	kirialikest	?kirialikest =kirialike  (PlEl  >kirialik !25_A	et	f	\N
176431	kirialikest	?kirialikest =kirialikes  (SgP  >kirialike !12_S	et	f	\N
176432	kirialikest	?kirialikest =kirialikes  (SgP  >kirialikene !12_S	et	f	\N
176433	kirialikest	?kirialikest =alikes  (SgP  >kiri+alike !12_S	et	f	\N
176434	kirialikest	?kirialikest =alikes  (SgP  >kiri+alikene !12_S	et	f	\N
176445	iuba	?iuba =iuba  (SgN  >iuba !16_S	et	f	\N
176446	iuba	?iuba =iuba  (SgG  >iuba !16_S	et	f	\N
176447	iuba	?iuba =iuba  (IndPrPs_  >iubama !29_V	et	f	\N
176448	iuba	?iuba =iuba  (ImpPrSg2  >iubama !29_V	et	f	\N
176467	oppetool	?oppetool =oppetoo  (SgAd  >oppetoo !26_S	et	f	\N
176468	oppetool	?oppetool =oppetool  (SgN  >oppetool !22_S	et	f	\N
176472	pohineb	?pohineb =pohine  (IndPrSg3  >pohinema !27_V	et	f	\N
176473	tuukka	?tuukka =tuukka  (SgN  >tuukka !01_S	et	f	\N
176474	tuukka	?tuukka =tuukka  (SgG  >tuukka !01_S	et	f	\N
176475	tuukka	?tuukka =tuukka  (IndPrPs_  >tuukkama !29_V	et	f	\N
176476	tuukka	?tuukka =tuukka  (ImpPrSg2  >tuukkama !29_V	et	f	\N
176507	t-1	### t-1	et	f	\N
176572	markima	?markima =marki  (Sup  >markima !28_V	et	f	\N
176573	markima	?markima =markima  (SgG  >markim !02_A	et	f	\N
176575	paevavalgus	?paevavalgus =paevavalgu  (IndIpfSg3  >paevavalguma !27_V	et	f	\N
176576	paevavalgus	?paevavalgus =paevavalgus  (SgN  >paevavalgus !11~09_S	et	f	\N
176577	paevavalgus	?paevavalgus =vavalgus  (SgN  >pae+vavalgus !11_S	et	f	\N
176578	mojutanud	?mojutanud =mojuta  (PtsPtPs  >mojutama !27_V	et	f	\N
176579	mojutanud	?mojutanud =mojutanu  (PlN  >mojutanu !01_S	et	f	\N
176580	mojutanud	?mojutanud =mojutanu  (IndPrSg2  >mojutanuma !27_V	et	f	\N
176581	mojutanud	?mojutanud =mojutanud  (ID  >mojutanud !41_A	et	f	\N
176586	ohtul	?ohtul =ohtul  (SgN  >ohtul !02_S	et	f	\N
176592	kuncz	### kuncz	et	f	\N
176594	tegemcz	### tegemcz	et	f	\N
176605	nuiid	?nuiid =nuii  (PlN  >nuii !26_S	et	f	\N
176606	nuiid	?nuiid =nuii  (SgP  >nuii !26_S	et	f	\N
176607	nuiid	?nuiid =nuiid  (SgN  >nuiid !22_S	et	f	\N
176610	uhendverb	?uhendverb =uhendverb  (SgN  >uhendverb !22_S	et	f	\N
176612	tyo	?tyo =tyo  (SgN  >tyo !26_S	et	f	\N
176613	tyo	?tyo =tyo  (SgG  >tyo !26_S	et	f	\N
176653	konekeelest	?konekeelest =konekeele  (SgEl  >konekeele !16_S	et	f	\N
176654	konekeelest	?konekeelest =konekeele  (PlEl  >konekeel !22_S	et	f	\N
176655	konekeelest	?konekeelest =konekeeles  (SgP  >konekeelene !10_A	et	f	\N
176666	voimalikust	?voimalikust =voimaliku  (SgEl  >voimalik !25_A	et	f	\N
176667	voimalikust	?voimalikust =voimalikus  (SgP  >voimalikus !11?09_S	et	f	\N
176668	pkevavalgus	?pkevavalgus =pkevavalgu  (IndIpfSg3  >pkevavalguma !27_V	et	f	\N
176669	pkevavalgus	?pkevavalgus =pkevavalgus  (SgN  >pkevavalgus !11~09_S	et	f	\N
176670	saub	?saub =saub  (SgN  >saub !22_S	et	f	\N
176673	sonavead	?sonavead =sonavea  (PlN  >sonavea !26_S	et	f	\N
176674	sonavead	?sonavead =sonavea  (SgP  >sonavea !26_S	et	f	\N
176675	sonavead	?sonavead =sonavead  (SgN  >sonavead !22_S	et	f	\N
176703	dill	?dill =dill  (SgN  >dill !22_S	et	f	\N
176363	kolmekorruselines	?kolmekorruselines =korruseline  (PlIn  >kolme+korruselin !19_S	et	f	\N
176364	kolmekorruselines	?kolmekorruselines =ekorruseline  (PlIn  >kolm+ekorruselin !19_S	et	f	\N
176381	saaeli	?saaeli =saaeli  (SgN  >saaeli !01_S	et	f	\N
176382	saaeli	?saaeli =saaeli  (SgG  >saaeli !01_S	et	f	\N
176383	saaeli	?saaeli =saaeli  (SgG  >saael !02_S	et	f	\N
176384	saaeli	?saaeli =saaeli  (IndPrPs_  >saaelima !28_V	et	f	\N
176385	saaeli	?saaeli =saaeli  (ImpPrSg2  >saaelima !28_V	et	f	\N
176390	põhiustab	?põhiustab =põhiusta  (IndPrSg3  >põhiustama !27_V	et	f	\N
176400	puudutavas	puudutavas =puudutava  (SgIn  >puudutav !02_A	et	f	\N
176401	puudutavas	"puudutav %puudu  )TAV_vAS  <puuduma ;27_V	et	f	\N
176402	puudutavas	"puudutav %puuduta  )V_vA  <puudutama ;27_V	et	f	\N
176403	puudutavas	puudutavas =tava  (SgIn  >puudu+tava !17_S	et	f	\N
176428	võtva	võtva =võtva  (SgG  >võttev !02_A	et	f	\N
176429	võtva	"võttev %võtt  )V_vA  <võtma ;35_V	et	f	\N
176455	saavutasid	saavutasid =saavuta  (IndIpfSg2  >saavutama !27_V	et	f	\N
176456	saavutasid	saavutasid =saavuta  (IndIpfPl3  >saavutama !27_V	et	f	\N
176457	suhtlemisiulguse	?suhtlemisiulguse =suhtlemisiulguse  (SgG  >suhtlemisiulgus !11~09_S	et	f	\N
176458	suhtlemisiulguse	?suhtlemisiulguse =lemisiulguse  (SgG  >suht+lemisiulgus !11~09_S	et	f	\N
176496	voimaldanud	?voimaldanud =voimalda  (PtsPtPs  >voimaldama !27_V	et	f	\N
176497	voimaldanud	?voimaldanud =voimaldanu  (PlN  >voimaldanu !01_S	et	f	\N
176498	voimaldanud	?voimaldanud =voimaldanu  (IndPrSg2  >voimaldanuma !27_V	et	f	\N
176499	voimaldanud	?voimaldanud =voimaldanud  (ID  >voimaldanud !41_A	et	f	\N
176510	e-kirj	### e-kirj	et	f	\N
176516	pohjustatuteks	?pohjustatuteks =pohjustatu  (PlTr  >pohjustatu !01_S	et	f	\N
176517	pohjustatuteks	?pohjustatuteks =pohjustatute  (PlTr  >pohjustatutt !22_S	et	f	\N
176523	monigi	?monigi =moni  (SgN^  >moni !17_S	et	f	\N
176524	monigi	?monigi =moni  (SgG^  >moni !17_S	et	f	\N
176525	monigi	?monigi =moni  (SgP^  >moni !17_S	et	f	\N
176526	monigi	?monigi =moni  (IndPrPs_^  >monima !27_V	et	f	\N
176527	monigi	?monigi =moni  (ImpPrSg2^  >monima !27_V	et	f	\N
176585	tdncz	### tdncz	et	f	\N
176602	lseenesest	?lseenesest =lseenese  (SgEl  >lseenene !10_A	et	f	\N
176603	lseenesest	?lseenesest =lseeneses  (SgP  >lseenesene !12_A	et	f	\N
176608	abimaarsona	?abimaarsona =abimaarso  (SgEs  >abimaarso !16_S	et	f	\N
176609	abimaarsona	?abimaarsona =maarso  (SgEs  >abi+maarso !16_S	et	f	\N
176619	kaassona	?kaassona =kaasso  (SgEs  >kaasso !16_S	et	f	\N
176620	kaassona	?kaassona =sona  (SgN  >kaas+sona !17_S	et	f	\N
176621	kaassona	?kaassona =sona  (SgG  >kaas+sona !17_S	et	f	\N
176622	kaassona	?kaassona =sona  (SgP  >kaas+sona !17_S	et	f	\N
176636	toenaosusega	?toenaosusega =toenaosuse  (SgKom  >toenaosus !11_S	et	f	\N
176637	toenaosusega	?toenaosusega =naosuse  (SgKom  >toe+naosus !11~09_S	et	f	\N
176643	iihe	?iihe =iihe  (SgN  >iihe !06_S	et	f	\N
176644	iihe	?iihe =iihe  (SgG  >iihe !06_S	et	f	\N
176645	iihe	?iihe =iihe  (IndPrPs_  >iihema !27_V	et	f	\N
176646	iihe	?iihe =iihe  (ImpPrSg2  >iihema !27_V	et	f	\N
176647	jou	?jou =jou  (SgN  >jou !26_S	et	f	\N
176648	jou	?jou =jou  (SgG  >jou !26_S	et	f	\N
176680	kid	### kid	et	f	\N
176681	pohjustanud	?pohjustanud =pohjusta  (PtsPtPs  >pohjustama !27_V	et	f	\N
176682	pohjustanud	?pohjustanud =pohjustanu  (PlN  >pohjustanu !01_S	et	f	\N
176683	pohjustanud	?pohjustanud =pohjustanu  (IndPrSg2  >pohjustanuma !27_V	et	f	\N
176684	pohjustanud	?pohjustanud =pohjustanud  (ID  >pohjustanud !41_A	et	f	\N
176686	taielikult	?taielikult =taieliku  (SgAbl  >taielik !25_A	et	f	\N
176687	taielikult	?taielikult =taielikult  (ID  >taielikult !41_D	et	f	\N
176688	taielikult	?taielikult =eliku  (SgAbl  >tai+eliku !01_S	et	f	\N
176689	hooletlisvea	?hooletlisvea =hooletlisvea  (SgN  >hooletlisvea !26_S	et	f	\N
176690	hooletlisvea	?hooletlisvea =hooletlisvea  (SgG  >hooletlisvea !26_S	et	f	\N
176691	hooletlisvea	?hooletlisvea =letlisvea  (SgN  >hoo+letlisvea !26_S	et	f	\N
176692	hooletlisvea	?hooletlisvea =letlisvea  (SgG  >hoo+letlisvea !26_S	et	f	\N
176696	ullatav	?ullatav =ulla  (PtsPrIps  >uldama !29_V	et	f	\N
176697	ullatav	?ullatav =ullata  (PtsPrPs  >ullatama !27_V	et	f	\N
176698	ullatav	?ullatav =ullatav  (SgN  >ullatav !02_A	et	f	\N
176711	kaest	kaest =kae  (SgEl  >kae !26_S	et	f	\N
176712	kaest	kaest =kaes  (SgP  >kaene !10_A	et	f	\N
176713	kaest	"kaene %kae  )NE_aA  <kae ;26_S	et	f	\N
176720	interjoori	?interjoori =interjoori  (SgN  >interjoori !16_S	et	f	\N
176721	interjoori	?interjoori =interjoori  (SgG  >interjoori !16_S	et	f	\N
176722	interjoori	?interjoori =interjoori  (SgG  >interjoor !22_S	et	f	\N
176723	interjoori	?interjoori =interjoori  (SgP  >interjoor !22_S	et	f	\N
176724	interjoori	?interjoori =interjoori  (SgAdt  >interjoor !22_S	et	f	\N
176725	interjoori	?interjoori =interjoori  (IndPrPs_  >interjoorima !28_V	et	f	\N
176726	interjoori	?interjoori =interjoori  (ImpPrSg2  >interjoorima !28_V	et	f	\N
176727	interjoori	?interjoori =joori  (SgN  >inter+joori !16_S	et	f	\N
176728	interjoori	?interjoori =joori  (SgG  >inter+joori !16_S	et	f	\N
176729	interjoori	?interjoori =joori  (SgG  >inter+joor !22_S	et	f	\N
176730	interjoori	?interjoori =joori  (SgP  >inter+joor !22_S	et	f	\N
176471	suuroja	suuroja =oja  (SgP  >suur+oja !17_S	et	f	\N
176479	vahetusuliopilasena	?vahetusuliopilasena =vahetusuliopilase  (SgEs  >vahetusuliopilane !12_S	et	f	\N
176480	vahetusuliopilasena	?vahetusuliopilasena =liopilase  (SgEs  >vahet+usu+liopilane !12_S	et	f	\N
176481	vahetusuliopilasena	?vahetusuliopilasena =uliopilase  (SgEs  >vahetus+uliopilane !12_S	et	f	\N
176482	vahetusuliopilasena	?vahetusuliopilasena =usuliopilase  (SgEs  >vahet+usuliopilane !12_S	et	f	\N
176483	vahetusuliopilasena	?vahetusuliopilasena =tusuliopilase  (SgEs  >vahe+tusuliopilane !12_S	et	f	\N
176500	o-d	o-d =o  (SgP  >o !xx_Q	et	f	\N
176501	o-d	o-d =o  (PlN  >o !xx_Q	et	f	\N
176502	kiriavahemargid	?kiriavahemargid =kiriavahemargi  (PlN  >kiriavahemark !22_S	et	f	\N
176503	kiriavahemargid	?kiriavahemargid =kiriavahemargi  (IndPrSg2  >kiriavahemarkima !28_V	et	f	\N
176504	kiriavahemargid	?kiriavahemargid =hemargi  (PlN  >kiri+ava+hemarg !02_S	et	f	\N
176505	kiriavahemargid	?kiriavahemargid =hemargi  (PlN  >kiri+ava+hemark !22_S	et	f	\N
176506	kiriavahemargid	?kiriavahemargid =avahemargi  (PlN  >kiri+avahemark !22_S	et	f	\N
176511	adega	?adega =ade  (SgKom  >ade !16_S	et	f	\N
176518	jattuksjdttan	?jattuksjdttan =jattuksjdttan  (SgN  >jattuksjdttan !02_S	et	f	\N
176532	sonalopuliste	?sonalopuliste =sonalopulis  (PlG  >sonalopulis !09_S	et	f	\N
176533	sonalopuliste	?sonalopuliste =sonalopulis  (PlG  >sonalopuline !12_A	et	f	\N
176534	sonalopuliste	?sonalopuliste =sonalopuliste  (PlP  >sonalopulist !22_S	et	f	\N
176553	nditus	?nditus =nditu  (SgIn  >nditu !16_S	et	f	\N
176554	nditus	?nditus =nditu  (IndIpfSg3  >ndituma !27_V	et	f	\N
176555	nditus	?nditus =nditus  (SgN  >nditus !09_S	et	f	\N
176556	moistetav	?moistetav =moiste  (PtsPrIps  >moistema !27_V	et	f	\N
176557	moistetav	?moistetav =moisteta  (PtsPrPs  >moistetama !27_V	et	f	\N
176558	moistetav	?moistetav =moistetav  (SgN  >moistetav !02_A	et	f	\N
176562	upris	?upris =upri  (SgIn  >upper !02_S	et	f	\N
176563	upris	?upris =upri  (IndIpfSg3  >uprima !28_V	et	f	\N
176564	upris	?upris =upris  (SgN  >upris !09_S	et	f	\N
176569	suntaks	?suntaks =sunta  (SgTr  >sunta !16_S	et	f	\N
176570	suntaks	?suntaks =sunta  (KndPrPs  >suntama !29_V	et	f	\N
176582	20ndczl	### 20ndczl	et	f	\N
176583	0aatun	?aatun =aatu  (IndPrSg1  >aatuma !27_V	et	f	\N
176584	0aatun	?aatun =aatun  (SgN  >aatun !02_S	et	f	\N
176587	pohjust	?pohjust =pohju  (SgEl  >pohju !16_S	et	f	\N
176588	pohjust	?pohjust =pohjus  (SgP  >pohjus !11~09_S	et	f	\N
176614	tyosta	?tyosta =tyost  (Inf  >tyostma !34_V	et	f	\N
176615	tyosta	?tyosta =tyosta  (SgN  >tyosta !01_S	et	f	\N
176616	tyosta	?tyosta =tyosta  (SgG  >tyosta !01_S	et	f	\N
176617	tyosta	?tyosta =tyosta  (IndPrPs_  >tyostama !27_V	et	f	\N
176618	tyosta	?tyosta =tyosta  (ImpPrSg2  >tyostama !27_V	et	f	\N
176623	eesl	?eesl =eesl  (SgN  >eesl !22_S	et	f	\N
176624	valistab	?valistab =valista  (IndPrSg3  >valistama !27_V	et	f	\N
176625	kni	### kni	et	f	\N
176639	kliigi	kliigi =klii  (SgN^  >klii !26_S	et	f	\N
176640	kliigi	kliigi =klii  (SgG^  >klii !26_S	et	f	\N
176641	konekeelt	?konekeelt =konekee  (SgAbl  >konekee !26_S	et	f	\N
176642	konekeelt	?konekeelt =konekeelt  (ID  >konekeelt !41_D	et	f	\N
176649	kaiva	?kaiva =kaiva  (SgN  >kaiva !16_S	et	f	\N
176650	kaiva	?kaiva =kaiva  (SgG  >kaiva !16_S	et	f	\N
176651	kaiva	?kaiva =kaiva  (IndPrPs_  >kaivama !29_V	et	f	\N
176652	kaiva	?kaiva =kaiva  (ImpPrSg2  >kaivama !29_V	et	f	\N
176693	sonas	?sonas =sona  (SgIn  >sona !17_S	et	f	\N
176694	sonas	?sonas =sona  (IndIpfSg3  >sonama !27_V	et	f	\N
176695	sonas	?sonas =sonas  (SgN  >sonas !09_S	et	f	\N
176701	konektselt	?konektselt =konektse  (SgAbl  >konektne !02_A	et	f	\N
176702	konektselt	?konektselt =konektselt  (ID  >konektselt !41_D	et	f	\N
176714	paevavalgust	?paevavalgust =paevavalgus  (SgP  >paevavalgus !11~09_S	et	f	\N
176715	paevavalgust	?paevavalgust =vavalgus  (SgP  >pae+vavalgus !11_S	et	f	\N
176732	jattan	?jattan =jatta  (IndPrSg1  >jattama !29_V	et	f	\N
176733	jattan	?jattan =jattan  (SgN  >jattan !02_S	et	f	\N
176751	kaugõppe	kaugõppe =õppe  (SgG  >kaug+õpe !06_S	et	f	\N
176752	kaugõppe	kaugõppe =õppe  (PlP  >kaug+õpp !22_S	et	f	\N
176764	väliseesti	?väliseesti =väliseesti  (ID  >väliseesti !41_D	et	f	\N
176765	väliseesti	?väliseesti =väliseesti  (IndPrPs_  >väliseestima !28_V	et	f	\N
176766	väliseesti	?väliseesti =väliseesti  (ImpPrSg2  >väliseestima !28_V	et	f	\N
176769	interrinde	interrinde =rinde  (PlG  >inter+rind !22_S	et	f	\N
176770	interrinde	interrinde =rinde  (SgG  >inter+rinne !06_S	et	f	\N
176771	interrinde	interrinde =rinde  (PlP  >inter+rind !22_S	et	f	\N
176791	sellelle	?sellelle =sellelle  (PlP  >sellell !22_S	et	f	\N
176792	sellelle	?sellelle =sellelle  (IndPrPs_  >sellellema !27_V	et	f	\N
176793	sellelle	?sellelle =sellelle  (ImpPrSg2  >sellellema !27_V	et	f	\N
176796	raimond	?raimond =raimond  (SgN  >raimond !22_S	et	f	\N
176801	tahtside	?tahtside =tahtsi  (PlG  >tahts !22_S	et	f	\N
176832	peetrikese	peetrikese =peetrikese  (SgG  >peetrike !12_S	et	f	\N
176833	peetrikese	"peetrike %peetri  )KE_dS  <peeter ;02_S	et	f	\N
176834	peetrikese	peetrikese =peetrikese  (SgG  >peetrikene !12_S	et	f	\N
176835	peetrikese	"peetrikene %peetri  )KENE_dS  <peeter ;02_S	et	f	\N
176599	kdsitse	?kdsitse =kdsitse  (ImpPrSg2  >kdsitsema !28_V	et	f	\N
176600	oigekirjaviga	?oigekirjaviga =oigekirjavi  (SgKom  >oigekirjav !02_A	et	f	\N
176626	sidle	?sidle =sidle  (SgN  >sidle !16_S	et	f	\N
176627	sidle	?sidle =sidle  (SgG  >sidle !16_S	et	f	\N
176628	sidle	?sidle =sidle  (PlP  >sidl !22_S	et	f	\N
176629	sidle	?sidle =sidle  (IndPrPs_  >sidlema !30_V	et	f	\N
176630	sidle	?sidle =sidle  (ImpPrSg2  >sidlema !30_V	et	f	\N
176632	vuibast	?vuibast =vuiba  (SgEl  >vuiba !16_S	et	f	\N
176633	vuibast	?vuibast =vuibas  (SgP  >vuibas !07_S	et	f	\N
176634	vuibast	?vuibast =vuibas  (SgP  >vuibane !10_A	et	f	\N
176656	interjooris	?interjooris =interjoori  (SgIn  >interjoori !16_S	et	f	\N
176657	interjooris	?interjooris =interjoori  (SgIn  >interjoor !22_S	et	f	\N
176658	interjooris	?interjooris =interjoori  (IndIpfSg3  >interjoorima !28_V	et	f	\N
176659	interjooris	?interjooris =interjooris  (SgN  >interjooris !09_S	et	f	\N
176660	interjooris	?interjooris =joori  (SgIn  >inter+joori !16_S	et	f	\N
176661	interjooris	?interjooris =joori  (SgIn  >inter+joor !22_S	et	f	\N
176662	interjooris	?interjooris =jooris  (SgN  >inter+jooris !09_S	et	f	\N
176671	konekeeles	?konekeeles =konekeele  (SgIn  >konekeele !16_S	et	f	\N
176672	konekeeles	?konekeeles =konekeele  (PlIn  >konekeel !22_S	et	f	\N
176685	valistada	?valistada =valista  (Inf  >valistama !27_V	et	f	\N
176699	interjoor	?interjoor =interjoor  (SgN  >interjoor !22_S	et	f	\N
176700	interjoor	?interjoor =joor  (SgN  >inter+joor !22_S	et	f	\N
176716	jouad	?jouad =joua  (PlN  >joua !16_S	et	f	\N
176717	jouad	?jouad =jouad  (SgN  >jouad !02_S	et	f	\N
176736	katlini	?katlini =katli  (SgTer  >kattel !02_S	et	f	\N
176739	katlini	?katlini =katlini  (SgG  >katlin !02_S	et	f	\N
176744	renditasu	renditasu =tasu  (SgN  >rendi+tasu !17_S	et	f	\N
176745	renditasu	renditasu =tasu  (SgG  >rendi+tasu !17_S	et	f	\N
176746	renditasu	renditasu =tasu  (SgP  >rendi+tasu !17_S	et	f	\N
176756	sõlmimise	sõlmimise =sõlmimise  (SgG  >sõlmimine !12_S	et	f	\N
176757	sõlmimise	"sõlmimine %sõlmi  )MINE_vS  <sõlmima ;28_V	et	f	\N
176779	2mlj	### 2mlj	et	f	\N
176783	nl-	### nl-	et	f	\N
176784	salaprotokoll	salaprotokoll =koll  (SgN  >sala+proto+koll !22_S	et	f	\N
176785	salaprotokoll	salaprotokoll =protokoll  (SgN  >sala+protokoll !22_S	et	f	\N
176788	ribbentropi	?ribbentropi =ribbentropi  (SgG  >ribbentropp !22_S	et	f	\N
176789	ribbentropi	?ribbentropi =ribbentropi  (IndPrPs_  >ribbentroppima !28_V	et	f	\N
176790	ribbentropi	?ribbentropi =ribbentropi  (ImpPrSg2  >ribbentroppima !28_V	et	f	\N
176808	vaanandi	?vaanandi =vaanandi  (SgN  >vaanandi !01_S	et	f	\N
176809	vaanandi	?vaanandi =vaanandi  (SgG  >vaanandi !01_S	et	f	\N
176810	vaanandi	?vaanandi =vaanandi  (SgG  >vaanand !02_S	et	f	\N
176811	vaanandi	?vaanandi =vaanandi  (SgG  >vaanant !22_S	et	f	\N
176812	vaanandi	?vaanandi =vaanandi  (IndPrPs_  >vaanantima !28_V	et	f	\N
176813	vaanandi	?vaanandi =vaanandi  (ImpPrSg2  >vaanantima !28_V	et	f	\N
176830	multikad	?multikad =multika  (PlN  >multika !01_S	et	f	\N
176831	multikad	?multikad =multika  (PlN  >multikas !02_S	et	f	\N
176843	suitsup	?suitsup =suitsup  (SgN  >suitsup !02_S	et	f	\N
176860	kaasaegsemat	kaasaegsemat =aegsema  (SgP  >kaas+aegsem !02_A	et	f	\N
176861	kaasaegsemat	"kaas+aegsem %aegse  )M_cA  <kaas+aegne ;02_A	et	f	\N
176868	ihaldatavat	ihaldatavat =ihalda  (KvtPrIps  >ihaldama !27_V	et	f	\N
176869	ihaldatavat	ihaldatavat =ihaldatava  (SgP  >ihaldatav !02_A	et	f	\N
176870	ihaldatavat	"ihaldatav %ihalda  )TAV_vAS  <ihaldama ;27_V	et	f	\N
176893	kõps	kõps =kõps  (ID  >kõps !41_I	et	f	\N
176894	kõps	kõps =kõps  (SgN  >kõps !22_S	et	f	\N
176904	60-ndatel	?-ndatel =ndate  (PlAd  >-ndatt !22_S	et	f	\N
176905	60-ndatel	?-ndatel =ndatel  (SgN  >-ndatel !02_S	et	f	\N
176916	1960-ndatel	?-ndatel =ndate  (PlAd  >-ndatt !22_S	et	f	\N
176917	1960-ndatel	?-ndatel =ndatel  (SgN  >-ndatel !02_S	et	f	\N
176920	pikkune	pikkune =pikkune  (SgN  >pikkune !12~10_A	et	f	\N
176921	pikkune	pikkune =une  (SgG  >pikk+uni !20_S	et	f	\N
176925	suveräänsusdeklaratsiooni	suveräänsusdeklaratsiooni =deklaratsiooni  (SgG  >suveräänsus+deklaratsioon !22_S	et	f	\N
176926	suveräänsusdeklaratsiooni	suveräänsusdeklaratsiooni =deklaratsiooni  (SgP  >suveräänsus+deklaratsioon !22_S	et	f	\N
176927	suveräänsusdeklaratsiooni	suveräänsusdeklaratsiooni =deklaratsiooni  (SgAdt  >suveräänsus+deklaratsioon !22_S	et	f	\N
176928	põrandaalused	põrandaalused =aluse  (PlN  >põranda+alus !09_S	et	f	\N
176929	põrandaalused	põrandaalused =aluse  (PlN  >põranda+alune !10_AS	et	f	\N
176930	põrandaalused	"põranda+alune %alu  )NE_aA  <põranda+alg ;22_S	et	f	\N
176946	ndatel	?ndatel =ndate  (PlAd  >ndatt !22_S	et	f	\N
176947	ndatel	?ndatel =ndatel  (SgN  >ndatel !02_S	et	f	\N
176948	rahutused	rahutused =rahutuse  (PlN  >rahutus !11_S	et	f	\N
176949	rahutused	"rahutus %rahu  )TUS2_aS  <rahu ;17_S	et	f	\N
176950	kgb	### kgb	et	f	\N
176956	ainulttal	?ainulttal =ainultta  (SgAd  >ainultta !01_S	et	f	\N
176984	saastumist	saastumist =saastumis  (SgP  >saastumine !12_S	et	f	\N
176985	saastumist	"saastumine %saastu  )MINE_vS  <saastuma ;27_V	et	f	\N
176988	kolivad	kolivad =koli  (IndPrPl3  >kolima !27_V	et	f	\N
176676	mojutatud	?mojutatud =mojuta  (PtsPtIps  >mojutama !27_V	et	f	\N
176677	mojutatud	?mojutatud =mojutatu  (PlN  >mojutatu !01_S	et	f	\N
176678	mojutatud	?mojutatud =mojutatu  (IndPrSg2  >mojutatuma !27_V	et	f	\N
176679	mojutatud	?mojutatud =mojutatud  (ID  >mojutatud !41_A	et	f	\N
176704	interjoorist	?interjoorist =interjoori  (SgEl  >interjoori !16_S	et	f	\N
176705	interjoorist	?interjoorist =interjoori  (SgEl  >interjoor !22_S	et	f	\N
176706	interjoorist	?interjoorist =interjooris  (SgP  >interjooris !09_S	et	f	\N
176707	interjoorist	?interjoorist =joori  (SgEl  >inter+joori !16_S	et	f	\N
176708	interjoorist	?interjoorist =joori  (SgEl  >inter+joor !22_S	et	f	\N
176709	interjoorist	?interjoorist =jooris  (SgP  >inter+jooris !09_S	et	f	\N
176710	interjoorist	?interjoorist =joorist  (SgN  >inter+joorist !22_S	et	f	\N
176719	jattaks	?jattaks =jatta  (KndPrPs  >jattama !29_V	et	f	\N
176743	nõuk	?nõuk =nõuk  (SgN  >nõuk !22_S	et	f	\N
176786	molotovi	?molotovi =molotovi  (ID  >molotovi !41_D	et	f	\N
176787	molotovi	?molotovi =molotovi  (SgG  >molotov !02_A	et	f	\N
176794	juhima	?juhima =juhi  (Sup  >juhima !27_V	et	f	\N
176795	juhima	?juhima =juhima  (SgG  >juhim !02_A	et	f	\N
176818	kruusemendi	?kruusemendi =kruusemendi  (SgG  >kruusement !22_S	et	f	\N
176819	kruusemendi	?kruusemendi =kruusemendi  (SgP  >kruusemend !22_S	et	f	\N
176820	kruusemendi	?kruusemendi =kruusemendi  (SgAdt  >kruusemend !22_S	et	f	\N
176821	kruusemendi	?kruusemendi =kruusemendi  (IndPrPs_  >kruusementima !28_V	et	f	\N
176822	kruusemendi	?kruusemendi =kruusemendi  (ImpPrSg2  >kruusementima !28_V	et	f	\N
176823	kruusemendi	?kruusemendi =emendi  (SgN  >kruus+emendi !01_S	et	f	\N
176824	kruusemendi	?kruusemendi =emendi  (SgG  >kruus+emendi !01_S	et	f	\N
176825	kruusemendi	?kruusemendi =emendi  (SgG  >kruus+emend !02_S	et	f	\N
176826	kruusemendi	?kruusemendi =emendi  (SgG  >kruus+ement !22_S	et	f	\N
176840	suitsupääsuke	suitsupääsuke =pääsuke  (SgN  >suitsu+pääsuke !12_S	et	f	\N
176841	suitsupääsuke	"suitsu+pääsuke %pääsu  )KE_dS  <suitsu+pääsu ;16_S	et	f	\N
176842	suitsupääsuke	"suitsu+pääsuke %pääsu  )KE_dS  <suitsu+pääs ;22_S	et	f	\N
176865	minnalaskmismeeleolu	minnalaskmismeeleolu =olu  (SgN  >minna+laskmis+meele+olu !17_S	et	f	\N
176866	minnalaskmismeeleolu	minnalaskmismeeleolu =olu  (SgG  >minna+laskmis+meele+olu !17_S	et	f	\N
176867	minnalaskmismeeleolu	minnalaskmismeeleolu =olu  (SgP  >minna+laskmis+meele+olu !17_S	et	f	\N
176871	soovitava	soovitava =soovitava  (SgG  >soovitav !02_A	et	f	\N
176872	soovitava	"soovitav %soovi  )TAV_vAS  <soovima ;28_V	et	f	\N
176873	soovitava	"soovitav %soovita  )V_vA  <soovitama ;27_V	et	f	\N
176874	soovitava	soovitava =tava  (SgN  >soovi+tava !17_S	et	f	\N
176875	soovitava	soovitava =tava  (SgG  >soovi+tava !17_S	et	f	\N
176876	soovitava	soovitava =tava  (SgP  >soovi+tava !17_S	et	f	\N
176880	eelnenudeelnesid	### eelnenudeelnesid	et	f	\N
176889	nukitsamees	?nukitsamees =nukitsamee  (SgIn  >nukitsamee !26_S	et	f	\N
176890	nukitsamees	?nukitsamees =nukitsamees  (SgN  >nukitsamees !22_S	et	f	\N
176891	nukitsamees	?nukitsamees =tsamee  (SgIn  >nuki+tsamee !26_S	et	f	\N
176892	nukitsamees	?nukitsamees =tsamees  (SgN  >nuki+tsamees !22_S	et	f	\N
176896	valitsemisaega	valitsemisaega =aega  (SgP  >valitsemis+aeg !22_S	et	f	\N
176897	valitsemisaega	valitsemisaega =aega  (SgAdt  >valitsemis+aeg !22_S	et	f	\N
176902	leevenema	?leevenema =leevene  (Sup  >leevenema !27_V	et	f	\N
176903	leevenema	?leevenema =leevenema  (SgG  >leevenem !02_A	et	f	\N
176918	lühenesid	lühenesid =lühene  (IndIpfSg2  >lühenema !27_V	et	f	\N
176919	lühenesid	lühenesid =lühene  (IndIpfPl3  >lühenema !27_V	et	f	\N
176922	vabadusejanu	vabadusejanu =janu  (SgN  >vabaduse+janu !17_S	et	f	\N
176923	vabadusejanu	vabadusejanu =janu  (SgG  >vabaduse+janu !17_S	et	f	\N
176924	vabadusejanu	vabadusejanu =janu  (SgP  >vabaduse+janu !17_S	et	f	\N
176931	pm	### pm	et	f	\N
176935	milj	### milj	et	f	\N
176936	rliikvia	?rliikvia =rliikvia  (SgN  >rliikvia !01_S	et	f	\N
176937	rliikvia	?rliikvia =rliikvia  (SgG  >rliikvia !01_S	et	f	\N
176938	ndad	### ndad	et	f	\N
176951	ndaid	?ndaid =ndai  (PlN  >ndai !26_S	et	f	\N
176952	ndaid	?ndaid =ndai  (SgP  >ndai !26_S	et	f	\N
176953	ndaid	?ndaid =ndaid  (SgN  >ndaid !22_S	et	f	\N
176954	inimnäoline	inimnäoline =näoline  (SgN  >inim+näoline !12?10_A	et	f	\N
176955	inimnäoline	"inim+näoline %näo  )LINE_aA  <inim+nägu ;18_S	et	f	\N
176959	dissidentid	### dissidentid	et	f	\N
176968	linnastumisega	linnastumisega =linnastumise  (SgKom  >linnastumine !12_S	et	f	\N
176969	linnastumisega	"linnastumine %linnastu  )MINE_vS  <linnastuma ;27_V	et	f	\N
176970	linnastumisega	linnastumisega =astumise  (SgKom  >linn+astumine !12_S	et	f	\N
176971	edukamateks	edukamateks =edukama  (PlTr  >edukam !02_A	et	f	\N
176972	edukamateks	"edukam %eduka  )M_cA  <edukas ;02_A	et	f	\N
176973	nl-u	### nl-u	et	f	\N
176977	vooluga	vooluga =voolu  (SgKom  >vool !22_S	et	f	\N
176978	vooluga	vooluga =luga  (SgN  >voo+luga !18_S	et	f	\N
176979	vooluga	vooluga =luga  (SgP  >voo+luga !18_S	et	f	\N
177027	arendatud	arendatud =arenda  (PtsPtIps  >arendama !27_V	et	f	\N
177028	arendatud	arendatud =arendatu  (PlN  >arendatu !01_S	et	f	\N
177029	arendatud	"arendatu %arenda  )TU1_vS  <arendama ;27_V	et	f	\N
176718	utled	?utled =utle  (IndPrSg2  >utlema !30_V	et	f	\N
176734	nadala	?nadala =nadala  (SgN  >nadala !01_S	et	f	\N
176735	nadala	?nadala =nadala  (SgG  >nadala !01_S	et	f	\N
176737	naitus	naitus =naitu  (SgIn  >naitu !01_S	et	f	\N
176738	naitus	naitus =naitu  (IndIpfSg3  >naituma !27_V	et	f	\N
176740	vahemalt	?vahemalt =vahema  (SgAbl  >vahem !02_A	et	f	\N
176741	vahemalt	?vahemalt =vahemalt  (ID  >vahemalt !41_D	et	f	\N
176742	vahemalt	?vahemalt =malt  (SgN  >vahe+malt !22_S	et	f	\N
176753	ateismi	ateismi =ateismi  (SgG  >ateism !22_S	et	f	\N
176754	ateismi	ateismi =ateismi  (SgP  >ateism !22_S	et	f	\N
176755	ateismi	ateismi =ateismi  (SgAdt  >ateism !22_S	et	f	\N
176761	jumalasse	jumalasse =jumala  (SgIll  >jumal !02_S	et	f	\N
176762	jumalasse	jumalasse =jumalas  (SgAdt  >jumalane !12_S	et	f	\N
176763	jumalasse	"jumalane %jumala  )NE_aA  <jumal ;02_S	et	f	\N
176767	sini-must-valge	sini-must-valge =valge  (SgN  >sini-must-valge !01_AS	et	f	\N
176768	sini-must-valge	sini-must-valge =valge  (SgG  >sini-must-valge !01_AS	et	f	\N
176776	nov	### nov	et	f	\N
176780	iseseisvuspüüde	iseseisvuspüüde =püü  (PlG  >ise+seisvus+püü !26_S	et	f	\N
176781	iseseisvuspüüde	iseseisvuspüüde =püüde  (SgG  >ise+seisvus+püüe !06_S	et	f	\N
176782	iseseisvuspüüde	iseseisvuspüüde =püüde  (PlP  >ise+seisvus+püüd !22_S	et	f	\N
176797	kirjanikutena	### kirjanikutena	et	f	\N
176798	ristikivi	ristikivi =kivi  (SgN  >risti+kivi !17_S	et	f	\N
176799	ristikivi	ristikivi =kivi  (SgG  >risti+kivi !17_S	et	f	\N
176800	ristikivi	ristikivi =kivi  (SgP  >risti+kivi !17_S	et	f	\N
176803	drama	?drama =drama  (SgN  >drama !17_S	et	f	\N
176804	drama	?drama =drama  (SgG  >drama !17_S	et	f	\N
176805	drama	?drama =drama  (SgP  >drama !17_S	et	f	\N
176806	drama	?drama =drama  (IndPrPs_  >dramama !27_V	et	f	\N
176807	drama	?drama =drama  (ImpPrSg2  >dramama !27_V	et	f	\N
176836	muusikasaade	muusikasaade =saade  (SgN  >muusika+saade !06_S	et	f	\N
176837	muusikasaade	muusikasaade =saade  (PlP  >muusika+saad !22_S	et	f	\N
176847	rukkilille	rukkilille =lille  (SgG  >rukki+lill !22_S	et	f	\N
176848	rukkilille	rukkilille =lille  (SgP  >rukki+lill !22_S	et	f	\N
176849	rukkilille	rukkilille =lille  (SgAdt  >rukki+lill !22_S	et	f	\N
176850	rukkilille	rukkilille =lille  (PlP  >rukki+lill !22_S	et	f	\N
176851	herlsinki	?herlsinki =herlsinki  (SgP  >herlsink !22_S	et	f	\N
176852	herlsinki	?herlsinki =herlsinki  (SgAdt  >herlsink !22_S	et	f	\N
176884	allutanud	allutanud =alluta  (PtsPtPs  >allutama !27_V	et	f	\N
176885	allutanud	allutanud =allutanu  (PlN  >allutanu !01_S	et	f	\N
176886	allutanud	"allutanu %alluta  )NU_vS  <allutama ;27_V	et	f	\N
176887	allutanud	allutanud =allutanud  (ID  >allutanud !41_A	et	f	\N
176888	allutanud	"allutanud %alluta  )NUD_vA  <allutama ;27_V	et	f	\N
176895	1953a	### 1953a	et	f	\N
176898	julgemalt	julgemalt =julgema  (SgAbl  >julgem !02_A	et	f	\N
176899	julgemalt	"julgem %julge  )M_cA  <julge ;01_A	et	f	\N
176900	julgemalt	julgemalt =julgemalt  (ID  >julgemalt !41_D	et	f	\N
176901	julgemalt	"julgemalt %julge  )MALT_mD  <julge ;01_A	et	f	\N
176957	murdeaasta	murdeaasta =aasta  (SgN  >murde+aasta !01_S	et	f	\N
176958	murdeaasta	murdeaasta =aasta  (SgG  >murde+aasta !01_S	et	f	\N
176965	linnastumine	linnastumine =linnastumine  (SgN  >linnastumine !12_S	et	f	\N
176966	linnastumine	"linnastumine %linnastu  )MINE_vS  <linnastuma ;27_V	et	f	\N
176967	linnastumine	linnastumine =astumine  (SgN  >linn+astumine !12_S	et	f	\N
176974	1960-ndate	?-ndate =ndate  (SgN  >-ndate !06_S	et	f	\N
176975	1960-ndate	?-ndate =ndate  (IndPrPs_  >-ndatema !27_V	et	f	\N
176976	1960-ndate	?-ndate =ndate  (ImpPrSg2  >-ndatema !27_V	et	f	\N
176999	linnukasvatus	linnukasvatus =kasvatu  (SgIn  >linnu+kasvatu !01_AS	et	f	\N
177000	linnukasvatus	linnukasvatus =kasvatus  (SgN  >linnu+kasvatus !11_S	et	f	\N
177003	seakasvatus	seakasvatus =kasvatu  (SgIn  >sea+kasvatu !01_AS	et	f	\N
177004	seakasvatus	seakasvatus =kasvatus  (SgN  >sea+kasvatus !11_S	et	f	\N
177018	põllumeeste	põllumeeste =mees  (PlG  >põllu+meene !10_A	et	f	\N
177019	põllumeeste	"põllu+meene %mee  )NE_aA  <põllu+mesi ;15_S	et	f	\N
177020	põllumeeste	põllumeeste =mees  (PlG  >põllu+mees !13_S	et	f	\N
177021	kultuuriliseks	kultuuriliseks =kultuurilise  (SgTr  >kultuuriline !12_A	et	f	\N
177022	kultuuriliseks	"kultuuriline %kultuuri  )LINE_aA  <kultuur ;22_S	et	f	\N
177049	venestamispoliitika	venestamispoliitika =poliitika  (SgN  >venestamis+poliitika !01_S	et	f	\N
177050	venestamispoliitika	venestamispoliitika =poliitika  (SgG  >venestamis+poliitika !01_S	et	f	\N
177140	rangema	rangema =rangema  (SgG  >rangem !02_A	et	f	\N
177141	rangema	"rangem %range  )M_cA  <range ;01_A	et	f	\N
177142	rangema	rangema =ema  (SgN  >rang+ema !17_S	et	f	\N
177143	rangema	rangema =ema  (SgG  >rang+ema !17_S	et	f	\N
177144	rangema	rangema =ema  (SgP  >rang+ema !17_S	et	f	\N
177156	mõttelaadi	mõttelaadi =laadi  (SgG  >mõtte+laad !22_S	et	f	\N
177157	mõttelaadi	mõttelaadi =laadi  (SgP  >mõtte+laad !22_S	et	f	\N
177158	mõttelaadi	mõttelaadi =laadi  (SgAdt  >mõtte+laad !22_S	et	f	\N
177159	kodakonsusega	?kodakonsusega =kodakonsuse  (SgKom  >kodakonsus !11~09_S	et	f	\N
176731	interjoori	?interjoori =joori  (SgAdt  >inter+joor !22_S	et	f	\N
176747	pühavaimu	pühavaimu =vaimu  (SgG  >püha+vaim !22_S	et	f	\N
176748	pühavaimu	pühavaimu =vaimu  (SgP  >püha+vaim !22_S	et	f	\N
176749	pühavaimu	pühavaimu =vaimu  (SgAdt  >püha+vaim !22_S	et	f	\N
176750	pühavaimu	pühavaimu =vaimu  (PlP  >püha+vaim !22_S	et	f	\N
176758	lakkasid	lakkasid =lakka  (PlP  >lakk !22_S	et	f	\N
176759	lakkasid	lakkasid =lakka  (IndIpfSg2  >lakkama !29_V	et	f	\N
176760	lakkasid	lakkasid =lakka  (IndIpfPl3  >lakkama !29_V	et	f	\N
176772	langeks	langeks =lange  (SgTr  >lange !06_S	et	f	\N
176773	langeks	langeks =lange  (PlTr  >lang !22_S	et	f	\N
176774	langeks	langeks =lange  (PlTr  >lank !22_S	et	f	\N
176775	langeks	langeks =lange  (KndPrPs  >langema !27_V	et	f	\N
176777	suveräänsuse	suveräänsuse =suveräänsuse  (SgG  >suveräänsus !11~09_S	et	f	\N
176778	suveräänsuse	"suveräänsus %suveräänse  )US_aS  <suveräänne ;02_A	et	f	\N
176802	stalinile	?stalinile =stalini  (SgAll  >stalin !02_S	et	f	\N
176814	aimla	?aimla =aimla  (SgN  >aimla !01_S	et	f	\N
176815	aimla	?aimla =aimla  (SgG  >aimla !01_S	et	f	\N
176816	aimla	?aimla =aimla  (IndPrPs_  >aimlama !29_V	et	f	\N
176817	aimla	?aimla =aimla  (ImpPrSg2  >aimlama !29_V	et	f	\N
176827	60-ndate	?-ndate =ndate  (SgN  >-ndate !06_S	et	f	\N
176828	60-ndate	?-ndate =ndate  (IndPrPs_  >-ndatema !27_V	et	f	\N
176829	60-ndate	?-ndate =ndate  (ImpPrSg2  >-ndatema !27_V	et	f	\N
176838	rahvuslinnu	rahvuslinnu =linnu  (SgG  >rahvus+lind !22_S	et	f	\N
176839	rahvuslinnu	rahvuslinnu =linnu  (PlP  >rahvus+linn !22_S	et	f	\N
176853	pakke	pakke =pakke  (SgG  >pake !06_S	et	f	\N
176854	pakke	pakke =pakke  (PlP  >pakk !22_S	et	f	\N
176855	muusikamaailma	muusikamaailma =ilma  (SgG  >muusika+maa+ilm !22_S	et	f	\N
176856	muusikamaailma	muusikamaailma =ilma  (SgP  >muusika+maa+ilm !22_S	et	f	\N
176857	muusikamaailma	muusikamaailma =ilma  (SgAdt  >muusika+maa+ilm !22_S	et	f	\N
176858	viljelesid	viljelesid =viljele  (IndIpfSg2  >viljelema !31~27_V	et	f	\N
176859	viljelesid	viljelesid =viljele  (IndIpfPl3  >viljelema !31~27_V	et	f	\N
176877	põlevad	põlevad =põle  (IndPrPl3  >põlema !27_V	et	f	\N
176878	põlevad	põlevad =põleva  (PlN  >põlev !02_A	et	f	\N
176879	põlevad	"põlev %põle  )V_vA  <põlema ;27_V	et	f	\N
176881	mrp	### mrp	et	f	\N
176882	tühistamist	tühistamist =tühistamis  (SgP  >tühistamine !12_S	et	f	\N
176883	tühistamist	"tühistamine %tühista  )MINE_vS  <tühistama ;27_V	et	f	\N
176912	kirjastused	kirjastused =kirjastuse  (PlN  >kirjastus !11_S	et	f	\N
176913	kirjastused	"kirjastus %kirjasta  )US_vS  <kirjastama ;27_V	et	f	\N
176932	põrgupõhja	põrgupõhja =põhja  (SgG  >põrgu+põhi !24_S	et	f	\N
176933	põrgupõhja	põrgupõhja =põhja  (SgP  >põrgu+põhi !24_S	et	f	\N
176934	põrgupõhja	põrgupõhja =põhja  (SgAdt  >põrgu+põhi !24_S	et	f	\N
176943	leonid	?leonid =leoni  (PlN  >leoni !16_S	et	f	\N
176944	leonid	?leonid =leoni  (PlN  >leon !22_S	et	f	\N
176945	leonid	?leonid =leoni  (IndPrSg2  >leonima !28_V	et	f	\N
176960	mõtlejad	mõtlejad =mõtleja  (PlN  >mõtleja !01_S	et	f	\N
176961	mõtlejad	"mõtleja %mõtle  )JA_vS  <mõtlema ;30_V	et	f	\N
176962	ndate	?ndate =ndate  (SgN  >ndate !06_S	et	f	\N
176963	ndate	?ndate =ndate  (IndPrPs_  >ndatema !27_V	et	f	\N
176964	ndate	?ndate =ndate  (ImpPrSg2  >ndatema !27_V	et	f	\N
176993	ettevõtte	ettevõtte =võtte  (SgG  >ette+võte !06_S	et	f	\N
176994	ettevõtte	ettevõtte =võtte  (PlP  >ette+võtt !22_S	et	f	\N
176997	loomakasvatus	loomakasvatus =kasvatu  (SgIn  >looma+kasvatu !01_AS	et	f	\N
176998	loomakasvatus	loomakasvatus =kasvatus  (SgN  >looma+kasvatus !11_S	et	f	\N
177009	kirjanduselus	kirjanduselus =elu  (SgIn  >kirjandus+elu !17_S	et	f	\N
177010	kirjanduselus	kirjanduselus =elus  (SgN  >kirjandus+elus !02_A	et	f	\N
177043	1980-ndate	?-ndate =ndate  (SgN  >-ndate !06_S	et	f	\N
177044	1980-ndate	?-ndate =ndate  (IndPrPs_  >-ndatema !27_V	et	f	\N
177045	1980-ndate	?-ndate =ndate  (ImpPrSg2  >-ndatema !27_V	et	f	\N
177098	beekmann	?beekmann =beekmann  (SgN  >beekmann !22_S	et	f	\N
177106	tugevmini	?tugevmini =tugevmi  (SgTer  >tugevmi !01_S	et	f	\N
177107	tugevmini	?tugevmini =tugevmi  (SgTer  >tugevm !22_S	et	f	\N
177108	tugevmini	?tugevmini =tugevmini  (ID  >tugevmini !41_D	et	f	\N
177109	tugevmini	?tugevmini =tugevmini  (SgG  >tugevmin !19_S	et	f	\N
177110	tugevmini	?tugevmini =tugevmini  (SgP  >tugevmin !19_S	et	f	\N
177111	tugevmini	?tugevmini =tugevmini  (SgAdt  >tugevmin !19_S	et	f	\N
177136	baltimaadele	baltimaadele =maa  (PlAll  >balti+maa !26_S	et	f	\N
177137	baltimaadele	baltimaadele =maade  (PlAll  >balti+maat !22_S	et	f	\N
177148	sagenesid	sagenesid =sagene  (IndIpfSg2  >sagenema !27_V	et	f	\N
177149	sagenesid	sagenesid =sagene  (IndIpfPl3  >sagenema !27_V	et	f	\N
177150	tunnustuse	tunnustuse =tunnustuse  (SgG  >tunnustus !11_S	et	f	\N
177151	tunnustuse	"tunnustus %tunnusta  )US_vS  <tunnustama ;27_V	et	f	\N
177180	kerese	kerese =kerese  (SgG  >kerene !10_A	et	f	\N
177181	kerese	"kerene %kere  )NE_aA  <kere ;16_S	et	f	\N
177199	pooleloli	?pooleloli =pooleloli  (SgG  >poolelol !19_S	et	f	\N
177200	pooleloli	?pooleloli =pooleloli  (SgP  >poolelol !19_S	et	f	\N
176844	paekivi	paekivi =kivi  (SgN  >pae+kivi !17_S	et	f	\N
176845	paekivi	paekivi =kivi  (SgG  >pae+kivi !17_S	et	f	\N
176846	paekivi	paekivi =kivi  (SgP  >pae+kivi !17_S	et	f	\N
176862	masendav	masendav =masenda  (PtsPrPs  >masendama !27_V	et	f	\N
176863	masendav	masendav =masendav  (SgN  >masendav !02_A	et	f	\N
176864	masendav	"masendav %masenda  )V_vA  <masendama ;27_V	et	f	\N
176906	puudutanud	puudutanud =puuduta  (PtsPtPs  >puudutama !27_V	et	f	\N
176907	puudutanud	puudutanud =puudutanu  (PlN  >puudutanu !01_S	et	f	\N
176908	puudutanud	"puudutanu %puuduta  )NU_vS  <puudutama ;27_V	et	f	\N
176909	puudutanud	puudutanud =puudutanud  (ID  >puudutanud !41_A	et	f	\N
176910	puudutanud	"puudutanud %puuduta  )NUD_vA  <puudutama ;27_V	et	f	\N
176911	puudutanud	puudutanud =tanu  (PlN  >puudu+tanu !17_S	et	f	\N
176914	orto	?orto =orto  (SgN  >orto !16_S	et	f	\N
176915	orto	?orto =orto  (SgG  >orto !16_S	et	f	\N
176939	kuuekümnendad	?kuuekümnendad =kuuekümnenda  (PlN  >kuuekümnenda !16_S	et	f	\N
176940	kuuekümnendad	?kuuekümnendad =kuuekümnenda  (IndPrSg2  >kuuekümnendama !27_V	et	f	\N
176941	kuuekümnendad	?kuuekümnendad =kümnenda  (PlN  >kuue+kümnenda !01_S	et	f	\N
176942	kuuekümnendad	?kuuekümnendad =ekümnenda  (PlN  >kuu+ekümnenda !16_S	et	f	\N
176980	arendamisele	arendamisele =arendamise  (SgAll  >arendamine !12_S	et	f	\N
176981	arendamisele	"arendamine %arenda  )MINE_vS  <arendama ;27_V	et	f	\N
176982	saastumine	saastumine =saastumine  (SgN  >saastumine !12_S	et	f	\N
176983	saastumine	"saastumine %saastu  )MINE_vS  <saastuma ;27_V	et	f	\N
176986	elektrifitseerimine	elektrifitseerimine =elektrifitseerimine  (SgN  >elektrifitseerimine !12_S	et	f	\N
176987	elektrifitseerimine	"elektrifitseerimine %elektrifitseeri  )MINE_vS  <elektrifitseerima ;28_V	et	f	\N
176991	ääremaa	ääremaa =maa  (SgN  >ääre+maa !26_S	et	f	\N
176992	ääremaa	ääremaa =maa  (SgG  >ääre+maa !26_S	et	f	\N
176995	tehnilisem	tehnilisem =tehnilisem  (SgN  >tehnilisem !02_A	et	f	\N
176996	tehnilisem	"tehnilisem %tehnilise  )M_cA  <tehniline ;12_A	et	f	\N
177001	piimakarjakasvatus	piimakarjakasvatus =kasvatu  (SgIn  >piima+karja+kasvatu !01_AS	et	f	\N
177002	piimakarjakasvatus	piimakarjakasvatus =kasvatus  (SgN  >piima+karja+kasvatus !11_S	et	f	\N
177007	arvutitehnika	arvutitehnika =tehnika  (SgN  >arvuti+tehnika !01_S	et	f	\N
177008	arvutitehnika	arvutitehnika =tehnika  (SgG  >arvuti+tehnika !01_S	et	f	\N
177011	keelatuid	keelatuid =keelatu  (PlP  >keelatu !01_S	et	f	\N
177012	keelatuid	"keelatu %keela  )TU1_vS  <keelama ;29_V	et	f	\N
177013	tsenseeritud	tsenseeritud =tsenseeri  (PtsPtIps  >tsenseerima !28_V	et	f	\N
177014	tsenseeritud	tsenseeritud =tsenseeritu  (PlN  >tsenseeritu !01_S	et	f	\N
177015	tsenseeritud	"tsenseeritu %tsenseeri  )TU1_vS  <tsenseerima ;28_V	et	f	\N
177016	tsenseeritud	tsenseeritud =tsenseeritud  (ID  >tsenseeritud !41_A	et	f	\N
177017	tsenseeritud	"tsenseeritud %tsenseeri  )TUD_vA  <tsenseerima ;28_V	et	f	\N
177051	poolpõrandaalune	poolpõrandaalune =alune  (SgN  >pool+põranda+alune !10_AS	et	f	\N
177052	poolpõrandaalune	"pool+põranda+alune %alu  )NE_aA  <pool+põranda+alg ;22_S	et	f	\N
177053	põrandaalune	põrandaalune =alune  (SgN  >põranda+alune !10_AS	et	f	\N
177054	põrandaalune	"põranda+alune %alu  )NE_aA  <põranda+alg ;22_S	et	f	\N
177063	marm	?marm =marm  (SgN  >marm !22_S	et	f	\N
177064	ilmuv	ilmuv =ilmu  (PtsPrPs  >ilmuma !27_V	et	f	\N
177065	ilmuv	ilmuv =ilmuv  (SgN  >ilmuv !02_A	et	f	\N
177066	ilmuv	"ilmuv %ilmu  )V_vA  <ilmuma ;27_V	et	f	\N
177067	kaalep	?kaalep =kaalep  (SgN  >kaalep !02_S	et	f	\N
177071	ägedalt	ägedalt =ägeda  (SgAbl  >äge !02_A	et	f	\N
177072	ägedalt	ägedalt =ägedalt  (ID  >ägedalt !41_D	et	f	\N
177073	ägedalt	"ägedalt %ägeda  )LT_mD  <äge ;02_A	et	f	\N
177074	toimunutel	toimunutel =toimunu  (PlAd  >toimunu !01_S	et	f	\N
177075	toimunutel	"toimunu %toimu  )NU_vS  <toimuma ;27_V	et	f	\N
177082	tagastamise	tagastamise =tagastamise  (SgG  >tagastamine !12_S	et	f	\N
177083	tagastamise	"tagastamine %tagasta  )MINE_vS  <tagastama ;27_V	et	f	\N
177089	kali	kali =kali  (SgN  >kali !17_S	et	f	\N
177090	kali	kali =kali  (SgN  >kali !24_S	et	f	\N
177092	kali	kali =kali  (SgG  >kali !17_S	et	f	\N
177093	kali	kali =kali  (SgP  >kali !17_S	et	f	\N
177105	vennestamise	?vennestamise =vennestamise  (SgG  >vennestamine !12_S	et	f	\N
177131	protokoll	protokoll =protokoll  (SgN  >protokoll !22_S	et	f	\N
177132	protokoll	protokoll =koll  (SgN  >proto+koll !22_S	et	f	\N
177133	vilnusist	?vilnusist =vilnusi  (PlEl  >vilnus !11_S	et	f	\N
177134	vilnusist	?vilnusist =vilnusis  (SgP  >vilnusis !11_S	et	f	\N
177135	vilnusist	?vilnusist =vilnusist  (SgN  >vilnusist !22_S	et	f	\N
177161	võõrvõimu	võõrvõimu =võimu  (SgG  >võõr+võim !22_S	et	f	\N
177162	võõrvõimu	võõrvõimu =võimu  (SgP  >võõr+võim !22_S	et	f	\N
177163	võõrvõimu	võõrvõimu =võimu  (SgAdt  >võõr+võim !22_S	et	f	\N
177178	maletamise	maletamise =maletamise  (SgG  >maletamine !12_S	et	f	\N
177179	maletamise	"maletamine %maleta  )MINE_vS  <maletama ;27_V	et	f	\N
177189	omoni	?omoni =omo  (SgTer  >omo !17~16_S	et	f	\N
177190	omoni	?omoni =omoni  (SgG  >omon !02_S	et	f	\N
177235	hermanis	?hermanis =hermani  (SgIn  >herman !02_S	et	f	\N
177236	hermanis	?hermanis =hermanis  (SgN  >hermanis !11_S	et	f	\N
176989	kolivad	kolivad =koliva  (PlN  >koliv !02_A	et	f	\N
176990	kolivad	"koliv %koli  )V_vA  <kolima ;27_V	et	f	\N
177005	toidukasvatus	toidukasvatus =kasvatu  (SgIn  >toidu+kasvatu !01_AS	et	f	\N
177006	toidukasvatus	toidukasvatus =kasvatus  (SgN  >toidu+kasvatus !11_S	et	f	\N
177023	emantsipeeritud	?emantsipeeritud =emantsipeeri  (PtsPtIps  >emantsipeerima !28_V	et	f	\N
177024	emantsipeeritud	?emantsipeeritud =emantsipeeritu  (PlN  >emantsipeeritu !01_S	et	f	\N
177025	emantsipeeritud	?emantsipeeritud =emantsipeeritu  (IndPrSg2  >emantsipeerituma !27_V	et	f	\N
177026	emantsipeeritud	?emantsipeeritud =emantsipeeritud  (ID  >emantsipeeritud !41_A	et	f	\N
177034	traadi	traadi =traadi  (SgG  >traat !22_S	et	f	\N
177035	traadi	traadi =traadi  (IndPrPs_  >traatima !28_V	et	f	\N
177036	traadi	traadi =traadi  (ImpPrSg2  >traatima !28_V	et	f	\N
177078	suurelt	suurelt =suure  (SgAbl  >suur !13_A	et	f	\N
177079	suurelt	suurelt =suurelt  (ID  >suurelt !41_D	et	f	\N
177080	suurelt	"suurelt %suure  )LT_mD  <suur ;13_A	et	f	\N
177081	suurelt	suurelt =re  (SgAbl  >suu+re !26_S	et	f	\N
177084	elujõukuse	elujõukuse =kuse  (SgG  >elu+jõu+kusi !20_S	et	f	\N
177085	elujõukuse	elujõukuse =jõukuse  (SgG  >elu+jõukus !11~09_S	et	f	\N
177086	elujõukuse	"elu+jõukus %jõuka  )US_aS  <elu+jõukas ;02_A	et	f	\N
177087	demonstratsiooniks	demonstratsiooniks =demonstratsiooni  (SgTr  >demonstratsioon !22_S	et	f	\N
177088	demonstratsiooniks	demonstratsiooniks =iks  (SgN  >demonstratsioon+iks !22_S	et	f	\N
177094	reisikrjad	?reisikrjad =reisikrja  (PlN  >reisikrjas !02_A	et	f	\N
177095	reisikrjad	?reisikrjad =reisikrja  (PlN  >reisikrja !16_S	et	f	\N
177096	tugevast	tugevast =tugeva  (SgEl  >tugev !02_A	et	f	\N
177097	tugevast	"tugev %tuge  )V_vA  <tugema ;27_V	et	f	\N
177102	1979-	### 1979-	et	f	\N
177119	salaprotokolli	salaprotokolli =kolli  (SgG  >sala+proto+koll !22_S	et	f	\N
177120	salaprotokolli	salaprotokolli =kolli  (SgP  >sala+proto+koll !22_S	et	f	\N
177121	salaprotokolli	salaprotokolli =kolli  (SgAdt  >sala+proto+koll !22_S	et	f	\N
177122	salaprotokolli	salaprotokolli =protokolli  (SgG  >sala+protokoll !22_S	et	f	\N
177123	salaprotokolli	salaprotokolli =protokolli  (SgP  >sala+protokoll !22_S	et	f	\N
177124	salaprotokolli	salaprotokolli =protokolli  (SgAdt  >sala+protokoll !22_S	et	f	\N
177125	pakti	pakti =pakti  (SgG  >pakt !22_S	et	f	\N
177127	pakti	pakti =pakti  (SgP  >pakt !22_S	et	f	\N
177129	pakti	pakti =pakti  (SgAdt  >pakt !22_S	et	f	\N
177145	soovisid	soovisid =soovi  (PlP  >soov !22_S	et	f	\N
177146	soovisid	soovisid =soovi  (IndIpfSg2  >soovima !28_V	et	f	\N
177147	soovisid	soovisid =soovi  (IndIpfPl3  >soovima !28_V	et	f	\N
177182	temanimelised	temanimelised =nimelise  (PlN  >tema+nimeline !12_A	et	f	\N
177183	temanimelised	"tema+nimeline %nime  )LINE_aA  <tema+nimi ;20_S	et	f	\N
177185	temanimeline	temanimeline =nimeline  (SgN  >tema+nimeline !12_A	et	f	\N
177187	temanimeline	"tema+nimeline %nime  )LINE_aA  <tema+nimi ;20_S	et	f	\N
177193	pingestamisele	pingestamisele =pingestamise  (SgAll  >pingestamine !12_S	et	f	\N
177194	pingestamisele	"pingestamine %pingesta  )MINE_vS  <pingestama ;27_V	et	f	\N
177197	visnapuu	visnapuu =puu  (SgN  >visna+puu !26_S	et	f	\N
177198	visnapuu	visnapuu =puu  (SgG  >visna+puu !26_S	et	f	\N
177207	1970-80ndate	?-ndate =ndate  (SgN  >-ndate !06_S	et	f	\N
177208	1970-80ndate	?-ndate =ndate  (IndPrPs_  >-ndatema !27_V	et	f	\N
177209	1970-80ndate	?-ndate =ndate  (ImpPrSg2  >-ndatema !27_V	et	f	\N
177261	1993a	### 1993a	et	f	\N
177277	arbujad	arbujad =arbuja  (PlN  >arbuja !01_S	et	f	\N
177278	arbujad	"arbuja %arbu  )JA_vS  <arbuma ;28_V	et	f	\N
177292	sõnalõpulist	sõnalõpulist =lõpulis  (SgP  >sõna+lõpuline !12_A	et	f	\N
177293	sõnalõpulist	"sõna+lõpuline %lõpu  )LINE_aA  <sõna+lõpp ;22_SA	et	f	\N
177300	ratusi	?ratusi =ratusi  (ID  >ratusi !41_D	et	f	\N
177320	parasiitsõna	parasiitsõna =sõna  (SgN  >para+siit+sõna !17_S	et	f	\N
177321	parasiitsõna	parasiitsõna =sõna  (SgG  >para+siit+sõna !17_S	et	f	\N
177322	parasiitsõna	parasiitsõna =sõna  (SgP  >para+siit+sõna !17_S	et	f	\N
177333	kõnekasutuses	kõnekasutuses =kasutuse  (SgIn  >kõne+kasutus !11_S	et	f	\N
177334	kõnekasutuses	"kõne+kasutus %kasu  )TUS2_aS  <kõne+kasu ;17_S	et	f	\N
177349	täpid	täpid =täpi  (PlN  >täpp !22_S	et	f	\N
177350	täpid	täpid =täpi  (IndPrSg2  >täppima !28_V	et	f	\N
177354	arjutamine	?arjutamine =arjutamine  (SgN  >arjutamine !12_S	et	f	\N
177355	arjutamine	?arjutamine =arjutamine  (PlP  >arjutamin !19_S	et	f	\N
177356	hakkama-tulema-	?hakkama-tulema- =hakkama-tulema  (SgG  >hakkama-tulem !02_A	et	f	\N
177357	hakkama-tulema-	?hakkama-tulema- =-tulema  (SgG  >hakkama+-tulem !02_A	et	f	\N
177358	hakkama-tulema-	?hakkama-tulema- =ama-tulema  (SgG  >hakk+ama-tulem !02_A	et	f	\N
177374	öpilaste	?öpilaste =öpilas  (PlG  >öpilane !12_S	et	f	\N
177379	iimestab	?iimestab =iimesta  (IndPrSg3  >iimestama !27_V	et	f	\N
177380	omapärased	omapärased =pärase  (PlN  >oma+pärane !10_A	et	f	\N
177381	omapärased	"oma+pärane %pära  )NE_aA  <oma+pära ;17_S	et	f	\N
177384	omaparased	?omaparased =omaparase  (PlN  >omaparane !12_A	et	f	\N
177385	omaparased	?omaparased =parase  (PlN  >oma+parane !10_A	et	f	\N
177443	1872pt	### 1872pt	et	f	\N
177452	12pt	### 12pt	et	f	\N
177030	arendatud	arendatud =arendatud  (ID  >arendatud !41_A	et	f	\N
177031	arendatud	"arendatud %arenda  )TUD_vA  <arendama ;27_V	et	f	\N
177032	hõbevalge	hõbevalge =valge  (SgN  >hõbe+valge !01_AS	et	f	\N
177033	hõbevalge	hõbevalge =valge  (SgG  >hõbe+valge !01_AS	et	f	\N
177037	avavaid	avavaid =avava  (PlP  >avav !02_A	et	f	\N
177038	avavaid	"avav %ava  )V_vA  <avama ;27_V	et	f	\N
177039	ramaatu	?ramaatu =ramaatu  (SgN  >ramaatu !01_AS	et	f	\N
177040	ramaatu	?ramaatu =ramaatu  (SgG  >ramaatu !01_AS	et	f	\N
177041	ramaatu	?ramaatu =ramaatu  (IndPrPs_  >ramaatuma !27_V	et	f	\N
177042	ramaatu	?ramaatu =ramaatu  (ImpPrSg2  >ramaatuma !27_V	et	f	\N
177046	katkematu	katkematu =katkematu  (SgN  >katkematu !01_A	et	f	\N
177047	katkematu	"katkematu %katke  )MATU_vA  <katkema ;27_V	et	f	\N
177048	katkematu	katkematu =katkematu  (SgG  >katkematu !01_A	et	f	\N
177055	hees	?hees =hees  (SgN  >hees !22_S	et	f	\N
177056	udi	udi =udi  (SgN  >udi !24_S	et	f	\N
177057	udi	udi =udi  (IndPrPs_  >udima !27_V	et	f	\N
177058	udi	udi =udi  (ImpPrSg2  >udima !27_V	et	f	\N
177059	reinla	?reinla =reinla  (SgN  >reinla !01_S	et	f	\N
177060	reinla	?reinla =reinla  (SgG  >reinla !01_S	et	f	\N
177061	reinla	?reinla =reinla  (IndPrPs_  >reinlama !29_V	et	f	\N
177062	reinla	?reinla =reinla  (ImpPrSg2  >reinlama !29_V	et	f	\N
177068	kiigi	kiigi =kiigi  (SgG  >kiik !22_S	et	f	\N
177069	kiigi	kiigi =kii  (SgN^  >kii !26_S	et	f	\N
177070	kiigi	kiigi =kii  (SgG^  >kii !26_S	et	f	\N
177076	öölaulupidudel	öölaulupidudel =pidu  (PlAd  >öö+laulu+pidu !17_S	et	f	\N
177077	öölaulupidudel	öölaulupidudel =pidu  (PlAd  >öö+laulu+pidu !18_S	et	f	\N
177091	meteoriitkraateri	?meteoriitkraateri =meteoriitkraateri  (SgG  >meteoriitkraater !02_S	et	f	\N
177099	krossi	krossi =krossi  (SgG  >kross !22_S	et	f	\N
177100	krossi	krossi =krossi  (SgP  >kross !22_S	et	f	\N
177101	krossi	krossi =krossi  (SgAdt  >kross !22_S	et	f	\N
177103	svlane	?svlane =svlane  (IndPrPs_  >svlanema !27_V	et	f	\N
177104	svlane	?svlane =svlane  (ImpPrSg2  >svlanema !27_V	et	f	\N
177112	üdi	üdi =üdi  (SgN  >üdi !17_S	et	f	\N
177113	üdi	üdi =üdi  (SgG  >üdi !17_S	et	f	\N
177114	üdi	üdi =üdi  (SgP  >üdi !17_S	et	f	\N
177115	olemast	olemast =ole  (SupEl  >olema !36_V	et	f	\N
177116	olemast	olemast =olema  (SgEl  >olem !02_S	et	f	\N
177117	olemast	olemast =olemas  (SgP  >olemane !12_A	et	f	\N
177118	olemast	"olemane %olema  )NE_aA  <olem ;02_S	et	f	\N
177126	molotovi-ribentropi	?molotovi-ribentropi =ribentropi  (SgG  >molotovi-ribentropp !22_S	et	f	\N
177128	molotovi-ribentropi	?molotovi-ribentropi =ribentropi  (IndPrPs_  >molotovi-ribentroppima !28_V	et	f	\N
177130	molotovi-ribentropi	?molotovi-ribentropi =ribentropi  (ImpPrSg2  >molotovi-ribentroppima !28_V	et	f	\N
177138	viiekroonisel	viiekroonisel =kroonise  (SgAd  >viie+kroonine !10_AS	et	f	\N
177139	viiekroonisel	"viie+kroonine %krooni  )NE_aA  <viie+kroon ;22_S	et	f	\N
177152	kaplinski	?kaplinski =kaplinski  (SgG  >kaplinsk !02_S	et	f	\N
177153	kaplinski	?kaplinski =kaplinski  (IndPrPs_  >kaplinskima !28_V	et	f	\N
177154	kaplinski	?kaplinski =kaplinski  (ImpPrSg2  >kaplinskima !28_V	et	f	\N
177155	kaplinski	?kaplinski =kaplins  (SgN^  >kaplins !02_S	et	f	\N
177164	eksistensi	?eksistensi =eksistensi  (SgG  >eksistenss !22_S	et	f	\N
177165	eksistensi	?eksistensi =eksistensi  (SgP  >eksistens !22_S	et	f	\N
177166	eksistensi	?eksistensi =eksistensi  (SgAdt  >eksistens !22_S	et	f	\N
177167	eksistensi	?eksistensi =eksistensi  (IndPrPs_  >eksistenssima !28_V	et	f	\N
177168	eksistensi	?eksistensi =eksistensi  (ImpPrSg2  >eksistenssima !28_V	et	f	\N
177169	eksistensi	?eksistensi =stensi  (SgN  >eksi+stensi !16_S	et	f	\N
177170	eksistensi	?eksistensi =stensi  (SgG  >eksi+stensi !16_S	et	f	\N
177171	eksistensi	?eksistensi =stensi  (SgG  >eksi+stenss !22_S	et	f	\N
177172	eksistensi	?eksistensi =stensi  (SgP  >eksi+stens !22_S	et	f	\N
177173	eksistensi	?eksistensi =stensi  (SgAdt  >eksi+stens !22_S	et	f	\N
177174	eksistensi	?eksistensi =istensi  (SgN  >eks+istensi !01_S	et	f	\N
177175	eksistensi	?eksistensi =istensi  (SgG  >eks+istensi !01_S	et	f	\N
177176	eksistensi	?eksistensi =istensi  (SgG  >eks+istens !02_S	et	f	\N
177177	eksistensi	?eksistensi =istensi  (SgG  >eks+istenss !22_S	et	f	\N
177195	elujõud	elujõud =jõu  (PlN  >elu+jõud !22_S	et	f	\N
177196	elujõud	elujõud =jõud  (SgN  >elu+jõud !22_S	et	f	\N
177210	rühmitused	rühmitused =rühmituse  (PlN  >rühmitus !11_S	et	f	\N
177211	rühmitused	"rühmitus %rühmita  )US_vS  <rühmitama ;27_V	et	f	\N
177212	rühmitused	"rühmitus %rühmi  )TUS2_aS  <rühm ;22_S	et	f	\N
177217	avatunud	?avatunud =avatu  (PtsPtPs  >avatuma !27_V	et	f	\N
177218	avatunud	?avatunud =avatunu  (PlN  >avatunu !01_S	et	f	\N
177219	avatunud	?avatunud =avatunu  (IndPrSg2  >avatunuma !27_V	et	f	\N
177220	avatunud	?avatunud =avatunud  (ID  >avatunud !41_A	et	f	\N
177221	avatunud	?avatunud =tunu  (PlN  >ava+tunu !17_S	et	f	\N
177224	õpilasrahutused	õpilasrahutused =rahutuse  (PlN  >õpilas+rahutus !11_S	et	f	\N
177225	õpilasrahutused	"õpilas+rahutus %rahu  )TUS2_aS  <õpilas+rahu ;17_S	et	f	\N
177226	reformida	reformida =reformi  (Inf  >reformima !28_V	et	f	\N
177227	reformida	reformida =ida  (SgN  >reform+ida !17_S	et	f	\N
177160	kodakonsusega	?kodakonsusega =konsuse  (SgKom  >koda+konsus !11~09_S	et	f	\N
177184	maleklubi	maleklubi =klubi  (SgN  >male+klubi !17_S	et	f	\N
177186	maleklubi	maleklubi =klubi  (SgG  >male+klubi !17_S	et	f	\N
177188	maleklubi	maleklubi =klubi  (SgP  >male+klubi !17_S	et	f	\N
177191	ahistamisele	ahistamisele =ahistamise  (SgAll  >ahistamine !12_S	et	f	\N
177192	ahistamisele	"ahistamine %ahista  )MINE_vS  <ahistama ;27_V	et	f	\N
177237	gediminase	?gediminase =gediminase  (SgG  >gediminane !12_A	et	f	\N
177238	molotov-ribbendropi	?molotov-ribbendropi =ribbendropi  (SgG  >molotov-ribbendropp !22_S	et	f	\N
177239	molotov-ribbendropi	?molotov-ribbendropi =ribbendropi  (IndPrPs_  >molotov-ribbendroppima !28_V	et	f	\N
177240	molotov-ribbendropi	?molotov-ribbendropi =ribbendropi  (ImpPrSg2  >molotov-ribbendroppima !28_V	et	f	\N
177245	tuumakatastroofi	tuumakatastroofi =katastroofi  (SgG  >tuuma+katastroof !22_S	et	f	\N
177246	tuumakatastroofi	tuumakatastroofi =katastroofi  (SgP  >tuuma+katastroof !22_S	et	f	\N
177247	tuumakatastroofi	tuumakatastroofi =katastroofi  (SgAdt  >tuuma+katastroof !22_S	et	f	\N
177252	lauluväljaluk	### lauluväljaluk	et	f	\N
177281	18-	### 18-	et	f	\N
177286	välismaiste	välismaiste =mais  (PlG  >välis+maine !10_A	et	f	\N
177287	välismaiste	"välis+maine %mai  )NE_aA  <välis+maa ;26_S	et	f	\N
177288	musketäri	musketäri =musketäri  (SgG  >musketär !19_S	et	f	\N
177289	musketäri	musketäri =musketäri  (SgP  >musketär !19_S	et	f	\N
177290	musketäri	musketäri =musketäri  (SgAdt  >musketär !19_S	et	f	\N
177297	ärajäänud	ärajäänud =jää  (PtsPtPs  >ära+_jääma !37_V	et	f	\N
177298	ärajäänud	ärajäänud =jäänu  (PlN  >ära+jäänu !01_S	et	f	\N
177299	ärajäänud	ärajäänud =jäänu  (PlN  >ära+jäänu !06_S	et	f	\N
177301	järeldanud	järeldanud =järelda  (PtsPtPs  >järeldama !27_V	et	f	\N
177302	järeldanud	järeldanud =järeldanu  (PlN  >järeldanu !01_S	et	f	\N
177303	järeldanud	"järeldanu %järelda  )NU_vS  <järeldama ;27_V	et	f	\N
177304	järeldanud	järeldanud =järeldanud  (ID  >järeldanud !41_A	et	f	\N
177305	järeldanud	"järeldanud %järelda  )NUD_vA  <järeldama ;27_V	et	f	\N
177317	pöördevormi	pöördevormi =vormi  (SgG  >pöörde+vorm !22_S	et	f	\N
177318	pöördevormi	pöördevormi =vormi  (SgP  >pöörde+vorm !22_S	et	f	\N
177319	pöördevormi	pöördevormi =vormi  (SgAdt  >pöörde+vorm !22_S	et	f	\N
177323	tekkepõhjust	tekkepõhjust =põhju  (PlEl  >tekke+põhi !24_S	et	f	\N
177324	tekkepõhjust	tekkepõhjust =põhjus  (SgP  >tekke+põhjus !11~09_S	et	f	\N
177330	vähene	vähene =vähene  (SgN  >vähene !10_A	et	f	\N
177331	vähene	vähene =vähene  (IndPrPs_  >vähenema !27_V	et	f	\N
177332	vähene	vähene =vähene  (ImpPrSg2  >vähenema !27_V	et	f	\N
177335	ij	### ij	et	f	\N
177341	hjäl	### hjäl	et	f	\N
177344	täpitähtede	täpitähtede =ede  (SgN  >täpi+täht+ede !16_S	et	f	\N
177345	täpitähtede	täpitähtede =ede  (SgG  >täpi+täht+ede !16_S	et	f	\N
177346	täpitähtede	täpitähtede =tähte  (PlG  >täpi+täht !22_S	et	f	\N
177359	poolpäeva	poolpäeva =päeva  (SgG  >pool+päev !22_S	et	f	\N
177360	poolpäeva	poolpäeva =päeva  (SgP  >pool+päev !22_S	et	f	\N
177361	poolpäeva	poolpäeva =päeva  (SgAdt  >pool+päev !22_S	et	f	\N
177362	vtlisa	?vtlisa =vtlisa  (SgN  >vtlisa !17_S	et	f	\N
177363	vtlisa	?vtlisa =vtlisa  (SgG  >vtlisa !17_S	et	f	\N
177364	vtlisa	?vtlisa =vtlisa  (SgP  >vtlisa !17_S	et	f	\N
177365	vtlisa	?vtlisa =vtlisa  (IndPrPs_  >vtlisama !27_V	et	f	\N
177366	vtlisa	?vtlisa =vtlisa  (ImpPrSg2  >vtlisama !27_V	et	f	\N
177371	nrl	### nrl	et	f	\N
177390	jl	### jl	et	f	\N
177395	sitletud	?sitletud =sitletu  (PlN  >sitletu !01_A	et	f	\N
177396	sitletud	?sitletud =sitletu  (IndPrSg2  >sitletuma !27_V	et	f	\N
177397	sitletud	?sitletud =sitletud  (ID  >sitletud !41_A	et	f	\N
177398	ma-da-	?ma-da- =ma-da  (SgN  >ma-da !16_S	et	f	\N
177399	ma-da-	?ma-da- =ma-da  (SgG  >ma-da !16_S	et	f	\N
177400	ma-da-	?ma-da- =ma-da  (IndPrPs_  >ma-dama !29_V	et	f	\N
177401	ma-da-	?ma-da- =ma-da  (ImpPrSg2  >ma-dama !29_V	et	f	\N
177402	kahekordsete	kahekordsete =sete  (SgN  >kahe+kord+sete !06_S	et	f	\N
177403	kahekordsete	kahekordsete =kordse  (PlG  >kahe+kordne !02_AS	et	f	\N
177411	saba	saba =saba  (SgN  >saba !17_S	et	f	\N
177412	saba	saba =saba  (SgG  >saba !17_S	et	f	\N
177413	saba	saba =saba  (SgP  >saba !17_S	et	f	\N
177414	polüüseemide	?polüüseemide =polüüseemi  (PlG  >polüüseemi !16_S	et	f	\N
177415	polüüseemide	?polüüseemide =polüüseemi  (PlG  >polüüseem !22_S	et	f	\N
177435	õppekool	õppekool =koo  (SgAd  >õppe+kubu !18_S	et	f	\N
177436	õppekool	õppekool =kool  (SgN  >õppe+kool !22_S	et	f	\N
177442	0cm	### 0cm	et	f	\N
177444	00001pt	### 00001pt	et	f	\N
177449	150span	### 150span	et	f	\N
177461	materialsete	?materialsete =materialse  (PlG  >materialne !02_A	et	f	\N
177466	genitiivikäände	?genitiivikäände =genitiivikäände  (PlP  >genitiivikäänd !22_S	et	f	\N
177483	ennast-	ennast- =ennas  (SgP  >enese !00_P	et	f	\N
177484	ennast-	ennast- =ennas  (SgP  >ise !00_P	et	f	\N
177490	tjäpselt	?tjäpselt =tjäpse  (SgAbl  >tjäpne !02_A	et	f	\N
177491	tjäpselt	?tjäpselt =tjäpse  (SgAbl  >tjäpse !06_S	et	f	\N
177201	pooleloli	?pooleloli =pooleloli  (SgAdt  >poolelol !19_S	et	f	\N
177202	pooleloli	?pooleloli =loli  (SgN  >poole+loli !17_S	et	f	\N
177203	pooleloli	?pooleloli =loli  (SgG  >poole+loli !17_S	et	f	\N
177204	pooleloli	?pooleloli =loli  (SgP  >poole+loli !17_S	et	f	\N
177205	pooleloli	?pooleloli =eloli  (ID  >pool+eloli !41_D	et	f	\N
177206	pooleloli	?pooleloli =eloli  (SgG  >pool+elol !02_S	et	f	\N
177213	vahtre	?vahtre =vahtre  (SgN  >vahtre !06_S	et	f	\N
177214	vahtre	?vahtre =vahtre  (SgG  >vahtre !06_S	et	f	\N
177215	vahtre	?vahtre =vahtre  (IndPrPs_  >vahtrema !27_V	et	f	\N
177216	vahtre	?vahtre =vahtre  (ImpPrSg2  >vahtrema !27_V	et	f	\N
177222	70ndatel	?ndatel =ndate  (PlAd  >ndatt !22_S	et	f	\N
177223	70ndatel	?ndatel =ndatel  (SgN  >ndatel !02_S	et	f	\N
177230	öölälupeod	?öölälupeod =öölälupeo  (PlN  >öölälupeo !01_S	et	f	\N
177231	öölälupeod	?öölälupeod =öölälupeod  (SgN  >öölälupeod !22_S	et	f	\N
177232	öölälupeod	?öölälupeod =lälupeo  (PlN  >öö+lälupeo !01_S	et	f	\N
177233	öölälupeod	?öölälupeod =lälupeod  (SgN  >öö+lälupeod !22_S	et	f	\N
177234	ersp	?ersp =ersp  (SgN  >ersp !22_S	et	f	\N
177242	90ndatel	?ndatel =ndate  (PlAd  >ndatt !22_S	et	f	\N
177243	90ndatel	?ndatel =ndatel  (SgN  >ndatel !02_S	et	f	\N
177248	alliksaar	alliksaar =aar  (SgN  >all+iks+aar !22_S	et	f	\N
177249	alliksaar	alliksaar =saar  (SgN  >allik+saar !13_S	et	f	\N
177250	masing	?masing =masing  (SgN  >masing !02_S	et	f	\N
177254	ebaõiglaselt	ebaõiglaselt =õiglase  (SgAbl  >eba+õiglane !12?10_A	et	f	\N
177255	ebaõiglaselt	ebaõiglaselt =õiglaselt  (ID  >eba+õiglaselt !41_D	et	f	\N
177256	ebaõiglaselt	"eba+õiglaselt %õiglase  )LT_mD  <eba+õiglane ;10_A	et	f	\N
177257	ebaõiglaselt	"eba+õiglaselt %õiglase  )LT_mD  <eba+õiglane ;12_A	et	f	\N
177265	masingu	?masingu =masingu  (SgN  >masingu !01_S	et	f	\N
177266	masingu	?masingu =masingu  (SgG  >masingu !01_S	et	f	\N
177267	masingu	?masingu =masingu  (SgG  >masing !02_S	et	f	\N
177268	masingu	?masingu =masingu  (IndPrPs_  >masinguma !27_V	et	f	\N
177269	masingu	?masingu =masingu  (ImpPrSg2  >masinguma !27_V	et	f	\N
177306	kõlaline	kõlaline =kõlaline  (SgN  >kõlaline !12_A	et	f	\N
177307	kõlaline	"kõlaline %kõla  )LINE_aA  <kõla ;17_S	et	f	\N
177308	kõnest	kõnest =kõne  (SgEl  >kõne !16_S	et	f	\N
177309	kõnest	kõnest =kõnes  (SgP  >kõnene !10_A	et	f	\N
177310	kõnest	"kõnene %kõne  )NE_aA  <kõne ;16_S	et	f	\N
177325	tema-pööre	tema-pööre =pööre  (SgN  >tema-pööre !05_S	et	f	\N
177326	tema-pööre	tema-pööre =pööre  (SgN  >tema-pööre !06_S	et	f	\N
177327	tema-pööre	tema-pööre =pööre  (PlP  >tema-pöör !22_S	et	f	\N
177342	kolmandavälteliste	kolmandavälteliste =vältelis  (PlG  >kolmanda+välteline !12_A	et	f	\N
177343	kolmandavälteliste	"kolmanda+välteline %välte  )LINE_aA  <kolmanda+välde ;06_S	et	f	\N
177386	2viga	viga =viga  (SgN  >viga !18_S	et	f	\N
177387	2viga	viga =viga  (SgP  >viga !18_S	et	f	\N
177391	hüpata-	hüpata- =hüpa  (Inf  >hüppama !29_V	et	f	\N
177392	hüpata-	hüpata- =hüpa  (IndPrIps_  >hüppama !29_V	et	f	\N
177393	hüpata-	hüpata- =hüpata  (IndPrPs_  >hüpatama !27_V	et	f	\N
177394	hüpata-	hüpata- =hüpata  (ImpPrSg2  >hüpatama !27_V	et	f	\N
177426	sõitsidläksid	?sõitsidläksid =sõitsidläksi  (PlN  >sõitsidläks !22_S	et	f	\N
177427	sõitsidläksid	?sõitsidläksid =sõitsidläksi  (IndPrSg2  >sõitsidläksima !28_V	et	f	\N
177447	text-indent	?text-indent =indent  (SgN  >text-indent !22_S	et	f	\N
177450	stylefont-size	?stylefont-size =size  (SgN  >stylefont-size !16_S	et	f	\N
177451	stylefont-size	?stylefont-size =size  (SgG  >stylefont-size !16_S	et	f	\N
177453	letter-spacing	?letter-spacing =spacing  (SgN  >letter-spacing !02_S	et	f	\N
177455	passivne	?passivne =passivne  (SgN  >passivne !02_A	et	f	\N
177456	passivne	?passivne =passivne  (PlP  >passivn !22_S	et	f	\N
177457	passivne	?passivne =passivne  (IndPrPs_  >passivnema !27_V	et	f	\N
177458	passivne	?passivne =passivne  (ImpPrSg2  >passivnema !27_V	et	f	\N
177459	materiaalsete	materiaalsete =materiaalse  (PlG  >materiaalne !02_A	et	f	\N
177460	materiaalsete	materiaalsete =sete  (SgN  >materiaal+sete !06_S	et	f	\N
177464	loto-	loto- =loto  (SgN  >loto !16_S	et	f	\N
177465	loto-	loto- =loto  (SgG  >loto !16_S	et	f	\N
177467	kõ	### kõ	et	f	\N
177472	vinitelnõi	?vinitelnõi =vinitelnõi  (SgN  >vinitelnõi !26_S	et	f	\N
177473	vinitelnõi	?vinitelnõi =vinitelnõi  (SgG  >vinitelnõi !26_S	et	f	\N
177477	olevas	olevas =oleva  (SgIn  >olev !02_A	et	f	\N
177478	olevas	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
177481	kooliskäimine	kooliskäimine =käimine  (SgN  >koolis+käimine !12?10_S	et	f	\N
177482	kooliskäimine	"koolis+käimine %käimi  )NE_aA  <koolis+käim ;22_S	et	f	\N
177485	mainfinitiivist	?mainfinitiivist =mainfinitiivi  (SgEl  >mainfinitiivi !16_S	et	f	\N
177486	mainfinitiivist	?mainfinitiivist =mainfinitiivi  (SgEl  >mainfinitiiv !22_S	et	f	\N
177487	mainfinitiivist	?mainfinitiivist =mainfinitiivis  (SgP  >mainfinitiivis !09_S	et	f	\N
177488	kõne-	kõne- =kõne  (SgN  >kõne !16_S	et	f	\N
177489	kõne-	kõne- =kõne  (SgG  >kõne !16_S	et	f	\N
177501	kontroltöö	?kontroltöö =kontroltöö  (SgN  >kontroltöö !26_S	et	f	\N
177228	reformida	reformida =ida  (SgG  >reform+ida !17_S	et	f	\N
177229	reformida	reformida =ida  (SgP  >reform+ida !17_S	et	f	\N
177241	im-	### im-	et	f	\N
177244	stagneerimise	?stagneerimise =stagneerimise  (SgG  >stagneerimine !12_S	et	f	\N
177251	palvedega	### palvedega	et	f	\N
177264	kirjanukutena	### kirjanukutena	et	f	\N
177270	1990ndani	?ndani =ndani  (SgN  >ndani !17_S	et	f	\N
177271	1990ndani	?ndani =ndani  (SgG  >ndani !17_S	et	f	\N
177273	1990ndani	?ndani =ndani  (SgP  >ndani !17_S	et	f	\N
177275	1990ndani	?ndani =ndani  (IndPrPs_  >ndanima !27_V	et	f	\N
177276	1990ndani	?ndani =ndani  (ImpPrSg2  >ndanima !27_V	et	f	\N
177284	sõnastusõpetuse	?sõnastusõpetuse =sõnastusõpetuse  (SgG  >sõnastusõpetus !11?09_S	et	f	\N
177285	sõnastusõpetuse	?sõnastusõpetuse =stusõpetuse  (SgG  >sõna+stusõpetus !11?09_S	et	f	\N
177294	põhistruktuuri	põhistruktuuri =struktuuri  (SgG  >põhi+struktuur !22_S	et	f	\N
177295	põhistruktuuri	põhistruktuuri =struktuuri  (SgP  >põhi+struktuur !22_S	et	f	\N
177296	põhistruktuuri	põhistruktuuri =struktuuri  (SgAdt  >põhi+struktuur !22_S	et	f	\N
177311	kohakäänetevead	?kohakäänetevead =kohakäänetevea  (PlN  >kohakäänetevea !26_S	et	f	\N
177312	kohakäänetevead	?kohakäänetevead =kohakäänetevea  (SgP  >kohakäänetevea !26_S	et	f	\N
177313	kohakäänetevead	?kohakäänetevead =kohakäänetevead  (SgN  >kohakäänetevead !22_S	et	f	\N
177314	kohakäänetevead	?kohakäänetevead =käänetevea  (PlN  >koha+käänetevea !26_S	et	f	\N
177315	kohakäänetevead	?kohakäänetevead =käänetevea  (SgP  >koha+käänetevea !26_S	et	f	\N
177316	kohakäänetevead	?kohakäänetevead =käänetevead  (SgN  >koha+käänetevead !22_S	et	f	\N
177347	õppivale	õppivale =õppiva  (SgAll  >õppiv !02_A	et	f	\N
177348	õppivale	"õppiv %õppi  )V_vA  <õppima ;28_V	et	f	\N
177372	tabei	?tabei =tabei  (SgN  >tabei !26_S	et	f	\N
177373	tabei	?tabei =tabei  (SgG  >tabei !26_S	et	f	\N
177375	õp	### õp	et	f	\N
177378	kü1l	### kü1l	et	f	\N
177382	asendused	asendused =asenduse  (PlN  >asendus !11_S	et	f	\N
177383	asendused	"asendus %asenda  )US_vS  <asendama ;27_V	et	f	\N
177404	rebaselt	rebaselt =rebase  (SgAbl  >rebane !10_S	et	f	\N
177405	rebaselt	"rebane %reba  )NE_aA  <reba ;17_S	et	f	\N
177406	rebaselt	rebaselt =rebaselt  (ID  >rebaselt !41_D	et	f	\N
177407	rebaselt	"rebaselt %reba  )SELT_mD  <reba ;17_S	et	f	\N
177408	a1ati	?aati =aati  (ID  >aati !41_D	et	f	\N
177409	a1ati	?aati =aati  (SgP  >aat !22_S	et	f	\N
177410	a1ati	?aati =aati  (SgAdt  >aat !22_S	et	f	\N
177430	kärtner	?kärtner =kärtner  (SgN  >kärtner !02_S	et	f	\N
177431	llinna	?llinna =llinna  (SgN  >llinna !16_S	et	f	\N
177432	llinna	?llinna =llinna  (SgG  >llinna !16_S	et	f	\N
177433	llinna	?llinna =llinna  (IndPrPs_  >llinnama !29_V	et	f	\N
177434	llinna	?llinna =llinna  (ImpPrSg2  >llinnama !29_V	et	f	\N
177437	alignright	### alignright	et	f	\N
177440	stylemargin	?stylemargin =stylemargi  (IndPrSg1  >stylemarkima !28_V	et	f	\N
177441	stylemargin	?stylemargin =stylemargin  (SgN  >stylemargin !02_S	et	f	\N
177445	432pt	### 432pt	et	f	\N
177448	72pt	### 72pt	et	f	\N
177462	loto	loto =loto  (SgN  >loto !16_S	et	f	\N
177463	loto	loto =loto  (SgG  >loto !16_S	et	f	\N
177468	arvavadki	arvavadki =arva  (IndPrPl3^  >arvama !29_V	et	f	\N
177469	arvavadki	arvavadki =arvava  (PlN^  >arvav !02_A	et	f	\N
177470	arvavadki	"arvav %arva  )V_vA^  <arvama ;29_V	et	f	\N
177471	arvavadki	arvavadki =ava  (PlN^  >arv+ava !17_S	et	f	\N
177505	insenär	?insenär =insenär  (SgN  >insenär !19_S	et	f	\N
177511	algvõrdest	algvõrdest =võrde  (SgEl  >alg+võrre !06_S	et	f	\N
177512	algvõrdest	algvõrdest =võrdes  (SgP  >alg+võrdene !12~10_A	et	f	\N
177513	algvõrdest	"alg+võrdene %võrde  )NE_aA  <alg+võrre ;06_S	et	f	\N
177519	nõmmes	nõmmes =nõmme  (SgIn  >nõmm !22_S	et	f	\N
177520	nõmmes	nõmmes =nõmme  (PlIn  >nõmm !22_S	et	f	\N
177521	kahekümmend	?kahekümmend =kahekümmend  (SgN  >kahekümmend !22_S	et	f	\N
177542	jättaksjä	### jättaksjä	et	f	\N
177549	rohtu	rohtu =rohtu  (ID  >rohtu !41_D	et	f	\N
177550	rohtu	rohtu =rohtu  (SgP  >roht !22_S	et	f	\N
177551	rohtu	rohtu =rohtu  (SgP  >rohi !24_S	et	f	\N
177552	rohtu	rohtu =rohtu  (SgAdt  >roht !22_S	et	f	\N
177553	rohtu	rohtu =rohtu  (SgAdt  >rohi !24_S	et	f	\N
177554	rohtu	rohtu =rohtu  (IndPrPs_  >rohtuma !27_V	et	f	\N
177555	rohtu	rohtu =rohtu  (ImpPrSg2  >rohtuma !27_V	et	f	\N
177556	kubisevad	kubisevad =kubise  (IndPrPl3  >kubisema !27_V	et	f	\N
177557	kubisevad	kubisevad =kubiseva  (PlN  >kubisev !02_A	et	f	\N
177558	kubisevad	"kubisev %kubise  )V_vA  <kubisema ;27_V	et	f	\N
177593	loema	?loema =loema  (SgN  >loema !16_S	et	f	\N
177594	loema	?loema =loema  (SgG  >loema !16_S	et	f	\N
177595	loema	?loema =loema  (IndPrPs_  >loemama !29_V	et	f	\N
177596	loema	?loema =loema  (ImpPrSg2  >loemama !29_V	et	f	\N
177600	keelelaagrilaste	keelelaagrilaste =las  (PlG  >keele+laagri+laps !14_S	et	f	\N
177601	keelelaagrilaste	keelelaagrilaste =laste  (PlP  >keele+laagri+last !22_S	et	f	\N
177605	keeruliste	keeruliste =keerulis  (PlG  >keeruline !12_A	et	f	\N
177253	1989a	### 1989a	et	f	\N
177258	jeltsin	?jeltsin =jeltsi  (IndPrSg1  >jeltsima !28_V	et	f	\N
177259	jeltsin	?jeltsin =jeltsin  (SgN  >jeltsin !02_S	et	f	\N
177260	20sept	?sept =sept  (SgN  >sept !22_S	et	f	\N
177262	täisliige	täisliige =liige  (SgN  >täis+liige !05_S	et	f	\N
177263	täisliige	täisliige =liige  (PlP  >täis+liig !22_S	et	f	\N
177272	pidevaks	pidevaks =pideva  (SgTr  >pidev !02_A	et	f	\N
177274	pidevaks	pidevaks =vaks  (SgN  >pide+vaks !22_S	et	f	\N
177279	intelligentsus	intelligentsus =intelligentsus  (SgN  >intelligentsus !11~09_S	et	f	\N
177280	intelligentsus	"intelligentsus %intelligentse  )US_aS  <intelligentne ;02_A	et	f	\N
177282	aastaste	aastaste =aastas  (PlG  >aastane !12~10_A	et	f	\N
177283	aastaste	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
177291	konsonantühendite	?konsonantühendite =konsonantühendi  (IndPrPl2  >konsonantühentima !28_V	et	f	\N
177328	õppinnud	?õppinnud =õppinnu  (PlN  >õppinnu !01_S	et	f	\N
177329	õppinnud	?õppinnud =õppinnu  (IndPrSg2  >õppinnuma !27_V	et	f	\N
177336	sjöma	?sjöma =sjöma  (SgN  >sjöma !17_S	et	f	\N
177337	sjöma	?sjöma =sjöma  (SgG  >sjöma !17_S	et	f	\N
177338	sjöma	?sjöma =sjöma  (SgP  >sjöma !17_S	et	f	\N
177339	sjöma	?sjöma =sjöma  (IndPrPs_  >sjömama !27_V	et	f	\N
177340	sjöma	?sjöma =sjöma  (ImpPrSg2  >sjömama !27_V	et	f	\N
177351	põhjustavad	põhjustavad =põhjusta  (IndPrPl3  >põhjustama !27_V	et	f	\N
177352	põhjustavad	põhjustavad =põhjustava  (PlN  >põhjustav !02_A	et	f	\N
177353	põhjustavad	"põhjustav %põhjusta  )V_vA  <põhjustama ;27_V	et	f	\N
177367	dsse	### dsse	et	f	\N
177368	kõlasid	kõlasid =kõla  (PlP  >kõla !17_S	et	f	\N
177369	kõlasid	kõlasid =kõla  (IndIpfSg2  >kõlama !27_V	et	f	\N
177370	kõlasid	kõlasid =kõla  (IndIpfPl3  >kõlama !27_V	et	f	\N
177376	ilaste	ilaste =ilas  (PlG  >ilane !10_A	et	f	\N
177377	ilaste	"ilane %ila  )NE_aA  <ila ;17_S	et	f	\N
177388	ksid	### ksid	et	f	\N
177389	xc	### xc	et	f	\N
177416	da-tegevusni	?da-tegevusni =tegevusni  (SgG  >da-tegevusn !22_S	et	f	\N
177417	da-tegevusni	?da-tegevusni =tegevusni  (SgP  >da-tegevusn !22_S	et	f	\N
177418	da-tegevusni	?da-tegevusni =tegevusni  (SgAdt  >da-tegevusn !22_S	et	f	\N
177419	da-tegevusni	?da-tegevusni =tegevusni  (IndPrPs_  >da-tegevusnima !28_V	et	f	\N
177420	da-tegevusni	?da-tegevusni =tegevusni  (ImpPrSg2  >da-tegevusnima !28_V	et	f	\N
177421	da-tegevusni	?da-tegevusni =usni  (SgN  >da-tegev+usni !16_S	et	f	\N
177422	da-tegevusni	?da-tegevusni =usni  (SgG  >da-tegev+usni !16_S	et	f	\N
177423	da-tegevusni	?da-tegevusni =usni  (SgG  >da-tegev+usn !22_S	et	f	\N
177424	da-tegevusni	?da-tegevusni =usni  (SgP  >da-tegev+usn !22_S	et	f	\N
177425	da-tegevusni	?da-tegevusni =usni  (SgAdt  >da-tegev+usn !22_S	et	f	\N
177428	asendamise	asendamise =asendamise  (SgG  >asendamine !12_S	et	f	\N
177429	asendamise	"asendamine %asenda  )MINE_vS  <asendama ;27_V	et	f	\N
177438	classmsonormal	?classmsonormal =classmsonorma  (SgAd  >classmsonorma !16_S	et	f	\N
177439	classmsonormal	?classmsonormal =classmsonormal  (SgN  >classmsonormal !02_S	et	f	\N
177446	text-align	?text-align =align  (SgN  >text-align !22_S	et	f	\N
177479	interferentsiveaga	?interferentsiveaga =interferentsivea  (SgKom  >interferentsivea !26_S	et	f	\N
177480	interferentsiveaga	?interferentsiveaga =ferentsivea  (SgKom  >inter+ferentsivea !26_S	et	f	\N
177494	tjäna	?tjäna =tjäna  (SgN  >tjäna !17_S	et	f	\N
177495	tjäna	?tjäna =tjäna  (SgG  >tjäna !17_S	et	f	\N
177496	tjäna	?tjäna =tjäna  (SgP  >tjäna !17_S	et	f	\N
177497	tjäna	?tjäna =tjäna  (IndPrPs_  >tjänama !27_V	et	f	\N
177498	tjäna	?tjäna =tjäna  (ImpPrSg2  >tjänama !27_V	et	f	\N
177528	kolmkümmenes	?kolmkümmenes =kolmkümmene  (PlIn  >kolmkümmen !19_S	et	f	\N
177532	hildumisvead	?hildumisvead =hildumisvea  (PlN  >hildumisvea !26_S	et	f	\N
177533	hildumisvead	?hildumisvead =hildumisvea  (SgP  >hildumisvea !26_S	et	f	\N
177534	hildumisvead	?hildumisvead =hildumisvead  (SgN  >hildumisvead !22_S	et	f	\N
177548	määletame	?määletame =määleta  (IndPrPl1  >määletama !27_V	et	f	\N
177559	kubisevad	kubisevad =kubise  (IndPrPl3  >kubisema !27_V	et	f	\N
177560	kubisevad	kubisevad =kubiseva  (PlN  >kubisev !02_A	et	f	\N
177561	kubisevad	"kubisev %kubise  )V_vA  <kubisema ;27_V	et	f	\N
177562	tahsin	?tahsin =tahsi  (IndPrSg1  >tahsima !28_V	et	f	\N
177563	tahsin	?tahsin =tahsin  (SgN  >tahsin !02_S	et	f	\N
177564	noorematel	noorematel =noorema  (PlAd  >noorem !02_A	et	f	\N
177565	noorematel	"noorem %noore  )M_cA  <noor ;13_AS	et	f	\N
177566	noorematel	noorematel =ate  (PlAd  >noorem+att !22_S	et	f	\N
177567	noorematel	noorematel =mate  (SgAd  >noore+mate !16_S	et	f	\N
177568	noorematel	noorematel =mate  (PlAd  >noore+matt !22_SA	et	f	\N
177577	üheski	üheski =ühe  (SgIn  >ükski !00_P	et	f	\N
177579	üheski	üheski =ühe  (SgIn^  >üks !22_NP	et	f	\N
177580	üheski	üheski =ühes  (ID^  >ühes !41_DK	et	f	\N
177597	tõedus	?tõedus =tõedu  (SgIn  >tõedu !16_S	et	f	\N
177598	tõedus	?tõedus =tõedu  (IndIpfSg3  >tõeduma !27_V	et	f	\N
177599	tõedus	?tõedus =tõedus  (SgN  >tõedus !11~09_S	et	f	\N
177602	rõivastega	rõivastega =rõivas  (PlKom  >rõivas !07_S	et	f	\N
177603	rõivastega	rõivastega =rõivas  (PlKom  >rõivane !10_A	et	f	\N
177454	01ptev-51	### 01ptev-51	et	f	\N
177474	verbirektsioonivead	?verbirektsioonivead =verbirektsioonivea  (PlN  >verbirektsioonivea !26_S	et	f	\N
177475	verbirektsioonivead	?verbirektsioonivead =verbirektsioonivea  (SgP  >verbirektsioonivea !26_S	et	f	\N
177476	verbirektsioonivead	?verbirektsioonivead =verbirektsioonivead  (SgN  >verbirektsioonivead !22_S	et	f	\N
177499	tjöötan	?tjöötan =tjööta  (IndPrSg1  >tjöötama !27_V	et	f	\N
177500	tjöötan	?tjöötan =tjöötan  (SgN  >tjöötan !02_S	et	f	\N
177517	põltsamaal	põltsamaal =maa  (SgAd  >põltsa+maa !26_S	et	f	\N
177518	põltsamaal	põltsamaal =maal  (SgN  >põltsa+maal !22_S	et	f	\N
177526	ütlemine	ütlemine =ütlemine  (SgN  >ütlemine !12_S	et	f	\N
177527	ütlemine	"ütlemine %ütle  )MINE_vS  <ütlema ;30_V	et	f	\N
177535	väljapool	väljapool =pool  (ID  >välja+pool !41_DK	et	f	\N
177536	väljapool	väljapool =pool  (SgN  >välja+pool !13_NS	et	f	\N
177537	väljapool	väljapool =pool  (SgN  >välja+pool !22_S	et	f	\N
177539	gekiri	?gekiri =gekiri  (SgN  >gekiri !01_S	et	f	\N
177540	gekiri	?gekiri =gekiri  (SgG  >gekiri !01_S	et	f	\N
177541	gekiri	?gekiri =gekiri  (SgG  >gekir !02_S	et	f	\N
177572	tööb	?tööb =tööb  (SgN  >tööb !22_S	et	f	\N
177584	siija	?siija =siija  (SgN  >siija !01_S	et	f	\N
177585	siija	?siija =siija  (SgG  >siija !01_S	et	f	\N
177586	siija	?siija =siija  (IndPrPs_  >siijama !29_V	et	f	\N
177592	siija	?siija =siija  (ImpPrSg2  >siijama !29_V	et	f	\N
177609	ajavormi	ajavormi =vormi  (SgG  >aja+vorm !22_S	et	f	\N
177610	ajavormi	ajavormi =vormi  (SgP  >aja+vorm !22_S	et	f	\N
177611	ajavormi	ajavormi =vormi  (SgAdt  >aja+vorm !22_S	et	f	\N
177623	koledamiks	koledamiks =koledami  (SgTr  >koledam !02_A	et	f	\N
177624	koledamiks	"koledam %koleda  )M_cA  <kole ;02_A	et	f	\N
177625	koledamaks	koledamaks =koledama  (SgTr  >koledam !02_A	et	f	\N
177626	koledamaks	"koledam %koleda  )M_cA  <kole ;02_A	et	f	\N
177633	organiseerijana	organiseerijana =organiseerija  (SgEs  >organiseerija !01_S	et	f	\N
177634	organiseerijana	"organiseerija %organiseeri  )JA_vS  <organiseerima ;28_V	et	f	\N
177644	mitte-enesekohasus	mitte-enesekohasus =kohasus  (SgN  >mitte-enese+kohasus !11_S	et	f	\N
177645	mitte-enesekohasus	"mitte-enese+kohasus %koha  )SUS_aS  <mitte-enese+koha ;17_S	et	f	\N
177646	mitte-enesekohasus	"mitte-enese+kohasus %koha  )SUS_aS  <mitte-enese+koht ;22_S	et	f	\N
177666	maodsates	?maodsates =maodsa  (PlIn  >maodsa !01_S	et	f	\N
177667	maodsates	?maodsates =maodsa  (Ger  >maodsama !29_V	et	f	\N
177668	maodsates	?maodsates =maodsate  (PlIn  >maodsatt !22_S	et	f	\N
177669	maodsates	?maodsates =dsate  (PlIn  >mao+dsatt !22_S	et	f	\N
177670	maodsates	?maodsates =dsates  (SgN  >mao+dsates !09_S	et	f	\N
177676	lingitusi	lingitusi =lingitusi  (PlP  >lingitus !11_S	et	f	\N
177677	lingitusi	"lingitus %lingi  )TUS2_aS  <link ;22_S	et	f	\N
177685	pingulolekult	?pingulolekult =pingulolekult  (ID  >pingulolekult !41_D	et	f	\N
177688	keksealised	?keksealised =keksealise  (PlN  >keksealine !12?10_A	et	f	\N
177693	hoolimatult	hoolimatult =hoolimatu  (SgAbl  >hoolimatu !01_A	et	f	\N
177694	hoolimatult	"hoolimatu %hooli  )MATU_vA  <hoolima ;28_V	et	f	\N
177695	hoolimatult	hoolimatult =hoolimatult  (ID  >hoolimatult !41_D	et	f	\N
177696	hoolimatult	"hoolimatult %hooli  )MATULT_mD  <hoolima ;28_V	et	f	\N
177697	hoolimatult	"hoolimatult %hoolimatu  )LT_mD  <hoolimatu ;01_A	et	f	\N
177698	hoolimatult	hoolimatult =limatu  (SgAbl  >hoo+limatu !01_A	et	f	\N
177699	hoolimatult	"hoo+limatu %lima  )TU2_kA  <hoo+lima ;17_S	et	f	\N
177700	hoolimatult	"hoo+limatult %lima  )TULT2_mD  <hoo+lima ;17_S	et	f	\N
177703	haigestuvad	haigestuvad =haigestu  (IndPrPl3  >haigestuma !27_V	et	f	\N
177704	haigestuvad	haigestuvad =haigestuva  (PlN  >haigestuv !02_A	et	f	\N
177705	haigestuvad	"haigestuv %haigestu  )V_vA  <haigestuma ;27_V	et	f	\N
177706	70-ndatel	?-ndatel =ndate  (PlAd  >-ndatt !22_S	et	f	\N
177707	70-ndatel	?-ndatel =ndatel  (SgN  >-ndatel !02_S	et	f	\N
177729	purskkaeve	purskkaeve =kaeve  (SgN  >pursk+kaeve !06_S	et	f	\N
177730	purskkaeve	purskkaeve =kaeve  (SgG  >pursk+kaeve !06_S	et	f	\N
177731	purskkaeve	purskkaeve =kaeve  (PlP  >pursk+kaev !22_S	et	f	\N
177734	värvilised	värvilised =värvilise  (PlN  >värviline !12_A	et	f	\N
177735	värvilised	"värviline %värvi  )LINE_aA  <värv ;22_S	et	f	\N
177752	punaseks	punaseks =punase  (SgTr  >punane !10_AS	et	f	\N
177753	punaseks	"punane %puna  )NE_aA  <puna ;17_S	et	f	\N
177755	punaseks	punaseks =seks  (SgN  >puna+seks !22_S	et	f	\N
177759	kastanipuu	kastanipuu =puu  (SgN  >kastani+puu !26_S	et	f	\N
177760	kastanipuu	kastanipuu =puu  (SgG  >kastani+puu !26_S	et	f	\N
177773	lompudel	?lompudel =lompu  (PlAd  >lompu !16_S	et	f	\N
177785	ärjest	?ärjest =ärje  (SgEl  >ärje !06_S	et	f	\N
177786	ärjest	?ärjest =ärjes  (SgP  >ärjes !09_S	et	f	\N
177787	ärjest	?ärjest =ärjes  (SgP  >ärjene !10_A	et	f	\N
177791	nädalait	?nädalait =nädalait  (SgN  >nädalait !22_S	et	f	\N
177797	puud-põsad	?puud-põsad =põsa  (PlN  >puud-põsa !17_S	et	f	\N
177798	puud-põsad	?puud-põsad =põsa  (IndPrSg2  >puud-põsama !27_V	et	f	\N
177810	valmivaid	valmivaid =valmiva  (PlP  >valmiv !02_A	et	f	\N
177812	valmivaid	"valmiv %valmi  )V_vA  <valmima ;27_V	et	f	\N
177492	tjäpselt	?tjäpselt =tjäpse  (PlAbl  >tjäps !22_S	et	f	\N
177493	tjäpselt	?tjäpselt =tjäpselt  (ID  >tjäpselt !41_D	et	f	\N
177506	hüpan	?hüpan =hüpa  (IndPrSg1  >hüpama !27_V	et	f	\N
177507	hüpan	?hüpan =hüpan  (SgN  >hüpan !02_S	et	f	\N
177508	omadusõna	?omadusõna =õna  (SgN  >omadus+õna !17_S	et	f	\N
177509	omadusõna	?omadusõna =õna  (SgG  >omadus+õna !17_S	et	f	\N
177510	omadusõna	?omadusõna =õna  (SgP  >omadus+õna !17_S	et	f	\N
177538	e-1	### e-1	et	f	\N
177575	olukordas	?olukordas =olukorda  (SgIn  >olukorda !16_S	et	f	\N
177576	olukordas	?olukordas =olukorda  (IndIpfSg3  >olukordama !27_V	et	f	\N
177578	olukordas	?olukordas =kordas  (SgN  >olu+kordas !07_S	et	f	\N
177581	mänguid	?mänguid =mängui  (PlN  >mängui !26_S	et	f	\N
177582	mänguid	?mänguid =mängui  (SgP  >mängui !26_S	et	f	\N
177583	mänguid	?mänguid =mänguid  (SgN  >mänguid !22_S	et	f	\N
177587	uurja	?uurja =uurja  (SgN  >uurja !01_S	et	f	\N
177588	uurja	?uurja =uurja  (SgG  >uurja !01_S	et	f	\N
177589	uurja	?uurja =uurja  (SgG  >uurjas !02_A	et	f	\N
177590	uurja	?uurja =uurja  (IndPrPs_  >uurjama !29_V	et	f	\N
177591	uurja	?uurja =uurja  (ImpPrSg2  >uurjama !29_V	et	f	\N
177612	teadmistest	teadmistest =teadmis  (PlEl  >teadmine !12?10_S	et	f	\N
177613	teadmistest	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
177614	teadmistest	teadmistest =test  (SgN  >teadmis+test !22_S	et	f	\N
177621	muutmise	muutmise =muutmise  (SgG  >muutmine !12?10_S	et	f	\N
177622	muutmise	"muutmine %muut  )MINE_vS  <muutma ;34_V	et	f	\N
177627	korratud	korratud =korra  (PtsPtIps  >kordama !29_V	et	f	\N
177628	korratud	korratud =korratu  (PlN  >korratu !01_AS	et	f	\N
177629	korratud	"korratu %korra  )TU1_vS  <kordama ;29_V	et	f	\N
177630	korratud	"korratu %korra  )TU2_kA  <kord ;22_S	et	f	\N
177631	korratud	korratud =korratud  (ID  >korratud !41_A	et	f	\N
177632	korratud	"korratud %korra  )TUD_vA  <kordama ;29_V	et	f	\N
177647	suhtlemisjulgus	suhtlemisjulgus =julgus  (SgN  >suhtlemis+julgus !11~09_S	et	f	\N
177648	suhtlemisjulgus	"suhtlemis+julgus %julge  )US_aS  <suhtlemis+julge ;01_A	et	f	\N
177652	finantsijuhi	?finantsijuhi =ijuhi  (SgN  >finants+ijuhi !01_S	et	f	\N
177653	finantsijuhi	?finantsijuhi =ijuhi  (SgG  >finants+ijuhi !01_S	et	f	\N
177659	autojuhiloa	autojuhiloa =loa  (SgG  >auto+juhi+luba !18_S	et	f	\N
177660	autojuhiloa	autojuhiloa =loa  (SgG  >auto+juhi+luga !18_S	et	f	\N
177674	kallihinnalisi	kallihinnalisi =hinnalisi  (PlP  >kalli+hinnaline !12_A	et	f	\N
177675	kallihinnalisi	"kalli+hinnaline %hinna  )LINE_aA  <kalli+hind ;22_S	et	f	\N
177678	tegevusvabadus	tegevusvabadus =vabadus  (SgN  >tegevus+vabadus !11_S	et	f	\N
177679	tegevusvabadus	"tegevus+vabadus %vaba  )US_aS  <tegevus+vaba ;17_A	et	f	\N
177680	narkootikumi	narkootikumi =narkootikumi  (SgG  >narkootikum !19_S	et	f	\N
177681	narkootikumi	narkootikumi =narkootikumi  (SgP  >narkootikum !19_S	et	f	\N
177682	narkootikumi	narkootikumi =narkootikumi  (SgAdt  >narkootikum !19_S	et	f	\N
177683	emotsionaalsuseid	emotsionaalsuseid =emotsionaalsuse  (PlP  >emotsionaalsus !09_S	et	f	\N
177684	emotsionaalsuseid	"emotsionaalsus %emotsionaalse  )US_aS  <emotsionaalne ;02_A	et	f	\N
177732	pariis	?pariis =parii  (SgIn  >parii !26_S	et	f	\N
177733	pariis	?pariis =pariis  (SgN  >pariis !22_S	et	f	\N
177741	manguasjad	?manguasjad =manguasja  (PlN  >manguasjas !02_A	et	f	\N
177742	manguasjad	?manguasjad =manguasja  (PlN  >manguasja !16_S	et	f	\N
177743	marguse	?marguse =marguse  (SgG  >margus !11~09_S	et	f	\N
177744	tasahiljut	?tasahiljut =hiljut  (SgN  >tasa+hiljut !02_S	et	f	\N
177745	ilmat	?ilmat =ilmat  (SgN  >ilmat !02_S	et	f	\N
177749	kollaseks	kollaseks =kollase  (SgTr  >kollane !10_A	et	f	\N
177750	kollaseks	"kollane %kolla  )NE_aA  <kold ;22_S	et	f	\N
177751	kollaseks	kollaseks =seks  (SgN  >kolla+seks !22_S	et	f	\N
177768	puudel-põõsasteld	?puudel-põõsasteld =põõsasteld  (SgN  >puudel-põõsasteld !22_S	et	f	\N
177769	puudel-põõsasteld	?puudel-põõsasteld =steld  (SgN  >puudel-põõsa+steld !22_S	et	f	\N
177774	järgjärgult	?järgjärgult =järgjärgu  (SgAbl  >järgjärgu !01_S	et	f	\N
177775	järgjärgult	?järgjärgult =järgjärgult  (ID  >järgjärgult !41_D	et	f	\N
177776	kolaseks	kolaseks =kolase  (SgTr  >kolane !10_A	et	f	\N
177777	kolaseks	"kolane %kola  )NE_aA  <kola ;17_S	et	f	\N
177784	aidades	?aidades =aida  (PlIn  >aida !16_S	et	f	\N
177802	kasstanipuult	?kasstanipuult =kasstanipuu  (SgAbl  >kasstanipuu !26_S	et	f	\N
177803	kasstanipuult	?kasstanipuult =kasstanipuult  (ID  >kasstanipuult !41_D	et	f	\N
177804	kasstanipuult	?kasstanipuult =stanipuu  (SgAbl  >kas+stanipuu !26_S	et	f	\N
177814	puudeld-põsasteld	?puudeld-põsasteld =põsasteld  (SgN  >puudeld-põsasteld !22_S	et	f	\N
177825	kaubandusalast	kaubandusalast =ala  (SgEl  >kaubandus+ala !17_S	et	f	\N
177826	kaubandusalast	kaubandusalast =alas  (SgP  >kaubandus+alane !10_AS	et	f	\N
177827	kaubandusalast	"kaubandus+alane %ala  )NE_aA  <kaubandus+ala ;17_S	et	f	\N
177830	algatusvõimeline	algatusvõimeline =võimeline  (SgN  >algatus+võimeline !12_A	et	f	\N
177831	algatusvõimeline	"algatus+võimeline %võime  )LINE_aA  <algatus+võime ;06_S	et	f	\N
177834	loovat	loovat =loo  (KvtPrPs  >looma !38_V	et	f	\N
177835	loovat	loovat =loova  (SgP  >loov !02_A	et	f	\N
177836	loovat	"loov %loo  )V_vA  <looma ;38_V	et	f	\N
177502	kontroltöö	?kontroltöö =kontroltöö  (SgG  >kontroltöö !26_S	et	f	\N
177503	kontroltöö	?kontroltöö =roltöö  (SgN  >kont+roltöö !26_S	et	f	\N
177504	kontroltöö	?kontroltöö =roltöö  (SgG  >kont+roltöö !26_S	et	f	\N
177514	järgnevad	järgnevad =järgne  (IndPrPl3  >järgnema !27_V	et	f	\N
177515	järgnevad	järgnevad =järgneva  (PlN  >järgnev !02_A	et	f	\N
177516	järgnevad	"järgnev %järgne  )V_vA  <järgnema ;27_V	et	f	\N
177522	kakskümnendal	?kakskümnendal =kakskümnenda  (SgAd  >kakskümnenda !16_S	et	f	\N
177523	kakskümnendal	?kakskümnendal =kakskümnendal  (SgN  >kakskümnendal !02_S	et	f	\N
177524	kakskümnendal	?kakskümnendal =kümnenda  (SgAd  >kaks+kümnenda !01_S	et	f	\N
177525	tlemisega	?tlemisega =tlemise  (SgKom  >tlemine !10_A	et	f	\N
177529	kolmekümnes	?kolmekümnes =kolmekümne  (PlIn  >kolmekümn !22_S	et	f	\N
177530	kolmekümnes	?kolmekümnes =kümne  (PlIn  >kolme+kümn !22_S	et	f	\N
177531	kolmekümnes	?kolmekümnes =ekümne  (PlIn  >kolm+ekümn !22_S	et	f	\N
177543	nüiid	?nüiid =nüii  (PlN  >nüii !26_S	et	f	\N
177544	nüiid	?nüiid =nüii  (SgP  >nüii !26_S	et	f	\N
177545	nüiid	?nüiid =nüiid  (SgN  >nüiid !22_S	et	f	\N
177546	abimäärsona	?abimäärsona =abimäärso  (SgEs  >abimäärso !16_S	et	f	\N
177547	abimäärsona	?abimäärsona =määrso  (SgEs  >abi+määrso !16_S	et	f	\N
177569	samaid	?samaid =samai  (PlN  >samai !26_S	et	f	\N
177570	samaid	?samaid =samai  (SgP  >samai !26_S	et	f	\N
177571	samaid	?samaid =samaid  (SgN  >samaid !22_S	et	f	\N
177573	riiku	?riiku =riiku  (SgN  >riiku !16_S	et	f	\N
177574	riiku	?riiku =riiku  (SgG  >riiku !16_S	et	f	\N
177607	laagrilaste	laagrilaste =las  (PlG  >laagri+laps !14_S	et	f	\N
177608	laagrilaste	laagrilaste =laste  (PlP  >laagri+last !22_S	et	f	\N
177615	käänamise	käänamise =käänamise  (SgG  >käänamine !12_S	et	f	\N
177616	käänamise	"käänamine %kääna  )MINE_vS  <käänama ;29_V	et	f	\N
177641	enesekohasus	enesekohasus =kohasus  (SgN  >enese+kohasus !11_S	et	f	\N
177642	enesekohasus	"enese+kohasus %koha  )SUS_aS  <enese+koha ;17_S	et	f	\N
177643	enesekohasus	"enese+kohasus %koha  )SUS_aS  <enese+koht ;22_S	et	f	\N
177649	suhtlemisjulguse	suhtlemisjulguse =julguse  (SgG  >suhtlemis+julgus !11~09_S	et	f	\N
177650	suhtlemisjulguse	"suhtlemis+julgus %julge  )US_aS  <suhtlemis+julge ;01_A	et	f	\N
177663	hoolivad	hoolivad =hooli  (IndPrPl3  >hoolima !28_V	et	f	\N
177664	hoolivad	hoolivad =hooliva  (PlN  >hooliv !02_A	et	f	\N
177665	hoolivad	"hooliv %hooli  )V_vA  <hoolima ;28_V	et	f	\N
177686	hoolitvad	?hoolitvad =hoolitva  (PlN  >hoolitva !01_S	et	f	\N
177687	hoolitvad	?hoolitvad =litva  (PlN  >hoo+litva !16_S	et	f	\N
177689	tervisesse	tervisesse =tervise  (SgIll  >tervis !09~11_S	et	f	\N
177690	tervisesse	tervisesse =tervises  (SgAdt  >tervisene !12_A	et	f	\N
177691	tervisesse	"tervisene %tervise  )NE_aA  <tervis ;09_S	et	f	\N
177692	tervisesse	"tervisene %tervise  )NE_aA  <tervis ;11_S	et	f	\N
177710	hingamist	hingamist =hingamis  (SgP  >hingamine !12_S	et	f	\N
177712	hingamist	"hingamine %hinga  )MINE_vS  <hingama ;29_V	et	f	\N
177713	pööravad	pööravad =pööra  (IndPrPl3  >pöörama !29_V	et	f	\N
177714	pööravad	pööravad =pöörava  (PlN  >pöörav !02_A	et	f	\N
177715	pööravad	"pöörav %pööra  )V_vA  <pöörama ;29_V	et	f	\N
177716	lemmiktegevasala	?lemmiktegevasala =lemmiktegevasala  (SgN  >lemmiktegevasala !01_S	et	f	\N
177717	lemmiktegevasala	?lemmiktegevasala =lemmiktegevasala  (SgG  >lemmiktegevasala !01_S	et	f	\N
177718	lemmiktegevasala	?lemmiktegevasala =asala  (SgN  >lemmik+tegev+asala !01_S	et	f	\N
177719	lemmiktegevasala	?lemmiktegevasala =asala  (SgG  >lemmik+tegev+asala !01_S	et	f	\N
177720	lemmiktegevasala	?lemmiktegevasala =tegevasala  (SgN  >lemmik+tegevasala !01_S	et	f	\N
177721	lemmiktegevasala	?lemmiktegevasala =tegevasala  (SgG  >lemmik+tegevasala !01_S	et	f	\N
177724	terviseest	terviseest =ee  (SgEl  >tervis+esi !15_S	et	f	\N
177725	terviseest	terviseest =ees  (SgP  >tervis+eene !10_A	et	f	\N
177726	terviseest	"tervis+eene %ee  )NE_aA  <tervis+esi ;15_S	et	f	\N
177763	tammetõrusi	?tammetõrusi =tammetõrusi  (PlP  >tammetõrus !11_S	et	f	\N
177764	tammetõrusi	?tammetõrusi =etõrusi  (PlP  >tamm+etõrus !11_S	et	f	\N
177811	aidadest	?aidadest =aida  (PlEl  >aida !16_S	et	f	\N
177813	aidadest	?aidadest =aidades  (SgP  >aidadene !12_A	et	f	\N
177817	lördsi	?lördsi =lördsi  (ID  >lördsi !41_D	et	f	\N
177818	lördsi	?lördsi =lördsi  (SgG  >lörds !22_S	et	f	\N
177819	lördsi	?lördsi =lördsi  (SgP  >lörds !22_S	et	f	\N
177820	lördsi	?lördsi =lördsi  (SgAdt  >lörds !22_S	et	f	\N
177821	lördsi	?lördsi =lördsi  (IndPrPs_  >lördsima !28_V	et	f	\N
177822	lördsi	?lördsi =lördsi  (ImpPrSg2  >lördsima !28_V	et	f	\N
177839	kanditatuur	?kanditatuur =kanditatuur  (SgN  >kanditatuur !22_S	et	f	\N
177840	kanditatuur	?kanditatuur =tatuur  (SgN  >kandi+tatuur !22_S	et	f	\N
177843	esmaspäevini	esmaspäevini =ini  (SgN  >esmas+päev+ini !17_S	et	f	\N
177844	esmaspäevini	esmaspäevini =ini  (SgG  >esmas+päev+ini !17_S	et	f	\N
177845	esmaspäevini	esmaspäevini =ini  (SgP  >esmas+päev+ini !17_S	et	f	\N
177846	esmaspäevini	esmaspäevini =päevi  (SgTer  >esmas+päev !22_S	et	f	\N
177848	tulnukatega	tulnukatega =tulnuka  (PlKom  >tulnuk !02_S	et	f	\N
177849	tulnukatega	tulnukatega =tulnuka  (PlKom  >tulnukas !02_S	et	f	\N
177604	rõivastega	"rõivane %rõiva  )NE_aA  <rõivas ;07_S	et	f	\N
177617	seitsenda	?seitsenda =seitsenda  (SgN  >seitsenda !01_S	et	f	\N
177618	seitsenda	?seitsenda =seitsenda  (SgG  >seitsenda !01_S	et	f	\N
177619	seitsenda	?seitsenda =seitsenda  (IndPrPs_  >seitsendama !27_V	et	f	\N
177620	seitsenda	?seitsenda =seitsenda  (ImpPrSg2  >seitsendama !27_V	et	f	\N
177661	b-kategoria	?b-kategoria =kategoria  (SgN  >b-kategoria !01_S	et	f	\N
177662	b-kategoria	?b-kategoria =kategoria  (SgG  >b-kategoria !01_S	et	f	\N
177671	büroruumides	?büroruumides =büroruumi  (PlIn  >büroruumi !16_S	et	f	\N
177672	büroruumides	?büroruumides =büroruumi  (PlIn  >büroruum !22_S	et	f	\N
177673	büroruumides	?büroruumides =büroruumi  (Ger  >büroruumima !28_V	et	f	\N
177701	sulele	sulele =sule  (SgAll  >sulg !22_S	et	f	\N
177702	sulele	sulele =sule  (PlAll  >sulg !22_S	et	f	\N
177708	suitsetasid	suitsetasid =suitseta  (IndIpfSg2  >suitsetama !27_V	et	f	\N
177709	suitsetasid	suitsetasid =suitseta  (IndIpfPl3  >suitsetama !27_V	et	f	\N
177711	värsket	?värsket =värske  (SgP  >värske !01_AS	et	f	\N
177722	ülaltoodu	ülaltoodu =toodu  (SgN  >ülal+toodu !01_S	et	f	\N
177723	ülaltoodu	ülaltoodu =toodu  (SgG  >ülal+toodu !01_S	et	f	\N
177727	luuvrit	?luuvrit =luuvri  (SgP  >luuver !02_S	et	f	\N
177728	luuvrit	?luuvrit =luuvrit  (SgN  >luuvrit !02_S	et	f	\N
177736	lapsekele	?lapsekele =lapseke  (PlAll  >lapsekk !22_S	et	f	\N
177737	lapsekele	?lapsekele =lapsekele  (PlP  >lapsekel !19_S	et	f	\N
177738	lapsekele	?lapsekele =kele  (SgN  >lapse+kele !16_S	et	f	\N
177739	lapsekele	?lapsekele =kele  (SgG  >lapse+kele !16_S	et	f	\N
177740	lapsekele	?lapsekele =eke  (PlAll  >laps+ekk !22_S	et	f	\N
177754	ehitti	?ehitti =ehitti  (SgN  >ehitti !01_S	et	f	\N
177756	ehitti	?ehitti =ehitti  (SgG  >ehitti !01_S	et	f	\N
177757	ehitti	?ehitti =ehitti  (SgP  >ehitt !22_S	et	f	\N
177758	ehitti	?ehitti =ehitti  (SgAdt  >ehitt !22_S	et	f	\N
177761	tammelt	tammelt =tamme  (SgAbl  >tamm !22_S	et	f	\N
177762	tammelt	tammelt =tamme  (PlAbl  >tamm !22_S	et	f	\N
177770	lahkuvad	lahkuvad =lahku  (IndPrPl3  >lahkuma !27_V	et	f	\N
177771	lahkuvad	lahkuvad =lahkuva  (PlN  >lahkuv !02_A	et	f	\N
177772	lahkuvad	"lahkuv %lahku  )V_vA  <lahkuma ;27_V	et	f	\N
177778	kastanipuuld	?kastanipuuld =kastanipuuld  (SgN  >kastanipuuld !22_S	et	f	\N
177779	kastanipuuld	?kastanipuuld =puuld  (SgN  >kastani+puuld !22_S	et	f	\N
177780	kastanipuuld	?kastanipuuld =anipuuld  (SgN  >kast+anipuuld !22_S	et	f	\N
177781	kastanipuuld	?kastanipuuld =tanipuuld  (SgN  >kas+tanipuuld !22_S	et	f	\N
177782	sarapuuld	?sarapuuld =sarapuuld  (SgN  >sarapuuld !22_S	et	f	\N
177783	sarapuuld	?sarapuuld =puuld  (SgN  >sara+puuld !22_S	et	f	\N
177788	puudelt-poosastelt	?puudelt-poosastelt =poosas  (PlAbl  >puudelt-poosas !07_S	et	f	\N
177789	puudelt-poosastelt	?puudelt-poosastelt =poosas  (PlAbl  >puudelt-poosane !10_A	et	f	\N
177790	puudelt-poosastelt	?puudelt-poosastelt =poosastelt  (ID  >puudelt-poosastelt !41_D	et	f	\N
177801	koläseks	### koläseks	et	f	\N
177805	tammetõrussid	?tammetõrussid =tammetõrussi  (PlN  >tammetõruss !22_S	et	f	\N
177806	tammetõrussid	?tammetõrussid =tammetõrussi  (IndPrSg2  >tammetõrussima !28_V	et	f	\N
177807	tammetõrussid	?tammetõrussid =tõrussi  (PlN  >tamme+tõrussi !01_S	et	f	\N
177808	tammetõrussid	?tammetõrussid =tõrussi  (PlN  >tamme+tõruss !22_S	et	f	\N
177809	tammetõrussid	?tammetõrussid =etõrussi  (PlN  >tamm+etõruss !22_S	et	f	\N
177823	omanaan	?omanaan =omanaan  (SgN  >omanaan !22_S	et	f	\N
177824	omanaan	?omanaan =naan  (SgN  >oma+naan !22_S	et	f	\N
177832	iseseisvane	?iseseisvane =iseseisvane  (SgN  >iseseisvane !12~10_A	et	f	\N
177833	iseseisvane	?iseseisvane =seisvane  (SgN  >ise+seisvane !12~10_A	et	f	\N
177837	ametiauto	ametiauto =auto  (SgN  >ameti+auto !16_S	et	f	\N
177838	ametiauto	ametiauto =auto  (SgG  >ameti+auto !16_S	et	f	\N
177841	nõudmisele	nõudmisele =nõudmise  (SgAll  >nõudmine !12?10_S	et	f	\N
177842	nõudmisele	"nõudmine %nõud  )MINE_vS  <nõudma ;34_V	et	f	\N
177856	relvastatuid	relvastatuid =relvastatu  (PlP  >relvastatu !01_S	et	f	\N
177857	relvastatuid	"relvastatu %relvasta  )TU1_vS  <relvastama ;27_V	et	f	\N
177858	eeristavad	?eeristavad =eerista  (IndPrPl3  >eeristama !27_V	et	f	\N
177859	eeristavad	?eeristavad =eeristava  (PlN  >eeristav !02_A	et	f	\N
177860	eeristavad	?eeristavad =eeristava  (PlN  >eeristava !16_S	et	f	\N
177878	kasulikumad	kasulikumad =kasulikuma  (PlN  >kasulikum !02_A	et	f	\N
177879	kasulikumad	"kasulikum %kasuliku  )M_cA  <kasulik ;25_A	et	f	\N
177908	skleroosi	skleroosi =skleroosi  (SgG  >skleroos !22_S	et	f	\N
177909	skleroosi	skleroosi =skleroosi  (SgP  >skleroos !22_S	et	f	\N
177910	skleroosi	skleroosi =skleroosi  (SgAdt  >skleroos !22_S	et	f	\N
177917	bns	### bns	et	f	\N
177921	pearaamatupidaja	pearaamatupidaja =pidaja  (SgN  >pea+raamatu+pidaja !01_S	et	f	\N
177922	pearaamatupidaja	pearaamatupidaja =pidaja  (SgG  >pea+raamatu+pidaja !01_S	et	f	\N
177925	aruande	aruande =ande  (SgG  >aru+anne !06_S	et	f	\N
177926	aruande	aruande =ande  (PlP  >aru+and !22_S	et	f	\N
177930	hele-sinine	?hele-sinine =sinine  (SgN  >hele-sinine !10_AS	et	f	\N
177931	hele-sinine	?hele-sinine =sinine  (IndPrPs_  >hele-sininema !27_V	et	f	\N
177606	keeruliste	"keeruline %keeru  )LINE_aA  <keerd ;22_SA	et	f	\N
177635	organiseerijatahan	?organiseerijatahan =organiseerijatahan  (SgN  >organiseerijatahan !19_S	et	f	\N
177636	kombineeritud	kombineeritud =kombineeri  (PtsPtIps  >kombineerima !28_V	et	f	\N
177637	kombineeritud	kombineeritud =kombineeritu  (PlN  >kombineeritu !01_S	et	f	\N
177638	kombineeritud	"kombineeritu %kombineeri  )TU1_vS  <kombineerima ;28_V	et	f	\N
177639	kombineeritud	kombineeritud =kombineeritud  (ID  >kombineeritud !41_A	et	f	\N
177640	kombineeritud	"kombineeritud %kombineeri  )TUD_vA  <kombineerima ;28_V	et	f	\N
177651	0519xxxxx	### 0519xxxxx	et	f	\N
177654	normen	?normen =norme  (IndPrSg1  >normema !27_V	et	f	\N
177655	normen	?normen =normen  (SgN  >normen !02_S	et	f	\N
177656	kosmetika	?kosmetika =kosmetika  (SgN  >kosmetika !01_S	et	f	\N
177657	kosmetika	?kosmetika =kosmetika  (SgG  >kosmetika !01_S	et	f	\N
177658	kosmetika	?kosmetika =kosmetika  (SgG  >kosmetikas !02_A	et	f	\N
177746	värvuvad	värvuvad =värvu  (IndPrPl3  >värvuma !27_V	et	f	\N
177747	värvuvad	värvuvad =värvuva  (PlN  >värvuv !02_A	et	f	\N
177748	värvuvad	"värvuv %värvu  )V_vA  <värvuma ;27_V	et	f	\N
177765	jahedamaks	jahedamaks =jahedama  (SgTr  >jahedam !02_A	et	f	\N
177766	jahedamaks	"jahedam %jaheda  )M_cA  <jahe ;02_AS	et	f	\N
177767	jahedamaks	jahedamaks =maks  (SgN  >jaheda+maks !22_S	et	f	\N
177792	lörtsi	lörtsi =lörtsi  (SgG  >lörts !22_SA	et	f	\N
177793	lörtsi	lörtsi =lörtsi  (SgP  >lörts !22_SA	et	f	\N
177794	lörtsi	lörtsi =lörtsi  (SgAdt  >lörts !22_SA	et	f	\N
177795	lörtsi	lörtsi =lörtsi  (IndPrPs_  >lörtsima !28_V	et	f	\N
177796	lörtsi	lörtsi =lörtsi  (ImpPrSg2  >lörtsima !28_V	et	f	\N
177799	järkjargult	?järkjargult =järkjargu  (SgAbl  >järkjargu !01_S	et	f	\N
177800	järkjargult	?järkjargult =järkjargult  (ID  >järkjargult !41_D	et	f	\N
177815	talvevalusid	talvevalusid =valu  (PlP  >talve+valu !17_S	et	f	\N
177816	talvevalusid	talvevalusid =valusi  (PlN  >talve+valus !02_A	et	f	\N
177828	rääkimises	rääkimises =rääkimise  (SgIn  >rääkimine !12_S	et	f	\N
177829	rääkimises	"rääkimine %rääki  )MINE_vS  <rääkima ;28_V	et	f	\N
177861	käskisid	käskisid =käski  (PlP  >käsk !22_S	et	f	\N
177862	käskisid	käskisid =käski  (IndIpfSg2  >käskima !28_V	et	f	\N
177863	käskisid	käskisid =käski  (IndIpfPl3  >käskima !28_V	et	f	\N
177885	korneeli	?korneeli =korneeli  (SgN  >korneeli !16_S	et	f	\N
177886	korneeli	?korneeli =korneeli  (SgG  >korneeli !16_S	et	f	\N
177887	korneeli	?korneeli =korneeli  (SgG  >korneel !22_S	et	f	\N
177888	korneeli	?korneeli =korneeli  (SgP  >korneel !22_S	et	f	\N
177889	korneeli	?korneeli =korneeli  (SgAdt  >korneel !22_S	et	f	\N
177890	korneeli	?korneeli =korneeli  (IndPrPs_  >korneelima !28_V	et	f	\N
177891	korneeli	?korneeli =korneeli  (ImpPrSg2  >korneelima !28_V	et	f	\N
177892	vitamiini	vitamiini =vitamiini  (SgG  >vitamiin !22_S	et	f	\N
177893	vitamiini	vitamiini =vitamiini  (SgP  >vitamiin !22_S	et	f	\N
177894	vitamiini	vitamiini =vitamiini  (SgAdt  >vitamiin !22_S	et	f	\N
177899	lükopeenid	?lükopeenid =lükopeeni  (PlN  >lükopeeni !16_S	et	f	\N
177900	lükopeenid	?lükopeenid =lükopeeni  (PlN  >lükopeen !22_S	et	f	\N
177901	lükopeenid	?lükopeenid =lükopeeni  (IndPrSg2  >lükopeenima !28_V	et	f	\N
177904	talistavad	?talistavad =talista  (IndPrPl3  >talistama !27_V	et	f	\N
177905	talistavad	?talistavad =talistava  (PlN  >talistav !02_A	et	f	\N
177906	talistavad	?talistavad =talistava  (PlN  >talistava !16_S	et	f	\N
177907	talistavad	?talistavad =stava  (PlN  >tali+stava !17_S	et	f	\N
177915	sinivoore	sinivoore =voore  (SgG  >sini+voor !13_S	et	f	\N
177916	sinivoore	sinivoore =voore  (PlP  >sini+voor !22_S	et	f	\N
177964	silmarõõmu	silmarõõmu =rõõmu  (SgG  >silma+rõõm !22_S	et	f	\N
177965	silmarõõmu	silmarõõmu =rõõmu  (SgP  >silma+rõõm !22_S	et	f	\N
177966	silmarõõmu	silmarõõmu =rõõmu  (SgAdt  >silma+rõõm !22_S	et	f	\N
177970	mänguasja	mänguasja =asja  (SgG  >mängu+asi !24_S	et	f	\N
177971	mänguasja	mänguasja =asja  (SgP  >mängu+asi !24_S	et	f	\N
177972	mänguasja	mänguasja =asja  (SgAdt  >mängu+asi !24_S	et	f	\N
177993	kodukäia	kodukäia =käia  (SgG  >kodu+käi !22_S	et	f	\N
177994	kodukäia	kodukäia =käia  (SgP  >kodu+käi !22_S	et	f	\N
177995	kodukäia	kodukäia =käia  (SgAdt  >kodu+käi !22_S	et	f	\N
178008	vihmavarju	vihmavarju =varju  (SgG  >vihma+vari !24_S	et	f	\N
178009	vihmavarju	vihmavarju =varju  (SgP  >vihma+vari !24_S	et	f	\N
178010	vihmavarju	vihmavarju =varju  (SgAdt  >vihma+vari !24_S	et	f	\N
178011	vihmavarju	vihmavarju =varju  (PlP  >vihma+vari !24_S	et	f	\N
178014	sõbranaga	sõbranaga =naga  (SgN  >sõbra+naga !17_S	et	f	\N
178015	sõbranaga	sõbranaga =naga  (SgG  >sõbra+naga !17_S	et	f	\N
178016	sõbranaga	sõbranaga =naga  (SgP  >sõbra+naga !17_S	et	f	\N
178034	vastuvõt	### vastuvõt	et	f	\N
178035	naabritejuures	?naabritejuures =naabritejuure  (SgIn  >naabritejuure !16_S	et	f	\N
178036	naabritejuures	?naabritejuures =naabritejuure  (PlIn  >naabritejuur !22_S	et	f	\N
178037	naabritejuures	?naabritejuures =tejuure  (SgIn  >naabri+tejuure !16_S	et	f	\N
178038	naabritejuures	?naabritejuures =tejuure  (PlIn  >naabri+tejuur !22_S	et	f	\N
177847	afgaanlased	?afgaanlased =afgaanlase  (PlN  >afgaanlane !12?10_S	et	f	\N
177864	rengeeniga	?rengeeniga =rengeeni  (SgKom  >rengeeni !16_S	et	f	\N
177865	rengeeniga	?rengeeniga =rengeeni  (SgKom  >rengeen !22_S	et	f	\N
177866	näia	?näia =näia  (SgN  >näia !16_S	et	f	\N
177867	näia	?näia =näia  (SgG  >näia !16_S	et	f	\N
177868	näia	?näia =näia  (IndPrPs_  >näiama !29_V	et	f	\N
177869	näia	?näia =näia  (ImpPrSg2  >näiama !29_V	et	f	\N
177873	afgaanlanad	### afgaanlanad	et	f	\N
177880	keetud	keetud =keetu  (PlN  >keetu !01_A	et	f	\N
177881	keetud	"keetu %kee  )TU2_kA  <kesi ;15_S	et	f	\N
177882	keetud	"keetu %kee  )TU2_kA  <kee ;26_S	et	f	\N
177883	kasulikem	kasulikem =kasulikem  (SgN  >kasulikem !02_A	et	f	\N
177884	kasulikem	"kasulikem %kasulike  )IM_sA  <kasulik ;25_A	et	f	\N
177902	antioksüdandid	?antioksüdandid =antioksüdandi  (PlN  >antioksüdant !22_S	et	f	\N
177903	antioksüdandid	?antioksüdandid =antioksüdandi  (IndPrSg2  >antioksüdantima !28_V	et	f	\N
177913	kasvajate	kasvajate =kasvaja  (PlG  >kasvaja !01_S	et	f	\N
177914	kasvajate	"kasvaja %kasva  )JA_vS  <kasvama ;28_V	et	f	\N
177923	europas	?europas =europa  (SgIn  >europa !01_S	et	f	\N
177938	õesti	?õesti =õesti  (ID  >õesti !41_D	et	f	\N
177939	õesti	?õesti =õesti  (SgG  >õest !22_S	et	f	\N
177940	õesti	?õesti =õesti  (SgP  >õest !22_S	et	f	\N
177941	õesti	?õesti =õesti  (SgAdt  >õest !22_S	et	f	\N
177942	õesti	?õesti =õesti  (IndPrPs_  >õestima !28_V	et	f	\N
177943	õesti	?õesti =õesti  (ImpPrSg2  >õestima !28_V	et	f	\N
177944	siistal	?siistal =siista  (SgAd  >siista !01_S	et	f	\N
177945	siistal	?siistal =siistal  (SgN  >siistal !02_S	et	f	\N
177953	rikkade	### rikkade	et	f	\N
177956	lapsede	lapsede =ede  (SgN  >laps+ede !16_S	et	f	\N
177957	lapsede	lapsede =ede  (SgG  >laps+ede !16_S	et	f	\N
177958	ruudulise	ruudulise =ruudulise  (SgG  >ruuduline !12_A	et	f	\N
177959	ruudulise	"ruuduline %ruudu  )LINE_aA  <ruut ;22_S	et	f	\N
177967	kommi	kommi =kommi  (SgG  >komm !22_S	et	f	\N
177968	kommi	kommi =kommi  (SgP  >komm !22_S	et	f	\N
177969	kommi	kommi =kommi  (SgAdt  >komm !22_S	et	f	\N
177979	punapea	punapea =pea  (SgN  >puna+pea !26_S	et	f	\N
177980	punapea	punapea =pea  (SgG  >puna+pea !26_S	et	f	\N
178002	sportlastele	sportlastele =sportlas  (PlAll  >sportlane !12?10_S	et	f	\N
178003	sportlastele	sportlastele =las  (PlAll  >sport+laps !14_S	et	f	\N
178004	sportlastele	sportlastele =laste  (PlAll  >sport+last !22_S	et	f	\N
178012	küpsetama	küpsetama =küpse  (SupIps  >küpsema !28_V	et	f	\N
178013	küpsetama	küpsetama =küpseta  (Sup  >küpsetama !27_V	et	f	\N
178048	ristipoega	ristipoega =poe  (SgKom  >risti+pood !22_S	et	f	\N
178049	ristipoega	ristipoega =poega  (SgP  >risti+poeg !22_S	et	f	\N
178050	ristipoega	ristipoega =poega  (SgAdt  >risti+poeg !22_S	et	f	\N
178065	sõitakse	?sõitakse =sõitakse  (SgG  >sõitakne !02_A	et	f	\N
178067	riidehoidu	riidehoidu =hoidu  (SgP  >riide+hoid !22_S	et	f	\N
178068	riidehoidu	riidehoidu =hoidu  (SgAdt  >riide+hoid !22_S	et	f	\N
178069	lehmi	lehmi =lehmi  (SgG  >lehm !22_S	et	f	\N
178070	lehmi	lehmi =lehmi  (SgP  >lehm !22_S	et	f	\N
178071	lehmi	lehmi =lehmi  (SgAdt  >lehm !22_S	et	f	\N
178072	lehmi	lehmi =lehmi  (PlP  >lehm !22_S	et	f	\N
178115	vaatamisväärsus	vaatamisväärsus =väärsus  (SgN  >vaatamis+väärsus !11~09_S	et	f	\N
178116	vaatamisväärsus	"vaatamis+väärsus %väärse  )US_aS  <vaatamis+väärne ;02_A	et	f	\N
178124	relvastus	relvastus =relvastu  (IndIpfSg3  >relvastuma !27_V	et	f	\N
178125	relvastus	relvastus =relvastus  (SgN  >relvastus !11_S	et	f	\N
178126	relvastus	"relvastus %relvasta  )US_vS  <relvastama ;27_V	et	f	\N
178153	küttetud	küttetud =küttetu  (PlN  >küttetu !01_A	et	f	\N
178154	küttetud	"küttetu %kütte  )TU2_kA  <küte ;06_S	et	f	\N
178156	õuest	õuest =õue  (SgEl  >õu !22_S	et	f	\N
178157	õuest	õuest =õues  (SgP  >õuene !10_A	et	f	\N
178158	õuest	"õuene %õue  )NE_aA  <õu ;22_S	et	f	\N
178159	õuest	õuest =õuest  (ID  >õuest !41_D	et	f	\N
178162	olmetehnika	olmetehnika =tehnika  (SgN  >olme+tehnika !01_S	et	f	\N
178163	olmetehnika	olmetehnika =tehnika  (SgG  >olme+tehnika !01_S	et	f	\N
178171	tolmu	tolmu =tolmu  (SgG  >tolm !22_S	et	f	\N
178172	tolmu	tolmu =tolmu  (SgP  >tolm !22_S	et	f	\N
178173	tolmu	tolmu =tolmu  (SgAdt  >tolm !22_S	et	f	\N
178174	tolmu	tolmu =tolmu  (IndPrPs_  >tolmuma !27_V	et	f	\N
178175	tolmu	tolmu =tolmu  (ImpPrSg2  >tolmuma !27_V	et	f	\N
178201	kodurahu	kodurahu =rahu  (SgN  >kodu+rahu !17_S	et	f	\N
178202	kodurahu	kodurahu =rahu  (SgG  >kodu+rahu !17_S	et	f	\N
178203	kodurahu	kodurahu =rahu  (SgP  >kodu+rahu !17_S	et	f	\N
178211	majapidamiseg	### majapidamiseg	et	f	\N
178240	lausi	?lausi =lausi  (SgN  >lausi !16_S	et	f	\N
178241	lausi	?lausi =lausi  (SgG  >lausi !16_S	et	f	\N
178242	lausi	?lausi =lausi  (SgG  >laus !22_S	et	f	\N
178243	lausi	?lausi =lausi  (SgP  >laus !22_S	et	f	\N
178244	lausi	?lausi =lausi  (SgAdt  >laus !22_S	et	f	\N
178245	lausi	?lausi =lausi  (IndPrPs_  >lausima !28_V	et	f	\N
178246	lausi	?lausi =lausi  (ImpPrSg2  >lausima !28_V	et	f	\N
177850	mässitud	mässitud =mässi  (PtsPtIps  >mässima !28_V	et	f	\N
177851	mässitud	mässitud =mässitu  (PlN  >mässitu !01_AS	et	f	\N
177852	mässitud	"mässitu %mässi  )TU1_vS  <mässima ;28_V	et	f	\N
177853	mässitud	"mässitu %mässi  )TU2_kA  <mäss ;22_S	et	f	\N
177854	mässitud	mässitud =mässitud  (ID  >mässitud !41_A	et	f	\N
177855	mässitud	"mässitud %mässi  )TUD_vA  <mässima ;28_V	et	f	\N
177924	kontrolib	### kontrolib	et	f	\N
177927	rahvusvahelisele	rahvusvahelisele =vahelise  (SgAll  >rahvus+vaheline !12_A	et	f	\N
177928	rahvusvahelisele	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
177929	saf	### saf	et	f	\N
177936	meeldibmina	?meeldibmina =meeldibmi  (SgEs  >meeldibmi !01_S	et	f	\N
177937	meeldibmina	?meeldibmina =meeldibmi  (SgEs  >meeldibm !22_S	et	f	\N
177946	vaese	vaese =vaese  (SgG  >vaene !10_AS	et	f	\N
177947	vaese	"vaene %vae  )NE_aA  <vaag ;22_S	et	f	\N
177948	lapspaha	lapspaha =paha  (SgN  >laps+paha !17_AS	et	f	\N
177949	lapspaha	lapspaha =paha  (SgG  >laps+paha !17_AS	et	f	\N
177950	lapspaha	lapspaha =paha  (SgG  >laps+pahk !22_S	et	f	\N
177951	lapspaha	lapspaha =paha  (SgP  >laps+paha !17_AS	et	f	\N
177960	potililli	potililli =lilli  (SgG  >poti+lill !22_S	et	f	\N
177961	potililli	potililli =lilli  (SgP  >poti+lill !22_S	et	f	\N
177962	potililli	potililli =lilli  (SgAdt  >poti+lill !22_S	et	f	\N
177963	potililli	potililli =lilli  (PlP  >poti+lill !22_S	et	f	\N
177986	spordimasast	?spordimasast =spordimasa  (SgEl  >spordimasa !16_S	et	f	\N
177987	spordimasast	?spordimasast =spordimasas  (SgP  >spordimasane !12_A	et	f	\N
177988	spordimasast	?spordimasast =masa  (SgEl  >spordi+masa !17_S	et	f	\N
177989	spordimasast	?spordimasast =masas  (SgP  >spordi+masas !09_S	et	f	\N
177990	spordimasast	?spordimasast =masas  (SgP  >spordi+masane !10_A	et	f	\N
177996	nafanja	?nafanja =nafanja  (SgN  >nafanja !16_S	et	f	\N
177997	nafanja	?nafanja =nafanja  (SgG  >nafanjas !02_A	et	f	\N
177998	nafanja	?nafanja =nafanja  (SgG  >nafanja !16_S	et	f	\N
177999	teet	?teet =teet  (SgN  >teet !22_S	et	f	\N
178017	rootsimaal	rootsimaal =maa  (SgAd  >rootsi+maa !26_S	et	f	\N
178018	rootsimaal	rootsimaal =maal  (SgN  >rootsi+maal !22_S	et	f	\N
178019	üüritusi	üüritusi =üüritusi  (PlP  >üüritus !11_S	et	f	\N
178020	üüritusi	"üüritus %üüri  )TUS1_aS  <üürima ;28_V	et	f	\N
178021	üüritusi	"üüritus %üüri  )TUS2_aS  <üür ;22_S	et	f	\N
178073	minetakse	?minetakse =minetakse  (SgG  >minetakne !02_A	et	f	\N
178074	minetakse	?minetakse =minetakse  (PlP  >minetaks !22_S	et	f	\N
178081	laevalael	laevalael =lae  (SgAd  >laeva+lagi !21_S	et	f	\N
178082	laevalael	laevalael =lae  (SgAd  >laeva+laad !22_S	et	f	\N
178135	kristiina	?kristiina =kristii  (SgEs  >kristii !26_S	et	f	\N
178136	kristiina	?kristiina =kristiina  (SgN  >kristiina !16_S	et	f	\N
178138	kristiina	?kristiina =kristiina  (SgG  >kristiina !16_S	et	f	\N
178146	populaarsemkoht	?populaarsemkoht =populaarsemkoht  (SgN  >populaarsemkoht !22_S	et	f	\N
178147	populaarsemkoht	?populaarsemkoht =semkoht  (SgN  >populaar+semkoht !22_S	et	f	\N
178148	populaarsemkoht	?populaarsemkoht =ulaarsemkoht  (SgN  >pop+ulaarsemkoht !22_S	et	f	\N
178198	kostev	kostev =kost  (PtsPrPs  >kostma !34_V	et	f	\N
178199	kostev	kostev =kostev  (SgN  >kostev !02_A	et	f	\N
178200	kostev	"kostev %kost  )V_vA  <kostma ;34_V	et	f	\N
178212	sõbru	?sõbru =sõbru  (SgN  >sõbru !16_S	et	f	\N
178213	sõbru	?sõbru =sõbru  (SgG  >sõbru !16_S	et	f	\N
178214	sõbru	?sõbru =sõbru  (IndPrPs_  >sõbruma !27_V	et	f	\N
178215	sõbru	?sõbru =sõbru  (ImpPrSg2  >sõbruma !27_V	et	f	\N
178222	jalgrataid	?jalgrataid =jalgratai  (PlN  >jalgratai !26_S	et	f	\N
178223	jalgrataid	?jalgrataid =jalgratai  (SgP  >jalgratai !26_S	et	f	\N
178224	jalgrataid	?jalgrataid =ratai  (PlN  >jalg+ratai !26_S	et	f	\N
178225	jalgrataid	?jalgrataid =ratai  (SgP  >jalg+ratai !26_S	et	f	\N
178226	jalgrataid	?jalgrataid =rataid  (SgN  >jalg+rataid !22_S	et	f	\N
178238	kingipakke	kingipakke =pakke  (SgG  >kingi+pake !06_S	et	f	\N
178239	kingipakke	kingipakke =pakke  (PlP  >kingi+pakk !22_S	et	f	\N
178252	kuninglikuid	?kuninglikuid =kuninglikui  (PlN  >kuninglikui !26_S	et	f	\N
178253	kuninglikuid	?kuninglikuid =kuninglikui  (SgP  >kuninglikui !26_S	et	f	\N
178254	karikakraid	karikakraid =krai  (PlN  >karika+krai !26_S	et	f	\N
178255	karikakraid	karikakraid =krai  (SgP  >karika+krai !26_S	et	f	\N
178256	karikakraid	karikakraid =kakra  (PlP  >kari+kakar !08_S	et	f	\N
178257	karikakraid	karikakraid =kakra  (PlP  >kari+kaker !08_S	et	f	\N
178264	laenesid	?laenesid =laene  (IndIpfSg2  >laenema !27_V	et	f	\N
178265	laenesid	?laenesid =laene  (IndIpfPl3  >laenema !27_V	et	f	\N
178266	laenesid	?laenesid =nesi  (PlN  >lae+nesi !17_S	et	f	\N
178269	õnnelikuid	?õnnelikuid =õnnelikui  (PlN  >õnnelikui !26_S	et	f	\N
178271	õnnelikuid	?õnnelikuid =õnnelikui  (SgP  >õnnelikui !26_S	et	f	\N
178282	tervitust	tervitust =tervitus  (SgP  >tervitus !11_S	et	f	\N
178283	tervitust	"tervitus %tervita  )US_vS  <tervitama ;27_V	et	f	\N
178297	koolikaaslast	koolikaaslast =la  (SgEl  >kooli+kaas+la !26_S	et	f	\N
178298	koolikaaslast	koolikaaslast =las  (SgP  >kooli+kaas+laps !14_S	et	f	\N
178299	koolikaaslast	koolikaaslast =last  (SgN  >kooli+kaas+last !22_S	et	f	\N
177870	kehi	kehi =kehi  (PlP  >keha !17_S	et	f	\N
177871	kehi	kehi =kehi  (IndPrPs_  >kehima !27_V	et	f	\N
177872	kehi	kehi =kehi  (ImpPrSg2  >kehima !27_V	et	f	\N
177874	haotatud	?haotatud =haota  (PtsPtIps  >haotama !27_V	et	f	\N
177875	haotatud	?haotatud =haotatu  (PlN  >haotatu !01_S	et	f	\N
177876	haotatud	?haotatud =haotatu  (IndPrSg2  >haotatuma !27_V	et	f	\N
177877	haotatud	?haotatud =haotatud  (ID  >haotatud !41_A	et	f	\N
177895	tomatides	### tomatides	et	f	\N
177896	omastamise	omastamise =omastamise  (SgG  >omastamine !12_S	et	f	\N
177897	omastamise	"omastamine %omasta  )MINE_vS  <omastama ;27_V	et	f	\N
177898	tomatidele	### tomatidele	et	f	\N
177911	pahaloomuliste	pahaloomuliste =loomulis  (PlG  >paha+loomuline !12_A	et	f	\N
177912	pahaloomuliste	"paha+loomuline %loomu  )LINE_aA  <paha+loom ;22_S	et	f	\N
177918	kontserni	kontserni =kontserni  (SgG  >kontsern !22_S	et	f	\N
177919	kontserni	kontserni =kontserni  (SgP  >kontsern !22_S	et	f	\N
177920	kontserni	kontserni =kontserni  (SgAdt  >kontsern !22_S	et	f	\N
177933	riietuvad	riietuvad =riietu  (IndPrPl3  >riietuma !27_V	et	f	\N
177934	riietuvad	riietuvad =riietuva  (PlN  >riietuv !02_A	et	f	\N
177935	riietuvad	"riietuv %riietu  )V_vA  <riietuma ;27_V	et	f	\N
177973	lemmikloomi	lemmikloomi =loomi  (SgG  >lemmik+loom !22_S	et	f	\N
177974	lemmikloomi	lemmikloomi =loomi  (SgP  >lemmik+loom !22_S	et	f	\N
177975	lemmikloomi	lemmikloomi =loomi  (SgAdt  >lemmik+loom !22_S	et	f	\N
177976	lemmikloomi	lemmikloomi =loomi  (PlP  >lemmik+loom !22_S	et	f	\N
177977	grupijuhataja	grupijuhataja =juhataja  (SgN  >grupi+juhataja !01_S	et	f	\N
177978	grupijuhataja	grupijuhataja =juhataja  (SgG  >grupi+juhataja !01_S	et	f	\N
177991	valges	valges =valge  (SgIn  >valge !01_AS	et	f	\N
177992	valges	valges =valge  (PlIn  >valk !22_S	et	f	\N
178060	juubilari	juubilari =juubilari  (SgG  >juubilar !19_S	et	f	\N
178061	juubilari	juubilari =juubilari  (SgP  >juubilar !19_S	et	f	\N
178062	juubilari	juubilari =juubilari  (SgAdt  >juubilar !19_S	et	f	\N
178066	andtakse	?andtakse =andtakse  (SgG  >andtakne !02_A	et	f	\N
178105	botaanikaaias	botaanikaaias =aia  (SgIn  >botaanika+aed !22_S	et	f	\N
178107	botaanikaaias	botaanikaaias =aia  (SgIn  >botaanika+ai !22_S	et	f	\N
178117	victoria	?victoria =victoria  (SgN  >victoria !01_S	et	f	\N
178118	victoria	?victoria =victoria  (SgG  >victoria !01_S	et	f	\N
178127	väärtuslikuid	?väärtuslikuid =väärtuslikui  (PlN  >väärtuslikui !26_S	et	f	\N
178128	väärtuslikuid	?väärtuslikuid =väärtuslikui  (SgP  >väärtuslikui !26_S	et	f	\N
178129	väärtuslikuid	?väärtuslikuid =usliku  (PlP  >väärt+usliku !01_S	et	f	\N
178130	väärtuslikuid	?väärtuslikuid =uslikui  (PlN  >väärt+uslikui !26_S	et	f	\N
178131	väärtuslikuid	?väärtuslikuid =uslikui  (SgP  >väärt+uslikui !26_S	et	f	\N
178132	väärtuslikuid	?väärtuslikuid =tusliku  (PlP  >väär+tusliku !01_S	et	f	\N
178133	väärtuslikuid	?väärtuslikuid =tuslikui  (PlN  >väär+tuslikui !26_S	et	f	\N
178134	väärtuslikuid	?väärtuslikuid =tuslikui  (SgP  >väär+tuslikui !26_S	et	f	\N
178141	drottningholmi	?drottningholmi =drottningholmi  (SgG  >drottningholm !22_S	et	f	\N
178142	drottningholmi	?drottningholmi =drottningholmi  (SgP  >drottningholm !22_S	et	f	\N
178143	drottningholmi	?drottningholmi =drottningholmi  (SgAdt  >drottningholm !22_S	et	f	\N
178144	drottningholmi	?drottningholmi =drottningholmi  (IndPrPs_  >drottningholmima !28_V	et	f	\N
178145	drottningholmi	?drottningholmi =drottningholmi  (ImpPrSg2  >drottningholmima !28_V	et	f	\N
178160	kodukorda	kodukorda =korda  (SgP  >kodu+kord !22_S	et	f	\N
178161	kodukorda	kodukorda =korda  (SgAdt  >kodu+kord !22_S	et	f	\N
178169	puudumistega	puudumistega =puudumis  (PlKom  >puudumine !12_S	et	f	\N
178170	puudumistega	"puudumine %puudu  )MINE_vS  <puuduma ;27_V	et	f	\N
178176	köetud	köetud =köe  (PtsPtIps  >küdema !28_V	et	f	\N
178177	köetud	köetud =köe  (PtsPtIps  >kütma !35_V	et	f	\N
178178	köetud	köetud =köetu  (PlN  >köetu !01_S	et	f	\N
178179	köetud	"köetu %köe  )TU1_vS  <küdema ;28_V	et	f	\N
178180	köetud	"köetu %köe  )TU1_vS  <kütma ;35_V	et	f	\N
178181	köetud	köetud =köetud  (ID  >köetud !41_A	et	f	\N
178182	köetud	"köetud %köe  )TUD_vA  <küdema ;28_V	et	f	\N
178183	köetud	"köetud %köe  )TUD_vA  <kütma ;35_V	et	f	\N
178191	tänavalt	tänavalt =tänava  (SgAbl  >tänav !02_A	et	f	\N
178192	tänavalt	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
178193	tänavalt	tänavalt =tänava  (SgAbl  >tänav !02_S	et	f	\N
178194	tänavalt	tänavalt =tänavalt  (ID  >tänavalt !41_D	et	f	\N
178195	tänavalt	"tänavalt %täna  )VALT_mD  <tänama ;27_V	et	f	\N
178196	tänavalt	"tänavalt %tänava  )LT_mD  <tänav ;02_A	et	f	\N
178197	tänavalt	tänavalt =alt  (SgN  >tänav+alt !22_S	et	f	\N
178216	kuuid	?kuuid =kuuid  (SgN  >kuuid !02_S	et	f	\N
178217	minuteid	minuteid =minute  (PlP  >minut !02_S	et	f	\N
178218	minuteid	minuteid =te  (PlP  >minu+tee !26_S	et	f	\N
178230	päkapikuid	?päkapikuid =päkapiku  (PlP  >päkapik !02_S	et	f	\N
178232	päkapikuid	?päkapikuid =päkapikui  (PlN  >päkapikui !26_S	et	f	\N
178234	päkapikuid	?päkapikuid =päkapikui  (SgP  >päkapikui !26_S	et	f	\N
178235	päkapikuid	?päkapikuid =pikui  (PlN  >päka+pikui !26_S	et	f	\N
177932	hele-sinine	?hele-sinine =sinine  (ImpPrSg2  >hele-sininema !27_V	et	f	\N
177952	kadub	### kadub	et	f	\N
177954	vaenede	?vaenede =nede  (SgN  >vae+nede !16_S	et	f	\N
177955	vaenede	?vaenede =nede  (SgG  >vae+nede !16_S	et	f	\N
177981	kuzja	?kuzja =kuzja  (SgN  >kuzja !16_S	et	f	\N
177982	kuzja	?kuzja =kuzja  (SgG  >kuzjas !02_A	et	f	\N
177983	kuzja	?kuzja =kuzja  (SgG  >kuzja !16_S	et	f	\N
177984	kuzja	?kuzja =kuzja  (IndPrPs_  >kuzjama !29_V	et	f	\N
177985	kuzja	?kuzja =kuzja  (ImpPrSg2  >kuzjama !29_V	et	f	\N
178000	parimatele	parimatele =parima  (PlAll  >parim !02_A	et	f	\N
178001	parimatele	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
178005	arve	arve =arve  (SgN  >arve !06_S	et	f	\N
178006	arve	arve =arve  (SgG  >arve !06_S	et	f	\N
178007	arve	arve =arve  (PlP  >arv !22_S	et	f	\N
178022	restoraani	?restoraani =restoraa  (SgTer  >restoraa !26_S	et	f	\N
178023	restoraani	?restoraani =restoraani  (SgN  >restoraani !16_S	et	f	\N
178024	restoraani	?restoraani =restoraani  (SgG  >restoraani !16_S	et	f	\N
178025	restoraani	?restoraani =restoraani  (SgG  >restoraan !22_S	et	f	\N
178026	restoraani	?restoraani =restoraani  (SgP  >restoraan !22_S	et	f	\N
178027	restoraani	?restoraani =restoraani  (SgAdt  >restoraan !22_S	et	f	\N
178028	restoraani	?restoraani =restoraani  (IndPrPs_  >restoraanima !28_V	et	f	\N
178029	restoraani	?restoraani =restoraani  (ImpPrSg2  >restoraanima !28_V	et	f	\N
178030	rajaid	?rajaid =raja  (PlP  >rajas !09_S	et	f	\N
178031	rajaid	?rajaid =rajai  (PlN  >rajai !26_S	et	f	\N
178032	rajaid	?rajaid =rajai  (SgP  >rajai !26_S	et	f	\N
178033	rajaid	?rajaid =rajaid  (SgN  >rajaid !22_S	et	f	\N
178046	huvitavait	?huvitavait =huvitavait  (SgN  >huvitavait !22_S	et	f	\N
178047	huvitavait	?huvitavait =tavait  (SgN  >huvi+tavait !22_S	et	f	\N
178063	soovitakse	soovitakse =soovi  (IndPrIps  >soovima !28_V	et	f	\N
178064	soovitakse	soovitakse =takse  (PlP  >soovi+taks !22_S	et	f	\N
178075	käietakse	?käietakse =käietakse  (SgG  >käietakne !02_A	et	f	\N
178076	käietakse	?käietakse =käietakse  (PlP  >käietaks !22_S	et	f	\N
178085	loomastik	loomastik =loomastik  (SgN  >loomastik !25_S	et	f	\N
178086	loomastik	loomastik =astik  (SgN  >loom+astik !02_S	et	f	\N
178091	stockholmis	?stockholmis =stockholmi  (SgIn  >stockholmi !01_S	et	f	\N
178092	stockholmis	?stockholmis =stockholmi  (SgIn  >stockholm !22_S	et	f	\N
178093	stockholmis	?stockholmis =stockholmi  (IndIpfSg3  >stockholmima !28_V	et	f	\N
178094	stockholmis	?stockholmis =stockholmis  (SgN  >stockholmis !11_S	et	f	\N
178102	bergiani	?bergiani =bergia  (SgTer  >bergia !01_S	et	f	\N
178103	bergiani	?bergiani =bergiani  (SgN  >bergiani !16_S	et	f	\N
178104	bergiani	?bergiani =bergiani  (SgG  >bergian !19~02_S	et	f	\N
178106	bergiani	?bergiani =bergiani  (SgG  >bergiani !16_S	et	f	\N
178108	bergiani	?bergiani =bergiani  (SgP  >bergian !19_S	et	f	\N
178109	bergiani	?bergiani =bergiani  (SgAdt  >bergian !19_S	et	f	\N
178110	bergiani	?bergiani =bergiani  (IndPrPs_  >bergianima !28_V	et	f	\N
178111	bergiani	?bergiani =bergiani  (ImpPrSg2  >bergianima !28_V	et	f	\N
178119	torniga	torniga =torni  (SgKom  >torn !22_S	et	f	\N
178120	torniga	torniga =iga  (SgN  >torn+iga !18_S	et	f	\N
178121	torniga	torniga =iga  (SgP  >torn+iga !18_S	et	f	\N
178122	igaaastased	igaaastased =aastase  (PlN  >iga+aastane !12~10_A	et	f	\N
178123	igaaastased	"iga+aastane %aasta  )NE_aA  <iga+aasta ;01_S	et	f	\N
178149	väärsuseid	väärsuseid =väärsuse  (PlP  >väärsus !09_S	et	f	\N
178150	väärsuseid	"väärsus %väärse  )US_aS  <väärne ;02_A	et	f	\N
178164	rahuldavad	rahuldavad =rahulda  (IndPrPl3  >rahuldama !27_V	et	f	\N
178165	rahuldavad	rahuldavad =rahuldava  (PlN  >rahuldav !02_A	et	f	\N
178166	rahuldavad	"rahuldav %rahulda  )V_vA  <rahuldama ;27_V	et	f	\N
178204	täiskasvanuks	täiskasvanuks =vanu  (PlTr  >täis+kas+vana !17_AS	et	f	\N
178205	täiskasvanuks	täiskasvanuks =kasvanu  (SgTr  >täis+kasvanu !01_S	et	f	\N
178219	ööid	?ööid =ööid  (SgN  >ööid !02_S	et	f	\N
178220	takso	takso =takso  (SgN  >takso !16_S	et	f	\N
178221	takso	takso =takso  (SgG  >takso !16_S	et	f	\N
178227	menüusid	?menüusid =menüu  (PlP  >menüu !26_S	et	f	\N
178228	menüusid	?menüusid =menüusi  (PlN  >menüus !22_S	et	f	\N
178229	menüusid	?menüusid =menüusi  (IndPrSg2  >menüusima !28_V	et	f	\N
178231	kaunistusi	kaunistusi =kaunistusi  (PlP  >kaunistus !11_S	et	f	\N
178233	kaunistusi	"kaunistus %kaunista  )US_vS  <kaunistama ;27_V	et	f	\N
178250	tervesid	?tervesid =terve  (IndIpfSg2  >tervema !27_V	et	f	\N
178251	tervesid	?tervesid =terve  (IndIpfPl3  >tervema !27_V	et	f	\N
178273	dekoreerituid	dekoreerituid =dekoreeritu  (PlP  >dekoreeritu !01_S	et	f	\N
178274	dekoreerituid	"dekoreeritu %dekoreeri  )TU1_vS  <dekoreerima ;28_V	et	f	\N
178275	ostuhimuliseid	?ostuhimuliseid =ostuhimulisei  (PlN  >ostuhimulisei !26_S	et	f	\N
178276	ostuhimuliseid	?ostuhimuliseid =ostuhimulisei  (SgP  >ostuhimulisei !26_S	et	f	\N
178277	ostuhimuliseid	?ostuhimuliseid =himulisei  (PlN  >ostu+himulisei !26_S	et	f	\N
178278	ostuhimuliseid	?ostuhimuliseid =himulisei  (SgP  >ostu+himulisei !26_S	et	f	\N
178285	majase	majase =majase  (SgG  >majane !10_A	et	f	\N
178286	majase	"majane %maja  )NE_aA  <maja ;17_S	et	f	\N
178039	naabritejuures	?naabritejuures =britejuure  (SgIn  >naa+britejuure !16_S	et	f	\N
178040	naabritejuures	?naabritejuures =britejuure  (PlIn  >naa+britejuur !22_S	et	f	\N
178041	päsupesa	?päsupesa =päsupesa  (SgN  >päsupesa !16_S	et	f	\N
178042	päsupesa	?päsupesa =päsupesa  (SgG  >päsupesa !16_S	et	f	\N
178043	vihmavarja	vihmavarja =varja  (SgG  >vihma+vari !24_S	et	f	\N
178044	vihmavarja	vihmavarja =varja  (SgP  >vihma+vari !24_S	et	f	\N
178045	vihmavarja	vihmavarja =varja  (SgAdt  >vihma+vari !24_S	et	f	\N
178051	vennapoega	vennapoega =poe  (SgKom  >venna+pood !22_S	et	f	\N
178052	vennapoega	vennapoega =poega  (SgP  >venna+poeg !22_S	et	f	\N
178053	vennapoega	vennapoega =poega  (SgAdt  >venna+poeg !22_S	et	f	\N
178054	käikse	?käikse =käikse  (SgN  >käikse !06_S	et	f	\N
178055	käikse	?käikse =käikse  (SgG  >käikne !02_A	et	f	\N
178056	käikse	?käikse =käikse  (SgG  >käikse !06_S	et	f	\N
178057	käikse	?käikse =käikse  (PlP  >käiks !22_S	et	f	\N
178058	käikse	?käikse =käikse  (IndPrPs_  >käiksema !28_V	et	f	\N
178059	käikse	?käikse =käikse  (ImpPrSg2  >käiksema !28_V	et	f	\N
178077	huvitavamast	huvitavamast =huvitavama  (SgEl  >huvitavam !02_A	et	f	\N
178078	huvitavamast	"huvitavam %huvita  )VAM_cA  <huvitama ;27_V	et	f	\N
178079	huvitavamast	"huvitavam %huvitava  )M_cA  <huvitav ;02_A	et	f	\N
178080	huvitavamast	huvitavamast =mast  (SgN  >huvi+tava+mast !22_S	et	f	\N
178083	linnavaatamisväärsuseid	linnavaatamisväärsuseid =väärsuse  (PlP  >linna+vaatamis+väärsus !09_S	et	f	\N
178084	linnavaatamisväärsuseid	"linna+vaatamis+väärsus %väärse  )US_aS  <linna+vaatamis+väärne ;02_A	et	f	\N
178087	rotsis	?rotsis =rotsi  (SgIn  >rotsi !16_S	et	f	\N
178088	rotsis	?rotsis =rotsi  (SgIn  >rots !22_S	et	f	\N
178089	rotsis	?rotsis =rotsi  (IndIpfSg3  >rotsima !28_V	et	f	\N
178090	rotsis	?rotsis =rotsis  (SgN  >rotsis !09_S	et	f	\N
178095	liljevalchsi	?liljevalchsi =liljevalchsi  (IndPrPs_  >liljevalchsima !28_V	et	f	\N
178096	liljevalchsi	?liljevalchsi =liljevalchsi  (ImpPrSg2  >liljevalchsima !28_V	et	f	\N
178097	eelajaloolist	eelajaloolist =loolis  (SgP  >eel+aja+looline !12?10_A	et	f	\N
178098	eelajaloolist	"eel+aja+looline %loo  )LINE_aA  <eel+aja+lugu ;18_S	et	f	\N
178099	eelajaloolist	"eel+aja+looline %loo  )LINE_aA  <eel+aja+loog ;22_S	et	f	\N
178100	eelajaloolist	"eel+aja+looline %loo  )LINE_aA  <eel+aja+lood ;22_S	et	f	\N
178101	eelajaloolist	eelajaloolist =loolis  (SgP  >eel+aja+looline !12?10_S	et	f	\N
178112	hiigelvesiroosi	hiigelvesiroosi =roosi  (SgG  >hiigel+vesi+roos !22_S	et	f	\N
178113	hiigelvesiroosi	hiigelvesiroosi =roosi  (SgP  >hiigel+vesi+roos !22_S	et	f	\N
178114	hiigelvesiroosi	hiigelvesiroosi =roosi  (SgAdt  >hiigel+vesi+roos !22_S	et	f	\N
178137	hõbetrooni	hõbetrooni =trooni  (SgG  >hõbe+troon !22_S	et	f	\N
178139	hõbetrooni	hõbetrooni =trooni  (SgP  >hõbe+troon !22_S	et	f	\N
178140	hõbetrooni	hõbetrooni =trooni  (SgAdt  >hõbe+troon !22_S	et	f	\N
178151	mitmekorruselises	mitmekorruselises =korruselise  (SgIn  >mitme+korruseline !12_A	et	f	\N
178152	mitmekorruselises	"mitme+korruseline %korruse  )LINE_aA  <mitme+korrus ;09_S	et	f	\N
178155	suhtudega	### suhtudega	et	f	\N
178167	mugavuste	mugavuste =mugavus  (PlG  >mugavus !11_S	et	f	\N
178168	mugavuste	"mugavus %mugava  )US_aS  <mugav ;02_A	et	f	\N
178184	omavaheliste	omavaheliste =vahelis  (PlG  >oma+vaheline !12_A	et	f	\N
178185	omavaheliste	"oma+vaheline %vahe  )LINE_aA  <oma+vahe ;16_S	et	f	\N
178186	väärtustatud	väärtustatud =väärtusta  (PtsPtIps  >väärtustama !27_V	et	f	\N
178187	väärtustatud	väärtustatud =väärtustatu  (PlN  >väärtustatu !01_S	et	f	\N
178188	väärtustatud	"väärtustatu %väärtusta  )TU1_vS  <väärtustama ;27_V	et	f	\N
178189	väärtustatud	väärtustatud =väärtustatud  (ID  >väärtustatud !41_A	et	f	\N
178190	väärtustatud	"väärtustatud %väärtusta  )TUD_vA  <väärtustama ;27_V	et	f	\N
178206	käsutuses	käsutuses =käsutuse  (SgIn  >käsutus !11_S	et	f	\N
178207	käsutuses	"käsutus %käsuta  )US_vS  <käsutama ;27_V	et	f	\N
178208	käsutuses	"käsutus %käsu  )TUS2_aS  <käsk ;22_S	et	f	\N
178209	muretsemisega	muretsemisega =muretsemise  (SgKom  >muretsemine !12_S	et	f	\N
178210	muretsemisega	"muretsemine %muretse  )MINE_vS  <muretsema ;27_V	et	f	\N
178258	naeratavaid	naeratavaid =naeratava  (PlP  >naeratav !02_A	et	f	\N
178259	naeratavaid	"naeratav %naerata  )V_vA  <naeratama ;27_V	et	f	\N
178279	pohlaid	?pohlaid =pohlai  (PlN  >pohlai !26_S	et	f	\N
178280	pohlaid	?pohlaid =pohlai  (SgP  >pohlai !26_S	et	f	\N
178281	pohlaid	?pohlaid =pohlaid  (SgN  >pohlaid !22_S	et	f	\N
178320	hakkaja	hakkaja =hakkaja  (SgN  >hakkaja !01_SA	et	f	\N
178321	hakkaja	"hakkaja %hakka  )JA_vS  <hakkama ;29_V	et	f	\N
178322	hakkaja	hakkaja =hakkaja  (SgG  >hakkaja !01_SA	et	f	\N
178323	hakkaja	hakkaja =aja  (SgG  >hakk+aeg !22_S	et	f	\N
178325	juljaga	?juljaga =julja  (SgKom  >juljas !02_A	et	f	\N
178326	juljaga	?juljaga =julja  (SgKom  >julja !16_S	et	f	\N
178331	märgikogu	märgikogu =kogu  (SgN  >märgi+kogu !17_S	et	f	\N
178332	märgikogu	märgikogu =kogu  (SgG  >märgi+kogu !17_S	et	f	\N
178333	märgikogu	märgikogu =kogu  (SgP  >märgi+kogu !17_S	et	f	\N
178340	isesisvalt	?isesisvalt =isesisva  (SgAbl  >isesisva !16_S	et	f	\N
178341	isesisvalt	?isesisvalt =isesisvalt  (ID  >isesisvalt !41_D	et	f	\N
178236	päkapikuid	?päkapikuid =pikui  (SgP  >päka+pikui !26_S	et	f	\N
178237	päkapikuid	?päkapikuid =pikuid  (SgN  >päka+pikuid !22_S	et	f	\N
178247	lõiguid	?lõiguid =lõigui  (PlN  >lõigui !26_S	et	f	\N
178248	lõiguid	?lõiguid =lõigui  (SgP  >lõigui !26_S	et	f	\N
178249	lõiguid	?lõiguid =lõiguid  (SgN  >lõiguid !22_S	et	f	\N
178272	eluetapide	### eluetapide	et	f	\N
178284	kirjadst	?kirjadst =kirjadst  (SgN  >kirjadst !22_S	et	f	\N
178287	pärandus	pärandus =pärandu  (IndIpfSg3  >päranduma !27_V	et	f	\N
178288	pärandus	pärandus =pärandus  (SgN  >pärandus !11_S	et	f	\N
178289	pärandus	"pärandus %päranda  )US_vS  <pärandama ;27_V	et	f	\N
178291	küülalistuba	?küülalistuba =küülalistuba  (SgN  >küülalistuba !16_S	et	f	\N
178292	küülalistuba	?küülalistuba =küülalistuba  (SgG  >küülalistuba !16_S	et	f	\N
178301	põhitegevus	põhitegevus =tegevus  (SgN  >põhi+tegevus !11_S	et	f	\N
178302	põhitegevus	"põhi+tegevus %tegeva  )US_aS  <põhi+tegev ;02_A	et	f	\N
178303	töökus	töökus =töökus  (SgN  >töökus !11~09_S	et	f	\N
178304	töökus	"töökus %tööka  )US_aS  <töökas ;02_A	et	f	\N
178306	koolikaslast	koolikaslast =la  (SgEl  >kooli+kas+la !26_S	et	f	\N
178307	koolikaslast	koolikaslast =las  (SgP  >kooli+kas+laps !14_S	et	f	\N
178308	koolikaslast	koolikaslast =last  (SgN  >kooli+kas+last !22_S	et	f	\N
178309	koolikaslast	koolikaslast =kaslas  (SgP  >kooli+kaslane !12?10_S	et	f	\N
178316	muiodu	?muiodu =muiodu  (SgN  >muiodu !01_S	et	f	\N
178317	muiodu	?muiodu =muiodu  (SgG  >muiodu !01_S	et	f	\N
178318	muiodu	?muiodu =muiodu  (IndPrPs_  >muioduma !27_V	et	f	\N
178319	muiodu	?muiodu =muiodu  (ImpPrSg2  >muioduma !27_V	et	f	\N
178329	sõbralikkus	sõbralikkus =sõbralikkus  (SgN  >sõbralikkus !11~09_S	et	f	\N
178330	sõbralikkus	"sõbralikkus %sõbralikku  )US_aS  <sõbralik ;25_A	et	f	\N
178349	sõidsid	?sõidsid =sõidsi  (PlN  >sõids !22_S	et	f	\N
178350	sõidsid	?sõidsid =sõidsi  (IndPrSg2  >sõidsima !28_V	et	f	\N
178365	30072003a	### 30072003a	et	f	\N
178378	ankeeti	ankeeti =ankeeti  (SgP  >ankeet !22_S	et	f	\N
178381	ankeeti	ankeeti =ankeeti  (SgAdt  >ankeet !22_S	et	f	\N
178395	versace	### versace	et	f	\N
178462	opib	?opib =opi  (IndPrSg3  >opima !27_V	et	f	\N
178463	opib	?opib =opi  (IndPrSg3  >oppima !28_V	et	f	\N
178464	kuduma	kuduma =kudu  (Sup  >kuduma !28_V	et	f	\N
178465	kuduma	kuduma =kuduma  (SgG  >kudum !02_S	et	f	\N
178466	viiese	viiese =viiese  (SgG  >viiene !10_AS	et	f	\N
178467	viiese	"viiene %viie  )NE_aA  <viis ;14_N	et	f	\N
178490	hobit	?hobit =hobit  (SgN  >hobit !02_S	et	f	\N
178502	suuremed	?suuremed =eme  (PlN  >suur+eme !16_S	et	f	\N
178503	suuremed	?suuremed =reme  (PlN  >suu+reme !16_S	et	f	\N
178518	võttavad	?võttavad =võtta  (IndPrPl3  >võttama !29_V	et	f	\N
178519	võttavad	?võttavad =võttava  (PlN  >võttava !01_S	et	f	\N
178520	võttavad	?võttavad =võttava  (PlN  >võttav !02_A	et	f	\N
178535	tuula	tuula =tuula  (IndPrPs_  >tuulama !29_V	et	f	\N
178536	tuula	tuula =tuula  (ImpPrSg2  >tuulama !29_V	et	f	\N
178548	lehet	?lehet =lehe  (SgP  >lehe !16_S	et	f	\N
178550	kastanipuud	kastanipuud =puu  (PlN  >kastani+puu !26_S	et	f	\N
178551	kastanipuud	kastanipuud =puu  (SgP  >kastani+puu !26_S	et	f	\N
178552	kastanipuud	kastanipuud =puud  (SgN  >kastani+puud !22_S	et	f	\N
178559	puudelt-põsastelt	?puudelt-põsastelt =põsas  (PlAbl  >puudelt-põsas !09_S	et	f	\N
178560	puudelt-põsastelt	?puudelt-põsastelt =põsas  (PlAbl  >puudelt-põsane !10_A	et	f	\N
178561	puudelt-põsastelt	?puudelt-põsastelt =põsastelt  (ID  >puudelt-põsastelt !41_D	et	f	\N
178590	puunaseks	puunaseks =puunase  (SgTr  >puunane !10_A	et	f	\N
178591	puunaseks	"puunane %puuna  )NE_aA  <puuna ;16_S	et	f	\N
178596	väher	?väher =väher  (SgN  >väher !02_S	et	f	\N
178625	kinknud	?kinknud =kinknu  (PlN  >kinknu !01_S	et	f	\N
178626	kinknud	?kinknud =kinknu  (IndPrSg2  >kinknuma !27_V	et	f	\N
178627	kinknud	?kinknud =kinknud  (ID  >kinknud !41_A	et	f	\N
178655	tarbimisele	tarbimisele =tarbimise  (SgAll  >tarbimine !12_S	et	f	\N
178656	tarbimisele	"tarbimine %tarbi  )MINE_vS  <tarbima ;27_V	et	f	\N
178723	öökulli-tüüpi	öökulli-tüüpi =tüüpi  (SgP  >öökulli-tüüp !22_S	et	f	\N
178724	öökulli-tüüpi	öökulli-tüüpi =tüüpi  (SgAdt  >öökulli-tüüp !22_S	et	f	\N
178727	elavik	?elavik =elavik  (SgN  >elavik !25_S	et	f	\N
178745	teegema	?teegema =teege  (Sup  >teegema !27_V	et	f	\N
178746	teegema	?teegema =teegema  (SgG  >teegem !02_A	et	f	\N
178747	teegema	?teegema =gema  (SgN  >tee+gema !17_S	et	f	\N
178748	teegema	?teegema =gema  (SgG  >tee+gema !17_S	et	f	\N
178749	teegema	?teegema =gema  (SgP  >tee+gema !17_S	et	f	\N
178754	ksu	### ksu	et	f	\N
178817	ekoloog	?ekoloog =ekoloog  (SgN  >ekoloog !22_S	et	f	\N
178819	töökab	?töökab =tööka  (IndPrSg3  >töökama !29_V	et	f	\N
178822	ooe	### ooe	et	f	\N
178852	praktilase	?praktilase =praktilase  (SgG  >praktilane !12_S	et	f	\N
178853	ehitusekaupluses	?ehitusekaupluses =ehitusekaupluse  (SgIn  >ehitusekauplus !11~09_S	et	f	\N
178854	ehitusekaupluses	?ehitusekaupluses =ekaupluse  (SgIn  >ehitus+ekauplus !11_S	et	f	\N
178866	ostjadele	### ostjadele	et	f	\N
178260	paadisid	?paadisid =paadi  (PlP  >paadi !16_S	et	f	\N
178261	paadisid	?paadisid =paadi  (PlP  >paad !22_S	et	f	\N
178262	paadisid	?paadisid =paadi  (IndIpfSg2  >paadima !28_V	et	f	\N
178263	paadisid	?paadisid =paadi  (IndIpfPl3  >paadima !28_V	et	f	\N
178267	kajakaid	kajakaid =kajaka  (PlP  >kajakas !02_S	et	f	\N
178268	kajakaid	kajakaid =kai  (PlN  >kaja+kai !26_S	et	f	\N
178270	kajakaid	kajakaid =kai  (SgP  >kaja+kai !26_S	et	f	\N
178290	estik	?estik =estik  (SgN  >estik !02_S	et	f	\N
178293	kottasemini	kottasemini =mi  (SgTer  >kott+ase+mi !26_S	et	f	\N
178294	kottasemini	kottasemini =mini  (SgN  >kott+ase+mini !17~16_S	et	f	\N
178295	kottasemini	kottasemini =mini  (SgG  >kott+ase+mini !17~16_S	et	f	\N
178296	kottasemini	kottasemini =mini  (SgP  >kott+ase+mini !17_S	et	f	\N
178314	tähelepanelikkus	tähelepanelikkus =panelikkus  (SgN  >tähele+panelikkus !11~09_S	et	f	\N
178315	tähelepanelikkus	"tähele+panelikkus %panelikku  )US_aS  <tähele+panelik ;25_A	et	f	\N
178364	kohtumenisi	?kohtumenisi =umenisi  (PlP  >koht+umenis !11_S	et	f	\N
178366	jollas	?jollas =jolla  (SgIn  >jolla !16_S	et	f	\N
178367	jollas	?jollas =jolla  (IndIpfSg3  >jollama !29_V	et	f	\N
178368	jollas	?jollas =jollas  (SgN  >jollas !07_S	et	f	\N
178369	tapediid	?tapediid =tapedi  (PlP  >tapedi !01_S	et	f	\N
178370	tapediid	?tapediid =tapedii  (PlN  >tapedii !26_S	et	f	\N
178371	tapediid	?tapediid =tapedii  (SgP  >tapedii !26_S	et	f	\N
178372	tapediid	?tapediid =tapediid  (SgN  >tapediid !22_S	et	f	\N
178377	graffik	?graffik =graffik  (SgN  >graffik !02_S	et	f	\N
178398	salvador	?salvador =salvador  (SgN  >salvador !19_S	et	f	\N
178399	salvador	?salvador =ador  (SgN  >salv+ador !02_S	et	f	\N
178411	signatsioni	?signatsioni =signatsio  (SgTer  >signatsio !01_S	et	f	\N
178412	signatsioni	?signatsioni =signatsioni  (SgN  >signatsioni !16_S	et	f	\N
178413	signatsioni	?signatsioni =signatsioni  (SgG  >signatsion !19~02_S	et	f	\N
178414	signatsioni	?signatsioni =signatsioni  (SgG  >signatsioni !16_S	et	f	\N
178415	signatsioni	?signatsioni =signatsioni  (SgP  >signatsion !19_S	et	f	\N
178416	signatsioni	?signatsioni =signatsioni  (SgAdt  >signatsion !19_S	et	f	\N
178417	signatsioni	?signatsioni =signatsioni  (IndPrPs_  >signatsionima !28_V	et	f	\N
178418	signatsioni	?signatsioni =signatsioni  (ImpPrSg2  >signatsionima !28_V	et	f	\N
178425	rimi	?rimi =rimi  (SgN  >rimi !17_S	et	f	\N
178426	rimi	?rimi =rimi  (SgG  >rimi !17_S	et	f	\N
178427	rimi	?rimi =rimi  (SgP  >rimi !17_S	et	f	\N
178428	rimi	?rimi =rimi  (IndPrPs_  >rimima !27_V	et	f	\N
178429	rimi	?rimi =rimi  (ImpPrSg2  >rimima !27_V	et	f	\N
178447	sookid	### sookid	et	f	\N
178451	plaanija	plaanija =plaanija  (SgN  >plaanija !01_S	et	f	\N
178452	plaanija	"plaanija %plaani  )JA_vS  <plaanima ;28_V	et	f	\N
178453	plaanija	plaanija =plaanija  (SgG  >plaanija !01_S	et	f	\N
178454	kolmakorruselises	kolmakorruselises =korruselise  (SgIn  >kolma+korruseline !12_A	et	f	\N
178455	kolmakorruselises	"kolma+korruseline %korruse  )LINE_aA  <kolma+korrus ;09_S	et	f	\N
178456	trükikodas	?trükikodas =kodas  (SgN  >trüki+kodas !07_S	et	f	\N
178458	üheksateistaastane	üheksateistaastane =aastane  (SgN  >üheksa+teist+aastane !12~10_A	et	f	\N
178459	üheksateistaastane	"üheksa+teist+aastane %aasta  )NE_aA  <üheksa+teist+aasta ;01_S	et	f	\N
178477	lasteaega	lasteaega =aega  (SgP  >laste+aeg !22_S	et	f	\N
178478	lasteaega	lasteaega =aega  (SgAdt  >laste+aeg !22_S	et	f	\N
178488	proobleme	?proobleme =prooble  (IndPrPl1  >prooblema !30_V	et	f	\N
178504	alju	?alju =alju  (SgN  >alju !16_S	et	f	\N
178505	alju	?alju =alju  (SgG  >alju !16_S	et	f	\N
178506	alju	?alju =alju  (IndPrPs_  >aljuma !27_V	et	f	\N
178507	alju	?alju =alju  (ImpPrSg2  >aljuma !27_V	et	f	\N
178539	päeast	?päeast =päeas  (SgP  >päeane !12~10_A	et	f	\N
178568	jarkjargult	?jarkjargult =jarkjargu  (SgAbl  >jarkjargu !01_S	et	f	\N
178569	jarkjargult	?jarkjargult =jarkjargult  (ID  >jarkjargult !41_D	et	f	\N
178573	jarjest	?jarjest =jarje  (SgEl  >jarje !06_S	et	f	\N
178574	jarjest	?jarjest =jarjes  (SgP  >jarjes !09_S	et	f	\N
178575	jarjest	?jarjest =jarjes  (SgP  >jarjene !10_A	et	f	\N
178583	sojäd	### sojäd	et	f	\N
178601	talmenelt	?talmenelt =talmenelt  (ID  >talmenelt !41_D	et	f	\N
178603	pähkleit	?pähkleit =pähkleit  (SgN  >pähkleit !22_S	et	f	\N
178619	võistlenud	?võistlenud =võistlenu  (PlN  >võistlenu !01_S	et	f	\N
178620	võistlenud	?võistlenud =võistlenu  (IndPrSg2  >võistlenuma !27_V	et	f	\N
178621	võistlenud	?võistlenud =võistlenud  (ID  >võistlenud !41_A	et	f	\N
178628	tõlknud	?tõlknud =tõlknu  (PlN  >tõlknu !01_S	et	f	\N
178629	tõlknud	?tõlknud =tõlknu  (IndPrSg2  >tõlknuma !27_V	et	f	\N
178630	tõlknud	?tõlknud =tõlknud  (ID  >tõlknud !41_A	et	f	\N
178643	täisti	?täisti =täisti  (ID  >täisti !41_D	et	f	\N
178644	täisti	?täisti =täisti  (SgG  >täist !22_S	et	f	\N
178645	täisti	?täisti =täisti  (SgP  >täist !22_S	et	f	\N
178646	täisti	?täisti =täisti  (SgAdt  >täist !22_S	et	f	\N
178647	täisti	?täisti =täisti  (IndPrPs_  >täistima !28_V	et	f	\N
178648	täisti	?täisti =täisti  (ImpPrSg2  >täistima !28_V	et	f	\N
178649	täidaksid	täidaksid =täida  (KndPrSg2  >täitma !34_V	et	f	\N
178300	koolikaaslast	koolikaaslast =kaaslas  (SgP  >kooli+kaaslane !12?10_S	et	f	\N
178310	paindlikkus	paindlikkus =paindlikkus  (SgN  >paindlikkus !11~09_S	et	f	\N
178311	paindlikkus	"paindlikkus %paindlikku  )US_aS  <paindlik ;25_A	et	f	\N
178312	harrastuse	harrastuse =harrastuse  (SgG  >harrastus !11_S	et	f	\N
178313	harrastuse	"harrastus %harrasta  )US_vS  <harrastama ;27_V	et	f	\N
178324	sõbralikkess	?sõbralikkess =sõbralikkess  (SgN  >sõbralikkess !22_S	et	f	\N
178353	ostjad	ostjad =ostja  (PlN  >ostja !01_S	et	f	\N
178354	ostjad	"ostja %ost  )JA_vS  <ostma ;34_V	et	f	\N
178357	käätte	?käätte =käätte  (SgN  >käätte !06_S	et	f	\N
178358	käätte	?käätte =käätte  (SgG  >käätte !06_S	et	f	\N
178359	käätte	?käätte =käätte  (PlP  >käätt !22_S	et	f	\N
178360	käätte	?käätte =käätte  (IndPrPs_  >käättema !27_V	et	f	\N
178361	käätte	?käätte =käätte  (ImpPrSg2  >käättema !27_V	et	f	\N
178375	kaaminad	?kaaminad =kaamina  (PlN  >kaamin !02_S	et	f	\N
178385	kutsutamine	?kutsutamine =kutsutamine  (SgN  >kutsutamine !12_S	et	f	\N
178386	kutsutamine	?kutsutamine =kutsutamine  (PlP  >kutsutamin !19_S	et	f	\N
178387	tsentral	?tsentral =tsentra  (SgAd  >tsentra !01_S	et	f	\N
178388	tsentral	?tsentral =tsentral  (SgN  >tsentral !02_S	et	f	\N
178409	kassale	kassale =kassa  (SgAll  >kassa !16_S	et	f	\N
178410	kassale	kassale =sale  (SgN  >kas+sale !02_A	et	f	\N
178443	kolmekorruseline	kolmekorruseline =korruseline  (SgN  >kolme+korruseline !12_A	et	f	\N
178444	kolmekorruseline	"kolme+korruseline %korruse  )LINE_aA  <kolme+korrus ;09_S	et	f	\N
178446	kudub	### kudub	et	f	\N
178449	velsicol	?velsicol =velsico  (SgAd  >velsico !16_S	et	f	\N
178450	velsicol	?velsicol =velsicol  (SgN  >velsicol !19_S	et	f	\N
178457	edik	?edik =edik  (SgN  >edik !02_S	et	f	\N
178471	lilleg	### lilleg	et	f	\N
178481	popularseid	?popularseid =popularse  (PlP  >popularne !02_A	et	f	\N
178483	popularseid	?popularseid =popularsei  (PlN  >popularsei !26_S	et	f	\N
178484	popularseid	?popularseid =popularsei  (SgP  >popularsei !26_S	et	f	\N
178485	popularseid	?popularseid =ularse  (PlP  >pop+ularne !02_A	et	f	\N
178486	popularseid	?popularseid =ularsei  (PlN  >pop+ularsei !26_S	et	f	\N
178487	popularseid	?popularseid =ularsei  (SgP  >pop+ularsei !26_S	et	f	\N
178489	nimitada	?nimitada =nimita  (Inf  >nimitama !27_V	et	f	\N
178491	nimitada	?nimitada =tada  (SgN  >nimi+tada !17_S	et	f	\N
178492	nimitada	?nimitada =tada  (SgG  >nimi+tada !17_S	et	f	\N
178493	nimitada	?nimitada =tada  (SgP  >nimi+tada !17_S	et	f	\N
178494	eluenergia	eluenergia =energia  (SgN  >elu+energia !01_S	et	f	\N
178495	eluenergia	eluenergia =energia  (SgG  >elu+energia !01_S	et	f	\N
178514	kursusee	?kursusee =kursusee  (SgN  >kursusee !26_S	et	f	\N
178515	kursusee	?kursusee =kursusee  (SgG  >kursusee !26_S	et	f	\N
178527	viiekümne	?viiekümne =viiekümne  (SgN  >viiekümne !02_A	et	f	\N
178528	viiekümne	?viiekümne =viiekümne  (PlP  >viiekümn !22_S	et	f	\N
178529	viiekümne	?viiekümne =kümne  (SgN  >viie+kümne !02_A	et	f	\N
178530	viiekümne	?viiekümne =kümne  (PlP  >viie+kümn !22_S	et	f	\N
178537	püahapäeval	?püahapäeval =püahapäeva  (SgAd  >püahapäeva !16_S	et	f	\N
178538	püahapäeval	?püahapäeval =püahapäeval  (SgN  >püahapäeval !02_S	et	f	\N
178549	kukup	?kukup =kukup  (SgN  >kukup !02_S	et	f	\N
178576	puudelt-põõsastelt	puudelt-põõsastelt =põõsas  (PlAbl  >puudelt-põõsas !07_S	et	f	\N
178577	puudelt-põõsastelt	puudelt-põõsastelt =põõsas  (PlAbl  >puudelt-põõsane !10_A	et	f	\N
178578	puudelt-põõsastelt	"puudelt-põõsane %põõsa  )NE_aA  <puudelt-põõsas ;07_S	et	f	\N
178581	täsahilju	?täsahilju =täsahilju  (IndPrPs_  >täsahiljuma !27_V	et	f	\N
178582	täsahilju	?täsahilju =täsahilju  (ImpPrSg2  >täsahiljuma !27_V	et	f	\N
178584	puud-põlsad	?puud-põlsad =põlsa  (PlN  >puud-põlsa !16_S	et	f	\N
178585	puud-põlsad	?puud-põlsad =põlsa  (IndPrSg2  >puud-põlsama !29_V	et	f	\N
178602	adades	?adades =ada  (PlIn  >ada !17_S	et	f	\N
178604	adades	?adades =ada  (Ger  >adama !27_V	et	f	\N
178605	jahedumaks	?jahedumaks =jahedu  (SupTr  >jaheduma !27_V	et	f	\N
178606	jahedumaks	?jahedumaks =jaheduma  (SgTr  >jahedum !02_A	et	f	\N
178607	jahedumaks	?jahedumaks =duma  (SgTr  >jahe+duma !17_S	et	f	\N
178631	suvekontsertitel	?suvekontsertitel =suvekontsertite  (PlAd  >suvekontsertitt !22_S	et	f	\N
178632	suvekontsertitel	?suvekontsertitel =ite  (PlAd  >suve+kontsert+itt !22_S	et	f	\N
178633	suvekontsertitel	?suvekontsertitel =itel  (SgN  >suve+kontsert+itel !02_S	et	f	\N
178634	suvekontsertitel	?suvekontsertitel =sertite  (PlAd  >suve+kont+sertitt !22_S	et	f	\N
178635	suvekontsertitel	?suvekontsertitel =kontserti  (PlAd  >suve+kontserti !01_S	et	f	\N
178636	suvekontsertitel	?suvekontsertitel =kontsertite  (PlAd  >suve+kontsertitt !22_S	et	f	\N
178666	aadres	?aadres =aadre  (SgIn  >aadre !06_S	et	f	\N
178667	aadres	?aadres =aadre  (IndIpfSg3  >aadrema !27_V	et	f	\N
178668	aadres	?aadres =aadres  (SgN  >aadres !09_S	et	f	\N
178695	arvatab	?arvatab =arvata  (IndPrSg3  >arvatama !27_V	et	f	\N
178699	inimes	### inimes	et	f	\N
178700	inimet	### inimet	et	f	\N
178726	intervjueeritar	?intervjueeritar =intervjueeritar  (SgN  >intervjueeritar !19_S	et	f	\N
178730	ettevõtmini	?ettevõtmini =ettevõtmi  (SgTer  >ettevõtm !22_S	et	f	\N
178305	tutvastasime	?tutvastasime =tutvasta  (IndIpfPl1  >tutvastama !27_V	et	f	\N
178327	diskos	?diskos =disko  (SgIn  >disko !16_S	et	f	\N
178328	diskos	?diskos =diskos  (SgN  >diskos !11~09_S	et	f	\N
178334	kohlta-järve	kohlta-järve =järve  (SgG  >kohlta-järv !22_S	et	f	\N
178335	kohlta-järve	kohlta-järve =järve  (SgP  >kohlta-järv !22_S	et	f	\N
178336	kohlta-järve	kohlta-järve =järve  (SgAdt  >kohlta-järv !22_S	et	f	\N
178337	kohlta-järve	kohlta-järve =järve  (PlP  >kohlta-järv !22_S	et	f	\N
178338	öökullitüüpi	öökullitüüpi =tüüpi  (SgP  >öö+kulli+tüüp !22_S	et	f	\N
178339	öökullitüüpi	öökullitüüpi =tüüpi  (SgAdt  >öö+kulli+tüüp !22_S	et	f	\N
178351	poodisest	?poodisest =poodise  (SgEl  >poodis !09_S	et	f	\N
178352	poodisest	?poodisest =poodises  (SgP  >poodisene !12_A	et	f	\N
178362	rõmmustasin	?rõmmustasin =rõmmusta  (IndIpfSg1  >rõmmustama !27_V	et	f	\N
178363	rõmmustasin	?rõmmustasin =rõmmustasin  (SgN  >rõmmustasin !19_S	et	f	\N
178389	agdek	?agdek =agdek  (SgN  >agdek !02_S	et	f	\N
178390	parfümeerija	?parfümeerija =parfümeerija  (SgN  >parfümeerija !01_S	et	f	\N
178391	parfümeerija	?parfümeerija =parfümeerija  (SgG  >parfümeerija !01_S	et	f	\N
178392	parfümeerija	?parfümeerija =parfümeerija  (SgG  >parfümeerijas !02_A	et	f	\N
178400	loreal	?loreal =lorea  (SgAd  >lorea !26_S	et	f	\N
178401	loreal	?loreal =loreal  (SgN  >loreal !19_S	et	f	\N
178402	juusevärvid	?juusevärvid =juusevärvi  (PlN  >juusevärv !22_S	et	f	\N
178404	juusevärvid	?juusevärvid =juusevärvi  (IndPrSg2  >juusevärvima !28_V	et	f	\N
178406	juusevärvid	?juusevärvid =evärvi  (PlN  >juus+evärvi !01_S	et	f	\N
178408	juusevärvid	?juusevärvid =evärvi  (PlN  >juus+evärv !22_S	et	f	\N
178421	ladu	ladu =ladu  (SgN  >ladu !18_S	et	f	\N
178422	ladu	ladu =ladu  (SgP  >ladu !18_S	et	f	\N
178438	abikasa	?abikasa =abikasa  (SgN  >abikasa !16_S	et	f	\N
178439	abikasa	?abikasa =abikasa  (SgG  >abikasa !16_S	et	f	\N
178440	abikasa	?abikasa =kasa  (SgN  >abi+kasa !17_S	et	f	\N
178441	abikasa	?abikasa =kasa  (SgG  >abi+kasa !17_S	et	f	\N
178442	abikasa	?abikasa =kasa  (SgP  >abi+kasa !17_S	et	f	\N
178445	tegeme	### tegeme	et	f	\N
178448	tutraga	### tutraga	et	f	\N
178482	poppkruppe	?poppkruppe =poppkruppe  (PlP  >poppkrupp !22_S	et	f	\N
178496	huviala	huviala =ala  (SgN  >huvi+ala !17_S	et	f	\N
178497	huviala	huviala =ala  (SgG  >huvi+ala !17_S	et	f	\N
178498	huviala	huviala =ala  (SgP  >huvi+ala !17_S	et	f	\N
178501	disk	?disk =disk  (SgN  >disk !22_S	et	f	\N
178510	tegelenda	?tegelenda =tegelenda  (SgN  >tegelenda !16_S	et	f	\N
178511	tegelenda	?tegelenda =tegelenda  (SgG  >tegelenda !16_S	et	f	\N
178512	tegelenda	?tegelenda =tegelenda  (IndPrPs_  >tegelendama !27_V	et	f	\N
178513	tegelenda	?tegelenda =tegelenda  (ImpPrSg2  >tegelendama !27_V	et	f	\N
178531	tööstaaz	### tööstaaz	et	f	\N
178534	kasvahooned	?kasvahooned =kasvahoone  (PlN  >kasvahoone !16_S	et	f	\N
178540	sovitaksin	?sovitaksin =sovita  (KndPrSg1  >sovitama !27_V	et	f	\N
178541	sovitaksin	?sovitaksin =sovitaksi  (IndPrSg1  >sovitaksima !28_V	et	f	\N
178542	sovitaksin	?sovitaksin =sovitaksin  (SgN  >sovitaksin !02_S	et	f	\N
178543	mereranda	mereranda =randa  (SgP  >mere+rand !22_S	et	f	\N
178544	mereranda	mereranda =randa  (SgAdt  >mere+rand !22_S	et	f	\N
178545	rohilised	?rohilised =rohilise  (PlN  >rohiline !12_A	et	f	\N
178546	järkjärguld	?järkjärguld =järkjärguld  (SgN  >järkjärguld !22_S	et	f	\N
178547	järkjärguld	?järkjärguld =järguld  (SgN  >järk+järguld !02_S	et	f	\N
178553	kastamimunasid	### kastamimunasid	et	f	\N
178554	jäärjest	?jäärjest =jäärje  (SgEl  >jäärje !06_S	et	f	\N
178555	jäärjest	?jäärjest =jäärjes  (SgP  >jäärjes !09_S	et	f	\N
178556	jäärjest	?jäärjest =jäärjes  (SgP  >jäärjene !12~10_A	et	f	\N
178557	hedamaks	?hedamaks =heda  (SupTr  >hedama !27_V	et	f	\N
178558	hedamaks	?hedamaks =hedama  (SgTr  >hedam !02_A	et	f	\N
178570	värvuvat	värvuvat =värvu  (KvtPrPs  >värvuma !27_V	et	f	\N
178571	värvuvat	värvuvat =värvuva  (SgP  >värvuv !02_A	et	f	\N
178572	värvuvat	"värvuv %värvu  )V_vA  <värvuma ;27_V	et	f	\N
178579	valmistu	valmistu =valmistu  (IndPrPs_  >valmistuma !27_V	et	f	\N
178580	valmistu	valmistu =valmistu  (ImpPrSg2  >valmistuma !27_V	et	f	\N
178586	värvivad	värvivad =värvi  (IndPrPl3  >värvima !28_V	et	f	\N
178587	värvivad	värvivad =värviva  (PlN  >värviv !02_A	et	f	\N
178588	värvivad	"värviv %värvi  )V_vA  <värvima ;28_V	et	f	\N
178589	värvivad	värvivad =iva  (PlN  >värv+iva !17_S	et	f	\N
178597	kastanimunisid	?kastanimunisid =kastanimuni  (PlP  >kastanimun !19_S	et	f	\N
178598	kastanimunisid	?kastanimunisid =muni  (PlP  >kastani+muni !17_S	et	f	\N
178599	kastanimunisid	?kastanimunisid =animuni  (PlP  >kast+animun !19_S	et	f	\N
178600	kastanimunisid	?kastanimunisid =tanimuni  (PlP  >kas+tanimun !19_S	et	f	\N
178614	kandasin	?kandasin =kanda  (IndIpfSg1  >kandama !29_V	et	f	\N
178615	kandasin	?kandasin =kandasin  (SgN  >kandasin !19_S	et	f	\N
178616	lendnud	?lendnud =lendnu  (PlN  >lendnu !01_S	et	f	\N
178617	lendnud	?lendnud =lendnu  (IndPrSg2  >lendnuma !27_V	et	f	\N
178618	lendnud	?lendnud =lendnud  (ID  >lendnud !41_A	et	f	\N
178637	stop	### stop	et	f	\N
178342	isesisvalt	?isesisvalt =sisva  (SgAbl  >ise+sisva !16_S	et	f	\N
178343	poodes	?poodes =poo  (PlIn  >poo !26_S	et	f	\N
178344	poodes	?poodes =poode  (IndIpfSg3  >poodema !27_V	et	f	\N
178345	poodes	?poodes =poodes  (SgN  >poodes !09_S	et	f	\N
178346	kassapparat	?kassapparat =kassappara  (SgP  >kassappara !16_S	et	f	\N
178347	kassapparat	?kassapparat =arat  (SgN  >kas+sapp+arat !02_S	et	f	\N
178348	kassapparat	?kassapparat =sappara  (SgP  >kas+sappara !01_S	et	f	\N
178355	müügijuhataja	müügijuhataja =juhataja  (SgN  >müügi+juhataja !01_S	et	f	\N
178356	müügijuhataja	müügijuhataja =juhataja  (SgG  >müügi+juhataja !01_S	et	f	\N
178373	liimad	?liimad =liima  (PlN  >liima !16_S	et	f	\N
178374	liimad	?liimad =liima  (IndPrSg2  >liimama !29_V	et	f	\N
178376	ladul	?ladul =ladul  (SgN  >ladul !02_S	et	f	\N
178379	täitme	?täitme =täitme  (SgN  >täitme !06_S	et	f	\N
178380	täitme	?täitme =täitme  (SgG  >täitme !06_S	et	f	\N
178382	täitme	?täitme =täitme  (PlP  >täitm !22_S	et	f	\N
178383	täitme	?täitme =täitme  (IndPrPs_  >täitmema !27_V	et	f	\N
178384	täitme	?täitme =täitme  (ImpPrSg2  >täitmema !27_V	et	f	\N
178393	parfüm	?parfüm =parfüm  (SgN  >parfüm !02_S	et	f	\N
178394	lacoste	?lacoste =lacos  (PlG  >lacos !11~09_S	et	f	\N
178396	lalique	?lalique =lalique  (SgN  >lalique !01_S	et	f	\N
178397	lalique	?lalique =lalique  (SgG  >lalique !01_S	et	f	\N
178403	dekotraktiivkosmeetika	?dekotraktiivkosmeetika =dekotraktiivkosmeetika  (SgN  >dekotraktiivkosmeetika !01_S	et	f	\N
178405	dekotraktiivkosmeetika	?dekotraktiivkosmeetika =dekotraktiivkosmeetika  (SgG  >dekotraktiivkosmeetika !01_S	et	f	\N
178407	dekotraktiivkosmeetika	?dekotraktiivkosmeetika =dekotraktiivkosmeetika  (SgG  >dekotraktiivkosmeetikas !02_A	et	f	\N
178419	kallusin	?kallusin =kallu  (IndIpfSg1  >kalluma !27_V	et	f	\N
178420	kallusin	?kallusin =kallusin  (SgN  >kallusin !19_S	et	f	\N
178423	rakveres	### rakveres	et	f	\N
178424	meeldik	?meeldik =meeldik  (SgN  >meeldik !02_S	et	f	\N
178430	oletöö	?oletöö =oletöö  (SgN  >oletöö !26_S	et	f	\N
178431	oletöö	?oletöö =oletöö  (SgG  >oletöö !26_S	et	f	\N
178432	kolmekümne	?kolmekümne =kolmekümne  (SgN  >kolmekümne !02_A	et	f	\N
178433	kolmekümne	?kolmekümne =kolmekümne  (PlP  >kolmekümn !22_S	et	f	\N
178434	kolmekümne	?kolmekümne =kümne  (SgN  >kolme+kümne !02_A	et	f	\N
178435	kolmekümne	?kolmekümne =kümne  (PlP  >kolme+kümn !22_S	et	f	\N
178436	kolmekümne	?kolmekümne =ekümne  (SgN  >kolm+ekümne !02_A	et	f	\N
178437	kolmekümne	?kolmekümne =ekümne  (PlP  >kolm+ekümn !22_S	et	f	\N
178460	kuusteistaastane	kuusteistaastane =aastane  (SgN  >kuus+teist+aastane !12~10_A	et	f	\N
178461	kuusteistaastane	"kuus+teist+aastane %aasta  )NE_aA  <kuus+teist+aasta ;01_S	et	f	\N
178468	venema	?venema =vene  (Sup  >venema !27_V	et	f	\N
178469	venema	?venema =venema  (SgG  >venem !02_A	et	f	\N
178470	kõib	?kõib =kõib  (SgN  >kõib !22_S	et	f	\N
178472	ljuba	?ljuba =ljuba  (SgN  >ljuba !17_S	et	f	\N
178473	ljuba	?ljuba =ljuba  (SgG  >ljuba !17_S	et	f	\N
178474	ljuba	?ljuba =ljuba  (SgP  >ljuba !17_S	et	f	\N
178475	ljuba	?ljuba =ljuba  (IndPrPs_  >ljubama !27_V	et	f	\N
178476	ljuba	?ljuba =ljuba  (ImpPrSg2  >ljubama !27_V	et	f	\N
178479	ratsutamine	ratsutamine =ratsutamine  (SgN  >ratsutamine !12_S	et	f	\N
178480	ratsutamine	"ratsutamine %ratsuta  )MINE_vS  <ratsutama ;27_V	et	f	\N
178499	klassika	klassika =klassika  (SgN  >klassika !01_S	et	f	\N
178500	klassika	klassika =klassika  (SgG  >klassika !01_S	et	f	\N
178508	kursustee	kursustee =tee  (SgN  >kursus+tee !26_S	et	f	\N
178509	kursustee	kursustee =tee  (SgG  >kursus+tee !26_S	et	f	\N
178516	kursud	?kursud =kursu  (PlN  >kursu !16_S	et	f	\N
178517	kursud	?kursud =kursu  (IndPrSg2  >kursuma !27_V	et	f	\N
178521	juksla	?juksla =juksla  (SgN  >juksla !01_S	et	f	\N
178522	juksla	?juksla =juksla  (SgG  >juksla !01_S	et	f	\N
178523	juksla	?juksla =juksla  (IndPrPs_  >jukslama !29_V	et	f	\N
178524	juksla	?juksla =juksla  (ImpPrSg2  >jukslama !29_V	et	f	\N
178525	rägisin	?rägisin =rägi  (IndIpfSg1  >rägima !27_V	et	f	\N
178526	rägisin	?rägisin =rägisin  (SgN  >rägisin !19_S	et	f	\N
178532	andrei	?andrei =andrei  (SgN  >andrei !26_S	et	f	\N
178533	andrei	?andrei =andrei  (SgG  >andrei !26_S	et	f	\N
178562	lõõrtsi	?lõõrtsi =lõõrtsi  (ID  >lõõrtsi !41_D	et	f	\N
178563	lõõrtsi	?lõõrtsi =lõõrtsi  (SgG  >lõõrts !22_S	et	f	\N
178564	lõõrtsi	?lõõrtsi =lõõrtsi  (SgP  >lõõrts !22_S	et	f	\N
178565	lõõrtsi	?lõõrtsi =lõõrtsi  (SgAdt  >lõõrts !22_S	et	f	\N
178566	lõõrtsi	?lõõrtsi =lõõrtsi  (IndPrPs_  >lõõrtsima !28_V	et	f	\N
178567	lõõrtsi	?lõõrtsi =lõõrtsi  (ImpPrSg2  >lõõrtsima !28_V	et	f	\N
178592	eritti	?eritti =eritti  (SgN  >eritti !01_S	et	f	\N
178593	eritti	?eritti =eritti  (SgG  >eritti !01_S	et	f	\N
178594	eritti	?eritti =eritti  (SgP  >eritt !22_S	et	f	\N
178595	eritti	?eritti =eritti  (SgAdt  >eritt !22_S	et	f	\N
178608	pudelt-põsastelt	?pudelt-põsastelt =põsas  (PlAbl  >pudelt-põsas !09_S	et	f	\N
178609	pudelt-põsastelt	?pudelt-põsastelt =põsas  (PlAbl  >pudelt-põsane !10_A	et	f	\N
178610	pudelt-põsastelt	?pudelt-põsastelt =põsastelt  (ID  >pudelt-põsastelt !41_D	et	f	\N
178611	hommikutti	hommikutti =utti  (SgP  >hommik+utt !22_S	et	f	\N
178612	hommikutti	hommikutti =utti  (SgAdt  >hommik+utt !22_S	et	f	\N
178613	hommikutti	hommikutti =utti  (PlP  >hommik+utt !22_S	et	f	\N
178622	märknud	?märknud =märknu  (PlN  >märknu !01_S	et	f	\N
178623	märknud	?märknud =märknu  (IndPrSg2  >märknuma !27_V	et	f	\N
178624	märknud	?märknud =märknud  (ID  >märknud !41_A	et	f	\N
178638	ulutustel	ulutustel =ulutus  (PlAd  >ulutus !11_S	et	f	\N
178639	ulutustel	"ulutus %ulu  )TUS1_aS  <uluma ;27_V	et	f	\N
178640	ulutustel	"ulutus %ulu  )TUS1_aS  <ulguma ;28_V	et	f	\N
178641	ulutustel	"ulutus %ulu  )TUS2_aS  <ulg ;22_S	et	f	\N
178642	ulutustel	ulutustel =tuste  (PlAd  >ulu+tust !22_S	et	f	\N
178651	seotub	?seotub =seotu  (IndPrSg3  >seotuma !27_V	et	f	\N
178652	raiskavad	raiskavad =raiska  (IndPrPl3  >raiskama !29_V	et	f	\N
178653	raiskavad	raiskavad =raiskava  (PlN  >raiskav !02_A	et	f	\N
178654	raiskavad	"raiskav %raiska  )V_vA  <raiskama ;29_V	et	f	\N
178663	12-	### 12-	et	f	\N
178664	13-aastane	-aastane =aastane  (SgN  >-aastane !12~10_A	et	f	\N
178665	13-aastane	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
178685	t-7-5651	### t-7-5651	et	f	\N
178703	töötast	?töötast =tööta  (SgEl  >tööta !16_S	et	f	\N
178704	töötast	?töötast =töötas  (SgP  >töötas !07_S	et	f	\N
178705	töötast	?töötast =töötas  (SgP  >töötane !12~10_A	et	f	\N
178706	töötast	?töötast =tast  (SgN  >töö+tast !22_S	et	f	\N
178736	kohtutäituri	kohtutäituri =turi  (SgN  >kohtu+täi+turi !24_S	et	f	\N
178737	kohtutäituri	kohtutäituri =täituri  (SgG  >kohtu+täitur !02_S	et	f	\N
178738	k-järve	k-järve =järve  (SgG  >k-järv !22_S	et	f	\N
178739	k-järve	k-järve =järve  (SgP  >k-järv !22_S	et	f	\N
178740	k-järve	k-järve =järve  (SgAdt  >k-järv !22_S	et	f	\N
178741	k-järve	k-järve =järve  (PlP  >k-järv !22_S	et	f	\N
178755	pola	?pola =pola  (SgN  >pola !17_S	et	f	\N
178756	pola	?pola =pola  (SgG  >pola !17_S	et	f	\N
178757	pola	?pola =pola  (SgP  >pola !17_S	et	f	\N
178758	pola	?pola =pola  (IndPrPs_  >polama !27_V	et	f	\N
178759	pola	?pola =pola  (ImpPrSg2  >polama !27_V	et	f	\N
178762	12-c	### 12-c	et	f	\N
178765	12s	### 12s	et	f	\N
178766	öökuli	öökuli =kuli  (SgN  >öö+kuli !17_S	et	f	\N
178767	öökuli	öökuli =kuli  (SgG  >öö+kuli !17_S	et	f	\N
178768	öökuli	öökuli =kuli  (SgP  >öö+kuli !17_S	et	f	\N
178769	töd	### töd	et	f	\N
178778	inetrjueeritav	?inetrjueeritav =inetrjueeri  (PtsPrIps  >inetrjueerima !28_V	et	f	\N
178779	inetrjueeritav	?inetrjueeritav =inetrjueerita  (PtsPrPs  >inetrjueeritama !27_V	et	f	\N
178780	inetrjueeritav	?inetrjueeritav =inetrjueeritav  (SgN  >inetrjueeritav !02_A	et	f	\N
178790	õigusteadaja	?õigusteadaja =õigusteadaja  (SgN  >õigusteadaja !01_S	et	f	\N
178791	õigusteadaja	?õigusteadaja =õigusteadaja  (SgG  >õigusteadaja !01_S	et	f	\N
178792	õigusteadaja	?õigusteadaja =õigusteadaja  (SgG  >õigusteadajas !02_A	et	f	\N
178793	õigusteadaja	?õigusteadaja =daja  (SgN  >õigust+ea+daja !17_S	et	f	\N
178794	õigusteadaja	?õigusteadaja =daja  (SgG  >õigust+ea+daja !17_S	et	f	\N
178795	õigusteadaja	?õigusteadaja =daja  (SgP  >õigust+ea+daja !17_S	et	f	\N
178796	õigusteadaja	?õigusteadaja =adaja  (SgN  >õiguste+adaja !01_S	et	f	\N
178797	õigusteadaja	?õigusteadaja =adaja  (SgG  >õiguste+adaja !01_S	et	f	\N
178798	õigusteadaja	?õigusteadaja =adaja  (SgG  >õiguste+adajas !02_A	et	f	\N
178799	õigusteadaja	?õigusteadaja =eadaja  (SgN  >õigust+eadaja !01_S	et	f	\N
178800	õigusteadaja	?õigusteadaja =eadaja  (SgG  >õigust+eadaja !01_S	et	f	\N
178801	õigusteadaja	?õigusteadaja =eadaja  (SgG  >õigust+eadajas !02_A	et	f	\N
178802	õigusteadaja	?õigusteadaja =teadaja  (SgN  >õigus+teadaja !01_S	et	f	\N
178803	õigusteadaja	?õigusteadaja =teadaja  (SgG  >õigus+teadaja !01_S	et	f	\N
178804	õigusteadaja	?õigusteadaja =teadaja  (SgG  >õigus+teadajas !02_A	et	f	\N
178805	õigusteadaja	?õigusteadaja =steadaja  (SgN  >õigu+steadaja !01_S	et	f	\N
178806	õigusteadaja	?õigusteadaja =steadaja  (SgG  >õigu+steadaja !01_S	et	f	\N
178807	õigusteadaja	?õigusteadaja =steadaja  (SgG  >õigu+steadajas !02_A	et	f	\N
178815	linnavalitsuselt	linnavalitsuselt =use  (PlAbl  >linn+ava+lits+usk !22_S	et	f	\N
178816	linnavalitsuselt	linnavalitsuselt =valitsuse  (SgAbl  >linna+valitsus !11_S	et	f	\N
178823	asjadeste	?asjadeste =asjades  (PlG  >asjadene !12_A	et	f	\N
178824	asjadeste	?asjadeste =deste  (SgN  >asja+deste !06_S	et	f	\N
178825	asjadeste	?asjadeste =deste  (SgG  >asja+deste !06_S	et	f	\N
178826	asjadeste	?asjadeste =deste  (PlP  >asja+dest !22_S	et	f	\N
178835	toimitab	?toimitab =toimita  (IndPrSg3  >toimitama !27_V	et	f	\N
178838	rakverest	?rakverest =rakveres  (SgP  >rakverene !12_A	et	f	\N
178859	klienti	klienti =klienti  (SgP  >klient !22_S	et	f	\N
178860	klienti	klienti =klienti  (SgAdt  >klient !22_S	et	f	\N
178861	kompleksoskutega	?kompleksoskutega =pleksosku  (PlKom  >kom+pleksosku !01_S	et	f	\N
178870	minutsi	?minutsi =minutsi  (ID  >minutsi !41_D	et	f	\N
178871	minutsi	?minutsi =minutsi  (SgG  >minuts !02_S	et	f	\N
178872	minutsi	?minutsi =minutsi  (IndPrPs_  >minutsima !28_V	et	f	\N
178650	täidaksid	täidaksid =täida  (KndPrPl3  >täitma !34_V	et	f	\N
178657	sudavad	?sudavad =suda  (IndPrPl3  >sudama !27_V	et	f	\N
178658	sudavad	?sudavad =sudava  (PlN  >sudava !01_S	et	f	\N
178659	sudavad	?sudavad =sudava  (PlN  >sudav !02_A	et	f	\N
178660	juhing	?juhing =juhing  (SgN  >juhing !02_S	et	f	\N
178661	jua	?jua =jua  (SgN  >jua !26_S	et	f	\N
178662	jua	?jua =jua  (SgG  >jua !26_S	et	f	\N
178669	fuht	?fuht =fuht  (SgN  >fuht !22_S	et	f	\N
178670	toidukauplusesse	toidukauplusesse =kaupluse  (SgIll  >toidu+kauplus !11~09_S	et	f	\N
178671	toidukauplusesse	toidukauplusesse =kaupluses  (SgAdt  >toidu+kauplusene !12_A	et	f	\N
178672	toidukauplusesse	"toidu+kauplusene %kaupluse  )NE_aA  <toidu+kauplus ;09_S	et	f	\N
178673	toidukauplusesse	"toidu+kauplusene %kaupluse  )NE_aA  <toidu+kauplus ;11_S	et	f	\N
178686	teatsin	?teatsin =teat  (IndIpfSg1  >teatma !34_V	et	f	\N
178687	teatsin	?teatsin =teatsi  (IndPrSg1  >teatsima !28_V	et	f	\N
178688	teatsin	?teatsin =teatsin  (SgN  >teatsin !02_S	et	f	\N
178689	algklassideõpetajaks	?algklassideõpetajaks =algklassideõpetaja  (SgTr  >algklassideõpetaja !01_S	et	f	\N
178690	algklassideõpetajaks	?algklassideõpetajaks =algklassideõpetaja  (SgTr  >algklassideõpetajas !02_A	et	f	\N
178691	algklassideõpetajaks	?algklassideõpetajaks =deõpetaja  (SgTr  >alg+klassi+deõpetaja !01_S	et	f	\N
178692	algklassideõpetajaks	?algklassideõpetajaks =deõpetaja  (SgTr  >alg+klassi+deõpetajas !02_A	et	f	\N
178693	algklassideõpetajaks	?algklassideõpetajaks =klassideõpetaja  (SgTr  >alg+klassideõpetaja !01_S	et	f	\N
178694	algklassideõpetajaks	?algklassideõpetajaks =klassideõpetaja  (SgTr  >alg+klassideõpetajas !02_A	et	f	\N
178697	juriiks	?juriiks =jurii  (SgTr  >jurii !26_S	et	f	\N
178698	juriiks	?juriiks =juriiks  (SgN  >juriiks !22_S	et	f	\N
178716	valetaja	valetaja =valetaja  (SgN  >valetaja !01_S	et	f	\N
178717	valetaja	"valetaja %valeta  )JA_vS  <valetama ;27_V	et	f	\N
178718	valetaja	valetaja =valetaja  (SgG  >valetaja !01_S	et	f	\N
178742	tõõpi	?tõõpi =tõõpi  (ID  >tõõpi !41_D	et	f	\N
178743	tõõpi	?tõõpi =tõõpi  (SgP  >tõõp !22_S	et	f	\N
178744	tõõpi	?tõõpi =tõõpi  (SgAdt  >tõõp !22_S	et	f	\N
178770	tulgev	?tulgev =tulge  (PtsPrPs  >tulgema !27_V	et	f	\N
178771	tulgev	?tulgev =tulgev  (SgN  >tulgev !02_A	et	f	\N
178772	kohlta-järvel	kohlta-järvel =järve  (SgAd  >kohlta-järv !22_S	et	f	\N
178773	kohlta-järvel	kohlta-järvel =järve  (PlAd  >kohlta-järv !22_S	et	f	\N
178774	targ	?targ =targ  (SgN  >targ !22_S	et	f	\N
178775	linnavalitsuses	linnavalitsuses =use  (PlIn  >linn+ava+lits+usk !22_S	et	f	\N
178776	linnavalitsuses	linnavalitsuses =valitsuse  (SgIn  >linna+valitsus !11_S	et	f	\N
178781	rugevad	?rugevad =ruge  (IndPrPl3  >rugema !27_V	et	f	\N
178782	rugevad	?rugevad =rugeva  (PlN  >rugeva !01_S	et	f	\N
178783	rugevad	?rugevad =rugeva  (PlN  >rugev !02_A	et	f	\N
178818	äriitab	?äriitab =äriita  (IndPrSg3  >äriitama !27_V	et	f	\N
178820	kõljed	?kõljed =kõlje  (PlN  >kõlje !06_S	et	f	\N
178821	kõljed	?kõljed =kõlje  (IndPrSg2  >kõljema !27_V	et	f	\N
178827	müüjavad	?müüjavad =müüja  (IndPrPl3  >müüjama !29_V	et	f	\N
178828	müüjavad	?müüjavad =müüjava  (PlN  >müüjava !01_S	et	f	\N
178829	müüjavad	?müüjavad =müüjava  (PlN  >müüjav !02_A	et	f	\N
178833	toimitavad	toimitavad =toimitava  (PlN  >toimitav !02_A	et	f	\N
178834	toimitavad	"toimitav %toimi  )TAV_vAS  <toimima ;28_V	et	f	\N
178836	kaubatarnija	kaubatarnija =tarnija  (SgN  >kauba+tarnija !01_S	et	f	\N
178837	kaubatarnija	kaubatarnija =tarnija  (SgG  >kauba+tarnija !01_S	et	f	\N
178839	allahinlus	?allahinlus =allahinlu  (IndIpfSg3  >allahinluma !27_V	et	f	\N
178840	allahinlus	?allahinlus =allahinlus  (SgN  >allahinlus !11~09_S	et	f	\N
178841	allahinlus	?allahinlus =hinlu  (SgIn  >alla+hinlu !16_S	et	f	\N
178842	allahinlus	?allahinlus =hinlus  (SgN  >alla+hinlus !11~09_S	et	f	\N
178843	allahinlus	?allahinlus =ahinlu  (SgIn  >all+ahinlu !01_S	et	f	\N
178844	allahinlus	?allahinlus =ahinlus  (SgN  >all+ahinlus !11_S	et	f	\N
178845	töölada	?töölada =ada  (SgN  >tööl+ada !17_S	et	f	\N
178846	töölada	?töölada =ada  (SgG  >tööl+ada !17_S	et	f	\N
178847	töölada	?töölada =ada  (SgP  >tööl+ada !17_S	et	f	\N
178848	töölada	?töölada =lada  (SgN  >töö+lada !17_S	et	f	\N
178849	töölada	?töölada =lada  (SgG  >töö+lada !17_S	et	f	\N
178850	töölada	?töölada =lada  (SgP  >töö+lada !17_S	et	f	\N
178864	müüjan	?müüjan =müüja  (IndPrSg1  >müüjama !29_V	et	f	\N
178865	müüjan	?müüjan =müüjan  (SgN  >müüjan !02_S	et	f	\N
178884	kohusetundlikku	kohusetundlikku =tundlikku  (SgP  >kohuse+tundlik !25_A	et	f	\N
178885	kohusetundlikku	kohusetundlikku =tundlikku  (SgAdt  >kohuse+tundlik !25_A	et	f	\N
178917	lastemajast	lastemajast =maja  (SgEl  >laste+maja !17_S	et	f	\N
178918	lastemajast	lastemajast =majas  (SgP  >laste+majane !10_A	et	f	\N
178919	lastemajast	"laste+majane %maja  )NE_aA  <laste+maja ;17_S	et	f	\N
178952	võga	?võga =võga  (SgN  >võga !17_S	et	f	\N
178953	võga	?võga =võga  (SgG  >võga !17_S	et	f	\N
178954	võga	?võga =võga  (SgP  >võga !17_S	et	f	\N
178955	võga	?võga =võga  (IndPrPs_  >võgama !27_V	et	f	\N
178956	võga	?võga =võga  (ImpPrSg2  >võgama !27_V	et	f	\N
178971	passaz	### passaz	et	f	\N
178674	esmapäevast	esmapäevast =ast  (SgN  >esma+päev+ast !22_S	et	f	\N
178675	esmapäevast	esmapäevast =päeva  (SgEl  >esma+päev !22_S	et	f	\N
178676	esmapäevast	esmapäevast =päevas  (SgP  >esma+päevane !10_A	et	f	\N
178677	esmapäevast	"esma+päevane %päeva  )NE_aA  <esma+päev ;22_S	et	f	\N
178678	johvi	?johvi =johvi  (SgN  >johvi !16_S	et	f	\N
178679	johvi	?johvi =johvi  (SgG  >johvi !16_S	et	f	\N
178680	johvi	?johvi =johvi  (SgG  >johv !22_S	et	f	\N
178681	johvi	?johvi =johvi  (SgP  >johv !22_S	et	f	\N
178682	johvi	?johvi =johvi  (SgAdt  >johv !22_S	et	f	\N
178683	johvi	?johvi =johvi  (IndPrPs_  >johvima !28_V	et	f	\N
178684	johvi	?johvi =johvi  (ImpPrSg2  >johvima !28_V	et	f	\N
178696	12c	### 12c	et	f	\N
178701	tuevad	?tuevad =tueva  (PlN  >tueva !16_S	et	f	\N
178702	tuevad	?tuevad =tueva  (IndPrSg2  >tuevama !29_V	et	f	\N
178707	intervju	?intervju =intervju  (SgN  >intervju !01_S	et	f	\N
178708	intervju	?intervju =intervju  (SgG  >intervju !01_S	et	f	\N
178709	intervju	?intervju =intervju  (IndPrPs_  >intervjuma !27_V	et	f	\N
178710	intervju	?intervju =intervju  (ImpPrSg2  >intervjuma !27_V	et	f	\N
178711	järtku	?järtku =järtku  (SgN  >järtku !01_S	et	f	\N
178712	järtku	?järtku =järtku  (SgG  >järtku !01_S	et	f	\N
178713	järtku	?järtku =järtku  (IndPrPs_  >järtkuma !27_V	et	f	\N
178714	järtku	?järtku =järtku  (ImpPrSg2  >järtkuma !27_V	et	f	\N
178715	siiukene	?siiukene =siiukene  (SgN  >siiukene !12_S	et	f	\N
178719	tede	?tede =tede  (SgN  >tede !16_S	et	f	\N
178720	tede	?tede =tede  (SgG  >tede !16_S	et	f	\N
178721	tede	?tede =tede  (IndPrPs_  >tedema !27_V	et	f	\N
178722	tede	?tede =tede  (ImpPrSg2  >tedema !27_V	et	f	\N
178725	32c	### 32c	et	f	\N
178728	kuljed	?kuljed =kulje  (PlN  >kulje !06_S	et	f	\N
178729	kuljed	?kuljed =kulje  (IndPrSg2  >kuljema !27_V	et	f	\N
178750	õeldut	?õeldut =õeldu  (SgP  >õeldu !01_S	et	f	\N
178751	õeldut	?õeldut =õeldut  (SgN  >õeldut !02_S	et	f	\N
178763	usune	usune =usune  (SgN  >usune !10_A	et	f	\N
178764	usune	"usune %usu  )NE_aA  <usk ;22_S	et	f	\N
178784	intervjueritav	?intervjueritav =intervjueri  (PtsPrIps  >intervjuerima !28_V	et	f	\N
178785	intervjueritav	?intervjueritav =intervjuerita  (PtsPrPs  >intervjueritama !27_V	et	f	\N
178786	intervjueritav	?intervjueritav =intervjueritav  (SgN  >intervjueritav !02_A	et	f	\N
178808	linnavaalitsuses	?linnavaalitsuses =linnavaalitsuse  (SgIn  >linnavaalitsus !11~09_S	et	f	\N
178809	linnavaalitsuses	?linnavaalitsuses =alitsuse  (SgIn  >linn+ava+alitsus !11_S	et	f	\N
178810	linnavaalitsuses	?linnavaalitsuses =vaalitsuse  (SgIn  >linna+vaalitsus !11_S	et	f	\N
178812	linnavaalitsuses	?linnavaalitsuses =avaalitsuse  (SgIn  >linn+avaalitsus !11~09_S	et	f	\N
178830	saatelehti	saatelehti =lehti  (SgP  >saate+leht !22_S	et	f	\N
178831	saatelehti	saatelehti =lehti  (SgAdt  >saate+leht !22_S	et	f	\N
178832	saatelehti	saatelehti =lehti  (PlP  >saate+leht !22_S	et	f	\N
178851	neilega	?neilega =neile  (SgKom  >neile !06_S	et	f	\N
178857	markeerimine	markeerimine =markeerimine  (SgN  >markeerimine !12_S	et	f	\N
178858	markeerimine	"markeerimine %markeeri  )MINE_vS  <markeerima ;28_V	et	f	\N
178862	kolliktiiv	?kolliktiiv =kolliktiiv  (SgN  >kolliktiiv !22_S	et	f	\N
178889	juutustad	?juutustad =juutusta  (PlN  >juutusta !01_S	et	f	\N
178890	juutustad	?juutustad =juutusta  (IndPrSg2  >juutustama !27_V	et	f	\N
178891	rest	rest =re  (SgEl  >re !26_S	et	f	\N
178892	rest	rest =rest  (SgN  >rest !22_S	et	f	\N
178899	sompa	sompa =sompa  (IndPrPs_  >sompama !29_V	et	f	\N
178900	sompa	sompa =sompa  (ImpPrSg2  >sompama !29_V	et	f	\N
178920	leno	?leno =leno  (SgN  >leno !17~16_S	et	f	\N
178921	leno	?leno =leno  (SgG  >leno !17~16_S	et	f	\N
178922	leno	?leno =leno  (SgP  >leno !17_S	et	f	\N
178923	töotasin	?töotasin =töota  (IndIpfSg1  >töotama !27_V	et	f	\N
178924	töotasin	?töotasin =töotasin  (SgN  >töotasin !19_S	et	f	\N
178943	töopäev	?töopäev =töopäev  (SgN  >töopäev !22_S	et	f	\N
178968	käindsin	?käindsin =käindsi  (IndPrSg1  >käindsima !28_V	et	f	\N
178969	käindsin	?käindsin =käindsin  (SgN  >käindsin !02_S	et	f	\N
178970	kauplusses	?kauplusses =kauplusse  (SgIn  >kauplusne !02_A	et	f	\N
178972	kauplusses	?kauplusses =kauplusse  (PlIn  >kaupluss !22_S	et	f	\N
178973	kauplusses	?kauplusses =lusse  (SgIn  >kaup+lusne !02_A	et	f	\N
178974	kauplusses	?kauplusses =lusse  (SgIn  >kaup+lusse !06_S	et	f	\N
178975	kauplusses	?kauplusses =lusse  (PlIn  >kaup+luss !22_S	et	f	\N
178976	kauplusses	?kauplusses =lusses  (SgN  >kaup+lusses !09_S	et	f	\N
178977	mänguasjadiosakonnas	?mänguasjadiosakonnas =mänguasjadiosakonna  (SgIn  >mänguasjadiosakonna !16_S	et	f	\N
178978	mänguasjadiosakonnas	?mänguasjadiosakonnas =mänguasjadiosakonna  (SgIn  >mänguasjadiosakond !22_S	et	f	\N
178979	mänguasjadiosakonnas	?mänguasjadiosakonnas =diosakonna  (SgIn  >mängu+asja+diosakonna !16_S	et	f	\N
178980	mänguasjadiosakonnas	?mänguasjadiosakonnas =diosakonna  (SgIn  >mängu+asja+diosakond !22_S	et	f	\N
178981	mänguasjadiosakonnas	?mänguasjadiosakonnas =asjadiosakonna  (SgIn  >mängu+asjadiosakonna !16_S	et	f	\N
178982	mänguasjadiosakonnas	?mänguasjadiosakonnas =asjadiosakonna  (SgIn  >mängu+asjadiosakond !22_S	et	f	\N
178986	kauplussses	?kauplussses =kauplussse  (SgIn  >kauplussne !02_A	et	f	\N
178731	ettevõtmini	?ettevõtmini =ettevõtmini  (ID  >ettevõtmini !41_D	et	f	\N
178732	ettevõtmini	?ettevõtmini =ettevõtmini  (SgG  >ettevõtmin !02_S	et	f	\N
178733	ettevõtmini	?ettevõtmini =võtmi  (SgTer  >ette+võtmi !16_S	et	f	\N
178734	ettevõtmini	?ettevõtmini =võtmi  (SgTer  >ette+võtm !22_S	et	f	\N
178735	ettevõtmini	?ettevõtmini =võtmini  (SgG  >ette+võtmin !02_S	et	f	\N
178752	elukutsell	?elukutsell =elukutsell  (SgN  >elukutsell !22_S	et	f	\N
178753	elukutsell	?elukutsell =kutsell  (SgN  >elu+kutsell !22_S	et	f	\N
178760	pankis	?pankis =panki  (IndIpfSg3  >pankima !28_V	et	f	\N
178761	pankis	?pankis =pankis  (ID  >pankis !41_DA	et	f	\N
178777	elistab	?elistab =elista  (IndPrSg3  >elistama !27_V	et	f	\N
178787	hoidja	hoidja =hoidja  (SgN  >hoidja !01_S	et	f	\N
178788	hoidja	"hoidja %hoid  )JA_vS  <hoidma ;34_V	et	f	\N
178789	hoidja	hoidja =hoidja  (SgG  >hoidja !01_S	et	f	\N
178811	kohtuses	kohtuses =kohtuse  (SgIn  >kohtune !12~10_A	et	f	\N
178813	kohtuses	"kohtune %kohtu  )NE_aA  <kohus ;05_S	et	f	\N
178814	kohtuses	kohtuses =use  (PlIn  >koht+usk !22_S	et	f	\N
178855	kohustused	kohustused =kohustuse  (PlN  >kohustus !11_S	et	f	\N
178856	kohustused	"kohustus %kohusta  )US_vS  <kohustama ;27_V	et	f	\N
178863	kaluun	?kaluun =kaluun  (SgN  >kaluun !22_S	et	f	\N
178867	mitta	?mitta =mitta  (ID  >mitta !41_D	et	f	\N
178868	mitta	?mitta =mitta  (IndPrPs_  >mittama !29_V	et	f	\N
178869	mitta	?mitta =mitta  (ImpPrSg2  >mittama !29_V	et	f	\N
178874	akberi	?akberi =akberi  (SgN  >akberi !01_S	et	f	\N
178875	akberi	?akberi =akberi  (SgG  >akberi !01_S	et	f	\N
178876	akberi	?akberi =akberi  (SgG  >akber !02_S	et	f	\N
178886	arenevat	arenevat =arene  (KvtPrPs  >arenema !27_V	et	f	\N
178887	arenevat	arenevat =areneva  (SgP  >arenev !02_A	et	f	\N
178888	arenevat	"arenev %arene  )V_vA  <arenema ;27_V	et	f	\N
178894	vorst-liha	vorst-liha =liha  (SgN  >vorst-liha !17_S	et	f	\N
178895	vorst-liha	vorst-liha =liha  (SgG  >vorst-liha !17_S	et	f	\N
178896	vorst-liha	vorst-liha =liha  (SgP  >vorst-liha !17_S	et	f	\N
178898	20ºº	### 20ºº	et	f	\N
178905	valerija	?valerija =valerija  (SgN  >valerija !01_S	et	f	\N
178906	valerija	?valerija =valerija  (SgG  >valerija !01_S	et	f	\N
178907	valerija	?valerija =valerija  (SgG  >valerijas !02_A	et	f	\N
178908	valerija	?valerija =rija  (SgN  >vale+rija !17_S	et	f	\N
178909	valerija	?valerija =rija  (SgG  >vale+rija !17_S	et	f	\N
178910	valerija	?valerija =rija  (SgP  >vale+rija !17_S	et	f	\N
178925	ijuli	?ijuli =ijuli  (ID  >ijuli !41_D	et	f	\N
178926	ijuli	?ijuli =ijuli  (SgG  >ijul !02_S	et	f	\N
178938	sigaeti	?sigaeti =sigaeti  (ID  >sigaeti !41_D	et	f	\N
178939	sigaeti	?sigaeti =sigaeti  (SgP  >sigaet !22_S	et	f	\N
178940	sigaeti	?sigaeti =sigaeti  (SgAdt  >sigaet !22_S	et	f	\N
178944	lena	?lena =lena  (SgN  >lena !17_S	et	f	\N
178945	lena	?lena =lena  (SgG  >lena !17_S	et	f	\N
178946	lena	?lena =lena  (SgP  >lena !17_S	et	f	\N
178947	lena	?lena =lena  (IndPrPs_  >lenama !27_V	et	f	\N
178948	lena	?lena =lena  (ImpPrSg2  >lenama !27_V	et	f	\N
178957	nagemmiseni	?nagemmiseni =nagemmise  (SgTer  >nagemmine !12_A	et	f	\N
178958	nagemmiseni	?nagemmiseni =nagemmiseni  (SgG  >nagemmisen !19_S	et	f	\N
178959	nagemmiseni	?nagemmiseni =nagemmiseni  (SgP  >nagemmisen !19_S	et	f	\N
178960	nagemmiseni	?nagemmiseni =nagemmiseni  (SgAdt  >nagemmisen !19_S	et	f	\N
178961	gorispolkoomi	?gorispolkoomi =gorispolkoomi  (SgN  >gorispolkoomi !16_S	et	f	\N
178962	gorispolkoomi	?gorispolkoomi =gorispolkoomi  (SgG  >gorispolkoomi !16_S	et	f	\N
178963	gorispolkoomi	?gorispolkoomi =gorispolkoomi  (SgG  >gorispolkoom !22_S	et	f	\N
178964	gorispolkoomi	?gorispolkoomi =gorispolkoomi  (SgP  >gorispolkoom !22_S	et	f	\N
178965	gorispolkoomi	?gorispolkoomi =gorispolkoomi  (SgAdt  >gorispolkoom !22_S	et	f	\N
178966	gorispolkoomi	?gorispolkoomi =gorispolkoomi  (IndPrPs_  >gorispolkoomima !28_V	et	f	\N
178967	gorispolkoomi	?gorispolkoomi =gorispolkoomi  (ImpPrSg2  >gorispolkoomima !28_V	et	f	\N
179007	9ºº-18ºº	### 9ºº-18ºº	et	f	\N
179008	9ºº-15ºº	### 9ºº-15ºº	et	f	\N
179009	külmad	külmad =külma  (PlN  >külm !22_AS	et	f	\N
179010	külmad	külmad =külma  (IndPrSg2  >külmama !29_V	et	f	\N
179026	deodororanti	?deodororanti =deodororanti  (SgP  >deodororant !22_S	et	f	\N
179027	deodororanti	?deodororanti =deodororanti  (SgAdt  >deodororant !22_S	et	f	\N
179047	volta	?volta =volta  (SgN  >volta !16_S	et	f	\N
179048	volta	?volta =volta  (SgG  >volta !16_S	et	f	\N
179049	volta	?volta =volta  (IndPrPs_  >voltama !29_V	et	f	\N
179050	volta	?volta =volta  (ImpPrSg2  >voltama !29_V	et	f	\N
179051	osakondi	osakondi =osakondi  (SgP  >osakond !22_S	et	f	\N
179052	osakondi	osakondi =osakondi  (SgAdt  >osakond !22_S	et	f	\N
179053	osakondi	osakondi =osakondi  (PlP  >osakond !22_S	et	f	\N
179054	osakondi	osakondi =kondi  (SgG  >osa+kont !22_S	et	f	\N
179057	kuueda	?kuueda =eda  (SgN  >kuu+eda !17_S	et	f	\N
179058	kuueda	?kuueda =eda  (SgG  >kuu+eda !17_S	et	f	\N
179059	kuueda	?kuueda =eda  (SgP  >kuu+eda !17_S	et	f	\N
179062	ijuulis	?ijuulis =ijuuli  (SgIn  >ijuuli !16_S	et	f	\N
179063	ijuulis	?ijuulis =ijuuli  (SgIn  >ijuul !22_S	et	f	\N
178873	minutsi	?minutsi =minutsi  (ImpPrSg2  >minutsima !28_V	et	f	\N
178897	8ºº-	### 8ºº-	et	f	\N
178927	vaina	?vaina =vaina  (SgN  >vaina !16_S	et	f	\N
178928	vaina	?vaina =vaina  (SgG  >vaina !16_S	et	f	\N
178929	vaina	?vaina =vaina  (IndPrPs_  >vainama !29_V	et	f	\N
178930	vaina	?vaina =vaina  (ImpPrSg2  >vainama !29_V	et	f	\N
178931	kopfekti	?kopfekti =kopfekti  (SgN  >kopfekti !01_S	et	f	\N
178932	kopfekti	?kopfekti =kopfekti  (SgG  >kopfekti !01_S	et	f	\N
178933	kopfekti	?kopfekti =kopfekti  (SgG  >kopfekt !22_S	et	f	\N
178934	kopfekti	?kopfekti =kopfekti  (SgP  >kopfekt !22_S	et	f	\N
178935	kopfekti	?kopfekti =kopfekti  (SgAdt  >kopfekt !22_S	et	f	\N
178936	kopfekti	?kopfekti =kopfekti  (IndPrPs_  >kopfektima !28_V	et	f	\N
178937	kopfekti	?kopfekti =kopfekti  (ImpPrSg2  >kopfektima !28_V	et	f	\N
178950	ehitusabc	?ehitusabc =ehitusabc  (SgN  >ehitusabc !22_S	et	f	\N
178951	ehitusabc	?ehitusabc =abc  (SgN  >ehitus+abc !22_S	et	f	\N
178992	boksi	boksi =boksi  (SgG  >boks !22_S	et	f	\N
178993	boksi	boksi =boksi  (SgP  >boks !22_S	et	f	\N
178994	boksi	boksi =boksi  (SgAdt  >boks !22_S	et	f	\N
179022	maionez	### maionez	et	f	\N
179036	inumest	?inumest =inumes  (SgP  >inumene !12_A	et	f	\N
179041	esimes	### esimes	et	f	\N
179055	kümmnendas	?kümmnendas =kümmnenda  (SgIn  >kümmnenda !01_S	et	f	\N
179056	kümmnendas	?kümmnendas =kümmnenda  (IndIpfSg3  >kümmnendama !27_V	et	f	\N
179060	tundasin	?tundasin =tunda  (IndIpfSg1  >tundama !29_V	et	f	\N
179061	tundasin	?tundasin =tundasin  (SgN  >tundasin !19_S	et	f	\N
179072	vanakiirikas	?vanakiirikas =vanakiirika  (SgIn  >vanakiirika !01_S	et	f	\N
179073	vanakiirikas	?vanakiirikas =vanakiirika  (SgIn  >vanakiirikas !02_A	et	f	\N
179074	vanakiirikas	?vanakiirikas =vanakiirikas  (SgN  >vanakiirikas !02_A	et	f	\N
179075	vanakiirikas	?vanakiirikas =ika  (SgIn  >vana+kiir+ika !16_S	et	f	\N
179076	vanakiirikas	?vanakiirikas =ikas  (SgN  >vana+kiir+ikas !07_S	et	f	\N
179077	vanakiirikas	?vanakiirikas =kiirika  (SgIn  >vana+kiirika !01_S	et	f	\N
179078	vanakiirikas	?vanakiirikas =kiirika  (SgIn  >vana+kiirikas !02_S	et	f	\N
179079	vanakiirikas	?vanakiirikas =kiirikas  (SgN  >vana+kiirikas !02_S	et	f	\N
179089	müdavad	?müdavad =müda  (IndPrPl3  >müdama !27_V	et	f	\N
179090	müdavad	?müdavad =müdava  (PlN  >müdava !01_S	et	f	\N
179091	müdavad	?müdavad =müdava  (PlN  >müdav !02_A	et	f	\N
179098	mantid	### mantid	et	f	\N
179106	korussel	?korussel =korusse  (SgAd  >korusne !02_A	et	f	\N
179107	korussel	?korussel =korusse  (PlAd  >koruss !22_S	et	f	\N
179108	korussel	?korussel =korussel  (SgN  >korussel !02_S	et	f	\N
179115	samutti	?samutti =samutti  (SgN  >samutti !01_S	et	f	\N
179116	samutti	?samutti =samutti  (SgG  >samutti !01_S	et	f	\N
179117	samutti	?samutti =samutti  (SgP  >samutt !22_S	et	f	\N
179118	samutti	?samutti =samutti  (SgAdt  >samutt !22_S	et	f	\N
179123	teadnu	teadnu =teadnu  (SgN  >teadnu !01_S	et	f	\N
179124	teadnu	"teadnu %tead  )NU_vS  <teadma ;34_V	et	f	\N
179125	teadnu	teadnu =teadnu  (SgG  >teadnu !01_S	et	f	\N
179127	koolivaheag	?koolivaheag =koolivaheag  (SgN  >koolivaheag !22_S	et	f	\N
179128	koolivaheag	?koolivaheag =vaheag  (SgN  >kooli+vaheag !22_S	et	f	\N
179129	koolivaheag	?koolivaheag =ivaheag  (SgN  >kool+ivaheag !22_S	et	f	\N
179135	vigud	?vigud =vigu  (PlN  >vigu !17_S	et	f	\N
179136	vigud	?vigud =vigu  (IndPrSg2  >viguma !27_V	et	f	\N
179137	eestkeelt	eestkeelt =kee  (SgAbl  >eest+kesi !15_S	et	f	\N
179138	eestkeelt	eestkeelt =kee  (SgAbl  >eest+kee !26_S	et	f	\N
179139	eestkeelt	eestkeelt =keel  (SgP  >eest+keel !13_S	et	f	\N
179144	suhleme	?suhleme =suhle  (IndPrPl1  >suhlema !30_V	et	f	\N
179168	venale	?venale =vena  (SgAll  >vena !17_S	et	f	\N
179169	venale	?venale =venale  (IndPrPs_  >venalema !27_V	et	f	\N
179170	venale	?venale =venale  (ImpPrSg2  >venalema !27_V	et	f	\N
179179	ööel	?ööel =ööel  (SgN  >ööel !02_S	et	f	\N
179206	õhutl	?õhutl =õhutl  (SgN  >õhutl !22_S	et	f	\N
179232	abikassa	abikassa =kassa  (SgN  >abi+kassa !16_S	et	f	\N
179233	abikassa	abikassa =kassa  (SgG  >abi+kassa !16_S	et	f	\N
179238	kaheksatist	?kaheksatist =kaheksati  (SgEl  >kaheksatt !22_S	et	f	\N
179239	kaheksatist	?kaheksatist =kaheksatis  (SgP  >kaheksatis !09_S	et	f	\N
179240	kaheksatist	?kaheksatist =kaheksatist  (SgN  >kaheksatist !22_S	et	f	\N
179241	kaheksatist	?kaheksatist =tist  (SgN  >kaheksa+tist !22_S	et	f	\N
179242	kaheksatist	?kaheksatist =ksati  (SgEl  >kahe+ksati !16_S	et	f	\N
179243	kaheksatist	?kaheksatist =ksati  (SgEl  >kahe+ksatt !22_S	et	f	\N
179244	kaheksatist	?kaheksatist =ksatis  (SgP  >kahe+ksatis !09_S	et	f	\N
179245	kaheksatist	?kaheksatist =ksatist  (SgN  >kahe+ksatist !22_S	et	f	\N
179251	kõrgemasse	kõrgemasse =kõrgema  (SgIll  >kõrgem !02_A	et	f	\N
179252	kõrgemasse	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
179253	kõrgemasse	kõrgemasse =masse  (PlP  >kõrge+mass !22_S	et	f	\N
179254	kõrgemasse	kõrgemasse =ema  (SgIll  >kõrg+ema !17_S	et	f	\N
179275	sõnaraamatuga	sõnaraamatuga =atu  (SgKom  >sõna+raam+att !22_S	et	f	\N
179276	sõnaraamatuga	sõnaraamatuga =raamatu  (SgKom  >sõna+raamat !02_S	et	f	\N
179318	sõnastlik	?sõnastlik =sõnastlik  (SgN  >sõnastlik !25_A	et	f	\N
178877	zauri	?zauri =zauri  (SgN  >zauri !16_S	et	f	\N
178878	zauri	?zauri =zauri  (SgG  >zauri !16_S	et	f	\N
178879	zauri	?zauri =zauri  (SgG  >zaur !22_S	et	f	\N
178880	zauri	?zauri =zauri  (SgP  >zaur !22_S	et	f	\N
178881	zauri	?zauri =zauri  (SgAdt  >zaur !22_S	et	f	\N
178882	zauri	?zauri =zauri  (IndPrPs_  >zaurima !28_V	et	f	\N
178883	zauri	?zauri =zauri  (ImpPrSg2  >zaurima !28_V	et	f	\N
178893	190m²	### 190m²	et	f	\N
178901	kaevanduses	kaevanduses =kaevanduse  (SgIn  >kaevandus !11_S	et	f	\N
178902	kaevanduses	"kaevandus %kaevanda  )US_vS  <kaevandama ;27_V	et	f	\N
178903	kaevurist	kaevurist =kaevuri  (SgEl  >kaevur !02_S	et	f	\N
178904	kaevurist	kaevurist =rist  (SgN  >kaevu+rist !22_S	et	f	\N
178911	valerija	?valerija =valerija  (SgN  >valerija !01_S	et	f	\N
178912	valerija	?valerija =valerija  (SgG  >valerija !01_S	et	f	\N
178913	valerija	?valerija =valerija  (SgG  >valerijas !02_A	et	f	\N
178914	valerija	?valerija =rija  (SgN  >vale+rija !17_S	et	f	\N
178915	valerija	?valerija =rija  (SgG  >vale+rija !17_S	et	f	\N
178916	valerija	?valerija =rija  (SgP  >vale+rija !17_S	et	f	\N
178941	kollektiv	?kollektiv =kollekti  (PtsPrPs  >kollektima !28_V	et	f	\N
178942	kollektiv	?kollektiv =kollektiv  (SgN  >kollektiv !02_A	et	f	\N
178949	pooes	?pooes =pooes  (SgN  >pooes !02_S	et	f	\N
178995	riiulilaudis	riiulilaudis =laudi  (SgIn  >riiuli+laudi !01_S	et	f	\N
178996	riiulilaudis	riiulilaudis =laudi  (SgIn  >riiuli+laut !22_S	et	f	\N
178997	riiulilaudis	riiulilaudis =laudi  (PlIn  >riiuli+laut !22_S	et	f	\N
178998	riiulilaudis	riiulilaudis =laudis  (SgN  >riiuli+laudis !09_S	et	f	\N
179011	mitmendased	?mitmendased =mitmendase  (PlN  >mitmendane !12_A	et	f	\N
179020	kohvikat	?kohvikat =kohvika  (SgP  >kohvika !01_S	et	f	\N
179021	kohvikat	?kohvikat =kohvika  (SgP  >kohvikas !02_S	et	f	\N
179024	mineral	?mineral =minera  (SgAd  >minera !01_S	et	f	\N
179025	mineral	?mineral =mineral  (SgN  >mineral !19_S	et	f	\N
179028	hombarasta	?hombarasta =hombarasta  (SgN  >hombarasta !16_S	et	f	\N
179029	hombarasta	?hombarasta =hombarasta  (SgG  >hombarasta !16_S	et	f	\N
179030	hombarasta	?hombarasta =hombarasta  (IndPrPs_  >hombarastama !27_V	et	f	\N
179031	hombarasta	?hombarasta =hombarasta  (ImpPrSg2  >hombarastama !27_V	et	f	\N
179037	tötasid	?tötasid =töta  (PlP  >töta !16_S	et	f	\N
179038	tötasid	?tötasid =töta  (IndIpfSg2  >tötama !27_V	et	f	\N
179039	tötasid	?tötasid =töta  (IndIpfPl3  >tötama !27_V	et	f	\N
179067	musi	musi =musi  (SgN  >musi !17_S	et	f	\N
179068	musi	musi =musi  (SgG  >musi !17_S	et	f	\N
179069	musi	musi =musi  (SgP  >musi !17_S	et	f	\N
179092	erenevat	erenevat =erene  (KvtPrPs  >erenema !27_V	et	f	\N
179094	erenevat	erenevat =ereneva  (SgP  >erenev !02_A	et	f	\N
179095	erenevat	"erenev %erene  )V_vA  <erenema ;27_V	et	f	\N
179102	blusid	?blusid =blusi  (PlN  >blusi !17_S	et	f	\N
179103	blusid	?blusid =blusi  (IndPrSg2  >blusima !27_V	et	f	\N
179104	kominesonid	?kominesonid =kominesoni  (PlN  >komineson !19_S	et	f	\N
179105	kominesonid	?kominesonid =inesoni  (PlN  >kom+ineson !19_S	et	f	\N
179109	autopeatus	autopeatus =peatu  (SgIn  >auto+peatu !01_A	et	f	\N
179110	autopeatus	"auto+peatu %pea  )TU2_kA  <auto+pea ;26_S	et	f	\N
179111	autopeatus	autopeatus =peatus  (SgN  >auto+peatus !11~09_S	et	f	\N
179112	autopeatus	"auto+peatus %pea  )TUS2_aS  <auto+pea ;26_S	et	f	\N
179120	10ºº-19ºº	### 10ºº-19ºº	et	f	\N
179126	olik	?olik =olik  (SgN  >olik !02_S	et	f	\N
179158	dimitri	?dimitri =dimitri  (SgN  >dimitri !01_S	et	f	\N
179159	dimitri	?dimitri =dimitri  (SgG  >dimitri !01_S	et	f	\N
179160	dimitri	?dimitri =dimitri  (SgG  >dimitter !02_S	et	f	\N
179161	dimitri	?dimitri =dimitri  (SgG  >dimiter !19_S	et	f	\N
179162	dimitri	?dimitri =dimitri  (SgP  >dimiter !19_S	et	f	\N
179163	dimitri	?dimitri =dimitri  (SgAdt  >dimiter !19_S	et	f	\N
179166	asatane	?asatane =asatane  (SgN  >asatane !12_A	et	f	\N
179167	asatane	?asatane =asatane  (PlP  >asatan !19_S	et	f	\N
179194	kursusule	?kursusule =kursusu  (SgAll  >kursusu !01_S	et	f	\N
179195	kursusule	?kursusule =kursusule  (PlP  >kursusul !19_S	et	f	\N
179196	kursusule	?kursusule =ule  (SgN  >kursus+ule !16_S	et	f	\N
179197	kursusule	?kursusule =ule  (SgG  >kursus+ule !16_S	et	f	\N
179198	idlas	?idlas =idla  (SgIn  >idla !16_S	et	f	\N
179199	idlas	?idlas =idla  (IndIpfSg3  >idlama !27_V	et	f	\N
179200	idlas	?idlas =idlas  (SgN  >idlas !07_S	et	f	\N
179221	valgeneskeskkoolis	?valgeneskeskkoolis =valgeneskeskkooli  (SgIn  >valgeneskeskkooli !16_S	et	f	\N
179222	valgeneskeskkoolis	?valgeneskeskkoolis =valgeneskeskkooli  (SgIn  >valgeneskeskkool !22_S	et	f	\N
179223	valgeneskeskkoolis	?valgeneskeskkoolis =valgeneskeskkooli  (IndIpfSg3  >valgeneskeskkoolima !28_V	et	f	\N
179224	valgeneskeskkoolis	?valgeneskeskkoolis =valgeneskeskkoolis  (SgN  >valgeneskeskkoolis !09_S	et	f	\N
179225	valgeneskeskkoolis	?valgeneskeskkoolis =neskeskkooli  (SgIn  >valge+neskeskkooli !16_S	et	f	\N
179226	valgeneskeskkoolis	?valgeneskeskkoolis =neskeskkooli  (SgIn  >valge+neskeskkool !22_S	et	f	\N
179227	valgeneskeskkoolis	?valgeneskeskkoolis =neskeskkoolis  (SgN  >valge+neskeskkoolis !09_S	et	f	\N
179228	valgeneskeskkoolis	?valgeneskeskkoolis =eneskeskkooli  (SgIn  >valg+eneskeskkooli !16_S	et	f	\N
178983	ostasid	?ostasid =osta  (PlP  >osta !16_S	et	f	\N
178984	ostasid	?ostasid =osta  (IndIpfSg2  >ostama !29_V	et	f	\N
178985	ostasid	?ostasid =osta  (IndIpfPl3  >ostama !29_V	et	f	\N
178999	räõõmsalt	?räõõmsalt =räõõmsa  (SgAbl  >räõõmsa !01_S	et	f	\N
179001	räõõmsalt	?räõõmsalt =räõõmsalt  (ID  >räõõmsalt !41_D	et	f	\N
179032	küme	?küme =küme  (SgN  >küme !16_S	et	f	\N
179033	küme	?küme =küme  (SgG  >küme !16_S	et	f	\N
179034	küme	?küme =küme  (IndPrPs_  >kümema !27_V	et	f	\N
179035	küme	?küme =küme  (ImpPrSg2  >kümema !27_V	et	f	\N
179043	kursussele	?kursussele =kursusse  (SgAll  >kursusne !02_A	et	f	\N
179044	kursussele	?kursussele =kursusse  (PlAll  >kursuss !22_S	et	f	\N
179045	kursussele	?kursussele =sele  (SgN  >kursus+sele !16_S	et	f	\N
179046	kursussele	?kursussele =sele  (SgG  >kursus+sele !16_S	et	f	\N
179081	21ºº	### 21ºº	et	f	\N
179096	seliku	?seliku =seliku  (SgN  >seliku !01_S	et	f	\N
179097	seliku	?seliku =seliku  (SgG  >seliku !01_S	et	f	\N
179099	seliku	?seliku =seliku  (SgG  >selik !02_S	et	f	\N
179100	seliku	?seliku =seliku  (IndPrPs_  >selikuma !27_V	et	f	\N
179101	seliku	?seliku =seliku  (ImpPrSg2  >selikuma !27_V	et	f	\N
179121	10ºº-16ºº	### 10ºº-16ºº	et	f	\N
179140	nengega	### nengega	et	f	\N
179157	limonaditehas	?limonaditehas =limonaditeha  (SgIn  >limonaditeha !16_S	et	f	\N
179164	käevad	?käevad =käeva  (PlN  >käeva !16_S	et	f	\N
179165	käevad	?käevad =käeva  (IndPrSg2  >käevama !29_V	et	f	\N
179171	kaevanuse	?kaevanuse =kaevanuse  (SgG  >kaevanus !11_S	et	f	\N
179176	lasteada	?lasteada =ada  (SgN  >laste+ada !17_S	et	f	\N
179177	lasteada	?lasteada =ada  (SgG  >laste+ada !17_S	et	f	\N
179178	lasteada	?lasteada =ada  (SgP  >laste+ada !17_S	et	f	\N
179207	raamt	?raamt =raamt  (SgN  >raamt !22_S	et	f	\N
179219	kazahstanis	?kazahstanis =kazahstani  (SgIn  >kazahstan !02_S	et	f	\N
179220	kazahstanis	?kazahstanis =kazahstanis  (SgN  >kazahstanis !09_S	et	f	\N
179255	infotehnoloog	infotehnoloog =loog  (SgN  >info+tehno+loog !22_S	et	f	\N
179256	infotehnoloog	infotehnoloog =tehnoloog  (SgN  >info+tehnoloog !22_S	et	f	\N
179257	lügeda	?lügeda =lüge  (Inf  >lügema !27_V	et	f	\N
179273	võttan	?võttan =võtta  (IndPrSg1  >võttama !29_V	et	f	\N
179274	võttan	?võttan =võttan  (SgN  >võttan !02_S	et	f	\N
179286	lõusen	?lõusen =lõuse  (IndPrSg1  >lõusema !28_V	et	f	\N
179287	lõusen	?lõusen =lõusen  (SgN  >lõusen !02_S	et	f	\N
179289	honniku	?honniku =honniku  (SgN  >honniku !01_S	et	f	\N
179290	honniku	?honniku =honniku  (SgG  >honniku !01_S	et	f	\N
179291	honniku	?honniku =honniku  (SgG  >honnik !02_S	et	f	\N
179292	honniku	?honniku =honniku  (IndPrPs_  >honnikuma !27_V	et	f	\N
179294	honniku	?honniku =honniku  (ImpPrSg2  >honnikuma !27_V	et	f	\N
179297	tööale	tööale =ale  (SgN  >töö+ale !16_S	et	f	\N
179298	tööale	tööale =ale  (SgG  >töö+ale !16_S	et	f	\N
179302	mägama	?mägama =mäga  (Sup  >mägama !27_V	et	f	\N
179303	mägama	?mägama =mägama  (SgG  >mägam !02_A	et	f	\N
179338	hinnab	?hinnab =hinna  (IndPrSg3  >hinnama !29_V	et	f	\N
179354	kartan	?kartan =karta  (IndPrSg1  >kartama !29_V	et	f	\N
179355	kartan	?kartan =kartan  (SgN  >kartan !02_S	et	f	\N
179371	leidad	?leidad =leida  (PlN  >leida !16_S	et	f	\N
179372	leidad	?leidad =leida  (IndPrSg2  >leidama !29_V	et	f	\N
179382	plaju	?plaju =plaju  (SgN  >plaju !17_S	et	f	\N
179383	plaju	?plaju =plaju  (SgG  >plaju !17_S	et	f	\N
179384	plaju	?plaju =plaju  (SgP  >plaju !17_S	et	f	\N
179385	plaju	?plaju =plaju  (IndPrPs_  >plajuma !27_V	et	f	\N
179386	plaju	?plaju =plaju  (ImpPrSg2  >plajuma !27_V	et	f	\N
179389	võõtkeelte	### võõtkeelte	et	f	\N
179420	allikiri	?allikiri =allikiri  (SgG  >allikir !19_S	et	f	\N
179421	allikiri	?allikiri =allikiri  (SgP  >allikir !19_S	et	f	\N
179422	allikiri	?allikiri =allikiri  (SgAdt  >allikir !19_S	et	f	\N
179423	allikiri	?allikiri =iri  (SgN  >allik+iri !17_S	et	f	\N
179424	allikiri	?allikiri =iri  (SgG  >allik+iri !17_S	et	f	\N
179425	allikiri	?allikiri =iri  (SgP  >allik+iri !17_S	et	f	\N
179426	allikiri	?allikiri =ikiri  (SgN  >all+ikiri !01_S	et	f	\N
179427	allikiri	?allikiri =ikiri  (SgG  >all+ikiri !01_S	et	f	\N
179428	allikiri	?allikiri =ikiri  (SgG  >all+ikir !02_S	et	f	\N
179435	bussifirma	bussifirma =firma  (SgN  >bussi+firma !16_S	et	f	\N
179436	bussifirma	bussifirma =firma  (SgG  >bussi+firma !16_S	et	f	\N
179437	sõitvad	sõitvad =sõitva  (PlN  >sõitev !02_A	et	f	\N
179438	sõitvad	"sõitev %sõit  )V_vA  <sõitma ;34_V	et	f	\N
179456	õpilaseda	?õpilaseda =eda  (SgN  >õpilas+eda !17_S	et	f	\N
179457	õpilaseda	?õpilaseda =eda  (SgG  >õpilas+eda !17_S	et	f	\N
179458	õpilaseda	?õpilaseda =eda  (SgP  >õpilas+eda !17_S	et	f	\N
179464	kirjutae	?kirjutae =kirjutae  (SgN  >kirjutae !26_S	et	f	\N
179465	kirjutae	?kirjutae =kirjutae  (SgG  >kirjutae !26_S	et	f	\N
179478	joome	joome =joo  (IndPrPl1  >jooma !38_V	et	f	\N
179479	joome	joome =joome  (SgG  >joom !22_S	et	f	\N
179480	joome	joome =joome  (SgP  >joom !22_S	et	f	\N
179482	joome	joome =joome  (SgAdt  >joom !22_S	et	f	\N
178987	kauplussses	?kauplussses =kauplussse  (PlIn  >kauplusss !22_S	et	f	\N
178988	kauplussses	?kauplussses =lussse  (SgIn  >kaup+lussne !02_A	et	f	\N
178989	kauplussses	?kauplussses =lussse  (SgIn  >kaup+lussse !06_S	et	f	\N
178990	kauplussses	?kauplussses =lussse  (PlIn  >kaup+lusss !22_S	et	f	\N
178991	kauplussses	?kauplussses =lussses  (SgN  >kaup+lussses !09_S	et	f	\N
179000	lapseid	?lapseid =lapse  (PlP  >lapne !02_A	et	f	\N
179002	lapseid	?lapseid =lapse  (PlP  >lapse !06_S	et	f	\N
179003	lapseid	?lapseid =lapsei  (PlN  >lapsei !26_S	et	f	\N
179004	lapseid	?lapseid =lapsei  (SgP  >lapsei !26_S	et	f	\N
179005	lapseid	?lapseid =lapseid  (SgN  >lapseid !22_S	et	f	\N
179006	lapseid	?lapseid =eid  (SgN  >laps+eid !22_S	et	f	\N
179012	toiduainedkohvi	?toiduainedkohvi =toiduainedkohvi  (SgG  >toiduainedkohv !22_S	et	f	\N
179013	toiduainedkohvi	?toiduainedkohvi =toiduainedkohvi  (SgP  >toiduainedkohv !22_S	et	f	\N
179014	toiduainedkohvi	?toiduainedkohvi =toiduainedkohvi  (SgAdt  >toiduainedkohv !22_S	et	f	\N
179015	toiduainedkohvi	?toiduainedkohvi =toiduainedkohvi  (IndPrPs_  >toiduainedkohvima !28_V	et	f	\N
179016	toiduainedkohvi	?toiduainedkohvi =toiduainedkohvi  (ImpPrSg2  >toiduainedkohvima !28_V	et	f	\N
179017	toiduainedkohvi	?toiduainedkohvi =ainedkohvi  (SgG  >toidu+ainedkohv !22_S	et	f	\N
179018	toiduainedkohvi	?toiduainedkohvi =ainedkohvi  (SgP  >toidu+ainedkohv !22_S	et	f	\N
179019	toiduainedkohvi	?toiduainedkohvi =ainedkohvi  (SgAdt  >toidu+ainedkohv !22_S	et	f	\N
179023	limonad	### limonad	et	f	\N
179040	sõpralik	?sõpralik =sõpralik  (SgN  >sõpralik !25_A	et	f	\N
179042	käisisn	?käisisn =käisisn  (SgN  >käisisn !22_S	et	f	\N
179066	tegelesib	### tegelesib	et	f	\N
179070	teatama	teatama =tea  (SupIps  >teadma !34_V	et	f	\N
179071	teatama	teatama =teata  (Sup  >teatama !27_V	et	f	\N
179080	9ºº	### 9ºº	et	f	\N
179088	market	?market =marke  (SgP  >marke !06_S	et	f	\N
179093	kaubat	?kaubat =kaubat  (SgN  >kaubat !02_S	et	f	\N
179113	kaplus	?kaplus =kaplu  (IndIpfSg3  >kapluma !27_V	et	f	\N
179114	kaplus	?kaplus =kaplus  (SgN  >kaplus !11~09_S	et	f	\N
179119	grafik	?grafik =grafik  (SgN  >grafik !02_S	et	f	\N
179122	tahat	?tahat =tahat  (SgN  >tahat !02_S	et	f	\N
179130	tütrukuga	?tütrukuga =tütruku  (SgKom  >tütruku !01_S	et	f	\N
179148	norem	?norem =norem  (SgN  >norem !02_A	et	f	\N
179150	setse	?setse =setse  (SgN  >setse !06_S	et	f	\N
179151	setse	?setse =setse  (SgG  >setne !02_A	et	f	\N
179152	setse	?setse =setse  (SgG  >setse !06_S	et	f	\N
179153	setse	?setse =setse  (PlP  >sets !22_S	et	f	\N
179154	setse	?setse =setse  (IndPrPs_  >setsema !27_V	et	f	\N
179155	setse	?setse =setse  (ImpPrSg2  >setsema !27_V	et	f	\N
179172	tõusema	tõusema =tõusema  (SgG  >tõusem !02_A	et	f	\N
179173	tõusema	"tõusem %tõu  )SEM_cA  <tõug ;22_S	et	f	\N
179174	tõusema	"tõusem %tõu  )SEM_cA  <tõu ;26_S	et	f	\N
179180	ramatiud	?ramatiud =ramatiu  (PlN  >ramatiu !01_S	et	f	\N
179181	ramatiud	?ramatiud =ramatiud  (SgN  >ramatiud !22_S	et	f	\N
179193	vladislav	?vladislav =vladislav  (SgN  >vladislav !02_A	et	f	\N
179202	peipsijärve	peipsijärve =järve  (SgG  >peipsi+järv !22_S	et	f	\N
179203	peipsijärve	peipsijärve =järve  (SgP  >peipsi+järv !22_S	et	f	\N
179204	peipsijärve	peipsijärve =järve  (SgAdt  >peipsi+järv !22_S	et	f	\N
179205	peipsijärve	peipsijärve =järve  (PlP  >peipsi+järv !22_S	et	f	\N
179208	autojunti	?autojunti =autojunti  (SgP  >autojunt !22_S	et	f	\N
179209	autojunti	?autojunti =autojunti  (SgAdt  >autojunt !22_S	et	f	\N
179210	autojunti	?autojunti =junti  (SgP  >auto+junt !22_S	et	f	\N
179211	autojunti	?autojunti =junti  (SgAdt  >auto+junt !22_S	et	f	\N
179212	autojunti	?autojunti =tojunti  (SgN  >au+tojunti !01_S	et	f	\N
179213	autojunti	?autojunti =tojunti  (SgG  >au+tojunti !01_S	et	f	\N
179214	autojunti	?autojunti =tojunti  (SgP  >au+tojunt !22_S	et	f	\N
179215	autojunti	?autojunti =tojunti  (SgAdt  >au+tojunt !22_S	et	f	\N
179216	nelikümand	?nelikümand =nelikümand  (SgN  >nelikümand !22_S	et	f	\N
179217	nelikümand	?nelikümand =ümand  (SgN  >nelik+ümand !02_S	et	f	\N
179218	nelikümand	?nelikümand =kümand  (SgN  >neli+kümand !02_S	et	f	\N
179231	laborantina	### laborantina	et	f	\N
179234	elektriik	?elektriik =elektriik  (SgN  >elektriik !22_S	et	f	\N
179246	aatat	?aatat =aata  (SgP  >aata !16_S	et	f	\N
179247	aatat	?aatat =aatat  (SgN  >aatat !02_S	et	f	\N
179248	pölütehnikumi	?pölütehnikumi =pölütehnikumi  (SgG  >pölütehnikum !19_S	et	f	\N
179249	pölütehnikumi	?pölütehnikumi =pölütehnikumi  (SgP  >pölütehnikum !19_S	et	f	\N
179250	pölütehnikumi	?pölütehnikumi =pölütehnikumi  (SgAdt  >pölütehnikum !19_S	et	f	\N
179258	mülle	?mülle =mülle  (SgN  >mülle !06_S	et	f	\N
179259	mülle	?mülle =mülle  (PlP  >müll !22_S	et	f	\N
179260	mülle	?mülle =mülle  (IndPrPs_  >müllema !30_V	et	f	\N
179261	mülle	?mülle =mülle  (ImpPrSg2  >müllema !30_V	et	f	\N
179283	õtlevad	?õtlevad =õtle  (IndPrPl3  >õtlema !30_V	et	f	\N
179284	õtlevad	?õtlevad =õtleva  (PlN  >õtleva !01_S	et	f	\N
179285	õtlevad	?õtlevad =õtleva  (PlN  >õtlev !02_A	et	f	\N
179293	võilemine	?võilemine =võilemine  (SgN  >võilemine !12_S	et	f	\N
179064	ijuulis	?ijuulis =ijuuli  (IndIpfSg3  >ijuulima !28_V	et	f	\N
179065	ijuulis	?ijuulis =ijuulis  (SgN  >ijuulis !09_S	et	f	\N
179082	7³º	### 7³º	et	f	\N
179083	lida	?lida =lida  (SgN  >lida !17_S	et	f	\N
179084	lida	?lida =lida  (SgG  >lida !17_S	et	f	\N
179085	lida	?lida =lida  (SgP  >lida !17_S	et	f	\N
179086	lida	?lida =lida  (IndPrPs_  >lidama !27_V	et	f	\N
179087	lida	?lida =lida  (ImpPrSg2  >lidama !27_V	et	f	\N
179131	kuida	?kuida =kuida  (SgN  >kuida !16_S	et	f	\N
179132	kuida	?kuida =kuida  (SgG  >kuida !16_S	et	f	\N
179133	kuida	?kuida =kuida  (IndPrPs_  >kuidama !29_V	et	f	\N
179134	kuida	?kuida =kuida  (ImpPrSg2  >kuidama !29_V	et	f	\N
179141	spestialid	?spestialid =spestiali  (PlN  >spestial !19~02_S	et	f	\N
179142	spestialid	?spestialid =spestiali  (PlN  >spestiali !16_S	et	f	\N
179143	spestialid	?spestialid =spestiali  (IndPrSg2  >spestialima !28_V	et	f	\N
179145	õppip	?õppip =õppip  (SgN  >õppip !02_S	et	f	\N
179146	kusteist	kusteist =te  (PlEl  >kus+tee !26_S	et	f	\N
179147	kusteist	kusteist =teist  (SgN  >kus+teist !22_S	et	f	\N
179149	käeb	?käeb =käeb  (SgN  >käeb !22_S	et	f	\N
179156	korused	?korused =koruse  (PlN  >korus !09_S	et	f	\N
179175	posisd	?posisd =posisd  (SgN  >posisd !02_S	et	f	\N
179182	evgeni	?evgeni =evge  (SgTer  >evge !06_S	et	f	\N
179183	evgeni	?evgeni =evgeni  (SgG  >evgen !02_S	et	f	\N
179184	seitsmeneteist	?seitsmeneteist =seitsmenetei  (SgEl  >seitsmenetei !26_S	et	f	\N
179185	seitsmeneteist	?seitsmeneteist =seitsmeneteist  (SgN  >seitsmeneteist !22_S	et	f	\N
179186	seitsmeneteist	?seitsmeneteist =netei  (SgEl  >seitsme+netei !26_S	et	f	\N
179187	seitsmeneteist	?seitsmeneteist =neteist  (SgN  >seitsme+neteist !22_S	et	f	\N
179188	vledislav	?vledislav =vledislav  (SgN  >vledislav !02_A	et	f	\N
179189	viieneteist	?viieneteist =viienetei  (SgEl  >viienetei !26_S	et	f	\N
179190	viieneteist	?viieneteist =viieneteist  (SgN  >viieneteist !22_S	et	f	\N
179191	viieneteist	?viieneteist =netei  (SgEl  >viie+netei !26_S	et	f	\N
179192	viieneteist	?viieneteist =neteist  (SgN  >viie+neteist !22_S	et	f	\N
179201	tubaw	### tubaw	et	f	\N
179235	tütard	?tütard =tütard  (SgN  >tütard !02_S	et	f	\N
179236	kakskümand	?kakskümand =kakskümand  (SgN  >kakskümand !22_S	et	f	\N
179237	kakskümand	?kakskümand =kümand  (SgN  >kaks+kümand !02_S	et	f	\N
179262	lasteaiale	lasteaiale =aia  (SgAll  >laste+aed !22_S	et	f	\N
179263	lasteaiale	lasteaiale =aia  (SgAll  >laste+ai !22_S	et	f	\N
179277	tõlkesin	?tõlkesin =tõlke  (IndIpfSg1  >tõlkema !27_V	et	f	\N
179278	tõlkesin	?tõlkesin =tõlkesin  (SgN  >tõlkesin !19_S	et	f	\N
179288	tein	?tein =tein  (SgN  >tein !22_S	et	f	\N
179299	toidipodis	?toidipodis =toidipodis  (SgN  >toidipodis !09_S	et	f	\N
179300	melidib	### melidib	et	f	\N
179316	õest	õest =õe  (SgEl  >õde !18_S	et	f	\N
179317	õest	õest =ões  (SgP  >ões !09_S	et	f	\N
179320	koerakesega	koerakesega =koerakese  (SgKom  >koerake !12_S	et	f	\N
179322	koerakesega	"koerake %koera  )KE_dS  <koer ;22_SA	et	f	\N
179324	koerakesega	"koerake %koera  )KE_dS  <koer ;23_SA	et	f	\N
179325	koerakesega	koerakesega =koerakese  (SgKom  >koerakene !12_S	et	f	\N
179326	koerakesega	"koerakene %koera  )KENE_dS  <koer ;22_SA	et	f	\N
179327	koerakesega	"koerakene %koera  )KENE_dS  <koer ;23_SA	et	f	\N
179329	severnoje	### severnoje	et	f	\N
179332	koolikaaslatega	?koolikaaslatega =koolikaasla  (PlKom  >koolikaasla !01_S	et	f	\N
179333	koolikaaslatega	?koolikaaslatega =kaasla  (PlKom  >kooli+kaasla !01_S	et	f	\N
179334	koolikaaslatega	?koolikaaslatega =ikaasla  (PlKom  >kool+ikaasla !01_S	et	f	\N
179343	pluusi	pluusi =pluusi  (SgG  >pluus !22_S	et	f	\N
179344	pluusi	pluusi =pluusi  (SgP  >pluus !22_S	et	f	\N
179345	pluusi	pluusi =pluusi  (SgAdt  >pluus !22_S	et	f	\N
179356	askamine	?askamine =askamine  (SgN  >askamine !12_S	et	f	\N
179357	askamine	?askamine =askamine  (PlP  >askamin !19_S	et	f	\N
179361	maailmaluletajad	?maailmaluletajad =maailmaluletaja  (PlN  >maailmaluletaja !01_S	et	f	\N
179362	maailmaluletajad	?maailmaluletajad =maailmaluletaja  (PlN  >maailmaluletajas !02_A	et	f	\N
179363	maailmaluletajad	?maailmaluletajad =letaja  (PlN  >maa+ilm+alu+letaja !01_S	et	f	\N
179364	maailmaluletajad	?maailmaluletajad =letaja  (PlN  >maa+ilm+alu+letajas !02_A	et	f	\N
179365	maailmaluletajad	?maailmaluletajad =luletaja  (PlN  >maa+ilma+luletaja !01_S	et	f	\N
179366	maailmaluletajad	?maailmaluletajad =luletaja  (PlN  >maa+ilma+luletajas !02_A	et	f	\N
179367	maailmaluletajad	?maailmaluletajad =aluletaja  (PlN  >maa+ilm+aluletaja !01_S	et	f	\N
179368	maailmaluletajad	?maailmaluletajad =aluletaja  (PlN  >maa+ilm+aluletajas !02_A	et	f	\N
179369	maailmaluletajad	?maailmaluletajad =ilmaluletaja  (PlN  >maa+ilmaluletaja !01_S	et	f	\N
179370	maailmaluletajad	?maailmaluletajad =ilmaluletaja  (PlN  >maa+ilmaluletajas !02_A	et	f	\N
179392	lasteaiast	lasteaiast =aia  (SgEl  >laste+aed !22_S	et	f	\N
179393	lasteaiast	lasteaiast =aia  (SgEl  >laste+ai !22_S	et	f	\N
179394	lasteaiast	lasteaiast =aias  (SgP  >laste+aiane !10_A	et	f	\N
179395	lasteaiast	"laste+aiane %aia  )NE_aA  <laste+aed ;22_S	et	f	\N
179396	lasteaiast	"laste+aiane %aia  )NE_aA  <laste+ai ;22_S	et	f	\N
179439	kilingi-nõmme	kilingi-nõmme =nõmme  (SgG  >kilingi-nõmm !22_S	et	f	\N
179229	valgeneskeskkoolis	?valgeneskeskkoolis =eneskeskkooli  (SgIn  >valg+eneskeskkool !22_S	et	f	\N
179230	valgeneskeskkoolis	?valgeneskeskkoolis =eneskeskkoolis  (SgN  >valg+eneskeskkoolis !09_S	et	f	\N
179264	kuulamina	?kuulamina =kuulami  (SgEs  >kuulami !01_S	et	f	\N
179265	kuulamina	?kuulamina =kuulami  (SgEs  >kuulam !02_A	et	f	\N
179266	kuulamina	?kuulamina =kuulamina  (SgG  >kuulamin !19_S	et	f	\N
179267	kuulamina	?kuulamina =kuulamina  (SgP  >kuulamin !19_S	et	f	\N
179268	kuulamina	?kuulamina =kuulamina  (SgAdt  >kuulamin !19_S	et	f	\N
179269	kuulamina	?kuulamina =ami  (SgEs  >kuul+ami !17_S	et	f	\N
179270	kuulamina	?kuulamina =amina  (SgG  >kuul+amin !02_S	et	f	\N
179271	kuulamina	?kuulamina =lami  (SgEs  >kuu+lami !17_S	et	f	\N
179272	kuulamina	?kuulamina =lamina  (SgG  >kuu+lamin !02_S	et	f	\N
179279	temga	?temga =temga  (SgN  >temga !16_S	et	f	\N
179280	temga	?temga =temga  (SgG  >temga !16_S	et	f	\N
179281	temga	?temga =temga  (IndPrPs_  >temgama !29_V	et	f	\N
179282	temga	?temga =temga  (ImpPrSg2  >temgama !29_V	et	f	\N
179304	tööile	?tööile =tööile  (IndPrPs_  >tööilema !27_V	et	f	\N
179305	tööile	?tööile =tööile  (ImpPrSg2  >tööilema !27_V	et	f	\N
179306	kõnelta	?kõnelta =kõnelta  (SgN  >kõnelta !01_S	et	f	\N
179307	kõnelta	?kõnelta =kõnelta  (SgG  >kõnelta !01_S	et	f	\N
179312	kurssusele	?kurssusele =kurssuse  (SgAll  >kurssus !11~09_S	et	f	\N
179313	kurssusele	?kurssusele =kurssusele  (PlP  >kurssusel !19_S	et	f	\N
179314	õdest	?õdest =õdes  (SgP  >õdes !09_S	et	f	\N
179315	õdest	?õdest =õdes  (SgP  >õdene !10_A	et	f	\N
179341	peeter-paul	?peeter-paul =pau  (SgAd  >peeter-pau !26_S	et	f	\N
179342	peeter-paul	?peeter-paul =paul  (SgN  >peeter-paul !22_S	et	f	\N
179346	töövõtja	töövõtja =võtja  (SgN  >töö+võtja !01_S	et	f	\N
179347	töövõtja	töövõtja =võtja  (SgG  >töö+võtja !01_S	et	f	\N
179352	õpesin	?õpesin =õpe  (IndIpfSg1  >õpema !27_V	et	f	\N
179353	õpesin	?õpesin =õpesin  (SgN  >õpesin !19_S	et	f	\N
179359	võrrkeel	?võrrkeel =võrrkee  (SgAd  >võrrkee !26_S	et	f	\N
179360	võrrkeel	?võrrkeel =võrrkeel  (SgN  >võrrkeel !22_S	et	f	\N
179373	võõrkeetvõib	?võõrkeetvõib =võõrkeetvõib  (SgN  >võõrkeetvõib !22_S	et	f	\N
179374	võõrkeetvõib	?võõrkeetvõib =keetvõib  (SgN  >võõr+keetvõib !22_S	et	f	\N
179375	töötöötada	?töötöötada =tada  (SgN  >töö+töö+tada !17_S	et	f	\N
179376	töötöötada	?töötöötada =tada  (SgG  >töö+töö+tada !17_S	et	f	\N
179377	töötöötada	?töötöötada =tada  (SgP  >töö+töö+tada !17_S	et	f	\N
179378	vat	### vat	et	f	\N
179379	õppite	### õppite	et	f	\N
179390	riigikeeles	riigikeeles =keele  (SgIn  >riigi+keel !13_S	et	f	\N
179391	riigikeeles	riigikeeles =keele  (PlIn  >riigi+keeld !22_S	et	f	\N
179402	ukrainasse	?ukrainasse =ukrainas  (SgAdt  >ukrainane !12_A	et	f	\N
179403	ukrainasse	?ukrainasse =ukrainasse  (SgG  >ukrainasne !02_A	et	f	\N
179404	ukrainasse	?ukrainasse =ukrainasse  (PlP  >ukrainass !22_S	et	f	\N
179412	kodakondsusetaei	?kodakondsusetaei =kodakondsusetaei  (SgN  >kodakondsusetaei !26_S	et	f	\N
179413	kodakondsusetaei	?kodakondsusetaei =kodakondsusetaei  (SgG  >kodakondsusetaei !26_S	et	f	\N
179414	kodakondsusetaei	?kodakondsusetaei =etaei  (SgN  >koda+kondsus+etaei !26_S	et	f	\N
179415	kodakondsusetaei	?kodakondsusetaei =etaei  (SgG  >koda+kondsus+etaei !26_S	et	f	\N
179416	kodakondsusetaei	?kodakondsusetaei =kondsusetaei  (SgN  >koda+kondsusetaei !26_S	et	f	\N
179417	kodakondsusetaei	?kodakondsusetaei =kondsusetaei  (SgG  >koda+kondsusetaei !26_S	et	f	\N
179444	teras	teras =tera  (SgIn  >tera !17_S	et	f	\N
179445	teras	teras =teras  (SgN  >teras !09_S	et	f	\N
179446	tõstamaal	tõstamaal =maa  (SgAd  >tõsta+maa !26_S	et	f	\N
179447	tõstamaal	tõstamaal =maal  (SgN  >tõsta+maal !22_S	et	f	\N
179448	terasele	terasele =terase  (SgAll  >teras !09_S	et	f	\N
179449	terasele	terasele =terase  (SgAll  >terane !10_A	et	f	\N
179450	terasele	"terane %tera  )NE_aA  <tera ;17_S	et	f	\N
179488	thau	?thau =thau  (SgN  >thau !26_S	et	f	\N
179489	thau	?thau =thau  (SgG  >thau !26_S	et	f	\N
179494	pänud	?pänud =pänu  (PlN  >pänu !17_S	et	f	\N
179495	pänud	?pänud =pänu  (IndPrSg2  >pänuma !27_V	et	f	\N
179497	aiaga	aiaga =aia  (SgKom  >aed !22_S	et	f	\N
179498	aiaga	aiaga =aia  (SgKom  >ai !22_S	et	f	\N
179574	oskamiseta	oskamiseta =oskamise  (SgAb  >oskamine !12_S	et	f	\N
179575	oskamiseta	"oskamine %oska  )MINE_vS  <oskama ;29_V	et	f	\N
179579	väilsmaal	?väilsmaal =väilsmaa  (SgAd  >väilsmaa !26_S	et	f	\N
179580	väilsmaal	?väilsmaal =väilsmaal  (SgN  >väilsmaal !22_S	et	f	\N
179597	suurendanud	suurendanud =suurenda  (PtsPtPs  >suurendama !27_V	et	f	\N
179598	suurendanud	suurendanud =suurendanu  (PlN  >suurendanu !01_S	et	f	\N
179599	suurendanud	"suurendanu %suurenda  )NU_vS  <suurendama ;27_V	et	f	\N
179600	suurendanud	suurendanud =suurendanud  (ID  >suurendanud !41_A	et	f	\N
179601	suurendanud	"suurendanud %suurenda  )NUD_vA  <suurendama ;27_V	et	f	\N
179618	maarika	?maarika =maarika  (SgN  >maarika !01_S	et	f	\N
179619	maarika	?maarika =maarika  (SgG  >maarika !01_S	et	f	\N
179620	maarika	?maarika =maarika  (SgG  >maarikas !02_S	et	f	\N
179621	maarika	?maarika =rika  (SgN  >maa+rika !16_S	et	f	\N
179295	võilemine	?võilemine =võilemine  (PlP  >võilemin !19_S	et	f	\N
179296	võilemine	?võilemine =lemine  (SgN  >või+lemine !10_A	et	f	\N
179301	käit	?käit =käit  (SgN  >käit !22_S	et	f	\N
179308	saadis	?saadis =saadi  (SgIn  >saadi !16_S	et	f	\N
179309	saadis	?saadis =saadi  (SgIn  >saat !22_S	et	f	\N
179310	saadis	?saadis =saadi  (IndIpfSg3  >saadima !28_V	et	f	\N
179311	saadis	?saadis =saadis  (SgN  >saadis !09_S	et	f	\N
179331	poberezje	### poberezje	et	f	\N
179335	koraldatakse	?koraldatakse =koralda  (IndPrIps  >koraldama !27_V	et	f	\N
179336	koraldatakse	?koraldatakse =koraldatakse  (SgG  >koraldatakne !02_A	et	f	\N
179337	koraldatakse	?koraldatakse =koraldatakse  (PlP  >koraldataks !22_S	et	f	\N
179339	juhtmisel	?juhtmisel =juhtmise  (SgAd  >juhtmine !12?10_A	et	f	\N
179340	juhtmisel	?juhtmisel =juhtmisel  (SgN  >juhtmisel !19_S	et	f	\N
179348	vätab	?vätab =väta  (IndPrSg3  >vätama !27_V	et	f	\N
179387	intsiativ	?intsiativ =intsiati  (PtsPrPs  >intsiatima !28_V	et	f	\N
179388	intsiativ	?intsiativ =intsiativ  (SgN  >intsiativ !02_A	et	f	\N
179400	kahekümneviieaastane	kahekümneviieaastane =aastane  (SgN  >kahe+kümne+viie+aastane !12~10_A	et	f	\N
179401	kahekümneviieaastane	"kahe+kümne+viie+aastane %aasta  )NE_aA  <kahe+kümne+viie+aasta ;01_S	et	f	\N
179405	taotleja	taotleja =taotleja  (SgN  >taotleja !01_S	et	f	\N
179406	taotleja	"taotleja %taotle  )JA_vS  <taotlema ;27_V	et	f	\N
179407	taotleja	taotleja =taotleja  (SgG  >taotleja !01_S	et	f	\N
179408	perekonna-	perekonna- =perekonna  (SgG  >perekond !22_S	et	f	\N
179409	perekonna-	perekonna- =konna  (SgG  >pere+konn !22_S	et	f	\N
179410	perekonna-	perekonna- =konna  (SgP  >pere+konn !22_S	et	f	\N
179411	perekonna-	perekonna- =konna  (SgAdt  >pere+konn !22_S	et	f	\N
179429	puhkana	?puhkana =puhka  (SgEs  >puhka !16_S	et	f	\N
179430	puhkana	?puhkana =ana  (SgN  >puhk+ana !17_S	et	f	\N
179431	puhkana	?puhkana =ana  (SgG  >puhk+ana !17_S	et	f	\N
179432	puhkana	?puhkana =ana  (SgP  >puhk+ana !17_S	et	f	\N
179433	lõbussad	?lõbussad =lõbussa  (PlN  >lõbussa !01_S	et	f	\N
179434	tegilise	?tegilise =tegilise  (SgG  >tegiline !12_A	et	f	\N
179459	ostjaid	ostjaid =ostja  (PlP  >ostja !01_S	et	f	\N
179460	ostjaid	"ostja %ost  )JA_vS  <ostma ;34_V	et	f	\N
179463	kukruse	?kukruse =kukruse  (SgG  >kukrus !11~09_S	et	f	\N
179466	kingiks	kingiks =kingi  (SgTr  >kink !22_S	et	f	\N
179467	kingiks	kingiks =kingi  (PlTr  >king !22_S	et	f	\N
179468	kingiks	kingiks =kingi  (KndPrPs  >kinkima !28_V	et	f	\N
179469	kingiks	kingiks =iks  (SgN  >king+iks !22_S	et	f	\N
179475	diskol	?diskol =disko  (SgAd  >disko !16_S	et	f	\N
179476	diskol	?diskol =diskol  (SgN  >diskol !02_S	et	f	\N
179477	trohkem	?trohkem =trohkem  (SgN  >trohkem !02_A	et	f	\N
179491	saadnud	?saadnud =saadnu  (PlN  >saadnu !01_S	et	f	\N
179492	saadnud	?saadnud =saadnu  (IndPrSg2  >saadnuma !27_V	et	f	\N
179493	saadnud	?saadnud =saadnud  (ID  >saadnud !41_A	et	f	\N
179512	kinkivad	kinkivad =kinkiva  (PlN  >kinkiv !02_A	et	f	\N
179513	kinkivad	"kinkiv %kinki  )V_vA  <kinkima ;28_V	et	f	\N
179521	prestiizi	?prestiizi =prestiizi  (SgN  >prestiizi !16_S	et	f	\N
179522	prestiizi	?prestiizi =prestiizi  (SgG  >prestiizi !16_S	et	f	\N
179523	prestiizi	?prestiizi =stiizi  (SgN  >pre+stiizi !16_S	et	f	\N
179524	prestiizi	?prestiizi =stiizi  (SgG  >pre+stiizi !16_S	et	f	\N
179525	mugavuses	mugavuses =mugavuse  (SgIn  >mugavus !11_S	et	f	\N
179526	mugavuses	"mugavus %mugava  )US_aS  <mugav ;02_A	et	f	\N
179528	tähits	?tähits =tähits  (SgN  >tähits !02_S	et	f	\N
179531	prantsusemaale	prantsusemaale =ale  (SgN  >prantsus+ema+ale !16_S	et	f	\N
179532	prantsusemaale	prantsusemaale =ale  (SgG  >prantsus+ema+ale !16_S	et	f	\N
179533	prantsusemaale	prantsusemaale =maa  (SgAll  >prantsuse+maa !26_S	et	f	\N
179534	prantsusemaale	prantsusemaale =maale  (PlP  >prantsuse+maal !22_S	et	f	\N
179542	osakamine	?osakamine =osakamine  (SgN  >osakamine !12_S	et	f	\N
179543	osakamine	?osakamine =osakamine  (PlP  >osakamin !19_S	et	f	\N
179544	osakamine	?osakamine =kamine  (SgN  >osa+kamine !10_A	et	f	\N
179560	kesk-evropas	?kesk-evropas =evropa  (SgIn  >kesk-evropa !01_S	et	f	\N
179566	noord	?noord =noord  (SgN  >noord !22_S	et	f	\N
179577	lugupidemisega	?lugupidemisega =lugupidemise  (SgKom  >lugupidemine !12_S	et	f	\N
179578	lugupidemisega	?lugupidemisega =pidemise  (SgKom  >lugu+pidemine !12_S	et	f	\N
179629	palunmulle	?palunmulle =palunmulle  (PlP  >palunmull !22_S	et	f	\N
179634	vanalinnasse	vanalinnasse =asse  (PlP  >vana+linn+ass !22_S	et	f	\N
179635	vanalinnasse	vanalinnasse =linna  (SgIll  >vana+linn !22_S	et	f	\N
179655	tulan	?tulan =tula  (IndPrSg1  >tulama !27_V	et	f	\N
179656	tulan	?tulan =tulan  (SgN  >tulan !02_S	et	f	\N
179675	päevisin	?päevisin =päevi  (IndIpfSg1  >päevima !28_V	et	f	\N
179676	päevisin	?päevisin =päevisin  (SgN  >päevisin !19_S	et	f	\N
179677	päevisin	?päevisin =isin  (SgN  >päev+isin !02_S	et	f	\N
179678	suutänu	suutänu =tänu  (SgN  >suu+tänu !17_S	et	f	\N
179679	suutänu	suutänu =tänu  (SgG  >suu+tänu !17_S	et	f	\N
179680	suutänu	suutänu =tänu  (SgP  >suu+tänu !17_S	et	f	\N
179684	puhapäevaks	?puhapäevaks =puhapäeva  (SgTr  >puhapäeva !16_S	et	f	\N
179319	daami	daami =daami  (SgG  >daam !22_S	et	f	\N
179321	daami	daami =daami  (SgP  >daam !22_S	et	f	\N
179323	daami	daami =daami  (SgAdt  >daam !22_S	et	f	\N
179328	internetit	?internetit =neti  (SgP  >inter+neti !16_S	et	f	\N
179330	internetit	?internetit =netit  (SgN  >inter+netit !02_S	et	f	\N
179349	spetsialisti	spetsialisti =spetsialisti  (SgG  >spetsialist !22_S	et	f	\N
179350	spetsialisti	spetsialisti =spetsialisti  (SgP  >spetsialist !22_S	et	f	\N
179351	spetsialisti	spetsialisti =spetsialisti  (SgAdt  >spetsialist !22_S	et	f	\N
179358	osakd	?osakd =osakd  (SgN  >osakd !02_S	et	f	\N
179380	venelaseid	?venelaseid =venelasei  (PlN  >venelasei !26_S	et	f	\N
179381	venelaseid	?venelaseid =venelasei  (SgP  >venelasei !26_S	et	f	\N
179397	ektiivselt	?ektiivselt =ektiivse  (SgAbl  >ektiivne !02_A	et	f	\N
179398	ektiivselt	?ektiivselt =ektiivse  (PlAbl  >ektiivs !22_S	et	f	\N
179399	ektiivselt	?ektiivselt =ektiivselt  (ID  >ektiivselt !41_D	et	f	\N
179418	kaarepere	kaarepere =pere  (SgN  >kaare+pere !16_S	et	f	\N
179419	kaarepere	kaarepere =pere  (SgG  >kaare+pere !16_S	et	f	\N
179451	terase	terase =terase  (SgG  >teras !09_S	et	f	\N
179452	terase	terase =terase  (SgG  >terane !10_A	et	f	\N
179453	terase	"terane %tera  )NE_aA  <tera ;17_S	et	f	\N
179461	palutakse	palutakse =palu  (IndPrIps  >paluma !27_V	et	f	\N
179462	palutakse	palutakse =takse  (PlP  >palu+taks !22_S	et	f	\N
179470	sünnipäevast	sünnipäevast =ast  (SgN  >sünni+päev+ast !22_S	et	f	\N
179471	sünnipäevast	sünnipäevast =päeva  (SgEl  >sünni+päev !22_S	et	f	\N
179472	sünnipäevast	sünnipäevast =päevas  (SgP  >sünni+päevane !10_A	et	f	\N
179473	sünnipäevast	"sünni+päevane %päeva  )NE_aA  <sünni+päev ;22_S	et	f	\N
179481	limonadi	### limonadi	et	f	\N
179490	10-	### 10-	et	f	\N
179535	õpimma	?õpimma =õpimma  (SgN  >õpimma !01_S	et	f	\N
179536	õpimma	?õpimma =õpimma  (SgG  >õpimma !01_S	et	f	\N
179539	oskamisega	oskamisega =oskamise  (SgKom  >oskamine !12_S	et	f	\N
179540	oskamisega	"oskamine %oska  )MINE_vS  <oskama ;29_V	et	f	\N
179554	keete	keete =kee  (IndPrPl2  >keema !37_V	et	f	\N
179555	keete	keete =keete  (SgG  >keede !06_S	et	f	\N
179556	keete	keete =keete  (PlP  >keet !22_S	et	f	\N
179561	muudadused	?muudadused =muudaduse  (PlN  >muudadus !11_S	et	f	\N
179562	muudadused	?muudadused =aduse  (PlN  >muud+adus !02_A	et	f	\N
179563	muudadused	?muudadused =daduse  (PlN  >muu+dadus !02_A	et	f	\N
179564	oskamist	oskamist =oskamis  (SgP  >oskamine !12_S	et	f	\N
179565	oskamist	"oskamine %oska  )MINE_vS  <oskama ;29_V	et	f	\N
179567	ajalehtes	### ajalehtes	et	f	\N
179568	kuulutusi	kuulutusi =kuulutusi  (PlP  >kuulutus !11_S	et	f	\N
179569	kuulutusi	"kuulutus %kuuluta  )US_vS  <kuulutama ;27_V	et	f	\N
179570	kuulutusi	"kuulutus %kuulu  )TUS1_aS  <kuuluma ;27_V	et	f	\N
179571	kuulutusi	"kuulutus %kuulu  )TUS2_aS  <kuuld ;22_S	et	f	\N
179587	originalis	?originalis =originali  (SgIn  >original !19_S	et	f	\N
179588	originalis	?originalis =originalis  (SgN  >originalis !09_S	et	f	\N
179589	võrkeelte	?võrkeelte =eelte  (SgN  >võrk+eelte !06_S	et	f	\N
179590	võrkeelte	?võrkeelte =eelte  (SgG  >võrk+eelde !06_S	et	f	\N
179605	küsita	küsita =küsi  (IndPrIps_  >küsima !27_V	et	f	\N
179606	küsita	küsita =küsita  (IndPrPs_  >küsitama !27_V	et	f	\N
179607	küsita	küsita =küsita  (ImpPrSg2  >küsitama !27_V	et	f	\N
179614	raskemalt	raskemalt =raskema  (SgAbl  >raskem !02_A	et	f	\N
179615	raskemalt	"raskem %raske  )M_cA  <raske ;01_A	et	f	\N
179616	raskemalt	raskemalt =raskemalt  (ID  >raskemalt !41_D	et	f	\N
179617	raskemalt	"raskemalt %raske  )MALT_mD  <raske ;01_A	et	f	\N
179630	kinot	?kinot =kinot  (SgN  >kinot !02_S	et	f	\N
179632	kirjuatan	?kirjuatan =kirjuata  (IndPrSg1  >kirjuatama !27_V	et	f	\N
179633	kirjuatan	?kirjuatan =kirjuatan  (SgN  >kirjuatan !02_S	et	f	\N
179640	sügus	?sügus =sügu  (SgIn  >sügu !17_S	et	f	\N
179641	sügus	?sügus =sügu  (IndIpfSg3  >süguma !27_V	et	f	\N
179642	sügus	?sügus =sügus  (SgN  >sügus !02_A	et	f	\N
179657	jargmiseni	?jargmiseni =jargmise  (SgTer  >jargmine !12?10_A	et	f	\N
179658	jargmiseni	?jargmiseni =jargmiseni  (SgG  >jargmisen !19_S	et	f	\N
179659	jargmiseni	?jargmiseni =jargmiseni  (SgP  >jargmisen !19_S	et	f	\N
179660	jargmiseni	?jargmiseni =jargmiseni  (SgAdt  >jargmisen !19_S	et	f	\N
179685	tullen	?tullen =tulle  (IndPrSg1  >tullema !30_V	et	f	\N
179686	tullen	?tullen =tullen  (SgN  >tullen !02_S	et	f	\N
179703	rided	?rided =ride  (PlN  >ride !16_S	et	f	\N
179704	rided	?rided =ride  (IndPrSg2  >ridema !27_V	et	f	\N
179711	seial	?seial =seia  (SgAd  >seia !16_S	et	f	\N
179712	seial	?seial =seial  (SgN  >seial !02_S	et	f	\N
179713	hinad	?hinad =hina  (PlN  >hina !17_S	et	f	\N
179714	hinad	?hinad =hina  (IndPrSg2  >hinama !27_V	et	f	\N
179718	akan	?akan =aka  (IndPrSg1  >akama !27_V	et	f	\N
179719	akan	?akan =akan  (SgN  >akan !02_S	et	f	\N
179722	ivõibola	?ivõibola =ivõibola  (SgN  >ivõibola !01_S	et	f	\N
179723	ivõibola	?ivõibola =ivõibola  (SgG  >ivõibola !01_S	et	f	\N
179730	kasa	?kasa =kasa  (SgN  >kasa !17_S	et	f	\N
179440	kilingi-nõmme	kilingi-nõmme =nõmme  (SgP  >kilingi-nõmm !22_S	et	f	\N
179441	kilingi-nõmme	kilingi-nõmme =nõmme  (SgAdt  >kilingi-nõmm !22_S	et	f	\N
179442	kilingi-nõmme	kilingi-nõmme =nõmme  (PlP  >kilingi-nõmm !22_S	et	f	\N
179443	võitega	?võitega =võite  (SgKom  >võide !06_S	et	f	\N
179454	käitusis	käitusis =käitusi  (PlIn  >käitus !11_S	et	f	\N
179455	käitusis	"käitus %käita  )US_vS  <käitama ;27_V	et	f	\N
179474	õunatega	### õunatega	et	f	\N
179485	asjud	?asjud =asju  (PlN  >asju !16_S	et	f	\N
179486	asjud	?asjud =asju  (IndPrSg2  >asjuma !27_V	et	f	\N
179496	vikaga	?vikaga =vika  (SgKom  >vika !16_S	et	f	\N
179499	serva	serva =serva  (SgG  >serv !22_S	et	f	\N
179500	serva	serva =serva  (SgP  >serv !22_S	et	f	\N
179501	serva	serva =serva  (SgAdt  >serv !22_S	et	f	\N
179502	serva	serva =serva  (IndPrPs_  >servama !29_V	et	f	\N
179503	serva	serva =serva  (ImpPrSg2  >servama !29_V	et	f	\N
179509	marila	?marila =marila  (SgN  >marila !01_S	et	f	\N
179510	marila	?marila =marila  (SgG  >marila !01_S	et	f	\N
179511	marek	?marek =marek  (SgN  >marek !02_S	et	f	\N
179514	süame	?süame =süame  (SgN  >süame !06_S	et	f	\N
179515	süame	?süame =süame  (SgG  >süame !06_S	et	f	\N
179516	süame	?süame =süame  (PlP  >süam !22_S	et	f	\N
179517	süame	?süame =süame  (IndPrPs_  >süamema !27_V	et	f	\N
179518	süame	?süame =süame  (ImpPrSg2  >süamema !27_V	et	f	\N
179529	sellepäeast	?sellepäeast =sellepäea  (SgEl  >sellepäea !26_S	et	f	\N
179530	sellepäeast	?sellepäeast =päeas  (SgP  >selle+päeane !12~10_A	et	f	\N
179537	erinevadel	?erinevadel =erineva  (PlAd  >erineva !16_S	et	f	\N
179538	erinevadel	?erinevadel =neva  (PlAd  >eri+neva !17_S	et	f	\N
179545	iseennasse	?iseennasse =iseenna  (SgIll  >iseenna !16_S	et	f	\N
179546	iseennasse	?iseennasse =iseennas  (SgAdt  >iseennane !12_A	et	f	\N
179547	iseennasse	?iseennasse =iseennasse  (SgG  >iseennasne !02_A	et	f	\N
179548	iseennasse	?iseennasse =iseennasse  (PlP  >iseennass !22_S	et	f	\N
179549	iseennasse	?iseennasse =enna  (SgIll  >ise+enna !16_S	et	f	\N
179550	iseennasse	?iseennasse =ennasse  (SgG  >ise+ennasne !02_A	et	f	\N
179551	iseennasse	?iseennasse =ennasse  (PlP  >ise+ennass !22_S	et	f	\N
179552	leiaksid	leiaksid =leia  (KndPrSg2  >leidma !34_V	et	f	\N
179553	leiaksid	leiaksid =leia  (KndPrPl3  >leidma !34_V	et	f	\N
179558	suhltema	?suhltema =suhlte  (Sup  >suhltema !27_V	et	f	\N
179559	suhltema	?suhltema =suhltema  (SgG  >suhltem !02_A	et	f	\N
179572	töökohtad	?töökohtad =töökohta  (PlN  >töökohta !01_S	et	f	\N
179573	töökohtad	?töökohtad =töökohta  (IndPrSg2  >töökohtama !27_V	et	f	\N
179583	tõlgejata	?tõlgejata =tõlgeja  (SgAb  >tõlgeja !01_S	et	f	\N
179584	tõlgejata	?tõlgejata =tõlgeja  (SgAb  >tõlgejas !02_A	et	f	\N
179585	tõlgejata	?tõlgejata =tõlgejata  (IndPrPs_  >tõlgejatama !27_V	et	f	\N
179586	tõlgejata	?tõlgejata =tõlgejata  (ImpPrSg2  >tõlgejatama !27_V	et	f	\N
179594	võõrkeelid	?võõrkeelid =võõrkeeli  (PlN  >võõrkeeli !16_S	et	f	\N
179595	võõrkeelid	?võõrkeelid =võõrkeeli  (PlN  >võõrkeel !22_S	et	f	\N
179596	võõrkeelid	?võõrkeelid =võõrkeeli  (IndPrSg2  >võõrkeelima !28_V	et	f	\N
179608	rägitakse	?rägitakse =rägi  (IndPrIps  >rägima !27_V	et	f	\N
179609	rägitakse	?rägitakse =rägitakse  (SgG  >rägitakne !02_A	et	f	\N
179610	rägitakse	?rägitakse =rägitakse  (PlP  >rägitaks !22_S	et	f	\N
179611	võõrkeeelte	### võõrkeeelte	et	f	\N
179612	kuursusi	?kuursusi =kuursusi  (ID  >kuursusi !41_D	et	f	\N
179613	kuursusi	?kuursusi =kuursusi  (PlP  >kuursus !11_S	et	f	\N
179623	hansapangas	hansapangas =panga  (SgIn  >hansa+pank !22_S	et	f	\N
179624	hansapangas	hansapangas =pangas  (SgN  >hansa+pangas !07_S	et	f	\N
179637	katedrali	### katedrali	et	f	\N
179643	loomaajja	?loomaajja =loomaajja  (SgN  >loomaajja !01_S	et	f	\N
179644	loomaajja	?loomaajja =loomaajja  (SgG  >loomaajja !01_S	et	f	\N
179645	loomaajja	?loomaajja =loomaajja  (SgG  >loomaajjas !02_A	et	f	\N
179646	loomaajja	?loomaajja =ajja  (SgN  >looma+ajja !16_S	et	f	\N
179647	loomaajja	?loomaajja =ajja  (SgG  >looma+ajjas !02_A	et	f	\N
179648	loomaajja	?loomaajja =ajja  (SgG  >looma+ajja !16_S	et	f	\N
179649	loomaajja	?loomaajja =aajja  (SgN  >loom+aajja !01_S	et	f	\N
179650	loomaajja	?loomaajja =aajja  (SgG  >loom+aajja !01_S	et	f	\N
179651	loomaajja	?loomaajja =aajja  (SgG  >loom+aajjas !02_A	et	f	\N
179652	loomaajja	?loomaajja =maajja  (SgN  >loo+maajja !01_S	et	f	\N
179653	loomaajja	?loomaajja =maajja  (SgG  >loo+maajja !01_S	et	f	\N
179654	loomaajja	?loomaajja =maajja  (SgG  >loo+maajjas !02_A	et	f	\N
179715	heiad	?heiad =heia  (PlN  >heia !16_S	et	f	\N
179716	heiad	?heiad =heia  (IndPrSg2  >heiama !29_V	et	f	\N
179717	heiad	?heiad =heiad  (SgN  >heiad !02_S	et	f	\N
179751	sisseosatb	?sisseosatb =sisseosatb  (SgN  >sisseosatb !22_S	et	f	\N
179752	sisseosatb	?sisseosatb =osatb  (SgN  >sisse+osatb !02_S	et	f	\N
179753	mobilltelefoni	?mobilltelefoni =mobilltelefo  (SgTer  >mobilltelefo !16_S	et	f	\N
179754	mobilltelefoni	?mobilltelefoni =mobilltelefoni  (SgG  >mobilltelefon !19_S	et	f	\N
179755	mobilltelefoni	?mobilltelefoni =mobilltelefoni  (SgP  >mobilltelefon !19_S	et	f	\N
179483	joome	joome =joome  (PlP  >joom !22_S	et	f	\N
179484	salattid	?salattid =salatti  (PlN  >salatti !01_S	et	f	\N
179487	ok	### ok	et	f	\N
179504	aerobikas	?aerobikas =aerobika  (SgIn  >aerobika !01_S	et	f	\N
179505	aerobikas	?aerobikas =aerobika  (SgIn  >aerobikas !02_A	et	f	\N
179506	aerobikas	?aerobikas =aerobikas  (SgN  >aerobikas !02_A	et	f	\N
179507	aerobikas	?aerobikas =bika  (SgIn  >aero+bika !16_S	et	f	\N
179508	aerobikas	?aerobikas =bikas  (SgN  >aero+bikas !07_S	et	f	\N
179519	paremate	paremate =parema  (PlG  >parem !02_A	et	f	\N
179520	paremate	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
179527	vätega	### vätega	et	f	\N
179541	ajaluguga	### ajaluguga	et	f	\N
179557	kolegikuga	?kolegikuga =kolegiku  (SgKom  >kolegik !02_S	et	f	\N
179576	informeetite	### informeetite	et	f	\N
179581	koduabilisena	koduabilisena =abilise  (SgEs  >kodu+abiline !12_S	et	f	\N
179582	koduabilisena	"kodu+abiline %abi  )LINE_aA  <kodu+abi ;17_S	et	f	\N
179591	kultuurit	?kultuurit =kultuuri  (SgP  >kultuuri !16_S	et	f	\N
179592	aluviisit	?aluviisit =aluviisi  (SgP  >aluviisi !16_S	et	f	\N
179593	aluviisit	?aluviisit =viisit  (SgN  >alu+viisit !02_S	et	f	\N
179602	võimalusid	?võimalusid =võimalu  (IndIpfSg2  >võimaluma !27_V	et	f	\N
179603	võimalusid	?võimalusid =võimalu  (IndIpfPl3  >võimaluma !27_V	et	f	\N
179604	võimalusid	?võimalusid =malu  (PlP  >või+malu !17_S	et	f	\N
179625	tarmo	?tarmo =tarmo  (SgN  >tarmo !16_S	et	f	\N
179626	tarmo	?tarmo =tarmo  (SgG  >tarmo !16_S	et	f	\N
179661	sõidemist	?sõidemist =sõidemi  (SgEl  >sõidemi !01_S	et	f	\N
179662	sõidemist	?sõidemist =sõidemi  (SgEl  >sõidem !02_A	et	f	\N
179663	sõidemist	?sõidemist =sõidemis  (SgP  >sõidemis !11_S	et	f	\N
179664	sõidemist	?sõidemist =sõidemis  (SgP  >sõidemine !12_S	et	f	\N
179665	sõidemist	?sõidemist =sõidemist  (SgN  >sõidemist !22_S	et	f	\N
179694	sule	sule =sule  (SgG  >sulg !22_S	et	f	\N
179696	sule	sule =sule  (IndPrPs_  >sulgema !28_V	et	f	\N
179698	sule	sule =sule  (ImpPrSg2  >sulgema !28_V	et	f	\N
179727	vatama	?vatama =vata  (Sup  >vatama !27_V	et	f	\N
179728	vatama	?vatama =vatama  (SgG  >vatam !02_A	et	f	\N
179737	müakse	?müakse =müakse  (SgN  >müakse !06_S	et	f	\N
179738	müakse	?müakse =müakse  (SgG  >müakne !02_A	et	f	\N
179739	müakse	?müakse =müakse  (SgG  >müakse !06_S	et	f	\N
179740	müakse	?müakse =müakse  (PlP  >müaks !22_S	et	f	\N
179741	müakse	?müakse =müakse  (IndPrPs_  >müaksema !27_V	et	f	\N
179742	müakse	?müakse =müakse  (ImpPrSg2  >müaksema !27_V	et	f	\N
179746	munu	?munu =munu  (SgN  >munu !17_S	et	f	\N
179747	munu	?munu =munu  (SgG  >munu !17_S	et	f	\N
179748	munu	?munu =munu  (SgP  >munu !17_S	et	f	\N
179749	munu	?munu =munu  (IndPrPs_  >munuma !27_V	et	f	\N
179750	munu	?munu =munu  (ImpPrSg2  >munuma !27_V	et	f	\N
179761	munust	?munust =munu  (SgEl  >munu !17_S	et	f	\N
179762	munust	?munust =munus  (SgP  >munus !09_S	et	f	\N
179768	kahekümnekaheksaneaastane	?kahekümnekaheksaneaastane =kahekümnekaheksaneaastane  (SgN  >kahekümnekaheksaneaastane !12~10_A	et	f	\N
179769	kahekümnekaheksaneaastane	?kahekümnekaheksaneaastane =neaastane  (SgN  >kahe+kümne+kaheksa+neaastane !12~10_A	et	f	\N
179770	kahekümnekaheksaneaastane	?kahekümnekaheksaneaastane =neaastane  (PlP  >kahe+kümne+kaheksa+neaastan !19_S	et	f	\N
179771	kahekümnekaheksaneaastane	?kahekümnekaheksaneaastane =ksaneaastane  (SgN  >kahe+kümne+kahe+ksaneaastane !12~10_A	et	f	\N
179772	kahekümnekaheksaneaastane	?kahekümnekaheksaneaastane =kaheksaneaastane  (SgN  >kahe+kümne+kaheksaneaastane !12~10_A	et	f	\N
179773	kahekümnekaheksaneaastane	?kahekümnekaheksaneaastane =kümnekaheksaneaastane  (SgN  >kahe+kümnekaheksaneaastane !12~10_A	et	f	\N
179796	adresile	### adresile	et	f	\N
179800	ida-irumaa	?ida-irumaa =irumaa  (SgN  >ida-irumaa !26_S	et	f	\N
179802	ida-irumaa	?ida-irumaa =irumaa  (SgG  >ida-irumaa !26_S	et	f	\N
179804	moobiltelefon	?moobiltelefon =moobiltelefon  (SgN  >moobiltelefon !19_S	et	f	\N
179823	kõin	?kõin =kõin  (SgN  >kõin !22_S	et	f	\N
179846	xxx8581	### xxx8581	et	f	\N
179885	29sept00	?sept =sept  (SgN  >sept !22_S	et	f	\N
179897	xx-zz	### xx-zz	et	f	\N
179910	juustm	?juustm =juustm  (SgN  >juustm !22_S	et	f	\N
179917	kiiri	kiiri =kiir  (PlP  >kiir !13_S	et	f	\N
179918	kiiri	kiiri =kiiri  (SgG  >kiir !22_S	et	f	\N
179919	kiiri	kiiri =kiiri  (SgP  >kiir !22_S	et	f	\N
179920	kiiri	kiiri =kiiri  (SgAdt  >kiir !22_S	et	f	\N
179925	viktor	?viktor =viktor  (SgN  >viktor !02_S	et	f	\N
179933	tüdrug	### tüdrug	et	f	\N
179987	tekkiv	tekkiv =tekki  (PtsPrPs  >tekkima !27~28_V	et	f	\N
179988	tekkiv	tekkiv =tekkiv  (SgN  >tekkiv !02_A	et	f	\N
179989	tekkiv	"tekkiv %tekki  )V_vA  <tekkima ;27_V	et	f	\N
179990	tekkiv	"tekkiv %tekki  )V_vA  <tekkima ;28_V	et	f	\N
180000	müüv	müüv =müü  (PtsPrPs  >müüma !38_V	et	f	\N
180001	müüv	müüv =müüv  (SgN  >müüv !02_A	et	f	\N
180002	müüv	"müüv %müü  )V_vA  <müüma ;38_V	et	f	\N
180012	tav-kesksõna	tav-kesksõna =sõna  (SgN  >tav-kesk+sõna !17_S	et	f	\N
180013	tav-kesksõna	tav-kesksõna =sõna  (SgG  >tav-kesk+sõna !17_S	et	f	\N
179622	maarika	?maarika =rika  (SgG  >maa+rika !16_S	et	f	\N
179627	perkonnaseis	?perkonnaseis =perkonnasei  (SgIn  >perkonnasei !26_S	et	f	\N
179628	perkonnaseis	?perkonnaseis =perkonnaseis  (SgN  >perkonnaseis !22_S	et	f	\N
179631	nägisime	?nägisime =nägi  (IndIpfPl1  >nägima !27_V	et	f	\N
179636	26-ndal	### 26-ndal	et	f	\N
179638	looamaega	?looamaega =looamae  (SgKom  >looamae !26_S	et	f	\N
179639	looamaega	?looamaega =amae  (SgKom  >loo+amae !26_S	et	f	\N
179666	teveks	?teveks =teve  (SgTr  >teve !16_S	et	f	\N
179667	teveks	?teveks =teve  (KndPrPs  >tevema !27_V	et	f	\N
179668	tööli	?tööli =tööli  (SgN  >tööli !16_S	et	f	\N
179669	tööli	?tööli =tööli  (SgG  >tööli !16_S	et	f	\N
179670	tööli	?tööli =tööli  (SgG  >tööl !22_S	et	f	\N
179671	tööli	?tööli =tööli  (SgP  >tööl !22_S	et	f	\N
179672	tööli	?tööli =tööli  (SgAdt  >tööl !22_S	et	f	\N
179673	tööli	?tööli =tööli  (IndPrPs_  >töölima !28_V	et	f	\N
179674	tööli	?tööli =tööli  (ImpPrSg2  >töölima !28_V	et	f	\N
179681	vabaõhumuuseumi	vabaõhumuuseumi =muuseumi  (SgG  >vaba+õhu+muuseum !19~02_S	et	f	\N
179682	vabaõhumuuseumi	vabaõhumuuseumi =muuseumi  (SgP  >vaba+õhu+muuseum !19_S	et	f	\N
179683	vabaõhumuuseumi	vabaõhumuuseumi =muuseumi  (SgAdt  >vaba+õhu+muuseum !19_S	et	f	\N
179687	loosi	loosi =loosi  (SgG  >loos !22_S	et	f	\N
179688	loosi	loosi =loosi  (SgP  >loos !22_S	et	f	\N
179689	loosi	loosi =loosi  (SgAdt  >loos !22_S	et	f	\N
179690	loosi	loosi =loosi  (IndPrPs_  >loosima !28_V	et	f	\N
179691	loosi	loosi =loosi  (ImpPrSg2  >loosima !28_V	et	f	\N
179708	kauplusese	kauplusese =kauplusese  (SgG  >kauplusene !12_A	et	f	\N
179709	kauplusese	"kauplusene %kaupluse  )NE_aA  <kauplus ;09_S	et	f	\N
179710	kauplusese	"kauplusene %kaupluse  )NE_aA  <kauplus ;11_S	et	f	\N
179720	lõpima	?lõpima =lõpi  (Sup  >lõpima !27_V	et	f	\N
179721	lõpima	?lõpima =lõpima  (SgG  >lõpim !02_A	et	f	\N
179778	tööpäevast	tööpäevast =ast  (SgN  >töö+päev+ast !22_S	et	f	\N
179779	tööpäevast	tööpäevast =päeva  (SgEl  >töö+päev !22_S	et	f	\N
179780	tööpäevast	tööpäevast =päevas  (SgP  >töö+päevane !10_A	et	f	\N
179781	tööpäevast	"töö+päevane %päeva  )NE_aA  <töö+päev ;22_S	et	f	\N
179782	perga	?perga =perga  (SgN  >perga !16_S	et	f	\N
179783	perga	?perga =perga  (SgG  >perga !16_S	et	f	\N
179784	perga	?perga =perga  (IndPrPs_  >pergama !29_V	et	f	\N
179785	perga	?perga =perga  (ImpPrSg2  >pergama !29_V	et	f	\N
179807	konttel	?konttel =kontte  (SgAd  >kontte !06_S	et	f	\N
179808	konttel	?konttel =kontte  (PlAd  >kontt !22_S	et	f	\N
179809	konttel	?konttel =konttel  (SgN  >konttel !02_S	et	f	\N
179810	müüjanavõi	?müüjanavõi =müüjanavõi  (SgN  >müüjanavõi !26_S	et	f	\N
179811	müüjanavõi	?müüjanavõi =müüjanavõi  (SgG  >müüjanavõi !26_S	et	f	\N
179812	müüjanavõi	?müüjanavõi =navõi  (SgN  >müüja+navõi !26_S	et	f	\N
179813	müüjanavõi	?müüjanavõi =navõi  (SgG  >müüja+navõi !26_S	et	f	\N
179847	teineks	?teineks =teine  (PlTr  >tein !22_S	et	f	\N
179848	teineks	?teineks =teine  (KndPrPs  >teinema !27_V	et	f	\N
179851	tutvustamiseks	tutvustamiseks =tutvustamise  (SgTr  >tutvustamine !12_S	et	f	\N
179852	tutvustamiseks	"tutvustamine %tutvusta  )MINE_vS  <tutvustama ;27_V	et	f	\N
179864	k-jarve	?k-jarve =jarve  (SgN  >k-jarve !06_S	et	f	\N
179865	k-jarve	?k-jarve =jarve  (SgG  >k-jarve !06_S	et	f	\N
179866	k-jarve	?k-jarve =jarve  (PlP  >k-jarv !22_S	et	f	\N
179867	k-jarve	?k-jarve =jarve  (IndPrPs_  >k-jarvema !27_V	et	f	\N
179868	k-jarve	?k-jarve =jarve  (ImpPrSg2  >k-jarvema !27_V	et	f	\N
179894	suheltada	### suheltada	et	f	\N
179926	headi	?headi =headi  (SgN  >headi !16_S	et	f	\N
179927	headi	?headi =headi  (SgG  >headi !16_S	et	f	\N
179928	headi	?headi =headi  (SgG  >heat !22_S	et	f	\N
179929	headi	?headi =headi  (SgP  >head !22_S	et	f	\N
179930	headi	?headi =headi  (SgAdt  >head !22_S	et	f	\N
179931	headi	?headi =headi  (IndPrPs_  >heatima !28_V	et	f	\N
179932	headi	?headi =headi  (ImpPrSg2  >heatima !28_V	et	f	\N
179940	kakkuminkake	?kakkuminkake =kakkuminkake  (SgN  >kakkuminkake !12_S	et	f	\N
179946	haigema	haigema =haigema  (SgG  >haigem !02_A	et	f	\N
179947	haigema	"haigem %haige  )M_cA  <haige ;01_AS	et	f	\N
179962	laskati	?laskati =laskati  (ID  >laskati !41_D	et	f	\N
179963	laskati	?laskati =laskati  (SgG  >laskat !02_S	et	f	\N
179964	laskati	?laskati =laskati  (SgG  >laskatt !22_S	et	f	\N
179965	laskati	?laskati =laskati  (IndPrPs_  >laskattima !28_V	et	f	\N
179966	laskati	?laskati =laskati  (ImpPrSg2  >laskattima !28_V	et	f	\N
179979	rääkiti	?rääkiti =rääkiti  (ID  >rääkiti !41_D	et	f	\N
179980	rääkiti	?rääkiti =rääkiti  (SgG  >rääkit !02_S	et	f	\N
179981	rääkiti	?rääkiti =rääkiti  (SgG  >rääkitt !22_S	et	f	\N
179982	rääkiti	?rääkiti =rääkiti  (IndPrPs_  >rääkittima !28_V	et	f	\N
179983	rääkiti	?rääkiti =rääkiti  (ImpPrSg2  >rääkittima !28_V	et	f	\N
179984	v-kesksõna	v-kesksõna =sõna  (SgN  >v-kesk+sõna !17_S	et	f	\N
179985	v-kesksõna	v-kesksõna =sõna  (SgG  >v-kesk+sõna !17_S	et	f	\N
179986	v-kesksõna	v-kesksõna =sõna  (SgP  >v-kesk+sõna !17_S	et	f	\N
179692	aitja	?aitja =aitja  (SgN  >aitja !01_S	et	f	\N
179693	aitja	?aitja =aitja  (SgG  >aitja !01_S	et	f	\N
179695	aitja	?aitja =aitja  (SgG  >aitjas !02_A	et	f	\N
179697	aitja	?aitja =aitja  (IndPrPs_  >aitjama !29_V	et	f	\N
179699	aitja	?aitja =aitja  (ImpPrSg2  >aitjama !29_V	et	f	\N
179700	akavad	?akavad =aka  (IndPrPl3  >akama !27_V	et	f	\N
179701	akavad	?akavad =akava  (PlN  >akava !01_S	et	f	\N
179702	akavad	?akavad =akava  (PlN  >akav !02_A	et	f	\N
179705	elektonika	?elektonika =elektonika  (SgN  >elektonika !01_S	et	f	\N
179706	elektonika	?elektonika =elektonika  (SgG  >elektonika !01_S	et	f	\N
179707	elektonika	?elektonika =elektonika  (SgG  >elektonikas !02_A	et	f	\N
179724	töötugrafik	?töötugrafik =töötugrafik  (SgN  >töötugrafik !02_S	et	f	\N
179725	töötugrafik	?töötugrafik =grafik  (SgN  >töötu+grafik !02_S	et	f	\N
179726	töötugrafik	?töötugrafik =tugrafik  (SgN  >töö+tugrafik !02_S	et	f	\N
179729	vel	### vel	et	f	\N
179736	nüit	?nüit =nüit  (SgN  >nüit !22_S	et	f	\N
179759	kirjua	?kirjua =kirjua  (SgN  >kirjua !01_S	et	f	\N
179760	kirjua	?kirjua =kirjua  (SgG  >kirjua !01_S	et	f	\N
179776	töögrafik	?töögrafik =töögrafik  (SgN  >töögrafik !02_S	et	f	\N
179777	töögrafik	?töögrafik =grafik  (SgN  >töö+grafik !02_S	et	f	\N
179816	keelda	?keelda =keelda  (SgN  >keelda !01_S	et	f	\N
179817	keelda	?keelda =keelda  (SgG  >keelda !01_S	et	f	\N
179818	keelda	?keelda =keelda  (IndPrPs_  >keeldama !27_V	et	f	\N
179819	keelda	?keelda =keelda  (ImpPrSg2  >keeldama !27_V	et	f	\N
179820	toiduageentina	?toiduageentina =ageenti  (SgEs  >toidu+ageenti !01_S	et	f	\N
179821	voldan	?voldan =volda  (IndPrSg1  >voldama !29_V	et	f	\N
179822	voldan	?voldan =voldan  (SgN  >voldan !02_S	et	f	\N
179824	erika	?erika =erika  (SgN  >erika !01_S	et	f	\N
179825	erika	?erika =erika  (SgG  >erika !01_S	et	f	\N
179826	erika	?erika =erika  (SgG  >erikas !02_S	et	f	\N
179835	muujat	muujat =muuja  (SgP  >muuja !01_S	et	f	\N
179836	muujat	"muuja %muu  )JA_vS  <muuma ;27_V	et	f	\N
179837	28-aastane	-aastane =aastane  (SgN  >-aastane !12~10_A	et	f	\N
179838	28-aastane	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
179839	keskeri	keskeri =eri  (ID  >kesk+eri !41_A	et	f	\N
179840	keskeri	keskeri =eri  (SgN  >kesk+eri !17_S	et	f	\N
179841	keskeri	keskeri =eri  (SgG  >kesk+eri !17_S	et	f	\N
179842	keskeri	keskeri =eri  (SgP  >kesk+eri !17_S	et	f	\N
179849	kaheksa-üheksa	kaheksa-üheksa =üheksa  (SgN  >kaheksa-üheksa !01_N	et	f	\N
179850	kaheksa-üheksa	kaheksa-üheksa =üheksa  (SgG  >kaheksa-üheksa !01_N	et	f	\N
179858	tunnistuse	tunnistuse =tunnistuse  (SgG  >tunnistus !11_S	et	f	\N
179859	tunnistuse	"tunnistus %tunnista  )US_vS  <tunnistama ;27_V	et	f	\N
179860	cennadi	?cennadi =cennadi  (SgN  >cennadi !01_S	et	f	\N
179861	cennadi	?cennadi =cennadi  (SgG  >cennadi !01_S	et	f	\N
179871	aktsiaseltsi	aktsiaseltsi =seltsi  (SgG  >aktsia+selts !22_S	et	f	\N
179872	aktsiaseltsi	aktsiaseltsi =seltsi  (SgP  >aktsia+selts !22_S	et	f	\N
179873	aktsiaseltsi	aktsiaseltsi =seltsi  (SgAdt  >aktsia+selts !22_S	et	f	\N
179889	kuududa	?kuududa =kuudu  (Inf  >kuuduma !27_V	et	f	\N
179890	kuududa	?kuududa =duda  (SgN  >kuu+duda !17_S	et	f	\N
179891	kuududa	?kuududa =duda  (SgG  >kuu+duda !17_S	et	f	\N
179892	kuududa	?kuududa =duda  (SgP  >kuu+duda !17_S	et	f	\N
179901	jarvel	?jarvel =jarve  (SgAd  >jarve !06_S	et	f	\N
179902	jarvel	?jarvel =jarve  (PlAd  >jarv !22_S	et	f	\N
179903	jarvel	?jarvel =jarvel  (SgN  >jarvel !02_S	et	f	\N
179911	hahetse	?hahetse =hahetse  (SgG  >hahetne !02_A	et	f	\N
179912	hahetse	?hahetse =hahetse  (IndPrPs_  >hahetsema !27_V	et	f	\N
179913	hahetse	?hahetse =hahetse  (ImpPrSg2  >hahetsema !27_V	et	f	\N
179954	andati	?andati =anda  (IndIpfIps  >antama !29_V	et	f	\N
179957	andati	?andati =andati  (ID  >andati !41_D	et	f	\N
179958	andati	?andati =andati  (SgG  >andat !02_S	et	f	\N
179959	andati	?andati =andati  (SgG  >andatt !22_S	et	f	\N
179960	andati	?andati =andati  (IndPrPs_  >andattima !28_V	et	f	\N
179961	andati	?andati =andati  (ImpPrSg2  >andattima !28_V	et	f	\N
179974	saadati	?saadati =saadati  (ID  >saadati !41_D	et	f	\N
179975	saadati	?saadati =saadati  (SgG  >saadat !02_S	et	f	\N
179976	saadati	?saadati =saadati  (SgG  >saadatt !22_S	et	f	\N
179977	saadati	?saadati =saadati  (IndPrPs_  >saadattima !28_V	et	f	\N
179978	saadati	?saadati =saadati  (ImpPrSg2  >saadattima !28_V	et	f	\N
179997	värskev	?värskev =värske  (PtsPrPs  >värskema !27_V	et	f	\N
179999	värskev	?värskev =värskev  (SgN  >värskev !02_A	et	f	\N
180011	ravidav	?ravidav =ravidav  (SgN  >ravidav !02_A	et	f	\N
180018	toidust	toidust =toidu  (SgEl  >toit !22_S	et	f	\N
180019	toidust	toidust =toidus  (SgP  >toidus !09_S	et	f	\N
180020	toidust	toidust =toidus  (SgP  >toidune !10_A	et	f	\N
180021	toidust	"toidune %toidu  )NE_aA  <toit ;22_S	et	f	\N
180039	klientid	?klientid =klienti  (PlN  >klienti !01_S	et	f	\N
180040	seeda	?seeda =seeda  (SgN  >seeda !16_S	et	f	\N
180041	seeda	?seeda =seeda  (SgG  >seeda !16_S	et	f	\N
180042	seeda	?seeda =seeda  (IndPrPs_  >seedama !29_V	et	f	\N
179731	kasa	?kasa =kasa  (SgG  >kasa !17_S	et	f	\N
179732	kasa	?kasa =kasa  (SgP  >kasa !17_S	et	f	\N
179733	kasa	?kasa =kasa  (IndPrPs_  >kasama !27_V	et	f	\N
179734	kasa	?kasa =kasa  (ImpPrSg2  >kasama !27_V	et	f	\N
179735	sur	### sur	et	f	\N
179743	jurvilja	?jurvilja =jurvilja  (SgN  >jurvilja !16_S	et	f	\N
179744	jurvilja	?jurvilja =jurvilja  (SgG  >jurviljas !02_A	et	f	\N
179745	jurvilja	?jurvilja =jurvilja  (SgG  >jurvilja !16_S	et	f	\N
179757	ottan	?ottan =otta  (IndPrSg1  >ottama !29_V	et	f	\N
179758	ottan	?ottan =ottan  (SgN  >ottan !02_S	et	f	\N
179774	majanduskool	majanduskool =koo  (SgAd  >majandus+kubu !18_S	et	f	\N
179775	majanduskool	majanduskool =kool  (SgN  >majandus+kool !22_S	et	f	\N
179788	aseris	?aseris =aseri  (SgIn  >aseri !01_S	et	f	\N
179789	aseris	?aseris =aseri  (SgIn  >aser !02_S	et	f	\N
179790	aseris	?aseris =aseris  (SgN  >aseris !11_S	et	f	\N
179799	aseri	?aseri =aseri  (SgN  >aseri !01_S	et	f	\N
179801	aseri	?aseri =aseri  (SgG  >aseri !01_S	et	f	\N
179803	aseri	?aseri =aseri  (SgG  >aser !02_S	et	f	\N
179805	koryy	?koryy =koryy  (SgN  >koryy !26_S	et	f	\N
179806	koryy	?koryy =koryy  (SgG  >koryy !26_S	et	f	\N
179827	töögraatik	?töögraatik =töögraatik  (SgN  >töögraatik !02_S	et	f	\N
179828	töögraatik	?töögraatik =graatik  (SgN  >töö+graatik !02_S	et	f	\N
179854	täitevosakonnas	täitevosakonnas =konna  (SgIn  >täitev+osa+konn !22_S	et	f	\N
179855	täitevosakonnas	täitevosakonnas =osakonna  (SgIn  >täitev+osakond !22_S	et	f	\N
179856	politseikool	politseikool =koo  (SgAd  >politsei+kubu !18_S	et	f	\N
179857	politseikool	politseikool =kool  (SgN  >politsei+kool !22_S	et	f	\N
179869	yy	?yy =yy  (SgN  >yy !26_S	et	f	\N
179870	yy	?yy =yy  (SgG  >yy !26_S	et	f	\N
179880	töökohal	töökohal =koha  (SgAd  >töö+koha !17_S	et	f	\N
179881	töökohal	töökohal =koha  (SgAd  >töö+koht !22_S	et	f	\N
179882	töögrafikut	?töögrafikut =töögrafiku  (SgP  >töögrafik !02_S	et	f	\N
179883	töögrafikut	?töögrafikut =grafiku  (SgP  >töö+grafiku !01_S	et	f	\N
179884	töögrafikut	?töögrafikut =grafiku  (SgP  >töö+grafik !02_S	et	f	\N
179886	tpü-i	tpü-i =tpü  (SgG  >tpü !xx_Q	et	f	\N
179887	tpü-i	tpü-i =tpü  (SgP  >tpü !xx_Q	et	f	\N
179888	tpü-i	tpü-i =tpü  (SgAdt  >tpü !xx_Q	et	f	\N
179898	koollis	?koollis =koolli  (SgIn  >kooll !22_S	et	f	\N
179899	koollis	?koollis =koolli  (IndIpfSg3  >koollima !28_V	et	f	\N
179900	koollis	?koollis =koollis  (SgN  >koollis !09_S	et	f	\N
179904	puudmase	?puudmase =puudmase  (SgG  >puudmane !12~10_A	et	f	\N
179905	puudmase	?puudmase =dmase  (SgN  >puu+dmase !16_S	et	f	\N
179906	puudmase	?puudmase =dmase  (SgG  >puu+dmase !16_S	et	f	\N
179907	komi	komi =komi  (SgN  >komi !17_S	et	f	\N
179908	komi	komi =komi  (SgG  >komi !17_S	et	f	\N
179909	komi	komi =komi  (SgP  >komi !17_S	et	f	\N
179921	kiiri	kiiri =kiir  (PlP  >kiir !13_S	et	f	\N
179922	kiiri	kiiri =kiiri  (SgG  >kiir !22_S	et	f	\N
179923	kiiri	kiiri =kiiri  (SgP  >kiir !22_S	et	f	\N
179924	kiiri	kiiri =kiiri  (SgAdt  >kiir !22_S	et	f	\N
179937	tuletud	tuletud =tuletu  (PlN  >tuletu !01_AS	et	f	\N
179938	tuletud	"tuletu %tule  )TU2_kA  <tuli ;20_S	et	f	\N
179939	tuletud	tuletud =tuletu  (IndPrSg2  >tuletuma !27_V	et	f	\N
179948	nõudati	?nõudati =nõudati  (ID  >nõudati !41_D	et	f	\N
179949	nõudati	?nõudati =nõudati  (SgG  >nõudat !02_S	et	f	\N
179950	nõudati	?nõudati =nõudati  (SgG  >nõudatt !22_S	et	f	\N
179951	nõudati	?nõudati =nõudati  (IndPrPs_  >nõudattima !28_V	et	f	\N
179952	nõudati	?nõudati =nõudati  (ImpPrSg2  >nõudattima !28_V	et	f	\N
179953	nõudati	?nõudati =dati  (SgN  >nõu+dati !16_S	et	f	\N
179955	nõudati	?nõudati =dati  (SgG  >nõu+dati !16_S	et	f	\N
179956	nõudati	?nõudati =dati  (SgG  >nõu+datt !22_S	et	f	\N
179967	lasati	?lasati =lasa  (IndIpfIps  >lasama !27_V	et	f	\N
179968	lasati	?lasati =lasa  (IndIpfIps  >laskama !29_V	et	f	\N
179969	lasati	?lasati =lasati  (ID  >lasati !41_D	et	f	\N
179970	lasati	?lasati =lasati  (SgG  >lasat !02_S	et	f	\N
179971	lasati	?lasati =lasati  (SgG  >lasatt !22_S	et	f	\N
179972	lasati	?lasati =lasati  (IndPrPs_  >lasattima !28_V	et	f	\N
179973	lasati	?lasati =lasati  (ImpPrSg2  >lasattima !28_V	et	f	\N
180003	müüv	müüv =müü  (PtsPrPs  >müüma !38_V	et	f	\N
180004	müüv	müüv =müüv  (SgN  >müüv !02_A	et	f	\N
180005	müüv	"müüv %müü  )V_vA  <müüma ;38_V	et	f	\N
180006	pehmev	?pehmev =pehme  (PtsPrPs  >pehmema !27_V	et	f	\N
180007	pehmev	?pehmev =pehmev  (SgN  >pehmev !02_A	et	f	\N
180031	käsitsevad	käsitsevad =käsitse  (IndPrPl3  >käsitsema !27_V	et	f	\N
180032	käsitsevad	käsitsevad =käsitseva  (PlN  >käsitsev !02_A	et	f	\N
180034	käsitsevad	"käsitsev %käsitse  )V_vA  <käsitsema ;27_V	et	f	\N
180055	lakkamatult	lakkamatult =lakkamatu  (SgAbl  >lakkamatu !01_A	et	f	\N
180056	lakkamatult	"lakkamatu %lakka  )MATU_vA  <lakkama ;29_V	et	f	\N
180057	lakkamatult	lakkamatult =lakkamatult  (ID  >lakkamatult !41_D	et	f	\N
180058	lakkamatult	"lakkamatult %lakka  )MATULT_mD  <lakkama ;29_V	et	f	\N
180059	lakkamatult	"lakkamatult %lakkamatu  )LT_mD  <lakkamatu ;01_A	et	f	\N
179756	mobilltelefoni	?mobilltelefoni =mobilltelefoni  (SgAdt  >mobilltelefon !19_S	et	f	\N
179763	abigasa	?abigasa =abigasa  (SgN  >abigasa !16_S	et	f	\N
179764	abigasa	?abigasa =abigasa  (SgG  >abigasa !16_S	et	f	\N
179765	abigasa	?abigasa =gasa  (SgN  >abi+gasa !17_S	et	f	\N
179766	abigasa	?abigasa =gasa  (SgG  >abi+gasa !17_S	et	f	\N
179767	abigasa	?abigasa =gasa  (SgP  >abi+gasa !17_S	et	f	\N
179786	mõõtes	mõõtes =mõõt  (Ger  >mõõtma !34_V	et	f	\N
179787	mõõtes	mõõtes =mõõte  (SgIn  >mõõde !06_S	et	f	\N
179791	saadke	?saadke =saadke  (SgN  >saadke !06_S	et	f	\N
179792	saadke	?saadke =saadke  (SgG  >saadke !06_S	et	f	\N
179793	saadke	?saadke =saadke  (PlP  >saadk !22_S	et	f	\N
179794	saadke	?saadke =saadke  (IndPrPs_  >saadkema !27_V	et	f	\N
179795	saadke	?saadke =saadke  (ImpPrSg2  >saadkema !27_V	et	f	\N
179797	kesktänav	kesktänav =tänav  (SgN  >kesk+tänav !02_A	et	f	\N
179798	kesktänav	kesktänav =tänav  (SgN  >kesk+tänav !02_S	et	f	\N
179814	kaubakool	kaubakool =koo  (SgAd  >kauba+kubu !18_S	et	f	\N
179815	kaubakool	kaubakool =kool  (SgN  >kauba+kool !22_S	et	f	\N
179829	kuulutusest	kuulutusest =kuulutuse  (SgEl  >kuulutus !11_S	et	f	\N
179830	kuulutusest	"kuulutus %kuuluta  )US_vS  <kuulutama ;27_V	et	f	\N
179831	kuulutusest	"kuulutus %kuulu  )TUS1_aS  <kuuluma ;27_V	et	f	\N
179832	kuulutusest	"kuulutus %kuulu  )TUS2_aS  <kuuld ;22_S	et	f	\N
179833	kuulutusest	kuulutusest =kuulutuses  (SgP  >kuulutusene !12_A	et	f	\N
179834	kuulutusest	"kuulutusene %kuulutuse  )NE_aA  <kuulutus ;11_S	et	f	\N
179843	pühkepäeva	?pühkepäeva =pühkepäeva  (SgN  >pühkepäeva !16_S	et	f	\N
179844	pühkepäeva	?pühkepäeva =pühkepäeva  (SgG  >pühkepäeva !16_S	et	f	\N
179845	x-y	### x-y	et	f	\N
179853	konstäblina	?konstäblina =konstäbli  (SgEs  >konstäbli !01_S	et	f	\N
179862	muttonen	?muttonen =muttone  (IndPrSg1  >muttonema !27_V	et	f	\N
179863	muttonen	?muttonen =muttonen  (SgN  >muttonen !19_S	et	f	\N
179874	raja	raja =raja  (SgN  >raja !17_S	et	f	\N
179875	raja	raja =raja  (SgG  >raja !17_S	et	f	\N
179876	raja	raja =raja  (SgG  >rada !18_S	et	f	\N
179877	raja	raja =raja  (SgP  >raja !17_S	et	f	\N
179878	raja	raja =raja  (IndPrPs_  >rajama !27_V	et	f	\N
179879	raja	raja =raja  (ImpPrSg2  >rajama !27_V	et	f	\N
179893	18092000a	### 18092000a	et	f	\N
179895	geoloogia	geoloogia =geoloogia  (SgN  >geoloogia !01_S	et	f	\N
179896	geoloogia	geoloogia =geoloogia  (SgG  >geoloogia !01_S	et	f	\N
179914	lõpin	?lõpin =lõpi  (IndPrSg1  >lõpima !27_V	et	f	\N
179915	lõpin	?lõpin =lõpi  (IndPrSg1  >lõppima !28_V	et	f	\N
179916	lõpin	?lõpin =lõpin  (SgN  >lõpin !02_S	et	f	\N
179934	valeri	?valeri =valeri  (SgN  >valeri !01_S	et	f	\N
179935	valeri	?valeri =valeri  (SgG  >valeri !01_S	et	f	\N
179936	valeri	?valeri =valeri  (SgG  >valer !02_S	et	f	\N
179941	oktombri	?oktombri =oktombri  (SgN  >oktombri !01_S	et	f	\N
179942	oktombri	?oktombri =oktombri  (SgG  >oktombri !01_S	et	f	\N
179943	oktombri	?oktombri =oktombri  (SgG  >oktomber !02_S	et	f	\N
179944	oktombri	?oktombri =oktombri  (IndPrPs_  >oktombrima !28_V	et	f	\N
179945	oktombri	?oktombri =oktombri  (ImpPrSg2  >oktombrima !28_V	et	f	\N
179991	tekkiv	tekkiv =tekki  (PtsPrPs  >tekkima !27~28_V	et	f	\N
179992	tekkiv	tekkiv =tekkiv  (SgN  >tekkiv !02_A	et	f	\N
179993	tekkiv	"tekkiv %tekki  )V_vA  <tekkima ;27_V	et	f	\N
179994	tekkiv	"tekkiv %tekki  )V_vA  <tekkima ;28_V	et	f	\N
180008	ravitav	ravitav =ravi  (PtsPrIps  >ravima !27_V	et	f	\N
180009	ravitav	ravitav =ravitav  (SgN  >ravitav !02_A	et	f	\N
180010	ravitav	"ravitav %ravi  )TAV_vAS  <ravima ;27_V	et	f	\N
180015	toodetav	toodetav =toode  (PtsPrIps  >tootma !34_V	et	f	\N
180016	toodetav	toodetav =toodetav  (SgN  >toodetav !02_A	et	f	\N
180017	toodetav	"toodetav %toode  )TAV_vAS  <tootma ;34_V	et	f	\N
180089	prinsiipe	?prinsiipe =prinsiipe  (SgN  >prinsiipe !16_S	et	f	\N
180090	prinsiipe	?prinsiipe =prinsiipe  (SgG  >prinsiipe !16_S	et	f	\N
180091	prinsiipe	?prinsiipe =prinsiipe  (PlP  >prinsiip !22_S	et	f	\N
180128	laskti	?laskti =laskti  (SgN  >laskti !01_S	et	f	\N
180129	laskti	?laskti =laskti  (SgG  >laskti !01_S	et	f	\N
180130	laskti	?laskti =laskti  (SgG  >laskt !22_S	et	f	\N
180131	laskti	?laskti =laskti  (SgP  >laskt !22_S	et	f	\N
180132	laskti	?laskti =laskti  (SgAdt  >laskt !22_S	et	f	\N
180133	laskti	?laskti =laskti  (IndPrPs_  >lasktima !28_V	et	f	\N
180134	laskti	?laskti =laskti  (ImpPrSg2  >lasktima !28_V	et	f	\N
180140	müuv	?müuv =müuv  (SgN  >müuv !22_S	et	f	\N
180154	pestavat	pestavat =pes  (KvtPrIps  >pesema !36_V	et	f	\N
180155	pestavat	"pestav %pes  )TAV_vAS  <pesema ;36_V	et	f	\N
180177	kosmeetikavendeid	?kosmeetikavendeid =kosmeetikavendei  (PlN  >kosmeetikavendei !26_S	et	f	\N
180178	kosmeetikavendeid	?kosmeetikavendeid =kosmeetikavendei  (SgP  >kosmeetikavendei !26_S	et	f	\N
180179	kosmeetikavendeid	?kosmeetikavendeid =vende  (PlP  >kosmeetika+venne !06_S	et	f	\N
180180	kosmeetikavendeid	?kosmeetikavendeid =vendei  (PlN  >kosmeetika+vendei !26_S	et	f	\N
180181	kosmeetikavendeid	?kosmeetikavendeid =vendei  (SgP  >kosmeetika+vendei !26_S	et	f	\N
180182	kosmeetikavendeid	?kosmeetikavendeid =vendeid  (SgN  >kosmeetika+vendeid !22_S	et	f	\N
179995	värskendavad	värskendavad =värskenda  (IndPrPl3  >värskendama !27_V	et	f	\N
179996	värskendavad	värskendavad =värskendava  (PlN  >värskendav !02_A	et	f	\N
179998	värskendavad	"värskendav %värskenda  )V_vA  <värskendama ;27_V	et	f	\N
180025	ostetav	ostetav =oste  (PtsPrIps  >ostma !34_V	et	f	\N
180026	ostetav	ostetav =ostetav  (SgN  >ostetav !02_A	et	f	\N
180027	ostetav	"ostetav %oste  )TAV_vAS  <ostma ;34_V	et	f	\N
180033	luituvad	luituvad =luitu  (IndPrPl3  >luituma !27_V	et	f	\N
180035	luituvad	luituvad =luituva  (PlN  >luituv !02_A	et	f	\N
180036	luituvad	"luituv %luitu  )V_vA  <luituma ;27_V	et	f	\N
180044	vabaturgi	vabaturgi =turgi  (SgP  >vaba+turg !22_S	et	f	\N
180045	vabaturgi	vabaturgi =turgi  (SgAdt  >vaba+turg !22_S	et	f	\N
180048	järelt	järelt =järe  (PlAbl  >järg !22_S	et	f	\N
180049	järelt	järelt =järelt  (ID  >järelt !41_K	et	f	\N
180051	lakkamatud	lakkamatud =lakkamatu  (PlN  >lakkamatu !01_A	et	f	\N
180053	lakkamatud	"lakkamatu %lakka  )MATU_vA  <lakkama ;29_V	et	f	\N
180066	värskendavate	värskendavate =värskendava  (PlG  >värskendav !02_A	et	f	\N
180067	värskendavate	"värskendav %värskenda  )V_vA  <värskendama ;27_V	et	f	\N
180071	toodetavad	toodetavad =toodetava  (PlN  >toodetav !02_A	et	f	\N
180072	toodetavad	"toodetav %toode  )TAV_vAS  <tootma ;34_V	et	f	\N
180093	hirmust	hirmust =hirmu  (SgEl  >hirm !22_S	et	f	\N
180094	hirmust	hirmust =us  (SgP  >hirm+uks !14_S	et	f	\N
180095	värskendava	värskendava =värskendava  (SgG  >värskendav !02_A	et	f	\N
180096	värskendava	"värskendav %värskenda  )V_vA  <värskendama ;27_V	et	f	\N
180097	müüvat	müüvat =müü  (KvtPrPs  >müüma !38_V	et	f	\N
180098	müüvat	müüvat =müüva  (SgP  >müüv !02_A	et	f	\N
180099	müüvat	"müüv %müü  )V_vA  <müüma ;38_V	et	f	\N
180119	turunduseprintsiipe	?turunduseprintsiipe =turunduseprintsiipe  (SgN  >turunduseprintsiipe !16_S	et	f	\N
180120	turunduseprintsiipe	?turunduseprintsiipe =turunduseprintsiipe  (SgG  >turunduseprintsiipe !16_S	et	f	\N
180121	turunduseprintsiipe	?turunduseprintsiipe =turunduseprintsiipe  (PlP  >turunduseprintsiip !22_S	et	f	\N
180122	turunduseprintsiipe	?turunduseprintsiipe =eprintsiipe  (SgN  >turundus+eprintsiipe !16_S	et	f	\N
180123	turunduseprintsiipe	?turunduseprintsiipe =eprintsiipe  (SgG  >turundus+eprintsiipe !16_S	et	f	\N
180124	turunduseprintsiipe	?turunduseprintsiipe =eprintsiipe  (PlP  >turundus+eprintsiip !22_S	et	f	\N
180125	ebameeldivalt	ebameeldivalt =meeldiva  (SgAbl  >eba+meeldiv !02_A	et	f	\N
180126	ebameeldivalt	ebameeldivalt =meeldivalt  (ID  >eba+meeldivalt !41_D	et	f	\N
180127	ebameeldivalt	"eba+meeldivalt %meeldiva  )LT_mD  <eba+meeldiv ;02_A	et	f	\N
180138	kosmetikavahendeid	?kosmetikavahendeid =kosmetikavahendei  (PlN  >kosmetikavahendei !26_S	et	f	\N
180139	kosmetikavahendeid	?kosmetikavahendeid =kosmetikavahendei  (SgP  >kosmetikavahendei !26_S	et	f	\N
180141	sisteem	?sisteem =sisteem  (SgN  >sisteem !22_S	et	f	\N
180149	ostetavat	ostetavat =oste  (KvtPrIps  >ostma !34_V	et	f	\N
180150	ostetavat	ostetavat =ostetava  (SgP  >ostetav !02_A	et	f	\N
180151	ostetavat	"ostetav %oste  )TAV_vAS  <ostma ;34_V	et	f	\N
180156	ostetavaid	ostetavaid =ostetava  (PlP  >ostetav !02_A	et	f	\N
180157	ostetavaid	"ostetav %oste  )TAV_vAS  <ostma ;34_V	et	f	\N
180165	üelti	?üelti =üelti  (ID  >üelti !41_D	et	f	\N
180166	üelti	?üelti =üelti  (SgP  >üelt !22_S	et	f	\N
180167	üelti	?üelti =üelti  (SgAdt  >üelt !22_S	et	f	\N
180170	paidama	?paidama =paida  (Sup  >paidama !29_V	et	f	\N
180171	paidama	?paidama =paidama  (SgG  >paidam !02_S	et	f	\N
180172	paidama	?paidama =dama  (SgN  >pai+dama !17_S	et	f	\N
180173	paidama	?paidama =dama  (SgG  >pai+dama !17_S	et	f	\N
180174	paidama	?paidama =dama  (SgP  >pai+dama !17_S	et	f	\N
180187	hoijate	?hoijate =hoija  (PlG  >hoija !01_S	et	f	\N
180188	hoijate	?hoijate =hoija  (IndPrPl2  >hoijama !29_V	et	f	\N
180189	värvivaid	värvivaid =värviva  (PlP  >värviv !02_A	et	f	\N
180190	värvivaid	"värviv %värvi  )V_vA  <värvima ;28_V	et	f	\N
180191	saadeva	?saadeva =saadeva  (SgN  >saadeva !01_S	et	f	\N
180192	saadeva	?saadeva =saadeva  (SgG  >saadeva !01_S	et	f	\N
180193	saadeva	?saadeva =saadeva  (SgG  >saadev !02_A	et	f	\N
180201	värskendavat	värskendavat =värskenda  (KvtPrPs  >värskendama !27_V	et	f	\N
180202	värskendavat	värskendavat =värskendava  (SgP  >värskendav !02_A	et	f	\N
180203	värskendavat	"värskendav %värskenda  )V_vA  <värskendama ;27_V	et	f	\N
180233	sorteerimine	sorteerimine =sorteerimine  (SgN  >sorteerimine !12_S	et	f	\N
180234	sorteerimine	"sorteerimine %sorteeri  )MINE_vS  <sorteerima ;28_V	et	f	\N
180258	käsiti	?käsiti =käsi  (IndIpfIps  >käsima !27_V	et	f	\N
180259	käsiti	?käsiti =käsiti  (ID  >käsiti !41_D	et	f	\N
180260	käsiti	?käsiti =käsiti  (SgG  >käsit !02_S	et	f	\N
180262	käsiti	?käsiti =käsiti  (SgG  >käsitt !22_S	et	f	\N
180263	käsiti	?käsiti =käsiti  (IndPrPs_  >käsittima !28_V	et	f	\N
180265	käsiti	?käsiti =käsiti  (ImpPrSg2  >käsittima !28_V	et	f	\N
180270	tellimisel	tellimisel =tellimise  (SgAd  >tellimine !12_S	et	f	\N
180271	tellimisel	"tellimine %telli  )MINE_vS  <tellima ;28_V	et	f	\N
180297	haljastustööd	haljastustööd =töö  (PlN  >haljastus+töö !26_S	et	f	\N
180298	haljastustööd	haljastustööd =töö  (SgP  >haljastus+töö !26_S	et	f	\N
180014	tav-kesksõna	tav-kesksõna =sõna  (SgP  >tav-kesk+sõna !17_S	et	f	\N
180022	süüatav	?süüatav =süüata  (PtsPrPs  >süüatama !27_V	et	f	\N
180023	süüatav	?süüatav =süüatav  (SgN  >süüatav !02_A	et	f	\N
180024	süüatav	?süüatav =atav  (SgN  >süü+atav !02_A	et	f	\N
180028	avatav	avatav =ava  (PtsPrIps  >avama !27_V	et	f	\N
180029	avatav	avatav =avatav  (SgN  >avatav !02_A	et	f	\N
180030	avatav	"avatav %ava  )TAV_vAS  <avama ;27_V	et	f	\N
180037	tellimiseks	tellimiseks =tellimise  (SgTr  >tellimine !12_S	et	f	\N
180038	tellimiseks	"tellimine %telli  )MINE_vS  <tellima ;28_V	et	f	\N
180046	korista	korista =korista  (IndPrPs_  >koristama !27_V	et	f	\N
180047	korista	korista =korista  (ImpPrSg2  >koristama !27_V	et	f	\N
180050	lakkamatu	lakkamatu =lakkamatu  (SgN  >lakkamatu !01_A	et	f	\N
180052	lakkamatu	"lakkamatu %lakka  )MATU_vA  <lakkama ;29_V	et	f	\N
180054	lakkamatu	lakkamatu =lakkamatu  (SgG  >lakkamatu !01_A	et	f	\N
180068	raviv	raviv =ravi  (PtsPrPs  >ravima !27_V	et	f	\N
180069	raviv	raviv =raviv  (SgN  >raviv !02_A	et	f	\N
180070	raviv	"raviv %ravi  )V_vA  <ravima ;27_V	et	f	\N
180079	kingitustega	kingitustega =kingitus  (PlKom  >kingitus !11_S	et	f	\N
180080	kingitustega	"kingitus %kingi  )TUS1_aS  <kinkima ;28_V	et	f	\N
180081	kingitustega	"kingitus %kingi  )TUS2_aS  <kink ;22_S	et	f	\N
180088	peidub	?peidub =peidu  (IndPrSg3  >peiduma !27_V	et	f	\N
180100	niisutava	niisutava =niisutava  (SgG  >niisutav !02_A	et	f	\N
180101	niisutava	"niisutav %niisuta  )V_vA  <niisutama ;27_V	et	f	\N
180102	ravivaid	ravivaid =raviva  (PlP  >raviv !02_A	et	f	\N
180103	ravivaid	"raviv %ravi  )V_vA  <ravima ;27_V	et	f	\N
180135	värsendava	?värsendava =värsendava  (SgN  >värsendava !16_S	et	f	\N
180136	värsendava	?värsendava =värsendava  (SgG  >värsendav !02_A	et	f	\N
180137	värsendava	?värsendava =värsendava  (SgG  >värsendava !16_S	et	f	\N
180142	rikkub	### rikkub	et	f	\N
180162	printsiibe	?printsiibe =printsiibe  (SgN  >printsiibe !16_S	et	f	\N
180163	printsiibe	?printsiibe =printsiibe  (SgG  >printsiibe !16_S	et	f	\N
180164	printsiibe	?printsiibe =printsiibe  (PlP  >printsiib !22_S	et	f	\N
180195	sorteeriv	sorteeriv =sorteeri  (PtsPrPs  >sorteerima !28_V	et	f	\N
180196	sorteeriv	sorteeriv =sorteeriv  (SgN  >sorteeriv !02_A	et	f	\N
180197	sorteeriv	"sorteeriv %sorteeri  )V_vA  <sorteerima ;28_V	et	f	\N
180212	kasipestav	?kasipestav =kasipesta  (PtsPrPs  >kasipestama !27_V	et	f	\N
180213	kasipestav	?kasipestav =kasipestav  (SgN  >kasipestav !02_A	et	f	\N
180214	kasipestav	?kasipestav =ipestav  (SgN  >kas+ipestav !02_A	et	f	\N
180255	müüdav	müüdav =müü  (PtsPrIps  >müüma !38_V	et	f	\N
180256	müüdav	müüdav =müüdav  (SgN  >müüdav !02_A	et	f	\N
180257	müüdav	"müüdav %müü  )TAV_vAS  <müüma ;38_V	et	f	\N
180266	söödetav	söödetav =sööde  (PtsPrIps  >söötma !34_V	et	f	\N
180267	söödetav	söödetav =söödetav  (SgN  >söödetav !02_A	et	f	\N
180268	söödetav	"söödetav %sööde  )TAV_vAS  <söötma ;34_V	et	f	\N
180269	avadav	?avadav =avadav  (SgN  >avadav !02_A	et	f	\N
180291	karvase	karvase =karvase  (SgG  >karvane !10_A	et	f	\N
180292	karvase	"karvane %karva  )NE_aA  <karv ;22_S	et	f	\N
180293	karvase	karvase =ase  (SgN  >karv+ase !04_S	et	f	\N
180299	rakendust	rakendust =rakendus  (SgP  >rakendus !11_S	et	f	\N
180300	rakendust	"rakendus %rakenda  )US_vS  <rakendama ;27_V	et	f	\N
180314	tutvusta	tutvusta =tutvusta  (IndPrPs_  >tutvustama !27_V	et	f	\N
180315	tutvusta	tutvusta =tutvusta  (ImpPrSg2  >tutvustama !27_V	et	f	\N
180316	teakus	?teakus =teaku  (SgIn  >teaku !16_S	et	f	\N
180317	teakus	?teakus =teaku  (IndIpfSg3  >teakuma !28_V	et	f	\N
180318	teakus	?teakus =teakus  (SgN  >teakus !11~09_S	et	f	\N
180319	turundusdirektoor	?turundusdirektoor =turundusdirektoor  (SgN  >turundusdirektoor !22_S	et	f	\N
180320	turundusdirektoor	?turundusdirektoor =direktoor  (SgN  >turundus+direktoor !22_S	et	f	\N
180360	rõhutassüüdistasteeskles	### rõhutassüüdistasteeskles	et	f	\N
180361	ülemust	ülemust =ülemus  (SgP  >ülemus !11_S	et	f	\N
180362	ülemust	"ülemus %ülema  )US_aS  <ülem ;02_AS	et	f	\N
180363	ülemust	ülemust =us  (SgP  >ülem+uks !14_S	et	f	\N
180366	võtakse	?võtakse =võtakse  (SgG  >võtakne !02_A	et	f	\N
180367	teakse	?teakse =teakse  (SgN  >teakse !06_S	et	f	\N
180368	teakse	?teakse =teakse  (SgG  >teakne !02_A	et	f	\N
180369	teakse	?teakse =teakse  (SgG  >teakse !06_S	et	f	\N
180370	teakse	?teakse =teakse  (PlP  >teaks !22_S	et	f	\N
180371	teakse	?teakse =teakse  (IndPrPs_  >teaksema !27_V	et	f	\N
180372	teakse	?teakse =teakse  (ImpPrSg2  >teaksema !27_V	et	f	\N
180382	tüüta	tüüta =tüü  (SgAb  >tüü !26_S	et	f	\N
180383	tüüta	tüüta =tüüta  (IndPrPs_  >tüütama !29_V	et	f	\N
180384	tüüta	tüüta =tüüta  (ImpPrSg2  >tüütama !29_V	et	f	\N
180399	pärane	pärane =pärane  (SgN  >pärane !10_A	et	f	\N
180400	pärane	"pärane %pära  )NE_aA  <pära ;17_S	et	f	\N
180403	kond-	?kond- =kond  (SgN  >kond !22_S	et	f	\N
180405	poolmeetriline	poolmeetriline =meetriline  (SgN  >pool+meetriline !12_A	et	f	\N
180406	poolmeetriline	"pool+meetriline %meetri  )LINE_aA  <pool+meeter ;02_S	et	f	\N
180415	valkond	?valkond =valkond  (SgN  >valkond !22_S	et	f	\N
180043	seeda	?seeda =seeda  (ImpPrSg2  >seedama !29_V	et	f	\N
180076	töötamata	töötamata =tööta  (SupAb  >töötama !27_V	et	f	\N
180077	töötamata	töötamata =töötamata  (ID  >töötamata !41_A	et	f	\N
180078	töötamata	"töötamata %tööta  )MATA_vA  <töötama ;27_V	et	f	\N
180085	avatavad	avatavad =avatava  (PlN  >avatav !02_A	et	f	\N
180086	avatavad	"avatav %ava  )TAV_vAS  <avama ;27_V	et	f	\N
180087	avatavad	avatavad =tava  (PlN  >ava+tava !17_S	et	f	\N
180117	leiutud	leiutud =leiutu  (PlN  >leiutu !01_AS	et	f	\N
180118	leiutud	"leiutu %leiu  )TU2_kA  <leid ;22_S	et	f	\N
180152	tekiv	?tekiv =teki  (PtsPrPs  >tekima !27_V	et	f	\N
180153	tekiv	?tekiv =tekiv  (SgN  >tekiv !02_A	et	f	\N
180194	kataloogistte	### kataloogistte	et	f	\N
180198	opetav	?opetav =ope  (PtsPrIps  >opema !27_V	et	f	\N
180199	opetav	?opetav =opeta  (PtsPrPs  >opetama !27_V	et	f	\N
180200	opetav	?opetav =opetav  (SgN  >opetav !02_A	et	f	\N
180205	toodev	?toodev =toode  (PtsPrPs  >toodema !27_V	et	f	\N
180206	toodev	?toodev =toodev  (SgN  >toodev !02_A	et	f	\N
180207	komponentid	?komponentid =ponenti  (PlN  >kom+ponenti !01_S	et	f	\N
180209	käsipestav	?käsipestav =käsipesta  (PtsPrPs  >käsipestama !27_V	et	f	\N
180210	käsipestav	?käsipestav =käsipestav  (SgN  >käsipestav !02_A	et	f	\N
180211	käsipestav	?käsipestav =pestav  (SgN  >käsi+pestav !02_A	et	f	\N
180216	kasvatav	kasvatav =kasva  (PtsPrIps  >kasvama !28_V	et	f	\N
180218	kasvatav	kasvatav =kasvata  (PtsPrPs  >kasvatama !27_V	et	f	\N
180220	kasvatav	kasvatav =kasvatav  (SgN  >kasvatav !02_A	et	f	\N
180221	kasvatav	"kasvatav %kasva  )TAV_vAS  <kasvama ;28_V	et	f	\N
180222	kasvatav	"kasvatav %kasvata  )V_vA  <kasvatama ;27_V	et	f	\N
180224	söötav	?söötav =sööta  (PtsPrPs  >söötama !27_V	et	f	\N
180225	söötav	?söötav =söötav  (SgN  >söötav !02_A	et	f	\N
180226	tekitav	tekitav =teki  (PtsPrIps  >tekkima !28_V	et	f	\N
180227	tekitav	tekitav =tekita  (PtsPrPs  >tekitama !27_V	et	f	\N
180228	tekitav	tekitav =tekitav  (SgN  >tekitav !02_A	et	f	\N
180229	tekitav	"tekitav %teki  )TAV_vAS  <tekkima ;28_V	et	f	\N
180230	tekitav	"tekitav %tekita  )V_vA  <tekitama ;27_V	et	f	\N
180237	printsipid	?printsipid =printsipi  (PlN  >printsipi !01_S	et	f	\N
180238	printsipid	?printsipid =printsipi  (PlN  >printsip !02_S	et	f	\N
180239	printsipid	?printsipid =printsipi  (PlN  >printsipp !22_S	et	f	\N
180240	printsipid	?printsipid =printsipi  (IndPrSg2  >printsippima !28_V	et	f	\N
180275	raagiti	?raagiti =raagi  (IndIpfIps  >raakima !28_V	et	f	\N
180276	raagiti	?raagiti =raagiti  (ID  >raagiti !41_D	et	f	\N
180277	raagiti	?raagiti =raagiti  (SgG  >raagit !02_S	et	f	\N
180278	raagiti	?raagiti =raagiti  (SgG  >raagitt !22_S	et	f	\N
180279	raagiti	?raagiti =raagiti  (IndPrPs_  >raagittima !28_V	et	f	\N
180280	raagiti	?raagiti =raagiti  (ImpPrSg2  >raagittima !28_V	et	f	\N
180281	raagiti	?raagiti =iti  (SgN  >raag+iti !16_S	et	f	\N
180282	raagiti	?raagiti =iti  (SgG  >raag+iti !16_S	et	f	\N
180283	raagiti	?raagiti =iti  (SgG  >raag+itt !22_S	et	f	\N
180284	värskendavateta	värskendavateta =värskendava  (PlAb  >värskendav !02_A	et	f	\N
180285	värskendavateta	"värskendav %värskenda  )V_vA  <värskendama ;27_V	et	f	\N
180289	viimist	viimist =viimis  (SgP  >viimine !12?10_S	et	f	\N
180290	viimist	"viimine %vii  )MINE_vS  <viima ;38_V	et	f	\N
180307	hojast	?hojast =hoja  (SgEl  >hoja !17_S	et	f	\N
180308	hojast	?hojast =hojas  (SgP  >hojas !09_S	et	f	\N
180309	hojast	?hojast =hojas  (SgP  >hojane !10_A	et	f	\N
180331	tööotsija	tööotsija =otsija  (SgN  >töö+otsija !01_S	et	f	\N
180332	tööotsija	tööotsija =otsija  (SgG  >töö+otsija !01_S	et	f	\N
180333	tootmisliini	tootmisliini =lii  (SgTer  >tootmis+lii !26_S	et	f	\N
180334	tootmisliini	tootmisliini =liini  (SgG  >tootmis+liin !22_S	et	f	\N
180335	tootmisliini	tootmisliini =liini  (SgP  >tootmis+liin !22_S	et	f	\N
180336	tootmisliini	tootmisliini =liini  (SgAdt  >tootmis+liin !22_S	et	f	\N
180337	kehtestamisegakäivitamisega	?kehtestamisegakäivitamisega =kehtestamisegakäivitamise  (SgKom  >kehtestamisegakäivitamine !12_S	et	f	\N
180340	viisime	viisime =vii  (IndIpfPl1  >viima !38_V	et	f	\N
180341	viisime	viisime =ime  (SgN  >viis+ime !16_S	et	f	\N
180342	viisime	viisime =ime  (SgG  >viis+ime !16_S	et	f	\N
180345	kinga	kinga =kinga  (SgG  >king !22_S	et	f	\N
180346	kinga	kinga =kinga  (SgP  >king !22_S	et	f	\N
180347	kinga	kinga =kinga  (SgAdt  >king !22_S	et	f	\N
180348	varrukas	varrukas =varruka  (SgIn  >varrukas !02_S	et	f	\N
180349	varrukas	varrukas =varrukas  (SgN  >varrukas !02_S	et	f	\N
180357	tänavail	tänavail =tänava  (PlAd  >tänav !02_A	et	f	\N
180358	tänavail	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
180359	tänavail	tänavail =tänava  (PlAd  >tänav !02_S	et	f	\N
180373	hindakse	?hindakse =hindakse  (SgG  >hindakne !02_A	et	f	\N
180398	ndus	### ndus	et	f	\N
180402	liitelised	liitelised =liitelise  (PlN  >liiteline !12_A	et	f	\N
180404	liitelised	"liiteline %liite  )LINE_aA  <liide ;06_S	et	f	\N
180422	intervjueerijat	intervjueerijat =intervjueerija  (SgP  >intervjueerija !01_S	et	f	\N
180423	intervjueerijat	"intervjueerija %intervjueeri  )JA_vS  <intervjueerima ;28_V	et	f	\N
180060	hirmuses	hirmuses =hirmuse  (SgIn  >hirmus !02_A	et	f	\N
180061	hirmuses	hirmuses =use  (PlIn  >hirm+usk !22_S	et	f	\N
180062	karva	karva =karva  (ID  >karva !41_A	et	f	\N
180063	karva	karva =karva  (SgG  >karv !22_S	et	f	\N
180064	karva	karva =karva  (SgP  >karv !22_S	et	f	\N
180065	karva	karva =karva  (SgAdt  >karv !22_S	et	f	\N
180073	söödav	söödav =söö  (PtsPrIps  >sööma !38_V	et	f	\N
180074	söödav	söödav =söödav  (SgN  >söödav !02_A	et	f	\N
180075	söödav	"söödav %söö  )TAV_vAS  <sööma ;38_V	et	f	\N
180082	visata	visata =visa  (SgAb  >visa !17_A	et	f	\N
180083	visata	visata =visa  (Inf  >viskama !29_V	et	f	\N
180084	visata	visata =visa  (IndPrIps_  >viskama !29_V	et	f	\N
180092	jubeks	?jubeks =jube  (KndPrPs  >jubema !27_V	et	f	\N
180104	toodetavale	toodetavale =toodetava  (SgAll  >toodetav !02_A	et	f	\N
180105	toodetavale	"toodetav %toode  )TAV_vAS  <tootma ;34_V	et	f	\N
180106	söödavast	söödavast =söödava  (SgEl  >söödav !02_A	et	f	\N
180107	söödavast	"söödav %söö  )TAV_vAS  <sööma ;38_V	et	f	\N
180108	ostetava	ostetava =ostetava  (SgG  >ostetav !02_A	et	f	\N
180109	ostetava	"ostetav %oste  )TAV_vAS  <ostma ;34_V	et	f	\N
180110	rügisüsteemi	?rügisüsteemi =rügisüsteemi  (SgN  >rügisüsteemi !16_S	et	f	\N
180111	rügisüsteemi	?rügisüsteemi =rügisüsteemi  (SgG  >rügisüsteemi !16_S	et	f	\N
180112	rügisüsteemi	?rügisüsteemi =rügisüsteemi  (SgG  >rügisüsteem !22_S	et	f	\N
180113	rügisüsteemi	?rügisüsteemi =rügisüsteemi  (SgP  >rügisüsteem !22_S	et	f	\N
180114	rügisüsteemi	?rügisüsteemi =rügisüsteemi  (SgAdt  >rügisüsteem !22_S	et	f	\N
180115	rügisüsteemi	?rügisüsteemi =rügisüsteemi  (IndPrPs_  >rügisüsteemima !28_V	et	f	\N
180116	rügisüsteemi	?rügisüsteemi =rügisüsteemi  (ImpPrSg2  >rügisüsteemima !28_V	et	f	\N
180143	kästsi	?kästsi =kästsi  (ID  >kästsi !41_D	et	f	\N
180144	kästsi	?kästsi =kästsi  (SgG  >kästs !22_S	et	f	\N
180145	kästsi	?kästsi =kästsi  (SgP  >kästs !22_S	et	f	\N
180146	kästsi	?kästsi =kästsi  (SgAdt  >kästs !22_S	et	f	\N
180147	kästsi	?kästsi =kästsi  (IndPrPs_  >kästsima !28_V	et	f	\N
180148	kästsi	?kästsi =kästsi  (ImpPrSg2  >kästsima !28_V	et	f	\N
180158	väljatoodeldud	?väljatoodeldud =väljatoodeldu  (IndPrSg2  >väljatoodelduma !27_V	et	f	\N
180159	väljatoodeldud	?väljatoodeldud =väljatoodeldud  (ID  >väljatoodeldud !41_A	et	f	\N
180160	väljatoodeldud	?väljatoodeldud =toodel  (PtsPtIps  >välja+_tootlema !30_V	et	f	\N
180161	väljatoodeldud	?väljatoodeldud =toodeldu  (PlN  >välja+toodeldu !01_S	et	f	\N
180168	põdenema	?põdenema =põdene  (Sup  >põdenema !27_V	et	f	\N
180169	põdenema	?põdenema =põdenema  (SgG  >põdenem !02_A	et	f	\N
180175	krappama	?krappama =krappa  (Sup  >krappama !29_V	et	f	\N
180176	krappama	?krappama =krappama  (SgG  >krappam !02_A	et	f	\N
180204	müüav	?müüav =müüav  (SgN  >müüav !02_S	et	f	\N
180208	effekt	?effekt =effekt  (SgN  >effekt !22_S	et	f	\N
180231	mõetav	?mõetav =mõeta  (PtsPrPs  >mõetama !27_V	et	f	\N
180232	mõetav	?mõetav =mõetav  (SgN  >mõetav !02_A	et	f	\N
180241	läba	?läba =läba  (SgN  >läba !17_S	et	f	\N
180242	läba	?läba =läba  (SgG  >läba !17_S	et	f	\N
180243	läba	?läba =läba  (SgP  >läba !17_S	et	f	\N
180244	läba	?läba =läba  (IndPrPs_  >läbama !27_V	et	f	\N
180245	läba	?läba =läba  (ImpPrSg2  >läbama !27_V	et	f	\N
180246	hirmselt	?hirmselt =hirmse  (SgAbl  >hirmne !02_A	et	f	\N
180247	hirmselt	?hirmselt =hirmse  (SgAbl  >hirmse !06_S	et	f	\N
180248	hirmselt	?hirmselt =hirmse  (PlAbl  >hirms !22_S	et	f	\N
180249	hirmselt	?hirmselt =hirmselt  (ID  >hirmselt !41_D	et	f	\N
180272	am-12	### am-12	et	f	\N
180310	kokkulepimine	?kokkulepimine =kokkulepimine  (SgN  >kokkulepimine !12_S	et	f	\N
180311	kokkulepimine	?kokkulepimine =kokkulepimine  (PlP  >kokkulepimin !19_S	et	f	\N
180312	kokkulepimine	?kokkulepimine =lepimine  (SgN  >kokku+lepimine !12_S	et	f	\N
180313	kokkulepimine	?kokkulepimine =lepimine  (PlP  >kokku+lepimin !19_S	et	f	\N
180324	arbija	?arbija =arbija  (SgN  >arbija !01_S	et	f	\N
180326	arbija	?arbija =arbija  (SgG  >arbija !01_S	et	f	\N
180327	arbija	?arbija =arbija  (SgG  >arbijas !02_A	et	f	\N
180343	küsimustikukõmu	?küsimustikukõmu =küsimustikukõmu  (IndPrPs_  >küsimustikukõmuma !27_V	et	f	\N
180344	küsimustikukõmu	?küsimustikukõmu =küsimustikukõmu  (ImpPrSg2  >küsimustikukõmuma !27_V	et	f	\N
180350	krae	krae =krae  (SgN  >krae !26_S	et	f	\N
180351	krae	krae =krae  (SgG  >krae !26_S	et	f	\N
180352	järeldavadjagunevadhulguvad	?järeldavadjagunevadhulguvad =järeldavadjagunevadhulgu  (IndPrPl3  >järeldavadjagunevadhulguma !27_V	et	f	\N
180353	järeldavadjagunevadhulguvad	?järeldavadjagunevadhulguvad =järeldavadjagunevadhulguva  (PlN  >järeldavadjagunevadhulguv !02_A	et	f	\N
180354	järeldavadjagunevadhulguvad	?järeldavadjagunevadhulguvad =järeldavadjagunevadhulguva  (PlN  >järeldavadjagunevadhulguva !16_S	et	f	\N
180355	järeldavadjagunevadhulguvad	?järeldavadjagunevadhulguvad =davadjagunevadhulguva  (PlN  >järel+davadjagunevadhulguv !02_A	et	f	\N
180356	järeldavadjagunevadhulguvad	?järeldavadjagunevadhulguvad =davadjagunevadhulguva  (PlN  >järel+davadjagunevadhulguva !16_S	et	f	\N
180394	rahalisi	rahalisi =rahalisi  (PlP  >rahaline !12_A	et	f	\N
180395	rahalisi	"rahaline %raha  )LINE_aA  <raha ;17_S	et	f	\N
180183	välismalt	?välismalt =välisma  (SgAbl  >välisma !01_S	et	f	\N
180184	välismalt	?välismalt =välismalt  (ID  >välismalt !41_D	et	f	\N
180185	välismalt	?välismalt =malt  (SgN  >välis+malt !22_S	et	f	\N
180186	välismalt	?välismalt =smalt  (SgN  >väli+smalt !22_S	et	f	\N
180215	valismaale	?valismaale =valismaa  (SgAll  >valismaa !26_S	et	f	\N
180217	valismaale	?valismaale =valismaale  (SgN  >valismaale !16_S	et	f	\N
180219	valismaale	?valismaale =valismaale  (SgG  >valismaale !16_S	et	f	\N
180223	valismaale	?valismaale =valismaale  (PlP  >valismaal !22_S	et	f	\N
180235	katalogist	?katalogist =katalogis  (SgP  >katalogis !09_S	et	f	\N
180236	katalogist	?katalogist =katalogist  (SgN  >katalogist !22_S	et	f	\N
180250	teadeti	?teadeti =teade  (IndIpfIps  >teadema !27_V	et	f	\N
180251	teadeti	?teadeti =teadeti  (ID  >teadeti !41_D	et	f	\N
180252	teadeti	?teadeti =teadeti  (SgG  >teadett !22_S	et	f	\N
180253	teadeti	?teadeti =teadeti  (IndPrPs_  >teadettima !28_V	et	f	\N
180254	teadeti	?teadeti =teadeti  (ImpPrSg2  >teadettima !28_V	et	f	\N
180261	pesetav	?pesetav =peseta  (PtsPrPs  >pesetama !27_V	et	f	\N
180264	pesetav	?pesetav =pesetav  (SgN  >pesetav !02_A	et	f	\N
180273	hügistama	?hügistama =hügista  (Sup  >hügistama !27_V	et	f	\N
180274	hügistama	?hügistama =hügistama  (SgG  >hügistam !02_A	et	f	\N
180286	ületoodamise	?ületoodamise =ületoodamise  (SgG  >ületoodamine !12_S	et	f	\N
180287	ületoodamise	?ületoodamise =damise  (SgG  >üle+too+damine !10_A	et	f	\N
180288	ületoodamise	?ületoodamise =toodamise  (SgG  >üle+toodamine !12_S	et	f	\N
180294	harki	harki =harki  (ID  >harki !41_D	et	f	\N
180295	harki	harki =harki  (SgP  >hark !22_S	et	f	\N
180296	harki	harki =harki  (SgAdt  >hark !22_S	et	f	\N
180301	liibuvad	liibuvad =liibu  (IndPrPl3  >liibuma !27_V	et	f	\N
180302	liibuvad	liibuvad =liibuva  (PlN  >liibuv !02_A	et	f	\N
180303	liibuvad	"liibuv %liibu  )V_vA  <liibuma ;27_V	et	f	\N
180304	reostus	reostus =reostu  (IndIpfSg3  >reostuma !27_V	et	f	\N
180305	reostus	reostus =reostus  (SgN  >reostus !11~09_S	et	f	\N
180306	reostus	"reostus %reosta  )US_vS  <reostama ;27_V	et	f	\N
180321	üleolevüllatunud	?üleolevüllatunud =üleolevüllatu  (PtsPtPs  >üleolevüllatuma !27_V	et	f	\N
180322	üleolevüllatunud	?üleolevüllatunud =üleolevüllatunu  (PlN  >üleolevüllatunu !01_S	et	f	\N
180323	üleolevüllatunud	?üleolevüllatunud =üleolevüllatunu  (IndPrSg2  >üleolevüllatunuma !27_V	et	f	\N
180325	üleolevüllatunud	?üleolevüllatunud =üleolevüllatunud  (ID  >üleolevüllatunud !41_A	et	f	\N
180328	üleolevüllatunud	?üleolevüllatunud =olevüllatu  (PtsPtPs  >üle+_olevüllatuma !27_V	et	f	\N
180329	üleolevüllatunud	?üleolevüllatunud =olevüllatunu  (PlN  >üle+olevüllatunu !01_S	et	f	\N
180338	meelitamisega	meelitamisega =meelitamise  (SgKom  >meelitamine !12_S	et	f	\N
180339	meelitamisega	"meelitamine %meelita  )MINE_vS  <meelitama ;27_V	et	f	\N
180374	töölepingu	töölepingu =pingu  (SgG  >tööle+ping !22_S	et	f	\N
180375	töölepingu	töölepingu =pingu  (SgP  >tööle+ping !22_S	et	f	\N
180376	töölepingu	töölepingu =pingu  (SgAdt  >tööle+ping !22_S	et	f	\N
180377	töölepingu	töölepingu =lepingu  (SgG  >töö+leping !02_S	et	f	\N
180378	abitööd	abitööd =töö  (PlN  >abi+töö !26_S	et	f	\N
180379	abitööd	abitööd =töö  (SgP  >abi+töö !26_S	et	f	\N
180387	rusikasse	rusikasse =rusika  (SgIll  >rusikas !02_S	et	f	\N
180388	rusikasse	rusikasse =rusikas  (SgAdt  >rusikane !12_A	et	f	\N
180389	rusikasse	"rusikane %rusika  )NE_aA  <rusikas ;02_S	et	f	\N
180407	kokkutulemine	kokkutulemine =tulemine  (SgN  >kokku+tulemine !12_S	et	f	\N
180408	kokkutulemine	"kokku+tulemine %tulemi  )NE_aA  <kokku+tulem ;02_S	et	f	\N
180410	kujundamine	kujundamine =kujundamine  (SgN  >kujundamine !12_S	et	f	\N
180411	kujundamine	"kujundamine %kujunda  )MINE_vS  <kujundama ;27_V	et	f	\N
180412	lepping	?lepping =lepping  (SgN  >lepping !02_S	et	f	\N
180433	kõhklge	?kõhklge =kõhklge  (SgN  >kõhklge !06_S	et	f	\N
180434	kõhklge	?kõhklge =kõhklge  (SgG  >kõhklge !06_S	et	f	\N
180435	kõhklge	?kõhklge =kõhklge  (PlP  >kõhklg !22_S	et	f	\N
180436	kõhklge	?kõhklge =kõhklge  (IndPrPs_  >kõhklgema !27_V	et	f	\N
180437	kõhklge	?kõhklge =kõhklge  (ImpPrSg2  >kõhklgema !27_V	et	f	\N
180483	allkirjutakse	?allkirjutakse =allkirju  (IndPrIps  >allkirjuma !27_V	et	f	\N
180484	allkirjutakse	?allkirjutakse =allkirjutakse  (SgG  >allkirjutakne !02_A	et	f	\N
180485	allkirjutakse	?allkirjutakse =allkirjutakse  (PlP  >allkirjutaks !22_S	et	f	\N
180486	allkirjutakse	?allkirjutakse =kirjutakse  (SgG  >all+kirjutakne !02_A	et	f	\N
180487	allkirjutakse	?allkirjutakse =kirjutakse  (PlP  >all+kirjutaks !22_S	et	f	\N
180509	oldakse	?oldakse =oldakse  (SgG  >oldakne !02_A	et	f	\N
180536	uurinik	?uurinik =uurinik  (SgN  >uurinik !25_S	et	f	\N
180563	tutvuv	tutvuv =tutvu  (PtsPrPs  >tutvuma !27_V	et	f	\N
180564	tutvuv	tutvuv =tutvuv  (SgN  >tutvuv !02_A	et	f	\N
180565	tutvuv	"tutvuv %tutvu  )V_vA  <tutvuma ;27_V	et	f	\N
180566	buklett	?buklett =buklett  (SgN  >buklett !22_S	et	f	\N
180584	midage	?midage =mida  (ImpPrPl2  >midama !27_V	et	f	\N
180587	liikmene	liikmene =liikmene  (SgN  >liikmene !12~10_A	et	f	\N
180588	liikmene	"liikmene %liikme  )NE_aA  <liige ;05_S	et	f	\N
180596	ke	### ke	et	f	\N
180330	hoolitsemehoolime	?hoolitsemehoolime =hoolitsemehooli  (IndPrPl1  >hoolitsemehoolima !28_V	et	f	\N
180364	umbisikuliseks	umbisikuliseks =isikulise  (SgTr  >umb+isikuline !12_A	et	f	\N
180365	umbisikuliseks	"umb+isikuline %isiku  )LINE_aA  <umb+isik ;02_S	et	f	\N
180380	piinlikkust	piinlikkust =piinlikkus  (SgP  >piinlikkus !11~09_S	et	f	\N
180381	piinlikkust	"piinlikkus %piinlikku  )US_aS  <piinlik ;25_A	et	f	\N
180385	vihale	vihale =viha  (SgAll  >viha !17_SA	et	f	\N
180386	vihale	vihale =viha  (SgAll  >viht !22_S	et	f	\N
180390	lausetest	lausetest =lause  (PlEl  >lause !06_S	et	f	\N
180391	lausetest	lausetest =test  (SgN  >lause+test !22_S	et	f	\N
180392	lausetest	lausetest =e  (PlEl  >laus+esi !15_S	et	f	\N
180393	lausetest	lausetest =sete  (PlEl  >lau+sett !22_S	et	f	\N
180413	lepimine	?lepimine =lepimine  (SgN  >lepimine !12_S	et	f	\N
180414	lepimine	?lepimine =lepimine  (PlP  >lepimin !19_S	et	f	\N
180420	hakkage	?hakkage =age  (SgN  >hakk+age !16_S	et	f	\N
180421	hakkage	?hakkage =age  (SgG  >hakk+age !16_S	et	f	\N
180428	intervjueerijale	intervjueerijale =intervjueerija  (SgAll  >intervjueerija !01_S	et	f	\N
180429	intervjueerijale	"intervjueerija %intervjueeri  )JA_vS  <intervjueerima ;28_V	et	f	\N
180451	suhtlelemeoskus	?suhtlelemeoskus =suhtlelemeosku  (IndIpfSg3  >suhtlelemeoskuma !27_V	et	f	\N
180452	suhtlelemeoskus	?suhtlelemeoskus =suhtlelemeoskus  (SgN  >suhtlelemeoskus !11~09_S	et	f	\N
180454	suhtlelemeoskus	?suhtlelemeoskus =lelemeoskus  (SgN  >suht+lelemeoskus !11~09_S	et	f	\N
180474	taisajaga	?taisajaga =taisaja  (SgKom  >taisaja !01_S	et	f	\N
180475	taisajaga	?taisajaga =taisaja  (SgKom  >taisajas !02_A	et	f	\N
180476	taisajaga	?taisajaga =saja  (SgKom  >tai+saja !17_S	et	f	\N
180477	uhendust	?uhendust =uhendu  (SgEl  >uhendu !01_S	et	f	\N
180478	uhendust	?uhendust =uhendus  (SgP  >uhendus !11_S	et	f	\N
180480	seadatakse	?seadatakse =seadatakse  (SgG  >seadatakne !02_A	et	f	\N
180481	seadatakse	?seadatakse =seadatakse  (PlP  >seadataks !22_S	et	f	\N
180482	seadatakse	?seadatakse =datakse  (SgG  >sea+datakne !02_A	et	f	\N
180493	kirjandu	?kirjandu =kirjandu  (SgN  >kirjandu !01_S	et	f	\N
180494	kirjandu	?kirjandu =kirjandu  (SgG  >kirjandu !01_S	et	f	\N
180495	kirjandu	?kirjandu =kirjandu  (IndPrPs_  >kirjanduma !27_V	et	f	\N
180496	kirjandu	?kirjandu =kirjandu  (ImpPrSg2  >kirjanduma !27_V	et	f	\N
180517	poolemetrid	?poolemetrid =poolemetri  (PlN  >poolemetter !02_S	et	f	\N
180518	poolemetrid	?poolemetrid =metri  (PlN  >poole+metter !02_S	et	f	\N
180519	poolemetrid	?poolemetrid =emetri  (PlN  >pool+emetri !01_S	et	f	\N
180520	poolemetrid	?poolemetrid =emetri  (PlN  >pool+emetter !02_S	et	f	\N
180521	poolemetrid	?poolemetrid =emetri  (PlN  >pool+emeter !19_S	et	f	\N
180529	suureparane	?suureparane =suureparane  (SgN  >suureparane !12_A	et	f	\N
180530	suureparane	?suureparane =suureparane  (PlP  >suureparan !19_S	et	f	\N
180531	suureparane	?suureparane =parane  (SgN  >suure+parane !10_A	et	f	\N
180532	suureparane	?suureparane =eparane  (SgN  >suur+eparane !12_A	et	f	\N
180533	suureparane	?suureparane =eparane  (PlP  >suur+eparan !19_S	et	f	\N
180534	suureparane	?suureparane =reparane  (SgN  >suu+reparane !12_A	et	f	\N
180535	suureparane	?suureparane =reparane  (PlP  >suu+reparan !19_S	et	f	\N
180549	puudke	?puudke =puudke  (SgN  >puudke !06_S	et	f	\N
180550	puudke	?puudke =puudke  (SgG  >puudke !06_S	et	f	\N
180551	puudke	?puudke =puudke  (PlP  >puudk !22_S	et	f	\N
180552	puudke	?puudke =puudke  (IndPrPs_  >puudkema !27_V	et	f	\N
180553	puudke	?puudke =puudke  (ImpPrSg2  >puudkema !27_V	et	f	\N
180567	tuubitud	tuubitud =tuubi  (PtsPtIps  >tuupima !28_V	et	f	\N
180568	tuubitud	tuubitud =tuubitu  (PlN  >tuubitu !01_AS	et	f	\N
180569	tuubitud	"tuubitu %tuubi  )TU1_vS  <tuupima ;28_V	et	f	\N
180570	tuubitud	"tuubitu %tuubi  )TU2_kA  <tuub ;22_S	et	f	\N
180571	tuubitud	tuubitud =tuubitud  (ID  >tuubitud !41_A	et	f	\N
180572	tuubitud	"tuubitud %tuubi  )TUD_vA  <tuupima ;28_V	et	f	\N
180573	järeldavadjagunevad	?järeldavadjagunevad =järeldavadjaguneva  (PlN  >järeldavadjagunev !02_A	et	f	\N
180574	järeldavadjagunevad	?järeldavadjagunevad =järeldavadjaguneva  (PlN  >järeldavadjaguneva !16_S	et	f	\N
180575	järeldavadjagunevad	?järeldavadjagunevad =davadjaguneva  (PlN  >järel+davadjagunev !02_A	et	f	\N
180576	järeldavadjagunevad	?järeldavadjagunevad =davadjaguneva  (PlN  >järel+davadjaguneva !16_S	et	f	\N
180589	leppimine	leppimine =leppimine  (SgN  >leppimine !12_S	et	f	\N
180590	leppimine	"leppimine %leppi  )MINE_vS  <leppima ;28_V	et	f	\N
180599	kõhelge	kõhelge =kõhel  (ImpPrPl2  >kõhklema !30_V	et	f	\N
180600	kõhelge	kõhelge =kõhel  (ImpPrPl2  >kõhelema !31_V	et	f	\N
180614	seiadus	?seiadus =seiadu  (SgIn  >seiadu !01_S	et	f	\N
180615	seiadus	?seiadus =seiadu  (IndIpfSg3  >seiaduma !27_V	et	f	\N
180616	seiadus	?seiadus =seiadus  (SgN  >seiadus !11_S	et	f	\N
180619	konserdil	?konserdil =konserdi  (SgAd  >konserdi !01_S	et	f	\N
180620	konserdil	?konserdil =konserdi  (SgAd  >konserd !02_S	et	f	\N
180621	konserdil	?konserdil =konserdi  (SgAd  >konsert !22_S	et	f	\N
180634	suurendus	suurendus =suurendus  (SgN  >suurendus !11_S	et	f	\N
180635	suurendus	"suurendus %suurenda  )US_vS  <suurendama ;27_V	et	f	\N
180636	üüriline	üüriline =üüriline  (SgN  >üüriline !12_S	et	f	\N
180637	üüriline	"üüriline %üüri  )LINE_aA  <üür ;22_S	et	f	\N
180396	rahalisi	"rahaline %raha  )LINE_aA  <rahk ;22_S	et	f	\N
180397	nik	### nik	et	f	\N
180401	ng	### ng	et	f	\N
180409	üüring	?üüring =üüring  (SgN  >üüring !02_S	et	f	\N
180430	võimetes	võimetes =võime  (PlIn  >võime !06_S	et	f	\N
180431	võimetes	võimetes =me  (PlIn  >või+mesi !15_S	et	f	\N
180432	võimetes	võimetes =mete  (PlIn  >või+mett !22_S	et	f	\N
180438	hulgilaost	hulgilaost =lao  (SgEl  >hulgi+ladu !18_S	et	f	\N
180439	hulgilaost	hulgilaost =lao  (SgEl  >hulgi+lagu !18_S	et	f	\N
180440	hulgilaost	hulgilaost =laos  (SgP  >hulgi+laos !09_S	et	f	\N
180444	kirjatakse	kirjatakse =kirja  (IndPrIps  >kirjama !29_V	et	f	\N
180445	kirjatakse	kirjatakse =takse  (PlP  >kirja+taks !22_S	et	f	\N
180453	enesemõitlev	?enesemõitlev =enesemõitlev  (SgN  >enesemõitlev !02_A	et	f	\N
180455	enesemõitlev	?enesemõitlev =mõitlev  (SgN  >enese+mõitlev !02_A	et	f	\N
180460	pahepanetud	?pahepanetud =pahepanetu  (PlN  >pahepanetu !01_A	et	f	\N
180461	pahepanetud	?pahepanetud =pahepanetu  (IndPrSg2  >pahepanetuma !27_V	et	f	\N
180462	pahepanetud	?pahepanetud =pahepanetud  (ID  >pahepanetud !41_A	et	f	\N
180469	käivitamisega	käivitamisega =käivitamise  (SgKom  >käivitamine !12_S	et	f	\N
180470	käivitamisega	"käivitamine %käivita  )MINE_vS  <käivitama ;27_V	et	f	\N
180488	raamatuskogus	?raamatuskogus =raamatuskogu  (IndIpfSg3  >raamatuskoguma !27_V	et	f	\N
180489	raamatuskogus	?raamatuskogus =raamatuskogus  (SgN  >raamatuskogus !11?09_S	et	f	\N
180490	raamatuskogus	?raamatuskogus =skogu  (SgIn  >raamatu+skogu !17_S	et	f	\N
180491	raamatuskogus	?raamatuskogus =skogus  (SgN  >raamatu+skogus !02_A	et	f	\N
180492	raamatuskogus	?raamatuskogus =atuskogus  (SgN  >raam+atuskogus !11?09_S	et	f	\N
180497	piinlikus	piinlikus =piinliku  (SgIn  >piinlik !25_A	et	f	\N
180498	piinlikus	piinlikus =piinlikus  (SgN  >piinlikus !11_S	et	f	\N
180499	piinlikus	"piinlikus %piinliku  )US_aS  <piinlik ;25_A	et	f	\N
180510	solmides	?solmides =solmi  (PlIn  >solmi !16_S	et	f	\N
180511	solmides	?solmides =solmi  (PlIn  >solm !22_S	et	f	\N
180512	solmides	?solmides =solmi  (Ger  >solmima !28_V	et	f	\N
180515	õhkond	?õhkond =õhkond  (SgN  >õhkond !22_S	et	f	\N
180516	õhkond	?õhkond =ond  (SgN  >õhk+ond !22_S	et	f	\N
180537	kujundaja	kujundaja =kujundaja  (SgN  >kujundaja !01_S	et	f	\N
180538	kujundaja	"kujundaja %kujunda  )JA_vS  <kujundama ;27_V	et	f	\N
180539	kujundaja	kujundaja =kujundaja  (SgG  >kujundaja !01_S	et	f	\N
180559	rumale	?rumale =ruma  (SgAll  >ruma !17_S	et	f	\N
180560	rumale	?rumale =rumale  (IndPrPs_  >rumalema !27_V	et	f	\N
180561	rumale	?rumale =rumale  (ImpPrSg2  >rumalema !27_V	et	f	\N
180593	säilita	säilita =säili  (IndPrIps_  >säilima !28_V	et	f	\N
180594	säilita	säilita =säilita  (IndPrPs_  >säilitama !27_V	et	f	\N
180595	säilita	säilita =säilita  (ImpPrSg2  >säilitama !27_V	et	f	\N
180617	ehitustöötega	?ehitustöötega =ehitustööte  (SgKom  >ehitustööte !16_S	et	f	\N
180618	ehitustöötega	?ehitustöötega =tööte  (SgKom  >ehitus+tööde !06_S	et	f	\N
180629	tootnik	?tootnik =tootnik  (SgN  >tootnik !25_S	et	f	\N
180644	kõhkelge	### kõhkelge	et	f	\N
180648	loata	loata =loa  (SgAb  >luba !18_S	et	f	\N
180649	loata	loata =loa  (SgAb  >luga !18_S	et	f	\N
180669	ennustustmõistetav	?ennustustmõistetav =ennustustmõisteta  (PtsPrPs  >ennustustmõistetama !27_V	et	f	\N
180670	ennustustmõistetav	?ennustustmõistetav =ennustustmõistetav  (SgN  >ennustustmõistetav !02_A	et	f	\N
180692	hakkake	?hakkake =hakkake  (SgN  >hakkake !12_S	et	f	\N
180693	hakkake	?hakkake =ake  (SgN  >hakk+ake !06_S	et	f	\N
180715	loeks	loeks =loe  (SgTr  >lood !22_S	et	f	\N
180716	loeks	loeks =loe  (KndPrPs  >lugema !28_V	et	f	\N
180719	lobisemisega	lobisemisega =lobisemise  (SgKom  >lobisemine !12_S	et	f	\N
180720	lobisemisega	"lobisemine %lobise  )MINE_vS  <lobisema ;27_V	et	f	\N
180723	suureline	suureline =suureline  (SgN  >suureline !12_A	et	f	\N
180724	suureline	suureline =reline  (SgN  >suu+reline !10_A	et	f	\N
180725	suureline	"suu+reline %re  )LINE_aA  <suu+re ;26_S	et	f	\N
180769	pesupulbriti	?pesupulbriti =pesupulbri  (IndIpfIps  >pesupulbrima !28_V	et	f	\N
180770	pesupulbriti	?pesupulbriti =pesupulbriti  (ID  >pesupulbriti !41_D	et	f	\N
180771	pesupulbriti	?pesupulbriti =pesupulbriti  (SgG  >pesupulbritt !22_S	et	f	\N
180772	pesupulbriti	?pesupulbriti =pesupulbriti  (IndPrPs_  >pesupulbrittima !28_V	et	f	\N
180773	pesupulbriti	?pesupulbriti =pesupulbriti  (ImpPrSg2  >pesupulbrittima !28_V	et	f	\N
180774	pesupulbriti	?pesupulbriti =pulbriti  (SgG  >pesu+pulbrit !02_S	et	f	\N
180775	pesupulbriti	?pesupulbriti =pulbriti  (SgG  >pesu+pulbritt !22_S	et	f	\N
180789	harimatu	harimatu =harimatu  (SgN  >harimatu !01_A	et	f	\N
180790	harimatu	"harimatu %hari  )MATU_vA  <harima ;27_V	et	f	\N
180791	harimatu	harimatu =harimatu  (SgG  >harimatu !01_A	et	f	\N
180807	toodetavaid	toodetavaid =toodetava  (PlP  >toodetav !02_A	et	f	\N
180808	toodetavaid	"toodetav %toode  )TAV_vAS  <tootma ;34_V	et	f	\N
180827	haritu	haritu =haritu  (SgN  >haritu !01_AS	et	f	\N
180828	haritu	"haritu %hari  )TU1_vS  <harima ;27_V	et	f	\N
180829	haritu	haritu =haritu  (SgG  >haritu !01_AS	et	f	\N
180842	põhimõttetesse	?põhimõttetesse =põhimõttete  (PlIll  >põhimõttett !22_S	et	f	\N
180416	valkond	?valkond =ond  (SgN  >valk+ond !22_S	et	f	\N
180417	käskivat	käskivat =käski  (KvtPrPs  >käskima !28_V	et	f	\N
180418	käskivat	käskivat =käskiva  (SgP  >käskiv !02_A	et	f	\N
180419	käskivat	"käskiv %käski  )V_vA  <käskima ;28_V	et	f	\N
180427	vaatage	### vaatage	et	f	\N
180441	tootud	?tootud =tootu  (PlN  >tootu !01_A	et	f	\N
180442	tootud	?tootud =tootu  (IndPrSg2  >tootuma !27_V	et	f	\N
180443	tootud	?tootud =tootud  (ID  >tootud !41_A	et	f	\N
180446	juhtliku	?juhtliku =juhtliku  (SgN  >juhtliku !01_S	et	f	\N
180447	juhtliku	?juhtliku =juhtliku  (SgG  >juhtliku !01_S	et	f	\N
180448	juhtliku	?juhtliku =juhtliku  (SgG  >juhtlik !25_A	et	f	\N
180449	juhtliku	?juhtliku =juhtliku  (IndPrPs_  >juhtlikuma !27_V	et	f	\N
180450	juhtliku	?juhtliku =juhtliku  (ImpPrSg2  >juhtlikuma !27_V	et	f	\N
180456	voldnik	?voldnik =voldnik  (SgN  >voldnik !25_S	et	f	\N
180467	kehtestamisega	kehtestamisega =kehtestamise  (SgKom  >kehtestamine !12_S	et	f	\N
180468	kehtestamisega	"kehtestamine %kehtesta  )MINE_vS  <kehtestama ;27_V	et	f	\N
180479	tehekse	?tehekse =tehekse  (SgG  >tehekne !02_A	et	f	\N
180500	meeleparane	?meeleparane =meeleparane  (SgN  >meeleparane !12_A	et	f	\N
180501	meeleparane	?meeleparane =meeleparane  (PlP  >meeleparan !19_S	et	f	\N
180502	meeleparane	?meeleparane =rane  (SgN  >mee+lepa+rane !16_S	et	f	\N
180503	meeleparane	?meeleparane =rane  (SgG  >mee+lepa+rane !16_S	et	f	\N
180504	meeleparane	?meeleparane =parane  (SgN  >meele+parane !10_A	et	f	\N
180505	meeleparane	?meeleparane =leparane  (SgN  >mee+leparane !12_A	et	f	\N
180506	meeleparane	?meeleparane =leparane  (PlP  >mee+leparan !19_S	et	f	\N
180507	äbaõgustus	?äbaõgustus =äbaõgustu  (IndIpfSg3  >äbaõgustuma !27_V	et	f	\N
180508	äbaõgustus	?äbaõgustus =äbaõgustus  (SgN  >äbaõgustus !11~09_S	et	f	\N
180541	seitsepaivane	?seitsepaivane =seitsepaivane  (SgN  >seitsepaivane !12_A	et	f	\N
180542	seitsepaivane	?seitsepaivane =vane  (SgN  >seitse+pai+vane !16_S	et	f	\N
180543	seitsepaivane	?seitsepaivane =vane  (SgG  >seitse+pai+vane !16_S	et	f	\N
180544	seitsepaivane	?seitsepaivane =paivane  (SgN  >seitse+paivane !10_A	et	f	\N
180545	kuulake	kuulake =kuula  (ImpPrPl2  >kuulama !29_V	et	f	\N
180546	kuulake	kuulake =lake  (SgN  >kuu+lake !06_S	et	f	\N
180547	kuulake	"kuu+lake %la  )KE_dS  <kuu+la ;26_S	et	f	\N
180585	poolmeetrine	poolmeetrine =meetrine  (SgN  >pool+meetrine !12~10_A	et	f	\N
180586	poolmeetrine	"pool+meetrine %meetri  )NE_aA  <pool+meeter ;02_S	et	f	\N
180591	seitsmepäevane	seitsmepäevane =päevane  (SgN  >seitsme+päevane !10_A	et	f	\N
180592	seitsmepäevane	"seitsme+päevane %päeva  )NE_aA  <seitsme+päev ;22_S	et	f	\N
180597	kõhkle	kõhkle =kõhkle  (IndPrPs_  >kõhklema !30_V	et	f	\N
180598	kõhkle	kõhkle =kõhkle  (ImpPrSg2  >kõhklema !30_V	et	f	\N
180601	ladust	### ladust	et	f	\N
180602	saatumusel	?saatumusel =saatumuse  (SgAd  >saatumus !11_S	et	f	\N
180603	saatumusel	?saatumusel =umuse  (SgAd  >saat+umus !09_S	et	f	\N
180604	saatumusel	?saatumusel =umusel  (SgN  >saat+umusel !19_S	et	f	\N
180608	karikas	karikas =karika  (SgIn  >karikas !02_S	et	f	\N
180609	karikas	karikas =karikas  (SgN  >karikas !02_S	et	f	\N
180622	maklerist	?maklerist =makleri  (SgEl  >makleri !01_S	et	f	\N
180623	maklerist	?maklerist =makleri  (SgEl  >makler !02_S	et	f	\N
180624	maklerist	?maklerist =makleris  (SgP  >makleris !11_S	et	f	\N
180625	maklerist	?maklerist =maklerist  (SgN  >maklerist !22_S	et	f	\N
180650	piinlikust	piinlikust =piinliku  (SgEl  >piinlik !25_A	et	f	\N
180651	piinlikust	piinlikust =piinlikus  (SgP  >piinlikus !11_S	et	f	\N
180652	piinlikust	"piinlikus %piinliku  )US_aS  <piinlik ;25_A	et	f	\N
180666	juhtuse	?juhtuse =juhtuse  (SgG  >juhtus !11~09_S	et	f	\N
180667	juhtuse	?juhtuse =use  (SgN  >juht+use !16_S	et	f	\N
180668	juhtuse	?juhtuse =use  (SgG  >juht+use !16_S	et	f	\N
180671	hooajast	hooajast =aja  (SgEl  >hoo+aeg !22_S	et	f	\N
180672	hooajast	hooajast =ajas  (SgP  >hoo+ajane !10_A	et	f	\N
180673	hooajast	"hoo+ajane %aja  )NE_aA  <hoo+aeg ;22_S	et	f	\N
180687	poolemeetrine	poolemeetrine =meetrine  (SgN  >poole+meetrine !12~10_A	et	f	\N
180688	poolemeetrine	"poole+meetrine %meetri  )NE_aA  <poole+meeter ;02_S	et	f	\N
180697	lobisesid	lobisesid =lobise  (IndIpfSg2  >lobisema !27_V	et	f	\N
180698	lobisesid	lobisesid =lobise  (IndIpfPl3  >lobisema !27_V	et	f	\N
180699	tüütasid	tüütasid =tüüta  (IndIpfSg2  >tüütama !29_V	et	f	\N
180700	tüütasid	tüütasid =tüüta  (IndIpfPl3  >tüütama !29_V	et	f	\N
180703	kujandamine	?kujandamine =kujandamine  (SgN  >kujandamine !12_S	et	f	\N
180704	kujandamine	?kujandamine =kujandamine  (PlP  >kujandamin !19_S	et	f	\N
180705	aiamine	?aiamine =aiamine  (SgN  >aiamine !12_S	et	f	\N
180717	raamatukos	?raamatukos =raamatuko  (SgIn  >raamatuko !16_S	et	f	\N
180718	raamatukos	?raamatukos =atuko  (SgIn  >raam+atuko !16_S	et	f	\N
180726	kokkutulija	kokkutulija =tulija  (SgN  >kokku+tulija !01_S	et	f	\N
180727	kokkutulija	kokkutulija =tulija  (SgG  >kokku+tulija !01_S	et	f	\N
180728	kirjaline	kirjaline =kirjaline  (SgN  >kirjaline !12_A	et	f	\N
180729	kirjaline	"kirjaline %kirja  )LINE_aA  <kiri ;24_S	et	f	\N
180776	kulutav	kulutav =kulu  (PtsPrIps  >kuluma !27_V	et	f	\N
180777	kulutav	kulutav =kuluta  (PtsPrPs  >kulutama !27_V	et	f	\N
180424	hilinegi	hilinegi =hiline  (SgN^  >hiline !10_A	et	f	\N
180425	hilinegi	hilinegi =hiline  (IndPrPs_^  >hilinema !27_V	et	f	\N
180426	hilinegi	hilinegi =hiline  (ImpPrSg2^  >hilinema !27_V	et	f	\N
180457	tutavatud	?tutavatud =tutavatu  (PlN  >tutavatu !01_A	et	f	\N
180458	tutavatud	?tutavatud =tutavatu  (IndPrSg2  >tutavatuma !27_V	et	f	\N
180459	tutavatud	?tutavatud =tutavatud  (ID  >tutavatud !41_A	et	f	\N
180463	teadliküleolevüllatunud	?teadliküleolevüllatunud =teadliküleolevüllatu  (PtsPtPs  >teadliküleolevüllatuma !27_V	et	f	\N
180464	teadliküleolevüllatunud	?teadliküleolevüllatunud =teadliküleolevüllatunu  (PlN  >teadliküleolevüllatunu !01_S	et	f	\N
180465	teadliküleolevüllatunud	?teadliküleolevüllatunud =teadliküleolevüllatunu  (IndPrSg2  >teadliküleolevüllatunuma !27_V	et	f	\N
180466	teadliküleolevüllatunud	?teadliküleolevüllatunud =teadliküleolevüllatunud  (ID  >teadliküleolevüllatunud !41_A	et	f	\N
180471	järeldavad	järeldavad =järelda  (IndPrPl3  >järeldama !27_V	et	f	\N
180472	järeldavad	järeldavad =järeldava  (PlN  >järeldav !02_A	et	f	\N
180473	järeldavad	"järeldav %järelda  )V_vA  <järeldama ;27_V	et	f	\N
180513	kassa	kassa =kassa  (SgN  >kassa !16_S	et	f	\N
180514	kassa	kassa =kassa  (SgG  >kassa !16_S	et	f	\N
180522	kuueliigmeline	?kuueliigmeline =kuueliigmeline  (SgN  >kuueliigmeline !12_A	et	f	\N
180523	kuueliigmeline	?kuueliigmeline =kuueliigmeline  (PlP  >kuueliigmelin !19_S	et	f	\N
180524	kuueliigmeline	?kuueliigmeline =meline  (SgN  >kuue+liig+meline !10_A	et	f	\N
180525	kuueliigmeline	?kuueliigmeline =liigmeline  (SgN  >kuue+liigmeline !12_A	et	f	\N
180526	kuueliigmeline	?kuueliigmeline =liigmeline  (PlP  >kuue+liigmelin !19_S	et	f	\N
180527	kuueliigmeline	?kuueliigmeline =eliigmeline  (SgN  >kuu+eliigmeline !12_A	et	f	\N
180528	kuueliigmeline	?kuueliigmeline =eliigmeline  (PlP  >kuu+eliigmelin !19_S	et	f	\N
180540	aianik	?aianik =aianik  (SgN  >aianik !25_S	et	f	\N
180548	kõhklege	### kõhklege	et	f	\N
180554	veedetud	veedetud =veede  (PtsPtIps  >veetma !34_V	et	f	\N
180555	veedetud	veedetud =veedetu  (PlN  >veedetu !01_AS	et	f	\N
180556	veedetud	"veedetu %veede  )TU1_vS  <veetma ;34_V	et	f	\N
180557	veedetud	veedetud =veedetud  (ID  >veedetud !41_A	et	f	\N
180558	veedetud	"veedetud %veede  )TUD_vA  <veetma ;34_V	et	f	\N
180562	kuubok	?kuubok =kuubok  (SgN  >kuubok !02_S	et	f	\N
180577	süüdistakse	?süüdistakse =süüdistakse  (SgG  >süüdistakne !02_A	et	f	\N
180578	süüdistakse	?süüdistakse =süüdistakse  (PlP  >süüdistaks !22_S	et	f	\N
180579	süüdistakse	?süüdistakse =stakse  (SgN  >süüdi+stakse !06_S	et	f	\N
180580	süüdistakse	?süüdistakse =stakse  (SgG  >süüdi+stakne !02_A	et	f	\N
180581	süüdistakse	?süüdistakse =stakse  (SgG  >süüdi+stakse !06_S	et	f	\N
180582	süüdistakse	?süüdistakse =stakse  (PlP  >süüdi+staks !22_S	et	f	\N
180583	süüdistakse	?süüdistakse =distakse  (SgG  >süü+distakne !02_A	et	f	\N
180626	valija	valija =valija  (SgN  >valija !01_S	et	f	\N
180627	valija	"valija %vali  )JA_vS  <valima ;27_V	et	f	\N
180628	valija	valija =valija  (SgG  >valija !01_S	et	f	\N
180630	liikne	?liikne =liikne  (SgN  >liikne !02_A	et	f	\N
180631	liikne	?liikne =liikne  (PlP  >liikn !22_S	et	f	\N
180632	liikne	?liikne =liikne  (IndPrPs_  >liiknema !27_V	et	f	\N
180633	liikne	?liikne =liikne  (ImpPrSg2  >liiknema !27_V	et	f	\N
180640	leppiline	?leppiline =leppiline  (SgN  >leppiline !12_A	et	f	\N
180641	leppiline	?leppiline =leppiline  (PlP  >leppilin !19_S	et	f	\N
180642	päevane	päevane =päevane  (SgN  >päevane !10_A	et	f	\N
180643	päevane	"päevane %päeva  )NE_aA  <päev ;22_S	et	f	\N
180655	õhuline	õhuline =õhuline  (SgN  >õhuline !12_A	et	f	\N
180656	õhuline	"õhuline %õhu  )LINE_aA  <õhk ;22_S	et	f	\N
180661	üürija	üürija =üürija  (SgN  >üürija !01_S	et	f	\N
180662	üürija	"üürija %üüri  )JA_vS  <üürima ;28_V	et	f	\N
180663	üürija	üürija =üürija  (SgG  >üürija !01_S	et	f	\N
180685	vaideb	?vaideb =vaide  (IndPrSg3  >vaidema !27_V	et	f	\N
180730	aendus	?aendus =aendu  (SgIn  >aendu !01_S	et	f	\N
180731	aendus	?aendus =aendu  (IndIpfSg3  >aenduma !27_V	et	f	\N
180732	aendus	?aendus =aendus  (SgN  >aendus !11~09_S	et	f	\N
180733	seitsepäevane	seitsepäevane =päevane  (SgN  >seitse+päevane !10_A	et	f	\N
180734	seitsepäevane	"seitse+päevane %päeva  )NE_aA  <seitse+päev ;22_S	et	f	\N
180743	tüüdata	tüüdata =tüüda  (Inf  >tüütama !29_V	et	f	\N
180744	tüüdata	tüüdata =tüüda  (IndPrIps_  >tüütama !29_V	et	f	\N
180745	ideaalseks	ideaalseks =ideaalse  (SgTr  >ideaalne !02_A	et	f	\N
180746	ideaalseks	ideaalseks =seks  (SgN  >ideaal+seks !22_S	et	f	\N
180752	poolemetriline	?poolemetriline =poolemetriline  (SgN  >poolemetriline !12_A	et	f	\N
180753	poolemetriline	?poolemetriline =poolemetriline  (PlP  >poolemetrilin !19_S	et	f	\N
180754	poolemetriline	?poolemetriline =metriline  (SgN  >poole+metriline !12_A	et	f	\N
180755	poolemetriline	?poolemetriline =metriline  (PlP  >poole+metrilin !19_S	et	f	\N
180756	poolemetriline	?poolemetriline =emetriline  (SgN  >pool+emetriline !12_A	et	f	\N
180757	poolemetriline	?poolemetriline =emetriline  (PlP  >pool+emetrilin !19_S	et	f	\N
180758	kreemituub	?kreemituub =kreemituub  (SgN  >kreemituub !22_S	et	f	\N
180759	kreemituub	?kreemituub =ituub  (SgN  >kreem+ituub !22_S	et	f	\N
180763	v-	### v-	et	f	\N
180605	kvartalist	kvartalist =kvartali  (SgEl  >kvartal !02_S	et	f	\N
180606	kvartalist	kvartalist =kvartalis  (SgP  >kvartaline !12_A	et	f	\N
180607	kvartalist	"kvartaline %kvartali  )NE_aA  <kvartal ;02_S	et	f	\N
180610	tuupitud	?tuupitud =tuupitu  (PlN  >tuupitu !01_AS	et	f	\N
180611	tuupitud	?tuupitud =tuupitu  (IndPrSg2  >tuupituma !27_V	et	f	\N
180612	tuupitud	?tuupitud =tuupitud  (ID  >tuupitud !41_A	et	f	\N
180613	hooldamehoolitseme	?hooldamehoolitseme =hooldamehoolitse  (IndPrPl1  >hooldamehoolitsema !27_V	et	f	\N
180638	meeldimine	meeldimine =meeldimine  (SgN  >meeldimine !12_S	et	f	\N
180639	meeldimine	"meeldimine %meeldi  )MINE_vS  <meeldima ;27_V	et	f	\N
180678	kõmu	kõmu =kõmu  (SgN  >kõmu !17_S	et	f	\N
180679	kõmu	kõmu =kõmu  (SgG  >kõmu !17_S	et	f	\N
180680	kõmu	kõmu =kõmu  (SgP  >kõmu !17_S	et	f	\N
180689	kuueliikmeline	kuueliikmeline =liikmeline  (SgN  >kuue+liikmeline !12_A	et	f	\N
180690	kuueliikmeline	"kuue+liikmeline %liikme  )LINE_aA  <kuue+liige ;05_S	et	f	\N
180691	kokkutelek	?kokkutelek =telek  (SgN  >kokku+telek !02_S	et	f	\N
180694	tuubidud	?tuubidud =tuubidu  (PlN  >tuubidu !01_S	et	f	\N
180695	tuubidud	?tuubidud =tuubidu  (IndPrSg2  >tuubiduma !27_V	et	f	\N
180696	tuubidud	?tuubidud =tuubidud  (ID  >tuubidud !41_A	et	f	\N
180701	toodeng	?toodeng =toodeng  (SgN  >toodeng !02_S	et	f	\N
180702	toodeng	?toodeng =deng  (SgN  >too+deng !22_S	et	f	\N
180706	leppija	leppija =leppija  (SgN  >leppija !01_S	et	f	\N
180707	leppija	"leppija %leppi  )JA_vS  <leppima ;28_V	et	f	\N
180708	leppija	leppija =leppija  (SgG  >leppija !01_S	et	f	\N
180711	sõlmiks	sõlmiks =sõlmi  (SgTr  >sõlm !22_S	et	f	\N
180712	sõlmiks	sõlmiks =sõlmi  (PlTr  >sõlm !22_S	et	f	\N
180713	sõlmiks	sõlmiks =sõlmi  (KndPrPs  >sõlmima !28_V	et	f	\N
180714	sõlmiks	sõlmiks =iks  (SgN  >sõlm+iks !22_S	et	f	\N
180760	haisema	haisema =haise  (Sup  >haisema !28_V	et	f	\N
180761	haisema	haisema =haisema  (SgG  >haisem !02_A	et	f	\N
180762	haisema	"haisem %hai  )SEM_cA  <hai ;26_S	et	f	\N
180764	todetavad	?todetavad =todeta  (IndPrPl3  >todetama !27_V	et	f	\N
180765	todetavad	?todetavad =todetava  (PlN  >todetav !02_A	et	f	\N
180766	todetavad	?todetavad =todetava  (PlN  >todetava !16_S	et	f	\N
180781	tekkub	?tekkub =tekku  (IndPrSg3  >tekkuma !27_V	et	f	\N
180800	müüjal	müüjal =müüja  (SgAd  >müüja !01_S	et	f	\N
180801	müüjal	"müüja %müü  )JA_vS  <müüma ;38_V	et	f	\N
180805	ostjal	ostjal =ostja  (SgAd  >ostja !01_S	et	f	\N
180806	ostjal	"ostja %ost  )JA_vS  <ostma ;34_V	et	f	\N
180833	oletavasse	oletavasse =oletava  (SgIll  >oletav !02_A	et	f	\N
180834	oletavasse	"oletav %oleta  )V_vA  <oletama ;27_V	et	f	\N
180875	printsiipid	?printsiipid =printsiipi  (PlN  >printsiipi !16_S	et	f	\N
180876	ümbertöötlemis	?ümbertöötlemis =ümbertöötlemi  (SgIn  >ümbertöötlem !02_A	et	f	\N
180877	ümbertöötlemis	?ümbertöötlemis =ümbertöötlemis  (SgN  >ümbertöötlemis !09_S	et	f	\N
180878	ümbertöötlemis	?ümbertöötlemis =töötlemi  (SgIn  >ümber+töötlemi !01_S	et	f	\N
180879	ümbertöötlemis	?ümbertöötlemis =töötlemi  (SgIn  >ümber+töötlem !02_A	et	f	\N
180880	ümbertöötlemis	?ümbertöötlemis =töötlemis  (SgN  >ümber+töötlemis !11_S	et	f	\N
180881	annetu	annetu =annetu  (SgN  >annetu !01_A	et	f	\N
180882	annetu	annetu =annetu  (SgG  >annetu !01_A	et	f	\N
180883	käskiti	?käskiti =käskiti  (ID  >käskiti !41_D	et	f	\N
180884	käskiti	?käskiti =käskiti  (SgG  >käskit !02_S	et	f	\N
180885	käskiti	?käskiti =käskiti  (SgG  >käskitt !22_S	et	f	\N
180886	käskiti	?käskiti =käskiti  (IndPrPs_  >käskittima !28_V	et	f	\N
180887	käskiti	?käskiti =käskiti  (ImpPrSg2  >käskittima !28_V	et	f	\N
180888	käskiti	?käskiti =iti  (SgN  >käsk+iti !16_S	et	f	\N
180889	käskiti	?käskiti =iti  (SgG  >käsk+iti !16_S	et	f	\N
180890	käskiti	?käskiti =iti  (SgG  >käsk+itt !22_S	et	f	\N
180893	maijusmokk	?maijusmokk =maijusmokk  (SgN  >maijusmokk !22_S	et	f	\N
180894	maijusmokk	?maijusmokk =jusmokk  (SgN  >mai+jusmokk !22_S	et	f	\N
180908	haritamatu	haritamatu =haritamatu  (SgN  >haritamatu !01_A	et	f	\N
180909	haritamatu	"haritamatu %hari  )TAMATU_vA  <harima ;27_V	et	f	\N
180910	haritamatu	haritamatu =haritamatu  (SgG  >haritamatu !01_A	et	f	\N
180911	toodav	toodav =too  (PtsPrIps  >tooma !38_V	et	f	\N
180912	toodav	toodav =toodav  (SgN  >toodav !02_A	et	f	\N
180913	toodav	"toodav %too  )TAV_vAS  <tooma ;38_V	et	f	\N
180914	toodetava	toodetava =toodetava  (SgG  >toodetav !02_A	et	f	\N
180915	toodetava	"toodetav %toode  )TAV_vAS  <tootma ;34_V	et	f	\N
180916	müüdetav	?müüdetav =müüde  (PtsPrIps  >müüdema !27_V	et	f	\N
180917	müüdetav	?müüdetav =müüdeta  (PtsPrPs  >müüdetama !27_V	et	f	\N
180918	müüdetav	?müüdetav =müüdetav  (SgN  >müüdetav !02_A	et	f	\N
180929	pesev	pesev =pese  (PtsPrPs  >pesema !36_V	et	f	\N
180930	pesev	pesev =pesev  (SgN  >pesev !02_A	et	f	\N
180931	pesev	"pesev %pese  )V_vA  <pesema ;36_V	et	f	\N
180934	ootamata	ootamata =oota  (SupAb  >ootama !29_V	et	f	\N
180935	ootamata	ootamata =ootamata  (ID  >ootamata !41_A	et	f	\N
180936	ootamata	"ootamata %oota  )MATA_vA  <ootama ;29_V	et	f	\N
180941	pesupubrit	?pesupubrit =pubri  (SgP  >pesu+pubri !16_S	et	f	\N
180645	õppitud	?õppitud =õppitu  (PlN  >õppitu !01_AS	et	f	\N
180646	õppitud	?õppitud =õppitu  (IndPrSg2  >õppituma !27_V	et	f	\N
180647	õppitud	?õppitud =õppitud  (ID  >õppitud !41_A	et	f	\N
180653	õhupärane	õhupärane =pärane  (SgN  >õhu+pärane !10_A	et	f	\N
180654	õhupärane	"õhu+pärane %pära  )NE_aA  <õhu+pära ;17_S	et	f	\N
180657	suuremine	?suuremine =suuremine  (SgN  >suuremine !12_S	et	f	\N
180658	suuremine	?suuremine =suuremine  (PlP  >suuremin !19_S	et	f	\N
180659	suuremine	?suuremine =emine  (SgN  >suur+emine !10_A	et	f	\N
180660	suuremine	?suuremine =remine  (SgN  >suu+remine !10_A	et	f	\N
180664	rumaluse	rumaluse =rumaluse  (SgG  >rumalus !11_S	et	f	\N
180665	rumaluse	"rumalus %rumala  )US_aS  <rumal ;02_A	et	f	\N
180674	õpetud	?õpetud =õpe  (PtsPtIps  >õpema !27_V	et	f	\N
180675	õpetud	?õpetud =õpetu  (PlN  >õpetu !01_A	et	f	\N
180676	õpetud	?õpetud =õpetu  (IndPrSg2  >õpetuma !27_V	et	f	\N
180677	õpetud	?õpetud =õpetud  (ID  >õpetud !41_A	et	f	\N
180681	meelepärast	meelepärast =meelepärast  (ID  >meele+pärast !41_D	et	f	\N
180682	meelepärast	meelepärast =pära  (SgEl  >meele+pära !17_S	et	f	\N
180683	meelepärast	meelepärast =päras  (SgP  >meele+pärane !10_A	et	f	\N
180684	meelepärast	"meele+pärane %pära  )NE_aA  <meele+pära ;17_S	et	f	\N
180686	öeldek	?öeldek =öeldek  (SgN  >öeldek !02_S	et	f	\N
180709	pähele	?pähele =pähele  (IndPrPs_  >pähelema !31~27_V	et	f	\N
180710	pähele	?pähele =pähele  (ImpPrSg2  >pähelema !31~27_V	et	f	\N
180721	pigista	pigista =pigista  (IndPrPs_  >pigistama !27_V	et	f	\N
180722	pigista	pigista =pigista  (ImpPrSg2  >pigistama !27_V	et	f	\N
180735	veetud	veetud =vee  (PtsPtIps  >vedama !28_V	et	f	\N
180736	veetud	veetud =veetu  (PlN  >veetu !01_SA	et	f	\N
180737	veetud	"veetu %vee  )TU1_vS  <vedama ;28_V	et	f	\N
180738	veetud	"veetud %vee  )TUD_vA  <vedama ;28_V	et	f	\N
180739	haka	?haka =haka  (SgN  >haka !16_S	et	f	\N
180740	haka	?haka =haka  (SgG  >haka !16_S	et	f	\N
180741	haka	?haka =haka  (IndPrPs_  >hakama !27_V	et	f	\N
180742	haka	?haka =haka  (ImpPrSg2  >hakama !27_V	et	f	\N
180747	pigistatud	pigistatud =pigista  (PtsPtIps  >pigistama !27_V	et	f	\N
180748	pigistatud	pigistatud =pigistatu  (PlN  >pigistatu !01_S	et	f	\N
180749	pigistatud	"pigistatu %pigista  )TU1_vS  <pigistama ;27_V	et	f	\N
180750	pigistatud	pigistatud =pigistatud  (ID  >pigistatud !41_A	et	f	\N
180751	pigistatud	"pigistatud %pigista  )TUD_vA  <pigistama ;27_V	et	f	\N
180802	laistud	?laistud =laistu  (PlN  >laistu !01_S	et	f	\N
180803	laistud	?laistud =laistu  (IndPrSg2  >laistuma !27_V	et	f	\N
180804	laistud	?laistud =laistud  (ID  >laistud !41_A	et	f	\N
180809	müüvalt	müüvalt =müüva  (SgAbl  >müüv !02_A	et	f	\N
180810	müüvalt	"müüv %müü  )V_vA  <müüma ;38_V	et	f	\N
180811	müüvalt	müüvalt =müüvalt  (ID  >müüvalt !41_D	et	f	\N
180812	müüvalt	"müüvalt %müü  )VALT_mD  <müüma ;38_V	et	f	\N
180813	müüvalt	"müüvalt %müüva  )LT_mD  <müüv ;02_A	et	f	\N
180817	ümbertöötmise	?ümbertöötmise =ümbertöötmise  (SgG  >ümbertöötmine !12_A	et	f	\N
180818	ümbertöötmise	?ümbertöötmise =töötmise  (SgG  >ümber+töötmine !12?10_S	et	f	\N
180824	õnnetu	õnnetu =õnnetu  (SgN  >õnnetu !01_A	et	f	\N
180825	õnnetu	"õnnetu %õnne  )TU2_kA  <õnn ;22_S	et	f	\N
180826	õnnetu	õnnetu =õnnetu  (SgG  >õnnetu !01_A	et	f	\N
180830	toodetavat	toodetavat =toode  (KvtPrIps  >tootma !34_V	et	f	\N
180831	toodetavat	toodetavat =toodetava  (SgP  >toodetav !02_A	et	f	\N
180832	toodetavat	"toodetav %toode  )TAV_vAS  <tootma ;34_V	et	f	\N
180843	müümise	müümise =müümise  (SgG  >müümine !12?10_S	et	f	\N
180845	müümise	"müümine %müü  )MINE_vS  <müüma ;38_V	et	f	\N
180873	listav	?listav =lista  (PtsPrPs  >listama !29_V	et	f	\N
180874	listav	?listav =listav  (SgN  >listav !02_A	et	f	\N
180898	keemiavahendinel	?keemiavahendinel =vahendine  (PlAd  >keemia+vahendin !19_S	et	f	\N
180919	lisatav	lisatav =lisa  (PtsPrIps  >lisama !27_V	et	f	\N
180920	lisatav	lisatav =lisatav  (SgN  >lisatav !02_A	et	f	\N
180921	lisatav	"lisatav %lisa  )TAV_vAS  <lisama ;27_V	et	f	\N
180979	majapidamistarve	majapidamistarve =arve  (SgN  >maja+pidamist+arve !06_S	et	f	\N
180980	majapidamistarve	majapidamistarve =arve  (SgG  >maja+pidamist+arve !06_S	et	f	\N
180981	majapidamistarve	majapidamistarve =arve  (PlP  >maja+pidamist+arv !22_S	et	f	\N
180982	majapidamistarve	majapidamistarve =tarve  (SgN  >maja+pidamis+tarve !06_S	et	f	\N
180998	töökust	töökust =töökus  (SgP  >töökus !11~09_S	et	f	\N
180999	töökust	"töökus %tööka  )US_aS  <töökas ;02_A	et	f	\N
181001	töökust	töökust =kus  (SgP  >töö+kusi !20_S	et	f	\N
181019	tähtaega	tähtaega =aega  (SgP  >täht+aeg !22_S	et	f	\N
181020	tähtaega	tähtaega =aega  (SgAdt  >täht+aeg !22_S	et	f	\N
181025	omastavasse	omastavasse =omastava  (SgIll  >omastav !02_A	et	f	\N
181026	omastavasse	"omastav %omasta  )V_vA  <omastama ;27_V	et	f	\N
181033	hilinemine	hilinemine =hilinemine  (SgN  >hilinemine !12_S	et	f	\N
181034	hilinemine	"hilinemine %hiline  )MINE_vS  <hilinema ;27_V	et	f	\N
181047	karin	?karin =kari  (IndPrSg1  >karima !27_V	et	f	\N
181048	karin	?karin =karin  (SgN  >karin !02_S	et	f	\N
180767	neiult	neiult =neiu  (SgAbl  >neiu !16_S	et	f	\N
180768	neiult	neiult =neiu  (SgAbl  >neid !22_S	et	f	\N
180785	onnetu	?onnetu =onnetu  (SgN  >onnetu !01_A	et	f	\N
180786	onnetu	?onnetu =onnetu  (SgG  >onnetu !01_A	et	f	\N
180787	onnetu	?onnetu =onnetu  (IndPrPs_  >onnetuma !27_V	et	f	\N
180788	onnetu	?onnetu =onnetu  (ImpPrSg2  >onnetuma !27_V	et	f	\N
180814	kahjustav	kahjustav =kahjusta  (PtsPrPs  >kahjustama !27_V	et	f	\N
180815	kahjustav	kahjustav =kahjustav  (SgN  >kahjustav !02_A	et	f	\N
180816	kahjustav	"kahjustav %kahjusta  )V_vA  <kahjustama ;27_V	et	f	\N
180819	töödeldud	töödeldud =töödel  (PtsPtIps  >töötlema !30_V	et	f	\N
180820	töödeldud	töödeldud =töödeldu  (PlN  >töödeldu !01_S	et	f	\N
180821	töödeldud	"töödeldu %töödel  )TU1_vS  <töötlema ;30_V	et	f	\N
180822	töödeldud	töödeldud =töödeldud  (ID  >töödeldud !41_A	et	f	\N
180823	töödeldud	"töödeldud %töödel  )TUD_vA  <töötlema ;30_V	et	f	\N
180857	olevasse	olevasse =oleva  (SgIll  >olev !02_A	et	f	\N
180858	olevasse	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
180891	uudisimulik	?uudisimulik =uudisimulik  (SgN  >uudisimulik !25_A	et	f	\N
180892	uudisimulik	?uudisimulik =imulik  (SgN  >uudis+imulik !25_A	et	f	\N
180932	kahjuv	?kahjuv =kahju  (PtsPrPs  >kahjuma !27_V	et	f	\N
180933	kahjuv	?kahjuv =kahjuv  (SgN  >kahjuv !02_A	et	f	\N
180937	hüppatama	?hüppatama =hüppata  (Sup  >hüppatama !27_V	et	f	\N
180938	hüppatama	?hüppatama =hüppatama  (SgG  >hüppatam !02_A	et	f	\N
180945	pohimotteid	?pohimotteid =pohimottei  (PlN  >pohimottei !26_S	et	f	\N
180946	pohimotteid	?pohimotteid =pohimottei  (SgP  >pohimottei !26_S	et	f	\N
180951	kingitusetega	### kingitusetega	et	f	\N
180956	oodatu	oodatu =oodatu  (SgN  >oodatu !01_S	et	f	\N
180957	oodatu	"oodatu %ooda  )TU1_vS  <ootama ;29_V	et	f	\N
180958	oodatu	oodatu =oodatu  (SgG  >oodatu !01_S	et	f	\N
180959	lissaks	?lissaks =lissa  (SgTr  >lissa !16_S	et	f	\N
180960	lissaks	?lissaks =lissa  (KndPrPs  >lissama !29_V	et	f	\N
180967	vastavatesse	vastavatesse =vastava  (PlIll  >vastav !02_A	et	f	\N
180968	vastavatesse	"vastav %vasta  )V_vA  <vastama ;29_V	et	f	\N
180969	majapidamistarvete	majapidamistarvete =e  (PlG  >maja+pidamist+arv+esi !15_S	et	f	\N
180970	majapidamistarvete	majapidamistarvete =arve  (PlG  >maja+pidamist+arve !06_S	et	f	\N
180971	majapidamistarvete	majapidamistarvete =tarve  (PlG  >maja+pidamis+tarve !06_S	et	f	\N
181031	reisijad	reisijad =reisija  (PlN  >reisija !01_S	et	f	\N
181032	reisijad	"reisija %reisi  )JA_vS  <reisima ;28_V	et	f	\N
181045	tööstuspiirkonnas	tööstuspiirkonnas =konna  (SgIn  >tööstus+piir+konn !22_S	et	f	\N
181046	tööstuspiirkonnas	tööstuspiirkonnas =piirkonna  (SgIn  >tööstus+piirkond !22_S	et	f	\N
181061	keetmata	keetmata =keet  (SupAb  >keetma !34_V	et	f	\N
181062	keetmata	keetmata =keetmata  (ID  >keetmata !41_A	et	f	\N
181063	keetmata	"keetmata %keet  )MATA_vA  <keetma ;34_V	et	f	\N
181084	villane	villane =villane  (SgN  >villane !10_A	et	f	\N
181085	villane	"villane %villa  )NE_aA  <villa ;16_S	et	f	\N
181086	villane	"villane %villa  )NE_aA  <vill ;22_S	et	f	\N
181105	õpema	?õpema =õpe  (Sup  >õpema !27_V	et	f	\N
181106	õpema	?õpema =õpema  (SgG  >õpem !02_A	et	f	\N
181109	lihsad	?lihsad =lihsa  (PlN  >lihsa !16_S	et	f	\N
181110	lihsad	?lihsad =lihsa  (IndPrSg2  >lihsama !29_V	et	f	\N
181137	võrreldades	?võrreldades =võrrelda  (Ger  >võrreldama !27_V	et	f	\N
181160	saavutust	saavutust =saavutus  (SgP  >saavutus !11_S	et	f	\N
181161	saavutust	"saavutus %saavuta  )US_vS  <saavutama ;27_V	et	f	\N
181182	kurbusist	kurbusist =kurbusi  (PlEl  >kurbus !11_S	et	f	\N
181183	kurbusist	"kurbus %kurb  )US_aS  <kurb ;22_A	et	f	\N
181203	maakonnana	maakonnana =maakonna  (SgEs  >maakond !22_S	et	f	\N
181204	maakonnana	maakonnana =konna  (SgEs  >maa+konn !22_S	et	f	\N
181211	passita	passita =passi  (SgAb  >pass !22_S	et	f	\N
181212	passita	passita =passi  (IndPrIps_  >passima !28_V	et	f	\N
181213	passita	passita =passita  (IndPrPs_  >passitama !27_V	et	f	\N
181214	passita	passita =passita  (ImpPrSg2  >passitama !27_V	et	f	\N
181221	ettvaatlikud	?ettvaatlikud =ettvaatliku  (PlN  >ettvaatlik !25_A	et	f	\N
181222	ettvaatlikud	?ettvaatlikud =ettvaatliku  (IndPrSg2  >ettvaatlikuma !27_V	et	f	\N
181237	lennukuga	?lennukuga =lennuku  (SgKom  >lennuku !01_S	et	f	\N
181238	lennukuga	?lennukuga =kuga  (SgN  >lennu+kuga !17_S	et	f	\N
181239	lennukuga	?lennukuga =kuga  (SgG  >lennu+kuga !17_S	et	f	\N
181240	lennukuga	?lennukuga =kuga  (SgP  >lennu+kuga !17_S	et	f	\N
181246	3selles	selles =selle  (SgIn  >see !00_P	et	f	\N
181248	3selles	selles =selle  (PlIn  >sell !22_S	et	f	\N
181252	resijad	?resijad =resija  (PlN  >resija !01_S	et	f	\N
181253	resijad	?resijad =resija  (PlN  >resijas !02_A	et	f	\N
181264	vaatamisväärsusta	?vaatamisväärsusta =vaatamisväärsusta  (SgN  >vaatamisväärsusta !16_S	et	f	\N
181265	vaatamisväärsusta	?vaatamisväärsusta =vaatamisväärsusta  (SgG  >vaatamisväärsusta !16_S	et	f	\N
181270	vaatamisväärsusta	?vaatamisväärsusta =vaatamisväärsusta  (IndPrPs_  >vaatamisväärsustama !27_V	et	f	\N
181271	vaatamisväärsusta	?vaatamisväärsusta =vaatamisväärsusta  (ImpPrSg2  >vaatamisväärsustama !27_V	et	f	\N
180778	kulutav	kulutav =kulutav  (SgN  >kulutav !02_A	et	f	\N
180779	kulutav	"kulutav %kulu  )TAV_vAS  <kuluma ;27_V	et	f	\N
180780	kulutav	"kulutav %kuluta  )V_vA  <kulutama ;27_V	et	f	\N
180782	põhimõttesse	põhimõttesse =mõtte  (SgIll  >põhi+mõte !06_S	et	f	\N
180783	põhimõttesse	põhimõttesse =mõttes  (SgAdt  >põhi+mõttene !12_A	et	f	\N
180784	põhimõttesse	"põhi+mõttene %mõtte  )NE_aA  <põhi+mõte ;06_S	et	f	\N
180792	loetamatu	loetamatu =loetamatu  (SgN  >loetamatu !01_A	et	f	\N
180793	loetamatu	"loetamatu %loe  )TAMATU_vA  <lugema ;28_V	et	f	\N
180794	loetamatu	"loetamatu %loeta  )MATU_vA  <loetama ;27_V	et	f	\N
180795	loetamatu	loetamatu =loetamatu  (SgG  >loetamatu !01_A	et	f	\N
180796	oodamatu	?oodamatu =oodamatu  (SgN  >oodamatu !01_A	et	f	\N
180797	oodamatu	?oodamatu =oodamatu  (SgG  >oodamatu !01_A	et	f	\N
180798	oodamatu	?oodamatu =oodamatu  (IndPrPs_  >oodamatuma !27_V	et	f	\N
180799	oodamatu	?oodamatu =oodamatu  (ImpPrSg2  >oodamatuma !27_V	et	f	\N
180835	kahjustatavat	kahjustatavat =kahjusta  (KvtPrIps  >kahjustama !27_V	et	f	\N
180836	kahjustatavat	kahjustatavat =kahjustatava  (SgP  >kahjustatav !02_A	et	f	\N
180837	kahjustatavat	"kahjustatav %kahjusta  )TAV_vAS  <kahjustama ;27_V	et	f	\N
180838	püsiklienditel	?püsiklienditel =püsikliendite  (PlAd  >püsiklienditt !22_S	et	f	\N
180839	püsiklienditel	?püsiklienditel =kliendi  (PlAd  >püsi+kliendi !01_S	et	f	\N
180840	püsiklienditel	?püsiklienditel =kliendi  (PlAd  >püsi+kliend !02_S	et	f	\N
180841	püsiklienditel	?püsiklienditel =kliendite  (PlAd  >püsi+klienditt !22_S	et	f	\N
180859	kahjustavatel	kahjustavatel =kahjustava  (PlAd  >kahjustav !02_A	et	f	\N
180860	kahjustavatel	"kahjustav %kahjusta  )V_vA  <kahjustama ;27_V	et	f	\N
180863	prahti	prahti =prahti  (SgP  >praht !22_S	et	f	\N
180864	prahti	prahti =prahti  (SgAdt  >praht !22_S	et	f	\N
180900	soorteerimis	?soorteerimis =soorteerimi  (SgIn  >soorteerim !02_A	et	f	\N
180901	soorteerimis	?soorteerimis =soorteerimis  (SgN  >soorteerimis !09_S	et	f	\N
180906	ebaharitud	ebaharitud =haritu  (PlN  >eba+haritu !01_AS	et	f	\N
180907	ebaharitud	ebaharitud =haritud  (ID  >eba+haritud !41_A	et	f	\N
180944	kaubasnduse	?kaubasnduse =kaubasnduse  (SgG  >kaubasndus !11~09_S	et	f	\N
180947	mainekab	### mainekab	et	f	\N
180952	lugematu	lugematu =lugematu  (SgN  >lugematu !01_A	et	f	\N
180953	lugematu	"lugematu %luge  )MATU_vA  <lugema ;28_V	et	f	\N
180954	lugematu	"lugematu %lugema  )TU2_kA  <lugem ;02_S	et	f	\N
180955	lugematu	lugematu =lugematu  (SgG  >lugematu !01_A	et	f	\N
180975	kurban	?kurban =kurba  (IndPrSg1  >kurbama !29_V	et	f	\N
180976	kurban	?kurban =kurban  (SgN  >kurban !02_S	et	f	\N
180986	saav	saav =saa  (PtsPrPs  >saama !37_V	et	f	\N
180987	saav	saav =saav  (SgN  >saav !02_A	et	f	\N
180988	saav	"saav %saa  )V_vA  <saama ;37_V	et	f	\N
181004	ajalooliselt	ajalooliselt =loolise  (SgAbl  >aja+looline !12?10_A	et	f	\N
181005	ajalooliselt	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
181006	ajalooliselt	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
181007	ajalooliselt	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
181008	ajalooliselt	ajalooliselt =loolise  (SgAbl  >aja+looline !12?10_S	et	f	\N
181009	ajalooliselt	"aja+looliselt %loo  )LISELT_mD  <aja+lugu ;18_S	et	f	\N
181010	ajalooliselt	"aja+looliselt %loo  )LISELT_mD  <aja+loog ;22_S	et	f	\N
181011	ajalooliselt	"aja+looliselt %loo  )LISELT_mD  <aja+lood ;22_S	et	f	\N
181012	ajalooliselt	"aja+looliselt %loolise  )LT_mD  <aja+looline ;10_A	et	f	\N
181013	ajalooliselt	"aja+looliselt %loolise  )LT_mD  <aja+looline ;12_A	et	f	\N
181023	esindajalt	esindajalt =esindaja  (SgAbl  >esindaja !01_S	et	f	\N
181024	esindajalt	"esindaja %esinda  )JA_vS  <esindama ;27_V	et	f	\N
181074	heino	?heino =heino  (SgN  >heino !16_S	et	f	\N
181075	heino	?heino =heino  (SgG  >heino !16_S	et	f	\N
181077	tagasõna	tagasõna =sõna  (SgN  >taga+sõna !17_S	et	f	\N
181078	tagasõna	tagasõna =sõna  (SgG  >taga+sõna !17_S	et	f	\N
181079	tagasõna	tagasõna =sõna  (SgP  >taga+sõna !17_S	et	f	\N
181090	autosse	autosse =auto  (SgIll  >auto !16_S	et	f	\N
181091	autosse	autosse =tosse  (PlP  >au+toss !22_S	et	f	\N
181092	autosse	autosse =tosse  (PlP  >au+toss !22_SA	et	f	\N
181096	oksi	oksi =oksi  (SgG  >oks !22_S	et	f	\N
181097	oksi	oksi =oksi  (SgP  >oks !22_S	et	f	\N
181098	oksi	oksi =oksi  (SgAdt  >oks !22_S	et	f	\N
181099	oksi	oksi =oksi  (PlP  >oks !23?22_S	et	f	\N
181141	eeile	?eeile =eeile  (IndPrPs_  >eeilema !27_V	et	f	\N
181142	eeile	?eeile =eeile  (ImpPrSg2  >eeilema !27_V	et	f	\N
181155	mugavuseid	?mugavuseid =mugavusei  (PlN  >mugavusei !26_S	et	f	\N
181156	mugavuseid	?mugavuseid =mugavusei  (SgP  >mugavusei !26_S	et	f	\N
181157	mugavuseid	?mugavuseid =eid  (SgN  >mugavus+eid !22_S	et	f	\N
181162	alga	alga =alga  (IndPrPs_  >algama !29_V	et	f	\N
181163	alga	alga =alga  (ImpPrSg2  >algama !29_V	et	f	\N
181164	pingitust	pingitust =pingitu  (SgEl  >pingitu !01_AS	et	f	\N
181165	pingitust	"pingitu %pingi  )TU2_kA  <pink ;22_S	et	f	\N
181166	pingitust	pingitust =pingitus  (SgP  >pingitus !11_S	et	f	\N
181167	pingitust	"pingitus %pingi  )TUS2_aS  <pink ;22_S	et	f	\N
181168	pingitust	pingitust =tust  (SgN  >pingi+tust !22_S	et	f	\N
180844	põhimõttetesse	?põhimõttetesse =põhimõttetes  (SgAdt  >põhimõttetene !12_A	et	f	\N
180846	põhimõttetesse	?põhimõttetesse =põhimõttetesse  (SgG  >põhimõttetesne !02_A	et	f	\N
180847	põhimõttetesse	?põhimõttetesse =põhimõttetesse  (PlP  >põhimõttetess !22_S	et	f	\N
180848	põhimõttetesse	?põhimõttetesse =mõtte  (PlIll  >põhi+mõtte !06_S	et	f	\N
180849	põhimõttetesse	?põhimõttetesse =mõttete  (PlIll  >põhi+mõttett !22_S	et	f	\N
180850	põhimõttetesse	?põhimõttetesse =mõttetes  (SgAdt  >põhi+mõttetene !12_A	et	f	\N
180851	põhimõttetesse	?põhimõttetesse =mõttetesse  (SgG  >põhi+mõttetesne !02_A	et	f	\N
180852	põhimõttetesse	?põhimõttetesse =mõttetesse  (PlP  >põhi+mõttetess !22_S	et	f	\N
180853	toodetavateid	?toodetavateid =toodetavatei  (PlN  >toodetavatei !26_S	et	f	\N
180854	toodetavateid	?toodetavateid =toodetavatei  (SgP  >toodetavatei !26_S	et	f	\N
180855	toodetavateid	?toodetavateid =detavatei  (PlN  >too+detavatei !26_S	et	f	\N
180856	toodetavateid	?toodetavateid =detavatei  (SgP  >too+detavatei !26_S	et	f	\N
180861	põhimõttese	põhimõttese =mõttese  (SgG  >põhi+mõttene !12~10_A	et	f	\N
180862	põhimõttese	"põhi+mõttene %mõtte  )NE_aA  <põhi+mõte ;06_S	et	f	\N
180865	järelekasutamissüstem	?järelekasutamissüstem =järelekasutamissüstem  (SgN  >järelekasutamissüstem !02_A	et	f	\N
180866	järelekasutamissüstem	?järelekasutamissüstem =süstem  (SgN  >järele+kasutamis+süstem !02_A	et	f	\N
180867	järelekasutamissüstem	?järelekasutamissüstem =tamissüstem  (SgN  >järele+kasu+tamissüstem !02_A	et	f	\N
180868	järelekasutamissüstem	?järelekasutamissüstem =utamissüstem  (SgN  >järele+kas+utamissüstem !02_A	et	f	\N
180869	järelekasutamissüstem	?järelekasutamissüstem =kasutamissüstem  (SgN  >järele+kasutamissüstem !02_A	et	f	\N
180870	järelekasutamissüstem	?järelekasutamissüstem =ekasutamissüstem  (SgN  >järel+ekasutamissüstem !02_A	et	f	\N
180871	uudishiimulik	?uudishiimulik =uudishiimulik  (SgN  >uudishiimulik !25_A	et	f	\N
180872	uudishiimulik	?uudishiimulik =hiimulik  (SgN  >uudis+hiimulik !25_A	et	f	\N
180895	kahjustatav	kahjustatav =kahjusta  (PtsPrIps  >kahjustama !27_V	et	f	\N
180896	kahjustatav	kahjustatav =kahjustatav  (SgN  >kahjustatav !02_A	et	f	\N
180897	kahjustatav	"kahjustatav %kahjusta  )TAV_vAS  <kahjustama ;27_V	et	f	\N
180899	püsiklientid	?püsiklientid =klienti  (PlN  >püsi+klienti !01_S	et	f	\N
180902	töödatud	?töödatud =töödatu  (PlN  >töödatu !01_S	et	f	\N
180903	töödatud	?töödatud =töödatu  (IndPrSg2  >töödatuma !27_V	et	f	\N
180904	töödatud	?töödatud =töödatud  (ID  >töödatud !41_A	et	f	\N
180905	töödatud	?töödatud =datu  (PlN  >töö+datu !16_S	et	f	\N
180922	pesumasinast	pesumasinast =ast  (SgN  >pesu+masin+ast !22_S	et	f	\N
180923	pesumasinast	pesumasinast =masina  (SgEl  >pesu+masin !02_S	et	f	\N
180924	pesumasinast	pesumasinast =masinas  (SgP  >pesu+masinane !12_A	et	f	\N
180925	pesumasinast	"pesu+masinane %masina  )NE_aA  <pesu+masin ;02_S	et	f	\N
180926	lisav	lisav =lisa  (PtsPrPs  >lisama !27_V	et	f	\N
180927	lisav	lisav =lisav  (SgN  >lisav !02_A	et	f	\N
180928	lisav	"lisav %lisa  )V_vA  <lisama ;27_V	et	f	\N
180939	majasmokk	?majasmokk =majasmokk  (SgN  >majasmokk !22_S	et	f	\N
180940	majasmokk	?majasmokk =smokk  (SgN  >maja+smokk !22_S	et	f	\N
180943	rikkutab	?rikkutab =rikkuta  (IndPrSg3  >rikkutama !27_V	et	f	\N
180948	klietideid	?klietideid =klietide  (PlP  >klietidi !01_S	et	f	\N
180949	klietideid	?klietideid =klietidei  (PlN  >klietidei !26_S	et	f	\N
180950	klietideid	?klietideid =klietidei  (SgP  >klietidei !26_S	et	f	\N
180964	ostjele	?ostjele =ostje  (SgAll  >ostje !06_S	et	f	\N
180965	ostjele	?ostjele =ostjele  (IndPrPs_  >ostjelema !31~27_V	et	f	\N
180966	ostjele	?ostjele =ostjele  (ImpPrSg2  >ostjelema !31~27_V	et	f	\N
180989	1möödunud	möödunud =möödu  (PtsPtPs  >mööduma !27_V	et	f	\N
180990	1möödunud	möödunud =möödunu  (PlN  >möödunu !01_S	et	f	\N
180991	1möödunud	"möödunu %möödu  )NU_vS  <mööduma ;27_V	et	f	\N
180992	1möödunud	möödunud =möödunud  (ID  >möödunud !41_A	et	f	\N
180993	1möödunud	"möödunud %möödu  )NUD_vA  <mööduma ;27_V	et	f	\N
180994	majandusjuhataja	majandusjuhataja =juhataja  (SgN  >majandus+juhataja !01_S	et	f	\N
180995	majandusjuhataja	majandusjuhataja =juhataja  (SgG  >majandus+juhataja !01_S	et	f	\N
181000	kannatlikust	kannatlikust =kannatliku  (SgEl  >kannatlik !25_A	et	f	\N
181002	kannatlikust	kannatlikust =kannatlikus  (SgP  >kannatlikus !11?09_S	et	f	\N
181003	kannatlikust	"kannatlikus %kannatliku  )US_aS  <kannatlik ;25_A	et	f	\N
181014	maakonnad	maakonnad =maakonna  (PlN  >maakond !22_S	et	f	\N
181015	maakonnad	maakonnad =konna  (PlN  >maa+konn !22_S	et	f	\N
181027	1ilma	ilma =ilma  (ID  >ilma !41_DK	et	f	\N
181028	1ilma	ilma =ilma  (SgG  >ilm !22_S	et	f	\N
181029	1ilma	ilma =ilma  (SgP  >ilm !22_S	et	f	\N
181030	1ilma	ilma =ilma  (SgAdt  >ilm !22_S	et	f	\N
181037	saastatus	saastatus =saastatu  (SgIn  >saastatu !01_S	et	f	\N
181038	saastatus	"saastatu %saasta  )TU1_vS  <saastama ;27_V	et	f	\N
181039	saastatus	"saastatu %saasta  )TU1_vS  <saastama ;29_V	et	f	\N
181040	saastatus	"saastatu %saasta  )TU2_kA  <saast ;22_S	et	f	\N
181041	saastatus	saastatus =saastatus  (SgN  >saastatus !11_S	et	f	\N
181042	saastatus	"saastatus %saasta  )TUS1_aS  <saastama ;27_V	et	f	\N
181043	saastatus	"saastatus %saasta  )TUS1_aS  <saastama ;29_V	et	f	\N
180942	pesupubrit	?pesupubrit =pubrit  (SgN  >pesu+pubrit !02_S	et	f	\N
180961	lakstud	?lakstud =lakstu  (PlN  >lakstu !01_S	et	f	\N
180962	lakstud	?lakstud =lakstu  (IndPrSg2  >lakstuma !27_V	et	f	\N
180963	lakstud	?lakstud =lakstud  (ID  >lakstud !41_A	et	f	\N
180972	majapidamistarvete	majapidamistarvete =e  (PlG  >maja+pidamist+arv+esi !15_S	et	f	\N
180973	majapidamistarvete	majapidamistarvete =arve  (PlG  >maja+pidamist+arve !06_S	et	f	\N
180974	majapidamistarvete	majapidamistarvete =tarve  (PlG  >maja+pidamis+tarve !06_S	et	f	\N
180977	kurbu	kurbu =kurbu  (IndPrPs_  >kurbuma !27_V	et	f	\N
180978	kurbu	kurbu =kurbu  (ImpPrSg2  >kurbuma !27_V	et	f	\N
180983	majapidamistarvetele	majapidamistarvetele =e  (PlAll  >maja+pidamist+arv+esi !15_S	et	f	\N
180984	majapidamistarvetele	majapidamistarvetele =arve  (PlAll  >maja+pidamist+arve !06_S	et	f	\N
180985	majapidamistarvetele	majapidamistarvetele =tarve  (PlAll  >maja+pidamis+tarve !06_S	et	f	\N
180996	kasvamine	kasvamine =kasvamine  (SgN  >kasvamine !12_S	et	f	\N
180997	kasvamine	"kasvamine %kasva  )MINE_vS  <kasvama ;28_V	et	f	\N
181016	majandusjuhatajast	majandusjuhatajast =juhataja  (SgEl  >majandus+juhataja !01_S	et	f	\N
181017	majandusjuhatajast	majandusjuhatajast =juhatajas  (SgP  >majandus+juhatajane !12_A	et	f	\N
181018	majandusjuhatajast	"majandus+juhatajane %juhataja  )NE_aA  <majandus+juhataja ;01_S	et	f	\N
181021	rahvase	rahvase =rahvase  (SgG  >rahvane !10_A	et	f	\N
181022	rahvase	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
181035	hilinemiste	hilinemiste =hilinemis  (PlG  >hilinemine !12_S	et	f	\N
181036	hilinemiste	"hilinemine %hiline  )MINE_vS  <hilinema ;27_V	et	f	\N
181064	asustusega	asustusega =asustuse  (SgKom  >asustus !11_S	et	f	\N
181065	asustusega	"asustus %asusta  )US_vS  <asustama ;27_V	et	f	\N
181066	mõjuvõimu	mõjuvõimu =võimu  (SgG  >mõju+võim !22_S	et	f	\N
181067	mõjuvõimu	mõjuvõimu =võimu  (SgP  >mõju+võim !22_S	et	f	\N
181068	mõjuvõimu	mõjuvõimu =võimu  (SgAdt  >mõju+võim !22_S	et	f	\N
181072	õppesõnastikku	õppesõnastikku =sõnastikku  (SgP  >õppe+sõnastik !25_S	et	f	\N
181073	õppesõnastikku	õppesõnastikku =sõnastikku  (SgAdt  >õppe+sõnastik !25_S	et	f	\N
181101	näoge	?näoge =näoge  (SgN  >näoge !06_S	et	f	\N
181102	näoge	?näoge =näoge  (PlP  >näog !22_S	et	f	\N
181103	näoge	?näoge =näoge  (IndPrPs_  >näogema !27_V	et	f	\N
181104	näoge	?näoge =näoge  (ImpPrSg2  >näogema !27_V	et	f	\N
181112	sügavat	sügavat =süga  (KvtPrPs  >sügama !27_V	et	f	\N
181113	sügavat	sügavat =sügava  (SgP  >sügav !02_A	et	f	\N
181114	sügavat	"sügav %süga  )V_vA  <sügama ;27_V	et	f	\N
181119	rahvasena	rahvasena =rahvase  (SgEs  >rahvane !10_A	et	f	\N
181120	rahvasena	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
181126	pesemata	pesemata =pese  (SupAb  >pesema !36_V	et	f	\N
181127	pesemata	pesemata =pesemata  (ID  >pesemata !41_A	et	f	\N
181128	pesemata	"pesemata %pese  )MATA_vA  <pesema ;36_V	et	f	\N
181129	vaatamisväärsuseid	vaatamisväärsuseid =väärsuse  (PlP  >vaatamis+väärsus !09_S	et	f	\N
181130	vaatamisväärsuseid	"vaatamis+väärsus %väärse  )US_aS  <vaatamis+väärne ;02_A	et	f	\N
181131	ametlikku	ametlikku =ametlikku  (SgP  >ametlik !25_A	et	f	\N
181132	ametlikku	ametlikku =ametlikku  (SgAdt  >ametlik !25_A	et	f	\N
181145	villast	villast =villa  (SgEl  >villa !16_S	et	f	\N
181146	villast	villast =villa  (SgEl  >vill !22_S	et	f	\N
181147	villast	villast =villas  (SgP  >villane !10_A	et	f	\N
181148	villast	"villane %villa  )NE_aA  <villa ;16_S	et	f	\N
181149	villast	"villane %villa  )NE_aA  <vill ;22_S	et	f	\N
181150	villast	villast =ast  (SgN  >vill+ast !22_S	et	f	\N
181152	palava	palava =palava  (SgG  >palav !02_A	et	f	\N
181153	palava	"palav %pala  )V_vA  <palama ;27_V	et	f	\N
181169	uesesse	?uesesse =uese  (SgIll  >uene !10_A	et	f	\N
181170	uesesse	?uesesse =uese  (SgIll  >uese !06_S	et	f	\N
181171	uesesse	?uesesse =uesesse  (SgG  >uesesne !02_A	et	f	\N
181172	uesesse	?uesesse =uesesse  (PlP  >uesess !22_S	et	f	\N
181177	väljasulle	?väljasulle =väljasulle  (PlP  >väljasull !22_S	et	f	\N
181178	väljasulle	?väljasulle =ulle  (SgN  >väljas+ulle !06_S	et	f	\N
181179	väljasulle	?väljasulle =ulle  (PlP  >väljas+ull !22_S	et	f	\N
181180	väljasulle	?väljasulle =sulle  (SgN  >välja+sulle !06_S	et	f	\N
181181	väljasulle	?väljasulle =sulle  (PlP  >välja+sull !22_S	et	f	\N
181194	osakonnasse	osakonnasse =osakonna  (SgIll  >osakond !22_S	et	f	\N
181195	osakonnasse	osakonnasse =osakonnas  (SgAdt  >osakonnane !12_A	et	f	\N
181196	osakonnasse	"osakonnane %osakonna  )NE_aA  <osakond ;22_S	et	f	\N
181198	osakonnasse	osakonnasse =konna  (SgIll  >osa+konn !22_S	et	f	\N
181205	baltisakslasteni	baltisakslasteni =las  (PlTer  >balt+isaks+laps !14_S	et	f	\N
181206	baltisakslasteni	baltisakslasteni =sakslas  (PlTer  >balti+sakslane !12?10_S	et	f	\N
181215	vaatamisväärsusteta	vaatamisväärsusteta =väärsus  (PlAb  >vaatamis+väärsus !11~09_S	et	f	\N
181216	vaatamisväärsusteta	"vaatamis+väärsus %väärse  )US_aS  <vaatamis+väärne ;02_A	et	f	\N
181219	hilinemise	hilinemise =hilinemise  (SgG  >hilinemine !12_S	et	f	\N
181220	hilinemise	"hilinemine %hiline  )MINE_vS  <hilinema ;27_V	et	f	\N
181223	inimorganisile	?inimorganisile =organisi  (PlAll  >inim+organis !11_S	et	f	\N
181231	uuetele	?uuetele =uue  (PlAll  >uue !06_S	et	f	\N
181044	saastatus	"saastatus %saasta  )TUS2_aS  <saast ;22_S	et	f	\N
181049	elanikkonnast	elanikkonnast =elanikkonna  (SgEl  >elanikkond !22_S	et	f	\N
181050	elanikkonnast	elanikkonnast =elanikkonnas  (SgP  >elanikkonnane !12_A	et	f	\N
181051	elanikkonnast	"elanikkonnane %elanikkonna  )NE_aA  <elanikkond ;22_S	et	f	\N
181056	tarvitanud	tarvitanud =tarvita  (PtsPtPs  >tarvitama !27_V	et	f	\N
181057	tarvitanud	tarvitanud =tarvitanu  (PlN  >tarvitanu !01_S	et	f	\N
181058	tarvitanud	"tarvitanu %tarvita  )NU_vS  <tarvitama ;27_V	et	f	\N
181059	tarvitanud	tarvitanud =tarvitanud  (ID  >tarvitanud !41_A	et	f	\N
181060	tarvitanud	"tarvitanud %tarvita  )NUD_vA  <tarvitama ;27_V	et	f	\N
181069	vene-eesti	vene-eesti =eesti  (ID  >vene-eesti !41_G	et	f	\N
181070	vene-eesti	vene-eesti =eesti  (SgN  >vene-eesti !16_H	et	f	\N
181071	vene-eesti	vene-eesti =eesti  (SgG  >vene-eesti !16_H	et	f	\N
181076	mustam	?mustam =mustam  (SgN  >mustam !02_A	et	f	\N
181093	vigad	?vigad =viga  (IndPrSg2  >vigama !27_V	et	f	\N
181123	baltisakslasteks	baltisakslasteks =las  (PlTr  >balt+isaks+laps !14_S	et	f	\N
181124	baltisakslasteks	baltisakslasteks =laste  (PlTr  >balt+isaks+last !22_S	et	f	\N
181125	baltisakslasteks	baltisakslasteks =sakslas  (PlTr  >balti+sakslane !12?10_S	et	f	\N
181133	taotlust	taotlust =taotlus  (SgP  >taotlus !11~09_S	et	f	\N
181135	taotlust	"taotlus %taotle  )US_vS  <taotlema ;27_V	et	f	\N
181143	ebapuhtam	ebapuhtam =puhtam  (SgN  >eba+puhtam !02_A	et	f	\N
181144	ebapuhtam	"eba+puhtam %puhta  )M_cA  <eba+puhas ;07_A	et	f	\N
181151	mägidel	### mägidel	et	f	\N
181154	näodega	?näodega =näo  (PlKom  >näo !26_S	et	f	\N
181173	ueses	?ueses =uese  (SgIn  >uene !10_A	et	f	\N
181174	ueses	?ueses =uese  (SgIn  >uese !06_S	et	f	\N
181175	ueses	?ueses =uese  (IndIpfSg3  >uesema !28_V	et	f	\N
181176	ueses	?ueses =ueses  (SgN  >ueses !09_S	et	f	\N
181184	sügavasse	sügavasse =sügava  (SgIll  >sügav !02_A	et	f	\N
181185	sügavasse	"sügav %süga  )V_vA  <sügama ;27_V	et	f	\N
181187	sügavasse	sügavasse =asse  (PlP  >sügav+ass !22_S	et	f	\N
181191	tehtnud	?tehtnud =tehtnu  (PlN  >tehtnu !01_S	et	f	\N
181192	tehtnud	?tehtnud =tehtnu  (IndPrSg2  >tehtnuma !27_V	et	f	\N
181193	tehtnud	?tehtnud =tehtnud  (ID  >tehtnud !41_A	et	f	\N
181197	majapidamistarvetes	majapidamistarvetes =e  (PlIn  >maja+pidamist+arv+esi !15_S	et	f	\N
181199	majapidamistarvetes	majapidamistarvetes =arve  (PlIn  >maja+pidamist+arve !06_S	et	f	\N
181200	majapidamistarvetes	majapidamistarvetes =tarve  (PlIn  >maja+pidamis+tarve !06_S	et	f	\N
181217	taotluseta	taotluseta =taotluse  (SgAb  >taotlus !11~09_S	et	f	\N
181218	taotluseta	"taotlus %taotle  )US_vS  <taotlema ;27_V	et	f	\N
181225	mustem	mustem =mustem  (SgN  >mustem !02_A	et	f	\N
181226	mustem	"mustem %muste  )M_cA  <must ;22_AS	et	f	\N
181227	villasest	villasest =villase  (SgEl  >villane !10_A	et	f	\N
181228	villasest	"villane %villa  )NE_aA  <villa ;16_S	et	f	\N
181229	villasest	"villane %villa  )NE_aA  <vill ;22_S	et	f	\N
181244	1siin	siin =siin  (ID  >siin !41_D	et	f	\N
181245	1siin	siin =siin  (SgN  >siin !22_S	et	f	\N
181254	suhutusid	?suhutusid =suhutu  (IndIpfSg2  >suhutuma !27_V	et	f	\N
181255	suhutusid	?suhutusid =suhutu  (IndIpfPl3  >suhutuma !27_V	et	f	\N
181277	5iga	iga =iga  (SgN  >iga !17_P	et	f	\N
181278	5iga	iga =iga  (SgN  >iga !18_S	et	f	\N
181279	5iga	iga =iga  (SgG  >iga !17_P	et	f	\N
181280	5iga	iga =iga  (SgP  >iga !17_P	et	f	\N
181281	5iga	iga =iga  (SgP  >iga !18_S	et	f	\N
181289	halsem	?halsem =halsem  (SgN  >halsem !02_A	et	f	\N
181295	manteliga	manteliga =manteli  (SgKom  >mantel !02_S	et	f	\N
181296	manteliga	manteliga =iga  (SgN  >mantel+iga !18_S	et	f	\N
181297	manteliga	manteliga =iga  (SgP  >mantel+iga !18_S	et	f	\N
181314	9selle	selle =selle  (SgG  >see !00_P	et	f	\N
181315	9selle	selle =selle  (PlP  >sell !22_S	et	f	\N
181330	kurbusest	kurbusest =kurbuse  (SgEl  >kurbus !11~09_S	et	f	\N
181331	kurbusest	"kurbus %kurb  )US_aS  <kurb ;22_A	et	f	\N
181332	kurbusest	kurbusest =kurbuses  (SgP  >kurbusene !12_A	et	f	\N
181333	kurbusest	"kurbusene %kurbuse  )NE_aA  <kurbus ;09_S	et	f	\N
181334	kurbusest	"kurbusene %kurbuse  )NE_aA  <kurbus ;11_S	et	f	\N
181335	kurbusest	kurbusest =use  (PlEl  >kurb+usk !22_S	et	f	\N
181336	perekonnaseisukohalt	perekonnaseisukohalt =koha  (SgAbl  >pere+konna+seisu+koha !17_S	et	f	\N
181337	perekonnaseisukohalt	perekonnaseisukohalt =koha  (SgAbl  >pere+konna+seisu+koht !22_S	et	f	\N
181377	oomise	oomise =oomise  (SgG  >oomine !10_A	et	f	\N
181378	oomise	"oomine %oomi  )NE_aA  <oom ;22_S	et	f	\N
181383	unev	?unev =une  (PtsPrPs  >unema !27_V	et	f	\N
181384	unev	?unev =unev  (SgN  >unev !02_A	et	f	\N
181388	astust	?astust =astu  (SgEl  >astu !16_S	et	f	\N
181389	astust	?astust =astus  (SgP  >astus !11~09_S	et	f	\N
181399	riti	?riti =riti  (SgN  >riti !16_S	et	f	\N
181400	riti	?riti =riti  (SgG  >riti !16_S	et	f	\N
181401	riti	?riti =riti  (SgG  >ritt !22_S	et	f	\N
181402	riti	?riti =riti  (IndPrPs_  >ritima !27_V	et	f	\N
181403	riti	?riti =riti  (IndPrPs_  >rittima !28_V	et	f	\N
181404	riti	?riti =riti  (ImpPrSg2  >ritima !27_V	et	f	\N
181052	rahvusvähemust	rahvusvähemust =us  (SgP  >rahvus+vähem+uks !14_S	et	f	\N
181053	rahvusvähemust	rahvusvähemust =must  (SgN  >rahvus+vähe+must !22_AS	et	f	\N
181054	rahvusvähemust	rahvusvähemust =vähemus  (SgP  >rahvus+vähemus !11_S	et	f	\N
181055	rahvusvähemust	"rahvus+vähemus %vähema  )US_aS  <rahvus+vähem ;02_A	et	f	\N
181080	sugulast	sugulast =sugulas  (SgP  >sugulane !12_S	et	f	\N
181081	sugulast	sugulast =la  (SgEl  >sugu+la !26_S	et	f	\N
181082	sugulast	sugulast =las  (SgP  >sugu+laps !14_S	et	f	\N
181083	sugulast	sugulast =last  (SgN  >sugu+last !22_S	et	f	\N
181087	villane	villane =villane  (SgN  >villane !10_A	et	f	\N
181088	villane	"villane %villa  )NE_aA  <villa ;16_S	et	f	\N
181089	villane	"villane %villa  )NE_aA  <vill ;22_S	et	f	\N
181094	saabusid	saabusid =saabu  (IndIpfSg2  >saabuma !27_V	et	f	\N
181095	saabusid	saabusid =saabu  (IndIpfPl3  >saabuma !27_V	et	f	\N
181100	hapuge	?hapuge =hapu  (ImpPrPl2  >hapuma !27_V	et	f	\N
181107	võidat	?võidat =võida  (SgP  >võida !16_S	et	f	\N
181108	võidat	?võidat =võidat  (SgN  >võidat !02_S	et	f	\N
181111	isehinned	### isehinned	et	f	\N
181115	seinast	seinast =seina  (SgEl  >sein !23?22_S	et	f	\N
181116	seinast	seinast =seinas  (SgP  >seinane !10_A	et	f	\N
181117	seinast	"seinane %seina  )NE_aA  <sein ;22_S	et	f	\N
181118	seinast	"seinane %seina  )NE_aA  <sein ;23_S	et	f	\N
181121	erinevateks	erinevateks =erineva  (PlTr  >erinev !02_A	et	f	\N
181122	erinevateks	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
181134	hilinemiseta	hilinemiseta =hilinemise  (SgAb  >hilinemine !12_S	et	f	\N
181136	hilinemiseta	"hilinemine %hiline  )MINE_vS  <hilinema ;27_V	et	f	\N
181138	seisu	seisu =seisu  (SgG  >seis !22_S	et	f	\N
181139	seisu	seisu =seisu  (SgP  >seis !22_S	et	f	\N
181140	seisu	seisu =seisu  (SgAdt  >seis !22_S	et	f	\N
181158	3sellel	sellel =selle  (SgAd  >see !00_P	et	f	\N
181159	3sellel	sellel =selle  (PlAd  >sell !22_S	et	f	\N
181186	kurbusisse	kurbusisse =kurbusi  (PlIll  >kurbus !11_S	et	f	\N
181188	kurbusisse	"kurbus %kurb  )US_aS  <kurb ;22_A	et	f	\N
181201	rahvaseni	rahvaseni =rahvase  (SgTer  >rahvane !10_A	et	f	\N
181202	rahvaseni	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
181207	esindajatene	?esindajatene =esindajatene  (SgN  >esindajatene !12_A	et	f	\N
181208	esindajatene	?esindajatene =esindajatene  (PlP  >esindajaten !19_S	et	f	\N
181209	esindajatene	?esindajatene =tene  (SgN  >esindaja+tene !16_S	et	f	\N
181210	esindajatene	?esindajatene =tene  (SgG  >esindaja+tene !16_S	et	f	\N
181224	lühikem	?lühikem =lühikem  (SgN  >lühikem !02_A	et	f	\N
181235	nugaga	### nugaga	et	f	\N
181266	taotlusta	?taotlusta =taotlusta  (SgN  >taotlusta !01_S	et	f	\N
181267	taotlusta	?taotlusta =taotlusta  (SgG  >taotlusta !01_S	et	f	\N
181268	taotlusta	?taotlusta =taotlusta  (IndPrPs_  >taotlustama !27_V	et	f	\N
181269	taotlusta	?taotlusta =taotlusta  (ImpPrSg2  >taotlustama !27_V	et	f	\N
181286	3hollandiga	?hollandiga =hollandi  (SgKom  >hollandi !01_S	et	f	\N
181287	3hollandiga	?hollandiga =hollandi  (SgKom  >holland !02_S	et	f	\N
181288	3hollandiga	?hollandiga =hollandi  (SgKom  >hollant !22_S	et	f	\N
181294	ituge	?ituge =itu  (ImpPrPl2  >ituma !27_V	et	f	\N
181308	6eduard	?eduard =eduard  (SgN  >eduard !22_S	et	f	\N
181309	6eduard	?eduard =ard  (SgN  >edu+ard !22_S	et	f	\N
181385	eidnud	?eidnud =eidnu  (PlN  >eidnu !01_S	et	f	\N
181386	eidnud	?eidnud =eidnu  (IndPrSg2  >eidnuma !27_V	et	f	\N
181387	eidnud	?eidnud =eidnud  (ID  >eidnud !41_A	et	f	\N
181390	aloolistel	?aloolistel =aloolis  (PlAd  >aloolis !09_S	et	f	\N
181391	aloolistel	?aloolistel =aloolis  (PlAd  >alooline !12?10_A	et	f	\N
181392	ündmustel	?ündmustel =ündmus  (PlAd  >ündmus !11~09_S	et	f	\N
181420	etta	?etta =etta  (ID  >etta !41_D	et	f	\N
181421	etta	?etta =etta  (IndPrPs_  >ettama !29_V	et	f	\N
181422	etta	?etta =etta  (ImpPrSg2  >ettama !29_V	et	f	\N
181430	leniniga	?leniniga =lenini  (SgKom  >lenin !02_S	et	f	\N
181437	eninite	?eninite =enini  (PlG  >enin !02_S	et	f	\N
181461	he1t	### he1t	et	f	\N
181464	teavitas	?teavitas =teavita  (IndIpfSg3  >teavitama !27_V	et	f	\N
181465	namlaste	?namlaste =namlas  (PlG  >namlas !07_S	et	f	\N
181466	namlaste	?namlaste =namlas  (PlG  >namlane !10_A	et	f	\N
181469	koolitatud	koolitatud =koolita  (PtsPtIps  >koolitama !27_V	et	f	\N
181470	koolitatud	koolitatud =koolitatu  (PlN  >koolitatu !01_S	et	f	\N
181471	koolitatud	"koolitatu %koolita  )TU1_vS  <koolitama ;27_V	et	f	\N
181472	koolitatud	koolitatud =koolitatud  (ID  >koolitatud !41_A	et	f	\N
181473	koolitatud	"koolitatud %koolita  )TUD_vA  <koolitama ;27_V	et	f	\N
181507	utada	?utada =uta  (Inf  >utama !27_V	et	f	\N
181510	õnes	?õnes =õne  (SgIn  >õne !16_S	et	f	\N
181511	õnes	?õnes =õne  (IndIpfSg3  >õnema !27_V	et	f	\N
181512	õnes	?õnes =õnes  (SgN  >õnes !09_S	et	f	\N
181521	gaüks	?gaüks =gaüks  (SgN  >gaüks !22_S	et	f	\N
181531	nne	### nne	et	f	\N
181532	a1	### a1	et	f	\N
181541	ainuvalitse	ainuvalitse =valitse  (IndPrPs_  >ainu+valitsema !27_V	et	f	\N
181542	ainuvalitse	ainuvalitse =valitse  (ImpPrSg2  >ainu+valitsema !27_V	et	f	\N
181189	kurbusis	kurbusis =kurbusi  (PlIn  >kurbus !11_S	et	f	\N
181190	kurbusis	"kurbus %kurb  )US_aS  <kurb ;22_A	et	f	\N
181230	vigaga	### vigaga	et	f	\N
181234	kohvitega	### kohvitega	et	f	\N
181256	ettepanekuses	?ettepanekuses =ettepanekuse  (SgIn  >ettepanekus !11?09_S	et	f	\N
181257	ettepanekuses	?ettepanekuses =panekuse  (SgIn  >ette+panekus !11_S	et	f	\N
181258	igasugusta	?igasugusta =igasugusta  (SgN  >igasugusta !16_S	et	f	\N
181259	igasugusta	?igasugusta =igasugusta  (SgG  >igasugusta !16_S	et	f	\N
181260	igasugusta	?igasugusta =igasugusta  (IndPrPs_  >igasugustama !27_V	et	f	\N
181261	igasugusta	?igasugusta =igasugusta  (ImpPrSg2  >igasugustama !27_V	et	f	\N
181262	igasugusta	?igasugusta =sugusta  (SgN  >iga+sugusta !01_S	et	f	\N
181263	igasugusta	?igasugusta =sugusta  (SgG  >iga+sugusta !01_S	et	f	\N
181290	villase	villase =villase  (SgG  >villane !10_A	et	f	\N
181291	villase	"villane %villa  )NE_aA  <villa ;16_S	et	f	\N
181292	villase	"villane %villa  )NE_aA  <vill ;22_S	et	f	\N
181293	villase	villase =ase  (SgN  >vill+ase !04_S	et	f	\N
181304	mäedel	?mäedel =mäe  (PlAd  >mäe !26_S	et	f	\N
181305	mäedel	?mäedel =mäede  (PlAd  >mäet !22_S	et	f	\N
181306	mäedel	?mäedel =mäedel  (SgN  >mäedel !02_S	et	f	\N
181316	4mis	mis =mis  (SgN  >mis !00_P	et	f	\N
181317	4mis	mis =mis  (PlN  >mis !00_P	et	f	\N
181318	4mis	mis =mi  (SgIn  >mi !26_S	et	f	\N
181324	3me	me =me  (PlG  >ma !00_P	et	f	\N
181325	3me	me =me  (PlN  >ma !00_P	et	f	\N
181328	sügavas	sügavas =sügava  (SgIn  >sügav !02_A	et	f	\N
181329	sügavas	"sügav %süga  )V_vA  <sügama ;27_V	et	f	\N
181355	tööhõive	tööhõive =hõive  (SgN  >töö+hõive !06_S	et	f	\N
181356	tööhõive	tööhõive =hõive  (SgG  >töö+hõive !06_S	et	f	\N
181357	kardsad	?kardsad =kardsa  (PlN  >kardsa !01_S	et	f	\N
181358	kardsad	?kardsad =kardsa  (IndPrSg2  >kardsama !29_V	et	f	\N
181369	mapärane	?mapärane =mapärane  (SgN  >mapärane !12_A	et	f	\N
181370	mapärane	?mapärane =mapärane  (PlP  >mapäran !19_S	et	f	\N
181379	eskseks	?eskseks =eskse  (SgTr  >eskne !02_A	et	f	\N
181380	eskseks	?eskseks =eskse  (SgTr  >eskse !06_S	et	f	\N
181381	eskseks	?eskseks =eskse  (PlTr  >esks !22_S	et	f	\N
181382	eskseks	?eskseks =eskse  (KndPrPs  >esksema !27_V	et	f	\N
181396	askonnale	?askonnale =askonna  (SgAll  >askonna !16_S	et	f	\N
181397	askonnale	?askonnale =askonna  (SgAll  >askond !22_S	et	f	\N
181424	lguses	?lguses =lguse  (SgIn  >lguse !16_S	et	f	\N
181425	lguses	?lguses =lguse  (IndIpfSg3  >lgusema !27_V	et	f	\N
181426	lguses	?lguses =lguses  (SgN  >lguses !09_S	et	f	\N
181428	usid	?usid =usi  (PlN  >usi !17_S	et	f	\N
181429	usid	?usid =usi  (IndPrSg2  >usima !27_V	et	f	\N
181433	sna	### sna	et	f	\N
181440	ärgatavalt	ärgatavalt =ärgatava  (SgAbl  >ärgatav !02_A	et	f	\N
181442	ärgatavalt	"ärgatav %ärga  )TAV_vAS  <ärkama ;29_V	et	f	\N
181444	ärgatavalt	ärgatavalt =ärgatavalt  (ID  >ärgatavalt !41_D	et	f	\N
181445	ärgatavalt	"ärgatavalt %ärga  )TAVALT_mD  <ärkama ;29_V	et	f	\N
181448	ambitsioonikad	?ambitsioonikad =ambitsioonika  (PlN  >ambitsioonika !01_S	et	f	\N
181449	ambitsioonikad	?ambitsioonikad =ambitsioonika  (PlN  >ambitsioonikas !02_A	et	f	\N
181455	nei1e	?neie =neie  (SgN  >neie !06_S	et	f	\N
181456	nei1e	?neie =neie  (SgG  >neie !06_S	et	f	\N
181457	makasupüüdlikuna	?makasupüüdlikuna =makasupüüdliku  (SgEs  >makasupüüdlik !25_A	et	f	\N
181478	tagaplaanile	tagaplaanile =tagaplaanile  (ID  >taga+plaanile !41_D	et	f	\N
181479	tagaplaanile	tagaplaanile =plaani  (SgAll  >taga+plaan !22_S	et	f	\N
181491	eab	?eab =eab  (SgN  >eab !22_S	et	f	\N
181501	isse	?isse =isse  (SgN  >isse !06_S	et	f	\N
181502	isse	?isse =isse  (SgG  >isne !02_A	et	f	\N
181503	isse	?isse =isse  (SgG  >isse !06_S	et	f	\N
181504	isse	?isse =isse  (PlP  >iss !22_S	et	f	\N
181505	isse	?isse =isse  (IndPrPs_  >issema !27_V	et	f	\N
181506	isse	?isse =isse  (ImpPrSg2  >issema !27_V	et	f	\N
181508	undus	?undus =undu  (IndIpfSg3  >unduma !27_V	et	f	\N
181509	undus	?undus =undus  (SgN  >undus !11~09_S	et	f	\N
181525	aabuvat	?aabuvat =aabu  (KvtPrPs  >aabuma !27_V	et	f	\N
181526	aabuvat	?aabuvat =aabuva  (SgP  >aabuva !01_S	et	f	\N
181527	aabuvat	?aabuvat =aabuva  (SgP  >aabuv !02_A	et	f	\N
181528	astada	### astada	et	f	\N
181529	ündmusi	?ündmusi =ündmusi  (ID  >ündmusi !41_D	et	f	\N
181530	ündmusi	?ündmusi =ündmusi  (PlP  >ündmus !11_S	et	f	\N
181549	austria-ungari	?austria-ungari =ungari  (SgN  >austria-ungari !01_S	et	f	\N
181550	austria-ungari	?austria-ungari =ungari  (SgG  >austria-ungari !01_S	et	f	\N
181551	austria-ungari	?austria-ungari =ungari  (SgG  >austria-ungar !02_S	et	f	\N
181555	töötatud	töötatud =tööta  (PtsPtIps  >töötama !27_V	et	f	\N
181556	töötatud	töötatud =töötatu  (PlN  >töötatu !01_S	et	f	\N
181557	töötatud	"töötatu %tööta  )TU1_vS  <töötama ;27_V	et	f	\N
181558	töötatud	töötatud =töötatud  (ID  >töötatud !41_A	et	f	\N
181559	töötatud	"töötatud %tööta  )TUD_vA  <töötama ;27_V	et	f	\N
181566	makasupüüdliku	?makasupüüdliku =makasupüüdliku  (SgG  >makasupüüdlik !25_A	et	f	\N
181232	uuetele	?uuetele =uuetele  (IndPrPs_  >uuetelema !36_V	et	f	\N
181233	uuetele	?uuetele =uuetele  (ImpPrSg2  >uuetelema !36_V	et	f	\N
181236	hapute	?hapute =hapu  (IndPrPl2  >hapuma !27_V	et	f	\N
181241	puhavad	?puhavad =puha  (IndPrPl3  >puhama !27_V	et	f	\N
181242	puhavad	?puhavad =puhava  (PlN  >puhava !01_S	et	f	\N
181243	puhavad	?puhavad =puhava  (PlN  >puhav !02_A	et	f	\N
181247	muugavat	?muugavat =muuga  (KvtPrPs  >muugama !29_V	et	f	\N
181249	muugavat	?muugavat =muugava  (SgP  >muugava !01_S	et	f	\N
181250	muugavat	?muugavat =muugava  (SgP  >muugav !02_A	et	f	\N
181251	muugavat	?muugavat =gavat  (SgN  >muu+gavat !02_S	et	f	\N
181319	5juhtunud	juhtunud =juhtu  (PtsPtPs  >juhtuma !27_V	et	f	\N
181320	5juhtunud	juhtunud =juhtunu  (PlN  >juhtunu !01_S	et	f	\N
181321	5juhtunud	"juhtunu %juhtu  )NU_vS  <juhtuma ;27_V	et	f	\N
181322	5juhtunud	juhtunud =juhtunud  (ID  >juhtunud !41_A	et	f	\N
181323	5juhtunud	"juhtunud %juhtu  )NUD_vA  <juhtuma ;27_V	et	f	\N
181338	töötasusumma	töötasusumma =summa  (SgN  >töö+tasu+summa !16_S	et	f	\N
181340	töötasusumma	töötasusumma =summa  (SgG  >töö+tasu+summa !16_S	et	f	\N
181341	töötasusumma	töötasusumma =summa  (SgG  >töö+tasu+summ !22_S	et	f	\N
181343	töötasusumma	töötasusumma =summa  (SgG  >töö+tasu+sumb !22_S	et	f	\N
181344	töötasusumma	töötasusumma =summa  (SgP  >töö+tasu+summ !22_S	et	f	\N
181345	töötasusumma	töötasusumma =summa  (SgAdt  >töö+tasu+summ !22_S	et	f	\N
181346	valitatud	?valitatud =valita  (PtsPtIps  >valitama !27_V	et	f	\N
181347	valitatud	?valitatud =valitatu  (PlN  >valitatu !01_S	et	f	\N
181348	valitatud	?valitatud =valitatu  (IndPrSg2  >valitatuma !27_V	et	f	\N
181349	valitatud	?valitatud =valitatud  (ID  >valitatud !41_A	et	f	\N
181359	tervce	?tervce =tervce  (SgN  >tervce !06_S	et	f	\N
181360	tervce	?tervce =tervce  (SgG  >tervce !06_S	et	f	\N
181361	tervce	?tervce =tervce  (PlP  >tervc !22_S	et	f	\N
181372	rmastuse	?rmastuse =rmastuse  (SgG  >rmastus !11~09_S	et	f	\N
181373	oliitika	?oliitika =oliitika  (SgN  >oliitika !01_S	et	f	\N
181374	oliitika	?oliitika =oliitika  (SgG  >oliitika !01_S	et	f	\N
181375	oliitika	?oliitika =oliitika  (SgG  >oliitikas !02_A	et	f	\N
181376	leks	?leks =leks  (SgN  >leks !22_S	et	f	\N
181398	ehastab	?ehastab =ehasta  (IndPrSg3  >ehastama !27_V	et	f	\N
181418	uudab	?uudab =uuda  (IndPrSg3  >uudama !29_V	et	f	\N
181423	leninile	?leninile =lenini  (SgAll  >lenin !02_S	et	f	\N
181441	kehvem	kehvem =kehvem  (SgN  >kehvem !02_A	et	f	\N
181443	kehvem	"kehvem %kehve  )M_cA  <kehv ;22_A	et	f	\N
181447	lid	### lid	et	f	\N
181475	ätta	?ätta =ätta  (ID  >ätta !41_D	et	f	\N
181476	ätta	?ätta =ätta  (IndPrPs_  >ättama !29_V	et	f	\N
181477	ätta	?ätta =ätta  (ImpPrSg2  >ättama !29_V	et	f	\N
181480	leniniks	?leniniks =lenini  (SgTr  >lenin !02_S	et	f	\N
181481	nnestuks	?nnestuks =nnestu  (SgTr  >nnestu !16_S	et	f	\N
181482	nnestuks	?nnestuks =nnestu  (KndPrPs  >nnestuma !27_V	et	f	\N
181483	para	?para =para  (SgN  >para !17_S	et	f	\N
181484	para	?para =para  (SgG  >para !17_S	et	f	\N
181485	para	?para =para  (SgP  >para !17_S	et	f	\N
181486	para	?para =para  (IndPrPs_  >parama !27_V	et	f	\N
181487	para	?para =para  (ImpPrSg2  >parama !27_V	et	f	\N
181493	ehastanud	?ehastanud =ehasta  (PtsPtPs  >ehastama !27_V	et	f	\N
181494	ehastanud	?ehastanud =ehastanu  (PlN  >ehastanu !01_S	et	f	\N
181495	ehastanud	?ehastanud =ehastanu  (IndPrSg2  >ehastanuma !27_V	et	f	\N
181497	ehastanud	?ehastanud =ehastanud  (ID  >ehastanud !41_A	et	f	\N
181498	ehastanud	?ehastanud =stanu  (PlN  >eha+stanu !17_S	et	f	\N
181537	kodanikuõigused	kodanikuõigused =õiguse  (PlN  >kodaniku+õigus !11~09_S	et	f	\N
181538	kodanikuõigused	"kodaniku+õigus %õige  )US_aS  <kodaniku+õige ;01_A	et	f	\N
181571	ärele	?ärele =ärele  (IndPrPs_  >ärelema !31~27_V	et	f	\N
181572	ärele	?ärele =ärele  (ImpPrSg2  >ärelema !31~27_V	et	f	\N
181589	meeldejäävamad	meeldejäävamad =jäävama  (PlN  >meelde+jäävam !02_A	et	f	\N
181590	meeldejäävamad	"meelde+jäävam %jääva  )M_cA  <meelde+jääv ;02_A	et	f	\N
181592	ahetked	### ahetked	et	f	\N
181610	aatamist	?aatamist =aatami  (SgEl  >aatami !01_S	et	f	\N
181611	aatamist	?aatamist =aatami  (SgEl  >aatam !02_A	et	f	\N
181612	aatamist	?aatamist =aatamis  (SgP  >aatamis !11_S	et	f	\N
181613	aatamist	?aatamist =aatamis  (SgP  >aatamine !12_S	et	f	\N
181614	aatamist	?aatamist =aatamist  (SgN  >aatamist !22_S	et	f	\N
181615	undeid	?undeid =unde  (PlP  >unne !06_S	et	f	\N
181616	undeid	?undeid =undei  (PlN  >undei !26_S	et	f	\N
181617	undeid	?undeid =undei  (SgP  >undei !26_S	et	f	\N
181618	undeid	?undeid =undeid  (SgN  >undeid !22_S	et	f	\N
181646	äl	### äl	et	f	\N
181655	almistati	?almistati =almista  (IndIpfIps  >almistama !27_V	et	f	\N
181656	almistati	?almistati =almistati  (SgG  >almistatt !22_S	et	f	\N
181657	almistati	?almistati =almistati  (IndPrPs_  >almistattima !28_V	et	f	\N
181658	almistati	?almistati =almistati  (ImpPrSg2  >almistattima !28_V	et	f	\N
181659	enineid	?enineid =enine  (PlP  >enin !02_S	et	f	\N
181660	enineid	?enineid =eninei  (PlN  >eninei !26_S	et	f	\N
181272	vaatamisväärsusta	?vaatamisväärsusta =susta  (SgN  >vaatamis+väär+susta !16_S	et	f	\N
181273	vaatamisväärsusta	?vaatamisväärsusta =susta  (SgG  >vaatamis+väär+susta !16_S	et	f	\N
181274	vaatamisväärsusta	?vaatamisväärsusta =väärsusta  (SgN  >vaatamis+väärsusta !01_S	et	f	\N
181275	vaatamisväärsusta	?vaatamisväärsusta =väärsusta  (SgG  >vaatamis+väärsusta !01_S	et	f	\N
181276	vähedes	?vähedes =vähe  (Ger  >vähema !27_V	et	f	\N
181282	avades	avades =ava  (PlIn  >ava !17_S	et	f	\N
181283	avades	avades =ava  (Ger  >avama !27_V	et	f	\N
181284	4sõjamees	sõjamees =mee  (SgIn  >sõja+mesi !15_S	et	f	\N
181285	4sõjamees	sõjamees =mees  (SgN  >sõja+mees !13_S	et	f	\N
181298	kurbuses	kurbuses =kurbuse  (SgIn  >kurbus !11~09_S	et	f	\N
181299	kurbuses	"kurbus %kurb  )US_aS  <kurb ;22_A	et	f	\N
181300	kurbuses	kurbuses =use  (PlIn  >kurb+usk !22_S	et	f	\N
181301	majapidamistarvetesse	majapidamistarvetesse =e  (PlIll  >maja+pidamist+arv+esi !15_S	et	f	\N
181302	majapidamistarvetesse	majapidamistarvetesse =arve  (PlIll  >maja+pidamist+arve !06_S	et	f	\N
181303	majapidamistarvetesse	majapidamistarvetesse =tarve  (PlIll  >maja+pidamis+tarve !06_S	et	f	\N
181307	uuedega	### uuedega	et	f	\N
181310	4oksi	oksi =oksi  (SgG  >oks !22_S	et	f	\N
181311	4oksi	oksi =oksi  (SgP  >oks !22_S	et	f	\N
181312	4oksi	oksi =oksi  (SgAdt  >oks !22_S	et	f	\N
181313	4oksi	oksi =oksi  (PlP  >oks !23?22_S	et	f	\N
181326	kurbuseni	kurbuseni =kurbuse  (SgTer  >kurbus !11~09_S	et	f	\N
181327	kurbuseni	"kurbus %kurb  )US_aS  <kurb ;22_A	et	f	\N
181339	määramine	määramine =määramine  (SgN  >määramine !12_S	et	f	\N
181342	määramine	"määramine %määra  )MINE_vS  <määrama ;29_V	et	f	\N
181350	öeldatud	?öeldatud =öelda  (PtsPtIps  >öeldama !27_V	et	f	\N
181351	öeldatud	?öeldatud =öelda  (PtsPtIps  >öeltama !29_V	et	f	\N
181352	öeldatud	?öeldatud =öeldatu  (PlN  >öeldatu !01_S	et	f	\N
181353	öeldatud	?öeldatud =öeldatu  (IndPrSg2  >öeldatuma !27_V	et	f	\N
181354	öeldatud	?öeldatud =öeldatud  (ID  >öeldatud !41_A	et	f	\N
181362	tekinud	?tekinud =teki  (PtsPtPs  >tekima !27_V	et	f	\N
181363	tekinud	?tekinud =tekinu  (PlN  >tekinu !01_S	et	f	\N
181364	tekinud	?tekinud =tekinu  (IndPrSg2  >tekinuma !27_V	et	f	\N
181365	tekinud	?tekinud =tekinud  (ID  >tekinud !41_A	et	f	\N
181366	selgust	selgust =selgus  (SgP  >selgus !11~09_S	et	f	\N
181367	selgust	"selgus %selge  )US_aS  <selge ;01_A	et	f	\N
181368	selgust	selgust =us  (SgP  >selg+uks !14_S	et	f	\N
181371	mavahel	?mavahel =mavahel  (SgN  >mavahel !19_S	et	f	\N
181393	vahendavad	vahendavad =vahenda  (IndPrPl3  >vahendama !27_V	et	f	\N
181394	vahendavad	vahendavad =vahendava  (PlN  >vahendav !02_A	et	f	\N
181395	vahendavad	"vahendav %vahenda  )V_vA  <vahendama ;27_V	et	f	\N
181419	lemuse	?lemuse =lemuse  (SgG  >lemus !09_S	et	f	\N
181427	har	### har	et	f	\N
181434	manipuleeritav	manipuleeritav =manipuleeri  (PtsPrIps  >manipuleerima !28_V	et	f	\N
181435	manipuleeritav	manipuleeritav =manipuleeritav  (SgN  >manipuleeritav !02_A	et	f	\N
181436	manipuleeritav	"manipuleeritav %manipuleeri  )TAV_vAS  <manipuleerima ;28_V	et	f	\N
181446	vassilil	### vassilil	et	f	\N
181458	oomine	oomine =oomine  (SgN  >oomine !10_A	et	f	\N
181459	oomine	"oomine %oomi  )NE_aA  <oom ;22_S	et	f	\N
181460	lluviimise	?lluviimise =lluviimise  (SgG  >lluviimine !10_A	et	f	\N
181467	õõnestustööd	õõnestustööd =töö  (PlN  >õõnestus+töö !26_S	et	f	\N
181468	õõnestustööd	õõnestustööd =töö  (SgP  >õõnestus+töö !26_S	et	f	\N
181474	lluviimisel	?lluviimisel =lluviimise  (SgAd  >lluviimine !10_A	et	f	\N
181513	kõigutamatu	kõigutamatu =kõigutamatu  (SgN  >kõigutamatu !01_A	et	f	\N
181514	kõigutamatu	"kõigutamatu %kõigu  )TAMATU_vA  <kõikuma ;28_V	et	f	\N
181515	kõigutamatu	"kõigutamatu %kõiguta  )MATU_vA  <kõigutama ;27_V	et	f	\N
181516	kõigutamatu	kõigutamatu =kõigutamatu  (SgG  >kõigutamatu !01_A	et	f	\N
181517	ooni	?ooni =ooni  (SgN  >ooni !16_S	et	f	\N
181518	ooni	?ooni =ooni  (SgG  >ooni !16_S	et	f	\N
181519	ooni	?ooni =ooni  (SgG  >oon !22_S	et	f	\N
181520	ooni	?ooni =ooni  (SgP  >oon !22_S	et	f	\N
181522	ooni	?ooni =ooni  (SgAdt  >oon !22_S	et	f	\N
181523	ooni	?ooni =ooni  (IndPrPs_  >oonima !28_V	et	f	\N
181524	ooni	?ooni =ooni  (ImpPrSg2  >oonima !28_V	et	f	\N
181533	aloolist	?aloolist =alooli  (SgEl  >alooli !16_S	et	f	\N
181534	aloolist	?aloolist =alooli  (SgEl  >alool !22_S	et	f	\N
181535	aloolist	?aloolist =aloolis  (SgP  >aloolis !09_S	et	f	\N
181536	aloolist	?aloolist =aloolis  (SgP  >alooline !12?10_A	et	f	\N
181539	rakonnad	?rakonnad =rakonna  (PlN  >rakonna !16_S	et	f	\N
181540	rakonnad	?rakonnad =rakonna  (PlN  >rakond !22_S	et	f	\N
181546	lõhestasid	lõhestasid =lõhesta  (IndIpfSg2  >lõhestama !27_V	et	f	\N
181547	lõhestasid	lõhestasid =lõhesta  (IndIpfPl3  >lõhestama !27_V	et	f	\N
181569	lukorra	?lukorra =lukorra  (SgN  >lukorra !01_S	et	f	\N
181570	lukorra	?lukorra =lukorra  (SgG  >lukorra !01_S	et	f	\N
181573	inimestevahelised	inimestevahelised =vahelise  (PlN  >inimeste+vaheline !12_A	et	f	\N
181574	inimestevahelised	"inimeste+vaheline %vahe  )LINE_aA  <inimeste+vahe ;16_S	et	f	\N
181584	orrapealt	?orrapealt =orrapea  (SgAbl  >orrapea !26_S	et	f	\N
181405	riti	?riti =riti  (ImpPrSg2  >rittima !28_V	et	f	\N
181406	ehastama	?ehastama =ehasta  (Sup  >ehastama !27_V	et	f	\N
181407	ehastama	?ehastama =ehastama  (SgG  >ehastam !02_A	et	f	\N
181408	ehastama	?ehastama =stama  (SgN  >eha+stama !17_S	et	f	\N
181409	ehastama	?ehastama =stama  (SgG  >eha+stama !17_S	et	f	\N
181410	ehastama	?ehastama =stama  (SgP  >eha+stama !17_S	et	f	\N
181411	mamoodi	?mamoodi =mamoodi  (SgN  >mamoodi !16_S	et	f	\N
181412	mamoodi	?mamoodi =mamoodi  (SgG  >mamoodi !16_S	et	f	\N
181413	mamoodi	?mamoodi =mamoodi  (SgG  >mamoot !22_S	et	f	\N
181414	mamoodi	?mamoodi =mamoodi  (SgP  >mamood !22_S	et	f	\N
181415	mamoodi	?mamoodi =mamoodi  (SgAdt  >mamood !22_S	et	f	\N
181416	mamoodi	?mamoodi =mamoodi  (IndPrPs_  >mamootima !28_V	et	f	\N
181417	mamoodi	?mamoodi =mamoodi  (ImpPrSg2  >mamootima !28_V	et	f	\N
181431	vastikustunnet	### vastikustunnet	et	f	\N
181432	älgida	?älgida =älgi  (Inf  >älgima !28_V	et	f	\N
181438	matkimise	matkimise =matkimise  (SgG  >matkimine !12_S	et	f	\N
181439	matkimise	"matkimine %matki  )MINE_vS  <matkima ;28_V	et	f	\N
181450	kesküla	?kesküla =kesküla  (SgN  >kesküla !01_S	et	f	\N
181451	kesküla	?kesküla =kesküla  (SgG  >kesküla !01_S	et	f	\N
181452	kesküla	?kesküla =üla  (SgN  >kesk+üla !17_S	et	f	\N
181453	kesküla	?kesküla =üla  (SgG  >kesk+üla !17_S	et	f	\N
181454	kesküla	?kesküla =üla  (SgP  >kesk+üla !17_S	et	f	\N
181462	nõusta	nõusta =nõusta  (IndPrPs_  >nõustama !27_V	et	f	\N
181463	nõusta	nõusta =nõusta  (ImpPrSg2  >nõustama !27_V	et	f	\N
181488	alikuks	?alikuks =aliku  (SgTr  >aliku !01_S	et	f	\N
181489	alikuks	?alikuks =aliku  (SgTr  >alik !02_S	et	f	\N
181490	alikuks	?alikuks =aliku  (KndPrPs  >alikuma !27_V	et	f	\N
181492	leninit	?leninit =lenini  (SgP  >lenin !02_S	et	f	\N
181496	näitle	näitle =näitle  (IndPrPs_  >näitlema !30_V	et	f	\N
181499	näitle	näitle =näitle  (ImpPrSg2  >näitlema !30_V	et	f	\N
181500	ääv	?ääv =ääv  (SgN  >ääv !22_S	et	f	\N
181545	aväemässud	?aväemässud =aväemässu  (IndPrSg2  >aväemässuma !27_V	et	f	\N
181552	serbiat	?serbiat =serbia  (SgP  >serbia !01_S	et	f	\N
181553	serbiat	?serbiat =serbiat  (SgN  >serbiat !22_S	et	f	\N
181578	är	### är	et	f	\N
181594	koolitamisega	koolitamisega =koolitamise  (SgKom  >koolitamine !12_S	et	f	\N
181595	koolitamisega	"koolitamine %koolita  )MINE_vS  <koolitama ;27_V	et	f	\N
181619	õik	?õik =õik  (SgN  >õik !22_S	et	f	\N
181636	skumatu	?skumatu =skumatu  (SgN  >skumatu !01_A	et	f	\N
181637	skumatu	?skumatu =skumatu  (SgG  >skumatu !01_A	et	f	\N
181638	skumatu	?skumatu =skumatu  (IndPrPs_  >skumatuma !27_V	et	f	\N
181639	skumatu	?skumatu =skumatu  (ImpPrSg2  >skumatuma !27_V	et	f	\N
181651	atkenditest	?atkenditest =atkendi  (PlEl  >atkendi !01_S	et	f	\N
181652	atkenditest	?atkenditest =atkendi  (PlEl  >atkend !02_S	et	f	\N
181653	atkenditest	?atkenditest =atkendite  (PlEl  >atkenditt !22_S	et	f	\N
181654	atkenditest	?atkenditest =atkendites  (SgP  >atkenditene !12_A	et	f	\N
181669	eda	?eda =eda  (SgN  >eda !17_S	et	f	\N
181670	eda	?eda =eda  (SgG  >eda !17_S	et	f	\N
181671	eda	?eda =eda  (SgP  >eda !17_S	et	f	\N
181672	eda	?eda =eda  (IndPrPs_  >edama !27_V	et	f	\N
181673	eda	?eda =eda  (ImpPrSg2  >edama !27_V	et	f	\N
181759	ihiteadlik	?ihiteadlik =ihiteadlik  (SgN  >ihiteadlik !25_A	et	f	\N
181761	sooritamata	sooritamata =soorita  (SupAb  >sooritama !27_V	et	f	\N
181762	sooritamata	sooritamata =sooritamata  (ID  >sooritamata !41_A	et	f	\N
181763	sooritamata	"sooritamata %soorita  )MATA_vA  <sooritama ;27_V	et	f	\N
181764	nnestunud	?nnestunud =nnestu  (PtsPtPs  >nnestuma !27_V	et	f	\N
181765	nnestunud	?nnestunud =nnestunu  (PlN  >nnestunu !01_S	et	f	\N
181766	nnestunud	?nnestunud =nnestunu  (IndPrSg2  >nnestunuma !27_V	et	f	\N
181767	nnestunud	?nnestunud =nnestunud  (ID  >nnestunud !41_A	et	f	\N
181786	särnasid	?särnasid =särna  (PlP  >särna !16_S	et	f	\N
181788	särnasid	?särnasid =särna  (IndIpfSg2  >särnama !29_V	et	f	\N
181789	särnasid	?särnasid =särna  (IndIpfPl3  >särnama !29_V	et	f	\N
181790	bolsevik	?bolsevik =bolsevik  (SgN  >bolsevik !25_S	et	f	\N
181809	inimsurma	inimsurma =surma  (SgG  >inim+surm !22_S	et	f	\N
181810	inimsurma	inimsurma =surma  (SgP  >inim+surm !22_S	et	f	\N
181811	inimsurma	inimsurma =surma  (SgAdt  >inim+surm !22_S	et	f	\N
181822	uppuvaid	uppuvaid =uppuva  (PlP  >uppuv !02_A	et	f	\N
181823	uppuvaid	"uppuv %uppu  )V_vA  <uppuma ;28_V	et	f	\N
181828	tetavad	?tetavad =teta  (IndPrPl3  >tetama !27_V	et	f	\N
181829	tetavad	?tetavad =tetava  (PlN  >tetava !01_S	et	f	\N
181830	tetavad	?tetavad =tetava  (PlN  >tetav !02_A	et	f	\N
181845	päästaks	päästaks =päästa  (KndPrPs  >päästma !34_V	et	f	\N
181846	päästaks	päästaks =taks  (SgN  >pääs+taks !22_S	et	f	\N
181847	ebaõigluse	ebaõigluse =õigluse  (SgG  >eba+õiglus !11~09_S	et	f	\N
181848	ebaõigluse	"eba+õiglus %õiglase  )US_aS  <eba+õiglane ;12_A	et	f	\N
181855	arutleksid	arutleksid =arutle  (KndPrSg2  >arutlema !27_V	et	f	\N
181856	arutleksid	arutleksid =arutle  (KndPrPl3  >arutlema !27_V	et	f	\N
181859	näljakas	?näljakas =näljaka  (SgIn  >näljaka !01_S	et	f	\N
181543	iis	?iis =ii  (SgIn  >ii !26_S	et	f	\N
181544	iis	?iis =iis  (SgN  >iis !22_S	et	f	\N
181548	ategevust	?ategevust =ategevus  (SgP  >ategevus !11?09_S	et	f	\N
181554	aplaan	?aplaan =aplaan  (SgN  >aplaan !22_S	et	f	\N
181560	serbia	?serbia =serbia  (SgN  >serbia !01_S	et	f	\N
181561	serbia	?serbia =serbia  (SgG  >serbia !01_S	et	f	\N
181562	duka	?duka =duka  (SgN  >duka !16_S	et	f	\N
181563	duka	?duka =duka  (SgG  >duka !16_S	et	f	\N
181564	duka	?duka =duka  (IndPrPs_  >dukama !27_V	et	f	\N
181565	duka	?duka =duka  (ImpPrSg2  >dukama !27_V	et	f	\N
181582	kahepalgeline	kahepalgeline =palgeline  (SgN  >kahe+palgeline !12_A	et	f	\N
181583	kahepalgeline	"kahe+palgeline %palge  )LINE_aA  <kahe+pale ;06_S	et	f	\N
181591	nal	### nal	et	f	\N
181593	leninite	?leninite =lenini  (PlG  >lenin !02_S	et	f	\N
181603	õttes	?õttes =õtte  (SgIn  >õte !06_S	et	f	\N
181604	õttes	?õttes =õtte  (IndIpfSg3  >õttema !27_V	et	f	\N
181605	õttes	?õttes =õttes  (SgN  >õttes !09_S	et	f	\N
181606	uleb	?uleb =ule  (IndPrSg3  >ulema !27_V	et	f	\N
181607	alooga	?alooga =aloo  (SgKom  >aloo !26_S	et	f	\N
181608	alooga	?alooga =alooga  (SgN  >alooga !16_S	et	f	\N
181609	alooga	?alooga =alooga  (SgG  >alooga !16_S	et	f	\N
181620	õib-	?õib- =õib  (SgN  >õib !22_S	et	f	\N
181625	üzee	?üzee =üzee  (SgN  >üzee !26_S	et	f	\N
181626	üzee	?üzee =üzee  (SgG  >üzee !26_S	et	f	\N
181629	rvates	?rvates =rvate  (PlIn  >rvatt !22_S	et	f	\N
181630	rvates	?rvates =rvate  (IndIpfSg3  >rvatema !27_V	et	f	\N
181631	rvates	?rvates =rvates  (SgN  >rvates !09_S	et	f	\N
181634	enini	?enini =eni  (SgTer  >eni !17_S	et	f	\N
181635	enini	?enini =enini  (SgG  >enin !02_S	et	f	\N
181640	eniniga	?eniniga =enini  (SgKom  >enin !02_S	et	f	\N
181647	etamatu	?etamatu =etamatu  (SgN  >etamatu !01_A	et	f	\N
181648	etamatu	?etamatu =etamatu  (SgG  >etamatu !01_A	et	f	\N
181649	etamatu	?etamatu =etamatu  (IndPrPs_  >etamatuma !27_V	et	f	\N
181650	etamatu	?etamatu =etamatu  (ImpPrSg2  >etamatuma !27_V	et	f	\N
181677	esküla	?esküla =esküla  (SgN  >esküla !01_S	et	f	\N
181678	esküla	?esküla =esküla  (SgG  >esküla !01_S	et	f	\N
181681	uure	uure =uure  (SgN  >uure !06_S	et	f	\N
181682	uure	uure =uure  (PlP  >uur !22_S	et	f	\N
181717	eadlik	?eadlik =eadlik  (SgN  >eadlik !25_A	et	f	\N
181721	ihti	?ihti =ihti  (ID  >ihti !41_D	et	f	\N
181722	ihti	?ihti =ihti  (SgP  >iht !22_S	et	f	\N
181723	ihti	?ihti =ihti  (SgAdt  >iht !22_S	et	f	\N
181751	õib	?õib =õib  (SgN  >õib !22_S	et	f	\N
181752	õlemad	?õlemad =õlema  (PlN  >õlem !02_A	et	f	\N
181755	vantürist	?vantürist =vantüri  (SgEl  >vantüri !01_S	et	f	\N
181756	vantürist	?vantürist =vantüri  (SgEl  >vantür !02_S	et	f	\N
181757	vantürist	?vantürist =vantüris  (SgP  >vantüris !11_S	et	f	\N
181758	vantürist	?vantürist =vantürist  (SgN  >vantürist !22_S	et	f	\N
181780	eniniks	?eniniks =enini  (SgTr  >enin !02_S	et	f	\N
181812	vereta	vereta =vere  (SgAb  >veri !20_S	et	f	\N
181813	vereta	vereta =vereta  (IndPrPs_  >veretama !27_V	et	f	\N
181814	vereta	vereta =vereta  (ImpPrSg2  >veretama !27_V	et	f	\N
181820	tänapäevasest	tänapäevasest =päevase  (SgEl  >täna+päevane !10_A	et	f	\N
181821	tänapäevasest	"täna+päevane %päeva  )NE_aA  <täna+päev ;22_S	et	f	\N
181831	kanaari	?kanaari =kanaari  (SgN  >kanaari !16_S	et	f	\N
181832	kanaari	?kanaari =kanaari  (SgG  >kanaari !16_S	et	f	\N
181833	kanaari	?kanaari =kanaari  (SgG  >kanaar !22_S	et	f	\N
181834	kanaari	?kanaari =kanaari  (SgP  >kanaar !22_S	et	f	\N
181835	kanaari	?kanaari =kanaari  (SgAdt  >kanaar !22_S	et	f	\N
181836	kanaari	?kanaari =kanaari  (IndPrPs_  >kanaarima !28_V	et	f	\N
181837	kanaari	?kanaari =kanaari  (ImpPrSg2  >kanaarima !28_V	et	f	\N
181838	kanaari	?kanaari =ari  (SgN  >kana+ari !17_S	et	f	\N
181839	kanaari	?kanaari =ari  (SgG  >kana+ari !17_S	et	f	\N
181840	kanaari	?kanaari =ari  (SgP  >kana+ari !17_S	et	f	\N
181857	vaadaks	?vaadaks =vaada  (SgTr  >vaada !16_S	et	f	\N
181858	vaadaks	?vaadaks =vaada  (KndPrPs  >vaadama !29_V	et	f	\N
181903	leninita	?leninita =lenini  (SgAb  >lenin !02_S	et	f	\N
181904	leninita	?leninita =leninita  (IndPrPs_  >leninitama !27_V	et	f	\N
181905	leninita	?leninita =leninita  (ImpPrSg2  >leninitama !27_V	et	f	\N
181906	suur-eestimaa	suur-eestimaa =maa  (SgN  >suur-eesti+maa !26_S	et	f	\N
181907	suur-eestimaa	suur-eestimaa =maa  (SgG  >suur-eesti+maa !26_S	et	f	\N
181916	uppub	### uppub	et	f	\N
181928	eneseteadvuse	eneseteadvuse =teadvuse  (SgG  >enese+teadvus !11~09_S	et	f	\N
181929	eneseteadvuse	"enese+teadvus %teadva  )US_aS  <enese+teadev ;02_A	et	f	\N
181938	ekspordiks	ekspordiks =ekspordi  (SgTr  >eksport !22_S	et	f	\N
181939	ekspordiks	ekspordiks =ekspordi  (KndPrPs  >eksportima !28_V	et	f	\N
181945	rühmituse	rühmituse =rühmituse  (SgG  >rühmitus !11_S	et	f	\N
181946	rühmituse	"rühmitus %rühmita  )US_vS  <rühmitama ;27_V	et	f	\N
181947	rühmituse	"rühmitus %rühmi  )TUS2_aS  <rühm ;22_S	et	f	\N
181964	ekspermenteeritud	?ekspermenteeritud =ekspermenteeri  (PtsPtIps  >ekspermenteerima !28_V	et	f	\N
181567	makasupüüdliku	?makasupüüdliku =makasupüüdliku  (IndPrPs_  >makasupüüdlikuma !27_V	et	f	\N
181568	makasupüüdliku	?makasupüüdliku =makasupüüdliku  (ImpPrSg2  >makasupüüdlikuma !27_V	et	f	\N
181575	filmistsenaariumi	filmistsenaariumi =stsenaariumi  (SgG  >filmi+stsenaarium !19~02_S	et	f	\N
181576	filmistsenaariumi	filmistsenaariumi =stsenaariumi  (SgP  >filmi+stsenaarium !19_S	et	f	\N
181577	filmistsenaariumi	filmistsenaariumi =stsenaariumi  (SgAdt  >filmi+stsenaarium !19_S	et	f	\N
181579	ekordselt	?ekordselt =ekordse  (SgAbl  >ekordne !02_A	et	f	\N
181580	ekordselt	?ekordselt =ekordse  (PlAbl  >ekords !22_S	et	f	\N
181581	ekordselt	?ekordselt =ekordselt  (ID  >ekordselt !41_D	et	f	\N
181586	nimellihtsalt	?nimellihtsalt =nimellihtsa  (SgAbl  >nimellihtsa !16_S	et	f	\N
181587	nimellihtsalt	?nimellihtsalt =nimellihtsalt  (ID  >nimellihtsalt !41_D	et	f	\N
181596	eninitele	?eninitele =enini  (PlAll  >enin !02_S	et	f	\N
181597	eninitele	?eninitele =eninite  (PlAll  >eninitt !22_S	et	f	\N
181598	eninitele	?eninitele =eninitele  (IndPrPs_  >eninitelema !36_V	et	f	\N
181599	eninitele	?eninitele =eninitele  (ImpPrSg2  >eninitelema !36_V	et	f	\N
181600	petada	?petada =peta  (Inf  >petama !27_V	et	f	\N
181601	leninlikku	leninlikku =leninlikku  (SgP  >leninlik !25_A	et	f	\N
181602	leninlikku	leninlikku =leninlikku  (SgAdt  >leninlik !25_A	et	f	\N
181621	ingitud	?ingitud =ingi  (PtsPtIps  >inkima !28_V	et	f	\N
181622	ingitud	?ingitud =ingitu  (PlN  >ingitu !01_AS	et	f	\N
181623	ingitud	?ingitud =ingitu  (IndPrSg2  >ingituma !27_V	et	f	\N
181624	ingitud	?ingitud =ingitud  (ID  >ingitud !41_A	et	f	\N
181632	üllatavam	üllatavam =üllatavam  (SgN  >üllatavam !02_A	et	f	\N
181633	üllatavam	"üllatavam %üllata  )VAM_cA  <üllatama ;27_V	et	f	\N
181641	ooksul	?ooksul =ooksu  (SgAd  >ooksu !01_S	et	f	\N
181642	ooksul	?ooksul =ooksul  (SgN  >ooksul !02_S	et	f	\N
181643	oomus	?oomus =oomu  (SgIn  >oomu !16_S	et	f	\N
181644	oomus	?oomus =oomu  (IndIpfSg3  >oomuma !27_V	et	f	\N
181645	oomus	?oomus =oomus  (SgN  >oomus !11~09_S	et	f	\N
181662	sandri	?sandri =sandri  (SgN  >sandri !01_S	et	f	\N
181663	sandri	?sandri =sandri  (SgG  >sandri !01_S	et	f	\N
181664	sandri	?sandri =sandri  (SgG  >sander !02_S	et	f	\N
181665	sandri	?sandri =sandri  (IndPrPs_  >sandrima !28_V	et	f	\N
181666	sandri	?sandri =sandri  (ImpPrSg2  >sandrima !28_V	et	f	\N
181668	eist	?eist =eist  (SgN  >eist !22_S	et	f	\N
181679	õttis	?õttis =õtti  (IndIpfSg3  >õttima !28_V	et	f	\N
181680	õttis	?õttis =õttis  (ID  >õttis !41_DA	et	f	\N
181690	õh	?õh =õh  (ID  >õh !41_I	et	f	\N
181695	ingerimaasi	?ingerimaasi =ingerimaasi  (SgN  >ingerimaasi !16_S	et	f	\N
181696	ingerimaasi	?ingerimaasi =ingerimaasi  (SgG  >ingerimaasi !16_S	et	f	\N
181697	ingerimaasi	?ingerimaasi =ingerimaasi  (SgG  >ingerimaas !22_S	et	f	\N
181698	ingerimaasi	?ingerimaasi =ingerimaasi  (SgP  >ingerimaas !22_S	et	f	\N
181699	ingerimaasi	?ingerimaasi =ingerimaasi  (SgAdt  >ingerimaas !22_S	et	f	\N
181700	ingerimaasi	?ingerimaasi =ingerimaasi  (IndPrPs_  >ingerimaasima !28_V	et	f	\N
181701	ingerimaasi	?ingerimaasi =ingerimaasi  (ImpPrSg2  >ingerimaasima !28_V	et	f	\N
181702	ingerimaasi	?ingerimaasi =maasi  (SgN  >ingeri+maasi !16_S	et	f	\N
181703	ingerimaasi	?ingerimaasi =maasi  (SgG  >ingeri+maasi !16_S	et	f	\N
181704	soomega	?soomega =mega  (SgN  >soo+mega !17_S	et	f	\N
181705	soomega	?soomega =mega  (SgG  >soo+mega !17_S	et	f	\N
181706	soomega	?soomega =mega  (SgP  >soo+mega !17_S	et	f	\N
181707	inult	?inult =inu  (SgAbl  >inu !17_S	et	f	\N
181708	inult	?inult =inult  (ID  >inult !41_D	et	f	\N
181709	deede	?deede =dee  (PlG  >dee !26_S	et	f	\N
181710	deede	?deede =deede  (SgN  >deede !06_S	et	f	\N
181711	deede	?deede =deede  (PlP  >deed !22_S	et	f	\N
181713	deede	?deede =deede  (IndPrPs_  >deedema !27_V	et	f	\N
181715	deede	?deede =deede  (ImpPrSg2  >deedema !27_V	et	f	\N
181724	htlikus	?htlikus =htliku  (SgIn  >htliku !16_S	et	f	\N
181725	htlikus	?htlikus =htliku  (SgIn  >htlikk !22_S	et	f	\N
181726	htlikus	?htlikus =htliku  (IndIpfSg3  >htlikuma !27_V	et	f	\N
181727	htlikus	?htlikus =htlikus  (SgN  >htlikus !09_S	et	f	\N
181728	almis	?almis =almi  (SgIn  >almi !16_S	et	f	\N
181729	almis	?almis =almi  (SgIn  >alm !22_S	et	f	\N
181730	almis	?almis =almi  (IndIpfSg3  >almima !28_V	et	f	\N
181731	almis	?almis =almis  (SgN  >almis !09_S	et	f	\N
181732	õgeneda	?õgeneda =õgene  (Inf  >õgenema !27_V	et	f	\N
181737	arta	?arta =arta  (SgN  >arta !16_S	et	f	\N
181738	arta	?arta =arta  (SgG  >arta !16_S	et	f	\N
181739	arta	?arta =arta  (IndPrPs_  >artama !29_V	et	f	\N
181740	arta	?arta =arta  (ImpPrSg2  >artama !29_V	et	f	\N
181791	patriotismi	patriotismi =patriotismi  (SgG  >patriotism !22_S	et	f	\N
181792	patriotismi	patriotismi =patriotismi  (SgP  >patriotism !22_S	et	f	\N
181793	patriotismi	patriotismi =patriotismi  (SgAdt  >patriotism !22_S	et	f	\N
181794	rezissööril	?rezissööril =rezissööri  (SgAd  >rezissööri !16_S	et	f	\N
181795	rezissööril	?rezissööril =rezissööri  (SgAd  >rezissöör !22_S	et	f	\N
181796	rezissööril	?rezissööril =rezissööril  (SgN  >rezissööril !02_S	et	f	\N
181804	ekspluateerimise	ekspluateerimise =ekspluateerimise  (SgG  >ekspluateerimine !12_S	et	f	\N
181585	orrapealt	?orrapealt =orrapealt  (ID  >orrapealt !41_D	et	f	\N
181588	asulik	?asulik =asulik  (SgN  >asulik !25_A	et	f	\N
181627	eeruline	?eeruline =eeruline  (SgN  >eeruline !12_A	et	f	\N
181628	eeruline	?eeruline =eeruline  (PlP  >eerulin !19_S	et	f	\N
181667	evolutsionäär	?evolutsionäär =evolutsionäär  (SgN  >evolutsionäär !22_S	et	f	\N
181674	eterburi	?eterburi =eterburi  (SgG  >eterbur !19_S	et	f	\N
181675	eterburi	?eterburi =eterburi  (SgP  >eterbur !19_S	et	f	\N
181676	eterburi	?eterburi =eterburi  (SgAdt  >eterbur !19_S	et	f	\N
181691	a-lätist	?a-lätist =läti  (SgEl  >a-läti !16_S	et	f	\N
181692	a-lätist	?a-lätist =läti  (SgEl  >a-lätt !22_S	et	f	\N
181693	a-lätist	?a-lätist =lätis  (SgP  >a-lätis !09_S	et	f	\N
181694	a-lätist	?a-lätist =lätist  (SgN  >a-lätist !22_S	et	f	\N
181712	propageeri	propageeri =propageeri  (IndPrPs_  >propageerima !28_V	et	f	\N
181714	propageeri	propageeri =propageeri  (ImpPrSg2  >propageerima !28_V	et	f	\N
181718	aristatav	?aristatav =arista  (PtsPrIps  >aristama !27_V	et	f	\N
181719	aristatav	?aristatav =aristata  (PtsPrPs  >aristatama !27_V	et	f	\N
181720	aristatav	?aristatav =aristatav  (SgN  >aristatav !02_A	et	f	\N
181744	htis	### htis	et	f	\N
181745	nneotsi	?nneotsi =nneotsi  (ID  >nneotsi !41_D	et	f	\N
181746	nneotsi	?nneotsi =nneotsi  (SgG  >nneots !22_S	et	f	\N
181747	nneotsi	?nneotsi =nneotsi  (SgP  >nneots !22_S	et	f	\N
181748	nneotsi	?nneotsi =nneotsi  (SgAdt  >nneots !22_S	et	f	\N
181749	nneotsi	?nneotsi =nneotsi  (IndPrPs_  >nneotsima !28_V	et	f	\N
181750	nneotsi	?nneotsi =nneotsi  (ImpPrSg2  >nneotsima !28_V	et	f	\N
181753	rvamused	?rvamused =rvamuse  (PlN  >rvamus !09_S	et	f	\N
181754	iged	?iged =ige  (IndPrSg2  >igema !27_V	et	f	\N
181760	äid	?äid =äid  (SgN  >äid !22_S	et	f	\N
181768	fi1mi1	?fimi =fimi  (SgN  >fimi !17_S	et	f	\N
181769	fi1mi1	?fimi =fimi  (SgG  >fimi !17_S	et	f	\N
181770	fi1mi1	?fimi =fimi  (SgP  >fimi !17_S	et	f	\N
181771	fi1mi1	?fimi =fimi  (IndPrPs_  >fimima !27_V	et	f	\N
181772	fi1mi1	?fimi =fimi  (ImpPrSg2  >fimima !27_V	et	f	\N
181777	enin	?enin =eni  (IndPrSg1  >enima !27_V	et	f	\N
181778	enin	?enin =enin  (SgN  >enin !02_S	et	f	\N
181779	eetakse	?eetakse =eetakse  (SgG  >eetakne !02_A	et	f	\N
181797	rezissööri	?rezissööri =rezissööri  (SgN  >rezissööri !16_S	et	f	\N
181798	rezissööri	?rezissööri =rezissööri  (SgG  >rezissööri !16_S	et	f	\N
181799	rezissööri	?rezissööri =rezissööri  (SgG  >rezissöör !22_S	et	f	\N
181800	rezissööri	?rezissööri =rezissööri  (SgP  >rezissöör !22_S	et	f	\N
181801	rezissööri	?rezissööri =rezissööri  (SgAdt  >rezissöör !22_S	et	f	\N
181802	rezissööri	?rezissööri =rezissööri  (IndPrPs_  >rezissöörima !28_V	et	f	\N
181803	rezissööri	?rezissööri =rezissööri  (ImpPrSg2  >rezissöörima !28_V	et	f	\N
181849	kinematograafia	kinematograafia =kinematograafia  (SgN  >kinematograafia !01_S	et	f	\N
181850	kinematograafia	kinematograafia =kinematograafia  (SgG  >kinematograafia !01_S	et	f	\N
181851	mõeldut	mõeldut =mõeldu  (SgP  >mõeldu !01_S	et	f	\N
181852	mõeldut	"mõeldu %mõel  )TU1_vS  <mõtlema ;30_V	et	f	\N
181853	istuksid	istuksid =istu  (KndPrSg2  >istuma !28_V	et	f	\N
181854	istuksid	istuksid =istu  (KndPrPl3  >istuma !28_V	et	f	\N
181876	pealiskaudselt	pealiskaudselt =kaudse  (SgAbl  >pealis+kaudne !02_A	et	f	\N
181877	pealiskaudselt	"pealis+kaudselt %kaudse  )LT_mD  <pealis+kaudne ;02_A	et	f	\N
181878	eakaaslastest	eakaaslastest =test  (SgN  >ea+kaaslas+test !22_S	et	f	\N
181879	eakaaslastest	eakaaslastest =las  (PlEl  >ea+kaas+laps !14_S	et	f	\N
181880	eakaaslastest	eakaaslastest =laste  (PlEl  >ea+kaas+last !22_S	et	f	\N
181881	eakaaslastest	eakaaslastest =kaaslas  (PlEl  >ea+kaaslane !12?10_S	et	f	\N
181894	napoleonil	?napoleonil =napoleoni  (SgAd  >napoleoni !16_S	et	f	\N
181895	napoleonil	?napoleonil =napoleoni  (SgAd  >napoleon !19_S	et	f	\N
181896	napoleonil	?napoleonil =napoleonil  (SgN  >napoleonil !02_S	et	f	\N
181899	surve	surve =surve  (SgN  >surve !06_S	et	f	\N
181900	surve	surve =surve  (SgG  >surve !06_S	et	f	\N
181908	juhtubme	?juhtubme =juhtubme  (PlP  >juhtubm !22_S	et	f	\N
181909	juhtubme	?juhtubme =ubme  (SgN  >juht+ubme !06_S	et	f	\N
181910	juhtubme	?juhtubme =ubme  (SgG  >juht+ubme !06_S	et	f	\N
181911	juhtubme	?juhtubme =ubme  (PlP  >juht+ubm !22_S	et	f	\N
181914	hullusena	hullusena =hulluse  (SgEs  >hullus !11~09_S	et	f	\N
181915	hullusena	"hullus %hull  )US_aS  <hull ;22_AS	et	f	\N
181917	naerualuseks	naerualuseks =seks  (SgN  >naeru+alu+seks !22_S	et	f	\N
181918	naerualuseks	naerualuseks =aluse  (SgTr  >naeru+alus !09_S	et	f	\N
181919	naerualuseks	naerualuseks =aluse  (SgTr  >naeru+alune !10_AS	et	f	\N
181920	naerualuseks	"naeru+alune %alu  )NE_aA  <naeru+alg ;22_S	et	f	\N
181924	arvamise	arvamise =arvamise  (SgG  >arvamine !12_S	et	f	\N
181925	arvamise	"arvamine %arva  )MINE_vS  <arvama ;29_V	et	f	\N
181935	turgu	turgu =turgu  (SgP  >turg !22_S	et	f	\N
181936	turgu	turgu =turgu  (SgAdt  >turg !22_S	et	f	\N
181948	noor-eesti	noor-eesti =eesti  (ID  >noor-eesti !41_G	et	f	\N
181949	noor-eesti	noor-eesti =eesti  (SgN  >noor-eesti !16_H	et	f	\N
181950	noor-eesti	noor-eesti =eesti  (SgG  >noor-eesti !16_H	et	f	\N
181661	enineid	?enineid =eninei  (SgP  >eninei !26_S	et	f	\N
181683	evolutsioonitegevuses	evolutsioonitegevuses =use  (PlIn  >evolutsiooni+tegev+usk !22_S	et	f	\N
181684	evolutsioonitegevuses	evolutsioonitegevuses =tegevuse  (SgIn  >evolutsiooni+tegevus !11_S	et	f	\N
181685	evolutsioonitegevuses	"evolutsiooni+tegevus %tegeva  )US_aS  <evolutsiooni+tegev ;02_A	et	f	\N
181686	estist	?estist =esti  (SgEl  >esti !16_S	et	f	\N
181687	estist	?estist =esti  (SgEl  >est !22_S	et	f	\N
181688	estist	?estist =estis  (SgP  >estis !09_S	et	f	\N
181689	estist	?estist =estist  (SgN  >estist !22_S	et	f	\N
181716	ealiseerida	?ealiseerida =ealiseeri  (Inf  >ealiseerima !28_V	et	f	\N
181733	õned	?õned =õne  (PlN  >õne !16_S	et	f	\N
181734	õned	?õned =õne  (IndPrSg2  >õnema !27_V	et	f	\N
181735	õimekaks	?õimekaks =õimeka  (SgTr  >õimeka !01_S	et	f	\N
181736	õimekaks	?õimekaks =õimeka  (SgTr  >õimekas !02_A	et	f	\N
181741	äidasid	?äidasid =äida  (PlP  >äida !16_S	et	f	\N
181742	äidasid	?äidasid =äida  (IndIpfSg2  >äidama !29_V	et	f	\N
181743	äidasid	?äidasid =äida  (IndIpfPl3  >äidama !29_V	et	f	\N
181773	unnustatud	?unnustatud =unnusta  (PtsPtIps  >unnustama !27_V	et	f	\N
181774	unnustatud	?unnustatud =unnustatu  (PlN  >unnustatu !01_S	et	f	\N
181775	unnustatud	?unnustatud =unnustatu  (IndPrSg2  >unnustatuma !27_V	et	f	\N
181776	unnustatud	?unnustatud =unnustatud  (ID  >unnustatud !41_A	et	f	\N
181781	okuvõttes	### okuvõttes	et	f	\N
181782	õin	?õin =õin  (SgN  >õin !22_S	et	f	\N
181783	ilmselge	ilmselge =selge  (SgN  >ilm+selge !01_A	et	f	\N
181784	ilmselge	ilmselge =selge  (SgG  >ilm+selge !01_A	et	f	\N
181785	ilmselge	ilmselge =selge  (PlP  >ilm+selg !22_S	et	f	\N
181787	bolsevikide	?bolsevikide =bolseviki  (PlG  >bolsevik !25_S	et	f	\N
181806	ebavõrdsuse	ebavõrdsuse =võrdsuse  (SgG  >eba+võrdsus !11~09_S	et	f	\N
181807	ebavõrdsuse	"eba+võrdsus %võrdse  )US_aS  <eba+võrdne ;02_A	et	f	\N
181815	lindi	lindi =lindi  (SgG  >lint !22_S	et	f	\N
181816	lindi	lindi =lindi  (SgP  >lind !22_S	et	f	\N
181817	lindi	lindi =lindi  (SgAdt  >lind !22_S	et	f	\N
181818	reaalsest	reaalsest =reaalse  (SgEl  >reaalne !02_A	et	f	\N
181819	reaalsest	reaalsest =alse  (PlEl  >rea+alss !22_S	et	f	\N
181862	sagedam	sagedam =sagedam  (SgN  >sagedam !02_A	et	f	\N
181863	sagedam	"sagedam %sageda  )M_cA  <sage ;02_A	et	f	\N
181897	purustamine	purustamine =purustamine  (SgN  >purustamine !12_S	et	f	\N
181898	purustamine	"purustamine %purusta  )MINE_vS  <purustama ;27_V	et	f	\N
181921	loetle	loetle =loetle  (IndPrPs_  >loetlema !27_V	et	f	\N
181922	loetle	loetle =loetle  (ImpPrSg2  >loetlema !27_V	et	f	\N
181923	valgustusesaj	### valgustusesaj	et	f	\N
181926	masarahva	?masarahva =masarahva  (SgN  >masarahva !16_S	et	f	\N
181927	masarahva	?masarahva =masarahva  (SgG  >masarahva !16_S	et	f	\N
181930	kreutzwaldil	?kreutzwaldil =kreutzwaldi  (SgAd  >kreutzwaldi !01_S	et	f	\N
181931	kreutzwaldil	?kreutzwaldil =kreutzwaldi  (SgAd  >kreutzwald !02_S	et	f	\N
181932	pol	### pol	et	f	\N
181940	profiili	profiili =profiili  (SgG  >profiil !22_S	et	f	\N
181941	profiili	profiili =profiili  (SgP  >profiil !22_S	et	f	\N
181942	profiili	profiili =profiili  (SgAdt  >profiil !22_S	et	f	\N
181943	profiili	profiili =profiili  (IndPrPs_  >profiilima !28_V	et	f	\N
181944	profiili	profiili =profiili  (ImpPrSg2  >profiilima !28_V	et	f	\N
181958	friedeberg	?friedeberg =friedeberg  (SgN  >friedeberg !22_S	et	f	\N
181976	pos	### pos	et	f	\N
181984	postimehele	postimehele =hele  (SgN  >post+ime+hele !02_A	et	f	\N
181985	postimehele	postimehele =mehe  (SgAll  >posti+mees !13_S	et	f	\N
182002	elankutele	?elankutele =elanku  (PlAll  >elanku !01_S	et	f	\N
182003	elankutele	?elankutele =elankute  (PlAll  >elankutt !22_S	et	f	\N
182004	elankutele	?elankutele =elankutele  (IndPrPs_  >elankutelema !36_V	et	f	\N
182005	elankutele	?elankutele =elankutele  (ImpPrSg2  >elankutelema !36_V	et	f	\N
182029	aktiivsemalt	aktiivsemalt =aktiivsema  (SgAbl  >aktiivsem !02_A	et	f	\N
182030	aktiivsemalt	"aktiivsem %aktiivse  )M_cA  <aktiivne ;02_A	et	f	\N
182031	aktiivsemalt	aktiivsemalt =aktiivsemalt  (ID  >aktiivsemalt !41_D	et	f	\N
182032	aktiivsemalt	"aktiivsemalt %aktiivse  )MALT_mD  <aktiivne ;02_A	et	f	\N
182035	heategevuse	heategevuse =tegevuse  (SgG  >hea+tegevus !11_S	et	f	\N
182036	heategevuse	"hea+tegevus %tegeva  )US_aS  <hea+tegev ;02_A	et	f	\N
182049	siided	?siided =siide  (IndPrSg2  >siidema !27_V	et	f	\N
182063	kog	### kog	et	f	\N
182101	25aug	?aug =aug  (SgN  >aug !22_S	et	f	\N
182111	tööliseeltsid	?tööliseeltsid =tööliseeltsi  (IndPrSg2  >tööliseeltsima !28_V	et	f	\N
182112	tööliseeltsid	?tööliseeltsid =eltsi  (PlN  >tööl+ise+elts !22_S	et	f	\N
182113	tööliseeltsid	?tööliseeltsid =eeltsi  (PlN  >töölis+eelts !22_S	et	f	\N
182114	tööliseeltsid	?tööliseeltsid =iseeltsi  (PlN  >tööl+iseeltsi !01_S	et	f	\N
182115	tööliseeltsid	?tööliseeltsid =iseeltsi  (PlN  >tööl+iseelts !22_S	et	f	\N
182120	seltsiliige	seltsiliige =liige  (SgN  >seltsi+liige !05_S	et	f	\N
182121	seltsiliige	seltsiliige =liige  (PlP  >seltsi+liig !22_S	et	f	\N
182124	kaastööliste	kaastööliste =iste  (SgN  >kaas+tööl+iste !05_S	et	f	\N
182125	kaastööliste	kaastööliste =iste  (SgN  >kaas+tööl+iste !06_S	et	f	\N
181805	ekspluateerimise	"ekspluateerimine %ekspluateeri  )MINE_vS  <ekspluateerima ;28_V	et	f	\N
181808	organizeerida	?organizeerida =organizeeri  (Inf  >organizeerima !28_V	et	f	\N
181824	luksuses	luksuses =luksuse  (SgIn  >luksus !11~09_S	et	f	\N
181825	luksuses	luksuses =use  (PlIn  >luks+usk !22_S	et	f	\N
181826	pügikastides	?pügikastides =pügikasti  (Ger  >pügikastima !28_V	et	f	\N
181827	riig	?riig =riig  (SgN  >riig !22_S	et	f	\N
181841	riigiraha	riigiraha =raha  (SgN  >riigi+raha !17_S	et	f	\N
181842	riigiraha	riigiraha =raha  (SgG  >riigi+raha !17_S	et	f	\N
181843	riigiraha	riigiraha =raha  (SgG  >riigi+rahk !22_S	et	f	\N
181844	riigiraha	riigiraha =raha  (SgP  >riigi+raha !17_S	et	f	\N
181901	vähendamine	vähendamine =vähendamine  (SgN  >vähendamine !12_S	et	f	\N
181902	vähendamine	"vähendamine %vähenda  )MINE_vS  <vähendama ;27_V	et	f	\N
181912	absuurdne	?absuurdne =absuurdne  (SgN  >absuurdne !02_A	et	f	\N
181913	absuurdne	?absuurdne =absuurdne  (PlP  >absuurdn !22_S	et	f	\N
181937	suht	?suht =suht  (SgN  >suht !22_S	et	f	\N
181956	luulel	luulel =luule  (SgAd  >luule !06_S	et	f	\N
181957	luulel	luulel =luule  (PlAd  >luul !22_S	et	f	\N
181961	avatusest	avatusest =avatuse  (SgEl  >avatus !11_S	et	f	\N
181962	avatusest	"avatus %ava  )TUS1_aS  <avama ;27_V	et	f	\N
181963	avatusest	"avatus %ava  )TUS2_aS  <ava ;17_S	et	f	\N
181978	vaimult	vaimult =vaimu  (SgAbl  >vaim !22_S	et	f	\N
181979	vaimult	vaimult =vaimu  (PlAbl  >vaim !22_S	et	f	\N
181998	orienteeritus	orienteeritus =orienteeritu  (SgIn  >orienteeritu !01_S	et	f	\N
181999	orienteeritus	"orienteeritu %orienteeri  )TU1_vS  <orienteerima ;28_V	et	f	\N
182000	orienteeritus	orienteeritus =orienteeritus  (SgN  >orienteeritus !11_S	et	f	\N
182001	orienteeritus	"orienteeritus %orienteeri  )TUS1_aS  <orienteerima ;28_V	et	f	\N
182008	sisemist	sisemist =sisemi  (SgEl  >sisem !02_A	et	f	\N
182009	sisemist	"sisem %si  )SEM_cA  <si ;26_S	et	f	\N
182010	sisemist	sisemist =sisemis  (SgP  >sisemine !12_A	et	f	\N
182014	rühmitus	rühmitus =rühmitu  (SgIn  >rühmitu !01_AS	et	f	\N
182015	rühmitus	"rühmitu %rühmi  )TU2_kA  <rühm ;22_S	et	f	\N
182016	rühmitus	rühmitus =rühmitu  (IndIpfSg3  >rühmituma !27_V	et	f	\N
182017	rühmitus	rühmitus =rühmitus  (SgN  >rühmitus !11_S	et	f	\N
182018	rühmitus	"rühmitus %rühmita  )US_vS  <rühmitama ;27_V	et	f	\N
182019	rühmitus	"rühmitus %rühmi  )TUS2_aS  <rühm ;22_S	et	f	\N
182067	põhiülesanne	põhiülesanne =anne  (SgN  >põhi+üles+anne !05_S	et	f	\N
182068	põhiülesanne	põhiülesanne =anne  (SgN  >põhi+üles+anne !06_S	et	f	\N
182091	loodearmee	loodearmee =armee  (SgN  >loode+armee !26_S	et	f	\N
182092	loodearmee	loodearmee =armee  (SgG  >loode+armee !26_S	et	f	\N
182110	simesi	?simesi =simesi  (ID  >simesi !41_D	et	f	\N
182116	suuna	suuna =suu  (SgEs  >suu !26_S	et	f	\N
182117	suuna	suuna =suuna  (SgG  >suund !22_S	et	f	\N
182118	suuna	suuna =suuna  (IndPrPs_  >suunama !29_V	et	f	\N
182119	suuna	suuna =suuna  (ImpPrSg2  >suunama !29_V	et	f	\N
182144	pollumeeste	### pollumeeste	et	f	\N
182147	saksatee	saksatee =tee  (SgN  >saksa+tee !26_S	et	f	\N
182148	saksatee	saksatee =tee  (SgG  >saksa+tee !26_S	et	f	\N
182178	paastrina	?paastrina =paastri  (SgEs  >paastri !01_S	et	f	\N
182179	paastrina	?paastrina =paastri  (SgEs  >paaster !02_S	et	f	\N
182194	õpetusi	õpetusi =õpetusi  (PlP  >õpetus !11_S	et	f	\N
182195	õpetusi	"õpetus %õpeta  )US_vS  <õpetama ;27_V	et	f	\N
182196	piimakari	piimakari =kari  (SgN  >piima+kari !17_S	et	f	\N
182197	piimakari	piimakari =kari  (SgN  >piima+kari !24_S	et	f	\N
182198	piimakari	piimakari =kari  (SgG  >piima+kari !17_S	et	f	\N
182199	piimakari	piimakari =kari  (SgP  >piima+kari !17_S	et	f	\N
182220	erakoole	erakoole =koo  (SgAll  >era+kubu !18_S	et	f	\N
182221	erakoole	erakoole =koole  (SgN  >era+koole !05_S	et	f	\N
182222	erakoole	erakoole =koole  (PlP  >era+kool !22_S	et	f	\N
182232	kooliderakoolid	?kooliderakoolid =kooliderakooli  (PlN  >kooliderakooli !16_S	et	f	\N
182233	kooliderakoolid	?kooliderakoolid =kooliderakooli  (PlN  >kooliderakool !22_S	et	f	\N
182234	kooliderakoolid	?kooliderakoolid =kooliderakooli  (IndPrSg2  >kooliderakoolima !28_V	et	f	\N
182235	kooliderakoolid	?kooliderakoolid =derakooli  (PlN  >kooli+derakooli !16_S	et	f	\N
182236	kooliderakoolid	?kooliderakoolid =derakooli  (PlN  >kooli+derakool !22_S	et	f	\N
182237	kooliderakoolid	?kooliderakoolid =iderakooli  (PlN  >kool+iderakooli !16_S	et	f	\N
182238	kooliderakoolid	?kooliderakoolid =iderakooli  (PlN  >kool+iderakool !22_S	et	f	\N
182247	muinasjutude	?muinasjutude =jutu  (PlG  >muinas+jutu !16_S	et	f	\N
182250	pimeduse-	pimeduse- =pimeduse  (SgG  >pimedus !11_S	et	f	\N
182252	pimeduse-	"pimedus %pimeda  )US_aS  <pime ;02_AS	et	f	\N
182280	liivikupermangud	?liivikupermangud =liivikupermangu  (PlN  >liivikupermang !02_S	et	f	\N
182281	liivikupermangud	?liivikupermangud =liivikupermangu  (IndPrSg2  >liivikupermanguma !27_V	et	f	\N
182282	liivikupermangud	?liivikupermangud =kupermangu  (PlN  >liivi+kupermang !02_S	et	f	\N
182283	liivikupermangud	?liivikupermangud =ikupermangu  (PlN  >liiv+ikupermang !02_S	et	f	\N
182308	demut-malinovski	?demut-malinovski =malinovski  (IndPrPs_  >demut-malinovskima !28_V	et	f	\N
182310	demut-malinovski	?demut-malinovski =malinovski  (ImpPrSg2  >demut-malinovskima !28_V	et	f	\N
181860	näljakas	?näljakas =näljaka  (SgIn  >näljakas !02_A	et	f	\N
181861	näljakas	?näljakas =näljakas  (SgN  >näljakas !02_A	et	f	\N
181864	õnelikkult	?õnelikkult =õnelikkult  (ID  >õnelikkult !41_D	et	f	\N
181865	veiderdajat	veiderdajat =veiderdaja  (SgP  >veiderdaja !01_S	et	f	\N
181866	veiderdajat	"veiderdaja %veiderda  )JA_vS  <veiderdama ;27_V	et	f	\N
181867	ebaviisakalt	ebaviisakalt =aka  (SgAbl  >eba+viis+aka !16_S	et	f	\N
181868	ebaviisakalt	ebaviisakalt =viisaka  (SgAbl  >eba+viisakas !02_A	et	f	\N
181869	ebaviisakalt	ebaviisakalt =viisakalt  (ID  >eba+viisakalt !41_D	et	f	\N
181870	ebaviisakalt	"eba+viisakalt %viisaka  )LT_mD  <eba+viisakas ;02_A	et	f	\N
181871	osanudki	osanudki =osa  (PtsPtPs^  >oskama !29_V	et	f	\N
181872	osanudki	osanudki =osanu  (PlN^  >osanu !01_S	et	f	\N
181873	osanudki	"osanu %osa  )NU_vS^  <oskama ;29_V	et	f	\N
181874	osanudki	osanudki =osanud  (ID^  >osanud !41_A	et	f	\N
181875	osanudki	"osanud %osa  )NUD_vA^  <oskama ;29_V	et	f	\N
181882	veidrus	veidrus =veidrus  (SgN  >veidrus !11~09_S	et	f	\N
181883	veidrus	"veidrus %veidra  )US_aS  <veider ;02_A	et	f	\N
181884	tegevuseesmärgidkui	?tegevuseesmärgidkui =tegevuseesmärgidkui  (SgN  >tegevuseesmärgidkui !26_S	et	f	\N
181885	tegevuseesmärgidkui	?tegevuseesmärgidkui =tegevuseesmärgidkui  (SgG  >tegevuseesmärgidkui !26_S	et	f	\N
181886	tegevuseesmärgidkui	?tegevuseesmärgidkui =märgidkui  (SgN  >tegevus+ees+märgidkui !26_S	et	f	\N
181887	tegevuseesmärgidkui	?tegevuseesmärgidkui =märgidkui  (SgG  >tegevus+ees+märgidkui !26_S	et	f	\N
181888	tegevuseesmärgidkui	?tegevuseesmärgidkui =esmärgidkui  (SgN  >tegevuse+esmärgidkui !26_S	et	f	\N
181889	tegevuseesmärgidkui	?tegevuseesmärgidkui =esmärgidkui  (SgG  >tegevuse+esmärgidkui !26_S	et	f	\N
181890	tegevuseesmärgidkui	?tegevuseesmärgidkui =eesmärgidkui  (SgN  >tegevus+eesmärgidkui !26_S	et	f	\N
181891	tegevuseesmärgidkui	?tegevuseesmärgidkui =eesmärgidkui  (SgG  >tegevus+eesmärgidkui !26_S	et	f	\N
181892	tegevuseesmärgidkui	?tegevuseesmärgidkui =useesmärgidkui  (SgN  >tegev+useesmärgidkui !26_S	et	f	\N
181893	tegevuseesmärgidkui	?tegevuseesmärgidkui =useesmärgidkui  (SgG  >tegev+useesmärgidkui !26_S	et	f	\N
181933	meelekindlus	meelekindlus =kindlus  (SgN  >meele+kindlus !11~09_S	et	f	\N
181934	meelekindlus	"meele+kindlus %kindla  )US_aS  <meele+kindel ;02_A	et	f	\N
181951	suitsu	suitsu =suitsu  (SgG  >suits !22_S	et	f	\N
181952	suitsu	suitsu =suitsu  (SgP  >suits !22_S	et	f	\N
181953	suitsu	suitsu =suitsu  (SgAdt  >suits !22_S	et	f	\N
181954	suitsu	suitsu =suitsu  (IndPrPs_  >suitsuma !27_V	et	f	\N
181955	suitsu	suitsu =suitsu  (ImpPrSg2  >suitsuma !27_V	et	f	\N
181959	proffessionaalsele	?proffessionaalsele =proffessionaalse  (SgAll  >proffessionaalne !02_A	et	f	\N
181960	proffessionaalsele	?proffessionaalsele =proffessionaalse  (PlAll  >proffessionaals !22_S	et	f	\N
181977	maailmamtippude	### maailmamtippude	et	f	\N
181980	rahvarvult	?rahvarvult =rahvarvu  (SgAbl  >rahvarvu !01_S	et	f	\N
181981	rahvarvult	?rahvarvult =rahvarvult  (ID  >rahvarvult !41_D	et	f	\N
181991	kooliharidust	kooliharidust =dust  (SgN  >kooli+hari+dust !22_S	et	f	\N
181992	kooliharidust	kooliharidust =haridus  (SgP  >kooli+haridus !11_S	et	f	\N
181996	orjameelsus	orjameelsus =meelsus  (SgN  >orja+meelsus !11~09_S	et	f	\N
181997	orjameelsus	"orja+meelsus %meelse  )US_aS  <orja+meelne ;02_A	et	f	\N
182006	tagasid	tagasid =taga  (IndIpfSg2  >tagama !27_V	et	f	\N
182007	tagasid	tagasid =taga  (IndIpfPl3  >tagama !27_V	et	f	\N
182013	lennulit	### lennulit	et	f	\N
182025	kujundajana	kujundajana =kujundaja  (SgEs  >kujundaja !01_S	et	f	\N
182026	kujundajana	"kujundaja %kujunda  )JA_vS  <kujundama ;27_V	et	f	\N
182028	ametl	?ametl =ametl  (SgN  >ametl !22_S	et	f	\N
182033	ühispangud	?ühispangud =ühispangu  (PlN  >ühispang !02_S	et	f	\N
182034	ühispangud	?ühispangud =ühispangu  (IndPrSg2  >ühispanguma !27_V	et	f	\N
182045	sala	sala =sala  (ID  >sala !41_D	et	f	\N
182046	sala	sala =sala  (SgN  >sala !17_S	et	f	\N
182047	sala	sala =sala  (SgG  >sala !17_S	et	f	\N
182048	sala	sala =sala  (SgP  >sala !17_S	et	f	\N
182050	poliit	?poliit =poliit  (SgN  >poliit !22_S	et	f	\N
182051	vadadust	?vadadust =vadadu  (SgEl  >vadadu !01_S	et	f	\N
182052	vadadust	?vadadust =vadadus  (SgP  >vadadus !11_S	et	f	\N
182056	kestvust	kestvust =kestvus  (SgP  >kestvus !11~09_S	et	f	\N
182057	kestvust	"kestvus %kest  )VUS_aS  <kestma ;34_V	et	f	\N
182058	kestvust	"kestvus %kestva  )US_aS  <kestev ;02_A	et	f	\N
182062	bsaks	?bsaks =bsaks  (SgN  >bsaks !22_S	et	f	\N
182064	tuntuvus	?tuntuvus =tuntuvu  (SgIn  >tuntuvu !01_S	et	f	\N
182065	tuntuvus	?tuntuvus =tuntuvu  (IndIpfSg3  >tuntuvuma !27_V	et	f	\N
182066	tuntuvus	?tuntuvus =tuntuvus  (SgN  >tuntuvus !11_S	et	f	\N
182069	anograatilise	?anograatilise =anograatilise  (SgG  >anograatiline !12_A	et	f	\N
182079	31dets	?dets =dets  (SgN  >dets !22_S	et	f	\N
182080	vaherahule	vaherahule =ahu  (SgAll  >vaher+ahu !17_S	et	f	\N
182081	vaherahule	vaherahule =ahu  (PlAll  >vaher+ahk !22_S	et	f	\N
182082	vaherahule	vaherahule =rahu  (SgAll  >vahe+rahu !17_S	et	f	\N
182083	vaherahule	vaherahule =rahu  (PlAll  >vahe+rahk !22_S	et	f	\N
182093	laevastik	laevastik =laevastik  (SgN  >laevastik !25_S	et	f	\N
182094	laevastik	laevastik =vastik  (SgN  >lae+vastik !02_A	et	f	\N
182095	kojusõjat	?kojusõjat =kojusõja  (SgP  >kojusõjas !02_A	et	f	\N
181965	ekspermenteeritud	?ekspermenteeritud =ekspermenteeritu  (PlN  >ekspermenteeritu !01_S	et	f	\N
181966	ekspermenteeritud	?ekspermenteeritud =ekspermenteeritu  (IndPrSg2  >ekspermenteerituma !27_V	et	f	\N
181967	ekspermenteeritud	?ekspermenteeritud =ekspermenteeritud  (ID  >ekspermenteeritud !41_A	et	f	\N
181968	ekspermenteeritud	?ekspermenteeritud =permenteeritu  (PlN  >eks+permenteeritu !01_S	et	f	\N
181969	underi	?underi =underi  (SgN  >underi !01_S	et	f	\N
181970	underi	?underi =underi  (SgG  >underi !01_S	et	f	\N
181971	underi	?underi =underi  (SgG  >under !02_S	et	f	\N
181972	armuluule	armuluule =luu  (SgAll  >armu+luu !26_S	et	f	\N
181973	armuluule	armuluule =luule  (SgN  >armu+luule !06_S	et	f	\N
181974	armuluule	armuluule =luule  (SgG  >armu+luule !06_S	et	f	\N
181975	armuluule	armuluule =luule  (PlP  >armu+luul !22_S	et	f	\N
181982	kaastöö	kaastöö =töö  (SgN  >kaas+töö !26_S	et	f	\N
181983	kaastöö	kaastöö =töö  (SgG  >kaas+töö !26_S	et	f	\N
181986	eestikeelsetmeelset	?eestikeelsetmeelset =eestikeelsetmeelse  (SgP  >eestikeelsetmeelne !02_A	et	f	\N
181987	eestikeelsetmeelset	?eestikeelsetmeelset =setmeelse  (SgP  >eesti+keel+setmeelne !02_A	et	f	\N
181988	eestikeelsetmeelset	?eestikeelsetmeelset =keelsetmeelse  (SgP  >eesti+keelsetmeelne !02_A	et	f	\N
181989	eestikeelsetmeelset	?eestikeelsetmeelset =ikeelsetmeelse  (SgP  >eest+ikeelsetmeelne !02_A	et	f	\N
181990	eestikeelsetmeelset	?eestikeelsetmeelset =tikeelsetmeelse  (SgP  >ees+tikeelsetmeelne !02_A	et	f	\N
182037	ajalehtedega	ajalehtedega =ede  (SgKom  >aja+leht+ede !16_S	et	f	\N
182038	ajalehtedega	ajalehtedega =lehte  (PlKom  >aja+leht !22_S	et	f	\N
182053	sõna-vabadust	sõna-vabadust =vabadus  (SgP  >sõna-vabadus !11_S	et	f	\N
182054	sõna-vabadust	"sõna-vabadus %vaba  )US_aS  <sõna-vaba ;17_A	et	f	\N
182055	sõna-vabadust	sõna-vabadust =dust  (SgN  >sõna-vaba+dust !22_S	et	f	\N
182074	kogunemine	kogunemine =kogunemine  (SgN  >kogunemine !12_S	et	f	\N
182075	kogunemine	"kogunemine %kogune  )MINE_vS  <kogunema ;27_V	et	f	\N
182077	otepää	?otepää =otepää  (SgN  >otepää !26_S	et	f	\N
182078	otepää	?otepää =otepää  (SgG  >otepää !26_S	et	f	\N
182084	sõjategevus	sõjategevus =tegevus  (SgN  >sõja+tegevus !11_S	et	f	\N
182085	sõjategevus	"sõja+tegevus %tegeva  )US_aS  <sõja+tegev ;02_A	et	f	\N
182086	taganenud	taganenud =tagane  (PtsPtPs  >taganema !27_V	et	f	\N
182087	taganenud	taganenud =taganenu  (PlN  >taganenu !01_S	et	f	\N
182088	taganenud	"taganenu %tagane  )NU_vS  <taganema ;27_V	et	f	\N
182089	taganenud	taganenud =taganenud  (ID  >taganenud !41_A	et	f	\N
182090	taganenud	"taganenud %tagane  )NUD_vA  <taganema ;27_V	et	f	\N
182098	interventsiooni	interventsiooni =interventsiooni  (SgG  >interventsioon !22_S	et	f	\N
182099	interventsiooni	interventsiooni =interventsiooni  (SgP  >interventsioon !22_S	et	f	\N
182100	interventsiooni	interventsiooni =interventsiooni  (SgAdt  >interventsioon !22_S	et	f	\N
182102	voetakse	?voetakse =voetakse  (SgG  >voetakne !02_A	et	f	\N
182103	demokr	?demokr =demokr  (SgN  >demokr !22_S	et	f	\N
182143	1920a	### 1920a	et	f	\N
182153	vebruaris	?vebruaris =vebruari  (SgIn  >vebruari !16_S	et	f	\N
182154	vebruaris	?vebruaris =vebruari  (SgIn  >vebruar !19_S	et	f	\N
182155	vebruaris	?vebruaris =vebruari  (IndIpfSg3  >vebruarima !28_V	et	f	\N
182156	vebruaris	?vebruaris =vebruaris  (SgN  >vebruaris !09_S	et	f	\N
182163	läbiviia	?läbiviia =läbiviia  (SgN  >läbiviia !16_S	et	f	\N
182164	läbiviia	?läbiviia =läbiviia  (SgG  >läbiviia !16_S	et	f	\N
182165	läbiviia	?läbiviia =viia  (SgN  >läbi+viia !16_S	et	f	\N
182166	läbiviia	?läbiviia =viia  (SgG  >läbi+viia !16_S	et	f	\N
182180	heanime	heanime =nime  (SgG  >hea+nimi !20_S	et	f	\N
182181	heanime	heanime =nime  (SgP  >hea+nimi !20_S	et	f	\N
182215	asutavad	asutavad =asuta  (IndPrPl3  >asutama !27_V	et	f	\N
182216	asutavad	asutavad =asutava  (PlN  >asutav !02_A	et	f	\N
182217	asutavad	"asutav %asu  )TAV_vAS  <asuma ;27_V	et	f	\N
182218	asutavad	"asutav %asuta  )V_vA  <asutama ;27_V	et	f	\N
182219	asutavad	asutavad =tava  (PlN  >asu+tava !17_S	et	f	\N
182223	toitnud	toitnud =toit  (PtsPtPs  >toitma !34_V	et	f	\N
182224	toitnud	toitnud =toitnu  (PlN  >toitnu !01_S	et	f	\N
182225	toitnud	"toitnu %toit  )NU_vS  <toitma ;34_V	et	f	\N
182226	toitnud	toitnud =toitnud  (ID  >toitnud !41_A	et	f	\N
182227	toitnud	"toitnud %toit  )NUD_vA  <toitma ;34_V	et	f	\N
182228	kunst-tööstuskool	kunst-tööstuskool =koo  (SgAd  >kunst-tööstus+kubu !18_S	et	f	\N
182229	kunst-tööstuskool	kunst-tööstuskool =kool  (SgN  >kunst-tööstus+kool !22_S	et	f	\N
182248	htampere	### htampere	et	f	\N
182261	kooliõpikuid	kooliõpikuid =ku  (PlP  >kooli+õpi+kuu !26_S	et	f	\N
182262	kooliõpikuid	kooliõpikuid =õpiku  (PlP  >kooli+õpik !02_S	et	f	\N
182273	eeesti	?eeesti =eeesti  (ID  >eeesti !41_D	et	f	\N
182274	eeesti	?eeesti =eeesti  (IndPrPs_  >eeestima !28_V	et	f	\N
182275	eeesti	?eeesti =eeesti  (ImpPrSg2  >eeestima !28_V	et	f	\N
182284	pidurdus	pidurdus =pidurdu  (IndIpfSg3  >pidurduma !27_V	et	f	\N
182285	pidurdus	pidurdus =pidurdus  (SgN  >pidurdus !11_S	et	f	\N
182286	pidurdus	"pidurdus %pidurda  )US_vS  <pidurdama ;27_V	et	f	\N
182296	jakobon	?jakobon =jakobon  (SgN  >jakobon !19_S	et	f	\N
182301	wilhelm	?wilhelm =wilhelm  (SgN  >wilhelm !22_S	et	f	\N
181993	konseptisoon	?konseptisoon =konseptisoon  (SgN  >konseptisoon !22_S	et	f	\N
181994	saksameelsuses	saksameelsuses =meelsuse  (SgIn  >saksa+meelsus !11~09_S	et	f	\N
181995	saksameelsuses	"saksa+meelsus %meelse  )US_aS  <saksa+meelne ;02_A	et	f	\N
182011	rahuldamine	rahuldamine =rahuldamine  (SgN  >rahuldamine !12_S	et	f	\N
182012	rahuldamine	"rahuldamine %rahulda  )MINE_vS  <rahuldama ;27_V	et	f	\N
182020	osatähtsusest	osatähtsusest =tähtsuse  (SgEl  >osa+tähtsus !11~09_S	et	f	\N
182021	osatähtsusest	"osa+tähtsus %tähtsa  )US_aS  <osa+tähtis ;02_A	et	f	\N
182022	osatähtsusest	osatähtsusest =tähtsuses  (SgP  >osa+tähtsusene !12_A	et	f	\N
182023	osatähtsusest	"osa+tähtsusene %tähtsuse  )NE_aA  <osa+tähtsus ;09_S	et	f	\N
182024	osatähtsusest	"osa+tähtsusene %tähtsuse  )NE_aA  <osa+tähtsus ;11_S	et	f	\N
182027	1882a	### 1882a	et	f	\N
182039	keelatus	keelatus =keelatu  (SgIn  >keelatu !01_S	et	f	\N
182040	keelatus	"keelatu %keela  )TU1_vS  <keelama ;29_V	et	f	\N
182041	keelatus	keelatus =keelatus  (SgN  >keelatus !11_S	et	f	\N
182042	keelatus	"keelatus %keela  )TUS1_aS  <keelama ;29_V	et	f	\N
182043	keelatus	keelatus =atu  (SgIn  >keel+att !22_S	et	f	\N
182044	eestl	?eestl =eestl  (SgN  >eestl !22_S	et	f	\N
182059	3teed	teed =tee  (PlN  >tee !26_S	et	f	\N
182060	3teed	teed =tee  (SgP  >tee !26_S	et	f	\N
182061	3teed	teed =tee  (IndPrSg2  >tegema !28_V	et	f	\N
182070	materjaale	?materjaale =materjaa  (SgAll  >materjaa !26_S	et	f	\N
182071	materjaale	?materjaale =materjaale  (SgN  >materjaale !16_S	et	f	\N
182072	materjaale	?materjaale =materjaale  (SgG  >materjaale !16_S	et	f	\N
182073	materjaale	?materjaale =materjaale  (PlP  >materjaal !22_S	et	f	\N
182076	jhurt	?jhurt =jhurt  (SgN  >jhurt !22_S	et	f	\N
182104	kod	### kod	et	f	\N
182136	1872a	### 1872a	et	f	\N
182139	korjamises	korjamises =korjamise  (SgIn  >korjamine !12_S	et	f	\N
182140	korjamises	"korjamine %korja  )MINE_vS  <korjama ;29_V	et	f	\N
182145	tegijatest	tegijatest =tegija  (PlEl  >tegija !01_S	et	f	\N
182146	tegijatest	"tegija %tegi  )JA_vS  <tegema ;28_V	et	f	\N
182173	auditooriumi	auditooriumi =auditooriumi  (SgG  >auditoorium !19~02_S	et	f	\N
182174	auditooriumi	auditooriumi =auditooriumi  (SgP  >auditoorium !19_S	et	f	\N
182175	auditooriumi	auditooriumi =auditooriumi  (SgAdt  >auditoorium !19_S	et	f	\N
182182	feebruaril	?feebruaril =feebruari  (SgAd  >feebruari !16_S	et	f	\N
182183	feebruaril	?feebruaril =feebruari  (SgAd  >feebruar !19_S	et	f	\N
182184	feebruaril	?feebruaril =feebruaril  (SgN  >feebruaril !02_S	et	f	\N
182239	tehnikakool	tehnikakool =koo  (SgAd  >tehnika+kubu !18_S	et	f	\N
182240	tehnikakool	tehnikakool =kool  (SgN  >tehnika+kool !22_S	et	f	\N
182245	ilukirjuanduse	?ilukirjuanduse =ilukirjuanduse  (SgG  >ilukirjuandus !11_S	et	f	\N
182246	ilukirjuanduse	?ilukirjuanduse =kirjuanduse  (SgG  >ilu+kirjuandus !11_S	et	f	\N
182265	tegutseid	?tegutseid =tegutse  (PlP  >tegutne !02_A	et	f	\N
182266	tegutseid	?tegutseid =tegutsei  (PlN  >tegutsei !26_S	et	f	\N
182267	tegutseid	?tegutseid =tegutsei  (SgP  >tegutsei !26_S	et	f	\N
182268	tegutseid	?tegutseid =tsei  (PlN  >tegu+tsei !26_S	et	f	\N
182269	tegutseid	?tegutseid =tsei  (SgP  >tegu+tsei !26_S	et	f	\N
182270	tegutseid	?tegutseid =tseid  (SgN  >tegu+tseid !22_S	et	f	\N
182279	arenem	?arenem =arenem  (SgN  >arenem !02_A	et	f	\N
182291	kristjan	?kristjan =kristja  (IndPrSg1  >kristjama !29_V	et	f	\N
182292	kristjan	?kristjan =kristjan  (SgN  >kristjan !02_S	et	f	\N
182325	hariduselus	hariduselus =elu  (SgIn  >haridus+elu !17_S	et	f	\N
182326	hariduselus	hariduselus =elus  (SgN  >haridus+elus !02_A	et	f	\N
182327	eõs	?eõs =eõs  (SgN  >eõs !22_S	et	f	\N
182330	rahvusl	?rahvusl =rahvusl  (SgN  >rahvusl !22_S	et	f	\N
182337	radikaal-dem	### radikaal-dem	et	f	\N
182338	teoloogilise	teoloogilise =teoloogilise  (SgG  >teoloogiline !12_A	et	f	\N
182339	teoloogilise	"teoloogiline %teoloogi  )LINE_aA  <teoloog ;22_S	et	f	\N
182340	teoloogilise	teoloogilise =loogilise  (SgG  >teo+loogiline !12_A	et	f	\N
182341	teoloogilise	"teo+loogiline %loogi  )LINE_aA  <teo+loog ;22_S	et	f	\N
182353	tug	### tug	et	f	\N
182354	vaimujõud	vaimujõud =jõu  (PlN  >vaimu+jõud !22_S	et	f	\N
182355	vaimujõud	vaimujõud =jõud  (SgN  >vaimu+jõud !22_S	et	f	\N
182375	reaalgümnaasiumi	reaalgümnaasiumi =gümnaasiumi  (SgG  >reaal+gümnaasium !19~02_S	et	f	\N
182376	reaalgümnaasiumi	reaalgümnaasiumi =gümnaasiumi  (SgP  >reaal+gümnaasium !19_S	et	f	\N
182377	reaalgümnaasiumi	reaalgümnaasiumi =gümnaasiumi  (SgAdt  >reaal+gümnaasium !19_S	et	f	\N
182390	huvtav	?huvtav =huvta  (PtsPrPs  >huvtama !29_V	et	f	\N
182391	huvtav	?huvtav =huvtav  (SgN  >huvtav !02_A	et	f	\N
182414	rahvaelu	rahvaelu =elu  (SgN  >rahva+elu !17_S	et	f	\N
182415	rahvaelu	rahvaelu =elu  (SgG  >rahva+elu !17_S	et	f	\N
182416	rahvaelu	rahvaelu =elu  (SgP  >rahva+elu !17_S	et	f	\N
182434	seltsielu	seltsielu =elu  (SgN  >seltsi+elu !17_S	et	f	\N
182435	seltsielu	seltsielu =elu  (SgG  >seltsi+elu !17_S	et	f	\N
182436	seltsielu	seltsielu =elu  (SgP  >seltsi+elu !17_S	et	f	\N
182437	usubadus	?usubadus =usubadu  (IndIpfSg3  >usubaduma !27_V	et	f	\N
182438	usubadus	?usubadus =usubadus  (SgN  >usubadus !11?09_S	et	f	\N
182439	usubadus	?usubadus =badu  (SgIn  >usu+badu !17_S	et	f	\N
182096	kojusõjat	?kojusõjat =kojusõja  (SgP  >kojusõja !16_S	et	f	\N
182097	kojusõjat	?kojusõjat =sõjat  (SgN  >koju+sõjat !02_S	et	f	\N
182105	ekms	?ekms =ekms  (SgN  >ekms !22_S	et	f	\N
182106	pärimuskultuuriga	?pärimuskultuuriga =pärimuskultuuri  (SgKom  >pärimuskultuuri !16_S	et	f	\N
182107	pärimuskultuuriga	?pärimuskultuuriga =pärimuskultuuri  (SgKom  >pärimuskultuur !22_S	et	f	\N
182108	pärimuskultuuriga	?pärimuskultuuriga =muskultuuri  (SgKom  >päri+muskultuuri !16_S	et	f	\N
182109	pärimuskultuuriga	?pärimuskultuuriga =muskultuuri  (SgKom  >päri+muskultuur !22_S	et	f	\N
182122	elutöö	elutöö =töö  (SgN  >elu+töö !26_S	et	f	\N
182123	elutöö	elutöö =töö  (SgG  >elu+töö !26_S	et	f	\N
182131	poska	?poska =poska  (SgN  >poska !16_S	et	f	\N
182132	poska	?poska =poska  (SgG  >poska !16_S	et	f	\N
182133	poska	?poska =poska  (IndPrPs_  >poskama !29_V	et	f	\N
182134	poska	?poska =poska  (ImpPrSg2  >poskama !29_V	et	f	\N
182135	ärkada	### ärkada	et	f	\N
182137	valdaksid	valdaksid =valda  (KndPrSg2  >valdama !29_V	et	f	\N
182138	valdaksid	valdaksid =valda  (KndPrPl3  >valdama !29_V	et	f	\N
182149	eestitee	eestitee =tee  (SgN  >eesti+tee !26_S	et	f	\N
182150	eestitee	eestitee =tee  (SgG  >eesti+tee !26_S	et	f	\N
182157	riigikogus	riigikogus =kogu  (SgIn  >riigi+kogu !17_S	et	f	\N
182158	riigikogus	riigikogus =kogus  (SgN  >riigi+kogus !02_A	et	f	\N
182159	riigikogus	riigikogus =kogus  (SgN  >riigi+kogus !09_S	et	f	\N
182160	riigivanemad	riigivanemad =vanema  (PlN  >riigi+vanem !02_AS	et	f	\N
182161	riigivanemad	"riigi+vanem %vane  )M_cA  <riigi+vana ;17_AS	et	f	\N
182162	tõnisson	?tõnisson =tõnisson  (SgN  >tõnisson !19_S	et	f	\N
182167	kaubalaeva	kaubalaeva =laeva  (SgG  >kauba+laev !22_S	et	f	\N
182168	kaubalaeva	kaubalaeva =laeva  (SgP  >kauba+laev !22_S	et	f	\N
182169	kaubalaeva	kaubalaeva =laeva  (SgAdt  >kauba+laev !22_S	et	f	\N
182172	üliõp	?üliõp =üliõp  (SgN  >üliõp !22_S	et	f	\N
182185	kuulutama	kuulutama =kuulu  (SupIps  >kuuluma !27_V	et	f	\N
182186	kuulutama	kuulutama =kuuluta  (Sup  >kuulutama !27_V	et	f	\N
182208	tungi	tungi =tungi  (SgG  >tung !22_S	et	f	\N
182209	tungi	tungi =tungi  (SgP  >tung !22_S	et	f	\N
182210	tungi	tungi =tungi  (SgAdt  >tung !22_S	et	f	\N
182211	tungi	tungi =tungi  (PlP  >tung !22_S	et	f	\N
182212	tungi	tungi =tungi  (IndPrPs_  >tungima !28_V	et	f	\N
182213	tungi	tungi =tungi  (ImpPrSg2  >tungima !28_V	et	f	\N
182230	omamine	omamine =omamine  (SgN  >omamine !12_S	et	f	\N
182231	omamine	"omamine %oma  )MINE_vS  <omama ;27_V	et	f	\N
182241	aariste	?aariste =aaris  (PlG  >aaris !09_S	et	f	\N
182242	aariste	?aariste =aariste  (PlP  >aarist !22_S	et	f	\N
182243	teadus-	teadus- =teadu  (SgIn  >tead !22_S	et	f	\N
182244	teadus-	teadus- =teadus  (SgN  >teadus !11~09_S	et	f	\N
182253	koduajast	koduajast =aja  (SgEl  >kodu+aeg !22_S	et	f	\N
182254	koduajast	koduajast =ajas  (SgP  >kodu+ajane !10_A	et	f	\N
182255	koduajast	"kodu+ajane %aja  )NE_aA  <kodu+aeg ;22_S	et	f	\N
182256	pimeduse	pimeduse =pimeduse  (SgG  >pimedus !11_S	et	f	\N
182257	pimeduse	"pimedus %pimeda  )US_aS  <pime ;02_AS	et	f	\N
182287	kultuuritegevus	kultuuritegevus =tegevus  (SgN  >kultuuri+tegevus !11_S	et	f	\N
182288	kultuuritegevus	"kultuuri+tegevus %tegeva  )US_aS  <kultuuri+tegev ;02_A	et	f	\N
182289	2loetle	loetle =loetle  (IndPrPs_  >loetlema !27_V	et	f	\N
182290	2loetle	loetle =loetle  (ImpPrSg2  >loetlema !27_V	et	f	\N
182294	luuletja	?luuletja =luuletja  (SgN  >luuletja !01_S	et	f	\N
182295	luuletja	?luuletja =luuletja  (SgG  >luuletja !01_S	et	f	\N
182297	luuletja	?luuletja =luuletja  (SgG  >luuletjas !02_A	et	f	\N
182298	luuletja	?luuletja =letja  (SgN  >luu+letja !01_S	et	f	\N
182299	luuletja	?luuletja =letja  (SgG  >luu+letja !01_S	et	f	\N
182300	luuletja	?luuletja =letja  (SgG  >luu+letjas !02_A	et	f	\N
182305	tolli	tolli =tolli  (SgG  >toll !22_S	et	f	\N
182306	tolli	tolli =tolli  (SgP  >toll !22_S	et	f	\N
182307	tolli	tolli =tolli  (SgAdt  >toll !22_S	et	f	\N
182309	tolli	tolli =tolli  (IndPrPs_  >tollima !28_V	et	f	\N
182311	tolli	tolli =tolli  (ImpPrSg2  >tollima !28_V	et	f	\N
182314	amandus	?amandus =amandu  (SgIn  >amandu !01_S	et	f	\N
182315	amandus	?amandus =amandu  (IndIpfSg3  >amanduma !27_V	et	f	\N
182316	amandus	?amandus =amandus  (SgN  >amandus !11_S	et	f	\N
182317	pätsu	pätsu =pätsu  (SgG  >päts !22_S	et	f	\N
182318	pätsu	pätsu =pätsu  (SgP  >päts !22_S	et	f	\N
182319	pätsu	pätsu =pätsu  (SgAdt  >päts !22_S	et	f	\N
182320	valimisega	valimisega =valimise  (SgKom  >valimine !12_S	et	f	\N
182321	valimisega	"valimine %vali  )MINE_vS  <valima ;27_V	et	f	\N
182342	baltisaksl	?baltisaksl =saksl  (SgN  >balti+saksl !22_S	et	f	\N
182343	baltisaksl	?baltisaksl =isaksl  (SgN  >balt+isaksl !22_S	et	f	\N
182361	kaheastmeline	kaheastmeline =astmeline  (SgN  >kahe+astmeline !12_A	et	f	\N
182362	kaheastmeline	"kahe+astmeline %astme  )LINE_aA  <kahe+aste ;05_S	et	f	\N
182368	täiendav	täiendav =täienda  (PtsPrPs  >täiendama !27_V	et	f	\N
182369	täiendav	täiendav =täiendav  (SgN  >täiendav !02_A	et	f	\N
182370	täiendav	"täiendav %täienda  )V_vA  <täiendama ;27_V	et	f	\N
182126	kaastööliste	kaastööliste =iste  (SgG  >kaas+tööl+iste !06_S	et	f	\N
182127	kaastööliste	kaastööliste =iste  (PlP  >kaas+tööl+ist !22_S	et	f	\N
182128	kaastööliste	kaastööliste =töölis  (PlG  >kaas+tööline !12?10_S	et	f	\N
182129	suveräänsust	suveräänsust =suveräänsus  (SgP  >suveräänsus !11~09_S	et	f	\N
182130	suveräänsust	"suveräänsus %suveräänse  )US_aS  <suveräänne ;02_A	et	f	\N
182141	rahvuvliikumise	?rahvuvliikumise =rahvuvliikumise  (SgG  >rahvuvliikumine !12_S	et	f	\N
182142	2veebr	?veebr =veebr  (SgN  >veebr !22_S	et	f	\N
182151	venetee	venetee =tee  (SgN  >vene+tee !26_S	et	f	\N
182152	venetee	venetee =tee  (SgG  >vene+tee !26_S	et	f	\N
182170	ilmaline	ilmaline =ilmaline  (SgN  >ilmaline !12_A	et	f	\N
182171	ilmaline	"ilmaline %ilma  )LINE_aA  <ilm ;22_S	et	f	\N
182176	otepäil	?otepäil =otepäi  (SgAd  >otepäi !26_S	et	f	\N
182177	otepäil	?otepäil =otepäil  (SgN  >otepäil !19_S	et	f	\N
182187	heategevusena	heategevusena =tegevuse  (SgEs  >hea+tegevus !11_S	et	f	\N
182188	heategevusena	"hea+tegevus %tegeva  )US_aS  <hea+tegev ;02_A	et	f	\N
182189	koole	koole =koo  (SgAll  >kubu !18_S	et	f	\N
182190	koole	koole =koole  (SgN  >koole !05_S	et	f	\N
182191	koole	koole =koole  (PlP  >kool !22_S	et	f	\N
182192	koole	koole =koole  (IndPrPs_  >koolma !33_V	et	f	\N
182193	koole	koole =koole  (ImpPrSg2  >koolma !33_V	et	f	\N
182200	vaimukultuuri	vaimukultuuri =kultuuri  (SgG  >vaimu+kultuur !22_S	et	f	\N
182201	vaimukultuuri	vaimukultuuri =kultuuri  (SgP  >vaimu+kultuur !22_S	et	f	\N
182202	vaimukultuuri	vaimukultuuri =kultuuri  (SgAdt  >vaimu+kultuur !22_S	et	f	\N
182203	lootvat	lootvat =loot  (KvtPrPs  >lootma !34_V	et	f	\N
182204	lootvat	lootvat =lootva  (SgP  >lootev !02_A	et	f	\N
182205	lootvat	"lootev %loot  )V_vA  <lootma ;34_V	et	f	\N
182206	puhuks	puhuks =puhu  (SgTr  >puhk !22_S	et	f	\N
182207	puhuks	puhuks =puhu  (KndPrPs  >puhuma !27_V	et	f	\N
182214	1906a	### 1906a	et	f	\N
182249	valguse-	valguse- =valguse  (SgG  >valgus !11~09_S	et	f	\N
182251	valguse-	"valgus %valge  )US_aS  <valge ;01_AS	et	f	\N
182258	kostas	?kostas =kosta  (SgIn  >kosta !16_S	et	f	\N
182259	kostas	?kostas =kosta  (IndIpfSg3  >kostama !29_V	et	f	\N
182260	kostas	?kostas =kostas  (SgN  >kostas !07_S	et	f	\N
182263	põllundus-majandus	põllundus-majandus =majandus  (SgN  >põllundus-majandus !11_S	et	f	\N
182264	põllundus-majandus	"põllundus-majandus %majanda  )US_vS  <põllundus-majandama ;27_V	et	f	\N
182271	algkool	algkool =koo  (SgAd  >alg+kubu !18_S	et	f	\N
182272	algkool	algkool =kool  (SgN  >alg+kool !22_S	et	f	\N
182276	aendast	?aendast =aenda  (SgEl  >aenda !01_S	et	f	\N
182277	aendast	?aendast =aendas  (SgP  >aendas !07_S	et	f	\N
182278	aendast	?aendast =aendas  (SgP  >aendane !12~10_A	et	f	\N
182293	peterson	?peterson =peterson  (SgN  >peterson !19_S	et	f	\N
182304	baclay	### baclay	et	f	\N
182313	weizenberg	?weizenberg =weizenberg  (SgN  >weizenberg !22_S	et	f	\N
182322	valituse	valituse =valituse  (SgG  >valitus !11_S	et	f	\N
182323	valituse	"valitus %vali  )TUS1_aS  <valima ;27_V	et	f	\N
182328	praktil	?praktil =prakti  (SgAd  >prakti !16_S	et	f	\N
182329	praktil	?praktil =prakti  (SgAd  >prakt !22_S	et	f	\N
182331	kättesaadav	kättesaadav =saa  (PtsPrIps  >kätte+_saama !37_V	et	f	\N
182332	kättesaadav	kättesaadav =saadav  (SgN  >kätte+saadav !02_A	et	f	\N
182351	sõjalised	sõjalised =sõjalise  (PlN  >sõjaline !12_A	et	f	\N
182352	sõjalised	"sõjaline %sõja  )LINE_aA  <sõda ;18_S	et	f	\N
182357	petendeerimisele	?petendeerimisele =petendeerimise  (SgAll  >petendeerimine !12_S	et	f	\N
182380	algusaasta	algusaasta =aasta  (SgN  >algus+aasta !01_S	et	f	\N
182381	algusaasta	algusaasta =aasta  (SgG  >algus+aasta !01_S	et	f	\N
182382	algusaasta	algusaasta =saasta  (SgG  >algu+saast !22_S	et	f	\N
182383	algusaasta	algusaasta =saasta  (SgP  >algu+saast !22_S	et	f	\N
182384	algusaasta	algusaasta =saasta  (SgAdt  >algu+saast !22_S	et	f	\N
182392	pimedusaeg	?pimedusaeg =pimedusaeg  (SgN  >pimedusaeg !22_S	et	f	\N
182393	pimedusaeg	?pimedusaeg =dusaeg  (SgN  >pime+dusaeg !22_S	et	f	\N
182412	keskõige	keskõige =õige  (SgN  >kesk+õige !01_A	et	f	\N
182413	keskõige	keskõige =õige  (SgG  >kesk+õige !01_A	et	f	\N
182451	hariuds	?hariuds =hariuds  (SgN  >hariuds !22_S	et	f	\N
182452	hariuds	?hariuds =uds  (SgN  >hari+uds !22_S	et	f	\N
182457	täiendkool	täiendkool =koo  (SgAd  >täiend+kubu !18_S	et	f	\N
182458	täiendkool	täiendkool =kool  (SgN  >täiend+kool !22_S	et	f	\N
182472	uits	?uits =uits  (SgN  >uits !22_S	et	f	\N
182475	rahvaluulekogumine	rahvaluulekogumine =kogumine  (SgN  >rahva+luule+kogumine !12_S	et	f	\N
182476	rahvaluulekogumine	"rahva+luule+kogumine %kogumi  )NE_aA  <rahva+luule+kogum ;02_S	et	f	\N
182477	nekkus	?nekkus =nekku  (IndIpfSg3  >nekkuma !27_V	et	f	\N
182478	nekkus	?nekkus =nekkus  (SgN  >nekkus !11~09_S	et	f	\N
182489	asutusi	asutusi =asutusi  (PlP  >asutus !11_S	et	f	\N
182490	asutusi	"asutus %asuta  )US_vS  <asutama ;27_V	et	f	\N
182491	asutusi	"asutus %asu  )TUS1_aS  <asuma ;27_V	et	f	\N
182492	asutusi	"asutus %asu  )TUS2_aS  <asu ;17_S	et	f	\N
182501	muinasnnud	?muinasnnud =muinasnnu  (PlN  >muinasnnu !01_S	et	f	\N
182302	astronoomiakeskuseks	astronoomiakeskuseks =use  (PlTr  >astronoomia+kesk+usk !22_S	et	f	\N
182303	astronoomiakeskuseks	astronoomiakeskuseks =keskuse  (SgTr  >astronoomia+keskus !11~09_S	et	f	\N
182333	kondasid	kondasid =konda  (IndIpfSg2  >kondama !29_V	et	f	\N
182334	kondasid	kondasid =konda  (IndIpfPl3  >kondama !29_V	et	f	\N
182344	pooldajaks	pooldajaks =pooldaja  (SgTr  >pooldaja !01_S	et	f	\N
182345	pooldajaks	"pooldaja %poolda  )JA_vS  <pooldama ;27_V	et	f	\N
182346	kuulunudki	kuulunudki =kuulu  (PtsPtPs^  >kuuluma !27_V	et	f	\N
182347	kuulunudki	kuulunudki =kuulunu  (PlN^  >kuulunu !01_S	et	f	\N
182348	kuulunudki	"kuulunu %kuulu  )NU_vS^  <kuuluma ;27_V	et	f	\N
182349	kuulunudki	kuulunudki =kuulunud  (ID^  >kuulunud !41_A	et	f	\N
182350	kuulunudki	"kuulunud %kuulu  )NUD_vA^  <kuuluma ;27_V	et	f	\N
182358	vm	### vm	et	f	\N
182360	põllumajanduslikk	### põllumajanduslikk	et	f	\N
182363	klassiline	klassiline =klassiline  (SgN  >klassiline !12_A	et	f	\N
182364	klassiline	"klassiline %klassi  )LINE_aA  <klass ;22_S	et	f	\N
182371	klassiliseks	klassiliseks =klassilise  (SgTr  >klassiline !12_A	et	f	\N
182372	klassiliseks	"klassiline %klassi  )LINE_aA  <klass ;22_S	et	f	\N
182387	ärkmisaeg	?ärkmisaeg =ärkmisaeg  (SgN  >ärkmisaeg !22_S	et	f	\N
182388	raakis	?raakis =raaki  (IndIpfSg3  >raakima !28_V	et	f	\N
182389	raakis	?raakis =raakis  (SgN  >raakis !11~09_S	et	f	\N
182403	mitemid	?mitemid =mitemi  (PlN  >mitemi !01_S	et	f	\N
182404	mitemid	?mitemid =mitemi  (PlN  >mitem !02_A	et	f	\N
182423	altiivsemaid	?altiivsemaid =altiivsema  (PlP  >altiivsem !02_A	et	f	\N
182424	altiivsemaid	?altiivsemaid =altiivsemai  (PlN  >altiivsemai !26_S	et	f	\N
182425	altiivsemaid	?altiivsemaid =altiivsemai  (SgP  >altiivsemai !26_S	et	f	\N
182426	altiivsemaid	?altiivsemaid =iivsema  (PlP  >alt+iivsem !02_A	et	f	\N
182427	altiivsemaid	?altiivsemaid =iivsemai  (PlN  >alt+iivsemai !26_S	et	f	\N
182428	altiivsemaid	?altiivsemaid =iivsemai  (SgP  >alt+iivsemai !26_S	et	f	\N
182429	vähemusrahvastest	vähemusrahvastest =rahvas  (PlEl  >vähemus+rahvas !07_S	et	f	\N
182430	vähemusrahvastest	vähemusrahvastest =rahvas  (PlEl  >vähemus+rahvane !10_A	et	f	\N
182431	vähemusrahvastest	"vähemus+rahvane %rahva  )NE_aA  <vähemus+rahvas ;07_S	et	f	\N
182460	progm	?progm =progm  (SgN  >progm !22_S	et	f	\N
182462	reaakool	?reaakool =reaakoo  (SgAd  >reaakoo !26_S	et	f	\N
182463	reaakool	?reaakool =reaakool  (SgN  >reaakool !22_S	et	f	\N
182464	reaakool	?reaakool =akoo  (SgAd  >rea+akoo !26_S	et	f	\N
182465	reaakool	?reaakool =akool  (SgN  >rea+akool !22_S	et	f	\N
182487	neurokirurgia	neurokirurgia =kirurgia  (SgN  >neuro+kirurgia !01_S	et	f	\N
182488	neurokirurgia	neurokirurgia =kirurgia  (SgG  >neuro+kirurgia !01_S	et	f	\N
182546	sets	?sets =sets  (SgN  >sets !22_S	et	f	\N
182547	põllumajandusteadus	põllumajandusteadus =teadu  (SgIn  >põllu+majandus+tead !22_S	et	f	\N
182548	põllumajandusteadus	põllumajandusteadus =teadus  (SgN  >põllu+majandus+teadus !11~09_S	et	f	\N
182558	kõneid	?kõneid =kõnei  (PlN  >kõnei !26_S	et	f	\N
182559	kõneid	?kõneid =kõnei  (SgP  >kõnei !26_S	et	f	\N
182560	kõneid	?kõneid =kõneid  (SgN  >kõneid !22_S	et	f	\N
182564	kontkatis	kontkatis =kati  (SgIn  >kont+katt !22_S	et	f	\N
182565	kontkatis	kontkatis =katis  (SgN  >kont+katis !09_S	et	f	\N
182566	emamaa	emamaa =maa  (SgN  >ema+maa !26_S	et	f	\N
182567	emamaa	emamaa =maa  (SgG  >ema+maa !26_S	et	f	\N
182582	kirjameesti	?kirjameesti =kirjameesti  (ID  >kirjameesti !41_D	et	f	\N
182583	kirjameesti	?kirjameesti =kirjameesti  (IndPrPs_  >kirjameestima !28_V	et	f	\N
182584	kirjameesti	?kirjameesti =kirjameesti  (ImpPrSg2  >kirjameestima !28_V	et	f	\N
182585	kirjameesti	?kirjameesti =meesti  (SgG  >kirja+meest !22_S	et	f	\N
182586	kirjameesti	?kirjameesti =meesti  (SgP  >kirja+meest !22_S	et	f	\N
182587	kirjameesti	?kirjameesti =meesti  (SgAdt  >kirja+meest !22_S	et	f	\N
182604	õpetajateks	õpetajateks =õpetaja  (PlTr  >õpetaja !01_S	et	f	\N
182605	õpetajateks	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
182606	taasärkamise	taasärkamise =ärkamise  (SgG  >taas+ärkamine !12_S	et	f	\N
182607	taasärkamise	"taas+ärkamine %ärka  )MINE_vS  <taas+ärkama ;29_V	et	f	\N
182625	karell	?karell =karell  (SgN  >karell !22_S	et	f	\N
182649	monitestatsioonid	?monitestatsioonid =monitestatsiooni  (PlN  >monitestatsiooni !16_S	et	f	\N
182650	monitestatsioonid	?monitestatsioonid =monitestatsiooni  (PlN  >monitestatsioon !22_S	et	f	\N
182651	monitestatsioonid	?monitestatsioonid =monitestatsiooni  (IndPrSg2  >monitestatsioonima !28_V	et	f	\N
182660	saksastumise	saksastumise =saksastumise  (SgG  >saksastumine !12_S	et	f	\N
182661	saksastumise	"saksastumine %saksastu  )MINE_vS  <saksastuma ;27_V	et	f	\N
182671	organiseerimiseks	organiseerimiseks =organiseerimise  (SgTr  >organiseerimine !12_S	et	f	\N
182672	organiseerimiseks	"organiseerimine %organiseeri  )MINE_vS  <organiseerima ;28_V	et	f	\N
182699	1870ndates	?ndates =ndate  (PlIn  >ndatt !22_S	et	f	\N
182700	1870ndates	?ndates =ndate  (IndIpfSg3  >ndatema !27_V	et	f	\N
182701	1870ndates	?ndates =ndates  (SgN  >ndates !09_S	et	f	\N
182702	panebbaluse	?panebbaluse =panebbaluse  (SgG  >panebbalus !11?09_S	et	f	\N
182716	1930-ndatek	?-ndatek =ndatek  (SgN  >-ndatek !02_S	et	f	\N
182721	tunniliseks	tunniliseks =tunnilise  (SgTr  >tunniline !12_A	et	f	\N
182312	demut-malinovski	?demut-malinovski =malinovs  (SgN^  >demut-malinovs !22_S	et	f	\N
182324	tek	### tek	et	f	\N
182335	taotlused	taotlused =taotluse  (PlN  >taotlus !11~09_S	et	f	\N
182336	taotlused	"taotlus %taotle  )US_vS  <taotlema ;27_V	et	f	\N
182356	igasug	### igasug	et	f	\N
182359	lus	### lus	et	f	\N
182365	reaali	reaali =reaali  (SgG  >reaal !22_S	et	f	\N
182366	reaali	reaali =reaali  (SgP  >reaal !22_S	et	f	\N
182367	reaali	reaali =reaali  (SgAdt  >reaal !22_S	et	f	\N
182373	5-	### 5-	et	f	\N
182374	progümnaasium	?progümnaasium =progümnaasium  (SgN  >progümnaasium !19~02_S	et	f	\N
182385	kadlusi	?kadlusi =kadlusi  (ID  >kadlusi !41_D	et	f	\N
182386	kadlusi	?kadlusi =kadlusi  (PlP  >kadlus !11_S	et	f	\N
182394	lesta	lesta =lesta  (SgG  >lest !22_S	et	f	\N
182395	lesta	lesta =lesta  (SgP  >lest !22_S	et	f	\N
182396	lesta	lesta =lesta  (SgAdt  >lest !22_S	et	f	\N
182405	riigitoetust	riigitoetust =tust  (SgN  >riigi+toe+tust !22_S	et	f	\N
182406	riigitoetust	riigitoetust =toetu  (SgEl  >riigi+toetu !01_A	et	f	\N
182407	riigitoetust	"riigi+toetu %toe  )TU2_kA  <riigi+tugi ;21_S	et	f	\N
182408	riigitoetust	riigitoetust =toetus  (SgP  >riigi+toetus !11~09_S	et	f	\N
182409	riigitoetust	"riigi+toetus %toe  )TUS2_aS  <riigi+tugi ;21_S	et	f	\N
182441	leehtedes	?leehtedes =leehte  (Ger  >leehtema !27_V	et	f	\N
182448	eijätku	eijätku =jätku  (SgG  >ei+jätk !22_S	et	f	\N
182449	eijätku	eijätku =jätku  (SgP  >ei+jätk !22_S	et	f	\N
182450	eijätku	eijätku =jätku  (SgAdt  >ei+jätk !22_S	et	f	\N
182453	kekkool	?kekkool =kekkoo  (SgAd  >kekkoo !26_S	et	f	\N
182454	kekkool	?kekkool =kekkool  (SgN  >kekkool !22_S	et	f	\N
182459	5kl	### 5kl	et	f	\N
182467	sasreste	?sasreste =sasres  (PlG  >sasres !09_S	et	f	\N
182468	sasreste	?sasreste =sasres  (PlG  >sasrene !10_A	et	f	\N
182469	teadussõnavara	teadussõnavara =vara  (SgN  >teadus+sõna+vara !17_S	et	f	\N
182470	teadussõnavara	teadussõnavara =vara  (SgG  >teadus+sõna+vara !17_S	et	f	\N
182471	teadussõnavara	teadussõnavara =vara  (SgP  >teadus+sõna+vara !17_S	et	f	\N
182479	erl	?erl =erl  (SgN  >erl !22_S	et	f	\N
182480	rahvalauluuurija	rahvalauluuurija =uurija  (SgN  >rahva+laulu+uurija !01_S	et	f	\N
182481	rahvalauluuurija	rahvalauluuurija =uurija  (SgG  >rahva+laulu+uurija !01_S	et	f	\N
182516	lõned	?lõned =lõne  (PlN  >lõne !16_S	et	f	\N
182517	lõned	?lõned =lõne  (IndPrSg2  >lõnema !27_V	et	f	\N
182522	keskvõimu	keskvõimu =võimu  (SgG  >kesk+võim !22_S	et	f	\N
182523	keskvõimu	keskvõimu =võimu  (SgP  >kesk+võim !22_S	et	f	\N
182524	keskvõimu	keskvõimu =võimu  (SgAdt  >kesk+võim !22_S	et	f	\N
182530	neljaklassiline	neljaklassiline =klassiline  (SgN  >nelja+klassiline !12_A	et	f	\N
182531	neljaklassiline	"nelja+klassiline %klassi  )LINE_aA  <nelja+klass ;22_S	et	f	\N
182539	6-kl	### 6-kl	et	f	\N
182549	arstid	arstid =arsti  (PlN  >arst !22_S	et	f	\N
182550	arstid	arstid =arsti  (IndPrSg2  >arstima !28_V	et	f	\N
182551	kooliõpetaja	kooliõpetaja =õpetaja  (SgN  >kooli+õpetaja !01_S	et	f	\N
182552	kooliõpetaja	kooliõpetaja =õpetaja  (SgG  >kooli+õpetaja !01_S	et	f	\N
182572	4klassi	klassi =klassi  (SgG  >klass !22_S	et	f	\N
182573	4klassi	klassi =klassi  (SgP  >klass !22_S	et	f	\N
182574	4klassi	klassi =klassi  (SgAdt  >klass !22_S	et	f	\N
182580	loiaalne	?loiaalne =loiaalne  (SgN  >loiaalne !02_A	et	f	\N
182581	loiaalne	?loiaalne =loiaalne  (PlP  >loiaaln !22_S	et	f	\N
182600	keskuseks	keskuseks =keskuse  (SgTr  >keskus !11~09_S	et	f	\N
182601	keskuseks	keskuseks =use  (PlTr  >kesk+usk !22_S	et	f	\N
182602	bioloogia	bioloogia =bioloogia  (SgN  >bioloogia !01_S	et	f	\N
182603	bioloogia	bioloogia =bioloogia  (SgG  >bioloogia !01_S	et	f	\N
182608	propagandeeris	?propagandeeris =propagandeeri  (SgIn  >propagandeeri !16_S	et	f	\N
182609	propagandeeris	?propagandeeris =propagandeeri  (SgIn  >propagandeer !22_S	et	f	\N
182610	propagandeeris	?propagandeeris =propagandeeri  (IndIpfSg3  >propagandeerima !28_V	et	f	\N
182611	propagandeeris	?propagandeeris =propagandeeris  (SgN  >propagandeeris !09_S	et	f	\N
182612	algatajaid	algatajaid =algataja  (PlP  >algataja !01_S	et	f	\N
182613	algatajaid	"algataja %algata  )JA_vS  <algatama ;27_V	et	f	\N
182618	petseri	?petseri =petseri  (SgN  >petseri !01_S	et	f	\N
182619	petseri	?petseri =petseri  (SgG  >petseri !01_S	et	f	\N
182620	petseri	?petseri =petseri  (SgG  >petser !02_S	et	f	\N
182621	leppisid	leppisid =leppi  (PlP  >lepp !22_S	et	f	\N
182622	leppisid	leppisid =leppi  (PlP  >lepp !22_SA	et	f	\N
182623	leppisid	leppisid =leppi  (IndIpfSg2  >leppima !28_V	et	f	\N
182624	leppisid	leppisid =leppi  (IndIpfPl3  >leppima !28_V	et	f	\N
182626	tõnisoniga	?tõnisoniga =tõnisoni  (SgKom  >tõnison !19_S	et	f	\N
182627	tõnisoniga	?tõnisoniga =oni  (SgKom  >tõnis+oni !17_S	et	f	\N
182641	ühiserahva	?ühiserahva =ühiserahva  (SgN  >ühiserahva !16_S	et	f	\N
182642	ühiserahva	?ühiserahva =ühiserahva  (SgG  >ühiserahva !16_S	et	f	\N
182643	ühiserahva	?ühiserahva =erahva  (SgN  >ühis+erahva !01_S	et	f	\N
182644	ühiserahva	?ühiserahva =erahva  (SgG  >ühis+erahva !01_S	et	f	\N
182652	mõu	?mõu =mõu  (SgN  >mõu !26_S	et	f	\N
182653	mõu	?mõu =mõu  (SgG  >mõu !26_S	et	f	\N
182378	kutseharidust	kutseharidust =dust  (SgN  >kutse+hari+dust !22_S	et	f	\N
182379	kutseharidust	kutseharidust =haridus  (SgP  >kutse+haridus !11_S	et	f	\N
182397	rahvusarkamine	?rahvusarkamine =rahvusarkamine  (SgN  >rahvusarkamine !12_S	et	f	\N
182398	rahvusarkamine	?rahvusarkamine =rahvusarkamine  (PlP  >rahvusarkamin !19_S	et	f	\N
182399	rahvusarkamine	?rahvusarkamine =arkamine  (SgN  >rahvus+arkamine !12_S	et	f	\N
182400	rahvusarkamine	?rahvusarkamine =arkamine  (PlP  >rahvus+arkamin !19_S	et	f	\N
182401	rahvusarkamine	?rahvusarkamine =sarkamine  (SgN  >rahvu+sarkamine !12_S	et	f	\N
182402	rahvusarkamine	?rahvusarkamine =sarkamine  (PlP  >rahvu+sarkamin !19_S	et	f	\N
182410	riigivanema	riigivanema =vanema  (SgG  >riigi+vanem !02_AS	et	f	\N
182411	riigivanema	"riigi+vanem %vane  )M_cA  <riigi+vana ;17_AS	et	f	\N
182417	riigitoetus	riigitoetus =toetu  (SgIn  >riigi+toetu !01_A	et	f	\N
182418	riigitoetus	"riigi+toetu %toe  )TU2_kA  <riigi+tugi ;21_S	et	f	\N
182419	riigitoetus	riigitoetus =toetus  (SgN  >riigi+toetus !11~09_S	et	f	\N
182420	riigitoetus	"riigi+toetus %toe  )TUS2_aS  <riigi+tugi ;21_S	et	f	\N
182421	vähemusrahvas	vähemusrahvas =rahva  (SgIn  >vähemus+rahvas !07_S	et	f	\N
182422	vähemusrahvas	vähemusrahvas =rahvas  (SgN  >vähemus+rahvas !07_S	et	f	\N
182432	edendasid	edendasid =edenda  (IndIpfSg2  >edendama !27_V	et	f	\N
182433	edendasid	edendasid =edenda  (IndIpfPl3  >edendama !27_V	et	f	\N
182442	lomeühenguid	?lomeühenguid =lomeühengu  (PlP  >lomeüheng !02_S	et	f	\N
182443	lomeühenguid	?lomeühenguid =lomeühengui  (PlN  >lomeühengui !26_S	et	f	\N
182444	lomeühenguid	?lomeühenguid =lomeühengui  (SgP  >lomeühengui !26_S	et	f	\N
182445	lit	### lit	et	f	\N
182446	proppageerima	?proppageerima =proppageeri  (Sup  >proppageerima !28_V	et	f	\N
182447	proppageerima	?proppageerima =proppageerima  (SgG  >proppageerim !02_A	et	f	\N
182455	rahvaülikool	rahvaülikool =koo  (SgAd  >rahva+üli+kubu !18_S	et	f	\N
182456	rahvaülikool	rahvaülikool =kool  (SgN  >rahva+üli+kool !22_S	et	f	\N
182466	teadland	?teadland =teadland  (SgN  >teadland !02_S	et	f	\N
182473	kampmaa	?kampmaa =kampmaa  (SgN  >kampmaa !26_S	et	f	\N
182474	kampmaa	?kampmaa =kampmaa  (SgG  >kampmaa !26_S	et	f	\N
182482	astronoomia	astronoomia =astronoomia  (SgN  >astronoomia !01_S	et	f	\N
182483	astronoomia	astronoomia =astronoomia  (SgG  >astronoomia !01_S	et	f	\N
182508	politilist	?politilist =politilis  (SgP  >politilis !09_S	et	f	\N
182509	politilist	?politilist =politilis  (SgP  >politiline !12_A	et	f	\N
182510	politilist	?politilist =politilist  (SgN  >politilist !22_S	et	f	\N
182528	hääleõigus	hääleõigus =õigus  (SgN  >hääle+õigus !11~09_S	et	f	\N
182529	hääleõigus	"hääle+õigus %õige  )US_aS  <hääle+õige ;01_A	et	f	\N
182561	põllumeesteseltsi	põllumeesteseltsi =seltsi  (SgG  >põllu+meeste+selts !22_S	et	f	\N
182562	põllumeesteseltsi	põllumeesteseltsi =seltsi  (SgP  >põllu+meeste+selts !22_S	et	f	\N
182563	põllumeesteseltsi	põllumeesteseltsi =seltsi  (SgAdt  >põllu+meeste+selts !22_S	et	f	\N
182568	riigiülestõus	riigiülestõus =tõu  (SgIn  >riigi+üles+tõug !22_S	et	f	\N
182569	riigiülestõus	riigiülestõus =tõu  (SgIn  >riigi+üles+tõu !26_S	et	f	\N
182570	riigiülestõus	riigiülestõus =tõus  (SgN  >riigi+üles+tõus !22_S	et	f	\N
182575	kohustuslikku	kohustuslikku =kohustuslikku  (SgP  >kohustuslik !25_A	et	f	\N
182576	kohustuslikku	kohustuslikku =kohustuslikku  (SgAdt  >kohustuslik !25_A	et	f	\N
182593	eseltse	?eseltse =eseltse  (SgG  >eseltne !02_A	et	f	\N
182594	eseltse	?eseltse =eseltse  (PlP  >eselts !22_S	et	f	\N
182595	eseltse	?eseltse =eseltse  (IndPrPs_  >eseltsema !27_V	et	f	\N
182596	eseltse	?eseltse =eseltse  (ImpPrSg2  >eseltsema !27_V	et	f	\N
182614	suurematel	suurematel =suurema  (PlAd  >suurem !02_A	et	f	\N
182615	suurematel	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
182616	suurematel	suurematel =mate  (SgAd  >suure+mate !16_S	et	f	\N
182617	suurematel	suurematel =mate  (PlAd  >suure+matt !22_SA	et	f	\N
182639	abiliseks	abiliseks =abilise  (SgTr  >abiline !12_S	et	f	\N
182640	abiliseks	"abiline %abi  )LINE_aA  <abi ;17_S	et	f	\N
182662	korrldasid	?korrldasid =korrlda  (IndIpfSg2  >korrldama !29_V	et	f	\N
182663	korrldasid	?korrldasid =korrlda  (IndIpfPl3  >korrldama !29_V	et	f	\N
182674	1930ndates	?ndates =ndate  (PlIn  >ndatt !22_S	et	f	\N
182675	1930ndates	?ndates =ndate  (IndIpfSg3  >ndatema !27_V	et	f	\N
182676	1930ndates	?ndates =ndates  (SgN  >ndates !09_S	et	f	\N
182677	ihise	?ihise =ihise  (SgG  >ihis !09_S	et	f	\N
182678	ihise	?ihise =ihise  (IndPrPs_  >ihisema !27_V	et	f	\N
182679	ihise	?ihise =ihise  (ImpPrSg2  >ihisema !27_V	et	f	\N
182703	1880ndat	### 1880ndat	et	f	\N
182706	manitesti	?manitesti =manitesti  (ID  >manitesti !41_D	et	f	\N
182707	manitesti	?manitesti =manitesti  (IndPrPs_  >manitestima !28_V	et	f	\N
182708	manitesti	?manitesti =manitesti  (ImpPrSg2  >manitestima !28_V	et	f	\N
182726	kirjaviisi	kirjaviisi =viisi  (ID  >kirja+viisi !41_D	et	f	\N
182727	kirjaviisi	kirjaviisi =viisi  (SgG  >kirja+viis !22_S	et	f	\N
182728	kirjaviisi	kirjaviisi =viisi  (SgP  >kirja+viis !22_S	et	f	\N
182729	kirjaviisi	kirjaviisi =viisi  (SgAdt  >kirja+viis !22_S	et	f	\N
182735	rahvavaimu	rahvavaimu =vaimu  (SgG  >rahva+vaim !22_S	et	f	\N
182736	rahvavaimu	rahvavaimu =vaimu  (SgP  >rahva+vaim !22_S	et	f	\N
182440	usubadus	?usubadus =badus  (SgN  >usu+badus !02_A	et	f	\N
182461	6klalgk	?klalgk =klalgk  (SgN  >klalgk !22_S	et	f	\N
182484	arstiteadusarenes	?arstiteadusarenes =arstiteadusarene  (PlIn  >arstiteadusaren !19_S	et	f	\N
182485	arstiteadusarenes	?arstiteadusarenes =teadusarene  (PlIn  >arsti+teadusaren !19_S	et	f	\N
182486	arstiteadusarenes	?arstiteadusarenes =iteadusarene  (PlIn  >arst+iteadusaren !19_S	et	f	\N
182493	sirur	?sirur =sirur  (SgN  >sirur !02_S	et	f	\N
182494	adson	?adson =adson  (SgN  >adson !02_S	et	f	\N
182495	gailit	?gailit =gaili  (SgP  >gaili !16_S	et	f	\N
182496	gailit	?gailit =gailit  (SgN  >gailit !02_S	et	f	\N
182497	alver	?alver =alver  (SgN  >alver !02_S	et	f	\N
182498	koiduajast	koiduajast =aja  (SgEl  >koidu+aeg !22_S	et	f	\N
182499	koiduajast	koiduajast =ajas  (SgP  >koidu+ajane !10_A	et	f	\N
182500	koiduajast	"koidu+ajane %aja  )NE_aA  <koidu+aeg ;22_S	et	f	\N
182503	usustamine	usustamine =usustamine  (SgN  >usustamine !12_S	et	f	\N
182504	usustamine	"usustamine %ususta  )MINE_vS  <usustama ;27_V	et	f	\N
182505	läänemererahvastest	läänemererahvastest =rahvas  (PlEl  >lääne+mere+rahvas !07_S	et	f	\N
182506	läänemererahvastest	läänemererahvastest =rahvas  (PlEl  >lääne+mere+rahvane !10_A	et	f	\N
182507	läänemererahvastest	"lääne+mere+rahvane %rahva  )NE_aA  <lääne+mere+rahvas ;07_S	et	f	\N
182514	jannsenil	?jannsenil =jannseni  (SgAd  >jannsen !02_S	et	f	\N
182515	jakobsonile	?jakobsonile =jakobsoni  (SgAll  >jakobson !19_S	et	f	\N
182525	vähemusrahvastel	vähemusrahvastel =rahvas  (PlAd  >vähemus+rahvas !07_S	et	f	\N
182526	vähemusrahvastel	vähemusrahvastel =rahvas  (PlAd  >vähemus+rahvane !10_A	et	f	\N
182527	vähemusrahvastel	"vähemus+rahvane %rahva  )NE_aA  <vähemus+rahvas ;07_S	et	f	\N
182534	3-klassiline	-klassiline =klassiline  (SgN  >-klassiline !12_A	et	f	\N
182535	3-klassiline	"-klassiline %klassi  )LINE_aA  <-klass ;22_S	et	f	\N
182538	4-kl	### 4-kl	et	f	\N
182540	mõistesõnaraamat	?mõistesõnaraamat =mõistesõnaraama  (SgP  >mõistesõnaraama !16_S	et	f	\N
182571	intelegentsust	?intelegentsust =intelegentsus  (SgP  >intelegentsus !11~09_S	et	f	\N
182577	uurij	### uurij	et	f	\N
182579	2carl	?carl =carl  (SgN  >carl !22_S	et	f	\N
182597	kontakteerida	?kontakteerida =kontakteeri  (Inf  >kontakteerima !28_V	et	f	\N
182645	valisus	?valisus =valisu  (SgIn  >valisu !01_S	et	f	\N
182646	valisus	?valisus =valisu  (IndIpfSg3  >valisuma !27_V	et	f	\N
182647	valisus	?valisus =valisus  (SgN  >valisus !11_S	et	f	\N
182664	sõlmis	sõlmis =sõlmi  (SgIn  >sõlm !22_S	et	f	\N
182665	sõlmis	sõlmis =sõlmi  (PlIn  >sõlm !22_S	et	f	\N
182666	sõlmis	sõlmis =sõlmi  (IndIpfSg3  >sõlmima !28_V	et	f	\N
182667	aoma	?aoma =aoma  (SgN  >aoma !16_S	et	f	\N
182668	aoma	?aoma =aoma  (SgG  >aoma !16_S	et	f	\N
182669	aoma	?aoma =aoma  (IndPrPs_  >aomama !29_V	et	f	\N
182670	aoma	?aoma =aoma  (ImpPrSg2  >aomama !29_V	et	f	\N
182673	arkamisaeg	?arkamisaeg =arkamisaeg  (SgN  >arkamisaeg !22_S	et	f	\N
182686	rahvuseepolse	?rahvuseepolse =rahvuseepolse  (SgG  >rahvuseepolne !02_A	et	f	\N
182687	rahvuseepolse	?rahvuseepolse =rahvuseepolse  (PlP  >rahvuseepols !22_S	et	f	\N
182688	rahvuseepolse	?rahvuseepolse =polse  (SgN  >rahvu+see+polse !06_S	et	f	\N
182689	rahvuseepolse	?rahvuseepolse =polse  (SgG  >rahvu+see+polne !02_A	et	f	\N
182690	rahvuseepolse	?rahvuseepolse =polse  (PlP  >rahvu+see+pols !22_S	et	f	\N
182691	rahvuseepolse	?rahvuseepolse =eepolse  (SgG  >rahvus+eepolne !02_A	et	f	\N
182692	rahvuseepolse	?rahvuseepolse =eepolse  (PlP  >rahvus+eepols !22_S	et	f	\N
182693	rahvuseepolse	?rahvuseepolse =seepolse  (SgG  >rahvu+seepolne !02_A	et	f	\N
182694	rahvuseepolse	?rahvuseepolse =seepolse  (PlP  >rahvu+seepols !22_S	et	f	\N
182695	eestlstele	?eestlstele =eestlste  (SgAll  >eestlste !06_S	et	f	\N
182696	eestlstele	?eestlstele =eestlste  (PlAll  >eestlst !22_S	et	f	\N
182697	eestlstele	?eestlstele =eestlstele  (IndPrPs_  >eestlstelema !27_V	et	f	\N
182698	eestlstele	?eestlstele =eestlstele  (ImpPrSg2  >eestlstelema !27_V	et	f	\N
182704	saavutamist	saavutamist =saavutamis  (SgP  >saavutamine !12_S	et	f	\N
182705	saavutamist	"saavutamine %saavuta  )MINE_vS  <saavutama ;27_V	et	f	\N
182739	wiedemann	?wiedemann =wiedemann  (SgN  >wiedemann !22_S	et	f	\N
182744	kukutatud	kukutatud =kukuta  (PtsPtIps  >kukutama !27_V	et	f	\N
182745	kukutatud	kukutatud =kukutatu  (PlN  >kukutatu !01_S	et	f	\N
182746	kukutatud	"kukutatu %kukuta  )TU1_vS  <kukutama ;27_V	et	f	\N
182747	kukutatud	kukutatud =kukutatud  (ID  >kukutatud !41_A	et	f	\N
182748	kukutatud	"kukutatud %kukuta  )TUD_vA  <kukutama ;27_V	et	f	\N
182754	kurgja	?kurgja =kurgja  (SgN  >kurgja !01_S	et	f	\N
182755	kurgja	?kurgja =kurgja  (SgG  >kurgja !01_S	et	f	\N
182756	kurgja	?kurgja =kurgja  (SgG  >kurgjas !02_A	et	f	\N
182757	kurgja	?kurgja =kurgja  (IndPrPs_  >kurgjama !29_V	et	f	\N
182758	kurgja	?kurgja =kurgja  (ImpPrSg2  >kurgjama !29_V	et	f	\N
182780	elavnemisele	elavnemisele =elavnemise  (SgAll  >elavnemine !12_S	et	f	\N
182781	elavnemisele	"elavnemine %elavne  )MINE_vS  <elavnema ;27_V	et	f	\N
182791	opli	?opli =opli  (ID  >opli !41_D	et	f	\N
182792	opli	?opli =opli  (SgG  >oppel !02_S	et	f	\N
182806	poliituline	?poliituline =poliituline  (SgN  >poliituline !12_A	et	f	\N
182502	muinasnnud	?muinasnnud =muinasnnu  (IndPrSg2  >muinasnnuma !27_V	et	f	\N
182511	rahvane	rahvane =rahvane  (SgN  >rahvane !10_A	et	f	\N
182512	rahvane	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
182513	rootslaset	### rootslaset	et	f	\N
182518	piimakase	piimakase =kase  (SgG  >piima+kask !22_S	et	f	\N
182519	piimakase	piimakase =akase  (SgG  >piim+akane !10_A	et	f	\N
182520	piimakase	"piim+akane %aka  )NE_aA  <piim+aka ;16_S	et	f	\N
182521	õmblusmampside	?õmblusmampside =mampsi  (PlG  >õmblus+mamps !22_S	et	f	\N
182532	6-klassiline	-klassiline =klassiline  (SgN  >-klassiline !12_A	et	f	\N
182533	6-klassiline	"-klassiline %klassi  )LINE_aA  <-klass ;22_S	et	f	\N
182536	politseikoolis	politseikoolis =kooli  (SgIn  >politsei+kool !22_S	et	f	\N
182537	politseikoolis	politseikoolis =kooli  (PlIn  >politsei+kool !22_S	et	f	\N
182541	veske	?veske =veske  (SgN  >veske !01_A	et	f	\N
182542	veske	?veske =veske  (SgG  >veske !01_A	et	f	\N
182543	veske	?veske =veske  (PlP  >vesk !22_S	et	f	\N
182544	veske	?veske =veske  (IndPrPs_  >veskema !27_V	et	f	\N
182545	veske	?veske =veske  (ImpPrSg2  >veskema !27_V	et	f	\N
182553	kostnud	kostnud =kost  (PtsPtPs  >kostma !34_V	et	f	\N
182554	kostnud	kostnud =kostnu  (PlN  >kostnu !01_S	et	f	\N
182555	kostnud	"kostnu %kost  )NU_vS  <kostma ;34_V	et	f	\N
182556	kostnud	kostnud =kostnud  (ID  >kostnud !41_A	et	f	\N
182557	kostnud	"kostnud %kost  )NUD_vA  <kostma ;34_V	et	f	\N
182578	ül	### ül	et	f	\N
182588	tõuke	tõuke =tõuke  (SgN  >tõuke !12?10_S	et	f	\N
182589	tõuke	"tõuke %tõu  )KE_dS  <tõug ;22_S	et	f	\N
182590	tõuke	"tõuke %tõu  )KE_dS  <tõu ;26_S	et	f	\N
182591	tõuke	tõuke =tõuke  (SgG  >tõuge !06_S	et	f	\N
182592	tõuke	tõuke =tõuke  (PlP  >tõuk !22_S	et	f	\N
182598	isamaal	isamaal =maa  (SgAd  >isa+maa !26_S	et	f	\N
182599	isamaal	isamaal =maal  (SgN  >isa+maal !22_S	et	f	\N
182628	poshe	?poshe =poshe  (SgN  >poshe !06_S	et	f	\N
182629	poshe	?poshe =poshe  (SgG  >poshe !06_S	et	f	\N
182630	poshe	?poshe =poshe  (PlP  >posh !22_S	et	f	\N
182631	poshe	?poshe =poshe  (IndPrPs_  >poshema !27_V	et	f	\N
182632	poshe	?poshe =poshe  (ImpPrSg2  >poshema !27_V	et	f	\N
182633	valitsusse	valitsusse =valitsus  (SgAdt  >valitsus !11_S	et	f	\N
182634	valitsusse	"valitsus %valitse  )US_vS  <valitsema ;27_V	et	f	\N
182635	pätsa	?pätsa =pätsa  (SgN  >pätsa !16_S	et	f	\N
182636	pätsa	?pätsa =pätsa  (SgG  >pätsa !16_S	et	f	\N
182637	pätsa	?pätsa =pätsa  (IndPrPs_  >pätsama !29_V	et	f	\N
182638	pätsa	?pätsa =pätsa  (ImpPrSg2  >pätsama !29_V	et	f	\N
182648	jaaoks	?jaaoks =jaaoks  (SgN  >jaaoks !22_S	et	f	\N
182654	tsiviliseerituks	tsiviliseerituks =tsiviliseeri  (KndPtIps  >tsiviliseerima !28_V	et	f	\N
182655	tsiviliseerituks	tsiviliseerituks =tsiviliseeritu  (SgTr  >tsiviliseeritu !01_S	et	f	\N
182656	tsiviliseerituks	"tsiviliseeritu %tsiviliseeri  )TU1_vS  <tsiviliseerima ;28_V	et	f	\N
182657	töstus	?töstus =töstu  (SgIn  >töstu !16_S	et	f	\N
182658	töstus	?töstus =töstu  (IndIpfSg3  >töstuma !27_V	et	f	\N
182659	töstus	?töstus =töstus  (SgN  >töstus !11~09_S	et	f	\N
182682	uldlaulupidu	?uldlaulupidu =uldlaulupidu  (IndPrPs_  >uldlaulupiduma !27_V	et	f	\N
182683	uldlaulupidu	?uldlaulupidu =uldlaulupidu  (ImpPrSg2  >uldlaulupiduma !27_V	et	f	\N
182684	ludia	?ludia =ludia  (SgN  >ludia !01_S	et	f	\N
182685	ludia	?ludia =ludia  (SgG  >ludia !01_S	et	f	\N
182719	tugevana	tugevana =tugeva  (SgEs  >tugev !02_A	et	f	\N
182720	tugevana	"tugev %tuge  )V_vA  <tugema ;27_V	et	f	\N
182749	maapäeva	maapäeva =päeva  (SgG  >maa+päev !22_S	et	f	\N
182750	maapäeva	maapäeva =päeva  (SgP  >maa+päev !22_S	et	f	\N
182751	maapäeva	maapäeva =päeva  (SgAdt  >maa+päev !22_S	et	f	\N
182764	kultuurilekunstile	?kultuurilekunstile =lekunsti  (SgAll  >kultuuri+lekunsti !01_S	et	f	\N
182765	kultuurilekunstile	?kultuurilekunstile =lekunsti  (SgAll  >kultuuri+lekunst !22_S	et	f	\N
182772	riigipöörde	?riigipöörde =riigipöörde  (PlP  >riigipöörd !22_S	et	f	\N
182773	poliitil	?poliitil =poliiti  (SgAd  >poliiti !16_S	et	f	\N
182774	vastuolu	vastuolu =olu  (SgN  >vastu+olu !17_S	et	f	\N
182775	vastuolu	vastuolu =olu  (SgG  >vastu+olu !17_S	et	f	\N
182776	vastuolu	vastuolu =olu  (SgP  >vastu+olu !17_S	et	f	\N
182782	tagasilangus	tagasilangus =langu  (SgIn  >tagasi+lang !22_S	et	f	\N
182783	tagasilangus	tagasilangus =langus  (SgN  >tagasi+langus !11~09_S	et	f	\N
182796	elitaarsusele	?elitaarsusele =elitaarsuse  (SgAll  >elitaarsus !11~09_S	et	f	\N
182797	elitaarsusele	?elitaarsusele =suse  (SgAll  >elitaar+suse !16_S	et	f	\N
182800	ühinenud	ühinenud =ühine  (PtsPtPs  >ühinema !27_V	et	f	\N
182801	ühinenud	ühinenud =ühinenu  (PlN  >ühinenu !01_S	et	f	\N
182802	ühinenud	"ühinenu %ühine  )NU_vS  <ühinema ;27_V	et	f	\N
182803	ühinenud	ühinenud =ühinenud  (ID  >ühinenud !41_A	et	f	\N
182804	ühinenud	"ühinenud %ühine  )NUD_vA  <ühinema ;27_V	et	f	\N
182808	iseteadvus	iseteadvus =teadvus  (SgN  >ise+teadvus !11~09_S	et	f	\N
182810	iseteadvus	"ise+teadvus %teadva  )US_aS  <ise+teadev ;02_A	et	f	\N
182814	tekstiili	tekstiili =tekstiili  (SgG  >tekstiil !22_S	et	f	\N
182815	tekstiili	tekstiili =tekstiili  (SgP  >tekstiil !22_S	et	f	\N
182680	mitmndal	?mitmndal =mitmnda  (SgAd  >mitmnda !01_S	et	f	\N
182681	mitmndal	?mitmndal =mitmndal  (SgN  >mitmndal !02_S	et	f	\N
182709	vägivastu	?vägivastu =vägivastu  (IndPrPs_  >vägivastuma !27_V	et	f	\N
182710	vägivastu	?vägivastu =vägivastu  (ImpPrSg2  >vägivastuma !27_V	et	f	\N
182711	tunnustatud	tunnustatud =tunnusta  (PtsPtIps  >tunnustama !27_V	et	f	\N
182712	tunnustatud	tunnustatud =tunnustatu  (PlN  >tunnustatu !01_S	et	f	\N
182713	tunnustatud	"tunnustatu %tunnusta  )TU1_vS  <tunnustama ;27_V	et	f	\N
182714	tunnustatud	tunnustatud =tunnustatud  (ID  >tunnustatud !41_A	et	f	\N
182715	tunnustatud	"tunnustatud %tunnusta  )TUD_vA  <tunnustama ;27_V	et	f	\N
182717	radikaal	radikaal =radikaal  (SgN  >radikaal !22_S	et	f	\N
182718	radikaal	radikaal =kaal  (SgN  >radi+kaal !22_S	et	f	\N
182730	rahvuskeel	rahvuskeel =kee  (SgAd  >rahvus+kesi !15_S	et	f	\N
182731	rahvuskeel	rahvuskeel =kee  (SgAd  >rahvus+kee !26_S	et	f	\N
182732	rahvuskeel	rahvuskeel =keel  (SgN  >rahvus+keel !13_S	et	f	\N
182740	tütarlastekooli	tütarlastekooli =kooli  (SgG  >tütar+laste+kool !22_S	et	f	\N
182741	tütarlastekooli	tütarlastekooli =kooli  (SgP  >tütar+laste+kool !22_S	et	f	\N
182742	tütarlastekooli	tütarlastekooli =kooli  (SgAdt  >tütar+laste+kool !22_S	et	f	\N
182743	tütarlastekooli	tütarlastekooli =kooli  (PlP  >tütar+laste+kool !22_S	et	f	\N
182752	isama	?isama =isa  (Sup  >isama !27_V	et	f	\N
182753	isama	?isama =isama  (SgG  >isam !02_A	et	f	\N
182759	näidistalu	näidistalu =talu  (SgN  >näidis+talu !17_S	et	f	\N
182760	näidistalu	näidistalu =talu  (SgG  >näidis+talu !17_S	et	f	\N
182761	näidistalu	näidistalu =talu  (SgP  >näidis+talu !17_S	et	f	\N
182762	autoritaarne	autoritaarne =autoritaarne  (SgN  >autoritaarne !02_A	et	f	\N
182763	autoritaarne	autoritaarne =taarne  (PlP  >autori+taarn !22_S	et	f	\N
182778	säilitamises	säilitamises =säilitamise  (SgIn  >säilitamine !12_S	et	f	\N
182779	säilitamises	"säilitamine %säilita  )MINE_vS  <säilitama ;27_V	et	f	\N
182784	põhjamaadest	põhjamaadest =maa  (PlEl  >põhja+maa !26_S	et	f	\N
182785	põhjamaadest	põhjamaadest =maade  (PlEl  >põhja+maat !22_S	et	f	\N
182833	rüh-mitus	rüh-mitus =mitus  (SgN  >rüh-mitus !09_S	et	f	\N
182834	rüh-mitus	"rüh-mitus %mi  )TUS2_aS  <rüh-mi ;26_S	et	f	\N
182847	kodukariõigus	kodukariõigus =õigus  (SgN  >kodu+kari+õigus !11~09_S	et	f	\N
182848	kodukariõigus	"kodu+kari+õigus %õige  )US_aS  <kodu+kari+õige ;01_A	et	f	\N
182849	sunnismaine	?sunnismaine =sunnismaine  (SgN  >sunnismaine !16_S	et	f	\N
182850	sunnismaine	?sunnismaine =sunnismaine  (SgG  >sunnismaine !16_S	et	f	\N
182851	sunnismaine	?sunnismaine =sunnismaine  (PlP  >sunnismain !19_S	et	f	\N
182852	sunnismaine	?sunnismaine =smaine  (SgN  >sunni+smaine !10_A	et	f	\N
182853	sunnismaine	?sunnismaine =smaine  (PlP  >sunni+smain !22_S	et	f	\N
182864	1870-	### 1870-	et	f	\N
182865	ääremaad	ääremaad =maa  (PlN  >ääre+maa !26_S	et	f	\N
182866	ääremaad	ääremaad =maa  (SgP  >ääre+maa !26_S	et	f	\N
182870	kõrgkultuuri	kõrgkultuuri =kultuuri  (SgG  >kõrg+kultuur !22_S	et	f	\N
182871	kõrgkultuuri	kõrgkultuuri =kultuuri  (SgP  >kõrg+kultuur !22_S	et	f	\N
182872	kõrgkultuuri	kõrgkultuuri =kultuuri  (SgAdt  >kõrg+kultuur !22_S	et	f	\N
182876	võlisturgusid	?võlisturgusid =võlisturgu  (IndIpfSg2  >võlisturguma !27_V	et	f	\N
182877	võlisturgusid	?võlisturgusid =võlisturgu  (IndIpfPl3  >võlisturguma !27_V	et	f	\N
182882	balkanimaadest	balkanimaadest =maa  (PlEl  >balkani+maa !26_S	et	f	\N
182883	balkanimaadest	balkanimaadest =maade  (PlEl  >balkani+maat !22_S	et	f	\N
182886	forforiidi	?forforiidi =forforiidi  (SgN  >forforiidi !16_S	et	f	\N
182887	forforiidi	?forforiidi =forforiidi  (SgG  >forforiidi !16_S	et	f	\N
182888	forforiidi	?forforiidi =forforiidi  (SgG  >forforiit !22_S	et	f	\N
182890	forforiidi	?forforiidi =forforiidi  (SgP  >forforiid !22_S	et	f	\N
182892	forforiidi	?forforiidi =forforiidi  (SgAdt  >forforiid !22_S	et	f	\N
182893	forforiidi	?forforiidi =forforiidi  (IndPrPs_  >forforiitima !28_V	et	f	\N
182894	forforiidi	?forforiidi =forforiidi  (ImpPrSg2  >forforiitima !28_V	et	f	\N
182898	esikohale	esikohale =koha  (SgAll  >esi+koha !17_S	et	f	\N
182899	esikohale	esikohale =koha  (SgAll  >esi+koht !22_S	et	f	\N
182900	metallurgia	metallurgia =metallurgia  (SgN  >metallurgia !01_S	et	f	\N
182902	metallurgia	metallurgia =metallurgia  (SgG  >metallurgia !01_S	et	f	\N
182914	majkriis	?majkriis =majkri  (PlIn  >majkri !01_S	et	f	\N
182915	majkriis	?majkriis =majkrii  (SgIn  >majkrii !26_S	et	f	\N
182916	majkriis	?majkriis =majkriis  (SgN  >majkriis !22_S	et	f	\N
182939	laululinnu	laululinnu =linnu  (SgG  >laulu+lind !22_S	et	f	\N
182940	laululinnu	laululinnu =linnu  (PlP  >laulu+linn !22_S	et	f	\N
182959	pärisor	?pärisor =pärisor  (SgN  >pärisor !19_S	et	f	\N
182968	viljakas	viljakas =viljaka  (SgIn  >viljakas !02_A	et	f	\N
182969	viljakas	viljakas =viljakas  (SgN  >viljakas !02_A	et	f	\N
182993	põlismurre	põlismurre =murre  (SgN  >põlis+murre !05_S	et	f	\N
182994	põlismurre	põlismurre =murre  (SgN  >põlis+murre !06_S	et	f	\N
183018	jänud	?jänud =jänu  (PlN  >jänu !17_S	et	f	\N
183019	jänud	?jänud =jänu  (IndPrSg2  >jänuma !27_V	et	f	\N
183020	käskitakse	?käskitakse =käskitakse  (SgG  >käskitakne !02_A	et	f	\N
182722	tunniliseks	"tunniline %tunni  )LINE_aA  <tund ;22_S	et	f	\N
182723	itsus	?itsus =itsu  (SgIn  >itsu !16_S	et	f	\N
182724	itsus	?itsus =itsu  (IndIpfSg3  >itsuma !28_V	et	f	\N
182725	itsus	?itsus =itsus  (SgN  >itsus !11~09_S	et	f	\N
182733	kirjtuas	?kirjtuas =kirjtua  (SgIn  >kirjtua !01_S	et	f	\N
182734	kirjtuas	?kirjtuas =kirjtuas  (SgN  >kirjtuas !22_S	et	f	\N
182768	kukkutamiseni	?kukkutamiseni =kukkutamise  (SgTer  >kukkutamine !12_S	et	f	\N
182769	kukkutamiseni	?kukkutamiseni =kukkutamiseni  (SgG  >kukkutamisen !19_S	et	f	\N
182770	kukkutamiseni	?kukkutamiseni =kukkutamiseni  (SgP  >kukkutamisen !19_S	et	f	\N
182771	kukkutamiseni	?kukkutamiseni =kukkutamiseni  (SgAdt  >kukkutamisen !19_S	et	f	\N
182786	orienteerutud	orienteerutud =orienteeru  (PtsPtIps  >orienteeruma !27_V	et	f	\N
182787	orienteerutud	orienteerutud =orienteerutu  (PlN  >orienteerutu !01_A	et	f	\N
182788	orienteerutud	"orienteerutu %orienteeru  )TU1_vS  <orienteeruma ;27_V	et	f	\N
182789	orienteerutud	orienteerutud =orienteerutud  (ID  >orienteerutud !41_A	et	f	\N
182790	orienteerutud	"orienteerutud %orienteeru  )TUD_vA  <orienteeruma ;27_V	et	f	\N
182798	tähtsamateks	tähtsamateks =tähtsama  (PlTr  >tähtsam !02_A	et	f	\N
182799	tähtsamateks	"tähtsam %tähtsa  )M_cA  <tähtis ;02_A	et	f	\N
182805	teateer	?teateer =teateer  (SgN  >teateer !22_S	et	f	\N
182811	elujõuliseks	elujõuliseks =jõulise  (SgTr  >elu+jõuline !12?10_A	et	f	\N
182812	elujõuliseks	"elu+jõuline %jõu  )LINE_aA  <elu+jõud ;22_S	et	f	\N
182813	elujõuliseks	"elu+jõuline %jõuli  )NE_aA  <elu+jõul ;22_S	et	f	\N
182821	tsemendi	tsemendi =tsemendi  (SgG  >tsement !22_S	et	f	\N
182822	tsemendi	tsemendi =tsemendi  (IndPrPs_  >tsementima !28_V	et	f	\N
182823	tsemendi	tsemendi =tsemendi  (ImpPrSg2  >tsementima !28_V	et	f	\N
182835	vabriigist	?vabriigist =vabriigi  (SgEl  >vabriigi !16_S	et	f	\N
182836	vabriigist	?vabriigist =vabriigi  (SgEl  >vabriik !22_S	et	f	\N
182837	vabriigist	?vabriigist =vabriigis  (SgP  >vabriigis !11_S	et	f	\N
182862	tõusule	tõusule =tõusu  (SgAll  >tõus !22_S	et	f	\N
182863	tõusule	tõusule =sule  (SgG  >tõu+sulg !22_S	et	f	\N
182884	siseturgu	siseturgu =turgu  (SgP  >sise+turg !22_S	et	f	\N
182885	siseturgu	siseturgu =turgu  (SgAdt  >sise+turg !22_S	et	f	\N
182895	kuldrubla	kuldrubla =rubla  (SgN  >kuld+rubla !16~17_S	et	f	\N
182896	kuldrubla	kuldrubla =rubla  (SgG  >kuld+rubla !16~17_S	et	f	\N
182897	kuldrubla	kuldrubla =rubla  (SgP  >kuld+rubla !17_S	et	f	\N
182906	piimatooteid	piimatooteid =te  (PlP  >piima+too+tee !26_S	et	f	\N
182907	piimatooteid	piimatooteid =toote  (PlP  >piima+toode !06_S	et	f	\N
182909	lambavilla	lambavilla =villa  (SgN  >lamba+villa !16_S	et	f	\N
182910	lambavilla	lambavilla =villa  (SgG  >lamba+villa !16_S	et	f	\N
182911	lambavilla	lambavilla =villa  (SgG  >lamba+vill !22_S	et	f	\N
182912	lambavilla	lambavilla =villa  (SgP  >lamba+vill !22_S	et	f	\N
182913	lambavilla	lambavilla =villa  (SgAdt  >lamba+vill !22_S	et	f	\N
182935	rähmitus	rähmitus =rähmitu  (SgIn  >rähmitu !01_AS	et	f	\N
182936	rähmitus	"rähmitu %rähmi  )TU2_kA  <rähm ;22_S	et	f	\N
182937	rähmitus	rähmitus =rähmitus  (SgN  >rähmitus !11_S	et	f	\N
182938	rähmitus	"rähmitus %rähmi  )TUS2_aS  <rähm ;22_S	et	f	\N
182945	sweda	?sweda =sweda  (SgN  >sweda !17_S	et	f	\N
182946	sweda	?sweda =sweda  (SgG  >sweda !17_S	et	f	\N
182947	sweda	?sweda =sweda  (SgP  >sweda !17_S	et	f	\N
182948	sweda	?sweda =sweda  (IndPrPs_  >swedama !27_V	et	f	\N
182949	sweda	?sweda =sweda  (ImpPrSg2  >swedama !27_V	et	f	\N
182953	sotsiaalselt	sotsiaalselt =sotsiaalse  (SgAbl  >sotsiaalne !02_A	et	f	\N
182954	sotsiaalselt	sotsiaalselt =sotsiaalselt  (ID  >sotsiaalselt !41_D	et	f	\N
182955	sotsiaalselt	"sotsiaalselt %sotsiaalse  )LT_mD  <sotsiaalne ;02_A	et	f	\N
182957	jv	### jv	et	f	\N
182964	agraarmaa	agraarmaa =maa  (SgN  >agraar+maa !26_S	et	f	\N
182965	agraarmaa	agraarmaa =maa  (SgG  >agraar+maa !26_S	et	f	\N
182983	militaalvajadused	?militaalvajadused =militaalvajaduse  (PlN  >militaalvajadus !11?09_S	et	f	\N
182985	tekstiiltööstus	?tekstiiltööstus =tekstiiltööstu  (IndIpfSg3  >tekstiiltööstuma !27_V	et	f	\N
182986	tekstiiltööstus	?tekstiiltööstus =tekstiiltööstus  (SgN  >tekstiiltööstus !11~09_S	et	f	\N
182987	tekstiiltööstus	?tekstiiltööstus =iltööstu  (SgIn  >teksti+iltööstu !01_S	et	f	\N
182988	tekstiiltööstus	?tekstiiltööstus =iltööstus  (SgN  >teksti+iltööstus !11~09_S	et	f	\N
183017	tunnakse	?tunnakse =tunnakse  (SgG  >tunnakne !02_A	et	f	\N
183044	ausamalt	ausamalt =ausama  (SgAbl  >ausam !02_A	et	f	\N
183045	ausamalt	"ausam %ausa  )M_cA  <aus ;02_A	et	f	\N
183046	ausamalt	ausamalt =ausamalt  (ID  >ausamalt !41_D	et	f	\N
183047	ausamalt	"ausamalt %ausa  )MALT_mD  <aus ;02_A	et	f	\N
183062	määrsõnadega	### määrsõnadega	et	f	\N
183065	õnnetustest	õnnetustest =õnnetus  (PlEl  >õnnetus !11_S	et	f	\N
183066	õnnetustest	"õnnetus %õnne  )TUS2_aS  <õnn ;22_S	et	f	\N
183067	õnnetustest	õnnetustest =test  (SgN  >õnnetus+test !22_S	et	f	\N
183068	õnnetustest	õnnetustest =tuste  (PlEl  >õnne+tust !22_S	et	f	\N
183078	söödud	söödud =söö  (PtsPtIps  >sööma !38_V	et	f	\N
183079	söödud	söödud =söödu  (PlN  >söödu !01_S	et	f	\N
183080	söödud	"söödu %söö  )TU1_vS  <sööma ;38_V	et	f	\N
182737	rahvavaimu	rahvavaimu =vaimu  (SgAdt  >rahva+vaim !22_S	et	f	\N
182738	rahvavaimu	rahvavaimu =vaimu  (PlP  >rahva+vaim !22_S	et	f	\N
182766	rahvusmeelsus	rahvusmeelsus =meelsus  (SgN  >rahvus+meelsus !11~09_S	et	f	\N
182767	rahvusmeelsus	"rahvus+meelsus %meelse  )US_aS  <rahvus+meelne ;02_A	et	f	\N
182777	allt	?allt =allt  (SgN  >allt !22_S	et	f	\N
182793	nooreestlastel	nooreestlastel =las  (PlAd  >noor+eest+laps !14_S	et	f	\N
182794	nooreestlastel	nooreestlastel =laste  (PlAd  >noor+eest+last !22_S	et	f	\N
182795	nooreestlastel	nooreestlastel =eestlas  (PlAd  >noor+eestlane !12?10_S	et	f	\N
182817	tootlusest	tootlusest =tootluse  (SgEl  >tootlus !11~09_S	et	f	\N
182818	tootlusest	tootlusest =tootluses  (SgP  >tootlusene !12_A	et	f	\N
182819	tootlusest	"tootlusene %tootluse  )NE_aA  <tootlus ;09_S	et	f	\N
182820	tootlusest	"tootlusene %tootluse  )NE_aA  <tootlus ;11_S	et	f	\N
182831	argraarriik	?argraarriik =argraarriik  (SgN  >argraarriik !22_S	et	f	\N
182832	argraarriik	?argraarriik =raarriik  (SgN  >arg+raarriik !22_S	et	f	\N
182845	passiseadus	passiseadus =seadu  (SgIn  >passi+sead !22_S	et	f	\N
182846	passiseadus	passiseadus =seadus  (SgN  >passi+seadus !11~09_S	et	f	\N
182854	ilmuna	?ilmuna =ilmu  (SgEs  >ilmu !16_S	et	f	\N
182855	ilmuna	?ilmuna =una  (SgN  >ilm+una !17_S	et	f	\N
182856	ilmuna	?ilmuna =una  (SgG  >ilm+una !17_S	et	f	\N
182857	ilmuna	?ilmuna =una  (SgP  >ilm+una !17_S	et	f	\N
182858	papa	papa =papa  (SgN  >papa !16_S	et	f	\N
182859	papa	papa =papa  (SgG  >papa !16_S	et	f	\N
182860	iseteadvuse	iseteadvuse =teadvuse  (SgG  >ise+teadvus !11~09_S	et	f	\N
182861	iseteadvuse	"ise+teadvus %teadva  )US_aS  <ise+teadev ;02_A	et	f	\N
182878	läänest	läänest =lääne  (SgEl  >lääs !14_S	et	f	\N
182879	läänest	läänest =lääne  (PlEl  >lään !22_S	et	f	\N
182880	läänest	läänest =läänes  (SgP  >läänene !10_A	et	f	\N
182881	läänest	"läänene %lääne  )NE_aA  <lääs ;14_S	et	f	\N
182889	kaevandamisega	kaevandamisega =kaevandamise  (SgKom  >kaevandamine !12_S	et	f	\N
182891	kaevandamisega	"kaevandamine %kaevanda  )MINE_vS  <kaevandama ;27_V	et	f	\N
182975	karjakasvatus	karjakasvatus =kasvatu  (SgIn  >karja+kasvatu !01_AS	et	f	\N
182976	karjakasvatus	karjakasvatus =kasvatus  (SgN  >karja+kasvatus !11_S	et	f	\N
182979	rukkusorti	?rukkusorti =rukkusorti  (SgP  >rukkusort !22_S	et	f	\N
182980	rukkusorti	?rukkusorti =rukkusorti  (SgAdt  >rukkusort !22_S	et	f	\N
182984	dvigatel	?dvigatel =dvigate  (PlAd  >dvigatt !22_S	et	f	\N
182989	kunstside	kunstside =si  (PlG  >kunst+si !26_S	et	f	\N
182990	kunstside	kunstside =side  (SgN  >kunst+side !04_S	et	f	\N
182991	kunstside	kunstside =side  (SgN  >kunst+side !16_S	et	f	\N
182992	kunstside	kunstside =side  (SgG  >kunst+side !16_S	et	f	\N
183001	arenemist	arenemist =arenemis  (SgP  >arenemine !12_S	et	f	\N
183002	arenemist	"arenemine %arene  )MINE_vS  <arenema ;27_V	et	f	\N
183075	vahetati	vahetati =vaheta  (IndIpfIps  >vahetama !27_V	et	f	\N
183076	vahetati	vahetati =ati  (SgG  >vahet+att !22_S	et	f	\N
183077	vahetati	vahetati =tati  (SgG  >vahe+tatt !22_S	et	f	\N
183084	kukuda	?kukuda =kuku  (Inf  >kukuma !27_V	et	f	\N
183125	õpija	?õpija =õpija  (SgN  >õpija !01_S	et	f	\N
183126	õpija	?õpija =õpija  (SgG  >õpija !01_S	et	f	\N
183127	õpija	?õpija =õpija  (SgG  >õpijas !02_A	et	f	\N
183131	suvelik	?suvelik =suvelik  (SgN  >suvelik !25_A	et	f	\N
183134	mõttelik	?mõttelik =mõttelik  (SgN  >mõttelik !25_A	et	f	\N
183161	elaja	elaja =elaja  (SgN  >elaja !01_S	et	f	\N
183162	elaja	"elaja %ela  )JA_vS  <elama ;27_V	et	f	\N
183163	elaja	elaja =elaja  (SgG  >elaja !01_S	et	f	\N
183164	elaja	elaja =elaja  (SgG  >elajas !02_S	et	f	\N
183181	tulemine	tulemine =tulemine  (SgN  >tulemine !12_S	et	f	\N
183182	tulemine	"tulemine %tule  )MINE_vS  <tulema ;36_V	et	f	\N
183183	tulemine	"tulemine %tulemi  )NE_aA  <tulem ;02_S	et	f	\N
183216	vananemine	vananemine =vananemine  (SgN  >vananemine !12_S	et	f	\N
183217	vananemine	"vananemine %vanane  )MINE_vS  <vananema ;27_V	et	f	\N
183224	jätatakse	?jätatakse =jäta  (IndPrIps  >jätama !27_V	et	f	\N
183225	jätatakse	?jätatakse =jäta  (IndPrIps  >jättama !29_V	et	f	\N
183226	jätatakse	?jätatakse =jätatakse  (SgG  >jätatakne !02_A	et	f	\N
183227	jätatakse	?jätatakse =jätatakse  (PlP  >jätataks !22_S	et	f	\N
183239	muuakse	?muuakse =muuakse  (SgG  >muuakne !02_A	et	f	\N
183240	muuakse	?muuakse =muuakse  (PlP  >muuaks !22_S	et	f	\N
183245	oodale	?oodale =ooda  (SgAll  >ooda !16_S	et	f	\N
183246	oodale	?oodale =oodale  (IndPrPs_  >oodalema !27_V	et	f	\N
183247	oodale	?oodale =oodale  (ImpPrSg2  >oodalema !27_V	et	f	\N
183267	rõõmusalt	?rõõmusalt =rõõmusa  (SgAbl  >rõõmusa !01_S	et	f	\N
183268	rõõmusalt	?rõõmusalt =rõõmusalt  (ID  >rõõmusalt !41_D	et	f	\N
183274	auslemini	?auslemini =auslemi  (SgTer  >auslemi !01_S	et	f	\N
183276	auslemini	?auslemini =auslemi  (SgTer  >auslem !02_A	et	f	\N
183278	auslemini	?auslemini =auslemini  (ID  >auslemini !41_D	et	f	\N
183279	auslemini	?auslemini =auslemini  (SgG  >auslemin !19_S	et	f	\N
183280	auslemini	?auslemini =auslemini  (SgP  >auslemin !19_S	et	f	\N
183281	auslemini	?auslemini =auslemini  (SgAdt  >auslemin !19_S	et	f	\N
182807	poliituline	?poliituline =poliituline  (PlP  >poliitulin !19_S	et	f	\N
182809	poliituline	?poliituline =uline  (SgN  >poliit+uline !10_A	et	f	\N
182829	ümbertegema	?ümbertegema =ümbertegema  (SgG  >ümbertegem !02_A	et	f	\N
182830	ümbertegema	?ümbertegema =tegema  (SgG  >ümber+tegem !02_A	et	f	\N
182917	eksporti	eksporti =eksporti  (SgP  >eksport !22_S	et	f	\N
182918	eksporti	eksporti =eksporti  (SgAdt  >eksport !22_S	et	f	\N
182941	siuru	?siuru =siuru  (SgN  >siuru !16_S	et	f	\N
182942	siuru	?siuru =siuru  (SgG  >siuru !16_S	et	f	\N
182943	siuru	?siuru =siuru  (IndPrPs_  >siuruma !27_V	et	f	\N
182944	siuru	?siuru =siuru  (ImpPrSg2  >siuruma !27_V	et	f	\N
182956	daomineerib	?daomineerib =daomineeri  (IndPrSg3  >daomineerima !28_V	et	f	\N
182958	jannsenn	?jannsenn =jannsenn  (SgN  >jannsenn !22_S	et	f	\N
182966	a-	### 24021918a-	et	f	\N
182967	esim	?esim =esim  (SgN  >esim !02_A	et	f	\N
182981	relvastamine	relvastamine =relvastamine  (SgN  >relvastamine !12_S	et	f	\N
182982	relvastamine	"relvastamine %relvasta  )MINE_vS  <relvastama ;27_V	et	f	\N
182997	fosforiidi	fosforiidi =fosforiidi  (SgG  >fosforiit !22_S	et	f	\N
182998	fosforiidi	fosforiidi =iidi  (SgG  >fosfor+iid !22_S	et	f	\N
182999	fosforiidi	fosforiidi =iidi  (SgP  >fosfor+iid !22_S	et	f	\N
183000	fosforiidi	fosforiidi =iidi  (SgAdt  >fosfor+iid !22_S	et	f	\N
183003	parenemist	parenemist =parenemis  (SgP  >parenemine !12_S	et	f	\N
183004	parenemist	"parenemine %parene  )MINE_vS  <parenema ;27_V	et	f	\N
183009	rühmitusse	rühmitusse =rühmitu  (SgIll  >rühmitu !01_AS	et	f	\N
183010	rühmitusse	"rühmitu %rühmi  )TU2_kA  <rühm ;22_S	et	f	\N
183011	rühmitusse	rühmitusse =rühmitus  (SgAdt  >rühmitus !11_S	et	f	\N
183012	rühmitusse	"rühmitus %rühmita  )US_vS  <rühmitama ;27_V	et	f	\N
183013	rühmitusse	"rühmitus %rühmi  )TUS2_aS  <rühm ;22_S	et	f	\N
183014	passiivi	passiivi =passiivi  (SgG  >passiiv !22_S	et	f	\N
183015	passiivi	passiivi =passiivi  (SgP  >passiiv !22_S	et	f	\N
183016	passiivi	passiivi =passiivi  (SgAdt  >passiiv !22_S	et	f	\N
183023	kallilt	kallilt =kalli  (SgAbl  >kallis !05~07_A	et	f	\N
183024	kallilt	kallilt =kallilt  (ID  >kallilt !41_D	et	f	\N
183025	kallilt	"kallilt %kalli  )LT_mD  <kallis ;05_A	et	f	\N
183026	kallilt	"kallilt %kalli  )LT_mD  <kallis ;07_A	et	f	\N
183029	määrsõnad	### määrsõnad	et	f	\N
183038	ilusamini	ilusamini =ilusami  (SgTer  >ilusam !02_A	et	f	\N
183039	ilusamini	"ilusam %ilusa  )M_cA  <ilus ;02_A	et	f	\N
183085	tupa	?tupa =tupa  (SgN  >tupa !16_S	et	f	\N
183086	tupa	?tupa =tupa  (SgG  >tupa !16_S	et	f	\N
183087	tupa	?tupa =tupa  (IndPrPs_  >tupama !27_V	et	f	\N
183088	tupa	?tupa =tupa  (ImpPrSg2  >tupama !27_V	et	f	\N
183089	kurvasti	?kurvasti =kurvasti  (ID  >kurvasti !41_D	et	f	\N
183090	kurvasti	?kurvasti =kurvasti  (IndPrPs_  >kurvastima !28_V	et	f	\N
183091	kurvasti	?kurvasti =kurvasti  (ImpPrSg2  >kurvastima !28_V	et	f	\N
183117	südaöö	südaöö =öö  (SgN  >süda+öö !26_S	et	f	\N
183118	südaöö	südaöö =öö  (SgG  >süda+öö !26_S	et	f	\N
183119	tuletõrju	?tuletõrju =tuletõrju  (IndPrPs_  >tuletõrjuma !27_V	et	f	\N
183120	tuletõrju	?tuletõrju =tuletõrju  (ImpPrSg2  >tuletõrjuma !27_V	et	f	\N
183121	tuletõrju	?tuletõrju =tõrju  (SgN  >tule+tõrju !16_S	et	f	\N
183122	tuletõrju	?tuletõrju =tõrju  (SgG  >tule+tõrju !16_S	et	f	\N
183138	õigusest	õigusest =õiguse  (SgEl  >õigus !11~09_S	et	f	\N
183139	õigusest	"õigus %õige  )US_aS  <õige ;01_A	et	f	\N
183140	õigusest	õigusest =õiguses  (SgP  >õigusene !12_A	et	f	\N
183141	õigusest	"õigusene %õiguse  )NE_aA  <õigus ;09_S	et	f	\N
183142	õigusest	"õigusene %õiguse  )NE_aA  <õigus ;11_S	et	f	\N
183147	lendma	?lendma =lendma  (IndPrPs_  >lendmama !29_V	et	f	\N
183148	lendma	?lendma =lendma  (ImpPrSg2  >lendmama !29_V	et	f	\N
183154	vr	### vr	et	f	\N
183155	söödi	söödi =söö  (IndIpfIps  >sööma !38_V	et	f	\N
183156	söödi	söödi =söödi  (SgG  >sööt !22_S	et	f	\N
183184	tulnukas	tulnukas =tulnuka  (SgIn  >tulnuk !02_S	et	f	\N
183185	tulnukas	tulnukas =tulnuka  (SgIn  >tulnukas !02_S	et	f	\N
183186	tulnukas	tulnukas =tulnukas  (SgN  >tulnukas !02_S	et	f	\N
183204	võistlusest	võistlusest =võistluse  (SgEl  >võistlus !11~09_S	et	f	\N
183205	võistlusest	võistlusest =võistluses  (SgP  >võistlusene !12_A	et	f	\N
183206	võistlusest	"võistlusene %võistluse  )NE_aA  <võistlus ;09_S	et	f	\N
183207	võistlusest	"võistlusene %võistluse  )NE_aA  <võistlus ;11_S	et	f	\N
183211	laululine	laululine =laululine  (SgN  >laululine !12_A	et	f	\N
183212	laululine	"laululine %laulu  )LINE_aA  <laul ;22_S	et	f	\N
183219	lg	### lg	et	f	\N
183236	olatakse	?olatakse =ola  (IndPrIps  >olama !27_V	et	f	\N
183237	olatakse	?olatakse =olatakse  (SgG  >olatakne !02_A	et	f	\N
183238	olatakse	?olatakse =olatakse  (PlP  >olataks !22_S	et	f	\N
183241	lenna	?lenna =lenna  (SgN  >lenna !16_S	et	f	\N
183242	lenna	?lenna =lenna  (SgG  >lenna !16_S	et	f	\N
183243	lenna	?lenna =lenna  (IndPrPs_  >lennama !29_V	et	f	\N
183244	lenna	?lenna =lenna  (ImpPrSg2  >lennama !29_V	et	f	\N
183248	võrran	?võrran =võrra  (IndPrSg1  >võrrama !29_V	et	f	\N
182816	tekstiili	tekstiili =tekstiili  (SgAdt  >tekstiil !22_S	et	f	\N
182824	20ndatel	?ndatel =ndate  (PlAd  >ndatt !22_S	et	f	\N
182825	20ndatel	?ndatel =ndatel  (SgN  >ndatel !02_S	et	f	\N
182826	englismaalt	?englismaalt =englismaa  (SgAbl  >englismaa !26_S	et	f	\N
182827	englismaalt	?englismaalt =englismaalt  (ID  >englismaalt !41_D	et	f	\N
182828	inim	?inim =inim  (SgN  >inim !02_A	et	f	\N
182838	artson	?artson =artson  (SgN  >artson !02_S	et	f	\N
182839	esindajatest	esindajatest =esindaja  (PlEl  >esindaja !01_S	et	f	\N
182840	esindajatest	"esindaja %esinda  )JA_vS  <esindama ;27_V	et	f	\N
182841	esindajatest	esindajatest =test  (SgN  >esindaja+test !22_S	et	f	\N
182842	tomus	?tomus =tomu  (SgIn  >tomu !17_S	et	f	\N
182843	tomus	?tomus =tomu  (IndIpfSg3  >tomuma !27_V	et	f	\N
182844	tomus	?tomus =tomus  (SgN  >tomus !09_S	et	f	\N
182867	pasunakoore	pasunakoore =koore  (SgG  >pasuna+koor !13_S	et	f	\N
182868	pasunakoore	pasunakoore =koore  (PlP  >pasuna+koor !22_S	et	f	\N
182869	väägveres	### väägveres	et	f	\N
182873	kaevandus-	kaevandus- =kaevandu  (IndIpfSg3  >kaevanduma !27_V	et	f	\N
182874	kaevandus-	kaevandus- =kaevandus  (SgN  >kaevandus !11_S	et	f	\N
182875	kaevandus-	"kaevandus %kaevanda  )US_vS  <kaevandama ;27_V	et	f	\N
182901	tööstusest	tööstusest =tööstuse  (SgEl  >tööstus !11~09_S	et	f	\N
182903	tööstusest	tööstusest =tööstuses  (SgP  >tööstusene !12_A	et	f	\N
182904	tööstusest	"tööstusene %tööstuse  )NE_aA  <tööstus ;09_S	et	f	\N
182905	tööstusest	"tööstusene %tööstuse  )NE_aA  <tööstus ;11_S	et	f	\N
182908	põhil	### põhil	et	f	\N
182919	väikeettevõttetele	?väikeettevõttetele =väikeettevõttete  (PlAll  >väikeettevõttett !22_S	et	f	\N
182920	väikeettevõttetele	?väikeettevõttetele =väikeettevõttetele  (IndPrPs_  >väikeettevõttetelema !36_V	et	f	\N
182921	väikeettevõttetele	?väikeettevõttetele =väikeettevõttetele  (ImpPrSg2  >väikeettevõttetelema !36_V	et	f	\N
182922	väikeettevõttetele	?väikeettevõttetele =võtte  (PlAll  >väike+ette+võtte !06_S	et	f	\N
182923	väikeettevõttetele	?väikeettevõttetele =võttete  (PlAll  >väike+ette+võttett !22_S	et	f	\N
182924	väikeettevõttetele	?väikeettevõttetele =ettevõttete  (PlAll  >väike+ettevõttett !22_S	et	f	\N
182925	väikeettevõttetele	?väikeettevõttetele =keettevõttete  (PlAll  >väi+keettevõttett !22_S	et	f	\N
182926	vabriigi	?vabriigi =vabriigi  (SgN  >vabriigi !16_S	et	f	\N
182927	vabriigi	?vabriigi =vabriigi  (SgG  >vabriigi !16_S	et	f	\N
182928	vabriigi	?vabriigi =vabriigi  (SgG  >vabriik !22_S	et	f	\N
182929	vabriigi	?vabriigi =vabriigi  (SgP  >vabriig !22_S	et	f	\N
182930	vabriigi	?vabriigi =vabriigi  (SgAdt  >vabriig !22_S	et	f	\N
182931	vabriigi	?vabriigi =vabriigi  (IndPrPs_  >vabriikima !28_V	et	f	\N
182932	vabriigi	?vabriigi =vabriigi  (ImpPrSg2  >vabriikima !28_V	et	f	\N
182933	vabriigi	?vabriigi =vabrii  (SgN^  >vabrii !26_S	et	f	\N
182934	vabriigi	?vabriigi =vabrii  (SgG^  >vabrii !26_S	et	f	\N
182950	rahvuslikult	rahvuslikult =rahvusliku  (SgAbl  >rahvuslik !25_A	et	f	\N
182951	rahvuslikult	rahvuslikult =rahvuslikult  (ID  >rahvuslikult !41_D	et	f	\N
182952	rahvuslikult	"rahvuslikult %rahvusliku  )LT_mD  <rahvuslik ;25_A	et	f	\N
182960	tudis	tudis =tudi  (SgIn  >tudi !17_S	et	f	\N
182961	tudis	tudis =tudi  (IndIpfSg3  >tudima !27_V	et	f	\N
182962	eneseteadvus	eneseteadvus =teadvus  (SgN  >enese+teadvus !11~09_S	et	f	\N
182963	eneseteadvus	"enese+teadvus %teadva  )US_aS  <enese+teadev ;02_A	et	f	\N
182970	ilmarine	?ilmarine =ilmarine  (SgN  >ilmarine !12_A	et	f	\N
182971	ilmarine	?ilmarine =ilmarine  (PlP  >ilmarin !19_S	et	f	\N
182972	ilmarine	?ilmarine =rine  (SgN  >ilma+rine !16_S	et	f	\N
182973	ilmarine	?ilmarine =rine  (SgG  >ilma+rine !16_S	et	f	\N
182974	ilmarine	?ilmarine =arine  (SgN  >ilm+arine !10_A	et	f	\N
182977	leiutati	leiutati =leiuta  (IndIpfIps  >leiutama !27_V	et	f	\N
182978	leiutati	leiutati =tati  (SgG  >leiu+tatt !22_S	et	f	\N
182995	parenesid	parenesid =parene  (IndIpfSg2  >parenema !27_V	et	f	\N
182996	parenesid	parenesid =parene  (IndIpfPl3  >parenema !27_V	et	f	\N
183005	suundumused	suundumused =suundumuse  (PlN  >suundumus !11_S	et	f	\N
183006	suundumused	"suundumus %suundu  )MUS_vS  <suunduma ;27_V	et	f	\N
183007	kodutütrerd	?kodutütrerd =kodutütrerd  (SgN  >kodutütrerd !22_S	et	f	\N
183008	kodutütrerd	?kodutütrerd =tütrerd  (SgN  >kodu+tütrerd !02_S	et	f	\N
183027	käita	käita =käita  (IndPrPs_  >käitama !27_V	et	f	\N
183028	käita	käita =käita  (ImpPrSg2  >käitama !27_V	et	f	\N
183030	kurvamalt	kurvamalt =kurvamalt  (ID  >kurvamalt !41_D	et	f	\N
183031	kurvamalt	"kurvamalt %kurva  )MALT_mD  <kurb ;22_A	et	f	\N
183032	julgemini	julgemini =julgemi  (SgTer  >julgem !02_A	et	f	\N
183033	julgemini	"julgem %julge  )M_cA  <julge ;01_A	et	f	\N
183034	julgemini	julgemini =mi  (SgTer  >julge+mi !26_S	et	f	\N
183035	julgemini	julgemini =mini  (SgN  >julge+mini !17~16_S	et	f	\N
183036	julgemini	julgemini =mini  (SgG  >julge+mini !17~16_S	et	f	\N
183037	julgemini	julgemini =mini  (SgP  >julge+mini !17_S	et	f	\N
183040	rõõmsamalt	rõõmsamalt =rõõmsama  (SgAbl  >rõõmsam !02_A	et	f	\N
183041	rõõmsamalt	"rõõmsam %rõõmsa  )M_cA  <rõõmus ;02_A	et	f	\N
183042	rõõmsamalt	rõõmsamalt =rõõmsamalt  (ID  >rõõmsamalt !41_D	et	f	\N
183043	rõõmsamalt	"rõõmsamalt %rõõmsa  )MALT_mD  <rõõmus ;02_A	et	f	\N
183021	käskitakse	?käskitakse =käskitakse  (PlP  >käskitaks !22_S	et	f	\N
183022	käskitakse	?käskitakse =itakse  (SgG  >käsk+itakne !02_A	et	f	\N
183048	vihaselt	vihaselt =vihase  (SgAbl  >vihane !10_A	et	f	\N
183049	vihaselt	"vihane %viha  )NE_aA  <viha ;17_SA	et	f	\N
183050	vihaselt	"vihane %viha  )NE_aA  <viht ;22_S	et	f	\N
183051	vihaselt	vihaselt =vihaselt  (ID  >vihaselt !41_D	et	f	\N
183052	vihaselt	"vihaselt %viha  )SELT_mD  <viha ;17_SA	et	f	\N
183053	vihaselt	"vihaselt %viha  )SELT_mD  <viht ;22_S	et	f	\N
183054	vihaselt	"vihaselt %vihase  )LT_mD  <vihane ;10_A	et	f	\N
183059	soojalt	soojalt =sooja  (SgAbl  >soe !24_AS	et	f	\N
183060	soojalt	soojalt =soojalt  (ID  >soojalt !41_D	et	f	\N
183061	soojalt	"soojalt %sooja  )LT_mD  <soe ;24_AS	et	f	\N
183073	prl	### prl	et	f	\N
183074	lhk	### lhk	et	f	\N
183094	rõõmsamini	rõõmsamini =rõõmsami  (SgTer  >rõõmsam !02_A	et	f	\N
183095	rõõmsamini	"rõõmsam %rõõmsa  )M_cA  <rõõmus ;02_A	et	f	\N
183096	rõõmsamini	rõõmsamini =mi  (SgTer  >rõõmsa+mi !26_S	et	f	\N
183097	rõõmsamini	rõõmsamini =mini  (SgN  >rõõmsa+mini !17~16_S	et	f	\N
183098	rõõmsamini	rõõmsamini =mini  (SgG  >rõõmsa+mini !17~16_S	et	f	\N
183099	rõõmsamini	rõõmsamini =mini  (SgP  >rõõmsa+mini !17_S	et	f	\N
183106	vihasemalt	vihasemalt =vihasema  (SgAbl  >vihasem !02_A	et	f	\N
183107	vihasemalt	"vihasem %viha  )SEM_cA  <viha ;17_SA	et	f	\N
183108	vihasemalt	"vihasem %viha  )SEM_cA  <viht ;22_S	et	f	\N
183109	vihasemalt	"vihasem %vihase  )M_cA  <vihane ;10_A	et	f	\N
183110	vihasemalt	vihasemalt =vihasemalt  (ID  >vihasemalt !41_D	et	f	\N
183111	vihasemalt	"vihasemalt %viha  )SEMALT_mD  <viha ;17_SA	et	f	\N
183112	vihasemalt	"vihasemalt %viha  )SEMALT_mD  <viht ;22_S	et	f	\N
183113	vihasemalt	"vihasemalt %vihase  )MALT_mD  <vihane ;10_A	et	f	\N
183114	kasvataja	kasvataja =kasvataja  (SgN  >kasvataja !01_S	et	f	\N
183115	kasvataja	"kasvataja %kasvata  )JA_vS  <kasvatama ;27_V	et	f	\N
183116	kasvataja	kasvataja =kasvataja  (SgG  >kasvataja !01_S	et	f	\N
183132	vanadus	vanadus =vanadus  (SgN  >vanadus !11_S	et	f	\N
183133	vanadus	"vanadus %vana  )US_aS  <vana ;17_AS	et	f	\N
183157	ilusamalt	ilusamalt =ilusama  (SgAbl  >ilusam !02_A	et	f	\N
183158	ilusamalt	"ilusam %ilusa  )M_cA  <ilus ;02_A	et	f	\N
183159	ilusamalt	ilusamalt =ilusamalt  (ID  >ilusamalt !41_D	et	f	\N
183160	ilusamalt	"ilusamalt %ilusa  )MALT_mD  <ilus ;02_A	et	f	\N
183194	õppimatus	õppimatus =õppimatu  (SgIn  >õppimatu !01_A	et	f	\N
183195	õppimatus	"õppimatu %õppi  )MATU_vA  <õppima ;28_V	et	f	\N
183196	õppimatus	õppimatus =õppimatus  (SgN  >õppimatus !11?09_S	et	f	\N
183197	õppimatus	"õppimatus %õppi  )MATUS_aS  <õppima ;28_V	et	f	\N
183198	mõtetu	?mõtetu =mõtetu  (SgN  >mõtetu !01_A	et	f	\N
183199	mõtetu	?mõtetu =mõtetu  (SgG  >mõtetu !01_A	et	f	\N
183200	mõtetu	?mõtetu =mõtetu  (IndPrPs_  >mõtetuma !27_V	et	f	\N
183201	mõtetu	?mõtetu =mõtetu  (ImpPrSg2  >mõtetuma !27_V	et	f	\N
183202	mõttekas	mõttekas =mõtteka  (SgIn  >mõttekas !02_A	et	f	\N
183203	mõttekas	mõttekas =mõttekas  (SgN  >mõttekas !02_A	et	f	\N
183221	tundatakse	?tundatakse =tunda  (IndPrIps  >tuntama !29_V	et	f	\N
183222	tundatakse	?tundatakse =tundatakse  (SgG  >tundatakne !02_A	et	f	\N
183223	tundatakse	?tundatakse =tundatakse  (PlP  >tundataks !22_S	et	f	\N
183228	võtatakse	?võtatakse =võta  (IndPrIps  >võtama !27_V	et	f	\N
183229	võtatakse	?võtatakse =võta  (IndPrIps  >võttama !29_V	et	f	\N
183230	võtatakse	?võtatakse =võtatakse  (SgG  >võtatakne !02_A	et	f	\N
183231	võtatakse	?võtatakse =võtatakse  (PlP  >võtataks !22_S	et	f	\N
183232	käsketakse	?käsketakse =käske  (IndPrIps  >käskema !27_V	et	f	\N
183233	käsketakse	?käsketakse =käsketakse  (SgG  >käsketakne !02_A	et	f	\N
183234	käsketakse	?käsketakse =käsketakse  (PlP  >käsketaks !22_S	et	f	\N
183235	käsketakse	?käsketakse =etakse  (SgG  >käsk+etakne !02_A	et	f	\N
183271	ausesti	?ausesti =ausesti  (ID  >ausesti !41_D	et	f	\N
183272	ausesti	?ausesti =ausesti  (IndPrPs_  >ausestima !28_V	et	f	\N
183273	ausesti	?ausesti =ausesti  (ImpPrSg2  >ausestima !28_V	et	f	\N
183275	ausesti	?ausesti =sesti  (SgN  >au+sesti !16_S	et	f	\N
183277	ausesti	?ausesti =sesti  (SgG  >au+sesti !16_S	et	f	\N
183286	vihamini	vihamini =mi  (SgTer  >viha+mi !26_S	et	f	\N
183288	vihamini	vihamini =mini  (SgN  >viha+mini !17~16_S	et	f	\N
183289	vihamini	vihamini =mini  (SgG  >viha+mini !17~16_S	et	f	\N
183291	vihamini	vihamini =mini  (SgP  >viha+mini !17_S	et	f	\N
183299	juttut	?juttut =juttut  (SgN  >juttut !02_S	et	f	\N
183302	õigususse	õigususse =usse  (PlP  >õigus+uss !22_S	et	f	\N
183303	õigususse	õigususse =susse  (PlP  >õigu+suss !22_S	et	f	\N
183314	kuku	kuku =kuku  (ID  >kuku !41_I	et	f	\N
183315	kuku	kuku =kuku  (SgN  >kuku !16_A	et	f	\N
183316	kuku	kuku =kuku  (SgG  >kuku !16_A	et	f	\N
183317	kuku	kuku =kuku  (IndPrPs_  >kukkuma !28_V	et	f	\N
183318	kuku	kuku =kuku  (ImpPrSg2  >kukkuma !28_V	et	f	\N
183319	sojemalt	?sojemalt =sojema  (SgAbl  >sojem !02_A	et	f	\N
183320	sojemalt	?sojemalt =sojemalt  (ID  >sojemalt !41_D	et	f	\N
183321	polleldi	?polleldi =pollel  (IndIpfIps  >poldlema !30_V	et	f	\N
183055	vihasemini	vihasemini =vihasemi  (SgTer  >vihasem !02_A	et	f	\N
183056	vihasemini	"vihasem %viha  )SEM_cA  <viha ;17_SA	et	f	\N
183057	vihasemini	"vihasem %viha  )SEM_cA  <viht ;22_S	et	f	\N
183058	vihasemini	"vihasem %vihase  )M_cA  <vihane ;10_A	et	f	\N
183063	naera	naera =naera  (IndPrPs_  >naerma !33_V	et	f	\N
183064	naera	naera =naera  (ImpPrSg2  >naerma !33_V	et	f	\N
183069	lühenda	lühenda =lühenda  (IndPrPs_  >lühendama !27_V	et	f	\N
183070	lühenda	lühenda =lühenda  (ImpPrSg2  >lühendama !27_V	et	f	\N
183071	preili	preili =preili  (SgN  >preili !16_S	et	f	\N
183072	preili	preili =preili  (SgG  >preili !16_S	et	f	\N
183123	tuletamine	tuletamine =tuletamine  (SgN  >tuletamine !12_S	et	f	\N
183124	tuletamine	"tuletamine %tuleta  )MINE_vS  <tuletama ;27_V	et	f	\N
183143	sööti	sööti =sööti  (ID  >sööti !41_D	et	f	\N
183144	sööti	sööti =sööti  (SgP  >sööt !22_S	et	f	\N
183145	sööti	sööti =sööti  (SgAdt  >sööt !22_S	et	f	\N
183146	sööti	sööti =sööti  (PlP  >sööt !22_S	et	f	\N
183149	elamus	elamus =elamu  (SgIn  >elamu !01_S	et	f	\N
183150	elamus	elamus =elamus  (SgN  >elamus !11_S	et	f	\N
183165	kasvaja	kasvaja =kasvaja  (SgN  >kasvaja !01_S	et	f	\N
183166	kasvaja	"kasvaja %kasva  )JA_vS  <kasvama ;28_V	et	f	\N
183167	kasvaja	kasvaja =kasvaja  (SgG  >kasvaja !01_S	et	f	\N
183168	kasvaja	kasvaja =vaja  (SgN  >kas+vaja !17_S	et	f	\N
183169	kasvaja	kasvaja =vaja  (SgG  >kas+vaja !17_S	et	f	\N
183170	kasvaja	kasvaja =vaja  (SgP  >kas+vaja !17_S	et	f	\N
183171	südametu	südametu =südametu  (SgN  >südametu !01_A	et	f	\N
183172	südametu	"südametu %südame  )TU2_kA  <süda ;04_S	et	f	\N
183173	südametu	südametu =südametu  (SgG  >südametu !01_A	et	f	\N
183174	südametus	südametus =südametu  (SgIn  >südametu !01_A	et	f	\N
183175	südametus	"südametu %südame  )TU2_kA  <süda ;04_S	et	f	\N
183176	südametus	südametus =südametus  (SgN  >südametus !11?09_S	et	f	\N
183177	südametus	"südametus %südame  )TUS2_aS  <süda ;04_S	et	f	\N
183187	lugematus	lugematus =lugematu  (SgIn  >lugematu !01_A	et	f	\N
183188	lugematus	"lugematu %luge  )MATU_vA  <lugema ;28_V	et	f	\N
183189	lugematus	"lugematu %lugema  )TU2_kA  <lugem ;02_S	et	f	\N
183190	lugematus	lugematus =lugematus  (SgN  >lugematus !11?09_S	et	f	\N
183191	lugematus	"lugematus %luge  )MATUS_aS  <lugema ;28_V	et	f	\N
183192	lugematus	"lugematus %lugema  )TUS2_aS  <lugem ;02_S	et	f	\N
183208	kasvav	kasvav =kasva  (PtsPrPs  >kasvama !28_V	et	f	\N
183209	kasvav	kasvav =kasvav  (SgN  >kasvav !02_A	et	f	\N
183210	kasvav	"kasvav %kasva  )V_vA  <kasvama ;28_V	et	f	\N
183213	lugemistu	?lugemistu =lugemistu  (IndPrPs_  >lugemistuma !27_V	et	f	\N
183214	lugemistu	?lugemistu =lugemistu  (ImpPrSg2  >lugemistuma !27_V	et	f	\N
183215	õppik	?õppik =õppik  (SgN  >õppik !02_S	et	f	\N
183218	pre	### pre	et	f	\N
183220	hrr	### hrr	et	f	\N
183250	leheda	?leheda =lehe  (Inf  >lehema !27_V	et	f	\N
183251	kurbesti	?kurbesti =kurbesti  (ID  >kurbesti !41_D	et	f	\N
183252	kurbesti	?kurbesti =kurbesti  (IndPrPs_  >kurbestima !28_V	et	f	\N
183253	kurbesti	?kurbesti =kurbesti  (ImpPrSg2  >kurbestima !28_V	et	f	\N
183255	kurbesti	?kurbesti =esti  (SgN  >kurb+esti !16_S	et	f	\N
183257	kurbesti	?kurbesti =esti  (SgG  >kurb+esti !16_S	et	f	\N
183259	kurbesti	?kurbesti =esti  (SgG  >kurb+est !22_S	et	f	\N
183261	kurbesti	?kurbesti =esti  (SgP  >kurb+est !22_S	et	f	\N
183263	kurbesti	?kurbesti =esti  (SgAdt  >kurb+est !22_S	et	f	\N
183296	südamine	?südamine =südamine  (SgN  >südamine !12_S	et	f	\N
183297	südamine	?südamine =südamine  (PlP  >südamin !19_S	et	f	\N
183310	võrrata	?võrrata =võrra  (Inf  >võrdama !29_V	et	f	\N
183311	võrrata	?võrrata =võrra  (IndPrIps_  >võrdama !29_V	et	f	\N
183312	võrrata	?võrrata =võrrata  (IndPrPs_  >võrratama !27_V	et	f	\N
183313	võrrata	?võrrata =võrrata  (ImpPrSg2  >võrratama !27_V	et	f	\N
183338	südanik	?südanik =südanik  (SgN  >südanik !25_S	et	f	\N
183355	vta	### vta	et	f	\N
183363	võrrlema	?võrrlema =võrrle  (Sup  >võrrlema !30_V	et	f	\N
183364	võrrlema	?võrrlema =võrrlema  (SgG  >võrrlem !02_A	et	f	\N
183365	kukuta	kukuta =kuku  (SgAb  >kuku !16_A	et	f	\N
183366	kukuta	kukuta =kuku  (IndPrIps_  >kukkuma !28_V	et	f	\N
183367	kukuta	kukuta =kukuta  (IndPrPs_  >kukutama !27_V	et	f	\N
183368	kukuta	kukuta =kukuta  (ImpPrSg2  >kukutama !27_V	et	f	\N
183411	peegeldamine	peegeldamine =peegeldamine  (SgN  >peegeldamine !12_S	et	f	\N
183412	peegeldamine	"peegeldamine %peegelda  )MINE_vS  <peegeldama ;27_V	et	f	\N
183413	pimedalt	pimedalt =pimeda  (SgAbl  >pime !02_AS	et	f	\N
183414	pimedalt	pimedalt =pimedalt  (ID  >pimedalt !41_D	et	f	\N
183415	pimedalt	"pimedalt %pimeda  )LT_mD  <pime ;02_AS	et	f	\N
183427	relva	relva =relva  (SgG  >relv !22_S	et	f	\N
183428	relva	relva =relva  (SgP  >relv !22_S	et	f	\N
183429	relva	relva =relva  (SgAdt  >relv !22_S	et	f	\N
183442	karjakesi	karjakesi =karjakesi  (PlP  >karjake !12_S	et	f	\N
183443	karjakesi	"karjake %karja  )KE_dS  <kari ;24_S	et	f	\N
183444	karjakesi	karjakesi =karjakesi  (PlP  >karjakene !12_S	et	f	\N
183081	söödud	söödud =söödu  (PlN  >sööt !22_S	et	f	\N
183082	söödud	söödud =söödud  (ID  >söödud !41_A	et	f	\N
183083	söödud	"söödud %söö  )TUD_vA  <sööma ;38_V	et	f	\N
183092	kurvemini	kurvemini =kurvemi  (SgTer  >kurvem !02_A	et	f	\N
183093	kurvemini	"kurvem %kurve  )M_cA  <kurb ;22_A	et	f	\N
183100	ausamini	ausamini =ausami  (SgTer  >ausam !02_A	et	f	\N
183101	ausamini	"ausam %ausa  )M_cA  <aus ;02_A	et	f	\N
183102	ausamini	ausamini =mi  (SgTer  >ausa+mi !26_S	et	f	\N
183103	ausamini	ausamini =mini  (SgN  >ausa+mini !17~16_S	et	f	\N
183104	ausamini	ausamini =mini  (SgG  >ausa+mini !17~16_S	et	f	\N
183105	ausamini	ausamini =mini  (SgP  >ausa+mini !17_S	et	f	\N
183128	suvitaja	suvitaja =suvitaja  (SgN  >suvitaja !01_S	et	f	\N
183129	suvitaja	"suvitaja %suvita  )JA_vS  <suvitama ;27_V	et	f	\N
183130	suvitaja	suvitaja =suvitaja  (SgG  >suvitaja !01_S	et	f	\N
183135	õnnetustele	õnnetustele =õnnetus  (PlAll  >õnnetus !11_S	et	f	\N
183136	õnnetustele	"õnnetus %õnne  )TUS2_aS  <õnn ;22_S	et	f	\N
183137	õnnetustele	õnnetustele =tuste  (PlAll  >õnne+tust !22_S	et	f	\N
183151	suvemaja	suvemaja =maja  (SgN  >suve+maja !17_S	et	f	\N
183152	suvemaja	suvemaja =maja  (SgG  >suve+maja !17_S	et	f	\N
183153	suvemaja	suvemaja =maja  (SgP  >suve+maja !17_S	et	f	\N
183178	tulija	tulija =tulija  (SgN  >tulija !01_S	et	f	\N
183179	tulija	"tulija %tuli  )JA_vS  <tulema ;36_V	et	f	\N
183180	tulija	tulija =tulija  (SgG  >tulija !01_S	et	f	\N
183193	õpilas	?õpilas =õpila  (SgIn  >õpila !01_S	et	f	\N
183284	vihanem	?vihanem =vihanem  (SgN  >vihanem !02_A	et	f	\N
183300	õnnetusele	õnnetusele =õnnetuse  (SgAll  >õnnetus !11_S	et	f	\N
183301	õnnetusele	"õnnetus %õnne  )TUS2_aS  <õnn ;22_S	et	f	\N
183304	jääti	?jääti =jääti  (ID  >jääti !41_D	et	f	\N
183305	jääti	?jääti =jääti  (SgP  >jäät !22_S	et	f	\N
183306	jääti	?jääti =jääti  (SgAdt  >jäät !22_S	et	f	\N
183307	võdetakse	?võdetakse =võde  (IndPrIps  >võdema !27_V	et	f	\N
183308	võdetakse	?võdetakse =võdetakse  (SgG  >võdetakne !02_A	et	f	\N
183309	võdetakse	?võdetakse =võdetakse  (PlP  >võdetaks !22_S	et	f	\N
183327	kasvatud	kasvatud =kasva  (PtsPtIps  >kasvama !28_V	et	f	\N
183328	kasvatud	kasvatud =kasvatu  (PlN  >kasvatu !01_AS	et	f	\N
183329	kasvatud	"kasvatu %kasva  )TU1_vS  <kasvama ;28_V	et	f	\N
183330	kasvatud	kasvatud =kasvatud  (ID  >kasvatud !41_A	et	f	\N
183332	kasvatud	"kasvatud %kasva  )TUD_vA  <kasvama ;28_V	et	f	\N
183362	võeldakse	?võeldakse =võeldakse  (SgG  >võeldakne !02_A	et	f	\N
183386	hindavad	hindavad =hinda  (IndPrPl3  >hindama !29_V	et	f	\N
183387	hindavad	hindavad =hindava  (PlN  >hindav !02_A	et	f	\N
183388	hindavad	"hindav %hinda  )V_vA  <hindama ;29_V	et	f	\N
183389	hindavad	hindavad =ava  (PlN  >hind+ava !17_S	et	f	\N
183393	kinoelamust	kinoelamust =elamu  (SgEl  >kino+elamu !01_S	et	f	\N
183394	kinoelamust	kinoelamust =elamus  (SgP  >kino+elamus !11_S	et	f	\N
183395	vaieldamatult	vaieldamatult =vaieldamatu  (SgAbl  >vaieldamatu !01_A	et	f	\N
183396	vaieldamatult	"vaieldamatu %vaiel  )TAMATU_vA  <vaidlema ;30_V	et	f	\N
183397	vaieldamatult	vaieldamatult =vaieldamatult  (ID  >vaieldamatult !41_D	et	f	\N
183398	vaieldamatult	"vaieldamatult %vaiel  )TAMATULT_mD  <vaidlema ;30_V	et	f	\N
183399	vaieldamatult	"vaieldamatult %vaieldamatu  )LT_mD  <vaieldamatu ;01_A	et	f	\N
183400	tõstetud	tõstetud =tõste  (PtsPtIps  >tõstma !34_V	et	f	\N
183401	tõstetud	tõstetud =tõstetu  (PlN  >tõstetu !01_AS	et	f	\N
183402	tõstetud	"tõstetu %tõste  )TU1_vS  <tõstma ;34_V	et	f	\N
183403	tõstetud	"tõstetu %tõste  )TU2_kA  <tõste ;06_S	et	f	\N
183404	tõstetud	tõstetud =tõstetud  (ID  >tõstetud !41_A	et	f	\N
183406	tõstetud	"tõstetud %tõste  )TUD_vA  <tõstma ;34_V	et	f	\N
183408	tallata	tallata =talla  (SgAb  >tald !22_S	et	f	\N
183409	tallata	tallata =talla  (Inf  >tallama !29_V	et	f	\N
183410	tallata	tallata =talla  (IndPrIps_  >tallama !29_V	et	f	\N
183434	halvustavale	halvustavale =halvustava  (SgAll  >halvustav !02_A	et	f	\N
183435	halvustavale	"halvustav %halvusta  )V_vA  <halvustama ;27_V	et	f	\N
183438	mõnitamisele	mõnitamisele =mõnitamise  (SgAll  >mõnitamine !12_S	et	f	\N
183439	mõnitamisele	"mõnitamine %mõnita  )MINE_vS  <mõnitama ;27_V	et	f	\N
183456	mõttevabadus	mõttevabadus =vabadus  (SgN  >mõtte+vabadus !11_S	et	f	\N
183457	mõttevabadus	"mõtte+vabadus %vaba  )US_aS  <mõtte+vaba ;17_A	et	f	\N
183460	läbipõimunud	läbipõimunud =põimu  (PtsPtPs  >läbi+_põimuma !27_V	et	f	\N
183461	läbipõimunud	läbipõimunud =põimunu  (PlN  >läbi+põimunu !01_S	et	f	\N
183462	kokkusaamised	kokkusaamised =saamise  (PlN  >kokku+saamine !12?10_S	et	f	\N
183463	kokkusaamised	"kokku+saamine %saami  )NE_aA  <kokku+saam ;22_S	et	f	\N
183464	keerulisele	keerulisele =keerulise  (SgAll  >keeruline !12_A	et	f	\N
183465	keerulisele	"keeruline %keeru  )LINE_aA  <keerd ;22_SA	et	f	\N
183470	kohtumisel	kohtumisel =kohtumise  (SgAd  >kohtumine !12_S	et	f	\N
183471	kohtumisel	"kohtumine %kohtu  )MINE_vS  <kohtuma ;27_V	et	f	\N
183505	humorikate	?humorikate =humorika  (PlG  >humorika !01_S	et	f	\N
183506	humorikate	?humorikate =humorika  (PlG  >humorikas !02_A	et	f	\N
183509	kambavaimu	kambavaimu =vaimu  (SgG  >kamba+vaim !22_S	et	f	\N
183249	võrran	?võrran =võrran  (SgN  >võrran !02_S	et	f	\N
183254	kurbemini	?kurbemini =kurbemi  (SgTer  >kurbemi !01_S	et	f	\N
183256	kurbemini	?kurbemini =kurbemi  (SgTer  >kurbem !02_A	et	f	\N
183258	kurbemini	?kurbemini =kurbemini  (ID  >kurbemini !41_D	et	f	\N
183260	kurbemini	?kurbemini =kurbemini  (SgG  >kurbemin !19_S	et	f	\N
183262	kurbemini	?kurbemini =kurbemini  (SgP  >kurbemin !19_S	et	f	\N
183264	kurbemini	?kurbemini =kurbemini  (SgAdt  >kurbemin !19_S	et	f	\N
183265	kurbemini	?kurbemini =emi  (SgTer  >kurb+emi !17_S	et	f	\N
183266	kurbemini	?kurbemini =emini  (SgG  >kurb+emin !02_S	et	f	\N
183269	rõõmusamalt	?rõõmusamalt =rõõmusama  (SgAbl  >rõõmusam !02_A	et	f	\N
183270	rõõmusamalt	?rõõmusamalt =rõõmusamalt  (ID  >rõõmusamalt !41_D	et	f	\N
183292	laulia	?laulia =laulia  (SgN  >laulia !01_S	et	f	\N
183293	laulia	?laulia =laulia  (SgG  >laulia !01_S	et	f	\N
183294	laulia	?laulia =lia  (SgN  >lau+lia !26_S	et	f	\N
183295	laulia	?laulia =lia  (SgG  >lau+lia !26_S	et	f	\N
183339	südamees	südamees =mee  (SgIn  >süda+mesi !15_S	et	f	\N
183340	südamees	südamees =mees  (SgN  >süda+mees !13_S	et	f	\N
183341	mõtekas	?mõtekas =mõteka  (SgIn  >mõteka !01_S	et	f	\N
183342	mõtekas	?mõtekas =mõteka  (SgIn  >mõtekas !02_A	et	f	\N
183343	mõtekas	?mõtekas =mõtekas  (SgN  >mõtekas !02_A	et	f	\N
183347	õigsusest	õigsusest =õigsuse  (SgEl  >õigsus !11~09_S	et	f	\N
183348	õigsusest	õigsusest =õigsuses  (SgP  >õigsusene !12_A	et	f	\N
183349	õigsusest	"õigsusene %õigsuse  )NE_aA  <õigsus ;09_S	et	f	\N
183350	õigsusest	"õigsusene %õigsuse  )NE_aA  <õigsus ;11_S	et	f	\N
183361	jättakse	?jättakse =jättakse  (SgG  >jättakne !02_A	et	f	\N
183373	sojamalt	?sojamalt =sojama  (SgAbl  >sojam !02_A	et	f	\N
183374	sojamalt	?sojamalt =sojamalt  (ID  >sojamalt !41_D	et	f	\N
183375	sojamalt	?sojamalt =malt  (SgN  >soja+malt !22_S	et	f	\N
183405	esindasid	esindasid =esinda  (IndIpfSg2  >esindama !27_V	et	f	\N
183407	esindasid	esindasid =esinda  (IndIpfPl3  >esindama !27_V	et	f	\N
183421	kired	kired =kire  (PlN  >kirg !22_S	et	f	\N
183422	kired	kired =kire  (IndPrSg2  >kirema !27_V	et	f	\N
183423	kuuldagi	kuuldagi =kuul  (Inf^  >kuulma !33_V	et	f	\N
183424	kuuldagi	kuuldagi =kuul  (IndPrIps_^  >kuulma !33_V	et	f	\N
183436	pilgule	pilgule =pilgu  (SgAll  >pilk !22_S	et	f	\N
183437	pilgule	pilgule =pilgu  (PlAll  >pilk !22_S	et	f	\N
183440	reaalsem	reaalsem =reaalsem  (SgN  >reaalsem !02_A	et	f	\N
183441	reaalsem	"reaalsem %reaalse  )M_cA  <reaalne ;02_A	et	f	\N
183446	tõsielulise	tõsielulise =elulise  (SgG  >tõsi+eluline !12_A	et	f	\N
183447	tõsielulise	"tõsi+eluline %elu  )LINE_aA  <tõsi+elu ;17_S	et	f	\N
183451	erapooletult	erapooletult =erapooletu  (SgAbl  >erapooletu !01_A	et	f	\N
183452	erapooletult	erapooletult =erapooletult  (ID  >erapooletult !41_D	et	f	\N
183453	erapooletult	"erapooletult %erapooletu  )LT_mD  <erapooletu ;01_A	et	f	\N
183454	erapooletult	erapooletult =pooletu  (SgAbl  >era+pooletu !01_A	et	f	\N
183455	erapooletult	"era+pooletult %pooletu  )LT_mD  <era+pooletu ;01_A	et	f	\N
183492	taandunud	taandunud =taandu  (PtsPtPs  >taanduma !27_V	et	f	\N
183494	taandunud	taandunud =taandunu  (PlN  >taandunu !01_S	et	f	\N
183496	taandunud	"taandunu %taandu  )NU_vS  <taanduma ;27_V	et	f	\N
183498	taandunud	taandunud =taandunud  (ID  >taandunud !41_A	et	f	\N
183499	taandunud	"taandunud %taandu  )NUD_vA  <taanduma ;27_V	et	f	\N
183500	kaaslaste	kaaslaste =kaaslas  (PlG  >kaaslane !12?10_S	et	f	\N
183502	kaaslaste	kaaslaste =las  (PlG  >kaas+laps !14_S	et	f	\N
183504	kaaslaste	kaaslaste =laste  (PlP  >kaas+last !22_S	et	f	\N
183507	tögamisega	tögamisega =tögamise  (SgKom  >tögamine !12_S	et	f	\N
183508	tögamisega	"tögamine %töga  )MINE_vS  <tögama ;27_V	et	f	\N
183513	kainelt	kainelt =kaine  (SgAbl  >kaine !01_A	et	f	\N
183514	kainelt	"kaine %kai  )NE_aA  <kai ;26_S	et	f	\N
183515	kainelt	kainelt =kaine  (SgAbl  >kaine !06_A	et	f	\N
183516	kainelt	kainelt =kaine  (PlAbl  >kain !22_S	et	f	\N
183517	kainelt	kainelt =kainelt  (ID  >kainelt !41_D	et	f	\N
183518	kainelt	"kainelt %kaine  )LT_mD  <kaine ;01_A	et	f	\N
183519	kainelt	"kainelt %kaine  )LT_mD  <kaine ;06_A	et	f	\N
183579	seletamatu	seletamatu =seletamatu  (SgN  >seletamatu !01_A	et	f	\N
183580	seletamatu	"seletamatu %seleta  )MATU_vA  <seletama ;27_V	et	f	\N
183581	seletamatu	seletamatu =seletamatu  (SgG  >seletamatu !01_A	et	f	\N
183590	südamevalu	südamevalu =valu  (SgN  >südame+valu !17_S	et	f	\N
183591	südamevalu	südamevalu =valu  (SgG  >südame+valu !17_S	et	f	\N
183592	südamevalu	südamevalu =valu  (SgP  >südame+valu !17_S	et	f	\N
183595	sümpaatia	sümpaatia =sümpaatia  (SgN  >sümpaatia !01_S	et	f	\N
183596	sümpaatia	sümpaatia =sümpaatia  (SgG  >sümpaatia !01_S	et	f	\N
183597	kadumise	kadumise =kadumise  (SgG  >kadumine !12_S	et	f	\N
183598	kadumise	"kadumine %kadu  )MINE_vS  <kaduma ;28_V	et	f	\N
183599	kadumise	"kadumine %kadumi  )NE_aA  <kadum ;02_S	et	f	\N
183613	leppimata	leppimata =leppi  (SupAb  >leppima !28_V	et	f	\N
183614	leppimata	leppimata =leppimata  (ID  >leppimata !41_A	et	f	\N
183615	leppimata	"leppimata %leppi  )MATA_vA  <leppima ;28_V	et	f	\N
183621	tätte	?tätte =tätte  (SgN  >tätte !06_S	et	f	\N
183282	auslemini	?auslemini =slemi  (SgTer  >au+slemi !17_S	et	f	\N
183283	auslemini	?auslemini =slemini  (SgG  >au+slemin !02_S	et	f	\N
183285	soemini	?soemini =soemi  (SgTer  >soemi !16_S	et	f	\N
183287	soemini	?soemini =soemi  (SgTer  >soem !22_S	et	f	\N
183290	soemini	?soemini =soemini  (SgG  >soemin !02_S	et	f	\N
183298	lutevik	?lutevik =lutevik  (SgN  >lutevik !25_S	et	f	\N
183344	õnnestusedest	?õnnestusedest =õnnestusedes  (SgP  >õnnestusedene !12_A	et	f	\N
183345	õnnestusedest	?õnnestusedest =stuse  (PlEl  >õnne+stuse !16_S	et	f	\N
183346	õnnestusedest	?õnnestusedest =stusedes  (SgP  >õnne+stusedene !12_A	et	f	\N
183356	võrd	?võrd =võrd  (SgN  >võrd !22_S	et	f	\N
183359	pril	### pril	et	f	\N
183378	inimväärikuse	inimväärikuse =väärikuse  (SgG  >inim+väärikus !11_S	et	f	\N
183379	inimväärikuse	"inim+väärikus %väärika  )US_aS  <inim+väärikas ;02_A	et	f	\N
183416	tegelaskuju	tegelaskuju =kuju  (SgN  >tegelas+kuju !17_S	et	f	\N
183417	tegelaskuju	tegelaskuju =kuju  (SgG  >tegelas+kuju !17_S	et	f	\N
183418	tegelaskuju	tegelaskuju =kuju  (SgP  >tegelas+kuju !17_S	et	f	\N
183419	koolimajas	koolimajas =maja  (SgIn  >kooli+maja !17_S	et	f	\N
183420	koolimajas	koolimajas =imaja  (SgIn  >kool+imaja !01_S	et	f	\N
183430	õpilastest	õpilastest =õpilas  (PlEl  >õpilane !12_S	et	f	\N
183431	õpilastest	õpilastest =test  (SgN  >õpilas+test !22_S	et	f	\N
183432	õpilastest	õpilastest =las  (PlEl  >õpi+laps !14_S	et	f	\N
183433	õpilastest	õpilastest =laste  (PlEl  >õpi+last !22_S	et	f	\N
183458	vahelistele	vahelistele =vahelis  (PlAll  >vaheline !12_A	et	f	\N
183459	vahelistele	"vaheline %vahe  )LINE_aA  <vahe ;16_S	et	f	\N
183468	meeldejäävamaks	meeldejäävamaks =jäävama  (SgTr  >meelde+jäävam !02_A	et	f	\N
183469	meeldejäävamaks	"meelde+jäävam %jääva  )M_cA  <meelde+jääv ;02_A	et	f	\N
183472	ohutusse	ohutusse =ohutu  (SgIll  >ohutu !01_A	et	f	\N
183473	ohutusse	"ohutu %ohu  )TU2_kA  <oht ;22_S	et	f	\N
183474	ohutusse	ohutusse =ohutus  (SgAdt  >ohutus !11_S	et	f	\N
183475	ohutusse	"ohutus %ohuta  )US_vS  <ohutama ;27_V	et	f	\N
183476	ohutusse	"ohutus %ohu  )TUS2_aS  <oht ;22_S	et	f	\N
183477	ohutusse	ohutusse =tusse  (PlP  >ohu+tuss !22_S	et	f	\N
183478	kaugusesse	kaugusesse =kauguse  (SgIll  >kaugus !11~09_S	et	f	\N
183479	kaugusesse	"kaugus %kauge  )US_aS  <kauge ;01_A	et	f	\N
183480	kaugusesse	kaugusesse =kauguse  (SgIll  >kaugune !10~12_A	et	f	\N
183481	kaugusesse	kaugusesse =kauguses  (SgAdt  >kaugusene !12_A	et	f	\N
183482	kaugusesse	"kaugusene %kauguse  )NE_aA  <kaugus ;09_S	et	f	\N
183483	kaugusesse	"kaugusene %kauguse  )NE_aA  <kaugus ;11_S	et	f	\N
183484	kaugusesse	kaugusesse =use  (PlIll  >kaug+usk !22_S	et	f	\N
183520	tegutse	tegutse =tegutse  (IndPrPs_  >tegutsema !27_V	et	f	\N
183521	tegutse	tegutse =tegutse  (ImpPrSg2  >tegutsema !27_V	et	f	\N
183529	kordumatuks	kordumatuks =kordumatu  (SgTr  >kordumatu !01_A	et	f	\N
183530	kordumatuks	"kordumatu %kordu  )MATU_vA  <korduma ;27_V	et	f	\N
183531	leiduks	leiduks =leidu  (KndPrPs  >leiduma !27_V	et	f	\N
183532	leiduks	leiduks =uks  (SgN  >leid+uks !14_S	et	f	\N
183542	esilinastunud	esilinastunud =linastu  (PtsPtPs  >esi+linastuma !27_V	et	f	\N
183543	esilinastunud	esilinastunud =linastunu  (PlN  >esi+linastunu !01_S	et	f	\N
183544	lavastajaks	lavastajaks =lavastaja  (SgTr  >lavastaja !01_S	et	f	\N
183545	lavastajaks	"lavastaja %lavasta  )JA_vS  <lavastama ;27_V	et	f	\N
183546	valmimust	valmimust =valmimus  (SgP  >valmimus !11_S	et	f	\N
183547	valmimust	"valmimus %valmi  )MUS_vS  <valmima ;27_V	et	f	\N
183548	väitest	väitest =väite  (SgEl  >väide !06_S	et	f	\N
183549	väitest	väitest =väites  (SgP  >väitene !12~10_A	et	f	\N
183550	väitest	"väitene %väite  )NE_aA  <väide ;06_S	et	f	\N
183551	väitest	väitest =test  (SgN  >väi+test !22_S	et	f	\N
183564	pingetest	pingetest =pinge  (PlEl  >pinge !06_S	et	f	\N
183565	pingetest	pingetest =test  (SgN  >pinge+test !22_S	et	f	\N
183566	pingetest	pingetest =e  (PlEl  >ping+esi !15_S	et	f	\N
183604	mõisahoovi	mõisahoovi =hoovi  (SgG  >mõisa+hoov !22_S	et	f	\N
183606	mõisahoovi	mõisahoovi =hoovi  (SgP  >mõisa+hoov !22_S	et	f	\N
183608	mõisahoovi	mõisahoovi =hoovi  (SgAdt  >mõisa+hoov !22_S	et	f	\N
183656	kodanlikku	kodanlikku =kodanlikku  (SgP  >kodanlik !25_A	et	f	\N
183657	kodanlikku	kodanlikku =kodanlikku  (SgAdt  >kodanlik !25_A	et	f	\N
183662	pealetungi	pealetungi =tungi  (SgG  >peale+tung !22_S	et	f	\N
183663	pealetungi	pealetungi =tungi  (SgP  >peale+tung !22_S	et	f	\N
183664	pealetungi	pealetungi =tungi  (SgAdt  >peale+tung !22_S	et	f	\N
183665	pealetungi	pealetungi =tungi  (PlP  >peale+tung !22_S	et	f	\N
183666	võimatuks	võimatuks =võimatu  (SgTr  >võimatu !01_A	et	f	\N
183667	võimatuks	"võimatu %või  )MATU_vA  <võima ;37_V	et	f	\N
183669	utoopilisust	?utoopilisust =utoopilisus  (SgP  >utoopilisus !11?09_S	et	f	\N
183675	valimist	valimist =valimis  (SgP  >valimine !12_S	et	f	\N
183676	valimist	"valimine %vali  )MINE_vS  <valima ;27_V	et	f	\N
183692	püstitamine	püstitamine =püstitamine  (SgN  >püstitamine !12_S	et	f	\N
183693	püstitamine	"püstitamine %püstita  )MINE_vS  <püstitama ;27_V	et	f	\N
183696	noorsugu	noorsugu =sugu  (SgN  >noor+sugu !18_S	et	f	\N
183697	noorsugu	noorsugu =sugu  (SgP  >noor+sugu !18_S	et	f	\N
183322	polleldi	?polleldi =polleldi  (SgN  >polleldi !01_S	et	f	\N
183323	polleldi	?polleldi =polleldi  (SgG  >polleldi !01_S	et	f	\N
183324	polleldi	?polleldi =polleldi  (SgG  >polleld !02_S	et	f	\N
183325	polleldi	?polleldi =polleldi  (IndPrPs_  >polleltima !28_V	et	f	\N
183326	polleldi	?polleldi =polleldi  (ImpPrSg2  >polleltima !28_V	et	f	\N
183331	laulutus	laulutus =laulutu  (SgIn  >laulutu !01_AS	et	f	\N
183333	laulutus	"laulutu %laulu  )TU2_kA  <laul ;22_S	et	f	\N
183334	laulutus	laulutus =laulutus  (SgN  >laulutus !11_S	et	f	\N
183335	laulutus	"laulutus %laulu  )TUS2_aS  <laul ;22_S	et	f	\N
183336	laulutus	laulutus =lutu  (SgIn  >lau+lutu !16_S	et	f	\N
183337	laulutus	laulutus =lutu  (SgIn  >lau+lutt !22_S	et	f	\N
183351	välismaalast	välismaalast =la  (SgEl  >välis+maa+la !26_S	et	f	\N
183352	välismaalast	välismaalast =las  (SgP  >välis+maa+laps !14_S	et	f	\N
183353	välismaalast	välismaalast =last  (SgN  >välis+maa+last !22_S	et	f	\N
183354	välismaalast	välismaalast =maalas  (SgP  >välis+maalane !12?10_S	et	f	\N
183357	prua	?prua =prua  (SgN  >prua !26_S	et	f	\N
183358	prua	?prua =prua  (SgG  >prua !26_S	et	f	\N
183360	här	### här	et	f	\N
183369	kurvamini	kurvamini =mi  (SgTer  >kurva+mi !26_S	et	f	\N
183370	kurvamini	kurvamini =mini  (SgN  >kurva+mini !17~16_S	et	f	\N
183371	kurvamini	kurvamini =mini  (SgG  >kurva+mini !17~16_S	et	f	\N
183372	kurvamini	kurvamini =mini  (SgP  >kurva+mini !17_S	et	f	\N
183376	sportisse	?sportisse =sportisse  (SgG  >sportisne !02_A	et	f	\N
183377	sportisse	?sportisse =sportisse  (PlP  >sportiss !22_S	et	f	\N
183380	mõõdupuuks	mõõdupuuks =puu  (SgTr  >mõõdu+puu !26_S	et	f	\N
183381	mõõdupuuks	mõõdupuuks =puuks  (SgN  >mõõdu+puuks !22_S	et	f	\N
183382	paljusi	paljusi =paljusi  (PlP  >paljus !11_S	et	f	\N
183383	paljusi	"paljus %palja  )US_aS  <paljas ;07_A	et	f	\N
183384	teenimise	teenimise =teenimise  (SgG  >teenimine !12_S	et	f	\N
183385	teenimise	"teenimine %teeni  )MINE_vS  <teenima ;28_V	et	f	\N
183390	tavapärast	tavapärast =pära  (SgEl  >tava+pära !17_S	et	f	\N
183391	tavapärast	tavapärast =päras  (SgP  >tava+pärane !10_A	et	f	\N
183392	tavapärast	"tava+pärane %pära  )NE_aA  <tava+pära ;17_S	et	f	\N
183425	veenmise	veenmise =veenmise  (SgG  >veenmine !12?10_S	et	f	\N
183426	veenmise	"veenmine %veen  )MINE_vS  <veenma ;33_V	et	f	\N
183448	inimlikult	inimlikult =inimliku  (SgAbl  >inimlik !25_A	et	f	\N
183449	inimlikult	inimlikult =inimlikult  (ID  >inimlikult !41_D	et	f	\N
183450	inimlikult	"inimlikult %inimliku  )LT_mD  <inimlik ;25_A	et	f	\N
183522	paljugi	paljugi =palju  (ID^  >palju !41_D	et	f	\N
183523	paljugi	paljugi =palju  (SgN^  >palju !16_P	et	f	\N
183524	paljugi	paljugi =palju  (SgG^  >palju !16_P	et	f	\N
183527	järelduseni	järelduseni =järelduse  (SgTer  >järeldus !11_S	et	f	\N
183528	järelduseni	"järeldus %järelda  )US_vS  <järeldama ;27_V	et	f	\N
183533	miljan	?miljan =milja  (IndPrSg1  >miljama !29_V	et	f	\N
183534	miljan	?miljan =miljan  (SgN  >miljan !02_S	et	f	\N
183535	stabiilsem	stabiilsem =stabiilsem  (SgN  >stabiilsem !02_A	et	f	\N
183536	stabiilsem	"stabiilsem %stabiilse  )M_cA  <stabiilne ;02_A	et	f	\N
183554	suurimpuudus	?suurimpuudus =suurimpuudu  (IndIpfSg3  >suurimpuuduma !27_V	et	f	\N
183555	suurimpuudus	?suurimpuudus =suurimpuudus  (SgN  >suurimpuudus !11~09_S	et	f	\N
183556	suurimpuudus	?suurimpuudus =impuudu  (SgIn  >suur+impuudu !01_S	et	f	\N
183557	suurimpuudus	?suurimpuudus =impuudus  (SgN  >suur+impuudus !11~09_S	et	f	\N
183558	suurimpuudus	?suurimpuudus =rimpuudu  (SgIn  >suu+rimpuudu !01_S	et	f	\N
183559	suurimpuudus	?suurimpuudus =rimpuudus  (SgN  >suu+rimpuudus !11~09_S	et	f	\N
183562	nendevahelistele	nendevahelistele =vahelis  (PlAll  >nende+vaheline !12_A	et	f	\N
183563	nendevahelistele	"nende+vaheline %vahe  )LINE_aA  <nende+vahe ;16_S	et	f	\N
183567	lõhestatusest	lõhestatusest =lõhestatuse  (SgEl  >lõhestatus !11?09_S	et	f	\N
183568	lõhestatusest	"lõhestatus %lõhesta  )TUS1_aS  <lõhestama ;27_V	et	f	\N
183569	lõhestatusest	lõhestatusest =lõhestatuses  (SgP  >lõhestatusene !12_A	et	f	\N
183570	lõhestatusest	"lõhestatusene %lõhestatuse  )NE_aA  <lõhestatus ;09_S	et	f	\N
183571	lõhestatusest	"lõhestatusene %lõhestatuse  )NE_aA  <lõhestatus ;11_S	et	f	\N
183603	ahast	ahast =aha  (SgEl  >ahk !22_S	et	f	\N
183605	ahast	ahast =ahas  (SgP  >ahas !07_A	et	f	\N
183607	ahast	ahast =ahas  (SgP  >ahane !10_A	et	f	\N
183609	ahast	"ahane %aha  )NE_aA  <ahk ;22_S	et	f	\N
183610	liigeldav	liigeldav =liigel  (PtsPrIps  >liiklema !30_V	et	f	\N
183611	liigeldav	liigeldav =liigeldav  (SgN  >liigeldav !02_A	et	f	\N
183612	liigeldav	"liigeldav %liigel  )TAV_vAS  <liiklema ;30_V	et	f	\N
183616	kehastanud	kehastanud =kehasta  (PtsPtPs  >kehastama !27_V	et	f	\N
183617	kehastanud	kehastanud =kehastanu  (PlN  >kehastanu !01_S	et	f	\N
183618	kehastanud	"kehastanu %kehasta  )NU_vS  <kehastama ;27_V	et	f	\N
183619	kehastanud	kehastanud =kehastanud  (ID  >kehastanud !41_A	et	f	\N
183620	kehastanud	"kehastanud %kehasta  )NUD_vA  <kehastama ;27_V	et	f	\N
183626	arusaadavamaks	arusaadavamaks =saadavama  (SgTr  >aru+saadavam !02_A	et	f	\N
183627	arusaadavamaks	"aru+saadavam %saadava  )M_cA  <aru+saadav ;02_A	et	f	\N
183634	kangelastena	kangelastena =kangelas  (PlEs  >kangelane !12_S	et	f	\N
183445	karjakesi	"karjakene %karja  )KENE_dS  <kari ;24_S	et	f	\N
183466	tühisematest	tühisematest =tühisema  (PlEl  >tühisem !02_A	et	f	\N
183467	tühisematest	"tühisem %tühise  )M_cA  <tühine ;10_A	et	f	\N
183485	mõtlematu	mõtlematu =mõtlematu  (SgN  >mõtlematu !01_A	et	f	\N
183486	mõtlematu	"mõtlematu %mõtle  )MATU_vA  <mõtlema ;30_V	et	f	\N
183487	mõtlematu	mõtlematu =mõtlematu  (SgG  >mõtlematu !01_A	et	f	\N
183488	kaalaste	?kaalaste =kaalas  (PlG  >kaalas !07_S	et	f	\N
183489	kaalaste	?kaalaste =kaalas  (PlG  >kaalane !12?10_S	et	f	\N
183490	omavahelistele	omavahelistele =vahelis  (PlAll  >oma+vaheline !12_A	et	f	\N
183491	omavahelistele	"oma+vaheline %vahe  )LINE_aA  <oma+vahe ;16_S	et	f	\N
183493	asendus	asendus =asendu  (IndIpfSg3  >asenduma !27_V	et	f	\N
183495	asendus	asendus =asendus  (SgN  >asendus !11_S	et	f	\N
183497	asendus	"asendus %asenda  )US_vS  <asendama ;27_V	et	f	\N
183501	süüdistamine	süüdistamine =süüdistamine  (SgN  >süüdistamine !12_S	et	f	\N
183503	süüdistamine	"süüdistamine %süüdista  )MINE_vS  <süüdistama ;27_V	et	f	\N
183525	kaasakiskuv	kaasakiskuv =kisku  (PtsPrPs  >kaasa+_kiskuma !28_V	et	f	\N
183526	kaasakiskuv	kaasakiskuv =kiskuv  (SgN  >kaasa+kiskuv !02_A	et	f	\N
183537	jääksid	jääksid =jää  (KndPrSg2  >jääma !37_V	et	f	\N
183538	jääksid	jääksid =jää  (KndPrPl3  >jääma !37_V	et	f	\N
183539	südametesse	südametesse =südame  (PlIll  >süda !04_S	et	f	\N
183540	südametesse	südametesse =me  (PlIll  >süda+mesi !15_S	et	f	\N
183541	südametesse	südametesse =mete  (PlIll  >süda+mett !22_S	et	f	\N
183552	tegureid	tegureid =tegure  (PlP  >tegur !02_S	et	f	\N
183553	tegureid	tegureid =reid  (SgN  >tegu+reid !22_S	et	f	\N
183560	osaliste	osaliste =osalis  (PlG  >osaline !12_SA	et	f	\N
183561	osaliste	"osaline %osa  )LINE_aA  <osa ;17_S	et	f	\N
183576	võigemasti	?võigemasti =võigemasti  (ID  >võigemasti !41_D	et	f	\N
183577	võigemasti	?võigemasti =võigemasti  (IndPrPs_  >võigemastima !28_V	et	f	\N
183578	võigemasti	?võigemasti =võigemasti  (ImpPrSg2  >võigemastima !28_V	et	f	\N
183589	kahekskistud	?kahekskistud =kahekskistu  (IndPrSg2  >kahekskistuma !27_V	et	f	\N
183636	lollusi	lollusi =lollusi  (PlP  >lollus !11_S	et	f	\N
183637	lollusi	"lollus %loll  )US_aS  <loll ;22_AS	et	f	\N
183639	ie	?ie =ie  (SgN  >ie !26_S	et	f	\N
183641	ie	?ie =ie  (SgG  >ie !26_S	et	f	\N
183647	käärmer	?käärmer =käärmer  (SgN  >käärmer !02_S	et	f	\N
183648	kapitalistlikust	kapitalistlikust =kapitalistliku  (SgEl  >kapitalistlik !25_A	et	f	\N
183649	kapitalistlikust	kapitalistlikust =kapitalistlikus  (SgP  >kapitalistlikus !11?09_S	et	f	\N
183651	kapitalistlikust	"kapitalistlikus %kapitalistliku  )US_aS  <kapitalistlik ;25_A	et	f	\N
183673	kesktee	kesktee =tee  (SgN  >kesk+tee !26_S	et	f	\N
183674	kesktee	kesktee =tee  (SgG  >kesk+tee !26_S	et	f	\N
183694	muutmisega	muutmisega =muutmise  (SgKom  >muutmine !12?10_S	et	f	\N
183695	muutmisega	"muutmine %muut  )MINE_vS  <muutma ;34_V	et	f	\N
183727	kangelastest	kangelastest =kangelas  (PlEl  >kangelane !12_S	et	f	\N
183728	kangelastest	kangelastest =test  (SgN  >kangelas+test !22_S	et	f	\N
183729	kangelastest	kangelastest =las  (PlEl  >kange+laps !14_S	et	f	\N
183730	kangelastest	kangelastest =laste  (PlEl  >kange+last !22_S	et	f	\N
183733	köide	köide =köi  (SgAdt  >köis !14_S	et	f	\N
183734	köide	köide =köide  (SgN  >köide !05_S	et	f	\N
183735	köide	köide =köide  (SgN  >köide !06_S	et	f	\N
183742	ühtsuse	ühtsuse =ühtsuse  (SgG  >ühtsus !11~09_S	et	f	\N
183743	ühtsuse	"ühtsus %ühtse  )US_aS  <ühtne ;02_A	et	f	\N
183760	teadvust	teadvust =teadvus  (SgP  >teadvus !11~09_S	et	f	\N
183761	teadvust	"teadvus %tead  )VUS_aS  <teadma ;34_V	et	f	\N
183762	teadvust	"teadvus %teadva  )US_aS  <teadev ;02_A	et	f	\N
183785	hukkusid	hukkusid =hukku  (PlP  >hukk !22_S	et	f	\N
183786	hukkusid	hukkusid =hukku  (IndIpfSg2  >hukkuma !27~28_V	et	f	\N
183787	hukkusid	hukkusid =hukku  (IndIpfPl3  >hukkuma !27~28_V	et	f	\N
183793	ajalooromaani	ajalooromaani =romaani  (SgG  >aja+loo+romaan !22_S	et	f	\N
183794	ajalooromaani	ajalooromaani =romaani  (SgP  >aja+loo+romaan !22_S	et	f	\N
183795	ajalooromaani	ajalooromaani =romaani  (SgAdt  >aja+loo+romaan !22_S	et	f	\N
183796	täisedu	täisedu =edu  (SgN  >täis+edu !17_S	et	f	\N
183797	täisedu	täisedu =edu  (SgG  >täis+edu !17_S	et	f	\N
183798	täisedu	täisedu =edu  (SgP  >täis+edu !17_S	et	f	\N
183804	löömas	löömas =löö  (SupIn  >lööma !38_V	et	f	\N
183805	löömas	löömas =lööma  (SgIn  >lööm !22_S	et	f	\N
183814	lahingutegevuses	lahingutegevuses =use  (PlIn  >lahingu+tegev+usk !22_S	et	f	\N
183815	lahingutegevuses	lahingutegevuses =tegevuse  (SgIn  >lahingu+tegevus !11_S	et	f	\N
183816	lahingutegevuses	"lahingu+tegevus %tegeva  )US_aS  <lahingu+tegev ;02_A	et	f	\N
183822	sõdimise	sõdimise =sõdimise  (SgG  >sõdimine !12_S	et	f	\N
183823	sõdimise	"sõdimine %sõdi  )MINE_vS  <sõdima ;27_V	et	f	\N
183824	piinamist	piinamist =piinamis  (SgP  >piinamine !12_S	et	f	\N
183825	piinamist	"piinamine %piina  )MINE_vS  <piinama ;29_V	et	f	\N
183856	räpast	räpast =räpa  (SgEl  >räpp !22_S	et	f	\N
183857	räpast	räpast =räpas  (SgP  >räpane !10_A	et	f	\N
183858	räpast	"räpane %räpa  )NE_aA  <räpp ;22_S	et	f	\N
183510	kambavaimu	kambavaimu =vaimu  (SgP  >kamba+vaim !22_S	et	f	\N
183511	kambavaimu	kambavaimu =vaimu  (SgAdt  >kamba+vaim !22_S	et	f	\N
183512	kambavaimu	kambavaimu =vaimu  (PlP  >kamba+vaim !22_S	et	f	\N
183572	veendumusega	veendumusega =veendumuse  (SgKom  >veendumus !11_S	et	f	\N
183573	veendumusega	"veendumus %veendu  )MUS_vS  <veenduma ;27_V	et	f	\N
183574	peaosatäitja	peaosatäitja =täitja  (SgN  >pea+osa+täitja !01_S	et	f	\N
183575	peaosatäitja	peaosatäitja =täitja  (SgG  >pea+osa+täitja !01_S	et	f	\N
183582	sära	sära =sära  (SgN  >sära !17_S	et	f	\N
183583	sära	sära =sära  (SgG  >sära !17_S	et	f	\N
183584	sära	sära =sära  (SgP  >sära !17_S	et	f	\N
183585	sära	sära =sära  (IndPrPs_  >särama !27_V	et	f	\N
183586	sära	sära =sära  (ImpPrSg2  >särama !27_V	et	f	\N
183587	inimlikkus	inimlikkus =inimlikkus  (SgN  >inimlikkus !11~09_S	et	f	\N
183588	inimlikkus	"inimlikkus %inimlikku  )US_aS  <inimlik ;25_A	et	f	\N
183593	kogenematud	kogenematud =kogenematu  (PlN  >kogenematu !01_A	et	f	\N
183594	kogenematud	"kogenematu %kogene  )MATU_vA  <kogenema ;27_V	et	f	\N
183600	lagedalt	?lagedalt =lageda  (SgAbl  >lage !02_A	et	f	\N
183601	lagedalt	?lagedalt =lagedalt  (ID  >lagedalt !41_D	et	f	\N
183602	lagedalt	?lagedalt =dalt  (SgN  >lage+dalt !22_S	et	f	\N
183638	labastanud	labastanud =labasta  (PtsPtPs  >labastama !27_V	et	f	\N
183640	labastanud	labastanud =labastanu  (PlN  >labastanu !01_S	et	f	\N
183642	labastanud	"labastanu %labasta  )NU_vS  <labastama ;27_V	et	f	\N
183643	labastanud	labastanud =labastanud  (ID  >labastanud !41_A	et	f	\N
183644	labastanud	"labastanud %labasta  )NUD_vA  <labastama ;27_V	et	f	\N
183650	ikkest	ikkest =ikke  (SgEl  >ike !06_S	et	f	\N
183652	ikkest	ikkest =ikkes  (SgP  >ikkene !12~10_A	et	f	\N
183653	ikkest	"ikkene %ikke  )NE_aA  <ike ;06_S	et	f	\N
183671	peaeesmärki	peaeesmärki =märki  (SgP  >pea+ees+märk !22_S	et	f	\N
183672	peaeesmärki	peaeesmärki =märki  (SgAdt  >pea+ees+märk !22_S	et	f	\N
183679	töölisklassi	töölisklassi =klassi  (SgG  >töölis+klass !22_S	et	f	\N
183680	töölisklassi	töölisklassi =klassi  (SgP  >töölis+klass !22_S	et	f	\N
183681	töölisklassi	töölisklassi =klassi  (SgAdt  >töölis+klass !22_S	et	f	\N
183690	seisukohale	seisukohale =koha  (SgAll  >seisu+koha !17_S	et	f	\N
183691	seisukohale	seisukohale =koha  (SgAll  >seisu+koht !22_S	et	f	\N
183740	stiililise	stiililise =stiililise  (SgG  >stiililine !12_A	et	f	\N
183741	stiililise	"stiililine %stiili  )LINE_aA  <stiil ;22_S	et	f	\N
183747	laiendamise	laiendamise =laiendamise  (SgG  >laiendamine !12_S	et	f	\N
183748	laiendamise	"laiendamine %laienda  )MINE_vS  <laiendama ;27_V	et	f	\N
183770	vindunud	vindunud =vindu  (PtsPtPs  >vinduma !27_V	et	f	\N
183771	vindunud	vindunud =vindunu  (PlN  >vindunu !01_S	et	f	\N
183772	vindunud	"vindunu %vindu  )NU_vS  <vinduma ;27_V	et	f	\N
183773	vindunud	vindunud =vindunud  (ID  >vindunud !41_A	et	f	\N
183774	vindunud	"vindunud %vindu  )NUD_vA  <vinduma ;27_V	et	f	\N
183775	kaasrahastajad	?kaasrahastajad =kaasrahastaja  (PlN  >kaasrahastaja !01_S	et	f	\N
183776	kaasrahastajad	?kaasrahastajad =kaasrahastaja  (PlN  >kaasrahastajas !02_A	et	f	\N
183777	kaasrahastajad	?kaasrahastajad =staja  (PlN  >kaas+raha+staja !17_S	et	f	\N
183778	kaasrahastajad	?kaasrahastajad =rahastaja  (PlN  >kaas+rahastaja !01_S	et	f	\N
183779	kaasrahastajad	?kaasrahastajad =rahastaja  (PlN  >kaas+rahastajas !02_A	et	f	\N
183780	kiitsid	kiitsid =kiit  (IndIpfSg2  >kiitma !34_V	et	f	\N
183781	kiitsid	kiitsid =kiit  (IndIpfPl3  >kiitma !34_V	et	f	\N
183782	kiitsid	kiitsid =kiitsi  (PlN  >kiits !22_S	et	f	\N
183783	vaatajal	vaatajal =vaataja  (SgAd  >vaataja !01_S	et	f	\N
183784	vaatajal	"vaataja %vaata  )JA_vS  <vaatama ;29_V	et	f	\N
183788	oodanudki	oodanudki =ooda  (PtsPtPs^  >ootama !29_V	et	f	\N
183789	oodanudki	oodanudki =oodanu  (PlN^  >oodanu !01_S	et	f	\N
183790	oodanudki	"oodanu %ooda  )NU_vS^  <ootama ;29_V	et	f	\N
183791	oodanudki	oodanudki =oodanud  (ID^  >oodanud !41_A	et	f	\N
183792	oodanudki	"oodanud %ooda  )NUD_vA^  <ootama ;29_V	et	f	\N
183806	tääekr	?tääekr =tääekr  (SgN  >tääekr !22_S	et	f	\N
183820	karastuse	karastuse =karastuse  (SgG  >karastus !11_S	et	f	\N
183821	karastuse	"karastus %karasta  )US_vS  <karastama ;27_V	et	f	\N
183826	tulista	tulista =tulista  (IndPrPs_  >tulistama !27_V	et	f	\N
183827	tulista	tulista =tulista  (ImpPrSg2  >tulistama !27_V	et	f	\N
183828	kurbi	kurbi =kurbi  (SgP  >kurb !22_A	et	f	\N
183829	kurbi	kurbi =kurbi  (SgAdt  >kurb !22_A	et	f	\N
183830	kurbi	kurbi =kurbi  (PlP  >kurb !22_A	et	f	\N
183847	üksküla	üksküla =küla  (SgN  >üks+küla !17_S	et	f	\N
183848	üksküla	üksküla =küla  (SgG  >üks+küla !17_S	et	f	\N
183849	üksküla	üksküla =küla  (SgP  >üks+küla !17_S	et	f	\N
183925	liigutaks	liigutaks =liigu  (KndPrIps  >liikuma !28_V	et	f	\N
183926	liigutaks	liigutaks =liiguta  (KndPrPs  >liigutama !27_V	et	f	\N
183927	hakkajaid	hakkajaid =hakkaja  (PlP  >hakkaja !01_SA	et	f	\N
183928	hakkajaid	"hakkaja %hakka  )JA_vS  <hakkama ;29_V	et	f	\N
183929	20nda	### 20nda	et	f	\N
183935	sotsialistlikus	sotsialistlikus =sotsialistliku  (SgIn  >sotsialistlik !25_A	et	f	\N
183622	tätte	?tätte =tätte  (SgG  >täte !06_S	et	f	\N
183623	tätte	?tätte =tätte  (PlP  >tätt !22_S	et	f	\N
183624	tätte	?tätte =tätte  (IndPrPs_  >tättema !27_V	et	f	\N
183625	tätte	?tätte =tätte  (ImpPrSg2  >tättema !27_V	et	f	\N
183628	rongivaritsusest	rongivaritsusest =varitsuse  (SgEl  >rongi+varitsus !11_S	et	f	\N
183629	rongivaritsusest	rongivaritsusest =varitsuses  (SgP  >rongi+varitsusene !12_A	et	f	\N
183630	rongivaritsusest	"rongi+varitsusene %varitsuse  )NE_aA  <rongi+varitsus ;11_S	et	f	\N
183631	tõeliste	tõeliste =tõelis  (PlG  >tõeline !12?10_A	et	f	\N
183632	tõeliste	"tõeline %tõe  )LINE_aA  <tõsi ;15_S	et	f	\N
183633	tõeliste	"tõeline %tõe  )LINE_aA  <tõde ;18_S	et	f	\N
183645	patriotismiideed	patriotismiideed =idee  (PlN  >patriotismi+idee !26_S	et	f	\N
183646	patriotismiideed	patriotismiideed =idee  (SgP  >patriotismi+idee !26_S	et	f	\N
183684	sissetungiv	sissetungiv =tungi  (PtsPrPs  >sisse+_tungima !28_V	et	f	\N
183685	sissetungiv	sissetungiv =tungiv  (SgN  >sisse+tungiv !02_A	et	f	\N
183686	töölisklassihulka	töölisklassihulka =hulka  (SgP  >töölis+klassi+hulk !22_S	et	f	\N
183687	töölisklassihulka	töölisklassihulka =hulka  (SgAdt  >töölis+klassi+hulk !22_S	et	f	\N
183688	otsustamise	otsustamise =otsustamise  (SgG  >otsustamine !12_S	et	f	\N
183689	otsustamise	"otsustamine %otsusta  )MINE_vS  <otsustama ;27_V	et	f	\N
183698	nimetaks	nimetaks =nimeta  (KndPrPs  >nimetama !27_V	et	f	\N
183699	nimetaks	nimetaks =taks  (SgN  >nime+taks !22_S	et	f	\N
183702	esmakordselt1935	esmakordselt =kordse  (SgAbl  >esma+kordne !02_AS	et	f	\N
183703	esmakordselt1935	"esma+kordselt %kordse  )LT_mD  <esma+kordne ;02_AS	et	f	\N
183721	kärbitud	kärbitud =kärbi  (PtsPtIps  >kärpima !28_V	et	f	\N
183722	kärbitud	kärbitud =kärbitu  (PlN  >kärbitu !01_AS	et	f	\N
183723	kärbitud	"kärbitu %kärbi  )TU1_vS  <kärpima ;28_V	et	f	\N
183724	kärbitud	"kärbitu %kärbi  )TU2_kA  <kärp ;22_S	et	f	\N
183725	kärbitud	kärbitud =kärbitud  (ID  >kärbitud !41_A	et	f	\N
183726	kärbitud	"kärbitud %kärbi  )TUD_vA  <kärpima ;28_V	et	f	\N
183755	kahtlev	kahtlev =kahtle  (PtsPrPs  >kahtlema !30_V	et	f	\N
183756	kahtlev	kahtlev =kahtlev  (SgN  >kahtlev !02_A	et	f	\N
183757	kahtlev	"kahtlev %kahtle  )V_vA  <kahtlema ;30_V	et	f	\N
183763	järgnenud	järgnenud =järgne  (PtsPtPs  >järgnema !27_V	et	f	\N
183764	järgnenud	järgnenud =järgnenu  (PlN  >järgnenu !01_S	et	f	\N
183765	järgnenud	"järgnenu %järgne  )NU_vS  <järgnema ;27_V	et	f	\N
183766	järgnenud	järgnenud =järgnenud  (ID  >järgnenud !41_A	et	f	\N
183767	järgnenud	"järgnenud %järgne  )NUD_vA  <järgnema ;27_V	et	f	\N
183799	kristian	?kristian =kristian  (SgN  >kristian !19~02_S	et	f	\N
183817	eller	?eller =eller  (SgN  >eller !02_S	et	f	\N
183818	lahingulise	lahingulise =lahingulise  (SgG  >lahinguline !12_A	et	f	\N
183819	lahingulise	"lahinguline %lahingu  )LINE_aA  <lahing ;02_S	et	f	\N
183831	martaga	?martaga =marta  (SgKom  >marta !16_S	et	f	\N
183836	humoorikas	humoorikas =humoorika  (SgIn  >humoorikas !02_A	et	f	\N
183837	humoorikas	humoorikas =humoorikas  (SgN  >humoorikas !02_A	et	f	\N
183853	kirevam	kirevam =kirevam  (SgN  >kirevam !02_A	et	f	\N
183854	kirevam	"kirevam %kire  )VAM_cA  <kirema ;27_V	et	f	\N
183855	kirevam	"kirevam %kireva  )M_cA  <kirev ;02_A	et	f	\N
183892	koolitamine	koolitamine =koolitamine  (SgN  >koolitamine !12_S	et	f	\N
183893	koolitamine	"koolitamine %koolita  )MINE_vS  <koolitama ;27_V	et	f	\N
183906	täide	täide =täi  (SgAdt  >täis !14_AS	et	f	\N
183907	täide	täide =täi  (PlG  >täi !26_S	et	f	\N
183908	täide	täide =täide  (SgN  >täide !06_S	et	f	\N
183930	rolliga	rolliga =rolli  (SgKom  >roll !22_S	et	f	\N
183931	rolliga	rolliga =iga  (SgN  >roll+iga !18_S	et	f	\N
183932	rolliga	rolliga =iga  (SgP  >roll+iga !18_S	et	f	\N
183965	õnnestu	õnnestu =õnnestu  (IndPrPs_  >õnnestuma !27_V	et	f	\N
183966	õnnestu	õnnestu =õnnestu  (ImpPrSg2  >õnnestuma !27_V	et	f	\N
183972	tublem	?tublem =tublem  (SgN  >tublem !02_A	et	f	\N
183981	leninil	?leninil =lenini  (SgAd  >lenin !02_S	et	f	\N
183982	teisikuid	teisikuid =teisiku  (PlP  >teisik !02_S	et	f	\N
183983	teisikuid	teisikuid =ku  (PlP  >teisi+kuu !26_S	et	f	\N
184034	armandi	?armandi =armandi  (SgN  >armandi !01_S	et	f	\N
184035	armandi	?armandi =armandi  (SgG  >armandi !01_S	et	f	\N
184036	armandi	?armandi =armandi  (SgG  >armand !02_S	et	f	\N
184037	armandi	?armandi =armandi  (SgG  >armant !22_S	et	f	\N
184038	armandi	?armandi =armandi  (IndPrPs_  >armantima !28_V	et	f	\N
184039	armandi	?armandi =armandi  (ImpPrSg2  >armantima !28_V	et	f	\N
184040	vale-leninite	?vale-leninite =lenini  (PlG  >vale-lenin !02_S	et	f	\N
184048	forrest	?forrest =forre  (PlEl  >forr !22_S	et	f	\N
184050	forrest	?forrest =forres  (SgP  >forres !09_S	et	f	\N
184051	forrest	?forrest =forres  (SgP  >forrene !10_A	et	f	\N
184052	gumpi	?gumpi =gumpi  (ID  >gumpi !41_D	et	f	\N
184053	gumpi	?gumpi =gumpi  (SgP  >gump !22_S	et	f	\N
184054	gumpi	?gumpi =gumpi  (SgAdt  >gump !22_S	et	f	\N
184058	minuseid	?minuseid =minuse  (PlP  >minus !09_S	et	f	\N
184059	minuseid	?minuseid =minusei  (PlN  >minusei !26_S	et	f	\N
184060	minuseid	?minuseid =minusei  (SgP  >minusei !26_S	et	f	\N
183635	kangelastena	kangelastena =las  (PlEs  >kange+laps !14_S	et	f	\N
183654	vabastamisse	vabastamisse =vabastamis  (SgAdt  >vabastamine !12_S	et	f	\N
183655	vabastamisse	"vabastamine %vabasta  )MINE_vS  <vabastama ;27_V	et	f	\N
183658	marrahvuslikku	?marrahvuslikku =marrahvuslikku  (SgP  >marrahvuslik !25_A	et	f	\N
183659	marrahvuslikku	?marrahvuslikku =marrahvuslikku  (SgAdt  >marrahvuslik !25_A	et	f	\N
183660	marrahvuslikku	?marrahvuslikku =marrahvuslikku  (IndPrPs_  >marrahvuslikkuma !27_V	et	f	\N
183661	marrahvuslikku	?marrahvuslikku =marrahvuslikku  (ImpPrSg2  >marrahvuslikkuma !27_V	et	f	\N
183668	kommunismiidee	kommunismiidee =idee  (SgN  >kommunismi+idee !26_S	et	f	\N
183670	kommunismiidee	kommunismiidee =idee  (SgG  >kommunismi+idee !26_S	et	f	\N
183677	kodanlusel	kodanlusel =kodanluse  (SgAd  >kodanlus !11_S	et	f	\N
183678	kodanlusel	"kodanlus %kodanlase  )US_aS  <kodanlane ;12_S	et	f	\N
183682	vabastamise	vabastamise =vabastamise  (SgG  >vabastamine !12_S	et	f	\N
183683	vabastamise	"vabastamine %vabasta  )MINE_vS  <vabastama ;27_V	et	f	\N
183709	osutunud	osutunud =osutu  (PtsPtPs  >osutuma !27_V	et	f	\N
183710	osutunud	osutunud =osutunu  (PlN  >osutunu !01_S	et	f	\N
183711	osutunud	"osutunu %osutu  )NU_vS  <osutuma ;27_V	et	f	\N
183712	osutunud	osutunud =osutunud  (ID  >osutunud !41_A	et	f	\N
183713	osutunud	"osutunud %osutu  )NUD_vA  <osutuma ;27_V	et	f	\N
183718	redigeeritu	redigeeritu =redigeeritu  (SgN  >redigeeritu !01_S	et	f	\N
183719	redigeeritu	"redigeeritu %redigeeri  )TU1_vS  <redigeerima ;28_V	et	f	\N
183720	redigeeritu	redigeeritu =redigeeritu  (SgG  >redigeeritu !01_S	et	f	\N
183736	kroonikali	kroonikali =kali  (SgN  >krooni+kali !17_S	et	f	\N
183737	kroonikali	kroonikali =kali  (SgN  >krooni+kali !24_S	et	f	\N
183738	kroonikali	kroonikali =kali  (SgG  >krooni+kali !17_S	et	f	\N
183739	kroonikali	kroonikali =kali  (SgP  >krooni+kali !17_S	et	f	\N
183744	tagajärjest	tagajärjest =järje  (SgEl  >taga+järg !22_S	et	f	\N
183745	tagajärjest	tagajärjest =järjes  (SgP  >taga+järjene !10_A	et	f	\N
183746	tagajärjest	"taga+järjene %järje  )NE_aA  <taga+järg ;22_S	et	f	\N
183758	juhtivtegelastest	juhtivtegelastest =test  (SgN  >juhtiv+tegelas+test !22_S	et	f	\N
183759	juhtivtegelastest	juhtivtegelastest =tegelas  (PlEl  >juhtiv+tegelane !12_S	et	f	\N
183807	arutlevad	arutlevad =arutle  (IndPrPl3  >arutlema !27_V	et	f	\N
183808	arutlevad	arutlevad =arutleva  (PlN  >arutlev !02_A	et	f	\N
183809	arutlevad	"arutlev %arutle  )V_vA  <arutlema ;27_V	et	f	\N
183810	organiseerumist	?organiseerumist =organiseerumi  (SgEl  >organiseerum !02_S	et	f	\N
183811	organiseerumist	?organiseerumist =organiseerumis  (SgP  >organiseerumis !09_S	et	f	\N
183812	organiseerumist	?organiseerumist =organiseerumis  (SgP  >organiseerumine !12_S	et	f	\N
183813	organiseerumist	?organiseerumist =organiseerumist  (SgN  >organiseerumist !22_S	et	f	\N
183834	võõrus	võõrus =võõrus  (SgN  >võõrus !11~09_S	et	f	\N
183835	võõrus	"võõrus %võõra  )US_aS  <võõras ;07_AS	et	f	\N
183843	huvitavgi	huvitavgi =huvita  (PtsPrPs^  >huvitama !27_V	et	f	\N
183844	huvitavgi	huvitavgi =huvitav  (SgN^  >huvitav !02_A	et	f	\N
183845	huvitavgi	"huvitav %huvita  )V_vA^  <huvitama ;27_V	et	f	\N
183850	üldilme	üldilme =ilme  (SgN  >üld+ilme !06_S	et	f	\N
183851	üldilme	üldilme =ilme  (SgG  >üld+ilme !06_S	et	f	\N
183852	üldilme	üldilme =ilme  (PlP  >üld+ilm !22_S	et	f	\N
183861	filmitudvustusest	?filmitudvustusest =filmitudvustuse  (SgEl  >filmitudvustus !11~09_S	et	f	\N
183862	filmitudvustusest	?filmitudvustusest =filmitudvustuses  (SgP  >filmitudvustusene !12_A	et	f	\N
183863	filmitudvustusest	?filmitudvustusest =tudvustuse  (SgEl  >filmi+tudvustus !11_S	et	f	\N
183864	filmitudvustusest	?filmitudvustusest =tudvustuses  (SgP  >filmi+tudvustusene !12_A	et	f	\N
183865	müügiedu	müügiedu =edu  (SgN  >müügi+edu !17_S	et	f	\N
183866	müügiedu	müügiedu =edu  (SgG  >müügi+edu !17_S	et	f	\N
183867	müügiedu	müügiedu =edu  (SgP  >müügi+edu !17_S	et	f	\N
183872	eestipärane	eestipärane =pärane  (SgN  >eesti+pärane !10_A	et	f	\N
183873	eestipärane	"eesti+pärane %pära  )NE_aA  <eesti+pära ;17_S	et	f	\N
183875	kujutus	kujutus =kujutu  (SgIn  >kujutu !01_A	et	f	\N
183876	kujutus	"kujutu %kuju  )TU2_kA  <kuju ;17_S	et	f	\N
183877	kujutus	kujutus =kujutus  (SgN  >kujutus !11_S	et	f	\N
183878	kujutus	"kujutus %kujuta  )US_vS  <kujutama ;27_V	et	f	\N
183879	kujutus	"kujutus %kuju  )TUS2_aS  <kuju ;17_S	et	f	\N
183880	põnevust	põnevust =põnevus  (SgP  >põnevus !11_S	et	f	\N
183881	põnevust	"põnevus %põneva  )US_aS  <põnev ;02_A	et	f	\N
183882	teisikutest	teisikutest =teisiku  (PlEl  >teisik !02_S	et	f	\N
183883	teisikutest	teisikutest =test  (SgN  >teisiku+test !22_S	et	f	\N
183886	sarimõrtsukas	sarimõrtsukas =mõrtsuka  (SgIn  >sari+mõrtsukas !02_S	et	f	\N
183887	sarimõrtsukas	sarimõrtsukas =mõrtsukas  (SgN  >sari+mõrtsukas !02_S	et	f	\N
183891	võltsleninite	?võltsleninite =lenini  (PlG  >võlts+lenin !02_S	et	f	\N
183894	laskmine	laskmine =laskmine  (SgN  >laskmine !12?10_S	et	f	\N
183895	laskmine	"laskmine %lask  )MINE_vS  <laskma ;34_V	et	f	\N
183896	komöödiaks	komöödiaks =komöödia  (SgTr  >komöödia !01_S	et	f	\N
183897	komöödiaks	komöödiaks =dia  (SgTr  >kom+öö+dia !26_S	et	f	\N
183901	pusklemist	pusklemist =pusklemis  (SgP  >pusklemine !12_S	et	f	\N
183700	tabamatuks	tabamatuks =tabamatu  (SgTr  >tabamatu !01_A	et	f	\N
183701	tabamatuks	"tabamatu %taba  )MATU_vA  <tabama ;27_V	et	f	\N
183704	joonealusena	joonealusena =aluse  (SgEs  >joone+alus !09_S	et	f	\N
183705	joonealusena	joonealusena =aluse  (SgEs  >joone+alune !10_AS	et	f	\N
183706	joonealusena	"joone+alune %alu  )NE_aA  <joone+alg ;22_S	et	f	\N
183707	ülikuulsaks	ülikuulsaks =saks  (SgN  >üli+kuul+saks !23?22_S	et	f	\N
183708	ülikuulsaks	ülikuulsaks =kuulsa  (SgTr  >üli+kuulus !02_A	et	f	\N
183714	meetus	meetus =meetu  (SgIn  >meetu !01_A	et	f	\N
183715	meetus	"meetu %mee  )TU2_kA  <mesi ;15_S	et	f	\N
183716	meetus	meetus =meetus  (SgN  >meetus !11~09_S	et	f	\N
183717	meetus	"meetus %mee  )TUS2_aS  <mesi ;15_S	et	f	\N
183731	esiplaanile	esiplaanile =esiplaanile  (ID  >esi+plaanile !41_D	et	f	\N
183732	esiplaanile	esiplaanile =plaani  (SgAll  >esi+plaan !22_S	et	f	\N
183749	päästatud	?päästatud =päästa  (PtsPtIps  >päästama !27_V	et	f	\N
183750	päästatud	?päästatud =päästatu  (PlN  >päästatu !01_S	et	f	\N
183751	päästatud	?päästatud =päästatu  (IndPrSg2  >päästatuma !27_V	et	f	\N
183752	päästatud	?päästatud =päästatud  (ID  >päästatud !41_A	et	f	\N
183753	päästatud	?päästatud =tatu  (PlN  >pääs+tatu !16_S	et	f	\N
183754	päästatud	?päästatud =statu  (PlN  >pää+statu !16_S	et	f	\N
183768	iseseisvusaastatel	iseseisvusaastatel =tate  (PlAd  >ise+seisvus+aas+tatt !22_S	et	f	\N
183769	iseseisvusaastatel	iseseisvusaastatel =aasta  (PlAd  >ise+seisvus+aasta !01_S	et	f	\N
183800	taska	?taska =taska  (SgN  >taska !16_S	et	f	\N
183801	taska	?taska =taska  (SgG  >taska !16_S	et	f	\N
183802	taska	?taska =taska  (IndPrPs_  >taskama !29_V	et	f	\N
183803	taska	?taska =taska  (ImpPrSg2  >taskama !29_V	et	f	\N
183832	armastuseni	armastuseni =armastuse  (SgTer  >armastus !11_S	et	f	\N
183833	armastuseni	"armastus %armasta  )US_vS  <armastama ;27_V	et	f	\N
183838	seiklusrikas	?seiklusrikas =seiklusrika  (SgIn  >seiklusrika !01_S	et	f	\N
183839	seiklusrikas	?seiklusrikas =seiklusrika  (SgIn  >seiklusrikas !02_A	et	f	\N
183840	seiklusrikas	?seiklusrikas =seiklusrikas  (SgN  >seiklusrikas !02_A	et	f	\N
183841	seiklusrikas	?seiklusrikas =rika  (SgIn  >seiklus+rika !16_S	et	f	\N
183842	seiklusrikas	?seiklusrikas =rikas  (SgN  >seiklus+rikas !07_A	et	f	\N
183846	dj	### dj	et	f	\N
183874	läänelik	?läänelik =läänelik  (SgN  >läänelik !25_A	et	f	\N
183898	suur-eesti	suur-eesti =eesti  (ID  >suur-eesti !41_G	et	f	\N
183899	suur-eesti	suur-eesti =eesti  (SgN  >suur-eesti !16_H	et	f	\N
183900	suur-eesti	suur-eesti =eesti  (SgG  >suur-eesti !16_H	et	f	\N
183909	väljamängitud	väljamängitud =mängi  (PtsPtIps  >välja+_mängima !28_V	et	f	\N
183910	väljamängitud	väljamängitud =mängitu  (PlN  >välja+mängitu !01_AS	et	f	\N
183911	mõjutama	mõjutama =mõju  (SupIps  >mõjuma !27_V	et	f	\N
183912	mõjutama	mõjutama =mõjuta  (Sup  >mõjutama !27_V	et	f	\N
183913	tegelikust	tegelikust =tegeliku  (SgEl  >tegelik !25_A	et	f	\N
183914	tegelikust	tegelikust =tegelikus  (SgP  >tegelikus !11?09_S	et	f	\N
183915	tegelikust	"tegelikus %tegeliku  )US_aS  <tegelik ;25_A	et	f	\N
183919	pähetuubitud	pähetuubitud =tuubi  (PtsPtIps  >pähe+_tuupima !28_V	et	f	\N
183920	pähetuubitud	pähetuubitud =tuubitu  (PlN  >pähe+tuubitu !01_AS	et	f	\N
183921	pähetuubitud	"pähe+tuubitu %tuubi  )TU2_kA  <pähe+tuub ;22_S	et	f	\N
183942	maamaja	maamaja =maja  (SgN  >maa+maja !17_S	et	f	\N
183944	maamaja	maamaja =maja  (SgG  >maa+maja !17_S	et	f	\N
183945	maamaja	maamaja =maja  (SgP  >maa+maja !17_S	et	f	\N
183987	kodulinnast	kodulinnast =ast  (SgN  >kodu+linn+ast !22_S	et	f	\N
183988	kodulinnast	kodulinnast =linna  (SgEl  >kodu+linn !22_S	et	f	\N
183989	kodulinnast	kodulinnast =linnas  (SgP  >kodu+linnas !09_S	et	f	\N
183990	kodulinnast	kodulinnast =linnas  (SgP  >kodu+linnane !10_A	et	f	\N
183991	kodulinnast	"kodu+linnane %linna  )NE_aA  <kodu+linn ;22_S	et	f	\N
183992	ammende	### ammende	et	f	\N
184006	ettevõtlikust	ettevõtlikust =võtliku  (SgEl  >ette+võtlik !25_A	et	f	\N
184007	ettevõtlikust	ettevõtlikust =võtlikus  (SgP  >ette+võtlikus !11_S	et	f	\N
184008	ettevõtlikust	"ette+võtlikus %võtliku  )US_aS  <ette+võtlik ;25_A	et	f	\N
184009	diplomaatne	?diplomaatne =diplomaatne  (SgN  >diplomaatne !02_A	et	f	\N
184010	diplomaatne	?diplomaatne =diplomaatne  (PlP  >diplomaatn !22_S	et	f	\N
184016	julmus	julmus =julmu  (IndIpfSg3  >julmuma !27_V	et	f	\N
184017	julmus	julmus =julmus  (SgN  >julmus !11~09_S	et	f	\N
184018	julmus	"julmus %julm  )US_aS  <julm ;22_A	et	f	\N
184019	tilka	tilka =tilka  (SgP  >tilk !22_S	et	f	\N
184020	tilka	tilka =tilka  (SgAdt  >tilk !22_S	et	f	\N
184032	inessa	?inessa =inessa  (SgN  >inessa !01_S	et	f	\N
184033	inessa	?inessa =inessa  (SgG  >inessa !01_S	et	f	\N
184041	krupskaja	?krupskaja =krupskaja  (SgN  >krupskaja !01_S	et	f	\N
184042	krupskaja	?krupskaja =krupskaja  (SgG  >krupskaja !01_S	et	f	\N
184043	krupskaja	?krupskaja =krupskaja  (SgG  >krupskajas !02_A	et	f	\N
184044	ristinud	ristinud =risti  (PtsPtPs  >ristima !28_V	et	f	\N
184045	ristinud	ristinud =ristinu  (PlN  >ristinu !01_S	et	f	\N
184046	ristinud	"ristinu %risti  )NU_vS  <ristima ;28_V	et	f	\N
184047	ristinud	ristinud =ristinud  (ID  >ristinud !41_A	et	f	\N
183859	hüppamisi	hüppamisi =hüppamisi  (PlP  >hüppamine !12_S	et	f	\N
183860	hüppamisi	"hüppamine %hüppa  )MINE_vS  <hüppama ;29_V	et	f	\N
183868	kinnisena	kinnisena =kinnise  (SgEs  >kinnis !09_S	et	f	\N
183869	kinnisena	kinnisena =kinnise  (SgEs  >kinnine !10~12_A	et	f	\N
183870	seiklushimulise	seiklushimulise =himulise  (SgG  >seiklus+himuline !12_A	et	f	\N
183871	seiklushimulise	"seiklus+himuline %himu  )LINE_aA  <seiklus+himu ;17_S	et	f	\N
183884	hulluksläinud	hulluksläinud =läinu  (PlN  >hulluks+läinu !01_S	et	f	\N
183885	hulluksläinud	hulluksläinud =läinu  (PlN  >hulluks+läinu !06_S	et	f	\N
183888	joomise	joomise =joomise  (SgG  >joomine !12?10_S	et	f	\N
183889	joomise	"joomine %joo  )MINE_vS  <jooma ;38_V	et	f	\N
183890	joomise	"joomine %joomi  )NE_aA  <joom ;22_S	et	f	\N
183903	unistaja	unistaja =unistaja  (SgN  >unistaja !01_S	et	f	\N
183904	unistaja	"unistaja %unista  )JA_vS  <unistama ;27_V	et	f	\N
183905	unistaja	unistaja =unistaja  (SgG  >unistaja !01_S	et	f	\N
183916	jäigalt	jäigalt =jäiga  (SgAbl  >jäik !22_A	et	f	\N
183917	jäigalt	jäigalt =jäigalt  (ID  >jäigalt !41_D	et	f	\N
183918	jäigalt	"jäigalt %jäiga  )LT_mD  <jäik ;22_A	et	f	\N
183938	liikumises	liikumises =liikumise  (SgIn  >liikumine !12_S	et	f	\N
183939	liikumises	"liikumine %liiku  )MINE_vS  <liikuma ;28_V	et	f	\N
183948	viimiseks	viimiseks =viimise  (SgTr  >viimine !12?10_S	et	f	\N
183949	viimiseks	"viimine %vii  )MINE_vS  <viima ;38_V	et	f	\N
183950	berni	?berni =berni  (SgN  >berni !16_S	et	f	\N
183951	berni	?berni =berni  (SgG  >berni !16_S	et	f	\N
183952	berni	?berni =berni  (SgG  >bern !22_S	et	f	\N
183953	berni	?berni =berni  (SgP  >bern !22_S	et	f	\N
183954	berni	?berni =berni  (SgAdt  >bern !22_S	et	f	\N
183955	berni	?berni =berni  (IndPrPs_  >bernima !28_V	et	f	\N
183956	berni	?berni =berni  (ImpPrSg2  >bernima !28_V	et	f	\N
183973	keskülale	?keskülale =kesküla  (SgAll  >kesküla !01_S	et	f	\N
183974	keskülale	?keskülale =keskülale  (PlP  >keskülal !19_S	et	f	\N
183975	keskülale	?keskülale =üla  (SgAll  >kesk+üla !17_S	et	f	\N
183993	komeedia	?komeedia =komeedia  (SgN  >komeedia !01_S	et	f	\N
183994	komeedia	?komeedia =komeedia  (SgG  >komeedia !01_S	et	f	\N
183995	komeedia	?komeedia =eedia  (SgN  >kom+eedia !01_S	et	f	\N
183996	komeedia	?komeedia =eedia  (SgG  >kom+eedia !01_S	et	f	\N
184028	revolutsionääri	revolutsionääri =revolutsionääri  (SgG  >revolutsionäär !22_S	et	f	\N
184030	revolutsionääri	revolutsionääri =revolutsionääri  (SgP  >revolutsionäär !22_S	et	f	\N
184031	revolutsionääri	revolutsionääri =revolutsionääri  (SgAdt  >revolutsionäär !22_S	et	f	\N
184065	revolutsionist	?revolutsionist =revolutsioni  (SgEl  >revolutsion !19~02_S	et	f	\N
184066	revolutsionist	?revolutsionist =revolutsioni  (SgEl  >revolutsioni !16_S	et	f	\N
184067	revolutsionist	?revolutsionist =revolutsionis  (SgP  >revolutsionis !09_S	et	f	\N
184068	revolutsionist	?revolutsionist =revolutsionist  (SgN  >revolutsionist !22_S	et	f	\N
184074	nadjaga	?nadjaga =nadja  (SgKom  >nadjas !02_A	et	f	\N
184075	nadjaga	?nadjaga =nadja  (SgKom  >nadja !16_S	et	f	\N
184076	elulood	elulood =loo  (PlN  >elu+lugu !18_S	et	f	\N
184077	elulood	elulood =loo  (PlN  >elu+loog !22_S	et	f	\N
184078	elulood	elulood =loo  (PlN  >elu+lood !22_S	et	f	\N
184079	elulood	elulood =lood  (SgN  >elu+lood !22_S	et	f	\N
184110	revolütsionääridel	?revolütsionääridel =revolütsionääri  (PlAd  >revolütsionääri !16_S	et	f	\N
184111	revolütsionääridel	?revolütsionääridel =revolütsionääri  (PlAd  >revolütsionäär !22_S	et	f	\N
184112	saatust	saatust =saatus  (SgP  >saatus !11~09_S	et	f	\N
184113	saatust	saatust =us  (SgP  >saat+uks !14_S	et	f	\N
184116	kaksikutest	kaksikutest =kaksiku  (PlEl  >kaksik !02_SA	et	f	\N
184117	kaksikutest	kaksikutest =ute  (SgEl  >kaksik+utt !22_S	et	f	\N
184118	kaksikutest	kaksikutest =ute  (PlEl  >kaksik+utt !22_S	et	f	\N
184119	kaksikutest	kaksikutest =utes  (SgP  >kaksik+utene !10_A	et	f	\N
184120	kaksikutest	"kaksik+utene %ute  )NE_aA  <kaksik+utt ;22_S	et	f	\N
184145	silmapaistvaimaks	silmapaistvaimaks =paistvaima  (SgTr  >silma+paistvaim !02_A	et	f	\N
184146	silmapaistvaimaks	"silma+paistvaim %paistva  )IM_sA  <silma+paistev ;02_A	et	f	\N
184184	sündivad	sündivad =sündiva  (PlN  >sündiv !02_A	et	f	\N
184185	sündivad	"sündiv %sündi  )V_vA  <sündima ;28_V	et	f	\N
184188	streigid	streigid =streigi  (PlN  >streik !22_S	et	f	\N
184189	streigid	streigid =streigi  (IndPrSg2  >streikima !28_V	et	f	\N
184195	armukesega	armukesega =armukese  (SgKom  >armuke !12_S	et	f	\N
184196	armukesega	"armuke %armu  )KE_dS  <arm ;22_S	et	f	\N
184197	armukesega	armukesega =armukese  (SgKom  >armukene !12_S	et	f	\N
184198	armukesega	"armukene %armu  )KENE_dS  <arm ;22_S	et	f	\N
184226	vastamata	vastamata =vasta  (SupAb  >vastama !29_V	et	f	\N
184227	vastamata	vastamata =vastamata  (ID  >vastamata !41_A	et	f	\N
184228	vastamata	"vastamata %vasta  )MATA_vA  <vastama ;29_V	et	f	\N
184261	ettenäha	?ettenäha =ettenäha  (SgN  >ettenäha !16_S	et	f	\N
184262	ettenäha	?ettenäha =ettenäha  (SgG  >ettenäha !16_S	et	f	\N
184280	lenitele	?lenitele =lenite  (PlAll  >lenitt !22_S	et	f	\N
184281	lenitele	?lenitele =lenitele  (IndPrPs_  >lenitelema !36_V	et	f	\N
183902	pusklemist	"pusklemine %puskle  )MINE_vS  <pusklema ;30_V	et	f	\N
183922	välismaalaste	välismaalaste =las  (PlG  >välis+maa+laps !14_S	et	f	\N
183923	välismaalaste	välismaalaste =laste  (PlP  >välis+maa+last !22_S	et	f	\N
183924	välismaalaste	välismaalaste =maalas  (PlG  >välis+maalane !12?10_S	et	f	\N
183933	pariisist	?pariisist =pariisi  (SgEl  >pariis !22_S	et	f	\N
183934	pariisist	?pariisist =pariisis  (SgP  >pariisis !09_S	et	f	\N
183946	kinnisidee	kinnisidee =idee  (SgN  >kinnis+idee !26_S	et	f	\N
183947	kinnisidee	kinnisidee =idee  (SgG  >kinnis+idee !26_S	et	f	\N
183962	trükkisid	trükkisid =trükki  (PlP  >trükk !22_S	et	f	\N
183963	trükkisid	trükkisid =trükki  (IndIpfSg2  >trükkima !28_V	et	f	\N
183964	trükkisid	trükkisid =trükki  (IndIpfPl3  >trükkima !28_V	et	f	\N
183967	koolilatakse	?koolilatakse =koolilatakse  (SgG  >koolilatakne !02_A	et	f	\N
183968	koolilatakse	?koolilatakse =koolilatakse  (PlP  >koolilataks !22_S	et	f	\N
183969	koolilatakse	?koolilatakse =latakse  (SgG  >kooli+latakne !02_A	et	f	\N
183970	koolilatakse	?koolilatakse =ilatakse  (SgG  >kool+ilatakne !02_A	et	f	\N
183971	koolilatakse	?koolilatakse =ilatakse  (PlP  >kool+ilataks !22_S	et	f	\N
183978	vanjaga	?vanjaga =vanja  (SgKom  >vanjas !02_A	et	f	\N
183979	vanjaga	?vanjaga =vanja  (SgKom  >vanja !16_S	et	f	\N
184011	delegatsiooni	delegatsiooni =delegatsiooni  (SgG  >delegatsioon !22_S	et	f	\N
184012	delegatsiooni	delegatsiooni =delegatsiooni  (SgP  >delegatsioon !22_S	et	f	\N
184013	delegatsiooni	delegatsiooni =delegatsiooni  (SgAdt  >delegatsioon !22_S	et	f	\N
184023	krupskajale	?krupskajale =krupskaja  (SgAll  >krupskaja !01_S	et	f	\N
184024	krupskajale	?krupskajale =krupskaja  (SgAll  >krupskajas !02_A	et	f	\N
184025	krupskajale	?krupskajale =krupskajale  (PlP  >krupskajal !19_S	et	f	\N
184026	iha	iha =iha  (SgN  >iha !17_S	et	f	\N
184027	iha	iha =iha  (SgG  >iha !17_S	et	f	\N
184029	iha	iha =iha  (SgP  >iha !17_S	et	f	\N
184055	tundmata	tundmata =tund  (SupAb  >tundma !34_V	et	f	\N
184056	tundmata	tundmata =tundmata  (ID  >tundmata !41_A	et	f	\N
184057	tundmata	"tundmata %tund  )MATA_vA  <tundma ;34_V	et	f	\N
184100	pageduses	?pageduses =pageduse  (SgIn  >pagedus !11_S	et	f	\N
184147	tõsielu	tõsielu =elu  (SgN  >tõsi+elu !17_S	et	f	\N
184148	tõsielu	tõsielu =elu  (SgG  >tõsi+elu !17_S	et	f	\N
184149	tõsielu	tõsielu =elu  (SgP  >tõsi+elu !17_S	et	f	\N
184151	tegevusesse	tegevusesse =tegevuse  (SgIll  >tegevus !11_S	et	f	\N
184152	tegevusesse	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
184153	tegevusesse	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
184154	tegevusesse	tegevusesse =tegevuses  (SgAdt  >tegevusene !12_A	et	f	\N
184155	tegevusesse	"tegevusene %tegevuse  )NE_aA  <tegevus ;11_S	et	f	\N
184156	tegevusesse	tegevusesse =use  (PlIll  >tegev+usk !22_S	et	f	\N
184163	topeltmängu	topeltmängu =mängu  (SgG  >topelt+mäng !22_S	et	f	\N
184164	topeltmängu	topeltmängu =mängu  (SgP  >topelt+mäng !22_S	et	f	\N
184165	topeltmängu	topeltmängu =mängu  (SgAdt  >topelt+mäng !22_S	et	f	\N
184168	okupeeri	okupeeri =okupeeri  (IndPrPs_  >okupeerima !28_V	et	f	\N
184169	okupeeri	okupeeri =okupeeri  (ImpPrSg2  >okupeerima !28_V	et	f	\N
184202	varemetel	varemetel =vareme  (PlAd  >vare !04_S	et	f	\N
184203	varemetel	varemetel =e  (PlAd  >varem+esi !15_S	et	f	\N
184204	afääri	afääri =afääri  (SgG  >afäär !22_S	et	f	\N
184205	afääri	afääri =afääri  (SgP  >afäär !22_S	et	f	\N
184206	afääri	afääri =afääri  (SgAdt  >afäär !22_S	et	f	\N
184209	igaltpoolt	?igaltpoolt =igaltpoo  (SgAbl  >igaltpoo !26_S	et	f	\N
184233	õigusteteaduskonnas	õigusteteaduskonnas =konna  (SgIn  >õiguste+teadus+konn !22_S	et	f	\N
184234	õigusteteaduskonnas	õigusteteaduskonnas =teaduskonna  (SgIn  >õiguste+teaduskond !22_S	et	f	\N
184241	kõigeks	kõigeks =kõige  (SgTr  >kõik !00_P	et	f	\N
184242	kõigeks	kõigeks =kõige  (PlTr  >kõik !22_S	et	f	\N
184268	pujändi	?pujändi =pujändi  (SgN  >pujändi !01_S	et	f	\N
184269	pujändi	?pujändi =pujändi  (SgG  >pujändi !01_S	et	f	\N
184270	pujändi	?pujändi =pujändi  (SgG  >pujänd !02_S	et	f	\N
184271	pujändi	?pujändi =pujändi  (SgG  >pujänt !22_S	et	f	\N
184272	pujändi	?pujändi =pujändi  (IndPrPs_  >pujäntima !28_V	et	f	\N
184273	pujändi	?pujändi =pujändi  (ImpPrSg2  >pujäntima !28_V	et	f	\N
184274	lenineid	?lenineid =lenine  (PlP  >lenin !02_S	et	f	\N
184275	lenineid	?lenineid =leninei  (PlN  >leninei !26_S	et	f	\N
184276	lenineid	?lenineid =leninei  (SgP  >leninei !26_S	et	f	\N
184295	sunorukovi	?sunorukovi =sunorukovi  (ID  >sunorukovi !41_D	et	f	\N
184296	sunorukovi	?sunorukovi =sunorukovi  (SgG  >sunorukov !02_A	et	f	\N
184301	meenugi	meenugi =meenu  (IndPrPs_^  >meenuma !27_V	et	f	\N
184302	meenugi	meenugi =meenu  (ImpPrSg2^  >meenuma !27_V	et	f	\N
184331	vagivalla	?vagivalla =vagivalla  (SgN  >vagivalla !16_S	et	f	\N
184332	vagivalla	?vagivalla =vagivalla  (SgG  >vagivalla !16_S	et	f	\N
184337	abiellunud	abiellunud =ellu  (PtsPtPs  >abi+elluma !27_V	et	f	\N
184338	abiellunud	abiellunud =ellunu  (PlN  >abi+ellunu !01_S	et	f	\N
184339	saavutanudki	saavutanudki =saavuta  (PtsPtPs^  >saavutama !27_V	et	f	\N
184340	saavutanudki	saavutanudki =saavutanu  (PlN^  >saavutanu !01_S	et	f	\N
183936	sotsialistlikus	sotsialistlikus =sotsialistlikus  (SgN  >sotsialistlikus !11?09_S	et	f	\N
183937	sotsialistlikus	"sotsialistlikus %sotsialistliku  )US_aS  <sotsialistlik ;25_A	et	f	\N
183940	jõukuse	jõukuse =jõukuse  (SgG  >jõukus !11~09_S	et	f	\N
183941	jõukuse	"jõukus %jõuka  )US_aS  <jõukas ;02_A	et	f	\N
183943	jõukuse	jõukuse =kuse  (SgG  >jõu+kusi !20_S	et	f	\N
183957	mülleri	?mülleri =mülleri  (SgN  >mülleri !01_S	et	f	\N
183958	mülleri	?mülleri =mülleri  (SgG  >mülleri !01_S	et	f	\N
183959	mülleri	?mülleri =mülleri  (SgG  >müller !02_S	et	f	\N
183960	uuriks	uuriks =uuri  (SgTr  >uur !22_S	et	f	\N
183961	uuriks	uuriks =uuri  (KndPrPs  >uurima !28_V	et	f	\N
183976	suurriiki	suurriiki =riiki  (SgP  >suur+riik !22_S	et	f	\N
183977	suurriiki	suurriiki =riiki  (SgAdt  >suur+riik !22_S	et	f	\N
183980	käipide	?käipide =käipi  (PlG  >käip !22_S	et	f	\N
183984	leninist	?leninist =lenini  (SgEl  >lenin !02_S	et	f	\N
183985	leninist	?leninist =leninis  (SgP  >leninis !11_S	et	f	\N
183986	leninist	?leninist =leninist  (SgN  >leninist !22_S	et	f	\N
183997	pseudoajalooline	pseudoajalooline =looline  (SgN  >pseudo+aja+looline !12?10_A	et	f	\N
183998	pseudoajalooline	"pseudo+aja+looline %loo  )LINE_aA  <pseudo+aja+lugu ;18_S	et	f	\N
183999	pseudoajalooline	"pseudo+aja+looline %loo  )LINE_aA  <pseudo+aja+loog ;22_S	et	f	\N
184000	pseudoajalooline	"pseudo+aja+looline %loo  )LINE_aA  <pseudo+aja+lood ;22_S	et	f	\N
184001	pseudoajalooline	pseudoajalooline =looline  (SgN  >pseudo+aja+looline !12?10_S	et	f	\N
184002	ajalood	ajalood =loo  (PlN  >aja+lugu !18_S	et	f	\N
184003	ajalood	ajalood =loo  (PlN  >aja+loog !22_S	et	f	\N
184004	ajalood	ajalood =loo  (PlN  >aja+lood !22_S	et	f	\N
184005	ajalood	ajalood =lood  (SgN  >aja+lood !22_S	et	f	\N
184014	plaaniks	plaaniks =plaani  (SgTr  >plaan !22_S	et	f	\N
184015	plaaniks	plaaniks =plaani  (KndPrPs  >plaanima !28_V	et	f	\N
184021	intelektuaalse	?intelektuaalse =intelektuaalse  (SgG  >intelektuaalne !02_A	et	f	\N
184022	intelektuaalse	?intelektuaalse =intelektuaalse  (PlP  >intelektuaals !22_S	et	f	\N
184072	võitjad	võitjad =võitja  (PlN  >võitja !01_S	et	f	\N
184073	võitjad	"võitja %võit  )JA_vS  <võitma ;34_V	et	f	\N
184089	zürichi	?zürichi =zürichi  (SgN  >zürichi !01_S	et	f	\N
184090	zürichi	?zürichi =zürichi  (SgG  >zürichi !01_S	et	f	\N
184091	zürichi	?zürichi =zürichi  (SgG  >zürich !22_S	et	f	\N
184092	zürichi	?zürichi =zürichi  (SgP  >zürich !22_S	et	f	\N
184093	zürichi	?zürichi =zürichi  (SgAdt  >zürich !22_S	et	f	\N
184103	ajaloolises	ajaloolises =loolise  (SgIn  >aja+looline !12?10_A	et	f	\N
184104	ajaloolises	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
184105	ajaloolises	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
184106	ajaloolises	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
184108	ajaloolises	ajaloolises =loolise  (SgIn  >aja+looline !12?10_S	et	f	\N
184114	leninlikkuse	leninlikkuse =leninlikkuse  (SgG  >leninlikkus !11~09_S	et	f	\N
184115	leninlikkuse	"leninlikkus %leninlikku  )US_aS  <leninlik ;25_A	et	f	\N
184126	arusaamatud	arusaamatud =saamatu  (PlN  >aru+saamatu !01_A	et	f	\N
184127	arusaamatud	"aru+saamatu %saama  )TU2_kA  <aru+saam ;22_S	et	f	\N
184140	rumalusteks	rumalusteks =rumalus  (PlTr  >rumalus !11_S	et	f	\N
184141	rumalusteks	"rumalus %rumala  )US_aS  <rumal ;02_A	et	f	\N
184166	kinnis-idee	kinnis-idee =idee  (SgN  >kinnis-idee !26_S	et	f	\N
184167	kinnis-idee	kinnis-idee =idee  (SgG  >kinnis-idee !26_S	et	f	\N
184177	sooemaid	?sooemaid =sooemai  (PlN  >sooemai !26_S	et	f	\N
184178	sooemaid	?sooemaid =sooemai  (SgP  >sooemai !26_S	et	f	\N
184179	sooemaid	?sooemaid =emai  (PlN  >soo+emai !26_S	et	f	\N
184180	sooemaid	?sooemaid =emai  (SgP  >soo+emai !26_S	et	f	\N
184181	sooemaid	?sooemaid =emaid  (SgN  >soo+emaid !22_S	et	f	\N
184186	revolutsioonilised	revolutsioonilised =revolutsioonilise  (PlN  >revolutsiooniline !12_A	et	f	\N
184187	revolutsioonilised	"revolutsiooniline %revolutsiooni  )LINE_aA  <revolutsioon ;22_S	et	f	\N
184190	tänapäevased	tänapäevased =päevase  (PlN  >täna+päevane !10_A	et	f	\N
184191	tänapäevased	"täna+päevane %päeva  )NE_aA  <täna+päev ;22_S	et	f	\N
184201	balanseerib	?balanseerib =balanseeri  (IndPrSg3  >balanseerima !28_V	et	f	\N
184207	valitsused	valitsused =valitsuse  (PlN  >valitsus !11_S	et	f	\N
184208	valitsused	"valitsus %valitse  )US_vS  <valitsema ;27_V	et	f	\N
184220	impulsiivselt	impulsiivselt =impulsiivse  (SgAbl  >impulsiivne !02_A	et	f	\N
184221	impulsiivselt	impulsiivselt =impulsiivselt  (ID  >impulsiivselt !41_D	et	f	\N
184222	impulsiivselt	"impulsiivselt %impulsiivse  )LT_mD  <impulsiivne ;02_A	et	f	\N
184229	arusaamatutest	arusaamatutest =tute  (PlEl  >aru+saama+tutt !22_S	et	f	\N
184230	arusaamatutest	arusaamatutest =saamatu  (PlEl  >aru+saamatu !01_A	et	f	\N
184231	arusaamatutest	"aru+saamatu %saama  )TU2_kA  <aru+saam ;22_S	et	f	\N
184235	ideetele	?ideetele =ideete  (SgAll  >ideete !16_S	et	f	\N
184236	ideetele	?ideetele =ideetele  (IndPrPs_  >ideetelema !36_V	et	f	\N
184237	ideetele	?ideetele =ideetele  (ImpPrSg2  >ideetelema !36_V	et	f	\N
184238	rüppes	?rüppes =rüppe  (SgIn  >rüpe !06_S	et	f	\N
184239	rüppes	?rüppes =rüppe  (IndIpfSg3  >rüppema !27_V	et	f	\N
184240	rüppes	?rüppes =rüppes  (SgN  >rüppes !09_S	et	f	\N
184049	ristinud	"ristinud %risti  )NUD_vA  <ristima ;28_V	et	f	\N
184080	dorpati	?dorpati =dorpati  (ID  >dorpati !41_D	et	f	\N
184081	dorpati	?dorpati =dorpati  (SgG  >dorpat !02_S	et	f	\N
184082	dorpati	?dorpati =dorpati  (SgG  >dorpatt !22_S	et	f	\N
184083	dorpati	?dorpati =dorpati  (IndPrPs_  >dorpattima !28_V	et	f	\N
184084	dorpati	?dorpati =dorpati  (ImpPrSg2  >dorpattima !28_V	et	f	\N
184107	komöödias	komöödias =komöödia  (SgIn  >komöödia !01_S	et	f	\N
184109	komöödias	komöödias =dia  (SgIn  >kom+öö+dia !26_S	et	f	\N
184121	programmis	programmis =programmi  (SgIn  >programm !22_S	et	f	\N
184122	programmis	programmis =programmi  (IndIpfSg3  >programmima !28_V	et	f	\N
184128	kehastavad	kehastavad =kehasta  (IndPrPl3  >kehastama !27_V	et	f	\N
184129	kehastavad	kehastavad =kehastava  (PlN  >kehastav !02_A	et	f	\N
184130	kehastavad	"kehastav %kehasta  )V_vA  <kehastama ;27_V	et	f	\N
184131	isikutel	isikutel =isiku  (PlAd  >isik !02_S	et	f	\N
184132	isikutel	isikutel =ute  (SgAd  >isik+utt !22_S	et	f	\N
184133	isikutel	isikutel =ute  (PlAd  >isik+utt !22_S	et	f	\N
184142	huvitavaimaks	huvitavaimaks =huvitavaima  (SgTr  >huvitavaim !02_A	et	f	\N
184143	huvitavaimaks	"huvitavaim %huvitava  )IM_sA  <huvitav ;02_A	et	f	\N
184144	huvitavaimaks	huvitavaimaks =ima  (SgTr  >huvi+tava+ima !17_S	et	f	\N
184150	sundib	?sundib =sundi  (IndPrSg3  >suntima !28_V	et	f	\N
184157	variseks	variseks =varise  (SgTr  >varis !09_S	et	f	\N
184158	variseks	variseks =varise  (KndPrPs  >varisema !27_V	et	f	\N
184159	variseks	variseks =seks  (SgN  >vari+seks !22_S	et	f	\N
184160	hukkumisele	hukkumisele =hukkumise  (SgAll  >hukkumine !12_S	et	f	\N
184161	hukkumisele	"hukkumine %hukku  )MINE_vS  <hukkuma ;27_V	et	f	\N
184162	hukkumisele	"hukkumine %hukku  )MINE_vS  <hukkuma ;28_V	et	f	\N
184192	infarkti	infarkti =infarkti  (SgG  >infarkt !22_S	et	f	\N
184193	infarkti	infarkti =infarkti  (SgP  >infarkt !22_S	et	f	\N
184194	infarkti	infarkti =infarkti  (SgAdt  >infarkt !22_S	et	f	\N
184199	keskülat	?keskülat =kesküla  (SgP  >kesküla !01_S	et	f	\N
184200	keskülat	?keskülat =ülat  (SgN  >kesk+ülat !02_S	et	f	\N
184210	räägimata	?räägimata =räägi  (SupAb  >räägima !28_V	et	f	\N
184211	räägimata	?räägimata =räägima  (SgAb  >räägim !02_A	et	f	\N
184212	räägimata	?räägimata =räägimata  (ID  >räägimata !41_A	et	f	\N
184213	räägimata	?räägimata =räägimata  (IndPrPs_  >räägimatama !27_V	et	f	\N
184214	räägimata	?räägimata =räägimata  (ImpPrSg2  >räägimatama !27_V	et	f	\N
184223	sobisid	sobisid =sobi  (PlP  >sobi !17_S	et	f	\N
184224	sobisid	sobisid =sobi  (IndIpfSg2  >sobima !27_V	et	f	\N
184225	sobisid	sobisid =sobi  (IndIpfPl3  >sobima !27_V	et	f	\N
184232	momendidest	?momendidest =momendides  (SgP  >momendidene !12_A	et	f	\N
184248	tõepäraseks	tõepäraseks =seks  (SgN  >tõe+pära+seks !22_S	et	f	\N
184249	tõepäraseks	tõepäraseks =pärase  (SgTr  >tõe+pärane !10_A	et	f	\N
184250	tõepäraseks	"tõe+pärane %pära  )NE_aA  <tõe+pära ;17_S	et	f	\N
184277	vürtsi	vürtsi =vürtsi  (SgG  >vürts !22_S	et	f	\N
184278	vürtsi	vürtsi =vürtsi  (SgP  >vürts !22_S	et	f	\N
184279	vürtsi	vürtsi =vürtsi  (SgAdt  >vürts !22_S	et	f	\N
184290	mängitud	mängitud =mängi  (PtsPtIps  >mängima !28_V	et	f	\N
184291	mängitud	mängitud =mängitu  (PlN  >mängitu !01_AS	et	f	\N
184292	mängitud	"mängitu %mängi  )TU1_vS  <mängima ;28_V	et	f	\N
184293	mängitud	mängitud =mängitud  (ID  >mängitud !41_A	et	f	\N
184294	mängitud	"mängitud %mängi  )TUD_vA  <mängima ;28_V	et	f	\N
184303	avastamisrõõmu	avastamisrõõmu =rõõmu  (SgG  >avastamis+rõõm !22_S	et	f	\N
184304	avastamisrõõmu	avastamisrõõmu =rõõmu  (SgP  >avastamis+rõõm !22_S	et	f	\N
184305	avastamisrõõmu	avastamisrõõmu =rõõmu  (SgAdt  >avastamis+rõõm !22_S	et	f	\N
184313	purustatud	purustatud =purusta  (PtsPtIps  >purustama !27_V	et	f	\N
184314	purustatud	purustatud =purustatu  (PlN  >purustatu !01_S	et	f	\N
184315	purustatud	"purustatu %purusta  )TU1_vS  <purustama ;27_V	et	f	\N
184316	purustatud	purustatud =purustatud  (ID  >purustatud !41_A	et	f	\N
184317	purustatud	"purustatud %purusta  )TUD_vA  <purustama ;27_V	et	f	\N
184318	katastroofiliseks	katastroofiliseks =katastroofilise  (SgTr  >katastroofiline !12_A	et	f	\N
184319	katastroofiliseks	"katastroofiline %katastroofi  )LINE_aA  <katastroof ;22_S	et	f	\N
184366	ajajärgudel	### ajajärgudel	et	f	\N
184367	avanevad	avanevad =avane  (IndPrPl3  >avanema !27_V	et	f	\N
184368	avanevad	avanevad =avaneva  (PlN  >avanev !02_A	et	f	\N
184369	avanevad	"avanev %avane  )V_vA  <avanema ;27_V	et	f	\N
184370	varjata	varjata =varja  (SgAb  >vari !24_S	et	f	\N
184371	varjata	varjata =varja  (Inf  >varjama !29_V	et	f	\N
184372	varjata	varjata =varja  (IndPrIps_  >varjama !29_V	et	f	\N
184398	muutubgi	?muutubgi =muutubgi  (SgN  >muutubgi !01_S	et	f	\N
184399	muutubgi	?muutubgi =muutubgi  (SgG  >muutubgi !01_S	et	f	\N
184400	muutubgi	?muutubgi =muutubgi  (SgG  >muutubg !02_S	et	f	\N
184401	muutubgi	?muutubgi =muutubgi  (IndPrPs_  >muutubgima !28_V	et	f	\N
184402	muutubgi	?muutubgi =muutubgi  (ImpPrSg2  >muutubgima !28_V	et	f	\N
184403	muutubgi	?muutubgi =tubgi  (SgN  >muu+tubgi !16_S	et	f	\N
184404	muutubgi	?muutubgi =tubgi  (SgG  >muu+tubgi !16_S	et	f	\N
184061	minuseid	?minuseid =sei  (PlN  >minu+sei !26_S	et	f	\N
184062	minuseid	?minuseid =sei  (SgP  >minu+sei !26_S	et	f	\N
184063	minuseid	?minuseid =seid  (SgN  >minu+seid !22_S	et	f	\N
184064	haitada	?haitada =haita  (Inf  >haitama !27_V	et	f	\N
184069	loodeosa	loodeosa =osa  (SgN  >loode+osa !17_S	et	f	\N
184070	loodeosa	loodeosa =osa  (SgG  >loode+osa !17_S	et	f	\N
184071	loodeosa	loodeosa =osa  (SgP  >loode+osa !17_S	et	f	\N
184085	illegaalselt	illegaalselt =illegaalse  (SgAbl  >illegaalne !02_A	et	f	\N
184086	illegaalselt	illegaalselt =illegaalselt  (ID  >illegaalselt !41_D	et	f	\N
184087	illegaalselt	"illegaalselt %illegaalse  )LT_mD  <illegaalne ;02_A	et	f	\N
184088	leipzigi	?leipzigi =leipzi  (ID^  >leipzi !41_D	et	f	\N
184094	berne	?berne =berne  (SgN  >berne !06_S	et	f	\N
184095	berne	?berne =berne  (SgG  >berne !06_S	et	f	\N
184096	berne	?berne =berne  (PlP  >bern !22_S	et	f	\N
184097	berne	?berne =berne  (IndPrPs_  >bernema !27_V	et	f	\N
184098	berne	?berne =berne  (ImpPrSg2  >bernema !27_V	et	f	\N
184099	fiks	?fiks =fiks  (SgN  >fiks !22_S	et	f	\N
184101	hispaanias	?hispaanias =hispaania  (SgIn  >hispaania !01_S	et	f	\N
184102	hispaanias	?hispaanias =hispaanias  (SgN  >hispaanias !11_S	et	f	\N
184123	revolütsionäärist	?revolütsionäärist =revolütsionääri  (SgEl  >revolütsionääri !16_S	et	f	\N
184124	revolütsionäärist	?revolütsionäärist =revolütsionääri  (SgEl  >revolütsionäär !22_S	et	f	\N
184125	revolütsionäärist	?revolütsionäärist =revolütsionääris  (SgP  >revolütsionääris !09_S	et	f	\N
184134	raisku	raisku =raisku  (ID  >raisku !41_D	et	f	\N
184135	raisku	raisku =raisku  (SgP  >raisk !22_S	et	f	\N
184136	raisku	raisku =raisku  (SgAdt  >raisk !22_S	et	f	\N
184137	raisku	raisku =raisku  (PlP  >raisk !22_S	et	f	\N
184138	raisku	raisku =raisku  (IndPrPs_  >raiskuma !27_V	et	f	\N
184139	raisku	raisku =raisku  (ImpPrSg2  >raiskuma !27_V	et	f	\N
184170	vaimustavalt	vaimustavalt =vaimustava  (SgAbl  >vaimustav !02_A	et	f	\N
184171	vaimustavalt	"vaimustav %vaimusta  )V_vA  <vaimustama ;27_V	et	f	\N
184172	vaimustavalt	vaimustavalt =vaimustavalt  (ID  >vaimustavalt !41_D	et	f	\N
184173	vaimustavalt	"vaimustavalt %vaimusta  )VALT_mD  <vaimustama ;27_V	et	f	\N
184174	vaimustavalt	"vaimustavalt %vaimustava  )LT_mD  <vaimustav ;02_A	et	f	\N
184175	vaimustavalt	vaimustavalt =ustava  (SgAbl  >vaim+ustav !02_A	et	f	\N
184176	vaimustavalt	"vaim+ustavalt %ustava  )LT_mD  <vaim+ustav ;02_A	et	f	\N
184182	uhkuse	uhkuse =uhkuse  (SgG  >uhkus !11~09_S	et	f	\N
184183	uhkuse	"uhkus %uhke  )US_aS  <uhke ;01_A	et	f	\N
184215	zinovjevi	?zinovjevi =zinovjevi  (ID  >zinovjevi !41_D	et	f	\N
184216	zinovjevi	?zinovjevi =zinovjevi  (SgG  >zinovjev !02_A	et	f	\N
184217	trükikotta	trükikotta =kotta  (SgP  >trüki+kott !22_S	et	f	\N
184218	trükikotta	trükikotta =kotta  (SgAdt  >trüki+koda !18_S	et	f	\N
184219	trükikotta	trükikotta =kotta  (SgAdt  >trüki+kott !22_S	et	f	\N
184251	paroodia	paroodia =paroodia  (SgN  >paroodia !01_S	et	f	\N
184252	paroodia	paroodia =paroodia  (SgG  >paroodia !01_S	et	f	\N
184253	oktoobrirevolutsiooni	oktoobrirevolutsiooni =revolutsiooni  (SgG  >oktoobri+revolutsioon !22_S	et	f	\N
184254	oktoobrirevolutsiooni	oktoobrirevolutsiooni =revolutsiooni  (SgP  >oktoobri+revolutsioon !22_S	et	f	\N
184255	oktoobrirevolutsiooni	oktoobrirevolutsiooni =revolutsiooni  (SgAdt  >oktoobri+revolutsioon !22_S	et	f	\N
184256	annetatud	annetatud =anneta  (PtsPtIps  >annetama !27_V	et	f	\N
184257	annetatud	annetatud =annetatu  (PlN  >annetatu !01_S	et	f	\N
184258	annetatud	"annetatu %anneta  )TU1_vS  <annetama ;27_V	et	f	\N
184259	annetatud	annetatud =annetatud  (ID  >annetatud !41_A	et	f	\N
184260	annetatud	"annetatud %anneta  )TUD_vA  <annetama ;27_V	et	f	\N
184263	sündmustikust	sündmustikust =sündmustiku  (SgEl  >sündmustik !25_S	et	f	\N
184264	sündmustikust	sündmustikust =sündmustikus  (SgP  >sündmustikune !10?12_A	et	f	\N
184265	sündmustikust	"sündmustikune %sündmustiku  )NE_aA  <sündmustik ;25_S	et	f	\N
184266	sündmustikust	sündmustikust =tiku  (SgEl  >sündmus+tikk !22_S	et	f	\N
184267	sündmustikust	sündmustikust =tiku  (PlEl  >sündmus+tikk !22_S	et	f	\N
184285	perfektselt	perfektselt =perfektse  (SgAbl  >perfektne !02_A	et	f	\N
184286	perfektselt	perfektselt =perfektselt  (ID  >perfektselt !41_D	et	f	\N
184287	perfektselt	"perfektselt %perfektse  )LT_mD  <perfektne ;02_A	et	f	\N
184297	leninina	?leninina =lenini  (SgEs  >lenin !02_S	et	f	\N
184298	leninina	?leninina =leninina  (SgG  >leninin !19_S	et	f	\N
184299	leninina	?leninina =leninina  (SgP  >leninin !19_S	et	f	\N
184300	leninina	?leninina =leninina  (SgAdt  >leninin !19_S	et	f	\N
184311	iroonia	iroonia =iroonia  (SgN  >iroonia !01_S	et	f	\N
184312	iroonia	iroonia =iroonia  (SgG  >iroonia !01_S	et	f	\N
184333	usaldasid	usaldasid =usalda  (IndIpfSg2  >usaldama !27_V	et	f	\N
184334	usaldasid	usaldasid =usalda  (IndIpfPl3  >usaldama !27_V	et	f	\N
184344	nadja	?nadja =nadja  (SgN  >nadja !16_S	et	f	\N
184345	nadja	?nadja =nadja  (SgG  >nadjas !02_A	et	f	\N
184346	nadja	?nadja =nadja  (SgG  >nadja !16_S	et	f	\N
184347	nadja	?nadja =nadja  (IndPrPs_  >nadjama !27_V	et	f	\N
184348	nadja	?nadja =nadja  (ImpPrSg2  >nadjama !27_V	et	f	\N
184349	vangijatest	?vangijatest =vangija  (PlEl  >vangija !01_S	et	f	\N
184243	võitleja	võitleja =võitleja  (SgN  >võitleja !01_SA	et	f	\N
184244	võitleja	"võitleja %võitle  )JA_vS  <võitlema ;30_V	et	f	\N
184245	võitleja	võitleja =võitleja  (SgG  >võitleja !01_SA	et	f	\N
184246	professionaalsust	professionaalsust =professionaalsus  (SgP  >professionaalsus !11~09_S	et	f	\N
184247	professionaalsust	"professionaalsus %professionaalse  )US_aS  <professionaalne ;02_A	et	f	\N
184306	komöödiline	?komöödiline =komöödiline  (SgN  >komöödiline !12_A	et	f	\N
184307	komöödiline	?komöödiline =komöödiline  (PlP  >komöödilin !19_S	et	f	\N
184308	komöödiline	?komöödiline =diline  (SgN  >kom+öö+diline !10_A	et	f	\N
184309	komöödiline	?komöödiline =öödiline  (SgN  >kom+öödiline !12_A	et	f	\N
184310	komöödiline	?komöödiline =öödiline  (PlP  >kom+öödilin !19_S	et	f	\N
184325	tunnistanud	tunnistanud =tunnista  (PtsPtPs  >tunnistama !27_V	et	f	\N
184326	tunnistanud	tunnistanud =tunnistanu  (PlN  >tunnistanu !01_S	et	f	\N
184327	tunnistanud	"tunnistanu %tunnista  )NU_vS  <tunnistama ;27_V	et	f	\N
184328	tunnistanud	tunnistanud =tunnistanud  (ID  >tunnistanud !41_A	et	f	\N
184329	tunnistanud	"tunnistanud %tunnista  )NUD_vA  <tunnistama ;27_V	et	f	\N
184330	tunnistanud	tunnistanud =tanu  (PlN  >tunnis+tanu !17_S	et	f	\N
184362	möödunust	möödunust =möödunu  (SgEl  >möödunu !01_S	et	f	\N
184363	möödunust	"möödunu %möödu  )NU_vS  <mööduma ;27_V	et	f	\N
184364	tõlgendamine	tõlgendamine =tõlgendamine  (SgN  >tõlgendamine !12_S	et	f	\N
184365	tõlgendamine	"tõlgendamine %tõlgenda  )MINE_vS  <tõlgendama ;27_V	et	f	\N
184381	subjektiivsemalt	subjektiivsemalt =subjektiivsema  (SgAbl  >subjektiivsem !02_A	et	f	\N
184382	subjektiivsemalt	"subjektiivsem %subjektiivse  )M_cA  <subjektiivne ;02_A	et	f	\N
184383	subjektiivsemalt	subjektiivsemalt =subjektiivsemalt  (ID  >subjektiivsemalt !41_D	et	f	\N
184384	subjektiivsemalt	"subjektiivsemalt %subjektiivse  )MALT_mD  <subjektiivne ;02_A	et	f	\N
184464	valmistuseks	valmistuseks =valmistuse  (SgTr  >valmistus !11_S	et	f	\N
184465	valmistuseks	"valmistus %valmista  )US_vS  <valmistama ;27_V	et	f	\N
184483	külapoodis	?külapoodis =külapoodi  (SgIn  >külapoodi !16_S	et	f	\N
184484	külapoodis	?külapoodis =külapoodi  (SgIn  >külapoot !22_S	et	f	\N
184485	külapoodis	?külapoodis =külapoodi  (IndIpfSg3  >külapoodima !28_V	et	f	\N
184486	külapoodis	?külapoodis =külapoodis  (SgN  >külapoodis !09_S	et	f	\N
184487	külapoodis	?külapoodis =poodi  (SgIn  >küla+poodi !16_S	et	f	\N
184488	külapoodis	?külapoodis =poodis  (SgN  >küla+poodis !09_S	et	f	\N
184498	tahtmisega	tahtmisega =tahtmise  (SgKom  >tahtmine !12?10_S	et	f	\N
184499	tahtmisega	"tahtmine %taht  )MINE_vS  <tahtma ;34_V	et	f	\N
184522	naiselikumad	naiselikumad =naiselikuma  (PlN  >naiselikum !02_A	et	f	\N
184523	naiselikumad	"naiselikum %naiseliku  )M_cA  <naiselik ;25_A	et	f	\N
184526	tagajargi	?tagajargi =tagajargi  (SgG  >tagajark !22_S	et	f	\N
184528	tagajargi	?tagajargi =tagajargi  (SgP  >tagajarg !22_S	et	f	\N
184530	tagajargi	?tagajargi =tagajargi  (SgAdt  >tagajarg !22_S	et	f	\N
184531	tagajargi	?tagajargi =tagajargi  (IndPrPs_  >tagajarkima !28_V	et	f	\N
184534	tagajargi	?tagajargi =tagajargi  (ImpPrSg2  >tagajarkima !28_V	et	f	\N
184535	tagajargi	?tagajargi =jargi  (SgG  >taga+jark !22_S	et	f	\N
184536	tagajargi	?tagajargi =jargi  (SgP  >taga+jarg !22_S	et	f	\N
184537	tagajargi	?tagajargi =jargi  (SgAdt  >taga+jarg !22_S	et	f	\N
184538	tagajargi	?tagajargi =tagajar  (SgN^  >tagajar !19_S	et	f	\N
184545	aparadiks	### aparadiks	et	f	\N
184549	muudatusedes	### muudatusedes	et	f	\N
184559	salve	salve =salve  (SgG  >salv !22_S	et	f	\N
184560	salve	salve =salve  (SgP  >salv !22_S	et	f	\N
184561	salve	salve =salve  (SgAdt  >salv !22_S	et	f	\N
184562	salve	salve =salve  (PlP  >salv !22_S	et	f	\N
184574	tohtnud	?tohtnud =tohtnu  (PlN  >tohtnu !01_S	et	f	\N
184575	tohtnud	?tohtnud =tohtnu  (IndPrSg2  >tohtnuma !27_V	et	f	\N
184576	tohtnud	?tohtnud =tohtnud  (ID  >tohtnud !41_A	et	f	\N
184600	varahmmikust	?varahmmikust =varahmmiku  (SgEl  >varahmmik !25_S	et	f	\N
184601	varahmmikust	?varahmmikust =varahmmikus  (SgP  >varahmmikus !11?09_S	et	f	\N
184612	soomist	?soomist =soomi  (SgEl  >soomi !16_S	et	f	\N
184613	soomist	?soomist =soomi  (SgEl  >soom !22_S	et	f	\N
184614	soomist	?soomist =soomis  (SgP  >soomis !09_S	et	f	\N
184615	soomist	?soomist =soomis  (SgP  >soomine !10_A	et	f	\N
184616	soomist	?soomist =soomist  (SgN  >soomist !22_S	et	f	\N
184619	siiruviiruline	?siiruviiruline =siiruviiruline  (SgN  >siiruviiruline !12_A	et	f	\N
184620	siiruviiruline	?siiruviiruline =siiruviiruline  (PlP  >siiruviirulin !19_S	et	f	\N
184625	lausab	?lausab =lausa  (IndPrSg3  >lausama !29_V	et	f	\N
184629	vaatamiseaega	?vaatamiseaega =vaatamiseae  (SgKom  >vaatamiseae !26_S	et	f	\N
184630	töökohaga	töökohaga =koha  (SgKom  >töö+koha !17_S	et	f	\N
184631	töökohaga	töökohaga =koha  (SgKom  >töö+koht !22_S	et	f	\N
184640	väikestel	väikestel =väikes  (PlAd  >väike !12?10_A	et	f	\N
184641	väikestel	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
184642	väikestel	väikestel =väikes  (PlAd  >väikene !12?10_A	et	f	\N
184643	väikestel	"väikene %väi  )KENE_dS  <väi ;26_S	et	f	\N
184644	väikestel	väikestel =keste  (SgAd  >väi+keste !06_S	et	f	\N
184282	lenitele	?lenitele =lenitele  (ImpPrSg2  >lenitelema !36_V	et	f	\N
184283	teisikuteist	teisikuteist =te  (PlEl  >teisiku+tee !26_S	et	f	\N
184284	teisikuteist	teisikuteist =teist  (SgN  >teisiku+teist !22_S	et	f	\N
184288	nauditavaks	nauditavaks =nauditava  (SgTr  >nauditav !02_A	et	f	\N
184289	nauditavaks	"nauditav %naudi  )TAV_vAS  <nautima ;28_V	et	f	\N
184320	nulli	nulli =nulli  (SgG  >null !22_NS	et	f	\N
184321	nulli	nulli =nulli  (SgP  >null !22_NS	et	f	\N
184322	nulli	nulli =nulli  (SgAdt  >null !22_NS	et	f	\N
184323	nulli	nulli =nulli  (IndPrPs_  >nullima !28_V	et	f	\N
184324	nulli	nulli =nulli  (ImpPrSg2  >nullima !28_V	et	f	\N
184335	ebaoluline	ebaoluline =oluline  (SgN  >eba+oluline !12_A	et	f	\N
184336	ebaoluline	"eba+oluline %olu  )LINE_aA  <eba+olu ;17_S	et	f	\N
184375	huvitanu	huvitanu =huvitanu  (SgN  >huvitanu !01_S	et	f	\N
184376	huvitanu	"huvitanu %huvita  )NU_vS  <huvitama ;27_V	et	f	\N
184377	huvitanu	huvitanu =huvitanu  (SgG  >huvitanu !01_S	et	f	\N
184378	huvitanu	huvitanu =tanu  (SgN  >huvi+tanu !17_S	et	f	\N
184379	huvitanu	huvitanu =tanu  (SgG  >huvi+tanu !17_S	et	f	\N
184380	huvitanu	huvitanu =tanu  (SgP  >huvi+tanu !17_S	et	f	\N
184385	mittehuvitanu	mittehuvitanu =tanu  (SgN  >mitte+huvi+tanu !17_S	et	f	\N
184386	mittehuvitanu	mittehuvitanu =tanu  (SgG  >mitte+huvi+tanu !17_S	et	f	\N
184387	mittehuvitanu	mittehuvitanu =tanu  (SgP  >mitte+huvi+tanu !17_S	et	f	\N
184388	mittehuvitanu	mittehuvitanu =huvitanu  (SgN  >mitte+huvitanu !01_S	et	f	\N
184389	mittehuvitanu	mittehuvitanu =huvitanu  (SgG  >mitte+huvitanu !01_S	et	f	\N
184392	mõistetu	mõistetu =mõistetu  (SgN  >mõistetu !01_S	et	f	\N
184393	mõistetu	"mõistetu %mõiste  )TU1_vS  <mõistma ;34_V	et	f	\N
184394	mõistetu	"mõistetu %mõiste  )TU2_kA  <mõiste ;06_S	et	f	\N
184395	mõistetu	mõistetu =mõistetu  (SgN  >mõistetu !01_A	et	f	\N
184396	mõistetu	mõistetu =mõistetu  (SgG  >mõistetu !01_S	et	f	\N
184397	mõistetu	mõistetu =mõistetu  (SgG  >mõistetu !01_A	et	f	\N
184412	vanaisast	vanaisast =isa  (SgEl  >vana+isa !17_S	et	f	\N
184413	vanaisast	vanaisast =isas  (SgP  >vana+isane !10_AS	et	f	\N
184414	vanaisast	"vana+isane %isa  )NE_aA  <vana+isa ;17_S	et	f	\N
184421	leenineid	?leenineid =leenine  (PlP  >leenin !02_S	et	f	\N
184422	leenineid	?leenineid =leeninei  (PlN  >leeninei !26_S	et	f	\N
184423	leenineid	?leenineid =leeninei  (SgP  >leeninei !26_S	et	f	\N
184424	leenineid	?leenineid =inei  (PlN  >leen+inei !26_S	et	f	\N
184425	leenineid	?leenineid =inei  (SgP  >leen+inei !26_S	et	f	\N
184426	leenineid	?leenineid =ineid  (SgN  >leen+ineid !22_S	et	f	\N
184439	nõrgendamises	nõrgendamises =nõrgendamise  (SgIn  >nõrgendamine !12_S	et	f	\N
184440	nõrgendamises	"nõrgendamine %nõrgenda  )MINE_vS  <nõrgendama ;27_V	et	f	\N
184441	kukutamises	kukutamises =kukutamise  (SgIn  >kukutamine !12_S	et	f	\N
184442	kukutamises	"kukutamine %kukuta  )MINE_vS  <kukutama ;27_V	et	f	\N
184451	pakunud	?pakunud =paku  (PtsPtPs  >pakuma !27_V	et	f	\N
184452	pakunud	?pakunud =pakunu  (PlN  >pakunu !01_S	et	f	\N
184453	pakunud	?pakunud =pakunu  (IndPrSg2  >pakunuma !27_V	et	f	\N
184454	pakunud	?pakunud =pakunud  (ID  >pakunud !41_A	et	f	\N
184472	kuulutusis	kuulutusis =kuulutusi  (PlIn  >kuulutus !11_S	et	f	\N
184473	kuulutusis	"kuulutus %kuuluta  )US_vS  <kuulutama ;27_V	et	f	\N
184474	kuulutusis	"kuulutus %kuulu  )TUS1_aS  <kuuluma ;27_V	et	f	\N
184475	kuulutusis	"kuulutus %kuulu  )TUS2_aS  <kuuld ;22_S	et	f	\N
184476	kuulutusis	kuulutusis =tusi  (PlIn  >kuulu+tusk !22_S	et	f	\N
184477	siberis	?siberis =siberi  (SgIn  >siberi !01_S	et	f	\N
184478	siberis	?siberis =siberi  (SgIn  >siber !02_S	et	f	\N
184479	siberis	?siberis =siberis  (SgN  >siberis !11_S	et	f	\N
184489	hingib	?hingib =hingi  (IndPrSg3  >hinkima !28_V	et	f	\N
184509	difteriat	?difteriat =difteria  (SgP  >difteria !01_S	et	f	\N
184510	difteriat	?difteriat =difteriat  (SgN  >difteriat !22_S	et	f	\N
184519	tekevad	?tekevad =teke  (IndPrPl3  >tekema !27_V	et	f	\N
184520	tekevad	?tekevad =tekeva  (PlN  >tekeva !01_S	et	f	\N
184521	tekevad	?tekevad =tekeva  (PlN  >tekev !02_A	et	f	\N
184527	soovimata	soovimata =soovi  (SupAb  >soovima !28_V	et	f	\N
184529	soovimata	soovimata =soovimata  (ID  >soovimata !41_A	et	f	\N
184532	soovimata	"soovimata %soovi  )MATA_vA  <soovima ;28_V	et	f	\N
184533	soovimata	soovimata =ima  (SgAb  >soov+ima !17_S	et	f	\N
184543	spordimine	?spordimine =spordimine  (SgN  >spordimine !12_S	et	f	\N
184544	spordimine	?spordimine =spordimine  (PlP  >spordimin !19_S	et	f	\N
184546	väiksedes	?väiksedes =väikse  (Ger  >väiksema !28_V	et	f	\N
184547	väiksedes	?väiksedes =ksede  (SgIn  >väi+ksede !16_S	et	f	\N
184548	väiksedes	?väiksedes =ksedes  (SgN  >väi+ksedes !09_S	et	f	\N
184556	kohases	kohases =kohase  (SgIn  >kohane !10_A	et	f	\N
184557	kohases	"kohane %koha  )NE_aA  <koha ;17_S	et	f	\N
184558	kohases	"kohane %koha  )NE_aA  <koht ;22_S	et	f	\N
184563	aksendi	?aksendi =aksendi  (SgN  >aksendi !01_S	et	f	\N
184564	aksendi	?aksendi =aksendi  (SgG  >aksendi !01_S	et	f	\N
184565	aksendi	?aksendi =aksendi  (SgG  >aksend !02_S	et	f	\N
184566	aksendi	?aksendi =aksendi  (SgG  >aksent !22_S	et	f	\N
184341	saavutanudki	"saavutanu %saavuta  )NU_vS^  <saavutama ;27_V	et	f	\N
184342	saavutanudki	saavutanudki =saavutanud  (ID^  >saavutanud !41_A	et	f	\N
184343	saavutanudki	"saavutanud %saavuta  )NUD_vA^  <saavutama ;27_V	et	f	\N
184356	hispaaniasse	?hispaaniasse =hispaania  (SgIll  >hispaania !01_S	et	f	\N
184357	hispaaniasse	?hispaaniasse =hispaanias  (SgAdt  >hispaanias !11_S	et	f	\N
184358	hispaaniasse	?hispaaniasse =hispaaniasse  (SgG  >hispaaniasne !02_A	et	f	\N
184359	hispaaniasse	?hispaaniasse =hispaaniasse  (PlP  >hispaaniass !22_S	et	f	\N
184360	ühelegi	ühelegi =ühe  (SgAll  >ükski !00_P	et	f	\N
184361	ühelegi	ühelegi =ühe  (SgAll^  >üks !22_NP	et	f	\N
184373	tõlgendamisega	tõlgendamisega =tõlgendamise  (SgKom  >tõlgendamine !12_S	et	f	\N
184374	tõlgendamisega	"tõlgendamine %tõlgenda  )MINE_vS  <tõlgendama ;27_V	et	f	\N
184415	lenist	?lenist =leni  (SgEl  >leni !17_S	et	f	\N
184416	lenist	?lenist =lenis  (SgP  >lenis !09_S	et	f	\N
184417	lenist	?lenist =lenist  (SgN  >lenist !22_S	et	f	\N
184418	tõedega	?tõedega =tõe  (PlKom  >tõe !26_S	et	f	\N
184419	kahtlusega	kahtlusega =kahtluse  (SgKom  >kahtlus !11~09_S	et	f	\N
184420	kahtlusega	"kahtlus %kahtlase  )US_aS  <kahtlane ;12_A	et	f	\N
184432	huvitanuid	huvitanuid =huvitanu  (PlP  >huvitanu !01_S	et	f	\N
184433	huvitanuid	"huvitanu %huvita  )NU_vS  <huvitama ;27_V	et	f	\N
184466	tagajarg	?tagajarg =tagajarg  (SgN  >tagajarg !22_S	et	f	\N
184467	tagajarg	?tagajarg =jarg  (SgN  >taga+jarg !22_S	et	f	\N
184480	jad	### jad	et	f	\N
184490	autoks	autoks =auto  (SgTr  >auto !16_S	et	f	\N
184491	autoks	autoks =toks  (SgN  >au+toks !22_S	et	f	\N
184500	jaed	?jaed =jaed  (SgN  >jaed !22_S	et	f	\N
184513	võti	võti =võti  (SgN  >võti !05_S	et	f	\N
184514	võti	võti =võti  (SgG  >võtt !22_S	et	f	\N
184517	naeratuse	naeratuse =naeratuse  (SgG  >naeratus !11_S	et	f	\N
184518	naeratuse	"naeratus %naerata  )US_vS  <naeratama ;27_V	et	f	\N
184524	mehelikumad	mehelikumad =mehelikuma  (PlN  >mehelikum !02_A	et	f	\N
184525	mehelikumad	"mehelikum %meheliku  )M_cA  <mehelik ;25_A	et	f	\N
184550	pükseid	?pükseid =pükse  (PlP  >pükne !02_A	et	f	\N
184551	pükseid	?pükseid =pükse  (PlP  >pükse !06_S	et	f	\N
184552	pükseid	?pükseid =püksei  (PlN  >püksei !26_S	et	f	\N
184553	pükseid	?pükseid =püksei  (SgP  >püksei !26_S	et	f	\N
184554	pükseid	?pükseid =pükseid  (SgN  >pükseid !22_S	et	f	\N
184555	pükseid	?pükseid =eid  (SgN  >püks+eid !22_S	et	f	\N
184577	saamas	saamas =saa  (SupIn  >saama !37_V	et	f	\N
184578	saamas	saamas =saama  (SgIn  >saam !22_S	et	f	\N
184588	salvedes	salvedes =salve  (PlIn  >salv !22_S	et	f	\N
184589	salvedes	salvedes =ede  (SgIn  >salv+ede !16_S	et	f	\N
184598	telefonist	telefonist =telefoni  (SgEl  >telefon !19_S	et	f	\N
184599	telefonist	telefonist =telefonist  (SgN  >telefonist !22_S	et	f	\N
184617	puhkajat	puhkajat =puhkaja  (SgP  >puhkaja !01_S	et	f	\N
184618	puhkajat	"puhkaja %puhka  )JA_vS  <puhkama ;29_V	et	f	\N
184646	raamatudega	?raamatudega =atu  (PlKom  >raam+atu !16_S	et	f	\N
184682	kodumaiste	kodumaiste =mais  (PlG  >kodu+maine !10_A	et	f	\N
184683	kodumaiste	"kodu+maine %mai  )NE_aA  <kodu+maa ;26_S	et	f	\N
184684	saaduste	saaduste =saadus  (PlG  >saadus !11~09_S	et	f	\N
184685	saaduste	"saadus %saa  )TUS1_aS  <saama ;37_V	et	f	\N
184694	9-klassiliseks	-klassiliseks =klassilise  (SgTr  >-klassiline !12_A	et	f	\N
184695	9-klassiliseks	"-klassiline %klassi  )LINE_aA  <-klass ;22_S	et	f	\N
184700	tööpuudust	tööpuudust =dust  (SgN  >töö+puu+dust !22_S	et	f	\N
184701	tööpuudust	tööpuudust =puudus  (SgP  >töö+puudus !11~09_S	et	f	\N
184740	tõstmist	tõstmist =tõstmis  (SgP  >tõstmine !12?10_S	et	f	\N
184741	tõstmist	"tõstmine %tõst  )MINE_vS  <tõstma ;34_V	et	f	\N
184759	õigemini	õigemini =õigemi  (SgTer  >õigem !02_A	et	f	\N
184760	õigemini	"õigem %õige  )M_cA  <õige ;01_A	et	f	\N
184761	õigemini	õigemini =õigemini  (ID  >õigemini !41_D	et	f	\N
184762	õigemini	õigemini =mi  (SgTer  >õige+mi !26_S	et	f	\N
184763	õigemini	õigemini =mini  (SgN  >õige+mini !17~16_S	et	f	\N
184764	õigemini	õigemini =mini  (SgG  >õige+mini !17~16_S	et	f	\N
184765	õigemini	õigemini =mini  (SgP  >õige+mini !17_S	et	f	\N
184766	kogumisega	kogumisega =kogumise  (SgKom  >kogumine !12_S	et	f	\N
184767	kogumisega	"kogumine %kogu  )MINE_vS  <koguma ;27_V	et	f	\N
184768	kogumisega	"kogumine %kogumi  )NE_aA  <kogum ;02_S	et	f	\N
184769	ühendamisele	ühendamisele =ühendamise  (SgAll  >ühendamine !12_S	et	f	\N
184770	ühendamisele	"ühendamine %ühenda  )MINE_vS  <ühendama ;27_V	et	f	\N
184773	pooldajaid	pooldajaid =pooldaja  (PlP  >pooldaja !01_S	et	f	\N
184774	pooldajaid	"pooldaja %poolda  )JA_vS  <pooldama ;27_V	et	f	\N
184775	tegevuste	tegevuste =tegevus  (PlG  >tegevus !11_S	et	f	\N
184776	tegevuste	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
184777	tegevuste	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
184778	tegevuste	tegevuste =us  (PlG  >tegev+uks !14_S	et	f	\N
184786	kõlbluse	kõlbluse =kõlbluse  (SgG  >kõlblus !11~09_S	et	f	\N
184787	kõlbluse	"kõlblus %kõlbla  )US_aS  <kõlblas ;02_A	et	f	\N
184791	põhimõttet	?põhimõttet =mõtte  (SgP  >põhi+mõtte !06_S	et	f	\N
184350	vangijatest	?vangijatest =vangija  (PlEl  >vangijas !02_A	et	f	\N
184351	vangijatest	?vangijatest =vangijate  (PlEl  >vangijatt !22_S	et	f	\N
184352	vangijatest	?vangijatest =vangijates  (SgP  >vangijatene !12_A	et	f	\N
184353	vangijatest	?vangijatest =jate  (PlEl  >vangi+jatt !22_S	et	f	\N
184354	vangijatest	?vangijatest =jates  (SgP  >vangi+jates !09_S	et	f	\N
184355	vangijatest	?vangijatest =jates  (SgP  >vangi+jatene !10_A	et	f	\N
184390	õiguses	õiguses =õiguse  (SgIn  >õigus !11~09_S	et	f	\N
184391	õiguses	"õigus %õige  )US_aS  <õige ;01_A	et	f	\N
184427	teoreetiliselt	teoreetiliselt =teoreetilise  (SgAbl  >teoreetiline !12_A	et	f	\N
184428	teoreetiliselt	teoreetiliselt =teoreetiliselt  (ID  >teoreetiliselt !41_D	et	f	\N
184429	teoreetiliselt	"teoreetiliselt %teoreetilise  )LT_mD  <teoreetiline ;12_A	et	f	\N
184434	üritustele	üritustele =üritus  (PlAll  >üritus !11_S	et	f	\N
184435	üritustele	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
184455	tahtmitega	?tahtmitega =tahtmi  (PlKom  >tahtmi !01_S	et	f	\N
184461	külapooes	?külapooes =külapooe  (SgIn  >külapooe !26_S	et	f	\N
184462	külapooes	?külapooes =külapooes  (SgN  >külapooes !22_S	et	f	\N
184463	külapooes	?külapooes =pooes  (SgN  >küla+pooes !02_S	et	f	\N
184468	nõudesse	nõudesse =nõu  (PlIll  >nõu !26_S	et	f	\N
184469	nõudesse	nõudesse =nõude  (SgIll  >nõue !06_S	et	f	\N
184481	kütama	?kütama =küta  (Sup  >kütama !27_V	et	f	\N
184482	kütama	?kütama =kütama  (SgG  >kütam !02_A	et	f	\N
184511	valdkonale	?valdkonale =valdkonale  (PlP  >valdkonal !19_S	et	f	\N
184512	valdkonale	?valdkonale =kona  (SgAll  >vald+kona !17_S	et	f	\N
184515	kütmisest	kütmisest =kütmise  (SgEl  >kütmine !12?10_S	et	f	\N
184516	kütmisest	"kütmine %küt  )MINE_vS  <kütma ;35_V	et	f	\N
184571	kaunivad	?kaunivad =kauni  (IndPrPl3  >kaunima !28_V	et	f	\N
184572	kaunivad	?kaunivad =kauniva  (PlN  >kauniva !01_S	et	f	\N
184573	kaunivad	?kaunivad =kauniva  (PlN  >kauniv !02_A	et	f	\N
184579	kiirest	kiirest =kiire  (SgEl  >kiire !01_A	et	f	\N
184580	kiirest	kiirest =kiire  (SgEl  >kiire !06_S	et	f	\N
184581	kiirest	kiirest =kiire  (SgEl  >kiire !06_AS	et	f	\N
184582	kiirest	kiirest =kiire  (SgEl  >kiir !13_S	et	f	\N
184583	kiirest	kiirest =kiire  (PlEl  >kiird !22_S	et	f	\N
184584	kiirest	kiirest =kiire  (PlEl  >kiir !22_S	et	f	\N
184585	kiirest	kiirest =kiires  (SgP  >kiirene !10_A	et	f	\N
184586	kiirest	"kiirene %kiire  )NE_aA  <kiire ;06_S	et	f	\N
184587	kiirest	"kiirene %kiire  )NE_aA  <kiir ;13_S	et	f	\N
184590	soovitatuid	soovitatuid =soovitatu  (PlP  >soovitatu !01_S	et	f	\N
184591	soovitatuid	"soovitatu %soovita  )TU1_vS  <soovitama ;27_V	et	f	\N
184595	tekkivaid	tekkivaid =tekkiva  (PlP  >tekkiv !02_A	et	f	\N
184596	tekkivaid	"tekkiv %tekki  )V_vA  <tekkima ;27_V	et	f	\N
184597	tekkivaid	"tekkiv %tekki  )V_vA  <tekkima ;28_V	et	f	\N
184623	mehilikumaks	?mehilikumaks =mehiliku  (SupTr  >mehilikuma !27_V	et	f	\N
184624	mehilikumaks	?mehilikumaks =mehilikuma  (SgTr  >mehilikum !02_A	et	f	\N
184637	stres	### stres	et	f	\N
184647	kütida	?kütida =küti  (Inf  >kütima !27_V	et	f	\N
184649	muudatuseid	?muudatuseid =muudatusei  (PlN  >muudatusei !26_S	et	f	\N
184650	muudatuseid	?muudatuseid =muudatusei  (SgP  >muudatusei !26_S	et	f	\N
184651	muudatuseid	?muudatuseid =atuse  (PlP  >muud+atus !09_S	et	f	\N
184652	muudatuseid	?muudatuseid =atusei  (PlN  >muud+atusei !26_S	et	f	\N
184653	muudatuseid	?muudatuseid =atusei  (SgP  >muud+atusei !26_S	et	f	\N
184654	muudatuseid	?muudatuseid =datuse  (PlP  >muu+datus !09_S	et	f	\N
184655	muudatuseid	?muudatuseid =datusei  (PlN  >muu+datusei !26_S	et	f	\N
184656	muudatuseid	?muudatuseid =datusei  (SgP  >muu+datusei !26_S	et	f	\N
184671	rahale	rahale =raha  (SgAll  >raha !17_S	et	f	\N
184672	rahale	rahale =raha  (SgAll  >rahk !22_S	et	f	\N
184692	astumiseks	astumiseks =astumise  (SgTr  >astumine !12_S	et	f	\N
184693	astumiseks	"astumine %astu  )MINE_vS  <astuma ;28_V	et	f	\N
184712	kreutzwaldiga	?kreutzwaldiga =kreutzwaldi  (SgKom  >kreutzwaldi !01_S	et	f	\N
184713	kreutzwaldiga	?kreutzwaldiga =kreutzwaldi  (SgKom  >kreutzwald !02_S	et	f	\N
184717	terviklikumaks	terviklikumaks =terviklikuma  (SgTr  >terviklikum !02_A	et	f	\N
184718	terviklikumaks	"terviklikum %tervikliku  )M_cA  <terviklik ;25_A	et	f	\N
184719	sihikindlamaks	sihikindlamaks =maks  (SgN  >sihi+kindla+maks !22_S	et	f	\N
184720	sihikindlamaks	sihikindlamaks =kindlama  (SgTr  >sihi+kindlam !02_A	et	f	\N
184721	sihikindlamaks	"sihi+kindlam %kindla  )M_cA  <sihi+kindel ;02_A	et	f	\N
184724	toovat	toovat =too  (KvtPrPs  >tooma !38_V	et	f	\N
184725	toovat	toovat =toova  (SgP  >toov !02_A	et	f	\N
184726	toovat	"toov %too  )V_vA  <tooma ;38_V	et	f	\N
184735	sunnil	sunnil =sunni  (SgAd  >sund !22_S	et	f	\N
184736	sunnil	sunnil =sunnil  (ID  >sunnil !41_K	et	f	\N
184744	kiiremale	kiiremale =kiirema  (SgAll  >kiirem !02_A	et	f	\N
184745	kiiremale	"kiirem %kiire  )M_cA  <kiire ;01_A	et	f	\N
184746	kiiremale	"kiirem %kiire  )M_cA  <kiire ;06_AS	et	f	\N
184747	kiiremale	kiiremale =male  (SgN  >kiire+male !16_S	et	f	\N
184748	kiiremale	kiiremale =male  (SgG  >kiire+male !16_S	et	f	\N
184749	kiiremale	kiiremale =ema  (SgAll  >kiir+ema !17_S	et	f	\N
184405	muutubgi	?muutubgi =tubgi  (SgG  >muu+tubg !22_S	et	f	\N
184406	muutubgi	?muutubgi =tubgi  (SgP  >muu+tubg !22_S	et	f	\N
184407	muutubgi	?muutubgi =tubgi  (SgAdt  >muu+tubg !22_S	et	f	\N
184408	asjadu	?asjadu =asjadu  (SgN  >asjadu !01_S	et	f	\N
184409	asjadu	?asjadu =asjadu  (SgG  >asjadu !01_S	et	f	\N
184410	asjadu	?asjadu =asjadu  (IndPrPs_  >asjaduma !27_V	et	f	\N
184411	asjadu	?asjadu =asjadu  (ImpPrSg2  >asjaduma !27_V	et	f	\N
184430	leenin	?leenin =leeni  (IndPrSg1  >leenima !28_V	et	f	\N
184431	leenin	?leenin =leenin  (SgN  >leenin !02_S	et	f	\N
184436	rahalisele	rahalisele =rahalise  (SgAll  >rahaline !12_A	et	f	\N
184437	rahalisele	"rahaline %raha  )LINE_aA  <raha ;17_S	et	f	\N
184438	rahalisele	"rahaline %raha  )LINE_aA  <rahk ;22_S	et	f	\N
184443	tegevustesse	tegevustesse =tegevus  (PlIll  >tegevus !11_S	et	f	\N
184444	tegevustesse	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
184445	tegevustesse	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
184446	tegevustesse	tegevustesse =us  (PlIll  >tegev+uks !14_S	et	f	\N
184447	naiivseteks	naiivseteks =naiivse  (PlTr  >naiivne !02_A	et	f	\N
184448	naiivseteks	naiivseteks =sete  (PlTr  >naiiv+sett !22_S	et	f	\N
184449	pistmist	pistmist =pistmis  (SgP  >pistmine !12?10_S	et	f	\N
184450	pistmist	"pistmine %pist  )MINE_vS  <pistma ;34_V	et	f	\N
184456	inimisi	?inimisi =inimisi  (ID  >inimisi !41_D	et	f	\N
184457	inimisi	?inimisi =inimisi  (PlP  >inimine !12_S	et	f	\N
184458	inimisi	?inimisi =isi  (SgN  >inim+isi !17_S	et	f	\N
184459	inimisi	?inimisi =isi  (SgG  >inim+isi !17_S	et	f	\N
184460	inimisi	?inimisi =isi  (SgP  >inim+isi !17_S	et	f	\N
184470	külmetamiseks	külmetamiseks =külmetamise  (SgTr  >külmetamine !12_S	et	f	\N
184471	külmetamiseks	"külmetamine %külmeta  )MINE_vS  <külmetama ;27_V	et	f	\N
184492	püksistele	püksistele =iste  (SgAll  >püks+iste !06_S	et	f	\N
184493	püksistele	püksistele =iste  (PlAll  >püks+ist !22_S	et	f	\N
184494	kõigidega	?kõigidega =kõigi  (PlKom  >kõigi !16_S	et	f	\N
184495	kõigidega	?kõigidega =kõigi  (PlKom  >kõig !22_S	et	f	\N
184496	sportimisega	sportimisega =sportimise  (SgKom  >sportimine !12_S	et	f	\N
184497	sportimisega	"sportimine %sporti  )MINE_vS  <sportima ;28_V	et	f	\N
184501	külapojast	külapojast =poja  (SgEl  >küla+poja !17_S	et	f	\N
184502	külapojast	külapojast =poja  (SgEl  >küla+poeg !22_S	et	f	\N
184503	külapojast	külapojast =pojas  (SgP  >küla+pojane !10_A	et	f	\N
184504	külapojast	"küla+pojane %poja  )NE_aA  <küla+poja ;17_S	et	f	\N
184505	külapojast	"küla+pojane %poja  )NE_aA  <küla+poeg ;22_S	et	f	\N
184506	saage	saage =saa  (ImpPrPl2  >saama !37_V	et	f	\N
184507	saage	saage =saage  (SgN  >saage !05_S	et	f	\N
184508	saage	saage =saage  (PlP  >saag !22_S	et	f	\N
184539	ülekoormusi	ülekoormusi =musi  (SgN  >üle+koor+musi !17_S	et	f	\N
184540	ülekoormusi	ülekoormusi =musi  (SgG  >üle+koor+musi !17_S	et	f	\N
184541	ülekoormusi	ülekoormusi =musi  (SgP  >üle+koor+musi !17_S	et	f	\N
184542	ülekoormusi	ülekoormusi =koormusi  (PlP  >üle+koormus !11_S	et	f	\N
184569	kütmima	?kütmima =kütmi  (Sup  >kütmima !28_V	et	f	\N
184570	kütmima	?kütmima =kütmima  (SgG  >kütmim !02_A	et	f	\N
184622	hooaga	### hooaga	et	f	\N
184626	lõunasoogi	lõunasoogi =soo  (SgN^  >lõuna+soo !26_S	et	f	\N
184627	lõunasoogi	lõunasoogi =soo  (SgG^  >lõuna+sugu !18_S	et	f	\N
184628	lõunasoogi	lõunasoogi =soo  (SgG^  >lõuna+soo !26_S	et	f	\N
184632	üllatatud	üllatatud =üllata  (PtsPtIps  >üllatama !27_V	et	f	\N
184633	üllatatud	üllatatud =üllatatu  (PlN  >üllatatu !01_S	et	f	\N
184634	üllatatud	"üllatatu %üllata  )TU1_vS  <üllatama ;27_V	et	f	\N
184635	üllatatud	üllatatud =üllatatud  (ID  >üllatatud !41_A	et	f	\N
184636	üllatatud	"üllatatud %üllata  )TUD_vA  <üllatama ;27_V	et	f	\N
184638	magiline	?magiline =magiline  (SgN  >magiline !12_A	et	f	\N
184639	magiline	?magiline =magiline  (PlP  >magilin !19_S	et	f	\N
184648	aparaadikset	?aparaadikset =aparaadikse  (SgP  >aparaadikne !02_A	et	f	\N
184657	naiselikuim	?naiselikuim =naiselikuim  (SgN  >naiselikuim !02_A	et	f	\N
184658	naiselikuim	?naiselikuim =elikuim  (SgN  >nais+elikuim !02_A	et	f	\N
184660	puhkades	?puhkades =puhka  (PlIn  >puhka !16_S	et	f	\N
184661	puhkades	?puhkades =ade  (SgIn  >puhk+ade !16_S	et	f	\N
184662	puhkades	?puhkades =ades  (SgN  >puhk+ades !09_S	et	f	\N
184678	sõlmimine	sõlmimine =sõlmimine  (SgN  >sõlmimine !12_S	et	f	\N
184679	sõlmimine	"sõlmimine %sõlmi  )MINE_vS  <sõlmima ;28_V	et	f	\N
184688	sulgemine	sulgemine =sulgemine  (SgN  >sulgemine !12_S	et	f	\N
184689	sulgemine	"sulgemine %sulge  )MINE_vS  <sulgema ;27_V	et	f	\N
184690	sulgemine	"sulgemine %sulge  )MINE_vS  <sulgema ;28_V	et	f	\N
184691	soikujäämise	?soikujäämise =soikujäämise  (SgG  >soikujäämine !10_A	et	f	\N
184710	ustavaks	ustavaks =ustava  (SgTr  >ustav !02_A	et	f	\N
184711	ustavaks	"ustav %us  )TAV_vAS  <uskuma ;28_V	et	f	\N
184731	venestamist	venestamist =venestamis  (SgP  >venestamine !12_S	et	f	\N
184732	venestamist	"venestamine %venesta  )MINE_vS  <venestama ;27_V	et	f	\N
184737	edendamisest	edendamisest =edendamise  (SgEl  >edendamine !12_S	et	f	\N
184738	edendamisest	"edendamine %edenda  )MINE_vS  <edendama ;27_V	et	f	\N
184567	aksendi	?aksendi =aksendi  (IndPrPs_  >aksentima !28_V	et	f	\N
184568	aksendi	?aksendi =aksendi  (ImpPrSg2  >aksentima !28_V	et	f	\N
184592	maandavad	maandavad =maanda  (IndPrPl3  >maandama !27_V	et	f	\N
184593	maandavad	maandavad =maandava  (PlN  >maandav !02_A	et	f	\N
184594	maandavad	"maandav %maanda  )V_vA  <maandama ;27_V	et	f	\N
184602	lõunasooki	?lõunasooki =lõunasooki  (SgN  >lõunasooki !16_S	et	f	\N
184603	lõunasooki	?lõunasooki =lõunasooki  (SgG  >lõunasooki !16_S	et	f	\N
184604	lõunasooki	?lõunasooki =lõunasooki  (SgP  >lõunasook !22_S	et	f	\N
184605	lõunasooki	?lõunasooki =lõunasooki  (SgAdt  >lõunasook !22_S	et	f	\N
184606	lõunasooki	?lõunasooki =sooki  (SgP  >lõuna+sook !22_S	et	f	\N
184607	lõunasooki	?lõunasooki =sooki  (SgAdt  >lõuna+sook !22_S	et	f	\N
184608	lõunasooki	?lõunasooki =nasooki  (SgN  >lõu+nasooki !16_S	et	f	\N
184609	lõunasooki	?lõunasooki =nasooki  (SgG  >lõu+nasooki !16_S	et	f	\N
184610	lõunasooki	?lõunasooki =nasooki  (SgP  >lõu+nasook !22_S	et	f	\N
184611	lõunasooki	?lõunasooki =nasooki  (SgAdt  >lõu+nasook !22_S	et	f	\N
184621	bk	### bk	et	f	\N
184673	üro	?üro =üro  (SgN  >üro !17~16_S	et	f	\N
184674	üro	?üro =üro  (SgG  >üro !17~16_S	et	f	\N
184675	üro	?üro =üro  (SgP  >üro !17_S	et	f	\N
184686	seismajäämise	seismajäämise =jäämise  (SgG  >seisma+jäämine !12?10_S	et	f	\N
184687	seismajäämise	"seisma+jäämine %jäämi  )NE_aA  <seisma+jääm ;22_S	et	f	\N
184698	pääsesid	pääsesid =pääse  (IndIpfSg2  >pääsema !28_V	et	f	\N
184699	pääsesid	pääsesid =pääse  (IndIpfPl3  >pääsema !28_V	et	f	\N
184702	kunstlikult	kunstlikult =kunstliku  (SgAbl  >kunstlik !25_A	et	f	\N
184703	kunstlikult	kunstlikult =kunstlikult  (ID  >kunstlikult !41_D	et	f	\N
184704	kunstlikult	"kunstlikult %kunstliku  )LT_mD  <kunstlik ;25_A	et	f	\N
184722	rahvusideoloogia	rahvusideoloogia =ideoloogia  (SgN  >rahvus+ideoloogia !01_S	et	f	\N
184723	rahvusideoloogia	rahvusideoloogia =ideoloogia  (SgG  >rahvus+ideoloogia !01_S	et	f	\N
184733	kreuzwaldiga	?kreuzwaldiga =kreuzwaldi  (SgKom  >kreuzwaldi !01_S	et	f	\N
184734	kreuzwaldiga	?kreuzwaldiga =kreuzwaldi  (SgKom  >kreuzwald !02_S	et	f	\N
184753	taandumist	taandumist =taandumis  (SgP  >taandumine !12_S	et	f	\N
184754	taandumist	"taandumine %taandu  )MINE_vS  <taanduma ;27_V	et	f	\N
184781	konkurentsi	konkurentsi =konkurentsi  (SgG  >konkurents !22_S	et	f	\N
184782	konkurentsi	konkurentsi =konkurentsi  (SgP  >konkurents !22_S	et	f	\N
184783	konkurentsi	konkurentsi =konkurentsi  (SgAdt  >konkurents !22_S	et	f	\N
184788	määrav	määrav =määra  (PtsPrPs  >määrama !29_V	et	f	\N
184789	määrav	määrav =määrav  (SgN  >määrav !02_A	et	f	\N
184790	määrav	"määrav %määra  )V_vA  <määrama ;29_V	et	f	\N
184796	tuntuimaid	?tuntuimaid =tuntuima  (PlP  >tuntuim !02_A	et	f	\N
184797	tuntuimaid	?tuntuimaid =tuntuimai  (PlN  >tuntuimai !26_S	et	f	\N
184798	tuntuimaid	?tuntuimaid =tuntuimai  (SgP  >tuntuimai !26_S	et	f	\N
184814	ristitamine	ristitamine =ristitamine  (SgN  >ristitamine !12_S	et	f	\N
184815	ristitamine	"ristitamine %ristita  )MINE_vS  <ristitama ;27_V	et	f	\N
184817	eestofile	?eestofile =eestofi  (SgAll  >eestofi !01_S	et	f	\N
184818	eestofile	?eestofile =eestofi  (SgAll  >eestof !02_S	et	f	\N
184819	eestofile	?eestofile =eestofi  (SgAll  >eestoff !22_S	et	f	\N
184821	eestofile	?eestofile =ofi  (SgAll  >eest+ofi !16_S	et	f	\N
184823	eestofile	?eestofile =ofi  (SgAll  >eest+off !22_S	et	f	\N
184824	eestofile	?eestofile =tofi  (SgAll  >ees+tofi !16_S	et	f	\N
184825	eestofile	?eestofile =tofi  (SgAll  >ees+toff !22_S	et	f	\N
184831	üliõpelastest	?üliõpelastest =üliõpelas  (PlEl  >üliõpelane !12_S	et	f	\N
184832	üliõpelastest	?üliõpelastest =üliõpelastes  (SgP  >üliõpelastene !12_A	et	f	\N
184833	üliõpelastest	?üliõpelastest =õpelas  (PlEl  >üli+õpelane !12_S	et	f	\N
184835	üliõpelastest	?üliõpelastest =õpelastes  (SgP  >üli+õpelastene !12_A	et	f	\N
184841	faelhmanil	?faelhmanil =faelhmani  (SgAd  >faelhman !02_S	et	f	\N
184846	kalevala	?kalevala =kalevala  (SgN  >kalevala !01_S	et	f	\N
184847	kalevala	?kalevala =kalevala  (SgG  >kalevala !01_S	et	f	\N
184859	toetusid	toetusid =toetu  (IndIpfSg2  >toetuma !27_V	et	f	\N
184860	toetusid	toetusid =toetu  (IndIpfPl3  >toetuma !27_V	et	f	\N
184877	aleksandrikool	?aleksandrikool =aleksandrikoo  (SgAd  >aleksandrikoo !26_S	et	f	\N
184878	aleksandrikool	?aleksandrikool =aleksandrikool  (SgN  >aleksandrikool !22_S	et	f	\N
184879	aleksandrikool	?aleksandrikool =ksandrikoo  (SgAd  >ale+ksandrikoo !26_S	et	f	\N
184880	aleksandrikool	?aleksandrikool =ksandrikool  (SgN  >ale+ksandrikool !22_S	et	f	\N
184881	mantlipärija	mantlipärija =pärija  (SgN  >mantli+pärija !01_S	et	f	\N
184882	mantlipärija	mantlipärija =pärija  (SgG  >mantli+pärija !01_S	et	f	\N
184887	eluisu	eluisu =isu  (SgN  >elu+isu !17_S	et	f	\N
184888	eluisu	eluisu =isu  (SgG  >elu+isu !17_S	et	f	\N
184889	eluisu	eluisu =isu  (SgP  >elu+isu !17_S	et	f	\N
184918	sügavamale	sügavamale =sügavama  (SgAll  >sügavam !02_A	et	f	\N
184919	sügavamale	"sügavam %süga  )VAM_cA  <sügama ;27_V	et	f	\N
184920	sügavamale	"sügavam %sügava  )M_cA  <sügav ;02_A	et	f	\N
184921	sügavamale	sügavamale =male  (SgN  >sügava+male !16_S	et	f	\N
184922	sügavamale	sügavamale =male  (SgG  >sügava+male !16_S	et	f	\N
184645	väikestel	väikestel =keste  (PlAd  >väi+kest !22_S	et	f	\N
184659	mehelikuim	?mehelikuim =mehelikuim  (SgN  >mehelikuim !02_A	et	f	\N
184663	sula-	sula- =sula  (SgN  >sula !17_AS	et	f	\N
184664	sula-	sula- =sula  (SgG  >sula !17_AS	et	f	\N
184665	sula-	sula- =sula  (SgP  >sula !17_AS	et	f	\N
184666	sula-	sula- =sula  (IndPrPs_  >sulama !27_V	et	f	\N
184667	sula-	sula- =sula  (ImpPrSg2  >sulama !27_V	et	f	\N
184668	kuuekümnendate	?kuuekümnendate =kuuekümnenda  (IndPrPl2  >kuuekümnendama !27_V	et	f	\N
184669	kuuekümnendate	?kuuekümnendate =ate  (SgN  >kuue+kümnend+ate !06_S	et	f	\N
184670	kuuekümnendate	?kuuekümnendate =kümnenda  (PlG  >kuue+kümnenda !01_S	et	f	\N
184676	1990te	te =te  (PlG  >sa !00_P	et	f	\N
184677	1990te	te =te  (PlN  >sa !00_P	et	f	\N
184680	sissetoomise	sissetoomise =toomise  (SgG  >sisse+toomine !12?10_S	et	f	\N
184681	sissetoomise	"sisse+toomine %toomi  )NE_aA  <sisse+toom ;22_S	et	f	\N
184696	võimulepääsemisega	võimulepääsemisega =emise  (SgKom  >võimule+pääs+emis !09_S	et	f	\N
184697	võimulepääsemisega	võimulepääsemisega =pääsemise  (SgKom  >võimule+pääsemine !12_S	et	f	\N
184705	rehabiliteeritud	rehabiliteeritud =rehabiliteeri  (PtsPtIps  >rehabiliteerima !28_V	et	f	\N
184706	rehabiliteeritud	rehabiliteeritud =rehabiliteeritu  (PlN  >rehabiliteeritu !01_S	et	f	\N
184707	rehabiliteeritud	"rehabiliteeritu %rehabiliteeri  )TU1_vS  <rehabiliteerima ;28_V	et	f	\N
184708	rehabiliteeritud	rehabiliteeritud =rehabiliteeritud  (ID  >rehabiliteeritud !41_A	et	f	\N
184709	rehabiliteeritud	"rehabiliteeritud %rehabiliteeri  )TUD_vA  <rehabiliteerima ;28_V	et	f	\N
184714	hurdast	hurdast =hurda  (SgEl  >hurt !22_S	et	f	\N
184715	hurdast	hurdast =hurdas  (SgP  >hurdane !10_A	et	f	\N
184716	hurdast	"hurdane %hurda  )NE_aA  <hurt ;22_S	et	f	\N
184727	rahvaluulesse	rahvaluulesse =luule  (SgIll  >rahva+luule !06_S	et	f	\N
184728	rahvaluulesse	rahvaluulesse =luule  (PlIll  >rahva+luul !22_S	et	f	\N
184729	ettekande	ettekande =kande  (SgG  >ette+kanne !06_S	et	f	\N
184730	ettekande	ettekande =kande  (PlP  >ette+kand !22_S	et	f	\N
184739	hardustaseme	### hardustaseme	et	f	\N
184742	rõhus	rõhus =rõhu  (SgIn  >rõhk !22_S	et	f	\N
184743	rõhus	rõhus =rõhu  (IndIpfSg3  >rõhuma !27_V	et	f	\N
184800	pärisorjuslikkorda	?pärisorjuslikkorda =pärisorjuslikkorda  (SgN  >pärisorjuslikkorda !16_S	et	f	\N
184801	pärisorjuslikkorda	?pärisorjuslikkorda =pärisorjuslikkorda  (SgG  >pärisorjuslikkorda !16_S	et	f	\N
184802	pärisorjuslikkorda	?pärisorjuslikkorda =pärisorjuslikkorda  (IndPrPs_  >pärisorjuslikkordama !27_V	et	f	\N
184803	pärisorjuslikkorda	?pärisorjuslikkorda =pärisorjuslikkorda  (ImpPrSg2  >pärisorjuslikkordama !27_V	et	f	\N
184804	pärisorjuslikkorda	?pärisorjuslikkorda =orjuslikkorda  (SgN  >päris+orjuslikkorda !16_S	et	f	\N
184805	pärisorjuslikkorda	?pärisorjuslikkorda =orjuslikkorda  (SgG  >päris+orjuslikkorda !16_S	et	f	\N
184806	pärisorjuslikkorda	?pärisorjuslikkorda =sorjuslikkorda  (SgN  >päri+sorjuslikkorda !16_S	et	f	\N
184807	pärisorjuslikkorda	?pärisorjuslikkorda =sorjuslikkorda  (SgG  >päri+sorjuslikkorda !16_S	et	f	\N
184828	mustendite	?mustendite =mustendi  (PlG  >mustendi !01_S	et	f	\N
184829	mustendite	?mustendite =mustendi  (PlG  >mustend !02_S	et	f	\N
184830	mustendite	?mustendite =mustendi  (IndPrPl2  >mustentima !28_V	et	f	\N
184834	haritsastest	?haritsastest =haritsas  (PlEl  >haritsane !12_A	et	f	\N
184836	haritsastest	?haritsastest =haritsastes  (SgP  >haritsastene !12_A	et	f	\N
184837	haritsastest	?haritsastest =tsaste  (SgEl  >hari+tsaste !06_S	et	f	\N
184838	haritsastest	?haritsastest =tsaste  (PlEl  >hari+tsast !22_S	et	f	\N
184839	haritsastest	?haritsastest =tsastes  (SgP  >hari+tsastes !09_S	et	f	\N
184840	haritsastest	?haritsastest =tsastes  (SgP  >hari+tsastene !12~10_A	et	f	\N
184853	eeposest	eeposest =eepose  (SgEl  >eepos !11~09_S	et	f	\N
184854	eeposest	eeposest =eeposes  (SgP  >eeposene !12_A	et	f	\N
184855	eeposest	"eeposene %eepose  )NE_aA  <eepos ;09_S	et	f	\N
184856	eeposest	"eeposene %eepose  )NE_aA  <eepos ;11_S	et	f	\N
184857	valgustustegevus	valgustustegevus =tegevus  (SgN  >valgustus+tegevus !11_S	et	f	\N
184858	valgustustegevus	"valgustus+tegevus %tegeva  )US_aS  <valgustus+tegev ;02_A	et	f	\N
184895	eestlastesse	eestlastesse =eestlas  (PlIll  >eestlane !12?10_S	et	f	\N
184897	eestlastesse	eestlastesse =las  (PlIll  >eest+laps !14_S	et	f	\N
184899	eestlastesse	eestlastesse =laste  (PlIll  >eest+last !22_S	et	f	\N
184913	1751a	### 1751a	et	f	\N
184930	kõlav	kõlav =kõla  (PtsPrPs  >kõlama !27_V	et	f	\N
184931	kõlav	kõlav =kõlav  (SgN  >kõlav !02_A	et	f	\N
184932	kõlav	"kõlav %kõla  )V_vA  <kõlama ;27_V	et	f	\N
184949	hiieks	hiieks =hiie  (SgTr  >hiis !14_S	et	f	\N
184950	hiieks	hiieks =hiie  (PlTr  >hiid !22_S	et	f	\N
184953	kudumisvardad	kudumisvardad =varda  (PlN  >kudumis+varras !07_S	et	f	\N
184954	kudumisvardad	kudumisvardad =varda  (PlN  >kudumis+vart !22_S	et	f	\N
184978	tapetu	tapetu =tapetu  (SgN  >tapetu !01_S	et	f	\N
184979	tapetu	"tapetu %tape  )TU1_vS  <tapma ;35_V	et	f	\N
184980	tapetu	tapetu =tapetu  (SgG  >tapetu !01_S	et	f	\N
184981	tapja	tapja =tapja  (SgN  >tapja !01_S	et	f	\N
184982	tapja	"tapja %tap  )JA_vS  <tapma ;35_V	et	f	\N
184983	tapja	tapja =tapja  (SgG  >tapja !01_S	et	f	\N
185003	haigustest	haigustest =haigus  (PlEl  >haigus !11~09_S	et	f	\N
184750	vaimuelu	vaimuelu =elu  (SgN  >vaimu+elu !17_S	et	f	\N
184751	vaimuelu	vaimuelu =elu  (SgG  >vaimu+elu !17_S	et	f	\N
184752	vaimuelu	vaimuelu =elu  (SgP  >vaimu+elu !17_S	et	f	\N
184755	kukutamiseks	kukutamiseks =kukutamise  (SgTr  >kukutamine !12_S	et	f	\N
184756	kukutamiseks	"kukutamine %kukuta  )MINE_vS  <kukutama ;27_V	et	f	\N
184757	pooldajate	pooldajate =pooldaja  (PlG  >pooldaja !01_S	et	f	\N
184758	pooldajate	"pooldaja %poolda  )JA_vS  <pooldama ;27_V	et	f	\N
184771	allutamist	allutamist =allutamis  (SgP  >allutamine !12_S	et	f	\N
184772	allutamist	"allutamine %alluta  )MINE_vS  <allutama ;27_V	et	f	\N
184784	vaimnekultuur	?vaimnekultuur =vaimnekultuur  (SgN  >vaimnekultuur !22_S	et	f	\N
184785	vaimnekultuur	?vaimnekultuur =nekultuur  (SgN  >vaim+nekultuur !22_S	et	f	\N
184820	valgustusfilosoofia	valgustusfilosoofia =filosoofia  (SgN  >valgustus+filosoofia !01_S	et	f	\N
184822	valgustusfilosoofia	valgustusfilosoofia =filosoofia  (SgG  >valgustus+filosoofia !01_S	et	f	\N
184850	kalevipja	?kalevipja =kalevipja  (SgN  >kalevipja !16_S	et	f	\N
184851	kalevipja	?kalevipja =kalevipja  (SgG  >kalevipjas !02_A	et	f	\N
184852	kalevipja	?kalevipja =kalevipja  (SgG  >kalevipja !16_S	et	f	\N
184874	panija	panija =panija  (SgN  >panija !01_S	et	f	\N
184875	panija	"panija %pani  )JA_vS  <panema ;36_V	et	f	\N
184876	panija	panija =panija  (SgG  >panija !01_S	et	f	\N
184890	laiemalt	laiemalt =laiema  (SgAbl  >laiem !02_A	et	f	\N
184891	laiemalt	"laiem %laie  )M_cA  <lai ;22_A	et	f	\N
184893	laiemalt	laiemalt =laiemalt  (ID  >laiemalt !41_D	et	f	\N
184896	laiemalt	"laiemalt %laiema  )LT_mD  <laiem ;02_A	et	f	\N
184898	laiemalt	laiemalt =ema  (SgAbl  >lai+ema !17_S	et	f	\N
184905	ülesleiti	?ülesleiti =ülesleiti  (SgN  >ülesleiti !16_S	et	f	\N
184906	ülesleiti	?ülesleiti =ülesleiti  (SgG  >ülesleiti !16_S	et	f	\N
184907	ülesleiti	?ülesleiti =ülesleiti  (SgP  >ülesleit !22_S	et	f	\N
184908	ülesleiti	?ülesleiti =ülesleiti  (SgAdt  >ülesleit !22_S	et	f	\N
184909	ülesleiti	?ülesleiti =leiti  (SgP  >üles+leit !22_S	et	f	\N
184910	ülesleiti	?ülesleiti =leiti  (SgAdt  >üles+leit !22_S	et	f	\N
184911	ülesleiti	?ülesleiti =sleiti  (SgP  >üle+sleit !22_S	et	f	\N
184912	ülesleiti	?ülesleiti =sleiti  (SgAdt  >üle+sleit !22_S	et	f	\N
184929	jt-	### jt-	et	f	\N
184962	rikkamatele	?rikkamatele =rikkama  (PlAll  >rikkam !02_A	et	f	\N
184963	rikkamatele	?rikkamatele =rikkamate  (PlAll  >rikkamatt !22_S	et	f	\N
184964	rikkamatele	?rikkamatele =rikkamatele  (IndPrPs_  >rikkamatelema !36_V	et	f	\N
184966	rikkamatele	?rikkamatele =rikkamatele  (ImpPrSg2  >rikkamatelema !36_V	et	f	\N
184984	suguseltsi	suguseltsi =seltsi  (SgG  >sugu+selts !22_S	et	f	\N
184985	suguseltsi	suguseltsi =seltsi  (SgP  >sugu+selts !22_S	et	f	\N
184986	suguseltsi	suguseltsi =seltsi  (SgAdt  >sugu+selts !22_S	et	f	\N
184987	suremise	suremise =suremise  (SgG  >suremine !12_S	et	f	\N
184988	suremise	"suremine %sure  )MINE_vS  <surema ;36_V	et	f	\N
184992	raiumine	raiumine =raiumine  (SgN  >raiumine !12_S	et	f	\N
184993	raiumine	"raiumine %raiu  )MINE_vS  <raiuma ;28_V	et	f	\N
185006	saavat	saavat =saa  (KvtPrPs  >saama !37_V	et	f	\N
185007	saavat	saavat =saava  (SgP  >saav !02_A	et	f	\N
185008	saavat	"saav %saa  )V_vA  <saama ;37_V	et	f	\N
185009	pesemisega	pesemisega =pesemise  (SgKom  >pesemine !12_S	et	f	\N
185010	pesemisega	"pesemine %pese  )MINE_vS  <pesema ;36_V	et	f	\N
185011	noorust	noorust =noorus  (SgP  >noorus !11~09_S	et	f	\N
185012	noorust	"noorus %noor  )US_aS  <noor ;13_AS	et	f	\N
185013	noorust	noorust =us  (SgP  >noor+uks !14_S	et	f	\N
185014	puuks	puuks =puu  (SgTr  >puu !26_S	et	f	\N
185015	puuks	puuks =puuks  (SgN  >puuks !22_S	et	f	\N
185043	keskusteks	keskusteks =keskus  (PlTr  >keskus !11~09_S	et	f	\N
185044	keskusteks	keskusteks =us  (PlTr  >kesk+uks !14_S	et	f	\N
185045	kaalu-	kaalu- =kaalu  (SgG  >kaal !22_S	et	f	\N
185046	kaalu-	kaalu- =kaalu  (SgP  >kaal !22_S	et	f	\N
185047	kaalu-	kaalu- =kaalu  (SgAdt  >kaal !22_S	et	f	\N
185048	kaalu-	kaalu- =kaalu  (IndPrPs_  >kaaluma !28_V	et	f	\N
185049	kaalu-	kaalu- =kaalu  (ImpPrSg2  >kaaluma !28_V	et	f	\N
185051	asukohale	asukohale =koha  (SgAll  >asu+koha !17_S	et	f	\N
185052	asukohale	asukohale =koha  (SgAll  >asu+koht !22_S	et	f	\N
185068	saabumisega	saabumisega =saabumise  (SgKom  >saabumine !12_S	et	f	\N
185069	saabumisega	"saabumine %saabu  )MINE_vS  <saabuma ;27_V	et	f	\N
185078	õhukesi	õhukesi =õhukesi  (PlP  >õhuke !12_A	et	f	\N
185079	õhukesi	"õhuke %õhu  )KE_dS  <õhk ;22_S	et	f	\N
185080	õhukesi	õhukesi =õhukesi  (PlP  >õhukene !12_S	et	f	\N
185081	õhukesi	"õhukene %õhu  )KENE_dS  <õhk ;22_S	et	f	\N
185082	kultuurikihti	kultuurikihti =kihti  (SgP  >kultuuri+kiht !22_S	et	f	\N
185083	kultuurikihti	kultuurikihti =kihti  (SgAdt  >kultuuri+kiht !22_S	et	f	\N
185089	soogiks	?soogiks =soogi  (SgTr  >soogi !16_S	et	f	\N
185090	soogiks	?soogiks =soogi  (SgTr  >soog !22_S	et	f	\N
185091	soogiks	?soogiks =soogi  (KndPrPs  >soogima !28_V	et	f	\N
185093	soogiks	?soogiks =giks  (SgN  >soo+giks !22_S	et	f	\N
185098	nooleotsiga	nooleotsiga =iga  (SgN  >noole+ots+iga !18_S	et	f	\N
185099	nooleotsiga	nooleotsiga =iga  (SgP  >noole+ots+iga !18_S	et	f	\N
184779	kardsid	?kardsid =kardsi  (PlN  >kards !22_S	et	f	\N
184780	kardsid	?kardsid =kardsi  (IndPrSg2  >kardsima !28_V	et	f	\N
184792	epigrammi	epigrammi =epigrammi  (SgG  >epigramm !22_S	et	f	\N
184793	epigrammi	epigrammi =epigrammi  (SgP  >epigramm !22_S	et	f	\N
184794	epigrammi	epigrammi =epigrammi  (SgAdt  >epigramm !22_S	et	f	\N
184816	haritas	?haritas =harita  (IndIpfSg3  >haritama !27_V	et	f	\N
184842	länrotti	?länrotti =länrotti  (SgN  >länrotti !01_S	et	f	\N
184843	länrotti	?länrotti =länrotti  (SgG  >länrotti !01_S	et	f	\N
184844	länrotti	?länrotti =länrotti  (SgP  >länrott !22_S	et	f	\N
184845	länrotti	?länrotti =länrotti  (SgAdt  >länrott !22_S	et	f	\N
184861	katariina	?katariina =katarii  (SgEs  >katarii !26_S	et	f	\N
184862	katariina	?katariina =katariina  (SgN  >katariina !16_S	et	f	\N
184863	katariina	?katariina =katariina  (SgG  >katariina !16_S	et	f	\N
184866	propageerisid	propageerisid =propageeri  (IndIpfSg2  >propageerima !28_V	et	f	\N
184867	propageerisid	propageerisid =propageeri  (IndIpfPl3  >propageerima !28_V	et	f	\N
184872	arutati	arutati =aruta  (IndIpfIps  >arutama !27_V	et	f	\N
184873	arutati	arutati =tati  (SgG  >aru+tatt !22_S	et	f	\N
184883	süstis	süstis =süst  (IndIpfSg3  >süstma !34_V	et	f	\N
184884	süstis	süstis =süsti  (SgIn  >süst !22_S	et	f	\N
184885	süstis	süstis =süsti  (PlIn  >süst !22_S	et	f	\N
184886	süstis	süstis =süsti  (IndIpfSg3  >süstima !28_V	et	f	\N
184900	piinast	piinast =piina  (SgEl  >piin !22_S	et	f	\N
184901	piinast	piinast =piinas  (SgP  >piinane !10_A	et	f	\N
184902	piinast	"piinane %piina  )NE_aA  <piin ;22_S	et	f	\N
184937	tähtsamatel	tähtsamatel =tähtsama  (PlAd  >tähtsam !02_A	et	f	\N
184938	tähtsamatel	"tähtsam %tähtsa  )M_cA  <tähtis ;02_A	et	f	\N
184946	ohverduspaika	?ohverduspaika =ohverduspaika  (SgN  >ohverduspaika !16_S	et	f	\N
184947	ohverduspaika	?ohverduspaika =ohverduspaika  (SgG  >ohverduspaikas !02_A	et	f	\N
184948	ohverduspaika	?ohverduspaika =ohverduspaika  (SgG  >ohverduspaika !16_S	et	f	\N
184955	tooru	?tooru =tooru  (SgN  >tooru !16_S	et	f	\N
184956	tooru	?tooru =tooru  (SgG  >tooru !16_S	et	f	\N
184957	tooru	?tooru =tooru  (IndPrPs_  >tooruma !27_V	et	f	\N
184958	tooru	?tooru =tooru  (ImpPrSg2  >tooruma !27_V	et	f	\N
184976	tappis	tappis =tapp  (IndIpfSg3  >tapma !35_V	et	f	\N
184977	tappis	tappis =tappi  (IndIpfSg3  >tappima !28_V	et	f	\N
184989	küsimata	küsimata =küsi  (SupAb  >küsima !27_V	et	f	\N
184990	küsimata	küsimata =küsimata  (ID  >küsimata !41_A	et	f	\N
184991	küsimata	"küsimata %küsi  )MATA_vA  <küsima ;27_V	et	f	\N
185000	allikale	allikale =allika  (SgAll  >allikas !02_S	et	f	\N
185001	allikale	allikale =ale  (SgN  >allik+ale !16_S	et	f	\N
185002	allikale	allikale =ale  (SgG  >allik+ale !16_S	et	f	\N
185022	müüsid	müüsid =müü  (IndIpfSg2  >müüma !38_V	et	f	\N
185023	müüsid	müüsid =müü  (IndIpfPl3  >müüma !38_V	et	f	\N
185024	müüsid	müüsid =müü  (PlP  >müü !26_S	et	f	\N
185025	vaha	vaha =vaha  (SgN  >vaha !17_S	et	f	\N
185026	vaha	vaha =vaha  (SgG  >vaha !17_S	et	f	\N
185027	vaha	vaha =vaha  (SgP  >vaha !17_S	et	f	\N
185028	tolleaegsetest	tolleaegsetest =sete  (PlEl  >tolle+aeg+sett !22_S	et	f	\N
185029	tolleaegsetest	tolleaegsetest =aegse  (PlEl  >tolle+aegne !02_A	et	f	\N
185032	kommunikeerisid	?kommunikeerisid =kommunikeeri  (PlP  >kommunikeeri !16_S	et	f	\N
185033	kommunikeerisid	?kommunikeerisid =kommunikeeri  (PlP  >kommunikeer !22_S	et	f	\N
185034	kommunikeerisid	?kommunikeerisid =kommunikeeri  (IndIpfSg2  >kommunikeerima !28_V	et	f	\N
185035	kommunikeerisid	?kommunikeerisid =kommunikeeri  (IndIpfPl3  >kommunikeerima !28_V	et	f	\N
185036	kommunikeerisid	?kommunikeerisid =munikeeri  (PlP  >kom+munikeeri !16_S	et	f	\N
185037	kommunikeerisid	?kommunikeerisid =munikeeri  (PlP  >kom+munikeer !22_S	et	f	\N
185057	hävitasid	hävitasid =hävita  (IndIpfSg2  >hävitama !27_V	et	f	\N
185058	hävitasid	hävitasid =hävita  (IndIpfPl3  >hävitama !27_V	et	f	\N
185059	sigmundi	?sigmundi =sigmundi  (SgN  >sigmundi !01_S	et	f	\N
185060	sigmundi	?sigmundi =sigmundi  (SgG  >sigmundi !01_S	et	f	\N
185061	sigmundi	?sigmundi =sigmundi  (SgG  >sigmund !02_S	et	f	\N
185062	sigmundi	?sigmundi =sigmundi  (SgG  >sigmunt !22_S	et	f	\N
185063	sigmundi	?sigmundi =sigmundi  (IndPrPs_  >sigmuntima !28_V	et	f	\N
185064	sigmundi	?sigmundi =sigmundi  (ImpPrSg2  >sigmuntima !28_V	et	f	\N
185065	1187a	### 1187a	et	f	\N
185066	minasaeg	?minasaeg =minasaeg  (SgN  >minasaeg !22_S	et	f	\N
185067	minasaeg	?minasaeg =saeg  (SgN  >mina+saeg !22_S	et	f	\N
185070	kiviaega	kiviaega =aega  (SgP  >kivi+aeg !22_S	et	f	\N
185071	kiviaega	kiviaega =aega  (SgAdt  >kivi+aeg !22_S	et	f	\N
185084	mesoliitikumit	### mesoliitikumit	et	f	\N
185092	tarvitatud	tarvitatud =tarvita  (PtsPtIps  >tarvitama !27_V	et	f	\N
185094	tarvitatud	tarvitatud =tarvitatu  (PlN  >tarvitatu !01_S	et	f	\N
185095	tarvitatud	"tarvitatu %tarvita  )TU1_vS  <tarvitama ;27_V	et	f	\N
185096	tarvitatud	tarvitatud =tarvitatud  (ID  >tarvitatud !41_A	et	f	\N
185097	tarvitatud	"tarvitatud %tarvita  )TUD_vA  <tarvitama ;27_V	et	f	\N
185101	mesoliitikul	?mesoliitikul =mesoliitiku  (SgAd  >mesoliitik !02_S	et	f	\N
184795	eestofilid	### eestofilid	et	f	\N
184799	cr	### cr	et	f	\N
184808	muinasajast	muinasajast =aja  (SgEl  >muinas+aeg !22_S	et	f	\N
184809	muinasajast	muinasajast =ajas  (SgP  >muinas+ajane !10_A	et	f	\N
184810	muinasajast	"muinas+ajane %aja  )NE_aA  <muinas+aeg ;22_S	et	f	\N
184811	vägivalgne	?vägivalgne =vägivalgne  (SgN  >vägivalgne !02_A	et	f	\N
184812	vägivalgne	?vägivalgne =valgne  (SgN  >vägi+valgne !02_A	et	f	\N
184813	vägivalgne	?vägivalgne =valgne  (PlP  >vägi+valgn !22_S	et	f	\N
184826	faelhmani	?faelhmani =faelhma  (SgTer  >faelhma !01_S	et	f	\N
184827	faelhmani	?faelhmani =faelhmani  (SgG  >faelhman !02_S	et	f	\N
184848	faelhman	?faelhman =faelhma  (IndPrSg1  >faelhmama !29_V	et	f	\N
184849	faelhman	?faelhman =faelhman  (SgN  >faelhman !02_S	et	f	\N
184864	vähenesid	vähenesid =vähene  (IndIpfSg2  >vähenema !27_V	et	f	\N
184865	vähenesid	vähenesid =vähene  (IndIpfPl3  >vähenema !27_V	et	f	\N
184868	õesi	?õesi =õesi  (SgN  >õesi !16_S	et	f	\N
184869	õesi	?õesi =õesi  (SgG  >õesi !16_S	et	f	\N
184870	õesi	?õesi =õesi  (IndPrPs_  >õesima !28_V	et	f	\N
184871	õesi	?õesi =õesi  (ImpPrSg2  >õesima !28_V	et	f	\N
184892	kõigisse	kõigisse =kõigi  (PlIll  >kõik !00_P	et	f	\N
184894	kõigisse	kõigisse =kõigi  (SgIll  >kõik !22_S	et	f	\N
184903	kolalikud	?kolalikud =kolaliku  (PlN  >kolalik !25_A	et	f	\N
184904	kolalikud	?kolalikud =kolaliku  (IndPrSg2  >kolalikuma !27_V	et	f	\N
184914	hatti	hatti =hatti  (SgP  >hatt !22_S	et	f	\N
184915	hatti	hatti =hatti  (SgAdt  >hatt !22_S	et	f	\N
184916	kokkupanijaks	kokkupanijaks =jaks  (SgN  >kokku+pani+jaks !22_S	et	f	\N
184917	kokkupanijaks	kokkupanijaks =panija  (SgTr  >kokku+panija !01_S	et	f	\N
184925	kõrgematele	kõrgematele =kõrgema  (PlAll  >kõrgem !02_A	et	f	\N
184926	kõrgematele	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
184927	kõrgematele	kõrgematele =mate  (SgAll  >kõrge+mate !16_S	et	f	\N
184928	kõrgematele	kõrgematele =mate  (PlAll  >kõrge+matt !22_SA	et	f	\N
184933	pahameelt	pahameelt =mee  (SgAbl  >paha+mesi !15_S	et	f	\N
184934	pahameelt	pahameelt =meel  (SgP  >paha+meel !13_S	et	f	\N
184935	ohverdasid	ohverdasid =ohverda  (IndIpfSg2  >ohverdama !27_V	et	f	\N
184936	ohverdasid	ohverdasid =ohverda  (IndIpfPl3  >ohverdama !27_V	et	f	\N
184959	meestega	meestega =mees  (PlKom  >meene !10_A	et	f	\N
184960	meestega	"meene %mee  )NE_aA  <mesi ;15_S	et	f	\N
184961	meestega	meestega =mees  (PlKom  >mees !13_S	et	f	\N
184997	ravivaks	ravivaks =raviva  (SgTr  >raviv !02_A	et	f	\N
184998	ravivaks	"raviv %ravi  )V_vA  <ravima ;27_V	et	f	\N
184999	ravivaks	ravivaks =vaks  (SgN  >ravi+vaks !22_S	et	f	\N
185030	osi	osi =osi  (SgN  >osi !24_S	et	f	\N
185031	osi	osi =osi  (PlP  >osa !17_S	et	f	\N
185050	1030a	### 1030a	et	f	\N
185055	võimutsemist	võimutsemist =võimutsemis  (SgP  >võimutsemine !12_S	et	f	\N
185056	võimutsemist	"võimutsemine %võimutse  )MINE_vS  <võimutsema ;27_V	et	f	\N
185072	aastatuhat	?aastatuhat =aastatuha  (SgP  >aastatuha !16_S	et	f	\N
185073	aastatuhat	?aastatuhat =tatuha  (SgP  >aas+tatuha !01_S	et	f	\N
185085	koriluse	koriluse =koriluse  (SgG  >korilus !11_S	et	f	\N
185086	koriluse	"korilus %korilase  )US_aS  <korilane ;12_S	et	f	\N
185113	amestav	?amestav =amesta  (PtsPrPs  >amestama !27_V	et	f	\N
185114	amestav	?amestav =amestav  (SgN  >amestav !02_A	et	f	\N
185117	korilus	korilus =korilus  (SgN  >korilus !11_S	et	f	\N
185118	korilus	"korilus %korilase  )US_aS  <korilane ;12_S	et	f	\N
185123	põldude	põldude =põldu  (PlG  >põld !22_S	et	f	\N
185124	põldude	põldude =ude  (SgN  >põld+ude !04_S	et	f	\N
185131	valgusallikana	valgusallikana =kana  (SgN  >valgu+salli+kana !17_S	et	f	\N
185132	valgusallikana	valgusallikana =kana  (SgG  >valgu+salli+kana !17_S	et	f	\N
185133	valgusallikana	valgusallikana =kana  (SgP  >valgu+salli+kana !17_S	et	f	\N
185134	valgusallikana	valgusallikana =allika  (SgEs  >valgus+allikas !02_S	et	f	\N
185137	sarnanesid	sarnanesid =sarnane  (IndIpfSg2  >sarnanema !27_V	et	f	\N
185138	sarnanesid	sarnanesid =sarnane  (IndIpfPl3  >sarnanema !27_V	et	f	\N
185143	matmisel	matmisel =matmise  (SgAd  >matmine !12?10_S	et	f	\N
185144	matmisel	"matmine %mat  )MINE_vS  <matma ;35_V	et	f	\N
185151	söögiülejääke	söögiülejääke =jääke  (SgN  >söögi+üle+jääke !12?10_S	et	f	\N
185152	söögiülejääke	"söögi+üle+jääke %jää  )KE_dS  <söögi+üle+jää ;26_S	et	f	\N
185153	söögiülejääke	söögiülejääke =jääke  (PlP  >söögi+üle+jääk !22_S	et	f	\N
185163	kasutuselevõttu	kasutuselevõttu =võttu  (SgP  >kasutusele+võtt !22_S	et	f	\N
185164	kasutuselevõttu	kasutuselevõttu =võttu  (SgAdt  >kasutusele+võtt !22_S	et	f	\N
185183	kallastel	kallastel =kallas  (PlAd  >kallas !07_S	et	f	\N
185184	kallastel	kallastel =kallas  (PlAd  >kallane !10_A	et	f	\N
185185	kallastel	"kallane %kalla  )NE_aA  <kalla ;16_S	et	f	\N
185196	kvartsi-	kvartsi- =kvartsi  (SgG  >kvarts !22_S	et	f	\N
185197	kvartsi-	kvartsi- =kvartsi  (SgP  >kvarts !22_S	et	f	\N
185198	kvartsi-	kvartsi- =kvartsi  (SgAdt  >kvarts !22_S	et	f	\N
185209	nõõrkeraamika	?nõõrkeraamika =nõõrkeraamika  (SgN  >nõõrkeraamika !01_S	et	f	\N
185210	nõõrkeraamika	?nõõrkeraamika =nõõrkeraamika  (SgG  >nõõrkeraamika !01_S	et	f	\N
184923	kaebasid	kaebasid =kaeba  (IndIpfSg2  >kaebama !29_V	et	f	\N
184924	kaebasid	kaebasid =kaeba  (IndIpfPl3  >kaebama !29_V	et	f	\N
184939	orja	orja =orja  (SgG  >ori !24_S	et	f	\N
184940	orja	orja =orja  (SgP  >ori !24_S	et	f	\N
184941	orja	orja =orja  (SgAdt  >ori !24_S	et	f	\N
184942	orja	orja =orja  (IndPrPs_  >orjama !29_V	et	f	\N
184943	orja	orja =orja  (ImpPrSg2  >orjama !29_V	et	f	\N
184944	alasid	alasid =ala  (PlP  >ala !17_S	et	f	\N
184945	alasid	alasid =alasi  (PlN  >alasi !01_S	et	f	\N
184951	ohverdusega	ohverdusega =ohverduse  (SgKom  >ohverdus !11_S	et	f	\N
184952	ohverdusega	"ohverdus %ohverda  )US_vS  <ohverdama ;27_V	et	f	\N
184965	pandaks	pandaks =pan  (KndPrIps  >panema !36_V	et	f	\N
184967	pandaks	pandaks =panda  (SgTr  >panda !16_S	et	f	\N
184968	vaesematele	vaesematele =vaesema  (PlAll  >vaesem !02_A	et	f	\N
184969	vaesematele	"vaesem %vae  )SEM_cA  <vaag ;22_S	et	f	\N
184970	vaesematele	"vaesem %vaese  )M_cA  <vaene ;10_AS	et	f	\N
184971	vaesematele	vaesematele =mate  (SgAll  >vaese+mate !16_S	et	f	\N
184972	vaesematele	vaesematele =mate  (PlAll  >vaese+matt !22_SA	et	f	\N
184973	veretasu	veretasu =tasu  (SgN  >vere+tasu !17_S	et	f	\N
184974	veretasu	veretasu =tasu  (SgG  >vere+tasu !17_S	et	f	\N
184975	veretasu	veretasu =tasu  (SgP  >vere+tasu !17_S	et	f	\N
184994	sümboliga	sümboliga =sümboli  (SgKom  >sümbol !02_S	et	f	\N
184995	sümboliga	sümboliga =iga  (SgN  >sümbol+iga !18_S	et	f	\N
184996	sümboliga	sümboliga =iga  (SgP  >sümbol+iga !18_S	et	f	\N
185019	metsaalast	metsaalast =ala  (SgEl  >metsa+ala !17_S	et	f	\N
185020	metsaalast	metsaalast =alas  (SgP  >metsa+alane !10_AS	et	f	\N
185021	metsaalast	"metsa+alane %ala  )NE_aA  <metsa+ala ;17_S	et	f	\N
185038	tk	### tk	et	f	\N
185039	ruunikirja	ruunikirja =kirja  (SgG  >ruuni+kiri !24_S	et	f	\N
185040	ruunikirja	ruunikirja =kirja  (SgP  >ruuni+kiri !24_S	et	f	\N
185041	ruunikirja	ruunikirja =kirja  (SgAdt  >ruuni+kiri !24_S	et	f	\N
185042	9-10saj	### 9-10saj	et	f	\N
185074	atek	?atek =atek  (SgN  >atek !02_S	et	f	\N
185075	paleoliitikumi	paleoliitikumi =paleoliitikumi  (SgG  >paleoliitikum !19_S	et	f	\N
185076	paleoliitikumi	paleoliitikumi =paleoliitikumi  (SgP  >paleoliitikum !19_S	et	f	\N
185077	paleoliitikumi	paleoliitikumi =paleoliitikumi  (SgAdt  >paleoliitikum !19_S	et	f	\N
185087	küttimisega	küttimisega =küttimise  (SgKom  >küttimine !12_S	et	f	\N
185088	küttimisega	"küttimine %kütti  )MINE_vS  <küttima ;28_V	et	f	\N
185103	kammivajutistega	?kammivajutistega =kammivajutis  (PlKom  >kammivajutis !09_S	et	f	\N
185104	kammivajutistega	?kammivajutistega =ivajutis  (PlKom  >kamm+ivajutis !09_S	et	f	\N
185110	kujuliste	kujuliste =kujulis  (PlG  >kujuline !12_A	et	f	\N
185112	kujuliste	"kujuline %kuju  )LINE_aA  <kuju ;17_S	et	f	\N
185121	kõplapõllundust	?kõplapõllundust =kõplapõllundus  (SgP  >kõplapõllundus !11_S	et	f	\N
185141	levimisel	levimisel =levimise  (SgAd  >levimine !12_S	et	f	\N
185142	levimisel	"levimine %levi  )MINE_vS  <levima ;27_V	et	f	\N
185149	suhteline	suhteline =suhteline  (SgN  >suhteline !12_A	et	f	\N
185150	suhteline	"suhteline %suhte  )LINE_aA  <suhe ;06_S	et	f	\N
185156	osavamaks	osavamaks =osavama  (SgTr  >osavam !02_A	et	f	\N
185157	osavamaks	"osavam %osava  )M_cA  <osav ;02_A	et	f	\N
185161	arheoloogilistel	arheoloogilistel =arheoloogilis  (PlAd  >arheoloogiline !12_A	et	f	\N
185162	arheoloogilistel	"arheoloogiline %arheoloogi  )LINE_aA  <arheoloog ;22_S	et	f	\N
185167	neemeri	?neemeri =neemeri  (SgN  >neemeri !01_S	et	f	\N
185168	neemeri	?neemeri =neemeri  (SgG  >neemeri !01_S	et	f	\N
185169	neemeri	?neemeri =neemeri  (SgG  >neemer !02_S	et	f	\N
185190	põhja-leedu	põhja-leedu =leedu  (SgN  >põhja-leedu !16_S	et	f	\N
185191	põhja-leedu	"põhja-leedu %lee  )TU1_vS  <põhja-leema ;37_V	et	f	\N
185192	põhja-leedu	põhja-leedu =leedu  (SgG  >põhja-leedu !16_S	et	f	\N
185199	kvaliteetsemad	kvaliteetsemad =kvaliteetsema  (PlN  >kvaliteetsem !02_A	et	f	\N
185200	kvaliteetsemad	"kvaliteetsem %kvaliteetse  )M_cA  <kvaliteetne ;02_A	et	f	\N
185212	paadikujulised	paadikujulised =kujulise  (PlN  >paadi+kujuline !12_A	et	f	\N
185213	paadikujulised	"paadi+kujuline %kuju  )LINE_aA  <paadi+kuju ;17_S	et	f	\N
185214	nõõriga	?nõõriga =nõõri  (SgKom  >nõõri !16_S	et	f	\N
185215	nõõriga	?nõõriga =nõõri  (SgKom  >nõõr !22_S	et	f	\N
185216	mustreid	mustreid =mustre  (PlP  >muster !02_S	et	f	\N
185217	mustreid	mustreid =reid  (SgN  >must+reid !22_S	et	f	\N
185224	asulakoha	asulakoha =koha  (SgN  >asula+koha !17_S	et	f	\N
185225	asulakoha	asulakoha =koha  (SgG  >asula+koha !17_S	et	f	\N
185226	asulakoha	asulakoha =koha  (SgG  >asula+koht !22_S	et	f	\N
185227	asulakoha	asulakoha =koha  (SgP  >asula+koha !17_S	et	f	\N
185228	poleoliitikume	?poleoliitikume =poleoliitiku  (IndPrPl1  >poleoliitikuma !27_V	et	f	\N
185229	poleoliitikume	?poleoliitikume =poleoliitikume  (PlP  >poleoliitikum !19_S	et	f	\N
185230	liikuva	liikuva =liikuva  (SgG  >liikuv !02_A	et	f	\N
185231	liikuva	"liikuv %liiku  )V_vA  <liikuma ;28_V	et	f	\N
185281	vibu	vibu =vibu  (SgN  >vibu !17_S	et	f	\N
185282	vibu	vibu =vibu  (SgG  >vibu !17_S	et	f	\N
185283	vibu	vibu =vibu  (SgP  >vibu !17_S	et	f	\N
185295	sarnaneva	sarnaneva =sarnaneva  (SgG  >sarnanev !02_A	et	f	\N
185004	haigustest	"haigus %haige  )US_aS  <haige ;01_AS	et	f	\N
185005	haigustest	haigustest =test  (SgN  >haigus+test !22_S	et	f	\N
185016	meelerahu	meelerahu =rahu  (SgN  >meele+rahu !17_S	et	f	\N
185017	meelerahu	meelerahu =rahu  (SgG  >meele+rahu !17_S	et	f	\N
185018	meelerahu	meelerahu =rahu  (SgP  >meele+rahu !17_S	et	f	\N
185053	lühiajalist	lühiajalist =ajalis  (SgP  >lühi+ajaline !12_A	et	f	\N
185054	lühiajalist	"lühi+ajaline %aja  )LINE_aA  <lühi+aeg ;22_S	et	f	\N
185119	algelist	algelist =algelis  (SgP  >algeline !12_A	et	f	\N
185120	algelist	"algeline %alge  )LINE_aA  <alge ;06_S	et	f	\N
185122	lelistellkividest	?lelistellkividest =lelistellkivides  (SgP  >lelistellkividene !12_A	et	f	\N
185125	toiduallikas	toiduallikas =allika  (SgIn  >toidu+allikas !02_S	et	f	\N
185126	toiduallikas	toiduallikas =allikas  (SgN  >toidu+allikas !02_S	et	f	\N
185145	animeeritud	?animeeritud =animeeri  (PtsPtIps  >animeerima !28_V	et	f	\N
185146	animeeritud	?animeeritud =animeeritu  (PlN  >animeeritu !01_S	et	f	\N
185147	animeeritud	?animeeritud =animeeritu  (IndPrSg2  >animeerituma !27_V	et	f	\N
185148	animeeritud	?animeeritud =animeeritud  (ID  >animeeritud !41_A	et	f	\N
185158	sõjakamaks	sõjakamaks =sõjakama  (SgTr  >sõjakam !02_A	et	f	\N
185159	sõjakamaks	"sõjakam %sõjaka  )M_cA  <sõjakas ;02_A	et	f	\N
185160	sõjakamaks	sõjakamaks =kama  (SgTr  >sõja+kama !17_S	et	f	\N
185165	arheoloogilistest	arheoloogilistest =arheoloogilis  (PlEl  >arheoloogiline !12_A	et	f	\N
185166	arheoloogilistest	"arheoloogiline %arheoloogi  )LINE_aA  <arheoloog ;22_S	et	f	\N
185170	vahetasid	vahetasid =vaheta  (IndIpfSg2  >vahetama !27_V	et	f	\N
185171	vahetasid	vahetasid =vaheta  (IndIpfPl3  >vahetama !27_V	et	f	\N
185172	elukohti	elukohti =kohti  (SgP  >elu+koht !22_S	et	f	\N
185173	elukohti	elukohti =kohti  (SgAdt  >elu+koht !22_S	et	f	\N
185174	elukohti	elukohti =kohti  (PlP  >elu+koht !22_S	et	f	\N
185177	20-100-kesti	--kesti =kesti  (SgG  >--kest !22_S	et	f	\N
185178	20-100-kesti	--kesti =kesti  (SgP  >--kest !22_S	et	f	\N
185179	20-100-kesti	--kesti =kesti  (SgAdt  >--kest !22_S	et	f	\N
185180	20-100-kesti	--kesti =kesti  (PlP  >--kest !22_S	et	f	\N
185193	lõuna-leedu	lõuna-leedu =leedu  (SgN  >lõuna-leedu !16_S	et	f	\N
185194	lõuna-leedu	"lõuna-leedu %lee  )TU1_vS  <lõuna-leema ;37_V	et	f	\N
185195	lõuna-leedu	lõuna-leedu =leedu  (SgG  >lõuna-leedu !16_S	et	f	\N
185201	kammiga	kammiga =kammi  (SgKom  >kamm !22_S	et	f	\N
185202	kammiga	kammiga =iga  (SgN  >kamm+iga !18_S	et	f	\N
185203	kammiga	kammiga =iga  (SgP  >kamm+iga !18_S	et	f	\N
185218	väljaspoole	väljaspoole =poole  (SgN  >väljas+poole !05_S	et	f	\N
185219	väljaspoole	väljaspoole =poole  (PlP  >väljas+pool !22_S	et	f	\N
185222	ajajargu	?ajajargu =ajajargu  (IndPrPs_  >ajajarguma !27_V	et	f	\N
185223	ajajargu	?ajajargu =ajajargu  (ImpPrSg2  >ajajarguma !27_V	et	f	\N
185232	liikusid	liikusid =liiku  (PlP  >liik !22_S	et	f	\N
185233	liikusid	liikusid =liiku  (IndIpfSg2  >liikuma !28_V	et	f	\N
185234	liikusid	liikusid =liiku  (IndIpfPl3  >liikuma !28_V	et	f	\N
185235	salgad	salgad =salga  (PlN  >salk !22_S	et	f	\N
185236	salgad	salgad =salga  (IndPrSg2  >salgama !29_V	et	f	\N
185246	sarvi	sarvi =sarvi  (SgG  >sarv !22_S	et	f	\N
185247	sarvi	sarvi =sarvi  (SgP  >sarv !22_S	et	f	\N
185248	sarvi	sarvi =sarvi  (SgAdt  >sarv !22_S	et	f	\N
185249	sarvi	sarvi =sarvi  (PlP  >sarv !22_S	et	f	\N
185250	paremini-	paremini- =paremi  (SgTer  >parem !02_A	et	f	\N
185251	paremini-	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
185252	paremini-	paremini- =paremini  (ID  >paremini !41_D	et	f	\N
185253	paremini-	paremini- =ini  (SgN  >parem+ini !17_S	et	f	\N
185254	paremini-	paremini- =ini  (SgG  >parem+ini !17_S	et	f	\N
185255	paremini-	paremini- =ini  (SgP  >parem+ini !17_S	et	f	\N
185262	püstkoha	püstkoha =koha  (SgN  >püst+koha !17_S	et	f	\N
185263	püstkoha	püstkoha =koha  (SgG  >püst+koha !17_S	et	f	\N
185264	püstkoha	püstkoha =koha  (SgG  >püst+koht !22_S	et	f	\N
185265	püstkoha	püstkoha =koha  (SgP  >püst+koha !17_S	et	f	\N
185266	erberiistu	?erberiistu =erberiistu  (IndPrPs_  >erberiistuma !27_V	et	f	\N
185267	erberiistu	?erberiistu =erberiistu  (ImpPrSg2  >erberiistuma !27_V	et	f	\N
185268	kivikõrveid	?kivikõrveid =kivikõrvei  (PlN  >kivikõrvei !26_S	et	f	\N
185269	kivikõrveid	?kivikõrveid =kivikõrvei  (SgP  >kivikõrvei !26_S	et	f	\N
185271	kivikõrveid	?kivikõrveid =kõrvei  (PlN  >kivi+kõrvei !26_S	et	f	\N
185273	kivikõrveid	?kivikõrveid =kõrvei  (SgP  >kivi+kõrvei !26_S	et	f	\N
185274	kivikõrveid	?kivikõrveid =kõrveid  (SgN  >kivi+kõrveid !22_S	et	f	\N
185288	laemalt	?laemalt =laema  (SgAbl  >laema !16_S	et	f	\N
185289	laemalt	?laemalt =laemalt  (ID  >laemalt !41_D	et	f	\N
185290	laemalt	?laemalt =malt  (SgN  >lae+malt !22_S	et	f	\N
185299	neemevi	?neemevi =neemevi  (ID  >neemevi !41_D	et	f	\N
185300	neemevi	?neemevi =neemevi  (SgG  >neemev !02_A	et	f	\N
185310	väiksemad	väiksemad =väiksema  (PlN  >väiksem !02_A	et	f	\N
185311	väiksemad	"väiksem %väikse  )M_cA  <väike ;10_A	et	f	\N
185324	kammkeraamikakultuur	?kammkeraamikakultuur =kammkeraamikakultuur  (SgN  >kammkeraamikakultuur !22_S	et	f	\N
185325	kammkeraamikakultuur	?kammkeraamikakultuur =amikakultuur  (SgN  >kamm+kera+amikakultuur !22_S	et	f	\N
185100	nooleotsiga	nooleotsiga =otsi  (SgKom  >noole+ots !22_S	et	f	\N
185105	koonuselise	koonuselise =koonuselise  (SgG  >koonuseline !12_A	et	f	\N
185106	koonuselise	"koonuseline %koonuse  )LINE_aA  <koonus ;09_S	et	f	\N
185107	koonuselise	"koonuseline %koonuse  )LINE_aA  <koonus ;11_S	et	f	\N
185127	metstarvast	metstarvast =tarva  (SgEl  >mets+tarvas !07_S	et	f	\N
185128	metstarvast	metstarvast =tarvas  (SgP  >mets+tarvas !07_S	et	f	\N
185129	metstarvast	metstarvast =tarvas  (SgP  >mets+tarvane !10_A	et	f	\N
185130	metstarvast	"mets+tarvane %tarva  )NE_aA  <mets+tarvas ;07_S	et	f	\N
185135	kogukonnas	kogukonnas =kogukonna  (SgIn  >kogukond !22_S	et	f	\N
185136	kogukonnas	kogukonnas =konna  (SgIn  >kogu+konn !22_S	et	f	\N
185181	paiknesid	paiknesid =paikne  (IndIpfSg2  >paiknema !27_V	et	f	\N
185182	paiknesid	paiknesid =paikne  (IndIpfPl3  >paiknema !27_V	et	f	\N
185220	kägaras	kägaras =kägara  (SgIn  >kägar !02_S	et	f	\N
185221	kägaras	kägaras =kägaras  (ID  >kägaras !41_DA	et	f	\N
185241	rõivaste	rõivaste =rõivas  (PlG  >rõivas !07_S	et	f	\N
185242	rõivaste	rõivaste =rõivas  (PlG  >rõivane !10_A	et	f	\N
185243	rõivaste	"rõivane %rõiva  )NE_aA  <rõivas ;07_S	et	f	\N
185244	katmiseks	katmiseks =katmise  (SgTr  >katmine !12?10_S	et	f	\N
185245	katmiseks	"katmine %kat  )MINE_vS  <katma ;35_V	et	f	\N
185256	tööristu	?tööristu =tööristu  (SgN  >tööristu !01_S	et	f	\N
185257	tööristu	?tööristu =tööristu  (SgG  >tööristu !01_S	et	f	\N
185258	tööristu	?tööristu =tööristu  (IndPrPs_  >tööristuma !27_V	et	f	\N
185259	tööristu	?tööristu =tööristu  (ImpPrSg2  >tööristuma !27_V	et	f	\N
185260	tööristu	?tööristu =ristu  (SgN  >töö+ristu !16_S	et	f	\N
185261	tööristu	?tööristu =ristu  (SgG  >töö+ristu !16_S	et	f	\N
185284	töödavate	?töödavate =töödava  (PlG  >töödava !01_S	et	f	\N
185285	töödavate	?töödavate =töödava  (PlG  >töödav !02_A	et	f	\N
185286	luu	luu =luu  (SgN  >luu !26_S	et	f	\N
185287	luu	luu =luu  (SgG  >luu !26_S	et	f	\N
185293	eesnevatest	eesnevatest =eesneva  (PlEl  >eesnev !02_A	et	f	\N
185294	eesnevatest	"eesnev %eesne  )V_vA  <eesnema ;27_V	et	f	\N
185304	paiksemad	paiksemad =paiksema  (PlN  >paiksem !02_A	et	f	\N
185305	paiksemad	"paiksem %paikse  )M_cA  <paikne ;02_A	et	f	\N
185318	paiksemaks	paiksemaks =paiksema  (SgTr  >paiksem !02_A	et	f	\N
185319	paiksemaks	"paiksem %paikse  )M_cA  <paikne ;02_A	et	f	\N
185320	hernes	hernes =herne  (SgIn  >hernes !07_S	et	f	\N
185321	hernes	hernes =hernes  (SgN  >hernes !07_S	et	f	\N
185322	uba	uba =uba  (SgN  >uba !18_S	et	f	\N
185323	uba	uba =uba  (SgP  >uba !18_S	et	f	\N
185327	kaunistati	kaunistati =kaunista  (IndIpfIps  >kaunistama !27_V	et	f	\N
185328	kaunistati	kaunistati =tati  (SgG  >kaunis+tatt !22_S	et	f	\N
185346	liiguti	liiguti =liigu  (IndIpfIps  >liikuma !28_V	et	f	\N
185347	liiguti	liiguti =uti  (SgG  >liig+utt !22_S	et	f	\N
185360	vaadeti	?vaadeti =vaade  (IndIpfIps  >vaadema !27_V	et	f	\N
185361	vaadeti	?vaadeti =vaadeti  (ID  >vaadeti !41_D	et	f	\N
185362	vaadeti	?vaadeti =vaadeti  (SgG  >vaadett !22_S	et	f	\N
185363	vaadeti	?vaadeti =vaadeti  (IndPrPs_  >vaadettima !28_V	et	f	\N
185366	vaadeti	?vaadeti =vaadeti  (ImpPrSg2  >vaadettima !28_V	et	f	\N
185386	rahvakunsti	rahvakunsti =kunsti  (SgG  >rahva+kunst !22_S	et	f	\N
185387	rahvakunsti	rahvakunsti =kunsti  (SgP  >rahva+kunst !22_S	et	f	\N
185388	rahvakunsti	rahvakunsti =kunsti  (SgAdt  >rahva+kunst !22_S	et	f	\N
185409	seebikad9	?seebikad =seebika  (PlN  >seebika !01_S	et	f	\N
185410	seebikad9	?seebikad =seebika  (PlN  >seebikas !02_S	et	f	\N
185411	seebikad9	?seebikad =bika  (PlN  >see+bika !16_S	et	f	\N
185421	leiesi	?leiesi =leiesi  (ID  >leiesi !41_D	et	f	\N
185423	leiesi	?leiesi =leiesi  (SgG  >leies !02_S	et	f	\N
185424	leiesi	?leiesi =leiesi  (IndPrPs_  >leiesima !28_V	et	f	\N
185425	leiesi	?leiesi =leiesi  (ImpPrSg2  >leiesima !28_V	et	f	\N
185426	multifilmi	multifilmi =filmi  (SgG  >multi+film !22_S	et	f	\N
185427	multifilmi	multifilmi =filmi  (SgP  >multi+film !22_S	et	f	\N
185428	multifilmi	multifilmi =filmi  (SgAdt  >multi+film !22_S	et	f	\N
185429	hullumeelsus	hullumeelsus =meelsus  (SgN  >hullu+meelsus !11~09_S	et	f	\N
185430	hullumeelsus	"hullu+meelsus %meelse  )US_aS  <hullu+meelne ;02_A	et	f	\N
185433	kaljo	?kaljo =kaljo  (SgN  >kaljo !16_S	et	f	\N
185434	kaljo	?kaljo =kaljo  (SgG  >kaljo !16_S	et	f	\N
185472	väljakutse	väljakutse =kutse  (SgN  >välja+kutse !06_S	et	f	\N
185473	väljakutse	väljakutse =kutse  (SgG  >välja+kutse !06_S	et	f	\N
185474	väljakutse	väljakutse =kutse  (PlP  >välja+kuts !22_S	et	f	\N
185477	kõrgemate	kõrgemate =kõrgema  (PlG  >kõrgem !02_A	et	f	\N
185478	kõrgemate	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
185479	kõrgemate	kõrgemate =mate  (SgN  >kõrge+mate !16_S	et	f	\N
185480	kõrgemate	kõrgemate =mate  (SgG  >kõrge+mate !16_S	et	f	\N
185481	bej	### bej	et	f	\N
185521	ühenenud	?ühenenud =ühene  (PtsPtPs  >ühenema !27_V	et	f	\N
185522	ühenenud	?ühenenud =ühenenu  (PlN  >ühenenu !01_S	et	f	\N
185523	ühenenud	?ühenenud =ühenenu  (IndPrSg2  >ühenenuma !27_V	et	f	\N
185524	ühenenud	?ühenenud =ühenenud  (ID  >ühenenud !41_A	et	f	\N
185102	mesoliitikul	?mesoliitikul =mesoliitikul  (SgN  >mesoliitikul !19_S	et	f	\N
185108	koonusekujulised	?koonusekujulised =koonusekujulise  (PlN  >koonusekujuline !12_A	et	f	\N
185109	koonusekujulised	?koonusekujulised =usekujulise  (PlN  >koon+usekujuline !12_A	et	f	\N
185111	kirvedega	### kirvedega	et	f	\N
185115	kalastamine	kalastamine =kalastamine  (SgN  >kalastamine !12_S	et	f	\N
185116	kalastamine	"kalastamine %kalasta  )MINE_vS  <kalastama ;27_V	et	f	\N
185139	noorkeraamika	noorkeraamika =keraamika  (SgN  >noor+keraamika !01_S	et	f	\N
185140	noorkeraamika	noorkeraamika =keraamika  (SgG  >noor+keraamika !01_S	et	f	\N
185154	rikkamaks	?rikkamaks =rikka  (SupTr  >rikkama !29_V	et	f	\N
185155	rikkamaks	?rikkamaks =rikkama  (SgTr  >rikkam !02_A	et	f	\N
185175	pikaajalisi	pikaajalisi =ajalisi  (PlP  >pika+ajaline !12_A	et	f	\N
185176	pikaajalisi	"pika+ajaline %aja  )LINE_aA  <pika+aeg ;22_S	et	f	\N
185186	sarvest	sarvest =sarve  (SgEl  >sarv !22_S	et	f	\N
185187	sarvest	sarvest =sarve  (PlEl  >sarv !22_S	et	f	\N
185188	sarvest	sarvest =sarves  (SgP  >sarvene !10_A	et	f	\N
185189	sarvest	"sarvene %sarve  )NE_aA  <sarv ;22_S	et	f	\N
185204	augustatud	augustatud =augusta  (PtsPtIps  >augustama !27_V	et	f	\N
185205	augustatud	augustatud =augustatu  (PlN  >augustatu !01_S	et	f	\N
185206	augustatud	"augustatu %augusta  )TU1_vS  <augustama ;27_V	et	f	\N
185207	augustatud	augustatud =augustatud  (ID  >augustatud !41_A	et	f	\N
185208	augustatud	"augustatud %augusta  )TUD_vA  <augustama ;27_V	et	f	\N
185275	uuenduseks	uuenduseks =uuenduse  (SgTr  >uuendus !11_S	et	f	\N
185276	uuenduseks	"uuendus %uuenda  )US_vS  <uuendama ;27_V	et	f	\N
185291	meieni	meieni =meie  (PlTer  >mina !00_P	et	f	\N
185292	meieni	meieni =meie  (SgTer  >meie !16_S	et	f	\N
185301	savikvartsgraniiditükkid	### savikvartsgraniiditükkid	et	f	\N
185302	lühiajalisi	lühiajalisi =ajalisi  (PlP  >lühi+ajaline !12_A	et	f	\N
185303	lühiajalisi	"lühi+ajaline %aja  )LINE_aA  <lühi+aeg ;22_S	et	f	\N
185308	korilusega	korilusega =koriluse  (SgKom  >korilus !11_S	et	f	\N
185309	korilusega	"korilus %korilase  )US_aS  <korilane ;12_S	et	f	\N
185316	kaeti	kaeti =kae  (IndIpfIps  >kaema !27_V	et	f	\N
185317	kaeti	kaeti =kae  (IndIpfIps  >katma !35_V	et	f	\N
185331	sisserännanud	sisserännanud =ränna  (PtsPtPs  >sisse+_rändama !29_V	et	f	\N
185332	sisserännanud	sisserännanud =rännanu  (PlN  >sisse+rännanu !01_S	et	f	\N
185339	hilisema	hilisema =hilisema  (SgG  >hilisem !02_A	et	f	\N
185340	hilisema	"hilisem %hilise  )M_cA  <hiline ;10_A	et	f	\N
185341	hilisema	hilisema =ema  (SgN  >hilis+ema !17_S	et	f	\N
185342	hilisema	hilisema =ema  (SgG  >hilis+ema !17_S	et	f	\N
185343	hilisema	hilisema =ema  (SgP  >hilis+ema !17_S	et	f	\N
185350	piirkonda	piirkonda =piirkonda  (SgP  >piirkond !22_S	et	f	\N
185351	piirkonda	piirkonda =piirkonda  (SgAdt  >piirkond !22_S	et	f	\N
185356	kulmkapid	?kulmkapid =kulmkapi  (PlN  >kulmkapi !01_S	et	f	\N
185357	kulmkapid	?kulmkapid =kulmkapi  (PlN  >kulmkap !02_S	et	f	\N
185358	kulmkapid	?kulmkapid =kulmkapi  (PlN  >kulmkapp !22_S	et	f	\N
185359	kulmkapid	?kulmkapid =kulmkapi  (IndPrSg2  >kulmkappima !28_V	et	f	\N
185364	tekevisiooni	?tekevisiooni =tekevisioo  (SgTer  >tekevisioo !26_S	et	f	\N
185365	tekevisiooni	?tekevisiooni =tekevisiooni  (SgN  >tekevisiooni !16_S	et	f	\N
185367	tekevisiooni	?tekevisiooni =tekevisiooni  (SgG  >tekevisiooni !16_S	et	f	\N
185368	tekevisiooni	?tekevisiooni =tekevisiooni  (SgG  >tekevisioon !22_S	et	f	\N
185369	tekevisiooni	?tekevisiooni =tekevisiooni  (SgP  >tekevisioon !22_S	et	f	\N
185370	tekevisiooni	?tekevisiooni =tekevisiooni  (SgAdt  >tekevisioon !22_S	et	f	\N
185371	tekevisiooni	?tekevisiooni =tekevisiooni  (IndPrPs_  >tekevisioonima !28_V	et	f	\N
185372	tekevisiooni	?tekevisiooni =tekevisiooni  (ImpPrSg2  >tekevisioonima !28_V	et	f	\N
185378	välismaist	välismaist =ma  (PlEl  >välis+maa !26_S	et	f	\N
185379	välismaist	välismaist =mai  (SgEl  >välis+mai !26_S	et	f	\N
185380	välismaist	välismaist =mais  (SgP  >välis+maine !10_A	et	f	\N
185381	välismaist	"välis+maine %mai  )NE_aA  <välis+maa ;26_S	et	f	\N
185382	uku	?uku =uku  (SgN  >uku !16_S	et	f	\N
185383	uku	?uku =uku  (SgG  >uku !16_S	et	f	\N
185384	uku	?uku =uku  (IndPrPs_  >ukuma !27_V	et	f	\N
185385	uku	?uku =uku  (ImpPrSg2  >ukuma !27_V	et	f	\N
185394	lapstähtede	lapstähtede =ede  (SgN  >laps+täht+ede !16_S	et	f	\N
185395	lapstähtede	lapstähtede =ede  (SgG  >laps+täht+ede !16_S	et	f	\N
185396	lapstähtede	lapstähtede =tähte  (PlG  >laps+täht !22_S	et	f	\N
185404	produteerima	?produteerima =produteeri  (Sup  >produteerima !28_V	et	f	\N
185405	produteerima	?produteerima =produteerima  (SgG  >produteerim !02_A	et	f	\N
185408	eid	?eid =eid  (SgN  >eid !22_S	et	f	\N
185412	kajastav	kajastav =kajasta  (PtsPrPs  >kajastama !27_V	et	f	\N
185413	kajastav	kajastav =kajastav  (SgN  >kajastav !02_A	et	f	\N
185414	kajastav	"kajastav %kajasta  )V_vA  <kajastama ;27_V	et	f	\N
185417	panti	panti =panti  (SgP  >pant !22_S	et	f	\N
185418	panti	panti =panti  (SgAdt  >pant !22_S	et	f	\N
185419	uno	?uno =uno  (SgN  >uno !17~16_S	et	f	\N
185420	uno	?uno =uno  (SgG  >uno !17~16_S	et	f	\N
185422	uno	?uno =uno  (SgP  >uno !17_S	et	f	\N
185211	nõõrkeraamika	?nõõrkeraamika =nõõrkeraamika  (SgG  >nõõrkeraamikas !02_A	et	f	\N
185237	põhjapõdru	?põhjapõdru =põhjapõdru  (IndPrPs_  >põhjapõdruma !27_V	et	f	\N
185238	põhjapõdru	?põhjapõdru =põhjapõdru  (ImpPrSg2  >põhjapõdruma !27_V	et	f	\N
185239	põhjapõdru	?põhjapõdru =põdru  (SgN  >põhja+põdru !16_S	et	f	\N
185240	põhjapõdru	?põhjapõdru =põdru  (SgG  >põhja+põdru !16_S	et	f	\N
185270	tahtsaks	?tahtsaks =tahtsa  (SgTr  >tahtsa !01_S	et	f	\N
185272	tahtsaks	?tahtsaks =tahtsa  (KndPrPs  >tahtsama !29_V	et	f	\N
185277	metsloomi	metsloomi =loomi  (SgG  >mets+loom !22_S	et	f	\N
185278	metsloomi	metsloomi =loomi  (SgP  >mets+loom !22_S	et	f	\N
185279	metsloomi	metsloomi =loomi  (SgAdt  >mets+loom !22_S	et	f	\N
185280	metsloomi	metsloomi =loomi  (PlP  >mets+loom !22_S	et	f	\N
185306	inimasutused	inimasutused =asutuse  (PlN  >inim+asutus !11_S	et	f	\N
185307	inimasutused	"inim+asutus %asu  )TUS2_aS  <inim+asu ;17_S	et	f	\N
185329	kammitaolise	?kammitaolise =kammitaolise  (SgG  >kammitaoline !12?10_A	et	f	\N
185330	kammitaolise	?kammitaolise =itaolise  (SgG  >kamm+itaoline !12?10_A	et	f	\N
185348	inimtegevuse	inimtegevuse =tegevuse  (SgG  >inim+tegevus !11_S	et	f	\N
185349	inimtegevuse	"inim+tegevus %tegeva  )US_aS  <inim+tegev ;02_A	et	f	\N
185375	praami-	praami- =praami  (SgG  >praam !22_S	et	f	\N
185376	praami-	praami- =praami  (SgP  >praam !22_S	et	f	\N
185377	praami-	praami- =praami  (SgAdt  >praam !22_S	et	f	\N
185397	laulukonkurssedel	### laulukonkurssedel	et	f	\N
185435	kõrboja	kõrboja =oja  (SgN  >kõrb+oja !17_S	et	f	\N
185436	kõrboja	kõrboja =oja  (SgG  >kõrb+oja !17_S	et	f	\N
185437	kõrboja	kõrboja =oja  (SgP  >kõrb+oja !17_S	et	f	\N
185438	kinokunsti	kinokunsti =kunsti  (SgG  >kino+kunst !22_S	et	f	\N
185439	kinokunsti	kinokunsti =kunsti  (SgP  >kino+kunst !22_S	et	f	\N
185440	kinokunsti	kinokunsti =kunsti  (SgAdt  >kino+kunst !22_S	et	f	\N
185444	novaatorlikku	novaatorlikku =novaatorlikku  (SgP  >novaatorlik !25_A	et	f	\N
185445	novaatorlikku	novaatorlikku =novaatorlikku  (SgAdt  >novaatorlik !25_A	et	f	\N
185463	jõuline	jõuline =jõuline  (SgN  >jõuline !12?10_A	et	f	\N
185464	jõuline	"jõuline %jõu  )LINE_aA  <jõud ;22_S	et	f	\N
185465	jõuline	"jõuline %jõuli  )NE_aA  <jõul ;22_S	et	f	\N
185470	alluvale	alluvale =alluva  (SgAll  >alluv !02_AS	et	f	\N
185471	alluvale	"alluv %allu  )V_vA  <alluma ;27_V	et	f	\N
185493	sotskiituslikele	?sotskiituslikele =sotskiituslike  (PlAll  >sotskiituslik !25_A	et	f	\N
185494	sotskiituslikele	?sotskiituslikele =kiituslike  (PlAll  >sots+kiituslik !25_A	et	f	\N
185517	kõikuvad	kõikuvad =kõikuva  (PlN  >kõikuv !02_A	et	f	\N
185518	kõikuvad	"kõikuv %kõiku  )V_vA  <kõikuma ;28_V	et	f	\N
185519	staalin	?staalin =staali  (IndPrSg1  >staalima !28_V	et	f	\N
185520	staalin	?staalin =staalin  (SgN  >staalin !02_S	et	f	\N
185526	stotsiumi	?stotsiumi =stotsiumi  (SgN  >stotsiumi !16_S	et	f	\N
185527	stotsiumi	?stotsiumi =stotsiumi  (SgG  >stotsium !19~02_S	et	f	\N
185528	stotsiumi	?stotsiumi =stotsiumi  (SgG  >stotsiumi !16_S	et	f	\N
185529	stotsiumi	?stotsiumi =stotsiumi  (SgP  >stotsium !19_S	et	f	\N
185530	stotsiumi	?stotsiumi =stotsiumi  (SgAdt  >stotsium !19_S	et	f	\N
185531	stotsiumi	?stotsiumi =stotsiumi  (IndPrPs_  >stotsiumima !28_V	et	f	\N
185532	stotsiumi	?stotsiumi =stotsiumi  (ImpPrSg2  >stotsiumima !28_V	et	f	\N
185551	korduvat	korduvat =kordu  (KvtPrPs  >korduma !27_V	et	f	\N
185552	korduvat	korduvat =korduva  (SgP  >korduv !02_A	et	f	\N
185553	korduvat	"korduv %kordu  )V_vA  <korduma ;27_V	et	f	\N
185566	kaevandustes	kaevandustes =kaevandus  (PlIn  >kaevandus !11_S	et	f	\N
185567	kaevandustes	"kaevandus %kaevanda  )US_vS  <kaevandama ;27_V	et	f	\N
185568	jõukusele	jõukusele =jõukuse  (SgAll  >jõukus !11~09_S	et	f	\N
185569	jõukusele	"jõukus %jõuka  )US_aS  <jõukas ;02_A	et	f	\N
185570	jõukusele	jõukusele =kuse  (SgAll  >jõu+kusi !20_S	et	f	\N
185572	nsvls	### nsvls	et	f	\N
185573	mõeldavgi	mõeldavgi =mõel  (PtsPrIps^  >mõtlema !30_V	et	f	\N
185574	mõeldavgi	mõeldavgi =mõeldav  (SgN^  >mõeldav !02_A	et	f	\N
185575	mõeldavgi	"mõeldav %mõel  )TAV_vAS^  <mõtlema ;30_V	et	f	\N
185594	läinudki	läinudki =läi  (PtsPtPs^  >minema !36_V	et	f	\N
185595	läinudki	läinudki =läinu  (PlN^  >läinu !01_S	et	f	\N
185596	läinudki	"läinu %läi  )NU_vS^  <minema ;36_V	et	f	\N
185597	läinudki	läinudki =läinu  (PlN^  >läinu !06_S	et	f	\N
185598	läinudki	läinudki =läinud  (ID^  >läinud !41_A	et	f	\N
185599	läinudki	"läinud %läi  )NUD_vA^  <minema ;36_V	et	f	\N
185612	lukutaga	### lukutaga	et	f	\N
185622	läänelikkuse	?läänelikkuse =läänelikkuse  (SgG  >läänelikkus !11~09_S	et	f	\N
185625	elutaloodusele	?elutaloodusele =elutalooduse  (SgAll  >elutaloodus !11~09_S	et	f	\N
185626	elutaloodusele	?elutaloodusele =talooduse  (SgAll  >elu+taloodus !11~09_S	et	f	\N
185654	kehtestataxe	### kehtestataxe	et	f	\N
185659	paixetele	?paixetele =paixe  (PlAll  >paixe !06_S	et	f	\N
185660	paixetele	?paixetele =paixete  (PlAll  >paixett !22_S	et	f	\N
185661	paixetele	?paixetele =paixetele  (IndPrPs_  >paixetelema !36_V	et	f	\N
185662	paixetele	?paixetele =paixetele  (ImpPrSg2  >paixetelema !36_V	et	f	\N
185663	paixetele	?paixetele =xete  (PlAll  >pai+xett !22_S	et	f	\N
185296	sarnaneva	"sarnanev %sarnane  )V_vA  <sarnanema ;27_V	et	f	\N
185297	kirvete	?kirvete =kirve  (PlG  >kirve !06_S	et	f	\N
185298	kirvete	?kirvete =kirve  (IndPrPl2  >kirvema !27_V	et	f	\N
185312	tulekolle	tulekolle =kolle  (SgN  >tule+kolle !06_S	et	f	\N
185313	tulekolle	tulekolle =kolle  (PlP  >tule+koll !22_S	et	f	\N
185314	koda	koda =koda  (SgN  >koda !18_S	et	f	\N
185315	koda	koda =koda  (SgP  >koda !18_S	et	f	\N
185352	osatu	osatu =osatu  (SgN  >osatu !01_AS	et	f	\N
185353	osatu	"osatu %osa  )TU1_vS  <oskama ;29_V	et	f	\N
185354	osatu	"osatu %osa  )TU2_kA  <osa ;17_S	et	f	\N
185355	osatu	osatu =osatu  (SgG  >osatu !01_AS	et	f	\N
185389	suviniiridena	?suviniiridena =suviniiri  (PlEs  >suviniiri !16_S	et	f	\N
185390	suviniiridena	?suviniiridena =suviniiri  (PlEs  >suviniir !22_S	et	f	\N
185391	suviniiridena	?suviniiridena =ride  (SgEs  >suvi+nii+ride !16_S	et	f	\N
185392	suviniiridena	?suviniiridena =niiri  (PlEs  >suvi+niiri !16_S	et	f	\N
185393	suviniiridena	?suviniiridena =niiri  (PlEs  >suvi+niir !22_S	et	f	\N
185403	haaletada	?haaletada =haaleta  (Inf  >haaletama !27_V	et	f	\N
185415	veldo	?veldo =veldo  (SgN  >veldo !16_S	et	f	\N
185416	veldo	?veldo =veldo  (SgG  >veldo !16_S	et	f	\N
185431	tihengut	?tihengut =tihengu  (SgP  >tihengu !01_S	et	f	\N
185432	tihengut	?tihengut =tihengu  (SgP  >tiheng !02_S	et	f	\N
185453	ärakasutatud	ärakasutatud =kasuta  (PtsPtIps  >ära+_kasutama !27_V	et	f	\N
185454	ärakasutatud	ärakasutatud =kasutatu  (PlN  >ära+kasutatu !01_S	et	f	\N
185455	nähtavat	nähtavat =näh  (KvtPrIps  >nägema !28_V	et	f	\N
185456	nähtavat	nähtavat =nähtava  (SgP  >nähtav !02_A	et	f	\N
185457	nähtavat	"nähtav %näh  )TAV_vAS  <nägema ;28_V	et	f	\N
185475	baltiest	?baltiest =baltie  (SgEl  >baltie !01_S	et	f	\N
185476	baltiest	?baltiest =balties  (SgP  >balties !11_S	et	f	\N
185497	keeldureast	?keeldureast =keeldurea  (SgEl  >keeldurea !26_S	et	f	\N
185498	keeldureast	?keeldureast =durea  (SgEl  >keel+durea !26_S	et	f	\N
185499	shakespeare	?shakespeare =shakespeare  (PlP  >shakespear !19_S	et	f	\N
185502	elustasid	elustasid =elusta  (IndIpfSg2  >elustama !27_V	et	f	\N
185503	elustasid	elustasid =elusta  (IndIpfPl3  >elustama !27_V	et	f	\N
185533	tekistabki	?tekistabki =tekistabki  (SgG  >tekistabk !22_S	et	f	\N
185534	tekistabki	?tekistabki =tekistabki  (SgP  >tekistabk !22_S	et	f	\N
185535	tekistabki	?tekistabki =tekistabki  (SgAdt  >tekistabk !22_S	et	f	\N
185536	tekistabki	?tekistabki =tekistabki  (IndPrPs_  >tekistabkima !28_V	et	f	\N
185537	tekistabki	?tekistabki =tekistabki  (ImpPrSg2  >tekistabkima !28_V	et	f	\N
185538	tekistabki	?tekistabki =stabki  (SgG  >teki+stabk !22_S	et	f	\N
185539	tekistabki	?tekistabki =stabki  (SgP  >teki+stabk !22_S	et	f	\N
185540	tekistabki	?tekistabki =stabki  (SgAdt  >teki+stabk !22_S	et	f	\N
185541	tekistabki	?tekistabki =tekista  (IndPrSg3^  >tekistama !27_V	et	f	\N
185542	kosmopolit	?kosmopolit =polit  (SgN  >kosmo+polit !02_S	et	f	\N
185557	suhtused	?suhtused =suhtuse  (PlN  >suhtus !11~09_S	et	f	\N
185558	suhtused	?suhtused =use  (PlN  >suht+use !16_S	et	f	\N
185562	kukkamõistu	?kukkamõistu =kukkamõistu  (IndPrPs_  >kukkamõistuma !27_V	et	f	\N
185565	kukkamõistu	?kukkamõistu =kukkamõistu  (ImpPrSg2  >kukkamõistuma !27_V	et	f	\N
185576	kundagi	?kundagi =kunda  (SgN^  >kunda !16_S	et	f	\N
185577	kundagi	?kundagi =kunda  (SgG^  >kunda !16_S	et	f	\N
185578	kundagi	?kundagi =kunda  (IndPrPs_^  >kundama !29_V	et	f	\N
185579	kundagi	?kundagi =kunda  (ImpPrSg2^  >kundama !29_V	et	f	\N
185606	väljka	?väljka =väljka  (SgN  >väljka !01_S	et	f	\N
185607	väljka	?väljka =väljka  (SgG  >väljka !01_S	et	f	\N
185608	väljka	?väljka =väljka  (IndPrPs_  >väljkama !29_V	et	f	\N
185609	väljka	?väljka =väljka  (ImpPrSg2  >väljkama !29_V	et	f	\N
185623	lähisvälismaa	lähisvälismaa =maa  (SgN  >lähis+välis+maa !26_S	et	f	\N
185624	lähisvälismaa	lähisvälismaa =maa  (SgG  >lähis+välis+maa !26_S	et	f	\N
185640	kaubavahetusel	kaubavahetusel =use  (PlAd  >kauba+vahet+usk !22_S	et	f	\N
185641	kaubavahetusel	kaubavahetusel =vahetuse  (SgAd  >kauba+vahetus !11_S	et	f	\N
185642	kaubavahetusel	"kauba+vahetus %vahe  )TUS2_aS  <kauba+vahe ;16_S	et	f	\N
185645	ümbertöötlema	?ümbertöötlema =ümbertöötlema  (SgG  >ümbertöötlem !02_A	et	f	\N
185646	ümbertöötlema	?ümbertöötlema =töötlema  (SgG  >ümber+töötlem !02_A	et	f	\N
185657	vähemal	vähemal =vähema  (SgAd  >vähem !02_A	et	f	\N
185658	vähemal	"vähem %vähe  )M_cA  <väike ;10_A	et	f	\N
185669	emigreeruvad	?emigreeruvad =emigreeru  (IndPrPl3  >emigreeruma !27_V	et	f	\N
185670	emigreeruvad	?emigreeruvad =emigreeruva  (PlN  >emigreeruv !02_A	et	f	\N
185671	emigreeruvad	?emigreeruvad =emigreeruva  (PlN  >emigreeruva !16_S	et	f	\N
185688	elavale	elavale =elava  (SgAll  >elav !02_A	et	f	\N
185689	elavale	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
185690	elavale	elavale =ale  (SgN  >elav+ale !16_S	et	f	\N
185691	elavale	elavale =ale  (SgG  >elav+ale !16_S	et	f	\N
185697	muldmetellidega	?muldmetellidega =muldmetelli  (PlKom  >muldmetell !22_S	et	f	\N
185699	muldmetellidega	?muldmetellidega =metelli  (PlKom  >muld+metell !22_S	et	f	\N
185706	kutselist	kutselist =kutselis  (SgP  >kutseline !12_A	et	f	\N
185707	kutselist	"kutseline %kutse  )LINE_aA  <kutse ;06_S	et	f	\N
185326	kammkeraamikakultuur	?kammkeraamikakultuur =keraamikakultuur  (SgN  >kamm+keraamikakultuur !22_S	et	f	\N
185333	nöörkeraamikakultuur	?nöörkeraamikakultuur =nöörkeraamikakultuur  (SgN  >nöörkeraamikakultuur !22_S	et	f	\N
185334	nöörkeraamikakultuur	?nöörkeraamikakultuur =amikakultuur  (SgN  >nöör+kera+amikakultuur !22_S	et	f	\N
185335	nöörkeraamikakultuur	?nöörkeraamikakultuur =keraamikakultuur  (SgN  >nöör+keraamikakultuur !22_S	et	f	\N
185336	eelpool	eelpool =pool  (ID  >eel+pool !41_DK	et	f	\N
185337	eelpool	eelpool =pool  (SgN  >eel+pool !13_NS	et	f	\N
185338	eelpool	eelpool =pool  (SgN  >eel+pool !22_S	et	f	\N
185344	kogukonnad	kogukonnad =kogukonna  (PlN  >kogukond !22_S	et	f	\N
185345	kogukonnad	kogukonnad =konna  (PlN  >kogu+konn !22_S	et	f	\N
185373	tallinn-helsinki	?tallinn-helsinki =helsinki  (SgP  >tallinn-helsink !22_S	et	f	\N
185374	tallinn-helsinki	?tallinn-helsinki =helsinki  (SgAdt  >tallinn-helsink !22_S	et	f	\N
185398	entel-tentel	?entel-tentel =tente  (SgAd  >entel-tende !06_S	et	f	\N
185399	entel-tentel	?entel-tentel =tentel  (SgN  >entel-tentel !02_S	et	f	\N
185400	raklaamfilm	?raklaamfilm =raklaamfilm  (SgN  >raklaamfilm !22_S	et	f	\N
185401	samanimelistest	samanimelistest =nimelis  (PlEl  >sama+nimeline !12_A	et	f	\N
185402	samanimelistest	"sama+nimeline %nime  )LINE_aA  <sama+nimi ;20_S	et	f	\N
185406	harivaid	harivaid =hariva  (PlP  >hariv !02_A	et	f	\N
185407	harivaid	"hariv %hari  )V_vA  <harima ;27_V	et	f	\N
185441	viljelejad	viljelejad =viljeleja  (PlN  >viljeleja !01_S	et	f	\N
185442	viljelejad	"viljeleja %viljele  )JA_vS  <viljelema ;27_V	et	f	\N
185443	viljelejad	"viljeleja %viljele  )JA_vS  <viljelema ;31_V	et	f	\N
185446	troot	?troot =troot  (SgN  >troot !22_S	et	f	\N
185448	eranditult	eranditult =eranditu  (SgAbl  >eranditu !01_A	et	f	\N
185449	eranditult	"eranditu %erandi  )TU2_kA  <erand ;02_S	et	f	\N
185450	eranditult	eranditult =eranditult  (ID  >eranditult !41_D	et	f	\N
185451	eranditult	"eranditult %erandi  )TULT2_mD  <erand ;02_S	et	f	\N
185452	eranditult	"eranditult %eranditu  )LT_mD  <eranditu ;01_A	et	f	\N
185458	näitemängu	näitemängu =mängu  (SgG  >näite+mäng !22_S	et	f	\N
185459	näitemängu	näitemängu =mängu  (SgP  >näite+mäng !22_S	et	f	\N
185460	näitemängu	näitemängu =mängu  (SgAdt  >näite+mäng !22_S	et	f	\N
185466	eelarvamustest	eelarvamustest =test  (SgN  >eel+arvamus+test !22_S	et	f	\N
185467	eelarvamustest	eelarvamustest =arvamus  (PlEl  >eel+arvamus !11_S	et	f	\N
185483	tej	### tej	et	f	\N
185489	kultuurimajad	kultuurimajad =maja  (PlN  >kultuuri+maja !17_S	et	f	\N
185490	kultuurimajad	kultuurimajad =imaja  (PlN  >kultuur+imaja !01_S	et	f	\N
185491	kinomajasi	?kinomajasi =kinomajasi  (SgG  >kinomajas !02_A	et	f	\N
185492	kinomajasi	?kinomajasi =kinomajasi  (PlP  >kinomajane !12_A	et	f	\N
185495	nõrgenemine	nõrgenemine =nõrgenemine  (SgN  >nõrgenemine !12_S	et	f	\N
185496	nõrgenemine	"nõrgenemine %nõrgene  )MINE_vS  <nõrgenema ;27_V	et	f	\N
185500	professionaalsetele	professionaalsetele =professionaalse  (PlAll  >professionaalne !02_A	et	f	\N
185501	professionaalsetele	professionaalsetele =sete  (PlAll  >professionaal+sett !22_S	et	f	\N
185514	kollektsiooni	kollektsiooni =kollektsiooni  (SgG  >kollektsioon !22_S	et	f	\N
185515	kollektsiooni	kollektsiooni =kollektsiooni  (SgP  >kollektsioon !22_S	et	f	\N
185516	kollektsiooni	kollektsiooni =kollektsiooni  (SgAdt  >kollektsioon !22_S	et	f	\N
185543	tõestamatu	tõestamatu =tõestamatu  (SgN  >tõestamatu !01_A	et	f	\N
185544	tõestamatu	"tõestamatu %tõesta  )MATU_vA  <tõestama ;27_V	et	f	\N
185545	tõestamatu	tõestamatu =tõestamatu  (SgG  >tõestamatu !01_A	et	f	\N
185554	libahunti	libahunti =hunti  (SgP  >liba+hunt !22_S	et	f	\N
185555	libahunti	libahunti =hunti  (SgAdt  >liba+hunt !22_S	et	f	\N
185559	kellessegi	kellessegi =kelle  (SgIll  >keegi !00_P	et	f	\N
185560	kellessegi	kellessegi =kelle  (SgIll^  >kes !00_P	et	f	\N
185561	kellessegi	kellessegi =kelle  (PlIll^  >kell !22_S	et	f	\N
185571	nsvlu	### nsvlu	et	f	\N
185580	astutud	astutud =astu  (PtsPtIps  >astuma !28_V	et	f	\N
185581	astutud	astutud =astutu  (PlN  >astutu !01_AS	et	f	\N
185582	astutud	"astutu %astu  )TU1_vS  <astuma ;28_V	et	f	\N
185583	astutud	astutud =astutud  (ID  >astutud !41_A	et	f	\N
185584	astutud	"astutud %astu  )TUD_vA  <astuma ;28_V	et	f	\N
185587	tv-d	tv-d =tv  (SgP  >tv !xx_Q	et	f	\N
185588	tv-d	tv-d =tv  (PlN  >tv !xx_Q	et	f	\N
185601	eesit	?eesit =eesi  (SgP  >eesi !16_S	et	f	\N
185602	eesit	?eesit =eesit  (SgN  >eesit !02_S	et	f	\N
185603	looduskaitse	looduskaitse =kaitse  (SgN  >loodus+kaitse !05_S	et	f	\N
185604	looduskaitse	looduskaitse =kaitse  (SgN  >loodus+kaitse !06_S	et	f	\N
185605	looduskaitse	looduskaitse =kaitse  (SgG  >loodus+kaitse !06_S	et	f	\N
185620	siinsetele	siinsetele =siinse  (PlAll  >siinne !02_A	et	f	\N
185621	siinsetele	siinsetele =sete  (PlAll  >siin+sett !22_S	et	f	\N
185627	egiptusest	?egiptusest =egiptuse  (SgEl  >egiptus !11_S	et	f	\N
185628	egiptusest	?egiptusest =egiptuses  (SgP  >egiptusene !12_A	et	f	\N
185655	rohkemal	rohkemal =rohkema  (SgAd  >rohkem !02_A	et	f	\N
185656	rohkemal	"rohkem %rohke  )M_cA  <rohke ;01_A	et	f	\N
185664	julgeolekukomitee	julgeolekukomitee =komitee  (SgN  >julge+oleku+komitee !26_S	et	f	\N
185665	julgeolekukomitee	julgeolekukomitee =komitee  (SgG  >julge+oleku+komitee !26_S	et	f	\N
185447	disidentide	?disidentide =disidenti  (PlG  >disident !22_S	et	f	\N
185461	sotsia	?sotsia =sotsia  (SgN  >sotsia !01_S	et	f	\N
185462	sotsia	?sotsia =sotsia  (SgG  >sotsia !01_S	et	f	\N
185468	hallile	hallile =halli  (SgAll  >hall !22_S	et	f	\N
185469	hallile	hallile =halli  (SgAll  >hall !22_AS	et	f	\N
185482	eej	### eej	et	f	\N
185484	liitlsetele	?liitlsetele =liitlse  (PlAll  >liitlne !02_A	et	f	\N
185485	liitlsetele	?liitlsetele =liitlse  (PlAll  >liitlse !06_S	et	f	\N
185486	liitlsetele	?liitlsetele =liitlsete  (PlAll  >liitlsett !22_S	et	f	\N
185487	liitlsetele	?liitlsetele =liitlsetele  (IndPrPs_  >liitlsetelema !36_V	et	f	\N
185488	liitlsetele	?liitlsetele =liitlsetele  (ImpPrSg2  >liitlsetelema !36_V	et	f	\N
185504	politiseeritud	?politiseeritud =politiseeri  (PtsPtIps  >politiseerima !28_V	et	f	\N
185505	politiseeritud	?politiseeritud =politiseeritu  (PlN  >politiseeritu !01_S	et	f	\N
185506	politiseeritud	?politiseeritud =politiseeritu  (IndPrSg2  >politiseerituma !27_V	et	f	\N
185507	politiseeritud	?politiseeritud =politiseeritud  (ID  >politiseeritud !41_A	et	f	\N
185508	novelli	novelli =novelli  (SgG  >novell !22_S	et	f	\N
185509	novelli	novelli =novelli  (SgP  >novell !22_S	et	f	\N
185510	novelli	novelli =novelli  (SgAdt  >novell !22_S	et	f	\N
185511	sotsrealismi	sotsrealismi =realismi  (SgG  >sots+realism !22_S	et	f	\N
185512	sotsrealismi	sotsrealismi =realismi  (SgP  >sots+realism !22_S	et	f	\N
185513	sotsrealismi	sotsrealismi =realismi  (SgAdt  >sots+realism !22_S	et	f	\N
185546	kartmine	kartmine =kartmine  (SgN  >kartmine !12?10_S	et	f	\N
185547	kartmine	"kartmine %kart  )MINE_vS  <kartma ;34_V	et	f	\N
185548	peegeldust	peegeldust =peegeldus  (SgP  >peegeldus !11_S	et	f	\N
185549	peegeldust	"peegeldus %peegelda  )US_vS  <peegeldama ;27_V	et	f	\N
185550	peegeldust	peegeldust =dust  (SgN  >peegel+dust !22_S	et	f	\N
185589	petmiseks	petmiseks =petmise  (SgTr  >petmine !12?10_S	et	f	\N
185590	petmiseks	"petmine %pet  )MINE_vS  <petma ;35_V	et	f	\N
185591	raatmatuid	?raatmatuid =raatmatu  (PlP  >raatmatu !01_A	et	f	\N
185592	raatmatuid	?raatmatuid =raatmatui  (PlN  >raatmatui !26_S	et	f	\N
185593	raatmatuid	?raatmatuid =raatmatui  (SgP  >raatmatui !26_S	et	f	\N
185600	keels	?keels =keels  (SgN  >keels !22_S	et	f	\N
185610	avameelselt	avameelselt =meelse  (SgAbl  >ava+meelne !02_A	et	f	\N
185611	avameelselt	"ava+meelselt %meelse  )LT_mD  <ava+meelne ;02_A	et	f	\N
185618	vahelisest	vahelisest =vahelise  (SgEl  >vaheline !12_A	et	f	\N
185619	vahelisest	"vaheline %vahe  )LINE_aA  <vahe ;16_S	et	f	\N
185631	lähisida	lähisida =ida  (SgN  >lähis+ida !17_S	et	f	\N
185632	lähisida	lähisida =ida  (SgG  >lähis+ida !17_S	et	f	\N
185633	lähisida	lähisida =ida  (SgP  >lähis+ida !17_S	et	f	\N
185649	elupaigax	### elupaigax	et	f	\N
185652	tööjõux	?tööjõux =tööjõux  (SgN  >tööjõux !22_S	et	f	\N
185653	tööjõux	?tööjõux =jõux  (SgN  >töö+jõux !22_S	et	f	\N
185666	isikuvabadust	isikuvabadust =dust  (SgN  >isiku+vaba+dust !22_S	et	f	\N
185667	isikuvabadust	isikuvabadust =vabadus  (SgP  >isiku+vabadus !11_S	et	f	\N
185668	isikuvabadust	"isiku+vabadus %vaba  )US_aS  <isiku+vaba ;17_A	et	f	\N
185680	pühapäevakoolis	pühapäevakoolis =kooli  (SgIn  >püha+päeva+kool !22_S	et	f	\N
185681	pühapäevakoolis	pühapäevakoolis =kooli  (PlIn  >püha+päeva+kool !22_S	et	f	\N
185686	seltsitegevus	seltsitegevus =tegevus  (SgN  >seltsi+tegevus !11_S	et	f	\N
185687	seltsitegevus	"seltsi+tegevus %tegeva  )US_aS  <seltsi+tegev ;02_A	et	f	\N
185695	nsvlst	### nsvlst	et	f	\N
185708	ballettid	?ballettid =balletti  (PlN  >balletti !01_S	et	f	\N
185709	tugevaimax	### tugevaimax	et	f	\N
185713	beriaga	?beriaga =beria  (SgKom  >beria !01_S	et	f	\N
185727	tootmise	tootmise =tootmise  (SgG  >tootmine !12?10_S	et	f	\N
185728	tootmise	"tootmine %toot  )MINE_vS  <tootma ;34_V	et	f	\N
185741	omanikutelt	omanikutelt =ute  (SgAbl  >omanik+utt !22_S	et	f	\N
185742	omanikutelt	omanikutelt =ute  (PlAbl  >omanik+utt !22_S	et	f	\N
185747	kosmonautikat	kosmonautikat =kosmonautika  (SgP  >kosmonautika !01_S	et	f	\N
185748	kosmonautikat	kosmonautikat =nautika  (SgP  >kosmo+nautika !01_S	et	f	\N
185749	vaenlasteadusteks	?vaenlasteadusteks =vaenlasteadus  (PlTr  >vaenlasteadus !11~09_S	et	f	\N
185752	jõukamad	jõukamad =jõukama  (PlN  >jõukam !02_A	et	f	\N
185753	jõukamad	"jõukam %jõuka  )M_cA  <jõukas ;02_A	et	f	\N
185754	jõukamad	jõukamad =kama  (PlN  >jõu+kama !17_S	et	f	\N
185811	nkgb	### nkgb	et	f	\N
185815	ida-virumaale	ida-virumaale =maa  (SgAll  >ida-viru+maa !26_S	et	f	\N
185816	ida-virumaale	ida-virumaale =maale  (PlP  >ida-viru+maal !22_S	et	f	\N
185819	isoleeritud	isoleeritud =isoleeri  (PtsPtIps  >isoleerima !28_V	et	f	\N
185820	isoleeritud	isoleeritud =isoleeritu  (PlN  >isoleeritu !01_S	et	f	\N
185821	isoleeritud	"isoleeritu %isoleeri  )TU1_vS  <isoleerima ;28_V	et	f	\N
185822	isoleeritud	isoleeritud =isoleeritud  (ID  >isoleeritud !41_A	et	f	\N
185824	isoleeritud	"isoleeritud %isoleeri  )TUD_vA  <isoleerima ;28_V	et	f	\N
185835	eu	?eu =eu  (SgN  >eu !26_S	et	f	\N
185836	eu	?eu =eu  (SgG  >eu !26_S	et	f	\N
185837	kunstiinimesi	kunstiinimesi =esi  (SgN  >kunsti+inim+esi !15_S	et	f	\N
185838	kunstiinimesi	kunstiinimesi =esi  (PlP  >kunsti+inim+esi !15_S	et	f	\N
185525	ühenenud	?ühenenud =nenu  (PlN  >ühe+nenu !17_S	et	f	\N
185556	tehit	?tehit =tehit  (SgN  >tehit !02_S	et	f	\N
185563	kritiseetitakse	?kritiseetitakse =kritiseetitakse  (SgG  >kritiseetitakne !02_A	et	f	\N
185564	kritiseetitakse	?kritiseetitakse =kritiseetitakse  (PlP  >kritiseetitaks !22_S	et	f	\N
185585	läänestumise	?läänestumise =läänestumise  (SgG  >läänestumine !12_S	et	f	\N
185586	läänestumise	?läänestumise =stumise  (SgG  >lääne+stumine !10_A	et	f	\N
185613	intiimsusest	intiimsusest =intiimsuse  (SgEl  >intiimsus !11~09_S	et	f	\N
185614	intiimsusest	"intiimsus %intiimse  )US_aS  <intiimne ;02_A	et	f	\N
185615	intiimsusest	intiimsusest =intiimsuses  (SgP  >intiimsusene !12_A	et	f	\N
185616	intiimsusest	"intiimsusene %intiimsuse  )NE_aA  <intiimsus ;09_S	et	f	\N
185617	intiimsusest	"intiimsusene %intiimsuse  )NE_aA  <intiimsus ;11_S	et	f	\N
185629	sulam	sulam =sulam  (SgN  >sulam !02_S	et	f	\N
185630	sulam	"sulam %sula  )M_cA  <sula ;17_AS	et	f	\N
185634	rahvastelt	rahvastelt =rahvas  (PlAbl  >rahvas !07_S	et	f	\N
185635	rahvastelt	rahvastelt =rahvas  (PlAbl  >rahvane !10_A	et	f	\N
185636	rahvastelt	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
185637	vaske	vaske =vaske  (SgP  >vask !22_S	et	f	\N
185638	vaske	vaske =vaske  (SgAdt  >vask !22_S	et	f	\N
185639	vaske	vaske =vaske  (PlP  >vask !22_S	et	f	\N
185643	ümbervalama	?ümbervalama =ümbervalama  (SgG  >ümbervalam !02_A	et	f	\N
185644	ümbervalama	?ümbervalama =valama  (SgG  >ümber+valam !02_A	et	f	\N
185647	pronksiaega	pronksiaega =aega  (SgP  >pronksi+aeg !22_S	et	f	\N
185648	pronksiaega	pronksiaega =aega  (SgAdt  >pronksi+aeg !22_S	et	f	\N
185650	asulad-hooned	asulad-hooned =hoone  (PlN  >asulad-hoone !06_S	et	f	\N
185651	asulad-hooned	"asulad-hoone %hoo  )NE_aA  <asulad-hoog ;22_S	et	f	\N
185692	võõrtööjõudu	võõrtööjõudu =jõudu  (SgP  >võõr+töö+jõud !22_S	et	f	\N
185693	võõrtööjõudu	võõrtööjõudu =jõudu  (SgAdt  >võõr+töö+jõud !22_S	et	f	\N
185704	tööstusrajoonix	### tööstusrajoonix	et	f	\N
185723	perteisse	?perteisse =perte  (PlIll  >perde !06_S	et	f	\N
185724	perteisse	?perteisse =pertei  (SgIll  >pertei !26_S	et	f	\N
185725	perteisse	?perteisse =perteisse  (SgG  >perteisne !02_A	et	f	\N
185726	perteisse	?perteisse =perteisse  (PlP  >perteiss !22_S	et	f	\N
185734	natsionaliseeritud	natsionaliseeritud =natsionaliseeri  (PtsPtIps  >natsionaliseerima !28_V	et	f	\N
185735	natsionaliseeritud	natsionaliseeritud =natsionaliseeritu  (PlN  >natsionaliseeritu !01_S	et	f	\N
185736	natsionaliseeritud	"natsionaliseeritu %natsionaliseeri  )TU1_vS  <natsionaliseerima ;28_V	et	f	\N
185737	natsionaliseeritud	natsionaliseeritud =natsionaliseeritud  (ID  >natsionaliseeritud !41_A	et	f	\N
185738	natsionaliseeritud	"natsionaliseeritud %natsionaliseeri  )TUD_vA  <natsionaliseerima ;28_V	et	f	\N
185750	geneetika	geneetika =geneetika  (SgN  >geneetika !01_S	et	f	\N
185751	geneetika	geneetika =geneetika  (SgG  >geneetika !01_S	et	f	\N
185765	len	### len	et	f	\N
185767	vastavaks	vastavaks =vastava  (SgTr  >vastav !02_A	et	f	\N
185768	vastavaks	"vastav %vasta  )V_vA  <vastama ;29_V	et	f	\N
185769	vastavaks	vastavaks =ava  (SgTr  >vast+ava !17_S	et	f	\N
185770	presiidiumi	presiidiumi =presiidiumi  (SgG  >presiidium !19~02_S	et	f	\N
185771	presiidiumi	presiidiumi =presiidiumi  (SgP  >presiidium !19_S	et	f	\N
185772	presiidiumi	presiidiumi =presiidiumi  (SgAdt  >presiidium !19_S	et	f	\N
185784	ühiskondkiku	?ühiskondkiku =ühiskondkiku  (SgG  >ühiskondkik !02_S	et	f	\N
185785	ühiskondkiku	?ühiskondkiku =ühiskondkiku  (IndPrPs_  >ühiskondkikuma !27_V	et	f	\N
185786	ühiskondkiku	?ühiskondkiku =ühiskondkiku  (ImpPrSg2  >ühiskondkikuma !27_V	et	f	\N
185787	ühiskondkiku	?ühiskondkiku =kondkiku  (SgN  >ühis+kondkiku !01_S	et	f	\N
185788	ühiskondkiku	?ühiskondkiku =kondkiku  (SgG  >ühis+kondkiku !01_S	et	f	\N
185789	ühiskondkiku	?ühiskondkiku =kondkiku  (SgG  >ühis+kondkik !02_S	et	f	\N
185808	kirjasõna	kirjasõna =sõna  (SgN  >kirja+sõna !17_S	et	f	\N
185809	kirjasõna	kirjasõna =sõna  (SgG  >kirja+sõna !17_S	et	f	\N
185810	kirjasõna	kirjasõna =sõna  (SgP  >kirja+sõna !17_S	et	f	\N
185817	rajoonid	rajoonid =rajooni  (PlN  >rajoon !22_S	et	f	\N
185818	rajoonid	rajoonid =rajooni  (IndPrSg2  >rajoonima !28_V	et	f	\N
185869	plaanimaj	### plaanimaj	et	f	\N
185878	riigitoetusel	riigitoetusel =toetuse  (SgAd  >riigi+toetus !11~09_S	et	f	\N
185879	riigitoetusel	"riigi+toetus %toe  )TUS2_aS  <riigi+tugi ;21_S	et	f	\N
185885	toomine	toomine =toomine  (SgN  >toomine !12?10_S	et	f	\N
185886	toomine	"toomine %too  )MINE_vS  <tooma ;38_V	et	f	\N
185887	toomine	"toomine %toomi  )NE_aA  <toom ;22_S	et	f	\N
185888	toomine	toomine =ine  (SgN  >toom+ine !16_S	et	f	\N
185889	toomine	toomine =ine  (SgG  >toom+ine !16_S	et	f	\N
185900	kuuluti	kuuluti =kuulu  (IndIpfIps  >kuuluma !27_V	et	f	\N
185901	kuuluti	kuuluti =uti  (SgG  >kuul+utt !22_S	et	f	\N
185902	kuuluti	kuuluti =luti  (SgG  >kuu+lutt !22_S	et	f	\N
185925	lauristin	?lauristin =lauristi  (IndPrSg1  >lauristima !28_V	et	f	\N
185926	lauristin	?lauristin =lauristin  (SgN  >lauristin !19_S	et	f	\N
185927	lauristin	?lauristin =ristin  (SgN  >lau+ristin !02_S	et	f	\N
185934	sundust	sundust =sundus  (SgP  >sundus !11~09_S	et	f	\N
185935	sundust	sundust =us  (SgP  >sund+uks !14_S	et	f	\N
185672	võda	?võda =võda  (SgN  >võda !17_S	et	f	\N
185673	võda	?võda =võda  (SgG  >võda !17_S	et	f	\N
185674	võda	?võda =võda  (SgP  >võda !17_S	et	f	\N
185675	võda	?võda =võda  (IndPrPs_  >võdama !27_V	et	f	\N
185676	võda	?võda =võda  (ImpPrSg2  >võdama !27_V	et	f	\N
185694	muulase	muulase =muulase  (SgG  >muulane !12?10_S	et	f	\N
185696	muulase	"muulane %muula  )NE_aA  <muul ;22_S	et	f	\N
185717	kohanemisest	kohanemisest =kohanemise  (SgEl  >kohanemine !12_S	et	f	\N
185718	kohanemisest	"kohanemine %kohane  )MINE_vS  <kohanema ;27_V	et	f	\N
185719	hakataxe	### hakataxe	et	f	\N
185827	represseeritu	represseeritu =represseeritu  (SgN  >represseeritu !01_S	et	f	\N
185828	represseeritu	"represseeritu %represseeri  )TU1_vS  <represseerima ;28_V	et	f	\N
185829	represseeritu	represseeritu =represseeritu  (SgG  >represseeritu !01_S	et	f	\N
185846	101-liikmeline	-liikmeline =liikmeline  (SgN  >-liikmeline !12_A	et	f	\N
185847	101-liikmeline	"-liikmeline %liikme  )LINE_aA  <-liige ;05_S	et	f	\N
185856	kuressaare	?kuressaare =kuressaare  (SgN  >kuressaare !16_S	et	f	\N
185857	kuressaare	?kuressaare =kuressaare  (SgG  >kuressaare !16_S	et	f	\N
185858	kuressaare	?kuressaare =kuressaare  (PlP  >kuressaar !22_S	et	f	\N
185870	näitaja	näitaja =näitaja  (SgN  >näitaja !01_S	et	f	\N
185871	näitaja	"näitaja %näita  )JA_vS  <näitama ;29_V	et	f	\N
185872	näitaja	näitaja =näitaja  (SgG  >näitaja !01_S	et	f	\N
185873	näitaja	näitaja =aja  (SgG  >näit+aeg !22_S	et	f	\N
185898	võõrtööjõud	võõrtööjõud =jõu  (PlN  >võõr+töö+jõud !22_S	et	f	\N
185899	võõrtööjõud	võõrtööjõud =jõud  (SgN  >võõr+töö+jõud !22_S	et	f	\N
185905	liigutust	liigutust =liigutu  (SgEl  >liigutu !01_AS	et	f	\N
185906	liigutust	"liigutu %liigu  )TU1_vS  <liikuma ;28_V	et	f	\N
185907	liigutust	"liigutu %liigu  )TU2_kA  <liik ;22_S	et	f	\N
185908	liigutust	liigutust =liigutus  (SgP  >liigutus !11_S	et	f	\N
185909	liigutust	"liigutus %liiguta  )US_vS  <liigutama ;27_V	et	f	\N
185910	liigutust	"liigutus %liigu  )TUS1_aS  <liikuma ;28_V	et	f	\N
185911	liigutust	"liigutus %liigu  )TUS2_aS  <liik ;22_S	et	f	\N
185920	tootmisega	tootmisega =tootmise  (SgKom  >tootmine !12?10_S	et	f	\N
185921	tootmisega	"tootmine %toot  )MINE_vS  <tootma ;34_V	et	f	\N
185952	kahlustamine	?kahlustamine =kahlustamine  (SgN  >kahlustamine !12_S	et	f	\N
185953	kahlustamine	?kahlustamine =kahlustamine  (PlP  >kahlustamin !19_S	et	f	\N
185955	teadmisel	teadmisel =teadmise  (SgAd  >teadmine !12?10_S	et	f	\N
185957	teadmisel	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
185965	vapustusi	vapustusi =vapustusi  (PlP  >vapustus !11_S	et	f	\N
185966	vapustusi	"vapustus %vapusta  )US_vS  <vapustama ;27_V	et	f	\N
185974	oon	?oon =oon  (SgN  >oon !22_S	et	f	\N
185975	industrialiseerimine	industrialiseerimine =industrialiseerimine  (SgN  >industrialiseerimine !12_S	et	f	\N
185976	industrialiseerimine	"industrialiseerimine %industrialiseeri  )MINE_vS  <industrialiseerima ;28_V	et	f	\N
185983	kommun	?kommun =kommu  (IndPrSg1  >kommuma !27_V	et	f	\N
185984	kommun	?kommun =kommun  (SgN  >kommun !02_S	et	f	\N
185988	sisuline	sisuline =sisuline  (SgN  >sisuline !12_A	et	f	\N
185989	sisuline	"sisuline %sisu  )LINE_aA  <sisu ;17_S	et	f	\N
186014	asutamiseks	asutamiseks =asutamise  (SgTr  >asutamine !12_S	et	f	\N
186015	asutamiseks	"asutamine %asuta  )MINE_vS  <asutama ;27_V	et	f	\N
186016	ebalojaalsuga20700	?ebalojaalsuga =lojaalsu  (SgKom  >eba+lojaalsu !01_S	et	f	\N
186042	õigustest	õigustest =õigus  (PlEl  >õigus !11~09_S	et	f	\N
186043	õigustest	"õigus %õige  )US_aS  <õige ;01_A	et	f	\N
186044	õigustest	õigustest =test  (SgN  >õigus+test !22_S	et	f	\N
186045	kahjutasu	kahjutasu =tasu  (SgN  >kahju+tasu !17_S	et	f	\N
186046	kahjutasu	kahjutasu =tasu  (SgG  >kahju+tasu !17_S	et	f	\N
186047	kahjutasu	kahjutasu =tasu  (SgP  >kahju+tasu !17_S	et	f	\N
186048	kultuurilist	kultuurilist =kultuurilis  (SgP  >kultuuriline !12_A	et	f	\N
186049	kultuurilist	"kultuuriline %kultuuri  )LINE_aA  <kultuur ;22_S	et	f	\N
186052	riigiaparat	?riigiaparat =riigiapara  (SgP  >riigiapara !16_S	et	f	\N
186053	riigiaparat	?riigiaparat =apara  (SgP  >riigi+apara !01_S	et	f	\N
186058	rahastas	?rahastas =rahasta  (SgIn  >rahasta !01_S	et	f	\N
186059	rahastas	?rahastas =rahasta  (IndIpfSg3  >rahastama !27_V	et	f	\N
186086	kirikuks	kirikuks =kiriku  (SgTr  >kirik !02_S	et	f	\N
186087	kirikuks	kirikuks =uks  (SgN  >kirik+uks !14_S	et	f	\N
186101	tankkid	?tankkid =tankki  (PlN  >tankki !01_S	et	f	\N
186102	tankkid	?tankkid =tankki  (PlN  >tankk !22_S	et	f	\N
186103	tankkid	?tankkid =tankki  (IndPrSg2  >tankkima !28_V	et	f	\N
186104	rigi	?rigi =rigi  (SgN  >rigi !17_S	et	f	\N
186105	rigi	?rigi =rigi  (SgG  >rigi !17_S	et	f	\N
186106	rigi	?rigi =rigi  (SgP  >rigi !17_S	et	f	\N
186107	rigi	?rigi =rigi  (IndPrPs_  >rigima !27_V	et	f	\N
186108	rigi	?rigi =rigi  (ImpPrSg2  >rigima !27_V	et	f	\N
186128	kultuurautonoomia	kultuurautonoomia =autonoomia  (SgN  >kultuur+autonoomia !01_S	et	f	\N
186129	kultuurautonoomia	kultuurautonoomia =autonoomia  (SgG  >kultuur+autonoomia !01_S	et	f	\N
186132	riiklikku	riiklikku =riiklikku  (SgP  >riiklik !25_A	et	f	\N
186133	riiklikku	riiklikku =riiklikku  (SgAdt  >riiklik !25_A	et	f	\N
185677	keeleinim	?keeleinim =keeleinim  (SgN  >keeleinim !02_A	et	f	\N
185678	keeleinim	?keeleinim =inim  (SgN  >keele+inim !02_A	et	f	\N
185679	keeleinim	?keeleinim =einim  (SgN  >keel+einim !02_A	et	f	\N
185682	kuluurii	?kuluurii =kuluurii  (SgN  >kuluurii !26_S	et	f	\N
185683	kuluurii	?kuluurii =kuluurii  (SgG  >kuluurii !26_S	et	f	\N
185684	kuluurii	?kuluurii =urii  (SgN  >kulu+urii !26_S	et	f	\N
185685	kuluurii	?kuluurii =urii  (SgG  >kulu+urii !26_S	et	f	\N
185698	ida-viru	ida-viru =viru  (SgN  >ida-viru !17_S	et	f	\N
185700	ida-viru	ida-viru =viru  (SgG  >ida-viru !17_S	et	f	\N
185701	ida-viru	ida-viru =viru  (SgP  >ida-viru !17_S	et	f	\N
185702	ida-viru	ida-viru =viru  (IndPrPs_  >ida-viruma !27_V	et	f	\N
185703	ida-viru	ida-viru =viru  (ImpPrSg2  >ida-viruma !27_V	et	f	\N
185705	talup	?talup =talup  (SgN  >talup !02_S	et	f	\N
185711	daknast	?daknast =daknas  (SgP  >daknas !07_S	et	f	\N
185712	daknast	?daknast =daknas  (SgP  >daknane !12~10_A	et	f	\N
185714	iseid	?iseid =isei  (PlN  >isei !26_S	et	f	\N
185715	iseid	?iseid =isei  (SgP  >isei !26_S	et	f	\N
185716	iseid	?iseid =iseid  (SgN  >iseid !22_S	et	f	\N
185720	kommunistlikusse	kommunistlikusse =kommunistliku  (SgIll  >kommunistlik !25_A	et	f	\N
185721	kommunistlikusse	kommunistlikusse =kommunistlikus  (SgAdt  >kommunistlikus !11_S	et	f	\N
185722	kommunistlikusse	"kommunistlikus %kommunistliku  )US_aS  <kommunistlik ;25_A	et	f	\N
185729	riigistanud	riigistanud =riigista  (PtsPtPs  >riigistama !27_V	et	f	\N
185730	riigistanud	riigistanud =riigistanu  (PlN  >riigistanu !01_S	et	f	\N
185731	riigistanud	"riigistanu %riigista  )NU_vS  <riigistama ;27_V	et	f	\N
185732	riigistanud	riigistanud =riigistanud  (ID  >riigistanud !41_A	et	f	\N
185733	riigistanud	"riigistanud %riigista  )NUD_vA  <riigistama ;27_V	et	f	\N
185744	rasketööstust	rasketööstust =tust  (SgN  >raske+töös+tust !22_S	et	f	\N
185746	rasketööstust	rasketööstust =tööstus  (SgP  >raske+tööstus !11~09_S	et	f	\N
185755	allusid	allusid =allu  (IndIpfSg2  >alluma !27_V	et	f	\N
185756	allusid	allusid =allu  (IndIpfPl3  >alluma !27_V	et	f	\N
185757	rikkusid	rikkusid =rikku  (IndIpfSg2  >rikkuma !28_V	et	f	\N
185758	rikkusid	rikkusid =rikku  (IndIpfPl3  >rikkuma !28_V	et	f	\N
185773	vares-barbarus	?vares-barbarus =barbaru  (SgIn  >vares-barbaru !01_S	et	f	\N
185774	vares-barbarus	?vares-barbarus =barbaru  (IndIpfSg3  >vares-barbaruma !27_V	et	f	\N
185775	vares-barbarus	?vares-barbarus =barbarus  (SgN  >vares-barbarus !11_S	et	f	\N
185779	ümberkorraldama	?ümberkorraldama =ümberkorralda  (Sup  >ümberkorraldama !27_V	et	f	\N
185780	ümberkorraldama	?ümberkorraldama =ümberkorraldama  (SgG  >ümberkorraldam !02_A	et	f	\N
185781	ümberkorraldama	?ümberkorraldama =korraldama  (SgG  >ümber+korraldam !02_A	et	f	\N
185782	määras	määras =määra  (SgIn  >määr !22_S	et	f	\N
185783	määras	määras =määra  (IndIpfSg3  >määrama !29_V	et	f	\N
185830	rehalibiteeriti	?rehalibiteeriti =rehalibiteeri  (IndIpfIps  >rehalibiteerima !28_V	et	f	\N
185831	rehalibiteeriti	?rehalibiteeriti =rehalibiteeriti  (ID  >rehalibiteeriti !41_D	et	f	\N
185832	rehalibiteeriti	?rehalibiteeriti =rehalibiteeriti  (SgG  >rehalibiteeritt !22_S	et	f	\N
185833	rehalibiteeriti	?rehalibiteeriti =rehalibiteeriti  (IndPrPs_  >rehalibiteerittima !28_V	et	f	\N
185834	rehalibiteeriti	?rehalibiteeriti =rehalibiteeriti  (ImpPrSg2  >rehalibiteerittima !28_V	et	f	\N
185840	vabamaj	### vabamaj	et	f	\N
185853	püüdlevad	püüdlevad =püüdle  (IndPrPl3  >püüdlema !30_V	et	f	\N
185854	püüdlevad	püüdlevad =püüdleva  (PlN  >püüdlev !02_A	et	f	\N
185855	püüdlevad	"püüdlev %püüdle  )V_vA  <püüdlema ;30_V	et	f	\N
185862	leerimine	?leerimine =leerimine  (SgN  >leerimine !12_S	et	f	\N
185863	leerimine	?leerimine =leerimine  (PlP  >leerimin !19_S	et	f	\N
185880	varatuteks	varatuteks =varatu  (PlTr  >varatu !01_A	et	f	\N
185881	varatuteks	"varatu %vara  )TU2_kA  <vara ;17_S	et	f	\N
185882	varatuteks	varatuteks =tute  (PlTr  >vara+tutt !22_S	et	f	\N
185883	nälgimise	nälgimise =nälgimise  (SgG  >nälgimine !12_S	et	f	\N
185884	nälgimise	"nälgimine %nälgi  )MINE_vS  <nälgima ;27_V	et	f	\N
185890	tagasipöördunud	?tagasipöördunud =tagasipöördu  (PtsPtPs  >tagasipöörduma !27_V	et	f	\N
185891	tagasipöördunud	?tagasipöördunud =tagasipöördunu  (PlN  >tagasipöördunu !01_S	et	f	\N
185892	tagasipöördunud	?tagasipöördunud =tagasipöördunu  (IndPrSg2  >tagasipöördunuma !27_V	et	f	\N
185893	tagasipöördunud	?tagasipöördunud =tagasipöördunud  (ID  >tagasipöördunud !41_A	et	f	\N
185894	tagasipöördunud	?tagasipöördunud =unu  (PlN  >tagasi+pöörd+unu !17_S	et	f	\N
185895	tagasipöördunud	?tagasipöördunud =ipöördunu  (PlN  >tagas+ipöördunu !01_S	et	f	\N
185896	tagasipöördunud	?tagasipöördunud =sipöördu  (PtsPtPs  >taga+_sipöörduma !27_V	et	f	\N
185897	tagasipöördunud	?tagasipöördunud =sipöördunu  (PlN  >taga+sipöördunu !01_S	et	f	\N
185916	minevaga	minevaga =mineva  (SgKom  >minev !02_A	et	f	\N
185917	minevaga	"minev %mine  )V_vA  <minema ;36_V	et	f	\N
185918	ülemanõukogu	?ülemanõukogu =ülemanõukogu  (IndPrPs_  >ülemanõukoguma !27_V	et	f	\N
185919	ülemanõukogu	?ülemanõukogu =ülemanõukogu  (ImpPrSg2  >ülemanõukoguma !27_V	et	f	\N
185922	ülemkogu	ülemkogu =kogu  (SgN  >ülem+kogu !17_S	et	f	\N
185923	ülemkogu	ülemkogu =kogu  (SgG  >ülem+kogu !17_S	et	f	\N
185924	ülemkogu	ülemkogu =kogu  (SgP  >ülem+kogu !17_S	et	f	\N
185710	küljex	### küljex	et	f	\N
185739	tööstusasutused	tööstusasutused =asutuse  (PlN  >tööstus+asutus !11_S	et	f	\N
185740	tööstusasutused	"tööstus+asutus %asu  )TUS2_aS  <tööstus+asu ;17_S	et	f	\N
185743	forseerima	?forseerima =forseeri  (Sup  >forseerima !28_V	et	f	\N
185745	forseerima	?forseerima =forseerima  (SgG  >forseerim !02_A	et	f	\N
185759	eluvõimalitteks	### eluvõimalitteks	et	f	\N
185760	riigistatud	riigistatud =riigista  (PtsPtIps  >riigistama !27_V	et	f	\N
185761	riigistatud	riigistatud =riigistatu  (PlN  >riigistatu !01_S	et	f	\N
185762	riigistatud	"riigistatu %riigista  )TU1_vS  <riigistama ;27_V	et	f	\N
185763	riigistatud	riigistatud =riigistatud  (ID  >riigistatud !41_A	et	f	\N
185764	riigistatud	"riigistatud %riigista  )TUD_vA  <riigistama ;27_V	et	f	\N
185766	nk	### nk	et	f	\N
185776	täitev	täitev =täit  (PtsPrPs  >täitma !34_V	et	f	\N
185777	täitev	täitev =täitev  (SgN  >täitev !02_A	et	f	\N
185778	täitev	"täitev %täit  )V_vA  <täitma ;34_V	et	f	\N
185790	kaade	?kaade =kaa  (PlG  >kaa !26_S	et	f	\N
185791	kaade	?kaade =kaade  (SgN  >kaade !06_S	et	f	\N
185792	kaade	?kaade =kaade  (PlP  >kaad !22_S	et	f	\N
185793	kaade	?kaade =kaade  (IndPrPs_  >kaadema !27_V	et	f	\N
185794	kaade	?kaade =kaade  (ImpPrSg2  >kaadema !27_V	et	f	\N
185795	rajooniks	rajooniks =rajooni  (SgTr  >rajoon !22_S	et	f	\N
185796	rajooniks	rajooniks =rajooni  (KndPrPs  >rajoonima !28_V	et	f	\N
185797	ümbernimetatud	ümbernimetatud =nimeta  (PtsPtIps  >ümber+_nimetama !27_V	et	f	\N
185798	ümbernimetatud	ümbernimetatud =nimetatu  (PlN  >ümber+nimetatu !01_S	et	f	\N
185799	põhivool	põhivool =voo  (SgAd  >põhi+voog !22_S	et	f	\N
185800	põhivool	põhivool =vool  (SgN  >põhi+vool !22_S	et	f	\N
185801	voole	voole =voo  (SgAll  >voog !22_S	et	f	\N
185802	voole	voole =voole  (SgN  >voole !05_S	et	f	\N
185803	voole	voole =voole  (SgN  >voole !06_S	et	f	\N
185804	voole	voole =voole  (SgG  >voole !06_S	et	f	\N
185805	voole	voole =voole  (PlP  >vool !22_S	et	f	\N
185806	trükivabadus	trükivabadus =vabadus  (SgN  >trüki+vabadus !11_S	et	f	\N
185807	trükivabadus	"trüki+vabadus %vaba  )US_aS  <trüki+vaba ;17_A	et	f	\N
185812	muudest	muudest =muu  (PlEl  >muu !26_P	et	f	\N
185813	muudest	muudest =muu  (PlEl  >muu !26_S	et	f	\N
185814	muudest	muudest =muude  (PlEl  >muut !22_S	et	f	\N
185823	berio	?berio =berio  (SgN  >berio !01_S	et	f	\N
185825	berio	?berio =berio  (SgG  >berio !01_S	et	f	\N
185826	suundada	?suundada =suunda  (Inf  >suundama !27_V	et	f	\N
185841	demokraatia	demokraatia =demokraatia  (SgN  >demokraatia !01_S	et	f	\N
185842	demokraatia	demokraatia =demokraatia  (SgG  >demokraatia !01_S	et	f	\N
185864	kehtinud	kehtinud =kehti  (PtsPtPs  >kehtima !27_V	et	f	\N
185865	kehtinud	kehtinud =kehtinu  (PlN  >kehtinu !01_S	et	f	\N
185866	kehtinud	"kehtinu %kehti  )NU_vS  <kehtima ;27_V	et	f	\N
185867	kehtinud	kehtinud =kehtinud  (ID  >kehtinud !41_A	et	f	\N
185868	kehtinud	"kehtinud %kehti  )NUD_vA  <kehtima ;27_V	et	f	\N
185903	majandusega	majandusega =majanduse  (SgKom  >majandus !11_S	et	f	\N
185904	majandusega	"majandus %majanda  )US_vS  <majandama ;27_V	et	f	\N
185914	lihtrahvas	lihtrahvas =rahva  (SgIn  >liht+rahvas !07_S	et	f	\N
185915	lihtrahvas	lihtrahvas =rahvas  (SgN  >liht+rahvas !07_S	et	f	\N
185932	mensavendadele	?mensavendadele =mensavenda  (PlAll  >mensavenda !16_S	et	f	\N
185933	kolhoseerimise	?kolhoseerimise =kolhoseerimise  (SgG  >kolhoseerimine !12_S	et	f	\N
185936	kultuuripoliitika	kultuuripoliitika =poliitika  (SgN  >kultuuri+poliitika !01_S	et	f	\N
185937	kultuuripoliitika	kultuuripoliitika =poliitika  (SgG  >kultuuri+poliitika !01_S	et	f	\N
185941	stalinistide	?stalinistide =stalinisti  (PlG  >stalinist !22_S	et	f	\N
185942	algaski	algaski =aski  (SgG  >alg+ask !22_S	et	f	\N
185943	algaski	algaski =aski  (SgP  >alg+ask !22_S	et	f	\N
185944	algaski	algaski =aski  (SgAdt  >alg+ask !22_S	et	f	\N
185945	algaski	algaski =alga  (IndIpfSg3^  >algama !29_V	et	f	\N
185949	käibet	?käibet =käibe  (SgP  >käibe !06_S	et	f	\N
185950	sotsialistikud	?sotsialistikud =sotsialistiku  (PlN  >sotsialistik !25_S	et	f	\N
185951	sotsialistikud	?sotsialistikud =sotsialistiku  (IndPrSg2  >sotsialistikuma !27_V	et	f	\N
185954	riigivõimu	riigivõimu =võimu  (SgG  >riigi+võim !22_S	et	f	\N
185956	riigivõimu	riigivõimu =võimu  (SgP  >riigi+võim !22_S	et	f	\N
185958	riigivõimu	riigivõimu =võimu  (SgAdt  >riigi+võim !22_S	et	f	\N
185964	stalinlik	?stalinlik =stalinlik  (SgN  >stalinlik !25_A	et	f	\N
185985	kohanemise	kohanemise =kohanemise  (SgG  >kohanemine !12_S	et	f	\N
185986	kohanemise	"kohanemine %kohane  )MINE_vS  <kohanema ;27_V	et	f	\N
185995	ainuparteilisus	ainuparteilisus =parteilisus  (SgN  >ainu+parteilisus !11?09_S	et	f	\N
185996	ainuparteilisus	"ainu+parteilisus %partei  )LISUS_aS  <ainu+partei ;26_S	et	f	\N
186000	usinalt	usinalt =usina  (SgAbl  >usin !02_A	et	f	\N
186001	usinalt	usinalt =usinalt  (ID  >usinalt !41_D	et	f	\N
186002	usinalt	"usinalt %usina  )LT_mD  <usin ;02_A	et	f	\N
186023	beria	?beria =beria  (SgN  >beria !01_S	et	f	\N
186024	beria	?beria =beria  (SgG  >beria !01_S	et	f	\N
186025	internaate	internaate =internaate  (PlP  >internaat !22_S	et	f	\N
185839	kunstiinimesi	kunstiinimesi =inimesi  (PlP  >kunsti+inimene !12_S	et	f	\N
185843	ühesugund	?ühesugund =ühesugund  (SgN  >ühesugund !22_S	et	f	\N
185844	ühesugund	?ühesugund =ugund  (SgN  >ühes+ugund !02_S	et	f	\N
185845	ühesugund	?ühesugund =sugund  (SgN  >ühe+sugund !02_S	et	f	\N
185848	tööliste	tööliste =töölis  (PlG  >tööline !12?10_S	et	f	\N
185849	tööliste	tööliste =iste  (SgN  >tööl+iste !05_S	et	f	\N
185850	tööliste	tööliste =iste  (SgN  >tööl+iste !06_S	et	f	\N
185851	tööliste	tööliste =iste  (SgG  >tööl+iste !06_S	et	f	\N
185852	tööliste	tööliste =iste  (PlP  >tööl+ist !22_S	et	f	\N
185859	külanõukogu	külanõukogu =kogu  (SgN  >küla+nõu+kogu !17_S	et	f	\N
185860	külanõukogu	külanõukogu =kogu  (SgG  >küla+nõu+kogu !17_S	et	f	\N
185861	külanõukogu	külanõukogu =kogu  (SgP  >küla+nõu+kogu !17_S	et	f	\N
185874	kogusest	kogusest =koguse  (SgEl  >kogus !09_S	et	f	\N
185875	kogusest	kogusest =koguse  (SgEl  >kogus !02_A	et	f	\N
185876	kogusest	kogusest =koguses  (SgP  >kogusene !12_A	et	f	\N
185877	kogusest	"kogusene %koguse  )NE_aA  <kogus ;09_S	et	f	\N
185912	ostuload	ostuload =loa  (PlN  >ostu+luba !18_S	et	f	\N
185913	ostuload	ostuload =loa  (PlN  >ostu+luga !18_S	et	f	\N
185938	tugevneva	tugevneva =tugevneva  (SgG  >tugevnev !02_A	et	f	\N
185939	tugevneva	"tugevnev %tugevne  )V_vA  <tugevnema ;27_V	et	f	\N
185946	haridussüsteemi	haridussüsteemi =süsteemi  (SgG  >haridus+süsteem !22_S	et	f	\N
185947	haridussüsteemi	haridussüsteemi =süsteemi  (SgP  >haridus+süsteem !22_S	et	f	\N
185948	haridussüsteemi	haridussüsteemi =süsteemi  (SgAdt  >haridus+süsteem !22_S	et	f	\N
185987	1947a	### 1947a	et	f	\N
185990	sotsiolism	?sotsiolism =sotsiolism  (SgN  >sotsiolism !22_S	et	f	\N
185991	sotsiolism	?sotsiolism =lism  (SgN  >sotsio+lism !22_S	et	f	\N
185992	sotsiolism	?sotsiolism =iolism  (SgN  >sots+iolism !22_S	et	f	\N
185997	põlvkivi	põlvkivi =kivi  (SgN  >põlv+kivi !17_S	et	f	\N
185998	põlvkivi	põlvkivi =kivi  (SgG  >põlv+kivi !17_S	et	f	\N
185999	põlvkivi	põlvkivi =kivi  (SgP  >põlv+kivi !17_S	et	f	\N
186017	majanduskasvu	majanduskasvu =kasvu  (SgG  >majandus+kasv !22_S	et	f	\N
186018	majanduskasvu	majanduskasvu =kasvu  (SgP  >majandus+kasv !22_S	et	f	\N
186019	majanduskasvu	majanduskasvu =kasvu  (SgAdt  >majandus+kasv !22_S	et	f	\N
186027	maalaste	maalaste =maalas  (PlG  >maalane !12?10_S	et	f	\N
186028	maalaste	maalaste =las  (PlG  >maa+laps !14_S	et	f	\N
186029	maalaste	maalaste =laste  (PlP  >maa+last !22_S	et	f	\N
186039	tahtest	tahtest =tahte  (SgEl  >tahe !06_S	et	f	\N
186040	tahtest	tahtest =tahtes  (SgP  >tahtene !12~10_A	et	f	\N
186041	tahtest	"tahtene %tahte  )NE_aA  <tahe ;06_S	et	f	\N
186073	seltsitegevust	seltsitegevust =us  (SgP  >seltsi+tegev+uks !14_S	et	f	\N
186074	seltsitegevust	seltsitegevust =tegevus  (SgP  >seltsi+tegevus !11_S	et	f	\N
186075	seltsitegevust	"seltsi+tegevus %tegeva  )US_aS  <seltsi+tegev ;02_A	et	f	\N
186088	konstantinoopalile	?konstantinoopalile =konstantinoopali  (SgAll  >konstantinoopal !02_S	et	f	\N
186089	konstantinoopalile	?konstantinoopalile =oopali  (SgAll  >konstantin+oopal !02_S	et	f	\N
186092	koguduselaul	koguduselaul =lau  (SgAd  >koguduse+laug !22_SA	et	f	\N
186094	koguduselaul	koguduselaul =laul  (SgN  >koguduse+laul !22_S	et	f	\N
186111	kultuurkapitaali	?kultuurkapitaali =kultuurkapitaali  (SgN  >kultuurkapitaali !16_S	et	f	\N
186112	kultuurkapitaali	?kultuurkapitaali =kultuurkapitaali  (SgG  >kultuurkapitaali !16_S	et	f	\N
186113	kultuurkapitaali	?kultuurkapitaali =kultuurkapitaali  (SgG  >kultuurkapitaal !22_S	et	f	\N
186114	kultuurkapitaali	?kultuurkapitaali =kultuurkapitaali  (SgP  >kultuurkapitaal !22_S	et	f	\N
186115	kultuurkapitaali	?kultuurkapitaali =kultuurkapitaali  (SgAdt  >kultuurkapitaal !22_S	et	f	\N
186116	kultuurkapitaali	?kultuurkapitaali =kultuurkapitaali  (IndPrPs_  >kultuurkapitaalima !28_V	et	f	\N
186117	kultuurkapitaali	?kultuurkapitaali =kultuurkapitaali  (ImpPrSg2  >kultuurkapitaalima !28_V	et	f	\N
186118	kultuurkapitaali	?kultuurkapitaali =taali  (SgN  >kultuur+kapi+taali !16_S	et	f	\N
186119	kultuurkapitaali	?kultuurkapitaali =taali  (SgG  >kultuur+kapi+taali !16_S	et	f	\N
186120	kultuurkapitaali	?kultuurkapitaali =taali  (SgG  >kultuur+kapi+taal !22_S	et	f	\N
186121	kultuurkapitaali	?kultuurkapitaali =taali  (SgP  >kultuur+kapi+taal !22_S	et	f	\N
186122	kultuurkapitaali	?kultuurkapitaali =taali  (SgAdt  >kultuur+kapi+taal !22_S	et	f	\N
186123	kultuurkapitaali	?kultuurkapitaali =kapitaali  (SgN  >kultuur+kapitaali !16_S	et	f	\N
186124	kultuurkapitaali	?kultuurkapitaali =kapitaali  (SgG  >kultuur+kapitaali !16_S	et	f	\N
186125	kultuurkapitaali	?kultuurkapitaali =kapitaali  (SgG  >kultuur+kapitaal !22_S	et	f	\N
186126	kultuurkapitaali	?kultuurkapitaali =kapitaali  (SgP  >kultuur+kapitaal !22_S	et	f	\N
186127	kultuurkapitaali	?kultuurkapitaali =kapitaali  (SgAdt  >kultuur+kapitaal !22_S	et	f	\N
186130	mõlematest	mõlematest =mõlema  (PlEl  >mõlema !02_P	et	f	\N
186131	mõlematest	mõlematest =test  (SgN  >mõlema+test !22_S	et	f	\N
186134	edendamiseks	edendamiseks =edendamise  (SgTr  >edendamine !12_S	et	f	\N
186135	edendamiseks	"edendamine %edenda  )MINE_vS  <edendama ;27_V	et	f	\N
186145	premeerima	premeerima =premeeri  (Sup  >premeerima !28_V	et	f	\N
186146	premeerima	premeerima =rima  (SgN  >pre+mee+rima !17_S	et	f	\N
186147	premeerima	premeerima =rima  (SgG  >pre+mee+rima !17_S	et	f	\N
185928	täitevkomiteediteks	?täitevkomiteediteks =täitevkomiteedite  (PlTr  >täitevkomiteeditt !22_S	et	f	\N
185929	täitevkomiteediteks	?täitevkomiteediteks =iteedite  (PlTr  >täitev+kom+iteeditt !22_S	et	f	\N
185930	täitevkomiteediteks	?täitevkomiteediteks =komiteedite  (PlTr  >täitev+komiteeditt !22_S	et	f	\N
185931	täitevkomiteediteks	?täitevkomiteediteks =tevkomiteedite  (PlTr  >täi+tevkomiteeditt !22_S	et	f	\N
185959	soosimisel	soosimisel =soosimise  (SgAd  >soosimine !12_S	et	f	\N
185960	soosimisel	"soosimine %soosi  )MINE_vS  <soosima ;28_V	et	f	\N
185961	äraproovitud	äraproovitud =proovi  (PtsPtIps  >ära+_proovima !28_V	et	f	\N
185962	äraproovitud	äraproovitud =proovitu  (PlN  >ära+proovitu !01_AS	et	f	\N
185963	äraproovitud	"ära+proovitu %proovi  )TU2_kA  <ära+proov ;22_S	et	f	\N
185967	sisuselt	sisuselt =sisuse  (SgAbl  >sisus !09_S	et	f	\N
185968	sisuselt	"sisus %si  )SUS_aS  <si ;26_S	et	f	\N
185969	sisuselt	sisuselt =sisuselt  (ID  >sisuselt !41_D	et	f	\N
185970	sisuselt	"sisuselt %sisu  )SELT_mD  <sisu ;17_S	et	f	\N
185977	väärtuste	väärtuste =väärtus  (PlG  >väärtus !11~09_S	et	f	\N
185978	väärtuste	väärtuste =us  (PlG  >väärt+uks !14_S	et	f	\N
185979	väärtuste	väärtuste =tuste  (PlP  >väär+tust !22_S	et	f	\N
185980	kultuuriajaloost	kultuuriajaloost =loo  (SgEl  >kultuuri+aja+lugu !18_S	et	f	\N
185981	kultuuriajaloost	kultuuriajaloost =loo  (SgEl  >kultuuri+aja+loog !22_S	et	f	\N
185982	kultuuriajaloost	kultuuriajaloost =loo  (SgEl  >kultuuri+aja+lood !22_S	et	f	\N
185993	haaramine	haaramine =haaramine  (SgN  >haaramine !12_S	et	f	\N
185994	haaramine	"haaramine %haara  )MINE_vS  <haarama ;29_V	et	f	\N
186010	julgeolekomitee	?julgeolekomitee =julgeolekomitee  (SgN  >julgeolekomitee !26_S	et	f	\N
186011	julgeolekomitee	?julgeolekomitee =julgeolekomitee  (SgG  >julgeolekomitee !26_S	et	f	\N
186012	julgeolekomitee	?julgeolekomitee =olekomitee  (SgN  >julge+olekomitee !26_S	et	f	\N
186013	julgeolekomitee	?julgeolekomitee =olekomitee  (SgG  >julge+olekomitee !26_S	et	f	\N
186033	eestased	?eestased =eestase  (PlN  >eestane !12~10_A	et	f	\N
186060	kapitali	kapitali =kapitali  (SgG  >kapital !19_S	et	f	\N
186061	kapitali	kapitali =kapitali  (SgP  >kapital !19_S	et	f	\N
186062	kapitali	kapitali =kapitali  (SgAdt  >kapital !19_S	et	f	\N
186063	kapitali	kapitali =tali  (SgN  >kapi+tali !17_S	et	f	\N
186064	kapitali	kapitali =tali  (SgN  >kapi+tali !24_S	et	f	\N
186065	kapitali	kapitali =tali  (SgG  >kapi+tali !17_S	et	f	\N
186066	kapitali	kapitali =tali  (SgP  >kapi+tali !17_S	et	f	\N
186091	tarvitusel	tarvitusel =tarvituse  (SgAd  >tarvitus !11_S	et	f	\N
186093	tarvitusel	"tarvitus %tarvita  )US_vS  <tarvitama ;27_V	et	f	\N
186095	käimist	käimist =käimi  (SgEl  >käim !22_S	et	f	\N
186096	käimist	käimist =käimis  (SgP  >käimine !12?10_S	et	f	\N
186097	käimist	"käimine %käi  )MINE_vS  <käima ;38_V	et	f	\N
186098	käimist	"käimine %käimi  )NE_aA  <käim ;22_S	et	f	\N
186139	näite-	näite- =näi  (IndPrPl2  >näima !37_V	et	f	\N
186140	näite-	näite- =näite  (SgG  >näide !06_S	et	f	\N
186141	näite-	näite- =näite  (PlP  >näit !22_S	et	f	\N
186149	amälk	?amälk =amälk  (SgN  >amälk !22_S	et	f	\N
186170	reabiliteeriti	?reabiliteeriti =reabiliteeri  (IndIpfIps  >reabiliteerima !28_V	et	f	\N
186171	reabiliteeriti	?reabiliteeriti =reabiliteeriti  (ID  >reabiliteeriti !41_D	et	f	\N
186172	reabiliteeriti	?reabiliteeriti =reabiliteeriti  (SgG  >reabiliteeritt !22_S	et	f	\N
186173	reabiliteeriti	?reabiliteeriti =reabiliteeriti  (IndPrPs_  >reabiliteerittima !28_V	et	f	\N
186174	reabiliteeriti	?reabiliteeriti =reabiliteeriti  (ImpPrSg2  >reabiliteerittima !28_V	et	f	\N
186175	reabiliteeriti	?reabiliteeriti =biliteeriti  (SgG  >rea+biliteeritt !22_S	et	f	\N
186209	stagnatsiooni	stagnatsiooni =stagnatsiooni  (SgG  >stagnatsioon !22_S	et	f	\N
186210	stagnatsiooni	stagnatsiooni =stagnatsiooni  (SgP  >stagnatsioon !22_S	et	f	\N
186211	stagnatsiooni	stagnatsiooni =stagnatsiooni  (SgAdt  >stagnatsioon !22_S	et	f	\N
186215	soojus	soojus =sooju  (IndIpfSg3  >soojuma !27_V	et	f	\N
186216	soojus	soojus =soojus  (SgN  >soojus !11~09_S	et	f	\N
186217	soojus	"soojus %sooj  )US_aS  <soe ;24_AS	et	f	\N
186235	muulaste	muulaste =muulas  (PlG  >muulane !12?10_S	et	f	\N
186236	muulaste	"muulane %muula  )NE_aA  <muul ;22_S	et	f	\N
186237	muulaste	muulaste =las  (PlG  >muu+laps !14_S	et	f	\N
186238	muulaste	muulaste =laste  (PlP  >muu+last !22_S	et	f	\N
186246	arusaamise	arusaamise =saamise  (SgG  >aru+saamine !12?10_S	et	f	\N
186247	arusaamise	"aru+saamine %saami  )NE_aA  <aru+saam ;22_S	et	f	\N
186248	taasstalinismiks	?taasstalinismiks =taasstalinismi  (SgTr  >taasstalinism !22_S	et	f	\N
186249	taasstalinismiks	?taasstalinismiks =taasstalinismi  (KndPrPs  >taasstalinismima !28_V	et	f	\N
186250	taasstalinismiks	?taasstalinismiks =stalinismi  (SgTr  >taas+stalinism !22_S	et	f	\N
186251	taasstalinismiks	?taasstalinismiks =stalinismi  (KndPrPs  >taas+stalinismima !28_V	et	f	\N
186261	kohalikusest	kohalikusest =kohalikuse  (SgEl  >kohalikus !11?09_S	et	f	\N
186262	kohalikusest	"kohalikus %kohaliku  )US_aS  <kohalik ;25_AS	et	f	\N
186265	aj	### aj	et	f	\N
186295	aastased	aastased =aastase  (PlN  >aastane !12~10_A	et	f	\N
186296	aastased	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
186298	muulased	muulased =muulase  (PlN  >muulane !12?10_S	et	f	\N
186299	muulased	"muulane %muula  )NE_aA  <muul ;22_S	et	f	\N
185940	stalinismiga	?stalinismiga =stalinismi  (SgKom  >stalinism !22_S	et	f	\N
185971	katastroofi	katastroofi =katastroofi  (SgG  >katastroof !22_S	et	f	\N
185972	katastroofi	katastroofi =katastroofi  (SgP  >katastroof !22_S	et	f	\N
185973	katastroofi	katastroofi =katastroofi  (SgAdt  >katastroof !22_S	et	f	\N
186003	leningraadi	?leningraadi =leningraadi  (SgN  >leningraadi !16_S	et	f	\N
186004	leningraadi	?leningraadi =leningraadi  (SgG  >leningraadi !16_S	et	f	\N
186005	leningraadi	?leningraadi =leningraadi  (SgG  >leningraat !22_S	et	f	\N
186006	leningraadi	?leningraadi =leningraadi  (SgP  >leningraad !22_S	et	f	\N
186007	leningraadi	?leningraadi =leningraadi  (SgAdt  >leningraad !22_S	et	f	\N
186008	leningraadi	?leningraadi =leningraadi  (IndPrPs_  >leningraatima !28_V	et	f	\N
186009	leningraadi	?leningraadi =leningraadi  (ImpPrSg2  >leningraatima !28_V	et	f	\N
186020	nälgisid	nälgisid =nälgi  (PlP  >nälg !22_S	et	f	\N
186021	nälgisid	nälgisid =nälgi  (IndIpfSg2  >nälgima !27_V	et	f	\N
186022	nälgisid	nälgisid =nälgi  (IndIpfPl3  >nälgima !27_V	et	f	\N
186032	1956a	### 1956a	et	f	\N
186051	25081940a	### 25081940a	et	f	\N
186067	kujutav-	kujutav- =kujuta  (PtsPrPs  >kujutama !27_V	et	f	\N
186068	kujutav-	kujutav- =kujutav  (SgN  >kujutav !02_A	et	f	\N
186069	kujutav-	"kujutav %kujuta  )V_vA  <kujutama ;27_V	et	f	\N
186070	aktivselt	?aktivselt =aktivse  (SgAbl  >aktivne !02_A	et	f	\N
186071	aktivselt	?aktivselt =aktivse  (PlAbl  >aktivs !22_S	et	f	\N
186072	aktivselt	?aktivselt =aktivselt  (ID  >aktivselt !41_D	et	f	\N
186076	hukkati	?hukkati =hukkati  (ID  >hukkati !41_D	et	f	\N
186077	hukkati	?hukkati =hukkati  (SgG  >hukkat !02_S	et	f	\N
186078	hukkati	?hukkati =hukkati  (SgG  >hukkatt !22_S	et	f	\N
186079	hukkati	?hukkati =hukkati  (IndPrPs_  >hukkattima !28_V	et	f	\N
186080	hukkati	?hukkati =hukkati  (ImpPrSg2  >hukkattima !28_V	et	f	\N
186081	kirjasõnast	kirjasõnast =sõna  (SgEl  >kirja+sõna !17_S	et	f	\N
186082	kirjasõnast	kirjasõnast =sõnas  (SgP  >kirja+sõnane !10_A	et	f	\N
186083	kirjasõnast	"kirja+sõnane %sõna  )NE_aA  <kirja+sõna ;17_S	et	f	\N
186099	aktiviseerusid	aktiviseerusid =aktiviseeru  (IndIpfSg2  >aktiviseeruma !27_V	et	f	\N
186100	aktiviseerusid	aktiviseerusid =aktiviseeru  (IndIpfPl3  >aktiviseeruma !27_V	et	f	\N
186144	1937a	### 1937a	et	f	\N
186158	käidua	?käidua =käidua  (SgN  >käidua !01_S	et	f	\N
186159	käidua	?käidua =käidua  (SgG  >käidua !01_S	et	f	\N
186162	ajaperioodi	ajaperioodi =perioodi  (SgG  >aja+periood !22_S	et	f	\N
186163	ajaperioodi	ajaperioodi =perioodi  (SgP  >aja+periood !22_S	et	f	\N
186164	ajaperioodi	ajaperioodi =perioodi  (SgAdt  >aja+periood !22_S	et	f	\N
186166	kergendamiseks	kergendamiseks =kergendamise  (SgTr  >kergendamine !12_S	et	f	\N
186167	kergendamiseks	"kergendamine %kergenda  )MINE_vS  <kergendama ;27_V	et	f	\N
186168	tõlgekirjandus	?tõlgekirjandus =tõlgekirjandu  (IndIpfSg3  >tõlgekirjanduma !27_V	et	f	\N
186169	tõlgekirjandus	?tõlgekirjandus =tõlgekirjandus  (SgN  >tõlgekirjandus !11_S	et	f	\N
186182	type1li	?typeli =typeli  (ID  >typeli !41_D	et	f	\N
186183	type1li	?typeli =typeli  (SgG  >typpel !02_S	et	f	\N
186185	classmsonormalbspan	?classmsonormalbspan =classmsonormalbspan  (SgN  >classmsonormalbspan !02_S	et	f	\N
186189	kruusemendilutsu	?kruusemendilutsu =kruusemendilutsu  (IndPrPs_  >kruusemendilutsuma !27_V	et	f	\N
186190	kruusemendilutsu	?kruusemendilutsu =kruusemendilutsu  (ImpPrSg2  >kruusemendilutsuma !27_V	et	f	\N
186202	kudias	?kudias =kudia  (SgIn  >kudia !01_S	et	f	\N
186203	kudias	?kudias =kudias  (SgN  >kudias !11_S	et	f	\N
186214	ettevõted	### ettevõted	et	f	\N
186227	halvenemist	halvenemist =halvenemis  (SgP  >halvenemine !12_S	et	f	\N
186228	halvenemist	"halvenemine %halvene  )MINE_vS  <halvenema ;27_V	et	f	\N
186253	nafta-	nafta- =nafta  (SgN  >nafta !16_S	et	f	\N
186254	nafta-	nafta- =nafta  (SgG  >nafta !16_S	et	f	\N
186255	urbaniseerumine	urbaniseerumine =urbaniseerumine  (SgN  >urbaniseerumine !12_S	et	f	\N
186256	urbaniseerumine	"urbaniseerumine %urbaniseeru  )MINE_vS  <urbaniseeruma ;27_V	et	f	\N
186259	tööjõud	tööjõud =jõu  (PlN  >töö+jõud !22_S	et	f	\N
186260	tööjõud	tööjõud =jõud  (SgN  >töö+jõud !22_S	et	f	\N
186263	nsvliidust	?nsvliidust =nsvliidu  (SgEl  >nsvliidu !16_S	et	f	\N
186264	nsvliidust	?nsvliidust =nsvliidus  (SgP  >nsvliidus !11~09_S	et	f	\N
186270	loaga	loaga =loa  (SgKom  >luba !18_S	et	f	\N
186271	loaga	loaga =loa  (SgKom  >luga !18_S	et	f	\N
186280	koolimaja	koolimaja =maja  (SgN  >kooli+maja !17_S	et	f	\N
186281	koolimaja	koolimaja =maja  (SgG  >kooli+maja !17_S	et	f	\N
186282	koolimaja	koolimaja =maja  (SgP  >kooli+maja !17_S	et	f	\N
186283	koolimaja	koolimaja =imaja  (SgN  >kool+imaja !01_S	et	f	\N
186284	koolimaja	koolimaja =imaja  (SgG  >kool+imaja !01_S	et	f	\N
186297	6a	### 6a	et	f	\N
186302	meelelahutussaade	meelelahutussaade =saade  (SgN  >meele+lahutus+saade !06_S	et	f	\N
186303	meelelahutussaade	meelelahutussaade =saade  (PlP  >meele+lahutus+saad !22_S	et	f	\N
186310	eestinsv	?eestinsv =eestinsv  (SgN  >eestinsv !22_S	et	f	\N
186311	eestinsv	?eestinsv =insv  (SgN  >eest+insv !22_S	et	f	\N
186312	eestinsv	?eestinsv =tinsv  (SgN  >ees+tinsv !22_S	et	f	\N
186326	kaevandused	kaevandused =kaevanduse  (PlN  >kaevandus !11_S	et	f	\N
186026	internaate	internaate =naate  (PlP  >inter+naat !22_S	et	f	\N
186030	kasvatamist	kasvatamist =kasvatamis  (SgP  >kasvatamine !12_S	et	f	\N
186031	kasvatamist	"kasvatamine %kasvata  )MINE_vS  <kasvatama ;27_V	et	f	\N
186034	lojaalsusest	lojaalsusest =lojaalsuse  (SgEl  >lojaalsus !11~09_S	et	f	\N
186035	lojaalsusest	"lojaalsus %lojaalse  )US_aS  <lojaalne ;02_A	et	f	\N
186036	lojaalsusest	lojaalsusest =lojaalsuses  (SgP  >lojaalsusene !12_A	et	f	\N
186037	lojaalsusest	"lojaalsusene %lojaalsuse  )NE_aA  <lojaalsus ;09_S	et	f	\N
186038	lojaalsusest	"lojaalsusene %lojaalsuse  )NE_aA  <lojaalsus ;11_S	et	f	\N
186050	24021918a-	### 24021918a-	et	f	\N
186054	vares-	vares- =vare  (SgIn  >vare !16_S	et	f	\N
186055	vares-	vares- =vares  (SgN  >vares !09_S	et	f	\N
186056	sõjatööstust	sõjatööstust =tust  (SgN  >sõja+töös+tust !22_S	et	f	\N
186057	sõjatööstust	sõjatööstust =tööstus  (SgP  >sõja+tööstus !11~09_S	et	f	\N
186084	ühinesid	ühinesid =ühine  (IndIpfSg2  >ühinema !27_V	et	f	\N
186085	ühinesid	ühinesid =ühine  (IndIpfPl3  >ühinema !27_V	et	f	\N
186090	plaaton	?plaaton =plaaton  (SgN  >plaaton !02_S	et	f	\N
186109	üldkultuuriliseks	üldkultuuriliseks =kultuurilise  (SgTr  >üld+kultuuriline !12_A	et	f	\N
186110	üldkultuuriliseks	"üld+kultuuriline %kultuuri  )LINE_aA  <üld+kultuur ;22_S	et	f	\N
186136	eriala-	eriala- =ala  (SgN  >eri+ala !17_S	et	f	\N
186137	eriala-	eriala- =ala  (SgG  >eri+ala !17_S	et	f	\N
186138	eriala-	eriala- =ala  (SgP  >eri+ala !17_S	et	f	\N
186150	lagle	lagle =lagle  (SgN  >lagle !16_S	et	f	\N
186151	lagle	lagle =lagle  (SgG  >lagle !16_S	et	f	\N
186154	betty	### betty	et	f	\N
186155	starkopf	?starkopf =starkopf  (SgN  >starkopf !22_S	et	f	\N
186160	kalmistusel	?kalmistusel =kalmistuse  (SgAd  >kalmistus !11_S	et	f	\N
186165	1956-	### 1956-	et	f	\N
186181	stylemargin-top	### stylemargin-top	et	f	\N
186186	migratsiooni	migratsiooni =migratsiooni  (SgG  >migratsioon !22_S	et	f	\N
186187	migratsiooni	migratsiooni =migratsiooni  (SgP  >migratsioon !22_S	et	f	\N
186188	migratsiooni	migratsiooni =migratsiooni  (SgAdt  >migratsioon !22_S	et	f	\N
186195	inimlikust	inimlikust =inimliku  (SgEl  >inimlik !25_A	et	f	\N
186197	inimlikust	inimlikust =inimlikus  (SgP  >inimlikus !11?09_S	et	f	\N
186199	inimlikust	"inimlikus %inimliku  )US_aS  <inimlik ;25_A	et	f	\N
186200	rohkemat	rohkemat =rohkema  (SgP  >rohkem !02_A	et	f	\N
186201	rohkemat	"rohkem %rohke  )M_cA  <rohke ;01_A	et	f	\N
186204	õppusest	õppusest =õppuse  (SgEl  >õppus !11~09_S	et	f	\N
186205	õppusest	õppusest =õppuses  (SgP  >õppusene !12_A	et	f	\N
186206	õppusest	"õppusene %õppuse  )NE_aA  <õppus ;09_S	et	f	\N
186207	õppusest	"õppusene %õppuse  )NE_aA  <õppus ;11_S	et	f	\N
186212	süvenemine	süvenemine =süvenemine  (SgN  >süvenemine !12_S	et	f	\N
186213	süvenemine	"süvenemine %süvene  )MINE_vS  <süvenema ;27_V	et	f	\N
186218	ettevoted	### ettevoted	et	f	\N
186231	eriloaga	eriloaga =loa  (SgKom  >eri+luba !18_S	et	f	\N
186232	eriloaga	eriloaga =loa  (SgKom  >eri+luga !18_S	et	f	\N
186239	mitte-eestlastele	mitte-eestlastele =eestlas  (PlAll  >mitte-eestlane !12?10_S	et	f	\N
186240	mitte-eestlastele	mitte-eestlastele =las  (PlAll  >mitte-eest+laps !14_S	et	f	\N
186241	mitte-eestlastele	mitte-eestlastele =laste  (PlAll  >mitte-eest+last !22_S	et	f	\N
186243	igapäevase	igapäevase =ase  (SgN  >iga+päev+ase !04_S	et	f	\N
186244	igapäevase	igapäevase =päevase  (SgG  >iga+päevane !10_A	et	f	\N
186245	igapäevase	"iga+päevane %päeva  )NE_aA  <iga+päev ;22_S	et	f	\N
186252	stalinismile	?stalinismile =stalinismi  (SgAll  >stalinism !22_S	et	f	\N
186272	talumeeste	talumeeste =mees  (PlG  >talu+meene !10_A	et	f	\N
186273	talumeeste	"talu+meene %mee  )NE_aA  <talu+mesi ;15_S	et	f	\N
186274	talumeeste	talumeeste =mees  (PlG  >talu+mees !13_S	et	f	\N
186275	kooilaste	?kooilaste =kooilas  (PlG  >kooilane !12?10_S	et	f	\N
186288	nsvs	### nsvs	et	f	\N
186300	teksaastes	teksaastes =aste  (SgIn  >teksa+aste !06_S	et	f	\N
186301	teksaastes	teksaastes =aste  (PlIn  >teksa+ast !22_S	et	f	\N
186304	tutvustati	tutvustati =tutvusta  (IndIpfIps  >tutvustama !27_V	et	f	\N
186305	tutvustati	tutvustati =tati  (SgG  >tutvus+tatt !22_S	et	f	\N
186320	kooskäimine	kooskäimine =käimine  (SgN  >koos+käimine !12?10_S	et	f	\N
186321	kooskäimine	"koos+käimine %käimi  )NE_aA  <koos+käim ;22_S	et	f	\N
186328	kvalititseeritud	?kvalititseeritud =kvalititseeri  (PtsPtIps  >kvalititseerima !28_V	et	f	\N
186329	kvalititseeritud	?kvalititseeritud =kvalititseeritu  (PlN  >kvalititseeritu !01_S	et	f	\N
186330	kvalititseeritud	?kvalititseeritud =kvalititseeritu  (IndPrSg2  >kvalititseerituma !27_V	et	f	\N
186331	kvalititseeritud	?kvalititseeritud =kvalititseeritud  (ID  >kvalititseeritud !41_A	et	f	\N
186334	audentsus	?audentsus =audentsu  (SgIn  >audentsu !01_S	et	f	\N
186335	audentsus	?audentsus =audentsu  (IndIpfSg3  >audentsuma !27_V	et	f	\N
186336	audentsus	?audentsus =audentsus  (SgN  >audentsus !11~09_S	et	f	\N
186337	audentsus	?audentsus =dentsus  (SgN  >au+dentsus !11~09_S	et	f	\N
186341	külakopelle	?külakopelle =külakopelle  (PlP  >külakopell !22_S	et	f	\N
186342	külakopelle	?külakopelle =kopelle  (PlP  >küla+kopell !22_S	et	f	\N
186349	improviseerimine	improviseerimine =improviseerimine  (SgN  >improviseerimine !12_S	et	f	\N
186142	sihtkapitalide	sihtkapitalide =tali  (PlG  >siht+kapi+tali !17_S	et	f	\N
186143	sihtkapitalide	sihtkapitalide =kapitali  (PlG  >siht+kapital !19_S	et	f	\N
186161	ensvst	?ensvst =ensvst  (SgN  >ensvst !22_S	et	f	\N
186176	jazz-muusika	jazz-muusika =muusika  (SgN  >jazz-muusika !01_S	et	f	\N
186177	jazz-muusika	jazz-muusika =muusika  (SgG  >jazz-muusika !01_S	et	f	\N
186192	iseloome	iseloome =loome  (SgN  >ise+loome !06_S	et	f	\N
186193	iseloome	iseloome =loome  (SgG  >ise+loome !06_S	et	f	\N
186194	iseloome	iseloome =loome  (PlP  >ise+loom !22_S	et	f	\N
186221	põliselanikute	?põliselanikute =põliselaniku  (PlG  >põliselanik !02_S	et	f	\N
186222	põliselanikute	?põliselanikute =põliselaniku  (IndPrPl2  >põliselanikuma !27_V	et	f	\N
186223	migrantid	?migrantid =migranti  (PlN  >migranti !01_S	et	f	\N
186229	salased	salased =salase  (PlN  >salane !10_A	et	f	\N
186230	salased	"salane %sala  )NE_aA  <sala ;17_S	et	f	\N
186233	nappimisega	nappimisega =nappimise  (SgKom  >nappimine !12_S	et	f	\N
186234	nappimisega	"nappimine %nappi  )MINE_vS  <nappima ;28_V	et	f	\N
186242	filmon	?filmon =filmon  (SgN  >filmon !02_S	et	f	\N
186257	elektritööstust	elektritööstust =tust  (SgN  >elektri+töös+tust !22_S	et	f	\N
186258	elektritööstust	elektritööstust =tööstus  (SgP  >elektri+tööstus !11~09_S	et	f	\N
186276	ristitakse	ristitakse =risti  (IndPrIps  >ristima !28_V	et	f	\N
186277	ristitakse	ristitakse =takse  (PlP  >risti+taks !22_S	et	f	\N
186278	talviseid	talviseid =talvise  (PlP  >talvine !10_A	et	f	\N
186279	talviseid	"talvine %talvi  )NE_aA  <talv ;22_S	et	f	\N
186285	koolielu	koolielu =elu  (SgN  >kooli+elu !17_S	et	f	\N
186286	koolielu	koolielu =elu  (SgG  >kooli+elu !17_S	et	f	\N
186287	koolielu	koolielu =elu  (SgP  >kooli+elu !17_S	et	f	\N
186289	musternäidis	musternäidis =näidi  (SgIn  >muster+näit !22_S	et	f	\N
186290	musternäidis	musternäidis =näidis  (SgN  >muster+näidis !09_S	et	f	\N
186318	teleke	teleke =teleke  (SgN  >teleke !12_S	et	f	\N
186319	teleke	"teleke %tele  )KE_dS  <tele ;16_S	et	f	\N
186322	valdo	?valdo =valdo  (SgN  >valdo !16_S	et	f	\N
186323	valdo	?valdo =valdo  (SgG  >valdo !16_S	et	f	\N
186332	muusikaelus	muusikaelus =elu  (SgIn  >muusika+elu !17_S	et	f	\N
186333	muusikaelus	muusikaelus =elus  (SgN  >muusika+elus !02_A	et	f	\N
186364	läbima	läbima =läbi  (Sup  >läbima !27_V	et	f	\N
186365	läbima	läbima =läbima  (SgG  >läbim !02_S	et	f	\N
186433	sõjasosalenud	?sõjasosalenud =sõjasosalenu  (PlN  >sõjasosalenu !01_S	et	f	\N
186434	sõjasosalenud	?sõjasosalenud =sõjasosalenu  (IndPrSg2  >sõjasosalenuma !27_V	et	f	\N
186435	sõjasosalenud	?sõjasosalenud =sõjasosalenud  (ID  >sõjasosalenud !41_A	et	f	\N
186436	sõjasosalenud	?sõjasosalenud =sosalenu  (PlN  >sõja+sosalenu !01_S	et	f	\N
186437	folkloorliikumine	?folkloorliikumine =folkloorliikumine  (SgN  >folkloorliikumine !12_S	et	f	\N
186438	folkloorliikumine	?folkloorliikumine =folkloorliikumine  (PlP  >folkloorliikumin !19_S	et	f	\N
186439	folkloorliikumine	?folkloorliikumine =loorliikumine  (SgN  >folk+loorliikumine !12_S	et	f	\N
186440	folkloorliikumine	?folkloorliikumine =loorliikumine  (PlP  >folk+loorliikumin !19_S	et	f	\N
186441	kohandatud	kohandatud =kohanda  (PtsPtIps  >kohandama !27_V	et	f	\N
186442	kohandatud	kohandatud =kohandatu  (PlN  >kohandatu !01_S	et	f	\N
186443	kohandatud	"kohandatu %kohanda  )TU1_vS  <kohandama ;27_V	et	f	\N
186444	kohandatud	kohandatud =kohandatud  (ID  >kohandatud !41_A	et	f	\N
186445	kohandatud	"kohandatud %kohanda  )TUD_vA  <kohandama ;27_V	et	f	\N
186474	triik	?triik =triik  (SgN  >triik !22_S	et	f	\N
186487	kultuuriajalukku	kultuuriajalukku =lukku  (SgP  >kultuuri+aja+lukk !22_S	et	f	\N
186488	kultuuriajalukku	kultuuriajalukku =lukku  (SgAdt  >kultuuri+aja+lugu !18_S	et	f	\N
186489	kultuuriajalukku	kultuuriajalukku =lukku  (SgAdt  >kultuuri+aja+lukk !22_S	et	f	\N
186495	utoplikust	?utoplikust =utopliku  (SgEl  >utoplik !25_A	et	f	\N
186496	utoplikust	?utoplikust =utoplikus  (SgP  >utoplikus !11?09_S	et	f	\N
186501	parteilisus	parteilisus =parteilisus  (SgN  >parteilisus !11?09_S	et	f	\N
186502	parteilisus	"parteilisus %partei  )LISUS_aS  <partei ;26_S	et	f	\N
186509	diktatuuri	diktatuuri =diktatuuri  (SgG  >diktatuur !22_S	et	f	\N
186510	diktatuuri	diktatuuri =diktatuuri  (SgP  >diktatuur !22_S	et	f	\N
186511	diktatuuri	diktatuuri =diktatuuri  (SgAdt  >diktatuur !22_S	et	f	\N
186547	vilimaa	vilimaa =maa  (SgN  >vili+maa !26_S	et	f	\N
186548	vilimaa	vilimaa =maa  (SgG  >vili+maa !26_S	et	f	\N
186582	takistusi	takistusi =takistusi  (PlP  >takistus !11_S	et	f	\N
186583	takistusi	"takistus %takista  )US_vS  <takistama ;27_V	et	f	\N
186616	eenstiiliks	?eenstiiliks =eenstiili  (SgTr  >eenstiili !16_S	et	f	\N
186617	eenstiiliks	?eenstiiliks =eenstiili  (SgTr  >eenstiil !22_S	et	f	\N
186618	eenstiiliks	?eenstiiliks =eenstiili  (KndPrPs  >eenstiilima !28_V	et	f	\N
186625	mõttetuid	mõttetuid =mõttetu  (PlP  >mõttetu !01_A	et	f	\N
186626	mõttetuid	"mõttetu %mõtte  )TU2_kA  <mõte ;06_S	et	f	\N
186627	mõttetuid	mõttetuid =tui  (PlN  >mõtte+tui !26_S	et	f	\N
186628	mõttetuid	mõttetuid =tui  (SgP  >mõtte+tui !26_S	et	f	\N
186635	sissevool	sissevool =voo  (SgAd  >sisse+voog !22_S	et	f	\N
186636	sissevool	sissevool =vool  (SgN  >sisse+vool !22_S	et	f	\N
186148	premeerima	premeerima =rima  (SgP  >pre+mee+rima !17_S	et	f	\N
186152	pallas	?pallas =palla  (IndIpfSg3  >pallama !29_V	et	f	\N
186153	pallas	?pallas =pallas  (SgN  >pallas !07_S	et	f	\N
186156	kajastuvaid	kajastuvaid =kajastuva  (PlP  >kajastuv !02_A	et	f	\N
186157	kajastuvaid	"kajastuv %kajastu  )V_vA  <kajastuma ;27_V	et	f	\N
186178	stalinistliku	?stalinistliku =stalinistliku  (SgG  >stalinistlik !25_A	et	f	\N
186179	stalinistliku	?stalinistliku =stalinistliku  (IndPrPs_  >stalinistlikuma !27_V	et	f	\N
186180	stalinistliku	?stalinistliku =stalinistliku  (ImpPrSg2  >stalinistlikuma !27_V	et	f	\N
186184	langetmajanduse	?langetmajanduse =langetmajanduse  (SgG  >langetmajandus !11_S	et	f	\N
186191	20-da	### 20-da	et	f	\N
186196	arno	?arno =arno  (SgN  >arno !16_S	et	f	\N
186198	arno	?arno =arno  (SgG  >arno !16_S	et	f	\N
186208	1970ndad	### 1970ndad	et	f	\N
186219	tööjõudu	tööjõudu =jõudu  (SgP  >töö+jõud !22_S	et	f	\N
186220	tööjõudu	tööjõudu =jõudu  (SgAdt  >töö+jõud !22_S	et	f	\N
186224	elupinda	elupinda =pinda  (SgG  >elu+pint !22_S	et	f	\N
186225	elupinda	elupinda =pinda  (SgP  >elu+pind !22_S	et	f	\N
186226	elupinda	elupinda =pinda  (SgAdt  >elu+pind !22_S	et	f	\N
186266	ruhnu	?ruhnu =ruhnu  (SgN  >ruhnu !01_S	et	f	\N
186267	ruhnu	?ruhnu =ruhnu  (SgG  >ruhnu !01_S	et	f	\N
186268	ruhnu	?ruhnu =ruhnu  (IndPrPs_  >ruhnuma !27_V	et	f	\N
186269	ruhnu	?ruhnu =ruhnu  (ImpPrSg2  >ruhnuma !27_V	et	f	\N
186291	riigikanaleid	riigikanaleid =lei  (PlN  >riigi+kana+lei !26_S	et	f	\N
186292	riigikanaleid	riigikanaleid =lei  (SgP  >riigi+kana+lei !26_S	et	f	\N
186293	riigikanaleid	riigikanaleid =leid  (SgN  >riigi+kana+leid !22_S	et	f	\N
186294	riigikanaleid	riigikanaleid =kanale  (PlP  >riigi+kanal !02_S	et	f	\N
186313	lastesadeid	?lastesadeid =lastesadei  (PlN  >lastesadei !26_S	et	f	\N
186314	lastesadeid	?lastesadeid =lastesadei  (SgP  >lastesadei !26_S	et	f	\N
186315	lastesadeid	?lastesadeid =sadei  (PlN  >laste+sadei !26_S	et	f	\N
186316	lastesadeid	?lastesadeid =sadei  (SgP  >laste+sadei !26_S	et	f	\N
186317	lastesadeid	?lastesadeid =sadeid  (SgN  >laste+sadeid !22_S	et	f	\N
186324	leiis	?leiis =leii  (SgIn  >leii !26_S	et	f	\N
186325	leiis	?leiis =leiis  (SgN  >leiis !22_S	et	f	\N
186343	klassikalise	klassikalise =klassikalise  (SgG  >klassikaline !12_A	et	f	\N
186344	klassikalise	"klassikaline %klassika  )LINE_aA  <klassika ;01_S	et	f	\N
186345	klassikalise	klassikalise =kalise  (SgG  >klassi+kaline !10_A	et	f	\N
186346	klassikalise	"klassi+kaline %kali  )NE_aA  <klassi+kali ;17_S	et	f	\N
186351	hellero	?hellero =hellero  (SgN  >hellero !01_S	et	f	\N
186352	hellero	?hellero =hellero  (SgG  >hellero !01_S	et	f	\N
186353	seelle	?seelle =seelle  (SgN  >seelle !06_S	et	f	\N
186354	seelle	?seelle =seelle  (SgG  >seelle !06_S	et	f	\N
186355	seelle	?seelle =seelle  (PlP  >seell !22_S	et	f	\N
186356	seelle	?seelle =seelle  (IndPrPs_  >seellema !30_V	et	f	\N
186357	seelle	?seelle =seelle  (ImpPrSg2  >seellema !30_V	et	f	\N
186366	vastuvõttav	?vastuvõttav =vastuvõttav  (SgN  >vastuvõttav !02_A	et	f	\N
186367	vastuvõttav	?vastuvõttav =võtta  (PtsPrPs  >vastu+_võttama !29_V	et	f	\N
186368	vastuvõttav	?vastuvõttav =võttav  (SgN  >vastu+võttav !02_A	et	f	\N
186369	vastuvõttav	?vastuvõttav =uvõttav  (SgN  >vast+uvõttav !02_A	et	f	\N
186370	tarbekaupa	tarbekaupa =kaupa  (ID  >tarbe+kaupa !41_D	et	f	\N
186371	tarbekaupa	tarbekaupa =kaupa  (SgP  >tarbe+kaup !22_S	et	f	\N
186372	tarbekaupa	tarbekaupa =kaupa  (SgAdt  >tarbe+kaup !22_S	et	f	\N
186376	trükitis	?trükitis =trükiti  (SgIn  >trükit !02_S	et	f	\N
186377	trükitis	?trükitis =trükiti  (SgIn  >trükitt !22_S	et	f	\N
186378	trükitis	?trükitis =trükitis  (SgN  >trükitis !11_S	et	f	\N
186404	hullumeesus	hullumeesus =meesus  (SgN  >hullu+meesus !11~09_S	et	f	\N
186405	hullumeesus	"hullu+meesus %mee  )SUS_aS  <hullu+mesi ;15_S	et	f	\N
186408	muusikasseal	?muusikasseal =muusikassea  (SgAd  >muusikassea !26_S	et	f	\N
186409	muusikasseal	?muusikasseal =muusikasseal  (SgN  >muusikasseal !19_S	et	f	\N
186410	muusikasseal	?muusikasseal =sikassea  (SgAd  >muu+sikassea !26_S	et	f	\N
186411	muusikasseal	?muusikasseal =sikasseal  (SgN  >muu+sikasseal !19_S	et	f	\N
186417	koorta	?koorta =koorta  (SgN  >koorta !01_S	et	f	\N
186418	koorta	?koorta =koorta  (SgG  >koorta !01_S	et	f	\N
186419	koorta	?koorta =koorta  (IndPrPs_  >koortama !29_V	et	f	\N
186420	koorta	?koorta =koorta  (ImpPrSg2  >koortama !29_V	et	f	\N
186456	massiteava	?massiteava =massiteava  (SgN  >massiteava !16_S	et	f	\N
186457	massiteava	?massiteava =massiteava  (SgG  >massiteava !16_S	et	f	\N
186458	massiteava	?massiteava =teava  (SgN  >massi+teava !16_S	et	f	\N
186459	massiteava	?massiteava =teava  (SgG  >massi+teava !16_S	et	f	\N
186460	massiteava	?massiteava =iteava  (SgN  >mass+iteava !16_S	et	f	\N
186461	massiteava	?massiteava =iteava  (SgG  >mass+iteava !16_S	et	f	\N
186463	ostei	?ostei =ostei  (SgN  >ostei !26_S	et	f	\N
186464	ostei	?ostei =ostei  (SgG  >ostei !26_S	et	f	\N
186472	iseloomulikum	iseloomulikum =loomulikum  (SgN  >ise+loomulikum !02_A	et	f	\N
186473	iseloomulikum	"ise+loomulikum %loomuliku  )M_cA  <ise+loomulik ;25_A	et	f	\N
186478	piimamees	piimamees =mee  (SgIn  >piima+mesi !15_S	et	f	\N
186306	aastavahetus	aastavahetus =vahetu  (SgIn  >aasta+vahetu !01_A	et	f	\N
186307	aastavahetus	"aasta+vahetu %vahe  )TU2_kA  <aasta+vahe ;16_S	et	f	\N
186308	aastavahetus	aastavahetus =vahetus  (SgN  >aasta+vahetus !11_S	et	f	\N
186309	aastavahetus	"aasta+vahetus %vahe  )TUS2_aS  <aasta+vahe ;16_S	et	f	\N
186338	spetsialselt	?spetsialselt =spetsialse  (SgAbl  >spetsialne !02_A	et	f	\N
186339	spetsialselt	?spetsialselt =spetsialse  (PlAbl  >spetsials !22_S	et	f	\N
186340	spetsialselt	?spetsialselt =spetsialselt  (ID  >spetsialselt !41_D	et	f	\N
186347	popmuusika	popmuusika =muusika  (SgN  >pop+muusika !01_S	et	f	\N
186348	popmuusika	popmuusika =muusika  (SgG  >pop+muusika !01_S	et	f	\N
186358	uuendused	uuendused =uuenduse  (PlN  >uuendus !11_S	et	f	\N
186359	uuendused	"uuendus %uuenda  )US_vS  <uuendama ;27_V	et	f	\N
186360	kasulikut	?kasulikut =uliku  (SgP  >kas+uliku !01_S	et	f	\N
186361	kasulikut	?kasulikut =uliku  (SgP  >kas+ulik !02_S	et	f	\N
186373	luksuskaubadele	?luksuskaubadele =luksuskauba  (PlAll  >luksuskauba !16_S	et	f	\N
186374	koomiksiline	koomiksiline =koomiksiline  (SgN  >koomiksiline !12_A	et	f	\N
186375	koomiksiline	"koomiksiline %koomiksi  )LINE_aA  <koomiks ;02_S	et	f	\N
186379	helsingi-tallinna	?helsingi-tallinna =tallinna  (SgN  >helsingi-tallinna !16_S	et	f	\N
186380	helsingi-tallinna	?helsingi-tallinna =tallinna  (SgG  >helsingi-tallinna !16_S	et	f	\N
186381	helsingi-tallinna	?helsingi-tallinna =tallinna  (SgP  >helsingi-tallinn !22_H	et	f	\N
186382	helsingi-tallinna	?helsingi-tallinna =tallinna  (SgAdt  >helsingi-tallinn !22_H	et	f	\N
186383	valutakauplusi	?valutakauplusi =valutakauplusi  (PlP  >valutakauplus !11_S	et	f	\N
186384	valutakauplusi	?valutakauplusi =takauplusi  (PlP  >valu+takauplus !11_S	et	f	\N
186395	inger	?inger =inger  (SgN  >inger !02_S	et	f	\N
186396	härala	?härala =härala  (SgN  >härala !01_S	et	f	\N
186397	härala	?härala =härala  (SgG  >härala !01_S	et	f	\N
186412	televisioonil	televisioonil =televisiooni  (SgAd  >televisioon !22_S	et	f	\N
186413	televisioonil	televisioonil =visiooni  (SgAd  >tele+visioon !22_S	et	f	\N
186446	koop	?koop =koop  (SgN  >koop !22_S	et	f	\N
186450	maakooli	maakooli =kooli  (SgG  >maa+kool !22_S	et	f	\N
186451	maakooli	maakooli =kooli  (SgP  >maa+kool !22_S	et	f	\N
186452	maakooli	maakooli =kooli  (SgAdt  >maa+kool !22_S	et	f	\N
186453	maakooli	maakooli =kooli  (PlP  >maa+kool !22_S	et	f	\N
186454	suundus	suundus =suundu  (IndIpfSg3  >suunduma !27_V	et	f	\N
186455	suundus	suundus =suundus  (SgN  >suundus !11~09_S	et	f	\N
186475	mäeküla	mäeküla =küla  (SgN  >mäe+küla !17_S	et	f	\N
186476	mäeküla	mäeküla =küla  (SgG  >mäe+küla !17_S	et	f	\N
186477	mäeküla	mäeküla =küla  (SgP  >mäe+küla !17_S	et	f	\N
186486	rezissör	?rezissör =rezissör  (SgN  >rezissör !19_S	et	f	\N
186497	sotsialismist	sotsialismist =sotsialismi  (SgEl  >sotsialism !22_S	et	f	\N
186498	sotsialismist	sotsialismist =sotsialismis  (SgP  >sotsialismine !12_A	et	f	\N
186499	sotsialismist	"sotsialismine %sotsialismi  )NE_aA  <sotsialism ;22_S	et	f	\N
186505	tegelikkuse	tegelikkuse =tegelikkuse  (SgG  >tegelikkus !11~09_S	et	f	\N
186506	tegelikkuse	"tegelikkus %tegelikku  )US_aS  <tegelik ;25_A	et	f	\N
186521	seisaku	seisaku =seisa  (ImpPrPs  >seiskama !29_V	et	f	\N
186522	seisaku	seisaku =seisaku  (SgG  >seisak !02_S	et	f	\N
186523	kujutava-	kujutava- =kujutava  (SgG  >kujutav !02_A	et	f	\N
186524	kujutava-	"kujutav %kujuta  )V_vA  <kujutama ;27_V	et	f	\N
186525	kujutava-	kujutava- =tava  (SgN  >kuju+tava !17_S	et	f	\N
186526	kujutava-	kujutava- =tava  (SgG  >kuju+tava !17_S	et	f	\N
186527	kujutava-	kujutava- =tava  (SgP  >kuju+tava !17_S	et	f	\N
186531	1970ndates	?ndates =ndate  (PlIn  >ndatt !22_S	et	f	\N
186532	1970ndates	?ndates =ndate  (IndIpfSg3  >ndatema !27_V	et	f	\N
186533	1970ndates	?ndates =ndates  (SgN  >ndates !09_S	et	f	\N
186538	toomingu	?toomingu =toomingu  (SgN  >toomingu !01_S	et	f	\N
186539	toomingu	?toomingu =toomingu  (SgG  >toomingu !01_S	et	f	\N
186540	toomingu	?toomingu =toomingu  (SgG  >tooming !02_S	et	f	\N
186541	toomingu	?toomingu =toomingu  (IndPrPs_  >toominguma !27_V	et	f	\N
186542	toomingu	?toomingu =toomingu  (ImpPrSg2  >toominguma !27_V	et	f	\N
186543	toomingu	?toomingu =ingu  (SgP  >toom+ing !22_S	et	f	\N
186544	toomingu	?toomingu =ingu  (SgAdt  >toom+ing !22_S	et	f	\N
186545	toomingu	?toomingu =mingu  (SgP  >too+ming !22_S	et	f	\N
186546	toomingu	?toomingu =mingu  (SgAdt  >too+ming !22_S	et	f	\N
186577	kaevandusse	kaevandusse =kaevandus  (SgAdt  >kaevandus !11_S	et	f	\N
186578	kaevandusse	"kaevandus %kaevanda  )US_vS  <kaevandama ;27_V	et	f	\N
186579	aseda	?aseda =ase  (Inf  >asema !27_V	et	f	\N
186594	vms	### vms	et	f	\N
186604	kruusa	kruusa =kruusa  (SgG  >kruus !22_S	et	f	\N
186605	kruusa	kruusa =kruusa  (SgP  >kruus !22_S	et	f	\N
186606	kruusa	kruusa =kruusa  (SgAdt  >kruus !22_S	et	f	\N
186621	arvastatav	?arvastatav =arvasta  (PtsPrIps  >arvastama !27_V	et	f	\N
186622	arvastatav	?arvastatav =arvastata  (PtsPrPs  >arvastatama !27_V	et	f	\N
186623	arvastatav	?arvastatav =arvastatav  (SgN  >arvastatav !02_A	et	f	\N
186624	arvastatav	?arvastatav =astatav  (SgN  >arv+astatav !02_A	et	f	\N
186633	kaevandamine	kaevandamine =kaevandamine  (SgN  >kaevandamine !12_S	et	f	\N
186327	kaevandused	"kaevandus %kaevanda  )US_vS  <kaevandama ;27_V	et	f	\N
186362	sõjaväelise	sõjaväelise =väelise  (SgG  >sõja+väeline !12?10_A	et	f	\N
186363	sõjaväelise	"sõja+väeline %väe  )LINE_aA  <sõja+vägi ;21_S	et	f	\N
186385	mundi	?mundi =mundi  (SgN  >mundi !16_S	et	f	\N
186386	mundi	?mundi =mundi  (SgG  >mundi !16_S	et	f	\N
186387	mundi	?mundi =mundi  (SgG  >munt !22_S	et	f	\N
186388	mundi	?mundi =mundi  (SgP  >mund !22_S	et	f	\N
186389	mundi	?mundi =mundi  (SgAdt  >mund !22_S	et	f	\N
186390	mundi	?mundi =mundi  (IndPrPs_  >muntima !28_V	et	f	\N
186391	mundi	?mundi =mundi  (ImpPrSg2  >muntima !28_V	et	f	\N
186392	70ndate	?ndate =ndate  (SgN  >ndate !06_S	et	f	\N
186393	70ndate	?ndate =ndate  (IndPrPs_  >ndatema !27_V	et	f	\N
186394	70ndate	?ndate =ndate  (ImpPrSg2  >ndatema !27_V	et	f	\N
186398	järdi	?järdi =järdi  (ID  >järdi !41_D	et	f	\N
186399	järdi	?järdi =järdi  (SgG  >järt !22_S	et	f	\N
186400	järdi	?järdi =järdi  (SgP  >järd !22_S	et	f	\N
186401	järdi	?järdi =järdi  (SgAdt  >järd !22_S	et	f	\N
186402	järdi	?järdi =järdi  (IndPrPs_  >järtima !28_V	et	f	\N
186403	järdi	?järdi =järdi  (ImpPrSg2  >järtima !28_V	et	f	\N
186406	laualt	laualt =laua  (SgAbl  >laud !22_S	et	f	\N
186407	laualt	laualt =alt  (SgN  >lau+alt !22_S	et	f	\N
186424	nsv-lik	### nsv-lik	et	f	\N
186462	1970ndal	### 1970ndal	et	f	\N
186465	kordis	?kordis =kordi  (SgIn  >kort !22_S	et	f	\N
186466	kordis	?kordis =kordi  (IndIpfSg3  >kordima !28_V	et	f	\N
186467	kordis	?kordis =kordis  (SgN  >kordis !09_S	et	f	\N
186483	filmikunstiga	filmikunstiga =iga  (SgN  >filmi+kunst+iga !18_S	et	f	\N
186484	filmikunstiga	filmikunstiga =iga  (SgP  >filmi+kunst+iga !18_S	et	f	\N
186485	filmikunstiga	filmikunstiga =kunsti  (SgKom  >filmi+kunst !22_S	et	f	\N
186493	martistlikud	?martistlikud =martistliku  (PlN  >martistlik !25_A	et	f	\N
186494	martistlikud	?martistlikud =martistliku  (IndPrSg2  >martistlikuma !27_V	et	f	\N
186534	autoreid	autoreid =autore  (PlP  >autor !02_S	et	f	\N
186535	autoreid	autoreid =reid  (SgN  >auto+reid !22_S	et	f	\N
186536	kroos	?kroos =kroo  (SgIn  >kroo !26_S	et	f	\N
186537	kroos	?kroos =kroos  (SgN  >kroos !22_S	et	f	\N
186551	lavastajad	lavastajad =lavastaja  (PlN  >lavastaja !01_S	et	f	\N
186552	lavastajad	"lavastaja %lavasta  )JA_vS  <lavastama ;27_V	et	f	\N
186553	debuteerisid	?debuteerisid =debuteeri  (PlP  >debuteeri !16_S	et	f	\N
186554	debuteerisid	?debuteerisid =debuteeri  (PlP  >debuteer !22_S	et	f	\N
186555	debuteerisid	?debuteerisid =debuteeri  (IndIpfSg2  >debuteerima !28_V	et	f	\N
186556	debuteerisid	?debuteerisid =debuteeri  (IndIpfPl3  >debuteerima !28_V	et	f	\N
186573	suurenev	suurenev =suurene  (PtsPrPs  >suurenema !27_V	et	f	\N
186574	suurenev	suurenev =suurenev  (SgN  >suurenev !02_A	et	f	\N
186575	suurenev	"suurenev %suurene  )V_vA  <suurenema ;27_V	et	f	\N
186607	mõtlematult	mõtlematult =mõtlematu  (SgAbl  >mõtlematu !01_A	et	f	\N
186608	mõtlematult	"mõtlematu %mõtle  )MATU_vA  <mõtlema ;30_V	et	f	\N
186610	mõtlematult	mõtlematult =mõtlematult  (ID  >mõtlematult !41_D	et	f	\N
186612	mõtlematult	"mõtlematult %mõtle  )MATULT_mD  <mõtlema ;30_V	et	f	\N
186613	mõtlematult	"mõtlematult %mõtlematu  )LT_mD  <mõtlematu ;01_A	et	f	\N
186614	näppamine	näppamine =näppamine  (SgN  >näppamine !12_S	et	f	\N
186615	näppamine	"näppamine %näppa  )MINE_vS  <näppama ;29_V	et	f	\N
186672	naeratakse	?naeratakse =naera  (IndPrIps  >naerama !29_V	et	f	\N
186673	naeratakse	?naeratakse =naeratakse  (SgG  >naeratakne !02_A	et	f	\N
186674	naeratakse	?naeratakse =naeratakse  (PlP  >naerataks !22_S	et	f	\N
186683	erikaga	?erikaga =erika  (SgKom  >erika !01_S	et	f	\N
186684	erikaga	?erikaga =erika  (SgKom  >erikas !02_S	et	f	\N
186685	erikaga	?erikaga =kaga  (SgN  >eri+kaga !17_S	et	f	\N
186686	erikaga	?erikaga =kaga  (SgG  >eri+kaga !17_S	et	f	\N
186687	erikaga	?erikaga =kaga  (SgP  >eri+kaga !17_S	et	f	\N
186702	büroklaatlik	?büroklaatlik =büroklaatlik  (SgN  >büroklaatlik !25_A	et	f	\N
186711	gigantproektid	?gigantproektid =gigantproekti  (PlN  >gigantproekt !22_S	et	f	\N
186712	gigantproektid	?gigantproektid =gigantproekti  (IndPrSg2  >gigantproektima !28_V	et	f	\N
186713	gigantproektid	?gigantproektid =proekti  (PlN  >gigant+proekt !22_S	et	f	\N
186715	saastamine	saastamine =saastamine  (SgN  >saastamine !12_S	et	f	\N
186716	saastamine	"saastamine %saasta  )MINE_vS  <saastama ;27_V	et	f	\N
186717	saastamine	"saastamine %saasta  )MINE_vS  <saastama ;29_V	et	f	\N
186718	jäätma	?jäätma =jäät  (Sup  >jäätma !34_V	et	f	\N
186719	jäätma	?jäätma =jäätma  (IndPrPs_  >jäätmama !29_V	et	f	\N
186720	jäätma	?jäätma =jäätma  (ImpPrSg2  >jäätmama !29_V	et	f	\N
186728	ökoloogilise	ökoloogilise =ökoloogilise  (SgG  >ökoloogiline !12_A	et	f	\N
186729	ökoloogilise	"ökoloogiline %ökoloogi  )LINE_aA  <ökoloog ;22_S	et	f	\N
186730	ökoloogilise	ökoloogilise =loogilise  (SgG  >öko+loogiline !12_A	et	f	\N
186731	ökoloogilise	"öko+loogiline %loogi  )LINE_aA  <öko+loog ;22_S	et	f	\N
186739	keemitehased	?keemitehased =keemitehase  (PlN  >keemitehane !12_A	et	f	\N
186750	ääremaadele	ääremaadele =maa  (PlAll  >ääre+maa !26_S	et	f	\N
186350	improviseerimine	"improviseerimine %improviseeri  )MINE_vS  <improviseerima ;28_V	et	f	\N
186414	tõsielusarja	tõsielusarja =sarja  (SgG  >tõsi+elu+sari !24_S	et	f	\N
186415	tõsielusarja	tõsielusarja =sarja  (SgP  >tõsi+elu+sari !24_S	et	f	\N
186416	tõsielusarja	tõsielusarja =sarja  (SgAdt  >tõsi+elu+sari !24_S	et	f	\N
186421	õppeprogrammi	õppeprogrammi =programmi  (SgG  >õppe+programm !22_S	et	f	\N
186422	õppeprogrammi	õppeprogrammi =programmi  (SgP  >õppe+programm !22_S	et	f	\N
186423	õppeprogrammi	õppeprogrammi =programmi  (SgAdt  >õppe+programm !22_S	et	f	\N
186425	aastavahetuseprogrammid	?aastavahetuseprogrammid =aastavahetuseprogrammi  (PlN  >aastavahetuseprogramm !22_S	et	f	\N
186426	aastavahetuseprogrammid	?aastavahetuseprogrammid =aastavahetuseprogrammi  (IndPrSg2  >aastavahetuseprogrammima !28_V	et	f	\N
186427	aastavahetuseprogrammid	?aastavahetuseprogrammid =eprogrammi  (PlN  >aasta+vahetus+eprogramm !22_S	et	f	\N
186428	aastavahetuseprogrammid	?aastavahetuseprogrammid =useprogrammi  (PlN  >aasta+vahet+useprogramm !22_S	et	f	\N
186429	aastavahetuseprogrammid	?aastavahetuseprogrammid =tuseprogrammi  (PlN  >aasta+vahe+tuseprogramm !22_S	et	f	\N
186430	aastavahetuseprogrammid	?aastavahetuseprogrammid =hetuseprogrammi  (PlN  >aas+tava+hetuseprogramm !22_S	et	f	\N
186431	aastavahetuseprogrammid	?aastavahetuseprogrammid =vahetuseprogrammi  (PlN  >aasta+vahetuseprogramm !22_S	et	f	\N
186432	aastavahetuseprogrammid	?aastavahetuseprogrammid =tavahetuseprogrammi  (PlN  >aas+tavahetuseprogramm !22_S	et	f	\N
186447	nõukogudelik	?nõukogudelik =nõukogudelik  (SgN  >nõukogudelik !25_A	et	f	\N
186448	nõukogudelik	?nõukogudelik =delik  (SgN  >nõu+kogu+delik !02_S	et	f	\N
186449	nõukogudelik	?nõukogudelik =kogudelik  (SgN  >nõu+kogudelik !25_A	et	f	\N
186468	ivask	?ivask =ivask  (SgN  >ivask !02_S	et	f	\N
186469	proosakirjandusest	proosakirjandusest =kirjanduse  (SgEl  >proosa+kirjandus !11_S	et	f	\N
186470	proosakirjandusest	proosakirjandusest =kirjanduses  (SgP  >proosa+kirjandusene !12_A	et	f	\N
186471	proosakirjandusest	"proosa+kirjandusene %kirjanduse  )NE_aA  <proosa+kirjandus ;11_S	et	f	\N
186491	kunstivool	kunstivool =voo  (SgAd  >kunsti+voog !22_S	et	f	\N
186492	kunstivool	kunstivool =vool  (SgN  >kunsti+vool !22_S	et	f	\N
186500	lenililt	### lenililt	et	f	\N
186528	1960ndates	?ndates =ndate  (PlIn  >ndatt !22_S	et	f	\N
186529	1960ndates	?ndates =ndate  (IndIpfSg3  >ndatema !27_V	et	f	\N
186530	1960ndates	?ndates =ndates  (SgN  >ndates !09_S	et	f	\N
186558	pravdale	?pravdale =pravda  (SgAll  >pravda !16_S	et	f	\N
186559	pravdale	?pravdale =pravdale  (IndPrPs_  >pravdalema !27_V	et	f	\N
186560	pravdale	?pravdale =pravdale  (ImpPrSg2  >pravdalema !27_V	et	f	\N
186562	täielikusest	täielikusest =täielikuse  (SgEl  >täielikus !11?09_S	et	f	\N
186563	täielikusest	"täielikus %täieliku  )US_aS  <täielik ;25_A	et	f	\N
186570	oskaril	?oskaril =oskari  (SgAd  >oskari !01_S	et	f	\N
186571	oskaril	?oskaril =oskari  (SgAd  >oskar !02_S	et	f	\N
186572	sab	### sab	et	f	\N
186587	loksa	?loksa =loksa  (SgN  >loksa !16_S	et	f	\N
186588	loksa	?loksa =loksa  (SgG  >loksa !16_S	et	f	\N
186589	loksa	?loksa =loksa  (IndPrPs_  >loksama !29_V	et	f	\N
186590	loksa	?loksa =loksa  (ImpPrSg2  >loksama !29_V	et	f	\N
186591	küllakutse	küllakutse =kutse  (SgN  >külla+kutse !06_S	et	f	\N
186592	küllakutse	küllakutse =kutse  (SgG  >külla+kutse !06_S	et	f	\N
186593	küllakutse	küllakutse =kutse  (PlP  >külla+kuts !22_S	et	f	\N
186595	pidsi	?pidsi =pidsi  (SgN  >pidsi !16_S	et	f	\N
186596	pidsi	?pidsi =pidsi  (SgG  >pidsi !16_S	et	f	\N
186597	pidsi	?pidsi =pidsi  (SgG  >pids !22_S	et	f	\N
186598	pidsi	?pidsi =pidsi  (SgP  >pids !22_S	et	f	\N
186599	pidsi	?pidsi =pidsi  (SgAdt  >pids !22_S	et	f	\N
186600	pidsi	?pidsi =pidsi  (IndPrPs_  >pidsima !28_V	et	f	\N
186602	pidsi	?pidsi =pidsi  (ImpPrSg2  >pidsima !28_V	et	f	\N
186609	hävinesid	hävinesid =hävine  (IndIpfSg2  >hävinema !27_V	et	f	\N
186611	hävinesid	hävinesid =hävine  (IndIpfPl3  >hävinema !27_V	et	f	\N
186629	heeringas	heeringas =heeringa  (SgIn  >heeringas !02_S	et	f	\N
186630	heeringas	heeringas =heeringas  (SgN  >heeringas !02_S	et	f	\N
186647	vajaduste	vajaduste =vajadus  (PlG  >vajadus !11_S	et	f	\N
186648	vajaduste	vajaduste =duste  (PlP  >vaja+dust !22_S	et	f	\N
186669	oskari	?oskari =oskari  (SgN  >oskari !01_S	et	f	\N
186670	oskari	?oskari =oskari  (SgG  >oskari !01_S	et	f	\N
186671	oskari	?oskari =oskari  (SgG  >oskar !02_S	et	f	\N
186677	eerikast	?eerikast =eerika  (SgEl  >eerika !01_S	et	f	\N
186678	eerikast	?eerikast =eerika  (SgEl  >eerikas !02_S	et	f	\N
186679	eerikast	?eerikast =eerikas  (SgP  >eerikane !12_A	et	f	\N
186700	breznev	?breznev =brezne  (PtsPrPs  >breznema !27_V	et	f	\N
186701	breznev	?breznev =breznev  (SgN  >breznev !02_A	et	f	\N
186703	priviligeerituks	?priviligeerituks =priviligeeri  (KndPtIps  >priviligeerima !28_V	et	f	\N
186704	priviligeerituks	?priviligeerituks =priviligeeritu  (SgTr  >priviligeeritu !01_S	et	f	\N
186705	priviligeerituks	?priviligeerituks =priviligeeritu  (KndPrPs  >priviligeerituma !27_V	et	f	\N
186708	põhjendamatud	põhjendamatud =põhjendamatu  (PlN  >põhjendamatu !01_A	et	f	\N
186710	põhjendamatud	"põhjendamatu %põhjenda  )MATU_vA  <põhjendama ;27_V	et	f	\N
186714	nsvl-u	### nsvl-u	et	f	\N
186732	halvenemise	halvenemise =halvenemise  (SgG  >halvenemine !12_S	et	f	\N
186479	piimamees	piimamees =mees  (SgN  >piima+mees !13_S	et	f	\N
186480	moortele	?moortele =moorte  (SgAll  >moorde !06_S	et	f	\N
186481	moortele	?moortele =moortele  (IndPrPs_  >moortelema !27_V	et	f	\N
186482	moortele	?moortele =moortele  (ImpPrSg2  >moortelema !27_V	et	f	\N
186490	näidimuster	?näidimuster =näidimuster  (SgN  >näidimuster !02_S	et	f	\N
186503	rahvalikkus	rahvalikkus =rahvalikkus  (SgN  >rahvalikkus !11~09_S	et	f	\N
186504	rahvalikkus	"rahvalikkus %rahvalikku  )US_aS  <rahvalik ;25_A	et	f	\N
186507	väikede	?väikede =kede  (SgN  >väi+kede !16_S	et	f	\N
186508	väikede	?väikede =kede  (SgG  >väi+kede !16_S	et	f	\N
186512	pessimis	?pessimis =pessimi  (SgIn  >pessimi !01_S	et	f	\N
186513	pessimis	?pessimis =pessimi  (SgIn  >pessim !02_A	et	f	\N
186514	pessimis	?pessimis =pessimis  (SgN  >pessimis !11_S	et	f	\N
186515	üürituse	üürituse =üürituse  (SgG  >üüritus !11_S	et	f	\N
186516	üürituse	"üüritus %üüri  )TUS1_aS  <üürima ;28_V	et	f	\N
186517	üürituse	"üüritus %üüri  )TUS2_aS  <üür ;22_S	et	f	\N
186518	vastavat	vastavat =vasta  (KvtPrPs  >vastama !29_V	et	f	\N
186519	vastavat	vastavat =vastava  (SgP  >vastav !02_A	et	f	\N
186520	vastavat	"vastav %vasta  )V_vA  <vastama ;29_V	et	f	\N
186549	murdmaa	murdmaa =maa  (SgN  >murd+maa !26_S	et	f	\N
186550	murdmaa	murdmaa =maa  (SgG  >murd+maa !26_S	et	f	\N
186557	saaded	?saaded =saade  (IndPrSg2  >saadema !27_V	et	f	\N
186561	andropov	?andropov =andropov  (SgN  >andropov !02_A	et	f	\N
186564	komenteerima	?komenteerima =komenteeri  (Sup  >komenteerima !28_V	et	f	\N
186565	komenteerima	?komenteerima =komenteerima  (SgG  >komenteerim !02_A	et	f	\N
186566	komenteerima	?komenteerima =enteerima  (SgG  >kom+enteerim !02_A	et	f	\N
186567	erikal	?erikal =erika  (SgAd  >erika !01_S	et	f	\N
186568	erikal	?erikal =erika  (SgAd  >erikas !02_S	et	f	\N
186569	erikal	?erikal =erikal  (SgN  >erikal !19_S	et	f	\N
186576	balit	?balit =balit  (SgN  >balit !02_S	et	f	\N
186580	keelseteks	keelseteks =keelse  (PlTr  >keelne !02_A	et	f	\N
186581	keelseteks	keelseteks =sete  (PlTr  >keel+sett !22_S	et	f	\N
186584	asumisel	asumisel =asumise  (SgAd  >asumine !12_S	et	f	\N
186585	asumisel	"asumine %asu  )MINE_vS  <asuma ;27_V	et	f	\N
186586	asumisel	"asumine %asumi  )NE_aA  <asum ;02_S	et	f	\N
186601	hävinemisest	hävinemisest =hävinemise  (SgEl  >hävinemine !12_S	et	f	\N
186603	hävinemisest	"hävinemine %hävine  )MINE_vS  <hävinema ;27_V	et	f	\N
186619	letialune	letialune =alune  (SgN  >leti+alune !10_AS	et	f	\N
186620	letialune	"leti+alune %alu  )NE_aA  <leti+alg ;22_S	et	f	\N
186631	oskarit	?oskarit =oskari  (SgP  >oskari !01_S	et	f	\N
186632	oskarit	?oskarit =oskari  (SgP  >oskar !02_S	et	f	\N
186653	säilitamisest	säilitamisest =säilitamise  (SgEl  >säilitamine !12_S	et	f	\N
186654	säilitamisest	"säilitamine %säilita  )MINE_vS  <säilitama ;27_V	et	f	\N
186658	sakslanna	sakslanna =sakslanna  (SgN  >sakslanna !16_S	et	f	\N
186659	sakslanna	sakslanna =sakslanna  (SgG  >sakslanna !16_S	et	f	\N
186660	rikast	?rikast =rika  (SgEl  >rika !16_S	et	f	\N
186661	rikast	?rikast =rikas  (SgP  >rikas !07_A	et	f	\N
186662	rikast	?rikast =rikas  (SgP  >rikane !10_A	et	f	\N
186664	tuutorina	?tuutorina =tuutori  (SgEs  >tuutori !01_S	et	f	\N
186665	tuutorina	?tuutorina =tuutori  (SgEs  >tuutor !02_S	et	f	\N
186666	tuutorina	?tuutorina =tuutorina  (SgG  >tuutorin !19_S	et	f	\N
186667	tuutorina	?tuutorina =tuutorina  (SgP  >tuutorin !19_S	et	f	\N
186668	tuutorina	?tuutorina =tuutorina  (SgAdt  >tuutorin !19_S	et	f	\N
186680	fortepiano	?fortepiano =fortepiano  (SgN  >fortepiano !16_S	et	f	\N
186681	fortepiano	?fortepiano =fortepiano  (SgG  >fortepiano !16_S	et	f	\N
186706	ekstensiivselt	ekstensiivselt =ekstensiivse  (SgAbl  >ekstensiivne !02_A	et	f	\N
186707	ekstensiivselt	ekstensiivselt =ekstensiivselt  (ID  >ekstensiivselt !41_D	et	f	\N
186709	ekstensiivselt	"ekstensiivselt %ekstensiivse  )LT_mD  <ekstensiivne ;02_A	et	f	\N
186735	reostajaks	reostajaks =reostaja  (SgTr  >reostaja !01_S	et	f	\N
186736	reostajaks	"reostaja %reosta  )JA_vS  <reostama ;27_V	et	f	\N
186737	tootsid	tootsid =toot  (IndIpfSg2  >tootma !34_V	et	f	\N
186738	tootsid	tootsid =toot  (IndIpfPl3  >tootma !34_V	et	f	\N
186749	desidentmõtlemisega	?desidentmõtlemisega =desidentmõtlemise  (SgKom  >desidentmõtlemine !12_S	et	f	\N
186757	kõrbeoja	kõrbeoja =oja  (SgN  >kõrbe+oja !17_S	et	f	\N
186758	kõrbeoja	kõrbeoja =oja  (SgG  >kõrbe+oja !17_S	et	f	\N
186759	kõrbeoja	kõrbeoja =oja  (SgP  >kõrbe+oja !17_S	et	f	\N
186765	vahekorda	vahekorda =korda  (SgP  >vahe+kord !22_S	et	f	\N
186766	vahekorda	vahekorda =korda  (SgAdt  >vahe+kord !22_S	et	f	\N
186767	erinevatge	?erinevatge =erinevatge  (PlP  >erinevatg !22_S	et	f	\N
186770	kõigeopealt	?kõigeopealt =kõigeopea  (SgAbl  >kõigeopea !26_S	et	f	\N
186771	kõigeopealt	?kõigeopealt =kõigeopealt  (ID  >kõigeopealt !41_D	et	f	\N
186772	kõigeopealt	?kõigeopealt =opea  (SgAbl  >kõige+opea !26_S	et	f	\N
186810	näidimajandeid	?näidimajandeid =näidimajandei  (PlN  >näidimajandei !26_S	et	f	\N
186811	näidimajandeid	?näidimajandeid =näidimajandei  (SgP  >näidimajandei !26_S	et	f	\N
186812	tillukesed	tillukesed =tillukese  (PlN  >tilluke !12_A	et	f	\N
186813	tillukesed	"tilluke %tillu  )KE_dA  <tillu ;16_A	et	f	\N
186634	kaevandamine	"kaevandamine %kaevanda  )MINE_vS  <kaevandama ;27_V	et	f	\N
186655	jääkappi	jääkappi =appi  (SgAdt  >jääk+abi !17_S	et	f	\N
186656	jääkappi	jääkappi =kappi  (SgP  >jää+kapp !22_S	et	f	\N
186657	jääkappi	jääkappi =kappi  (SgAdt  >jää+kapp !22_S	et	f	\N
186675	oskariga	?oskariga =oskari  (SgKom  >oskari !01_S	et	f	\N
186676	oskariga	?oskariga =oskari  (SgKom  >oskar !02_S	et	f	\N
186682	tehaet	?tehaet =tehaet  (SgN  >tehaet !22_S	et	f	\N
186688	kartrused	?kartrused =kartruse  (PlN  >kartrus !11~09_S	et	f	\N
186693	finalli	?finalli =finalli  (SgN  >finalli !01_S	et	f	\N
186694	finalli	?finalli =finalli  (SgG  >finalli !01_S	et	f	\N
186695	finalli	?finalli =finalli  (SgG  >finall !22_S	et	f	\N
186696	finalli	?finalli =finalli  (SgP  >finall !22_S	et	f	\N
186697	finalli	?finalli =finalli  (SgAdt  >finall !22_S	et	f	\N
186698	finalli	?finalli =finalli  (IndPrPs_  >finallima !28_V	et	f	\N
186699	finalli	?finalli =finalli  (ImpPrSg2  >finallima !28_V	et	f	\N
186723	breznevi	?breznevi =breznevi  (ID  >breznevi !41_D	et	f	\N
186724	breznevi	?breznevi =breznevi  (SgG  >breznev !02_A	et	f	\N
186725	raiskav	raiskav =raiska  (PtsPrPs  >raiskama !29_V	et	f	\N
186726	raiskav	raiskav =raiskav  (SgN  >raiskav !02_A	et	f	\N
186727	raiskav	"raiskav %raiska  )V_vA  <raiskama ;29_V	et	f	\N
186742	loodushoiust	loodushoiust =hoiu  (SgEl  >loodus+hoid !22_S	et	f	\N
186743	loodushoiust	loodushoiust =hoius  (SgP  >loodus+hoius !09_S	et	f	\N
186752	filmistatud	?filmistatud =filmista  (PtsPtIps  >filmistama !27_V	et	f	\N
186753	filmistatud	?filmistatud =filmistatu  (PlN  >filmistatu !01_S	et	f	\N
186754	filmistatud	?filmistatud =filmistatu  (IndPrSg2  >filmistatuma !27_V	et	f	\N
186755	filmistatud	?filmistatud =filmistatud  (ID  >filmistatud !41_A	et	f	\N
186756	filmistatud	?filmistatud =statu  (PlN  >filmi+statu !16_S	et	f	\N
186775	tõmbunud	tõmbunud =tõmbu  (PtsPtPs  >tõmbuma !27_V	et	f	\N
186776	tõmbunud	tõmbunud =tõmbunu  (PlN  >tõmbunu !01_S	et	f	\N
186777	tõmbunud	"tõmbunu %tõmbu  )NU_vS  <tõmbuma ;27_V	et	f	\N
186778	tõmbunud	tõmbunud =tõmbunud  (ID  >tõmbunud !41_A	et	f	\N
186779	tõmbunud	"tõmbunud %tõmbu  )NUD_vA  <tõmbuma ;27_V	et	f	\N
186795	hävitamisest	hävitamisest =hävitamise  (SgEl  >hävitamine !12_S	et	f	\N
186796	hävitamisest	"hävitamine %hävita  )MINE_vS  <hävitama ;27_V	et	f	\N
186800	carson	?carson =carson  (SgN  >carson !02_S	et	f	\N
186816	müüdud	müüdud =müü  (PtsPtIps  >müüma !38_V	et	f	\N
186817	müüdud	müüdud =müüdu  (PlN  >müüdu !01_S	et	f	\N
186818	müüdud	"müüdu %müü  )TU1_vS  <müüma ;38_V	et	f	\N
186819	müüdud	müüdud =müüdud  (ID  >müüdud !41_A	et	f	\N
186820	müüdud	"müüdud %müü  )TUD_vA  <müüma ;38_V	et	f	\N
186849	mõistust	mõistust =mõistu  (SgEl  >mõist !22_S	et	f	\N
186850	mõistust	mõistust =mõistus  (SgP  >mõistus !11~09_S	et	f	\N
186863	ekoloogilisi	?ekoloogilisi =ekoloogilisi  (PlP  >ekoloogiline !12_A	et	f	\N
186875	märksamaks	?märksamaks =märksa  (SupTr  >märksama !29_V	et	f	\N
186876	märksamaks	?märksamaks =märksama  (SgTr  >märksam !02_A	et	f	\N
186885	kaevandamise	kaevandamise =kaevandamise  (SgG  >kaevandamine !12_S	et	f	\N
186886	kaevandamise	"kaevandamine %kaevanda  )MINE_vS  <kaevandama ;27_V	et	f	\N
186887	vähenemist	vähenemist =vähenemis  (SgP  >vähenemine !12_S	et	f	\N
186888	vähenemist	"vähenemine %vähene  )MINE_vS  <vähenema ;27_V	et	f	\N
186908	keved	?keved =keve  (PlN  >keve !16_S	et	f	\N
186909	keved	?keved =keve  (IndPrSg2  >kevema !27_V	et	f	\N
186925	püüdliketele	?püüdliketele =püüdlikete  (PlAll  >püüdlikett !22_S	et	f	\N
186926	püüdliketele	?püüdliketele =püüdliketele  (IndPrPs_  >püüdliketelema !36_V	et	f	\N
186927	püüdliketele	?püüdliketele =püüdliketele  (ImpPrSg2  >püüdliketelema !36_V	et	f	\N
186948	venestumis	?venestumis =venestumi  (SgIn  >venestum !02_A	et	f	\N
186949	venestumis	?venestumis =venestumis  (SgN  >venestumis !09_S	et	f	\N
186950	venestumis	?venestumis =stumi  (SgIn  >vene+stumi !17_S	et	f	\N
186951	venestumis	?venestumis =stumis  (SgN  >vene+stumis !09_S	et	f	\N
186954	rikadest	?rikadest =rika  (PlEl  >rika !16_S	et	f	\N
186955	rikadest	?rikadest =rikades  (SgP  >rikadene !12_A	et	f	\N
186956	vaesematest	vaesematest =vaesema  (PlEl  >vaesem !02_A	et	f	\N
186957	vaesematest	"vaesem %vae  )SEM_cA  <vaag ;22_S	et	f	\N
186958	vaesematest	"vaesem %vaese  )M_cA  <vaene ;10_AS	et	f	\N
186959	vaesematest	vaesematest =test  (SgN  >vaes+ema+test !22_S	et	f	\N
186960	vaesematest	vaesematest =mate  (SgEl  >vaese+mate !16_S	et	f	\N
186961	vaesematest	vaesematest =mate  (PlEl  >vaese+matt !22_SA	et	f	\N
186962	vaesematest	vaesematest =mates  (SgP  >vaese+matene !10_A	et	f	\N
186963	vaesematest	"vaese+matene %mate  )NE_aA  <vaese+mate ;16_S	et	f	\N
186964	põletatud	põletatud =põleta  (PtsPtIps  >põletama !27_V	et	f	\N
186965	põletatud	põletatud =põletatu  (PlN  >põletatu !01_S	et	f	\N
186966	põletatud	"põletatu %põleta  )TU1_vS  <põletama ;27_V	et	f	\N
186967	põletatud	põletatud =põletatud  (ID  >põletatud !41_A	et	f	\N
186968	põletatud	"põletatud %põleta  )TUD_vA  <põletama ;27_V	et	f	\N
186969	realismjätis	?realismjätis =realismjäti  (SgIn  >realismjätt !22_S	et	f	\N
186637	ökoloogilised	ökoloogilised =ökoloogilise  (PlN  >ökoloogiline !12_A	et	f	\N
186638	ökoloogilised	"ökoloogiline %ökoloogi  )LINE_aA  <ökoloog ;22_S	et	f	\N
186639	ökoloogilised	ökoloogilised =loogilise  (PlN  >öko+loogiline !12_A	et	f	\N
186640	ökoloogilised	"öko+loogiline %loogi  )LINE_aA  <öko+loog ;22_S	et	f	\N
186641	saakd	?saakd =saakd  (SgN  >saakd !22_S	et	f	\N
186642	kaendatud	?kaendatud =kaenda  (PtsPtIps  >kaendama !27_V	et	f	\N
186643	kaendatud	?kaendatud =kaenda  (PtsPtIps  >kaentama !29_V	et	f	\N
186644	kaendatud	?kaendatud =kaendatu  (PlN  >kaendatu !01_S	et	f	\N
186645	kaendatud	?kaendatud =kaendatu  (IndPrSg2  >kaendatuma !27_V	et	f	\N
186646	kaendatud	?kaendatud =kaendatud  (ID  >kaendatud !41_A	et	f	\N
186649	emmigreerisid	?emmigreerisid =emmigreeri  (PlP  >emmigreeri !16_S	et	f	\N
186650	emmigreerisid	?emmigreerisid =emmigreeri  (PlP  >emmigreer !22_S	et	f	\N
186651	emmigreerisid	?emmigreerisid =emmigreeri  (IndIpfSg2  >emmigreerima !28_V	et	f	\N
186652	emmigreerisid	?emmigreerisid =emmigreeri  (IndIpfPl3  >emmigreerima !28_V	et	f	\N
186663	põhjendattud	?põhjendattud =põhjendattu  (IndPrSg2  >põhjendattuma !27_V	et	f	\N
186689	rahulolematus	rahulolematus =olematu  (SgIn  >rahul+olematu !01_A	et	f	\N
186690	rahulolematus	"rahul+olematu %olema  )TU2_kA  <rahul+olem ;02_S	et	f	\N
186691	rahulolematus	rahulolematus =olematus  (SgN  >rahul+olematus !11?09_S	et	f	\N
186692	rahulolematus	"rahul+olematus %olema  )TUS2_aS  <rahul+olem ;02_S	et	f	\N
186721	valitsemisajajärku	valitsemisajajärku =järku  (SgP  >valitsemis+aja+järk !22_S	et	f	\N
186722	valitsemisajajärku	valitsemisajajärku =järku  (SgAdt  >valitsemis+aja+järk !22_S	et	f	\N
186740	rahvusvahelise	rahvusvahelise =vahelise  (SgG  >rahvus+vaheline !12_A	et	f	\N
186741	rahvusvahelise	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
186746	kaldest	kaldest =kalde  (SgEl  >kalle !06_S	et	f	\N
186747	kaldest	kaldest =kaldes  (SgP  >kaldene !12~10_A	et	f	\N
186748	kaldest	"kaldene %kalde  )NE_aA  <kalle ;06_S	et	f	\N
186760	romaad	?romaad =romaa  (PlN  >romaa !26_S	et	f	\N
186761	romaad	?romaad =romaa  (SgP  >romaa !26_S	et	f	\N
186762	romaad	?romaad =romaad  (SgN  >romaad !22_S	et	f	\N
186763	armastava	armastava =armastava  (SgG  >armastav !02_A	et	f	\N
186764	armastava	"armastav %armasta  )V_vA  <armastama ;27_V	et	f	\N
186780	lahenda	lahenda =lahenda  (IndPrPs_  >lahendama !27_V	et	f	\N
186781	lahenda	lahenda =lahenda  (ImpPrSg2  >lahendama !27_V	et	f	\N
186782	põlevkivi-kaevandused	põlevkivi-kaevandused =kaevanduse  (PlN  >põlevkivi-kaevandus !11_S	et	f	\N
186783	põlevkivi-kaevandused	"põlevkivi-kaevandus %kaevanda  )US_vS  <põlevkivi-kaevandama ;27_V	et	f	\N
186786	põhad	?põhad =põha  (PlN  >põha !17_S	et	f	\N
186787	põhad	?põhad =põha  (IndPrSg2  >põhama !27_V	et	f	\N
186801	hääletu	hääletu =hääletu  (SgN  >hääletu !01_A	et	f	\N
186802	hääletu	"hääletu %hääle  )TU2_kA  <hääl ;13_S	et	f	\N
186803	hääletu	hääletu =hääletu  (SgG  >hääletu !01_A	et	f	\N
186804	looduhoidu	?looduhoidu =looduhoidu  (IndPrPs_  >looduhoiduma !27_V	et	f	\N
186805	looduhoidu	?looduhoidu =looduhoidu  (ImpPrSg2  >looduhoiduma !27_V	et	f	\N
186806	looduhoidu	?looduhoidu =duhoidu  (SgN  >loo+duhoidu !01_S	et	f	\N
186807	looduhoidu	?looduhoidu =duhoidu  (SgG  >loo+duhoidu !01_S	et	f	\N
186821	saadavat	saadavat =saa  (KvtPrIps  >saama !37_V	et	f	\N
186822	saadavat	saadavat =saadava  (SgP  >saadav !02_A	et	f	\N
186823	saadavat	"saadav %saa  )TAV_vAS  <saama ;37_V	et	f	\N
186838	soodsad	soodsad =soodsa  (PlN  >soodus !02_A	et	f	\N
186839	soodsad	soodsad =soodsa  (PlN  >soodne !02_A	et	f	\N
186868	nappardumist	?nappardumist =nappardumi  (SgEl  >nappardum !02_A	et	f	\N
186872	nappardumist	?nappardumist =nappardumis  (SgP  >nappardumis !09_S	et	f	\N
186873	nappardumist	?nappardumist =nappardumis  (SgP  >nappardumine !12_S	et	f	\N
186874	nappardumist	?nappardumist =nappardumist  (SgN  >nappardumist !22_S	et	f	\N
186892	protestid	protestid =protesti  (PlN  >protest !22_S	et	f	\N
186893	protestid	protestid =protesti  (IndPrSg2  >protestima !28_V	et	f	\N
186905	vajaline	vajaline =vajaline  (SgN  >vajaline !12_A	et	f	\N
186906	vajaline	"vajaline %vaja  )LINE_aA  <vaja ;17_S	et	f	\N
186913	arendadi	### arendadi	et	f	\N
186936	igatepidi	?igatepidi =epidi  (SgN  >igat+epidi !01_S	et	f	\N
186937	igatepidi	?igatepidi =epidi  (SgG  >igat+epidi !01_S	et	f	\N
186938	igatepidi	?igatepidi =tepidi  (SgN  >iga+tepidi !01_S	et	f	\N
186939	igatepidi	?igatepidi =tepidi  (SgG  >iga+tepidi !01_S	et	f	\N
186940	teatred	?teatred =teatre  (PlN  >teatre !06_S	et	f	\N
186941	teatred	?teatred =teatre  (IndPrSg2  >teatrema !27_V	et	f	\N
186947	väljaanned	### väljaanned	et	f	\N
186952	endistest	endistest =endis  (PlEl  >endine !10~12_A	et	f	\N
186953	endistest	endistest =test  (SgN  >endis+test !22_S	et	f	\N
186988	prostitutsiooni	prostitutsiooni =prostitutsiooni  (SgG  >prostitutsioon !22_S	et	f	\N
186989	prostitutsiooni	prostitutsiooni =prostitutsiooni  (SgP  >prostitutsioon !22_S	et	f	\N
186990	prostitutsiooni	prostitutsiooni =prostitutsiooni  (SgAdt  >prostitutsioon !22_S	et	f	\N
187004	mälk	?mälk =mälk  (SgN  >mälk !22_S	et	f	\N
187005	jstalini	?jstalini =jstali  (SgTer  >jstali !17_S	et	f	\N
187006	jstalini	?jstalini =jstalini  (SgG  >jstalin !02_S	et	f	\N
186733	halvenemise	"halvenemine %halvene  )MINE_vS  <halvenema ;27_V	et	f	\N
186734	oeamiseks	?oeamiseks =oeamise  (SgTr  >oeamine !10_A	et	f	\N
186744	ükskõiksuse	ükskõiksuse =kõiksuse  (SgG  >üks+kõiksus !11~09_S	et	f	\N
186745	ükskõiksuse	"üks+kõiksus %kõikse  )US_aS  <üks+kõikne ;02_A	et	f	\N
186773	erikat	?erikat =erika  (SgP  >erika !01_S	et	f	\N
186774	erikat	?erikat =erika  (SgP  >erikas !02_S	et	f	\N
186788	põha	?põha =põha  (SgN  >põha !17_S	et	f	\N
186789	põha	?põha =põha  (SgG  >põha !17_S	et	f	\N
186790	põha	?põha =põha  (SgP  >põha !17_S	et	f	\N
186791	põha	?põha =põha  (IndPrPs_  >põhama !27_V	et	f	\N
186792	põha	?põha =põha  (ImpPrSg2  >põhama !27_V	et	f	\N
186793	kaevati	kaevati =kaeva  (IndIpfIps  >kaebama !29_V	et	f	\N
186794	kaevati	kaevati =kaeva  (IndIpfIps  >kaevama !29_V	et	f	\N
186797	pühast	pühast =püha  (SgEl  >püha !17_SA	et	f	\N
186798	pühast	pühast =pühas  (SgP  >pühane !10_A	et	f	\N
186799	pühast	"pühane %püha  )NE_aA  <püha ;17_SA	et	f	\N
186808	allkakohad	?allkakohad =allkakoha  (PlN  >allkakoha !16_S	et	f	\N
186809	allkakohad	?allkakohad =kakoha  (PlN  >all+kakoha !01_S	et	f	\N
186833	kõikke	?kõikke =kõikke  (SgN  >kõikke !06_S	et	f	\N
186834	kõikke	?kõikke =kõikke  (SgG  >kõikke !06_S	et	f	\N
186835	kõikke	?kõikke =kõikke  (PlP  >kõikk !22_S	et	f	\N
186836	kõikke	?kõikke =kõikke  (IndPrPs_  >kõikkema !27_V	et	f	\N
186837	kõikke	?kõikke =kõikke  (ImpPrSg2  >kõikkema !27_V	et	f	\N
186842	iseloomulikult	iseloomulikult =loomuliku  (SgAbl  >ise+loomulik !25_A	et	f	\N
186843	iseloomulikult	"ise+loomulikult %loomuliku  )LT_mD  <ise+loomulik ;25_A	et	f	\N
186844	isiklikku	isiklikku =isiklikku  (SgP  >isiklik !25_A	et	f	\N
186845	isiklikku	isiklikku =isiklikku  (SgAdt  >isiklik !25_A	et	f	\N
186846	ustav	ustav =us  (PtsPrIps  >uskuma !28_V	et	f	\N
186847	ustav	ustav =ustav  (SgN  >ustav !02_A	et	f	\N
186848	ustav	"ustav %us  )TAV_vAS  <uskuma ;28_V	et	f	\N
186855	ristmikule	ristmikule =ristmiku  (SgAll  >ristmik !25_S	et	f	\N
186856	ristmikule	ristmikule =miku  (SgAll  >rist+mikk !22_S	et	f	\N
186862	leningradi	### leningradi	et	f	\N
186879	rikkumisele	rikkumisele =rikkumise  (SgAll  >rikkumine !12_S	et	f	\N
186880	rikkumisele	"rikkumine %rikku  )MINE_vS  <rikkuma ;28_V	et	f	\N
186920	tegelevatele	tegelevatele =tegeleva  (PlAll  >tegelev !02_A	et	f	\N
186921	tegelevatele	"tegelev %tegele  )V_vA  <tegelema ;27_V	et	f	\N
186922	tegelevatele	"tegelev %tegele  )V_vA  <tegelema ;31_V	et	f	\N
186978	tunnistatut	tunnistatut =tunnistatu  (SgP  >tunnistatu !01_S	et	f	\N
186979	tunnistatut	"tunnistatu %tunnista  )TU1_vS  <tunnistama ;27_V	et	f	\N
187017	humanitaarharu	humanitaarharu =haru  (SgN  >humanitaar+haru !17_S	et	f	\N
187018	humanitaarharu	humanitaarharu =haru  (SgG  >humanitaar+haru !17_S	et	f	\N
187019	humanitaarharu	humanitaarharu =haru  (SgP  >humanitaar+haru !17_S	et	f	\N
187039	kõrgemast	kõrgemast =kõrgema  (SgEl  >kõrgem !02_A	et	f	\N
187040	kõrgemast	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
187041	kõrgemast	kõrgemast =mast  (SgN  >kõrge+mast !22_S	et	f	\N
187042	kõrgemast	kõrgemast =ema  (SgEl  >kõrg+ema !17_S	et	f	\N
187043	kõrgemast	kõrgemast =emas  (SgP  >kõrg+emane !10_AS	et	f	\N
187044	kõrgemast	"kõrg+emane %ema  )NE_aA  <kõrg+ema ;17_S	et	f	\N
187049	hävitamisele	hävitamisele =hävitamise  (SgAll  >hävitamine !12_S	et	f	\N
187050	hävitamisele	"hävitamine %hävita  )MINE_vS  <hävitama ;27_V	et	f	\N
187057	jpm	### jpm	et	f	\N
187078	vaidlesid	vaidlesid =vaidle  (IndIpfSg2  >vaidlema !30_V	et	f	\N
187079	vaidlesid	vaidlesid =vaidle  (IndIpfPl3  >vaidlema !30_V	et	f	\N
187087	elustiili	elustiili =stiili  (SgG  >elu+stiil !22_S	et	f	\N
187088	elustiili	elustiili =stiili  (SgP  >elu+stiil !22_S	et	f	\N
187089	elustiili	elustiili =stiili  (SgAdt  >elu+stiil !22_S	et	f	\N
187092	prop	### prop	et	f	\N
187099	harrastustega	harrastustega =harrastus  (PlKom  >harrastus !11_S	et	f	\N
187100	harrastustega	"harrastus %harrasta  )US_vS  <harrastama ;27_V	et	f	\N
187105	edukamad	edukamad =edukama  (PlN  >edukam !02_A	et	f	\N
187106	edukamad	"edukam %eduka  )M_cA  <edukas ;02_A	et	f	\N
187107	edukamad	edukamad =kama  (PlN  >edu+kama !17_S	et	f	\N
187120	asemetele	asemetele =aseme  (PlAll  >ase !04_S	et	f	\N
187121	asemetele	asemetele =me  (PlAll  >ase+mesi !15_S	et	f	\N
187122	asemetele	asemetele =mete  (PlAll  >ase+mett !22_S	et	f	\N
187123	nimetat	### nimetat	et	f	\N
187124	võimuürganid	?võimuürganid =võimuürgani  (PlN  >võimuürgan !19_S	et	f	\N
187125	võimuürganid	?võimuürganid =ani  (PlN  >võimu+ürg+ani !17_S	et	f	\N
187126	võimuürganid	?võimuürganid =ürgani  (PlN  >võimu+ürgan !02_S	et	f	\N
187127	võimuürganid	?võimuürganid =muürgani  (PlN  >või+muürgan !02_S	et	f	\N
187176	riigisümboolika	riigisümboolika =sümboolika  (SgN  >riigi+sümboolika !01_S	et	f	\N
187177	riigisümboolika	riigisümboolika =sümboolika  (SgG  >riigi+sümboolika !01_S	et	f	\N
187200	sotsialostlik	?sotsialostlik =sotsialostlik  (SgN  >sotsialostlik !25_A	et	f	\N
187201	sep	### sep	et	f	\N
187247	xviii-xix	### xviii-xix	et	f	\N
187253	veena	veena =vee  (SgEs  >vesi !15_S	et	f	\N
186751	ääremaadele	ääremaadele =maade  (PlAll  >ääre+maat !22_S	et	f	\N
186768	identiteediga	?identiteediga =identiteedi  (SgKom  >identiteedi !16_S	et	f	\N
186769	identiteediga	?identiteediga =identiteedi  (SgKom  >identiteet !22_S	et	f	\N
186784	põliselanikkel	?põliselanikkel =põliselanikkel  (SgN  >põliselanikkel !02_S	et	f	\N
186785	põliselanikkel	?põliselanikkel =elanikkel  (SgN  >põlis+elanikkel !02_S	et	f	\N
186824	arvestatav	arvestatav =arvesta  (PtsPrIps  >arvestama !27_V	et	f	\N
186825	arvestatav	arvestatav =arvestatav  (SgN  >arvestatav !02_A	et	f	\N
186826	arvestatav	"arvestatav %arvesta  )TAV_vAS  <arvestama ;27_V	et	f	\N
186840	ringid	ringid =ringi  (PlN  >ring !22_S	et	f	\N
186841	ringid	ringid =ringi  (IndPrSg2  >ringima !28_V	et	f	\N
186851	peeta	peeta =pee  (IndPrIps_  >pidama !28_V	et	f	\N
186852	peeta	peeta =pee  (SgAb  >pee !26_S	et	f	\N
186853	peeta	peeta =peeta  (IndPrPs_  >peetama !27_V	et	f	\N
186854	peeta	peeta =peeta  (ImpPrSg2  >peetama !27_V	et	f	\N
186859	tasakaalu	tasakaalu =kaalu  (SgG  >tasa+kaal !22_S	et	f	\N
186860	tasakaalu	tasakaalu =kaalu  (SgP  >tasa+kaal !22_S	et	f	\N
186861	tasakaalu	tasakaalu =kaalu  (SgAdt  >tasa+kaal !22_S	et	f	\N
186881	fosforiiti	fosforiiti =fosforiiti  (SgP  >fosforiit !22_S	et	f	\N
186882	fosforiiti	fosforiiti =fosforiiti  (SgAdt  >fosforiit !22_S	et	f	\N
186889	mõustus	?mõustus =mõustu  (SgIn  >mõustu !01_S	et	f	\N
186890	mõustus	?mõustus =mõustu  (IndIpfSg3  >mõustuma !27_V	et	f	\N
186891	mõustus	?mõustus =mõustus  (SgN  >mõustus !11~09_S	et	f	\N
186895	hakatikasvatama	?hakatikasvatama =hakatikasvata  (Sup  >hakatikasvatama !27_V	et	f	\N
186896	hakatikasvatama	?hakatikasvatama =hakatikasvatama  (SgG  >hakatikasvatam !02_A	et	f	\N
186897	saasta	saasta =saasta  (SgG  >saast !22_S	et	f	\N
186898	saasta	saasta =saasta  (SgP  >saast !22_S	et	f	\N
186899	saasta	saasta =saasta  (SgAdt  >saast !22_S	et	f	\N
186900	saasta	saasta =saasta  (IndPrPs_  >saastama !29~27_V	et	f	\N
186901	saasta	saasta =saasta  (ImpPrSg2  >saastama !29~27_V	et	f	\N
186910	omapäraseks	omapäraseks =seks  (SgN  >oma+pära+seks !22_S	et	f	\N
186911	omapäraseks	omapäraseks =pärase  (SgTr  >oma+pärane !10_A	et	f	\N
186912	omapäraseks	"oma+pärane %pära  )NE_aA  <oma+pära ;17_S	et	f	\N
186914	3haruline	haruline =haruline  (SgN  >haruline !12_A	et	f	\N
186915	3haruline	"haruline %haru  )LINE_aA  <haru ;17_S	et	f	\N
186923	tegutsemiseks	tegutsemiseks =tegutsemise  (SgTr  >tegutsemine !12_S	et	f	\N
186924	tegutsemiseks	"tegutsemine %tegutse  )MINE_vS  <tegutsema ;27_V	et	f	\N
186944	pisirahvastel	pisirahvastel =rahvas  (PlAd  >pisi+rahvas !07_S	et	f	\N
186945	pisirahvastel	pisirahvastel =rahvas  (PlAd  >pisi+rahvane !10_A	et	f	\N
186946	pisirahvastel	"pisi+rahvane %rahva  )NE_aA  <pisi+rahvas ;07_S	et	f	\N
186991	riigilõivu	riigilõivu =lõivu  (SgG  >riigi+lõiv !22_S	et	f	\N
186992	riigilõivu	riigilõivu =lõivu  (SgP  >riigi+lõiv !22_S	et	f	\N
186993	riigilõivu	riigilõivu =lõivu  (SgAdt  >riigi+lõiv !22_S	et	f	\N
186994	sihtkapitalideks	sihtkapitalideks =tali  (PlTr  >siht+kapi+tali !17_S	et	f	\N
186995	sihtkapitalideks	sihtkapitalideks =kapitali  (PlTr  >siht+kapital !19_S	et	f	\N
187007	hävitamise	hävitamise =hävitamise  (SgG  >hävitamine !12_S	et	f	\N
187008	hävitamise	"hävitamine %hävita  )MINE_vS  <hävitama ;27_V	et	f	\N
187033	ülikoolini	ülikoolini =ini  (SgN  >üli+kool+ini !17_S	et	f	\N
187034	ülikoolini	ülikoolini =ini  (SgG  >üli+kool+ini !17_S	et	f	\N
187035	ülikoolini	ülikoolini =ini  (SgP  >üli+kool+ini !17_S	et	f	\N
187036	ülikoolini	ülikoolini =kooli  (SgTer  >üli+kool !22_S	et	f	\N
187045	andvad	andvad =andva  (PlN  >andev !02_A	et	f	\N
187046	andvad	"andev %and  )V_vA  <andma ;34_V	et	f	\N
187060	linnastus	linnastus =linnastu  (SgIn  >linnastu !01_S	et	f	\N
187061	linnastus	linnastus =linnastu  (IndIpfSg3  >linnastuma !27_V	et	f	\N
187062	linnastus	linnastus =linnastus  (SgN  >linnastus !11_S	et	f	\N
187063	linnastus	"linnastus %linnasta  )US_vS  <linnastama ;27_V	et	f	\N
187068	finanseerimine	?finanseerimine =finanseerimine  (SgN  >finanseerimine !12_S	et	f	\N
187069	finanseerimine	?finanseerimine =finanseerimine  (PlP  >finanseerimin !19_S	et	f	\N
187084	utoopiliselt	utoopiliselt =utoopilise  (SgAbl  >utoopiline !12_A	et	f	\N
187085	utoopiliselt	utoopiliselt =utoopiliselt  (ID  >utoopiliselt !41_D	et	f	\N
187086	utoopiliselt	"utoopiliselt %utoopilise  )LT_mD  <utoopiline ;12_A	et	f	\N
187090	miinustest	miinustest =miinus  (PlEl  >miinus !09_S	et	f	\N
187091	miinustest	miinustest =test  (SgN  >miinus+test !22_S	et	f	\N
187101	amakorda	?amakorda =amakorda  (SgN  >amakorda !16_S	et	f	\N
187102	amakorda	?amakorda =amakorda  (SgG  >amakorda !16_S	et	f	\N
187103	amakorda	?amakorda =amakorda  (IndPrPs_  >amakordama !27_V	et	f	\N
187104	amakorda	?amakorda =amakorda  (ImpPrSg2  >amakordama !27_V	et	f	\N
187108	makstus	makstus =makstu  (SgIn  >makstu !01_S	et	f	\N
187109	makstus	"makstu %maks  )TU1_vS  <maksma ;32_V	et	f	\N
187110	makstus	makstus =makstus  (SgN  >makstus !11~09_S	et	f	\N
187111	makstus	"makstus %maks  )TUS1_aS  <maksma ;32_V	et	f	\N
187114	asjaajamiskeel	asjaajamiskeel =kee  (SgAd  >asja+aja+mis+kesi !15_S	et	f	\N
187115	asjaajamiskeel	asjaajamiskeel =kee  (SgAd  >asja+aja+mis+kee !26_S	et	f	\N
186814	tillukesed	tillukesed =tillukese  (PlN  >tillukene !12_A	et	f	\N
186815	tillukesed	"tillukene %tillu  )KENE_dA  <tillu ;16_A	et	f	\N
186827	keskonnas	?keskonnas =keskonna  (SgIn  >keskonna !16_S	et	f	\N
186828	keskonnas	?keskonnas =keskonna  (SgIn  >keskond !22_S	et	f	\N
186829	keskonnas	?keskonnas =onna  (SgIn  >kesk+onna !16_S	et	f	\N
186830	keskonnas	?keskonnas =onnas  (SgN  >kesk+onnas !07_S	et	f	\N
186831	küllalti	?küllalti =küllalti  (SgN  >küllalti !01_S	et	f	\N
186832	küllalti	?küllalti =küllalti  (SgG  >küllalti !01_S	et	f	\N
186857	ekoloogia	?ekoloogia =ekoloogia  (SgN  >ekoloogia !01_S	et	f	\N
186858	ekoloogia	?ekoloogia =ekoloogia  (SgG  >ekoloogia !01_S	et	f	\N
186864	kruusi	kruusi =kruusi  (SgG  >kruus !22_S	et	f	\N
186865	kruusi	kruusi =kruusi  (SgP  >kruus !22_S	et	f	\N
186866	kruusi	kruusi =kruusi  (SgAdt  >kruus !22_S	et	f	\N
186867	kruusi	kruusi =kruusi  (PlP  >kruus !22_S	et	f	\N
186869	mõtlematule	mõtlematule =mõtlematu  (SgAll  >mõtlematu !01_A	et	f	\N
186870	mõtlematule	"mõtlematu %mõtle  )MATU_vA  <mõtlema ;30_V	et	f	\N
186871	mõtlematule	mõtlematule =tule  (SgG  >mõtlema+tuli !20_S	et	f	\N
186877	näteks	?näteks =näte  (PlTr  >nätt !22_S	et	f	\N
186878	näteks	?näteks =näte  (KndPrPs  >nätema !27_V	et	f	\N
186883	aktiviseerumisele	aktiviseerumisele =aktiviseerumise  (SgAll  >aktiviseerumine !12_S	et	f	\N
186884	aktiviseerumisele	"aktiviseerumine %aktiviseeru  )MINE_vS  <aktiviseeruma ;27_V	et	f	\N
186894	agressivset	?agressivset =agressivse  (SgP  >agressivne !02_A	et	f	\N
186902	liha-	liha- =liha  (SgN  >liha !17_S	et	f	\N
186903	liha-	liha- =liha  (SgG  >liha !17_S	et	f	\N
186904	liha-	liha- =liha  (SgP  >liha !17_S	et	f	\N
186907	tegemeseks	?tegemeseks =tegemese  (SgTr  >tegemene !12_A	et	f	\N
186916	loodut	loodut =loodu  (SgP  >loodu !01_S	et	f	\N
186917	loodut	"loodu %loo  )TU1_vS  <looma ;38_V	et	f	\N
186918	arenemisel	arenemisel =arenemise  (SgAd  >arenemine !12_S	et	f	\N
186919	arenemisel	"arenemine %arene  )MINE_vS  <arenema ;27_V	et	f	\N
186928	preemijaid	?preemijaid =preemija  (PlP  >preemija !01_S	et	f	\N
186929	preemijaid	?preemijaid =preemija  (PlP  >preemijas !02_A	et	f	\N
186930	preemijaid	?preemijaid =preemijai  (PlN  >preemijai !26_S	et	f	\N
186931	preemijaid	?preemijaid =preemijai  (SgP  >preemijai !26_S	et	f	\N
186932	preemijaid	?preemijaid =emija  (PlP  >pre+emija !01_S	et	f	\N
186933	preemijaid	?preemijaid =emija  (PlP  >pre+emijas !02_A	et	f	\N
186934	preemijaid	?preemijaid =emijai  (PlN  >pre+emijai !26_S	et	f	\N
186935	preemijaid	?preemijaid =emijai  (SgP  >pre+emijai !26_S	et	f	\N
186942	püüdi	püüdi =püüdi  (SgP  >püüd !22_S	et	f	\N
186943	püüdi	püüdi =püüdi  (SgAdt  >püüd !22_S	et	f	\N
186980	vähemaltki	vähemaltki =vähema  (SgAbl^  >vähem !02_A	et	f	\N
186981	vähemaltki	"vähem %vähe  )M_cA^  <väike ;10_A	et	f	\N
186982	vähemaltki	vähemaltki =vähemalt  (ID^  >vähemalt !41_D	et	f	\N
186983	vähemaltki	"vähemalt %vähema  )LT_mD^  <vähem ;02_A	et	f	\N
186984	vähemaltki	vähemaltki =alt  (SgN^  >vähem+alt !22_S	et	f	\N
187001	saajaks	saajaks =saaja  (SgTr  >saaja !01_S	et	f	\N
187002	saajaks	"saaja %saa  )JA_vS  <saama ;37_V	et	f	\N
187003	saajaks	saajaks =saaja  (SgTr  >sae !24_S	et	f	\N
187009	vaesusest	vaesusest =vaesuse  (SgEl  >vaesus !11~09_S	et	f	\N
187010	vaesusest	"vaesus %vae  )SUS_aS  <vaag ;22_S	et	f	\N
187011	vaesusest	vaesusest =vaesuses  (SgP  >vaesusene !12_A	et	f	\N
187012	vaesusest	"vaesusene %vaesuse  )NE_aA  <vaesus ;09_S	et	f	\N
187013	vaesusest	"vaesusene %vaesuse  )NE_aA  <vaesus ;11_S	et	f	\N
187014	vaesusest	vaesusest =use  (PlEl  >vaes+usk !22_S	et	f	\N
187020	kommertsharu	kommertsharu =haru  (SgN  >kommerts+haru !17_S	et	f	\N
187021	kommertsharu	kommertsharu =haru  (SgG  >kommerts+haru !17_S	et	f	\N
187022	kommertsharu	kommertsharu =haru  (SgP  >kommerts+haru !17_S	et	f	\N
187047	vastukultuurautonoomia	vastukultuurautonoomia =autonoomia  (SgN  >vastu+kultuur+autonoomia !01_S	et	f	\N
187048	vastukultuurautonoomia	vastukultuurautonoomia =autonoomia  (SgG  >vastu+kultuur+autonoomia !01_S	et	f	\N
187064	toimos	?toimos =toimo  (SgIn  >toimo !16_S	et	f	\N
187065	toimos	?toimos =toimos  (SgN  >toimos !11~09_S	et	f	\N
187066	urbaniseerumisega	urbaniseerumisega =urbaniseerumise  (SgKom  >urbaniseerumine !12_S	et	f	\N
187067	urbaniseerumisega	"urbaniseerumine %urbaniseeru  )MINE_vS  <urbaniseeruma ;27_V	et	f	\N
187070	taastamisega	taastamisega =taastamise  (SgKom  >taastamine !12_S	et	f	\N
187071	taastamisega	"taastamine %taasta  )MINE_vS  <taastama ;27_V	et	f	\N
187112	sohvoos	?sohvoos =sohvoo  (SgIn  >sohvoo !26_S	et	f	\N
187113	sohvoos	?sohvoos =sohvoos  (SgN  >sohvoos !22_S	et	f	\N
187141	allver	?allver =allver  (SgN  >allver !02_S	et	f	\N
187155	vallatamie	?vallatamie =vallatamie  (SgN  >vallatamie !01_S	et	f	\N
187156	vallatamie	?vallatamie =vallatamie  (SgG  >vallatamie !01_S	et	f	\N
187157	vallatamie	?vallatamie =tamie  (SgN  >valla+tamie !01_S	et	f	\N
187158	vallatamie	?vallatamie =tamie  (SgG  >valla+tamie !01_S	et	f	\N
187159	mehilas	?mehilas =mehila  (SgIn  >mehila !01_S	et	f	\N
187170	kõrgkoole	kõrgkoole =koo  (SgAll  >kõrg+kubu !18_S	et	f	\N
187171	kõrgkoole	kõrgkoole =koole  (SgN  >kõrg+koole !05_S	et	f	\N
186970	realismjätis	?realismjätis =realismjätis  (SgN  >realismjätis !09_S	et	f	\N
186971	realismjätis	?realismjätis =lismjäti  (SgIn  >rea+lismjäti !01_S	et	f	\N
186972	realismjätis	?realismjätis =lismjäti  (SgIn  >rea+lismjätt !22_S	et	f	\N
186973	realismjätis	?realismjätis =lismjätis  (SgN  >rea+lismjätis !11_S	et	f	\N
186974	kolhoodest	?kolhoodest =kolhoo  (PlEl  >kolhoo !26_S	et	f	\N
186975	kolhoodest	?kolhoodest =kolhoode  (SgEl  >kolhoode !16_S	et	f	\N
186976	kolhoodest	?kolhoodest =kolhoode  (PlEl  >kolhoot !22_S	et	f	\N
186977	kolhoodest	?kolhoodest =kolhoodes  (SgP  >kolhoodene !10_A	et	f	\N
186985	tubakaaktsiisi	tubakaaktsiisi =aktsiisi  (SgG  >tubaka+aktsiis !22_S	et	f	\N
186986	tubakaaktsiisi	tubakaaktsiisi =aktsiisi  (SgP  >tubaka+aktsiis !22_S	et	f	\N
186987	tubakaaktsiisi	tubakaaktsiisi =aktsiisi  (SgAdt  >tubaka+aktsiis !22_S	et	f	\N
186996	köitele	köitele =köi  (PlAll  >köis !14_S	et	f	\N
186997	köitele	köitele =köite  (SgAll  >köide !06_S	et	f	\N
186998	talusid	talusid =talu  (PlP  >talu !17_S	et	f	\N
186999	talusid	talusid =talu  (IndIpfSg2  >taluma !27_V	et	f	\N
187000	talusid	talusid =talu  (IndIpfPl3  >taluma !27_V	et	f	\N
187023	reaalharu	reaalharu =haru  (SgN  >reaal+haru !17_S	et	f	\N
187024	reaalharu	reaalharu =haru  (SgG  >reaal+haru !17_S	et	f	\N
187025	reaalharu	reaalharu =haru  (SgP  >reaal+haru !17_S	et	f	\N
187028	kooliteed	kooliteed =tee  (PlN  >kooli+tee !26_S	et	f	\N
187029	kooliteed	kooliteed =tee  (SgP  >kooli+tee !26_S	et	f	\N
187030	internaatkoole	internaatkoole =koo  (SgAll  >internaat+kubu !18_S	et	f	\N
187031	internaatkoole	internaatkoole =koole  (SgN  >internaat+koole !05_S	et	f	\N
187032	internaatkoole	internaatkoole =koole  (PlP  >internaat+kool !22_S	et	f	\N
187052	kirjandusvoolu	kirjandusvoolu =voolu  (SgG  >kirjandus+vool !22_S	et	f	\N
187053	kirjandusvoolu	kirjandusvoolu =voolu  (SgP  >kirjandus+vool !22_S	et	f	\N
187054	kirjandusvoolu	kirjandusvoolu =voolu  (SgAdt  >kirjandus+vool !22_S	et	f	\N
187058	geograafid	geograafid =geograafi  (PlN  >geograaf !22_S	et	f	\N
187059	geograafid	geograafid =graafi  (PlN  >geo+graaf !22_S	et	f	\N
187080	arreteerimist	arreteerimist =arreteerimis  (SgP  >arreteerimine !12_S	et	f	\N
187081	arreteerimist	"arreteerimine %arreteeri  )MINE_vS  <arreteerima ;28_V	et	f	\N
187082	ületamisele	ületamisele =ületamise  (SgAll  >ületamine !12_S	et	f	\N
187083	ületamisele	"ületamine %ületa  )MINE_vS  <ületama ;27_V	et	f	\N
187097	haridustee	haridustee =tee  (SgN  >haridus+tee !26_S	et	f	\N
187098	haridustee	haridustee =tee  (SgG  >haridus+tee !26_S	et	f	\N
187118	eetonia	?eetonia =eetonia  (SgN  >eetonia !01_S	et	f	\N
187119	eetonia	?eetonia =eetonia  (SgG  >eetonia !01_S	et	f	\N
187128	komitlased	?komitlased =komitlase  (PlN  >komitlane !12_S	et	f	\N
187129	komitlased	?komitlased =itlase  (PlN  >kom+itlane !12?10_S	et	f	\N
187143	pärastsõjajärjgset	?pärastsõjajärjgset =pärastsõjajärjgse  (SgP  >pärastsõjajärjgne !02_A	et	f	\N
187144	pärastsõjajärjgset	?pärastsõjajärjgset =järjgse  (SgP  >pärast+sõja+järjgne !02_A	et	f	\N
187145	pärastsõjajärjgset	?pärastsõjajärjgset =järjgse  (SgP  >pärast+sõja+järjgse !06_S	et	f	\N
187146	pärastsõjajärjgset	?pärastsõjajärjgset =sõjajärjgse  (SgP  >pärast+sõjajärjgne !02_A	et	f	\N
187160	märtsi	märtsi =märtsi  (SgG  >märts !22_S	et	f	\N
187162	märtsi	märtsi =märtsi  (SgP  >märts !22_S	et	f	\N
187164	märtsi	märtsi =märtsi  (SgAdt  >märts !22_S	et	f	\N
187178	häivitada	?häivitada =häivita  (Inf  >häivitama !27_V	et	f	\N
187215	saematerialid	?saematerialid =saemateriali  (PlN  >saemateriali !16_S	et	f	\N
187216	saematerialid	?saematerialid =saemateriali  (PlN  >saematerial !19_S	et	f	\N
187217	saematerialid	?saematerialid =saemateriali  (IndPrSg2  >saematerialima !28_V	et	f	\N
187218	saematerialid	?saematerialid =materiali  (PlN  >sae+materiali !16_S	et	f	\N
187219	saematerialid	?saematerialid =materiali  (PlN  >sae+material !19_S	et	f	\N
187235	rõhutanud	rõhutanud =rõhuta  (PtsPtPs  >rõhutama !27_V	et	f	\N
187236	rõhutanud	rõhutanud =rõhutanu  (PlN  >rõhutanu !01_S	et	f	\N
187237	rõhutanud	"rõhutanu %rõhuta  )NU_vS  <rõhutama ;27_V	et	f	\N
187238	rõhutanud	rõhutanud =rõhutanud  (ID  >rõhutanud !41_A	et	f	\N
187239	rõhutanud	"rõhutanud %rõhuta  )NUD_vA  <rõhutama ;27_V	et	f	\N
187240	rõhutanud	rõhutanud =tanu  (PlN  >rõhu+tanu !17_S	et	f	\N
187258	ajamõju	ajamõju =mõju  (SgN  >aja+mõju !17_S	et	f	\N
187259	ajamõju	ajamõju =mõju  (SgG  >aja+mõju !17_S	et	f	\N
187260	ajamõju	ajamõju =mõju  (SgP  >aja+mõju !17_S	et	f	\N
187264	ajutis	?ajutis =ajuti  (SgIn  >ajut !02_S	et	f	\N
187265	ajutis	?ajutis =ajuti  (SgIn  >ajutt !22_S	et	f	\N
187266	ajutis	?ajutis =ajutis  (SgN  >ajutis !11_S	et	f	\N
187296	kultuurimõiste	kultuurimõiste =mõiste  (SgN  >kultuuri+mõiste !06_S	et	f	\N
187297	kultuurimõiste	kultuurimõiste =mõiste  (SgG  >kultuuri+mõiste !06_S	et	f	\N
187298	kultuurimõiste	kultuurimõiste =mõiste  (PlP  >kultuuri+mõist !22_S	et	f	\N
187312	ekspordeeriti	?ekspordeeriti =ekspordeeri  (IndIpfIps  >ekspordeerima !28_V	et	f	\N
187313	ekspordeeriti	?ekspordeeriti =ekspordeeriti  (ID  >ekspordeeriti !41_D	et	f	\N
187314	ekspordeeriti	?ekspordeeriti =ekspordeeriti  (SgG  >ekspordeeritt !22_S	et	f	\N
187315	ekspordeeriti	?ekspordeeriti =ekspordeeriti  (IndPrPs_  >ekspordeerittima !28_V	et	f	\N
187015	5-klassiline	-klassiline =klassiline  (SgN  >-klassiline !12_A	et	f	\N
187016	5-klassiline	"-klassiline %klassi  )LINE_aA  <-klass ;22_S	et	f	\N
187026	7-klassiline	-klassiline =klassiline  (SgN  >-klassiline !12_A	et	f	\N
187027	7-klassiline	"-klassiline %klassi  )LINE_aA  <-klass ;22_S	et	f	\N
187037	kkleis	?kkleis =kklei  (SgIn  >kklei !26_S	et	f	\N
187038	kkleis	?kkleis =kkleis  (SgN  >kkleis !22_S	et	f	\N
187051	triiklik	?triiklik =triiklik  (SgN  >triiklik !25_A	et	f	\N
187055	ülistasid	ülistasid =ülista  (IndIpfSg2  >ülistama !27_V	et	f	\N
187056	ülistasid	ülistasid =ülista  (IndIpfPl3  >ülistama !27_V	et	f	\N
187072	venestumispoliitika	?venestumispoliitika =venestumispoliitika  (SgN  >venestumispoliitika !01_S	et	f	\N
187073	venestumispoliitika	?venestumispoliitika =venestumispoliitika  (SgG  >venestumispoliitika !01_S	et	f	\N
187074	venestumispoliitika	?venestumispoliitika =venestumispoliitika  (SgG  >venestumispoliitikas !02_A	et	f	\N
187075	venestumispoliitika	?venestumispoliitika =stumispoliitika  (SgN  >vene+stumispoliitika !01_S	et	f	\N
187076	venestumispoliitika	?venestumispoliitika =stumispoliitika  (SgG  >vene+stumispoliitika !01_S	et	f	\N
187077	venestumispoliitika	?venestumispoliitika =stumispoliitika  (SgG  >vene+stumispoliitikas !02_A	et	f	\N
187093	sõpruskondi	sõpruskondi =sõpruskondi  (SgP  >sõpruskond !22_S	et	f	\N
187094	sõpruskondi	sõpruskondi =sõpruskondi  (SgAdt  >sõpruskond !22_S	et	f	\N
187095	sõpruskondi	sõpruskondi =sõpruskondi  (PlP  >sõpruskond !22_S	et	f	\N
187096	sõpruskondi	sõpruskondi =kondi  (SgG  >sõprus+kont !22_S	et	f	\N
187117	edandada	?edandada =edanda  (Inf  >edandama !27_V	et	f	\N
187132	heidetakse	heidetakse =heide  (IndPrIps  >heitma !34_V	et	f	\N
187133	heidetakse	heidetakse =takse  (PlP  >heide+taks !22_S	et	f	\N
187134	beti	?beti =beti  (SgN  >beti !16_S	et	f	\N
187135	beti	?beti =beti  (SgG  >beti !16_S	et	f	\N
187136	beti	?beti =beti  (SgG  >bett !22_S	et	f	\N
187137	beti	?beti =beti  (IndPrPs_  >betima !27_V	et	f	\N
187138	beti	?beti =beti  (IndPrPs_  >bettima !28_V	et	f	\N
187139	beti	?beti =beti  (ImpPrSg2  >betima !27_V	et	f	\N
187140	beti	?beti =beti  (ImpPrSg2  >bettima !28_V	et	f	\N
187142	starkopp	?starkopp =starkopp  (SgN  >starkopp !22_S	et	f	\N
187147	harituid	harituid =haritu  (PlP  >haritu !01_AS	et	f	\N
187148	harituid	"haritu %hari  )TU1_vS  <harima ;27_V	et	f	\N
187149	harituid	harituid =tui  (PlN  >hari+tui !26_S	et	f	\N
187150	harituid	harituid =tui  (SgP  >hari+tui !26_S	et	f	\N
187182	1940-ndate	?-ndate =ndate  (SgN  >-ndate !06_S	et	f	\N
187183	1940-ndate	?-ndate =ndate  (IndPrPs_  >-ndatema !27_V	et	f	\N
187184	1940-ndate	?-ndate =ndate  (ImpPrSg2  >-ndatema !27_V	et	f	\N
187222	jõul	jõul =jõu  (SgAd  >jõud !22_S	et	f	\N
187223	jõul	jõul =jõul  (ID  >jõul !41_K	et	f	\N
187225	jõul	jõul =jõul  (SgN  >jõul !22_S	et	f	\N
187241	tööstustõusu	tööstustõusu =tõusu  (SgG  >tööstus+tõus !22_S	et	f	\N
187242	tööstustõusu	tööstustõusu =tõusu  (SgP  >tööstus+tõus !22_S	et	f	\N
187243	tööstustõusu	tööstustõusu =tõusu  (SgAdt  >tööstus+tõus !22_S	et	f	\N
187244	eksporteeriti	?eksporteeriti =eksporteeri  (IndIpfIps  >eksporteerima !28_V	et	f	\N
187245	eksporteeriti	?eksporteeriti =eksporteeriti  (ID  >eksporteeriti !41_D	et	f	\N
187246	eksporteeriti	?eksporteeriti =eksporteeriti  (SgG  >eksporteeritt !22_S	et	f	\N
187248	eksporteeriti	?eksporteeriti =eksporteeriti  (IndPrPs_  >eksporteerittima !28_V	et	f	\N
187249	eksporteeriti	?eksporteeriti =eksporteeriti  (ImpPrSg2  >eksporteerittima !28_V	et	f	\N
187250	eksporteeriti	?eksporteeriti =eeriti  (SgG  >eks+port+eerit !02_S	et	f	\N
187251	eksporteeriti	?eksporteeriti =eeriti  (SgG  >eks+port+eeritt !22_S	et	f	\N
187252	eksporteeriti	?eksporteeriti =porteeriti  (SgG  >eks+porteeritt !22_S	et	f	\N
187261	saavutustega	saavutustega =saavutus  (PlKom  >saavutus !11_S	et	f	\N
187262	saavutustega	"saavutus %saavuta  )US_vS  <saavutama ;27_V	et	f	\N
187275	natsionaalvähemused	natsionaalvähemused =vähemuse  (PlN  >natsionaal+vähemus !11_S	et	f	\N
187276	natsionaalvähemused	"natsionaal+vähemus %vähema  )US_aS  <natsionaal+vähem ;02_A	et	f	\N
187279	ev-inkorporeeritud	ev-inkorporeeritud =inkorporeeri  (PtsPtIps  >ev-inkorporeerima !28_V	et	f	\N
187280	ev-inkorporeeritud	ev-inkorporeeritud =inkorporeeritu  (PlN  >ev-inkorporeeritu !01_S	et	f	\N
187281	ev-inkorporeeritud	"ev-inkorporeeritu %inkorporeeri  )TU1_vS  <ev-inkorporeerima ;28_V	et	f	\N
187282	ev-inkorporeeritud	ev-inkorporeeritud =inkorporeeritud  (ID  >ev-inkorporeeritud !41_A	et	f	\N
187283	ev-inkorporeeritud	"ev-inkorporeeritud %inkorporeeri  )TUD_vA  <ev-inkorporeerima ;28_V	et	f	\N
187287	küüditus	küüditus =küüditu  (SgIn  >küüditu !01_AS	et	f	\N
187288	küüditus	"küüditu %küüdi  )TU1_vS  <küütima ;28_V	et	f	\N
187289	küüditus	"küüditu %küüdi  )TU2_kA  <küüt ;22_S	et	f	\N
187290	küüditus	küüditus =küüditus  (SgN  >küüditus !11_S	et	f	\N
187291	küüditus	"küüditus %küüdita  )US_vS  <küüditama ;27_V	et	f	\N
187292	küüditus	"küüditus %küüdi  )TUS1_aS  <küütima ;28_V	et	f	\N
187293	küüditus	"küüditus %küüdi  )TUS2_aS  <küüt ;22_S	et	f	\N
187294	sotsiaalpropaganda	sotsiaalpropaganda =propaganda  (SgN  >sotsiaal+propaganda !16_S	et	f	\N
187295	sotsiaalpropaganda	sotsiaalpropaganda =propaganda  (SgG  >sotsiaal+propaganda !16_S	et	f	\N
187299	ekonoomika	?ekonoomika =ekonoomika  (SgN  >ekonoomika !01_S	et	f	\N
187116	asjaajamiskeel	asjaajamiskeel =keel  (SgN  >asja+aja+mis+keel !13_S	et	f	\N
187130	puhastuse	puhastuse =puhastuse  (SgG  >puhastus !11_S	et	f	\N
187131	puhastuse	"puhastus %puhasta  )US_vS  <puhastama ;27_V	et	f	\N
187151	rahvateadus	rahvateadus =teadu  (SgIn  >rahva+tead !22_S	et	f	\N
187152	rahvateadus	rahvateadus =teadus  (SgN  >rahva+teadus !11~09_S	et	f	\N
187153	parastsõjajärgse	?parastsõjajärgse =parastsõjajärgse  (SgG  >parastsõjajärgne !02_A	et	f	\N
187154	parastsõjajärgse	?parastsõjajärgse =tsõjajärgse  (SgG  >paras+tsõjajärgne !02_A	et	f	\N
187161	pleeniumi	?pleeniumi =pleeniumi  (SgN  >pleeniumi !16_S	et	f	\N
187163	pleeniumi	?pleeniumi =pleeniumi  (SgG  >pleenium !19~02_S	et	f	\N
187165	pleeniumi	?pleeniumi =pleeniumi  (SgG  >pleeniumi !16_S	et	f	\N
187166	pleeniumi	?pleeniumi =pleeniumi  (SgP  >pleenium !19_S	et	f	\N
187167	pleeniumi	?pleeniumi =pleeniumi  (SgAdt  >pleenium !19_S	et	f	\N
187168	pleeniumi	?pleeniumi =pleeniumi  (IndPrPs_  >pleeniumima !28_V	et	f	\N
187169	pleeniumi	?pleeniumi =pleeniumi  (ImpPrSg2  >pleeniumima !28_V	et	f	\N
187202	mõisnikute	?mõisnikute =mõisniku  (PlG  >mõisniku !01_S	et	f	\N
187203	mõisnikute	?mõisnikute =mõisniku  (IndPrPl2  >mõisnikuma !27_V	et	f	\N
187204	suurimad	"suurim %suuri  )IM_sA  <suur ;13_A	et	f	\N
187205	suurimad	suurimad =ima  (PlN  >suur+ima !17_S	et	f	\N
187206	suurimad	suurimad =rima  (PlN  >suu+rima !17_S	et	f	\N
187220	beekoni	?beekoni =beeko  (SgTer  >beeko !16_S	et	f	\N
187221	beekoni	?beekoni =beekoni  (SgG  >beekon !02_S	et	f	\N
187307	entusiasmi	entusiasmi =entusiasmi  (SgG  >entusiasm !22_S	et	f	\N
187308	entusiasmi	entusiasmi =entusiasmi  (SgP  >entusiasm !22_S	et	f	\N
187309	entusiasmi	entusiasmi =entusiasmi  (SgAdt  >entusiasm !22_S	et	f	\N
187318	keemitööstus	?keemitööstus =keemitööstu  (IndIpfSg3  >keemitööstuma !27_V	et	f	\N
187319	keemitööstus	?keemitööstus =keemitööstus  (SgN  >keemitööstus !11~09_S	et	f	\N
187324	hävitud	hävitud =hävi  (PtsPtIps  >hävima !27_V	et	f	\N
187325	hävitud	hävitud =hävitu  (PlN  >hävitu !01_AS	et	f	\N
187326	hävitud	"hävitu %hävi  )TU1_vS  <hävima ;27_V	et	f	\N
187327	hävitud	"hävitu %hävi  )TU2_kA  <hävi ;17_S	et	f	\N
187328	hävitud	hävitud =hävitud  (ID  >hävitud !41_A	et	f	\N
187329	hävitud	"hävitud %hävi  )TUD_vA  <hävima ;27_V	et	f	\N
187342	trükitut	trükitut =trükitu  (SgP  >trükitu !01_AS	et	f	\N
187343	trükitut	"trükitu %trüki  )TU1_vS  <trükkima ;28_V	et	f	\N
187345	trükitut	"trükitu %trüki  )TU2_kA  <trükk ;22_S	et	f	\N
187360	trükkid	### trükkid	et	f	\N
187368	korrekteeriti	?korrekteeriti =korrekteeri  (IndIpfIps  >korrekteerima !28_V	et	f	\N
187369	korrekteeriti	?korrekteeriti =korrekteeriti  (ID  >korrekteeriti !41_D	et	f	\N
187370	korrekteeriti	?korrekteeriti =korrekteeriti  (SgG  >korrekteeritt !22_S	et	f	\N
187371	korrekteeriti	?korrekteeriti =korrekteeriti  (IndPrPs_  >korrekteerittima !28_V	et	f	\N
187372	korrekteeriti	?korrekteeriti =korrekteeriti  (ImpPrSg2  >korrekteerittima !28_V	et	f	\N
187373	vabanemine	vabanemine =vabanemine  (SgN  >vabanemine !12_S	et	f	\N
187374	vabanemine	"vabanemine %vabane  )MINE_vS  <vabanema ;27_V	et	f	\N
187384	pilli-	pilli- =pilli  (SgG  >pill !22_S	et	f	\N
187385	pilli-	pilli- =pilli  (SgP  >pill !22_S	et	f	\N
187386	pilli-	pilli- =pilli  (SgAdt  >pill !22_S	et	f	\N
187387	pilli-	pilli- =pilli  (IndPrPs_  >pillima !28_V	et	f	\N
187388	pilli-	pilli- =pilli  (ImpPrSg2  >pillima !28_V	et	f	\N
187391	ideoloogilised	ideoloogilised =ideoloogilise  (PlN  >ideoloogiline !12_A	et	f	\N
187392	ideoloogilised	"ideoloogiline %ideoloogi  )LINE_aA  <ideoloog ;22_S	et	f	\N
187393	ideoloogilised	ideoloogilised =loogilise  (PlN  >ideo+loogiline !12_A	et	f	\N
187394	ideoloogilised	"ideo+loogiline %loogi  )LINE_aA  <ideo+loog ;22_S	et	f	\N
187403	paljastamine	paljastamine =paljastamine  (SgN  >paljastamine !12_S	et	f	\N
187404	paljastamine	"paljastamine %paljasta  )MINE_vS  <paljastama ;27_V	et	f	\N
187405	loominguliste	loominguliste =loomingulis  (PlG  >loominguline !12_A	et	f	\N
187407	loominguliste	"loominguline %loomingu  )LINE_aA  <looming ;02_S	et	f	\N
187419	välismaiseid	välismaiseid =maise  (PlP  >välis+maine !10_A	et	f	\N
187420	välismaiseid	"välis+maine %mai  )NE_aA  <välis+maa ;26_S	et	f	\N
187440	laulupeotraditsiooni	laulupeotraditsiooni =traditsiooni  (SgG  >laulu+peo+traditsioon !22_S	et	f	\N
187441	laulupeotraditsiooni	laulupeotraditsiooni =traditsiooni  (SgP  >laulu+peo+traditsioon !22_S	et	f	\N
187442	laulupeotraditsiooni	laulupeotraditsiooni =traditsiooni  (SgAdt  >laulu+peo+traditsioon !22_S	et	f	\N
187473	reklammikool	?reklammikool =reklammikoo  (SgAd  >reklammikoo !26_S	et	f	\N
187474	reklammikool	?reklammikool =reklammikool  (SgN  >reklammikool !22_S	et	f	\N
187497	värdjas	värdjas =värdja  (SgIn  >värdjas !02_S	et	f	\N
187498	värdjas	värdjas =värdjas  (SgN  >värdjas !02_S	et	f	\N
187499	külaelu	külaelu =elu  (SgN  >küla+elu !17_S	et	f	\N
187500	külaelu	külaelu =elu  (SgG  >küla+elu !17_S	et	f	\N
187501	külaelu	külaelu =elu  (SgP  >küla+elu !17_S	et	f	\N
187506	80ndate	?ndate =ndate  (SgN  >ndate !06_S	et	f	\N
187507	80ndate	?ndate =ndate  (IndPrPs_  >ndatema !27_V	et	f	\N
187508	80ndate	?ndate =ndate  (ImpPrSg2  >ndatema !27_V	et	f	\N
187509	norma	?norma =norma  (SgN  >norma !16_S	et	f	\N
187172	kõrgkoole	kõrgkoole =koole  (PlP  >kõrg+kool !22_S	et	f	\N
187173	häivitatakse	?häivitatakse =häivita  (IndPrIps  >häivitama !27_V	et	f	\N
187174	häivitatakse	?häivitatakse =häivitatakse  (SgG  >häivitatakne !02_A	et	f	\N
187175	häivitatakse	?häivitatakse =häivitatakse  (PlP  >häivitataks !22_S	et	f	\N
187179	trasitsioonid	?trasitsioonid =trasitsiooni  (PlN  >trasitsiooni !16_S	et	f	\N
187180	trasitsioonid	?trasitsioonid =trasitsiooni  (PlN  >trasitsioon !22_S	et	f	\N
187181	trasitsioonid	?trasitsioonid =trasitsiooni  (IndPrSg2  >trasitsioonima !28_V	et	f	\N
187185	sotsiolismi	?sotsiolismi =sotsiolismi  (SgG  >sotsiolism !22_S	et	f	\N
187186	sotsiolismi	?sotsiolismi =sotsiolismi  (SgP  >sotsiolism !22_S	et	f	\N
187187	sotsiolismi	?sotsiolismi =sotsiolismi  (SgAdt  >sotsiolism !22_S	et	f	\N
187188	sotsiolismi	?sotsiolismi =sotsiolismi  (IndPrPs_  >sotsiolismima !28_V	et	f	\N
187189	sotsiolismi	?sotsiolismi =sotsiolismi  (ImpPrSg2  >sotsiolismima !28_V	et	f	\N
187190	sotsiolismi	?sotsiolismi =lismi  (SgN  >sotsio+lismi !16_S	et	f	\N
187191	sotsiolismi	?sotsiolismi =lismi  (SgG  >sotsio+lismi !16_S	et	f	\N
187192	sotsiolismi	?sotsiolismi =lismi  (SgG  >sotsio+lism !22_S	et	f	\N
187193	sotsiolismi	?sotsiolismi =lismi  (SgP  >sotsio+lism !22_S	et	f	\N
187194	sotsiolismi	?sotsiolismi =lismi  (SgAdt  >sotsio+lism !22_S	et	f	\N
187195	sotsiolismi	?sotsiolismi =iolismi  (SgN  >sots+iolismi !01_S	et	f	\N
187196	sotsiolismi	?sotsiolismi =iolismi  (SgG  >sots+iolismi !01_S	et	f	\N
187197	sotsiolismi	?sotsiolismi =iolismi  (SgG  >sots+iolism !22_S	et	f	\N
187198	sotsiolismi	?sotsiolismi =iolismi  (SgP  >sots+iolism !22_S	et	f	\N
187199	sotsiolismi	?sotsiolismi =iolismi  (SgAdt  >sots+iolism !22_S	et	f	\N
187207	erakapitalist	erakapitalist =tali  (SgEl  >era+kapi+tali !17_S	et	f	\N
187208	erakapitalist	erakapitalist =talis  (SgP  >era+kapi+taline !10_A	et	f	\N
187209	erakapitalist	"era+kapi+taline %tali  )NE_aA  <era+kapi+tali ;24_S	et	f	\N
187210	erakapitalist	"era+kapi+taline %tali  )NE_aA  <era+kapi+tali ;17_S	et	f	\N
187211	erakapitalist	erakapitalist =kapitali  (SgEl  >era+kapital !19_S	et	f	\N
187212	erakapitalist	erakapitalist =kapitalis  (SgP  >era+kapitaline !12_A	et	f	\N
187213	erakapitalist	"era+kapitaline %kapitali  )NE_aA  <era+kapital ;19_S	et	f	\N
187214	erakapitalist	erakapitalist =kapitalist  (SgN  >era+kapitalist !22_S	et	f	\N
187224	inporteeriti	?inporteeriti =inporteeri  (IndIpfIps  >inporteerima !28_V	et	f	\N
187226	inporteeriti	?inporteeriti =inporteeriti  (ID  >inporteeriti !41_D	et	f	\N
187227	inporteeriti	?inporteeriti =inporteeriti  (SgG  >inporteeritt !22_S	et	f	\N
187228	inporteeriti	?inporteeriti =inporteeriti  (IndPrPs_  >inporteerittima !28_V	et	f	\N
187229	inporteeriti	?inporteeriti =inporteeriti  (ImpPrSg2  >inporteerittima !28_V	et	f	\N
187230	balanseeritud	?balanseeritud =balanseeri  (PtsPtIps  >balanseerima !28_V	et	f	\N
187231	balanseeritud	?balanseeritud =balanseeritu  (PlN  >balanseeritu !01_S	et	f	\N
187232	balanseeritud	?balanseeritud =balanseeritu  (IndPrSg2  >balanseerituma !27_V	et	f	\N
187233	balanseeritud	?balanseeritud =balanseeritud  (ID  >balanseeritud !41_A	et	f	\N
187234	rigatehas	?rigatehas =rigateha  (SgIn  >rigateha !16_S	et	f	\N
187263	mallemaailmas	?mallemaailmas =mallemaailma  (SgIn  >mallemaailma !16_S	et	f	\N
187277	kirjanuds	?kirjanuds =kirjanuds  (SgN  >kirjanuds !22_S	et	f	\N
187278	kirjanuds	?kirjanuds =nuds  (SgN  >kirja+nuds !22_S	et	f	\N
187304	jõukalt	jõukalt =jõuka  (SgAbl  >jõukas !02_A	et	f	\N
187305	jõukalt	jõukalt =jõukalt  (ID  >jõukalt !41_D	et	f	\N
187306	jõukalt	"jõukalt %jõuka  )LT_mD  <jõukas ;02_A	et	f	\N
187340	marksism-leninismist	marksism-leninismist =leninismi  (SgEl  >marksism-leninism !22_S	et	f	\N
187341	marksism-leninismist	marksism-leninismist =leninismis  (SgP  >marksism-leninismine !12_A	et	f	\N
187344	marksism-leninismist	"marksism-leninismine %leninismi  )NE_aA  <marksism-leninism ;22_S	et	f	\N
187361	lõked	?lõked =lõke  (IndPrSg2  >lõkema !27_V	et	f	\N
187375	ideoloogilisi	ideoloogilisi =ideoloogilisi  (PlP  >ideoloogiline !12_A	et	f	\N
187376	ideoloogilisi	"ideoloogiline %ideoloogi  )LINE_aA  <ideoloog ;22_S	et	f	\N
187377	ideoloogilisi	ideoloogilisi =loogilisi  (PlP  >ideo+loogiline !12_A	et	f	\N
187378	ideoloogilisi	"ideo+loogiline %loogi  )LINE_aA  <ideo+loog ;22_S	et	f	\N
187379	ellujäämise	ellujäämise =jäämise  (SgG  >ellu+jäämine !12?10_S	et	f	\N
187380	ellujäämise	"ellu+jäämine %jäämi  )NE_aA  <ellu+jääm ;22_S	et	f	\N
187409	vabameelsem	vabameelsem =meelsem  (SgN  >vaba+meelsem !02_A	et	f	\N
187410	vabameelsem	"vaba+meelsem %meelse  )M_cA  <vaba+meelne ;02_A	et	f	\N
187415	tsensuuri-	tsensuuri- =tsensuuri  (SgG  >tsensuur !22_S	et	f	\N
187416	tsensuuri-	tsensuuri- =tsensuuri  (SgP  >tsensuur !22_S	et	f	\N
187417	tsensuuri-	tsensuuri- =tsensuuri  (SgAdt  >tsensuur !22_S	et	f	\N
187418	nsvi	### nsvi	et	f	\N
187421	eksportisid	eksportisid =eksporti  (PlP  >eksport !22_S	et	f	\N
187422	eksportisid	eksportisid =eksporti  (IndIpfSg2  >eksportima !28_V	et	f	\N
187423	eksportisid	eksportisid =eksporti  (IndIpfPl3  >eksportima !28_V	et	f	\N
187424	tootmist	tootmist =tootmis  (SgP  >tootmine !12?10_S	et	f	\N
187425	tootmist	"tootmine %toot  )MINE_vS  <tootma ;34_V	et	f	\N
187426	köögitehnika	köögitehnika =tehnika  (SgN  >köögi+tehnika !01_S	et	f	\N
187427	köögitehnika	köögitehnika =tehnika  (SgG  >köögi+tehnika !01_S	et	f	\N
187254	veena	veena =veena  (IndPrPs_  >veenma !33_V	et	f	\N
187255	veena	veena =veena  (ImpPrSg2  >veenma !33_V	et	f	\N
187256	kvalitee	?kvalitee =kvalitee  (SgN  >kvalitee !26_S	et	f	\N
187257	kvalitee	?kvalitee =kvalitee  (SgG  >kvalitee !26_S	et	f	\N
187267	lähenemine	lähenemine =lähenemine  (SgN  >lähenemine !12_S	et	f	\N
187268	lähenemine	"lähenemine %lähene  )MINE_vS  <lähenema ;27_V	et	f	\N
187269	täislik	?täislik =täislik  (SgN  >täislik !25_A	et	f	\N
187270	legaliseeritud	legaliseeritud =legaliseeri  (PtsPtIps  >legaliseerima !28_V	et	f	\N
187271	legaliseeritud	legaliseeritud =legaliseeritu  (PlN  >legaliseeritu !01_S	et	f	\N
187272	legaliseeritud	"legaliseeritu %legaliseeri  )TU1_vS  <legaliseerima ;28_V	et	f	\N
187273	legaliseeritud	legaliseeritud =legaliseeritud  (ID  >legaliseeritud !41_A	et	f	\N
187274	legaliseeritud	"legaliseeritud %legaliseeri  )TUD_vA  <legaliseerima ;28_V	et	f	\N
187284	jaotuses	jaotuses =jaotuse  (SgIn  >jaotus !11~09_S	et	f	\N
187285	jaotuses	"jaotus %jaota  )US_vS  <jaotama ;27_V	et	f	\N
187286	jaotuses	"jaotus %jao  )TUS2_aS  <jagu ;18_S	et	f	\N
187310	kaabel	kaabel =kaabe  (PlAd  >kaap !22_S	et	f	\N
187311	kaabel	kaabel =kaabel  (SgN  >kaabel !02_S	et	f	\N
187320	kampaania	kampaania =kampaania  (SgN  >kampaania !01_S	et	f	\N
187321	kampaania	kampaania =kampaania  (SgG  >kampaania !01_S	et	f	\N
187322	vastutegu	vastutegu =tegu  (SgN  >vastu+tegu !18_S	et	f	\N
187323	vastutegu	vastutegu =tegu  (SgP  >vastu+tegu !18_S	et	f	\N
187332	vähemused	vähemused =vähemuse  (PlN  >vähemus !11_S	et	f	\N
187333	vähemused	"vähemus %vähema  )US_aS  <vähem ;02_A	et	f	\N
187338	97hääletasid	hääletasid =hääleta  (IndIpfSg2  >hääletama !27_V	et	f	\N
187339	97hääletasid	hääletasid =hääleta  (IndIpfPl3  >hääletama !27_V	et	f	\N
187349	mädanev	mädanev =mädane  (PtsPrPs  >mädanema !27_V	et	f	\N
187350	mädanev	mädanev =mädanev  (SgN  >mädanev !02_A	et	f	\N
187351	mädanev	"mädanev %mädane  )V_vA  <mädanema ;27_V	et	f	\N
187400	läänestumine	?läänestumine =läänestumine  (SgN  >läänestumine !12_S	et	f	\N
187401	läänestumine	?läänestumine =läänestumine  (PlP  >läänestumin !19_S	et	f	\N
187402	läänestumine	?läänestumine =stumine  (SgN  >lääne+stumine !10_A	et	f	\N
187411	armastusele	armastusele =armastuse  (SgAll  >armastus !11_S	et	f	\N
187412	armastusele	"armastus %armasta  )US_vS  <armastama ;27_V	et	f	\N
187428	tutvustasid	tutvustasid =tutvusta  (IndIpfSg2  >tutvustama !27_V	et	f	\N
187429	tutvustasid	tutvustasid =tutvusta  (IndIpfPl3  >tutvustama !27_V	et	f	\N
187439	donald	?donald =donald  (SgN  >donald !02_S	et	f	\N
187446	läänekultuuri	läänekultuuri =kultuuri  (SgG  >lääne+kultuur !22_S	et	f	\N
187447	läänekultuuri	läänekultuuri =kultuuri  (SgP  >lääne+kultuur !22_S	et	f	\N
187448	läänekultuuri	läänekultuuri =kultuuri  (SgAdt  >lääne+kultuur !22_S	et	f	\N
187454	valgusesse	valgusesse =valguse  (SgIll  >valgus !11~09_S	et	f	\N
187455	valgusesse	"valgus %valge  )US_aS  <valge ;01_AS	et	f	\N
187456	valgusesse	valgusesse =valguses  (SgAdt  >valgusene !12_A	et	f	\N
187457	valgusesse	"valgusene %valguse  )NE_aA  <valgus ;09_S	et	f	\N
187458	valgusesse	"valgusene %valguse  )NE_aA  <valgus ;11_S	et	f	\N
187459	valgusesse	valgusesse =sesse  (PlP  >valgu+sess !22_S	et	f	\N
187460	valgusesse	valgusesse =use  (PlIll  >valg+usk !22_S	et	f	\N
187465	abinõudeni	abinõudeni =nõu  (PlTer  >abi+nõu !26_S	et	f	\N
187466	abinõudeni	abinõudeni =nõude  (SgTer  >abi+nõue !06_S	et	f	\N
187471	lastesaaded	?lastesaaded =lastesaade  (PlN  >lastesaade !16_S	et	f	\N
187477	agressiivsust	agressiivsust =agressiivsus  (SgP  >agressiivsus !11~09_S	et	f	\N
187478	agressiivsust	"agressiivsus %agressiivse  )US_aS  <agressiivne ;02_A	et	f	\N
187481	agressiivsuse	agressiivsuse =agressiivsuse  (SgG  >agressiivsus !11~09_S	et	f	\N
187482	agressiivsuse	"agressiivsus %agressiivse  )US_aS  <agressiivne ;02_A	et	f	\N
187502	levides	levides =levi  (PlIn  >levi !17_S	et	f	\N
187503	levides	levides =levi  (Ger  >levima !27_V	et	f	\N
187513	sportlastel	sportlastel =sportlas  (PlAd  >sportlane !12?10_S	et	f	\N
187514	sportlastel	sportlastel =las  (PlAd  >sport+laps !14_S	et	f	\N
187515	sportlastel	sportlastel =laste  (PlAd  >sport+last !22_S	et	f	\N
187516	kino-	kino- =kino  (SgN  >kino !17_S	et	f	\N
187517	kino-	kino- =kino  (SgG  >kino !17_S	et	f	\N
187518	kino-	kino- =kino  (SgP  >kino !17_S	et	f	\N
187519	käsitluse	käsitluse =käsitluse  (SgG  >käsitlus !11_S	et	f	\N
187520	käsitluse	"käsitlus %käsitle  )US_vS  <käsitlema ;27_V	et	f	\N
187524	kolisid	kolisid =koli  (PlP  >koli !17_S	et	f	\N
187525	kolisid	kolisid =koli  (IndIpfSg2  >kolima !27_V	et	f	\N
187526	kolisid	kolisid =koli  (IndIpfPl3  >kolima !27_V	et	f	\N
187527	etv-d	etv-d =etv  (SgP  >etv !xx_Q	et	f	\N
187528	etv-d	etv-d =etv  (PlN  >etv !xx_Q	et	f	\N
187552	standardile	standardile =standardi  (SgAll  >standard !02_S	et	f	\N
187553	standardile	standardile =standardi  (SgAll  >standart !22_S	et	f	\N
187557	väidetavalt	väidetavalt =väidetava  (SgAbl  >väidetav !02_A	et	f	\N
187558	väidetavalt	"väidetav %väide  )TAV_vAS  <väitma ;34_V	et	f	\N
187559	väidetavalt	väidetavalt =väidetavalt  (ID  >väidetavalt !41_D	et	f	\N
187560	väidetavalt	"väidetavalt %väide  )TAVALT_mD  <väitma ;34_V	et	f	\N
187300	ekonoomika	?ekonoomika =ekonoomika  (SgG  >ekonoomika !01_S	et	f	\N
187301	ekonoomika	?ekonoomika =ekonoomika  (SgG  >ekonoomikas !02_A	et	f	\N
187302	balteks	?balteks =balte  (SgTr  >balde !06_S	et	f	\N
187303	balteks	?balteks =balte  (KndPrPs  >baltema !27_V	et	f	\N
187354	zanrites	?zanrites =zanrite  (PlIn  >zanritt !22_S	et	f	\N
187355	pidurdatud	pidurdatud =pidurda  (PtsPtIps  >pidurdama !27_V	et	f	\N
187356	pidurdatud	pidurdatud =pidurdatu  (PlN  >pidurdatu !01_S	et	f	\N
187357	pidurdatud	"pidurdatu %pidurda  )TU1_vS  <pidurdama ;27_V	et	f	\N
187358	pidurdatud	pidurdatud =pidurdatud  (ID  >pidurdatud !41_A	et	f	\N
187359	pidurdatud	"pidurdatud %pidurda  )TUD_vA  <pidurdama ;27_V	et	f	\N
187362	sotsialismideega	?sotsialismideega =sotsialismidee  (SgKom  >sotsialismidee !26_S	et	f	\N
187363	sotsialismideega	?sotsialismideega =sotsialismideega  (SgN  >sotsialismideega !16_S	et	f	\N
187364	sotsialismideega	?sotsialismideega =sotsialismideega  (SgG  >sotsialismideega !16_S	et	f	\N
187365	sotsialismideega	?sotsialismideega =dee  (SgKom  >sotsialismi+dee !26_S	et	f	\N
187366	sotsialismideega	?sotsialismideega =deega  (SgN  >sotsialismi+deega !16_S	et	f	\N
187367	sotsialismideega	?sotsialismideega =deega  (SgG  >sotsialismi+deega !16_S	et	f	\N
187381	taasavasid	taasavasid =ava  (PlP  >taas+ava !17_S	et	f	\N
187382	taasavasid	taasavasid =ava  (IndIpfSg2  >taas+avama !27_V	et	f	\N
187383	taasavasid	taasavasid =ava  (IndIpfPl3  >taas+avama !27_V	et	f	\N
187389	katkestasid	katkestasid =katkesta  (IndIpfSg2  >katkestama !27_V	et	f	\N
187390	katkestasid	katkestasid =katkesta  (IndIpfPl3  >katkestama !27_V	et	f	\N
187395	riigikorda	riigikorda =korda  (SgP  >riigi+kord !22_S	et	f	\N
187396	riigikorda	riigikorda =korda  (SgAdt  >riigi+kord !22_S	et	f	\N
187397	lubatu	lubatu =lubatu  (SgN  >lubatu !01_AS	et	f	\N
187398	lubatu	"lubatu %luba  )TU1_vS  <lubama ;27_V	et	f	\N
187399	lubatu	lubatu =lubatu  (SgG  >lubatu !01_AS	et	f	\N
187406	ennistamine	ennistamine =ennistamine  (SgN  >ennistamine !12_S	et	f	\N
187408	ennistamine	"ennistamine %ennista  )MINE_vS  <ennistama ;27_V	et	f	\N
187451	südamerahu	südamerahu =rahu  (SgN  >südame+rahu !17_S	et	f	\N
187452	südamerahu	südamerahu =rahu  (SgG  >südame+rahu !17_S	et	f	\N
187453	südamerahu	südamerahu =rahu  (SgP  >südame+rahu !17_S	et	f	\N
187472	elanikutega	### elanikutega	et	f	\N
187475	turims	?turims =turims  (SgN  >turims !22_S	et	f	\N
187476	llaiuse	?llaiuse =llaiuse  (SgG  >llaius !11~09_S	et	f	\N
187486	tegutsemisele	tegutsemisele =tegutsemise  (SgAll  >tegutsemine !12_S	et	f	\N
187487	tegutsemisele	"tegutsemine %tegutse  )MINE_vS  <tegutsema ;27_V	et	f	\N
187504	vaheldust	vaheldust =vaheldus  (SgP  >vaheldus !11_S	et	f	\N
187505	vaheldust	"vaheldus %vahelda  )US_vS  <vaheldama ;27_V	et	f	\N
187531	vaatajateni	vaatajateni =vaataja  (PlTer  >vaataja !01_S	et	f	\N
187532	vaatajateni	"vaataja %vaata  )JA_vS  <vaatama ;29_V	et	f	\N
187539	populaarsuse	populaarsuse =populaarsuse  (SgG  >populaarsus !11~09_S	et	f	\N
187540	populaarsuse	"populaarsus %populaarse  )US_aS  <populaarne ;02_A	et	f	\N
187579	naissoo	naissoo =soo  (SgN  >nais+soo !26_S	et	f	\N
187580	naissoo	naissoo =soo  (SgG  >nais+sugu !18_S	et	f	\N
187581	naissoo	naissoo =soo  (SgG  >nais+soo !26_S	et	f	\N
187588	inerrinde	?inerrinde =inerrinde  (PlP  >inerrind !22_S	et	f	\N
187595	hoolitsenud	hoolitsenud =hoolitse  (PtsPtPs  >hoolitsema !27_V	et	f	\N
187596	hoolitsenud	hoolitsenud =hoolitsenu  (PlN  >hoolitsenu !01_S	et	f	\N
187597	hoolitsenud	"hoolitsenu %hoolitse  )NU_vS  <hoolitsema ;27_V	et	f	\N
187598	hoolitsenud	hoolitsenud =hoolitsenud  (ID  >hoolitsenud !41_A	et	f	\N
187599	hoolitsenud	"hoolitsenud %hoolitse  )NUD_vA  <hoolitsema ;27_V	et	f	\N
187600	juhtkonna	juhtkonna =juhtkonna  (SgG  >juhtkond !22_S	et	f	\N
187601	juhtkonna	juhtkonna =konna  (SgG  >juht+konn !22_S	et	f	\N
187602	juhtkonna	juhtkonna =konna  (SgP  >juht+konn !22_S	et	f	\N
187603	juhtkonna	juhtkonna =konna  (SgAdt  >juht+konn !22_S	et	f	\N
187630	ens	?ens =ens  (SgN  >ens !22_S	et	f	\N
187645	kaubandusest	kaubandusest =kaubanduse  (SgEl  >kaubandus !11_S	et	f	\N
187646	kaubandusest	kaubandusest =kaubanduses  (SgP  >kaubandusene !12_A	et	f	\N
187647	kaubandusest	"kaubandusene %kaubanduse  )NE_aA  <kaubandus ;11_S	et	f	\N
187648	lammutamise	lammutamise =lammutamise  (SgG  >lammutamine !12_S	et	f	\N
187649	lammutamise	"lammutamine %lammuta  )MINE_vS  <lammutama ;27_V	et	f	\N
187684	päpast	?päpast =päpa  (SgEl  >päpa !16_S	et	f	\N
187685	päpast	?päpast =päpas  (SgP  >päpas !07_S	et	f	\N
187686	päpast	?päpast =päpas  (SgP  >päpane !10_A	et	f	\N
187701	surmaks	surmaks =surma  (SgTr  >surm !22_S	et	f	\N
187702	surmaks	surmaks =surma  (KndPrPs  >surmama !29_V	et	f	\N
187736	integreerimine	integreerimine =integreerimine  (SgN  >integreerimine !12_S	et	f	\N
187737	integreerimine	"integreerimine %integreeri  )MINE_vS  <integreerima ;28_V	et	f	\N
187740	eeldavad	eeldavad =eelda  (IndPrPl3  >eeldama !27_V	et	f	\N
187744	eeldavad	eeldavad =eeldava  (PlN  >eeldav !02_A	et	f	\N
187745	eeldavad	"eeldav %eelda  )V_vA  <eeldama ;27_V	et	f	\N
187758	eluvastuvõttmine	?eluvastuvõttmine =eluvastuvõttmine  (SgN  >eluvastuvõttmine !12_A	et	f	\N
187762	eluvastuvõttmine	?eluvastuvõttmine =võttmine  (SgN  >elu+vastu+võttmine !12?10_A	et	f	\N
187316	ekspordeeriti	?ekspordeeriti =ekspordeeriti  (ImpPrSg2  >ekspordeerittima !28_V	et	f	\N
187317	ekspordeeriti	?ekspordeeriti =pordeeriti  (SgG  >eks+pordeeritt !22_S	et	f	\N
187330	luuterlik	?luuterlik =luuterlik  (SgN  >luuterlik !25_A	et	f	\N
187331	luuterlik	?luuterlik =terlik  (SgN  >luu+terlik !25_A	et	f	\N
187334	falsititseeritud	?falsititseeritud =falsititseeri  (PtsPtIps  >falsititseerima !28_V	et	f	\N
187335	falsititseeritud	?falsititseeritud =falsititseeritu  (PlN  >falsititseeritu !01_S	et	f	\N
187336	falsititseeritud	?falsititseeritud =falsititseeritu  (IndPrSg2  >falsititseerituma !27_V	et	f	\N
187337	falsititseeritud	?falsititseeritud =falsititseeritud  (ID  >falsititseeritud !41_A	et	f	\N
187346	raskustega	raskustega =raskus  (PlKom  >raskus !11~09_S	et	f	\N
187347	raskustega	"raskus %raske  )US_aS  <raske ;01_A	et	f	\N
187348	raskustega	raskustega =raskus  (PlKom  >raskune !12~10_A	et	f	\N
187352	läbitut	läbitut =läbitu  (SgP  >läbitu !01_AS	et	f	\N
187353	läbitut	"läbitu %läbi  )TU1_vS  <läbima ;27_V	et	f	\N
187413	informeeritusele	informeeritusele =informeerituse  (SgAll  >informeeritus !11_S	et	f	\N
187414	informeeritusele	"informeeritus %informeeri  )TUS1_aS  <informeerima ;28_V	et	f	\N
187430	reklaamiklubi	reklaamiklubi =klubi  (SgN  >reklaami+klubi !17_S	et	f	\N
187431	reklaamiklubi	reklaamiklubi =klubi  (SgG  >reklaami+klubi !17_S	et	f	\N
187432	reklaamiklubi	reklaamiklubi =klubi  (SgP  >reklaami+klubi !17_S	et	f	\N
187437	piilupart	piilupart =par  (SgP  >piilu+pars !14_S	et	f	\N
187438	piilupart	piilupart =part  (SgN  >piilu+part !22_S	et	f	\N
187443	kiuste	kiuste =kius  (PlG  >kius !09_S	et	f	\N
187444	kiuste	kiuste =kiuste  (ID  >kiuste !41_DK	et	f	\N
187445	kiuste	kiuste =kiuste  (PlP  >kiust !22_S	et	f	\N
187479	tegelikuses	tegelikuses =tegelikuse  (SgIn  >tegelikus !11?09_S	et	f	\N
187480	tegelikuses	"tegelikus %tegeliku  )US_aS  <tegelik ;25_A	et	f	\N
187493	hallist	hallist =halli  (SgEl  >hall !22_S	et	f	\N
187494	hallist	hallist =halli  (SgEl  >hall !22_AS	et	f	\N
187495	hallist	hallist =hallis  (SgP  >halline !10_A	et	f	\N
187496	hallist	"halline %halli  )NE_aA  <hall ;22_S	et	f	\N
187521	tendentslikus	tendentslikus =tendentsliku  (SgIn  >tendentslik !25_A	et	f	\N
187522	tendentslikus	tendentslikus =tendentslikus  (SgN  >tendentslikus !11?09_S	et	f	\N
187523	tendentslikus	"tendentslikus %tendentsliku  )US_aS  <tendentslik ;25_A	et	f	\N
187533	tsentraliseerimine	tsentraliseerimine =tsentraliseerimine  (SgN  >tsentraliseerimine !12_S	et	f	\N
187534	tsentraliseerimine	"tsentraliseerimine %tsentraliseeri  )MINE_vS  <tsentraliseerima ;28_V	et	f	\N
187535	joala	?joala =joala  (SgN  >joala !16_S	et	f	\N
187536	joala	?joala =joala  (SgG  >joala !16_S	et	f	\N
187537	joala	?joala =joala  (IndPrPs_  >joalama !29_V	et	f	\N
187538	joala	?joala =joala  (ImpPrSg2  >joalama !29_V	et	f	\N
187550	sobimatuse	sobimatuse =sobimatuse  (SgG  >sobimatus !11?09_S	et	f	\N
187551	sobimatuse	"sobimatus %sobi  )MATUS_aS  <sobima ;27_V	et	f	\N
187554	invaliide	invaliide =invaliide  (PlP  >invaliid !22_S	et	f	\N
187555	invaliide	invaliide =lii  (PlG  >inva+lii !26_S	et	f	\N
187556	invaliide	invaliide =liide  (SgN  >inva+liide !06_S	et	f	\N
187582	aoit	?aoit =aoit  (SgN  >aoit !02_S	et	f	\N
187611	koondumist	koondumist =koondumis  (SgP  >koondumine !12_S	et	f	\N
187612	koondumist	"koondumine %koondu  )MINE_vS  <koonduma ;27_V	et	f	\N
187628	valitsusel	valitsusel =valitsuse  (SgAd  >valitsus !11_S	et	f	\N
187629	valitsusel	"valitsus %valitse  )US_vS  <valitsema ;27_V	et	f	\N
187631	bankrotti	?bankrotti =bankrotti  (SgN  >bankrotti !01_S	et	f	\N
187632	bankrotti	?bankrotti =bankrotti  (SgG  >bankrotti !01_S	et	f	\N
187633	bankrotti	?bankrotti =bankrotti  (SgP  >bankrott !22_S	et	f	\N
187634	bankrotti	?bankrotti =bankrotti  (SgAdt  >bankrott !22_S	et	f	\N
187635	takistanud	takistanud =takista  (PtsPtPs  >takistama !27_V	et	f	\N
187636	takistanud	takistanud =takistanu  (PlN  >takistanu !01_S	et	f	\N
187637	takistanud	"takistanu %takista  )NU_vS  <takistama ;27_V	et	f	\N
187638	takistanud	takistanud =takistanud  (ID  >takistanud !41_A	et	f	\N
187639	takistanud	"takistanud %takista  )NUD_vA  <takistama ;27_V	et	f	\N
187652	oppositsioonis	?oppositsioonis =oppositsiooni  (SgIn  >oppositsiooni !16_S	et	f	\N
187653	oppositsioonis	?oppositsioonis =oppositsiooni  (SgIn  >oppositsioon !22_S	et	f	\N
187654	oppositsioonis	?oppositsioonis =oppositsiooni  (IndIpfSg3  >oppositsioonima !28_V	et	f	\N
187655	oppositsioonis	?oppositsioonis =oppositsioonis  (SgN  >oppositsioonis !09_S	et	f	\N
187657	eekile	?eekile =eekile  (IndPrPs_  >eekilema !27_V	et	f	\N
187658	eekile	?eekile =eekile  (ImpPrSg2  >eekilema !27_V	et	f	\N
187677	kettil	### kettil	et	f	\N
187678	natsionaal	?natsionaal =natsionaa  (SgAd  >natsionaa !26_S	et	f	\N
187679	natsionaal	?natsionaal =natsionaal  (SgN  >natsionaal !22_S	et	f	\N
187680	natsionaal	?natsionaal =onaa  (SgAd  >natsi+onaa !26_S	et	f	\N
187681	natsionaal	?natsionaal =onaal  (SgN  >natsi+onaal !22_S	et	f	\N
187682	natsionaal	?natsionaal =ionaa  (SgAd  >nats+ionaa !26_S	et	f	\N
187683	natsionaal	?natsionaal =ionaal  (SgN  >nats+ionaal !22_S	et	f	\N
187687	aktsioni	?aktsioni =aktsio  (SgTer  >aktsio !01_S	et	f	\N
187688	aktsioni	?aktsioni =aktsioni  (SgN  >aktsioni !16_S	et	f	\N
187689	aktsioni	?aktsioni =aktsioni  (SgG  >aktsion !19~02_S	et	f	\N
187433	levimuusikasaade	levimuusikasaade =saade  (SgN  >levi+muusika+saade !06_S	et	f	\N
187434	levimuusikasaade	levimuusikasaade =saade  (PlP  >levi+muusika+saad !22_S	et	f	\N
187435	vaatajad	vaatajad =vaataja  (PlN  >vaataja !01_S	et	f	\N
187436	vaatajad	"vaataja %vaata  )JA_vS  <vaatama ;29_V	et	f	\N
187449	hävitamist	hävitamist =hävitamis  (SgP  >hävitamine !12_S	et	f	\N
187450	hävitamist	"hävitamine %hävita  )MINE_vS  <hävitama ;27_V	et	f	\N
187461	kadedus	kadedus =kadedus  (SgN  >kadedus !11_S	et	f	\N
187462	kadedus	"kadedus %kadeda  )US_aS  <kade ;02_A	et	f	\N
187463	teistsugusesse	teistsugusesse =sesse  (PlP  >teist+sugu+sess !22_S	et	f	\N
187464	teistsugusesse	teistsugusesse =suguse  (SgIll  >teist+sugune !10_P	et	f	\N
187467	riigipiiri	riigipiiri =piiri  (SgG  >riigi+piir !22_S	et	f	\N
187468	riigipiiri	riigipiiri =piiri  (SgP  >riigi+piir !22_S	et	f	\N
187469	riigipiiri	riigipiiri =piiri  (SgAdt  >riigi+piir !22_S	et	f	\N
187470	elanikutel	?elanikutel =elanikute  (PlAd  >elanikutt !22_S	et	f	\N
187483	mõtlemisviisi	mõtlemisviisi =viisi  (SgG  >mõtlemis+viis !22_S	et	f	\N
187484	mõtlemisviisi	mõtlemisviisi =viisi  (SgP  >mõtlemis+viis !22_S	et	f	\N
187485	mõtlemisviisi	mõtlemisviisi =viisi  (SgAdt  >mõtlemis+viis !22_S	et	f	\N
187488	sallinud	sallinud =salli  (PtsPtPs  >sallima !28_V	et	f	\N
187489	sallinud	sallinud =sallinu  (PlN  >sallinu !01_S	et	f	\N
187490	sallinud	"sallinu %salli  )NU_vS  <sallima ;28_V	et	f	\N
187491	sallinud	sallinud =sallinud  (ID  >sallinud !41_A	et	f	\N
187492	sallinud	"sallinud %salli  )NUD_vA  <sallima ;28_V	et	f	\N
187541	kogukonnast	kogukonnast =kogukonna  (SgEl  >kogukond !22_S	et	f	\N
187542	kogukonnast	kogukonnast =kogukonnas  (SgP  >kogukonnane !12_A	et	f	\N
187543	kogukonnast	"kogukonnane %kogukonna  )NE_aA  <kogukond ;22_S	et	f	\N
187544	kogukonnast	kogukonnast =konna  (SgEl  >kogu+konn !22_S	et	f	\N
187545	kogukonnast	kogukonnast =konnas  (SgP  >kogu+konnane !10_A	et	f	\N
187546	kogukonnast	"kogu+konnane %konna  )NE_aA  <kogu+konn ;22_S	et	f	\N
187572	jazzmuusika	?jazzmuusika =jazzmuusika  (SgN  >jazzmuusika !01_S	et	f	\N
187573	jazzmuusika	?jazzmuusika =jazzmuusika  (SgG  >jazzmuusika !01_S	et	f	\N
187574	jazzmuusika	?jazzmuusika =jazzmuusika  (SgG  >jazzmuusikas !02_A	et	f	\N
187575	jazzmuusika	?jazzmuusika =sika  (SgN  >jazz+muu+sika !16_S	et	f	\N
187576	jazzmuusika	?jazzmuusika =sika  (SgG  >jazz+muu+sika !16_S	et	f	\N
187577	levimuusika	levimuusika =muusika  (SgN  >levi+muusika !01_S	et	f	\N
187578	levimuusika	levimuusika =muusika  (SgG  >levi+muusika !01_S	et	f	\N
187583	torujüri	torujüri =jüri  (SgN  >toru+jüri !17~16_S	et	f	\N
187584	torujüri	torujüri =jüri  (SgG  >toru+jüri !17~16_S	et	f	\N
187585	torujüri	torujüri =jüri  (SgP  >toru+jüri !17_S	et	f	\N
187609	erastamine	erastamine =erastamine  (SgN  >erastamine !12_S	et	f	\N
187610	erastamine	"erastamine %erasta  )MINE_vS  <erastama ;27_V	et	f	\N
187613	kollaste	kollaste =kollas  (PlG  >kollane !10_A	et	f	\N
187614	kollaste	"kollane %kolla  )NE_aA  <kold ;22_S	et	f	\N
187625	rahapoliitika	rahapoliitika =poliitika  (SgN  >raha+poliitika !01_S	et	f	\N
187627	rahapoliitika	rahapoliitika =poliitika  (SgG  >raha+poliitika !01_S	et	f	\N
187669	najta	?najta =najta  (SgN  >najta !16_S	et	f	\N
187670	najta	?najta =najta  (SgG  >najta !16_S	et	f	\N
187671	najta	?najta =najta  (IndPrPs_  >najtama !29_V	et	f	\N
187672	najta	?najta =najta  (ImpPrSg2  >najtama !29_V	et	f	\N
187706	unistuse	unistuse =unistuse  (SgG  >unistus !11_S	et	f	\N
187707	unistuse	"unistus %unista  )US_vS  <unistama ;27_V	et	f	\N
187708	iseseisvusest	iseseisvusest =seisvuse  (SgEl  >ise+seisvus !11~09_S	et	f	\N
187709	iseseisvusest	"ise+seisvus %seisva  )US_aS  <ise+seisev ;02_A	et	f	\N
187710	iseseisvusest	iseseisvusest =seisvuses  (SgP  >ise+seisvusene !12_A	et	f	\N
187711	iseseisvusest	"ise+seisvusene %seisvuse  )NE_aA  <ise+seisvus ;09_S	et	f	\N
187712	iseseisvusest	"ise+seisvusene %seisvuse  )NE_aA  <ise+seisvus ;11_S	et	f	\N
187722	vangle	?vangle =vangle  (SgN  >vangle !06_S	et	f	\N
187724	vangle	?vangle =vangle  (SgG  >vangle !06_S	et	f	\N
187725	vangle	?vangle =vangle  (IndPrPs_  >vanglema !30_V	et	f	\N
187726	vangle	?vangle =vangle  (ImpPrSg2  >vanglema !30_V	et	f	\N
187729	integreerimis	?integreerimis =integreerimi  (SgIn  >integreerim !02_A	et	f	\N
187730	integreerimis	?integreerimis =integreerimis  (SgN  >integreerimis !09_S	et	f	\N
187746	ajutilist	?ajutilist =ajutilis  (SgP  >ajutilis !09_S	et	f	\N
187747	ajutilist	?ajutilist =ajutilis  (SgP  >ajutiline !12_A	et	f	\N
187748	ajutilist	?ajutilist =ajutilist  (SgN  >ajutilist !22_S	et	f	\N
187749	ajutilist	?ajutilist =tili  (SgEl  >aju+tili !17_S	et	f	\N
187750	ajutilist	?ajutilist =tilis  (SgP  >aju+tilis !09_S	et	f	\N
187751	ajutilist	?ajutilist =tilis  (SgP  >aju+tiline !10_A	et	f	\N
187752	ajutilist	?ajutilist =tilist  (SgN  >aju+tilist !22_S	et	f	\N
187765	inerrinne	?inerrinne =inerrinne  (SgN  >inerrinne !02_A	et	f	\N
187766	inerrinne	?inerrinne =inerrinne  (PlP  >inerrinn !22_S	et	f	\N
187778	ühisraha	ühisraha =raha  (SgN  >ühis+raha !17_S	et	f	\N
187779	ühisraha	ühisraha =raha  (SgG  >ühis+raha !17_S	et	f	\N
187780	ühisraha	ühisraha =raha  (SgG  >ühis+rahk !22_S	et	f	\N
187781	ühisraha	ühisraha =raha  (SgP  >ühis+raha !17_S	et	f	\N
187510	norma	?norma =norma  (SgG  >norma !16_S	et	f	\N
187511	norma	?norma =norma  (IndPrPs_  >normama !29_V	et	f	\N
187512	norma	?norma =norma  (ImpPrSg2  >normama !29_V	et	f	\N
187529	läänelike	?läänelike =läänelike  (SgN  >läänelike !12_S	et	f	\N
187530	läänelike	?läänelike =läänelike  (PlG  >läänelik !25_A	et	f	\N
187547	toimis	toimis =toimi  (SgIn  >toim !22_S	et	f	\N
187548	toimis	toimis =toimi  (PlIn  >toim !22_S	et	f	\N
187549	toimis	toimis =toimi  (IndIpfSg3  >toimima !28_V	et	f	\N
187561	valitsevale	valitsevale =valitseva  (SgAll  >valitsev !02_A	et	f	\N
187562	valitsevale	"valitsev %valitse  )V_vA  <valitsema ;27_V	et	f	\N
187567	jazzilikus	?jazzilikus =jazziliku  (SgIn  >jazzilik !25_A	et	f	\N
187568	jazzilikus	?jazzilikus =jazziliku  (IndIpfSg3  >jazzilikuma !27_V	et	f	\N
187569	jazzilikus	?jazzilikus =jazzilikus  (SgN  >jazzilikus !11?09_S	et	f	\N
187615	elamispaigadega	?elamispaigadega =gade  (SgKom  >elamis+pai+gade !16_S	et	f	\N
187616	elamispaigadega	?elamispaigadega =paiga  (PlKom  >elamis+paiga !16_S	et	f	\N
187617	halvema	halvema =halvema  (SgG  >halvem !02_A	et	f	\N
187618	halvema	"halvem %halve  )M_cA  <halb ;22_A	et	f	\N
187640	majandanud	majandanud =majanda  (PtsPtPs  >majandama !27_V	et	f	\N
187641	majandanud	majandanud =majandanu  (PlN  >majandanu !01_S	et	f	\N
187642	majandanud	"majandanu %majanda  )NU_vS  <majandama ;27_V	et	f	\N
187643	majandanud	majandanud =majandanud  (ID  >majandanud !41_A	et	f	\N
187644	majandanud	"majandanud %majanda  )NUD_vA  <majandama ;27_V	et	f	\N
187650	peatamine	peatamine =peatamine  (SgN  >peatamine !12_S	et	f	\N
187651	peatamine	"peatamine %peata  )MINE_vS  <peatama ;27_V	et	f	\N
187660	lausuti	lausuti =lausu  (IndIpfIps  >lausuma !28_V	et	f	\N
187661	lausuti	lausuti =uti  (SgG  >laus+utt !22_S	et	f	\N
187662	lausuti	lausuti =suti  (SgG  >lau+sutt !22_S	et	f	\N
187667	endil	endil =end  (PlAd  >enda !00_P	et	f	\N
187668	endil	endil =end  (PlAd  >ise !00_P	et	f	\N
187673	kütust	kütust =kütu  (SgEl  >kütt !22_S	et	f	\N
187674	kütust	kütust =kütus  (SgP  >kütus !09_S	et	f	\N
187703	elamisvõime	elamisvõime =võime  (SgN  >elamis+võime !06_S	et	f	\N
187704	elamisvõime	elamisvõime =võime  (SgG  >elamis+võime !06_S	et	f	\N
187705	elamisvõime	elamisvõime =võime  (PlP  >elamis+võim !22_S	et	f	\N
187718	likvideeritud	likvideeritud =likvideeri  (PtsPtIps  >likvideerima !28_V	et	f	\N
187719	likvideeritud	likvideeritud =likvideeritu  (PlN  >likvideeritu !01_S	et	f	\N
187720	likvideeritud	"likvideeritu %likvideeri  )TU1_vS  <likvideerima ;28_V	et	f	\N
187721	likvideeritud	likvideeritud =likvideeritud  (ID  >likvideeritud !41_A	et	f	\N
187723	likvideeritud	"likvideeritud %likvideeri  )TUD_vA  <likvideerima ;28_V	et	f	\N
187731	80-nde	### 80-nde	et	f	\N
187741	õppeprotsessi	õppeprotsessi =protsessi  (SgG  >õppe+protsess !22_S	et	f	\N
187742	õppeprotsessi	õppeprotsessi =protsessi  (SgP  >õppe+protsess !22_S	et	f	\N
187743	õppeprotsessi	õppeprotsessi =protsessi  (SgAdt  >õppe+protsess !22_S	et	f	\N
187755	tunnistajate	tunnistajate =tunnistaja  (PlG  >tunnistaja !01_S	et	f	\N
187756	tunnistajate	"tunnistaja %tunnista  )JA_vS  <tunnistama ;27_V	et	f	\N
187767	lmeri	?lmeri =lmeri  (SgN  >lmeri !17_S	et	f	\N
187768	lmeri	?lmeri =lmeri  (SgG  >lmeri !17_S	et	f	\N
187769	lmeri	?lmeri =lmeri  (SgP  >lmeri !17_S	et	f	\N
187770	lmeri	?lmeri =lmeri  (IndPrPs_  >lmerima !27_V	et	f	\N
187771	lmeri	?lmeri =lmeri  (ImpPrSg2  >lmerima !27_V	et	f	\N
187785	tasulistes	tasulistes =tasulis  (PlIn  >tasuline !12_A	et	f	\N
187786	tasulistes	"tasuline %tasu  )LINE_aA  <tasu ;17_S	et	f	\N
187795	nipernaadlikkus	?nipernaadlikkus =nipernaadlikku  (IndIpfSg3  >nipernaadlikkuma !27_V	et	f	\N
187796	nipernaadlikkus	?nipernaadlikkus =nipernaadlikkus  (SgN  >nipernaadlikkus !11~09_S	et	f	\N
187807	barbie	?barbie =barbie  (SgN  >barbie !01_S	et	f	\N
187808	barbie	?barbie =barbie  (SgG  >barbie !01_S	et	f	\N
187831	uutmine	?uutmine =uutmine  (SgN  >uutmine !12?10_S	et	f	\N
187832	uutmine	?uutmine =uutmine  (IndPrPs_  >uutminema !27_V	et	f	\N
187833	uutmine	?uutmine =uutmine  (ImpPrSg2  >uutminema !27_V	et	f	\N
187870	rakendusharidust	rakendusharidust =dust  (SgN  >rakendus+hari+dust !22_S	et	f	\N
187871	rakendusharidust	rakendusharidust =haridus  (SgP  >rakendus+haridus !11_S	et	f	\N
187884	rakenduslikku	rakenduslikku =rakenduslikku  (SgP  >rakenduslik !25_A	et	f	\N
187885	rakenduslikku	rakenduslikku =rakenduslikku  (SgAdt  >rakenduslik !25_A	et	f	\N
187899	näidena	?näidena =näi  (PlEs  >näi !26_S	et	f	\N
187900	sotsiaal-psühholoogi-eriala	sotsiaal-psühholoogi-eriala =ala  (SgN  >sotsiaal-psühholoogi-eri+ala !17_S	et	f	\N
187901	sotsiaal-psühholoogi-eriala	sotsiaal-psühholoogi-eriala =ala  (SgG  >sotsiaal-psühholoogi-eri+ala !17_S	et	f	\N
187902	sotsiaal-psühholoogi-eriala	sotsiaal-psühholoogi-eriala =ala  (SgP  >sotsiaal-psühholoogi-eri+ala !17_S	et	f	\N
187922	probleemseks	probleemseks =probleemse  (SgTr  >probleemne !02_A	et	f	\N
187923	probleemseks	probleemseks =seks  (SgN  >probleem+seks !22_S	et	f	\N
187987	kaevamiste	kaevamiste =kaevamis  (PlG  >kaevamine !12_S	et	f	\N
187988	kaevamiste	"kaevamine %kaeva  )MINE_vS  <kaevama ;29_V	et	f	\N
187995	taasiseseisvuuumisel	?taasiseseisvuuumisel =taasiseseisvuuumise  (SgAd  >taasiseseisvuuumine !10_A	et	f	\N
187563	folkloormuusikat	?folkloormuusikat =folkloormuusika  (SgP  >folkloormuusika !01_S	et	f	\N
187564	folkloormuusikat	?folkloormuusikat =folkloormuusika  (SgP  >folkloormuusikas !02_A	et	f	\N
187565	folkloormuusikat	?folkloormuusikat =loormuusika  (SgP  >folk+loormuusika !01_S	et	f	\N
187566	folkloormuusikat	?folkloormuusikat =loormuusika  (SgP  >folk+loormuusikas !02_A	et	f	\N
187570	laadis	laadis =laadi  (SgIn  >laad !22_S	et	f	\N
187571	laadis	laadis =laadi  (IndIpfSg3  >laadima !28_V	et	f	\N
187586	majanduselus	majanduselus =elu  (SgIn  >majandus+elu !17_S	et	f	\N
187587	majanduselus	majanduselus =elus  (SgN  >majandus+elus !02_A	et	f	\N
187589	200891sellel	sellel =selle  (SgAd  >see !00_P	et	f	\N
187590	200891sellel	sellel =selle  (PlAd  >sell !22_S	et	f	\N
187591	uuendamisega	uuendamisega =uuendamise  (SgKom  >uuendamine !12_S	et	f	\N
187592	uuendamisega	"uuendamine %uuenda  )MINE_vS  <uuendama ;27_V	et	f	\N
187593	pidurdasid	pidurdasid =pidurda  (IndIpfSg2  >pidurdama !27_V	et	f	\N
187594	pidurdasid	pidurdasid =pidurda  (IndIpfPl3  >pidurdama !27_V	et	f	\N
187604	tagastatud	tagastatud =tagasta  (PtsPtIps  >tagastama !27_V	et	f	\N
187605	tagastatud	tagastatud =tagastatu  (PlN  >tagastatu !01_S	et	f	\N
187606	tagastatud	"tagastatu %tagasta  )TU1_vS  <tagastama ;27_V	et	f	\N
187607	tagastatud	tagastatud =tagastatud  (ID  >tagastatud !41_A	et	f	\N
187608	tagastatud	"tagastatud %tagasta  )TUD_vA  <tagastama ;27_V	et	f	\N
187619	üürinikud	?üürinikud =üüriniku  (PlN  >üürinik !25_S	et	f	\N
187620	üürinikud	?üürinikud =üüriniku  (IndPrSg2  >üürinikuma !27_V	et	f	\N
187621	üürinikud	?üürinikud =niku  (PlN  >üüri+niku !16_S	et	f	\N
187622	üürinikud	?üürinikud =niku  (PlN  >üüri+nikk !22_S	et	f	\N
187623	hoiusi	?hoiusi =hoiusi  (ID  >hoiusi !41_D	et	f	\N
187624	hoiusi	?hoiusi =hoiusi  (IndPrPs_  >hoiusima !28_V	et	f	\N
187626	hoiusi	?hoiusi =hoiusi  (ImpPrSg2  >hoiusima !28_V	et	f	\N
187656	kellam	?kellam =kellam  (SgN  >kellam !02_A	et	f	\N
187659	afganistaniga	?afganistaniga =afganistani  (SgKom  >afganistan !02_S	et	f	\N
187663	niikuinii	?niikuinii =niikuinii  (SgN  >niikuinii !26_S	et	f	\N
187664	niikuinii	?niikuinii =niikuinii  (SgG  >niikuinii !26_S	et	f	\N
187665	niikuinii	?niikuinii =kuinii  (SgN  >nii+kuinii !26_S	et	f	\N
187666	niikuinii	?niikuinii =kuinii  (SgG  >nii+kuinii !26_S	et	f	\N
187675	väiksemagi	väiksemagi =väiksema  (SgG^  >väiksem !02_A	et	f	\N
187676	väiksemagi	"väiksem %väikse  )M_cA^  <väike ;10_A	et	f	\N
187697	aitaksid	aitaksid =aita  (KndPrSg2  >aitama !29_V	et	f	\N
187698	aitaksid	aitaksid =aita  (KndPrPl3  >aitama !29_V	et	f	\N
187699	lagunemiseks	lagunemiseks =lagunemise  (SgTr  >lagunemine !12_S	et	f	\N
187700	lagunemiseks	"lagunemine %lagune  )MINE_vS  <lagunema ;27_V	et	f	\N
187738	seltskonda	seltskonda =seltskonda  (SgP  >seltskond !22_S	et	f	\N
187739	seltskonda	seltskonda =seltskonda  (SgAdt  >seltskond !22_S	et	f	\N
187792	katkevad	katkevad =katke  (IndPrPl3  >katkema !27_V	et	f	\N
187793	katkevad	katkevad =katkeva  (PlN  >katkev !02_A	et	f	\N
187794	katkevad	"katkev %katke  )V_vA  <katkema ;27_V	et	f	\N
187797	sotsaiilpsühholoog	?sotsaiilpsühholoog =sotsaiilpsühholoog  (SgN  >sotsaiilpsühholoog !22_S	et	f	\N
187798	sotsaiilpsühholoog	?sotsaiilpsühholoog =aiilpsühholoog  (SgN  >sots+aiilpsühholoog !22_S	et	f	\N
187813	kuuluvaks	kuuluvaks =kuuluva  (SgTr  >kuuluv !02_A	et	f	\N
187814	kuuluvaks	"kuuluv %kuulu  )V_vA  <kuuluma ;27_V	et	f	\N
187815	kuuluvaks	kuuluvaks =vaks  (SgN  >kuulu+vaks !22_S	et	f	\N
187837	läbipaistvus	läbipaistvus =paistvus  (SgN  >läbi+paistvus !11~09_S	et	f	\N
187838	läbipaistvus	"läbi+paistvus %paistva  )US_aS  <läbi+paistev ;02_A	et	f	\N
187839	kuritegu	kuritegu =tegu  (SgN  >kuri+tegu !18_S	et	f	\N
187840	kuritegu	kuritegu =tegu  (SgP  >kuri+tegu !18_S	et	f	\N
187850	peatumist	peatumist =peatumi  (SgEl  >peatum !02_A	et	f	\N
187851	peatumist	"peatum %pea  )TUM2_cA  <pea ;26_S	et	f	\N
187852	peatumist	"peatum %peatu  )M_cA  <peatu ;01_A	et	f	\N
187853	peatumist	peatumist =peatumis  (SgP  >peatumine !12_S	et	f	\N
187854	peatumist	"peatumine %peatu  )MINE_vS  <peatuma ;27_V	et	f	\N
187861	mõõdetud	mõõdetud =mõõde  (PtsPtIps  >mõõtma !34_V	et	f	\N
187862	mõõdetud	mõõdetud =mõõdetu  (PlN  >mõõdetu !01_AS	et	f	\N
187863	mõõdetud	"mõõdetu %mõõde  )TU1_vS  <mõõtma ;34_V	et	f	\N
187864	mõõdetud	mõõdetud =mõõdetud  (ID  >mõõdetud !41_A	et	f	\N
187865	mõõdetud	"mõõdetud %mõõde  )TUD_vA  <mõõtma ;34_V	et	f	\N
187866	ümbernimetus	ümbernimetus =nimetu  (SgIn  >ümber+nimetu !01_A	et	f	\N
187867	ümbernimetus	"ümber+nimetu %nime  )TU2_kA  <ümber+nimi ;20_S	et	f	\N
187868	ümbernimetus	ümbernimetus =nimetus  (SgN  >ümber+nimetus !11_S	et	f	\N
187869	ümbernimetus	"ümber+nimetus %nime  )TUS2_aS  <ümber+nimi ;20_S	et	f	\N
187886	õppetooliga	õppetooliga =liga  (SgN  >õppe+too+liga !17_S	et	f	\N
187887	õppetooliga	õppetooliga =liga  (SgG  >õppe+too+liga !17_S	et	f	\N
187888	õppetooliga	õppetooliga =liga  (SgP  >õppe+too+liga !17_S	et	f	\N
187889	õppetooliga	õppetooliga =tooli  (SgKom  >õppe+tool !22_S	et	f	\N
187914	pärdi	?pärdi =pärdi  (ID  >pärdi !41_D	et	f	\N
187915	pärdi	?pärdi =pärdi  (SgG  >pärt !22_S	et	f	\N
187916	pärdi	?pärdi =pärdi  (SgP  >pärd !22_S	et	f	\N
187690	aktsioni	?aktsioni =aktsioni  (SgG  >aktsioni !16_S	et	f	\N
187691	aktsioni	?aktsioni =aktsioni  (SgP  >aktsion !19_S	et	f	\N
187692	aktsioni	?aktsioni =aktsioni  (SgAdt  >aktsion !19_S	et	f	\N
187693	aktsioni	?aktsioni =aktsioni  (IndPrPs_  >aktsionima !28_V	et	f	\N
187694	aktsioni	?aktsioni =aktsioni  (ImpPrSg2  >aktsionima !28_V	et	f	\N
187695	keskendusid	keskendusid =keskendu  (IndIpfSg2  >keskenduma !27_V	et	f	\N
187696	keskendusid	keskendusid =keskendu  (IndIpfPl3  >keskenduma !27_V	et	f	\N
187713	inkorporeeritud	inkorporeeritud =inkorporeeri  (PtsPtIps  >inkorporeerima !28_V	et	f	\N
187714	inkorporeeritud	inkorporeeritud =inkorporeeritu  (PlN  >inkorporeeritu !01_S	et	f	\N
187715	inkorporeeritud	"inkorporeeritu %inkorporeeri  )TU1_vS  <inkorporeerima ;28_V	et	f	\N
187716	inkorporeeritud	inkorporeeritud =inkorporeeritud  (ID  >inkorporeeritud !41_A	et	f	\N
187717	inkorporeeritud	"inkorporeeritud %inkorporeeri  )TUD_vA  <inkorporeerima ;28_V	et	f	\N
187727	põhjendasid	põhjendasid =põhjenda  (IndIpfSg2  >põhjendama !27_V	et	f	\N
187728	põhjendasid	põhjendasid =põhjenda  (IndIpfPl3  >põhjendama !27_V	et	f	\N
187732	sissetoomine	sissetoomine =ine  (SgN  >sisse+toom+ine !16_S	et	f	\N
187733	sissetoomine	sissetoomine =ine  (SgG  >sisse+toom+ine !16_S	et	f	\N
187734	sissetoomine	sissetoomine =toomine  (SgN  >sisse+toomine !12?10_S	et	f	\N
187735	sissetoomine	"sisse+toomine %toomi  )NE_aA  <sisse+toom ;22_S	et	f	\N
187753	sarjad	sarjad =sarja  (PlN  >sari !24_S	et	f	\N
187754	sarjad	sarjad =sarja  (IndPrSg2  >sarjama !29_V	et	f	\N
187757	obstraktsianism	?obstraktsianism =obstraktsianism  (SgN  >obstraktsianism !22_S	et	f	\N
187759	ühinevad	ühinevad =ühine  (IndPrPl3  >ühinema !27_V	et	f	\N
187760	ühinevad	ühinevad =ühineva  (PlN  >ühinev !02_A	et	f	\N
187761	ühinevad	"ühinev %ühine  )V_vA  <ühinema ;27_V	et	f	\N
187772	liikmest	liikmest =liikme  (SgEl  >liige !05_S	et	f	\N
187773	liikmest	liikmest =liikmes  (SgP  >liikmene !12~10_A	et	f	\N
187774	liikmest	"liikmene %liikme  )NE_aA  <liige ;05_S	et	f	\N
187775	majandireformi	majandireformi =reformi  (SgG  >majandi+reform !22_S	et	f	\N
187776	majandireformi	majandireformi =reformi  (SgP  >majandi+reform !22_S	et	f	\N
187777	majandireformi	majandireformi =reformi  (SgAdt  >majandi+reform !22_S	et	f	\N
187788	õpetamisesüsteem	?õpetamisesüsteem =õpetamisesüsteem  (SgN  >õpetamisesüsteem !22_S	et	f	\N
187824	piiriprobleemi	piiriprobleemi =probleemi  (SgG  >piiri+probleem !22_S	et	f	\N
187825	piiriprobleemi	piiriprobleemi =probleemi  (SgP  >piiri+probleem !22_S	et	f	\N
187826	piiriprobleemi	piiriprobleemi =probleemi  (SgAdt  >piiri+probleem !22_S	et	f	\N
187829	valitsemisel	valitsemisel =valitsemise  (SgAd  >valitsemine !12_S	et	f	\N
187830	valitsemisel	"valitsemine %valitse  )MINE_vS  <valitsema ;27_V	et	f	\N
187834	perstroika	?perstroika =perstroika  (SgN  >perstroika !16_S	et	f	\N
187835	perstroika	?perstroika =perstroika  (SgG  >perstroikas !02_S	et	f	\N
187836	perstroika	?perstroika =perstroika  (SgG  >perstroika !16_S	et	f	\N
187844	gorbatsov	?gorbatsov =gorbatsov  (SgN  >gorbatsov !02_A	et	f	\N
187848	andropovi	?andropovi =andropovi  (ID  >andropovi !41_D	et	f	\N
187849	andropovi	?andropovi =andropovi  (SgG  >andropov !02_A	et	f	\N
187875	püsivust	püsivust =püsivus  (SgP  >püsivus !11_S	et	f	\N
187876	püsivust	"püsivus %püsi  )VUS_aS  <püsima ;27_V	et	f	\N
187877	püsivust	"püsivus %püsiva  )US_aS  <püsiv ;02_A	et	f	\N
187924	suuremateks	suuremateks =suurema  (PlTr  >suurem !02_A	et	f	\N
187925	suuremateks	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
187926	suuremateks	suuremateks =mate  (SgTr  >suure+mate !16_S	et	f	\N
187927	suuremateks	suuremateks =mate  (PlTr  >suure+matt !22_SA	et	f	\N
187944	vapustavas	vapustavas =vapustava  (SgIn  >vapustav !02_A	et	f	\N
187945	vapustavas	"vapustav %vapusta  )V_vA  <vapustama ;27_V	et	f	\N
187946	ürituses	ürituses =ürituse  (SgIn  >üritus !11_S	et	f	\N
187947	ürituses	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
187952	hellitavalt	hellitavalt =hellitava  (SgAbl  >hellitav !02_A	et	f	\N
187953	hellitavalt	"hellitav %hellita  )V_vA  <hellitama ;27_V	et	f	\N
187954	hellitavalt	hellitavalt =hellitavalt  (ID  >hellitavalt !41_D	et	f	\N
187955	hellitavalt	"hellitavalt %hellita  )VALT_mD  <hellitama ;27_V	et	f	\N
187959	tavalisi	tavalisi =tavalisi  (PlP  >tavaline !12_A	et	f	\N
187960	tavalisi	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
187961	kangastel	kangastel =kangas  (PlAd  >kangas !07_S	et	f	\N
187962	kangastel	kangastel =kangas  (PlAd  >kangane !10_A	et	f	\N
187963	kangastel	"kangane %kanga  )NE_aA  <kangas ;07_S	et	f	\N
187964	koputajaid	koputajaid =koputaja  (PlP  >koputaja !01_S	et	f	\N
187965	koputajaid	"koputaja %koputa  )JA_vS  <koputama ;27_V	et	f	\N
187970	sööbinud	sööbinud =sööbi  (PtsPtPs  >sööbima !27_V	et	f	\N
187971	sööbinud	sööbinud =sööbinu  (PlN  >sööbinu !01_S	et	f	\N
187972	sööbinud	"sööbinu %sööbi  )NU_vS  <sööbima ;27_V	et	f	\N
187973	sööbinud	sööbinud =sööbinud  (ID  >sööbinud !41_A	et	f	\N
187974	sööbinud	"sööbinud %sööbi  )NUD_vA  <sööbima ;27_V	et	f	\N
187975	lehvis	lehvis =lehvi  (SgIn  >lehv !22_S	et	f	\N
187976	lehvis	lehvis =lehvi  (IndIpfSg3  >lehvima !28_V	et	f	\N
187981	interrinneir	?interrinneir =interrinneir  (SgN  >interrinneir !19_S	et	f	\N
187763	eluvastuvõttmine	?eluvastuvõttmine =uvõttmine  (SgN  >elu+vast+uvõttmine !12_A	et	f	\N
187764	eluvastuvõttmine	?eluvastuvõttmine =vastuvõttmine  (SgN  >elu+vastuvõttmine !12_A	et	f	\N
187782	taasiseseisvus	taasiseseisvus =seisvu  (IndIpfSg3  >taas+ise+seisvuma !27_V	et	f	\N
187783	taasiseseisvus	taasiseseisvus =seisvus  (SgN  >taas+ise+seisvus !11~09_S	et	f	\N
187784	taasiseseisvus	"taas+ise+seisvus %seisva  )US_aS  <taas+ise+seisev ;02_A	et	f	\N
187787	õpetamissuunad	?õpetamissuunad =õpetamissuuna  (PlN  >õpetamissuuna !16_S	et	f	\N
187799	mänadzerid	?mänadzerid =mänadzeri  (PlN  >mänadzer !02_S	et	f	\N
187800	sailitanud	?sailitanud =sailita  (PtsPtPs  >sailitama !27_V	et	f	\N
187801	sailitanud	?sailitanud =sailitanu  (PlN  >sailitanu !01_S	et	f	\N
187802	sailitanud	?sailitanud =sailitanu  (IndPrSg2  >sailitanuma !27_V	et	f	\N
187803	sailitanud	?sailitanud =sailitanud  (ID  >sailitanud !41_A	et	f	\N
187804	sailitanud	?sailitanud =litanu  (PlN  >sai+litanu !01_S	et	f	\N
187805	mälestus	mälestus =mälestus  (SgN  >mälestus !11_S	et	f	\N
187806	mälestus	"mälestus %mälesta  )US_vS  <mälestama ;27_V	et	f	\N
187816	loost	loost =loo  (SgEl  >lugu !18_S	et	f	\N
187817	loost	loost =loo  (SgEl  >loog !22_S	et	f	\N
187818	loost	loost =loo  (SgEl  >lood !22_S	et	f	\N
187827	tsernenko	?tsernenko =tsernenko  (SgN  >tsernenko !16_S	et	f	\N
187828	tsernenko	?tsernenko =tsernenko  (SgG  >tsernenko !16_S	et	f	\N
187878	demonstreerisid	demonstreerisid =demonstreeri  (IndIpfSg2  >demonstreerima !28_V	et	f	\N
187879	demonstreerisid	demonstreerisid =demonstreeri  (IndIpfPl3  >demonstreerima !28_V	et	f	\N
187893	taandus	taandus =taandu  (IndIpfSg3  >taanduma !27_V	et	f	\N
187894	taandus	taandus =taandus  (SgN  >taandus !11~09_S	et	f	\N
187895	taandus	"taandus %taanda  )US_vS  <taandama ;27_V	et	f	\N
187896	graadid	?graadid =graadi  (PlN  >graadi !16_S	et	f	\N
187897	graadid	?graadid =graadi  (PlN  >graat !22_S	et	f	\N
187898	graadid	?graadid =graadi  (IndPrSg2  >graatima !28_V	et	f	\N
187912	volbriöö	volbriöö =öö  (SgN  >volbri+öö !26_S	et	f	\N
187913	volbriöö	volbriöö =öö  (SgG  >volbri+öö !26_S	et	f	\N
187928	people	?people =people  (SgN  >people !06_S	et	f	\N
187929	people	?people =people  (SgG  >people !06_S	et	f	\N
187930	people	?people =people  (IndPrPs_  >peoplema !30_V	et	f	\N
187931	people	?people =people  (ImpPrSg2  >peoplema !30_V	et	f	\N
187936	saarlaste	saarlaste =saarlas  (PlG  >saarlane !12?10_S	et	f	\N
187937	saarlaste	saarlaste =las  (PlG  >saar+laps !14_S	et	f	\N
187938	saarlaste	saarlaste =laste  (PlP  >saar+last !22_S	et	f	\N
187948	iseseisvusetaotluse	?iseseisvusetaotluse =iseseisvusetaotluse  (SgG  >iseseisvusetaotlus !11~09_S	et	f	\N
187949	iseseisvusetaotluse	?iseseisvusetaotluse =etaotluse  (SgG  >ise+seisvus+etaotlus !11_S	et	f	\N
187950	iseseisvusetaotluse	?iseseisvusetaotluse =seisvusetaotluse  (SgG  >ise+seisvusetaotlus !11~09_S	et	f	\N
187983	kgbga	### kgbga	et	f	\N
187989	intensiivistamise	intensiivistamise =intensiivistamise  (SgG  >intensiivistamine !12_S	et	f	\N
187991	intensiivistamise	"intensiivistamine %intensiivista  )MINE_vS  <intensiivistama ;27_V	et	f	\N
188009	tagajargade	?tagajargade =tagajarga  (PlG  >tagajarga !16_S	et	f	\N
188010	tagajargade	?tagajargade =jarga  (PlG  >taga+jarga !16_S	et	f	\N
188015	surenev	?surenev =surene  (PtsPrPs  >surenema !27_V	et	f	\N
188016	surenev	?surenev =surenev  (SgN  >surenev !02_A	et	f	\N
188028	kogumised	kogumised =kogumise  (PlN  >kogumine !12_S	et	f	\N
188029	kogumised	"kogumine %kogu  )MINE_vS  <koguma ;27_V	et	f	\N
188030	kogumised	"kogumine %kogumi  )NE_aA  <kogum ;02_S	et	f	\N
188031	tekks	?tekks =tekks  (SgN  >tekks !22_S	et	f	\N
188067	juhendasid	juhendasid =juhenda  (IndIpfSg2  >juhendama !27_V	et	f	\N
188068	juhendasid	juhendasid =juhenda  (IndIpfPl3  >juhendama !27_V	et	f	\N
188075	hukkuga	### hukkuga	et	f	\N
188092	luulsas	?luulsas =luulsa  (SgIn  >luulsa !01_S	et	f	\N
188093	luulsas	?luulsas =luulsa  (IndIpfSg3  >luulsama !29_V	et	f	\N
188094	luulsas	?luulsas =luulsas  (SgN  >luulsas !07_S	et	f	\N
188117	taasiseseivumises	?taasiseseivumises =taasiseseivumise  (SgIn  >taasiseseivumine !12_S	et	f	\N
188118	taasiseseivumises	?taasiseseivumises =seivumise  (SgIn  >taas+ise+seivumine !12_S	et	f	\N
188119	taasiseseivumises	?taasiseseivumises =iseseivumise  (SgIn  >taas+iseseivumine !12_S	et	f	\N
188123	kelam	?kelam =kelam  (SgN  >kelam !02_A	et	f	\N
188141	riikigeda	### riikigeda	et	f	\N
188149	taasisesesvumise	?taasisesesvumise =taasisesesvumise  (SgG  >taasisesesvumine !12_S	et	f	\N
188150	taasisesesvumise	?taasisesesvumise =sesvumise  (SgG  >taas+ise+sesvumine !12_S	et	f	\N
188151	taasisesesvumise	?taasisesesvumise =isesesvumise  (SgG  >taas+isesesvumine !12_S	et	f	\N
188157	sinine-must-valge	sinine-must-valge =valge  (SgN  >sinine-must-valge !01_AS	et	f	\N
188159	sinine-must-valge	sinine-must-valge =valge  (SgG  >sinine-must-valge !01_AS	et	f	\N
188186	jeltsini	?jeltsini =jeltsi  (SgTer  >jelts !22_S	et	f	\N
188187	jeltsini	?jeltsini =jeltsini  (SgG  >jeltsin !02_S	et	f	\N
188203	öeda	?öeda =öeda  (SgN  >öeda !16_S	et	f	\N
188204	öeda	?öeda =öeda  (SgG  >öeda !16_S	et	f	\N
188205	öeda	?öeda =öeda  (IndPrPs_  >öedama !29_V	et	f	\N
188206	öeda	?öeda =öeda  (ImpPrSg2  >öedama !29_V	et	f	\N
187789	vahetused	vahetused =vahetuse  (PlN  >vahetus !11_S	et	f	\N
187790	vahetused	"vahetus %vaheta  )US_vS  <vahetama ;27_V	et	f	\N
187791	vahetused	"vahetus %vahe  )TUS2_aS  <vahe ;16_S	et	f	\N
187809	tühjendamine	tühjendamine =tühjendamine  (SgN  >tühjendamine !12_S	et	f	\N
187810	tühjendamine	"tühjendamine %tühjenda  )MINE_vS  <tühjendama ;27_V	et	f	\N
187811	tõigi	tõigi =tõigi  (SgG  >tõik !22_S	et	f	\N
187812	tõigi	tõigi =tõ  (IndIpfSg3^  >tooma !38_V	et	f	\N
187819	pärnapikme	?pärnapikme =pärnapikme  (PlP  >pärnapikm !22_S	et	f	\N
187820	pärnapikme	?pärnapikme =pikme  (SgN  >pärna+pikme !06_S	et	f	\N
187821	pärnapikme	?pärnapikme =pikme  (SgG  >pärna+pikme !06_S	et	f	\N
187822	pärnapikme	?pärnapikme =pikme  (PlP  >pärna+pikm !22_S	et	f	\N
187823	pärnapikme	?pärnapikme =apikme  (PlP  >pärn+apikm !22_S	et	f	\N
187841	madalseisu	madalseisu =seisu  (SgG  >madal+seis !22_S	et	f	\N
187842	madalseisu	madalseisu =seisu  (SgP  >madal+seis !22_S	et	f	\N
187843	madalseisu	madalseisu =seisu  (SgAdt  >madal+seis !22_S	et	f	\N
187845	püütis	?püütis =püüt  (IndIpfSg3  >püütma !34_V	et	f	\N
187846	püütis	?püütis =püüti  (IndIpfSg3  >püütima !28_V	et	f	\N
187847	püütis	?püütis =püütis  (SgN  >püütis !11~09_S	et	f	\N
187855	esimesti	esimesti =mesti  (SgG  >esi+mest !22_S	et	f	\N
187856	esimesti	esimesti =mesti  (SgP  >esi+mest !22_S	et	f	\N
187857	esimesti	esimesti =mesti  (SgAdt  >esi+mest !22_S	et	f	\N
187858	enamkontrollida	enamkontrollida =ida  (SgN  >enam+kont+roll+ida !17_S	et	f	\N
187859	enamkontrollida	enamkontrollida =ida  (SgG  >enam+kont+roll+ida !17_S	et	f	\N
187860	enamkontrollida	enamkontrollida =ida  (SgP  >enam+kont+roll+ida !17_S	et	f	\N
187872	erivärvi	erivärvi =värvi  (SgG  >eri+värv !22_S	et	f	\N
187873	erivärvi	erivärvi =värvi  (SgP  >eri+värv !22_S	et	f	\N
187874	erivärvi	erivärvi =värvi  (SgAdt  >eri+värv !22_S	et	f	\N
187880	rahvapüüed	?rahvapüüed =rahvapüüe  (PlN  >rahvapüüe !26_S	et	f	\N
187881	rahvapüüed	?rahvapüüed =rahvapüüe  (SgP  >rahvapüüe !26_S	et	f	\N
187882	rahvapüüed	?rahvapüüed =rahvapüüed  (SgN  >rahvapüüed !22_S	et	f	\N
187883	rahvapüüed	?rahvapüüed =püüed  (SgN  >rahva+püüed !02_S	et	f	\N
187890	graad	?graad =graa  (PlN  >graa !26_S	et	f	\N
187891	graad	?graad =graa  (SgP  >graa !26_S	et	f	\N
187892	graad	?graad =graad  (SgN  >graad !22_S	et	f	\N
187903	nimetustest	nimetustest =nimetus  (PlEl  >nimetus !11_S	et	f	\N
187904	nimetustest	"nimetus %nimeta  )US_vS  <nimetama ;27_V	et	f	\N
187905	nimetustest	"nimetus %nime  )TUS2_aS  <nimi ;20_S	et	f	\N
187906	nimetustest	nimetustest =tuste  (PlEl  >nime+tust !22_S	et	f	\N
187907	teoloogia	teoloogia =teoloogia  (SgN  >teoloogia !01_S	et	f	\N
187908	teoloogia	teoloogia =teoloogia  (SgG  >teoloogia !01_S	et	f	\N
187909	tähtpäeva	tähtpäeva =päeva  (SgG  >täht+päev !22_S	et	f	\N
187910	tähtpäeva	tähtpäeva =päeva  (SgP  >täht+päev !22_S	et	f	\N
187911	tähtpäeva	tähtpäeva =päeva  (SgAdt  >täht+päev !22_S	et	f	\N
187942	inimketti	inimketti =ketti  (SgP  >inim+kett !22_S	et	f	\N
187943	inimketti	inimketti =ketti  (SgAdt  >inim+kett !22_S	et	f	\N
187951	teadvamusele	?teadvamusele =teadvamuse  (SgAll  >teadvamus !11_S	et	f	\N
187966	mattiseni	?mattiseni =mattiseni  (SgG  >mattisen !19_S	et	f	\N
187967	mattiseni	?mattiseni =mattiseni  (SgP  >mattisen !19_S	et	f	\N
187968	mattiseni	?mattiseni =mattiseni  (SgAdt  >mattisen !19_S	et	f	\N
187969	mattiseni	?mattiseni =iseni  (SgG  >matt+isen !02_S	et	f	\N
187985	pooldasid	pooldasid =poolda  (IndIpfSg2  >pooldama !27_V	et	f	\N
187986	pooldasid	pooldasid =poolda  (IndIpfPl3  >pooldama !27_V	et	f	\N
187993	fosforiidile	fosforiidile =fosforiidi  (SgAll  >fosforiit !22_S	et	f	\N
187994	fosforiidile	fosforiidile =iidi  (SgAll  >fosfor+iid !22_S	et	f	\N
187999	rühmitust	rühmitust =rühmitu  (SgEl  >rühmitu !01_AS	et	f	\N
188000	rühmitust	"rühmitu %rühmi  )TU2_kA  <rühm ;22_S	et	f	\N
188001	rühmitust	rühmitust =rühmitus  (SgP  >rühmitus !11_S	et	f	\N
188002	rühmitust	"rühmitus %rühmita  )US_vS  <rühmitama ;27_V	et	f	\N
188003	rühmitust	"rühmitus %rühmi  )TUS2_aS  <rühm ;22_S	et	f	\N
188023	tekkimiste	tekkimiste =tekkimis  (PlG  >tekkimine !12_S	et	f	\N
188024	tekkimiste	"tekkimine %tekki  )MINE_vS  <tekkima ;27_V	et	f	\N
188025	tekkimiste	"tekkimine %tekki  )MINE_vS  <tekkima ;28_V	et	f	\N
188032	rajajaks	rajajaks =rajaja  (SgTr  >rajaja !01_S	et	f	\N
188033	rajajaks	"rajaja %raja  )JA_vS  <rajama ;27_V	et	f	\N
188034	rajajaks	rajajaks =jaks  (SgN  >raja+jaks !22_S	et	f	\N
188035	saviraari	?saviraari =saviraari  (SgN  >saviraari !16_S	et	f	\N
188036	saviraari	?saviraari =saviraari  (SgG  >saviraari !16_S	et	f	\N
188037	saviraari	?saviraari =saviraari  (SgG  >saviraar !22_S	et	f	\N
188038	saviraari	?saviraari =saviraari  (SgP  >saviraar !22_S	et	f	\N
188039	saviraari	?saviraari =saviraari  (SgAdt  >saviraar !22_S	et	f	\N
188040	saviraari	?saviraari =saviraari  (IndPrPs_  >saviraarima !28_V	et	f	\N
188041	saviraari	?saviraari =saviraari  (ImpPrSg2  >saviraarima !28_V	et	f	\N
188042	saviraari	?saviraari =raari  (SgN  >savi+raari !16_S	et	f	\N
188043	saviraari	?saviraari =raari  (SgG  >savi+raari !16_S	et	f	\N
187917	pärdi	?pärdi =pärdi  (SgAdt  >pärd !22_S	et	f	\N
187918	pärdi	?pärdi =pärdi  (IndPrPs_  >pärtima !28_V	et	f	\N
187919	pärdi	?pärdi =pärdi  (ImpPrSg2  >pärtima !28_V	et	f	\N
187920	luuletajatele	luuletajatele =luuletaja  (PlAll  >luuletaja !01_S	et	f	\N
187921	luuletajatele	"luuletaja %luuleta  )JA_vS  <luuletama ;27_V	et	f	\N
187932	hilarious	?hilarious =hilariou  (SgIn  >hilariou !26_S	et	f	\N
187933	hilarious	?hilarious =hilarious  (SgN  >hilarious !22_S	et	f	\N
187934	murre-küsimus	murre-küsimus =küsimus  (SgN  >murre-küsimus !11_S	et	f	\N
187935	murre-küsimus	"murre-küsimus %küsi  )MUS_vS  <murre-küsima ;27_V	et	f	\N
187939	molotov-ribbentropi	?molotov-ribbentropi =ribbentropi  (SgG  >molotov-ribbentropp !22_S	et	f	\N
187940	molotov-ribbentropi	?molotov-ribbentropi =ribbentropi  (IndPrPs_  >molotov-ribbentroppima !28_V	et	f	\N
187941	molotov-ribbentropi	?molotov-ribbentropi =ribbentropi  (ImpPrSg2  >molotov-ribbentroppima !28_V	et	f	\N
187956	rahvarindesse	rahvarindesse =rinde  (SgIll  >rahva+rinne !06_S	et	f	\N
187957	rahvarindesse	rahvarindesse =rindes  (SgAdt  >rahva+rindene !12_A	et	f	\N
187958	rahvarindesse	"rahva+rindene %rinde  )NE_aA  <rahva+rinne ;06_S	et	f	\N
187977	taasloomise	taasloomise =loomise  (SgG  >taas+loomis !09_S	et	f	\N
187978	taasloomise	taasloomise =loomise  (SgG  >taas+loomine !12?10_S	et	f	\N
187979	taasloomise	"taas+loomine %loo  )MINE_vS  <taas+looma ;38_V	et	f	\N
187980	taasloomise	"taas+loomine %loomi  )NE_aA  <taas+loom ;22_S	et	f	\N
187997	ühtsustunde	ühtsustunde =tunde  (SgG  >ühtsus+tunne !06_S	et	f	\N
187998	ühtsustunde	ühtsustunde =tunde  (PlP  >ühtsus+tund !22_S	et	f	\N
188011	likvideerimiseks	likvideerimiseks =likvideerimise  (SgTr  >likvideerimine !12_S	et	f	\N
188012	likvideerimiseks	"likvideerimine %likvideeri  )MINE_vS  <likvideerima ;28_V	et	f	\N
188076	kiiremas	kiiremas =kiirema  (SgIn  >kiirem !02_A	et	f	\N
188077	kiiremas	"kiirem %kiire  )M_cA  <kiire ;01_A	et	f	\N
188078	kiiremas	"kiirem %kiire  )M_cA  <kiire ;06_AS	et	f	\N
188079	kiiremas	kiiremas =ema  (SgIn  >kiir+ema !17_S	et	f	\N
188080	nüd	### nüd	et	f	\N
188081	pooed	?pooed =pooed  (SgN  >pooed !02_S	et	f	\N
188090	koondusid	koondusid =koondu  (IndIpfSg2  >koonduma !27_V	et	f	\N
188091	koondusid	koondusid =koondu  (IndIpfPl3  >koonduma !27_V	et	f	\N
188113	lammutamine	lammutamine =lammutamine  (SgN  >lammutamine !12_S	et	f	\N
188115	lammutamine	"lammutamine %lammuta  )MINE_vS  <lammutama ;27_V	et	f	\N
188120	parraleelselt	?parraleelselt =parraleelse  (SgAbl  >parraleelne !02_A	et	f	\N
188121	parraleelselt	?parraleelselt =parraleelse  (PlAbl  >parraleels !22_S	et	f	\N
188122	parraleelselt	?parraleelselt =parraleelselt  (ID  >parraleelselt !41_D	et	f	\N
188125	doturimine	?doturimine =doturimine  (SgN  >doturimine !12_S	et	f	\N
188126	doturimine	?doturimine =doturimine  (PlP  >doturimin !19_S	et	f	\N
188129	alkoholipoliitika	alkoholipoliitika =poliitika  (SgN  >alkoholi+poliitika !01_S	et	f	\N
188130	alkoholipoliitika	alkoholipoliitika =poliitika  (SgG  >alkoholi+poliitika !01_S	et	f	\N
188131	piiritust	piiritust =piiritu  (SgEl  >piiritu !01_A	et	f	\N
188132	piiritust	"piiritu %piiri  )TU2_kA  <piir ;22_S	et	f	\N
188133	piiritust	piiritust =piiritus  (SgP  >piiritus !11_S	et	f	\N
188134	piiritust	"piiritus %piiri  )TUS2_aS  <piir ;22_S	et	f	\N
188135	piiritust	piiritust =tust  (SgN  >piiri+tust !22_S	et	f	\N
188142	kutmist	?kutmist =kutmi  (SgEl  >kutmi !16_S	et	f	\N
188143	kutmist	?kutmist =kutmi  (SgEl  >kutm !22_S	et	f	\N
188144	kutmist	?kutmist =kutmis  (SgP  >kutmis !09_S	et	f	\N
188145	kutmist	?kutmist =kutmis  (SgP  >kutmine !12?10_S	et	f	\N
188146	kutmist	?kutmist =kutmist  (SgN  >kutmist !22_S	et	f	\N
188160	suveräänsus	suveräänsus =suveräänsus  (SgN  >suveräänsus !11~09_S	et	f	\N
188161	suveräänsus	"suveräänsus %suveräänse  )US_aS  <suveräänne ;02_A	et	f	\N
188170	eesi	?eesi =eesi  (SgN  >eesi !16_S	et	f	\N
188171	eesi	?eesi =eesi  (SgG  >eesi !16_S	et	f	\N
188172	eesi	?eesi =eesi  (IndPrPs_  >eesima !28_V	et	f	\N
188173	eesi	?eesi =eesi  (ImpPrSg2  >eesima !28_V	et	f	\N
188174	kaasaaitav	kaasaaitav =aita  (PtsPrPs  >kaasa+_aitama !29_V	et	f	\N
188175	kaasaaitav	kaasaaitav =aitav  (SgN  >kaasa+aitav !02_A	et	f	\N
188179	90-ndate	?-ndate =ndate  (SgN  >-ndate !06_S	et	f	\N
188180	90-ndate	?-ndate =ndate  (IndPrPs_  >-ndatema !27_V	et	f	\N
188181	90-ndate	?-ndate =ndate  (ImpPrSg2  >-ndatema !27_V	et	f	\N
188211	hääletusõigus	hääletusõigus =õigus  (SgN  >hääletus+õigus !11~09_S	et	f	\N
188212	hääletusõigus	"hääletus+õigus %õige  )US_aS  <hääletus+õige ;01_A	et	f	\N
188217	langus	langus =langu  (SgIn  >lang !22_S	et	f	\N
188218	langus	langus =langus  (SgN  >langus !11~09_S	et	f	\N
188233	toimuvaga	toimuvaga =toimuva  (SgKom  >toimuv !02_A	et	f	\N
188234	toimuvaga	"toimuv %toimu  )V_vA  <toimuma ;27_V	et	f	\N
188235	väiksemate	väiksemate =väiksema  (PlG  >väiksem !02_A	et	f	\N
188236	väiksemate	"väiksem %väikse  )M_cA  <väike ;10_A	et	f	\N
188237	väiksemate	väiksemate =mate  (SgN  >väikse+mate !16_S	et	f	\N
188238	väiksemate	väiksemate =mate  (SgG  >väikse+mate !16_S	et	f	\N
188239	rahvuskeele	rahvuskeele =kee  (SgAll  >rahvus+kesi !15_S	et	f	\N
188240	rahvuskeele	rahvuskeele =kee  (SgAll  >rahvus+kee !26_S	et	f	\N
187982	interrinneir	?interrinneir =rinneir  (SgN  >inter+rinneir !22_S	et	f	\N
187984	forforiidikaevanduste	?forforiidikaevanduste =forforiidikaevandus  (PlG  >forforiidikaevandus !11_S	et	f	\N
187990	rrlased	?rrlased =rrlase  (PlN  >rrlase !16_S	et	f	\N
187992	rrlased	?rrlased =rrlase  (IndPrSg2  >rrlasema !27_V	et	f	\N
188013	afganistanis	?afganistanis =afganistani  (SgIn  >afganistan !02_S	et	f	\N
188014	afganistanis	?afganistanis =afganistanis  (SgN  >afganistanis !09_S	et	f	\N
188017	fosvoriiti	?fosvoriiti =fosvoriiti  (SgN  >fosvoriiti !16_S	et	f	\N
188018	fosvoriiti	?fosvoriiti =fosvoriiti  (SgG  >fosvoriiti !16_S	et	f	\N
188020	fosvoriiti	?fosvoriiti =fosvoriiti  (SgP  >fosvoriit !22_S	et	f	\N
188021	fosvoriiti	?fosvoriiti =fosvoriiti  (SgAdt  >fosvoriit !22_S	et	f	\N
188026	rahvalikkused	rahvalikkused =rahvalikkuse  (PlN  >rahvalikkus !11~09_S	et	f	\N
188027	rahvalikkused	"rahvalikkus %rahvalikku  )US_aS  <rahvalik ;25_A	et	f	\N
188059	öeseti	?öeseti =öese  (IndIpfIps  >öesema !28_V	et	f	\N
188060	öeseti	?öeseti =öeseti  (ID  >öeseti !41_D	et	f	\N
188061	öeseti	?öeseti =öeseti  (SgG  >öesett !22_S	et	f	\N
188062	öeseti	?öeseti =öeseti  (IndPrPs_  >öesettima !28_V	et	f	\N
188063	öeseti	?öeseti =öeseti  (ImpPrSg2  >öesettima !28_V	et	f	\N
188095	savisaarest	savisaarest =saare  (SgEl  >savi+saar !13_S	et	f	\N
188096	savisaarest	savisaarest =saares  (SgP  >savi+saarene !10_A	et	f	\N
188097	savisaarest	"savi+saarene %saare  )NE_aA  <savi+saar ;13_S	et	f	\N
188106	taotlse	?taotlse =taotlse  (SgN  >taotlse !06_S	et	f	\N
188107	taotlse	?taotlse =taotlse  (SgG  >taotlne !02_A	et	f	\N
188108	taotlse	?taotlse =taotlse  (SgG  >taotlse !06_S	et	f	\N
188109	taotlse	?taotlse =taotlse  (PlP  >taotls !22_S	et	f	\N
188110	taotlse	?taotlse =taotlse  (IndPrPs_  >taotlsema !27_V	et	f	\N
188111	taotlse	?taotlse =taotlse  (ImpPrSg2  >taotlsema !27_V	et	f	\N
188114	peatataks	peatataks =peata  (KndPrIps  >peatama !27_V	et	f	\N
188116	peatataks	peatataks =taks  (SgN  >peata+taks !22_S	et	f	\N
188124	ühtustunde	?ühtustunde =ühtustunde  (PlP  >ühtustund !22_S	et	f	\N
188138	annoll	?annoll =annoll  (SgN  >annoll !22_S	et	f	\N
188162	hääletusi	hääletusi =hääletusi  (PlP  >hääletus !11_S	et	f	\N
188163	hääletusi	"hääletus %hääleta  )US_vS  <hääletama ;27_V	et	f	\N
188164	hääletusi	"hääletus %hääle  )TUS2_aS  <hääl ;13_S	et	f	\N
188176	riigisüsteemi	riigisüsteemi =süsteemi  (SgG  >riigi+süsteem !22_S	et	f	\N
188177	riigisüsteemi	riigisüsteemi =süsteemi  (SgP  >riigi+süsteem !22_S	et	f	\N
188178	riigisüsteemi	riigisüsteemi =süsteemi  (SgAdt  >riigi+süsteem !22_S	et	f	\N
188184	hävenemine	?hävenemine =hävenemine  (SgN  >hävenemine !12_S	et	f	\N
188185	hävenemine	?hävenemine =hävenemine  (PlP  >hävenemin !19_S	et	f	\N
188190	suundamine	?suundamine =suundamine  (SgN  >suundamine !12_S	et	f	\N
188191	suundamine	?suundamine =suundamine  (PlP  >suundamin !19_S	et	f	\N
188201	kehtestamine	kehtestamine =kehtestamine  (SgN  >kehtestamine !12_S	et	f	\N
188202	kehtestamine	"kehtestamine %kehtesta  )MINE_vS  <kehtestama ;27_V	et	f	\N
188219	hullemas	hullemas =hullema  (SgIn  >hullem !02_A	et	f	\N
188220	hullemas	"hullem %hulle  )M_cA  <hull ;22_AS	et	f	\N
188221	hullemas	hullemas =ema  (SgIn  >hull+ema !17_S	et	f	\N
188224	riigikeelest	riigikeelest =keele  (SgEl  >riigi+keel !13_S	et	f	\N
188225	riigikeelest	riigikeelest =keele  (PlEl  >riigi+keeld !22_S	et	f	\N
188226	riigikeelest	riigikeelest =keeles  (SgP  >riigi+keelene !10_A	et	f	\N
188227	riigikeelest	"riigi+keelene %keele  )NE_aA  <riigi+keel ;13_S	et	f	\N
188263	viingute	?viingute =viingu  (PlG  >viingu !01_S	et	f	\N
188264	viingute	?viingute =viingu  (IndPrPl2  >viinguma !27_V	et	f	\N
188265	viingute	?viingute =viingu  (IndPrPl2  >viinkuma !28_V	et	f	\N
188272	viikingute	viikingute =viikingu  (PlG  >viiking !02_S	et	f	\N
188273	viikingute	viikingute =ute  (SgG  >viiking+utt !22_S	et	f	\N
188284	harjumaakonna	harjumaakonna =konna  (SgG  >harju+maa+konn !22_S	et	f	\N
188285	harjumaakonna	harjumaakonna =konna  (SgP  >harju+maa+konn !22_S	et	f	\N
188286	harjumaakonna	harjumaakonna =konna  (SgAdt  >harju+maa+konn !22_S	et	f	\N
188287	harjumaakonna	harjumaakonna =maakonna  (SgG  >harju+maakond !22_S	et	f	\N
188288	künkade	?künkade =künka  (PlG  >künka !16_S	et	f	\N
188289	linnus	linnus =linnu  (SgIn  >lind !22_S	et	f	\N
188290	linnus	linnus =linnu  (PlIn  >linn !22_S	et	f	\N
188291	linnus	linnus =linnus  (SgN  >linnus !09_S	et	f	\N
188340	mattuse	?mattuse =mattuse  (SgG  >mattus !11~09_S	et	f	\N
188341	mattuse	?mattuse =use  (SgN  >matt+use !16_S	et	f	\N
188342	mattuse	?mattuse =use  (SgG  >matt+use !16_S	et	f	\N
188352	haudu	haudu =haudu  (PlP  >haud !22_S	et	f	\N
188353	haudu	haudu =haudu  (IndPrPs_  >hauduma !27_V	et	f	\N
188354	haudu	haudu =haudu  (ImpPrSg2  >hauduma !27_V	et	f	\N
188376	tehtut	tehtut =tehtu  (SgP  >tehtu !01_S	et	f	\N
188377	tehtut	"tehtu %teh  )TU1_vS  <tegema ;28_V	et	f	\N
188382	siguldat	### siguldat	et	f	\N
188385	ekr-1227	?ekr- =ekr  (SgN  >ekr !22_S	et	f	\N
188386	period	?period =perio  (PlN  >perio !01_S	et	f	\N
188387	period	?period =period  (SgN  >period !22_S	et	f	\N
188402	tegutsevaid	tegutsevaid =tegutseva  (PlP  >tegutsev !02_A	et	f	\N
187996	taasiseseisvuuumisel	?taasiseseisvuuumisel =seisvuuumise  (SgAd  >taas+ise+seisvuuumine !10_A	et	f	\N
188004	rrlasi	?rrlasi =rrlasi  (SgN  >rrlasi !17_S	et	f	\N
188005	rrlasi	?rrlasi =rrlasi  (SgG  >rrlasi !17_S	et	f	\N
188006	rrlasi	?rrlasi =rrlasi  (SgP  >rrlasi !17_S	et	f	\N
188007	rrlasi	?rrlasi =rrlasi  (IndPrPs_  >rrlasima !27_V	et	f	\N
188008	rrlasi	?rrlasi =rrlasi  (ImpPrSg2  >rrlasima !27_V	et	f	\N
188019	kaevanduste	kaevanduste =kaevandus  (PlG  >kaevandus !11_S	et	f	\N
188022	kaevanduste	"kaevandus %kaevanda  )US_vS  <kaevandama ;27_V	et	f	\N
188047	molotov-ribbentroppi	?molotov-ribbentroppi =ribbentroppi  (SgP  >molotov-ribbentropp !22_S	et	f	\N
188048	molotov-ribbentroppi	?molotov-ribbentroppi =ribbentroppi  (SgAdt  >molotov-ribbentropp !22_S	et	f	\N
188049	juuridilist	?juuridilist =juuridilis  (SgP  >juuridilis !09_S	et	f	\N
188050	juuridilist	?juuridilist =juuridilis  (SgP  >juuridiline !12_A	et	f	\N
188051	juuridilist	?juuridilist =juuridilist  (SgN  >juuridilist !22_S	et	f	\N
188052	juuridilist	?juuridilist =dili  (SgEl  >juuri+dili !17_S	et	f	\N
188053	juuridilist	?juuridilist =dilis  (SgP  >juuri+dilis !09_S	et	f	\N
188054	juuridilist	?juuridilist =dilis  (SgP  >juuri+diline !10_A	et	f	\N
188055	juuridilist	?juuridilist =dilist  (SgN  >juuri+dilist !22_S	et	f	\N
188056	juuridilist	?juuridilist =idilis  (SgP  >juur+idilis !11_S	et	f	\N
188057	juuridilist	?juuridilist =idilis  (SgP  >juur+idiline !12_A	et	f	\N
188058	juuridilist	?juuridilist =idilist  (SgN  >juur+idilist !22_S	et	f	\N
188064	ettendus	?ettendus =ettendu  (SgIn  >ettendu !01_S	et	f	\N
188065	ettendus	?ettendus =ettendu  (IndIpfSg3  >ettenduma !27_V	et	f	\N
188066	ettendus	?ettendus =ettendus  (SgN  >ettendus !11_S	et	f	\N
188069	isamaaliidu	isamaaliidu =idu  (SgN  >isa+maali+idu !17_S	et	f	\N
188070	isamaaliidu	isamaaliidu =idu  (SgN  >isa+maali+idu !18_S	et	f	\N
188071	isamaaliidu	isamaaliidu =idu  (SgG  >isa+maali+idu !17_S	et	f	\N
188072	isamaaliidu	isamaaliidu =idu  (SgP  >isa+maali+idu !17_S	et	f	\N
188073	isamaaliidu	isamaaliidu =idu  (SgP  >isa+maali+idu !18_S	et	f	\N
188074	isamaaliidu	isamaaliidu =liidu  (SgG  >isa+maa+liit !22_S	et	f	\N
188086	lagunemisega	lagunemisega =lagunemise  (SgKom  >lagunemine !12_S	et	f	\N
188087	lagunemisega	"lagunemine %lagune  )MINE_vS  <lagunema ;27_V	et	f	\N
188101	titme	?titme =titme  (SgN  >titme !06_S	et	f	\N
188102	titme	?titme =titme  (SgG  >titme !06_S	et	f	\N
188103	titme	?titme =titme  (PlP  >titm !22_S	et	f	\N
188104	titme	?titme =titme  (IndPrPs_  >titmema !27_V	et	f	\N
188105	titme	?titme =titme  (ImpPrSg2  >titmema !27_V	et	f	\N
188136	olmekuviin	?olmekuviin =olmekuviin  (SgN  >olmekuviin !22_S	et	f	\N
188137	olmekuviin	?olmekuviin =kuviin  (SgN  >olme+kuviin !22_S	et	f	\N
188139	adekolonnid	?adekolonnid =adekolonni  (PlN  >adekolonn !22_S	et	f	\N
188140	adekolonnid	?adekolonnid =adekolonni  (IndPrSg2  >adekolonnima !28_V	et	f	\N
188152	molotov-ribentropi	?molotov-ribentropi =ribentropi  (SgG  >molotov-ribentropp !22_S	et	f	\N
188153	molotov-ribentropi	?molotov-ribentropi =ribentropi  (IndPrPs_  >molotov-ribentroppima !28_V	et	f	\N
188154	molotov-ribentropi	?molotov-ribentropi =ribentropi  (ImpPrSg2  >molotov-ribentroppima !28_V	et	f	\N
188168	eraldatamiseks	?eraldatamiseks =eraldatamise  (SgTr  >eraldatamine !12_S	et	f	\N
188255	pakkid	### pakkid	et	f	\N
188258	nliitu	?nliitu =nliitu  (SgN  >nliitu !01_A	et	f	\N
188259	nliitu	?nliitu =nliitu  (SgG  >nliitu !01_A	et	f	\N
188260	nliitu	?nliitu =nliitu  (IndPrPs_  >nliituma !27_V	et	f	\N
188261	nliitu	?nliitu =nliitu  (ImpPrSg2  >nliituma !27_V	et	f	\N
188328	siise	?siise =siise  (SgN  >siise !06_S	et	f	\N
188329	siise	?siise =siise  (SgG  >siise !06_S	et	f	\N
188330	siise	?siise =siise  (IndPrPs_  >siisema !28_V	et	f	\N
188331	siise	?siise =siise  (ImpPrSg2  >siisema !28_V	et	f	\N
188335	viikingutel	viikingutel =viikingu  (PlAd  >viiking !02_S	et	f	\N
188336	viikingutel	viikingutel =ute  (SgAd  >viiking+utt !22_S	et	f	\N
188337	viikingutel	viikingutel =ute  (PlAd  >viiking+utt !22_S	et	f	\N
188360	eksisteerivaid	eksisteerivaid =eksisteeriva  (PlP  >eksisteeriv !02_A	et	f	\N
188361	eksisteerivaid	"eksisteeriv %eksisteeri  )V_vA  <eksisteerima ;28_V	et	f	\N
188362	vallandaslinnuse	?vallandaslinnuse =vallandaslinnuse  (SgG  >vallandaslinnus !11~09_S	et	f	\N
188397	aleksandrinimetuse	?aleksandrinimetuse =aleksandrinimetuse  (SgG  >aleksandrinimetus !11?09_S	et	f	\N
188398	aleksandrinimetuse	?aleksandrinimetuse =ksandrinimetuse  (SgG  >ale+ksandrinimetus !11?09_S	et	f	\N
188410	väljaostmisõigused	väljaostmisõigused =õiguse  (PlN  >välja+ostmis+õigus !11~09_S	et	f	\N
188411	väljaostmisõigused	"välja+ostmis+õigus %õige  )US_aS  <välja+ostmis+õige ;01_A	et	f	\N
188414	ue	?ue =ue  (SgN  >ue !26_S	et	f	\N
188415	ue	?ue =ue  (SgG  >ue !26_S	et	f	\N
188427	linnaosakonnad	linnaosakonnad =konna  (PlN  >linna+osa+konn !22_S	et	f	\N
188428	linnaosakonnad	linnaosakonnad =osakonna  (PlN  >linna+osakond !22_S	et	f	\N
188429	kohtn	?kohtn =kohtn  (SgN  >kohtn !22_S	et	f	\N
188457	sobitatud	sobitatud =sobita  (PtsPtIps  >sobitama !27_V	et	f	\N
188458	sobitatud	sobitatud =sobitatu  (PlN  >sobitatu !01_S	et	f	\N
188459	sobitatud	"sobitatu %sobita  )TU1_vS  <sobitama ;27_V	et	f	\N
188460	sobitatud	sobitatud =sobitatud  (ID  >sobitatud !41_A	et	f	\N
188461	sobitatud	"sobitatud %sobita  )TUD_vA  <sobitama ;27_V	et	f	\N
188044	saviraari	?saviraari =raari  (SgG  >savi+raar !22_S	et	f	\N
188045	saviraari	?saviraari =raari  (SgP  >savi+raar !22_S	et	f	\N
188046	saviraari	?saviraari =raari  (SgAdt  >savi+raar !22_S	et	f	\N
188082	doteeris	?doteeris =doteeri  (SgIn  >doteeri !16_S	et	f	\N
188083	doteeris	?doteeris =doteeri  (SgIn  >doteer !22_S	et	f	\N
188084	doteeris	?doteeris =doteeri  (IndIpfSg3  >doteerima !28_V	et	f	\N
188085	doteeris	?doteeris =doteeris  (SgN  >doteeris !09_S	et	f	\N
188088	massiprganisatsioon	?massiprganisatsioon =massiprganisatsioon  (SgN  >massiprganisatsioon !22_S	et	f	\N
188089	massiprganisatsioon	?massiprganisatsioon =iprganisatsioon  (SgN  >mass+iprganisatsioon !22_S	et	f	\N
188098	pr-i	pr-i =pr  (SgG  >pr !xx_Q	et	f	\N
188099	pr-i	pr-i =pr  (SgP  >pr !xx_Q	et	f	\N
188100	pr-i	pr-i =pr  (SgAdt  >pr !xx_Q	et	f	\N
188112	rr-	### rr-	et	f	\N
188127	nutmine	nutmine =nutmine  (SgN  >nutmine !12?10_S	et	f	\N
188128	nutmine	"nutmine %nut  )MINE_vS  <nutma ;35_V	et	f	\N
188147	lagunemine	lagunemine =lagunemine  (SgN  >lagunemine !12_S	et	f	\N
188148	lagunemine	"lagunemine %lagune  )MINE_vS  <lagunema ;27_V	et	f	\N
188155	pikk-hermanile	?pikk-hermanile =hermani  (SgAll  >pikk-herman !02_S	et	f	\N
188156	pikk-hermanile	?pikk-hermanile =nile  (SgN  >pikk-herma+nile !16_S	et	f	\N
188158	pikk-hermanile	?pikk-hermanile =nile  (SgG  >pikk-herma+nile !16_S	et	f	\N
188165	taasiseisvumise	?taasiseisvumise =taasiseisvumise  (SgG  >taasiseisvumine !12_S	et	f	\N
188166	taasiseisvumise	?taasiseisvumise =isvumise  (SgG  >taas+ise+isvumine !12_S	et	f	\N
188167	taasiseisvumise	?taasiseisvumise =iseisvumise  (SgG  >taas+iseisvumine !12_S	et	f	\N
188169	tahask	?tahask =tahask  (SgN  >tahask !02_S	et	f	\N
188182	eraldasid	eraldasid =eralda  (IndIpfSg2  >eraldama !27_V	et	f	\N
188183	eraldasid	eraldasid =eralda  (IndIpfPl3  >eraldama !27_V	et	f	\N
188188	esipresidendiks	esipresidendiks =sidendi  (SgTr  >esi+pre+sidend !02_S	et	f	\N
188189	esipresidendiks	esipresidendiks =presidendi  (SgTr  >esi+president !22_S	et	f	\N
188192	ümberajamine	ümberajamine =ajamine  (SgN  >ümber+ajamine !12_S	et	f	\N
188193	ümberajamine	"ümber+ajamine %ajami  )NE_aA  <ümber+ajam ;02_S	et	f	\N
188194	reziimi	?reziimi =reziimi  (SgN  >reziimi !16_S	et	f	\N
188195	reziimi	?reziimi =reziimi  (SgG  >reziimi !16_S	et	f	\N
188196	reziimi	?reziimi =reziimi  (SgG  >reziim !22_S	et	f	\N
188197	reziimi	?reziimi =reziimi  (SgP  >reziim !22_S	et	f	\N
188198	reziimi	?reziimi =reziimi  (SgAdt  >reziim !22_S	et	f	\N
188199	reziimi	?reziimi =reziimi  (IndPrPs_  >reziimima !28_V	et	f	\N
188200	reziimi	?reziimi =reziimi  (ImpPrSg2  >reziimima !28_V	et	f	\N
188209	kõrgendamine	kõrgendamine =kõrgendamine  (SgN  >kõrgendamine !12_S	et	f	\N
188210	kõrgendamine	"kõrgendamine %kõrgenda  )MINE_vS  <kõrgendama ;27_V	et	f	\N
188222	liberaliseerimine	?liberaliseerimine =liberaliseerimine  (SgN  >liberaliseerimine !12_S	et	f	\N
188223	liberaliseerimine	?liberaliseerimine =liberaliseerimine  (PlP  >liberaliseerimin !19_S	et	f	\N
188242	suhtluskeel	suhtluskeel =kee  (SgAd  >suhtlus+kesi !15_S	et	f	\N
188243	suhtluskeel	suhtluskeel =kee  (SgAd  >suhtlus+kee !26_S	et	f	\N
188244	suhtluskeel	suhtluskeel =keel  (SgN  >suhtlus+keel !13_S	et	f	\N
188250	afganistani	?afganistani =afganista  (SgTer  >afganista !16_S	et	f	\N
188251	afganistani	?afganistani =afganistani  (SgG  >afganistan !02_S	et	f	\N
188252	toiduabi	toiduabi =abi  (SgN  >toidu+abi !17_S	et	f	\N
188253	toiduabi	toiduabi =abi  (SgG  >toidu+abi !17_S	et	f	\N
188254	toiduabi	toiduabi =abi  (SgP  >toidu+abi !17_S	et	f	\N
188256	igapäevaseid	igapäevaseid =päevase  (PlP  >iga+päevane !10_A	et	f	\N
188257	igapäevaseid	"iga+päevane %päeva  )NE_aA  <iga+päev ;22_S	et	f	\N
188269	viikingutele	viikingutele =viikingu  (PlAll  >viiking !02_S	et	f	\N
188270	viikingutele	viikingutele =ute  (SgAll  >viiking+utt !22_S	et	f	\N
188271	viikingutele	viikingutele =ute  (PlAll  >viiking+utt !22_S	et	f	\N
188279	ingvari	?ingvari =ingvari  (SgN  >ingvari !01_S	et	f	\N
188280	ingvari	?ingvari =ingvari  (SgG  >ingvari !01_S	et	f	\N
188281	ingvari	?ingvari =ingvari  (SgG  >ingvar !02_S	et	f	\N
188292	kunstiliselt	kunstiliselt =kunstilise  (SgAbl  >kunstiline !12_A	et	f	\N
188293	kunstiliselt	"kunstiline %kunsti  )LINE_aA  <kunst ;22_S	et	f	\N
188294	kunstiliselt	kunstiliselt =kunstiliselt  (ID  >kunstiliselt !41_D	et	f	\N
188295	kunstiliselt	"kunstiliselt %kunsti  )LISELT_mD  <kunst ;22_S	et	f	\N
188296	kunstiliselt	"kunstiliselt %kunstilise  )LT_mD  <kunstiline ;12_A	et	f	\N
188297	plaatkivist	?plaatkivist =plaatkivi  (SgEl  >plaatkiv !02_A	et	f	\N
188298	plaatkivist	?plaatkivist =plaatkivis  (SgP  >plaatkivis !11_S	et	f	\N
188299	plaatkivist	?plaatkivist =plaatkivist  (SgN  >plaatkivist !22_S	et	f	\N
188300	voorete	?voorete =voore  (PlG  >voore !06_S	et	f	\N
188301	voorete	?voorete =voore  (IndPrPl2  >voorema !27_V	et	f	\N
188302	voorete	?voorete =rete  (SgN  >voo+rete !06_S	et	f	\N
188319	aared	?aared =aare  (IndPrSg2  >aarema !27_V	et	f	\N
188324	jane	?jane =jane  (SgN  >jane !16_S	et	f	\N
188325	jane	?jane =jane  (SgG  >jane !16_S	et	f	\N
188326	jane	?jane =jane  (IndPrPs_  >janema !27_V	et	f	\N
188327	jane	?jane =jane  (ImpPrSg2  >janema !27_V	et	f	\N
188347	ristliku	?ristliku =ristliku  (SgN  >ristliku !01_S	et	f	\N
188207	kestva	kestva =kestva  (SgG  >kestev !02_A	et	f	\N
188208	kestva	"kestev %kest  )V_vA  <kestma ;34_V	et	f	\N
188213	toimusidki	toimusidki =toimu  (IndIpfSg2^  >toimuma !27_V	et	f	\N
188214	toimusidki	toimusidki =toimu  (IndIpfPl3^  >toimuma !27_V	et	f	\N
188215	uuendustega	uuendustega =uuendus  (PlKom  >uuendus !11_S	et	f	\N
188216	uuendustega	"uuendus %uuenda  )US_vS  <uuendama ;27_V	et	f	\N
188228	rahareformi	rahareformi =reformi  (SgG  >raha+reform !22_S	et	f	\N
188229	rahareformi	rahareformi =reformi  (SgP  >raha+reform !22_S	et	f	\N
188230	rahareformi	rahareformi =reformi  (SgAdt  >raha+reform !22_S	et	f	\N
188231	teeninduse	teeninduse =teeninduse  (SgG  >teenindus !11_S	et	f	\N
188232	teeninduse	"teenindus %teeninda  )US_vS  <teenindama ;27_V	et	f	\N
188266	hukkunutele	hukkunutele =hukkunu  (PlAll  >hukkunu !01_S	et	f	\N
188267	hukkunutele	"hukkunu %hukku  )NU_vS  <hukkuma ;27_V	et	f	\N
188268	hukkunutele	"hukkunu %hukku  )NU_vS  <hukkuma ;28_V	et	f	\N
188309	metallesmeid	?metallesmeid =metallesmei  (PlN  >metallesmei !26_S	et	f	\N
188310	metallesmeid	?metallesmeid =metallesmei  (SgP  >metallesmei !26_S	et	f	\N
188311	metallesmeid	?metallesmeid =esme  (PlP  >metall+esme !06_S	et	f	\N
188312	metallesmeid	?metallesmeid =esmei  (PlN  >metall+esmei !26_S	et	f	\N
188313	metallesmeid	?metallesmeid =esmei  (SgP  >metall+esmei !26_S	et	f	\N
188314	metallesmeid	?metallesmeid =esmeid  (SgN  >metall+esmeid !22_S	et	f	\N
188315	metallesmeid	?metallesmeid =lesme  (PlP  >metal+lesme !06_S	et	f	\N
188316	metallesmeid	?metallesmeid =lesmei  (PlN  >metal+lesmei !26_S	et	f	\N
188317	metallesmeid	?metallesmeid =lesmei  (SgP  >metal+lesmei !26_S	et	f	\N
188318	metallesmeid	?metallesmeid =lesmeid  (SgN  >metal+lesmeid !22_S	et	f	\N
188320	leiuti	?leiuti =leiu  (IndIpfIps  >leiuma !27_V	et	f	\N
188321	leiuti	?leiuti =leiuti  (SgN  >leiuti !01_S	et	f	\N
188322	leiuti	?leiuti =leiuti  (SgG  >leiuti !01_S	et	f	\N
188323	leiuti	?leiuti =leiuti  (SgG  >leiut !02_S	et	f	\N
188338	nurgalised	nurgalised =nurgalise  (PlN  >nurgaline !12_A	et	f	\N
188339	nurgalised	"nurgaline %nurga  )LINE_aA  <nurk ;22_S	et	f	\N
188355	tuhka	tuhka =tuhka  (SgP  >tuhk !22_S	et	f	\N
188356	tuhka	tuhka =tuhka  (SgAdt  >tuhk !22_S	et	f	\N
188357	tuhka	tuhka =tuhka  (IndPrPs_  >tuhkama !29_V	et	f	\N
188358	tuhka	tuhka =tuhka  (ImpPrSg2  >tuhkama !29_V	et	f	\N
188363	viikingulaevad	?viikingulaevad =viikingulaeva  (PlN  >viikingulaeva !16_S	et	f	\N
188364	viikingulaevad	?viikingulaevad =ulaeva  (PlN  >viiking+ulaeva !01_S	et	f	\N
188365	viikingulaevad	?viikingulaevad =ingulaeva  (PlN  >viik+ingulaeva !16_S	et	f	\N
188366	riputatud	riputatud =riputa  (PtsPtIps  >riputama !27_V	et	f	\N
188367	riputatud	riputatud =riputatu  (PlN  >riputatu !01_S	et	f	\N
188368	riputatud	"riputatu %riputa  )TU1_vS  <riputama ;27_V	et	f	\N
188369	riputatud	riputatud =riputatud  (ID  >riputatud !41_A	et	f	\N
188370	riputatud	"riputatud %riputa  )TUD_vA  <riputama ;27_V	et	f	\N
188371	sõudmise	sõudmise =sõudmise  (SgG  >sõudmine !12?10_S	et	f	\N
188372	sõudmise	"sõudmine %sõud  )MINE_vS  <sõudma ;34_V	et	f	\N
188373	nahast	nahast =naha  (SgEl  >nahk !22_S	et	f	\N
188374	nahast	nahast =nahas  (SgP  >nahane !10_A	et	f	\N
188375	nahast	"nahane %naha  )NE_aA  <nahk ;22_S	et	f	\N
188378	sõjaretki	sõjaretki =retki  (SgG  >sõja+retk !22_S	et	f	\N
188379	sõjaretki	sõjaretki =retki  (SgP  >sõja+retk !22_S	et	f	\N
188380	sõjaretki	sõjaretki =retki  (SgAdt  >sõja+retk !22_S	et	f	\N
188381	sõjaretki	sõjaretki =retki  (PlP  >sõja+retk !22_S	et	f	\N
188383	liivlastega	liivlastega =liivlas  (PlKom  >liivlane !12?10_S	et	f	\N
188384	liivlastega	liivlastega =las  (PlKom  >liiv+laps !14_S	et	f	\N
188391	muinasajaseset	?muinasajaseset =sese  (SgP  >muinas+aja+sese !16_S	et	f	\N
188399	maalikunsti	maalikunsti =kunsti  (SgG  >maali+kunst !22_S	et	f	\N
188400	maalikunsti	maalikunsti =kunsti  (SgP  >maali+kunst !22_S	et	f	\N
188401	maalikunsti	maalikunsti =kunsti  (SgAdt  >maali+kunst !22_S	et	f	\N
188412	usundivabadus	usundivabadus =vabadus  (SgN  >usundi+vabadus !11_S	et	f	\N
188413	usundivabadus	"usundi+vabadus %vaba  )US_aS  <usundi+vaba ;17_A	et	f	\N
188430	piiskopi	piiskopi =piiskopi  (SgG  >piiskop !22_S	et	f	\N
188431	piiskopi	piiskopi =piiskopi  (SgP  >piiskop !22_S	et	f	\N
188432	piiskopi	piiskopi =piiskopi  (SgAdt  >piiskop !22_S	et	f	\N
188439	troonike	troonike =troonike  (SgN  >troonike !12_S	et	f	\N
188440	troonike	"troonike %trooni  )KE_dS  <troon ;22_S	et	f	\N
188441	troonike	troonike =ike  (SgN  >troon+ike !06_S	et	f	\N
188445	1578a	### 1578a	et	f	\N
188450	poolale	poolale =ale  (SgN  >pool+ale !16_S	et	f	\N
188451	poolale	poolale =ale  (SgG  >pool+ale !16_S	et	f	\N
188474	madalmaad	madalmaad =maa  (PlN  >madal+maa !26_S	et	f	\N
188475	madalmaad	madalmaad =maa  (SgP  >madal+maa !26_S	et	f	\N
188476	novgorad	?novgorad =novgora  (PlN  >novgora !01_S	et	f	\N
188477	karusnahka	karusnahka =nahka  (SgP  >karus+nahk !22_S	et	f	\N
188478	karusnahka	karusnahka =nahka  (SgAdt  >karus+nahk !22_S	et	f	\N
188487	puhtama	puhtama =puhtama  (SgG  >puhtam !02_A	et	f	\N
188488	puhtama	"puhtam %puhta  )M_cA  <puhas ;07_A	et	f	\N
188516	hariduspunktiks	hariduspunktiks =iks  (SgN  >haridus+punkt+iks !22_S	et	f	\N
188241	rahvuskeele	rahvuskeele =keele  (SgG  >rahvus+keel !13_S	et	f	\N
188245	kommunismivastase	kommunismivastase =ase  (SgN  >kommunismi+vast+ase !04_S	et	f	\N
188246	kommunismivastase	kommunismivastase =vastase  (SgG  >kommunismi+vastane !10_AS	et	f	\N
188247	pahameeleprotesti	pahameeleprotesti =protesti  (SgG  >paha+meele+protest !22_S	et	f	\N
188248	pahameeleprotesti	pahameeleprotesti =protesti  (SgP  >paha+meele+protest !22_S	et	f	\N
188249	pahameeleprotesti	pahameeleprotesti =protesti  (SgAdt  >paha+meele+protest !22_S	et	f	\N
188262	tunnistub	?tunnistub =tunnistu  (IndPrSg3  >tunnistuma !27_V	et	f	\N
188274	dateeritud	dateeritud =dateeri  (PtsPtIps  >dateerima !28_V	et	f	\N
188275	dateeritud	dateeritud =dateeritu  (PlN  >dateeritu !01_S	et	f	\N
188276	dateeritud	"dateeritu %dateeri  )TU1_vS  <dateerima ;28_V	et	f	\N
188277	dateeritud	dateeritud =dateeritud  (ID  >dateeritud !41_A	et	f	\N
188278	dateeritud	"dateeritud %dateeri  )TUD_vA  <dateerima ;28_V	et	f	\N
188282	kunigas	### kunigas	et	f	\N
188283	ingvar	?ingvar =ingvar  (SgN  >ingvar !02_S	et	f	\N
188303	vajatud	vajatud =vaja  (PtsPtIps  >vajama !27_V	et	f	\N
188304	vajatud	vajatud =vajatu  (PlN  >vajatu !01_AS	et	f	\N
188305	vajatud	"vajatu %vaja  )TU1_vS  <vajama ;27_V	et	f	\N
188306	vajatud	"vajatu %vaja  )TU2_kA  <vaja ;17_S	et	f	\N
188307	vajatud	vajatud =vajatud  (ID  >vajatud !41_A	et	f	\N
188308	vajatud	"vajatud %vaja  )TUD_vA  <vajama ;27_V	et	f	\N
188332	viikingutelt	viikingutelt =viikingu  (PlAbl  >viiking !02_S	et	f	\N
188333	viikingutelt	viikingutelt =ute  (SgAbl  >viiking+utt !22_S	et	f	\N
188334	viikingutelt	viikingutelt =ute  (PlAbl  >viiking+utt !22_S	et	f	\N
188343	ladusid	ladusid =ladu  (PlP  >ladu !18_S	et	f	\N
188344	ladusid	ladusid =ladu  (IndIpfSg2  >laduma !28_V	et	f	\N
188345	ladusid	ladusid =ladu  (IndIpfPl3  >laduma !28_V	et	f	\N
188346	ladusid	ladusid =ladusi  (PlN  >ladus !02_A	et	f	\N
188359	viikinug	### viikinug	et	f	\N
188388	vaadeldab	?vaadeldab =vaadelda  (IndPrSg3  >vaadeldama !27_V	et	f	\N
188392	rahvavaimuvara	rahvavaimuvara =vara  (SgN  >rahva+vaimu+vara !17_S	et	f	\N
188393	rahvavaimuvara	rahvavaimuvara =vara  (SgG  >rahva+vaimu+vara !17_S	et	f	\N
188394	rahvavaimuvara	rahvavaimuvara =vara  (SgP  >rahva+vaimu+vara !17_S	et	f	\N
188395	eksisteerima	eksisteerima =eksisteeri  (Sup  >eksisteerima !28_V	et	f	\N
188396	eksisteerima	eksisteerima =erima  (SgG  >eks+iste+erim !02_S	et	f	\N
188404	pannus	pannus =pannu  (SgIn  >pannu !16_S	et	f	\N
188405	pannus	"pannu %pan  )NU_vS  <panema ;36_V	et	f	\N
188406	pannus	pannus =pannu  (PlIn  >pand !22_S	et	f	\N
188416	suuruseks	suuruseks =suuruse  (SgTr  >suurus !11~09_S	et	f	\N
188417	suuruseks	"suurus %suur  )US_aS  <suur ;13_A	et	f	\N
188418	suuruseks	suuruseks =suuruse  (SgTr  >suurune !10~12_A	et	f	\N
188419	suuruseks	suuruseks =use  (PlTr  >suur+usk !22_S	et	f	\N
188420	suuruseks	suuruseks =ruse  (PlTr  >suu+rusk !22_S	et	f	\N
188421	heringas	?heringas =heringa  (SgIn  >heringa !01_S	et	f	\N
188422	heringas	?heringas =heringa  (SgIn  >heringas !02_S	et	f	\N
188423	heringas	?heringas =heringas  (SgN  >heringas !02_S	et	f	\N
188424	magitraat	?magitraat =magitraat  (SgN  >magitraat !22_S	et	f	\N
188425	valituseüksus	?valituseüksus =valituseüksu  (IndIpfSg3  >valituseüksuma !27_V	et	f	\N
188426	valituseüksus	?valituseüksus =valituseüksus  (SgN  >valituseüksus !11~09_S	et	f	\N
188435	peenemate	peenemate =peenema  (PlG  >peenem !02_A	et	f	\N
188436	peenemate	"peenem %peene  )M_cA  <peen ;13_A	et	f	\N
188437	peenemate	peenemate =mate  (SgN  >peene+mate !16_S	et	f	\N
188438	peenemate	peenemate =mate  (SgG  >peene+mate !16_S	et	f	\N
188462	veenvaks	veenvaks =veenva  (SgTr  >veenev !02_A	et	f	\N
188463	veenvaks	"veenev %veen  )V_vA  <veenma ;33_V	et	f	\N
188481	mitmepalgeline	mitmepalgeline =palgeline  (SgN  >mitme+palgeline !12_A	et	f	\N
188482	mitmepalgeline	"mitme+palgeline %palge  )LINE_aA  <mitme+pale ;06_S	et	f	\N
188489	ladgolid	?ladgolid =ladgoli  (PlN  >ladgol !02_S	et	f	\N
188497	kaitses	kaitses =kaitse  (IndIpfSg3  >kaitsma !32_V	et	f	\N
188498	kaitses	kaitses =kaitse  (SgIn  >kaitse !06_S	et	f	\N
188499	kaitses	kaitses =kaitse  (IndIpfSg3  >kaitsema !28_V	et	f	\N
188502	käsitöga	?käsitöga =töga  (SgN  >käsi+töga !17_S	et	f	\N
188503	käsitöga	?käsitöga =töga  (SgG  >käsi+töga !17_S	et	f	\N
188504	käsitöga	?käsitöga =töga  (SgP  >käsi+töga !17_S	et	f	\N
188525	toomkirikute	toomkirikute =ute  (SgG  >toom+kirik+utt !22_S	et	f	\N
188526	toomkirikute	toomkirikute =kiriku  (PlG  >toom+kirik !02_S	et	f	\N
188559	paidutus	?paidutus =paidutu  (SgIn  >paidutu !01_AS	et	f	\N
188560	paidutus	?paidutus =paidutu  (IndIpfSg3  >paidutuma !27_V	et	f	\N
188561	paidutus	?paidutus =paidutus  (SgN  >paidutus !11_S	et	f	\N
188562	paidutus	?paidutus =dutu  (SgIn  >pai+dutu !16_S	et	f	\N
188563	paidutus	?paidutus =dutus  (SgN  >pai+dutus !09_S	et	f	\N
188564	valtida	?valtida =valti  (Inf  >valtima !28_V	et	f	\N
188570	võimsuse	võimsuse =võimsuse  (SgG  >võimsus !11~09_S	et	f	\N
188571	võimsuse	"võimsus %võimsa  )US_aS  <võimas ;03_A	et	f	\N
188588	varustus	varustus =varustu  (IndIpfSg3  >varustuma !27_V	et	f	\N
188589	varustus	varustus =varustus  (SgN  >varustus !11_S	et	f	\N
188590	varustus	"varustus %varusta  )US_vS  <varustama ;27_V	et	f	\N
188348	ristliku	?ristliku =ristliku  (SgG  >ristliku !01_S	et	f	\N
188349	ristliku	?ristliku =ristliku  (SgG  >ristlik !25_A	et	f	\N
188350	ristliku	?ristliku =ristliku  (IndPrPs_  >ristlikuma !27_V	et	f	\N
188351	ristliku	?ristliku =ristliku  (ImpPrSg2  >ristlikuma !27_V	et	f	\N
188389	teostatut	teostatut =teostatu  (SgP  >teostatu !01_S	et	f	\N
188390	teostatut	"teostatu %teosta  )TU1_vS  <teostama ;27_V	et	f	\N
188407	releerima	releerima =rima  (SgN  >relee+rima !17_S	et	f	\N
188408	releerima	releerima =rima  (SgG  >relee+rima !17_S	et	f	\N
188409	releerima	releerima =rima  (SgP  >relee+rima !17_S	et	f	\N
188442	schenkenberg	?schenkenberg =schenkenberg  (SgN  >schenkenberg !22_S	et	f	\N
188446	pommitati	pommitati =pommita  (IndIpfIps  >pommitama !27_V	et	f	\N
188447	pommitati	pommitati =tati  (SgG  >pommi+tatt !22_S	et	f	\N
188464	rahvakeeles	rahvakeeles =keele  (SgIn  >rahva+keel !13_S	et	f	\N
188465	rahvakeeles	rahvakeeles =keele  (PlIn  >rahva+keeld !22_S	et	f	\N
188466	ladinakeeles	ladinakeeles =keele  (SgIn  >ladina+keel !13_S	et	f	\N
188467	ladinakeeles	ladinakeeles =keele  (PlIn  >ladina+keeld !22_S	et	f	\N
188470	lübeck	?lübeck =lübeck  (SgN  >lübeck !22_S	et	f	\N
188479	linnaõiguse	linnaõiguse =õiguse  (SgG  >linna+õigus !11~09_S	et	f	\N
188480	linnaõiguse	"linna+õigus %õige  )US_aS  <linna+õige ;01_A	et	f	\N
188485	saksasoost	saksasoost =soo  (SgEl  >saksa+sugu !18_S	et	f	\N
188486	saksasoost	saksasoost =soo  (SgEl  >saksa+soo !26_S	et	f	\N
188500	kohapealese	kohapealese =ese  (SgN  >koha+peal+ese !04_S	et	f	\N
188501	kohapealese	kohapealese =lese  (SgG  >koha+pea+lesk !22_S	et	f	\N
188505	edendajad	edendajad =edendaja  (PlN  >edendaja !01_S	et	f	\N
188506	edendajad	"edendaja %edenda  )JA_vS  <edendama ;27_V	et	f	\N
188509	turuplatsile	turuplatsile =si  (SgAll  >turu+plat+si !26_S	et	f	\N
188510	turuplatsile	turuplatsile =sile  (SgN  >turu+plat+sile !02_A	et	f	\N
188511	turuplatsile	turuplatsile =platsi  (SgAll  >turu+plats !22_S	et	f	\N
188512	kummardamine	kummardamine =kummardamine  (SgN  >kummardamine !12_S	et	f	\N
188513	kummardamine	"kummardamine %kummarda  )MINE_vS  <kummardama ;27_V	et	f	\N
188529	edendaja	edendaja =edendaja  (SgN  >edendaja !01_S	et	f	\N
188530	edendaja	"edendaja %edenda  )JA_vS  <edendama ;27_V	et	f	\N
188531	edendaja	edendaja =edendaja  (SgG  >edendaja !01_S	et	f	\N
188534	eestisoost	eestisoost =soo  (SgEl  >eesti+sugu !18_S	et	f	\N
188535	eestisoost	eestisoost =soo  (SgEl  >eesti+soo !26_S	et	f	\N
188536	kirikukooned	?kirikukooned =kirikukoone  (PlN  >kirikukoone !16_S	et	f	\N
188539	määrasid	määrasid =määra  (PlP  >määr !22_S	et	f	\N
188540	määrasid	määrasid =määra  (IndIpfSg2  >määrama !29_V	et	f	\N
188541	määrasid	määrasid =määra  (IndIpfPl3  >määrama !29_V	et	f	\N
188546	luuleks	luuleks =luule  (SgTr  >luule !06_S	et	f	\N
188547	luuleks	luuleks =luule  (PlTr  >luul !22_S	et	f	\N
188548	puhujad	puhujad =puhuja  (PlN  >puhuja !01_S	et	f	\N
188549	puhujad	"puhuja %puhu  )JA_vS  <puhuma ;27_V	et	f	\N
188550	meditsiinilist	meditsiinilist =meditsiinilis  (SgP  >meditsiiniline !12_A	et	f	\N
188551	meditsiinilist	"meditsiiniline %meditsiini  )LINE_aA  <meditsiin ;22_S	et	f	\N
188575	ühtsus	ühtsus =ühtsus  (SgN  >ühtsus !11~09_S	et	f	\N
188576	ühtsus	"ühtsus %ühtse  )US_aS  <ühtne ;02_A	et	f	\N
188593	pikaajalisteks	pikaajalisteks =ajalis  (PlTr  >pika+ajaline !12_A	et	f	\N
188594	pikaajalisteks	"pika+ajaline %aja  )LINE_aA  <pika+aeg ;22_S	et	f	\N
188597	lehooniga	?lehooniga =lehooni  (SgKom  >lehooni !16_S	et	f	\N
188598	lehooniga	?lehooniga =lehooni  (SgKom  >lehoon !22_S	et	f	\N
188605	tastu	?tastu =tastu  (SgN  >tastu !16_S	et	f	\N
188606	tastu	?tastu =tastu  (SgG  >tastu !16_S	et	f	\N
188607	tastu	?tastu =tastu  (IndPrPs_  >tastuma !27_V	et	f	\N
188609	tastu	?tastu =tastu  (ImpPrSg2  >tastuma !27_V	et	f	\N
188677	gooti	gooti =gooti  (ID  >gooti !41_G	et	f	\N
188678	gooti	gooti =gooti  (SgP  >goot !22_S	et	f	\N
188679	gooti	gooti =gooti  (SgAdt  >goot !22_S	et	f	\N
188697	1582a	### 1582a	et	f	\N
188698	katoliklik	?katoliklik =katoliklik  (SgN  >katoliklik !25_A	et	f	\N
188701	koolitati	koolitati =koolita  (IndIpfIps  >koolitama !27_V	et	f	\N
188702	koolitati	koolitati =tati  (SgG  >kooli+tatt !22_S	et	f	\N
188719	lüübeki	?lüübeki =lüübeki  (SgN  >lüübeki !01_S	et	f	\N
188720	lüübeki	?lüübeki =lüübeki  (SgG  >lüübeki !01_S	et	f	\N
188721	lüübeki	?lüübeki =lüübeki  (SgG  >lüübek !02_S	et	f	\N
188722	lüübeki	?lüübeki =lüübeki  (SgG  >lüübekk !22_S	et	f	\N
188723	lüübeki	?lüübeki =lüübeki  (IndPrPs_  >lüübekkima !28_V	et	f	\N
188724	lüübeki	?lüübeki =lüübeki  (ImpPrSg2  >lüübekkima !28_V	et	f	\N
188732	tundja	tundja =tundja  (SgN  >tundja !01_S	et	f	\N
188733	tundja	"tundja %tund  )JA_vS  <tundma ;34_V	et	f	\N
188734	tundja	tundja =tundja  (SgG  >tundja !01_S	et	f	\N
188740	vallalised	vallalised =vallalise  (PlN  >vallaline !12_AS	et	f	\N
188741	vallalised	"vallaline %valla  )LINE_aA  <vald ;22_S	et	f	\N
188742	holnrike	?holnrike =holnrike  (SgN  >holnrike !12_S	et	f	\N
188743	holnrike	?holnrike =holnrike  (PlG  >holnrik !25_S	et	f	\N
188746	elanikute	?elanikute =elaniku  (IndPrPl2  >elanikuma !27_V	et	f	\N
188403	tegutsevaid	"tegutsev %tegutse  )V_vA  <tegutsema ;27_V	et	f	\N
188433	korraldusel	korraldusel =korralduse  (SgAd  >korraldus !11_S	et	f	\N
188434	korraldusel	"korraldus %korralda  )US_vS  <korraldama ;27_V	et	f	\N
188443	kauplemise	kauplemise =kauplemise  (SgG  >kauplemine !12_S	et	f	\N
188444	kauplemise	"kauplemine %kauple  )MINE_vS  <kauplema ;30_V	et	f	\N
188448	vallutamiseks	vallutamiseks =vallutamise  (SgTr  >vallutamine !12_S	et	f	\N
188449	vallutamiseks	"vallutamine %valluta  )MINE_vS  <vallutama ;27_V	et	f	\N
188452	samastatud	samastatud =samasta  (PtsPtIps  >samastama !27_V	et	f	\N
188453	samastatud	samastatud =samastatu  (PlN  >samastatu !01_S	et	f	\N
188454	samastatud	"samastatu %samasta  )TU1_vS  <samastama ;27_V	et	f	\N
188455	samastatud	samastatud =samastatud  (ID  >samastatud !41_A	et	f	\N
188456	samastatud	"samastatud %samasta  )TUD_vA  <samastama ;27_V	et	f	\N
188471	keskpunktiks	keskpunktiks =iks  (SgN  >kesk+punkt+iks !22_S	et	f	\N
188472	keskpunktiks	keskpunktiks =tiks  (SgN  >kesk+punk+tiks !22_S	et	f	\N
188473	keskpunktiks	keskpunktiks =punkti  (SgTr  >kesk+punkt !22_S	et	f	\N
188490	väljakujunenud	väljakujunenud =kujune  (PtsPtPs  >välja+_kujunema !27_V	et	f	\N
188491	väljakujunenud	väljakujunenud =kujunenu  (PlN  >välja+kujunenu !01_S	et	f	\N
188492	hierarhia	hierarhia =hierarhia  (SgN  >hierarhia !01_S	et	f	\N
188493	hierarhia	hierarhia =hierarhia  (SgG  >hierarhia !01_S	et	f	\N
188494	tsunfti	tsunfti =tsunfti  (SgG  >tsunft !22_S	et	f	\N
188495	tsunfti	tsunfti =tsunfti  (SgP  >tsunft !22_S	et	f	\N
188496	tsunfti	tsunfti =tsunfti  (SgAdt  >tsunft !22_S	et	f	\N
188507	kultuurikeskusteks	kultuurikeskusteks =us  (PlTr  >kultuuri+kesk+uks !14_S	et	f	\N
188508	kultuurikeskusteks	kultuurikeskusteks =keskus  (PlTr  >kultuuri+keskus !11~09_S	et	f	\N
188532	forselius	?forselius =forseliu  (SgIn  >forseliu !01_S	et	f	\N
188533	forselius	?forselius =forselius  (SgN  >forselius !11_S	et	f	\N
188572	peapiiskopi	peapiiskopi =piiskopi  (SgG  >pea+piiskop !22_S	et	f	\N
188573	peapiiskopi	peapiiskopi =piiskopi  (SgP  >pea+piiskop !22_S	et	f	\N
188574	peapiiskopi	peapiiskopi =piiskopi  (SgAdt  >pea+piiskop !22_S	et	f	\N
188577	kahurilika	?kahurilika =kahurilika  (SgN  >kahurilika !01_S	et	f	\N
188578	kahurilika	?kahurilika =kahurilika  (SgG  >kahurilika !01_S	et	f	\N
188580	kahurilika	?kahurilika =kahurilika  (SgG  >kahurilikas !02_A	et	f	\N
188582	kahurilika	?kahurilika =ilika  (SgN  >kahur+ilika !01_S	et	f	\N
188583	kahurilika	?kahurilika =ilika  (SgG  >kahur+ilika !01_S	et	f	\N
188584	kahurilika	?kahurilika =ilika  (SgG  >kahur+ilikas !02_S	et	f	\N
188585	kahurilika	?kahurilika =rilika  (SgN  >kahu+rilika !01_S	et	f	\N
188586	kahurilika	?kahurilika =rilika  (SgG  >kahu+rilika !01_S	et	f	\N
188587	kahurilika	?kahurilika =rilika  (SgG  >kahu+rilikas !02_S	et	f	\N
188595	innustust	innustust =innustus  (SgP  >innustus !11_S	et	f	\N
188596	innustust	"innustus %innusta  )US_vS  <innustama ;27_V	et	f	\N
188599	võidus	võidus =võidu  (SgIn  >võidu !01_S	et	f	\N
188600	võidus	"võidu %või  )TU1_vS  <võima ;37_V	et	f	\N
188601	võidus	võidus =võidu  (SgIn  >võit !22_S	et	f	\N
188602	võidus	võidus =võidu  (IndIpfSg3  >võiduma !27_V	et	f	\N
188603	võidus	võidus =võidus  (SgN  >võidus !11~09_S	et	f	\N
188604	võidus	"võidus %või  )TUS1_aS  <võima ;37_V	et	f	\N
188612	jätmine	jätmine =jätmine  (SgN  >jätmine !12?10_S	et	f	\N
188613	jätmine	"jätmine %jät  )MINE_vS  <jätma ;35_V	et	f	\N
188622	lihtsama	lihtsama =lihtsama  (SgG  >lihtsam !02_A	et	f	\N
188623	lihtsama	"lihtsam %lihtsa  )M_cA  <lihtne ;02_A	et	f	\N
188628	kuivatamine	kuivatamine =kuivatamine  (SgN  >kuivatamine !12_S	et	f	\N
188629	kuivatamine	"kuivatamine %kuivata  )MINE_vS  <kuivatama ;27_V	et	f	\N
188630	kangasid	?kangasid =kanga  (PlP  >kanga !16_S	et	f	\N
188631	kangasid	?kangasid =kanga  (IndIpfSg2  >kangama !29_V	et	f	\N
188632	kangasid	?kangasid =kanga  (IndIpfPl3  >kangama !29_V	et	f	\N
188633	hülgerasva	hülgerasva =rasva  (SgG  >hülge+rasv !22_S	et	f	\N
188634	hülgerasva	hülgerasva =rasva  (SgP  >hülge+rasv !22_S	et	f	\N
188635	hülgerasva	hülgerasva =rasva  (SgAdt  >hülge+rasv !22_S	et	f	\N
188647	matsmaarahvas	?matsmaarahvas =matsmaarahva  (SgIn  >matsmaarahva !16_S	et	f	\N
188649	vaehl	?vaehl =vaehl  (SgN  >vaehl !22_S	et	f	\N
188650	visitat	### visitat	et	f	\N
188667	frantsihlased	?frantsihlased =frantsihlase  (PlN  >frantsihlane !12_S	et	f	\N
188680	stiilils	?stiilils =stiilils  (SgN  >stiilils !22_S	et	f	\N
188688	russowi	?russowi =russowi  (SgN  >russowi !01_S	et	f	\N
188689	russowi	?russowi =russowi  (SgG  >russowi !01_S	et	f	\N
188714	keskaega	keskaega =aega  (SgP  >kesk+aeg !22_S	et	f	\N
188715	keskaega	keskaega =aega  (SgAdt  >kesk+aeg !22_S	et	f	\N
188749	arvel	arvel =arve  (SgAd  >arve !06_S	et	f	\N
188750	arvel	arvel =arve  (PlAd  >arv !22_S	et	f	\N
188751	arvel	arvel =arvel  (ID  >arvel !41_K	et	f	\N
188763	killustatud	killustatud =killusta  (PtsPtIps  >killustama !27_V	et	f	\N
188764	killustatud	killustatud =killustatu  (PlN  >killustatu !01_S	et	f	\N
188765	killustatud	"killustatu %killusta  )TU1_vS  <killustama ;27_V	et	f	\N
188766	killustatud	killustatud =killustatud  (ID  >killustatud !41_A	et	f	\N
188767	killustatud	"killustatud %killusta  )TUD_vA  <killustama ;27_V	et	f	\N
188468	matmine	matmine =matmine  (SgN  >matmine !12?10_S	et	f	\N
188469	matmine	"matmine %mat  )MINE_vS  <matma ;35_V	et	f	\N
188483	maamatsideks	maamatsideks =matsi  (PlTr  >maa+mats !22_S	et	f	\N
188484	maamatsideks	maamatsideks =matsi  (PlTr  >maa+mats !22_SA	et	f	\N
188514	jutlustuse	jutlustuse =jutlustuse  (SgG  >jutlustus !11_S	et	f	\N
188515	jutlustuse	"jutlustus %jutlusta  )US_vS  <jutlustama ;27_V	et	f	\N
188519	wandradt-koelli	?wandradt-koelli =koelli  (ID  >wandradt-koelli !41_D	et	f	\N
188520	wandradt-koelli	?wandradt-koelli =koelli  (SgG  >wandradt-koell !22_S	et	f	\N
188521	wandradt-koelli	?wandradt-koelli =koelli  (SgP  >wandradt-koell !22_S	et	f	\N
188522	wandradt-koelli	?wandradt-koelli =koelli  (SgAdt  >wandradt-koell !22_S	et	f	\N
188523	wandradt-koelli	?wandradt-koelli =koelli  (IndPrPs_  >wandradt-koellima !28_V	et	f	\N
188524	wandradt-koelli	?wandradt-koelli =koelli  (ImpPrSg2  >wandradt-koellima !28_V	et	f	\N
188527	koolitamiseks	koolitamiseks =koolitamise  (SgTr  >koolitamine !12_S	et	f	\N
188528	koolitamiseks	"koolitamine %koolita  )MINE_vS  <koolitama ;27_V	et	f	\N
188542	gootistiilis	?gootistiilis =gootistiili  (SgIn  >gootistiili !16_S	et	f	\N
188543	gootistiilis	?gootistiilis =gootistiili  (SgIn  >gootistiil !22_S	et	f	\N
188544	gootistiilis	?gootistiilis =gootistiili  (IndIpfSg3  >gootistiilima !28_V	et	f	\N
188545	gootistiilis	?gootistiilis =gootistiilis  (SgN  >gootistiilis !09_S	et	f	\N
188568	liiviordu	liiviordu =ordu  (SgN  >liivi+ordu !16_S	et	f	\N
188569	liiviordu	liiviordu =ordu  (SgG  >liivi+ordu !16_S	et	f	\N
188579	onekool	?onekool =onekoo  (SgAd  >onekoo !26_S	et	f	\N
188581	onekool	?onekool =onekool  (SgN  >onekool !22_S	et	f	\N
188618	linnaõigus	linnaõigus =õigus  (SgN  >linna+õigus !11~09_S	et	f	\N
188619	linnaõigus	"linna+õigus %õige  )US_aS  <linna+õige ;01_A	et	f	\N
188624	asustuse	asustuse =asustuse  (SgG  >asustus !11_S	et	f	\N
188625	asustuse	"asustus %asusta  )US_vS  <asustama ;27_V	et	f	\N
188626	hinnaliseks	hinnaliseks =hinnalise  (SgTr  >hinnaline !12_A	et	f	\N
188627	hinnaliseks	"hinnaline %hinna  )LINE_aA  <hind ;22_S	et	f	\N
188636	kanepist	kanepist =kanepi  (SgEl  >kanep !02_S	et	f	\N
188637	kanepist	kanepist =kanepis  (SgP  >kanepine !12_A	et	f	\N
188638	kanepist	"kanepine %kanepi  )NE_aA  <kanep ;02_S	et	f	\N
188643	peatamiseks	peatamiseks =peatamise  (SgTr  >peatamine !12_S	et	f	\N
188644	peatamiseks	"peatamine %peata  )MINE_vS  <peatama ;27_V	et	f	\N
188656	tegelesdi	?tegelesdi =tegelesdi  (SgG  >tegelesd !22_S	et	f	\N
188657	tegelesdi	?tegelesdi =tegelesdi  (SgP  >tegelesd !22_S	et	f	\N
188658	tegelesdi	?tegelesdi =tegelesdi  (SgAdt  >tegelesd !22_S	et	f	\N
188659	tegelesdi	?tegelesdi =tegelesdi  (IndPrPs_  >tegelesdima !28_V	et	f	\N
188660	tegelesdi	?tegelesdi =tegelesdi  (ImpPrSg2  >tegelesdima !28_V	et	f	\N
188664	õptasid	?õptasid =õpta  (PlP  >õpta !16_S	et	f	\N
188665	õptasid	?õptasid =õpta  (IndIpfSg2  >õptama !29_V	et	f	\N
188666	õptasid	?õptasid =õpta  (IndIpfPl3  >õptama !29_V	et	f	\N
188668	begiinid	?begiinid =begiini  (PlN  >begiini !16_S	et	f	\N
188669	begiinid	?begiinid =begiini  (PlN  >begiin !22_S	et	f	\N
188670	begiinid	?begiinid =begiini  (IndPrSg2  >begiinima !28_V	et	f	\N
188681	kaunistamine	kaunistamine =kaunistamine  (SgN  >kaunistamine !12_S	et	f	\N
188682	kaunistamine	"kaunistamine %kaunista  )MINE_vS  <kaunistama ;27_V	et	f	\N
188686	uhkem	uhkem =uhkem  (SgN  >uhkem !02_A	et	f	\N
188687	uhkem	"uhkem %uhke  )M_cA  <uhke ;01_A	et	f	\N
188694	17saj	### 17saj	et	f	\N
188699	gregooriuse	?gregooriuse =gregooriuse  (SgG  >gregoorius !11_S	et	f	\N
188700	1585a	### 1585a	et	f	\N
188703	misjonäär	?misjonäär =misjonäär  (SgN  >misjonäär !22_S	et	f	\N
188704	misjonäär	?misjonäär =jonäär  (SgN  >mis+jonäär !22_S	et	f	\N
188707	1625a	### 1625a	et	f	\N
188711	vikingiajast	?vikingiajast =vikingiaja  (SgEl  >vikingiaja !01_S	et	f	\N
188712	vikingiajast	?vikingiajast =vikingiaja  (SgEl  >vikingiajas !02_A	et	f	\N
188713	vikingiajast	?vikingiajast =vikingiajas  (SgP  >vikingiajane !12_A	et	f	\N
188716	kaitsetonid	?kaitsetonid =kaitsetoni  (PlN  >kaitseton !19_S	et	f	\N
188717	kaitsetonid	?kaitsetonid =toni  (PlN  >kaitse+toni !17_S	et	f	\N
188718	kaitsetonid	?kaitsetonid =tsetoni  (PlN  >kai+tseton !02_S	et	f	\N
188737	rikkastest	?rikkastest =rikkas  (PlEl  >rikkas !07_S	et	f	\N
188738	rikkastest	?rikkastest =rikkas  (PlEl  >rikkane !12~10_A	et	f	\N
188739	rikkastest	?rikkastest =rikkastes  (SgP  >rikkastene !12_A	et	f	\N
188744	russovi	?russovi =russovi  (ID  >russovi !41_D	et	f	\N
188745	russovi	?russovi =russovi  (SgG  >russov !02_A	et	f	\N
188768	omavahelistes	omavahelistes =vahelis  (PlIn  >oma+vaheline !12_A	et	f	\N
188769	omavahelistes	"oma+vaheline %vahe  )LINE_aA  <oma+vahe ;16_S	et	f	\N
188772	maksmist	maksmist =maksmis  (SgP  >maksmine !12?10_S	et	f	\N
188773	maksmist	"maksmine %maks  )MINE_vS  <maksma ;32_V	et	f	\N
188785	7-aastane	-aastane =aastane  (SgN  >-aastane !12~10_A	et	f	\N
188786	7-aastane	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
188794	eduta	eduta =edu  (SgAb  >edu !17_S	et	f	\N
188795	eduta	eduta =eduta  (IndPrPs_  >edutama !27_V	et	f	\N
188796	eduta	eduta =eduta  (ImpPrSg2  >edutama !27_V	et	f	\N
188797	täitmist	täitmist =täitmis  (SgP  >täitmine !12?10_S	et	f	\N
188517	hariduspunktiks	hariduspunktiks =tiks  (SgN  >haridus+punk+tiks !22_S	et	f	\N
188518	hariduspunktiks	hariduspunktiks =punkti  (SgTr  >haridus+punkt !22_S	et	f	\N
188537	sündsuse	sündsuse =sündsuse  (SgG  >sündsus !11~09_S	et	f	\N
188538	sündsuse	"sündsus %sündsa  )US_aS  <sünnis ;03_A	et	f	\N
188552	keskaegesse	?keskaegesse =keskaege  (PlIll  >keskaek !22_S	et	f	\N
188553	keskaegesse	?keskaegesse =keskaeges  (SgAdt  >keskaegene !12_A	et	f	\N
188554	keskaegesse	?keskaegesse =keskaegesse  (SgG  >keskaegesne !02_A	et	f	\N
188555	keskaegesse	?keskaegesse =keskaegesse  (PlP  >keskaegess !22_S	et	f	\N
188556	keskaegesse	?keskaegesse =aege  (PlIll  >kesk+aek !22_S	et	f	\N
188557	keskaegesse	?keskaegesse =aegesse  (SgG  >kesk+aegesne !02_A	et	f	\N
188558	keskaegesse	?keskaegesse =aegesse  (PlP  >kesk+aegess !22_S	et	f	\N
188565	tuleohtu	tuleohtu =ohtu  (ID  >tule+ohtu !41_A	et	f	\N
188566	tuleohtu	tuleohtu =ohtu  (SgP  >tule+oht !22_S	et	f	\N
188567	tuleohtu	tuleohtu =ohtu  (SgAdt  >tule+oht !22_S	et	f	\N
188620	moodustusid	moodustusid =moodustu  (IndIpfSg2  >moodustuma !27_V	et	f	\N
188621	moodustusid	moodustusid =moodustu  (IndIpfPl3  >moodustuma !27_V	et	f	\N
188645	omaduse	omaduse =omaduse  (SgG  >omadus !11_S	et	f	\N
188646	omaduse	"omadus %oma  )US_aS  <oma ;17_A	et	f	\N
188651	protokollides	protokollides =protokolli  (PlIn  >protokoll !22_S	et	f	\N
188652	protokollides	protokollides =protokolli  (Ger  >protokollima !28_V	et	f	\N
188653	protokollides	protokollides =kolli  (PlIn  >proto+koll !22_S	et	f	\N
188654	paiksus	paiksus =paiksus  (SgN  >paiksus !11~09_S	et	f	\N
188655	paiksus	"paiksus %paikse  )US_aS  <paikne ;02_A	et	f	\N
188661	missiooni	missiooni =missiooni  (SgG  >missioon !22_S	et	f	\N
188662	missiooni	missiooni =missiooni  (SgP  >missioon !22_S	et	f	\N
188663	missiooni	missiooni =missiooni  (SgAdt  >missioon !22_S	et	f	\N
188671	begardid	?begardid =begardi  (PlN  >begardi !01_S	et	f	\N
188672	begardid	?begardid =begardi  (PlN  >begard !02_S	et	f	\N
188673	begardid	?begardid =begardi  (PlN  >begart !22_S	et	f	\N
188674	begardid	?begardid =begardi  (IndPrSg2  >begartima !28_V	et	f	\N
188690	agressivseks	?agressivseks =agressivse  (SgTr  >agressivne !02_A	et	f	\N
188691	agressivseks	?agressivseks =agressivse  (PlTr  >agressivs !22_S	et	f	\N
188708	1629a	### 1629a	et	f	\N
188709	altmarki	altmarki =marki  (SgP  >alt+mark !22_S	et	f	\N
188710	altmarki	altmarki =marki  (SgAdt  >alt+mark !22_S	et	f	\N
188727	raejuhatus	raejuhatus =juhatu  (SgIn  >rae+juhatu !01_AS	et	f	\N
188728	raejuhatus	"rae+juhatu %juha  )TU2_kA  <rae+juha ;17_S	et	f	\N
188729	raejuhatus	raejuhatus =juhatus  (SgN  >rae+juhatus !11_S	et	f	\N
188730	raejuhatus	"rae+juhatus %juha  )TUS2_aS  <rae+juha ;17_S	et	f	\N
188731	sundik	?sundik =sundik  (SgN  >sundik !02_S	et	f	\N
188735	ühendused	ühendused =ühenduse  (PlN  >ühendus !11_S	et	f	\N
188736	ühendused	"ühendus %ühenda  )US_vS  <ühendama ;27_V	et	f	\N
188760	feodaalselt	feodaalselt =feodaalse  (SgAbl  >feodaalne !02_A	et	f	\N
188761	feodaalselt	feodaalselt =feodaalselt  (ID  >feodaalselt !41_D	et	f	\N
188762	feodaalselt	"feodaalselt %feodaalse  )LT_mD  <feodaalne ;02_A	et	f	\N
188774	põhjendamatu	põhjendamatu =põhjendamatu  (SgN  >põhjendamatu !01_A	et	f	\N
188775	põhjendamatu	"põhjendamatu %põhjenda  )MATU_vA  <põhjendama ;27_V	et	f	\N
188776	põhjendamatu	põhjendamatu =põhjendamatu  (SgG  >põhjendamatu !01_A	et	f	\N
188787	taaniga	?taaniga =taani  (SgKom  >taani !16_S	et	f	\N
188788	taaniga	?taaniga =taani  (SgKom  >taan !22_S	et	f	\N
188789	1661a	### 1661a	et	f	\N
188790	oliwa	?oliwa =oliwa  (SgN  >oliwa !01_S	et	f	\N
188791	oliwa	?oliwa =oliwa  (SgG  >oliwa !01_S	et	f	\N
188792	kaotajateks	kaotajateks =kaotaja  (PlTr  >kaotaja !01_S	et	f	\N
188793	kaotajateks	"kaotaja %kaota  )JA_vS  <kaotama ;27_V	et	f	\N
188803	kättesaamatuks	kättesaamatuks =tuks  (SgN  >kätte+saama+tuks !22_S	et	f	\N
188804	kättesaamatuks	kättesaamatuks =saamatu  (SgTr  >kätte+saamatu !01_A	et	f	\N
188805	kättesaamatuks	"kätte+saamatu %saama  )TU2_kA  <kätte+saam ;22_S	et	f	\N
188806	rahas	rahas =raha  (SgIn  >raha !17_S	et	f	\N
188807	rahas	rahas =raha  (SgIn  >rahk !22_S	et	f	\N
188821	säilitajateks	säilitajateks =säilitaja  (PlTr  >säilitaja !01_S	et	f	\N
188822	säilitajateks	"säilitaja %säilita  )JA_vS  <säilitama ;27_V	et	f	\N
188922	religiosset	?religiosset =religiosse  (SgP  >religiosne !02_A	et	f	\N
188933	katekismusest	katekismusest =katekismuse  (SgEl  >katekismus !11~09_S	et	f	\N
188934	katekismusest	katekismusest =katekismuses  (SgP  >katekismusene !12_A	et	f	\N
188935	katekismusest	"katekismusene %katekismuse  )NE_aA  <katekismus ;09_S	et	f	\N
188936	katekismusest	"katekismusene %katekismuse  )NE_aA  <katekismus ;11_S	et	f	\N
188951	allutamise	allutamise =allutamise  (SgG  >allutamine !12_S	et	f	\N
188952	allutamise	"allutamine %alluta  )MINE_vS  <allutama ;27_V	et	f	\N
188963	henrikuks	?henrikuks =henriku  (SgTr  >henriku !01_S	et	f	\N
188964	henrikuks	?henrikuks =henriku  (SgTr  >henrik !02_S	et	f	\N
188965	henrikuks	?henrikuks =henriku  (KndPrPs  >henrikuma !27_V	et	f	\N
188973	lubecki	?lubecki =lubecki  (SgG  >lubeck !22_S	et	f	\N
188974	lubecki	?lubecki =lubecki  (SgP  >lubeck !22_S	et	f	\N
188591	väljaõppe	väljaõppe =õppe  (SgG  >välja+õpe !06_S	et	f	\N
188592	väljaõppe	väljaõppe =õppe  (PlP  >välja+õpp !22_S	et	f	\N
188608	tasumata	tasumata =tasu  (SupAb  >tasuma !27_V	et	f	\N
188610	tasumata	tasumata =tasumata  (ID  >tasumata !41_A	et	f	\N
188611	tasumata	"tasumata %tasu  )MATA_vA  <tasuma ;27_V	et	f	\N
188614	kiusati	kiusati =kiusa  (IndIpfIps  >kiusama !29_V	et	f	\N
188615	kiusati	kiusati =ati  (SgG  >kius+att !22_S	et	f	\N
188616	õigeusklikku	õigeusklikku =usklikku  (SgP  >õige+usklik !25_AS	et	f	\N
188617	õigeusklikku	õigeusklikku =usklikku  (SgAdt  >õige+usklik !25_AS	et	f	\N
188639	puitu	puitu =puitu  (SgP  >puit !22_S	et	f	\N
188640	puitu	puitu =puitu  (SgAdt  >puit !22_S	et	f	\N
188641	puitu	puitu =puitu  (IndPrPs_  >puituma !27_V	et	f	\N
188642	puitu	puitu =puitu  (ImpPrSg2  >puituma !27_V	et	f	\N
188648	sakssakslased	?sakssakslased =sakssakslase  (PlN  >sakssakslane !12_S	et	f	\N
188675	gootika	gootika =gootika  (SgN  >gootika !01_S	et	f	\N
188676	gootika	gootika =gootika  (SgG  >gootika !01_S	et	f	\N
188683	raekivist	raekivist =kivi  (SgEl  >rae+kivi !17_S	et	f	\N
188684	raekivist	raekivist =kivis  (SgP  >rae+kivine !10_A	et	f	\N
188685	raekivist	"rae+kivine %kivi  )NE_aA  <rae+kivi ;17_S	et	f	\N
188692	schnkenberg	?schnkenberg =schnkenberg  (SgN  >schnkenberg !02_S	et	f	\N
188693	puruksmkivipommidega	?puruksmkivipommidega =puruksmkivipommi  (PlKom  >puruksmkivipomm !22_S	et	f	\N
188695	poolakatele	poolakatele =poolaka  (PlAll  >poolakas !02_S	et	f	\N
188696	poolakatele	poolakatele =kate  (PlAll  >poola+katt !22_S	et	f	\N
188705	poolakad	poolakad =poolaka  (PlN  >poolakas !02_S	et	f	\N
188706	poolakad	poolakad =aka  (PlN  >pool+aka !16_S	et	f	\N
188725	valitsuseks	valitsuseks =valitsuse  (SgTr  >valitsus !11_S	et	f	\N
188726	valitsuseks	"valitsus %valitse  )US_vS  <valitsema ;27_V	et	f	\N
188747	tulusid	tulusid =tulu  (PlP  >tulu !17_S	et	f	\N
188748	tulusid	tulusid =tulusi  (PlN  >tulus !02_A	et	f	\N
188752	hilisgooti	hilisgooti =gooti  (SgP  >hilis+goot !22_S	et	f	\N
188753	hilisgooti	hilisgooti =gooti  (SgAdt  >hilis+goot !22_S	et	f	\N
188756	tugenenud	?tugenenud =tugene  (PtsPtPs  >tugenema !27_V	et	f	\N
188757	tugenenud	?tugenenud =tugenenu  (PlN  >tugenenu !01_S	et	f	\N
188758	tugenenud	?tugenenud =tugenenu  (IndPrSg2  >tugenenuma !27_V	et	f	\N
188759	tugenenud	?tugenenud =tugenenud  (ID  >tugenenud !41_A	et	f	\N
188770	läbikäiku	läbikäiku =käiku  (SgP  >läbi+käik !22_S	et	f	\N
188771	läbikäiku	läbikäiku =käiku  (SgAdt  >läbi+käik !22_S	et	f	\N
188782	tugevnev	tugevnev =tugevne  (PtsPrPs  >tugevnema !27_V	et	f	\N
188783	tugevnev	tugevnev =tugevnev  (SgN  >tugevnev !02_A	et	f	\N
188784	tugevnev	"tugevnev %tugevne  )V_vA  <tugevnema ;27_V	et	f	\N
188827	sobtas	?sobtas =sobta  (IndIpfSg3  >sobtama !29_V	et	f	\N
188828	sobtas	?sobtas =sobtas  (SgN  >sobtas !07_S	et	f	\N
188834	pühapaikude	pühapaikude =kude  (SgN  >püha+pai+kude !18_S	et	f	\N
188835	pühapaikude	pühapaikude =kude  (SgP  >püha+pai+kude !18_S	et	f	\N
188840	sälmid	?sälmid =sälmi  (PlN  >sälmi !16_S	et	f	\N
188841	sälmid	?sälmid =sälmi  (PlN  >sälm !22_S	et	f	\N
188843	sälmid	?sälmid =sälmi  (IndPrSg2  >sälmima !28_V	et	f	\N
188849	madalmaaa	?madalmaaa =madalmaaa  (SgN  >madalmaaa !26_S	et	f	\N
188850	madalmaaa	?madalmaaa =madalmaaa  (SgG  >madalmaaa !26_S	et	f	\N
188851	madalmaaa	?madalmaaa =maaa  (SgN  >madal+maaa !26_S	et	f	\N
188852	madalmaaa	?madalmaaa =maaa  (SgG  >madal+maaa !26_S	et	f	\N
188857	paikne	paikne =paikne  (SgN  >paikne !02_A	et	f	\N
188858	paikne	paikne =paikne  (IndPrPs_  >paiknema !27_V	et	f	\N
188859	paikne	paikne =paikne  (ImpPrSg2  >paiknema !27_V	et	f	\N
188860	traditsioonilisus	traditsioonilisus =traditsioonilisus  (SgN  >traditsioonilisus !11?09_S	et	f	\N
188861	traditsioonilisus	"traditsioonilisus %traditsiooni  )LISUS_aS  <traditsioon ;22_S	et	f	\N
188862	kohakeelt	kohakeelt =kee  (SgAbl  >koha+kesi !15_S	et	f	\N
188863	kohakeelt	kohakeelt =kee  (SgAbl  >koha+kee !26_S	et	f	\N
188864	kohakeelt	kohakeelt =keel  (SgP  >koha+keel !13_S	et	f	\N
188865	jumalasõnast	jumalasõnast =sõna  (SgEl  >jumala+sõna !17_S	et	f	\N
188866	jumalasõnast	jumalasõnast =sõnas  (SgP  >jumala+sõnane !10_A	et	f	\N
188867	jumalasõnast	"jumala+sõnane %sõna  )NE_aA  <jumala+sõna ;17_S	et	f	\N
188870	hansakaupmeestele	hansakaupmeestele =mees  (PlAll  >hansa+kaup+meene !10_A	et	f	\N
188871	hansakaupmeestele	"hansa+kaup+meene %mee  )NE_aA  <hansa+kaup+mesi ;15_S	et	f	\N
188872	hansakaupmeestele	hansakaupmeestele =mees  (PlAll  >hansa+kaup+mees !13_S	et	f	\N
188879	lübedui	?lübedui =lübedui  (SgN  >lübedui !26_S	et	f	\N
188880	lübedui	?lübedui =lübedui  (SgG  >lübedui !26_S	et	f	\N
188881	kloostrikoolis	kloostrikoolis =kooli  (SgIn  >kloostri+kool !22_S	et	f	\N
188882	kloostrikoolis	kloostrikoolis =kooli  (PlIn  >kloostri+kool !22_S	et	f	\N
188894	eetlaste	?eetlaste =eetlas  (PlG  >eetlas !07_S	et	f	\N
188895	eetlaste	?eetlaste =eetlas  (PlG  >eetlane !12?10_S	et	f	\N
188899	1801a	### 1801a	et	f	\N
188938	ebatahtlikum	ebatahtlikum =tahtlikum  (SgN  >eba+tahtlikum !02_A	et	f	\N
188939	ebatahtlikum	"eba+tahtlikum %tahtliku  )M_cA  <eba+tahtlik ;25_A	et	f	\N
188959	väidetavat	väidetavat =väide  (KvtPrIps  >väitma !34_V	et	f	\N
188754	ikaldused	ikaldused =ikalduse  (PlN  >ikaldus !11_S	et	f	\N
188755	ikaldused	"ikaldus %ikalda  )US_vS  <ikaldama ;27_V	et	f	\N
188777	poola-	?poola- =poola  (ID  >poola !41_G	et	f	\N
188778	poola-	?poola- =poola  (IndPrPs_  >poolama !29_V	et	f	\N
188779	poola-	?poola- =poola  (ImpPrSg2  >poolama !29_V	et	f	\N
188808	jonnis	jonnis =jonni  (SgIn  >jonn !22_S	et	f	\N
188809	jonnis	jonnis =jonni  (IndIpfSg3  >jonnima !28_V	et	f	\N
188813	kvaliteetkangast	kvaliteetkangast =kanga  (SgEl  >kvaliteet+kangas !07_S	et	f	\N
188814	kvaliteetkangast	kvaliteetkangast =kangas  (SgP  >kvaliteet+kangas !07_S	et	f	\N
188815	kvaliteetkangast	kvaliteetkangast =kangas  (SgP  >kvaliteet+kangane !10_A	et	f	\N
188816	kvaliteetkangast	"kvaliteet+kangane %kanga  )NE_aA  <kvaliteet+kangas ;07_S	et	f	\N
188832	tagapoolseks	tagapoolseks =seks  (SgN  >taga+pool+seks !22_S	et	f	\N
188833	tagapoolseks	tagapoolseks =poolse  (SgTr  >taga+poolne !02_A	et	f	\N
188836	madalama	madalama =madalama  (SgG  >madalam !02_A	et	f	\N
188837	madalama	"madalam %madala  )M_cA  <madal ;02_AS	et	f	\N
188838	relikviiad	?relikviiad =relikviia  (PlN  >relikviia !16_S	et	f	\N
188839	relikviiad	?relikviiad =relikviiad  (SgN  >relikviiad !22_S	et	f	\N
188842	elukogumised	elukogumised =kogumise  (PlN  >elu+kogumine !12_S	et	f	\N
188844	elukogumised	"elu+kogumine %kogumi  )NE_aA  <elu+kogum ;02_S	et	f	\N
188868	kohakeeles	kohakeeles =keele  (SgIn  >koha+keel !13_S	et	f	\N
188869	kohakeeles	kohakeeles =keele  (PlIn  >koha+keeld !22_S	et	f	\N
188885	1208a	### 1208a	et	f	\N
188888	kristimises	?kristimises =kristimise  (SgIn  >kristimine !12_S	et	f	\N
188896	võideldavat	võideldavat =võidel  (KvtPrIps  >võitlema !30_V	et	f	\N
188897	võideldavat	võideldavat =võideldava  (SgP  >võideldav !02_A	et	f	\N
188898	võideldavat	"võideldav %võidel  )TAV_vAS  <võitlema ;30_V	et	f	\N
188900	1551a	### 1551a	et	f	\N
188901	evanglumeid	?evanglumeid =evanglume  (PlP  >evanglum !02_S	et	f	\N
188902	evanglumeid	?evanglumeid =evanglumei  (PlN  >evanglumei !26_S	et	f	\N
188903	evanglumeid	?evanglumeid =evanglumei  (SgP  >evanglumei !26_S	et	f	\N
188909	henrikut	?henrikut =henriku  (SgP  >henriku !01_S	et	f	\N
188910	henrikut	?henrikut =henriku  (SgP  >henrik !02_S	et	f	\N
188912	kloostrikoolist	kloostrikoolist =kooli  (SgEl  >kloostri+kool !22_S	et	f	\N
188913	kloostrikoolist	kloostrikoolist =kooli  (PlEl  >kloostri+kool !22_S	et	f	\N
188914	kloostrikoolist	kloostrikoolist =koolis  (SgP  >kloostri+kooline !10_A	et	f	\N
188915	kloostrikoolist	"kloostri+kooline %koo  )LINE_aA  <kloostri+kubu ;18_S	et	f	\N
188916	kloostrikoolist	"kloostri+kooline %kooli  )NE_aA  <kloostri+kool ;22_S	et	f	\N
188917	kohalikuid	?kohalikuid =kohalikui  (PlN  >kohalikui !26_S	et	f	\N
188918	kohalikuid	?kohalikuid =kohalikui  (SgP  >kohalikui !26_S	et	f	\N
188919	kohalikuid	?kohalikuid =ikui  (PlN  >kohal+ikui !26_S	et	f	\N
188920	kohalikuid	?kohalikuid =ikui  (SgP  >kohal+ikui !26_S	et	f	\N
188921	kohalikuid	?kohalikuid =ikuid  (SgN  >kohal+ikuid !22_S	et	f	\N
188925	mainitseb	?mainitseb =mainitse  (IndPrSg3  >mainitsema !27_V	et	f	\N
188926	taarast	taarast =taara  (SgEl  >taara !16_S	et	f	\N
188927	taarast	taarast =taaras  (SgP  >taarane !10_A	et	f	\N
188928	taarast	"taarane %taara  )NE_aA  <taara ;16_S	et	f	\N
188937	mõisades	?mõisades =mõisa  (PlIn  >mõisa !16_S	et	f	\N
188940	alandavam	alandavam =alandavam  (SgN  >alandavam !02_A	et	f	\N
188941	alandavam	"alandavam %alanda  )VAM_cA  <alandama ;27_V	et	f	\N
188942	kloostrikooli	kloostrikooli =kooli  (SgG  >kloostri+kool !22_S	et	f	\N
188943	kloostrikooli	kloostrikooli =kooli  (SgP  >kloostri+kool !22_S	et	f	\N
188944	kloostrikooli	kloostrikooli =kooli  (SgAdt  >kloostri+kool !22_S	et	f	\N
188945	kloostrikooli	kloostrikooli =kooli  (PlP  >kloostri+kool !22_S	et	f	\N
188953	meinhardi	?meinhardi =meinhardi  (SgN  >meinhardi !01_S	et	f	\N
188954	meinhardi	?meinhardi =meinhardi  (SgG  >meinhardi !01_S	et	f	\N
188955	meinhardi	?meinhardi =meinhardi  (SgG  >meinhard !02_S	et	f	\N
188956	meinhardi	?meinhardi =meinhardi  (SgG  >meinhart !22_S	et	f	\N
188957	meinhardi	?meinhardi =meinhardi  (IndPrPs_  >meinhartima !28_V	et	f	\N
188958	meinhardi	?meinhardi =meinhardi  (ImpPrSg2  >meinhartima !28_V	et	f	\N
188976	misionääriks	?misionääriks =misionääri  (SgTr  >misionääri !16_S	et	f	\N
188977	misionääriks	?misionääriks =misionääri  (SgTr  >misionäär !22_S	et	f	\N
188978	misionääriks	?misionääriks =misionääri  (KndPrPs  >misionäärima !28_V	et	f	\N
188979	misionääriks	?misionääriks =ionääri  (SgTr  >mis+ionääri !16_S	et	f	\N
188980	misionääriks	?misionääriks =ionääri  (SgTr  >mis+ionäär !22_S	et	f	\N
188985	suurematesse	suurematesse =suurema  (PlIll  >suurem !02_A	et	f	\N
188986	suurematesse	"suurem %suure  )M_cA  <suur ;13_A	et	f	\N
188987	suurematesse	suurematesse =mate  (SgIll  >suure+mate !16_S	et	f	\N
188988	suurematesse	suurematesse =mate  (PlIll  >suure+matt !22_SA	et	f	\N
188997	baltazar	?baltazar =baltazar  (SgN  >baltazar !19_S	et	f	\N
188998	baltazar	?baltazar =azar  (SgN  >balt+azar !02_S	et	f	\N
189001	kelli	kelli =kelli  (SgG  >kell !22_S	et	f	\N
189002	kelli	kelli =kelli  (SgP  >kell !22_S	et	f	\N
189003	kelli	kelli =kelli  (SgAdt  >kell !22_S	et	f	\N
189004	kelli	kelli =kelli  (PlP  >kell !22_S	et	f	\N
188780	rjetzpospolita	?rjetzpospolita =rjetzpospolita  (IndPrPs_  >rjetzpospolitama !27_V	et	f	\N
188781	rjetzpospolita	?rjetzpospolita =rjetzpospolita  (ImpPrSg2  >rjetzpospolitama !27_V	et	f	\N
188810	palumine	palumine =palumine  (SgN  >palumine !12_S	et	f	\N
188811	palumine	"palumine %palu  )MINE_vS  <paluma ;27_V	et	f	\N
188823	liikuvusest	liikuvusest =liikuvuse  (SgEl  >liikuvus !11_S	et	f	\N
188824	liikuvusest	"liikuvus %liiku  )VUS_aS  <liikuma ;28_V	et	f	\N
188825	liikuvusest	"liikuvus %liikuva  )US_aS  <liikuv ;02_A	et	f	\N
188826	liikuvusest	liikuvusest =use  (PlEl  >liikuv+usk !22_S	et	f	\N
188845	põhja-saksa	põhja-saksa =saksa  (ID  >põhja-saksa !41_G	et	f	\N
188846	põhja-saksa	põhja-saksa =saksa  (SgG  >põhja-saks !23?22_S	et	f	\N
188847	põhja-saksa	põhja-saksa =saksa  (SgP  >põhja-saks !23?22_S	et	f	\N
188848	põhja-saksa	põhja-saksa =saksa  (SgAdt  >põhja-saks !23?22_S	et	f	\N
188873	hansakaupmeeste	hansakaupmeeste =mees  (PlG  >hansa+kaup+meene !10_A	et	f	\N
188874	hansakaupmeeste	"hansa+kaup+meene %mee  )NE_aA  <hansa+kaup+mesi ;15_S	et	f	\N
188875	hansakaupmeeste	hansakaupmeeste =mees  (PlG  >hansa+kaup+mees !13_S	et	f	\N
188886	preester	preester =preester  (SgN  >preester !02_S	et	f	\N
188887	preester	preester =ester  (SgN  >pre+ester !02_S	et	f	\N
188908	lät	### lät	et	f	\N
188911	madeburg	?madeburg =madeburg  (SgN  >madeburg !22_S	et	f	\N
188931	taevasega	taevasega =taevase  (SgKom  >taevane !10~12_A	et	f	\N
188932	taevasega	"taevane %taeva  )NE_aA  <taevas ;07_S	et	f	\N
188981	tõlhitud	?tõlhitud =tõlhi  (PtsPtIps  >tõlhima !28_V	et	f	\N
188982	tõlhitud	?tõlhitud =tõlhitu  (PlN  >tõlhitu !01_AS	et	f	\N
188983	tõlhitud	?tõlhitud =tõlhitu  (IndPrSg2  >tõlhituma !27_V	et	f	\N
188984	tõlhitud	?tõlhitud =tõlhitud  (ID  >tõlhitud !41_A	et	f	\N
188989	visitatsiooni	visitatsiooni =visitatsiooni  (SgG  >visitatsioon !22_S	et	f	\N
188990	visitatsiooni	visitatsiooni =visitatsiooni  (SgP  >visitatsioon !22_S	et	f	\N
188991	visitatsiooni	visitatsiooni =visitatsiooni  (SgAdt  >visitatsioon !22_S	et	f	\N
188992	protokollid	protokollid =protokolli  (PlN  >protokoll !22_S	et	f	\N
188993	protokollid	protokollid =protokolli  (IndPrSg2  >protokollima !28_V	et	f	\N
188994	protokollid	protokollid =kolli  (PlN  >proto+koll !22_S	et	f	\N
188995	pööraks	pööraks =pööra  (SgTr  >pöör !22_S	et	f	\N
188996	pööraks	pööraks =pööra  (KndPrPs  >pöörama !29_V	et	f	\N
189007	liiklusvabadus	liiklusvabadus =vabadus  (SgN  >liiklus+vabadus !11_S	et	f	\N
189008	liiklusvabadus	"liiklus+vabadus %vaba  )US_aS  <liiklus+vaba ;17_A	et	f	\N
189018	vasturääkiv	vasturääkiv =rääki  (PtsPrPs  >vastu+_rääkima !28_V	et	f	\N
189019	vasturääkiv	vasturääkiv =rääkiv  (SgN  >vastu+rääkiv !02_A	et	f	\N
189050	julgem	julgem =julgem  (SgN  >julgem !02_A	et	f	\N
189051	julgem	"julgem %julge  )M_cA  <julge ;01_A	et	f	\N
189055	grammaticus	?grammaticus =grammaticus  (SgN  >grammaticus !11?09_S	et	f	\N
189057	vallutusretkeil	?vallutusretkeil =vallutusretkei  (SgAd  >vallutusretkei !26_S	et	f	\N
189058	vallutusretkeil	?vallutusretkeil =vallutusretkeil  (SgN  >vallutusretkeil !19_S	et	f	\N
189059	vallutusretkeil	?vallutusretkeil =retke  (PlAd  >vallutus+retke !06_S	et	f	\N
189060	vallutusretkeil	?vallutusretkeil =retkei  (SgAd  >vallutus+retkei !26_S	et	f	\N
189061	vallutusretkeil	?vallutusretkeil =retkeil  (SgN  >vallutus+retkeil !22_S	et	f	\N
189072	roomast	roomast =rooma  (SgEl  >room !22_S	et	f	\N
189073	roomast	roomast =roomas  (SgP  >roomane !10_A	et	f	\N
189074	roomast	"roomane %rooma  )NE_aA  <room ;22_S	et	f	\N
189075	roomast	roomast =mast  (SgN  >roo+mast !22_S	et	f	\N
189086	misjonitöö	misjonitöö =töö  (SgN  >misjoni+töö !26_S	et	f	\N
189087	misjonitöö	misjonitöö =töö  (SgG  >misjoni+töö !26_S	et	f	\N
189100	ühiskondlikusüsteemi	?ühiskondlikusüsteemi =ühiskondlikusüsteemi  (SgN  >ühiskondlikusüsteemi !16_S	et	f	\N
189101	ühiskondlikusüsteemi	?ühiskondlikusüsteemi =ühiskondlikusüsteemi  (SgG  >ühiskondlikusüsteemi !16_S	et	f	\N
189102	ühiskondlikusüsteemi	?ühiskondlikusüsteemi =ühiskondlikusüsteemi  (SgG  >ühiskondlikusüsteem !22_S	et	f	\N
189103	ühiskondlikusüsteemi	?ühiskondlikusüsteemi =ühiskondlikusüsteemi  (SgP  >ühiskondlikusüsteem !22_S	et	f	\N
189104	ühiskondlikusüsteemi	?ühiskondlikusüsteemi =ühiskondlikusüsteemi  (SgAdt  >ühiskondlikusüsteem !22_S	et	f	\N
189105	ühiskondlikusüsteemi	?ühiskondlikusüsteemi =ühiskondlikusüsteemi  (IndPrPs_  >ühiskondlikusüsteemima !28_V	et	f	\N
189106	ühiskondlikusüsteemi	?ühiskondlikusüsteemi =ühiskondlikusüsteemi  (ImpPrSg2  >ühiskondlikusüsteemima !28_V	et	f	\N
189109	algataja	algataja =algataja  (SgN  >algataja !01_S	et	f	\N
189110	algataja	"algataja %algata  )JA_vS  <algatama ;27_V	et	f	\N
189111	algataja	algataja =algataja  (SgG  >algataja !01_S	et	f	\N
189116	preister	?preister =preister  (SgN  >preister !02_S	et	f	\N
189117	preister	?preister =ister  (SgN  >pre+ister !02_S	et	f	\N
189124	gogogo	?gogogo =gogogo  (SgN  >gogogo !01_S	et	f	\N
189126	gogogo	?gogogo =gogogo  (SgG  >gogogo !01_S	et	f	\N
189146	standartid	?standartid =standarti  (PlN  >standarti !01_S	et	f	\N
189148	aravtaks	?aravtaks =aravta  (SgTr  >aravta !01_S	et	f	\N
189149	aravtaks	?aravtaks =aravtaks  (SgN  >aravtaks !22_S	et	f	\N
189161	tõustmine	?tõustmine =tõustmine  (SgN  >tõustmine !12?10_S	et	f	\N
189162	tõustmine	?tõustmine =tõustmine  (IndPrPs_  >tõustminema !27_V	et	f	\N
188798	täitmist	"täitmine %täit  )MINE_vS  <täitma ;34_V	et	f	\N
188799	jutlusest	jutlusest =jutluse  (SgEl  >jutlus !11~09_S	et	f	\N
188800	jutlusest	jutlusest =jutluses  (SgP  >jutlusene !12_A	et	f	\N
188801	jutlusest	"jutlusene %jutluse  )NE_aA  <jutlus ;09_S	et	f	\N
188802	jutlusest	"jutlusene %jutluse  )NE_aA  <jutlus ;11_S	et	f	\N
188812	hli	### hli	et	f	\N
188817	genotaafide	?genotaafide =genotaafi  (PlG  >genotaafi !16_S	et	f	\N
188818	genotaafide	?genotaafide =genotaafi  (PlG  >genotaaf !22_S	et	f	\N
188819	genotaafide	?genotaafide =taafi  (PlG  >geno+taafi !16_S	et	f	\N
188820	genotaafide	?genotaafide =taafi  (PlG  >geno+taaf !22_S	et	f	\N
188829	surnuile	surnuile =surnu  (PlAll  >surnu !01_S	et	f	\N
188830	surnuile	"surnu %sur  )NU_vS  <surema ;36_V	et	f	\N
188831	surnuile	surnuile =surnu  (PlAll  >surnu !06_S	et	f	\N
188853	preisimaa	preisimaa =maa  (SgN  >preisi+maa !26_S	et	f	\N
188854	preisimaa	preisimaa =maa  (SgG  >preisi+maa !26_S	et	f	\N
188855	säilijaks	säilijaks =säilija  (SgTr  >säilija !01_S	et	f	\N
188856	säilijaks	"säilija %säili  )JA_vS  <säilima ;28_V	et	f	\N
188876	1185a	### 1185a	et	f	\N
188877	põhja-saksamaal	põhja-saksamaal =maa  (SgAd  >põhja-saksa+maa !26_S	et	f	\N
188878	põhja-saksamaal	põhja-saksamaal =maal  (SgN  >põhja-saksa+maal !22_S	et	f	\N
188883	liivimaale	liivimaale =maa  (SgAll  >liivi+maa !26_S	et	f	\N
188884	liivimaale	liivimaale =maale  (PlP  >liivi+maal !22_S	et	f	\N
188889	kardetud	kardetud =karde  (PtsPtIps  >kartma !34_V	et	f	\N
188890	kardetud	kardetud =kardetu  (PlN  >kardetu !01_S	et	f	\N
188891	kardetud	"kardetu %karde  )TU1_vS  <kartma ;34_V	et	f	\N
188892	kardetud	kardetud =kardetud  (ID  >kardetud !41_A	et	f	\N
188893	kardetud	"kardetud %karde  )TUD_vA  <kartma ;34_V	et	f	\N
188904	varast	varast =vara  (SgEl  >vara !17_S	et	f	\N
188905	varast	varast =varas  (SgP  >varas !07_S	et	f	\N
188906	varast	varast =varas  (SgP  >varane !10_A	et	f	\N
188907	varast	"varane %vara  )NE_aA  <vara ;17_S	et	f	\N
188923	usunditest	usunditest =usundi  (PlEl  >usund !02_S	et	f	\N
188924	usunditest	usunditest =test  (SgN  >usundi+test !22_S	et	f	\N
188929	äikesega	äikesega =äikese  (SgKom  >äike !12?10_S	et	f	\N
188930	äikesega	äikesega =äikese  (SgKom  >äikene !12?10_S	et	f	\N
188946	preestriks	preestriks =preestri  (SgTr  >preester !02_S	et	f	\N
188947	preestriks	preestriks =estri  (SgTr  >pre+ester !02_S	et	f	\N
188948	põlisrahvaste	põlisrahvaste =rahvas  (PlG  >põlis+rahvas !07_S	et	f	\N
188949	põlisrahvaste	põlisrahvaste =rahvas  (PlG  >põlis+rahvane !10_A	et	f	\N
188950	põlisrahvaste	"põlis+rahvane %rahva  )NE_aA  <põlis+rahvas ;07_S	et	f	\N
188968	lettus	?lettus =lettu  (IndIpfSg3  >lettuma !27_V	et	f	\N
188969	lettus	?lettus =lettus  (SgN  >lettus !11~09_S	et	f	\N
189012	hindlamisraamat	?hindlamisraamat =hindlamisraama  (SgP  >hindlamisraama !16_S	et	f	\N
189013	hindlamisraamat	?hindlamisraamat =lamisraama  (SgP  >hind+lamisraama !16_S	et	f	\N
189044	tultetatud	?tultetatud =tulteta  (PtsPtIps  >tultetama !27_V	et	f	\N
189045	tultetatud	?tultetatud =tultetatu  (PlN  >tultetatu !01_S	et	f	\N
189046	tultetatud	?tultetatud =tultetatu  (IndPrSg2  >tultetatuma !27_V	et	f	\N
189047	tultetatud	?tultetatud =tultetatud  (ID  >tultetatud !41_A	et	f	\N
189048	luce	?luce =luce  (SgN  >luce !06_S	et	f	\N
189049	luce	?luce =luce  (SgG  >luce !06_S	et	f	\N
189062	ümera	?ümera =ümera  (SgN  >ümera !01_S	et	f	\N
189063	ümera	?ümera =ümera  (SgG  >ümera !01_S	et	f	\N
189064	ruussov	?ruussov =ruussov  (SgN  >ruussov !02_A	et	f	\N
189112	kirikukommete	kirikukommete =me  (PlG  >kiriku+kom+mesi !15_S	et	f	\N
189113	kirikukommete	kirikukommete =komme  (PlG  >kiriku+komme !06_S	et	f	\N
189118	lutherlik	?lutherlik =lutherlik  (SgN  >lutherlik !25_A	et	f	\N
189171	instruktsiooni	instruktsiooni =instruktsiooni  (SgG  >instruktsioon !22_S	et	f	\N
189172	instruktsiooni	instruktsiooni =instruktsiooni  (SgP  >instruktsioon !22_S	et	f	\N
189173	instruktsiooni	instruktsiooni =instruktsiooni  (SgAdt  >instruktsioon !22_S	et	f	\N
189176	arvane	?arvane =arvane  (SgN  >arvane !10_A	et	f	\N
189177	arvane	?arvane =arvane  (IndPrPs_  >arvanema !27_V	et	f	\N
189178	arvane	?arvane =arvane  (ImpPrSg2  >arvanema !27_V	et	f	\N
189179	arvane	?arvane =ane  (SgN  >arv+ane !16_S	et	f	\N
189180	arvane	?arvane =ane  (SgG  >arv+ane !16_S	et	f	\N
189189	alnult	?alnult =alnu  (SgAbl  >alnu !01_S	et	f	\N
189190	alnult	?alnult =alnult  (ID  >alnult !41_D	et	f	\N
189205	arvest	arvest =arve  (SgEl  >arve !06_S	et	f	\N
189206	arvest	arvest =arve  (PlEl  >arv !22_S	et	f	\N
189207	arvest	arvest =arves  (SgP  >arvene !10_A	et	f	\N
189208	arvest	"arvene %arve  )NE_aA  <arve ;06_S	et	f	\N
189211	kotti	kotti =kotti  (ID  >kotti !41_D	et	f	\N
189212	kotti	kotti =kotti  (SgP  >kott !22_S	et	f	\N
189213	kotti	kotti =kotti  (SgAdt  >kott !22_S	et	f	\N
189214	kotti	kotti =kotti  (PlP  >kott !22_S	et	f	\N
189241	varastatu	varastatu =varastatu  (SgN  >varastatu !01_S	et	f	\N
189242	varastatu	"varastatu %varasta  )TU1_vS  <varastama ;27_V	et	f	\N
189243	varastatu	varastatu =varastatu  (SgG  >varastatu !01_S	et	f	\N
188960	väidetavat	väidetavat =väidetava  (SgP  >väidetav !02_A	et	f	\N
188961	väidetavat	"väidetav %väide  )TAV_vAS  <väitma ;34_V	et	f	\N
188962	tharapitat	### tharapitat	et	f	\N
188966	lad	lad =la  (PlN  >la !26_S	et	f	\N
188967	lad	lad =la  (SgP  >la !26_S	et	f	\N
188970	magdeburgis	?magdeburgis =magdeburgi  (SgIn  >magdeburk !22_S	et	f	\N
188971	magdeburgis	?magdeburgis =magdeburgi  (IndIpfSg3  >magdeburgima !28_V	et	f	\N
188972	magdeburgis	?magdeburgis =magdeburgis  (SgN  >magdeburgis !09_S	et	f	\N
189014	henrikus	?henrikus =henriku  (SgIn  >henriku !01_S	et	f	\N
189015	henrikus	?henrikus =henriku  (SgIn  >henrik !02_S	et	f	\N
189016	henrikus	?henrikus =henriku  (IndIpfSg3  >henrikuma !27_V	et	f	\N
189017	henrikus	?henrikus =henrikus  (SgN  >henrikus !11_S	et	f	\N
189022	lüübekist	?lüübekist =lüübeki  (SgEl  >lüübeki !01_S	et	f	\N
189023	lüübekist	?lüübekist =lüübeki  (SgEl  >lüübek !02_S	et	f	\N
189024	lüübekist	?lüübekist =lüübeki  (SgEl  >lüübekk !22_S	et	f	\N
189025	lüübekist	?lüübekist =lüübekis  (SgP  >lüübekis !11_S	et	f	\N
189026	lüübekist	?lüübekist =lüübekist  (SgN  >lüübekist !22_S	et	f	\N
189028	keli	?keli =keli  (SgN  >keli !17_S	et	f	\N
189029	keli	?keli =keli  (SgG  >keli !17_S	et	f	\N
189030	keli	?keli =keli  (SgP  >keli !17_S	et	f	\N
189031	keli	?keli =keli  (IndPrPs_  >kelima !27_V	et	f	\N
189032	keli	?keli =keli  (ImpPrSg2  >kelima !27_V	et	f	\N
189033	p-eesti	p-eesti =eesti  (ID  >p-eesti !41_G	et	f	\N
189034	p-eesti	p-eesti =eesti  (SgN  >p-eesti !16_H	et	f	\N
189035	p-eesti	p-eesti =eesti  (SgG  >p-eesti !16_H	et	f	\N
189065	koell	?koell =koell  (SgN  >koell !22_S	et	f	\N
189077	vallutajad	vallutajad =vallutaja  (PlN  >vallutaja !01_S	et	f	\N
189078	vallutajad	"vallutaja %valluta  )JA_vS  <vallutama ;27_V	et	f	\N
189079	uurijatel	uurijatel =uurija  (PlAd  >uurija !01_S	et	f	\N
189080	uurijatel	"uurija %uuri  )JA_vS  <uurima ;28_V	et	f	\N
189093	killustunud	killustunud =killustu  (PtsPtPs  >killustuma !27_V	et	f	\N
189094	killustunud	killustunud =killustunu  (PlN  >killustunu !01_S	et	f	\N
189095	killustunud	"killustunu %killustu  )NU_vS  <killustuma ;27_V	et	f	\N
189096	killustunud	killustunud =killustunud  (ID  >killustunud !41_A	et	f	\N
189097	killustunud	"killustunud %killustu  )NUD_vA  <killustuma ;27_V	et	f	\N
189119	e-d	e-d =e  (SgP  >e !xx_Q	et	f	\N
189120	e-d	e-d =e  (PlN  >e !xx_Q	et	f	\N
189142	ettevatlikult	?ettevatlikult =ettevatliku  (SgAbl  >ettevatlik !25_A	et	f	\N
189143	ettevatlikult	?ettevatlikult =ettevatlikult  (ID  >ettevatlikult !41_D	et	f	\N
189144	ettevatlikult	?ettevatlikult =vatliku  (SgAbl  >ette+vatlik !25_A	et	f	\N
189145	ettevatlikult	?ettevatlikult =vatliku  (SgAbl  >ette+vatliku !01_S	et	f	\N
189164	kontrolltööid	?kontrolltööid =kontrolltööi  (PlN  >kontrolltööi !26_S	et	f	\N
189165	kontrolltööid	?kontrolltööid =kontrolltööi  (SgP  >kontrolltööi !26_S	et	f	\N
189166	kontrolltööid	?kontrolltööid =kontrolltööid  (SgN  >kontrolltööid !22_S	et	f	\N
189167	kontrolltööid	?kontrolltööid =tööid  (SgN  >kont+roll+tööid !02_S	et	f	\N
189181	looen	?looen =looen  (SgN  >looen !02_S	et	f	\N
189202	muugav	?muugav =muuga  (PtsPrPs  >muugama !29_V	et	f	\N
189203	muugav	?muugav =muugav  (SgN  >muugav !02_A	et	f	\N
189248	kurjategija	kurjategija =tegija  (SgN  >kurja+tegija !01_S	et	f	\N
189249	kurjategija	kurjategija =tegija  (SgG  >kurja+tegija !01_S	et	f	\N
189256	vabanenuid	vabanenuid =vabanenu  (PlP  >vabanenu !01_S	et	f	\N
189257	vabanenuid	"vabanenu %vabane  )NU_vS  <vabanema ;27_V	et	f	\N
189280	kiirabi	kiirabi =abi  (SgN  >kiir+abi !17_S	et	f	\N
189281	kiirabi	kiirabi =abi  (SgG  >kiir+abi !17_S	et	f	\N
189282	kiirabi	kiirabi =abi  (SgP  >kiir+abi !17_S	et	f	\N
189285	lihtsemaid	lihtsemaid =lihtsema  (PlP  >lihtsem !02_A	et	f	\N
189286	lihtsemaid	"lihtsem %lihtse  )M_cA  <lihtne ;02_A	et	f	\N
189287	läksit	?läksit =läksi  (SgP  >läksi !16_S	et	f	\N
189288	läksit	?läksit =läksit  (SgN  >läksit !02_S	et	f	\N
189313	narkootikumeid	?narkootikumeid =narkootikumei  (PlN  >narkootikumei !26_S	et	f	\N
189314	narkootikumeid	?narkootikumeid =narkootikumei  (SgP  >narkootikumei !26_S	et	f	\N
189315	narkootikumeid	?narkootikumeid =otikumei  (PlN  >narko+otikumei !26_S	et	f	\N
189316	narkootikumeid	?narkootikumeid =otikumei  (SgP  >narko+otikumei !26_S	et	f	\N
189341	imineme	?imineme =imine  (IndPrPl1  >iminema !27_V	et	f	\N
189342	andunud	andunud =andu  (PtsPtPs  >anduma !27_V	et	f	\N
189343	andunud	andunud =andunu  (PlN  >andunu !01_S	et	f	\N
189344	andunud	"andunu %andu  )NU_vS  <anduma ;27_V	et	f	\N
189345	andunud	andunud =andunud  (ID  >andunud !41_A	et	f	\N
189346	andunud	"andunud %andu  )NUD_vA  <anduma ;27_V	et	f	\N
189369	stabiliseerimine	stabiliseerimine =stabiliseerimine  (SgN  >stabiliseerimine !12_S	et	f	\N
189370	stabiliseerimine	"stabiliseerimine %stabiliseeri  )MINE_vS  <stabiliseerima ;28_V	et	f	\N
189371	lühiajalistest	lühiajalistest =ajalis  (PlEl  >lühi+ajaline !12_A	et	f	\N
189372	lühiajalistest	"lühi+ajaline %aja  )LINE_aA  <lühi+aeg ;22_S	et	f	\N
189382	arengutbr	### arengutbr	et	f	\N
189383	investoriks	?investoriks =investori  (SgTr  >investor !02_S	et	f	\N
189392	massilist	massilist =massilis  (SgP  >massiline !12_A	et	f	\N
188975	lubecki	?lubecki =lubecki  (SgAdt  >lubeck !22_S	et	f	\N
188999	saxo	?saxo =saxo  (SgN  >saxo !16_S	et	f	\N
189000	saxo	?saxo =saxo  (SgG  >saxo !16_S	et	f	\N
189009	teorjus	?teorjus =teorju  (SgIn  >teorju !01_S	et	f	\N
189010	teorjus	?teorjus =teorju  (IndIpfSg3  >teorjuma !27_V	et	f	\N
189011	teorjus	?teorjus =teorjus  (SgN  >teorjus !11~09_S	et	f	\N
189020	magdeburgist	?magdeburgist =magdeburgi  (SgEl  >magdeburk !22_S	et	f	\N
189021	magdeburgist	?magdeburgist =magdeburgis  (SgP  >magdeburgis !09_S	et	f	\N
189027	magdeburgist	?magdeburgist =magdeburgist  (SgN  >magdeburgist !22_S	et	f	\N
189042	eesltaste	?eesltaste =eesltas  (PlG  >eesltas !07_S	et	f	\N
189043	eesltaste	?eesltaste =eesltas  (PlG  >eesltane !12~10_A	et	f	\N
189052	hiljutigi	hiljutigi =hilju  (IndIpfIps^  >hiljuma !28_V	et	f	\N
189053	hiljutigi	hiljutigi =hiljuti  (ID^  >hiljuti !41_D	et	f	\N
189054	sako	sako =sako  (SgN  >sako !16_S	et	f	\N
189056	sako	sako =sako  (SgG  >sako !16_S	et	f	\N
189068	mõisanikumaal	?mõisanikumaal =mõisanikumaa  (SgAd  >mõisanikumaa !26_S	et	f	\N
189069	mõisanikumaal	?mõisanikumaal =mõisanikumaal  (SgN  >mõisanikumaal !22_S	et	f	\N
189070	mõisanikumaal	?mõisanikumaal =nikumaa  (SgAd  >mõisa+nikumaa !26_S	et	f	\N
189071	mõisanikumaal	?mõisanikumaal =nikumaal  (SgN  >mõisa+nikumaal !22_S	et	f	\N
189076	meinchard	?meinchard =meinchard  (SgN  >meinchard !02_S	et	f	\N
189081	misjonäärid	?misjonäärid =misjonääri  (PlN  >misjonääri !16_S	et	f	\N
189082	misjonäärid	?misjonäärid =misjonääri  (PlN  >misjonäär !22_S	et	f	\N
189083	misjonäärid	?misjonäärid =misjonääri  (IndPrSg2  >misjonäärima !28_V	et	f	\N
189084	misjonäärid	?misjonäärid =jonääri  (PlN  >mis+jonääri !16_S	et	f	\N
189085	misjonäärid	?misjonäärid =jonääri  (PlN  >mis+jonäär !22_S	et	f	\N
189088	viikingiajast	viikingiajast =aja  (SgEl  >viikingi+aeg !22_S	et	f	\N
189089	viikingiajast	viikingiajast =ajas  (SgP  >viikingi+ajane !10_A	et	f	\N
189090	viikingiajast	"viikingi+ajane %aja  )NE_aA  <viikingi+aeg ;22_S	et	f	\N
189121	doc	### doc	et	f	\N
189122	asdasdbr	?asdasdbr =asdasdbr  (SgN  >asdasdbr !22_S	et	f	\N
189127	ekstruktsiooni	?ekstruktsiooni =ekstruktsioo  (SgTer  >ekstruktsioo !26_S	et	f	\N
189128	ekstruktsiooni	?ekstruktsiooni =ekstruktsiooni  (SgN  >ekstruktsiooni !16_S	et	f	\N
189129	ekstruktsiooni	?ekstruktsiooni =ekstruktsiooni  (SgG  >ekstruktsiooni !16_S	et	f	\N
189130	ekstruktsiooni	?ekstruktsiooni =ekstruktsiooni  (SgG  >ekstruktsioon !22_S	et	f	\N
189131	ekstruktsiooni	?ekstruktsiooni =ekstruktsiooni  (SgP  >ekstruktsioon !22_S	et	f	\N
189132	ekstruktsiooni	?ekstruktsiooni =ekstruktsiooni  (SgAdt  >ekstruktsioon !22_S	et	f	\N
189133	ekstruktsiooni	?ekstruktsiooni =ekstruktsiooni  (IndPrPs_  >ekstruktsioonima !28_V	et	f	\N
189134	ekstruktsiooni	?ekstruktsiooni =ekstruktsiooni  (ImpPrSg2  >ekstruktsioonima !28_V	et	f	\N
189135	ekstruktsiooni	?ekstruktsiooni =truktsioo  (SgTer  >eks+truktsioo !26_S	et	f	\N
189136	ekstruktsiooni	?ekstruktsiooni =truktsiooni  (SgN  >eks+truktsiooni !16_S	et	f	\N
189137	ekstruktsiooni	?ekstruktsiooni =truktsiooni  (SgG  >eks+truktsiooni !16_S	et	f	\N
189138	ekstruktsiooni	?ekstruktsiooni =truktsiooni  (SgG  >eks+truktsioon !22_S	et	f	\N
189139	ekstruktsiooni	?ekstruktsiooni =truktsiooni  (SgP  >eks+truktsioon !22_S	et	f	\N
189140	ekstruktsiooni	?ekstruktsiooni =truktsiooni  (SgAdt  >eks+truktsioon !22_S	et	f	\N
189150	pidakse	?pidakse =pidakse  (SgG  >pidakne !02_A	et	f	\N
189151	lõppueksamid	?lõppueksamid =lõppueksami  (PlN  >lõppueksam !02_A	et	f	\N
189152	ülekoolis	ülekoolis =kooli  (SgIn  >üle+kool !22_S	et	f	\N
189153	ülekoolis	ülekoolis =kooli  (PlIn  >üle+kool !22_S	et	f	\N
189174	söödavate	söödavate =söödava  (PlG  >söödav !02_A	et	f	\N
189175	söödavate	"söödav %söö  )TAV_vAS  <sööma ;38_V	et	f	\N
189191	haakama	?haakama =haaka  (Sup  >haakama !29_V	et	f	\N
189192	haakama	?haakama =haakama  (SgG  >haakam !02_A	et	f	\N
189193	haakama	?haakama =ama  (SgN  >haak+ama !17_S	et	f	\N
189194	haakama	?haakama =ama  (SgG  >haak+ama !17_S	et	f	\N
189195	haakama	?haakama =ama  (SgP  >haak+ama !17_S	et	f	\N
189199	teis	teis =te  (PlIn  >sa !00_P	et	f	\N
189200	teis	teis =te  (PlIn  >tee !26_S	et	f	\N
189230	dokumeendid	?dokumeendid =dokumeendi  (PlN  >dokumeent !22_S	et	f	\N
189231	dokumeendid	?dokumeendid =dokumeendi  (IndPrSg2  >dokumeentima !28_V	et	f	\N
189232	dokumeendid	?dokumeendid =umeendi  (PlN  >dok+umeendi !01_S	et	f	\N
189233	dokumeendid	?dokumeendid =umeendi  (PlN  >dok+umeend !02_S	et	f	\N
189234	dokumeendid	?dokumeendid =umeendi  (PlN  >dok+umeent !22_S	et	f	\N
189283	jalgraturit	?jalgraturit =raturi  (SgP  >jalg+raturi !01_S	et	f	\N
189284	jalgraturit	?jalgraturit =raturi  (SgP  >jalg+ratur !02_S	et	f	\N
189299	rangeimad	rangeimad =rangeima  (PlN  >rangeim !02_A	et	f	\N
189301	rangeimad	"rangeim %range  )IM_sA  <range ;01_A	et	f	\N
189310	äriplaani	äriplaani =plaani  (SgG  >äri+plaan !22_S	et	f	\N
189311	äriplaani	äriplaani =plaani  (SgP  >äri+plaan !22_S	et	f	\N
189312	äriplaani	äriplaani =plaani  (SgAdt  >äri+plaan !22_S	et	f	\N
189326	otsustusvõimeline	otsustusvõimeline =võimeline  (SgN  >otsustus+võimeline !12_A	et	f	\N
189327	otsustusvõimeline	"otsustus+võimeline %võime  )LINE_aA  <otsustus+võime ;06_S	et	f	\N
189337	harjumustest	harjumustest =harjumus  (PlEl  >harjumus !11_S	et	f	\N
189005	infoallikas	infoallikas =allika  (SgIn  >info+allikas !02_S	et	f	\N
189006	infoallikas	infoallikas =allikas  (SgN  >info+allikas !02_S	et	f	\N
189036	jjungi	?jjungi =jjungi  (ID  >jjungi !41_D	et	f	\N
189037	jjungi	?jjungi =jjungi  (SgG  >jjunk !22_S	et	f	\N
189038	jjungi	?jjungi =jjungi  (SgP  >jjung !22_S	et	f	\N
189039	jjungi	?jjungi =jjungi  (SgAdt  >jjung !22_S	et	f	\N
189040	jjungi	?jjungi =jjungi  (IndPrPs_  >jjunkima !28_V	et	f	\N
189041	jjungi	?jjungi =jjungi  (ImpPrSg2  >jjunkima !28_V	et	f	\N
189066	inimõigusi	inimõigusi =õigusi  (PlP  >inim+õigus !11_S	et	f	\N
189067	inimõigusi	"inim+õigus %õige  )US_aS  <inim+õige ;01_A	et	f	\N
189091	põlisrahvas	põlisrahvas =rahva  (SgIn  >põlis+rahvas !07_S	et	f	\N
189092	põlisrahvas	põlisrahvas =rahvas  (SgN  >põlis+rahvas !07_S	et	f	\N
189098	linnakodanikuks	linnakodanikuks =uks  (SgN  >linna+kodanik+uks !14_S	et	f	\N
189099	linnakodanikuks	linnakodanikuks =kodaniku  (SgTr  >linna+kodanik !25_S	et	f	\N
189107	kirjatarkus	kirjatarkus =tarkus  (SgN  >kirja+tarkus !11~09_S	et	f	\N
189108	kirjatarkus	"kirja+tarkus %tark  )US_aS  <kirja+tark ;22_AS	et	f	\N
189114	lihtsustamise	lihtsustamise =lihtsustamise  (SgG  >lihtsustamine !12_S	et	f	\N
189115	lihtsustamise	"lihtsustamine %lihtsusta  )MINE_vS  <lihtsustama ;27_V	et	f	\N
189123	trallalala	?trallalala =trallalala  (SgN  >trallalala !01_S	et	f	\N
189125	trallalala	?trallalala =trallalala  (SgG  >trallalala !01_S	et	f	\N
189141	elektriseadmet	?elektriseadmet =seadme  (SgP  >elektri+seadme !06_S	et	f	\N
189147	cvt	### cvt	et	f	\N
189154	teistmodi	?teistmodi =teistmodi  (SgN  >teistmodi !01_S	et	f	\N
189155	teistmodi	?teistmodi =teistmodi  (SgG  >teistmodi !01_S	et	f	\N
189156	teistmodi	?teistmodi =teistmodi  (SgG  >teistmod !02_S	et	f	\N
189157	teistmodi	?teistmodi =modi  (SgN  >teist+modi !17_S	et	f	\N
189158	teistmodi	?teistmodi =modi  (SgG  >teist+modi !17_S	et	f	\N
189159	teistmodi	?teistmodi =modi  (SgP  >teist+modi !17_S	et	f	\N
189160	cvis	### cvis	et	f	\N
189168	triikrauda	triikrauda =rauda  (SgP  >triik+raud !22_S	et	f	\N
189169	triikrauda	triikrauda =rauda  (SgAdt  >triik+raud !22_S	et	f	\N
189170	elektritooded	?elektritooded =elektritoode  (PlN  >elektritoode !16_S	et	f	\N
189185	uskan	?uskan =uska  (IndPrSg1  >uskama !29_V	et	f	\N
189188	uskan	?uskan =uskan  (SgN  >uskan !02_S	et	f	\N
189204	inimened	?inimened =ene  (PlN  >inim+ene !16_S	et	f	\N
189209	yyy	?yyy =yyy  (SgN  >yyy !26_S	et	f	\N
189210	yyy	?yyy =yyy  (SgG  >yyy !26_S	et	f	\N
189235	isik-kaart	isik-kaart =kaar  (SgP  >isik-kaar !13_S	et	f	\N
189236	isik-kaart	isik-kaart =kaart  (SgN  >isik-kaart !22_S	et	f	\N
189238	mobilltelefon	?mobilltelefon =mobilltelefon  (SgN  >mobilltelefon !19_S	et	f	\N
189246	xyy	?xyy =xyy  (SgN  >xyy !26_S	et	f	\N
189247	xyy	?xyy =xyy  (SgG  >xyy !26_S	et	f	\N
189261	lapsest	lapsest =lapse  (SgEl  >laps !14_S	et	f	\N
189262	lapsest	lapsest =lapse  (PlEl  >laps !22_S	et	f	\N
189263	lapsest	lapsest =lapses  (SgP  >lapsene !10_A	et	f	\N
189264	lapsest	"lapsene %lapse  )NE_aA  <laps ;14_S	et	f	\N
189271	jalgratur	?jalgratur =jalgratur  (SgN  >jalgratur !19_S	et	f	\N
189272	jalgratur	?jalgratur =ratur  (SgN  >jalg+ratur !02_S	et	f	\N
189294	konkurentid	### konkurentid	et	f	\N
189324	internetil	?internetil =neti  (SgAd  >inter+neti !16_S	et	f	\N
189325	internetil	?internetil =neti  (SgAd  >inter+nett !22_AS	et	f	\N
189328	reaalsustaju	reaalsustaju =taju  (SgN  >reaalsus+taju !17_S	et	f	\N
189329	reaalsustaju	reaalsustaju =taju  (SgG  >reaalsus+taju !17_S	et	f	\N
189330	reaalsustaju	reaalsustaju =taju  (SgP  >reaalsus+taju !17_S	et	f	\N
189331	realist	realist =realis  (SgP  >realine !12?10_A	et	f	\N
189332	realist	"realine %rea  )LINE_aA  <rida ;18_S	et	f	\N
189333	realist	realist =realist  (SgN  >realist !22_S	et	f	\N
189334	äritegevuses	äritegevuses =use  (PlIn  >äri+tegev+usk !22_S	et	f	\N
189335	äritegevuses	äritegevuses =tegevuse  (SgIn  >äri+tegevus !11_S	et	f	\N
189336	äritegevuses	"äri+tegevus %tegeva  )US_aS  <äri+tegev ;02_A	et	f	\N
189366	acce	?acce =acce  (SgN  >acce !06_S	et	f	\N
189367	acce	?acce =acce  (SgG  >acce !06_S	et	f	\N
189368	acce	?acce =acce  (PlP  >acc !22_S	et	f	\N
189374	arvuti-	arvuti- =arvuti  (SgN  >arvuti !01_S	et	f	\N
189375	arvuti-	arvuti- =arvuti  (SgG  >arvuti !01_S	et	f	\N
189376	arvuti-	arvuti- =uti  (SgG  >arv+utt !22_S	et	f	\N
189387	it-süsteemi	it-süsteemi =süsteemi  (SgG  >it-süsteem !22_S	et	f	\N
189388	it-süsteemi	it-süsteemi =süsteemi  (SgP  >it-süsteem !22_S	et	f	\N
189389	it-süsteemi	it-süsteemi =süsteemi  (SgAdt  >it-süsteem !22_S	et	f	\N
189398	viidudbr	?viidudbr =viidudbr  (SgN  >viidudbr !22_S	et	f	\N
189431	trükkikodas	?trükkikodas =kodas  (SgN  >trükki+kodas !07_S	et	f	\N
189434	rahulda	rahulda =rahulda  (IndPrPs_  >rahuldama !27_V	et	f	\N
189435	rahulda	rahulda =rahulda  (ImpPrSg2  >rahuldama !27_V	et	f	\N
189436	üheksakorrusselises	?üheksakorrusselises =üheksakorrusselise  (SgIn  >üheksakorrusseline !12_A	et	f	\N
189437	üheksakorrusselises	?üheksakorrusselises =korrusselise  (SgIn  >üheksa+korrusseline !12_A	et	f	\N
189438	üheksakorrusselises	?üheksakorrusselises =akorrusselise  (SgIn  >üheks+akorrusseline !12_A	et	f	\N
189163	tõustmine	?tõustmine =tõustmine  (ImpPrSg2  >tõustminema !27_V	et	f	\N
189182	goroskopi	?goroskopi =goroskopi  (SgG  >goroskopp !22_S	et	f	\N
189183	goroskopi	?goroskopi =goroskopi  (IndPrPs_  >goroskoppima !28_V	et	f	\N
189184	goroskopi	?goroskopi =goroskopi  (ImpPrSg2  >goroskoppima !28_V	et	f	\N
189186	alnul	?alnul =alnu  (SgAd  >alnu !01_S	et	f	\N
189187	alnul	?alnul =alnul  (SgN  >alnul !02_S	et	f	\N
189196	juuhus	?juuhus =juuhu  (SgIn  >juuhu !16_S	et	f	\N
189197	juuhus	?juuhus =juuhu  (IndIpfSg3  >juuhuma !27_V	et	f	\N
189198	juuhus	?juuhus =juuhus  (SgN  >juuhus !11~09_S	et	f	\N
189201	moobiiltelefon	?moobiiltelefon =moobiiltelefon  (SgN  >moobiiltelefon !19_S	et	f	\N
189215	poskal	?poskal =poska  (SgAd  >poska !16_S	et	f	\N
189216	poskal	?poskal =poskal  (SgN  >poskal !02_S	et	f	\N
189217	peatusbr	?peatusbr =peatusbr  (SgN  >peatusbr !22_S	et	f	\N
189218	peatusbr	?peatusbr =tusbr  (SgN  >pea+tusbr !22_S	et	f	\N
189219	osalejäid	?osalejäid =osalejäi  (PlN  >osalejäi !26_S	et	f	\N
189220	osalejäid	?osalejäid =osalejäi  (SgP  >osalejäi !26_S	et	f	\N
189221	osalejäid	?osalejäid =osalejäid  (SgN  >osalejäid !22_S	et	f	\N
189222	osalejäid	?osalejäid =lejäi  (PlN  >osa+lejäi !26_S	et	f	\N
189223	osalejäid	?osalejäid =lejäi  (SgP  >osa+lejäi !26_S	et	f	\N
189224	osalejäid	?osalejäid =lejäid  (SgN  >osa+lejäid !22_S	et	f	\N
189225	gucci	?gucci =gucci  (SgN  >gucci !16_S	et	f	\N
189226	gucci	?gucci =gucci  (SgG  >gucci !16_S	et	f	\N
189227	gucci	?gucci =gucci  (SgG  >gucc !22_S	et	f	\N
189228	gucci	?gucci =gucci  (SgP  >gucc !22_S	et	f	\N
189229	gucci	?gucci =gucci  (SgAdt  >gucc !22_S	et	f	\N
189237	pankakaart	?pankakaart =pankakaart  (SgN  >pankakaart !22_S	et	f	\N
189239	rahakottis	?rahakottis =rahakotti  (IndIpfSg3  >rahakottima !28_V	et	f	\N
189240	rahakottis	?rahakottis =rahakottis  (SgN  >rahakottis !09_S	et	f	\N
189250	sünnita	sünnita =sünni  (SgAb  >sünd !22_S	et	f	\N
189251	sünnita	sünnita =sünni  (IndPrIps_  >sündima !28_V	et	f	\N
189252	sünnita	sünnita =sünnita  (IndPrPs_  >sünnitama !27_V	et	f	\N
189253	sünnita	sünnita =sünnita  (ImpPrSg2  >sünnitama !27_V	et	f	\N
189265	välispoolt	?välispoolt =välispoo  (SgAbl  >välispoo !26_S	et	f	\N
189266	välispoolt	?välispoolt =poo  (SgAbl  >välis+poo !26_S	et	f	\N
189267	välispoolt	?välispoolt =spoo  (SgAbl  >väli+spoo !26_S	et	f	\N
189268	välispoolt	?välispoolt =spoolt  (SgN  >väli+spoolt !22_S	et	f	\N
189273	jalgratur	?jalgratur =jalgratur  (SgN  >jalgratur !19_S	et	f	\N
189274	jalgratur	?jalgratur =ratur  (SgN  >jalg+ratur !02_S	et	f	\N
189275	hoidnud	hoidnud =hoid  (PtsPtPs  >hoidma !34_V	et	f	\N
189276	hoidnud	hoidnud =hoidnu  (PlN  >hoidnu !01_S	et	f	\N
189277	hoidnud	"hoidnu %hoid  )NU_vS  <hoidma ;34_V	et	f	\N
189278	hoidnud	hoidnud =hoidnud  (ID  >hoidnud !41_A	et	f	\N
189279	hoidnud	"hoidnud %hoid  )NUD_vA  <hoidma ;34_V	et	f	\N
189289	bankroti	?bankroti =bankroti  (ID  >bankroti !41_D	et	f	\N
189290	bankroti	?bankroti =bankroti  (SgG  >bankrot !02_S	et	f	\N
189291	bankroti	?bankroti =bankroti  (SgG  >bankrott !22_S	et	f	\N
189292	bankroti	?bankroti =bankroti  (IndPrPs_  >bankrottima !28_V	et	f	\N
189293	bankroti	?bankroti =bankroti  (ImpPrSg2  >bankrottima !28_V	et	f	\N
189300	karistused	karistused =karistuse  (PlN  >karistus !11_S	et	f	\N
189302	karistused	"karistus %karista  )US_vS  <karistama ;27_V	et	f	\N
189303	ajaviite	ajaviite =viite  (SgG  >aja+viide !06_S	et	f	\N
189304	ajaviite	ajaviite =viite  (PlP  >aja+viit !22_S	et	f	\N
189305	käivest	?käivest =käives  (SgP  >käives !09_S	et	f	\N
189306	käivest	?käivest =käives  (SgP  >käivene !10_A	et	f	\N
189317	politseiosakonnal	politseiosakonnal =konna  (SgAd  >politsei+osa+konn !22_S	et	f	\N
189318	politseiosakonnal	politseiosakonnal =osakonna  (SgAd  >politsei+osakond !22_S	et	f	\N
189319	arvutita	arvutita =arvuti  (SgAb  >arvuti !01_S	et	f	\N
189320	arvutita	arvutita =tita  (SgN  >arvu+tita !16_S	et	f	\N
189321	arvutita	arvutita =tita  (SgG  >arvu+tita !16_S	et	f	\N
189322	arvutita	arvutita =uti  (SgAb  >arv+utt !22_S	et	f	\N
189323	referaadit	?referaadit =referaadi  (SgP  >referaadi !16_S	et	f	\N
189352	elegantselt	elegantselt =elegantse  (SgAbl  >elegantne !02_A	et	f	\N
189353	elegantselt	elegantselt =elegantse  (PlAbl  >elegants !22_S	et	f	\N
189354	elegantselt	elegantselt =elegantselt  (ID  >elegantselt !41_D	et	f	\N
189355	elegantselt	"elegantselt %elegantse  )LT_mD  <elegantne ;02_A	et	f	\N
189377	reguleerinud	reguleerinud =reguleeri  (PtsPtPs  >reguleerima !28_V	et	f	\N
189378	reguleerinud	reguleerinud =reguleerinu  (PlN  >reguleerinu !01_S	et	f	\N
189379	reguleerinud	"reguleerinu %reguleeri  )NU_vS  <reguleerima ;28_V	et	f	\N
189380	reguleerinud	reguleerinud =reguleerinud  (ID  >reguleerinud !41_A	et	f	\N
189381	reguleerinud	"reguleerinud %reguleeri  )NUD_vA  <reguleerima ;28_V	et	f	\N
189384	ppangandus-	?ppangandus- =ppangandu  (SgIn  >ppangandu !01_S	et	f	\N
189385	ppangandus-	?ppangandus- =ppangandu  (IndIpfSg3  >ppanganduma !27_V	et	f	\N
189386	ppangandus-	?ppangandus- =ppangandus  (SgN  >ppangandus !11_S	et	f	\N
189396	investeerimise	investeerimise =investeerimise  (SgG  >investeerimine !12_S	et	f	\N
189397	investeerimise	"investeerimine %investeeri  )MINE_vS  <investeerima ;28_V	et	f	\N
189244	kroonispan	?kroonispan =kroonispan  (SgN  >kroonispan !19_S	et	f	\N
189245	kroonispan	?kroonispan =ispan  (SgN  >kroon+ispan !02_S	et	f	\N
189254	kuritegelikusest	kuritegelikusest =tegelikuse  (SgEl  >kuri+tegelikus !11?09_S	et	f	\N
189255	kuritegelikusest	"kuri+tegelikus %tegeliku  )US_aS  <kuri+tegelik ;25_A	et	f	\N
189258	vanglast	vanglast =vangla  (SgEl  >vangla !01_S	et	f	\N
189259	vanglast	vanglast =vanglas  (SgP  >vanglane !12?10_S	et	f	\N
189260	vanglast	"vanglane %vangla  )NE_aA  <vangla ;01_S	et	f	\N
189269	ristmikul	ristmikul =ristmiku  (SgAd  >ristmik !25_S	et	f	\N
189270	ristmikul	ristmikul =miku  (SgAd  >rist+mikk !22_S	et	f	\N
189295	tööpartnirid	?tööpartnirid =tööpartniri  (PlN  >tööpartnir !02_S	et	f	\N
189296	tööpartnirid	?tööpartnirid =niri  (PlN  >töö+part+niri !17_S	et	f	\N
189297	tööpartnirid	?tööpartnirid =partniri  (PlN  >töö+partniri !01_S	et	f	\N
189298	tööpartnirid	?tööpartnirid =partniri  (PlN  >töö+partnir !02_S	et	f	\N
189307	kasumist	kasumist =kasumi  (SgEl  >kasum !02_S	et	f	\N
189308	kasumist	kasumist =kasumis  (SgP  >kasumine !12_S	et	f	\N
189309	kasumist	"kasumine %kasumi  )NE_aA  <kasum ;02_S	et	f	\N
189347	lõhnastatud	lõhnastatud =lõhnasta  (PtsPtIps  >lõhnastama !27_V	et	f	\N
189348	lõhnastatud	lõhnastatud =lõhnastatu  (PlN  >lõhnastatu !01_S	et	f	\N
189349	lõhnastatud	"lõhnastatu %lõhnasta  )TU1_vS  <lõhnastama ;27_V	et	f	\N
189350	lõhnastatud	lõhnastatud =lõhnastatud  (ID  >lõhnastatud !41_A	et	f	\N
189351	lõhnastatud	"lõhnastatud %lõhnasta  )TUD_vA  <lõhnastama ;27_V	et	f	\N
189356	päevases	päevases =päevase  (SgIn  >päevane !10_A	et	f	\N
189357	päevases	"päevane %päeva  )NE_aA  <päev ;22_S	et	f	\N
189363	nägusid	nägusid =nägu  (PlP  >nägu !18_S	et	f	\N
189364	nägusid	nägusid =nägusi  (PlN  >nägus !02_A	et	f	\N
189373	välisinvestoreidbr	### välisinvestoreidbr	et	f	\N
189394	pakkuvateks	pakkuvateks =pakkuva  (PlTr  >pakkuv !02_A	et	f	\N
189395	pakkuvateks	"pakkuv %pakku  )V_vA  <pakkuma ;28_V	et	f	\N
189399	eksportkaubaartikkliks	?eksportkaubaartikkliks =eksportkaubaartikkli  (KndPrPs  >eksportkaubaartikklima !28_V	et	f	\N
189400	eksportkaubaartikkliks	?eksportkaubaartikkliks =artikkli  (SgTr  >eks+port+kauba+artikkli !01_S	et	f	\N
189401	eksportkaubaartikkliks	?eksportkaubaartikkliks =artikkli  (SgTr  >eks+port+kauba+artikkl !22_S	et	f	\N
189408	imagoloogia	?imagoloogia =imagoloogia  (SgN  >imagoloogia !01_S	et	f	\N
189409	imagoloogia	?imagoloogia =imagoloogia  (SgG  >imagoloogia !01_S	et	f	\N
189424	kvalikfikatsioonist	?kvalikfikatsioonist =kvalikfikatsiooni  (SgEl  >kvalikfikatsiooni !16_S	et	f	\N
189425	kvalikfikatsioonist	?kvalikfikatsioonist =kvalikfikatsiooni  (SgEl  >kvalikfikatsioon !22_S	et	f	\N
189426	kvalikfikatsioonist	?kvalikfikatsioonist =kvalikfikatsioonis  (SgP  >kvalikfikatsioonis !09_S	et	f	\N
189447	oigatab	?oigatab =oigata  (IndPrSg3  >oigatama !27_V	et	f	\N
189458	annaksid	annaksid =anna  (KndPrSg2  >andma !34_V	et	f	\N
189459	annaksid	annaksid =anna  (KndPrPl3  >andma !34_V	et	f	\N
189464	painduv	painduv =paindu  (PtsPrPs  >painduma !27_V	et	f	\N
189465	painduv	painduv =painduv  (SgN  >painduv !02_A	et	f	\N
189467	painduv	"painduv %paindu  )V_vA  <painduma ;27_V	et	f	\N
189475	õppemise	?õppemise =õppemise  (SgG  >õppemine !12_S	et	f	\N
189479	turismifirma	turismifirma =firma  (SgN  >turismi+firma !16_S	et	f	\N
189480	turismifirma	turismifirma =firma  (SgG  >turismi+firma !16_S	et	f	\N
189481	täpsemat	täpsemat =täpsema  (SgP  >täpsem !02_A	et	f	\N
189482	täpsemat	"täpsem %täpse  )M_cA  <täpne ;02_A	et	f	\N
189512	lll	### lll	et	f	\N
189518	ledo	?ledo =ledo  (SgN  >ledo !17~16_S	et	f	\N
189519	ledo	?ledo =ledo  (SgG  >ledo !17~16_S	et	f	\N
189520	ledo	?ledo =ledo  (SgP  >ledo !17_S	et	f	\N
189526	toitlus	toitlus =toitlus  (SgN  >toitlus !11~09_S	et	f	\N
189527	toitlus	"toitlus %toitlase  )US_aS  <toitlane ;12_S	et	f	\N
189528	123-	### 123-	et	f	\N
189530	rrr	### rrr	et	f	\N
189548	bank	?bank =bank  (SgN  >bank !22_S	et	f	\N
189549	teenindust	teenindust =teenindus  (SgP  >teenindus !11_S	et	f	\N
189550	teenindust	"teenindus %teeninda  )US_vS  <teenindama ;27_V	et	f	\N
189575	maksmiseks	maksmiseks =maksmise  (SgTr  >maksmine !12?10_S	et	f	\N
189576	maksmiseks	"maksmine %maks  )MINE_vS  <maksma ;32_V	et	f	\N
189581	sõlmimisel	sõlmimisel =sõlmimise  (SgAd  >sõlmimine !12_S	et	f	\N
189582	sõlmimisel	"sõlmimine %sõlmi  )MINE_vS  <sõlmima ;28_V	et	f	\N
189583	määrada	### määrada	et	f	\N
189598	kiiremaks	kiiremaks =kiirema  (SgTr  >kiirem !02_A	et	f	\N
189599	kiiremaks	"kiirem %kiire  )M_cA  <kiire ;01_A	et	f	\N
189600	kiiremaks	"kiirem %kiire  )M_cA  <kiire ;06_AS	et	f	\N
189601	kiiremaks	kiiremaks =maks  (SgN  >kiire+maks !22_S	et	f	\N
189602	kiiremaks	kiiremaks =ema  (SgTr  >kiir+ema !17_S	et	f	\N
189622	pikkuses	pikkuses =pikkuse  (SgIn  >pikkus !11~09_S	et	f	\N
189623	pikkuses	"pikkus %pikk  )US_aS  <pikk ;22_AS	et	f	\N
189624	pikkuses	pikkuses =pikkuse  (SgIn  >pikkune !12~10_A	et	f	\N
189625	pikkuses	pikkuses =use  (PlIn  >pikk+usk !22_S	et	f	\N
189630	poolteise	?poolteise =poolteise  (PlP  >poolteis !22_S	et	f	\N
189631	poolteise	?poolteise =poolteise  (IndPrPs_  >poolteisema !27_V	et	f	\N
189632	poolteise	?poolteise =poolteise  (ImpPrSg2  >poolteisema !27_V	et	f	\N
189338	harjumustest	"harjumus %harju  )MUS_vS  <harjuma ;27_V	et	f	\N
189339	harjumustest	harjumustest =test  (SgN  >harjumus+test !22_S	et	f	\N
189340	harjumustest	harjumustest =muste  (PlEl  >harju+must !22_AS	et	f	\N
189358	õmmeldud	õmmeldud =õmmel  (PtsPtIps  >õmblema !30_V	et	f	\N
189359	õmmeldud	õmmeldud =õmmeldu  (PlN  >õmmeldu !01_S	et	f	\N
189360	õmmeldud	"õmmeldu %õmmel  )TU1_vS  <õmblema ;30_V	et	f	\N
189361	õmmeldud	õmmeldud =õmmeldud  (ID  >õmmeldud !41_A	et	f	\N
189362	õmmeldud	"õmmeldud %õmmel  )TUD_vA  <õmblema ;30_V	et	f	\N
189365	investoritega	?investoritega =investori  (PlKom  >investor !02_S	et	f	\N
189390	esindused	esindused =esinduse  (PlN  >esindus !11_S	et	f	\N
189391	esindused	"esindus %esinda  )US_vS  <esindama ;27_V	et	f	\N
189418	raamises	raamises =raamise  (SgIn  >raamine !10_A	et	f	\N
189419	raamises	"raamine %raami  )NE_aA  <raam ;22_S	et	f	\N
189429	kuritegija	kuritegija =tegija  (SgN  >kuri+tegija !01_S	et	f	\N
189430	kuritegija	kuritegija =tegija  (SgG  >kuri+tegija !01_S	et	f	\N
189432	perefirma	perefirma =firma  (SgN  >pere+firma !16_S	et	f	\N
189433	perefirma	perefirma =firma  (SgG  >pere+firma !16_S	et	f	\N
189440	viietoaline	viietoaline =toaline  (SgN  >viie+toaline !12?10_A	et	f	\N
189441	viietoaline	"viie+toaline %toa  )LINE_aA  <viie+tuba ;18_S	et	f	\N
189442	ehitamisel	ehitamisel =ehitamise  (SgAd  >ehitamine !12_S	et	f	\N
189443	ehitamisel	"ehitamine %ehita  )MINE_vS  <ehitama ;27_V	et	f	\N
189454	toodega	### toodega	et	f	\N
189460	välimust	välimust =välimus  (SgP  >välimus !11_S	et	f	\N
189461	välimust	välimust =must  (SgN  >väli+must !22_AS	et	f	\N
189462	mittepikk	mittepikk =pikk  (SgN  >mitte+pikk !22_S	et	f	\N
189463	mittepikk	mittepikk =pikk  (SgN  >mitte+pikk !22_AS	et	f	\N
189466	kehabr	?kehabr =kehabr  (SgN  >kehabr !22_S	et	f	\N
189472	õpeaine	?õpeaine =õpeaine  (SgN  >õpeaine !16_S	et	f	\N
189473	õpeaine	?õpeaine =õpeaine  (SgG  >õpeaine !16_S	et	f	\N
189474	õpeaine	?õpeaine =õpeaine  (PlP  >õpeain !19_S	et	f	\N
189483	pakutavate	pakutavate =pakutava  (PlG  >pakutav !02_A	et	f	\N
189484	pakutavate	"pakutav %paku  )TAV_vAS  <pakkuma ;28_V	et	f	\N
189485	pakutavate	"pakutav %pakuta  )V_vA  <pakutama ;27_V	et	f	\N
189486	riiga	?riiga =rii  (SgKom  >rii !26_S	et	f	\N
189487	riiga	?riiga =riiga  (SgN  >riiga !16_S	et	f	\N
189488	riiga	?riiga =riiga  (SgG  >riiga !16_S	et	f	\N
189489	riiga	?riiga =riiga  (IndPrPs_  >riigama !29_V	et	f	\N
189490	riiga	?riiga =riiga  (ImpPrSg2  >riigama !29_V	et	f	\N
189521	visiitist	?visiitist =visiiti  (SgEl  >visiiti !16_S	et	f	\N
189522	visiitist	?visiitist =visiitis  (SgP  >visiitis !11_S	et	f	\N
189540	arbu	arbu =arbu  (SgG  >arp !22_S	et	f	\N
189541	arbu	arbu =arbu  (IndPrPs_  >arbuma !28_V	et	f	\N
189542	arbu	arbu =arbu  (ImpPrSg2  >arbuma !28_V	et	f	\N
189555	sularaha	sularaha =raha  (SgN  >sula+raha !17_S	et	f	\N
189556	sularaha	sularaha =raha  (SgG  >sula+raha !17_S	et	f	\N
189557	sularaha	sularaha =raha  (SgG  >sula+rahk !22_S	et	f	\N
189558	sularaha	sularaha =raha  (SgP  >sula+raha !17_S	et	f	\N
189562	mobiilimakse	?mobiilimakse =mobiilimakse  (SgG  >mobiilimakne !02_A	et	f	\N
189563	mobiilimakse	?mobiilimakse =imakse  (SgG  >mobiil+imakne !02_A	et	f	\N
189564	koodkroonidsendid	?koodkroonidsendid =koodkroonidsendi  (PlN  >koodkroonidsent !22_S	et	f	\N
189565	koodkroonidsendid	?koodkroonidsendid =koodkroonidsendi  (IndPrSg2  >koodkroonidsentima !28_V	et	f	\N
189567	kinnitamiseks	kinnitamiseks =kinnitamise  (SgTr  >kinnitamine !12_S	et	f	\N
189568	kinnitamiseks	"kinnitamine %kinnita  )MINE_vS  <kinnitama ;27_V	et	f	\N
189586	sisenemiseks	sisenemiseks =sisenemise  (SgTr  >sisenemine !12_S	et	f	\N
189587	sisenemiseks	"sisenemine %sisene  )MINE_vS  <sisenema ;27_V	et	f	\N
189593	maksmised	maksmised =maksmise  (PlN  >maksmine !12?10_S	et	f	\N
189594	maksmised	"maksmine %maks  )MINE_vS  <maksma ;32_V	et	f	\N
189595	odavamaks	odavamaks =odavama  (SgTr  >odavam !02_A	et	f	\N
189596	odavamaks	"odavam %odava  )M_cA  <odav ;02_A	et	f	\N
189597	odavamaks	odavamaks =maks  (SgN  >odava+maks !22_S	et	f	\N
189609	adekvaatselt	adekvaatselt =adekvaatse  (SgAbl  >adekvaatne !02_A	et	f	\N
189610	adekvaatselt	adekvaatselt =adekvaatselt  (ID  >adekvaatselt !41_D	et	f	\N
189611	adekvaatselt	"adekvaatselt %adekvaatse  )LT_mD  <adekvaatne ;02_A	et	f	\N
189618	piidalaua	?piidalaua =piidalaua  (SgN  >piidalaua !01_S	et	f	\N
189619	piidalaua	?piidalaua =piidalaua  (SgG  >piidalaua !01_S	et	f	\N
189643	mistahes	mistahes =tahe  (PlIn  >mis+tahk !22_S	et	f	\N
189644	mistahes	mistahes =tahe  (PlIn  >mis+taht !22_S	et	f	\N
189645	teosest	teosest =teose  (SgEl  >teos !09_S	et	f	\N
189646	teosest	teosest =teoses  (SgP  >teosene !10_A	et	f	\N
189647	teosest	"teosene %teose  )NE_aA  <teos ;09_S	et	f	\N
189650	temaatika	temaatika =temaatika  (SgN  >temaatika !01_S	et	f	\N
189651	temaatika	temaatika =temaatika  (SgG  >temaatika !01_S	et	f	\N
189658	ajaruumi	ajaruumi =ruumi  (SgG  >aja+ruum !22_S	et	f	\N
189659	ajaruumi	ajaruumi =ruumi  (SgP  >aja+ruum !22_S	et	f	\N
189660	ajaruumi	ajaruumi =ruumi  (SgAdt  >aja+ruum !22_S	et	f	\N
189681	bock	?bock =bock  (SgN  >bock !22_S	et	f	\N
189698	mättiku	?mättiku =mättiku  (SgN  >mättiku !01_S	et	f	\N
189393	massilist	"massiline %massi  )LINE_aA  <mass ;22_S	et	f	\N
189403	haugutav	haugutav =haugu  (PtsPrIps  >haukuma !28_V	et	f	\N
189404	haugutav	haugutav =hauguta  (PtsPrPs  >haugutama !27_V	et	f	\N
189405	haugutav	haugutav =haugutav  (SgN  >haugutav !02_A	et	f	\N
189406	haugutav	"haugutav %haugu  )TAV_vAS  <haukuma ;28_V	et	f	\N
189407	haugutav	"haugutav %hauguta  )V_vA  <haugutama ;27_V	et	f	\N
189410	tegevustes	tegevustes =tegevus  (PlIn  >tegevus !11_S	et	f	\N
189411	tegevustes	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
189412	tegevustes	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
189413	tegevustes	tegevustes =us  (PlIn  >tegev+uks !14_S	et	f	\N
189414	kommenteerimine	kommenteerimine =kommenteerimine  (SgN  >kommenteerimine !12_S	et	f	\N
189415	kommenteerimine	"kommenteerimine %kommenteeri  )MINE_vS  <kommenteerima ;28_V	et	f	\N
189422	narkotikumit	?narkotikumit =tikumi  (SgP  >narko+tikumi !01_S	et	f	\N
189423	narkotikumit	?narkotikumit =tikumi  (SgP  >narko+tikum !02_S	et	f	\N
189444	aitanud	?aitanud =aitanu  (PlN  >aitanu !01_S	et	f	\N
189445	aitanud	?aitanud =aitanu  (IndPrSg2  >aitanuma !27_V	et	f	\N
189446	aitanud	?aitanud =aitanud  (ID  >aitanud !41_A	et	f	\N
189448	sabo	?sabo =sabo  (SgN  >sabo !17~16_S	et	f	\N
189449	sabo	?sabo =sabo  (SgG  >sabo !17~16_S	et	f	\N
189450	sabo	?sabo =sabo  (SgP  >sabo !17_S	et	f	\N
189469	õppemateriaaliga	õppemateriaaliga =iga  (SgN  >õppe+materiaal+iga !18_S	et	f	\N
189470	õppemateriaaliga	õppemateriaaliga =iga  (SgP  >õppe+materiaal+iga !18_S	et	f	\N
189476	kohvita	kohvita =kohvi  (SgAb  >kohv !22_S	et	f	\N
189477	kohvita	kohvita =kohvita  (IndPrPs_  >kohvitama !27_V	et	f	\N
189478	kohvita	kohvita =kohvita  (ImpPrSg2  >kohvitama !27_V	et	f	\N
189491	töötajat	töötajat =töötaja  (SgP  >töötaja !01_S	et	f	\N
189492	töötajat	"töötaja %tööta  )JA_vS  <töötama ;27_V	et	f	\N
189501	järelepärimiskirja	järelepärimiskirja =kirja  (SgG  >järele+päri+mis+kiri !24_S	et	f	\N
189502	järelepärimiskirja	järelepärimiskirja =kirja  (SgP  >järele+päri+mis+kiri !24_S	et	f	\N
189503	järelepärimiskirja	järelepärimiskirja =kirja  (SgAdt  >järele+päri+mis+kiri !24_S	et	f	\N
189504	reisidefirmasse	?reisidefirmasse =reisidefirma  (SgIll  >reisidefirma !16_S	et	f	\N
189505	reisidefirmasse	?reisidefirmasse =reisidefirmas  (SgAdt  >reisidefirmane !12_A	et	f	\N
189506	reisidefirmasse	?reisidefirmasse =reisidefirmasse  (SgG  >reisidefirmasne !02_A	et	f	\N
189507	reisidefirmasse	?reisidefirmasse =reisidefirmasse  (PlP  >reisidefirmass !22_S	et	f	\N
189508	reisidefirmasse	?reisidefirmasse =defirma  (SgIll  >reisi+defirma !01_S	et	f	\N
189509	reisidefirmasse	?reisidefirmasse =defirmas  (SgAdt  >reisi+defirmane !12_A	et	f	\N
189510	reisidefirmasse	?reisidefirmasse =defirmasse  (SgG  >reisi+defirmasne !02_A	et	f	\N
189511	reisidefirmasse	?reisidefirmasse =defirmasse  (PlP  >reisi+defirmass !22_S	et	f	\N
189515	teenindusmajast	teenindusmajast =maja  (SgEl  >teenindus+maja !17_S	et	f	\N
189516	teenindusmajast	teenindusmajast =majas  (SgP  >teenindus+majane !10_A	et	f	\N
189517	teenindusmajast	"teenindus+majane %maja  )NE_aA  <teenindus+maja ;17_S	et	f	\N
189529	ttt	### ttt	et	f	\N
189543	lõikus	lõikus =lõiku  (IndIpfSg3  >lõikuma !27_V	et	f	\N
189544	lõikus	lõikus =lõiku  (IndIpfSg3  >lõikuma !28_V	et	f	\N
189545	lõikus	lõikus =lõikus  (SgN  >lõikus !11~09_S	et	f	\N
189584	astumisega	astumisega =astumise  (SgKom  >astumine !12_S	et	f	\N
189585	astumisega	"astumine %astu  )MINE_vS  <astuma ;28_V	et	f	\N
189613	härrastemaja-ärklist	härrastemaja-ärklist =ärkli  (SgEl  >härrastemaja-ärkel !02_S	et	f	\N
189614	härrastemaja-ärklist	härrastemaja-ärklist =ärklis  (SgP  >härrastemaja-ärkline !12~10_A	et	f	\N
189615	härrastemaja-ärklist	"härrastemaja-ärkline %ärkli  )NE_aA  <härrastemaja-ärkel ;02_S	et	f	\N
189653	sidumine	sidumine =sidumine  (SgN  >sidumine !12_S	et	f	\N
189655	sidumine	"sidumine %sidu  )MINE_vS  <siduma ;28_V	et	f	\N
189670	esiletoomisel	esiletoomisel =toomise  (SgAd  >esile+toomine !12?10_S	et	f	\N
189671	esiletoomisel	"esile+toomine %toomi  )NE_aA  <esile+toom ;22_S	et	f	\N
189672	inimvaimu	inimvaimu =vaimu  (SgG  >inim+vaim !22_S	et	f	\N
189673	inimvaimu	inimvaimu =vaimu  (SgP  >inim+vaim !22_S	et	f	\N
189674	inimvaimu	inimvaimu =vaimu  (SgAdt  >inim+vaim !22_S	et	f	\N
189675	inimvaimu	inimvaimu =vaimu  (PlP  >inim+vaim !22_S	et	f	\N
189687	schlüsserburgi	?schlüsserburgi =schlüsserburgi  (SgG  >schlüsserburk !22_S	et	f	\N
189688	schlüsserburgi	?schlüsserburgi =schlüsserburgi  (SgP  >schlüsserburg !22_S	et	f	\N
189689	schlüsserburgi	?schlüsserburgi =schlüsserburgi  (SgAdt  >schlüsserburg !22_S	et	f	\N
189690	schlüsserburgi	?schlüsserburgi =schlüsserburgi  (IndPrPs_  >schlüsserburkima !28_V	et	f	\N
189691	schlüsserburgi	?schlüsserburgi =schlüsserburgi  (ImpPrSg2  >schlüsserburkima !28_V	et	f	\N
189692	schlüsserburgi	?schlüsserburgi =schlüsserbur  (SgN^  >schlüsserbur !19_S	et	f	\N
189771	nimisõnakorduspiidalaua	?nimisõnakorduspiidalaua =nimisõnakorduspiidalaua  (SgN  >nimisõnakorduspiidalaua !01_S	et	f	\N
189772	nimisõnakorduspiidalaua	?nimisõnakorduspiidalaua =nimisõnakorduspiidalaua  (SgG  >nimisõnakorduspiidalaua !01_S	et	f	\N
189773	nimisõnakorduspiidalaua	?nimisõnakorduspiidalaua =piidalaua  (SgN  >nimi+sõna+kordus+piidalaua !01_S	et	f	\N
189774	nimisõnakorduspiidalaua	?nimisõnakorduspiidalaua =piidalaua  (SgG  >nimi+sõna+kordus+piidalaua !01_S	et	f	\N
189402	tõusnd	?tõusnd =tõusnd  (SgN  >tõusnd !22_S	et	f	\N
189416	kuritegusid	kuritegusid =tegu  (PlP  >kuri+tegu !18_S	et	f	\N
189417	kuritegusid	kuritegusid =tegusi  (PlN  >kuri+tegus !02_A	et	f	\N
189420	jõukus	jõukus =jõukus  (SgN  >jõukus !11~09_S	et	f	\N
189421	jõukus	"jõukus %jõuka  )US_aS  <jõukas ;02_A	et	f	\N
189427	vabanemistel	vabanemistel =vabanemis  (PlAd  >vabanemine !12_S	et	f	\N
189428	vabanemistel	"vabanemine %vabane  )MINE_vS  <vabanema ;27_V	et	f	\N
189455	tagastaksid	tagastaksid =tagasta  (KndPrSg2  >tagastama !27_V	et	f	\N
189456	tagastaksid	tagastaksid =tagasta  (KndPrPl3  >tagastama !27_V	et	f	\N
189457	tagastaksid	tagastaksid =taksi  (PlN  >tagas+taks !22_S	et	f	\N
189468	lõpetasi	?lõpetasi =lõpetasi  (PlP  >lõpetane !12_A	et	f	\N
189471	õpelased	?õpelased =õpelase  (PlN  >õpelane !12_S	et	f	\N
189493	pakkumistest	pakkumistest =pakkumis  (PlEl  >pakkumine !12_S	et	f	\N
189494	pakkumistest	"pakkumine %pakku  )MINE_vS  <pakkuma ;28_V	et	f	\N
189495	pakkumistest	pakkumistest =test  (SgN  >pakkumis+test !22_S	et	f	\N
189523	majutus	majutus =majutu  (IndIpfSg3  >majutuma !27_V	et	f	\N
189524	majutus	majutus =majutus  (SgN  >majutus !11_S	et	f	\N
189525	majutus	"majutus %majuta  )US_vS  <majutama ;27_V	et	f	\N
189533	liiklusõnnetus	liiklusõnnetus =õnnetu  (SgIn  >liiklus+õnnetu !01_A	et	f	\N
189534	liiklusõnnetus	"liiklus+õnnetu %õnne  )TU2_kA  <liiklus+õnn ;22_S	et	f	\N
189535	liiklusõnnetus	liiklusõnnetus =õnnetus  (SgN  >liiklus+õnnetus !11_S	et	f	\N
189536	liiklusõnnetus	"liiklus+õnnetus %õnne  )TUS2_aS  <liiklus+õnn ;22_S	et	f	\N
189537	sillade	?sillade =silla  (PlG  >silla !16_S	et	f	\N
189546	liikluspolitsei	liikluspolitsei =politsei  (SgN  >liiklus+politsei !26_S	et	f	\N
189547	liikluspolitsei	liikluspolitsei =politsei  (SgG  >liiklus+politsei !26_S	et	f	\N
189566	sumass	?sumass =sumass  (SgN  >sumass !22_S	et	f	\N
189588	tolli-	tolli- =tolli  (SgG  >toll !22_S	et	f	\N
189589	tolli-	tolli- =tolli  (SgP  >toll !22_S	et	f	\N
189590	tolli-	tolli- =tolli  (SgAdt  >toll !22_S	et	f	\N
189591	tolli-	tolli- =tolli  (IndPrPs_  >tollima !28_V	et	f	\N
189592	tolli-	tolli- =tolli  (ImpPrSg2  >tollima !28_V	et	f	\N
189605	kõrvutavlingvistiline	?kõrvutavlingvistiline =kõrvutavlingvistiline  (SgN  >kõrvutavlingvistiline !12_A	et	f	\N
189606	kõrvutavlingvistiline	?kõrvutavlingvistiline =kõrvutavlingvistiline  (PlP  >kõrvutavlingvistilin !19_S	et	f	\N
189607	kõrvutavlingvistiline	?kõrvutavlingvistiline =tavlingvistiline  (SgN  >kõrvu+tavlingvistiline !12_A	et	f	\N
189608	kõrvutavlingvistiline	?kõrvutavlingvistiline =tavlingvistiline  (PlP  >kõrvu+tavlingvistilin !19_S	et	f	\N
189616	vahelisel	vahelisel =vahelise  (SgAd  >vaheline !12_A	et	f	\N
189617	vahelisel	"vaheline %vahe  )LINE_aA  <vahe ;16_S	et	f	\N
189620	käeliigutusega	käeliigutusega =liigutuse  (SgKom  >käe+liigutus !11_S	et	f	\N
189621	käeliigutusega	"käe+liigutus %liigu  )TUS2_aS  <käe+liik ;22_S	et	f	\N
189664	lähtekohaks	lähtekohaks =koha  (SgTr  >lähte+koha !17_S	et	f	\N
189665	lähtekohaks	lähtekohaks =koha  (SgTr  >lähte+koht !22_S	et	f	\N
189666	peituvate	peituvate =peituva  (PlG  >peituv !02_A	et	f	\N
189667	peituvate	"peituv %peitu  )V_vA  <peituma ;27_V	et	f	\N
189679	timotheus	?timotheus =timotheu  (SgIn  >timotheu !26_S	et	f	\N
189680	timotheus	?timotheus =timotheus  (SgN  >timotheus !11_S	et	f	\N
189693	kasematti	kasematti =matti  (SgP  >kase+matt !22_SA	et	f	\N
189694	kasematti	kasematti =matti  (SgAdt  >kase+matt !22_SA	et	f	\N
189700	avaldaja	avaldaja =avaldaja  (SgN  >avaldaja !01_S	et	f	\N
189703	avaldaja	"avaldaja %avalda  )JA_vS  <avaldama ;27_V	et	f	\N
189705	avaldaja	avaldaja =avaldaja  (SgG  >avaldaja !01_S	et	f	\N
189709	ühtlustanudkross	?ühtlustanudkross =ühtlustanudkross  (SgN  >ühtlustanudkross !22_S	et	f	\N
189710	ühtlustanudkross	?ühtlustanudkross =lustanudkross  (SgN  >üht+lustanudkross !22_S	et	f	\N
189715	pealkirjast	pealkirjast =kirja  (SgEl  >peal+kiri !24_S	et	f	\N
189716	pealkirjast	pealkirjast =kirjas  (SgP  >peal+kirjane !10_A	et	f	\N
189717	pealkirjast	"peal+kirjane %kirja  )NE_aA  <peal+kiri ;24_S	et	f	\N
189718	sõnaraamatustjohan	?sõnaraamatustjohan =sõnaraamatustjohan  (SgN  >sõnaraamatustjohan !19_S	et	f	\N
189719	sõnaraamatustjohan	?sõnaraamatustjohan =atustjohan  (SgN  >sõna+raam+atustjohan !19_S	et	f	\N
189720	sõnaraamatustjohan	?sõnaraamatustjohan =raamatustjohan  (SgN  >sõna+raamatustjohan !19_S	et	f	\N
189726	sõnastikust	sõnastikust =sõnastiku  (SgEl  >sõnastik !25_S	et	f	\N
189727	sõnastikust	sõnastikust =sõnastikus  (SgP  >sõnastikune !10?12_A	et	f	\N
189728	sõnastikust	"sõnastikune %sõnastiku  )NE_aA  <sõnastik ;25_S	et	f	\N
189730	venekeelsetest	venekeelsetest =sete  (PlEl  >vene+keel+sett !22_S	et	f	\N
189731	venekeelsetest	venekeelsetest =keelse  (PlEl  >vene+keelne !02_A	et	f	\N
189737	milletõttu	milletõttu =tõttu  (SgP  >mille+tõtt !22_S	et	f	\N
189738	milletõttu	milletõttu =tõttu  (SgAdt  >mille+tõtt !22_S	et	f	\N
189786	erladi	?erladi =erladi  (SgN  >erladi !01_S	et	f	\N
189787	erladi	?erladi =erladi  (SgG  >erladi !01_S	et	f	\N
189823	seletav	seletav =seleta  (PtsPrPs  >seletama !27_V	et	f	\N
189824	seletav	seletav =seletav  (SgN  >seletav !02_A	et	f	\N
189825	seletav	"seletav %seleta  )V_vA  <seletama ;27_V	et	f	\N
189838	httpvene-eestiaseee	?httpvene-eestiaseee =eestiaseee  (SgN  >httpvene-eestiaseee !26_S	et	f	\N
189439	üheksakorrusselises	?üheksakorrusselises =ksakorrusselise  (SgIn  >ühe+ksakorrusseline !12_A	et	f	\N
189451	venis	venis =veni  (SgIn  >veni !17_S	et	f	\N
189452	venis	venis =veni  (IndIpfSg3  >venima !27_V	et	f	\N
189453	venis	venis =venis  (SgN  >venis !09_S	et	f	\N
189496	pakkumised	pakkumised =pakkumise  (PlN  >pakkumine !12_S	et	f	\N
189497	pakkumised	"pakkumine %pakku  )MINE_vS  <pakkuma ;28_V	et	f	\N
189498	ekskursiooniprogramm	?ekskursiooniprogramm =ekskursiooniprogramm  (SgN  >ekskursiooniprogramm !22_S	et	f	\N
189499	ekskursiooniprogramm	?ekskursiooniprogramm =ooniprogramm  (SgN  >eks+kursi+ooniprogramm !22_S	et	f	\N
189500	ekskursiooniprogramm	?ekskursiooniprogramm =kursiooniprogramm  (SgN  >eks+kursiooniprogramm !22_S	et	f	\N
189513	personalijuhataja	personalijuhataja =juhataja  (SgN  >personali+juhataja !01_S	et	f	\N
189514	personalijuhataja	personalijuhataja =juhataja  (SgG  >personali+juhataja !01_S	et	f	\N
189531	liiklusõnnetuse	liiklusõnnetuse =õnnetuse  (SgG  >liiklus+õnnetus !11_S	et	f	\N
189532	liiklusõnnetuse	"liiklus+õnnetus %õnne  )TUS2_aS  <liiklus+õnn ;22_S	et	f	\N
189538	xxxyyy	?xxxyyy =xxxyyy  (SgN  >xxxyyy !26_S	et	f	\N
189539	xxxyyy	?xxxyyy =xxxyyy  (SgG  >xxxyyy !26_S	et	f	\N
189551	mobiilitelefoniga	?mobiilitelefoniga =mobiilitelefoni  (SgKom  >mobiilitelefon !19_S	et	f	\N
189552	mobiilitelefoniga	?mobiilitelefoniga =itelefoni  (SgKom  >mobiil+itelefon !19_S	et	f	\N
189553	ettevõtja	ettevõtja =võtja  (SgN  >ette+võtja !01_S	et	f	\N
189554	ettevõtja	ettevõtja =võtja  (SgG  >ette+võtja !01_S	et	f	\N
189559	mobiiliga	mobiiliga =mobiili  (SgKom  >mobiil !22_S	et	f	\N
189560	mobiiliga	mobiiliga =iga  (SgN  >mobiil+iga !18_S	et	f	\N
189561	mobiiliga	mobiiliga =iga  (SgP  >mobiil+iga !18_S	et	f	\N
189569	senti	senti =senti  (SgP  >sent !22_S	et	f	\N
189570	senti	senti =senti  (SgAdt  >sent !22_S	et	f	\N
189571	turvakoodi	turvakoodi =koodi  (SgG  >turva+kood !22_S	et	f	\N
189572	turvakoodi	turvakoodi =koodi  (SgG  >turva+koot !22_S	et	f	\N
189573	turvakoodi	turvakoodi =koodi  (SgP  >turva+kood !22_S	et	f	\N
189574	turvakoodi	turvakoodi =koodi  (SgAdt  >turva+kood !22_S	et	f	\N
189577	sõlmida	sõlmida =sõlmi  (Inf  >sõlmima !28_V	et	f	\N
189578	sõlmida	sõlmida =ida  (SgN  >sõlm+ida !17_S	et	f	\N
189579	sõlmida	sõlmida =ida  (SgG  >sõlm+ida !17_S	et	f	\N
189580	sõlmida	sõlmida =ida  (SgP  >sõlm+ida !17_S	et	f	\N
189603	avanevaid	avanevaid =avaneva  (PlP  >avanev !02_A	et	f	\N
189604	avanevaid	"avanev %avane  )V_vA  <avanema ;27_V	et	f	\N
189612	16-ndal	### 16-ndal	et	f	\N
189626	pahemale	pahemale =pahema  (SgAll  >pahem !02_A	et	f	\N
189627	pahemale	"pahem %pahe  )M_cA  <paha ;17_AS	et	f	\N
189628	pahemale	pahemale =ale  (SgN  >pahem+ale !16_S	et	f	\N
189629	pahemale	pahemale =ale  (SgG  >pahem+ale !16_S	et	f	\N
189648	luuletajana	luuletajana =luuletaja  (SgEs  >luuletaja !01_S	et	f	\N
189649	luuletajana	"luuletaja %luuleta  )JA_vS  <luuletama ;27_V	et	f	\N
189656	fantaasiavabadusega	fantaasiavabadusega =vabaduse  (SgKom  >fantaasia+vabadus !11_S	et	f	\N
189657	fantaasiavabadusega	"fantaasia+vabadus %vaba  )US_aS  <fantaasia+vaba ;17_A	et	f	\N
189661	keisrikotta	keisrikotta =kotta  (SgP  >keisri+kott !22_S	et	f	\N
189662	keisrikotta	keisrikotta =kotta  (SgAdt  >keisri+koda !18_S	et	f	\N
189663	keisrikotta	keisrikotta =kotta  (SgAdt  >keisri+kott !22_S	et	f	\N
189668	tahkude	tahkude =tahku  (PlG  >tahk !22_S	et	f	\N
189669	tahkude	tahkude =ude  (SgN  >tahk+ude !04_S	et	f	\N
189695	timo	?timo =timo  (SgN  >timo !17~16_S	et	f	\N
189696	timo	?timo =timo  (SgG  >timo !17~16_S	et	f	\N
189697	timo	?timo =timo  (SgP  >timo !17_S	et	f	\N
189706	loetavaks	loetavaks =loetava  (SgTr  >loetav !02_AS	et	f	\N
189707	loetavaks	"loetav %loe  )TAV_vAS  <lugema ;28_V	et	f	\N
189708	loetavaks	"loetav %loeta  )V_vA  <loetama ;27_V	et	f	\N
189732	vastetest	vastetest =vaste  (PlEl  >vaste !06_S	et	f	\N
189733	vastetest	vastetest =e  (PlEl  >vast+esi !15_S	et	f	\N
189742	sõnaks	sõnaks =sõna  (SgTr  >sõna !17_S	et	f	\N
189743	sõnaks	sõnaks =sõna  (KndPrPs  >sõnama !27_V	et	f	\N
189744	struktuuriliselt	struktuuriliselt =struktuurilise  (SgAbl  >struktuuriline !12_A	et	f	\N
189745	struktuuriliselt	"struktuuriline %struktuuri  )LINE_aA  <struktuur ;22_S	et	f	\N
189746	struktuuriliselt	struktuuriliselt =struktuuriliselt  (ID  >struktuuriliselt !41_D	et	f	\N
189747	struktuuriliselt	"struktuuriliselt %struktuuri  )LISELT_mD  <struktuur ;22_S	et	f	\N
189748	struktuuriliselt	"struktuuriliselt %struktuurilise  )LT_mD  <struktuuriline ;12_A	et	f	\N
189749	peidupaikmis	?peidupaikmis =peidupaikmi  (SgIn  >peidupaikm !22_S	et	f	\N
189750	peidupaikmis	?peidupaikmis =peidupaikmi  (IndIpfSg3  >peidupaikmima !28_V	et	f	\N
189751	peidupaikmis	?peidupaikmis =peidupaikmis  (SgN  >peidupaikmis !09_S	et	f	\N
189752	peidupaikmis	?peidupaikmis =paikmi  (SgIn  >peidu+paikm !22_S	et	f	\N
189753	peidupaikmis	?peidupaikmis =paikmis  (SgN  >peidu+paikmis !09_S	et	f	\N
189760	tervikku	?tervikku =tervikku  (SgN  >tervikku !01_S	et	f	\N
189761	tervikku	?tervikku =tervikku  (SgG  >tervikku !01_S	et	f	\N
189762	tervikku	?tervikku =tervikku  (IndPrPs_  >tervikkuma !27_V	et	f	\N
189763	tervikku	?tervikku =tervikku  (ImpPrSg2  >tervikkuma !27_V	et	f	\N
189770	asendaminepeidupaik	?asendaminepeidupaik =asendaminepeidupaik  (SgN  >asendaminepeidupaik !22_S	et	f	\N
189633	poolteise	?poolteise =eise  (SgN  >poolt+eise !06_S	et	f	\N
189634	poolteise	?poolteise =eise  (SgG  >poolt+eise !06_S	et	f	\N
189635	poolteise	?poolteise =eise  (PlP  >poolt+eis !22_S	et	f	\N
189636	poolteise	?poolteise =teise  (PlP  >pool+teis !22_S	et	f	\N
189637	varjul	varjul =varju  (SgAd  >vari !24_S	et	f	\N
189638	varjul	varjul =varju  (PlAd  >vari !24_S	et	f	\N
189639	varjul	varjul =varjul  (ID  >varjul !41_D	et	f	\N
189640	jäävadki	jäävadki =jää  (IndPrPl3^  >jääma !37_V	et	f	\N
189641	jäävadki	jäävadki =jääva  (PlN^  >jääv !02_A	et	f	\N
189642	jäävadki	"jääv %jää  )V_vA^  <jääma ;37_V	et	f	\N
189652	faktitruuduse	faktitruuduse =truuduse  (SgG  >fakti+truudus !11~09_S	et	f	\N
189654	faktitruuduse	"fakti+truudus %truu  )US_aS  <fakti+truu ;26_A	et	f	\N
189676	toore	toore =toore  (SgN  >toore !05_S	et	f	\N
189677	toore	toore =toore  (SgG  >toores !07_A	et	f	\N
189678	toore	toore =toore  (PlP  >toor !22_S	et	f	\N
189682	hulljulge	hulljulge =julge  (SgN  >hull+julge !01_A	et	f	\N
189683	hulljulge	hulljulge =julge  (SgG  >hull+julge !01_A	et	f	\N
189684	tsaarivõimu	tsaarivõimu =võimu  (SgG  >tsaari+võim !22_S	et	f	\N
189685	tsaarivõimu	tsaarivõimu =võimu  (SgP  >tsaari+võim !22_S	et	f	\N
189686	tsaarivõimu	tsaarivõimu =võimu  (SgAdt  >tsaari+võim !22_S	et	f	\N
189711	jutustava	jutustava =jutustava  (SgG  >jutustav !02_A	et	f	\N
189712	jutustava	"jutustav %jutusta  )V_vA  <jutustama ;27_V	et	f	\N
189713	järjestikune	järjestikune =järjestikune  (SgN  >järjestikune !10?12_A	et	f	\N
189714	järjestikune	"järjestikune %järjestiku  )NE_aA  <järjestik ;25_S	et	f	\N
189724	elektroonilisest	?elektroonilisest =elektroonilise  (SgEl  >elektrooniline !12_A	et	f	\N
189725	elektroonilisest	?elektroonilisest =onilise  (SgEl  >elektro+oniline !12_A	et	f	\N
189739	temaatiliseks	temaatiliseks =temaatilise  (SgTr  >temaatiline !12_A	et	f	\N
189740	temaatiliseks	temaatiliseks =atilise  (SgTr  >tema+atiline !12_A	et	f	\N
189741	temaatiliseks	"tema+atiline %ati  )LINE_aA  <tema+att ;22_S	et	f	\N
189754	temaatiline	temaatiline =temaatiline  (SgN  >temaatiline !12_A	et	f	\N
189755	temaatiline	temaatiline =atiline  (SgN  >tema+atiline !12_A	et	f	\N
189756	temaatiline	"tema+atiline %ati  )LINE_aA  <tema+att ;22_S	et	f	\N
189757	sidususvahendite	?sidususvahendite =sidususvahendi  (IndPrPl2  >sidususvahentima !28_V	et	f	\N
189758	loogilist	loogilist =loogilis  (SgP  >loogiline !12_A	et	f	\N
189759	loogilist	"loogiline %loogi  )LINE_aA  <loog ;22_S	et	f	\N
189764	sidususvahendeid	?sidususvahendeid =sidususvahendei  (PlN  >sidususvahendei !26_S	et	f	\N
189765	sidususvahendeid	?sidususvahendeid =sidususvahendei  (SgP  >sidususvahendei !26_S	et	f	\N
189766	sidususvahendeid	?sidususvahendeid =usvahendei  (PlN  >sidus+usvahendei !26_S	et	f	\N
189767	sidususvahendeid	?sidususvahendeid =usvahendei  (SgP  >sidus+usvahendei !26_S	et	f	\N
189783	varieeruvad	varieeruvad =varieeru  (IndPrPl3  >varieeruma !27_V	et	f	\N
189784	varieeruvad	varieeruvad =varieeruva  (PlN  >varieeruv !02_A	et	f	\N
189785	varieeruvad	"varieeruv %varieeru  )V_vA  <varieeruma ;27_V	et	f	\N
189788	läbipaistev	läbipaistev =paist  (PtsPrPs  >läbi+_paistma !34_V	et	f	\N
189789	läbipaistev	läbipaistev =paistev  (SgN  >läbi+paistev !02_A	et	f	\N
189790	õs	### õs	et	f	\N
189791	selgeeesti-vene	selgeeesti-vene =vene  (ID  >selgeeesti-vene !41_G	et	f	\N
189792	selgeeesti-vene	selgeeesti-vene =vene  (SgN  >selgeeesti-vene !16_S	et	f	\N
189793	selgeeesti-vene	selgeeesti-vene =vene  (SgG  >selgeeesti-vene !16_S	et	f	\N
189802	peidupaigast	peidupaigast =paiga  (SgEl  >peidu+paik !22_S	et	f	\N
189803	peidupaigast	peidupaigast =paigas  (SgP  >peidu+paigas !09_S	et	f	\N
189804	peidupaigast	peidupaigast =paigas  (SgP  >peidu+paigane !10_A	et	f	\N
189805	peidupaigast	"peidu+paigane %paiga  )NE_aA  <peidu+paik ;22_S	et	f	\N
189809	jtammärkel	?jtammärkel =jtammärkel  (SgN  >jtammärkel !02_S	et	f	\N
189822	üsnaõs	?üsnaõs =üsnaõs  (SgN  >üsnaõs !22_S	et	f	\N
189832	elektrooniline	?elektrooniline =elektrooniline  (SgN  >elektrooniline !12_A	et	f	\N
189833	elektrooniline	?elektrooniline =elektrooniline  (PlP  >elektroonilin !19_S	et	f	\N
189834	elektrooniline	?elektrooniline =oniline  (SgN  >elektro+oniline !12_A	et	f	\N
189835	elektrooniline	?elektrooniline =oniline  (PlP  >elektro+onilin !19_S	et	f	\N
189848	algteksti	algteksti =teksti  (SgG  >alg+tekst !22_S	et	f	\N
189849	algteksti	algteksti =teksti  (SgP  >alg+tekst !22_S	et	f	\N
189850	algteksti	algteksti =teksti  (SgAdt  >alg+tekst !22_S	et	f	\N
189867	sidusuvahenditest	?sidusuvahenditest =sidusuvahendite  (PlEl  >sidusuvahenditt !22_S	et	f	\N
189868	sidusuvahenditest	?sidusuvahenditest =sidusuvahendites  (SgP  >sidusuvahenditene !12_A	et	f	\N
189869	sidusuvahenditest	?sidusuvahenditest =uvahendite  (PlEl  >sidus+uvahenditt !22_S	et	f	\N
189870	sidusuvahenditest	?sidusuvahenditest =uvahendites  (SgP  >sidus+uvahenditene !12_A	et	f	\N
189871	varjulkahtlased	?varjulkahtlased =varjulkahtlase  (PlN  >varjulkahtlane !12?10_S	et	f	\N
189880	personifitseerimine	personifitseerimine =personifitseerimine  (SgN  >personifitseerimine !12_S	et	f	\N
189881	personifitseerimine	"personifitseerimine %personifitseeri  )MINE_vS  <personifitseerima ;28_V	et	f	\N
189900	kinldate	?kinldate =kinlda  (PlG  >kinlda !01_S	et	f	\N
189901	kinldate	?kinldate =kinlda  (IndPrPl2  >kinldama !29_V	et	f	\N
189699	mättiku	?mättiku =mättiku  (SgG  >mättiku !01_S	et	f	\N
189701	mättiku	?mättiku =mättiku  (SgG  >mättik !02_S	et	f	\N
189702	mättiku	?mättiku =mättiku  (IndPrPs_  >mättikuma !27_V	et	f	\N
189704	mättiku	?mättiku =mättiku  (ImpPrSg2  >mättikuma !27_V	et	f	\N
189721	eesti-vene-eesti	eesti-vene-eesti =eesti  (ID  >eesti-vene-eesti !41_G	et	f	\N
189722	eesti-vene-eesti	eesti-vene-eesti =eesti  (SgN  >eesti-vene-eesti !16_H	et	f	\N
189723	eesti-vene-eesti	eesti-vene-eesti =eesti  (SgG  >eesti-vene-eesti !16_H	et	f	\N
189729	httpwwwaseeedict	?httpwwwaseeedict =httpwwwaseeedict  (SgN  >httpwwwaseeedict !22_S	et	f	\N
189734	tähendusnüanssi	tähendusnüanssi =nüanssi  (SgG  >tähendus+nüanss !22_S	et	f	\N
189735	tähendusnüanssi	tähendusnüanssi =nüanssi  (SgP  >tähendus+nüanss !22_S	et	f	\N
189736	tähendusnüanssi	tähendusnüanssi =nüanssi  (SgAdt  >tähendus+nüanss !22_S	et	f	\N
189768	asesõnaline	asesõnaline =sõnaline  (SgN  >ase+sõnaline !12_A	et	f	\N
189769	asesõnaline	"ase+sõnaline %sõna  )LINE_aA  <ase+sõna ;17_S	et	f	\N
189806	mul-asesõna	mul-asesõna =sõna  (SgN  >mul-ase+sõna !17_S	et	f	\N
189807	mul-asesõna	mul-asesõna =sõna  (SgG  >mul-ase+sõna !17_S	et	f	\N
189808	mul-asesõna	mul-asesõna =sõna  (SgP  >mul-ase+sõna !17_S	et	f	\N
189812	hooneosaõs	?hooneosaõs =hooneosaõs  (SgN  >hooneosaõs !22_S	et	f	\N
189814	hooneosaõs	?hooneosaõs =saõs  (SgN  >hoo+neo+saõs !22_S	et	f	\N
189815	hooneosaõs	?hooneosaõs =osaõs  (SgN  >hoone+osaõs !22_S	et	f	\N
189816	hooneosaõs	?hooneosaõs =neosaõs  (SgN  >hoo+neosaõs !22_S	et	f	\N
189826	suhtesvene-eesti	suhtesvene-eesti =eesti  (ID  >suhtesvene-eesti !41_G	et	f	\N
189827	suhtesvene-eesti	suhtesvene-eesti =eesti  (SgN  >suhtesvene-eesti !16_H	et	f	\N
189828	suhtesvene-eesti	suhtesvene-eesti =eesti  (SgG  >suhtesvene-eesti !16_H	et	f	\N
189829	sümmeetriliselt	sümmeetriliselt =sümmeetrilise  (SgAbl  >sümmeetriline !12_A	et	f	\N
189830	sümmeetriliselt	sümmeetriliselt =sümmeetriliselt  (ID  >sümmeetriliselt !41_D	et	f	\N
189831	sümmeetriliselt	"sümmeetriliselt %sümmeetrilise  )LT_mD  <sümmeetriline ;12_A	et	f	\N
189836	seletusi	seletusi =seletusi  (PlP  >seletus !11_S	et	f	\N
189837	seletusi	"seletus %seleta  )US_vS  <seletama ;27_V	et	f	\N
189847	tehn	?tehn =tehn  (SgN  >tehn !22_S	et	f	\N
189852	selgituse	selgituse =selgituse  (SgG  >selgitus !11_S	et	f	\N
189853	selgituse	"selgitus %selgita  )US_vS  <selgitama ;27_V	et	f	\N
189854	selgituse	"selgitus %selgi  )TUS1_aS  <selgima ;27_V	et	f	\N
189865	isikulise	isikulise =isikulise  (SgG  >isikuline !12_A	et	f	\N
189866	isikulise	"isikuline %isiku  )LINE_aA  <isik ;02_S	et	f	\N
189884	võimete	võimete =võime  (PlG  >võime !06_S	et	f	\N
189885	võimete	võimete =me  (PlG  >või+mesi !15_S	et	f	\N
189892	llause	?llause =llause  (SgN  >llause !06_S	et	f	\N
189893	llause	?llause =llause  (SgG  >llause !06_S	et	f	\N
189894	llause	?llause =llause  (PlP  >llaus !22_S	et	f	\N
189895	llause	?llause =llause  (IndPrPs_  >llausema !28_V	et	f	\N
189896	llause	?llause =llause  (ImpPrSg2  >llausema !28_V	et	f	\N
189897	sõnaraamatj	### sõnaraamatj	et	f	\N
189898	tõlgevariandiks	?tõlgevariandiks =tõlgevariandi  (SgTr  >tõlgevariant !22_S	et	f	\N
189899	tõlgevariandiks	?tõlgevariandiks =tõlgevariandi  (KndPrPs  >tõlgevariantima !28_V	et	f	\N
189916	loengute	loengute =loengu  (PlG  >loeng !02_S	et	f	\N
189917	loengute	loengute =ute  (SgG  >loeng+utt !22_S	et	f	\N
189918	konspektid	konspektid =konspekti  (PlN  >konspekt !22_S	et	f	\N
189919	konspektid	konspektid =konspekti  (IndPrSg2  >konspektima !28_V	et	f	\N
189924	vastuvõtlikumad	vastuvõtlikumad =võtlikuma  (PlN  >vastu+võtlikum !02_A	et	f	\N
189925	vastuvõtlikumad	"vastu+võtlikum %võtliku  )M_cA  <vastu+võtlik ;25_A	et	f	\N
189944	muudki	muudki =muu  (PlN^  >muu !26_S	et	f	\N
189945	muudki	muudki =muu  (PlN^  >muu !26_P	et	f	\N
189946	muudki	muudki =muu  (SgP^  >muu !26_S	et	f	\N
189947	muudki	muudki =muu  (SgP^  >muu !26_P	et	f	\N
189948	muudki	muudki =muu  (IndPrSg2^  >muuma !27_V	et	f	\N
189951	sammalhabemel	### sammalhabemel	et	f	\N
189957	lõiganud	lõiganud =lõiga  (PtsPtPs  >lõikama !29_V	et	f	\N
189958	lõiganud	lõiganud =lõiganu  (PlN  >lõiganu !01_S	et	f	\N
189959	lõiganud	"lõiganu %lõiga  )NU_vS  <lõikama ;29_V	et	f	\N
189960	lõiganud	lõiganud =lõiganud  (ID  >lõiganud !41_A	et	f	\N
189961	lõiganud	"lõiganud %lõiga  )NUD_vA  <lõikama ;29_V	et	f	\N
189965	paistsid	paistsid =paist  (IndIpfSg2  >paistma !34_V	et	f	\N
189966	paistsid	paistsid =paist  (IndIpfPl3  >paistma !34_V	et	f	\N
189975	kohtumisest	kohtumisest =kohtumise  (SgEl  >kohtumine !12_S	et	f	\N
189976	kohtumisest	"kohtumine %kohtu  )MINE_vS  <kohtuma ;27_V	et	f	\N
189983	tegelastevahelise	tegelastevahelise =vahelise  (SgG  >tegelaste+vaheline !12_A	et	f	\N
189984	tegelastevahelise	"tegelaste+vaheline %vahe  )LINE_aA  <tegelaste+vahe ;16_S	et	f	\N
189996	anafooria	?anafooria =anafooria  (SgN  >anafooria !01_S	et	f	\N
189997	anafooria	?anafooria =anafooria  (SgG  >anafooria !01_S	et	f	\N
190033	müügiputka	müügiputka =putka  (SgN  >müügi+putka !16_S	et	f	\N
190034	müügiputka	müügiputka =putka  (SgG  >müügi+putka !16_S	et	f	\N
190035	putka-	putka- =putka  (SgN  >putka !16_S	et	f	\N
190036	putka-	putka- =putka  (SgG  >putka !16_S	et	f	\N
189775	nimisõnakorduspiidalaua	?nimisõnakorduspiidalaua =uspiidalaua  (SgN  >nimi+sõna+kord+uspiidalaua !01_S	et	f	\N
189776	nimisõnakorduspiidalaua	?nimisõnakorduspiidalaua =uspiidalaua  (SgG  >nimi+sõna+kord+uspiidalaua !01_S	et	f	\N
189777	nimisõnakorduspiidalaua	?nimisõnakorduspiidalaua =korduspiidalaua  (SgN  >nimi+sõna+korduspiidalaua !01_S	et	f	\N
189778	nimisõnakorduspiidalaua	?nimisõnakorduspiidalaua =korduspiidalaua  (SgG  >nimi+sõna+korduspiidalaua !01_S	et	f	\N
189779	nimisõnakorduspiidalaua	?nimisõnakorduspiidalaua =sõnakorduspiidalaua  (SgN  >nimi+sõnakorduspiidalaua !01_S	et	f	\N
189780	nimisõnakorduspiidalaua	?nimisõnakorduspiidalaua =sõnakorduspiidalaua  (SgG  >nimi+sõnakorduspiidalaua !01_S	et	f	\N
189795	jäänudsee	?jäänudsee =jäänudsee  (SgN  >jäänudsee !26_S	et	f	\N
189796	jäänudsee	?jäänudsee =jäänudsee  (SgG  >jäänudsee !26_S	et	f	\N
189797	jäänudsee	?jäänudsee =nudsee  (SgN  >jää+nudsee !26_S	et	f	\N
189798	jäänudsee	?jäänudsee =nudsee  (SgG  >jää+nudsee !26_S	et	f	\N
189799	mõtest	?mõtest =mõte  (PlEl  >mõtt !22_S	et	f	\N
189800	mõtest	?mõtest =mõtes  (SgP  >mõtes !09_S	et	f	\N
189801	mõtest	?mõtest =mõtes  (SgP  >mõtene !10_A	et	f	\N
189845	seletused	seletused =seletuse  (PlN  >seletus !11_S	et	f	\N
189846	seletused	"seletus %seleta  )US_vS  <seletama ;27_V	et	f	\N
189855	assitsieerub	?assitsieerub =assitsieeru  (IndPrSg3  >assitsieeruma !27_V	et	f	\N
189856	karbistvormi	?karbistvormi =karbistvormi  (SgG  >karbistvorm !22_S	et	f	\N
189857	karbistvormi	?karbistvormi =karbistvormi  (SgP  >karbistvorm !22_S	et	f	\N
189858	karbistvormi	?karbistvormi =karbistvormi  (SgAdt  >karbistvorm !22_S	et	f	\N
189859	karbistvormi	?karbistvormi =karbistvormi  (IndPrPs_  >karbistvormima !28_V	et	f	\N
189860	karbistvormi	?karbistvormi =karbistvormi  (ImpPrSg2  >karbistvormima !28_V	et	f	\N
189861	sidussuvahendina	?sidussuvahendina =sidussuvahendi  (SgEs  >sidussuvahent !22_S	et	f	\N
189862	sidussuvahendina	?sidussuvahendina =suvahendi  (SgEs  >sidus+suvahent !22_S	et	f	\N
189863	sidumiseks	sidumiseks =sidumise  (SgTr  >sidumine !12_S	et	f	\N
189864	sidumiseks	"sidumine %sidu  )MINE_vS  <siduma ;28_V	et	f	\N
189872	metafoore	metafoore =metafoore  (PlP  >metafoor !22_S	et	f	\N
189873	metafoore	metafoore =foore  (PlP  >meta+foor !22_S	et	f	\N
189890	tegemist-	tegemist- =tegemis  (SgP  >tegemine !12_S	et	f	\N
189891	tegemist-	"tegemine %tege  )MINE_vS  <tegema ;28_V	et	f	\N
189904	sõltuvusmäärus	?sõltuvusmäärus =sõltuvusmääru  (IndIpfSg3  >sõltuvusmääruma !27_V	et	f	\N
189905	sõltuvusmäärus	?sõltuvusmäärus =sõltuvusmäärus  (SgN  >sõltuvusmäärus !11~09_S	et	f	\N
189906	287a	### 287a	et	f	\N
189909	madalk	?madalk =madalk  (SgN  >madalk !22_S	et	f	\N
189910	leivast	leivast =leiva  (SgEl  >leib !22_S	et	f	\N
189911	leivast	leivast =leivas  (SgP  >leivane !10_A	et	f	\N
189912	leivast	"leivane %leiva  )NE_aA  <leib ;22_S	et	f	\N
189922	lapades	?lapades =lapa  (PlIn  >lapa !16_S	et	f	\N
189923	lapades	?lapades =lapa  (Ger  >lapama !27_V	et	f	\N
189927	jäätiseputka	jäätiseputka =putka  (SgN  >jäät+ise+putka !16_S	et	f	\N
189928	jäätiseputka	jäätiseputka =putka  (SgG  >jäät+ise+putka !16_S	et	f	\N
189930	kingpool	kingpool =pool  (ID  >king+pool !41_DK	et	f	\N
189931	kingpool	kingpool =pool  (SgN  >king+pool !13_NS	et	f	\N
189932	kingpool	kingpool =pool  (SgN  >king+pool !22_S	et	f	\N
189972	httpwwwestonicaorgestpopupraudnaksidhtm	### httpwwwestonicaorgestpopupraudnaksidhtm	et	f	\N
189974	kirjaldada-	?kirjaldada- =kirjalda  (Inf  >kirjaldama !27_V	et	f	\N
189977	sõlmitus	sõlmitus =sõlmitu  (SgIn  >sõlmitu !01_AS	et	f	\N
189978	sõlmitus	"sõlmitu %sõlmi  )TU1_vS  <sõlmima ;28_V	et	f	\N
189979	sõlmitus	"sõlmitu %sõlmi  )TU2_kA  <sõlm ;22_S	et	f	\N
189980	sõlmitus	sõlmitus =sõlmitus  (SgN  >sõlmitus !11_S	et	f	\N
189981	sõlmitus	"sõlmitus %sõlmi  )TUS1_aS  <sõlmima ;28_V	et	f	\N
189982	sõlmitus	"sõlmitus %sõlmi  )TUS2_aS  <sõlm ;22_S	et	f	\N
189998	nadanafooria	?nadanafooria =nadanafooria  (SgN  >nadanafooria !01_S	et	f	\N
190000	nadanafooria	?nadanafooria =nadanafooria  (SgG  >nadanafooria !01_S	et	f	\N
190012	kordust	kordust =kordus  (SgP  >kordus !11~09_S	et	f	\N
190013	kordust	kordust =us  (SgP  >kord+uks !14_S	et	f	\N
190016	lähemaks	lähemaks =lähema  (SgTr  >lähem !02_A	et	f	\N
190017	lähemaks	"lähem %lähe  )M_cA  <lähike ;12_A	et	f	\N
190028	sünonüümsõnastikust	?sünonüümsõnastikust =sünonüümsõnastiku  (SgEl  >sünonüümsõnastik !25_S	et	f	\N
190029	sünonüümsõnastikust	?sünonüümsõnastikust =sünonüümsõnastikus  (SgP  >sünonüümsõnastikus !11?09_S	et	f	\N
190030	sünonüümsõnastikust	?sünonüümsõnastikust =sünonüümsõnastikus  (SgP  >sünonüümsõnastikune !10?12_A	et	f	\N
190031	seletuse	seletuse =seletuse  (SgG  >seletus !11_S	et	f	\N
190032	seletuse	"seletus %seleta  )US_vS  <seletama ;27_V	et	f	\N
190046	asendatudtõlgitud	?asendatudtõlgitud =asendatudtõlgi  (PtsPtIps  >asendatudtõlkima !28_V	et	f	\N
190047	asendatudtõlgitud	?asendatudtõlgitud =asendatudtõlgitu  (PlN  >asendatudtõlgitu !01_A	et	f	\N
190048	asendatudtõlgitud	?asendatudtõlgitud =asendatudtõlgitu  (IndPrSg2  >asendatudtõlgituma !27_V	et	f	\N
190049	asendatudtõlgitud	?asendatudtõlgitud =asendatudtõlgitud  (ID  >asendatudtõlgitud !41_A	et	f	\N
190074	venekeelde	venekeelde =keel  (SgAdt  >vene+keel !13_S	et	f	\N
190075	venekeelde	venekeelde =keelde  (PlP  >vene+keeld !22_S	et	f	\N
189781	täpsustamine	täpsustamine =täpsustamine  (SgN  >täpsustamine !12_S	et	f	\N
189782	täpsustamine	"täpsustamine %täpsusta  )MINE_vS  <täpsustama ;27_V	et	f	\N
189794	jtamm	?jtamm =jtamm  (SgN  >jtamm !22_S	et	f	\N
189810	eenduv	eenduv =eendu  (PtsPrPs  >eenduma !27_V	et	f	\N
189811	eenduv	eenduv =eenduv  (SgN  >eenduv !02_A	et	f	\N
189813	eenduv	"eenduv %eendu  )V_vA  <eenduma ;27_V	et	f	\N
189817	vahendidverbi	?vahendidverbi =vahendidverbi  (SgG  >vahendidverp !22_S	et	f	\N
189818	vahendidverbi	?vahendidverbi =vahendidverbi  (SgP  >vahendidverb !22_S	et	f	\N
189819	vahendidverbi	?vahendidverbi =vahendidverbi  (SgAdt  >vahendidverb !22_S	et	f	\N
189820	vahendidverbi	?vahendidverbi =vahendidverbi  (IndPrPs_  >vahendidverpima !28_V	et	f	\N
189821	vahendidverbi	?vahendidverbi =vahendidverbi  (ImpPrSg2  >vahendidverpima !28_V	et	f	\N
189844	sõnaraamatusj	### sõnaraamatusj	et	f	\N
189874	metafoori	metafoori =metafoori  (SgG  >metafoor !22_S	et	f	\N
189875	metafoori	metafoori =metafoori  (SgP  >metafoor !22_S	et	f	\N
189876	metafoori	metafoori =metafoori  (SgAdt  >metafoor !22_S	et	f	\N
189877	metafoori	metafoori =foori  (SgG  >meta+foor !22_S	et	f	\N
189878	metafoori	metafoori =foori  (SgP  >meta+foor !22_S	et	f	\N
189879	metafoori	metafoori =foori  (SgAdt  >meta+foor !22_S	et	f	\N
189882	isikustamine	isikustamine =isikustamine  (SgN  >isikustamine !12_S	et	f	\N
189883	isikustamine	"isikustamine %isikusta  )MINE_vS  <isikustama ;27_V	et	f	\N
189913	eluasemest	eluasemest =mest  (SgN  >elu+ase+mest !22_S	et	f	\N
189914	eluasemest	eluasemest =aseme  (SgEl  >elu+ase !04_S	et	f	\N
189942	päkapikkudeks	päkapikkudeks =pikku  (PlTr  >päka+pikk !22_S	et	f	\N
189943	päkapikkudeks	päkapikkudeks =pikku  (PlTr  >päka+pikk !22_AS	et	f	\N
189949	iseäralikku	iseäralikku =äralikku  (SgP  >ise+äralik !25_A	et	f	\N
189950	iseäralikku	iseäralikku =äralikku  (SgAdt  >ise+äralik !25_A	et	f	\N
189955	mullusuvised	mullusuvised =suvise  (PlN  >mullu+suvine !10_A	et	f	\N
189956	mullusuvised	"mullu+suvine %suvi  )NE_aA  <mullu+suvi ;20_S	et	f	\N
189985	tegevustiku	tegevustiku =tegevustiku  (SgG  >tegevustik !25_S	et	f	\N
189986	tegevustiku	tegevustiku =tiku  (SgG  >tegevus+tikk !22_S	et	f	\N
189989	sidususvahend	?sidususvahend =sidususvahend  (SgN  >sidususvahend !22_S	et	f	\N
189990	sidususvahend	?sidususvahend =usvahend  (SgN  >sidus+usvahend !22_S	et	f	\N
189991	pronominalisatsioonasesõnaline	?pronominalisatsioonasesõnaline =pronominalisatsioonasesõnaline  (SgN  >pronominalisatsioonasesõnaline !12_A	et	f	\N
189992	pronominalisatsioonasesõnaline	?pronominalisatsioonasesõnaline =pronominalisatsioonasesõnaline  (PlP  >pronominalisatsioonasesõnalin !19_S	et	f	\N
190002	täpsusta	täpsusta =täpsusta  (IndPrPs_  >täpsustama !27_V	et	f	\N
190003	täpsusta	täpsusta =täpsusta  (ImpPrSg2  >täpsustama !27_V	et	f	\N
190024	juuresantud	juuresantud =an  (PtsPtIps  >juures+_andma !34_V	et	f	\N
190025	juuresantud	juuresantud =antu  (PlN  >juures+antu !01_S	et	f	\N
190063	meessoostmis	?meessoostmis =meessoostmi  (SgIn  >meessoostmi !01_S	et	f	\N
190064	meessoostmis	?meessoostmis =meessoostmi  (SgIn  >meessoostm !22_S	et	f	\N
190065	meessoostmis	?meessoostmis =meessoostmi  (IndIpfSg3  >meessoostmima !28_V	et	f	\N
190066	meessoostmis	?meessoostmis =meessoostmis  (SgN  >meessoostmis !11_S	et	f	\N
190067	meessoostmis	?meessoostmis =soostmi  (SgIn  >mees+soostmi !01_S	et	f	\N
190068	meessoostmis	?meessoostmis =soostmi  (SgIn  >mees+soostm !22_S	et	f	\N
190069	meessoostmis	?meessoostmis =soostmis  (SgN  >mees+soostmis !09_S	et	f	\N
190103	kohmakalt	kohmakalt =kohmaka  (SgAbl  >kohmakas !02_A	et	f	\N
190104	kohmakalt	kohmakalt =kohmakalt  (ID  >kohmakalt !41_D	et	f	\N
190105	kohmakalt	"kohmakalt %kohmaka  )LT_mD  <kohmakas ;02_A	et	f	\N
190111	sidkriipsuga	?sidkriipsuga =sidkriipsu  (SgKom  >sidkriipsu !01_S	et	f	\N
190128	aspektuaalsuse	?aspektuaalsuse =aspektuaalsuse  (SgG  >aspektuaalsus !11~09_S	et	f	\N
190132	interpritatsiooni	?interpritatsiooni =interpritatsioo  (SgTer  >interpritatsioo !26_S	et	f	\N
190133	interpritatsiooni	?interpritatsiooni =interpritatsiooni  (SgN  >interpritatsiooni !16_S	et	f	\N
190134	interpritatsiooni	?interpritatsiooni =interpritatsiooni  (SgG  >interpritatsiooni !16_S	et	f	\N
190135	interpritatsiooni	?interpritatsiooni =interpritatsiooni  (SgG  >interpritatsioon !22_S	et	f	\N
190136	interpritatsiooni	?interpritatsiooni =interpritatsiooni  (SgP  >interpritatsioon !22_S	et	f	\N
190137	interpritatsiooni	?interpritatsiooni =interpritatsiooni  (SgAdt  >interpritatsioon !22_S	et	f	\N
190138	interpritatsiooni	?interpritatsiooni =interpritatsiooni  (IndPrPs_  >interpritatsioonima !28_V	et	f	\N
190139	interpritatsiooni	?interpritatsiooni =interpritatsiooni  (ImpPrSg2  >interpritatsioonima !28_V	et	f	\N
190140	interpritatsiooni	?interpritatsiooni =pritatsioo  (SgTer  >inter+pritatsioo !26_S	et	f	\N
190141	interpritatsiooni	?interpritatsiooni =pritatsiooni  (SgN  >inter+pritatsiooni !16_S	et	f	\N
190142	interpritatsiooni	?interpritatsiooni =pritatsiooni  (SgG  >inter+pritatsiooni !16_S	et	f	\N
190143	interpritatsiooni	?interpritatsiooni =pritatsiooni  (SgG  >inter+pritatsioon !22_S	et	f	\N
190144	interpritatsiooni	?interpritatsiooni =pritatsiooni  (SgP  >inter+pritatsioon !22_S	et	f	\N
190145	interpritatsiooni	?interpritatsiooni =pritatsiooni  (SgAdt  >inter+pritatsioon !22_S	et	f	\N
190146	mängulisust	mängulisust =mängulisus  (SgP  >mängulisus !11?09_S	et	f	\N
190147	mängulisust	"mängulisus %mängu  )LISUS_aS  <mäng ;22_S	et	f	\N
189839	httpvene-eestiaseee	?httpvene-eestiaseee =eestiaseee  (SgG  >httpvene-eestiaseee !26_S	et	f	\N
189840	httpvene-eestiaseee	?httpvene-eestiaseee =aseee  (SgN  >httpvene-eesti+aseee !26_S	et	f	\N
189841	httpvene-eestiaseee	?httpvene-eestiaseee =aseee  (SgG  >httpvene-eesti+aseee !26_S	et	f	\N
189842	httpvene-eestiaseee	?httpvene-eestiaseee =tiaseee  (SgN  >httpvene-ees+tiaseee !26_S	et	f	\N
189843	httpvene-eestiaseee	?httpvene-eestiaseee =tiaseee  (SgG  >httpvene-ees+tiaseee !26_S	et	f	\N
189851	etn	?etn =etn  (SgN  >etn !22_S	et	f	\N
189886	peidukohta	peidukohta =kohta  (SgP  >peidu+koht !22_S	et	f	\N
189887	peidukohta	peidukohta =kohta  (SgAdt  >peidu+koht !22_S	et	f	\N
189888	asesõnalist	asesõnalist =sõnalis  (SgP  >ase+sõnaline !12_A	et	f	\N
189889	asesõnalist	"ase+sõnaline %sõna  )LINE_aA  <ase+sõna ;17_S	et	f	\N
189920	eeltöö	eeltöö =töö  (SgN  >eel+töö !26_S	et	f	\N
189921	eeltöö	eeltöö =töö  (SgG  >eel+töö !26_S	et	f	\N
189926	jutudele	?jutudele =jutu  (PlAll  >jutu !16_S	et	f	\N
189952	samblast	samblast =sambla  (SgEl  >sammal !08_S	et	f	\N
189953	samblast	samblast =samblas  (SgP  >samblane !10~12_A	et	f	\N
189954	samblast	"samblane %sambla  )NE_aA  <sammal ;08_S	et	f	\N
189970	uudishimulikult	uudishimulikult =himuliku  (SgAbl  >uudis+himulik !25_A	et	f	\N
189971	uudishimulikult	"uudis+himulikult %himuliku  )LT_mD  <uudis+himulik ;25_A	et	f	\N
189973	httpwwwlibrutalesraudmufta1txt	### httpwwwlibrutalesraudmufta1txt	et	f	\N
189993	muhvkatafoorid	?muhvkatafoorid =muhvkatafoori  (PlN  >muhvkatafoori !16_S	et	f	\N
189994	muhvkatafoorid	?muhvkatafoorid =muhvkatafoori  (PlN  >muhvkatafoor !22_S	et	f	\N
189995	muhvkatafoorid	?muhvkatafoorid =muhvkatafoori  (IndPrSg2  >muhvkatafoorima !28_V	et	f	\N
189999	jutustusetegevuse	?jutustusetegevuse =jutustusetegevuse  (SgG  >jutustusetegevus !11?09_S	et	f	\N
190001	jutustusetegevuse	?jutustusetegevuse =stusetegevuse  (SgG  >jutu+stusetegevus !11?09_S	et	f	\N
190014	oletus	oletus =oletus  (SgN  >oletus !11_S	et	f	\N
190015	oletus	"oletus %oleta  )US_vS  <oletama ;27_V	et	f	\N
190022	juures-	juures- =juure  (SgIn  >juur !13_S	et	f	\N
190023	juures-	juures- =juures  (ID  >juures !41_DK	et	f	\N
190050	nimetusega-	nimetusega- =nimetuse  (SgKom  >nimetus !11_S	et	f	\N
190051	nimetusega-	"nimetus %nimeta  )US_vS  <nimetama ;27_V	et	f	\N
190052	nimetusega-	"nimetus %nime  )TUS2_aS  <nimi ;20_S	et	f	\N
190076	elektroonilises	?elektroonilises =elektroonilise  (SgIn  >elektrooniline !12_A	et	f	\N
190077	elektroonilises	?elektroonilises =onilise  (SgIn  >elektro+oniline !12_A	et	f	\N
190082	seletusest	seletusest =seletuse  (SgEl  >seletus !11_S	et	f	\N
190083	seletusest	"seletus %seleta  )US_vS  <seletama ;27_V	et	f	\N
190084	seletusest	seletusest =seletuses  (SgP  >seletusene !12_A	et	f	\N
190085	seletusest	"seletusene %seletuse  )NE_aA  <seletus ;11_S	et	f	\N
190088	kastikesega	kastikesega =kastikese  (SgKom  >kastike !12_S	et	f	\N
190089	kastikesega	"kastike %kasti  )KE_dS  <kast ;22_S	et	f	\N
190090	kastikesega	kastikesega =kastikese  (SgKom  >kastikene !12_S	et	f	\N
190091	kastikesega	"kastikene %kasti  )KENE_dS  <kast ;22_S	et	f	\N
190092	putkast	putkast =putka  (SgEl  >putka !16_S	et	f	\N
190093	putkast	putkast =putkas  (SgP  >putkane !12~10_A	et	f	\N
190094	putkast	"putkane %putka  )NE_aA  <putka ;16_S	et	f	\N
190123	vormi-	vormi- =vormi  (SgG  >vorm !22_S	et	f	\N
190124	vormi-	vormi- =vormi  (SgP  >vorm !22_S	et	f	\N
190125	vormi-	vormi- =vormi  (SgAdt  >vorm !22_S	et	f	\N
190126	vormi-	vormi- =vormi  (IndPrPs_  >vormima !28_V	et	f	\N
190127	vormi-	vormi- =vormi  (ImpPrSg2  >vormima !28_V	et	f	\N
190129	originaaltõlkest	originaaltõlkest =tõlke  (SgEl  >originaal+tõlge !06_S	et	f	\N
190130	originaaltõlkest	originaaltõlkest =tõlkes  (SgP  >originaal+tõlkene !12~10_A	et	f	\N
190131	originaaltõlkest	"originaal+tõlkene %tõlke  )NE_aA  <originaal+tõlge ;06_S	et	f	\N
190150	alistavat	alistavat =alista  (KvtPrPs  >alistama !27_V	et	f	\N
190151	alistavat	alistavat =alistava  (SgP  >alistav !02_A	et	f	\N
190152	alistavat	"alistav %alista  )V_vA  <alistama ;27_V	et	f	\N
190166	eredaidemotsionaalseid	?eredaidemotsionaalseid =eredaidemotsionaalse  (PlP  >eredaidemotsionaalne !02_A	et	f	\N
190167	eredaidemotsionaalseid	?eredaidemotsionaalseid =eredaidemotsionaalsei  (PlN  >eredaidemotsionaalsei !26_S	et	f	\N
190168	eredaidemotsionaalseid	?eredaidemotsionaalseid =eredaidemotsionaalsei  (SgP  >eredaidemotsionaalsei !26_S	et	f	\N
190169	eredaidemotsionaalseid	?eredaidemotsionaalseid =idemotsionaalse  (PlP  >ereda+idemotsionaalne !02_A	et	f	\N
190170	eredaidemotsionaalseid	?eredaidemotsionaalseid =idemotsionaalsei  (PlN  >ereda+idemotsionaalsei !26_S	et	f	\N
190171	eredaidemotsionaalseid	?eredaidemotsionaalseid =idemotsionaalsei  (SgP  >ereda+idemotsionaalsei !26_S	et	f	\N
190172	eredaidemotsionaalseid	?eredaidemotsionaalseid =daidemotsionaalse  (PlP  >ere+daidemotsionaalne !02_A	et	f	\N
190173	eredaidemotsionaalseid	?eredaidemotsionaalseid =daidemotsionaalsei  (PlN  >ere+daidemotsionaalsei !26_S	et	f	\N
190174	eredaidemotsionaalseid	?eredaidemotsionaalseid =daidemotsionaalsei  (SgP  >ere+daidemotsionaalsei !26_S	et	f	\N
190182	iselooma	iselooma =looma  (SgG  >ise+loom !22_S	et	f	\N
190183	iselooma	iselooma =looma  (SgP  >ise+loom !22_S	et	f	\N
190184	iselooma	iselooma =looma  (SgAdt  >ise+loom !22_S	et	f	\N
190190	hirmusta	?hirmusta =hirmusta  (SgN  >hirmusta !01_S	et	f	\N
190191	hirmusta	?hirmusta =hirmusta  (SgG  >hirmusta !01_S	et	f	\N
189902	siinjätmaon	?siinjätmaon =siinjätmaon  (SgN  >siinjätmaon !19_S	et	f	\N
189903	siinjätmaon	?siinjätmaon =jätmaon  (SgN  >siin+jätmaon !22_S	et	f	\N
189907	ristsõnamõistatust	ristsõnamõistatust =tust  (SgN  >rist+sõna+mõista+tust !22_S	et	f	\N
189908	ristsõnamõistatust	ristsõnamõistatust =mõistatus  (SgP  >rist+sõna+mõistatus !11_S	et	f	\N
189915	ross	?ross =ross  (SgN  >ross !22_S	et	f	\N
189929	sammalhabe	### sammalhabe	et	f	\N
189933	jäätismüüja	?jäätismüüja =jäätismüüja  (SgN  >jäätismüüja !16_S	et	f	\N
189934	jäätismüüja	?jäätismüüja =jäätismüüja  (SgG  >jäätismüüjas !02_A	et	f	\N
189935	jäätismüüja	?jäätismüüja =jäätismüüja  (SgG  >jäätismüüja !16_S	et	f	\N
189936	jäätismüüja	?jäätismüüja =ismüüja  (SgN  >jäät+ismüüja !16_S	et	f	\N
189937	jäätismüüja	?jäätismüüja =ismüüja  (SgG  >jäät+ismüüjas !02_A	et	f	\N
189938	jäätismüüja	?jäätismüüja =ismüüja  (SgG  >jäät+ismüüja !16_S	et	f	\N
189939	jäätismüüja	?jäätismüüja =tismüüja  (SgN  >jää+tismüüja !16_S	et	f	\N
189940	jäätismüüja	?jäätismüüja =tismüüja  (SgG  >jää+tismüüjas !02_A	et	f	\N
189941	jäätismüüja	?jäätismüüja =tismüüja  (SgG  >jää+tismüüja !16_S	et	f	\N
189962	muhvi	muhvi =muhvi  (SgG  >muhv !22_S	et	f	\N
189963	muhvi	muhvi =muhvi  (SgP  >muhv !22_S	et	f	\N
189964	muhvi	muhvi =muhvi  (SgAdt  >muhv !22_S	et	f	\N
189967	limpsisid	limpsisid =limpsi  (PlP  >limps !22_S	et	f	\N
189968	limpsisid	limpsisid =limpsi  (IndIpfSg2  >limpsima !28_V	et	f	\N
189969	limpsisid	limpsisid =limpsi  (IndIpfPl3  >limpsima !28_V	et	f	\N
189987	tegelasedmikroteemad	?tegelasedmikroteemad =tegelasedmikroteema  (PlN  >tegelasedmikroteema !16_S	et	f	\N
189988	tegelasedmikroteemad	?tegelasedmikroteemad =edmikroteema  (PlN  >tegelas+edmikroteema !16_S	et	f	\N
190004	tulevasel	tulevasel =tulevase  (SgAd  >tulevane !12_AS	et	f	\N
190005	tulevasel	tulevasel =vase  (SgAd  >tule+vask !22_S	et	f	\N
190006	nimetusega	nimetusega =nimetuse  (SgKom  >nimetus !11_S	et	f	\N
190007	nimetusega	"nimetus %nimeta  )US_vS  <nimetama ;27_V	et	f	\N
190008	nimetusega	"nimetus %nime  )TUS2_aS  <nimi ;20_S	et	f	\N
190009	parraleelid	?parraleelid =parraleeli  (PlN  >parraleeli !16_S	et	f	\N
190010	parraleelid	?parraleelid =parraleeli  (PlN  >parraleel !22_S	et	f	\N
190011	parraleelid	?parraleelid =parraleeli  (IndPrSg2  >parraleelima !28_V	et	f	\N
190018	salapärasust	salapärasust =pärasus  (SgP  >sala+pärasus !11_S	et	f	\N
190019	salapärasust	"sala+pärasus %pära  )SUS_aS  <sala+pära ;17_S	et	f	\N
190020	arvust	arvust =arvu  (SgEl  >arv !22_S	et	f	\N
190021	arvust	arvust =us  (SgP  >arv+uks !14_S	et	f	\N
190026	kohtumine-	kohtumine- =kohtumine  (SgN  >kohtumine !12_S	et	f	\N
190027	kohtumine-	"kohtumine %kohtu  )MINE_vS  <kohtuma ;27_V	et	f	\N
190039	elektroonilise	?elektroonilise =elektroonilise  (SgG  >elektrooniline !12_A	et	f	\N
190040	elektroonilise	?elektroonilise =onilise  (SgG  >elektro+oniline !12_A	et	f	\N
190041	sünaraamatus	?sünaraamatus =sünaraamatu  (SgIn  >sünaraamatu !01_A	et	f	\N
190042	sünaraamatus	?sünaraamatus =sünaraamatu  (IndIpfSg3  >sünaraamatuma !27_V	et	f	\N
190043	sünaraamatus	?sünaraamatus =sünaraamatus  (SgN  >sünaraamatus !11?09_S	et	f	\N
190044	tavapärased-	tavapärased- =pärase  (PlN  >tava+pärane !10_A	et	f	\N
190045	tavapärased-	"tava+pärane %pära  )NE_aA  <tava+pära ;17_S	et	f	\N
190053	võetuna	võetuna =võetu  (SgEs  >võetu !01_S	et	f	\N
190054	võetuna	"võetu %võe  )TU1_vS  <võtma ;35_V	et	f	\N
190070	sammalhabe-	### sammalhabe-	et	f	\N
190071	kingpool-	kingpool- =pool  (ID  >king+pool !41_DK	et	f	\N
190072	kingpool-	kingpool- =pool  (SgN  >king+pool !13_NS	et	f	\N
190073	kingpool-	kingpool- =pool  (SgN  >king+pool !22_S	et	f	\N
190112	ülikena	ülikena =kena  (SgN  >üli+kena !17_A	et	f	\N
190113	ülikena	ülikena =kena  (SgG  >üli+kena !17_A	et	f	\N
190114	ülikena	ülikena =kena  (SgP  >üli+kena !17_A	et	f	\N
190120	eelnevat	eelnevat =eelne  (KvtPrPs  >eelnema !27_V	et	f	\N
190121	eelnevat	eelnevat =eelneva  (SgP  >eelnev !02_A	et	f	\N
190122	eelnevat	"eelnev %eelne  )V_vA  <eelnema ;27_V	et	f	\N
190261	neljaastaseks	?neljaastaseks =neljaastase  (SgTr  >neljaastane !12~10_A	et	f	\N
190262	neljaastaseks	?neljaastaseks =astase  (SgTr  >nelja+astane !12~10_A	et	f	\N
190301	täiendamine	täiendamine =täiendamine  (SgN  >täiendamine !12_S	et	f	\N
190302	täiendamine	"täiendamine %täienda  )MINE_vS  <täiendama ;27_V	et	f	\N
190326	taastamiseks	taastamiseks =taastamise  (SgTr  >taastamine !12_S	et	f	\N
190327	taastamiseks	"taastamine %taasta  )MINE_vS  <taastama ;27_V	et	f	\N
190347	erifondi	erifondi =fondi  (SgG  >eri+fond !22_S	et	f	\N
190348	erifondi	erifondi =fondi  (SgP  >eri+fond !22_S	et	f	\N
190349	erifondi	erifondi =fondi  (SgAdt  >eri+fond !22_S	et	f	\N
190360	sara	sara =sara  (SgN  >sara !17_S	et	f	\N
190362	sara	sara =sara  (SgG  >sara !17_S	et	f	\N
190363	sara	sara =sara  (SgG  >sarg !22_S	et	f	\N
190364	sara	sara =sara  (SgP  >sara !17_S	et	f	\N
190373	merion	?merion =merion  (SgN  >merion !19_S	et	f	\N
190399	sarat	?sarat =sarat  (SgN  >sarat !02_S	et	f	\N
190400	amfetamiini	?amfetamiini =amfetamii  (SgTer  >amfetamii !26_S	et	f	\N
190401	amfetamiini	?amfetamiini =amfetamiini  (SgN  >amfetamiini !16_S	et	f	\N
190037	putka-	putka- =putka  (IndPrPs_  >putkama !29_V	et	f	\N
190038	putka-	putka- =putka  (ImpPrSg2  >putkama !29_V	et	f	\N
190055	kohatuks	kohatuks =koha  (KndPtIps  >kohama !27_V	et	f	\N
190056	kohatuks	kohatuks =koha  (KndPtIps  >kohtama !29_V	et	f	\N
190057	kohatuks	kohatuks =kohatu  (SgTr  >kohatu !01_AS	et	f	\N
190058	kohatuks	"kohatu %koha  )TU1_vS  <kohama ;27_V	et	f	\N
190059	kohatuks	"kohatu %koha  )TU1_vS  <kohtama ;29_V	et	f	\N
190060	kohatuks	"kohatu %koha  )TU2_kA  <koha ;17_S	et	f	\N
190061	kohatuks	"kohatu %koha  )TU2_kA  <koht ;22_S	et	f	\N
190062	kohatuks	kohatuks =tuks  (SgN  >koha+tuks !22_S	et	f	\N
190078	jäätisemüüja	jäätisemüüja =müüja  (SgN  >jäät+ise+müüja !01_S	et	f	\N
190079	jäätisemüüja	jäätisemüüja =müüja  (SgG  >jäät+ise+müüja !01_S	et	f	\N
190080	ozegovi	?ozegovi =ozegovi  (ID  >ozegovi !41_D	et	f	\N
190081	ozegovi	?ozegovi =ozegovi  (SgG  >ozegov !02_A	et	f	\N
190086	uurides	uurides =uuri  (PlIn  >uur !22_S	et	f	\N
190087	uurides	uurides =uuri  (Ger  >uurima !28_V	et	f	\N
190095	venekeeleses	venekeeleses =keelese  (SgIn  >vene+keelene !10_A	et	f	\N
190096	venekeeleses	"vene+keelene %keele  )NE_aA  <vene+keel ;13_S	et	f	\N
190097	kahjusta	kahjusta =kahjusta  (IndPrPs_  >kahjustama !27_V	et	f	\N
190098	kahjusta	kahjusta =kahjusta  (ImpPrSg2  >kahjustama !27_V	et	f	\N
190115	imekena	imekena =kena  (SgN  >ime+kena !17_A	et	f	\N
190116	imekena	imekena =kena  (SgG  >ime+kena !17_A	et	f	\N
190117	imekena	imekena =kena  (SgP  >ime+kena !17_A	et	f	\N
190157	edasianda	?edasianda =edasianda  (SgN  >edasianda !16_S	et	f	\N
190158	edasianda	?edasianda =edasianda  (SgG  >edasianda !16_S	et	f	\N
190159	edasianda	?edasianda =edasianda  (IndPrPs_  >edasiandama !27_V	et	f	\N
190160	edasianda	?edasianda =edasianda  (ImpPrSg2  >edasiandama !27_V	et	f	\N
190161	edasianda	?edasianda =anda  (SgN  >edasi+anda !16_S	et	f	\N
190162	edasianda	?edasianda =anda  (SgG  >edasi+anda !16_S	et	f	\N
190163	mõõtet	?mõõtet =mõõte  (SgP  >mõõte !06_S	et	f	\N
190164	lapselikkust	lapselikkust =lapselikkus  (SgP  >lapselikkus !11~09_S	et	f	\N
190165	lapselikkust	"lapselikkus %lapselikku  )US_aS  <lapselik ;25_A	et	f	\N
190180	printsiipist	?printsiipist =printsiipi  (SgEl  >printsiipi !16_S	et	f	\N
190181	printsiipist	?printsiipist =printsiipis  (SgP  >printsiipis !11_S	et	f	\N
190197	tranlatsioon	?tranlatsioon =tranlatsioon  (SgN  >tranlatsioon !22_S	et	f	\N
190203	kellaajalise	kellaajalise =ajalise  (SgG  >kella+ajaline !12_A	et	f	\N
190204	kellaajalise	"kella+ajaline %aja  )LINE_aA  <kella+aeg ;22_S	et	f	\N
190232	rünnaku	rünnaku =rünna  (ImpPrPs  >ründama !29_V	et	f	\N
190233	rünnaku	rünnaku =rünnaku  (SgG  >rünnak !02_S	et	f	\N
190243	boriss	?boriss =boriss  (SgN  >boriss !22_S	et	f	\N
190260	pigemraadiost	?pigemraadiost =pigemraadio  (SgEl  >pigemraadio !01_S	et	f	\N
190280	plakatidega	### plakatidega	et	f	\N
190284	piiramisel	piiramisel =piiramise  (SgAd  >piiramine !12_S	et	f	\N
190285	piiramisel	"piiramine %piira  )MINE_vS  <piirama ;29_V	et	f	\N
190303	rekonstrueerimine	rekonstrueerimine =rekonstrueerimine  (SgN  >rekonstrueerimine !12_S	et	f	\N
190304	rekonstrueerimine	"rekonstrueerimine %rekonstrueeri  )MINE_vS  <rekonstrueerima ;28_V	et	f	\N
190314	kokkukutsutud	kokkukutsutud =kutsu  (PtsPtIps  >kokku+_kutsuma !28_V	et	f	\N
190315	kokkukutsutud	kokkukutsutud =kutsutu  (PlN  >kokku+kutsutu !01_S	et	f	\N
190316	kokkukutsutud	"kokku+kutsutu %kutsu  )TU2_kA  <kokku+kutsu ;16_S	et	f	\N
190319	tõstati	?tõstati =tõsta  (IndIpfIps  >tõstama !29_V	et	f	\N
190320	tõstati	?tõstati =tõstati  (ID  >tõstati !41_D	et	f	\N
190321	tõstati	?tõstati =tõstati  (SgG  >tõstat !02_S	et	f	\N
190322	tõstati	?tõstati =tõstati  (SgG  >tõstatt !22_S	et	f	\N
190323	tõstati	?tõstati =tõstati  (IndPrPs_  >tõstattima !28_V	et	f	\N
190324	tõstati	?tõstati =tõstati  (ImpPrSg2  >tõstattima !28_V	et	f	\N
190328	1970-	### 1970-	et	f	\N
190354	darren	?darren =darre  (IndPrSg1  >darrema !27_V	et	f	\N
190355	darren	?darren =darren  (SgN  >darren !02_S	et	f	\N
190356	aronofsky	### aronofsky	et	f	\N
190374	garri	?garri =garri  (SgN  >garri !16_S	et	f	\N
190375	garri	?garri =garri  (SgG  >garri !16_S	et	f	\N
190376	garri	?garri =garri  (SgG  >garr !22_S	et	f	\N
190377	garri	?garri =garri  (SgP  >garr !22_S	et	f	\N
190378	garri	?garri =garri  (SgAdt  >garr !22_S	et	f	\N
190379	garri	?garri =garri  (IndPrPs_  >garrima !28_V	et	f	\N
190380	garri	?garri =garri  (ImpPrSg2  >garrima !28_V	et	f	\N
190435	nikiforov	?nikiforov =nikiforov  (SgN  >nikiforov !02_A	et	f	\N
190436	reisimisega	reisimisega =reisimise  (SgKom  >reisimine !12_S	et	f	\N
190437	reisimisega	"reisimine %reisi  )MINE_vS  <reisima ;28_V	et	f	\N
190442	võõrkeleoskust	?võõrkeleoskust =võõrkeleoskus  (SgP  >võõrkeleoskus !11~09_S	et	f	\N
190443	võõrkeleoskust	?võõrkeleoskust =keleoskus  (SgP  >võõr+keleoskus !11~09_S	et	f	\N
190456	kreegipuu	?kreegipuu =kreegipuu  (SgN  >kreegipuu !26_S	et	f	\N
190457	kreegipuu	?kreegipuu =kreegipuu  (SgG  >kreegipuu !26_S	et	f	\N
190477	kasulikk	### kasulikk	et	f	\N
190480	mõtlemist	mõtlemist =mõtlemis  (SgP  >mõtlemine !12_S	et	f	\N
190481	mõtlemist	"mõtlemine %mõtle  )MINE_vS  <mõtlema ;30_V	et	f	\N
190099	muuda	muuda =muu  (IndPrIps_  >muuma !27_V	et	f	\N
190100	muuda	muuda =muu  (Inf  >muuma !27_V	et	f	\N
190101	muuda	muuda =muuda  (IndPrPs_  >muutma !34_V	et	f	\N
190102	muuda	muuda =muuda  (ImpPrSg2  >muutma !34_V	et	f	\N
190106	deminutiivi	deminutiivi =deminutiivi  (SgG  >deminutiiv !22_S	et	f	\N
190107	deminutiivi	deminutiivi =deminutiivi  (SgP  >deminutiiv !22_S	et	f	\N
190108	deminutiivi	deminutiivi =deminutiivi  (SgAdt  >deminutiiv !22_S	et	f	\N
190109	venekeelsetele	venekeelsetele =sete  (PlAll  >vene+keel+sett !22_S	et	f	\N
190110	venekeelsetele	venekeelsetele =keelse  (PlAll  >vene+keelne !02_A	et	f	\N
190118	minevikuhetkele	minevikuhetkele =hetke  (SgAll  >mineviku+hetk !22_S	et	f	\N
190119	minevikuhetkele	minevikuhetkele =hetke  (PlAll  >mineviku+hetk !22_S	et	f	\N
190148	igavam	igavam =igavam  (SgN  >igavam !02_A	et	f	\N
190149	igavam	"igavam %igava  )M_cA  <igav ;02_A	et	f	\N
190153	iseäralikkust	iseäralikkust =äralikkus  (SgP  >ise+äralikkus !11~09_S	et	f	\N
190154	iseäralikkust	"ise+äralikkus %äralikku  )US_aS  <ise+äralik ;25_A	et	f	\N
190155	tõlkijal	tõlkijal =tõlkija  (SgAd  >tõlkija !01_S	et	f	\N
190156	tõlkijal	"tõlkija %tõlki  )JA_vS  <tõlkima ;28_V	et	f	\N
190177	emotsionaalsust	emotsionaalsust =emotsionaalsus  (SgP  >emotsionaalsus !11~09_S	et	f	\N
190178	emotsionaalsust	"emotsionaalsus %emotsionaalse  )US_aS  <emotsionaalne ;02_A	et	f	\N
190179	httpcsnetruconf2006ruslangmaintrendarharovahtm	### httpcsnetruconf2006ruslangmaintrendarharovahtm	et	f	\N
190198	formeeritud	formeeritud =formeeri  (PtsPtIps  >formeerima !28_V	et	f	\N
190199	formeeritud	formeeritud =formeeritu  (PlN  >formeeritu !01_S	et	f	\N
190200	formeeritud	"formeeritu %formeeri  )TU1_vS  <formeerima ;28_V	et	f	\N
190201	formeeritud	formeeritud =formeeritud  (ID  >formeeritud !41_A	et	f	\N
190202	formeeritud	"formeeritud %formeeri  )TUD_vA  <formeerima ;28_V	et	f	\N
190211	koledus	koledus =koledus  (SgN  >koledus !11_S	et	f	\N
190212	koledus	"koledus %koleda  )US_aS  <kole ;02_A	et	f	\N
190216	putsh	?putsh =putsh  (SgN  >putsh !22_S	et	f	\N
190225	kaitsa	?kaitsa =kaitsa  (SgN  >kaitsa !01_S	et	f	\N
190226	kaitsa	?kaitsa =kaitsa  (SgG  >kaitsa !01_S	et	f	\N
190227	kaitsa	?kaitsa =kaitsa  (IndPrPs_  >kaitsama !29_V	et	f	\N
190228	kaitsa	?kaitsa =kaitsa  (ImpPrSg2  >kaitsama !29_V	et	f	\N
190235	ohvrideta	?ohvrideta =ohvrideta  (IndPrPs_  >ohvridetama !27_V	et	f	\N
190236	ohvrideta	?ohvrideta =ohvrideta  (ImpPrSg2  >ohvridetama !27_V	et	f	\N
190241	mgorbatshovi	?mgorbatshovi =mgorbatshovi  (ID  >mgorbatshovi !41_D	et	f	\N
190242	mgorbatshovi	?mgorbatshovi =mgorbatshovi  (SgG  >mgorbatshov !02_A	et	f	\N
190253	dessantväeosa	dessantväeosa =osa  (SgN  >dessant+väe+osa !17_S	et	f	\N
190254	dessantväeosa	dessantväeosa =osa  (SgG  >dessant+väe+osa !17_S	et	f	\N
190255	dessantväeosa	dessantväeosa =osa  (SgP  >dessant+väe+osa !17_S	et	f	\N
190256	putshist	?putshist =putshi  (SgEl  >putshi !01_S	et	f	\N
190257	putshist	?putshist =putshi  (SgEl  >putsh !22_S	et	f	\N
190258	putshist	?putshist =putshis  (SgP  >putshis !09_S	et	f	\N
190259	putshist	?putshist =putshist  (SgN  >putshist !22_S	et	f	\N
190276	dessantnikud	?dessantnikud =dessantniku  (PlN  >dessantnik !25_S	et	f	\N
190277	dessantnikud	?dessantnikud =dessantniku  (IndPrSg2  >dessantnikuma !27_V	et	f	\N
190278	dessantnikud	?dessantnikud =niku  (PlN  >dessant+niku !16_S	et	f	\N
190279	dessantnikud	?dessantnikud =niku  (PlN  >dessant+nikk !22_S	et	f	\N
190281	soldatidel	### soldatidel	et	f	\N
190286	olekseestivenelane	?olekseestivenelane =olekseestivenelane  (SgN  >olekseestivenelane !12_S	et	f	\N
190287	olekseestivenelane	?olekseestivenelane =olekseestivenelane  (PlP  >olekseestivenelan !19_S	et	f	\N
190289	martsis	?martsis =martsi  (SgIn  >marts !22_S	et	f	\N
190290	martsis	?martsis =martsi  (IndIpfSg3  >martsima !28_V	et	f	\N
190291	martsis	?martsis =martsis  (SgN  >martsis !09_S	et	f	\N
190305	1991a	### 1991a	et	f	\N
190310	nõrgustamist	?nõrgustamist =nõrgustami  (SgEl  >nõrgustam !02_A	et	f	\N
190311	nõrgustamist	?nõrgustamist =nõrgustamis  (SgP  >nõrgustamis !09_S	et	f	\N
190312	nõrgustamist	?nõrgustamist =nõrgustamis  (SgP  >nõrgustamine !12_S	et	f	\N
190313	nõrgustamist	?nõrgustamist =nõrgustamist  (SgN  >nõrgustamist !22_S	et	f	\N
190317	lippude	lippude =lippu  (PlG  >lipp !22_S	et	f	\N
190318	lippude	lippude =ude  (SgN  >lipp+ude !04_S	et	f	\N
190325	seak	?seak =seak  (SgN  >seak !22_S	et	f	\N
190329	ideoloogilise	ideoloogilise =ideoloogilise  (SgG  >ideoloogiline !12_A	et	f	\N
190330	ideoloogilise	"ideoloogiline %ideoloogi  )LINE_aA  <ideoloog ;22_S	et	f	\N
190331	ideoloogilise	ideoloogilise =loogilise  (SgG  >ideo+loogiline !12_A	et	f	\N
190332	ideoloogilise	"ideo+loogiline %loogi  )LINE_aA  <ideo+loog ;22_S	et	f	\N
190333	eraldatus	eraldatus =eraldatu  (SgIn  >eraldatu !01_S	et	f	\N
190334	eraldatus	"eraldatu %eralda  )TU1_vS  <eraldama ;27_V	et	f	\N
190335	eraldatus	eraldatus =eraldatus  (SgN  >eraldatus !11?09_S	et	f	\N
190336	eraldatus	"eraldatus %eralda  )TUS1_aS  <eraldama ;27_V	et	f	\N
190352	kakskeelsus	kakskeelsus =keelsus  (SgN  >kaks+keelsus !11~09_S	et	f	\N
190353	kakskeelsus	"kaks+keelsus %keelse  )US_aS  <kaks+keelne ;02_A	et	f	\N
190357	ajavahemikust	ajavahemikust =miku  (SgEl  >aja+vahe+mikk !22_S	et	f	\N
190175	emotsionaalsuse	emotsionaalsuse =emotsionaalsuse  (SgG  >emotsionaalsus !11~09_S	et	f	\N
190176	emotsionaalsuse	"emotsionaalsus %emotsionaalse  )US_aS  <emotsionaalne ;02_A	et	f	\N
190185	isikuse	?isikuse =isikuse  (SgG  >isikus !11_S	et	f	\N
190186	isikuse	?isikuse =use  (SgN  >isik+use !16_S	et	f	\N
190187	isikuse	?isikuse =use  (SgG  >isik+use !16_S	et	f	\N
190188	käitumisele	käitumisele =käitumise  (SgAll  >käitumine !12_S	et	f	\N
190189	käitumisele	"käitumine %käitu  )MINE_vS  <käituma ;27_V	et	f	\N
190213	tajusid	tajusid =taju  (PlP  >taju !17_S	et	f	\N
190214	tajusid	tajusid =taju  (IndIpfSg2  >tajuma !27_V	et	f	\N
190215	tajusid	tajusid =taju  (IndIpfPl3  >tajuma !27_V	et	f	\N
190223	hõivata	hõivata =hõiva  (Inf  >hõivama !29_V	et	f	\N
190224	hõivata	hõivata =hõiva  (IndPrIps_  >hõivama !29_V	et	f	\N
190244	avalikkusele	avalikkusele =avalikkuse  (SgAll  >avalikkus !11~09_S	et	f	\N
190245	avalikkusele	"avalikkus %avalikku  )US_aS  <avalik ;25_A	et	f	\N
190246	riigipöörajatele	?riigipöörajatele =riigipööraja  (PlAll  >riigipööraja !01_S	et	f	\N
190247	riigipöörajatele	?riigipöörajatele =riigipööraja  (PlAll  >riigipöörajas !02_A	et	f	\N
190248	riigipöörajatele	?riigipöörajatele =riigipöörajate  (PlAll  >riigipöörajatt !22_S	et	f	\N
190249	riigipöörajatele	?riigipöörajatele =riigipöörajatele  (IndPrPs_  >riigipöörajatelema !36_V	et	f	\N
190250	riigipöörajatele	?riigipöörajatele =riigipöörajatele  (ImpPrSg2  >riigipöörajatelema !36_V	et	f	\N
190251	armeed	armeed =armee  (PlN  >armee !26_S	et	f	\N
190252	armeed	armeed =armee  (SgP  >armee !26_S	et	f	\N
190269	jäudis	?jäudis =jäudi  (SgIn  >jäudi !16_S	et	f	\N
190270	jäudis	?jäudis =jäudi  (SgIn  >jäut !22_S	et	f	\N
190271	jäudis	?jäudis =jäudi  (IndIpfSg3  >jäudima !28_V	et	f	\N
190272	jäudis	?jäudis =jäudis  (SgN  >jäudis !09_S	et	f	\N
190275	nägedes	?nägedes =näge  (PlIn  >näge !16_S	et	f	\N
190288	kujytada	### kujytada	et	f	\N
190306	lagunemiseni	lagunemiseni =lagunemise  (SgTer  >lagunemine !12_S	et	f	\N
190307	lagunemiseni	"lagunemine %lagune  )MINE_vS  <lagunema ;27_V	et	f	\N
190308	ajaltähendas	?ajaltähendas =ajaltähenda  (SgIn  >ajaltähenda !16_S	et	f	\N
190309	ajaltähendas	?ajaltähendas =ajaltähenda  (IndIpfSg3  >ajaltähendama !27_V	et	f	\N
190339	arengutest	arengutest =arengu  (PlEl  >areng !02_S	et	f	\N
190340	arengutest	arengutest =test  (SgN  >arengu+test !22_S	et	f	\N
190343	ebasovita	?ebasovita =ebasovi  (SgAb  >ebasov !02_A	et	f	\N
190344	ebasovita	?ebasovita =ebasovita  (IndPrPs_  >ebasovitama !27_V	et	f	\N
190345	ebasovita	?ebasovita =ebasovita  (ImpPrSg2  >ebasovitama !27_V	et	f	\N
190346	ebasovita	?ebasovita =sovi  (SgAb  >eba+sovi !17_S	et	f	\N
190350	sundorienteeritus	sundorienteeritus =orienteeritu  (SgIn  >sund+orienteeritu !01_S	et	f	\N
190351	sundorienteeritus	sundorienteeritus =orienteeritus  (SgN  >sund+orienteeritus !11_S	et	f	\N
190392	lõppevad	lõppevad =lõppe  (IndPrPl3  >lõppema !27_V	et	f	\N
190393	lõppevad	lõppevad =lõppeva  (PlN  >lõppev !02_A	et	f	\N
190394	lõppevad	"lõppev %lõpp  )V_vA  <lõpma ;35_V	et	f	\N
190395	lõppevad	"lõppev %lõppe  )V_vA  <lõppema ;27_V	et	f	\N
190396	lõppevad	"lõppev %lõppe  )V_vA  <lõppema ;28_V	et	f	\N
190408	viirastusi	viirastusi =viirastusi  (PlP  >viirastus !11_S	et	f	\N
190409	viirastusi	"viirastus %viirasta  )US_vS  <viirastama ;27_V	et	f	\N
190418	pop-art-i	pop-art-i =pop-art  (SgG  >pop-art !xx_Q	et	f	\N
190419	pop-art-i	pop-art-i =pop-art  (SgP  >pop-art !xx_Q	et	f	\N
190420	pop-art-i	pop-art-i =pop-art  (SgAdt  >pop-art !xx_Q	et	f	\N
190421	trükitähtedega	trükitähtedega =ede  (SgKom  >trüki+täht+ede !16_S	et	f	\N
190422	trükitähtedega	trükitähtedega =tähte  (PlKom  >trüki+täht !22_S	et	f	\N
190433	tellimine	tellimine =tellimine  (SgN  >tellimine !12_S	et	f	\N
190434	tellimine	"tellimine %telli  )MINE_vS  <tellima ;28_V	et	f	\N
190469	präegusel	?präegusel =präeguse  (SgAd  >präegus !11~09_S	et	f	\N
190470	präegusel	?präegusel =präegusel  (SgN  >präegusel !19_S	et	f	\N
190471	veetmises	veetmises =veetmise  (SgIn  >veetmine !12?10_S	et	f	\N
190472	veetmises	"veetmine %veet  )MINE_vS  <veetma ;34_V	et	f	\N
190473	minuarust	minuarust =aru  (SgEl  >minu+aru !17_S	et	f	\N
190474	minuarust	minuarust =aru  (PlEl  >minu+arg !22_A	et	f	\N
190475	minuarust	minuarust =arus  (SgP  >minu+arune !10_A	et	f	\N
190476	minuarust	"minu+arune %aru  )NE_aA  <minu+aru ;17_S	et	f	\N
190478	inimkondale	?inimkondale =inimkonda  (SgAll  >inimkonda !16_S	et	f	\N
190479	inimkondale	?inimkondale =konda  (SgAll  >inim+konda !16_S	et	f	\N
190482	mercedes	### mercedes	et	f	\N
190492	autorendist	autorendist =rendi  (SgEl  >auto+rent !22_S	et	f	\N
190493	autorendist	autorendist =rendis  (SgP  >auto+rendis !09_S	et	f	\N
190494	autovedu	autovedu =vedu  (SgN  >auto+vedu !18_S	et	f	\N
190495	autovedu	autovedu =vedu  (SgP  >auto+vedu !18_S	et	f	\N
190519	parkimise	parkimise =parkimise  (SgG  >parkimine !12_S	et	f	\N
190520	parkimise	"parkimine %parki  )MINE_vS  <parkima ;28_V	et	f	\N
190552	panka	panka =panka  (ID  >panka !41_D	et	f	\N
190553	panka	panka =panka  (SgG  >pangas !07_S	et	f	\N
190554	panka	panka =panka  (SgP  >pank !22_S	et	f	\N
190555	panka	panka =panka  (SgAdt  >pank !22_S	et	f	\N
190192	hirmusta	?hirmusta =hirmusta  (IndPrPs_  >hirmustama !27_V	et	f	\N
190193	hirmusta	?hirmusta =hirmusta  (ImpPrSg2  >hirmustama !27_V	et	f	\N
190194	hirmusta	?hirmusta =usta  (SgN  >hirm+usta !16_S	et	f	\N
190195	hirmusta	?hirmusta =usta  (SgG  >hirm+usta !16_S	et	f	\N
190196	rphkem	### rphkem	et	f	\N
190205	täpsustega	täpsustega =täpsus  (PlKom  >täpsus !11~09_S	et	f	\N
190206	täpsustega	"täpsus %täpsa  )US_aS  <täppis ;02_A	et	f	\N
190207	täpsustega	"täpsus %täpse  )US_aS  <täpne ;02_A	et	f	\N
190208	kaos	kaos =kao  (SgIn  >kabu !18_S	et	f	\N
190209	kaos	kaos =kao  (SgIn  >kadu !18_S	et	f	\N
190210	kaos	kaos =kaos  (SgN  >kaos !09_S	et	f	\N
190217	päevadja	?päevadja =päevadja  (SgN  >päevadja !01_S	et	f	\N
190218	päevadja	?päevadja =päevadja  (SgG  >päevadja !01_S	et	f	\N
190219	päevadja	?päevadja =päevadja  (SgG  >päevadjas !02_A	et	f	\N
190220	päevadja	?päevadja =adja  (SgN  >päev+adja !16_S	et	f	\N
190221	päevadja	?päevadja =adja  (SgG  >päev+adjas !02_A	et	f	\N
190222	päevadja	?päevadja =adja  (SgG  >päev+adja !16_S	et	f	\N
190229	seisasid	?seisasid =seisa  (PlP  >seisa !16_S	et	f	\N
190230	seisasid	?seisasid =seisa  (IndIpfSg2  >seisama !29_V	et	f	\N
190231	seisasid	?seisasid =seisa  (IndIpfPl3  >seisama !29_V	et	f	\N
190234	tõrjumuse	?tõrjumuse =tõrjumuse  (SgG  >tõrjumus !11_S	et	f	\N
190237	janajev	?janajev =janajev  (SgN  >janajev !02_A	et	f	\N
190238	volitusedpõhjendades	?volitusedpõhjendades =volitusedpõhjenda  (PlIn  >volitusedpõhjenda !16_S	et	f	\N
190239	volitusedpõhjendades	?volitusedpõhjendades =volitusedpõhjenda  (Ger  >volitusedpõhjendama !27_V	et	f	\N
190240	volitusedpõhjendades	?volitusedpõhjendades =tusedpõhjenda  (PlIn  >voli+tusedpõhjenda !16_S	et	f	\N
190263	usutav	usutav =usu  (PtsPrIps  >uskuma !28_V	et	f	\N
190264	usutav	usutav =usuta  (PtsPrPs  >usutama !27_V	et	f	\N
190265	usutav	usutav =usutav  (SgN  >usutav !02_A	et	f	\N
190266	usutav	"usutav %usu  )TAV_vAS  <uskuma ;28_V	et	f	\N
190267	usutav	"usutav %usuta  )V_vA  <usutama ;27_V	et	f	\N
190268	shanss	?shanss =shanss  (SgN  >shanss !22_S	et	f	\N
190273	teadnus	teadnus =teadnu  (SgIn  >teadnu !01_S	et	f	\N
190274	teadnus	"teadnu %tead  )NU_vS  <teadma ;34_V	et	f	\N
190282	kaitsjaid	kaitsjaid =kaitsja  (PlP  >kaitsja !01_S	et	f	\N
190283	kaitsjaid	"kaitsja %kaits  )JA_vS  <kaitsma ;32_V	et	f	\N
190292	valitseva	valitseva =valitseva  (SgG  >valitsev !02_A	et	f	\N
190293	valitseva	"valitsev %valitse  )V_vA  <valitsema ;27_V	et	f	\N
190294	rezhiimi	?rezhiimi =rezhiimi  (SgN  >rezhiimi !16_S	et	f	\N
190295	rezhiimi	?rezhiimi =rezhiimi  (SgG  >rezhiimi !16_S	et	f	\N
190296	rezhiimi	?rezhiimi =rezhiimi  (SgG  >rezhiim !22_S	et	f	\N
190297	rezhiimi	?rezhiimi =rezhiimi  (SgP  >rezhiim !22_S	et	f	\N
190298	rezhiimi	?rezhiimi =rezhiimi  (SgAdt  >rezhiim !22_S	et	f	\N
190299	rezhiimi	?rezhiimi =rezhiimi  (IndPrPs_  >rezhiimima !28_V	et	f	\N
190300	rezhiimi	?rezhiimi =rezhiimi  (ImpPrSg2  >rezhiimima !28_V	et	f	\N
190337	läänevaimsetest	läänevaimsetest =sete  (PlEl  >lääne+vaim+sett !22_S	et	f	\N
190338	läänevaimsetest	läänevaimsetest =vaimse  (PlEl  >lääne+vaimne !02_A	et	f	\N
190341	sundorienteeritust	sundorienteeritust =orienteeritu  (SgEl  >sund+orienteeritu !01_S	et	f	\N
190342	sundorienteeritust	sundorienteeritust =orienteeritus  (SgP  >sund+orienteeritus !11_S	et	f	\N
190359	eakas	eakas =eaka  (SgIn  >eakas !02_A	et	f	\N
190361	eakas	eakas =eakas  (SgN  >eakas !02_A	et	f	\N
190381	tairon	?tairon =tairon  (SgN  >tairon !02_S	et	f	\N
190382	plaanivad	plaanivad =plaani  (IndPrPl3  >plaanima !28_V	et	f	\N
190383	plaanivad	plaanivad =plaaniva  (PlN  >plaaniv !02_A	et	f	\N
190384	plaanivad	"plaaniv %plaani  )V_vA  <plaanima ;28_V	et	f	\N
190385	merionisse	?merionisse =merioni  (SgIll  >merioni !16_S	et	f	\N
190386	merionisse	?merionisse =merioni  (SgIll  >merion !19_S	et	f	\N
190387	merionisse	?merionisse =merionisse  (SgG  >merionisne !02_A	et	f	\N
190388	merionisse	?merionisse =merionisse  (PlP  >merioniss !22_S	et	f	\N
190389	merionisse	?merionisse =oni  (SgIll  >meri+oni !17_S	et	f	\N
190390	merionisse	?merionisse =onisse  (SgG  >meri+onisne !02_A	et	f	\N
190391	merionisse	?merionisse =onisse  (PlP  >meri+oniss !22_S	et	f	\N
190410	amputeerivad	amputeerivad =amputeeri  (IndPrPl3  >amputeerima !28_V	et	f	\N
190411	amputeerivad	amputeerivad =amputeeriva  (PlN  >amputeeriv !02_A	et	f	\N
190412	amputeerivad	"amputeeriv %amputeeri  )V_vA  <amputeerima ;28_V	et	f	\N
190438	tutvumisi	tutvumisi =tutvumisi  (PlP  >tutvumine !12_S	et	f	\N
190440	tutvumisi	"tutvumine %tutvu  )MINE_vS  <tutvuma ;27_V	et	f	\N
190444	ridala	?ridala =ridala  (SgN  >ridala !01_S	et	f	\N
190445	ridala	?ridala =ridala  (SgG  >ridala !01_S	et	f	\N
190446	topu	?topu =topu  (SgN  >topu !16_S	et	f	\N
190447	topu	?topu =topu  (SgG  >topu !16_S	et	f	\N
190448	topu	?topu =topu  (IndPrPs_  >topuma !27_V	et	f	\N
190449	topu	?topu =topu  (ImpPrSg2  >topuma !27_V	et	f	\N
190452	telkimise	telkimise =telkimise  (SgG  >telkimine !12_S	et	f	\N
190453	telkimise	"telkimine %telki  )MINE_vS  <telkima ;28_V	et	f	\N
190454	vihmase	vihmase =vihmase  (SgG  >vihmane !10_A	et	f	\N
190455	vihmase	"vihmane %vihma  )NE_aA  <vihm ;22_S	et	f	\N
190358	ajavahemikust	ajavahemikust =vahemiku  (SgEl  >aja+vahemik !25_S	et	f	\N
190365	goldfarb	?goldfarb =goldfarb  (SgN  >goldfarb !02_S	et	f	\N
190366	garri	?garri =garri  (SgN  >garri !16_S	et	f	\N
190367	garri	?garri =garri  (SgG  >garri !16_S	et	f	\N
190368	garri	?garri =garri  (SgG  >garr !22_S	et	f	\N
190369	garri	?garri =garri  (SgP  >garr !22_S	et	f	\N
190370	garri	?garri =garri  (SgAdt  >garr !22_S	et	f	\N
190371	garri	?garri =garri  (IndPrPs_  >garrima !28_V	et	f	\N
190372	garri	?garri =garri  (ImpPrSg2  >garrima !28_V	et	f	\N
190397	müüjate	müüjate =müüja  (PlG  >müüja !01_S	et	f	\N
190398	müüjate	"müüja %müü  )JA_vS  <müüma ;38_V	et	f	\N
190416	montaazh	?montaazh =montaazh  (SgN  >montaazh !22_S	et	f	\N
190417	tunmedad	### tunmedad	et	f	\N
190431	httpwwwmolesee	?httpwwwmolesee =httpwwwmolesee  (SgN  >httpwwwmolesee !26_S	et	f	\N
190432	httpwwwmolesee	?httpwwwmolesee =httpwwwmolesee  (SgG  >httpwwwmolesee !26_S	et	f	\N
190450	wwwheapuhkusee	?wwwheapuhkusee =wwwheapuhkusee  (SgN  >wwwheapuhkusee !26_S	et	f	\N
190451	wwwheapuhkusee	?wwwheapuhkusee =wwwheapuhkusee  (SgG  >wwwheapuhkusee !26_S	et	f	\N
190484	opel	?opel =ope  (PlAd  >opp !22_S	et	f	\N
190485	opel	?opel =opel  (SgN  >opel !02_S	et	f	\N
190486	vormel	vormel =vorme  (PlAd  >vorm !22_S	et	f	\N
190487	vormel	vormel =vormel  (SgN  >vormel !02_S	et	f	\N
190488	nissan	?nissan =nissa  (IndPrSg1  >nissama !29_V	et	f	\N
190489	nissan	?nissan =nissan  (SgN  >nissan !02_S	et	f	\N
190490	primera	?primera =primera  (SgN  >primera !01_S	et	f	\N
190491	primera	?primera =primera  (SgG  >primera !01_S	et	f	\N
190501	sõltuvust	sõltuvust =sõltuvus  (SgP  >sõltuvus !11_S	et	f	\N
190502	sõltuvust	"sõltuvus %sõltu  )VUS_aS  <sõltuma ;27_V	et	f	\N
190503	sõltuvust	"sõltuvus %sõltuva  )US_aS  <sõltuv ;02_A	et	f	\N
190511	inimekond	?inimekond =inimekond  (SgN  >inimekond !22_S	et	f	\N
190512	inimekond	?inimekond =ekond  (SgN  >inim+ekond !22_S	et	f	\N
190521	meelelahutustest	meelelahutustest =test  (SgN  >meele+lahutus+test !22_S	et	f	\N
190522	meelelahutustest	meelelahutustest =lahutus  (PlEl  >meele+lahutus !11_S	et	f	\N
190523	meelelahutustest	"meele+lahutus %lahu  )TUS2_aS  <meele+lahk ;22_S	et	f	\N
190531	aregab	### aregab	et	f	\N
190532	arengusega	?arengusega =arenguse  (SgKom  >arengus !11_S	et	f	\N
190533	arengusega	?arengusega =sega  (SgN  >arengu+sega !17_S	et	f	\N
190534	arengusega	?arengusega =sega  (SgG  >arengu+sega !17_S	et	f	\N
190535	arengusega	?arengusega =sega  (SgP  >arengu+sega !17_S	et	f	\N
190536	leiuvad	?leiuvad =leiu  (IndPrPl3  >leiuma !27_V	et	f	\N
190537	leiuvad	?leiuvad =leiuva  (PlN  >leiuva !01_S	et	f	\N
190538	leiuvad	?leiuvad =leiuva  (PlN  >leiuv !02_A	et	f	\N
190539	saatab	?saatab =saata  (IndPrSg3  >saatama !27_V	et	f	\N
190548	kontrollivad	kontrollivad =kontrolli  (IndPrPl3  >kontrollima !28_V	et	f	\N
190549	kontrollivad	kontrollivad =kontrolliva  (PlN  >kontrolliv !02_A	et	f	\N
190550	kontrollivad	"kontrolliv %kontrolli  )V_vA  <kontrollima ;28_V	et	f	\N
190551	kontrollivad	kontrollivad =iva  (PlN  >kont+roll+iva !17_S	et	f	\N
190557	konstrueritud	?konstrueritud =konstrueri  (PtsPtIps  >konstruerima !28_V	et	f	\N
190558	konstrueritud	?konstrueritud =konstrueritu  (PlN  >konstrueritu !01_A	et	f	\N
190559	konstrueritud	?konstrueritud =konstrueritu  (IndPrSg2  >konstruerituma !27_V	et	f	\N
190560	konstrueritud	?konstrueritud =konstrueritud  (ID  >konstrueritud !41_A	et	f	\N
190565	kaevusid	kaevusid =kaevu  (PlP  >kaev !22_S	et	f	\N
190566	kaevusid	"kaev %kae  )V_vA  <kaema ;27_V	et	f	\N
190567	kaevusid	kaevusid =kaevu  (IndIpfSg2  >kaevuma !27_V	et	f	\N
190568	kaevusid	kaevusid =kaevu  (IndIpfPl3  >kaevuma !27_V	et	f	\N
190591	ülikkolides	### ülikkolides	et	f	\N
190592	saalid	saalid =saali  (PlN  >saal !22_S	et	f	\N
190593	saalid	saalid =saali  (IndPrSg2  >saalima !28_V	et	f	\N
190622	oliksid	?oliksid =oli  (KndPrSg2  >olima !27_V	et	f	\N
190623	oliksid	?oliksid =oli  (KndPrPl3  >olima !27_V	et	f	\N
190624	oliksid	?oliksid =oliksi  (PlN  >oliksi !01_S	et	f	\N
190625	oliksid	?oliksid =oliksi  (IndPrSg2  >oliksima !28_V	et	f	\N
190634	kuulamist	kuulamist =kuulamis  (SgP  >kuulamine !12_S	et	f	\N
190635	kuulamist	"kuulamine %kuula  )MINE_vS  <kuulama ;29_V	et	f	\N
190636	erialaaine	erialaaine =aine  (SgN  >eri+ala+aine !06_S	et	f	\N
190637	erialaaine	erialaaine =aine  (SgG  >eri+ala+aine !06_S	et	f	\N
190638	erialaaine	erialaaine =aine  (PlP  >eri+ala+ain !22_S	et	f	\N
190653	varu	varu =varu  (SgN  >varu !17_S	et	f	\N
190654	varu	varu =varu  (SgG  >varu !17_S	et	f	\N
190655	varu	varu =varu  (SgP  >varu !17_S	et	f	\N
190656	varu	varu =varu  (IndPrPs_  >varuma !27_V	et	f	\N
190657	varu	varu =varu  (ImpPrSg2  >varuma !27_V	et	f	\N
190658	õppesime	?õppesime =õppe  (IndIpfPl1  >õppema !27_V	et	f	\N
190676	õppejõuaga	?õppejõuaga =õppejõua  (SgKom  >õppejõua !01_S	et	f	\N
190677	õppejõuaga	?õppejõuaga =jõua  (SgKom  >õppe+jõua !16_S	et	f	\N
190696	näema	?näema =näema  (SgN  >näema !16_S	et	f	\N
190697	näema	?näema =näema  (SgG  >näema !16_S	et	f	\N
190698	näema	?näema =näema  (IndPrPs_  >näemama !29_V	et	f	\N
190699	näema	?näema =näema  (ImpPrSg2  >näemama !29_V	et	f	\N
190402	amfetamiini	?amfetamiini =amfetamiini  (SgG  >amfetamiini !16_S	et	f	\N
190403	amfetamiini	?amfetamiini =amfetamiini  (SgG  >amfetamiin !22_S	et	f	\N
190404	amfetamiini	?amfetamiini =amfetamiini  (SgP  >amfetamiin !22_S	et	f	\N
190405	amfetamiini	?amfetamiini =amfetamiini  (SgAdt  >amfetamiin !22_S	et	f	\N
190406	amfetamiini	?amfetamiini =amfetamiini  (IndPrPs_  >amfetamiinima !28_V	et	f	\N
190407	amfetamiini	?amfetamiini =amfetamiini  (ImpPrSg2  >amfetamiinima !28_V	et	f	\N
190413	doosi	doosi =doosi  (SgG  >doos !22_S	et	f	\N
190414	doosi	doosi =doosi  (SgP  >doos !22_S	et	f	\N
190415	doosi	doosi =doosi  (SgAdt  >doos !22_S	et	f	\N
190423	abazhuur	?abazhuur =abazhuur  (SgN  >abazhuur !22_S	et	f	\N
190424	tiraazh	?tiraazh =tiraazh  (SgN  >tiraazh !22_S	et	f	\N
190425	eksempläri	?eksempläri =eksempläri  (SgG  >eksemplär !19_S	et	f	\N
190426	eksempläri	?eksempläri =eksempläri  (SgP  >eksemplär !19_S	et	f	\N
190427	eksempläri	?eksempläri =eksempläri  (SgAdt  >eksemplär !19_S	et	f	\N
190428	eksempläri	?eksempläri =empläri  (SgN  >eks+empläri !01_S	et	f	\N
190429	eksempläri	?eksempläri =empläri  (SgG  >eks+empläri !01_S	et	f	\N
190430	eksempläri	?eksempläri =empläri  (SgG  >eks+emplär !02_S	et	f	\N
190439	iseseisvamaks	iseseisvamaks =seisvama  (SgTr  >ise+seisvam !02_A	et	f	\N
190441	iseseisvamaks	"ise+seisvam %seisva  )M_cA  <ise+seisev ;02_A	et	f	\N
190458	leiutatud	leiutatud =leiuta  (PtsPtIps  >leiutama !27_V	et	f	\N
190459	leiutatud	leiutatud =leiutatu  (PlN  >leiutatu !01_S	et	f	\N
190460	leiutatud	"leiutatu %leiuta  )TU1_vS  <leiutama ;27_V	et	f	\N
190461	leiutatud	leiutatud =leiutatud  (ID  >leiutatud !41_A	et	f	\N
190462	leiutatud	"leiutatud %leiuta  )TUD_vA  <leiutama ;27_V	et	f	\N
190506	trükkimiseks	trükkimiseks =trükkimise  (SgTr  >trükkimine !12_S	et	f	\N
190507	trükkimiseks	"trükkimine %trükki  )MINE_vS  <trükkima ;28_V	et	f	\N
190513	lendis	?lendis =lendi  (SgIn  >lendi !16_S	et	f	\N
190514	lendis	?lendis =lendi  (SgIn  >lent !22_S	et	f	\N
190515	lendis	?lendis =lendi  (IndIpfSg3  >lendima !28_V	et	f	\N
190516	lendis	?lendis =lendis  (SgN  >lendis !09_S	et	f	\N
190517	kohtumise	kohtumise =kohtumise  (SgG  >kohtumine !12_S	et	f	\N
190518	kohtumise	"kohtumine %kohtu  )MINE_vS  <kohtuma ;27_V	et	f	\N
190540	aitava	aitava =aitava  (SgG  >aitav !02_A	et	f	\N
190541	aitava	"aitav %aita  )V_vA  <aitama ;29_V	et	f	\N
190576	talved	talved =talve  (PlN  >talv !22_S	et	f	\N
190577	talved	talved =talve  (PlN  >tali !24_S	et	f	\N
190594	presintatsiooni	?presintatsiooni =presintatsioo  (SgTer  >presintatsioo !26_S	et	f	\N
190595	presintatsiooni	?presintatsiooni =presintatsiooni  (SgN  >presintatsiooni !16_S	et	f	\N
190596	presintatsiooni	?presintatsiooni =presintatsiooni  (SgG  >presintatsiooni !16_S	et	f	\N
190597	presintatsiooni	?presintatsiooni =presintatsiooni  (SgG  >presintatsioon !22_S	et	f	\N
190598	presintatsiooni	?presintatsiooni =presintatsiooni  (SgP  >presintatsioon !22_S	et	f	\N
190599	presintatsiooni	?presintatsiooni =presintatsiooni  (SgAdt  >presintatsioon !22_S	et	f	\N
190600	presintatsiooni	?presintatsiooni =presintatsiooni  (IndPrPs_  >presintatsioonima !28_V	et	f	\N
190601	presintatsiooni	?presintatsiooni =presintatsiooni  (ImpPrSg2  >presintatsioonima !28_V	et	f	\N
190602	presintatsiooni	?presintatsiooni =sintatsioo  (SgTer  >pre+sintatsioo !26_S	et	f	\N
190603	presintatsiooni	?presintatsiooni =sintatsiooni  (SgN  >pre+sintatsiooni !16_S	et	f	\N
190604	presintatsiooni	?presintatsiooni =sintatsiooni  (SgG  >pre+sintatsiooni !16_S	et	f	\N
190605	presintatsiooni	?presintatsiooni =sintatsiooni  (SgG  >pre+sintatsioon !22_S	et	f	\N
190606	presintatsiooni	?presintatsiooni =sintatsiooni  (SgP  >pre+sintatsioon !22_S	et	f	\N
190607	presintatsiooni	?presintatsiooni =sintatsiooni  (SgAdt  >pre+sintatsioon !22_S	et	f	\N
190620	kõrgkoolisse	kõrgkoolisse =kooli  (SgIll  >kõrg+kool !22_S	et	f	\N
190621	kõrgkoolisse	kõrgkoolisse =kooli  (PlIll  >kõrg+kool !22_S	et	f	\N
190630	geomeetria	geomeetria =geomeetria  (SgN  >geomeetria !01_S	et	f	\N
190631	geomeetria	geomeetria =geomeetria  (SgG  >geomeetria !01_S	et	f	\N
190645	luuletajatest	luuletajatest =luuletaja  (PlEl  >luuletaja !01_S	et	f	\N
190647	luuletajatest	"luuletaja %luuleta  )JA_vS  <luuletama ;27_V	et	f	\N
190659	õppetud	õppetud =õppetu  (PlN  >õppetu !01_A	et	f	\N
190660	õppetud	"õppetu %õppe  )TU2_kA  <õpe ;06_S	et	f	\N
190680	tähendused	tähendused =tähenduse  (PlN  >tähendus !11_S	et	f	\N
190681	tähendused	"tähendus %tähenda  )US_vS  <tähendama ;27_V	et	f	\N
190701	edukamaks	edukamaks =edukama  (SgTr  >edukam !02_A	et	f	\N
190702	edukamaks	"edukam %eduka  )M_cA  <edukas ;02_A	et	f	\N
190703	edukamaks	edukamaks =kama  (SgTr  >edu+kama !17_S	et	f	\N
190704	millionid	?millionid =millioni  (PlN  >million !19~02_S	et	f	\N
190705	millionid	?millionid =millioni  (PlN  >millioni !16_S	et	f	\N
190706	millionid	?millionid =millioni  (IndPrSg2  >millionima !28_V	et	f	\N
190707	millionid	?millionid =oni  (PlN  >milli+oni !17_S	et	f	\N
190711	lõike	lõike =lõike  (SgG  >lõige !06_S	et	f	\N
190712	lõike	lõike =lõike  (PlP  >lõik !22_S	et	f	\N
190713	pera	?pera =pera  (SgN  >pera !17_S	et	f	\N
190714	pera	?pera =pera  (SgG  >pera !17_S	et	f	\N
190715	pera	?pera =pera  (SgP  >pera !17_S	et	f	\N
190716	pera	?pera =pera  (IndPrPs_  >perama !27_V	et	f	\N
190463	ülessandeid	?ülessandeid =ülessandei  (PlN  >ülessandei !26_S	et	f	\N
190464	ülessandeid	?ülessandeid =ülessandei  (SgP  >ülessandei !26_S	et	f	\N
190465	ülessandeid	?ülessandeid =sande  (PlP  >üles+sanne !06_S	et	f	\N
190466	ülessandeid	?ülessandeid =sandei  (PlN  >üles+sandei !26_S	et	f	\N
190467	ülessandeid	?ülessandeid =sandei  (SgP  >üles+sandei !26_S	et	f	\N
190468	ülessandeid	?ülessandeid =sandeid  (SgN  >üles+sandeid !22_S	et	f	\N
190483	benz	### benz	et	f	\N
190524	üüritustest	üüritustest =üüritus  (PlEl  >üüritus !11_S	et	f	\N
190525	üüritustest	"üüritus %üüri  )TUS1_aS  <üürima ;28_V	et	f	\N
190526	üüritustest	"üüritus %üüri  )TUS2_aS  <üür ;22_S	et	f	\N
190527	üüritustest	üüritustest =tuste  (PlEl  >üüri+tust !22_S	et	f	\N
190542	omamoodes	?omamoodes =omamoo  (PlIn  >omamoo !26_S	et	f	\N
190543	omamoodes	?omamoodes =omamoode  (SgIn  >omamoode !16_S	et	f	\N
190544	omamoodes	?omamoodes =omamoode  (PlIn  >omamoot !22_S	et	f	\N
190545	omamoodes	?omamoodes =moo  (PlIn  >oma+moo !26_S	et	f	\N
190546	omamoodes	?omamoodes =moode  (PlIn  >oma+moot !22_S	et	f	\N
190547	omamoodes	?omamoodes =moodes  (SgN  >oma+moodes !09_S	et	f	\N
190561	mõtleid	?mõtleid =mõtle  (PlP  >mõttel !02_S	et	f	\N
190562	mõtleid	?mõtleid =mõtlei  (PlN  >mõtlei !26_S	et	f	\N
190563	mõtleid	?mõtleid =mõtlei  (SgP  >mõtlei !26_S	et	f	\N
190564	mõtleid	?mõtleid =mõtleid  (SgN  >mõtleid !22_S	et	f	\N
190574	hoolda	hoolda =hoolda  (IndPrPs_  >hooldama !27_V	et	f	\N
190575	hoolda	hoolda =hoolda  (ImpPrSg2  >hooldama !27_V	et	f	\N
190589	isele	?isele =isele  (IndPrPs_  >iselema !31~27_V	et	f	\N
190590	isele	?isele =isele  (ImpPrSg2  >iselema !31~27_V	et	f	\N
190608	otstarbekam	otstarbekam =tarbekam  (SgN  >ots+tarbekam !02_A	et	f	\N
190609	otstarbekam	"ots+tarbekam %tarbeka  )M_cA  <ots+tarbekas ;02_A	et	f	\N
190611	ohh	?ohh =ohh  (ID  >ohh !41_I	et	f	\N
190616	filosoofilisi	filosoofilisi =filosoofilisi  (PlP  >filosoofiline !12_A	et	f	\N
190617	filosoofilisi	"filosoofiline %filosoofi  )LINE_aA  <filosoof ;22_S	et	f	\N
190628	raskemad	raskemad =raskema  (PlN  >raskem !02_A	et	f	\N
190629	raskemad	"raskem %raske  )M_cA  <raske ;01_A	et	f	\N
190632	definitsiooneid	?definitsiooneid =definitsioonei  (PlN  >definitsioonei !26_S	et	f	\N
190633	definitsiooneid	?definitsiooneid =definitsioonei  (SgP  >definitsioonei !26_S	et	f	\N
190639	hooneosasid	hooneosasid =sasi  (PlN  >hoo+neo+sasi !17_S	et	f	\N
190640	hooneosasid	hooneosasid =osa  (PlP  >hoone+osa !17_S	et	f	\N
190643	näitlejatest	näitlejatest =näitleja  (PlEl  >näitleja !01_S	et	f	\N
190644	näitlejatest	"näitleja %näitle  )JA_vS  <näitlema ;30_V	et	f	\N
190646	näitlejatest	näitlejatest =test  (SgN  >näitleja+test !22_S	et	f	\N
190650	keelet	?keelet =keele  (SgP  >keele !06_S	et	f	\N
190666	valgustusi	valgustusi =valgustusi  (PlP  >valgustus !11_S	et	f	\N
190667	valgustusi	"valgustus %valgusta  )US_vS  <valgustama ;27_V	et	f	\N
190670	õppeasutuses	õppeasutuses =asutuse  (SgIn  >õppe+asutus !11_S	et	f	\N
190671	õppeasutuses	"õppe+asutus %asu  )TUS2_aS  <õppe+asu ;17_S	et	f	\N
190672	aidatakse	aidatakse =aida  (IndPrIps  >aitama !29_V	et	f	\N
190673	aidatakse	aidatakse =takse  (PlP  >aida+taks !22_S	et	f	\N
190684	erinevatelt	erinevatelt =erineva  (PlAbl  >erinev !02_A	et	f	\N
190685	erinevatelt	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
190688	verivorsti	verivorsti =vorsti  (SgG  >veri+vorst !22_S	et	f	\N
190689	verivorsti	verivorsti =vorsti  (SgP  >veri+vorst !22_S	et	f	\N
190690	verivorsti	verivorsti =vorsti  (SgAdt  >veri+vorst !22_S	et	f	\N
190691	viiendaks	viiendaks =viienda  (SgTr  >viies !02_O	et	f	\N
190692	viiendaks	viiendaks =viiendaks  (ID  >viiendaks !41_D	et	f	\N
190700	wordil	?wordil =wordi  (SgAd  >wort !22_S	et	f	\N
190807	infohallikas	infohallikas =hallika  (SgIn  >info+hallikas !02_A	et	f	\N
190808	infohallikas	infohallikas =hallikas  (SgN  >info+hallikas !02_A	et	f	\N
190817	tradition	?tradition =tradition  (SgN  >tradition !19_S	et	f	\N
190833	hard-rocky	### hard-rocky	et	f	\N
190860	telefoonid	telefoonid =telefooni  (IndPrSg2  >telefoonima !28_V	et	f	\N
190861	telefoonid	telefoonid =fooni  (PlN  >tele+foon !22_S	et	f	\N
190865	lihtned	?lihtned =lihtne  (IndPrSg2  >lihtnema !27_V	et	f	\N
190928	no-how	### no-how	et	f	\N
190960	autose	?autose =autose  (SgG  >autos !11~09_S	et	f	\N
190961	autose	?autose =tose  (SgN  >au+tose !16_S	et	f	\N
190962	autose	?autose =tose  (SgG  >au+tose !16_S	et	f	\N
190985	vererõhku	vererõhku =rõhku  (SgP  >vere+rõhk !22_S	et	f	\N
190986	vererõhku	vererõhku =rõhku  (SgAdt  >vere+rõhk !22_S	et	f	\N
190993	haiguseid	haiguseid =haiguse  (PlP  >haigus !09_S	et	f	\N
190994	haiguseid	"haigus %haige  )US_aS  <haige ;01_AS	et	f	\N
190995	dushshi	?dushshi =dushshi  (SgN  >dushshi !01_S	et	f	\N
190996	dushshi	?dushshi =dushshi  (SgG  >dushshi !01_S	et	f	\N
190997	dushshi	?dushshi =dushshi  (SgG  >dushsh !22_S	et	f	\N
190998	dushshi	?dushshi =dushshi  (SgP  >dushsh !22_S	et	f	\N
190999	dushshi	?dushshi =dushshi  (SgAdt  >dushsh !22_S	et	f	\N
191000	dushshi	?dushshi =dushshi  (IndPrPs_  >dushshima !28_V	et	f	\N
191001	dushshi	?dushshi =dushshi  (ImpPrSg2  >dushshima !28_V	et	f	\N
190496	õluta	?õluta =õlu  (IndPrIps_  >õluma !27_V	et	f	\N
190497	õluta	?õluta =õluta  (IndPrPs_  >õlutama !27_V	et	f	\N
190498	õluta	?õluta =õluta  (ImpPrSg2  >õlutama !27_V	et	f	\N
190499	raamatuta	raamatuta =raamatu  (SgAb  >raamat !02_S	et	f	\N
190500	raamatuta	raamatuta =atu  (SgAb  >raam+att !22_S	et	f	\N
190504	surfin	?surfin =surfi  (IndPrSg1  >surfima !28_V	et	f	\N
190505	surfin	?surfin =surfin  (SgN  >surfin !02_S	et	f	\N
190508	gaasita	gaasita =gaasi  (SgAb  >gaas !22_S	et	f	\N
190509	gaasita	gaasita =gaasita  (IndPrPs_  >gaasitama !27_V	et	f	\N
190510	gaasita	gaasita =gaasita  (ImpPrSg2  >gaasitama !27_V	et	f	\N
190528	keegile	?keegile =keegi  (SgAll  >keek !22_S	et	f	\N
190529	keegile	?keegile =keegile  (IndPrPs_  >keegilema !27_V	et	f	\N
190530	keegile	?keegile =keegile  (ImpPrSg2  >keegilema !27_V	et	f	\N
190569	mada	?mada =mada  (SgN  >mada !17_S	et	f	\N
190570	mada	?mada =mada  (SgG  >mada !17_S	et	f	\N
190571	mada	?mada =mada  (SgP  >mada !17_S	et	f	\N
190572	mada	?mada =mada  (IndPrPs_  >madama !27_V	et	f	\N
190573	mada	?mada =mada  (ImpPrSg2  >madama !27_V	et	f	\N
190578	külmkappid	?külmkappid =külmkappi  (PlN  >külmkappi !01_S	et	f	\N
190584	leiutiseid	?leiutiseid =leiutisei  (PlN  >leiutisei !26_S	et	f	\N
190585	leiutiseid	?leiutiseid =leiutisei  (SgP  >leiutisei !26_S	et	f	\N
190586	leiutiseid	?leiutiseid =tisei  (PlN  >leiu+tisei !26_S	et	f	\N
190587	leiutiseid	?leiutiseid =tisei  (SgP  >leiu+tisei !26_S	et	f	\N
190588	leiutiseid	?leiutiseid =tiseid  (SgN  >leiu+tiseid !22_S	et	f	\N
190610	sündib	?sündib =sündi  (IndPrSg3  >süntima !28_V	et	f	\N
190612	tänapäevuse	?tänapäevuse =tänapäevuse  (SgG  >tänapäevus !11~09_S	et	f	\N
190613	tänapäevuse	?tänapäevuse =use  (SgN  >täna+päev+use !16_S	et	f	\N
190614	tänapäevuse	?tänapäevuse =use  (SgG  >täna+päev+use !16_S	et	f	\N
190615	tänapäevuse	?tänapäevuse =päevuse  (SgG  >täna+päevus !11~09_S	et	f	\N
190618	fülosoofiliselt	?fülosoofiliselt =fülosoofilise  (SgAbl  >fülosoofiline !12_A	et	f	\N
190619	fülosoofiliselt	?fülosoofiliselt =fülosoofiliselt  (ID  >fülosoofiliselt !41_D	et	f	\N
190648	heliloojatest	heliloojatest =test  (SgN  >heli+looja+test !22_S	et	f	\N
190649	heliloojatest	heliloojatest =looja  (PlEl  >heli+looja !01_S	et	f	\N
190651	osakonnale	osakonnale =osakonna  (SgAll  >osakond !22_S	et	f	\N
190652	osakonnale	osakonnale =konna  (SgAll  >osa+konn !22_S	et	f	\N
190661	trolli	trolli =trolli  (SgN  >trolli !16_S	et	f	\N
190662	trolli	trolli =trolli  (SgG  >trolli !16_S	et	f	\N
190663	trolli	trolli =trolli  (SgG  >troll !22_S	et	f	\N
190664	trolli	trolli =trolli  (SgP  >troll !22_S	et	f	\N
190665	trolli	trolli =trolli  (SgAdt  >troll !22_S	et	f	\N
190668	halvaks	halvaks =halva  (SgTr  >halb !22_A	et	f	\N
190669	halvaks	halvaks =halva  (KndPrPs  >halvama !29_V	et	f	\N
190674	teadmistel	teadmistel =teadmis  (PlAd  >teadmine !12?10_S	et	f	\N
190675	teadmistel	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
190678	hooneteehitus	hooneteehitus =ehitu  (SgIn  >hoonete+ehitu !01_AS	et	f	\N
190679	hooneteehitus	hooneteehitus =ehitus  (SgN  >hoonete+ehitus !11_S	et	f	\N
190686	erinevade	?erinevade =erineva  (PlG  >erineva !16_S	et	f	\N
190687	erinevade	?erinevade =neva  (PlG  >eri+neva !17_S	et	f	\N
190693	sünoonimi	?sünoonimi =sünoonimi  (SgG  >sünoonim !02_A	et	f	\N
190694	kuuendaks	kuuendaks =kuuenda  (SgTr  >kuues !02_O	et	f	\N
190695	kuuendaks	kuuendaks =kuuendaks  (ID  >kuuendaks !41_D	et	f	\N
190722	tõstakse	?tõstakse =tõstakse  (SgG  >tõstakne !02_A	et	f	\N
190723	koordinaalselt	?koordinaalselt =koordinaalse  (SgAbl  >koordinaalne !02_A	et	f	\N
190724	koordinaalselt	?koordinaalselt =koordinaalse  (PlAbl  >koordinaals !22_S	et	f	\N
190725	koordinaalselt	?koordinaalselt =koordinaalselt  (ID  >koordinaalselt !41_D	et	f	\N
190726	koordinaalselt	?koordinaalselt =dinaalse  (SgAbl  >koor+dinaalne !02_A	et	f	\N
190727	koordinaalselt	?koordinaalselt =dinaalse  (PlAbl  >koor+dinaals !22_S	et	f	\N
190740	järvelt	järvelt =järve  (SgAbl  >järv !22_S	et	f	\N
190741	järvelt	järvelt =järve  (PlAbl  >järv !22_S	et	f	\N
190749	mobiiltelefoniga	mobiiltelefoniga =iga  (SgN  >mobiil+telefon+iga !18_S	et	f	\N
190750	mobiiltelefoniga	mobiiltelefoniga =iga  (SgP  >mobiil+telefon+iga !18_S	et	f	\N
190751	mobiiltelefoniga	mobiiltelefoniga =telefoni  (SgKom  >mobiil+telefon !19_S	et	f	\N
190758	ümbritsevatele	ümbritsevatele =ümbritseva  (PlAll  >ümbritsev !02_A	et	f	\N
190759	ümbritsevatele	"ümbritsev %ümbritse  )V_vA  <ümbritsema ;27_V	et	f	\N
190772	lähedamat	lähedamat =lähedama  (SgP  >lähedam !02_A	et	f	\N
190773	lähedamat	"lähedam %läheda  )M_cA  <läheda ;02_A	et	f	\N
190776	raamatukogutele	?raamatukogutele =raamatukogute  (PlAll  >raamatukogutt !22_S	et	f	\N
190777	raamatukogutele	?raamatukogutele =raamatukogutele  (IndPrPs_  >raamatukogutelema !36_V	et	f	\N
190778	raamatukogutele	?raamatukogutele =raamatukogutele  (ImpPrSg2  >raamatukogutelema !36_V	et	f	\N
190779	raamatukogutele	?raamatukogutele =kogute  (PlAll  >raamatu+kogutt !22_S	et	f	\N
190780	raamatukogutele	?raamatukogutele =atukogute  (PlAll  >raam+atukogutt !22_S	et	f	\N
190797	riigiasutust	riigiasutust =tust  (SgN  >riigi+asu+tust !22_S	et	f	\N
190798	riigiasutust	riigiasutust =asutu  (SgEl  >riigi+asutu !01_AS	et	f	\N
190556	aidab	?aidab =aida  (IndPrSg3  >aidama !29_V	et	f	\N
190579	konstrueeritud	konstrueeritud =konstrueeri  (PtsPtIps  >konstrueerima !28_V	et	f	\N
190580	konstrueeritud	konstrueeritud =konstrueeritu  (PlN  >konstrueeritu !01_S	et	f	\N
190581	konstrueeritud	"konstrueeritu %konstrueeri  )TU1_vS  <konstrueerima ;28_V	et	f	\N
190582	konstrueeritud	konstrueeritud =konstrueeritud  (ID  >konstrueeritud !41_A	et	f	\N
190583	konstrueeritud	"konstrueeritud %konstrueeri  )TUD_vA  <konstrueerima ;28_V	et	f	\N
190626	ainetest	ainetest =aine  (PlEl  >aine !06_S	et	f	\N
190627	ainetest	ainetest =test  (SgN  >aine+test !22_S	et	f	\N
190641	kommest	kommest =komme  (PlEl  >komm !22_S	et	f	\N
190642	kommest	kommest =mest  (SgN  >kom+mest !22_S	et	f	\N
190682	rääkijatele	rääkijatele =rääkija  (PlAll  >rääkija !01_S	et	f	\N
190683	rääkijatele	"rääkija %rääki  )JA_vS  <rääkima ;28_V	et	f	\N
190718	hüdraulika	hüdraulika =hüdraulika  (SgN  >hüdraulika !01_S	et	f	\N
190719	hüdraulika	hüdraulika =hüdraulika  (SgG  >hüdraulika !01_S	et	f	\N
190738	mobiiltelefonist	mobiiltelefonist =telefoni  (SgEl  >mobiil+telefon !19_S	et	f	\N
190739	mobiiltelefonist	mobiiltelefonist =telefonist  (SgN  >mobiil+telefonist !22_S	et	f	\N
190742	televisorita	?televisorita =televisori  (SgAb  >televisor !02_S	et	f	\N
190743	televisorita	?televisorita =televisorita  (IndPrPs_  >televisoritama !27_V	et	f	\N
190744	televisorita	?televisorita =televisorita  (ImpPrSg2  >televisoritama !27_V	et	f	\N
190745	televisorita	?televisorita =visori  (SgAb  >tele+visori !01_S	et	f	\N
190746	televisorita	?televisorita =visori  (SgAb  >tele+visor !02_S	et	f	\N
190760	tehnikakõrgkoolist	tehnikakõrgkoolist =kooli  (SgEl  >tehnika+kõrg+kool !22_S	et	f	\N
190761	tehnikakõrgkoolist	tehnikakõrgkoolist =kooli  (PlEl  >tehnika+kõrg+kool !22_S	et	f	\N
190762	tehnikakõrgkoolist	tehnikakõrgkoolist =koolis  (SgP  >tehnika+kõrg+kooline !10_A	et	f	\N
190763	tehnikakõrgkoolist	"tehnika+kõrg+kooline %koo  )LINE_aA  <tehnika+kõrg+kubu ;18_S	et	f	\N
190764	tehnikakõrgkoolist	"tehnika+kõrg+kooline %kooli  )NE_aA  <tehnika+kõrg+kool ;22_S	et	f	\N
190768	leitustest	leitustest =leitus  (PlEl  >leitus !11~09_S	et	f	\N
190769	leitustest	"leitus %lei  )TUS1_aS  <leidma ;34_V	et	f	\N
190770	leitustest	"leitus %lei  )TUS2_aS  <lei ;26_S	et	f	\N
190771	leitustest	leitustest =us  (PlEl  >leit+uks !14_S	et	f	\N
190774	õnnelikku	õnnelikku =õnnelikku  (SgP  >õnnelik !25_A	et	f	\N
190775	õnnelikku	õnnelikku =õnnelikku  (SgAdt  >õnnelik !25_A	et	f	\N
190781	riige	?riige =riige  (SgN  >riige !06_S	et	f	\N
190782	riige	?riige =riige  (PlP  >riig !22_S	et	f	\N
190783	riige	?riige =riige  (IndPrPs_  >riigema !27_V	et	f	\N
190784	riige	?riige =riige  (ImpPrSg2  >riigema !27_V	et	f	\N
190785	fan	### fan	et	f	\N
190790	erinevatesse	erinevatesse =erineva  (PlIll  >erinev !02_A	et	f	\N
190791	erinevatesse	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
190804	arvutides	?arvutides =tide  (SgIn  >arvu+tide !16_S	et	f	\N
190805	arvutides	?arvutides =tides  (SgN  >arvu+tides !09_S	et	f	\N
190806	arvutides	?arvutides =uti  (PlIn  >arv+uti !16_S	et	f	\N
190811	sovitab	?sovitab =sovita  (IndPrSg3  >sovitama !27_V	et	f	\N
190821	hed	### hed	et	f	\N
190828	mikrolaenuahju	mikrolaenuahju =ahju  (SgG  >mikro+laenu+ahi !24_S	et	f	\N
190829	mikrolaenuahju	mikrolaenuahju =ahju  (SgP  >mikro+laenu+ahi !24_S	et	f	\N
190830	mikrolaenuahju	mikrolaenuahju =ahju  (SgAdt  >mikro+laenu+ahi !24_S	et	f	\N
190848	rehvid	rehvid =rehvi  (PlN  >rehv !22_S	et	f	\N
190849	rehvid	rehvid =rehvi  (IndPrSg2  >rehvima !28_V	et	f	\N
190949	rismikul	?rismikul =rismiku  (SgAd  >rismiku !01_S	et	f	\N
190950	rismikul	?rismikul =rismiku  (SgAd  >rismik !02_S	et	f	\N
190951	rismikul	?rismikul =rismikul  (SgN  >rismikul !19_S	et	f	\N
190968	rasvaseid	rasvaseid =rasvase  (PlP  >rasvane !10_A	et	f	\N
190969	rasvaseid	"rasvane %rasva  )NE_aA  <rasv ;22_S	et	f	\N
191031	metalluks	metalluks =uks  (SgN  >metall+uks !14_S	et	f	\N
191032	metalluks	metalluks =luks  (SgN  >metal+luks !22_S	et	f	\N
191033	metalluks	metalluks =luks  (SgN  >metal+luks !22_SA	et	f	\N
191048	planeeringut	?planeeringut =planeeringu  (SgP  >planeering !02_S	et	f	\N
191061	raskemetall-muusika	raskemetall-muusika =muusika  (SgN  >raskemetall-muusika !01_S	et	f	\N
191062	raskemetall-muusika	raskemetall-muusika =muusika  (SgG  >raskemetall-muusika !01_S	et	f	\N
191071	iludust	iludust =iludus  (SgP  >iludus !11_S	et	f	\N
191072	iludust	iludust =dust  (SgN  >ilu+dust !22_S	et	f	\N
191077	varalapsepõlves	varalapsepõlves =põlve  (SgIn  >vara+lapse+põlv !22_S	et	f	\N
191078	varalapsepõlves	varalapsepõlves =põlve  (SgIn  >vara+lapse+põli !24_S	et	f	\N
191079	varalapsepõlves	varalapsepõlves =põlve  (PlIn  >vara+lapse+põlv !22_S	et	f	\N
191086	arendavat	arendavat =arenda  (KvtPrPs  >arendama !27_V	et	f	\N
191087	arendavat	arendavat =arendava  (SgP  >arendav !02_A	et	f	\N
191088	arendavat	"arendav %arenda  )V_vA  <arendama ;27_V	et	f	\N
191106	sampoone	?sampoone =sampoone  (SgN  >sampoone !12~10_A	et	f	\N
191107	sampoone	?sampoone =sampoone  (PlP  >sampoon !22_S	et	f	\N
191108	sampoone	?sampoone =sampoone  (IndPrPs_  >sampoonema !27_V	et	f	\N
191109	sampoone	?sampoone =sampoone  (ImpPrSg2  >sampoonema !27_V	et	f	\N
191110	sampoone	?sampoone =one  (SgN  >sampo+one !16_S	et	f	\N
190708	liine	liine =liine  (SgN  >liine !10_A	et	f	\N
190709	liine	"liine %lii  )NE_aA  <lii ;26_S	et	f	\N
190710	liine	liine =liine  (PlP  >liin !22_S	et	f	\N
190730	asendanud	asendanud =asenda  (PtsPtPs  >asendama !27_V	et	f	\N
190731	asendanud	asendanud =asendanu  (PlN  >asendanu !01_S	et	f	\N
190732	asendanud	"asendanu %asenda  )NU_vS  <asendama ;27_V	et	f	\N
190733	asendanud	asendanud =asendanud  (ID  >asendanud !41_A	et	f	\N
190734	asendanud	"asendanud %asenda  )NUD_vA  <asendama ;27_V	et	f	\N
190753	trendikas	?trendikas =trendika  (SgIn  >trendika !01_S	et	f	\N
190754	trendikas	?trendikas =trendika  (SgIn  >trendikas !02_S	et	f	\N
190755	trendikas	?trendikas =trendikas  (SgN  >trendikas !02_S	et	f	\N
190765	kultuureid	?kultuureid =kultuurei  (PlN  >kultuurei !26_S	et	f	\N
190766	kultuureid	?kultuureid =kultuurei  (SgP  >kultuurei !26_S	et	f	\N
190767	kultuureid	?kultuureid =eid  (SgN  >kultuur+eid !22_S	et	f	\N
190786	jalgpallimaailmast	jalgpallimaailmast =ast  (SgN  >jalg+palli+maa+ilm+ast !22_S	et	f	\N
190787	jalgpallimaailmast	jalgpallimaailmast =ilma  (SgEl  >jalg+palli+maa+ilm !22_S	et	f	\N
190788	jalgpallimaailmast	jalgpallimaailmast =ilmas  (SgP  >jalg+palli+maa+ilmane !10_A	et	f	\N
190789	jalgpallimaailmast	"jalg+palli+maa+ilmane %ilma  )NE_aA  <jalg+palli+maa+ilm ;22_S	et	f	\N
190802	paberidel	?paberidel =ide  (SgAd  >paber+ide !16_S	et	f	\N
190803	paberidel	?paberidel =idel  (SgN  >paber+idel !02_S	et	f	\N
190812	sony	### sony	et	f	\N
190813	philips	?philips =philips  (SgN  >philips !02_S	et	f	\N
190818	ued	?ued =ue  (PlN  >ue !26_S	et	f	\N
190819	ued	?ued =ue  (SgP  >ue !26_S	et	f	\N
190820	ued	?ued =ued  (SgN  >ued !22_S	et	f	\N
190825	moobiltelefooniga	?moobiltelefooniga =moobiltelefooni  (SgKom  >moobiltelefooni !16_S	et	f	\N
190826	moobiltelefooniga	?moobiltelefooniga =moobiltelefooni  (SgKom  >moobiltelefoon !22_S	et	f	\N
190834	player	?player =player  (SgN  >player !02_S	et	f	\N
190854	leitusid	?leitusid =leitu  (IndIpfSg2  >leituma !27_V	et	f	\N
190855	leitusid	?leitusid =leitu  (IndIpfPl3  >leituma !27_V	et	f	\N
190856	leitusid	?leitusid =usi  (PlN  >leit+usi !17_S	et	f	\N
190862	computrid	?computrid =computri  (PlN  >computri !01_S	et	f	\N
190863	computrid	?computrid =computri  (PlN  >computter !02_S	et	f	\N
190864	computrid	?computrid =computri  (PlN  >computer !19_S	et	f	\N
190866	kasulikkum	?kasulikkum =kasulikkum  (SgN  >kasulikkum !02_S	et	f	\N
190867	kasulikkum	?kasulikkum =ulikkum  (SgN  >kas+ulikkum !19_S	et	f	\N
190868	trollid	trollid =trolli  (PlN  >trolli !16_S	et	f	\N
190869	trollid	trollid =trolli  (PlN  >troll !22_S	et	f	\N
190870	susteemid	?susteemid =susteemi  (PlN  >susteemi !16_S	et	f	\N
190871	susteemid	?susteemid =susteemi  (PlN  >susteem !22_S	et	f	\N
190872	susteemid	?susteemid =susteemi  (IndPrSg2  >susteemima !28_V	et	f	\N
190873	avarii	avarii =avarii  (SgN  >avarii !26_S	et	f	\N
190874	avarii	avarii =avarii  (SgG  >avarii !26_S	et	f	\N
190876	juthub	?juthub =juthu  (IndPrSg3  >juthuma !27_V	et	f	\N
190877	ohutuks	ohutuks =ohutu  (SgTr  >ohutu !01_A	et	f	\N
190878	ohutuks	"ohutu %ohu  )TU2_kA  <oht ;22_S	et	f	\N
190879	ohutuks	ohutuks =tuks  (SgN  >ohu+tuks !22_S	et	f	\N
190880	tanavatel	?tanavatel =tanava  (PlAd  >tanava !01_S	et	f	\N
190881	tanavatel	?tanavatel =tanava  (PlAd  >tanav !02_A	et	f	\N
190882	tanavatel	?tanavatel =tanavate  (PlAd  >tanavatt !22_S	et	f	\N
190919	fonosüsteemiga	?fonosüsteemiga =fonosüsteemi  (SgKom  >fonosüsteemi !16_S	et	f	\N
190920	fonosüsteemiga	?fonosüsteemiga =fonosüsteemi  (SgKom  >fonosüsteem !22_S	et	f	\N
190921	sootuks	sootuks =sootu  (SgTr  >sootu !01_A	et	f	\N
190922	sootuks	"sootu %soo  )TU2_kA  <sugu ;18_S	et	f	\N
190923	sootuks	"sootu %soo  )TU2_kA  <soo ;26_S	et	f	\N
190924	sootuks	sootuks =sootuks  (ID  >sootuks !41_D	et	f	\N
190925	sootuks	sootuks =tuks  (SgN  >soo+tuks !22_S	et	f	\N
190926	natike	natike =natike  (SgN  >natike !12_S	et	f	\N
190927	natike	"natike %nati  )KE_dS  <natt ;22_S	et	f	\N
190939	vw	### vw	et	f	\N
190946	näitsin	?näitsin =näit  (IndIpfSg1  >näitma !34_V	et	f	\N
190947	näitsin	?näitsin =näitsi  (IndPrSg1  >näitsima !28_V	et	f	\N
190948	näitsin	?näitsin =näitsin  (SgN  >näitsin !02_S	et	f	\N
190979	südamehaigus	südamehaigus =haigu  (SgIn  >südame+haik !22_S	et	f	\N
190980	südamehaigus	südamehaigus =haigus  (SgN  >südame+haigus !11~09_S	et	f	\N
190981	südamehaigus	"südame+haigus %haige  )US_aS  <südame+haige ;01_AS	et	f	\N
190987	söögitoru	söögitoru =toru  (SgN  >söögi+toru !17_S	et	f	\N
190988	söögitoru	söögitoru =toru  (SgG  >söögi+toru !17_S	et	f	\N
190989	söögitoru	söögitoru =toru  (SgP  >söögi+toru !17_S	et	f	\N
191002	närvstressi	?närvstressi =närvstressi  (SgN  >närvstressi !01_S	et	f	\N
191003	närvstressi	?närvstressi =närvstressi  (SgG  >närvstressi !01_S	et	f	\N
191004	närvstressi	?närvstressi =närvstressi  (SgG  >närvstress !22_S	et	f	\N
191005	närvstressi	?närvstressi =närvstressi  (SgP  >närvstress !22_S	et	f	\N
191006	närvstressi	?närvstressi =närvstressi  (SgAdt  >närvstress !22_S	et	f	\N
191007	närvstressi	?närvstressi =närvstressi  (IndPrPs_  >närvstressima !28_V	et	f	\N
191008	närvstressi	?närvstressi =närvstressi  (ImpPrSg2  >närvstressima !28_V	et	f	\N
190717	pera	?pera =pera  (ImpPrSg2  >perama !27_V	et	f	\N
190720	ökoloogia	ökoloogia =ökoloogia  (SgN  >ökoloogia !01_S	et	f	\N
190721	ökoloogia	ökoloogia =ökoloogia  (SgG  >ökoloogia !01_S	et	f	\N
190728	orienteerumisega	orienteerumisega =orienteerumise  (SgKom  >orienteerumine !12_S	et	f	\N
190729	orienteerumisega	"orienteerumine %orienteeru  )MINE_vS  <orienteeruma ;27_V	et	f	\N
190735	effektiivseid	?effektiivseid =effektiivse  (PlP  >effektiivne !02_A	et	f	\N
190736	effektiivseid	?effektiivseid =effektiivsei  (PlN  >effektiivsei !26_S	et	f	\N
190737	effektiivseid	?effektiivseid =effektiivsei  (SgP  >effektiivsei !26_S	et	f	\N
190747	funktionaalsus	?funktionaalsus =funktionaalsu  (IndIpfSg3  >funktionaalsuma !27_V	et	f	\N
190748	funktionaalsus	?funktionaalsus =funktionaalsus  (SgN  >funktionaalsus !11~09_S	et	f	\N
190752	smsi	### smsi	et	f	\N
190756	tartumaal	tartumaal =maa  (SgAd  >tartu+maa !26_S	et	f	\N
190757	tartumaal	tartumaal =maal  (SgN  >tartu+maal !22_S	et	f	\N
190792	riigidesse	?riigidesse =riigi  (PlIll  >riigi !16_S	et	f	\N
190793	riigidesse	?riigidesse =riigi  (PlIll  >riig !22_S	et	f	\N
190794	riigidesse	?riigidesse =riigides  (SgAdt  >riigidene !12_A	et	f	\N
190795	riigidesse	?riigidesse =riigidesse  (SgG  >riigidesne !02_A	et	f	\N
190796	riigidesse	?riigidesse =riigidesse  (PlP  >riigidess !22_S	et	f	\N
190816	televisorida	### televisorida	et	f	\N
190822	e-mailid	?e-mailid =maili  (PlN  >e-maili !16_S	et	f	\N
190823	e-mailid	?e-mailid =maili  (PlN  >e-mail !22_S	et	f	\N
190824	e-mailid	?e-mailid =maili  (IndPrSg2  >e-mailima !28_V	et	f	\N
190831	magnetoola	magnetoola =magnetoola  (SgN  >magnetoola !16_S	et	f	\N
190832	magnetoola	magnetoola =magnetoola  (SgG  >magnetoola !16_S	et	f	\N
190875	mittevajalikkuks	?mittevajalikkuks =mittevajalikku  (KndPrPs  >mittevajalikkuma !27_V	et	f	\N
190890	piisut	?piisut =piisu  (SgP  >piisu !16_S	et	f	\N
190891	piisut	?piisut =piisut  (SgN  >piisut !02_S	et	f	\N
190892	üheksakorruselis	?üheksakorruselis =üheksakorruselis  (SgN  >üheksakorruselis !09_S	et	f	\N
190893	üheksakorruselis	?üheksakorruselis =korruseli  (SgIn  >üheksa+korrusel !19_S	et	f	\N
190894	üheksakorruselis	?üheksakorruselis =korruselis  (SgN  >üheksa+korruselis !09_S	et	f	\N
190895	üheksakorruselis	?üheksakorruselis =akorruselis  (SgN  >üheks+akorruselis !09_S	et	f	\N
190896	üheksakorruselis	?üheksakorruselis =ksakorruselis  (SgN  >ühe+ksakorruselis !09_S	et	f	\N
190902	iste	iste =iste  (SgN  >iste !05_S	et	f	\N
190903	iste	iste =iste  (SgN  >iste !06_S	et	f	\N
190904	iste	iste =iste  (SgG  >iste !06_S	et	f	\N
190905	iste	iste =iste  (PlP  >ist !22_S	et	f	\N
190906	tõusata	?tõusata =tõusa  (SgAb  >tõusa !16_S	et	f	\N
190907	tõusata	?tõusata =tõusa  (Inf  >tõusama !29_V	et	f	\N
190908	tõusata	?tõusata =tõusa  (IndPrIps_  >tõusama !29_V	et	f	\N
190909	tõusata	?tõusata =tõusata  (IndPrPs_  >tõusatama !27_V	et	f	\N
190911	tõusata	?tõusata =tõusata  (ImpPrSg2  >tõusatama !27_V	et	f	\N
190913	tõusata	?tõusata =sata  (SgN  >tõu+sata !16_S	et	f	\N
190915	tõusata	?tõusata =sata  (SgG  >tõu+sata !16_S	et	f	\N
190929	validatuleb	### validatuleb	et	f	\N
190930	autotbr	?autotbr =autotbr  (SgN  >autotbr !22_S	et	f	\N
190931	autotbr	?autotbr =totbr  (SgN  >au+totbr !22_S	et	f	\N
190933	dodge	?dodge =dodge  (SgN  >dodge !06_S	et	f	\N
190934	dodge	?dodge =dodge  (SgG  >dodge !06_S	et	f	\N
190935	dodge	?dodge =dodge  (PlP  >dodg !22_S	et	f	\N
190936	dodge	?dodge =dodge  (IndPrPs_  >dodgema !27_V	et	f	\N
190937	dodge	?dodge =dodge  (ImpPrSg2  >dodgema !27_V	et	f	\N
190938	kabr	?kabr =kabr  (SgN  >kabr !22_S	et	f	\N
190945	kõvased	?kõvased =kõvase  (PlN  >kõvane !10_A	et	f	\N
190953	jalgrattult	?jalgrattult =jalgrattu  (SgAbl  >jalgrattu !01_S	et	f	\N
190954	jalgrattult	?jalgrattult =jalgrattult  (ID  >jalgrattult !41_D	et	f	\N
190955	paremalt	paremalt =parema  (SgAbl  >parem !02_A	et	f	\N
190956	paremalt	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
190957	paremalt	paremalt =paremalt  (ID  >paremalt !41_D	et	f	\N
190958	paremalt	"paremalt %parema  )LT_mD  <parem ;02_A	et	f	\N
190959	paremalt	paremalt =alt  (SgN  >parem+alt !22_S	et	f	\N
190963	pärilikkusest	pärilikkusest =pärilikkuse  (SgEl  >pärilikkus !11~09_S	et	f	\N
190964	pärilikkusest	"pärilikkus %pärilikku  )US_aS  <pärilik ;25_A	et	f	\N
190965	pärilikkusest	pärilikkusest =pärilikkuses  (SgP  >pärilikkusene !12_A	et	f	\N
190966	pärilikkusest	"pärilikkusene %pärilikkuse  )NE_aA  <pärilikkus ;09_S	et	f	\N
190967	pärilikkusest	"pärilikkusene %pärilikkuse  )NE_aA  <pärilikkus ;11_S	et	f	\N
190970	vägijoogid	vägijoogid =joogi  (PlN  >vägi+joogi !16_S	et	f	\N
190971	vägijoogid	vägijoogid =joogi  (PlN  >vägi+jook !22_S	et	f	\N
190990	närvstressid	?närvstressid =närvstressi  (PlN  >närvstressi !01_S	et	f	\N
190991	närvstressid	?närvstressid =närvstressi  (PlN  >närvstress !22_S	et	f	\N
190992	närvstressid	?närvstressid =närvstressi  (IndPrSg2  >närvstressima !28_V	et	f	\N
191009	narkotikut	?narkotikut =narkotiku  (SgP  >narkotik !02_S	et	f	\N
191010	narkotikut	?narkotikut =tiku  (SgP  >narko+tiku !16_S	et	f	\N
191011	narkotikut	?narkotikut =tikut  (SgN  >narko+tikut !02_S	et	f	\N
191037	ruutmetrit	?ruutmetrit =ruutmetri  (SgP  >ruutmetri !01_S	et	f	\N
190799	riigiasutust	"riigi+asutu %asu  )TU2_kA  <riigi+asu ;17_S	et	f	\N
190800	riigiasutust	riigiasutust =asutus  (SgP  >riigi+asutus !11_S	et	f	\N
190801	riigiasutust	"riigi+asutus %asu  )TUS2_aS  <riigi+asu ;17_S	et	f	\N
190809	informatsionit	?informatsionit =informatsioni  (SgP  >informatsion !02_S	et	f	\N
190810	informatsionit	?informatsionit =informatsioni  (SgP  >informatsioni !16_S	et	f	\N
190814	hojan	?hojan =hoja  (IndPrSg1  >hojama !27_V	et	f	\N
190815	hojan	?hojan =hojan  (SgN  >hojan !02_S	et	f	\N
190827	rööster	?rööster =rööster  (SgN  >rööster !02_S	et	f	\N
190835	leiutus	leiutus =leiutu  (SgIn  >leiutu !01_AS	et	f	\N
190836	leiutus	"leiutu %leiu  )TU2_kA  <leid ;22_S	et	f	\N
190837	leiutus	leiutus =leiutus  (SgN  >leiutus !11_S	et	f	\N
190838	leiutus	"leiutus %leiuta  )US_vS  <leiutama ;27_V	et	f	\N
190839	leiutus	"leiutus %leiu  )TUS2_aS  <leid ;22_S	et	f	\N
190840	automaatiline	?automaatiline =automaatiline  (SgN  >automaatiline !12_A	et	f	\N
190841	automaatiline	?automaatiline =automaatiline  (PlP  >automaatilin !19_S	et	f	\N
190842	automaatiline	?automaatiline =iline  (SgN  >automaat+iline !10_A	et	f	\N
190843	automaatiline	?automaatiline =tiline  (SgN  >auto+maa+tiline !10_A	et	f	\N
190844	automaatiline	?automaatiline =maatiline  (SgN  >auto+maatiline !12_A	et	f	\N
190845	automaatiline	?automaatiline =maatiline  (PlP  >auto+maatilin !19_S	et	f	\N
190846	automaatiline	?automaatiline =tomaatiline  (SgN  >au+tomaatiline !12_A	et	f	\N
190847	automaatiline	?automaatiline =tomaatiline  (PlP  >au+tomaatilin !19_S	et	f	\N
190850	mugadest	?mugadest =muga  (PlEl  >muga !17_S	et	f	\N
190851	mugadest	?mugadest =mugades  (SgP  >mugadene !12_A	et	f	\N
190852	toide	toide =toi  (PlG  >toi !26_S	et	f	\N
190853	toide	toide =toide  (SgN  >toide !06_S	et	f	\N
190857	mobiili	mobiili =mobiili  (SgG  >mobiil !22_S	et	f	\N
190858	mobiili	mobiili =mobiili  (SgP  >mobiil !22_S	et	f	\N
190859	mobiili	mobiili =mobiili  (SgAdt  >mobiil !22_S	et	f	\N
190883	televisioonita	televisioonita =televisiooni  (SgAb  >televisioon !22_S	et	f	\N
190884	televisioonita	televisioonita =visiooni  (SgAb  >tele+visioon !22_S	et	f	\N
190885	kasulikumaist	kasulikumaist =kasulikuma  (PlEl  >kasulikum !02_A	et	f	\N
190886	kasulikumaist	"kasulikum %kasuliku  )M_cA  <kasulik ;25_A	et	f	\N
190887	palju-palju	palju-palju =palju  (ID  >palju-palju !41_D	et	f	\N
190888	palju-palju	palju-palju =palju  (SgN  >palju-palju !16_P	et	f	\N
190889	palju-palju	palju-palju =palju  (SgG  >palju-palju !16_P	et	f	\N
190897	rajooni	rajooni =rajooni  (SgG  >rajoon !22_S	et	f	\N
190898	rajooni	rajooni =rajooni  (SgP  >rajoon !22_S	et	f	\N
190899	rajooni	rajooni =rajooni  (SgAdt  >rajoon !22_S	et	f	\N
190900	rajooni	rajooni =rajooni  (IndPrPs_  >rajoonima !28_V	et	f	\N
190901	rajooni	rajooni =rajooni  (ImpPrSg2  >rajoonima !28_V	et	f	\N
190910	jälgsi	?jälgsi =jälgsi  (ID  >jälgsi !41_D	et	f	\N
190912	jälgsi	?jälgsi =jälgsi  (SgG  >jälgs !22_S	et	f	\N
190914	jälgsi	?jälgsi =jälgsi  (SgP  >jälgs !22_S	et	f	\N
190916	jälgsi	?jälgsi =jälgsi  (SgAdt  >jälgs !22_S	et	f	\N
190917	jälgsi	?jälgsi =jälgsi  (IndPrPs_  >jälgsima !28_V	et	f	\N
190918	jälgsi	?jälgsi =jälgsi  (ImpPrSg2  >jälgsima !28_V	et	f	\N
190932	viper	?viper =viper  (SgN  >viper !02_S	et	f	\N
190940	autoteenindusekeskuses	?autoteenindusekeskuses =autoteenindusekeskuse  (SgIn  >autoteenindusekeskus !11~09_S	et	f	\N
190941	autoteenindusekeskuses	?autoteenindusekeskuses =ekeskuse  (SgIn  >auto+teenindus+ekeskus !11_S	et	f	\N
190942	autoteenindusekeskuses	?autoteenindusekeskuses =nindusekeskuse  (SgIn  >auto+tee+nindusekeskus !11~09_S	et	f	\N
190943	autoteenindusekeskuses	?autoteenindusekeskuses =teenindusekeskuse  (SgIn  >auto+teenindusekeskus !11~09_S	et	f	\N
190944	autoteenindusekeskuses	?autoteenindusekeskuses =toteenindusekeskuse  (SgIn  >au+toteenindusekeskus !11~09_S	et	f	\N
190952	jalgratturilte	### jalgratturilte	et	f	\N
190972	korratult	korratult =korratu  (SgAbl  >korratu !01_AS	et	f	\N
190973	korratult	"korratu %korra  )TU1_vS  <kordama ;29_V	et	f	\N
190974	korratult	"korratu %korra  )TU2_kA  <kord ;22_S	et	f	\N
190975	korratult	korratult =korratult  (ID  >korratult !41_D	et	f	\N
190976	korratult	"korratult %korra  )TULT1_mD  <kordama ;29_V	et	f	\N
190977	korratult	"korratult %korra  )TULT2_mD  <kord ;22_S	et	f	\N
190978	korratult	"korratult %korratu  )LT_mD  <korratu ;01_AS	et	f	\N
190982	kõrge-	kõrge- =kõrge  (SgN  >kõrge !01_A	et	f	\N
190983	kõrge-	kõrge- =kõrge  (SgN  >kõrge !05_S	et	f	\N
190984	kõrge-	kõrge- =kõrge  (SgG  >kõrge !01_A	et	f	\N
191016	ehitu	ehitu =ehitu  (SgN  >ehitu !01_AS	et	f	\N
191017	ehitu	"ehitu %ehi  )TU1_vS  <ehtima ;28_V	et	f	\N
191018	ehitu	ehitu =ehitu  (SgG  >ehitu !01_AS	et	f	\N
191019	ehitu	ehitu =ehitu  (IndPrPs_  >ehituma !27_V	et	f	\N
191020	ehitu	ehitu =ehitu  (ImpPrSg2  >ehituma !27_V	et	f	\N
191030	tpetikoda	### tpetikoda	et	f	\N
191034	plastmassraamiga	plastmassraamiga =iga  (SgN  >plast+mass+raam+iga !18_S	et	f	\N
191035	plastmassraamiga	plastmassraamiga =iga  (SgP  >plast+mass+raam+iga !18_S	et	f	\N
191036	plastmassraamiga	plastmassraamiga =raami  (SgKom  >plast+mass+raam !22_S	et	f	\N
191041	parkett	parkett =parkett  (SgN  >parkett !22_S	et	f	\N
191042	parkett	parkett =e  (SgP  >park+esi !15_S	et	f	\N
191012	piirkonnasse	piirkonnasse =piirkonna  (SgIll  >piirkond !22_S	et	f	\N
191013	piirkonnasse	piirkonnasse =piirkonnas  (SgAdt  >piirkonnane !12_A	et	f	\N
191014	piirkonnasse	"piirkonnane %piirkonna  )NE_aA  <piirkond ;22_S	et	f	\N
191015	piirkonnasse	piirkonnasse =konna  (SgIll  >piir+konn !22_S	et	f	\N
191021	korruseline	korruseline =korruseline  (SgN  >korruseline !12_A	et	f	\N
191022	korruseline	"korruseline %korruse  )LINE_aA  <korrus ;09_S	et	f	\N
191050	ümbrises	ümbrises =ümbrise  (SgIn  >ümbris !09_S	et	f	\N
191051	ümbrises	ümbrises =ümbrise  (SgIn  >ümbrine !12~10_A	et	f	\N
191052	priisle	?priisle =priisle  (SgN  >priisle !06_S	et	f	\N
191053	priisle	?priisle =priisle  (SgG  >priisle !06_S	et	f	\N
191054	priisle	?priisle =priisle  (IndPrPs_  >priislema !30_V	et	f	\N
191055	priisle	?priisle =priisle  (ImpPrSg2  >priislema !30_V	et	f	\N
191065	kurju	kurju =kurju  (IndPrPs_  >kurjuma !27_V	et	f	\N
191066	kurju	kurju =kurju  (ImpPrSg2  >kurjuma !27_V	et	f	\N
191083	murduvad	murduvad =murdu  (IndPrPl3  >murduma !27_V	et	f	\N
191084	murduvad	murduvad =murduva  (PlN  >murduv !02_A	et	f	\N
191085	murduvad	"murduv %murdu  )V_vA  <murduma ;27_V	et	f	\N
191089	turvalisemaks	turvalisemaks =turvalisema  (SgTr  >turvalisem !02_A	et	f	\N
191090	turvalisemaks	"turvalisem %turva  )LISEM_cA  <turb ;22_SA	et	f	\N
191091	turvalisemaks	"turvalisem %turva  )LISEM_cA  <turv ;22_S	et	f	\N
191092	turvalisemaks	"turvalisem %turvalise  )M_cA  <turvaline ;12_A	et	f	\N
191093	keemiatoodeteid	?keemiatoodeteid =keemiatoodetei  (PlN  >keemiatoodetei !26_S	et	f	\N
191094	keemiatoodeteid	?keemiatoodeteid =keemiatoodetei  (SgP  >keemiatoodetei !26_S	et	f	\N
191095	keemiatoodeteid	?keemiatoodeteid =detei  (PlN  >keemia+too+detei !26_S	et	f	\N
191096	keemiatoodeteid	?keemiatoodeteid =detei  (SgP  >keemia+too+detei !26_S	et	f	\N
191097	keemiatoodeteid	?keemiatoodeteid =deteid  (SgN  >keemia+too+deteid !22_S	et	f	\N
191098	keemiatoodeteid	?keemiatoodeteid =toodetei  (PlN  >keemia+toodetei !26_S	et	f	\N
191099	keemiatoodeteid	?keemiatoodeteid =toodetei  (SgP  >keemia+toodetei !26_S	et	f	\N
191100	sampoonid	?sampoonid =sampooni  (PlN  >sampooni !16_S	et	f	\N
191101	sampoonid	?sampoonid =sampooni  (PlN  >sampoon !22_S	et	f	\N
191102	sampoonid	?sampoonid =sampooni  (IndPrSg2  >sampoonima !28_V	et	f	\N
191103	sampoonid	?sampoonid =oni  (PlN  >sampo+oni !17_S	et	f	\N
191112	tugevdavad	tugevdavad =tugevda  (IndPrPl3  >tugevdama !27_V	et	f	\N
191113	tugevdavad	tugevdavad =tugevdava  (PlN  >tugevdav !02_A	et	f	\N
191114	tugevdavad	"tugevdav %tugevda  )V_vA  <tugevdama ;27_V	et	f	\N
191121	küürimispastateid	?küürimispastateid =küürimispastatei  (PlN  >küürimispastatei !26_S	et	f	\N
191122	küürimispastateid	?küürimispastateid =küürimispastatei  (SgP  >küürimispastatei !26_S	et	f	\N
191123	küürimispasta	?küürimispasta =küürimispasta  (SgN  >küürimispasta !16_S	et	f	\N
191124	küürimispasta	?küürimispasta =küürimispasta  (SgG  >küürimispasta !16_S	et	f	\N
191125	küürimispasta	?küürimispasta =küürimispasta  (IndPrPs_  >küürimispastama !27_V	et	f	\N
191126	küürimispasta	?küürimispasta =küürimispasta  (ImpPrSg2  >küürimispastama !27_V	et	f	\N
191151	suttumise	?suttumise =suttumise  (SgG  >suttumine !12_S	et	f	\N
191152	rohke	rohke =rohke  (SgN  >rohke !01_A	et	f	\N
191153	rohke	rohke =rohke  (SgG  >rohke !01_A	et	f	\N
191182	neise	?neise =neise  (SgN  >neise !06_S	et	f	\N
191183	neise	?neise =neise  (SgG  >neise !06_S	et	f	\N
191184	neise	?neise =neise  (PlP  >neis !22_S	et	f	\N
191185	neise	?neise =neise  (IndPrPs_  >neisema !28_V	et	f	\N
191186	neise	?neise =neise  (ImpPrSg2  >neisema !28_V	et	f	\N
191198	harrastused	harrastused =harrastuse  (PlN  >harrastus !11_S	et	f	\N
191199	harrastused	"harrastus %harrasta  )US_vS  <harrastama ;27_V	et	f	\N
191208	tuleta	tuleta =tule  (SgAb  >tuli !20_S	et	f	\N
191210	tuleta	tuleta =tuleta  (IndPrPs_  >tuletama !27_V	et	f	\N
191212	tuleta	tuleta =tuleta  (ImpPrSg2  >tuletama !27_V	et	f	\N
191220	ületeha	?ületeha =ületeha  (SgN  >ületeha !16_S	et	f	\N
191221	ületeha	?ületeha =ületeha  (SgG  >ületeha !16_S	et	f	\N
191222	ületeha	?ületeha =teha  (SgN  >üle+teha !17_S	et	f	\N
191223	ületeha	?ületeha =teha  (SgG  >üle+teha !17_S	et	f	\N
191224	ületeha	?ületeha =teha  (SgP  >üle+teha !17_S	et	f	\N
191228	vaheta	vaheta =vahe  (SgAb  >vahe !16_S	et	f	\N
191229	vaheta	vaheta =vaheta  (IndPrPs_  >vahetama !27_V	et	f	\N
191230	vaheta	vaheta =vaheta  (ImpPrSg2  >vahetama !27_V	et	f	\N
191235	rahvusevähemus	?rahvusevähemus =rahvusevähemu  (IndIpfSg3  >rahvusevähemuma !27_V	et	f	\N
191236	rahvusevähemus	?rahvusevähemus =rahvusevähemus  (SgN  >rahvusevähemus !11?09_S	et	f	\N
191237	rahvusevähemus	?rahvusevähemus =evähemus  (SgN  >rahvus+evähemus !11?09_S	et	f	\N
191238	rahvusevähemus	?rahvusevähemus =sevähemus  (SgN  >rahvu+sevähemus !11?09_S	et	f	\N
191260	esienesse	?esienesse =esiene  (SgIll  >esiene !16_S	et	f	\N
191261	esienesse	?esienesse =esiene  (PlIll  >esien !19_S	et	f	\N
191262	esienesse	?esienesse =esienes  (SgAdt  >esienene !12_A	et	f	\N
191263	esienesse	?esienesse =esienesse  (SgG  >esienesne !02_A	et	f	\N
191264	esienesse	?esienesse =esienesse  (PlP  >esieness !22_S	et	f	\N
191265	esienesse	?esienesse =ene  (SgIll  >esi+ene !16_S	et	f	\N
191266	esienesse	?esienesse =enesse  (SgG  >esi+enesne !02_A	et	f	\N
191023	tehati	?tehati =teha  (IndIpfIps  >tehama !27_V	et	f	\N
191024	tehati	?tehati =teha  (IndIpfIps  >tehtama !29_V	et	f	\N
191025	tehati	?tehati =tehati  (ID  >tehati !41_D	et	f	\N
191026	tehati	?tehati =tehati  (SgG  >tehat !02_S	et	f	\N
191027	tehati	?tehati =tehati  (SgG  >tehatt !22_S	et	f	\N
191028	tehati	?tehati =tehati  (IndPrPs_  >tehattima !28_V	et	f	\N
191029	tehati	?tehati =tehati  (ImpPrSg2  >tehattima !28_V	et	f	\N
191049	kandevsein	?kandevsein =kandevsein  (SgN  >kandevsein !19_S	et	f	\N
191060	rock-	?rock- =rock  (SgN  >rock !22_S	et	f	\N
191063	eluseadus	eluseadus =seadu  (SgIn  >elu+sead !22_S	et	f	\N
191064	eluseadus	eluseadus =seadus  (SgN  >elu+seadus !11~09_S	et	f	\N
191067	headust	headust =headus  (SgP  >headus !11~09_S	et	f	\N
191068	headust	"headus %hea  )US_aS  <hea ;26_A	et	f	\N
191069	headust	headust =us  (SgP  >head+uks !14_S	et	f	\N
191070	headust	headust =dust  (SgN  >hea+dust !22_S	et	f	\N
191104	küürimispastad	?küürimispastad =küürimispasta  (PlN  >küürimispasta !16_S	et	f	\N
191105	küürimispastad	?küürimispastad =küürimispasta  (IndPrSg2  >küürimispastama !27_V	et	f	\N
191115	nõudepesevahendeid	?nõudepesevahendeid =nõudepesevahendei  (PlN  >nõudepesevahendei !26_S	et	f	\N
191116	nõudepesevahendeid	?nõudepesevahendeid =nõudepesevahendei  (SgP  >nõudepesevahendei !26_S	et	f	\N
191117	nõudepesevahendeid	?nõudepesevahendeid =pesevahendei  (PlN  >nõude+pesevahendei !26_S	et	f	\N
191118	nõudepesevahendeid	?nõudepesevahendeid =pesevahendei  (SgP  >nõude+pesevahendei !26_S	et	f	\N
191119	nõudepesevahendeid	?nõudepesevahendeid =depesevahendei  (PlN  >nõu+depesevahendei !26_S	et	f	\N
191120	nõudepesevahendeid	?nõudepesevahendeid =depesevahendei  (SgP  >nõu+depesevahendei !26_S	et	f	\N
191129	allergia	allergia =allergia  (SgN  >allergia !01_S	et	f	\N
191130	allergia	allergia =allergia  (SgG  >allergia !01_S	et	f	\N
191134	allergoologid	### allergoologid	et	f	\N
191147	tihtihoida	?tihtihoida =hoida  (SgN  >tihti+hoida !16_S	et	f	\N
191148	tihtihoida	?tihtihoida =hoida  (SgG  >tihti+hoida !16_S	et	f	\N
191164	külli	külli =külli  (SgG  >küll !22_S	et	f	\N
191165	külli	külli =külli  (SgP  >küll !22_S	et	f	\N
191166	külli	külli =külli  (SgAdt  >küll !22_S	et	f	\N
191167	külli	külli =külli  (PlP  >küll !22_S	et	f	\N
191172	muutasin	?muutasin =muuta  (IndIpfSg1  >muutama !27_V	et	f	\N
191173	muutasin	?muutasin =muutasin  (SgN  >muutasin !19_S	et	f	\N
191174	muutasin	?muutasin =tasin  (SgN  >muu+tasin !02_S	et	f	\N
191187	vastutusrikas	?vastutusrikas =vastutusrika  (SgIn  >vastutusrika !01_S	et	f	\N
191188	vastutusrikas	?vastutusrikas =vastutusrika  (SgIn  >vastutusrikas !02_A	et	f	\N
191189	vastutusrikas	?vastutusrikas =vastutusrikas  (SgN  >vastutusrikas !02_A	et	f	\N
191190	vastutusrikas	?vastutusrikas =rika  (SgIn  >vastutus+rika !16_S	et	f	\N
191191	vastutusrikas	?vastutusrikas =rikas  (SgN  >vastutus+rikas !07_A	et	f	\N
191192	vastutusrikas	?vastutusrikas =tusrika  (SgIn  >vastu+tusrika !01_S	et	f	\N
191193	vastutusrikas	?vastutusrikas =tusrika  (SgIn  >vastu+tusrikas !02_S	et	f	\N
191194	vastutusrikas	?vastutusrikas =tusrikas  (SgN  >vastu+tusrikas !02_S	et	f	\N
191195	vastutusrikas	?vastutusrikas =utusrika  (SgIn  >vast+utusrika !01_S	et	f	\N
191196	vastutusrikas	?vastutusrikas =utusrika  (SgIn  >vast+utusrikas !02_A	et	f	\N
191197	vastutusrikas	?vastutusrikas =utusrikas  (SgN  >vast+utusrikas !02_A	et	f	\N
191203	õhuta	õhuta =õhu  (SgAb  >õhk !22_S	et	f	\N
191204	õhuta	õhuta =õhuta  (IndPrPs_  >õhutama !27_V	et	f	\N
191205	õhuta	õhuta =õhuta  (ImpPrSg2  >õhutama !27_V	et	f	\N
191239	koostuvad	koostuvad =koostu  (IndPrPl3  >koostuma !27_V	et	f	\N
191240	koostuvad	koostuvad =koostuva  (PlN  >koostuv !02_A	et	f	\N
191241	koostuvad	"koostuv %koostu  )V_vA  <koostuma ;27_V	et	f	\N
191257	teekida	teekida =kida  (SgN  >tee+kida !17_S	et	f	\N
191258	teekida	teekida =kida  (SgG  >tee+kida !17_S	et	f	\N
191259	teekida	teekida =kida  (SgP  >tee+kida !17_S	et	f	\N
191268	õppisekeel	?õppisekeel =õppisekee  (SgAd  >õppisekee !26_S	et	f	\N
191269	õppisekeel	?õppisekeel =õppisekeel  (SgN  >õppisekeel !22_S	et	f	\N
191290	selgitanud	selgitanud =selgita  (PtsPtPs  >selgitama !27_V	et	f	\N
191291	selgitanud	selgitanud =selgitanu  (PlN  >selgitanu !01_S	et	f	\N
191292	selgitanud	"selgitanu %selgita  )NU_vS  <selgitama ;27_V	et	f	\N
191293	selgitanud	selgitanud =selgitanud  (ID  >selgitanud !41_A	et	f	\N
191294	selgitanud	"selgitanud %selgita  )NUD_vA  <selgitama ;27_V	et	f	\N
191295	demonstratsiooniga	demonstratsiooniga =demonstratsiooni  (SgKom  >demonstratsioon !22_S	et	f	\N
191296	demonstratsiooniga	demonstratsiooniga =iga  (SgN  >demonstratsioon+iga !18_S	et	f	\N
191297	demonstratsiooniga	demonstratsiooniga =iga  (SgP  >demonstratsioon+iga !18_S	et	f	\N
191298	ettevalmistada	?ettevalmistada =ettevalmista  (Inf  >ettevalmistama !27_V	et	f	\N
191299	ettevalmistada	?ettevalmistada =tada  (SgN  >ette+valmis+tada !17_S	et	f	\N
191300	ettevalmistada	?ettevalmistada =tada  (SgG  >ette+valmis+tada !17_S	et	f	\N
191301	ettevalmistada	?ettevalmistada =tada  (SgP  >ette+valmis+tada !17_S	et	f	\N
191302	kiirustamine	kiirustamine =kiirustamine  (SgN  >kiirustamine !12_S	et	f	\N
191303	kiirustamine	"kiirustamine %kiirusta  )MINE_vS  <kiirustama ;27_V	et	f	\N
191306	õpetust	õpetust =õpetus  (SgP  >õpetus !11_S	et	f	\N
191038	ruutmetrit	?ruutmetrit =ruutmetri  (SgP  >ruutmetter !02_S	et	f	\N
191039	ruutmetrit	?ruutmetrit =metri  (SgP  >ruut+metter !02_S	et	f	\N
191040	ruutmetrit	?ruutmetrit =metrit  (SgN  >ruut+metrit !02_S	et	f	\N
191043	tapetseeritud	tapetseeritud =tapetseeri  (PtsPtIps  >tapetseerima !28_V	et	f	\N
191044	tapetseeritud	tapetseeritud =tapetseeritu  (PlN  >tapetseeritu !01_S	et	f	\N
191045	tapetseeritud	"tapetseeritu %tapetseeri  )TU1_vS  <tapetseerima ;28_V	et	f	\N
191046	tapetseeritud	tapetseeritud =tapetseeritud  (ID  >tapetseeritud !41_A	et	f	\N
191047	tapetseeritud	"tapetseeritud %tapetseeri  )TUD_vA  <tapetseerima ;28_V	et	f	\N
191073	õpitada	?õpitada =õpita  (Inf  >õpitama !27_V	et	f	\N
191074	õpitada	?õpitada =tada  (SgN  >õpi+tada !17_S	et	f	\N
191075	õpitada	?õpitada =tada  (SgG  >õpi+tada !17_S	et	f	\N
191076	õpitada	?õpitada =tada  (SgP  >õpi+tada !17_S	et	f	\N
191080	nõrgalt	nõrgalt =nõrga  (SgAbl  >nõrk !22_A	et	f	\N
191081	nõrgalt	nõrgalt =nõrgalt  (ID  >nõrgalt !41_D	et	f	\N
191082	nõrgalt	"nõrgalt %nõrga  )LT_mD  <nõrk ;22_A	et	f	\N
191135	arvestavad	arvestavad =arvesta  (IndPrPl3  >arvestama !27_V	et	f	\N
191136	arvestavad	arvestavad =arvestava  (PlN  >arvestav !02_A	et	f	\N
191137	arvestavad	"arvestav %arvesta  )V_vA  <arvestama ;27_V	et	f	\N
191138	inimistel	inimistel =iste  (SgAd  >inim+iste !06_S	et	f	\N
191139	inimistel	inimistel =iste  (PlAd  >inim+ist !22_S	et	f	\N
191140	allergoologile	### allergoologile	et	f	\N
191149	siilma	?siilma =siilma  (IndPrPs_  >siilmama !29_V	et	f	\N
191150	siilma	?siilma =siilma  (ImpPrSg2  >siilmama !29_V	et	f	\N
191157	prügikasti	prügikasti =kasti  (SgG  >prügi+kast !22_S	et	f	\N
191158	prügikasti	prügikasti =kasti  (SgP  >prügi+kast !22_S	et	f	\N
191159	prügikasti	prügikasti =kasti  (SgAdt  >prügi+kast !22_S	et	f	\N
191180	elumärki	elumärki =märki  (SgP  >elu+märk !22_S	et	f	\N
191181	elumärki	elumärki =märki  (SgAdt  >elu+märk !22_S	et	f	\N
191244	solvunud	solvunud =solvu  (PtsPtPs  >solvuma !27_V	et	f	\N
191245	solvunud	solvunud =solvunu  (PlN  >solvunu !01_S	et	f	\N
191246	solvunud	"solvunu %solvu  )NU_vS  <solvuma ;27_V	et	f	\N
191247	solvunud	solvunud =solvunud  (ID  >solvunud !41_A	et	f	\N
191248	solvunud	"solvunud %solvu  )NUD_vA  <solvuma ;27_V	et	f	\N
191286	jõuta	jõuta =jõu  (SgAb  >jõud !22_S	et	f	\N
191287	jõuta	jõuta =jõu  (IndPrIps_  >jõudma !34_V	et	f	\N
191288	jõuta	jõuta =jõuta  (IndPrPs_  >jõutama !27_V	et	f	\N
191289	jõuta	jõuta =jõuta  (ImpPrSg2  >jõutama !27_V	et	f	\N
191309	kergemalt	kergemalt =kergema  (SgAbl  >kergem !02_A	et	f	\N
191310	kergemalt	"kergem %kerge  )M_cA  <kerge ;01_A	et	f	\N
191311	kergemalt	kergemalt =kergemalt  (ID  >kergemalt !41_D	et	f	\N
191312	kergemalt	"kergemalt %kerge  )MALT_mD  <kerge ;01_A	et	f	\N
191313	kergemalt	kergemalt =ema  (SgAbl  >kerg+ema !17_S	et	f	\N
191326	ollema	?ollema =olle  (Sup  >ollema !30_V	et	f	\N
191327	ollema	?ollema =ollema  (SgG  >ollem !02_A	et	f	\N
191338	võrras	?võrras =võrra  (IndIpfSg3  >võrrama !29_V	et	f	\N
191339	võrras	?võrras =võrras  (SgN  >võrras !07_S	et	f	\N
191384	teisestest	teisestest =teises  (PlEl  >teisene !10_A	et	f	\N
191385	teisestest	"teisene %teise  )NE_aA  <teine ;12_NP	et	f	\N
191390	harridust	?harridust =harridu  (SgEl  >harridu !01_S	et	f	\N
191391	harridust	?harridust =harridus  (SgP  >harridus !11_S	et	f	\N
191395	minused	?minused =minuse  (PlN  >minus !09_S	et	f	\N
191441	inimesedele	### inimesedele	et	f	\N
191442	jätkusis	?jätkusis =jätkusi  (PlIn  >jätkus !11_S	et	f	\N
191443	jätkusis	?jätkusis =jätkusis  (SgN  >jätkusis !11_S	et	f	\N
191444	pühtitsasse	?pühtitsasse =pühtitsa  (SgIll  >pühtitsa !01_S	et	f	\N
191445	pühtitsasse	?pühtitsasse =pühtitsas  (SgAdt  >pühtitsane !12_A	et	f	\N
191446	pühtitsasse	?pühtitsasse =pühtitsasse  (SgG  >pühtitsasne !02_A	et	f	\N
191447	pühtitsasse	?pühtitsasse =pühtitsasse  (PlP  >pühtitsass !22_S	et	f	\N
191450	tahaksi	?tahaksi =tahaksi  (SgN  >tahaksi !01_S	et	f	\N
191451	tahaksi	?tahaksi =tahaksi  (SgG  >tahaksi !01_S	et	f	\N
191452	tahaksi	?tahaksi =tahaksi  (IndPrPs_  >tahaksima !28_V	et	f	\N
191453	tahaksi	?tahaksi =tahaksi  (ImpPrSg2  >tahaksima !28_V	et	f	\N
191457	saamuti	?saamuti =saamu  (IndIpfIps  >saamuma !27_V	et	f	\N
191458	saamuti	?saamuti =saamuti  (SgN  >saamuti !01_S	et	f	\N
191459	saamuti	?saamuti =saamuti  (SgG  >saamuti !01_S	et	f	\N
191460	saamuti	?saamuti =saamuti  (SgG  >saamut !02_S	et	f	\N
191461	saamuti	?saamuti =saamuti  (SgG  >saamutt !22_S	et	f	\N
191462	saamuti	?saamuti =saamuti  (IndPrPs_  >saamuttima !28_V	et	f	\N
191463	saamuti	?saamuti =saamuti  (ImpPrSg2  >saamuttima !28_V	et	f	\N
191464	vära	?vära =vära  (SgN  >vära !17_S	et	f	\N
191465	vära	?vära =vära  (SgG  >vära !17_S	et	f	\N
191466	vära	?vära =vära  (SgP  >vära !17_S	et	f	\N
191467	vära	?vära =vära  (IndPrPs_  >värama !27_V	et	f	\N
191468	vära	?vära =vära  (ImpPrSg2  >värama !27_V	et	f	\N
191469	linnasse	linnasse =linna  (SgIll  >linn !22_S	et	f	\N
191470	linnasse	linnasse =asse  (PlP  >linn+ass !22_S	et	f	\N
191485	ütlesis	?ütlesis =ütlesi  (PlIn  >ütlene !12_A	et	f	\N
191056	metrit	?metrit =metri  (SgP  >metter !02_S	et	f	\N
191057	metrit	?metrit =metrit  (SgN  >metrit !02_S	et	f	\N
191058	kasvatamisest	kasvatamisest =kasvatamise  (SgEl  >kasvatamine !12_S	et	f	\N
191059	kasvatamisest	"kasvatamine %kasvata  )MINE_vS  <kasvatama ;27_V	et	f	\N
191131	ääritus	?ääritus =ääritu  (SgIn  >ääritu !01_AS	et	f	\N
191132	ääritus	?ääritus =ääritu  (IndIpfSg3  >äärituma !27_V	et	f	\N
191133	ääritus	?ääritus =ääritus  (SgN  >ääritus !11_S	et	f	\N
191141	kasutumisjuhist	?kasutumisjuhist =kasutumisjuhis  (SgP  >kasutumisjuhis !09_S	et	f	\N
191142	kasutumisjuhist	?kasutumisjuhist =kasutumisjuhist  (SgN  >kasutumisjuhist !22_S	et	f	\N
191143	kasutumisjuhist	?kasutumisjuhist =tumisjuhis  (SgP  >kasu+tumisjuhis !09_S	et	f	\N
191144	kasutumisjuhist	?kasutumisjuhist =tumisjuhist  (SgN  >kasu+tumisjuhist !22_S	et	f	\N
191145	kasutumisjuhist	?kasutumisjuhist =utumisjuhis  (SgP  >kas+utumisjuhis !09_S	et	f	\N
191146	kasutumisjuhist	?kasutumisjuhist =utumisjuhist  (SgN  >kas+utumisjuhist !22_S	et	f	\N
191154	siilma	?siilma =siilma  (IndPrPs_  >siilmama !29_V	et	f	\N
191155	siilma	?siilma =siilma  (ImpPrSg2  >siilmama !29_V	et	f	\N
191156	tavalisse	tavalisse =tavalis  (SgAdt  >tavaline !12_A	et	f	\N
191160	tavalisse	"tavaline %tava  )LINE_aA  <tava ;17_S	et	f	\N
191163	kannapöörded	### kannapöörded	et	f	\N
191168	vaheldusi	vaheldusi =vaheldusi  (PlP  >vaheldus !11_S	et	f	\N
191169	vaheldusi	"vaheldus %vahelda  )US_vS  <vaheldama ;27_V	et	f	\N
191170	vaheldused	vaheldused =vahelduse  (PlN  >vaheldus !11_S	et	f	\N
191171	vaheldused	"vaheldus %vahelda  )US_vS  <vaheldama ;27_V	et	f	\N
191177	võrrases	?võrrases =võrrase  (SgIn  >võrrane !10_A	et	f	\N
191201	kommita	kommita =kommi  (SgAb  >komm !22_S	et	f	\N
191202	kommita	kommita =mi  (SgAb  >kom+mi !26_S	et	f	\N
191213	minimum	?minimum =minimum  (SgN  >minimum !19_S	et	f	\N
191214	lasteajast	lasteajast =aja  (SgEl  >laste+aeg !22_S	et	f	\N
191215	lasteajast	lasteajast =ajas  (SgP  >laste+ajane !10_A	et	f	\N
191216	lasteajast	"laste+ajane %aja  )NE_aA  <laste+aeg ;22_S	et	f	\N
191217	haridusetase	?haridusetase =haridusetase  (SgG  >haridusetane !12_A	et	f	\N
191218	haridusetase	?haridusetase =etase  (SgG  >haridus+etane !10_A	et	f	\N
191219	haridusetase	?haridusetase =dusetase  (SgG  >hari+dusetane !12_A	et	f	\N
191242	demokraatiliselt	?demokraatiliselt =demokraatilise  (SgAbl  >demokraatiline !12_A	et	f	\N
191243	demokraatiliselt	?demokraatiliselt =demokraatiliselt  (ID  >demokraatiliselt !41_D	et	f	\N
191275	raskus	raskus =rasku  (IndIpfSg3  >raskuma !27_V	et	f	\N
191276	raskus	raskus =raskus  (SgN  >raskus !11~09_S	et	f	\N
191277	raskus	"raskus %raske  )US_aS  <raske ;01_A	et	f	\N
191304	shokkis	?shokkis =shokki  (IndIpfSg3  >shokkima !28_V	et	f	\N
191305	shokkis	?shokkis =shokkis  (ID  >shokkis !41_DA	et	f	\N
191314	annabe	### annabe	et	f	\N
191318	jätkavad	jätkavad =jätka  (IndPrPl3  >jätkama !29_V	et	f	\N
191319	jätkavad	jätkavad =jätkava  (PlN  >jätkav !02_A	et	f	\N
191320	jätkavad	"jätkav %jätka  )V_vA  <jätkama ;29_V	et	f	\N
191362	lütsei	?lütsei =lütsei  (SgN  >lütsei !26_S	et	f	\N
191363	lütsei	?lütsei =lütsei  (SgG  >lütsei !26_S	et	f	\N
191375	koolidbr	?koolidbr =koolidbr  (SgN  >koolidbr !22_S	et	f	\N
191376	koolidbr	?koolidbr =idbr  (SgN  >kool+idbr !22_S	et	f	\N
191378	spetsifilist	?spetsifilist =spetsifilis  (SgP  >spetsifilis !09_S	et	f	\N
191379	spetsifilist	?spetsifilist =spetsifilis  (SgP  >spetsifiline !12_A	et	f	\N
191380	spetsifilist	?spetsifilist =spetsifilist  (SgN  >spetsifilist !22_S	et	f	\N
191381	spetsifilist	?spetsifilist =ifilis  (SgP  >spets+ifilis !11_S	et	f	\N
191382	spetsifilist	?spetsifilist =ifilis  (SgP  >spets+ifiline !12_A	et	f	\N
191383	spetsifilist	?spetsifilist =ifilist  (SgN  >spets+ifilist !22_S	et	f	\N
191386	kohustasi	?kohustasi =kohustasi  (PlP  >kohustane !12_A	et	f	\N
191387	kohustasi	?kohustasi =stasi  (SgN  >kohu+stasi !17_S	et	f	\N
191388	kohustasi	?kohustasi =stasi  (SgG  >kohu+stasi !17_S	et	f	\N
191389	kohustasi	?kohustasi =stasi  (SgP  >kohu+stasi !17_S	et	f	\N
191433	mite	?mite =mite  (SgN  >mite !06_S	et	f	\N
191434	mite	?mite =mite  (IndPrPs_  >mitema !27_V	et	f	\N
191435	mite	?mite =mite  (ImpPrSg2  >mitema !27_V	et	f	\N
191439	agapalju	?agapalju =agapalju  (IndPrPs_  >agapaljuma !27_V	et	f	\N
191440	agapalju	?agapalju =agapalju  (ImpPrSg2  >agapaljuma !27_V	et	f	\N
191476	seapraadi	seapraadi =praadi  (SgP  >sea+praad !22_S	et	f	\N
191477	seapraadi	seapraadi =praadi  (SgAdt  >sea+praad !22_S	et	f	\N
191506	halusin	?halusin =halu  (IndIpfSg1  >haluma !27_V	et	f	\N
191507	halusin	?halusin =halusin  (SgN  >halusin !19_S	et	f	\N
191516	lauluväljuku	?lauluväljuku =lauluväljuku  (IndPrPs_  >lauluväljukuma !27_V	et	f	\N
191517	lauluväljuku	?lauluväljuku =lauluväljuku  (ImpPrSg2  >lauluväljukuma !27_V	et	f	\N
191518	lauluväljuku	?lauluväljuku =väljuku  (SgN  >laulu+väljuku !01_S	et	f	\N
191519	lauluväljuku	?lauluväljuku =väljuku  (SgG  >laulu+väljuku !01_S	et	f	\N
191525	vabaõhumuseumisse	?vabaõhumuseumisse =vabaõhumuseumi  (SgIll  >vabaõhumuseumi !16_S	et	f	\N
191526	vabaõhumuseumisse	?vabaõhumuseumisse =vabaõhumuseumi  (SgIll  >vabaõhumuseum !19_S	et	f	\N
191527	vabaõhumuseumisse	?vabaõhumuseumisse =vabaõhumuseumisse  (SgG  >vabaõhumuseumisne !02_A	et	f	\N
191111	sampoone	?sampoone =one  (SgG  >sampo+one !16_S	et	f	\N
191127	puhastumiseks	puhastumiseks =puhastumise  (SgTr  >puhastumine !12_S	et	f	\N
191128	puhastumiseks	"puhastumine %puhastu  )MINE_vS  <puhastuma ;27_V	et	f	\N
191161	hoidla	hoidla =hoidla  (SgN  >hoidla !01_S	et	f	\N
191162	hoidla	hoidla =hoidla  (SgG  >hoidla !01_S	et	f	\N
191175	instituuti	instituuti =instituuti  (SgP  >instituut !22_S	et	f	\N
191176	instituuti	instituuti =instituuti  (SgAdt  >instituut !22_S	et	f	\N
191178	professionalne	?professionalne =professionalne  (SgN  >professionalne !02_A	et	f	\N
191179	professionalne	?professionalne =professionalne  (PlP  >professionaln !22_S	et	f	\N
191200	tupperware	?tupperware =tupperware  (PlP  >tupperwar !19_S	et	f	\N
191206	veetta	?veetta =veetta  (SgN  >veetta !01_S	et	f	\N
191207	veetta	?veetta =veetta  (SgG  >veetta !01_S	et	f	\N
191209	veetta	?veetta =veetta  (IndPrPs_  >veettama !29_V	et	f	\N
191211	veetta	?veetta =veetta  (ImpPrSg2  >veettama !29_V	et	f	\N
191225	hariduseprogramm	?hariduseprogramm =hariduseprogramm  (SgN  >hariduseprogramm !22_S	et	f	\N
191226	hariduseprogramm	?hariduseprogramm =eprogramm  (SgN  >haridus+eprogramm !22_S	et	f	\N
191227	hariduseprogramm	?hariduseprogramm =duseprogramm  (SgN  >hari+duseprogramm !22_S	et	f	\N
191231	stopivad	?stopivad =stopi  (IndPrPl3  >stopima !27_V	et	f	\N
191232	stopivad	?stopivad =stopi  (IndPrPl3  >stoppima !28_V	et	f	\N
191233	stopivad	?stopivad =stopiva  (PlN  >stopiva !01_S	et	f	\N
191234	stopivad	?stopivad =stopiva  (PlN  >stopiv !02_A	et	f	\N
191249	kättemaksta	?kättemaksta =kättemaksta  (SgN  >kättemaksta !16_S	et	f	\N
191250	kättemaksta	?kättemaksta =kättemaksta  (SgG  >kättemaksta !16_S	et	f	\N
191251	kättemaksta	?kättemaksta =kättemaksta  (IndPrPs_  >kättemakstama !27_V	et	f	\N
191252	kättemaksta	?kättemaksta =kättemaksta  (ImpPrSg2  >kättemakstama !27_V	et	f	\N
191253	kättemaksta	?kättemaksta =maksta  (SgN  >kätte+maksta !01_S	et	f	\N
191254	kättemaksta	?kättemaksta =maksta  (SgG  >kätte+maksta !01_S	et	f	\N
191255	kättemaksta	?kättemaksta =emaksta  (SgN  >kätt+emaksta !01_S	et	f	\N
191256	kättemaksta	?kättemaksta =emaksta  (SgG  >kätt+emaksta !01_S	et	f	\N
191270	demokraatlikus	demokraatlikus =demokraatliku  (SgIn  >demokraatlik !25_A	et	f	\N
191271	demokraatlikus	demokraatlikus =demokraatlikus  (SgN  >demokraatlikus !11?09_S	et	f	\N
191272	demokraatlikus	"demokraatlikus %demokraatliku  )US_aS  <demokraatlik ;25_A	et	f	\N
191278	magnetofoni	magnetofoni =magnetofoni  (SgG  >magnetofon !19_S	et	f	\N
191279	magnetofoni	magnetofoni =magnetofoni  (SgP  >magnetofon !19_S	et	f	\N
191280	magnetofoni	magnetofoni =magnetofoni  (SgAdt  >magnetofon !19_S	et	f	\N
191281	õppemetoodika	õppemetoodika =metoodika  (SgN  >õppe+metoodika !01_S	et	f	\N
191282	õppemetoodika	õppemetoodika =metoodika  (SgG  >õppe+metoodika !01_S	et	f	\N
191315	harjumatu	harjumatu =harjumatu  (SgN  >harjumatu !01_A	et	f	\N
191316	harjumatu	"harjumatu %harju  )MATU_vA  <harjuma ;27_V	et	f	\N
191317	harjumatu	harjumatu =harjumatu  (SgG  >harjumatu !01_A	et	f	\N
191321	suuev	?suuev =suuev  (SgN  >suuev !02_S	et	f	\N
191322	diskrimineerimine	diskrimineerimine =diskrimineerimine  (SgN  >diskrimineerimine !12_S	et	f	\N
191323	diskrimineerimine	"diskrimineerimine %diskrimineeri  )MINE_vS  <diskrimineerima ;28_V	et	f	\N
191335	üleminema	?üleminema =üleminema  (SgG  >üleminem !02_A	et	f	\N
191336	üleminema	?üleminema =inema  (SgG  >ülem+inem !02_A	et	f	\N
191337	üleminema	?üleminema =minema  (SgG  >üle+minem !02_A	et	f	\N
191352	väjagi	?väjagi =väja  (SgN^  >väja !17_S	et	f	\N
191353	väjagi	?väjagi =väja  (SgG^  >väja !17_S	et	f	\N
191354	väjagi	?väjagi =väja  (SgP^  >väja !17_S	et	f	\N
191355	väjagi	?väjagi =väja  (IndPrPs_^  >väjama !27_V	et	f	\N
191356	väjagi	?väjagi =väja  (ImpPrSg2^  >väjama !27_V	et	f	\N
191357	venekeelest	venekeelest =keele  (SgEl  >vene+keel !13_S	et	f	\N
191358	venekeelest	venekeelest =keele  (PlEl  >vene+keeld !22_S	et	f	\N
191359	venekeelest	venekeelest =keeles  (SgP  >vene+keelene !10_A	et	f	\N
191360	venekeelest	"vene+keelene %keele  )NE_aA  <vene+keel ;13_S	et	f	\N
191365	süva	süva =süva  (SgN  >süva !17_A	et	f	\N
191366	süva	süva =süva  (SgG  >süva !17_A	et	f	\N
191367	süva	süva =süva  (SgP  >süva !17_A	et	f	\N
191371	kõikede	kõikede =ede  (SgN  >kõik+ede !16_S	et	f	\N
191372	kõikede	kõikede =ede  (SgG  >kõik+ede !16_S	et	f	\N
191396	estlaseid	?estlaseid =estlase  (PlP  >estlane !10_S	et	f	\N
191397	estlaseid	?estlaseid =estlasei  (PlN  >estlasei !26_S	et	f	\N
191398	estlaseid	?estlaseid =estlasei  (SgP  >estlasei !26_S	et	f	\N
191407	vanematesele	?vanematesele =vanematese  (SgAll  >vanematene !12_A	et	f	\N
191408	vanematesele	?vanematesele =sele  (SgN  >vanemate+sele !16_S	et	f	\N
191409	vanematesele	?vanematesele =sele  (SgG  >vanemate+sele !16_S	et	f	\N
191410	vanematesele	?vanematesele =tese  (SgAll  >vanema+tese !16_S	et	f	\N
191411	vanematesele	?vanematesele =atese  (SgAll  >vanem+atene !10_A	et	f	\N
191412	vanematesele	?vanematesele =atesele  (PlP  >vanem+atesel !19_S	et	f	\N
191418	õppekeelt	õppekeelt =kee  (SgAbl  >õppe+kesi !15_S	et	f	\N
191419	õppekeelt	õppekeelt =kee  (SgAbl  >õppe+kee !26_S	et	f	\N
191420	õppekeelt	õppekeelt =keel  (SgP  >õppe+keel !13_S	et	f	\N
191421	muutusteks	muutusteks =muutus  (PlTr  >muutus !11~09_S	et	f	\N
191267	esienesse	?esienesse =enesse  (PlP  >esi+eness !22_S	et	f	\N
191273	temmatikaga	?temmatikaga =temmatika  (SgKom  >temmatika !01_S	et	f	\N
191274	temmatikaga	?temmatikaga =temmatika  (SgKom  >temmatikas !02_A	et	f	\N
191283	tebeleid	?tebeleid =tebele  (PlP  >tebel !02_S	et	f	\N
191284	tebeleid	?tebeleid =tebelei  (PlN  >tebelei !26_S	et	f	\N
191285	tebeleid	?tebeleid =tebelei  (SgP  >tebelei !26_S	et	f	\N
191324	hingelt	hingelt =hinge  (SgAbl  >hing !22_S	et	f	\N
191325	hingelt	hingelt =hinge  (PlAbl  >hink !22_S	et	f	\N
191340	suhtusring	?suhtusring =suhtusring  (SgN  >suhtusring !02_S	et	f	\N
191341	suhtusring	?suhtusring =usring  (SgN  >suht+usring !02_S	et	f	\N
191342	koolilõppetamisega	?koolilõppetamisega =koolilõppetamise  (SgKom  >koolilõppetamine !12_S	et	f	\N
191343	koolilõppetamisega	?koolilõppetamisega =etamise  (SgKom  >kooli+lõpp+etamine !12_S	et	f	\N
191344	koolilõppetamisega	?koolilõppetamisega =lõppetamise  (SgKom  >kooli+lõppetamine !12_S	et	f	\N
191345	koolilõppetamisega	?koolilõppetamisega =ilõppetamise  (SgKom  >kool+ilõppetamine !12_S	et	f	\N
191349	härjutama	?härjutama =härju  (SupIps  >härjuma !27_V	et	f	\N
191350	härjutama	?härjutama =härjuta  (Sup  >härjutama !27_V	et	f	\N
191351	härjutama	?härjutama =härjutama  (SgG  >härjutam !02_A	et	f	\N
191399	häälestatud	häälestatud =häälesta  (PtsPtIps  >häälestama !27_V	et	f	\N
191400	häälestatud	häälestatud =häälestatu  (PlN  >häälestatu !01_S	et	f	\N
191401	häälestatud	"häälestatu %häälesta  )TU1_vS  <häälestama ;27_V	et	f	\N
191402	häälestatud	häälestatud =häälestatud  (ID  >häälestatud !41_A	et	f	\N
191403	häälestatud	"häälestatud %häälesta  )TUD_vA  <häälestama ;27_V	et	f	\N
191454	oliksin	?oliksin =oli  (KndPrSg1  >olima !27_V	et	f	\N
191455	oliksin	?oliksin =oliksi  (IndPrSg1  >oliksima !28_V	et	f	\N
191456	oliksin	?oliksin =oliksin  (SgN  >oliksin !19_S	et	f	\N
191482	emalle	?emalle =emalle  (PlP  >emall !22_S	et	f	\N
191483	emalle	?emalle =emalle  (IndPrPs_  >emallema !27_V	et	f	\N
191484	emalle	?emalle =emalle  (ImpPrSg2  >emallema !27_V	et	f	\N
191494	sõitsis	?sõitsis =sõitsi  (SgIn  >sõits !22_S	et	f	\N
191495	sõitsis	?sõitsis =sõitsi  (IndIpfSg3  >sõitsima !28_V	et	f	\N
191496	sõitsis	?sõitsis =sõitsis  (SgN  >sõitsis !09_S	et	f	\N
191508	meeldsis	?meeldsis =meeldsi  (SgIn  >meelds !22_S	et	f	\N
191509	meeldsis	?meeldsis =meeldsi  (IndIpfSg3  >meeldsima !28_V	et	f	\N
191510	meeldsis	?meeldsis =meeldsis  (SgN  >meeldsis !09_S	et	f	\N
191512	lauluväljukule	?lauluväljukule =lauluväljukule  (PlP  >lauluväljukul !19_S	et	f	\N
191513	lauluväljukule	?lauluväljukule =väljuku  (SgAll  >laulu+väljuku !01_S	et	f	\N
191514	lauluväljukule	?lauluväljukule =väljukule  (PlP  >laulu+väljukul !19_S	et	f	\N
191515	lauluväljukule	?lauluväljukule =luväljukule  (PlP  >lau+luväljukul !19_S	et	f	\N
191537	mustsõstuveini	?mustsõstuveini =mustsõstuvei  (SgTer  >mustsõstuvei !26_S	et	f	\N
191538	mustsõstuveini	?mustsõstuveini =mustsõstuveini  (SgN  >mustsõstuveini !16_S	et	f	\N
191539	mustsõstuveini	?mustsõstuveini =mustsõstuveini  (SgG  >mustsõstuveini !16_S	et	f	\N
191540	mustsõstuveini	?mustsõstuveini =mustsõstuveini  (SgG  >mustsõstuvein !19_S	et	f	\N
191541	mustsõstuveini	?mustsõstuveini =mustsõstuveini  (SgP  >mustsõstuvein !19_S	et	f	\N
191542	mustsõstuveini	?mustsõstuveini =mustsõstuveini  (SgAdt  >mustsõstuvein !19_S	et	f	\N
191543	mustsõstuveini	?mustsõstuveini =mustsõstuveini  (IndPrPs_  >mustsõstuveinima !28_V	et	f	\N
191544	mustsõstuveini	?mustsõstuveini =mustsõstuveini  (ImpPrSg2  >mustsõstuveinima !28_V	et	f	\N
191545	mustsõstuveini	?mustsõstuveini =sõstuvei  (SgTer  >must+sõstuvei !26_S	et	f	\N
191546	mustsõstuveini	?mustsõstuveini =sõstuveini  (SgN  >must+sõstuveini !16_S	et	f	\N
191547	mustsõstuveini	?mustsõstuveini =sõstuveini  (SgG  >must+sõstuveini !16_S	et	f	\N
191548	mustsõstuveini	?mustsõstuveini =sõstuveini  (SgG  >must+sõstuvein !19_S	et	f	\N
191549	mustsõstuveini	?mustsõstuveini =sõstuveini  (SgP  >must+sõstuvein !19_S	et	f	\N
191550	mustsõstuveini	?mustsõstuveini =sõstuveini  (SgAdt  >must+sõstuvein !19_S	et	f	\N
191551	ostanud	?ostanud =osta  (PtsPtPs  >ostama !29_V	et	f	\N
191552	ostanud	?ostanud =ostanu  (PlN  >ostanu !01_S	et	f	\N
191553	ostanud	?ostanud =ostanu  (IndPrSg2  >ostanuma !27_V	et	f	\N
191554	ostanud	?ostanud =ostanud  (ID  >ostanud !41_A	et	f	\N
191562	närvline	?närvline =närvline  (SgN  >närvline !12~10_A	et	f	\N
191563	närvline	?närvline =närvline  (IndPrPs_  >närvlinema !27_V	et	f	\N
191564	närvline	?närvline =närvline  (ImpPrSg2  >närvlinema !27_V	et	f	\N
191570	jalustuskäiku	?jalustuskäiku =jalustuskäiku  (IndPrPs_  >jalustuskäikuma !27_V	et	f	\N
191571	jalustuskäiku	?jalustuskäiku =jalustuskäiku  (ImpPrSg2  >jalustuskäikuma !27_V	et	f	\N
191572	jalustuskäiku	?jalustuskäiku =uskäiku  (SgN  >jalust+uskäiku !01_S	et	f	\N
191573	jalustuskäiku	?jalustuskäiku =uskäiku  (SgG  >jalust+uskäiku !01_S	et	f	\N
191576	kaasüürilisele	kaasüürilisele =üürilise  (SgAll  >kaas+üüriline !12_S	et	f	\N
191577	kaasüürilisele	"kaas+üüriline %üüri  )LINE_aA  <kaas+üür ;22_S	et	f	\N
191584	saiakest	saiakest =saiakes  (SgP  >saiake !12_S	et	f	\N
191585	saiakest	"saiake %saia  )KE_dS  <sai ;22_S	et	f	\N
191586	saiakest	saiakest =saiakes  (SgP  >saiakene !12_S	et	f	\N
191587	saiakest	"saiakene %saia  )KENE_dS  <sai ;22_S	et	f	\N
191307	õpetust	"õpetus %õpeta  )US_vS  <õpetama ;27_V	et	f	\N
191308	kõikjadele	?kõikjadele =jade  (SgAll  >kõik+jade !16_S	et	f	\N
191328	õppetajad	?õppetajad =õppetaja  (PlN  >õppetaja !01_S	et	f	\N
191329	õppetajad	?õppetajad =õppetaja  (PlN  >õppetajas !02_A	et	f	\N
191330	õppetajad	?õppetajad =taja  (PlN  >õppe+taja !17_S	et	f	\N
191331	süvaõpemisega	?süvaõpemisega =süvaõpemise  (SgKom  >süvaõpemine !12_S	et	f	\N
191332	süvaõpemisega	?süvaõpemisega =õpemise  (SgKom  >süva+õpemine !12_S	et	f	\N
191333	ratsenalsem	?ratsenalsem =ratsenalsem  (SgN  >ratsenalsem !02_A	et	f	\N
191334	aravn	?aravn =aravn  (SgN  >aravn !22_S	et	f	\N
191346	kakõige	?kakõige =kakõige  (PlP  >kakõig !22_S	et	f	\N
191347	väiksest	väiksest =väikse  (SgEl  >väike !10_A	et	f	\N
191348	väiksest	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
191361	ebs	?ebs =ebs  (SgN  >ebs !22_S	et	f	\N
191364	frantsuse	?frantsuse =frantsuse  (SgG  >frantsus !11~09_S	et	f	\N
191368	gümnasium	?gümnasium =gümnasium  (SgN  >gümnasium !19_S	et	f	\N
191369	süstemile	?süstemile =süstemi  (SgAll  >süstemi !01_S	et	f	\N
191370	süstemile	?süstemile =süstemi  (SgAll  >süstem !02_A	et	f	\N
191373	süvaõppe	süvaõppe =õppe  (SgG  >süva+õpe !06_S	et	f	\N
191374	süvaõppe	süvaõppe =õppe  (PlP  >süva+õpp !22_S	et	f	\N
191377	kaklukstel	?kaklukstel =kaklukste  (PlAd  >kaklukst !22_S	et	f	\N
191392	kergeminibr	?kergeminibr =kergeminibr  (SgN  >kergeminibr !22_S	et	f	\N
191393	kergeminibr	?kergeminibr =minibr  (SgN  >kerge+minibr !22_S	et	f	\N
191394	kergeminibr	?kergeminibr =eminibr  (SgN  >kerg+eminibr !22_S	et	f	\N
191404	organizatsioone	?organizatsioone =organizatsioone  (SgN  >organizatsioone !16_S	et	f	\N
191405	organizatsioone	?organizatsioone =organizatsioone  (SgG  >organizatsioone !16_S	et	f	\N
191406	organizatsioone	?organizatsioone =organizatsioone  (PlP  >organizatsioon !22_S	et	f	\N
191413	klassidestele	?klassidestele =klassides  (PlAll  >klassidene !12_A	et	f	\N
191414	klassidestele	?klassidestele =klassidestele  (IndPrPs_  >klassidestelema !36_V	et	f	\N
191415	klassidestele	?klassidestele =klassidestele  (ImpPrSg2  >klassidestelema !36_V	et	f	\N
191416	klassidestele	?klassidestele =deste  (SgAll  >klassi+deste !06_S	et	f	\N
191417	klassidestele	?klassidestele =deste  (PlAll  >klassi+dest !22_S	et	f	\N
191428	peavalut	?peavalut =peavalu  (SgP  >peavalu !01_S	et	f	\N
191429	peavalut	?peavalut =valut  (SgN  >pea+valut !02_S	et	f	\N
191436	maitses	maitses =maitse  (IndIpfSg3  >maitsma !32_V	et	f	\N
191437	maitses	maitses =maitse  (SgIn  >maitse !06_S	et	f	\N
191438	maitses	maitses =maitse  (IndIpfSg3  >maitsema !28_V	et	f	\N
191448	pühtitsa	?pühtitsa =pühtitsa  (SgN  >pühtitsa !01_S	et	f	\N
191449	pühtitsa	?pühtitsa =pühtitsa  (SgG  >pühtitsa !01_S	et	f	\N
191471	räägisis	?räägisis =räägisis  (SgN  >räägisis !11_S	et	f	\N
191472	rääginud	?rääginud =räägi  (PtsPtPs  >räägima !28_V	et	f	\N
191473	rääginud	?rääginud =rääginu  (PlN  >rääginu !01_S	et	f	\N
191474	rääginud	?rääginud =rääginu  (IndPrSg2  >rääginuma !27_V	et	f	\N
191475	rääginud	?rääginud =rääginud  (ID  >rääginud !41_A	et	f	\N
191478	museumis	?museumis =museumi  (SgIn  >museumi !01_S	et	f	\N
191479	museumis	?museumis =museumi  (SgIn  >museum !22_S	et	f	\N
191480	museumis	?museumis =museumi  (IndIpfSg3  >museumima !28_V	et	f	\N
191481	museumis	?museumis =museumis  (SgN  >museumis !09_S	et	f	\N
191504	maiustused	maiustused =maiustuse  (PlN  >maiustus !11_S	et	f	\N
191505	maiustused	"maiustus %maiusta  )US_vS  <maiustama ;27_V	et	f	\N
191511	jumalteenistuse	?jumalteenistuse =jumalteenistuse  (SgG  >jumalteenistus !11_S	et	f	\N
191555	berliinisse	?berliinisse =berliini  (SgIll  >berliini !16_S	et	f	\N
191556	berliinisse	?berliinisse =berliini  (SgIll  >berliin !22_S	et	f	\N
191557	berliinisse	?berliinisse =berliinisse  (SgG  >berliinisne !02_A	et	f	\N
191558	berliinisse	?berliinisse =berliinisse  (PlP  >berliiniss !22_S	et	f	\N
191591	pahandanud	pahandanud =pahanda  (PtsPtPs  >pahandama !27_V	et	f	\N
191592	pahandanud	pahandanud =pahandanu  (PlN  >pahandanu !01_S	et	f	\N
191593	pahandanud	"pahandanu %pahanda  )NU_vS  <pahandama ;27_V	et	f	\N
191594	pahandanud	pahandanud =pahandanud  (ID  >pahandanud !41_A	et	f	\N
191595	pahandanud	"pahandanud %pahanda  )NUD_vA  <pahandama ;27_V	et	f	\N
191596	kümnet	### kümnet	et	f	\N
191618	järjelugu	järjelugu =lugu  (SgN  >järje+lugu !18_S	et	f	\N
191620	järjelugu	järjelugu =lugu  (SgP  >järje+lugu !18_S	et	f	\N
191625	läksim	?läksim =läksim  (SgN  >läksim !02_A	et	f	\N
191652	pagaslt	?pagaslt =pagaslt  (SgN  >pagaslt !22_S	et	f	\N
191673	riidedga	?riidedga =riidedga  (SgN  >riidedga !01_S	et	f	\N
191674	riidedga	?riidedga =riidedga  (SgG  >riidedga !01_S	et	f	\N
191678	südalinnasse	südalinnasse =asse  (PlP  >süda+linn+ass !22_S	et	f	\N
191679	südalinnasse	südalinnasse =linna  (SgIll  >süda+linn !22_S	et	f	\N
191687	tiomekas	?tiomekas =tiomeka  (SgIn  >tiomeka !01_S	et	f	\N
191688	tiomekas	?tiomekas =tiomeka  (SgIn  >tiomekas !02_A	et	f	\N
191689	tiomekas	?tiomekas =tiomekas  (SgN  >tiomekas !02_A	et	f	\N
191709	lancesterisse	?lancesterisse =lancesteri  (SgIll  >lancester !02_S	et	f	\N
191710	lancesterisse	?lancesterisse =lancesterisse  (SgG  >lancesterisne !02_A	et	f	\N
191422	muutusteks	"muutus %muu  )TUS2_aS  <muu ;26_S	et	f	\N
191423	muutusteks	muutusteks =tuste  (PlTr  >muu+tust !22_S	et	f	\N
191424	nabririigis	?nabririigis =nabririigi  (SgIn  >nabririigi !16_S	et	f	\N
191425	nabririigis	?nabririigis =nabririigi  (SgIn  >nabririik !22_S	et	f	\N
191426	nabririigis	?nabririigis =nabririigi  (IndIpfSg3  >nabririigima !28_V	et	f	\N
191427	nabririigis	?nabririigis =nabririigis  (SgN  >nabririigis !09_S	et	f	\N
191430	õpimiskeele	õpimiskeele =kee  (SgAll  >õpi+mis+kesi !15_S	et	f	\N
191431	õpimiskeele	õpimiskeele =kee  (SgAll  >õpi+mis+kee !26_S	et	f	\N
191432	õpimiskeele	õpimiskeele =keele  (SgG  >õpi+mis+keel !13_S	et	f	\N
191493	tassi	tassi =tassi  (SgG  >tass !22_S	et	f	\N
191497	tassi	tassi =tassi  (SgP  >tass !22_S	et	f	\N
191498	tassi	tassi =tassi  (SgAdt  >tass !22_S	et	f	\N
191499	tassi	tassi =tassi  (IndPrPs_  >tassima !28_V	et	f	\N
191500	tassi	tassi =tassi  (ImpPrSg2  >tassima !28_V	et	f	\N
191501	vaarikakooki	vaarikakooki =kooki  (SgP  >vaarika+kook !22_S	et	f	\N
191502	vaarikakooki	vaarikakooki =kooki  (SgAdt  >vaarika+kook !22_S	et	f	\N
191503	ostasime	?ostasime =osta  (IndIpfPl1  >ostama !29_V	et	f	\N
191520	olde	?olde =olde  (SgN  >olde !06_S	et	f	\N
191521	olde	?olde =olde  (SgG  >olle !06_S	et	f	\N
191522	olde	?olde =olde  (PlP  >old !22_S	et	f	\N
191523	olde	?olde =olde  (IndPrPs_  >oldema !27_V	et	f	\N
191524	olde	?olde =olde  (ImpPrSg2  >oldema !27_V	et	f	\N
191559	näenud	?näenud =näenu  (PlN  >näenu !16_S	et	f	\N
191560	näenud	?näenud =näenu  (IndPrSg2  >näenuma !28_V	et	f	\N
191561	näenud	?näenud =näenud  (ID  >näenud !41_A	et	f	\N
191581	piimiga	piimiga =piimi  (SgKom  >piim !22_S	et	f	\N
191582	piimiga	piimiga =iga  (SgN  >piim+iga !18_S	et	f	\N
191583	piimiga	piimiga =iga  (SgP  >piim+iga !18_S	et	f	\N
191608	laenutama	laenutama =laenu  (SupIps  >laenuma !27_V	et	f	\N
191609	laenutama	laenutama =laenuta  (Sup  >laenutama !27_V	et	f	\N
191616	kaasüürilitsega	?kaasüürilitsega =kaasüürilitse  (SgKom  >kaasüürilitne !02_A	et	f	\N
191617	kaasüürilitsega	?kaasüürilitsega =litse  (SgKom  >kaas+üüri+litne !02_A	et	f	\N
191619	kaasüürilitsega	?kaasüürilitsega =litse  (SgKom  >kaas+üüri+litse !06_S	et	f	\N
191621	kaasüürilitsega	?kaasüürilitsega =üürilitse  (SgKom  >kaas+üürilitne !02_A	et	f	\N
191629	märkustes	märkustes =märkus  (PlIn  >märkus !11~09_S	et	f	\N
191630	märkustes	märkustes =us  (PlIn  >märk+uks !14_S	et	f	\N
191632	pärastlõunnal	?pärastlõunnal =pärastlõunna  (SgAd  >pärastlõunna !16_S	et	f	\N
191633	pärastlõunnal	?pärastlõunnal =pärastlõunnal  (SgN  >pärastlõunnal !02_S	et	f	\N
191634	pärastlõunnal	?pärastlõunnal =lõunna  (SgAd  >pärast+lõunna !01_S	et	f	\N
191635	pärastlõunnal	?pärastlõunnal =lõunnal  (SgN  >pärast+lõunnal !02_S	et	f	\N
191642	hommikusööku	?hommikusööku =hommikusööku  (IndPrPs_  >hommikusöökuma !27_V	et	f	\N
191643	hommikusööku	?hommikusööku =hommikusööku  (ImpPrSg2  >hommikusöökuma !27_V	et	f	\N
191644	hommikusööku	?hommikusööku =sööku  (SgN  >hommiku+sööku !16_S	et	f	\N
191645	hommikusööku	?hommikusööku =sööku  (SgG  >hommiku+sööku !16_S	et	f	\N
191646	hommikusööku	?hommikusööku =usööku  (SgN  >hommik+usööku !01_S	et	f	\N
191647	hommikusööku	?hommikusööku =usööku  (SgG  >hommik+usööku !01_S	et	f	\N
191650	väljusis	?väljusis =väljusi  (PlIn  >väljus !11_S	et	f	\N
191651	väljusis	?väljusis =väljusis  (SgN  >väljusis !11_S	et	f	\N
191653	verrand	?verrand =verrand  (SgN  >verrand !02_S	et	f	\N
191654	õhtusse	õhtusse =õhtu  (SgIll  >õhtu !01_S	et	f	\N
191655	õhtusse	õhtusse =õhtus  (SgAdt  >õhtune !12_A	et	f	\N
191656	õhtusse	"õhtune %õhtu  )NE_aA  <õhtu ;01_S	et	f	\N
191659	paddingtonisse	?paddingtonisse =paddingtoni  (SgIll  >paddington !02_S	et	f	\N
191660	paddingtonisse	?paddingtonisse =paddingtonisse  (SgG  >paddingtonisne !02_A	et	f	\N
191661	paddingtonisse	?paddingtonisse =paddingtonisse  (PlP  >paddingtoniss !22_S	et	f	\N
191669	inimesedga	?inimesedga =inimesedga  (SgN  >inimesedga !16_S	et	f	\N
191670	inimesedga	?inimesedga =inimesedga  (SgG  >inimesedga !16_S	et	f	\N
191671	inimesedga	?inimesedga =esedga  (SgN  >inim+esedga !01_S	et	f	\N
191672	inimesedga	?inimesedga =esedga  (SgG  >inim+esedga !01_S	et	f	\N
191675	muljielt	?muljielt =muljie  (SgAbl  >muljie !01_S	et	f	\N
191676	muljielt	?muljielt =muljielt  (ID  >muljielt !41_D	et	f	\N
191691	temse	?temse =temse  (SgN  >temse !06_S	et	f	\N
191692	temse	?temse =temse  (SgG  >temne !02_A	et	f	\N
191693	temse	?temse =temse  (PlP  >tems !22_S	et	f	\N
191694	temse	?temse =temse  (IndPrPs_  >temsema !27_V	et	f	\N
191695	temse	?temse =temse  (ImpPrSg2  >temsema !27_V	et	f	\N
191698	gardenisse	?gardenisse =gardeni  (SgIll  >garden !02_S	et	f	\N
191700	gardenisse	?gardenisse =gardenis  (SgAdt  >gardenis !11_S	et	f	\N
191701	gardenisse	?gardenisse =gardenisse  (SgG  >gardenisne !02_A	et	f	\N
191702	gardenisse	?gardenisse =gardenisse  (PlP  >gardeniss !22_S	et	f	\N
191718	28juuli	juuli =juuli  (SgN  >juuli !16_S	et	f	\N
191719	28juuli	juuli =juuli  (SgG  >juuli !16_S	et	f	\N
191741	ruckby	### ruckby	et	f	\N
191750	kovhik	?kovhik =kovhik  (SgN  >kovhik !02_S	et	f	\N
191486	ütlesis	?ütlesis =ütlesis  (SgN  >ütlesis !11_S	et	f	\N
191487	ususin	?ususin =usu  (IndIpfSg1  >usuma !27_V	et	f	\N
191488	ususin	?ususin =ususin  (SgN  >ususin !19_S	et	f	\N
191489	normaaline	normaaline =normaaline  (SgN  >normaaline !12?10_A	et	f	\N
191490	normaaline	"normaaline %normaali  )NE_aA  <normaal ;22_S	et	f	\N
191491	normaaline	normaaline =ine  (SgN  >normaal+ine !16_S	et	f	\N
191492	normaaline	normaaline =ine  (SgG  >normaal+ine !16_S	et	f	\N
191568	keestin	?keestin =keesti  (IndPrSg1  >keestima !28_V	et	f	\N
191569	keestin	?keestin =keestin  (SgN  >keestin !02_S	et	f	\N
191574	jooksin	jooksin =joo  (KndPrSg1  >jooma !38_V	et	f	\N
191575	jooksin	jooksin =jooks  (IndIpfSg1  >jooksma !32_V	et	f	\N
191610	xxxle	### xxxle	et	f	\N
191611	semiaritöö	?semiaritöö =semiaritöö  (SgN  >semiaritöö !26_S	et	f	\N
191612	semiaritöö	?semiaritöö =semiaritöö  (SgG  >semiaritöö !26_S	et	f	\N
191613	kests	?kests =kests  (SgN  >kests !22_S	et	f	\N
191623	lost	?lost =lost  (SgN  >lost !22_S	et	f	\N
191626	pesnud	pesnud =pes  (PtsPtPs  >pesema !36_V	et	f	\N
191627	pesnud	"pesnu %pes  )NU_vS  <pesema ;36_V	et	f	\N
191628	pesnud	"pesnud %pes  )NUD_vA  <pesema ;36_V	et	f	\N
191631	xxxsse	### xxxsse	et	f	\N
191638	emailisid	emailisid =emaili  (PlP  >email !22_S	et	f	\N
191639	emailisid	emailisid =emaili  (IndIpfSg2  >emailima !28_V	et	f	\N
191640	emailisid	emailisid =emaili  (IndIpfPl3  >emailima !28_V	et	f	\N
191657	25juuli	juuli =juuli  (SgN  >juuli !16_S	et	f	\N
191658	25juuli	juuli =juuli  (SgG  >juuli !16_S	et	f	\N
191682	parg	?parg =parg  (SgN  >parg !22_S	et	f	\N
191699	covent	?covent =covent  (SgN  >covent !22_S	et	f	\N
191703	muffins	?muffins =muffins  (SgN  >muffins !02_S	et	f	\N
191720	keskpäeviti	?keskpäeviti =keskpäevi  (IndIpfIps  >keskpäevima !28_V	et	f	\N
191721	keskpäeviti	?keskpäeviti =keskpäeviti  (ID  >keskpäeviti !41_D	et	f	\N
191722	keskpäeviti	?keskpäeviti =keskpäeviti  (SgG  >keskpäevitt !22_S	et	f	\N
191723	keskpäeviti	?keskpäeviti =keskpäeviti  (IndPrPs_  >keskpäevittima !28_V	et	f	\N
191724	keskpäeviti	?keskpäeviti =keskpäeviti  (ImpPrSg2  >keskpäevittima !28_V	et	f	\N
191725	keskpäeviti	?keskpäeviti =iti  (SgN  >kesk+päev+iti !16_S	et	f	\N
191726	keskpäeviti	?keskpäeviti =iti  (SgG  >kesk+päev+iti !16_S	et	f	\N
191727	keskpäeviti	?keskpäeviti =iti  (SgG  >kesk+päev+itt !22_S	et	f	\N
191728	keskpäeviti	?keskpäeviti =päeviti  (SgG  >kesk+päevit !02_S	et	f	\N
191729	keskpäeviti	?keskpäeviti =päeviti  (SgG  >kesk+päevitt !22_S	et	f	\N
191744	lancesteril	?lancesteril =lancesteri  (SgAd  >lancester !02_S	et	f	\N
191761	lake	lake =lake  (SgN  >lake !06_S	et	f	\N
191762	lake	"lake %la  )KE_dS  <la ;26_S	et	f	\N
191792	brüsselisse	?brüsselisse =brüsseli  (SgIll  >brüssel !02_S	et	f	\N
191793	brüsselisse	?brüsselisse =brüsselis  (SgAdt  >brüsselis !11_S	et	f	\N
191794	brüsselisse	?brüsselisse =brüsselis  (SgAdt  >brüsseline !12_A	et	f	\N
191795	brüsselisse	?brüsselisse =brüsselisse  (SgG  >brüsselisne !02_A	et	f	\N
191796	brüsselisse	?brüsselisse =brüsselisse  (PlP  >brüsseliss !22_S	et	f	\N
191812	montrealis	?montrealis =montreali  (SgIn  >montreali !16_S	et	f	\N
191813	montrealis	?montrealis =montreali  (SgIn  >montreal !19_S	et	f	\N
191814	montrealis	?montrealis =montreali  (IndIpfSg3  >montrealima !28_V	et	f	\N
191815	montrealis	?montrealis =montrealis  (SgN  >montrealis !09_S	et	f	\N
191817	ida-kanadas	### ida-kanadas	et	f	\N
191823	supermarketi	?supermarketi =supermarketi  (SgG  >supermarkett !22_S	et	f	\N
191824	supermarketi	?supermarketi =supermarketi  (IndPrPs_  >supermarkettima !28_V	et	f	\N
191825	supermarketi	?supermarketi =supermarketi  (ImpPrSg2  >supermarkettima !28_V	et	f	\N
191826	supermarketi	?supermarketi =marketi  (SgG  >super+markett !22_S	et	f	\N
191853	magogis	?magogis =magogi  (SgIn  >magog !02_S	et	f	\N
191854	magogis	?magogis =magogis  (SgN  >magogis !11_S	et	f	\N
191869	kilometrit	?kilometrit =kilometri  (SgP  >kilometter !02_S	et	f	\N
191870	kilometrit	?kilometrit =metri  (SgP  >kilo+metter !02_S	et	f	\N
191871	kilometrit	?kilometrit =metrit  (SgN  >kilo+metrit !02_S	et	f	\N
191881	kirsidega	?kirsidega =kirsi  (PlKom  >kirsi !16_S	et	f	\N
191904	breakfast	?breakfast =breakfa  (SgEl  >breakfa !01_S	et	f	\N
191905	breakfast	?breakfast =breakfas  (SgP  >breakfane !12~10_A	et	f	\N
191914	hash	?hash =hash  (SgN  >hash !22_S	et	f	\N
191932	göttingenis	?göttingenis =göttingeni  (SgIn  >göttingen !19_S	et	f	\N
191933	göttingenis	?göttingenis =göttingenis  (SgN  >göttingenis !09_S	et	f	\N
192002	citysse	?citysse =citysse  (SgG  >citysne !02_A	et	f	\N
192003	citysse	?citysse =citysse  (PlP  >cityss !22_S	et	f	\N
192009	lady	### lady	et	f	\N
192028	jälutuskäik	?jälutuskäik =jälutuskäik  (SgN  >jälutuskäik !22_S	et	f	\N
192029	jaoksja	?jaoksja =jaoksja  (SgN  >jaoksja !01_S	et	f	\N
192030	jaoksja	?jaoksja =jaoksja  (SgG  >jaoksja !01_S	et	f	\N
192031	jaoksja	?jaoksja =jaoksja  (SgG  >jaoksjas !02_A	et	f	\N
192032	jaoksja	?jaoksja =jaoksja  (IndPrPs_  >jaoksjama !29_V	et	f	\N
192033	jaoksja	?jaoksja =jaoksja  (ImpPrSg2  >jaoksjama !29_V	et	f	\N
192034	turgisse	?turgisse =turgi  (SgIll  >turk !22_S	et	f	\N
191528	vabaõhumuseumisse	?vabaõhumuseumisse =vabaõhumuseumisse  (PlP  >vabaõhumuseumiss !22_S	et	f	\N
191529	vabaõhumuseumisse	?vabaõhumuseumisse =museumi  (SgIll  >vaba+õhu+museumi !01_S	et	f	\N
191530	vabaõhumuseumisse	?vabaõhumuseumisse =museumi  (SgIll  >vaba+õhu+museum !22_S	et	f	\N
191531	vabaõhumuseumisse	?vabaõhumuseumisse =museumisse  (SgG  >vaba+õhu+museumisne !02_A	et	f	\N
191532	vabaõhumuseumisse	?vabaõhumuseumisse =museumisse  (PlP  >vaba+õhu+museumiss !22_S	et	f	\N
191533	vabaõhumuseumisse	?vabaõhumuseumisse =õhumuseumi  (SgIll  >vaba+õhumuseumi !16_S	et	f	\N
191534	vabaõhumuseumisse	?vabaõhumuseumisse =õhumuseumi  (SgIll  >vaba+õhumuseum !19_S	et	f	\N
191535	vabaõhumuseumisse	?vabaõhumuseumisse =õhumuseumisse  (SgG  >vaba+õhumuseumisne !02_A	et	f	\N
191536	vabaõhumuseumisse	?vabaõhumuseumisse =õhumuseumisse  (PlP  >vaba+õhumuseumiss !22_S	et	f	\N
191565	nädalatest	nädalatest =nädala  (PlEl  >nädal !02_S	et	f	\N
191566	nädalatest	nädalatest =test  (SgN  >nädala+test !22_S	et	f	\N
191567	xxxga	### xxxga	et	f	\N
191578	tahnud	?tahnud =tahnu  (PlN  >tahnu !01_S	et	f	\N
191579	tahnud	?tahnud =tahnu  (IndPrSg2  >tahnuma !27_V	et	f	\N
191580	tahnud	?tahnud =tahnud  (ID  >tahnud !41_A	et	f	\N
191589	kaaselanigutel	?kaaselanigutel =kaaselanigute  (PlAd  >kaaselanigutt !22_S	et	f	\N
191590	kaaselanigutel	?kaaselanigutel =elanigute  (PlAd  >kaas+elanigutt !22_S	et	f	\N
191597	vahuveinseid	?vahuveinseid =vahuveinse  (PlP  >vahuveinne !02_A	et	f	\N
191598	vahuveinseid	?vahuveinseid =vahuveinsei  (PlN  >vahuveinsei !26_S	et	f	\N
191599	vahuveinseid	?vahuveinseid =vahuveinsei  (SgP  >vahuveinsei !26_S	et	f	\N
191600	vahuveinseid	?vahuveinseid =veinse  (PlP  >vahu+veinne !02_A	et	f	\N
191601	vahuveinseid	?vahuveinseid =veinse  (PlP  >vahu+veinse !06_S	et	f	\N
191602	vahuveinseid	?vahuveinseid =veinsei  (PlN  >vahu+veinsei !26_S	et	f	\N
191603	vahuveinseid	?vahuveinseid =veinsei  (SgP  >vahu+veinsei !26_S	et	f	\N
191604	vahuveinseid	?vahuveinseid =veinseid  (SgN  >vahu+veinseid !22_S	et	f	\N
191622	kesköö	kesköö =öö  (SgN  >kesk+öö !26_S	et	f	\N
191624	kesköö	kesköö =öö  (SgG  >kesk+öö !26_S	et	f	\N
191648	24juuli	juuli =juuli  (SgN  >juuli !16_S	et	f	\N
191649	24juuli	juuli =juuli  (SgG  >juuli !16_S	et	f	\N
191662	camden	?camden =camde  (IndPrSg1  >camdema !27_V	et	f	\N
191663	camden	?camden =camden  (SgN  >camden !02_S	et	f	\N
191665	inimesedga	?inimesedga =inimesedga  (SgN  >inimesedga !16_S	et	f	\N
191666	inimesedga	?inimesedga =inimesedga  (SgG  >inimesedga !16_S	et	f	\N
191667	inimesedga	?inimesedga =esedga  (SgN  >inim+esedga !01_S	et	f	\N
191668	inimesedga	?inimesedga =esedga  (SgG  >inim+esedga !01_S	et	f	\N
191677	eindrücken	?eindrücken =eindrücken  (SgN  >eindrücken !19_S	et	f	\N
191680	kolmverrand	?kolmverrand =kolmverrand  (SgN  >kolmverrand !22_S	et	f	\N
191681	kolmverrand	?kolmverrand =verrand  (SgN  >kolm+verrand !02_S	et	f	\N
191683	dume	?dume =dume  (SgN  >dume !16_S	et	f	\N
191684	dume	?dume =dume  (SgG  >dume !16_S	et	f	\N
191685	dume	?dume =dume  (IndPrPs_  >dumema !27_V	et	f	\N
191686	dume	?dume =dume  (ImpPrSg2  >dumema !27_V	et	f	\N
191705	27juuli	juuli =juuli  (SgN  >juuli !16_S	et	f	\N
191706	27juuli	juuli =juuli  (SgG  >juuli !16_S	et	f	\N
191736	grillfest	?grillfest =grillfe  (SgEl  >grillfe !06_S	et	f	\N
191737	grillfest	?grillfest =grillfe  (PlEl  >grillf !22_S	et	f	\N
191738	grillfest	?grillfest =grillfes  (SgP  >grillfes !09_S	et	f	\N
191739	grillfest	?grillfest =grillfes  (SgP  >grillfene !12~10_A	et	f	\N
191740	grillfest	?grillfest =fest  (SgN  >grill+fest !22_S	et	f	\N
191768	kothusime	?kothusime =kothu  (IndIpfPl1  >kothuma !27_V	et	f	\N
191818	pilvitu	pilvitu =pilvitu  (SgN  >pilvitu !01_A	et	f	\N
191819	pilvitu	"pilvitu %pilvi  )TU2_kA  <pilv ;22_S	et	f	\N
191820	pilvitu	pilvitu =pilvitu  (SgG  >pilvitu !01_A	et	f	\N
191865	lennoxvillesse	?lennoxvillesse =lennoxville  (PlIll  >lennoxvill !22_S	et	f	\N
191866	lennoxvillesse	?lennoxvillesse =lennoxvilles  (SgAdt  >lennoxvillene !12_A	et	f	\N
191867	lennoxvillesse	?lennoxvillesse =lennoxvillesse  (SgG  >lennoxvillesne !02_A	et	f	\N
191868	lennoxvillesse	?lennoxvillesse =lennoxvillesse  (PlP  >lennoxvilless !22_S	et	f	\N
191876	stanstead	?stanstead =stanstea  (PlN  >stanstea !26_S	et	f	\N
191877	stanstead	?stanstead =stanstea  (SgP  >stanstea !26_S	et	f	\N
191878	stanstead	?stanstead =stanstead  (SgN  >stanstead !22_S	et	f	\N
191893	stansteadi	?stansteadi =stansteadi  (SgN  >stansteadi !16_S	et	f	\N
191894	stansteadi	?stansteadi =stansteadi  (SgG  >stansteadi !16_S	et	f	\N
191895	stansteadi	?stansteadi =stansteadi  (SgG  >stansteat !22_S	et	f	\N
191896	stansteadi	?stansteadi =stansteadi  (SgP  >stanstead !22_S	et	f	\N
191897	stansteadi	?stansteadi =stansteadi  (SgAdt  >stanstead !22_S	et	f	\N
191898	stansteadi	?stansteadi =stansteadi  (IndPrPs_  >stansteatima !28_V	et	f	\N
191899	stansteadi	?stansteadi =stansteadi  (ImpPrSg2  >stansteatima !28_V	et	f	\N
191901	fondue	?fondue =fondue  (SgN  >fondue !01_S	et	f	\N
191902	fondue	?fondue =fondue  (SgG  >fondue !01_S	et	f	\N
191915	browns	?browns =browns  (SgN  >browns !22_S	et	f	\N
191916	automaatika	automaatika =automaatika  (SgN  >automaatika !01_S	et	f	\N
191917	automaatika	automaatika =automaatika  (SgG  >automaatika !01_S	et	f	\N
191918	automaatika	automaatika =tika  (SgG  >auto+maa+tikk !22_S	et	f	\N
191588	saiakest	saiakest =kest  (SgN  >saia+kest !22_S	et	f	\N
191605	lühidus	lühidus =lühidus  (SgN  >lühidus !11_S	et	f	\N
191606	lühidus	"lühidus %lühi  )US_aS  <lühike ;12_A	et	f	\N
191607	jagrattaga	?jagrattaga =jagratta  (SgKom  >jagratta !01_S	et	f	\N
191614	vihtisin	?vihtisin =vihti  (IndIpfSg1  >vihtima !28_V	et	f	\N
191615	vihtisin	?vihtisin =vihtisin  (SgN  >vihtisin !19_S	et	f	\N
191636	india	?india =india  (SgN  >india !01_S	et	f	\N
191637	india	?india =india  (SgG  >india !01_S	et	f	\N
191641	kaaselanigutega	### kaaselanigutega	et	f	\N
191664	londonilt	?londonilt =londoni  (SgAbl  >london !02_S	et	f	\N
191690	sõitasime	?sõitasime =sõita  (IndIpfPl1  >sõitama !27_V	et	f	\N
191696	pinkil	### pinkil	et	f	\N
191697	jazz	### jazz	et	f	\N
191704	mmh	### mmh	et	f	\N
191707	väljus	väljus =välju  (PlIn  >väli !24_S	et	f	\N
191708	väljus	väljus =välju  (IndIpfSg3  >väljuma !27_V	et	f	\N
191714	nägeminel	?nägeminel =nägemine  (PlAd  >nägemin !19_S	et	f	\N
191757	30juuli	juuli =juuli  (SgN  >juuli !16_S	et	f	\N
191758	30juuli	juuli =juuli  (SgG  >juuli !16_S	et	f	\N
191772	mitternachtsessen	?mitternachtsessen =mitternachtsessen  (SgN  >mitternachtsessen !02_S	et	f	\N
191773	makarooni	?makarooni =makaroo  (SgTer  >makaroo !26_S	et	f	\N
191774	makarooni	?makarooni =makarooni  (SgN  >makarooni !16_S	et	f	\N
191775	makarooni	?makarooni =makarooni  (SgG  >makarooni !16_S	et	f	\N
191776	makarooni	?makarooni =makarooni  (SgG  >makaroon !22_S	et	f	\N
191777	makarooni	?makarooni =makarooni  (SgP  >makaroon !22_S	et	f	\N
191778	makarooni	?makarooni =makarooni  (SgAdt  >makaroon !22_S	et	f	\N
191779	makarooni	?makarooni =makarooni  (IndPrPs_  >makaroonima !28_V	et	f	\N
191780	makarooni	?makarooni =makarooni  (ImpPrSg2  >makaroonima !28_V	et	f	\N
191797	montrealisse	?montrealisse =montreali  (SgIll  >montreali !16_S	et	f	\N
191798	montrealisse	?montrealisse =montreali  (SgIll  >montreal !19_S	et	f	\N
191799	montrealisse	?montrealisse =montrealis  (SgAdt  >montrealine !12_A	et	f	\N
191800	montrealisse	?montrealisse =montrealisse  (SgG  >montrealisne !02_A	et	f	\N
191801	montrealisse	?montrealisse =montrealisse  (PlP  >montrealiss !22_S	et	f	\N
191807	royali	?royali =royali  (SgN  >royali !01_S	et	f	\N
191808	royali	?royali =royali  (SgG  >royali !01_S	et	f	\N
191809	royali	?royali =royali  (SgG  >royal !02_S	et	f	\N
191810	royali	?royali =royali  (IndPrPs_  >royalima !28_V	et	f	\N
191811	royali	?royali =royali  (ImpPrSg2  >royalima !28_V	et	f	\N
191816	saapusime	?saapusime =saapu  (IndIpfPl1  >saapuma !27_V	et	f	\N
191827	leidsi	?leidsi =leidsi  (ID  >leidsi !41_D	et	f	\N
191828	leidsi	?leidsi =leidsi  (SgG  >leids !22_S	et	f	\N
191829	leidsi	?leidsi =leidsi  (SgP  >leids !22_S	et	f	\N
191830	leidsi	?leidsi =leidsi  (SgAdt  >leids !22_S	et	f	\N
191831	leidsi	?leidsi =leidsi  (IndPrPs_  >leidsima !28_V	et	f	\N
191832	leidsi	?leidsi =leidsi  (ImpPrSg2  >leidsima !28_V	et	f	\N
191835	sõitsi	?sõitsi =sõitsi  (ID  >sõitsi !41_D	et	f	\N
191836	sõitsi	?sõitsi =sõitsi  (SgG  >sõits !22_S	et	f	\N
191837	sõitsi	?sõitsi =sõitsi  (SgP  >sõits !22_S	et	f	\N
191838	sõitsi	?sõitsi =sõitsi  (SgAdt  >sõits !22_S	et	f	\N
191839	sõitsi	?sõitsi =sõitsi  (IndPrPs_  >sõitsima !28_V	et	f	\N
191840	sõitsi	?sõitsi =sõitsi  (ImpPrSg2  >sõitsima !28_V	et	f	\N
191847	magogisse	?magogisse =magogi  (SgIll  >magog !02_S	et	f	\N
191848	magogisse	?magogisse =magogis  (SgAdt  >magogis !11_S	et	f	\N
191849	magogisse	?magogisse =magogisse  (SgG  >magogisne !02_A	et	f	\N
191850	magogisse	?magogisse =magogisse  (PlP  >magogiss !22_S	et	f	\N
191859	stansteadis	?stansteadis =stansteadi  (SgIn  >stansteadi !16_S	et	f	\N
191860	stansteadis	?stansteadis =stansteadi  (SgIn  >stansteat !22_S	et	f	\N
191861	stansteadis	?stansteadis =stansteadi  (IndIpfSg3  >stansteadima !28_V	et	f	\N
191862	stansteadis	?stansteadis =stansteadis  (SgN  >stansteadis !09_S	et	f	\N
191882	jääsi	?jääsi =jääsi  (SgN  >jääsi !16_S	et	f	\N
191883	jääsi	?jääsi =jääsi  (SgG  >jääsi !16_S	et	f	\N
191884	jääsi	?jääsi =jääsi  (SgG  >jääs !22_S	et	f	\N
191885	jääsi	?jääsi =jääsi  (SgP  >jääs !22_S	et	f	\N
191886	jääsi	?jääsi =jääsi  (SgAdt  >jääs !22_S	et	f	\N
191887	jääsi	?jääsi =jääsi  (IndPrPs_  >jääsima !28_V	et	f	\N
191888	jääsi	?jääsi =jääsi  (ImpPrSg2  >jääsima !28_V	et	f	\N
191891	salati	salati =sala  (IndIpfIps  >salgama !29_V	et	f	\N
191892	salati	salati =salati  (SgG  >salat !02_S	et	f	\N
191900	tulesime	### tulesime	et	f	\N
191903	canadian	?canadian =canadian  (SgN  >canadian !19_S	et	f	\N
191913	syrup	?syrup =syrup  (SgN  >syrup !02_S	et	f	\N
191923	dogi	dogi =dogi  (SgN  >dogi !17_S	et	f	\N
191924	dogi	dogi =dogi  (SgG  >dogi !17_S	et	f	\N
191925	dogi	dogi =dogi  (SgP  >dogi !17_S	et	f	\N
191926	dogi	dogi =do  (SgN^  >do !26_S	et	f	\N
191927	dogi	dogi =do  (SgG^  >do !26_S	et	f	\N
191940	töötasi	?töötasi =töötasi  (ID  >töötasi !41_D	et	f	\N
191941	töötasi	?töötasi =töötasi  (PlP  >töötane !12_A	et	f	\N
191942	töötasi	?töötasi =tasi  (SgN  >töö+tasi !17_S	et	f	\N
191711	lancesterisse	?lancesterisse =lancesterisse  (PlP  >lancesteriss !22_S	et	f	\N
191712	lancesteris	?lancesteris =lancesteri  (SgIn  >lancester !02_S	et	f	\N
191713	lancesteris	?lancesteris =lancesteris  (SgN  >lancesteris !09_S	et	f	\N
191715	makaroni	makaroni =makaroni  (SgG  >makaron !19_S	et	f	\N
191716	makaroni	makaroni =makaroni  (SgP  >makaron !19_S	et	f	\N
191717	makaroni	makaroni =makaroni  (SgAdt  >makaron !19_S	et	f	\N
191730	päikesepiste	päikesepiste =piste  (SgN  >päikese+piste !06_S	et	f	\N
191731	päikesepiste	päikesepiste =piste  (SgG  >päikese+piste !06_S	et	f	\N
191732	röstpidu	?röstpidu =röstpidu  (SgN  >röstpidu !01_S	et	f	\N
191733	röstpidu	?röstpidu =röstpidu  (SgG  >röstpidu !01_S	et	f	\N
191734	röstpidu	?röstpidu =röstpidu  (IndPrPs_  >röstpiduma !27_V	et	f	\N
191735	röstpidu	?röstpidu =röstpidu  (ImpPrSg2  >röstpiduma !27_V	et	f	\N
191742	29juuli	juuli =juuli  (SgN  >juuli !16_S	et	f	\N
191743	29juuli	juuli =juuli  (SgG  >juuli !16_S	et	f	\N
191745	kovhikusse	?kovhikusse =kovhiku  (SgIll  >kovhiku !01_S	et	f	\N
191746	kovhikusse	?kovhikusse =kovhiku  (SgIll  >kovhik !02_S	et	f	\N
191747	kovhikusse	?kovhikusse =kovhikus  (SgAdt  >kovhikus !11_S	et	f	\N
191748	kovhikusse	?kovhikusse =kovhikusse  (SgG  >kovhikusne !02_A	et	f	\N
191749	kovhikusse	?kovhikusse =kovhikusse  (PlP  >kovhikuss !22_S	et	f	\N
191751	koogi	koogi =koogi  (SgG  >kook !22_S	et	f	\N
191752	koogi	koogi =koogi  (IndPrPs_  >kookima !28_V	et	f	\N
191753	koogi	koogi =koogi  (ImpPrSg2  >kookima !28_V	et	f	\N
191754	koogi	koogi =koo  (SgG^  >kubu !18_S	et	f	\N
191755	koogi	koogi =koo  (IndPrPs_^  >kuduma !28_V	et	f	\N
191756	koogi	koogi =koo  (ImpPrSg2^  >kuduma !28_V	et	f	\N
191760	fahrt	?fahrt =fahrt  (SgN  >fahrt !22_S	et	f	\N
191769	kesköösöökein	?kesköösöökein =kesköösöökein  (SgN  >kesköösöökein !19_S	et	f	\N
191770	kesköösöökein	?kesköösöökein =söökein  (SgN  >kesk+öö+söökein !22_S	et	f	\N
191771	kesköösöökein	?kesköösöökein =öösöökein  (SgN  >kesk+öösöökein !19_S	et	f	\N
191783	kölni	?kölni =kölni  (SgN  >kölni !16_S	et	f	\N
191784	kölni	?kölni =kölni  (SgG  >kölni !16_S	et	f	\N
191785	kölni	?kölni =kölni  (SgG  >köln !22_S	et	f	\N
191786	kölni	?kölni =kölni  (SgP  >köln !22_S	et	f	\N
191787	kölni	?kölni =kölni  (SgAdt  >köln !22_S	et	f	\N
191788	kölni	?kölni =kölni  (IndPrPs_  >kölnima !28_V	et	f	\N
191789	kölni	?kölni =kölni  (ImpPrSg2  >kölnima !28_V	et	f	\N
191806	mont	?mont =mont  (SgN  >mont !22_S	et	f	\N
191833	ärkasi	?ärkasi =ärkasi  (ID  >ärkasi !41_D	et	f	\N
191834	ärkasi	?ärkasi =ärkasi  (PlP  >ärkane !12_A	et	f	\N
191855	seejäral	?seejäral =seejära  (SgAd  >seejära !01_S	et	f	\N
191856	seejäral	?seejäral =seejäral  (SgN  >seejäral !19_S	et	f	\N
191857	seejäral	?seejäral =jära  (SgAd  >see+jära !17_S	et	f	\N
191858	seejäral	?seejäral =järal  (SgN  >see+järal !02_S	et	f	\N
191863	kävin	?kävin =kävi  (IndPrSg1  >kävima !27_V	et	f	\N
191864	kävin	?kävin =kävin  (SgN  >kävin !02_S	et	f	\N
191889	kanapraadi	kanapraadi =praadi  (SgP  >kana+praad !22_S	et	f	\N
191890	kanapraadi	kanapraadi =praadi  (SgAdt  >kana+praad !22_S	et	f	\N
191910	maple	?maple =maple  (SgN  >maple !06_S	et	f	\N
191911	maple	?maple =maple  (IndPrPs_  >maplema !30_V	et	f	\N
191912	maple	?maple =maple  (ImpPrSg2  >maplema !30_V	et	f	\N
191920	tulisime	?tulisime =tuli  (IndIpfPl1  >tulima !27_V	et	f	\N
191934	käiksi	?käiksi =käiksi  (ID  >käiksi !41_D	et	f	\N
191935	käiksi	?käiksi =käiksi  (SgG  >käiks !22_S	et	f	\N
191936	käiksi	?käiksi =käiksi  (SgP  >käiks !22_S	et	f	\N
191937	käiksi	?käiksi =käiksi  (SgAdt  >käiks !22_S	et	f	\N
191938	käiksi	?käiksi =käiksi  (IndPrPs_  >käiksima !28_V	et	f	\N
191939	käiksi	?käiksi =käiksi  (ImpPrSg2  >käiksima !28_V	et	f	\N
191986	jessies	?jessies =jessie  (SgIn  >jessie !01_S	et	f	\N
191987	jessies	?jessies =jessies  (SgN  >jessies !11_S	et	f	\N
191988	maitsevaga	maitsevaga =maitseva  (SgKom  >maitsev !02_A	et	f	\N
191989	maitsevaga	"maitsev %maits  )V_vA  <maitsma ;32_V	et	f	\N
191990	maitsevaga	"maitsev %maitse  )V_vA  <maitsema ;28_V	et	f	\N
191991	maitsevaga	maitsevaga =vaga  (SgN  >maitse+vaga !17_A	et	f	\N
191992	maitsevaga	maitsevaga =vaga  (SgG  >maitse+vaga !17_A	et	f	\N
191993	maitsevaga	maitsevaga =vaga  (SgP  >maitse+vaga !17_A	et	f	\N
191994	eastern	?eastern =eastern  (SgN  >eastern !22_S	et	f	\N
191995	eastern	?eastern =stern  (SgN  >ea+stern !22_S	et	f	\N
192000	ida-kanada	?ida-kanada =kana  (Inf  >ida-kanama !27_V	et	f	\N
192024	cityguesthousesse	?cityguesthousesse =cityguesthouse  (PlIll  >cityguesthous !22_S	et	f	\N
192025	cityguesthousesse	?cityguesthousesse =cityguesthouses  (SgAdt  >cityguesthousene !12_A	et	f	\N
192026	cityguesthousesse	?cityguesthousesse =cityguesthousesse  (SgG  >cityguesthousesne !02_A	et	f	\N
192027	cityguesthousesse	?cityguesthousesse =cityguesthousesse  (PlP  >cityguesthousess !22_S	et	f	\N
192058	lounasöök	?lounasöök =lounasöök  (SgN  >lounasöök !22_S	et	f	\N
192064	supplinna	?supplinna =supplinna  (SgN  >supplinna !16_S	et	f	\N
192065	supplinna	?supplinna =supplinna  (SgG  >supplinna !16_S	et	f	\N
191759	sõitjaoksfür	?sõitjaoksfür =sõitjaoksfür  (SgN  >sõitjaoksfür !19_S	et	f	\N
191763	districtisse	?districtisse =districti  (SgIll  >districti !01_S	et	f	\N
191764	districtisse	?districtisse =districti  (SgIll  >district !22_S	et	f	\N
191765	districtisse	?districtisse =districtis  (SgAdt  >districtis !11_S	et	f	\N
191766	districtisse	?districtisse =districtisse  (SgG  >districtisne !02_A	et	f	\N
191767	districtisse	?districtisse =districtisse  (PlP  >districtiss !22_S	et	f	\N
191781	inglisemaal	inglisemaal =maa  (SgAd  >inglise+maa !26_S	et	f	\N
191782	inglisemaal	inglisemaal =maal  (SgN  >inglise+maal !22_S	et	f	\N
191790	ootasi	?ootasi =ootasi  (ID  >ootasi !41_D	et	f	\N
191791	ootasi	?ootasi =ootasi  (PlP  >ootane !12_A	et	f	\N
191802	turismisibaas	?turismisibaas =turismisibaa  (SgIn  >turismisibaa !26_S	et	f	\N
191803	turismisibaas	?turismisibaas =turismisibaas  (SgN  >turismisibaas !22_S	et	f	\N
191804	turismisibaas	?turismisibaas =sibaa  (SgIn  >turismi+sibaa !26_S	et	f	\N
191805	turismisibaas	?turismisibaas =sibaas  (SgN  >turismi+sibaas !22_S	et	f	\N
191821	royalil	?royalil =royali  (SgAd  >royali !01_S	et	f	\N
191822	royalil	?royalil =royali  (SgAd  >royal !02_S	et	f	\N
191841	north	?north =north  (SgN  >north !22_S	et	f	\N
191842	bayle	?bayle =bayle  (SgN  >bayle !06_S	et	f	\N
191843	bayle	?bayle =bayle  (SgG  >bayle !06_S	et	f	\N
191844	bayle	?bayle =bayle  (PlP  >bayl !22_S	et	f	\N
191845	bayle	?bayle =bayle  (IndPrPs_  >baylema !27_V	et	f	\N
191846	bayle	?bayle =bayle  (ImpPrSg2  >baylema !27_V	et	f	\N
191851	võõrustajad	võõrustajad =võõrustaja  (PlN  >võõrustaja !01_S	et	f	\N
191852	võõrustajad	"võõrustaja %võõrusta  )JA_vS  <võõrustama ;27_V	et	f	\N
191872	stansteadist	?stansteadist =stansteadi  (SgEl  >stansteadi !16_S	et	f	\N
191873	stansteadist	?stansteadist =stansteadi  (SgEl  >stansteat !22_S	et	f	\N
191874	stansteadist	?stansteadist =stansteadis  (SgP  >stansteadis !09_S	et	f	\N
191875	stansteadist	?stansteadist =stansteadist  (SgN  >stansteadist !22_S	et	f	\N
191879	t-särki	t-särki =särki  (SgP  >t-särk !22_S	et	f	\N
191880	t-särki	t-särki =särki  (SgAdt  >t-särk !22_S	et	f	\N
191906	pankooki	?pankooki =pankooki  (SgN  >pankooki !16_S	et	f	\N
191907	pankooki	?pankooki =pankooki  (SgG  >pankooki !16_S	et	f	\N
191908	pankooki	?pankooki =pankooki  (SgP  >pankook !22_S	et	f	\N
191909	pankooki	?pankooki =pankooki  (SgAdt  >pankook !22_S	et	f	\N
191919	automaatikaga	automaatikaga =automaatika  (SgKom  >automaatika !01_S	et	f	\N
191921	automaatikaga	automaatikaga =tika  (SgKom  >auto+maa+tikk !22_S	et	f	\N
192001	quebec	### quebec	et	f	\N
192004	château	### château	et	f	\N
192010	turismisbaasisse	?turismisbaasisse =turismisbaasi  (SgIll  >turismisbaasi !16_S	et	f	\N
192011	turismisbaasisse	?turismisbaasisse =turismisbaasi  (SgIll  >turismisbaas !22_S	et	f	\N
192012	turismisbaasisse	?turismisbaasisse =turismisbaasisse  (SgG  >turismisbaasisne !02_A	et	f	\N
192013	turismisbaasisse	?turismisbaasisse =turismisbaasisse  (PlP  >turismisbaasiss !22_S	et	f	\N
192015	berlinisse	?berlinisse =berlini  (SgIll  >berlin !02_S	et	f	\N
192016	berlinisse	?berlinisse =berlinis  (SgAdt  >berlinis !11_S	et	f	\N
192017	berlinisse	?berlinisse =berlinisse  (SgG  >berlinisne !02_A	et	f	\N
192018	berlinisse	?berlinisse =berlinisse  (PlP  >berliniss !22_S	et	f	\N
192046	rööm	?rööm =rööm  (SgN  >rööm !22_S	et	f	\N
192054	pahkla	?pahkla =pahkla  (SgN  >pahkla !01_S	et	f	\N
192055	pahkla	?pahkla =pahkla  (SgG  >pahkla !01_S	et	f	\N
192056	pahkla	?pahkla =pahkla  (IndPrPs_  >pahklama !29_V	et	f	\N
192057	pahkla	?pahkla =pahkla  (ImpPrSg2  >pahklama !29_V	et	f	\N
192063	päikepaiste	?päikepaiste =päikepaiste  (PlP  >päikepaist !22_S	et	f	\N
192111	lemmiklaule	lemmiklaule =lau  (SgAll  >lemmik+laug !22_SA	et	f	\N
192112	lemmiklaule	lemmiklaule =laule  (PlP  >lemmik+laul !22_S	et	f	\N
192127	lõtspill	?lõtspill =lõtspill  (SgN  >lõtspill !22_S	et	f	\N
192128	laulurahvasid	?laulurahvasid =laulurahva  (PlP  >laulurahva !16_S	et	f	\N
192129	laulurahvasid	?laulurahvasid =rahva  (PlP  >laulu+rahva !16_S	et	f	\N
192130	naiskoore	naiskoore =koore  (SgG  >nais+koor !13_S	et	f	\N
192131	naiskoore	naiskoore =koore  (PlP  >nais+koor !22_S	et	f	\N
192136	ettekandele	ettekandele =kande  (SgAll  >ette+kanne !06_S	et	f	\N
192137	ettekandele	ettekandele =kande  (PlAll  >ette+kant !22_S	et	f	\N
192141	enem	?enem =enem  (SgN  >enem !02_A	et	f	\N
192160	päevaseni	päevaseni =päevase  (SgTer  >päevane !10_A	et	f	\N
192161	päevaseni	"päevane %päeva  )NE_aA  <päev ;22_S	et	f	\N
192162	lauld	?lauld =lauld  (SgN  >lauld !22_S	et	f	\N
192185	versiooni	versiooni =versiooni  (SgG  >versioon !22_S	et	f	\N
192186	versiooni	versiooni =versiooni  (SgP  >versioon !22_S	et	f	\N
192187	versiooni	versiooni =versiooni  (SgAdt  >versioon !22_S	et	f	\N
192190	rahvuspidudeks	rahvuspidudeks =pidu  (PlTr  >rahvus+pidu !17_S	et	f	\N
192191	rahvuspidudeks	rahvuspidudeks =pidu  (PlTr  >rahvus+pidu !18_S	et	f	\N
192200	tratsiooniks	?tratsiooniks =tratsiooni  (SgTr  >tratsiooni !16_S	et	f	\N
192201	tratsiooniks	?tratsiooniks =tratsiooni  (SgTr  >tratsioon !22_S	et	f	\N
192202	tratsiooniks	?tratsiooniks =tratsiooni  (KndPrPs  >tratsioonima !28_V	et	f	\N
192216	sünnitust	sünnitust =sünnitu  (SgEl  >sünnitu !01_AS	et	f	\N
191922	hot	### hot	et	f	\N
191928	elaksi	?elaksi =elaksi  (SgN  >elaksi !01_S	et	f	\N
191929	elaksi	?elaksi =elaksi  (SgG  >elaksi !01_S	et	f	\N
191930	elaksi	?elaksi =elaksi  (IndPrPs_  >elaksima !28_V	et	f	\N
191931	elaksi	?elaksi =elaksi  (ImpPrSg2  >elaksima !28_V	et	f	\N
191945	televiisioni	?televiisioni =televiisio  (SgTer  >televiisio !01_S	et	f	\N
191946	televiisioni	?televiisioni =televiisioni  (SgN  >televiisioni !16_S	et	f	\N
191947	televiisioni	?televiisioni =televiisioni  (SgG  >televiision !19~02_S	et	f	\N
191948	televiisioni	?televiisioni =televiisioni  (SgG  >televiisioni !16_S	et	f	\N
191949	televiisioni	?televiisioni =televiisioni  (SgP  >televiision !19_S	et	f	\N
191950	televiisioni	?televiisioni =televiisioni  (SgAdt  >televiision !19_S	et	f	\N
191951	televiisioni	?televiisioni =televiisioni  (IndPrPs_  >televiisionima !28_V	et	f	\N
191952	televiisioni	?televiisioni =televiisioni  (ImpPrSg2  >televiisionima !28_V	et	f	\N
191953	televiisioni	?televiisioni =oni  (SgN  >tele+viisi+oni !17_S	et	f	\N
191954	televiisioni	?televiisioni =oni  (SgG  >tele+viisi+oni !17_S	et	f	\N
191955	televiisioni	?televiisioni =oni  (SgP  >tele+viisi+oni !17_S	et	f	\N
191956	televiisioni	?televiisioni =io  (SgTer  >tele+viis+io !26_S	et	f	\N
191957	televiisioni	?televiisioni =ioni  (SgN  >tele+viis+ioni !16_S	et	f	\N
191958	televiisioni	?televiisioni =ioni  (SgG  >tele+viis+ioni !16_S	et	f	\N
191959	televiisioni	?televiisioni =ioni  (SgG  >tele+viis+ion !22_S	et	f	\N
191960	televiisioni	?televiisioni =ioni  (SgP  >tele+viis+ion !22_S	et	f	\N
191961	televiisioni	?televiisioni =ioni  (SgAdt  >tele+viis+ion !22_S	et	f	\N
191962	televiisioni	?televiisioni =viisio  (SgTer  >tele+viisio !01_S	et	f	\N
191963	televiisioni	?televiisioni =viisioni  (SgN  >tele+viisioni !16_S	et	f	\N
191964	televiisioni	?televiisioni =viisioni  (SgG  >tele+viision !19~02_S	et	f	\N
191965	televiisioni	?televiisioni =viisioni  (SgG  >tele+viisioni !16_S	et	f	\N
191966	televiisioni	?televiisioni =viisioni  (SgP  >tele+viision !19_S	et	f	\N
191967	televiisioni	?televiisioni =viisioni  (SgAdt  >tele+viision !19_S	et	f	\N
191981	räägisime	?räägisime =räägi  (IndIpfPl1  >räägima !28_V	et	f	\N
192006	poedega	?poedega =poe  (PlKom  >poe !26_S	et	f	\N
192019	ärevil	ärevil =ärevi  (SgAd  >ärev !02_A	et	f	\N
192020	ärevil	ärevil =ärevil  (ID  >ärevil !41_DA	et	f	\N
192021	maandusis	maandusis =maandusi  (PlIn  >maandus !11_S	et	f	\N
192022	maandusis	"maandus %maanda  )US_vS  <maandama ;27_V	et	f	\N
192023	õnelik	?õnelik =õnelik  (SgN  >õnelik !25_A	et	f	\N
192037	rautejaam	?rautejaam =rautejaam  (SgN  >rautejaam !22_S	et	f	\N
192047	kestsis	?kestsis =kestsi  (SgIn  >kests !22_S	et	f	\N
192048	kestsis	?kestsis =kestsi  (IndIpfSg3  >kestsima !28_V	et	f	\N
192049	kestsis	?kestsis =kestsis  (SgN  >kestsis !09_S	et	f	\N
192050	joudsime	?joudsime =joudsi  (IndPrPl1  >joudsima !28_V	et	f	\N
192070	check-in	### check-in	et	f	\N
192077	neljakümmend	?neljakümmend =neljakümmend  (SgN  >neljakümmend !22_S	et	f	\N
192100	koostneb	?koostneb =koostne  (IndPrSg3  >koostnema !27_V	et	f	\N
192103	pulmapidu	pulmapidu =pidu  (SgN  >pulma+pidu !17_S	et	f	\N
192104	pulmapidu	pulmapidu =pidu  (SgN  >pulma+pidu !18_S	et	f	\N
192105	pulmapidu	pulmapidu =pidu  (SgG  >pulma+pidu !17_S	et	f	\N
192106	pulmapidu	pulmapidu =pidu  (SgP  >pulma+pidu !17_S	et	f	\N
192107	pulmapidu	pulmapidu =pidu  (SgP  >pulma+pidu !18_S	et	f	\N
192115	levimist	levimist =levimis  (SgP  >levimine !12_S	et	f	\N
192116	levimist	"levimine %levi  )MINE_vS  <levima ;27_V	et	f	\N
192123	käsitööid	?käsitööid =käsitööi  (PlN  >käsitööi !26_S	et	f	\N
192124	käsitööid	?käsitööid =käsitööi  (SgP  >käsitööi !26_S	et	f	\N
192125	käsitööid	?käsitööid =käsitööid  (SgN  >käsitööid !22_S	et	f	\N
192126	käsitööid	?käsitööid =tööid  (SgN  >käsi+tööid !02_S	et	f	\N
192132	poistekoore	poistekoore =koore  (SgG  >poiste+koor !13_S	et	f	\N
192134	poistekoore	poistekoore =koore  (PlP  >poiste+koor !22_S	et	f	\N
192138	läänemeresoomest	läänemeresoomest =mest  (SgN  >lääne+mere+soo+mest !22_S	et	f	\N
192139	läänemeresoomest	läänemeresoomest =oome  (PlEl  >lääne+meres+oom !22_S	et	f	\N
192148	peoses	?peoses =peose  (SgIn  >peose !06_S	et	f	\N
192149	peoses	?peoses =peose  (IndIpfSg3  >peosema !28_V	et	f	\N
192150	peoses	?peoses =peoses  (SgN  >peoses !09_S	et	f	\N
192165	kultuuriidentiteedi	?kultuuriidentiteedi =kultuuriidentiteedi  (SgN  >kultuuriidentiteedi !16_S	et	f	\N
192166	kultuuriidentiteedi	?kultuuriidentiteedi =kultuuriidentiteedi  (SgG  >kultuuriidentiteedi !16_S	et	f	\N
192167	kultuuriidentiteedi	?kultuuriidentiteedi =kultuuriidentiteedi  (SgG  >kultuuriidentiteet !22_S	et	f	\N
192168	kultuuriidentiteedi	?kultuuriidentiteedi =kultuuriidentiteedi  (SgP  >kultuuriidentiteed !22_S	et	f	\N
192169	kultuuriidentiteedi	?kultuuriidentiteedi =kultuuriidentiteedi  (SgAdt  >kultuuriidentiteed !22_S	et	f	\N
192170	kultuuriidentiteedi	?kultuuriidentiteedi =kultuuriidentiteedi  (IndPrPs_  >kultuuriidentiteetima !28_V	et	f	\N
192171	kultuuriidentiteedi	?kultuuriidentiteedi =kultuuriidentiteedi  (ImpPrSg2  >kultuuriidentiteetima !28_V	et	f	\N
192172	kultuuriidentiteedi	?kultuuriidentiteedi =identiteedi  (SgN  >kultuuri+identiteedi !16_S	et	f	\N
192173	kultuuriidentiteedi	?kultuuriidentiteedi =identiteedi  (SgG  >kultuuri+identiteedi !16_S	et	f	\N
192174	kultuuriidentiteedi	?kultuuriidentiteedi =identiteedi  (SgG  >kultuuri+identiteet !22_S	et	f	\N
191943	töötasi	?töötasi =tasi  (SgG  >töö+tasi !17_S	et	f	\N
191944	töötasi	?töötasi =tasi  (SgP  >töö+tasi !17_S	et	f	\N
191968	televiisionis	?televiisionis =televiisioni  (SgIn  >televiision !19~02_S	et	f	\N
191969	televiisionis	?televiisionis =televiisioni  (SgIn  >televiisioni !16_S	et	f	\N
191970	televiisionis	?televiisionis =televiisioni  (IndIpfSg3  >televiisionima !28_V	et	f	\N
191971	televiisionis	?televiisionis =televiisionis  (SgN  >televiisionis !09_S	et	f	\N
191972	televiisionis	?televiisionis =oni  (SgIn  >tele+viisi+oni !17_S	et	f	\N
191973	televiisionis	?televiisionis =onis  (SgN  >tele+viisi+onis !09_S	et	f	\N
191974	televiisionis	?televiisionis =ioni  (SgIn  >tele+viis+ioni !16_S	et	f	\N
191975	televiisionis	?televiisionis =ioni  (SgIn  >tele+viis+ion !22_S	et	f	\N
191976	televiisionis	?televiisionis =ionis  (SgN  >tele+viis+ionis !09_S	et	f	\N
191977	televiisionis	?televiisionis =viisioni  (SgIn  >tele+viision !19~02_S	et	f	\N
191978	televiisionis	?televiisionis =viisioni  (SgIn  >tele+viisioni !16_S	et	f	\N
191979	televiisionis	?televiisionis =viisionis  (SgN  >tele+viisionis !09_S	et	f	\N
191980	hip-hop	### hip-hop	et	f	\N
191982	viimeine	?viimeine =viimeine  (SgN  >viimeine !12~10_A	et	f	\N
191983	viimeine	?viimeine =viimeine  (PlP  >viimein !22_S	et	f	\N
191984	viimeine	?viimeine =viimeine  (IndPrPs_  >viimeinema !27_V	et	f	\N
191985	viimeine	?viimeine =viimeine  (ImpPrSg2  >viimeinema !27_V	et	f	\N
191996	townshipis	?townshipis =townshipi  (SgIn  >townshipi !01_S	et	f	\N
191997	townshipis	?townshipis =townshipi  (SgIn  >township !02_S	et	f	\N
191998	townshipis	?townshipis =townshipi  (SgIn  >townshipp !22_S	et	f	\N
191999	townshipis	?townshipis =townshipis  (SgN  >townshipis !11_S	et	f	\N
192005	frontenac	### frontenac	et	f	\N
192007	cd-plaati	cd-plaati =plaati  (SgP  >cd-plaat !22_S	et	f	\N
192008	cd-plaati	cd-plaati =plaati  (SgAdt  >cd-plaat !22_S	et	f	\N
192014	lennukjaam	?lennukjaam =lennukjaam  (SgN  >lennukjaam !22_S	et	f	\N
192038	kadusis	?kadusis =kadusi  (SgIn  >kadus !02_A	et	f	\N
192039	kadusis	?kadusis =kadusis  (SgN  >kadusis !11_S	et	f	\N
192051	pahklas	?pahklas =pahkla  (SgIn  >pahkla !01_S	et	f	\N
192052	pahklas	?pahklas =pahkla  (IndIpfSg3  >pahklama !29_V	et	f	\N
192053	pahklas	?pahklas =pahklas  (SgN  >pahklas !07_S	et	f	\N
192059	purjetamisadam	?purjetamisadam =purjetamisadam  (SgN  >purjetamisadam !02_A	et	f	\N
192060	purjetamisadam	?purjetamisadam =adam  (SgN  >purjetamis+adam !02_A	et	f	\N
192061	purjetamisadam	?purjetamisadam =tamisadam  (SgN  >purje+tamisadam !02_A	et	f	\N
192075	leedule	leedule =leedu  (SgAll  >leedu !16_S	et	f	\N
192076	leedule	"leedu %lee  )TU1_vS  <leema ;37_V	et	f	\N
192085	kurgi	kurgi =kurgi  (SgG  >kurk !22_S	et	f	\N
192086	kurgi	kurgi =kurgi  (SgP  >kurg !22_S	et	f	\N
192087	kurgi	kurgi =kurgi  (SgAdt  >kurg !22_S	et	f	\N
192088	kurgi	kurgi =kurgi  (PlP  >kurg !22_S	et	f	\N
192101	tansust	?tansust =tansu  (SgEl  >tansu !16_S	et	f	\N
192102	tansust	?tansust =tansus  (SgP  >tansus !11~09_S	et	f	\N
192108	kuulavat	kuulavat =kuula  (KvtPrPs  >kuulama !29_V	et	f	\N
192109	kuulavat	kuulavat =kuulava  (SgP  >kuulav !02_A	et	f	\N
192110	kuulavat	"kuulav %kuula  )V_vA  <kuulama ;29_V	et	f	\N
192113	levimine	levimine =levimine  (SgN  >levimine !12_S	et	f	\N
192114	levimine	"levimine %levi  )MINE_vS  <levima ;27_V	et	f	\N
192140	tansulise	?tansulise =tansulise  (SgG  >tansuline !12_A	et	f	\N
192145	mängijag	### mängijag	et	f	\N
192146	tunnustamine	tunnustamine =tunnustamine  (SgN  >tunnustamine !12_S	et	f	\N
192147	tunnustamine	"tunnustamine %tunnusta  )MINE_vS  <tunnustama ;27_V	et	f	\N
192152	kavvale	?kavvale =kavva  (SgAll  >kavva !16_S	et	f	\N
192153	kavvale	?kavvale =kavvale  (IndPrPs_  >kavvalema !27_V	et	f	\N
192154	kavvale	?kavvale =kavvale  (ImpPrSg2  >kavvalema !27_V	et	f	\N
192156	hoijanud	?hoijanud =hoija  (PtsPtPs  >hoijama !29_V	et	f	\N
192157	hoijanud	?hoijanud =hoijanu  (PlN  >hoijanu !01_S	et	f	\N
192158	hoijanud	?hoijanud =hoijanu  (IndPrSg2  >hoijanuma !27_V	et	f	\N
192159	hoijanud	?hoijanud =hoijanud  (ID  >hoijanud !41_A	et	f	\N
192182	kihistust	kihistust =kihistu  (SgEl  >kihistu !01_S	et	f	\N
192183	kihistust	kihistust =kihistus  (SgP  >kihistus !11_S	et	f	\N
192184	kihistust	"kihistus %kihista  )US_vS  <kihistama ;27_V	et	f	\N
192206	aegaga	### aegaga	et	f	\N
192209	lähedamaks	lähedamaks =lähedama  (SgTr  >lähedam !02_A	et	f	\N
192210	lähedamaks	"lähedam %läheda  )M_cA  <läheda ;02_A	et	f	\N
192211	hinget	?hinget =hinge  (SgP  >hinge !06_S	et	f	\N
192214	harjumustega	harjumustega =harjumus  (PlKom  >harjumus !11_S	et	f	\N
192215	harjumustega	"harjumus %harju  )MUS_vS  <harjuma ;27_V	et	f	\N
192225	samasugusi	?samasugusi =samasugusi  (PlP  >samasugus !11_S	et	f	\N
192226	samasugusi	?samasugusi =sugusi  (SgG  >sama+sugus !02_A	et	f	\N
192230	üritusele	üritusele =ürituse  (SgAll  >üritus !11_S	et	f	\N
192231	üritusele	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
192244	rahvades	?rahvades =rahva  (PlIn  >rahva !16_S	et	f	\N
192253	mooderni	?mooderni =mooderni  (SgN  >mooderni !01_S	et	f	\N
192254	mooderni	?mooderni =mooderni  (SgG  >mooderni !01_S	et	f	\N
192255	mooderni	?mooderni =mooderni  (SgG  >moodern !22_S	et	f	\N
192035	turgisse	?turgisse =turgisse  (SgG  >turgisne !02_A	et	f	\N
192036	turgisse	?turgisse =turgisse  (PlP  >turgiss !22_S	et	f	\N
192040	krahlis	?krahlis =krahli  (SgIn  >krahli !16_S	et	f	\N
192041	krahlis	?krahlis =krahli  (SgIn  >krahl !22_S	et	f	\N
192042	krahlis	?krahlis =krahli  (IndIpfSg3  >krahlima !28_V	et	f	\N
192043	krahlis	?krahlis =krahlis  (SgN  >krahlis !09_S	et	f	\N
192044	pahklasse	pahklasse =la  (SgIll  >pahk+la !26_S	et	f	\N
192045	pahklasse	pahklasse =lasse  (PlP  >pahk+lass !22_S	et	f	\N
192062	kaifisime	?kaifisime =kaifi  (IndIpfPl1  >kaifima !28_V	et	f	\N
192066	lennukjaamisse	?lennukjaamisse =lennukjaami  (SgIll  >lennukjaami !16_S	et	f	\N
192067	lennukjaamisse	?lennukjaamisse =lennukjaami  (SgIll  >lennukjaam !22_S	et	f	\N
192068	lennukjaamisse	?lennukjaamisse =lennukjaamisse  (SgG  >lennukjaamisne !02_A	et	f	\N
192069	lennukjaamisse	?lennukjaamisse =lennukjaamisse  (PlP  >lennukjaamiss !22_S	et	f	\N
192071	vilniusse	?vilniusse =vilniu  (SgIll  >vilniu !01_S	et	f	\N
192072	vilniusse	?vilniusse =vilnius  (SgAdt  >vilnius !11_S	et	f	\N
192073	vilniusse	?vilniusse =vilniusse  (SgG  >vilniusne !02_A	et	f	\N
192074	vilniusse	?vilniusse =vilniusse  (PlP  >vilniuss !22_S	et	f	\N
192078	vilnius	?vilnius =vilniu  (SgIn  >vilniu !01_S	et	f	\N
192079	vilnius	?vilnius =vilnius  (SgN  >vilnius !11_S	et	f	\N
192084	koristade	### koristade	et	f	\N
192089	päikepaisteline	?päikepaisteline =päikepaisteline  (SgN  >päikepaisteline !12_A	et	f	\N
192090	päikepaisteline	?päikepaisteline =päikepaisteline  (PlP  >päikepaistelin !19_S	et	f	\N
192095	kosutav	kosutav =kosu  (PtsPrIps  >kosuma !27_V	et	f	\N
192096	kosutav	kosutav =kosuta  (PtsPrPs  >kosutama !27_V	et	f	\N
192097	kosutav	kosutav =kosutav  (SgN  >kosutav !02_A	et	f	\N
192098	kosutav	"kosutav %kosu  )TAV_vAS  <kosuma ;27_V	et	f	\N
192099	kosutav	"kosutav %kosuta  )V_vA  <kosutama ;27_V	et	f	\N
192155	lastekoride	?lastekoride =lastekori  (PlG  >lastekor !19_S	et	f	\N
192163	emotsioonaalne	?emotsioonaalne =emotsioonaalne  (SgN  >emotsioonaalne !02_A	et	f	\N
192164	emotsioonaalne	?emotsioonaalne =emotsioonaalne  (PlP  >emotsioonaaln !22_S	et	f	\N
192188	töödeldut	töödeldut =töödeldu  (SgP  >töödeldu !01_S	et	f	\N
192189	töödeldut	"töödeldu %töödel  )TU1_vS  <töötlema ;30_V	et	f	\N
192203	südametes	südametes =südame  (PlIn  >süda !04_S	et	f	\N
192204	südametes	südametes =me  (PlIn  >süda+mesi !15_S	et	f	\N
192205	südametes	südametes =mete  (PlIn  >süda+mett !22_S	et	f	\N
192207	ühina	?ühina =ühi  (SgEs  >ühi !17_S	et	f	\N
192208	ühina	?ühina =ühina  (SgG  >ühin !02_S	et	f	\N
192227	nnad	### nnad	et	f	\N
192228	laulupidudes	laulupidudes =pidu  (PlIn  >laulu+pidu !17_S	et	f	\N
192229	laulupidudes	laulupidudes =pidu  (PlIn  >laulu+pidu !18_S	et	f	\N
192234	hõikusid	hõikusid =hõiku  (PlP  >hõik !22_S	et	f	\N
192235	hõikusid	hõikusid =hõiku  (IndIpfSg2  >hõikuma !28_V	et	f	\N
192236	hõikusid	hõikusid =hõiku  (IndIpfPl3  >hõikuma !28_V	et	f	\N
192248	vanalajal	?vanalajal =vanalaja  (SgAd  >vanalaja !01_S	et	f	\N
192249	vanalajal	?vanalajal =vanalaja  (SgAd  >vanalajas !02_A	et	f	\N
192250	vanalajal	?vanalajal =vanalajal  (SgN  >vanalajal !19_S	et	f	\N
192251	vanalajal	?vanalajal =laja  (SgAd  >vana+laja !17_S	et	f	\N
192252	vanalajal	?vanalajal =lajal  (SgN  >vana+lajal !02_S	et	f	\N
192271	antis	?antis =anti  (IndIpfSg3  >antima !28_V	et	f	\N
192272	antis	?antis =antis  (ID  >antis !41_DA	et	f	\N
192278	kuuskilt	kuuskilt =kuuski  (SgAbl  >kuusk !22_S	et	f	\N
192279	kuuskilt	kuuskilt =kilt  (SgN  >kuus+kilt !22_S	et	f	\N
192287	juttustasid	?juttustasid =juttusta  (IndIpfSg2  >juttustama !27_V	et	f	\N
192288	juttustasid	?juttustasid =juttusta  (IndIpfPl3  >juttustama !27_V	et	f	\N
192289	juttustasid	?juttustasid =stasi  (PlN  >juttu+stasi !17_S	et	f	\N
192290	juttustasid	?juttustasid =usta  (PlP  >jutt+usta !16_S	et	f	\N
192332	väljakülalistele	väljakülalistele =külalis  (PlAll  >välja+külaline !12_S	et	f	\N
192333	väljakülalistele	"välja+külaline %küla  )LINE_aA  <välja+küla ;17_S	et	f	\N
192353	põllumajunduse	?põllumajunduse =põllumajunduse  (SgG  >põllumajundus !11_S	et	f	\N
192354	põllumajunduse	?põllumajunduse =majunduse  (SgG  >põllu+majundus !11_S	et	f	\N
192365	juhtude	juhtude =juhtu  (PlG  >juht !22_S	et	f	\N
192366	juhtude	juhtude =ude  (SgN  >juht+ude !04_S	et	f	\N
192369	möödasid	?möödasid =mööda  (IndIpfSg2  >möödama !29_V	et	f	\N
192370	möödasid	?möödasid =mööda  (IndIpfPl3  >möödama !29_V	et	f	\N
192373	laulata	laulata =laulata  (IndPrPs_  >laulatama !27_V	et	f	\N
192374	laulata	laulata =laulata  (ImpPrSg2  >laulatama !27_V	et	f	\N
192375	laulata	laulata =la  (SgAb  >lau+la !26_S	et	f	\N
192377	põllumestena	?põllumestena =põllumes  (PlEs  >põllumene !12_A	et	f	\N
192378	põllumestena	?põllumestena =meste  (SgEs  >põllu+meste !16_S	et	f	\N
192382	pidudes	pidudes =pidu  (PlIn  >pidu !17_S	et	f	\N
192383	pidudes	pidudes =pidu  (PlIn  >pidu !18_S	et	f	\N
192410	spaani	?spaani =spaa  (SgTer  >spaa !26_S	et	f	\N
192411	spaani	?spaani =spaani  (SgN  >spaani !16_S	et	f	\N
192412	spaani	?spaani =spaani  (SgG  >spaani !16_S	et	f	\N
192413	spaani	?spaani =spaani  (SgG  >spaan !22_S	et	f	\N
192080	aedisse	?aedisse =aedi  (SgIll  >aedi !16_S	et	f	\N
192081	aedisse	?aedisse =aedi  (SgIll  >aet !22_S	et	f	\N
192082	aedisse	?aedisse =aedisse  (SgG  >aedisne !02_A	et	f	\N
192083	aedisse	?aedisse =aedisse  (PlP  >aediss !22_S	et	f	\N
192091	aedis	?aedis =aedi  (SgIn  >aedi !16_S	et	f	\N
192092	aedis	?aedis =aedi  (SgIn  >aet !22_S	et	f	\N
192093	aedis	?aedis =aedi  (IndIpfSg3  >aedima !28_V	et	f	\N
192094	aedis	?aedis =aedis  (SgN  >aedis !09_S	et	f	\N
192117	rahvasliku	?rahvasliku =rahvasliku  (SgG  >rahvaslik !25_A	et	f	\N
192118	rahvasliku	?rahvasliku =rahvasliku  (IndPrPs_  >rahvaslikuma !27_V	et	f	\N
192119	rahvasliku	?rahvasliku =rahvasliku  (ImpPrSg2  >rahvaslikuma !27_V	et	f	\N
192120	rahvasliku	?rahvasliku =sliku  (SgN  >rahva+sliku !16_S	et	f	\N
192121	rahvasliku	?rahvasliku =sliku  (SgG  >rahva+sliku !16_S	et	f	\N
192122	rahvasliku	?rahvasliku =sliku  (SgG  >rahva+slikk !22_S	et	f	\N
192133	lastekoore	lastekoore =koore  (SgG  >laste+koor !13_S	et	f	\N
192135	lastekoore	lastekoore =koore  (PlP  >laste+koor !22_S	et	f	\N
192142	baseritud	?baseritud =baseritu  (PlN  >baseritu !01_A	et	f	\N
192143	baseritud	?baseritud =baseritu  (IndPrSg2  >baserituma !27_V	et	f	\N
192144	baseritud	?baseritud =baseritud  (ID  >baseritud !41_A	et	f	\N
192151	meeskoridele	?meeskoridele =skori  (PlAll  >mee+skori !17_S	et	f	\N
192192	jätkuvad	jätkuvad =jätku  (IndPrPl3  >jätkuma !27_V	et	f	\N
192193	jätkuvad	jätkuvad =jätkuva  (PlN  >jätkuv !02_A	et	f	\N
192194	jätkuvad	"jätkuv %jätku  )V_vA  <jätkuma ;27_V	et	f	\N
192195	rahvatraditsiooni	rahvatraditsiooni =traditsiooni  (SgG  >rahva+traditsioon !22_S	et	f	\N
192196	rahvatraditsiooni	rahvatraditsiooni =traditsiooni  (SgP  >rahva+traditsioon !22_S	et	f	\N
192197	rahvatraditsiooni	rahvatraditsiooni =traditsiooni  (SgAdt  >rahva+traditsioon !22_S	et	f	\N
192198	laulupeoga	laulupeoga =peo  (SgKom  >laulu+pidu !18_S	et	f	\N
192199	laulupeoga	laulupeoga =peo  (SgKom  >laulu+peo !26_S	et	f	\N
192212	iseloomade	iseloomade =made  (SgN  >ise+loo+made !04_S	et	f	\N
192213	iseloomade	iseloomade =looma  (PlG  >ise+loom !22_S	et	f	\N
192224	alguset	?alguset =use  (SgP  >alg+use !16_S	et	f	\N
192237	propagandeerivad	?propagandeerivad =propagandeeri  (IndPrPl3  >propagandeerima !28_V	et	f	\N
192238	propagandeerivad	?propagandeerivad =propagandeeriva  (PlN  >propagandeeriv !02_A	et	f	\N
192239	propagandeerivad	?propagandeerivad =propagandeeriva  (PlN  >propagandeeriva !16_S	et	f	\N
192260	urimise	?urimise =urimise  (SgG  >urimine !12_S	et	f	\N
192261	lihtendati	?lihtendati =lihtenda  (IndIpfIps  >lihtendama !27_V	et	f	\N
192262	lihtendati	?lihtendati =lihtendati  (SgG  >lihtendatt !22_S	et	f	\N
192263	lihtendati	?lihtendati =lihtendati  (IndPrPs_  >lihtendattima !28_V	et	f	\N
192264	lihtendati	?lihtendati =lihtendati  (ImpPrSg2  >lihtendattima !28_V	et	f	\N
192265	lihtendati	?lihtendati =endati  (SgG  >liht+endat !02_S	et	f	\N
192266	lihtendati	?lihtendati =endati  (SgG  >liht+endatt !22_S	et	f	\N
192269	tööisel	?tööisel =tööisel  (SgN  >tööisel !02_S	et	f	\N
192270	tööisel	?tööisel =isel  (SgN  >töö+isel !02_S	et	f	\N
192273	ühindas	?ühindas =ühinda  (SgIn  >ühinda !01_S	et	f	\N
192274	ühindas	?ühindas =ühinda  (IndIpfSg3  >ühindama !27_V	et	f	\N
192276	kaksadatuhad	?kaksadatuhad =kaksadatuha  (PlN  >kaksadatuha !16_S	et	f	\N
192277	kaksadatuhad	?kaksadatuhad =adatuha  (PlN  >kaks+adatuha !16_S	et	f	\N
192291	võttnud	?võttnud =võttnu  (PlN  >võttnu !01_S	et	f	\N
192292	võttnud	?võttnud =võttnu  (IndPrSg2  >võttnuma !27_V	et	f	\N
192293	võttnud	?võttnud =võttnud  (ID  >võttnud !41_A	et	f	\N
192304	rifmad	?rifmad =rifma  (PlN  >rifma !16_S	et	f	\N
192305	rifmad	?rifmad =rifma  (IndPrSg2  >rifmama !29_V	et	f	\N
192314	laulupeosel	?laulupeosel =laulupeose  (PlAd  >laulupeos !22_S	et	f	\N
192315	laulupeosel	?laulupeosel =laulupeosel  (SgN  >laulupeosel !02_S	et	f	\N
192316	laulupeosel	?laulupeosel =peose  (SgAd  >laulu+peose !06_S	et	f	\N
192317	laulupeosel	?laulupeosel =peosel  (SgN  >laulu+peosel !02_S	et	f	\N
192318	laulupeosel	?laulupeosel =lupeose  (PlAd  >lau+lupeos !22_S	et	f	\N
192319	laulupeosel	?laulupeosel =lupeosel  (SgN  >lau+lupeosel !02_S	et	f	\N
192327	folklöörides	?folklöörides =folklööri  (PlIn  >folklööri !16_S	et	f	\N
192328	folklöörides	?folklöörides =folklööri  (PlIn  >folklöör !22_S	et	f	\N
192329	folklöörides	?folklöörides =folklööri  (Ger  >folklöörima !28_V	et	f	\N
192330	folklöörides	?folklöörides =lööri  (PlIn  >folk+lööri !16_S	et	f	\N
192331	folklöörides	?folklöörides =lööri  (PlIn  >folk+löör !22_S	et	f	\N
192340	rahvastiili	rahvastiili =iili  (SgG  >rahvast+iil !22_S	et	f	\N
192341	rahvastiili	rahvastiili =iili  (SgP  >rahvast+iil !22_S	et	f	\N
192342	rahvastiili	rahvastiili =iili  (SgAdt  >rahvast+iil !22_S	et	f	\N
192343	rahvastiili	rahvastiili =stiili  (SgG  >rahva+stiil !22_S	et	f	\N
192344	rahvastiili	rahvastiili =stiili  (SgP  >rahva+stiil !22_S	et	f	\N
192345	rahvastiili	rahvastiili =stiili  (SgAdt  >rahva+stiil !22_S	et	f	\N
192351	laulpidude	### laulpidude	et	f	\N
192352	sajandidel	### sajandidel	et	f	\N
192362	magamise	magamise =magamise  (SgG  >magamine !12_S	et	f	\N
192363	magamise	"magamine %maga  )MINE_vS  <magama ;27_V	et	f	\N
192379	ühendasid	ühendasid =ühenda  (IndIpfSg2  >ühendama !27_V	et	f	\N
192175	kultuuriidentiteedi	?kultuuriidentiteedi =identiteedi  (SgP  >kultuuri+identiteed !22_S	et	f	\N
192176	kultuuriidentiteedi	?kultuuriidentiteedi =identiteedi  (SgAdt  >kultuuri+identiteed !22_S	et	f	\N
192177	kultuuriidentiteedi	?kultuuriidentiteedi =iidentiteedi  (SgN  >kultuur+iidentiteedi !16_S	et	f	\N
192178	kultuuriidentiteedi	?kultuuriidentiteedi =iidentiteedi  (SgG  >kultuur+iidentiteedi !16_S	et	f	\N
192179	kultuuriidentiteedi	?kultuuriidentiteedi =iidentiteedi  (SgG  >kultuur+iidentiteet !22_S	et	f	\N
192180	kultuuriidentiteedi	?kultuuriidentiteedi =iidentiteedi  (SgP  >kultuur+iidentiteed !22_S	et	f	\N
192181	kultuuriidentiteedi	?kultuuriidentiteedi =iidentiteedi  (SgAdt  >kultuur+iidentiteed !22_S	et	f	\N
192275	osajated	### osajated	et	f	\N
192297	tähelepanuväärsemad	tähelepanuväärsemad =väärsema  (PlN  >tähele+panu+väärsem !02_A	et	f	\N
192298	tähelepanuväärsemad	"tähele+panu+väärsem %väärse  )M_cA  <tähele+panu+väärne ;02_A	et	f	\N
192306	näitevad	?näitevad =näite  (IndPrPl3  >näitema !27_V	et	f	\N
192307	näitevad	?näitevad =näiteva  (PlN  >näiteva !01_S	et	f	\N
192308	näitevad	?näitevad =näiteva  (PlN  >näitev !02_A	et	f	\N
192309	näitevad	?näitevad =eva  (PlN  >näit+eva !17_S	et	f	\N
192310	nõudu	?nõudu =nõudu  (SgN  >nõudu !16_S	et	f	\N
192311	nõudu	?nõudu =nõudu  (SgG  >nõudu !16_S	et	f	\N
192312	nõudu	?nõudu =nõudu  (IndPrPs_  >nõuduma !27_V	et	f	\N
192313	nõudu	?nõudu =nõudu  (ImpPrSg2  >nõuduma !27_V	et	f	\N
192337	folkloorid	folkloorid =folkloori  (PlN  >folkloor !22_S	et	f	\N
192338	folkloorid	folkloorid =loori  (PlN  >folk+loori !16_S	et	f	\N
192339	folkloorid	folkloorid =loori  (PlN  >folk+loor !22_S	et	f	\N
192359	räägimiseta	?räägimiseta =räägimise  (SgAb  >räägimine !12_S	et	f	\N
192360	räägimiseta	?räägimiseta =räägimiseta  (IndPrPs_  >räägimisetama !27_V	et	f	\N
192361	räägimiseta	?räägimiseta =räägimiseta  (ImpPrSg2  >räägimisetama !27_V	et	f	\N
192381	kaunised	?kaunised =kaunise  (IndPrSg2  >kaunisema !27_V	et	f	\N
192393	ümbertöötlusevad	?ümbertöötlusevad =ümbertöötluseva  (PlN  >ümbertöötlusev !02_A	et	f	\N
192394	ümbertöötlusevad	?ümbertöötlusevad =ümbertöötluseva  (PlN  >ümbertöötluseva !16_S	et	f	\N
192395	ümbertöötlusevad	?ümbertöötlusevad =eva  (PlN  >ümber+töötlus+eva !17_S	et	f	\N
192396	ümbertöötlusevad	?ümbertöötlusevad =töötluseva  (PlN  >ümber+töötlusev !02_A	et	f	\N
192397	ümbertöötlusevad	?ümbertöötlusevad =töötluseva  (PlN  >ümber+töötluseva !16_S	et	f	\N
192399	kaasnev	kaasnev =kaasne  (PtsPrPs  >kaasnema !27_V	et	f	\N
192400	kaasnev	kaasnev =kaasnev  (SgN  >kaasnev !02_A	et	f	\N
192401	kaasnev	"kaasnev %kaasne  )V_vA  <kaasnema ;27_V	et	f	\N
192423	leituma	leituma =leituma  (SgG  >leitum !02_A	et	f	\N
192424	leituma	"leitum %lei  )TUM1_cA  <leidma ;34_V	et	f	\N
192425	leituma	"leitum %lei  )TUM2_cA  <lei ;26_S	et	f	\N
192435	padari	?padari =padari  (SgN  >padari !01_S	et	f	\N
192436	padari	?padari =padari  (SgG  >padari !01_S	et	f	\N
192437	padari	?padari =padari  (SgG  >padar !02_S	et	f	\N
192440	austus	austus =austus  (SgN  >austus !11~09_S	et	f	\N
192441	austus	"austus %austa  )US_vS  <austama ;27_V	et	f	\N
192449	kukkuvad	kukkuvad =kukkuva  (PlN  >kukkuv !02_A	et	f	\N
192450	kukkuvad	"kukkuv %kukku  )V_vA  <kukkuma ;28_V	et	f	\N
192456	hingeid	?hingeid =hinge  (PlP  >hinge !06_S	et	f	\N
192457	hingeid	?hingeid =hingei  (PlN  >hingei !26_S	et	f	\N
192458	hingeid	?hingeid =hingei  (SgP  >hingei !26_S	et	f	\N
192459	hingeid	?hingeid =hingeid  (SgN  >hingeid !22_S	et	f	\N
192464	sugulastesse	sugulastesse =sugulas  (PlIll  >sugulane !12_S	et	f	\N
192465	sugulastesse	sugulastesse =las  (PlIll  >sugu+laps !14_S	et	f	\N
192466	sugulastesse	sugulastesse =laste  (PlIll  >sugu+last !22_S	et	f	\N
192467	hoidjad	hoidjad =hoidja  (PlN  >hoidja !01_S	et	f	\N
192468	hoidjad	"hoidja %hoid  )JA_vS  <hoidma ;34_V	et	f	\N
192476	rahvasümboliks	rahvasümboliks =iks  (SgN  >rahva+sümbol+iks !22_S	et	f	\N
192477	rahvasümboliks	rahvasümboliks =sümboli  (SgTr  >rahva+sümbol !02_S	et	f	\N
192482	eestipärased	eestipärased =pärase  (PlN  >eesti+pärane !10_A	et	f	\N
192483	eestipärased	"eesti+pärane %pära  )NE_aA  <eesti+pära ;17_S	et	f	\N
192487	lomingus	?lomingus =lomingu  (SgIn  >lomingu !01_S	et	f	\N
192488	lomingus	?lomingus =lomingu  (SgIn  >loming !02_S	et	f	\N
192489	lomingus	?lomingus =lomingu  (IndIpfSg3  >lominguma !27_V	et	f	\N
192490	lomingus	?lomingus =lomingus  (SgN  >lomingus !11_S	et	f	\N
192502	rock-stiilis	rock-stiilis =stiili  (SgIn  >rock-stiil !22_S	et	f	\N
192503	rock-stiilis	rock-stiilis =stiili  (IndIpfSg3  >rock-stiilima !28_V	et	f	\N
192535	ühikonnal	?ühikonnal =ühikonna  (SgAd  >ühikonna !16_S	et	f	\N
192536	ühikonnal	?ühikonnal =ühikonna  (SgAd  >ühikond !22_S	et	f	\N
192537	ühikonnal	?ühikonnal =ühikonnal  (SgN  >ühikonnal !02_S	et	f	\N
192546	väiksena	väiksena =väikse  (SgEs  >väike !10_A	et	f	\N
192547	väiksena	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
192558	vabahingeline	vabahingeline =hingeline  (SgN  >vaba+hingeline !12_SA	et	f	\N
192559	vabahingeline	"vaba+hingeline %hinge  )LINE_aA  <vaba+hing ;22_S	et	f	\N
192567	kõvem	kõvem =kõvem  (SgN  >kõvem !02_A	et	f	\N
192568	kõvem	"kõvem %kõve  )M_cA  <kõva ;17_A	et	f	\N
192574	imeline	imeline =imeline  (SgN  >imeline !12_A	et	f	\N
192217	sünnitust	"sünnitu %sünni  )TU1_vS  <sündima ;28_V	et	f	\N
192218	sünnitust	"sünnitu %sünni  )TU2_kA  <sünd ;22_S	et	f	\N
192219	sünnitust	sünnitust =sünnitus  (SgP  >sünnitus !11_S	et	f	\N
192220	sünnitust	"sünnitus %sünnita  )US_vS  <sünnitama ;27_V	et	f	\N
192221	sünnitust	"sünnitus %sünni  )TUS1_aS  <sündima ;28_V	et	f	\N
192222	sünnitust	"sünnitus %sünni  )TUS2_aS  <sünd ;22_S	et	f	\N
192223	sünnitust	sünnitust =tust  (SgN  >sünni+tust !22_S	et	f	\N
192232	karjased	karjased =karjase  (PlN  >karjane !10_S	et	f	\N
192233	karjased	"karjane %karja  )NE_aA  <kari ;24_S	et	f	\N
192240	laularahva	?laularahva =laularahva  (SgN  >laularahva !16_S	et	f	\N
192241	laularahva	?laularahva =laularahva  (SgG  >laularahva !16_S	et	f	\N
192242	laularahva	?laularahva =larahva  (SgN  >lau+larahva !01_S	et	f	\N
192243	laularahva	?laularahva =larahva  (SgG  >lau+larahva !01_S	et	f	\N
192245	eelus	?eelus =eelu  (SgIn  >eelu !16_S	et	f	\N
192246	eelus	?eelus =eelu  (IndIpfSg3  >eeluma !28_V	et	f	\N
192247	eelus	?eelus =eelus  (SgN  >eelus !11~09_S	et	f	\N
192280	rahvusmuusikale	rahvusmuusikale =muusika  (SgAll  >rahvus+muusika !01_S	et	f	\N
192281	rahvusmuusikale	rahvusmuusikale =muusikale  (PlP  >rahvus+muusikal !19_S	et	f	\N
192284	lastelaulu	lastelaulu =laulu  (SgG  >laste+laul !22_S	et	f	\N
192285	lastelaulu	lastelaulu =laulu  (SgP  >laste+laul !22_S	et	f	\N
192286	lastelaulu	lastelaulu =laulu  (SgAdt  >laste+laul !22_S	et	f	\N
192294	regilauluks	regilauluks =luks  (SgN  >regi+lau+luks !22_S	et	f	\N
192295	regilauluks	regilauluks =luks  (SgN  >regi+lau+luks !22_SA	et	f	\N
192296	regilauluks	regilauluks =laulu  (SgTr  >regi+laul !22_S	et	f	\N
192302	käitakse	?käitakse =käitakse  (SgG  >käitakne !02_A	et	f	\N
192303	mitmedest	?mitmedest =mitmedes  (SgP  >mitmedene !12_A	et	f	\N
192320	saaremaast	saaremaast =ast  (SgN  >saar+ema+ast !22_S	et	f	\N
192321	saaremaast	saaremaast =maa  (SgEl  >saare+maa !26_S	et	f	\N
192322	külalistele	külalistele =külalis  (PlAll  >külaline !12_S	et	f	\N
192323	külalistele	"külaline %küla  )LINE_aA  <küla ;17_S	et	f	\N
192334	tuttvus	?tuttvus =tuttvu  (SgIn  >tuttvu !01_S	et	f	\N
192335	tuttvus	?tuttvus =tuttvu  (IndIpfSg3  >tuttvuma !27_V	et	f	\N
192336	tuttvus	?tuttvus =tuttvus  (SgN  >tuttvus !11~09_S	et	f	\N
192346	laulutöö	laulutöö =töö  (SgN  >laulu+töö !26_S	et	f	\N
192347	laulutöö	laulutöö =töö  (SgG  >laulu+töö !26_S	et	f	\N
192355	tööda	?tööda =tööda  (SgN  >tööda !16_S	et	f	\N
192356	tööda	?tööda =tööda  (SgG  >tööda !16_S	et	f	\N
192357	tööda	?tööda =tööda  (IndPrPs_  >töödama !29_V	et	f	\N
192358	tööda	?tööda =tööda  (ImpPrSg2  >töödama !29_V	et	f	\N
192364	sõjade	?sõjade =sõja  (PlG  >sõja !17_S	et	f	\N
192367	praegus	?praegus =praegu  (IndIpfSg3  >praeguma !27_V	et	f	\N
192368	praegus	?praegus =praegus  (SgN  >praegus !11~09_S	et	f	\N
192371	sõjadele	?sõjadele =sõja  (PlAll  >sõja !17_S	et	f	\N
192376	põhiliseld	?põhiliseld =põhiliseld  (SgN  >põhiliseld !22_S	et	f	\N
192384	külastaksid	külastaksid =külasta  (KndPrSg2  >külastama !27_V	et	f	\N
192385	külastaksid	külastaksid =külasta  (KndPrPl3  >külastama !27_V	et	f	\N
192386	külastaksid	külastaksid =taksi  (PlN  >külas+taks !22_S	et	f	\N
192404	kesk-aafrika	?kesk-aafrika =aafrika  (SgN  >kesk-aafrika !01_S	et	f	\N
192405	kesk-aafrika	?kesk-aafrika =aafrika  (SgG  >kesk-aafrika !01_S	et	f	\N
192406	kesk-aafrika	?kesk-aafrika =aafrika  (SgG  >kesk-aafrikas !02_S	et	f	\N
192420	keestavad	?keestavad =keesta  (IndPrPl3  >keestama !27_V	et	f	\N
192421	keestavad	?keestavad =keestava  (PlN  >keestava !01_S	et	f	\N
192422	keestavad	?keestavad =keestava  (PlN  >keestav !02_A	et	f	\N
192451	lasteslt	?lasteslt =lasteslt  (SgN  >lasteslt !22_S	et	f	\N
192472	pop-muusika	pop-muusika =muusika  (SgN  >pop-muusika !01_S	et	f	\N
192473	pop-muusika	pop-muusika =muusika  (SgG  >pop-muusika !01_S	et	f	\N
192474	pulmalaule	pulmalaule =lau  (SgAll  >pulma+laug !22_SA	et	f	\N
192475	pulmalaule	pulmalaule =laule  (PlP  >pulma+laul !22_S	et	f	\N
192509	jalgadepõrutustele	?jalgadepõrutustele =jalgadepõrutus  (PlAll  >jalgadepõrutus !11?09_S	et	f	\N
192510	jalgadepõrutustele	?jalgadepõrutustele =jalgadepõrutustele  (IndPrPs_  >jalgadepõrutustelema !36_V	et	f	\N
192511	jalgadepõrutustele	?jalgadepõrutustele =jalgadepõrutustele  (ImpPrSg2  >jalgadepõrutustelema !36_V	et	f	\N
192512	jalgadepõrutustele	?jalgadepõrutustele =depõrutus  (PlAll  >jalga+depõrutus !11?09_S	et	f	\N
192513	jalgadepõrutustele	?jalgadepõrutustele =adepõrutus  (PlAll  >jalg+adepõrutus !11?09_S	et	f	\N
192514	uuemast	uuemast =uuema  (SgEl  >uuem !02_A	et	f	\N
192515	uuemast	"uuem %uue  )M_cA  <uus ;14_A	et	f	\N
192516	uuemast	uuemast =mast  (SgN  >uue+mast !22_S	et	f	\N
192521	süvendume	?süvendume =süvendu  (IndPrPl1  >süvenduma !27_V	et	f	\N
192522	mitmekesisemad	?mitmekesisemad =mitmekesisema  (PlN  >mitmekesisem !02_A	et	f	\N
192538	äkiliselt	äkiliselt =äkilise  (SgAbl  >äkiline !12_A	et	f	\N
192539	äkiliselt	äkiliselt =äkiliselt  (ID  >äkiliselt !41_D	et	f	\N
192540	äkiliselt	"äkiliselt %äkilise  )LT_mD  <äkiline ;12_A	et	f	\N
192560	häbenematult	häbenematult =häbenematu  (SgAbl  >häbenematu !01_A	et	f	\N
192561	häbenematult	"häbenematu %häbene  )MATU_vA  <häbenema ;27_V	et	f	\N
192256	mooderni	?mooderni =mooderni  (SgP  >moodern !22_S	et	f	\N
192257	mooderni	?mooderni =mooderni  (SgAdt  >moodern !22_S	et	f	\N
192258	mooderni	?mooderni =mooderni  (IndPrPs_  >moodernima !28_V	et	f	\N
192259	mooderni	?mooderni =mooderni  (ImpPrSg2  >moodernima !28_V	et	f	\N
192267	põlludes	?põlludes =põllu  (PlIn  >põllu !16_S	et	f	\N
192268	põlludes	?põlludes =põllu  (Ger  >põlluma !27_V	et	f	\N
192282	tegeleksid	tegeleksid =tegele  (KndPrSg2  >tegelema !31~27_V	et	f	\N
192283	tegeleksid	tegeleksid =tegele  (KndPrPl3  >tegelema !31~27_V	et	f	\N
192299	massilisemad	massilisemad =massilisema  (PlN  >massilisem !02_A	et	f	\N
192300	massilisemad	"massilisem %massi  )LISEM_cA  <mass ;22_S	et	f	\N
192301	massilisemad	"massilisem %massilise  )M_cA  <massiline ;12_A	et	f	\N
192324	iseloomulikust	iseloomulikust =loomuliku  (SgEl  >ise+loomulik !25_A	et	f	\N
192325	iseloomulikust	iseloomulikust =loomulikus  (SgP  >ise+loomulikus !11?09_S	et	f	\N
192326	iseloomulikust	"ise+loomulikus %loomuliku  )US_aS  <ise+loomulik ;25_A	et	f	\N
192348	riikades	?riikades =riika  (PlIn  >riika !16_S	et	f	\N
192349	riikades	?riikades =ade  (SgIn  >riik+ade !16_S	et	f	\N
192350	riikades	?riikades =ades  (SgN  >riik+ades !09_S	et	f	\N
192372	õnnelikkutena	### õnnelikkutena	et	f	\N
192407	kaasnevad	kaasnevad =kaasne  (IndPrPl3  >kaasnema !27_V	et	f	\N
192408	kaasnevad	kaasnevad =kaasneva  (PlN  >kaasnev !02_A	et	f	\N
192409	kaasnevad	"kaasnev %kaasne  )V_vA  <kaasnema ;27_V	et	f	\N
192418	isepoolest	isepoolest =poole  (PlEl  >ise+pool !22_S	et	f	\N
192419	isepoolest	isepoolest =pooles  (SgP  >ise+poolene !10_A	et	f	\N
192426	rock-versiooni	rock-versiooni =versiooni  (SgG  >rock-versioon !22_S	et	f	\N
192427	rock-versiooni	rock-versiooni =versiooni  (SgP  >rock-versioon !22_S	et	f	\N
192428	rock-versiooni	rock-versiooni =versiooni  (SgAdt  >rock-versioon !22_S	et	f	\N
192431	sordi	sordi =sordi  (ID  >sordi !41_D	et	f	\N
192432	sordi	sordi =sordi  (SgG  >sort !22_S	et	f	\N
192433	sordi	sordi =sordi  (IndPrPs_  >sortima !28_V	et	f	\N
192434	sordi	sordi =sordi  (ImpPrSg2  >sortima !28_V	et	f	\N
192442	armastamine	armastamine =armastamine  (SgN  >armastamine !12_S	et	f	\N
192443	armastamine	"armastamine %armasta  )MINE_vS  <armastama ;27_V	et	f	\N
192444	tuntut	tuntut =tuntu  (SgP  >tuntu !01_S	et	f	\N
192445	tuntut	"tuntu %tun  )TU1_vS  <tundma ;34_V	et	f	\N
192460	ammust	ammust =ammu  (SgEl  >amb !22_S	et	f	\N
192461	ammust	ammust =ammus  (SgP  >ammune !10_A	et	f	\N
192462	ammust	"ammune %ammu  )NE_aA  <amb ;22_S	et	f	\N
192463	ammust	ammust =ammust  (ID  >ammust !41_D	et	f	\N
192478	korraldatus	korraldatus =korraldatu  (SgIn  >korraldatu !01_S	et	f	\N
192479	korraldatus	"korraldatu %korralda  )TU1_vS  <korraldama ;27_V	et	f	\N
192480	korraldatus	korraldatus =korraldatus  (SgN  >korraldatus !11?09_S	et	f	\N
192481	korraldatus	"korraldatus %korralda  )TUS1_aS  <korraldama ;27_V	et	f	\N
192491	muusikaplaati	muusikaplaati =plaati  (SgP  >muusika+plaat !22_S	et	f	\N
192492	muusikaplaati	muusikaplaati =plaati  (SgAdt  >muusika+plaat !22_S	et	f	\N
192506	väljendamise	väljendamise =väljendamise  (SgG  >väljendamine !12_S	et	f	\N
192507	väljendamise	"väljendamine %väljenda  )MINE_vS  <väljendama ;27_V	et	f	\N
192525	esinejad	esinejad =esineja  (PlN  >esineja !01_S	et	f	\N
192526	esinejad	"esineja %esine  )JA_vS  <esinema ;27_V	et	f	\N
192528	natsioonaalsed	?natsioonaalsed =natsioonaalse  (PlN  >natsioonaalne !02_A	et	f	\N
192529	natsioonaalsed	?natsioonaalsed =oonaalse  (PlN  >natsi+oonaalne !02_A	et	f	\N
192530	natsioonaalsed	?natsioonaalsed =ioonaalse  (PlN  >nats+ioonaalne !02_A	et	f	\N
192531	säilitavad	säilitavad =säilita  (IndPrPl3  >säilitama !27_V	et	f	\N
192532	säilitavad	säilitavad =säilitava  (PlN  >säilitav !02_A	et	f	\N
192533	säilitavad	"säilitav %säili  )TAV_vAS  <säilima ;28_V	et	f	\N
192534	säilitavad	"säilitav %säilita  )V_vA  <säilitama ;27_V	et	f	\N
192548	piiridestest	?piiridestest =piirides  (PlEl  >piiridene !12_A	et	f	\N
192549	piiridestest	?piiridestest =piiridestes  (SgP  >piiridestene !12_A	et	f	\N
192550	piiridestest	?piiridestest =stest  (SgN  >piiride+stest !22_S	et	f	\N
192551	piiridestest	?piiridestest =deste  (SgEl  >piiri+deste !06_S	et	f	\N
192552	piiridestest	?piiridestest =deste  (PlEl  >piiri+dest !22_S	et	f	\N
192553	piiridestest	?piiridestest =destes  (SgP  >piiri+destes !09_S	et	f	\N
192554	piiridestest	?piiridestest =destes  (SgP  >piiri+destene !12~10_A	et	f	\N
192555	piiridestest	?piiridestest =ides  (PlEl  >piir+ides !09_S	et	f	\N
192556	piiridestest	?piiridestest =ides  (PlEl  >piir+idene !10_A	et	f	\N
192557	piiridestest	?piiridestest =idestes  (SgP  >piir+idestene !12_A	et	f	\N
192589	lühikeselt	lühikeselt =lühikese  (SgAbl  >lühike !12_A	et	f	\N
192590	lühikeselt	"lühike %lühi  )KE_dS  <lüht ;22_S	et	f	\N
192591	lühikeselt	lühikeselt =lühikese  (SgAbl  >lühikene !12_S	et	f	\N
192592	lühikeselt	"lühikene %lühi  )KENE_dS  <lüht ;22_S	et	f	\N
192593	hingeliseid	?hingeliseid =hingelisei  (PlN  >hingelisei !26_S	et	f	\N
192594	hingeliseid	?hingeliseid =hingelisei  (SgP  >hingelisei !26_S	et	f	\N
192598	naiskoorit	?naiskoorit =naiskoori  (SgP  >naiskoori !16_S	et	f	\N
192599	naiskoorit	?naiskoorit =koori  (SgP  >nais+koori !16_S	et	f	\N
192380	ühendasid	ühendasid =ühenda  (IndIpfPl3  >ühendama !27_V	et	f	\N
192387	folklööre	?folklööre =folklööre  (SgN  >folklööre !16_S	et	f	\N
192388	folklööre	?folklööre =folklööre  (SgG  >folklööre !16_S	et	f	\N
192389	folklööre	?folklööre =folklööre  (PlP  >folklöör !22_S	et	f	\N
192390	folklööre	?folklööre =lööre  (SgN  >folk+lööre !06_S	et	f	\N
192391	folklööre	?folklööre =lööre  (SgG  >folk+lööre !06_S	et	f	\N
192392	folklööre	?folklööre =lööre  (PlP  >folk+löör !22_S	et	f	\N
192398	arhivides	### arhivides	et	f	\N
192402	kombele	kombele =kombe  (SgAll  >komme !06_S	et	f	\N
192403	kombele	kombele =kombe  (PlAll  >komp !22_S	et	f	\N
192429	muusikamaailmasse	muusikamaailmasse =asse  (PlP  >muusika+maa+ilm+ass !22_S	et	f	\N
192430	muusikamaailmasse	muusikamaailmasse =ilma  (SgIll  >muusika+maa+ilm !22_S	et	f	\N
192438	armastamist	armastamist =armastamis  (SgP  >armastamine !12_S	et	f	\N
192439	armastamist	"armastamine %armasta  )MINE_vS  <armastama ;27_V	et	f	\N
192452	ümbervaadata	?ümbervaadata =ümbervaada  (SgAb  >ümbervaada !16_S	et	f	\N
192453	ümbervaadata	?ümbervaadata =ümbervaadata  (IndPrPs_  >ümbervaadatama !27_V	et	f	\N
192454	ümbervaadata	?ümbervaadata =ümbervaadata  (ImpPrSg2  >ümbervaadatama !27_V	et	f	\N
192455	ümbervaadata	?ümbervaadata =vaada  (SgAb  >ümber+vaada !16_S	et	f	\N
192484	ülemaailma	ülemaailma =ilma  (SgG  >üle+maa+ilm !22_S	et	f	\N
192485	ülemaailma	ülemaailma =ilma  (SgP  >üle+maa+ilm !22_S	et	f	\N
192486	ülemaailma	ülemaailma =ilma  (SgAdt  >üle+maa+ilm !22_S	et	f	\N
192493	setu-keeles	setu-keeles =keele  (SgIn  >setu-keel !13_S	et	f	\N
192494	setu-keeles	setu-keeles =keele  (PlIn  >setu-keeld !22_S	et	f	\N
192508	ootsutamisele	?ootsutamisele =ootsutamise  (SgAll  >ootsutamine !12_S	et	f	\N
192517	lindistusi	lindistusi =lindistusi  (PlP  >lindistus !11_S	et	f	\N
192518	lindistusi	"lindistus %lindista  )US_vS  <lindistama ;27_V	et	f	\N
192519	töödelduid	töödelduid =töödeldu  (PlP  >töödeldu !01_S	et	f	\N
192520	töödelduid	"töödeldu %töödel  )TU1_vS  <töötlema ;30_V	et	f	\N
192523	tantsimiseks	tantsimiseks =tantsimise  (SgTr  >tantsimine !12_S	et	f	\N
192524	tantsimiseks	"tantsimine %tantsi  )MINE_vS  <tantsima ;28_V	et	f	\N
192527	laupupidudel	### laupupidudel	et	f	\N
192541	kudagi	?kudagi =kuda  (SgN^  >kuda !17_S	et	f	\N
192542	kudagi	?kudagi =kuda  (SgG^  >kuda !17_S	et	f	\N
192543	kudagi	?kudagi =kuda  (SgP^  >kuda !17_S	et	f	\N
192544	kudagi	?kudagi =kuda  (IndPrPs_^  >kudama !27_V	et	f	\N
192545	kudagi	?kudagi =kuda  (ImpPrSg2^  >kudama !27_V	et	f	\N
192572	põnevam	põnevam =põnevam  (SgN  >põnevam !02_A	et	f	\N
192573	põnevam	"põnevam %põneva  )M_cA  <põnev ;02_A	et	f	\N
192577	rahvafolkloor	rahvafolkloor =loor  (SgN  >rahva+folk+loor !22_S	et	f	\N
192578	rahvafolkloor	rahvafolkloor =folkloor  (SgN  >rahva+folkloor !22_S	et	f	\N
192601	rahvapeo	rahvapeo =peo  (SgN  >rahva+peo !26_S	et	f	\N
192602	rahvapeo	rahvapeo =peo  (SgG  >rahva+pidu !18_S	et	f	\N
192603	rahvapeo	rahvapeo =peo  (SgG  >rahva+peo !26_S	et	f	\N
192620	tuttavamaid	tuttavamaid =tuttavama  (PlP  >tuttavam !02_A	et	f	\N
192621	tuttavamaid	"tuttavam %tuttava  )M_cA  <tuttav ;02_AS	et	f	\N
192622	tuttavamaid	tuttavamaid =ma  (PlP  >tutt+ava+maa !26_S	et	f	\N
192623	tuttavamaid	tuttavamaid =mai  (PlN  >tutt+ava+mai !26_S	et	f	\N
192624	tuttavamaid	tuttavamaid =mai  (SgP  >tutt+ava+mai !26_S	et	f	\N
192636	üleestiline	?üleestiline =üleestiline  (SgN  >üleestiline !12_A	et	f	\N
192637	üleestiline	?üleestiline =üleestiline  (PlP  >üleestilin !19_S	et	f	\N
192701	tänapäevastele	tänapäevastele =aste  (SgAll  >täna+päev+aste !06_S	et	f	\N
192702	tänapäevastele	tänapäevastele =aste  (PlAll  >täna+päev+ast !22_S	et	f	\N
192703	tänapäevastele	tänapäevastele =päevas  (PlAll  >täna+päevane !10_A	et	f	\N
192704	tänapäevastele	"täna+päevane %päeva  )NE_aA  <täna+päev ;22_S	et	f	\N
192733	kokkusobivus	kokkusobivus =sobivus  (SgN  >kokku+sobivus !11_S	et	f	\N
192734	kokkusobivus	"kokku+sobivus %sobiva  )US_aS  <kokku+sobiv ;02_A	et	f	\N
192740	lainesid	?lainesid =laine  (IndIpfSg2  >lainema !27_V	et	f	\N
192741	lainesid	?lainesid =laine  (IndIpfPl3  >lainema !27_V	et	f	\N
192742	lainesid	?lainesid =nesi  (PlN  >lai+nesi !17_S	et	f	\N
192750	kuleb	?kuleb =kule  (IndPrSg3  >kulema !27_V	et	f	\N
192759	ajadele	?ajadele =aja  (PlAll  >aja !17_S	et	f	\N
192769	aeganõudvalt	aeganõudvalt =nõudva  (SgAbl  >aega+nõudev !02_A	et	f	\N
192770	aeganõudvalt	"aega+nõudvalt %nõudva  )LT_mD  <aega+nõudev ;02_A	et	f	\N
192774	lemmikutest	lemmikutest =lemmiku  (PlEl  >lemmik !02_S	et	f	\N
192775	lemmikutest	lemmikutest =ute  (SgEl  >lemmik+utt !22_S	et	f	\N
192776	lemmikutest	lemmikutest =ute  (PlEl  >lemmik+utt !22_S	et	f	\N
192777	lemmikutest	lemmikutest =utes  (SgP  >lemmik+utene !10_A	et	f	\N
192778	lemmikutest	"lemmik+utene %ute  )NE_aA  <lemmik+utt ;22_S	et	f	\N
192783	rahvamuusikale	rahvamuusikale =muusika  (SgAll  >rahva+muusika !01_S	et	f	\N
192784	rahvamuusikale	rahvamuusikale =muusikale  (PlP  >rahva+muusikal !19_S	et	f	\N
192800	rahvalaulaks	rahvalaulaks =la  (SgTr  >rahva+lau+la !26_S	et	f	\N
192801	rahvalaulaks	rahvalaulaks =laks  (SgN  >rahva+lau+laks !22_S	et	f	\N
192806	muusikamõju	muusikamõju =mõju  (SgN  >muusika+mõju !17_S	et	f	\N
192414	spaani	?spaani =spaani  (SgP  >spaan !22_S	et	f	\N
192415	spaani	?spaani =spaani  (SgAdt  >spaan !22_S	et	f	\N
192416	spaani	?spaani =spaani  (IndPrPs_  >spaanima !28_V	et	f	\N
192417	spaani	?spaani =spaani  (ImpPrSg2  >spaanima !28_V	et	f	\N
192446	permanentsets	?permanentsets =permanentsets  (SgN  >permanentsets !22_S	et	f	\N
192447	lahkumisel	lahkumisel =lahkumise  (SgAd  >lahkumine !12_S	et	f	\N
192448	lahkumisel	"lahkumine %lahku  )MINE_vS  <lahkuma ;27_V	et	f	\N
192469	hojavad	?hojavad =hoja  (IndPrPl3  >hojama !27_V	et	f	\N
192470	hojavad	?hojavad =hojava  (PlN  >hojava !01_S	et	f	\N
192471	hojavad	?hojavad =hojava  (PlN  >hojav !02_A	et	f	\N
192495	muusitseerivad	?muusitseerivad =muusitseeri  (IndPrPl3  >muusitseerima !28_V	et	f	\N
192496	muusitseerivad	?muusitseerivad =muusitseeriva  (PlN  >muusitseeriv !02_A	et	f	\N
192497	muusitseerivad	?muusitseerivad =muusitseeriva  (PlN  >muusitseeriva !16_S	et	f	\N
192498	muusitseerivad	?muusitseerivad =eeriva  (PlN  >muu+sits+eeriva !01_S	et	f	\N
192499	muusitseerivad	?muusitseerivad =eeriva  (PlN  >muu+sits+eeriv !02_A	et	f	\N
192500	muusitseerivad	?muusitseerivad =sitseeriva  (PlN  >muu+sitseeriv !02_A	et	f	\N
192501	muusitseerivad	?muusitseerivad =sitseeriva  (PlN  >muu+sitseeriva !16_S	et	f	\N
192504	sure	sure =sure  (IndPrPs_  >surema !36_V	et	f	\N
192505	sure	sure =sure  (ImpPrSg2  >surema !36_V	et	f	\N
192565	võtsit	?võtsit =võtsi  (SgP  >võtsi !16_S	et	f	\N
192566	võtsit	?võtsit =võtsit  (SgN  >võtsit !02_S	et	f	\N
192569	laulukultuuri	laulukultuuri =kultuuri  (SgG  >laulu+kultuur !22_S	et	f	\N
192570	laulukultuuri	laulukultuuri =kultuuri  (SgP  >laulu+kultuur !22_S	et	f	\N
192571	laulukultuuri	laulukultuuri =kultuuri  (SgAdt  >laulu+kultuur !22_S	et	f	\N
192587	noorus	noorus =noorus  (SgN  >noorus !11~09_S	et	f	\N
192588	noorus	"noorus %noor  )US_aS  <noor ;13_AS	et	f	\N
192604	massivne	?massivne =massivne  (SgN  >massivne !02_A	et	f	\N
192605	massivne	?massivne =massivne  (PlP  >massivn !22_S	et	f	\N
192606	massivne	?massivne =massivne  (IndPrPs_  >massivnema !27_V	et	f	\N
192607	massivne	?massivne =massivne  (ImpPrSg2  >massivnema !27_V	et	f	\N
192608	massivne	?massivne =ivne  (SgN  >mass+ivne !02_A	et	f	\N
192609	massivne	?massivne =ivne  (PlP  >mass+ivn !22_S	et	f	\N
192614	pulmapidudel	pulmapidudel =pidu  (PlAd  >pulma+pidu !17_S	et	f	\N
192615	pulmapidudel	pulmapidudel =pidu  (PlAd  >pulma+pidu !18_S	et	f	\N
192626	andekaid	andekaid =andeka  (PlP  >andekas !02_A	et	f	\N
192627	andekaid	andekaid =kai  (PlN  >ande+kai !26_S	et	f	\N
192628	andekaid	andekaid =kai  (SgP  >ande+kai !26_S	et	f	\N
192633	folklooriga	folklooriga =folkloori  (SgKom  >folkloor !22_S	et	f	\N
192634	folklooriga	folklooriga =loori  (SgKom  >folk+loori !16_S	et	f	\N
192635	folklooriga	folklooriga =loori  (SgKom  >folk+loor !22_S	et	f	\N
192674	muusikal	muusikal =muusika  (SgAd  >muusika !01_S	et	f	\N
192675	muusikal	muusikal =muusikal  (SgN  >muusikal !19_S	et	f	\N
192676	mitmekesiseks	?mitmekesiseks =mitmekesise  (SgTr  >mitmekesis !09_S	et	f	\N
192677	juhtusid	juhtusid =juhtu  (PlP  >juht !22_S	et	f	\N
192678	juhtusid	juhtusid =juhtu  (IndIpfSg2  >juhtuma !27_V	et	f	\N
192679	juhtusid	juhtusid =juhtu  (IndIpfPl3  >juhtuma !27_V	et	f	\N
192688	folkloorrühmi	?folkloorrühmi =folkloorrühmi  (SgG  >folkloorrühm !22_S	et	f	\N
192689	folkloorrühmi	?folkloorrühmi =folkloorrühmi  (SgP  >folkloorrühm !22_S	et	f	\N
192690	folkloorrühmi	?folkloorrühmi =folkloorrühmi  (SgAdt  >folkloorrühm !22_S	et	f	\N
192691	folkloorrühmi	?folkloorrühmi =folkloorrühmi  (IndPrPs_  >folkloorrühmima !28_V	et	f	\N
192692	folkloorrühmi	?folkloorrühmi =folkloorrühmi  (ImpPrSg2  >folkloorrühmima !28_V	et	f	\N
192693	folkloorrühmi	?folkloorrühmi =loorrühmi  (SgN  >folk+loorrühmi !01_S	et	f	\N
192694	folkloorrühmi	?folkloorrühmi =loorrühmi  (SgG  >folk+loorrühmi !01_S	et	f	\N
192695	folkloorrühmi	?folkloorrühmi =loorrühmi  (SgG  >folk+loorrühm !22_S	et	f	\N
192696	folkloorrühmi	?folkloorrühmi =loorrühmi  (SgP  >folk+loorrühm !22_S	et	f	\N
192697	folkloorrühmi	?folkloorrühmi =loorrühmi  (SgAdt  >folk+loorrühm !22_S	et	f	\N
192705	jõusid	?jõusid =jõu  (PlP  >jõu !26_S	et	f	\N
192706	jõusid	?jõusid =jõusi  (PlN  >jõusi !16_S	et	f	\N
192707	jõusid	?jõusid =jõusi  (IndPrSg2  >jõusima !28_V	et	f	\N
192717	riimi	riimi =riimi  (ID  >riimi !41_D	et	f	\N
192718	riimi	riimi =riimi  (SgG  >riim !22_S	et	f	\N
192719	riimi	riimi =riimi  (SgP  >riim !22_S	et	f	\N
192720	riimi	riimi =riimi  (SgAdt  >riim !22_S	et	f	\N
192721	riimi	riimi =riimi  (IndPrPs_  >riimima !28_V	et	f	\N
192722	riimi	riimi =riimi  (ImpPrSg2  >riimima !28_V	et	f	\N
192762	emalauldes	?emalauldes =laulde  (PlIn  >ema+lault !22_S	et	f	\N
192763	emalauldes	?emalauldes =lauldes  (SgN  >ema+lauldes !09_S	et	f	\N
192764	seoutud	?seoutud =seoutu  (PlN  >seoutu !01_AS	et	f	\N
192765	seoutud	?seoutud =seoutu  (IndPrSg2  >seoutuma !27_V	et	f	\N
192766	seoutud	?seoutud =seoutud  (ID  >seoutud !41_A	et	f	\N
192785	folkloorisse	folkloorisse =folkloori  (SgIll  >folkloor !22_S	et	f	\N
192786	folkloorisse	folkloorisse =loori  (SgIll  >folk+loori !16_S	et	f	\N
192787	folkloorisse	folkloorisse =loori  (SgIll  >folk+loor !22_S	et	f	\N
192804	ema-lapse	ema-lapse =lapse  (SgG  >ema-laps !14_S	et	f	\N
192562	häbenematult	häbenematult =häbenematult  (ID  >häbenematult !41_D	et	f	\N
192563	häbenematult	"häbenematult %häbene  )MATULT_mD  <häbenema ;27_V	et	f	\N
192564	häbenematult	"häbenematult %häbenematu  )LT_mD  <häbenematu ;01_A	et	f	\N
192595	populaarselt	populaarselt =populaarse  (SgAbl  >populaarne !02_A	et	f	\N
192596	populaarselt	populaarselt =populaarselt  (ID  >populaarselt !41_D	et	f	\N
192597	populaarselt	"populaarselt %populaarse  )LT_mD  <populaarne ;02_A	et	f	\N
192638	muusikajõud	muusikajõud =jõu  (PlN  >muusika+jõud !22_S	et	f	\N
192639	muusikajõud	muusikajõud =jõud  (SgN  >muusika+jõud !22_S	et	f	\N
192640	julgeks	julgeks =julge  (SgTr  >julge !01_A	et	f	\N
192641	julgeks	julgeks =julge  (PlTr  >julk !22_S	et	f	\N
192642	julgeks	julgeks =julge  (KndPrPs  >julgema !27_V	et	f	\N
192643	igapäevasest	igapäevasest =päevase  (SgEl  >iga+päevane !10_A	et	f	\N
192644	igapäevasest	"iga+päevane %päeva  )NE_aA  <iga+päev ;22_S	et	f	\N
192647	kaheksateistkümnendal	?kaheksateistkümnendal =kaheksateistkümnenda  (SgAd  >kaheksateistkümnenda !16_S	et	f	\N
192648	kaheksateistkümnendal	?kaheksateistkümnendal =kaheksateistkümnendal  (SgN  >kaheksateistkümnendal !02_S	et	f	\N
192649	kaheksateistkümnendal	?kaheksateistkümnendal =kümnenda  (SgAd  >kaheksa+teist+kümnenda !01_S	et	f	\N
192650	kaheksateistkümnendal	?kaheksateistkümnendal =teistkümnenda  (SgAd  >kaheksa+teistkümnenda !16_S	et	f	\N
192651	kaheksateistkümnendal	?kaheksateistkümnendal =teistkümnendal  (SgN  >kaheksa+teistkümnendal !02_S	et	f	\N
192652	kaheksateistkümnendal	?kaheksateistkümnendal =ksateistkümnenda  (SgAd  >kahe+ksateistkümnenda !16_S	et	f	\N
192653	kaheksateistkümnendal	?kaheksateistkümnendal =ksateistkümnendal  (SgN  >kahe+ksateistkümnendal !02_S	et	f	\N
192668	riimis	riimis =riimi  (SgIn  >riim !22_S	et	f	\N
192669	riimis	riimis =riimi  (IndIpfSg3  >riimima !28_V	et	f	\N
192670	riimis	riimis =riimis  (ID  >riimis !41_DA	et	f	\N
192680	meeleolut	?meeleolut =olut  (SgN  >meele+olut !02_S	et	f	\N
192681	meeleolut	?meeleolut =leolu  (SgP  >mee+leolu !16_S	et	f	\N
192682	meeleolut	?meeleolut =leolut  (SgN  >mee+leolut !02_S	et	f	\N
192683	lõbusamad	lõbusamad =lõbusama  (PlN  >lõbusam !02_A	et	f	\N
192684	lõbusamad	"lõbusam %lõbusa  )M_cA  <lõbus ;02_A	et	f	\N
192708	vallandavad	vallandavad =vallanda  (IndPrPl3  >vallandama !27_V	et	f	\N
192709	vallandavad	vallandavad =vallandava  (PlN  >vallandav !02_A	et	f	\N
192710	vallandavad	"vallandav %vallanda  )V_vA  <vallandama ;27_V	et	f	\N
192711	astet	astet =aste  (SgP  >aste !05_S	et	f	\N
192712	astet	astet =aste  (SgP  >aste !06_S	et	f	\N
192723	kellegiga	### kellegiga	et	f	\N
192724	leitsid	?leitsid =leit  (IndIpfSg2  >leitma !34_V	et	f	\N
192725	leitsid	?leitsid =leit  (IndIpfPl3  >leitma !34_V	et	f	\N
192726	leitsid	?leitsid =leitsi  (PlN  >leits !22_S	et	f	\N
192727	leitsid	?leitsid =leitsi  (IndPrSg2  >leitsima !28_V	et	f	\N
192728	eeldus	eeldus =eeldus  (SgN  >eeldus !11~09_S	et	f	\N
192729	eeldus	"eeldus %eelda  )US_vS  <eeldama ;27_V	et	f	\N
192730	jägada	?jägada =jäga  (Inf  >jägama !27_V	et	f	\N
192731	ühenda	ühenda =ühenda  (IndPrPs_  >ühendama !27_V	et	f	\N
192732	ühenda	ühenda =ühenda  (ImpPrSg2  >ühendama !27_V	et	f	\N
192748	laulumist	laulumist =lumis  (SgP  >lau+lumine !10_A	et	f	\N
192749	laulumist	"lau+lumine %lumi  )NE_aA  <lau+lumi ;20_S	et	f	\N
192751	mängides	mängides =mängi  (PlIn  >mäng !22_S	et	f	\N
192752	mängides	mängides =mängi  (Ger  >mängima !28_V	et	f	\N
192771	lauluajaloost	lauluajaloost =loo  (SgEl  >laulu+aja+lugu !18_S	et	f	\N
192772	lauluajaloost	lauluajaloost =loo  (SgEl  >laulu+aja+loog !22_S	et	f	\N
192773	lauluajaloost	lauluajaloost =loo  (SgEl  >laulu+aja+lood !22_S	et	f	\N
192826	tolel	?tolel =tole  (SgAd  >tole !16_S	et	f	\N
192827	tolel	?tolel =tolel  (SgN  >tolel !02_S	et	f	\N
192836	propagandistlikku	propagandistlikku =propagandistlikku  (SgP  >propagandistlik !25_A	et	f	\N
192837	propagandistlikku	propagandistlikku =propagandistlikku  (SgAdt  >propagandistlik !25_A	et	f	\N
192842	iii-köide	iii-köide =köi  (SgAdt  >iii-köis !14_S	et	f	\N
192843	iii-köide	iii-köide =köide  (SgN  >iii-köide !05_S	et	f	\N
192844	iii-köide	iii-köide =köide  (SgN  >iii-köide !06_S	et	f	\N
192862	andnus	andnus =andnu  (SgIn  >andnu !01_S	et	f	\N
192863	andnus	"andnu %and  )NU_vS  <andma ;34_V	et	f	\N
192873	sures	?sures =sure  (SgIn  >sure !16_S	et	f	\N
192874	sures	?sures =sures  (SgN  >sures !09_S	et	f	\N
192879	krjandus	?krjandus =krjandu  (IndIpfSg3  >krjanduma !27_V	et	f	\N
192880	krjandus	?krjandus =krjandus  (SgN  >krjandus !11~09_S	et	f	\N
192923	mihkelson	?mihkelson =mihkelson  (SgN  >mihkelson !19_S	et	f	\N
192924	raskuse	raskuse =raskuse  (SgG  >raskus !11~09_S	et	f	\N
192925	raskuse	"raskus %raske  )US_aS  <raske ;01_A	et	f	\N
192926	raskuse	raskuse =raskuse  (SgG  >raskune !12~10_A	et	f	\N
192931	rahvuslikeväeosade	?rahvuslikeväeosade =rahvuslikeväeosa  (PlG  >rahvuslikeväeosa !16_S	et	f	\N
192933	rahvuslikeväeosade	?rahvuslikeväeosade =slikeväeosa  (PlG  >rahvu+slikeväeosa !16_S	et	f	\N
192950	mmetsanurg	?mmetsanurg =mmetsanurg  (SgN  >mmetsanurg !22_S	et	f	\N
192953	jsemper	?jsemper =jsemper  (SgN  >jsemper !02_S	et	f	\N
192955	okupeerimist	okupeerimist =okupeerimis  (SgP  >okupeerimine !12_S	et	f	\N
192575	imeline	"imeline %ime  )LINE_aA  <ime ;16_S	et	f	\N
192576	kaunisest	?kaunisest =kaunises  (SgP  >kaunisene !12_A	et	f	\N
192579	muusikaürituseid	?muusikaürituseid =muusikaürituse  (PlP  >muusikaüritus !09_S	et	f	\N
192580	muusikaürituseid	?muusikaürituseid =muusikaüritusei  (PlN  >muusikaüritusei !26_S	et	f	\N
192581	muusikaürituseid	?muusikaürituseid =muusikaüritusei  (SgP  >muusikaüritusei !26_S	et	f	\N
192582	muusikaürituseid	?muusikaürituseid =üritusei  (PlN  >muusika+üritusei !26_S	et	f	\N
192583	muusikaürituseid	?muusikaürituseid =üritusei  (SgP  >muusika+üritusei !26_S	et	f	\N
192584	muusikaürituseid	?muusikaürituseid =sikaürituse  (PlP  >muu+sikaüritus !09_S	et	f	\N
192585	muusikaürituseid	?muusikaürituseid =sikaüritusei  (PlN  >muu+sikaüritusei !26_S	et	f	\N
192586	muusikaürituseid	?muusikaürituseid =sikaüritusei  (SgP  >muu+sikaüritusei !26_S	et	f	\N
192610	kaulu	?kaulu =kaulu  (SgN  >kaulu !16_S	et	f	\N
192611	kaulu	?kaulu =kaulu  (SgG  >kaulu !16_S	et	f	\N
192612	kaulu	?kaulu =kaulu  (IndPrPs_  >kauluma !28_V	et	f	\N
192613	kaulu	?kaulu =kaulu  (ImpPrSg2  >kauluma !28_V	et	f	\N
192645	sotsiaaltegevus	sotsiaaltegevus =tegevus  (SgN  >sotsiaal+tegevus !11_S	et	f	\N
192646	sotsiaaltegevus	"sotsiaal+tegevus %tegeva  )US_aS  <sotsiaal+tegev ;02_A	et	f	\N
192654	piduõhtuti	?piduõhtuti =piduõhtu  (IndIpfIps  >piduõhtuma !27_V	et	f	\N
192655	piduõhtuti	?piduõhtuti =piduõhtuti  (SgG  >piduõhtutt !22_S	et	f	\N
192656	piduõhtuti	?piduõhtuti =piduõhtuti  (IndPrPs_  >piduõhtuttima !28_V	et	f	\N
192657	piduõhtuti	?piduõhtuti =piduõhtuti  (ImpPrSg2  >piduõhtuttima !28_V	et	f	\N
192658	piduõhtuti	?piduõhtuti =õhtuti  (SgG  >pidu+õhtut !02_S	et	f	\N
192659	piduõhtuti	?piduõhtuti =õhtuti  (SgG  >pidu+õhtutt !22_S	et	f	\N
192698	teematilisi	teematilisi =matilisi  (PlP  >tee+matiline !12_A	et	f	\N
192699	teematilisi	"tee+matiline %mati  )LINE_aA  <tee+mati ;16_S	et	f	\N
192700	teematilisi	"tee+matiline %mati  )LINE_aA  <tee+matt ;22_SA	et	f	\N
192743	toimumist	toimumist =toimumis  (SgP  >toimumine !12_S	et	f	\N
192744	toimumist	"toimumine %toimu  )MINE_vS  <toimuma ;27_V	et	f	\N
192745	loodamine	?loodamine =loodamine  (SgN  >loodamine !12_S	et	f	\N
192746	loodamine	?loodamine =loodamine  (PlP  >loodamin !19_S	et	f	\N
192747	loodamine	?loodamine =damine  (SgN  >loo+damine !10_A	et	f	\N
192755	laulupidusi	?laulupidusi =laulupidusi  (PlP  >laulupidus !11_S	et	f	\N
192756	laulupidusi	?laulupidusi =pidusi  (SgG  >laulu+pidus !02_A	et	f	\N
192757	laulupidusi	?laulupidusi =lupidusi  (PlP  >lau+lupidus !11_S	et	f	\N
192758	hingades	?hingades =hinga  (PlIn  >hinga !16_S	et	f	\N
192760	ühiks	?ühiks =ühi  (SgTr  >ühi !17_S	et	f	\N
192761	ühiks	?ühiks =ühi  (KndPrPs  >ühima !27_V	et	f	\N
192781	esilaulja	esilaulja =laulja  (SgN  >esi+laulja !01_S	et	f	\N
192782	esilaulja	esilaulja =laulja  (SgG  >esi+laulja !01_S	et	f	\N
192788	muusikafestivaal	?muusikafestivaal =muusikafestivaa  (SgAd  >muusikafestivaa !26_S	et	f	\N
192789	muusikafestivaal	?muusikafestivaal =muusikafestivaal  (SgN  >muusikafestivaal !22_S	et	f	\N
192790	muusikafestivaal	?muusikafestivaal =festivaa  (SgAd  >muusika+festivaa !26_S	et	f	\N
192791	muusikafestivaal	?muusikafestivaal =festivaal  (SgN  >muusika+festivaal !22_S	et	f	\N
192792	muusikafestivaal	?muusikafestivaal =sikafestivaa  (SgAd  >muu+sikafestivaa !26_S	et	f	\N
192793	muusikafestivaal	?muusikafestivaal =sikafestivaal  (SgN  >muu+sikafestivaal !22_S	et	f	\N
192794	rahvasel	rahvasel =rahvase  (SgAd  >rahvane !10_A	et	f	\N
192795	rahvasel	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
192812	folk	?folk =folk  (SgN  >folk !22_S	et	f	\N
192816	rahvaseks	rahvaseks =rahvase  (SgTr  >rahvane !10_A	et	f	\N
192817	rahvaseks	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
192818	rahvaseks	rahvaseks =seks  (SgN  >rahva+seks !22_S	et	f	\N
192828	sumboliteks	?sumboliteks =sumboli  (PlTr  >sumbol !02_S	et	f	\N
192829	sumboliteks	?sumboliteks =sumbolite  (PlTr  >sumbolitt !22_S	et	f	\N
192860	kolhosid	?kolhosid =kolho  (PlP  >kolho !16_S	et	f	\N
192864	kasvatade	?kasvatade =vata  (PlG  >kas+vata !16_S	et	f	\N
192877	põhjenda	põhjenda =põhjenda  (IndPrPs_  >põhjendama !27_V	et	f	\N
192878	põhjenda	põhjenda =põhjenda  (ImpPrSg2  >põhjendama !27_V	et	f	\N
192881	kirjanduseuurija	kirjanduseuurija =uurija  (SgN  >kirjanduse+uurija !01_S	et	f	\N
192882	kirjanduseuurija	kirjanduseuurija =uurija  (SgG  >kirjanduse+uurija !01_S	et	f	\N
192934	küüditamisest	küüditamisest =küüditamise  (SgEl  >küüditamine !12_S	et	f	\N
192935	küüditamisest	"küüditamine %küüdita  )MINE_vS  <küüditama ;27_V	et	f	\N
192938	sõjaväkkede	### sõjaväkkede	et	f	\N
192939	elatustasa	?elatustasa =elatustasa  (SgN  >elatustasa !16_S	et	f	\N
192940	elatustasa	?elatustasa =elatustasa  (SgG  >elatustasa !16_S	et	f	\N
192951	soovere	soovere =ere  (SgN  >soov+ere !02_A	et	f	\N
192952	soovere	soovere =vere  (SgG  >soo+veri !20_S	et	f	\N
192961	nõutsid	?nõutsid =nõut  (IndIpfSg2  >nõutma !34_V	et	f	\N
192962	nõutsid	?nõutsid =nõut  (IndIpfPl3  >nõutma !34_V	et	f	\N
192963	nõutsid	?nõutsid =nõutsi  (PlN  >nõuts !22_S	et	f	\N
192964	nõutsid	?nõutsid =nõutsi  (IndPrSg2  >nõutsima !28_V	et	f	\N
193003	võidelta	võidelta =delta  (SgN  >või+delta !16_S	et	f	\N
193004	võidelta	võidelta =delta  (SgG  >või+delta !16_S	et	f	\N
192600	naiskoorit	?naiskoorit =koorit  (SgN  >nais+koorit !02_S	et	f	\N
192616	tänapäevast	tänapäevast =ast  (SgN  >täna+päev+ast !22_S	et	f	\N
192617	tänapäevast	tänapäevast =päeva  (SgEl  >täna+päev !22_S	et	f	\N
192618	tänapäevast	tänapäevast =päevas  (SgP  >täna+päevane !10_A	et	f	\N
192619	tänapäevast	"täna+päevane %päeva  )NE_aA  <täna+päev ;22_S	et	f	\N
192625	muusikantid	?muusikantid =sikanti  (PlN  >muu+sikanti !01_S	et	f	\N
192629	sõjaid	?sõjaid =sõja  (PlP  >sõjas !09_S	et	f	\N
192630	sõjaid	?sõjaid =sõjai  (PlN  >sõjai !26_S	et	f	\N
192631	sõjaid	?sõjaid =sõjai  (SgP  >sõjai !26_S	et	f	\N
192632	sõjaid	?sõjaid =sõjaid  (SgN  >sõjaid !22_S	et	f	\N
192660	muusikatendentsite	?muusikatendentsite =muusikatendentsi  (IndPrPl2  >muusikatendentsima !28_V	et	f	\N
192661	muusikatendentsite	?muusikatendentsite =tendentsi  (PlG  >muusika+tendentsi !01_S	et	f	\N
192662	salmi	salmi =salmi  (SgG  >salm !22_S	et	f	\N
192663	salmi	salmi =salmi  (SgP  >salm !22_S	et	f	\N
192664	salmi	salmi =salmi  (SgAdt  >salm !22_S	et	f	\N
192665	salmi	salmi =salmi  (PlP  >salm !22_S	et	f	\N
192666	salmi	salmi =salmi  (IndPrPs_  >salmima !28_V	et	f	\N
192667	salmi	salmi =salmi  (ImpPrSg2  >salmima !28_V	et	f	\N
192671	puhkpilleorkestrid	?puhkpilleorkestrid =puhkpilleorkestri  (PlN  >puhkpilleorkester !02_S	et	f	\N
192672	puhkpilleorkestrid	?puhkpilleorkestrid =puhkpilleorkestri  (IndPrSg2  >puhkpilleorkestrima !28_V	et	f	\N
192673	puhkpilleorkestrid	?puhkpilleorkestrid =pilleorkestri  (PlN  >puhk+pilleorkester !02_S	et	f	\N
192685	armsaim	armsaim =armsaim  (SgN  >armsaim !02_A	et	f	\N
192686	armsaim	"armsaim %armsa  )IM_sA  <armas ;03_A	et	f	\N
192687	armsaim	"armsaim %armsa  )IM_sA  <armas ;05_A	et	f	\N
192713	lõppuriimiline	?lõppuriimiline =lõppuriimiline  (SgN  >lõppuriimiline !12_A	et	f	\N
192714	lõppuriimiline	?lõppuriimiline =lõppuriimiline  (PlP  >lõppuriimilin !19_S	et	f	\N
192715	lõppuriimiline	?lõppuriimiline =uriimiline  (SgN  >lõpp+uriimiline !12_A	et	f	\N
192716	lõppuriimiline	?lõppuriimiline =uriimiline  (PlP  >lõpp+uriimilin !19_S	et	f	\N
192735	proovivad	proovivad =proovi  (IndPrPl3  >proovima !28_V	et	f	\N
192736	proovivad	proovivad =prooviva  (PlN  >prooviv !02_A	et	f	\N
192737	proovivad	"prooviv %proovi  )V_vA  <proovima ;28_V	et	f	\N
192738	regilaulust	regilaulust =lust  (SgN  >regi+lau+lust !22_S	et	f	\N
192739	regilaulust	regilaulust =laulu  (SgEl  >regi+laul !22_S	et	f	\N
192753	pidusi	?pidusi =pidusi  (ID  >pidusi !41_D	et	f	\N
192754	pidusi	?pidusi =pidusi  (SgG  >pidus !02_A	et	f	\N
192767	kultuuriloaga	kultuuriloaga =loa  (SgKom  >kultuuri+luba !18_S	et	f	\N
192768	kultuuriloaga	kultuuriloaga =loa  (SgKom  >kultuuri+luga !18_S	et	f	\N
192779	pidutsemisel	pidutsemisel =pidutsemise  (SgAd  >pidutsemine !12_S	et	f	\N
192780	pidutsemisel	"pidutsemine %pidutse  )MINE_vS  <pidutsema ;27_V	et	f	\N
192796	pärandavad	pärandavad =päranda  (IndPrPl3  >pärandama !27_V	et	f	\N
192797	pärandavad	pärandavad =pärandava  (PlN  >pärandav !02_A	et	f	\N
192798	pärandavad	"pärandav %päranda  )V_vA  <pärandama ;27_V	et	f	\N
192799	pärandavad	pärandavad =ava  (PlN  >pärand+ava !17_S	et	f	\N
192802	karjalaul	karjalaul =lau  (SgAd  >karja+laug !22_SA	et	f	\N
192803	karjalaul	karjalaul =laul  (SgN  >karja+laul !22_S	et	f	\N
192822	uhkuda	?uhkuda =uhku  (Inf  >uhkuma !27_V	et	f	\N
192823	võidlemisest	?võidlemisest =võidlemise  (SgEl  >võidlemine !12_S	et	f	\N
192824	võidlemisest	?võidlemisest =dlemise  (SgEl  >või+dlemine !10_A	et	f	\N
192852	kiirestiarendama	?kiirestiarendama =kiirestiarenda  (Sup  >kiirestiarendama !27_V	et	f	\N
192853	kiirestiarendama	?kiirestiarendama =kiirestiarendama  (SgG  >kiirestiarendam !02_A	et	f	\N
192854	kiirestiarendama	?kiirestiarendama =arendama  (SgG  >kiiresti+arendam !02_A	et	f	\N
192855	kiirestiarendama	?kiirestiarendama =stiarendama  (SgG  >kiire+stiarendam !02_A	et	f	\N
192856	kiirestiarendama	?kiirestiarendama =estiarendama  (SgG  >kiir+estiarendam !02_A	et	f	\N
192861	kolhosid	?kolhosid =kolho  (PlP  >kolho !16_S	et	f	\N
192866	vaesele	vaesele =vaese  (SgAll  >vaene !10_AS	et	f	\N
192867	vaesele	"vaene %vae  )NE_aA  <vaag ;22_S	et	f	\N
192868	rongu	?rongu =rongu  (ID  >rongu !41_D	et	f	\N
192869	rongu	?rongu =rongu  (IndPrPs_  >ronguma !27_V	et	f	\N
192870	rongu	?rongu =rongu  (IndPrPs_  >ronkuma !28_V	et	f	\N
192871	rongu	?rongu =rongu  (ImpPrSg2  >ronguma !27_V	et	f	\N
192872	rongu	?rongu =rongu  (ImpPrSg2  >ronkuma !28_V	et	f	\N
192885	tappetud	tappetud =tappetu  (PlN  >tappetu !01_A	et	f	\N
192886	tappetud	"tappetu %tappe  )TU2_kA  <tape ;06_S	et	f	\N
192928	vabatahtlikust	vabatahtlikust =tahtliku  (SgEl  >vaba+tahtlik !25_A	et	f	\N
192929	vabatahtlikust	vabatahtlikust =tahtlikus  (SgP  >vaba+tahtlikus !11_S	et	f	\N
192930	vabatahtlikust	"vaba+tahtlikus %tahtliku  )US_aS  <vaba+tahtlik ;25_A	et	f	\N
192941	piirini	piirini =piiri  (SgTer  >piir !22_S	et	f	\N
192942	piirini	piirini =ini  (SgN  >piir+ini !17_S	et	f	\N
192943	piirini	piirini =ini  (SgG  >piir+ini !17_S	et	f	\N
192944	piirini	piirini =ini  (SgP  >piir+ini !17_S	et	f	\N
192970	bezobrazov	?bezobrazov =bezobrazov  (SgN  >bezobrazov !02_A	et	f	\N
192979	muusikaseltsi	muusikaseltsi =seltsi  (SgG  >muusika+selts !22_S	et	f	\N
192980	muusikaseltsi	muusikaseltsi =seltsi  (SgP  >muusika+selts !22_S	et	f	\N
192805	ema-lapse	ema-lapse =lapse  (PlP  >ema-laps !22_S	et	f	\N
192809	festevaalid	?festevaalid =festevaali  (PlN  >festevaali !16_S	et	f	\N
192810	festevaalid	?festevaalid =festevaali  (PlN  >festevaal !22_S	et	f	\N
192811	festevaalid	?festevaalid =festevaali  (IndPrSg2  >festevaalima !28_V	et	f	\N
192830	muinasjutulaulu	muinasjutulaulu =laulu  (SgG  >muinas+jutu+laul !22_S	et	f	\N
192831	muinasjutulaulu	muinasjutulaulu =laulu  (SgP  >muinas+jutu+laul !22_S	et	f	\N
192832	muinasjutulaulu	muinasjutulaulu =laulu  (SgAdt  >muinas+jutu+laul !22_S	et	f	\N
192841	ahtaamsare	?ahtaamsare =ahtaamsare  (PlP  >ahtaamsar !19_S	et	f	\N
192859	draaamateater	?draaamateater =draaamateater  (SgN  >draaamateater !02_S	et	f	\N
192875	tompea	?tompea =tompea  (SgN  >tompea !26_S	et	f	\N
192876	tompea	?tompea =tompea  (SgG  >tompea !26_S	et	f	\N
192894	luuletuseid	?luuletuseid =luuletusei  (PlN  >luuletusei !26_S	et	f	\N
192895	luuletuseid	?luuletuseid =luuletusei  (SgP  >luuletusei !26_S	et	f	\N
192896	luuletuseid	?luuletuseid =eid  (SgN  >luuletus+eid !22_S	et	f	\N
192897	luuletuseid	?luuletuseid =tusei  (PlN  >luule+tusei !26_S	et	f	\N
192898	luuletuseid	?luuletuseid =tusei  (SgP  >luule+tusei !26_S	et	f	\N
192899	luuletuseid	?luuletuseid =tuseid  (SgN  >luule+tuseid !22_S	et	f	\N
192900	luuletuseid	?luuletuseid =letuse  (PlP  >luu+letus !09_S	et	f	\N
192901	luuletuseid	?luuletuseid =letusei  (PlN  >luu+letusei !26_S	et	f	\N
192902	luuletuseid	?luuletuseid =letusei  (SgP  >luu+letusei !26_S	et	f	\N
192912	hansen	?hansen =hanse  (IndPrSg1  >hansema !27_V	et	f	\N
192913	hansen	?hansen =hansen  (SgN  >hansen !02_S	et	f	\N
192914	kpätsi	?kpätsi =kpätsi  (SgN  >kpätsi !16_S	et	f	\N
192915	kpätsi	?kpätsi =kpätsi  (SgG  >kpätsi !16_S	et	f	\N
192916	kpätsi	?kpätsi =kpätsi  (SgG  >kpäts !22_S	et	f	\N
192917	kpätsi	?kpätsi =kpätsi  (SgP  >kpäts !22_S	et	f	\N
192918	kpätsi	?kpätsi =kpätsi  (SgAdt  >kpäts !22_S	et	f	\N
192919	kpätsi	?kpätsi =kpätsi  (IndPrPs_  >kpätsima !28_V	et	f	\N
192920	kpätsi	?kpätsi =kpätsi  (ImpPrSg2  >kpätsima !28_V	et	f	\N
192932	leningradis	?leningradis =leningradis  (SgN  >leningradis !09_S	et	f	\N
192936	töölaagritest	töölaagritest =test  (SgN  >töö+laagri+test !22_S	et	f	\N
192937	töölaagritest	töölaagritest =laagri  (PlEl  >töö+laager !02_S	et	f	\N
192965	lühenemist	lühenemist =lühenemis  (SgP  >lühenemine !12_S	et	f	\N
192966	lühenemist	"lühenemine %lühene  )MINE_vS  <lühenema ;27_V	et	f	\N
192971	bozobrazov	?bozobrazov =bozobrazov  (SgN  >bozobrazov !02_A	et	f	\N
192972	bernhard	?bernhard =bernhard  (SgN  >bernhard !02_S	et	f	\N
193005	religiose	?religiose =religiose  (PlP  >religios !22_S	et	f	\N
193017	arstiteadus	arstiteadus =teadu  (SgIn  >arsti+tead !22_S	et	f	\N
193018	arstiteadus	arstiteadus =teadus  (SgN  >arsti+teadus !11~09_S	et	f	\N
193024	liite	liite =liite  (SgG  >liide !06_S	et	f	\N
193026	liite	liite =liite  (PlP  >liit !22_S	et	f	\N
193044	mõistnikude	?mõistnikude =mõistniku  (PlG  >mõistnik !25_S	et	f	\N
193045	pördekatse	?pördekatse =pördekatse  (SgG  >pördekatne !02_A	et	f	\N
193046	pördekatse	?pördekatse =pördekatse  (PlP  >pördekats !22_S	et	f	\N
193047	pördekatse	?pördekatse =pördekatse  (IndPrPs_  >pördekatsema !27_V	et	f	\N
193048	pördekatse	?pördekatse =pördekatse  (ImpPrSg2  >pördekatsema !27_V	et	f	\N
193049	elavatele	elavatele =elava  (PlAll  >elav !02_A	et	f	\N
193050	elavatele	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
193051	elavatele	elavatele =ate  (PlAll  >elav+att !22_S	et	f	\N
193055	markaga	?markaga =marka  (SgKom  >marka !16_S	et	f	\N
193068	süzheedid	?süzheedid =süzheedi  (PlN  >süzheedi !16_S	et	f	\N
193069	süzheedid	?süzheedid =süzheedi  (PlN  >süzheet !22_S	et	f	\N
193070	süzheedid	?süzheedid =süzheedi  (IndPrSg2  >süzheetima !28_V	et	f	\N
193072	soodustasid	soodustasid =soodusta  (IndIpfSg2  >soodustama !27_V	et	f	\N
193073	soodustasid	soodustasid =soodusta  (IndIpfPl3  >soodustama !27_V	et	f	\N
193086	regiväärsilisest	regiväärsilisest =silise  (SgEl  >regi+väär+siline !10_A	et	f	\N
193087	regiväärsilisest	"regi+väär+siline %si  )LINE_aA  <regi+väär+si ;26_S	et	f	\N
193090	pärandamises	pärandamises =pärandamise  (SgIn  >pärandamine !12_S	et	f	\N
193091	pärandamises	"pärandamine %päranda  )MINE_vS  <pärandama ;27_V	et	f	\N
193098	kaanel	kaanel =kaane  (SgAd  >kaas !14_S	et	f	\N
193099	kaanel	kaanel =kaane  (PlAd  >kaan !22_S	et	f	\N
193102	andev	andev =and  (PtsPrPs  >andma !34_V	et	f	\N
193103	andev	andev =andev  (SgN  >andev !02_A	et	f	\N
193104	andev	"andev %and  )V_vA  <andma ;34_V	et	f	\N
193114	ansamblidesse	?ansamblidesse =ansamblides  (SgAdt  >ansamblidene !12_A	et	f	\N
193115	ansamblidesse	?ansamblidesse =ansamblidesse  (SgG  >ansamblidesne !02_A	et	f	\N
193116	ansamblidesse	?ansamblidesse =ansamblidesse  (PlP  >ansamblidess !22_S	et	f	\N
193124	sammuks	sammuks =sammu  (SgTr  >samm !22_S	et	f	\N
193125	sammuks	sammuks =sammu  (PlTr  >samb !22_S	et	f	\N
193126	sammuks	sammuks =sammu  (KndPrPs  >sammuma !28_V	et	f	\N
193135	saarnik	?saarnik =saarnik  (SgN  >saarnik !25_S	et	f	\N
193165	esindamine	esindamine =esindamine  (SgN  >esindamine !12_S	et	f	\N
193166	esindamine	"esindamine %esinda  )MINE_vS  <esindama ;27_V	et	f	\N
193167	muusikaalsete	?muusikaalsete =muusikaalse  (PlG  >muusikaalne !02_A	et	f	\N
192807	muusikamõju	muusikamõju =mõju  (SgG  >muusika+mõju !17_S	et	f	\N
192808	muusikamõju	muusikamõju =mõju  (SgP  >muusika+mõju !17_S	et	f	\N
192813	eraldumata	eraldumata =eraldu  (SupAb  >eralduma !27_V	et	f	\N
192814	eraldumata	eraldumata =eraldumata  (ID  >eraldumata !41_A	et	f	\N
192815	eraldumata	"eraldumata %eraldu  )MATA_vA  <eralduma ;27_V	et	f	\N
192819	muljest	muljest =mulje  (SgEl  >mulje !06_S	et	f	\N
192820	muljest	muljest =muljes  (SgP  >muljene !10_A	et	f	\N
192821	muljest	"muljene %mulje  )NE_aA  <mulje ;06_S	et	f	\N
192825	korjades	?korjades =korja  (PlIn  >korja !16_S	et	f	\N
192833	koorilauluga	koorilauluga =luga  (SgN  >koori+lau+luga !18_S	et	f	\N
192834	koorilauluga	koorilauluga =luga  (SgP  >koori+lau+luga !18_S	et	f	\N
192835	koorilauluga	koorilauluga =laulu  (SgKom  >koori+laul !22_S	et	f	\N
192838	respublika	?respublika =respublika  (SgN  >respublika !01_S	et	f	\N
192839	respublika	?respublika =respublika  (SgG  >respublika !01_S	et	f	\N
192840	respublika	?respublika =respublika  (SgG  >respublikas !02_A	et	f	\N
192845	siuri	?siuri =siuri  (SgN  >siuri !16_S	et	f	\N
192846	siuri	?siuri =siuri  (SgG  >siuri !16_S	et	f	\N
192847	siuri	?siuri =siuri  (SgG  >siur !22_S	et	f	\N
192848	siuri	?siuri =siuri  (SgP  >siur !22_S	et	f	\N
192849	siuri	?siuri =siuri  (SgAdt  >siur !22_S	et	f	\N
192850	siuri	?siuri =siuri  (IndPrPs_  >siurima !28_V	et	f	\N
192851	siuri	?siuri =siuri  (ImpPrSg2  >siurima !28_V	et	f	\N
192857	estonis	?estonis =estoni  (SgIn  >eston !02_S	et	f	\N
192858	estonis	?estonis =estonis  (SgN  >estonis !11_S	et	f	\N
192865	metsavenad	?metsavenad =vena  (PlN  >metsa+vena !17_S	et	f	\N
192883	raudemasideni	raudemasideni =si  (PlTer  >raud+ema+si !26_S	et	f	\N
192884	raudemasideni	raudemasideni =side  (SgTer  >raud+ema+side !16_S	et	f	\N
192887	kaotud	kaotud =kao  (PtsPtIps  >kaduma !28_V	et	f	\N
192888	kaotud	kaotud =kaotu  (PlN  >kaotu !01_A	et	f	\N
192889	kaotud	"kaotu %kao  )TU1_vS  <kaduma ;28_V	et	f	\N
192890	kaotud	"kaotu %kao  )TU2_kA  <kabu ;18_S	et	f	\N
192891	kaotud	"kaotu %kao  )TU2_kA  <kadu ;18_S	et	f	\N
192892	kaotud	kaotud =kaotud  (ID  >kaotud !41_A	et	f	\N
192893	kaotud	"kaotud %kao  )TUD_vA  <kaduma ;28_V	et	f	\N
192903	punaarmeesse	punaarmeesse =armee  (SgIll  >puna+armee !26_S	et	f	\N
192904	punaarmeesse	punaarmeesse =armees  (SgAdt  >puna+armeene !12_A	et	f	\N
192905	punaarmeesse	"puna+armeene %armee  )NE_aA  <puna+armee ;26_S	et	f	\N
192906	kirjanikkeluuletajad	?kirjanikkeluuletajad =kirjanikkeluuletaja  (PlN  >kirjanikkeluuletaja !01_S	et	f	\N
192907	kirjanikkeluuletajad	?kirjanikkeluuletajad =kirjanikkeluuletaja  (PlN  >kirjanikkeluuletajas !02_A	et	f	\N
192908	kirjanikkeluuletajad	?kirjanikkeluuletajad =uuletaja  (PlN  >kirja+nikkel+uuletaja !01_S	et	f	\N
192909	kirjanikkeluuletajad	?kirjanikkeluuletajad =uuletaja  (PlN  >kirja+nikkel+uuletajas !02_A	et	f	\N
192910	kirjanikkeluuletajad	?kirjanikkeluuletajad =nikkeluuletaja  (PlN  >kirja+nikkeluuletaja !01_S	et	f	\N
192911	kirjanikkeluuletajad	?kirjanikkeluuletajad =nikkeluuletaja  (PlN  >kirja+nikkeluuletajas !02_A	et	f	\N
192921	novellistika	novellistika =novellistika  (SgN  >novellistika !01_S	et	f	\N
192922	novellistika	novellistika =novellistika  (SgG  >novellistika !01_S	et	f	\N
192927	kitzberg	?kitzberg =kitzberg  (SgN  >kitzberg !02_S	et	f	\N
192945	ima	ima =ima  (SgN  >ima !17_S	et	f	\N
192946	ima	ima =ima  (SgG  >ima !17_S	et	f	\N
192947	ima	ima =ima  (SgP  >ima !17_S	et	f	\N
192948	ima	ima =ima  (IndPrPs_  >imama !27_V	et	f	\N
192949	ima	ima =ima  (ImpPrSg2  >imama !27_V	et	f	\N
192954	andson	?andson =andson  (SgN  >andson !02_S	et	f	\N
192957	küüdatamist	?küüdatamist =küüdatami  (SgEl  >küüdatam !02_A	et	f	\N
192958	küüdatamist	?küüdatamist =küüdatamis  (SgP  >küüdatamis !09_S	et	f	\N
192959	küüdatamist	?küüdatamist =küüdatamis  (SgP  >küüdatamine !12_S	et	f	\N
192960	küüdatamist	?küüdatamist =küüdatamist  (SgN  >küüdatamist !22_S	et	f	\N
192967	mässamine	mässamine =mässamine  (SgN  >mässamine !12_S	et	f	\N
192968	mässamine	"mässamine %mässa  )MINE_vS  <mässama ;29_V	et	f	\N
192973	paiba	?paiba =paiba  (SgN  >paiba !16_S	et	f	\N
192974	paiba	?paiba =paiba  (SgG  >paiba !16_S	et	f	\N
192975	paiba	?paiba =paiba  (IndPrPs_  >paibama !29_V	et	f	\N
192976	paiba	?paiba =paiba  (ImpPrSg2  >paibama !29_V	et	f	\N
192977	vigala	?vigala =vigala  (SgN  >vigala !01_S	et	f	\N
192978	vigala	?vigala =vigala  (SgG  >vigala !01_S	et	f	\N
192981	korraldaja	korraldaja =korraldaja  (SgN  >korraldaja !01_S	et	f	\N
192983	korraldaja	"korraldaja %korralda  )JA_vS  <korraldama ;27_V	et	f	\N
192984	korraldaja	korraldaja =korraldaja  (SgG  >korraldaja !01_S	et	f	\N
192987	tapmist	tapmist =tapmis  (SgP  >tapmine !12?10_S	et	f	\N
192988	tapmist	"tapmine %tap  )MINE_vS  <tapma ;35_V	et	f	\N
192991	riives	riives =riive  (SgIn  >riive !06_S	et	f	\N
192992	riives	riives =riive  (PlIn  >riiv !22_S	et	f	\N
192993	esitlus	esitlus =esitlus  (SgN  >esitlus !11_S	et	f	\N
192994	esitlus	"esitlus %esitle  )US_vS  <esitlema ;27_V	et	f	\N
193001	eitati	eitati =eita  (IndIpfIps  >eitama !27_V	et	f	\N
193002	eitati	eitati =tati  (SgG  >ei+tatt !22_S	et	f	\N
193034	3-astmeliseks	-astmeliseks =astmelise  (SgTr  >-astmeline !12_A	et	f	\N
192956	okupeerimist	"okupeerimine %okupeeri  )MINE_vS  <okupeerima ;28_V	et	f	\N
192969	mõisade	?mõisade =mõisa  (PlG  >mõisa !16_S	et	f	\N
192985	peksmise	peksmise =peksmise  (SgG  >peksmine !12?10_S	et	f	\N
192986	peksmise	"peksmine %peks  )MINE_vS  <peksma ;32_V	et	f	\N
192997	usuvabadusest	usuvabadusest =vabaduse  (SgEl  >usu+vabadus !11_S	et	f	\N
192998	usuvabadusest	"usu+vabadus %vaba  )US_aS  <usu+vaba ;17_A	et	f	\N
192999	usuvabadusest	usuvabadusest =vabaduses  (SgP  >usu+vabadusene !12_A	et	f	\N
193000	usuvabadusest	"usu+vabadusene %vabaduse  )NE_aA  <usu+vabadus ;11_S	et	f	\N
193008	wabariigi	?wabariigi =wabariigi  (SgN  >wabariigi !16_S	et	f	\N
193009	wabariigi	?wabariigi =wabariigi  (SgG  >wabariigi !16_S	et	f	\N
193010	wabariigi	?wabariigi =wabariigi  (SgG  >wabariik !22_S	et	f	\N
193011	wabariigi	?wabariigi =wabariigi  (SgP  >wabariig !22_S	et	f	\N
193012	wabariigi	?wabariigi =wabariigi  (SgAdt  >wabariig !22_S	et	f	\N
193013	wabariigi	?wabariigi =wabariigi  (IndPrPs_  >wabariikima !28_V	et	f	\N
193014	wabariigi	?wabariigi =wabariigi  (ImpPrSg2  >wabariikima !28_V	et	f	\N
193015	wabariigi	?wabariigi =wabarii  (SgN^  >wabarii !26_S	et	f	\N
193016	wabariigi	?wabariigi =wabarii  (SgG^  >wabarii !26_S	et	f	\N
193021	usi	?usi =usi  (SgN  >usi !17_S	et	f	\N
193022	usi	?usi =usi  (SgG  >usi !17_S	et	f	\N
193023	usi	?usi =usi  (SgP  >usi !17_S	et	f	\N
193025	usi	?usi =usi  (IndPrPs_  >usima !27_V	et	f	\N
193027	usi	?usi =usi  (ImpPrSg2  >usima !27_V	et	f	\N
193028	aav	?aav =aav  (SgN  >aav !22_S	et	f	\N
193037	uuendatud	uuendatud =uuenda  (PtsPtIps  >uuendama !27_V	et	f	\N
193038	uuendatud	uuendatud =uuendatu  (PlN  >uuendatu !01_S	et	f	\N
193039	uuendatud	"uuendatu %uuenda  )TU1_vS  <uuendama ;27_V	et	f	\N
193040	uuendatud	uuendatud =uuendatud  (ID  >uuendatud !41_A	et	f	\N
193041	uuendatud	"uuendatud %uuenda  )TUD_vA  <uuendama ;27_V	et	f	\N
193076	isamaaliste	isamaaliste =maalis  (PlG  >isa+maaline !12?10_A	et	f	\N
193077	isamaaliste	"isa+maaline %maa  )LINE_aA  <isa+maa ;26_S	et	f	\N
193078	isamaaliste	"isa+maaline %maali  )NE_aA  <isa+maal ;22_S	et	f	\N
193079	mitmekordselt	mitmekordselt =kordse  (SgAbl  >mitme+kordne !02_AS	et	f	\N
193080	mitmekordselt	"mitme+kordselt %kordse  )LT_mD  <mitme+kordne ;02_AS	et	f	\N
193088	riimilisest	riimilisest =riimilise  (SgEl  >riimiline !12_A	et	f	\N
193089	riimilisest	"riimiline %riimi  )LINE_aA  <riim ;22_S	et	f	\N
193112	etendustel	etendustel =etendus  (PlAd  >etendus !11_S	et	f	\N
193113	etendustel	"etendus %etenda  )US_vS  <etendama ;27_V	et	f	\N
193140	peaan	?peaan =peaan  (SgN  >peaan !22_S	et	f	\N
193143	ühekoos	ühekoos =koo  (SgIn  >ühe+kubu !18_S	et	f	\N
193144	ühekoos	ühekoos =koos  (SgN  >ühe+koos !22_S	et	f	\N
193154	kaelast	kaelast =kaela  (SgEl  >kael !23?22_S	et	f	\N
193155	kaelast	kaelast =kaelas  (SgP  >kaelane !12?10_S	et	f	\N
193156	kaelast	"kaelane %kaela  )NE_aA  <kael ;22_S	et	f	\N
193157	kaelast	"kaelane %kaela  )NE_aA  <kael ;23_S	et	f	\N
193158	kaelast	kaelast =kaelast  (ID  >kaelast !41_K	et	f	\N
193159	kaelast	kaelast =ast  (SgN  >kael+ast !22_S	et	f	\N
193182	korraldatavad	korraldatavad =korraldatava  (PlN  >korraldatav !02_A	et	f	\N
193183	korraldatavad	"korraldatav %korralda  )TAV_vAS  <korraldama ;27_V	et	f	\N
193184	väljenduvad	väljenduvad =väljendu  (IndPrPl3  >väljenduma !27_V	et	f	\N
193185	väljenduvad	väljenduvad =väljenduva  (PlN  >väljenduv !02_A	et	f	\N
193186	väljenduvad	"väljenduv %väljendu  )V_vA  <väljenduma ;27_V	et	f	\N
193194	riimilaul	?riimilaul =riimilau  (SgAd  >riimilau !26_S	et	f	\N
193195	riimilaul	?riimilaul =riimilaul  (SgN  >riimilaul !19_S	et	f	\N
193216	tegidki	tegidki =teg  (IndIpfSg2^  >tegema !28_V	et	f	\N
193217	tegidki	tegidki =teg  (IndIpfPl3^  >tegema !28_V	et	f	\N
193249	ühinemine	ühinemine =ühinemine  (SgN  >ühinemine !12_S	et	f	\N
193250	ühinemine	"ühinemine %ühine  )MINE_vS  <ühinema ;27_V	et	f	\N
193261	tõenäolisega	tõenäolisega =näolise  (SgKom  >tõe+näoline !12?10_A	et	f	\N
193262	tõenäolisega	"tõe+näoline %näo  )LINE_aA  <tõe+nägu ;18_S	et	f	\N
193279	rocca	?rocca =rocca  (SgN  >rocca !16_S	et	f	\N
193280	rocca	?rocca =rocca  (SgG  >rocca !16_S	et	f	\N
193281	laulukuns	?laulukuns =laulukuns  (SgN  >laulukuns !22_S	et	f	\N
193282	laulukuns	?laulukuns =kuns  (SgN  >laulu+kuns !22_S	et	f	\N
193283	laulukuns	?laulukuns =lukuns  (SgN  >lau+lukuns !02_S	et	f	\N
193300	riimilaulud	?riimilaulud =riimilaulu  (IndPrSg2  >riimilauluma !27_V	et	f	\N
193306	laulti	?laulti =laulti  (ID  >laulti !41_D	et	f	\N
193307	laulti	?laulti =laulti  (SgP  >lault !22_S	et	f	\N
193308	laulti	?laulti =laulti  (SgAdt  >lault !22_S	et	f	\N
193320	talismaaniks	?talismaaniks =talismaani  (SgTr  >talismaani !16_S	et	f	\N
193321	talismaaniks	?talismaaniks =talismaani  (SgTr  >talismaan !22_S	et	f	\N
193322	talismaaniks	?talismaaniks =talismaani  (KndPrPs  >talismaanima !28_V	et	f	\N
193323	talismaaniks	?talismaaniks =smaani  (SgTr  >tali+smaani !16_S	et	f	\N
193324	talismaaniks	?talismaaniks =smaani  (SgTr  >tali+smaan !22_S	et	f	\N
193352	tsaari-venemaa	tsaari-venemaa =maa  (SgN  >tsaari-vene+maa !26_S	et	f	\N
193353	tsaari-venemaa	tsaari-venemaa =maa  (SgG  >tsaari-vene+maa !26_S	et	f	\N
192982	muusikaseltsi	muusikaseltsi =seltsi  (SgAdt  >muusika+selts !22_S	et	f	\N
192989	aino	?aino =aino  (SgN  >aino !16_S	et	f	\N
192990	aino	?aino =aino  (SgG  >aino !16_S	et	f	\N
192995	algklassiline	algklassiline =klassiline  (SgN  >alg+klassiline !12_A	et	f	\N
192996	algklassiline	"alg+klassiline %klassi  )LINE_aA  <alg+klass ;22_S	et	f	\N
193006	usuõpetajatest	usuõpetajatest =test  (SgN  >usu+õpetaja+test !22_S	et	f	\N
193007	usuõpetajatest	usuõpetajatest =õpetaja  (PlEl  >usu+õpetaja !01_S	et	f	\N
193019	asutakse	asutakse =asu  (IndPrIps  >asuma !27_V	et	f	\N
193020	asutakse	asutakse =takse  (PlP  >asu+taks !22_S	et	f	\N
193056	vaikivperiood	?vaikivperiood =vaikivperioo  (PlN  >vaikivperioo !26_S	et	f	\N
193057	vaikivperiood	?vaikivperiood =vaikivperioo  (SgP  >vaikivperioo !26_S	et	f	\N
193058	vaikivperiood	?vaikivperiood =vaikivperiood  (SgN  >vaikivperiood !22_S	et	f	\N
193059	vaikivperiood	?vaikivperiood =ivperioo  (PlN  >vaik+ivperioo !26_S	et	f	\N
193060	vaikivperiood	?vaikivperiood =ivperioo  (SgP  >vaik+ivperioo !26_S	et	f	\N
193061	vaikivperiood	?vaikivperiood =ivperiood  (SgN  >vaik+ivperiood !22_S	et	f	\N
193071	säilitub	?säilitub =säilitu  (IndPrSg3  >säilituma !27_V	et	f	\N
193094	eestu	?eestu =eestu  (SgN  >eestu !01_S	et	f	\N
193095	eestu	?eestu =eestu  (SgG  >eestu !01_S	et	f	\N
193096	eestu	?eestu =eestu  (IndPrPs_  >eestuma !27_V	et	f	\N
193097	eestu	?eestu =eestu  (ImpPrSg2  >eestuma !27_V	et	f	\N
193107	laulukombeid	laulukombeid =bei  (PlN  >laulu+kom+bei !26_S	et	f	\N
193108	laulukombeid	laulukombeid =bei  (SgP  >laulu+kom+bei !26_S	et	f	\N
193109	laulukombeid	laulukombeid =kombe  (PlP  >laulu+komme !06_S	et	f	\N
193122	pühenduse	pühenduse =pühenduse  (SgG  >pühendus !11_S	et	f	\N
193123	pühenduse	"pühendus %pühenda  )US_vS  <pühendama ;27_V	et	f	\N
193127	sorti	sorti =sorti  (SgP  >sort !22_S	et	f	\N
193128	sorti	sorti =sorti  (SgAdt  >sort !22_S	et	f	\N
193133	sellisteks	sellisteks =sellis  (PlTr  >selline !10_P	et	f	\N
193134	sellisteks	"selline %selli  )NE_aA  <sell ;22_S	et	f	\N
193145	pillimängist	?pillimängist =pillimängi  (SgEl  >pillimäng !02_S	et	f	\N
193146	pillimängist	?pillimängist =pillimängi  (SgEl  >pillimänk !22_S	et	f	\N
193147	pillimängist	?pillimängist =pillimängis  (SgP  >pillimängis !09_S	et	f	\N
193148	pillimängist	?pillimängist =pillimängist  (SgN  >pillimängist !22_S	et	f	\N
193149	pillimängist	?pillimängist =mängi  (SgEl  >pilli+mänk !22_S	et	f	\N
193150	pillimängist	?pillimängist =mängis  (SgP  >pilli+mängis !09_S	et	f	\N
193151	pillimängist	?pillimängist =mängist  (SgN  >pilli+mängist !22_S	et	f	\N
193152	lauluv	?lauluv =laulu  (PtsPrPs  >lauluma !28_V	et	f	\N
193153	lauluv	?lauluv =lauluv  (SgN  >lauluv !02_A	et	f	\N
193160	öösed	?öösed =ööse  (PlN  >ööse !06_S	et	f	\N
193161	öösed	?öösed =ööse  (IndPrSg2  >öösema !28_V	et	f	\N
193171	laulmisest	laulmisest =laulmise  (SgEl  >laulmine !12?10_S	et	f	\N
193172	laulmisest	"laulmine %laul  )MINE_vS  <laulma ;33_V	et	f	\N
193202	lõppriimilisest	lõppriimilisest =riimilise  (SgEl  >lõpp+riimiline !12_A	et	f	\N
193203	lõppriimilisest	"lõpp+riimiline %riimi  )LINE_aA  <lõpp+riim ;22_S	et	f	\N
193223	levinenud	?levinenud =levine  (PtsPtPs  >levinema !27_V	et	f	\N
193224	levinenud	?levinenud =levinenu  (PlN  >levinenu !01_S	et	f	\N
193225	levinenud	?levinenud =levinenu  (IndPrSg2  >levinenuma !27_V	et	f	\N
193226	levinenud	?levinenud =levinenud  (ID  >levinenud !41_A	et	f	\N
193227	levinenud	?levinenud =nenu  (PlN  >levi+nenu !17_S	et	f	\N
193239	armastajatele	armastajatele =armastaja  (PlAll  >armastaja !01_S	et	f	\N
193240	armastajatele	"armastaja %armasta  )JA_vS  <armastama ;27_V	et	f	\N
193241	klassikaliste	klassikaliste =klassikalis  (PlG  >klassikaline !12_A	et	f	\N
193242	klassikaliste	"klassikaline %klassika  )LINE_aA  <klassika ;01_S	et	f	\N
193243	klassikaliste	klassikaliste =kalis  (PlG  >klassi+kaline !10_A	et	f	\N
193244	klassikaliste	"klassi+kaline %kali  )NE_aA  <klassi+kali ;17_S	et	f	\N
193255	meeliülendavamaks	meeliülendavamaks =ülendavama  (SgTr  >meeli+ülendavam !02_A	et	f	\N
193256	meeliülendavamaks	"meeli+ülendavam %ülendava  )M_cA  <meeli+ülendav ;02_A	et	f	\N
193275	üüritustel	üüritustel =üüritus  (PlAd  >üüritus !11_S	et	f	\N
193276	üüritustel	"üüritus %üüri  )TUS1_aS  <üürima ;28_V	et	f	\N
193277	üüritustel	"üüritus %üüri  )TUS2_aS  <üür ;22_S	et	f	\N
193278	üüritustel	üüritustel =tuste  (PlAd  >üüri+tust !22_S	et	f	\N
193284	laulukogumiku	laulukogumiku =miku  (SgG  >laulu+kogu+mikk !22_S	et	f	\N
193285	laulukogumiku	laulukogumiku =kogumiku  (SgG  >laulu+kogumik !25_S	et	f	\N
193294	solo	?solo =solo  (SgN  >solo !17~16_S	et	f	\N
193295	solo	?solo =solo  (SgG  >solo !17~16_S	et	f	\N
193296	solo	?solo =solo  (SgP  >solo !17_S	et	f	\N
193325	vaimude	vaimude =vaimu  (PlG  >vaim !22_S	et	f	\N
193326	vaimude	vaimude =ude  (SgN  >vaim+ude !04_S	et	f	\N
193337	kolmased	?kolmased =kolmase  (PlN  >kolmane !10_A	et	f	\N
193338	rahvustantsu	rahvustantsu =tantsu  (SgG  >rahvus+tants !22_S	et	f	\N
193339	rahvustantsu	rahvustantsu =tantsu  (SgP  >rahvus+tants !22_S	et	f	\N
193340	rahvustantsu	rahvustantsu =tantsu  (SgAdt  >rahvus+tants !22_S	et	f	\N
193345	nõutuda	?nõutuda =nõutu  (Inf  >nõutuma !27_V	et	f	\N
193029	ühtlaskoolid	?ühtlaskoolid =ühtlaskooli  (PlN  >ühtlaskooli !16_S	et	f	\N
193030	ühtlaskoolid	?ühtlaskoolid =ühtlaskooli  (PlN  >ühtlaskool !22_S	et	f	\N
193031	ühtlaskoolid	?ühtlaskoolid =ühtlaskooli  (IndPrSg2  >ühtlaskoolima !28_V	et	f	\N
193032	ühtlaskoolid	?ühtlaskoolid =laskooli  (PlN  >üht+laskooli !16_S	et	f	\N
193033	ühtlaskoolid	?ühtlaskoolid =laskooli  (PlN  >üht+laskool !22_S	et	f	\N
193052	trükkisõna	trükkisõna =sõna  (SgN  >trükki+sõna !17_S	et	f	\N
193053	trükkisõna	trükkisõna =sõna  (SgG  >trükki+sõna !17_S	et	f	\N
193054	trükkisõna	trükkisõna =sõna  (SgP  >trükki+sõna !17_S	et	f	\N
193065	sofhoosides	?sofhoosides =sofhoosi  (PlIn  >sofhoosi !16_S	et	f	\N
193066	sofhoosides	?sofhoosides =sofhoosi  (PlIn  >sofhoos !22_S	et	f	\N
193067	sofhoosides	?sofhoosides =sofhoosi  (Ger  >sofhoosima !28_V	et	f	\N
193074	stiliseerimise	stiliseerimise =stiliseerimise  (SgG  >stiliseerimine !12_S	et	f	\N
193075	stiliseerimise	"stiliseerimine %stiliseeri  )MINE_vS  <stiliseerima ;28_V	et	f	\N
193084	kõigpealt	?kõigpealt =kõigpea  (SgAbl  >kõigpea !26_S	et	f	\N
193085	kõigpealt	?kõigpealt =kõigpealt  (ID  >kõigpealt !41_D	et	f	\N
193092	lähedamini	lähedamini =lähedami  (SgTer  >lähedam !02_A	et	f	\N
193093	lähedamini	"lähedam %läheda  )M_cA  <läheda ;02_A	et	f	\N
193111	teatrides	?teatrides =teatri  (Ger  >teatrima !28_V	et	f	\N
193117	hetkelisest	hetkelisest =hetkelise  (SgEl  >hetkeline !12_A	et	f	\N
193118	hetkelisest	"hetkeline %hetke  )LINE_aA  <hetk ;22_S	et	f	\N
193119	saadas	?saadas =saada  (SgIn  >saada !16_S	et	f	\N
193120	saadas	?saadas =saada  (IndIpfSg3  >saadama !29_V	et	f	\N
193121	saadas	?saadas =saadas  (SgN  >saadas !07_S	et	f	\N
193164	mõtteaga	?mõtteaga =mõttea  (SgKom  >mõttea !26_S	et	f	\N
193196	laulamise	?laulamise =laulamise  (SgG  >laulamine !12_S	et	f	\N
193197	laulamise	?laulamise =lamise  (SgG  >lau+lamine !10_A	et	f	\N
193198	kutsutake	?kutsutake =kutsutake  (SgN  >kutsutake !12_S	et	f	\N
193204	regivärsilisest	regivärsilisest =värsilise  (SgEl  >regi+värsiline !12_A	et	f	\N
193205	regivärsilisest	"regi+värsiline %värsi  )LINE_aA  <regi+värss ;22_S	et	f	\N
193212	pidudega	pidudega =pidu  (PlKom  >pidu !17_S	et	f	\N
193213	pidudega	pidudega =pidu  (PlKom  >pidu !18_S	et	f	\N
193218	muised	?muised =muise  (PlN  >muise !06_S	et	f	\N
193219	muised	?muised =muise  (IndPrSg2  >muisema !28_V	et	f	\N
193220	poppmuusika	?poppmuusika =poppmuusika  (SgN  >poppmuusika !01_S	et	f	\N
193221	poppmuusika	?poppmuusika =poppmuusika  (SgG  >poppmuusika !01_S	et	f	\N
193222	poppmuusika	?poppmuusika =poppmuusika  (SgG  >poppmuusikas !02_A	et	f	\N
193228	tantsimises	tantsimises =tantsimise  (SgIn  >tantsimine !12_S	et	f	\N
193229	tantsimises	"tantsimine %tantsi  )MINE_vS  <tantsima ;28_V	et	f	\N
193230	ülemaalist	ülemaalist =maali  (SgEl  >üle+maal !22_S	et	f	\N
193231	ülemaalist	ülemaalist =maalis  (SgP  >üle+maaline !12?10_A	et	f	\N
193232	ülemaalist	"üle+maaline %maa  )LINE_aA  <üle+maa ;26_S	et	f	\N
193233	ülemaalist	"üle+maaline %maali  )NE_aA  <üle+maal ;22_S	et	f	\N
193236	linnamõju	linnamõju =mõju  (SgN  >linna+mõju !17_S	et	f	\N
193237	linnamõju	linnamõju =mõju  (SgG  >linna+mõju !17_S	et	f	\N
193238	linnamõju	linnamõju =mõju  (SgP  >linna+mõju !17_S	et	f	\N
193245	klas	### klas	et	f	\N
193253	juubelilaulupeol	juubelilaulupeol =peo  (SgAd  >juubeli+laulu+pidu !18_S	et	f	\N
193254	juubelilaulupeol	juubelilaulupeol =peo  (SgAd  >juubeli+laulu+peo !26_S	et	f	\N
193271	tantsimisele	tantsimisele =tantsimise  (SgAll  >tantsimine !12_S	et	f	\N
193272	tantsimisele	"tantsimine %tantsi  )MINE_vS  <tantsima ;28_V	et	f	\N
193286	lapselapsele	lapselapsele =lapse  (SgAll  >lapse+laps !14_S	et	f	\N
193287	lapselapsele	lapselapsele =lapse  (PlAll  >lapse+laps !22_S	et	f	\N
193288	hetkeolukorrast	hetkeolukorrast =korra  (SgEl  >hetke+olu+kord !22_S	et	f	\N
193289	hetkeolukorrast	hetkeolukorrast =korras  (SgP  >hetke+olu+korrane !10_A	et	f	\N
193290	hetkeolukorrast	"hetke+olu+korrane %korra  )NE_aA  <hetke+olu+kord ;22_S	et	f	\N
193297	kuluv	kuluv =kulu  (PtsPrPs  >kuluma !27_V	et	f	\N
193298	kuluv	kuluv =kuluv  (SgN  >kuluv !02_A	et	f	\N
193299	kuluv	"kuluv %kulu  )V_vA  <kuluma ;27_V	et	f	\N
193318	ookeaania	?ookeaania =ookeaania  (SgN  >ookeaania !01_S	et	f	\N
193319	ookeaania	?ookeaania =ookeaania  (SgG  >ookeaania !01_S	et	f	\N
193335	sõjalaule	sõjalaule =lau  (SgAll  >sõja+laug !22_SA	et	f	\N
193336	sõjalaule	sõjalaule =laule  (PlP  >sõja+laul !22_S	et	f	\N
193341	regivärsiliseid	?regivärsiliseid =regivärsilisei  (PlN  >regivärsilisei !26_S	et	f	\N
193342	regivärsiliseid	?regivärsiliseid =regivärsilisei  (SgP  >regivärsilisei !26_S	et	f	\N
193343	regivärsiliseid	?regivärsiliseid =värsilisei  (PlN  >regi+värsilisei !26_S	et	f	\N
193344	regivärsiliseid	?regivärsiliseid =värsilisei  (SgP  >regi+värsilisei !26_S	et	f	\N
193356	folkloorefestivali	?folkloorefestivali =folkloorefestivali  (SgG  >folkloorefestival !19_S	et	f	\N
193357	folkloorefestivali	?folkloorefestivali =folkloorefestivali  (SgP  >folkloorefestival !19_S	et	f	\N
193358	folkloorefestivali	?folkloorefestivali =folkloorefestivali  (SgAdt  >folkloorefestival !19_S	et	f	\N
193359	folkloorefestivali	?folkloorefestivali =refestivali  (SgG  >folk+loo+refestival !19_S	et	f	\N
193360	folkloorefestivali	?folkloorefestivali =refestivali  (SgP  >folk+loo+refestival !19_S	et	f	\N
193035	3-astmeliseks	"-astmeline %astme  )LINE_aA  <-aste ;05_S	et	f	\N
193036	humanitaar-	?humanitaar- =humanitaar  (SgN  >humanitaar !22_S	et	f	\N
193042	kirikumaad	kirikumaad =maa  (PlN  >kiriku+maa !26_S	et	f	\N
193043	kirikumaad	kirikumaad =maa  (SgP  >kiriku+maa !26_S	et	f	\N
193062	elamisviisi	elamisviisi =viisi  (SgG  >elamis+viis !22_S	et	f	\N
193063	elamisviisi	elamisviisi =viisi  (SgP  >elamis+viis !22_S	et	f	\N
193064	elamisviisi	elamisviisi =viisi  (SgAdt  >elamis+viis !22_S	et	f	\N
193081	näideid	?näideid =näidei  (PlN  >näidei !26_S	et	f	\N
193082	näideid	?näideid =näidei  (SgP  >näidei !26_S	et	f	\N
193083	näideid	?näideid =näideid  (SgN  >näideid !22_S	et	f	\N
193100	raskemas	raskemas =raskema  (SgIn  >raskem !02_A	et	f	\N
193101	raskemas	"raskem %raske  )M_cA  <raske ;01_A	et	f	\N
193105	rahvapeol	rahvapeol =peo  (SgAd  >rahva+pidu !18_S	et	f	\N
193106	rahvapeol	rahvapeol =peo  (SgAd  >rahva+peo !26_S	et	f	\N
193110	rahvamassiliset	### rahvamassiliset	et	f	\N
193129	laulukogumikke	laulukogumikke =mikke  (SgG  >laulu+kogu+mike !06_S	et	f	\N
193130	laulukogumikke	"laulu+kogu+mike %mi  )KE_dS  <laulu+kogu+mi ;26_S	et	f	\N
193131	laulukogumikke	laulukogumikke =mikke  (PlP  >laulu+kogu+mikk !22_S	et	f	\N
193132	laulukogumikke	laulukogumikke =kogumikke  (PlP  >laulu+kogumik !25_S	et	f	\N
193136	vello	?vello =vello  (SgN  >vello !16_S	et	f	\N
193137	vello	?vello =vello  (SgG  >vello !16_S	et	f	\N
193138	noortepärased	noortepärased =pärase  (PlN  >noorte+pärane !10_A	et	f	\N
193139	noortepärased	"noorte+pärane %pära  )NE_aA  <noorte+pära ;17_S	et	f	\N
193141	keskid	?keskid =keski  (PlN  >keski !16_S	et	f	\N
193142	keskid	?keskid =keski  (IndPrSg2  >keskima !28_V	et	f	\N
193162	laulakse	laulakse =lakse  (SgG  >lau+lakne !02_A	et	f	\N
193163	laulakse	laulakse =lakse  (PlP  >lau+laks !22_S	et	f	\N
193173	noortefestivaalidest	?noortefestivaalidest =noortefestivaali  (PlEl  >noortefestivaali !16_S	et	f	\N
193174	noortefestivaalidest	?noortefestivaalidest =noortefestivaali  (PlEl  >noortefestivaal !22_S	et	f	\N
193175	noortefestivaalidest	?noortefestivaalidest =noortefestivaalides  (SgP  >noortefestivaalidene !12_A	et	f	\N
193176	noortefestivaalidest	?noortefestivaalidest =festivaali  (PlEl  >noorte+festivaali !16_S	et	f	\N
193177	noortefestivaalidest	?noortefestivaalidest =festivaali  (PlEl  >noorte+festivaal !22_S	et	f	\N
193178	noortefestivaalidest	?noortefestivaalidest =festivaalides  (SgP  >noorte+festivaalidene !12_A	et	f	\N
193179	noortefestivaalidest	?noortefestivaalidest =tefestivaali  (PlEl  >noor+tefestivaali !16_S	et	f	\N
193180	noortefestivaalidest	?noortefestivaalidest =tefestivaali  (PlEl  >noor+tefestivaal !22_S	et	f	\N
193181	noortefestivaalidest	?noortefestivaalidest =tefestivaalides  (SgP  >noor+tefestivaalidene !12_A	et	f	\N
193187	saamises	saamises =saamise  (SgIn  >saamine !12?10_S	et	f	\N
193188	saamises	"saamine %saa  )MINE_vS  <saama ;37_V	et	f	\N
193189	saamises	"saamine %saami  )NE_aA  <saam ;22_S	et	f	\N
193192	pärandasid	pärandasid =päranda  (IndIpfSg2  >pärandama !27_V	et	f	\N
193193	pärandasid	pärandasid =päranda  (IndIpfPl3  >pärandama !27_V	et	f	\N
193199	laulupidudele	laulupidudele =pidu  (PlAll  >laulu+pidu !17_S	et	f	\N
193200	laulupidudele	laulupidudele =pidu  (PlAll  >laulu+pidu !18_S	et	f	\N
193206	peatanud	peatanud =peata  (PtsPtPs  >peatama !27_V	et	f	\N
193207	peatanud	peatanud =peatanu  (PlN  >peatanu !01_S	et	f	\N
193208	peatanud	"peatanu %peata  )NU_vS  <peatama ;27_V	et	f	\N
193209	peatanud	peatanud =peatanud  (ID  >peatanud !41_A	et	f	\N
193210	peatanud	"peatanud %peata  )NUD_vA  <peatama ;27_V	et	f	\N
193211	peatanud	peatanud =tanu  (PlN  >pea+tanu !17_S	et	f	\N
193214	eestastes	eestastes =aste  (SgIn  >eest+aste !06_S	et	f	\N
193215	eestastes	eestastes =aste  (PlIn  >eest+ast !22_S	et	f	\N
193257	jaksu	jaksu =jaksu  (SgG  >jaks !22_S	et	f	\N
193258	jaksu	jaksu =jaksu  (SgP  >jaks !22_S	et	f	\N
193259	jaksu	jaksu =jaksu  (SgAdt  >jaks !22_S	et	f	\N
193263	festivaalist	?festivaalist =festivaali  (SgEl  >festivaali !16_S	et	f	\N
193264	festivaalist	?festivaalist =festivaali  (SgEl  >festivaal !22_S	et	f	\N
193265	festivaalist	?festivaalist =festivaalis  (SgP  >festivaalis !09_S	et	f	\N
193266	festivaalist	?festivaalist =festivaalis  (SgP  >festivaaline !12?10_A	et	f	\N
193267	instrumentina	### instrumentina	et	f	\N
193268	lõbutsimine	?lõbutsimine =lõbutsimine  (SgN  >lõbutsimine !12_S	et	f	\N
193269	lõbutsimine	?lõbutsimine =lõbutsimine  (PlP  >lõbutsimin !19_S	et	f	\N
193270	lõbutsimine	?lõbutsimine =tsimine  (SgN  >lõbu+tsimine !10_A	et	f	\N
193301	taastunud	taastunud =taastu  (PtsPtPs  >taastuma !27_V	et	f	\N
193302	taastunud	taastunud =taastunu  (PlN  >taastunu !01_S	et	f	\N
193303	taastunud	"taastunu %taastu  )NU_vS  <taastuma ;27_V	et	f	\N
193304	taastunud	taastunud =taastunud  (ID  >taastunud !41_A	et	f	\N
193305	taastunud	"taastunud %taastu  )NUD_vA  <taastuma ;27_V	et	f	\N
193309	sündmustedel	?sündmustedel =tede  (SgAd  >sündmus+tede !16_S	et	f	\N
193310	sündmustedel	?sündmustedel =tedel  (SgN  >sündmus+tedel !02_S	et	f	\N
193316	võistlustedel	?võistlustedel =tede  (SgAd  >võistlus+tede !16_S	et	f	\N
193317	võistlustedel	?võistlustedel =tedel  (SgN  >võistlus+tedel !02_S	et	f	\N
193373	veetmiseks	veetmiseks =veetmise  (SgTr  >veetmine !12?10_S	et	f	\N
193168	muusikaalsete	?muusikaalsete =alse  (PlG  >muusika+alne !02_A	et	f	\N
193169	muusikaalsete	?muusikaalsete =alse  (PlG  >muusika+alse !06_S	et	f	\N
193170	muusikaalsete	?muusikaalsete =sikaalse  (PlG  >muu+sikaalne !02_A	et	f	\N
193190	hällis	hällis =hälli  (SgIn  >häll !22_S	et	f	\N
193191	hällis	hällis =hälli  (IndIpfSg3  >hällima !28_V	et	f	\N
193201	täpäeval	?täpäeval =täpäeva  (SgAd  >täpäeva !01_S	et	f	\N
193234	ehtsam	ehtsam =ehtsam  (SgN  >ehtsam !02_A	et	f	\N
193235	ehtsam	"ehtsam %ehtsa  )M_cA  <ehtne ;02_A	et	f	\N
193246	eurolaulu	eurolaulu =laulu  (SgG  >euro+laul !22_S	et	f	\N
193247	eurolaulu	eurolaulu =laulu  (SgP  >euro+laul !22_S	et	f	\N
193248	eurolaulu	eurolaulu =laulu  (SgAdt  >euro+laul !22_S	et	f	\N
193251	riimilisteks	riimilisteks =riimilis  (PlTr  >riimiline !12_A	et	f	\N
193252	riimilisteks	"riimiline %riimi  )LINE_aA  <riim ;22_S	et	f	\N
193260	sam	### sam	et	f	\N
193273	mitmetel	mitmetel =mitme  (PlAd  >mitu !05_P	et	f	\N
193274	mitmetel	"mitu %mi  )TU2_kA  <mi ;26_S	et	f	\N
193291	lauljatest	lauljatest =laulja  (PlEl  >laulja !01_S	et	f	\N
193292	lauljatest	"laulja %laul  )JA_vS  <laulma ;33_V	et	f	\N
193293	lauljatest	lauljatest =test  (SgN  >laulja+test !22_S	et	f	\N
193311	s-dil	### s-dil	et	f	\N
193312	aastades	?aastades =aasta  (Ger  >aastama !27_V	et	f	\N
193313	aastades	?aastades =tade  (SgIn  >aas+tade !16_S	et	f	\N
193314	aastades	?aastades =tades  (SgN  >aas+tades !09_S	et	f	\N
193315	tanapaevase	?tanapaevase =tanapaevase  (SgG  >tanapaevane !12_A	et	f	\N
193327	kurjade	?kurjade =kurja  (PlG  >kurja !16_S	et	f	\N
193328	kurjade	?kurjade =kurja  (PlG  >kuri !24_A	et	f	\N
193329	kommeid	?kommeid =kommei  (PlN  >kommei !26_S	et	f	\N
193330	kommeid	?kommeid =kommei  (SgP  >kommei !26_S	et	f	\N
193331	kommeid	?kommeid =kommeid  (SgN  >kommeid !22_S	et	f	\N
193332	kommeid	?kommeid =mei  (PlN  >kom+mei !26_S	et	f	\N
193333	kommeid	?kommeid =mei  (SgP  >kom+mei !26_S	et	f	\N
193334	kommeid	?kommeid =meid  (SgN  >kom+meid !22_S	et	f	\N
193349	lapse-	lapse- =lapse  (SgG  >laps !14_S	et	f	\N
193350	lapse-	lapse- =lapse  (PlP  >laps !22_S	et	f	\N
193371	peolt	peolt =peo  (SgAbl  >pidu !18_S	et	f	\N
193372	peolt	peolt =peo  (SgAbl  >peo !26_S	et	f	\N
193394	vaslapäev	?vaslapäev =vaslapäev  (SgN  >vaslapäev !22_S	et	f	\N
193407	isamalaul	?isamalaul =isamalau  (SgAd  >isamalau !26_S	et	f	\N
193408	isamalaul	?isamalaul =isamalaul  (SgN  >isamalaul !19_S	et	f	\N
193409	isamalaul	?isamalaul =malau  (SgAd  >isa+malau !26_S	et	f	\N
193410	isamalaul	?isamalaul =malaul  (SgN  >isa+malaul !22_S	et	f	\N
193413	rahvajõudu	rahvajõudu =jõudu  (SgP  >rahva+jõud !22_S	et	f	\N
193414	rahvajõudu	rahvajõudu =jõudu  (SgAdt  >rahva+jõud !22_S	et	f	\N
193431	pannatakse	?pannatakse =panna  (IndPrIps  >pandama !29_V	et	f	\N
193432	pannatakse	?pannatakse =pannatakse  (SgG  >pannatakne !02_A	et	f	\N
193433	pannatakse	?pannatakse =pannatakse  (PlP  >pannataks !22_S	et	f	\N
193434	pannatakse	?pannatakse =atakse  (SgG  >pann+atakne !02_A	et	f	\N
193441	folklör	?folklör =folklör  (SgN  >folklör !02_S	et	f	\N
193443	meelelahetus	meelelahetus =lahetu  (SgIn  >meele+lahetu !01_AS	et	f	\N
193444	meelelahetus	"meele+lahetu %lahe  )TU2_kA  <meele+laht ;22_S	et	f	\N
193445	meelelahetus	meelelahetus =lahetus  (SgN  >meele+lahetus !11_S	et	f	\N
193446	meelelahetus	"meele+lahetus %lahe  )TUS2_aS  <meele+laht ;22_S	et	f	\N
193476	välismaalistele	välismaalistele =maalis  (PlAll  >välis+maaline !12?10_A	et	f	\N
193477	välismaalistele	"välis+maaline %maa  )LINE_aA  <välis+maa ;26_S	et	f	\N
193478	välismaalistele	"välis+maaline %maali  )NE_aA  <välis+maal ;22_S	et	f	\N
193479	koordatakse	?koordatakse =koorda  (IndPrIps  >koordama !27_V	et	f	\N
193480	koordatakse	?koordatakse =koorda  (IndPrIps  >koortama !29_V	et	f	\N
193481	koordatakse	?koordatakse =koordatakse  (SgG  >koordatakne !02_A	et	f	\N
193482	koordatakse	?koordatakse =koordatakse  (PlP  >koordataks !22_S	et	f	\N
193483	koordatakse	?koordatakse =datakse  (SgG  >koor+datakne !02_A	et	f	\N
193484	kombedel	?kombedel =bede  (SgAd  >kom+bede !16_S	et	f	\N
193485	kombedel	?kombedel =bedel  (SgN  >kom+bedel !02_S	et	f	\N
193486	lõpupool	lõpupool =pool  (ID  >lõpu+pool !41_DK	et	f	\N
193487	lõpupool	lõpupool =pool  (SgN  >lõpu+pool !13_NS	et	f	\N
193488	lõpupool	lõpupool =pool  (SgN  >lõpu+pool !22_S	et	f	\N
193508	ülemaalises	ülemaalises =maalise  (SgIn  >üle+maaline !12?10_A	et	f	\N
193509	ülemaalises	"üle+maaline %maa  )LINE_aA  <üle+maa ;26_S	et	f	\N
193510	ülemaalises	"üle+maaline %maali  )NE_aA  <üle+maal ;22_S	et	f	\N
193515	jaaipäev	?jaaipäev =jaaipäev  (SgN  >jaaipäev !22_S	et	f	\N
193519	kiikusid	kiikusid =kiiku  (PlP  >kiik !22_S	et	f	\N
193520	kiikusid	kiikusid =kiiku  (IndIpfSg2  >kiikuma !28_V	et	f	\N
193521	kiikusid	kiikusid =kiiku  (IndIpfPl3  >kiikuma !28_V	et	f	\N
193532	minevikkus	?minevikkus =minevikku  (IndIpfSg3  >minevikkuma !27_V	et	f	\N
193533	minevikkus	?minevikkus =minevikkus  (SgN  >minevikkus !11~09_S	et	f	\N
193540	muusikainstrumendide	?muusikainstrumendide =muusikainstrumendi  (PlG  >muusikainstrumend !22_S	et	f	\N
193541	muusikainstrumendide	?muusikainstrumendide =instrumendi  (PlG  >muusika+instrumend !22_S	et	f	\N
193346	nõutuda	?nõutuda =tuda  (SgN  >nõu+tuda !17_S	et	f	\N
193347	nõutuda	?nõutuda =tuda  (SgG  >nõu+tuda !17_S	et	f	\N
193348	nõutuda	?nõutuda =tuda  (SgP  >nõu+tuda !17_S	et	f	\N
193351	keegil	?keegil =keegi  (SgAd  >keek !22_S	et	f	\N
193370	ülslaulupidude	### ülslaulupidude	et	f	\N
193392	laularahv	?laularahv =laularahv  (SgN  >laularahv !22_S	et	f	\N
193393	laularahv	?laularahv =larahv  (SgN  >lau+larahv !22_S	et	f	\N
193396	kingitasid	?kingitasid =kingita  (IndIpfSg2  >kingitama !27_V	et	f	\N
193397	kingitasid	?kingitasid =kingita  (IndIpfPl3  >kingitama !27_V	et	f	\N
193398	kingitasid	?kingitasid =tasi  (PlN  >kingi+tasi !17_S	et	f	\N
193399	kingitasid	?kingitasid =ita  (PlP  >king+ita !16_S	et	f	\N
193402	tansisid	?tansisid =tansi  (PlP  >tansi !16_S	et	f	\N
193403	tansisid	?tansisid =tansi  (PlP  >tans !22_S	et	f	\N
193404	tansisid	?tansisid =tansi  (IndIpfSg2  >tansima !28_V	et	f	\N
193405	tansisid	?tansisid =tansi  (IndIpfPl3  >tansima !28_V	et	f	\N
193415	lauakse	?lauakse =lauakse  (SgG  >lauakne !02_A	et	f	\N
193416	lauakse	?lauakse =lauakse  (PlP  >lauaks !22_S	et	f	\N
193417	lauab	?lauab =lauab  (SgN  >lauab !02_S	et	f	\N
193418	levitasid	levitasid =levita  (IndIpfSg2  >levitama !27_V	et	f	\N
193419	levitasid	levitasid =levita  (IndIpfPl3  >levitama !27_V	et	f	\N
193422	janseen	?janseen =janseen  (SgN  >janseen !22_S	et	f	\N
193423	võitelda	?võitelda =võitelda  (IndPrPs_  >võiteldama !27_V	et	f	\N
193424	võitelda	?võitelda =võitelda  (ImpPrSg2  >võiteldama !27_V	et	f	\N
193425	võitelda	?võitelda =telda  (SgN  >või+telda !16_S	et	f	\N
193426	võitelda	?võitelda =telda  (SgG  >või+telda !16_S	et	f	\N
193497	tähelepanuväärsemam	?tähelepanuväärsemam =tähelepanuväärsemam  (SgN  >tähelepanuväärsemam !02_A	et	f	\N
193498	tähelepanuväärsemam	?tähelepanuväärsemam =semam  (SgN  >tähele+panu+väär+semam !02_A	et	f	\N
193499	tähelepanuväärsemam	?tähelepanuväärsemam =väärsemam  (SgN  >tähele+panu+väärsemam !02_A	et	f	\N
193500	tähelepanuväärsemam	?tähelepanuväärsemam =nuväärsemam  (SgN  >tähe+lepa+nuväärsemam !02_A	et	f	\N
193501	tähelepanuväärsemam	?tähelepanuväärsemam =panuväärsemam  (SgN  >tähele+panuväärsemam !02_A	et	f	\N
193502	tähelepanuväärsemam	?tähelepanuväärsemam =lepanuväärsemam  (SgN  >tähe+lepanuväärsemam !02_A	et	f	\N
193506	laulpeos	?laulpeos =laulpeo  (SgIn  >laulpeo !01_S	et	f	\N
193507	laulpeos	?laulpeos =laulpeos  (SgN  >laulpeos !22_S	et	f	\N
193524	vanalaule	vanalaule =lau  (SgAll  >vana+laug !22_SA	et	f	\N
193525	vanalaule	vanalaule =laule  (PlP  >vana+laul !22_S	et	f	\N
193561	viisitad	?viisitad =viisita  (IndPrSg2  >viisitama !27_V	et	f	\N
193562	viisitad	?viisitad =ita  (PlN  >viis+ita !16_S	et	f	\N
193567	tõusteda	?tõusteda =tõuste  (Inf  >tõustema !27_V	et	f	\N
193568	tõusteda	?tõusteda =steda  (SgN  >tõu+steda !17_S	et	f	\N
193569	tõusteda	?tõusteda =steda  (SgG  >tõu+steda !17_S	et	f	\N
193570	tõusteda	?tõusteda =steda  (SgP  >tõu+steda !17_S	et	f	\N
193571	rahvamuusikal	rahvamuusikal =muusika  (SgAd  >rahva+muusika !01_S	et	f	\N
193572	rahvamuusikal	rahvamuusikal =muusikal  (SgN  >rahva+muusikal !19_S	et	f	\N
193589	eestikultuuri	eestikultuuri =kultuuri  (SgG  >eesti+kultuur !22_S	et	f	\N
193590	eestikultuuri	eestikultuuri =kultuuri  (SgP  >eesti+kultuur !22_S	et	f	\N
193591	eestikultuuri	eestikultuuri =kultuuri  (SgAdt  >eesti+kultuur !22_S	et	f	\N
193592	vokaalselt	vokaalselt =vokaalse  (SgAbl  >vokaalne !02_A	et	f	\N
193593	vokaalselt	vokaalselt =vokaalselt  (ID  >vokaalselt !41_D	et	f	\N
193594	vokaalselt	"vokaalselt %vokaalse  )LT_mD  <vokaalne ;02_A	et	f	\N
193600	kõikasid	?kõikasid =kõika  (PlP  >kõika !16_S	et	f	\N
193601	kõikasid	?kõikasid =kõika  (IndIpfSg2  >kõikama !29_V	et	f	\N
193602	kõikasid	?kõikasid =kõika  (IndIpfPl3  >kõikama !29_V	et	f	\N
193603	kõikasid	?kõikasid =kõikasi  (PlN  >kõikas !02_A	et	f	\N
193627	mureid	?mureid =murei  (PlN  >murei !26_S	et	f	\N
193628	mureid	?mureid =murei  (SgP  >murei !26_S	et	f	\N
193629	mureid	?mureid =mureid  (SgN  >mureid !22_S	et	f	\N
193634	naidata	?naidata =naida  (SgAb  >naida !16_S	et	f	\N
193635	naidata	?naidata =naidata  (IndPrPs_  >naidatama !27_V	et	f	\N
193636	naidata	?naidata =naidata  (ImpPrSg2  >naidatama !27_V	et	f	\N
193637	jaavad	?jaavad =jaava  (PlN  >jaava !16_S	et	f	\N
193638	jaavad	?jaavad =jaava  (IndPrSg2  >jaavama !29_V	et	f	\N
193641	tantsuti	?tantsuti =tantsu  (IndIpfIps  >tantsuma !28_V	et	f	\N
193642	tantsuti	?tantsuti =tantsuti  (SgN  >tantsuti !01_S	et	f	\N
193643	tantsuti	?tantsuti =tantsuti  (SgG  >tantsuti !01_S	et	f	\N
193644	tantsuti	?tantsuti =tantsuti  (SgG  >tantsut !02_S	et	f	\N
193645	tantsuti	?tantsuti =tantsuti  (SgG  >tantsutt !22_S	et	f	\N
193646	tantsuti	?tantsuti =tantsuti  (IndPrPs_  >tantsuttima !28_V	et	f	\N
193647	tantsuti	?tantsuti =tantsuti  (ImpPrSg2  >tantsuttima !28_V	et	f	\N
193662	eeskujutud	eeskujutud =kujutu  (PlN  >ees+kujutu !01_A	et	f	\N
193663	eeskujutud	"ees+kujutu %kuju  )TU2_kA  <ees+kuju ;17_S	et	f	\N
193738	muretseid	?muretseid =muretse  (PlP  >muretne !02_A	et	f	\N
193739	muretseid	?muretseid =muretsei  (PlN  >muretsei !26_S	et	f	\N
193740	muretseid	?muretseid =muretsei  (SgP  >muretsei !26_S	et	f	\N
193741	muretseid	?muretseid =sei  (PlN  >muret+sei !26_S	et	f	\N
193354	laulaväljakul	?laulaväljakul =laulaväljakul  (SgN  >laulaväljakul !19_S	et	f	\N
193355	laulaväljakul	?laulaväljakul =laväljakul  (SgN  >lau+laväljakul !19_S	et	f	\N
193365	laularahvaks	?laularahvaks =laularahva  (SgTr  >laularahva !16_S	et	f	\N
193366	laularahvaks	?laularahvaks =larahva  (SgTr  >lau+larahva !01_S	et	f	\N
193379	ülemaalisel	ülemaalisel =maalise  (SgAd  >üle+maaline !12?10_A	et	f	\N
193380	ülemaalisel	"üle+maaline %maa  )LINE_aA  <üle+maa ;26_S	et	f	\N
193381	ülemaalisel	"üle+maaline %maali  )NE_aA  <üle+maal ;22_S	et	f	\N
193390	laulukooris	laulukooris =koori  (SgIn  >laulu+koor !22_S	et	f	\N
193391	laulukooris	laulukooris =koori  (PlIn  >laulu+koor !13_S	et	f	\N
193420	rahvapidudel	rahvapidudel =pidu  (PlAd  >rahva+pidu !17_S	et	f	\N
193421	rahvapidudel	rahvapidudel =pidu  (PlAd  >rahva+pidu !18_S	et	f	\N
193429	rahvapidudest	rahvapidudest =pidu  (PlEl  >rahva+pidu !17_S	et	f	\N
193430	rahvapidudest	rahvapidudest =pidu  (PlEl  >rahva+pidu !18_S	et	f	\N
193468	valdkonnal	valdkonnal =valdkonna  (SgAd  >valdkond !22_S	et	f	\N
193469	valdkonnal	valdkonnal =konna  (SgAd  >vald+konn !22_S	et	f	\N
193471	pehmelt	pehmelt =pehme  (SgAbl  >pehme !01_A	et	f	\N
193474	pehmelt	pehmelt =pehmelt  (ID  >pehmelt !41_D	et	f	\N
193475	pehmelt	"pehmelt %pehme  )LT_mD  <pehme ;01_A	et	f	\N
193495	laulpeod	?laulpeod =laulpeo  (PlN  >laulpeo !01_S	et	f	\N
193496	laulpeod	?laulpeod =laulpeod  (SgN  >laulpeod !22_S	et	f	\N
193522	kiikude	kiikude =kiiku  (PlG  >kiik !22_S	et	f	\N
193523	kiikude	kiikude =ude  (SgN  >kiik+ude !04_S	et	f	\N
193530	korraldamis	?korraldamis =korraldami  (SgIn  >korraldam !02_A	et	f	\N
193531	korraldamis	?korraldamis =korraldamis  (SgN  >korraldamis !09_S	et	f	\N
193534	tõustada	?tõustada =tõusta  (Inf  >tõustama !27_V	et	f	\N
193535	tõustada	?tõustada =stada  (SgN  >tõu+stada !17_S	et	f	\N
193536	tõustada	?tõustada =stada  (SgG  >tõu+stada !17_S	et	f	\N
193537	tõustada	?tõustada =stada  (SgP  >tõu+stada !17_S	et	f	\N
193608	kokkusaades	?kokkusaades =kokkusaa  (PlIn  >kokkusaa !26_S	et	f	\N
193610	kokkusaades	?kokkusaades =kokkusaade  (SgIn  >kokkusaade !16_S	et	f	\N
193612	kokkusaades	?kokkusaades =kokkusaade  (PlIn  >kokkusaat !22_S	et	f	\N
193613	kokkusaades	?kokkusaades =saa  (PlIn  >kokku+saa !26_S	et	f	\N
193614	kokkusaades	?kokkusaades =saades  (SgN  >kokku+saades !09_S	et	f	\N
193624	naitavad	?naitavad =naita  (IndPrPl3  >naitama !27_V	et	f	\N
193625	naitavad	?naitavad =naitava  (PlN  >naitava !01_S	et	f	\N
193626	naitavad	?naitavad =naitava  (PlN  >naitav !02_A	et	f	\N
193651	piili	?piili =piili  (SgN  >piili !16_S	et	f	\N
193652	piili	?piili =piili  (SgG  >piili !16_S	et	f	\N
193653	piili	?piili =piili  (SgG  >piil !22_S	et	f	\N
193654	piili	?piili =piili  (SgP  >piil !22_S	et	f	\N
193655	piili	?piili =piili  (SgAdt  >piil !22_S	et	f	\N
193656	piili	?piili =piili  (IndPrPs_  >piilima !28_V	et	f	\N
193657	piili	?piili =piili  (ImpPrSg2  >piilima !28_V	et	f	\N
193670	kassari	kassari =sari  (SgN  >kas+sari !17_S	et	f	\N
193671	kassari	kassari =sari  (SgN  >kas+sari !24_S	et	f	\N
193672	kassari	kassari =sari  (SgG  >kas+sari !17_S	et	f	\N
193673	kassari	kassari =sari  (SgP  >kas+sari !17_S	et	f	\N
193676	folklori	folklori =lori  (SgN  >folk+lori !17_S	et	f	\N
193677	folklori	folklori =lori  (SgG  >folk+lori !17_S	et	f	\N
193678	folklori	folklori =lori  (SgP  >folk+lori !17_S	et	f	\N
193690	cats	?cats =cats  (SgN  >cats !22_S	et	f	\N
193697	muusikalistes	muusikalistes =muusikalis  (PlIn  >muusikaline !12_A	et	f	\N
193698	muusikalistes	"muusikaline %muusika  )LINE_aA  <muusika ;01_S	et	f	\N
193699	muusikalistes	"muusikaline %muusikali  )NE_aA  <muusikal ;19_S	et	f	\N
193700	ilusamadest	?ilusamadest =ilusamades  (SgP  >ilusamadene !12_A	et	f	\N
193701	ilusamadest	?ilusamadest =samades  (SgP  >ilu+samadene !12_A	et	f	\N
193717	jazzi-	?jazzi- =jazzi  (SgN  >jazzi !16_S	et	f	\N
193718	jazzi-	?jazzi- =jazzi  (SgG  >jazzi !16_S	et	f	\N
193726	loobu	loobu =loobu  (IndPrPs_  >loobuma !27_V	et	f	\N
193727	loobu	loobu =loobu  (ImpPrSg2  >loobuma !27_V	et	f	\N
193753	lemmikum	?lemmikum =lemmikum  (SgN  >lemmikum !19_S	et	f	\N
193786	lauluidee	lauluidee =idee  (SgN  >laulu+idee !26_S	et	f	\N
193787	lauluidee	lauluidee =idee  (SgG  >laulu+idee !26_S	et	f	\N
193794	laulutega	### laulutega	et	f	\N
193802	laulmikud	?laulmikud =laulmiku  (PlN  >laulmik !25_S	et	f	\N
193803	laulmikud	?laulmikud =laulmiku  (PlN  >laulmiku !01_S	et	f	\N
193804	laulmikud	?laulmikud =laulmiku  (IndPrSg2  >laulmikuma !27_V	et	f	\N
193807	liikumiste	liikumiste =liikumis  (PlG  >liikumine !12_S	et	f	\N
193808	liikumiste	"liikumine %liiku  )MINE_vS  <liikuma ;28_V	et	f	\N
193813	tehed	?tehed =tehe  (IndPrSg2  >tehema !27_V	et	f	\N
193817	lindistused	lindistused =lindistuse  (PlN  >lindistus !11_S	et	f	\N
193818	lindistused	"lindistus %lindista  )US_vS  <lindistama ;27_V	et	f	\N
193826	ammu-ammu	ammu-ammu =ammu  (ID  >ammu-ammu !41_D	et	f	\N
193827	ammu-ammu	ammu-ammu =ammu  (SgG  >ammu-amb !22_S	et	f	\N
193828	ammu-ammu	ammu-ammu =ammu  (IndPrPs_  >ammu-ammuma !28_V	et	f	\N
193829	ammu-ammu	ammu-ammu =ammu  (IndPrPs_  >ammu-ambuma !28_V	et	f	\N
193830	ammu-ammu	ammu-ammu =ammu  (ImpPrSg2  >ammu-ammuma !28_V	et	f	\N
193361	folkloorefestivali	?folkloorefestivali =refestivali  (SgAdt  >folk+loo+refestival !19_S	et	f	\N
193362	folkloorefestivali	?folkloorefestivali =loorefestivali  (SgG  >folk+loorefestival !19_S	et	f	\N
193363	folkloorefestivali	?folkloorefestivali =loorefestivali  (SgP  >folk+loorefestival !19_S	et	f	\N
193364	folkloorefestivali	?folkloorefestivali =loorefestivali  (SgAdt  >folk+loorefestival !19_S	et	f	\N
193367	austavad	austavad =austa  (IndPrPl3  >austama !27_V	et	f	\N
193368	austavad	austavad =austava  (PlN  >austav !02_A	et	f	\N
193369	austavad	"austav %austa  )V_vA  <austama ;27_V	et	f	\N
193387	sfääri	sfääri =sfääri  (SgG  >sfäär !22_S	et	f	\N
193388	sfääri	sfääri =sfääri  (SgP  >sfäär !22_S	et	f	\N
193389	sfääri	sfääri =sfääri  (SgAdt  >sfäär !22_S	et	f	\N
193395	selledes	### selledes	et	f	\N
193400	õnnetlesid	?õnnetlesid =õnnetle  (IndIpfSg2  >õnnetlema !27_V	et	f	\N
193401	õnnetlesid	?õnnetlesid =õnnetle  (IndIpfPl3  >õnnetlema !27_V	et	f	\N
193435	põhusi	?põhusi =põhusi  (ID  >põhusi !41_D	et	f	\N
193439	arenemisesse	arenemisesse =arenemise  (SgIll  >arenemine !12_S	et	f	\N
193440	arenemisesse	"arenemine %arene  )MINE_vS  <arenema ;27_V	et	f	\N
193442	variantid	### variantid	et	f	\N
193470	meloodiliselt	meloodiliselt =meloodilise  (SgAbl  >meloodiline !12_A	et	f	\N
193472	meloodiliselt	meloodiliselt =meloodiliselt  (ID  >meloodiliselt !41_D	et	f	\N
193473	meloodiliselt	"meloodiliselt %meloodilise  )LT_mD  <meloodiline ;12_A	et	f	\N
193493	rahvafolklor	?rahvafolklor =rahvafolklor  (SgN  >rahvafolklor !02_S	et	f	\N
193494	rahvafolklor	?rahvafolklor =folklor  (SgN  >rahva+folklor !02_S	et	f	\N
193503	soovija	soovija =soovija  (SgN  >soovija !01_S	et	f	\N
193504	soovija	"soovija %soovi  )JA_vS  <soovima ;28_V	et	f	\N
193505	soovija	soovija =soovija  (SgG  >soovija !01_S	et	f	\N
193511	tansu	?tansu =tansu  (SgN  >tansu !16_S	et	f	\N
193512	tansu	?tansu =tansu  (SgG  >tansu !16_S	et	f	\N
193513	tansu	?tansu =tansu  (IndPrPs_  >tansuma !27_V	et	f	\N
193514	tansu	?tansu =tansu  (ImpPrSg2  >tansuma !27_V	et	f	\N
193516	tansesid	?tansesid =tanse  (IndIpfSg2  >tansema !27_V	et	f	\N
193517	tansesid	?tansesid =tanse  (IndIpfPl3  >tansema !27_V	et	f	\N
193563	abitseda	?abitseda =abitse  (Inf  >abitsema !27_V	et	f	\N
193564	abitseda	?abitseda =tseda  (SgN  >abi+tseda !17_S	et	f	\N
193565	abitseda	?abitseda =tseda  (SgG  >abi+tseda !17_S	et	f	\N
193566	abitseda	?abitseda =tseda  (SgP  >abi+tseda !17_S	et	f	\N
193581	tradatsioonid	?tradatsioonid =tradatsiooni  (PlN  >tradatsiooni !16_S	et	f	\N
193582	tradatsioonid	?tradatsioonid =tradatsiooni  (PlN  >tradatsioon !22_S	et	f	\N
193583	tradatsioonid	?tradatsioonid =tradatsiooni  (IndPrSg2  >tradatsioonima !28_V	et	f	\N
193584	tundav	?tundav =tunda  (PtsPrPs  >tundama !29_V	et	f	\N
193585	tundav	?tundav =tundav  (SgN  >tundav !02_A	et	f	\N
193618	tennima	?tennima =tenni  (Sup  >tennima !28_V	et	f	\N
193619	tennima	?tennima =tennima  (SgG  >tennim !02_A	et	f	\N
193622	bojan	?bojan =boja  (IndPrSg1  >bojama !27_V	et	f	\N
193623	bojan	?bojan =bojan  (SgN  >bojan !02_S	et	f	\N
193639	laularahvaseks	?laularahvaseks =laularahvase  (SgTr  >laularahvane !12_A	et	f	\N
193640	laularahvaseks	?laularahvaseks =larahvase  (SgTr  >lau+larahvane !12_A	et	f	\N
193664	rahvaviisi	rahvaviisi =viisi  (ID  >rahva+viisi !41_D	et	f	\N
193665	rahvaviisi	rahvaviisi =viisi  (SgG  >rahva+viis !22_S	et	f	\N
193666	rahvaviisi	rahvaviisi =viisi  (SgP  >rahva+viis !22_S	et	f	\N
193667	rahvaviisi	rahvaviisi =viisi  (SgAdt  >rahva+viis !22_S	et	f	\N
193680	tantsuda	?tantsuda =tantsu  (Inf  >tantsuma !28_V	et	f	\N
193688	vabaduseni	vabaduseni =vabaduse  (SgTer  >vabadus !11_S	et	f	\N
193689	vabaduseni	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
193695	romeo	?romeo =romeo  (SgN  >romeo !01_S	et	f	\N
193696	romeo	?romeo =romeo  (SgG  >romeo !01_S	et	f	\N
193702	muusikafestivaale	?muusikafestivaale =muusikafestivaa  (SgAll  >muusikafestivaa !26_S	et	f	\N
193703	muusikafestivaale	?muusikafestivaale =muusikafestivaale  (SgN  >muusikafestivaale !16_S	et	f	\N
193704	muusikafestivaale	?muusikafestivaale =muusikafestivaale  (SgG  >muusikafestivaale !16_S	et	f	\N
193705	muusikafestivaale	?muusikafestivaale =muusikafestivaale  (PlP  >muusikafestivaal !22_S	et	f	\N
193706	muusikafestivaale	?muusikafestivaale =festivaa  (SgAll  >muusika+festivaa !26_S	et	f	\N
193707	muusikafestivaale	?muusikafestivaale =festivaale  (SgN  >muusika+festivaale !16_S	et	f	\N
193708	muusikafestivaale	?muusikafestivaale =festivaale  (SgG  >muusika+festivaale !16_S	et	f	\N
193709	muusikafestivaale	?muusikafestivaale =festivaale  (PlP  >muusika+festivaal !22_S	et	f	\N
193710	muusikafestivaale	?muusikafestivaale =sikafestivaa  (SgAll  >muu+sikafestivaa !26_S	et	f	\N
193711	muusikafestivaale	?muusikafestivaale =sikafestivaale  (SgN  >muu+sikafestivaale !16_S	et	f	\N
193713	muusikafestivaale	?muusikafestivaale =sikafestivaale  (SgG  >muu+sikafestivaale !16_S	et	f	\N
193714	muusikafestivaale	?muusikafestivaale =sikafestivaale  (PlP  >muu+sikafestivaal !22_S	et	f	\N
193734	dagö	### dagö	et	f	\N
193747	südmusi	?südmusi =südmusi  (ID  >südmusi !41_D	et	f	\N
193748	südmusi	?südmusi =südmusi  (PlP  >südmus !11_S	et	f	\N
193769	valgustustuaja	?valgustustuaja =valgustustuaja  (SgN  >valgustustuaja !01_S	et	f	\N
193770	valgustustuaja	?valgustustuaja =valgustustuaja  (SgG  >valgustustuaja !01_S	et	f	\N
193374	veetmiseks	"veetmine %veet  )MINE_vS  <veetma ;34_V	et	f	\N
193375	anse	?anse =anse  (SgN  >anse !06_S	et	f	\N
193376	anse	?anse =anse  (PlP  >ans !22_S	et	f	\N
193377	anse	?anse =anse  (IndPrPs_  >ansema !27_V	et	f	\N
193378	anse	?anse =anse  (ImpPrSg2  >ansema !27_V	et	f	\N
193382	lõtspiil	?lõtspiil =lõtspi  (PlAd  >lõtspi !01_S	et	f	\N
193383	lõtspiil	?lõtspiil =lõtspii  (SgAd  >lõtspii !26_S	et	f	\N
193384	lõtspiil	?lõtspiil =lõtspiil  (SgN  >lõtspiil !22_S	et	f	\N
193385	võistelda	võistelda =võistel  (Inf  >võistlema !30_V	et	f	\N
193386	võistelda	võistelda =võistel  (IndPrIps_  >võistlema !30_V	et	f	\N
193406	sündmüs	### sündmüs	et	f	\N
193411	tunneta	tunneta =tunneta  (IndPrPs_  >tunnetama !27_V	et	f	\N
193412	tunneta	tunneta =tunneta  (ImpPrSg2  >tunnetama !27_V	et	f	\N
193427	kiihnul	?kiihnul =kiihnu  (SgAd  >kiihnu !01_S	et	f	\N
193428	kiihnul	?kiihnul =kiihnul  (SgN  >kiihnul !02_S	et	f	\N
193436	kontrollisid	kontrollisid =kontrolli  (PlP  >kontroll !22_S	et	f	\N
193437	kontrollisid	kontrollisid =kontrolli  (IndIpfSg2  >kontrollima !28_V	et	f	\N
193438	kontrollisid	kontrollisid =kontrolli  (IndIpfPl3  >kontrollima !28_V	et	f	\N
193447	19-	### 19-	et	f	\N
193448	väärtlised	?väärtlised =väärtlise  (PlN  >väärtline !12~10_A	et	f	\N
193449	väärtlised	?väärtlised =väärtlise  (IndPrSg2  >väärtlisema !27_V	et	f	\N
193450	kaasatundlus	?kaasatundlus =kaasatundlu  (IndIpfSg3  >kaasatundluma !27_V	et	f	\N
193451	kaasatundlus	?kaasatundlus =kaasatundlus  (SgN  >kaasatundlus !11~09_S	et	f	\N
193452	kaasatundlus	?kaasatundlus =tundlu  (SgIn  >kaasa+tundlu !01_S	et	f	\N
193453	kaasatundlus	?kaasatundlus =tundlus  (SgN  >kaasa+tundlus !11~09_S	et	f	\N
193454	kaasatundlus	?kaasatundlus =atundlu  (SgIn  >kaas+atundlu !01_S	et	f	\N
193455	kaasatundlus	?kaasatundlus =atundlus  (SgN  >kaas+atundlus !11~09_S	et	f	\N
193456	tänapaeva	?tänapaeva =tänapaeva  (SgN  >tänapaeva !16_S	et	f	\N
193457	tänapaeva	?tänapaeva =tänapaeva  (SgG  >tänapaeva !16_S	et	f	\N
193458	tänapaeva	?tänapaeva =paeva  (SgN  >täna+paeva !16_S	et	f	\N
193459	tänapaeva	?tänapaeva =paeva  (SgG  >täna+paeva !16_S	et	f	\N
193460	mateljaalid	?mateljaalid =mateljaali  (PlN  >mateljaali !16_S	et	f	\N
193461	mateljaalid	?mateljaalid =mateljaali  (PlN  >mateljaal !22_S	et	f	\N
193462	mateljaalid	?mateljaalid =mateljaali  (IndPrSg2  >mateljaalima !28_V	et	f	\N
193463	harrimustest	?harrimustest =harrimus  (PlEl  >harrimus !11_S	et	f	\N
193464	harrimustest	?harrimustest =harrimustes  (SgP  >harrimustene !12_A	et	f	\N
193465	etendus	etendus =etendu  (IndIpfSg3  >etenduma !27_V	et	f	\N
193466	etendus	etendus =etendus  (SgN  >etendus !11_S	et	f	\N
193467	etendus	"etendus %etenda  )US_vS  <etendama ;27_V	et	f	\N
193489	tänapäevasel	tänapäevasel =päevase  (SgAd  >täna+päevane !10_A	et	f	\N
193490	tänapäevasel	"täna+päevane %päeva  )NE_aA  <täna+päev ;22_S	et	f	\N
193491	kiigutasid	kiigutasid =kiiguta  (IndIpfSg2  >kiigutama !27_V	et	f	\N
193492	kiigutasid	kiigutasid =kiiguta  (IndIpfPl3  >kiigutama !27_V	et	f	\N
193518	lõkket	?lõkket =lõkke  (SgP  >lõkke !06_S	et	f	\N
193526	vanansu	?vanansu =vanansu  (SgN  >vanansu !01_S	et	f	\N
193527	vanansu	?vanansu =vanansu  (SgG  >vanansu !01_S	et	f	\N
193528	vanansu	?vanansu =vanansu  (IndPrPs_  >vanansuma !27_V	et	f	\N
193529	vanansu	?vanansu =vanansu  (ImpPrSg2  >vanansuma !27_V	et	f	\N
193538	loomide	loomide =loomi  (PlG  >loom !22_S	et	f	\N
193539	loomide	loomide =mi  (PlG  >loo+mi !26_S	et	f	\N
193546	taasiseisvuseni	?taasiseisvuseni =taasiseisvuse  (SgTer  >taasiseisvus !11~09_S	et	f	\N
193547	taasiseisvuseni	?taasiseisvuseni =taasiseisvuseni  (SgG  >taasiseisvusen !19_S	et	f	\N
193548	taasiseisvuseni	?taasiseisvuseni =taasiseisvuseni  (SgP  >taasiseisvusen !19_S	et	f	\N
193549	taasiseisvuseni	?taasiseisvuseni =taasiseisvuseni  (SgAdt  >taasiseisvusen !19_S	et	f	\N
193550	taasiseisvuseni	?taasiseisvuseni =isvuse  (SgTer  >taas+ise+isvus !11~09_S	et	f	\N
193551	taasiseisvuseni	?taasiseisvuseni =isvuseni  (SgG  >taas+ise+isvusen !19_S	et	f	\N
193552	taasiseisvuseni	?taasiseisvuseni =isvuseni  (SgP  >taas+ise+isvusen !19_S	et	f	\N
193553	taasiseisvuseni	?taasiseisvuseni =isvuseni  (SgAdt  >taas+ise+isvusen !19_S	et	f	\N
193554	taasiseisvuseni	?taasiseisvuseni =iseisvuse  (SgTer  >taas+iseisvus !11_S	et	f	\N
193555	taasiseisvuseni	?taasiseisvuseni =iseisvuseni  (SgG  >taas+iseisvusen !19_S	et	f	\N
193556	taasiseisvuseni	?taasiseisvuseni =iseisvuseni  (SgP  >taas+iseisvusen !19_S	et	f	\N
193557	taasiseisvuseni	?taasiseisvuseni =iseisvuseni  (SgAdt  >taas+iseisvusen !19_S	et	f	\N
193573	huvitaval	huvitaval =huvitava  (SgAd  >huvitav !02_A	et	f	\N
193574	huvitaval	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
193575	huvitaval	huvitaval =tava  (SgAd  >huvi+tava !17_S	et	f	\N
193586	vanakultuuriga	vanakultuuriga =iga  (SgN  >vana+kultuur+iga !18_S	et	f	\N
193587	vanakultuuriga	vanakultuuriga =iga  (SgP  >vana+kultuur+iga !18_S	et	f	\N
193588	vanakultuuriga	vanakultuuriga =kultuuri  (SgKom  >vana+kultuur !22_S	et	f	\N
193604	ümberlausid	?ümberlausid =ümberlau  (PlP  >ümberlau !26_S	et	f	\N
193605	ümberlausid	?ümberlausid =ümberlausi  (PlN  >ümberlausi !16_S	et	f	\N
193606	ümberlausid	?ümberlausid =ümberlausi  (IndPrSg2  >ümberlausima !28_V	et	f	\N
193607	ümberlausid	?ümberlausid =lau  (PlP  >ümber+lau !26_S	et	f	\N
193542	muusikainstrumendide	?muusikainstrumendide =sikainstrumendi  (PlG  >muu+sikainstrumend !22_S	et	f	\N
193543	naistkoorid	?naistkoorid =naistkoori  (PlN  >naistkoori !16_S	et	f	\N
193544	naistkoorid	?naistkoorid =naistkoori  (PlN  >naistkoor !22_S	et	f	\N
193545	naistkoorid	?naistkoorid =naistkoori  (IndPrSg2  >naistkoorima !28_V	et	f	\N
193558	arkamisaja	?arkamisaja =arkamisaja  (SgN  >arkamisaja !01_S	et	f	\N
193559	arkamisaja	?arkamisaja =arkamisaja  (SgG  >arkamisaja !01_S	et	f	\N
193560	arkamisaja	?arkamisaja =arkamisaja  (SgG  >arkamisajas !02_A	et	f	\N
193576	lauluda	lauluda =luda  (SgN  >lau+luda !17_S	et	f	\N
193577	lauluda	lauluda =luda  (SgG  >lau+luda !17_S	et	f	\N
193578	lauluda	lauluda =luda  (SgP  >lau+luda !17_S	et	f	\N
193579	koorisse	koorisse =koori  (SgIll  >koor !22_S	et	f	\N
193580	koorisse	koorisse =koori  (PlIll  >koor !13_S	et	f	\N
193595	pilita	?pilita =pili  (SgAb  >pili !17_S	et	f	\N
193596	pilita	?pilita =pili  (IndPrIps_  >pilima !27_V	et	f	\N
193597	pilita	?pilita =pilita  (IndPrPs_  >pilitama !27_V	et	f	\N
193598	pilita	?pilita =pilita  (ImpPrSg2  >pilitama !27_V	et	f	\N
193599	kulturise	?kulturise =kulturise  (SgG  >kulturis !11_S	et	f	\N
193615	puttu	?puttu =puttu  (ID  >puttu !41_D	et	f	\N
193616	puttu	?puttu =puttu  (IndPrPs_  >puttuma !27_V	et	f	\N
193617	puttu	?puttu =puttu  (ImpPrSg2  >puttuma !27_V	et	f	\N
193630	folklööransamble	### folklööransamble	et	f	\N
193658	maie	?maie =maie  (SgN  >maie !06_S	et	f	\N
193659	maie	?maie =maie  (SgG  >maie !06_S	et	f	\N
193681	meelelahutada	?meelelahutada =meelelahuta  (Inf  >meelelahutama !27_V	et	f	\N
193682	eriliste	eriliste =erilis  (PlG  >eriline !12_A	et	f	\N
193683	eriliste	"eriline %eri  )LINE_aA  <eri ;17_S	et	f	\N
193684	vaimuvabadus	vaimuvabadus =vabadus  (SgN  >vaimu+vabadus !11_S	et	f	\N
193685	vaimuvabadus	"vaimu+vabadus %vaba  )US_aS  <vaimu+vaba ;17_A	et	f	\N
193686	vedaski	vedaski =veda  (SgIn^  >veda !17_S	et	f	\N
193687	vedaski	vedaski =veda  (IndIpfSg3^  >vedama !28_V	et	f	\N
193712	jazzkarr	?jazzkarr =jazzkarr  (SgN  >jazzkarr !22_S	et	f	\N
193715	klassika-	klassika- =klassika  (SgN  >klassika !01_S	et	f	\N
193716	klassika-	klassika- =klassika  (SgG  >klassika !01_S	et	f	\N
193732	hoidjaks	hoidjaks =hoidja  (SgTr  >hoidja !01_S	et	f	\N
193733	hoidjaks	"hoidja %hoid  )JA_vS  <hoidma ;34_V	et	f	\N
193735	täpsusega	täpsusega =täpsuse  (SgKom  >täpsus !11~09_S	et	f	\N
193736	täpsusega	"täpsus %täpsa  )US_aS  <täppis ;02_A	et	f	\N
193737	täpsusega	"täpsus %täpse  )US_aS  <täpne ;02_A	et	f	\N
193755	linnamuusika	linnamuusika =muusika  (SgN  >linna+muusika !01_S	et	f	\N
193756	linnamuusika	linnamuusika =muusika  (SgG  >linna+muusika !01_S	et	f	\N
193762	taastamise	taastamise =taastamise  (SgG  >taastamine !12_S	et	f	\N
193763	taastamise	"taastamine %taasta  )MINE_vS  <taastama ;27_V	et	f	\N
193788	teostasid	teostasid =teosta  (IndIpfSg2  >teostama !27_V	et	f	\N
193789	teostasid	teostasid =teosta  (IndIpfPl3  >teostama !27_V	et	f	\N
193809	ühinenuna	ühinenuna =ühinenu  (SgEs  >ühinenu !01_S	et	f	\N
193810	ühinenuna	"ühinenu %ühine  )NU_vS  <ühinema ;27_V	et	f	\N
193814	hällilaule	hällilaule =lau  (SgAll  >hälli+laug !22_SA	et	f	\N
193815	hällilaule	hällilaule =laule  (PlP  >hälli+laul !22_S	et	f	\N
193844	koorilaule	koorilaule =lau  (SgAll  >koori+laug !22_SA	et	f	\N
193845	koorilaule	koorilaule =laule  (PlP  >koori+laul !22_S	et	f	\N
193848	meelelahutamisek	### meelelahutamisek	et	f	\N
193871	pääsuke	pääsuke =pääsuke  (SgN  >pääsuke !12_S	et	f	\N
193872	pääsuke	"pääsuke %pääsu  )KE_dS  <pääsu ;16_S	et	f	\N
193873	pääsuke	"pääsuke %pääsu  )KE_dS  <pääs ;22_S	et	f	\N
193877	ebatavalised	ebatavalised =tavalise  (PlN  >eba+tavaline !12_A	et	f	\N
193878	ebatavalised	"eba+tavaline %tava  )LINE_aA  <eba+tava ;17_S	et	f	\N
193885	bulgaarias	?bulgaarias =bulgaaria  (SgIn  >bulgaaria !01_S	et	f	\N
193886	bulgaarias	?bulgaarias =bulgaarias  (SgN  >bulgaarias !11_S	et	f	\N
193887	vapustatud	vapustatud =vapusta  (PtsPtIps  >vapustama !27_V	et	f	\N
193888	vapustatud	vapustatud =vapustatu  (PlN  >vapustatu !01_S	et	f	\N
193889	vapustatud	"vapustatu %vapusta  )TU1_vS  <vapustama ;27_V	et	f	\N
193890	vapustatud	vapustatud =vapustatud  (ID  >vapustatud !41_A	et	f	\N
193891	vapustatud	"vapustatud %vapusta  )TUD_vA  <vapustama ;27_V	et	f	\N
193897	jnd	### jnd	et	f	\N
193903	pedafolk	?pedafolk =pedafolk  (SgN  >pedafolk !22_S	et	f	\N
193908	korraldatatakse	?korraldatatakse =korraldata  (IndPrIps  >korraldatama !27_V	et	f	\N
193909	korraldatatakse	?korraldatatakse =korraldatatakse  (SgG  >korraldatatakne !02_A	et	f	\N
193910	korraldatatakse	?korraldatatakse =korraldatatakse  (PlP  >korraldatataks !22_S	et	f	\N
193914	viljand	?viljand =viljand  (SgN  >viljand !02_S	et	f	\N
193915	rahvases	rahvases =rahvase  (SgIn  >rahvane !10_A	et	f	\N
193916	rahvases	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
193926	elabgi	?elabgi =elabgi  (SgN  >elabgi !01_S	et	f	\N
193927	elabgi	?elabgi =elabgi  (SgG  >elabgi !01_S	et	f	\N
193928	elabgi	?elabgi =elabgi  (SgG  >elabg !02_S	et	f	\N
193929	elabgi	?elabgi =elabgi  (IndPrPs_  >elabgima !28_V	et	f	\N
193930	elabgi	?elabgi =elabgi  (ImpPrSg2  >elabgima !28_V	et	f	\N
193609	ümberlausid	?ümberlausid =lausi  (PlN  >ümber+lausi !16_S	et	f	\N
193611	ümberlausid	?ümberlausid =lausi  (PlN  >ümber+laus !22_S	et	f	\N
193620	settumaal	?settumaal =settumaa  (SgAd  >settumaa !26_S	et	f	\N
193621	settumaal	?settumaal =settumaal  (SgN  >settumaal !22_S	et	f	\N
193631	eestikultuuriajaloost	eestikultuuriajaloost =loo  (SgEl  >eesti+kultuuri+aja+lugu !18_S	et	f	\N
193632	eestikultuuriajaloost	eestikultuuriajaloost =loo  (SgEl  >eesti+kultuuri+aja+loog !22_S	et	f	\N
193633	eestikultuuriajaloost	eestikultuuriajaloost =loo  (SgEl  >eesti+kultuuri+aja+lood !22_S	et	f	\N
193648	motiivi	motiivi =motiivi  (SgG  >motiiv !22_S	et	f	\N
193649	motiivi	motiivi =motiivi  (SgP  >motiiv !22_S	et	f	\N
193650	motiivi	motiivi =motiivi  (SgAdt  >motiiv !22_S	et	f	\N
193660	riimid	riimid =riimi  (PlN  >riim !22_S	et	f	\N
193661	riimid	riimid =riimi  (IndPrSg2  >riimima !28_V	et	f	\N
193668	kuulsaim	kuulsaim =kuulsaim  (SgN  >kuulsaim !02_A	et	f	\N
193669	kuulsaim	"kuulsaim %kuulsa  )IM_sA  <kuulus ;02_A	et	f	\N
193674	rahvav	?rahvav =rahva  (PtsPrPs  >rahvama !29_V	et	f	\N
193675	rahvav	?rahvav =rahvav  (SgN  >rahvav !02_A	et	f	\N
193679	vilistlasid	### vilistlasid	et	f	\N
193691	fame	?fame =fame  (SgN  >fame !16_S	et	f	\N
193692	fame	?fame =fame  (SgG  >fame !16_S	et	f	\N
193693	fame	?fame =fame  (IndPrPs_  >famema !27_V	et	f	\N
193694	fame	?fame =fame  (ImpPrSg2  >famema !27_V	et	f	\N
193719	rocki-	?rocki- =rocki  (SgN  >rocki !16_S	et	f	\N
193720	rocki-	?rocki- =rocki  (SgG  >rocki !16_S	et	f	\N
193721	rocki-	?rocki- =rocki  (SgG  >rock !22_S	et	f	\N
193722	rocki-	?rocki- =rocki  (SgP  >rock !22_S	et	f	\N
193723	rocki-	?rocki- =rocki  (SgAdt  >rock !22_S	et	f	\N
193724	rocki-	?rocki- =rocki  (IndPrPs_  >rockima !28_V	et	f	\N
193725	rocki-	?rocki- =rocki  (ImpPrSg2  >rockima !28_V	et	f	\N
193728	uema	?uema =uema  (SgN  >uema !16_S	et	f	\N
193729	uema	?uema =uema  (SgG  >uema !16_S	et	f	\N
193730	uema	?uema =uema  (IndPrPs_  >uemama !29_V	et	f	\N
193731	uema	?uema =uema  (ImpPrSg2  >uemama !29_V	et	f	\N
193754	ärkimisele	?ärkimisele =ärkimise  (SgAll  >ärkimine !12_S	et	f	\N
193757	mõjut	?mõjut =mõjut  (SgN  >mõjut !02_S	et	f	\N
193758	tegemiste	tegemiste =tegemis  (PlG  >tegemine !12_S	et	f	\N
193759	tegemiste	"tegemine %tege  )MINE_vS  <tegema ;28_V	et	f	\N
193764	kujundamises	kujundamises =kujundamise  (SgIn  >kujundamine !12_S	et	f	\N
193765	kujundamises	"kujundamine %kujunda  )MINE_vS  <kujundama ;27_V	et	f	\N
193766	praaktiliselt	?praaktiliselt =praaktilise  (SgAbl  >praaktiline !12_A	et	f	\N
193767	praaktiliselt	?praaktiliselt =praaktiliselt  (ID  >praaktiliselt !41_D	et	f	\N
193768	praaktiliselt	?praaktiliselt =tilise  (SgAbl  >praak+tiline !10_A	et	f	\N
193795	suudis	?suudis =suudi  (SgIn  >suudi !16_S	et	f	\N
193796	suudis	?suudis =suudi  (SgIn  >suut !22_S	et	f	\N
193797	suudis	?suudis =suudi  (IndIpfSg3  >suudima !28_V	et	f	\N
193798	suudis	?suudis =suudis  (SgN  >suudis !09_S	et	f	\N
193800	rahvustest	rahvustest =rahvus  (PlEl  >rahvus !11~09_S	et	f	\N
193801	rahvustest	rahvustest =test  (SgN  >rahvus+test !22_S	et	f	\N
193805	tantsuliste	tantsuliste =tantsulis  (PlG  >tantsuline !12_A	et	f	\N
193806	tantsuliste	"tantsuline %tantsu  )LINE_aA  <tants ;22_S	et	f	\N
193821	muistatest	?muistatest =muista  (PlEl  >muista !01_S	et	f	\N
193822	muistatest	?muistatest =muistate  (PlEl  >muistatt !22_S	et	f	\N
193823	muistatest	?muistatest =muistates  (SgP  >muistatene !12_A	et	f	\N
193824	teisedki	teisedki =teise  (PlN^  >teine !12_OP	et	f	\N
193825	teisedki	teisedki =teise  (PlN^  >teise !12_P	et	f	\N
193841	ristiuskuga	?ristiuskuga =usku  (SgKom  >risti+usku !16_S	et	f	\N
193849	ühendamiseks	ühendamiseks =ühendamise  (SgTr  >ühendamine !12_S	et	f	\N
193850	ühendamiseks	"ühendamine %ühenda  )MINE_vS  <ühendama ;27_V	et	f	\N
193874	tantsijad	tantsijad =tantsija  (PlN  >tantsija !01_S	et	f	\N
193875	tantsijad	"tantsija %tantsi  )JA_vS  <tantsima ;28_V	et	f	\N
193898	püüades	?püüades =püüa  (PlIn  >püüa !16_S	et	f	\N
193905	kombes	kombes =kombe  (SgIn  >komme !06_S	et	f	\N
193906	kombes	kombes =kombe  (PlIn  >komp !22_S	et	f	\N
193907	kombes	kombes =kombes  (ID  >kombes !41_D	et	f	\N
193911	kuuluvus	kuuluvus =kuuluvus  (SgN  >kuuluvus !11_S	et	f	\N
193912	kuuluvus	"kuuluvus %kuulu  )VUS_aS  <kuuluma ;27_V	et	f	\N
193913	kuuluvus	"kuuluvus %kuuluva  )US_aS  <kuuluv ;02_A	et	f	\N
193931	rahvalaulde	?rahvalaulde =rahvalaulde  (PlP  >rahvalauld !22_S	et	f	\N
193932	rahvalaulde	?rahvalaulde =laulde  (SgN  >rahva+laulde !06_S	et	f	\N
193933	rahvalaulde	?rahvalaulde =laulde  (PlP  >rahva+lauld !22_S	et	f	\N
193953	ümberkirjutati	?ümberkirjutati =ümberkirjuta  (IndIpfIps  >ümberkirjutama !27_V	et	f	\N
193954	ümberkirjutati	?ümberkirjutati =ümberkirjutati  (SgG  >ümberkirjutatt !22_S	et	f	\N
193955	ümberkirjutati	?ümberkirjutati =ümberkirjutati  (IndPrPs_  >ümberkirjutattima !28_V	et	f	\N
193956	ümberkirjutati	?ümberkirjutati =ümberkirjutati  (ImpPrSg2  >ümberkirjutattima !28_V	et	f	\N
193957	ümberkirjutati	?ümberkirjutati =kirjutati  (SgG  >ümber+kirjutatt !22_S	et	f	\N
193961	rocki	?rocki =rocki  (SgN  >rocki !16_S	et	f	\N
193962	rocki	?rocki =rocki  (SgG  >rocki !16_S	et	f	\N
193742	muretseid	?muretseid =sei  (SgP  >muret+sei !26_S	et	f	\N
193743	muretseid	?muretseid =seid  (SgN  >muret+seid !22_S	et	f	\N
193744	muretseid	?muretseid =tsei  (PlN  >mure+tsei !26_S	et	f	\N
193745	muretseid	?muretseid =tsei  (SgP  >mure+tsei !26_S	et	f	\N
193746	muretseid	?muretseid =tseid  (SgN  >mure+tseid !22_S	et	f	\N
193749	lauluajalugu	lauluajalugu =lugu  (SgN  >laulu+aja+lugu !18_S	et	f	\N
193750	lauluajalugu	lauluajalugu =lugu  (SgP  >laulu+aja+lugu !18_S	et	f	\N
193751	esitamises	esitamises =esitamise  (SgIn  >esitamine !12_S	et	f	\N
193752	esitamises	"esitamine %esita  )MINE_vS  <esitama ;27_V	et	f	\N
193760	päästmist	päästmist =päästmis  (SgP  >päästmine !12?10_S	et	f	\N
193761	päästmist	"päästmine %pääst  )MINE_vS  <päästma ;34_V	et	f	\N
193790	kõikili	?kõikili =kõikili  (ID  >kõikili !41_D	et	f	\N
193791	kõikili	?kõikili =ili  (SgN  >kõik+ili !17_S	et	f	\N
193792	kõikili	?kõikili =ili  (SgG  >kõik+ili !17_S	et	f	\N
193793	kõikili	?kõikili =ili  (SgP  >kõik+ili !17_S	et	f	\N
193816	19nda	### 19nda	et	f	\N
193837	pärindatud	?pärindatud =pärinda  (PtsPtIps  >pärindama !27_V	et	f	\N
193838	pärindatud	?pärindatud =pärindatu  (PlN  >pärindatu !01_S	et	f	\N
193839	pärindatud	?pärindatud =pärindatu  (IndPrSg2  >pärindatuma !27_V	et	f	\N
193840	pärindatud	?pärindatud =pärindatud  (ID  >pärindatud !41_A	et	f	\N
193855	üleeestilist	?üleeestilist =üleeestili  (SgEl  >üleeestil !02_S	et	f	\N
193856	üleeestilist	?üleeestilist =üleeestilis  (SgP  >üleeestilis !09_S	et	f	\N
193857	üleeestilist	?üleeestilist =üleeestilis  (SgP  >üleeestiline !12_A	et	f	\N
193858	üleeestilist	?üleeestilist =üleeestilist  (SgN  >üleeestilist !22_S	et	f	\N
193859	üleeestilist	?üleeestilist =list  (SgN  >üle+eesti+list !22_S	et	f	\N
193860	üleeestilist	?üleeestilist =ili  (SgEl  >üle+eest+ili !17_S	et	f	\N
193861	üleeestilist	?üleeestilist =ilis  (SgP  >üle+eest+ilis !09_S	et	f	\N
193862	üleeestilist	?üleeestilist =ilis  (SgP  >üle+eest+iline !10_A	et	f	\N
193863	üleeestilist	?üleeestilist =ilist  (SgN  >üle+eest+ilist !22_S	et	f	\N
193864	üleeestilist	?üleeestilist =tili  (SgEl  >üle+ees+tili !17_S	et	f	\N
193865	üleeestilist	?üleeestilist =tilis  (SgP  >üle+ees+tilis !09_S	et	f	\N
193866	üleeestilist	?üleeestilist =tilis  (SgP  >üle+ees+tiline !10_A	et	f	\N
193867	üleeestilist	?üleeestilist =tilist  (SgN  >üle+ees+tilist !22_S	et	f	\N
193879	pop-ansamble	?pop-ansamble =ansamble  (IndPrPs_  >pop-ansamblema !27_V	et	f	\N
193880	pop-ansamble	?pop-ansamble =ansamble  (ImpPrSg2  >pop-ansamblema !27_V	et	f	\N
193881	rahvuslaulu	rahvuslaulu =laulu  (SgG  >rahvus+laul !22_S	et	f	\N
193882	rahvuslaulu	rahvuslaulu =laulu  (SgP  >rahvus+laul !22_S	et	f	\N
193883	rahvuslaulu	rahvuslaulu =laulu  (SgAdt  >rahvus+laul !22_S	et	f	\N
193892	etendusel	etendusel =etenduse  (SgAd  >etendus !11_S	et	f	\N
193893	etendusel	"etendus %etenda  )US_vS  <etendama ;27_V	et	f	\N
193894	käimisel	käimisel =käimise  (SgAd  >käimine !12?10_S	et	f	\N
193895	käimisel	"käimine %käi  )MINE_vS  <käima ;38_V	et	f	\N
193896	käimisel	"käimine %käimi  )NE_aA  <käim ;22_S	et	f	\N
193920	meenutus	meenutus =meenutu  (SgIn  >meenutu !01_AS	et	f	\N
193921	meenutus	"meenutu %meenu  )TU1_vS  <meenuma ;27_V	et	f	\N
193922	meenutus	meenutus =meenutus  (SgN  >meenutus !11_S	et	f	\N
193923	meenutus	"meenutus %meenuta  )US_vS  <meenutama ;27_V	et	f	\N
193924	meenutus	"meenutus %meenu  )TUS1_aS  <meenuma ;27_V	et	f	\N
193925	meenutus	meenutus =nutu  (SgIn  >mee+nutt !22_S	et	f	\N
193934	kandmist	kandmist =kandmis  (SgP  >kandmine !12?10_SA	et	f	\N
193935	kandmist	"kandmine %kand  )MINE_vS  <kandma ;34_V	et	f	\N
193942	õnnehetki	õnnehetki =hetki  (SgG  >õnne+hetk !22_S	et	f	\N
193943	õnnehetki	õnnehetki =hetki  (SgP  >õnne+hetk !22_S	et	f	\N
193944	õnnehetki	õnnehetki =hetki  (SgAdt  >õnne+hetk !22_S	et	f	\N
193945	õnnehetki	õnnehetki =hetki  (PlP  >õnne+hetk !22_S	et	f	\N
193958	korrladama	?korrladama =korrladama  (SgG  >korrladam !02_A	et	f	\N
193971	kaasarvatud	kaasarvatud =atu  (PlN  >kaas+arv+att !22_S	et	f	\N
193972	kaasarvatud	kaasarvatud =arvatu  (PlN  >kaas+arvatu !01_AS	et	f	\N
193989	tipphetkeks	tipphetkeks =hetke  (SgTr  >tipp+hetk !22_S	et	f	\N
193990	tipphetkeks	tipphetkeks =hetke  (PlTr  >tipp+hetk !22_S	et	f	\N
193996	tavapära	tavapära =pära  (SgN  >tava+pära !17_S	et	f	\N
193999	tavapära	tavapära =pära  (SgG  >tava+pära !17_S	et	f	\N
194000	tavapära	tavapära =pära  (SgP  >tava+pära !17_S	et	f	\N
194006	ühendamist	ühendamist =ühendamis  (SgP  >ühendamine !12_S	et	f	\N
194007	ühendamist	"ühendamine %ühenda  )MINE_vS  <ühendama ;27_V	et	f	\N
194015	kullerkuppud	?kullerkuppud =kullerkuppu  (IndPrSg2  >kullerkuppuma !27_V	et	f	\N
194017	liiguv	?liiguv =liigu  (PtsPrPs  >liiguma !27_V	et	f	\N
194018	liiguv	?liiguv =liiguv  (SgN  >liiguv !02_A	et	f	\N
194025	rahvusprogrammiga	rahvusprogrammiga =iga  (SgN  >rahvus+programm+iga !18_S	et	f	\N
194026	rahvusprogrammiga	rahvusprogrammiga =iga  (SgP  >rahvus+programm+iga !18_S	et	f	\N
194027	rahvusprogrammiga	rahvusprogrammiga =programmi  (SgKom  >rahvus+programm !22_S	et	f	\N
194072	rock-bändid	rock-bändid =bändi  (PlN  >rock-bändi !16_S	et	f	\N
194073	rock-bändid	rock-bändid =bändi  (PlN  >rock-bänd !22_S	et	f	\N
193771	valgustustuaja	?valgustustuaja =valgustustuaja  (SgG  >valgustustuajas !02_A	et	f	\N
193772	valgustustuaja	?valgustustuaja =tuaja  (SgN  >valgustus+tuaja !01_S	et	f	\N
193773	valgustustuaja	?valgustustuaja =tuaja  (SgG  >valgustus+tuaja !01_S	et	f	\N
193774	valgustustuaja	?valgustustuaja =ustuaja  (SgN  >valgust+ustuaja !01_S	et	f	\N
193775	valgustustuaja	?valgustustuaja =ustuaja  (SgG  >valgust+ustuaja !01_S	et	f	\N
193776	valgustustuaja	?valgustustuaja =ustuaja  (SgG  >valgust+ustuajas !02_A	et	f	\N
193777	valgustustuaja	?valgustustuaja =tustuaja  (SgN  >valgus+tustuaja !01_S	et	f	\N
193778	valgustustuaja	?valgustustuaja =tustuaja  (SgG  >valgus+tustuaja !01_S	et	f	\N
193779	valgustustuaja	?valgustustuaja =tustuaja  (SgG  >valgus+tustuajas !02_A	et	f	\N
193780	valgustustuaja	?valgustustuaja =stustuaja  (SgN  >valgu+stustuaja !01_S	et	f	\N
193781	valgustustuaja	?valgustustuaja =stustuaja  (SgG  >valgu+stustuaja !01_S	et	f	\N
193782	valgustustuaja	?valgustustuaja =stustuaja  (SgG  >valgu+stustuajas !02_A	et	f	\N
193783	valgustustuaja	?valgustustuaja =ustustuaja  (SgN  >valg+ustustuaja !01_S	et	f	\N
193784	valgustustuaja	?valgustustuaja =ustustuaja  (SgG  >valg+ustustuaja !01_S	et	f	\N
193785	valgustustuaja	?valgustustuaja =ustustuaja  (SgG  >valg+ustustuajas !02_A	et	f	\N
193799	ühtlastab	?ühtlastab =ühtlasta  (IndPrSg3  >ühtlastama !27_V	et	f	\N
193811	ühisrahvas	ühisrahvas =rahva  (SgIn  >ühis+rahvas !07_S	et	f	\N
193812	ühisrahvas	ühisrahvas =rahvas  (SgN  >ühis+rahvas !07_S	et	f	\N
193819	esituses	esituses =esituse  (SgIn  >esitus !11_S	et	f	\N
193820	esituses	"esitus %esita  )US_vS  <esitama ;27_V	et	f	\N
193832	kõkjal	?kõkjal =kõkja  (SgAd  >kõkja !01_S	et	f	\N
193833	kõkjal	?kõkjal =kõkja  (SgAd  >kõkjas !02_A	et	f	\N
193834	kõkjal	?kõkjal =kõkjal  (SgN  >kõkjal !02_S	et	f	\N
193851	rokkbändid	rokkbändid =bändi  (PlN  >rokk+bändi !16_S	et	f	\N
193852	rokkbändid	rokkbändid =bändi  (PlN  >rokk+bänd !22_S	et	f	\N
193899	unikaalsuse	unikaalsuse =unikaalsuse  (SgG  >unikaalsus !11~09_S	et	f	\N
193900	unikaalsuse	"unikaalsus %unikaalse  )US_aS  <unikaalne ;02_A	et	f	\N
193901	ohustasid	ohustasid =ohusta  (IndIpfSg2  >ohustama !27_V	et	f	\N
193902	ohustasid	ohustasid =ohusta  (IndIpfPl3  >ohustama !27_V	et	f	\N
193904	peedab	?peedab =peeda  (IndPrSg3  >peedama !29_V	et	f	\N
193917	sümboolikast	sümboolikast =sümboolika  (SgEl  >sümboolika !01_S	et	f	\N
193918	sümboolikast	sümboolikast =sümboolikas  (SgP  >sümboolikane !12_A	et	f	\N
193919	sümboolikast	"sümboolikane %sümboolika  )NE_aA  <sümboolika ;01_S	et	f	\N
193940	meeli	meeli =meel  (PlP  >meel !13_S	et	f	\N
193941	meeli	meeli =meeli  (ID  >meeli !41_D	et	f	\N
193946	ennemgi	ennemgi =ennem  (ID^  >ennem !41_D	et	f	\N
193947	ennemgi	ennemgi =ennem  (SgN^  >ennem !02_A	et	f	\N
193959	setulaule	setulaule =lau  (SgAll  >setu+laug !22_SA	et	f	\N
193960	setulaule	setulaule =laule  (PlP  >setu+laul !22_S	et	f	\N
193968	laulukultuuriga	laulukultuuriga =iga  (SgN  >laulu+kultuur+iga !18_S	et	f	\N
193969	laulukultuuriga	laulukultuuriga =iga  (SgP  >laulu+kultuur+iga !18_S	et	f	\N
193970	laulukultuuriga	laulukultuuriga =kultuuri  (SgKom  >laulu+kultuur !22_S	et	f	\N
193976	ikks	?ikks =ikks  (SgN  >ikks !22_S	et	f	\N
193984	riigivahelistes	riigivahelistes =vahelis  (PlIn  >riigi+vaheline !12_A	et	f	\N
193985	riigivahelistes	"riigi+vaheline %vahe  )LINE_aA  <riigi+vahe ;16_S	et	f	\N
193993	ühinevat	ühinevat =ühine  (KvtPrPs  >ühinema !27_V	et	f	\N
193994	ühinevat	ühinevat =ühineva  (SgP  >ühinev !02_A	et	f	\N
193995	ühinevat	"ühinev %ühine  )V_vA  <ühinema ;27_V	et	f	\N
193997	kultuurilise	kultuurilise =kultuurilise  (SgG  >kultuuriline !12_A	et	f	\N
193998	kultuurilise	"kultuuriline %kultuuri  )LINE_aA  <kultuur ;22_S	et	f	\N
194003	iseseistvust	?iseseistvust =iseseistvus  (SgP  >iseseistvus !11~09_S	et	f	\N
194004	iseseistvust	?iseseistvust =seistvu  (SgEl  >ise+seistvu !01_S	et	f	\N
194005	iseseistvust	?iseseistvust =seistvus  (SgP  >ise+seistvus !11~09_S	et	f	\N
194016	aruneb	?aruneb =arune  (IndPrSg3  >arunema !27_V	et	f	\N
194031	vabadusega	vabadusega =vabaduse  (SgKom  >vabadus !11_S	et	f	\N
194032	vabadusega	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
194052	suureosaliselt	suureosaliselt =osalise  (SgAbl  >suure+osaline !12_SA	et	f	\N
194053	suureosaliselt	"suure+osaline %osa  )LINE_aA  <suure+osa ;17_S	et	f	\N
194054	suureosaliselt	"suure+osaliselt %osa  )LISELT_mD  <suure+osa ;17_S	et	f	\N
194063	laulmisel	laulmisel =laulmise  (SgAd  >laulmine !12?10_S	et	f	\N
194064	laulmisel	"laulmine %laul  )MINE_vS  <laulma ;33_V	et	f	\N
194065	tänapäevaseni	tänapäevaseni =päevase  (SgTer  >täna+päevane !10_A	et	f	\N
194066	tänapäevaseni	"täna+päevane %päeva  )NE_aA  <täna+päev ;22_S	et	f	\N
194076	regulaarseks	regulaarseks =regulaarse  (SgTr  >regulaarne !02_A	et	f	\N
194077	regulaarseks	regulaarseks =seks  (SgN  >regulaar+seks !22_S	et	f	\N
194078	tänapäevaseid	tänapäevaseid =päevase  (PlP  >täna+päevane !10_A	et	f	\N
194079	tänapäevaseid	"täna+päevane %päeva  )NE_aA  <täna+päev ;22_S	et	f	\N
194087	silt	silt =si  (SgAbl  >si !26_S	et	f	\N
194088	silt	silt =silt  (SgN  >silt !22_S	et	f	\N
194104	lähim-ida	lähim-ida =ida  (SgN  >lähim-ida !17_S	et	f	\N
194105	lähim-ida	lähim-ida =ida  (SgG  >lähim-ida !17_S	et	f	\N
194106	lähim-ida	lähim-ida =ida  (SgP  >lähim-ida !17_S	et	f	\N
193831	ammu-ammu	ammu-ammu =ammu  (ImpPrSg2  >ammu-ambuma !28_V	et	f	\N
193835	puhkamisel	puhkamisel =puhkamise  (SgAd  >puhkamine !12_S	et	f	\N
193836	puhkamisel	"puhkamine %puhka  )MINE_vS  <puhkama ;29_V	et	f	\N
193842	ilmnesid	ilmnesid =ilmne  (IndIpfSg2  >ilmnema !27_V	et	f	\N
193843	ilmnesid	ilmnesid =ilmne  (IndIpfPl3  >ilmnema !27_V	et	f	\N
193846	slaavimuusika	slaavimuusika =muusika  (SgN  >slaavi+muusika !01_S	et	f	\N
193847	slaavimuusika	slaavimuusika =muusika  (SgG  >slaavi+muusika !01_S	et	f	\N
193853	pühendasid	pühendasid =pühenda  (IndIpfSg2  >pühendama !27_V	et	f	\N
193854	pühendasid	pühendasid =pühenda  (IndIpfPl3  >pühendama !27_V	et	f	\N
193868	koreograafiaansamblis	?koreograafiaansamblis =koreograafiaansambli  (SgIn  >koreograafiaansambel !02_S	et	f	\N
193869	koreograafiaansamblis	?koreograafiaansamblis =koreograafiaansambli  (IndIpfSg3  >koreograafiaansamblima !28_V	et	f	\N
193870	koreograafiaansamblis	?koreograafiaansamblis =koreograafiaansamblis  (SgN  >koreograafiaansamblis !09_S	et	f	\N
193876	laudakse	?laudakse =laudakse  (SgG  >laudakne !02_A	et	f	\N
193884	koreograafiaansambliga	?koreograafiaansambliga =koreograafiaansambli  (SgKom  >koreograafiaansambel !02_S	et	f	\N
193948	konkreetsemad	konkreetsemad =konkreetsema  (PlN  >konkreetsem !02_A	et	f	\N
193949	konkreetsemad	"konkreetsem %konkreetse  )M_cA  <konkreetne ;02_A	et	f	\N
193950	laululehti	laululehti =lehti  (SgP  >laulu+leht !22_S	et	f	\N
193951	laululehti	laululehti =lehti  (SgAdt  >laulu+leht !22_S	et	f	\N
193952	laululehti	laululehti =lehti  (PlP  >laulu+leht !22_S	et	f	\N
193973	mööduvad	mööduvad =möödu  (IndPrPl3  >mööduma !27_V	et	f	\N
193974	mööduvad	mööduvad =mööduva  (PlN  >mööduv !02_A	et	f	\N
193975	mööduvad	"mööduv %möödu  )V_vA  <mööduma ;27_V	et	f	\N
194019	erinevalest	?erinevalest =erinevale  (PlEl  >erineval !19_S	et	f	\N
194020	erinevalest	?erinevalest =erinevales  (SgP  >erinevalene !12_A	et	f	\N
194021	erinevalest	?erinevalest =nevales  (SgP  >eri+nevalene !12_A	et	f	\N
194055	meeskooridele	meeskooridele =koori  (PlAll  >mees+koor !22_S	et	f	\N
194056	meeskooridele	meeskooridele =skoori  (PlAll  >mee+skoor !22_S	et	f	\N
194057	laulvamaks	laulvamaks =laulvama  (SgTr  >laulvam !02_A	et	f	\N
194058	laulvamaks	"laulvam %laul  )VAM_cA  <laulma ;33_V	et	f	\N
194059	laulvamaks	"laulvam %laulva  )M_cA  <laulev ;02_A	et	f	\N
194070	kujutlusi	kujutlusi =kujutlusi  (PlP  >kujutlus !11_S	et	f	\N
194071	kujutlusi	"kujutlus %kujutle  )US_vS  <kujutlema ;27_V	et	f	\N
194074	kujutlust	kujutlust =kujutlus  (SgP  >kujutlus !11_S	et	f	\N
194075	kujutlust	"kujutlus %kujutle  )US_vS  <kujutlema ;27_V	et	f	\N
194083	maje	?maje =maje  (SgN  >maje !16_S	et	f	\N
194084	maje	?maje =maje  (SgG  >maje !16_S	et	f	\N
194085	maje	?maje =maje  (IndPrPs_  >majema !27_V	et	f	\N
194086	maje	?maje =maje  (ImpPrSg2  >majema !27_V	et	f	\N
194095	rtobias	?rtobias =rtobia  (SgIn  >rtobia !01_S	et	f	\N
194096	rtobias	?rtobias =rtobias  (SgN  >rtobias !11_S	et	f	\N
194107	pärsia	?pärsia =pärsia  (ID  >pärsia !41_G	et	f	\N
194116	juri	?juri =juri  (SgN  >juri !17_S	et	f	\N
194117	juri	?juri =juri  (SgG  >juri !17_S	et	f	\N
194118	juri	?juri =juri  (SgP  >juri !17_S	et	f	\N
194119	juri	?juri =juri  (IndPrPs_  >jurima !27_V	et	f	\N
194120	juri	?juri =juri  (ImpPrSg2  >jurima !27_V	et	f	\N
194123	tihendus	tihendus =tihendus  (SgN  >tihendus !11_S	et	f	\N
194124	tihendus	"tihendus %tihenda  )US_vS  <tihendama ;27_V	et	f	\N
194129	osalemiseks	osalemiseks =osalemise  (SgTr  >osalemine !12_S	et	f	\N
194130	osalemiseks	"osalemine %osale  )MINE_vS  <osalema ;27_V	et	f	\N
194139	püüdmisest	püüdmisest =püüdmise  (SgEl  >püüdmine !12?10_S	et	f	\N
194140	püüdmisest	"püüdmine %püüd  )MINE_vS  <püüdma ;34_V	et	f	\N
194150	kampaaniadesse	?kampaaniadesse =kampaaniade  (PlIll  >kampaaniat !22_S	et	f	\N
194151	kampaaniadesse	?kampaaniadesse =kampaaniades  (SgAdt  >kampaaniadene !12_A	et	f	\N
194152	kampaaniadesse	?kampaaniadesse =kampaaniadesse  (SgG  >kampaaniadesne !02_A	et	f	\N
194154	kampaaniadesse	?kampaaniadesse =kampaaniadesse  (PlP  >kampaaniadess !22_S	et	f	\N
194161	külamastaabne	?külamastaabne =külamastaabne  (SgN  >külamastaabne !02_A	et	f	\N
194162	külamastaabne	?külamastaabne =külamastaabne  (PlP  >külamastaabn !22_S	et	f	\N
194163	külamastaabne	?külamastaabne =mastaabne  (SgN  >küla+mastaabne !02_A	et	f	\N
194164	külamastaabne	?külamastaabne =mastaabne  (PlP  >küla+mastaabn !22_S	et	f	\N
194173	lisanduvad	lisanduvad =lisandu  (IndPrPl3  >lisanduma !27_V	et	f	\N
194174	lisanduvad	lisanduvad =lisanduva  (PlN  >lisanduv !02_A	et	f	\N
194175	lisanduvad	"lisanduv %lisandu  )V_vA  <lisanduma ;27_V	et	f	\N
194178	kokkusulamine	kokkusulamine =sulamine  (SgN  >kokku+sulamine !12_S	et	f	\N
194179	kokkusulamine	"kokku+sulamine %sulami  )NE_aA  <kokku+sulam ;02_S	et	f	\N
194193	esinejates	esinejates =esineja  (PlIn  >esineja !01_S	et	f	\N
194194	esinejates	"esineja %esine  )JA_vS  <esinema ;27_V	et	f	\N
194197	silmapaistvam	silmapaistvam =paistvam  (SgN  >silma+paistvam !02_A	et	f	\N
194198	silmapaistvam	"silma+paistvam %paistva  )M_cA  <silma+paistev ;02_A	et	f	\N
194199	suurepäärane	?suurepäärane =suurepäärane  (SgN  >suurepäärane !10_A	et	f	\N
194200	suurepäärane	?suurepäärane =rane  (SgN  >suure+pää+rane !16_S	et	f	\N
194201	suurepäärane	?suurepäärane =rane  (SgG  >suure+pää+rane !16_S	et	f	\N
193936	pärastki	pärastki =pära  (SgEl^  >pära !17_S	et	f	\N
193937	pärastki	pärastki =päras  (SgP^  >pärane !10_A	et	f	\N
193938	pärastki	"pärane %pära  )NE_aA^  <pära ;17_S	et	f	\N
193939	pärastki	pärastki =pärast  (ID^  >pärast !41_DK	et	f	\N
193982	tahenda	tahenda =tahenda  (IndPrPs_  >tahendama !27_V	et	f	\N
193983	tahenda	tahenda =tahenda  (ImpPrSg2  >tahendama !27_V	et	f	\N
193991	laulevat	laulevat =lauleva  (SgP  >laulev !02_A	et	f	\N
193992	laulevat	"laulev %laul  )V_vA  <laulma ;33_V	et	f	\N
194001	muusikafolkloor	muusikafolkloor =loor  (SgN  >muusika+folk+loor !22_S	et	f	\N
194002	muusikafolkloor	muusikafolkloor =folkloor  (SgN  >muusika+folkloor !22_S	et	f	\N
194022	kontserdidest	?kontserdidest =kontserdides  (SgP  >kontserdidene !12_A	et	f	\N
194023	kontserdidest	?kontserdidest =serdi  (PlEl  >kont+serd !22_S	et	f	\N
194024	kontserdidest	?kontserdidest =serdides  (SgP  >kont+serdidene !12_A	et	f	\N
194039	paljust	paljust =palju  (SgEl  >palju !16_P	et	f	\N
194040	paljust	paljust =paljus  (SgP  >paljus !11~09_S	et	f	\N
194041	paljust	"paljus %palja  )US_aS  <paljas ;07_A	et	f	\N
194043	suulisel	suulisel =suulise  (SgAd  >suuline !12?10_AS	et	f	\N
194045	suulisel	"suuline %suu  )LINE_aA  <suu ;26_S	et	f	\N
194046	massiliseks	massiliseks =massilise  (SgTr  >massiline !12_A	et	f	\N
194047	massiliseks	"massiline %massi  )LINE_aA  <mass ;22_S	et	f	\N
194048	teekonna	teekonna =teekonna  (SgG  >teekond !22_S	et	f	\N
194049	teekonna	teekonna =konna  (SgG  >tee+konn !22_S	et	f	\N
194050	teekonna	teekonna =konna  (SgP  >tee+konn !22_S	et	f	\N
194051	teekonna	teekonna =konna  (SgAdt  >tee+konn !22_S	et	f	\N
194060	edaspidiseks	edaspidiseks =edaspidiseks  (ID  >edas+pidiseks !41_D	et	f	\N
194061	edaspidiseks	edaspidiseks =seks  (SgN  >edas+pidi+seks !22_S	et	f	\N
194062	edaspidiseks	edaspidiseks =pidise  (SgTr  >edas+pidine !10_A	et	f	\N
194081	regiväeline	regiväeline =väeline  (SgN  >regi+väeline !12?10_A	et	f	\N
194082	regiväeline	"regi+väeline %väe  )LINE_aA  <regi+vägi ;21_S	et	f	\N
194099	kõrghetkeks	kõrghetkeks =hetke  (SgTr  >kõrg+hetk !22_S	et	f	\N
194100	kõrghetkeks	kõrghetkeks =hetke  (PlTr  >kõrg+hetk !22_S	et	f	\N
194109	nuta	nuta =nuta  (IndPrPs_  >nutma !35_V	et	f	\N
194110	nuta	nuta =nuta  (ImpPrSg2  >nutma !35_V	et	f	\N
194111	arvanud	arvanud =arva  (PtsPtPs  >arvama !29_V	et	f	\N
194112	arvanud	arvanud =arvanu  (PlN  >arvanu !01_S	et	f	\N
194113	arvanud	"arvanu %arva  )NU_vS  <arvama ;29_V	et	f	\N
194114	arvanud	arvanud =arvanud  (ID  >arvanud !41_A	et	f	\N
194115	arvanud	"arvanud %arva  )NUD_vA  <arvama ;29_V	et	f	\N
194153	kogunedi	?kogunedi =nedi  (SgN  >kogu+nedi !17_S	et	f	\N
194155	kogunedi	?kogunedi =nedi  (SgG  >kogu+nedi !17_S	et	f	\N
194156	kogunedi	?kogunedi =nedi  (SgP  >kogu+nedi !17_S	et	f	\N
194157	kududes	kududes =kudu  (PlIn  >kudu !17_S	et	f	\N
194158	kududes	kududes =kudu  (Ger  >kuduma !28_V	et	f	\N
194159	igavamad	igavamad =igavama  (PlN  >igavam !02_A	et	f	\N
194160	igavamad	"igavam %igava  )M_cA  <igav ;02_A	et	f	\N
194171	luterlus	luterlus =luterlus  (SgN  >luterlus !11_S	et	f	\N
194172	luterlus	"luterlus %luterlase  )US_aS  <luterlane ;12_S	et	f	\N
194176	romantistlikud	?romantistlikud =romantistliku  (PlN  >romantistlik !25_A	et	f	\N
194177	romantistlikud	?romantistlikud =romantistliku  (IndPrSg2  >romantistlikuma !27_V	et	f	\N
194182	ärkamisele	ärkamisele =ärkamise  (SgAll  >ärkamine !12_S	et	f	\N
194183	ärkamisele	"ärkamine %ärka  )MINE_vS  <ärkama ;29_V	et	f	\N
194188	keerulisel	keerulisel =keerulise  (SgAd  >keeruline !12_A	et	f	\N
194189	keerulisel	"keeruline %keeru  )LINE_aA  <keerd ;22_SA	et	f	\N
194192	uuetes	?uuetes =uue  (PlIn  >uue !06_S	et	f	\N
194222	omapäärane	?omapäärane =omapäärane  (SgN  >omapäärane !10_A	et	f	\N
194223	omapäärane	?omapäärane =rane  (SgN  >oma+pää+rane !16_S	et	f	\N
194224	omapäärane	?omapäärane =rane  (SgG  >oma+pää+rane !16_S	et	f	\N
194225	omapäärane	?omapäärane =päärane  (SgN  >oma+päärane !10_A	et	f	\N
194232	laulutüüpiga	laulutüüpiga =iga  (SgN  >laulu+tüüp+iga !18_S	et	f	\N
194233	laulutüüpiga	laulutüüpiga =iga  (SgP  >laulu+tüüp+iga !18_S	et	f	\N
194236	ülemaalised	ülemaalised =maalise  (PlN  >üle+maaline !12?10_A	et	f	\N
194237	ülemaalised	"üle+maaline %maa  )LINE_aA  <üle+maa ;26_S	et	f	\N
194238	ülemaalised	"üle+maaline %maali  )NE_aA  <üle+maal ;22_S	et	f	\N
194250	ühenevad	?ühenevad =ühene  (IndPrPl3  >ühenema !27_V	et	f	\N
194251	ühenevad	?ühenevad =üheneva  (PlN  >ühenev !02_A	et	f	\N
194252	ühenevad	?ühenevad =üheneva  (PlN  >üheneva !16_S	et	f	\N
194253	ühenevad	?ühenevad =neva  (PlN  >ühe+neva !17_S	et	f	\N
194254	surene	?surene =surene  (SgN  >surene !10_A	et	f	\N
194255	surene	?surene =surene  (IndPrPs_  >surenema !27_V	et	f	\N
194256	surene	?surene =surene  (ImpPrSg2  >surenema !27_V	et	f	\N
194270	lastelaul	lastelaul =lau  (SgAd  >laste+laug !22_SA	et	f	\N
194271	lastelaul	lastelaul =laul  (SgN  >laste+laul !22_S	et	f	\N
194272	veetsid	veetsid =veet  (IndIpfSg2  >veetma !34_V	et	f	\N
194273	veetsid	veetsid =veet  (IndIpfPl3  >veetma !34_V	et	f	\N
194276	osalemisest	osalemisest =osalemise  (SgEl  >osalemine !12_S	et	f	\N
194277	osalemisest	"osalemine %osale  )MINE_vS  <osalema ;27_V	et	f	\N
193963	rocki	?rocki =rocki  (SgG  >rock !22_S	et	f	\N
193964	rocki	?rocki =rocki  (SgP  >rock !22_S	et	f	\N
193965	rocki	?rocki =rocki  (SgAdt  >rock !22_S	et	f	\N
193966	rocki	?rocki =rocki  (IndPrPs_  >rockima !28_V	et	f	\N
193967	rocki	?rocki =rocki  (ImpPrSg2  >rockima !28_V	et	f	\N
193977	saamegi	saamegi =saa  (IndPrPl1^  >saama !37_V	et	f	\N
193978	saamegi	saamegi =saame  (PlP^  >saam !22_S	et	f	\N
193979	töölesid	?töölesid =tööle  (IndIpfSg2  >töölema !27_V	et	f	\N
193980	töölesid	?töölesid =tööle  (IndIpfPl3  >töölema !27_V	et	f	\N
193981	töölesid	?töölesid =lesi  (PlN  >töö+lesi !17_S	et	f	\N
193986	peo-	peo- =peo  (SgN  >peo !26_S	et	f	\N
193987	peo-	peo- =peo  (SgG  >pidu !18_S	et	f	\N
193988	peo-	peo- =peo  (SgG  >peo !26_S	et	f	\N
194008	festivaali	?festivaali =festivaali  (SgN  >festivaali !16_S	et	f	\N
194009	festivaali	?festivaali =festivaali  (SgG  >festivaali !16_S	et	f	\N
194010	festivaali	?festivaali =festivaali  (SgG  >festivaal !22_S	et	f	\N
194011	festivaali	?festivaali =festivaali  (SgP  >festivaal !22_S	et	f	\N
194012	festivaali	?festivaali =festivaali  (SgAdt  >festivaal !22_S	et	f	\N
194013	festivaali	?festivaali =festivaali  (IndPrPs_  >festivaalima !28_V	et	f	\N
194014	festivaali	?festivaali =festivaali  (ImpPrSg2  >festivaalima !28_V	et	f	\N
194028	täthsus	?täthsus =täthsu  (SgIn  >täthsu !01_S	et	f	\N
194029	täthsus	?täthsus =täthsu  (IndIpfSg3  >täthsuma !27_V	et	f	\N
194030	täthsus	?täthsus =täthsus  (SgN  >täthsus !11~09_S	et	f	\N
194033	rahvaspidudele	?rahvaspidudele =spidu  (PlAll  >rahva+spidu !17_S	et	f	\N
194034	sündimisest	sündimisest =sündimise  (SgEl  >sündimine !12_S	et	f	\N
194035	sündimisest	"sündimine %sündi  )MINE_vS  <sündima ;28_V	et	f	\N
194036	muudel	muudel =muu  (PlAd  >muu !26_P	et	f	\N
194037	muudel	muudel =muu  (PlAd  >muu !26_S	et	f	\N
194038	muudel	muudel =muude  (PlAd  >muut !22_S	et	f	\N
194042	pärandamine	pärandamine =pärandamine  (SgN  >pärandamine !12_S	et	f	\N
194044	pärandamine	"pärandamine %päranda  )MINE_vS  <pärandama ;27_V	et	f	\N
194067	päästas	?päästas =päästa  (SgIn  >päästa !01_S	et	f	\N
194068	päästas	?päästas =päästa  (IndIpfSg3  >päästama !27_V	et	f	\N
194069	päästas	?päästas =päästas  (SgN  >päästas !07_S	et	f	\N
194080	vanate	?vanate =vana  (IndPrPl2  >vanama !27_V	et	f	\N
194097	aktuaalsuse	aktuaalsuse =aktuaalsuse  (SgG  >aktuaalsus !11~09_S	et	f	\N
194098	aktuaalsuse	"aktuaalsus %aktuaalse  )US_aS  <aktuaalne ;02_A	et	f	\N
194101	hinnavad	?hinnavad =hinna  (IndPrPl3  >hinnama !29_V	et	f	\N
194102	hinnavad	?hinnavad =hinnava  (PlN  >hinnava !01_S	et	f	\N
194103	hinnavad	?hinnavad =hinnava  (PlN  >hinnav !02_A	et	f	\N
194128	bentoniga	?bentoniga =bentoni  (SgKom  >benton !02_S	et	f	\N
194144	isiklikust	isiklikust =isikliku  (SgEl  >isiklik !25_A	et	f	\N
194145	isiklikust	isiklikust =isiklikus  (SgP  >isiklikus !11?09_S	et	f	\N
194146	isiklikust	"isiklikus %isikliku  )US_aS  <isiklik ;25_A	et	f	\N
194169	regivärsilisteks	regivärsilisteks =värsilis  (PlTr  >regi+värsiline !12_A	et	f	\N
194170	regivärsilisteks	"regi+värsiline %värsi  )LINE_aA  <regi+värss ;22_S	et	f	\N
194180	helikiirusega	helikiirusega =kiiruse  (SgKom  >heli+kiirus !11~09_S	et	f	\N
194181	helikiirusega	"heli+kiirus %kiire  )US_aS  <heli+kiire ;01_A	et	f	\N
194195	kindlust	kindlust =kindlus  (SgP  >kindlus !11~09_S	et	f	\N
194196	kindlust	"kindlus %kindla  )US_aS  <kindel ;02_A	et	f	\N
194205	erksalt	erksalt =erksa  (SgAbl  >ergas !03~05_A	et	f	\N
194206	erksalt	erksalt =erksalt  (ID  >erksalt !41_D	et	f	\N
194207	erksalt	"erksalt %erksa  )LT_mD  <ergas ;03_A	et	f	\N
194208	erksalt	"erksalt %erksa  )LT_mD  <ergas ;05_A	et	f	\N
194228	rahvaerilisus	rahvaerilisus =erilisus  (SgN  >rahva+erilisus !11?09_S	et	f	\N
194229	rahvaerilisus	"rahva+erilisus %eri  )LISUS_aS  <rahva+eri ;17_S	et	f	\N
194242	vokaalansamble	### vokaalansamble	et	f	\N
194257	laulava	laulava =lava  (SgN  >lau+lava !17_S	et	f	\N
194258	laulava	laulava =lava  (SgG  >lau+lava !17_S	et	f	\N
194259	laulava	laulava =lava  (SgP  >lau+lava !17_S	et	f	\N
194262	ühinemise	ühinemise =ühinemise  (SgG  >ühinemine !12_S	et	f	\N
194263	ühinemise	"ühinemine %ühine  )MINE_vS  <ühinema ;27_V	et	f	\N
194264	remikse	?remikse =remikse  (SgG  >remikne !02_A	et	f	\N
194266	neiokõsõ	### neiokõsõ	et	f	\N
194311	veedasid	?veedasid =veeda  (PlP  >veeda !16_S	et	f	\N
194312	veedasid	?veedasid =veeda  (IndIpfSg2  >veedama !29_V	et	f	\N
194313	veedasid	?veedasid =veeda  (IndIpfPl3  >veedama !29_V	et	f	\N
194314	veedasid	?veedasid =dasi  (PlN  >vee+dasi !17_S	et	f	\N
194321	piirandatud	?piirandatud =piiranda  (PtsPtIps  >piirandama !27_V	et	f	\N
194322	piirandatud	?piirandatud =piirandatu  (PlN  >piirandatu !01_S	et	f	\N
194323	piirandatud	?piirandatud =piirandatu  (IndPrSg2  >piirandatuma !27_V	et	f	\N
194324	piirandatud	?piirandatud =piirandatud  (ID  >piirandatud !41_A	et	f	\N
194325	piirandatud	?piirandatud =andatu  (PlN  >piir+andatu !01_S	et	f	\N
194328	folkloorifestivaalide	?folkloorifestivaalide =folkloorifestivaali  (PlG  >folkloorifestivaali !16_S	et	f	\N
194329	folkloorifestivaalide	?folkloorifestivaalide =folkloorifestivaali  (PlG  >folkloorifestivaal !22_S	et	f	\N
194089	laululehtede	laululehtede =ede  (SgN  >laulu+leht+ede !16_S	et	f	\N
194090	laululehtede	laululehtede =ede  (SgG  >laulu+leht+ede !16_S	et	f	\N
194091	laululehtede	laululehtede =lehte  (PlG  >laulu+leht !22_S	et	f	\N
194092	heliloojasid	?heliloojasid =helilooja  (PlP  >helilooja !16_S	et	f	\N
194093	heliloojasid	?heliloojasid =heliloojasi  (PlN  >heliloojas !02_A	et	f	\N
194094	heliloojasid	?heliloojasid =jasi  (PlN  >heli+loo+jasi !17_S	et	f	\N
194108	emir	?emir =emir  (SgN  >emir !02_S	et	f	\N
194121	muinasajadelt	?muinasajadelt =muinasajadelt  (ID  >muinasajadelt !41_D	et	f	\N
194122	muinasajadelt	?muinasajadelt =aja  (PlAbl  >muinas+aja !17_S	et	f	\N
194131	laulmistraditsiooni	laulmistraditsiooni =traditsiooni  (SgG  >laulmis+traditsioon !22_S	et	f	\N
194132	laulmistraditsiooni	laulmistraditsiooni =traditsiooni  (SgP  >laulmis+traditsioon !22_S	et	f	\N
194133	laulmistraditsiooni	laulmistraditsiooni =traditsiooni  (SgAdt  >laulmis+traditsioon !22_S	et	f	\N
194134	vähestama	?vähestama =vähesta  (Sup  >vähestama !27_V	et	f	\N
194135	vähestama	?vähestama =vähestama  (SgG  >vähestam !02_A	et	f	\N
194136	vähestama	?vähestama =stama  (SgN  >vähe+stama !17_S	et	f	\N
194137	vähestama	?vähestama =stama  (SgG  >vähe+stama !17_S	et	f	\N
194138	vähestama	?vähestama =stama  (SgP  >vähe+stama !17_S	et	f	\N
194148	väljamõeldes	?väljamõeldes =mõelde  (PlIn  >välja+mõelt !22_S	et	f	\N
194149	väljamõeldes	?väljamõeldes =mõeldes  (SgN  >välja+mõeldes !09_S	et	f	\N
194190	juuretest	juuretest =test  (SgN  >juure+test !22_S	et	f	\N
194191	juuretest	juuretest =e  (PlEl  >juur+esi !15_S	et	f	\N
194230	pulmani	pulmani =pulma  (SgTer  >pulm !22_S	et	f	\N
194231	pulmani	pulmani =pulmani  (SgG  >pulman !02_S	et	f	\N
194239	taasiseseisvimise	?taasiseseisvimise =taasiseseisvimise  (SgG  >taasiseseisvimine !12_S	et	f	\N
194240	taasiseseisvimise	?taasiseseisvimise =seisvimise  (SgG  >taas+ise+seisvimine !12_S	et	f	\N
194241	taasiseseisvimise	?taasiseseisvimise =iseseisvimise  (SgG  >taas+iseseisvimine !12_S	et	f	\N
194246	uhkendada	?uhkendada =uhkenda  (Inf  >uhkendama !27_V	et	f	\N
194274	tuntumaks	tuntumaks =tuntuma  (SgTr  >tuntum !02_A	et	f	\N
194275	tuntumaks	"tuntum %tun  )TUM1_cA  <tundma ;34_V	et	f	\N
194288	folkloorfestival	?folkloorfestival =folkloorfestiva  (SgAd  >folkloorfestiv !02_A	et	f	\N
194289	folkloorfestival	?folkloorfestival =folkloorfestiva  (SgAd  >folkloorfestiva !16_S	et	f	\N
194290	folkloorfestival	?folkloorfestival =folkloorfestival  (SgN  >folkloorfestival !19_S	et	f	\N
194291	folkloorfestival	?folkloorfestival =loorfestiva  (SgAd  >folk+loorfestiv !02_A	et	f	\N
194292	folkloorfestival	?folkloorfestival =loorfestiva  (SgAd  >folk+loorfestiva !16_S	et	f	\N
194293	folkloorfestival	?folkloorfestival =loorfestival  (SgN  >folk+loorfestival !19_S	et	f	\N
194294	kultuuriilu	kultuuriilu =ilu  (SgN  >kultuuri+ilu !17_S	et	f	\N
194295	kultuuriilu	kultuuriilu =ilu  (SgG  >kultuuri+ilu !17_S	et	f	\N
194296	kultuuriilu	kultuuriilu =ilu  (SgP  >kultuuri+ilu !17_S	et	f	\N
194348	rahvulise	?rahvulise =rahvulise  (SgG  >rahvuline !12_A	et	f	\N
194353	absolütselt	?absolütselt =absolütse  (SgAbl  >absolütne !02_A	et	f	\N
194354	absolütselt	?absolütselt =absolütse  (PlAbl  >absolüts !22_S	et	f	\N
194355	absolütselt	?absolütselt =absolütselt  (ID  >absolütselt !41_D	et	f	\N
194361	iidentiteeti	?iidentiteeti =iidentiteeti  (SgN  >iidentiteeti !16_S	et	f	\N
194362	iidentiteeti	?iidentiteeti =iidentiteeti  (SgG  >iidentiteeti !16_S	et	f	\N
194363	iidentiteeti	?iidentiteeti =iidentiteeti  (SgP  >iidentiteet !22_S	et	f	\N
194364	iidentiteeti	?iidentiteeti =iidentiteeti  (SgAdt  >iidentiteet !22_S	et	f	\N
194369	harrastus	harrastus =harrastus  (SgN  >harrastus !11_S	et	f	\N
194370	harrastus	"harrastus %harrasta  )US_vS  <harrastama ;27_V	et	f	\N
194393	kannell	?kannell =kannell  (SgN  >kannell !22_S	et	f	\N
194416	laulaksid	laulaksid =laula  (KndPrSg2  >laulma !33_V	et	f	\N
194417	laulaksid	laulaksid =laula  (KndPrPl3  >laulma !33_V	et	f	\N
194418	laulaksid	laulaksid =laksi  (PlN  >lau+laks !22_S	et	f	\N
194430	käiti	?käiti =käiti  (ID  >käiti !41_D	et	f	\N
194431	käiti	?käiti =käiti  (SgP  >käit !22_S	et	f	\N
194432	käiti	?käiti =käiti  (SgAdt  >käit !22_S	et	f	\N
194442	jagatatakse	?jagatatakse =jagata  (IndPrIps  >jagatama !27_V	et	f	\N
194443	jagatatakse	?jagatatakse =jagatatakse  (SgG  >jagatatakne !02_A	et	f	\N
194444	jagatatakse	?jagatatakse =jagatatakse  (PlP  >jagatataks !22_S	et	f	\N
194446	osakese	osakese =osakese  (SgG  >osake !12_S	et	f	\N
194447	osakese	"osake %osa  )KE_dS  <osa ;17_S	et	f	\N
194448	osakese	osakese =osakese  (SgG  >osakene !12_S	et	f	\N
194449	osakese	"osakene %osa  )KENE_dS  <osa ;17_S	et	f	\N
194454	tsaari-venemaal	tsaari-venemaal =maa  (SgAd  >tsaari-vene+maa !26_S	et	f	\N
194455	tsaari-venemaal	tsaari-venemaal =maal  (SgN  >tsaari-vene+maal !22_S	et	f	\N
194462	levinunud	?levinunud =levinu  (PtsPtPs  >levinuma !27_V	et	f	\N
194463	levinunud	?levinunud =levinunu  (PlN  >levinunu !01_S	et	f	\N
194464	levinunud	?levinunud =levinunu  (IndPrSg2  >levinunuma !27_V	et	f	\N
194465	levinunud	?levinunud =levinunud  (ID  >levinunud !41_A	et	f	\N
194466	levinunud	?levinunud =nunu  (PlN  >levi+nunu !17_S	et	f	\N
194490	ülekaalukas	ülekaalukas =kaaluka  (SgIn  >üle+kaalukas !02_A	et	f	\N
194491	ülekaalukas	ülekaalukas =kaalukas  (SgN  >üle+kaalukas !02_A	et	f	\N
194125	tantsukultuuri	tantsukultuuri =kultuuri  (SgG  >tantsu+kultuur !22_S	et	f	\N
194126	tantsukultuuri	tantsukultuuri =kultuuri  (SgP  >tantsu+kultuur !22_S	et	f	\N
194127	tantsukultuuri	tantsukultuuri =kultuuri  (SgAdt  >tantsu+kultuur !22_S	et	f	\N
194141	küla-	küla- =küla  (SgN  >küla !17_S	et	f	\N
194142	küla-	küla- =küla  (SgG  >küla !17_S	et	f	\N
194143	küla-	küla- =küla  (SgP  >küla !17_S	et	f	\N
194147	tegust	### tegust	et	f	\N
194165	rütmisliikumine	?rütmisliikumine =rütmisliikumine  (SgN  >rütmisliikumine !12_S	et	f	\N
194166	rütmisliikumine	?rütmisliikumine =rütmisliikumine  (PlP  >rütmisliikumin !19_S	et	f	\N
194167	rütmisliikumine	?rütmisliikumine =sliikumine  (SgN  >rütmi+sliikumine !12_S	et	f	\N
194168	rütmisliikumine	?rütmisliikumine =sliikumine  (PlP  >rütmi+sliikumin !19_S	et	f	\N
194184	loomisele	loomisele =loomise  (SgAll  >loomis !09_S	et	f	\N
194185	loomisele	loomisele =loomise  (SgAll  >loomine !12?10_S	et	f	\N
194186	loomisele	"loomine %loo  )MINE_vS  <looma ;38_V	et	f	\N
194187	loomisele	"loomine %loomi  )NE_aA  <loom ;22_S	et	f	\N
194209	ülendav	ülendav =ülenda  (PtsPrPs  >ülendama !27_V	et	f	\N
194210	ülendav	ülendav =ülendav  (SgN  >ülendav !02_A	et	f	\N
194211	ülendav	"ülendav %ülenda  )V_vA  <ülendama ;27_V	et	f	\N
194212	folkloorpäevi	?folkloorpäevi =folkloorpäevi  (SgN  >folkloorpäevi !16_S	et	f	\N
194213	folkloorpäevi	?folkloorpäevi =folkloorpäevi  (SgG  >folkloorpäevi !16_S	et	f	\N
194214	folkloorpäevi	?folkloorpäevi =folkloorpäevi  (SgG  >folkloorpäev !22_S	et	f	\N
194215	folkloorpäevi	?folkloorpäevi =folkloorpäevi  (SgP  >folkloorpäev !22_S	et	f	\N
194216	folkloorpäevi	?folkloorpäevi =folkloorpäevi  (SgAdt  >folkloorpäev !22_S	et	f	\N
194217	folkloorpäevi	?folkloorpäevi =folkloorpäevi  (IndPrPs_  >folkloorpäevima !28_V	et	f	\N
194218	folkloorpäevi	?folkloorpäevi =folkloorpäevi  (ImpPrSg2  >folkloorpäevima !28_V	et	f	\N
194219	folkloorpäevi	?folkloorpäevi =loorpäevi  (SgG  >folk+loorpäev !22_S	et	f	\N
194220	folkloorpäevi	?folkloorpäevi =loorpäevi  (SgP  >folk+loorpäev !22_S	et	f	\N
194221	folkloorpäevi	?folkloorpäevi =loorpäevi  (SgAdt  >folk+loorpäev !22_S	et	f	\N
194226	põlveni	põlveni =põlve  (SgTer  >põlv !22_S	et	f	\N
194227	põlveni	põlveni =põlve  (SgTer  >põli !24_S	et	f	\N
194234	kirikutega	kirikutega =kiriku  (PlKom  >kirik !02_S	et	f	\N
194235	kirikutega	kirikutega =ute  (SgKom  >kirik+utt !22_S	et	f	\N
194243	teadlikust	teadlikust =teadliku  (SgEl  >teadlik !25_A	et	f	\N
194244	teadlikust	teadlikust =teadlikus  (SgP  >teadlikus !11_S	et	f	\N
194245	teadlikust	"teadlikus %teadliku  )US_aS  <teadlik ;25_A	et	f	\N
194260	musikaalinstrumente	?musikaalinstrumente =musikaalinstrumente  (PlP  >musikaalinstrument !22_S	et	f	\N
194261	musikaalinstrumente	?musikaalinstrumente =kaalinstrumente  (PlP  >musi+kaalinstrument !22_S	et	f	\N
194278	rahvapeoks	rahvapeoks =peo  (SgTr  >rahva+pidu !18_S	et	f	\N
194279	rahvapeoks	rahvapeoks =peo  (SgTr  >rahva+peo !26_S	et	f	\N
194281	laulukolektiivid	?laulukolektiivid =laulukolektiivi  (PlN  >laulukolektiivi !16_S	et	f	\N
194282	laulukolektiivid	?laulukolektiivid =laulukolektiivi  (PlN  >laulukolektiiv !22_S	et	f	\N
194283	laulukolektiivid	?laulukolektiivid =laulukolektiivi  (IndPrSg2  >laulukolektiivima !28_V	et	f	\N
194284	laulukolektiivid	?laulukolektiivid =kolektiivi  (PlN  >laulu+kolektiivi !16_S	et	f	\N
194285	laulukolektiivid	?laulukolektiivid =kolektiivi  (PlN  >laulu+kolektiiv !22_S	et	f	\N
194286	laulukolektiivid	?laulukolektiivid =lukolektiivi  (PlN  >lau+lukolektiivi !16_S	et	f	\N
194287	laulukolektiivid	?laulukolektiivid =lukolektiivi  (PlN  >lau+lukolektiiv !22_S	et	f	\N
194297	laulukolektiividest	?laulukolektiividest =laulukolektiivi  (PlEl  >laulukolektiivi !16_S	et	f	\N
194298	laulukolektiividest	?laulukolektiividest =laulukolektiivi  (PlEl  >laulukolektiiv !22_S	et	f	\N
194299	laulukolektiividest	?laulukolektiividest =laulukolektiivides  (SgP  >laulukolektiividene !12_A	et	f	\N
194300	laulukolektiividest	?laulukolektiividest =kolektiivi  (PlEl  >laulu+kolektiivi !16_S	et	f	\N
194301	laulukolektiividest	?laulukolektiividest =kolektiivi  (PlEl  >laulu+kolektiiv !22_S	et	f	\N
194302	laulukolektiividest	?laulukolektiividest =kolektiivides  (SgP  >laulu+kolektiividene !12_A	et	f	\N
194303	laulukolektiividest	?laulukolektiividest =lukolektiivi  (PlEl  >lau+lukolektiivi !16_S	et	f	\N
194304	laulukolektiividest	?laulukolektiividest =lukolektiivi  (PlEl  >lau+lukolektiiv !22_S	et	f	\N
194305	laulukolektiividest	?laulukolektiividest =lukolektiivides  (SgP  >lau+lukolektiividene !12_A	et	f	\N
194315	ootamises	ootamises =ootamise  (SgIn  >ootamine !12_S	et	f	\N
194316	ootamises	"ootamine %oota  )MINE_vS  <ootama ;29_V	et	f	\N
194326	laulupidudega	laulupidudega =pidu  (PlKom  >laulu+pidu !17_S	et	f	\N
194327	laulupidudega	laulupidudega =pidu  (PlKom  >laulu+pidu !18_S	et	f	\N
194344	suhtemis	suhtemis =mi  (SgIn  >suhte+mi !26_S	et	f	\N
194345	suhtemis	suhtemis =emis  (SgN  >suht+emis !09_S	et	f	\N
194367	harrastus	harrastus =harrastus  (SgN  >harrastus !11_S	et	f	\N
194368	harrastus	"harrastus %harrasta  )US_vS  <harrastama ;27_V	et	f	\N
194373	jalapõrutus	jalapõrutus =põrutu  (SgIn  >jala+põrutu !01_AS	et	f	\N
194374	jalapõrutus	jalapõrutus =põrutus  (SgN  >jala+põrutus !11_S	et	f	\N
194388	aranema	?aranema =arane  (Sup  >aranema !27_V	et	f	\N
194389	aranema	?aranema =aranema  (SgG  >aranem !02_A	et	f	\N
194390	aranema	?aranema =nema  (SgN  >ara+nema !17_S	et	f	\N
194202	suurepäärane	?suurepäärane =päärane  (SgN  >suure+päärane !10_A	et	f	\N
194203	suurepäärane	?suurepäärane =epäärane  (SgN  >suur+epäärane !10_A	et	f	\N
194204	suurepäärane	?suurepäärane =repäärane  (SgN  >suu+repäärane !10_A	et	f	\N
194247	rahvalaulu-	rahvalaulu- =laulu  (SgG  >rahva+laul !22_S	et	f	\N
194248	rahvalaulu-	rahvalaulu- =laulu  (SgP  >rahva+laul !22_S	et	f	\N
194249	rahvalaulu-	rahvalaulu- =laulu  (SgAdt  >rahva+laul !22_S	et	f	\N
194265	pop-folk	?pop-folk =folk  (SgN  >pop-folk !22_S	et	f	\N
194267	teemale	teemale =teema  (SgAll  >teema !16_S	et	f	\N
194268	teemale	teemale =male  (SgN  >tee+male !16_S	et	f	\N
194269	teemale	teemale =male  (SgG  >tee+male !16_S	et	f	\N
194280	leab	?leab =leab  (SgN  >leab !22_S	et	f	\N
194317	pärinesid	pärinesid =pärine  (IndIpfSg2  >pärinema !27_V	et	f	\N
194318	pärinesid	pärinesid =pärine  (IndIpfPl3  >pärinema !27_V	et	f	\N
194319	vallandasid	vallandasid =vallanda  (IndIpfSg2  >vallandama !27_V	et	f	\N
194320	vallandasid	vallandasid =vallanda  (IndIpfPl3  >vallandama !27_V	et	f	\N
194349	eestlastena	eestlastena =eestlas  (PlEs  >eestlane !12?10_S	et	f	\N
194350	eestlastena	eestlastena =las  (PlEs  >eest+laps !14_S	et	f	\N
194365	tähendamist	tähendamist =tähendamis  (SgP  >tähendamine !12_S	et	f	\N
194366	tähendamist	"tähendamine %tähenda  )MINE_vS  <tähendama ;27_V	et	f	\N
194371	õõtsutamine	õõtsutamine =õõtsutamine  (SgN  >õõtsutamine !12_S	et	f	\N
194372	õõtsutamine	"õõtsutamine %õõtsuta  )MINE_vS  <õõtsutama ;27_V	et	f	\N
194383	uuemas	uuemas =uuema  (SgIn  >uuem !02_A	et	f	\N
194384	uuemas	"uuem %uue  )M_cA  <uus ;14_A	et	f	\N
194394	püüjavad	?püüjavad =püüja  (IndPrPl3  >püüjama !29_V	et	f	\N
194395	püüjavad	?püüjavad =püüjava  (PlN  >püüjava !01_S	et	f	\N
194396	püüjavad	?püüjavad =püüjava  (PlN  >püüjav !02_A	et	f	\N
194397	üüritusele	üüritusele =üürituse  (SgAll  >üüritus !11_S	et	f	\N
194398	üüritusele	"üüritus %üüri  )TUS1_aS  <üürima ;28_V	et	f	\N
194399	üüritusele	"üüritus %üüri  )TUS2_aS  <üür ;22_S	et	f	\N
194402	enna	?enna =enna  (SgN  >enna !16_S	et	f	\N
194403	enna	?enna =enna  (SgG  >enna !16_S	et	f	\N
194404	enna	?enna =enna  (IndPrPs_  >ennama !29_V	et	f	\N
194405	enna	?enna =enna  (ImpPrSg2  >ennama !29_V	et	f	\N
194433	rajuma	?rajuma =raju  (Sup  >rajuma !27_V	et	f	\N
194439	tõelisi	tõelisi =tõelisi  (PlP  >tõeline !12_A	et	f	\N
194440	tõelisi	"tõeline %tõe  )LINE_aA  <tõsi ;15_S	et	f	\N
194441	tõelisi	"tõeline %tõe  )LINE_aA  <tõde ;18_S	et	f	\N
194450	zanreid	?zanreid =zanre  (PlP  >zanre !06_S	et	f	\N
194451	zanreid	?zanreid =zanrei  (PlN  >zanrei !26_S	et	f	\N
194452	zanreid	?zanreid =zanrei  (SgP  >zanrei !26_S	et	f	\N
194453	zanreid	?zanreid =zanreid  (SgN  >zanreid !22_S	et	f	\N
194459	iseseivuse	?iseseivuse =iseseivuse  (SgG  >iseseivus !11~09_S	et	f	\N
194460	iseseivuse	?iseseivuse =seivuse  (SgG  >ise+seivus !11~09_S	et	f	\N
194461	zanr	?zanr =zanr  (SgN  >zanr !22_S	et	f	\N
194467	rahvalaulutraditsiooni	rahvalaulutraditsiooni =traditsiooni  (SgG  >rahva+laulu+traditsioon !22_S	et	f	\N
194468	rahvalaulutraditsiooni	rahvalaulutraditsiooni =traditsiooni  (SgP  >rahva+laulu+traditsioon !22_S	et	f	\N
194469	rahvalaulutraditsiooni	rahvalaulutraditsiooni =traditsiooni  (SgAdt  >rahva+laulu+traditsioon !22_S	et	f	\N
194478	yorgis	?yorgis =yorgi  (SgIn  >yorg !02_S	et	f	\N
194479	yorgis	?yorgis =yorgi  (SgIn  >york !22_S	et	f	\N
194480	yorgis	?yorgis =yorgi  (IndIpfSg3  >yorgima !28_V	et	f	\N
194481	yorgis	?yorgis =yorgis  (SgN  >yorgis !09_S	et	f	\N
194489	häletas	?häletas =häleta  (IndIpfSg3  >häletama !27_V	et	f	\N
194495	venestuse	venestuse =venestuse  (SgG  >venestus !11_S	et	f	\N
194496	venestuse	"venestus %venesta  )US_vS  <venestama ;27_V	et	f	\N
194500	kreekat	?kreekat =kreeka  (SgP  >kreekas !02_A	et	f	\N
194501	kreekat	?kreekat =kreeka  (SgP  >kreeka !16_S	et	f	\N
194502	kreekat	?kreekat =kreekat  (SgN  >kreekat !02_S	et	f	\N
194505	joonistused	joonistused =joonistuse  (PlN  >joonistus !11_S	et	f	\N
194506	joonistused	"joonistus %joonista  )US_vS  <joonistama ;27_V	et	f	\N
194543	tsivilisatioon	?tsivilisatioon =tsivilisatioon  (SgN  >tsivilisatioon !22_S	et	f	\N
194550	kultuurig	### kultuurig	et	f	\N
194551	riikiges	?riikiges =iges  (SgN  >riik+iges !09_S	et	f	\N
194554	kaidi	?kaidi =kaidi  (SgN  >kaidi !16_S	et	f	\N
194555	kaidi	?kaidi =kaidi  (SgG  >kaidi !16_S	et	f	\N
194556	kaidi	?kaidi =kaidi  (SgG  >kait !22_S	et	f	\N
194557	kaidi	?kaidi =kaidi  (SgP  >kaid !22_S	et	f	\N
194558	kaidi	?kaidi =kaidi  (SgAdt  >kaid !22_S	et	f	\N
194559	kaidi	?kaidi =kaidi  (IndPrPs_  >kaitima !28_V	et	f	\N
194560	kaidi	?kaidi =kaidi  (ImpPrSg2  >kaitima !28_V	et	f	\N
194561	ennkõige	?ennkõige =ennkõige  (PlP  >ennkõig !22_S	et	f	\N
194563	teddy	### teddy	et	f	\N
194566	teddyl	?teddyl =teddyl  (SgN  >teddyl !02_S	et	f	\N
194587	lüsikas	?lüsikas =lüsika  (SgIn  >lüsika !01_S	et	f	\N
194588	lüsikas	?lüsikas =lüsika  (SgIn  >lüsikas !02_S	et	f	\N
194589	lüsikas	?lüsikas =lüsikas  (SgN  >lüsikas !02_S	et	f	\N
194591	joonistus	joonistus =joonistu  (IndIpfSg3  >joonistuma !27_V	et	f	\N
194306	levitatud	levitatud =levita  (PtsPtIps  >levitama !27_V	et	f	\N
194307	levitatud	levitatud =levitatu  (PlN  >levitatu !01_S	et	f	\N
194308	levitatud	"levitatu %levita  )TU1_vS  <levitama ;27_V	et	f	\N
194309	levitatud	levitatud =levitatud  (ID  >levitatud !41_A	et	f	\N
194310	levitatud	"levitatud %levita  )TUD_vA  <levitama ;27_V	et	f	\N
194336	püüjas	?püüjas =püüja  (SgIn  >püüja !01_S	et	f	\N
194337	püüjas	?püüjas =püüja  (IndIpfSg3  >püüjama !29_V	et	f	\N
194338	püüjas	?püüjas =püüjas  (SgN  >püüjas !07_S	et	f	\N
194339	laulama	?laulama =laula  (Sup  >laulama !29_V	et	f	\N
194340	laulama	?laulama =laulama  (SgG  >laulam !02_A	et	f	\N
194341	laulama	?laulama =lama  (SgN  >lau+lama !17_S	et	f	\N
194342	laulama	?laulama =lama  (SgG  >lau+lama !17_S	et	f	\N
194343	laulama	?laulama =lama  (SgP  >lau+lama !17_S	et	f	\N
194351	enesesse	enesesse =enese  (SgIll  >enese !00_P	et	f	\N
194352	enesesse	enesesse =enese  (SgIll  >ise !00_P	et	f	\N
194356	karjaste	karjaste =karjas  (PlG  >karjane !10_S	et	f	\N
194357	karjaste	"karjane %karja  )NE_aA  <kari ;24_S	et	f	\N
194375	ehitust	ehitust =ehitu  (SgEl  >ehitu !01_AS	et	f	\N
194376	ehitust	"ehitu %ehi  )TU1_vS  <ehtima ;28_V	et	f	\N
194377	ehitust	ehitust =ehitus  (SgP  >ehitus !11_S	et	f	\N
194378	ehitust	"ehitus %ehita  )US_vS  <ehitama ;27_V	et	f	\N
194379	ehitust	"ehitus %ehi  )TUS1_aS  <ehtima ;28_V	et	f	\N
194380	kiikudes	kiikudes =kiiku  (PlIn  >kiik !22_S	et	f	\N
194381	kiikudes	kiikudes =kiiku  (Ger  >kiikuma !28_V	et	f	\N
194401	singers	?singers =singers  (SgN  >singers !02_S	et	f	\N
194406	esinejaid	esinejaid =esineja  (PlP  >esineja !01_S	et	f	\N
194407	esinejaid	"esineja %esine  )JA_vS  <esinema ;27_V	et	f	\N
194422	töödati	?töödati =töödati  (ID  >töödati !41_D	et	f	\N
194423	töödati	?töödati =töödati  (SgG  >töödat !02_S	et	f	\N
194424	töödati	?töödati =töödati  (SgG  >töödatt !22_S	et	f	\N
194425	töödati	?töödati =töödati  (IndPrPs_  >töödattima !28_V	et	f	\N
194426	töödati	?töödati =töödati  (ImpPrSg2  >töödattima !28_V	et	f	\N
194427	töödati	?töödati =dati  (SgN  >töö+dati !16_S	et	f	\N
194428	töödati	?töödati =dati  (SgG  >töö+dati !16_S	et	f	\N
194429	töödati	?töödati =dati  (SgG  >töö+datt !22_S	et	f	\N
194434	tunneti	?tunneti =tunne  (IndIpfIps  >tunnema !27_V	et	f	\N
194435	tunneti	?tunneti =tunneti  (ID  >tunneti !41_D	et	f	\N
194436	tunneti	?tunneti =tunneti  (SgG  >tunnett !22_S	et	f	\N
194437	tunneti	?tunneti =tunneti  (IndPrPs_  >tunnettima !28_V	et	f	\N
194438	tunneti	?tunneti =tunneti  (ImpPrSg2  >tunnettima !28_V	et	f	\N
194445	naeramise	?naeramise =naeramise  (SgG  >naeramine !12_S	et	f	\N
194470	venestust	venestust =venestus  (SgP  >venestus !11_S	et	f	\N
194471	venestust	"venestus %venesta  )US_vS  <venestama ;27_V	et	f	\N
194476	kohades	kohades =koha  (PlIn  >koha !17_S	et	f	\N
194477	kohades	kohades =koha  (Ger  >kohama !27_V	et	f	\N
194482	koolitused	koolitused =koolituse  (PlN  >koolitus !11_S	et	f	\N
194484	koolitused	"koolitus %koolita  )US_vS  <koolitama ;27_V	et	f	\N
194485	koolitused	"koolitus %kooli  )TUS2_aS  <kool ;22_S	et	f	\N
194494	230888a	### 230888a	et	f	\N
194503	väärtusta	väärtusta =väärtusta  (IndPrPs_  >väärtustama !27_V	et	f	\N
194504	väärtusta	väärtusta =väärtusta  (ImpPrSg2  >väärtustama !27_V	et	f	\N
194509	mahukas	mahukas =mahuka  (SgIn  >mahukas !02_A	et	f	\N
194510	mahukas	mahukas =mahukas  (SgN  >mahukas !02_A	et	f	\N
194536	tuntuv	?tuntuv =tuntu  (PtsPrPs  >tuntuma !27_V	et	f	\N
194537	tuntuv	?tuntuv =tuntuv  (SgN  >tuntuv !02_A	et	f	\N
194541	nõukogumiste	nõukogumiste =kogumis  (PlG  >nõu+kogumine !12_S	et	f	\N
194542	nõukogumiste	"nõu+kogumine %kogumi  )NE_aA  <nõu+kogum ;02_S	et	f	\N
194545	seostatud	seostatud =seosta  (PtsPtIps  >seostama !27_V	et	f	\N
194546	seostatud	seostatud =seostatu  (PlN  >seostatu !01_S	et	f	\N
194547	seostatud	"seostatu %seosta  )TU1_vS  <seostama ;27_V	et	f	\N
194548	seostatud	seostatud =seostatud  (ID  >seostatud !41_A	et	f	\N
194549	seostatud	"seostatud %seosta  )TUD_vA  <seostama ;27_V	et	f	\N
194564	valge-kollane	valge-kollane =kollane  (SgN  >valge-kollane !10_A	et	f	\N
194565	valge-kollane	"valge-kollane %kolla  )NE_aA  <valge-kold ;22_S	et	f	\N
194577	ringane	?ringane =ringane  (SgN  >ringane !10_A	et	f	\N
194578	ringane	?ringane =ringane  (IndPrPs_  >ringanema !27_V	et	f	\N
194579	ringane	?ringane =ringane  (ImpPrSg2  >ringanema !27_V	et	f	\N
194580	ringane	?ringane =ane  (SgN  >ring+ane !16_S	et	f	\N
194581	ringane	?ringane =ane  (SgG  >ring+ane !16_S	et	f	\N
194596	finland	?finland =finland  (SgN  >finland !02_S	et	f	\N
194609	kasutatub	?kasutatub =kasutatu  (IndPrSg3  >kasutatuma !27_V	et	f	\N
194611	mustriline	mustriline =mustriline  (SgN  >mustriline !12_A	et	f	\N
194612	mustriline	"mustriline %mustri  )LINE_aA  <muster ;02_S	et	f	\N
194662	teelusikas	teelusikas =lusika  (SgIn  >tee+lusikas !02_S	et	f	\N
194663	teelusikas	teelusikas =lusikas  (SgN  >tee+lusikas !02_S	et	f	\N
194681	eksklussiivne	?eksklussiivne =eksklussiivne  (SgN  >eksklussiivne !02_A	et	f	\N
194682	eksklussiivne	?eksklussiivne =eksklussiivne  (PlP  >eksklussiivn !22_S	et	f	\N
194330	folkloorifestivaalide	?folkloorifestivaalide =festivaali  (PlG  >folkloori+festivaali !16_S	et	f	\N
194331	folkloorifestivaalide	?folkloorifestivaalide =festivaali  (PlG  >folkloori+festivaal !22_S	et	f	\N
194332	folkloorifestivaalide	?folkloorifestivaalide =rifestivaali  (PlG  >folk+loo+rifestivaali !16_S	et	f	\N
194333	folkloorifestivaalide	?folkloorifestivaalide =rifestivaali  (PlG  >folk+loo+rifestivaal !22_S	et	f	\N
194334	folkloorifestivaalide	?folkloorifestivaalide =loorifestivaali  (PlG  >folk+loorifestivaali !16_S	et	f	\N
194335	folkloorifestivaalide	?folkloorifestivaalide =loorifestivaali  (PlG  >folk+loorifestivaal !22_S	et	f	\N
194346	gruppile	?gruppile =gruppile  (IndPrPs_  >gruppilema !27_V	et	f	\N
194347	gruppile	?gruppile =gruppile  (ImpPrSg2  >gruppilema !27_V	et	f	\N
194358	värskast	?värskast =värska  (SgEl  >värska !01_S	et	f	\N
194359	värskast	?värskast =värskas  (SgP  >värskas !07_S	et	f	\N
194360	värskast	?värskast =värskas  (SgP  >värskane !12~10_A	et	f	\N
194382	spontaalsed	?spontaalsed =spontaalse  (PlN  >spontaalne !02_A	et	f	\N
194385	rahvalaulas	?rahvalaulas =rahvalaula  (SgIn  >rahvalaula !01_S	et	f	\N
194386	rahvalaulas	?rahvalaulas =laula  (SgIn  >rahva+laula !16_S	et	f	\N
194387	rahvalaulas	?rahvalaulas =laulas  (SgN  >rahva+laulas !07_S	et	f	\N
194410	spetsaalselt	?spetsaalselt =spetsaalse  (SgAbl  >spetsaalne !02_A	et	f	\N
194411	spetsaalselt	?spetsaalselt =spetsaalse  (PlAbl  >spetsaals !22_S	et	f	\N
194412	spetsaalselt	?spetsaalselt =spetsaalselt  (ID  >spetsaalselt !41_D	et	f	\N
194413	spetsaalselt	?spetsaalselt =aalse  (SgAbl  >spets+aalne !02_A	et	f	\N
194414	spetsaalselt	?spetsaalselt =aalse  (SgAbl  >spets+aalse !06_S	et	f	\N
194415	spetsaalselt	?spetsaalselt =aalse  (PlAbl  >spets+aals !22_S	et	f	\N
194419	kokkuleppe	kokkuleppe =leppe  (SgG  >kokku+lepe !06_S	et	f	\N
194420	kokkuleppe	kokkuleppe =leppe  (PlP  >kokku+lepp !22_S	et	f	\N
194421	kokkuleppe	kokkuleppe =leppe  (PlP  >kokku+lepp !22_SA	et	f	\N
194456	pearolli	pearolli =rolli  (SgG  >pea+roll !22_S	et	f	\N
194457	pearolli	pearolli =rolli  (SgP  >pea+roll !22_S	et	f	\N
194458	pearolli	pearolli =rolli  (SgAdt  >pea+roll !22_S	et	f	\N
194486	kuritegumisi	?kuritegumisi =kuritegumisi  (ID  >kuritegumisi !41_D	et	f	\N
194487	kuritegumisi	?kuritegumisi =kuritegumisi  (PlP  >kuritegumine !12_S	et	f	\N
194488	kuritegumisi	?kuritegumisi =tegumisi  (PlP  >kuri+tegumine !12_S	et	f	\N
194492	toetajal	toetajal =toetaja  (SgAd  >toetaja !01_S	et	f	\N
194493	toetajal	"toetaja %toeta  )JA_vS  <toetama ;27_V	et	f	\N
194497	vilnus	?vilnus =vilnu  (SgIn  >vilnu !01_S	et	f	\N
194498	vilnus	?vilnus =vilnu  (IndIpfSg3  >vilnuma !27_V	et	f	\N
194499	vilnus	?vilnus =vilnus  (SgN  >vilnus !11~09_S	et	f	\N
194515	kombesid	?kombesid =kombe  (IndIpfSg2  >kombema !27_V	et	f	\N
194516	kombesid	?kombesid =kombe  (IndIpfPl3  >kombema !27_V	et	f	\N
194517	kombesid	?kombesid =besi  (PlN  >kom+besi !17_S	et	f	\N
194522	kopeeritud	kopeeritud =kopeeri  (PtsPtIps  >kopeerima !28_V	et	f	\N
194523	kopeeritud	kopeeritud =kopeeritu  (PlN  >kopeeritu !01_S	et	f	\N
194524	kopeeritud	"kopeeritu %kopeeri  )TU1_vS  <kopeerima ;28_V	et	f	\N
194525	kopeeritud	"kopeeritu %kopeeri  )TU2_kA  <kopeer ;22_S	et	f	\N
194526	kopeeritud	kopeeritud =kopeeritud  (ID  >kopeeritud !41_A	et	f	\N
194527	kopeeritud	"kopeeritud %kopeeri  )TUD_vA  <kopeerima ;28_V	et	f	\N
194553	arfitektuur	?arfitektuur =arfitektuur  (SgN  >arfitektuur !22_S	et	f	\N
194562	teddy	### teddy	et	f	\N
194569	kadakast	kadakast =kadaka  (SgEl  >kadakas !02_S	et	f	\N
194570	kadakast	kadakast =kadakas  (SgP  >kadakane !12_A	et	f	\N
194571	kadakast	"kadakane %kadaka  )NE_aA  <kadakas ;02_S	et	f	\N
194572	kadakast	kadakast =kast  (SgN  >kada+kast !22_S	et	f	\N
194573	tähtsab	?tähtsab =tähtsa  (IndPrSg3  >tähtsama !29_V	et	f	\N
194582	värvis	värvis =värvi  (SgIn  >värv !22_S	et	f	\N
194583	värvis	värvis =värvi  (IndIpfSg3  >värvima !28_V	et	f	\N
194584	värvis	värvis =värvis  (SgN  >värvis !09_S	et	f	\N
194585	kalug	### kalug	et	f	\N
194602	graami	?graami =graami  (SgN  >graami !16_S	et	f	\N
194603	graami	?graami =graami  (SgG  >graami !16_S	et	f	\N
194604	graami	?graami =graami  (SgG  >graam !22_S	et	f	\N
194605	graami	?graami =graami  (SgP  >graam !22_S	et	f	\N
194606	graami	?graami =graami  (SgAdt  >graam !22_S	et	f	\N
194607	graami	?graami =graami  (IndPrPs_  >graamima !28_V	et	f	\N
194608	graami	?graami =graami  (ImpPrSg2  >graamima !28_V	et	f	\N
194615	võitmete	?võitmete =võitme  (PlG  >võitme !06_S	et	f	\N
194616	võitmete	?võitmete =võitme  (IndPrPl2  >võitmema !27_V	et	f	\N
194636	formis	?formis =formi  (SgIn  >formi !16_S	et	f	\N
194637	formis	?formis =formi  (SgIn  >form !22_S	et	f	\N
194638	formis	?formis =formi  (IndIpfSg3  >formima !28_V	et	f	\N
194639	formis	?formis =formis  (SgN  >formis !09_S	et	f	\N
194644	nokias	?nokias =nokia  (SgIn  >nokia !01_S	et	f	\N
194645	nokias	?nokias =nokias  (SgN  >nokias !11_S	et	f	\N
194646	valitan	?valitan =valita  (IndPrSg1  >valitama !27_V	et	f	\N
194647	valitan	?valitan =valitan  (SgN  >valitan !19_S	et	f	\N
194664	hõbelusikas	hõbelusikas =lusika  (SgIn  >hõbe+lusikas !02_S	et	f	\N
194665	hõbelusikas	hõbelusikas =lusikas  (SgN  >hõbe+lusikas !02_S	et	f	\N
194685	vööd	vööd =vöö  (PlN  >vöö !26_S	et	f	\N
194391	aranema	?aranema =nema  (SgG  >ara+nema !17_S	et	f	\N
194392	aranema	?aranema =nema  (SgP  >ara+nema !17_S	et	f	\N
194400	orthodox	### orthodox	et	f	\N
194408	käsitlesid	käsitlesid =käsitle  (IndIpfSg2  >käsitlema !27_V	et	f	\N
194409	käsitlesid	käsitlesid =käsitle  (IndIpfPl3  >käsitlema !27_V	et	f	\N
194472	lootsid	lootsid =loot  (IndIpfSg2  >lootma !34_V	et	f	\N
194473	lootsid	lootsid =loot  (IndIpfPl3  >lootma !34_V	et	f	\N
194474	lootsid	lootsid =lootsi  (PlN  >loots !22_S	et	f	\N
194475	lootsid	lootsid =lootsi  (IndPrSg2  >lootsima !28_V	et	f	\N
194483	floridas	### floridas	et	f	\N
194507	kuulamisel	kuulamisel =kuulamise  (SgAd  >kuulamine !12_S	et	f	\N
194508	kuulamisel	"kuulamine %kuula  )MINE_vS  <kuulama ;29_V	et	f	\N
194511	kombest	kombest =kombe  (SgEl  >komme !06_S	et	f	\N
194512	kombest	kombest =kombe  (PlEl  >komp !22_S	et	f	\N
194513	kombest	kombest =kombes  (SgP  >kombene !12~10_A	et	f	\N
194514	kombest	"kombene %kombe  )NE_aA  <komme ;06_S	et	f	\N
194518	kombedest	?kombedest =kombedes  (SgP  >kombedene !12_A	et	f	\N
194519	kombedest	?kombedest =bede  (SgEl  >kom+bede !16_S	et	f	\N
194520	kombedest	?kombedest =bedes  (SgP  >kom+bedes !09_S	et	f	\N
194521	kombedest	?kombedest =bedes  (SgP  >kom+bedene !10_A	et	f	\N
194528	rahvastega	rahvastega =rahvas  (PlKom  >rahvas !07_S	et	f	\N
194529	rahvastega	rahvastega =rahvas  (PlKom  >rahvane !10_A	et	f	\N
194530	rahvastega	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
194567	tõsisel	tõsisel =tõsise  (SgAd  >tõsine !10_A	et	f	\N
194568	tõsisel	"tõsine %tõsi  )NE_aA  <tõsi ;15_S	et	f	\N
194574	sugulastelt	sugulastelt =sugulas  (PlAbl  >sugulane !12_S	et	f	\N
194575	sugulastelt	sugulastelt =las  (PlAbl  >sugu+laps !14_S	et	f	\N
194576	sugulastelt	sugulastelt =laste  (PlAbl  >sugu+last !22_S	et	f	\N
194594	todud	?todud =todu  (PlN  >todu !17_S	et	f	\N
194595	todud	?todud =todu  (IndPrSg2  >toduma !27_V	et	f	\N
194599	kuuskümend	?kuuskümend =kuuskümend  (SgN  >kuuskümend !22_S	et	f	\N
194600	kuuskümend	?kuuskümend =kümend  (SgN  >kuus+kümend !02_S	et	f	\N
194601	kuuskümend	?kuuskümend =skümend  (SgN  >kuu+skümend !02_S	et	f	\N
194613	võtmehoidja	võtmehoidja =hoidja  (SgN  >võtme+hoidja !01_S	et	f	\N
194614	võtmehoidja	võtmehoidja =hoidja  (SgG  >võtme+hoidja !01_S	et	f	\N
194617	metallist	metallist =metalli  (SgEl  >metall !22_S	et	f	\N
194618	metallist	metallist =metallis  (SgP  >metalline !10_A	et	f	\N
194619	metallist	"metalline %metalli  )NE_aA  <metall ;22_S	et	f	\N
194620	metallist	metallist =metallist  (SgN  >metallist !22_S	et	f	\N
194623	frantsusmaale	?frantsusmaale =frantsusmaa  (SgAll  >frantsusmaa !26_S	et	f	\N
194624	frantsusmaale	?frantsusmaale =frantsusmaale  (SgN  >frantsusmaale !16_S	et	f	\N
194625	frantsusmaale	?frantsusmaale =frantsusmaale  (SgG  >frantsusmaale !16_S	et	f	\N
194626	frantsusmaale	?frantsusmaale =frantsusmaale  (PlP  >frantsusmaal !22_S	et	f	\N
194651	klahvi	klahvi =klahvi  (SgG  >klahv !22_S	et	f	\N
194652	klahvi	klahvi =klahvi  (SgP  >klahv !22_S	et	f	\N
194653	klahvi	klahvi =klahvi  (SgAdt  >klahv !22_S	et	f	\N
194698	pei	?pei =pei  (SgN  >pei !26_S	et	f	\N
194699	pei	?pei =pei  (SgG  >pei !26_S	et	f	\N
194717	uinutama	uinutama =uinu  (SupIps  >uinuma !27_V	et	f	\N
194718	uinutama	uinutama =uinuta  (Sup  >uinutama !27_V	et	f	\N
194729	tekkitada	?tekkitada =tekkita  (Inf  >tekkitama !27_V	et	f	\N
194740	tabavad	tabavad =taba  (IndPrPl3  >tabama !27_V	et	f	\N
194742	tabavad	tabavad =tabava  (PlN  >tabav !02_A	et	f	\N
194743	tabavad	"tabav %taba  )V_vA  <tabama ;27_V	et	f	\N
194754	mooritud	mooritud =moori  (PtsPtIps  >moorima !28_V	et	f	\N
194755	mooritud	mooritud =mooritu  (PlN  >mooritu !01_AS	et	f	\N
194756	mooritud	"mooritu %moori  )TU1_vS  <moorima ;28_V	et	f	\N
194757	mooritud	"mooritu %moori  )TU2_kA  <moor ;22_S	et	f	\N
194758	mooritud	mooritud =mooritud  (ID  >mooritud !41_A	et	f	\N
194759	mooritud	"mooritud %moori  )TUD_vA  <moorima ;28_V	et	f	\N
194774	kalaseljanka	kalaseljanka =seljanka  (SgN  >kala+seljanka !16_S	et	f	\N
194775	kalaseljanka	kalaseljanka =seljanka  (SgG  >kala+seljanka !16_S	et	f	\N
194781	joodid	joodid =joodi  (PlN  >jood !22_S	et	f	\N
194785	joodid	joodid =joodi  (IndPrSg2  >joodima !28_V	et	f	\N
194797	kaste	kaste =kaste  (SgN  >kaste !05_S	et	f	\N
194798	kaste	kaste =kaste  (SgN  >kaste !06_S	et	f	\N
194799	kaste	kaste =kaste  (SgG  >kaste !06_S	et	f	\N
194800	kaste	kaste =kaste  (PlP  >kast !22_S	et	f	\N
194801	grintvein	?grintvein =grintvein  (SgN  >grintvein !22_S	et	f	\N
194804	rosalje	?rosalje =rosalje  (SgN  >rosalje !16_S	et	f	\N
194805	rosalje	?rosalje =rosalje  (SgG  >rosalje !16_S	et	f	\N
194823	naturalne	?naturalne =naturalne  (SgN  >naturalne !02_A	et	f	\N
194824	naturalne	?naturalne =naturalne  (PlP  >naturaln !22_S	et	f	\N
194834	kastas	?kastas =kasta  (SgIn  >kasta !16_S	et	f	\N
194835	kastas	?kastas =kasta  (IndIpfSg3  >kastama !29_V	et	f	\N
194836	kastas	?kastas =kastas  (SgN  >kastas !07_S	et	f	\N
194856	kohf	?kohf =kohf  (SgN  >kohf !22_S	et	f	\N
194864	reguleerimine	reguleerimine =reguleerimine  (SgN  >reguleerimine !12_S	et	f	\N
194531	aju	aju =aju  (SgN  >aju !17_S	et	f	\N
194532	aju	aju =aju  (SgG  >aju !17_S	et	f	\N
194533	aju	aju =aju  (SgP  >aju !17_S	et	f	\N
194534	aju	aju =aju  (IndPrPs_  >ajuma !27_V	et	f	\N
194535	aju	aju =aju  (ImpPrSg2  >ajuma !27_V	et	f	\N
194538	laenavad	laenavad =laena  (IndPrPl3  >laenama !29_V	et	f	\N
194539	laenavad	laenavad =laenava  (PlN  >laenav !02_A	et	f	\N
194540	laenavad	"laenav %laena  )V_vA  <laenama ;29_V	et	f	\N
194544	krewtzwald	?krewtzwald =krewtzwald  (SgN  >krewtzwald !02_S	et	f	\N
194552	sssrs	### sssrs	et	f	\N
194586	kümend	?kümend =kümend  (SgN  >kümend !02_S	et	f	\N
194590	tehtub	?tehtub =tehtu  (IndPrSg3  >tehtuma !27_V	et	f	\N
194621	epfeli	?epfeli =epfeli  (ID  >epfeli !41_D	et	f	\N
194622	epfeli	?epfeli =epfeli  (SgG  >epfel !02_S	et	f	\N
194632	model	?model =mode  (SgAd  >mode !16_S	et	f	\N
194633	model	?model =model  (SgN  >model !02_S	et	f	\N
194654	telefoniraamatuses	?telefoniraamatuses =telefoniraamatuse  (SgIn  >telefoniraamatus !11?09_S	et	f	\N
194655	telefoniraamatuses	?telefoniraamatuses =atuse  (SgIn  >telefoni+raam+atus !09_S	et	f	\N
194656	telefoniraamatuses	?telefoniraamatuses =raamatuse  (SgIn  >telefoni+raamatus !11_S	et	f	\N
194657	telefoniraamatuses	?telefoniraamatuses =iraamatuse  (SgIn  >telefon+iraamatus !11?09_S	et	f	\N
194658	telefoniraamatuses	?telefoniraamatuses =foniraamatuse  (SgIn  >tele+foniraamatus !11?09_S	et	f	\N
194659	peenike	peenike =peenike  (SgN  >peenike !12_A	et	f	\N
194660	peenike	peenike =ike  (SgN  >peen+ike !06_S	et	f	\N
194670	finlandia	?finlandia =finlandia  (SgN  >finlandia !01_S	et	f	\N
194671	finlandia	?finlandia =finlandia  (SgG  >finlandia !01_S	et	f	\N
194672	suveniri	?suveniri =suveniri  (SgG  >suvenir !19_S	et	f	\N
194673	suveniri	?suveniri =suveniri  (SgP  >suvenir !19_S	et	f	\N
194674	suveniri	?suveniri =suveniri  (SgAdt  >suvenir !19_S	et	f	\N
194675	suveniri	?suveniri =niri  (SgN  >suve+niri !17_S	et	f	\N
194676	suveniri	?suveniri =niri  (SgG  >suve+niri !17_S	et	f	\N
194677	suveniri	?suveniri =niri  (SgP  >suve+niri !17_S	et	f	\N
194690	lillekuiuline	?lillekuiuline =lillekuiuline  (SgN  >lillekuiuline !12_A	et	f	\N
194695	lillekuiuline	?lillekuiuline =uline  (SgN  >lille+kui+uline !10_A	et	f	\N
194696	lillekuiuline	?lillekuiuline =kuiuline  (SgN  >lille+kuiuline !12_A	et	f	\N
194697	lillekuiuline	?lillekuiuline =ekuiuline  (SgN  >lill+ekuiuline !12_A	et	f	\N
194700	tumesinine	?tumesinine =tumesinine  (SgN  >tumesinine !12_A	et	f	\N
194701	tumesinine	?tumesinine =tumesinine  (PlP  >tumesinin !19_S	et	f	\N
194702	tumesinine	?tumesinine =sinine  (SgN  >tume+sinine !10_AS	et	f	\N
194704	lehtedega	lehtedega =lehte  (PlKom  >leht !22_S	et	f	\N
194705	lehtedega	lehtedega =ede  (SgKom  >leht+ede !16_S	et	f	\N
194712	kinkinud	kinkinud =kinki  (PtsPtPs  >kinkima !28_V	et	f	\N
194713	kinkinud	kinkinud =kinkinu  (PlN  >kinkinu !01_S	et	f	\N
194714	kinkinud	"kinkinu %kinki  )NU_vS  <kinkima ;28_V	et	f	\N
194715	kinkinud	kinkinud =kinkinud  (ID  >kinkinud !41_A	et	f	\N
194716	kinkinud	"kinkinud %kinki  )NUD_vA  <kinkima ;28_V	et	f	\N
194719	nõudmistega	nõudmistega =nõudmis  (PlKom  >nõudmine !12?10_S	et	f	\N
194720	nõudmistega	"nõudmine %nõud  )MINE_vS  <nõudma ;34_V	et	f	\N
194727	tekkitavad	tekkitavad =tekkitava  (PlN  >tekkitav !02_A	et	f	\N
194728	tekkitavad	"tekkitav %tekki  )TAV_vAS  <tekkima ;27_V	et	f	\N
194730	alergiat	?alergiat =alergia  (SgP  >alergia !01_S	et	f	\N
194731	alergiat	?alergiat =alergiat  (SgN  >alergiat !22_S	et	f	\N
194737	madanema	?madanema =madane  (Sup  >madanema !27_V	et	f	\N
194738	madanema	?madanema =madanema  (SgG  >madanem !02_A	et	f	\N
194739	mullasse	mullasse =mulla  (SgIll  >mulla !16_S	et	f	\N
194741	mullasse	mullasse =mulla  (SgIll  >muld !22_S	et	f	\N
194751	värskekapsasupp	?värskekapsasupp =värskekapsasupp  (SgN  >värskekapsasupp !22_S	et	f	\N
194752	masikakompot	?masikakompot =masikakompo  (SgP  >masikakompo !16_S	et	f	\N
194753	singisalat	?singisalat =singisala  (SgP  >singisala !01_S	et	f	\N
194777	mandlikovrike	?mandlikovrike =mandlikovrike  (SgN  >mandlikovrike !12_S	et	f	\N
194778	mandlikovrike	?mandlikovrike =kovrike  (SgN  >mandli+kovrike !12_S	et	f	\N
194793	kaste	kaste =kaste  (SgN  >kaste !05_S	et	f	\N
194794	kaste	kaste =kaste  (SgN  >kaste !06_S	et	f	\N
194795	kaste	kaste =kaste  (SgG  >kaste !06_S	et	f	\N
194796	kaste	kaste =kaste  (PlP  >kast !22_S	et	f	\N
194809	kevaduse	?kevaduse =kevaduse  (SgG  >kevadus !11_S	et	f	\N
194810	kevaduse	?kevaduse =use  (SgN  >kevad+use !16_S	et	f	\N
194811	kevaduse	?kevaduse =use  (SgG  >kevad+use !16_S	et	f	\N
194815	soolased	soolased =soolase  (PlN  >soolane !10_A	et	f	\N
194817	soolased	"soolane %soola  )NE_aA  <sool ;22_S	et	f	\N
194825	õuna-ananassi	õuna-ananassi =ananassi  (SgG  >õuna-ananass !22_S	et	f	\N
194826	õuna-ananassi	õuna-ananassi =ananassi  (SgP  >õuna-ananass !22_S	et	f	\N
194827	õuna-ananassi	õuna-ananassi =ananassi  (SgAdt  >õuna-ananass !22_S	et	f	\N
194829	kartulipüree	kartulipüree =püree  (SgN  >kartuli+püree !26_S	et	f	\N
194830	kartulipüree	kartulipüree =püree  (SgG  >kartuli+püree !26_S	et	f	\N
194837	kastas	?kastas =kasta  (SgIn  >kasta !16_S	et	f	\N
194838	kastas	?kastas =kasta  (IndIpfSg3  >kastama !29_V	et	f	\N
194592	joonistus	joonistus =joonistus  (SgN  >joonistus !11_S	et	f	\N
194593	joonistus	"joonistus %joonista  )US_vS  <joonistama ;27_V	et	f	\N
194597	kinkitama	?kinkitama =kinkita  (Sup  >kinkitama !27_V	et	f	\N
194598	kinkitama	?kinkitama =kinkitama  (SgG  >kinkitam !02_A	et	f	\N
194610	sõbr	?sõbr =sõbr  (SgN  >sõbr !22_S	et	f	\N
194627	võitmetele	?võitmetele =võitme  (PlAll  >võitme !06_S	et	f	\N
194628	võitmetele	?võitmetele =võitmete  (PlAll  >võitmett !22_S	et	f	\N
194629	võitmetele	?võitmetele =võitmetele  (IndPrPs_  >võitmetelema !36_V	et	f	\N
194630	võitmetele	?võitmetele =võitmetele  (ImpPrSg2  >võitmetelema !36_V	et	f	\N
194631	esed	?esed =ese  (IndPrSg2  >esema !27_V	et	f	\N
194634	model	?model =mode  (SgAd  >mode !16_S	et	f	\N
194635	model	?model =model  (SgN  >model !02_S	et	f	\N
194640	saldo	saldo =saldo  (SgN  >saldo !16_S	et	f	\N
194641	saldo	saldo =saldo  (SgG  >saldo !16_S	et	f	\N
194642	modelis	?modelis =modeli  (SgIn  >model !02_S	et	f	\N
194643	modelis	?modelis =modelis  (SgN  >modelis !11_S	et	f	\N
194648	numbrimärksed	?numbrimärksed =numbrimärkse  (PlN  >numbrimärkne !02_A	et	f	\N
194649	numbrimärksed	?numbrimärksed =märkse  (PlN  >numbri+märkne !02_A	et	f	\N
194650	numbrimärksed	?numbrimärksed =märkse  (PlN  >numbri+märkse !06_S	et	f	\N
194661	pot	### pot	et	f	\N
194666	kujtatud	?kujtatud =kujta  (PtsPtIps  >kujtama !29_V	et	f	\N
194667	kujtatud	?kujtatud =kujtatu  (PlN  >kujtatu !01_S	et	f	\N
194668	kujtatud	?kujtatud =kujtatu  (IndPrSg2  >kujtatuma !27_V	et	f	\N
194669	kujtatud	?kujtatud =kujtatud  (ID  >kujtatud !41_A	et	f	\N
194678	hõbedast	hõbedast =hõbeda  (SgEl  >hõbe !02_S	et	f	\N
194679	hõbedast	hõbedast =hõbedas  (SgP  >hõbedane !12_A	et	f	\N
194680	hõbedast	"hõbedane %hõbeda  )NE_aA  <hõbe ;02_S	et	f	\N
194703	kirjulise	?kirjulise =kirjulise  (SgG  >kirjuline !12_A	et	f	\N
194710	linnukujuliseks	linnukujuliseks =kujulise  (SgTr  >linnu+kujuline !12_A	et	f	\N
194711	linnukujuliseks	"linnu+kujuline %kuju  )LINE_aA  <linnu+kuju ;17_S	et	f	\N
194732	iiveldust	iiveldust =iiveldus  (SgP  >iiveldus !11_S	et	f	\N
194733	iiveldust	"iiveldus %iivelda  )US_vS  <iiveldama ;27_V	et	f	\N
194760	pilaf	?pilaf =pilaf  (SgN  >pilaf !02_S	et	f	\N
194769	lambaruulad	?lambaruulad =lambaruula  (PlN  >lambaruula !16_S	et	f	\N
194770	lambaruulad	?lambaruulad =ruula  (PlN  >lamba+ruula !16_S	et	f	\N
194772	serbiapäraselt	?serbiapäraselt =serbiapärase  (SgAbl  >serbiapärane !12_A	et	f	\N
194773	serbiapäraselt	?serbiapäraselt =serbiapäraselt  (ID  >serbiapäraselt !41_D	et	f	\N
194806	olivje	### olivje	et	f	\N
194812	salatt	?salatt =salatt  (SgN  >salatt !22_S	et	f	\N
194814	sinepkastmega	### sinepkastmega	et	f	\N
194821	tunikala	?tunikala =tunikala  (SgN  >tunikala !01_S	et	f	\N
194822	tunikala	?tunikala =tunikala  (SgG  >tunikala !01_S	et	f	\N
194846	puuviilja	?puuviilja =puuviilja  (SgN  >puuviilja !16_S	et	f	\N
194847	puuviilja	?puuviilja =puuviilja  (SgG  >puuviiljas !02_A	et	f	\N
194848	puuviilja	?puuviilja =puuviilja  (SgG  >puuviilja !16_S	et	f	\N
194849	puuviilja	?puuviilja =viilja  (SgN  >puu+viilja !01_S	et	f	\N
194850	puuviilja	?puuviilja =viilja  (SgG  >puu+viilja !01_S	et	f	\N
194851	puuviilja	?puuviilja =viilja  (SgG  >puu+viiljas !02_A	et	f	\N
194857	sobivast	sobivast =sobiva  (SgEl  >sobiv !02_A	et	f	\N
194858	sobivast	"sobiv %sobi  )V_vA  <sobima ;27_V	et	f	\N
194867	töölaud	töölaud =au  (PlN  >tööl+au !26_S	et	f	\N
194868	töölaud	töölaud =lau  (PlN  >töö+laug !22_SA	et	f	\N
194869	töölaud	töölaud =laud  (SgN  >töö+laud !22_S	et	f	\N
194876	kõrsusega	?kõrsusega =kõrsuse  (SgKom  >kõrsus !11~09_S	et	f	\N
194893	kvalited	### kvalited	et	f	\N
194900	ootamis	?ootamis =ootami  (SgIn  >ootami !01_S	et	f	\N
194901	ootamis	?ootamis =ootami  (SgIn  >ootam !02_A	et	f	\N
194902	ootamis	?ootamis =ootamis  (SgN  >ootamis !11_S	et	f	\N
194903	valimusest	valimusest =valimuse  (SgEl  >valimus !11_S	et	f	\N
194904	valimusest	"valimus %vali  )MUS_vS  <valima ;27_V	et	f	\N
194941	tarbial	?tarbial =tarbia  (SgAd  >tarbia !01_S	et	f	\N
194942	tarbial	?tarbial =tarbial  (SgN  >tarbial !19~02_S	et	f	\N
194966	vanusega	vanusega =vanuse  (SgKom  >vanus !09_S	et	f	\N
194967	vanusega	vanusega =vanuse  (SgKom  >vanune !10_A	et	f	\N
194973	esiljagu	?esiljagu =esiljagu  (IndPrPs_  >esiljaguma !27_V	et	f	\N
194974	esiljagu	?esiljagu =esiljagu  (ImpPrSg2  >esiljaguma !27_V	et	f	\N
194976	ununie	?ununie =ununie  (SgN  >ununie !01_S	et	f	\N
194977	ununie	?ununie =ununie  (SgG  >ununie !01_S	et	f	\N
194982	lõõbusaid	?lõõbusaid =lõõbusa  (PlP  >lõõbusa !01_S	et	f	\N
194983	lõõbusaid	?lõõbusaid =lõõbusai  (PlN  >lõõbusai !26_S	et	f	\N
194984	lõõbusaid	?lõõbusaid =lõõbusai  (SgP  >lõõbusai !26_S	et	f	\N
194993	kleitid	### kleitid	et	f	\N
194995	räägitasime	?räägitasime =räägita  (IndIpfPl1  >räägitama !27_V	et	f	\N
195015	jõid	jõid =jõ  (IndIpfSg2  >jooma !38_V	et	f	\N
195016	jõid	jõid =jõ  (IndIpfPl3  >jooma !38_V	et	f	\N
195017	x-linna	x-linna =linna  (SgG  >x-linn !22_S	et	f	\N
195018	x-linna	x-linna =linna  (SgP  >x-linn !22_S	et	f	\N
194683	eksklussiivne	?eksklussiivne =klussiivne  (SgN  >eks+klussiivne !02_A	et	f	\N
194684	eksklussiivne	?eksklussiivne =klussiivne  (PlP  >eks+klussiivn !22_S	et	f	\N
194687	vööb	?vööb =vööb  (SgN  >vööb !22_S	et	f	\N
194706	mururoheline	mururoheline =roheline  (SgN  >muru+roheline !12_A	et	f	\N
194707	mururoheline	"muru+roheline %rohe  )LINE_aA  <muru+rohe ;16_S	et	f	\N
194724	kokteili	kokteili =kokteili  (SgG  >kokteil !22_S	et	f	\N
194725	kokteili	kokteili =kokteili  (SgP  >kokteil !22_S	et	f	\N
194726	kokteili	kokteili =kokteili  (SgAdt  >kokteil !22_S	et	f	\N
194744	ohku	?ohku =ohku  (ID  >ohku !41_D	et	f	\N
194745	ohku	?ohku =ohku  (IndPrPs_  >ohkuma !27_V	et	f	\N
194746	ohku	?ohku =ohku  (ImpPrSg2  >ohkuma !27_V	et	f	\N
194750	toksidilised	?toksidilised =toksidilise  (PlN  >toksidiline !12_A	et	f	\N
194767	vadimka	?vadimka =vadimka  (SgN  >vadimka !16_S	et	f	\N
194768	vadimka	?vadimka =vadimka  (SgG  >vadimka !16_S	et	f	\N
194779	bacardi	?bacardi =bacardi  (SgN  >bacardi !01_S	et	f	\N
194780	bacardi	?bacardi =bacardi  (SgG  >bacardi !01_S	et	f	\N
194782	bacardi	?bacardi =bacardi  (SgG  >bacard !02_S	et	f	\N
194783	bacardi	?bacardi =bacardi  (SgG  >bacart !22_S	et	f	\N
194784	bacardi	?bacardi =bacardi  (IndPrPs_  >bacartima !28_V	et	f	\N
194786	bacardi	?bacardi =bacardi  (ImpPrSg2  >bacartima !28_V	et	f	\N
194787	biifsteeks	?biifsteeks =biifstee  (SgTr  >biifstee !26_S	et	f	\N
194788	biifsteeks	?biifsteeks =biifsteeks  (SgN  >biifsteeks !22_S	et	f	\N
194807	venegrett	?venegrett =venegrett  (SgN  >venegrett !22_S	et	f	\N
194808	venegrett	?venegrett =grett  (SgN  >vene+grett !22_S	et	f	\N
194813	pannkogit	?pannkogit =pannkogi  (SgP  >pannkog !02_S	et	f	\N
194816	pannkogit	?pannkogit =kogit  (SgN  >pann+kogit !02_S	et	f	\N
194859	võimaldatud	võimaldatud =võimalda  (PtsPtIps  >võimaldama !27_V	et	f	\N
194860	võimaldatud	võimaldatud =võimaldatu  (PlN  >võimaldatu !01_S	et	f	\N
194861	võimaldatud	"võimaldatu %võimalda  )TU1_vS  <võimaldama ;27_V	et	f	\N
194862	võimaldatud	võimaldatud =võimaldatud  (ID  >võimaldatud !41_A	et	f	\N
194863	võimaldatud	"võimaldatud %võimalda  )TUD_vA  <võimaldama ;27_V	et	f	\N
194874	reguleeritava	reguleeritava =reguleeritava  (SgG  >reguleeritav !02_A	et	f	\N
194875	reguleeritava	"reguleeritav %reguleeri  )TAV_vAS  <reguleerima ;28_V	et	f	\N
194916	kummardajate	kummardajate =kummardaja  (PlG  >kummardaja !01_S	et	f	\N
194917	kummardajate	"kummardaja %kummarda  )JA_vS  <kummardama ;27_V	et	f	\N
194929	marketites	?marketites =marketite  (PlIn  >marketitt !22_S	et	f	\N
194934	ostes	ostes =ost  (Ger  >ostma !34_V	et	f	\N
194935	ostes	ostes =oste  (PlIn  >ost !22_S	et	f	\N
194955	rahulolev	rahulolev =ole  (PtsPrPs  >rahul+_olema !36_V	et	f	\N
194956	rahulolev	rahulolev =olev  (SgN  >rahul+olev !02_A	et	f	\N
194999	kooku	kooku =kooku  (ID  >kooku !41_D	et	f	\N
195000	kooku	kooku =kooku  (SgP  >kook !22_S	et	f	\N
195001	kooku	kooku =kooku  (SgAdt  >kook !22_S	et	f	\N
195011	agro	?agro =agro  (SgN  >agro !16_S	et	f	\N
195012	agro	?agro =agro  (SgG  >agro !16_S	et	f	\N
195013	pidaksime	?pidaksime =pidaksi  (IndPrPl1  >pidaksima !28_V	et	f	\N
195029	õhtuosakonna	õhtuosakonna =konna  (SgG  >õhtu+osa+konn !22_S	et	f	\N
195030	õhtuosakonna	õhtuosakonna =konna  (SgP  >õhtu+osa+konn !22_S	et	f	\N
195031	õhtuosakonna	õhtuosakonna =konna  (SgAdt  >õhtu+osa+konn !22_S	et	f	\N
195032	õhtuosakonna	õhtuosakonna =osakonna  (SgG  >õhtu+osakond !22_S	et	f	\N
195055	korrast	korrast =korra  (SgEl  >kord !22_S	et	f	\N
195056	korrast	korrast =korras  (SgP  >korrane !10_A	et	f	\N
195057	korrast	"korrane %korra  )NE_aA  <kord ;22_S	et	f	\N
195058	korrast	korrast =korrast  (ID  >korrast !41_D	et	f	\N
195069	dukumendid	?dukumendid =dukumendi  (PlN  >dukument !22_S	et	f	\N
195070	dukumendid	?dukumendid =dukumendi  (IndPrSg2  >dukumentima !28_V	et	f	\N
195080	floristika	floristika =floristika  (SgN  >floristika !01_S	et	f	\N
195081	floristika	floristika =floristika  (SgG  >floristika !01_S	et	f	\N
195094	televad	?televad =tele  (IndPrPl3  >telema !27_V	et	f	\N
195095	televad	?televad =televa  (PlN  >televa !01_S	et	f	\N
195096	televad	?televad =televa  (PlN  >telev !02_A	et	f	\N
195099	olukordi	olukordi =kordi  (SgP  >olu+kord !22_S	et	f	\N
195100	olukordi	olukordi =kordi  (SgAdt  >olu+kord !22_S	et	f	\N
195101	olukordi	olukordi =kordi  (PlP  >olu+kord !22_S	et	f	\N
195121	kiirusta	kiirusta =kiirusta  (IndPrPs_  >kiirustama !27_V	et	f	\N
195122	kiirusta	kiirusta =kiirusta  (ImpPrSg2  >kiirustama !27_V	et	f	\N
195123	esemeses	?esemeses =esemese  (SgIn  >esemene !12_A	et	f	\N
195153	kulmatu	?kulmatu =kulmatu  (SgN  >kulmatu !01_A	et	f	\N
195154	kulmatu	?kulmatu =kulmatu  (SgG  >kulmatu !01_A	et	f	\N
195155	kulmatu	?kulmatu =kulmatu  (IndPrPs_  >kulmatuma !27_V	et	f	\N
195156	kulmatu	?kulmatu =kulmatu  (ImpPrSg2  >kulmatuma !27_V	et	f	\N
195157	tasakaalukus	tasakaalukus =kaalukus  (SgN  >tasa+kaalukus !11_S	et	f	\N
195158	tasakaalukus	"tasa+kaalukus %kaaluka  )US_aS  <tasa+kaalukas ;02_A	et	f	\N
195175	tuttavalt	tuttavalt =tuttava  (SgAbl  >tuttav !02_AS	et	f	\N
195176	tuttavalt	tuttavalt =tuttavalt  (ID  >tuttavalt !41_D	et	f	\N
195177	tuttavalt	"tuttavalt %tuttava  )LT_mD  <tuttav ;02_AS	et	f	\N
194686	vööd	vööd =vöö  (SgP  >vöö !26_S	et	f	\N
194688	vastupidav	vastupidav =pida  (PtsPrPs  >vastu+_pidama !28_V	et	f	\N
194689	vastupidav	vastupidav =pidav  (SgN  >vastu+pidav !02_A	et	f	\N
194691	lillekuiuline	?lillekuiuline =lillekuiuline  (SgN  >lillekuiuline !12_A	et	f	\N
194692	lillekuiuline	?lillekuiuline =uline  (SgN  >lille+kui+uline !10_A	et	f	\N
194693	lillekuiuline	?lillekuiuline =kuiuline  (SgN  >lille+kuiuline !12_A	et	f	\N
194694	lillekuiuline	?lillekuiuline =ekuiuline  (SgN  >lill+ekuiuline !12_A	et	f	\N
194708	noorõde	noorõde =õde  (SgN  >noor+õde !18_S	et	f	\N
194709	noorõde	noorõde =õde  (SgP  >noor+õde !18_S	et	f	\N
194721	sõbralle	?sõbralle =sõbralle  (PlP  >sõbrall !22_S	et	f	\N
194722	sõbralle	?sõbralle =sõbralle  (IndPrPs_  >sõbrallema !27_V	et	f	\N
194723	sõbralle	?sõbralle =sõbralle  (ImpPrSg2  >sõbrallema !27_V	et	f	\N
194734	konservantid	### konservantid	et	f	\N
194735	viisatakse	viisatakse =viisa  (IndPrIps  >viisama !29_V	et	f	\N
194736	viisatakse	viisatakse =takse  (PlP  >viisa+taks !22_S	et	f	\N
194747	imbuvad	imbuvad =imbu  (IndPrPl3  >imbuma !27_V	et	f	\N
194748	imbuvad	imbuvad =imbuva  (PlN  >imbuv !02_A	et	f	\N
194749	imbuvad	"imbuv %imbu  )V_vA  <imbuma ;27_V	et	f	\N
194761	glasuuri	glasuuri =glasuuri  (SgG  >glasuur !22_S	et	f	\N
194762	glasuuri	glasuuri =glasuuri  (SgP  >glasuur !22_S	et	f	\N
194763	glasuuri	glasuuri =glasuuri  (SgAdt  >glasuur !22_S	et	f	\N
194764	glasuuri	glasuuri =glasuuri  (IndPrPs_  >glasuurima !28_V	et	f	\N
194765	glasuuri	glasuuri =glasuuri  (ImpPrSg2  >glasuurima !28_V	et	f	\N
194766	whiskey	### whiskey	et	f	\N
194771	kalmaarirõngad	?kalmaarirõngad =kalmaarirõnga  (PlN  >kalmaarirõnga !16_S	et	f	\N
194776	kalmaarisalat	?kalmaarisalat =kalmaarisala  (SgP  >kalmaarisala !01_S	et	f	\N
194789	kaste	kaste =kaste  (SgN  >kaste !05_S	et	f	\N
194790	kaste	kaste =kaste  (SgN  >kaste !06_S	et	f	\N
194791	kaste	kaste =kaste  (SgG  >kaste !06_S	et	f	\N
194792	kaste	kaste =kaste  (PlP  >kast !22_S	et	f	\N
194802	kala-justusalatt	?kala-justusalatt =justusalatt  (SgN  >kala-justusalatt !22_S	et	f	\N
194803	kala-justusalatt	?kala-justusalatt =usalatt  (SgN  >kala-just+usalatt !22_S	et	f	\N
194818	hakkliha	hakkliha =liha  (SgN  >hakk+liha !17_S	et	f	\N
194819	hakkliha	hakkliha =liha  (SgG  >hakk+liha !17_S	et	f	\N
194820	hakkliha	hakkliha =liha  (SgP  >hakk+liha !17_S	et	f	\N
194828	kedukartul	?kedukartul =kedukartul  (SgN  >kedukartul !02_S	et	f	\N
194831	aedviiljasupp	?aedviiljasupp =aedviiljasupp  (SgN  >aedviiljasupp !22_S	et	f	\N
194832	aedviiljasupp	?aedviiljasupp =jasupp  (SgN  >aed+viil+jasupp !22_S	et	f	\N
194833	aedviiljasupp	?aedviiljasupp =viiljasupp  (SgN  >aed+viiljasupp !22_S	et	f	\N
194840	merekala	merekala =kala  (SgN  >mere+kala !17_S	et	f	\N
194841	merekala	merekala =kala  (SgG  >mere+kala !17_S	et	f	\N
194842	merekala	merekala =kala  (SgP  >mere+kala !17_S	et	f	\N
194843	aedviiljasalat	?aedviiljasalat =aedviiljasala  (SgP  >aedviiljasala !01_S	et	f	\N
194844	aedviiljasalat	?aedviiljasalat =jasala  (SgP  >aed+viil+jasala !01_S	et	f	\N
194845	aedviiljasalat	?aedviiljasalat =viiljasala  (SgP  >aed+viiljasala !01_S	et	f	\N
194877	3x	### 3x	et	f	\N
194884	liigutatav	liigutatav =liiguta  (PtsPrIps  >liigutama !27_V	et	f	\N
194885	liigutatav	liigutatav =liigutatav  (SgN  >liigutatav !02_A	et	f	\N
194886	liigutatav	"liigutatav %liiguta  )TAV_vAS  <liigutama ;27_V	et	f	\N
194890	ubandused	?ubandused =ubanduse  (PlN  >ubandus !11_S	et	f	\N
194912	ärritadan	?ärritadan =ärritadan  (SgN  >ärritadan !19_S	et	f	\N
194914	austajate	austajate =austaja  (PlG  >austaja !01_S	et	f	\N
194915	austajate	"austaja %austa  )JA_vS  <austama ;27_V	et	f	\N
194918	ootamise	ootamise =ootamise  (SgG  >ootamine !12_S	et	f	\N
194919	ootamise	"ootamine %oota  )MINE_vS  <ootama ;29_V	et	f	\N
194943	tarbiakaitse	?tarbiakaitse =tarbiakaitse  (SgG  >tarbiakaitne !02_A	et	f	\N
194944	tarbiakaitse	?tarbiakaitse =tarbiakaitse  (PlP  >tarbiakaits !22_S	et	f	\N
194945	tarbiakaitse	?tarbiakaitse =tarbiakaitse  (IndPrPs_  >tarbiakaitsema !27_V	et	f	\N
194946	tarbiakaitse	?tarbiakaitse =tarbiakaitse  (ImpPrSg2  >tarbiakaitsema !27_V	et	f	\N
194947	tagasise	?tagasise =tagasise  (SgG  >tagasis !11_S	et	f	\N
194948	tagasise	?tagasise =sise  (SgN  >taga+sise !16_S	et	f	\N
194949	tagasise	?tagasise =sise  (SgG  >taga+sise !16_S	et	f	\N
194950	kordaläinud	kordaläinud =läi  (PtsPtPs  >korda+_minema !36_V	et	f	\N
194951	kordaläinud	kordaläinud =läinu  (PlN  >korda+läinu !01_S	et	f	\N
194952	kordaläinud	kordaläinud =läinu  (PlN  >korda+läinu !06_S	et	f	\N
194953	suhtumise	suhtumise =suhtumise  (SgG  >suhtumine !12_S	et	f	\N
194954	suhtumise	"suhtumine %suhtu  )MINE_vS  <suhtuma ;27_V	et	f	\N
194965	tansisime	?tansisime =tansi  (IndIpfPl1  >tansima !28_V	et	f	\N
194975	majustustega	?majustustega =majustus  (PlKom  >majustus !11_S	et	f	\N
194979	õhtuklassi	õhtuklassi =klassi  (SgG  >õhtu+klass !22_S	et	f	\N
194980	õhtuklassi	õhtuklassi =klassi  (SgP  >õhtu+klass !22_S	et	f	\N
194981	õhtuklassi	õhtuklassi =klassi  (SgAdt  >õhtu+klass !22_S	et	f	\N
194996	asjalikult	asjalikult =asjaliku  (SgAbl  >asjalik !25_A	et	f	\N
194997	asjalikult	asjalikult =asjalikult  (ID  >asjalikult !41_D	et	f	\N
194998	asjalikult	"asjalikult %asjaliku  )LT_mD  <asjalik ;25_A	et	f	\N
194839	kastas	?kastas =kastas  (SgN  >kastas !07_S	et	f	\N
194852	marjademahlast	?marjademahlast =marjademahla  (SgEl  >marjademahla !01_S	et	f	\N
194853	marjademahlast	?marjademahlast =marjademahlas  (SgP  >marjademahlane !12_S	et	f	\N
194854	marjademahlast	?marjademahlast =demahla  (SgEl  >marja+demahla !01_S	et	f	\N
194855	marjademahlast	?marjademahlast =demahlas  (SgP  >marja+demahlane !12_S	et	f	\N
194866	2x	### 2x	et	f	\N
194887	kataloogika	?kataloogika =kataloogika  (SgN  >kataloogika !01_S	et	f	\N
194888	kataloogika	?kataloogika =kataloogika  (SgG  >kataloogika !01_S	et	f	\N
194889	kataloogika	?kataloogika =kataloogika  (SgG  >kataloogikas !02_A	et	f	\N
194891	marketis	?marketis =marketi  (SgIn  >markett !22_S	et	f	\N
194892	marketis	?marketis =marketis  (SgN  >marketis !11_S	et	f	\N
194894	pildikesi	pildikesi =pildikesi  (PlP  >pildike !12_S	et	f	\N
194895	pildikesi	"pildike %pildi  )KE_dS  <pilt ;22_S	et	f	\N
194896	pildikesi	pildikesi =pildikesi  (PlP  >pildikene !12_S	et	f	\N
194897	pildikesi	"pildikene %pildi  )KENE_dS  <pilt ;22_S	et	f	\N
194925	avaldatavate	avaldatavate =avaldatava  (PlG  >avaldatav !02_A	et	f	\N
194926	avaldatavate	"avaldatav %avalda  )TAV_vAS  <avaldama ;27_V	et	f	\N
194936	puhkusest	puhkusest =puhkuse  (SgEl  >puhkus !11~09_S	et	f	\N
194937	puhkusest	puhkusest =puhkuses  (SgP  >puhkusene !12_A	et	f	\N
194938	puhkusest	"puhkusene %puhkuse  )NE_aA  <puhkus ;09_S	et	f	\N
194939	puhkusest	"puhkusene %puhkuse  )NE_aA  <puhkus ;11_S	et	f	\N
194940	puhkusest	puhkusest =use  (PlEl  >puhk+usk !22_S	et	f	\N
194957	soodsalt	soodsalt =soodsa  (SgAbl  >soodus !02_A	et	f	\N
194958	soodsalt	soodsalt =soodsa  (SgAbl  >soodne !02_A	et	f	\N
194959	soodsalt	soodsalt =soodsalt  (ID  >soodsalt !41_D	et	f	\N
194960	soodsalt	"soodsalt %soodsa  )LT_mD  <soodus ;02_A	et	f	\N
194961	soodsalt	"soodsalt %soodsa  )LT_mD  <soodne ;02_A	et	f	\N
194962	limonaadi	limonaadi =limonaadi  (SgG  >limonaad !22_S	et	f	\N
194963	limonaadi	limonaadi =limonaadi  (SgP  >limonaad !22_S	et	f	\N
194964	limonaadi	limonaadi =limonaadi  (SgAdt  >limonaad !22_S	et	f	\N
194978	teksaga	?teksaga =teksa  (SgKom  >teksa !16_S	et	f	\N
194991	praadi	praadi =praadi  (SgP  >praad !22_S	et	f	\N
194992	praadi	praadi =praadi  (SgAdt  >praad !22_S	et	f	\N
195004	mõnicord	?mõnicord =mõnicord  (SgN  >mõnicord !22_S	et	f	\N
195005	mõnicord	?mõnicord =cord  (SgN  >mõni+cord !22_S	et	f	\N
195006	vaelased	?vaelased =vaelase  (PlN  >vaelane !12?10_S	et	f	\N
195033	tööruumi	tööruumi =ruumi  (SgG  >töö+ruum !22_S	et	f	\N
195034	tööruumi	tööruumi =ruumi  (SgP  >töö+ruum !22_S	et	f	\N
195035	tööruumi	tööruumi =ruumi  (SgAdt  >töö+ruum !22_S	et	f	\N
195039	niinas	?niinas =niina  (SgIn  >niina !16_S	et	f	\N
195040	niinas	?niinas =niina  (IndIpfSg3  >niinama !29_V	et	f	\N
195041	niinas	?niinas =niinas  (SgN  >niinas !07_S	et	f	\N
195046	tunnd	?tunnd =tunnd  (SgN  >tunnd !22_S	et	f	\N
195052	hinnele	?hinnele =hinne  (PlAll  >hinn !22_S	et	f	\N
195053	hinnele	?hinnele =hinnele  (IndPrPs_  >hinnelema !31~27_V	et	f	\N
195054	hinnele	?hinnele =hinnele  (ImpPrSg2  >hinnelema !31~27_V	et	f	\N
195059	ensekindel	?ensekindel =ensekinde  (PlAd  >ensekint !22_S	et	f	\N
195067	kojusse	?kojusse =kojusse  (SgG  >kojusne !02_A	et	f	\N
195068	kojusse	?kojusse =kojusse  (PlP  >kojuss !22_S	et	f	\N
195071	ajalooõpetaja	ajalooõpetaja =õpetaja  (SgN  >aja+loo+õpetaja !01_S	et	f	\N
195072	ajalooõpetaja	ajalooõpetaja =õpetaja  (SgG  >aja+loo+õpetaja !01_S	et	f	\N
195074	lemmikõppeaine	lemmikõppeaine =aine  (SgN  >lemmik+õppe+aine !06_S	et	f	\N
195075	lemmikõppeaine	lemmikõppeaine =aine  (SgG  >lemmik+õppe+aine !06_S	et	f	\N
195076	lemmikõppeaine	lemmikõppeaine =aine  (PlP  >lemmik+õppe+ain !22_S	et	f	\N
195106	paluvad	paluvad =palu  (IndPrPl3  >paluma !27_V	et	f	\N
195107	paluvad	paluvad =paluva  (PlN  >paluv !02_A	et	f	\N
195108	paluvad	"paluv %palu  )V_vA  <paluma ;27_V	et	f	\N
195113	maganvale	?maganvale =maganva  (SgAll  >maganva !01_S	et	f	\N
195119	tülitse	tülitse =tülitse  (IndPrPs_  >tülitsema !27_V	et	f	\N
195120	tülitse	tülitse =tülitse  (ImpPrSg2  >tülitsema !27_V	et	f	\N
195126	estimaa	?estimaa =estimaa  (SgN  >estimaa !26_S	et	f	\N
195127	estimaa	?estimaa =estimaa  (SgG  >estimaa !26_S	et	f	\N
195162	keskaegsetel	keskaegsetel =sete  (PlAd  >kesk+aeg+sett !22_S	et	f	\N
195163	keskaegsetel	keskaegsetel =aegse  (PlAd  >kesk+aegne !02_A	et	f	\N
195171	spordikeskuses	spordikeskuses =use  (PlIn  >spordi+kesk+usk !22_S	et	f	\N
195172	spordikeskuses	spordikeskuses =keskuse  (SgIn  >spordi+keskus !11~09_S	et	f	\N
195173	pingelises	pingelises =pingelise  (SgIn  >pingeline !12_A	et	f	\N
195174	pingelises	"pingeline %pinge  )LINE_aA  <pinge ;06_S	et	f	\N
195183	lülitamised	lülitamised =lülitamise  (PlN  >lülitamine !12_S	et	f	\N
195184	lülitamised	"lülitamine %lülita  )MINE_vS  <lülitama ;27_V	et	f	\N
195189	eksita	eksita =eksi  (IndPrIps_  >eksima !28_V	et	f	\N
195190	eksita	eksita =eksita  (IndPrPs_  >eksitama !27_V	et	f	\N
195191	eksita	eksita =eksita  (ImpPrSg2  >eksitama !27_V	et	f	\N
195198	negativsed	?negativsed =negativse  (PlN  >negativne !02_A	et	f	\N
195205	miditsini	?miditsini =miditsi  (SgTer  >midits !02_S	et	f	\N
194865	reguleerimine	"reguleerimine %reguleeri  )MINE_vS  <reguleerima ;28_V	et	f	\N
194870	püsikinde	?püsikinde =püsikinde  (PlP  >püsikind !22_S	et	f	\N
194871	püsikinde	?püsikinde =kinde  (SgN  >püsi+kinde !06_S	et	f	\N
194872	püsikinde	?püsikinde =kinde  (SgG  >püsi+kinne !06_S	et	f	\N
194873	püsikinde	?püsikinde =kinde  (PlP  >püsi+kind !22_S	et	f	\N
194878	u-kujuline	u-kujuline =kujuline  (SgN  >u-kujuline !12_A	et	f	\N
194879	u-kujuline	"u-kujuline %kuju  )LINE_aA  <u-kuju ;17_S	et	f	\N
194880	käepäraselt	käepäraselt =pärase  (SgAbl  >käe+pärane !10_A	et	f	\N
194881	käepäraselt	"käe+pärane %pära  )NE_aA  <käe+pära ;17_S	et	f	\N
194882	käepäraselt	"käe+päraselt %pära  )SELT_mD  <käe+pära ;17_S	et	f	\N
194883	käepäraselt	"käe+päraselt %pärase  )LT_mD  <käe+pärane ;10_A	et	f	\N
194898	kataloogid	kataloogid =kataloogi  (PlN  >kataloog !22_S	et	f	\N
194899	kataloogid	kataloogid =kataloogi  (IndPrSg2  >kataloogima !28_V	et	f	\N
194905	piiratus	piiratus =piiratu  (SgIn  >piiratu !01_AS	et	f	\N
194906	piiratus	"piiratu %piira  )TU1_vS  <piirama ;29_V	et	f	\N
194907	piiratus	"piiratu %piira  )TU2_kA  <piird ;22_S	et	f	\N
194908	piiratus	piiratus =piiratus  (SgN  >piiratus !11_S	et	f	\N
194909	piiratus	"piiratus %piira  )TUS1_aS  <piirama ;29_V	et	f	\N
194910	piiratus	"piiratus %piira  )TUS2_aS  <piird ;22_S	et	f	\N
194911	piiratus	piiratus =atu  (SgIn  >piir+att !22_S	et	f	\N
194913	kaupad	?kaupad =kaupa  (IndPrSg2  >kaupama !29_V	et	f	\N
194920	riknenud	riknenud =rikne  (PtsPtPs  >riknema !27_V	et	f	\N
194921	riknenud	riknenud =riknenu  (PlN  >riknenu !01_S	et	f	\N
194922	riknenud	"riknenu %rikne  )NU_vS  <riknema ;27_V	et	f	\N
194923	riknenud	riknenud =riknenud  (ID  >riknenud !41_A	et	f	\N
194924	riknenud	"riknenud %rikne  )NUD_vA  <riknema ;27_V	et	f	\N
194927	tõstmine	tõstmine =tõstmine  (SgN  >tõstmine !12?10_S	et	f	\N
194928	tõstmine	"tõstmine %tõst  )MINE_vS  <tõstma ;34_V	et	f	\N
194930	poedes	?poedes =poe  (PlIn  >poe !26_S	et	f	\N
194931	poedes	?poedes =poede  (PlIn  >poet !22_S	et	f	\N
194932	poedes	?poedes =poede  (IndIpfSg3  >poedema !27_V	et	f	\N
194933	poedes	?poedes =poedes  (SgN  >poedes !09_S	et	f	\N
194968	lasteaijas	?lasteaijas =lasteaija  (SgIn  >lasteaija !01_S	et	f	\N
194969	lasteaijas	?lasteaijas =lasteaija  (SgIn  >lasteaijas !02_A	et	f	\N
194970	lasteaijas	?lasteaijas =lasteaijas  (SgN  >lasteaijas !02_A	et	f	\N
194971	lasteaijas	?lasteaijas =aija  (SgIn  >laste+aija !01_S	et	f	\N
194972	lasteaijas	?lasteaijas =aijas  (SgN  >laste+aijas !07_S	et	f	\N
194985	noorusel	noorusel =nooruse  (SgAd  >noorus !11~09_S	et	f	\N
194986	noorusel	"noorus %noor  )US_aS  <noor ;13_AS	et	f	\N
194987	noorusel	noorusel =use  (PlAd  >noor+usk !22_S	et	f	\N
194988	targaid	?targaid =targai  (PlN  >targai !26_S	et	f	\N
194989	targaid	?targaid =targai  (SgP  >targai !26_S	et	f	\N
194990	targaid	?targaid =targaid  (SgN  >targaid !22_S	et	f	\N
194994	ostime	?ostime =osti  (IndPrPl1  >ostima !28_V	et	f	\N
195002	tansime	?tansime =tansi  (IndPrPl1  >tanssima !28_V	et	f	\N
195008	pojeg	### pojeg	et	f	\N
195024	õhtuosakonnas	õhtuosakonnas =konna  (SgIn  >õhtu+osa+konn !22_S	et	f	\N
195025	õhtuosakonnas	õhtuosakonnas =osakonna  (SgIn  >õhtu+osakond !22_S	et	f	\N
195050	jutustust	jutustust =jutustus  (SgP  >jutustus !11_S	et	f	\N
195051	jutustust	"jutustus %jutusta  )US_vS  <jutustama ;27_V	et	f	\N
195063	lähedamalt	lähedamalt =lähedama  (SgAbl  >lähedam !02_A	et	f	\N
195064	lähedamalt	"lähedam %läheda  )M_cA  <läheda ;02_A	et	f	\N
195065	lähedamalt	lähedamalt =lähedamalt  (ID  >lähedamalt !41_D	et	f	\N
195066	lähedamalt	"lähedamalt %läheda  )MALT_mD  <läheda ;02_A	et	f	\N
195073	nägimes	### nägimes	et	f	\N
195077	englise	?englise =englise  (SgG  >engline !12~10_A	et	f	\N
195078	englise	?englise =englise  (IndPrPs_  >englisema !27_V	et	f	\N
195079	englise	?englise =englise  (ImpPrSg2  >englisema !27_V	et	f	\N
195090	sünipäev	?sünipäev =sünipäev  (SgN  >sünipäev !22_S	et	f	\N
195091	rõmmus	?rõmmus =rõmmu  (SgIn  >rõmmu !16_S	et	f	\N
195092	rõmmus	?rõmmus =rõmmu  (IndIpfSg3  >rõmmuma !27_V	et	f	\N
195093	rõmmus	?rõmmus =rõmmus  (SgN  >rõmmus !11~09_S	et	f	\N
195097	lauame	?lauame =ame  (SgN  >lau+ame !16_S	et	f	\N
195098	lauame	?lauame =ame  (SgG  >lau+ame !16_S	et	f	\N
195114	närveeri	närveeri =närveeri  (IndPrPs_  >närveerima !28_V	et	f	\N
195115	närveeri	närveeri =närveeri  (ImpPrSg2  >närveerima !28_V	et	f	\N
195116	närveeri	närveeri =eri  (SgN  >närve+eri !17_S	et	f	\N
195117	närveeri	närveeri =eri  (SgG  >närve+eri !17_S	et	f	\N
195118	närveeri	närveeri =eri  (SgP  >närve+eri !17_S	et	f	\N
195124	siiras	siiras =siira  (SgIn  >siiras !07_A	et	f	\N
195125	siiras	siiras =siiras  (SgN  >siiras !07_A	et	f	\N
195151	buratino	?buratino =buratino  (SgN  >buratino !16_S	et	f	\N
195152	buratino	?buratino =buratino  (SgG  >buratino !16_S	et	f	\N
195159	agranomiks	?agranomiks =agranomi  (SgTr  >agranom !19_S	et	f	\N
195179	selliseit	?selliseit =selliseit  (SgN  >selliseit !22_S	et	f	\N
195180	divanil	?divanil =divani  (SgAd  >divan !02_S	et	f	\N
195193	pihuarvutiga	?pihuarvutiga =pihuarvuti  (SgKom  >pihuarvutt !22_S	et	f	\N
195003	esimisel	?esimisel =esimise  (SgAd  >esimine !12_S	et	f	\N
195007	rägisime	?rägisime =rägi  (IndIpfPl1  >rägima !27_V	et	f	\N
195009	18aastane	aastane =aastane  (SgN  >aastane !12~10_A	et	f	\N
195010	18aastane	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
195014	toort	?toort =toort  (SgN  >toort !22_S	et	f	\N
195020	elektrotehnika	elektrotehnika =tehnika  (SgN  >elektro+tehnika !01_S	et	f	\N
195021	elektrotehnika	elektrotehnika =tehnika  (SgG  >elektro+tehnika !01_S	et	f	\N
195022	päevaosakonnas	päevaosakonnas =konna  (SgIn  >päeva+osa+konn !22_S	et	f	\N
195023	päevaosakonnas	päevaosakonnas =osakonna  (SgIn  >päeva+osakond !22_S	et	f	\N
195026	tunnist	tunnist =tunni  (SgEl  >tund !22_S	et	f	\N
195027	tunnist	tunnist =tunnis  (SgP  >tunnine !10_A	et	f	\N
195028	tunnist	"tunnine %tunni  )NE_aA  <tund ;22_S	et	f	\N
195042	sõpranna	?sõpranna =sõpranna  (SgN  >sõpranna !16_S	et	f	\N
195043	sõpranna	?sõpranna =sõpranna  (SgG  >sõpranna !16_S	et	f	\N
195044	alaloo	alaloo =loo  (SgG  >ala+lugu !18_S	et	f	\N
195045	alaloo	alaloo =loo  (SgG  >ala+loog !22_S	et	f	\N
195047	alaloo	alaloo =loo  (SgG  >ala+lood !22_S	et	f	\N
195085	pruunised	?pruunised =pruunise  (PlN  >pruunis !09_S	et	f	\N
195086	pruunised	?pruunised =pruunise  (IndPrSg2  >pruunisema !27_V	et	f	\N
195087	pruunised	?pruunised =nise  (PlN  >pruu+nise !16_S	et	f	\N
195104	kinkitakse	?kinkitakse =kinkitakse  (SgG  >kinkitakne !02_A	et	f	\N
195105	kinkitakse	?kinkitakse =kinkitakse  (PlP  >kinkitaks !22_S	et	f	\N
195128	tahaksis	?tahaksis =tahaksi  (SgIn  >tahaksi !01_S	et	f	\N
195129	tahaksis	?tahaksis =tahaksi  (IndIpfSg3  >tahaksima !28_V	et	f	\N
195130	tahaksis	?tahaksis =tahaksis  (SgN  >tahaksis !11_S	et	f	\N
195146	arvatan	?arvatan =arvata  (IndPrSg1  >arvatama !27_V	et	f	\N
195147	arvatan	?arvatan =arvatan  (SgN  >arvatan !19_S	et	f	\N
195148	arvatan	?arvatan =atan  (SgN  >arv+atan !02_S	et	f	\N
195160	koristajaks	koristajaks =koristaja  (SgTr  >koristaja !01_S	et	f	\N
195161	koristajaks	"koristaja %korista  )JA_vS  <koristama ;27_V	et	f	\N
195164	kirikutel	kirikutel =kiriku  (PlAd  >kirik !02_S	et	f	\N
195165	kirikutel	kirikutel =ute  (SgAd  >kirik+utt !22_S	et	f	\N
195166	kirikutel	kirikutel =ute  (PlAd  >kirik+utt !22_S	et	f	\N
195185	puhkusereis	puhkusereis =reis  (SgN  >puhkuse+reis !14_S	et	f	\N
195186	puhkusereis	puhkusereis =reis  (SgN  >puhkuse+reis !22_S	et	f	\N
195187	lisakilomeetrid	lisakilomeetrid =meetri  (PlN  >lisa+kilo+meeter !02_S	et	f	\N
195188	lisakilomeetrid	lisakilomeetrid =kilomeetri  (PlN  >lisa+kilomeeter !02_S	et	f	\N
195199	kvalitetne	?kvalitetne =kvalitetne  (SgN  >kvalitetne !02_A	et	f	\N
195200	kvalitetne	?kvalitetne =kvalitetne  (PlP  >kvalitetn !22_S	et	f	\N
195215	kvalitet	### kvalitet	et	f	\N
195218	reklaamimise	reklaamimise =reklaamimise  (SgG  >reklaamimine !12_S	et	f	\N
195219	reklaamimise	"reklaamimine %reklaami  )MINE_vS  <reklaamima ;28_V	et	f	\N
195233	looduselt	looduselt =looduse  (SgAbl  >loodus !11~09_S	et	f	\N
195234	looduselt	"loodus %loo  )TUS1_aS  <looma ;38_V	et	f	\N
195235	looduselt	looduselt =looduselt  (ID  >looduselt !41_D	et	f	\N
195236	looduselt	"looduselt %loodu  )SELT_mD  <loodu ;01_S	et	f	\N
195246	individualselt	?individualselt =individualse  (SgAbl  >individualne !02_A	et	f	\N
195247	individualselt	?individualselt =individualse  (PlAbl  >individuals !22_S	et	f	\N
195248	individualselt	?individualselt =individualselt  (ID  >individualselt !41_D	et	f	\N
195281	koguse	koguse =koguse  (SgG  >kogus !02_A	et	f	\N
195282	koguse	koguse =koguse  (SgG  >kogus !09_S	et	f	\N
195314	kahekümneviiendal	?kahekümneviiendal =kahekümneviienda  (SgAd  >kahekümneviienda !16_S	et	f	\N
195315	kahekümneviiendal	?kahekümneviiendal =kahekümneviiendal  (SgN  >kahekümneviiendal !02_S	et	f	\N
195316	kahekümneviiendal	?kahekümneviiendal =viienda  (SgAd  >kahe+kümne+viienda !01_S	et	f	\N
195317	kahekümneviiendal	?kahekümneviiendal =kümneviienda  (SgAd  >kahe+kümneviienda !16_S	et	f	\N
195318	kahekümneviiendal	?kahekümneviiendal =kümneviiendal  (SgN  >kahe+kümneviiendal !02_S	et	f	\N
195333	radelina	?radelina =radeli  (SgEs  >radel !02_S	et	f	\N
195334	radelina	?radelina =radelina  (SgG  >radelin !19_S	et	f	\N
195335	radelina	?radelina =radelina  (SgP  >radelin !19_S	et	f	\N
195336	radelina	?radelina =radelina  (SgAdt  >radelin !19_S	et	f	\N
195337	eeldustele	eeldustele =eeldus  (PlAll  >eeldus !11~09_S	et	f	\N
195338	eeldustele	"eeldus %eelda  )US_vS  <eeldama ;27_V	et	f	\N
195339	eeldustele	eeldustele =duste  (PlAll  >eel+dust !22_S	et	f	\N
195346	õppepraktika	õppepraktika =praktika  (SgN  >õppe+praktika !01_S	et	f	\N
195347	õppepraktika	õppepraktika =praktika  (SgG  >õppe+praktika !01_S	et	f	\N
195358	silbet	?silbet =silbe  (SgP  >silbe !06_S	et	f	\N
195377	distansil	?distansil =distansi  (SgAd  >distansi !01_S	et	f	\N
195378	distansil	?distansil =distansi  (SgAd  >distans !02_S	et	f	\N
195379	distansil	?distansil =distansi  (SgAd  >distanss !22_S	et	f	\N
195384	möödumisel	möödumisel =möödumise  (SgAd  >möödumine !12_S	et	f	\N
195386	möödumisel	"möödumine %möödu  )MINE_vS  <mööduma ;27_V	et	f	\N
195412	tunnilõpus	tunnilõpus =lõpu  (SgIn  >tunni+lõpp !22_SA	et	f	\N
195413	tunnilõpus	tunnilõpus =lõpus  (SgN  >tunni+lõpus !09_S	et	f	\N
195019	x-linna	x-linna =linna  (SgAdt  >x-linn !22_S	et	f	\N
195036	kirjulaud	?kirjulaud =kirjulau  (PlN  >kirjulau !26_S	et	f	\N
195037	kirjulaud	?kirjulaud =kirjulau  (SgP  >kirjulau !26_S	et	f	\N
195038	kirjulaud	?kirjulaud =kirjulaud  (SgN  >kirjulaud !22_S	et	f	\N
195048	gruppitöö	?gruppitöö =gruppitöö  (SgN  >gruppitöö !26_S	et	f	\N
195049	gruppitöö	?gruppitöö =gruppitöö  (SgG  >gruppitöö !26_S	et	f	\N
195060	tunnipärast	tunnipärast =pära  (SgEl  >tunni+pära !17_S	et	f	\N
195061	tunnipärast	tunnipärast =päras  (SgP  >tunni+pärane !10_A	et	f	\N
195062	tunnipärast	"tunni+pärane %pära  )NE_aA  <tunni+pära ;17_S	et	f	\N
195082	külalislahke	külalislahke =lahke  (SgN  >külalis+lahke !01_A	et	f	\N
195083	külalislahke	külalislahke =lahke  (SgG  >külalis+lahke !01_A	et	f	\N
195084	külalislahke	külalislahke =lahke  (PlP  >külalis+lahk !22_S	et	f	\N
195088	rahulike	rahulike =rahulike  (PlG  >rahulik !25_A	et	f	\N
195089	rahulike	rahulike =ike  (SgN  >rahul+ike !06_S	et	f	\N
195102	jalutamine	jalutamine =jalutamine  (SgN  >jalutamine !12_S	et	f	\N
195103	jalutamine	"jalutamine %jaluta  )MINE_vS  <jalutama ;27_V	et	f	\N
195109	aktivne	?aktivne =aktivne  (SgN  >aktivne !02_A	et	f	\N
195110	aktivne	?aktivne =aktivne  (PlP  >aktivn !22_S	et	f	\N
195111	aktivne	?aktivne =aktivne  (IndPrPs_  >aktivnema !27_V	et	f	\N
195112	aktivne	?aktivne =aktivne  (ImpPrSg2  >aktivnema !27_V	et	f	\N
195131	eritit	?eritit =eriti  (SgP  >erit !02_S	et	f	\N
195132	õhtukeskoolis	?õhtukeskoolis =õhtukeskooli  (SgIn  >õhtukeskooli !16_S	et	f	\N
195133	õhtukeskoolis	?õhtukeskoolis =õhtukeskooli  (SgIn  >õhtukeskool !22_S	et	f	\N
195134	õhtukeskoolis	?õhtukeskoolis =õhtukeskooli  (IndIpfSg3  >õhtukeskoolima !28_V	et	f	\N
195135	õhtukeskoolis	?õhtukeskoolis =õhtukeskoolis  (SgN  >õhtukeskoolis !09_S	et	f	\N
195136	õhtukeskoolis	?õhtukeskoolis =ooli  (SgIn  >õhtu+kesk+ooli !16_S	et	f	\N
195137	õhtukeskoolis	?õhtukeskoolis =ooli  (SgIn  >õhtu+kesk+ool !22_S	et	f	\N
195138	õhtukeskoolis	?õhtukeskoolis =oolis  (SgN  >õhtu+kesk+oolis !09_S	et	f	\N
195139	õhtukeskoolis	?õhtukeskoolis =keskooli  (SgIn  >õhtu+keskooli !16_S	et	f	\N
195140	õhtukeskoolis	?õhtukeskoolis =keskooli  (SgIn  >õhtu+keskool !22_S	et	f	\N
195141	õhtukeskoolis	?õhtukeskoolis =keskoolis  (SgN  >õhtu+keskoolis !09_S	et	f	\N
195142	tehnoloogiliste	tehnoloogiliste =tehnoloogilis  (PlG  >tehnoloogiline !12_A	et	f	\N
195143	tehnoloogiliste	"tehnoloogiline %tehnoloogi  )LINE_aA  <tehnoloog ;22_S	et	f	\N
195144	tehnoloogiliste	tehnoloogiliste =loogilis  (PlG  >tehno+loogiline !12_A	et	f	\N
195145	tehnoloogiliste	"tehno+loogiline %loogi  )LINE_aA  <tehno+loog ;22_S	et	f	\N
195149	kakskümmendkaks	?kakskümmendkaks =kakskümmendka  (SgTr  >kakskümmendka !16_S	et	f	\N
195150	kakskümmendkaks	?kakskümmendkaks =kümmendka  (SgTr  >kaks+kümmendka !01_S	et	f	\N
195167	neljateistkümnendas	?neljateistkümnendas =neljateistkümnenda  (SgIn  >neljateistkümnenda !16_S	et	f	\N
195168	neljateistkümnendas	?neljateistkümnendas =neljateistkümnenda  (IndIpfSg3  >neljateistkümnendama !27_V	et	f	\N
195169	neljateistkümnendas	?neljateistkümnendas =kümnenda  (SgIn  >nelja+teist+kümnenda !01_S	et	f	\N
195170	neljateistkümnendas	?neljateistkümnendas =teistkümnenda  (SgIn  >nelja+teistkümnenda !16_S	et	f	\N
195181	puhkuses	puhkuses =puhkuse  (SgIn  >puhkus !11~09_S	et	f	\N
195182	puhkuses	puhkuses =use  (PlIn  >puhk+usk !22_S	et	f	\N
195192	navigatsioonsüüstem	?navigatsioonsüüstem =navigatsioonsüüstem  (SgN  >navigatsioonsüüstem !02_A	et	f	\N
195194	kvalitetsem	?kvalitetsem =kvalitetsem  (SgN  >kvalitetsem !02_A	et	f	\N
195213	rahandumine	?rahandumine =rahandumine  (SgN  >rahandumine !12_S	et	f	\N
195214	rahandumine	?rahandumine =rahandumine  (PlP  >rahandumin !19_S	et	f	\N
195216	suhtute	suhtute =suhtu  (IndPrPl2  >suhtuma !27_V	et	f	\N
195217	suhtute	suhtute =ute  (SgG  >suht+utt !22_S	et	f	\N
195230	lõinud	?lõinud =lõinu  (PlN  >lõinu !16_S	et	f	\N
195231	lõinud	?lõinud =lõinu  (IndPrSg2  >lõinuma !28_V	et	f	\N
195232	lõinud	?lõinud =lõinud  (ID  >lõinud !41_A	et	f	\N
195258	erinavades	?erinavades =erinava  (PlIn  >erinava !16_S	et	f	\N
195259	erinavades	?erinavades =nava  (PlIn  >eri+nava !17_S	et	f	\N
195272	küttimisele	küttimisele =küttimise  (SgAll  >küttimine !12_S	et	f	\N
195273	küttimisele	"küttimine %kütti  )MINE_vS  <küttima ;28_V	et	f	\N
195274	määrduliku	?määrduliku =määrduliku  (SgG  >määrdulik !25_A	et	f	\N
195275	määrduliku	?määrduliku =määrduliku  (IndPrPs_  >määrdulikuma !27_V	et	f	\N
195276	määrduliku	?määrduliku =määrduliku  (ImpPrSg2  >määrdulikuma !27_V	et	f	\N
195277	suusatavad	suusatavad =suusata  (IndPrPl3  >suusatama !27_V	et	f	\N
195278	suusatavad	suusatavad =suusatava  (PlN  >suusatav !02_A	et	f	\N
195279	suusatavad	"suusatav %suusata  )V_vA  <suusatama ;27_V	et	f	\N
195280	suusatavad	suusatavad =tava  (PlN  >suusa+tava !17_S	et	f	\N
195291	prooblemi	?prooblemi =prooblemi  (SgN  >prooblemi !01_S	et	f	\N
195292	prooblemi	?prooblemi =prooblemi  (SgG  >prooblemi !01_S	et	f	\N
195293	prooblemi	?prooblemi =prooblemi  (SgG  >prooblem !02_A	et	f	\N
195319	t-market	?t-market =marke  (SgP  >t-marke !06_S	et	f	\N
195325	vaevatasu	vaevatasu =tasu  (SgN  >vaeva+tasu !17_S	et	f	\N
195326	vaevatasu	vaevatasu =tasu  (SgG  >vaeva+tasu !17_S	et	f	\N
195327	vaevatasu	vaevatasu =tasu  (SgP  >vaeva+tasu !17_S	et	f	\N
195178	tuttavalt	tuttavalt =ava  (SgAbl  >tutt+ava !17_S	et	f	\N
195206	suhtumistest	suhtumistest =suhtumis  (PlEl  >suhtumine !12_S	et	f	\N
195208	suhtumistest	"suhtumine %suhtu  )MINE_vS  <suhtuma ;27_V	et	f	\N
195227	toodas	?toodas =tooda  (SgIn  >tooda !16_S	et	f	\N
195228	toodas	?toodas =tooda  (IndIpfSg3  >toodama !29_V	et	f	\N
195229	toodas	?toodas =toodas  (SgN  >toodas !07_S	et	f	\N
195249	massireklaami	massireklaami =reklaami  (SgG  >massi+reklaam !22_S	et	f	\N
195250	massireklaami	massireklaami =reklaami  (SgP  >massi+reklaam !22_S	et	f	\N
195251	massireklaami	massireklaami =reklaami  (SgAdt  >massi+reklaam !22_S	et	f	\N
195252	loomast	loomast =loo  (SupEl  >looma !38_V	et	f	\N
195253	loomast	loomast =looma  (SgEl  >loom !22_S	et	f	\N
195254	loomast	loomast =loomas  (SgP  >loomane !10_A	et	f	\N
195255	loomast	"loomane %looma  )NE_aA  <loom ;22_S	et	f	\N
195256	loomast	loomast =ast  (SgN  >loom+ast !22_S	et	f	\N
195257	loomast	loomast =mast  (SgN  >loo+mast !22_S	et	f	\N
195271	kütsuda	?kütsuda =kütsu  (Inf  >kütsuma !28_V	et	f	\N
195283	valgustuste	valgustuste =valgustus  (PlG  >valgustus !11_S	et	f	\N
195284	valgustuste	"valgustus %valgusta  )US_vS  <valgustama ;27_V	et	f	\N
195285	valgustuste	valgustuste =us  (PlG  >valgust+uks !14_S	et	f	\N
195286	valgustuste	valgustuste =tuste  (PlP  >valgus+tust !22_S	et	f	\N
195297	lingofonikabineti	?lingofonikabineti =lingofonikabineti  (SgG  >lingofonikabinett !22_S	et	f	\N
195298	lingofonikabineti	?lingofonikabineti =lingofonikabineti  (IndPrPs_  >lingofonikabinettima !28_V	et	f	\N
195299	lingofonikabineti	?lingofonikabineti =lingofonikabineti  (ImpPrSg2  >lingofonikabinettima !28_V	et	f	\N
195305	õppinguid	?õppinguid =õppingu  (PlP  >õppingu !01_S	et	f	\N
195306	õppinguid	?õppinguid =õppingu  (PlP  >õpping !02_S	et	f	\N
195307	õppinguid	?õppinguid =õppingui  (PlN  >õppingui !26_S	et	f	\N
195308	õppinguid	?õppinguid =õppingui  (SgP  >õppingui !26_S	et	f	\N
195320	süsimusta	süsimusta =musta  (SgG  >süsi+must !22_AS	et	f	\N
195321	süsimusta	süsimusta =musta  (SgP  >süsi+must !22_AS	et	f	\N
195322	süsimusta	süsimusta =musta  (SgAdt  >süsi+must !22_AS	et	f	\N
195323	kontaktnumer	?kontaktnumer =kontaktnumer  (SgN  >kontaktnumer !02_S	et	f	\N
195324	kontaktnumer	?kontaktnumer =numer  (SgN  >kontakt+numer !02_S	et	f	\N
195330	eek-i	eek-i =eek  (SgG  >eek !xx_Q	et	f	\N
195331	eek-i	eek-i =eek  (SgP  >eek !xx_Q	et	f	\N
195332	eek-i	eek-i =eek  (SgAdt  >eek !xx_Q	et	f	\N
195368	efektiivsult	?efektiivsult =efektiivsult  (ID  >efektiivsult !41_D	et	f	\N
195369	efektiivsult	?efektiivsult =ivsu  (SgAbl  >efekti+ivsu !16_S	et	f	\N
195382	ostupäevast	ostupäevast =ast  (SgN  >ostu+päev+ast !22_S	et	f	\N
195383	ostupäevast	ostupäevast =päeva  (SgEl  >ostu+päev !22_S	et	f	\N
195385	ostupäevast	ostupäevast =päevas  (SgP  >ostu+päevane !10_A	et	f	\N
195387	ostupäevast	"ostu+päevane %päeva  )NE_aA  <ostu+päev ;22_S	et	f	\N
195390	remontimiseks	remontimiseks =remontimise  (SgTr  >remontimine !12_S	et	f	\N
195391	remontimiseks	"remontimine %remonti  )MINE_vS  <remontima ;28_V	et	f	\N
195394	60-aastane	-aastane =aastane  (SgN  >-aastane !12~10_A	et	f	\N
195395	60-aastane	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
195405	puhtat	?puhtat =puhtat  (SgN  >puhtat !02_S	et	f	\N
195428	funktsion	?funktsion =funktsion  (SgN  >funktsion !19~02_S	et	f	\N
195440	sajlitada	?sajlitada =sajlita  (Inf  >sajlitama !27_V	et	f	\N
195452	valjä	### valjä	et	f	\N
195459	soovitani	?soovitani =soovitani  (SgG  >soovitan !19_S	et	f	\N
195460	soovitani	?soovitani =soovitani  (SgP  >soovitan !19_S	et	f	\N
195461	soovitani	?soovitani =soovitani  (SgAdt  >soovitan !19_S	et	f	\N
195462	soovitani	?soovitani =tani  (SgN  >soovi+tani !17_S	et	f	\N
195463	soovitani	?soovitani =tani  (SgG  >soovi+tani !17_S	et	f	\N
195464	soovitani	?soovitani =tani  (SgP  >soovi+tani !17_S	et	f	\N
195465	soovitani	?soovitani =ita  (SgTer  >soov+ita !16_S	et	f	\N
195466	soovitani	?soovitani =itani  (SgG  >soov+itan !02_S	et	f	\N
195467	soovitani	?soovitani =vita  (SgTer  >soo+vita !16_S	et	f	\N
195468	soovitani	?soovitani =vitani  (SgG  >soo+vitan !02_S	et	f	\N
195479	matkast	matkast =matka  (SgEl  >matk !22_S	et	f	\N
195480	matkast	matkast =matkas  (SgP  >matkane !12~10_A	et	f	\N
195482	matkast	"matkane %matka  )NE_aA  <matk ;22_S	et	f	\N
195493	triibulist	triibulist =triibulis  (SgP  >triibuline !12_A	et	f	\N
195494	triibulist	"triibuline %triibu  )LINE_aA  <triip ;22_S	et	f	\N
195520	museumid	?museumid =museumi  (PlN  >museumi !01_S	et	f	\N
195521	museumid	?museumid =museumi  (PlN  >museum !22_S	et	f	\N
195522	museumid	?museumid =museumi  (IndPrSg2  >museumima !28_V	et	f	\N
195524	sõitta	?sõitta =sõitta  (SgN  >sõitta !01_S	et	f	\N
195525	sõitta	?sõitta =sõitta  (SgG  >sõitta !01_S	et	f	\N
195526	sõitta	?sõitta =sõitta  (IndPrPs_  >sõittama !29_V	et	f	\N
195527	sõitta	?sõitta =sõitta  (ImpPrSg2  >sõittama !29_V	et	f	\N
195528	kiitesti	?kiitesti =kiitesti  (ID  >kiitesti !41_D	et	f	\N
195529	kiitesti	?kiitesti =kiitesti  (IndPrPs_  >kiitestima !28_V	et	f	\N
195530	kiitesti	?kiitesti =kiitesti  (ImpPrSg2  >kiitestima !28_V	et	f	\N
195547	asstorijal	?asstorijal =asstorija  (SgAd  >asstorija !01_S	et	f	\N
195195	tasulisest	tasulisest =tasulise  (SgEl  >tasuline !12_A	et	f	\N
195196	tasulisest	"tasuline %tasu  )LINE_aA  <tasu ;17_S	et	f	\N
195197	poolad	?poolad =poola  (IndPrSg2  >poolama !29_V	et	f	\N
195201	rahandumistest	?rahandumistest =rahandumis  (PlEl  >rahandumis !09_S	et	f	\N
195202	rahandumistest	?rahandumistest =rahandumis  (PlEl  >rahandumine !12_S	et	f	\N
195203	rahandumistest	?rahandumistest =rahandumiste  (PlEl  >rahandumist !22_S	et	f	\N
195204	rahandumistest	?rahandumistest =rahandumistes  (SgP  >rahandumistene !12_A	et	f	\N
195211	rahaldumine	?rahaldumine =rahaldumine  (SgN  >rahaldumine !12_S	et	f	\N
195212	rahaldumine	?rahaldumine =rahaldumine  (PlP  >rahaldumin !19_S	et	f	\N
195237	spetsiialisti	?spetsiialisti =spetsiialisti  (ID  >spetsiialisti !41_D	et	f	\N
195238	spetsiialisti	?spetsiialisti =spetsiialisti  (SgG  >spetsiialist !22_S	et	f	\N
195239	spetsiialisti	?spetsiialisti =spetsiialisti  (SgP  >spetsiialist !22_S	et	f	\N
195240	spetsiialisti	?spetsiialisti =spetsiialisti  (SgAdt  >spetsiialist !22_S	et	f	\N
195241	spetsiialisti	?spetsiialisti =spetsiialisti  (IndPrPs_  >spetsiialistima !28_V	et	f	\N
195242	spetsiialisti	?spetsiialisti =spetsiialisti  (ImpPrSg2  >spetsiialistima !28_V	et	f	\N
195243	spetsiialisti	?spetsiialisti =iialisti  (SgG  >spets+iialist !22_S	et	f	\N
195244	spetsiialisti	?spetsiialisti =iialisti  (SgP  >spets+iialist !22_S	et	f	\N
195245	spetsiialisti	?spetsiialisti =iialisti  (SgAdt  >spets+iialist !22_S	et	f	\N
195260	õnnuks	?õnnuks =õnnu  (SgTr  >õnnu !16_S	et	f	\N
195261	õnnuks	?õnnuks =õnnu  (KndPrPs  >õnnuma !27_V	et	f	\N
195262	huvitavamalt	huvitavamalt =huvitavama  (SgAbl  >huvitavam !02_A	et	f	\N
195263	huvitavamalt	"huvitavam %huvita  )VAM_cA  <huvitama ;27_V	et	f	\N
195264	huvitavamalt	"huvitavam %huvitava  )M_cA  <huvitav ;02_A	et	f	\N
195265	huvitavamalt	huvitavamalt =huvitavamalt  (ID  >huvitavamalt !41_D	et	f	\N
195266	huvitavamalt	"huvitavamalt %huvita  )VAMALT_mD  <huvitama ;27_V	et	f	\N
195267	huvitavamalt	"huvitavamalt %huvitava  )MALT_mD  <huvitav ;02_A	et	f	\N
195268	rahuldus	rahuldus =rahuldu  (IndIpfSg3  >rahulduma !27_V	et	f	\N
195269	rahuldus	rahuldus =rahuldus  (SgN  >rahuldus !11_S	et	f	\N
195270	rahuldus	"rahuldus %rahulda  )US_vS  <rahuldama ;27_V	et	f	\N
195287	elektrivalgust	elektrivalgust =us  (SgP  >elektri+valg+uks !14_S	et	f	\N
195288	elektrivalgust	elektrivalgust =valgu  (SgEl  >elektri+valk !22_S	et	f	\N
195289	elektrivalgust	elektrivalgust =valgus  (SgP  >elektri+valgus !11~09_S	et	f	\N
195290	elektrivalgust	"elektri+valgus %valge  )US_aS  <elektri+valge ;01_AS	et	f	\N
195294	lingofonikabinetiga	?lingofonikabinetiga =lingofonikabineti  (SgKom  >lingofonikabinett !22_S	et	f	\N
195296	talgastamise	?talgastamise =talgastamise  (SgG  >talgastamine !12_S	et	f	\N
195300	kuulanud	kuulanud =kuula  (PtsPtPs  >kuulama !29_V	et	f	\N
195301	kuulanud	kuulanud =kuulanu  (PlN  >kuulanu !01_S	et	f	\N
195302	kuulanud	"kuulanu %kuula  )NU_vS  <kuulama ;29_V	et	f	\N
195303	kuulanud	kuulanud =kuulanud  (ID  >kuulanud !41_A	et	f	\N
195304	kuulanud	"kuulanud %kuula  )NUD_vA  <kuulama ;29_V	et	f	\N
195309	sooviga	sooviga =soovi  (SgKom  >soov !22_S	et	f	\N
195310	sooviga	sooviga =iga  (SgN  >soov+iga !18_S	et	f	\N
195311	sooviga	sooviga =iga  (SgP  >soov+iga !18_S	et	f	\N
195312	sooviga	sooviga =viga  (SgN  >soo+viga !18_S	et	f	\N
195313	sooviga	sooviga =viga  (SgP  >soo+viga !18_S	et	f	\N
195348	lolgi	?lolgi =lolgi  (ID  >lolgi !41_D	et	f	\N
195349	lolgi	?lolgi =lolgi  (SgG  >lolk !22_S	et	f	\N
195350	lolgi	?lolgi =lolgi  (SgP  >lolg !22_S	et	f	\N
195351	lolgi	?lolgi =lolgi  (SgAdt  >lolg !22_S	et	f	\N
195352	lolgi	?lolgi =lolgi  (IndPrPs_  >lolkima !28_V	et	f	\N
195353	lolgi	?lolgi =lolgi  (ImpPrSg2  >lolkima !28_V	et	f	\N
195359	laos	laos =lao  (SgIn  >ladu !18_S	et	f	\N
195360	laos	laos =lao  (SgIn  >lagu !18_S	et	f	\N
195361	laos	laos =laos  (SgN  >laos !09_S	et	f	\N
195362	marketingi	?marketingi =marketingi  (SgG  >marketing !02_S	et	f	\N
195363	marketingi	?marketingi =marketingi  (SgG  >marketink !22_S	et	f	\N
195364	marketingi	?marketingi =marketingi  (IndPrPs_  >marketinkima !28_V	et	f	\N
195365	marketingi	?marketingi =marketingi  (ImpPrSg2  >marketinkima !28_V	et	f	\N
195366	marketingi	?marketingi =marketi  (IndPrSg1^  >markettima !28_V	et	f	\N
195367	marketingi	?marketingi =marketin  (SgN^  >marketin !19_S	et	f	\N
195373	keemilise	keemilise =keemilise  (SgG  >keemiline !12_A	et	f	\N
195374	keemilise	"keemiline %keemi  )LINE_aA  <keem ;22_S	et	f	\N
195401	tali	tali =tali  (SgN  >tali !17_S	et	f	\N
195402	tali	tali =tali  (SgN  >tali !24_S	et	f	\N
195403	tali	tali =tali  (SgG  >tali !17_S	et	f	\N
195404	tali	tali =tali  (SgP  >tali !17_S	et	f	\N
195422	sms-i	sms-i =sms  (SgG  >sms !xx_Q	et	f	\N
195423	sms-i	sms-i =sms  (SgP  >sms !xx_Q	et	f	\N
195424	sms-i	sms-i =sms  (SgAdt  >sms !xx_Q	et	f	\N
195430	paljukilomeetreid	paljukilomeetreid =meetre  (PlP  >palju+kilo+meeter !02_S	et	f	\N
195431	paljukilomeetreid	paljukilomeetreid =kilomeetre  (PlP  >palju+kilomeeter !02_S	et	f	\N
195441	infomenüüd	infomenüüd =menüü  (PlN  >info+menüü !26_S	et	f	\N
195442	infomenüüd	infomenüüd =menüü  (SgP  >info+menüü !26_S	et	f	\N
195451	mobiltelefon	?mobiltelefon =mobiltelefon  (SgN  >mobiltelefon !19_S	et	f	\N
195207	miditsini	?miditsini =miditsini  (SgG  >miditsin !19_S	et	f	\N
195209	miditsini	?miditsini =miditsini  (SgP  >miditsin !19_S	et	f	\N
195210	miditsini	?miditsini =miditsini  (SgAdt  >miditsin !19_S	et	f	\N
195220	televisionis	?televisionis =televisioni  (SgIn  >televisioni !16_S	et	f	\N
195221	televisionis	?televisionis =televisioni  (SgIn  >television !19_S	et	f	\N
195222	televisionis	?televisionis =televisioni  (IndIpfSg3  >televisionima !28_V	et	f	\N
195223	televisionis	?televisionis =televisionis  (SgN  >televisionis !09_S	et	f	\N
195224	televisionis	?televisionis =visioni  (SgIn  >tele+visioni !16_S	et	f	\N
195225	televisionis	?televisionis =visioni  (SgIn  >tele+vision !19_S	et	f	\N
195226	televisionis	?televisionis =visionis  (SgN  >tele+visionis !09_S	et	f	\N
195295	tehnimuse	?tehnimuse =tehnimuse  (SgG  >tehnimus !11_S	et	f	\N
195342	kolmeaastased	kolmeaastased =aastase  (PlN  >kolme+aastane !12~10_A	et	f	\N
195343	kolmeaastased	"kolme+aastane %aasta  )NE_aA  <kolme+aasta ;01_S	et	f	\N
195354	müügilaos	müügilaos =ao  (SgIn  >müügil+agu !18_S	et	f	\N
195355	müügilaos	müügilaos =lao  (SgIn  >müügi+ladu !18_S	et	f	\N
195356	müügilaos	müügilaos =lao  (SgIn  >müügi+lagu !18_S	et	f	\N
195357	müügilaos	müügilaos =laos  (SgN  >müügi+laos !09_S	et	f	\N
195380	soojendus	soojendus =soojendus  (SgN  >soojendus !11_S	et	f	\N
195381	soojendus	"soojendus %soojenda  )US_vS  <soojendama ;27_V	et	f	\N
195388	lahendamiseks	lahendamiseks =lahendamise  (SgTr  >lahendamine !12_S	et	f	\N
195389	lahendamiseks	"lahendamine %lahenda  )MINE_vS  <lahendama ;27_V	et	f	\N
195392	lemmikõpetaja	lemmikõpetaja =õpetaja  (SgN  >lemmik+õpetaja !01_S	et	f	\N
195393	lemmikõpetaja	lemmikõpetaja =õpetaja  (SgG  >lemmik+õpetaja !01_S	et	f	\N
195399	tunnivälisel	tunnivälisel =välise  (SgAd  >tunni+väline !10_A	et	f	\N
195400	tunnivälisel	"tunni+väline %väli  )NE_aA  <tunni+väli ;24_S	et	f	\N
195406	kingi	kingi =kingi  (SgG  >kink !22_S	et	f	\N
195407	kingi	kingi =kingi  (SgP  >king !22_S	et	f	\N
195408	kingi	kingi =kingi  (SgAdt  >king !22_S	et	f	\N
195409	kingi	kingi =kingi  (PlP  >king !22_S	et	f	\N
195410	kingi	kingi =kingi  (IndPrPs_  >kinkima !28_V	et	f	\N
195411	kingi	kingi =kingi  (ImpPrSg2  >kinkima !28_V	et	f	\N
195414	mtelefon	?mtelefon =mtelefon  (SgN  >mtelefon !19_S	et	f	\N
195421	mobil	?mobil =mobi  (SgAd  >mobi !17_S	et	f	\N
195453	lületatud	?lületatud =lületa  (PtsPtIps  >lületama !27_V	et	f	\N
195454	lületatud	?lületatud =lületatu  (PlN  >lületatu !01_S	et	f	\N
195455	lületatud	?lületatud =lületatu  (IndPrSg2  >lületatuma !27_V	et	f	\N
195456	lületatud	?lületatud =lületatud  (ID  >lületatud !41_A	et	f	\N
195457	sovitas	?sovitas =sovita  (IndIpfSg3  >sovitama !27_V	et	f	\N
195458	mahakukuda	?mahakukuda =mahakuku  (Inf  >mahakukuma !27_V	et	f	\N
195478	suhel	?suhel =suhel  (SgN  >suhel !02_S	et	f	\N
195510	vaatamisväärsusede	vaatamisväärsusede =ede  (SgN  >vaatamis+väärsus+ede !16_S	et	f	\N
195511	vaatamisväärsusede	vaatamisväärsusede =ede  (SgG  >vaatamis+väärsus+ede !16_S	et	f	\N
195531	petergof	### petergof	et	f	\N
195562	kaliningrad	?kaliningrad =kaliningra  (PlN  >kaliningra !16_S	et	f	\N
195565	paikepaisteline	?paikepaisteline =paikepaisteline  (SgN  >paikepaisteline !12_A	et	f	\N
195566	paikepaisteline	?paikepaisteline =paikepaisteline  (PlP  >paikepaistelin !19_S	et	f	\N
195567	paikepaisteline	?paikepaisteline =kepaisteline  (SgN  >pai+kepaisteline !12_A	et	f	\N
195568	paikepaisteline	?paikepaisteline =kepaisteline  (PlP  >pai+kepaistelin !19_S	et	f	\N
195572	unustamatud	unustamatud =unustamatu  (PlN  >unustamatu !01_A	et	f	\N
195573	unustamatud	"unustamatu %unusta  )MATU_vA  <unustama ;27_V	et	f	\N
195588	teatridesse	?teatridesse =teatrides  (SgAdt  >teatridene !12_A	et	f	\N
195589	teatridesse	?teatridesse =teatridesse  (SgG  >teatridesne !02_A	et	f	\N
195590	teatridesse	?teatridesse =teatridesse  (PlP  >teatridess !22_S	et	f	\N
195604	isaaki	?isaaki =isaaki  (SgN  >isaaki !16_S	et	f	\N
195605	isaaki	?isaaki =isaaki  (SgG  >isaaki !16_S	et	f	\N
195606	isaaki	?isaaki =isaaki  (SgP  >isaak !22_S	et	f	\N
195607	isaaki	?isaaki =isaaki  (SgAdt  >isaak !22_S	et	f	\N
195609	isaaki	?isaaki =aki  (SgN  >isa+aki !16_S	et	f	\N
195611	isaaki	?isaaki =aki  (SgG  >isa+aki !16_S	et	f	\N
195613	isaaki	?isaaki =aki  (SgG  >isa+akk !22_S	et	f	\N
195629	petergofis	?petergofis =petergofi  (SgIn  >petergoff !22_S	et	f	\N
195630	petergofis	?petergofis =petergofis  (SgN  >petergofis !09_S	et	f	\N
195633	ekatiriina	?ekatiriina =ekatirii  (SgEs  >ekatirii !26_S	et	f	\N
195634	ekatiriina	?ekatiriina =ekatiriina  (SgN  >ekatiriina !16_S	et	f	\N
195635	ekatiriina	?ekatiriina =ekatiriina  (SgG  >ekatiriina !16_S	et	f	\N
195650	õppetooli	õppetooli =tooli  (SgG  >õppe+tool !22_S	et	f	\N
195651	õppetooli	õppetooli =tooli  (SgP  >õppe+tool !22_S	et	f	\N
195652	õppetooli	õppetooli =tooli  (SgAdt  >õppe+tool !22_S	et	f	\N
195662	meeldivate	meeldivate =meeldiva  (PlG  >meeldiv !02_A	et	f	\N
195663	meeldivate	"meeldiv %meeldi  )V_vA  <meeldima ;27_V	et	f	\N
195676	kaubakeskuses	kaubakeskuses =use  (PlIn  >kauba+kesk+usk !22_S	et	f	\N
195677	kaubakeskuses	kaubakeskuses =keskuse  (SgIn  >kauba+keskus !11~09_S	et	f	\N
195685	järjekordi	järjekordi =kordi  (SgP  >järje+kord !22_S	et	f	\N
195328	toimetamise	toimetamise =toimetamise  (SgG  >toimetamine !12_S	et	f	\N
195329	toimetamise	"toimetamine %toimeta  )MINE_vS  <toimetama ;27_V	et	f	\N
195340	keemiline	keemiline =keemiline  (SgN  >keemiline !12_A	et	f	\N
195341	keemiline	"keemiline %keemi  )LINE_aA  <keem ;22_S	et	f	\N
195344	laomajandaja	laomajandaja =majandaja  (SgN  >lao+majandaja !01_S	et	f	\N
195345	laomajandaja	laomajandaja =majandaja  (SgG  >lao+majandaja !01_S	et	f	\N
195370	laotööd	laotööd =töö  (PlN  >lao+töö !26_S	et	f	\N
195371	laotööd	laotööd =töö  (SgP  >lao+töö !26_S	et	f	\N
195372	reaktiivided	?reaktiivided =ide  (PlN  >reaktiiv+ide !16_S	et	f	\N
195375	keemilises	keemilises =keemilise  (SgIn  >keemiline !12_A	et	f	\N
195376	keemilises	"keemiline %keemi  )LINE_aA  <keem ;22_S	et	f	\N
195396	maitsekalt	maitsekalt =maitseka  (SgAbl  >maitsekas !02_A	et	f	\N
195397	maitsekalt	maitsekalt =maitsekalt  (ID  >maitsekalt !41_D	et	f	\N
195398	maitsekalt	"maitsekalt %maitseka  )LT_mD  <maitsekas ;02_A	et	f	\N
195415	paela	paela =paela  (SgG  >pael !23?22_S	et	f	\N
195416	paela	paela =paela  (SgP  >pael !23?22_S	et	f	\N
195417	paela	paela =paela  (SgAdt  >pael !23?22_S	et	f	\N
195418	paela	paela =paela  (IndPrPs_  >paelama !29_V	et	f	\N
195419	paela	paela =paela  (ImpPrSg2  >paelama !29_V	et	f	\N
195429	kardit	?kardit =kardit  (SgN  >kardit !02_S	et	f	\N
195432	kaardit	?kaardit =kaardit  (SgN  >kaardit !02_S	et	f	\N
195434	viivitamatult	viivitamatult =viivitamatu  (SgAbl  >viivitamatu !01_A	et	f	\N
195436	viivitamatult	"viivitamatu %viivita  )MATU_vA  <viivitama ;27_V	et	f	\N
195437	viivitamatult	viivitamatult =viivitamatult  (ID  >viivitamatult !41_D	et	f	\N
195438	viivitamatult	"viivitamatult %viivita  )MATULT_mD  <viivitama ;27_V	et	f	\N
195439	viivitamatult	"viivitamatult %viivitamatu  )LT_mD  <viivitamatu ;01_A	et	f	\N
195443	kendi	?kendi =kendi  (SgN  >kendi !16_S	et	f	\N
195444	kendi	?kendi =kendi  (SgG  >kendi !16_S	et	f	\N
195445	kendi	?kendi =kendi  (SgG  >kent !22_S	et	f	\N
195446	kendi	?kendi =kendi  (SgP  >kend !22_S	et	f	\N
195447	kendi	?kendi =kendi  (SgAdt  >kend !22_S	et	f	\N
195448	kendi	?kendi =kendi  (IndPrPs_  >kentima !28_V	et	f	\N
195449	kendi	?kendi =kendi  (ImpPrSg2  >kentima !28_V	et	f	\N
195469	minuma	?minuma =minu  (Sup  >minuma !27_V	et	f	\N
195470	minuma	?minuma =minuma  (SgG  >minum !02_A	et	f	\N
195475	swartsnegerist	?swartsnegerist =swartsnegeri  (SgEl  >swartsneger !19_S	et	f	\N
195476	swartsnegerist	?swartsnegerist =swartsnegeris  (SgP  >swartsnegeris !09_S	et	f	\N
195477	swartsnegerist	?swartsnegerist =swartsnegerist  (SgN  >swartsnegerist !22_S	et	f	\N
195485	sepast	sepast =sepa  (SgEl  >sepp !22_S	et	f	\N
195486	sepast	sepast =sepas  (SgP  >sepane !10_A	et	f	\N
195487	sepast	"sepane %sepa  )NE_aA  <sepp ;22_S	et	f	\N
195498	kühvlist	kühvlist =kühvli  (SgEl  >kühvel !02_S	et	f	\N
195499	kühvlist	kühvlist =kühvlis  (SgP  >kühvline !12~10_A	et	f	\N
195500	kühvlist	"kühvline %kühvli  )NE_aA  <kühvel ;02_S	et	f	\N
195508	planime	?planime =plani  (IndPrPl1  >planima !27_V	et	f	\N
195512	oobime	?oobime =oobi  (IndPrPl1  >oobima !27_V	et	f	\N
195513	oobime	?oobime =oobi  (IndPrPl1  >oopima !28_V	et	f	\N
195514	tahksi	?tahksi =tahksi  (ID  >tahksi !41_D	et	f	\N
195515	tahksi	?tahksi =tahksi  (SgG  >tahks !22_S	et	f	\N
195516	tahksi	?tahksi =tahksi  (SgP  >tahks !22_S	et	f	\N
195517	tahksi	?tahksi =tahksi  (SgAdt  >tahks !22_S	et	f	\N
195518	tahksi	?tahksi =tahksi  (IndPrPs_  >tahksima !28_V	et	f	\N
195519	tahksi	?tahksi =tahksi  (ImpPrSg2  >tahksima !28_V	et	f	\N
195532	kurjutanud	?kurjutanud =kurjuta  (PtsPtPs  >kurjutama !27_V	et	f	\N
195533	kurjutanud	?kurjutanud =kurjutanu  (PlN  >kurjutanu !01_S	et	f	\N
195534	kurjutanud	?kurjutanud =kurjutanu  (IndPrSg2  >kurjutanuma !27_V	et	f	\N
195535	kurjutanud	?kurjutanud =kurjutanud  (ID  >kurjutanud !41_A	et	f	\N
195538	asstorija	?asstorija =asstorija  (SgN  >asstorija !01_S	et	f	\N
195539	asstorija	?asstorija =asstorija  (SgG  >asstorija !01_S	et	f	\N
195540	asstorija	?asstorija =asstorija  (SgG  >asstorijas !02_A	et	f	\N
195541	lemmikusse	lemmikusse =lemmiku  (SgIll  >lemmik !02_S	et	f	\N
195542	lemmikusse	lemmikusse =usse  (PlP  >lemmik+uss !22_S	et	f	\N
195555	tervitused	tervitused =tervituse  (PlN  >tervitus !11_S	et	f	\N
195556	tervitused	"tervitus %tervita  )US_vS  <tervitama ;27_V	et	f	\N
195557	juutustan	?juutustan =juutusta  (IndPrSg1  >juutustama !27_V	et	f	\N
195558	juutustan	?juutustan =juutustan  (SgN  >juutustan !19_S	et	f	\N
195559	kaliningradis	?kaliningradis =kaliningradis  (SgN  >kaliningradis !09_S	et	f	\N
195563	mael	?mael =mae  (SgAd  >mae !26_S	et	f	\N
195564	mael	?mael =mael  (SgN  >mael !22_S	et	f	\N
195579	soidsime	?soidsime =soidsi  (IndPrPl1  >soidsima !28_V	et	f	\N
195581	pillet	?pillet =pille  (SgP  >pille !06_S	et	f	\N
195596	abukaasal	?abukaasal =abukaasa  (SgAd  >abukaasa !16_S	et	f	\N
195597	abukaasal	?abukaasal =abukaasal  (SgN  >abukaasal !02_S	et	f	\N
195598	nädalt	?nädalt =näda  (SgAbl  >näda !17_S	et	f	\N
195599	nädalt	?nädalt =nädalt  (ID  >nädalt !41_D	et	f	\N
195600	viisaga	viisaga =viisa  (SgKom  >viisas !07_A	et	f	\N
195420	mobil	?mobil =mobi  (SgAd  >mobi !17_S	et	f	\N
195425	navigatsiooni	navigatsiooni =navigatsiooni  (SgG  >navigatsioon !22_S	et	f	\N
195426	navigatsiooni	navigatsiooni =navigatsiooni  (SgP  >navigatsioon !22_S	et	f	\N
195427	navigatsiooni	navigatsiooni =navigatsiooni  (SgAdt  >navigatsioon !22_S	et	f	\N
195433	reisijatele	reisijatele =reisija  (PlAll  >reisija !01_S	et	f	\N
195435	reisijatele	"reisija %reisi  )JA_vS  <reisima ;28_V	et	f	\N
195450	rolitaga	### rolitaga	et	f	\N
195472	spetsialiistiks	?spetsialiistiks =spetsialiisti  (SgTr  >spetsialiist !22_S	et	f	\N
195473	spetsialiistiks	?spetsialiistiks =spetsialiisti  (KndPrPs  >spetsialiistima !28_V	et	f	\N
195474	stalonest	?stalonest =stalones  (SgP  >stalonene !12_A	et	f	\N
195481	amerikale	?amerikale =amerika  (SgAll  >amerika !01_S	et	f	\N
195483	amerikale	?amerikale =amerika  (SgAll  >amerikas !02_A	et	f	\N
195484	amerikale	?amerikale =amerikale  (PlP  >amerikal !19_S	et	f	\N
195488	huvitavast	huvitavast =huvitava  (SgEl  >huvitav !02_A	et	f	\N
195489	huvitavast	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
195490	huvitavast	huvitavast =tava  (SgEl  >huvi+tava !17_S	et	f	\N
195491	huvitavast	huvitavast =tavas  (SgP  >huvi+tavane !10_A	et	f	\N
195492	huvitavast	"huvi+tavane %tava  )NE_aA  <huvi+tava ;17_S	et	f	\N
195505	aime	aime =aime  (SgN  >aime !06_S	et	f	\N
195506	aime	aime =aime  (SgG  >aime !06_S	et	f	\N
195507	aime	aime =aime  (PlP  >aim !22_S	et	f	\N
195543	kunst-kamerasse	?kunst-kamerasse =kamera  (SgIll  >kunst-kamera !01_S	et	f	\N
195544	kunst-kamerasse	?kunst-kamerasse =kameras  (SgAdt  >kunst-kamerane !12_A	et	f	\N
195545	kunst-kamerasse	?kunst-kamerasse =kamerasse  (SgG  >kunst-kamerasne !02_A	et	f	\N
195546	kunst-kamerasse	?kunst-kamerasse =kamerasse  (PlP  >kunst-kamerass !22_S	et	f	\N
195550	kolmekohaline	kolmekohaline =ine  (SgN  >kolme+kohal+ine !16_S	et	f	\N
195551	kolmekohaline	kolmekohaline =ine  (SgG  >kolme+kohal+ine !16_S	et	f	\N
195552	kolmekohaline	kolmekohaline =kohaline  (SgN  >kolme+kohaline !12_A	et	f	\N
195553	kolmekohaline	"kolme+kohaline %koha  )LINE_aA  <kolme+koha ;17_S	et	f	\N
195554	kolmekohaline	"kolme+kohaline %koha  )LINE_aA  <kolme+koht ;22_S	et	f	\N
195580	tutrega	?tutrega =tutre  (SgKom  >tudre !06_S	et	f	\N
195582	peterburgisse	?peterburgisse =peterburgi  (SgIll  >peterburk !22_S	et	f	\N
195583	peterburgisse	?peterburgisse =peterburgisse  (SgG  >peterburgisne !02_A	et	f	\N
195584	peterburgisse	?peterburgisse =peterburgisse  (PlP  >peterburgiss !22_S	et	f	\N
195591	milla	?milla =milla  (SgN  >milla !16_S	et	f	\N
195592	milla	?milla =milla  (SgG  >milla !16_S	et	f	\N
195593	milla	?milla =milla  (IndPrPs_  >millama !29_V	et	f	\N
195594	milla	?milla =milla  (ImpPrSg2  >millama !29_V	et	f	\N
195624	marsovipõld	?marsovipõld =marsovipõld  (SgN  >marsovipõld !22_S	et	f	\N
195636	peterburg	?peterburg =peterburg  (SgN  >peterburg !22_S	et	f	\N
195653	kassetti	kassetti =kassetti  (SgP  >kassett !22_S	et	f	\N
195654	kassetti	kassetti =kassetti  (SgAdt  >kassett !22_S	et	f	\N
195655	kassetti	kassetti =setti  (SgP  >kas+sett !22_S	et	f	\N
195656	kassetti	kassetti =setti  (SgAdt  >kas+sett !22_S	et	f	\N
195712	öömatkamas	?öömatkamas =öömatkama  (SgIn  >öömatkam !02_A	et	f	\N
195713	öömatkamas	?öömatkamas =matkama  (SgIn  >öö+matkam !02_A	et	f	\N
195715	algal	?algal =alga  (SgAd  >alga !16_S	et	f	\N
195716	algal	?algal =algal  (SgN  >algal !02_S	et	f	\N
195732	tarbitada	?tarbitada =tarbita  (Inf  >tarbitama !27_V	et	f	\N
195742	küsimustel	küsimustel =küsimus  (PlAd  >küsimus !11_S	et	f	\N
195743	küsimustel	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
195744	küsimustel	küsimustel =muste  (PlAd  >küsi+must !22_AS	et	f	\N
195751	glenfild	?glenfild =glenfild  (SgN  >glenfild !02_S	et	f	\N
195760	tarbijakaitsemaetisse	?tarbijakaitsemaetisse =tarbijakaitsemaeti  (SgIll  >tarbijakaitsemaeti !16_S	et	f	\N
195761	tarbijakaitsemaetisse	?tarbijakaitsemaetisse =tarbijakaitsemaetisse  (SgG  >tarbijakaitsemaetisne !02_A	et	f	\N
195762	tarbijakaitsemaetisse	?tarbijakaitsemaetisse =tarbijakaitsemaetisse  (PlP  >tarbijakaitsemaetiss !22_S	et	f	\N
195763	tarbijakaitsemaetisse	?tarbijakaitsemaetisse =maetis  (SgAdt  >tarbija+kaitse+maetis !11_S	et	f	\N
195764	tarbijakaitsemaetisse	?tarbijakaitsemaetisse =maetisse  (SgG  >tarbija+kaitse+maetisne !02_A	et	f	\N
195765	tarbijakaitsemaetisse	?tarbijakaitsemaetisse =maetisse  (PlP  >tarbija+kaitse+maetiss !22_S	et	f	\N
195766	tarbijakaitsemaetisse	?tarbijakaitsemaetisse =tsemaetis  (SgAdt  >tarbija+kai+tsemaetis !11_S	et	f	\N
195768	tarbijakaitsemaetisse	?tarbijakaitsemaetisse =tsemaetisse  (SgG  >tarbija+kai+tsemaetisne !02_A	et	f	\N
195770	tarbijakaitsemaetisse	?tarbijakaitsemaetisse =tsemaetisse  (PlP  >tarbija+kai+tsemaetiss !22_S	et	f	\N
195772	tarbijakaitsemaetisse	?tarbijakaitsemaetisse =kaitsemaeti  (SgIll  >tarbija+kaitsemaeti !16_S	et	f	\N
195774	tarbijakaitsemaetisse	?tarbijakaitsemaetisse =kaitsemaetisse  (SgG  >tarbija+kaitsemaetisne !02_A	et	f	\N
195776	tarbijakaitsemaetisse	?tarbijakaitsemaetisse =kaitsemaetisse  (PlP  >tarbija+kaitsemaetiss !22_S	et	f	\N
195779	goods	?goods =goods  (SgN  >goods !22_S	et	f	\N
195796	reageeri	reageeri =reageeri  (IndPrPs_  >reageerima !28_V	et	f	\N
195797	reageeri	reageeri =reageeri  (ImpPrSg2  >reageerima !28_V	et	f	\N
195849	lõhnaõli	lõhnaõli =õli  (SgN  >lõhna+õli !17_S	et	f	\N
195850	lõhnaõli	lõhnaõli =õli  (SgG  >lõhna+õli !17_S	et	f	\N
195471	tervida	?tervida =tervi  (Inf  >tervima !28_V	et	f	\N
195495	pallist	pallist =palli  (SgEl  >pall !22_S	et	f	\N
195496	pallist	pallist =pallis  (SgP  >palline !10_A	et	f	\N
195497	pallist	"palline %palli  )NE_aA  <pall ;22_S	et	f	\N
195501	hummerist	?hummerist =hummeri  (SgEl  >hummeri !01_S	et	f	\N
195502	hummerist	?hummerist =hummeri  (SgEl  >hummer !02_S	et	f	\N
195503	hummerist	?hummerist =hummeris  (SgP  >hummeris !11_S	et	f	\N
195504	hummerist	?hummerist =hummerist  (SgN  >hummerist !22_S	et	f	\N
195509	lagodas	### lagodas	et	f	\N
195523	reiss	?reiss =reiss  (SgN  >reiss !22_S	et	f	\N
195536	kurjutan	?kurjutan =kurjuta  (IndPrSg1  >kurjutama !27_V	et	f	\N
195537	kurjutan	?kurjutan =kurjutan  (SgN  >kurjutan !19_S	et	f	\N
195560	külalis	?külalis =külali  (SgIn  >külal !02_S	et	f	\N
195561	külalis	?külalis =külalis  (SgN  >külalis !11_S	et	f	\N
195571	solarium	?solarium =solarium  (SgN  >solarium !19_S	et	f	\N
195585	erinivad	?erinivad =eriniva  (PlN  >eriniv !02_A	et	f	\N
195586	erinivad	?erinivad =eriniva  (PlN  >eriniva !16_S	et	f	\N
195587	erinivad	?erinivad =niva  (PlN  >eri+niva !17_S	et	f	\N
195595	regina	?regina =regina  (SgG  >regin !02_S	et	f	\N
195602	loodaks	loodaks =loo  (KndPrIps  >looma !38_V	et	f	\N
195603	loodaks	loodaks =looda  (KndPrPs  >lootma !34_V	et	f	\N
195639	realharu	?realharu =realharu  (SgN  >realharu !01_S	et	f	\N
195640	realharu	?realharu =realharu  (SgG  >realharu !01_S	et	f	\N
195641	realharu	?realharu =realharu  (IndPrPs_  >realharuma !27_V	et	f	\N
195642	realharu	?realharu =realharu  (ImpPrSg2  >realharuma !27_V	et	f	\N
195646	vastlapäevast	vastlapäevast =ast  (SgN  >vastla+päev+ast !22_S	et	f	\N
195647	vastlapäevast	vastlapäevast =päeva  (SgEl  >vastla+päev !22_S	et	f	\N
195648	vastlapäevast	vastlapäevast =päevas  (SgP  >vastla+päevane !10_A	et	f	\N
195649	vastlapäevast	"vastla+päevane %päeva  )NE_aA  <vastla+päev ;22_S	et	f	\N
195659	kaminatule	kaminatule =kaminatu  (SgAll  >kaminatu !01_A	et	f	\N
195660	kaminatule	"kaminatu %kamina  )TU2_kA  <kamin ;02_S	et	f	\N
195661	kaminatule	kaminatule =tule  (SgG  >kamina+tuli !20_S	et	f	\N
195667	avastusi	avastusi =avastusi  (PlP  >avastus !11_S	et	f	\N
195668	avastusi	"avastus %avasta  )US_vS  <avastama ;27_V	et	f	\N
195674	hias	?hias =hia  (SgIn  >hia !26_S	et	f	\N
195675	hias	?hias =hias  (SgN  >hias !22_S	et	f	\N
195692	tirjutada	?tirjutada =tirjuta  (Inf  >tirjutama !27_V	et	f	\N
195707	eneergiat	?eneergiat =eneergia  (SgP  >eneergia !01_S	et	f	\N
195708	eneergiat	?eneergiat =eneergiat  (SgN  >eneergiat !22_S	et	f	\N
195714	mängisimi	?mängisimi =mängisimi  (SgG  >mängisim !02_A	et	f	\N
195733	ekstravaganseid	?ekstravaganseid =ekstravaganse  (PlP  >ekstravaganne !02_A	et	f	\N
195734	ekstravaganseid	?ekstravaganseid =ekstravagansei  (PlN  >ekstravagansei !26_S	et	f	\N
195735	ekstravaganseid	?ekstravaganseid =ekstravagansei  (SgP  >ekstravagansei !26_S	et	f	\N
195736	ekstravaganseid	?ekstravaganseid =vaganse  (PlP  >ekstra+vaganne !02_A	et	f	\N
195737	ekstravaganseid	?ekstravaganseid =vagansei  (PlN  >ekstra+vagansei !26_S	et	f	\N
195738	ekstravaganseid	?ekstravaganseid =vagansei  (SgP  >ekstra+vagansei !26_S	et	f	\N
195739	ekstravaganseid	?ekstravaganseid =travaganse  (PlP  >eks+travaganne !02_A	et	f	\N
195740	ekstravaganseid	?ekstravaganseid =travagansei  (PlN  >eks+travagansei !26_S	et	f	\N
195741	ekstravaganseid	?ekstravaganseid =travagansei  (SgP  >eks+travagansei !26_S	et	f	\N
195778	damaged	### damaged	et	f	\N
195782	palgapäeva	palgapäeva =päeva  (SgG  >palga+päev !22_S	et	f	\N
195783	palgapäeva	palgapäeva =päeva  (SgP  >palga+päev !22_S	et	f	\N
195784	palgapäeva	palgapäeva =päeva  (SgAdt  >palga+päev !22_S	et	f	\N
195791	keeldusid	keeldusid =keeldu  (PlP  >keeld !22_S	et	f	\N
195792	keeldusid	keeldusid =keeldu  (IndIpfSg2  >keelduma !27_V	et	f	\N
195793	keeldusid	keeldusid =keeldu  (IndIpfPl3  >keelduma !27_V	et	f	\N
195806	tugevatest	tugevatest =tugeva  (PlEl  >tugev !02_A	et	f	\N
195807	tugevatest	"tugev %tuge  )V_vA  <tugema ;27_V	et	f	\N
195808	tugevatest	tugevatest =test  (SgN  >tugeva+test !22_S	et	f	\N
195831	asutuse	asutuse =asutuse  (SgG  >asutus !11_S	et	f	\N
195832	asutuse	"asutus %asuta  )US_vS  <asutama ;27_V	et	f	\N
195833	asutuse	"asutus %asu  )TUS1_aS  <asuma ;27_V	et	f	\N
195834	asutuse	"asutus %asu  )TUS2_aS  <asu ;17_S	et	f	\N
195845	pikkem	?pikkem =pikkem  (SgN  >pikkem !02_A	et	f	\N
195873	püüdle	püüdle =püüdle  (IndPrPs_  >püüdlema !30_V	et	f	\N
195874	püüdle	püüdle =püüdle  (ImpPrSg2  >püüdlema !30_V	et	f	\N
195898	tuudengite	?tuudengite =tuudengi  (PlG  >tuudeng !02_S	et	f	\N
195899	tuudengite	?tuudengite =tuudengi  (IndPrPl2  >tuudenkima !28_V	et	f	\N
195906	laska	?laska =laska  (SgN  >laska !16_S	et	f	\N
195907	laska	?laska =laska  (SgG  >laska !16_S	et	f	\N
195908	laska	?laska =laska  (IndPrPs_  >laskama !29_V	et	f	\N
195909	laska	?laska =laska  (ImpPrSg2  >laskama !29_V	et	f	\N
195929	suvalistele	suvalistele =suvalis  (PlAll  >suvaline !12_A	et	f	\N
195930	suvalistele	"suvaline %suva  )LINE_aA  <suva ;17_S	et	f	\N
195964	jetsettide	?jetsettide =jetsetti  (PlG  >jetsett !22_S	et	f	\N
195970	miljoonid	?miljoonid =miljooni  (PlN  >miljooni !16_S	et	f	\N
195548	asstorijal	?asstorijal =asstorija  (SgAd  >asstorijas !02_A	et	f	\N
195549	asstorijal	?asstorijal =asstorijal  (SgN  >asstorijal !19_S	et	f	\N
195569	vaatamiseväärsused	?vaatamiseväärsused =vaatamiseväärsuse  (PlN  >vaatamiseväärsus !11~09_S	et	f	\N
195570	vaatamiseväärsused	?vaatamiseväärsused =eväärsuse  (PlN  >vaatamis+eväärsus !11~09_S	et	f	\N
195574	pangi	pangi =pangi  (SgG  >pank !22_S	et	f	\N
195575	pangi	pangi =pangi  (SgP  >pang !22_S	et	f	\N
195576	pangi	pangi =pangi  (SgAdt  >pang !22_S	et	f	\N
195577	pangi	pangi =pangi  (PlP  >pang !22_S	et	f	\N
195578	pangi	pangi =pan  (SgN^  >pan !19_S	et	f	\N
195608	admiralihoone	?admiralihoone =admiralihoone  (SgN  >admiralihoone !16_S	et	f	\N
195610	admiralihoone	?admiralihoone =admiralihoone  (SgG  >admiralihoone !16_S	et	f	\N
195612	admiralihoone	?admiralihoone =admiralihoone  (PlP  >admiralihoon !22_S	et	f	\N
195631	petergofis	?petergofis =petergofi  (SgIn  >petergoff !22_S	et	f	\N
195632	petergofis	?petergofis =petergofis  (SgN  >petergofis !09_S	et	f	\N
195637	sõigad	?sõigad =sõiga  (PlN  >sõiga !16_S	et	f	\N
195638	sõigad	?sõigad =sõiga  (IndPrSg2  >sõigama !29_V	et	f	\N
195643	vähemusrahvastele	vähemusrahvastele =rahvas  (PlAll  >vähemus+rahvas !07_S	et	f	\N
195644	vähemusrahvastele	vähemusrahvastele =rahvas  (PlAll  >vähemus+rahvane !10_A	et	f	\N
195645	vähemusrahvastele	"vähemus+rahvane %rahva  )NE_aA  <vähemus+rahvas ;07_S	et	f	\N
195657	maitsetest	maitsetest =maitse  (PlEl  >maitse !06_S	et	f	\N
195658	maitsetest	maitsetest =test  (SgN  >maitse+test !22_S	et	f	\N
195664	maalisi	maalisi =maalisi  (PlP  >maaline !12_A	et	f	\N
195665	maalisi	"maaline %maa  )LINE_aA  <maa ;26_S	et	f	\N
195666	maalisi	"maaline %maali  )NE_aA  <maal ;22_S	et	f	\N
195669	imelisem	imelisem =imelisem  (SgN  >imelisem !02_A	et	f	\N
195670	imelisem	"imelisem %ime  )LISEM_cA  <ime ;16_S	et	f	\N
195671	imelisem	"imelisem %imelise  )M_cA  <imeline ;12_A	et	f	\N
195672	projekteerimises	projekteerimises =projekteerimise  (SgIn  >projekteerimine !12_S	et	f	\N
195673	projekteerimises	"projekteerimine %projekteeri  )MINE_vS  <projekteerima ;28_V	et	f	\N
195678	toimuksid	toimuksid =toimu  (KndPrSg2  >toimuma !27_V	et	f	\N
195679	toimuksid	toimuksid =toimu  (KndPrPl3  >toimuma !27_V	et	f	\N
195720	soovitusi	soovitusi =soovitusi  (PlP  >soovitus !11_S	et	f	\N
195721	soovitusi	"soovitus %soovita  )US_vS  <soovitama ;27_V	et	f	\N
195722	soovitusi	"soovitus %soovi  )TUS1_aS  <soovima ;28_V	et	f	\N
195723	soovitusi	"soovitus %soovi  )TUS2_aS  <soov ;22_S	et	f	\N
195729	proobleemid	?proobleemid =proobleemi  (PlN  >proobleemi !16_S	et	f	\N
195730	proobleemid	?proobleemid =proobleemi  (PlN  >proobleem !22_S	et	f	\N
195731	proobleemid	?proobleemid =proobleemi  (IndPrSg2  >proobleemima !28_V	et	f	\N
195745	kataloogis	kataloogis =kataloogi  (SgIn  >kataloog !22_S	et	f	\N
195746	kataloogis	kataloogis =kataloogi  (IndIpfSg3  >kataloogima !28_V	et	f	\N
195750	pärilisust	?pärilisust =pärilisus  (SgP  >pärilisus !11?09_S	et	f	\N
195754	kondsad	?kondsad =kondsa  (PlN  >kondsa !01_S	et	f	\N
195755	kondsad	?kondsad =kondsa  (IndPrSg2  >kondsama !29_V	et	f	\N
195758	praakkaub	?praakkaub =praakkaub  (SgN  >praakkaub !22_S	et	f	\N
195759	praakkaub	?praakkaub =kaub  (SgN  >praak+kaub !22_S	et	f	\N
195790	puldinupud	?puldinupud =puldinupu  (IndPrSg2  >puldinupuma !27_V	et	f	\N
195798	lülitamisele	lülitamisele =lülitamise  (SgAll  >lülitamine !12_S	et	f	\N
195799	lülitamisele	"lülitamine %lülita  )MINE_vS  <lülitama ;27_V	et	f	\N
195800	summas	summas =summa  (SgIn  >summa !16_S	et	f	\N
195801	summas	summas =summa  (SgIn  >summ !22_S	et	f	\N
195802	summas	summas =summa  (SgIn  >sumb !22_S	et	f	\N
195804	xyyspan	?xyyspan =xyyspa  (IndPrSg1  >xyyspama !29_V	et	f	\N
195805	xyyspan	?xyyspan =xyyspan  (SgN  >xyyspan !02_S	et	f	\N
195825	väljumata	väljumata =välju  (SupAb  >väljuma !27_V	et	f	\N
195826	väljumata	väljumata =väljumata  (ID  >väljumata !41_A	et	f	\N
195827	väljumata	"väljumata %välju  )MATA_vA  <väljuma ;27_V	et	f	\N
195852	kahtlustused	kahtlustused =kahtlustuse  (PlN  >kahtlustus !11_S	et	f	\N
195853	kahtlustused	"kahtlustus %kahtlusta  )US_vS  <kahtlustama ;27_V	et	f	\N
195854	artikle	?artikle =artikle  (PlP  >artikel !19_S	et	f	\N
195855	artikle	?artikle =artikle  (IndPrPs_  >artiklema !27_V	et	f	\N
195856	artikle	?artikle =artikle  (ImpPrSg2  >artiklema !27_V	et	f	\N
195863	saavadki	saavadki =saa  (IndPrPl3^  >saama !37_V	et	f	\N
195864	saavadki	saavadki =saava  (PlN^  >saav !02_A	et	f	\N
195865	saavadki	"saav %saa  )V_vA^  <saama ;37_V	et	f	\N
195866	meditsiinisüsteemi	meditsiinisüsteemi =süsteemi  (SgG  >meditsiini+süsteem !22_S	et	f	\N
195867	meditsiinisüsteemi	meditsiinisüsteemi =süsteemi  (SgP  >meditsiini+süsteem !22_S	et	f	\N
195868	meditsiinisüsteemi	meditsiinisüsteemi =süsteemi  (SgAdt  >meditsiini+süsteem !22_S	et	f	\N
195910	kajuks	?kajuks =kaju  (SgTr  >kaju !17_S	et	f	\N
195911	kajuks	?kajuks =kaju  (KndPrPs  >kajuma !27_V	et	f	\N
195933	naudi	naudi =naudi  (SgG  >naud !22_S	et	f	\N
195934	naudi	naudi =naudi  (SgP  >naud !22_S	et	f	\N
195935	naudi	naudi =naudi  (SgAdt  >naud !22_S	et	f	\N
195936	naudi	naudi =naudi  (IndPrPs_  >nautima !28_V	et	f	\N
195937	naudi	naudi =naudi  (ImpPrSg2  >nautima !28_V	et	f	\N
195601	viisaga	viisaga =viisa  (SgKom  >viisa !16_S	et	f	\N
195614	kasanski	?kasanski =kasanski  (SgG  >kasansk !02_S	et	f	\N
195615	kasanski	?kasanski =kasanski  (IndPrPs_  >kasanskima !28_V	et	f	\N
195616	kasanski	?kasanski =kasanski  (ImpPrSg2  >kasanskima !28_V	et	f	\N
195617	kasanski	?kasanski =anski  (SgN  >kas+anski !01_S	et	f	\N
195618	kasanski	?kasanski =anski  (SgG  >kas+anski !01_S	et	f	\N
195619	kasanski	?kasanski =anski  (SgG  >kas+ansk !22_S	et	f	\N
195620	kasanski	?kasanski =anski  (SgP  >kas+ansk !22_S	et	f	\N
195621	kasanski	?kasanski =anski  (SgAdt  >kas+ansk !22_S	et	f	\N
195622	kasanski	?kasanski =kasans  (SgN^  >kasans !02_S	et	f	\N
195623	kasanski	?kasanski =ans  (SgN^  >kas+ans !22_S	et	f	\N
195625	kingisseppis	?kingisseppis =kingisseppi  (IndIpfSg3  >kingisseppima !28_V	et	f	\N
195626	kingisseppis	?kingisseppis =kingisseppis  (SgN  >kingisseppis !09_S	et	f	\N
195627	kingisseppis	?kingisseppis =isseppi  (SgIn  >king+isseppi !01_S	et	f	\N
195628	kingisseppis	?kingisseppis =isseppis  (SgN  >king+isseppis !11_S	et	f	\N
195680	soodutused	?soodutused =soodutuse  (PlN  >soodutus !11_S	et	f	\N
195681	soodutused	?soodutused =dutuse  (PlN  >soo+dutus !09_S	et	f	\N
195682	hinnast	hinnast =hinna  (SgEl  >hind !22_S	et	f	\N
195683	hinnast	hinnast =hinnas  (SgP  >hinnane !10_A	et	f	\N
195684	hinnast	"hinnane %hinna  )NE_aA  <hind ;22_S	et	f	\N
195706	rõõmusad	?rõõmusad =rõõmusa  (PlN  >rõõmusa !01_S	et	f	\N
195709	päevamatkamas	?päevamatkamas =päevamatkama  (SgIn  >päevamatkam !02_A	et	f	\N
195710	päevamatkamas	?päevamatkamas =matkama  (SgIn  >päeva+matkam !02_A	et	f	\N
195711	päevamatkamas	?päevamatkamas =amatkama  (SgIn  >päev+amatkam !02_A	et	f	\N
195717	koduneülesannet	### koduneülesannet	et	f	\N
195747	seisukorrast	seisukorrast =korra  (SgEl  >seisu+kord !22_S	et	f	\N
195748	seisukorrast	seisukorrast =korras  (SgP  >seisu+korrane !10_A	et	f	\N
195749	seisukorrast	"seisu+korrane %korra  )NE_aA  <seisu+kord ;22_S	et	f	\N
195767	sünnitud	sünnitud =sünni  (PtsPtIps  >sündima !28_V	et	f	\N
195769	sünnitud	sünnitud =sünnitu  (PlN  >sünnitu !01_AS	et	f	\N
195771	sünnitud	"sünnitu %sünni  )TU1_vS  <sündima ;28_V	et	f	\N
195773	sünnitud	"sünnitu %sünni  )TU2_kA  <sünd ;22_S	et	f	\N
195775	sünnitud	sünnitud =sünnitud  (ID  >sünnitud !41_A	et	f	\N
195777	sünnitud	"sünnitud %sünni  )TUD_vA  <sündima ;28_V	et	f	\N
195803	kontaktandmedbr	?kontaktandmedbr =andmedbr  (SgN  >kontakt+andmedbr !22_S	et	f	\N
195821	korratu	korratu =korratu  (SgN  >korratu !01_AS	et	f	\N
195822	korratu	"korratu %korra  )TU1_vS  <kordama ;29_V	et	f	\N
195823	korratu	"korratu %korra  )TU2_kA  <kord ;22_S	et	f	\N
195824	korratu	korratu =korratu  (SgG  >korratu !01_AS	et	f	\N
195828	kood	kood =koo  (PlN  >kubu !18_S	et	f	\N
195829	kood	kood =koo  (IndPrSg2  >kuduma !28_V	et	f	\N
195830	kood	kood =kood  (SgN  >kood !22_S	et	f	\N
195844	hinnetelehe	### hinnetelehe	et	f	\N
195858	särtsu	särtsu =särtsu  (SgG  >särts !22_S	et	f	\N
195859	särtsu	särtsu =särtsu  (SgP  >särts !22_S	et	f	\N
195860	särtsu	särtsu =särtsu  (SgAdt  >särts !22_S	et	f	\N
195861	särtsu	särtsu =särtsu  (IndPrPs_  >särtsuma !28_V	et	f	\N
195862	särtsu	särtsu =särtsu  (ImpPrSg2  >särtsuma !28_V	et	f	\N
195871	võtaksid	võtaksid =võta  (KndPrSg2  >võtma !35_V	et	f	\N
195872	võtaksid	võtaksid =võta  (KndPrPl3  >võtma !35_V	et	f	\N
195884	selleseid	?selleseid =sellese  (PlP  >sellene !10_A	et	f	\N
195885	selleseid	?selleseid =sellesei  (PlN  >sellesei !26_S	et	f	\N
195886	selleseid	?selleseid =sellesei  (SgP  >sellesei !26_S	et	f	\N
195887	selleseid	?selleseid =sei  (PlN  >selle+sei !26_S	et	f	\N
195888	selleseid	?selleseid =sei  (SgP  >selle+sei !26_S	et	f	\N
195889	selleseid	?selleseid =seid  (SgN  >selle+seid !22_S	et	f	\N
195892	tuudengeid	?tuudengeid =tuudenge  (PlP  >tuudeng !02_S	et	f	\N
195893	tuudengeid	?tuudengeid =tuudengei  (PlN  >tuudengei !26_S	et	f	\N
195894	tuudengeid	?tuudengeid =tuudengei  (SgP  >tuudengei !26_S	et	f	\N
195912	kindlustust	kindlustust =kindlustus  (SgP  >kindlustus !11_S	et	f	\N
195914	kindlustust	"kindlustus %kindlusta  )US_vS  <kindlustama ;27_V	et	f	\N
195916	kindlustust	kindlustust =tust  (SgN  >kindlus+tust !22_S	et	f	\N
195938	sildi	sildi =sildi  (SgG  >silt !22_S	et	f	\N
195939	sildi	sildi =sildi  (SgP  >sild !22_S	et	f	\N
195940	sildi	sildi =sildi  (SgAdt  >sild !22_S	et	f	\N
195941	filtreerivad	filtreerivad =filtreeri  (IndPrPl3  >filtreerima !28_V	et	f	\N
195942	filtreerivad	filtreerivad =filtreeriva  (PlN  >filtreeriv !02_A	et	f	\N
195943	filtreerivad	"filtreeriv %filtreeri  )V_vA  <filtreerima ;28_V	et	f	\N
195957	kaissu	kaissu =kaissu  (SgP  >kaiss !22_S	et	f	\N
195958	kaissu	kaissu =kaissu  (SgAdt  >kaiss !22_S	et	f	\N
195985	mahani	?mahani =mahani  (SgG  >mahan !02_S	et	f	\N
195991	kahta	?kahta =kahta  (SgN  >kahta !16_S	et	f	\N
195992	kahta	?kahta =kahta  (SgG  >kahta !16_S	et	f	\N
195993	kahta	?kahta =kahta  (IndPrPs_  >kahtama !29_V	et	f	\N
195994	kahta	?kahta =kahta  (ImpPrSg2  >kahtama !29_V	et	f	\N
195995	valgemad	valgemad =valgema  (PlN  >valgem !02_A	et	f	\N
195996	valgemad	"valgem %valge  )M_cA  <valge ;01_AS	et	f	\N
195686	järjekordi	järjekordi =kordi  (SgAdt  >järje+kord !22_S	et	f	\N
195687	järjekordi	järjekordi =kordi  (PlP  >järje+kord !22_S	et	f	\N
195688	sanitaarnõuetele	sanitaarnõuetele =e  (PlAll  >sanitaar+nõu+esi !15_S	et	f	\N
195689	sanitaarnõuetele	sanitaarnõuetele =nõue  (PlAll  >sanitaar+nõue !06_S	et	f	\N
195690	mälestusmärke	mälestusmärke =märke  (SgG  >mälestus+märge !06_S	et	f	\N
195691	mälestusmärke	mälestusmärke =märke  (PlP  >mälestus+märk !22_S	et	f	\N
195693	veedamist	?veedamist =veedami  (SgEl  >veedami !01_S	et	f	\N
195694	veedamist	?veedamist =veedami  (SgEl  >veedam !02_S	et	f	\N
195695	veedamist	?veedamist =veedamis  (SgP  >veedamis !11_S	et	f	\N
195696	veedamist	?veedamist =veedamis  (SgP  >veedamine !12_S	et	f	\N
195697	veedamist	?veedamist =veedamist  (SgN  >veedamist !22_S	et	f	\N
195698	veedamist	?veedamist =dami  (SgEl  >vee+dami !17_S	et	f	\N
195699	veedamist	?veedamist =damis  (SgP  >vee+damis !09_S	et	f	\N
195700	veedamist	?veedamist =damis  (SgP  >vee+damine !10_A	et	f	\N
195701	veedamist	?veedamist =damist  (SgN  >vee+damist !22_S	et	f	\N
195702	kurtna	?kurtna =kurtna  (SgN  >kurtna !01_S	et	f	\N
195703	kurtna	?kurtna =kurtna  (SgG  >kurtna !01_S	et	f	\N
195704	kurtna	?kurtna =kurtna  (IndPrPs_  >kurtnama !29_V	et	f	\N
195705	kurtna	?kurtna =kurtna  (ImpPrSg2  >kurtnama !29_V	et	f	\N
195718	mälestusväärsust	mälestusväärsust =väärsus  (SgP  >mälestus+väärsus !11~09_S	et	f	\N
195719	mälestusväärsust	"mälestus+väärsus %väärse  )US_aS  <mälestus+väärne ;02_A	et	f	\N
195724	vestlemisel	vestlemisel =vestlemise  (SgAd  >vestlemine !12_S	et	f	\N
195725	vestlemisel	"vestlemine %vestle  )MINE_vS  <vestlema ;30_V	et	f	\N
195726	kaubakirja	kaubakirja =kirja  (SgG  >kauba+kiri !24_S	et	f	\N
195727	kaubakirja	kaubakirja =kirja  (SgP  >kauba+kiri !24_S	et	f	\N
195728	kaubakirja	kaubakirja =kirja  (SgAdt  >kauba+kiri !24_S	et	f	\N
195752	kõrgkondsaga	?kõrgkondsaga =kõrgkondsa  (SgKom  >kõrgkondsa !01_S	et	f	\N
195753	kõrgkondsaga	?kõrgkondsaga =kondsa  (SgKom  >kõrg+kondsa !01_S	et	f	\N
195756	iargmisel	?iargmisel =iargmise  (SgAd  >iargmine !12?10_A	et	f	\N
195757	iargmisel	?iargmisel =iargmisel  (SgN  >iargmisel !19_S	et	f	\N
195780	katkise	katkise =katkise  (SgG  >katkine !12~10_A	et	f	\N
195781	katkise	"katkine %katki  )NE_aA  <katk ;22_S	et	f	\N
195785	lülitatud	lülitatud =lülita  (PtsPtIps  >lülitama !27_V	et	f	\N
195786	lülitatud	lülitatud =lülitatu  (PlN  >lülitatu !01_S	et	f	\N
195787	lülitatud	"lülitatu %lülita  )TU1_vS  <lülitama ;27_V	et	f	\N
195788	lülitatud	lülitatud =lülitatud  (ID  >lülitatud !41_A	et	f	\N
195789	lülitatud	"lülitatud %lülita  )TUD_vA  <lülitama ;27_V	et	f	\N
195794	töötamast	töötamast =tööta  (SupEl  >töötama !27_V	et	f	\N
195795	töötamast	töötamast =mast  (SgN  >tööta+mast !22_S	et	f	\N
195809	tööinterjuule	?tööinterjuule =tööinterjuu  (SgAll  >tööinterjuu !26_S	et	f	\N
195810	tööinterjuule	?tööinterjuule =tööinterjuule  (SgN  >tööinterjuule !16_S	et	f	\N
195811	tööinterjuule	?tööinterjuule =tööinterjuule  (SgG  >tööinterjuule !16_S	et	f	\N
195812	tööinterjuule	?tööinterjuule =tööinterjuule  (PlP  >tööinterjuul !22_S	et	f	\N
195813	tööinterjuule	?tööinterjuule =juu  (SgAll  >töö+inter+juu !26_S	et	f	\N
195814	tööinterjuule	?tööinterjuule =juule  (SgN  >töö+inter+juule !06_S	et	f	\N
195815	tööinterjuule	?tööinterjuule =juule  (SgG  >töö+inter+juule !06_S	et	f	\N
195816	tööinterjuule	?tööinterjuule =juule  (PlP  >töö+inter+juul !22_S	et	f	\N
195817	tööinterjuule	?tööinterjuule =interjuu  (SgAll  >töö+interjuu !26_S	et	f	\N
195818	tööinterjuule	?tööinterjuule =interjuule  (SgN  >töö+interjuule !16_S	et	f	\N
195819	tööinterjuule	?tööinterjuule =interjuule  (SgG  >töö+interjuule !16_S	et	f	\N
195820	tööinterjuule	?tööinterjuule =interjuule  (PlP  >töö+interjuul !22_S	et	f	\N
195835	pannaks	pannaks =panna  (SgTr  >panna !16_S	et	f	\N
195836	pannaks	pannaks =panna  (SgTr  >pand !22_S	et	f	\N
195837	diploomi	?diploomi =diploomi  (SgN  >diploomi !16_S	et	f	\N
195838	diploomi	?diploomi =diploomi  (SgG  >diploomi !16_S	et	f	\N
195839	diploomi	?diploomi =diploomi  (SgG  >diploom !22_S	et	f	\N
195840	diploomi	?diploomi =diploomi  (SgP  >diploom !22_S	et	f	\N
195841	diploomi	?diploomi =diploomi  (SgAdt  >diploom !22_S	et	f	\N
195842	diploomi	?diploomi =diploomi  (IndPrPs_  >diploomima !28_V	et	f	\N
195843	diploomi	?diploomi =diploomi  (ImpPrSg2  >diploomima !28_V	et	f	\N
195846	keskkkonnast	?keskkkonnast =keskkkonna  (SgEl  >keskkkonna !16_S	et	f	\N
195847	keskkkonnast	?keskkkonnast =keskkkonna  (SgEl  >keskkkond !22_S	et	f	\N
195848	keskkkonnast	?keskkkonnast =keskkkonnas  (SgP  >keskkkonnane !12_A	et	f	\N
195857	httpwwwekspresseeviewdoc15920b432da110b0c225718600353e84	?httpwwwekspresseeviewdocbdabce =httpwwwekspresseeviewdocbdabce  (PlP  >httpwwwekspresseeviewdocbdabc !22_S	et	f	\N
195869	suudaksid	suudaksid =suuda  (KndPrSg2  >suutma !34_V	et	f	\N
195870	suudaksid	suudaksid =suuda  (KndPrPl3  >suutma !34_V	et	f	\N
195881	tormavad	tormavad =torma  (IndPrPl3  >tormama !29_V	et	f	\N
195882	tormavad	tormavad =tormava  (PlN  >tormav !02_A	et	f	\N
195883	tormavad	"tormav %torma  )V_vA  <tormama ;29_V	et	f	\N
195895	töökaid	töökaid =tööka  (PlP  >töökas !02_A	et	f	\N
195896	töökaid	töökaid =kai  (PlN  >töö+kai !26_S	et	f	\N
195851	lõhnaõli	lõhnaõli =õli  (SgP  >lõhna+õli !17_S	et	f	\N
195875	võtmepositsiione	?võtmepositsiione =võtmepositsiione  (SgN  >võtmepositsiione !16_S	et	f	\N
195876	võtmepositsiione	?võtmepositsiione =võtmepositsiione  (SgG  >võtmepositsiione !16_S	et	f	\N
195877	võtmepositsiione	?võtmepositsiione =võtmepositsiione  (PlP  >võtmepositsiion !19_S	et	f	\N
195878	võtmepositsiione	?võtmepositsiione =positsiione  (SgN  >võtme+positsiione !16_S	et	f	\N
195879	võtmepositsiione	?võtmepositsiione =positsiione  (SgG  >võtme+positsiione !16_S	et	f	\N
195880	võtmepositsiione	?võtmepositsiione =positsiione  (PlP  >võtme+positsiion !19_S	et	f	\N
195890	uudishimulisi	uudishimulisi =himulisi  (PlP  >uudis+himuline !12_A	et	f	\N
195891	uudishimulisi	"uudis+himuline %himu  )LINE_aA  <uudis+himu ;17_S	et	f	\N
195902	pangast	pangast =panga  (SgEl  >pank !22_S	et	f	\N
195903	pangast	pangast =pangas  (SgP  >pangas !07_S	et	f	\N
195904	pangast	pangast =pangas  (SgP  >pangane !10_A	et	f	\N
195905	pangast	"pangane %panga  )NE_aA  <pank ;22_S	et	f	\N
195924	palki	palki =palki  (SgP  >palk !22_S	et	f	\N
195925	palki	palki =palki  (SgAdt  >palk !22_S	et	f	\N
195926	kandideerivad	kandideerivad =kandideeri  (IndPrPl3  >kandideerima !28_V	et	f	\N
195927	kandideerivad	kandideerivad =kandideeriva  (PlN  >kandideeriv !02_A	et	f	\N
195928	kandideerivad	"kandideeriv %kandideeri  )V_vA  <kandideerima ;28_V	et	f	\N
195946	kulutatud	kulutatud =kuluta  (PtsPtIps  >kulutama !27_V	et	f	\N
195947	kulutatud	kulutatud =kulutatu  (PlN  >kulutatu !01_S	et	f	\N
195948	kulutatud	"kulutatu %kuluta  )TU1_vS  <kulutama ;27_V	et	f	\N
195949	kulutatud	kulutatud =kulutatud  (ID  >kulutatud !41_A	et	f	\N
195950	kulutatud	"kulutatud %kuluta  )TUD_vA  <kulutama ;27_V	et	f	\N
195951	muul	muul =muu  (SgAd  >muu !26_S	et	f	\N
195952	muul	muul =muu  (SgAd  >muu !26_P	et	f	\N
195953	muul	muul =muul  (SgN  >muul !22_S	et	f	\N
195954	pugeta	?pugeta =puge  (SgAb  >puge !16_S	et	f	\N
195955	pugeta	?pugeta =pugeta  (IndPrPs_  >pugetama !27_V	et	f	\N
195956	pugeta	?pugeta =pugeta  (ImpPrSg2  >pugetama !27_V	et	f	\N
195966	ettevõttede	### ettevõttede	et	f	\N
195977	tarbimispeosse	tarbimispeosse =peo  (SgIll  >tarbimis+pidu !18_S	et	f	\N
195978	tarbimispeosse	tarbimispeosse =peo  (SgIll  >tarbimis+peo !26_S	et	f	\N
195998	moelviisil	?moelviisil =moelviisi  (SgAd  >moelviisi !16_S	et	f	\N
195999	moelviisil	?moelviisil =moelviisi  (SgAd  >moelviis !22_S	et	f	\N
196032	ftuglas	?ftuglas =ftugla  (SgIn  >ftugla !16_S	et	f	\N
196033	ftuglas	?ftuglas =ftugla  (IndIpfSg3  >ftuglama !27_V	et	f	\N
196034	ftuglas	?ftuglas =ftuglas  (SgN  >ftuglas !07_S	et	f	\N
196063	piiratamist	?piiratamist =piiratami  (SgEl  >piiratam !02_A	et	f	\N
196064	piiratamist	?piiratamist =piiratamis  (SgP  >piiratamis !09_S	et	f	\N
196065	piiratamist	?piiratamist =piiratamis  (SgP  >piiratamine !12_S	et	f	\N
196066	piiratamist	?piiratamist =piiratamist  (SgN  >piiratamist !22_S	et	f	\N
196067	piiratamist	?piiratamist =atami  (SgEl  >piir+atami !01_S	et	f	\N
196068	piiratamist	?piiratamist =atami  (SgEl  >piir+atam !02_A	et	f	\N
196069	piiratamist	?piiratamist =atamis  (SgP  >piir+atamis !11_S	et	f	\N
196070	piiratamist	?piiratamist =atamis  (SgP  >piir+atamine !12_S	et	f	\N
196071	piiratamist	?piiratamist =atamist  (SgN  >piir+atamist !22_S	et	f	\N
196077	telegrafi	?telegrafi =telegrafi  (SgG  >telegraff !22_S	et	f	\N
196078	telegrafi	?telegrafi =telegrafi  (IndPrPs_  >telegraffima !28_V	et	f	\N
196079	telegrafi	?telegrafi =telegrafi  (ImpPrSg2  >telegraffima !28_V	et	f	\N
196080	telegrafi	?telegrafi =grafi  (SgN  >tele+grafi !16_S	et	f	\N
196081	telegrafi	?telegrafi =grafi  (SgG  >tele+grafi !16_S	et	f	\N
196082	telegrafi	?telegrafi =grafi  (SgG  >tele+graff !22_S	et	f	\N
196088	ühinemistküll	?ühinemistküll =ühinemistküll  (SgN  >ühinemistküll !22_S	et	f	\N
196106	tulebelada	### tulebelada	et	f	\N
196122	kalendripäeva	kalendripäeva =päeva  (SgG  >kalendri+päev !22_S	et	f	\N
196123	kalendripäeva	kalendripäeva =päeva  (SgP  >kalendri+päev !22_S	et	f	\N
196124	kalendripäeva	kalendripäeva =päeva  (SgAdt  >kalendri+päev !22_S	et	f	\N
196128	lõbustustest	lõbustustest =lõbustus  (PlEl  >lõbustus !11_S	et	f	\N
196129	lõbustustest	"lõbustus %lõbusta  )US_vS  <lõbustama ;27_V	et	f	\N
196130	lõbustustest	lõbustustest =test  (SgN  >lõbustus+test !22_S	et	f	\N
196144	valjem	valjem =valjem  (SgN  >valjem !02_A	et	f	\N
196145	valjem	"valjem %valje  )M_cA  <vali ;24_A	et	f	\N
196146	kiikedel	kiikedel =kiike  (PlAd  >kiik !22_S	et	f	\N
196147	kiikedel	kiikedel =ede  (SgAd  >kiik+ede !16_S	et	f	\N
196148	kiikedel	kiikedel =edel  (SgN  >kiik+edel !02_S	et	f	\N
196151	katsid	katsid =kat  (IndIpfSg2  >katma !35_V	et	f	\N
196152	katsid	katsid =kat  (IndIpfPl3  >katma !35_V	et	f	\N
196153	katsid	katsid =katsi  (PlN  >kats !22_S	et	f	\N
196162	kergendamist	kergendamist =kergendamis  (SgP  >kergendamine !12_S	et	f	\N
196163	kergendamist	"kergendamine %kergenda  )MINE_vS  <kergendama ;27_V	et	f	\N
196175	äändevormide	?äändevormide =äändevormi  (PlG  >äändevorm !22_S	et	f	\N
196179	analüsis	?analüsis =analüsis  (SgN  >analüsis !09_S	et	f	\N
196192	akpekti	?akpekti =akpekti  (SgN  >akpekti !01_S	et	f	\N
196193	akpekti	?akpekti =akpekti  (SgG  >akpekti !01_S	et	f	\N
195897	töökaid	töökaid =kai  (SgP  >töö+kai !26_S	et	f	\N
195900	lasete	lasete =lase  (PlG  >lase !06_S	et	f	\N
195901	lasete	lasete =lase  (IndPrPl2  >laskma !34_V	et	f	\N
195913	sotsiaaltagatiseid	?sotsiaaltagatiseid =sotsiaaltagatise  (PlP  >sotsiaaltagatis !09_S	et	f	\N
195915	sotsiaaltagatiseid	?sotsiaaltagatiseid =sotsiaaltagatisei  (PlN  >sotsiaaltagatisei !26_S	et	f	\N
195917	sotsiaaltagatiseid	?sotsiaaltagatiseid =sotsiaaltagatisei  (SgP  >sotsiaaltagatisei !26_S	et	f	\N
195918	sotsiaaltagatiseid	?sotsiaaltagatiseid =eid  (SgN  >sotsiaal+tagatis+eid !22_S	et	f	\N
195919	sotsiaaltagatiseid	?sotsiaaltagatiseid =tisei  (PlN  >sotsiaal+taga+tisei !26_S	et	f	\N
195920	sotsiaaltagatiseid	?sotsiaaltagatiseid =tisei  (SgP  >sotsiaal+taga+tisei !26_S	et	f	\N
195921	sotsiaaltagatiseid	?sotsiaaltagatiseid =tiseid  (SgN  >sotsiaal+taga+tiseid !22_S	et	f	\N
195922	sotsiaaltagatiseid	?sotsiaaltagatiseid =tagatisei  (PlN  >sotsiaal+tagatisei !26_S	et	f	\N
195923	sotsiaaltagatiseid	?sotsiaaltagatiseid =tagatisei  (SgP  >sotsiaal+tagatisei !26_S	et	f	\N
195931	töökohtadile	?töökohtadile =adi  (SgAll  >töö+koht+adi !17_S	et	f	\N
195932	töökohtadile	?töökohtadile =kohtadi  (SgAll  >töö+kohtadi !01_S	et	f	\N
195959	hellust	hellust =hellus  (SgP  >hellus !11~09_S	et	f	\N
195960	hellust	"hellus %hell  )US_aS  <hell ;22_A	et	f	\N
195961	särata	särata =sära  (SgAb  >sära !17_S	et	f	\N
195962	särata	särata =sära  (IndPrIps_  >särama !27_V	et	f	\N
195963	särata	särata =särata  (IndPrPs_  >säratama !27_V	et	f	\N
195965	särata	särata =särata  (ImpPrSg2  >säratama !27_V	et	f	\N
195973	raisaksid	?raisaksid =raisa  (KndPrSg2  >raisama !29_V	et	f	\N
195974	raisaksid	?raisaksid =raisa  (KndPrPl3  >raisama !29_V	et	f	\N
195975	raisaksid	?raisaksid =raisaksi  (PlN  >raisaksi !01_S	et	f	\N
195976	raisaksid	?raisaksid =raisaksi  (IndPrSg2  >raisaksima !28_V	et	f	\N
195989	lööklause	lööklause =lause  (SgN  >löök+lause !06_S	et	f	\N
195990	lööklause	lööklause =lause  (SgG  >löök+lause !06_S	et	f	\N
196005	ajaloosbr	?ajaloosbr =loosbr  (SgN  >aja+loosbr !22_S	et	f	\N
196006	raamatutelugejate	?raamatutelugejate =raamatutelugeja  (PlG  >raamatutelugeja !01_S	et	f	\N
196007	raamatutelugejate	?raamatutelugejate =raamatutelugeja  (PlG  >raamatutelugejas !02_A	et	f	\N
196008	raamatutelugejate	?raamatutelugejate =telugeja  (PlG  >raamatu+telugeja !01_S	et	f	\N
196009	raamatutelugejate	?raamatutelugejate =telugeja  (PlG  >raamatu+telugejas !02_A	et	f	\N
196010	raamatutelugejate	?raamatutelugejate =atutelugeja  (PlG  >raam+atutelugeja !01_S	et	f	\N
196012	raamatutelugejate	?raamatutelugejate =atutelugeja  (PlG  >raam+atutelugejas !02_A	et	f	\N
196024	neuroloogia	neuroloogia =neuroloogia  (SgN  >neuroloogia !01_S	et	f	\N
196025	neuroloogia	neuroloogia =neuroloogia  (SgG  >neuroloogia !01_S	et	f	\N
196035	ftuglas	?ftuglas =ftugla  (SgIn  >ftugla !16_S	et	f	\N
196036	ftuglas	?ftuglas =ftugla  (IndIpfSg3  >ftuglama !27_V	et	f	\N
196037	ftuglas	?ftuglas =ftuglas  (SgN  >ftuglas !07_S	et	f	\N
196038	haritlaskonna	haritlaskonna =haritlaskonna  (SgG  >haritlaskond !22_S	et	f	\N
196039	haritlaskonna	haritlaskonna =konna  (SgG  >haritlas+konn !22_S	et	f	\N
196040	haritlaskonna	haritlaskonna =konna  (SgP  >haritlas+konn !22_S	et	f	\N
196041	haritlaskonna	haritlaskonna =konna  (SgAdt  >haritlas+konn !22_S	et	f	\N
196050	keelesbr	?keelesbr =keelesbr  (SgN  >keelesbr !22_S	et	f	\N
196051	keelesbr	?keelesbr =esbr  (SgN  >keel+esbr !22_S	et	f	\N
196083	lühines	?lühines =lühine  (IndIpfSg3  >lühinema !27_V	et	f	\N
196093	rendi	rendi =rendi  (SgG  >rent !22_S	et	f	\N
196094	rendi	rendi =rendi  (IndPrPs_  >rentima !28_V	et	f	\N
196095	rendi	rendi =rendi  (ImpPrSg2  >rentima !28_V	et	f	\N
196107	ariteeritud	?ariteeritud =ariteeri  (PtsPtIps  >ariteerima !28_V	et	f	\N
196108	ariteeritud	?ariteeritud =ariteeritu  (PlN  >ariteeritu !01_S	et	f	\N
196109	ariteeritud	?ariteeritud =ariteeritu  (IndPrSg2  >ariteerituma !27_V	et	f	\N
196110	ariteeritud	?ariteeritud =ariteeritud  (ID  >ariteeritud !41_A	et	f	\N
196115	eddasi	?eddasi =eddasi  (ID  >eddasi !41_D	et	f	\N
196116	kultuuriruumisvastlapäev	?kultuuriruumisvastlapäev =kultuuriruumisvastlapäev  (SgN  >kultuuriruumisvastlapäev !22_S	et	f	\N
196117	kultuuriruumisvastlapäev	?kultuuriruumisvastlapäev =svastlapäev  (SgN  >kultuuri+ruumi+svastlapäev !22_S	et	f	\N
196118	kultuuriruumisvastlapäev	?kultuuriruumisvastlapäev =isvastlapäev  (SgN  >kultuuri+ruum+isvastlapäev !22_S	et	f	\N
196119	kultuuriruumisvastlapäev	?kultuuriruumisvastlapäev =ruumisvastlapäev  (SgN  >kultuuri+ruumisvastlapäev !22_S	et	f	\N
196120	kultuuriruumisvastlapäev	?kultuuriruumisvastlapäev =iruumisvastlapäev  (SgN  >kultuur+iruumisvastlapäev !22_S	et	f	\N
196154	pearoaks	pearoaks =roa  (SgTr  >pea+ruga !18_S	et	f	\N
196155	pearoaks	pearoaks =roa  (SgTr  >pea+roog !22_S	et	f	\N
196156	ratsutamist	ratsutamist =ratsutamis  (SgP  >ratsutamine !12_S	et	f	\N
196157	ratsutamist	"ratsutamine %ratsuta  )MINE_vS  <ratsutama ;27_V	et	f	\N
196164	rääkivate	rääkivate =rääkiva  (PlG  >rääkiv !02_A	et	f	\N
196165	rääkivate	"rääkiv %rääki  )V_vA  <rääkima ;28_V	et	f	\N
196168	makorda	?makorda =makorda  (SgN  >makorda !01_S	et	f	\N
196169	makorda	?makorda =makorda  (SgG  >makorda !01_S	et	f	\N
196170	makorda	?makorda =makorda  (IndPrPs_  >makordama !27_V	et	f	\N
196171	makorda	?makorda =makorda  (ImpPrSg2  >makordama !27_V	et	f	\N
195944	pikale	pikale =pika  (SgAll  >pikk !22_S	et	f	\N
195945	pikale	pikale =pika  (SgAll  >pikk !22_AS	et	f	\N
195967	reklaamieelarve	reklaamieelarve =arve  (SgN  >reklaami+eel+arve !06_S	et	f	\N
195968	reklaamieelarve	reklaamieelarve =arve  (SgG  >reklaami+eel+arve !06_S	et	f	\N
195969	reklaamieelarve	reklaamieelarve =arve  (PlP  >reklaami+eel+arv !22_S	et	f	\N
195979	ponds	?ponds =ponds  (SgN  >ponds !22_S	et	f	\N
195986	valo	?valo =valo  (SgN  >valo !17~16_S	et	f	\N
195987	valo	?valo =valo  (SgG  >valo !17~16_S	et	f	\N
195988	valo	?valo =valo  (SgP  >valo !17_S	et	f	\N
196013	teadustearengu	?teadustearengu =teadustearengu  (SgG  >teadusteareng !02_S	et	f	\N
196014	teadustearengu	?teadustearengu =teadustearengu  (IndPrPs_  >teadustearenguma !27_V	et	f	\N
196015	teadustearengu	?teadustearengu =teadustearengu  (ImpPrSg2  >teadustearenguma !27_V	et	f	\N
196016	teadustearengu	?teadustearengu =tearengu  (SgN  >teadus+tearengu !01_S	et	f	\N
196017	teadustearengu	?teadustearengu =tearengu  (SgG  >teadus+tearengu !01_S	et	f	\N
196018	teadustearengu	?teadustearengu =tearengu  (SgG  >teadus+teareng !02_S	et	f	\N
196019	teadustearengu	?teadustearengu =stearengu  (SgN  >teadu+stearengu !01_S	et	f	\N
196020	teadustearengu	?teadustearengu =stearengu  (SgG  >teadu+stearengu !01_S	et	f	\N
196021	teadustearengu	?teadustearengu =stearengu  (SgG  >teadu+steareng !02_S	et	f	\N
196026	ajuoperatsioonebr	?ajuoperatsioonebr =ajuoperatsioonebr  (SgN  >ajuoperatsioonebr !22_S	et	f	\N
196027	ajuoperatsioonebr	?ajuoperatsioonebr =operatsioonebr  (SgN  >aju+operatsioonebr !22_S	et	f	\N
196028	kirjandusrühmitus	kirjandusrühmitus =rühmitu  (SgIn  >kirjandus+rühmitu !01_AS	et	f	\N
196029	kirjandusrühmitus	"kirjandus+rühmitu %rühmi  )TU2_kA  <kirjandus+rühm ;22_S	et	f	\N
196030	kirjandusrühmitus	kirjandusrühmitus =rühmitus  (SgN  >kirjandus+rühmitus !11_S	et	f	\N
196031	kirjandusrühmitus	"kirjandus+rühmitus %rühmi  )TUS2_aS  <kirjandus+rühm ;22_S	et	f	\N
196044	ahtammsare	### ahtammsare	et	f	\N
196052	gümn	?gümn =gümn  (SgN  >gümn !22_S	et	f	\N
196086	piirati	piirati =piira  (IndIpfIps  >piirama !29_V	et	f	\N
196087	piirati	piirati =ati  (SgG  >piir+att !22_S	et	f	\N
196097	maksmise	maksmise =maksmise  (SgG  >maksmine !12?10_S	et	f	\N
196098	maksmise	"maksmine %maks  )MINE_vS  <maksma ;32_V	et	f	\N
196111	tapetudbr	### tapetudbr	et	f	\N
196121	korrekteeridatänan	?korrekteeridatänan =korrekteeridatänan  (SgN  >korrekteeridatänan !19_S	et	f	\N
196141	lärmakam	lärmakam =lärmakam  (SgN  >lärmakam !02_A	et	f	\N
196142	lärmakam	"lärmakam %lärmaka  )M_cA  <lärmakas ;02_A	et	f	\N
196143	liumägesi	?liumägesi =liumägesi  (PlP  >liumägene !12_A	et	f	\N
196160	andestust	andestust =andestus  (SgP  >andestus !11_S	et	f	\N
196161	andestust	"andestus %andesta  )US_vS  <andestama ;27_V	et	f	\N
196213	esolevas	?esolevas =esoleva  (SgIn  >esolev !02_A	et	f	\N
196214	esolevas	?esolevas =esoleva  (SgIn  >esoleva !16_S	et	f	\N
196215	sihtkeelede	sihtkeelede =ede  (SgN  >siht+keel+ede !16_S	et	f	\N
196216	sihtkeelede	sihtkeelede =ede  (SgG  >siht+keel+ede !16_S	et	f	\N
196235	problemeid	?problemeid =probleme  (PlP  >problemi !01_S	et	f	\N
196236	problemeid	?problemeid =probleme  (PlP  >problem !02_A	et	f	\N
196237	problemeid	?problemeid =problemei  (PlN  >problemei !26_S	et	f	\N
196238	problemeid	?problemeid =problemei  (SgP  >problemei !26_S	et	f	\N
196241	armatuseta	?armatuseta =armatuse  (SgAb  >armatus !11_S	et	f	\N
196242	armatuseta	?armatuseta =armatuseta  (IndPrPs_  >armatusetama !27_V	et	f	\N
196243	armatuseta	?armatuseta =armatuseta  (ImpPrSg2  >armatusetama !27_V	et	f	\N
196254	enesetappe	enesetappe =tappe  (SgG  >enese+tape !06_S	et	f	\N
196255	enesetappe	enesetappe =tappe  (PlP  >enese+tapp !22_S	et	f	\N
196275	kütega	### kütega	et	f	\N
196276	ästi	?ästi =ästi  (SgN  >ästi !16_S	et	f	\N
196277	ästi	?ästi =ästi  (SgG  >ästi !16_S	et	f	\N
196278	ästi	?ästi =ästi  (SgG  >äst !22_S	et	f	\N
196279	ästi	?ästi =ästi  (SgP  >äst !22_S	et	f	\N
196280	ästi	?ästi =ästi  (SgAdt  >äst !22_S	et	f	\N
196281	ästi	?ästi =ästi  (IndPrPs_  >ästima !28_V	et	f	\N
196282	ästi	?ästi =ästi  (ImpPrSg2  >ästima !28_V	et	f	\N
196289	sõpradetta	?sõpradetta =sõpradetta  (SgN  >sõpradetta !16_S	et	f	\N
196290	sõpradetta	?sõpradetta =sõpradetta  (SgG  >sõpradetta !16_S	et	f	\N
196300	teehnika	?teehnika =teehnika  (SgN  >teehnika !01_S	et	f	\N
196301	teehnika	?teehnika =teehnika  (SgG  >teehnika !01_S	et	f	\N
196302	teehnika	?teehnika =teehnika  (SgG  >teehnikas !02_S	et	f	\N
196315	armastusbr	### armastusbr	et	f	\N
196318	tütra	?tütra =tütra  (ID  >tütra !41_D	et	f	\N
196319	tütra	?tütra =tütra  (IndPrPs_  >tütrama !29_V	et	f	\N
196320	tütra	?tütra =tütra  (ImpPrSg2  >tütrama !29_V	et	f	\N
196357	võrkeeli	?võrkeeli =võrkeeli  (SgN  >võrkeeli !16_S	et	f	\N
196358	võrkeeli	?võrkeeli =võrkeeli  (SgG  >võrkeeli !16_S	et	f	\N
196359	võrkeeli	?võrkeeli =võrkeeli  (SgG  >võrkeel !22_S	et	f	\N
196360	võrkeeli	?võrkeeli =võrkeeli  (SgP  >võrkeel !22_S	et	f	\N
196361	võrkeeli	?võrkeeli =võrkeeli  (SgAdt  >võrkeel !22_S	et	f	\N
196362	võrkeeli	?võrkeeli =võrkeeli  (IndPrPs_  >võrkeelima !28_V	et	f	\N
196363	võrkeeli	?võrkeeli =võrkeeli  (ImpPrSg2  >võrkeelima !28_V	et	f	\N
195971	miljoonid	?miljoonid =miljooni  (PlN  >miljoon !22_S	et	f	\N
195972	miljoonid	?miljoonid =miljooni  (IndPrSg2  >miljoonima !28_V	et	f	\N
195980	suudlesid	suudlesid =suudle  (IndIpfSg2  >suudlema !30_V	et	f	\N
195981	suudlesid	suudlesid =suudle  (IndIpfPl3  >suudlema !30_V	et	f	\N
195982	sukka	sukka =sukka  (SgP  >sukk !22_S	et	f	\N
195983	sukka	sukka =sukka  (SgAdt  >suga !18_S	et	f	\N
195984	sukka	sukka =sukka  (SgAdt  >sukk !22_S	et	f	\N
196022	loodusteadust	loodusteadust =teadu  (SgEl  >loodus+tead !22_S	et	f	\N
196023	loodusteadust	loodusteadust =teadus  (SgP  >loodus+teadus !11~09_S	et	f	\N
196042	kasvamisele	kasvamisele =kasvamise  (SgAll  >kasvamine !12_S	et	f	\N
196043	kasvamisele	"kasvamine %kasva  )MINE_vS  <kasvama ;28_V	et	f	\N
196045	kirjanikurühmitus	kirjanikurühmitus =rühmitu  (SgIn  >kirjaniku+rühmitu !01_AS	et	f	\N
196046	kirjanikurühmitus	"kirjaniku+rühmitu %rühmi  )TU2_kA  <kirjaniku+rühm ;22_S	et	f	\N
196047	kirjanikurühmitus	kirjanikurühmitus =rühmitus  (SgN  >kirjaniku+rühmitus !11_S	et	f	\N
196048	kirjanikurühmitus	"kirjaniku+rühmitus %rühmi  )TUS2_aS  <kirjaniku+rühm ;22_S	et	f	\N
196053	lühinemist	?lühinemist =lühinemi  (SgEl  >lühinem !02_A	et	f	\N
196054	lühinemist	?lühinemist =lühinemis  (SgP  >lühinemis !09_S	et	f	\N
196055	lühinemist	?lühinemist =lühinemis  (SgP  >lühinemine !12_S	et	f	\N
196056	lühinemist	?lühinemist =lühinemist  (SgN  >lühinemist !22_S	et	f	\N
196057	lühinemist	?lühinemist =nemi  (SgEl  >lühi+nemi !17_S	et	f	\N
196058	lühinemist	?lühinemist =nemis  (SgP  >lühi+nemis !09_S	et	f	\N
196059	lühinemist	?lühinemist =nemis  (SgP  >lühi+nemine !10_A	et	f	\N
196060	lühinemist	?lühinemist =nemist  (SgN  >lühi+nemist !22_S	et	f	\N
196084	trahvimist	trahvimist =trahvimis  (SgP  >trahvimine !12_S	et	f	\N
196085	trahvimist	"trahvimine %trahvi  )MINE_vS  <trahvima ;28_V	et	f	\N
196089	mõisanikke	?mõisanikke =mõisanikke  (PlP  >mõisanik !25_S	et	f	\N
196090	mõisanikke	?mõisanikke =nikke  (SgN  >mõisa+nikke !06_S	et	f	\N
196091	mõisanikke	?mõisanikke =nikke  (SgG  >mõisa+nike !06_S	et	f	\N
196092	mõisanikke	?mõisanikke =nikke  (PlP  >mõisa+nikk !22_S	et	f	\N
196096	kergendamistbr	?kergendamistbr =mistbr  (SgN  >kerg+enda+mistbr !22_S	et	f	\N
196112	testime	testime =testi  (IndPrPl1  >testima !28_V	et	f	\N
196113	testime	testime =ime  (SgN  >test+ime !16_S	et	f	\N
196114	testime	testime =ime  (SgG  >test+ime !16_S	et	f	\N
196125	liikuvate	liikuvate =liikuva  (PlG  >liikuv !02_A	et	f	\N
196126	liikuvate	"liikuv %liiku  )V_vA  <liikuma ;28_V	et	f	\N
196127	lihavõttetega	?lihavõttetega =võtte  (PlKom  >liha+võtte !06_S	et	f	\N
196131	sööda	sööda =söö  (IndPrIps_  >sööma !38_V	et	f	\N
196132	sööda	sööda =sööda  (SgG  >sööt !22_S	et	f	\N
196133	sööda	sööda =sööda  (IndPrPs_  >söötma !34_V	et	f	\N
196134	sööda	sööda =sööda  (ImpPrSg2  >söötma !34_V	et	f	\N
196149	lõbustuste	lõbustuste =lõbustus  (PlG  >lõbustus !11_S	et	f	\N
196150	lõbustuste	"lõbustus %lõbusta  )US_vS  <lõbustama ;27_V	et	f	\N
196158	väimees	väimees =mee  (SgIn  >väi+mesi !15_S	et	f	\N
196159	väimees	väimees =mees  (SgN  >väi+mees !13_S	et	f	\N
196166	ähtsamaks	?ähtsamaks =ähtsa  (SupTr  >ähtsama !29_V	et	f	\N
196167	ähtsamaks	?ähtsamaks =ähtsama  (SgTr  >ähtsam !02_A	et	f	\N
196176	väärase	väärase =väärase  (SgG  >väärane !10_A	et	f	\N
196177	väärase	"väärane %väära  )NE_aA  <väär ;22_S	et	f	\N
196178	väärase	väärase =ase  (SgN  >väär+ase !04_S	et	f	\N
196180	lähtekohast	lähtekohast =koha  (SgEl  >lähte+koha !17_S	et	f	\N
196181	lähtekohast	lähtekohast =koha  (SgEl  >lähte+koht !22_S	et	f	\N
196182	lähtekohast	lähtekohast =kohas  (SgP  >lähte+kohane !10_A	et	f	\N
196183	lähtekohast	"lähte+kohane %koha  )NE_aA  <lähte+koha ;17_S	et	f	\N
196184	lähtekohast	"lähte+kohane %koha  )NE_aA  <lähte+koht ;22_S	et	f	\N
196199	perfektiivsust	perfektiivsust =perfektiivsus  (SgP  >perfektiivsus !11~09_S	et	f	\N
196200	perfektiivsust	"perfektiivsus %perfektiivse  )US_aS  <perfektiivne ;02_A	et	f	\N
196205	kahtlevad	kahtlevad =kahtle  (IndPrPl3  >kahtlema !30_V	et	f	\N
196206	kahtlevad	kahtlevad =kahtleva  (PlN  >kahtlev !02_A	et	f	\N
196207	kahtlevad	"kahtlev %kahtle  )V_vA  <kahtlema ;30_V	et	f	\N
196239	agresiivne	?agresiivne =agresiivne  (SgN  >agresiivne !02_A	et	f	\N
196240	agresiivne	?agresiivne =agresiivne  (PlP  >agresiivn !22_S	et	f	\N
196249	narkomaneid	?narkomaneid =narkomanei  (PlN  >narkomanei !26_S	et	f	\N
196250	narkomaneid	?narkomaneid =narkomanei  (SgP  >narkomanei !26_S	et	f	\N
196251	narkomaneid	?narkomaneid =manei  (PlN  >narko+manei !26_S	et	f	\N
196252	narkomaneid	?narkomaneid =manei  (SgP  >narko+manei !26_S	et	f	\N
196253	narkomaneid	?narkomaneid =maneid  (SgN  >narko+maneid !22_S	et	f	\N
196283	töötadaveel	?töötadaveel =töötadavee  (SgAd  >töötadavee !26_S	et	f	\N
196284	töötadaveel	?töötadaveel =töötadaveel  (SgN  >töötadaveel !22_S	et	f	\N
196285	töötadaveel	?töötadaveel =davee  (SgAd  >tööta+davee !26_S	et	f	\N
196286	töötadaveel	?töötadaveel =daveel  (SgN  >tööta+daveel !22_S	et	f	\N
196287	töötadaveel	?töötadaveel =tadavee  (SgAd  >töö+tadavee !26_S	et	f	\N
196288	töötadaveel	?töötadaveel =tadaveel  (SgN  >töö+tadaveel !22_S	et	f	\N
195997	valgemad	valgemad =ema  (PlN  >valg+ema !17_S	et	f	\N
196000	sündmste	?sündmste =sündmste  (SgN  >sündmste !06_S	et	f	\N
196001	sündmste	?sündmste =sündmste  (SgG  >sündmste !06_S	et	f	\N
196002	sündmste	?sündmste =sündmste  (PlP  >sündmst !22_S	et	f	\N
196003	sündmste	?sündmste =sündmste  (IndPrPs_  >sündmstema !27_V	et	f	\N
196004	sündmste	?sündmste =sündmste  (ImpPrSg2  >sündmstema !27_V	et	f	\N
196011	arvbr	?arvbr =arvbr  (SgN  >arvbr !22_S	et	f	\N
196049	siurubr	?siurubr =siurubr  (SgN  >siurubr !22_S	et	f	\N
196061	trahvimise	trahvimise =trahvimise  (SgG  >trahvimine !12_S	et	f	\N
196062	trahvimise	"trahvimine %trahvi  )MINE_vS  <trahvima ;28_V	et	f	\N
196072	privillegid	### privillegid	et	f	\N
196073	streigisid	?streigisid =streigi  (PlP  >streigi !16_S	et	f	\N
196074	streigisid	?streigisid =streigi  (PlP  >streig !22_S	et	f	\N
196075	streigisid	?streigisid =streigi  (IndIpfSg2  >streigima !28_V	et	f	\N
196076	streigisid	?streigisid =streigi  (IndIpfPl3  >streigima !28_V	et	f	\N
196099	1905a	### 1905a	et	f	\N
196100	levitanud	levitanud =levita  (PtsPtPs  >levitama !27_V	et	f	\N
196101	levitanud	levitanud =levitanu  (PlN  >levitanu !01_S	et	f	\N
196102	levitanud	"levitanu %levita  )NU_vS  <levitama ;27_V	et	f	\N
196103	levitanud	levitanud =levitanud  (ID  >levitanud !41_A	et	f	\N
196104	levitanud	"levitanud %levita  )NUD_vA  <levitama ;27_V	et	f	\N
196105	levitanud	levitanud =tanu  (PlN  >levi+tanu !17_S	et	f	\N
196135	või-pannkooke	või-pannkooke =kooke  (SgN  >või-pann+kooke !12?10_S	et	f	\N
196136	või-pannkooke	"või-pann+kooke %koo  )KE_dS  <või-pann+kubu ;18_S	et	f	\N
196137	või-pannkooke	või-pannkooke =kooke  (PlP  >või-pann+kook !22_S	et	f	\N
196138	rahvapüha	rahvapüha =püha  (SgN  >rahva+püha !17_SA	et	f	\N
196139	rahvapüha	rahvapüha =püha  (SgG  >rahva+püha !17_SA	et	f	\N
196140	rahvapüha	rahvapüha =püha  (SgP  >rahva+püha !17_SA	et	f	\N
196191	aspektuaalset	?aspektuaalset =aspektuaalse  (SgP  >aspektuaalne !02_A	et	f	\N
196217	strateegia	strateegia =strateegia  (SgN  >strateegia !01_S	et	f	\N
196218	strateegia	strateegia =strateegia  (SgG  >strateegia !01_S	et	f	\N
196227	infinitiivvormide	?infinitiivvormide =infinitiivvormi  (PlG  >infinitiivvorm !22_S	et	f	\N
196232	põhifraasi	põhifraasi =fraasi  (SgG  >põhi+fraas !22_S	et	f	\N
196233	põhifraasi	põhifraasi =fraasi  (SgP  >põhi+fraas !22_S	et	f	\N
196234	põhifraasi	põhifraasi =fraasi  (SgAdt  >põhi+fraas !22_S	et	f	\N
196270	tvja	### tvja	et	f	\N
196321	kedagil	### kedagil	et	f	\N
196325	võõrkeeliga	võõrkeeliga =iga  (SgN  >võõr+keel+iga !18_S	et	f	\N
196326	võõrkeeliga	võõrkeeliga =iga  (SgP  >võõr+keel+iga !18_S	et	f	\N
196342	oskamata	oskamata =oska  (SupAb  >oskama !29_V	et	f	\N
196343	oskamata	oskamata =oskamata  (ID  >oskamata !41_A	et	f	\N
196344	oskamata	"oskamata %oska  )MATA_vA  <oskama ;29_V	et	f	\N
196353	lauteda	?lauteda =laute  (Inf  >lautema !27_V	et	f	\N
196354	lauteda	?lauteda =teda  (SgN  >lau+teda !17_S	et	f	\N
196355	lauteda	?lauteda =teda  (SgG  >lau+teda !17_S	et	f	\N
196356	lauteda	?lauteda =teda  (SgP  >lau+teda !17_S	et	f	\N
196390	laies	laies =laie  (SgIn  >laie !06_S	et	f	\N
196391	laies	laies =laie  (PlIn  >laid !22_S	et	f	\N
196399	inimohvred	?inimohvred =ohvre  (PlN  >inim+ohvre !06_S	et	f	\N
196437	milelta	?milelta =milelta  (SgN  >milelta !01_S	et	f	\N
196438	milelta	?milelta =milelta  (SgG  >milelta !01_S	et	f	\N
196466	liisakormuse	?liisakormuse =liisakormuse  (SgG  >liisakormus !11~09_S	et	f	\N
196470	kaardi	kaardi =kaardi  (SgG  >kaart !22_S	et	f	\N
196471	kaardi	kaardi =kaardi  (SgP  >kaard !22_S	et	f	\N
196472	kaardi	kaardi =kaardi  (SgAdt  >kaard !22_S	et	f	\N
196482	tasustavat	tasustavat =tasusta  (KvtPrPs  >tasustama !27_V	et	f	\N
196484	tasustavat	tasustavat =tasustava  (SgP  >tasustav !02_A	et	f	\N
196486	tasustavat	"tasustav %tasusta  )V_vA  <tasustama ;27_V	et	f	\N
196498	juznaja	?juznaja =juznaja  (SgN  >juznaja !01_S	et	f	\N
196499	juznaja	?juznaja =juznaja  (SgG  >juznaja !01_S	et	f	\N
196500	juznaja	?juznaja =juznaja  (SgG  >juznajas !02_A	et	f	\N
196510	belgorodi	### belgorodi	et	f	\N
196513	ukrainaga	### ukrainaga	et	f	\N
196520	marininski	?marininski =marininski  (IndPrPs_  >marininskima !28_V	et	f	\N
196521	marininski	?marininski =marininski  (ImpPrSg2  >marininskima !28_V	et	f	\N
196522	marininski	?marininski =ninski  (SgN  >mari+ninski !01_S	et	f	\N
196523	marininski	?marininski =ninski  (SgG  >mari+ninski !01_S	et	f	\N
196524	marininski	?marininski =ninski  (SgG  >mari+ninsk !22_S	et	f	\N
196525	marininski	?marininski =ninski  (SgP  >mari+ninsk !22_S	et	f	\N
196526	marininski	?marininski =ninski  (SgAdt  >mari+ninsk !22_S	et	f	\N
196527	marininski	?marininski =marinins  (SgN^  >marinins !22_S	et	f	\N
196528	marininski	?marininski =nins  (SgN^  >mari+nins !22_S	et	f	\N
196542	moskvase	?moskvase =moskvase  (SgG  >moskvane !12~10_A	et	f	\N
196548	punasel	punasel =punase  (SgAd  >punane !10_AS	et	f	\N
196549	punasel	"punane %puna  )NE_aA  <puna ;17_S	et	f	\N
196552	borodinskaja	?borodinskaja =borodinskaja  (SgN  >borodinskaja !01_S	et	f	\N
196553	borodinskaja	?borodinskaja =borodinskaja  (SgG  >borodinskaja !01_S	et	f	\N
196172	kõnelevatele	kõnelevatele =kõneleva  (PlAll  >kõnelev !02_A	et	f	\N
196173	kõnelevatele	"kõnelev %kõnele  )V_vA  <kõnelema ;27_V	et	f	\N
196174	kõnelevatele	"kõnelev %kõnele  )V_vA  <kõnelema ;31_V	et	f	\N
196185	õpetajatel	õpetajatel =õpetaja  (PlAd  >õpetaja !01_S	et	f	\N
196186	õpetajatel	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
196187	kolmes	kolmes =kolme  (SgIn  >kolm !22_N	et	f	\N
196188	kolmes	kolmes =kolme  (PlIn  >kolm !22_N	et	f	\N
196189	põhivormiks	põhivormiks =iks  (SgN  >põhi+vorm+iks !22_S	et	f	\N
196190	põhivormiks	põhivormiks =vormi  (SgTr  >põhi+vorm !22_S	et	f	\N
196201	tekitavaks	tekitavaks =tekitava  (SgTr  >tekitav !02_A	et	f	\N
196202	tekitavaks	"tekitav %teki  )TAV_vAS  <tekkima ;28_V	et	f	\N
196203	tekitavaks	"tekitav %tekita  )V_vA  <tekitama ;27_V	et	f	\N
196204	tekitavaks	tekitavaks =tava  (SgTr  >teki+tava !17_S	et	f	\N
196208	infinitiivvormi	?infinitiivvormi =infinitiivvormi  (SgG  >infinitiivvorm !22_S	et	f	\N
196209	infinitiivvormi	?infinitiivvormi =infinitiivvormi  (SgP  >infinitiivvorm !22_S	et	f	\N
196210	infinitiivvormi	?infinitiivvormi =infinitiivvormi  (SgAdt  >infinitiivvorm !22_S	et	f	\N
196211	infinitiivvormi	?infinitiivvormi =infinitiivvormi  (IndPrPs_  >infinitiivvormima !28_V	et	f	\N
196212	infinitiivvormi	?infinitiivvormi =infinitiivvormi  (ImpPrSg2  >infinitiivvormima !28_V	et	f	\N
196262	kõigides	?kõigides =kõigi  (PlIn  >kõigi !16_S	et	f	\N
196263	kõigides	?kõigides =kõigi  (PlIn  >kõig !22_S	et	f	\N
196264	kõigides	?kõigides =kõigi  (Ger  >kõigima !28_V	et	f	\N
196265	gruppiks	### gruppiks	et	f	\N
196291	pidata	?pidata =pida  (SgAb  >pida !17_S	et	f	\N
196292	pidata	?pidata =pidata  (IndPrPs_  >pidatama !27_V	et	f	\N
196293	pidata	?pidata =pidata  (ImpPrSg2  >pidatama !27_V	et	f	\N
196294	võimali	võimali =mali  (SgN  >või+mali !17_S	et	f	\N
196295	võimali	võimali =mali  (SgG  >või+mali !17_S	et	f	\N
196296	võimali	võimali =mali  (SgP  >või+mali !17_S	et	f	\N
196303	asendavad	asendavad =asenda  (IndPrPl3  >asendama !27_V	et	f	\N
196304	asendavad	asendavad =asendava  (PlN  >asendav !02_A	et	f	\N
196305	asendavad	"asendav %asenda  )V_vA  <asendama ;27_V	et	f	\N
196306	pojata	pojata =poja  (SgAb  >poja !17_S	et	f	\N
196307	pojata	pojata =poja  (SgAb  >poeg !22_S	et	f	\N
196337	suhtleid	suhtleid =lei  (PlN  >suht+lei !26_S	et	f	\N
196338	suhtleid	suhtleid =lei  (SgP  >suht+lei !26_S	et	f	\N
196339	suhtleid	suhtleid =leid  (SgN  >suht+leid !22_S	et	f	\N
196345	tasuvat	tasuvat =tasu  (KvtPrPs  >tasuma !27_V	et	f	\N
196346	tasuvat	tasuvat =tasuva  (SgP  >tasuv !02_A	et	f	\N
196347	tasuvat	"tasuv %tasu  )V_vA  <tasuma ;27_V	et	f	\N
196386	sünnitamist	sünnitamist =sünnitamis  (SgP  >sünnitamine !12_S	et	f	\N
196387	sünnitamist	"sünnitamine %sünnita  )MINE_vS  <sünnitama ;27_V	et	f	\N
196434	noorpaaril	?noorpaaril =noorpaari  (SgAd  >noorpaari !16_S	et	f	\N
196435	noorpaaril	?noorpaaril =noorpaari  (SgAd  >noorpaar !22_S	et	f	\N
196436	elubr	?elubr =elubr  (SgN  >elubr !22_S	et	f	\N
196441	tihemini	tihemini =mi  (SgTer  >tihe+mi !26_S	et	f	\N
196442	tihemini	tihemini =mini  (SgN  >tihe+mini !17~16_S	et	f	\N
196443	tihemini	tihemini =mini  (SgG  >tihe+mini !17~16_S	et	f	\N
196444	tihemini	tihemini =mini  (SgP  >tihe+mini !17_S	et	f	\N
196454	üleelamised	?üleelamised =üleelamise  (PlN  >üleelamine !12_S	et	f	\N
196455	misukused	?misukused =misukuse  (PlN  >misukus !11_S	et	f	\N
196456	misukused	?misukused =ukuse  (PlN  >mis+ukus !09_S	et	f	\N
196462	edukatöö	?edukatöö =edukatöö  (SgN  >edukatöö !26_S	et	f	\N
196463	edukatöö	?edukatöö =edukatöö  (SgG  >edukatöö !26_S	et	f	\N
196464	edukatöö	?edukatöö =katöö  (SgN  >edu+katöö !26_S	et	f	\N
196465	edukatöö	?edukatöö =katöö  (SgG  >edu+katöö !26_S	et	f	\N
196480	töökohata	töökohata =koha  (SgAb  >töö+koha !17_S	et	f	\N
196481	töökohata	töökohata =koha  (SgAb  >töö+koht !22_S	et	f	\N
196483	kõrgemalt	kõrgemalt =kõrgema  (SgAbl  >kõrgem !02_A	et	f	\N
196485	kõrgemalt	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
196487	kõrgemalt	kõrgemalt =kõrgemalt  (ID  >kõrgemalt !41_D	et	f	\N
196488	kõrgemalt	"kõrgemalt %kõrge  )MALT_mD  <kõrge ;01_A	et	f	\N
196489	kõrgemalt	"kõrgemalt %kõrgema  )LT_mD  <kõrgem ;02_A	et	f	\N
196490	kõrgemalt	kõrgemalt =ema  (SgAbl  >kõrg+ema !17_S	et	f	\N
196496	soodustuse	soodustuse =soodustuse  (SgG  >soodustus !11_S	et	f	\N
196497	soodustuse	"soodustus %soodusta  )US_vS  <soodustama ;27_V	et	f	\N
196501	museumit	?museumit =museumi  (SgP  >museumi !01_S	et	f	\N
196505	puskino	?puskino =puskino  (SgN  >puskino !01_S	et	f	\N
196506	puskino	?puskino =puskino  (SgG  >puskino !01_S	et	f	\N
196507	nägemisini	nägemisini =ini  (SgN  >nägemis+ini !17_S	et	f	\N
196508	nägemisini	nägemisini =ini  (SgG  >nägemis+ini !17_S	et	f	\N
196509	nägemisini	nägemisini =ini  (SgP  >nägemis+ini !17_S	et	f	\N
196511	piirmaa	piirmaa =maa  (SgN  >piir+maa !26_S	et	f	\N
196512	piirmaa	piirmaa =maa  (SgG  >piir+maa !26_S	et	f	\N
196514	peterburgini	?peterburgini =peterburgi  (SgTer  >peterburk !22_S	et	f	\N
196515	peterburgini	?peterburgini =peterburgini  (SgG  >peterburgin !02_S	et	f	\N
196518	klassisõbranna	klassisõbranna =sõbranna  (SgN  >klassi+sõbranna !16_S	et	f	\N
196194	akpekti	?akpekti =akpekti  (SgG  >akpekt !22_S	et	f	\N
196195	akpekti	?akpekti =akpekti  (SgP  >akpekt !22_S	et	f	\N
196196	akpekti	?akpekti =akpekti  (SgAdt  >akpekt !22_S	et	f	\N
196197	akpekti	?akpekti =akpekti  (IndPrPs_  >akpektima !28_V	et	f	\N
196198	akpekti	?akpekti =akpekti  (ImpPrSg2  >akpektima !28_V	et	f	\N
196219	eksitav	eksitav =eksi  (PtsPrIps  >eksima !28_V	et	f	\N
196220	eksitav	eksitav =eksita  (PtsPrPs  >eksitama !27_V	et	f	\N
196221	eksitav	eksitav =eksitav  (SgN  >eksitav !02_A	et	f	\N
196222	eksitav	"eksitav %eksi  )TAV_vAS  <eksima ;28_V	et	f	\N
196223	eksitav	"eksitav %eksita  )V_vA  <eksitama ;27_V	et	f	\N
196224	kõnelejat	kõnelejat =kõneleja  (SgP  >kõneleja !01_S	et	f	\N
196225	kõnelejat	"kõneleja %kõnele  )JA_vS  <kõnelema ;27_V	et	f	\N
196226	kõnelejat	"kõneleja %kõnele  )JA_vS  <kõnelema ;31_V	et	f	\N
196228	ininitiiv	?ininitiiv =ininitiiv  (SgN  >ininitiiv !22_S	et	f	\N
196229	õppimata	õppimata =õppi  (SupAb  >õppima !28_V	et	f	\N
196230	õppimata	õppimata =õppimata  (ID  >õppimata !41_A	et	f	\N
196231	õppimata	"õppimata %õppi  )MATA_vA  <õppima ;28_V	et	f	\N
196244	üksivus	?üksivus =üksivu  (SgIn  >üksivu !01_S	et	f	\N
196245	üksivus	?üksivus =üksivu  (IndIpfSg3  >üksivuma !27_V	et	f	\N
196246	üksivus	?üksivus =üksivus  (SgN  >üksivus !11_S	et	f	\N
196247	üksivus	?üksivus =ivu  (SgIn  >üks+ivu !17_S	et	f	\N
196248	üksivus	?üksivus =ivus  (SgN  >üks+ivus !09_S	et	f	\N
196256	süvaõpega	### süvaõpega	et	f	\N
196257	paraleellselt	?paraleellselt =paraleellse  (SgAbl  >paraleellne !02_A	et	f	\N
196258	paraleellselt	?paraleellselt =paraleellselt  (ID  >paraleellselt !41_D	et	f	\N
196259	paraleellselt	?paraleellselt =leellse  (SgAbl  >para+leellne !02_A	et	f	\N
196260	paraleellselt	?paraleellselt =leellse  (SgAbl  >para+leellse !06_S	et	f	\N
196261	paraleellselt	?paraleellselt =leellse  (PlAbl  >para+leells !22_S	et	f	\N
196266	sisenevad	sisenevad =sisene  (IndPrPl3  >sisenema !27_V	et	f	\N
196267	sisenevad	sisenevad =siseneva  (PlN  >sisenev !02_A	et	f	\N
196268	sisenevad	"sisenev %sisene  )V_vA  <sisenema ;27_V	et	f	\N
196269	vised	?vised =vise  (IndPrSg2  >visema !27_V	et	f	\N
196271	rõmsam	?rõmsam =rõmsam  (SgN  >rõmsam !02_A	et	f	\N
196272	tähtsis	?tähtsis =tähtsi  (SgIn  >tähts !22_S	et	f	\N
196273	tähtsis	?tähtsis =tähtsi  (IndIpfSg3  >tähtsima !28_V	et	f	\N
196274	tähtsis	?tähtsis =tähtsis  (SgN  >tähtsis !09_S	et	f	\N
196298	inimisel	?inimisel =inimise  (SgAd  >inimine !12_S	et	f	\N
196299	inimisel	?inimisel =isel  (SgN  >inim+isel !02_S	et	f	\N
196316	kirjasbr	?kirjasbr =kirjasbr  (SgN  >kirjasbr !22_S	et	f	\N
196317	typemoz	### typemoz	et	f	\N
196333	annad	annad =anna  (PlN  >anna !16_S	et	f	\N
196334	annad	annad =anna  (IndPrSg2  >andma !34_V	et	f	\N
196335	soed	soed =soe  (PlN  >susi !15_S	et	f	\N
196336	soed	soed =soe  (IndPrSg2  >sugema !28_V	et	f	\N
196351	mugavuseta	mugavuseta =mugavuse  (SgAb  >mugavus !11_S	et	f	\N
196352	mugavuseta	"mugavus %mugava  )US_aS  <mugav ;02_A	et	f	\N
196364	võrkeeli	?võrkeeli =võrkeeli  (SgN  >võrkeeli !16_S	et	f	\N
196365	võrkeeli	?võrkeeli =võrkeeli  (SgG  >võrkeeli !16_S	et	f	\N
196366	võrkeeli	?võrkeeli =võrkeeli  (SgG  >võrkeel !22_S	et	f	\N
196367	võrkeeli	?võrkeeli =võrkeeli  (SgP  >võrkeel !22_S	et	f	\N
196368	võrkeeli	?võrkeeli =võrkeeli  (SgAdt  >võrkeel !22_S	et	f	\N
196369	võrkeeli	?võrkeeli =võrkeeli  (IndPrPs_  >võrkeelima !28_V	et	f	\N
196370	võrkeeli	?võrkeeli =võrkeeli  (ImpPrSg2  >võrkeelima !28_V	et	f	\N
196371	õppilase	?õppilase =õppilase  (SgG  >õppilane !12_S	et	f	\N
196374	perekonnata	perekonnata =perekonna  (SgAb  >perekond !22_S	et	f	\N
196375	perekonnata	perekonnata =konna  (SgAb  >pere+konn !22_S	et	f	\N
196378	päikeseta	päikeseta =päikese  (SgAb  >päike !12?10_S	et	f	\N
196379	päikeseta	päikeseta =päikese  (SgAb  >päikene !12?10_S	et	f	\N
196380	inimsele	?inimsele =inimse  (SgAll  >inimne !02_A	et	f	\N
196381	inimsele	?inimsele =inimse  (PlAll  >inimss !22_S	et	f	\N
196382	inimsele	?inimsele =sele  (SgN  >inim+sele !16_S	et	f	\N
196383	inimsele	?inimsele =sele  (SgG  >inim+sele !16_S	et	f	\N
196392	koobades	?koobades =kooba  (PlIn  >kooba !16_S	et	f	\N
196403	kasvatusest	kasvatusest =kasvatuse  (SgEl  >kasvatus !11_S	et	f	\N
196404	kasvatusest	"kasvatus %kasvata  )US_vS  <kasvatama ;27_V	et	f	\N
196405	kasvatusest	"kasvatus %kasva  )TUS1_aS  <kasvama ;28_V	et	f	\N
196406	kasvatusest	kasvatusest =kasvatuses  (SgP  >kasvatusene !12_A	et	f	\N
196407	kasvatusest	"kasvatusene %kasvatuse  )NE_aA  <kasvatus ;11_S	et	f	\N
196424	säilitamise	säilitamise =säilitamise  (SgG  >säilitamine !12_S	et	f	\N
196425	säilitamise	"säilitamine %säilita  )MINE_vS  <säilitama ;27_V	et	f	\N
196447	lähimad	lähimad =lähima  (PlN  >lähim !02_A	et	f	\N
196448	lähimad	"lähim %lähi  )IM_sA  <lähike ;12_A	et	f	\N
196457	lomulikult	?lomulikult =lomuliku  (SgAbl  >lomulik !25_A	et	f	\N
196458	lomulikult	?lomulikult =lomulikult  (ID  >lomulikult !41_D	et	f	\N
196477	õhkuga	?õhkuga =uga  (SgN  >õhk+uga !17_S	et	f	\N
196478	õhkuga	?õhkuga =uga  (SgG  >õhk+uga !17_S	et	f	\N
196479	õhkuga	?õhkuga =uga  (SgP  >õhk+uga !17_S	et	f	\N
196297	oelpoolmainitutt	?oelpoolmainitutt =oelpoolmainitutt  (SgN  >oelpoolmainitutt !22_S	et	f	\N
196308	koras	?koras =kora  (SgIn  >kora !17_S	et	f	\N
196309	koras	?koras =kora  (IndIpfSg3  >korama !27_V	et	f	\N
196310	koras	?koras =koras  (SgN  >koras !09_S	et	f	\N
196311	õlda	?õlda =õlda  (SgN  >õlda !16_S	et	f	\N
196312	õlda	?õlda =õlda  (SgG  >õlda !16_S	et	f	\N
196313	õlda	?õlda =õlda  (IndPrPs_  >õldama !29_V	et	f	\N
196314	õlda	?õlda =õlda  (ImpPrSg2  >õldama !29_V	et	f	\N
196322	narkoga	?narkoga =narko  (SgKom  >narko !16_S	et	f	\N
196323	vanemadel	?vanemadel =ade  (SgAd  >vanem+ade !16_S	et	f	\N
196324	vanemadel	?vanemadel =adel  (SgN  >vanem+adel !02_S	et	f	\N
196327	kindlemini	?kindlemini =kindlemi  (SgTer  >kindlemi !01_S	et	f	\N
196328	kindlemini	?kindlemini =kindlemi  (SgTer  >kindlem !02_A	et	f	\N
196329	kindlemini	?kindlemini =kindlemini  (ID  >kindlemini !41_D	et	f	\N
196330	kindlemini	?kindlemini =kindlemini  (SgG  >kindlemin !19_S	et	f	\N
196331	kindlemini	?kindlemini =kindlemini  (SgP  >kindlemin !19_S	et	f	\N
196332	kindlemini	?kindlemini =kindlemini  (SgAdt  >kindlemin !19_S	et	f	\N
196340	suprudeta	?suprudeta =suprudeta  (IndPrPs_  >suprudetama !27_V	et	f	\N
196341	suprudeta	?suprudeta =suprudeta  (ImpPrSg2  >suprudetama !27_V	et	f	\N
196348	tutvuga	?tutvuga =tutvu  (SgKom  >tutvu !16_S	et	f	\N
196349	lahja	lahja =lahja  (SgN  >lahja !16_A	et	f	\N
196350	lahja	lahja =lahja  (SgG  >lahja !16_A	et	f	\N
196372	sideta	sideta =si  (PlAb  >si !26_S	et	f	\N
196373	sideta	sideta =side  (SgAb  >side !16_S	et	f	\N
196388	prognoosid	prognoosid =prognoosi  (PlN  >prognoos !22_S	et	f	\N
196389	prognoosid	prognoosid =prognoosi  (IndPrSg2  >prognoosima !28_V	et	f	\N
196393	säästmine	säästmine =säästmine  (SgN  >säästmine !12?10_S	et	f	\N
196394	säästmine	"säästmine %sääst  )MINE_vS  <säästma ;34_V	et	f	\N
196395	kasvuhoone	kasvuhoone =hoone  (SgN  >kasvu+hoone !06_S	et	f	\N
196396	kasvuhoone	"kasvu+hoone %hoo  )NE_aA  <kasvu+hoog ;22_S	et	f	\N
196397	kasvuhoone	kasvuhoone =hoone  (SgG  >kasvu+hoone !06_S	et	f	\N
196398	kasvuhoone	kasvuhoone =hoone  (PlP  >kasvu+hoon !22_A	et	f	\N
196400	infosüsteemi	infosüsteemi =süsteemi  (SgG  >info+süsteem !22_S	et	f	\N
196401	infosüsteemi	infosüsteemi =süsteemi  (SgP  >info+süsteem !22_S	et	f	\N
196402	infosüsteemi	infosüsteemi =süsteemi  (SgAdt  >info+süsteem !22_S	et	f	\N
196417	sõltumatust	sõltumatust =sõltumatu  (SgEl  >sõltumatu !01_A	et	f	\N
196418	sõltumatust	"sõltumatu %sõltu  )MATU_vA  <sõltuma ;27_V	et	f	\N
196419	sõltumatust	sõltumatust =sõltumatus  (SgP  >sõltumatus !11?09_S	et	f	\N
196420	sõltumatust	"sõltumatus %sõltu  )MATUS_aS  <sõltuma ;27_V	et	f	\N
196426	annavab	### annavab	et	f	\N
196427	teadustest	teadustest =teadus  (PlEl  >teadus !11~09_S	et	f	\N
196428	teadustest	teadustest =test  (SgN  >teadus+test !22_S	et	f	\N
196439	arvutiteta	arvutiteta =arvuti  (PlAb  >arvuti !01_S	et	f	\N
196440	arvutiteta	arvutiteta =tite  (SgAb  >arvu+titt !22_S	et	f	\N
196449	kaotused	kaotused =kaotuse  (PlN  >kaotus !11~09_S	et	f	\N
196450	kaotused	"kaotus %kaota  )US_vS  <kaotama ;27_V	et	f	\N
196451	kaotused	"kaotus %kao  )TUS1_aS  <kaduma ;28_V	et	f	\N
196452	kaotused	"kaotus %kao  )TUS2_aS  <kabu ;18_S	et	f	\N
196453	kaotused	"kaotus %kao  )TUS2_aS  <kadu ;18_S	et	f	\N
196473	inimine	inimine =ine  (SgN  >inim+ine !16_S	et	f	\N
196474	inimine	inimine =ine  (SgG  >inim+ine !16_S	et	f	\N
196475	terviga	?terviga =tervi  (SgKom  >tervi !16_S	et	f	\N
196476	terviga	?terviga =tervi  (SgKom  >terv !22_S	et	f	\N
196502	valjak	?valjak =valjak  (SgN  >valjak !02_S	et	f	\N
196556	leppime	### leppime	et	f	\N
196590	pikasilmi	pikasilmi =silmi  (SgG  >pika+silm !22_S	et	f	\N
196591	pikasilmi	pikasilmi =silmi  (SgP  >pika+silm !22_S	et	f	\N
196592	pikasilmi	pikasilmi =silmi  (SgAdt  >pika+silm !22_S	et	f	\N
196593	pikasilmi	pikasilmi =silmi  (PlP  >pika+silm !22_S	et	f	\N
196594	uudes	?uudes =uude  (PlIn  >uut !22_S	et	f	\N
196595	uudes	?uudes =uude  (IndIpfSg3  >uudema !27_V	et	f	\N
196596	uudes	?uudes =uudes  (SgN  >uudes !09_S	et	f	\N
196616	neljatoaline	neljatoaline =toaline  (SgN  >nelja+toaline !12?10_A	et	f	\N
196617	neljatoaline	"nelja+toaline %toa  )LINE_aA  <nelja+tuba ;18_S	et	f	\N
196622	sõitajan	?sõitajan =sõitajan  (SgN  >sõitajan !19_S	et	f	\N
196630	oraninbaumi	?oraninbaumi =oraninbaumi  (SgN  >oraninbaumi !16_S	et	f	\N
196631	oraninbaumi	?oraninbaumi =oraninbaumi  (SgG  >oraninbaumi !16_S	et	f	\N
196632	oraninbaumi	?oraninbaumi =oraninbaumi  (SgG  >oraninbaum !19_S	et	f	\N
196633	oraninbaumi	?oraninbaumi =oraninbaumi  (SgP  >oraninbaum !19_S	et	f	\N
196634	oraninbaumi	?oraninbaumi =oraninbaumi  (SgAdt  >oraninbaum !19_S	et	f	\N
196635	oraninbaumi	?oraninbaumi =oraninbaumi  (IndPrPs_  >oraninbaumima !28_V	et	f	\N
196636	oraninbaumi	?oraninbaumi =oraninbaumi  (ImpPrSg2  >oraninbaumima !28_V	et	f	\N
196642	õhtusööma	õhtusööma =sööma  (SgG  >õhtu+sööm !22_S	et	f	\N
196643	õhtusööma	õhtusööma =sööma  (SgP  >õhtu+sööm !22_S	et	f	\N
196644	õhtusööma	õhtusööma =sööma  (SgAdt  >õhtu+sööm !22_S	et	f	\N
196661	pilete	?pilete =pile  (IndPrPl2  >pilema !27_V	et	f	\N
196376	sõprata	?sõprata =sõprata  (IndPrPs_  >sõpratama !27_V	et	f	\N
196377	sõprata	?sõprata =sõprata  (ImpPrSg2  >sõpratama !27_V	et	f	\N
196384	vajalikum	vajalikum =vajalikum  (SgN  >vajalikum !02_A	et	f	\N
196385	vajalikum	"vajalikum %vajaliku  )M_cA  <vajalik ;25_A	et	f	\N
196408	haritatud	?haritatud =harita  (PtsPtIps  >haritama !27_V	et	f	\N
196409	haritatud	?haritatud =haritatu  (PlN  >haritatu !01_S	et	f	\N
196410	haritatud	?haritatud =haritatu  (IndPrSg2  >haritatuma !27_V	et	f	\N
196411	haritatud	?haritatud =haritatud  (ID  >haritatud !41_A	et	f	\N
196412	haritatud	?haritatud =tatu  (PlN  >hari+tatu !16_S	et	f	\N
196413	vaidelda	?vaidelda =vaidel  (Inf  >vaitlema !30_V	et	f	\N
196414	vaidelda	?vaidelda =vaidel  (IndPrIps_  >vaitlema !30_V	et	f	\N
196415	vaidelda	?vaidelda =vaidelda  (IndPrPs_  >vaideldama !27_V	et	f	\N
196416	vaidelda	?vaidelda =vaidelda  (ImpPrSg2  >vaideldama !27_V	et	f	\N
196421	maakera	maakera =kera  (SgN  >maa+kera !17_S	et	f	\N
196422	maakera	maakera =kera  (SgG  >maa+kera !17_S	et	f	\N
196423	maakera	maakera =kera  (SgP  >maa+kera !17_S	et	f	\N
196429	teistmeelised	teistmeelised =meelise  (PlN  >teist+meeline !10_A	et	f	\N
196430	teistmeelised	"teist+meeline %mee  )LINE_aA  <teist+mesi ;15_S	et	f	\N
196431	tehnikumisse	tehnikumisse =tehnikumi  (SgIll  >tehnikum !19_S	et	f	\N
196432	tehnikumisse	tehnikumisse =tehnikumis  (SgAdt  >tehnikumine !12_S	et	f	\N
196433	tehnikumisse	"tehnikumine %tehnikumi  )NE_aA  <tehnikum ;19_S	et	f	\N
196445	teenimine	teenimine =teenimine  (SgN  >teenimine !12_S	et	f	\N
196446	teenimine	"teenimine %teeni  )MINE_vS  <teenima ;28_V	et	f	\N
196459	töökogemusest	töökogemusest =kogemuse  (SgEl  >töö+kogemus !11_S	et	f	\N
196460	töökogemusest	töökogemusest =kogemuses  (SgP  >töö+kogemusene !12_A	et	f	\N
196461	töökogemusest	"töö+kogemusene %kogemuse  )NE_aA  <töö+kogemus ;11_S	et	f	\N
196467	bensini	?bensini =bensi  (SgTer  >bensi !16_S	et	f	\N
196468	bensini	?bensini =bensi  (SgTer  >benss !22_S	et	f	\N
196469	bensini	?bensini =bensini  (SgG  >bensin !02_S	et	f	\N
196491	allaga	### allaga	et	f	\N
196492	bööro	?bööro =bööro  (SgN  >bööro !16_S	et	f	\N
196493	bööro	?bööro =bööro  (SgG  >bööro !16_S	et	f	\N
196503	peatume	peatume =peatu  (IndPrPl1  >peatuma !27_V	et	f	\N
196504	peatume	peatume =tume  (SgN  >pea+tume !02_A	et	f	\N
196516	belgorodist	?belgorodist =belgorodis  (SgP  >belgorodis !09_S	et	f	\N
196517	belgorodist	?belgorodist =belgorodist  (SgN  >belgorodist !22_S	et	f	\N
196550	praga	praga =praga  (IndPrPs_  >pragama !27_V	et	f	\N
196551	praga	praga =praga  (ImpPrSg2  >pragama !27_V	et	f	\N
196558	nägamiseni	?nägamiseni =nägamise  (SgTer  >nägamine !12_S	et	f	\N
196559	nägamiseni	?nägamiseni =nägamiseni  (SgG  >nägamisen !19_S	et	f	\N
196560	nägamiseni	?nägamiseni =nägamiseni  (SgP  >nägamisen !19_S	et	f	\N
196561	nägamiseni	?nägamiseni =nägamiseni  (SgAdt  >nägamisen !19_S	et	f	\N
196570	võimalikus	võimalikus =võimaliku  (SgIn  >võimalik !25_A	et	f	\N
196571	võimalikus	võimalikus =võimalikus  (SgN  >võimalikus !11?09_S	et	f	\N
196572	võimalikus	"võimalikus %võimaliku  )US_aS  <võimalik ;25_A	et	f	\N
196575	kinglasti	kinglasti =lasti  (SgG  >king+last !22_S	et	f	\N
196576	kinglasti	kinglasti =lasti  (SgP  >king+last !22_S	et	f	\N
196577	kinglasti	kinglasti =lasti  (SgAdt  >king+last !22_S	et	f	\N
196597	iuli	?iuli =iuli  (SgN  >iuli !16_S	et	f	\N
196598	iuli	?iuli =iuli  (SgG  >iuli !16_S	et	f	\N
196599	iuli	?iuli =iuli  (SgG  >iul !22_S	et	f	\N
196600	iuli	?iuli =iuli  (SgP  >iul !22_S	et	f	\N
196601	iuli	?iuli =iuli  (SgAdt  >iul !22_S	et	f	\N
196602	iuli	?iuli =iuli  (IndPrPs_  >iulima !28_V	et	f	\N
196603	iuli	?iuli =iuli  (ImpPrSg2  >iulima !28_V	et	f	\N
196613	reisit	?reisit =reisit  (SgN  >reisit !02_S	et	f	\N
196639	petergoff	?petergoff =petergoff  (SgN  >petergoff !22_S	et	f	\N
196655	paleed	paleed =palee  (PlN  >palee !26_S	et	f	\N
196656	paleed	paleed =palee  (SgP  >palee !26_S	et	f	\N
196692	uueneik	?uueneik =uueneik  (SgN  >uueneik !22_S	et	f	\N
196693	uueneik	?uueneik =neik  (SgN  >uue+neik !22_S	et	f	\N
196699	museum	?museum =museum  (SgN  >museum !22_S	et	f	\N
196708	väsimus	väsimus =väsimus  (SgN  >väsimus !11_S	et	f	\N
196711	väsimus	"väsimus %väsi  )MUS_vS  <väsima ;27_V	et	f	\N
196727	meiga	?meiga =mei  (SgKom  >mei !26_S	et	f	\N
196728	meiga	?meiga =meiga  (SgN  >meiga !16_S	et	f	\N
196729	meiga	?meiga =meiga  (SgG  >meiga !16_S	et	f	\N
196730	meiga	?meiga =meiga  (IndPrPs_  >meigama !29_V	et	f	\N
196731	meiga	?meiga =meiga  (ImpPrSg2  >meigama !29_V	et	f	\N
196736	ocean	?ocean =ocean  (SgN  >ocean !19_S	et	f	\N
196757	ustjugist	?ustjugist =ustjugis  (SgP  >ustjugis !11_S	et	f	\N
196758	ustjugist	?ustjugist =ustjugist  (SgN  >ustjugist !22_S	et	f	\N
196759	laina	?laina =laina  (SgN  >laina !16_S	et	f	\N
196760	laina	?laina =laina  (SgG  >laina !16_S	et	f	\N
196761	laina	?laina =laina  (IndPrPs_  >lainama !29_V	et	f	\N
196762	laina	?laina =laina  (ImpPrSg2  >lainama !29_V	et	f	\N
196773	vesjegonskis	?vesjegonskis =vesjegonski  (IndIpfSg3  >vesjegonskima !28_V	et	f	\N
196494	travel	?travel =trave  (SgAd  >trave !16_S	et	f	\N
196495	travel	?travel =travel  (SgN  >travel !02_S	et	f	\N
196529	naitusele	?naitusele =naituse  (SgAll  >naitus !11~09_S	et	f	\N
196530	naitusele	?naitusele =naitusele  (PlP  >naitusel !19_S	et	f	\N
196563	küllalista	?küllalista =küllalista  (SgN  >küllalista !16_S	et	f	\N
196564	küllalista	?küllalista =küllalista  (SgG  >küllalista !16_S	et	f	\N
196565	küllalista	?küllalista =küllalista  (IndPrPs_  >küllalistama !27_V	et	f	\N
196566	küllalista	?küllalista =küllalista  (ImpPrSg2  >küllalistama !27_V	et	f	\N
196567	küllalista	?küllalista =lista  (SgN  >külla+lista !16_S	et	f	\N
196568	küllalista	?küllalista =lista  (SgG  >külla+lista !16_S	et	f	\N
196573	siksten	?siksten =sikste  (IndPrSg1  >sikstema !27_V	et	f	\N
196574	siksten	?siksten =siksten  (SgN  >siksten !02_S	et	f	\N
196612	välijak	### välijak	et	f	\N
196665	tervistustega	tervistustega =tervistus  (PlKom  >tervistus !11_S	et	f	\N
196666	tervistustega	"tervistus %tervista  )US_vS  <tervistama ;27_V	et	f	\N
196667	tervistustega	tervistustega =us  (PlKom  >tervist+uks !14_S	et	f	\N
196696	pühakupildid	?pühakupildid =pühakupildi  (IndPrSg2  >pühakupiltima !28_V	et	f	\N
196697	pühakupildid	?pühakupildid =kupildi  (PlN  >püha+kupildi !01_S	et	f	\N
196698	pühakupildid	?pühakupildid =kupildi  (PlN  >püha+kupild !02_S	et	f	\N
196702	kahekümnekaheksandal	?kahekümnekaheksandal =kahekümnekaheksanda  (SgAd  >kahekümnekaheksanda !16_S	et	f	\N
196703	kahekümnekaheksandal	?kahekümnekaheksandal =kahekümnekaheksandal  (SgN  >kahekümnekaheksandal !02_S	et	f	\N
196704	kahekümnekaheksandal	?kahekümnekaheksandal =ksanda  (SgAd  >kahe+kümne+kahe+ksanda !16_S	et	f	\N
196705	kahekümnekaheksandal	?kahekümnekaheksandal =ksandal  (SgN  >kahe+kümne+kahe+ksandal !02_S	et	f	\N
196706	kahekümnekaheksandal	?kahekümnekaheksandal =kaheksanda  (SgAd  >kahe+kümne+kaheksanda !16_S	et	f	\N
196707	kahekümnekaheksandal	?kahekümnekaheksandal =kaheksandal  (SgN  >kahe+kümne+kaheksandal !02_S	et	f	\N
196709	kahekümnekaheksandal	?kahekümnekaheksandal =kümnekaheksanda  (SgAd  >kahe+kümnekaheksanda !16_S	et	f	\N
196710	kahekümnekaheksandal	?kahekümnekaheksandal =kümnekaheksandal  (SgN  >kahe+kümnekaheksandal !02_S	et	f	\N
196712	uspenie	?uspenie =uspenie  (SgN  >uspenie !01_S	et	f	\N
196713	uspenie	?uspenie =uspenie  (SgG  >uspenie !01_S	et	f	\N
196733	tulas	?tulas =tula  (SgIn  >tula !17_S	et	f	\N
196734	tulas	?tulas =tula  (IndIpfSg3  >tulama !27_V	et	f	\N
196735	tulas	?tulas =tulas  (SgN  >tulas !09_S	et	f	\N
196749	ustjugi	?ustjugi =ustju  (SgN^  >ustju !01_S	et	f	\N
196750	ustjugi	?ustjugi =ustju  (SgG^  >ustju !01_S	et	f	\N
196751	ustjugi	?ustjugi =ustju  (IndPrPs_^  >ustjuma !27_V	et	f	\N
196752	ustjugi	?ustjugi =ustju  (ImpPrSg2^  >ustjuma !27_V	et	f	\N
196753	suhhona	?suhhona =suhho  (SgEs  >suhho !16_S	et	f	\N
196754	näärivana	näärivana =vana  (SgN  >nääri+vana !17_AS	et	f	\N
196755	näärivana	näärivana =vana  (SgG  >nääri+vana !17_AS	et	f	\N
196756	näärivana	näärivana =vana  (SgP  >nääri+vana !17_AS	et	f	\N
196772	julilis	?julilis =julilis  (SgN  >julilis !11_S	et	f	\N
196800	mousoleumi	?mousoleumi =mousoleumi  (SgN  >mousoleumi !16_S	et	f	\N
196801	mousoleumi	?mousoleumi =mousoleumi  (SgG  >mousoleumi !16_S	et	f	\N
196802	mousoleumi	?mousoleumi =mousoleumi  (SgG  >mousoleum !19_S	et	f	\N
196803	mousoleumi	?mousoleumi =mousoleumi  (SgP  >mousoleum !19_S	et	f	\N
196804	mousoleumi	?mousoleumi =mousoleumi  (SgAdt  >mousoleum !19_S	et	f	\N
196805	mousoleumi	?mousoleumi =mousoleumi  (IndPrPs_  >mousoleumima !28_V	et	f	\N
196806	mousoleumi	?mousoleumi =mousoleumi  (ImpPrSg2  >mousoleumima !28_V	et	f	\N
196814	puiestel	?puiestel =puies  (PlAd  >puiene !10_A	et	f	\N
196815	sõidata	?sõidata =sõida  (SgAb  >sõida !16_S	et	f	\N
196816	sõidata	?sõidata =sõidata  (IndPrPs_  >sõidatama !27_V	et	f	\N
196817	sõidata	?sõidata =sõidata  (ImpPrSg2  >sõidatama !27_V	et	f	\N
196818	maksasin	?maksasin =maksa  (IndIpfSg1  >maksama !29_V	et	f	\N
196819	maksasin	?maksasin =maksasin  (SgN  >maksasin !19_S	et	f	\N
196835	lopetan	?lopetan =lopeta  (IndPrSg1  >lopetama !27_V	et	f	\N
196836	lopetan	?lopetan =lopetan  (SgN  >lopetan !19_S	et	f	\N
196856	äide	?äide =äide  (SgN  >äide !06_S	et	f	\N
196857	äide	?äide =äide  (PlP  >äid !22_S	et	f	\N
196858	äide	?äide =äide  (IndPrPs_  >äidema !27_V	et	f	\N
196859	äide	?äide =äide  (ImpPrSg2  >äidema !27_V	et	f	\N
196860	eeldusi	eeldusi =eeldusi  (PlP  >eeldus !11_S	et	f	\N
196861	eeldusi	"eeldus %eelda  )US_vS  <eeldama ;27_V	et	f	\N
196867	eneseusku	eneseusku =usku  (SgP  >enese+usk !22_S	et	f	\N
196868	eneseusku	eneseusku =usku  (SgAdt  >enese+usk !22_S	et	f	\N
196869	täiendava	täiendava =täiendava  (SgG  >täiendav !02_A	et	f	\N
196870	täiendava	"täiendav %täienda  )V_vA  <täiendama ;27_V	et	f	\N
196871	täiendava	täiendava =ava  (SgN  >täiend+ava !17_S	et	f	\N
196872	täiendava	täiendava =ava  (SgG  >täiend+ava !17_S	et	f	\N
196873	täiendava	täiendava =ava  (SgP  >täiend+ava !17_S	et	f	\N
196874	vastuollu	?vastuollu =vastuollu  (IndPrPs_  >vastuolluma !27_V	et	f	\N
196875	vastuollu	?vastuollu =vastuollu  (ImpPrSg2  >vastuolluma !27_V	et	f	\N
196876	vastuollu	?vastuollu =ollu  (SgN  >vastu+ollu !16_S	et	f	\N
196519	klassisõbranna	klassisõbranna =sõbranna  (SgG  >klassi+sõbranna !16_S	et	f	\N
196531	kahekümnekuuenda	?kahekümnekuuenda =kahekümnekuuenda  (SgN  >kahekümnekuuenda !16_S	et	f	\N
196532	kahekümnekuuenda	?kahekümnekuuenda =kahekümnekuuenda  (SgG  >kahekümnekuuenda !16_S	et	f	\N
196533	kahekümnekuuenda	?kahekümnekuuenda =kahekümnekuuenda  (IndPrPs_  >kahekümnekuuendama !27_V	et	f	\N
196534	kahekümnekuuenda	?kahekümnekuuenda =kahekümnekuuenda  (ImpPrSg2  >kahekümnekuuendama !27_V	et	f	\N
196535	kahekümnekuuenda	?kahekümnekuuenda =kuuenda  (SgN  >kahe+kümne+kuuenda !01_S	et	f	\N
196536	kahekümnekuuenda	?kahekümnekuuenda =kuuenda  (SgG  >kahe+kümne+kuuenda !01_S	et	f	\N
196537	kahekümnekuuenda	?kahekümnekuuenda =kümnekuuenda  (SgN  >kahe+kümnekuuenda !16_S	et	f	\N
196538	kahekümnekuuenda	?kahekümnekuuenda =kümnekuuenda  (SgG  >kahe+kümnekuuenda !16_S	et	f	\N
196539	metro	?metro =metro  (SgN  >metro !16_S	et	f	\N
196540	metro	?metro =metro  (SgG  >metro !16_S	et	f	\N
196541	peterburise	?peterburise =peterburise  (SgG  >peterburis !09_S	et	f	\N
196543	turizmi	?turizmi =turizmi  (SgN  >turizmi !01_S	et	f	\N
196544	turizmi	?turizmi =turizmi  (SgG  >turizmi !01_S	et	f	\N
196545	turizmi	?turizmi =turizmi  (SgG  >turizm !22_S	et	f	\N
196546	turizmi	?turizmi =turizmi  (SgP  >turizm !22_S	et	f	\N
196547	turizmi	?turizmi =turizmi  (SgAdt  >turizm !22_S	et	f	\N
196555	panoram	?panoram =panoram  (SgN  >panoram !02_A	et	f	\N
196557	võttame	?võttame =võtta  (IndPrPl1  >võttama !29_V	et	f	\N
196562	sank	?sank =sank  (SgN  >sank !22_S	et	f	\N
196569	kolmtoalines	?kolmtoalines =lines  (SgN  >kolm+toa+lines !09_S	et	f	\N
196608	kindlastid	?kindlastid =kindlasti  (IndPrSg2  >kindlastima !28_V	et	f	\N
196614	nagemisine	?nagemisine =nagemisine  (SgN  >nagemisine !12_A	et	f	\N
196615	nagemisine	?nagemisine =nagemisine  (PlP  >nagemisin !19_S	et	f	\N
196618	vanaviisi	vanaviisi =viisi  (SgG  >vana+viis !22_S	et	f	\N
196619	vanaviisi	vanaviisi =viisi  (SgP  >vana+viis !22_S	et	f	\N
196620	vanaviisi	vanaviisi =viisi  (SgAdt  >vana+viis !22_S	et	f	\N
196621	speterburgis	?speterburgis =speterburgi  (SgIn  >speterburk !22_S	et	f	\N
196623	speterburgis	?speterburgis =speterburgi  (IndIpfSg3  >speterburgima !28_V	et	f	\N
196624	speterburgis	?speterburgis =speterburgis  (SgN  >speterburgis !09_S	et	f	\N
196637	pavlovi	?pavlovi =pavlovi  (ID  >pavlovi !41_D	et	f	\N
196638	pavlovi	?pavlovi =pavlovi  (SgG  >pavlov !02_A	et	f	\N
196640	kaunid	kaunid =kauni  (PlN  >kaunis !05~07_A	et	f	\N
196641	kaunid	kaunid =kauni  (PlN  >kaun !22_S	et	f	\N
196646	ekateriini	?ekateriini =ekaterii  (SgTer  >ekaterii !26_S	et	f	\N
196648	ekateriini	?ekateriini =ekateriini  (SgN  >ekateriini !16_S	et	f	\N
196649	ekateriini	?ekateriini =ekateriini  (SgG  >ekateriini !16_S	et	f	\N
196650	ekateriini	?ekateriini =ekateriini  (SgG  >ekateriin !22_S	et	f	\N
196651	ekateriini	?ekateriini =ekateriini  (SgP  >ekateriin !22_S	et	f	\N
196652	ekateriini	?ekateriini =ekateriini  (SgAdt  >ekateriin !22_S	et	f	\N
196653	ekateriini	?ekateriini =ekateriini  (IndPrPs_  >ekateriinima !28_V	et	f	\N
196654	ekateriini	?ekateriini =ekateriini  (ImpPrSg2  >ekateriinima !28_V	et	f	\N
196659	sõitajame	?sõitajame =jame  (SgN  >sõita+jame !16_S	et	f	\N
196660	sõitajame	?sõitajame =jame  (SgG  >sõita+jame !16_S	et	f	\N
196662	speterburgist	?speterburgist =speterburgi  (SgEl  >speterburk !22_S	et	f	\N
196663	speterburgist	?speterburgist =speterburgis  (SgP  >speterburgis !09_S	et	f	\N
196664	speterburgist	?speterburgist =speterburgist  (SgN  >speterburgist !22_S	et	f	\N
196671	ksenii	?ksenii =ksenii  (SgN  >ksenii !26_S	et	f	\N
196672	ksenii	?ksenii =ksenii  (SgG  >ksenii !26_S	et	f	\N
196694	relikviad	?relikviad =relikvia  (PlN  >relikvia !01_S	et	f	\N
196695	relikviad	?relikviad =relikviad  (SgN  >relikviad !22_S	et	f	\N
196700	punas	punas =puna  (SgIn  >puna !17_S	et	f	\N
196701	punas	punas =puna  (IndIpfSg3  >punama !27_V	et	f	\N
196715	küsimast	küsimast =küsi  (SupEl  >küsima !27_V	et	f	\N
196716	küsimast	küsimast =mast  (SgN  >küsi+mast !22_S	et	f	\N
196717	sõdame	?sõdame =sõda  (IndPrPl1  >sõdama !27_V	et	f	\N
196725	kahekümneks	?kahekümneks =kahekümne  (PlTr  >kahekümn !22_S	et	f	\N
196726	kahekümneks	?kahekümneks =kümne  (PlTr  >kahe+kümn !22_S	et	f	\N
196737	platside	platside =platsi  (PlG  >plats !22_S	et	f	\N
196738	platside	platside =si  (PlG  >plat+si !26_S	et	f	\N
196739	platside	platside =side  (SgN  >plat+side !04_S	et	f	\N
196740	platside	platside =side  (SgN  >plat+side !16_S	et	f	\N
196741	platside	platside =side  (SgG  >plat+side !16_S	et	f	\N
196744	veliki	?veliki =veliki  (SgN  >veliki !01_S	et	f	\N
196745	veliki	?veliki =veliki  (SgG  >veliki !01_S	et	f	\N
196746	veliki	?veliki =veliki  (SgG  >velik !02_S	et	f	\N
196747	veliki	?veliki =veliki  (IndPrPs_  >velikkima !28_V	et	f	\N
196748	veliki	?veliki =veliki  (ImpPrSg2  >velikkima !28_V	et	f	\N
196764	poliklinikus	?poliklinikus =polikliniku  (SgIn  >poliklinik !02_S	et	f	\N
196766	poliklinikus	?poliklinikus =polikliniku  (IndIpfSg3  >poliklinikuma !27_V	et	f	\N
196768	poliklinikus	?poliklinikus =poliklinikus  (SgN  >poliklinikus !11?09_S	et	f	\N
196799	esimisest	?esimisest =esimise  (SgEl  >esimine !12_S	et	f	\N
196820	muuseums	?muuseums =muuseums  (SgN  >muuseums !22_S	et	f	\N
196554	borodinskaja	?borodinskaja =borodinskaja  (SgG  >borodinskajas !02_A	et	f	\N
196578	muusiumi	?muusiumi =muusiumi  (SgN  >muusiumi !16_S	et	f	\N
196579	muusiumi	?muusiumi =muusiumi  (SgG  >muusium !19~02_S	et	f	\N
196580	muusiumi	?muusiumi =muusiumi  (SgG  >muusiumi !16_S	et	f	\N
196581	muusiumi	?muusiumi =muusiumi  (SgP  >muusium !19_S	et	f	\N
196582	muusiumi	?muusiumi =muusiumi  (SgAdt  >muusium !19_S	et	f	\N
196583	muusiumi	?muusiumi =muusiumi  (IndPrPs_  >muusiumima !28_V	et	f	\N
196584	muusiumi	?muusiumi =muusiumi  (ImpPrSg2  >muusiumima !28_V	et	f	\N
196585	muusiumi	?muusiumi =siumi  (SgN  >muu+siumi !16_S	et	f	\N
196586	muusiumi	?muusiumi =siumi  (SgG  >muu+siumi !16_S	et	f	\N
196587	muusiumi	?muusiumi =siumi  (SgG  >muu+sium !22_S	et	f	\N
196588	muusiumi	?muusiumi =siumi  (SgP  >muu+sium !22_S	et	f	\N
196589	muusiumi	?muusiumi =siumi  (SgAdt  >muu+sium !22_S	et	f	\N
196604	muuseimi	muuseimi =seimi  (SgG  >muu+seim !22_S	et	f	\N
196605	muuseimi	muuseimi =seimi  (SgP  >muu+seim !22_S	et	f	\N
196606	muuseimi	muuseimi =seimi  (SgAdt  >muu+seim !22_S	et	f	\N
196607	bilettid	?bilettid =biletti  (PlN  >biletti !01_S	et	f	\N
196609	jaalutama	?jaalutama =jaalu  (SupIps  >jaaluma !28_V	et	f	\N
196610	jaalutama	?jaalutama =jaaluta  (Sup  >jaalutama !27_V	et	f	\N
196611	jaalutama	?jaalutama =jaalutama  (SgG  >jaalutam !02_A	et	f	\N
196625	juulist	juulist =juuli  (SgEl  >juuli !16_S	et	f	\N
196626	juulist	juulist =juulis  (SgP  >juuline !10_A	et	f	\N
196627	juulist	"juuline %juuli  )NE_aA  <juuli ;16_S	et	f	\N
196628	lossie	?lossie =lossie  (SgN  >lossie !01_S	et	f	\N
196629	lossie	?lossie =lossie  (SgG  >lossie !01_S	et	f	\N
196645	palee	palee =palee  (SgN  >palee !26_S	et	f	\N
196647	palee	palee =palee  (SgG  >palee !26_S	et	f	\N
196657	hommikusöökid	?hommikusöökid =hommikusööki  (PlN  >hommikusööki !16_S	et	f	\N
196658	hommikusöökid	?hommikusöökid =usööki  (PlN  >hommik+usööki !16_S	et	f	\N
196673	siinagoogi	?siinagoogi =siinagoogi  (SgN  >siinagoogi !16_S	et	f	\N
196674	siinagoogi	?siinagoogi =siinagoogi  (SgG  >siinagoogi !16_S	et	f	\N
196675	siinagoogi	?siinagoogi =siinagoogi  (SgG  >siinagoog !22_S	et	f	\N
196676	siinagoogi	?siinagoogi =siinagoogi  (SgP  >siinagoog !22_S	et	f	\N
196677	siinagoogi	?siinagoogi =siinagoogi  (SgAdt  >siinagoog !22_S	et	f	\N
196678	siinagoogi	?siinagoogi =siinagoogi  (IndPrPs_  >siinagoogima !28_V	et	f	\N
196679	siinagoogi	?siinagoogi =siinagoogi  (ImpPrSg2  >siinagoogima !28_V	et	f	\N
196680	siinagoogi	?siinagoogi =agoogi  (SgN  >siin+agoogi !16_S	et	f	\N
196681	siinagoogi	?siinagoogi =agoogi  (SgG  >siin+agoogi !16_S	et	f	\N
196682	siinagoogi	?siinagoogi =agoogi  (SgG  >siin+agoog !22_S	et	f	\N
196683	siinagoogi	?siinagoogi =agoogi  (SgP  >siin+agoog !22_S	et	f	\N
196684	siinagoogi	?siinagoogi =agoogi  (SgAdt  >siin+agoog !22_S	et	f	\N
196685	siinagoogi	?siinagoogi =siinagoo  (SgN^  >siinagoo !26_S	et	f	\N
196686	siinagoogi	?siinagoogi =siinagoo  (SgG^  >siinagoo !26_S	et	f	\N
196687	siinagoogi	?siinagoogi =agoo  (SgN^  >siin+agoo !26_S	et	f	\N
196688	siinagoogi	?siinagoogi =agoo  (SgG^  >siin+agoo !26_S	et	f	\N
196718	adleri	?adleri =adleri  (SgN  >adleri !01_S	et	f	\N
196719	adleri	?adleri =adleri  (SgG  >adleri !01_S	et	f	\N
196720	adleri	?adleri =adleri  (SgG  >adler !02_S	et	f	\N
196763	vanavisi	?vanavisi =vanavisi  (PlP  >vanavis !11_S	et	f	\N
196765	vanavisi	?vanavisi =visi  (SgN  >vana+visi !17_S	et	f	\N
196767	vanavisi	?vanavisi =visi  (SgG  >vana+visi !17_S	et	f	\N
196769	vanavisi	?vanavisi =visi  (SgP  >vana+visi !17_S	et	f	\N
196770	tuhan	?tuhan =tuha  (IndPrSg1  >tuhama !27_V	et	f	\N
196771	tuhan	?tuhan =tuhan  (SgN  >tuhan !02_S	et	f	\N
196775	korrusee	?korrusee =korrusee  (SgN  >korrusee !26_S	et	f	\N
196776	korrusee	?korrusee =korrusee  (SgG  >korrusee !26_S	et	f	\N
196779	kurski	?kurski =kurski  (SgN  >kurski !01_S	et	f	\N
196780	kurski	?kurski =kurski  (SgG  >kurski !01_S	et	f	\N
196781	kurski	?kurski =kurski  (SgG  >kursk !22_S	et	f	\N
196782	kurski	?kurski =kurski  (SgP  >kursk !22_S	et	f	\N
196783	kurski	?kurski =kurski  (SgAdt  >kursk !22_S	et	f	\N
196784	kurski	?kurski =kurski  (IndPrPs_  >kurskima !28_V	et	f	\N
196785	kurski	?kurski =kurski  (ImpPrSg2  >kurskima !28_V	et	f	\N
196786	kurski	?kurski =kurs  (SgN^  >kurs !22_S	et	f	\N
196787	zooparkii	?zooparkii =zooparkii  (SgN  >zooparkii !26_S	et	f	\N
196788	zooparkii	?zooparkii =zooparkii  (SgG  >zooparkii !26_S	et	f	\N
196789	zooparkii	?zooparkii =parkii  (SgN  >zoo+parkii !26_S	et	f	\N
196790	zooparkii	?zooparkii =parkii  (SgG  >zoo+parkii !26_S	et	f	\N
196807	köime	?köime =köime  (SgN  >köime !06_S	et	f	\N
196808	köime	?köime =köime  (SgG  >köime !06_S	et	f	\N
196809	köime	?köime =köime  (PlP  >köim !22_S	et	f	\N
196810	köime	?köime =köime  (IndPrPs_  >köimema !27_V	et	f	\N
196811	köime	?köime =köime  (ImpPrSg2  >köimema !27_V	et	f	\N
196880	äpardusi	äpardusi =äpardusi  (PlP  >äpardus !11_S	et	f	\N
196881	äpardusi	"äpardus %äparda  )US_vS  <äpardama ;27_V	et	f	\N
196886	saavutamisel	saavutamisel =saavutamise  (SgAd  >saavutamine !12_S	et	f	\N
196887	saavutamisel	"saavutamine %saavuta  )MINE_vS  <saavutama ;27_V	et	f	\N
196668	venekondus	?venekondus =venekondu  (IndIpfSg3  >venekonduma !27_V	et	f	\N
196669	venekondus	?venekondus =venekondus  (SgN  >venekondus !11_S	et	f	\N
196670	venekondus	?venekondus =kondus  (SgN  >vene+kondus !11~09_S	et	f	\N
196689	moskas	?moskas =moska  (SgIn  >moska !16_S	et	f	\N
196690	moskas	?moskas =moska  (IndIpfSg3  >moskama !29_V	et	f	\N
196691	moskas	?moskas =moskas  (SgN  >moskas !07_S	et	f	\N
196714	kakstuhat	?kakstuhat =kakstuha  (SgP  >kakstuha !01_S	et	f	\N
196721	normalne	?normalne =normalne  (SgN  >normalne !02_A	et	f	\N
196722	normalne	?normalne =normalne  (PlP  >normaln !22_S	et	f	\N
196723	normalne	?normalne =alne  (SgN  >norm+alne !02_A	et	f	\N
196724	normalne	?normalne =alne  (PlP  >norm+aln !22_S	et	f	\N
196732	jatkub	?jatkub =jatku  (IndPrSg3  >jatkuma !27_V	et	f	\N
196742	vologda	?vologda =vologda  (SgN  >vologda !01_S	et	f	\N
196743	vologda	?vologda =vologda  (SgG  >vologda !01_S	et	f	\N
196777	leningradist	?leningradist =leningradis  (SgP  >leningradis !09_S	et	f	\N
196778	leningradist	?leningradist =leningradist  (SgN  >leningradist !22_S	et	f	\N
196791	kurskis	?kurskis =kurski  (SgIn  >kurski !01_S	et	f	\N
196792	kurskis	?kurskis =kurski  (SgIn  >kursk !22_S	et	f	\N
196793	kurskis	?kurskis =kurski  (IndIpfSg3  >kurskima !28_V	et	f	\N
196794	kurskis	?kurskis =kurskis  (SgN  >kurskis !09_S	et	f	\N
196837	täti	?täti =täti  (SgN  >täti !16_S	et	f	\N
196838	täti	?täti =täti  (SgG  >täti !16_S	et	f	\N
196839	täti	?täti =täti  (SgG  >tätt !22_S	et	f	\N
196840	täti	?täti =täti  (IndPrPs_  >tätima !27_V	et	f	\N
196841	täti	?täti =täti  (IndPrPs_  >tättima !28_V	et	f	\N
196842	täti	?täti =täti  (ImpPrSg2  >tätima !27_V	et	f	\N
196843	täti	?täti =täti  (ImpPrSg2  >tättima !28_V	et	f	\N
196854	kahekümneni	?kahekümneni =kahekümneni  (SgG  >kahekümnen !02_S	et	f	\N
196855	kahekümneni	?kahekümneni =kümneni  (SgG  >kahe+kümnen !02_S	et	f	\N
196862	avardunud	avardunud =avardu  (PtsPtPs  >avarduma !27_V	et	f	\N
196863	avardunud	avardunud =avardunu  (PlN  >avardunu !01_S	et	f	\N
196864	avardunud	"avardunu %avardu  )NU_vS  <avarduma ;27_V	et	f	\N
196865	avardunud	avardunud =avardunud  (ID  >avardunud !41_A	et	f	\N
196866	avardunud	"avardunud %avardu  )NUD_vA  <avarduma ;27_V	et	f	\N
196893	isesesvuslikuks	?isesesvuslikuks =isesesvusliku  (SgTr  >isesesvuslik !25_A	et	f	\N
196894	isesesvuslikuks	?isesesvuslikuks =isesesvusliku  (KndPrPs  >isesesvuslikuma !27_V	et	f	\N
196895	isesesvuslikuks	?isesesvuslikuks =sesvusliku  (SgTr  >ise+sesvuslik !25_A	et	f	\N
196905	püüdlikus	püüdlikus =püüdliku  (SgIn  >püüdlik !25_A	et	f	\N
196906	püüdlikus	püüdlikus =püüdlikus  (SgN  >püüdlikus !11_S	et	f	\N
196907	püüdlikus	"püüdlikus %püüdliku  )US_aS  <püüdlik ;25_A	et	f	\N
196925	lõpetadaaga	?lõpetadaaga =lõpetadaa  (SgKom  >lõpetadaa !26_S	et	f	\N
196926	lõpetadaaga	?lõpetadaaga =lõpetadaaga  (SgN  >lõpetadaaga !16_S	et	f	\N
196927	lõpetadaaga	?lõpetadaaga =lõpetadaaga  (SgG  >lõpetadaaga !16_S	et	f	\N
196949	seaduseidinimesikodumaal	?seaduseidinimesikodumaal =seaduseidinimesikodumaa  (SgAd  >seaduseidinimesikodumaa !26_S	et	f	\N
196950	seaduseidinimesikodumaal	?seaduseidinimesikodumaal =seaduseidinimesikodumaal  (SgN  >seaduseidinimesikodumaal !22_S	et	f	\N
196951	seaduseidinimesikodumaal	?seaduseidinimesikodumaal =dinimesikodumaa  (SgAd  >seadus+ei+dinimesikodumaa !26_S	et	f	\N
196952	seaduseidinimesikodumaal	?seaduseidinimesikodumaal =dinimesikodumaal  (SgN  >seadus+ei+dinimesikodumaal !22_S	et	f	\N
196953	seaduseidinimesikodumaal	?seaduseidinimesikodumaal =idinimesikodumaa  (SgAd  >seaduse+idinimesikodumaa !26_S	et	f	\N
196954	seaduseidinimesikodumaal	?seaduseidinimesikodumaal =idinimesikodumaal  (SgN  >seaduse+idinimesikodumaal !22_S	et	f	\N
196955	seaduseidinimesikodumaal	?seaduseidinimesikodumaal =eidinimesikodumaa  (SgAd  >seadus+eidinimesikodumaa !26_S	et	f	\N
196956	seaduseidinimesikodumaal	?seaduseidinimesikodumaal =eidinimesikodumaal  (SgN  >seadus+eidinimesikodumaal !22_S	et	f	\N
196957	seaduseidinimesikodumaal	?seaduseidinimesikodumaal =duseidinimesikodumaa  (SgAd  >sea+duseidinimesikodumaa !26_S	et	f	\N
196958	seaduseidinimesikodumaal	?seaduseidinimesikodumaal =duseidinimesikodumaal  (SgN  >sea+duseidinimesikodumaal !22_S	et	f	\N
196975	värtusta	?värtusta =värtusta  (SgN  >värtusta !01_S	et	f	\N
196976	värtusta	?värtusta =värtusta  (SgG  >värtusta !01_S	et	f	\N
196977	värtusta	?värtusta =värtusta  (IndPrPs_  >värtustama !27_V	et	f	\N
196978	värtusta	?värtusta =värtusta  (ImpPrSg2  >värtustama !27_V	et	f	\N
196989	eesmäkite	?eesmäkite =eesmäki  (PlG  >eesmäki !01_S	et	f	\N
196990	eesmäkite	?eesmäkite =eesmäki  (IndPrPl2  >eesmäkkima !28_V	et	f	\N
197002	õpiimine	?õpiimine =õpiimine  (SgN  >õpiimine !10_A	et	f	\N
197004	õpiimine	?õpiimine =imine  (SgN  >õpi+imine !10_A	et	f	\N
197009	noormatselt	noormatselt =matse  (PlAbl  >noor+mats !22_S	et	f	\N
197010	noormatselt	noormatselt =matse  (PlAbl  >noor+mats !22_SA	et	f	\N
197016	lugetud	?lugetud =lugetu  (PlN  >lugetu !01_AS	et	f	\N
197017	lugetud	?lugetud =lugetu  (IndPrSg2  >lugetuma !27_V	et	f	\N
197018	lugetud	?lugetud =lugetud  (ID  >lugetud !41_A	et	f	\N
197026	meeletust	meeletust =meeletu  (SgEl  >meeletu !01_A	et	f	\N
197027	meeletust	"meeletu %meele  )TU2_kA  <meel ;13_S	et	f	\N
197028	meeletust	meeletust =meeletus  (SgP  >meeletus !11_S	et	f	\N
197029	meeletust	"meeletus %meele  )TUS2_aS  <meel ;13_S	et	f	\N
196774	vesjegonskis	?vesjegonskis =vesjegonskis  (SgN  >vesjegonskis !09_S	et	f	\N
196795	helli	helli =helli  (SgG  >hell !22_A	et	f	\N
196796	helli	helli =helli  (SgP  >hell !22_A	et	f	\N
196797	helli	helli =helli  (SgAdt  >hell !22_A	et	f	\N
196798	helli	helli =helli  (PlP  >hell !22_A	et	f	\N
196812	jarel	?jarel =jare  (SgAd  >jare !16_S	et	f	\N
196813	jarel	?jarel =jarel  (SgN  >jarel !02_S	et	f	\N
196825	nägemisem	?nägemisem =nägemisem  (SgN  >nägemisem !02_A	et	f	\N
196832	purskkaevad	?purskkaevad =purskkaeva  (PlN  >purskkaeva !01_S	et	f	\N
196833	purskkaevad	?purskkaevad =kaeva  (PlN  >pursk+kaeva !16_S	et	f	\N
196846	täti	?täti =täti  (SgN  >täti !16_S	et	f	\N
196847	täti	?täti =täti  (SgG  >täti !16_S	et	f	\N
196848	täti	?täti =täti  (SgG  >tätt !22_S	et	f	\N
196849	täti	?täti =täti  (IndPrPs_  >tätima !27_V	et	f	\N
196850	täti	?täti =täti  (IndPrPs_  >tättima !28_V	et	f	\N
196851	täti	?täti =täti  (ImpPrSg2  >tätima !27_V	et	f	\N
196852	täti	?täti =täti  (ImpPrSg2  >tättima !28_V	et	f	\N
196853	juurs	?juurs =juurs  (SgN  >juurs !22_S	et	f	\N
196891	heasuhtlemisaldis	heasuhtlemisaldis =aldi  (SgIn  >hea+suhtlemis+alt !22_S	et	f	\N
196892	heasuhtlemisaldis	heasuhtlemisaldis =aldis  (SgN  >hea+suhtlemis+aldis !07_A	et	f	\N
196899	häasti	?häasti =häasti  (ID  >häasti !41_D	et	f	\N
196900	häasti	?häasti =häasti  (SgG  >häast !22_S	et	f	\N
196901	häasti	?häasti =häasti  (SgP  >häast !22_S	et	f	\N
196902	häasti	?häasti =häasti  (SgAdt  >häast !22_S	et	f	\N
196903	häasti	?häasti =häasti  (IndPrPs_  >häastima !28_V	et	f	\N
196904	häasti	?häasti =häasti  (ImpPrSg2  >häastima !28_V	et	f	\N
196908	võimalikusse	võimalikusse =võimaliku  (SgIll  >võimalik !25_A	et	f	\N
196909	võimalikusse	võimalikusse =võimalikus  (SgAdt  >võimalikus !11_S	et	f	\N
196910	võimalikusse	"võimalikus %võimaliku  )US_aS  <võimalik ;25_A	et	f	\N
196911	vajalikut	### vajalikut	et	f	\N
196916	õpenguid	?õpenguid =õpengu  (PlP  >õpengu !01_S	et	f	\N
196917	õpenguid	?õpenguid =õpengu  (PlP  >õpeng !02_S	et	f	\N
196918	õpenguid	?õpenguid =õpengui  (PlN  >õpengui !26_S	et	f	\N
196919	õpenguid	?õpenguid =õpengui  (SgP  >õpengui !26_S	et	f	\N
196928	probleemidainult	?probleemidainult =probleemidainu  (SgAbl  >probleemidainu !01_S	et	f	\N
196929	probleemidainult	?probleemidainult =probleemidainult  (ID  >probleemidainult !41_D	et	f	\N
196930	probleemidainult	?probleemidainult =inu  (SgAbl  >probleem+ida+inu !17_S	et	f	\N
196931	probleemidainult	?probleemidainult =dainu  (SgAbl  >probleemi+dainu !16_S	et	f	\N
196932	probleemidainult	?probleemidainult =idainu  (SgAbl  >probleem+idainu !01_S	et	f	\N
196940	töötadasest	?töötadasest =töötadase  (SgEl  >töötadane !12_A	et	f	\N
196941	töötadasest	?töötadasest =töötadases  (SgP  >töötadasene !12_A	et	f	\N
196942	töötadasest	?töötadasest =dase  (SgEl  >tööta+dase !16_S	et	f	\N
196943	töötadasest	?töötadasest =dases  (SgP  >tööta+dases !09_S	et	f	\N
196944	töötadasest	?töötadasest =dases  (SgP  >tööta+dasene !10_A	et	f	\N
196945	töötadasest	?töötadasest =tadase  (SgEl  >töö+tadane !10_A	et	f	\N
196946	töötadasest	?töötadasest =tadases  (SgP  >töö+tadasene !12_A	et	f	\N
196961	ülikoolisei	?ülikoolisei =ülikoolisei  (SgN  >ülikoolisei !26_S	et	f	\N
196962	ülikoolisei	?ülikoolisei =ülikoolisei  (SgG  >ülikoolisei !26_S	et	f	\N
196963	ülikoolisei	?ülikoolisei =sei  (SgN  >üli+kooli+sei !26_S	et	f	\N
196964	ülikoolisei	?ülikoolisei =sei  (SgG  >üli+kooli+sei !26_S	et	f	\N
196965	ülikoolisei	?ülikoolisei =isei  (SgN  >üli+kool+isei !26_S	et	f	\N
196966	ülikoolisei	?ülikoolisei =isei  (SgG  >üli+kool+isei !26_S	et	f	\N
196967	ülikoolisei	?ülikoolisei =koolisei  (SgN  >üli+koolisei !26_S	et	f	\N
196968	ülikoolisei	?ülikoolisei =koolisei  (SgG  >üli+koolisei !26_S	et	f	\N
196991	märksalt	?märksalt =märksalt  (ID  >märksalt !41_D	et	f	\N
196999	seepaärast	?seepaärast =seepaära  (SgEl  >seepaära !01_S	et	f	\N
197000	seepaärast	?seepaärast =seepaäras  (SgP  >seepaärane !12_A	et	f	\N
197001	seepaärast	?seepaärast =paära  (SgEl  >see+paära !16_S	et	f	\N
197003	seepaärast	?seepaärast =paäras  (SgP  >see+paäras !07_S	et	f	\N
197005	seepaärast	?seepaärast =paäras  (SgP  >see+paärane !10_A	et	f	\N
197019	huvitatus	huvitatus =huvitatu  (SgIn  >huvitatu !01_S	et	f	\N
197020	huvitatus	"huvitatu %huvita  )TU1_vS  <huvitama ;27_V	et	f	\N
197021	huvitatus	huvitatus =huvitatus  (SgN  >huvitatus !11?09_S	et	f	\N
197022	huvitatus	"huvitatus %huvita  )TUS1_aS  <huvitama ;27_V	et	f	\N
197041	kahelt	kahelt =kahe  (SgAbl  >kaks !22_N	et	f	\N
197042	kahelt	kahelt =kahe  (PlAbl  >kahk !22_S	et	f	\N
197070	tsentreeritud	tsentreeritud =tsentreeri  (PtsPtIps  >tsentreerima !28_V	et	f	\N
197071	tsentreeritud	tsentreeritud =tsentreeritu  (PlN  >tsentreeritu !01_S	et	f	\N
197072	tsentreeritud	"tsentreeritu %tsentreeri  )TU1_vS  <tsentreerima ;28_V	et	f	\N
197073	tsentreeritud	tsentreeritud =tsentreeritud  (ID  >tsentreeritud !41_A	et	f	\N
197074	tsentreeritud	"tsentreeritud %tsentreeri  )TUD_vA  <tsentreerima ;28_V	et	f	\N
197080	semikoolon	?semikoolon =semikoolon  (SgN  >semikoolon !02_S	et	f	\N
197090	tiia-mai	tiia-mai =mai  (SgN  >tiia-mai !26_S	et	f	\N
196821	muuseums	?muuseums =seums  (SgN  >muu+seums !22_S	et	f	\N
196822	vaatamisvarsast	vaatamisvarsast =varsa  (SgEl  >vaatamis+varss !22_S	et	f	\N
196823	vaatamisvarsast	vaatamisvarsast =varsas  (SgP  >vaatamis+varsane !10_A	et	f	\N
196824	vaatamisvarsast	"vaatamis+varsane %varsa  )NE_aA  <vaatamis+varss ;22_S	et	f	\N
196826	ekskursionid	?ekskursionid =ekskursioni  (PlN  >ekskursion !19~02_S	et	f	\N
196827	ekskursionid	?ekskursionid =ekskursioni  (PlN  >ekskursioni !16_S	et	f	\N
196828	ekskursionid	?ekskursionid =ekskursioni  (IndPrSg2  >ekskursionima !28_V	et	f	\N
196829	ekskursionid	?ekskursionid =oni  (PlN  >eks+kursi+oni !17_S	et	f	\N
196830	ekskursionid	?ekskursionid =kursioni  (PlN  >eks+kursion !19~02_S	et	f	\N
196831	ekskursionid	?ekskursionid =kursioni  (PlN  >eks+kursioni !16_S	et	f	\N
196834	olib	?olib =oli  (IndPrSg3  >olima !27_V	et	f	\N
196844	kosmonauti	kosmonauti =kosmonauti  (SgP  >kosmonaut !22_S	et	f	\N
196845	kosmonauti	kosmonauti =kosmonauti  (SgAdt  >kosmonaut !22_S	et	f	\N
196882	elueesmärgi	elueesmärgi =märgi  (SgG  >elu+ees+märk !22_S	et	f	\N
196883	elueesmärgi	elueesmärgi =märgi  (SgP  >elu+ees+märg !22_AS	et	f	\N
196884	elueesmärgi	elueesmärgi =märgi  (SgAdt  >elu+ees+märg !22_AS	et	f	\N
196885	elueesmärgi	elueesmärgi =märgi  (PlP  >elu+ees+märg !22_AS	et	f	\N
196888	arvutitöötada	?arvutitöötada =tada  (SgN  >arvuti+töö+tada !17_S	et	f	\N
196889	arvutitöötada	?arvutitöötada =tada  (SgG  >arvuti+töö+tada !17_S	et	f	\N
196890	arvutitöötada	?arvutitöötada =tada  (SgP  >arvuti+töö+tada !17_S	et	f	\N
196915	eksamidel	?eksamidel =ami  (PlAd  >eks+ami !17_S	et	f	\N
196920	1miks	miks =mi  (SgTr  >mi !26_S	et	f	\N
196921	1miks	miks =miks  (ID  >miks !41_D	et	f	\N
196937	õppidaeestis	?õppidaeestis =õppidaeesti  (IndIpfSg3  >õppidaeestima !28_V	et	f	\N
196938	õppidaeestis	?õppidaeestis =õppidaeestis  (SgN  >õppidaeestis !09_S	et	f	\N
196971	sellepärastet	### sellepärastet	et	f	\N
196979	haridussest	?haridussest =haridusse  (SgEl  >haridusne !02_A	et	f	\N
196980	haridussest	?haridussest =haridusse  (PlEl  >hariduss !22_S	et	f	\N
196981	haridussest	?haridussest =haridusses  (SgP  >haridussene !12_A	et	f	\N
196982	haridussest	?haridussest =dusse  (SgEl  >hari+dusne !02_A	et	f	\N
196983	haridussest	?haridussest =dusse  (SgEl  >hari+dusse !06_S	et	f	\N
196984	haridussest	?haridussest =dusse  (PlEl  >hari+duss !22_S	et	f	\N
196985	haridussest	?haridussest =dusses  (SgP  >hari+dusses !09_S	et	f	\N
196986	haridussest	?haridussest =dusses  (SgP  >hari+dussene !10_A	et	f	\N
197011	eruditsiooni	eruditsiooni =eruditsiooni  (SgG  >eruditsioon !22_S	et	f	\N
197012	eruditsiooni	eruditsiooni =eruditsiooni  (SgP  >eruditsioon !22_S	et	f	\N
197013	eruditsiooni	eruditsiooni =eruditsiooni  (SgAdt  >eruditsioon !22_S	et	f	\N
197023	raevust	raevust =raevu  (SgEl  >raev !22_S	et	f	\N
197024	raevust	raevust =raevus  (SgP  >raevune !10_A	et	f	\N
197025	raevust	"raevune %raevu  )NE_aA  <raev ;22_S	et	f	\N
197032	sooritamisest	sooritamisest =sooritamise  (SgEl  >sooritamine !12_S	et	f	\N
197033	sooritamisest	"sooritamine %soorita  )MINE_vS  <sooritama ;27_V	et	f	\N
197044	vegas	?vegas =vega  (SgIn  >vega !17_S	et	f	\N
197045	vegas	?vegas =vega  (IndIpfSg3  >vegama !27_V	et	f	\N
197046	vegas	?vegas =vegas  (SgN  >vegas !07_S	et	f	\N
197048	subtiitri	subtiitri =subtiitri  (SgG  >subtiiter !02_S	et	f	\N
197049	subtiitri	subtiitri =tiitri  (SgG  >sub+tiiter !02_S	et	f	\N
197057	löödud	löödud =löö  (PtsPtIps  >lööma !38_V	et	f	\N
197058	löödud	löödud =löödu  (PlN  >löödu !01_S	et	f	\N
197059	löödud	"löödu %löö  )TU1_vS  <lööma ;38_V	et	f	\N
197060	löödud	löödud =löödud  (ID  >löödud !41_A	et	f	\N
197061	löödud	"löödud %löö  )TUD_vA  <lööma ;38_V	et	f	\N
197063	kaherealine	kaherealine =realine  (SgN  >kahe+realine !12?10_A	et	f	\N
197065	kaherealine	"kahe+realine %rea  )LINE_aA  <kahe+rida ;18_S	et	f	\N
197075	poolitamine	poolitamine =poolitamine  (SgN  >poolitamine !12_S	et	f	\N
197076	poolitamine	"poolitamine %poolita  )MINE_vS  <poolitama ;27_V	et	f	\N
197085	teksi	teksi =teksi  (SgG  >teks !22_S	et	f	\N
197086	teksi	teksi =teksi  (SgP  >teks !22_S	et	f	\N
197087	teksi	teksi =teksi  (SgAdt  >teks !22_S	et	f	\N
197100	dokumentaalsari	dokumentaalsari =sari  (SgN  >dokumentaal+sari !17_S	et	f	\N
197102	dokumentaalsari	dokumentaalsari =sari  (SgN  >dokumentaal+sari !24_S	et	f	\N
197104	dokumentaalsari	dokumentaalsari =sari  (SgG  >dokumentaal+sari !17_S	et	f	\N
197105	dokumentaalsari	dokumentaalsari =sari  (SgP  >dokumentaal+sari !17_S	et	f	\N
197114	asetati	asetati =aseta  (IndIpfIps  >asetama !27_V	et	f	\N
197115	asetati	asetati =ati  (SgG  >aset+att !22_S	et	f	\N
197116	asetati	asetati =tati  (SgG  >ase+tatt !22_S	et	f	\N
197125	subtiitriga	subtiitriga =subtiitri  (SgKom  >subtiiter !02_S	et	f	\N
197126	subtiitriga	subtiitriga =tiitri  (SgKom  >sub+tiiter !02_S	et	f	\N
197132	rita	?rita =rita  (SgN  >rita !16_S	et	f	\N
197133	rita	?rita =rita  (SgG  >rita !16_S	et	f	\N
197134	rita	?rita =rita  (IndPrPs_  >ritama !27_V	et	f	\N
197135	rita	?rita =rita  (ImpPrSg2  >ritama !27_V	et	f	\N
197158	huvialasid	huvialasid =ala  (PlP  >huvi+ala !17_S	et	f	\N
197159	huvialasid	huvialasid =alasi  (PlN  >huvi+alasi !01_S	et	f	\N
196877	vastuollu	?vastuollu =ollu  (SgG  >vastu+ollu !16_S	et	f	\N
196878	vastuollu	?vastuollu =uollu  (SgN  >vast+uollu !01_S	et	f	\N
196879	vastuollu	?vastuollu =uollu  (SgG  >vast+uollu !01_S	et	f	\N
196896	õppeala	õppeala =ala  (SgN  >õppe+ala !17_S	et	f	\N
196897	õppeala	õppeala =ala  (SgG  >õppe+ala !17_S	et	f	\N
196898	õppeala	õppeala =ala  (SgP  >õppe+ala !17_S	et	f	\N
196912	püstisasid	püstisasid =sasi  (PlN  >püsti+sasi !17_S	et	f	\N
196913	püstisasid	püstisasid =isa  (PlP  >püst+isa !17_S	et	f	\N
196922	õpinsest	?õpinsest =õpinse  (SgEl  >õpinne !02_A	et	f	\N
196923	õpinsest	?õpinsest =õpinse  (PlEl  >õpinss !22_S	et	f	\N
196924	õpinsest	?õpinsest =õpinses  (SgP  >õpinsene !12_A	et	f	\N
196933	õppekoormuspalju	?õppekoormuspalju =õppekoormuspalju  (IndPrPs_  >õppekoormuspaljuma !27_V	et	f	\N
196934	õppekoormuspalju	?õppekoormuspalju =õppekoormuspalju  (ImpPrSg2  >õppekoormuspaljuma !27_V	et	f	\N
196935	õppekoormuspalju	?õppekoormuspalju =muspalju  (SgN  >õppe+koor+muspalju !01_S	et	f	\N
196936	õppekoormuspalju	?õppekoormuspalju =muspalju  (SgG  >õppe+koor+muspalju !01_S	et	f	\N
196972	värtustavad	?värtustavad =värtusta  (IndPrPl3  >värtustama !27_V	et	f	\N
196973	värtustavad	?värtustavad =värtustava  (PlN  >värtustav !02_A	et	f	\N
196974	värtustavad	?värtustavad =värtustava  (PlN  >värtustava !16_S	et	f	\N
196987	diskool	?diskool =diskoo  (SgAd  >diskoo !26_S	et	f	\N
196988	diskool	?diskool =diskool  (SgN  >diskool !22_S	et	f	\N
196992	vähenenult	vähenenult =vähenenu  (SgAbl  >vähenenu !01_S	et	f	\N
196993	vähenenult	"vähenenu %vähene  )NU_vS  <vähenema ;27_V	et	f	\N
196994	vähenenult	vähenenult =vähenenult  (ID  >vähenenult !41_D	et	f	\N
196995	vähenenult	"vähenenult %vähene  )NULT_mD  <vähenema ;27_V	et	f	\N
197014	teamised	?teamised =teamise  (PlN  >teamine !10_A	et	f	\N
197015	teamised	?teamised =teamise  (IndPrSg2  >teamisema !27_V	et	f	\N
197077	semantiliselt	semantiliselt =semantilise  (SgAbl  >semantiline !12_A	et	f	\N
197078	semantiliselt	semantiliselt =semantiliselt  (ID  >semantiliselt !41_D	et	f	\N
197079	semantiliselt	"semantiliselt %semantilise  )LT_mD  <semantiline ;12_A	et	f	\N
197081	samasuguselt	samasuguselt =suguse  (SgAbl  >sama+sugune !10_P	et	f	\N
197082	samasuguselt	"sama+suguselt %suguse  )LT_mD  <sama+sugune ;10_A	et	f	\N
197088	veaks	veaks =vea  (SgTr  >viga !18_S	et	f	\N
197089	veaks	veaks =vea  (KndPrPs  >vedama !28_V	et	f	\N
197092	dokumentaalsari	dokumentaalsari =sari  (SgN  >dokumentaal+sari !17_S	et	f	\N
197093	dokumentaalsari	dokumentaalsari =sari  (SgN  >dokumentaal+sari !24_S	et	f	\N
197094	dokumentaalsari	dokumentaalsari =sari  (SgG  >dokumentaal+sari !17_S	et	f	\N
197095	dokumentaalsari	dokumentaalsari =sari  (SgP  >dokumentaal+sari !17_S	et	f	\N
197136	talson	?talson =talson  (SgN  >talson !02_S	et	f	\N
197151	mõniga	### mõniga	et	f	\N
197152	astumiseni	astumiseni =astumise  (SgTer  >astumine !12_S	et	f	\N
197153	astumiseni	"astumine %astu  )MINE_vS  <astuma ;28_V	et	f	\N
197156	sisetunde	sisetunde =tunde  (SgG  >sise+tunne !06_S	et	f	\N
197157	sisetunde	sisetunde =tunde  (PlP  >sise+tund !22_S	et	f	\N
197177	rabelemata	rabelemata =rabele  (SupAb  >rabelema !31~27_V	et	f	\N
197178	rabelemata	rabelemata =rabelemata  (ID  >rabelemata !41_A	et	f	\N
197179	rabelemata	"rabelemata %rabele  )MATA_vA  <rabelema ;27_V	et	f	\N
197180	rabelemata	"rabelemata %rabele  )MATA_vA  <rabelema ;31_V	et	f	\N
197184	18-aastased	-aastased =aastase  (PlN  >-aastane !12~10_A	et	f	\N
197185	18-aastased	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
197186	teistkümnetunniseid	teistkümnetunniseid =tunnise  (PlP  >teist+kümne+tunnine !10_A	et	f	\N
197187	teistkümnetunniseid	"teist+kümne+tunnine %tunni  )NE_aA  <teist+kümne+tund ;22_S	et	f	\N
197219	keskonnakaitsja	?keskonnakaitsja =keskonnakaitsja  (SgN  >keskonnakaitsja !16_S	et	f	\N
197220	keskonnakaitsja	?keskonnakaitsja =keskonnakaitsja  (SgG  >keskonnakaitsjas !02_A	et	f	\N
197221	keskonnakaitsja	?keskonnakaitsja =keskonnakaitsja  (SgG  >keskonnakaitsja !16_S	et	f	\N
197222	keskonnakaitsja	?keskonnakaitsja =onnakaitsja  (SgN  >kesk+onnakaitsja !16_S	et	f	\N
197223	keskonnakaitsja	?keskonnakaitsja =onnakaitsja  (SgG  >kesk+onnakaitsjas !02_A	et	f	\N
197224	keskonnakaitsja	?keskonnakaitsja =onnakaitsja  (SgG  >kesk+onnakaitsja !16_S	et	f	\N
197225	artid	### artid	et	f	\N
197226	rahulikkut	?rahulikkut =ikkut  (SgN  >rahul+ikkut !02_S	et	f	\N
197231	hoolitsev	hoolitsev =hoolitse  (PtsPrPs  >hoolitsema !27_V	et	f	\N
197232	hoolitsev	hoolitsev =hoolitsev  (SgN  >hoolitsev !02_A	et	f	\N
197233	hoolitsev	"hoolitsev %hoolitse  )V_vA  <hoolitsema ;27_V	et	f	\N
197234	tänavasel	tänavasel =tänavase  (SgAd  >tänavane !12_A	et	f	\N
197235	tänavasel	"tänavane %tänava  )NE_aA  <tänav ;02_S	et	f	\N
197236	tänavasel	tänavasel =vase  (SgAd  >täna+vask !22_S	et	f	\N
197242	noordest	?noordest =noorde  (PlEl  >noort !22_S	et	f	\N
197243	noordest	?noordest =noordes  (SgP  >noordes !09_S	et	f	\N
197244	noordest	?noordest =noordes  (SgP  >noordene !12~10_A	et	f	\N
197249	tõttamist	tõttamist =tõttamis  (SgP  >tõttamine !12_S	et	f	\N
197250	tõttamist	"tõttamine %tõtta  )MINE_vS  <tõttama ;29_V	et	f	\N
197256	kriminaaliga	kriminaaliga =iga  (SgN  >kriminaal+iga !18_S	et	f	\N
197257	kriminaaliga	kriminaaliga =iga  (SgP  >kriminaal+iga !18_S	et	f	\N
196914	hinned	?hinned =hinne  (IndPrSg2  >hinnema !27_V	et	f	\N
196939	arvanet	?arvanet =ane  (SgP  >arv+ane !16_S	et	f	\N
196947	kõiktean	?kõiktean =kõiktean  (SgN  >kõiktean !19_S	et	f	\N
196948	kõiktean	?kõiktean =tean  (SgN  >kõik+tean !22_S	et	f	\N
196959	õppidaei	?õppidaei =õppidaei  (SgN  >õppidaei !26_S	et	f	\N
196960	õppidaei	?õppidaei =õppidaei  (SgG  >õppidaei !26_S	et	f	\N
196969	5miks	miks =mi  (SgTr  >mi !26_S	et	f	\N
196970	5miks	miks =miks  (ID  >miks !41_D	et	f	\N
196996	konkreetstele	?konkreetstele =konkreetste  (PlAll  >konkreetst !22_S	et	f	\N
196997	konkreetstele	?konkreetstele =konkreetstele  (IndPrPs_  >konkreetstelema !36_V	et	f	\N
196998	konkreetstele	?konkreetstele =konkreetstele  (ImpPrSg2  >konkreetstelema !36_V	et	f	\N
197006	soiskus	?soiskus =soisku  (SgIn  >soisku !01_S	et	f	\N
197007	soiskus	?soiskus =soisku  (IndIpfSg3  >soiskuma !27_V	et	f	\N
197008	soiskus	?soiskus =soiskus  (SgN  >soiskus !11~09_S	et	f	\N
197043	robinsons	?robinsons =robinsons  (SgN  >robinsons !22_S	et	f	\N
197050	sünkroonis	?sünkroonis =sünkrooni  (SgIn  >sünkrooni !16_S	et	f	\N
197051	sünkroonis	?sünkroonis =sünkrooni  (SgIn  >sünkroon !22_S	et	f	\N
197052	sünkroonis	?sünkroonis =sünkrooni  (IndIpfSg3  >sünkroonima !28_V	et	f	\N
197053	sünkroonis	?sünkroonis =sünkroonis  (SgN  >sünkroonis !09_S	et	f	\N
197054	sünkroonis	?sünkroonis =rooni  (SgIn  >sünk+rooni !16_S	et	f	\N
197055	sünkroonis	?sünkroonis =rooni  (SgIn  >sünk+roon !22_S	et	f	\N
197056	sünkroonis	?sünkroonis =roonis  (SgN  >sünk+roonis !09_S	et	f	\N
197062	ekraani	ekraani =ekraani  (SgG  >ekraan !22_S	et	f	\N
197064	ekraani	ekraani =ekraani  (SgP  >ekraan !22_S	et	f	\N
197066	ekraani	ekraani =ekraani  (SgAdt  >ekraan !22_S	et	f	\N
197067	ülemine	ülemine =ülemine  (SgN  >ülemine !12_A	et	f	\N
197068	ülemine	ülemine =ine  (SgN  >ülem+ine !16_S	et	f	\N
197069	ülemine	ülemine =ine  (SgG  >ülem+ine !16_S	et	f	\N
197127	piisavad	piisavad =piisa  (IndPrPl3  >piisama !29_V	et	f	\N
197128	piisavad	piisavad =piisava  (PlN  >piisav !02_A	et	f	\N
197129	piisavad	"piisav %piisa  )V_vA  <piisama ;29_V	et	f	\N
197130	tõlkijad	tõlkijad =tõlkija  (PlN  >tõlkija !01_S	et	f	\N
197131	tõlkijad	"tõlkija %tõlki  )JA_vS  <tõlkima ;28_V	et	f	\N
197137	makki	makki =makki  (SgP  >makk !22_S	et	f	\N
197138	makki	makki =makki  (SgAdt  >makk !22_S	et	f	\N
197139	lapsehoidja	lapsehoidja =hoidja  (SgN  >lapse+hoidja !01_S	et	f	\N
197140	lapsehoidja	lapsehoidja =hoidja  (SgG  >lapse+hoidja !01_S	et	f	\N
197147	huvatavat	?huvatavat =huva  (KvtPrIps  >huvama !27_V	et	f	\N
197148	huvatavat	?huvatavat =huvata  (KvtPrPs  >huvatama !27_V	et	f	\N
197149	huvatavat	?huvatavat =huvatava  (SgP  >huvatav !02_A	et	f	\N
197150	huvatavat	?huvatavat =huvatava  (SgP  >huvatava !16_S	et	f	\N
197175	algkoolis	algkoolis =kooli  (SgIn  >alg+kool !22_S	et	f	\N
197176	algkoolis	algkoolis =kooli  (PlIn  >alg+kool !22_S	et	f	\N
197182	rapsimisi	rapsimisi =rapsimisi  (PlP  >rapsimine !12_S	et	f	\N
197183	rapsimisi	"rapsimine %rapsi  )MINE_vS  <rapsima ;28_V	et	f	\N
197192	kogetud	kogetud =koge  (PtsPtIps  >kogema !27_V	et	f	\N
197193	kogetud	kogetud =kogetu  (PlN  >kogetu !01_AS	et	f	\N
197194	kogetud	"kogetu %koge  )TU1_vS  <kogema ;27_V	et	f	\N
197195	kogetud	"kogetu %koge  )TU2_kA  <koge ;16_S	et	f	\N
197196	kogetud	kogetud =kogetud  (ID  >kogetud !41_A	et	f	\N
197197	kogetud	"kogetud %koge  )TUD_vA  <kogema ;27_V	et	f	\N
197198	stabiilsus	stabiilsus =stabiilsus  (SgN  >stabiilsus !11~09_S	et	f	\N
197199	stabiilsus	"stabiilsus %stabiilse  )US_aS  <stabiilne ;02_A	et	f	\N
197207	tulekust	tulekust =tuleku  (SgEl  >tulek !02_S	et	f	\N
197208	tulekust	tulekust =kus  (SgP  >tule+kusi !20_S	et	f	\N
197248	terveslik	?terveslik =terveslik  (SgN  >terveslik !25_A	et	f	\N
197265	avatude	?avatude =tude  (SgN  >ava+tude !16_S	et	f	\N
197266	avatude	?avatude =tude  (SgG  >ava+tude !16_S	et	f	\N
197269	kahetsetav	kahetsetav =kahetse  (PtsPrIps  >kahetsema !27_V	et	f	\N
197270	kahetsetav	kahetsetav =kahetsetav  (SgN  >kahetsetav !02_A	et	f	\N
197271	kahetsetav	"kahetsetav %kahetse  )TAV_vAS  <kahetsema ;27_V	et	f	\N
197288	audenteses	?audenteses =audentese  (SgIn  >audentene !12_A	et	f	\N
197291	audenteses	?audenteses =dentese  (SgIn  >au+dentene !12~10_A	et	f	\N
197303	kolamanda	?kolamanda =kolamanda  (SgN  >kolamanda !16_S	et	f	\N
197304	kolamanda	?kolamanda =kolamanda  (SgG  >kolamanda !16_S	et	f	\N
197305	kolamanda	?kolamanda =kolamanda  (IndPrPs_  >kolamandama !27_V	et	f	\N
197306	kolamanda	?kolamanda =kolamanda  (ImpPrSg2  >kolamandama !27_V	et	f	\N
197345	mineval	mineval =mineva  (SgAd  >minev !02_A	et	f	\N
197346	mineval	"minev %mine  )V_vA  <minema ;36_V	et	f	\N
197365	ruhm	?ruhm =ruhm  (SgN  >ruhm !22_S	et	f	\N
197376	vanemadega	?vanemadega =ade  (SgKom  >vanem+ade !16_S	et	f	\N
197402	tuupiliselt	?tuupiliselt =tuupilise  (SgAbl  >tuupiline !12_A	et	f	\N
197403	tuupiliselt	?tuupiliselt =tuupiliselt  (ID  >tuupiliselt !41_D	et	f	\N
197446	tuulevad	?tuulevad =tuule  (IndPrPl3  >tuulema !27_V	et	f	\N
197447	tuulevad	?tuulevad =tuuleva  (PlN  >tuuleva !01_S	et	f	\N
197448	tuulevad	?tuulevad =tuuleva  (PlN  >tuulev !02_A	et	f	\N
197030	meeletust	meeletust =tust  (SgN  >meele+tust !22_S	et	f	\N
197031	meeletust	meeletust =letu  (SgEl  >mee+letu !16_S	et	f	\N
197034	paksust	paksust =paksu  (SgEl  >paks !22_AS	et	f	\N
197035	paksust	paksust =paksus  (SgP  >paksus !11~09_S	et	f	\N
197036	paksust	"paksus %paks  )US_aS  <paks ;22_AS	et	f	\N
197037	paksust	paksust =paksus  (SgP  >paksune !10~12_A	et	f	\N
197038	paksust	paksust =us  (SgP  >paks+uks !14_S	et	f	\N
197039	üüs	?üüs =üü  (SgIn  >üü !26_S	et	f	\N
197040	üüs	?üüs =üüs  (SgN  >üüs !22_S	et	f	\N
197047	2s	### 2s	et	f	\N
197083	subtiitril	subtiitril =subtiitri  (SgAd  >subtiiter !02_S	et	f	\N
197084	subtiitril	subtiitril =tiitri  (SgAd  >sub+tiiter !02_S	et	f	\N
197101	lastetaltsutaja	lastetaltsutaja =taltsutaja  (SgN  >laste+taltsutaja !01_S	et	f	\N
197103	lastetaltsutaja	lastetaltsutaja =taltsutaja  (SgG  >laste+taltsutaja !01_S	et	f	\N
197106	seriaali	seriaali =seriaali  (SgG  >seriaal !22_S	et	f	\N
197107	seriaali	seriaali =seriaali  (SgP  >seriaal !22_S	et	f	\N
197108	seriaali	seriaali =seriaali  (SgAdt  >seriaal !22_S	et	f	\N
197111	kõneleva	kõneleva =kõneleva  (SgG  >kõnelev !02_A	et	f	\N
197112	kõneleva	"kõnelev %kõnele  )V_vA  <kõnelema ;27_V	et	f	\N
197113	kõneleva	"kõnelev %kõnele  )V_vA  <kõnelema ;31_V	et	f	\N
197154	arvestus	arvestus =arvestus  (SgN  >arvestus !11_S	et	f	\N
197155	arvestus	"arvestus %arvesta  )US_vS  <arvestama ;27_V	et	f	\N
197163	kõndivad	kõndivad =kõndiva  (PlN  >kõndiv !02_A	et	f	\N
197164	kõndivad	"kõndiv %kõndi  )V_vA  <kõndima ;28_V	et	f	\N
197181	liisida	?liisida =liisi  (Inf  >liisima !28_V	et	f	\N
197203	ome	?ome =ome  (SgN  >ome !16_S	et	f	\N
197204	ome	?ome =ome  (SgG  >ome !16_S	et	f	\N
197205	ome	?ome =ome  (IndPrPs_  >omema !27_V	et	f	\N
197206	ome	?ome =ome  (ImpPrSg2  >omema !27_V	et	f	\N
197209	kaalepp	?kaalepp =kaalepp  (SgN  >kaalepp !22_S	et	f	\N
197210	ekspressis	ekspressis =ekspressi  (SgIn  >ekspress !22_S	et	f	\N
197211	ekspressis	ekspressis =pressi  (SgIn  >eks+press !22_S	et	f	\N
197215	loterii	loterii =loterii  (SgN  >loterii !26_S	et	f	\N
197216	loterii	loterii =loterii  (SgG  >loterii !26_S	et	f	\N
197237	töökogtadele	### töökogtadele	et	f	\N
197238	üldne	?üldne =üldne  (SgN  >üldne !02_A	et	f	\N
197239	üldne	?üldne =üldne  (PlP  >üldn !22_S	et	f	\N
197240	üldne	?üldne =üldne  (IndPrPs_  >üldnema !27_V	et	f	\N
197241	üldne	?üldne =üldne  (ImpPrSg2  >üldnema !27_V	et	f	\N
197245	validakse	?validakse =validakse  (SgG  >validakne !02_A	et	f	\N
197278	niisamas	?niisamas =niisa  (SupIn  >niisama !29_V	et	f	\N
197279	niisamas	?niisamas =niisama  (SgIn  >niisam !02_A	et	f	\N
197280	ettevaatlikut	?ettevaatlikut =vaatliku  (SgP  >ette+vaatliku !01_S	et	f	\N
197286	realiseeru	realiseeru =realiseeru  (IndPrPs_  >realiseeruma !27_V	et	f	\N
197287	realiseeru	realiseeru =realiseeru  (ImpPrSg2  >realiseeruma !27_V	et	f	\N
197292	mahaanikuna	?mahaanikuna =mahaaniku  (SgEs  >mahaanik !02_S	et	f	\N
197293	mahaanikuna	?mahaanikuna =aniku  (SgEs  >maha+aniku !01_S	et	f	\N
197294	mahaanikuna	?mahaanikuna =aniku  (SgEs  >maha+anik !02_S	et	f	\N
197296	eksamitulemustest	eksamitulemustest =test  (SgN  >eksami+tulemus+test !22_S	et	f	\N
197297	eksamitulemustest	eksamitulemustest =muste  (PlEl  >eksami+tule+must !22_AS	et	f	\N
197298	eksamitulemustest	eksamitulemustest =tulemus  (PlEl  >eksami+tulemus !11_S	et	f	\N
197299	külelt	?külelt =küle  (SgAbl  >küle !16_S	et	f	\N
197300	külelt	?külelt =külelt  (ID  >külelt !41_D	et	f	\N
197313	üllatuseks	üllatuseks =üllatuse  (SgTr  >üllatus !11_S	et	f	\N
197314	üllatuseks	"üllatus %üllata  )US_vS  <üllatama ;27_V	et	f	\N
197326	uliopilane	?uliopilane =uliopilane  (SgN  >uliopilane !12_S	et	f	\N
197327	uliopilane	?uliopilane =uliopilane  (PlP  >uliopilan !19_S	et	f	\N
197340	ulikoolisse	?ulikoolisse =ulikooli  (SgIll  >ulikooli !16_S	et	f	\N
197341	ulikoolisse	?ulikoolisse =ulikooli  (SgIll  >ulikool !22_S	et	f	\N
197342	ulikoolisse	?ulikoolisse =ulikoolis  (SgAdt  >ulikooline !12_A	et	f	\N
197343	ulikoolisse	?ulikoolisse =ulikoolisse  (SgG  >ulikoolisne !02_A	et	f	\N
197344	ulikoolisse	?ulikoolisse =ulikoolisse  (PlP  >ulikooliss !22_S	et	f	\N
197349	juhtkirja	juhtkirja =kirja  (SgG  >juht+kiri !24_S	et	f	\N
197350	juhtkirja	juhtkirja =kirja  (SgP  >juht+kiri !24_S	et	f	\N
197351	juhtkirja	juhtkirja =kirja  (SgAdt  >juht+kiri !24_S	et	f	\N
197361	komast	komast =koma  (SgEl  >koma !17_S	et	f	\N
197362	komast	komast =komas  (SgP  >komane !10_A	et	f	\N
197363	komast	"komane %koma  )NE_aA  <koma ;17_S	et	f	\N
197364	komast	komast =ast  (SgN  >kom+ast !22_S	et	f	\N
197406	vaiksematest	vaiksematest =vaiksema  (PlEl  >vaiksem !02_A	et	f	\N
197407	vaiksematest	"vaiksem %vaikse  )M_cA  <vaikne ;02_A	et	f	\N
197409	kaalepile	?kaalepile =kaalepi  (SgAll  >kaalepi !01_S	et	f	\N
197411	kaalepile	?kaalepile =kaalepi  (SgAll  >kaalep !02_S	et	f	\N
197413	kaalepile	?kaalepile =kaalepi  (SgAll  >kaalepp !22_S	et	f	\N
197439	korrasaga	?korrasaga =korrasa  (SgKom  >korrasa !01_S	et	f	\N
197440	korrasaga	?korrasaga =saga  (SgN  >korra+saga !17_S	et	f	\N
197441	korrasaga	?korrasaga =saga  (SgG  >korra+saga !17_S	et	f	\N
197091	tiia-mai	tiia-mai =mai  (SgG  >tiia-mai !26_S	et	f	\N
197096	teeliiklusest	teeliiklusest =liikluse  (SgEl  >tee+liiklus !11~09_S	et	f	\N
197097	teeliiklusest	teeliiklusest =liikluses  (SgP  >tee+liiklusene !12_A	et	f	\N
197098	teeliiklusest	"tee+liiklusene %liikluse  )NE_aA  <tee+liiklus ;09_S	et	f	\N
197099	teeliiklusest	"tee+liiklusene %liikluse  )NE_aA  <tee+liiklus ;11_S	et	f	\N
197109	lohakam	lohakam =lohakam  (SgN  >lohakam !02_A	et	f	\N
197110	lohakam	"lohakam %lohaka  )M_cA  <lohakas ;02_A	et	f	\N
197117	dokumentaalsaades	?dokumentaalsaades =dokumentaalsaa  (PlIn  >dokumentaalsaa !26_S	et	f	\N
197118	dokumentaalsaades	?dokumentaalsaades =dokumentaalsaade  (SgIn  >dokumentaalsaade !16_S	et	f	\N
197119	dokumentaalsaades	?dokumentaalsaades =dokumentaalsaade  (PlIn  >dokumentaalsaat !22_S	et	f	\N
197120	dokumentaalsaades	?dokumentaalsaades =saa  (PlIn  >dokumentaal+saa !26_S	et	f	\N
197121	dokumentaalsaades	?dokumentaalsaades =saades  (SgN  >dokumentaal+saades !09_S	et	f	\N
197122	dokumentaalsaades	?dokumentaalsaades =umentaalsaa  (PlIn  >dok+umentaalsaa !26_S	et	f	\N
197123	dokumentaalsaades	?dokumentaalsaades =umentaalsaade  (SgIn  >dok+umentaalsaade !16_S	et	f	\N
197124	dokumentaalsaades	?dokumentaalsaades =umentaalsaade  (PlIn  >dok+umentaalsaat !22_S	et	f	\N
197141	jooksvaid	jooksvaid =jooksva  (PlP  >jooksva !01_S	et	f	\N
197142	jooksvaid	jooksvaid =jooksva  (PlP  >jooksev !02_A	et	f	\N
197143	jooksvaid	"jooksev %jooks  )V_vA  <jooksma ;32_V	et	f	\N
197144	austaja	austaja =austaja  (SgN  >austaja !01_S	et	f	\N
197145	austaja	"austaja %austa  )JA_vS  <austama ;27_V	et	f	\N
197146	austaja	austaja =austaja  (SgG  >austaja !01_S	et	f	\N
197200	erimaja	erimaja =maja  (SgN  >eri+maja !17_S	et	f	\N
197201	erimaja	erimaja =maja  (SgG  >eri+maja !17_S	et	f	\N
197202	erimaja	erimaja =maja  (SgP  >eri+maja !17_S	et	f	\N
197212	garanteerivad	garanteerivad =garanteeri  (IndPrPl3  >garanteerima !28_V	et	f	\N
197213	garanteerivad	garanteerivad =garanteeriva  (PlN  >garanteeriv !02_A	et	f	\N
197214	garanteerivad	"garanteeriv %garanteeri  )V_vA  <garanteerima ;28_V	et	f	\N
197217	sotsiaaltöötaja	sotsiaaltöötaja =töötaja  (SgN  >sotsiaal+töötaja !01_S	et	f	\N
197218	sotsiaaltöötaja	sotsiaaltöötaja =töötaja  (SgG  >sotsiaal+töötaja !01_S	et	f	\N
197275	nuttavad	?nuttavad =nutta  (IndPrPl3  >nuttama !29_V	et	f	\N
197276	nuttavad	?nuttavad =nuttava  (PlN  >nuttava !01_S	et	f	\N
197277	nuttavad	?nuttavad =nuttava  (PlN  >nuttav !02_A	et	f	\N
197281	tesied	?tesied =tesie  (PlN  >tesie !01_S	et	f	\N
197282	tesied	?tesied =tesied  (SgN  >tesied !22_S	et	f	\N
197295	liisimiseks	?liisimiseks =liisimise  (SgTr  >liisimine !12_S	et	f	\N
197309	keskonnakaitsejana	?keskonnakaitsejana =keskonnakaitseja  (SgEs  >keskonnakaitseja !01_S	et	f	\N
197310	keskonnakaitsejana	?keskonnakaitsejana =keskonnakaitseja  (SgEs  >keskonnakaitsejas !02_A	et	f	\N
197311	keskonnakaitsejana	?keskonnakaitsejana =onnakaitseja  (SgEs  >kesk+onnakaitseja !01_S	et	f	\N
197312	keskonnakaitsejana	?keskonnakaitsejana =onnakaitseja  (SgEs  >kesk+onnakaitsejas !02_A	et	f	\N
197315	kompeteensemaid	?kompeteensemaid =kompeteensema  (PlP  >kompeteensem !02_A	et	f	\N
197316	kompeteensemaid	?kompeteensemaid =kompeteensemai  (PlN  >kompeteensemai !26_S	et	f	\N
197317	kompeteensemaid	?kompeteensemaid =kompeteensemai  (SgP  >kompeteensemai !26_S	et	f	\N
197318	kompeteensemaid	?kompeteensemaid =peteensema  (PlP  >kom+peteensem !02_A	et	f	\N
197319	kompeteensemaid	?kompeteensemaid =peteensemai  (PlN  >kom+peteensemai !26_S	et	f	\N
197320	kompeteensemaid	?kompeteensemaid =peteensemai  (SgP  >kom+peteensemai !26_S	et	f	\N
197328	tehnikaulikooli	?tehnikaulikooli =tehnikaulikooli  (SgN  >tehnikaulikooli !16_S	et	f	\N
197329	tehnikaulikooli	?tehnikaulikooli =tehnikaulikooli  (SgG  >tehnikaulikooli !16_S	et	f	\N
197330	tehnikaulikooli	?tehnikaulikooli =tehnikaulikooli  (SgG  >tehnikaulikool !22_S	et	f	\N
197331	tehnikaulikooli	?tehnikaulikooli =tehnikaulikooli  (SgP  >tehnikaulikool !22_S	et	f	\N
197332	tehnikaulikooli	?tehnikaulikooli =tehnikaulikooli  (SgAdt  >tehnikaulikool !22_S	et	f	\N
197333	tehnikaulikooli	?tehnikaulikooli =tehnikaulikooli  (IndPrPs_  >tehnikaulikoolima !28_V	et	f	\N
197334	tehnikaulikooli	?tehnikaulikooli =tehnikaulikooli  (ImpPrSg2  >tehnikaulikoolima !28_V	et	f	\N
197335	tehnikaulikooli	?tehnikaulikooli =ulikooli  (SgN  >tehnika+ulikooli !16_S	et	f	\N
197336	tehnikaulikooli	?tehnikaulikooli =ulikooli  (SgG  >tehnika+ulikooli !16_S	et	f	\N
197337	tehnikaulikooli	?tehnikaulikooli =ulikooli  (SgG  >tehnika+ulikool !22_S	et	f	\N
197338	tehnikaulikooli	?tehnikaulikooli =ulikooli  (SgP  >tehnika+ulikool !22_S	et	f	\N
197339	tehnikaulikooli	?tehnikaulikooli =ulikooli  (SgAdt  >tehnika+ulikool !22_S	et	f	\N
197352	nadalalehtis	?nadalalehtis =nadalalehti  (IndIpfSg3  >nadalalehtima !28_V	et	f	\N
197353	nadalalehtis	?nadalalehtis =nadalalehtis  (SgN  >nadalalehtis !09_S	et	f	\N
197366	ked	### ked	et	f	\N
197367	sotsiaaltootajad	?sotsiaaltootajad =sotsiaaltootaja  (PlN  >sotsiaaltootaja !01_S	et	f	\N
197368	sotsiaaltootajad	?sotsiaaltootajad =sotsiaaltootaja  (PlN  >sotsiaaltootajas !02_A	et	f	\N
197369	sotsiaaltootajad	?sotsiaaltootajad =taja  (PlN  >sotsiaal+too+taja !17_S	et	f	\N
197370	sotsiaaltootajad	?sotsiaaltootajad =tootaja  (PlN  >sotsiaal+tootaja !01_S	et	f	\N
197371	sotsiaaltootajad	?sotsiaaltootajad =tootaja  (PlN  >sotsiaal+tootajas !02_A	et	f	\N
197391	sotsiaaltootaja	?sotsiaaltootaja =sotsiaaltootaja  (SgN  >sotsiaaltootaja !01_S	et	f	\N
197392	sotsiaaltootaja	?sotsiaaltootaja =sotsiaaltootaja  (SgG  >sotsiaaltootaja !01_S	et	f	\N
197160	arvutimängu	arvutimängu =mängu  (SgG  >arvuti+mäng !22_S	et	f	\N
197161	arvutimängu	arvutimängu =mängu  (SgP  >arvuti+mäng !22_S	et	f	\N
197162	arvutimängu	arvutimängu =mängu  (SgAdt  >arvuti+mäng !22_S	et	f	\N
197165	sihitult	sihitult =sihitu  (SgAbl  >sihitu !01_AS	et	f	\N
197166	sihitult	"sihitu %sihi  )TU1_vS  <sihtima ;28_V	et	f	\N
197167	sihitult	"sihitu %sihi  )TU2_kA  <siht ;22_S	et	f	\N
197168	sihitult	sihitult =sihitult  (ID  >sihitult !41_D	et	f	\N
197169	sihitult	"sihitult %sihi  )TULT1_mD  <sihtima ;28_V	et	f	\N
197170	sihitult	"sihitult %sihi  )TULT2_mD  <siht ;22_S	et	f	\N
197171	sihitult	"sihitult %sihitu  )LT_mD  <sihitu ;01_AS	et	f	\N
197172	nortele	?nortele =norte  (SgAll  >norde !06_S	et	f	\N
197173	nortele	?nortele =nortele  (IndPrPs_  >nortelema !27_V	et	f	\N
197174	nortele	?nortele =nortele  (ImpPrSg2  >nortelema !27_V	et	f	\N
197188	tööpäevi	tööpäevi =päevi  (SgG  >töö+päev !22_S	et	f	\N
197189	tööpäevi	tööpäevi =päevi  (SgP  >töö+päev !22_S	et	f	\N
197190	tööpäevi	tööpäevi =päevi  (SgAdt  >töö+päev !22_S	et	f	\N
197191	tööpäevi	tööpäevi =päevi  (PlP  >töö+päev !22_S	et	f	\N
197227	polka	polka =polka  (SgN  >polka !16_S	et	f	\N
197228	polka	polka =polka  (SgG  >polka !16_S	et	f	\N
197229	rahulikut	?rahulikut =iku  (SgP  >rahul+iku !16_S	et	f	\N
197230	rahulikut	?rahulikut =ikut  (SgN  >rahul+ikut !02_S	et	f	\N
197246	südistama	?südistama =südista  (Sup  >südistama !27_V	et	f	\N
197247	südistama	?südistama =südistama  (SgG  >südistam !02_A	et	f	\N
197251	muretult	muretult =muretu  (SgAbl  >muretu !01_A	et	f	\N
197252	muretult	"muretu %mure  )TU2_kA  <mure ;16_S	et	f	\N
197253	muretult	muretult =muretult  (ID  >muretult !41_D	et	f	\N
197254	muretult	"muretult %mure  )TULT2_mD  <mure ;16_S	et	f	\N
197255	muretult	"muretult %muretu  )LT_mD  <muretu ;01_A	et	f	\N
197258	sajaprotsendiliselt	sajaprotsendiliselt =protsendilise  (SgAbl  >saja+protsendiline !12_A	et	f	\N
197259	sajaprotsendiliselt	"saja+protsendiline %protsendi  )LINE_aA  <saja+protsent ;22_S	et	f	\N
197260	sajaprotsendiliselt	"saja+protsendiliselt %protsendi  )LISELT_mD  <saja+protsent ;22_S	et	f	\N
197261	sajaprotsendiliselt	"saja+protsendiliselt %protsendilise  )LT_mD  <saja+protsendiline ;12_A	et	f	\N
197262	soovitega	### soovitega	et	f	\N
197272	mõnedainult	?mõnedainult =mõnedainu  (SgAbl  >mõnedainu !01_S	et	f	\N
197273	mõnedainult	?mõnedainult =mõnedainult  (ID  >mõnedainult !41_D	et	f	\N
197274	mõnedainult	?mõnedainult =dainu  (SgAbl  >mõne+dainu !16_S	et	f	\N
197289	rahvusvahelisi	rahvusvahelisi =vahelisi  (PlP  >rahvus+vaheline !12_A	et	f	\N
197290	rahvusvahelisi	"rahvus+vaheline %vahe  )LINE_aA  <rahvus+vahe ;16_S	et	f	\N
197347	nadalal	?nadalal =nadala  (SgAd  >nadala !01_S	et	f	\N
197348	nadalal	?nadalal =nadalal  (SgN  >nadalal !19_S	et	f	\N
197354	vahenoudlike	?vahenoudlike =vahenoudlike  (SgN  >vahenoudlike !12_S	et	f	\N
197355	vahenoudlike	?vahenoudlike =vahenoudlike  (PlG  >vahenoudlik !25_A	et	f	\N
197356	vahenoudlike	?vahenoudlike =noudlike  (SgN  >vahe+noudlike !12_S	et	f	\N
197357	vahenoudlike	?vahenoudlike =noudlike  (PlG  >vahe+noudlik !25_A	et	f	\N
197358	ruhmidest	?ruhmidest =ruhmi  (PlEl  >ruhmi !16_S	et	f	\N
197359	ruhmidest	?ruhmidest =ruhmi  (PlEl  >ruhm !22_S	et	f	\N
197360	ruhmidest	?ruhmidest =ruhmides  (SgP  >ruhmidene !12_A	et	f	\N
197384	rüpes	rüpes =rüpe  (SgIn  >rüpp !22_S	et	f	\N
197385	rüpes	rüpes =rüpe  (PlIn  >rüpp !22_S	et	f	\N
197386	ulikoolidesse	?ulikoolidesse =ulikooli  (PlIll  >ulikooli !16_S	et	f	\N
197387	ulikoolidesse	?ulikoolidesse =ulikooli  (PlIll  >ulikool !22_S	et	f	\N
197388	ulikoolidesse	?ulikoolidesse =ulikoolides  (SgAdt  >ulikoolidene !12_A	et	f	\N
197389	ulikoolidesse	?ulikoolidesse =ulikoolidesse  (SgG  >ulikoolidesne !02_A	et	f	\N
197390	ulikoolidesse	?ulikoolidesse =ulikoolidesse  (PlP  >ulikoolidess !22_S	et	f	\N
197396	keskkonnakaitsja	keskkonnakaitsja =kaitsja  (SgN  >kesk+konna+kaitsja !01_S	et	f	\N
197398	keskkonnakaitsja	keskkonnakaitsja =kaitsja  (SgG  >kesk+konna+kaitsja !01_S	et	f	\N
197472	kahetsemisega	kahetsemisega =kahetsemise  (SgKom  >kahetsemine !12_S	et	f	\N
197473	kahetsemisega	"kahetsemine %kahetse  )MINE_vS  <kahetsema ;27_V	et	f	\N
197479	mingisugusi	?mingisugusi =mingisugusi  (PlP  >mingisugus !11_S	et	f	\N
197480	mingisugusi	?mingisugusi =sugusi  (SgG  >mingi+sugus !02_A	et	f	\N
197489	väärilist	väärilist =väärilis  (SgP  >vääriline !12_A	et	f	\N
197490	väärilist	"vääriline %vääri  )LINE_aA  <väär ;22_S	et	f	\N
197491	mugavamaks	mugavamaks =mugavama  (SgTr  >mugavam !02_A	et	f	\N
197492	mugavamaks	"mugavam %mugava  )M_cA  <mugav ;02_A	et	f	\N
197497	artiiklit	?artiiklit =artiikli  (SgP  >artiikli !01_S	et	f	\N
197498	artiiklit	?artiiklit =artiikli  (SgP  >artiikel !02_S	et	f	\N
197519	sqbrad	### sqbrad	et	f	\N
197531	oppidaja	?oppidaja =oppidaja  (SgN  >oppidaja !01_S	et	f	\N
197532	oppidaja	?oppidaja =oppidaja  (SgG  >oppidaja !01_S	et	f	\N
197533	oppidaja	?oppidaja =oppidaja  (SgG  >oppidajas !02_A	et	f	\N
197534	uliqpilased	?uliqpilased =uliqpilase  (PlN  >uliqpilane !12_S	et	f	\N
197536	oppidasee	?oppidasee =oppidasee  (SgN  >oppidasee !26_S	et	f	\N
197537	oppidasee	?oppidasee =oppidasee  (SgG  >oppidasee !26_S	et	f	\N
197263	tasulistele	tasulistele =tasulis  (PlAll  >tasuline !12_A	et	f	\N
197264	tasulistele	"tasuline %tasu  )LINE_aA  <tasu ;17_S	et	f	\N
197267	parianti	?parianti =parianti  (SgP  >pariant !22_S	et	f	\N
197268	parianti	?parianti =parianti  (SgAdt  >pariant !22_S	et	f	\N
197283	vaeseks	vaeseks =vaese  (SgTr  >vaene !10_AS	et	f	\N
197284	vaeseks	"vaene %vae  )NE_aA  <vaag ;22_S	et	f	\N
197285	vaeseks	vaeseks =seks  (SgN  >vae+seks !22_S	et	f	\N
197301	ebastabiilsus	ebastabiilsus =stabiilsus  (SgN  >eba+stabiilsus !11~09_S	et	f	\N
197302	ebastabiilsus	"eba+stabiilsus %stabiilse  )US_aS  <eba+stabiilne ;02_A	et	f	\N
197307	küsitlejatest	küsitlejatest =küsitleja  (PlEl  >küsitleja !01_S	et	f	\N
197308	küsitlejatest	"küsitleja %küsitle  )JA_vS  <küsitlema ;27_V	et	f	\N
197321	muni	?muni =muni  (SgN  >muni !17_S	et	f	\N
197322	muni	?muni =muni  (SgG  >muni !17_S	et	f	\N
197323	muni	?muni =muni  (SgP  >muni !17_S	et	f	\N
197324	muni	?muni =muni  (IndPrPs_  >munima !27_V	et	f	\N
197325	muni	?muni =muni  (ImpPrSg2  >munima !27_V	et	f	\N
197372	utelda	?utelda =utel  (Inf  >utlema !30_V	et	f	\N
197373	utelda	?utelda =utel  (IndPrIps_  >utlema !30_V	et	f	\N
197374	utelda	?utelda =utelda  (IndPrPs_  >uteldama !27_V	et	f	\N
197375	utelda	?utelda =utelda  (ImpPrSg2  >uteldama !27_V	et	f	\N
197377	opi	?opi =opi  (SgN  >opi !16_S	et	f	\N
197378	opi	?opi =opi  (SgG  >opi !16_S	et	f	\N
197379	opi	?opi =opi  (SgG  >opp !22_S	et	f	\N
197380	opi	?opi =opi  (IndPrPs_  >opima !27_V	et	f	\N
197381	opi	?opi =opi  (IndPrPs_  >oppima !28_V	et	f	\N
197382	opi	?opi =opi  (ImpPrSg2  >opima !27_V	et	f	\N
197383	opi	?opi =opi  (ImpPrSg2  >oppima !28_V	et	f	\N
197404	konelejad	?konelejad =koneleja  (PlN  >koneleja !01_S	et	f	\N
197405	konelejad	?konelejad =koneleja  (PlN  >konelejas !02_A	et	f	\N
197408	jatkumise	?jatkumise =jatkumise  (SgG  >jatkumine !12_S	et	f	\N
197410	lptiina	?lptiina =lptii  (SgEs  >lptii !26_S	et	f	\N
197412	lptiina	?lptiina =lptiina  (SgN  >lptiina !16_S	et	f	\N
197414	lptiina	?lptiina =lptiina  (SgG  >lptiina !16_S	et	f	\N
197415	lptiina	?lptiina =lptiina  (IndPrPs_  >lptiinama !29_V	et	f	\N
197416	lptiina	?lptiina =lptiina  (ImpPrSg2  >lptiinama !29_V	et	f	\N
197417	jõuelektronika	?jõuelektronika =jõuelektronika  (SgN  >jõuelektronika !01_S	et	f	\N
197418	jõuelektronika	?jõuelektronika =jõuelektronika  (SgG  >jõuelektronika !01_S	et	f	\N
197419	jõuelektronika	?jõuelektronika =jõuelektronika  (SgG  >jõuelektronikas !02_A	et	f	\N
197420	jõuelektronika	?jõuelektronika =ika  (SgN  >jõu+elektron+ika !16_S	et	f	\N
197421	jõuelektronika	?jõuelektronika =ika  (SgG  >jõu+elektron+ika !16_S	et	f	\N
197422	jõuelektronika	?jõuelektronika =nika  (SgN  >jõu+elektro+nika !16_S	et	f	\N
197423	jõuelektronika	?jõuelektronika =nika  (SgG  >jõu+elektro+nika !16_S	et	f	\N
197424	jõuelektronika	?jõuelektronika =elektronika  (SgN  >jõu+elektronika !01_S	et	f	\N
197425	jõuelektronika	?jõuelektronika =elektronika  (SgG  >jõu+elektronika !01_S	et	f	\N
197426	jõuelektronika	?jõuelektronika =elektronika  (SgG  >jõu+elektronikas !02_A	et	f	\N
197435	töönendel	?töönendel =töönende  (PlAd  >töönent !22_S	et	f	\N
197436	töönendel	?töönendel =nende  (SgAd  >töö+nenne !06_S	et	f	\N
197437	töönendel	?töönendel =nende  (PlAd  >töö+nent !22_S	et	f	\N
197438	töönendel	?töönendel =nendel  (SgN  >töö+nendel !02_S	et	f	\N
197449	looteriga	?looteriga =looteri  (SgKom  >looteri !01_S	et	f	\N
197450	looteriga	?looteriga =looteri  (SgKom  >looter !02_S	et	f	\N
197451	looteriga	?looteriga =riga  (SgN  >loote+riga !17_S	et	f	\N
197452	looteriga	?looteriga =riga  (SgG  >loote+riga !17_S	et	f	\N
197453	looteriga	?looteriga =riga  (SgP  >loote+riga !17_S	et	f	\N
197454	looteriga	?looteriga =teri  (SgKom  >loo+teri !17_S	et	f	\N
197468	iseloomulikkud	?iseloomulikkud =iseloomulikku  (IndPrSg2  >iseloomulikkuma !27_V	et	f	\N
197469	iseloomulikkud	?iseloomulikkud =ulikku  (PlN  >ise+loom+ulikku !01_S	et	f	\N
197470	iseloomulikkud	?iseloomulikkud =mulikku  (PlN  >ise+loo+mulikku !01_S	et	f	\N
197474	tänapäevastel	tänapäevastel =aste  (SgAd  >täna+päev+aste !06_S	et	f	\N
197475	tänapäevastel	tänapäevastel =aste  (PlAd  >täna+päev+ast !22_S	et	f	\N
197476	tänapäevastel	tänapäevastel =astel  (SgN  >täna+päev+astel !08_S	et	f	\N
197477	tänapäevastel	tänapäevastel =päevas  (PlAd  >täna+päevane !10_A	et	f	\N
197478	tänapäevastel	"täna+päevane %päeva  )NE_aA  <täna+päev ;22_S	et	f	\N
197496	seotada	?seotada =seota  (Inf  >seotama !27_V	et	f	\N
197499	alguselt	alguselt =alguse  (SgAbl  >algus !11~09_S	et	f	\N
197500	alguselt	alguselt =alguselt  (ID  >alguselt !41_D	et	f	\N
197501	alguselt	"alguselt %algu  )SELT_mD  <alg ;22_S	et	f	\N
197502	alguselt	alguselt =use  (PlAbl  >alg+usk !22_S	et	f	\N
197520	huviallad	?huviallad =huvialla  (PlN  >huvialla !16_S	et	f	\N
197521	muidugisest	?muidugisest =muidugise  (SgEl  >muidugis !11_S	et	f	\N
197522	muidugisest	?muidugisest =muidugises  (SgP  >muidugisene !12_A	et	f	\N
197523	muidugisest	?muidugisest =gise  (SgEl  >muidu+gise !16_S	et	f	\N
197524	muidugisest	?muidugisest =gises  (SgP  >muidu+gises !09_S	et	f	\N
197525	muidugisest	?muidugisest =gises  (SgP  >muidu+gisene !10_A	et	f	\N
197526	ragite	?ragite =ragi  (IndPrPl2  >ragima !27_V	et	f	\N
197393	sotsiaaltootaja	?sotsiaaltootaja =sotsiaaltootaja  (SgG  >sotsiaaltootajas !02_A	et	f	\N
197394	sotsiaaltootaja	?sotsiaaltootaja =taja  (SgN  >sotsiaal+too+taja !17_S	et	f	\N
197395	sotsiaaltootaja	?sotsiaaltootaja =taja  (SgG  >sotsiaal+too+taja !17_S	et	f	\N
197397	sotsiaaltootaja	?sotsiaaltootaja =taja  (SgP  >sotsiaal+too+taja !17_S	et	f	\N
197399	sotsiaaltootaja	?sotsiaaltootaja =tootaja  (SgN  >sotsiaal+tootaja !01_S	et	f	\N
197400	sotsiaaltootaja	?sotsiaaltootaja =tootaja  (SgG  >sotsiaal+tootaja !01_S	et	f	\N
197401	sotsiaaltootaja	?sotsiaaltootaja =tootaja  (SgG  >sotsiaal+tootajas !02_A	et	f	\N
197427	erialalasma	?erialalasma =erialalasma  (SgN  >erialalasma !16_S	et	f	\N
197428	erialalasma	?erialalasma =erialalasma  (SgG  >erialalasma !16_S	et	f	\N
197429	erialalasma	?erialalasma =asma  (SgN  >eri+alal+asma !16_S	et	f	\N
197430	erialalasma	?erialalasma =asma  (SgG  >eri+alal+asma !16_S	et	f	\N
197431	erialalasma	?erialalasma =lasma  (SgN  >eri+ala+lasma !16_S	et	f	\N
197432	erialalasma	?erialalasma =lasma  (SgG  >eri+ala+lasma !16_S	et	f	\N
197433	erialalasma	?erialalasma =alalasma  (SgN  >eri+alalasma !16_S	et	f	\N
197434	erialalasma	?erialalasma =alalasma  (SgG  >eri+alalasma !16_S	et	f	\N
197455	võimalusestaga	?võimalusestaga =võimalusesta  (SgKom  >võimalusesta !16_S	et	f	\N
197456	võimalusestaga	?võimalusestaga =malusesta  (SgKom  >või+malusesta !16_S	et	f	\N
197457	ennasele	?ennasele =ennase  (SgAll  >ennane !10_A	et	f	\N
197458	ennasele	?ennasele =ennasele  (PlP  >ennasel !19_S	et	f	\N
197460	tööidsellega	### tööidsellega	et	f	\N
197466	jagamine	jagamine =jagamine  (SgN  >jagamine !12_S	et	f	\N
197467	jagamine	"jagamine %jaga  )MINE_vS  <jagama ;27_V	et	f	\N
197471	tüüpid	### tüüpid	et	f	\N
197528	tulimuse	?tulimuse =tulimuse  (SgG  >tulimus !11_S	et	f	\N
197529	tulimuse	?tulimuse =muse  (SgN  >tuli+muse !16_S	et	f	\N
197530	tulimuse	?tulimuse =muse  (SgG  >tuli+muse !16_S	et	f	\N
197544	andndsin	?andndsin =andndsi  (IndPrSg1  >andndsima !28_V	et	f	\N
197545	andndsin	?andndsin =andndsin  (SgN  >andndsin !02_S	et	f	\N
197549	muudata	?muudata =muuda  (SgAb  >muuda !16_S	et	f	\N
197550	muudata	?muudata =muudata  (IndPrPs_  >muudatama !27_V	et	f	\N
197551	muudata	?muudata =muudata  (ImpPrSg2  >muudatama !27_V	et	f	\N
197552	muudata	?muudata =data  (SgN  >muu+data !16_S	et	f	\N
197553	muudata	?muudata =data  (SgG  >muu+data !16_S	et	f	\N
197558	tundiline	?tundiline =tundiline  (SgN  >tundiline !12_A	et	f	\N
197559	tundiline	?tundiline =tundiline  (PlP  >tundilin !19_S	et	f	\N
197569	mõnte	?mõnte =mõnte  (SgN  >mõnte !06_S	et	f	\N
197570	mõnte	?mõnte =mõnte  (SgG  >mõnde !06_S	et	f	\N
197571	mõnte	?mõnte =mõnte  (PlP  >mõnt !22_S	et	f	\N
197572	mõnte	?mõnte =mõnte  (IndPrPs_  >mõntema !27_V	et	f	\N
197573	mõnte	?mõnte =mõnte  (ImpPrSg2  >mõntema !27_V	et	f	\N
197581	komputriga	?komputriga =komputri  (SgKom  >komputri !01_S	et	f	\N
197582	komputriga	?komputriga =komputri  (SgKom  >komputter !02_S	et	f	\N
197583	komputriga	?komputriga =komputri  (SgKom  >komputer !19_S	et	f	\N
197584	komputriga	?komputriga =putri  (SgKom  >kom+putter !02_S	et	f	\N
197590	klienditenindaja	?klienditenindaja =klienditenindaja  (SgN  >klienditenindaja !01_S	et	f	\N
197591	klienditenindaja	?klienditenindaja =klienditenindaja  (SgG  >klienditenindaja !01_S	et	f	\N
197592	klienditenindaja	?klienditenindaja =klienditenindaja  (SgG  >klienditenindajas !02_A	et	f	\N
197593	klienditenindaja	?klienditenindaja =tenindaja  (SgN  >kliendi+tenindaja !01_S	et	f	\N
197594	klienditenindaja	?klienditenindaja =tenindaja  (SgG  >kliendi+tenindaja !01_S	et	f	\N
197595	klienditenindaja	?klienditenindaja =tenindaja  (SgG  >kliendi+tenindajas !02_A	et	f	\N
197626	kliendit	?kliendit =kliendi  (SgP  >kliendi !01_S	et	f	\N
197627	kliendit	?kliendit =kliendi  (SgP  >kliend !02_S	et	f	\N
197628	klieditajad	?klieditajad =klieditaja  (PlN  >klieditaja !01_S	et	f	\N
197629	klieditajad	?klieditajad =klieditaja  (PlN  >klieditajas !02_A	et	f	\N
197634	õppelased	?õppelased =õppelase  (PlN  >õppelane !12_S	et	f	\N
197635	eraldavaid	eraldavaid =eraldava  (PlP  >eraldav !02_A	et	f	\N
197636	eraldavaid	"eraldav %eralda  )V_vA  <eraldama ;27_V	et	f	\N
197649	õppimenud	?õppimenud =õppimenu  (PlN  >õppimenu !01_S	et	f	\N
197650	õppimenud	?õppimenud =õppimenu  (IndPrSg2  >õppimenuma !27_V	et	f	\N
197651	õppimenud	?õppimenud =õppimenud  (ID  >õppimenud !41_A	et	f	\N
197662	terje	?terje =terje  (SgN  >terje !06_S	et	f	\N
197663	terje	?terje =terje  (SgG  >terje !06_S	et	f	\N
197664	terje	?terje =terje  (IndPrPs_  >terjema !27_V	et	f	\N
197665	terje	?terje =terje  (ImpPrSg2  >terjema !27_V	et	f	\N
197666	konsum	?konsum =konsum  (SgN  >konsum !02_S	et	f	\N
197675	tööhoiveamet	### tööhoiveamet	et	f	\N
197686	tulevukus	?tulevukus =tulevuku  (IndIpfSg3  >tulevukuma !27_V	et	f	\N
197687	tulevukus	?tulevukus =tulevukus  (SgN  >tulevukus !11?09_S	et	f	\N
197688	tulevukus	?tulevukus =uku  (SgIn  >tulev+uku !16_S	et	f	\N
197689	tulevukus	?tulevukus =ukus  (SgN  >tulev+ukus !09_S	et	f	\N
197690	tulevukus	?tulevukus =vuku  (SgIn  >tule+vuku !16_S	et	f	\N
197691	tulevukus	?tulevukus =vukus  (SgN  >tule+vukus !09_S	et	f	\N
197694	jaanuarni	?jaanuarni =jaanuarni  (SgG  >jaanuarn !22_S	et	f	\N
197695	jaanuarni	?jaanuarni =jaanuarni  (SgP  >jaanuarn !22_S	et	f	\N
197442	korrasaga	?korrasaga =saga  (SgP  >korra+saga !17_S	et	f	\N
197443	tegemanad	### tegemanad	et	f	\N
197444	saabnad	?saabnad =saabna  (PlN  >saabna !01_S	et	f	\N
197445	saabnad	?saabnad =saabna  (IndPrSg2  >saabnama !29_V	et	f	\N
197464	eelmistest	eelmistest =eelmis  (PlEl  >eelmine !12?10_A	et	f	\N
197465	eelmistest	eelmistest =test  (SgN  >eel+mis+test !22_S	et	f	\N
197487	ihaldusväärseks	ihaldusväärseks =seks  (SgN  >ihaldus+väär+seks !22_S	et	f	\N
197488	ihaldusväärseks	ihaldusväärseks =väärse  (SgTr  >ihaldus+väärne !02_A	et	f	\N
197493	meeldivamaks	meeldivamaks =meeldivama  (SgTr  >meeldivam !02_A	et	f	\N
197494	meeldivamaks	"meeldivam %meeldi  )VAM_cA  <meeldima ;27_V	et	f	\N
197495	meeldivamaks	"meeldivam %meeldiva  )M_cA  <meeldiv ;02_A	et	f	\N
197515	üksendast	?üksendast =üksenda  (SgEl  >üksenda !01_S	et	f	\N
197516	üksendast	?üksendast =üksendas  (SgP  >üksendane !12_A	et	f	\N
197517	üksendast	?üksendast =endas  (SgP  >üks+endas !07_S	et	f	\N
197518	üksendast	?üksendast =endas  (SgP  >üks+endane !10_A	et	f	\N
197535	ulikoolised	?ulikoolised =ulikoolise  (PlN  >ulikooline !12?10_A	et	f	\N
197541	sikupilli	sikupilli =pilli  (SgG  >siku+pill !22_S	et	f	\N
197542	sikupilli	sikupilli =pilli  (SgP  >siku+pill !22_S	et	f	\N
197543	sikupilli	sikupilli =pilli  (SgAdt  >siku+pill !22_S	et	f	\N
197554	koolipäevaplaani	koolipäevaplaani =plaani  (SgG  >kooli+päeva+plaan !22_S	et	f	\N
197555	koolipäevaplaani	koolipäevaplaani =plaani  (SgP  >kooli+päeva+plaan !22_S	et	f	\N
197556	koolipäevaplaani	koolipäevaplaani =plaani  (SgAdt  >kooli+päeva+plaan !22_S	et	f	\N
197565	suureb	?suureb =suure  (IndPrSg3  >suurema !27_V	et	f	\N
197566	valimust	valimust =valimus  (SgP  >valimus !11_S	et	f	\N
197567	valimust	"valimus %vali  )MUS_vS  <valima ;27_V	et	f	\N
197596	tarbijakaitse	tarbijakaitse =kaitse  (SgN  >tarbija+kaitse !05_S	et	f	\N
197597	tarbijakaitse	tarbijakaitse =kaitse  (SgN  >tarbija+kaitse !06_S	et	f	\N
197598	tarbijakaitse	tarbijakaitse =kaitse  (SgG  >tarbija+kaitse !06_S	et	f	\N
197625	erite	?erite =eri  (IndPrPl2  >erima !27_V	et	f	\N
197639	vastunud	?vastunud =vastu  (PtsPtPs  >vastuma !27_V	et	f	\N
197640	vastunud	?vastunud =vastunu  (PlN  >vastunu !01_S	et	f	\N
197641	vastunud	?vastunud =vastunu  (IndPrSg2  >vastunuma !27_V	et	f	\N
197642	vastunud	?vastunud =vastunud  (ID  >vastunud !41_A	et	f	\N
197643	vastunud	?vastunud =unu  (PlN  >vast+unu !17_S	et	f	\N
197655	nagemis	?nagemis =nagemi  (SgIn  >nagemi !01_S	et	f	\N
197656	nagemis	?nagemis =nagemi  (SgIn  >nagem !02_A	et	f	\N
197657	nagemis	?nagemis =nagemis  (SgN  >nagemis !11_S	et	f	\N
197668	kairi	?kairi =kairi  (SgN  >kairi !16_S	et	f	\N
197669	kairi	?kairi =kairi  (SgG  >kairi !16_S	et	f	\N
197670	kairi	?kairi =kairi  (SgG  >kair !22_S	et	f	\N
197671	kairi	?kairi =kairi  (SgP  >kair !22_S	et	f	\N
197672	kairi	?kairi =kairi  (SgAdt  >kair !22_S	et	f	\N
197673	kairi	?kairi =kairi  (IndPrPs_  >kairima !28_V	et	f	\N
197674	kairi	?kairi =kairi  (ImpPrSg2  >kairima !28_V	et	f	\N
197678	nõub	?nõub =nõub  (SgN  >nõub !22_S	et	f	\N
197699	psüholoogia	?psüholoogia =psüholoogia  (SgN  >psüholoogia !01_S	et	f	\N
197700	psüholoogia	?psüholoogia =psüholoogia  (SgG  >psüholoogia !01_S	et	f	\N
197703	õigusnõuandla	õigusnõuandla =andla  (SgN  >õigus+nõu+andla !01_S	et	f	\N
197704	õigusnõuandla	õigusnõuandla =andla  (SgG  >õigus+nõu+andla !01_S	et	f	\N
197740	virgi	virgi =virgi  (SgG  >virk !22_A	et	f	\N
197741	virgi	virgi =virgi  (SgP  >virg !22_S	et	f	\N
197742	virgi	virgi =virgi  (SgAdt  >virg !22_S	et	f	\N
197743	virgi	virgi =virgi  (PlP  >virg !22_S	et	f	\N
197750	asjaajaminst	?asjaajaminst =minst  (SgN  >asja+aja+minst !22_S	et	f	\N
197763	nora	?nora =nora  (SgN  >nora !17_S	et	f	\N
197764	nora	?nora =nora  (SgG  >nora !17_S	et	f	\N
197765	nora	?nora =nora  (SgP  >nora !17_S	et	f	\N
197766	nora	?nora =nora  (IndPrPs_  >norama !27_V	et	f	\N
197767	nora	?nora =nora  (ImpPrSg2  >norama !27_V	et	f	\N
197775	reesirverisime	### reesirverisime	et	f	\N
197785	pihkvasse	?pihkvasse =pihkva  (SgIll  >pihkva !01_S	et	f	\N
197786	pihkvasse	?pihkvasse =pihkvas  (SgAdt  >pihkvane !12_A	et	f	\N
197787	pihkvasse	?pihkvasse =pihkvasse  (SgG  >pihkvasne !02_A	et	f	\N
197788	pihkvasse	?pihkvasse =pihkvasse  (PlP  >pihkvass !22_S	et	f	\N
197796	kohtla-järvelt	kohtla-järvelt =järve  (SgAbl  >kohtla-järv !22_S	et	f	\N
197797	kohtla-järvelt	kohtla-järvelt =järve  (PlAbl  >kohtla-järv !22_S	et	f	\N
197824	aivar	?aivar =aivar  (SgN  >aivar !02_S	et	f	\N
197837	kroni	?kroni =kroni  (SgN  >kroni !17_S	et	f	\N
197838	kroni	?kroni =kroni  (SgG  >kroni !17_S	et	f	\N
197839	kroni	?kroni =kroni  (SgP  >kroni !17_S	et	f	\N
197840	kroni	?kroni =kroni  (IndPrPs_  >kronima !27_V	et	f	\N
197841	kroni	?kroni =kroni  (ImpPrSg2  >kronima !27_V	et	f	\N
197860	aabikasa	?aabikasa =aabikasa  (SgN  >aabikasa !16_S	et	f	\N
197861	aabikasa	?aabikasa =aabikasa  (SgG  >aabikasa !16_S	et	f	\N
197863	nedelas	?nedelas =nedela  (SgIn  >nedela !01_S	et	f	\N
197868	tutvon	?tutvon =tutvon  (SgN  >tutvon !02_S	et	f	\N
197870	siina	?siina =sii  (SgEs  >sii !26_S	et	f	\N
197459	meldiskirjutage	?meldiskirjutage =meldiskirjuta  (ImpPrPl2  >meldiskirjutama !27_V	et	f	\N
197461	huvitavana	huvitavana =huvitava  (SgEs  >huvitav !02_A	et	f	\N
197462	huvitavana	"huvitav %huvita  )V_vA  <huvitama ;27_V	et	f	\N
197463	huvitavana	huvitavana =tava  (SgEs  >huvi+tava !17_S	et	f	\N
197481	suurjoonelisi	suurjoonelisi =joonelisi  (PlP  >suur+jooneline !12_A	et	f	\N
197482	suurjoonelisi	"suur+jooneline %joone  )LINE_aA  <suur+joon ;13_S	et	f	\N
197483	suurjoonelisi	"suur+jooneline %jooneli  )NE_aA  <suur+joonel ;02_S	et	f	\N
197484	idülli	idülli =idülli  (SgG  >idüll !22_S	et	f	\N
197485	idülli	idülli =idülli  (SgP  >idüll !22_S	et	f	\N
197486	idülli	idülli =idülli  (SgAdt  >idüll !22_S	et	f	\N
197503	teistsmoodi	?teistsmoodi =teistsmoodi  (SgN  >teistsmoodi !16_S	et	f	\N
197504	teistsmoodi	?teistsmoodi =teistsmoodi  (SgG  >teistsmoodi !16_S	et	f	\N
197505	teistsmoodi	?teistsmoodi =teistsmoodi  (SgG  >teistsmoot !22_S	et	f	\N
197506	teistsmoodi	?teistsmoodi =teistsmoodi  (SgP  >teistsmood !22_S	et	f	\N
197507	teistsmoodi	?teistsmoodi =teistsmoodi  (SgAdt  >teistsmood !22_S	et	f	\N
197508	teistsmoodi	?teistsmoodi =teistsmoodi  (IndPrPs_  >teistsmootima !28_V	et	f	\N
197509	teistsmoodi	?teistsmoodi =teistsmoodi  (ImpPrSg2  >teistsmootima !28_V	et	f	\N
197510	teistsmoodi	?teistsmoodi =smoodi  (SgN  >teist+smoodi !16_S	et	f	\N
197511	teistsmoodi	?teistsmoodi =smoodi  (SgG  >teist+smoodi !16_S	et	f	\N
197512	teistsmoodi	?teistsmoodi =smoodi  (SgG  >teist+smoot !22_S	et	f	\N
197513	teistsmoodi	?teistsmoodi =smoodi  (SgP  >teist+smood !22_S	et	f	\N
197514	teistsmoodi	?teistsmoodi =smoodi  (SgAdt  >teist+smood !22_S	et	f	\N
197527	takkistab	?takkistab =takkista  (IndPrSg3  >takkistama !27_V	et	f	\N
197538	sekretäär	?sekretäär =sekretäär  (SgN  >sekretäär !22_S	et	f	\N
197539	õppekaartis	?õppekaartis =õppekaarti  (IndIpfSg3  >õppekaartima !28_V	et	f	\N
197540	õppekaartis	?õppekaartis =õppekaartis  (SgN  >õppekaartis !09_S	et	f	\N
197568	mitet	?mitet =mite  (SgP  >mite !06_S	et	f	\N
197574	lahete	?lahete =lahe  (IndPrPl2  >lahema !27_V	et	f	\N
197585	koputriga	?koputriga =koputri  (SgKom  >koputri !01_S	et	f	\N
197586	koputriga	?koputriga =koputri  (SgKom  >koputter !02_S	et	f	\N
197587	koputriga	?koputriga =koputri  (SgKom  >koputer !19_S	et	f	\N
197601	töod	?töod =töo  (PlN  >töo !26_S	et	f	\N
197602	töod	?töod =töo  (SgP  >töo !26_S	et	f	\N
197603	töod	?töod =töod  (SgN  >töod !22_S	et	f	\N
197606	nägemisine	nägemisine =ine  (SgN  >nägemis+ine !16_S	et	f	\N
197607	nägemisine	nägemisine =ine  (SgG  >nägemis+ine !16_S	et	f	\N
197611	klienditeedamine	?klienditeedamine =klienditeedamine  (SgN  >klienditeedamine !12_S	et	f	\N
197612	klienditeedamine	?klienditeedamine =klienditeedamine  (PlP  >klienditeedamin !19_S	et	f	\N
197613	klienditeedamine	?klienditeedamine =amine  (SgN  >kliendi+teed+amine !10_A	et	f	\N
197614	klienditeedamine	?klienditeedamine =damine  (SgN  >kliendi+tee+damine !10_A	et	f	\N
197615	klienditeedamine	?klienditeedamine =teedamine  (SgN  >kliendi+teedamine !12_S	et	f	\N
197616	klienditeedamine	?klienditeedamine =teedamine  (PlP  >kliendi+teedamin !19_S	et	f	\N
197630	ord	?ord =ord  (SgN  >ord !22_S	et	f	\N
197652	psuhholoogija	?psuhholoogija =psuhholoogija  (SgN  >psuhholoogija !01_S	et	f	\N
197653	psuhholoogija	?psuhholoogija =psuhholoogija  (SgG  >psuhholoogija !01_S	et	f	\N
197654	psuhholoogija	?psuhholoogija =psuhholoogija  (SgG  >psuhholoogijas !02_A	et	f	\N
197658	igasugusi	?igasugusi =igasugusi  (PlP  >igasugus !11_S	et	f	\N
197659	igasugusi	?igasugusi =sugusi  (SgG  >iga+sugus !02_A	et	f	\N
197660	müümist	müümist =müümis  (SgP  >müümine !12?10_S	et	f	\N
197661	müümist	"müümine %müü  )MINE_vS  <müüma ;38_V	et	f	\N
197676	kivilisse	kivilisse =kivilis  (SgAdt  >kiviline !12_A	et	f	\N
197677	kivilisse	"kiviline %kivi  )LINE_aA  <kivi ;17_S	et	f	\N
197684	kuuldsin	?kuuldsin =kuuldsi  (IndPrSg1  >kuuldsima !28_V	et	f	\N
197685	kuuldsin	?kuuldsin =kuuldsin  (SgN  >kuuldsin !02_S	et	f	\N
197692	kirjatänan	?kirjatänan =kirjatänan  (SgN  >kirjatänan !19_S	et	f	\N
197693	kirjatänan	?kirjatänan =tänan  (SgN  >kirja+tänan !02_S	et	f	\N
197728	piletimüja	?piletimüja =piletimüja  (SgN  >piletimüja !16_S	et	f	\N
197729	piletimüja	?piletimüja =piletimüja  (SgG  >piletimüjas !02_A	et	f	\N
197730	piletimüja	?piletimüja =piletimüja  (SgG  >piletimüja !16_S	et	f	\N
197731	piletimüja	?piletimüja =müja  (SgN  >pileti+müja !17_S	et	f	\N
197732	piletimüja	?piletimüja =müja  (SgG  >pileti+müja !17_S	et	f	\N
197733	piletimüja	?piletimüja =müja  (SgP  >pileti+müja !17_S	et	f	\N
197734	kiviolis	?kiviolis =kivioli  (SgIn  >kivioli !16_S	et	f	\N
197735	kiviolis	?kiviolis =kivioli  (SgIn  >kiviol !19_S	et	f	\N
197736	kiviolis	?kiviolis =kivioli  (IndIpfSg3  >kiviolima !28_V	et	f	\N
197737	kiviolis	?kiviolis =kiviolis  (SgN  >kiviolis !09_S	et	f	\N
197738	kiviolis	?kiviolis =oli  (SgIn  >kivi+oli !17_S	et	f	\N
197739	kiviolis	?kiviolis =olis  (SgN  >kivi+olis !09_S	et	f	\N
197753	kliediga	?kliediga =kliedi  (SgKom  >kliedi !16_S	et	f	\N
197754	kliediga	?kliediga =kliedi  (SgKom  >kliet !22_S	et	f	\N
197761	buusiga	?buusiga =buusi  (SgKom  >buusi !16_S	et	f	\N
197762	buusiga	?buusiga =buusi  (SgKom  >buus !22_S	et	f	\N
197780	hoteel	?hoteel =hotee  (SgAd  >hotee !26_S	et	f	\N
197546	plaier	?plaier =plaier  (SgN  >plaier !02_S	et	f	\N
197547	kontakst	?kontakst =kontakst  (SgN  >kontakst !22_S	et	f	\N
197548	kontakst	?kontakst =akst  (SgN  >kont+akst !22_S	et	f	\N
197557	esimiset	### esimiset	et	f	\N
197563	muutuse	muutuse =muutuse  (SgG  >muutus !11~09_S	et	f	\N
197564	muutuse	"muutus %muu  )TUS2_aS  <muu ;26_S	et	f	\N
197599	tööõigus	tööõigus =õigus  (SgN  >töö+õigus !11~09_S	et	f	\N
197600	tööõigus	"töö+õigus %õige  )US_aS  <töö+õige ;01_A	et	f	\N
197617	inimeseidega	?inimeseidega =inimesei  (PlKom  >inimesei !26_S	et	f	\N
197618	inimeseidega	?inimeseidega =ide  (SgKom  >inimese+ide !16_S	et	f	\N
197619	inimeseidega	?inimeseidega =esei  (PlKom  >inim+esei !26_S	et	f	\N
197620	nägesemini	?nägesemini =nägesemi  (SgTer  >nägesem !02_A	et	f	\N
197621	nägesemini	?nägesemini =nägesemini  (ID  >nägesemini !41_D	et	f	\N
197622	nägesemini	?nägesemini =nägesemini  (SgG  >nägesemin !19_S	et	f	\N
197623	nägesemini	?nägesemini =nägesemini  (SgP  >nägesemin !19_S	et	f	\N
197624	nägesemini	?nägesemini =nägesemini  (SgAdt  >nägesemin !19_S	et	f	\N
197638	sullega	### sullega	et	f	\N
197644	fotoatelje	?fotoatelje =atelje  (SgN  >foto+atelje !16_S	et	f	\N
197645	fotoatelje	?fotoatelje =atelje  (SgG  >foto+atelje !16_S	et	f	\N
197646	viiekorruselise	viiekorruselise =korruselise  (SgG  >viie+korruseline !12_A	et	f	\N
197647	viiekorruselise	"viie+korruseline %korruse  )LINE_aA  <viie+korrus ;09_S	et	f	\N
197648	korterväga	### korterväga	et	f	\N
197667	kliendidele	### kliendidele	et	f	\N
197679	kiirust	kiirust =kiiru  (SgEl  >kiird !22_S	et	f	\N
197680	kiirust	kiirust =kiiru  (SgEl  >kiir !22_S	et	f	\N
197681	kiirust	kiirust =kiirus  (SgP  >kiirus !11~09_S	et	f	\N
197682	kiirust	"kiirus %kiire  )US_aS  <kiire ;01_A	et	f	\N
197683	kiirust	kiirust =us  (SgP  >kiir+uks !14_S	et	f	\N
197705	puhkuselt	puhkuselt =puhkuse  (SgAbl  >puhkus !11~09_S	et	f	\N
197706	puhkuselt	puhkuselt =use  (PlAbl  >puhk+usk !22_S	et	f	\N
197709	paräst	?paräst =paräst  (SgN  >paräst !22_S	et	f	\N
197712	pahe	pahe =pahe  (SgN  >pahe !16_S	et	f	\N
197713	pahe	pahe =pahe  (SgG  >pahe !16_S	et	f	\N
197714	rõmus	?rõmus =rõmu  (SgIn  >rõmu !17_S	et	f	\N
197715	rõmus	?rõmus =rõmu  (IndIpfSg3  >rõmuma !27_V	et	f	\N
197716	rõmus	?rõmus =rõmus  (SgN  >rõmus !09_S	et	f	\N
197717	kule	?kule =kule  (SgN  >kule !16_S	et	f	\N
197718	kule	?kule =kule  (SgG  >kule !16_S	et	f	\N
197719	kule	?kule =kule  (IndPrPs_  >kulema !27_V	et	f	\N
197720	kule	?kule =kule  (ImpPrSg2  >kulema !27_V	et	f	\N
197721	kaugeselt	?kaugeselt =kaugese  (SgAbl  >kaugene !10_A	et	f	\N
197722	kaugeselt	?kaugeselt =kaugeselt  (ID  >kaugeselt !41_D	et	f	\N
197723	meire	?meire =meire  (SgN  >meire !06_S	et	f	\N
197724	meire	?meire =meire  (SgG  >meire !06_S	et	f	\N
197725	meire	?meire =meire  (PlP  >meir !22_S	et	f	\N
197726	meire	?meire =meire  (IndPrPs_  >meirema !27_V	et	f	\N
197727	meire	?meire =meire  (ImpPrSg2  >meirema !27_V	et	f	\N
197751	tööturgu	tööturgu =turgu  (SgP  >töö+turg !22_S	et	f	\N
197752	tööturgu	tööturgu =turgu  (SgAdt  >töö+turg !22_S	et	f	\N
197768	kõrras	?kõrras =kõrra  (SgIn  >kõrra !16_S	et	f	\N
197769	kõrras	?kõrras =kõrra  (IndIpfSg3  >kõrrama !29_V	et	f	\N
197770	kõrras	?kõrras =kõrras  (SgN  >kõrras !07_S	et	f	\N
197809	kohtumeni	?kohtumeni =kohtumeni  (SgG  >kohtumen !19_S	et	f	\N
197810	kohtumeni	?kohtumeni =kohtumeni  (SgP  >kohtumen !19_S	et	f	\N
197811	kohtumeni	?kohtumeni =kohtumeni  (SgAdt  >kohtumen !19_S	et	f	\N
197812	kohtumeni	?kohtumeni =meni  (SgN  >kohtu+meni !17_S	et	f	\N
197813	kohtumeni	?kohtumeni =meni  (SgG  >kohtu+meni !17_S	et	f	\N
197814	kohtumeni	?kohtumeni =meni  (SgP  >kohtu+meni !17_S	et	f	\N
197815	kohtumeni	?kohtumeni =ume  (SgTer  >koht+ume !16_S	et	f	\N
197816	kohtumeni	?kohtumeni =umeni  (SgG  >koht+umen !02_S	et	f	\N
197825	jüba	?jüba =jüba  (SgN  >jüba !17_S	et	f	\N
197826	jüba	?jüba =jüba  (SgG  >jüba !17_S	et	f	\N
197827	jüba	?jüba =jüba  (SgP  >jüba !17_S	et	f	\N
197828	jüba	?jüba =jüba  (IndPrPs_  >jübama !27_V	et	f	\N
197829	jüba	?jüba =jüba  (ImpPrSg2  >jübama !27_V	et	f	\N
197830	töölagris	?töölagris =töölagri  (SgIn  >töölagri !01_S	et	f	\N
197831	töölagris	?töölagris =töölagri  (IndIpfSg3  >töölagrima !28_V	et	f	\N
197832	töölagris	?töölagris =töölagris  (SgN  >töölagris !11_S	et	f	\N
197833	töölagris	?töölagris =agri  (SgIn  >tööl+agri !16_S	et	f	\N
197834	töölagris	?töölagris =agris  (SgN  >tööl+agris !09_S	et	f	\N
197835	töölagris	?töölagris =lagri  (SgIn  >töö+lagri !16_S	et	f	\N
197836	töölagris	?töölagris =lagris  (SgN  >töö+lagris !09_S	et	f	\N
197854	kostroma	?kostroma =kostroma  (SgN  >kostroma !01_S	et	f	\N
197855	kostroma	?kostroma =kostroma  (SgG  >kostroma !01_S	et	f	\N
197872	kohtumisumi	?kohtumisumi =kohtumisumi  (SgG  >kohtumisum !19_S	et	f	\N
197874	kohtumisumi	?kohtumisumi =kohtumisumi  (SgP  >kohtumisum !19_S	et	f	\N
197876	kohtumisumi	?kohtumisumi =kohtumisumi  (SgAdt  >kohtumisum !19_S	et	f	\N
197878	kohtumisumi	?kohtumisumi =umi  (SgN  >kohtu+mis+umi !17_S	et	f	\N
197560	koduülesandid	koduülesandid =sandi  (PlN  >kodu+üle+sand !22_S	et	f	\N
197561	koduülesandid	koduülesandid =sandi  (PlN  >kodu+üle+sant !22_SA	et	f	\N
197562	kodusbr	?kodusbr =kodusbr  (SgN  >kodusbr !22_S	et	f	\N
197575	ordi	?ordi =ordi  (ID  >ordi !41_D	et	f	\N
197576	ordi	?ordi =ordi  (SgG  >ort !22_S	et	f	\N
197577	ordi	?ordi =ordi  (SgP  >ord !22_S	et	f	\N
197578	ordi	?ordi =ordi  (SgAdt  >ord !22_S	et	f	\N
197579	ordi	?ordi =ordi  (IndPrPs_  >ortima !28_V	et	f	\N
197580	ordi	?ordi =ordi  (ImpPrSg2  >ortima !28_V	et	f	\N
197588	pladid	?pladid =pladi  (PlN  >pladi !17_S	et	f	\N
197589	pladid	?pladid =pladi  (IndPrSg2  >pladima !27_V	et	f	\N
197604	tööitad	?tööitad =tööita  (IndPrSg2  >tööitama !27_V	et	f	\N
197605	tööitad	?tööitad =ita  (PlN  >töö+ita !16_S	et	f	\N
197608	asjaajamist	asjaajamist =ajami  (SgEl  >asja+ajam !02_S	et	f	\N
197609	asjaajamist	asjaajamist =ajamis  (SgP  >asja+ajamine !12_S	et	f	\N
197610	asjaajamist	"asja+ajamine %ajami  )NE_aA  <asja+ajam ;02_S	et	f	\N
197631	killometris	?killometris =killometri  (SgIn  >killometter !02_S	et	f	\N
197632	killometris	?killometris =killometri  (IndIpfSg3  >killometrima !28_V	et	f	\N
197633	killometris	?killometris =killometris  (SgN  >killometris !09_S	et	f	\N
197637	astar	?astar =astar  (SgN  >astar !02_S	et	f	\N
197707	sõbanna	?sõbanna =sõbanna  (SgN  >sõbanna !16_S	et	f	\N
197708	sõbanna	?sõbanna =sõbanna  (SgG  >sõbanna !16_S	et	f	\N
197710	läksima	?läksima =läksi  (Sup  >läksima !28_V	et	f	\N
197711	läksima	?läksima =läksima  (SgG  >läksim !02_A	et	f	\N
197748	õnnetlen	?õnnetlen =õnnetle  (IndPrSg1  >õnnetlema !27_V	et	f	\N
197749	õnnetlen	?õnnetlen =õnnetlen  (SgN  >õnnetlen !19_S	et	f	\N
197755	peteerburgis	?peteerburgis =peteerburgi  (SgIn  >peteerburk !22_S	et	f	\N
197756	peteerburgis	?peteerburgis =peteerburgi  (IndIpfSg3  >peteerburgima !28_V	et	f	\N
197757	peteerburgis	?peteerburgis =peteerburgis  (SgN  >peteerburgis !09_S	et	f	\N
197771	odessasse	?odessasse =odessa  (SgIll  >odessa !01_S	et	f	\N
197772	odessasse	?odessasse =odessas  (SgAdt  >odessane !12_A	et	f	\N
197773	odessasse	?odessasse =odessasse  (SgG  >odessasne !02_A	et	f	\N
197774	odessasse	?odessasse =odessasse  (PlP  >odessass !22_S	et	f	\N
197791	eestimisel	?eestimisel =eestimise  (SgAd  >eestimine !12_S	et	f	\N
197792	eestimisel	?eestimisel =imise  (SgAd  >eest+imine !10_A	et	f	\N
197793	eestimisel	?eestimisel =imisel  (SgN  >eest+imisel !19_S	et	f	\N
197794	eestimisel	?eestimisel =timise  (SgAd  >ees+timine !10_A	et	f	\N
197795	eestimisel	?eestimisel =timisel  (SgN  >ees+timisel !19_S	et	f	\N
197798	kremle	?kremle =kremle  (SgN  >kremle !06_S	et	f	\N
197799	kremle	?kremle =kremle  (SgG  >kremle !06_S	et	f	\N
197800	kremle	?kremle =kremle  (IndPrPs_  >kremlema !30_V	et	f	\N
197801	kremle	?kremle =kremle  (ImpPrSg2  >kremlema !30_V	et	f	\N
197817	1februaril	?februaril =februari  (SgAd  >februari !16_S	et	f	\N
197818	1februaril	?februaril =februari  (SgAd  >februar !19_S	et	f	\N
197819	1februaril	?februaril =februaril  (SgN  >februaril !02_S	et	f	\N
197842	kaheteistkümmnendal	?kaheteistkümmnendal =kaheteistkümmnenda  (SgAd  >kaheteistkümmnenda !16_S	et	f	\N
197843	kaheteistkümmnendal	?kaheteistkümmnendal =kaheteistkümmnendal  (SgN  >kaheteistkümmnendal !02_S	et	f	\N
197844	kaheteistkümmnendal	?kaheteistkümmnendal =kümmnenda  (SgAd  >kahe+teist+kümmnenda !01_S	et	f	\N
197845	kaheteistkümmnendal	?kaheteistkümmnendal =teistkümmnenda  (SgAd  >kahe+teistkümmnenda !16_S	et	f	\N
197846	kaheteistkümmnendal	?kaheteistkümmnendal =teistkümmnendal  (SgN  >kahe+teistkümmnendal !02_S	et	f	\N
197849	kiirestan	?kiirestan =kiiresta  (IndPrSg1  >kiirestama !27_V	et	f	\N
197850	kiirestan	?kiirestan =kiirestan  (SgN  >kiirestan !19_S	et	f	\N
197851	kiirestan	?kiirestan =estan  (SgN  >kiir+estan !02_S	et	f	\N
197852	kostromas	?kostromas =kostroma  (SgIn  >kostroma !01_S	et	f	\N
197857	raudutee	raudutee =tee  (SgN  >raudu+tee !26_S	et	f	\N
197858	raudutee	raudutee =tee  (SgG  >raudu+tee !26_S	et	f	\N
197859	plaaniten	?plaaniten =plaaniten  (SgN  >plaaniten !19_S	et	f	\N
197864	juks	?juks =juks  (SgN  >juks !22_S	et	f	\N
197866	sõbran	?sõbran =sõbra  (IndPrSg1  >sõbrama !27_V	et	f	\N
197867	sõbran	?sõbran =sõbran  (SgN  >sõbran !02_S	et	f	\N
197901	suvorovski	?suvorovski =suvorovski  (IndPrPs_  >suvorovskima !28_V	et	f	\N
197902	suvorovski	?suvorovski =suvorovski  (ImpPrSg2  >suvorovskima !28_V	et	f	\N
197903	suvorovski	?suvorovski =suvorovs  (SgN^  >suvorovs !22_S	et	f	\N
197928	kunstimuseum	?kunstimuseum =kunstimuseum  (SgN  >kunstimuseum !19_S	et	f	\N
197929	kunstimuseum	?kunstimuseum =museum  (SgN  >kunsti+museum !22_S	et	f	\N
197930	kunstimuseum	?kunstimuseum =imuseum  (SgN  >kunst+imuseum !19_S	et	f	\N
197945	häste	?häste =häste  (SgN  >häste !06_S	et	f	\N
197946	häste	?häste =häste  (SgG  >häste !06_S	et	f	\N
197947	häste	?häste =häste  (PlP  >häst !22_S	et	f	\N
197948	häste	?häste =häste  (IndPrPs_  >hästema !27_V	et	f	\N
197949	häste	?häste =häste  (ImpPrSg2  >hästema !27_V	et	f	\N
197976	õlikikvide	?õlikikvide =õlikikvi  (PlG  >õlikikv !22_S	et	f	\N
197977	õlikikvide	?õlikikvide =kikvi  (PlG  >õli+kikvi !16_S	et	f	\N
197978	õlikikvide	?õlikikvide =kikvi  (PlG  >õli+kikv !22_S	et	f	\N
197696	jaanuarni	?jaanuarni =jaanuarni  (SgAdt  >jaanuarn !22_S	et	f	\N
197697	jaanuarni	?jaanuarni =jaanuarni  (IndPrPs_  >jaanuarnima !28_V	et	f	\N
197698	jaanuarni	?jaanuarni =jaanuarni  (ImpPrSg2  >jaanuarnima !28_V	et	f	\N
197701	juriist	?juriist =jurii  (SgEl  >jurii !26_S	et	f	\N
197702	juriist	?juriist =juriist  (SgN  >juriist !22_S	et	f	\N
197744	virgi	virgi =virgi  (SgG  >virk !22_A	et	f	\N
197745	virgi	virgi =virgi  (SgP  >virg !22_S	et	f	\N
197746	virgi	virgi =virgi  (SgAdt  >virg !22_S	et	f	\N
197747	virgi	virgi =virgi  (PlP  >virg !22_S	et	f	\N
197758	peteerburgis	?peteerburgis =peteerburgi  (SgIn  >peteerburk !22_S	et	f	\N
197759	peteerburgis	?peteerburgis =peteerburgi  (IndIpfSg3  >peteerburgima !28_V	et	f	\N
197760	peteerburgis	?peteerburgis =peteerburgis  (SgN  >peteerburgis !09_S	et	f	\N
197776	hoteelis	?hoteelis =hoteeli  (SgIn  >hoteeli !16_S	et	f	\N
197777	hoteelis	?hoteelis =hoteeli  (SgIn  >hoteel !22_S	et	f	\N
197778	hoteelis	?hoteelis =hoteeli  (IndIpfSg3  >hoteelima !28_V	et	f	\N
197779	hoteelis	?hoteelis =hoteelis  (SgN  >hoteelis !09_S	et	f	\N
197782	reeisin	?reeisin =reeisi  (IndPrSg1  >reeisima !28_V	et	f	\N
197783	reeisin	?reeisin =reeisin  (SgN  >reeisin !02_S	et	f	\N
197784	reeisin	?reeisin =isin  (SgN  >ree+isin !02_S	et	f	\N
197789	novgorodisse	?novgorodisse =novgorodisse  (SgG  >novgorodisne !02_A	et	f	\N
197790	novgorodisse	?novgorodisse =novgorodisse  (PlP  >novgorodiss !22_S	et	f	\N
197802	puhkekodu	puhkekodu =kodu  (SgN  >puhke+kodu !17_S	et	f	\N
197803	puhkekodu	puhkekodu =kodu  (SgG  >puhke+kodu !17_S	et	f	\N
197804	puhkekodu	puhkekodu =kodu  (SgP  >puhke+kodu !17_S	et	f	\N
197807	puhkedust	puhkedust =dust  (SgN  >puhke+dust !22_S	et	f	\N
197808	puhkedust	puhkedust =edu  (SgEl  >puhk+edu !17_S	et	f	\N
197820	peterburii	?peterburii =peterburii  (SgN  >peterburii !26_S	et	f	\N
197821	peterburii	?peterburii =peterburii  (SgG  >peterburii !26_S	et	f	\N
197822	ilusamaid	ilusamaid =ilusama  (PlP  >ilusam !02_A	et	f	\N
197823	ilusamaid	"ilusam %ilusa  )M_cA  <ilus ;02_A	et	f	\N
197847	08062005a	### 08062005a	et	f	\N
197848	pongiga	?pongiga =pongi  (SgKom  >ponk !22_S	et	f	\N
197853	busisa	?busisa =busisa  (SgN  >busisa !01_S	et	f	\N
197856	busisa	?busisa =busisa  (SgG  >busisa !01_S	et	f	\N
197865	nedelas	?nedelas =nedela  (SgIn  >nedela !01_S	et	f	\N
197869	nedalat	?nedalat =nedala  (SgP  >nedala !01_S	et	f	\N
197887	lossides	lossides =lossi  (PlIn  >loss !22_S	et	f	\N
197888	lossides	lossides =lossi  (Ger  >lossima !28_V	et	f	\N
197904	pujesteel	?pujesteel =pujestee  (SgAd  >pujestee !26_S	et	f	\N
197905	pujesteel	?pujesteel =pujesteel  (SgN  >pujesteel !22_S	et	f	\N
197908	komunaalkorteris	?komunaalkorteris =komunaalkorteri  (SgIn  >komunaalkorter !02_S	et	f	\N
197909	komunaalkorteris	?komunaalkorteris =komunaalkorteris  (SgN  >komunaalkorteris !09_S	et	f	\N
197910	komunaalkorteris	?komunaalkorteris =unaalkorteri  (SgIn  >kom+unaalkorter !02_S	et	f	\N
197911	komunaalkorteris	?komunaalkorteris =unaalkorteris  (SgN  >kom+unaalkorteris !09_S	et	f	\N
197931	nädel	?nädel =näde  (SgAd  >näde !16_S	et	f	\N
197933	nädel	?nädel =nädel  (SgN  >nädel !02_S	et	f	\N
197936	tervituti	?tervituti =tervitu  (IndIpfIps  >tervituma !27_V	et	f	\N
197937	tervituti	?tervituti =tervituti  (SgG  >tervitutt !22_S	et	f	\N
197938	tervituti	?tervituti =tervituti  (IndPrPs_  >tervituttima !28_V	et	f	\N
197939	tervituti	?tervituti =tervituti  (ImpPrSg2  >tervituttima !28_V	et	f	\N
197966	võiu	?võiu =võiu  (SgN  >võiu !16_S	et	f	\N
197967	võiu	?võiu =võiu  (SgG  >võiu !16_S	et	f	\N
197968	võiu	?võiu =võiu  (IndPrPs_  >võiuma !27_V	et	f	\N
197969	võiu	?võiu =võiu  (ImpPrSg2  >võiuma !27_V	et	f	\N
197980	vabadusse	vabadusse =vabadus  (SgAdt  >vabadus !11_S	et	f	\N
197981	vabadusse	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
197984	kõvemaks	kõvemaks =kõvema  (SgTr  >kõvem !02_A	et	f	\N
197985	kõvemaks	"kõvem %kõve  )M_cA  <kõva ;17_A	et	f	\N
197996	vanemmeelsem	vanemmeelsem =meelsem  (SgN  >vanem+meelsem !02_A	et	f	\N
197997	vanemmeelsem	"vanem+meelsem %meelse  )M_cA  <vanem+meelne ;02_A	et	f	\N
197999	kuiroteod	?kuiroteod =kuiroteo  (PlN  >kuiroteo !01_S	et	f	\N
198000	kuiroteod	?kuiroteod =kuiroteod  (SgN  >kuiroteod !22_S	et	f	\N
198001	kuiroteod	?kuiroteod =roteo  (PlN  >kui+roteo !01_S	et	f	\N
198002	kuiroteod	?kuiroteod =roteod  (SgN  >kui+roteod !22_S	et	f	\N
198003	ohtlikute	?ohtlikute =ohtliku  (PlG  >ohtliku !01_S	et	f	\N
198004	ohtlikute	?ohtlikute =ohtliku  (IndPrPl2  >ohtlikuma !27_V	et	f	\N
198014	sellesteest	sellesteest =ee  (SgEl  >sellest+esi !15_S	et	f	\N
198015	sellesteest	sellesteest =ees  (SgP  >sellest+eene !10_A	et	f	\N
198016	sellesteest	"sellest+eene %ee  )NE_aA  <sellest+esi ;15_S	et	f	\N
198017	põlvedele	põlvedele =põlve  (PlAll  >põlv !22_S	et	f	\N
198018	põlvedele	põlvedele =põlve  (PlAll  >põli !24_S	et	f	\N
198019	põlvedele	põlvedele =ede  (SgAll  >põlv+ede !16_S	et	f	\N
198022	hoolitseksid	hoolitseksid =hoolitse  (KndPrSg2  >hoolitsema !27_V	et	f	\N
198023	hoolitseksid	hoolitseksid =hoolitse  (KndPrPl3  >hoolitsema !27_V	et	f	\N
198048	koolivoimla	?koolivoimla =koolivoimla  (SgN  >koolivoimla !01_S	et	f	\N
198049	koolivoimla	?koolivoimla =koolivoimla  (SgG  >koolivoimla !01_S	et	f	\N
197781	hoteel	?hoteel =hoteel  (SgN  >hoteel !22_S	et	f	\N
197805	liivane	liivane =liivane  (SgN  >liivane !10_A	et	f	\N
197806	liivane	"liivane %liiva  )NE_aA  <liiv ;22_S	et	f	\N
197862	juks	?juks =juks  (SgN  >juks !22_S	et	f	\N
197889	kirikutesses	?kirikutesses =kirikutesse  (SgIn  >kirikutesne !02_A	et	f	\N
197890	kirikutesses	?kirikutesses =kirikutesse  (PlIn  >kirikutess !22_S	et	f	\N
197891	kirikutesses	?kirikutesses =tesse  (SgIn  >kiriku+tesne !02_A	et	f	\N
197892	kirikutesses	?kirikutesses =tesse  (SgIn  >kiriku+tesse !06_S	et	f	\N
197893	kirikutesses	?kirikutesses =tesse  (PlIn  >kiriku+tess !22_S	et	f	\N
197894	kirikutesses	?kirikutesses =tesses  (SgN  >kiriku+tesses !09_S	et	f	\N
197895	kirikutesses	?kirikutesses =utesse  (SgIn  >kirik+utesne !02_A	et	f	\N
197896	kirikutesses	?kirikutesses =utesse  (PlIn  >kirik+utess !22_S	et	f	\N
197897	kirikutesses	?kirikutesses =kutesse  (SgIn  >kiri+kutesne !02_A	et	f	\N
197898	kirikutesses	?kirikutesses =kutesse  (PlIn  >kiri+kutess !22_S	et	f	\N
197912	intelligeentne	?intelligeentne =intelligeentne  (SgN  >intelligeentne !02_A	et	f	\N
197921	tütruga	### tütruga	et	f	\N
197922	tuhand	?tuhand =tuhand  (SgN  >tuhand !02_S	et	f	\N
197953	köisime	?köisime =köisi  (IndPrPl1  >köisima !28_V	et	f	\N
197957	vjasniki	?vjasniki =vjasniki  (SgN  >vjasniki !01_S	et	f	\N
197958	vjasniki	?vjasniki =vjasniki  (SgG  >vjasniki !01_S	et	f	\N
197959	vjasniki	?vjasniki =vjasniki  (SgG  >vjasnik !02_S	et	f	\N
197960	vjasniki	?vjasniki =vjasniki  (IndPrPs_  >vjasnikkima !28_V	et	f	\N
197961	vjasniki	?vjasniki =vjasniki  (ImpPrSg2  >vjasnikkima !28_V	et	f	\N
197972	mõjumist	mõjumist =mõjumis  (SgP  >mõjumine !12_S	et	f	\N
197973	mõjumist	"mõjumine %mõju  )MINE_vS  <mõjuma ;27_V	et	f	\N
197974	majandusteadus	majandusteadus =teadu  (SgIn  >majandus+tead !22_S	et	f	\N
197975	majandusteadus	majandusteadus =teadus  (SgN  >majandus+teadus !11~09_S	et	f	\N
197987	lõppul	?lõppul =lõppul  (SgN  >lõppul !02_S	et	f	\N
197993	maksutasu	maksutasu =tasu  (SgN  >maksu+tasu !17_S	et	f	\N
197994	maksutasu	maksutasu =tasu  (SgG  >maksu+tasu !17_S	et	f	\N
197995	maksutasu	maksutasu =tasu  (SgP  >maksu+tasu !17_S	et	f	\N
197998	gorbatsõvi	### gorbatsõvi	et	f	\N
198005	effektiivseltne	?effektiivseltne =effektiivseltne  (SgN  >effektiivseltne !02_A	et	f	\N
198006	suitsuotsi	suitsuotsi =otsi  (SgG  >suitsu+ots !22_S	et	f	\N
198007	suitsuotsi	suitsuotsi =otsi  (SgP  >suitsu+ots !22_S	et	f	\N
198008	suitsuotsi	suitsuotsi =otsi  (SgAdt  >suitsu+ots !22_S	et	f	\N
198009	suitsuotsi	suitsuotsi =otsi  (PlP  >suitsu+ots !23?22_S	et	f	\N
198012	rjaksin	?rjaksin =rjaksi  (IndPrSg1  >rjaksima !28_V	et	f	\N
198013	rjaksin	?rjaksin =rjaksin  (SgN  >rjaksin !02_S	et	f	\N
198027	väke	?väke =väke  (SgN  >väke !06_S	et	f	\N
198028	väke	?väke =väke  (IndPrPs_  >väkema !27_V	et	f	\N
198029	väke	?väke =väke  (ImpPrSg2  >väkema !27_V	et	f	\N
198060	puhkeruumi	puhkeruumi =ruumi  (SgG  >puhke+ruum !22_S	et	f	\N
198061	puhkeruumi	puhkeruumi =ruumi  (SgP  >puhke+ruum !22_S	et	f	\N
198062	puhkeruumi	puhkeruumi =ruumi  (SgAdt  >puhke+ruum !22_S	et	f	\N
198066	muretsemine	muretsemine =muretsemine  (SgN  >muretsemine !12_S	et	f	\N
198068	muretsemine	"muretsemine %muretse  )MINE_vS  <muretsema ;27_V	et	f	\N
198074	shnitsel	?shnitsel =shnitse  (SgAd  >shnitne !02_A	et	f	\N
198075	shnitsel	?shnitsel =shnitse  (SgAd  >shnitse !06_S	et	f	\N
198076	shnitsel	?shnitsel =shnitse  (PlAd  >shnits !22_S	et	f	\N
198077	shnitsel	?shnitsel =shnitsel  (SgN  >shnitsel !02_S	et	f	\N
198090	organismi	organismi =organismi  (SgG  >organism !22_S	et	f	\N
198091	organismi	organismi =organismi  (SgP  >organism !22_S	et	f	\N
198092	organismi	organismi =organismi  (SgAdt  >organism !22_S	et	f	\N
198102	peizhaas	?peizhaas =peizhaa  (SgIn  >peizhaa !26_S	et	f	\N
198103	peizhaas	?peizhaas =peizhaas  (SgN  >peizhaas !22_S	et	f	\N
198109	roheliste	roheliste =rohelis  (PlG  >roheline !12_A	et	f	\N
198110	roheliste	"roheline %rohe  )LINE_aA  <rohe ;16_S	et	f	\N
198128	püüüan	?püüüan =püüüan  (SgN  >püüüan !22_S	et	f	\N
198135	klasisse	?klasisse =klasi  (SgIll  >klasi !17_S	et	f	\N
198136	klasisse	?klasisse =klasisse  (SgG  >klasisne !02_A	et	f	\N
198137	klasisse	?klasisse =klasisse  (PlP  >klasiss !22_S	et	f	\N
198151	sidunud	sidunud =sidu  (PtsPtPs  >siduma !28_V	et	f	\N
198152	sidunud	sidunud =sidunu  (PlN  >sidunu !01_S	et	f	\N
198153	sidunud	"sidunu %sidu  )NU_vS  <siduma ;28_V	et	f	\N
198154	sidunud	sidunud =sidunud  (ID  >sidunud !41_A	et	f	\N
198155	sidunud	"sidunud %sidu  )NUD_vA  <siduma ;28_V	et	f	\N
198213	eesmärgiletal	?eesmärgiletal =eesmärgiletal  (SgN  >eesmärgiletal !19_S	et	f	\N
198214	eesmärgiletal	?eesmärgiletal =leta  (SgAd  >ees+märgi+leta !16_S	et	f	\N
198215	eesmärgiletal	?eesmärgiletal =letal  (SgN  >ees+märgi+letal !02_S	et	f	\N
198216	eesmärgiletal	?eesmärgiletal =märgiletal  (SgN  >ees+märgiletal !19_S	et	f	\N
198226	7mis	mis =mis  (SgN  >mis !00_P	et	f	\N
198227	7mis	mis =mis  (PlN  >mis !00_P	et	f	\N
198228	7mis	mis =mi  (SgIn  >mi !26_S	et	f	\N
198235	parematest	parematest =parema  (PlEl  >parem !02_A	et	f	\N
198236	parematest	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
198237	parematest	parematest =test  (SgN  >parema+test !22_S	et	f	\N
197871	siina	?siina =siina  (SgN  >siina !16_S	et	f	\N
197873	siina	?siina =siina  (SgG  >siina !16_S	et	f	\N
197875	siina	?siina =siina  (IndPrPs_  >siinama !29_V	et	f	\N
197877	siina	?siina =siina  (ImpPrSg2  >siinama !29_V	et	f	\N
197899	natalia	?natalia =natalia  (SgN  >natalia !01_S	et	f	\N
197900	natalia	?natalia =natalia  (SgG  >natalia !01_S	et	f	\N
197906	külalisel	külalisel =külalise  (SgAd  >külaline !12_S	et	f	\N
197907	külalisel	"külaline %küla  )LINE_aA  <küla ;17_S	et	f	\N
197913	vologdas	?vologdas =vologda  (SgIn  >vologda !01_S	et	f	\N
197923	saranski	?saranski =saranski  (SgG  >saransk !02_S	et	f	\N
197924	saranski	?saranski =saranski  (IndPrPs_  >saranskima !28_V	et	f	\N
197925	saranski	?saranski =saranski  (ImpPrSg2  >saranskima !28_V	et	f	\N
197926	saranski	?saranski =sarans  (SgN^  >sarans !02_S	et	f	\N
197932	nägemisene	?nägemisene =nägemisene  (PlP  >nägemisen !19_S	et	f	\N
197934	nägemisene	?nägemisene =ene  (SgN  >nägemis+ene !16_S	et	f	\N
197935	nägemisene	?nägemisene =ene  (SgG  >nägemis+ene !16_S	et	f	\N
197950	näetus	?näetus =näetu  (SgIn  >näetu !01_A	et	f	\N
197951	näetus	?näetus =näetu  (IndIpfSg3  >näetuma !27_V	et	f	\N
197952	näetus	?näetus =näetus  (SgN  >näetus !11~09_S	et	f	\N
197954	vladimiri	?vladimiri =vladimiri  (SgG  >vladimir !19_S	et	f	\N
197955	vladimiri	?vladimiri =vladimiri  (SgP  >vladimir !19_S	et	f	\N
197956	vladimiri	?vladimiri =vladimiri  (SgAdt  >vladimir !19_S	et	f	\N
197962	nägimiseni	?nägimiseni =nägimise  (SgTer  >nägimine !12_S	et	f	\N
197963	nägimiseni	?nägimiseni =nägimiseni  (SgG  >nägimisen !19_S	et	f	\N
197964	nägimiseni	?nägimiseni =nägimiseni  (SgP  >nägimisen !19_S	et	f	\N
197965	nägimiseni	?nägimiseni =nägimiseni  (SgAdt  >nägimisen !19_S	et	f	\N
197988	kingiseff	?kingiseff =kingiseff  (SgN  >kingiseff !22_S	et	f	\N
197989	kingiseff	?kingiseff =eff  (SgN  >kingis+eff !22_S	et	f	\N
197990	kingiseff	?kingiseff =seff  (SgN  >kingi+seff !22_S	et	f	\N
197991	kingiseff	?kingiseff =iseff  (SgN  >king+iseff !22_S	et	f	\N
198011	renoveerimise	?renoveerimise =renoveerimise  (SgG  >renoveerimine !12_S	et	f	\N
198025	teadmisipäev	?teadmisipäev =teadmisipäev  (SgN  >teadmisipäev !22_S	et	f	\N
198026	teadmisipäev	?teadmisipäev =ipäev  (SgN  >teadmis+ipäev !22_S	et	f	\N
198037	koolihoone	koolihoone =hoone  (SgN  >kooli+hoone !06_S	et	f	\N
198038	koolihoone	"kooli+hoone %hoo  )NE_aA  <kooli+hoog ;22_S	et	f	\N
198039	koolihoone	koolihoone =hoone  (SgG  >kooli+hoone !06_S	et	f	\N
198040	koolihoone	koolihoone =hoone  (PlP  >kooli+hoon !22_A	et	f	\N
198044	küsitluses	küsitluses =küsitluse  (SgIn  >küsitlus !11_S	et	f	\N
198045	küsitluses	"küsitlus %küsitle  )US_vS  <küsitlema ;27_V	et	f	\N
198069	õptamise	?õptamise =õptamise  (SgG  >õptamine !12_S	et	f	\N
198070	privaadis	?privaadis =privaadi  (SgIn  >privaadi !16_S	et	f	\N
198071	privaadis	?privaadis =privaadi  (SgIn  >privaat !22_S	et	f	\N
198072	privaadis	?privaadis =privaadi  (IndIpfSg3  >privaadima !28_V	et	f	\N
198073	privaadis	?privaadis =privaadis  (SgN  >privaadis !11_S	et	f	\N
198119	kesmisel	?kesmisel =kesmise  (SgAd  >kesmine !10_A	et	f	\N
198120	kesmisel	?kesmisel =kesmisel  (SgN  >kesmisel !19_S	et	f	\N
198121	koduseülesandeid	?koduseülesandeid =koduseülesandei  (PlN  >koduseülesandei !26_S	et	f	\N
198122	koduseülesandeid	?koduseülesandeid =koduseülesandei  (SgP  >koduseülesandei !26_S	et	f	\N
198123	koduseülesandeid	?koduseülesandeid =seülesandei  (PlN  >kodu+seülesandei !26_S	et	f	\N
198124	koduseülesandeid	?koduseülesandeid =seülesandei  (SgP  >kodu+seülesandei !26_S	et	f	\N
198138	kolmata	?kolmata =kolma  (SgAb  >kolma !16_S	et	f	\N
198139	kolmata	?kolmata =kolma  (Inf  >kolmama !29_V	et	f	\N
198140	kolmata	?kolmata =kolma  (IndPrIps_  >kolmama !29_V	et	f	\N
198141	kolmata	?kolmata =kolmata  (ID  >kolmata !41_A	et	f	\N
198142	kolmata	?kolmata =kolmata  (IndPrPs_  >kolmatama !27_V	et	f	\N
198143	kolmata	?kolmata =kolmata  (ImpPrSg2  >kolmatama !27_V	et	f	\N
198145	omadusi	omadusi =omadusi  (PlP  >omadus !11_S	et	f	\N
198146	omadusi	"omadus %oma  )US_aS  <oma ;17_A	et	f	\N
198147	elukeskond	?elukeskond =elukeskond  (SgN  >elukeskond !22_S	et	f	\N
198148	elukeskond	?elukeskond =ond  (SgN  >elu+kesk+ond !22_S	et	f	\N
198149	elukeskond	?elukeskond =keskond  (SgN  >elu+keskond !22_S	et	f	\N
198156	füloloogia	?füloloogia =füloloogia  (SgN  >füloloogia !01_S	et	f	\N
198157	füloloogia	?füloloogia =füloloogia  (SgG  >füloloogia !01_S	et	f	\N
198162	riigieksamide	?riigieksamide =ami  (PlG  >riigi+eks+ami !17_S	et	f	\N
198174	õppiks	### õppiks	et	f	\N
198182	kanatlikus	?kanatlikus =kanatliku  (SgIn  >kanatlik !25_A	et	f	\N
198183	kanatlikus	?kanatlikus =kanatliku  (IndIpfSg3  >kanatlikuma !27_V	et	f	\N
198184	kanatlikus	?kanatlikus =kanatlikus  (SgN  >kanatlikus !11?09_S	et	f	\N
198188	klassikaslaste	klassikaslaste =las  (PlG  >klassi+kas+laps !14_S	et	f	\N
198189	klassikaslaste	klassikaslaste =laste  (PlP  >klassi+kas+last !22_S	et	f	\N
198190	klassikaslaste	klassikaslaste =kaslas  (PlG  >klassi+kaslane !12?10_S	et	f	\N
198192	tahama	?tahama =taha  (Sup  >tahama !27_V	et	f	\N
198193	tahama	?tahama =tahama  (SgG  >taham !02_A	et	f	\N
198194	maailmasharidus	?maailmasharidus =maailmasharidu  (IndIpfSg3  >maailmashariduma !27_V	et	f	\N
197879	kohtumisumi	?kohtumisumi =umi  (SgG  >kohtu+mis+umi !17_S	et	f	\N
197880	kohtumisumi	?kohtumisumi =umi  (SgP  >kohtu+mis+umi !17_S	et	f	\N
197881	kohtumisumi	?kohtumisumi =misumi  (SgN  >kohtu+misumi !01_S	et	f	\N
197882	kohtumisumi	?kohtumisumi =misumi  (SgG  >kohtu+misumi !01_S	et	f	\N
197883	kohtumisumi	?kohtumisumi =misumi  (SgG  >kohtu+misum !02_S	et	f	\N
197884	kohtumisumi	?kohtumisumi =umisumi  (SgG  >koht+umisum !19_S	et	f	\N
197885	kohtumisumi	?kohtumisumi =umisumi  (SgP  >koht+umisum !19_S	et	f	\N
197886	kohtumisumi	?kohtumisumi =umisumi  (SgAdt  >koht+umisum !19_S	et	f	\N
197914	eksaamit	?eksaamit =eksaami  (SgP  >eksaami !16_S	et	f	\N
197915	eksaamit	?eksaamit =aami  (SgP  >eks+aami !16_S	et	f	\N
197916	eksaamit	?eksaamit =aamit  (SgN  >eks+aamit !02_S	et	f	\N
197917	mordvasse	?mordvasse =mordva  (SgIll  >mordev !02_A	et	f	\N
197918	mordvasse	?mordvasse =mordvas  (SgAdt  >mordvane !12_A	et	f	\N
197919	mordvasse	?mordvasse =mordvasse  (SgG  >mordvasne !02_A	et	f	\N
197920	mordvasse	?mordvasse =mordvasse  (PlP  >mordvass !22_S	et	f	\N
197927	saransk	?saransk =saransk  (SgN  >saransk !02_S	et	f	\N
197940	riina	?riina =rii  (SgEs  >rii !26_S	et	f	\N
197941	riina	?riina =riina  (SgN  >riina !16_S	et	f	\N
197942	riina	?riina =riina  (SgG  >riina !16_S	et	f	\N
197943	riina	?riina =riina  (IndPrPs_  >riinama !29_V	et	f	\N
197944	riina	?riina =riina  (ImpPrSg2  >riinama !29_V	et	f	\N
197970	bakterioloogia	bakterioloogia =bakterioloogia  (SgN  >bakterioloogia !01_S	et	f	\N
197971	bakterioloogia	bakterioloogia =bakterioloogia  (SgG  >bakterioloogia !01_S	et	f	\N
197979	laborotoorium	?laborotoorium =laborotoorium  (SgN  >laborotoorium !19~02_S	et	f	\N
197992	kd	### kd	et	f	\N
198030	klasisi	?klasisi =klasisi  (ID  >klasisi !41_D	et	f	\N
198031	vesllevad	?vesllevad =veslle  (IndPrPl3  >vesllema !30_V	et	f	\N
198032	vesllevad	?vesllevad =veslleva  (PlN  >veslleva !01_S	et	f	\N
198033	vesllevad	?vesllevad =veslleva  (PlN  >vesllev !02_A	et	f	\N
198041	kelllel	?kelllel =kellle  (SgAd  >kellle !06_S	et	f	\N
198042	kelllel	?kelllel =kellle  (PlAd  >kelll !22_S	et	f	\N
198043	kelllel	?kelllel =kelllel  (SgN  >kelllel !02_S	et	f	\N
198058	tähtsusjarjekorras	?tähtsusjarjekorras =tähtsusjarjekorra  (SgIn  >tähtsusjarjekorra !16_S	et	f	\N
198059	tähtsusjarjekorras	?tähtsusjarjekorras =susjarjekorra  (SgIn  >täht+susjarjekorra !16_S	et	f	\N
198063	koolivõimla	koolivõimla =võimla  (SgN  >kooli+võimla !01_S	et	f	\N
198064	koolivõimla	koolivõimla =võimla  (SgG  >kooli+võimla !01_S	et	f	\N
198097	sünnipäevasse	sünnipäevasse =asse  (PlP  >sünni+päev+ass !22_S	et	f	\N
198098	sünnipäevasse	sünnipäevasse =päeva  (SgIll  >sünni+päev !22_S	et	f	\N
198112	navigatsioonsüsteemi	?navigatsioonsüsteemi =navigatsioonsüsteemi  (SgN  >navigatsioonsüsteemi !16_S	et	f	\N
198113	navigatsioonsüsteemi	?navigatsioonsüsteemi =navigatsioonsüsteemi  (SgG  >navigatsioonsüsteemi !16_S	et	f	\N
198114	navigatsioonsüsteemi	?navigatsioonsüsteemi =navigatsioonsüsteemi  (SgG  >navigatsioonsüsteem !22_S	et	f	\N
198115	navigatsioonsüsteemi	?navigatsioonsüsteemi =navigatsioonsüsteemi  (SgP  >navigatsioonsüsteem !22_S	et	f	\N
198116	navigatsioonsüsteemi	?navigatsioonsüsteemi =navigatsioonsüsteemi  (SgAdt  >navigatsioonsüsteem !22_S	et	f	\N
198117	navigatsioonsüsteemi	?navigatsioonsüsteemi =navigatsioonsüsteemi  (IndPrPs_  >navigatsioonsüsteemima !28_V	et	f	\N
198118	navigatsioonsüsteemi	?navigatsioonsüsteemi =navigatsioonsüsteemi  (ImpPrSg2  >navigatsioonsüsteemima !28_V	et	f	\N
198163	peamiset	### peamiset	et	f	\N
198164	heate	?heate =heate  (SgN  >heate !06_S	et	f	\N
198165	heate	?heate =heate  (SgG  >heade !06_S	et	f	\N
198166	heate	?heate =heate  (PlP  >heat !22_S	et	f	\N
198167	heate	?heate =heate  (IndPrPs_  >heatema !27_V	et	f	\N
198168	heate	?heate =heate  (ImpPrSg2  >heatema !27_V	et	f	\N
198169	tuneb	?tuneb =tune  (IndPrSg3  >tunema !27_V	et	f	\N
198171	seatused	seatused =seatuse  (PlN  >seatus !11~09_S	et	f	\N
198172	seatused	"seatus %sea  )TUS1_aS  <seadma ;34_V	et	f	\N
198173	seatused	"seatus %sea  )TUS2_aS  <siga ;18_SA	et	f	\N
198175	fakultetid	?fakultetid =fakulteti  (PlN  >fakultett !22_S	et	f	\N
198176	fakultetid	?fakultetid =fakulteti  (IndPrSg2  >fakultettima !28_V	et	f	\N
198180	master	?master =master  (SgN  >master !02_S	et	f	\N
198185	koolimaterjali	koolimaterjali =materjali  (SgG  >kooli+materjal !19_S	et	f	\N
198186	koolimaterjali	koolimaterjali =materjali  (SgP  >kooli+materjal !19_S	et	f	\N
198187	koolimaterjali	koolimaterjali =materjali  (SgAdt  >kooli+materjal !19_S	et	f	\N
198199	paremma	?paremma =paremma  (SgN  >paremma !01_S	et	f	\N
198200	paremma	?paremma =paremma  (SgG  >paremma !01_S	et	f	\N
198208	kõrgedma	?kõrgedma =kõrgedma  (SgN  >kõrgedma !01_S	et	f	\N
198209	kõrgedma	?kõrgedma =kõrgedma  (SgG  >kõrgedma !01_S	et	f	\N
198222	lemmikku	?lemmikku =lemmikku  (SgN  >lemmikku !01_S	et	f	\N
198223	lemmikku	?lemmikku =lemmikku  (SgG  >lemmikku !01_S	et	f	\N
198224	lemmikku	?lemmikku =lemmikku  (IndPrPs_  >lemmikkuma !27_V	et	f	\N
198225	lemmikku	?lemmikku =lemmikku  (ImpPrSg2  >lemmikkuma !27_V	et	f	\N
198246	laendada	?laendada =laenda  (Inf  >laendama !27_V	et	f	\N
198281	kirjaviisiga	kirjaviisiga =iga  (SgN  >kirja+viis+iga !18_S	et	f	\N
198282	kirjaviisiga	kirjaviisiga =iga  (SgP  >kirja+viis+iga !18_S	et	f	\N
197982	armiat	?armiat =armia  (SgP  >armia !01_S	et	f	\N
197983	armiat	?armiat =armiat  (SgN  >armiat !22_S	et	f	\N
197986	kollektivisatsioon	?kollektivisatsioon =kollektivisatsioon  (SgN  >kollektivisatsioon !22_S	et	f	\N
198010	muuid	?muuid =muuid  (SgN  >muuid !02_S	et	f	\N
198020	kaitsmist	kaitsmist =kaitsmis  (SgP  >kaitsmine !12?10_S	et	f	\N
198021	kaitsmist	"kaitsmine %kaits  )MINE_vS  <kaitsma ;32_V	et	f	\N
198024	piltil	### piltil	et	f	\N
198034	muusikaapparatuur	?muusikaapparatuur =muusikaapparatuur  (SgN  >muusikaapparatuur !22_S	et	f	\N
198035	muusikaapparatuur	?muusikaapparatuur =apparatuur  (SgN  >muusika+apparatuur !22_S	et	f	\N
198036	muusikaapparatuur	?muusikaapparatuur =sikaapparatuur  (SgN  >muu+sikaapparatuur !22_S	et	f	\N
198046	õppevehend	?õppevehend =õppevehend  (SgN  >õppevehend !22_S	et	f	\N
198047	õppevehend	?õppevehend =vehend  (SgN  >õppe+vehend !02_S	et	f	\N
198053	aula	aula =aula  (SgN  >aula !01_S	et	f	\N
198055	aula	aula =aula  (SgN  >aula !16_S	et	f	\N
198056	aula	aula =aula  (SgG  >aula !01_S	et	f	\N
198057	aula	aula =aula  (SgG  >aula !16_S	et	f	\N
198065	valgustite	valgustite =valgusti  (PlG  >valgusti !01_S	et	f	\N
198067	valgustite	valgustite =tite  (SgG  >valgus+titt !22_S	et	f	\N
198078	keedu	keedu =keedu  (SgN  >keedu !16_S	et	f	\N
198079	keedu	"keedu %kee  )TU1_vS  <keema ;37_V	et	f	\N
198080	keedu	keedu =keedu  (SgG  >keedu !16_S	et	f	\N
198081	keedu	keedu =keedu  (SgG  >keet !22_S	et	f	\N
198084	sõbrame	?sõbrame =sõbra  (IndPrPl1  >sõbrama !27_V	et	f	\N
198085	häälposti	?häälposti =häälposti  (SgN  >häälposti !01_S	et	f	\N
198086	häälposti	?häälposti =häälposti  (SgG  >häälposti !01_S	et	f	\N
198087	häälposti	?häälposti =häälposti  (IndPrPs_  >häälpostima !28_V	et	f	\N
198088	häälposti	?häälposti =häälposti  (ImpPrSg2  >häälpostima !28_V	et	f	\N
198089	jälutada	?jälutada =jäluta  (Inf  >jälutama !27_V	et	f	\N
198104	peizhaasis	?peizhaasis =peizhaasi  (SgIn  >peizhaasi !16_S	et	f	\N
198105	peizhaasis	?peizhaasis =peizhaasi  (SgIn  >peizhaas !22_S	et	f	\N
198106	peizhaasis	?peizhaasis =peizhaasi  (PlIn  >peizhaane !12_A	et	f	\N
198107	peizhaasis	?peizhaasis =peizhaasi  (IndIpfSg3  >peizhaasima !28_V	et	f	\N
198108	peizhaasis	?peizhaasis =peizhaasis  (SgN  >peizhaasis !09_S	et	f	\N
198111	lehtega	### lehtega	et	f	\N
198129	kolmatakui	?kolmatakui =kolmatakui  (SgN  >kolmatakui !26_S	et	f	\N
198130	kolmatakui	?kolmatakui =kolmatakui  (SgG  >kolmatakui !26_S	et	f	\N
198131	kolmatakui	?kolmatakui =takui  (SgN  >kolma+takui !26_S	et	f	\N
198132	kolmatakui	?kolmatakui =takui  (SgG  >kolma+takui !26_S	et	f	\N
198133	kolmatakui	?kolmatakui =atakui  (SgN  >kolm+atakui !26_S	et	f	\N
198134	kolmatakui	?kolmatakui =atakui  (SgG  >kolm+atakui !26_S	et	f	\N
198158	peremini	peremini =mi  (SgTer  >pere+mi !26_S	et	f	\N
198159	peremini	peremini =mini  (SgN  >pere+mini !17~16_S	et	f	\N
198160	peremini	peremini =mini  (SgG  >pere+mini !17~16_S	et	f	\N
198161	peremini	peremini =mini  (SgP  >pere+mini !17_S	et	f	\N
198177	kõrgharjutust	kõrgharjutust =tust  (SgN  >kõrg+harju+tust !22_S	et	f	\N
198178	kõrgharjutust	kõrgharjutust =harjutu  (SgEl  >kõrg+harjutu !01_AS	et	f	\N
198179	kõrgharjutust	kõrgharjutust =harjutus  (SgP  >kõrg+harjutus !11_S	et	f	\N
198181	meester	?meester =meester  (SgN  >meester !02_S	et	f	\N
198198	keskmiseltvaid	?keskmiseltvaid =keskmiseltvai  (PlN  >keskmiseltvai !26_S	et	f	\N
198201	keskmiseltvaid	?keskmiseltvaid =keskmiseltvai  (SgP  >keskmiseltvai !26_S	et	f	\N
198202	keskmiseltvaid	?keskmiseltvaid =eltva  (PlP  >kesk+mis+eltva !01_S	et	f	\N
198203	keskmiseltvaid	?keskmiseltvaid =eltvai  (PlN  >kesk+mis+eltvai !26_S	et	f	\N
198204	keskmiseltvaid	?keskmiseltvaid =eltvai  (SgP  >kesk+mis+eltvai !26_S	et	f	\N
198205	keskmiseltvaid	?keskmiseltvaid =eltvaid  (SgN  >kesk+mis+eltvaid !22_S	et	f	\N
198256	tilevikus	?tilevikus =tileviku  (SgIn  >tilevik !25_S	et	f	\N
198257	tilevikus	?tilevikus =tileviku  (IndIpfSg3  >tilevikuma !27_V	et	f	\N
198258	tilevikus	?tilevikus =tilevikus  (SgN  >tilevikus !11?09_S	et	f	\N
198268	püüjan	?püüjan =püüja  (IndPrSg1  >püüjama !29_V	et	f	\N
198269	püüjan	?püüjan =püüjan  (SgN  >püüjan !02_S	et	f	\N
198301	tagajärjeid	?tagajärjeid =tagajärjei  (PlN  >tagajärjei !26_S	et	f	\N
198302	tagajärjeid	?tagajärjeid =tagajärjei  (SgP  >tagajärjei !26_S	et	f	\N
198303	tagajärjeid	?tagajärjeid =järje  (PlP  >taga+järje !06_S	et	f	\N
198304	tagajärjeid	?tagajärjeid =järjei  (PlN  >taga+järjei !26_S	et	f	\N
198305	tagajärjeid	?tagajärjeid =järjei  (SgP  >taga+järjei !26_S	et	f	\N
198306	tagajärjeid	?tagajärjeid =järjeid  (SgN  >taga+järjeid !22_S	et	f	\N
198309	erikkorras	?erikkorras =erikkorra  (SgIn  >erikkorra !16_S	et	f	\N
198314	manufakturid	?manufakturid =manufakturi  (PlN  >manufaktur !02_S	et	f	\N
198345	paleoliitikumist	paleoliitikumist =paleoliitikumi  (SgEl  >paleoliitikum !19_S	et	f	\N
198346	paleoliitikumist	paleoliitikumist =paleoliitikumis  (SgP  >paleoliitikumine !12_S	et	f	\N
198347	paleoliitikumist	"paleoliitikumine %paleoliitikumi  )NE_aA  <paleoliitikum ;19_S	et	f	\N
198353	tööristad	?tööristad =töörista  (PlN  >töörista !01_S	et	f	\N
198354	tööristad	?tööristad =töörista  (IndPrSg2  >tööristama !27_V	et	f	\N
198355	tööristad	?tööristad =rista  (PlN  >töö+rista !16_S	et	f	\N
198050	koolivoimla	?koolivoimla =voimla  (SgN  >kooli+voimla !01_S	et	f	\N
198051	koolivoimla	?koolivoimla =voimla  (SgG  >kooli+voimla !01_S	et	f	\N
198052	koolivoimla	?koolivoimla =ivoimla  (SgN  >kool+ivoimla !01_S	et	f	\N
198054	koolivoimla	?koolivoimla =ivoimla  (SgG  >kool+ivoimla !01_S	et	f	\N
198082	nõuanne	nõuanne =anne  (SgN  >nõu+anne !05_S	et	f	\N
198083	nõuanne	nõuanne =anne  (SgN  >nõu+anne !06_S	et	f	\N
198093	pingiline	pingiline =pingiline  (SgN  >pingiline !12_A	et	f	\N
198094	pingiline	"pingiline %pingi  )LINE_aA  <pink ;22_S	et	f	\N
198095	pingiline	pingiline =ine  (SgN  >pingil+ine !16_S	et	f	\N
198096	pingiline	pingiline =ine  (SgG  >pingil+ine !16_S	et	f	\N
198099	sõbrat	?sõbrat =sõbra  (SgP  >sõbra !16_S	et	f	\N
198100	sõbrat	?sõbrat =sõbrat  (SgN  >sõbrat !02_S	et	f	\N
198101	vedan	?vedan =vedan  (SgN  >vedan !02_S	et	f	\N
198125	tulemustest	tulemustest =tulemus  (PlEl  >tulemus !11_S	et	f	\N
198126	tulemustest	tulemustest =test  (SgN  >tulemus+test !22_S	et	f	\N
198127	tulemustest	tulemustest =muste  (PlEl  >tule+must !22_AS	et	f	\N
198144	sihekindel	?sihekindel =sihekinde  (PlAd  >sihekint !22_S	et	f	\N
198150	perem	?perem =perem  (SgN  >perem !02_A	et	f	\N
198170	rasskused	?rasskused =rasskuse  (PlN  >rasskus !11~09_S	et	f	\N
198191	variaantid	### variaantid	et	f	\N
198206	kannatlikuse	kannatlikuse =kannatlikuse  (SgG  >kannatlikus !11?09_S	et	f	\N
198207	kannatlikuse	"kannatlikus %kannatliku  )US_aS  <kannatlik ;25_A	et	f	\N
198210	eesmäärgital	?eesmäärgital =eesmäärgital  (SgN  >eesmäärgital !19_S	et	f	\N
198211	eesmäärgital	?eesmäärgital =määrgital  (SgN  >ees+määrgital !19_S	et	f	\N
198229	isikulised	isikulised =isikulise  (PlN  >isikuline !12_A	et	f	\N
198230	isikulised	"isikuline %isiku  )LINE_aA  <isik ;02_S	et	f	\N
198231	haritudharitud	?haritudharitud =haritudharitu  (PlN  >haritudharitu !01_A	et	f	\N
198232	haritudharitud	?haritudharitud =haritudharitu  (IndPrSg2  >haritudharituma !27_V	et	f	\N
198233	haritudharitud	?haritudharitud =haritudharitud  (ID  >haritudharitud !41_A	et	f	\N
198234	haritudharitud	?haritudharitud =tudharitu  (PlN  >hari+tudharitu !01_A	et	f	\N
198239	õppilastest	?õppilastest =õppilas  (PlEl  >õppilane !12_S	et	f	\N
198240	õppilastest	?õppilastest =õppilastes  (SgP  >õppilastene !12_A	et	f	\N
198244	hindedma	?hindedma =hindedma  (SgN  >hindedma !01_S	et	f	\N
198245	hindedma	?hindedma =hindedma  (SgG  >hindedma !01_S	et	f	\N
198252	õppetöödkui	?õppetöödkui =õppetöödkui  (SgN  >õppetöödkui !26_S	et	f	\N
198253	õppetöödkui	?õppetöödkui =õppetöödkui  (SgG  >õppetöödkui !26_S	et	f	\N
198254	õppetöödkui	?õppetöödkui =töödkui  (SgN  >õppe+töödkui !26_S	et	f	\N
198255	õppetöödkui	?õppetöödkui =töödkui  (SgG  >õppe+töödkui !26_S	et	f	\N
198263	jaoksma	?jaoksma =jaoksma  (IndPrPs_  >jaoksmama !29_V	et	f	\N
198264	jaoksma	?jaoksma =jaoksma  (ImpPrSg2  >jaoksmama !29_V	et	f	\N
198293	forseliuse	?forseliuse =forseliuse  (SgG  >forselius !11_S	et	f	\N
198297	eriõigustega	eriõigustega =õigus  (PlKom  >eri+õigus !11~09_S	et	f	\N
198298	eriõigustega	"eri+õigus %õige  )US_aS  <eri+õige ;01_A	et	f	\N
198323	humanitaarteadvused	humanitaarteadvused =teadvuse  (PlN  >humanitaar+teadvus !11~09_S	et	f	\N
198324	humanitaarteadvused	"humanitaar+teadvus %teadva  )US_aS  <humanitaar+teadev ;02_A	et	f	\N
198329	passid	passid =passi  (PlN  >pass !22_S	et	f	\N
198330	passid	passid =passi  (IndPrSg2  >passima !28_V	et	f	\N
198331	teadvus	teadvus =teadvus  (SgN  >teadvus !11~09_S	et	f	\N
198332	teadvus	"teadvus %tead  )VUS_aS  <teadma ;34_V	et	f	\N
198333	teadvus	"teadvus %teadva  )US_aS  <teadev ;02_A	et	f	\N
198351	muutuseid	muutuseid =muutuse  (PlP  >muutus !09_S	et	f	\N
198352	muutuseid	"muutus %muu  )TUS2_aS  <muu ;26_S	et	f	\N
198356	ideeid	?ideeid =ideei  (PlN  >ideei !26_S	et	f	\N
198357	ideeid	?ideeid =ideei  (SgP  >ideei !26_S	et	f	\N
198372	pronksiajast	pronksiajast =aja  (SgEl  >pronksi+aeg !22_S	et	f	\N
198373	pronksiajast	pronksiajast =ajas  (SgP  >pronksi+ajane !10_A	et	f	\N
198374	pronksiajast	"pronksi+ajane %aja  )NE_aA  <pronksi+aeg ;22_S	et	f	\N
198382	tsiviliseeritum	tsiviliseeritum =tsiviliseeritum  (SgN  >tsiviliseeritum !02_A	et	f	\N
198383	tsiviliseeritum	"tsiviliseeritum %tsiviliseeri  )TUM1_cA  <tsiviliseerima ;28_V	et	f	\N
198396	haaranud	haaranud =haara  (PtsPtPs  >haarama !29_V	et	f	\N
198397	haaranud	haaranud =haaranu  (PlN  >haaranu !01_S	et	f	\N
198398	haaranud	"haaranu %haara  )NU_vS  <haarama ;29_V	et	f	\N
198399	haaranud	haaranud =haaranud  (ID  >haaranud !41_A	et	f	\N
198400	haaranud	"haaranud %haara  )NUD_vA  <haarama ;29_V	et	f	\N
198466	lühendamise	lühendamise =lühendamise  (SgG  >lühendamine !12_S	et	f	\N
198467	lühendamise	"lühendamine %lühenda  )MINE_vS  <lühendama ;27_V	et	f	\N
198492	loodis	loodis =loodi  (SgIn  >lood !22_S	et	f	\N
198493	loodis	loodis =loodi  (IndIpfSg3  >loodima !28_V	et	f	\N
198494	loodis	loodis =loodis  (ID  >loodis !41_DA	et	f	\N
198497	patriootiliseid	?patriootiliseid =patriootilisei  (PlN  >patriootilisei !26_S	et	f	\N
198498	patriootiliseid	?patriootiliseid =patriootilisei  (SgP  >patriootilisei !26_S	et	f	\N
198512	apogee	apogee =apogee  (SgN  >apogee !26_S	et	f	\N
198513	apogee	apogee =apogee  (SgG  >apogee !26_S	et	f	\N
198195	maailmasharidus	?maailmasharidus =maailmasharidus  (SgN  >maailmasharidus !11?09_S	et	f	\N
198196	maailmasharidus	?maailmasharidus =asharidus  (SgN  >maa+ilm+asharidus !11?09_S	et	f	\N
198197	maailmasharidus	?maailmasharidus =ilmasharidus  (SgN  >maa+ilmasharidus !11?09_S	et	f	\N
198212	kannatlikuset	### kannatlikuset	et	f	\N
198217	ruttadaveel	?ruttadaveel =ruttadavee  (SgAd  >ruttadavee !26_S	et	f	\N
198218	ruttadaveel	?ruttadaveel =ruttadaveel  (SgN  >ruttadaveel !22_S	et	f	\N
198219	eksame	?eksame =eksa  (IndPrPl1  >eksama !29_V	et	f	\N
198220	eksame	?eksame =ame  (SgN  >eks+ame !16_S	et	f	\N
198221	eksame	?eksame =ame  (SgG  >eks+ame !16_S	et	f	\N
198241	peaminema	?peaminema =peamine  (Sup  >peaminema !27_V	et	f	\N
198242	peaminema	?peaminema =peaminema  (SgG  >peaminem !02_A	et	f	\N
198243	peaminema	?peaminema =minema  (SgG  >pea+minem !02_A	et	f	\N
198247	mudugi	?mudugi =mudu  (SgN^  >mudu !17_S	et	f	\N
198248	mudugi	?mudugi =mudu  (SgG^  >mudu !17_S	et	f	\N
198249	mudugi	?mudugi =mudu  (SgP^  >mudu !17_S	et	f	\N
198250	mudugi	?mudugi =mudu  (IndPrPs_^  >muduma !27_V	et	f	\N
198251	mudugi	?mudugi =mudu  (ImpPrSg2^  >muduma !27_V	et	f	\N
198265	õdukalt	?õdukalt =õduka  (SgAbl  >õduka !01_S	et	f	\N
198266	õdukalt	?õdukalt =õduka  (SgAbl  >õdukas !02_A	et	f	\N
198267	õdukalt	?õdukalt =õdukalt  (ID  >õdukalt !41_D	et	f	\N
198273	upsala	?upsala =upsala  (SgN  >upsala !01_S	et	f	\N
198274	upsala	?upsala =upsala  (SgG  >upsala !01_S	et	f	\N
198279	forselisus	?forselisus =forselisu  (IndIpfSg3  >forselisuma !27_V	et	f	\N
198280	forselisus	?forselisus =forselisus  (SgN  >forselisus !11?09_S	et	f	\N
198294	eestalst	?eestalst =eestalst  (SgN  >eestalst !22_S	et	f	\N
198295	eestalst	?eestalst =alst  (SgN  >eest+alst !22_S	et	f	\N
198296	eestalst	?eestalst =talst  (SgN  >ees+talst !22_S	et	f	\N
198307	püüdlesid	püüdlesid =püüdle  (IndIpfSg2  >püüdlema !30_V	et	f	\N
198308	püüdlesid	püüdlesid =püüdle  (IndIpfPl3  >püüdlema !30_V	et	f	\N
198315	talupojaid	?talupojaid =talupoja  (PlP  >talupoja !01_S	et	f	\N
198316	talupojaid	?talupojaid =talupoja  (PlP  >talupojas !02_A	et	f	\N
198317	talupojaid	?talupojaid =talupojai  (PlN  >talupojai !26_S	et	f	\N
198318	talupojaid	?talupojaid =talupojai  (SgP  >talupojai !26_S	et	f	\N
198319	talupojaid	?talupojaid =poja  (PlP  >talu+pojas !09_S	et	f	\N
198320	talupojaid	?talupojaid =pojai  (PlN  >talu+pojai !26_S	et	f	\N
198321	talupojaid	?talupojaid =pojai  (SgP  >talu+pojai !26_S	et	f	\N
198322	talupojaid	?talupojaid =pojaid  (SgN  >talu+pojaid !22_S	et	f	\N
198339	identeet	?identeet =identeet  (SgN  >identeet !22_S	et	f	\N
198358	nägemiselt	nägemiselt =nägemise  (SgAbl  >nägemine !12_S	et	f	\N
198359	nägemiselt	"nägemine %näge  )MINE_vS  <nägema ;28_V	et	f	\N
198375	rauaajast	rauaajast =aja  (SgEl  >raua+aeg !22_S	et	f	\N
198376	rauaajast	rauaajast =ajas  (SgP  >raua+ajane !10_A	et	f	\N
198377	rauaajast	"raua+ajane %aja  )NE_aA  <raua+aeg ;22_S	et	f	\N
198378	estimal	?estimal =estima  (SgAd  >estim !02_A	et	f	\N
198379	estimal	?estimal =estimal  (ID  >estimal !41_D	et	f	\N
198380	kivimajad	kivimajad =aja  (PlN  >kivim+aeg !22_S	et	f	\N
198381	kivimajad	kivimajad =maja  (PlN  >kivi+maja !17_S	et	f	\N
198419	kellelgil	?kellelgil =kellelgi  (SgAd  >kellelg !02_S	et	f	\N
198420	kellelgil	?kellelgil =kellelgi  (SgAd  >kellelk !22_S	et	f	\N
198424	biiblist	?biiblist =biibli  (SgEl  >biibel !02_S	et	f	\N
198425	biiblist	?biiblist =biiblis  (SgP  >biiblis !09_S	et	f	\N
198426	biiblist	?biiblist =biiblis  (SgP  >biibline !12~10_A	et	f	\N
198427	biiblist	?biiblist =biiblist  (SgN  >biiblist !22_S	et	f	\N
198432	tavaelus	tavaelus =elu  (SgIn  >tava+elu !17_S	et	f	\N
198433	tavaelus	tavaelus =elus  (SgN  >tava+elus !02_A	et	f	\N
198434	ärgipäeva	?ärgipäeva =ärgipäeva  (SgN  >ärgipäeva !16_S	et	f	\N
198435	ärgipäeva	?ärgipäeva =ärgipäeva  (SgG  >ärgipäeva !16_S	et	f	\N
198436	etendusi	etendusi =etendusi  (PlP  >etendus !11_S	et	f	\N
198437	etendusi	"etendus %etenda  )US_vS  <etendama ;27_V	et	f	\N
198438	kreuzwald	?kreuzwald =kreuzwald  (SgN  >kreuzwald !02_S	et	f	\N
198449	seltsides	seltsides =seltsi  (PlIn  >selts !22_S	et	f	\N
198450	seltsides	seltsides =seltsi  (Ger  >seltsima !28_V	et	f	\N
198451	pärsiorjusest	pärsiorjusest =orjuse  (SgEl  >pärsi+orjus !11~09_S	et	f	\N
198452	pärsiorjusest	pärsiorjusest =orjuses  (SgP  >pärsi+orjusene !12_A	et	f	\N
198453	pärsiorjusest	"pärsi+orjusene %orjuse  )NE_aA  <pärsi+orjus ;09_S	et	f	\N
198454	pärsiorjusest	"pärsi+orjusene %orjuse  )NE_aA  <pärsi+orjus ;11_S	et	f	\N
198460	surunud	surunud =suru  (PtsPtPs  >suruma !27_V	et	f	\N
198461	surunud	surunud =surunu  (PlN  >surunu !01_S	et	f	\N
198462	surunud	"surunu %suru  )NU_vS  <suruma ;27_V	et	f	\N
198463	surunud	surunud =surunud  (ID  >surunud !41_A	et	f	\N
198464	surunud	"surunud %suru  )NUD_vA  <suruma ;27_V	et	f	\N
198465	imperatori	?imperatori =imperatori  (SgG  >imperator !02_S	et	f	\N
198495	naiseluuletaja	naiseluuletaja =luuletaja  (SgN  >naise+luuletaja !01_S	et	f	\N
198496	naiseluuletaja	naiseluuletaja =luuletaja  (SgG  >naise+luuletaja !01_S	et	f	\N
198505	tsunffeid	?tsunffeid =tsunffe  (PlP  >tsunffi !01_S	et	f	\N
198506	tsunffeid	?tsunffeid =tsunffe  (PlP  >tsunffe !06_S	et	f	\N
198238	parematest	parematest =ate  (PlEl  >parem+att !22_S	et	f	\N
198259	tallinasma	?tallinasma =tallinasma  (SgN  >tallinasma !16_S	et	f	\N
198260	tallinasma	?tallinasma =tallinasma  (SgG  >tallinasma !16_S	et	f	\N
198261	tallinasma	?tallinasma =nasma  (SgN  >talli+nasma !16_S	et	f	\N
198262	tallinasma	?tallinasma =nasma  (SgG  >talli+nasma !16_S	et	f	\N
198270	õpengud	?õpengud =õpengu  (PlN  >õpengu !01_S	et	f	\N
198271	õpengud	?õpengud =õpengu  (PlN  >õpeng !02_S	et	f	\N
198272	õpengud	?õpengud =õpengu  (IndPrSg2  >õpenguma !27_V	et	f	\N
198275	talurahvakooli	talurahvakooli =kooli  (SgG  >talu+rahva+kool !22_S	et	f	\N
198276	talurahvakooli	talurahvakooli =kooli  (SgP  >talu+rahva+kool !22_S	et	f	\N
198277	talurahvakooli	talurahvakooli =kooli  (SgAdt  >talu+rahva+kool !22_S	et	f	\N
198278	talurahvakooli	talurahvakooli =kooli  (PlP  >talu+rahva+kool !22_S	et	f	\N
198289	teaduskondi	teaduskondi =teaduskondi  (SgP  >teaduskond !22_S	et	f	\N
198290	teaduskondi	teaduskondi =teaduskondi  (SgAdt  >teaduskond !22_S	et	f	\N
198291	teaduskondi	teaduskondi =teaduskondi  (PlP  >teaduskond !22_S	et	f	\N
198292	teaduskondi	teaduskondi =kondi  (SgG  >teadus+kont !22_S	et	f	\N
198299	muujal	muujal =muuja  (SgAd  >muuja !01_S	et	f	\N
198300	muujal	"muuja %muu  )JA_vS  <muuma ;27_V	et	f	\N
198310	posiivne	?posiivne =posiivne  (SgN  >posiivne !02_A	et	f	\N
198311	posiivne	?posiivne =posiivne  (PlP  >posiivn !22_S	et	f	\N
198312	posiivne	?posiivne =posiivne  (IndPrPs_  >posiivnema !27_V	et	f	\N
198313	posiivne	?posiivne =posiivne  (ImpPrSg2  >posiivnema !27_V	et	f	\N
198325	edenesid	edenesid =edene  (IndIpfSg2  >edenema !27_V	et	f	\N
198326	edenesid	edenesid =edene  (IndIpfPl3  >edenema !27_V	et	f	\N
198348	neoliitikumist	neoliitikumist =neoliitikumi  (SgEl  >neoliitikum !19_S	et	f	\N
198349	neoliitikumist	neoliitikumist =neoliitikumis  (SgP  >neoliitikumine !12_S	et	f	\N
198350	neoliitikumist	"neoliitikumine %neoliitikumi  )NE_aA  <neoliitikum ;19_S	et	f	\N
198386	vallatuma	vallatuma =vallatuma  (SgG  >vallatum !02_A	et	f	\N
198387	vallatuma	"vallatum %valla  )TUM1_cA  <valdama ;29_V	et	f	\N
198388	vallatuma	"vallatum %valla  )TUM2_cA  <vald ;22_S	et	f	\N
198389	vallatuma	"vallatum %vallatu  )M_cA  <vallatu ;01_AS	et	f	\N
198401	sõjataktika	sõjataktika =taktika  (SgN  >sõja+taktika !01_S	et	f	\N
198402	sõjataktika	sõjataktika =taktika  (SgG  >sõja+taktika !01_S	et	f	\N
198409	muinaseestlaste	muinaseestlaste =las  (PlG  >muinas+eest+laps !14_S	et	f	\N
198410	muinaseestlaste	muinaseestlaste =laste  (PlP  >muinas+eest+last !22_S	et	f	\N
198411	muinaseestlaste	muinaseestlaste =eestlas  (PlG  >muinas+eestlane !12?10_S	et	f	\N
198421	väärtuslikut	?väärtuslikut =usliku  (SgP  >väärt+usliku !01_S	et	f	\N
198422	väärtuslikut	?väärtuslikut =tusliku  (SgP  >väär+tusliku !01_S	et	f	\N
198455	linnastumist	linnastumist =linnastumis  (SgP  >linnastumine !12_S	et	f	\N
198456	linnastumist	"linnastumine %linnastu  )MINE_vS  <linnastuma ;27_V	et	f	\N
198457	linnastumist	linnastumist =astumis  (SgP  >linn+astumine !12_S	et	f	\N
198478	murdel	murdel =murde  (SgAd  >murre !06_S	et	f	\N
198479	murdel	murdel =murdel  (SgN  >murdel !02_S	et	f	\N
198482	intellegentsi	?intellegentsi =intellegentsi  (SgG  >intellegents !22_S	et	f	\N
198483	intellegentsi	?intellegentsi =intellegentsi  (SgP  >intellegents !22_S	et	f	\N
198484	intellegentsi	?intellegentsi =intellegentsi  (SgAdt  >intellegents !22_S	et	f	\N
198485	intellegentsi	?intellegentsi =intellegentsi  (IndPrPs_  >intellegentsima !28_V	et	f	\N
198486	intellegentsi	?intellegentsi =intellegentsi  (ImpPrSg2  >intellegentsima !28_V	et	f	\N
198487	ülelaulupidu	ülelaulupidu =pidu  (SgN  >üle+laulu+pidu !17_S	et	f	\N
198488	ülelaulupidu	ülelaulupidu =pidu  (SgN  >üle+laulu+pidu !18_S	et	f	\N
198489	ülelaulupidu	ülelaulupidu =pidu  (SgG  >üle+laulu+pidu !17_S	et	f	\N
198490	ülelaulupidu	ülelaulupidu =pidu  (SgP  >üle+laulu+pidu !17_S	et	f	\N
198491	ülelaulupidu	ülelaulupidu =pidu  (SgP  >üle+laulu+pidu !18_S	et	f	\N
198502	paigustuma	?paigustuma =paigustu  (Sup  >paigustuma !27_V	et	f	\N
198503	paigustuma	?paigustuma =paigustuma  (SgG  >paigustum !02_A	et	f	\N
198504	paigustuma	?paigustuma =gustuma  (SgG  >pai+gustum !02_A	et	f	\N
198521	rauakirvesid	### rauakirvesid	et	f	\N
198523	kergendasid	kergendasid =kergenda  (IndIpfSg2  >kergendama !27_V	et	f	\N
198525	kergendasid	kergendasid =kergenda  (IndIpfPl3  >kergendama !27_V	et	f	\N
198536	täiendasid	täiendasid =täienda  (IndIpfSg2  >täiendama !27_V	et	f	\N
198537	täiendasid	täiendasid =täienda  (IndIpfPl3  >täiendama !27_V	et	f	\N
198546	keskendatud	keskendatud =keskenda  (PtsPtIps  >keskendama !27_V	et	f	\N
198547	keskendatud	keskendatud =keskendatu  (PlN  >keskendatu !01_S	et	f	\N
198548	keskendatud	"keskendatu %keskenda  )TU1_vS  <keskendama ;27_V	et	f	\N
198549	keskendatud	keskendatud =keskendatud  (ID  >keskendatud !41_A	et	f	\N
198550	keskendatud	"keskendatud %keskenda  )TUD_vA  <keskendama ;27_V	et	f	\N
198587	katehisis	?katehisis =katehisi  (PlIn  >katehis !11_S	et	f	\N
198588	katehisis	?katehisis =katehisis  (SgN  >katehisis !09_S	et	f	\N
198591	avalikust	avalikust =avaliku  (SgEl  >avalik !25_A	et	f	\N
198592	avalikust	avalikust =avalikus  (SgP  >avalikus !11?09_S	et	f	\N
198593	avalikust	"avalikus %avaliku  )US_aS  <avalik ;25_A	et	f	\N
198283	kirjaviisiga	kirjaviisiga =viisi  (SgKom  >kirja+viis !22_S	et	f	\N
198284	alistatud	alistatud =alista  (PtsPtIps  >alistama !27_V	et	f	\N
198285	alistatud	alistatud =alistatu  (PlN  >alistatu !01_S	et	f	\N
198286	alistatud	"alistatu %alista  )TU1_vS  <alistama ;27_V	et	f	\N
198287	alistatud	alistatud =alistatud  (ID  >alistatud !41_A	et	f	\N
198288	alistatud	"alistatud %alista  )TUD_vA  <alistama ;27_V	et	f	\N
198327	rakendasid	rakendasid =rakenda  (IndIpfSg2  >rakendama !27_V	et	f	\N
198328	rakendasid	rakendasid =rakenda  (IndIpfPl3  >rakendama !27_V	et	f	\N
198334	tegelnud	tegelnud =tegel  (PtsPtPs  >tegelema !31_V	et	f	\N
198335	tegelnud	tegelnud =tegelnu  (PlN  >tegelnu !01_S	et	f	\N
198336	tegelnud	"tegelnu %tegel  )NU_vS  <tegelema ;31_V	et	f	\N
198337	tegelnud	tegelnud =tegelnud  (ID  >tegelnud !41_A	et	f	\N
198338	tegelnud	"tegelnud %tegel  )NUD_vA  <tegelema ;31_V	et	f	\N
198340	kaotusega	kaotusega =kaotuse  (SgKom  >kaotus !11~09_S	et	f	\N
198341	kaotusega	"kaotus %kaota  )US_vS  <kaotama ;27_V	et	f	\N
198342	kaotusega	"kaotus %kao  )TUS1_aS  <kaduma ;28_V	et	f	\N
198343	kaotusega	"kaotus %kao  )TUS2_aS  <kabu ;18_S	et	f	\N
198344	kaotusega	"kaotus %kao  )TUS2_aS  <kadu ;18_S	et	f	\N
198367	meelekindus	?meelekindus =meelekindu  (IndIpfSg3  >meelekinduma !27_V	et	f	\N
198368	meelekindus	?meelekindus =meelekindus  (SgN  >meelekindus !11_S	et	f	\N
198369	meelekindus	?meelekindus =kindus  (SgN  >meele+kindus !11~09_S	et	f	\N
198370	meelekindus	?meelekindus =lekindu  (SgIn  >mee+lekindu !01_S	et	f	\N
198371	meelekindus	?meelekindus =lekindus  (SgN  >mee+lekindus !11_S	et	f	\N
198384	kihelkonnadest	?kihelkonnadest =kihelkonna  (PlEl  >kihelkonna !16_S	et	f	\N
198385	kihelkonnadest	?kihelkonnadest =kihelkonnades  (SgP  >kihelkonnadene !12_A	et	f	\N
198392	lahinguid	lahinguid =lahingu  (PlP  >lahing !02_S	et	f	\N
198393	lahinguid	lahinguid =ui  (PlN  >lahing+ui !26_S	et	f	\N
198394	lahinguid	lahinguid =ui  (SgP  >lahing+ui !26_S	et	f	\N
198395	lahinguid	lahinguid =uid  (SgN  >lahing+uid !22_S	et	f	\N
198403	muistselt	muistselt =muistse  (SgAbl  >muistne !02_A	et	f	\N
198405	muistselt	muistselt =muistselt  (ID  >muistselt !41_D	et	f	\N
198407	muistselt	"muistselt %muistse  )LT_mD  <muistne ;02_A	et	f	\N
198412	vabadusvõitlusest	vabadusvõitlusest =võitluse  (SgEl  >vabadus+võitlus !11~09_S	et	f	\N
198413	vabadusvõitlusest	vabadusvõitlusest =võitluses  (SgP  >vabadus+võitlusene !12_A	et	f	\N
198414	vabadusvõitlusest	"vabadus+võitlusene %võitluse  )NE_aA  <vabadus+võitlus ;09_S	et	f	\N
198415	vabadusvõitlusest	"vabadus+võitlusene %võitluse  )NE_aA  <vabadus+võitlus ;11_S	et	f	\N
198416	rahvasesse	rahvasesse =rahvase  (SgIll  >rahvane !10_A	et	f	\N
198417	rahvasesse	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
198418	rahvasesse	rahvasesse =sesse  (PlP  >rahva+sess !22_S	et	f	\N
198428	propagandevust	?propagandevust =propagandevus  (SgP  >propagandevus !11?09_S	et	f	\N
198441	tagajärjeteks	?tagajärjeteks =tagajärjete  (PlTr  >tagajärjett !22_S	et	f	\N
198442	tagajärjeteks	?tagajärjeteks =järje  (PlTr  >taga+järje !06_S	et	f	\N
198443	tagajärjeteks	?tagajärjeteks =järjete  (PlTr  >taga+järjett !22_S	et	f	\N
198444	piiramatu	piiramatu =piiramatu  (SgN  >piiramatu !01_A	et	f	\N
198445	piiramatu	"piiramatu %piira  )MATU_vA  <piirama ;29_V	et	f	\N
198446	piiramatu	piiramatu =piiramatu  (SgG  >piiramatu !01_A	et	f	\N
198447	panuseks	panuseks =panuse  (SgTr  >panus !09_S	et	f	\N
198448	panuseks	panuseks =seks  (SgN  >panu+seks !22_S	et	f	\N
198458	töötlejate	töötlejate =töötleja  (PlG  >töötleja !01_S	et	f	\N
198459	töötlejate	"töötleja %töötle  )JA_vS  <töötlema ;30_V	et	f	\N
198468	sibirisse	?sibirisse =sibiri  (SgIll  >sibiri !01_S	et	f	\N
198469	sibirisse	?sibirisse =sibiri  (SgIll  >sibir !02_S	et	f	\N
198470	sibirisse	?sibirisse =sibiris  (SgAdt  >sibiris !11_S	et	f	\N
198471	sibirisse	?sibirisse =sibirisse  (SgG  >sibirisne !02_A	et	f	\N
198472	sibirisse	?sibirisse =sibirisse  (PlP  >sibiriss !22_S	et	f	\N
198473	sibirisse	?sibirisse =risse  (SgN  >sibi+risse !06_S	et	f	\N
198474	sibirisse	?sibirisse =risse  (SgG  >sibi+risne !02_A	et	f	\N
198475	sibirisse	?sibirisse =risse  (SgG  >sibi+risse !06_S	et	f	\N
198476	sibirisse	?sibirisse =risse  (PlP  >sibi+riss !22_S	et	f	\N
198477	virgiliusega	?virgiliusega =virgiliuse  (SgKom  >virgilius !11_S	et	f	\N
198522	rauatööristad	?rauatööristad =rauatöörista  (PlN  >rauatöörista !16_S	et	f	\N
198524	rauatööristad	?rauatööristad =rauatöörista  (IndPrSg2  >rauatööristama !27_V	et	f	\N
198526	rauatööristad	?rauatööristad =rista  (PlN  >raua+töö+rista !16_S	et	f	\N
198538	ametikohti	ametikohti =kohti  (SgP  >ameti+koht !22_S	et	f	\N
198539	ametikohti	ametikohti =kohti  (SgAdt  >ameti+koht !22_S	et	f	\N
198540	ametikohti	ametikohti =kohti  (PlP  >ameti+koht !22_S	et	f	\N
198561	kalapüügimises	?kalapüügimises =kalapüügimise  (SgIn  >kalapüügimine !12_S	et	f	\N
198562	kalapüügimises	?kalapüügimises =püügimise  (SgIn  >kala+püügimine !12_S	et	f	\N
198565	muisted	?muisted =muiste  (IndPrSg2  >muistema !27_V	et	f	\N
198566	keelealased	keelealased =alase  (PlN  >keele+alane !10_AS	et	f	\N
198567	keelealased	"keele+alane %ala  )NE_aA  <keele+ala ;17_S	et	f	\N
198568	rahvuslikus	rahvuslikus =rahvusliku  (SgIn  >rahvuslik !25_A	et	f	\N
198360	tugevnenud	tugevnenud =tugevne  (PtsPtPs  >tugevnema !27_V	et	f	\N
198361	tugevnenud	tugevnenud =tugevnenu  (PlN  >tugevnenu !01_S	et	f	\N
198362	tugevnenud	"tugevnenu %tugevne  )NU_vS  <tugevnema ;27_V	et	f	\N
198363	tugevnenud	tugevnenud =tugevnenud  (ID  >tugevnenud !41_A	et	f	\N
198364	tugevnenud	"tugevnenud %tugevne  )NUD_vA  <tugevnema ;27_V	et	f	\N
198365	vaimujõudu	vaimujõudu =jõudu  (SgP  >vaimu+jõud !22_S	et	f	\N
198366	vaimujõudu	vaimujõudu =jõudu  (SgAdt  >vaimu+jõud !22_S	et	f	\N
198390	õpetatuid	õpetatuid =õpetatu  (PlP  >õpetatu !01_S	et	f	\N
198391	õpetatuid	"õpetatu %õpeta  )TU1_vS  <õpetama ;27_V	et	f	\N
198404	eestastelt	eestastelt =aste  (SgAbl  >eest+aste !06_S	et	f	\N
198406	eestastelt	eestastelt =aste  (PlAbl  >eest+ast !22_S	et	f	\N
198408	eestastelt	eestastelt =astel  (SgP  >eest+astel !08_S	et	f	\N
198423	päikejumal	?päikejumal =päikejumal  (SgN  >päikejumal !19_S	et	f	\N
198429	ristiisa	ristiisa =isa  (SgN  >risti+isa !17_S	et	f	\N
198430	ristiisa	ristiisa =isa  (SgG  >risti+isa !17_S	et	f	\N
198431	ristiisa	ristiisa =isa  (SgP  >risti+isa !17_S	et	f	\N
198439	tuntuma	tuntuma =tuntuma  (SgG  >tuntum !02_A	et	f	\N
198440	tuntuma	"tuntum %tun  )TUM1_cA  <tundma ;34_V	et	f	\N
198480	jvjannsen	?jvjannsen =jvjannse  (IndPrSg1  >jvjannsema !27_V	et	f	\N
198481	jvjannsen	?jvjannsen =jvjannsen  (SgN  >jvjannsen !02_S	et	f	\N
198499	liikumisvabadust	liikumisvabadust =dust  (SgN  >liikumis+vaba+dust !22_S	et	f	\N
198500	liikumisvabadust	liikumisvabadust =vabadus  (SgP  >liikumis+vabadus !11_S	et	f	\N
198501	liikumisvabadust	"liikumis+vabadus %vaba  )US_aS  <liikumis+vaba ;17_A	et	f	\N
198510	rajamisega	rajamisega =rajamise  (SgKom  >rajamine !12_S	et	f	\N
198511	rajamisega	"rajamine %raja  )MINE_vS  <rajama ;27_V	et	f	\N
198516	tekstiilitööstust	tekstiilitööstust =tust  (SgN  >tekstiili+töös+tust !22_S	et	f	\N
198517	tekstiilitööstust	tekstiilitööstust =tööstus  (SgP  >tekstiili+tööstus !11~09_S	et	f	\N
198527	lammbad	?lammbad =lammba  (PlN  >lammba !01_S	et	f	\N
198528	lammbad	?lammbad =lammba  (IndPrSg2  >lammbama !29_V	et	f	\N
198533	linnasüdaks	?linnasüdaks =üda  (SgTr  >linnas+üda !17_S	et	f	\N
198583	valgustlikud	?valgustlikud =valgustliku  (PlN  >valgustlik !25_A	et	f	\N
198584	valgustlikud	?valgustlikud =valgustliku  (IndPrSg2  >valgustlikuma !27_V	et	f	\N
198585	valgustlikud	?valgustlikud =ustliku  (PlN  >valg+ustlik !25_A	et	f	\N
198586	valgustlikud	?valgustlikud =ustliku  (PlN  >valg+ustliku !01_S	et	f	\N
198614	koristasid	koristasid =korista  (IndIpfSg2  >koristama !27_V	et	f	\N
198615	koristasid	koristasid =korista  (IndIpfPl3  >koristama !27_V	et	f	\N
198616	levinevad	?levinevad =levine  (IndPrPl3  >levinema !27_V	et	f	\N
198617	levinevad	?levinevad =levineva  (PlN  >levinev !02_A	et	f	\N
198618	levinevad	?levinevad =levineva  (PlN  >levineva !16_S	et	f	\N
198619	levinevad	?levinevad =neva  (PlN  >levi+neva !17_S	et	f	\N
198621	ettekujutusest	ettekujutusest =kujutuse  (SgEl  >ette+kujutus !11_S	et	f	\N
198622	ettekujutusest	"ette+kujutus %kuju  )TUS2_aS  <ette+kuju ;17_S	et	f	\N
198624	ettekujutusest	ettekujutusest =kujutuses  (SgP  >ette+kujutusene !12_A	et	f	\N
198625	ettekujutusest	"ette+kujutusene %kujutuse  )NE_aA  <ette+kujutus ;11_S	et	f	\N
198634	perekonade	?perekonade =kona  (PlG  >pere+kona !17_S	et	f	\N
198644	trükitehnika	trükitehnika =tehnika  (SgN  >trüki+tehnika !01_S	et	f	\N
198645	trükitehnika	trükitehnika =tehnika  (SgG  >trüki+tehnika !01_S	et	f	\N
198648	kroonikaid	kroonikaid =kroonika  (PlP  >kroonika !01_S	et	f	\N
198649	kroonikaid	kroonikaid =kai  (PlN  >krooni+kai !26_S	et	f	\N
198650	kroonikaid	kroonikaid =kai  (SgP  >krooni+kai !26_S	et	f	\N
198653	kirjutajaks	kirjutajaks =kirjutaja  (SgTr  >kirjutaja !01_S	et	f	\N
198654	kirjutajaks	"kirjutaja %kirjuta  )JA_vS  <kirjutama ;27_V	et	f	\N
198657	skytte	?skytte =skytte  (SgN  >skytte !06_S	et	f	\N
198658	skytte	?skytte =skytte  (SgG  >skyte !06_S	et	f	\N
198659	skytte	?skytte =skytte  (PlP  >skytt !22_S	et	f	\N
198660	skytte	?skytte =skytte  (IndPrPs_  >skyttema !27_V	et	f	\N
198661	skytte	?skytte =skytte  (ImpPrSg2  >skyttema !27_V	et	f	\N
198662	soovitustel	soovitustel =soovitus  (PlAd  >soovitus !11_S	et	f	\N
198663	soovitustel	"soovitus %soovita  )US_vS  <soovitama ;27_V	et	f	\N
198664	soovitustel	"soovitus %soovi  )TUS1_aS  <soovima ;28_V	et	f	\N
198665	soovitustel	"soovitus %soovi  )TUS2_aS  <soov ;22_S	et	f	\N
198666	soovitustel	soovitustel =tuste  (PlAd  >soovi+tust !22_S	et	f	\N
198671	eriseisus	eriseisus =seisu  (SgIn  >eri+seis !22_S	et	f	\N
198672	eriseisus	eriseisus =seisus  (SgN  >eri+seisus !11~09_S	et	f	\N
198673	kaubavahetust	kaubavahetust =us  (SgP  >kauba+vahet+uks !14_S	et	f	\N
198674	kaubavahetust	kaubavahetust =tust  (SgN  >kauba+vahe+tust !22_S	et	f	\N
198675	kaubavahetust	kaubavahetust =vahetu  (SgEl  >kauba+vahetu !01_A	et	f	\N
198676	kaubavahetust	"kauba+vahetu %vahe  )TU2_kA  <kauba+vahe ;16_S	et	f	\N
198677	kaubavahetust	kaubavahetust =vahetus  (SgP  >kauba+vahetus !11_S	et	f	\N
198678	kaubavahetust	"kauba+vahetus %vahe  )TUS2_aS  <kauba+vahe ;16_S	et	f	\N
198681	venestumist	venestumist =venestumis  (SgP  >venestumine !12_S	et	f	\N
198682	venestumist	"venestumine %venestu  )MINE_vS  <venestuma ;27_V	et	f	\N
198687	võsud	võsud =võsu  (PlN  >võsu !17_S	et	f	\N
198507	tsunffeid	?tsunffeid =tsunffei  (PlN  >tsunffei !26_S	et	f	\N
198508	tsunffeid	?tsunffeid =tsunffei  (SgP  >tsunffei !26_S	et	f	\N
198509	tsunffeid	?tsunffeid =tsunffeid  (SgN  >tsunffeid !22_S	et	f	\N
198529	lehmaid	?lehmaid =lehmai  (PlN  >lehmai !26_S	et	f	\N
198530	lehmaid	?lehmaid =lehmai  (SgP  >lehmai !26_S	et	f	\N
198531	lehmaid	?lehmaid =lehmaid  (SgN  >lehmaid !22_S	et	f	\N
198532	lehmaid	?lehmaid =aid  (SgN  >lehm+aid !22_S	et	f	\N
198543	gotika	?gotika =gotika  (SgN  >gotika !01_S	et	f	\N
198544	gotika	?gotika =gotika  (SgG  >gotika !01_S	et	f	\N
198545	gotika	?gotika =gotika  (SgG  >gotikas !02_S	et	f	\N
198551	hanza	?hanza =hanza  (SgN  >hanza !16_S	et	f	\N
198552	hanza	?hanza =hanza  (SgG  >hanza !16_S	et	f	\N
198556	klostrid	?klostrid =klostri  (PlN  >klostri !01_S	et	f	\N
198557	klostrid	?klostrid =klostri  (PlN  >kloster !02_S	et	f	\N
198558	klostrid	?klostrid =klostri  (IndPrSg2  >klostrima !28_V	et	f	\N
198559	küttides	küttides =kütti  (PlIn  >kütt !22_S	et	f	\N
198560	küttides	küttides =kütti  (Ger  >küttima !28_V	et	f	\N
198563	võitama	võitama =või  (SupIps  >võidma !34_V	et	f	\N
198564	võitama	võitama =võita  (Sup  >võitama !27_V	et	f	\N
198571	humaniistliku	?humaniistliku =humaniistliku  (SgG  >humaniistlik !25_A	et	f	\N
198572	humaniistliku	?humaniistliku =humaniistliku  (IndPrPs_  >humaniistlikuma !27_V	et	f	\N
198573	humaniistliku	?humaniistliku =humaniistliku  (ImpPrSg2  >humaniistlikuma !27_V	et	f	\N
198606	kultuurikeskustena	kultuurikeskustena =us  (PlEs  >kultuuri+kesk+uks !14_S	et	f	\N
198607	kultuurikeskustena	kultuurikeskustena =keskus  (PlEs  >kultuuri+keskus !11~09_S	et	f	\N
198608	muinaseestlasteelu	muinaseestlasteelu =elu  (SgN  >muinas+eest+laste+elu !17_S	et	f	\N
198609	muinaseestlasteelu	muinaseestlasteelu =elu  (SgG  >muinas+eest+laste+elu !17_S	et	f	\N
198610	muinaseestlasteelu	muinaseestlasteelu =elu  (SgP  >muinas+eest+laste+elu !17_S	et	f	\N
198620	vaesete	vaesete =e  (PlG  >vaes+esi !15_S	et	f	\N
198623	vaesete	vaesete =sete  (SgN  >vae+sete !06_S	et	f	\N
198655	gümnaasiumiharidust	gümnaasiumiharidust =dust  (SgN  >gümnaasiumi+hari+dust !22_S	et	f	\N
198656	gümnaasiumiharidust	gümnaasiumiharidust =haridus  (SgP  >gümnaasiumi+haridus !11_S	et	f	\N
198717	ülestõus	ülestõus =tõu  (SgIn  >üles+tõug !22_S	et	f	\N
198719	ülestõus	ülestõus =tõu  (SgIn  >üles+tõu !26_S	et	f	\N
198720	ülestõus	ülestõus =tõus  (SgN  >üles+tõus !22_S	et	f	\N
198721	rauaeg	?rauaeg =rauaeg  (SgN  >rauaeg !22_S	et	f	\N
198728	telegema	?telegema =telegema  (SgG  >telegem !02_A	et	f	\N
198729	telegema	?telegema =gema  (SgN  >tele+gema !17_S	et	f	\N
198730	telegema	?telegema =gema  (SgG  >tele+gema !17_S	et	f	\N
198731	telegema	?telegema =gema  (SgP  >tele+gema !17_S	et	f	\N
198742	hõbet	### hõbet	et	f	\N
198744	liikumisvabadus	liikumisvabadus =vabadus  (SgN  >liikumis+vabadus !11_S	et	f	\N
198745	liikumisvabadus	"liikumis+vabadus %vaba  )US_aS  <liikumis+vaba ;17_A	et	f	\N
198769	uskumuskommetest	?uskumuskommetest =uskumuskommete  (PlEl  >uskumuskommett !22_S	et	f	\N
198770	uskumuskommetest	?uskumuskommetest =uskumuskommetes  (SgP  >uskumuskommetene !12_A	et	f	\N
198771	uskumuskommetest	?uskumuskommetest =muskommete  (PlEl  >usku+muskommett !22_S	et	f	\N
198772	uskumuskommetest	?uskumuskommetest =muskommetes  (SgP  >usku+muskommetene !12_A	et	f	\N
198773	sümbolitest	sümbolitest =sümboli  (PlEl  >sümbol !02_S	et	f	\N
198774	sümbolitest	sümbolitest =test  (SgN  >sümboli+test !22_S	et	f	\N
198775	püstkoju	?püstkoju =püstkoju  (SgN  >püstkoju !01_S	et	f	\N
198776	püstkoju	?püstkoju =püstkoju  (SgG  >püstkoju !01_S	et	f	\N
198777	püstkoju	?püstkoju =püstkoju  (IndPrPs_  >püstkojuma !27_V	et	f	\N
198778	püstkoju	?püstkoju =püstkoju  (ImpPrSg2  >püstkojuma !27_V	et	f	\N
198836	laatlased	?laatlased =laatlase  (PlN  >laatlane !12?10_S	et	f	\N
198844	muusiumid	?muusiumid =muusiumi  (PlN  >muusium !19~02_S	et	f	\N
198845	muusiumid	?muusiumid =muusiumi  (PlN  >muusiumi !16_S	et	f	\N
198846	muusiumid	?muusiumid =muusiumi  (IndPrSg2  >muusiumima !28_V	et	f	\N
198847	muusiumid	?muusiumid =siumi  (PlN  >muu+siumi !16_S	et	f	\N
198848	muusiumid	?muusiumid =siumi  (PlN  >muu+sium !22_S	et	f	\N
198849	sõõgiriistad	?sõõgiriistad =sõõgiriista  (PlN  >sõõgiriista !16_S	et	f	\N
198850	sõõgiriistad	?sõõgiriistad =sõõgiriista  (IndPrSg2  >sõõgiriistama !27_V	et	f	\N
198871	väljendus	väljendus =väljendu  (IndIpfSg3  >väljenduma !27_V	et	f	\N
198872	väljendus	väljendus =väljendus  (SgN  >väljendus !11_S	et	f	\N
198873	väljendus	"väljendus %väljenda  )US_vS  <väljendama ;27_V	et	f	\N
198896	professionaalsem	professionaalsem =professionaalsem  (SgN  >professionaalsem !02_A	et	f	\N
198897	professionaalsem	"professionaalsem %professionaalse  )M_cA  <professionaalne ;02_A	et	f	\N
198913	kõstri	?kõstri =kõstri  (SgN  >kõstri !01_S	et	f	\N
198914	kõstri	?kõstri =kõstri  (SgG  >kõstri !01_S	et	f	\N
198915	kõstri	?kõstri =kõstri  (SgG  >kõster !02_S	et	f	\N
198916	kõstri	?kõstri =kõstri  (IndPrPs_  >kõstrima !28_V	et	f	\N
198917	kõstri	?kõstri =kõstri  (ImpPrSg2  >kõstrima !28_V	et	f	\N
198925	rahvakoolis	rahvakoolis =kooli  (SgIn  >rahva+kool !22_S	et	f	\N
198926	rahvakoolis	rahvakoolis =kooli  (PlIn  >rahva+kool !22_S	et	f	\N
198942	luterlik	?luterlik =luterlik  (SgN  >luterlik !25_A	et	f	\N
198514	piimatööstust	piimatööstust =tust  (SgN  >piima+töös+tust !22_S	et	f	\N
198515	piimatööstust	piimatööstust =tööstus  (SgP  >piima+tööstus !11~09_S	et	f	\N
198518	aurumasiin	?aurumasiin =aurumasiin  (SgN  >aurumasiin !22_S	et	f	\N
198519	aurumasiin	?aurumasiin =masiin  (SgN  >auru+masiin !22_S	et	f	\N
198520	aurumasiin	?aurumasiin =rumasiin  (SgN  >au+rumasiin !22_S	et	f	\N
198534	saakslased	?saakslased =saakslase  (PlN  >saakslane !12?10_S	et	f	\N
198535	saakslased	?saakslased =slase  (PlN  >saak+slase !16_S	et	f	\N
198541	kindlustusega	kindlustusega =kindlustuse  (SgKom  >kindlustus !11_S	et	f	\N
198542	kindlustusega	"kindlustus %kindlusta  )US_vS  <kindlustama ;27_V	et	f	\N
198553	eraldus	eraldus =eraldu  (IndIpfSg3  >eralduma !27_V	et	f	\N
198554	eraldus	eraldus =eraldus  (SgN  >eraldus !11_S	et	f	\N
198555	eraldus	"eraldus %eralda  )US_vS  <eraldama ;27_V	et	f	\N
198576	mõistnikute	?mõistnikute =mõistniku  (PlG  >mõistniku !01_S	et	f	\N
198577	mõistnikute	?mõistnikute =mõistniku  (IndPrPl2  >mõistnikuma !27_V	et	f	\N
198589	jumalaga	jumalaga =jumala  (SgKom  >jumal !02_S	et	f	\N
198590	jumalaga	jumalaga =jumalaga  (ID  >jumalaga !41_I	et	f	\N
198651	talupojakoolis	talupojakoolis =kooli  (SgIn  >talu+poja+kool !22_S	et	f	\N
198652	talupojakoolis	talupojakoolis =kooli  (PlIn  >talu+poja+kool !22_S	et	f	\N
198706	kandes	kandes =kand  (Ger  >kandma !34_V	et	f	\N
198707	kandes	kandes =kande  (SgIn  >kanne !06_S	et	f	\N
198708	kandes	kandes =kande  (PlIn  >kant !22_S	et	f	\N
198737	ehitusviisi	ehitusviisi =viisi  (SgG  >ehitus+viis !22_S	et	f	\N
198738	ehitusviisi	ehitusviisi =viisi  (SgP  >ehitus+viis !22_S	et	f	\N
198739	ehitusviisi	ehitusviisi =viisi  (SgAdt  >ehitus+viis !22_S	et	f	\N
198740	omanduse	omanduse =omanduse  (SgG  >omandus !11_S	et	f	\N
198741	omanduse	"omandus %omanda  )US_vS  <omandama ;27_V	et	f	\N
198746	kodumendi	?kodumendi =kodumendi  (SgG  >kodument !22_S	et	f	\N
198747	kodumendi	?kodumendi =kodumendi  (SgP  >kodumend !22_S	et	f	\N
198748	kodumendi	?kodumendi =kodumendi  (SgAdt  >kodumend !22_S	et	f	\N
198749	kodumendi	?kodumendi =kodumendi  (IndPrPs_  >kodumentima !28_V	et	f	\N
198750	kodumendi	?kodumendi =kodumendi  (ImpPrSg2  >kodumentima !28_V	et	f	\N
198751	kodumendi	?kodumendi =mendi  (SgN  >kodu+mendi !16_S	et	f	\N
198752	kodumendi	?kodumendi =mendi  (SgG  >kodu+mendi !16_S	et	f	\N
198753	kodumendi	?kodumendi =mendi  (SgG  >kodu+ment !22_S	et	f	\N
198754	kodumendi	?kodumendi =mendi  (SgP  >kodu+mend !22_S	et	f	\N
198755	kodumendi	?kodumendi =mendi  (SgAdt  >kodu+mend !22_S	et	f	\N
198768	peitleidude	### peitleidude	et	f	\N
198792	veelinnujahti	veelinnujahti =jahti  (SgP  >vee+linnu+jaht !22_S	et	f	\N
198793	veelinnujahti	veelinnujahti =jahti  (SgAdt  >vee+linnu+jaht !22_S	et	f	\N
198816	sotsiaal-demok	?sotsiaal-demok =demok  (SgN  >sotsiaal-demok !02_S	et	f	\N
198819	tõendav	tõendav =tõenda  (PtsPrPs  >tõendama !27_V	et	f	\N
198820	tõendav	tõendav =tõendav  (SgN  >tõendav !02_A	et	f	\N
198821	tõendav	"tõendav %tõenda  )V_vA  <tõendama ;27_V	et	f	\N
198822	riigiteenistajad	?riigiteenistajad =riigiteenistaja  (PlN  >riigiteenistaja !01_S	et	f	\N
198823	riigiteenistajad	?riigiteenistajad =riigiteenistaja  (PlN  >riigiteenistajas !02_A	et	f	\N
198824	riigiteenistajad	?riigiteenistajad =nistaja  (PlN  >riigi+tee+nistaja !01_S	et	f	\N
198825	riigiteenistajad	?riigiteenistajad =nistaja  (PlN  >riigi+tee+nistajas !02_A	et	f	\N
198826	riigiteenistajad	?riigiteenistajad =teenistaja  (PlN  >riigi+teenistaja !01_S	et	f	\N
198827	riigiteenistajad	?riigiteenistajad =teenistaja  (PlN  >riigi+teenistajas !02_A	et	f	\N
198837	idast	idast =ida  (SgEl  >ida !17_S	et	f	\N
198838	idast	idast =idas  (SgP  >idane !10_A	et	f	\N
198839	idast	"idane %ida  )NE_aA  <ida ;17_S	et	f	\N
198843	arheoologid	?arheoologid =oologi  (PlN  >arhe+oolog !02_S	et	f	\N
198854	palvetasid	palvetasid =palveta  (IndIpfSg2  >palvetama !27_V	et	f	\N
198855	palvetasid	palvetasid =palveta  (IndIpfPl3  >palvetama !27_V	et	f	\N
198856	relvastust	relvastust =relvastus  (SgP  >relvastus !11_S	et	f	\N
198857	relvastust	"relvastus %relvasta  )US_vS  <relvastama ;27_V	et	f	\N
198878	märkimisväärseks	märkimisväärseks =seks  (SgN  >märki+mis+väär+seks !22_S	et	f	\N
198879	märkimisväärseks	märkimisväärseks =väärse  (SgTr  >märki+mis+väärne !02_A	et	f	\N
198889	parempartei	parempartei =partei  (SgN  >parem+partei !26_S	et	f	\N
198890	parempartei	parempartei =partei  (SgG  >parem+partei !26_S	et	f	\N
198898	põllundusest	põllundusest =põllunduse  (SgEl  >põllundus !11_S	et	f	\N
198899	põllundusest	põllundusest =põllunduses  (SgP  >põllundusene !12_A	et	f	\N
198900	põllundusest	"põllundusene %põllunduse  )NE_aA  <põllundus ;11_S	et	f	\N
198909	kvaliteetsem	kvaliteetsem =kvaliteetsem  (SgN  >kvaliteetsem !02_A	et	f	\N
198910	kvaliteetsem	"kvaliteetsem %kvaliteetse  )M_cA  <kvaliteetne ;02_A	et	f	\N
198918	ettevalmistamaks	?ettevalmistamaks =ettevalmista  (SupTr  >ettevalmistama !27_V	et	f	\N
198919	ettevalmistamaks	?ettevalmistamaks =ettevalmistama  (SgTr  >ettevalmistam !02_A	et	f	\N
198920	ettevalmistamaks	?ettevalmistamaks =tama  (SgTr  >ette+valmis+tama !17_S	et	f	\N
198921	ettevalmistamaks	?ettevalmistamaks =valmistama  (SgTr  >ette+valmistam !02_A	et	f	\N
198922	rahvakoole	rahvakoole =koo  (SgAll  >rahva+kubu !18_S	et	f	\N
198569	rahvuslikus	rahvuslikus =rahvuslikus  (SgN  >rahvuslikus !11?09_S	et	f	\N
198570	rahvuslikus	"rahvuslikus %rahvusliku  )US_aS  <rahvuslik ;25_A	et	f	\N
198574	levendamine	?levendamine =levendamine  (SgN  >levendamine !12_S	et	f	\N
198575	levendamine	?levendamine =levendamine  (PlP  >levendamin !19_S	et	f	\N
198578	tõendava	tõendava =tõendava  (SgG  >tõendav !02_A	et	f	\N
198579	tõendava	"tõendav %tõenda  )V_vA  <tõendama ;27_V	et	f	\N
198580	tõendava	tõendava =ava  (SgN  >tõend+ava !17_S	et	f	\N
198581	tõendava	tõendava =ava  (SgG  >tõend+ava !17_S	et	f	\N
198582	tõendava	tõendava =ava  (SgP  >tõend+ava !17_S	et	f	\N
198594	trükkiti	?trükkiti =trükkiti  (ID  >trükkiti !41_D	et	f	\N
198595	trükkiti	?trükkiti =trükkiti  (SgG  >trükkit !02_S	et	f	\N
198596	trükkiti	?trükkiti =trükkiti  (SgG  >trükkitt !22_S	et	f	\N
198597	trükkiti	?trükkiti =trükkiti  (IndPrPs_  >trükkittima !28_V	et	f	\N
198598	trükkiti	?trükkiti =trükkiti  (ImpPrSg2  >trükkittima !28_V	et	f	\N
198599	koidulaga	koidulaga =la  (SgKom  >koidu+la !26_S	et	f	\N
198600	koidulaga	koidulaga =laga  (SgN  >koidu+laga !17_S	et	f	\N
198601	koidulaga	koidulaga =laga  (SgG  >koidu+laga !17_S	et	f	\N
198602	koidulaga	koidulaga =laga  (SgP  >koidu+laga !17_S	et	f	\N
198629	kirikulaule	kirikulaule =lau  (SgAll  >kiriku+laug !22_SA	et	f	\N
198630	kirikulaule	kirikulaule =laule  (PlP  >kiriku+laul !22_S	et	f	\N
198631	esmasti	?esmasti =esmasti  (ID  >esmasti !41_D	et	f	\N
198632	esmasti	?esmasti =esmasti  (IndPrPs_  >esmastima !28_V	et	f	\N
198633	esmasti	?esmasti =esmasti  (ImpPrSg2  >esmastima !28_V	et	f	\N
198635	kroonikadest	?kroonikadest =kroonikades  (SgP  >kroonikadene !12_A	et	f	\N
198636	kroonikadest	?kroonikadest =kades  (SgP  >krooni+kades !09_S	et	f	\N
198637	kroonikadest	?kroonikadest =kades  (SgP  >krooni+kadene !10_A	et	f	\N
198638	kroonikadest	?kroonikadest =ika  (PlEl  >kroon+ika !16_S	et	f	\N
198639	kroonikadest	?kroonikadest =ikades  (SgP  >kroon+ikadene !12_A	et	f	\N
198642	linnalaps	linnalaps =laps  (SgN  >linna+laps !14_S	et	f	\N
198643	linnalaps	linnalaps =laps  (SgN  >linna+laps !22_S	et	f	\N
198670	anthon	?anthon =anthon  (SgN  >anthon !02_S	et	f	\N
198679	püsimisele	püsimisele =püsimise  (SgAll  >püsimine !12_S	et	f	\N
198680	püsimisele	"püsimine %püsi  )MINE_vS  <püsima ;27_V	et	f	\N
198685	eripärane	eripärane =pärane  (SgN  >eri+pärane !10_A	et	f	\N
198686	eripärane	"eri+pärane %pära  )NE_aA  <eri+pära ;17_S	et	f	\N
198696	vastastena	vastastena =vastas  (PlEs  >vastane !10_AS	et	f	\N
198697	vastastena	vastastena =aste  (SgEs  >vast+aste !06_S	et	f	\N
198702	harimises	harimises =harimise  (SgIn  >harimine !12_S	et	f	\N
198703	harimises	"harimine %hari  )MINE_vS  <harima ;27_V	et	f	\N
198713	taluperemees	taluperemees =mee  (SgIn  >talu+pere+mesi !15_S	et	f	\N
198714	taluperemees	taluperemees =mees  (SgN  >talu+pere+mees !13_S	et	f	\N
198715	talupojakultuuri	talupojakultuuri =kultuuri  (SgG  >talu+poja+kultuur !22_S	et	f	\N
198716	talupojakultuuri	talupojakultuuri =kultuuri  (SgP  >talu+poja+kultuur !22_S	et	f	\N
198718	talupojakultuuri	talupojakultuuri =kultuuri  (SgAdt  >talu+poja+kultuur !22_S	et	f	\N
198722	relveid	?relveid =relve  (PlP  >relve !06_S	et	f	\N
198723	relveid	?relveid =relvei  (PlN  >relvei !26_S	et	f	\N
198724	relveid	?relveid =relvei  (SgP  >relvei !26_S	et	f	\N
198725	relveid	?relveid =relveid  (SgN  >relveid !22_S	et	f	\N
198726	pidamises	pidamises =pidamise  (SgIn  >pidamine !12_S	et	f	\N
198727	pidamises	"pidamine %pida  )MINE_vS  <pidama ;28_V	et	f	\N
198761	esimesene	?esimesene =esimesene  (SgN  >esimesene !12_A	et	f	\N
198762	esimesene	?esimesene =esimesene  (PlP  >esimesen !19_S	et	f	\N
198763	esimesene	?esimesene =mesene  (SgN  >esi+mesene !10_A	et	f	\N
198764	seisukoha	seisukoha =koha  (SgN  >seisu+koha !17_S	et	f	\N
198765	seisukoha	seisukoha =koha  (SgG  >seisu+koha !17_S	et	f	\N
198766	seisukoha	seisukoha =koha  (SgG  >seisu+koht !22_S	et	f	\N
198767	seisukoha	seisukoha =koha  (SgP  >seisu+koha !17_S	et	f	\N
198785	kurjadest	?kurjadest =kurja  (PlEl  >kurja !16_S	et	f	\N
198786	kurjadest	?kurjadest =kurja  (PlEl  >kuri !24_A	et	f	\N
198787	kurjadest	?kurjadest =kurjades  (SgP  >kurjadene !12_A	et	f	\N
198788	ajajärgi	ajajärgi =järgi  (SgG  >aja+järk !22_S	et	f	\N
198789	ajajärgi	ajajärgi =järgi  (SgP  >aja+järg !22_S	et	f	\N
198790	ajajärgi	ajajärgi =järgi  (SgAdt  >aja+järg !22_S	et	f	\N
198791	ajajärgi	ajajärgi =järgi  (PlP  >aja+järg !22_S	et	f	\N
198796	serpe	?serpe =serpe  (SgN  >serpe !06_S	et	f	\N
198797	serpe	?serpe =serpe  (SgG  >serbe !06_S	et	f	\N
198798	serpe	?serpe =serpe  (PlP  >serp !22_S	et	f	\N
198799	serpe	?serpe =serpe  (IndPrPs_  >serpema !27_V	et	f	\N
198800	serpe	?serpe =serpe  (ImpPrSg2  >serpema !27_V	et	f	\N
198807	arendamisi	arendamisi =arendamisi  (PlP  >arendamine !12_S	et	f	\N
198808	arendamisi	"arendamine %arenda  )MINE_vS  <arendama ;27_V	et	f	\N
198810	parnu	?parnu =parnu  (SgN  >parnu !01_S	et	f	\N
198811	parnu	?parnu =parnu  (SgG  >parnu !01_S	et	f	\N
198812	parnu	?parnu =parnu  (IndPrPs_  >parnuma !27_V	et	f	\N
198813	parnu	?parnu =parnu  (ImpPrSg2  >parnuma !27_V	et	f	\N
198603	argikultuuri	argikultuuri =kultuuri  (SgG  >argi+kultuur !22_S	et	f	\N
198604	argikultuuri	argikultuuri =kultuuri  (SgP  >argi+kultuur !22_S	et	f	\N
198605	argikultuuri	argikultuuri =kultuuri  (SgAdt  >argi+kultuur !22_S	et	f	\N
198611	elumõiste	elumõiste =mõiste  (SgN  >elu+mõiste !06_S	et	f	\N
198612	elumõiste	elumõiste =mõiste  (SgG  >elu+mõiste !06_S	et	f	\N
198613	elumõiste	elumõiste =mõiste  (PlP  >elu+mõist !22_S	et	f	\N
198626	peaagu	peaagu =agu  (SgN  >pea+agu !18_S	et	f	\N
198627	peaagu	peaagu =agu  (SgP  >pea+agu !18_S	et	f	\N
198628	maximum	?maximum =maximum  (SgN  >maximum !19_S	et	f	\N
198640	mainitused	mainitused =mainituse  (PlN  >mainitus !11_S	et	f	\N
198641	mainitused	"mainitus %maini  )TUS1_aS  <mainima ;28_V	et	f	\N
198646	huvituti	huvituti =huvitu  (IndIpfIps  >huvituma !27_V	et	f	\N
198647	huvituti	huvituti =tuti  (SgG  >huvi+tutt !22_S	et	f	\N
198667	thorttelle	?thorttelle =thorttelle  (PlP  >thorttell !22_S	et	f	\N
198668	thorttelle	?thorttelle =thorttelle  (IndPrPs_  >thorttellema !27_V	et	f	\N
198669	thorttelle	?thorttelle =thorttelle  (ImpPrSg2  >thorttellema !27_V	et	f	\N
198683	intensiivsemad	intensiivsemad =intensiivsema  (PlN  >intensiivsem !02_A	et	f	\N
198684	intensiivsemad	"intensiivsem %intensiivse  )M_cA  <intensiivne ;02_A	et	f	\N
198689	huvituma	huvituma =huvitu  (Sup  >huvituma !27_V	et	f	\N
198690	huvituma	huvituma =huvituma  (SgG  >huvitum !02_A	et	f	\N
198691	huvituma	"huvitum %huvi  )TUM2_cA  <huvi ;17_S	et	f	\N
198692	huvituma	"huvitum %huvitu  )M_cA  <huvitu ;01_A	et	f	\N
198693	süstisid	süstisid =süsti  (PlP  >süst !22_S	et	f	\N
198694	süstisid	süstisid =süsti  (IndIpfSg2  >süstima !28_V	et	f	\N
198695	süstisid	süstisid =süsti  (IndIpfPl3  >süstima !28_V	et	f	\N
198704	valgustamises	valgustamises =valgustamise  (SgIn  >valgustamine !12_S	et	f	\N
198705	valgustamises	"valgustamine %valgusta  )MINE_vS  <valgustama ;27_V	et	f	\N
198711	kukutamise	kukutamise =kukutamise  (SgG  >kukutamine !12_S	et	f	\N
198712	kukutamise	"kukutamine %kukuta  )MINE_vS  <kukutama ;27_V	et	f	\N
198734	patriorhaalsteks	### patriorhaalsteks	et	f	\N
198809	kreutswald	?kreutswald =kreutswald  (SgN  >kreutswald !02_S	et	f	\N
198817	aritöötajad	?aritöötajad =aritöötaja  (PlN  >aritöötaja !01_S	et	f	\N
198818	aritöötajad	?aritöötajad =aritöötaja  (PlN  >aritöötajas !02_A	et	f	\N
198830	põhjast	põhjast =põhja  (SgEl  >põhi !24_S	et	f	\N
198831	põhjast	põhjast =põhjas  (SgP  >põhjane !10_A	et	f	\N
198832	põhjast	"põhjane %põhja  )NE_aA  <põhi ;24_S	et	f	\N
198840	kammikultuur	?kammikultuur =kammikultuur  (SgN  >kammikultuur !22_S	et	f	\N
198841	kammikultuur	?kammikultuur =ikultuur  (SgN  >kamm+ikultuur !22_S	et	f	\N
198853	munkid	### munkid	et	f	\N
198863	siirdusid	siirdusid =siirdu  (IndIpfSg2  >siirduma !27_V	et	f	\N
198864	siirdusid	siirdusid =siirdu  (IndIpfPl3  >siirduma !27_V	et	f	\N
198867	suurehulgaliselt	suurehulgaliselt =hulgalise  (SgAbl  >suure+hulgaline !12_A	et	f	\N
198868	suurehulgaliselt	"suure+hulgaline %hulga  )LINE_aA  <suure+hulk ;22_S	et	f	\N
198869	suurehulgaliselt	"suure+hulgaliselt %hulga  )LISELT_mD  <suure+hulk ;22_S	et	f	\N
198870	suurehulgaliselt	"suure+hulgaliselt %hulgalise  )LT_mD  <suure+hulgaline ;12_A	et	f	\N
198876	luuletajaks	luuletajaks =luuletaja  (SgTr  >luuletaja !01_S	et	f	\N
198877	luuletajaks	"luuletaja %luuleta  )JA_vS  <luuletama ;27_V	et	f	\N
198880	tuntav	tuntav =tun  (PtsPrIps  >tundma !34_V	et	f	\N
198881	tuntav	tuntav =tuntav  (SgN  >tuntav !02_A	et	f	\N
198882	tuntav	"tuntav %tun  )TAV_vAS  <tundma ;34_V	et	f	\N
198894	taktika	taktika =taktika  (SgN  >taktika !01_S	et	f	\N
198895	taktika	taktika =taktika  (SgG  >taktika !01_S	et	f	\N
198906	kasvatatav	kasvatatav =kasvata  (PtsPrIps  >kasvatama !27_V	et	f	\N
198907	kasvatatav	kasvatatav =kasvatatav  (SgN  >kasvatatav !02_A	et	f	\N
198908	kasvatatav	"kasvatatav %kasvata  )TAV_vAS  <kasvatama ;27_V	et	f	\N
198927	jõukamate	jõukamate =jõukama  (PlG  >jõukam !02_A	et	f	\N
198928	jõukamate	"jõukam %jõuka  )M_cA  <jõukas ;02_A	et	f	\N
198938	impordiks	impordiks =impordi  (SgTr  >import !22_S	et	f	\N
198939	impordiks	impordiks =impordi  (KndPrPs  >importima !28_V	et	f	\N
198975	sulatamine	sulatamine =sulatamine  (SgN  >sulatamine !12_S	et	f	\N
198976	sulatamine	"sulatamine %sulata  )MINE_vS  <sulatama ;27_V	et	f	\N
198979	viljasaaki	viljasaaki =saaki  (SgP  >vilja+saak !22_S	et	f	\N
198980	viljasaaki	viljasaaki =saaki  (SgAdt  >vilja+saak !22_S	et	f	\N
198981	tarandkalmetesse	?tarandkalmetesse =tarandkalmete  (PlIll  >tarandkalmett !22_S	et	f	\N
198982	tarandkalmetesse	?tarandkalmetesse =tarandkalmetes  (SgAdt  >tarandkalmetene !12_A	et	f	\N
198983	tarandkalmetesse	?tarandkalmetesse =tarandkalmetesse  (SgG  >tarandkalmetesne !02_A	et	f	\N
198984	tarandkalmetesse	?tarandkalmetesse =tarandkalmetesse  (PlP  >tarandkalmetess !22_S	et	f	\N
199001	vallutamisega	vallutamisega =vallutamise  (SgKom  >vallutamine !12_S	et	f	\N
199002	vallutamisega	"vallutamine %valluta  )MINE_vS  <vallutama ;27_V	et	f	\N
199009	teataval	teataval =teatava  (SgAd  >teatav !02_A	et	f	\N
199010	teataval	"teatav %tea  )TAV_vAS  <teadma ;34_V	et	f	\N
199011	teataval	"teatav %teata  )V_vA  <teatama ;27_V	et	f	\N
199061	linzendorffi	?linzendorffi =linzendorffi  (IndPrPs_  >linzendorffima !28_V	et	f	\N
198688	võsud	võsud =võsu  (IndPrSg2  >võsuma !27_V	et	f	\N
198698	iseteadvusetõusus	iseteadvusetõusus =tõusu  (SgIn  >ise+teadvuse+tõus !22_S	et	f	\N
198699	iseteadvusetõusus	iseteadvusetõusus =tõusus  (SgN  >ise+teadvuse+tõusus !11~09_S	et	f	\N
198700	iseteadvusetõusus	"ise+teadvuse+tõusus %tõu  )SUS_aS  <ise+teadvuse+tõug ;22_S	et	f	\N
198701	iseteadvusetõusus	"ise+teadvuse+tõusus %tõu  )SUS_aS  <ise+teadvuse+tõu ;26_S	et	f	\N
198709	teadusemees	teadusemees =mee  (SgIn  >teaduse+mesi !15_S	et	f	\N
198710	teadusemees	teadusemees =mees  (SgN  >teaduse+mees !13_S	et	f	\N
198732	peeres	peeres =peere  (PlIn  >peerg !22_S	et	f	\N
198733	peeres	peeres =peere  (PlIn  >peer !22_S	et	f	\N
198735	ohverdamised	ohverdamised =ohverdamise  (PlN  >ohverdamine !12_S	et	f	\N
198736	ohverdamised	"ohverdamine %ohverda  )MINE_vS  <ohverdama ;27_V	et	f	\N
198743	hõbet	### hõbet	et	f	\N
198756	kirjavara	kirjavara =vara  (SgN  >kirja+vara !17_S	et	f	\N
198757	kirjavara	kirjavara =vara  (SgG  >kirja+vara !17_S	et	f	\N
198758	kirjavara	kirjavara =vara  (SgP  >kirja+vara !17_S	et	f	\N
198759	käsiraamatud	käsiraamatud =atu  (PlN  >käsi+raam+att !22_S	et	f	\N
198760	käsiraamatud	käsiraamatud =raamatu  (PlN  >käsi+raamat !02_S	et	f	\N
198779	hauatagusse	?hauatagusse =hauatagus  (SgAdt  >hauatagus !11_S	et	f	\N
198780	hauatagusse	?hauatagusse =hauatagusse  (SgG  >hauatagusne !02_A	et	f	\N
198781	hauatagusse	?hauatagusse =hauatagusse  (PlP  >hauataguss !22_S	et	f	\N
198782	hauatagusse	?hauatagusse =tagu  (SgIll  >haua+tagu !17_S	et	f	\N
198783	hauatagusse	?hauatagusse =tagusse  (SgG  >haua+tagusne !02_A	et	f	\N
198784	hauatagusse	?hauatagusse =tagusse  (PlP  >haua+taguss !22_S	et	f	\N
198794	anastaspõllumajandusest	?anastaspõllumajandusest =anastaspõllumajanduse  (SgEl  >anastaspõllumajandus !11_S	et	f	\N
198795	anastaspõllumajandusest	?anastaspõllumajandusest =anastaspõllumajanduses  (SgP  >anastaspõllumajandusene !12_A	et	f	\N
198801	kõblaid	?kõblaid =kõblai  (PlN  >kõblai !26_S	et	f	\N
198802	kõblaid	?kõblaid =kõblai  (SgP  >kõblai !26_S	et	f	\N
198803	kõblaid	?kõblaid =kõblaid  (SgN  >kõblaid !22_S	et	f	\N
198804	reliigia	?reliigia =reliigia  (SgN  >reliigia !01_S	et	f	\N
198805	reliigia	?reliigia =reliigia  (SgG  >reliigia !01_S	et	f	\N
198806	talupogade	?talupogade =poga  (PlG  >talu+poga !17_S	et	f	\N
198814	lkoidula	?lkoidula =lkoidula  (SgN  >lkoidula !01_S	et	f	\N
198815	lkoidula	?lkoidula =lkoidula  (SgG  >lkoidula !01_S	et	f	\N
198842	nõõrsokultuur	?nõõrsokultuur =nõõrsokultuur  (SgN  >nõõrsokultuur !22_S	et	f	\N
198860	aidasid	?aidasid =aida  (PlP  >aida !16_S	et	f	\N
198861	aidasid	?aidasid =aida  (IndIpfSg2  >aidama !29_V	et	f	\N
198862	aidasid	?aidasid =aida  (IndIpfPl3  >aidama !29_V	et	f	\N
198874	algatajateks	algatajateks =algataja  (PlTr  >algataja !01_S	et	f	\N
198875	algatajateks	"algataja %algata  )JA_vS  <algatama ;27_V	et	f	\N
198885	lihtrahvast	lihtrahvast =rahva  (SgEl  >liht+rahvas !07_S	et	f	\N
198886	lihtrahvast	lihtrahvast =rahvas  (SgP  >liht+rahvas !07_S	et	f	\N
198887	lihtrahvast	lihtrahvast =rahvas  (SgP  >liht+rahvane !10_A	et	f	\N
198888	lihtrahvast	"liht+rahvane %rahva  )NE_aA  <liht+rahvas ;07_S	et	f	\N
198891	mõjuvat	mõjuvat =mõju  (KvtPrPs  >mõjuma !27_V	et	f	\N
198892	mõjuvat	mõjuvat =mõjuva  (SgP  >mõjuv !02_A	et	f	\N
198893	mõjuvat	"mõjuv %mõju  )V_vA  <mõjuma ;27_V	et	f	\N
198901	mõjuvamad	mõjuvamad =mõjuvama  (PlN  >mõjuvam !02_A	et	f	\N
198902	mõjuvamad	"mõjuvam %mõju  )VAM_cA  <mõjuma ;27_V	et	f	\N
198903	mõjuvamad	"mõjuvam %mõjuva  )M_cA  <mõjuv ;02_A	et	f	\N
198904	siinmaal	siinmaal =maa  (SgAd  >siin+maa !26_S	et	f	\N
198905	siinmaal	siinmaal =maal  (SgN  >siin+maal !22_S	et	f	\N
198911	töötlemiseks	töötlemiseks =töötlemise  (SgTr  >töötlemine !12_S	et	f	\N
198912	töötlemiseks	"töötlemine %töötle  )MINE_vS  <töötlema ;30_V	et	f	\N
198940	rikastumist	rikastumist =rikastumis  (SgP  >rikastumine !12_S	et	f	\N
198941	rikastumist	"rikastumine %rikastu  )MINE_vS  <rikastuma ;27_V	et	f	\N
198945	tähtsaimad	tähtsaimad =tähtsaima  (PlN  >tähtsaim !02_A	et	f	\N
198946	tähtsaimad	"tähtsaim %tähtsa  )IM_sA  <tähtis ;02_A	et	f	\N
198947	radikaalsema	radikaalsema =radikaalsema  (SgG  >radikaalsem !02_A	et	f	\N
198948	radikaalsema	"radikaalsem %radikaalse  )M_cA  <radikaalne ;02_A	et	f	\N
198970	vastupidavamad	vastupidavamad =pidavama  (PlN  >vastu+pidavam !02_A	et	f	\N
198971	vastupidavamad	"vastu+pidavam %pidava  )M_cA  <vastu+pidav ;02_A	et	f	\N
198987	ühikkond	?ühikkond =ühikkond  (SgN  >ühikkond !22_S	et	f	\N
198995	osavus	osavus =osavus  (SgN  >osavus !11_S	et	f	\N
198996	osavus	"osavus %osava  )US_aS  <osav ;02_A	et	f	\N
199020	kultuuriliselt	kultuuriliselt =kultuurilise  (SgAbl  >kultuuriline !12_A	et	f	\N
199021	kultuuriliselt	"kultuuriline %kultuuri  )LINE_aA  <kultuur ;22_S	et	f	\N
199022	kultuuriliselt	kultuuriliselt =kultuuriliselt  (ID  >kultuuriliselt !41_D	et	f	\N
199023	kultuuriliselt	"kultuuriliselt %kultuuri  )LISELT_mD  <kultuur ;22_S	et	f	\N
199024	kultuuriliselt	"kultuuriliselt %kultuurilise  )LT_mD  <kultuuriline ;12_A	et	f	\N
199027	rahvulikus	?rahvulikus =rahvuliku  (SgIn  >rahvulik !25_A	et	f	\N
199028	rahvulikus	?rahvulikus =rahvuliku  (IndIpfSg3  >rahvulikuma !27_V	et	f	\N
199029	rahvulikus	?rahvulikus =rahvulikus  (SgN  >rahvulikus !11?09_S	et	f	\N
198828	mojutasid	?mojutasid =mojuta  (IndIpfSg2  >mojutama !27_V	et	f	\N
198829	mojutasid	?mojutasid =mojuta  (IndIpfPl3  >mojutama !27_V	et	f	\N
198833	idast	idast =ida  (SgEl  >ida !17_S	et	f	\N
198834	idast	idast =idas  (SgP  >idane !10_A	et	f	\N
198835	idast	"idane %ida  )NE_aA  <ida ;17_S	et	f	\N
198851	kirikutedes	?kirikutedes =tede  (SgIn  >kiriku+tede !16_S	et	f	\N
198852	kirikutedes	?kirikutedes =tedes  (SgN  >kiriku+tedes !09_S	et	f	\N
198858	tööriste	tööriste =riste  (SgN  >töö+riste !05_S	et	f	\N
198859	tööriste	tööriste =riste  (PlP  >töö+rist !22_S	et	f	\N
198865	võtsidki	võtsidki =võt  (IndIpfSg2^  >võtma !35_V	et	f	\N
198866	võtsidki	võtsidki =võt  (IndIpfPl3^  >võtma !35_V	et	f	\N
198883	feodaalkorra	?feodaalkorra =feodaalkorra  (SgN  >feodaalkorra !16_S	et	f	\N
198884	feodaalkorra	?feodaalkorra =feodaalkorra  (SgG  >feodaalkorra !16_S	et	f	\N
198931	rahvakooli	rahvakooli =kooli  (SgG  >rahva+kool !22_S	et	f	\N
198932	rahvakooli	rahvakooli =kooli  (SgP  >rahva+kool !22_S	et	f	\N
198933	rahvakooli	rahvakooli =kooli  (SgAdt  >rahva+kool !22_S	et	f	\N
198934	rahvakooli	rahvakooli =kooli  (PlP  >rahva+kool !22_S	et	f	\N
198935	läänemaailmale	läänemaailmale =ale  (SgN  >lääne+maa+ilm+ale !16_S	et	f	\N
198936	läänemaailmale	läänemaailmale =ale  (SgG  >lääne+maa+ilm+ale !16_S	et	f	\N
198937	läänemaailmale	läänemaailmale =ilma  (SgAll  >lääne+maa+ilm !22_S	et	f	\N
198943	soosis	soosis =soosi  (SgIn  >soos !22_S	et	f	\N
198944	soosis	soosis =soosi  (IndIpfSg3  >soosima !28_V	et	f	\N
198954	koguja	koguja =koguja  (SgN  >koguja !01_S	et	f	\N
198955	koguja	"koguja %kogu  )JA_vS  <koguma ;27_V	et	f	\N
198956	koguja	koguja =koguja  (SgG  >koguja !01_S	et	f	\N
198977	söötis	söötis =sööt  (IndIpfSg3  >söötma !34_V	et	f	\N
198978	söötis	söötis =söötis  (ID  >söötis !41_DA	et	f	\N
198997	künniloomana	künniloomana =mana  (SgN  >künni+loo+mana !17_S	et	f	\N
198998	künniloomana	künniloomana =mana  (SgG  >künni+loo+mana !17_S	et	f	\N
198999	künniloomana	künniloomana =mana  (SgP  >künni+loo+mana !17_S	et	f	\N
199000	künniloomana	künniloomana =looma  (SgEs  >künni+loom !22_S	et	f	\N
199012	ülestõusu	ülestõusu =tõusu  (SgG  >üles+tõus !22_S	et	f	\N
199013	ülestõusu	ülestõusu =tõusu  (SgP  >üles+tõus !22_S	et	f	\N
199014	ülestõusu	ülestõusu =tõusu  (SgAdt  >üles+tõus !22_S	et	f	\N
199015	võõrvõimust	võõrvõimust =must  (SgN  >võõr+või+must !22_AS	et	f	\N
199016	võõrvõimust	võõrvõimust =võimu  (SgEl  >võõr+võim !22_S	et	f	\N
199017	võõrvõimust	võõrvõimust =võimus  (SgP  >võõr+võimus !09_S	et	f	\N
199037	tantsijat	tantsijat =tantsija  (SgP  >tantsija !01_S	et	f	\N
199038	tantsijat	"tantsija %tantsi  )JA_vS  <tantsima ;28_V	et	f	\N
199039	pehmendasid	pehmendasid =pehmenda  (IndIpfSg2  >pehmendama !27_V	et	f	\N
199040	pehmendasid	pehmendasid =pehmenda  (IndIpfPl3  >pehmendama !27_V	et	f	\N
199046	korrapärane	korrapärane =pärane  (SgN  >korra+pärane !10_A	et	f	\N
199047	korrapärane	"korra+pärane %pära  )NE_aA  <korra+pära ;17_S	et	f	\N
199054	asutustele	asutustele =asutus  (PlAll  >asutus !11_S	et	f	\N
199055	asutustele	"asutus %asuta  )US_vS  <asutama ;27_V	et	f	\N
199056	asutustele	"asutus %asu  )TUS1_aS  <asuma ;27_V	et	f	\N
199057	asutustele	"asutus %asu  )TUS2_aS  <asu ;17_S	et	f	\N
199058	asutustele	asutustele =tuste  (PlAll  >asu+tust !22_S	et	f	\N
199060	descartresi	?descartresi =descartresi  (PlP  >descartrene !12_A	et	f	\N
199068	eeltsentsuuri	?eeltsentsuuri =eeltsentsuuri  (SgN  >eeltsentsuuri !16_S	et	f	\N
199069	eeltsentsuuri	?eeltsentsuuri =eeltsentsuuri  (SgG  >eeltsentsuuri !16_S	et	f	\N
199070	eeltsentsuuri	?eeltsentsuuri =eeltsentsuuri  (SgG  >eeltsentsuur !22_S	et	f	\N
199071	eeltsentsuuri	?eeltsentsuuri =eeltsentsuuri  (SgP  >eeltsentsuur !22_S	et	f	\N
199072	eeltsentsuuri	?eeltsentsuuri =eeltsentsuuri  (SgAdt  >eeltsentsuur !22_S	et	f	\N
199073	eeltsentsuuri	?eeltsentsuuri =eeltsentsuuri  (IndPrPs_  >eeltsentsuurima !28_V	et	f	\N
199074	eeltsentsuuri	?eeltsentsuuri =eeltsentsuuri  (ImpPrSg2  >eeltsentsuurima !28_V	et	f	\N
199075	eeltsentsuuri	?eeltsentsuuri =tsentsuuri  (SgN  >eel+tsentsuuri !16_S	et	f	\N
199076	eeltsentsuuri	?eeltsentsuuri =tsentsuuri  (SgG  >eel+tsentsuuri !16_S	et	f	\N
199077	eeltsentsuuri	?eeltsentsuuri =tsentsuuri  (SgG  >eel+tsentsuur !22_S	et	f	\N
199078	eeltsentsuuri	?eeltsentsuuri =tsentsuuri  (SgP  >eel+tsentsuur !22_S	et	f	\N
199079	eeltsentsuuri	?eeltsentsuuri =tsentsuuri  (SgAdt  >eel+tsentsuur !22_S	et	f	\N
199087	kalastamisest	kalastamisest =kalastamise  (SgEl  >kalastamine !12_S	et	f	\N
199088	kalastamisest	"kalastamine %kalasta  )MINE_vS  <kalastama ;27_V	et	f	\N
199125	inimarvu	inimarvu =arvu  (SgG  >inim+arv !22_S	et	f	\N
199126	inimarvu	inimarvu =arvu  (SgP  >inim+arv !22_S	et	f	\N
199127	inimarvu	inimarvu =arvu  (SgAdt  >inim+arv !22_S	et	f	\N
199148	surusid	surusid =suru  (PlP  >suru !17_S	et	f	\N
199149	surusid	surusid =suru  (IndIpfSg2  >suruma !27_V	et	f	\N
199150	surusid	surusid =suru  (IndIpfPl3  >suruma !27_V	et	f	\N
199161	viljakasvatus	viljakasvatus =kasvatu  (SgIn  >vilja+kasvatu !01_AS	et	f	\N
199162	viljakasvatus	viljakasvatus =kasvatus  (SgN  >vilja+kasvatus !11_S	et	f	\N
199172	saaklased	?saaklased =saaklase  (PlN  >saaklane !12?10_S	et	f	\N
198923	rahvakoole	rahvakoole =koole  (SgN  >rahva+koole !05_S	et	f	\N
198924	rahvakoole	rahvakoole =koole  (PlP  >rahva+kool !22_S	et	f	\N
198929	targemad	targemad =targema  (PlN  >targem !02_A	et	f	\N
198930	targemad	"targem %targe  )M_cA  <tark ;22_AS	et	f	\N
198949	toetaja	toetaja =toetaja  (SgN  >toetaja !01_S	et	f	\N
198950	toetaja	"toetaja %toeta  )JA_vS  <toetama ;27_V	et	f	\N
198951	toetaja	toetaja =toetaja  (SgG  >toetaja !01_S	et	f	\N
198957	organiseerija	organiseerija =organiseerija  (SgN  >organiseerija !01_S	et	f	\N
198958	organiseerija	"organiseerija %organiseeri  )JA_vS  <organiseerima ;28_V	et	f	\N
198959	organiseerija	organiseerija =organiseerija  (SgG  >organiseerija !01_S	et	f	\N
198972	tätsam	?tätsam =tätsam  (SgN  >tätsam !02_A	et	f	\N
198985	ringikujulistesse	ringikujulistesse =kujulis  (PlIll  >ringi+kujuline !12_A	et	f	\N
198986	ringikujulistesse	"ringi+kujuline %kuju  )LINE_aA  <ringi+kuju ;17_S	et	f	\N
198988	kantavate	kantavate =kantava  (PlG  >kantav !02_A	et	f	\N
198989	kantavate	"kantav %kan  )TAV_vAS  <kandma ;34_V	et	f	\N
198993	ketramise	ketramise =ketramise  (SgG  >ketramine !12_S	et	f	\N
198994	ketramise	"ketramine %ketra  )MINE_vS  <ketrama ;29_V	et	f	\N
199018	isikuvabaduse	isikuvabaduse =vabaduse  (SgG  >isiku+vabadus !11_S	et	f	\N
199019	isikuvabaduse	"isiku+vabadus %vaba  )US_aS  <isiku+vaba ;17_A	et	f	\N
199030	liikumisest	liikumisest =liikumise  (SgEl  >liikumine !12_S	et	f	\N
199031	liikumisest	"liikumine %liiku  )MINE_vS  <liikuma ;28_V	et	f	\N
199063	juhuluule	juhuluule =luu  (SgAll  >juhu+luu !26_S	et	f	\N
199064	juhuluule	juhuluule =luule  (SgN  >juhu+luule !06_S	et	f	\N
199065	juhuluule	juhuluule =luule  (SgG  >juhu+luule !06_S	et	f	\N
199066	juhuluule	juhuluule =luule  (PlP  >juhu+luul !22_S	et	f	\N
199093	kõplad	kõplad =kõpla  (PlN  >kõblas !07_S	et	f	\N
199094	kõplad	kõplad =kõpla  (IndPrSg2  >kõplama !29_V	et	f	\N
199097	juude	?juude =juu  (PlG  >juu !26_S	et	f	\N
199098	juude	?juude =juude  (SgN  >juude !06_S	et	f	\N
199099	juude	?juude =juude  (PlP  >juud !22_S	et	f	\N
199100	juude	?juude =juude  (IndPrPs_  >juudema !27_V	et	f	\N
199101	juude	?juude =juude  (ImpPrSg2  >juudema !27_V	et	f	\N
199128	usundisel	?usundisel =usundise  (SgAd  >usundis !11_S	et	f	\N
199147	lõõk	?lõõk =lõõk  (SgN  >lõõk !22_S	et	f	\N
199155	kooskõlastatus	kooskõlastatus =kõlastatu  (SgIn  >koos+kõlastatu !01_S	et	f	\N
199156	kooskõlastatus	kooskõlastatus =kõlastatus  (SgN  >koos+kõlastatus !11?09_S	et	f	\N
199163	tahtsal	?tahtsal =tahtsa  (SgAd  >tahtsa !01_S	et	f	\N
199164	tahtsal	?tahtsal =tahtsal  (SgN  >tahtsal !02_S	et	f	\N
199173	sõjavangi	sõjavangi =vangi  (SgG  >sõja+vang !22_S	et	f	\N
199174	sõjavangi	sõjavangi =vangi  (SgP  >sõja+vang !22_S	et	f	\N
199175	sõjavangi	sõjavangi =vangi  (SgAdt  >sõja+vang !22_S	et	f	\N
199176	jäämise	jäämise =jäämise  (SgG  >jäämine !12?10_S	et	f	\N
199177	jäämise	"jäämine %jää  )MINE_vS  <jääma ;37_V	et	f	\N
199178	jäämise	"jäämine %jäämi  )NE_aA  <jääm ;22_S	et	f	\N
199194	vabaduseks	vabaduseks =vabaduse  (SgTr  >vabadus !11_S	et	f	\N
199195	vabaduseks	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
199214	pööraste	pööraste =pööras  (PlG  >pöörane !10_A	et	f	\N
199215	pööraste	"pöörane %pööra  )NE_aA  <pöör ;22_S	et	f	\N
199218	maavillane	maavillane =villane  (SgN  >maa+villane !10_A	et	f	\N
199219	maavillane	"maa+villane %villa  )NE_aA  <maa+villa ;16_S	et	f	\N
199220	maavillane	"maa+villane %villa  )NE_aA  <maa+vill ;22_S	et	f	\N
199256	filmiteost	filmiteost =teo  (SgEl  >filmi+tegu !18_S	et	f	\N
199257	filmiteost	filmiteost =teo  (SgEl  >filmi+tigu !18_S	et	f	\N
199258	filmiteost	filmiteost =teos  (SgP  >filmi+teos !09_S	et	f	\N
199281	karmid	karmid =karmi  (PlN  >karm !22_S	et	f	\N
199282	karmid	karmid =karmi  (PlN  >karm !22_A	et	f	\N
199296	madisepäeva	madisepäeva =päeva  (SgG  >madise+päev !22_S	et	f	\N
199297	madisepäeva	madisepäeva =päeva  (SgP  >madise+päev !22_S	et	f	\N
199298	madisepäeva	madisepäeva =päeva  (SgAdt  >madise+päev !22_S	et	f	\N
199326	eelkäijaest	?eelkäijaest =eelkäijae  (SgEl  >eelkäijae !26_S	et	f	\N
199327	eelkäijaest	?eelkäijaest =käijae  (SgEl  >eel+käijae !26_S	et	f	\N
199328	eelkäijaest	?eelkäijaest =käijaes  (SgP  >eel+käijaene !12~10_A	et	f	\N
199336	väiksele	väiksele =väikse  (SgAll  >väike !10_A	et	f	\N
199337	väiksele	"väike %väi  )KE_dS  <väi ;26_S	et	f	\N
199342	huviorbiiti	huviorbiiti =orbiiti  (SgP  >huvi+orbiit !22_S	et	f	\N
199343	huviorbiiti	huviorbiiti =orbiiti  (SgAdt  >huvi+orbiit !22_S	et	f	\N
199364	oimetuks	oimetuks =oimetu  (SgTr  >oimetu !01_A	et	f	\N
199365	oimetuks	oimetuks =oimetu  (KndPrPs  >oimetuma !27_V	et	f	\N
199368	situdagi	?situdagi =situ  (Inf^  >situma !27_V	et	f	\N
199383	interpretatsiooni	interpretatsiooni =interpretatsiooni  (SgG  >interpretatsioon !22_S	et	f	\N
199384	interpretatsiooni	interpretatsiooni =interpretatsiooni  (SgP  >interpretatsioon !22_S	et	f	\N
199385	interpretatsiooni	interpretatsiooni =interpretatsiooni  (SgAdt  >interpretatsioon !22_S	et	f	\N
199403	viist	?viist =vii  (SgEl  >vii !26_S	et	f	\N
199404	viist	?viist =viist  (SgN  >viist !22_S	et	f	\N
199440	sajaldil	?sajaldil =sajaldi  (SgAd  >sajaldi !01_S	et	f	\N
198952	tasakaalukam	tasakaalukam =kaalukam  (SgN  >tasa+kaalukam !02_A	et	f	\N
198953	tasakaalukam	"tasa+kaalukam %kaaluka  )M_cA  <tasa+kaalukas ;02_A	et	f	\N
198960	aastasajal	?aastasajal =aastasaja  (SgAd  >aastasaja !01_S	et	f	\N
198961	aastasajal	?aastasajal =aastasaja  (SgAd  >aastasajas !02_A	et	f	\N
198962	aastasajal	?aastasajal =aastasajal  (SgN  >aastasajal !19_S	et	f	\N
198963	aastasajal	?aastasajal =saja  (SgAd  >aasta+saja !17_S	et	f	\N
198964	aastasajal	?aastasajal =sajal  (SgN  >aasta+sajal !02_S	et	f	\N
198965	aastasajal	?aastasajal =tasaja  (SgAd  >aas+tasaja !01_S	et	f	\N
198966	aastasajal	?aastasajal =tasaja  (SgAd  >aas+tasajas !02_A	et	f	\N
198967	aastasajal	?aastasajal =tasajal  (SgN  >aas+tasajal !19_S	et	f	\N
198968	efektiivsemad	efektiivsemad =efektiivsema  (PlN  >efektiivsem !02_A	et	f	\N
198969	efektiivsemad	"efektiivsem %efektiivse  )M_cA  <efektiivne ;02_A	et	f	\N
198973	rauamaaki	rauamaaki =maaki  (SgP  >raua+maak !22_S	et	f	\N
198974	rauamaaki	rauamaaki =maaki  (SgAdt  >raua+maak !22_S	et	f	\N
198990	kudumise	kudumise =kudumise  (SgG  >kudumine !12_S	et	f	\N
198991	kudumise	"kudumine %kudu  )MINE_vS  <kuduma ;28_V	et	f	\N
198992	kudumise	"kudumine %kudumi  )NE_aA  <kudum ;02_S	et	f	\N
199003	vöörvõimu	?vöörvõimu =vöörvõimu  (SgN  >vöörvõimu !01_S	et	f	\N
199004	vöörvõimu	?vöörvõimu =vöörvõimu  (SgG  >vöörvõimu !01_S	et	f	\N
199005	vöörvõimu	?vöörvõimu =vöörvõimu  (IndPrPs_  >vöörvõimuma !27_V	et	f	\N
199006	vöörvõimu	?vöörvõimu =vöörvõimu  (ImpPrSg2  >vöörvõimuma !27_V	et	f	\N
199007	pühul	?pühul =pühu  (SgAd  >pühu !17_S	et	f	\N
199008	pühul	?pühul =pühul  (SgN  >pühul !02_S	et	f	\N
199025	õpetusele	õpetusele =õpetuse  (SgAll  >õpetus !11_S	et	f	\N
199026	õpetusele	"õpetus %õpeta  )US_vS  <õpetama ;27_V	et	f	\N
199035	ühtekuuluvus	ühtekuuluvus =kuuluvus  (SgN  >ühte+kuuluvus !11_S	et	f	\N
199036	ühtekuuluvus	"ühte+kuuluvus %kuuluva  )US_aS  <ühte+kuuluv ;02_A	et	f	\N
199048	teotöö	teotöö =töö  (SgN  >teo+töö !26_S	et	f	\N
199049	teotöö	teotöö =töö  (SgG  >teo+töö !26_S	et	f	\N
199059	tõlgit	?tõlgit =tõlgit  (SgN  >tõlgit !02_S	et	f	\N
199083	korilusest	korilusest =koriluse  (SgEl  >korilus !11_S	et	f	\N
199084	korilusest	"korilus %korilase  )US_aS  <korilane ;12_S	et	f	\N
199085	korilusest	korilusest =koriluses  (SgP  >korilusene !12_A	et	f	\N
199086	korilusest	"korilusene %koriluse  )NE_aA  <korilus ;11_S	et	f	\N
199089	kõplapõllundus	?kõplapõllundus =kõplapõllundu  (IndIpfSg3  >kõplapõllunduma !27_V	et	f	\N
199090	kõplapõllundus	?kõplapõllundus =kõplapõllundus  (SgN  >kõplapõllundus !11_S	et	f	\N
199095	maalappi	maalappi =lappi  (SgP  >maa+lapp !22_S	et	f	\N
199096	maalappi	maalappi =lappi  (SgAdt  >maa+lapp !22_S	et	f	\N
199151	kaubandusteed	kaubandusteed =tee  (PlN  >kaubandus+tee !26_S	et	f	\N
199152	kaubandusteed	kaubandusteed =tee  (SgP  >kaubandus+tee !26_S	et	f	\N
199159	toita	toita =toi  (SgAb  >toi !26_S	et	f	\N
199160	toita	toita =toit  (Inf  >toitma !34_V	et	f	\N
199184	eestlasliku	?eestlasliku =eestlasliku  (SgG  >eestlaslik !25_A	et	f	\N
199185	eestlasliku	?eestlasliku =eestlasliku  (IndPrPs_  >eestlaslikuma !27_V	et	f	\N
199186	eestlasliku	?eestlasliku =eestlasliku  (ImpPrSg2  >eestlaslikuma !27_V	et	f	\N
199187	eestlasliku	?eestlasliku =lasliku  (SgN  >eest+lasliku !01_S	et	f	\N
199189	eestlasliku	?eestlasliku =lasliku  (SgG  >eest+lasliku !01_S	et	f	\N
199191	eestlasliku	?eestlasliku =lasliku  (SgG  >eest+laslik !25_A	et	f	\N
199196	anastamine	anastamine =anastamine  (SgN  >anastamine !12_S	et	f	\N
199197	anastamine	"anastamine %anasta  )MINE_vS  <anastama ;27_V	et	f	\N
199209	mõistlikult	mõistlikult =mõistliku  (SgAbl  >mõistlik !25_A	et	f	\N
199210	mõistlikult	mõistlikult =mõistlikult  (ID  >mõistlikult !41_D	et	f	\N
199211	mõistlikult	"mõistlikult %mõistliku  )LT_mD  <mõistlik ;25_A	et	f	\N
199216	takune	takune =takune  (SgN  >takune !10_A	et	f	\N
199217	takune	"takune %taku  )NE_aA  <takk ;22_S	et	f	\N
199275	karupee	karupee =pee  (SgN  >karu+pee !26_S	et	f	\N
199276	karupee	karupee =pee  (SgG  >karu+pee !26_S	et	f	\N
199299	vallutajatega	vallutajatega =vallutaja  (PlKom  >vallutaja !01_S	et	f	\N
199300	vallutajatega	"vallutaja %valluta  )JA_vS  <vallutama ;27_V	et	f	\N
199305	raskendatud	raskendatud =raskenda  (PtsPtIps  >raskendama !27_V	et	f	\N
199306	raskendatud	raskendatud =raskendatu  (PlN  >raskendatu !01_S	et	f	\N
199307	raskendatud	"raskendatu %raskenda  )TU1_vS  <raskendama ;27_V	et	f	\N
199308	raskendatud	raskendatud =raskendatud  (ID  >raskendatud !41_A	et	f	\N
199309	raskendatud	"raskendatud %raskenda  )TUD_vA  <raskendama ;27_V	et	f	\N
199310	veriselt	veriselt =verise  (SgAbl  >verine !10_A	et	f	\N
199311	veriselt	"verine %veri  )NE_aA  <veri ;20_S	et	f	\N
199312	veriselt	veriselt =veriselt  (ID  >veriselt !41_D	et	f	\N
199313	veriselt	"veriselt %verise  )LT_mD  <verine ;10_A	et	f	\N
199331	uhkekski	uhkekski =uhke  (SgTr^  >uhke !01_A	et	f	\N
199332	uhkekski	uhkekski =uhke  (SgTr^  >uhe !06_S	et	f	\N
199359	kentsakas	kentsakas =kentsaka  (SgIn  >kentsakas !02_A	et	f	\N
199360	kentsakas	kentsakas =kentsakas  (SgN  >kentsakas !02_A	et	f	\N
199376	tõepärane	tõepärane =pärane  (SgN  >tõe+pärane !10_A	et	f	\N
199377	tõepärane	"tõe+pärane %pära  )NE_aA  <tõe+pära ;17_S	et	f	\N
199032	lauluseltsi	lauluseltsi =seltsi  (SgG  >laulu+selts !22_S	et	f	\N
199033	lauluseltsi	lauluseltsi =seltsi  (SgP  >laulu+selts !22_S	et	f	\N
199034	lauluseltsi	lauluseltsi =seltsi  (SgAdt  >laulu+selts !22_S	et	f	\N
199041	1850ndatel	?ndatel =ndate  (PlAd  >ndatt !22_S	et	f	\N
199042	1850ndatel	?ndatel =ndatel  (SgN  >ndatel !02_S	et	f	\N
199043	protestisid	protestisid =protesti  (PlP  >protest !22_S	et	f	\N
199044	protestisid	protestisid =protesti  (IndIpfSg2  >protestima !28_V	et	f	\N
199045	protestisid	protestisid =protesti  (IndIpfPl3  >protestima !28_V	et	f	\N
199050	lisajõudu	lisajõudu =jõudu  (SgP  >lisa+jõud !22_S	et	f	\N
199051	lisajõudu	lisajõudu =jõudu  (SgAdt  >lisa+jõud !22_S	et	f	\N
199052	uppsala	?uppsala =uppsala  (SgN  >uppsala !01_S	et	f	\N
199053	uppsala	?uppsala =uppsala  (SgG  >uppsala !01_S	et	f	\N
199091	asendusid	asendusid =asendu  (IndIpfSg2  >asenduma !27_V	et	f	\N
199092	asendusid	asendusid =asendu  (IndIpfPl3  >asenduma !27_V	et	f	\N
199113	laotud	laotud =lao  (PtsPtIps  >laduma !28_V	et	f	\N
199114	laotud	laotud =laotu  (PlN  >laotu !01_A	et	f	\N
199115	laotud	"laotu %lao  )TU1_vS  <laduma ;28_V	et	f	\N
199116	laotud	"laotu %lao  )TU2_kA  <ladu ;18_S	et	f	\N
199117	laotud	"laotu %lao  )TU2_kA  <lagu ;18_S	et	f	\N
199118	laotud	laotud =laotu  (IndPrSg2  >laotuma !27_V	et	f	\N
199119	laotud	laotud =laotud  (ID  >laotud !41_A	et	f	\N
199120	laotud	"laotud %lao  )TUD_vA  <laduma ;28_V	et	f	\N
199131	kvaliteetsematele	kvaliteetsematele =kvaliteetsema  (PlAll  >kvaliteetsem !02_A	et	f	\N
199132	kvaliteetsematele	"kvaliteetsem %kvaliteetse  )M_cA  <kvaliteetne ;02_A	et	f	\N
199133	rundajaid	?rundajaid =rundaja  (PlP  >rundaja !01_S	et	f	\N
199134	rundajaid	?rundajaid =rundaja  (PlP  >rundajas !02_A	et	f	\N
199135	rundajaid	?rundajaid =rundajai  (PlN  >rundajai !26_S	et	f	\N
199136	rundajaid	?rundajaid =rundajai  (SgP  >rundajai !26_S	et	f	\N
199137	kõrgematesse	kõrgematesse =kõrgema  (PlIll  >kõrgem !02_A	et	f	\N
199138	kõrgematesse	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
199139	kõrgematesse	kõrgematesse =mate  (SgIll  >kõrge+mate !16_S	et	f	\N
199140	kõrgematesse	kõrgematesse =mate  (PlIll  >kõrge+matt !22_SA	et	f	\N
199141	rüüstamisi	rüüstamisi =rüüstamisi  (PlP  >rüüstamine !12_S	et	f	\N
199142	rüüstamisi	"rüüstamine %rüüsta  )MINE_vS  <rüüstama ;29_V	et	f	\N
199165	absurdiseikluskomöödia	absurdiseikluskomöödia =dia  (SgN  >absurdi+seiklus+kom+öö+dia !26_S	et	f	\N
199166	absurdiseikluskomöödia	absurdiseikluskomöödia =dia  (SgG  >absurdi+seiklus+kom+öö+dia !26_S	et	f	\N
199167	absurdiseikluskomöödia	absurdiseikluskomöödia =komöödia  (SgN  >absurdi+seiklus+komöödia !01_S	et	f	\N
199168	absurdiseikluskomöödia	absurdiseikluskomöödia =komöödia  (SgG  >absurdi+seiklus+komöödia !01_S	et	f	\N
199182	takistused	takistused =takistuse  (PlN  >takistus !11_S	et	f	\N
199183	takistused	"takistus %takista  )US_vS  <takistama ;27_V	et	f	\N
199188	suhestumine	?suhestumine =suhestumine  (SgN  >suhestumine !12_S	et	f	\N
199190	suhestumine	?suhestumine =suhestumine  (PlP  >suhestumin !19_S	et	f	\N
199192	uurid	uurid =uuri  (PlN  >uur !22_S	et	f	\N
199193	uurid	uurid =uuri  (IndPrSg2  >uurima !28_V	et	f	\N
199198	tantsitega	### tantsitega	et	f	\N
199202	ilge	ilge =ilge  (SgN  >ilge !01_A	et	f	\N
199203	ilge	ilge =ilge  (SgG  >ilge !01_A	et	f	\N
199204	ilge	ilge =ilge  (IndPrPs_  >ilgema !27_V	et	f	\N
199205	ilge	ilge =ilge  (ImpPrSg2  >ilgema !27_V	et	f	\N
199226	filmiteosest	filmiteosest =teose  (SgEl  >filmi+teos !09_S	et	f	\N
199227	filmiteosest	filmiteosest =teoses  (SgP  >filmi+teosene !10_A	et	f	\N
199228	filmiteosest	"filmi+teosene %teose  )NE_aA  <filmi+teos ;09_S	et	f	\N
199229	vähekenegi	?vähekenegi =vähekene  (SgN^  >vähekene !12_S	et	f	\N
199230	vähekenegi	?vähekenegi =vähekene  (PlP^  >väheken !19_S	et	f	\N
199268	värvikalt	värvikalt =värvika  (SgAbl  >värvikas !02_A	et	f	\N
199269	värvikalt	värvikalt =värvikalt  (ID  >värvikalt !41_D	et	f	\N
199270	värvikalt	"värvikalt %värvika  )LT_mD  <värvikas ;02_A	et	f	\N
199277	külakeses	külakeses =külakese  (SgIn  >külake !12_S	et	f	\N
199278	külakeses	"külake %küla  )KE_dS  <küla ;17_S	et	f	\N
199279	külakeses	külakeses =külakese  (SgIn  >külakene !12_S	et	f	\N
199280	külakeses	"külakene %küla  )KENE_dS  <küla ;17_S	et	f	\N
199287	muutununa	muutununa =muutunu  (SgEs  >muutunu !01_S	et	f	\N
199288	muutununa	"muutunu %muutu  )NU_vS  <muutuma ;27_V	et	f	\N
199289	tallas	tallas =talla  (SgIn  >tald !22_S	et	f	\N
199290	tallas	tallas =talla  (IndIpfSg3  >tallama !29_V	et	f	\N
199314	tõlgenduse	tõlgenduse =tõlgenduse  (SgG  >tõlgendus !11_S	et	f	\N
199315	tõlgenduse	"tõlgendus %tõlgenda  )US_vS  <tõlgendama ;27_V	et	f	\N
199320	kaotamiseni	kaotamiseni =kaotamise  (SgTer  >kaotamine !12_S	et	f	\N
199321	kaotamiseni	"kaotamine %kaota  )MINE_vS  <kaotama ;27_V	et	f	\N
199333	meelelahutulik	?meelelahutulik =meelelahutulik  (SgN  >meelelahutulik !25_A	et	f	\N
199334	meelelahutulik	?meelelahutulik =lahutulik  (SgN  >meele+lahutulik !25_A	et	f	\N
199335	meelelahutulik	?meelelahutulik =lelahutulik  (SgN  >mee+lelahutulik !25_A	et	f	\N
199347	lembitu	?lembitu =lembitu  (SgN  >lembitu !01_AS	et	f	\N
199348	lembitu	?lembitu =lembitu  (SgG  >lembitu !01_AS	et	f	\N
199062	linzendorffi	?linzendorffi =linzendorffi  (ImpPrSg2  >linzendorffima !28_V	et	f	\N
199067	kopernikuse	?kopernikuse =kopernikuse  (SgG  >kopernikus !11?09_S	et	f	\N
199080	tahtsamad	?tahtsamad =tahtsama  (PlN  >tahtsam !02_A	et	f	\N
199081	küttimisest	küttimisest =küttimise  (SgEl  >küttimine !12_S	et	f	\N
199082	küttimisest	"küttimine %kütti  )MINE_vS  <küttima ;28_V	et	f	\N
199102	asulast	asulast =asula  (SgEl  >asula !01_S	et	f	\N
199103	asulast	asulast =asulas  (SgP  >asulane !12_S	et	f	\N
199104	asulast	"asulane %asula  )NE_aA  <asula ;01_S	et	f	\N
199105	asulast	asulast =la  (SgEl  >asu+la !26_S	et	f	\N
199106	asulast	asulast =las  (SgP  >asu+laps !14_S	et	f	\N
199107	asulast	asulast =last  (SgN  >asu+last !22_S	et	f	\N
199108	kivikirstkalmeid	?kivikirstkalmeid =kivikirstkalmei  (PlN  >kivikirstkalmei !26_S	et	f	\N
199109	kivikirstkalmeid	?kivikirstkalmeid =kivikirstkalmei  (SgP  >kivikirstkalmei !26_S	et	f	\N
199110	kivikirstkalmeid	?kivikirstkalmeid =kirstkalme  (PlP  >kivi+kirstkalmi !01_S	et	f	\N
199111	kivikirstkalmeid	?kivikirstkalmeid =kirstkalmei  (PlN  >kivi+kirstkalmei !26_S	et	f	\N
199112	kivikirstkalmeid	?kivikirstkalmeid =kirstkalmei  (SgP  >kivi+kirstkalmei !26_S	et	f	\N
199121	looma-	looma- =loo  (Sup  >looma !38_V	et	f	\N
199122	looma-	looma- =looma  (SgG  >loom !22_S	et	f	\N
199123	looma-	looma- =looma  (SgP  >loom !22_S	et	f	\N
199124	looma-	looma- =looma  (SgAdt  >loom !22_S	et	f	\N
199129	kaasusaamisel	?kaasusaamisel =kaasusaamise  (SgAd  >kaasusaamine !10_A	et	f	\N
199130	kaasusaamisel	?kaasusaamisel =usaamise  (SgAd  >kaas+usaamine !10_A	et	f	\N
199143	ristimata	ristimata =risti  (SupAb  >ristima !28_V	et	f	\N
199144	ristimata	ristimata =ristimata  (ID  >ristimata !41_A	et	f	\N
199145	ristimata	"ristimata %risti  )MATA_vA  <ristima ;28_V	et	f	\N
199146	ristimata	ristimata =ima  (SgAb  >rist+ima !17_S	et	f	\N
199153	paganatest	paganatest =pagana  (PlEl  >pagan !02_S	et	f	\N
199154	paganatest	paganatest =test  (SgN  >pagana+test !22_S	et	f	\N
199157	liikmelist	liikmelist =liikmelis  (SgP  >liikmeline !12_A	et	f	\N
199158	liikmelist	"liikmeline %liikme  )LINE_aA  <liige ;05_S	et	f	\N
199169	üritavad	üritavad =ürita  (IndPrPl3  >üritama !27_V	et	f	\N
199170	üritavad	üritavad =üritava  (PlN  >üritav !02_A	et	f	\N
199171	üritavad	"üritav %ürita  )V_vA  <üritama ;27_V	et	f	\N
199179	keerisesse	keerisesse =keerise  (SgIll  >keeris !09_S	et	f	\N
199180	keerisesse	keerisesse =keerises  (SgAdt  >keerisene !12_A	et	f	\N
199181	keerisesse	"keerisene %keerise  )NE_aA  <keeris ;09_S	et	f	\N
199212	otsad	otsad =otsa  (PlN  >ots !23?22_S	et	f	\N
199213	otsad	otsad =otsa  (IndPrSg2  >otsama !29_V	et	f	\N
199224	vaadatuna	vaadatuna =vaadatu  (SgEs  >vaadatu !01_S	et	f	\N
199225	vaadatuna	"vaadatu %vaada  )TU1_vS  <vaatama ;29_V	et	f	\N
199237	püüelda	püüelda =püüel  (Inf  >püüdlema !30_V	et	f	\N
199238	püüelda	püüelda =püüel  (IndPrIps_  >püüdlema !30_V	et	f	\N
199242	ajalooteemaline	ajalooteemaline =maline  (SgN  >aja+loo+tee+maline !10_A	et	f	\N
199243	ajalooteemaline	"aja+loo+tee+maline %mali  )NE_aA  <aja+loo+tee+mali ;17_S	et	f	\N
199244	ajalooteemaline	ajalooteemaline =emaline  (SgN  >aja+loote+emaline !12_A	et	f	\N
199245	ajalooteemaline	"aja+loote+emaline %ema  )LINE_aA  <aja+loote+ema ;17_S	et	f	\N
199246	ajalooteemaline	ajalooteemaline =teemaline  (SgN  >aja+loo+teemaline !12_A	et	f	\N
199247	ajalooteemaline	"aja+loo+teemaline %teema  )LINE_aA  <aja+loo+teema ;16_S	et	f	\N
199248	näivad	näivad =näi  (IndPrPl3  >näima !37_V	et	f	\N
199249	näivad	näivad =näiva  (PlN  >näiv !02_A	et	f	\N
199250	näivad	"näiv %näi  )V_vA  <näima ;37_V	et	f	\N
199251	käsitle	käsitle =käsitle  (IndPrPs_  >käsitlema !27_V	et	f	\N
199252	käsitle	käsitle =käsitle  (ImpPrSg2  >käsitlema !27_V	et	f	\N
199259	tõlgendus	tõlgendus =tõlgendus  (SgN  >tõlgendus !11_S	et	f	\N
199260	tõlgendus	"tõlgendus %tõlgenda  )US_vS  <tõlgendama ;27_V	et	f	\N
199261	rezissööriks	?rezissööriks =rezissööri  (SgTr  >rezissööri !16_S	et	f	\N
199262	rezissööriks	?rezissööriks =rezissööri  (SgTr  >rezissöör !22_S	et	f	\N
199263	rezissööriks	?rezissööriks =rezissööri  (KndPrPs  >rezissöörima !28_V	et	f	\N
199264	lavastatust	lavastatust =lavastatu  (SgEl  >lavastatu !01_S	et	f	\N
199265	lavastatust	"lavastatu %lavasta  )TU1_vS  <lavastama ;27_V	et	f	\N
199266	lavastatust	lavastatust =lavastatus  (SgP  >lavastatus !11?09_S	et	f	\N
199267	lavastatust	"lavastatus %lavasta  )TUS1_aS  <lavastama ;27_V	et	f	\N
199273	ähvardaval	ähvardaval =ähvardava  (SgAd  >ähvardav !02_A	et	f	\N
199274	ähvardaval	"ähvardav %ähvarda  )V_vA  <ähvardama ;27_V	et	f	\N
199303	tarka	tarka =tarka  (SgP  >tark !22_AS	et	f	\N
199304	tarka	tarka =tarka  (SgAdt  >tark !22_AS	et	f	\N
199324	sissesööbinud	sissesööbinud =sööbi  (PtsPtPs  >sisse+_sööbima !27_V	et	f	\N
199325	sissesööbinud	sissesööbinud =sööbinu  (PlN  >sisse+sööbinu !01_S	et	f	\N
199354	kuklasse	kuklasse =kukla  (SgIll  >kukal !08_S	et	f	\N
199355	kuklasse	kuklasse =kuklas  (SgAdt  >kuklane !12_S	et	f	\N
199356	kuklasse	"kuklane %kukla  )NE_aA  <kukal ;08_S	et	f	\N
199361	veste	veste =veste  (SgN  >veste !06_S	et	f	\N
199362	veste	veste =veste  (SgG  >veste !06_S	et	f	\N
199363	veste	veste =veste  (PlP  >vest !22_S	et	f	\N
199199	uro	?uro =uro  (SgN  >uro !17~16_S	et	f	\N
199200	uro	?uro =uro  (SgG  >uro !17~16_S	et	f	\N
199201	uro	?uro =uro  (SgP  >uro !17_S	et	f	\N
199206	ehe	ehe =ehe  (SgN  >ehe !02_A	et	f	\N
199207	ehe	ehe =ehe  (SgN  >ehe !05_S	et	f	\N
199208	ehe	ehe =ehe  (SgN  >ehe !06_S	et	f	\N
199221	muinaseestlastest	muinaseestlastest =las  (PlEl  >muinas+eest+laps !14_S	et	f	\N
199222	muinaseestlastest	muinaseestlastest =laste  (PlEl  >muinas+eest+last !22_S	et	f	\N
199223	muinaseestlastest	muinaseestlastest =eestlas  (PlEl  >muinas+eestlane !12?10_S	et	f	\N
199231	ajalooteemaliste	ajalooteemaliste =malis  (PlG  >aja+loo+tee+maline !10_A	et	f	\N
199232	ajalooteemaliste	"aja+loo+tee+maline %mali  )NE_aA  <aja+loo+tee+mali ;17_S	et	f	\N
199233	ajalooteemaliste	ajalooteemaliste =emalis  (PlG  >aja+loote+emaline !12_A	et	f	\N
199234	ajalooteemaliste	"aja+loote+emaline %ema  )LINE_aA  <aja+loote+ema ;17_S	et	f	\N
199235	ajalooteemaliste	ajalooteemaliste =teemalis  (PlG  >aja+loo+teemaline !12_A	et	f	\N
199236	ajalooteemaliste	"aja+loo+teemaline %teema  )LINE_aA  <aja+loo+teema ;16_S	et	f	\N
199239	tõepära	tõepära =pära  (SgN  >tõe+pära !17_S	et	f	\N
199240	tõepära	tõepära =pära  (SgG  >tõe+pära !17_S	et	f	\N
199241	tõepära	tõepära =pära  (SgP  >tõe+pära !17_S	et	f	\N
199253	stampseisukohti	stampseisukohti =kohti  (SgP  >stamp+seisu+koht !22_S	et	f	\N
199254	stampseisukohti	stampseisukohti =kohti  (SgAdt  >stamp+seisu+koht !22_S	et	f	\N
199255	stampseisukohti	stampseisukohti =kohti  (PlP  >stamp+seisu+koht !22_S	et	f	\N
199271	verehimulised	verehimulised =himulise  (PlN  >vere+himuline !12_A	et	f	\N
199272	verehimulised	"vere+himuline %himu  )LINE_aA  <vere+himu ;17_S	et	f	\N
199283	vangistusest	vangistusest =vangistuse  (SgEl  >vangistus !11_S	et	f	\N
199284	vangistusest	"vangistus %vangista  )US_vS  <vangistama ;27_V	et	f	\N
199285	vangistusest	vangistusest =vangistuses  (SgP  >vangistusene !12_A	et	f	\N
199286	vangistusest	"vangistusene %vangistuse  )NE_aA  <vangistus ;11_S	et	f	\N
199291	rukililli	?rukililli =rukililli  (SgG  >rukilill !22_S	et	f	\N
199292	rukililli	?rukililli =rukililli  (SgP  >rukilill !22_S	et	f	\N
199293	rukililli	?rukililli =rukililli  (SgAdt  >rukilill !22_S	et	f	\N
199294	rukililli	?rukililli =rukililli  (IndPrPs_  >rukilillima !28_V	et	f	\N
199295	rukililli	?rukililli =rukililli  (ImpPrSg2  >rukilillima !28_V	et	f	\N
199301	maakonnavanemad	maakonnavanemad =vanema  (PlN  >maa+konna+vanem !02_AS	et	f	\N
199302	maakonnavanemad	"maa+konna+vanem %vane  )M_cA  <maa+konna+vana ;17_AS	et	f	\N
199316	psühholoogilistest	psühholoogilistest =psühholoogilis  (PlEl  >psühholoogiline !12_A	et	f	\N
199317	psühholoogilistest	"psühholoogiline %psühholoogi  )LINE_aA  <psühholoog ;22_S	et	f	\N
199318	psühholoogilistest	psühholoogilistest =loogilis  (PlEl  >psühho+loogiline !12_A	et	f	\N
199319	psühholoogilistest	"psühho+loogiline %loogi  )LINE_aA  <psühho+loog ;22_S	et	f	\N
199322	kollektiivsesse	kollektiivsesse =kollektiivse  (SgIll  >kollektiivne !02_A	et	f	\N
199323	kollektiivsesse	kollektiivsesse =sesse  (PlP  >kollektiiv+sess !22_S	et	f	\N
199329	uhkeks	uhkeks =uhke  (SgTr  >uhke !01_A	et	f	\N
199330	uhkeks	uhkeks =uhke  (SgTr  >uhe !06_S	et	f	\N
199338	röövretke	röövretke =retke  (SgG  >rööv+retk !22_S	et	f	\N
199339	röövretke	röövretke =retke  (SgP  >rööv+retk !22_S	et	f	\N
199340	röövretke	röövretke =retke  (SgAdt  >rööv+retk !22_S	et	f	\N
199341	röövretke	röövretke =retke  (PlP  >rööv+retk !22_S	et	f	\N
199344	vallutaja	vallutaja =vallutaja  (SgN  >vallutaja !01_S	et	f	\N
199345	vallutaja	"vallutaja %valluta  )JA_vS  <vallutama ;27_V	et	f	\N
199346	vallutaja	vallutaja =vallutaja  (SgG  >vallutaja !01_S	et	f	\N
199357	alistamist	alistamist =alistamis  (SgP  >alistamine !12_S	et	f	\N
199358	alistamist	"alistamine %alista  )MINE_vS  <alistama ;27_V	et	f	\N
199369	ristitud	ristitud =risti  (PtsPtIps  >ristima !28_V	et	f	\N
199370	ristitud	ristitud =ristitu  (PlN  >ristitu !01_AS	et	f	\N
199371	ristitud	"ristitu %risti  )TU1_vS  <ristima ;28_V	et	f	\N
199372	ristitud	"ristitu %risti  )TU2_kA  <risti ;16_S	et	f	\N
199373	ristitud	"ristitu %risti  )TU2_kA  <rist ;22_S	et	f	\N
199374	ristitud	ristitud =ristitud  (ID  >ristitud !41_A	et	f	\N
199375	ristitud	"ristitud %risti  )TUD_vA  <ristima ;28_V	et	f	\N
199378	tabavaid	tabavaid =tabava  (PlP  >tabav !02_A	et	f	\N
199379	tabavaid	"tabav %taba  )V_vA  <tabama ;27_V	et	f	\N
199429	pilgul	pilgul =pilgu  (SgAd  >pilk !22_S	et	f	\N
199430	pilgul	pilgul =pilgu  (PlAd  >pilk !22_S	et	f	\N
199438	absurdkomöödia	?absurdkomöödia =absurdkomöödia  (SgN  >absurdkomöödia !01_S	et	f	\N
199439	absurdkomöödia	?absurdkomöödia =absurdkomöödia  (SgG  >absurdkomöödia !01_S	et	f	\N
199442	juskui	?juskui =juskui  (SgN  >juskui !26_S	et	f	\N
199443	juskui	?juskui =juskui  (SgG  >juskui !26_S	et	f	\N
199478	kestev	kestev =kest  (PtsPrPs  >kestma !34_V	et	f	\N
199480	kestev	kestev =kestev  (SgN  >kestev !02_A	et	f	\N
199482	kestev	"kestev %kest  )V_vA  <kestma ;34_V	et	f	\N
199514	sealgi	sealgi =sea  (SgAd^  >siga !18_SA	et	f	\N
199515	sealgi	sealgi =seal  (ID^  >seal !41_D	et	f	\N
199519	hööveldamisest	hööveldamisest =hööveldamise  (SgEl  >hööveldamine !12_S	et	f	\N
199520	hööveldamisest	"hööveldamine %höövelda  )MINE_vS  <hööveldama ;27_V	et	f	\N
199349	lembitu	?lembitu =lembitu  (IndPrPs_  >lembituma !27_V	et	f	\N
199350	lembitu	?lembitu =lembitu  (ImpPrSg2  >lembituma !27_V	et	f	\N
199351	karata	karata =kara  (SgAb  >kara !17_S	et	f	\N
199352	karata	karata =kara  (Inf  >kargama !29_V	et	f	\N
199353	karata	karata =kara  (IndPrIps_  >kargama !29_V	et	f	\N
199366	sõrmekooku	sõrmekooku =kooku  (SgP  >sõrme+kook !22_S	et	f	\N
199367	sõrmekooku	sõrmekooku =kooku  (SgAdt  >sõrme+kook !22_S	et	f	\N
199412	rahvaluuleks	rahvaluuleks =luule  (SgTr  >rahva+luule !06_S	et	f	\N
199413	rahvaluuleks	rahvaluuleks =luule  (PlTr  >rahva+luul !22_S	et	f	\N
199419	jurmala	?jurmala =jurmala  (SgN  >jurmala !01_S	et	f	\N
199420	jurmala	?jurmala =jurmala  (SgG  >jurmala !01_S	et	f	\N
199422	raevu	raevu =raevu  (SgG  >raev !22_S	et	f	\N
199423	raevu	raevu =raevu  (SgP  >raev !22_S	et	f	\N
199424	raevu	raevu =raevu  (SgAdt  >raev !22_S	et	f	\N
199425	raevu	raevu =raevu  (IndPrPs_  >raevuma !27_V	et	f	\N
199426	raevu	raevu =raevu  (ImpPrSg2  >raevuma !27_V	et	f	\N
199433	huvitatavamaks	huvitatavamaks =huvitatavama  (SgTr  >huvitatavam !02_A	et	f	\N
199434	huvitatavamaks	"huvitatavam %huvita  )TAVAM_cA  <huvitama ;27_V	et	f	\N
199453	naeratust	naeratust =naeratus  (SgP  >naeratus !11_S	et	f	\N
199454	naeratust	"naeratus %naerata  )US_vS  <naeratama ;27_V	et	f	\N
199458	mõstavad	mõstavad =mõstava  (PlN  >mõstav !02_A	et	f	\N
199459	mõstavad	"mõstav %mõs  )TAV_vAS  <mõskma ;34_V	et	f	\N
199491	õhutusel	õhutusel =õhutuse  (SgAd  >õhutus !11_S	et	f	\N
199492	õhutusel	"õhutus %õhuta  )US_vS  <õhutama ;27_V	et	f	\N
199493	õhutusel	"õhutus %õhu  )TUS2_aS  <õhk ;22_S	et	f	\N
199516	tõetera	tõetera =tera  (SgN  >tõe+tera !17_S	et	f	\N
199517	tõetera	tõetera =tera  (SgG  >tõe+tera !17_S	et	f	\N
199518	tõetera	tõetera =tera  (SgP  >tõe+tera !17_S	et	f	\N
199523	lembituid	?lembituid =lembitu  (PlP  >lembitu !01_AS	et	f	\N
199524	lembituid	?lembituid =lembitui  (PlN  >lembitui !26_S	et	f	\N
199525	lembituid	?lembituid =lembitui  (SgP  >lembitui !26_S	et	f	\N
199529	kobin	kobin =kobi  (IndPrSg1  >kobima !27_V	et	f	\N
199530	kobin	kobin =kobin  (SgN  >kobin !02_S	et	f	\N
199546	detailsetele	detailsetele =detailse  (PlAll  >detailne !02_A	et	f	\N
199547	detailsetele	detailsetele =sete  (PlAll  >detail+sett !22_S	et	f	\N
199587	õpetustele	õpetustele =õpetus  (PlAll  >õpetus !11_S	et	f	\N
199588	õpetustele	"õpetus %õpeta  )US_vS  <õpetama ;27_V	et	f	\N
199626	djek	### djek	et	f	\N
199627	missuri	?missuri =missuri  (SgN  >missuri !01_S	et	f	\N
199628	missuri	?missuri =missuri  (SgG  >missuri !01_S	et	f	\N
199631	missuri	?missuri =missuri  (SgG  >missur !02_S	et	f	\N
199632	missuri	?missuri =suri  (SgN  >mis+suri !17_S	et	f	\N
199634	missuri	?missuri =suri  (SgG  >mis+suri !17_S	et	f	\N
199636	missuri	?missuri =suri  (SgP  >mis+suri !17_S	et	f	\N
199642	avastuselehakkas	?avastuselehakkas =avastuselehakka  (SgIn  >avastuselehakka !16_S	et	f	\N
199643	avastuselehakkas	?avastuselehakkas =stuselehakka  (SgIn  >ava+stuselehakka !16_S	et	f	\N
199654	töötlevad	töötlevad =töötle  (IndPrPl3  >töötlema !30_V	et	f	\N
199655	töötlevad	töötlevad =töötleva  (PlN  >töötlev !02_A	et	f	\N
199656	töötlevad	"töötlev %töötle  )V_vA  <töötlema ;30_V	et	f	\N
199665	meditsiinilise	meditsiinilise =meditsiinilise  (SgG  >meditsiiniline !12_A	et	f	\N
199666	meditsiinilise	"meditsiiniline %meditsiini  )LINE_aA  <meditsiin ;22_S	et	f	\N
199677	mikroskeemi	mikroskeemi =skeemi  (SgG  >mikro+skeem !22_S	et	f	\N
199678	mikroskeemi	mikroskeemi =skeemi  (SgP  >mikro+skeem !22_S	et	f	\N
199679	mikroskeemi	mikroskeemi =skeemi  (SgAdt  >mikro+skeem !22_S	et	f	\N
199696	laadu	laadu =laadu  (IndPrPs_  >laaduma !27_V	et	f	\N
199697	laadu	laadu =laadu  (ImpPrSg2  >laaduma !27_V	et	f	\N
199720	pust	?pust =pust  (SgN  >pust !22_S	et	f	\N
199730	parketti	parketti =parketti  (SgP  >parkett !22_S	et	f	\N
199731	parketti	parketti =parketti  (SgAdt  >parkett !22_S	et	f	\N
199735	plaatiga	### plaatiga	et	f	\N
199737	köögiplitt	?köögiplitt =köögiplitt  (SgN  >köögiplitt !22_S	et	f	\N
199738	köögiplitt	?köögiplitt =plitt  (SgN  >köögi+plitt !22_S	et	f	\N
199741	piljardilaud	piljardilaud =lau  (PlN  >piljardi+laug !22_SA	et	f	\N
199742	piljardilaud	piljardilaud =laud  (SgN  >piljardi+laud !22_S	et	f	\N
199819	valgustajaga	valgustajaga =valgustaja  (SgKom  >valgustaja !01_S	et	f	\N
199820	valgustajaga	"valgustaja %valgusta  )JA_vS  <valgustama ;27_V	et	f	\N
199821	valgustajaga	valgustajaga =aja  (SgKom  >valgust+aeg !22_S	et	f	\N
199823	sälitada	?sälitada =sälita  (Inf  >sälitama !27_V	et	f	\N
199834	soojustamisega	soojustamisega =soojustamise  (SgKom  >soojustamine !12_S	et	f	\N
199835	soojustamisega	"soojustamine %soojusta  )MINE_vS  <soojustama ;27_V	et	f	\N
199846	piljardisaali	piljardisaali =saali  (SgG  >piljardi+saal !22_S	et	f	\N
199847	piljardisaali	piljardisaali =saali  (SgP  >piljardi+saal !22_S	et	f	\N
199848	piljardisaali	piljardisaali =saali  (SgAdt  >piljardi+saal !22_S	et	f	\N
199851	plaadimistoid	plaadimistoid =toi  (PlN  >plaadi+mis+toi !26_S	et	f	\N
199852	plaadimistoid	plaadimistoid =toi  (SgP  >plaadi+mis+toi !26_S	et	f	\N
199857	soem	?soem =soem  (SgN  >soem !22_S	et	f	\N
199380	ajakohaseid	ajakohaseid =kohase  (PlP  >aja+kohane !10_A	et	f	\N
199381	ajakohaseid	"aja+kohane %koha  )NE_aA  <aja+koha ;17_S	et	f	\N
199382	ajakohaseid	"aja+kohane %koha  )NE_aA  <aja+koht ;22_S	et	f	\N
199386	muutmatu	muutmatu =muutmatu  (SgN  >muutmatu !01_A	et	f	\N
199387	muutmatu	"muutmatu %muut  )MATU_vA  <muutma ;34_V	et	f	\N
199388	muutmatu	muutmatu =muutmatu  (SgG  >muutmatu !01_A	et	f	\N
199389	kannatust	kannatust =kannatu  (SgEl  >kannatu !01_AS	et	f	\N
199390	kannatust	"kannatu %kanna  )TU2_kA  <kanna ;16_S	et	f	\N
199391	kannatust	"kannatu %kanna  )TU2_kA  <kand ;22_S	et	f	\N
199392	kannatust	kannatust =kannatus  (SgP  >kannatus !11_S	et	f	\N
199393	kannatust	"kannatus %kannata  )US_vS  <kannatama ;27_V	et	f	\N
199394	kannatust	"kannatus %kanna  )TUS2_aS  <kanna ;16_S	et	f	\N
199395	kannatust	"kannatus %kanna  )TUS2_aS  <kand ;22_S	et	f	\N
199396	kannatust	kannatust =tust  (SgN  >kanna+tust !22_S	et	f	\N
199397	veenas	?veenas =veena  (SgIn  >veena !16_S	et	f	\N
199398	veenas	?veenas =veena  (IndIpfSg3  >veenama !29_V	et	f	\N
199399	veenas	?veenas =veenas  (SgN  >veenas !07_S	et	f	\N
199417	rahvussümbole	?rahvussümbole =rahvussümbo  (SgAll  >rahvussümbo !16_S	et	f	\N
199418	rahvussümbole	?rahvussümbole =sümbo  (SgAll  >rahvus+sümbo !16_S	et	f	\N
199431	humorimeelsus	?humorimeelsus =humorimeelsu  (IndIpfSg3  >humorimeelsuma !27_V	et	f	\N
199432	humorimeelsus	?humorimeelsus =humorimeelsus  (SgN  >humorimeelsus !11~09_S	et	f	\N
199450	humoorikalt	humoorikalt =humoorika  (SgAbl  >humoorikas !02_A	et	f	\N
199451	humoorikalt	humoorikalt =humoorikalt  (ID  >humoorikalt !41_D	et	f	\N
199452	humoorikalt	"humoorikalt %humoorika  )LT_mD  <humoorikas ;02_A	et	f	\N
199467	tänapäevaste	tänapäevaste =aste  (SgN  >täna+päev+aste !05_S	et	f	\N
199468	tänapäevaste	tänapäevaste =aste  (SgN  >täna+päev+aste !06_S	et	f	\N
199469	tänapäevaste	tänapäevaste =aste  (SgG  >täna+päev+aste !06_S	et	f	\N
199470	tänapäevaste	tänapäevaste =aste  (PlP  >täna+päev+ast !22_S	et	f	\N
199471	tänapäevaste	tänapäevaste =päevas  (PlG  >täna+päevane !10_A	et	f	\N
199472	tänapäevaste	"täna+päevane %päeva  )NE_aA  <täna+päev ;22_S	et	f	\N
199494	lembituga	?lembituga =lembitu  (SgKom  >lembitu !01_AS	et	f	\N
199495	varitsevast	varitsevast =varitseva  (SgEl  >varitsev !02_A	et	f	\N
199496	varitsevast	"varitsev %varitse  )V_vA  <varitsema ;27_V	et	f	\N
199497	tõsisema	tõsisema =tõsisema  (SgG  >tõsisem !02_A	et	f	\N
199498	tõsisema	"tõsisem %tõsise  )M_cA  <tõsine ;10_A	et	f	\N
199502	kärajad	kärajad =käraja  (PlN  >käraja !01_S	et	f	\N
199503	kärajad	"käraja %kära  )JA_vS  <kärama ;27_V	et	f	\N
199550	fantaasiarikka	?fantaasiarikka =fantaasiarikka  (SgN  >fantaasiarikka !16_S	et	f	\N
199551	fantaasiarikka	?fantaasiarikka =fantaasiarikka  (SgG  >fantaasiarikka !16_S	et	f	\N
199552	fantaasiarikka	?fantaasiarikka =rikka  (SgG  >fantaasia+rikas !07_A	et	f	\N
199559	ajalooliseks	ajalooliseks =loolise  (SgTr  >aja+looline !12?10_A	et	f	\N
199560	ajalooliseks	"aja+looline %loo  )LINE_aA  <aja+lugu ;18_S	et	f	\N
199561	ajalooliseks	"aja+looline %loo  )LINE_aA  <aja+loog ;22_S	et	f	\N
199562	ajalooliseks	"aja+looline %loo  )LINE_aA  <aja+lood ;22_S	et	f	\N
199563	ajalooliseks	ajalooliseks =loolise  (SgTr  >aja+looline !12?10_S	et	f	\N
199569	tegelikus	tegelikus =tegeliku  (SgIn  >tegelik !25_A	et	f	\N
199570	tegelikus	tegelikus =tegelikus  (SgN  >tegelikus !11?09_S	et	f	\N
199571	tegelikus	"tegelikus %tegeliku  )US_aS  <tegelik ;25_A	et	f	\N
199572	eestipäraseid	eestipäraseid =pärase  (PlP  >eesti+pärane !10_A	et	f	\N
199573	eestipäraseid	"eesti+pärane %pära  )NE_aA  <eesti+pära ;17_S	et	f	\N
199580	sõdimiseks	sõdimiseks =sõdimise  (SgTr  >sõdimine !12_S	et	f	\N
199581	sõdimiseks	"sõdimine %sõdi  )MINE_vS  <sõdima ;27_V	et	f	\N
199582	sõjahobused	sõjahobused =hobuse  (PlN  >sõja+hobune !10_S	et	f	\N
199583	sõjahobused	"sõja+hobune %hobu  )NE_aA  <sõja+hobu ;17_S	et	f	\N
199616	temperaturiga	?temperaturiga =temperaturi  (SgKom  >temperatur !19_S	et	f	\N
199617	toituainedel	?toituainedel =toituaine  (PlAd  >toituaine !16_S	et	f	\N
199621	kehtivuse	kehtivuse =kehtivuse  (SgG  >kehtivus !11_S	et	f	\N
199622	kehtivuse	"kehtivus %kehti  )VUS_aS  <kehtima ;27_V	et	f	\N
199623	kehtivuse	"kehtivus %kehtiva  )US_aS  <kehtiv ;02_A	et	f	\N
199638	texase	?texase =texase  (SgG  >texane !10_A	et	f	\N
199639	integraalskeemid	?integraalskeemid =integraalskeemi  (PlN  >integraalskeemi !16_S	et	f	\N
199640	integraalskeemid	?integraalskeemid =integraalskeemi  (PlN  >integraalskeem !22_S	et	f	\N
199641	integraalskeemid	?integraalskeemid =integraalskeemi  (IndPrSg2  >integraalskeemima !28_V	et	f	\N
199659	pesumasinadest	?pesumasinadest =pesumasina  (PlEl  >pesumasin !19_S	et	f	\N
199660	pesumasinadest	?pesumasinadest =pesumasinades  (SgP  >pesumasinadene !12_A	et	f	\N
199661	pesumasinadest	?pesumasinadest =ade  (SgEl  >pesu+masin+ade !16_S	et	f	\N
199662	pesumasinadest	?pesumasinadest =ades  (SgP  >pesu+masin+ades !09_S	et	f	\N
199663	pesumasinadest	?pesumasinadest =ades  (SgP  >pesu+masin+adene !10_A	et	f	\N
199664	pesumasinadest	?pesumasinadest =masinades  (SgP  >pesu+masinadene !12_A	et	f	\N
199675	arvutitomograafia	arvutitomograafia =tomograafia  (SgN  >arvuti+tomograafia !01_S	et	f	\N
199676	arvutitomograafia	arvutitomograafia =tomograafia  (SgG  >arvuti+tomograafia !01_S	et	f	\N
199400	käides	?käides =käide  (PlIn  >käit !22_S	et	f	\N
199401	käides	?käides =käide  (IndIpfSg3  >käidema !27_V	et	f	\N
199402	käides	?käides =käides  (SgN  >käides !09_S	et	f	\N
199405	alust	alust =alu  (SgEl  >alg !22_S	et	f	\N
199406	alust	alust =alu  (PlEl  >ala !17_S	et	f	\N
199407	alust	alust =alus  (SgP  >alus !09_S	et	f	\N
199408	alust	alust =alus  (SgP  >alune !10_AS	et	f	\N
199409	alust	"alune %alu  )NE_aA  <alg ;22_S	et	f	\N
199410	suuliste	suuliste =suulis  (PlG  >suuline !12?10_AS	et	f	\N
199411	suuliste	"suuline %suu  )LINE_aA  <suu ;26_S	et	f	\N
199414	millekski	millekski =mille  (SgTr  >miski !00_P	et	f	\N
199415	millekski	millekski =mille  (SgTr^  >mis !00_P	et	f	\N
199416	millekski	millekski =milleks  (ID^  >milleks !41_D	et	f	\N
199421	hippolyt	### hippolyt	et	f	\N
199427	loal	loal =loa  (SgAd  >luba !18_S	et	f	\N
199428	loal	loal =loa  (SgAd  >luga !18_S	et	f	\N
199435	naljateta	?naljateta =nalja  (PlAb  >naljas !02_A	et	f	\N
199436	naljateta	?naljateta =naljateta  (IndPrPs_  >naljatetama !27_V	et	f	\N
199437	naljateta	?naljateta =naljateta  (ImpPrSg2  >naljatetama !27_V	et	f	\N
199444	detailsem	detailsem =detailsem  (SgN  >detailsem !02_A	et	f	\N
199445	detailsem	"detailsem %detailse  )M_cA  <detailne ;02_A	et	f	\N
199455	enamusel	enamusel =enamuse  (SgAd  >enamus !11_S	et	f	\N
199456	enamusel	"enamus %enama  )US_aS  <enam ;02_A	et	f	\N
199457	enamusel	enamusel =use  (PlAd  >enam+usk !22_S	et	f	\N
199460	soovitaks	soovitaks =soovi  (KndPrIps  >soovima !28_V	et	f	\N
199461	soovitaks	soovitaks =soovita  (KndPrPs  >soovitama !27_V	et	f	\N
199462	soovitaks	soovitaks =taks  (SgN  >soovi+taks !22_S	et	f	\N
199463	mõttemaailmast	mõttemaailmast =ast  (SgN  >mõtte+maa+ilm+ast !22_S	et	f	\N
199464	mõttemaailmast	mõttemaailmast =ilma  (SgEl  >mõtte+maa+ilm !22_S	et	f	\N
199465	mõttemaailmast	mõttemaailmast =ilmas  (SgP  >mõtte+maa+ilmane !10_A	et	f	\N
199466	mõttemaailmast	"mõtte+maa+ilmane %ilma  )NE_aA  <mõtte+maa+ilm ;22_S	et	f	\N
199473	eestimaine	eestimaine =maine  (SgN  >eesti+maine !06_S	et	f	\N
199474	eestimaine	"eesti+maine %mai  )NE_aA  <eesti+maa ;26_S	et	f	\N
199475	eestimaine	eestimaine =maine  (SgN  >eesti+maine !10_A	et	f	\N
199476	eestimaine	eestimaine =maine  (SgG  >eesti+maine !06_S	et	f	\N
199485	templiordu	templiordu =ordu  (SgN  >templi+ordu !16_S	et	f	\N
199486	templiordu	templiordu =ordu  (SgG  >templi+ordu !16_S	et	f	\N
199487	piltilus	piltilus =ilu  (SgIn  >pilt+ilu !17_S	et	f	\N
199488	piltilus	piltilus =ilus  (SgN  >pilt+ilus !02_A	et	f	\N
199489	harimisele	harimisele =harimise  (SgAll  >harimine !12_S	et	f	\N
199490	harimisele	"harimine %hari  )MINE_vS  <harima ;27_V	et	f	\N
199506	sellegi	sellegi =selle  (SgG^  >see !00_P	et	f	\N
199507	sellegi	sellegi =selle  (PlP^  >sell !22_S	et	f	\N
199508	näme	?näme =näme  (SgN  >näme !16_S	et	f	\N
199509	näme	?näme =näme  (SgG  >näme !16_S	et	f	\N
199510	näme	?näme =näme  (IndPrPs_  >nämema !27_V	et	f	\N
199511	näme	?näme =näme  (ImpPrSg2  >nämema !27_V	et	f	\N
199512	kohtlastena	kohtlastena =kohtlas  (PlEs  >kohtlane !12?10_A	et	f	\N
199513	kohtlastena	kohtlastena =las  (PlEs  >koht+laps !14_S	et	f	\N
199526	teadvaid	teadvaid =teadva  (PlP  >teadev !02_A	et	f	\N
199527	teadvaid	"teadev %tead  )V_vA  <teadma ;34_V	et	f	\N
199534	rügavaid	rügavaid =rügava  (PlP  >rügav !02_A	et	f	\N
199535	rügavaid	"rügav %rüga  )V_vA  <rügama ;27_V	et	f	\N
199548	toetuva	toetuva =toetuva  (SgG  >toetuv !02_A	et	f	\N
199549	toetuva	"toetuv %toetu  )V_vA  <toetuma ;27_V	et	f	\N
199557	filmielamus	filmielamus =elamu  (SgIn  >filmi+elamu !01_S	et	f	\N
199558	filmielamus	filmielamus =elamus  (SgN  >filmi+elamus !11_S	et	f	\N
199574	igapäevaste	igapäevaste =aste  (SgN  >iga+päev+aste !05_S	et	f	\N
199575	igapäevaste	igapäevaste =aste  (SgN  >iga+päev+aste !06_S	et	f	\N
199576	igapäevaste	igapäevaste =aste  (SgG  >iga+päev+aste !06_S	et	f	\N
199577	igapäevaste	igapäevaste =aste  (PlP  >iga+päev+ast !22_S	et	f	\N
199578	igapäevaste	igapäevaste =päevas  (PlG  >iga+päevane !10_A	et	f	\N
199579	igapäevaste	"iga+päevane %päeva  )NE_aA  <iga+päev ;22_S	et	f	\N
199584	murest	murest =mure  (SgEl  >mure !16_S	et	f	\N
199585	murest	murest =mures  (SgP  >murene !10_A	et	f	\N
199586	murest	"murene %mure  )NE_aA  <mure ;16_S	et	f	\N
199589	lüüasaamist	lüüasaamist =saami  (SgEl  >lüüa+saam !22_S	et	f	\N
199590	lüüasaamist	lüüasaamist =saamis  (SgP  >lüüa+saamine !12?10_S	et	f	\N
199591	lüüasaamist	"lüüa+saamine %saami  )NE_aA  <lüüa+saam ;22_S	et	f	\N
199598	kaalepi	?kaalepi =kaalepi  (SgN  >kaalepi !01_S	et	f	\N
199599	kaalepi	?kaalepi =kaalepi  (SgG  >kaalepi !01_S	et	f	\N
199600	kaalepi	?kaalepi =kaalepi  (SgG  >kaalep !02_S	et	f	\N
199601	kaalepi	?kaalepi =kaalepi  (SgG  >kaalepp !22_S	et	f	\N
199602	kaalepi	?kaalepi =kaalepi  (IndPrPs_  >kaaleppima !28_V	et	f	\N
199603	kaalepi	?kaalepi =kaalepi  (ImpPrSg2  >kaaleppima !28_V	et	f	\N
199609	vajalikult	vajalikult =vajaliku  (SgAbl  >vajalik !25_A	et	f	\N
199610	vajalikult	vajalikult =vajalikult  (ID  >vajalikult !41_D	et	f	\N
199611	vajalikult	"vajalikult %vajaliku  )LT_mD  <vajalik ;25_A	et	f	\N
199441	sajaldil	?sajaldil =sajaldi  (SgAd  >sajald !02_S	et	f	\N
199446	vabadusvõistlusest	vabadusvõistlusest =võistluse  (SgEl  >vabadus+võistlus !11~09_S	et	f	\N
199447	vabadusvõistlusest	vabadusvõistlusest =võistluses  (SgP  >vabadus+võistlusene !12_A	et	f	\N
199448	vabadusvõistlusest	"vabadus+võistlusene %võistluse  )NE_aA  <vabadus+võistlus ;09_S	et	f	\N
199449	vabadusvõistlusest	"vabadus+võistlusene %võistluse  )NE_aA  <vabadus+võistlus ;11_S	et	f	\N
199477	tervelt	tervelt =terve  (SgAbl  >terve !01_AS	et	f	\N
199479	tervelt	tervelt =terve  (SgAbl  >terve !06_AS	et	f	\N
199481	tervelt	tervelt =tervelt  (ID  >tervelt !41_D	et	f	\N
199483	tervelt	"tervelt %terve  )LT_mD  <terve ;01_AS	et	f	\N
199484	tervelt	"tervelt %terve  )LT_mD  <terve ;06_AS	et	f	\N
199499	peata	peata =pea  (SgAb  >pea !26_S	et	f	\N
199500	peata	peata =peata  (IndPrPs_  >peatama !27_V	et	f	\N
199501	peata	peata =peata  (ImpPrSg2  >peatama !27_V	et	f	\N
199504	suudeta	suudeta =suu  (PlAb  >suu !26_S	et	f	\N
199505	suudeta	suudeta =suude  (IndPrIps_  >suutma !34_V	et	f	\N
199521	huvituvaid	huvituvaid =huvituva  (PlP  >huvituv !02_A	et	f	\N
199522	huvituvaid	"huvituv %huvitu  )V_vA  <huvituma ;27_V	et	f	\N
199531	tuimalt	tuimalt =tuima  (SgAbl  >tuim !22_A	et	f	\N
199532	tuimalt	tuimalt =tuimalt  (ID  >tuimalt !41_D	et	f	\N
199533	tuimalt	"tuimalt %tuima  )LT_mD  <tuim ;22_A	et	f	\N
199536	tugiseid	?tugiseid =tugise  (PlP  >tugis !09_S	et	f	\N
199537	tugiseid	?tugiseid =tugisei  (PlN  >tugisei !26_S	et	f	\N
199538	tugiseid	?tugiseid =tugisei  (SgP  >tugisei !26_S	et	f	\N
199539	tugiseid	?tugiseid =sei  (PlN  >tugi+sei !26_S	et	f	\N
199540	tugiseid	?tugiseid =sei  (SgP  >tugi+sei !26_S	et	f	\N
199541	tugiseid	?tugiseid =seid  (SgN  >tugi+seid !22_S	et	f	\N
199544	veidike	veidike =veidike  (ID  >veidike !41_D	et	f	\N
199545	veidike	veidike =veidike  (SgN  >veidike !12_S	et	f	\N
199553	komöödiaga	komöödiaga =komöödia  (SgKom  >komöödia !01_S	et	f	\N
199554	komöödiaga	komöödiaga =dia  (SgKom  >kom+öö+dia !26_S	et	f	\N
199555	huumorimeelt	huumorimeelt =mee  (SgAbl  >huumori+mesi !15_S	et	f	\N
199556	huumorimeelt	huumorimeelt =meel  (SgP  >huumori+meel !13_S	et	f	\N
199564	kavalusega	kavalusega =kavaluse  (SgKom  >kavalus !11_S	et	f	\N
199565	kavalusega	"kavalus %kavala  )US_aS  <kaval ;02_A	et	f	\N
199566	euroopalikult	euroopalikult =euroopaliku  (SgAbl  >euroopalik !25_A	et	f	\N
199567	euroopalikult	euroopalikult =euroopalikult  (ID  >euroopalikult !41_D	et	f	\N
199568	euroopalikult	"euroopalikult %euroopaliku  )LT_mD  <euroopalik ;25_A	et	f	\N
199637	citys	### citys	et	f	\N
199644	mikroelektronika	?mikroelektronika =mikroelektronika  (SgN  >mikroelektronika !01_S	et	f	\N
199645	mikroelektronika	?mikroelektronika =mikroelektronika  (SgG  >mikroelektronika !01_S	et	f	\N
199646	mikroelektronika	?mikroelektronika =mikroelektronika  (SgG  >mikroelektronikas !02_A	et	f	\N
199647	mikroelektronika	?mikroelektronika =ika  (SgN  >mikro+elektron+ika !16_S	et	f	\N
199648	mikroelektronika	?mikroelektronika =ika  (SgG  >mikro+elektron+ika !16_S	et	f	\N
199649	mikroelektronika	?mikroelektronika =nika  (SgN  >mikro+elektro+nika !16_S	et	f	\N
199650	mikroelektronika	?mikroelektronika =nika  (SgG  >mikro+elektro+nika !16_S	et	f	\N
199651	mikroelektronika	?mikroelektronika =elektronika  (SgN  >mikro+elektronika !01_S	et	f	\N
199652	mikroelektronika	?mikroelektronika =elektronika  (SgG  >mikro+elektronika !01_S	et	f	\N
199653	mikroelektronika	?mikroelektronika =elektronika  (SgG  >mikro+elektronikas !02_A	et	f	\N
199669	tuuma	tuuma =tuuma  (SgG  >tuum !22_S	et	f	\N
199670	tuuma	tuuma =tuuma  (SgP  >tuum !22_S	et	f	\N
199671	tuuma	tuuma =tuuma  (SgAdt  >tuum !22_S	et	f	\N
199682	eluväikese	eluväikese =väikese  (SgG  >elu+väike !12?10_A	et	f	\N
199683	eluväikese	"elu+väike %väi  )KE_dS  <elu+väi ;26_S	et	f	\N
199684	eluväikese	eluväikese =väikese  (SgG  >elu+väikene !12?10_A	et	f	\N
199685	eluväikese	"elu+väikene %väi  )KENE_dS  <elu+väi ;26_S	et	f	\N
199693	laadus	laadus =laadu  (PlIn  >laat !22_S	et	f	\N
199694	laadus	laadus =laadu  (IndIpfSg3  >laaduma !27_V	et	f	\N
199714	plaaditud	plaaditud =plaadi  (PtsPtIps  >plaatima !28_V	et	f	\N
199715	plaaditud	plaaditud =plaaditu  (PlN  >plaaditu !01_AS	et	f	\N
199716	plaaditud	"plaaditu %plaadi  )TU1_vS  <plaatima ;28_V	et	f	\N
199717	plaaditud	"plaaditu %plaadi  )TU2_kA  <plaat ;22_S	et	f	\N
199718	plaaditud	plaaditud =plaaditud  (ID  >plaaditud !41_A	et	f	\N
199719	plaaditud	"plaaditud %plaadi  )TUD_vA  <plaatima ;28_V	et	f	\N
199725	külalistetuba	külalistetuba =tuba  (SgN  >külaliste+tuba !18_S	et	f	\N
199726	külalistetuba	külalistetuba =tuba  (SgP  >külaliste+tuba !18_S	et	f	\N
199733	krohvimist	krohvimist =krohvimis  (SgP  >krohvimine !12_S	et	f	\N
199734	krohvimist	"krohvimine %krohvi  )MINE_vS  <krohvima ;28_V	et	f	\N
199736	ventilatsion	?ventilatsion =ventilatsion  (SgN  >ventilatsion !19~02_S	et	f	\N
199747	koristamisega	koristamisega =koristamise  (SgKom  >koristamine !12_S	et	f	\N
199748	koristamisega	"koristamine %korista  )MINE_vS  <koristama ;27_V	et	f	\N
199750	remontimise	remontimise =remontimise  (SgG  >remontimine !12_S	et	f	\N
199751	remontimise	"remontimine %remonti  )MINE_vS  <remontima ;28_V	et	f	\N
199763	abstrageerimine	?abstrageerimine =abstrageerimine  (SgN  >abstrageerimine !12_S	et	f	\N
199528	manivaldesid	### manivaldesid	et	f	\N
199542	uusberg	?uusberg =uusberg  (SgN  >uusberg !02_S	et	f	\N
199543	uusberg	?uusberg =berg  (SgN  >uus+berg !22_S	et	f	\N
199592	ekspressi	ekspressi =ekspressi  (SgG  >ekspress !22_S	et	f	\N
199593	ekspressi	ekspressi =ekspressi  (SgP  >ekspress !22_S	et	f	\N
199594	ekspressi	ekspressi =ekspressi  (SgAdt  >ekspress !22_S	et	f	\N
199595	ekspressi	ekspressi =pressi  (SgG  >eks+press !22_S	et	f	\N
199596	ekspressi	ekspressi =pressi  (SgP  >eks+press !22_S	et	f	\N
199597	ekspressi	ekspressi =pressi  (SgAdt  >eks+press !22_S	et	f	\N
199604	kohtaarikkel	?kohtaarikkel =kohtaarikkel  (SgN  >kohtaarikkel !02_S	et	f	\N
199605	kohtaarikkel	?kohtaarikkel =aarikkel  (SgN  >koht+aarikkel !02_S	et	f	\N
199606	ohutumad	ohutumad =ohutuma  (PlN  >ohutum !02_A	et	f	\N
199607	ohutumad	"ohutum %ohu  )TUM2_cA  <oht ;22_S	et	f	\N
199608	ohutumad	"ohutum %ohutu  )M_cA  <ohutu ;01_A	et	f	\N
199612	sailitage	?sailitage =sailita  (ImpPrPl2  >sailitama !27_V	et	f	\N
199613	mikroobi	mikroobi =mikroobi  (SgG  >mikroob !22_S	et	f	\N
199614	mikroobi	mikroobi =mikroobi  (SgP  >mikroob !22_S	et	f	\N
199615	mikroobi	mikroobi =mikroobi  (SgAdt  >mikroob !22_S	et	f	\N
199618	kehtivuse	kehtivuse =kehtivuse  (SgG  >kehtivus !11_S	et	f	\N
199619	kehtivuse	"kehtivus %kehti  )VUS_aS  <kehtima ;27_V	et	f	\N
199620	kehtivuse	"kehtivus %kehtiva  )US_aS  <kehtiv ;02_A	et	f	\N
199625	texas	?texas =texa  (SgIn  >texa !16_S	et	f	\N
199629	jeferson	?jeferson =jeferson  (SgN  >jeferson !19_S	et	f	\N
199657	mehanismeid	?mehanismeid =mehanismei  (PlN  >mehanismei !26_S	et	f	\N
199658	mehanismeid	?mehanismeid =mehanismei  (SgP  >mehanismei !26_S	et	f	\N
199667	diagnostika	diagnostika =diagnostika  (SgN  >diagnostika !01_S	et	f	\N
199668	diagnostika	diagnostika =diagnostika  (SgG  >diagnostika !01_S	et	f	\N
199672	rezonanse	?rezonanse =rezonanse  (SgG  >rezonanne !02_A	et	f	\N
199674	rezonanse	?rezonanse =rezonanse  (PlP  >rezonans !22_S	et	f	\N
199686	elektronilise	elektronilise =elektronilise  (SgG  >elektroniline !12_A	et	f	\N
199687	elektronilise	"elektroniline %elektroni  )LINE_aA  <elektron ;19_S	et	f	\N
199708	10c	### 10c	et	f	\N
199709	külmetussüstemi	?külmetussüstemi =külmetussüstemi  (SgG  >külmetussüstem !02_A	et	f	\N
199710	külmetussüstemi	?külmetussüstemi =süstemi  (SgN  >külmetus+süstemi !01_S	et	f	\N
199711	külmetussüstemi	?külmetussüstemi =süstemi  (SgG  >külmetus+süstemi !01_S	et	f	\N
199712	külmetussüstemi	?külmetussüstemi =süstemi  (SgG  >külmetus+süstem !02_A	et	f	\N
199713	külmetussüstemi	?külmetussüstemi =etussüstemi  (SgG  >külm+etussüstem !02_A	et	f	\N
199721	riulit	?riulit =riuli  (SgP  >riuli !16_S	et	f	\N
199722	riulit	?riulit =riulit  (SgN  >riulit !02_S	et	f	\N
199727	plaatitud	?plaatitud =plaatitu  (PlN  >plaatitu !01_AS	et	f	\N
199728	plaatitud	?plaatitud =plaatitu  (IndPrSg2  >plaatituma !27_V	et	f	\N
199729	plaatitud	?plaatitud =plaatitud  (ID  >plaatitud !41_A	et	f	\N
199732	plaatin	?plaatin =plaatin  (SgN  >plaatin !02_S	et	f	\N
199745	sanitaartehnika	sanitaartehnika =tehnika  (SgN  >sanitaar+tehnika !01_S	et	f	\N
199746	sanitaartehnika	sanitaartehnika =tehnika  (SgG  >sanitaar+tehnika !01_S	et	f	\N
199749	proekt	?proekt =proekt  (SgN  >proekt !22_S	et	f	\N
199752	majaalune	majaalune =alune  (SgN  >maja+alune !10_AS	et	f	\N
199753	majaalune	"maja+alune %alu  )NE_aA  <maja+alg ;22_S	et	f	\N
199756	26-	### 26-	et	f	\N
199769	kanalistsioon	?kanalistsioon =kanalistsioon  (SgN  >kanalistsioon !22_S	et	f	\N
199770	kanalistsioon	?kanalistsioon =listsioon  (SgN  >kana+listsioon !22_S	et	f	\N
199777	isolerivate	?isolerivate =isoleriva  (PlG  >isoleriv !02_A	et	f	\N
199786	planeritakse	?planeritakse =planeritakse  (SgG  >planeritakne !02_A	et	f	\N
199787	planeritakse	?planeritakse =planeritakse  (PlP  >planeritaks !22_S	et	f	\N
199793	kinotuba	kinotuba =tuba  (SgN  >kino+tuba !18_S	et	f	\N
199794	kinotuba	kinotuba =tuba  (SgP  >kino+tuba !18_S	et	f	\N
199800	akkustika	?akkustika =akkustika  (SgN  >akkustika !01_S	et	f	\N
199802	akkustika	?akkustika =akkustika  (SgG  >akkustika !01_S	et	f	\N
199803	akkustika	?akkustika =akkustika  (SgG  >akkustikas !02_A	et	f	\N
199814	plasma	plasma =plasma  (SgN  >plasma !16_S	et	f	\N
199815	plasma	plasma =plasma  (SgG  >plasma !16_S	et	f	\N
199829	mangitakse	?mangitakse =mangi  (IndPrIps  >mankima !28_V	et	f	\N
199830	mangitakse	?mangitakse =mangitakse  (SgG  >mangitakne !02_A	et	f	\N
199831	mangitakse	?mangitakse =mangitakse  (PlP  >mangitaks !22_S	et	f	\N
199832	robottolmuimeja	robottolmuimeja =imeja  (SgN  >robot+tolmu+imeja !01_S	et	f	\N
199833	robottolmuimeja	robottolmuimeja =imeja  (SgG  >robot+tolmu+imeja !01_S	et	f	\N
199836	paljujalu	?paljujalu =paljujalu  (IndPrPs_  >paljujaluma !27_V	et	f	\N
199837	paljujalu	?paljujalu =paljujalu  (ImpPrSg2  >paljujaluma !27_V	et	f	\N
199855	elektritoid	elektritoid =toi  (PlN  >elektri+toi !26_S	et	f	\N
199856	elektritoid	elektritoid =toi  (SgP  >elektri+toi !26_S	et	f	\N
199872	mahutuse	mahutuse =mahutuse  (SgG  >mahutus !11_S	et	f	\N
199873	mahutuse	"mahutus %mahuta  )US_vS  <mahutama ;27_V	et	f	\N
199874	mahutuse	"mahutus %mahu  )TUS1_aS  <mahtuma ;28_V	et	f	\N
199875	mahutuse	"mahutus %mahu  )TUS2_aS  <maht ;22_S	et	f	\N
199624	instruments	?instruments =instruments  (SgN  >instruments !22_S	et	f	\N
199630	osarigis	?osarigis =osarigis  (SgN  >osarigis !09_S	et	f	\N
199633	osarigis	?osarigis =rigi  (SgIn  >osa+rigi !17_S	et	f	\N
199635	osarigis	?osarigis =rigis  (SgN  >osa+rigis !09_S	et	f	\N
199673	magneetilise	?magneetilise =magneetilise  (SgG  >magneetiline !12_A	et	f	\N
199680	täidsid	?täidsid =täidsi  (PlN  >täids !22_S	et	f	\N
199681	täidsid	?täidsid =täidsi  (IndPrSg2  >täidsima !28_V	et	f	\N
199688	kalkulatori	?kalkulatori =kalkulatori  (SgG  >kalkulator !02_S	et	f	\N
199692	jagutakse	jagutakse =jagu  (IndPrIps  >jaguma !27_V	et	f	\N
199695	jagutakse	jagutakse =takse  (PlP  >jagu+taks !22_S	et	f	\N
199698	betoneeritud	betoneeritud =betoneeri  (PtsPtIps  >betoneerima !28_V	et	f	\N
199699	betoneeritud	betoneeritud =betoneeritu  (PlN  >betoneeritu !01_S	et	f	\N
199700	betoneeritud	"betoneeritu %betoneeri  )TU1_vS  <betoneerima ;28_V	et	f	\N
199701	betoneeritud	betoneeritud =betoneeritud  (ID  >betoneeritud !41_A	et	f	\N
199702	betoneeritud	"betoneeritud %betoneeri  )TUD_vA  <betoneerima ;28_V	et	f	\N
199705	riulid	?riulid =riuli  (PlN  >riuli !16_S	et	f	\N
199706	riulid	?riulid =riuli  (PlN  >riul !22_S	et	f	\N
199707	riulid	?riulid =riuli  (IndPrSg2  >riulima !28_V	et	f	\N
199723	klaaslaud	klaaslaud =lau  (PlN  >klaas+laug !22_SA	et	f	\N
199724	klaaslaud	klaaslaud =laud  (SgN  >klaas+laud !22_S	et	f	\N
199757	proekti	?proekti =proekti  (ID  >proekti !41_D	et	f	\N
199758	proekti	?proekti =proekti  (SgG  >proekt !22_S	et	f	\N
199759	proekti	?proekti =proekti  (SgP  >proekt !22_S	et	f	\N
199760	proekti	?proekti =proekti  (SgAdt  >proekt !22_S	et	f	\N
199761	proekti	?proekti =proekti  (IndPrPs_  >proektima !28_V	et	f	\N
199762	proekti	?proekti =proekti  (ImpPrSg2  >proektima !28_V	et	f	\N
199764	askeldusest	askeldusest =askelduse  (SgEl  >askeldus !11_S	et	f	\N
199766	askeldusest	"askeldus %askelda  )US_vS  <askeldama ;27_V	et	f	\N
199767	askeldusest	askeldusest =askelduses  (SgP  >askeldusene !12_A	et	f	\N
199768	askeldusest	"askeldusene %askelduse  )NE_aA  <askeldus ;11_S	et	f	\N
199774	karkassi	karkassi =karkassi  (SgG  >karkass !22_S	et	f	\N
199775	karkassi	karkassi =karkassi  (SgP  >karkass !22_S	et	f	\N
199776	karkassi	karkassi =karkassi  (SgAdt  >karkass !22_S	et	f	\N
199778	soendus	soendus =soendus  (SgN  >soendus !11~09_S	et	f	\N
199779	soendus	"soendus %soenda  )US_vS  <soendama ;27_V	et	f	\N
199780	töötlemise	töötlemise =töötlemise  (SgG  >töötlemine !12_S	et	f	\N
199781	töötlemise	"töötlemine %töötle  )MINE_vS  <töötlema ;30_V	et	f	\N
199789	valesvomis	?valesvomis =valesvomi  (SgIn  >valesvom !19_S	et	f	\N
199790	valesvomis	?valesvomis =valesvomis  (SgN  >valesvomis !09_S	et	f	\N
199791	valesvomis	?valesvomis =svomi  (SgIn  >vale+svomi !17_S	et	f	\N
199792	valesvomis	?valesvomis =svomis  (SgN  >vale+svomis !09_S	et	f	\N
199797	tühendusse	?tühendusse =tühendu  (SgIll  >tühendu !01_S	et	f	\N
199798	tühendusse	?tühendusse =tühendus  (SgAdt  >tühendus !11_S	et	f	\N
199799	tühendusse	?tühendusse =tühendusse  (SgG  >tühendusne !02_A	et	f	\N
199801	tühendusse	?tühendusse =tühendusse  (PlP  >tühenduss !22_S	et	f	\N
199807	krohvliga	krohvliga =liga  (SgN  >krohv+liga !17_S	et	f	\N
199808	krohvliga	krohvliga =liga  (SgG  >krohv+liga !17_S	et	f	\N
199809	krohvliga	krohvliga =liga  (SgP  >krohv+liga !17_S	et	f	\N
199810	töötlevast	töötlevast =töötleva  (SgEl  >töötlev !02_A	et	f	\N
199811	töötlevast	"töötlev %töötle  )V_vA  <töötlema ;30_V	et	f	\N
199850	ming	?ming =ming  (SgN  >ming !22_S	et	f	\N
199853	toid	toid =toi  (PlN  >toi !26_S	et	f	\N
199854	toid	toid =toi  (SgP  >toi !26_S	et	f	\N
199858	lähitulevikus	lähitulevikus =viku  (SgIn  >lähi+tule+vikk !22_S	et	f	\N
199859	lähitulevikus	lähitulevikus =tuleviku  (SgIn  >lähi+tulevik !25_S	et	f	\N
199865	tehaksin	?tehaksin =teha  (KndPrSg1  >tehama !27_V	et	f	\N
199866	tehaksin	?tehaksin =tehaksi  (IndPrSg1  >tehaksima !28_V	et	f	\N
199867	tehaksin	?tehaksin =tehaksin  (SgN  >tehaksin !19_S	et	f	\N
199885	pladitud	?pladitud =pladi  (PtsPtIps  >pladima !27_V	et	f	\N
199886	pladitud	?pladitud =pladitu  (PlN  >pladitu !01_AS	et	f	\N
199887	pladitud	?pladitud =pladitu  (IndPrSg2  >pladituma !27_V	et	f	\N
199888	pladitud	?pladitud =pladitud  (ID  >pladitud !41_A	et	f	\N
199890	krohvitud	krohvitud =krohvi  (PtsPtIps  >krohvima !28_V	et	f	\N
199891	krohvitud	krohvitud =krohvitu  (PlN  >krohvitu !01_AS	et	f	\N
199892	krohvitud	"krohvitu %krohvi  )TU1_vS  <krohvima ;28_V	et	f	\N
199893	krohvitud	"krohvitu %krohvi  )TU2_kA  <krohv ;22_S	et	f	\N
199894	krohvitud	krohvitud =krohvitud  (ID  >krohvitud !41_A	et	f	\N
199895	krohvitud	"krohvitud %krohvi  )TUD_vA  <krohvima ;28_V	et	f	\N
199904	jonistatud	?jonistatud =jonista  (PtsPtIps  >jonistama !27_V	et	f	\N
199905	jonistatud	?jonistatud =jonistatu  (PlN  >jonistatu !01_S	et	f	\N
199906	jonistatud	?jonistatud =jonistatu  (IndPrSg2  >jonistatuma !27_V	et	f	\N
199907	jonistatud	?jonistatud =jonistatud  (ID  >jonistatud !41_A	et	f	\N
199912	laudid	laudid =laudi  (PlN  >laudi !01_S	et	f	\N
199913	laudid	laudid =laudi  (PlN  >laut !22_S	et	f	\N
199914	laudid	laudid =laudi  (IndPrSg2  >lautima !28_V	et	f	\N
199919	tisleritöökoda	### tisleritöökoda	et	f	\N
199689	koduarvutid	koduarvutid =uti  (PlN  >kodu+arv+utt !22_S	et	f	\N
199690	koduarvutid	koduarvutid =arvuti  (PlN  >kodu+arvuti !01_S	et	f	\N
199691	alouseks	?alouseks =alouse  (PlTr  >alous !22_S	et	f	\N
199703	muutuseta	muutuseta =muutuse  (SgAb  >muutus !11~09_S	et	f	\N
199704	muutuseta	"muutus %muu  )TUS2_aS  <muu ;26_S	et	f	\N
199739	kapike	kapike =kapike  (SgN  >kapike !12_S	et	f	\N
199740	kapike	"kapike %kapi  )KE_dS  <kapp ;22_S	et	f	\N
199743	stereosüstem	?stereosüstem =stereosüstem  (SgN  >stereosüstem !02_A	et	f	\N
199744	stereosüstem	?stereosüstem =süstem  (SgN  >stereo+süstem !02_A	et	f	\N
199754	katkine	katkine =katkine  (SgN  >katkine !12~10_A	et	f	\N
199755	katkine	"katkine %katki  )NE_aA  <katk ;22_S	et	f	\N
199784	plaadid	plaadid =plaadi  (PlN  >plaat !22_S	et	f	\N
199785	plaadid	plaadid =plaadi  (IndPrSg2  >plaatima !28_V	et	f	\N
199788	uustega	?uustega =uuste  (SgKom  >uuste !06_S	et	f	\N
199795	vormitakse	vormitakse =vormi  (IndPrIps  >vormima !28_V	et	f	\N
199796	vormitakse	vormitakse =takse  (PlP  >vormi+taks !22_S	et	f	\N
199806	faktuurse	?faktuurse =faktuurse  (SgG  >faktuurne !02_A	et	f	\N
199812	dekoreritakse	?dekoreritakse =dekoreritakse  (SgG  >dekoreritakne !02_A	et	f	\N
199813	dekoreritakse	?dekoreritakse =dekoreritakse  (PlP  >dekoreritaks !22_S	et	f	\N
199822	värskem	?värskem =värskem  (SgN  >värskem !02_A	et	f	\N
199824	sailitatakse	?sailitatakse =sailita  (IndPrIps  >sailitama !27_V	et	f	\N
199825	sailitatakse	?sailitatakse =sailitatakse  (SgG  >sailitatakne !02_A	et	f	\N
199826	sailitatakse	?sailitatakse =sailitatakse  (PlP  >sailitataks !22_S	et	f	\N
199827	sailitatakse	?sailitatakse =litatakse  (SgG  >sai+litatakne !02_A	et	f	\N
199828	sailitatakse	?sailitatakse =litatakse  (PlP  >sai+litataks !22_S	et	f	\N
199844	pinke	pinke =pinke  (SgG  >pinge !06_S	et	f	\N
199845	pinke	pinke =pinke  (PlP  >pink !22_S	et	f	\N
199881	rietus	?rietus =rietu  (SgIn  >rietu !01_A	et	f	\N
199882	rietus	?rietus =rietu  (IndIpfSg3  >rietuma !27_V	et	f	\N
199883	rietus	?rietus =rietus  (SgN  >rietus !11~09_S	et	f	\N
199896	magamis	?magamis =magami  (SgIn  >magami !01_S	et	f	\N
199897	magamis	?magamis =magami  (SgIn  >magam !02_A	et	f	\N
199898	magamis	?magamis =magamis  (SgN  >magamis !11_S	et	f	\N
199910	köök-ladu	köök-ladu =ladu  (SgN  >köök-ladu !18_S	et	f	\N
199911	köök-ladu	köök-ladu =ladu  (SgP  >köök-ladu !18_S	et	f	\N
199937	kottist	?kottist =kottist  (SgN  >kottist !22_S	et	f	\N
199940	arateeritud	?arateeritud =arateeri  (PtsPtIps  >arateerima !28_V	et	f	\N
199941	arateeritud	?arateeritud =arateeritu  (PlN  >arateeritu !01_S	et	f	\N
199942	arateeritud	?arateeritud =arateeritu  (IndPrSg2  >arateerituma !27_V	et	f	\N
199943	arateeritud	?arateeritud =arateeritud  (ID  >arateeritud !41_A	et	f	\N
199944	arateeritud	?arateeritud =ritu  (PlN  >ara+tee+ritu !16_S	et	f	\N
199945	arateeritud	?arateeritud =teeritu  (PlN  >ara+teeritu !01_AS	et	f	\N
199952	prunid	?prunid =pruni  (PlN  >pruni !17_S	et	f	\N
199954	prunid	?prunid =pruni  (IndPrSg2  >prunima !27_V	et	f	\N
199967	näes	?näes =näe  (SgIn  >näe !26_S	et	f	\N
199968	näes	?näes =näes  (SgN  >näes !09_S	et	f	\N
199971	sõitak	?sõitak =sõitak  (SgN  >sõitak !02_S	et	f	\N
199982	varasta	varasta =varasta  (IndPrPs_  >varastama !27_V	et	f	\N
199983	varasta	varasta =varasta  (ImpPrSg2  >varastama !27_V	et	f	\N
200018	horoskop	### horoskop	et	f	\N
200029	lülita	lülita =lüli  (SgAb  >lüli !17_S	et	f	\N
200030	lülita	lülita =lüli  (IndPrIps_  >lülima !27_V	et	f	\N
200031	lülita	lülita =lülita  (IndPrPs_  >lülitama !27_V	et	f	\N
200032	lülita	lülita =lülita  (ImpPrSg2  >lülitama !27_V	et	f	\N
200064	varugenerator	?varugenerator =varugenerator  (SgN  >varugenerator !02_S	et	f	\N
200065	varugenerator	?varugenerator =generator  (SgN  >varu+generator !02_S	et	f	\N
200071	ups	?ups =ups  (SgN  >ups !22_S	et	f	\N
200083	rävala	?rävala =rävala  (SgN  >rävala !01_S	et	f	\N
200084	rävala	?rävala =rävala  (SgG  >rävala !01_S	et	f	\N
200104	ebatavalise	ebatavalise =tavalise  (SgG  >eba+tavaline !12_A	et	f	\N
200105	ebatavalise	"eba+tavaline %tava  )LINE_aA  <eba+tava ;17_S	et	f	\N
200109	automatiseeritud	automatiseeritud =automatiseeri  (PtsPtIps  >automatiseerima !28_V	et	f	\N
200110	automatiseeritud	automatiseeritud =automatiseeritu  (PlN  >automatiseeritu !01_S	et	f	\N
200111	automatiseeritud	"automatiseeritu %automatiseeri  )TU1_vS  <automatiseerima ;28_V	et	f	\N
200112	automatiseeritud	automatiseeritud =automatiseeritud  (ID  >automatiseeritud !41_A	et	f	\N
200113	automatiseeritud	"automatiseeritud %automatiseeri  )TUD_vA  <automatiseerima ;28_V	et	f	\N
200114	automatiseeritud	automatiseeritud =seeritu  (PlN  >au+tomati+seeritu !01_AS	et	f	\N
200117	põlemist	põlemist =põlemi  (SgEl  >põlem !02_S	et	f	\N
200118	põlemist	põlemist =põlemis  (SgP  >põlemine !12_S	et	f	\N
200119	põlemist	"põlemine %põle  )MINE_vS  <põlema ;27_V	et	f	\N
200120	põlemist	"põlemine %põlemi  )NE_aA  <põlem ;02_S	et	f	\N
200157	natsionaliseerumine	?natsionaliseerumine =natsionaliseerumine  (SgN  >natsionaliseerumine !12_S	et	f	\N
200158	natsionaliseerumine	?natsionaliseerumine =natsionaliseerumine  (PlP  >natsionaliseerumin !19_S	et	f	\N
200159	natsionaliseerumine	?natsionaliseerumine =onaliseerumine  (SgN  >natsi+onaliseerumine !12_S	et	f	\N
199765	abstrageerimine	?abstrageerimine =abstrageerimine  (PlP  >abstrageerimin !19_S	et	f	\N
199771	soendadus	?soendadus =soendadu  (SgIn  >soendadu !01_S	et	f	\N
199772	soendadus	?soendadus =soendadu  (IndIpfSg3  >soendaduma !27_V	et	f	\N
199773	soendadus	?soendadus =soendadus  (SgN  >soendadus !11_S	et	f	\N
199782	plaadid	plaadid =plaadi  (PlN  >plaat !22_S	et	f	\N
199783	plaadid	plaadid =plaadi  (IndPrSg2  >plaatima !28_V	et	f	\N
199804	kaetakse	kaetakse =kae  (IndPrIps  >kaema !27_V	et	f	\N
199805	kaetakse	kaetakse =kae  (IndPrIps  >katma !35_V	et	f	\N
199816	metsikust	metsikust =metsiku  (SgEl  >metsik !02_AS	et	f	\N
199817	metsikust	metsikust =metsikus  (SgP  >metsikus !11_S	et	f	\N
199818	metsikust	"metsikus %metsiku  )US_aS  <metsik ;02_AS	et	f	\N
199838	santehnikatöid	?santehnikatöid =santehnikatöi  (PlN  >santehnikatöi !26_S	et	f	\N
199839	santehnikatöid	?santehnikatöid =santehnikatöi  (SgP  >santehnikatöi !26_S	et	f	\N
199840	santehnikatöid	?santehnikatöid =santehnikatöid  (SgN  >santehnikatöid !22_S	et	f	\N
199841	leiliruumi	leiliruumi =ruumi  (SgG  >leili+ruum !22_S	et	f	\N
199842	leiliruumi	leiliruumi =ruumi  (SgP  >leili+ruum !22_S	et	f	\N
199843	leiliruumi	leiliruumi =ruumi  (SgAdt  >leili+ruum !22_S	et	f	\N
199849	põrandakutet	?põrandakutet =kute  (SgP  >põranda+kute !06_S	et	f	\N
199860	kirjeldanud	kirjeldanud =kirjelda  (PtsPtPs  >kirjeldama !27_V	et	f	\N
199861	kirjeldanud	kirjeldanud =kirjeldanu  (PlN  >kirjeldanu !01_S	et	f	\N
199862	kirjeldanud	"kirjeldanu %kirjelda  )NU_vS  <kirjeldama ;27_V	et	f	\N
199863	kirjeldanud	kirjeldanud =kirjeldanud  (ID  >kirjeldanud !41_A	et	f	\N
199864	kirjeldanud	"kirjeldanud %kirjelda  )NUD_vA  <kirjeldama ;27_V	et	f	\N
199868	paniks	paniks =pani  (SgTr  >pani !16_S	et	f	\N
199869	paniks	paniks =pani  (SgTr  >pan !19_S	et	f	\N
199870	nurgisse	nurgisse =nurgi  (SgIll  >nurk !22_S	et	f	\N
199871	nurgisse	nurgisse =nurgi  (PlIll  >nurk !22_S	et	f	\N
199899	taapedid	?taapedid =taapedi  (PlN  >taapedi !01_S	et	f	\N
199908	ktee	?ktee =ktee  (SgN  >ktee !26_S	et	f	\N
199909	ktee	?ktee =ktee  (SgG  >ktee !26_S	et	f	\N
199915	treninguseade	?treninguseade =treningusea  (PlG  >treningusea !26_S	et	f	\N
199916	treninguseade	?treninguseade =treninguseade  (PlP  >treningusead !22_S	et	f	\N
199920	tisleripink	?tisleripink =tisleripink  (SgN  >tisleripink !22_S	et	f	\N
199926	viskada	### viskada	et	f	\N
199969	kottiga	kottiga =iga  (SgN  >kott+iga !18_S	et	f	\N
199970	kottiga	kottiga =iga  (SgP  >kott+iga !18_S	et	f	\N
199989	mugavus	mugavus =mugavus  (SgN  >mugavus !11_S	et	f	\N
199990	mugavus	"mugavus %mugava  )US_aS  <mugav ;02_A	et	f	\N
200006	kummid	kummid =kummi  (PlN  >kummi !16_S	et	f	\N
200007	kummid	kummid =kummi  (PlN  >kumm !22_S	et	f	\N
200008	kummid	kummid =kummi  (IndPrSg2  >kummima !28_V	et	f	\N
200009	kohtle	kohtle =kohtle  (IndPrPs_  >kohtlema !30_V	et	f	\N
200010	kohtle	kohtle =kohtle  (ImpPrSg2  >kohtlema !30_V	et	f	\N
200011	ohutult	ohutult =ohutu  (SgAbl  >ohutu !01_A	et	f	\N
200012	ohutult	"ohutu %ohu  )TU2_kA  <oht ;22_S	et	f	\N
200013	ohutult	ohutult =ohutult  (ID  >ohutult !41_D	et	f	\N
200014	ohutult	"ohutult %ohu  )TULT2_mD  <oht ;22_S	et	f	\N
200015	ohutult	"ohutult %ohutu  )LT_mD  <ohutu ;01_A	et	f	\N
200016	ristkülikuline	ristkülikuline =külikuline  (SgN  >rist+külikuline !12_A	et	f	\N
200017	ristkülikuline	"rist+külikuline %küliku  )LINE_aA  <rist+külik ;02_S	et	f	\N
200023	taskuse	?taskuse =taskuse  (SgG  >taskus !11~09_S	et	f	\N
200024	lülikatke	lülikatke =katke  (SgN  >lüli+katke !06_S	et	f	\N
200025	lülikatke	lülikatke =katke  (SgG  >lüli+katke !06_S	et	f	\N
200026	lülikatke	lülikatke =katke  (PlP  >lüli+katk !22_S	et	f	\N
200037	ladima	?ladima =ladi  (Sup  >ladima !27_V	et	f	\N
200038	ladima	?ladima =ladima  (SgG  >ladim !02_A	et	f	\N
200072	patareid	patareid =patarei  (PlN  >patarei !26_S	et	f	\N
200073	patareid	patareid =patarei  (SgP  >patarei !26_S	et	f	\N
200088	olma	?olma =olma  (SgN  >olma !16_S	et	f	\N
200089	olma	?olma =olma  (SgG  >olma !16_S	et	f	\N
200090	olma	?olma =olma  (IndPrPs_  >olmama !29_V	et	f	\N
200091	olma	?olma =olma  (ImpPrSg2  >olmama !29_V	et	f	\N
200121	õlevihad	õlevihad =viha  (PlN  >õle+viha !17_SA	et	f	\N
200122	õlevihad	õlevihad =viha  (PlN  >õle+viht !22_S	et	f	\N
200123	3kirjelda	kirjelda =kirjelda  (IndPrPs_  >kirjeldama !27_V	et	f	\N
200124	3kirjelda	kirjelda =kirjelda  (ImpPrSg2  >kirjeldama !27_V	et	f	\N
200139	vüisid	?vüisid =vüi  (PlP  >vüi !26_S	et	f	\N
200140	vüisid	?vüisid =vüisi  (PlN  >vüisi !16_S	et	f	\N
200141	vüisid	?vüisid =vüisi  (PlN  >vüis !22_S	et	f	\N
200142	vüisid	?vüisid =vüisi  (IndPrSg2  >vüisima !28_V	et	f	\N
200165	kontrollda	?kontrollda =kontrollda  (IndPrPs_  >kontrolldama !27_V	et	f	\N
200166	kontrollda	?kontrollda =kontrollda  (ImpPrSg2  >kontrolldama !27_V	et	f	\N
200176	furmas	?furmas =furma  (SgIn  >furma !16_S	et	f	\N
200177	furmas	?furmas =furma  (IndIpfSg3  >furmama !29_V	et	f	\N
200178	furmas	?furmas =furmas  (SgN  >furmas !07_S	et	f	\N
200183	lejan	?lejan =leja  (IndPrSg1  >lejama !27_V	et	f	\N
200184	lejan	?lejan =lejan  (SgN  >lejan !02_S	et	f	\N
199876	oleke	?oleke =oleke  (SgN  >oleke !12_S	et	f	\N
199884	basein	?basein =basein  (SgN  >basein !22_S	et	f	\N
199900	malitud	malitud =malitu  (PlN  >malitu !01_AS	et	f	\N
199901	malitud	"malitu %mali  )TU2_kA  <mali ;17_S	et	f	\N
199917	võimsadega	### võimsadega	et	f	\N
199921	montöötööristad	?montöötööristad =montöötöörista  (PlN  >montöötöörista !16_S	et	f	\N
199922	montöötööristad	?montöötööristad =montöötöörista  (IndPrSg2  >montöötööristama !27_V	et	f	\N
199936	lähemes	### lähemes	et	f	\N
199946	tunnistaja	tunnistaja =tunnistaja  (SgN  >tunnistaja !01_S	et	f	\N
199947	tunnistaja	"tunnistaja %tunnista  )JA_vS  <tunnistama ;27_V	et	f	\N
199948	tunnistaja	tunnistaja =tunnistaja  (SgG  >tunnistaja !01_S	et	f	\N
199949	riienud	?riienud =riienu  (PlN  >riienu !01_S	et	f	\N
199950	riienud	?riienud =riienu  (IndPrSg2  >riienuma !27_V	et	f	\N
199951	riienud	?riienud =riienud  (ID  >riienud !41_A	et	f	\N
199961	maantel	?maantel =maante  (SgAd  >maande !06_S	et	f	\N
199962	maantel	?maantel =maantel  (SgN  >maantel !02_S	et	f	\N
199963	röövida	röövida =röövi  (Inf  >röövima !28_V	et	f	\N
199964	röövida	röövida =ida  (SgN  >rööv+ida !17_S	et	f	\N
199965	röövida	röövida =ida  (SgG  >rööv+ida !17_S	et	f	\N
199966	röövida	röövida =ida  (SgP  >rööv+ida !17_S	et	f	\N
199972	edukast	edukast =eduka  (SgEl  >edukas !02_A	et	f	\N
199973	edukast	edukast =kast  (SgN  >edu+kast !22_S	et	f	\N
199977	tugiga	### tugiga	et	f	\N
199978	tuuduvalt	?tuuduvalt =tuuduva  (SgAbl  >tuuduva !01_S	et	f	\N
199979	tuuduvalt	?tuuduvalt =tuuduva  (SgAbl  >tuuduv !02_A	et	f	\N
199980	tuuduvalt	?tuuduvalt =tuuduvalt  (ID  >tuuduvalt !41_D	et	f	\N
199984	armuke	armuke =armuke  (SgN  >armuke !12_S	et	f	\N
199985	armuke	"armuke %armu  )KE_dS  <arm ;22_S	et	f	\N
199991	taskukohane	taskukohane =kohane  (SgN  >tasku+kohane !10_A	et	f	\N
199992	taskukohane	"tasku+kohane %koha  )NE_aA  <tasku+koha ;17_S	et	f	\N
199993	taskukohane	"tasku+kohane %koha  )NE_aA  <tasku+koht ;22_S	et	f	\N
200001	moodsuse	moodsuse =moodsuse  (SgG  >moodsus !11~09_S	et	f	\N
200002	moodsuse	"moodsus %moodsa  )US_aS  <moodne ;02_A	et	f	\N
200003	moodsuse	"moodsus %moodse  )US_aS  <moodne ;02_A	et	f	\N
200021	kottisse	?kottisse =kottisse  (SgG  >kottisne !02_A	et	f	\N
200022	kottisse	?kottisse =kottisse  (PlP  >kottiss !22_S	et	f	\N
200035	aku	aku =aku  (SgN  >aku !16_S	et	f	\N
200036	aku	aku =aku  (SgG  >aku !16_S	et	f	\N
200041	aratus	?aratus =aratu  (SgIn  >aratu !01_AS	et	f	\N
200042	aratus	?aratus =aratu  (IndIpfSg3  >aratuma !27_V	et	f	\N
200043	aratus	?aratus =aratus  (SgN  >aratus !11_S	et	f	\N
200051	rumide	?rumide =rumi  (PlG  >rumi !17_S	et	f	\N
200060	olulistel	olulistel =olulis  (PlAd  >oluline !12_A	et	f	\N
200061	olulistel	"oluline %olu  )LINE_aA  <olu ;17_S	et	f	\N
200066	arvutitele	arvutitele =arvuti  (PlAll  >arvuti !01_S	et	f	\N
200067	arvutitele	arvutitele =tite  (SgAll  >arvu+titt !22_S	et	f	\N
200068	arvutitele	arvutitele =tite  (PlAll  >arvu+titt !22_S	et	f	\N
200092	värvus	värvus =värvu  (SgIn  >värb !22_S	et	f	\N
200093	värvus	värvus =värvu  (IndIpfSg3  >värvuma !27_V	et	f	\N
200094	värvus	värvus =värvus  (SgN  >värvus !11~09_S	et	f	\N
200095	kolane	kolane =kolane  (SgN  >kolane !10_A	et	f	\N
200096	kolane	"kolane %kola  )NE_aA  <kola ;17_S	et	f	\N
200097	unistute	?unistute =unistu  (PlG  >unistu !01_S	et	f	\N
200098	unistute	?unistute =unistu  (IndPrPl2  >unistuma !27_V	et	f	\N
200099	unistute	?unistute =stute  (SgN  >uni+stute !06_S	et	f	\N
200103	metallik	?metallik =metallik  (SgN  >metallik !02_A	et	f	\N
200115	seitsme-kaheksa	seitsme-kaheksa =kaheksa  (SgN  >seitsme-kaheksa !01_N	et	f	\N
200116	seitsme-kaheksa	seitsme-kaheksa =kaheksa  (SgG  >seitsme-kaheksa !01_N	et	f	\N
200125	bolshevikud	?bolshevikud =bolsheviku  (PlN  >bolshevik !25_S	et	f	\N
200126	bolshevikud	?bolshevikud =bolsheviku  (IndPrSg2  >bolshevikuma !27_V	et	f	\N
200128	lõpuksneil	?lõpuksneil =lõpuksne  (PlAd  >lõpuksni !01_S	et	f	\N
200129	lõpuksneil	?lõpuksneil =lõpuksnei  (SgAd  >lõpuksnei !26_S	et	f	\N
200130	lõpuksneil	?lõpuksneil =lõpuksneil  (SgN  >lõpuksneil !19_S	et	f	\N
200137	sisimusel	sisimusel =sisimuse  (SgAd  >sisimus !11_S	et	f	\N
200138	sisimusel	"sisimus %sisima  )US_aS  <sisim ;02_A	et	f	\N
200153	sisimuselt	sisimuselt =sisimuse  (SgAbl  >sisimus !11_S	et	f	\N
200154	sisimuselt	"sisimus %sisima  )US_aS  <sisim ;02_A	et	f	\N
200155	avaldusi	avaldusi =avaldusi  (PlP  >avaldus !11_S	et	f	\N
200156	avaldusi	"avaldus %avalda  )US_vS  <avaldama ;27_V	et	f	\N
200171	minevat	minevat =mine  (KvtPrPs  >minema !36_V	et	f	\N
200172	minevat	minevat =mineva  (SgP  >minev !02_A	et	f	\N
200173	minevat	"minev %mine  )V_vA  <minema ;36_V	et	f	\N
200181	riigiülikool	riigiülikool =koo  (SgAd  >riigi+üli+kubu !18_S	et	f	\N
200182	riigiülikool	riigiülikool =kool  (SgN  >riigi+üli+kool !22_S	et	f	\N
200199	paem	?paem =paem  (SgN  >paem !22_S	et	f	\N
200228	meldi	?meldi =meldi  (ID  >meldi !41_D	et	f	\N
200229	meldi	?meldi =meldi  (SgG  >melt !22_S	et	f	\N
200230	meldi	?meldi =meldi  (SgP  >meld !22_S	et	f	\N
200231	meldi	?meldi =meldi  (SgAdt  >meld !22_S	et	f	\N
199877	veetaksin	?veetaksin =veeta  (KndPrSg1  >veetama !27_V	et	f	\N
199878	veetaksin	?veetaksin =veetaksi  (IndPrSg1  >veetaksima !28_V	et	f	\N
199879	veetaksin	?veetaksin =veetaksin  (SgN  >veetaksin !19_S	et	f	\N
199880	veetaksin	?veetaksin =taksin  (SgN  >vee+taksin !02_S	et	f	\N
199889	sojundusega	?sojundusega =sojunduse  (SgKom  >sojundus !11_S	et	f	\N
199902	lilla	lilla =lilla  (SgN  >lilla !16_AS	et	f	\N
199903	lilla	lilla =lilla  (SgG  >lilla !16_AS	et	f	\N
199918	sambakedega	?sambakedega =kede  (SgKom  >samba+kede !16_S	et	f	\N
199923	tankmise	?tankmise =tankmise  (SgG  >tankmine !12?10_A	et	f	\N
199924	tankmise	?tankmise =tankmise  (IndPrPs_  >tankmisema !27_V	et	f	\N
199925	tankmise	?tankmise =tankmise  (ImpPrSg2  >tankmisema !27_V	et	f	\N
199931	reaktsiooni	reaktsiooni =reaktsiooni  (SgG  >reaktsioon !22_S	et	f	\N
199932	reaktsiooni	reaktsiooni =reaktsiooni  (SgP  >reaktsioon !22_S	et	f	\N
199933	reaktsiooni	reaktsiooni =reaktsiooni  (SgAdt  >reaktsioon !22_S	et	f	\N
199934	tunnistajaks	tunnistajaks =tunnistaja  (SgTr  >tunnistaja !01_S	et	f	\N
199935	tunnistajaks	"tunnistaja %tunnista  )JA_vS  <tunnistama ;27_V	et	f	\N
199938	ründajat	ründajat =ründaja  (SgP  >ründaja !01_S	et	f	\N
199939	ründajat	"ründaja %ründa  )JA_vS  <ründama ;29_V	et	f	\N
199953	vuntsid	vuntsid =vuntsi  (PlN  >vunts !22_S	et	f	\N
199955	vuntsid	vuntsid =vuntsi  (IndPrSg2  >vuntsima !28_V	et	f	\N
199956	hämmeldanud	hämmeldanud =hämmelda  (PtsPtPs  >hämmeldama !27_V	et	f	\N
199957	hämmeldanud	hämmeldanud =hämmeldanu  (PlN  >hämmeldanu !01_S	et	f	\N
199958	hämmeldanud	"hämmeldanu %hämmelda  )NU_vS  <hämmeldama ;27_V	et	f	\N
199959	hämmeldanud	hämmeldanud =hämmeldanud  (ID  >hämmeldanud !41_A	et	f	\N
199960	hämmeldanud	"hämmeldanud %hämmelda  )NUD_vA  <hämmeldama ;27_V	et	f	\N
199975	istmepea	istmepea =pea  (SgN  >istme+pea !26_S	et	f	\N
199976	istmepea	istmepea =pea  (SgG  >istme+pea !26_S	et	f	\N
199994	juhimine	?juhimine =juhimine  (SgN  >juhimine !12_S	et	f	\N
199995	juhimine	?juhimine =juhimine  (PlP  >juhimin !19_S	et	f	\N
200033	elektrivõrku	elektrivõrku =võrku  (SgP  >elektri+võrk !22_S	et	f	\N
200034	elektrivõrku	elektrivõrku =võrku  (SgAdt  >elektri+võrk !22_S	et	f	\N
200044	taimerile	taimerile =taimeri  (SgAll  >taimer !02_S	et	f	\N
200045	taimerile	taimerile =eri  (SgAll  >taim+eri !17_S	et	f	\N
200048	põrandaharja	põrandaharja =harja  (SgG  >põranda+hari !24_S	et	f	\N
200049	põrandaharja	põrandaharja =harja  (SgP  >põranda+hari !24_S	et	f	\N
200050	põrandaharja	põrandaharja =harja  (SgAdt  >põranda+hari !24_S	et	f	\N
200054	masinatemihanismid	?masinatemihanismid =masinatemihanismi  (PlN  >masinatemihanism !22_S	et	f	\N
200055	masinatemihanismid	?masinatemihanismid =masinatemihanismi  (IndPrSg2  >masinatemihanismima !28_V	et	f	\N
200056	masinatemihanismid	?masinatemihanismid =temihanismi  (PlN  >masina+temihanism !22_S	et	f	\N
200057	masinatemihanismid	?masinatemihanismid =atemihanismi  (PlN  >masin+atemihanism !22_S	et	f	\N
200058	raadarid	?raadarid =raadari  (PlN  >raadari !01_S	et	f	\N
200059	raadarid	?raadarid =raadari  (PlN  >raadar !02_S	et	f	\N
200085	turvalisus	turvalisus =turvalisus  (SgN  >turvalisus !11?09_S	et	f	\N
200086	turvalisus	"turvalisus %turva  )LISUS_aS  <turb ;22_SA	et	f	\N
200087	turvalisus	"turvalisus %turva  )LISUS_aS  <turv ;22_S	et	f	\N
200131	tegutsemaka	?tegutsemaka =tegutsemaka  (SgN  >tegutsemaka !16_S	et	f	\N
200132	tegutsemaka	?tegutsemaka =tegutsemaka  (SgG  >tegutsemakas !02_A	et	f	\N
200133	tegutsemaka	?tegutsemaka =tegutsemaka  (SgG  >tegutsemaka !16_S	et	f	\N
200134	tegutsemaka	?tegutsemaka =tsemaka  (SgN  >tegu+tsemaka !01_S	et	f	\N
200135	tegutsemaka	?tegutsemaka =tsemaka  (SgG  >tegu+tsemaka !01_S	et	f	\N
200136	tegutsemaka	?tegutsemaka =tsemaka  (SgG  >tegu+tsemakas !02_A	et	f	\N
200143	purustav	purustav =purusta  (PtsPrPs  >purustama !27_V	et	f	\N
200144	purustav	purustav =purustav  (SgN  >purustav !02_A	et	f	\N
200145	purustav	"purustav %purusta  )V_vA  <purustama ;27_V	et	f	\N
200151	stagnatsioonaga	?stagnatsioonaga =stagnatsioona  (SgKom  >stagnatsioona !16_S	et	f	\N
200152	stagnatsioonaga	?stagnatsioonaga =tsioona  (SgKom  >stagna+tsioona !16_S	et	f	\N
200167	ui	ui =ui  (ID  >ui !41_I	et	f	\N
200168	ui	ui =ui  (SgN  >ui !26_S	et	f	\N
200169	ui	ui =ui  (SgG  >ui !26_S	et	f	\N
200193	savutada	?savutada =savuta  (Inf  >savutama !27_V	et	f	\N
200196	tehnikaülikooliga	tehnikaülikooliga =iga  (SgN  >tehnika+üli+kool+iga !18_S	et	f	\N
200197	tehnikaülikooliga	tehnikaülikooliga =iga  (SgP  >tehnika+üli+kool+iga !18_S	et	f	\N
200198	tehnikaülikooliga	tehnikaülikooliga =kooli  (SgKom  >tehnika+üli+kool !22_S	et	f	\N
200206	pudub	?pudub =pudu  (IndPrSg3  >puduma !27_V	et	f	\N
200209	samaegselt	?samaegselt =samaegse  (SgAbl  >samaegne !02_A	et	f	\N
200210	samaegselt	?samaegselt =samaegse  (PlAbl  >samaegs !22_S	et	f	\N
200211	samaegselt	?samaegselt =samaegselt  (ID  >samaegselt !41_D	et	f	\N
200212	samaegselt	?samaegselt =egse  (SgAbl  >sama+egne !02_A	et	f	\N
200213	samaegselt	?samaegselt =egse  (SgAbl  >sama+egse !06_S	et	f	\N
200214	samaegselt	?samaegselt =egse  (PlAbl  >sama+egs !22_S	et	f	\N
200215	pidan	?pidan =pidan  (SgN  >pidan !02_S	et	f	\N
200240	arvitidega	?arvitidega =iti  (PlKom  >arv+iti !16_S	et	f	\N
200244	arvuteid	arvuteid =arvute  (PlP  >arvuti !01_S	et	f	\N
199927	kingakotsiga	?kingakotsiga =kingakotsi  (SgKom  >kingakots !22_S	et	f	\N
199928	kingakotsiga	?kingakotsiga =kotsi  (SgKom  >kinga+kotsi !16_S	et	f	\N
199929	kingakotsiga	?kingakotsiga =kotsi  (SgKom  >kinga+kots !22_S	et	f	\N
199930	kingakotsiga	?kingakotsiga =akotsi  (SgKom  >king+akots !02_S	et	f	\N
199974	saalon	?saalon =saalon  (SgN  >saalon !02_S	et	f	\N
199981	signaliisasioon	?signaliisasioon =signaliisasioon  (SgN  >signaliisasioon !22_S	et	f	\N
199986	moodsus	moodsus =moodsus  (SgN  >moodsus !11~09_S	et	f	\N
199987	moodsus	"moodsus %moodsa  )US_aS  <moodne ;02_A	et	f	\N
199988	moodsus	"moodsus %moodse  )US_aS  <moodne ;02_A	et	f	\N
199996	kütusekulu	kütusekulu =kulu  (SgN  >kütuse+kulu !17_S	et	f	\N
199997	kütusekulu	kütusekulu =kulu  (SgG  >kütuse+kulu !17_S	et	f	\N
199998	kütusekulu	kütusekulu =kulu  (SgG  >kütuse+kulg !22_S	et	f	\N
199999	kütusekulu	kütusekulu =kulu  (SgP  >kütuse+kulu !17_S	et	f	\N
200000	tuseluuk	?tuseluuk =tuseluuk  (SgN  >tuseluuk !22_S	et	f	\N
200004	mugane	mugane =mugane  (IndPrPs_  >muganema !27_V	et	f	\N
200005	mugane	mugane =mugane  (ImpPrSg2  >muganema !27_V	et	f	\N
200019	kasutamisest	kasutamisest =kasutamise  (SgEl  >kasutamine !12_S	et	f	\N
200020	kasutamisest	"kasutamine %kasuta  )MINE_vS  <kasutama ;27_V	et	f	\N
200027	elektrilised	elektrilised =elektrilise  (PlN  >elektriline !12_A	et	f	\N
200028	elektrilised	"elektriline %elektri  )LINE_aA  <elekter ;02_S	et	f	\N
200039	halvakvaliteetiga	halvakvaliteetiga =iga  (SgN  >halva+kvaliteet+iga !18_S	et	f	\N
200040	halvakvaliteetiga	halvakvaliteetiga =iga  (SgP  >halva+kvaliteet+iga !18_S	et	f	\N
200046	puhasta	puhasta =puhasta  (IndPrPs_  >puhastama !27_V	et	f	\N
200047	puhasta	puhasta =puhasta  (ImpPrSg2  >puhastama !27_V	et	f	\N
200052	koristamiseks	koristamiseks =koristamise  (SgTr  >koristamine !12_S	et	f	\N
200053	koristamiseks	"koristamine %korista  )MINE_vS  <koristama ;27_V	et	f	\N
200062	toiteallikas	toiteallikas =allika  (SgIn  >toite+allikas !02_S	et	f	\N
200063	toiteallikas	toiteallikas =allikas  (SgN  >toite+allikas !02_S	et	f	\N
200069	katkestus	katkestus =katkestus  (SgN  >katkestus !11_S	et	f	\N
200070	katkestus	"katkestus %katkesta  )US_vS  <katkestama ;27_V	et	f	\N
200074	liivalaja	?liivalaja =liivalaja  (SgN  >liivalaja !01_S	et	f	\N
200075	liivalaja	?liivalaja =liivalaja  (SgG  >liivalaja !01_S	et	f	\N
200076	liivalaja	?liivalaja =liivalaja  (SgG  >liivalajas !02_A	et	f	\N
200077	liivalaja	?liivalaja =laja  (SgN  >liiva+laja !17_S	et	f	\N
200078	liivalaja	?liivalaja =laja  (SgG  >liiva+laja !17_S	et	f	\N
200079	liivalaja	?liivalaja =laja  (SgP  >liiva+laja !17_S	et	f	\N
200080	liivalaja	?liivalaja =alaja  (SgN  >liiv+alaja !01_S	et	f	\N
200081	liivalaja	?liivalaja =alaja  (SgG  >liiv+alaja !01_S	et	f	\N
200082	liivalaja	?liivalaja =alaja  (SgG  >liiv+alajas !02_A	et	f	\N
200100	polo	polo =polo  (SgN  >polo !17~16_S	et	f	\N
200101	polo	polo =polo  (SgG  >polo !17~16_S	et	f	\N
200102	polo	polo =polo  (SgP  >polo !17_S	et	f	\N
200106	vajatusel	vajatusel =vajatuse  (SgAd  >vajatus !11_S	et	f	\N
200107	vajatusel	"vajatus %vaja  )TUS1_aS  <vajama ;27_V	et	f	\N
200108	vajatusel	"vajatus %vaja  )TUS2_aS  <vaja ;17_S	et	f	\N
200127	ii-se	### ii-se	et	f	\N
200146	õnnestuski	õnnestuski =õnnestu  (IndIpfSg3^  >õnnestuma !27_V	et	f	\N
200147	õnnestuski	õnnestuski =õnnestus  (SgN^  >õnnestus !11_S	et	f	\N
200148	õnnestuski	"õnnestus %õnnesta  )US_vS^  <õnnestama ;27_V	et	f	\N
200149	brezhnevi	?brezhnevi =brezhnevi  (ID  >brezhnevi !41_D	et	f	\N
200150	brezhnevi	?brezhnevi =brezhnevi  (SgG  >brezhnev !02_A	et	f	\N
200163	lojaalsuses	lojaalsuses =lojaalsuse  (SgIn  >lojaalsus !11~09_S	et	f	\N
200164	lojaalsuses	"lojaalsus %lojaalse  )US_aS  <lojaalne ;02_A	et	f	\N
200170	näidusõite	?näidusõite =näidusõite  (PlP  >näidusõit !22_S	et	f	\N
200179	majandusel	majandusel =majanduse  (SgAd  >majandus !11_S	et	f	\N
200180	majandusel	"majandus %majanda  )US_vS  <majandama ;27_V	et	f	\N
200189	ettevõtlusest	ettevõtlusest =võtluse  (SgEl  >ette+võtlus !11~09_S	et	f	\N
200190	ettevõtlusest	ettevõtlusest =võtluses  (SgP  >ette+võtlusene !12_A	et	f	\N
200191	ettevõtlusest	"ette+võtlusene %võtluse  )NE_aA  <ette+võtlus ;09_S	et	f	\N
200192	ettevõtlusest	"ette+võtlusene %võtluse  )NE_aA  <ette+võtlus ;11_S	et	f	\N
200203	tsiviilehitus	tsiviilehitus =ehitu  (SgIn  >tsiviil+ehitu !01_AS	et	f	\N
200204	tsiviilehitus	tsiviilehitus =ehitus  (SgN  >tsiviil+ehitus !11_S	et	f	\N
200207	tähted	?tähted =tähte  (IndPrSg2  >tähtema !27_V	et	f	\N
200218	annelinna	?annelinna =annelinna  (SgN  >annelinna !16_S	et	f	\N
200219	annelinna	?annelinna =annelinna  (SgG  >annelinna !16_S	et	f	\N
200223	windowsi	?windowsi =windowsi  (SgN  >windowsi !01_S	et	f	\N
200224	windowsi	?windowsi =windowsi  (SgG  >windowsi !01_S	et	f	\N
200225	windowsi	?windowsi =windowsi  (SgG  >windows !22_S	et	f	\N
200226	windowsi	?windowsi =windowsi  (SgP  >windows !22_S	et	f	\N
200227	windowsi	?windowsi =windowsi  (SgAdt  >windows !22_S	et	f	\N
200246	kaasaegsede	?kaasaegsede =sede  (SgN  >kaas+aeg+sede !16_S	et	f	\N
200247	kaasaegsede	?kaasaegsede =sede  (SgG  >kaas+aeg+sede !16_S	et	f	\N
200253	sellepärest	?sellepärest =sellepäre  (PlEl  >sellepär !19_S	et	f	\N
200254	sellepärest	?sellepärest =sellepäres  (SgP  >sellepärene !12_A	et	f	\N
200160	natsionaliseerumine	?natsionaliseerumine =onaliseerumine  (PlP  >natsi+onaliseerumin !19_S	et	f	\N
200161	natsionaliseerumine	?natsionaliseerumine =ionaliseerumine  (SgN  >nats+ionaliseerumine !12_S	et	f	\N
200162	natsionaliseerumine	?natsionaliseerumine =ionaliseerumine  (PlP  >nats+ionaliseerumin !19_S	et	f	\N
200174	koolilt	koolilt =kooli  (SgAbl  >kool !22_S	et	f	\N
200175	koolilt	koolilt =kooli  (PlAbl  >kool !22_S	et	f	\N
200185	reaalkooli	reaalkooli =kooli  (SgG  >reaal+kool !22_S	et	f	\N
200186	reaalkooli	reaalkooli =kooli  (SgP  >reaal+kool !22_S	et	f	\N
200187	reaalkooli	reaalkooli =kooli  (SgAdt  >reaal+kool !22_S	et	f	\N
200188	reaalkooli	reaalkooli =kooli  (PlP  >reaal+kool !22_S	et	f	\N
200200	inseneri	inseneri =inseneri  (SgG  >insener !19_S	et	f	\N
200201	inseneri	inseneri =inseneri  (SgP  >insener !19_S	et	f	\N
200202	inseneri	inseneri =inseneri  (SgAdt  >insener !19_S	et	f	\N
200216	aktualne	?aktualne =aktualne  (SgN  >aktualne !02_A	et	f	\N
200217	aktualne	?aktualne =aktualne  (PlP  >aktualn !22_S	et	f	\N
200220	aastasel	aastasel =aastase  (SgAd  >aastane !12~10_A	et	f	\N
200221	aastasel	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
200237	naarvast	?naarvast =naarva  (SgEl  >naarva !01_S	et	f	\N
200238	naarvast	?naarvast =naarvas  (SgP  >naarvas !07_S	et	f	\N
200239	naarvast	?naarvast =naarvas  (SgP  >naarvane !12~10_A	et	f	\N
200262	semestr	?semestr =semestr  (SgN  >semestr !22_S	et	f	\N
200269	kikpoksi	?kikpoksi =kikpoksi  (SgN  >kikpoksi !01_S	et	f	\N
200270	kikpoksi	?kikpoksi =kikpoksi  (SgG  >kikpoksi !01_S	et	f	\N
200271	kikpoksi	?kikpoksi =kikpoksi  (IndPrPs_  >kikpoksima !28_V	et	f	\N
200272	kikpoksi	?kikpoksi =kikpoksi  (ImpPrSg2  >kikpoksima !28_V	et	f	\N
200277	viguga	?viguga =vigu  (SgKom  >vigu !17_S	et	f	\N
200278	finantsi	finantsi =finantsi  (SgG  >finants !22_S	et	f	\N
200279	finantsi	finantsi =finantsi  (SgP  >finants !22_S	et	f	\N
200280	finantsi	finantsi =finantsi  (SgAdt  >finants !22_S	et	f	\N
200282	kohtla-jarvelt	?kohtla-jarvelt =jarve  (SgAbl  >kohtla-jarve !06_S	et	f	\N
200283	kohtla-jarvelt	?kohtla-jarvelt =jarve  (PlAbl  >kohtla-jarv !22_S	et	f	\N
200284	kohtla-jarvelt	?kohtla-jarvelt =jarvelt  (ID  >kohtla-jarvelt !41_D	et	f	\N
200285	elektroenergetika	?elektroenergetika =elektroenergetika  (SgN  >elektroenergetika !01_S	et	f	\N
200286	elektroenergetika	?elektroenergetika =elektroenergetika  (SgG  >elektroenergetika !01_S	et	f	\N
200287	elektroenergetika	?elektroenergetika =elektroenergetika  (SgG  >elektroenergetikas !02_A	et	f	\N
200288	elektroenergetika	?elektroenergetika =energetika  (SgN  >elektro+energetika !01_S	et	f	\N
200289	elektroenergetika	?elektroenergetika =energetika  (SgG  >elektro+energetika !01_S	et	f	\N
200290	elektroenergetika	?elektroenergetika =energetika  (SgG  >elektro+energetikas !02_A	et	f	\N
200306	deklarerida	### deklarerida	et	f	\N
200307	sühtlesi	?sühtlesi =sühtlesi  (ID  >sühtlesi !41_D	et	f	\N
200308	sühtlesi	?sühtlesi =sühtlesi  (PlP  >sühtlene !12_A	et	f	\N
200309	praktida	?praktida =prakti  (Inf  >praktima !28_V	et	f	\N
200346	oskusede	oskusede =ede  (SgN  >oskus+ede !16_S	et	f	\N
200347	oskusede	oskusede =ede  (SgG  >oskus+ede !16_S	et	f	\N
200371	tudente	?tudente =tudente  (PlP  >tudent !22_S	et	f	\N
200390	tehnikaülikoolisse	tehnikaülikoolisse =kooli  (SgIll  >tehnika+üli+kool !22_S	et	f	\N
200391	tehnikaülikoolisse	tehnikaülikoolisse =kooli  (PlIll  >tehnika+üli+kool !22_S	et	f	\N
200403	majandusmatemaatika	majandusmatemaatika =matemaatika  (SgN  >majandus+matemaatika !01_S	et	f	\N
200405	majandusmatemaatika	majandusmatemaatika =matemaatika  (SgG  >majandus+matemaatika !01_S	et	f	\N
200464	humanitaargümnaasiumi	humanitaargümnaasiumi =gümnaasiumi  (SgG  >humanitaar+gümnaasium !19~02_S	et	f	\N
200465	humanitaargümnaasiumi	humanitaargümnaasiumi =gümnaasiumi  (SgP  >humanitaar+gümnaasium !19_S	et	f	\N
200466	humanitaargümnaasiumi	humanitaargümnaasiumi =gümnaasiumi  (SgAdt  >humanitaar+gümnaasium !19_S	et	f	\N
200469	majandusteaduskonda	majandusteaduskonda =teaduskonda  (SgP  >majandus+teaduskond !22_S	et	f	\N
200470	majandusteaduskonda	majandusteaduskonda =teaduskonda  (SgAdt  >majandus+teaduskond !22_S	et	f	\N
200471	ajutööd	ajutööd =töö  (PlN  >aju+töö !26_S	et	f	\N
200472	ajutööd	ajutööd =töö  (SgP  >aju+töö !26_S	et	f	\N
200500	vabakutselised	vabakutselised =kutselise  (PlN  >vaba+kutseline !12_A	et	f	\N
200501	vabakutselised	"vaba+kutseline %kutse  )LINE_aA  <vaba+kutse ;06_S	et	f	\N
200511	pidn	?pidn =pidn  (SgN  >pidn !22_S	et	f	\N
200518	lõuna-aafrika	?lõuna-aafrika =aafrika  (SgN  >lõuna-aafrika !01_S	et	f	\N
200519	lõuna-aafrika	?lõuna-aafrika =aafrika  (SgG  >lõuna-aafrika !01_S	et	f	\N
200520	lõuna-aafrika	?lõuna-aafrika =aafrika  (SgG  >lõuna-aafrikas !02_S	et	f	\N
200554	kättesaamisel	kättesaamisel =saamise  (SgAd  >kätte+saamine !12?10_S	et	f	\N
200555	kättesaamisel	"kätte+saamine %saami  )NE_aA  <kätte+saam ;22_S	et	f	\N
200573	murdas	?murdas =murda  (SgIn  >murda !16_S	et	f	\N
200574	murdas	?murdas =murda  (IndIpfSg3  >murdama !29_V	et	f	\N
200575	murdas	?murdas =murdas  (SgN  >murdas !07_S	et	f	\N
200590	seitsmest	seitsmest =seitsme  (SgEl  >seitse !05_N	et	f	\N
200591	seitsmest	seitsmest =seitsmes  (SgP  >seitsmene !12~10_A	et	f	\N
200592	seitsmest	"seitsmene %seitsme  )NE_aA  <seitse ;05_N	et	f	\N
200601	kolmekümene	?kolmekümene =kolmekümene  (SgN  >kolmekümene !12_A	et	f	\N
200194	õpitamiseks	?õpitamiseks =õpitamise  (SgTr  >õpitamine !12_S	et	f	\N
200195	õpitamiseks	?õpitamiseks =tamise  (SgTr  >õpi+tamine !10_A	et	f	\N
200205	proekteerida	?proekteerida =proekteeri  (Inf  >proekteerima !28_V	et	f	\N
200208	kiber-punk	?kiber-punk =punk  (SgN  >kiber-punk !22_S	et	f	\N
200222	organizerin	?organizerin =organizerin  (SgN  >organizerin !19_S	et	f	\N
200234	halvasi	?halvasi =halvasi  (ID  >halvasi !41_D	et	f	\N
200241	tehniliselt	tehniliselt =tehnilise  (SgAbl  >tehniline !12_A	et	f	\N
200242	tehniliselt	tehniliselt =tehniliselt  (ID  >tehniliselt !41_D	et	f	\N
200243	tehniliselt	"tehniliselt %tehnilise  )LT_mD  <tehniline ;12_A	et	f	\N
200248	üikool	?üikool =üikoo  (SgAd  >üikoo !26_S	et	f	\N
200249	üikool	?üikool =üikool  (SgN  >üikool !22_S	et	f	\N
200258	lihtsem	lihtsem =lihtsem  (SgN  >lihtsem !02_A	et	f	\N
200259	lihtsem	"lihtsem %lihtse  )M_cA  <lihtne ;02_A	et	f	\N
200263	üheksatest	üheksatest =üheksa  (PlEl  >üheksa !01_N	et	f	\N
200264	üheksatest	üheksatest =test  (SgN  >üheksa+test !22_S	et	f	\N
200265	üheksatest	üheksatest =ate  (PlEl  >üheks+att !22_S	et	f	\N
200275	tõsiline	?tõsiline =tõsiline  (SgN  >tõsiline !12_A	et	f	\N
200276	tõsiline	?tõsiline =tõsiline  (PlP  >tõsilin !19_S	et	f	\N
200293	institud	?institud =insti  (PtsPtIps  >instima !28_V	et	f	\N
200294	institud	?institud =institu  (PlN  >institu !01_AS	et	f	\N
200295	institud	?institud =institu  (IndPrSg2  >instituma !27_V	et	f	\N
200296	institud	?institud =institud  (ID  >institud !41_A	et	f	\N
200300	tasustatud	tasustatud =tasusta  (PtsPtIps  >tasustama !27_V	et	f	\N
200301	tasustatud	tasustatud =tasustatu  (PlN  >tasustatu !01_S	et	f	\N
200302	tasustatud	"tasustatu %tasusta  )TU1_vS  <tasustama ;27_V	et	f	\N
200303	tasustatud	tasustatud =tasustatud  (ID  >tasustatud !41_A	et	f	\N
200304	tasustatud	"tasustatud %tasusta  )TUD_vA  <tasustama ;27_V	et	f	\N
200310	süsteemtehnika	?süsteemtehnika =süsteemtehnika  (SgN  >süsteemtehnika !01_S	et	f	\N
200311	süsteemtehnika	?süsteemtehnika =süsteemtehnika  (SgG  >süsteemtehnika !01_S	et	f	\N
200312	süsteemtehnika	?süsteemtehnika =süsteemtehnika  (SgG  >süsteemtehnikas !02_A	et	f	\N
200316	inimestedega	### inimestedega	et	f	\N
200321	arienteeruda	?arienteeruda =arienteeru  (Inf  >arienteeruma !27_V	et	f	\N
200325	asjat	?asjat =asja  (SgP  >asjas !02_A	et	f	\N
200326	asjat	?asjat =asja  (SgP  >asja !16_S	et	f	\N
200327	asjat	?asjat =asjat  (SgN  >asjat !02_S	et	f	\N
200328	gümnasiumis	?gümnasiumis =gümnasiumi  (SgIn  >gümnasiumi !16_S	et	f	\N
200329	gümnasiumis	?gümnasiumis =gümnasiumi  (SgIn  >gümnasium !19_S	et	f	\N
200330	gümnasiumis	?gümnasiumis =gümnasiumi  (IndIpfSg3  >gümnasiumima !28_V	et	f	\N
200331	gümnasiumis	?gümnasiumis =gümnasiumis  (SgN  >gümnasiumis !09_S	et	f	\N
200339	tihnilise	?tihnilise =tihnilise  (SgG  >tihniline !12_A	et	f	\N
200342	õppemine	?õppemine =õppemine  (SgN  >õppemine !12_S	et	f	\N
200343	õppemine	?õppemine =õppemine  (PlP  >õppemin !19_S	et	f	\N
200361	ujumisega	ujumisega =ujumise  (SgKom  >ujumine !12_S	et	f	\N
200362	ujumisega	"ujumine %uju  )MINE_vS  <ujuma ;27_V	et	f	\N
200363	ujumisega	"ujumine %ujumi  )NE_aA  <ujum ;02_S	et	f	\N
200374	divisionis	?divisionis =divisioni  (SgIn  >divisioni !16_S	et	f	\N
200375	divisionis	?divisionis =divisioni  (SgIn  >division !19_S	et	f	\N
200376	divisionis	?divisionis =divisioni  (IndIpfSg3  >divisionima !28_V	et	f	\N
200377	divisionis	?divisionis =divisionis  (SgN  >divisionis !09_S	et	f	\N
200400	naudid	naudid =naudi  (PlN  >naud !22_S	et	f	\N
200401	naudid	naudid =naudi  (IndPrSg2  >nautima !28_V	et	f	\N
200407	näeratasime	?näeratasime =näerata  (IndIpfPl1  >näeratama !27_V	et	f	\N
200416	sooritud	sooritud =sooritu  (PlN  >sooritu !01_AS	et	f	\N
200417	sooritud	"sooritu %soori  )TU2_kA  <soor ;22_S	et	f	\N
200418	informatikasse	?informatikasse =informatika  (SgIll  >informatika !01_S	et	f	\N
200419	informatikasse	?informatikasse =informatika  (SgIll  >informatikas !02_A	et	f	\N
200420	informatikasse	?informatikasse =informatikas  (SgAdt  >informatikane !12_A	et	f	\N
200421	informatikasse	?informatikasse =informatikasse  (SgG  >informatikasne !02_A	et	f	\N
200422	informatikasse	?informatikasse =informatikasse  (PlP  >informatikass !22_S	et	f	\N
200440	kavatsesid	kavatsesid =kavatse  (IndIpfSg2  >kavatsema !27_V	et	f	\N
200441	kavatsesid	kavatsesid =kavatse  (IndIpfPl3  >kavatsema !27_V	et	f	\N
200445	jaba	?jaba =jaba  (SgN  >jaba !17_S	et	f	\N
200446	jaba	?jaba =jaba  (SgG  >jaba !17_S	et	f	\N
200447	jaba	?jaba =jaba  (SgP  >jaba !17_S	et	f	\N
200448	jaba	?jaba =jaba  (IndPrPs_  >jabama !27_V	et	f	\N
200449	jaba	?jaba =jaba  (ImpPrSg2  >jabama !27_V	et	f	\N
200450	imetlenud	imetlenud =imetle  (PtsPtPs  >imetlema !27_V	et	f	\N
200451	imetlenud	imetlenud =imetlenu  (PlN  >imetlenu !01_S	et	f	\N
200452	imetlenud	"imetlenu %imetle  )NU_vS  <imetlema ;27_V	et	f	\N
200453	imetlenud	imetlenud =imetlenud  (ID  >imetlenud !41_A	et	f	\N
200454	imetlenud	"imetlenud %imetle  )NUD_vA  <imetlema ;27_V	et	f	\N
200476	surepärased	?surepärased =surepärase  (PlN  >surepärane !12_A	et	f	\N
200486	iseravida	### iseravida	et	f	\N
200487	age	?age =age  (SgN  >age !16_S	et	f	\N
200488	age	?age =age  (SgG  >age !16_S	et	f	\N
200232	meldi	?meldi =meldi  (IndPrPs_  >meltima !28_V	et	f	\N
200233	meldi	?meldi =meldi  (ImpPrSg2  >meltima !28_V	et	f	\N
200235	päärit	?päärit =pääri  (SgP  >pääri !16_S	et	f	\N
200236	päärit	?päärit =päärit  (SgN  >päärit !02_S	et	f	\N
200250	gümnasiumit	?gümnasiumit =gümnasiumi  (SgP  >gümnasiumi !16_S	et	f	\N
200281	analütik	?analütik =analütik  (SgN  >analütik !02_S	et	f	\N
200313	lihtselt	lihtselt =lihtse  (SgAbl  >lihtne !02_A	et	f	\N
200314	lihtselt	lihtselt =lihtselt  (ID  >lihtselt !41_D	et	f	\N
200315	lihtselt	"lihtselt %lihtse  )LT_mD  <lihtne ;02_A	et	f	\N
200319	õpepäeval	?õpepäeval =õpepäeva  (SgAd  >õpepäeva !16_S	et	f	\N
200320	õpepäeval	?õpepäeval =õpepäeval  (SgN  >õpepäeval !02_S	et	f	\N
200344	spordihall	spordihall =hall  (SgN  >spordi+hall !22_S	et	f	\N
200345	spordihall	spordihall =hall  (SgN  >spordi+hall !22_AS	et	f	\N
200348	saksakeele	saksakeele =kee  (SgAll  >saksa+kesi !15_S	et	f	\N
200349	saksakeele	saksakeele =kee  (SgAll  >saksa+kee !26_S	et	f	\N
200350	saksakeele	saksakeele =keele  (SgG  >saksa+keel !13_S	et	f	\N
200356	tutvu	tutvu =tutvu  (IndPrPs_  >tutvuma !27_V	et	f	\N
200357	tutvu	tutvu =tutvu  (ImpPrSg2  >tutvuma !27_V	et	f	\N
200381	euroremontid	?euroremontid =remonti  (PlN  >euro+remonti !01_S	et	f	\N
200385	korpus	korpus =korpu  (IndIpfSg3  >korpuma !27_V	et	f	\N
200386	korpus	korpus =korpus  (SgN  >korpus !11~09_S	et	f	\N
200409	teadet	teadet =teade  (SgP  >teade !05_S	et	f	\N
200410	teadet	teadet =teade  (SgP  >teade !06_S	et	f	\N
200411	insenäär	?insenäär =insenäär  (SgN  >insenäär !22_S	et	f	\N
200426	informaatikasse	informaatikasse =informaatika  (SgIll  >informaatika !01_S	et	f	\N
200427	informaatikasse	informaatikasse =informaatikas  (SgAdt  >informaatikane !12_A	et	f	\N
200428	informaatikasse	"informaatikane %informaatika  )NE_aA  <informaatika ;01_S	et	f	\N
200429	reaalkool	reaalkool =koo  (SgAd  >reaal+kubu !18_S	et	f	\N
200430	reaalkool	reaalkool =kool  (SgN  >reaal+kool !22_S	et	f	\N
200431	bakalauri	?bakalauri =bakalauri  (SgN  >bakalauri !16_S	et	f	\N
200432	bakalauri	?bakalauri =bakalauri  (SgG  >bakalauri !16_S	et	f	\N
200433	bakalauri	?bakalauri =bakalauri  (SgG  >bakalaur !19_S	et	f	\N
200434	bakalauri	?bakalauri =bakalauri  (SgP  >bakalaur !19_S	et	f	\N
200435	bakalauri	?bakalauri =bakalauri  (SgAdt  >bakalaur !19_S	et	f	\N
200436	bakalauri	?bakalauri =bakalauri  (IndPrPs_  >bakalaurima !28_V	et	f	\N
200437	bakalauri	?bakalauri =bakalauri  (ImpPrSg2  >bakalaurima !28_V	et	f	\N
200438	asjav	?asjav =asja  (PtsPrPs  >asjama !29_V	et	f	\N
200439	asjav	?asjav =asjav  (SgN  >asjav !02_A	et	f	\N
200442	seltsivad	seltsivad =seltsi  (IndPrPl3  >seltsima !28_V	et	f	\N
200443	seltsivad	seltsivad =seltsiva  (PlN  >seltsiv !02_A	et	f	\N
200444	seltsivad	"seltsiv %seltsi  )V_vA  <seltsima ;28_V	et	f	\N
200455	ülikukoolis	?ülikukoolis =ülikukooli  (SgIn  >ülikukooli !16_S	et	f	\N
200456	ülikukoolis	?ülikukoolis =ülikukooli  (SgIn  >ülikukool !22_S	et	f	\N
200457	ülikukoolis	?ülikukoolis =ülikukooli  (IndIpfSg3  >ülikukoolima !28_V	et	f	\N
200458	ülikukoolis	?ülikukoolis =ülikukoolis  (SgN  >ülikukoolis !09_S	et	f	\N
200459	ülikukoolis	?ülikukoolis =kukooli  (SgIn  >üli+kukooli !16_S	et	f	\N
200460	ülikukoolis	?ülikukoolis =kukooli  (SgIn  >üli+kukool !22_S	et	f	\N
200461	ülikukoolis	?ülikukoolis =kukoolis  (SgN  >üli+kukoolis !09_S	et	f	\N
200475	programerida	### programerida	et	f	\N
200480	it-maja	it-maja =maja  (SgN  >it-maja !17_S	et	f	\N
200481	it-maja	it-maja =maja  (SgG  >it-maja !17_S	et	f	\N
200482	it-maja	it-maja =maja  (SgP  >it-maja !17_S	et	f	\N
200492	1997a	### 1997a	et	f	\N
200533	registreerunud	registreerunud =registreeru  (PtsPtPs  >registreeruma !27_V	et	f	\N
200534	registreerunud	registreerunud =registreerunu  (PlN  >registreerunu !01_S	et	f	\N
200535	registreerunud	"registreerunu %registreeru  )NU_vS  <registreeruma ;27_V	et	f	\N
200536	registreerunud	registreerunud =registreerunud  (ID  >registreerunud !41_A	et	f	\N
200537	registreerunud	"registreerunud %registreeru  )NUD_vA  <registreeruma ;27_V	et	f	\N
200564	liikuv	liikuv =liiku  (PtsPrPs  >liikuma !28_V	et	f	\N
200565	liikuv	liikuv =liikuv  (SgN  >liikuv !02_A	et	f	\N
200566	liikuv	"liikuv %liiku  )V_vA  <liikuma ;28_V	et	f	\N
200576	tagasihoidlikus	tagasihoidlikus =hoidliku  (SgIn  >tagasi+hoidlik !25_A	et	f	\N
200577	tagasihoidlikus	tagasihoidlikus =hoidlikus  (SgN  >tagasi+hoidlikus !11_S	et	f	\N
200578	tagasihoidlikus	"tagasi+hoidlikus %hoidliku  )US_aS  <tagasi+hoidlik ;25_A	et	f	\N
200600	londonas	### londonas	et	f	\N
200638	üheksakümene	?üheksakümene =üheksakümene  (SgN  >üheksakümene !12_A	et	f	\N
200639	üheksakümene	?üheksakümene =üheksakümene  (PlP  >üheksakümen !19_S	et	f	\N
200640	üheksakümene	?üheksakümene =kümene  (SgN  >üheksa+kümene !10_A	et	f	\N
200641	üheksakümene	?üheksakümene =akümene  (SgN  >üheks+akümene !12_A	et	f	\N
200642	üheksakümene	?üheksakümene =akümene  (PlP  >üheks+akümen !19_S	et	f	\N
200643	üheksakümene	?üheksakümene =ksakümene  (SgN  >ühe+ksakümene !12_A	et	f	\N
200644	üheksakümene	?üheksakümene =ksakümene  (PlP  >ühe+ksakümen !19_S	et	f	\N
200645	murdada	?murdada =ada  (SgN  >murd+ada !17_S	et	f	\N
200646	murdada	?murdada =ada  (SgG  >murd+ada !17_S	et	f	\N
200245	arvuteid	arvuteid =te  (PlP  >arvu+tee !26_S	et	f	\N
200251	politseinikuna	politseinikuna =politseiniku  (SgEs  >politseinik !25_S	et	f	\N
200252	politseinikuna	politseinikuna =politseiniku  (SgEs  >politseinik !02_S	et	f	\N
200260	kasaaegsed	?kasaaegsed =kasaaegse  (PlN  >kasaaegne !02_A	et	f	\N
200261	kasaaegsed	?kasaaegsed =aaegse  (PlN  >kas+aaegne !02_A	et	f	\N
200266	mino	?mino =mino  (SgN  >mino !17~16_S	et	f	\N
200267	mino	?mino =mino  (SgG  >mino !17~16_S	et	f	\N
200268	mino	?mino =mino  (SgP  >mino !17_S	et	f	\N
200291	elektroenergetik	?elektroenergetik =elektroenergetik  (SgN  >elektroenergetik !02_S	et	f	\N
200292	elektroenergetik	?elektroenergetik =energetik  (SgN  >elektro+energetik !02_S	et	f	\N
200317	oldino	?oldino =oldino  (SgN  >oldino !01_S	et	f	\N
200318	oldino	?oldino =oldino  (SgG  >oldino !01_S	et	f	\N
200322	hoonetes	hoonetes =hoone  (PlIn  >hoone !06_S	et	f	\N
200323	hoonetes	"hoone %hoo  )NE_aA  <hoog ;22_S	et	f	\N
200324	probleemit	?probleemit =probleemi  (SgP  >probleemi !16_S	et	f	\N
200332	gümnaasimi	?gümnaasimi =gümnaasimi  (SgG  >gümnaasim !02_A	et	f	\N
200333	elektroenergeetika	elektroenergeetika =energeetika  (SgN  >elektro+energeetika !01_S	et	f	\N
200334	elektroenergeetika	elektroenergeetika =energeetika  (SgG  >elektro+energeetika !01_S	et	f	\N
200340	kafees	?kafees =kafee  (SgIn  >kafee !26_S	et	f	\N
200341	kafees	?kafees =kafees  (SgN  >kafees !22_S	et	f	\N
200358	kick	?kick =kick  (SgN  >kick !22_S	et	f	\N
200372	õhutõrje	õhutõrje =tõrje  (SgN  >õhu+tõrje !06_S	et	f	\N
200373	õhutõrje	õhutõrje =tõrje  (SgG  >õhu+tõrje !06_S	et	f	\N
200382	saamodi	?saamodi =saamodi  (SgN  >saamodi !01_S	et	f	\N
200383	saamodi	?saamodi =saamodi  (SgG  >saamodi !01_S	et	f	\N
200384	saamodi	?saamodi =saamodi  (SgG  >saamod !02_S	et	f	\N
200387	lõpuõhtu	lõpuõhtu =õhtu  (SgN  >lõpu+õhtu !01_S	et	f	\N
200388	lõpuõhtu	lõpuõhtu =õhtu  (SgG  >lõpu+õhtu !01_S	et	f	\N
200389	filoologiks	### filoologiks	et	f	\N
200397	ttü-i	ttü-i =ttü  (SgG  >ttü !xx_Q	et	f	\N
200398	ttü-i	ttü-i =ttü  (SgP  >ttü !xx_Q	et	f	\N
200399	ttü-i	ttü-i =ttü  (SgAdt  >ttü !xx_Q	et	f	\N
200408	veetasime	?veetasime =veeta  (IndIpfPl1  >veetama !27_V	et	f	\N
200462	oodanut	oodanut =oodanu  (SgP  >oodanu !01_S	et	f	\N
200463	oodanut	"oodanu %ooda  )NU_vS  <ootama ;29_V	et	f	\N
200477	õppehoones	õppehoones =hoone  (SgIn  >õppe+hoone !06_S	et	f	\N
200478	õppehoones	"õppe+hoone %hoo  )NE_aA  <õppe+hoog ;22_S	et	f	\N
200479	õppehoones	õppehoones =hoone  (PlIn  >õppe+hoon !22_A	et	f	\N
200483	õppetajaga	?õppetajaga =õppetaja  (SgKom  >õppetaja !01_S	et	f	\N
200484	õppetajaga	?õppetajaga =õppetaja  (SgKom  >õppetajas !02_A	et	f	\N
200485	õppetajaga	?õppetajaga =taja  (SgKom  >õppe+taja !17_S	et	f	\N
200502	erenivates	?erenivates =ereniva  (PlIn  >ereniv !02_A	et	f	\N
200503	erenivates	?erenivates =erenivate  (PlIn  >erenivatt !22_S	et	f	\N
200504	erenivates	?erenivates =nivate  (PlIn  >ere+nivatt !22_S	et	f	\N
200507	etenduse	etenduse =etenduse  (SgG  >etendus !11_S	et	f	\N
200508	etenduse	"etendus %etenda  )US_vS  <etendama ;27_V	et	f	\N
200515	nemadel	?nemadel =nema  (PlAd  >nema !17_S	et	f	\N
200538	kontorist	kontorist =kontori  (SgEl  >kontor !02_S	et	f	\N
200539	kontorist	kontorist =kontorist  (SgN  >kontorist !22_S	et	f	\N
200540	kontorist	kontorist =rist  (SgN  >konto+rist !22_S	et	f	\N
200541	kontorist	kontorist =oris  (SgP  >kont+orine !10_A	et	f	\N
200542	kontorist	"kont+orine %ori  )NE_aA  <kont+ori ;24_S	et	f	\N
200556	lisaküsimustele	lisaküsimustele =muste  (PlAll  >lisa+küsi+must !22_AS	et	f	\N
200557	lisaküsimustele	lisaküsimustele =küsimus  (PlAll  >lisa+küsimus !11_S	et	f	\N
200558	virtuaalkodu	?virtuaalkodu =virtuaalkodu  (IndPrPs_  >virtuaalkoduma !27_V	et	f	\N
200559	virtuaalkodu	?virtuaalkodu =virtuaalkodu  (ImpPrSg2  >virtuaalkoduma !27_V	et	f	\N
200571	teatride	### teatride	et	f	\N
200572	noordega	### noordega	et	f	\N
200579	lõuna-aafrikas	?lõuna-aafrikas =aafrika  (SgIn  >lõuna-aafrika !01_S	et	f	\N
200580	lõuna-aafrikas	?lõuna-aafrikas =aafrika  (SgIn  >lõuna-aafrikas !02_S	et	f	\N
200581	lõuna-aafrikas	?lõuna-aafrikas =aafrikas  (SgN  >lõuna-aafrikas !02_S	et	f	\N
200661	astast	?astast =asta  (SgEl  >asta !16_S	et	f	\N
200662	astast	?astast =astas  (SgP  >astas !07_S	et	f	\N
200663	astast	?astast =astas  (SgP  >astane !12~10_A	et	f	\N
200687	ühekümne	?ühekümne =ühekümne  (SgN  >ühekümne !02_A	et	f	\N
200688	ühekümne	?ühekümne =ühekümne  (PlP  >ühekümn !22_S	et	f	\N
200689	ühekümne	?ühekümne =kümne  (SgN  >ühe+kümne !02_A	et	f	\N
200690	ühekümne	?ühekümne =kümne  (PlP  >ühe+kümn !22_S	et	f	\N
200691	teatrised	?teatrised =teatrise  (PlN  >teatris !09_S	et	f	\N
200692	teatrised	?teatrised =teatrise  (IndPrSg2  >teatrisema !27_V	et	f	\N
200698	tagasihoidlus	tagasihoidlus =hoidlus  (SgN  >tagasi+hoidlus !11~09_S	et	f	\N
200699	tagasihoidlus	"tagasi+hoidlus %hoidlase  )US_aS  <tagasi+hoidlane ;12_S	et	f	\N
200707	üheksakümme	?üheksakümme =üheksakümme  (PlP  >üheksakümm !22_S	et	f	\N
200708	üheksakümme	?üheksakümme =kümme  (PlP  >üheksa+kümm !22_S	et	f	\N
200709	üheksakümme	?üheksakümme =akümme  (PlP  >üheks+akümm !22_S	et	f	\N
200255	sellepärest	?sellepärest =päre  (SgEl  >selle+päre !16_S	et	f	\N
200256	sellepärest	?sellepärest =päres  (SgP  >selle+päres !09_S	et	f	\N
200257	sellepärest	?sellepärest =päres  (SgP  >selle+pärene !10_A	et	f	\N
200273	algsin	?algsin =algsi  (IndPrSg1  >algsima !28_V	et	f	\N
200274	algsin	?algsin =algsin  (SgN  >algsin !02_S	et	f	\N
200297	elektroenergetiks	?elektroenergetiks =elektroenergeti  (SgTr  >elektroenergett !22_S	et	f	\N
200298	elektroenergetiks	?elektroenergetiks =elektroenergeti  (KndPrPs  >elektroenergettima !28_V	et	f	\N
200299	elektroenergetiks	?elektroenergetiks =energeti  (SgTr  >elektro+energett !22_S	et	f	\N
200305	simester	?simester =simester  (SgN  >simester !02_S	et	f	\N
200335	aaru	?aaru =aaru  (SgN  >aaru !16_S	et	f	\N
200336	aaru	?aaru =aaru  (SgG  >aaru !16_S	et	f	\N
200337	aaru	?aaru =aaru  (IndPrPs_  >aaruma !27_V	et	f	\N
200338	aaru	?aaru =aaru  (ImpPrSg2  >aaruma !27_V	et	f	\N
200351	klappinud	klappinud =klappi  (PtsPtPs  >klappima !28_V	et	f	\N
200352	klappinud	klappinud =klappinu  (PlN  >klappinu !01_S	et	f	\N
200353	klappinud	"klappinu %klappi  )NU_vS  <klappima ;28_V	et	f	\N
200354	klappinud	klappinud =klappinud  (ID  >klappinud !41_A	et	f	\N
200355	klappinud	"klappinud %klappi  )NUD_vA  <klappima ;28_V	et	f	\N
200359	boksinguga	?boksinguga =boksingu  (SgKom  >boksingu !01_S	et	f	\N
200360	boksinguga	?boksinguga =boksingu  (SgKom  >boksing !02_S	et	f	\N
200364	räkima	?räkima =räki  (Sup  >räkima !27_V	et	f	\N
200365	räkima	?räkima =räkima  (SgG  >räkim !02_A	et	f	\N
200366	politseinikuks	politseinikuks =politseiniku  (SgTr  >politseinik !25_S	et	f	\N
200367	politseinikuks	politseinikuks =politseiniku  (SgTr  >politseinik !02_S	et	f	\N
200368	valeksin	?valeksin =vale  (KndPrSg1  >valema !27_V	et	f	\N
200369	valeksin	?valeksin =valeksi  (IndPrSg1  >valeksima !28_V	et	f	\N
200370	valeksin	?valeksin =valeksin  (SgN  >valeksin !19_S	et	f	\N
200378	dembel	?dembel =dembe  (SgAd  >demme !06_S	et	f	\N
200379	dembel	?dembel =dembe  (PlAd  >demp !22_S	et	f	\N
200380	dembel	?dembel =dembel  (SgN  >dembel !02_S	et	f	\N
200392	huvitunud	huvitunud =huvitu  (PtsPtPs  >huvituma !27_V	et	f	\N
200393	huvitunud	huvitunud =huvitunu  (PlN  >huvitunu !01_S	et	f	\N
200394	huvitunud	"huvitunu %huvitu  )NU_vS  <huvituma ;27_V	et	f	\N
200395	huvitunud	huvitunud =huvitunud  (ID  >huvitunud !41_A	et	f	\N
200396	huvitunud	"huvitunud %huvitu  )NUD_vA  <huvituma ;27_V	et	f	\N
200402	mikroökonoomika	mikroökonoomika =ökonoomika  (SgN  >mikro+ökonoomika !01_S	et	f	\N
200404	mikroökonoomika	mikroökonoomika =ökonoomika  (SgG  >mikro+ökonoomika !01_S	et	f	\N
200406	loobutasime	?loobutasime =loobuta  (IndIpfPl1  >loobutama !27_V	et	f	\N
200412	elektropriikooli	elektropriikooli =kooli  (SgG  >elektro+prii+kool !22_S	et	f	\N
200413	elektropriikooli	elektropriikooli =kooli  (SgP  >elektro+prii+kool !22_S	et	f	\N
200414	elektropriikooli	elektropriikooli =kooli  (SgAdt  >elektro+prii+kool !22_S	et	f	\N
200415	elektropriikooli	elektropriikooli =kooli  (PlP  >elektro+prii+kool !22_S	et	f	\N
200423	süsteemitehnikasse	süsteemitehnikasse =tehnika  (SgIll  >süsteemi+tehnika !01_S	et	f	\N
200424	süsteemitehnikasse	süsteemitehnikasse =tehnikas  (SgAdt  >süsteemi+tehnikane !12_A	et	f	\N
200425	süsteemitehnikasse	"süsteemi+tehnikane %tehnika  )NE_aA  <süsteemi+tehnika ;01_S	et	f	\N
200467	kunstrahaga	kunstrahaga =raha  (SgKom  >kunst+raha !17_S	et	f	\N
200468	kunstrahaga	kunstrahaga =raha  (SgKom  >kunst+rahk !22_S	et	f	\N
200473	kahtest	?kahtest =kahtes  (SgP  >kahtes !09_S	et	f	\N
200474	kahtest	?kahtest =kahtes  (SgP  >kahtene !12~10_A	et	f	\N
200491	edur	?edur =edur  (SgN  >edur !02_S	et	f	\N
200493	üheksaseitsmes	?üheksaseitsmes =itsme  (SgIn  >üheks+ase+itsme !06_S	et	f	\N
200494	üheksaseitsmes	?üheksaseitsmes =itsme  (PlIn  >üheks+ase+itsm !22_S	et	f	\N
200495	üheksaseitsmes	?üheksaseitsmes =itsmes  (SgN  >üheks+ase+itsmes !09_S	et	f	\N
200496	üheksaseitsmes	?üheksaseitsmes =seitsme  (SgIn  >üheksa+seitsme !06_S	et	f	\N
200497	üheksaseitsmes	?üheksaseitsmes =seitsme  (PlIn  >üheksa+seitsm !22_S	et	f	\N
200498	üheksaseitsmes	?üheksaseitsmes =aseitsme  (PlIn  >üheks+aseitsm !22_S	et	f	\N
200499	üheksaseitsmes	?üheksaseitsmes =ksaseitsme  (PlIn  >ühe+ksaseitsm !22_S	et	f	\N
200512	paaris	paaris =paari  (SgIn  >paar !22_NS	et	f	\N
200513	paaris	paaris =paari  (IndIpfSg3  >paarima !28_V	et	f	\N
200514	paaris	paaris =paaris  (ID  >paaris !41_DA	et	f	\N
200516	tagasihoidlikult	tagasihoidlikult =hoidliku  (SgAbl  >tagasi+hoidlik !25_A	et	f	\N
200517	tagasihoidlikult	"tagasi+hoidlikult %hoidliku  )LT_mD  <tagasi+hoidlik ;25_A	et	f	\N
200529	tarkust	tarkust =tarkus  (SgP  >tarkus !11~09_S	et	f	\N
200530	tarkust	"tarkus %tark  )US_aS  <tark ;22_AS	et	f	\N
200531	tarkust	tarkust =tarkus  (SgP  >tarkune !12~10_A	et	f	\N
200532	tarkust	tarkust =us  (SgP  >tark+uks !14_S	et	f	\N
200546	postiasutusest	postiasutusest =asutuse  (SgEl  >posti+asutus !11_S	et	f	\N
200547	postiasutusest	"posti+asutus %asu  )TUS2_aS  <posti+asu ;17_S	et	f	\N
200548	postiasutusest	postiasutusest =asutuses  (SgP  >posti+asutusene !12_A	et	f	\N
200549	postiasutusest	"posti+asutusene %asutuse  )NE_aA  <posti+asutus ;11_S	et	f	\N
200552	tasud	tasud =tasu  (PlN  >tasu !17_S	et	f	\N
200553	tasud	tasud =tasu  (IndPrSg2  >tasuma !27_V	et	f	\N
200489	age	?age =age  (IndPrPs_  >agema !27_V	et	f	\N
200490	age	?age =age  (ImpPrSg2  >agema !27_V	et	f	\N
200505	agel	?agel =age  (SgAd  >age !16_S	et	f	\N
200506	agel	?agel =agel  (SgN  >agel !02_S	et	f	\N
200509	jalaluu	jalaluu =luu  (SgN  >jala+luu !26_S	et	f	\N
200510	jalaluu	jalaluu =luu  (SgG  >jala+luu !26_S	et	f	\N
200521	lõuna-aafrikasse	?lõuna-aafrikasse =aafrika  (SgIll  >lõuna-aafrika !01_S	et	f	\N
200522	lõuna-aafrikasse	?lõuna-aafrikasse =aafrika  (SgIll  >lõuna-aafrikas !02_S	et	f	\N
200523	lõuna-aafrikasse	?lõuna-aafrikasse =aafrikas  (SgAdt  >lõuna-aafrikane !12_A	et	f	\N
200524	lõuna-aafrikasse	?lõuna-aafrikasse =aafrikasse  (SgG  >lõuna-aafrikasne !02_A	et	f	\N
200525	lõuna-aafrikasse	?lõuna-aafrikasse =aafrikasse  (PlP  >lõuna-aafrikass !22_S	et	f	\N
200526	eelise	eelise =eelise  (SgG  >eelis !09_S	et	f	\N
200527	eelise	eelise =eelise  (SgG  >eeline !10_A	et	f	\N
200528	eelise	"eeline %ee  )LINE_aA  <esi ;15_S	et	f	\N
200543	lähimast	lähimast =lähima  (SgEl  >lähim !02_A	et	f	\N
200544	lähimast	"lähim %lähi  )IM_sA  <lähike ;12_A	et	f	\N
200545	lähimast	lähimast =mast  (SgN  >lähi+mast !22_S	et	f	\N
200550	helikasseti	helikasseti =seti  (SgG  >heli+kas+sett !22_S	et	f	\N
200551	helikasseti	helikasseti =kasseti  (SgG  >heli+kassett !22_S	et	f	\N
200560	sobid	sobid =sobi  (PlN  >sobi !17_S	et	f	\N
200561	sobid	sobid =sobi  (IndPrSg2  >sobima !27_V	et	f	\N
200567	kolmküne	?kolmküne =küne  (SgN  >kolm+küne !16_S	et	f	\N
200568	kolmküne	?kolmküne =küne  (SgG  >kolm+küne !16_S	et	f	\N
200569	seitsmiselt	?seitsmiselt =seitsmise  (SgAbl  >seitsmine !12?10_A	et	f	\N
200570	seitsmiselt	?seitsmiselt =seitsmiselt  (ID  >seitsmiselt !41_D	et	f	\N
200597	lõuna-aafrikal	?lõuna-aafrikal =aafrika  (SgAd  >lõuna-aafrika !01_S	et	f	\N
200598	lõuna-aafrikal	?lõuna-aafrikal =aafrika  (SgAd  >lõuna-aafrikas !02_S	et	f	\N
200599	lõuna-aafrikal	?lõuna-aafrikal =aafrikal  (SgN  >lõuna-aafrikal !19_S	et	f	\N
200612	planeerivad	planeerivad =planeeri  (IndPrPl3  >planeerima !28_V	et	f	\N
200613	planeerivad	planeerivad =planeeriva  (PlN  >planeeriv !02_A	et	f	\N
200614	planeerivad	"planeeriv %planeeri  )V_vA  <planeerima ;28_V	et	f	\N
200651	kümnane	?kümnane =kümnane  (SgN  >kümnane !10_A	et	f	\N
200652	kümnane	?kümnane =kümnane  (IndPrPs_  >kümnanema !27_V	et	f	\N
200653	kümnane	?kümnane =kümnane  (ImpPrSg2  >kümnanema !27_V	et	f	\N
200655	vabakutselinevad	?vabakutselinevad =vabakutselineva  (PlN  >vabakutselinev !02_A	et	f	\N
200656	vabakutselinevad	?vabakutselinevad =vabakutselineva  (PlN  >vabakutselineva !16_S	et	f	\N
200657	vabakutselinevad	?vabakutselinevad =lineva  (PlN  >vaba+kutse+lineva !01_S	et	f	\N
200658	vabakutselinevad	?vabakutselinevad =lineva  (PlN  >vaba+kutse+linev !02_A	et	f	\N
200659	vabakutselinevad	?vabakutselinevad =kutselineva  (PlN  >vaba+kutselinev !02_A	et	f	\N
200660	vabakutselinevad	?vabakutselinevad =kutselineva  (PlN  >vaba+kutselineva !16_S	et	f	\N
200664	erinevades	?erinevades =erineva  (PlIn  >erineva !16_S	et	f	\N
200665	erinevades	?erinevades =neva  (PlIn  >eri+neva !17_S	et	f	\N
200666	suhtumad	?suhtumad =suhtuma  (PlN  >suhtum !02_A	et	f	\N
200667	suhtumad	?suhtumad =uma  (PlN  >suht+uma !17_S	et	f	\N
200668	murdnud	murdnud =murd  (PtsPtPs  >murdma !34_V	et	f	\N
200669	murdnud	murdnud =murdnu  (PlN  >murdnu !01_S	et	f	\N
200670	murdnud	"murdnu %murd  )NU_vS  <murdma ;34_V	et	f	\N
200671	murdnud	murdnud =murdnud  (ID  >murdnud !41_A	et	f	\N
200672	murdnud	"murdnud %murd  )NUD_vA  <murdma ;34_V	et	f	\N
200674	kolmekümnane	?kolmekümnane =kolmekümnane  (SgN  >kolmekümnane !12_A	et	f	\N
200675	kolmekümnane	?kolmekümnane =kümnane  (SgN  >kolme+kümnane !10_A	et	f	\N
200676	kolmekümnane	?kolmekümnane =ekümnane  (SgN  >kolm+ekümnane !12_A	et	f	\N
200677	kolmekümnane	?kolmekümnane =ekümnane  (PlP  >kolm+ekümnan !19_S	et	f	\N
200725	plaaneritud	plaaneritud =plaaneritu  (PlN  >plaaneritu !01_A	et	f	\N
200726	plaaneritud	"plaaneritu %plaaneri  )TU2_kA  <plaaner ;02_S	et	f	\N
200745	noordetest	?noordetest =noorde  (PlEl  >noorde !06_S	et	f	\N
200746	noordetest	?noordetest =noordete  (PlEl  >noordett !22_S	et	f	\N
200747	noordetest	?noordetest =noordetes  (SgP  >noordetene !12_A	et	f	\N
200748	noordetest	?noordetest =dete  (PlEl  >noor+dett !22_S	et	f	\N
200749	noordetest	?noordetest =detes  (SgP  >noor+detes !09_S	et	f	\N
200750	noordetest	?noordetest =detes  (SgP  >noor+detene !10_A	et	f	\N
200765	tervisiga	tervisiga =iga  (SgN  >tervis+iga !18_S	et	f	\N
200766	tervisiga	tervisiga =iga  (SgP  >tervis+iga !18_S	et	f	\N
200773	nooret	?nooret =noore  (SgP  >noore !06_S	et	f	\N
200774	kümmendseitse	?kümmendseitse =kümmendseitse  (SgG  >kümmendseitne !02_A	et	f	\N
200775	kümmendseitse	?kümmendseitse =kümmendseitse  (PlP  >kümmendseits !22_S	et	f	\N
200776	kümmendseitse	?kümmendseitse =kümmendseitse  (IndPrPs_  >kümmendseitsema !27_V	et	f	\N
200777	kümmendseitse	?kümmendseitse =kümmendseitse  (ImpPrSg2  >kümmendseitsema !27_V	et	f	\N
200780	murdsib	?murdsib =murdsi  (IndPrSg3  >murdsima !28_V	et	f	\N
200785	vabakutselist	vabakutselist =kutselis  (SgP  >vaba+kutseline !12_A	et	f	\N
200786	vabakutselist	"vaba+kutseline %kutse  )LINE_aA  <vaba+kutse ;06_S	et	f	\N
200813	kolmküment	?kolmküment =kolmküment  (SgN  >kolmküment !22_S	et	f	\N
200562	vabanduse	vabanduse =vabanduse  (SgG  >vabandus !11_S	et	f	\N
200563	vabanduse	"vabandus %vabanda  )US_vS  <vabandama ;27_V	et	f	\N
200582	üheksakumne	?üheksakumne =üheksakumne  (SgN  >üheksakumne !02_A	et	f	\N
200583	üheksakumne	?üheksakumne =üheksakumne  (PlP  >üheksakumn !22_S	et	f	\N
200584	üheksakumne	?üheksakumne =kumne  (SgN  >üheksa+kumne !02_A	et	f	\N
200585	üheksakumne	?üheksakumne =kumne  (PlP  >üheksa+kumn !22_S	et	f	\N
200586	üheksakumne	?üheksakumne =akumne  (SgN  >üheks+akumne !02_A	et	f	\N
200587	üheksakumne	?üheksakumne =akumne  (PlP  >üheks+akumn !22_S	et	f	\N
200588	üheksakumne	?üheksakumne =ksakumne  (SgN  >ühe+ksakumne !02_A	et	f	\N
200589	üheksakumne	?üheksakumne =ksakumne  (PlP  >ühe+ksakumn !22_S	et	f	\N
200593	teatre	?teatre =teatre  (SgN  >teatre !06_S	et	f	\N
200594	teatre	?teatre =teatre  (SgG  >teatre !06_S	et	f	\N
200595	teatre	?teatre =teatre  (IndPrPs_  >teatrema !27_V	et	f	\N
200596	teatre	?teatre =teatre  (ImpPrSg2  >teatrema !27_V	et	f	\N
200606	tuhate	?tuhate =tuha  (IndPrPl2  >tuhama !27_V	et	f	\N
200607	vabakutselivad	?vabakutselivad =vabakutseliva  (PlN  >vabakutseliv !02_A	et	f	\N
200608	vabakutselivad	?vabakutselivad =vabakutseliva  (PlN  >vabakutseliva !16_S	et	f	\N
200609	vabakutselivad	?vabakutselivad =liva  (PlN  >vaba+kutse+liva !17_S	et	f	\N
200610	vabakutselivad	?vabakutselivad =kutseliva  (PlN  >vaba+kutseliv !02_A	et	f	\N
200611	vabakutselivad	?vabakutselivad =kutseliva  (PlN  >vaba+kutseliva !16_S	et	f	\N
200621	lõuna-aafrikale	?lõuna-aafrikale =aafrika  (SgAll  >lõuna-aafrika !01_S	et	f	\N
200622	lõuna-aafrikale	?lõuna-aafrikale =aafrika  (SgAll  >lõuna-aafrikas !02_S	et	f	\N
200623	lõuna-aafrikale	?lõuna-aafrikale =aafrikale  (PlP  >lõuna-aafrikal !19_S	et	f	\N
200624	noordele	?noordele =noorde  (PlAll  >noort !22_S	et	f	\N
200625	noordele	?noordele =noordele  (IndPrPs_  >noordelema !31~27_V	et	f	\N
200626	noordele	?noordele =noordele  (ImpPrSg2  >noordelema !31~27_V	et	f	\N
200627	etenduses	etenduses =etenduse  (SgIn  >etendus !11_S	et	f	\N
200628	etenduses	"etendus %etenda  )US_vS  <etendama ;27_V	et	f	\N
200629	kolmkümme	?kolmkümme =kolmkümme  (PlP  >kolmkümm !22_S	et	f	\N
200630	kolmkümme	?kolmkümme =kümme  (PlP  >kolm+kümm !22_S	et	f	\N
200634	nooredest	nooredest =ede  (SgEl  >noor+ede !16_S	et	f	\N
200635	nooredest	nooredest =edes  (SgP  >noor+edene !10_A	et	f	\N
200636	nooredest	"noor+edene %ede  )NE_aA  <noor+ede ;16_S	et	f	\N
200637	seitsemst	?seitsemst =seitsemst  (SgN  >seitsemst !22_S	et	f	\N
200678	üheksesaja	?üheksesaja =üheksesaja  (SgN  >üheksesaja !01_S	et	f	\N
200679	üheksesaja	?üheksesaja =üheksesaja  (SgG  >üheksesaja !01_S	et	f	\N
200680	üheksesaja	?üheksesaja =üheksesaja  (SgG  >üheksesajas !02_A	et	f	\N
200681	üheksesaja	?üheksesaja =esaja  (SgN  >üheks+esaja !01_S	et	f	\N
200682	üheksesaja	?üheksesaja =esaja  (SgG  >üheks+esaja !01_S	et	f	\N
200683	üheksesaja	?üheksesaja =esaja  (SgG  >üheks+esajas !02_A	et	f	\N
200684	üheksesaja	?üheksesaja =ksesaja  (SgN  >ühe+ksesaja !01_S	et	f	\N
200685	üheksesaja	?üheksesaja =ksesaja  (SgG  >ühe+ksesaja !01_S	et	f	\N
200686	üheksesaja	?üheksesaja =ksesaja  (SgG  >ühe+ksesajas !02_A	et	f	\N
200700	päevasel	päevasel =päevase  (SgAd  >päevane !10_A	et	f	\N
200701	päevasel	"päevane %päeva  )NE_aA  <päev ;22_S	et	f	\N
200723	murdsid	murdsid =murd  (IndIpfSg2  >murdma !34_V	et	f	\N
200724	murdsid	murdsid =murd  (IndIpfPl3  >murdma !34_V	et	f	\N
200739	kolmekümnekaks	?kolmekümnekaks =kolmekümneka  (SgTr  >kolmekümnekas !02_A	et	f	\N
200740	kolmekümnekaks	?kolmekümnekaks =kolmekümneka  (SgTr  >kolmekümneka !16_S	et	f	\N
200741	kolmekümnekaks	?kolmekümnekaks =kümneka  (SgTr  >kolme+kümneka !01_S	et	f	\N
200742	kolmekümnekaks	?kolmekümnekaks =kümneka  (SgTr  >kolme+kümnekas !02_A	et	f	\N
200743	kolmekümnekaks	?kolmekümnekaks =ekümneka  (SgTr  >kolm+ekümnekas !02_A	et	f	\N
200744	kolmekümnekaks	?kolmekümnekaks =ekümneka  (SgTr  >kolm+ekümneka !16_S	et	f	\N
200763	seitseni	?seitseni =seitse  (SgTer  >seitne !02_A	et	f	\N
200764	seitseni	?seitseni =seitseni  (SgG  >seitsen !02_S	et	f	\N
200770	lõuna-aafris	?lõuna-aafris =aafri  (SgIn  >lõuna-aafr !22_S	et	f	\N
200771	lõuna-aafris	?lõuna-aafris =aafri  (IndIpfSg3  >lõuna-aafrima !28_V	et	f	\N
200772	lõuna-aafris	?lõuna-aafris =aafris  (SgN  >lõuna-aafris !09_S	et	f	\N
200781	etendusest	etendusest =etenduse  (SgEl  >etendus !11_S	et	f	\N
200782	etendusest	"etendus %etenda  )US_vS  <etendama ;27_V	et	f	\N
200783	etendusest	etendusest =etenduses  (SgP  >etendusene !12_A	et	f	\N
200784	etendusest	"etendusene %etenduse  )NE_aA  <etendus ;11_S	et	f	\N
200792	tansima	?tansima =tansi  (Sup  >tansima !28_V	et	f	\N
200793	tansima	?tansima =tansima  (SgG  >tansim !02_A	et	f	\N
200794	paremi	paremi =paremi  (SgG  >parem !02_A	et	f	\N
200795	paremi	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
200796	teadreid	?teadreid =teadre  (PlP  >teader !02_S	et	f	\N
200797	teadreid	?teadreid =teadre  (PlP  >teadre !06_S	et	f	\N
200798	teadreid	?teadreid =teadrei  (PlN  >teadrei !26_S	et	f	\N
200799	teadreid	?teadreid =teadrei  (SgP  >teadrei !26_S	et	f	\N
200800	teadreid	?teadreid =teadreid  (SgN  >teadreid !22_S	et	f	\N
200805	nooreid	?nooreid =noore  (PlP  >noore !06_S	et	f	\N
200806	nooreid	?nooreid =noorei  (PlN  >noorei !26_S	et	f	\N
200602	kolmekümene	?kolmekümene =kolmekümene  (PlP  >kolmekümen !19_S	et	f	\N
200603	kolmekümene	?kolmekümene =kümene  (SgN  >kolme+kümene !10_A	et	f	\N
200604	kolmekümene	?kolmekümene =ekümene  (SgN  >kolm+ekümene !12_A	et	f	\N
200605	kolmekümene	?kolmekümene =ekümene  (PlP  >kolm+ekümen !19_S	et	f	\N
200615	parevad	?parevad =pare  (IndPrPl3  >parema !27_V	et	f	\N
200616	parevad	?parevad =pareva  (PlN  >pareva !01_S	et	f	\N
200617	parevad	?parevad =pareva  (PlN  >parev !02_A	et	f	\N
200618	lõunas-aafrikas	?lõunas-aafrikas =aafrika  (SgIn  >lõunas-aafrika !01_S	et	f	\N
200619	lõunas-aafrikas	?lõunas-aafrikas =aafrika  (SgIn  >lõunas-aafrikas !02_S	et	f	\N
200620	lõunas-aafrikas	?lõunas-aafrikas =aafrikas  (SgN  >lõunas-aafrikas !02_S	et	f	\N
200631	seitsel	?seitsel =seitse  (SgAd  >seitne !02_A	et	f	\N
200632	seitsel	?seitsel =seitse  (PlAd  >seits !22_S	et	f	\N
200633	seitsel	?seitsel =seitsel  (SgN  >seitsel !02_S	et	f	\N
200695	murdned	?murdned =murdne  (IndPrSg2  >murdnema !27_V	et	f	\N
200696	pidatakse	?pidatakse =pidatakse  (SgG  >pidatakne !02_A	et	f	\N
200697	pidatakse	?pidatakse =pidatakse  (PlP  >pidataks !22_S	et	f	\N
200702	kolmekümmne	?kolmekümmne =kolmekümmne  (SgN  >kolmekümmne !02_A	et	f	\N
200703	kolmekümmne	?kolmekümmne =kümmne  (SgN  >kolme+kümmne !02_A	et	f	\N
200704	kolmekümmne	?kolmekümmne =kümmne  (PlP  >kolme+kümmn !22_S	et	f	\N
200705	kolmekümmne	?kolmekümmne =ekümmne  (SgN  >kolm+ekümmne !02_A	et	f	\N
200706	kolmekümmne	?kolmekümmne =ekümmne  (PlP  >kolm+ekümmn !22_S	et	f	\N
200721	armastakse	?armastakse =armastakse  (SgG  >armastakne !02_A	et	f	\N
200722	armastakse	?armastakse =armastakse  (PlP  >armastaks !22_S	et	f	\N
200733	vabakutseliste	vabakutseliste =kutselis  (PlG  >vaba+kutseline !12_A	et	f	\N
200734	vabakutseliste	"vaba+kutseline %kutse  )LINE_aA  <vaba+kutse ;06_S	et	f	\N
200757	kümmand	?kümmand =kümmand  (SgN  >kümmand !02_S	et	f	\N
200762	erinevatedes	### erinevatedes	et	f	\N
200787	suheldud	suheldud =suhel  (PtsPtIps  >suhtlema !30_V	et	f	\N
200788	suheldud	suheldud =suheldu  (PlN  >suheldu !01_S	et	f	\N
200789	suheldud	"suheldu %suhel  )TU1_vS  <suhtlema ;30_V	et	f	\N
200790	suheldud	suheldud =suheldud  (ID  >suheldud !41_A	et	f	\N
200791	suheldud	"suheldud %suhel  )TUD_vA  <suhtlema ;30_V	et	f	\N
200810	lõuna-afrikast	?lõuna-afrikast =afrika  (SgEl  >lõuna-afrika !01_S	et	f	\N
200811	lõuna-afrikast	?lõuna-afrikast =afrika  (SgEl  >lõuna-afrikas !02_S	et	f	\N
200812	lõuna-afrikast	?lõuna-afrikast =afrikas  (SgP  >lõuna-afrikane !12_A	et	f	\N
200815	planeeritatakse	?planeeritatakse =planeerita  (IndPrIps  >planeeritama !27_V	et	f	\N
200816	planeeritatakse	?planeeritatakse =planeeritatakse  (SgG  >planeeritatakne !02_A	et	f	\N
200817	planeeritatakse	?planeeritatakse =planeeritatakse  (PlP  >planeeritataks !22_S	et	f	\N
200826	ligne	?ligne =ligne  (SgN  >ligne !02_A	et	f	\N
200827	ligne	?ligne =ligne  (PlP  >lign !22_S	et	f	\N
200828	ligne	?ligne =ligne  (IndPrPs_  >lignema !27_V	et	f	\N
200829	ligne	?ligne =ligne  (ImpPrSg2  >lignema !27_V	et	f	\N
200865	balletti	balletti =balletti  (SgP  >ballett !22_S	et	f	\N
200866	balletti	balletti =balletti  (SgAdt  >ballett !22_S	et	f	\N
200867	veelinnu	veelinnu =innu  (SgG  >veel+ind !22_S	et	f	\N
200868	veelinnu	veelinnu =linnu  (SgG  >vee+lind !22_S	et	f	\N
200869	veelinnu	veelinnu =linnu  (PlP  >vee+linn !22_S	et	f	\N
200870	ümberkorraldata	?ümberkorraldata =ümberkorralda  (SgAb  >ümberkorralda !16_S	et	f	\N
200871	ümberkorraldata	?ümberkorraldata =ümberkorralda  (IndPrIps_  >ümberkorraldama !27_V	et	f	\N
200872	ümberkorraldata	?ümberkorraldata =ümberkorraldata  (IndPrPs_  >ümberkorraldatama !27_V	et	f	\N
200873	ümberkorraldata	?ümberkorraldata =ümberkorraldata  (ImpPrSg2  >ümberkorraldatama !27_V	et	f	\N
200874	reada	?reada =reada  (SgN  >reada !16_S	et	f	\N
200875	reada	?reada =reada  (SgG  >reada !16_S	et	f	\N
200876	reada	?reada =reada  (IndPrPs_  >readama !29_V	et	f	\N
200877	reada	?reada =reada  (ImpPrSg2  >readama !29_V	et	f	\N
200906	eiro	?eiro =eiro  (SgN  >eiro !16_S	et	f	\N
200907	eiro	?eiro =eiro  (SgG  >eiro !16_S	et	f	\N
200912	bürokraatilised	?bürokraatilised =bürokraatilise  (PlN  >bürokraatiline !12_A	et	f	\N
200919	happy	### happy	et	f	\N
200922	woman	?woman =woma  (IndPrSg1  >womama !27_V	et	f	\N
200923	woman	?woman =woman  (SgN  >woman !02_S	et	f	\N
200939	mäedes	?mäedes =mäe  (PlIn  >mäe !26_S	et	f	\N
200940	mäedes	?mäedes =mäede  (PlIn  >mäet !22_S	et	f	\N
200941	mäedes	?mäedes =mäede  (IndIpfSg3  >mäedema !27_V	et	f	\N
200942	mäedes	?mäedes =mäedes  (SgN  >mäedes !09_S	et	f	\N
200964	hangeldaja	hangeldaja =hangeldaja  (SgN  >hangeldaja !01_S	et	f	\N
200965	hangeldaja	"hangeldaja %hangelda  )JA_vS  <hangeldama ;27_V	et	f	\N
200966	hangeldaja	hangeldaja =hangeldaja  (SgG  >hangeldaja !01_S	et	f	\N
200970	immenhof	### immenhof	et	f	\N
200981	holsteiner	?holsteiner =holsteiner  (SgN  >holsteiner !02_S	et	f	\N
200987	situatsionid	?situatsionid =situatsioni  (PlN  >situatsion !19~02_S	et	f	\N
200988	situatsionid	?situatsionid =situatsioni  (PlN  >situatsioni !16_S	et	f	\N
200989	situatsionid	?situatsionid =situatsioni  (IndPrSg2  >situatsionima !28_V	et	f	\N
200992	tõelisust	tõelisust =tõelisus  (SgP  >tõelisus !11_S	et	f	\N
200647	murdada	?murdada =ada  (SgP  >murd+ada !17_S	et	f	\N
200648	lõuna-aafrikast	?lõuna-aafrikast =aafrika  (SgEl  >lõuna-aafrika !01_S	et	f	\N
200649	lõuna-aafrikast	?lõuna-aafrikast =aafrika  (SgEl  >lõuna-aafrikas !02_S	et	f	\N
200650	lõuna-aafrikast	?lõuna-aafrikast =aafrikas  (SgP  >lõuna-aafrikane !12_A	et	f	\N
200654	kümment	?kümment =kümment  (SgN  >kümment !22_S	et	f	\N
200673	tühat	?tühat =tühat  (SgN  >tühat !02_S	et	f	\N
200693	tervil	?tervil =tervi  (SgAd  >tervi !16_S	et	f	\N
200694	tervil	?tervil =tervi  (SgAd  >terv !22_S	et	f	\N
200711	taseele	?taseele =tasee  (SgAll  >tasee !26_S	et	f	\N
200712	taseele	?taseele =taseele  (SgN  >taseele !16_S	et	f	\N
200713	taseele	?taseele =taseele  (SgG  >taseele !16_S	et	f	\N
200714	taseele	?taseele =taseele  (PlP  >taseel !22_S	et	f	\N
200715	taseele	?taseele =taseele  (IndPrPs_  >taseelema !27_V	et	f	\N
200716	taseele	?taseele =taseele  (ImpPrSg2  >taseelema !27_V	et	f	\N
200737	loondonis	?loondonis =loondoni  (SgIn  >loondon !02_S	et	f	\N
200738	loondonis	?loondonis =loondonis  (SgN  >loondonis !11_S	et	f	\N
200753	nemade	?nemade =nema  (PlG  >nema !17_S	et	f	\N
200754	lõuna-aafrisse	?lõuna-aafrisse =aafri  (SgIll  >lõuna-aafr !22_S	et	f	\N
200755	lõuna-aafrisse	?lõuna-aafrisse =aafrisse  (SgG  >lõuna-aafrisne !02_A	et	f	\N
200756	lõuna-aafrisse	?lõuna-aafrisse =aafrisse  (PlP  >lõuna-aafriss !22_S	et	f	\N
200758	seitsest	?seitsest =seitse  (SgEl  >seitne !02_A	et	f	\N
200759	seitsest	?seitsest =seitse  (PlEl  >seits !22_S	et	f	\N
200760	seitsest	?seitsest =seitses  (SgP  >seitses !09_S	et	f	\N
200761	seitsest	?seitsest =seitses  (SgP  >seitsene !12~10_A	et	f	\N
200767	murdan	?murdan =murda  (IndPrSg1  >murdama !29_V	et	f	\N
200768	murdan	?murdan =murdan  (SgN  >murdan !02_S	et	f	\N
200818	seitsemendast	?seitsemendast =seitsemenda  (SgEl  >seitsemenda !16_S	et	f	\N
200819	seitsemendast	?seitsemendast =seitsemendas  (SgP  >seitsemendane !12_A	et	f	\N
200820	seitsemendast	?seitsemendast =menda  (SgEl  >seitse+menda !16_S	et	f	\N
200821	seitsemendast	?seitsemendast =mendas  (SgP  >seitse+mendas !07_S	et	f	\N
200822	seitsemendast	?seitsemendast =mendas  (SgP  >seitse+mendane !10_A	et	f	\N
200859	apervik	?apervik =apervik  (SgN  >apervik !25_S	et	f	\N
200861	lmerel	?lmerel =lmere  (SgAd  >lmere !16_S	et	f	\N
200862	lmerel	?lmerel =lmerel  (SgN  >lmerel !02_S	et	f	\N
200924	armastuskomöödia	armastuskomöödia =dia  (SgN  >armastus+kom+öö+dia !26_S	et	f	\N
200925	armastuskomöödia	armastuskomöödia =dia  (SgG  >armastus+kom+öö+dia !26_S	et	f	\N
200926	armastuskomöödia	armastuskomöödia =komöödia  (SgN  >armastus+komöödia !01_S	et	f	\N
200927	armastuskomöödia	armastuskomöödia =komöödia  (SgG  >armastus+komöödia !01_S	et	f	\N
200937	baierimaa	baierimaa =maa  (SgN  >baieri+maa !26_S	et	f	\N
200938	baierimaa	baierimaa =maa  (SgG  >baieri+maa !26_S	et	f	\N
200951	heidis	heidis =heidi  (SgIn  >heit !22_S	et	f	\N
200952	heidis	heidis =heidis  (SgN  >heidis !09_S	et	f	\N
200959	eraldadud	?eraldadud =eraldadu  (IndPrSg2  >eraldaduma !27_V	et	f	\N
200960	eraldadud	?eraldadud =eraldadud  (ID  >eraldadud !41_A	et	f	\N
200983	vastandeid	vastandeid =vastande  (PlP  >vastand !02_S	et	f	\N
200984	vastandeid	vastandeid =ande  (PlP  >vast+anne !06_S	et	f	\N
201007	lastelega	?lastelega =lega  (SgN  >laste+lega !17_S	et	f	\N
201008	lastelega	?lastelega =lega  (SgG  >laste+lega !17_S	et	f	\N
201009	lastelega	?lastelega =lega  (SgP  >laste+lega !17_S	et	f	\N
201010	koolini	koolini =kooli  (SgTer  >kool !22_S	et	f	\N
201011	koolini	koolini =ini  (SgN  >kool+ini !17_S	et	f	\N
201012	koolini	koolini =ini  (SgG  >kool+ini !17_S	et	f	\N
201013	koolini	koolini =ini  (SgP  >kool+ini !17_S	et	f	\N
201026	maalatud	maalatud =latu  (PlN  >maa+latu !16_S	et	f	\N
201027	maalatud	"maa+latu %la  )TU2_kA  <maa+la ;26_S	et	f	\N
201028	ovad	?ovad =ova  (PlN  >ova !17_S	et	f	\N
201029	ovad	?ovad =ova  (IndPrSg2  >ovama !27_V	et	f	\N
201037	linnudest	?linnudest =linnu  (PlEl  >linnu !16_S	et	f	\N
201038	linnudest	?linnudest =linnudes  (SgP  >linnudene !12_A	et	f	\N
201039	linnudest	?linnudest =udes  (SgP  >linn+udes !09_S	et	f	\N
201040	linnudest	?linnudest =udes  (SgP  >linn+udene !10_A	et	f	\N
201050	vesterålenil	### vesterålenil	et	f	\N
201052	sellepärst	?sellepärst =pärst  (SgN  >selle+pärst !22_S	et	f	\N
201053	põhitulid	?põhitulid =põhituli  (PlN  >põhitul !19_S	et	f	\N
201068	j6uluturul	?juluturul =juluturul  (SgN  >juluturul !19_S	et	f	\N
201077	istusimme	?istusimme =istusimme  (PlP  >istusimm !22_S	et	f	\N
201081	sünnipäevalaps	sünnipäevalaps =laps  (SgN  >sünni+päeva+laps !14_S	et	f	\N
201082	sünnipäevalaps	sünnipäevalaps =laps  (SgN  >sünni+päeva+laps !22_S	et	f	\N
201083	s6in	### s6in	et	f	\N
201086	tatort	?tatort =tatort  (SgN  >tatort !22_S	et	f	\N
201102	tintenherz	### tintenherz	et	f	\N
201112	tagalt	?tagalt =tagalt  (ID  >tagalt !41_D	et	f	\N
201113	hiiret	?hiiret =hiire  (SgP  >hiire !06_S	et	f	\N
201118	jõululaulu	jõululaulu =laulu  (SgG  >jõulu+laul !22_S	et	f	\N
201119	jõululaulu	jõululaulu =laulu  (SgP  >jõulu+laul !22_S	et	f	\N
201120	jõululaulu	jõululaulu =laulu  (SgAdt  >jõulu+laul !22_S	et	f	\N
200710	üheksakümme	?üheksakümme =ksakümme  (PlP  >ühe+ksakümm !22_S	et	f	\N
200717	seitmes	?seitmes =seitme  (SgIn  >seitme !06_S	et	f	\N
200718	seitmes	?seitmes =seitme  (PlIn  >seitm !22_S	et	f	\N
200719	seitmes	?seitmes =seitme  (IndIpfSg3  >seitmema !27_V	et	f	\N
200720	seitmes	?seitmes =seitmes  (SgN  >seitmes !09_S	et	f	\N
200727	inglismal	?inglismal =inglisma  (SgAd  >inglisma !01_S	et	f	\N
200728	inglismal	?inglismal =inglismal  (ID  >inglismal !41_D	et	f	\N
200729	pleneritud	?pleneritud =pleneritu  (PlN  >pleneritu !01_A	et	f	\N
200730	pleneritud	?pleneritud =pleneritu  (IndPrSg2  >plenerituma !27_V	et	f	\N
200731	pleneritud	?pleneritud =pleneritud  (ID  >pleneritud !41_A	et	f	\N
200732	londonil	?londonil =londoni  (SgAd  >london !02_S	et	f	\N
200735	pidadab	### pidadab	et	f	\N
200736	nemadele	?nemadele =nema  (PlAll  >nema !17_S	et	f	\N
200751	etendu	etendu =etendu  (IndPrPs_  >etenduma !27_V	et	f	\N
200752	etendu	etendu =etendu  (ImpPrSg2  >etenduma !27_V	et	f	\N
200769	planerida	### planerida	et	f	\N
200778	erinevas	erinevas =erineva  (SgIn  >erinev !02_A	et	f	\N
200779	erinevas	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
200801	armastavakse	?armastavakse =armastavakse  (SgG  >armastavakne !02_A	et	f	\N
200802	planeerimata	planeerimata =planeeri  (SupAb  >planeerima !28_V	et	f	\N
200803	planeerimata	planeerimata =planeerimata  (ID  >planeerimata !41_A	et	f	\N
200804	planeerimata	"planeerimata %planeeri  )MATA_vA  <planeerima ;28_V	et	f	\N
200847	etend	?etend =etend  (SgN  >etend !02_S	et	f	\N
200855	usuvat	?usuvat =usu  (KvtPrPs  >usuma !27_V	et	f	\N
200856	usuvat	?usuvat =usuva  (SgP  >usuva !01_S	et	f	\N
200857	usuvat	?usuvat =usuva  (SgP  >usuv !02_A	et	f	\N
200860	abeeman	?abeeman =abeeman  (SgN  >abeeman !02_S	et	f	\N
200880	väliskapitaali	?väliskapitaali =väliskapitaali  (SgN  >väliskapitaali !16_S	et	f	\N
200881	väliskapitaali	?väliskapitaali =väliskapitaali  (SgG  >väliskapitaali !16_S	et	f	\N
200882	väliskapitaali	?väliskapitaali =väliskapitaali  (SgG  >väliskapitaal !22_S	et	f	\N
200883	väliskapitaali	?väliskapitaali =väliskapitaali  (SgP  >väliskapitaal !22_S	et	f	\N
200884	väliskapitaali	?väliskapitaali =väliskapitaali  (SgAdt  >väliskapitaal !22_S	et	f	\N
200885	väliskapitaali	?väliskapitaali =väliskapitaali  (IndPrPs_  >väliskapitaalima !28_V	et	f	\N
200886	väliskapitaali	?väliskapitaali =väliskapitaali  (ImpPrSg2  >väliskapitaalima !28_V	et	f	\N
200887	väliskapitaali	?väliskapitaali =taali  (SgN  >välis+kapi+taali !16_S	et	f	\N
200888	väliskapitaali	?väliskapitaali =taali  (SgG  >välis+kapi+taali !16_S	et	f	\N
200889	väliskapitaali	?väliskapitaali =taali  (SgG  >välis+kapi+taal !22_S	et	f	\N
200890	väliskapitaali	?väliskapitaali =taali  (SgP  >välis+kapi+taal !22_S	et	f	\N
200891	väliskapitaali	?väliskapitaali =taali  (SgAdt  >välis+kapi+taal !22_S	et	f	\N
200892	väliskapitaali	?väliskapitaali =kapitaali  (SgN  >välis+kapitaali !16_S	et	f	\N
200893	väliskapitaali	?väliskapitaali =kapitaali  (SgG  >välis+kapitaali !16_S	et	f	\N
200894	väliskapitaali	?väliskapitaali =kapitaali  (SgG  >välis+kapitaal !22_S	et	f	\N
200895	väliskapitaali	?väliskapitaali =kapitaali  (SgP  >välis+kapitaal !22_S	et	f	\N
200896	väliskapitaali	?väliskapitaali =kapitaali  (SgAdt  >välis+kapitaal !22_S	et	f	\N
200897	väliskapitaali	?väliskapitaali =skapitaali  (SgN  >väli+skapitaali !16_S	et	f	\N
200898	väliskapitaali	?väliskapitaali =skapitaali  (SgG  >väli+skapitaali !16_S	et	f	\N
200899	väliskapitaali	?väliskapitaali =skapitaali  (SgG  >väli+skapitaal !22_S	et	f	\N
200900	väliskapitaali	?väliskapitaali =skapitaali  (SgP  >väli+skapitaal !22_S	et	f	\N
200901	väliskapitaali	?väliskapitaali =skapitaali  (SgAdt  >väli+skapitaal !22_S	et	f	\N
200909	lopez	### lopez	et	f	\N
200913	armastus-	armastus- =armastus  (SgN  >armastus !11_S	et	f	\N
200914	armastus-	"armastus %armasta  )US_vS  <armastama ;27_V	et	f	\N
200928	armastajadest	?armastajadest =armastajades  (SgP  >armastajadene !12_A	et	f	\N
200929	schiwago	?schiwago =schiwago  (SgN  >schiwago !01_S	et	f	\N
200930	schiwago	?schiwago =schiwago  (SgG  >schiwago !01_S	et	f	\N
200954	filmit	?filmit =filmi  (SgP  >filmi !16_S	et	f	\N
200955	filmit	?filmit =filmit  (SgN  >filmit !02_S	et	f	\N
200961	maaharija	maaharija =harija  (SgN  >maa+harija !01_S	et	f	\N
200962	maaharija	maaharija =harija  (SgG  >maa+harija !01_S	et	f	\N
200963	maaharija	maaharija =harija  (SgG  >maa+harijas !02_A	et	f	\N
200967	mädchen	?mädchen =mädche  (IndPrSg1  >mädchema !27_V	et	f	\N
200968	mädchen	?mädchen =mädchen  (SgN  >mädchen !02_S	et	f	\N
200975	ethelberti	?ethelberti =ethelberti  (SgP  >ethelbert !22_S	et	f	\N
200976	ethelberti	?ethelberti =ethelberti  (SgAdt  >ethelbert !22_S	et	f	\N
200986	kitsch	?kitsch =kitsch  (SgN  >kitsch !22_S	et	f	\N
200990	näida	näida =näi  (Inf  >näima !37_V	et	f	\N
200991	näida	näida =näi  (IndPrIps_  >näima !37_V	et	f	\N
201017	kasavab	### kasavab	et	f	\N
201030	ovad	?ovad =ova  (PlN  >ova !17_S	et	f	\N
201031	ovad	?ovad =ova  (IndPrSg2  >ovama !27_V	et	f	\N
201041	lõbusaim	lõbusaim =lõbusaim  (SgN  >lõbusaim !02_A	et	f	\N
201043	lõbusaim	"lõbusaim %lõbusa  )IM_sA  <lõbus ;02_A	et	f	\N
201044	värvikaid	värvikaid =värvika  (PlP  >värvikas !02_A	et	f	\N
200807	nooreid	?nooreid =noorei  (SgP  >noorei !26_S	et	f	\N
200808	nooreid	?nooreid =nooreid  (SgN  >nooreid !22_S	et	f	\N
200809	nooreid	?nooreid =eid  (SgN  >noor+eid !22_S	et	f	\N
200823	murras	?murras =murra  (SgIn  >murra !16_S	et	f	\N
200824	murras	?murras =murra  (IndIpfSg3  >murrama !29_V	et	f	\N
200825	murras	?murras =murras  (SgN  >murras !07_S	et	f	\N
200840	üheksaküme	?üheksaküme =üheksaküme  (PlP  >üheksaküm !19_S	et	f	\N
200841	üheksaküme	?üheksaküme =küme  (SgN  >üheksa+küme !16_S	et	f	\N
200842	üheksaküme	?üheksaküme =küme  (SgG  >üheksa+küme !16_S	et	f	\N
200843	muura	?muura =muura  (SgN  >muura !16_S	et	f	\N
200844	muura	?muura =muura  (SgG  >muura !16_S	et	f	\N
200845	muura	?muura =muura  (IndPrPs_  >muurama !29_V	et	f	\N
200846	muura	?muura =muura  (ImpPrSg2  >muurama !29_V	et	f	\N
200858	konfliktseise	?konfliktseise =konfliktseise  (PlP  >konfliktseis !22_S	et	f	\N
200863	hanno	?hanno =hanno  (SgN  >hanno !16_S	et	f	\N
200864	hanno	?hanno =hanno  (SgG  >hanno !16_S	et	f	\N
200902	tiitre	?tiitre =tiitre  (SgN  >tiitre !06_S	et	f	\N
200903	tiitre	?tiitre =tiitre  (SgG  >tiitre !06_S	et	f	\N
200904	tiitre	?tiitre =tiitre  (IndPrPs_  >tiitrema !27_V	et	f	\N
200905	tiitre	?tiitre =tiitre  (ImpPrSg2  >tiitrema !27_V	et	f	\N
200915	rääkitakse	?rääkitakse =rääkitakse  (SgG  >rääkitakne !02_A	et	f	\N
200916	rääkitakse	?rääkitakse =rääkitakse  (PlP  >rääkitaks !22_S	et	f	\N
200917	armastuses	armastuses =armastuse  (SgIn  >armastus !11_S	et	f	\N
200918	armastuses	"armastus %armasta  )US_vS  <armastama ;27_V	et	f	\N
200920	armastuspaar	?armastuspaar =armastuspaar  (SgN  >armastuspaar !22_S	et	f	\N
200931	titanic	### titanic	et	f	\N
200932	armastajade	### armastajade	et	f	\N
200933	armastaja	armastaja =armastaja  (SgN  >armastaja !01_S	et	f	\N
200934	armastaja	"armastaja %armasta  )JA_vS  <armastama ;27_V	et	f	\N
200935	armastaja	armastaja =armastaja  (SgG  >armastaja !01_S	et	f	\N
200945	lüneburgi	?lüneburgi =lüneburgi  (SgG  >lüneburk !22_S	et	f	\N
200946	lüneburgi	?lüneburgi =lüneburgi  (SgP  >lüneburg !22_S	et	f	\N
200947	lüneburgi	?lüneburgi =lüneburgi  (SgAdt  >lüneburg !22_S	et	f	\N
200948	lüneburgi	?lüneburgi =lüneburgi  (IndPrPs_  >lüneburkima !28_V	et	f	\N
200949	lüneburgi	?lüneburgi =lüneburgi  (ImpPrSg2  >lüneburkima !28_V	et	f	\N
200950	lüneburgi	?lüneburgi =lünebur  (SgN^  >lünebur !19_S	et	f	\N
200953	vaadab	?vaadab =vaada  (IndPrSg3  >vaadama !29_V	et	f	\N
200969	vom	### vom	et	f	\N
201000	aeas	?aeas =aeas  (SgN  >aeas !02_S	et	f	\N
201001	pirnipuud	pirnipuud =puu  (PlN  >pirni+puu !26_S	et	f	\N
201002	pirnipuud	pirnipuud =puu  (SgP  >pirni+puu !26_S	et	f	\N
201003	pirnipuud	pirnipuud =puud  (SgN  >pirni+puud !22_S	et	f	\N
201018	pari	pari =pari  (SgN  >pari !17_S	et	f	\N
201019	pari	pari =pari  (SgG  >pari !17_S	et	f	\N
201020	pari	pari =pari  (SgP  >pari !17_S	et	f	\N
201032	golfstrom	?golfstrom =golfstrom  (SgN  >golfstrom !02_S	et	f	\N
201055	pizza	?pizza =pizza  (SgN  >pizza !16_S	et	f	\N
201056	pizza	?pizza =pizza  (SgG  >pizza !16_S	et	f	\N
201062	celles	?celles =celle  (PlIn  >cell !22_S	et	f	\N
201063	celles	?celles =celle  (IndIpfSg3  >cellema !30_V	et	f	\N
201064	celles	?celles =celles  (SgN  >celles !09_S	et	f	\N
201074	aegana	?aegana =ana  (SgN  >aeg+ana !17_S	et	f	\N
201075	aegana	?aegana =ana  (SgG  >aeg+ana !17_S	et	f	\N
201076	aegana	?aegana =ana  (SgP  >aeg+ana !17_S	et	f	\N
201084	kaasüürilisega	kaasüürilisega =üürilise  (SgKom  >kaas+üüriline !12_S	et	f	\N
201085	kaasüürilisega	"kaas+üüriline %üüri  )LINE_aA  <kaas+üür ;22_S	et	f	\N
201089	palu	palu =palu  (SgN  >palu !17_S	et	f	\N
201090	palu	palu =palu  (SgG  >palu !17_S	et	f	\N
201091	palu	palu =palu  (SgP  >palu !17_S	et	f	\N
201092	palu	palu =palu  (PlP  >pala !17_S	et	f	\N
201093	palu	palu =palu  (IndPrPs_  >paluma !27_V	et	f	\N
201094	palu	palu =palu  (ImpPrSg2  >paluma !27_V	et	f	\N
201114	lumièris	### lumièris	et	f	\N
201133	skandinavistises	?skandinavistises =skandinavistise  (SgIn  >skandinavistis !09_S	et	f	\N
201155	campusesse	?campusesse =campuse  (SgIll  >campus !11~09_S	et	f	\N
201156	campusesse	?campusesse =campuses  (SgAdt  >campusene !12_A	et	f	\N
201157	campusesse	?campusesse =campusesse  (SgG  >campusesne !02_A	et	f	\N
201158	campusesse	?campusesse =campusesse  (PlP  >campusess !22_S	et	f	\N
201163	ajasivad	?ajasivad =ajasiva  (PlN  >ajasiv !02_A	et	f	\N
201164	ajasivad	?ajasivad =ajasiva  (PlN  >ajasiva !16_S	et	f	\N
201187	udused	udused =uduse  (PlN  >udune !10_A	et	f	\N
201188	udused	"udune %udu  )NE_aA  <udu ;17_S	et	f	\N
201198	öös	öös =öö  (SgIn  >öö !26_S	et	f	\N
201199	öös	öös =öös  (SgN  >öös !22_S	et	f	\N
201203	võrumaa	võrumaa =maa  (SgN  >võru+maa !26_S	et	f	\N
201205	võrumaa	võrumaa =maa  (SgG  >võru+maa !26_S	et	f	\N
201211	lääne-virumaa	lääne-virumaa =maa  (SgN  >lääne-viru+maa !26_S	et	f	\N
201212	lääne-virumaa	lääne-virumaa =maa  (SgG  >lääne-viru+maa !26_S	et	f	\N
201228	rhein-land-pfalz	### rhein-land-pfalz	et	f	\N
201234	berlin	?berlin =berli  (IndPrSg1  >berlima !28_V	et	f	\N
200814	kolmküment	?kolmküment =küment  (SgN  >kolm+küment !22_S	et	f	\N
200830	kolmkümentkaks	?kolmkümentkaks =kolmkümentka  (SgTr  >kolmkümentka !16_S	et	f	\N
200831	kolmkümentkaks	?kolmkümentkaks =kümentka  (SgTr  >kolm+kümentka !01_S	et	f	\N
200832	tuhadüheksasajaüheksakümne	?tuhadüheksasajaüheksakümne =tuhadüheksasajaüheksakümne  (SgN  >tuhadüheksasajaüheksakümne !02_A	et	f	\N
200833	tuhadüheksasajaüheksakümne	?tuhadüheksasajaüheksakümne =tuhadüheksasajaüheksakümne  (PlP  >tuhadüheksasajaüheksakümn !22_S	et	f	\N
200834	tuhadüheksasajaüheksakümne	?tuhadüheksasajaüheksakümne =düheksasajaüheksakümne  (SgN  >tuha+düheksasajaüheksakümne !02_A	et	f	\N
200835	tuhadüheksasajaüheksakümne	?tuhadüheksasajaüheksakümne =düheksasajaüheksakümne  (PlP  >tuha+düheksasajaüheksakümn !22_S	et	f	\N
200836	londonnis	?londonnis =londonni  (SgIn  >londonni !01_S	et	f	\N
200837	londonnis	?londonnis =londonni  (SgIn  >londonn !22_S	et	f	\N
200838	londonnis	?londonnis =londonni  (IndIpfSg3  >londonnima !28_V	et	f	\N
200839	londonnis	?londonnis =londonnis  (SgN  >londonnis !11_S	et	f	\N
200848	lõuna-afrikasse	?lõuna-afrikasse =afrika  (SgIll  >lõuna-afrika !01_S	et	f	\N
200849	lõuna-afrikasse	?lõuna-afrikasse =afrika  (SgIll  >lõuna-afrikas !02_S	et	f	\N
200850	lõuna-afrikasse	?lõuna-afrikasse =afrikas  (SgAdt  >lõuna-afrikane !12_A	et	f	\N
200851	lõuna-afrikasse	?lõuna-afrikasse =afrikasse  (SgG  >lõuna-afrikasne !02_A	et	f	\N
200852	lõuna-afrikasse	?lõuna-afrikasse =afrikasse  (PlP  >lõuna-afrikass !22_S	et	f	\N
200853	kolmekümmend	?kolmekümmend =kolmekümmend  (SgN  >kolmekümmend !22_S	et	f	\N
200854	kolmekümmend	?kolmekümmend =ekümmend  (SgN  >kolm+ekümmend !22_S	et	f	\N
200878	intensiivsust	intensiivsust =intensiivsus  (SgP  >intensiivsus !11~09_S	et	f	\N
200879	intensiivsust	"intensiivsus %intensiivse  )US_aS  <intensiivne ;02_A	et	f	\N
200908	jennifer	?jennifer =jennifer  (SgN  >jennifer !19_S	et	f	\N
200910	lopesa	?lopesa =lopesa  (SgN  >lopesa !01_S	et	f	\N
200911	lopesa	?lopesa =lopesa  (SgG  >lopesa !01_S	et	f	\N
200921	pretty	### pretty	et	f	\N
200936	vanemadele	?vanemadele =ade  (SgAll  >vanem+ade !16_S	et	f	\N
200943	põhisaksamaal	põhisaksamaal =maa  (SgAd  >põhi+saksa+maa !26_S	et	f	\N
200944	põhisaksamaal	põhisaksamaal =maal  (SgN  >põhi+saksa+maal !22_S	et	f	\N
200956	köstüüme	?köstüüme =köstüüme  (SgN  >köstüüme !16_S	et	f	\N
200957	köstüüme	?köstüüme =köstüüme  (SgG  >köstüüme !16_S	et	f	\N
200958	köstüüme	?köstüüme =köstüüme  (PlP  >köstüüm !22_S	et	f	\N
200971	onupoja	onupoja =poja  (SgN  >onu+poja !17_S	et	f	\N
200972	onupoja	onupoja =poja  (SgG  >onu+poja !17_S	et	f	\N
200973	onupoja	onupoja =poja  (SgG  >onu+poeg !22_S	et	f	\N
200974	onupoja	onupoja =poja  (SgP  >onu+poja !17_S	et	f	\N
200977	kummistuslikud	?kummistuslikud =kummistusliku  (PlN  >kummistuslik !25_A	et	f	\N
200978	kummistuslikud	?kummistuslikud =kummistusliku  (IndPrSg2  >kummistuslikuma !27_V	et	f	\N
200979	kummistuslikud	?kummistuslikud =stusliku  (PlN  >kummi+stuslik !25_A	et	f	\N
200980	kummistuslikud	?kummistuslikud =stusliku  (PlN  >kummi+stusliku !01_S	et	f	\N
200982	schweiz	### schweiz	et	f	\N
200985	traditsioonid-arenamised	?traditsioonid-arenamised =arenamise  (PlN  >traditsioonid-arenamine !12_S	et	f	\N
200995	western-filmid	western-filmid =filmi  (PlN  >western-film !22_S	et	f	\N
200996	western-filmid	western-filmid =filmi  (IndPrSg2  >western-filmima !28_V	et	f	\N
200997	jänesid	?jänesid =jäne  (PlP  >jäne !16_S	et	f	\N
200998	jänesid	?jänesid =jäne  (IndIpfSg2  >jänema !27_V	et	f	\N
200999	jänesid	?jänesid =jäne  (IndIpfPl3  >jänema !27_V	et	f	\N
201014	vesterålen-saarila	vesterålen-saarila =ila  (SgN  >vesterålen-saar+ila !17_S	et	f	\N
201015	vesterålen-saarila	vesterålen-saarila =ila  (SgG  >vesterålen-saar+ila !17_S	et	f	\N
201016	vesterålen-saarila	vesterålen-saarila =ila  (SgP  >vesterålen-saar+ila !17_S	et	f	\N
201033	wale	?wale =wale  (SgN  >wale !16_S	et	f	\N
201034	wale	?wale =wale  (SgG  >wale !16_S	et	f	\N
201035	wale	?wale =wale  (IndPrPs_  >walema !27_V	et	f	\N
201036	wale	?wale =wale  (ImpPrSg2  >walema !27_V	et	f	\N
201047	kummaliselt	kummaliselt =kummalise  (SgAbl  >kummaline !12_A	et	f	\N
201048	kummaliselt	kummaliselt =kummaliselt  (ID  >kummaliselt !41_D	et	f	\N
201049	kummaliselt	"kummaliselt %kummalise  )LT_mD  <kummaline ;12_A	et	f	\N
201078	göttingenisse	?göttingenisse =göttingeni  (SgIll  >göttingen !19_S	et	f	\N
201079	göttingenisse	?göttingenisse =göttingenisse  (SgG  >göttingenisne !02_A	et	f	\N
201080	göttingenisse	?göttingenisse =göttingenisse  (PlP  >göttingeniss !22_S	et	f	\N
201100	jõulekingitusekes	?jõulekingitusekes =jõulekingituseke  (PlIn  >jõulekingitusekk !22_S	et	f	\N
201101	jõulekingitusekes	?jõulekingitusekes =lekingituseke  (PlIn  >jõu+lekingitusekk !22_S	et	f	\N
201103	kooril	kooril =koori  (SgAd  >koor !22_S	et	f	\N
201104	kooril	kooril =koori  (PlAd  >koor !13_S	et	f	\N
201177	päikesepaistelised	päikesepaistelised =paistelise  (PlN  >päikese+paisteline !12_A	et	f	\N
201178	päikesepaistelised	"päikese+paisteline %paiste  )LINE_aA  <päikese+paiste ;06_S	et	f	\N
201180	vahelduva	vahelduva =vahelduva  (SgG  >vahelduv !02_A	et	f	\N
201181	vahelduva	"vahelduv %vaheldu  )V_vA  <vahelduma ;27_V	et	f	\N
201190	talves	talves =talve  (SgIn  >talv !22_S	et	f	\N
201191	talves	talves =talve  (SgIn  >tali !24_S	et	f	\N
200993	tõelisust	"tõelisus %tõe  )LISUS_aS  <tõsi ;15_S	et	f	\N
200994	tõelisust	"tõelisus %tõe  )LISUS_aS  <tõde ;18_S	et	f	\N
201004	ploomipuud	ploomipuud =puu  (PlN  >ploomi+puu !26_S	et	f	\N
201005	ploomipuud	ploomipuud =puu  (SgP  >ploomi+puu !26_S	et	f	\N
201006	ploomipuud	ploomipuud =puud  (SgN  >ploomi+puud !22_S	et	f	\N
201021	hoonest	hoonest =hoone  (SgEl  >hoone !06_S	et	f	\N
201022	hoonest	"hoone %hoo  )NE_aA  <hoog ;22_S	et	f	\N
201023	hoonest	hoonest =hoone  (PlEl  >hoon !22_A	et	f	\N
201024	hoonest	hoonest =hoones  (SgP  >hoonene !10_A	et	f	\N
201025	hoonest	"hoonene %hoone  )NE_aA  <hoone ;06_S	et	f	\N
201042	papageientaucher	?papageientaucher =papageientaucher  (SgN  >papageientaucher !02_S	et	f	\N
201051	vesterålenid	### vesterålenid	et	f	\N
201065	raudteejaama	raudteejaama =jaama  (SgG  >raud+tee+jaam !22_S	et	f	\N
201066	raudteejaama	raudteejaama =jaama  (SgP  >raud+tee+jaam !22_S	et	f	\N
201067	raudteejaama	raudteejaama =jaama  (SgAdt  >raud+tee+jaam !22_S	et	f	\N
201069	göttingenisgöttingenis	?göttingenisgöttingenis =göttingenisgöttingeni  (SgIn  >göttingenisgöttingen !02_S	et	f	\N
201070	göttingenisgöttingenis	?göttingenisgöttingenis =göttingenisgöttingenis  (SgN  >göttingenisgöttingenis !09_S	et	f	\N
201071	hambaarsti	hambaarsti =arsti  (SgG  >hamba+arst !22_S	et	f	\N
201072	hambaarsti	hambaarsti =arsti  (SgP  >hamba+arst !22_S	et	f	\N
201073	hambaarsti	hambaarsti =arsti  (SgAdt  >hamba+arst !22_S	et	f	\N
201087	nädalavehetusel	?nädalavehetusel =nädalavehetuse  (SgAd  >nädalavehetus !11?09_S	et	f	\N
201088	nädalavehetusel	?nädalavehetusel =vehetuse  (SgAd  >nädala+vehetus !11_S	et	f	\N
201108	aquavit	?aquavit =aquavi  (SgP  >aquavi !16_S	et	f	\N
201109	jõululalud	?jõululalud =jõululalu  (IndPrSg2  >jõululaluma !27_V	et	f	\N
201110	jõululalud	?jõululalud =lalu  (PlN  >jõulu+lalu !17_S	et	f	\N
201111	jõululalud	?jõululalud =lulalu  (PlN  >jõu+lulalu !01_S	et	f	\N
201115	õpettajast	?õpettajast =õpettaja  (SgEl  >õpettaja !01_S	et	f	\N
201116	õpettajast	?õpettajast =õpettaja  (SgEl  >õpettajas !02_A	et	f	\N
201117	õpettajast	?õpettajast =õpettajas  (SgP  >õpettajane !12_A	et	f	\N
201126	nelipäeva	nelipäeva =päeva  (SgG  >neli+päev !22_S	et	f	\N
201127	nelipäeva	nelipäeva =päeva  (SgP  >neli+päev !22_S	et	f	\N
201128	nelipäeva	nelipäeva =päeva  (SgAdt  >neli+päev !22_S	et	f	\N
201134	skandinavistises	?skandinavistises =skandinavistise  (SgIn  >skandinavistis !09_S	et	f	\N
201143	gilmore	### gilmore	et	f	\N
201151	janis	?janis =jani  (SgIn  >jani !17_S	et	f	\N
201152	janis	?janis =jani  (IndIpfSg3  >janima !27_V	et	f	\N
201153	janis	?janis =janis  (SgN  >janis !09_S	et	f	\N
201154	julianega	?julianega =juliane  (SgKom  >juliane !16_S	et	f	\N
201170	koodused	?koodused =kooduse  (PlN  >koodus !11~09_S	et	f	\N
201185	vihmased	vihmased =vihmase  (PlN  >vihmane !10_A	et	f	\N
201186	vihmased	"vihmane %vihma  )NE_aA  <vihm ;22_S	et	f	\N
201207	valgamaa	valgamaa =maa  (SgN  >valga+maa !26_S	et	f	\N
201208	valgamaa	valgamaa =maa  (SgG  >valga+maa !26_S	et	f	\N
201213	pärnumaa	pärnumaa =maa  (SgN  >pärnu+maa !26_S	et	f	\N
201214	pärnumaa	pärnumaa =maa  (SgG  >pärnu+maa !26_S	et	f	\N
201218	pihkajärv	?pihkajärv =pihkajärv  (SgN  >pihkajärv !22_S	et	f	\N
201226	hessen	?hessen =hesse  (IndPrSg1  >hessema !27_V	et	f	\N
201227	hessen	?hessen =hessen  (SgN  >hessen !02_S	et	f	\N
201243	berliin	?berliin =berliin  (SgN  >berliin !22_S	et	f	\N
201245	düsseldorf	?düsseldorf =düsseldorf  (SgN  >düsseldorf !22_S	et	f	\N
201251	bodenjärv	?bodenjärv =bodenjärv  (SgN  >bodenjärv !22_S	et	f	\N
201252	alpenmäestik	?alpenmäestik =alpenmäestik  (SgN  >alpenmäestik !25_S	et	f	\N
201256	donau	?donau =donau  (SgN  >donau !26_S	et	f	\N
201257	donau	?donau =donau  (SgG  >donau !26_S	et	f	\N
201263	suurin	?suurin =suuri  (IndPrSg1  >suurima !28_V	et	f	\N
201264	suurin	?suurin =suurin  (SgN  >suurin !02_S	et	f	\N
201278	silitama	silitama =sili  (SupIps  >silima !27_V	et	f	\N
201279	silitama	silitama =silita  (Sup  >silitama !27_V	et	f	\N
201308	ehtamatas	?ehtamatas =ehtamata  (IndIpfSg3  >ehtamatama !27_V	et	f	\N
201312	ehmutada	?ehmutada =ehmuta  (Inf  >ehmutama !27_V	et	f	\N
201318	odanud	?odanud =oda  (PtsPtPs  >odama !27_V	et	f	\N
201319	odanud	?odanud =odanu  (PlN  >odanu !01_S	et	f	\N
201320	odanud	?odanud =odanu  (IndPrSg2  >odanuma !27_V	et	f	\N
201321	odanud	?odanud =odanud  (ID  >odanud !41_A	et	f	\N
201340	siiamne	?siiamne =siiamne  (SgN  >siiamne !02_A	et	f	\N
201341	siiamne	?siiamne =siiamne  (PlP  >siiamn !22_S	et	f	\N
201344	kammimine	kammimine =kammimine  (SgN  >kammimine !12_S	et	f	\N
201345	kammimine	"kammimine %kammi  )MINE_vS  <kammima ;28_V	et	f	\N
201348	jootmine	jootmine =jootmine  (SgN  >jootmine !12?10_S	et	f	\N
201349	jootmine	"jootmine %joot  )MINE_vS  <jootma ;34_V	et	f	\N
201367	safariparki	safariparki =parki  (SgP  >safari+park !22_S	et	f	\N
201368	safariparki	safariparki =parki  (SgAdt  >safari+park !22_S	et	f	\N
201370	sonja	?sonja =sonja  (SgN  >sonja !16_S	et	f	\N
201372	sonja	?sonja =sonja  (SgG  >sonjas !02_A	et	f	\N
201373	sonja	?sonja =sonja  (SgG  >sonja !16_S	et	f	\N
201374	sonja	?sonja =sonja  (IndPrPs_  >sonjama !29_V	et	f	\N
201045	värvikaid	värvikaid =kai  (PlN  >värvi+kai !26_S	et	f	\N
201046	värvikaid	värvikaid =kai  (SgP  >värvi+kai !26_S	et	f	\N
201054	nordlichter	?nordlichter =nordlichter  (SgN  >nordlichter !02_S	et	f	\N
201057	barbarella	?barbarella =barbarella  (SgN  >barbarella !16_S	et	f	\N
201058	barbarella	?barbarella =barbarella  (SgG  >barbarella !16_S	et	f	\N
201059	ümbres	?ümbres =ümbre  (SgIn  >ümbre !06_S	et	f	\N
201060	ümbres	?ümbres =ümbre  (IndIpfSg3  >ümbrema !27_V	et	f	\N
201061	ümbres	?ümbres =ümbres  (SgN  >ümbres !09_S	et	f	\N
201095	jaksanud	jaksanud =jaksa  (PtsPtPs  >jaksama !29_V	et	f	\N
201096	jaksanud	jaksanud =jaksanu  (PlN  >jaksanu !01_S	et	f	\N
201097	jaksanud	"jaksanu %jaksa  )NU_vS  <jaksama ;29_V	et	f	\N
201098	jaksanud	jaksanud =jaksanud  (ID  >jaksanud !41_A	et	f	\N
201099	jaksanud	"jaksanud %jaksa  )NUD_vA  <jaksama ;29_V	et	f	\N
201105	õpettaja	?õpettaja =õpettaja  (SgN  >õpettaja !01_S	et	f	\N
201106	õpettaja	?õpettaja =õpettaja  (SgG  >õpettaja !01_S	et	f	\N
201107	õpettaja	?õpettaja =õpettaja  (SgG  >õpettajas !02_A	et	f	\N
201137	soome-uugri	?soome-uugri =uugri  (ID  >soome-uugri !41_D	et	f	\N
201138	soome-uugri	?soome-uugri =uugri  (SgG  >soome-uuger !02_S	et	f	\N
201139	soome-uugri	?soome-uugri =uugri  (IndPrPs_  >soome-uugrima !28_V	et	f	\N
201140	soome-uugri	?soome-uugri =uugri  (ImpPrSg2  >soome-uugrima !28_V	et	f	\N
201144	girls	?girls =girls  (SgN  >girls !22_S	et	f	\N
201159	kaksteistest	kaksteistest =test  (SgN  >kaks+teis+test !22_S	et	f	\N
201160	kaksteistest	kaksteistest =teiste  (PlEl  >kaks+teist !22_S	et	f	\N
201161	istusivad	?istusivad =istusiva  (PlN  >istusiv !02_A	et	f	\N
201162	istusivad	?istusivad =istusiva  (PlN  >istusiva !16_S	et	f	\N
201171	pudustan	?pudustan =pudusta  (IndPrSg1  >pudustama !27_V	et	f	\N
201172	pudustan	?pudustan =pudustan  (SgN  >pudustan !19_S	et	f	\N
201173	aastaaega	aastaaega =aega  (SgP  >aasta+aeg !22_S	et	f	\N
201174	aastaaega	aastaaega =aega  (SgAdt  >aasta+aeg !22_S	et	f	\N
201183	juhtime	juhtime =ime  (SgN  >juht+ime !16_S	et	f	\N
201184	juhtime	juhtime =ime  (SgG  >juht+ime !16_S	et	f	\N
201189	metsäs	### metsäs	et	f	\N
201201	maakonda	maakonda =maakonda  (SgP  >maakond !22_S	et	f	\N
201202	maakonda	maakonda =maakonda  (SgAdt  >maakond !22_S	et	f	\N
201204	tartumaa	tartumaa =maa  (SgN  >tartu+maa !26_S	et	f	\N
201206	tartumaa	tartumaa =maa  (SgG  >tartu+maa !26_S	et	f	\N
201221	kesk-europas	?kesk-europas =europa  (SgIn  >kesk-europa !01_S	et	f	\N
201223	baden-württemberg	?baden-württemberg =württemberg  (SgN  >baden-württemberg !22_S	et	f	\N
201232	hamburg	?hamburg =hamburg  (SgN  >hamburg !02_S	et	f	\N
201238	thüringen	?thüringen =thüringen  (SgN  >thüringen !19_S	et	f	\N
201242	schleswig-holstein	?schleswig-holstein =holstein  (SgN  >schleswig-holstein !22_S	et	f	\N
201247	köln	?köln =köln  (SgN  >köln !22_S	et	f	\N
201253	rhein	?rhein =rhein  (SgN  >rhein !22_S	et	f	\N
201266	dresdenis	?dresdenis =dresdeni  (SgIn  >dresden !02_S	et	f	\N
201267	dresdenis	?dresdenis =dresdenis  (SgN  >dresdenis !11_S	et	f	\N
201277	papagojiga	### papagojiga	et	f	\N
201292	neju	?neju =neju  (SgN  >neju !17_S	et	f	\N
201293	neju	?neju =neju  (SgG  >neju !17_S	et	f	\N
201294	neju	?neju =neju  (SgP  >neju !17_S	et	f	\N
201295	neju	?neju =neju  (IndPrPs_  >nejuma !27_V	et	f	\N
201296	neju	?neju =neju  (ImpPrSg2  >nejuma !27_V	et	f	\N
201300	niissugused	?niissugused =niissuguse  (PlN  >niissugus !11_S	et	f	\N
201304	karjumisega	karjumisega =karjumise  (SgKom  >karjumine !12_S	et	f	\N
201305	karjumisega	"karjumine %karju  )MINE_vS  <karjuma ;28_V	et	f	\N
201356	aktivsed	?aktivsed =aktivse  (PlN  >aktivne !02_A	et	f	\N
201383	sonjast	?sonjast =sonja  (SgEl  >sonjas !02_A	et	f	\N
201384	sonjast	?sonjast =sonja  (SgEl  >sonja !16_S	et	f	\N
201385	sonjast	?sonjast =sonjas  (SgP  >sonjane !10_A	et	f	\N
201399	söbralikud	?söbralikud =söbraliku  (PlN  >söbralik !25_A	et	f	\N
201400	söbralikud	?söbralikud =söbraliku  (IndPrSg2  >söbralikuma !27_V	et	f	\N
201423	laamasid	laamasid =laama  (PlP  >laama !16_S	et	f	\N
201424	laamasid	laamasid =laama  (PlP  >laam !22_S	et	f	\N
201435	freeman	?freeman =freema  (IndPrSg1  >freemama !29_V	et	f	\N
201436	freeman	?freeman =freeman  (SgN  >freeman !02_S	et	f	\N
201439	liigitamine	liigitamine =liigitamine  (SgN  >liigitamine !12_S	et	f	\N
201440	liigitamine	"liigitamine %liigita  )MINE_vS  <liigitama ;27_V	et	f	\N
201448	vaikust	vaikust =vaikus  (SgP  >vaikus !11~09_S	et	f	\N
201449	vaikust	vaikust =us  (SgP  >vaik+uks !14_S	et	f	\N
201455	sünipäeva	?sünipäeva =sünipäeva  (SgN  >sünipäeva !16_S	et	f	\N
201456	sünipäeva	?sünipäeva =sünipäeva  (SgG  >sünipäeva !16_S	et	f	\N
201477	koliksioneerin	?koliksioneerin =koliksioneeri  (IndPrSg1  >koliksioneerima !28_V	et	f	\N
201478	koliksioneerin	?koliksioneerin =koliksioneerin  (SgN  >koliksioneerin !02_S	et	f	\N
201479	koliksioneerin	?koliksioneerin =ksioneerin  (SgN  >koli+ksioneerin !02_S	et	f	\N
201484	fu	### fu	et	f	\N
201486	lahendaksid	lahendaksid =lahenda  (KndPrSg2  >lahendama !27_V	et	f	\N
201487	lahendaksid	lahendaksid =lahenda  (KndPrPl3  >lahendama !27_V	et	f	\N
201502	õppilastele	?õppilastele =õppilas  (PlAll  >õppilane !12_S	et	f	\N
201121	nädalavahetusest	nädalavahetusest =use  (PlEl  >nädala+vahet+usk !22_S	et	f	\N
201122	nädalavahetusest	nädalavahetusest =vahetuse  (SgEl  >nädala+vahetus !11_S	et	f	\N
201123	nädalavahetusest	"nädala+vahetus %vahe  )TUS2_aS  <nädala+vahe ;16_S	et	f	\N
201124	nädalavahetusest	nädalavahetusest =vahetuses  (SgP  >nädala+vahetusene !12_A	et	f	\N
201125	nädalavahetusest	"nädala+vahetusene %vahetuse  )NE_aA  <nädala+vahetus ;11_S	et	f	\N
201129	jõulepeod	?jõulepeod =jõulepeo  (PlN  >jõulepeo !01_S	et	f	\N
201130	jõulepeod	?jõulepeod =jõulepeod  (SgN  >jõulepeod !22_S	et	f	\N
201131	jõulepeod	?jõulepeod =lepeo  (PlN  >jõu+lepeo !01_S	et	f	\N
201132	jõulepeod	?jõulepeod =lepeod  (SgN  >jõu+lepeod !22_S	et	f	\N
201135	lucia	?lucia =lucia  (SgN  >lucia !01_S	et	f	\N
201136	lucia	?lucia =lucia  (SgG  >lucia !01_S	et	f	\N
201141	julianele	?julianele =juliane  (SgAll  >juliane !16_S	et	f	\N
201142	julianele	?julianele =juliane  (PlAll  >julian !19_S	et	f	\N
201145	juliane	?juliane =juliane  (SgN  >juliane !16_S	et	f	\N
201146	juliane	?juliane =juliane  (SgG  >juliane !16_S	et	f	\N
201147	juliane	?juliane =juliane  (PlP  >julian !19_S	et	f	\N
201148	küpsesid	küpsesid =küpse  (PlP  >küpse !16_A	et	f	\N
201149	küpsesid	küpsesid =küpse  (IndIpfSg2  >küpsema !28_V	et	f	\N
201150	küpsesid	küpsesid =küpse  (IndIpfPl3  >küpsema !28_V	et	f	\N
201165	helistais	?helistais =helista  (PlIn  >helista !01_S	et	f	\N
201166	helistais	?helistais =helistai  (SgIn  >helistai !26_S	et	f	\N
201167	helistais	?helistais =helistais  (SgN  >helistais !22_S	et	f	\N
201168	helistais	?helistais =stai  (SgIn  >heli+stai !26_S	et	f	\N
201169	helistais	?helistais =stais  (SgN  >heli+stais !22_S	et	f	\N
201175	kevadet	kevadet =kevade  (SgP  >kevade !01_S	et	f	\N
201176	kevadet	kevadet =kevade  (SgP  >kevad !02_S	et	f	\N
201179	pilvisusega	pilvisusega =pilvisuse  (SgKom  >pilvisus !11_S	et	f	\N
201182	pilvisusega	"pilvisus %pilvi  )SUS_aS  <pilv ;22_S	et	f	\N
201200	kirre-europas	?kirre-europas =europa  (SgIn  >kirre-europa !01_S	et	f	\N
201209	põhvamaa	?põhvamaa =põhvamaa  (SgN  >põhvamaa !26_S	et	f	\N
201210	põhvamaa	?põhvamaa =põhvamaa  (SgG  >põhvamaa !26_S	et	f	\N
201219	rahvuslikpühapaev	?rahvuslikpühapaev =rahvuslikpühapaev  (SgN  >rahvuslikpühapaev !22_S	et	f	\N
201220	rahvuslikpühapaev	?rahvuslikpühapaev =slikpühapaev  (SgN  >rahvu+slikpühapaev !22_S	et	f	\N
201224	saarland	?saarland =saarland  (SgN  >saarland !02_S	et	f	\N
201225	saarland	?saarland =land  (SgN  >saar+land !22_S	et	f	\N
201230	sachsen-anhalt	?sachsen-anhalt =anha  (SgAbl  >sachsen-anha !16_S	et	f	\N
201231	sachsen-anhalt	?sachsen-anhalt =anhalt  (ID  >sachsen-anhalt !41_D	et	f	\N
201233	mecklenburg-vorpommern	?mecklenburg-vorpommern =vorpommern  (SgN  >mecklenburg-vorpommern !22_S	et	f	\N
201248	stuttgart	?stuttgart =stuttgart  (SgN  >stuttgart !22_S	et	f	\N
201254	spree	?spree =spree  (SgN  >spree !26_S	et	f	\N
201255	spree	?spree =spree  (SgG  >spree !26_S	et	f	\N
201272	kölnis	?kölnis =kölni  (SgIn  >kölni !16_S	et	f	\N
201273	kölnis	?kölnis =kölni  (SgIn  >köln !22_S	et	f	\N
201274	kölnis	?kölnis =kölni  (IndIpfSg3  >kölnima !28_V	et	f	\N
201275	kölnis	?kölnis =kölnis  (SgN  >kölnis !09_S	et	f	\N
201281	papagoja	?papagoja =papagoja  (SgN  >papagoja !01_S	et	f	\N
201282	papagoja	?papagoja =papagoja  (SgG  >papagoja !01_S	et	f	\N
201283	papagoja	?papagoja =papagoja  (SgG  >papagojas !02_A	et	f	\N
201297	ehmusid	ehmusid =ehmu  (PlP  >ehm !22_S	et	f	\N
201298	ehmusid	ehmusid =ehmu  (IndIpfSg2  >ehmuma !27_V	et	f	\N
201299	ehmusid	ehmusid =ehmu  (IndIpfPl3  >ehmuma !27_V	et	f	\N
201306	ootamatusest	ootamatusest =ootamatuse  (SgEl  >ootamatus !11?09_S	et	f	\N
201307	ootamatusest	"ootamatus %oota  )MATUS_aS  <ootama ;29_V	et	f	\N
201309	ootamatusest	ootamatusest =ootamatuses  (SgP  >ootamatusene !12_A	et	f	\N
201310	ootamatusest	"ootamatusene %ootamatuse  )NE_aA  <ootamatus ;09_S	et	f	\N
201311	ootamatusest	"ootamatusene %ootamatuse  )NE_aA  <ootamatus ;11_S	et	f	\N
201313	helega	### helega	et	f	\N
201322	temu	?temu =temu  (SgN  >temu !17_S	et	f	\N
201323	temu	?temu =temu  (SgG  >temu !17_S	et	f	\N
201324	temu	?temu =temu  (SgP  >temu !17_S	et	f	\N
201325	temu	?temu =temu  (IndPrPs_  >temuma !27_V	et	f	\N
201326	temu	?temu =temu  (ImpPrSg2  >temuma !27_V	et	f	\N
201329	semneid	?semneid =semnei  (PlN  >semnei !26_S	et	f	\N
201330	semneid	?semneid =semnei  (SgP  >semnei !26_S	et	f	\N
201331	semneid	?semneid =semneid  (SgN  >semneid !22_S	et	f	\N
201337	kärjus	?kärjus =kärju  (SgIn  >kärju !16_S	et	f	\N
201338	kärjus	?kärjus =kärju  (IndIpfSg3  >kärjuma !27_V	et	f	\N
201339	kärjus	?kärjus =kärjus  (SgN  >kärjus !11~09_S	et	f	\N
201359	kapsat	?kapsat =kapsa  (SgP  >kapsa !16_S	et	f	\N
201360	kapsat	?kapsat =kapsat  (SgN  >kapsat !02_S	et	f	\N
201366	ndiyo	### ndiyo	et	f	\N
201369	safariparki	safariparki =parki  (SgP  >safari+park !22_S	et	f	\N
201371	safariparki	safariparki =parki  (SgAdt  >safari+park !22_S	et	f	\N
201386	ndyo	?ndyo =ndyo  (SgN  >ndyo !26_S	et	f	\N
201387	ndyo	?ndyo =ndyo  (SgG  >ndyo !26_S	et	f	\N
201390	pesakonna	pesakonna =pesakonna  (SgG  >pesakond !22_S	et	f	\N
201192	talves	talves =talve  (PlIn  >talv !22_S	et	f	\N
201193	lueme	?lueme =lueme  (SgN  >lueme !06_S	et	f	\N
201194	lueme	?lueme =lueme  (SgG  >lueme !06_S	et	f	\N
201195	lueme	?lueme =lueme  (PlP  >luem !22_S	et	f	\N
201196	lueme	?lueme =lueme  (IndPrPs_  >luemema !27_V	et	f	\N
201197	lueme	?lueme =lueme  (ImpPrSg2  >luemema !27_V	et	f	\N
201215	väikelinna	väikelinna =linna  (SgG  >väike+linn !22_S	et	f	\N
201216	väikelinna	väikelinna =linna  (SgP  >väike+linn !22_S	et	f	\N
201217	väikelinna	väikelinna =linna  (SgAdt  >väike+linn !22_S	et	f	\N
201222	bayern	?bayern =bayern  (SgN  >bayern !22_S	et	f	\N
201229	niedersachsen	?niedersachsen =niedersachsen  (SgN  >niedersachsen !02_S	et	f	\N
201236	nordrhein-westfalen	?nordrhein-westfalen =westfale  (IndPrSg1  >nordrhein-westfalema !27_V	et	f	\N
201237	nordrhein-westfalen	?nordrhein-westfalen =westfalen  (SgN  >nordrhein-westfalen !19_S	et	f	\N
201244	berliin	?berliin =berliin  (SgN  >berliin !22_S	et	f	\N
201249	essen	?essen =esse  (IndPrSg1  >essema !27_V	et	f	\N
201250	essen	?essen =essen  (SgN  >essen !02_S	et	f	\N
201258	elbe	?elbe =elbe  (SgN  >elbe !06_S	et	f	\N
201259	elbe	?elbe =elbe  (PlP  >elb !22_S	et	f	\N
201260	elbe	?elbe =elbe  (IndPrPs_  >elbema !27_V	et	f	\N
201261	elbe	?elbe =elbe  (ImpPrSg2  >elbema !27_V	et	f	\N
201265	müritz	### müritz	et	f	\N
201276	rakida	?rakida =raki  (Inf  >rakima !27_V	et	f	\N
201280	papagoji	### papagoji	et	f	\N
201284	räkib	?räkib =räki  (IndPrSg3  >räkima !27_V	et	f	\N
201285	räkib	?räkib =räki  (IndPrSg3  >räkkima !28_V	et	f	\N
201286	ehmatavad	ehmatavad =ehmata  (IndPrPl3  >ehmatama !27_V	et	f	\N
201287	ehmatavad	ehmatavad =ehmatava  (PlN  >ehmatav !02_A	et	f	\N
201288	ehmatavad	"ehmatav %ehmata  )V_vA  <ehmatama ;27_V	et	f	\N
201289	ehmus	ehmus =ehmu  (SgIn  >ehm !22_S	et	f	\N
201290	ehmus	ehmus =ehmu  (IndIpfSg3  >ehmuma !27_V	et	f	\N
201291	ehmus	ehmus =ehmus  (SgN  >ehmus !11~09_S	et	f	\N
201302	ootamatut	ootamatut =ootamatu  (SgP  >ootamatu !01_A	et	f	\N
201303	ootamatut	"ootamatu %oota  )MATU_vA  <ootama ;29_V	et	f	\N
201317	ehmutas	?ehmutas =ehmuta  (IndIpfSg3  >ehmutama !27_V	et	f	\N
201327	üllatusega	üllatusega =üllatuse  (SgKom  >üllatus !11_S	et	f	\N
201328	üllatusega	"üllatus %üllata  )US_vS  <üllatama ;27_V	et	f	\N
201332	saattis	?saattis =saatti  (SgIn  >saatt !22_S	et	f	\N
201333	saattis	?saattis =saatti  (IndIpfSg3  >saattima !28_V	et	f	\N
201334	saattis	?saattis =saattis  (ID  >saattis !41_DA	et	f	\N
201335	ehmatasid	ehmatasid =ehmata  (IndIpfSg2  >ehmatama !27_V	et	f	\N
201336	ehmatasid	ehmatasid =ehmata  (IndIpfPl3  >ehmatama !27_V	et	f	\N
201342	hoolitsemine	hoolitsemine =hoolitsemine  (SgN  >hoolitsemine !12_S	et	f	\N
201343	hoolitsemine	"hoolitsemine %hoolitse  )MINE_vS  <hoolitsema ;27_V	et	f	\N
201346	söötmine	söötmine =söötmine  (SgN  >söötmine !12?10_S	et	f	\N
201347	söötmine	"söötmine %sööt  )MINE_vS  <söötma ;34_V	et	f	\N
201353	mäigivad	?mäigivad =mäigi  (IndPrPl3  >mäikima !28_V	et	f	\N
201354	mäigivad	?mäigivad =mäigiva  (PlN  >mäigiva !01_S	et	f	\N
201355	mäigivad	?mäigivad =mäigiva  (PlN  >mäigiv !02_A	et	f	\N
201365	ndiyo	### ndiyo	et	f	\N
201376	lemmikloomade	lemmikloomade =made  (SgN  >lemmik+loo+made !04_S	et	f	\N
201377	lemmikloomade	lemmikloomade =looma  (PlG  >lemmik+loom !22_S	et	f	\N
201378	voodise	?voodise =voodise  (SgG  >voodis !09_S	et	f	\N
201379	voodise	?voodise =voodise  (IndPrPs_  >voodisema !27_V	et	f	\N
201380	voodise	?voodise =voodise  (ImpPrSg2  >voodisema !27_V	et	f	\N
201381	voodise	?voodise =dise  (SgN  >voo+dise !16_S	et	f	\N
201382	voodise	?voodise =dise  (SgG  >voo+dise !16_S	et	f	\N
201396	sonia	?sonia =sonia  (SgN  >sonia !01_S	et	f	\N
201397	sonia	?sonia =sonia  (SgG  >sonia !01_S	et	f	\N
201414	lõvikutsikule	?lõvikutsikule =lõvikutsiku  (SgAll  >lõvikutsik !02_S	et	f	\N
201415	lõvikutsikule	?lõvikutsikule =lõvikutsikule  (PlP  >lõvikutsikul !19_S	et	f	\N
201416	lõvikutsikule	?lõvikutsikule =kutsiku  (SgAll  >lõvi+kutsiku !01_S	et	f	\N
201417	lõvikutsikule	?lõvikutsikule =kutsiku  (SgAll  >lõvi+kutsik !02_S	et	f	\N
201418	lõvikutsikule	?lõvikutsikule =kutsikule  (PlP  >lõvi+kutsikul !19_S	et	f	\N
201427	kerra	kerra =kerra  (ID  >kerra !41_D	et	f	\N
201428	kerra	kerra =kerra  (SgAdt  >kera !17_S	et	f	\N
201431	taastutvumiseks	taastutvumiseks =tutvumise  (SgTr  >taas+tutvumine !12_S	et	f	\N
201432	taastutvumiseks	"taas+tutvumine %tutvu  )MINE_vS  <taas+tutvuma ;27_V	et	f	\N
201433	freeman	?freeman =freema  (IndPrSg1  >freemama !29_V	et	f	\N
201434	freeman	?freeman =freeman  (SgN  >freeman !02_S	et	f	\N
201457	peresisselised	?peresisselised =peresisselise  (PlN  >peresisseline !12_A	et	f	\N
201458	peresisselised	?peresisselised =sisselise  (PlN  >pere+sisseline !12_A	et	f	\N
201496	kammandage	?kammandage =kammanda  (ImpPrPl2  >kammandama !27_V	et	f	\N
201500	organisaatorik	?organisaatorik =organisaatorik  (SgN  >organisaatorik !02_S	et	f	\N
201509	enamuse	enamuse =enamuse  (SgG  >enamus !11_S	et	f	\N
201510	enamuse	"enamus %enama  )US_aS  <enam ;02_A	et	f	\N
201526	varasem	varasem =varasem  (SgN  >varasem !02_A	et	f	\N
201235	berlin	?berlin =berlin  (SgN  >berlin !02_S	et	f	\N
201239	sachsen	?sachsen =sachse  (IndPrSg1  >sachsema !27_V	et	f	\N
201240	sachsen	?sachsen =sachsen  (SgN  >sachsen !02_S	et	f	\N
201241	brandenburg	?brandenburg =brandenburg  (SgN  >brandenburg !22_S	et	f	\N
201246	frankfurt	?frankfurt =frankfurt  (SgN  >frankfurt !22_S	et	f	\N
201262	main	?main =main  (SgN  >main !22_S	et	f	\N
201268	hamburgis	?hamburgis =hamburgi  (SgIn  >hamburg !02_S	et	f	\N
201269	hamburgis	?hamburgis =hamburgi  (SgIn  >hamburk !22_S	et	f	\N
201270	hamburgis	?hamburgis =hamburgi  (IndIpfSg3  >hamburgima !28_V	et	f	\N
201271	hamburgis	?hamburgis =hamburgis  (SgN  >hamburgis !11_S	et	f	\N
201301	papagoiaga	?papagoiaga =papagoia  (SgKom  >papagoia !16_S	et	f	\N
201314	avo	?avo =avo  (SgN  >avo !17~16_S	et	f	\N
201315	avo	?avo =avo  (SgG  >avo !17~16_S	et	f	\N
201316	avo	?avo =avo  (SgP  >avo !17_S	et	f	\N
201350	müravad	müravad =müra  (IndPrPl3  >mürama !27_V	et	f	\N
201351	müravad	müravad =mürava  (PlN  >mürav !02_A	et	f	\N
201352	müravad	"mürav %müra  )V_vA  <mürama ;27_V	et	f	\N
201357	eksotiline	eksotiline =otiline  (SgN  >eks+otiline !12_A	et	f	\N
201358	eksotiline	"eks+otiline %oti  )LINE_aA  <eks+ott ;22_S	et	f	\N
201361	keskpikka	keskpikka =pikka  (SgP  >kesk+pikk !22_S	et	f	\N
201362	keskpikka	keskpikka =pikka  (SgP  >kesk+pikk !22_AS	et	f	\N
201363	keskpikka	keskpikka =pikka  (SgAdt  >kesk+pikk !22_S	et	f	\N
201364	keskpikka	keskpikka =pikka  (SgAdt  >kesk+pikk !22_AS	et	f	\N
201388	lõvikutsikas	lõvikutsikas =kutsika  (SgIn  >lõvi+kutsikas !02_S	et	f	\N
201389	lõvikutsikas	lõvikutsikas =kutsikas  (SgN  >lõvi+kutsikas !02_S	et	f	\N
201394	hülga	hülga =hülga  (IndPrPs_  >hülgama !29_V	et	f	\N
201395	hülga	hülga =hülga  (ImpPrSg2  >hülgama !29_V	et	f	\N
201408	kombel	kombel =kombe  (SgAd  >komme !06_S	et	f	\N
201409	kombel	kombel =kombe  (PlAd  >komp !22_S	et	f	\N
201410	kombel	kombel =kombel  (ID  >kombel !41_DK	et	f	\N
201429	ndiyole	?ndiyole =ndiyole  (IndPrPs_  >ndiyolema !27_V	et	f	\N
201430	ndiyole	?ndiyole =ndiyole  (ImpPrSg2  >ndiyolema !27_V	et	f	\N
201441	mahutitesse	mahutitesse =mahuti  (PlIll  >mahuti !01_S	et	f	\N
201442	mahutitesse	mahutitesse =tite  (SgIll  >mahu+titt !22_S	et	f	\N
201443	mahutitesse	mahutitesse =tite  (PlIll  >mahu+titt !22_S	et	f	\N
201450	positiivsus	positiivsus =positiivsus  (SgN  >positiivsus !11~09_S	et	f	\N
201451	positiivsus	"positiivsus %positiivse  )US_aS  <positiivne ;02_A	et	f	\N
201483	kung-	?kung- =kung  (SgN  >kung !22_S	et	f	\N
201485	kellegil	### kellegil	et	f	\N
201488	kahehümnene	?kahehümnene =kahehümnene  (SgN  >kahehümnene !12_A	et	f	\N
201489	kahehümnene	?kahehümnene =hümnene  (SgN  >kahe+hümnene !10_A	et	f	\N
201494	loendamine	loendamine =loendamine  (SgN  >loendamine !12_S	et	f	\N
201495	loendamine	"loendamine %loenda  )MINE_vS  <loendama ;27_V	et	f	\N
201507	suhtlejad	suhtlejad =suhtleja  (PlN  >suhtleja !01_S	et	f	\N
201508	suhtlejad	"suhtleja %suhtle  )JA_vS  <suhtlema ;30_V	et	f	\N
201537	meresõitja	meresõitja =sõitja  (SgN  >mere+sõitja !01_S	et	f	\N
201538	meresõitja	meresõitja =sõitja  (SgG  >mere+sõitja !01_S	et	f	\N
201551	vanuseks	vanuseks =vanuse  (SgTr  >vanus !09_S	et	f	\N
201552	vanuseks	vanuseks =vanuse  (SgTr  >vanune !10_A	et	f	\N
201553	vanuseks	vanuseks =seks  (SgN  >vanu+seks !22_S	et	f	\N
201557	langemisega	langemisega =langemise  (SgKom  >langemine !12_S	et	f	\N
201558	langemisega	"langemine %lange  )MINE_vS  <langema ;27_V	et	f	\N
201564	germania	?germania =germania  (SgN  >germania !01_S	et	f	\N
201565	germania	?germania =germania  (SgG  >germania !01_S	et	f	\N
201590	fantaasiaküllasem	fantaasiaküllasem =küllasem  (SgN  >fantaasia+küllasem !02_A	et	f	\N
201591	fantaasiaküllasem	"fantaasia+küllasem %külla  )SEM_cA  <fantaasia+küll ;22_S	et	f	\N
201592	fantaasiaküllasem	"fantaasia+küllasem %küllase  )M_cA  <fantaasia+küllane ;10_A	et	f	\N
201601	kirdesse	kirdesse =kirde  (SgIll  >kirre !06_S	et	f	\N
201602	kirdesse	kirdesse =kirdes  (SgAdt  >kirdene !12_A	et	f	\N
201603	kirdesse	"kirdene %kirde  )NE_aA  <kirre ;06_S	et	f	\N
201610	hankimiseks	hankimiseks =hankimise  (SgTr  >hankimine !12_S	et	f	\N
201611	hankimiseks	"hankimine %hanki  )MINE_vS  <hankima ;28_V	et	f	\N
201612	merevaigutee	merevaigutee =tee  (SgN  >mere+vaigu+tee !26_S	et	f	\N
201613	merevaigutee	merevaigutee =tee  (SgG  >mere+vaigu+tee !26_S	et	f	\N
201624	tõenäolisemalt	tõenäolisemalt =näolisema  (SgAbl  >tõe+näolisem !02_A	et	f	\N
201625	tõenäolisemalt	"tõe+näolisem %näo  )LISEM_cA  <tõe+nägu ;18_S	et	f	\N
201626	tõenäolisemalt	"tõe+näolisem %näolise  )M_cA  <tõe+näoline ;10_A	et	f	\N
201627	tõenäolisemalt	"tõe+näolisem %näolise  )M_cA  <tõe+näoline ;12_A	et	f	\N
201628	tõenäolisemalt	"tõe+näolisemalt %näo  )LISEMALT_mD  <tõe+nägu ;18_S	et	f	\N
201629	tõenäolisemalt	"tõe+näolisemalt %näolise  )MALT_mD  <tõe+näoline ;10_A	et	f	\N
201630	tõenäolisemalt	"tõe+näolisemalt %näolise  )MALT_mD  <tõe+näoline ;12_A	et	f	\N
201635	aestide	?aestide =aesti  (PlG  >aest !22_S	et	f	\N
201675	hõbemünti	hõbemünti =münti  (SgP  >hõbe+münt !22_S	et	f	\N
201676	hõbemünti	hõbemünti =münti  (SgAdt  >hõbe+münt !22_S	et	f	\N
201689	ölandil	?ölandil =ölandi  (SgAd  >ölandi !01_S	et	f	\N
201375	sonja	?sonja =sonja  (ImpPrSg2  >sonjama !29_V	et	f	\N
201398	freemanil	?freemanil =freemani  (SgAd  >freeman !02_S	et	f	\N
201401	ndiyot	?ndiyot =ndiyot  (SgN  >ndiyot !02_S	et	f	\N
201419	eesleid	eesleid =eesle  (PlP  >eesel !02_S	et	f	\N
201420	eesleid	eesleid =lei  (PlN  >ees+lei !26_S	et	f	\N
201421	eesleid	eesleid =lei  (SgP  >ees+lei !26_S	et	f	\N
201422	eesleid	eesleid =leid  (SgN  >ees+leid !22_S	et	f	\N
201437	loomaparki	loomaparki =parki  (SgP  >looma+park !22_S	et	f	\N
201438	loomaparki	loomaparki =parki  (SgAdt  >looma+park !22_S	et	f	\N
201444	peremaa	peremaa =maa  (SgN  >pere+maa !26_S	et	f	\N
201445	peremaa	peremaa =maa  (SgG  >pere+maa !26_S	et	f	\N
201459	klaasivese	?klaasivese =klaasivese  (SgG  >klaasivene !12_A	et	f	\N
201460	klaasivese	?klaasivese =vese  (SgN  >klaasi+vese !16_S	et	f	\N
201461	klaasivese	?klaasivese =vese  (SgG  >klaasi+vese !16_S	et	f	\N
201462	klaasivese	?klaasivese =ivese  (SgG  >klaas+ivene !10_A	et	f	\N
201466	kutsekeskhariduskeskuses	kutsekeskhariduskeskuses =use  (PlIn  >kutse+kesk+haridus+kesk+usk !22_S	et	f	\N
201467	kutsekeskhariduskeskuses	kutsekeskhariduskeskuses =keskuse  (SgIn  >kutse+kesk+haridus+keskus !11~09_S	et	f	\N
201468	tallinnaülikooli	?tallinnaülikooli =tallinnaülikooli  (SgN  >tallinnaülikooli !16_S	et	f	\N
201469	tallinnaülikooli	?tallinnaülikooli =tallinnaülikooli  (SgG  >tallinnaülikooli !16_S	et	f	\N
201470	tallinnaülikooli	?tallinnaülikooli =tallinnaülikooli  (SgG  >tallinnaülikool !22_S	et	f	\N
201471	tallinnaülikooli	?tallinnaülikooli =tallinnaülikooli  (SgP  >tallinnaülikool !22_S	et	f	\N
201472	tallinnaülikooli	?tallinnaülikooli =tallinnaülikooli  (SgAdt  >tallinnaülikool !22_S	et	f	\N
201473	tallinnaülikooli	?tallinnaülikooli =tallinnaülikooli  (IndPrPs_  >tallinnaülikoolima !28_V	et	f	\N
201474	tallinnaülikooli	?tallinnaülikooli =tallinnaülikooli  (ImpPrSg2  >tallinnaülikoolima !28_V	et	f	\N
201490	siirust	siirust =siirus  (SgP  >siirus !11~09_S	et	f	\N
201491	siirust	"siirus %siira  )US_aS  <siiras ;07_A	et	f	\N
201497	isiklikus	isiklikus =isikliku  (SgIn  >isiklik !25_A	et	f	\N
201498	isiklikus	isiklikus =isiklikus  (SgN  >isiklikus !11?09_S	et	f	\N
201499	isiklikus	"isiklikus %isikliku  )US_aS  <isiklik ;25_A	et	f	\N
201539	salapärast	salapärast =pära  (SgEl  >sala+pära !17_S	et	f	\N
201540	salapärast	salapärast =päras  (SgP  >sala+pärane !10_A	et	f	\N
201541	salapärast	"sala+pärane %pära  )NE_aA  <sala+pära ;17_S	et	f	\N
201566	aestid	?aestid =aesti  (PlN  >aest !22_S	et	f	\N
201567	aestid	?aestid =aesti  (IndPrSg2  >aestima !28_V	et	f	\N
201574	leedulaste	leedulaste =leedulas  (PlG  >leedulane !12_S	et	f	\N
201575	leedulaste	leedulaste =las  (PlG  >leedu+laps !14_S	et	f	\N
201576	leedulaste	leedulaste =laste  (PlP  >leedu+last !22_S	et	f	\N
201582	keskusest	keskusest =keskuse  (SgEl  >keskus !11~09_S	et	f	\N
201583	keskusest	keskusest =keskuses  (SgP  >keskusene !12_A	et	f	\N
201584	keskusest	"keskusene %keskuse  )NE_aA  <keskus ;09_S	et	f	\N
201585	keskusest	"keskusene %keskuse  )NE_aA  <keskus ;11_S	et	f	\N
201587	keskusest	keskusest =use  (PlEl  >kesk+usk !22_S	et	f	\N
201604	homerose	### homerose	et	f	\N
201621	kauplemisel	kauplemisel =kauplemise  (SgAd  >kauplemine !12_S	et	f	\N
201622	kauplemisel	"kauplemine %kauple  )MINE_vS  <kauplema ;30_V	et	f	\N
201623	helm	?helm =helm  (SgN  >helm !22_S	et	f	\N
201631	koondnimetus	koondnimetus =nimetu  (SgIn  >koond+nimetu !01_A	et	f	\N
201632	koondnimetus	"koond+nimetu %nime  )TU2_kA  <koond+nimi ;20_S	et	f	\N
201633	koondnimetus	koondnimetus =nimetus  (SgN  >koond+nimetus !11_S	et	f	\N
201634	koondnimetus	"koond+nimetus %nime  )TUS2_aS  <koond+nimi ;20_S	et	f	\N
201640	hõlmatavasse	hõlmatavasse =hõlmatava  (SgIll  >hõlmatav !02_A	et	f	\N
201641	hõlmatavasse	"hõlmatav %hõlma  )TAV_vAS  <hõlmama ;29_V	et	f	\N
201644	aastatuhandet	### aastatuhandet	et	f	\N
201653	oletatav	oletatav =oleta  (PtsPrIps  >oletama !27_V	et	f	\N
201654	oletatav	oletatav =oletatav  (SgN  >oletatav !02_A	et	f	\N
201655	oletatav	"oletatav %oleta  )TAV_vAS  <oletama ;27_V	et	f	\N
201659	jõjaretkest	?jõjaretkest =jõjaretke  (PlEl  >jõjaretk !22_S	et	f	\N
201660	jõjaretkest	?jõjaretkest =jõjaretkes  (SgP  >jõjaretkene !12_S	et	f	\N
201670	viikingitest	viikingitest =viikingi  (PlEl  >viiking !02_S	et	f	\N
201671	viikingitest	viikingitest =test  (SgN  >viikingi+test !22_S	et	f	\N
201672	maapõuest	maapõuest =põue  (SgEl  >maa+põu !22_S	et	f	\N
201673	maapõuest	maapõuest =põues  (SgP  >maa+põuene !10_A	et	f	\N
201674	maapõuest	"maa+põuene %põue  )NE_aA  <maa+põu ;22_S	et	f	\N
201681	gestra	?gestra =gestra  (SgN  >gestra !01_S	et	f	\N
201682	gestra	?gestra =gestra  (SgG  >gestra !01_S	et	f	\N
201683	gestra	?gestra =gestra  (IndPrPs_  >gestrama !29_V	et	f	\N
201684	gestra	?gestra =gestra  (ImpPrSg2  >gestrama !29_V	et	f	\N
201686	kurelaste	kurelaste =kurelas  (PlG  >kurelane !12_S	et	f	\N
201687	kurelaste	kurelaste =las  (PlG  >kure+laps !14_S	et	f	\N
201688	kurelaste	kurelaste =laste  (PlP  >kure+last !22_S	et	f	\N
201692	rüüsteretkel	?rüüsteretkel =rüüsteretke  (PlAd  >rüüsteretk !22_S	et	f	\N
201693	rüüsteretkel	?rüüsteretkel =rüüsteretkel  (SgN  >rüüsteretkel !02_S	et	f	\N
201694	rüüsteretkel	?rüüsteretkel =steretke  (PlAd  >rüü+steretk !22_S	et	f	\N
201391	pesakonna	pesakonna =konna  (SgG  >pesa+konn !22_S	et	f	\N
201392	pesakonna	pesakonna =konna  (SgP  >pesa+konn !22_S	et	f	\N
201393	pesakonna	pesakonna =konna  (SgAdt  >pesa+konn !22_S	et	f	\N
201402	ööseks	ööseks =ööse  (PlTr  >öös !22_S	et	f	\N
201403	ööseks	ööseks =ööseks  (ID  >ööseks !41_D	et	f	\N
201404	ööseks	ööseks =seks  (SgN  >öö+seks !22_S	et	f	\N
201405	hoolitsemiseks	hoolitsemiseks =hoolitsemise  (SgTr  >hoolitsemine !12_S	et	f	\N
201406	hoolitsemiseks	"hoolitsemine %hoolitse  )MINE_vS  <hoolitsema ;27_V	et	f	\N
201407	hoolitsemiseks	hoolitsemiseks =emise  (SgTr  >hoo+lits+emis !09_S	et	f	\N
201411	lõvikutsikuga	?lõvikutsikuga =lõvikutsiku  (SgKom  >lõvikutsik !02_S	et	f	\N
201412	lõvikutsikuga	?lõvikutsikuga =kutsiku  (SgKom  >lõvi+kutsiku !01_S	et	f	\N
201413	lõvikutsikuga	?lõvikutsikuga =kutsiku  (SgKom  >lõvi+kutsik !02_S	et	f	\N
201425	hooldajat	hooldajat =hooldaja  (SgP  >hooldaja !01_S	et	f	\N
201426	hooldajat	"hooldaja %hoolda  )JA_vS  <hooldama ;27_V	et	f	\N
201446	hariduskeskusse	hariduskeskusse =usse  (PlP  >haridus+kesk+uss !22_S	et	f	\N
201447	hariduskeskusse	hariduskeskusse =keskus  (SgAdt  >haridus+keskus !11_S	et	f	\N
201452	külalistest	külalistest =külalis  (PlEl  >külaline !12_S	et	f	\N
201453	külalistest	"külaline %küla  )LINE_aA  <küla ;17_S	et	f	\N
201454	külalistest	külalistest =test  (SgN  >külalis+test !22_S	et	f	\N
201463	hingen	?hingen =hinge  (IndPrSg1  >hingema !27_V	et	f	\N
201464	hingen	?hingen =hingen  (SgN  >hingen !02_S	et	f	\N
201465	rääkin	?rääkin =rääkin  (SgN  >rääkin !02_S	et	f	\N
201475	varmistas	?varmistas =varmista  (SgIn  >varmista !01_S	et	f	\N
201476	varmistas	?varmistas =varmista  (IndIpfSg3  >varmistama !27_V	et	f	\N
201480	sportliga	sportliga =liga  (SgN  >sport+liga !17_S	et	f	\N
201481	sportliga	sportliga =liga  (SgG  >sport+liga !17_S	et	f	\N
201482	sportliga	sportliga =liga  (SgP  >sport+liga !17_S	et	f	\N
201492	riielda	riielda =riiel  (Inf  >riidlema !30_V	et	f	\N
201493	riielda	riielda =riiel  (IndPrIps_  >riidlema !30_V	et	f	\N
201501	liiderik	?liiderik =liiderik  (SgN  >liiderik !25_S	et	f	\N
201519	asulakohad	asulakohad =koha  (PlN  >asula+koha !17_S	et	f	\N
201520	asulakohad	asulakohad =koha  (PlN  >asula+koht !22_S	et	f	\N
201521	omavahelistest	omavahelistest =vahelis  (PlEl  >oma+vaheline !12_A	et	f	\N
201522	omavahelistest	"oma+vaheline %vahe  )LINE_aA  <oma+vahe ;16_S	et	f	\N
201523	kroonikatest	kroonikatest =kroonika  (PlEl  >kroonika !01_S	et	f	\N
201524	kroonikatest	kroonikatest =test  (SgN  >kroonika+test !22_S	et	f	\N
201525	kroonikatest	kroonikatest =kate  (PlEl  >krooni+katt !22_S	et	f	\N
201529	pytheas	?pytheas =pythea  (SgIn  >pythea !26_S	et	f	\N
201530	pytheas	?pytheas =pytheas  (SgN  >pytheas !22_S	et	f	\N
201549	välista	välista =välista  (IndPrPs_  >välistama !27_V	et	f	\N
201550	välista	välista =välista  (ImpPrSg2  >välistama !27_V	et	f	\N
201561	tacitus	?tacitus =tacitu  (SgIn  >tacitu !01_AS	et	f	\N
201562	tacitus	?tacitus =tacitu  (IndIpfSg3  >tacituma !27_V	et	f	\N
201563	tacitus	?tacitus =tacitus  (SgN  >tacitus !11_S	et	f	\N
201577	fennide	?fennide =fenni  (PlG  >fenni !16_S	et	f	\N
201578	fennide	?fennide =fenni  (PlG  >fenn !22_S	et	f	\N
201581	tacituse	?tacituse =tacituse  (SgG  >tacitus !11_S	et	f	\N
201593	tacitusel	?tacitusel =tacituse  (SgAd  >tacitus !11_S	et	f	\N
201596	ebamäärane	ebamäärane =määrane  (SgN  >eba+määrane !10_A	et	f	\N
201597	ebamäärane	"eba+määrane %määra  )NE_aA  <eba+määr ;22_S	et	f	\N
201618	vsks	### vsks	et	f	\N
201656	suurvürsti	suurvürsti =vürsti  (SgG  >suur+vürst !22_S	et	f	\N
201657	suurvürsti	suurvürsti =vürsti  (SgP  >suur+vürst !22_S	et	f	\N
201658	suurvürsti	suurvürsti =vürsti  (SgAdt  >suur+vürst !22_S	et	f	\N
201661	hilisemas	hilisemas =hilisema  (SgIn  >hilisem !02_A	et	f	\N
201662	hilisemas	"hilisem %hilise  )M_cA  <hiline ;10_A	et	f	\N
201663	hilisemas	hilisemas =ema  (SgIn  >hilis+ema !17_S	et	f	\N
201664	kaevamistel	kaevamistel =kaevamis  (PlAd  >kaevamine !12_S	et	f	\N
201665	kaevamistel	"kaevamine %kaeva  )MINE_vS  <kaevama ;29_V	et	f	\N
201677	mündid	mündid =mündi  (PlN  >münt !22_S	et	f	\N
201678	mündid	mündid =mündi  (IndPrSg2  >müntima !28_V	et	f	\N
201703	rünnata	rünnata =rünna  (Inf  >ründama !29_V	et	f	\N
201704	rünnata	rünnata =rünna  (IndPrIps_  >ründama !29_V	et	f	\N
201719	norutnud	?norutnud =norutnu  (PlN  >norutnu !01_S	et	f	\N
201720	norutnud	?norutnud =norutnu  (IndPrSg2  >norutnuma !27_V	et	f	\N
201739	huvipakkuvamaid	huvipakkuvamaid =pakkuvama  (PlP  >huvi+pakkuvam !02_A	et	f	\N
201740	huvipakkuvamaid	"huvi+pakkuvam %pakkuva  )M_cA  <huvi+pakkuv ;02_A	et	f	\N
201758	takaks	?takaks =taka  (SgTr  >taka !16_S	et	f	\N
201759	takaks	?takaks =taka  (KndPrPs  >takama !27_V	et	f	\N
201764	puutunuud	?puutunuud =puutunuu  (PlN  >puutunuu !26_S	et	f	\N
201765	puutunuud	?puutunuud =puutunuu  (SgP  >puutunuu !26_S	et	f	\N
201766	puutunuud	?puutunuud =puutunuud  (SgN  >puutunuud !22_S	et	f	\N
201767	puutunuud	?puutunuud =tunuu  (PlN  >puu+tunuu !26_S	et	f	\N
201768	puutunuud	?puutunuud =tunuu  (SgP  >puu+tunuu !26_S	et	f	\N
201769	puutunuud	?puutunuud =tunuud  (SgN  >puu+tunuud !22_S	et	f	\N
201503	õppilastele	?õppilastele =õppilastele  (IndPrPs_  >õppilastelema !36_V	et	f	\N
201504	õppilastele	?õppilastele =õppilastele  (ImpPrSg2  >õppilastelema !36_V	et	f	\N
201505	heamelsed	?heamelsed =heamelse  (PlN  >heamelne !02_A	et	f	\N
201506	heamelsed	?heamelsed =melse  (PlN  >hea+melne !02_A	et	f	\N
201511	kaevatud	kaevatud =kaeva  (PtsPtIps  >kaebama !29_V	et	f	\N
201512	kaevatud	kaevatud =kaeva  (PtsPtIps  >kaevama !29_V	et	f	\N
201513	kaevatud	kaevatud =kaevatu  (PlN  >kaevatu !01_AS	et	f	\N
201514	kaevatud	"kaevatu %kaeva  )TU1_vS  <kaebama ;29_V	et	f	\N
201515	kaevatud	"kaevatu %kaeva  )TU1_vS  <kaevama ;29_V	et	f	\N
201516	kaevatud	kaevatud =kaevatud  (ID  >kaevatud !41_A	et	f	\N
201517	kaevatud	"kaevatud %kaeva  )TUD_vA  <kaebama ;29_V	et	f	\N
201518	kaevatud	"kaevatud %kaeva  )TUD_vA  <kaevama ;29_V	et	f	\N
201531	vanakreeka	?vanakreeka =vanakreeka  (SgN  >vanakreeka !16_S	et	f	\N
201532	vanakreeka	?vanakreeka =vanakreeka  (SgG  >vanakreekas !02_A	et	f	\N
201533	vanakreeka	?vanakreeka =vanakreeka  (SgG  >vanakreeka !16_S	et	f	\N
201534	vanakreeka	?vanakreeka =kreeka  (SgN  >vana+kreeka !16_S	et	f	\N
201535	vanakreeka	?vanakreeka =kreeka  (SgG  >vana+kreekas !02_A	et	f	\N
201536	vanakreeka	?vanakreeka =kreeka  (SgG  >vana+kreeka !16_S	et	f	\N
201546	lääne-euroopa	lääne-euroopa =euroopa  (ID  >lääne-euroopa !41_G	et	f	\N
201547	lääne-euroopa	lääne-euroopa =euroopa  (SgN  >lääne-euroopa !01_H	et	f	\N
201548	lääne-euroopa	lääne-euroopa =euroopa  (SgG  >lääne-euroopa !01_H	et	f	\N
201579	lõunanaabriteks	lõunanaabriteks =brite  (PlTr  >lõuna+naa+britt !22_S	et	f	\N
201580	lõunanaabriteks	lõunanaabriteks =naabri  (PlTr  >lõuna+naaber !02_S	et	f	\N
201594	arvestatavate	arvestatavate =arvestatava  (PlG  >arvestatav !02_A	et	f	\N
201595	arvestatavate	"arvestatav %arvesta  )TAV_vAS  <arvestama ;27_V	et	f	\N
201598	vislast	?vislast =visla  (SgEl  >visla !16_S	et	f	\N
201599	vislast	?vislast =vislas  (SgP  >vislas !07_S	et	f	\N
201600	vislast	?vislast =vislas  (SgP  >vislane !10_A	et	f	\N
201605	etruski	etruski =etruski  (SgG  >etrusk !22_S	et	f	\N
201606	etruski	etruski =etruski  (SgP  >etrusk !22_S	et	f	\N
201607	etruski	etruski =etruski  (SgAdt  >etrusk !22_S	et	f	\N
201608	otsetee	otsetee =tee  (SgN  >otse+tee !26_S	et	f	\N
201609	otsetee	otsetee =tee  (SgG  >otse+tee !26_S	et	f	\N
201617	glaesum	?glaesum =glaesum  (SgN  >glaesum !02_S	et	f	\N
201619	glaes	?glaes =glae  (SgIn  >glae !26_S	et	f	\N
201620	glaes	?glaes =glaes  (SgN  >glaes !09_S	et	f	\N
201636	kirjelduse	kirjelduse =kirjelduse  (SgG  >kirjeldus !11_S	et	f	\N
201637	kirjelduse	"kirjeldus %kirjelda  )US_vS  <kirjeldama ;27_V	et	f	\N
201638	vahemere	vahemere =vahemere  (ID  >vahe+mere !41_G	et	f	\N
201639	vahemere	vahemere =mere  (SgG  >vahe+meri !20_S	et	f	\N
201645	tacitusele	?tacitusele =tacituse  (SgAll  >tacitus !11_S	et	f	\N
201651	ajalooallikateks	ajalooallikateks =ate  (PlTr  >aja+loo+allik+att !22_S	et	f	\N
201652	ajalooallikateks	ajalooallikateks =allika  (PlTr  >aja+loo+allikas !02_S	et	f	\N
201666	nooleotsi	nooleotsi =otsi  (SgG  >noole+ots !22_S	et	f	\N
201667	nooleotsi	nooleotsi =otsi  (SgP  >noole+ots !22_S	et	f	\N
201668	nooleotsi	nooleotsi =otsi  (SgAdt  >noole+ots !22_S	et	f	\N
201669	nooleotsi	nooleotsi =otsi  (PlP  >noole+ots !23?22_S	et	f	\N
201698	hoiatanud	hoiatanud =hoiata  (PtsPtPs  >hoiatama !27_V	et	f	\N
201699	hoiatanud	hoiatanud =hoiatanu  (PlN  >hoiatanu !01_S	et	f	\N
201700	hoiatanud	"hoiatanu %hoiata  )NU_vS  <hoiatama ;27_V	et	f	\N
201701	hoiatanud	hoiatanud =hoiatanud  (ID  >hoiatanud !41_A	et	f	\N
201702	hoiatanud	"hoiatanud %hoiata  )NUD_vA  <hoiatama ;27_V	et	f	\N
201705	hoiatuse	hoiatuse =hoiatuse  (SgG  >hoiatus !11_S	et	f	\N
201706	hoiatuse	"hoiatus %hoiata  )US_vS  <hoiatama ;27_V	et	f	\N
201714	laulnud-tantsinud	laulnud-tantsinud =tantsi  (PtsPtPs  >laulnud-tantsima !28_V	et	f	\N
201715	laulnud-tantsinud	laulnud-tantsinud =tantsinu  (PlN  >laulnud-tantsinu !01_S	et	f	\N
201716	laulnud-tantsinud	"laulnud-tantsinu %tantsi  )NU_vS  <laulnud-tantsima ;28_V	et	f	\N
201717	laulnud-tantsinud	laulnud-tantsinud =tantsinud  (ID  >laulnud-tantsinud !41_A	et	f	\N
201718	laulnud-tantsinud	"laulnud-tantsinud %tantsi  )NUD_vA  <laulnud-tantsima ;28_V	et	f	\N
201729	tapnud	tapnud =tap  (PtsPtPs  >tapma !35_V	et	f	\N
201730	tapnud	tapnud =tapnu  (PlN  >tapnu !01_S	et	f	\N
201731	tapnud	"tapnu %tap  )NU_vS  <tapma ;35_V	et	f	\N
201732	tapnud	tapnud =tapnud  (ID  >tapnud !41_A	et	f	\N
201733	tapnud	"tapnud %tap  )NUD_vA  <tapma ;35_V	et	f	\N
201754	riigieksamist	riigieksamist =eksami  (SgEl  >riigi+eksam !02_S	et	f	\N
201755	riigieksamist	riigieksamist =eksamis  (SgP  >riigi+eksamine !12_S	et	f	\N
201756	riigieksamist	"riigi+eksamine %eksami  )NE_aA  <riigi+eksam ;02_S	et	f	\N
201760	kindlustatus	kindlustatus =kindlustatu  (SgIn  >kindlustatu !01_S	et	f	\N
201761	kindlustatus	"kindlustatu %kindlusta  )TU1_vS  <kindlustama ;27_V	et	f	\N
201762	kindlustatus	kindlustatus =kindlustatus  (SgN  >kindlustatus !11?09_S	et	f	\N
201763	kindlustatus	"kindlustatus %kindlusta  )TUS1_aS  <kindlustama ;27_V	et	f	\N
201805	vajalikuid	?vajalikuid =vajalikui  (PlN  >vajalikui !26_S	et	f	\N
201806	vajalikuid	?vajalikuid =vajalikui  (SgP  >vajalikui !26_S	et	f	\N
201816	nissugusest	?nissugusest =nissuguse  (SgEl  >nissugus !11_S	et	f	\N
201527	varasem	"varasem %vara  )SEM_cA  <vara ;17_S	et	f	\N
201528	varasem	"varasem %varase  )M_cA  <varane ;10_A	et	f	\N
201542	thule	?thule =thule  (SgN  >thule !16_S	et	f	\N
201543	thule	?thule =thule  (SgG  >thule !16_S	et	f	\N
201544	thule	?thule =thule  (IndPrPs_  >thulema !27_V	et	f	\N
201545	thule	?thule =thule  (ImpPrSg2  >thulema !27_V	et	f	\N
201554	kaali	kaali =kaali  (SgG  >kaal !22_S	et	f	\N
201555	kaali	kaali =kaali  (SgP  >kaal !22_S	et	f	\N
201556	kaali	kaali =kaali  (SgAdt  >kaal !22_S	et	f	\N
201559	saaremaad	saaremaad =maa  (PlN  >saare+maa !26_S	et	f	\N
201560	saaremaad	saaremaad =maa  (SgP  >saare+maa !26_S	et	f	\N
201568	aestii	?aestii =aestii  (SgN  >aestii !26_S	et	f	\N
201569	aestii	?aestii =aestii  (SgG  >aestii !26_S	et	f	\N
201570	visla	?visla =visla  (SgN  >visla !16_S	et	f	\N
201571	visla	?visla =visla  (SgG  >visla !16_S	et	f	\N
201572	visla	?visla =visla  (IndPrPs_  >vislama !29_V	et	f	\N
201573	visla	?visla =visla  (ImpPrSg2  >vislama !29_V	et	f	\N
201586	ebamäärasemaks	ebamäärasemaks =määrasema  (SgTr  >eba+määrasem !02_A	et	f	\N
201588	ebamäärasemaks	"eba+määrasem %määra  )SEM_cA  <eba+määr ;22_S	et	f	\N
201589	ebamäärasemaks	"eba+määrasem %määrase  )M_cA  <eba+määrane ;10_A	et	f	\N
201614	nero	?nero =nero  (SgN  >nero !17~16_S	et	f	\N
201615	nero	?nero =nero  (SgG  >nero !17~16_S	et	f	\N
201616	nero	?nero =nero  (SgP  >nero !17_S	et	f	\N
201642	kultuuripilti	kultuuripilti =pilti  (SgP  >kultuuri+pilt !22_S	et	f	\N
201643	kultuuripilti	kultuuripilti =pilti  (SgAdt  >kultuuri+pilt !22_S	et	f	\N
201646	tõusnud	tõusnud =tõus  (PtsPtPs  >tõusma !32_V	et	f	\N
201647	tõusnud	tõusnud =tõusnu  (PlN  >tõusnu !01_S	et	f	\N
201648	tõusnud	"tõusnu %tõus  )NU_vS  <tõusma ;32_V	et	f	\N
201649	tõusnud	tõusnud =tõusnud  (ID  >tõusnud !41_A	et	f	\N
201650	tõusnud	"tõusnud %tõus  )NUD_vA  <tõusma ;32_V	et	f	\N
201679	haruldasemate	haruldasemate =haruldasema  (PlG  >haruldasem !02_A	et	f	\N
201680	haruldasemate	"haruldasem %haruldase  )M_cA  <haruldane ;12_A	et	f	\N
201685	dorum	?dorum =dorum  (SgN  >dorum !02_S	et	f	\N
201734	kaotusi	kaotusi =kaotusi  (PlP  >kaotus !11_S	et	f	\N
201735	kaotusi	"kaotus %kaota  )US_vS  <kaotama ;27_V	et	f	\N
201736	kaotusi	"kaotus %kao  )TUS1_aS  <kaduma ;28_V	et	f	\N
201737	kaotusi	"kaotus %kao  )TUS2_aS  <kabu ;18_S	et	f	\N
201738	kaotusi	"kaotus %kao  )TUS2_aS  <kadu ;18_S	et	f	\N
201741	esiajaloole	esiajaloole =loo  (SgAll  >esi+aja+lugu !18_S	et	f	\N
201742	esiajaloole	esiajaloole =loo  (SgAll  >esi+aja+loog !22_S	et	f	\N
201743	esiajaloole	esiajaloole =loo  (SgAll  >esi+aja+lood !22_S	et	f	\N
201744	kujuteldamatult	kujuteldamatult =kujuteldamatu  (SgAbl  >kujuteldamatu !01_A	et	f	\N
201745	kujuteldamatult	"kujuteldamatu %kujutel  )TAMATU_vA  <kujutelema ;36_V	et	f	\N
201746	kujuteldamatult	kujuteldamatult =kujuteldamatult  (ID  >kujuteldamatult !41_D	et	f	\N
201747	kujuteldamatult	"kujuteldamatult %kujutel  )TAMATULT_mD  <kujutelema ;36_V	et	f	\N
201748	kujuteldamatult	"kujuteldamatult %kujuteldamatu  )LT_mD  <kujuteldamatu ;01_A	et	f	\N
201749	teiga	?teiga =tei  (SgKom  >tei !26_S	et	f	\N
201750	teiga	?teiga =teiga  (SgN  >teiga !16_S	et	f	\N
201751	teiga	?teiga =teiga  (SgG  >teiga !16_S	et	f	\N
201752	teiga	?teiga =teiga  (IndPrPs_  >teigama !29_V	et	f	\N
201753	teiga	?teiga =teiga  (ImpPrSg2  >teigama !29_V	et	f	\N
201770	viivida	?viivida =viivi  (Inf  >viivima !28_V	et	f	\N
201787	artiki	?artiki =artiki  (SgN  >artiki !01_S	et	f	\N
201788	artiki	?artiki =artiki  (SgG  >artiki !01_S	et	f	\N
201789	artiki	?artiki =artiki  (SgG  >artik !02_S	et	f	\N
201790	artiki	?artiki =artiki  (IndPrPs_  >artikkima !28_V	et	f	\N
201791	artiki	?artiki =artiki  (ImpPrSg2  >artikkima !28_V	et	f	\N
201807	vahendusi	vahendusi =vahendusi  (PlP  >vahendus !11_S	et	f	\N
201808	vahendusi	"vahendus %vahenda  )US_vS  <vahendama ;27_V	et	f	\N
201813	ebamääratud	ebamääratud =määratu  (PlN  >eba+määratu !01_AS	et	f	\N
201814	ebamääratud	"eba+määratu %määra  )TU2_kA  <eba+määr ;22_S	et	f	\N
201815	ebamääratud	ebamääratud =määratud  (ID  >eba+määratud !41_A	et	f	\N
201852	töölast	töölast =ast  (SgN  >tööl+ast !22_S	et	f	\N
201853	töölast	töölast =la  (SgEl  >töö+la !26_S	et	f	\N
201854	töölast	töölast =las  (SgP  >töö+laps !14_S	et	f	\N
201855	töölast	töölast =last  (SgN  >töö+last !22_S	et	f	\N
201861	seelist	?seelist =seeli  (SgEl  >seeli !16_S	et	f	\N
201862	seelist	?seelist =seeli  (SgEl  >seel !22_S	et	f	\N
201863	seelist	?seelist =seelis  (SgP  >seelis !09_S	et	f	\N
201864	seelist	?seelist =seelis  (SgP  >seeline !10_A	et	f	\N
201865	seelist	?seelist =seelist  (SgN  >seelist !22_S	et	f	\N
201866	seelist	?seelist =list  (SgN  >see+list !22_S	et	f	\N
201890	sarnasel	sarnasel =sarnase  (SgAd  >sarnane !10_A	et	f	\N
201891	sarnasel	"sarnane %sarna  )NE_aA  <sarn ;22_S	et	f	\N
201900	tõlkimisest	tõlkimisest =tõlkimise  (SgEl  >tõlkimine !12_S	et	f	\N
201901	tõlkimisest	"tõlkimine %tõlki  )MINE_vS  <tõlkima ;28_V	et	f	\N
201904	teiege	### teiege	et	f	\N
201918	vannemad	?vannemad =vannema  (PlN  >vannem !02_A	et	f	\N
201690	ölandil	?ölandil =ölandi  (SgAd  >öland !02_S	et	f	\N
201691	ölandil	?ölandil =ölandi  (SgAd  >ölant !22_S	et	f	\N
201707	õelnud	?õelnud =õelnu  (PlN  >õelnu !01_S	et	f	\N
201708	õelnud	?õelnud =õelnu  (IndPrSg2  >õelnuma !27_V	et	f	\N
201709	õelnud	?õelnud =õelnud  (ID  >õelnud !41_A	et	f	\N
201721	puumaterjalist	puumaterjalist =materjali  (SgEl  >puu+materjal !19_S	et	f	\N
201722	puumaterjalist	puumaterjalist =materjalis  (SgP  >puu+materjaline !12_A	et	f	\N
201723	puumaterjalist	"puu+materjaline %materjali  )NE_aA  <puu+materjal ;19_S	et	f	\N
201757	situatsion	?situatsion =situatsion  (SgN  >situatsion !19~02_S	et	f	\N
201780	samusugune	?samusugune =samusugune  (SgN  >samusugune !12_A	et	f	\N
201781	samusugune	?samusugune =samusugune  (PlP  >samusugun !19_S	et	f	\N
201809	hakkida	hakkida =hakki  (Inf  >hakkima !28_V	et	f	\N
201810	hakkida	hakkida =ida  (SgN  >hakk+ida !17_S	et	f	\N
201811	hakkida	hakkida =ida  (SgG  >hakk+ida !17_S	et	f	\N
201812	hakkida	hakkida =ida  (SgP  >hakk+ida !17_S	et	f	\N
201823	sotsiaalsfääri	sotsiaalsfääri =sfääri  (SgG  >sotsiaal+sfäär !22_S	et	f	\N
201824	sotsiaalsfääri	sotsiaalsfääri =sfääri  (SgP  >sotsiaal+sfäär !22_S	et	f	\N
201825	sotsiaalsfääri	sotsiaalsfääri =sfääri  (SgAdt  >sotsiaal+sfäär !22_S	et	f	\N
201845	töölased	?töölased =töölase  (PlN  >töölane !12?10_S	et	f	\N
201860	staaziga	?staaziga =staazi  (SgKom  >staazi !16_S	et	f	\N
201870	jäämine	jäämine =jäämine  (SgN  >jäämine !12?10_S	et	f	\N
201871	jäämine	"jäämine %jää  )MINE_vS  <jääma ;37_V	et	f	\N
201872	jäämine	"jäämine %jäämi  )NE_aA  <jääm ;22_S	et	f	\N
201873	abituriendite	?abituriendite =abituriendi  (IndPrPl2  >abiturientima !28_V	et	f	\N
201874	abituriendite	?abituriendite =riendi  (PlG  >abitu+riend !02_S	et	f	\N
201882	igakuiselt	igakuiselt =kuise  (SgAbl  >iga+kuine !10_A	et	f	\N
201883	igakuiselt	"iga+kuine %kui  )NE_aA  <iga+kuu ;26_S	et	f	\N
201884	igakuiselt	"iga+kuiselt %kuise  )LT_mD  <iga+kuine ;10_A	et	f	\N
201925	solvava	solvava =solvava  (SgG  >solvav !02_A	et	f	\N
201926	solvava	"solvav %solva  )V_vA  <solvama ;29_V	et	f	\N
201931	solvav	solvav =solva  (PtsPrPs  >solvama !29_V	et	f	\N
201932	solvav	solvav =solvav  (SgN  >solvav !02_A	et	f	\N
201933	solvav	"solvav %solva  )V_vA  <solvama ;29_V	et	f	\N
201951	praegustest	praegustest =praegus  (PlEl  >praegune !10~12_A	et	f	\N
201952	praegustest	praegustest =test  (SgN  >praegus+test !22_S	et	f	\N
201966	arstiteenindusest	arstiteenindusest =teeninduse  (SgEl  >arsti+teenindus !11_S	et	f	\N
201967	arstiteenindusest	arstiteenindusest =teeninduses  (SgP  >arsti+teenindusene !12_A	et	f	\N
201968	arstiteenindusest	"arsti+teenindusene %teeninduse  )NE_aA  <arsti+teenindus ;11_S	et	f	\N
201972	käiv	käiv =käi  (PtsPrPs  >käima !38_V	et	f	\N
201973	käiv	käiv =käiv  (SgN  >käiv !02_A	et	f	\N
201974	käiv	"käiv %käi  )V_vA  <käima ;38_V	et	f	\N
201979	austavalt	austavalt =austava  (SgAbl  >austav !02_A	et	f	\N
201980	austavalt	"austav %austa  )V_vA  <austama ;27_V	et	f	\N
201981	austavalt	austavalt =austavalt  (ID  >austavalt !41_D	et	f	\N
201982	austavalt	"austavalt %austa  )VALT_mD  <austama ;27_V	et	f	\N
201983	austavalt	"austavalt %austava  )LT_mD  <austav ;02_A	et	f	\N
202002	ferrari	?ferrari =ferrari  (SgN  >ferrari !01_S	et	f	\N
202003	ferrari	?ferrari =ferrari  (SgG  >ferrari !01_S	et	f	\N
202004	ferrari	?ferrari =ferrari  (SgG  >ferrar !02_S	et	f	\N
202018	koolilaps	koolilaps =laps  (SgN  >kooli+laps !14_S	et	f	\N
202020	koolilaps	koolilaps =laps  (SgN  >kooli+laps !22_S	et	f	\N
202024	abiturientile	### abiturientile	et	f	\N
202042	graadi	?graadi =graadi  (SgN  >graadi !16_S	et	f	\N
202043	graadi	?graadi =graadi  (SgG  >graadi !16_S	et	f	\N
202044	graadi	?graadi =graadi  (SgG  >graat !22_S	et	f	\N
202045	graadi	?graadi =graadi  (SgP  >graad !22_S	et	f	\N
202046	graadi	?graadi =graadi  (SgAdt  >graad !22_S	et	f	\N
202047	graadi	?graadi =graadi  (IndPrPs_  >graatima !28_V	et	f	\N
202048	graadi	?graadi =graadi  (ImpPrSg2  >graatima !28_V	et	f	\N
202071	hool	hool =hoo  (SgAd  >hoog !22_S	et	f	\N
202072	hool	hool =hool  (SgN  >hool !13_S	et	f	\N
202073	kahekümneaastlased	?kahekümneaastlased =kahekümneaastlase  (PlN  >kahekümneaastlane !12?10_S	et	f	\N
202074	kahekümneaastlased	?kahekümneaastlased =aastlase  (PlN  >kahe+kümne+aastlane !12?10_S	et	f	\N
202075	kahekümneaastlased	?kahekümneaastlased =kümneaastlase  (PlN  >kahe+kümneaastlane !12?10_S	et	f	\N
202084	elukutses	elukutses =kutse  (SgIn  >elu+kutse !06_S	et	f	\N
202085	elukutses	elukutses =kutse  (PlIn  >elu+kuts !22_S	et	f	\N
202091	kasutu	kasutu =kasutu  (SgN  >kasutu !01_A	et	f	\N
202092	kasutu	"kasutu %kasu  )TU2_kA  <kasu ;17_S	et	f	\N
202093	kasutu	kasutu =kasutu  (SgG  >kasutu !01_A	et	f	\N
202094	istuvadki	istuvadki =istu  (IndPrPl3^  >istuma !28_V	et	f	\N
202095	istuvadki	istuvadki =istuva  (PlN^  >istuv !02_A	et	f	\N
202096	istuvadki	"istuv %istu  )V_vA^  <istuma ;28_V	et	f	\N
202107	ajalehekirjutis	ajalehekirjutis =kirjuti  (SgIn  >aja+lehe+kirjuti !01_S	et	f	\N
202108	ajalehekirjutis	ajalehekirjutis =kirjutis  (SgN  >aja+lehe+kirjutis !11_S	et	f	\N
202122	ollo	?ollo =ollo  (SgN  >ollo !16_S	et	f	\N
201695	rüüsteretkel	?rüüsteretkel =steretkel  (SgN  >rüü+steretkel !02_S	et	f	\N
201696	väejuhte	väejuhte =juhte  (SgG  >väe+juhe !06_S	et	f	\N
201697	väejuhte	väejuhte =juhte  (PlP  >väe+juht !22_S	et	f	\N
201710	otsustavat	otsustavat =otsusta  (KvtPrPs  >otsustama !27_V	et	f	\N
201711	otsustavat	otsustavat =otsustava  (SgP  >otsustav !02_A	et	f	\N
201712	otsustavat	"otsustav %otsusta  )V_vA  <otsustama ;27_V	et	f	\N
201713	otsustavat	otsustavat =ustava  (SgP  >ots+ustav !02_A	et	f	\N
201724	vallutanud	vallutanud =valluta  (PtsPtPs  >vallutama !27_V	et	f	\N
201725	vallutanud	vallutanud =vallutanu  (PlN  >vallutanu !01_S	et	f	\N
201726	vallutanud	"vallutanu %valluta  )NU_vS  <vallutama ;27_V	et	f	\N
201727	vallutanud	vallutanud =vallutanud  (ID  >vallutanud !41_A	et	f	\N
201728	vallutanud	"vallutanud %valluta  )NUD_vA  <vallutama ;27_V	et	f	\N
201773	majandusteatusosakonnas	?majandusteatusosakonnas =majandusteatusosakonna  (SgIn  >majandusteatusosakonna !16_S	et	f	\N
201774	majandusteatusosakonnas	?majandusteatusosakonnas =majandusteatusosakonna  (SgIn  >majandusteatusosakond !22_S	et	f	\N
201775	majandusteatusosakonnas	?majandusteatusosakonnas =teatusosakonna  (SgIn  >majandus+teatusosakonna !16_S	et	f	\N
201776	majandusteatusosakonnas	?majandusteatusosakonnas =teatusosakonna  (SgIn  >majandus+teatusosakond !22_S	et	f	\N
201782	abituriendidest	?abituriendidest =abituriendi  (PlEl  >abituriend !22_S	et	f	\N
201783	abituriendidest	?abituriendidest =abituriendides  (SgP  >abituriendidene !12_A	et	f	\N
201784	abituriendidest	?abituriendidest =riendides  (SgP  >abitu+riendidene !12_A	et	f	\N
201785	abituriendidest	?abituriendidest =turiendi  (PlEl  >abi+turiend !22_S	et	f	\N
201786	abituriendidest	?abituriendidest =turiendides  (SgP  >abi+turiendidene !12_A	et	f	\N
201792	tänavatest	tänavatest =tänava  (PlEl  >tänav !02_A	et	f	\N
201793	tänavatest	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
201794	tänavatest	tänavatest =tänava  (PlEl  >tänav !02_S	et	f	\N
201795	tänavatest	tänavatest =test  (SgN  >tänava+test !22_S	et	f	\N
201796	tänavatest	tänavatest =ate  (PlEl  >tänav+att !22_S	et	f	\N
201797	tänavatest	tänavatest =vate  (PlEl  >täna+vatt !22_S	et	f	\N
201798	laiskjatest	?laiskjatest =laiskja  (PlEl  >laiskja !01_S	et	f	\N
201799	laiskjatest	?laiskjatest =laiskja  (PlEl  >laiskjas !02_A	et	f	\N
201800	laiskjatest	?laiskjatest =laiskjate  (PlEl  >laiskjatt !22_S	et	f	\N
201801	laiskjatest	?laiskjatest =laiskjates  (SgP  >laiskjatene !12_A	et	f	\N
201802	laiskjatest	?laiskjatest =jate  (PlEl  >laisk+jatt !22_S	et	f	\N
201803	laiskjatest	?laiskjatest =jates  (SgP  >laisk+jates !09_S	et	f	\N
201804	laiskjatest	?laiskjatest =jates  (SgP  >laisk+jatene !10_A	et	f	\N
201818	vatamata	?vatamata =vata  (SupAb  >vatama !27_V	et	f	\N
201819	vatamata	?vatamata =vatama  (SgAb  >vatam !02_A	et	f	\N
201820	vatamata	?vatamata =vatamata  (ID  >vatamata !41_A	et	f	\N
201821	vatamata	?vatamata =vatamata  (IndPrPs_  >vatamatama !27_V	et	f	\N
201822	vatamata	?vatamata =vatamata  (ImpPrSg2  >vatamatama !27_V	et	f	\N
201830	optimistidek	### optimistidek	et	f	\N
201836	kutsekoolisse	kutsekoolisse =kooli  (SgIll  >kutse+kool !22_S	et	f	\N
201837	kutsekoolisse	kutsekoolisse =kooli  (PlIll  >kutse+kool !22_S	et	f	\N
201856	töölast	töölast =ast  (SgN  >tööl+ast !22_S	et	f	\N
201857	töölast	töölast =la  (SgEl  >töö+la !26_S	et	f	\N
201858	töölast	töölast =las  (SgP  >töö+laps !14_S	et	f	\N
201859	töölast	töölast =last  (SgN  >töö+last !22_S	et	f	\N
201885	rangemaks	rangemaks =rangema  (SgTr  >rangem !02_A	et	f	\N
201886	rangemaks	"rangem %range  )M_cA  <range ;01_A	et	f	\N
201887	rangemaks	rangemaks =ema  (SgTr  >rang+ema !17_S	et	f	\N
201892	tueb	?tueb =tueb  (SgN  >tueb !22_S	et	f	\N
201902	teiest	?teiest =teie  (SgEl  >teie !06_S	et	f	\N
201903	teiest	?teiest =teies  (SgP  >teiene !10_A	et	f	\N
201913	tegivusi	?tegivusi =tegivusi  (PlP  >tegivus !11_S	et	f	\N
201914	tehnologiad	?tehnologiad =tehnologia  (PlN  >tehnologia !01_S	et	f	\N
201915	tehnologiad	?tehnologiad =tehnologiad  (SgN  >tehnologiad !22_S	et	f	\N
201916	tehnologiad	?tehnologiad =logia  (PlN  >tehno+logia !01_S	et	f	\N
201917	tehnologiad	?tehnologiad =logiad  (SgN  >tehno+logiad !22_S	et	f	\N
201924	kalep	?kalep =kalep  (SgN  >kalep !02_S	et	f	\N
201934	10dets2005	?dets =dets  (SgN  >dets !22_S	et	f	\N
201936	mõnidel	### mõnidel	et	f	\N
201946	erilisemaid	erilisemaid =erilisema  (PlP  >erilisem !02_A	et	f	\N
201947	erilisemaid	"erilisem %eri  )LISEM_cA  <eri ;17_S	et	f	\N
201948	erilisemaid	"erilisem %erilise  )M_cA  <eriline ;12_A	et	f	\N
201964	sellineeriala	?sellineeriala =sellineeriala  (SgN  >sellineeriala !01_S	et	f	\N
201965	sellineeriala	?sellineeriala =sellineeriala  (SgG  >sellineeriala !01_S	et	f	\N
201977	õppatajana	?õppatajana =õppataja  (SgEs  >õppataja !01_S	et	f	\N
201978	õppatajana	?õppatajana =õppataja  (SgEs  >õppatajas !02_A	et	f	\N
201987	sjukune	?sjukune =sjukune  (SgN  >sjukune !10_A	et	f	\N
201988	sjukune	?sjukune =sjukune  (IndPrPs_  >sjukunema !27_V	et	f	\N
201989	sjukune	?sjukune =sjukune  (ImpPrSg2  >sjukunema !27_V	et	f	\N
202021	nõustuvad	nõustuvad =nõustu  (IndPrPl3  >nõustuma !27_V	et	f	\N
202022	nõustuvad	nõustuvad =nõustuva  (PlN  >nõustuv !02_A	et	f	\N
202023	nõustuvad	"nõustuv %nõustu  )V_vA  <nõustuma ;27_V	et	f	\N
201771	kaheksateisaastane	kaheksateisaastane =aastane  (SgN  >kaheksa+teis+aastane !12~10_A	et	f	\N
201772	kaheksateisaastane	"kaheksa+teis+aastane %aasta  )NE_aA  <kaheksa+teis+aasta ;01_S	et	f	\N
201777	mässavad	mässavad =mässa  (IndPrPl3  >mässama !29_V	et	f	\N
201778	mässavad	mässavad =mässava  (PlN  >mässav !02_A	et	f	\N
201779	mässavad	"mässav %mässa  )V_vA  <mässama ;29_V	et	f	\N
201826	seeiloos	?seeiloos =seeiloo  (SgIn  >seeiloo !26_S	et	f	\N
201827	seeiloos	?seeiloos =seeiloos  (SgN  >seeiloos !22_S	et	f	\N
201828	seeiloos	?seeiloos =iloo  (SgIn  >see+iloo !26_S	et	f	\N
201829	seeiloos	?seeiloos =iloos  (SgN  >see+iloos !22_S	et	f	\N
201831	tulevikuplaanit	?tulevikuplaanit =tulevikuplaani  (SgP  >tulevikuplaani !16_S	et	f	\N
201832	tulevikuplaanit	?tulevikuplaanit =plaani  (SgP  >tuleviku+plaani !16_S	et	f	\N
201833	tulevikuplaanit	?tulevikuplaanit =plaanit  (SgN  >tuleviku+plaanit !02_S	et	f	\N
201834	tulevikuplaanit	?tulevikuplaanit =ikuplaani  (SgP  >tulev+ikuplaani !16_S	et	f	\N
201835	tulevikuplaanit	?tulevikuplaanit =vikuplaani  (SgP  >tule+vikuplaani !16_S	et	f	\N
201838	riigsse	?riigsse =riigsse  (SgN  >riigsse !06_S	et	f	\N
201839	riigsse	?riigsse =riigsse  (SgG  >riigsne !02_A	et	f	\N
201840	riigsse	?riigsse =riigsse  (SgG  >riigsse !06_S	et	f	\N
201841	riigsse	?riigsse =riigsse  (PlP  >riigss !22_S	et	f	\N
201842	riigsse	?riigsse =riigsse  (IndPrPs_  >riigssema !27_V	et	f	\N
201843	riigsse	?riigsse =riigsse  (ImpPrSg2  >riigssema !27_V	et	f	\N
201875	eelistaksid	eelistaksid =eelista  (KndPrSg2  >eelistama !27_V	et	f	\N
201876	eelistaksid	eelistaksid =eelista  (KndPrPl3  >eelistama !27_V	et	f	\N
201877	eelistaksid	eelistaksid =taksi  (PlN  >eelis+taks !22_S	et	f	\N
201878	abiturienditel	?abiturienditel =abituriendite  (PlAd  >abiturienditt !22_S	et	f	\N
201879	abiturienditel	?abiturienditel =riendi  (PlAd  >abitu+riend !02_S	et	f	\N
201880	abiturienditel	?abiturienditel =riendite  (PlAd  >abitu+rienditt !22_S	et	f	\N
201881	abiturienditel	?abiturienditel =turiendite  (PlAd  >abi+turienditt !22_S	et	f	\N
201888	hindamine	hindamine =hindamine  (SgN  >hindamine !12_S	et	f	\N
201889	hindamine	"hindamine %hinda  )MINE_vS  <hindama ;29_V	et	f	\N
201893	vähenõudike	?vähenõudike =vähenõudike  (SgN  >vähenõudike !12_S	et	f	\N
201894	vähenõudike	?vähenõudike =vähenõudike  (PlG  >vähenõudik !25_S	et	f	\N
201895	vähenõudike	?vähenõudike =dike  (SgN  >vähe+nõu+dike !06_S	et	f	\N
201896	vähenõudike	?vähenõudike =nõudike  (SgN  >vähe+nõudike !12_S	et	f	\N
201905	thaksid	?thaksid =thaksi  (PlN  >thaksi !16_S	et	f	\N
201906	thaksid	?thaksid =thaksi  (PlN  >thaks !22_S	et	f	\N
201907	thaksid	?thaksid =thaksi  (IndPrSg2  >thaksima !28_V	et	f	\N
201935	mõnidel	### mõnidel	et	f	\N
201942	tulemist	tulemist =tulemi  (SgEl  >tulem !02_S	et	f	\N
201943	tulemist	tulemist =tulemis  (SgP  >tulemine !12_S	et	f	\N
201944	tulemist	"tulemine %tule  )MINE_vS  <tulema ;36_V	et	f	\N
201945	tulemist	"tulemine %tulemi  )NE_aA  <tulem ;02_S	et	f	\N
201953	riskiks	riskiks =riski  (SgTr  >risk !22_S	et	f	\N
201954	riskiks	riskiks =riski  (KndPrPs  >riskima !28_V	et	f	\N
201969	õpeteja	?õpeteja =õpeteja  (SgN  >õpeteja !01_S	et	f	\N
201970	õpeteja	?õpeteja =õpeteja  (SgG  >õpeteja !01_S	et	f	\N
201971	õpeteja	?õpeteja =õpeteja  (SgG  >õpetejas !02_A	et	f	\N
201975	valimiseks	valimiseks =valimise  (SgTr  >valimine !12_S	et	f	\N
201976	valimiseks	"valimine %vali  )MINE_vS  <valima ;27_V	et	f	\N
201984	ametikohad	ametikohad =koha  (PlN  >ameti+koha !17_S	et	f	\N
201985	ametikohad	ametikohad =koha  (PlN  >ameti+koht !22_S	et	f	\N
202009	tuletõrjajaka	?tuletõrjajaka =tuletõrjajaka  (SgN  >tuletõrjajaka !16_S	et	f	\N
202010	tuletõrjajaka	?tuletõrjajaka =tuletõrjajaka  (SgG  >tuletõrjajakas !02_A	et	f	\N
202011	tuletõrjajaka	?tuletõrjajaka =tuletõrjajaka  (SgG  >tuletõrjajaka !16_S	et	f	\N
202012	tuletõrjajaka	?tuletõrjajaka =tõrjajaka  (SgN  >tule+tõrjajaka !16_S	et	f	\N
202013	tuletõrjajaka	?tuletõrjajaka =tõrjajaka  (SgG  >tule+tõrjajakas !02_A	et	f	\N
202014	tuletõrjajaka	?tuletõrjajaka =tõrjajaka  (SgG  >tule+tõrjajaka !16_S	et	f	\N
202038	psühholoog	psühholoog =psühholoog  (SgN  >psühholoog !22_S	et	f	\N
202039	psühholoog	psühholoog =loog  (SgN  >psühho+loog !22_S	et	f	\N
202052	sotsiaaltöötajaks	sotsiaaltöötajaks =jaks  (SgN  >sotsiaal+tööta+jaks !22_S	et	f	\N
202053	sotsiaaltöötajaks	sotsiaaltöötajaks =töötaja  (SgTr  >sotsiaal+töötaja !01_S	et	f	\N
202059	virelda	virelda =virel  (Inf  >virelema !31_V	et	f	\N
202060	virelda	virelda =virel  (IndPrIps_  >virelema !31_V	et	f	\N
202061	httpwwwekspresseeviewdoc54f0555e004dbacec2257186002b9be3	### httpwwwekspresseeviewdoc54f0555e004dbacec2257186002b9be3	et	f	\N
202062	idulli	?idulli =idulli  (SgN  >idulli !01_S	et	f	\N
202063	idulli	?idulli =idulli  (SgG  >idulli !01_S	et	f	\N
202064	idulli	?idulli =idulli  (SgG  >idull !22_S	et	f	\N
202065	idulli	?idulli =idulli  (SgP  >idull !22_S	et	f	\N
202066	idulli	?idulli =idulli  (SgAdt  >idull !22_S	et	f	\N
202067	idulli	?idulli =idulli  (IndPrPs_  >idullima !28_V	et	f	\N
202068	idulli	?idulli =idulli  (ImpPrSg2  >idullima !28_V	et	f	\N
202076	vastustundetu	vastustundetu =tundetu  (SgN  >vastus+tundetu !01_A	et	f	\N
202077	vastustundetu	"vastus+tundetu %tunde  )TU2_kA  <vastus+tunne ;06_S	et	f	\N
201817	nissugusest	?nissugusest =nissuguses  (SgP  >nissugusene !12_A	et	f	\N
201844	lahendakse	?lahendakse =lahendakse  (SgG  >lahendakne !02_A	et	f	\N
201846	kõrgekvalifitsiooniga	?kõrgekvalifitsiooniga =kõrgekvalifitsiooni  (SgKom  >kõrgekvalifitsiooni !16_S	et	f	\N
201847	kõrgekvalifitsiooniga	?kõrgekvalifitsiooniga =kõrgekvalifitsiooni  (SgKom  >kõrgekvalifitsioon !22_S	et	f	\N
201848	kõrgekvalifitsiooniga	?kõrgekvalifitsiooniga =kvalifitsiooni  (SgKom  >kõrge+kvalifitsiooni !16_S	et	f	\N
201849	kõrgekvalifitsiooniga	?kõrgekvalifitsiooniga =kvalifitsiooni  (SgKom  >kõrge+kvalifitsioon !22_S	et	f	\N
201850	kõrgekvalifitsiooniga	?kõrgekvalifitsiooniga =ekvalifitsiooni  (SgKom  >kõrg+ekvalifitsiooni !16_S	et	f	\N
201851	kõrgekvalifitsiooniga	?kõrgekvalifitsiooniga =ekvalifitsiooni  (SgKom  >kõrg+ekvalifitsioon !22_S	et	f	\N
201867	putuvad	?putuvad =putu  (IndPrPl3  >putuma !27_V	et	f	\N
201868	putuvad	?putuvad =putuva  (PlN  >putuva !01_S	et	f	\N
201869	putuvad	?putuvad =putuva  (PlN  >putuv !02_A	et	f	\N
201897	problemmid	?problemmid =problemmi  (PlN  >problemmi !01_S	et	f	\N
201898	problemmid	?problemmid =problemmi  (PlN  >problemm !22_S	et	f	\N
201899	problemmid	?problemmid =problemmi  (IndPrSg2  >problemmima !28_V	et	f	\N
201908	eraldav	eraldav =eralda  (PtsPrPs  >eraldama !27_V	et	f	\N
201909	eraldav	eraldav =eraldav  (SgN  >eraldav !02_A	et	f	\N
201910	eraldav	"eraldav %eralda  )V_vA  <eraldama ;27_V	et	f	\N
201911	hoollekanne	?hoollekanne =hoollekanne  (SgN  >hoollekanne !02_A	et	f	\N
201912	hoollekanne	?hoollekanne =hoollekanne  (PlP  >hoollekann !22_S	et	f	\N
201919	teines	?teines =teine  (PlIn  >tein !22_S	et	f	\N
201920	teines	?teines =teine  (IndIpfSg3  >teinema !27_V	et	f	\N
201921	teines	?teines =teines  (SgN  >teines !09_S	et	f	\N
201937	jõulisemat	jõulisemat =jõulisema  (SgP  >jõulisem !02_A	et	f	\N
201938	jõulisemat	"jõulisem %jõu  )LISEM_cA  <jõud ;22_S	et	f	\N
201939	jõulisemat	"jõulisem %jõuli  )SEM_cA  <jõul ;22_S	et	f	\N
201940	jõulisemat	"jõulisem %jõulise  )M_cA  <jõuline ;10_A	et	f	\N
201941	jõulisemat	"jõulisem %jõulise  )M_cA  <jõuline ;12_A	et	f	\N
201955	pikaajalise	pikaajalise =ajalise  (SgG  >pika+ajaline !12_A	et	f	\N
201956	pikaajalise	"pika+ajaline %aja  )LINE_aA  <pika+aeg ;22_S	et	f	\N
201957	isiklikelu	?isiklikelu =isiklikelu  (SgN  >isiklikelu !17_S	et	f	\N
201958	isiklikelu	?isiklikelu =isiklikelu  (SgG  >isiklikelu !17_S	et	f	\N
201959	isiklikelu	?isiklikelu =isiklikelu  (SgP  >isiklikelu !17_S	et	f	\N
201960	isiklikelu	?isiklikelu =isiklikelu  (IndPrPs_  >isiklikeluma !27_V	et	f	\N
201961	isiklikelu	?isiklikelu =isiklikelu  (ImpPrSg2  >isiklikeluma !27_V	et	f	\N
201962	heapalgaline	heapalgaline =palgaline  (SgN  >hea+palgaline !12_SA	et	f	\N
201963	heapalgaline	"hea+palgaline %palga  )LINE_aA  <hea+palk ;22_S	et	f	\N
201986	võimalisi	?võimalisi =võimalisi  (PlP  >võimaline !12_A	et	f	\N
201990	spetsiolisti	?spetsiolisti =spetsiolisti  (ID  >spetsiolisti !41_D	et	f	\N
201991	spetsiolisti	?spetsiolisti =spetsiolisti  (SgG  >spetsiolist !22_S	et	f	\N
201992	spetsiolisti	?spetsiolisti =spetsiolisti  (SgP  >spetsiolist !22_S	et	f	\N
201993	spetsiolisti	?spetsiolisti =spetsiolisti  (SgAdt  >spetsiolist !22_S	et	f	\N
201994	spetsiolisti	?spetsiolisti =spetsiolisti  (IndPrPs_  >spetsiolistima !28_V	et	f	\N
201995	spetsiolisti	?spetsiolisti =spetsiolisti  (ImpPrSg2  >spetsiolistima !28_V	et	f	\N
201996	spetsiolisti	?spetsiolisti =iolisti  (SgN  >spets+iolisti !01_S	et	f	\N
201997	spetsiolisti	?spetsiolisti =iolisti  (SgG  >spets+iolisti !01_S	et	f	\N
201998	spetsiolisti	?spetsiolisti =iolisti  (SgG  >spets+iolist !22_S	et	f	\N
201999	spetsiolisti	?spetsiolisti =iolisti  (SgP  >spets+iolist !22_S	et	f	\N
202000	spetsiolisti	?spetsiolisti =iolisti  (SgAdt  >spets+iolist !22_S	et	f	\N
202001	porshe	?porshe =porshe  (SgN  >porshe !06_S	et	f	\N
202005	porshe	?porshe =porshe  (SgG  >porshe !06_S	et	f	\N
202006	porshe	?porshe =porshe  (PlP  >porsh !22_S	et	f	\N
202007	porshe	?porshe =porshe  (IndPrPs_  >porshema !27_V	et	f	\N
202008	porshe	?porshe =porshe  (ImpPrSg2  >porshema !27_V	et	f	\N
202015	nendela	?nendela =nendela  (SgN  >nendela !01_S	et	f	\N
202016	nendela	?nendela =nendela  (SgG  >nendela !01_S	et	f	\N
202017	viieteistkümneaastane	viieteistkümneaastane =aastane  (SgN  >viie+teist+kümne+aastane !12~10_A	et	f	\N
202019	viieteistkümneaastane	"viie+teist+kümne+aastane %aasta  )NE_aA  <viie+teist+kümne+aasta ;01_S	et	f	\N
202025	artiikli	?artiikli =artiikli  (SgN  >artiikli !01_S	et	f	\N
202026	artiikli	?artiikli =artiikli  (SgG  >artiikli !01_S	et	f	\N
202027	artiikli	?artiikli =artiikli  (SgG  >artiikel !02_S	et	f	\N
202028	artiikli	?artiikli =artiikli  (IndPrPs_  >artiiklima !28_V	et	f	\N
202029	artiikli	?artiikli =artiikli  (ImpPrSg2  >artiiklima !28_V	et	f	\N
202057	tervet	tervet =terve  (SgP  >terve !01_AS	et	f	\N
202058	tervet	tervet =terve  (SgP  >terve !06_AS	et	f	\N
202088	proffessionaalid	?proffessionaalid =proffessionaali  (PlN  >proffessionaali !16_S	et	f	\N
202089	proffessionaalid	?proffessionaalid =proffessionaali  (PlN  >proffessionaal !22_S	et	f	\N
202090	proffessionaalid	?proffessionaalid =proffessionaali  (IndPrSg2  >proffessionaalima !28_V	et	f	\N
202097	laisalt	laisalt =laisa  (SgAbl  >laisk !22_A	et	f	\N
202098	laisalt	laisalt =laisalt  (ID  >laisalt !41_D	et	f	\N
202099	laisalt	"laisalt %laisa  )LT_mD  <laisk ;22_A	et	f	\N
202103	kirjuda	?kirjuda =kirju  (Inf  >kirjuma !27_V	et	f	\N
201922	paremide	?paremide =ide  (SgN  >parem+ide !16_S	et	f	\N
201923	paremide	?paremide =ide  (SgG  >parem+ide !16_S	et	f	\N
201927	lõpetajad	lõpetajad =lõpetaja  (PlN  >lõpetaja !01_S	et	f	\N
201928	lõpetajad	"lõpetaja %lõpeta  )JA_vS  <lõpetama ;27_V	et	f	\N
201929	abiturienti	abiturienti =abiturienti  (SgP  >abiturient !22_S	et	f	\N
201930	abiturienti	abiturienti =abiturienti  (SgAdt  >abiturient !22_S	et	f	\N
201949	julgemat	julgemat =julgema  (SgP  >julgem !02_A	et	f	\N
201950	julgemat	"julgem %julge  )M_cA  <julge ;01_A	et	f	\N
202032	energeetikateaduskonnas	energeetikateaduskonnas =konna  (SgIn  >energeetika+teadus+konn !22_S	et	f	\N
202033	energeetikateaduskonnas	energeetikateaduskonnas =teaduskonna  (SgIn  >energeetika+teaduskond !22_S	et	f	\N
202036	juura	juura =juura  (SgN  >juura !16_S	et	f	\N
202037	juura	juura =juura  (SgG  >juura !16_S	et	f	\N
202040	trendikad	?trendikad =trendika  (PlN  >trendika !01_S	et	f	\N
202041	trendikad	?trendikad =trendika  (PlN  >trendikas !02_S	et	f	\N
202054	esmatahtis	?esmatahtis =esmatahti  (IndIpfSg3  >esmatahtima !28_V	et	f	\N
202055	esmatahtis	?esmatahtis =esmatahtis  (SgN  >esmatahtis !09_S	et	f	\N
202056	esmatahtis	?esmatahtis =tahtis  (SgN  >esma+tahtis !09_S	et	f	\N
202082	jirgeni	?jirgeni =jirgeni  (SgG  >jirgen !02_S	et	f	\N
202120	politikud	?politikud =politiku  (PlN  >politik !02_S	et	f	\N
202121	politikud	?politikud =politiku  (IndPrSg2  >politikuma !27_V	et	f	\N
202177	ekspresis	?ekspresis =ekspresi  (PlIn  >eksprene !12_A	et	f	\N
202178	ekspresis	?ekspresis =ekspresis  (SgN  >ekspresis !11_S	et	f	\N
202179	ekspresis	?ekspresis =presi  (SgIn  >eks+presi !17_S	et	f	\N
202180	ekspresis	?ekspresis =presis  (SgN  >eks+presis !09_S	et	f	\N
202184	surenevad	?surenevad =surene  (IndPrPl3  >surenema !27_V	et	f	\N
202185	surenevad	?surenevad =sureneva  (PlN  >surenev !02_A	et	f	\N
202186	surenevad	?surenevad =sureneva  (PlN  >sureneva !16_S	et	f	\N
202190	elektrijamid	?elektrijamid =elektrijami  (PlN  >elektrijam !02_A	et	f	\N
202191	elektrijamid	?elektrijamid =jami  (PlN  >elektri+jami !17_S	et	f	\N
202238	abituriendit	?abituriendit =riendi  (SgP  >abitu+riend !02_S	et	f	\N
202239	abituriendit	?abituriendit =riendit  (SgN  >abitu+riendit !02_S	et	f	\N
202273	turvalise	turvalise =turvalise  (SgG  >turvaline !12_A	et	f	\N
202274	turvalise	"turvaline %turva  )LINE_aA  <turb ;22_SA	et	f	\N
202275	turvalise	"turvaline %turva  )LINE_aA  <turv ;22_S	et	f	\N
202276	suunitakste	?suunitakste =nitakste  (PlP  >suu+nitakst !22_S	et	f	\N
202282	eluetabil	?eluetabil =etabi  (SgAd  >elu+etabi !01_S	et	f	\N
202287	süüstem	?süüstem =süüstem  (SgN  >süüstem !02_A	et	f	\N
202318	kujunemiseks	kujunemiseks =kujunemise  (SgTr  >kujunemine !12_S	et	f	\N
202319	kujunemiseks	"kujunemine %kujune  )MINE_vS  <kujunema ;27_V	et	f	\N
202322	õiglasem	õiglasem =õiglasem  (SgN  >õiglasem !02_A	et	f	\N
202323	õiglasem	"õiglasem %õiglase  )M_cA  <õiglane ;10_A	et	f	\N
202324	õiglasem	"õiglasem %õiglase  )M_cA  <õiglane ;12_A	et	f	\N
202333	õppilasel	?õppilasel =õppilase  (SgAd  >õppilane !12_S	et	f	\N
202334	teadumiste	?teadumiste =teadumis  (PlG  >teadumis !11_S	et	f	\N
202335	teadumiste	?teadumiste =teadumis  (PlG  >teadumine !12_S	et	f	\N
202336	teadumiste	?teadumiste =teadumiste  (PlP  >teadumist !22_S	et	f	\N
202346	oskutöölisega	?oskutöölisega =oskutöölise  (SgKom  >oskutööline !12?10_A	et	f	\N
202367	harjusid	harjusid =harju  (IndIpfSg2  >harjuma !27_V	et	f	\N
202368	harjusid	harjusid =harju  (IndIpfPl3  >harjuma !27_V	et	f	\N
202378	noormaalset	?noormaalset =noormaalse  (SgP  >noormaalne !02_A	et	f	\N
202379	noormaalset	?noormaalset =maalse  (SgP  >noor+maalne !02_A	et	f	\N
202380	noormaalset	?noormaalset =maalse  (SgP  >noor+maalse !06_S	et	f	\N
202386	role	?role =role  (SgN  >role !16_S	et	f	\N
202387	role	?role =role  (SgG  >role !16_S	et	f	\N
202388	role	?role =role  (IndPrPs_  >rolema !27_V	et	f	\N
202389	role	?role =role  (ImpPrSg2  >rolema !27_V	et	f	\N
202409	pärani	pärani =pära  (SgTer  >pära !17_S	et	f	\N
202410	pärani	pärani =pärani  (ID  >pärani !41_DA	et	f	\N
202413	unistasid	unistasid =unista  (IndIpfSg2  >unistama !27_V	et	f	\N
202414	unistasid	unistasid =unista  (IndIpfPl3  >unistama !27_V	et	f	\N
202424	koduülesanne	koduülesanne =anne  (SgN  >kodu+üles+anne !05_S	et	f	\N
202425	koduülesanne	koduülesanne =anne  (SgN  >kodu+üles+anne !06_S	et	f	\N
202429	hoolekanne	hoolekanne =kanne  (SgN  >hoole+kanne !05_S	et	f	\N
202430	hoolekanne	hoolekanne =kanne  (SgN  >hoole+kanne !06_S	et	f	\N
202431	hoolekanne	hoolekanne =kanne  (PlP  >hoole+kann !22_S	et	f	\N
202434	muretu	muretu =muretu  (SgN  >muretu !01_A	et	f	\N
202435	muretu	"muretu %mure  )TU2_kA  <mure ;16_S	et	f	\N
202436	muretu	muretu =muretu  (SgG  >muretu !01_A	et	f	\N
202439	suhtlusvõimelised	suhtlusvõimelised =võimelise  (PlN  >suhtlus+võimeline !12_A	et	f	\N
202440	suhtlusvõimelised	"suhtlus+võimeline %võime  )LINE_aA  <suhtlus+võime ;06_S	et	f	\N
202465	demineerimis	?demineerimis =demineerimi  (SgIn  >demineerim !02_A	et	f	\N
202466	demineerimis	?demineerimis =demineerimis  (SgN  >demineerimis !09_S	et	f	\N
202488	lõbusevad	?lõbusevad =lõbuseva  (PlN  >lõbusev !02_A	et	f	\N
202489	lõbusevad	?lõbusevad =lõbuseva  (PlN  >lõbuseva !16_S	et	f	\N
202030	jürgen	?jürgen =jürge  (IndPrSg1  >jürgema !27_V	et	f	\N
202031	jürgen	?jürgen =jürgen  (SgN  >jürgen !02_S	et	f	\N
202034	popuulaarsemad	?popuulaarsemad =popuulaarsema  (PlN  >popuulaarsem !02_A	et	f	\N
202035	popuulaarsemad	?popuulaarsemad =uulaarsema  (PlN  >pop+uulaarsem !02_A	et	f	\N
202049	psühholoogiks	psühholoogiks =psühholoogi  (SgTr  >psühholoog !22_S	et	f	\N
202050	psühholoogiks	psühholoogiks =loogi  (SgTr  >psühho+loog !22_S	et	f	\N
202051	psühholoogiks	psühholoogiks =loogi  (PlTr  >psühho+look !22_S	et	f	\N
202069	tähelepannu	tähelepannu =pannu  (SgN  >tähele+pannu !16_S	et	f	\N
202070	tähelepannu	tähelepannu =pannu  (SgG  >tähele+pannu !16_S	et	f	\N
202079	tarksed	?tarksed =tarkse  (PlN  >tarkne !02_A	et	f	\N
202080	tarksed	?tarksed =tarkse  (PlN  >tarkse !06_S	et	f	\N
202081	tarksed	?tarksed =tarkse  (IndPrSg2  >tarksema !27_V	et	f	\N
202100	tahtmata	tahtmata =taht  (SupAb  >tahtma !34_V	et	f	\N
202101	tahtmata	tahtmata =tahtmata  (ID  >tahtmata !41_A	et	f	\N
202102	tahtmata	"tahtmata %taht  )MATA_vA  <tahtma ;34_V	et	f	\N
202104	kohaajalehest	kohaajalehest =lehe  (SgEl  >koha+aja+leht !22_S	et	f	\N
202105	kohaajalehest	kohaajalehest =lehes  (SgP  >koha+aja+lehene !10_A	et	f	\N
202106	kohaajalehest	"koha+aja+lehene %lehe  )NE_aA  <koha+aja+leht ;22_S	et	f	\N
202127	avata	avata =ava  (SgAb  >ava !17_S	et	f	\N
202128	avata	avata =ava  (IndPrIps_  >avama !27_V	et	f	\N
202148	nenden	?nenden =nende  (IndPrSg1  >nendema !27_V	et	f	\N
202149	nenden	?nenden =nenden  (SgN  >nenden !02_S	et	f	\N
202161	üliõppilasest	?üliõppilasest =üliõppilase  (SgEl  >üliõppilane !12_S	et	f	\N
202162	üliõppilasest	?üliõppilasest =õppilase  (SgEl  >üli+õppilane !12_S	et	f	\N
202172	agate	?agate =aga  (IndPrPl2  >agama !27_V	et	f	\N
202175	jurgen	?jurgen =jurge  (IndPrSg1  >jurgema !27_V	et	f	\N
202176	jurgen	?jurgen =jurgen  (SgN  >jurgen !02_S	et	f	\N
202194	noorsoorahutuste	noorsoorahutuste =tuste  (PlP  >noor+soo+rahu+tust !22_S	et	f	\N
202195	noorsoorahutuste	noorsoorahutuste =rahutus  (PlG  >noor+soo+rahutus !11_S	et	f	\N
202196	noorsoorahutuste	"noor+soo+rahutus %rahu  )TUS2_aS  <noor+soo+rahu ;17_S	et	f	\N
202209	puuimutamine	?puuimutamine =puuimutamine  (SgN  >puuimutamine !12_S	et	f	\N
202210	puuimutamine	?puuimutamine =puuimutamine  (PlP  >puuimutamin !19_S	et	f	\N
202211	puuimutamine	?puuimutamine =imutamine  (SgN  >puu+imutamine !12_S	et	f	\N
202212	puuimutamine	?puuimutamine =imutamine  (PlP  >puu+imutamin !19_S	et	f	\N
202220	11102006a	### 11102006a	et	f	\N
202227	majandusteatuskondis	?majandusteatuskondis =majandusteatuskondi  (SgIn  >majandusteatuskont !22_S	et	f	\N
202228	majandusteatuskondis	?majandusteatuskondis =majandusteatuskondi  (IndIpfSg3  >majandusteatuskondima !28_V	et	f	\N
202229	majandusteatuskondis	?majandusteatuskondis =majandusteatuskondis  (SgN  >majandusteatuskondis !09_S	et	f	\N
202230	majandusteatuskondis	?majandusteatuskondis =teatuskondi  (SgIn  >majandus+teatuskont !22_S	et	f	\N
202231	majandusteatuskondis	?majandusteatuskondis =teatuskondis  (SgN  >majandus+teatuskondis !09_S	et	f	\N
202232	abiturieentidel	?abiturieentidel =abiturieenti  (PlAd  >abiturieent !22_S	et	f	\N
202233	abiturieentidel	?abiturieentidel =rieenti  (PlAd  >abitu+rieent !22_S	et	f	\N
202234	abiturieentidel	?abiturieentidel =turieenti  (PlAd  >abi+turieent !22_S	et	f	\N
202246	nendelt	nendelt =nen  (PlAbl  >see !00_P	et	f	\N
202247	nendelt	nendelt =nen  (PlAbl  >tema !00_P	et	f	\N
202261	algpõhjus	algpõhjus =põhju  (PlIn  >alg+põhi !24_S	et	f	\N
202262	algpõhjus	algpõhjus =põhjus  (SgN  >alg+põhjus !11~09_S	et	f	\N
202277	madalamaad	madalamaad =maa  (PlN  >madala+maa !26_S	et	f	\N
202278	madalamaad	madalamaad =maa  (SgP  >madala+maa !26_S	et	f	\N
202283	ebaproportsioonalselt	?ebaproportsioonalselt =ebaproportsioonalse  (SgAbl  >ebaproportsioonalne !02_A	et	f	\N
202284	ebaproportsioonalselt	?ebaproportsioonalselt =ebaproportsioonalselt  (ID  >ebaproportsioonalselt !41_D	et	f	\N
202285	ebaproportsioonalselt	?ebaproportsioonalselt =proportsioonalse  (SgAbl  >eba+proportsioonalne !02_A	et	f	\N
202286	ebaproportsioonalselt	?ebaproportsioonalselt =proportsioonalselt  (ID  >eba+proportsioonalselt !41_D	et	f	\N
202292	sotsialiismi	?sotsialiismi =sotsialiismi  (SgG  >sotsialiism !22_S	et	f	\N
202294	sotsialiismi	?sotsialiismi =sotsialiismi  (SgP  >sotsialiism !22_S	et	f	\N
202295	sotsialiismi	?sotsialiismi =sotsialiismi  (SgAdt  >sotsialiism !22_S	et	f	\N
202297	sotsialiismi	?sotsialiismi =sotsialiismi  (IndPrPs_  >sotsialiismima !28_V	et	f	\N
202298	sotsialiismi	?sotsialiismi =sotsialiismi  (ImpPrSg2  >sotsialiismima !28_V	et	f	\N
202325	kääsitlakse	?kääsitlakse =kääsitlakse  (SgG  >kääsitlakne !02_A	et	f	\N
202337	harituse	harituse =harituse  (SgG  >haritus !11_S	et	f	\N
202338	harituse	"haritus %hari  )TUS1_aS  <harima ;27_V	et	f	\N
202348	juhajaga	?juhajaga =juhaja  (SgKom  >juhaja !01_S	et	f	\N
202349	juhajaga	?juhajaga =juhaja  (SgKom  >juhajas !02_A	et	f	\N
202384	perekonale	?perekonale =perekonale  (PlP  >perekonal !19_S	et	f	\N
202385	perekonale	?perekonale =kona  (SgAll  >pere+kona !17_S	et	f	\N
202400	kuueteskümnest	?kuueteskümnest =kuueteskümne  (PlEl  >kuueteskümn !22_S	et	f	\N
202401	kuueteskümnest	?kuueteskümnest =kuueteskümnes  (SgP  >kuueteskümnene !12_A	et	f	\N
202402	kuueteskümnest	?kuueteskümnest =teskümne  (PlEl  >kuue+teskümn !22_S	et	f	\N
202403	kuueteskümnest	?kuueteskümnest =teskümnes  (SgP  >kuue+teskümnene !12_A	et	f	\N
202078	vastustundetu	vastustundetu =tundetu  (SgG  >vastus+tundetu !01_A	et	f	\N
202083	sõltuvus	sõltuvus =sõltuvus  (SgN  >sõltuvus !11_S	et	f	\N
202086	sõltuvus	"sõltuvus %sõltu  )VUS_aS  <sõltuma ;27_V	et	f	\N
202087	sõltuvus	"sõltuvus %sõltuva  )US_aS  <sõltuv ;02_A	et	f	\N
202109	maadelda	maadelda =maadel  (Inf  >maadlema !30_V	et	f	\N
202110	maadelda	maadelda =maadel  (IndPrIps_  >maadlema !30_V	et	f	\N
202111	valladama	?valladama =valladama  (SgG  >valladam !02_A	et	f	\N
202112	valladama	?valladama =dama  (SgN  >valla+dama !17_S	et	f	\N
202113	valladama	?valladama =dama  (SgG  >valla+dama !17_S	et	f	\N
202114	valladama	?valladama =dama  (SgP  >valla+dama !17_S	et	f	\N
202115	ministeriumides	?ministeriumides =ministeriumi  (PlIn  >ministeriumi !16_S	et	f	\N
202116	ministeriumides	?ministeriumides =ministeriumi  (PlIn  >ministerium !19_S	et	f	\N
202117	ministeriumides	?ministeriumides =ministeriumi  (Ger  >ministeriumima !28_V	et	f	\N
202118	ministeriumides	?ministeriumides =steriumi  (PlIn  >mini+steriumi !16_S	et	f	\N
202119	ministeriumides	?ministeriumides =steriumi  (PlIn  >mini+sterium !19_S	et	f	\N
202124	ohtu	ohtu =ohtu  (ID  >ohtu !41_A	et	f	\N
202125	ohtu	ohtu =ohtu  (SgP  >oht !22_S	et	f	\N
202126	ohtu	ohtu =ohtu  (SgAdt  >oht !22_S	et	f	\N
202181	keskonnaga	?keskonnaga =keskonna  (SgKom  >keskonna !16_S	et	f	\N
202182	keskonnaga	?keskonnaga =keskonna  (SgKom  >keskond !22_S	et	f	\N
202183	keskonnaga	?keskonnaga =onna  (SgKom  >kesk+onna !16_S	et	f	\N
202197	kahekümneaastases	kahekümneaastases =aastase  (SgIn  >kahe+kümne+aastane !12~10_A	et	f	\N
202198	kahekümneaastases	"kahe+kümne+aastane %aasta  )NE_aA  <kahe+kümne+aasta ;01_S	et	f	\N
202204	abiturientid	### abiturientid	et	f	\N
202235	mõtlevat	mõtlevat =mõtle  (KvtPrPs  >mõtlema !30_V	et	f	\N
202236	mõtlevat	mõtlevat =mõtleva  (SgP  >mõtlev !02_A	et	f	\N
202237	mõtlevat	"mõtlev %mõtle  )V_vA  <mõtlema ;30_V	et	f	\N
202240	muigugi	?muigugi =muigu  (SgN^  >muigu !16_S	et	f	\N
202241	muigugi	?muigugi =muigu  (SgG^  >muigu !16_S	et	f	\N
202242	muigugi	?muigugi =muigu  (IndPrPs_^  >muiguma !27_V	et	f	\N
202243	muigugi	?muigugi =muigu  (IndPrPs_^  >muikuma !28_V	et	f	\N
202244	muigugi	?muigugi =muigu  (ImpPrSg2^  >muiguma !27_V	et	f	\N
202245	muigugi	?muigugi =muigu  (ImpPrSg2^  >muikuma !28_V	et	f	\N
202250	õigu	?õigu =õigu  (SgN  >õigu !16_S	et	f	\N
202251	õigu	?õigu =õigu  (SgG  >õigu !16_S	et	f	\N
202252	õigu	?õigu =õigu  (IndPrPs_  >õiguma !27_V	et	f	\N
202253	õigu	?õigu =õigu  (IndPrPs_  >õikuma !28_V	et	f	\N
202254	õigu	?õigu =õigu  (ImpPrSg2  >õiguma !27_V	et	f	\N
202255	õigu	?õigu =õigu  (ImpPrSg2  >õikuma !28_V	et	f	\N
202299	apaatiline	?apaatiline =apaatiline  (SgN  >apaatiline !12_A	et	f	\N
202300	apaatiline	?apaatiline =apaatiline  (PlP  >apaatilin !19_S	et	f	\N
202301	haridusesüsteemi	?haridusesüsteemi =haridusesüsteemi  (SgN  >haridusesüsteemi !16_S	et	f	\N
202302	haridusesüsteemi	?haridusesüsteemi =haridusesüsteemi  (SgG  >haridusesüsteemi !16_S	et	f	\N
202303	haridusesüsteemi	?haridusesüsteemi =haridusesüsteemi  (SgG  >haridusesüsteem !22_S	et	f	\N
202304	haridusesüsteemi	?haridusesüsteemi =haridusesüsteemi  (SgP  >haridusesüsteem !22_S	et	f	\N
202305	haridusesüsteemi	?haridusesüsteemi =haridusesüsteemi  (SgAdt  >haridusesüsteem !22_S	et	f	\N
202306	haridusesüsteemi	?haridusesüsteemi =haridusesüsteemi  (IndPrPs_  >haridusesüsteemima !28_V	et	f	\N
202307	haridusesüsteemi	?haridusesüsteemi =haridusesüsteemi  (ImpPrSg2  >haridusesüsteemima !28_V	et	f	\N
202308	haridusesüsteemi	?haridusesüsteemi =esüsteemi  (SgN  >haridus+esüsteemi !16_S	et	f	\N
202309	haridusesüsteemi	?haridusesüsteemi =esüsteemi  (SgG  >haridus+esüsteemi !16_S	et	f	\N
202310	haridusesüsteemi	?haridusesüsteemi =esüsteemi  (SgG  >haridus+esüsteem !22_S	et	f	\N
202311	haridusesüsteemi	?haridusesüsteemi =esüsteemi  (SgP  >haridus+esüsteem !22_S	et	f	\N
202312	haridusesüsteemi	?haridusesüsteemi =esüsteemi  (SgAdt  >haridus+esüsteem !22_S	et	f	\N
202313	haridusesüsteemi	?haridusesüsteemi =dusesüsteemi  (SgN  >hari+dusesüsteemi !16_S	et	f	\N
202314	haridusesüsteemi	?haridusesüsteemi =dusesüsteemi  (SgG  >hari+dusesüsteemi !16_S	et	f	\N
202315	haridusesüsteemi	?haridusesüsteemi =dusesüsteemi  (SgG  >hari+dusesüsteem !22_S	et	f	\N
202316	haridusesüsteemi	?haridusesüsteemi =dusesüsteemi  (SgP  >hari+dusesüsteem !22_S	et	f	\N
202317	haridusesüsteemi	?haridusesüsteemi =dusesüsteemi  (SgAdt  >hari+dusesüsteem !22_S	et	f	\N
202320	sooritamise	sooritamise =sooritamise  (SgG  >sooritamine !12_S	et	f	\N
202321	sooritamise	"sooritamine %soorita  )MINE_vS  <sooritama ;27_V	et	f	\N
202326	objektiivsemalt	objektiivsemalt =objektiivsema  (SgAbl  >objektiivsem !02_A	et	f	\N
202327	objektiivsemalt	"objektiivsem %objektiivse  )M_cA  <objektiivne ;02_A	et	f	\N
202328	objektiivsemalt	objektiivsemalt =objektiivsemalt  (ID  >objektiivsemalt !41_D	et	f	\N
202329	objektiivsemalt	"objektiivsemalt %objektiivse  )MALT_mD  <objektiivne ;02_A	et	f	\N
202350	maldamatu	maldamatu =maldamatu  (SgN  >maldamatu !01_A	et	f	\N
202351	maldamatu	"maldamatu %malda  )MATU_vA  <maldama ;29_V	et	f	\N
202352	maldamatu	maldamatu =maldamatu  (SgG  >maldamatu !01_A	et	f	\N
202376	tulevikuks	tulevikuks =tuleviku  (SgTr  >tulevik !25_S	et	f	\N
202377	tulevikuks	tulevikuks =viku  (SgTr  >tule+vikk !22_S	et	f	\N
202411	arvude	arvude =arvu  (PlG  >arv !22_S	et	f	\N
202123	ollo	?ollo =ollo  (SgG  >ollo !16_S	et	f	\N
202129	kannatanu	kannatanu =kannatanu  (SgN  >kannatanu !01_S	et	f	\N
202130	kannatanu	"kannatanu %kannata  )NU_vS  <kannatama ;27_V	et	f	\N
202131	kannatanu	kannatanu =kannatanu  (SgG  >kannatanu !01_S	et	f	\N
202132	kannatanu	kannatanu =tanu  (SgN  >kanna+tanu !17_S	et	f	\N
202133	kannatanu	kannatanu =tanu  (SgG  >kanna+tanu !17_S	et	f	\N
202134	kannatanu	kannatanu =tanu  (SgP  >kanna+tanu !17_S	et	f	\N
202135	tahaad	?tahaad =tahaa  (PlN  >tahaa !26_S	et	f	\N
202136	tahaad	?tahaad =tahaa  (SgP  >tahaa !26_S	et	f	\N
202137	tahaad	?tahaad =tahaad  (SgN  >tahaad !22_S	et	f	\N
202141	võimelisused	võimelisused =võimelisuse  (PlN  >võimelisus !11?09_S	et	f	\N
202142	võimelisused	"võimelisus %võime  )LISUS_aS  <võime ;06_S	et	f	\N
202155	mõeldnud	?mõeldnud =mõeldnu  (PlN  >mõeldnu !01_S	et	f	\N
202156	mõeldnud	?mõeldnud =mõeldnu  (IndPrSg2  >mõeldnuma !27_V	et	f	\N
202157	mõeldnud	?mõeldnud =mõeldnud  (ID  >mõeldnud !41_A	et	f	\N
202165	inseneeri	?inseneeri =inseneeri  (SgN  >inseneeri !16_S	et	f	\N
202166	inseneeri	?inseneeri =inseneeri  (SgG  >inseneeri !16_S	et	f	\N
202167	inseneeri	?inseneeri =inseneeri  (SgG  >inseneer !22_S	et	f	\N
202168	inseneeri	?inseneeri =inseneeri  (SgP  >inseneer !22_S	et	f	\N
202169	inseneeri	?inseneeri =inseneeri  (SgAdt  >inseneer !22_S	et	f	\N
202170	inseneeri	?inseneeri =inseneeri  (IndPrPs_  >inseneerima !28_V	et	f	\N
202171	inseneeri	?inseneeri =inseneeri  (ImpPrSg2  >inseneerima !28_V	et	f	\N
202192	teenindamise	teenindamise =teenindamise  (SgG  >teenindamine !12_S	et	f	\N
202193	teenindamise	"teenindamine %teeninda  )MINE_vS  <teenindama ;27_V	et	f	\N
202199	realistikud	?realistikud =realistiku  (PlN  >realistik !25_S	et	f	\N
202200	realistikud	?realistikud =realistiku  (IndPrSg2  >realistikuma !27_V	et	f	\N
202201	realistikud	?realistikud =listiku  (PlN  >rea+listiku !01_S	et	f	\N
202202	realistikud	?realistikud =listiku  (PlN  >rea+listik !02_S	et	f	\N
202203	tanapäevased	?tanapäevased =tanapäevase  (PlN  >tanapäevane !12_A	et	f	\N
202215	kaha	kaha =kaha  (SgN  >kaha !17_S	et	f	\N
202216	kaha	kaha =kaha  (SgG  >kaha !17_S	et	f	\N
202217	kaha	kaha =kaha  (SgP  >kaha !17_S	et	f	\N
202218	kaha	kaha =kaha  (IndPrPs_  >kahama !27_V	et	f	\N
202219	kaha	kaha =kaha  (ImpPrSg2  >kahama !27_V	et	f	\N
202221	abiturieendid	?abiturieendid =abiturieendi  (PlN  >abiturieent !22_S	et	f	\N
202222	abiturieendid	?abiturieendid =abiturieendi  (IndPrSg2  >abiturieentima !28_V	et	f	\N
202223	abiturieendid	?abiturieendid =rieendi  (PlN  >abitu+rieendi !01_S	et	f	\N
202224	abiturieendid	?abiturieendid =rieendi  (PlN  >abitu+rieend !02_S	et	f	\N
202225	abiturieendid	?abiturieendid =rieendi  (PlN  >abitu+rieent !22_S	et	f	\N
202226	abiturieendid	?abiturieendid =turieendi  (PlN  >abi+turieent !22_S	et	f	\N
202258	silmanurgast	silmanurgast =nurga  (SgEl  >silma+nurk !22_S	et	f	\N
202259	silmanurgast	silmanurgast =nurgas  (SgP  >silma+nurgane !10_A	et	f	\N
202260	silmanurgast	"silma+nurgane %nurga  )NE_aA  <silma+nurk ;22_S	et	f	\N
202263	seiseneb	?seiseneb =seisene  (IndPrSg3  >seisenema !27_V	et	f	\N
202264	stabilne	?stabilne =stabilne  (SgN  >stabilne !02_A	et	f	\N
202265	stabilne	?stabilne =stabilne  (PlP  >stabiln !22_S	et	f	\N
202268	niisuguseks	niisuguseks =seks  (SgN  >nii+sugu+seks !22_S	et	f	\N
202269	niisuguseks	niisuguseks =suguse  (SgTr  >nii+sugune !10_P	et	f	\N
202270	ebapealetükkivalt	ebapealetükkivalt =iva  (SgAbl  >eba+peale+tükk+iva !17_S	et	f	\N
202271	ebapealetükkivalt	ebapealetükkivalt =tükkiva  (SgAbl  >eba+peale+tükkiv !02_A	et	f	\N
202272	ebapealetükkivalt	"eba+peale+tükkivalt %tükkiva  )LT_mD  <eba+peale+tükkiv ;02_A	et	f	\N
202288	prevaleerimine	prevaleerimine =prevaleerimine  (SgN  >prevaleerimine !12_S	et	f	\N
202289	prevaleerimine	"prevaleerimine %prevaleeri  )MINE_vS  <prevaleerima ;28_V	et	f	\N
202290	prevaleerimine	prevaleerimine =erimine  (SgN  >pre+vale+erimine !12_S	et	f	\N
202291	prevaleerimine	"pre+vale+erimine %erimi  )NE_aA  <pre+vale+erim ;02_S	et	f	\N
202330	mitmekülgsemalt	mitmekülgsemalt =külgsema  (SgAbl  >mitme+külgsem !02_A	et	f	\N
202331	mitmekülgsemalt	"mitme+külgsem %külgse  )M_cA  <mitme+külgne ;02_A	et	f	\N
202332	mitmekülgsemalt	"mitme+külgsemalt %külgse  )MALT_mD  <mitme+külgne ;02_A	et	f	\N
202345	profitsiit	?profitsiit =profitsiit  (SgN  >profitsiit !22_S	et	f	\N
202347	profitsiit	?profitsiit =tsiit  (SgN  >profi+tsiit !22_S	et	f	\N
202356	üliõpelane	?üliõpelane =üliõpelane  (SgN  >üliõpelane !12_S	et	f	\N
202357	üliõpelane	?üliõpelane =üliõpelane  (PlP  >üliõpelan !19_S	et	f	\N
202358	üliõpelane	?üliõpelane =õpelane  (SgN  >üli+õpelane !12_S	et	f	\N
202359	üliõpelane	?üliõpelane =õpelane  (PlP  >üli+õpelan !19_S	et	f	\N
202363	õlikooli	õlikooli =kooli  (SgG  >õli+kool !22_S	et	f	\N
202364	õlikooli	õlikooli =kooli  (SgP  >õli+kool !22_S	et	f	\N
202365	õlikooli	õlikooli =kooli  (SgAdt  >õli+kool !22_S	et	f	\N
202366	õlikooli	õlikooli =kooli  (PlP  >õli+kool !22_S	et	f	\N
202369	firmi	?firmi =firmi  (SgN  >firmi !16_S	et	f	\N
202370	firmi	?firmi =firmi  (SgG  >firmi !16_S	et	f	\N
202371	firmi	?firmi =firmi  (SgG  >firm !22_S	et	f	\N
202372	firmi	?firmi =firmi  (SgP  >firm !22_S	et	f	\N
202373	firmi	?firmi =firmi  (SgAdt  >firm !22_S	et	f	\N
202138	ebaõigelt	ebaõigelt =õige  (SgAbl  >eba+õige !01_A	et	f	\N
202139	ebaõigelt	ebaõigelt =õigelt  (ID  >eba+õigelt !41_D	et	f	\N
202140	ebaõigelt	"eba+õigelt %õige  )LT_mD  <eba+õige ;01_A	et	f	\N
202143	vääriliselt	vääriliselt =väärilise  (SgAbl  >vääriline !12_A	et	f	\N
202144	vääriliselt	"vääriline %vääri  )LINE_aA  <väär ;22_S	et	f	\N
202145	vääriliselt	vääriliselt =vääriliselt  (ID  >vääriliselt !41_D	et	f	\N
202146	vääriliselt	"vääriliselt %vääri  )LISELT_mD  <väär ;22_S	et	f	\N
202147	vääriliselt	"vääriliselt %väärilise  )LT_mD  <vääriline ;12_A	et	f	\N
202150	luugenud	?luugenud =luuge  (PtsPtPs  >luugema !27_V	et	f	\N
202151	luugenud	?luugenud =luugenu  (PlN  >luugenu !01_S	et	f	\N
202152	luugenud	?luugenud =luugenu  (IndPrSg2  >luugenuma !27_V	et	f	\N
202153	luugenud	?luugenud =luugenud  (ID  >luugenud !41_A	et	f	\N
202154	luugenud	?luugenud =genu  (PlN  >luu+genu !17_S	et	f	\N
202158	täilikult	?täilikult =täiliku  (SgAbl  >täiliku !01_S	et	f	\N
202159	täilikult	?täilikult =täiliku  (SgAbl  >täilik !02_S	et	f	\N
202160	täilikult	?täilikult =täilikult  (ID  >täilikult !41_D	et	f	\N
202163	kuulsama	kuulsama =kuulsama  (SgG  >kuulsam !02_A	et	f	\N
202164	kuulsama	"kuulsam %kuulsa  )M_cA  <kuulus ;02_A	et	f	\N
202173	jagamisega	jagamisega =jagamise  (SgKom  >jagamine !12_S	et	f	\N
202174	jagamisega	"jagamine %jaga  )MINE_vS  <jagama ;27_V	et	f	\N
202187	sotsialtöötaja	?sotsialtöötaja =sotsialtöötaja  (SgN  >sotsialtöötaja !01_S	et	f	\N
202188	sotsialtöötaja	?sotsialtöötaja =sotsialtöötaja  (SgG  >sotsialtöötaja !01_S	et	f	\N
202189	sotsialtöötaja	?sotsialtöötaja =sotsialtöötaja  (SgG  >sotsialtöötajas !02_A	et	f	\N
202205	üliõppilane	?üliõppilane =üliõppilane  (SgN  >üliõppilane !12_S	et	f	\N
202206	üliõppilane	?üliõppilane =üliõppilane  (PlP  >üliõppilan !19_S	et	f	\N
202207	üliõppilane	?üliõppilane =õppilane  (SgN  >üli+õppilane !12_S	et	f	\N
202208	üliõppilane	?üliõppilane =õppilane  (PlP  >üli+õppilan !19_S	et	f	\N
202213	afferistid	?afferistid =afferisti  (PlN  >afferist !22_S	et	f	\N
202214	afferistid	?afferistid =afferisti  (IndPrSg2  >afferistima !28_V	et	f	\N
202248	retseinsiooniga	?retseinsiooniga =retseinsiooni  (SgKom  >retseinsiooni !16_S	et	f	\N
202249	retseinsiooniga	?retseinsiooniga =retseinsiooni  (SgKom  >retseinsioon !22_S	et	f	\N
202256	apaatia	apaatia =apaatia  (SgN  >apaatia !01_S	et	f	\N
202257	apaatia	apaatia =apaatia  (SgG  >apaatia !01_S	et	f	\N
202266	lootmiseks	lootmiseks =lootmise  (SgTr  >lootmine !12?10_S	et	f	\N
202267	lootmiseks	"lootmine %loot  )MINE_vS  <lootma ;34_V	et	f	\N
202279	suhtiliselt	?suhtiliselt =suhtilise  (SgAbl  >suhtiline !12_A	et	f	\N
202280	suhtiliselt	?suhtiliselt =suhtiliselt  (ID  >suhtiliselt !41_D	et	f	\N
202281	suhtiliselt	?suhtiliselt =ilise  (SgAbl  >suht+iline !10_A	et	f	\N
202293	kajad	kajad =kaja  (PlN  >kaja !17_S	et	f	\N
202296	kajad	kajad =kaja  (IndPrSg2  >kajama !27_V	et	f	\N
202339	haruduseta	?haruduseta =haruduse  (SgAb  >harudus !11_S	et	f	\N
202340	haruduseta	?haruduseta =haruduseta  (IndPrPs_  >harudusetama !27_V	et	f	\N
202341	haruduseta	?haruduseta =haruduseta  (ImpPrSg2  >harudusetama !27_V	et	f	\N
202342	haruduseta	?haruduseta =duse  (SgAb  >haru+duse !16_S	et	f	\N
202343	neljakünneaastased	?neljakünneaastased =neljakünneaastase  (PlN  >neljakünneaastane !12~10_A	et	f	\N
202344	neljakünneaastased	?neljakünneaastased =künneaastase  (PlN  >nelja+künneaastane !12~10_A	et	f	\N
202353	taotlevad	taotlevad =taotle  (IndPrPl3  >taotlema !27_V	et	f	\N
202354	taotlevad	taotlevad =taotleva  (PlN  >taotlev !02_A	et	f	\N
202355	taotlevad	"taotlev %taotle  )V_vA  <taotlema ;27_V	et	f	\N
202360	päevalehest	päevalehest =lehe  (SgEl  >päeva+leht !22_S	et	f	\N
202361	päevalehest	päevalehest =lehes  (SgP  >päeva+lehene !10_A	et	f	\N
202362	päevalehest	"päeva+lehene %lehe  )NE_aA  <päeva+leht ;22_S	et	f	\N
202394	püüvad	?püüvad =püüva  (PlN  >püüva !16_S	et	f	\N
202395	püüvad	?püüvad =püüva  (IndPrSg2  >püüvama !29_V	et	f	\N
202396	hoolsalt	hoolsalt =hoolsa  (SgAbl  >hoolas !03~05_A	et	f	\N
202397	hoolsalt	hoolsalt =hoolsalt  (ID  >hoolsalt !41_D	et	f	\N
202398	hoolsalt	"hoolsalt %hoolsa  )LT_mD  <hoolas ;03_A	et	f	\N
202399	hoolsalt	"hoolsalt %hoolsa  )LT_mD  <hoolas ;05_A	et	f	\N
202406	mõttesse	mõttesse =mõtte  (SgIll  >mõte !06_S	et	f	\N
202407	mõttesse	mõttesse =mõttes  (SgAdt  >mõttene !12_A	et	f	\N
202408	mõttesse	"mõttene %mõtte  )NE_aA  <mõte ;06_S	et	f	\N
202415	finantseeri	finantseeri =finantseeri  (IndPrPs_  >finantseerima !28_V	et	f	\N
202416	finantseeri	finantseeri =finantseeri  (ImpPrSg2  >finantseerima !28_V	et	f	\N
202419	esmakurslane	?esmakurslane =esmakurslane  (SgN  >esmakurslane !12_S	et	f	\N
202420	esmakurslane	?esmakurslane =kurslane  (SgN  >esma+kurslane !12?10_S	et	f	\N
202432	garantii	garantii =garantii  (SgN  >garantii !26_S	et	f	\N
202433	garantii	garantii =garantii  (SgG  >garantii !26_S	et	f	\N
202453	automaatikaliselt	automaatikaliselt =automaatikalise  (SgAbl  >automaatikaline !12_A	et	f	\N
202454	automaatikaliselt	"automaatikaline %automaatika  )LINE_aA  <automaatika ;01_S	et	f	\N
202455	automaatikaliselt	automaatikaliselt =automaatikaliselt  (ID  >automaatikaliselt !41_D	et	f	\N
202456	automaatikaliselt	"automaatikaliselt %automaatika  )LISELT_mD  <automaatika ;01_S	et	f	\N
202374	firmi	?firmi =firmi  (IndPrPs_  >firmima !28_V	et	f	\N
202375	firmi	?firmi =firmi  (ImpPrSg2  >firmima !28_V	et	f	\N
202381	koodule	?koodule =koodu  (SgAll  >koodu !16_S	et	f	\N
202382	koodule	?koodule =koodule  (IndPrPs_  >koodulema !27_V	et	f	\N
202383	koodule	?koodule =koodule  (ImpPrSg2  >koodulema !27_V	et	f	\N
202390	kümnesse	kümnesse =kümne  (SgIll  >kümmend !05_N	et	f	\N
202391	kümnesse	kümnesse =kümne  (SgIll  >kümme !05_N	et	f	\N
202392	kümnesse	kümnesse =kümnes  (SgAdt  >kümnene !12_AS	et	f	\N
202393	kümnesse	"kümnene %kümne  )NE_aA  <kümme ;05_N	et	f	\N
202421	vähenõdlike	?vähenõdlike =vähenõdlike  (SgN  >vähenõdlike !12_S	et	f	\N
202422	vähenõdlike	?vähenõdlike =vähenõdlike  (PlG  >vähenõdlik !25_A	et	f	\N
202423	vähenõdlike	?vähenõdlike =nõdlike  (SgN  >vähe+nõdlike !12_S	et	f	\N
202426	kindlustus	kindlustus =kindlustu  (IndIpfSg3  >kindlustuma !27_V	et	f	\N
202427	kindlustus	kindlustus =kindlustus  (SgN  >kindlustus !11_S	et	f	\N
202428	kindlustus	"kindlustus %kindlusta  )US_vS  <kindlustama ;27_V	et	f	\N
202441	põlvkonnas	põlvkonnas =põlvkonna  (SgIn  >põlvkond !22_S	et	f	\N
202442	põlvkonnas	põlvkonnas =konna  (SgIn  >põlv+konn !22_S	et	f	\N
202443	ministre	### ministre	et	f	\N
202448	loengudel	?loengudel =udel  (SgN  >loeng+udel !02_S	et	f	\N
202449	rägida	?rägida =rägi  (Inf  >rägima !27_V	et	f	\N
202450	arusama	?arusama =arusama  (SgG  >arusam !02_A	et	f	\N
202472	ehitustööd	ehitustööd =töö  (PlN  >ehitus+töö !26_S	et	f	\N
202473	ehitustööd	ehitustööd =töö  (SgP  >ehitus+töö !26_S	et	f	\N
202479	inzeneerina	?inzeneerina =inzeneeri  (SgEs  >inzeneeri !16_S	et	f	\N
202480	inzeneerina	?inzeneerina =inzeneeri  (SgEs  >inzeneer !22_S	et	f	\N
202481	inzeneerina	?inzeneerina =inzeneerina  (SgG  >inzeneerin !02_S	et	f	\N
202485	studentid	?studentid =studenti  (PlN  >studenti !01_S	et	f	\N
202491	informatika	?informatika =informatika  (SgN  >informatika !01_S	et	f	\N
202492	informatika	?informatika =informatika  (SgG  >informatika !01_S	et	f	\N
202493	informatika	?informatika =informatika  (SgG  >informatikas !02_A	et	f	\N
202503	pingema	pingema =ema  (SgN  >ping+ema !17_S	et	f	\N
202504	pingema	pingema =ema  (SgG  >ping+ema !17_S	et	f	\N
202505	pingema	pingema =ema  (SgP  >ping+ema !17_S	et	f	\N
202513	energetikud	?energetikud =energetiku  (PlN  >energetik !02_S	et	f	\N
202514	energetikud	?energetikud =energetiku  (IndPrSg2  >energetikuma !27_V	et	f	\N
202515	tulisin	?tulisin =tuli  (IndIpfSg1  >tulima !27_V	et	f	\N
202516	tulisin	?tulisin =tulisin  (SgN  >tulisin !19_S	et	f	\N
202523	ehitusel	ehitusel =ehituse  (SgAd  >ehitus !11_S	et	f	\N
202524	ehitusel	"ehitus %ehita  )US_vS  <ehitama ;27_V	et	f	\N
202525	ehitusel	"ehitus %ehi  )TUS1_aS  <ehtima ;28_V	et	f	\N
202530	pangaautomaat	pangaautomaat =maat  (SgN  >panga+auto+maat !22_S	et	f	\N
202531	pangaautomaat	pangaautomaat =automaat  (SgN  >panga+automaat !22_S	et	f	\N
202533	mitmekesiseid	?mitmekesiseid =mitmekesise  (PlP  >mitmekesis !09_S	et	f	\N
202534	mitmekesiseid	?mitmekesiseid =mitmekesisei  (PlN  >mitmekesisei !26_S	et	f	\N
202535	mitmekesiseid	?mitmekesiseid =mitmekesisei  (SgP  >mitmekesisei !26_S	et	f	\N
202544	spordihoones	spordihoones =hoone  (SgIn  >spordi+hoone !06_S	et	f	\N
202545	spordihoones	"spordi+hoone %hoo  )NE_aA  <spordi+hoog ;22_S	et	f	\N
202546	spordihoones	spordihoones =hoone  (PlIn  >spordi+hoon !22_A	et	f	\N
202547	jooksurada	jooksurada =rada  (SgN  >jooksu+rada !18_S	et	f	\N
202548	jooksurada	jooksurada =rada  (SgP  >jooksu+rada !18_S	et	f	\N
202572	nõudlikumatel	nõudlikumatel =nõudlikuma  (PlAd  >nõudlikum !02_A	et	f	\N
202573	nõudlikumatel	"nõudlikum %nõudliku  )M_cA  <nõudlik ;25_A	et	f	\N
202577	kulutusi	kulutusi =kulutusi  (PlP  >kulutus !11_S	et	f	\N
202578	kulutusi	"kulutus %kuluta  )US_vS  <kulutama ;27_V	et	f	\N
202579	kulutusi	"kulutus %kulu  )TUS1_aS  <kuluma ;27_V	et	f	\N
202580	kulutusi	"kulutus %kulu  )TUS2_aS  <kulu ;17_S	et	f	\N
202581	kulutusi	"kulutus %kulu  )TUS2_aS  <kulg ;22_S	et	f	\N
202585	erinevatega	erinevatega =erineva  (PlKom  >erinev !02_A	et	f	\N
202586	erinevatega	"erinev %erine  )V_vA  <erinema ;27_V	et	f	\N
202592	parendamist	parendamist =parendamis  (SgP  >parendamine !12_S	et	f	\N
202593	parendamist	"parendamine %parenda  )MINE_vS  <parendama ;27_V	et	f	\N
202627	kolektiiv	?kolektiiv =kolektiiv  (SgN  >kolektiiv !22_S	et	f	\N
202651	erialates	?erialates =eriala  (PlIn  >eriala !01_S	et	f	\N
202652	erialates	?erialates =erialate  (PlIn  >erialatt !22_S	et	f	\N
202653	erialates	?erialates =alate  (PlIn  >eri+alatt !22_S	et	f	\N
202658	ttülikoolis	?ttülikoolis =ttülikooli  (SgIn  >ttülikooli !16_S	et	f	\N
202659	ttülikoolis	?ttülikoolis =ttülikooli  (SgIn  >ttülikool !22_S	et	f	\N
202660	ttülikoolis	?ttülikoolis =ttülikooli  (IndIpfSg3  >ttülikoolima !28_V	et	f	\N
202661	ttülikoolis	?ttülikoolis =ttülikoolis  (SgN  >ttülikoolis !09_S	et	f	\N
202666	lõpetamisel	lõpetamisel =lõpetamise  (SgAd  >lõpetamine !12_S	et	f	\N
202667	lõpetamisel	"lõpetamine %lõpeta  )MINE_vS  <lõpetama ;27_V	et	f	\N
202668	teaduskonnale	teaduskonnale =teaduskonna  (SgAll  >teaduskond !22_S	et	f	\N
202669	teaduskonnale	teaduskonnale =konna  (SgAll  >teadus+konn !22_S	et	f	\N
202674	tehniliseid	?tehniliseid =tehnilisei  (PlN  >tehnilisei !26_S	et	f	\N
202404	kuueteskümnest	?kuueteskümnest =eteskümne  (PlEl  >kuu+eteskümn !22_S	et	f	\N
202405	kuueteskümnest	?kuueteskümnest =eteskümnes  (SgP  >kuu+eteskümnene !12_A	et	f	\N
202451	perspektivne	?perspektivne =perspektivne  (SgN  >perspektivne !02_A	et	f	\N
202452	perspektivne	?perspektivne =perspektivne  (PlP  >perspektivn !22_S	et	f	\N
202462	õppeaines	õppeaines =aine  (SgIn  >õppe+aine !06_S	et	f	\N
202463	õppeaines	õppeaines =aine  (PlIn  >õppe+ain !22_S	et	f	\N
202464	õppeaines	õppeaines =aines  (SgN  >õppe+aines !09_S	et	f	\N
202474	proekteerimine	?proekteerimine =proekteerimine  (SgN  >proekteerimine !12_S	et	f	\N
202475	proekteerimine	?proekteerimine =proekteerimine  (PlP  >proekteerimin !19_S	et	f	\N
202482	astmise	?astmise =astmise  (SgG  >astmine !12?10_S	et	f	\N
202483	astmise	?astmise =astmise  (IndPrPs_  >astmisema !27_V	et	f	\N
202484	astmise	?astmise =astmise  (ImpPrSg2  >astmisema !27_V	et	f	\N
202506	energeetikast	energeetikast =energeetika  (SgEl  >energeetika !01_S	et	f	\N
202507	energeetikast	energeetikast =energeetikas  (SgP  >energeetikane !12_A	et	f	\N
202508	energeetikast	"energeetikane %energeetika  )NE_aA  <energeetika ;01_S	et	f	\N
202519	õpeda	?õpeda =õpe  (Inf  >õpema !27_V	et	f	\N
202526	ehitusteaduskonna	ehitusteaduskonna =konna  (SgG  >ehitus+teadus+konn !22_S	et	f	\N
202527	ehitusteaduskonna	ehitusteaduskonna =konna  (SgP  >ehitus+teadus+konn !22_S	et	f	\N
202528	ehitusteaduskonna	ehitusteaduskonna =konna  (SgAdt  >ehitus+teadus+konn !22_S	et	f	\N
202529	ehitusteaduskonna	ehitusteaduskonna =teaduskonna  (SgG  >ehitus+teaduskond !22_S	et	f	\N
202536	linnakus	linnakus =linnaku  (SgIn  >linnak !02_S	et	f	\N
202537	linnakus	linnakus =aku  (SgIn  >linn+aku !16_S	et	f	\N
202540	täismõõtmetega	täismõõtmetega =me  (PlKom  >täis+mõõt+mesi !15_S	et	f	\N
202541	täismõõtmetega	täismõõtmetega =mõõtme  (PlKom  >täis+mõõde !05_S	et	f	\N
202568	õppekoha	õppekoha =koha  (SgN  >õppe+koha !17_S	et	f	\N
202569	õppekoha	õppekoha =koha  (SgG  >õppe+koha !17_S	et	f	\N
202570	õppekoha	õppekoha =koha  (SgG  >õppe+koht !22_S	et	f	\N
202571	õppekoha	õppekoha =koha  (SgP  >õppe+koha !17_S	et	f	\N
202574	igakuist	igakuist =ku  (PlEl  >iga+kuu !26_S	et	f	\N
202575	igakuist	igakuist =kuis  (SgP  >iga+kuine !10_A	et	f	\N
202576	igakuist	"iga+kuine %kui  )NE_aA  <iga+kuu ;26_S	et	f	\N
202590	spetsialiistid	?spetsialiistid =spetsialiisti  (PlN  >spetsialiist !22_S	et	f	\N
202591	spetsialiistid	?spetsialiistid =spetsialiisti  (IndPrSg2  >spetsialiistima !28_V	et	f	\N
202635	nõuest	?nõuest =nõues  (SgP  >nõuene !10_A	et	f	\N
202644	õpimiseks	?õpimiseks =õpimise  (SgTr  >õpimine !12_S	et	f	\N
202645	suhtlemisvalmis	suhtlemisvalmis =valmi  (SgIn  >suhtlemis+valmis !02_A	et	f	\N
202646	suhtlemisvalmis	suhtlemisvalmis =valmi  (SgIn  >suhtlemis+valm !22_S	et	f	\N
202647	suhtlemisvalmis	suhtlemisvalmis =valmis  (SgN  >suhtlemis+valmis !02_A	et	f	\N
202714	daiving	?daiving =daiving  (SgN  >daiving !02_S	et	f	\N
202718	1aasta	aasta =aasta  (SgN  >aasta !01_S	et	f	\N
202719	1aasta	aasta =aasta  (SgG  >aasta !01_S	et	f	\N
202720	nõutus	nõutus =nõutu  (SgIn  >nõutu !01_AS	et	f	\N
202721	nõutus	"nõutu %nõu  )TU1_vS  <nõudma ;34_V	et	f	\N
202722	nõutus	"nõutu %nõu  )TU2_kA  <nõu ;26_S	et	f	\N
202723	nõutus	nõutus =nõutus  (SgN  >nõutus !11~09_S	et	f	\N
202724	nõutus	"nõutus %nõuta  )US_vS  <nõutama ;27_V	et	f	\N
202725	nõutus	"nõutus %nõu  )TUS1_aS  <nõudma ;34_V	et	f	\N
202726	nõutus	"nõutus %nõu  )TUS2_aS  <nõu ;26_S	et	f	\N
202737	tula	?tula =tula  (SgN  >tula !17_S	et	f	\N
202738	tula	?tula =tula  (SgG  >tula !17_S	et	f	\N
202739	tula	?tula =tula  (SgP  >tula !17_S	et	f	\N
202740	tula	?tula =tula  (IndPrPs_  >tulama !27_V	et	f	\N
202741	tula	?tula =tula  (ImpPrSg2  >tulama !27_V	et	f	\N
202744	vahem	?vahem =vahem  (SgN  >vahem !02_A	et	f	\N
202759	tallinnini	tallinnini =ini  (SgN  >tallinn+ini !17_S	et	f	\N
202760	tallinnini	tallinnini =ini  (SgG  >tallinn+ini !17_S	et	f	\N
202761	tallinnini	tallinnini =ini  (SgP  >tallinn+ini !17_S	et	f	\N
202764	emakeelseks	emakeelseks =seks  (SgN  >ema+keel+seks !22_S	et	f	\N
202765	emakeelseks	emakeelseks =keelse  (SgTr  >ema+keelne !02_A	et	f	\N
202768	3ii	?ii =ii  (SgN  >ii !26_S	et	f	\N
202769	3ii	?ii =ii  (SgG  >ii !26_S	et	f	\N
202780	ekraniseeritud	ekraniseeritud =ekraniseeri  (PtsPtIps  >ekraniseerima !28_V	et	f	\N
202781	ekraniseeritud	ekraniseeritud =ekraniseeritu  (PlN  >ekraniseeritu !01_S	et	f	\N
202782	ekraniseeritud	"ekraniseeritu %ekraniseeri  )TU1_vS  <ekraniseerima ;28_V	et	f	\N
202783	ekraniseeritud	ekraniseeritud =ekraniseeritud  (ID  >ekraniseeritud !41_A	et	f	\N
202784	ekraniseeritud	"ekraniseeritud %ekraniseeri  )TUD_vA  <ekraniseerima ;28_V	et	f	\N
202786	vaatajatele	vaatajatele =vaataja  (PlAll  >vaataja !01_S	et	f	\N
202787	vaatajatele	"vaataja %vaata  )JA_vS  <vaatama ;29_V	et	f	\N
202794	jätakse	?jätakse =jätakse  (SgG  >jätakne !02_A	et	f	\N
202801	valitsejaga	valitsejaga =valitseja  (SgKom  >valitseja !01_S	et	f	\N
202802	valitsejaga	"valitseja %valitse  )JA_vS  <valitsema ;27_V	et	f	\N
202815	kromanov	?kromanov =kromanov  (SgN  >kromanov !02_A	et	f	\N
202821	kunstihuvi	kunstihuvi =huvi  (SgN  >kunsti+huvi !17_S	et	f	\N
202822	kunstihuvi	kunstihuvi =huvi  (SgG  >kunsti+huvi !17_S	et	f	\N
202412	arvude	arvude =ude  (SgN  >arv+ude !04_S	et	f	\N
202417	unistustega	unistustega =unistus  (PlKom  >unistus !11_S	et	f	\N
202418	unistustega	"unistus %unista  )US_vS  <unistama ;27_V	et	f	\N
202437	ambitsioonilised	ambitsioonilised =ambitsioonilise  (PlN  >ambitsiooniline !12_A	et	f	\N
202438	ambitsioonilised	"ambitsiooniline %ambitsiooni  )LINE_aA  <ambitsioon ;22_S	et	f	\N
202444	kõrgkool	kõrgkool =koo  (SgAd  >kõrg+kubu !18_S	et	f	\N
202445	kõrgkool	kõrgkool =kool  (SgN  >kõrg+kool !22_S	et	f	\N
202446	õppitama	?õppitama =õppita  (Sup  >õppitama !27_V	et	f	\N
202447	õppitama	?õppitama =õppitama  (SgG  >õppitam !02_A	et	f	\N
202460	pristiizne	?pristiizne =pristiizne  (SgN  >pristiizne !02_A	et	f	\N
202461	pristiizne	?pristiizne =pristiizne  (PlP  >pristiizn !22_S	et	f	\N
202476	labolatooriumid	?labolatooriumid =labolatooriumi  (PlN  >labolatoorium !19~02_S	et	f	\N
202477	labolatooriumid	?labolatooriumid =labolatooriumi  (PlN  >labolatooriumi !16_S	et	f	\N
202478	labolatooriumid	?labolatooriumid =labolatooriumi  (IndPrSg2  >labolatooriumima !28_V	et	f	\N
202494	valesin	?valesin =vale  (IndIpfSg1  >valema !27_V	et	f	\N
202495	valesin	?valesin =valesin  (SgN  >valesin !19_S	et	f	\N
202499	puhasmatemaatika	puhasmatemaatika =matemaatika  (SgN  >puhas+matemaatika !01_S	et	f	\N
202500	puhasmatemaatika	puhasmatemaatika =matemaatika  (SgG  >puhas+matemaatika !01_S	et	f	\N
202509	energetikast	?energetikast =energetika  (SgEl  >energetika !01_S	et	f	\N
202510	energetikast	?energetikast =energetika  (SgEl  >energetikas !02_A	et	f	\N
202511	energetikast	?energetikast =energetikas  (SgP  >energetikane !12_A	et	f	\N
202512	inemest	?inemest =inemes  (SgP  >inemene !12_A	et	f	\N
202517	tundilt	?tundilt =tundi  (SgAbl  >tundi !16_S	et	f	\N
202518	tundilt	?tundilt =tundi  (SgAbl  >tunt !22_S	et	f	\N
202532	jnne	### jnne	et	f	\N
202566	hea-	hea- =hea  (SgN  >hea !26_AS	et	f	\N
202567	hea-	hea- =hea  (SgG  >hea !26_AS	et	f	\N
202588	tsiviiliehutuse	?tsiviiliehutuse =tsiviiliehutuse  (SgG  >tsiviiliehutus !11?09_S	et	f	\N
202594	vaalik	?vaalik =vaalik  (SgN  >vaalik !02_S	et	f	\N
202615	õppetamis	?õppetamis =õppetami  (SgIn  >õppetam !02_A	et	f	\N
202616	õppetamis	?õppetamis =õppetamis  (SgN  >õppetamis !09_S	et	f	\N
202617	õppetamis	?õppetamis =tami  (SgIn  >õppe+tami !17_S	et	f	\N
202618	õppetamis	?õppetamis =tamis  (SgN  >õppe+tamis !09_S	et	f	\N
202631	millile	?millile =milli  (SgAll  >milli !16_S	et	f	\N
202632	millile	?millile =milli  (SgAll  >mill !22_S	et	f	\N
202633	millile	?millile =millile  (IndPrPs_  >millilema !27_V	et	f	\N
202634	millile	?millile =millile  (ImpPrSg2  >millilema !27_V	et	f	\N
202636	kujutamine	kujutamine =kujutamine  (SgN  >kujutamine !12_S	et	f	\N
202637	kujutamine	"kujutamine %kujuta  )MINE_vS  <kujutama ;27_V	et	f	\N
202640	laiendamist	laiendamist =laiendamis  (SgP  >laiendamine !12_S	et	f	\N
202641	laiendamist	"laiendamine %laienda  )MINE_vS  <laiendama ;27_V	et	f	\N
202676	pähi	?pähi =pähi  (SgN  >pähi !17_S	et	f	\N
202677	pähi	?pähi =pähi  (SgG  >pähi !17_S	et	f	\N
202678	pähi	?pähi =pähi  (SgP  >pähi !17_S	et	f	\N
202679	pähi	?pähi =pähi  (IndPrPs_  >pähima !27_V	et	f	\N
202680	pähi	?pähi =pähi  (ImpPrSg2  >pähima !27_V	et	f	\N
202686	tuutorid	?tuutorid =tuutori  (PlN  >tuutori !01_S	et	f	\N
202687	tuutorid	?tuutorid =tuutori  (PlN  >tuutor !02_S	et	f	\N
202692	tunnidest	?tunnidest =tunni  (PlEl  >tunni !16_S	et	f	\N
202693	tunnidest	?tunnidest =tunni  (PlEl  >tunn !22_S	et	f	\N
202694	tunnidest	?tunnidest =tunnides  (SgP  >tunnidene !12_A	et	f	\N
202735	tsivil	?tsivil =tsivi  (SgAd  >tsivi !17_S	et	f	\N
202736	profession	?profession =profession  (SgN  >profession !19~02_S	et	f	\N
202770	okkupatsioon	?okkupatsioon =okkupatsioon  (SgN  >okkupatsioon !22_S	et	f	\N
202773	kettis	?kettis =ketti  (IndIpfSg3  >kettima !28_V	et	f	\N
202774	kettis	?kettis =kettis  (ID  >kettis !41_DA	et	f	\N
202816	mäekula	mäekula =kula  (SgN  >mäe+kula !17_S	et	f	\N
202817	mäekula	mäekula =kula  (SgG  >mäe+kula !17_S	et	f	\N
202818	mäekula	mäekula =kula  (SgP  >mäe+kula !17_S	et	f	\N
202825	abstraktsionismi	abstraktsionismi =abstraktsionismi  (SgG  >abstraktsionism !22_S	et	f	\N
202826	abstraktsionismi	abstraktsionismi =abstraktsionismi  (SgP  >abstraktsionism !22_S	et	f	\N
202827	abstraktsionismi	abstraktsionismi =abstraktsionismi  (SgAdt  >abstraktsionism !22_S	et	f	\N
202838	kettiga	### kettiga	et	f	\N
202839	ribbentroppi-molotovi	?ribbentroppi-molotovi =molotovi  (ID  >ribbentroppi-molotovi !41_D	et	f	\N
202840	ribbentroppi-molotovi	?ribbentroppi-molotovi =molotovi  (SgG  >ribbentroppi-molotov !02_A	et	f	\N
202841	tänavasse	tänavasse =tänava  (SgIll  >tänav !02_A	et	f	\N
202842	tänavasse	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
202843	tänavasse	tänavasse =tänava  (SgIll  >tänav !02_S	et	f	\N
202844	tänavasse	tänavasse =tänavas  (SgAdt  >tänavane !12_A	et	f	\N
202845	tänavasse	"tänavane %tänava  )NE_aA  <tänav ;02_S	et	f	\N
202846	tänavasse	tänavasse =asse  (PlP  >tänav+ass !22_S	et	f	\N
202847	eestini	eestini =eesti  (SgTer  >eesti !16_H	et	f	\N
202848	eestini	eestini =ini  (SgN  >eest+ini !17_S	et	f	\N
202849	eestini	eestini =ini  (SgG  >eest+ini !17_S	et	f	\N
202850	eestini	eestini =ini  (SgP  >eest+ini !17_S	et	f	\N
202457	automaatikaliselt	automaatikaliselt =tikalise  (SgAbl  >auto+maa+tikaline !12_A	et	f	\N
202458	automaatikaliselt	"auto+maa+tikaline %tika  )LINE_aA  <auto+maa+tikk ;22_S	et	f	\N
202459	automaatikaliselt	"auto+maa+tikaliselt %tika  )LISELT_mD  <auto+maa+tikk ;22_S	et	f	\N
202467	turvatööd	turvatööd =töö  (PlN  >turva+töö !26_S	et	f	\N
202468	turvatööd	turvatööd =töö  (SgP  >turva+töö !26_S	et	f	\N
202469	seeüldiselt	seeüldiselt =üldise  (SgAbl  >see+üldine !10~12_A	et	f	\N
202470	seeüldiselt	"see+üldiselt %üldise  )LT_mD  <see+üldine ;10_A	et	f	\N
202471	seeüldiselt	"see+üldiselt %üldise  )LT_mD  <see+üldine ;12_A	et	f	\N
202486	seltivad	?seltivad =seltiva  (PlN  >seltiva !01_S	et	f	\N
202487	seltivad	?seltivad =seltiva  (PlN  >seltiv !02_A	et	f	\N
202520	ehituseriala	ehituseriala =ala  (SgN  >ehitus+eri+ala !17_S	et	f	\N
202521	ehituseriala	ehituseriala =ala  (SgG  >ehitus+eri+ala !17_S	et	f	\N
202522	ehituseriala	ehituseriala =ala  (SgP  >ehitus+eri+ala !17_S	et	f	\N
202538	sportivõimalusi	?sportivõimalusi =sportivõimalusi  (PlP  >sportivõimalus !11_S	et	f	\N
202539	sportivõimalusi	?sportivõimalusi =ivõimalusi  (PlP  >sport+ivõimalus !11_S	et	f	\N
202559	fittest	?fittest =fitte  (SgEl  >fite !06_S	et	f	\N
202560	fittest	?fittest =fittes  (SgP  >fittes !09_S	et	f	\N
202561	fittest	?fittest =fittes  (SgP  >fittene !12~10_A	et	f	\N
202595	piiretu	?piiretu =piiretu  (SgN  >piiretu !01_A	et	f	\N
202596	piiretu	?piiretu =piiretu  (SgG  >piiretu !01_A	et	f	\N
202597	piiretu	?piiretu =piiretu  (IndPrPs_  >piiretuma !27_V	et	f	\N
202598	piiretu	?piiretu =piiretu  (ImpPrSg2  >piiretuma !27_V	et	f	\N
202599	piiretu	?piiretu =etu  (SgN  >piir+etu !16_S	et	f	\N
202600	piiretu	?piiretu =etu  (SgG  >piir+etu !16_S	et	f	\N
202606	kolmani	?kolmani =kolma  (SgTer  >kolma !16_S	et	f	\N
202607	kolmani	?kolmani =kolmani  (SgG  >kolman !02_S	et	f	\N
202608	kolmani	?kolmani =ani  (SgN  >kolm+ani !17_S	et	f	\N
202609	kolmani	?kolmani =ani  (SgG  >kolm+ani !17_S	et	f	\N
202610	kolmani	?kolmani =ani  (SgP  >kolm+ani !17_S	et	f	\N
202611	tuleviks	tuleviks =tulevi  (SgTr  >tulev !02_A	et	f	\N
202612	tuleviks	"tulev %tule  )V_vA  <tulema ;36_V	et	f	\N
202613	tuleviks	tuleviks =iks  (SgN  >tulev+iks !22_S	et	f	\N
202614	tuleviks	tuleviks =viks  (SgN  >tule+viks !22_AS	et	f	\N
202642	unustamist	unustamist =unustamis  (SgP  >unustamine !12_S	et	f	\N
202643	unustamist	"unustamine %unusta  )MINE_vS  <unustama ;27_V	et	f	\N
202648	tsiviilehitusesse	tsiviilehitusesse =ehituse  (SgIll  >tsiviil+ehitus !11_S	et	f	\N
202649	tsiviilehitusesse	tsiviilehitusesse =ehituses  (SgAdt  >tsiviil+ehitusene !12_A	et	f	\N
202650	tsiviilehitusesse	"tsiviil+ehitusene %ehituse  )NE_aA  <tsiviil+ehitus ;11_S	et	f	\N
202654	eelarveliselt	eelarveliselt =arvelise  (SgAbl  >eel+arveline !12_A	et	f	\N
202655	eelarveliselt	"eel+arveline %arve  )LINE_aA  <eel+arve ;06_S	et	f	\N
202656	eelarveliselt	"eel+arveliselt %arve  )LISELT_mD  <eel+arve ;06_S	et	f	\N
202657	eelarveliselt	"eel+arveliselt %arvelise  )LT_mD  <eel+arveline ;12_A	et	f	\N
202662	ttülikoolis	?ttülikoolis =ttülikooli  (SgIn  >ttülikooli !16_S	et	f	\N
202663	ttülikoolis	?ttülikoolis =ttülikooli  (SgIn  >ttülikool !22_S	et	f	\N
202664	ttülikoolis	?ttülikoolis =ttülikooli  (IndIpfSg3  >ttülikoolima !28_V	et	f	\N
202665	ttülikoolis	?ttülikoolis =ttülikoolis  (SgN  >ttülikoolis !09_S	et	f	\N
202672	küllaga	küllaga =külla  (SgKom  >küll !22_S	et	f	\N
202673	küllaga	küllaga =küllaga  (ID  >küllaga !41_D	et	f	\N
202681	programmerimise	programmerimise =erimise  (SgG  >programm+erimine !12_S	et	f	\N
202682	programmerimise	"programm+erimine %erimi  )NE_aA  <programm+erim ;02_S	et	f	\N
202698	kevadest	kevadest =kevade  (SgEl  >kevade !01_S	et	f	\N
202699	kevadest	kevadest =kevade  (SgEl  >kevad !02_S	et	f	\N
202700	kevadest	kevadest =kevades  (SgP  >kevadene !12_A	et	f	\N
202701	kevadest	"kevadene %kevade  )NE_aA  <kevade ;01_S	et	f	\N
202702	kevadest	"kevadene %kevade  )NE_aA  <kevad ;02_S	et	f	\N
202747	õppeaastast	õppeaastast =aasta  (SgEl  >õppe+aasta !01_S	et	f	\N
202748	õppeaastast	õppeaastast =aastas  (SgP  >õppe+aastane !12~10_A	et	f	\N
202749	õppeaastast	"õppe+aastane %aasta  )NE_aA  <õppe+aasta ;01_S	et	f	\N
202750	hoonega	hoonega =hoone  (SgKom  >hoone !06_S	et	f	\N
202751	hoonega	"hoone %hoo  )NE_aA  <hoog ;22_S	et	f	\N
202752	tubat	?tubat =tubat  (SgN  >tubat !02_S	et	f	\N
202763	õpeaastat	?õpeaastat =õpeaasta  (SgP  >õpeaasta !16_S	et	f	\N
202766	olulisest	olulisest =olulise  (SgEl  >oluline !12_A	et	f	\N
202767	olulisest	"oluline %olu  )LINE_aA  <olu ;17_S	et	f	\N
202788	lahendavad	lahendavad =lahenda  (IndPrPl3  >lahendama !27_V	et	f	\N
202789	lahendavad	lahendavad =lahendava  (PlN  >lahendav !02_A	et	f	\N
202790	lahendavad	"lahendav %lahenda  )V_vA  <lahendama ;27_V	et	f	\N
202791	räägiva	?räägiva =räägiva  (SgN  >räägiva !01_S	et	f	\N
202792	räägiva	?räägiva =räägiva  (SgG  >räägiva !01_S	et	f	\N
202793	räägiva	?räägiva =räägiva  (SgG  >räägiv !02_A	et	f	\N
202799	hallim	hallim =hallim  (SgN  >hallim !02_A	et	f	\N
202800	hallim	"hallim %halli  )M_cA  <hall ;22_AS	et	f	\N
202805	pehmeme	?pehmeme =pehme  (IndPrPl1  >pehmema !27_V	et	f	\N
202806	ooperas	?ooperas =oopera  (SgIn  >oopera !01_S	et	f	\N
202490	lõbusevad	?lõbusevad =seva  (PlN  >lõbu+seva !17_S	et	f	\N
202496	kallastelt	kallastelt =kallas  (PlAbl  >kallas !07_S	et	f	\N
202497	kallastelt	kallastelt =kallas  (PlAbl  >kallane !10_A	et	f	\N
202498	kallastelt	"kallane %kalla  )NE_aA  <kalla ;16_S	et	f	\N
202501	tehtikaülikool	?tehtikaülikool =tehtikaülikoo  (SgAd  >tehtikaülikoo !26_S	et	f	\N
202502	tehtikaülikool	?tehtikaülikool =tehtikaülikool  (SgN  >tehtikaülikool !22_S	et	f	\N
202542	jooksurajad	jooksurajad =raja  (PlN  >jooksu+raja !17_S	et	f	\N
202543	jooksurajad	jooksurajad =raja  (PlN  >jooksu+rada !18_S	et	f	\N
202549	võimlemise	võimlemise =võimlemise  (SgG  >võimlemine !12_S	et	f	\N
202550	võimlemise	"võimlemine %võimle  )MINE_vS  <võimlema ;30_V	et	f	\N
202551	badmintoniplatsi	?badmintoniplatsi =badmintoniplatsi  (SgG  >badmintoniplats !22_S	et	f	\N
202552	badmintoniplatsi	?badmintoniplatsi =badmintoniplatsi  (SgP  >badmintoniplats !22_S	et	f	\N
202553	badmintoniplatsi	?badmintoniplatsi =badmintoniplatsi  (SgAdt  >badmintoniplats !22_S	et	f	\N
202554	badmintoniplatsi	?badmintoniplatsi =badmintoniplatsi  (IndPrPs_  >badmintoniplatsima !28_V	et	f	\N
202555	badmintoniplatsi	?badmintoniplatsi =badmintoniplatsi  (ImpPrSg2  >badmintoniplatsima !28_V	et	f	\N
202556	terviseklubi	terviseklubi =klubi  (SgN  >tervise+klubi !17_S	et	f	\N
202557	terviseklubi	terviseklubi =klubi  (SgG  >tervise+klubi !17_S	et	f	\N
202558	terviseklubi	terviseklubi =klubi  (SgP  >tervise+klubi !17_S	et	f	\N
202562	massööri	massööri =ööri  (SgG  >mass+öör !22_S	et	f	\N
202563	massööri	massööri =ööri  (SgP  >mass+öör !22_S	et	f	\N
202564	massööri	massööri =ööri  (SgAdt  >mass+öör !22_S	et	f	\N
202565	campuse	?campuse =campuse  (SgG  >campus !11~09_S	et	f	\N
202582	kümnes	kümnes =kümne  (SgIn  >kümmend !05_N	et	f	\N
202583	kümnes	kümnes =kümne  (SgIn  >kümme !05_N	et	f	\N
202584	kümnes	kümnes =kümnes  (SgN  >kümnes !02_O	et	f	\N
202587	ehitusteaduskonnas	ehitusteaduskonnas =konna  (SgIn  >ehitus+teadus+konn !22_S	et	f	\N
202589	ehitusteaduskonnas	ehitusteaduskonnas =teaduskonna  (SgIn  >ehitus+teaduskond !22_S	et	f	\N
202601	olümpiadides	?olümpiadides =olümpiadi  (PlIn  >olümpiadi !16_S	et	f	\N
202602	olümpiadides	?olümpiadides =olümpiadi  (PlIn  >olümpiad !22_S	et	f	\N
202603	olümpiadides	?olümpiadides =olümpiadi  (Ger  >olümpiadima !28_V	et	f	\N
202604	olümpiadides	?olümpiadides =dide  (SgIn  >olümpia+dide !16_S	et	f	\N
202605	olümpiadides	?olümpiadides =dides  (SgN  >olümpia+dides !09_S	et	f	\N
202619	õppetamist	?õppetamist =õppetami  (SgEl  >õppetam !02_A	et	f	\N
202620	õppetamist	?õppetamist =õppetamis  (SgP  >õppetamis !09_S	et	f	\N
202621	õppetamist	?õppetamist =õppetamis  (SgP  >õppetamine !12_S	et	f	\N
202622	õppetamist	?õppetamist =õppetamist  (SgN  >õppetamist !22_S	et	f	\N
202623	õppetamist	?õppetamist =tami  (SgEl  >õppe+tami !17_S	et	f	\N
202624	õppetamist	?õppetamist =tamis  (SgP  >õppe+tamis !09_S	et	f	\N
202625	õppetamist	?õppetamist =tamis  (SgP  >õppe+tamine !10_A	et	f	\N
202626	õppetamist	?õppetamist =tamist  (SgN  >õppe+tamist !22_S	et	f	\N
202628	insineer	?insineer =insineer  (SgN  >insineer !22_S	et	f	\N
202629	insineeriga	?insineeriga =insineeri  (SgKom  >insineeri !16_S	et	f	\N
202630	insineeriga	?insineeriga =insineeri  (SgKom  >insineer !22_S	et	f	\N
202638	kahesta	kahesta =kahesta  (IndPrPs_  >kahestama !27_V	et	f	\N
202639	kahesta	kahesta =kahesta  (ImpPrSg2  >kahestama !27_V	et	f	\N
202670	programmerimine	programmerimine =erimine  (SgN  >programm+erimine !12_S	et	f	\N
202671	programmerimine	"programm+erimine %erimi  )NE_aA  <programm+erim ;02_S	et	f	\N
202703	discol	?discol =disco  (SgAd  >disco !16_S	et	f	\N
202704	discol	?discol =discol  (SgN  >discol !02_S	et	f	\N
202707	mikroraioonis	?mikroraioonis =mikroraiooni  (SgIn  >mikroraiooni !16_S	et	f	\N
202708	mikroraioonis	?mikroraioonis =mikroraiooni  (SgIn  >mikroraioon !22_S	et	f	\N
202709	mikroraioonis	?mikroraioonis =mikroraiooni  (IndIpfSg3  >mikroraioonima !28_V	et	f	\N
202710	mikroraioonis	?mikroraioonis =mikroraioonis  (SgN  >mikroraioonis !09_S	et	f	\N
202711	mikroraioonis	?mikroraioonis =raiooni  (SgIn  >mikro+raiooni !16_S	et	f	\N
202712	mikroraioonis	?mikroraioonis =raiooni  (SgIn  >mikro+raioon !22_S	et	f	\N
202713	mikroraioonis	?mikroraioonis =raioonis  (SgN  >mikro+raioonis !09_S	et	f	\N
202715	biisnes	?biisnes =biisne  (PlIn  >biisn !22_S	et	f	\N
202716	biisnes	?biisnes =biisne  (IndIpfSg3  >biisnema !27_V	et	f	\N
202717	biisnes	?biisnes =biisnes  (SgN  >biisnes !09_S	et	f	\N
202727	energeline	?energeline =energeline  (SgN  >energeline !12_A	et	f	\N
202728	energeline	?energeline =energeline  (PlP  >energelin !19_S	et	f	\N
202745	õpehoones	?õpehoones =õpehoone  (SgIn  >õpehoone !16_S	et	f	\N
202746	õpehoones	?õpehoones =õpehoone  (PlIn  >õpehoon !22_S	et	f	\N
202753	vanemalt	vanemalt =vanema  (SgAbl  >vanem !02_AS	et	f	\N
202754	vanemalt	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
202755	vanemalt	vanemalt =vanemalt  (ID  >vanemalt !41_D	et	f	\N
202756	vanemalt	"vanemalt %vanema  )LT_mD  <vanem ;02_AS	et	f	\N
202757	vanemalt	vanemalt =alt  (SgN  >vanem+alt !22_S	et	f	\N
202762	jarjekorras	?jarjekorras =jarjekorra  (SgIn  >jarjekorra !16_S	et	f	\N
202771	okkupatsioo	?okkupatsioo =okkupatsioo  (SgN  >okkupatsioo !26_S	et	f	\N
202772	okkupatsioo	?okkupatsioo =okkupatsioo  (SgG  >okkupatsioo !26_S	et	f	\N
202675	tehniliseid	?tehniliseid =tehnilisei  (SgP  >tehnilisei !26_S	et	f	\N
202683	informatikale	?informatikale =informatika  (SgAll  >informatika !01_S	et	f	\N
202684	informatikale	?informatikale =informatika  (SgAll  >informatikas !02_A	et	f	\N
202685	informatikale	?informatikale =informatikale  (PlP  >informatikal !19_S	et	f	\N
202688	õpetajast	õpetajast =õpetaja  (SgEl  >õpetaja !01_S	et	f	\N
202689	õpetajast	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
202690	õpetajast	õpetajast =õpetajas  (SgP  >õpetajane !12_A	et	f	\N
202691	õpetajast	"õpetajane %õpetaja  )NE_aA  <õpetaja ;01_S	et	f	\N
202695	probleemeid	?probleemeid =probleemei  (PlN  >probleemei !26_S	et	f	\N
202696	probleemeid	?probleemeid =probleemei  (SgP  >probleemei !26_S	et	f	\N
202697	probleemeid	?probleemeid =eid  (SgN  >probleem+eid !22_S	et	f	\N
202705	rühti	rühti =rühti  (SgP  >rüht !22_S	et	f	\N
202706	rühti	rühti =rühti  (SgAdt  >rüht !22_S	et	f	\N
202729	infotehnologia	?infotehnologia =infotehnologia  (SgN  >infotehnologia !01_S	et	f	\N
202730	infotehnologia	?infotehnologia =infotehnologia  (SgG  >infotehnologia !01_S	et	f	\N
202731	infotehnologia	?infotehnologia =logia  (SgN  >info+tehno+logia !01_S	et	f	\N
202732	infotehnologia	?infotehnologia =logia  (SgG  >info+tehno+logia !01_S	et	f	\N
202733	infotehnologia	?infotehnologia =tehnologia  (SgN  >info+tehnologia !01_S	et	f	\N
202734	infotehnologia	?infotehnologia =tehnologia  (SgG  >info+tehnologia !01_S	et	f	\N
202742	õpehoones	?õpehoones =õpehoone  (SgIn  >õpehoone !16_S	et	f	\N
202743	õpehoones	?õpehoones =õpehoone  (PlIn  >õpehoon !22_S	et	f	\N
202758	kellettega	### kellettega	et	f	\N
202775	hakkava	hakkava =hakkava  (SgG  >hakkav !02_A	et	f	\N
202776	hakkava	"hakkav %hakka  )V_vA  <hakkama ;29_V	et	f	\N
202777	hakkava	hakkava =ava  (SgN  >hakk+ava !17_S	et	f	\N
202778	hakkava	hakkava =ava  (SgG  >hakk+ava !17_S	et	f	\N
202779	hakkava	hakkava =ava  (SgP  >hakk+ava !17_S	et	f	\N
202795	nsväle	?nsväle =nsväle  (SgN  >nsväle !16_S	et	f	\N
202796	nsväle	?nsväle =nsväle  (SgG  >nsväle !16_S	et	f	\N
202797	nsväle	?nsväle =nsväle  (IndPrPs_  >nsvälema !27_V	et	f	\N
202798	nsväle	?nsväle =nsväle  (ImpPrSg2  >nsvälema !27_V	et	f	\N
202807	baletis	?baletis =baleti  (SgIn  >balett !22_S	et	f	\N
202808	baletis	?baletis =baletis  (SgN  >baletis !11_S	et	f	\N
202812	rezisöörid	?rezisöörid =rezisööri  (PlN  >rezisööri !16_S	et	f	\N
202813	rezisöörid	?rezisöörid =rezisööri  (PlN  >rezisöör !22_S	et	f	\N
202814	rezisöörid	?rezisöörid =rezisööri  (IndPrSg2  >rezisöörima !28_V	et	f	\N
202831	televisioone	televisioone =televisioone  (PlP  >televisioon !22_S	et	f	\N
202832	televisioone	televisioone =visioone  (PlP  >tele+visioon !22_S	et	f	\N
202835	huvilisi	huvilisi =huvilisi  (PlP  >huviline !12_SA	et	f	\N
202836	huvilisi	"huviline %huvi  )LINE_aA  <huvi ;17_S	et	f	\N
202860	stuudias	?stuudias =stuudia  (SgIn  >stuudia !01_S	et	f	\N
202861	stuudias	?stuudias =stuudias  (SgN  >stuudias !11_S	et	f	\N
202885	rezisööri	?rezisööri =rezisööri  (SgN  >rezisööri !16_S	et	f	\N
202886	rezisööri	?rezisööri =rezisööri  (SgG  >rezisööri !16_S	et	f	\N
202887	rezisööri	?rezisööri =rezisööri  (SgG  >rezisöör !22_S	et	f	\N
202888	rezisööri	?rezisööri =rezisööri  (SgP  >rezisöör !22_S	et	f	\N
202889	rezisööri	?rezisööri =rezisööri  (SgAdt  >rezisöör !22_S	et	f	\N
202890	rezisööri	?rezisööri =rezisööri  (IndPrPs_  >rezisöörima !28_V	et	f	\N
202891	rezisööri	?rezisööri =rezisööri  (ImpPrSg2  >rezisöörima !28_V	et	f	\N
202894	veterinaar	?veterinaar =veterinaar  (SgN  >veterinaar !22_S	et	f	\N
202895	veterinaar	?veterinaar =rinaar  (SgN  >vete+rinaar !22_S	et	f	\N
202914	mpilli	?mpilli =mpilli  (SgN  >mpilli !16_S	et	f	\N
202915	mpilli	?mpilli =mpilli  (SgG  >mpilli !16_S	et	f	\N
202916	mpilli	?mpilli =mpilli  (SgG  >mpill !22_S	et	f	\N
202917	mpilli	?mpilli =mpilli  (SgP  >mpill !22_S	et	f	\N
202918	mpilli	?mpilli =mpilli  (SgAdt  >mpill !22_S	et	f	\N
202919	mpilli	?mpilli =mpilli  (IndPrPs_  >mpillima !28_V	et	f	\N
202920	mpilli	?mpilli =mpilli  (ImpPrSg2  >mpillima !28_V	et	f	\N
202930	streigima	?streigima =streigi  (Sup  >streigima !28_V	et	f	\N
202931	streigima	?streigima =streigima  (SgG  >streigim !02_A	et	f	\N
202941	igak	?igak =igak  (SgN  >igak !02_S	et	f	\N
202949	püan	?püan =püan  (SgN  >püan !22_S	et	f	\N
202971	tutvuja	tutvuja =tutvuja  (SgN  >tutvuja !01_S	et	f	\N
202972	tutvuja	"tutvuja %tutvu  )JA_vS  <tutvuma ;27_V	et	f	\N
202973	tutvuja	tutvuja =tutvuja  (SgG  >tutvuja !01_S	et	f	\N
202981	sõbrade	?sõbrade =sõbra  (PlG  >sõbra !16_S	et	f	\N
203013	müüjage	### müüjage	et	f	\N
203042	magistraturis	?magistraturis =magistraturi  (SgIn  >magistratur !19_S	et	f	\N
203043	magistraturis	?magistraturis =magistraturis  (SgN  >magistraturis !09_S	et	f	\N
203078	elsamitöö	?elsamitöö =elsamitöö  (SgN  >elsamitöö !26_S	et	f	\N
203079	elsamitöö	?elsamitöö =elsamitöö  (SgG  >elsamitöö !26_S	et	f	\N
203088	aktsepteerivad	aktsepteerivad =aktsepteeri  (IndPrPl3  >aktsepteerima !28_V	et	f	\N
203089	aktsepteerivad	aktsepteerivad =aktsepteeriva  (PlN  >aktsepteeriv !02_A	et	f	\N
203090	aktsepteerivad	"aktsepteeriv %aktsepteeri  )V_vA  <aktsepteerima ;28_V	et	f	\N
202785	50-ndal	### 50-ndal	et	f	\N
202803	hrushtshovi	?hrushtshovi =hrushtshovi  (ID  >hrushtshovi !41_D	et	f	\N
202804	hrushtshovi	?hrushtshovi =hrushtshovi  (SgG  >hrushtshov !02_A	et	f	\N
202809	debüteerivad	debüteerivad =debüteeri  (IndPrPl3  >debüteerima !28_V	et	f	\N
202810	debüteerivad	debüteerivad =debüteeriva  (PlN  >debüteeriv !02_A	et	f	\N
202811	debüteerivad	"debüteeriv %debüteeri  )V_vA  <debüteerima ;28_V	et	f	\N
202819	relikvia	?relikvia =relikvia  (SgN  >relikvia !01_S	et	f	\N
202820	relikvia	?relikvia =relikvia  (SgG  >relikvia !01_S	et	f	\N
202877	jägisin	?jägisin =jägi  (IndIpfSg1  >jägima !27_V	et	f	\N
202878	jägisin	?jägisin =jägisin  (SgN  >jägisin !19_S	et	f	\N
202893	eseet	?eseet =eseet  (SgN  >eseet !22_S	et	f	\N
202911	majandusteadust	majandusteadust =teadu  (SgEl  >majandus+tead !22_S	et	f	\N
202912	majandusteadust	majandusteadust =teadus  (SgP  >majandus+teadus !11~09_S	et	f	\N
202935	iseseisvuste	iseseisvuste =seisvus  (PlG  >ise+seisvus !11~09_S	et	f	\N
202936	iseseisvuste	"ise+seisvus %seisva  )US_aS  <ise+seisev ;02_A	et	f	\N
202937	sõbraline	sõbraline =sõbraline  (SgN  >sõbraline !12_A	et	f	\N
202938	sõbraline	"sõbraline %sõbra  )LINE_aA  <sõber ;24_S	et	f	\N
202939	kultluur	?kultluur =kultluur  (SgN  >kultluur !22_S	et	f	\N
202959	vau	vau =vau  (SgN  >vau !26_S	et	f	\N
202960	vau	vau =vau  (SgG  >vau !26_S	et	f	\N
202980	lühedalt	?lühedalt =lühedalt  (ID  >lühedalt !41_D	et	f	\N
202993	energetikul	?energetikul =energetiku  (SgAd  >energetik !02_S	et	f	\N
202994	energetikul	?energetikul =energetikul  (SgN  >energetikul !19_S	et	f	\N
203017	bakalaurisse	?bakalaurisse =bakalauri  (SgIll  >bakalauri !16_S	et	f	\N
203018	bakalaurisse	?bakalaurisse =bakalauri  (SgIll  >bakalaur !19_S	et	f	\N
203019	bakalaurisse	?bakalaurisse =bakalaurisse  (SgG  >bakalaurisne !02_A	et	f	\N
203020	bakalaurisse	?bakalaurisse =bakalaurisse  (PlP  >bakalauriss !22_S	et	f	\N
203025	realiseeritud	realiseeritud =realiseeri  (PtsPtIps  >realiseerima !28_V	et	f	\N
203026	realiseeritud	realiseeritud =realiseeritu  (PlN  >realiseeritu !01_S	et	f	\N
203027	realiseeritud	"realiseeritu %realiseeri  )TU1_vS  <realiseerima ;28_V	et	f	\N
203028	realiseeritud	realiseeritud =realiseeritud  (ID  >realiseeritud !41_A	et	f	\N
203029	realiseeritud	"realiseeritud %realiseeri  )TUD_vA  <realiseerima ;28_V	et	f	\N
203046	huvitavama	huvitavama =huvitavama  (SgG  >huvitavam !02_A	et	f	\N
203047	huvitavama	"huvitavam %huvita  )VAM_cA  <huvitama ;27_V	et	f	\N
203048	huvitavama	"huvitavam %huvitava  )M_cA  <huvitav ;02_A	et	f	\N
203093	harjumuspäraselt	harjumuspäraselt =pärase  (SgAbl  >harjumus+pärane !10_A	et	f	\N
203095	harjumuspäraselt	"harjumus+pärane %pära  )NE_aA  <harjumus+pära ;17_S	et	f	\N
203096	harjumuspäraselt	"harjumus+päraselt %pära  )SELT_mD  <harjumus+pära ;17_S	et	f	\N
203098	harjumuspäraselt	"harjumus+päraselt %pärase  )LT_mD  <harjumus+pärane ;10_A	et	f	\N
203103	kehtestanud	kehtestanud =kehtesta  (PtsPtPs  >kehtestama !27_V	et	f	\N
203104	kehtestanud	kehtestanud =kehtestanu  (PlN  >kehtestanu !01_S	et	f	\N
203105	kehtestanud	"kehtestanu %kehtesta  )NU_vS  <kehtestama ;27_V	et	f	\N
203106	kehtestanud	kehtestanud =kehtestanud  (ID  >kehtestanud !41_A	et	f	\N
203107	kehtestanud	"kehtestanud %kehtesta  )NUD_vA  <kehtestama ;27_V	et	f	\N
203116	kommunikeerub	?kommunikeerub =kommunikeeru  (IndPrSg3  >kommunikeeruma !27_V	et	f	\N
203142	traditsioonilisusel	traditsioonilisusel =traditsioonilisuse  (SgAd  >traditsioonilisus !11?09_S	et	f	\N
203143	traditsioonilisusel	"traditsioonilisus %traditsiooni  )LISUS_aS  <traditsioon ;22_S	et	f	\N
203158	wremja	?wremja =wremja  (SgN  >wremja !16_S	et	f	\N
203159	wremja	?wremja =wremja  (SgG  >wremjas !02_A	et	f	\N
203160	wremja	?wremja =wremja  (SgG  >wremja !16_S	et	f	\N
203161	wremja	?wremja =wremja  (IndPrPs_  >wremjama !29_V	et	f	\N
203162	wremja	?wremja =wremja  (ImpPrSg2  >wremjama !29_V	et	f	\N
203164	aiku	?aiku =aiku  (SgN  >aiku !16_S	et	f	\N
203165	aiku	?aiku =aiku  (SgG  >aiku !16_S	et	f	\N
203170	eluterved	eluterved =terve  (PlN  >elu+terve !01_AS	et	f	\N
203171	eluterved	eluterved =terve  (PlN  >elu+terve !06_AS	et	f	\N
203203	tajumisel	tajumisel =tajumise  (SgAd  >tajumine !12_S	et	f	\N
203205	tajumisel	"tajumine %taju  )MINE_vS  <tajuma ;27_V	et	f	\N
203211	4l	### 4l	et	f	\N
203214	suhtlumaneer	?suhtlumaneer =suhtlumaneer  (SgN  >suhtlumaneer !22_S	et	f	\N
203215	suhtlumaneer	?suhtlumaneer =lumaneer  (SgN  >suht+lumaneer !22_S	et	f	\N
203216	loomus	loomus =loomu  (SgIn  >loom !22_S	et	f	\N
203217	loomus	loomus =loomus  (SgN  >loomus !11~09_S	et	f	\N
203220	koostöövalmidusest	koostöövalmidusest =valmiduse  (SgEl  >koos+töö+valmidus !11_S	et	f	\N
203221	koostöövalmidusest	"koos+töö+valmidus %valmi  )US_aS  <koos+töö+valmis ;02_A	et	f	\N
203222	koostöövalmidusest	koostöövalmidusest =valmiduses  (SgP  >koos+töö+valmidusene !12_A	et	f	\N
203223	koostöövalmidusest	"koos+töö+valmidusene %valmiduse  )NE_aA  <koos+töö+valmidus ;11_S	et	f	\N
203244	nädalalõpu-lisalehte	nädalalõpu-lisalehte =lehte  (SgP  >nädalalõpu-lisa+leht !22_S	et	f	\N
203245	nädalalõpu-lisalehte	nädalalõpu-lisalehte =lehte  (SgAdt  >nädalalõpu-lisa+leht !22_S	et	f	\N
203246	nädalalõpu-lisalehte	nädalalõpu-lisalehte =lehte  (PlP  >nädalalõpu-lisa+leht !22_S	et	f	\N
203271	beasley	### beasley	et	f	\N
202823	kunstihuvi	kunstihuvi =huvi  (SgP  >kunsti+huvi !17_S	et	f	\N
202824	kunstihuvi	kunstihuvi =ihuvi  (SgG  >kunst+ihuv !02_A	et	f	\N
202857	rexisöörid	?rexisöörid =rexisööri  (PlN  >rexisööri !16_S	et	f	\N
202858	rexisöörid	?rexisöörid =rexisööri  (PlN  >rexisöör !22_S	et	f	\N
202859	rexisöörid	?rexisöörid =rexisööri  (IndPrSg2  >rexisöörima !28_V	et	f	\N
202865	asutamisega	asutamisega =asutamise  (SgKom  >asutamine !12_S	et	f	\N
202866	asutamisega	"asutamine %asuta  )MINE_vS  <asutama ;27_V	et	f	\N
202872	kasvatanud	kasvatanud =kasvata  (PtsPtPs  >kasvatama !27_V	et	f	\N
202873	kasvatanud	kasvatanud =kasvatanu  (PlN  >kasvatanu !01_S	et	f	\N
202874	kasvatanud	"kasvatanu %kasvata  )NU_vS  <kasvatama ;27_V	et	f	\N
202875	kasvatanud	kasvatanud =kasvatanud  (ID  >kasvatanud !41_A	et	f	\N
202876	kasvatanud	"kasvatanud %kasvata  )NUD_vA  <kasvatama ;27_V	et	f	\N
202879	esitletud	esitletud =esitle  (PtsPtIps  >esitlema !27_V	et	f	\N
202880	esitletud	esitletud =esitletu  (PlN  >esitletu !01_S	et	f	\N
202881	esitletud	"esitletu %esitle  )TU1_vS  <esitlema ;27_V	et	f	\N
202882	esitletud	esitletud =esitletud  (ID  >esitletud !41_A	et	f	\N
202883	esitletud	"esitletud %esitle  )TUD_vA  <esitlema ;27_V	et	f	\N
202898	lnnus	### lnnus	et	f	\N
202905	reaalkallukaga	?reaalkallukaga =reaalkalluka  (SgKom  >reaalkallukas !02_A	et	f	\N
202906	reaalkallukaga	?reaalkallukaga =reaalkalluka  (SgKom  >reaalkalluka !16_S	et	f	\N
202907	reaalkallukaga	?reaalkallukaga =kalluka  (SgKom  >reaal+kalluka !01_S	et	f	\N
202908	reaalkallukaga	?reaalkallukaga =kalluka  (SgKom  >reaal+kallukas !02_A	et	f	\N
202909	reaalkallukaga	?reaalkallukaga =alkalluka  (SgKom  >rea+alkallukas !02_A	et	f	\N
202910	reaalkallukaga	?reaalkallukaga =alkalluka  (SgKom  >rea+alkalluka !16_S	et	f	\N
202913	tegesid	?tegesid =tege  (PlP  >tege !16_S	et	f	\N
202927	faasi	faasi =faasi  (SgG  >faas !22_S	et	f	\N
202928	faasi	faasi =faasi  (SgP  >faas !22_S	et	f	\N
202929	faasi	faasi =faasi  (SgAdt  >faas !22_S	et	f	\N
202942	töstus-	?töstus- =töstu  (SgIn  >töstu !16_S	et	f	\N
202943	töstus-	?töstus- =töstu  (IndIpfSg3  >töstuma !27_V	et	f	\N
202944	töstus-	?töstus- =töstus  (SgN  >töstus !11~09_S	et	f	\N
202945	bakalaurise	?bakalaurise =bakalaurise  (SgG  >bakalauris !09_S	et	f	\N
202946	tpt	### tpt	et	f	\N
202961	kindlasli	?kindlasli =kindlasli  (SgN  >kindlasli !01_S	et	f	\N
202962	kindlasli	?kindlasli =kindlasli  (SgG  >kindlasli !01_S	et	f	\N
202963	kindlasli	?kindlasli =kindlasli  (SgG  >kindlasl !22_S	et	f	\N
202964	kindlasli	?kindlasli =kindlasli  (SgP  >kindlasl !22_S	et	f	\N
202965	kindlasli	?kindlasli =kindlasli  (SgAdt  >kindlasl !22_S	et	f	\N
202966	kindlasli	?kindlasli =kindlasli  (IndPrPs_  >kindlaslima !28_V	et	f	\N
202967	kindlasli	?kindlasli =kindlasli  (ImpPrSg2  >kindlaslima !28_V	et	f	\N
202969	tugendemis	?tugendemis =tugendemi  (SgIn  >tugendem !02_A	et	f	\N
202970	tugendemis	?tugendemis =tugendemis  (SgN  >tugendemis !09_S	et	f	\N
202976	rahuldamist	rahuldamist =rahuldamis  (SgP  >rahuldamine !12_S	et	f	\N
202977	rahuldamist	"rahuldamine %rahulda  )MINE_vS  <rahuldama ;27_V	et	f	\N
203001	exmatrekulerimine	?exmatrekulerimine =exmatrekulerimine  (SgN  >exmatrekulerimine !12_S	et	f	\N
203002	exmatrekulerimine	?exmatrekulerimine =exmatrekulerimine  (PlP  >exmatrekulerimin !19_S	et	f	\N
203010	mehanikale	?mehanikale =mehanika  (SgAll  >mehanika !01_S	et	f	\N
203011	mehanikale	?mehanikale =mehanika  (SgAll  >mehanikas !02_A	et	f	\N
203012	mehanikale	?mehanikale =mehanikale  (PlP  >mehanikal !19_S	et	f	\N
203037	õppemist	?õppemist =õppemi  (SgEl  >õppemi !01_S	et	f	\N
203038	õppemist	?õppemist =õppemi  (SgEl  >õppem !02_A	et	f	\N
203039	õppemist	?õppemist =õppemis  (SgP  >õppemis !11_S	et	f	\N
203040	õppemist	?õppemist =õppemis  (SgP  >õppemine !12_S	et	f	\N
203041	õppemist	?õppemist =õppemist  (SgN  >õppemist !22_S	et	f	\N
203049	insperatsioon	?insperatsioon =insperatsioon  (SgN  >insperatsioon !22_S	et	f	\N
203055	insineeriks	?insineeriks =insineeri  (SgTr  >insineeri !16_S	et	f	\N
203056	insineeriks	?insineeriks =insineeri  (SgTr  >insineer !22_S	et	f	\N
203057	insineeriks	?insineeriks =insineeri  (KndPrPs  >insineerima !28_V	et	f	\N
203082	kindlustunde	kindlustunde =tunde  (SgG  >kindlus+tunne !06_S	et	f	\N
203083	kindlustunde	kindlustunde =tunde  (PlP  >kindlus+tund !22_S	et	f	\N
203084	normaalseks	normaalseks =normaalse  (SgTr  >normaalne !02_A	et	f	\N
203085	normaalseks	normaalseks =seks  (SgN  >normaal+seks !22_S	et	f	\N
203108	sotsialiseeruma	?sotsialiseeruma =sotsialiseeru  (Sup  >sotsialiseeruma !27_V	et	f	\N
203121	vastavas	vastavas =vastava  (SgIn  >vastav !02_A	et	f	\N
203122	vastavas	"vastav %vasta  )V_vA  <vastama ;29_V	et	f	\N
203123	vastavas	vastavas =ava  (SgIn  >vast+ava !17_S	et	f	\N
203127	formuleerub	?formuleerub =formuleeru  (IndPrSg3  >formuleeruma !27_V	et	f	\N
203136	tagaksid	tagaksid =taga  (KndPrSg2  >tagama !27_V	et	f	\N
203138	tagaksid	tagaksid =taga  (KndPrPl3  >tagama !27_V	et	f	\N
203140	kindlustundel	kindlustundel =tunde  (SgAd  >kindlus+tunne !06_S	et	f	\N
203141	kindlustundel	kindlustundel =tundel  (SgN  >kindlus+tundel !02_S	et	f	\N
203144	järgimine	järgimine =järgimine  (SgN  >järgimine !12_S	et	f	\N
203145	järgimine	"järgimine %järgi  )MINE_vS  <järgima ;27_V	et	f	\N
202828	kassettipõlvkond	?kassettipõlvkond =kassettipõlvkond  (SgN  >kassettipõlvkond !22_S	et	f	\N
202829	kassettipõlvkond	?kassettipõlvkond =ipõlvkond  (SgN  >kassett+ipõlvkond !22_S	et	f	\N
202830	kassettipõlvkond	?kassettipõlvkond =settipõlvkond  (SgN  >kas+settipõlvkond !22_S	et	f	\N
202833	kirjanikutel	?kirjanikutel =kirjanikute  (PlAd  >kirjanikutt !22_S	et	f	\N
202834	kirjanikutel	?kirjanikutel =nikute  (PlAd  >kirja+nikutt !22_S	et	f	\N
202837	baltik	?baltik =baltik  (SgN  >baltik !02_S	et	f	\N
202862	otsiga	otsiga =otsi  (SgKom  >ots !22_S	et	f	\N
202863	otsiga	otsiga =iga  (SgN  >ots+iga !18_S	et	f	\N
202864	otsiga	otsiga =iga  (SgP  >ots+iga !18_S	et	f	\N
202868	tõesi	?tõesi =tõesi  (SgN  >tõesi !16_S	et	f	\N
202869	tõesi	?tõesi =tõesi  (SgG  >tõesi !16_S	et	f	\N
202870	tõesi	?tõesi =tõesi  (IndPrPs_  >tõesima !28_V	et	f	\N
202871	tõesi	?tõesi =tõesi  (ImpPrSg2  >tõesima !28_V	et	f	\N
202884	tollajasel	?tollajasel =tollajase  (SgAd  >tollajane !12_A	et	f	\N
202896	muinasteadust	muinasteadust =teadu  (SgEl  >muinas+tead !22_S	et	f	\N
202897	muinasteadust	muinasteadust =teadus  (SgP  >muinas+teadus !11~09_S	et	f	\N
202921	avalda	avalda =avalda  (IndPrPs_  >avaldama !27_V	et	f	\N
202922	avalda	avalda =avalda  (ImpPrSg2  >avaldama !27_V	et	f	\N
202947	napal	napal =napa  (SgAd  >napp !22_S	et	f	\N
202948	napal	napal =napa  (SgAd  >napp !22_A	et	f	\N
202982	tarkuses	tarkuses =tarkuse  (SgIn  >tarkus !11~09_S	et	f	\N
202983	tarkuses	"tarkus %tark  )US_aS  <tark ;22_AS	et	f	\N
202984	tarkuses	tarkuses =tarkuse  (SgIn  >tarkune !12~10_A	et	f	\N
202985	tarkuses	tarkuses =use  (PlIn  >tark+usk !22_S	et	f	\N
202995	jõuenergetika	?jõuenergetika =jõuenergetika  (SgN  >jõuenergetika !01_S	et	f	\N
202996	jõuenergetika	?jõuenergetika =jõuenergetika  (SgG  >jõuenergetika !01_S	et	f	\N
202997	jõuenergetika	?jõuenergetika =jõuenergetika  (SgG  >jõuenergetikas !02_A	et	f	\N
202998	jõuenergetika	?jõuenergetika =energetika  (SgN  >jõu+energetika !01_S	et	f	\N
202999	jõuenergetika	?jõuenergetika =energetika  (SgG  >jõu+energetika !01_S	et	f	\N
203000	jõuenergetika	?jõuenergetika =energetika  (SgG  >jõu+energetikas !02_A	et	f	\N
203005	jarigmesel	?jarigmesel =jarigmese  (SgAd  >jarigmene !12_A	et	f	\N
203021	õppetööt	?õppetööt =õppetööt  (SgN  >õppetööt !22_S	et	f	\N
203022	õppetööt	?õppetööt =tööt  (SgN  >õppe+tööt !22_S	et	f	\N
203030	testerimine	testerimine =erimine  (SgN  >test+erimine !12_S	et	f	\N
203031	testerimine	"test+erimine %erimi  )NE_aA  <test+erim ;02_S	et	f	\N
203050	matkas	matkas =matka  (SgIn  >matk !22_S	et	f	\N
203051	matkas	matkas =matka  (IndIpfSg3  >matkama !29_V	et	f	\N
203065	haabersti	?haabersti =haabersti  (SgN  >haabersti !01_S	et	f	\N
203066	haabersti	?haabersti =haabersti  (SgG  >haabersti !01_S	et	f	\N
203067	haabersti	?haabersti =haabersti  (SgG  >haaberst !22_S	et	f	\N
203068	haabersti	?haabersti =haabersti  (SgP  >haaberst !22_S	et	f	\N
203069	haabersti	?haabersti =haabersti  (SgAdt  >haaberst !22_S	et	f	\N
203070	haabersti	?haabersti =haabersti  (IndPrPs_  >haaberstima !28_V	et	f	\N
203071	haabersti	?haabersti =haabersti  (ImpPrSg2  >haaberstima !28_V	et	f	\N
203072	haabersti	?haabersti =ersti  (SgN  >haab+ersti !01_S	et	f	\N
203073	haabersti	?haabersti =ersti  (SgG  >haab+ersti !01_S	et	f	\N
203074	haabersti	?haabersti =ersti  (SgG  >haab+erst !22_S	et	f	\N
203075	haabersti	?haabersti =ersti  (SgP  >haab+erst !22_S	et	f	\N
203076	haabersti	?haabersti =ersti  (SgAdt  >haab+erst !22_S	et	f	\N
203114	iseõpitud	iseõpitud =õpitu  (PlN  >ise+õpitu !01_S	et	f	\N
203115	iseõpitud	"ise+õpitu %õpi  )TU2_kA  <ise+õpp ;22_S	et	f	\N
203148	mitmetähenduslikkusele	mitmetähenduslikkusele =tähenduslikkuse  (SgAll  >mitme+tähenduslikkus !11~09_S	et	f	\N
203149	mitmetähenduslikkusele	"mitme+tähenduslikkus %tähenduslikku  )US_aS  <mitme+tähenduslik ;25_A	et	f	\N
203150	minapildi	minapildi =pildi  (SgG  >mina+pilt !22_S	et	f	\N
203151	minapildi	minapildi =pildi  (SgP  >mina+pild !22_S	et	f	\N
203152	minapildi	minapildi =pildi  (SgAdt  >mina+pild !22_S	et	f	\N
203168	veidrused	veidrused =veidruse  (PlN  >veidrus !11~09_S	et	f	\N
203169	veidrused	"veidrus %veidra  )US_aS  <veider ;02_A	et	f	\N
203212	ladus	ladus =ladu  (IndIpfSg3  >laduma !28_V	et	f	\N
203213	ladus	ladus =ladus  (SgN  >ladus !02_A	et	f	\N
203229	toimetuses	toimetuses =toimetuse  (SgIn  >toimetus !11_S	et	f	\N
203230	toimetuses	"toimetus %toimeta  )US_vS  <toimetama ;27_V	et	f	\N
203231	toimetuses	"toimetus %toime  )TUS2_aS  <toime ;06_S	et	f	\N
203232	toimetuses	"toimetus %toime  )TUS2_aS  <toim ;22_S	et	f	\N
203233	tõlkeabi	tõlkeabi =abi  (SgN  >tõlke+abi !17_S	et	f	\N
203234	tõlkeabi	tõlkeabi =abi  (SgG  >tõlke+abi !17_S	et	f	\N
203235	tõlkeabi	tõlkeabi =abi  (SgP  >tõlke+abi !17_S	et	f	\N
203238	toimetusele	toimetusele =toimetuse  (SgAll  >toimetus !11_S	et	f	\N
203239	toimetusele	"toimetus %toimeta  )US_vS  <toimetama ;27_V	et	f	\N
203240	toimetusele	"toimetus %toime  )TUS2_aS  <toime ;06_S	et	f	\N
203241	toimetusele	"toimetus %toime  )TUS2_aS  <toim ;22_S	et	f	\N
203269	eesõo	?eesõo =eesõo  (SgN  >eesõo !26_S	et	f	\N
203270	eesõo	?eesõo =eesõo  (SgG  >eesõo !26_S	et	f	\N
203272	teenija	teenija =teenija  (SgN  >teenija !01_S	et	f	\N
202851	maailmat	?maailmat =maailma  (SgP  >maailma !01_S	et	f	\N
202852	maailmat	?maailmat =ilmat  (SgN  >maa+ilmat !02_S	et	f	\N
202853	hirve	hirve =hirve  (SgG  >hirv !22_S	et	f	\N
202854	hirve	hirve =hirve  (SgP  >hirv !22_S	et	f	\N
202855	hirve	hirve =hirve  (SgAdt  >hirv !22_S	et	f	\N
202856	hirve	hirve =hirve  (PlP  >hirv !22_S	et	f	\N
202867	talumehede	?talumehede =mehe  (PlG  >talu+mehe !16_S	et	f	\N
202892	tollajase	?tollajase =tollajase  (SgG  >tollajane !12_A	et	f	\N
202899	suitsuetersoni	?suitsuetersoni =suitsueterso  (SgTer  >suitsueterso !16_S	et	f	\N
202900	suitsuetersoni	?suitsuetersoni =suitsuetersoni  (SgG  >suitsueterson !02_S	et	f	\N
202901	suitsuetersoni	?suitsuetersoni =eterso  (SgTer  >suitsu+eterso !16_S	et	f	\N
202902	suitsuetersoni	?suitsuetersoni =etersoni  (SgG  >suitsu+eterson !19_S	et	f	\N
202903	suitsuetersoni	?suitsuetersoni =etersoni  (SgP  >suitsu+eterson !19_S	et	f	\N
202904	suitsuetersoni	?suitsuetersoni =etersoni  (SgAdt  >suitsu+eterson !19_S	et	f	\N
202923	tõusmist	tõusmist =tõusmis  (SgP  >tõusmine !12?10_S	et	f	\N
202924	tõusmist	"tõusmine %tõus  )MINE_vS  <tõusma ;32_V	et	f	\N
202925	koolitöö	koolitöö =töö  (SgN  >kooli+töö !26_S	et	f	\N
202926	koolitöö	koolitöö =töö  (SgG  >kooli+töö !26_S	et	f	\N
202932	revolutsione	?revolutsione =revolutsione  (SgN  >revolutsione !16_S	et	f	\N
202933	revolutsione	?revolutsione =revolutsione  (SgG  >revolutsione !16_S	et	f	\N
202934	revolutsione	?revolutsione =revolutsione  (PlP  >revolutsion !19_S	et	f	\N
202940	sssr	### sssr	et	f	\N
202950	jälgpallis	?jälgpallis =jälgpalli  (SgIn  >jälgpalli !01_S	et	f	\N
202951	jälgpallis	?jälgpallis =jälgpalli  (SgIn  >jälgpall !22_S	et	f	\N
202952	jälgpallis	?jälgpallis =jälgpalli  (IndIpfSg3  >jälgpallima !28_V	et	f	\N
202953	jälgpallis	?jälgpallis =jälgpallis  (SgN  >jälgpallis !11_S	et	f	\N
202954	mehhatroonik	?mehhatroonik =mehhatroonik  (SgN  >mehhatroonik !02_S	et	f	\N
202955	prespektiivne	?prespektiivne =prespektiivne  (SgN  >prespektiivne !02_A	et	f	\N
202956	prespektiivne	?prespektiivne =prespektiivne  (PlP  >prespektiivn !22_S	et	f	\N
202957	prespektiivne	?prespektiivne =spektiivne  (SgN  >pre+spektiivne !02_A	et	f	\N
202958	prespektiivne	?prespektiivne =spektiivne  (PlP  >pre+spektiivn !22_S	et	f	\N
202968	enseneer	?enseneer =enseneer  (SgN  >enseneer !22_S	et	f	\N
202974	tutvujad	tutvujad =tutvuja  (PlN  >tutvuja !01_S	et	f	\N
202975	tutvujad	"tutvuja %tutvu  )JA_vS  <tutvuma ;27_V	et	f	\N
202978	kultuursemaks	kultuursemaks =kultuursema  (SgTr  >kultuursem !02_A	et	f	\N
202979	kultuursemaks	"kultuursem %kultuurse  )M_cA  <kultuurne ;02_A	et	f	\N
202986	mottes	?mottes =motte  (SgIn  >mote !06_S	et	f	\N
202987	mottes	?mottes =motte  (IndIpfSg3  >mottema !27_V	et	f	\N
202988	mottes	?mottes =mottes  (SgN  >mottes !09_S	et	f	\N
202989	sillamae	?sillamae =sillamae  (SgN  >sillamae !26_S	et	f	\N
202990	sillamae	?sillamae =sillamae  (SgG  >sillamae !26_S	et	f	\N
202991	sillamae	?sillamae =mae  (SgN  >silla+mae !26_S	et	f	\N
202992	sillamae	?sillamae =mae  (SgG  >silla+mae !26_S	et	f	\N
203003	käheteistkümne	?käheteistkümne =käheteistkümne  (SgN  >käheteistkümne !02_A	et	f	\N
203004	käheteistkümne	?käheteistkümne =käheteistkümne  (PlP  >käheteistkümn !22_S	et	f	\N
203006	bakalauris	?bakalauris =bakalauri  (SgIn  >bakalauri !16_S	et	f	\N
203007	bakalauris	?bakalauris =bakalauri  (SgIn  >bakalaur !19_S	et	f	\N
203008	bakalauris	?bakalauris =bakalauri  (IndIpfSg3  >bakalaurima !28_V	et	f	\N
203009	bakalauris	?bakalauris =bakalauris  (SgN  >bakalauris !09_S	et	f	\N
203014	autorium	?autorium =autorium  (SgN  >autorium !19_S	et	f	\N
203015	autorium	?autorium =rium  (SgN  >auto+rium !22_S	et	f	\N
203016	autorium	?autorium =torium  (SgN  >au+torium !19_S	et	f	\N
203023	teduskonnas	?teduskonnas =teduskonna  (SgIn  >teduskonna !16_S	et	f	\N
203024	teduskonnas	?teduskonnas =teduskonna  (SgIn  >teduskond !22_S	et	f	\N
203032	bakalaurusse	?bakalaurusse =bakalaurus  (SgAdt  >bakalaurus !11_S	et	f	\N
203033	bakalaurusse	?bakalaurusse =bakalaurusse  (SgG  >bakalaurusne !02_A	et	f	\N
203034	bakalaurusse	?bakalaurusse =bakalaurusse  (PlP  >bakalauruss !22_S	et	f	\N
203035	jatkama	?jatkama =jatka  (Sup  >jatkama !29_V	et	f	\N
203036	jatkama	?jatkama =jatkama  (SgG  >jatkam !02_A	et	f	\N
203044	omandates	?omandates =omanda  (PlIn  >omanda !01_S	et	f	\N
203045	omandates	?omandates =omandate  (PlIn  >omandatt !22_S	et	f	\N
203052	ehitusega	ehitusega =ehituse  (SgKom  >ehitus !11_S	et	f	\N
203053	ehitusega	"ehitus %ehita  )US_vS  <ehitama ;27_V	et	f	\N
203054	ehitusega	"ehitus %ehi  )TUS1_aS  <ehtima ;28_V	et	f	\N
203058	baltikus	?baltikus =baltiku  (SgIn  >baltiku !01_S	et	f	\N
203059	baltikus	?baltikus =baltiku  (SgIn  >baltik !02_S	et	f	\N
203060	baltikus	?baltikus =baltiku  (IndIpfSg3  >baltikuma !27_V	et	f	\N
203061	baltikus	?baltikus =baltikus  (SgN  >baltikus !11_S	et	f	\N
203062	baltikus	?baltikus =iku  (SgIn  >balt+iku !16_S	et	f	\N
203063	baltikus	?baltikus =iku  (SgIn  >balt+ikk !22_S	et	f	\N
203064	baltikus	?baltikus =ikus  (SgN  >balt+ikus !09_S	et	f	\N
203077	trakistusi	?trakistusi =trakistusi  (PlP  >trakistus !11_S	et	f	\N
203080	normaalsus	normaalsus =normaalsus  (SgN  >normaalsus !11~09_S	et	f	\N
203081	normaalsus	"normaalsus %normaalse  )US_aS  <normaalne ;02_A	et	f	\N
203086	alusbaasiks	alusbaasiks =iks  (SgN  >alus+baas+iks !22_S	et	f	\N
203087	alusbaasiks	alusbaasiks =baasi  (SgTr  >alus+baas !22_S	et	f	\N
203091	kogukondatesse	?kogukondatesse =kogukondate  (PlIll  >kogukondatt !22_S	et	f	\N
203092	kogukondatesse	?kogukondatesse =kogukondates  (SgAdt  >kogukondatene !12_A	et	f	\N
203094	kogukondatesse	?kogukondatesse =kogukondatesse  (SgG  >kogukondatesne !02_A	et	f	\N
203097	kogukondatesse	?kogukondatesse =kogukondatesse  (PlP  >kogukondatess !22_S	et	f	\N
203099	kogukondatesse	?kogukondatesse =kondate  (PlIll  >kogu+kondatt !22_S	et	f	\N
203100	kogukondatesse	?kogukondatesse =kondates  (SgAdt  >kogu+kondatene !12_A	et	f	\N
203101	kogukondatesse	?kogukondatesse =kondatesse  (SgG  >kogu+kondatesne !02_A	et	f	\N
203102	kogukondatesse	?kogukondatesse =kondatesse  (PlP  >kogu+kondatess !22_S	et	f	\N
203109	mõistetavasse	mõistetavasse =mõistetava  (SgIll  >mõistetav !02_A	et	f	\N
203110	mõistetavasse	"mõistetav %mõiste  )TAV_vAS  <mõistma ;34_V	et	f	\N
203113	õpitatavad	?õpitatavad =õpitata  (IndPrPl3  >õpitatama !27_V	et	f	\N
203117	õpitatavad	?õpitatavad =õpitatava  (PlN  >õpitatav !02_A	et	f	\N
203118	õpitatavad	?õpitatavad =õpitatava  (PlN  >õpitatava !16_S	et	f	\N
203119	õpitatavad	?õpitatavad =tatava  (PlN  >õpi+tatava !01_S	et	f	\N
203120	õpitatavad	?õpitatavad =tatava  (PlN  >õpi+tatav !02_A	et	f	\N
203130	normaalsusest	normaalsusest =normaalsuse  (SgEl  >normaalsus !11~09_S	et	f	\N
203131	normaalsusest	"normaalsus %normaalse  )US_aS  <normaalne ;02_A	et	f	\N
203135	eksistentsi	eksistentsi =eksistentsi  (SgG  >eksistents !22_S	et	f	\N
203137	eksistentsi	eksistentsi =eksistentsi  (SgP  >eksistents !22_S	et	f	\N
203139	eksistentsi	eksistentsi =eksistentsi  (SgAdt  >eksistents !22_S	et	f	\N
203153	kommenteerisid	kommenteerisid =kommenteeri  (IndIpfSg2  >kommenteerima !28_V	et	f	\N
203154	kommenteerisid	kommenteerisid =kommenteeri  (IndIpfPl3  >kommenteerima !28_V	et	f	\N
203166	kiiksud	kiiksud =kiiksu  (PlN  >kiiks !22_S	et	f	\N
203167	kiiksud	kiiksud =kiiksu  (IndPrSg2  >kiiksuma !28_V	et	f	\N
203186	kasugi	kasugi =kasu  (SgN^  >kasu !17_S	et	f	\N
203187	kasugi	kasugi =kasu  (SgG^  >kasu !17_S	et	f	\N
203188	kasugi	kasugi =kasu  (SgP^  >kasu !17_S	et	f	\N
203189	meeskonda	meeskonda =meeskonda  (SgP  >meeskond !22_S	et	f	\N
203190	meeskonda	meeskonda =meeskonda  (SgAdt  >meeskond !22_S	et	f	\N
203191	erinevamatest	erinevamatest =erinevama  (PlEl  >erinevam !02_A	et	f	\N
203192	erinevamatest	"erinevam %erine  )VAM_cA  <erinema ;27_V	et	f	\N
203193	erinevamatest	"erinevam %erineva  )M_cA  <erinev ;02_A	et	f	\N
203208	meeldivuse	meeldivuse =meeldivuse  (SgG  >meeldivus !11_S	et	f	\N
203209	meeldivuse	"meeldivus %meeldi  )VUS_aS  <meeldima ;27_V	et	f	\N
203210	meeldivuse	"meeldivus %meeldiva  )US_aS  <meeldiv ;02_A	et	f	\N
203247	esinemises	esinemises =esinemise  (SgIn  >esinemine !12_S	et	f	\N
203248	esinemises	"esinemine %esine  )MINE_vS  <esinema ;27_V	et	f	\N
203277	hoovist	hoovist =hoovi  (SgEl  >hoov !22_S	et	f	\N
203278	hoovist	hoovist =hoovi  (PlEl  >hoob !22_S	et	f	\N
203279	hoovist	hoovist =vist  (SgN  >hoo+vist !22_S	et	f	\N
203282	lollikest	lollikest =lollikes  (SgP  >lollike !12_AS	et	f	\N
203283	lollikest	"lollike %lolli  )KE_dA  <loll ;22_AS	et	f	\N
203284	lollikest	lollikest =lollikes  (SgP  >lollikene !12_S	et	f	\N
203285	lollikest	"lollikene %lolli  )KENE_dA  <loll ;22_AS	et	f	\N
203286	lollikest	lollikest =kest  (SgN  >lolli+kest !22_S	et	f	\N
203289	uuringufirma	uuringufirma =firma  (SgN  >uuringu+firma !16_S	et	f	\N
203290	uuringufirma	uuringufirma =firma  (SgG  >uuringu+firma !16_S	et	f	\N
203296	intelligentsust	intelligentsust =intelligentsus  (SgP  >intelligentsus !11~09_S	et	f	\N
203297	intelligentsust	"intelligentsus %intelligentse  )US_aS  <intelligentne ;02_A	et	f	\N
203301	soovitud	soovitud =soovi  (PtsPtIps  >soovima !28_V	et	f	\N
203302	soovitud	soovitud =soovitu  (PlN  >soovitu !01_AS	et	f	\N
203303	soovitud	"soovitu %soovi  )TU1_vS  <soovima ;28_V	et	f	\N
203304	soovitud	"soovitu %soovi  )TU2_kA  <soov ;22_S	et	f	\N
203305	soovitud	soovitud =soovitud  (ID  >soovitud !41_A	et	f	\N
203306	soovitud	"soovitud %soovi  )TUD_vA  <soovima ;28_V	et	f	\N
203312	ratsionaalselt	ratsionaalselt =ratsionaalse  (SgAbl  >ratsionaalne !02_A	et	f	\N
203313	ratsionaalselt	ratsionaalselt =ratsionaalselt  (ID  >ratsionaalselt !41_D	et	f	\N
203314	ratsionaalselt	"ratsionaalselt %ratsionaalse  )LT_mD  <ratsionaalne ;02_A	et	f	\N
203322	milel	?milel =mile  (SgAd  >mile !16_S	et	f	\N
203323	milel	?milel =milel  (SgN  >milel !02_S	et	f	\N
203329	rahulolevalt	rahulolevalt =oleva  (SgAbl  >rahul+olev !02_A	et	f	\N
203330	rahulolevalt	"rahul+olevalt %oleva  )LT_mD  <rahul+olev ;02_A	et	f	\N
203342	antus	antus =antu  (SgIn  >antu !01_S	et	f	\N
203343	antus	"antu %an  )TU1_vS  <andma ;34_V	et	f	\N
203344	antus	antus =antus  (SgN  >antus !11~09_S	et	f	\N
203345	antus	"antus %an  )TUS1_aS  <andma ;34_V	et	f	\N
203356	töökateks	töökateks =tööka  (PlTr  >töökas !02_A	et	f	\N
203357	töökateks	töökateks =kate  (PlTr  >töö+katt !22_S	et	f	\N
203358	vastuvõtvamad	vastuvõtvamad =võtvama  (PlN  >vastu+võtvam !02_A	et	f	\N
203359	vastuvõtvamad	"vastu+võtvam %võtva  )M_cA  <vastu+võttev ;02_A	et	f	\N
203362	strateegiline	strateegiline =strateegiline  (SgN  >strateegiline !12_A	et	f	\N
203111	sotsialiseerumine	?sotsialiseerumine =sotsialiseerumine  (SgN  >sotsialiseerumine !12_S	et	f	\N
203112	sotsialiseerumine	?sotsialiseerumine =sotsialiseerumine  (PlP  >sotsialiseerumin !19_S	et	f	\N
203124	sotsialiseerumisprotsessi	sotsialiseerumisprotsessi =protsessi  (SgG  >sotsialiseerumis+protsess !22_S	et	f	\N
203125	sotsialiseerumisprotsessi	sotsialiseerumisprotsessi =protsessi  (SgP  >sotsialiseerumis+protsess !22_S	et	f	\N
203126	sotsialiseerumisprotsessi	sotsialiseerumisprotsessi =protsessi  (SgAdt  >sotsialiseerumis+protsess !22_S	et	f	\N
203128	normaalsust	normaalsust =normaalsus  (SgP  >normaalsus !11~09_S	et	f	\N
203129	normaalsust	"normaalsus %normaalse  )US_aS  <normaalne ;02_A	et	f	\N
203132	kindlaksmääratud	kindlaksmääratud =määra  (PtsPtIps  >kindlaks+_määrama !29_V	et	f	\N
203133	kindlaksmääratud	kindlaksmääratud =määratu  (PlN  >kindlaks+määratu !01_AS	et	f	\N
203134	kindlaksmääratud	"kindlaks+määratu %määra  )TU2_kA  <kindlaks+määr ;22_S	et	f	\N
203146	multikultuurilises	multikultuurilises =kultuurilise  (SgIn  >multi+kultuuriline !12_A	et	f	\N
203147	multikultuurilises	"multi+kultuuriline %kultuuri  )LINE_aA  <multi+kultuur ;22_S	et	f	\N
203163	pets	?pets =pets  (SgN  >pets !22_S	et	f	\N
203172	kiiksud	kiiksud =kiiksu  (PlN  >kiiks !22_S	et	f	\N
203173	kiiksud	kiiksud =kiiksu  (IndPrSg2  >kiiksuma !28_V	et	f	\N
203174	normi	normi =normi  (SgG  >norm !22_S	et	f	\N
203175	normi	normi =normi  (SgP  >norm !22_S	et	f	\N
203176	normi	normi =normi  (SgAdt  >norm !22_S	et	f	\N
203177	normi	normi =normi  (IndPrPs_  >normima !28_V	et	f	\N
203178	normi	normi =normi  (ImpPrSg2  >normima !28_V	et	f	\N
203179	alge	alge =alge  (SgN  >alge !05_S	et	f	\N
203180	alge	alge =alge  (SgN  >alge !06_S	et	f	\N
203181	alge	alge =alge  (SgG  >alge !06_S	et	f	\N
203182	alge	alge =alge  (PlP  >alg !22_S	et	f	\N
203183	mitmekesisemaks	?mitmekesisemaks =mitmekesisema  (SgTr  >mitmekesisem !02_A	et	f	\N
203194	tulemuslikumalt	tulemuslikumalt =tulemuslikuma  (SgAbl  >tulemuslikum !02_A	et	f	\N
203195	tulemuslikumalt	"tulemuslikum %tulemusliku  )M_cA  <tulemuslik ;25_A	et	f	\N
203196	tulemuslikumalt	tulemuslikumalt =tulemuslikumalt  (ID  >tulemuslikumalt !41_D	et	f	\N
203197	tulemuslikumalt	"tulemuslikumalt %tulemusliku  )MALT_mD  <tulemuslik ;25_A	et	f	\N
203200	7-liikmelist	-liikmelist =liikmelis  (SgP  >-liikmeline !12_A	et	f	\N
203201	7-liikmelist	"-liikmeline %liikme  )LINE_aA  <-liige ;05_S	et	f	\N
203206	psühholoogid	psühholoogid =psühholoogi  (PlN  >psühholoog !22_S	et	f	\N
203207	psühholoogid	psühholoogid =loogi  (PlN  >psühho+loog !22_S	et	f	\N
203257	lisatööd	lisatööd =töö  (PlN  >lisa+töö !26_S	et	f	\N
203258	lisatööd	lisatööd =töö  (SgP  >lisa+töö !26_S	et	f	\N
203263	simaki	?simaki =simaki  (SgN  >simaki !01_S	et	f	\N
203264	simaki	?simaki =simaki  (SgG  >simaki !01_S	et	f	\N
203265	simaki	?simaki =simaki  (SgG  >simak !02_S	et	f	\N
203266	simaki	?simaki =simaki  (SgG  >simakk !22_S	et	f	\N
203267	simaki	?simaki =simaki  (IndPrPs_  >simakkima !28_V	et	f	\N
203268	simaki	?simaki =simaki  (ImpPrSg2  >simakkima !28_V	et	f	\N
203291	gallup	?gallup =gallup  (SgN  >gallup !02_S	et	f	\N
203292	annet	annet =anne  (SgP  >anne !05_S	et	f	\N
203293	annet	annet =anne  (SgP  >anne !06_S	et	f	\N
203294	tugevaid	tugevaid =tugeva  (PlP  >tugev !02_A	et	f	\N
203295	tugevaid	"tugev %tuge  )V_vA  <tugema ;27_V	et	f	\N
203300	goleman	?goleman =goleman  (SgN  >goleman !19_S	et	f	\N
203324	võikski	võikski =või  (SgTr^  >või !26_S	et	f	\N
203325	võikski	võikski =või  (KndPrPs^  >võima !37_V	et	f	\N
203331	läbistavad	läbistavad =läbista  (IndPrPl3  >läbistama !27_V	et	f	\N
203332	läbistavad	läbistavad =läbistava  (PlN  >läbistav !02_A	et	f	\N
203333	läbistavad	"läbistav %läbista  )V_vA  <läbistama ;27_V	et	f	\N
203354	sirguksid	sirguksid =sirgu  (KndPrSg2  >sirguma !27_V	et	f	\N
203355	sirguksid	sirguksid =sirgu  (KndPrPl3  >sirguma !27_V	et	f	\N
203393	millegagi	millegagi =mille  (SgKom  >miski !00_P	et	f	\N
203394	millegagi	millegagi =mille  (SgKom^  >mis !00_P	et	f	\N
203396	sellelel	?sellelel =sellelel  (SgN  >sellelel !19_S	et	f	\N
203397	kodusoojust	kodusoojust =soojus  (SgP  >kodu+soojus !11~09_S	et	f	\N
203398	kodusoojust	"kodu+soojus %sooj  )US_aS  <kodu+soe ;24_AS	et	f	\N
203399	kodusoojust	kodusoojust =soojus  (SgP  >kodu+soojune !10~12_A	et	f	\N
203400	omadusteks	omadusteks =omadus  (PlTr  >omadus !11_S	et	f	\N
203401	omadusteks	"omadus %oma  )US_aS  <oma ;17_A	et	f	\N
203402	omadusteks	omadusteks =duste  (PlTr  >oma+dust !22_S	et	f	\N
203409	omaduste	omaduste =omadus  (PlG  >omadus !11_S	et	f	\N
203410	omaduste	"omadus %oma  )US_aS  <oma ;17_A	et	f	\N
203411	omaduste	omaduste =duste  (PlP  >oma+dust !22_S	et	f	\N
203423	varasemalt	varasemalt =varasema  (SgAbl  >varasem !02_A	et	f	\N
203424	varasemalt	"varasem %vara  )SEM_cA  <vara ;17_S	et	f	\N
203425	varasemalt	"varasem %varase  )M_cA  <varane ;10_A	et	f	\N
203426	varasemalt	varasemalt =varasemalt  (ID  >varasemalt !41_D	et	f	\N
203427	varasemalt	"varasemalt %vara  )SEMALT_mD  <vara ;17_S	et	f	\N
203428	varasemalt	"varasemalt %varase  )MALT_mD  <varane ;10_A	et	f	\N
203441	naiselikku	naiselikku =naiselikku  (SgP  >naiselik !25_A	et	f	\N
203442	naiselikku	naiselikku =naiselikku  (SgAdt  >naiselik !25_A	et	f	\N
203155	telesaatest	telesaatest =saate  (SgEl  >tele+saade !06_S	et	f	\N
203156	telesaatest	telesaatest =saates  (SgP  >tele+saatene !12~10_A	et	f	\N
203157	telesaatest	"tele+saatene %saate  )NE_aA  <tele+saade ;06_S	et	f	\N
203184	teinekors	?teinekors =teinekors  (SgN  >teinekors !22_S	et	f	\N
203185	teinekors	?teinekors =kors  (SgN  >teine+kors !22_S	et	f	\N
203198	arvuline	arvuline =arvuline  (SgN  >arvuline !12_A	et	f	\N
203199	arvuline	"arvuline %arvu  )LINE_aA  <arv ;22_S	et	f	\N
203202	esmamulje	esmamulje =mulje  (SgN  >esma+mulje !06_S	et	f	\N
203204	esmamulje	esmamulje =mulje  (SgG  >esma+mulje !06_S	et	f	\N
203218	teadmusühiskonnas	?teadmusühiskonnas =teadmusühiskonna  (SgIn  >teadmusühiskonna !16_S	et	f	\N
203219	teadmusühiskonnas	?teadmusühiskonnas =teadmusühiskonna  (SgIn  >teadmusühiskond !22_S	et	f	\N
203224	organisatsiooni	organisatsiooni =organisatsiooni  (SgG  >organisatsioon !22_S	et	f	\N
203225	organisatsiooni	organisatsiooni =organisatsiooni  (SgP  >organisatsioon !22_S	et	f	\N
203226	organisatsiooni	organisatsiooni =organisatsiooni  (SgAdt  >organisatsioon !22_S	et	f	\N
203227	suhtlemisest	suhtlemisest =suhtlemise  (SgEl  >suhtlemine !12_S	et	f	\N
203228	suhtlemisest	"suhtlemine %suhtle  )MINE_vS  <suhtlema ;30_V	et	f	\N
203236	juku	juku =juku  (SgN  >juku !16_S	et	f	\N
203237	juku	juku =juku  (SgG  >juku !16_S	et	f	\N
203242	värviliste	värviliste =värvilis  (PlG  >värviline !12_A	et	f	\N
203243	värviliste	"värviline %värvi  )LINE_aA  <värv ;22_S	et	f	\N
203249	toimetust	toimetust =toimetu  (SgEl  >toimetu !01_A	et	f	\N
203250	toimetust	"toimetu %toime  )TU2_kA  <toime ;06_S	et	f	\N
203251	toimetust	"toimetu %toime  )TU2_kA  <toim ;22_S	et	f	\N
203252	toimetust	toimetust =toimetus  (SgP  >toimetus !11_S	et	f	\N
203253	toimetust	"toimetus %toimeta  )US_vS  <toimetama ;27_V	et	f	\N
203254	toimetust	"toimetus %toime  )TUS2_aS  <toime ;06_S	et	f	\N
203255	toimetust	"toimetus %toime  )TUS2_aS  <toim ;22_S	et	f	\N
203256	toimetust	toimetust =tust  (SgN  >toime+tust !22_S	et	f	\N
203259	muti	muti =muti  (SgN  >muti !16_S	et	f	\N
203260	muti	muti =muti  (SgG  >muti !16_S	et	f	\N
203261	muti	muti =muti  (SgG  >mutt !22_S	et	f	\N
203262	aifford	?aifford =aifford  (SgN  >aifford !22_S	et	f	\N
203287	välise	välise =välise  (SgG  >väline !10_A	et	f	\N
203288	välise	"väline %väli  )NE_aA  <väli ;24_S	et	f	\N
203311	iq	### iq	et	f	\N
203320	unikaalsuses	unikaalsuses =unikaalsuse  (SgIn  >unikaalsus !11~09_S	et	f	\N
203321	unikaalsuses	"unikaalsus %unikaalse  )US_aS  <unikaalne ;02_A	et	f	\N
203334	ihu	ihu =ihu  (SgN  >ihu !17_S	et	f	\N
203335	ihu	ihu =ihu  (SgG  >ihu !17_S	et	f	\N
203336	ihu	ihu =ihu  (SgG  >ihk !22_S	et	f	\N
203337	ihu	ihu =ihu  (SgP  >ihu !17_S	et	f	\N
203338	ihu	ihu =ihu  (IndPrPs_  >ihuma !27_V	et	f	\N
203339	ihu	ihu =ihu  (IndPrPs_  >ihkuma !28_V	et	f	\N
203340	ihu	ihu =ihu  (ImpPrSg2  >ihuma !27_V	et	f	\N
203341	ihu	ihu =ihu  (ImpPrSg2  >ihkuma !28_V	et	f	\N
203364	kaklevaid	kaklevaid =kakleva  (PlP  >kaklev !02_A	et	f	\N
203365	kaklevaid	"kaklev %kakle  )V_vA  <kaklema ;30_V	et	f	\N
203390	kõlapinda	kõlapinda =pinda  (SgG  >kõla+pint !22_S	et	f	\N
203391	kõlapinda	kõlapinda =pinda  (SgP  >kõla+pind !22_S	et	f	\N
203392	kõlapinda	kõlapinda =pinda  (SgAdt  >kõla+pind !22_S	et	f	\N
203414	rakendavad	rakendavad =rakenda  (IndPrPl3  >rakendama !27_V	et	f	\N
203415	rakendavad	rakendavad =rakendava  (PlN  >rakendav !02_A	et	f	\N
203416	rakendavad	"rakendav %rakenda  )V_vA  <rakendama ;27_V	et	f	\N
203439	muutumise	muutumise =muutumise  (SgG  >muutumine !12_S	et	f	\N
203440	muutumise	"muutumine %muutu  )MINE_vS  <muutuma ;27_V	et	f	\N
203454	olekusvõitlus	?olekusvõitlus =olekusvõitlu  (IndIpfSg3  >olekusvõitluma !27_V	et	f	\N
203455	olekusvõitlus	?olekusvõitlus =olekusvõitlus  (SgN  >olekusvõitlus !11~09_S	et	f	\N
203456	olekusvõitlus	?olekusvõitlus =svõitlu  (SgIn  >oleku+svõitlu !01_S	et	f	\N
203457	olekusvõitlus	?olekusvõitlus =svõitlus  (SgN  >oleku+svõitlus !11~09_S	et	f	\N
203477	võitlemise	võitlemise =võitlemise  (SgG  >võitlemine !12_S	et	f	\N
203478	võitlemise	"võitlemine %võitle  )MINE_vS  <võitlema ;30_V	et	f	\N
203495	jäigemalt	jäigemalt =jäigema  (SgAbl  >jäigem !02_A	et	f	\N
203496	jäigemalt	"jäigem %jäige  )M_cA  <jäik ;22_A	et	f	\N
203497	jäigemalt	jäigemalt =jäigemalt  (ID  >jäigemalt !41_D	et	f	\N
203498	jäigemalt	"jäigemalt %jäigema  )LT_mD  <jäigem ;02_A	et	f	\N
203504	koduste	koduste =kodus  (PlG  >kodune !10_A	et	f	\N
203505	koduste	"kodune %kodu  )NE_aA  <kodu ;17_S	et	f	\N
203517	emadus	emadus =emadus  (SgN  >emadus !11_S	et	f	\N
203518	emadus	"emadus %ema  )US_aS  <ema ;17_S	et	f	\N
203519	rikastavam	rikastavam =rikastavam  (SgN  >rikastavam !02_A	et	f	\N
203520	rikastavam	"rikastavam %rikasta  )VAM_cA  <rikastama ;27_V	et	f	\N
203521	sõjakamalt	sõjakamalt =sõjakama  (SgAbl  >sõjakam !02_A	et	f	\N
203522	sõjakamalt	"sõjakam %sõjaka  )M_cA  <sõjakas ;02_A	et	f	\N
203523	sõjakamalt	sõjakamalt =sõjakamalt  (ID  >sõjakamalt !41_D	et	f	\N
203524	sõjakamalt	"sõjakamalt %sõjaka  )MALT_mD  <sõjakas ;02_A	et	f	\N
203525	sõjakamalt	sõjakamalt =kama  (SgAbl  >sõja+kama !17_S	et	f	\N
203273	teenija	"teenija %teeni  )JA_vS  <teenima ;28_V	et	f	\N
203274	teenija	teenija =teenija  (SgG  >teenija !01_S	et	f	\N
203275	mittevastavaks	mittevastavaks =ava  (SgTr  >mitte+vast+ava !17_S	et	f	\N
203276	mittevastavaks	mittevastavaks =vastava  (SgTr  >mitte+vastav !02_A	et	f	\N
203280	tundmatute	tundmatute =tundmatu  (PlG  >tundmatu !01_AS	et	f	\N
203281	tundmatute	"tundmatu %tund  )MATU_vA  <tundma ;34_V	et	f	\N
203307	intelligentsemad	intelligentsemad =intelligentsema  (PlN  >intelligentsem !02_A	et	f	\N
203308	intelligentsemad	"intelligentsem %intelligentse  )M_cA  <intelligentne ;02_A	et	f	\N
203309	läbilöövamad	läbilöövamad =löövama  (PlN  >läbi+löövam !02_A	et	f	\N
203310	läbilöövamad	"läbi+löövam %lööva  )M_cA  <läbi+lööv ;02_A	et	f	\N
203346	mõisteta	mõisteta =mõiste  (SgAb  >mõiste !06_S	et	f	\N
203347	mõisteta	mõisteta =mõiste  (IndPrIps_  >mõistma !34_V	et	f	\N
203370	edasieksisteerimise	edasieksisteerimise =erimise  (SgG  >edasi+eks+iste+erimine !12_S	et	f	\N
203371	edasieksisteerimise	"edasi+eks+iste+erimine %erimi  )NE_aA  <edasi+eks+iste+erim ;02_S	et	f	\N
203372	edasieksisteerimise	edasieksisteerimise =eksisteerimise  (SgG  >edasi+eksisteerimine !12_S	et	f	\N
203379	tögavaks	tögavaks =tögava  (SgTr  >tögav !02_A	et	f	\N
203380	tögavaks	"tögav %töga  )V_vA  <tögama ;27_V	et	f	\N
203384	vastuvõetav	vastuvõetav =võe  (PtsPrIps  >vastu+_võtma !35_V	et	f	\N
203385	vastuvõetav	vastuvõetav =võetav  (SgN  >vastu+võetav !02_A	et	f	\N
203386	tulenevalt	tulenevalt =tuleneva  (SgAbl  >tulenev !02_A	et	f	\N
203387	tulenevalt	"tulenev %tulene  )V_vA  <tulenema ;27_V	et	f	\N
203388	tulenevalt	tulenevalt =tulenevalt  (ID  >tulenevalt !41_D	et	f	\N
203389	tulenevalt	"tulenevalt %tulene  )VALT_mD  <tulenema ;27_V	et	f	\N
203395	ühiskolnd	?ühiskolnd =kolnd  (SgN  >ühis+kolnd !22_S	et	f	\N
203403	hingeomaduse	hingeomaduse =omaduse  (SgG  >hinge+omadus !11_S	et	f	\N
203404	hingeomaduse	"hinge+omadus %oma  )US_aS  <hinge+oma ;17_A	et	f	\N
203407	üleannet	üleannet =anne  (SgP  >üle+anne !05_S	et	f	\N
203408	üleannet	üleannet =anne  (SgP  >üle+anne !06_S	et	f	\N
203419	omadustest	omadustest =omadus  (PlEl  >omadus !11_S	et	f	\N
203420	omadustest	"omadus %oma  )US_aS  <oma ;17_A	et	f	\N
203421	omadustest	omadustest =test  (SgN  >omadus+test !22_S	et	f	\N
203422	omadustest	omadustest =duste  (PlEl  >oma+dust !22_S	et	f	\N
203436	traditsioonilisemat	traditsioonilisemat =traditsioonilisema  (SgP  >traditsioonilisem !02_A	et	f	\N
203437	traditsioonilisemat	"traditsioonilisem %traditsiooni  )LISEM_cA  <traditsioon ;22_S	et	f	\N
203438	traditsioonilisemat	"traditsioonilisem %traditsioonilise  )M_cA  <traditsiooniline ;12_A	et	f	\N
203445	teene	teene =teene  (SgN  >teene !06_S	et	f	\N
203446	teene	"teene %tee  )NE_aA  <tee ;26_S	et	f	\N
203447	teene	teene =teene  (SgN  >teene !10_A	et	f	\N
203448	teene	teene =teene  (SgG  >teene !06_S	et	f	\N
203449	dünaamilisemad	dünaamilisemad =dünaamilisema  (PlN  >dünaamilisem !02_A	et	f	\N
203450	dünaamilisemad	"dünaamilisem %dünaamilise  )M_cA  <dünaamiline ;12_A	et	f	\N
203463	leplikum	leplikum =leplikum  (SgN  >leplikum !02_A	et	f	\N
203464	leplikum	"leplikum %lepliku  )M_cA  <leplik ;25_A	et	f	\N
203479	üksikindiviidi	üksikindiviidi =indiviidi  (SgG  >üksik+indiviid !22_S	et	f	\N
203480	üksikindiviidi	üksikindiviidi =indiviidi  (SgP  >üksik+indiviid !22_S	et	f	\N
203481	üksikindiviidi	üksikindiviidi =indiviidi  (SgAdt  >üksik+indiviid !22_S	et	f	\N
203482	aktsepteeritav	aktsepteeritav =aktsepteeri  (PtsPrIps  >aktsepteerima !28_V	et	f	\N
203483	aktsepteeritav	aktsepteeritav =aktsepteeritav  (SgN  >aktsepteeritav !02_A	et	f	\N
203484	aktsepteeritav	"aktsepteeritav %aktsepteeri  )TAV_vAS  <aktsepteerima ;28_V	et	f	\N
203485	kumukartust	?kumukartust =kumukartus  (SgP  >kumukartus !11~09_S	et	f	\N
203488	mitmetahulisem	mitmetahulisem =tahulisem  (SgN  >mitme+tahulisem !02_A	et	f	\N
203489	mitmetahulisem	"mitme+tahulisem %tahu  )LISEM_cA  <mitme+tahk ;22_S	et	f	\N
203490	mitmetahulisem	"mitme+tahulisem %tahulise  )M_cA  <mitme+tahuline ;12_A	et	f	\N
203491	tundmise	tundmise =tundmise  (SgG  >tundmine !12?10_S	et	f	\N
203492	tundmise	"tundmine %tund  )MINE_vS  <tundma ;34_V	et	f	\N
203506	toimetuste	toimetuste =toimetus  (PlG  >toimetus !11_S	et	f	\N
203507	toimetuste	"toimetus %toimeta  )US_vS  <toimetama ;27_V	et	f	\N
203508	toimetuste	"toimetus %toime  )TUS2_aS  <toime ;06_S	et	f	\N
203509	toimetuste	"toimetus %toime  )TUS2_aS  <toim ;22_S	et	f	\N
203510	toimetuste	toimetuste =tuste  (PlP  >toime+tust !22_S	et	f	\N
203536	ratei	?ratei =ratei  (SgN  >ratei !26_S	et	f	\N
203537	ratei	?ratei =ratei  (SgG  >ratei !26_S	et	f	\N
203550	meenutusi	meenutusi =meenutusi  (PlP  >meenutus !11_S	et	f	\N
203551	meenutusi	"meenutus %meenuta  )US_vS  <meenutama ;27_V	et	f	\N
203552	meenutusi	"meenutus %meenu  )TUS1_aS  <meenuma ;27_V	et	f	\N
203561	blogis	?blogis =blogi  (SgIn  >blogi !17_S	et	f	\N
203562	blogis	?blogis =blogi  (IndIpfSg3  >blogima !27_V	et	f	\N
203563	blogis	?blogis =blogis  (SgN  >blogis !09_S	et	f	\N
203584	e-postiga	e-postiga =posti  (SgKom  >e-post !22_S	et	f	\N
203585	e-postiga	e-postiga =iga  (SgN  >e-post+iga !18_S	et	f	\N
203586	e-postiga	e-postiga =iga  (SgP  >e-post+iga !18_S	et	f	\N
203587	vajaminev	vajaminev =mine  (PtsPrPs  >vaja+_minema !36_V	et	f	\N
203298	eq-d	eq-d =eq  (SgP  >eq !xx_Q	et	f	\N
203299	eq-d	eq-d =eq  (PlN  >eq !xx_Q	et	f	\N
203315	avarduvad	avarduvad =avardu  (IndPrPl3  >avarduma !27_V	et	f	\N
203316	avarduvad	avarduvad =avarduva  (PlN  >avarduv !02_A	et	f	\N
203317	avarduvad	"avarduv %avardu  )V_vA  <avarduma ;27_V	et	f	\N
203318	piiritletavaks	piiritletavaks =piiritletava  (SgTr  >piiritletav !02_A	et	f	\N
203319	piiritletavaks	"piiritletav %piiritle  )TAV_vAS  <piiritlema ;27_V	et	f	\N
203326	peeglisse	peeglisse =peegli  (SgIll  >peegel !02_S	et	f	\N
203327	peeglisse	peeglisse =peeglis  (SgAdt  >peegline !12_A	et	f	\N
203328	peeglisse	"peegline %peegli  )NE_aA  <peegel ;02_S	et	f	\N
203348	riietumise	riietumise =riietumise  (SgG  >riietumine !12_S	et	f	\N
203349	riietumise	"riietumine %riietu  )MINE_vS  <riietuma ;27_V	et	f	\N
203350	võsukesed	võsukesed =võsukese  (PlN  >võsuke !12_S	et	f	\N
203351	võsukesed	"võsuke %võsu  )KE_dS  <võsu ;17_S	et	f	\N
203352	võsukesed	võsukesed =võsukese  (PlN  >võsukene !12_S	et	f	\N
203353	võsukesed	"võsukene %võsu  )KENE_dS  <võsu ;17_S	et	f	\N
203360	normaalsuse	normaalsuse =normaalsuse  (SgG  >normaalsus !11~09_S	et	f	\N
203361	normaalsuse	"normaalsus %normaalse  )US_aS  <normaalne ;02_A	et	f	\N
203368	põnevus	põnevus =põnevus  (SgN  >põnevus !11_S	et	f	\N
203369	põnevus	"põnevus %põneva  )US_aS  <põnev ;02_A	et	f	\N
203377	õelduks	?õelduks =õeldu  (SgTr  >õeldu !01_S	et	f	\N
203378	õelduks	?õelduks =õeldu  (KndPrPs  >õelduma !27_V	et	f	\N
203381	kastisüsteemi	kastisüsteemi =süsteemi  (SgG  >kasti+süsteem !22_S	et	f	\N
203382	kastisüsteemi	kastisüsteemi =süsteemi  (SgP  >kasti+süsteem !22_S	et	f	\N
203383	kastisüsteemi	kastisüsteemi =süsteemi  (SgAdt  >kasti+süsteem !22_S	et	f	\N
203412	hägustumist	hägustumist =hägustumis  (SgP  >hägustumine !12_S	et	f	\N
203413	hägustumist	"hägustumine %hägustu  )MINE_vS  <hägustuma ;27_V	et	f	\N
203433	altimad	altimad =altima  (PlN  >altim !02_A	et	f	\N
203434	altimad	"altim %alti  )M_cA  <aldis ;07_A	et	f	\N
203435	altimad	altimad =ima  (PlN  >alt+ima !17_S	et	f	\N
203458	valimata	valimata =vali  (SupAb  >valima !27_V	et	f	\N
203459	valimata	valimata =valimata  (ID  >valimata !41_A	et	f	\N
203460	valimata	"valimata %vali  )MATA_vA  <valima ;27_V	et	f	\N
203461	vastuvõtlikum	vastuvõtlikum =võtlikum  (SgN  >vastu+võtlikum !02_A	et	f	\N
203462	vastuvõtlikum	"vastu+võtlikum %võtliku  )M_cA  <vastu+võtlik ;25_A	et	f	\N
203469	jõuliselt	jõuliselt =jõulise  (SgAbl  >jõuline !12?10_A	et	f	\N
203470	jõuliselt	"jõuline %jõu  )LINE_aA  <jõud ;22_S	et	f	\N
203471	jõuliselt	"jõuline %jõuli  )NE_aA  <jõul ;22_S	et	f	\N
203472	jõuliselt	jõuliselt =jõuliselt  (ID  >jõuliselt !41_D	et	f	\N
203473	jõuliselt	"jõuliselt %jõu  )LISELT_mD  <jõud ;22_S	et	f	\N
203474	jõuliselt	"jõuliselt %jõuli  )SELT_mD  <jõul ;22_S	et	f	\N
203475	jõuliselt	"jõuliselt %jõulise  )LT_mD  <jõuline ;10_A	et	f	\N
203476	jõuliselt	"jõuliselt %jõulise  )LT_mD  <jõuline ;12_A	et	f	\N
203486	kasvataks	kasvataks =kasva  (KndPrIps  >kasvama !28_V	et	f	\N
203487	kasvataks	kasvataks =kasvata  (KndPrPs  >kasvatama !27_V	et	f	\N
203493	jaotusid	jaotusid =jaotu  (IndIpfSg2  >jaotuma !27_V	et	f	\N
203494	jaotusid	jaotusid =jaotu  (IndIpfPl3  >jaotuma !27_V	et	f	\N
203499	kohalduma	?kohalduma =kohaldu  (Sup  >kohalduma !27_V	et	f	\N
203500	kohalduma	?kohalduma =kohalduma  (SgG  >kohaldum !02_A	et	f	\N
203501	kohalduma	?kohalduma =duma  (SgN  >kohal+duma !17_S	et	f	\N
203502	kohalduma	?kohalduma =duma  (SgG  >kohal+duma !17_S	et	f	\N
203503	kohalduma	?kohalduma =duma  (SgP  >kohal+duma !17_S	et	f	\N
203530	blogist	?blogist =blogi  (SgEl  >blogi !17_S	et	f	\N
203531	blogist	?blogist =blogis  (SgP  >blogis !09_S	et	f	\N
203532	blogist	?blogist =blogist  (SgN  >blogist !22_S	et	f	\N
203540	msni	### msni	et	f	\N
203556	intentiteetidega	?intentiteetidega =intentiteeti  (PlKom  >intentiteeti !16_S	et	f	\N
203557	intentiteetidega	?intentiteetidega =intentiteeti  (PlKom  >intentiteet !22_S	et	f	\N
203574	lemmiklaulu	lemmiklaulu =laulu  (SgG  >lemmik+laul !22_S	et	f	\N
203575	lemmiklaulu	lemmiklaulu =laulu  (SgP  >lemmik+laul !22_S	et	f	\N
203576	lemmiklaulu	lemmiklaulu =laulu  (SgAdt  >lemmik+laul !22_S	et	f	\N
203598	scrappi	?scrappi =scrappi  (ID  >scrappi !41_D	et	f	\N
203599	scrappi	?scrappi =scrappi  (SgP  >scrapp !22_S	et	f	\N
203600	scrappi	?scrappi =scrappi  (SgAdt  >scrapp !22_S	et	f	\N
203619	mailinglistid	?mailinglistid =mailinglisti  (PlN  >mailinglist !22_S	et	f	\N
203620	mailinglistid	?mailinglistid =mailinglisti  (IndPrSg2  >mailinglistima !28_V	et	f	\N
203621	mailinglistid	?mailinglistid =linglisti  (PlN  >mai+linglisti !01_S	et	f	\N
203622	mailinglistid	?mailinglistid =linglisti  (PlN  >mai+linglist !22_S	et	f	\N
203623	põhiinfo	põhiinfo =info  (SgN  >põhi+info !16_S	et	f	\N
203624	põhiinfo	põhiinfo =info  (SgG  >põhi+info !16_S	et	f	\N
203625	kodulehtedel	kodulehtedel =ede  (SgAd  >kodu+leht+ede !16_S	et	f	\N
203626	kodulehtedel	kodulehtedel =edel  (SgN  >kodu+leht+edel !02_S	et	f	\N
203627	kodulehtedel	kodulehtedel =lehte  (PlAd  >kodu+leht !22_S	et	f	\N
203630	kasutajaks	kasutajaks =kasutaja  (SgTr  >kasutaja !01_S	et	f	\N
203632	kasutajaks	"kasutaja %kasuta  )JA_vS  <kasutama ;27_V	et	f	\N
203363	strateegiline	"strateegiline %strateegi  )LINE_aA  <strateeg ;22_S	et	f	\N
203366	juuatäis	?juuatäis =juuatäi  (SgIn  >juuatäi !26_S	et	f	\N
203367	juuatäis	?juuatäis =juuatäis  (SgN  >juuatäis !22_S	et	f	\N
203373	noridel	?noridel =nori  (PlAd  >nori !17_S	et	f	\N
203374	sõnadekombinatsiooni	sõnadekombinatsiooni =kombinatsiooni  (SgG  >sõnade+kombinatsioon !22_S	et	f	\N
203375	sõnadekombinatsiooni	sõnadekombinatsiooni =kombinatsiooni  (SgP  >sõnade+kombinatsioon !22_S	et	f	\N
203376	sõnadekombinatsiooni	sõnadekombinatsiooni =kombinatsiooni  (SgAdt  >sõnade+kombinatsioon !22_S	et	f	\N
203405	aastasadu	aastasadu =sadu  (SgN  >aasta+sadu !18_S	et	f	\N
203406	aastasadu	aastasadu =sadu  (SgP  >aasta+sadu !18_S	et	f	\N
203417	arvamisele	arvamisele =arvamise  (SgAll  >arvamine !12_S	et	f	\N
203418	arvamisele	"arvamine %arva  )MINE_vS  <arvama ;29_V	et	f	\N
203429	juletud	juletud =jule  (PtsPtIps  >julgema !27_V	et	f	\N
203430	juletud	juletud =juletu  (PlN  >juletu !01_S	et	f	\N
203431	juletud	"juletu %jule  )TU1_vS  <julgema ;27_V	et	f	\N
203432	juletud	"juletud %jule  )TUD_vA  <julgema ;27_V	et	f	\N
203443	tulevate	tulevate =tuleva  (PlG  >tulev !02_A	et	f	\N
203444	tulevate	"tulev %tule  )V_vA  <tulema ;36_V	et	f	\N
203451	kohanemisvõimelisemad	kohanemisvõimelisemad =võimelisema  (PlN  >kohanemis+võimelisem !02_A	et	f	\N
203452	kohanemisvõimelisemad	"kohanemis+võimelisem %võime  )LISEM_cA  <kohanemis+võime ;06_S	et	f	\N
203453	kohanemisvõimelisemad	"kohanemis+võimelisem %võimelise  )M_cA  <kohanemis+võimeline ;12_A	et	f	\N
203511	tervitatav	tervitatav =tervita  (PtsPrIps  >tervitama !27_V	et	f	\N
203512	tervitatav	tervitatav =tervitatav  (SgN  >tervitatav !02_A	et	f	\N
203513	tervitatav	"tervitatav %tervita  )TAV_vAS  <tervitama ;27_V	et	f	\N
203528	rollijaotuseni	rollijaotuseni =jaotuse  (SgTer  >rolli+jaotus !11~09_S	et	f	\N
203529	rollijaotuseni	"rolli+jaotus %jao  )TUS2_aS  <rolli+jagu ;18_S	et	f	\N
203538	orkutit	?orkutit =orkuti  (SgP  >orkuti !01_S	et	f	\N
203539	orkutit	?orkutit =orkuti  (SgP  >orkut !02_S	et	f	\N
203541	foorume	?foorume =fooru  (IndPrPl1  >fooruma !27_V	et	f	\N
203545	blogi	?blogi =blogi  (SgN  >blogi !17_S	et	f	\N
203546	blogi	?blogi =blogi  (SgG  >blogi !17_S	et	f	\N
203547	blogi	?blogi =blogi  (SgP  >blogi !17_S	et	f	\N
203548	blogi	?blogi =blogi  (IndPrPs_  >blogima !27_V	et	f	\N
203549	blogi	?blogi =blogi  (ImpPrSg2  >blogima !27_V	et	f	\N
203564	tegemistest	tegemistest =tegemis  (PlEl  >tegemine !12_S	et	f	\N
203565	tegemistest	"tegemine %tege  )MINE_vS  <tegema ;28_V	et	f	\N
203566	tegemistest	tegemistest =test  (SgN  >tegemis+test !22_S	et	f	\N
203568	hetkemeeleolu	hetkemeeleolu =olu  (SgN  >hetke+meele+olu !17_S	et	f	\N
203569	hetkemeeleolu	hetkemeeleolu =olu  (SgG  >hetke+meele+olu !17_S	et	f	\N
203570	hetkemeeleolu	hetkemeeleolu =olu  (SgP  >hetke+meele+olu !17_S	et	f	\N
203615	luulekonkurssi	luulekonkurssi =konkurssi  (SgP  >luule+konkurss !22_S	et	f	\N
203616	luulekonkurssi	luulekonkurssi =konkurssi  (SgAdt  >luule+konkurss !22_S	et	f	\N
203628	registreerinud	registreerinud =registreeri  (PtsPtPs  >registreerima !28_V	et	f	\N
203629	registreerinud	registreerinud =registreerinu  (PlN  >registreerinu !01_S	et	f	\N
203631	registreerinud	"registreerinu %registreeri  )NU_vS  <registreerima ;28_V	et	f	\N
203633	registreerinud	registreerinud =registreerinud  (ID  >registreerinud !41_A	et	f	\N
203634	registreerinud	"registreerinud %registreeri  )NUD_vA  <registreerima ;28_V	et	f	\N
203639	esindamata	esindamata =esinda  (SupAb  >esindama !27_V	et	f	\N
203640	esindamata	esindamata =esindamata  (ID  >esindamata !41_A	et	f	\N
203641	esindamata	"esindamata %esinda  )MATA_vA  <esindama ;27_V	et	f	\N
203649	luues	luues =luu  (Ger  >looma !38_V	et	f	\N
203650	luues	luues =luues  (SgN  >luues !09_S	et	f	\N
203657	nikei	?nikei =nikei  (SgN  >nikei !26_S	et	f	\N
203658	nikei	?nikei =nikei  (SgG  >nikei !26_S	et	f	\N
203680	kindlamalt	kindlamalt =kindlama  (SgAbl  >kindlam !02_A	et	f	\N
203681	kindlamalt	"kindlam %kindla  )M_cA  <kindel ;02_A	et	f	\N
203682	kindlamalt	kindlamalt =kindlamalt  (ID  >kindlamalt !41_D	et	f	\N
203683	kindlamalt	"kindlamalt %kindla  )MALT_mD  <kindel ;02_A	et	f	\N
203686	hägusamaks	?hägusamaks =hägusama  (SgTr  >hägusam !02_A	et	f	\N
203715	suhtumisega	suhtumisega =suhtumise  (SgKom  >suhtumine !12_S	et	f	\N
203716	suhtumisega	"suhtumine %suhtu  )MINE_vS  <suhtuma ;27_V	et	f	\N
203722	elatamiseks	elatamiseks =elatamise  (SgTr  >elatamine !12_S	et	f	\N
203723	elatamiseks	"elatamine %elata  )MINE_vS  <elatama ;27_V	et	f	\N
203730	soodustanud	soodustanud =soodusta  (PtsPtPs  >soodustama !27_V	et	f	\N
203731	soodustanud	soodustanud =soodustanu  (PlN  >soodustanu !01_S	et	f	\N
203732	soodustanud	"soodustanu %soodusta  )NU_vS  <soodustama ;27_V	et	f	\N
203733	soodustanud	soodustanud =soodustanud  (ID  >soodustanud !41_A	et	f	\N
203734	soodustanud	"soodustanud %soodusta  )NUD_vA  <soodustama ;27_V	et	f	\N
203735	soodustanud	soodustanud =tanu  (PlN  >soodus+tanu !17_S	et	f	\N
203758	töötajana	töötajana =töötaja  (SgEs  >töötaja !01_S	et	f	\N
203759	töötajana	"töötaja %tööta  )JA_vS  <töötama ;27_V	et	f	\N
203760	soovigi	soovigi =soovi  (SgG^  >soov !22_S	et	f	\N
203761	soovigi	soovigi =soovi  (SgP^  >soov !22_S	et	f	\N
203762	soovigi	soovigi =soovi  (SgAdt^  >soov !22_S	et	f	\N
203465	hämaruses	hämaruses =hämaruse  (SgIn  >hämarus !11_S	et	f	\N
203466	hämaruses	"hämarus %hämara  )US_aS  <hämar ;02_AS	et	f	\N
203467	hämaruses	hämaruses =use  (PlIn  >hämar+usk !22_S	et	f	\N
203468	hämaruses	hämaruses =ruse  (PlIn  >häma+rusk !22_S	et	f	\N
203514	rõõmustav	rõõmustav =rõõmusta  (PtsPrPs  >rõõmustama !27_V	et	f	\N
203515	rõõmustav	rõõmustav =rõõmustav  (SgN  >rõõmustav !02_A	et	f	\N
203516	rõõmustav	"rõõmustav %rõõmusta  )V_vA  <rõõmustama ;27_V	et	f	\N
203533	internetimaailma	internetimaailma =ilma  (SgG  >interneti+maa+ilm !22_S	et	f	\N
203534	internetimaailma	internetimaailma =ilma  (SgP  >interneti+maa+ilm !22_S	et	f	\N
203535	internetimaailma	internetimaailma =ilma  (SgAdt  >interneti+maa+ilm !22_S	et	f	\N
203553	olulisema	olulisema =olulisema  (SgG  >olulisem !02_A	et	f	\N
203554	olulisema	"olulisem %olu  )LISEM_cA  <olu ;17_S	et	f	\N
203555	olulisema	"olulisem %olulise  )M_cA  <oluline ;12_A	et	f	\N
203567	msnis	### msnis	et	f	\N
203577	orkuti	?orkuti =orku  (IndIpfIps  >orkuma !27_V	et	f	\N
203578	orkuti	?orkuti =orkuti  (SgN  >orkuti !01_S	et	f	\N
203579	orkuti	?orkuti =orkuti  (SgG  >orkuti !01_S	et	f	\N
203580	orkuti	?orkuti =orkuti  (SgG  >orkut !02_S	et	f	\N
203581	orkuti	?orkuti =orkuti  (SgG  >orkutt !22_S	et	f	\N
203582	orkuti	?orkuti =orkuti  (IndPrPs_  >orkuttima !28_V	et	f	\N
203583	orkuti	?orkuti =orkuti  (ImpPrSg2  >orkuttima !28_V	et	f	\N
203603	kasvatusel	kasvatusel =kasvatuse  (SgAd  >kasvatus !11_S	et	f	\N
203605	kasvatusel	"kasvatus %kasvata  )US_vS  <kasvatama ;27_V	et	f	\N
203606	kasvatusel	"kasvatus %kasva  )TUS1_aS  <kasvama ;28_V	et	f	\N
203612	telefonitoru	telefonitoru =toru  (SgN  >telefoni+toru !17_S	et	f	\N
203613	telefonitoru	telefonitoru =toru  (SgG  >telefoni+toru !17_S	et	f	\N
203614	telefonitoru	telefonitoru =toru  (SgP  >telefoni+toru !17_S	et	f	\N
203647	omavahelisel	omavahelisel =vahelise  (SgAd  >oma+vaheline !12_A	et	f	\N
203648	omavahelisel	"oma+vaheline %vahe  )LINE_aA  <oma+vahe ;16_S	et	f	\N
203651	vastavates	vastavates =vastava  (PlIn  >vastav !02_A	et	f	\N
203652	vastavates	"vastav %vasta  )V_vA  <vastama ;29_V	et	f	\N
203666	kasvatuseni	kasvatuseni =kasvatuse  (SgTer  >kasvatus !11_S	et	f	\N
203667	kasvatuseni	"kasvatus %kasvata  )US_vS  <kasvatama ;27_V	et	f	\N
203668	kasvatuseni	"kasvatus %kasva  )TUS1_aS  <kasvama ;28_V	et	f	\N
203677	mõtekam	?mõtekam =mõtekam  (SgN  >mõtekam !02_A	et	f	\N
203684	ühtedele	ühtedele =ühte  (PlAll  >üks !22_NP	et	f	\N
203685	ühtedele	ühtedele =ede  (SgAll  >üht+ede !16_S	et	f	\N
203696	suundumust	suundumust =suundumus  (SgP  >suundumus !11_S	et	f	\N
203697	suundumust	"suundumus %suundu  )MUS_vS  <suunduma ;27_V	et	f	\N
203698	julgus	julgus =julgu  (IndIpfSg3  >julguma !27_V	et	f	\N
203699	julgus	julgus =julgus  (SgN  >julgus !11~09_S	et	f	\N
203700	julgus	"julgus %julge  )US_aS  <julge ;01_A	et	f	\N
203707	tunnistamine	tunnistamine =tunnistamine  (SgN  >tunnistamine !12_S	et	f	\N
203709	tunnistamine	"tunnistamine %tunnista  )MINE_vS  <tunnistama ;27_V	et	f	\N
203727	olulisemkas	?olulisemkas =olulisemka  (SgIn  >olulisemka !16_S	et	f	\N
203738	teadmisele	teadmisele =teadmise  (SgAll  >teadmine !12?10_S	et	f	\N
203739	teadmisele	"teadmine %tead  )MINE_vS  <teadma ;34_V	et	f	\N
203745	domineerivaks	domineerivaks =domineeriva  (SgTr  >domineeriv !02_A	et	f	\N
203746	domineerivaks	"domineeriv %domineeri  )V_vA  <domineerima ;28_V	et	f	\N
203749	kaitsmisel	kaitsmisel =kaitsmise  (SgAd  >kaitsmine !12?10_S	et	f	\N
203750	kaitsmisel	"kaitsmine %kaits  )MINE_vS  <kaitsma ;32_V	et	f	\N
203755	tegelemiseks	tegelemiseks =tegelemise  (SgTr  >tegelemine !12_S	et	f	\N
203756	tegelemiseks	"tegelemine %tegele  )MINE_vS  <tegelema ;27_V	et	f	\N
203757	tegelemiseks	"tegelemine %tegele  )MINE_vS  <tegelema ;31_V	et	f	\N
203782	võrreldatav	?võrreldatav =võrrelda  (PtsPrIps  >võrreldama !27_V	et	f	\N
203783	võrreldatav	?võrreldatav =võrreldata  (PtsPrPs  >võrreldatama !27_V	et	f	\N
203784	võrreldatav	?võrreldatav =võrreldatav  (SgN  >võrreldatav !02_A	et	f	\N
203785	muutuvale	muutuvale =muutuva  (SgAll  >muutuv !02_A	et	f	\N
203786	muutuvale	"muutuv %muutu  )V_vA  <muutuma ;27_V	et	f	\N
203787	muutuvale	muutuvale =vale  (SgN  >muutu+vale !16_SA	et	f	\N
203788	muutuvale	muutuvale =vale  (SgG  >muutu+vale !16_SA	et	f	\N
203809	traditsioonilistele	traditsioonilistele =traditsioonilis  (PlAll  >traditsiooniline !12_A	et	f	\N
203810	traditsioonilistele	"traditsiooniline %traditsiooni  )LINE_aA  <traditsioon ;22_S	et	f	\N
203813	avalduvad	avalduvad =avaldu  (IndPrPl3  >avalduma !27_V	et	f	\N
203814	avalduvad	avalduvad =avalduva  (PlN  >avalduv !02_A	et	f	\N
203815	avalduvad	"avalduv %avaldu  )V_vA  <avalduma ;27_V	et	f	\N
203818	tõusevad	tõusevad =tõuse  (IndPrPl3  >tõusma !32_V	et	f	\N
203819	tõusevad	tõusevad =tõuseva  (PlN  >tõusev !02_A	et	f	\N
203820	tõusevad	"tõusev %tõus  )V_vA  <tõusma ;32_V	et	f	\N
203821	märkamatuks	märkamatuks =märkamatu  (SgTr  >märkamatu !01_A	et	f	\N
203822	märkamatuks	"märkamatu %märka  )MATU_vA  <märkama ;29_V	et	f	\N
203847	ühiskonnad	ühiskonnad =ühiskonna  (PlN  >ühiskond !22_S	et	f	\N
203848	ühiskonnad	ühiskonnad =konna  (PlN  >ühis+konn !22_S	et	f	\N
203853	verstapostiks	verstapostiks =iks  (SgN  >versta+post+iks !22_S	et	f	\N
203526	väärtuslikumana	väärtuslikumana =väärtuslikuma  (SgEs  >väärtuslikum !02_A	et	f	\N
203527	väärtuslikumana	"väärtuslikum %väärtusliku  )M_cA  <väärtuslik ;25_A	et	f	\N
203542	blogisid	?blogisid =blogi  (PlP  >blogi !17_S	et	f	\N
203543	blogisid	?blogisid =blogi  (IndIpfSg2  >blogima !27_V	et	f	\N
203544	blogisid	?blogisid =blogi  (IndIpfPl3  >blogima !27_V	et	f	\N
203558	persoonivahelist	?persoonivahelist =persoonivahelis  (SgP  >persoonivahelis !09_S	et	f	\N
203559	persoonivahelist	?persoonivahelist =persoonivahelis  (SgP  >persoonivaheline !12_A	et	f	\N
203560	persoonivahelist	?persoonivahelist =persoonivahelist  (SgN  >persoonivahelist !22_S	et	f	\N
203571	poseeringu	?poseeringu =poseeringu  (SgG  >poseering !02_S	et	f	\N
203572	poseeringu	?poseeringu =poseeringu  (IndPrPs_  >poseeringuma !27_V	et	f	\N
203573	poseeringu	?poseeringu =poseeringu  (ImpPrSg2  >poseeringuma !27_V	et	f	\N
203589	kasutajanime	kasutajanime =nime  (SgG  >kasutaja+nimi !20_S	et	f	\N
203590	kasutajanime	kasutajanime =nime  (SgP  >kasutaja+nimi !20_S	et	f	\N
203607	e-kirja	e-kirja =kirja  (SgG  >e-kiri !24_S	et	f	\N
203608	e-kirja	e-kirja =kirja  (SgP  >e-kiri !24_S	et	f	\N
203609	e-kirja	e-kirja =kirja  (SgAdt  >e-kiri !24_S	et	f	\N
203610	e-kirja	e-kirja =kirja  (IndPrPs_  >e-kirjama !29_V	et	f	\N
203611	e-kirja	e-kirja =kirja  (ImpPrSg2  >e-kirjama !29_V	et	f	\N
203617	teavitamiskanaleid	?teavitamiskanaleid =teavitamiskanalei  (PlN  >teavitamiskanalei !26_S	et	f	\N
203618	teavitamiskanaleid	?teavitamiskanaleid =teavitamiskanalei  (SgP  >teavitamiskanalei !26_S	et	f	\N
203642	kommunikeeruvad	?kommunikeeruvad =kommunikeeru  (IndPrPl3  >kommunikeeruma !27_V	et	f	\N
203643	kommunikeeruvad	?kommunikeeruvad =kommunikeeruva  (PlN  >kommunikeeruv !02_A	et	f	\N
203644	kommunikeeruvad	?kommunikeeruvad =kommunikeeruva  (PlN  >kommunikeeruva !16_S	et	f	\N
203645	kommunikeeruvad	?kommunikeeruvad =munikeeruva  (PlN  >kom+munikeeruv !02_A	et	f	\N
203646	kommunikeeruvad	?kommunikeeruvad =munikeeruva  (PlN  >kom+munikeeruva !16_S	et	f	\N
203655	virtuaalmaailmas	?virtuaalmaailmas =virtuaalmaailma  (SgIn  >virtuaalmaailma !16_S	et	f	\N
203664	rasvavolti	rasvavolti =volti  (SgP  >rasva+volt !22_S	et	f	\N
203665	rasvavolti	rasvavolti =volti  (SgAdt  >rasva+volt !22_S	et	f	\N
203672	blog	### blog	et	f	\N
203675	õnnestumisest	õnnestumisest =õnnestumise  (SgEl  >õnnestumine !12_S	et	f	\N
203676	õnnestumisest	"õnnestumine %õnnestu  )MINE_vS  <õnnestuma ;27_V	et	f	\N
203701	eelistusi	eelistusi =eelistusi  (PlP  >eelistus !11_S	et	f	\N
203702	eelistusi	"eelistus %eelista  )US_vS  <eelistama ;27_V	et	f	\N
203713	halvustava	halvustava =halvustava  (SgG  >halvustav !02_A	et	f	\N
203714	halvustava	"halvustav %halvusta  )V_vA  <halvustama ;27_V	et	f	\N
203717	tavalisem	tavalisem =tavalisem  (SgN  >tavalisem !02_A	et	f	\N
203718	tavalisem	"tavalisem %tava  )LISEM_cA  <tava ;17_S	et	f	\N
203719	tavalisem	"tavalisem %tavalise  )M_cA  <tavaline ;12_A	et	f	\N
203720	ületunde	ületunde =tunde  (SgG  >üle+tunne !06_S	et	f	\N
203721	ületunde	ületunde =tunde  (PlP  >üle+tund !22_S	et	f	\N
203742	palgatõusu	palgatõusu =tõusu  (SgG  >palga+tõus !22_S	et	f	\N
203743	palgatõusu	palgatõusu =tõusu  (SgP  >palga+tõus !22_S	et	f	\N
203744	palgatõusu	palgatõusu =tõusu  (SgAdt  >palga+tõus !22_S	et	f	\N
203747	valikute	valikute =valiku  (PlG  >valik !02_S	et	f	\N
203748	valikute	valikute =ute  (SgG  >valik+utt !22_S	et	f	\N
203791	ühiskondlikult	ühiskondlikult =ühiskondliku  (SgAbl  >ühiskondlik !25_A	et	f	\N
203792	ühiskondlikult	ühiskondlikult =ühiskondlikult  (ID  >ühiskondlikult !41_D	et	f	\N
203793	ühiskondlikult	"ühiskondlikult %ühiskondliku  )LT_mD  <ühiskondlik ;25_A	et	f	\N
203805	survestavad	?survestavad =survesta  (IndPrPl3  >survestama !27_V	et	f	\N
203806	survestavad	?survestavad =survestava  (PlN  >survestav !02_A	et	f	\N
203807	survestavad	?survestavad =survestava  (PlN  >survestava !16_S	et	f	\N
203808	survestavad	?survestavad =stava  (PlN  >surve+stava !17_S	et	f	\N
203811	elustandardid	elustandardid =standardi  (PlN  >elu+standard !02_S	et	f	\N
203812	elustandardid	elustandardid =standardi  (PlN  >elu+standart !22_S	et	f	\N
203824	sotsiaalsete	sotsiaalsete =sotsiaalse  (PlG  >sotsiaalne !02_A	et	f	\N
203826	sotsiaalsete	sotsiaalsete =sete  (SgN  >sotsiaal+sete !06_S	et	f	\N
203829	era-	era- =era  (SgN  >era !17_S	et	f	\N
203830	era-	era- =era  (SgG  >era !17_S	et	f	\N
203831	era-	era- =era  (SgP  >era !17_S	et	f	\N
203857	seksuaalrevolutsiooni	seksuaalrevolutsiooni =revolutsiooni  (SgG  >seksuaal+revolutsioon !22_S	et	f	\N
203858	seksuaalrevolutsiooni	seksuaalrevolutsiooni =revolutsiooni  (SgP  >seksuaal+revolutsioon !22_S	et	f	\N
203859	seksuaalrevolutsiooni	seksuaalrevolutsiooni =revolutsiooni  (SgAdt  >seksuaal+revolutsioon !22_S	et	f	\N
203870	kirjutavas	kirjutavas =kirjutava  (SgIn  >kirjutav !02_A	et	f	\N
203872	kirjutavas	"kirjutav %kirjuta  )V_vA  <kirjutama ;27_V	et	f	\N
203891	tööalaselt	tööalaselt =alase  (SgAbl  >töö+alane !10_AS	et	f	\N
203892	tööalaselt	"töö+alane %ala  )NE_aA  <töö+ala ;17_S	et	f	\N
203893	tööalaselt	"töö+alaselt %ala  )SELT_mD  <töö+ala ;17_S	et	f	\N
203894	tööalaselt	"töö+alaselt %alase  )LT_mD  <töö+alane ;10_AS	et	f	\N
203897	ülalkirjutatust	ülalkirjutatust =kirjutatu  (SgEl  >ülal+kirjutatu !01_S	et	f	\N
203898	ülalkirjutatust	ülalkirjutatust =kirjutatus  (SgP  >ülal+kirjutatus !11?09_S	et	f	\N
203588	vajaminev	vajaminev =minev  (SgN  >vaja+minev !02_A	et	f	\N
203591	suhtlevadki	suhtlevadki =suhtle  (IndPrPl3^  >suhtlema !30_V	et	f	\N
203592	suhtlevadki	suhtlevadki =suhtleva  (PlN^  >suhtlev !02_A	et	f	\N
203593	suhtlevadki	"suhtlev %suhtle  )V_vA^  <suhtlema ;30_V	et	f	\N
203594	orkutis	?orkutis =orkuti  (SgIn  >orkuti !01_S	et	f	\N
203595	orkutis	?orkutis =orkuti  (SgIn  >orkut !02_S	et	f	\N
203596	orkutis	?orkutis =orkuti  (SgIn  >orkutt !22_S	et	f	\N
203597	orkutis	?orkutis =orkutis  (SgN  >orkutis !11_S	et	f	\N
203601	lapsevanematel	lapsevanematel =ate  (PlAd  >lapse+vanem+att !22_S	et	f	\N
203602	lapsevanematel	lapsevanematel =vanema  (PlAd  >lapse+vanem !02_AS	et	f	\N
203604	lapsevanematel	"lapse+vanem %vane  )M_cA  <lapse+vana ;17_AS	et	f	\N
203635	rateee	?rateee =rateee  (SgN  >rateee !26_S	et	f	\N
203636	rateee	?rateee =rateee  (SgG  >rateee !26_S	et	f	\N
203637	huvigruppi	huvigruppi =gruppi  (SgP  >huvi+grupp !22_S	et	f	\N
203638	huvigruppi	huvigruppi =gruppi  (SgAdt  >huvi+grupp !22_S	et	f	\N
203659	pusa	pusa =pusa  (SgN  >pusa !17_S	et	f	\N
203660	pusa	pusa =pusa  (SgG  >pusa !17_S	et	f	\N
203661	pusa	pusa =pusa  (SgP  >pusa !17_S	et	f	\N
203669	salga	salga =salga  (SgG  >salk !22_S	et	f	\N
203670	salga	salga =salga  (IndPrPs_  >salgama !29_V	et	f	\N
203671	salga	salga =salga  (ImpPrSg2  >salgama !29_V	et	f	\N
203673	konto	konto =konto  (SgN  >konto !16_S	et	f	\N
203674	konto	konto =konto  (SgG  >konto !16_S	et	f	\N
203687	roosasid	roosasid =roosa  (PlP  >roosa !16_AS	et	f	\N
203688	roosasid	roosasid =sasi  (PlN  >roo+sasi !17_S	et	f	\N
203691	söandanud	söandanud =söanda  (PtsPtPs  >söandama !27_V	et	f	\N
203692	söandanud	söandanud =söandanu  (PlN  >söandanu !01_S	et	f	\N
203693	söandanud	"söandanu %söanda  )NU_vS  <söandama ;27_V	et	f	\N
203694	söandanud	söandanud =söandanud  (ID  >söandanud !41_A	et	f	\N
203695	söandanud	"söandanud %söanda  )NUD_vA  <söandama ;27_V	et	f	\N
203706	homoseksuaalsuse	?homoseksuaalsuse =homoseksuaalsuse  (SgG  >homoseksuaalsus !11~09_S	et	f	\N
203708	homoseksuaalsuse	?homoseksuaalsuse =suse  (SgN  >homo+seksuaal+suse !16_S	et	f	\N
203710	homoseksuaalsuse	?homoseksuaalsuse =suse  (SgG  >homo+seksuaal+suse !16_S	et	f	\N
203728	peresiseselt	peresiseselt =sisese  (SgAbl  >pere+sisene !10_A	et	f	\N
203729	peresiseselt	"pere+siseselt %sisese  )LT_mD  <pere+sisene ;10_A	et	f	\N
203751	tagasihoidlikumad	tagasihoidlikumad =hoidlikuma  (PlN  >tagasi+hoidlikum !02_A	et	f	\N
203752	tagasihoidlikumad	"tagasi+hoidlikum %hoidliku  )M_cA  <tagasi+hoidlik ;25_A	et	f	\N
203771	väljendamisel	väljendamisel =väljendamise  (SgAd  >väljendamine !12_S	et	f	\N
203772	väljendamisel	"väljendamine %väljenda  )MINE_vS  <väljendama ;27_V	et	f	\N
203803	saavutatut	saavutatut =saavutatu  (SgP  >saavutatu !01_S	et	f	\N
203804	saavutatut	"saavutatu %saavuta  )TU1_vS  <saavutama ;27_V	et	f	\N
203816	muutumisele	muutumisele =muutumise  (SgAll  >muutumine !12_S	et	f	\N
203817	muutumisele	"muutumine %muutu  )MINE_vS  <muutuma ;27_V	et	f	\N
203827	olulisust	olulisust =olulisus  (SgP  >olulisus !11?09_S	et	f	\N
203828	olulisust	"olulisus %olu  )LISUS_aS  <olu ;17_S	et	f	\N
203843	sugupoolt	?sugupoolt =sugupoo  (SgAbl  >sugupoo !26_S	et	f	\N
203844	sugupoolt	?sugupoolt =poo  (SgAbl  >sugu+poo !26_S	et	f	\N
203845	pädevus	pädevus =pädevus  (SgN  >pädevus !11_S	et	f	\N
203846	pädevus	"pädevus %pädeva  )US_aS  <pädev ;02_A	et	f	\N
203855	hääleõiguse	hääleõiguse =õiguse  (SgG  >hääle+õigus !11~09_S	et	f	\N
203856	hääleõiguse	"hääle+õigus %õige  )US_aS  <hääle+õige ;01_A	et	f	\N
203860	järk-järgulisele	järk-järgulisele =järgulise  (SgAll  >järk-järguline !12_A	et	f	\N
203863	järk-järgulisele	"järk-järguline %järgu  )LINE_aA  <järk-järk ;22_S	et	f	\N
203869	võrd-	?võrd- =võrd  (SgN  >võrd !22_S	et	f	\N
203895	majapidamistöödes	majapidamistöödes =öö  (PlIn  >maja+pidamist+öö !26_S	et	f	\N
203896	majapidamistöödes	majapidamistöödes =töö  (PlIn  >maja+pidamis+töö !26_S	et	f	\N
203901	täheldatavad	täheldatavad =täheldatava  (PlN  >täheldatav !02_A	et	f	\N
203902	täheldatavad	"täheldatav %tähelda  )TAV_vAS  <täheldama ;27_V	et	f	\N
203905	ennekuulmatu	ennekuulmatu =kuulmatu  (SgN  >enne+kuulmatu !01_A	et	f	\N
203906	ennekuulmatu	ennekuulmatu =kuulmatu  (SgG  >enne+kuulmatu !01_A	et	f	\N
203931	uuendusi	uuendusi =uuendusi  (PlP  >uuendus !11_S	et	f	\N
203932	uuendusi	"uuendus %uuenda  )US_vS  <uuendama ;27_V	et	f	\N
203943	mõningast	mõningast =mõninga  (SgEl  >mõningas !02_P	et	f	\N
203944	mõningast	mõningast =mõningas  (SgP  >mõningane !12_P	et	f	\N
203948	nõrkust	nõrkust =nõrkus  (SgP  >nõrkus !11~09_S	et	f	\N
203949	nõrkust	"nõrkus %nõrk  )US_aS  <nõrk ;22_A	et	f	\N
203963	hääbumist	hääbumist =hääbumis  (SgP  >hääbumine !12_S	et	f	\N
203964	hääbumist	"hääbumine %hääbu  )MINE_vS  <hääbuma ;27_V	et	f	\N
203978	globaliseerumisest	?globaliseerumisest =globaliseerumise  (SgEl  >globaliseerumine !12_S	et	f	\N
203991	piiritute	piiritute =piiritu  (PlG  >piiritu !01_A	et	f	\N
203992	piiritute	"piiritu %piiri  )TU2_kA  <piir ;22_S	et	f	\N
203993	bakalaureusetöö	?bakalaureusetöö =bakalaureusetöö  (SgN  >bakalaureusetöö !26_S	et	f	\N
203994	bakalaureusetöö	?bakalaureusetöö =bakalaureusetöö  (SgG  >bakalaureusetöö !26_S	et	f	\N
203653	harjuvad	harjuvad =harju  (IndPrPl3  >harjuma !27_V	et	f	\N
203654	harjuvad	harjuvad =harjuva  (PlN  >harjuv !02_A	et	f	\N
203656	harjuvad	"harjuv %harju  )V_vA  <harjuma ;27_V	et	f	\N
203662	photoshopis	?photoshopis =photoshopi  (SgIn  >photoshopp !22_S	et	f	\N
203663	photoshopis	?photoshopis =photoshopis  (SgN  >photoshopis !09_S	et	f	\N
203678	hääbu	hääbu =hääbu  (IndPrPs_  >hääbuma !27_V	et	f	\N
203679	hääbu	hääbu =hääbu  (ImpPrSg2  >hääbuma !27_V	et	f	\N
203689	pluusesid	?pluusesid =pluuse  (IndIpfSg2  >pluusema !28_V	et	f	\N
203690	pluusesid	?pluusesid =pluuse  (IndIpfPl3  >pluusema !28_V	et	f	\N
203703	orientatsiooni	orientatsiooni =orientatsiooni  (SgG  >orientatsioon !22_S	et	f	\N
203704	orientatsiooni	orientatsiooni =orientatsiooni  (SgP  >orientatsioon !22_S	et	f	\N
203705	orientatsiooni	orientatsiooni =orientatsiooni  (SgAdt  >orientatsioon !22_S	et	f	\N
203711	kaotamisega	kaotamisega =kaotamise  (SgKom  >kaotamine !12_S	et	f	\N
203712	kaotamisega	"kaotamine %kaota  )MINE_vS  <kaotama ;27_V	et	f	\N
203724	armastav	armastav =armasta  (PtsPrPs  >armastama !27_V	et	f	\N
203725	armastav	armastav =armastav  (SgN  >armastav !02_A	et	f	\N
203726	armastav	"armastav %armasta  )V_vA  <armastama ;27_V	et	f	\N
203736	õiguseid	õiguseid =õiguse  (PlP  >õigus !09_S	et	f	\N
203737	õiguseid	"õigus %õige  )US_aS  <õige ;01_A	et	f	\N
203740	lapsepuhkusele	lapsepuhkusele =use  (PlAll  >lapse+puhk+usk !22_S	et	f	\N
203741	lapsepuhkusele	lapsepuhkusele =puhkuse  (SgAll  >lapse+puhkus !11~09_S	et	f	\N
203753	kindlameelsemad	kindlameelsemad =meelsema  (PlN  >kindla+meelsem !02_A	et	f	\N
203754	kindlameelsemad	"kindla+meelsem %meelse  )M_cA  <kindla+meelne ;02_A	et	f	\N
203768	avatumad	avatumad =avatuma  (PlN  >avatum !02_A	et	f	\N
203769	avatumad	"avatum %ava  )TUM1_cA  <avama ;27_V	et	f	\N
203770	avatumad	"avatum %ava  )TUM2_cA  <ava ;17_S	et	f	\N
203776	mõistev	mõistev =mõist  (PtsPrPs  >mõistma !34_V	et	f	\N
203777	mõistev	mõistev =mõistev  (SgN  >mõistev !02_A	et	f	\N
203778	mõistev	"mõistev %mõist  )V_vA  <mõistma ;34_V	et	f	\N
203794	mutkiks	?mutkiks =mutki  (SgTr  >mutki !16_S	et	f	\N
203795	mutkiks	?mutkiks =mutki  (SgTr  >mutk !22_S	et	f	\N
203796	mutkiks	?mutkiks =mutki  (KndPrPs  >mutkima !28_V	et	f	\N
203797	üheselt	üheselt =ühese  (SgAbl  >ühene !10_AS	et	f	\N
203798	üheselt	"ühene %ühe  )NE_aA  <üks ;22_NP	et	f	\N
203799	üheselt	üheselt =üheselt  (ID  >üheselt !41_D	et	f	\N
203800	üheselt	"üheselt %ühese  )LT_mD  <ühene ;10_AS	et	f	\N
203801	sotsiaalsesse	sotsiaalsesse =sotsiaalse  (SgIll  >sotsiaalne !02_A	et	f	\N
203802	sotsiaalsesse	sotsiaalsesse =sesse  (PlP  >sotsiaal+sess !22_S	et	f	\N
203837	paindlikult	paindlikult =paindliku  (SgAbl  >paindlik !25_A	et	f	\N
203838	paindlikult	paindlikult =paindlikult  (ID  >paindlikult !41_D	et	f	\N
203839	paindlikult	"paindlikult %paindliku  )LT_mD  <paindlik ;25_A	et	f	\N
203874	figureerivad	figureerivad =figureeri  (IndPrPl3  >figureerima !28_V	et	f	\N
203875	figureerivad	figureerivad =figureeriva  (PlN  >figureeriv !02_A	et	f	\N
203876	figureerivad	"figureeriv %figureeri  )V_vA  <figureerima ;28_V	et	f	\N
203877	atraktiivse	?atraktiivse =atraktiivse  (SgG  >atraktiivne !02_A	et	f	\N
203878	atraktiivse	?atraktiivse =atraktiivse  (PlP  >atraktiivs !22_S	et	f	\N
203884	edukaid	edukaid =eduka  (PlP  >edukas !02_A	et	f	\N
203885	edukaid	edukaid =kai  (PlN  >edu+kai !26_S	et	f	\N
203886	edukaid	edukaid =kai  (SgP  >edu+kai !26_S	et	f	\N
203903	võrdõiguslikkuse	võrdõiguslikkuse =õiguslikkuse  (SgG  >võrd+õiguslikkus !11~09_S	et	f	\N
203904	võrdõiguslikkuse	"võrd+õiguslikkus %õiguslikku  )US_aS  <võrd+õiguslik ;25_A	et	f	\N
203941	ülalkirjeldam	?ülalkirjeldam =ülalkirjeldam  (SgN  >ülalkirjeldam !02_A	et	f	\N
203942	ülalkirjeldam	?ülalkirjeldam =kirjeldam  (SgN  >ülal+kirjeldam !02_A	et	f	\N
203953	võlu	võlu =võlu  (SgN  >võlu !17_S	et	f	\N
203954	võlu	võlu =võlu  (SgG  >võlu !17_S	et	f	\N
203955	võlu	võlu =võlu  (SgP  >võlu !17_S	et	f	\N
203956	võlu	võlu =võlu  (IndPrPs_  >võluma !27_V	et	f	\N
203957	võlu	võlu =võlu  (ImpPrSg2  >võluma !27_V	et	f	\N
203969	vastandlikku	vastandlikku =vastandlikku  (SgP  >vastandlik !25_A	et	f	\N
203970	vastandlikku	vastandlikku =vastandlikku  (SgAdt  >vastandlik !25_A	et	f	\N
203971	vastandlikku	vastandlikku =andlikku  (SgP  >vast+andlik !25_A	et	f	\N
203972	vastandlikku	vastandlikku =andlikku  (SgAdt  >vast+andlik !25_A	et	f	\N
203989	mööde	mööde =mööde  (SgN  >mööde !06_S	et	f	\N
203990	mööde	mööde =mööde  (SgG  >mööde !06_S	et	f	\N
204004	kultuuriuurija	kultuuriuurija =uurija  (SgN  >kultuuri+uurija !01_S	et	f	\N
204006	kultuuriuurija	kultuuriuurija =uurija  (SgG  >kultuuri+uurija !01_S	et	f	\N
204018	globaliseerivas	?globaliseerivas =globaliseeriva  (SgIn  >globaliseeriv !02_A	et	f	\N
204019	globaliseerivas	?globaliseerivas =globaliseeriva  (SgIn  >globaliseeriva !16_S	et	f	\N
204020	kultuuridimensiooni	kultuuridimensiooni =dimensiooni  (SgG  >kultuuri+dimensioon !22_S	et	f	\N
204021	kultuuridimensiooni	kultuuridimensiooni =dimensiooni  (SgP  >kultuuri+dimensioon !22_S	et	f	\N
204022	kultuuridimensiooni	kultuuridimensiooni =dimensiooni  (SgAdt  >kultuuri+dimensioon !22_S	et	f	\N
204023	globaalruumiga	globaalruumiga =iga  (SgN  >globaal+ruum+iga !18_S	et	f	\N
204024	globaalruumiga	globaalruumiga =iga  (SgP  >globaal+ruum+iga !18_S	et	f	\N
203763	soovigi	soovigi =soovi  (IndPrPs_^  >soovima !28_V	et	f	\N
203764	soovigi	soovigi =soovi  (ImpPrSg2^  >soovima !28_V	et	f	\N
203765	least	?least =lea  (SgEl  >lea !26_S	et	f	\N
203766	least	?least =leas  (SgP  >leane !10_A	et	f	\N
203767	least	?least =least  (SgN  >least !22_S	et	f	\N
203773	hooliv	hooliv =hooli  (PtsPrPs  >hoolima !28_V	et	f	\N
203774	hooliv	hooliv =hooliv  (SgN  >hooliv !02_A	et	f	\N
203775	hooliv	"hooliv %hooli  )V_vA  <hoolima ;28_V	et	f	\N
203779	rollist	rollist =rolli  (SgEl  >roll !22_S	et	f	\N
203780	rollist	rollist =rollis  (SgP  >rolline !10_A	et	f	\N
203781	rollist	"rolline %rolli  )NE_aA  <roll ;22_S	et	f	\N
203789	tagamise	tagamise =tagamise  (SgG  >tagamine !12_S	et	f	\N
203790	tagamise	"tagamine %taga  )MINE_vS  <tagama ;27_V	et	f	\N
203823	traditsiooniliste	traditsiooniliste =traditsioonilis  (PlG  >traditsiooniline !12_A	et	f	\N
203825	traditsiooniliste	"traditsiooniline %traditsiooni  )LINE_aA  <traditsioon ;22_S	et	f	\N
203832	sotsiaalelus	sotsiaalelus =elu  (SgIn  >sotsiaal+elu !17_S	et	f	\N
203833	sotsiaalelus	sotsiaalelus =elus  (SgN  >sotsiaal+elus !02_A	et	f	\N
203834	väärikalt	väärikalt =väärika  (SgAbl  >väärikas !02_A	et	f	\N
203835	väärikalt	väärikalt =väärikalt  (ID  >väärikalt !41_D	et	f	\N
203836	väärikalt	"väärikalt %väärika  )LT_mD  <väärikas ;02_A	et	f	\N
203840	veenuselt	?veenuselt =veenuse  (SgAbl  >veenus !11~09_S	et	f	\N
203841	veenuselt	?veenuselt =veenuselt  (ID  >veenuselt !41_D	et	f	\N
203842	veenuselt	?veenuselt =nuse  (SgAbl  >vee+nuse !16_S	et	f	\N
203849	jahti	jahti =jahti  (SgP  >jaht !22_S	et	f	\N
203850	jahti	jahti =jahti  (SgAdt  >jaht !22_S	et	f	\N
203851	revolutsioonilisi	revolutsioonilisi =revolutsioonilisi  (PlP  >revolutsiooniline !12_A	et	f	\N
203852	revolutsioonilisi	"revolutsiooniline %revolutsiooni  )LINE_aA  <revolutsioon ;22_S	et	f	\N
203879	majandus-	majandus- =majandus  (SgN  >majandus !11_S	et	f	\N
203880	majandus-	"majandus %majanda  )US_vS  <majandama ;27_V	et	f	\N
203887	tihtipelae	?tihtipelae =tihtipelae  (SgN  >tihtipelae !26_S	et	f	\N
203888	tihtipelae	?tihtipelae =tihtipelae  (SgG  >tihtipelae !26_S	et	f	\N
203889	tihtipelae	?tihtipelae =pelae  (SgN  >tihti+pelae !26_S	et	f	\N
203890	tihtipelae	?tihtipelae =pelae  (SgG  >tihti+pelae !26_S	et	f	\N
203912	meeletult	meeletult =meeletu  (SgAbl  >meeletu !01_A	et	f	\N
203913	meeletult	"meeletu %meele  )TU2_kA  <meel ;13_S	et	f	\N
203914	meeletult	meeletult =meeletult  (ID  >meeletult !41_D	et	f	\N
203915	meeletult	"meeletult %meele  )TULT2_mD  <meel ;13_S	et	f	\N
203916	meeletult	"meeletult %meeletu  )LT_mD  <meeletu ;01_A	et	f	\N
203917	meeletult	meeletult =letu  (SgAbl  >mee+letu !16_S	et	f	\N
203920	rahutus	rahutus =rahutu  (SgIn  >rahutu !01_A	et	f	\N
203921	rahutus	"rahutu %rahu  )TU2_kA  <rahu ;17_S	et	f	\N
203922	rahutus	rahutus =rahutus  (SgN  >rahutus !11_S	et	f	\N
203923	rahutus	"rahutus %rahu  )TUS2_aS  <rahu ;17_S	et	f	\N
203924	tööelus	tööelus =elu  (SgIn  >töö+elu !17_S	et	f	\N
203925	tööelus	tööelus =elus  (SgN  >töö+elus !02_A	et	f	\N
203926	ahvatlustele	ahvatlustele =ahvatlus  (PlAll  >ahvatlus !11_S	et	f	\N
203927	ahvatlustele	"ahvatlus %ahvatle  )US_vS  <ahvatlema ;27_V	et	f	\N
203950	kosmoseajastu	kosmoseajastu =ajastu  (SgN  >kosmose+ajastu !01_S	et	f	\N
203951	kosmoseajastu	kosmoseajastu =ajastu  (SgG  >kosmose+ajastu !01_S	et	f	\N
203952	globaliseerimise	?globaliseerimise =globaliseerimise  (SgG  >globaliseerimine !12_S	et	f	\N
203965	globaalsus	globaalsus =globaalsus  (SgN  >globaalsus !11~09_S	et	f	\N
203966	globaalsus	"globaalsus %globaalse  )US_aS  <globaalne ;02_A	et	f	\N
203973	mõjutamata	mõjutamata =mõjuta  (SupAb  >mõjutama !27_V	et	f	\N
203974	mõjutamata	mõjutamata =mõjutamata  (ID  >mõjutamata !41_A	et	f	\N
203975	mõjutamata	"mõjutamata %mõjuta  )MATA_vA  <mõjutama ;27_V	et	f	\N
203976	aktiivsesse	aktiivsesse =aktiivse  (SgIll  >aktiivne !02_A	et	f	\N
203977	aktiivsesse	aktiivsesse =sesse  (PlP  >aktiiv+sess !22_S	et	f	\N
203981	mõttemaailma	mõttemaailma =ilma  (SgG  >mõtte+maa+ilm !22_S	et	f	\N
203982	mõttemaailma	mõttemaailma =ilma  (SgP  >mõtte+maa+ilm !22_S	et	f	\N
203983	mõttemaailma	mõttemaailma =ilma  (SgAdt  >mõtte+maa+ilm !22_S	et	f	\N
204000	piiritustest	piiritustest =piiritus  (PlEl  >piiritus !11_S	et	f	\N
204001	piiritustest	"piiritus %piiri  )TUS2_aS  <piir ;22_S	et	f	\N
204002	piiritustest	piiritustest =test  (SgN  >piiritus+test !22_S	et	f	\N
204003	piiritustest	piiritustest =tuste  (PlEl  >piiri+tust !22_S	et	f	\N
204008	kaasne	kaasne =kaasne  (IndPrPs_  >kaasnema !27_V	et	f	\N
204009	kaasne	kaasne =kaasne  (ImpPrSg2  >kaasnema !27_V	et	f	\N
204067	turvalisse	turvalisse =turvalis  (SgAdt  >turvaline !12_A	et	f	\N
204068	turvalisse	"turvaline %turva  )LINE_aA  <turb ;22_SA	et	f	\N
204069	turvalisse	"turvaline %turva  )LINE_aA  <turv ;22_S	et	f	\N
204077	tunneksid	tunneksid =tunne  (KndPrSg2  >tundma !34_V	et	f	\N
204078	tunneksid	tunneksid =tunne  (KndPrPl3  >tundma !34_V	et	f	\N
204079	sellese	?sellese =sellese  (SgG  >sellene !10_A	et	f	\N
204083	globaalsuse	globaalsuse =globaalsuse  (SgG  >globaalsus !11~09_S	et	f	\N
204086	globaalsuse	"globaalsus %globaalse  )US_aS  <globaalne ;02_A	et	f	\N
203854	verstapostiks	verstapostiks =posti  (SgTr  >versta+post !22_S	et	f	\N
203861	vähenemisele	vähenemisele =vähenemise  (SgAll  >vähenemine !12_S	et	f	\N
203862	vähenemisele	"vähenemine %vähene  )MINE_vS  <vähenema ;27_V	et	f	\N
203864	tõstnud	tõstnud =tõst  (PtsPtPs  >tõstma !34_V	et	f	\N
203865	tõstnud	tõstnud =tõstnu  (PlN  >tõstnu !01_S	et	f	\N
203866	tõstnud	"tõstnu %tõst  )NU_vS  <tõstma ;34_V	et	f	\N
203867	tõstnud	tõstnud =tõstnud  (ID  >tõstnud !41_A	et	f	\N
203868	tõstnud	"tõstnud %tõst  )NUD_vA  <tõstma ;34_V	et	f	\N
203871	telemeedias	telemeedias =dia  (SgIn  >tele+mee+dia !26_S	et	f	\N
203873	telemeedias	telemeedias =meedia  (SgIn  >tele+meedia !01_S	et	f	\N
203881	muutuvatele	muutuvatele =muutuva  (PlAll  >muutuv !02_A	et	f	\N
203882	muutuvatele	"muutuv %muutu  )V_vA  <muutuma ;27_V	et	f	\N
203883	muutuvatele	muutuvatele =vate  (PlAll  >muutu+vatt !22_S	et	f	\N
203899	võrdsustumine	võrdsustumine =võrdsustumine  (SgN  >võrdsustumine !12_S	et	f	\N
203900	võrdsustumine	"võrdsustumine %võrdsustu  )MINE_vS  <võrdsustuma ;27_V	et	f	\N
203918	lähedasemad	lähedasemad =lähedasema  (PlN  >lähedasem !02_A	et	f	\N
203919	lähedasemad	"lähedasem %lähedase  )M_cA  <lähedane ;12_AS	et	f	\N
203945	liidrirolli	liidrirolli =rolli  (SgG  >liidri+roll !22_S	et	f	\N
203946	liidrirolli	liidrirolli =rolli  (SgP  >liidri+roll !22_S	et	f	\N
203947	liidrirolli	liidrirolli =rolli  (SgAdt  >liidri+roll !22_S	et	f	\N
203958	globaliseerumise	?globaliseerumise =globaliseerumise  (SgG  >globaliseerumine !12_S	et	f	\N
203959	maailmastumisega	maailmastumisega =astumise  (SgKom  >maa+ilm+astumine !12_S	et	f	\N
203960	maailmastumisega	maailmastumisega =ilmastumise  (SgKom  >maa+ilmastumine !12_S	et	f	\N
203979	globalprobleemidega	?globalprobleemidega =globalprobleemi  (PlKom  >globalprobleemi !16_S	et	f	\N
203980	globalprobleemidega	?globalprobleemidega =globalprobleemi  (PlKom  >globalprobleem !22_S	et	f	\N
203984	lisandunud	lisandunud =lisandu  (PtsPtPs  >lisanduma !27_V	et	f	\N
203985	lisandunud	lisandunud =lisandunu  (PlN  >lisandunu !01_S	et	f	\N
203986	lisandunud	"lisandunu %lisandu  )NU_vS  <lisanduma ;27_V	et	f	\N
203987	lisandunud	lisandunud =lisandunud  (ID  >lisandunud !41_A	et	f	\N
203988	lisandunud	"lisandunud %lisandu  )NUD_vA  <lisanduma ;27_V	et	f	\N
203995	austraalias	?austraalias =austraalia  (SgIn  >austraalia !01_S	et	f	\N
203996	austraalias	?austraalias =austraalias  (SgN  >austraalias !11_S	et	f	\N
203997	globaalmaailma	globaalmaailma =ilma  (SgG  >globaal+maa+ilm !22_S	et	f	\N
203998	globaalmaailma	globaalmaailma =ilma  (SgP  >globaal+maa+ilm !22_S	et	f	\N
203999	globaalmaailma	globaalmaailma =ilma  (SgAdt  >globaal+maa+ilm !22_S	et	f	\N
204007	globaliseerumisega	?globaliseerumisega =globaliseerumise  (SgKom  >globaliseerumine !12_S	et	f	\N
204028	psühholoogiale	psühholoogiale =psühholoogia  (SgAll  >psühholoogia !01_S	et	f	\N
204029	psühholoogiale	psühholoogiale =ale  (SgN  >psühholoogi+ale !16_S	et	f	\N
204030	psühholoogiale	psühholoogiale =ale  (SgG  >psühholoogi+ale !16_S	et	f	\N
204031	burgerieine	burgerieine =eine  (SgN  >burgeri+eine !06_S	et	f	\N
204032	burgerieine	burgerieine =eine  (SgG  >burgeri+eine !06_S	et	f	\N
204040	määramatuse	määramatuse =määramatuse  (SgG  >määramatus !11?09_S	et	f	\N
204041	määramatuse	"määramatus %määra  )MATUS_aS  <määrama ;29_V	et	f	\N
204060	globaliseerumine	?globaliseerumine =globaliseerumine  (SgN  >globaliseerumine !12_S	et	f	\N
204061	globaliseerumine	?globaliseerumine =globaliseerumine  (PlP  >globaliseerumin !19_S	et	f	\N
204062	turvaliste	turvaliste =turvalis  (PlG  >turvaline !12_A	et	f	\N
204064	turvaliste	"turvaline %turva  )LINE_aA  <turb ;22_SA	et	f	\N
204066	turvaliste	"turvaline %turva  )LINE_aA  <turv ;22_S	et	f	\N
204088	indiviidi	indiviidi =indiviidi  (SgG  >indiviid !22_S	et	f	\N
204089	indiviidi	indiviidi =indiviidi  (SgP  >indiviid !22_S	et	f	\N
204090	indiviidi	indiviidi =indiviidi  (SgAdt  >indiviid !22_S	et	f	\N
204109	virtuaalkeskkonna	?virtuaalkeskkonna =virtuaalkeskkonna  (SgN  >virtuaalkeskkonna !16_S	et	f	\N
204110	virtuaalkeskkonna	?virtuaalkeskkonna =virtuaalkeskkonna  (SgG  >virtuaalkeskkonna !16_S	et	f	\N
204111	virtuaalkeskkonna	?virtuaalkeskkonna =virtuaalkeskkonna  (SgG  >virtuaalkeskkond !22_S	et	f	\N
204128	globaliseerumisprotsess	?globaliseerumisprotsess =globaliseerumisprotsess  (SgN  >globaliseerumisprotsess !22_S	et	f	\N
204131	amerikaniseerumine	amerikaniseerumine =amerikaniseerumine  (SgN  >amerikaniseerumine !12_S	et	f	\N
204132	amerikaniseerumine	"amerikaniseerumine %amerikaniseeru  )MINE_vS  <amerikaniseeruma ;27_V	et	f	\N
204135	eestitseerumisse	?eestitseerumisse =eestitseerumi  (SgIll  >eestitseerum !02_S	et	f	\N
204136	eestitseerumisse	?eestitseerumisse =eestitseerumis  (SgAdt  >eestitseerumine !12_S	et	f	\N
204137	eestitseerumisse	?eestitseerumisse =eestitseerumisse  (SgG  >eestitseerumisne !02_A	et	f	\N
204138	eestitseerumisse	?eestitseerumisse =eestitseerumisse  (PlP  >eestitseerumiss !22_S	et	f	\N
204139	eestitseerumisse	?eestitseerumisse =tseerumi  (SgIll  >eesti+tseerumi !01_S	et	f	\N
204140	eestitseerumisse	?eestitseerumisse =tseerumi  (SgIll  >eesti+tseerum !02_S	et	f	\N
204141	eestitseerumisse	?eestitseerumisse =tseerumis  (SgAdt  >eesti+tseerumis !11_S	et	f	\N
204142	eestitseerumisse	?eestitseerumisse =tseerumis  (SgAdt  >eesti+tseerumine !12_S	et	f	\N
204143	eestitseerumisse	?eestitseerumisse =tseerumisse  (SgG  >eesti+tseerumisne !02_A	et	f	\N
204144	eestitseerumisse	?eestitseerumisse =tseerumisse  (PlP  >eesti+tseerumiss !22_S	et	f	\N
203907	kohtlemist	kohtlemist =kohtlemis  (SgP  >kohtlemine !12_S	et	f	\N
203908	kohtlemist	"kohtlemine %kohtle  )MINE_vS  <kohtlema ;30_V	et	f	\N
203909	meestelt	meestelt =mees  (PlAbl  >meene !10_A	et	f	\N
203910	meestelt	"meene %mee  )NE_aA  <mesi ;15_S	et	f	\N
203911	meestelt	meestelt =mees  (PlAbl  >mees !13_S	et	f	\N
203928	sugupool	sugupool =pool  (ID  >sugu+pool !41_DK	et	f	\N
203929	sugupool	sugupool =pool  (SgN  >sugu+pool !13_NS	et	f	\N
203930	sugupool	sugupool =pool  (SgN  >sugu+pool !22_S	et	f	\N
203933	tehnoinnovaatilistele	?tehnoinnovaatilistele =tehnoinnovaatilis  (PlAll  >tehnoinnovaatilis !09_S	et	f	\N
203934	tehnoinnovaatilistele	?tehnoinnovaatilistele =tehnoinnovaatilis  (PlAll  >tehnoinnovaatiline !12_A	et	f	\N
203935	tehnoinnovaatilistele	?tehnoinnovaatilistele =tehnoinnovaatiliste  (PlAll  >tehnoinnovaatilist !22_S	et	f	\N
203936	tehnoinnovaatilistele	?tehnoinnovaatilistele =tehnoinnovaatilistele  (IndPrPs_  >tehnoinnovaatilistelema !36_V	et	f	\N
203937	tehnoinnovaatilistele	?tehnoinnovaatilistele =tehnoinnovaatilistele  (ImpPrSg2  >tehnoinnovaatilistelema !36_V	et	f	\N
203938	tehnoinnovaatilistele	?tehnoinnovaatilistele =innovaatilis  (PlAll  >tehno+innovaatilis !09_S	et	f	\N
203939	tehnoinnovaatilistele	?tehnoinnovaatilistele =innovaatilis  (PlAll  >tehno+innovaatiline !12_A	et	f	\N
203940	tehnoinnovaatilistele	?tehnoinnovaatilistele =innovaatiliste  (PlAll  >tehno+innovaatilist !22_S	et	f	\N
203961	iseärasuste	iseärasuste =us  (PlG  >ise+äras+uks !14_S	et	f	\N
203962	iseärasuste	iseärasuste =ärasus  (PlG  >ise+ärasus !11_S	et	f	\N
203967	lokaalsus	lokaalsus =lokaalsus  (SgN  >lokaalsus !11~09_S	et	f	\N
203968	lokaalsus	"lokaalsus %lokaalse  )US_aS  <lokaalne ;02_A	et	f	\N
204042	vahendamise	vahendamise =vahendamise  (SgG  >vahendamine !12_S	et	f	\N
204043	vahendamise	"vahendamine %vahenda  )MINE_vS  <vahendama ;27_V	et	f	\N
204058	eelnevast	eelnevast =eelneva  (SgEl  >eelnev !02_A	et	f	\N
204059	eelnevast	"eelnev %eelne  )V_vA  <eelnema ;27_V	et	f	\N
204070	globaalkeskkonda	globaalkeskkonda =keskkonda  (SgP  >globaal+keskkond !22_S	et	f	\N
204071	globaalkeskkonda	globaalkeskkonda =keskkonda  (SgAdt  >globaal+keskkond !22_S	et	f	\N
204075	mõistaksid	mõistaksid =mõista  (KndPrSg2  >mõistma !34_V	et	f	\N
204076	mõistaksid	mõistaksid =mõista  (KndPrPl3  >mõistma !34_V	et	f	\N
204093	tolerantsem	tolerantsem =tolerantsem  (SgN  >tolerantsem !02_A	et	f	\N
204094	tolerantsem	"tolerantsem %tolerantse  )M_cA  <tolerantne ;02_A	et	f	\N
204101	hoomata	hoomata =hooma  (Inf  >hoomama !29_V	et	f	\N
204102	hoomata	hoomata =hooma  (IndPrIps_  >hoomama !29_V	et	f	\N
204119	jensenil	?jensenil =jenseni  (SgAd  >jensen !02_S	et	f	\N
204155	vastastikku	vastastikku =vastastikku  (ID  >vastastikku !41_D	et	f	\N
204156	vastastikku	vastastikku =tikku  (SgP  >vastas+tikk !22_S	et	f	\N
204157	vastastikku	vastastikku =tikku  (SgAdt  >vastas+tigu !18_S	et	f	\N
204158	vastastikku	vastastikku =tikku  (SgAdt  >vastas+tikk !22_S	et	f	\N
204159	vastastikku	vastastikku =tikku  (PlP  >vastas+tikk !22_S	et	f	\N
204160	sümbioosi	sümbioosi =sümbioosi  (SgG  >sümbioos !22_S	et	f	\N
204161	sümbioosi	sümbioosi =sümbioosi  (SgP  >sümbioos !22_S	et	f	\N
204162	sümbioosi	sümbioosi =sümbioosi  (SgAdt  >sümbioos !22_S	et	f	\N
204196	tarbijad	tarbijad =tarbija  (PlN  >tarbija !01_S	et	f	\N
204197	tarbijad	"tarbija %tarbi  )JA_vS  <tarbima ;27_V	et	f	\N
204198	teeniksid	teeniksid =teeni  (KndPrSg2  >teenima !28_V	et	f	\N
204199	teeniksid	teeniksid =teeni  (KndPrPl3  >teenima !28_V	et	f	\N
204200	teeniksid	teeniksid =niksi  (PlN  >tee+niks !22_S	et	f	\N
204204	mina-pilti	mina-pilti =pilti  (SgP  >mina-pilt !22_S	et	f	\N
204205	mina-pilti	mina-pilti =pilti  (SgAdt  >mina-pilt !22_S	et	f	\N
204210	defineerivad	defineerivad =defineeri  (IndPrPl3  >defineerima !28_V	et	f	\N
204211	defineerivad	defineerivad =defineeriva  (PlN  >defineeriv !02_A	et	f	\N
204212	defineerivad	"defineeriv %defineeri  )V_vA  <defineerima ;28_V	et	f	\N
204217	kohanenud	kohanenud =kohane  (PtsPtPs  >kohanema !27_V	et	f	\N
204218	kohanenud	kohanenud =kohanenu  (PlN  >kohanenu !01_S	et	f	\N
204219	kohanenud	"kohanenu %kohane  )NU_vS  <kohanema ;27_V	et	f	\N
204220	kohanenud	kohanenud =kohanenud  (ID  >kohanenud !41_A	et	f	\N
204221	kohanenud	"kohanenud %kohane  )NUD_vA  <kohanema ;27_V	et	f	\N
204222	teaba	?teaba =teaba  (SgN  >teaba !16_S	et	f	\N
204223	teaba	?teaba =teaba  (SgG  >teaba !16_S	et	f	\N
204224	teaba	?teaba =teaba  (IndPrPs_  >teabama !29_V	et	f	\N
204225	teaba	?teaba =teaba  (ImpPrSg2  >teabama !29_V	et	f	\N
204233	tajutav	tajutav =taju  (PtsPrIps  >tajuma !27_V	et	f	\N
204234	tajutav	tajutav =tajutav  (SgN  >tajutav !02_A	et	f	\N
204235	tajutav	"tajutav %taju  )TAV_vAS  <tajuma ;27_V	et	f	\N
204249	dima	?dima =dima  (SgN  >dima !17_S	et	f	\N
204250	dima	?dima =dima  (SgG  >dima !17_S	et	f	\N
204251	dima	?dima =dima  (SgP  >dima !17_S	et	f	\N
204252	dima	?dima =dima  (IndPrPs_  >dimama !27_V	et	f	\N
204253	dima	?dima =dima  (ImpPrSg2  >dimama !27_V	et	f	\N
204267	aktsepteeritud	aktsepteeritud =aktsepteeri  (PtsPtIps  >aktsepteerima !28_V	et	f	\N
204268	aktsepteeritud	aktsepteeritud =aktsepteeritu  (PlN  >aktsepteeritu !01_S	et	f	\N
204269	aktsepteeritud	"aktsepteeritu %aktsepteeri  )TU1_vS  <aktsepteerima ;28_V	et	f	\N
204270	aktsepteeritud	aktsepteeritud =aktsepteeritud  (ID  >aktsepteeritud !41_A	et	f	\N
204005	hofstede	### hofstede	et	f	\N
204010	unifitseerumist	?unifitseerumist =unifitseerumi  (SgEl  >unifitseerum !02_S	et	f	\N
204011	unifitseerumist	?unifitseerumist =unifitseerumis  (SgP  >unifitseerumis !09_S	et	f	\N
204012	unifitseerumist	?unifitseerumist =unifitseerumis  (SgP  >unifitseerumine !12_S	et	f	\N
204013	unifitseerumist	?unifitseerumist =unifitseerumist  (SgN  >unifitseerumist !22_S	et	f	\N
204014	unifitseerumist	?unifitseerumist =fitseerumi  (SgEl  >uni+fitseerum !02_S	et	f	\N
204015	unifitseerumist	?unifitseerumist =fitseerumis  (SgP  >uni+fitseerumis !09_S	et	f	\N
204016	unifitseerumist	?unifitseerumist =fitseerumis  (SgP  >uni+fitseerumine !12_S	et	f	\N
204017	unifitseerumist	?unifitseerumist =fitseerumist  (SgN  >uni+fitseerumist !22_S	et	f	\N
204026	varieerumised	varieerumised =varieerumise  (PlN  >varieerumine !12_S	et	f	\N
204027	varieerumised	"varieerumine %varieeru  )MINE_vS  <varieeruma ;27_V	et	f	\N
204044	määramatust	määramatust =määramatu  (SgEl  >määramatu !01_A	et	f	\N
204045	määramatust	"määramatu %määra  )MATU_vA  <määrama ;29_V	et	f	\N
204046	määramatust	määramatust =määramatus  (SgP  >määramatus !11?09_S	et	f	\N
204047	määramatust	"määramatus %määra  )MATUS_aS  <määrama ;29_V	et	f	\N
204048	määramatus	määramatus =määramatu  (SgIn  >määramatu !01_A	et	f	\N
204049	määramatus	"määramatu %määra  )MATU_vA  <määrama ;29_V	et	f	\N
204050	määramatus	määramatus =määramatus  (SgN  >määramatus !11?09_S	et	f	\N
204051	määramatus	"määramatus %määra  )MATUS_aS  <määrama ;29_V	et	f	\N
204054	ennustused	ennustused =ennustuse  (PlN  >ennustus !11_S	et	f	\N
204055	ennustused	"ennustus %ennusta  )US_vS  <ennustama ;27_V	et	f	\N
204072	globaalruumi	globaalruumi =ruumi  (SgG  >globaal+ruum !22_S	et	f	\N
204073	globaalruumi	globaalruumi =ruumi  (SgP  >globaal+ruum !22_S	et	f	\N
204074	globaalruumi	globaalruumi =ruumi  (SgAdt  >globaal+ruum !22_S	et	f	\N
204087	globaliseerimisega	?globaliseerimisega =globaliseerimise  (SgKom  >globaliseerimine !12_S	et	f	\N
204095	stereotüübid	stereotüübid =stereotüübi  (PlN  >stereotüüp !22_S	et	f	\N
204096	stereotüübid	stereotüübid =stereotüübi  (IndPrSg2  >stereotüüpima !28_V	et	f	\N
204129	muretsemiseks	muretsemiseks =muretsemise  (SgTr  >muretsemine !12_S	et	f	\N
204130	muretsemiseks	"muretsemine %muretse  )MINE_vS  <muretsema ;27_V	et	f	\N
204133	suhtuks	suhtuks =suhtu  (KndPrPs  >suhtuma !27_V	et	f	\N
204134	suhtuks	suhtuks =uks  (SgN  >suht+uks !14_S	et	f	\N
204180	korporatiivset	?korporatiivset =korporatiivse  (SgP  >korporatiivne !02_A	et	f	\N
204213	taibata	taibata =taiba  (Inf  >taipama !29_V	et	f	\N
204214	taibata	taibata =taiba  (IndPrIps_  >taipama !29_V	et	f	\N
204244	intrigeeriv	intrigeeriv =intrigeeri  (PtsPrPs  >intrigeerima !28_V	et	f	\N
204245	intrigeeriv	intrigeeriv =intrigeeriv  (SgN  >intrigeeriv !02_A	et	f	\N
204246	intrigeeriv	"intrigeeriv %intrigeeri  )V_vA  <intrigeerima ;28_V	et	f	\N
204259	normaalsem	normaalsem =normaalsem  (SgN  >normaalsem !02_A	et	f	\N
204260	normaalsem	"normaalsem %normaalse  )M_cA  <normaalne ;02_A	et	f	\N
204274	done	done =done  (SgN  >done !16_S	et	f	\N
204275	done	"done %do  )NE_aA  <do ;26_S	et	f	\N
204276	done	done =done  (SgG  >done !16_S	et	f	\N
204279	suhtlemis-	?suhtlemis- =suhtlemi  (SgIn  >suhtlemi !01_S	et	f	\N
204280	suhtlemis-	?suhtlemis- =suhtlemi  (SgIn  >suhtlem !02_A	et	f	\N
204281	suhtlemis-	?suhtlemis- =suhtlemis  (SgN  >suhtlemis !11_S	et	f	\N
204282	suhtlemis-	?suhtlemis- =lemi  (SgIn  >suht+lemi !17_S	et	f	\N
204283	suhtlemis-	?suhtlemis- =lemis  (SgN  >suht+lemis !09_S	et	f	\N
204291	argumenteerimise	argumenteerimise =argumenteerimise  (SgG  >argumenteerimine !12_S	et	f	\N
204292	argumenteerimise	"argumenteerimine %argumenteeri  )MINE_vS  <argumenteerima ;28_V	et	f	\N
204296	tulemisele	tulemisele =tulemise  (SgAll  >tulemine !12_S	et	f	\N
204297	tulemisele	"tulemine %tule  )MINE_vS  <tulema ;36_V	et	f	\N
204298	tulemisele	"tulemine %tulemi  )NE_aA  <tulem ;02_S	et	f	\N
204302	kiitusega	kiitusega =kiituse  (SgKom  >kiitus !11~09_S	et	f	\N
204303	kiitusega	"kiitus %kii  )TUS2_aS  <kii ;26_S	et	f	\N
204306	dimast	?dimast =dima  (SgEl  >dima !17_S	et	f	\N
204307	dimast	?dimast =dimas  (SgP  >dimas !09_S	et	f	\N
204308	dimast	?dimast =dimas  (SgP  >dimane !10_A	et	f	\N
204317	pööraseid	pööraseid =pöörase  (PlP  >pöörane !10_A	et	f	\N
204318	pööraseid	"pöörane %pööra  )NE_aA  <pöör ;22_S	et	f	\N
204321	austraaliast	?austraaliast =austraalia  (SgEl  >austraalia !01_S	et	f	\N
204322	austraaliast	?austraaliast =austraalias  (SgP  >austraalias !11_S	et	f	\N
204327	freudlikul	?freudlikul =freudliku  (SgAd  >freudlik !25_A	et	f	\N
204328	freudlikul	?freudlikul =freudliku  (SgAd  >freudliku !01_S	et	f	\N
204329	freudlikul	?freudlikul =freudlikul  (SgN  >freudlikul !19_S	et	f	\N
204334	normaalsuseni	normaalsuseni =normaalsuse  (SgTer  >normaalsus !11~09_S	et	f	\N
204335	normaalsuseni	"normaalsus %normaalse  )US_aS  <normaalne ;02_A	et	f	\N
204368	vastamiseks	vastamiseks =vastamise  (SgTr  >vastamine !12_S	et	f	\N
204369	vastamiseks	"vastamine %vasta  )MINE_vS  <vastama ;29_V	et	f	\N
204370	üksimateks	üksimateks =mate  (SgTr  >üksi+mate !16_S	et	f	\N
204371	üksimateks	üksimateks =mate  (PlTr  >üksi+matt !22_SA	et	f	\N
204412	järeldustele	järeldustele =järeldus  (PlAll  >järeldus !11_S	et	f	\N
204025	globaalruumiga	globaalruumiga =ruumi  (SgKom  >globaal+ruum !22_S	et	f	\N
204033	mcdonaldsi	?mcdonaldsi =mcdonaldsi  (SgN  >mcdonaldsi !01_S	et	f	\N
204034	mcdonaldsi	?mcdonaldsi =mcdonaldsi  (SgG  >mcdonaldsi !01_S	et	f	\N
204035	mcdonaldsi	?mcdonaldsi =mcdonaldsi  (SgG  >mcdonalds !22_S	et	f	\N
204036	mcdonaldsi	?mcdonaldsi =mcdonaldsi  (SgP  >mcdonalds !22_S	et	f	\N
204037	mcdonaldsi	?mcdonaldsi =mcdonaldsi  (SgAdt  >mcdonalds !22_S	et	f	\N
204038	mcdonaldsi	?mcdonaldsi =mcdonaldsi  (IndPrPs_  >mcdonaldsima !28_V	et	f	\N
204039	mcdonaldsi	?mcdonaldsi =mcdonaldsi  (ImpPrSg2  >mcdonaldsima !28_V	et	f	\N
204052	avastused	avastused =avastuse  (PlN  >avastus !11_S	et	f	\N
204053	avastused	"avastus %avasta  )US_vS  <avastama ;27_V	et	f	\N
204056	inimajus	inimajus =aju  (SgIn  >inim+aju !17_S	et	f	\N
204057	inimajus	inimajus =aju  (PlIn  >inim+aeg !22_S	et	f	\N
204063	ühtsete	ühtsete =ühtse  (PlG  >ühtne !02_A	et	f	\N
204065	ühtsete	ühtsete =sete  (SgN  >üht+sete !06_S	et	f	\N
204080	mikromaailma	mikromaailma =ilma  (SgG  >mikro+maa+ilm !22_S	et	f	\N
204081	mikromaailma	mikromaailma =ilma  (SgP  >mikro+maa+ilm !22_S	et	f	\N
204082	mikromaailma	mikromaailma =ilma  (SgAdt  >mikro+maa+ilm !22_S	et	f	\N
204084	lokaalsusega	lokaalsusega =lokaalsuse  (SgKom  >lokaalsus !11~09_S	et	f	\N
204085	lokaalsusega	"lokaalsus %lokaalse  )US_aS  <lokaalne ;02_A	et	f	\N
204091	globliseerumine	?globliseerumine =globliseerumine  (SgN  >globliseerumine !12_S	et	f	\N
204092	globliseerumine	?globliseerumine =globliseerumine  (PlP  >globliseerumin !19_S	et	f	\N
204106	teadmisjanu	teadmisjanu =janu  (SgN  >teadmis+janu !17_S	et	f	\N
204107	teadmisjanu	teadmisjanu =janu  (SgG  >teadmis+janu !17_S	et	f	\N
204108	teadmisjanu	teadmisjanu =janu  (SgP  >teadmis+janu !17_S	et	f	\N
204120	rolf	?rolf =rolf  (SgN  >rolf !22_S	et	f	\N
204121	infoühiskonna	infoühiskonna =konna  (SgG  >info+ühis+konn !22_S	et	f	\N
204122	infoühiskonna	infoühiskonna =konna  (SgP  >info+ühis+konn !22_S	et	f	\N
204123	infoühiskonna	infoühiskonna =konna  (SgAdt  >info+ühis+konn !22_S	et	f	\N
204124	infoühiskonna	infoühiskonna =ühiskonna  (SgG  >info+ühiskond !22_S	et	f	\N
204125	globaliseerumisprotsessis	?globaliseerumisprotsessis =globaliseerumisprotsessi  (SgIn  >globaliseerumisprotsess !22_S	et	f	\N
204126	globaliseerumisprotsessis	?globaliseerumisprotsessis =globaliseerumisprotsessi  (IndIpfSg3  >globaliseerumisprotsessima !28_V	et	f	\N
204127	globaliseerumisprotsessis	?globaliseerumisprotsessis =globaliseerumisprotsessis  (SgN  >globaliseerumisprotsessis !09_S	et	f	\N
204153	suruta	suruta =suru  (SgAb  >suru !17_S	et	f	\N
204154	suruta	suruta =suru  (IndPrIps_  >suruma !27_V	et	f	\N
204172	mtü	### mtü	et	f	\N
204176	identiteedil	?identiteedil =identiteedi  (SgAd  >identiteedi !16_S	et	f	\N
204177	identiteedil	?identiteedil =identiteedi  (SgAd  >identiteet !22_S	et	f	\N
204178	identiteedil	?identiteedil =identiteedil  (SgN  >identiteedil !02_S	et	f	\N
204184	alustala	alustala =tala  (SgN  >alus+tala !17_S	et	f	\N
204185	alustala	alustala =tala  (SgG  >alus+tala !17_S	et	f	\N
204186	alustala	alustala =tala  (SgP  >alus+tala !17_S	et	f	\N
204187	infomüra	infomüra =müra  (SgN  >info+müra !17_S	et	f	\N
204188	infomüra	infomüra =müra  (SgG  >info+müra !17_S	et	f	\N
204189	infomüra	infomüra =müra  (SgP  >info+müra !17_S	et	f	\N
204206	hoolivas	hoolivas =hooliva  (SgIn  >hooliv !02_A	et	f	\N
204207	hoolivas	"hooliv %hooli  )V_vA  <hoolima ;28_V	et	f	\N
204228	lähenemisnurki	lähenemisnurki =nurki  (SgP  >lähenemis+nurk !22_S	et	f	\N
204229	lähenemisnurki	lähenemisnurki =nurki  (SgAdt  >lähenemis+nurk !22_S	et	f	\N
204230	lähenemisnurki	lähenemisnurki =nurki  (PlP  >lähenemis+nurk !22_S	et	f	\N
204240	loomisel	loomisel =loomise  (SgAd  >loomis !09_S	et	f	\N
204241	loomisel	loomisel =loomise  (SgAd  >loomine !12?10_S	et	f	\N
204242	loomisel	"loomine %loo  )MINE_vS  <looma ;38_V	et	f	\N
204243	loomisel	"loomine %loomi  )NE_aA  <loom ;22_S	et	f	\N
204254	dima	?dima =dima  (SgN  >dima !17_S	et	f	\N
204255	dima	?dima =dima  (SgG  >dima !17_S	et	f	\N
204256	dima	?dima =dima  (SgP  >dima !17_S	et	f	\N
204257	dima	?dima =dima  (IndPrPs_  >dimama !27_V	et	f	\N
204258	dima	?dima =dima  (ImpPrSg2  >dimama !27_V	et	f	\N
204272	peetrist	peetrist =peetri  (SgEl  >peeter !02_S	et	f	\N
204273	peetrist	peetrist =rist  (SgN  >peet+rist !22_S	et	f	\N
204284	reklaamibüroo	reklaamibüroo =büroo  (SgN  >reklaami+büroo !26_S	et	f	\N
204285	reklaamibüroo	reklaamibüroo =büroo  (SgG  >reklaami+büroo !26_S	et	f	\N
204299	dimale	?dimale =dima  (SgAll  >dima !17_S	et	f	\N
204300	dimale	?dimale =dimale  (IndPrPs_  >dimalema !27_V	et	f	\N
204301	dimale	?dimale =dimale  (ImpPrSg2  >dimalema !27_V	et	f	\N
204344	massiühiskonnas	massiühiskonnas =konna  (SgIn  >massi+ühis+konn !22_S	et	f	\N
204345	massiühiskonnas	massiühiskonnas =ühiskonna  (SgIn  >massi+ühiskond !22_S	et	f	\N
204346	väidelda	väidelda =väidel  (Inf  >väitlema !30_V	et	f	\N
204347	väidelda	väidelda =väidel  (IndPrIps_  >väitlema !30_V	et	f	\N
204364	suurimate	"suurim %suuri  )IM_sA  <suur ;13_A	et	f	\N
204365	suurimate	suurimate =mate  (SgN  >suuri+mate !16_S	et	f	\N
204366	suurimate	suurimate =mate  (SgG  >suuri+mate !16_S	et	f	\N
204376	kandmisega	kandmisega =kandmise  (SgKom  >kandmine !12?10_SA	et	f	\N
204097	globaliseerumist	?globaliseerumist =globaliseerumi  (SgEl  >globaliseerum !02_S	et	f	\N
204098	globaliseerumist	?globaliseerumist =globaliseerumis  (SgP  >globaliseerumis !09_S	et	f	\N
204099	globaliseerumist	?globaliseerumist =globaliseerumis  (SgP  >globaliseerumine !12_S	et	f	\N
204100	globaliseerumist	?globaliseerumist =globaliseerumist  (SgN  >globaliseerumist !22_S	et	f	\N
204103	piiritustes	piiritustes =piiritus  (PlIn  >piiritus !11_S	et	f	\N
204104	piiritustes	"piiritus %piiri  )TUS2_aS  <piir ;22_S	et	f	\N
204105	piiritustes	piiritustes =tuste  (PlIn  >piiri+tust !22_S	et	f	\N
204112	pahupool	pahupool =pool  (ID  >pahu+pool !41_DK	et	f	\N
204113	pahupool	pahupool =pool  (SgN  >pahu+pool !13_NS	et	f	\N
204114	pahupool	pahupool =pool  (SgN  >pahu+pool !22_S	et	f	\N
204115	kaugeltki	kaugeltki =kaugeltki  (ID  >kaugeltki !41_D	et	f	\N
204116	kaugeltki	kaugeltki =kauge  (SgAbl^  >kauge !01_A	et	f	\N
204117	kaugeltki	kaugeltki =kaugelt  (ID^  >kaugelt !41_D	et	f	\N
204118	kaugeltki	"kaugelt %kauge  )LT_mD^  <kauge ;01_A	et	f	\N
204173	korporatiivsel	?korporatiivsel =korporatiivse  (SgAd  >korporatiivne !02_A	et	f	\N
204174	korporatiivsel	?korporatiivsel =korporatiivse  (PlAd  >korporatiivs !22_S	et	f	\N
204175	korporatiivsel	?korporatiivsel =korporatiivsel  (SgN  >korporatiivsel !02_S	et	f	\N
204179	ettevõttete	?ettevõttete =võtte  (PlG  >ette+võtte !06_S	et	f	\N
204190	tarbijate	tarbijate =tarbija  (PlG  >tarbija !01_S	et	f	\N
204191	tarbijate	"tarbija %tarbi  )JA_vS  <tarbima ;27_V	et	f	\N
204201	sooviksime	sooviksime =soovi  (KndPrPl1  >soovima !28_V	et	f	\N
204202	sooviksime	sooviksime =ime  (SgN  >soov+iks+ime !16_S	et	f	\N
204203	sooviksime	sooviksime =ime  (SgG  >soov+iks+ime !16_S	et	f	\N
204208	innustavas	innustavas =innustava  (SgIn  >innustav !02_A	et	f	\N
204209	innustavas	"innustav %innusta  )V_vA  <innustama ;27_V	et	f	\N
204215	infoühiskonnaga	infoühiskonnaga =konna  (SgKom  >info+ühis+konn !22_S	et	f	\N
204216	infoühiskonnaga	infoühiskonnaga =ühiskonna  (SgKom  >info+ühiskond !22_S	et	f	\N
204236	äri-	äri- =äri  (SgN  >äri !17_S	et	f	\N
204237	äri-	äri- =äri  (SgG  >äri !17_S	et	f	\N
204238	äri-	äri- =äri  (SgP  >äri !17_S	et	f	\N
204239	eetevõtte	?eetevõtte =eetevõtte  (PlP  >eetevõtt !22_S	et	f	\N
204247	normaalsem	normaalsem =normaalsem  (SgN  >normaalsem !02_A	et	f	\N
204248	normaalsem	"normaalsem %normaalse  )M_cA  <normaalne ;02_A	et	f	\N
204263	massiühikonnas	?massiühikonnas =massiühikonna  (SgIn  >massiühikonna !16_S	et	f	\N
204264	massiühikonnas	?massiühikonnas =massiühikonna  (SgIn  >massiühikond !22_S	et	f	\N
204265	massiühikonnas	?massiühikonnas =ühikonna  (SgIn  >massi+ühikonna !16_S	et	f	\N
204266	massiühikonnas	?massiühikonnas =ühikonna  (SgIn  >massi+ühikond !22_S	et	f	\N
204277	tooteesitleja	tooteesitleja =esitleja  (SgN  >toote+esitleja !01_S	et	f	\N
204278	tooteesitleja	tooteesitleja =esitleja  (SgG  >toote+esitleja !01_S	et	f	\N
204304	normaalsemat	normaalsemat =normaalsema  (SgP  >normaalsem !02_A	et	f	\N
204305	normaalsemat	"normaalsem %normaalse  )M_cA  <normaalne ;02_A	et	f	\N
204336	arvamustest	arvamustest =arvamus  (PlEl  >arvamus !11_S	et	f	\N
204337	arvamustest	arvamustest =test  (SgN  >arvamus+test !22_S	et	f	\N
204357	müügimuskonnale	?müügimuskonnale =müügimuskonna  (SgAll  >müügimuskonna !16_S	et	f	\N
204358	müügimuskonnale	?müügimuskonnale =müügimuskonna  (SgAll  >müügimuskond !22_S	et	f	\N
204359	müügimuskonnale	?müügimuskonnale =muskonna  (SgAll  >müügi+muskonna !16_S	et	f	\N
204360	müügimuskonnale	?müügimuskonnale =muskonna  (SgAll  >müügi+muskond !22_S	et	f	\N
204367	tunustarude	### tunustarude	et	f	\N
204372	alustahedeks	?alustahedeks =stahe  (PlTr  >alu+stahe !16_S	et	f	\N
204374	kandmisel	kandmisel =kandmise  (SgAd  >kandmine !12?10_SA	et	f	\N
204375	kandmisel	"kandmine %kand  )MINE_vS  <kandma ;34_V	et	f	\N
204380	kliendidega	### kliendidega	et	f	\N
204400	siingi	siingi =siin  (ID^  >siin !41_D	et	f	\N
204401	siingi	siingi =siin  (SgN^  >siin !22_S	et	f	\N
204402	kuuluvatest	kuuluvatest =kuuluva  (PlEl  >kuuluv !02_A	et	f	\N
204403	kuuluvatest	"kuuluv %kuulu  )V_vA  <kuuluma ;27_V	et	f	\N
204404	kuuluvatest	kuuluvatest =vate  (PlEl  >kuulu+vatt !22_S	et	f	\N
204405	rahakulutuse	rahakulutuse =kulutuse  (SgG  >raha+kulutus !11_S	et	f	\N
204406	rahakulutuse	"raha+kulutus %kulu  )TUS2_aS  <raha+kulu ;17_S	et	f	\N
204407	rahakulutuse	"raha+kulutus %kulu  )TUS2_aS  <raha+kulg ;22_S	et	f	\N
204415	turundusosakonna	turundusosakonna =konna  (SgG  >turundus+osa+konn !22_S	et	f	\N
204416	turundusosakonna	turundusosakonna =konna  (SgP  >turundus+osa+konn !22_S	et	f	\N
204417	turundusosakonna	turundusosakonna =konna  (SgAdt  >turundus+osa+konn !22_S	et	f	\N
204418	turundusosakonna	turundusosakonna =osakonna  (SgG  >turundus+osakond !22_S	et	f	\N
204448	töötavaid	töötavaid =töötava  (PlP  >töötav !02_A	et	f	\N
204449	töötavaid	"töötav %tööta  )V_vA  <töötama ;27_V	et	f	\N
204455	eksisteeris	eksisteeris =eksisteeri  (IndIpfSg3  >eksisteerima !28_V	et	f	\N
204456	eksisteeris	eksisteeris =eri  (SgIn  >eks+iste+eri !17_S	et	f	\N
204457	eksisteeris	eksisteeris =steeri  (SgIn  >eksi+steer !22_S	et	f	\N
204485	aastapikkuse	aastapikkuse =pikkuse  (SgG  >aasta+pikkus !11~09_S	et	f	\N
204486	aastapikkuse	"aasta+pikkus %pikk  )US_aS  <aasta+pikk ;22_AS	et	f	\N
204145	eestitseerumisse	?eestitseerumisse =itseerumi  (SgIll  >eest+itseerum !02_S	et	f	\N
204146	eestitseerumisse	?eestitseerumisse =itseerumis  (SgAdt  >eest+itseerumine !12_S	et	f	\N
204147	eestitseerumisse	?eestitseerumisse =itseerumisse  (SgG  >eest+itseerumisne !02_A	et	f	\N
204148	eestitseerumisse	?eestitseerumisse =itseerumisse  (PlP  >eest+itseerumiss !22_S	et	f	\N
204149	eestitseerumisse	?eestitseerumisse =titseerumi  (SgIll  >ees+titseerum !02_S	et	f	\N
204150	eestitseerumisse	?eestitseerumisse =titseerumis  (SgAdt  >ees+titseerumine !12_S	et	f	\N
204151	eestitseerumisse	?eestitseerumisse =titseerumisse  (SgG  >ees+titseerumisne !02_A	et	f	\N
204152	eestitseerumisse	?eestitseerumisse =titseerumisse  (PlP  >ees+titseerumiss !22_S	et	f	\N
204163	harmooniliselt	harmooniliselt =harmoonilise  (SgAbl  >harmooniline !12_A	et	f	\N
204164	harmooniliselt	harmooniliselt =harmooniliselt  (ID  >harmooniliselt !41_D	et	f	\N
204165	harmooniliselt	"harmooniliselt %harmoonilise  )LT_mD  <harmooniline ;12_A	et	f	\N
204166	korporatiivne	?korporatiivne =korporatiivne  (SgN  >korporatiivne !02_A	et	f	\N
204167	korporatiivne	?korporatiivne =korporatiivne  (PlP  >korporatiivn !22_S	et	f	\N
204168	riigiasutus	riigiasutus =asutu  (SgIn  >riigi+asutu !01_AS	et	f	\N
204169	riigiasutus	"riigi+asutu %asu  )TU2_kA  <riigi+asu ;17_S	et	f	\N
204170	riigiasutus	riigiasutus =asutus  (SgN  >riigi+asutus !11_S	et	f	\N
204171	riigiasutus	"riigi+asutus %asu  )TUS2_aS  <riigi+asu ;17_S	et	f	\N
204181	teenimiseks	teenimiseks =teenimise  (SgTr  >teenimine !12_S	et	f	\N
204182	teenimiseks	"teenimine %teeni  )MINE_vS  <teenima ;28_V	et	f	\N
204183	teenimiseks	teenimiseks =seks  (SgN  >tee+nimi+seks !22_S	et	f	\N
204192	tegevusel	tegevusel =tegevuse  (SgAd  >tegevus !11_S	et	f	\N
204193	tegevusel	"tegevus %tege  )VUS_aS  <tegema ;28_V	et	f	\N
204194	tegevusel	"tegevus %tegeva  )US_aS  <tegev ;02_A	et	f	\N
204195	tegevusel	tegevusel =use  (PlAd  >tegev+usk !22_S	et	f	\N
204226	selekteerimise	selekteerimise =selekteerimise  (SgG  >selekteerimine !12_S	et	f	\N
204227	selekteerimise	"selekteerimine %selekteeri  )MINE_vS  <selekteerima ;28_V	et	f	\N
204231	peituvaid	peituvaid =peituva  (PlP  >peituv !02_A	et	f	\N
204232	peituvaid	"peituv %peitu  )V_vA  <peituma ;27_V	et	f	\N
204261	muretse	muretse =muretse  (IndPrPs_  >muretsema !27_V	et	f	\N
204262	muretse	muretse =muretse  (ImpPrSg2  >muretsema !27_V	et	f	\N
204286	müügi-	müügi- =müügi  (SgG  >müük !22_S	et	f	\N
204287	müügi-	müügi- =müü  (SgN^  >müü !26_S	et	f	\N
204288	müügi-	müügi- =müü  (SgG^  >müü !26_S	et	f	\N
204289	müügi-	müügi- =müü  (IndPrPs_^  >müüma !38_V	et	f	\N
204290	müügi-	müügi- =müü  (ImpPrSg2^  >müüma !38_V	et	f	\N
204309	kohutavalt	kohutavalt =kohutava  (SgAbl  >kohutav !02_A	et	f	\N
204310	kohutavalt	"kohutav %kohu  )TAV_vAS  <kohuma ;27_V	et	f	\N
204311	kohutavalt	"kohutav %kohuta  )V_vA  <kohutama ;27_V	et	f	\N
204312	kohutavalt	kohutavalt =kohutavalt  (ID  >kohutavalt !41_D	et	f	\N
204313	kohutavalt	"kohutavalt %kohu  )TAVALT_mD  <kohuma ;27_V	et	f	\N
204314	kohutavalt	"kohutavalt %kohuta  )VALT_mD  <kohutama ;27_V	et	f	\N
204315	kohutavalt	"kohutavalt %kohutava  )LT_mD  <kohutav ;02_A	et	f	\N
204316	kohutavalt	kohutavalt =tava  (SgAbl  >kohu+tava !17_S	et	f	\N
204323	ameerikani	?ameerikani =ameerika  (SgTer  >ameerikas !02_A	et	f	\N
204324	ameerikani	?ameerikani =ameerikani  (SgG  >ameerikan !19_S	et	f	\N
204325	ameerikani	?ameerikani =ameerikani  (SgP  >ameerikan !19_S	et	f	\N
204326	ameerikani	?ameerikani =ameerikani  (SgAdt  >ameerikan !19_S	et	f	\N
204332	mittenormaalseteks	mittenormaalseteks =sete  (PlTr  >mitte+normaal+sett !22_S	et	f	\N
204333	mittenormaalseteks	mittenormaalseteks =normaalse  (PlTr  >mitte+normaalne !02_A	et	f	\N
204349	muutmisel	muutmisel =muutmise  (SgAd  >muutmine !12?10_S	et	f	\N
204350	muutmisel	"muutmine %muut  )MINE_vS  <muutma ;34_V	et	f	\N
204373	sloganit	?sloganit =slogani  (SgP  >slogan !02_S	et	f	\N
204390	eesnõrkudest	?eesnõrkudest =eesnõrkudes  (SgP  >eesnõrkudene !12_A	et	f	\N
204391	eesnõrkudest	?eesnõrkudest =nõrku  (PlEl  >ees+nõrku !16_S	et	f	\N
204392	eesnõrkudest	?eesnõrkudest =nõrkudes  (SgP  >ees+nõrkudene !12_A	et	f	\N
204396	süüvudes	?süüvudes =süüvu  (PlIn  >süüvu !16_S	et	f	\N
204397	süüvudes	?süüvudes =süüvu  (Ger  >süüvuma !27_V	et	f	\N
204398	süüvudes	?süüvudes =vude  (SgIn  >süü+vude !16_S	et	f	\N
204399	süüvudes	?süüvudes =vudes  (SgN  >süü+vudes !09_S	et	f	\N
204408	istet	istet =iste  (SgP  >iste !05_S	et	f	\N
204409	istet	istet =iste  (SgP  >iste !06_S	et	f	\N
204423	vajava	vajava =vajava  (SgG  >vajav !02_A	et	f	\N
204424	vajava	"vajav %vaja  )V_vA  <vajama ;27_V	et	f	\N
204432	pandiks	pandiks =pandi  (SgTr  >pant !22_S	et	f	\N
204433	pandiks	pandiks =pandi  (KndPrPs  >pantima !28_V	et	f	\N
204434	mõistest	mõistest =mõiste  (SgEl  >mõiste !06_S	et	f	\N
204435	mõistest	mõistest =mõiste  (PlEl  >mõist !22_S	et	f	\N
204436	mõistest	mõistest =mõistes  (SgP  >mõistene !12~10_A	et	f	\N
204437	mõistest	"mõistene %mõiste  )NE_aA  <mõiste ;06_S	et	f	\N
204440	k-poliitika	k-poliitika =poliitika  (SgN  >k-poliitika !01_S	et	f	\N
204441	k-poliitika	k-poliitika =poliitika  (SgG  >k-poliitika !01_S	et	f	\N
204458	brände	?brände =brände  (SgN  >brände !06_S	et	f	\N
204271	aktsepteeritud	"aktsepteeritud %aktsepteeri  )TUD_vA  <aktsepteerima ;28_V	et	f	\N
204293	võlusid	võlusid =võlu  (PlP  >võlu !17_S	et	f	\N
204294	võlusid	võlusid =võlu  (IndIpfSg2  >võluma !27_V	et	f	\N
204295	võlusid	võlusid =võlu  (IndIpfPl3  >võluma !27_V	et	f	\N
204319	backpackusid	?backpackusid =backpacku  (IndIpfSg2  >backpackuma !27_V	et	f	\N
204320	backpackusid	?backpackusid =backpacku  (IndIpfPl3  >backpackuma !27_V	et	f	\N
204330	normaalseteks	normaalseteks =normaalse  (PlTr  >normaalne !02_A	et	f	\N
204331	normaalseteks	normaalseteks =sete  (PlTr  >normaal+sett !22_S	et	f	\N
204338	henzbergki	?henzbergki =henzbergki  (SgG  >henzbergk !22_S	et	f	\N
204339	henzbergki	?henzbergki =henzbergki  (SgP  >henzbergk !22_S	et	f	\N
204340	henzbergki	?henzbergki =henzbergki  (SgAdt  >henzbergk !22_S	et	f	\N
204341	henzbergki	?henzbergki =henzbergki  (IndPrPs_  >henzbergkima !28_V	et	f	\N
204342	henzbergki	?henzbergki =henzbergki  (ImpPrSg2  >henzbergkima !28_V	et	f	\N
204343	henzbergki	?henzbergki =henzberg  (SgN^  >henzberg !02_S	et	f	\N
204348	kannapöörde	?kannapöörde =kannapöörde  (PlP  >kannapöörd !22_S	et	f	\N
204351	töötunde	töötunde =tunde  (SgG  >töö+tunne !06_S	et	f	\N
204352	töötunde	töötunde =tunde  (PlP  >töö+tund !22_S	et	f	\N
204353	tunitud	?tunitud =tuni  (PtsPtIps  >tunima !27_V	et	f	\N
204354	tunitud	?tunitud =tunitu  (PlN  >tunitu !01_AS	et	f	\N
204355	tunitud	?tunitud =tunitu  (IndPrSg2  >tunituma !27_V	et	f	\N
204356	tunitud	?tunitud =tunitud  (ID  >tunitud !41_A	et	f	\N
204361	pankasse	pankasse =panka  (SgIll  >pangas !07_S	et	f	\N
204362	pankasse	pankasse =pankas  (SgAdt  >pankane !12_A	et	f	\N
204363	pankasse	"pankane %panka  )NE_aA  <pangas ;07_S	et	f	\N
204378	omavahelist	omavahelist =vahelis  (SgP  >oma+vaheline !12_A	et	f	\N
204379	omavahelist	"oma+vaheline %vahe  )LINE_aA  <oma+vahe ;16_S	et	f	\N
204387	osuseid	?osuseid =osuse  (PlP  >osus !09_S	et	f	\N
204388	osuseid	?osuseid =osusei  (PlN  >osusei !26_S	et	f	\N
204389	osuseid	?osuseid =osusei  (SgP  >osusei !26_S	et	f	\N
204394	lähenemisse	lähenemisse =lähenemis  (SgAdt  >lähenemine !12_S	et	f	\N
204395	lähenemisse	"lähenemine %lähene  )MINE_vS  <lähenema ;27_V	et	f	\N
204419	arendamisel	arendamisel =arendamise  (SgAd  >arendamine !12_S	et	f	\N
204420	arendamisel	"arendamine %arenda  )MINE_vS  <arendama ;27_V	et	f	\N
204425	valdkonnaga	valdkonnaga =valdkonna  (SgKom  >valdkond !22_S	et	f	\N
204426	valdkonnaga	valdkonnaga =konna  (SgKom  >vald+konn !22_S	et	f	\N
204438	oravapartei	oravapartei =partei  (SgN  >orava+partei !26_S	et	f	\N
204439	oravapartei	oravapartei =partei  (SgG  >orava+partei !26_S	et	f	\N
204452	varjatumal	varjatumal =varjatuma  (SgAd  >varjatum !02_A	et	f	\N
204453	varjatumal	"varjatum %varja  )TUM1_cA  <varjama ;29_V	et	f	\N
204454	varjatumal	"varjatum %varja  )TUM2_cA  <vari ;24_S	et	f	\N
204469	eristuv	eristuv =eristu  (PtsPrPs  >eristuma !27_V	et	f	\N
204470	eristuv	eristuv =eristuv  (SgN  >eristuv !02_A	et	f	\N
204471	eristuv	"eristuv %eristu  )V_vA  <eristuma ;27_V	et	f	\N
204481	kujundamisega	kujundamisega =kujundamise  (SgKom  >kujundamine !12_S	et	f	\N
204482	kujundamisega	"kujundamine %kujunda  )MINE_vS  <kujundama ;27_V	et	f	\N
204483	endasarnaste	endasarnaste =sarnas  (PlG  >enda+sarnane !10_A	et	f	\N
204484	endasarnaste	"enda+sarnane %sarna  )NE_aA  <enda+sarn ;22_S	et	f	\N
204492	muutmiseks	muutmiseks =muutmise  (SgTr  >muutmine !12?10_S	et	f	\N
204493	muutmiseks	"muutmine %muut  )MINE_vS  <muutma ;34_V	et	f	\N
204494	korporatiivselt	?korporatiivselt =korporatiivse  (SgAbl  >korporatiivne !02_A	et	f	\N
204495	korporatiivselt	?korporatiivselt =korporatiivse  (PlAbl  >korporatiivs !22_S	et	f	\N
204496	korporatiivselt	?korporatiivselt =korporatiivselt  (ID  >korporatiivselt !41_D	et	f	\N
204514	agresiivsema	?agresiivsema =agresiivsema  (SgG  >agresiivsem !02_A	et	f	\N
204521	peegeldajaks	peegeldajaks =peegeldaja  (SgTr  >peegeldaja !01_S	et	f	\N
204522	peegeldajaks	"peegeldaja %peegelda  )JA_vS  <peegeldama ;27_V	et	f	\N
204526	tungitud	tungitud =tungi  (PtsPtIps  >tungima !28_V	et	f	\N
204527	tungitud	tungitud =tungitu  (PlN  >tungitu !01_AS	et	f	\N
204528	tungitud	"tungitu %tungi  )TU1_vS  <tungima ;28_V	et	f	\N
204529	tungitud	"tungitu %tungi  )TU2_kA  <tung ;22_S	et	f	\N
204530	tungitud	tungitud =tungitud  (ID  >tungitud !41_A	et	f	\N
204531	tungitud	"tungitud %tungi  )TUD_vA  <tungima ;28_V	et	f	\N
204543	järjepidevalt	järjepidevalt =pideva  (SgAbl  >järje+pidev !02_A	et	f	\N
204544	järjepidevalt	"järje+pidevalt %pideva  )LT_mD  <järje+pidev ;02_A	et	f	\N
204561	põhineva	põhineva =põhineva  (SgG  >põhinev !02_A	et	f	\N
204562	põhineva	"põhinev %põhine  )V_vA  <põhinema ;27_V	et	f	\N
204572	ilmsemaid	ilmsemaid =ilmsema  (PlP  >ilmsem !02_A	et	f	\N
204573	ilmsemaid	"ilmsem %ilmse  )M_cA  <ilmne ;02_A	et	f	\N
204597	kangutamiseks	kangutamiseks =kangutamise  (SgTr  >kangutamine !12_S	et	f	\N
204598	kangutamiseks	"kangutamine %kanguta  )MINE_vS  <kangutama ;27_V	et	f	\N
204634	põlised	põlised =põlise  (PlN  >põline !10_A	et	f	\N
204635	põlised	"põline %põli  )NE_aA  <põli ;24_S	et	f	\N
204636	määratlevad	määratlevad =määratle  (IndPrPl3  >määratlema !27_V	et	f	\N
204637	määratlevad	määratlevad =määratleva  (PlN  >määratlev !02_A	et	f	\N
204377	kandmisega	"kandmine %kand  )MINE_vS  <kandma ;34_V	et	f	\N
204381	lõpegi	lõpegi =lõpe  (SgN^  >lõpe !05_S	et	f	\N
204382	lõpegi	lõpegi =lõpe  (SgN^  >lõpe !06_S	et	f	\N
204383	lõpegi	lõpegi =lõpe  (IndPrPs_^  >lõppema !28_V	et	f	\N
204384	lõpegi	lõpegi =lõpe  (IndPrPs_^  >lõpma !35_V	et	f	\N
204385	lõpegi	lõpegi =lõpe  (ImpPrSg2^  >lõppema !28_V	et	f	\N
204386	lõpegi	lõpegi =lõpe  (ImpPrSg2^  >lõpma !35_V	et	f	\N
204393	ekisteerimiseks	?ekisteerimiseks =ekisteerimise  (SgTr  >ekisteerimine !12_S	et	f	\N
204410	sarnastele	sarnastele =sarnas  (PlAll  >sarnane !10_A	et	f	\N
204411	sarnastele	"sarnane %sarna  )NE_aA  <sarn ;22_S	et	f	\N
204421	panustamist	panustamist =panustamis  (SgP  >panustamine !12_S	et	f	\N
204422	panustamist	"panustamine %panusta  )MINE_vS  <panustama ;27_V	et	f	\N
204427	ühtekuuluvuse	ühtekuuluvuse =kuuluvuse  (SgG  >ühte+kuuluvus !11_S	et	f	\N
204428	ühtekuuluvuse	"ühte+kuuluvus %kuuluva  )US_aS  <ühte+kuuluv ;02_A	et	f	\N
204429	järjepidevale	järjepidevale =vale  (SgN  >järje+pide+vale !16_SA	et	f	\N
204430	järjepidevale	järjepidevale =vale  (SgG  >järje+pide+vale !16_SA	et	f	\N
204431	järjepidevale	järjepidevale =pideva  (SgAll  >järje+pidev !02_A	et	f	\N
204446	brändi	brändi =brändi  (SgN  >brändi !16_S	et	f	\N
204447	brändi	brändi =brändi  (SgG  >brändi !16_S	et	f	\N
204450	nähtusega	nähtusega =nähtuse  (SgKom  >nähtus !11~09_S	et	f	\N
204451	nähtusega	"nähtus %näh  )TUS1_aS  <nägema ;28_V	et	f	\N
204463	adidas	### adidas	et	f	\N
204464	eelistatud	eelistatud =eelista  (PtsPtIps  >eelistama !27_V	et	f	\N
204465	eelistatud	eelistatud =eelistatu  (PlN  >eelistatu !01_S	et	f	\N
204466	eelistatud	"eelistatu %eelista  )TU1_vS  <eelistama ;27_V	et	f	\N
204467	eelistatud	eelistatud =eelistatud  (ID  >eelistatud !41_A	et	f	\N
204468	eelistatud	"eelistatud %eelista  )TUD_vA  <eelistama ;27_V	et	f	\N
204477	loomis	loomis =loomi  (SgIn  >loom !22_S	et	f	\N
204478	loomis	loomis =loomi  (PlIn  >loom !22_S	et	f	\N
204479	loomis	loomis =loomis  (SgN  >loomis !09_S	et	f	\N
204480	loomis	loomis =mi  (SgIn  >loo+mi !26_S	et	f	\N
204499	tööealine	tööealine =ealine  (SgN  >töö+ealine !12?10_A	et	f	\N
204500	tööealine	"töö+ealine %ea  )LINE_aA  <töö+iga ;18_S	et	f	\N
204509	nooremaid	nooremaid =noorema  (PlP  >noorem !02_A	et	f	\N
204510	nooremaid	"noorem %noore  )M_cA  <noor ;13_AS	et	f	\N
204511	nooremaid	nooremaid =ma  (PlP  >noore+maa !26_S	et	f	\N
204512	nooremaid	nooremaid =mai  (PlN  >noore+mai !26_S	et	f	\N
204513	nooremaid	nooremaid =mai  (SgP  >noore+mai !26_S	et	f	\N
204545	tegutsemisstrateegia	tegutsemisstrateegia =strateegia  (SgN  >tegutsemis+strateegia !01_S	et	f	\N
204546	tegutsemisstrateegia	tegutsemisstrateegia =strateegia  (SgG  >tegutsemis+strateegia !01_S	et	f	\N
204577	keskendumine	keskendumine =keskendumine  (SgN  >keskendumine !12_S	et	f	\N
204578	keskendumine	"keskendumine %keskendu  )MINE_vS  <keskenduma ;27_V	et	f	\N
204584	osalus	osalus =osalus  (SgN  >osalus !11_S	et	f	\N
204585	osalus	"osalus %osale  )US_vS  <osalema ;27_V	et	f	\N
204643	üllataval	üllataval =üllatava  (SgAd  >üllatav !02_A	et	f	\N
204644	üllataval	"üllatav %üllata  )V_vA  <üllatama ;27_V	et	f	\N
204645	üllataval	üllataval =tava  (SgAd  >ülla+tava !17_S	et	f	\N
204655	isapuhkust	isapuhkust =us  (SgP  >isa+puhk+uks !14_S	et	f	\N
204656	isapuhkust	isapuhkust =puhkus  (SgP  >isa+puhkus !11~09_S	et	f	\N
204664	teisenemisega	teisenemisega =teisenemise  (SgKom  >teisenemine !12_S	et	f	\N
204665	teisenemisega	"teisenemine %teisene  )MINE_vS  <teisenema ;27_V	et	f	\N
204666	tühiseks	tühiseks =tühise  (SgTr  >tühine !10_A	et	f	\N
204667	tühiseks	"tühine %tühi  )NE_aA  <tühi ;24_A	et	f	\N
204668	tühiseks	tühiseks =seks  (SgN  >tühi+seks !22_S	et	f	\N
204696	blogides	?blogides =blogi  (PlIn  >blogi !17_S	et	f	\N
204697	blogides	?blogides =blogi  (Ger  >blogima !27_V	et	f	\N
204707	jaatavalt	jaatavalt =jaatava  (SgAbl  >jaatav !02_A	et	f	\N
204708	jaatavalt	"jaatav %jaata  )V_vA  <jaatama ;27_V	et	f	\N
204709	jaatavalt	jaatavalt =jaatavalt  (ID  >jaatavalt !41_D	et	f	\N
204710	jaatavalt	"jaatavalt %jaata  )VALT_mD  <jaatama ;27_V	et	f	\N
204711	jaatavalt	"jaatavalt %jaatava  )LT_mD  <jaatav ;02_A	et	f	\N
204723	internetikommentaariumites	?internetikommentaariumites =internetikommentaariumi  (PlIn  >internetikommentaarium !02_S	et	f	\N
204724	internetikommentaariumites	?internetikommentaariumites =internetikommentaariumite  (PlIn  >internetikommentaariumitt !22_S	et	f	\N
204725	internetikommentaariumites	?internetikommentaariumites =umite  (PlIn  >interneti+kommentaari+umitt !22_S	et	f	\N
204726	internetikommentaariumites	?internetikommentaariumites =mentaariumi  (PlIn  >interneti+kom+mentaarium !02_S	et	f	\N
204727	internetikommentaariumites	?internetikommentaariumites =mentaariumite  (PlIn  >interneti+kom+mentaariumitt !22_S	et	f	\N
204728	internetikommentaariumites	?internetikommentaariumites =kommentaariumi  (PlIn  >interneti+kommentaarium !02_S	et	f	\N
204729	internetikommentaariumites	?internetikommentaariumites =kommentaariumite  (PlIn  >interneti+kommentaariumitt !22_S	et	f	\N
204730	internetikommentaariumites	?internetikommentaariumites =netikommentaariumi  (PlIn  >inter+netikommentaarium !02_S	et	f	\N
204731	internetikommentaariumites	?internetikommentaariumites =netikommentaariumite  (PlIn  >inter+netikommentaariumitt !22_S	et	f	\N
204413	järeldustele	"järeldus %järelda  )US_vS  <järeldama ;27_V	et	f	\N
204414	järeldustele	järeldustele =duste  (PlAll  >järel+dust !22_S	et	f	\N
204442	möelda	?möelda =möelda  (SgN  >möelda !01_S	et	f	\N
204443	möelda	?möelda =möelda  (SgG  >möelda !01_S	et	f	\N
204444	möelda	?möelda =möelda  (IndPrPs_  >möeldama !27_V	et	f	\N
204445	möelda	?möelda =möelda  (ImpPrSg2  >möeldama !27_V	et	f	\N
204488	hindamiseks	hindamiseks =hindamise  (SgTr  >hindamine !12_S	et	f	\N
204489	hindamiseks	"hindamine %hinda  )MINE_vS  <hindama ;29_V	et	f	\N
204501	lähemistee	?lähemistee =lähemistee  (SgN  >lähemistee !26_S	et	f	\N
204502	lähemistee	?lähemistee =lähemistee  (SgG  >lähemistee !26_S	et	f	\N
204515	lähenemisega	lähenemisega =lähenemise  (SgKom  >lähenemine !12_S	et	f	\N
204516	lähenemisega	"lähenemine %lähene  )MINE_vS  <lähenema ;27_V	et	f	\N
204536	rõhutamisega	rõhutamisega =rõhutamise  (SgKom  >rõhutamine !12_S	et	f	\N
204537	rõhutamisega	"rõhutamine %rõhuta  )MINE_vS  <rõhutama ;27_V	et	f	\N
204547	lahkamisel	lahkamisel =lahkamise  (SgAd  >lahkamine !12_S	et	f	\N
204548	lahkamisel	"lahkamine %lahka  )MINE_vS  <lahkama ;29_V	et	f	\N
204549	lahkamisel	"lahkamine %lahkami  )NE_aA  <lahkam ;02_S	et	f	\N
204557	ühikondlike	?ühikondlike =ühikondlike  (SgN  >ühikondlike !12_S	et	f	\N
204558	ühikondlike	?ühikondlike =ühikondlike  (PlG  >ühikondlik !25_A	et	f	\N
204563	jaotusega	jaotusega =jaotuse  (SgKom  >jaotus !11~09_S	et	f	\N
204564	jaotusega	"jaotus %jaota  )US_vS  <jaotama ;27_V	et	f	\N
204565	jaotusega	"jaotus %jao  )TUS2_aS  <jagu ;18_S	et	f	\N
204566	väär	väär =väär  (SgN  >väär !02_A	et	f	\N
204567	väär	väär =väär  (SgN  >väär !22_S	et	f	\N
204568	väär	väär =väär  (SgN  >väär !22_A	et	f	\N
204581	standardid	standardid =standardi  (PlN  >standard !02_S	et	f	\N
204582	standardid	standardid =standardi  (PlN  >standart !22_S	et	f	\N
204583	standardid	standardid =standardi  (IndPrSg2  >standardima !28_V	et	f	\N
204614	reguleerijana	reguleerijana =reguleerija  (SgEs  >reguleerija !01_S	et	f	\N
204615	reguleerijana	"reguleerija %reguleeri  )JA_vS  <reguleerima ;28_V	et	f	\N
204621	jagamisel	jagamisel =jagamise  (SgAd  >jagamine !12_S	et	f	\N
204622	jagamisel	"jagamine %jaga  )MINE_vS  <jagama ;27_V	et	f	\N
204623	maikugi	maikugi =maiku  (SgP^  >maik !22_S	et	f	\N
204624	maikugi	maikugi =maiku  (SgAdt^  >maik !22_S	et	f	\N
204652	häbenemata	häbenemata =häbene  (SupAb  >häbenema !27_V	et	f	\N
204653	häbenemata	häbenemata =häbenemata  (ID  >häbenemata !41_A	et	f	\N
204654	häbenemata	"häbenemata %häbene  )MATA_vA  <häbenema ;27_V	et	f	\N
204675	rõhutama	rõhutama =rõhu  (SupIps  >rõhuma !27_V	et	f	\N
204676	rõhutama	rõhutama =rõhuta  (Sup  >rõhutama !27_V	et	f	\N
204750	maailmapildi	maailmapildi =pildi  (SgG  >maa+ilma+pilt !22_S	et	f	\N
204751	maailmapildi	maailmapildi =pildi  (SgP  >maa+ilma+pild !22_S	et	f	\N
204753	maailmapildi	maailmapildi =pildi  (SgAdt  >maa+ilma+pild !22_S	et	f	\N
204757	solvavad	solvavad =solva  (IndPrPl3  >solvama !29_V	et	f	\N
204758	solvavad	solvavad =solvava  (PlN  >solvav !02_A	et	f	\N
204759	solvavad	"solvav %solva  )V_vA  <solvama ;29_V	et	f	\N
204764	teemasse	teemasse =teema  (SgIll  >teema !16_S	et	f	\N
204765	teemasse	teemasse =masse  (PlP  >tee+mass !22_S	et	f	\N
204769	elavates	elavates =elava  (PlIn  >elav !02_A	et	f	\N
204770	elavates	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
204771	elavates	elavates =ate  (PlIn  >elav+att !22_S	et	f	\N
204783	telekanaleid	telekanaleid =lei  (PlN  >tele+kana+lei !26_S	et	f	\N
204784	telekanaleid	telekanaleid =lei  (SgP  >tele+kana+lei !26_S	et	f	\N
204785	telekanaleid	telekanaleid =leid  (SgN  >tele+kana+leid !22_S	et	f	\N
204786	telekanaleid	telekanaleid =kanale  (PlP  >tele+kanal !02_S	et	f	\N
204803	omanud	omanud =oma  (PtsPtPs  >omama !27_V	et	f	\N
204804	omanud	omanud =omanu  (PlN  >omanu !01_S	et	f	\N
204805	omanud	"omanu %oma  )NU_vS  <omama ;27_V	et	f	\N
204806	omanud	omanud =omanud  (ID  >omanud !41_A	et	f	\N
204807	omanud	"omanud %oma  )NUD_vA  <omama ;27_V	et	f	\N
204816	potensiaalset	?potensiaalset =potensiaalse  (SgP  >potensiaalne !02_A	et	f	\N
204817	kajastu	kajastu =kajastu  (IndPrPs_  >kajastuma !27_V	et	f	\N
204818	kajastu	kajastu =kajastu  (ImpPrSg2  >kajastuma !27_V	et	f	\N
204825	uskumatumal	uskumatumal =uskumatuma  (SgAd  >uskumatum !02_A	et	f	\N
204826	uskumatumal	"uskumatum %usku  )MATUM_cA  <uskuma ;28_V	et	f	\N
204827	uskumatumal	"uskumatum %uskumatu  )M_cA  <uskumatu ;01_A	et	f	\N
204830	haaravad	haaravad =haara  (IndPrPl3  >haarama !29_V	et	f	\N
204831	haaravad	haaravad =haarava  (PlN  >haarav !02_A	et	f	\N
204832	haaravad	"haarav %haara  )V_vA  <haarama ;29_V	et	f	\N
204839	dimat	?dimat =dimat  (SgN  >dimat !02_S	et	f	\N
204846	hoole	hoole =hoo  (SgAll  >hoog !22_S	et	f	\N
204847	hoole	hoole =hoole  (SgN  >hoole !06_S	et	f	\N
204848	hoole	hoole =hoole  (SgG  >hool !13_S	et	f	\N
204852	osalenute	osalenute =osalenu  (PlG  >osalenu !01_S	et	f	\N
204854	osalenute	"osalenu %osale  )NU_vS  <osalema ;27_V	et	f	\N
204868	intriigitsejaid	intriigitsejaid =intriigitseja  (PlP  >intriigitseja !01_S	et	f	\N
204869	intriigitsejaid	"intriigitseja %intriigitse  )JA_vS  <intriigitsema ;27_V	et	f	\N
204459	brände	?brände =brände  (SgG  >bränne !06_S	et	f	\N
204460	brände	?brände =brände  (PlP  >bränd !22_S	et	f	\N
204461	brände	?brände =brände  (IndPrPs_  >brändema !27_V	et	f	\N
204462	brände	?brände =brände  (ImpPrSg2  >brändema !27_V	et	f	\N
204472	tegeldud	tegeldud =tegel  (PtsPtIps  >tegelema !31_V	et	f	\N
204473	tegeldud	tegeldud =tegeldu  (PlN  >tegeldu !01_S	et	f	\N
204474	tegeldud	"tegeldu %tegel  )TU1_vS  <tegelema ;31_V	et	f	\N
204475	tegeldud	tegeldud =tegeldud  (ID  >tegeldud !41_A	et	f	\N
204476	tegeldud	"tegeldud %tegel  )TUD_vA  <tegelema ;31_V	et	f	\N
204490	kinnistamiseks	kinnistamiseks =kinnistamise  (SgTr  >kinnistamine !12_S	et	f	\N
204491	kinnistamiseks	"kinnistamine %kinnista  )MINE_vS  <kinnistama ;27_V	et	f	\N
204503	emt	?emt =emt  (SgN  >emt !22_S	et	f	\N
204506	juhtpositsiooni	juhtpositsiooni =positsiooni  (SgG  >juht+positsioon !22_S	et	f	\N
204507	juhtpositsiooni	juhtpositsiooni =positsiooni  (SgP  >juht+positsioon !22_S	et	f	\N
204508	juhtpositsiooni	juhtpositsiooni =positsiooni  (SgAdt  >juht+positsioon !22_S	et	f	\N
204519	teleyks	?teleyks =teleyks  (SgN  >teleyks !22_S	et	f	\N
204520	teleyks	?teleyks =yks  (SgN  >tele+yks !22_S	et	f	\N
204523	usaldusväärseimaks	usaldusväärseimaks =seima  (SgTr  >usaldus+väär+seim !22_S	et	f	\N
204524	usaldusväärseimaks	usaldusväärseimaks =väärseima  (SgTr  >usaldus+väärseim !02_A	et	f	\N
204525	usaldusväärseimaks	"usaldus+väärseim %väärse  )IM_sA  <usaldus+väärne ;02_A	et	f	\N
204534	eristumine	eristumine =eristumine  (SgN  >eristumine !12_S	et	f	\N
204535	eristumine	"eristumine %eristu  )MINE_vS  <eristuma ;27_V	et	f	\N
204550	aparatuuri	aparatuuri =aparatuuri  (SgG  >aparatuur !22_S	et	f	\N
204551	aparatuuri	aparatuuri =aparatuuri  (SgP  >aparatuur !22_S	et	f	\N
204552	aparatuuri	aparatuuri =aparatuuri  (SgAdt  >aparatuur !22_S	et	f	\N
204559	binaarsetel	binaarsetel =binaarse  (PlAd  >binaarne !02_A	et	f	\N
204560	binaarsetel	binaarsetel =sete  (PlAd  >binaar+sett !22_S	et	f	\N
204569	jaotusi	jaotusi =jaotusi  (PlP  >jaotus !11_S	et	f	\N
204570	jaotusi	"jaotus %jaota  )US_vS  <jaotama ;27_V	et	f	\N
204571	jaotusi	"jaotus %jao  )TUS2_aS  <jagu ;18_S	et	f	\N
204586	lõputult	lõputult =lõputu  (SgAbl  >lõputu !01_A	et	f	\N
204587	lõputult	"lõputu %lõpu  )TU2_kA  <lõpp ;22_SA	et	f	\N
204588	lõputult	lõputult =lõputult  (ID  >lõputult !41_D	et	f	\N
204589	lõputult	"lõputult %lõpu  )TULT2_mD  <lõpp ;22_SA	et	f	\N
204590	lõputult	"lõputult %lõputu  )LT_mD  <lõputu ;01_A	et	f	\N
204593	kehtestamist	kehtestamist =kehtestamis  (SgP  >kehtestamine !12_S	et	f	\N
204594	kehtestamist	"kehtestamine %kehtesta  )MINE_vS  <kehtestama ;27_V	et	f	\N
204599	määratumalt	määratumalt =määratuma  (SgAbl  >määratum !02_A	et	f	\N
204600	määratumalt	"määratum %määra  )TUM1_cA  <määrama ;29_V	et	f	\N
204601	määratumalt	"määratum %määra  )TUM2_cA  <määr ;22_S	et	f	\N
204602	määratumalt	"määratum %määratu  )M_cA  <määratu ;01_AS	et	f	\N
204603	määratumalt	määratumalt =määratumalt  (ID  >määratumalt !41_D	et	f	\N
204604	määratumalt	"määratumalt %määra  )TUMALT1_mD  <määrama ;29_V	et	f	\N
204605	määratumalt	"määratumalt %määra  )TUMALT2_mD  <määr ;22_S	et	f	\N
204606	määratumalt	"määratumalt %määratu  )MALT_mD  <määratu ;01_AS	et	f	\N
204607	väiksemaidki	väiksemaidki =väiksema  (PlP^  >väiksem !02_A	et	f	\N
204608	väiksemaidki	"väiksem %väikse  )M_cA^  <väike ;10_A	et	f	\N
204609	väiksemaidki	väiksemaidki =ma  (PlP^  >väikse+maa !26_S	et	f	\N
204610	väiksemaidki	väiksemaidki =mai  (PlN^  >väikse+mai !26_S	et	f	\N
204611	väiksemaidki	väiksemaidki =mai  (SgP^  >väikse+mai !26_S	et	f	\N
204616	ebaolulisemaks	ebaolulisemaks =olulisema  (SgTr  >eba+olulisem !02_A	et	f	\N
204617	ebaolulisemaks	"eba+olulisem %olu  )LISEM_cA  <eba+olu ;17_S	et	f	\N
204618	ebaolulisemaks	"eba+olulisem %olulise  )M_cA  <eba+oluline ;12_A	et	f	\N
204619	hankijana	hankijana =hankija  (SgEs  >hankija !01_S	et	f	\N
204620	hankijana	"hankija %hanki  )JA_vS  <hankima ;28_V	et	f	\N
204625	tammsaarelikus	?tammsaarelikus =tammsaareliku  (SgIn  >tammsaarelik !25_A	et	f	\N
204626	tammsaarelikus	?tammsaarelikus =tammsaareliku  (IndIpfSg3  >tammsaarelikuma !27_V	et	f	\N
204627	tammsaarelikus	?tammsaarelikus =tammsaarelikus  (SgN  >tammsaarelikus !11?09_S	et	f	\N
204629	tammsaarelikus	?tammsaarelikus =eliku  (SgIn  >tamm+saar+eliku !01_S	et	f	\N
204631	tammsaarelikus	?tammsaarelikus =elikus  (SgN  >tamm+saar+elikus !11_S	et	f	\N
204632	tammsaarelikus	?tammsaarelikus =saareliku  (SgIn  >tamm+saarelik !25_A	et	f	\N
204633	tammsaarelikus	?tammsaarelikus =saarelikus  (SgN  >tamm+saarelikus !11?09_S	et	f	\N
204641	kehtestajat	kehtestajat =kehtestaja  (SgP  >kehtestaja !01_S	et	f	\N
204642	kehtestajat	"kehtestaja %kehtesta  )JA_vS  <kehtestama ;27_V	et	f	\N
204662	igipõlistena	igipõlistena =põlis  (PlEs  >igi+põline !10_A	et	f	\N
204663	igipõlistena	"igi+põline %põli  )NE_aA  <igi+põli ;24_S	et	f	\N
204690	tõstatatud	tõstatatud =tõstata  (PtsPtIps  >tõstatama !27_V	et	f	\N
204691	tõstatatud	tõstatatud =tõstatatu  (PlN  >tõstatatu !01_S	et	f	\N
204692	tõstatatud	"tõstatatu %tõstata  )TU1_vS  <tõstatama ;27_V	et	f	\N
204693	tõstatatud	tõstatatud =tõstatatud  (ID  >tõstatatud !41_A	et	f	\N
204694	tõstatatud	"tõstatatud %tõstata  )TUD_vA  <tõstatama ;27_V	et	f	\N
204487	aastapikkuse	aastapikkuse =pikkuse  (SgG  >aasta+pikkune !12~10_A	et	f	\N
204497	identiteedilt	?identiteedilt =identiteedi  (SgAbl  >identiteedi !16_S	et	f	\N
204498	identiteedilt	?identiteedilt =identiteedi  (SgAbl  >identiteet !22_S	et	f	\N
204504	teenusepakkuja	teenusepakkuja =pakkuja  (SgN  >teenuse+pakkuja !01_S	et	f	\N
204505	teenusepakkuja	teenusepakkuja =pakkuja  (SgG  >teenuse+pakkuja !01_S	et	f	\N
204517	tele2	tele =tele  (SgN  >tele !16_S	et	f	\N
204518	tele2	tele =tele  (SgG  >tele !16_S	et	f	\N
204532	tugevaim	tugevaim =tugevaim  (SgN  >tugevaim !02_A	et	f	\N
204533	tugevaim	"tugevaim %tugeva  )IM_sA  <tugev ;02_A	et	f	\N
204538	väiksusest	väiksusest =väiksuse  (SgEl  >väiksus !11~09_S	et	f	\N
204539	väiksusest	"väiksus %väiks  )US_aS  <väike ;10_A	et	f	\N
204540	väiksusest	väiksusest =väiksuses  (SgP  >väiksusene !12_A	et	f	\N
204541	väiksusest	"väiksusene %väiksuse  )NE_aA  <väiksus ;09_S	et	f	\N
204542	väiksusest	"väiksusene %väiksuse  )NE_aA  <väiksus ;11_S	et	f	\N
204553	detailini	detailini =detaili  (SgTer  >detail !22_S	et	f	\N
204554	detailini	detailini =ini  (SgN  >detail+ini !17_S	et	f	\N
204555	detailini	detailini =ini  (SgG  >detail+ini !17_S	et	f	\N
204556	detailini	detailini =ini  (SgP  >detail+ini !17_S	et	f	\N
204574	tavalisemaid	tavalisemaid =tavalisema  (PlP  >tavalisem !02_A	et	f	\N
204575	tavalisemaid	"tavalisem %tava  )LISEM_cA  <tava ;17_S	et	f	\N
204576	tavalisemaid	"tavalisem %tavalise  )M_cA  <tavaline ;12_A	et	f	\N
204579	kehtestasid	kehtestasid =kehtesta  (IndIpfSg2  >kehtestama !27_V	et	f	\N
204580	kehtestasid	kehtestasid =kehtesta  (IndIpfPl3  >kehtestama !27_V	et	f	\N
204591	aktsepteeritavate	aktsepteeritavate =aktsepteeritava  (PlG  >aktsepteeritav !02_A	et	f	\N
204592	aktsepteeritavate	"aktsepteeritav %aktsepteeri  )TAV_vAS  <aktsepteerima ;28_V	et	f	\N
204595	lävimisse	lävimisse =lävimis  (SgAdt  >lävimine !12_S	et	f	\N
204596	lävimisse	"lävimine %lävi  )MINE_vS  <lävima ;27_V	et	f	\N
204612	vaikimisi	vaikimisi =vaikimisi  (PlP  >vaikimine !12_S	et	f	\N
204613	vaikimisi	"vaikimine %vaiki  )MINE_vS  <vaikima ;27_V	et	f	\N
204628	õndsuses	õndsuses =õndsuse  (SgIn  >õndsus !11~09_S	et	f	\N
204630	õndsuses	"õndsus %õndsa  )US_aS  <õnnis ;03_A	et	f	\N
204639	toitjat	toitjat =toitja  (SgP  >toitja !01_S	et	f	\N
204640	toitjat	"toitja %toit  )JA_vS  <toitma ;34_V	et	f	\N
204646	naistevahelistes	naistevahelistes =vahelis  (PlIn  >naiste+vaheline !12_A	et	f	\N
204647	naistevahelistes	"naiste+vaheline %vahe  )LINE_aA  <naiste+vahe ;16_S	et	f	\N
204648	feminiinsemale	feminiinsemale =feminiinsema  (SgAll  >feminiinsem !02_A	et	f	\N
204650	feminiinsemale	"feminiinsem %feminiinse  )M_cA  <feminiinne ;02_A	et	f	\N
204669	vice	?vice =vice  (SgN  >vice !06_S	et	f	\N
204670	vice	?vice =vice  (SgG  >vice !06_S	et	f	\N
204683	märgatavamatele	märgatavamatele =märgatavama  (PlAll  >märgatavam !02_A	et	f	\N
204684	märgatavamatele	"märgatavam %märga  )TAVAM_cA  <märkama ;29_V	et	f	\N
204685	märgatavamatele	"märgatavam %märgatava  )M_cA  <märgatav ;02_A	et	f	\N
204688	demokraatlikumaks	demokraatlikumaks =demokraatlikuma  (SgTr  >demokraatlikum !02_A	et	f	\N
204689	demokraatlikumaks	"demokraatlikum %demokraatliku  )M_cA  <demokraatlik ;25_A	et	f	\N
204702	avaramad	avaramad =avarama  (PlN  >avaram !02_A	et	f	\N
204703	avaramad	"avaram %avara  )M_cA  <avar ;02_A	et	f	\N
204712	jõudvates	jõudvates =jõudva  (PlIn  >jõudev !02_A	et	f	\N
204713	jõudvates	"jõudev %jõud  )V_vA  <jõudma ;34_V	et	f	\N
204714	tehnoliigia	?tehnoliigia =tehnoliigia  (SgN  >tehnoliigia !01_S	et	f	\N
204715	tehnoliigia	?tehnoliigia =tehnoliigia  (SgG  >tehnoliigia !01_S	et	f	\N
204716	tehnoliigia	?tehnoliigia =liigia  (SgN  >tehno+liigia !01_S	et	f	\N
204717	tehnoliigia	?tehnoliigia =liigia  (SgG  >tehno+liigia !01_S	et	f	\N
204718	vastuseisu	vastuseisu =seisu  (SgG  >vastu+seis !22_S	et	f	\N
204719	vastuseisu	vastuseisu =seisu  (SgP  >vastu+seis !22_S	et	f	\N
204720	vastuseisu	vastuseisu =seisu  (SgAdt  >vastu+seis !22_S	et	f	\N
204732	vastukaja	vastukaja =kaja  (SgN  >vastu+kaja !17_S	et	f	\N
204733	vastukaja	vastukaja =kaja  (SgG  >vastu+kaja !17_S	et	f	\N
204734	vastukaja	vastukaja =kaja  (SgP  >vastu+kaja !17_S	et	f	\N
204745	eelistustega	eelistustega =eelistus  (PlKom  >eelistus !11_S	et	f	\N
204746	eelistustega	"eelistus %eelista  )US_vS  <eelistama ;27_V	et	f	\N
204752	avardamisele	avardamisele =avardamise  (SgAll  >avardamine !12_S	et	f	\N
204754	avardamisele	"avardamine %avarda  )MINE_vS  <avardama ;27_V	et	f	\N
204760	prominenti	prominenti =prominenti  (SgP  >prominent !22_S	et	f	\N
204761	prominenti	prominenti =prominenti  (SgAdt  >prominent !22_S	et	f	\N
204775	absolüütselt	?absolüütselt =absolüütse  (SgAbl  >absolüütne !02_A	et	f	\N
204776	absolüütselt	?absolüütselt =absolüütse  (PlAbl  >absolüüts !22_S	et	f	\N
204777	absolüütselt	?absolüütselt =absolüütselt  (ID  >absolüütselt !41_D	et	f	\N
204787	tähts	?tähts =tähts  (SgN  >tähts !22_S	et	f	\N
204795	arenenute	arenenute =arenenu  (PlG  >arenenu !01_S	et	f	\N
204796	arenenute	"arenenu %arene  )NU_vS  <arenema ;27_V	et	f	\N
204811	kulmineerus	?kulmineerus =kulmineeru  (IndIpfSg3  >kulmineeruma !27_V	et	f	\N
204812	kulmineerus	?kulmineerus =kulmineerus  (SgN  >kulmineerus !11~09_S	et	f	\N
204828	kurbtõsine	kurbtõsine =tõsine  (SgN  >kurb+tõsine !10_A	et	f	\N
204638	määratlevad	"määratlev %määratle  )V_vA  <määratlema ;27_V	et	f	\N
204649	maailmavaatele	maailmavaatele =ate  (PlAll  >maa+ilm+ava+att !22_S	et	f	\N
204651	maailmavaatele	maailmavaatele =vaate  (SgAll  >maa+ilma+vaade !06_S	et	f	\N
204657	sobitunud	sobitunud =sobitu  (PtsPtPs  >sobituma !27_V	et	f	\N
204658	sobitunud	sobitunud =sobitunu  (PlN  >sobitunu !01_S	et	f	\N
204659	sobitunud	"sobitunu %sobitu  )NU_vS  <sobituma ;27_V	et	f	\N
204660	sobitunud	sobitunud =sobitunud  (ID  >sobitunud !41_A	et	f	\N
204661	sobitunud	"sobitunud %sobitu  )NUD_vA  <sobituma ;27_V	et	f	\N
204671	versa	?versa =versa  (SgN  >versa !16_S	et	f	\N
204672	versa	?versa =versa  (SgG  >versa !16_S	et	f	\N
204673	versa	?versa =versa  (IndPrPs_  >versama !29_V	et	f	\N
204674	versa	?versa =versa  (ImpPrSg2  >versama !29_V	et	f	\N
204677	pelga	pelga =pelga  (SgG  >pelk !22_A	et	f	\N
204678	pelga	pelga =pelga  (IndPrPs_  >pelgama !29_V	et	f	\N
204679	pelga	pelga =pelga  (ImpPrSg2  >pelgama !29_V	et	f	\N
204680	olulisemate	olulisemate =olulisema  (PlG  >olulisem !02_A	et	f	\N
204681	olulisemate	"olulisem %olu  )LISEM_cA  <olu ;17_S	et	f	\N
204682	olulisemate	"olulisem %olulise  )M_cA  <oluline ;12_A	et	f	\N
204686	kommunikatsioonitehnoloogia	kommunikatsioonitehnoloogia =tehnoloogia  (SgN  >kommunikatsiooni+tehnoloogia !01_S	et	f	\N
204687	kommunikatsioonitehnoloogia	kommunikatsioonitehnoloogia =tehnoloogia  (SgG  >kommunikatsiooni+tehnoloogia !01_S	et	f	\N
204695	kommentaariumites	?kommentaariumites =kommentaariumi  (PlIn  >kommentaarium !02_S	et	f	\N
204698	kommentaariumites	?kommentaariumites =kommentaariumite  (PlIn  >kommentaariumitt !22_S	et	f	\N
204699	kommentaariumites	?kommentaariumites =umite  (PlIn  >kommentaari+umitt !22_S	et	f	\N
204700	kommentaariumites	?kommentaariumites =mentaariumi  (PlIn  >kom+mentaarium !02_S	et	f	\N
204701	kommentaariumites	?kommentaariumites =mentaariumite  (PlIn  >kom+mentaariumitt !22_S	et	f	\N
204735	kõneldud	kõneldud =kõnel  (PtsPtIps  >kõnelema !31_V	et	f	\N
204736	kõneldud	kõneldud =kõneldu  (PlN  >kõneldu !01_S	et	f	\N
204737	kõneldud	"kõneldu %kõnel  )TU1_vS  <kõnelema ;31_V	et	f	\N
204738	kõneldud	kõneldud =kõneldud  (ID  >kõneldud !41_A	et	f	\N
204739	kõneldud	"kõneldud %kõnel  )TUD_vA  <kõnelema ;31_V	et	f	\N
204747	kollasid	?kollasid =kolla  (PlP  >kolla !16_S	et	f	\N
204748	kollasid	?kollasid =kolla  (IndIpfSg2  >kollama !29_V	et	f	\N
204749	kollasid	?kollasid =kolla  (IndIpfPl3  >kollama !29_V	et	f	\N
204755	lahendamisele	lahendamisele =lahendamise  (SgAll  >lahendamine !12_S	et	f	\N
204756	lahendamisele	"lahendamine %lahenda  )MINE_vS  <lahendama ;27_V	et	f	\N
204813	teisaks	?teisaks =teisa  (SgTr  >teisa !16_S	et	f	\N
204814	teisaks	?teisaks =teisa  (KndPrPs  >teisama !29_V	et	f	\N
204815	teisaks	?teisaks =aks  (SgN  >teis+aks !22_S	et	f	\N
204840	aprillirahutusi	aprillirahutusi =rahutusi  (PlP  >aprilli+rahutus !11_S	et	f	\N
204841	aprillirahutusi	"aprilli+rahutus %rahu  )TUS2_aS  <aprilli+rahu ;17_S	et	f	\N
204849	ülistavad	ülistavad =ülista  (IndPrPl3  >ülistama !27_V	et	f	\N
204850	ülistavad	ülistavad =ülistava  (PlN  >ülistav !02_A	et	f	\N
204851	ülistavad	"ülistav %ülista  )V_vA  <ülistama ;27_V	et	f	\N
204859	meediasse	meediasse =meedia  (SgIll  >meedia !01_S	et	f	\N
204860	meediasse	meediasse =dia  (SgIll  >mee+dia !26_S	et	f	\N
204866	lahterda	lahterda =lahterda  (IndPrPs_  >lahterdama !27_V	et	f	\N
204867	lahterda	lahterda =lahterda  (ImpPrSg2  >lahterdama !27_V	et	f	\N
204886	lahterdust	lahterdust =lahterdus  (SgP  >lahterdus !11_S	et	f	\N
204887	lahterdust	"lahterdus %lahterda  )US_vS  <lahterdama ;27_V	et	f	\N
204888	piiramatuid	piiramatuid =piiramatu  (PlP  >piiramatu !01_A	et	f	\N
204889	piiramatuid	"piiramatu %piira  )MATU_vA  <piirama ;29_V	et	f	\N
204890	kg	### kg	et	f	\N
204914	kurki	kurki =kurki  (SgP  >kurk !22_S	et	f	\N
204915	kurki	kurki =kurki  (SgAdt  >kurk !22_S	et	f	\N
204920	nõrgemaid	nõrgemaid =nõrgema  (PlP  >nõrgem !02_A	et	f	\N
204921	nõrgemaid	"nõrgem %nõrge  )M_cA  <nõrk ;22_A	et	f	\N
204929	kelleltki	kelleltki =kelle  (SgAbl  >keegi !00_P	et	f	\N
204930	kelleltki	kelleltki =kelle  (SgAbl^  >kes !00_P	et	f	\N
204931	kelleltki	kelleltki =kelle  (PlAbl^  >kell !22_S	et	f	\N
204935	vastatud	vastatud =vasta  (PtsPtIps  >vastama !29_V	et	f	\N
204936	vastatud	vastatud =vastatu  (PlN  >vastatu !01_S	et	f	\N
204937	vastatud	"vastatu %vasta  )TU1_vS  <vastama ;29_V	et	f	\N
204938	vastatud	vastatud =vastatud  (ID  >vastatud !41_A	et	f	\N
204939	vastatud	"vastatud %vasta  )TUD_vA  <vastama ;29_V	et	f	\N
204940	vastatud	vastatud =atu  (PlN  >vast+att !22_S	et	f	\N
204941	normaalsete	normaalsete =normaalse  (PlG  >normaalne !02_A	et	f	\N
204942	normaalsete	normaalsete =sete  (SgN  >normaal+sete !06_S	et	f	\N
204965	supermees	supermees =mee  (SgIn  >super+mesi !15_S	et	f	\N
204966	supermees	supermees =mees  (SgN  >super+mees !13_S	et	f	\N
205019	õnnetuna	õnnetuna =õnnetu  (SgEs  >õnnetu !01_A	et	f	\N
205020	õnnetuna	"õnnetu %õnne  )TU2_kA  <õnn ;22_S	et	f	\N
205047	tulevased	tulevased =tulevase  (PlN  >tulevane !12_AS	et	f	\N
205048	tulevased	tulevased =vase  (PlN  >tule+vask !22_S	et	f	\N
205056	kohanemisvõime	kohanemisvõime =võime  (SgN  >kohanemis+võime !06_S	et	f	\N
204704	mõtlemata	mõtlemata =mõtle  (SupAb  >mõtlema !30_V	et	f	\N
204705	mõtlemata	mõtlemata =mõtlemata  (ID  >mõtlemata !41_A	et	f	\N
204706	mõtlemata	"mõtlemata %mõtle  )MATA_vA  <mõtlema ;30_V	et	f	\N
204721	mobiilioperaatori	?mobiilioperaatori =mobiilioperaatori  (SgG  >mobiilioperaator !02_S	et	f	\N
204722	mobiilioperaatori	?mobiilioperaatori =ioperaatori  (SgG  >mobiil+ioperaator !02_S	et	f	\N
204740	paberlehtedes	paberlehtedes =ede  (SgIn  >paber+leht+ede !16_S	et	f	\N
204741	paberlehtedes	paberlehtedes =lehte  (PlIn  >paber+leht !22_S	et	f	\N
204742	online	?online =online  (SgN  >online !10_A	et	f	\N
204743	online	?online =online  (IndPrPs_  >onlinema !27_V	et	f	\N
204744	online	?online =online  (ImpPrSg2  >onlinema !27_V	et	f	\N
204797	juhtusin	juhtusin =juhtu  (IndIpfSg1  >juhtuma !27_V	et	f	\N
204798	juhtusin	juhtusin =usin  (SgN  >juht+usin !02_A	et	f	\N
204799	võrdlusesse	võrdlusesse =võrdluse  (SgIll  >võrdlus !11~09_S	et	f	\N
204800	võrdlusesse	võrdlusesse =võrdluses  (SgAdt  >võrdlusene !12_A	et	f	\N
204801	võrdlusesse	"võrdlusene %võrdluse  )NE_aA  <võrdlus ;09_S	et	f	\N
204802	võrdlusesse	"võrdlusene %võrdluse  )NE_aA  <võrdlus ;11_S	et	f	\N
204808	rahvuskaaslaste	rahvuskaaslaste =las  (PlG  >rahvus+kaas+laps !14_S	et	f	\N
204809	rahvuskaaslaste	rahvuskaaslaste =laste  (PlP  >rahvus+kaas+last !22_S	et	f	\N
204810	rahvuskaaslaste	rahvuskaaslaste =kaaslas  (PlG  >rahvus+kaaslane !12?10_S	et	f	\N
204819	haaratud	haaratud =haara  (PtsPtIps  >haarama !29_V	et	f	\N
204820	haaratud	haaratud =haaratu  (PlN  >haaratu !01_AS	et	f	\N
204821	haaratud	"haaratu %haara  )TU1_vS  <haarama ;29_V	et	f	\N
204822	haaratud	"haaratu %haara  )TU2_kA  <haar ;22_S	et	f	\N
204823	haaratud	haaratud =haaratud  (ID  >haaratud !41_A	et	f	\N
204824	haaratud	"haaratud %haara  )TUD_vA  <haarama ;29_V	et	f	\N
204844	käivitusid	käivitusid =käivitu  (IndIpfSg2  >käivituma !27_V	et	f	\N
204845	käivitusid	käivitusid =käivitu  (IndIpfPl3  >käivituma !27_V	et	f	\N
204876	tutvusringkonnas	tutvusringkonnas =konna  (SgIn  >tutvus+ring+konn !22_S	et	f	\N
204877	tutvusringkonnas	tutvusringkonnas =ringkonna  (SgIn  >tutvus+ringkond !22_S	et	f	\N
204891	suni	?suni =suni  (SgN  >suni !17_S	et	f	\N
204892	suni	?suni =suni  (SgG  >suni !17_S	et	f	\N
204893	suni	?suni =suni  (SgP  >suni !17_S	et	f	\N
204894	suni	?suni =suni  (IndPrPs_  >sunima !27_V	et	f	\N
204895	suni	?suni =suni  (ImpPrSg2  >sunima !27_V	et	f	\N
204901	tahetagi	tahetagi =tagi  (SgN  >tahe+tagi !17_S	et	f	\N
204902	tahetagi	tahetagi =tagi  (SgG  >tahe+tagi !17_S	et	f	\N
204903	tahetagi	tahetagi =tagi  (SgP  >tahe+tagi !17_S	et	f	\N
204904	tahetagi	tahetagi =tahe  (IndPrIps_^  >tahtma !34_V	et	f	\N
204905	matemaakikud	?matemaakikud =matemaakiku  (PlN  >matemaakik !02_S	et	f	\N
204906	matemaakikud	?matemaakikud =matemaakiku  (IndPrSg2  >matemaakikuma !27_V	et	f	\N
204916	darwini	?darwini =darwi  (SgTer  >darwi !16_S	et	f	\N
204917	darwini	?darwini =darwi  (SgTer  >darw !22_S	et	f	\N
204918	darwini	?darwini =darwini  (SgG  >darwin !02_S	et	f	\N
204927	minestusse	minestusse =minestus  (SgAdt  >minestus !11_S	et	f	\N
204928	minestusse	"minestus %minesta  )US_vS  <minestama ;27_V	et	f	\N
204954	rokib	?rokib =roki  (IndPrSg3  >rokima !27_V	et	f	\N
204955	rokib	?rokib =roki  (IndPrSg3  >rokkima !28_V	et	f	\N
204972	idüllilisele	idüllilisele =idüllilise  (SgAll  >idülliline !12_A	et	f	\N
204973	idüllilisele	"idülliline %idülli  )LINE_aA  <idüll ;22_S	et	f	\N
204981	musta-	musta- =musta  (SgG  >must !22_AS	et	f	\N
204982	musta-	musta- =musta  (SgP  >must !22_AS	et	f	\N
204983	musta-	musta- =musta  (SgAdt  >must !22_AS	et	f	\N
204984	musta-	musta- =musta  (IndPrPs_  >mustama !29_V	et	f	\N
204985	musta-	musta- =musta  (ImpPrSg2  >mustama !29_V	et	f	\N
205006	identiteedita	?identiteedita =identiteedi  (SgAb  >identiteedi !16_S	et	f	\N
205007	identiteedita	?identiteedita =identiteedi  (SgAb  >identiteet !22_S	et	f	\N
205008	identiteedita	?identiteedita =identiteedi  (IndPrIps_  >identiteetima !28_V	et	f	\N
205009	identiteedita	?identiteedita =identiteedita  (IndPrPs_  >identiteeditama !27_V	et	f	\N
205010	identiteedita	?identiteedita =identiteedita  (ImpPrSg2  >identiteeditama !27_V	et	f	\N
205040	hajuvad	hajuvad =haju  (IndPrPl3  >hajuma !27_V	et	f	\N
205041	hajuvad	hajuvad =hajuva  (PlN  >hajuv !02_A	et	f	\N
205042	hajuvad	"hajuv %haju  )V_vA  <hajuma ;27_V	et	f	\N
205059	väljaviib	?väljaviib =väljaviib  (SgN  >väljaviib !22_S	et	f	\N
205060	väljaviib	?väljaviib =viib  (SgN  >välja+viib !22_S	et	f	\N
205064	avatuse	avatuse =avatuse  (SgG  >avatus !11_S	et	f	\N
205065	avatuse	"avatus %ava  )TUS1_aS  <avama ;27_V	et	f	\N
205066	avatuse	"avatus %ava  )TUS2_aS  <ava ;17_S	et	f	\N
205072	samavõrdselt	samavõrdselt =võrdse  (SgAbl  >sama+võrdne !02_A	et	f	\N
205073	samavõrdselt	"sama+võrdselt %võrdse  )LT_mD  <sama+võrdne ;02_A	et	f	\N
205074	ümbritsevale	ümbritsevale =ümbritseva  (SgAll  >ümbritsev !02_A	et	f	\N
205075	ümbritsevale	"ümbritsev %ümbritse  )V_vA  <ümbritsema ;27_V	et	f	\N
205097	stsenaariumitest	stsenaariumitest =stsenaariumi  (PlEl  >stsenaarium !02_S	et	f	\N
205098	stsenaariumitest	stsenaariumitest =test  (SgN  >stsenaariumi+test !22_S	et	f	\N
205103	kääkirja	?kääkirja =kääkirja  (SgN  >kääkirja !16_S	et	f	\N
204762	arvamusliidritest	arvamusliidritest =test  (SgN  >arvamus+liidri+test !22_S	et	f	\N
204763	arvamusliidritest	arvamusliidritest =liidri  (PlEl  >arvamus+liider !02_S	et	f	\N
204766	süvenemata	süvenemata =süvene  (SupAb  >süvenema !27_V	et	f	\N
204767	süvenemata	süvenemata =süvenemata  (ID  >süvenemata !41_A	et	f	\N
204768	süvenemata	"süvenemata %süvene  )MATA_vA  <süvenema ;27_V	et	f	\N
204772	üllata	üllata =ülla  (SgAb  >üllas !07_A	et	f	\N
204773	üllata	üllata =üllata  (IndPrPs_  >üllatama !27_V	et	f	\N
204774	üllata	üllata =üllata  (ImpPrSg2  >üllatama !27_V	et	f	\N
204778	temperamenti	temperamenti =temperamenti  (SgP  >temperament !22_S	et	f	\N
204779	temperamenti	temperamenti =temperamenti  (SgAdt  >temperament !22_S	et	f	\N
204780	elavatel	elavatel =elava  (PlAd  >elav !02_A	et	f	\N
204781	elavatel	"elav %ela  )V_vA  <elama ;27_V	et	f	\N
204782	elavatel	elavatel =ate  (PlAd  >elav+att !22_S	et	f	\N
204788	moodustavadgi	?moodustavadgi =moodustavadgi  (SgG  >moodustavadg !22_S	et	f	\N
204789	moodustavadgi	?moodustavadgi =moodustavadgi  (SgP  >moodustavadg !22_S	et	f	\N
204790	moodustavadgi	?moodustavadgi =moodustavadgi  (SgAdt  >moodustavadg !22_S	et	f	\N
204791	moodustavadgi	?moodustavadgi =moodustavadgi  (IndPrPs_  >moodustavadgima !28_V	et	f	\N
204792	moodustavadgi	?moodustavadgi =moodustavadgi  (ImpPrSg2  >moodustavadgima !28_V	et	f	\N
204793	arengumaadest	arengumaadest =maa  (PlEl  >arengu+maa !26_S	et	f	\N
204794	arengumaadest	arengumaadest =maade  (PlEl  >arengu+maat !22_S	et	f	\N
204833	hoopistühis	?hoopistühis =hoopistühis  (SgN  >hoopistühis !09_S	et	f	\N
204834	hoopistühis	?hoopistühis =ühi  (SgIn  >hoo+pist+ühi !17_S	et	f	\N
204835	hoopistühis	?hoopistühis =ühis  (SgN  >hoo+pist+ühis !09_S	et	f	\N
204836	hoopistühis	?hoopistühis =tühis  (SgN  >hoopis+tühis !09_S	et	f	\N
204837	hoopistühis	?hoopistühis =pistühi  (SgIn  >hoo+pistühi !01_S	et	f	\N
204838	hoopistühis	?hoopistühis =pistühis  (SgN  >hoo+pistühis !11_S	et	f	\N
204842	problemaatilisemaks	problemaatilisemaks =problemaatilisema  (SgTr  >problemaatilisem !02_A	et	f	\N
204843	problemaatilisemaks	"problemaatilisem %problemaatilise  )M_cA  <problemaatiline ;12_A	et	f	\N
204861	kohelnud	kohelnud =kohel  (PtsPtPs  >kohtlema !30_V	et	f	\N
204862	kohelnud	kohelnud =kohelnu  (PlN  >kohelnu !01_S	et	f	\N
204863	kohelnud	"kohelnu %kohel  )NU_vS  <kohtlema ;30_V	et	f	\N
204864	kohelnud	kohelnud =kohelnud  (ID  >kohelnud !41_A	et	f	\N
204865	kohelnud	"kohelnud %kohel  )NUD_vA  <kohtlema ;30_V	et	f	\N
204870	sõbralikumalt	sõbralikumalt =sõbralikuma  (SgAbl  >sõbralikum !02_A	et	f	\N
204871	sõbralikumalt	"sõbralikum %sõbraliku  )M_cA  <sõbralik ;25_A	et	f	\N
204872	sõbralikumalt	sõbralikumalt =sõbralikumalt  (ID  >sõbralikumalt !41_D	et	f	\N
204873	sõbralikumalt	"sõbralikumalt %sõbraliku  )MALT_mD  <sõbralik ;25_A	et	f	\N
204874	eestimeelselt	eestimeelselt =meelse  (SgAbl  >eesti+meelne !02_A	et	f	\N
204875	eestimeelselt	"eesti+meelselt %meelse  )LT_mD  <eesti+meelne ;02_A	et	f	\N
204878	alateadvusesse	alateadvusesse =teadvuse  (SgIll  >ala+teadvus !11~09_S	et	f	\N
204879	alateadvusesse	"ala+teadvus %teadva  )US_aS  <ala+teadev ;02_A	et	f	\N
204880	alateadvusesse	alateadvusesse =teadvuses  (SgAdt  >ala+teadvusene !12_A	et	f	\N
204881	alateadvusesse	"ala+teadvusene %teadvuse  )NE_aA  <ala+teadvus ;09_S	et	f	\N
204882	alateadvusesse	"ala+teadvusene %teadvuse  )NE_aA  <ala+teadvus ;11_S	et	f	\N
204896	eriliselt	eriliselt =erilise  (SgAbl  >eriline !12_A	et	f	\N
204897	eriliselt	"eriline %eri  )LINE_aA  <eri ;17_S	et	f	\N
204898	eriliselt	eriliselt =eriliselt  (ID  >eriliselt !41_D	et	f	\N
204899	eriliselt	"eriliselt %eri  )LISELT_mD  <eri ;17_S	et	f	\N
204900	eriliselt	"eriliselt %erilise  )LT_mD  <eriline ;12_A	et	f	\N
204947	erakonda	erakonda =erakonda  (SgP  >erakond !22_S	et	f	\N
204948	erakonda	erakonda =erakonda  (SgAdt  >erakond !22_S	et	f	\N
204958	harjumuste	harjumuste =harjumus  (PlG  >harjumus !11_S	et	f	\N
204959	harjumuste	"harjumus %harju  )MUS_vS  <harjuma ;27_V	et	f	\N
204960	harjumuste	harjumuste =muste  (PlP  >harju+must !22_AS	et	f	\N
204974	kellepoole	?kellepoole =kellepoo  (SgAll  >kellepoo !26_S	et	f	\N
204975	kellepoole	?kellepoole =kellepoole  (SgN  >kellepoole !16_S	et	f	\N
204976	kellepoole	?kellepoole =kellepoole  (SgG  >kellepoole !16_S	et	f	\N
204977	kellepoole	?kellepoole =kellepoole  (PlP  >kellepool !22_S	et	f	\N
204986	valgenahaline	valgenahaline =nahaline  (SgN  >valge+nahaline !12_A	et	f	\N
204987	valgenahaline	"valge+nahaline %naha  )LINE_aA  <valge+nahk ;22_S	et	f	\N
204990	lõppeesmärki	lõppeesmärki =märki  (SgP  >lõpp+ees+märk !22_S	et	f	\N
204991	lõppeesmärki	lõppeesmärki =märki  (SgAdt  >lõpp+ees+märk !22_S	et	f	\N
204997	pubi	?pubi =pubi  (SgN  >pubi !17_S	et	f	\N
204998	pubi	?pubi =pubi  (SgG  >pubi !17_S	et	f	\N
204999	pubi	?pubi =pubi  (SgP  >pubi !17_S	et	f	\N
205000	pubi	?pubi =pubi  (IndPrPs_  >pubima !27_V	et	f	\N
205001	pubi	?pubi =pubi  (ImpPrSg2  >pubima !27_V	et	f	\N
205002	päralt	päralt =pära  (SgAbl  >pära !17_S	et	f	\N
205003	päralt	päralt =päralt  (ID  >päralt !41_K	et	f	\N
205004	trügi	trügi =trügi  (IndPrPs_  >trügima !27_V	et	f	\N
205005	trügi	trügi =trügi  (ImpPrSg2  >trügima !27_V	et	f	\N
205032	globaliseerimine	?globaliseerimine =globaliseerimine  (SgN  >globaliseerimine !12_S	et	f	\N
204829	kurbtõsine	"kurb+tõsine %tõsi  )NE_aA  <kurb+tõsi ;15_S	et	f	\N
204853	puutumata	puutumata =puutu  (SupAb  >puutuma !27_V	et	f	\N
204855	puutumata	puutumata =puutuma  (SgAb  >puutum !02_A	et	f	\N
204856	puutumata	"puutum %puu  )TUM2_cA  <puu ;26_S	et	f	\N
204857	puutumata	puutumata =puutumata  (ID  >puutumata !41_A	et	f	\N
204858	puutumata	"puutumata %puutu  )MATA_vA  <puutuma ;27_V	et	f	\N
204883	keelebarjääri	keelebarjääri =barjääri  (SgG  >keele+barjäär !22_S	et	f	\N
204884	keelebarjääri	keelebarjääri =barjääri  (SgP  >keele+barjäär !22_S	et	f	\N
204885	keelebarjääri	keelebarjääri =barjääri  (SgAdt  >keele+barjäär !22_S	et	f	\N
204919	rikuradapidi	### rikuradapidi	et	f	\N
204932	ülikõva	ülikõva =kõva  (SgN  >üli+kõva !17_A	et	f	\N
204933	ülikõva	ülikõva =kõva  (SgG  >üli+kõva !17_A	et	f	\N
204934	ülikõva	ülikõva =kõva  (SgP  >üli+kõva !17_A	et	f	\N
204949	salli	salli =salli  (SgG  >sall !22_S	et	f	\N
204950	salli	salli =salli  (SgP  >sall !22_S	et	f	\N
204951	salli	salli =salli  (SgAdt  >sall !22_S	et	f	\N
204952	salli	salli =salli  (IndPrPs_  >sallima !28_V	et	f	\N
204953	salli	salli =salli  (ImpPrSg2  >sallima !28_V	et	f	\N
204967	suhelnud	suhelnud =suhel  (PtsPtPs  >suhtlema !30_V	et	f	\N
204968	suhelnud	suhelnud =suhelnu  (PlN  >suhelnu !01_S	et	f	\N
204969	suhelnud	"suhelnu %suhel  )NU_vS  <suhtlema ;30_V	et	f	\N
204970	suhelnud	suhelnud =suhelnud  (ID  >suhelnud !41_A	et	f	\N
204971	suhelnud	"suhelnud %suhel  )NUD_vA  <suhtlema ;30_V	et	f	\N
204978	invaliid	invaliid =invaliid  (SgN  >invaliid !22_S	et	f	\N
204979	invaliid	invaliid =lii  (PlN  >inva+lii !26_S	et	f	\N
204980	invaliid	invaliid =lii  (SgP  >inva+lii !26_S	et	f	\N
204988	vabadused	vabadused =vabaduse  (PlN  >vabadus !11_S	et	f	\N
204989	vabadused	"vabadus %vaba  )US_aS  <vaba ;17_A	et	f	\N
204992	tungis	tungis =tungi  (SgIn  >tung !22_S	et	f	\N
204993	tungis	tungis =tungi  (PlIn  >tung !22_S	et	f	\N
204994	tungis	tungis =tungi  (IndIpfSg3  >tungima !28_V	et	f	\N
204995	virtuaalmaailmast	?virtuaalmaailmast =virtuaalmaailma  (SgEl  >virtuaalmaailma !16_S	et	f	\N
204996	virtuaalmaailmast	?virtuaalmaailmast =virtuaalmaailmas  (SgP  >virtuaalmaailmane !12_A	et	f	\N
205011	ninaotsa	ninaotsa =otsa  (SgG  >nina+ots !23?22_S	et	f	\N
205012	ninaotsa	ninaotsa =otsa  (SgP  >nina+ots !23?22_S	et	f	\N
205013	ninaotsa	ninaotsa =otsa  (SgAdt  >nina+ots !23?22_S	et	f	\N
205029	mõjukaim	mõjukaim =mõjukaim  (SgN  >mõjukaim !02_A	et	f	\N
205030	mõjukaim	"mõjukaim %mõjuka  )IM_sA  <mõjukas ;02_A	et	f	\N
205031	mõjukaim	mõjukaim =kaim  (SgN  >mõju+kaim !22_S	et	f	\N
205045	väljenduses	väljenduses =väljenduse  (SgIn  >väljendus !11_S	et	f	\N
205046	väljenduses	"väljendus %väljenda  )US_vS  <väljendama ;27_V	et	f	\N
205049	tulevaste	tulevaste =tulevas  (PlG  >tulevane !12_AS	et	f	\N
205050	tulevaste	tulevaste =aste  (SgN  >tulev+aste !05_S	et	f	\N
205051	tulevaste	tulevaste =aste  (SgN  >tulev+aste !06_S	et	f	\N
205052	tulevaste	tulevaste =aste  (SgG  >tulev+aste !06_S	et	f	\N
205053	tulevaste	tulevaste =aste  (PlP  >tulev+ast !22_S	et	f	\N
205054	tulevaste	tulevaste =vaste  (SgN  >tule+vaste !06_S	et	f	\N
205055	tulevaste	tulevaste =vaste  (SgG  >tule+vaste !06_S	et	f	\N
205070	globaalseks	globaalseks =globaalse  (SgTr  >globaalne !02_A	et	f	\N
205071	globaalseks	globaalseks =seks  (SgN  >globaal+seks !22_S	et	f	\N
205077	tekket	?tekket =tekke  (SgP  >tekke !06_S	et	f	\N
205082	mehanismid	?mehanismid =mehanismi  (PlN  >mehanism !22_S	et	f	\N
205083	mehanismid	?mehanismid =mehanismi  (IndPrSg2  >mehanismima !28_V	et	f	\N
205106	tööelu	tööelu =elu  (SgN  >töö+elu !17_S	et	f	\N
205107	tööelu	tööelu =elu  (SgG  >töö+elu !17_S	et	f	\N
205108	tööelu	tööelu =elu  (SgP  >töö+elu !17_S	et	f	\N
205114	muutume	muutume =muutu  (IndPrPl1  >muutuma !27_V	et	f	\N
205115	muutume	muutume =tume  (SgN  >muu+tume !02_A	et	f	\N
205149	kantseldaja	kantseldaja =kantseldaja  (SgN  >kantseldaja !01_S	et	f	\N
205150	kantseldaja	"kantseldaja %kantselda  )JA_vS  <kantseldama ;27_V	et	f	\N
205151	kantseldaja	kantseldaja =kantseldaja  (SgG  >kantseldaja !01_S	et	f	\N
205167	hoolivamaks	hoolivamaks =hoolivama  (SgTr  >hoolivam !02_A	et	f	\N
205168	hoolivamaks	"hoolivam %hooli  )VAM_cA  <hoolima ;28_V	et	f	\N
205169	hoolivamaks	"hoolivam %hooliva  )M_cA  <hooliv ;02_A	et	f	\N
205170	hoolivamaks	hoolivamaks =maks  (SgN  >hoo+liva+maks !22_S	et	f	\N
205171	majapidamistöödega	majapidamistöödega =öö  (PlKom  >maja+pidamist+öö !26_S	et	f	\N
205172	majapidamistöödega	majapidamistöödega =töö  (PlKom  >maja+pidamis+töö !26_S	et	f	\N
205178	aktiivsemad	aktiivsemad =aktiivsema  (PlN  >aktiivsem !02_A	et	f	\N
205179	aktiivsemad	"aktiivsem %aktiivse  )M_cA  <aktiivne ;02_A	et	f	\N
205196	moodsamaid	moodsamaid =moodsama  (PlP  >moodsam !02_A	et	f	\N
205197	moodsamaid	"moodsam %moodsa  )M_cA  <moodne ;02_A	et	f	\N
205217	gramaatilised	?gramaatilised =gramaatilise  (PlN  >gramaatiline !12_A	et	f	\N
205218	gramaatikal	?gramaatikal =gramaatika  (SgAd  >gramaatika !01_S	et	f	\N
205219	gramaatikal	?gramaatikal =gramaatika  (SgAd  >gramaatikas !02_A	et	f	\N
205220	gramaatikal	?gramaatikal =gramaatikal  (SgN  >gramaatikal !19_S	et	f	\N
204907	mahtumine	mahtumine =mahtumine  (SgN  >mahtumine !12_S	et	f	\N
204908	mahtumine	"mahtumine %mahtu  )MINE_vS  <mahtuma ;28_V	et	f	\N
204909	sättinud	sättinud =sätti  (PtsPtPs  >sättima !28_V	et	f	\N
204910	sättinud	sättinud =sättinu  (PlN  >sättinu !01_S	et	f	\N
204911	sättinud	"sättinu %sätti  )NU_vS  <sättima ;28_V	et	f	\N
204912	sättinud	sättinud =sättinud  (ID  >sättinud !41_A	et	f	\N
204913	sättinud	"sättinud %sätti  )NUD_vA  <sättima ;28_V	et	f	\N
204922	paigalt	paigalt =paiga  (SgAbl  >paik !22_S	et	f	\N
204923	paigalt	paigalt =paigalt  (ID  >paigalt !41_D	et	f	\N
204924	vajalikust	vajalikust =vajaliku  (SgEl  >vajalik !25_A	et	f	\N
204925	vajalikust	vajalikust =vajalikus  (SgP  >vajalikus !11?09_S	et	f	\N
204926	vajalikust	"vajalikus %vajaliku  )US_aS  <vajalik ;25_A	et	f	\N
204943	sutsu	sutsu =sutsu  (ID  >sutsu !41_D	et	f	\N
204944	sutsu	sutsu =sutsu  (SgG  >suts !22_S	et	f	\N
204945	sutsu	sutsu =sutsu  (SgP  >suts !22_S	et	f	\N
204946	sutsu	sutsu =sutsu  (SgAdt  >suts !22_S	et	f	\N
204956	kordki	kordki =kord  (ID^  >kord !41_D	et	f	\N
204957	kordki	kordki =kord  (SgN^  >kord !22_S	et	f	\N
204961	32-aastane	-aastane =aastane  (SgN  >-aastane !12~10_A	et	f	\N
204962	32-aastane	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
204963	ühtisid	ühtisid =ühti  (IndIpfSg2  >ühtima !27_V	et	f	\N
204964	ühtisid	ühtisid =ühti  (IndIpfPl3  >ühtima !27_V	et	f	\N
205014	pista	pista =pist  (Inf  >pistma !34_V	et	f	\N
205015	pista	pista =pista  (IndPrPs_  >pistma !34_V	et	f	\N
205016	pista	pista =pista  (ImpPrSg2  >pistma !34_V	et	f	\N
205017	reaalsuses	reaalsuses =reaalsuse  (SgIn  >reaalsus !11~09_S	et	f	\N
205018	reaalsuses	"reaalsus %reaalse  )US_aS  <reaalne ;02_A	et	f	\N
205021	lohutust	lohutust =lohutu  (SgEl  >lohutu !01_A	et	f	\N
205022	lohutust	"lohutu %lohu  )TU2_kA  <lohk ;22_S	et	f	\N
205023	lohutust	"lohutu %lohu  )TU2_kA  <loht ;22_S	et	f	\N
205024	lohutust	lohutust =lohutus  (SgP  >lohutus !11_S	et	f	\N
205025	lohutust	"lohutus %lohuta  )US_vS  <lohutama ;27_V	et	f	\N
205026	lohutust	"lohutus %lohu  )TUS2_aS  <lohk ;22_S	et	f	\N
205027	lohutust	"lohutus %lohu  )TUS2_aS  <loht ;22_S	et	f	\N
205028	lohutust	lohutust =tust  (SgN  >lohu+tust !22_S	et	f	\N
205034	mõistetavaks	mõistetavaks =mõistetava  (SgTr  >mõistetav !02_A	et	f	\N
205035	mõistetavaks	"mõistetav %mõiste  )TAV_vAS  <mõistma ;34_V	et	f	\N
205036	global	?global =globa  (SgAd  >globa !17_S	et	f	\N
205037	global	?global =global  (SgN  >global !02_S	et	f	\N
205043	mastaabses	?mastaabses =mastaabse  (SgIn  >mastaabne !02_A	et	f	\N
205044	mastaabses	?mastaabses =mastaabse  (PlIn  >mastaabs !22_S	et	f	\N
205067	tõuseks	tõuseks =tõuse  (PlTr  >tõus !22_S	et	f	\N
205068	tõuseks	tõuseks =tõuse  (KndPrPs  >tõusma !32_V	et	f	\N
205069	tõuseks	tõuseks =seks  (SgN  >tõu+seks !22_S	et	f	\N
205087	juhtimise	juhtimise =juhtimise  (SgG  >juhtimine !12_S	et	f	\N
205088	juhtimise	"juhtimine %juhti  )MINE_vS  <juhtima ;28_V	et	f	\N
205091	fantoomist	fantoomist =fantoomi  (SgEl  >fantoom !22_S	et	f	\N
205092	fantoomist	fantoomist =fantoomis  (SgP  >fantoomine !10_A	et	f	\N
205093	fantoomist	"fantoomine %fantoomi  )NE_aA  <fantoom ;22_S	et	f	\N
205109	argielu	argielu =elu  (SgN  >argi+elu !17_S	et	f	\N
205110	argielu	argielu =elu  (SgG  >argi+elu !17_S	et	f	\N
205111	argielu	argielu =elu  (SgP  >argi+elu !17_S	et	f	\N
205140	toimetusi	toimetusi =toimetusi  (PlP  >toimetus !11_S	et	f	\N
205141	toimetusi	"toimetus %toimeta  )US_vS  <toimetama ;27_V	et	f	\N
205142	toimetusi	"toimetus %toime  )TUS2_aS  <toime ;06_S	et	f	\N
205143	toimetusi	"toimetus %toime  )TUS2_aS  <toim ;22_S	et	f	\N
205147	koduhoidja	koduhoidja =hoidja  (SgN  >kodu+hoidja !01_S	et	f	\N
205148	koduhoidja	koduhoidja =hoidja  (SgG  >kodu+hoidja !01_S	et	f	\N
205160	toimimisel	toimimisel =toimimise  (SgAd  >toimimine !12_S	et	f	\N
205161	toimimisel	"toimimine %toimi  )MINE_vS  <toimima ;28_V	et	f	\N
205162	toimetustes	toimetustes =toimetus  (PlIn  >toimetus !11_S	et	f	\N
205163	toimetustes	"toimetus %toimeta  )US_vS  <toimetama ;27_V	et	f	\N
205164	toimetustes	"toimetus %toime  )TUS2_aS  <toime ;06_S	et	f	\N
205165	toimetustes	"toimetus %toime  )TUS2_aS  <toim ;22_S	et	f	\N
205166	toimetustes	toimetustes =tuste  (PlIn  >toime+tust !22_S	et	f	\N
205190	tunnustamist	tunnustamist =tunnustamis  (SgP  >tunnustamine !12_S	et	f	\N
205191	tunnustamist	"tunnustamine %tunnusta  )MINE_vS  <tunnustama ;27_V	et	f	\N
205198	dissidentlik	?dissidentlik =dissidentlik  (SgN  >dissidentlik !25_A	et	f	\N
205201	päärati	?päärati =päära  (IndIpfIps  >päärama !29_V	et	f	\N
205202	päärati	?päärati =päärati  (ID  >päärati !41_D	et	f	\N
205203	päärati	?päärati =päärati  (SgG  >päärat !02_S	et	f	\N
205204	päärati	?päärati =päärati  (SgG  >pääratt !22_S	et	f	\N
205205	päärati	?päärati =päärati  (IndPrPs_  >päärattima !28_V	et	f	\N
205206	päärati	?päärati =päärati  (ImpPrSg2  >päärattima !28_V	et	f	\N
205207	päärati	?päärati =rati  (SgN  >pää+rati !16_S	et	f	\N
205208	päärati	?päärati =rati  (SgG  >pää+rati !16_S	et	f	\N
205209	päärati	?päärati =rati  (SgG  >pää+ratt !22_S	et	f	\N
205033	globaliseerimine	?globaliseerimine =globaliseerimine  (PlP  >globaliseerimin !19_S	et	f	\N
205038	kavatsused	kavatsused =kavatsuse  (PlN  >kavatsus !11_S	et	f	\N
205039	kavatsused	"kavatsus %kavatse  )US_vS  <kavatsema ;27_V	et	f	\N
205076	ressurside	### ressurside	et	f	\N
205078	rahvasid	?rahvasid =rahva  (PlP  >rahva !16_S	et	f	\N
205079	rahvasid	?rahvasid =rahva  (IndIpfSg2  >rahvama !29_V	et	f	\N
205080	rahvasid	?rahvasid =rahva  (IndIpfPl3  >rahvama !29_V	et	f	\N
205084	suhtkond	?suhtkond =suhtkond  (SgN  >suhtkond !22_S	et	f	\N
205089	keerukaim	keerukaim =keerukaim  (SgN  >keerukaim !02_A	et	f	\N
205090	keerukaim	"keerukaim %keeruka  )IM_sA  <keerukas ;02_A	et	f	\N
205099	imelises	imelises =imelise  (SgIn  >imeline !12_A	et	f	\N
205100	imelises	"imeline %ime  )LINE_aA  <ime ;16_S	et	f	\N
205101	loomingulisust	loomingulisust =loomingulisus  (SgP  >loomingulisus !11?09_S	et	f	\N
205102	loomingulisust	"loomingulisus %loomingu  )LISUS_aS  <looming ;02_S	et	f	\N
205117	veendunult	veendunult =veendunu  (SgAbl  >veendunu !01_S	et	f	\N
205118	veendunult	"veendunu %veendu  )NU_vS  <veenduma ;27_V	et	f	\N
205119	veendunult	veendunult =veendunult  (ID  >veendunult !41_D	et	f	\N
205120	veendunult	"veendunult %veendu  )NULT_mD  <veenduma ;27_V	et	f	\N
205157	valmid	valmid =valmi  (PlN  >valmis !02_A	et	f	\N
205158	valmid	valmid =valmi  (PlN  >valm !22_S	et	f	\N
205159	valmid	valmid =valmi  (IndPrSg2  >valmima !27_V	et	f	\N
205187	abistav	abistav =abista  (PtsPrPs  >abistama !27_V	et	f	\N
205188	abistav	abistav =abistav  (SgN  >abistav !02_A	et	f	\N
205189	abistav	"abistav %abista  )V_vA  <abistama ;27_V	et	f	\N
205194	väliseestlastega	väliseestlastega =las  (PlKom  >väli+seest+laps !14_S	et	f	\N
205195	väliseestlastega	väliseestlastega =eestlas  (PlKom  >välis+eestlane !12?10_S	et	f	\N
205199	kahepalgaline	kahepalgaline =palgaline  (SgN  >kahe+palgaline !12_SA	et	f	\N
205200	kahepalgaline	"kahe+palgaline %palga  )LINE_aA  <kahe+palk ;22_S	et	f	\N
205210	pingestumisele	?pingestumisele =pingestumise  (SgAll  >pingestumine !12_S	et	f	\N
205211	pingestumisele	?pingestumisele =stumise  (SgAll  >pinge+stumine !10_A	et	f	\N
205212	pingestumisele	?pingestumisele =stumisele  (PlP  >pinge+stumisel !19_S	et	f	\N
205213	pingestumisele	?pingestumisele =estumise  (SgAll  >ping+estumine !12_S	et	f	\N
205214	bürokraatile	?bürokraatile =bürokraati  (SgAll  >bürokraati !16_S	et	f	\N
205221	raadiopt	?raadiopt =raadiopt  (SgN  >raadiopt !22_S	et	f	\N
205225	polõtehnikumis	?polõtehnikumis =polõtehnikumi  (SgIn  >polõtehnikum !19_S	et	f	\N
205226	polõtehnikumis	?polõtehnikumis =polõtehnikumis  (SgN  >polõtehnikumis !09_S	et	f	\N
205231	kirjlikud	?kirjlikud =kirjliku  (PlN  >kirjlik !25_A	et	f	\N
205232	kirjlikud	?kirjlikud =kirjliku  (PlN  >kirjliku !01_S	et	f	\N
205233	kirjlikud	?kirjlikud =kirjliku  (IndPrSg2  >kirjlikuma !27_V	et	f	\N
205234	õpilastelt	õpilastelt =õpilas  (PlAbl  >õpilane !12_S	et	f	\N
205235	õpilastelt	õpilastelt =las  (PlAbl  >õpi+laps !14_S	et	f	\N
205236	õpilastelt	õpilastelt =laste  (PlAbl  >õpi+last !22_S	et	f	\N
205237	sõnnikoht	?sõnnikoht =sõnnikoht  (SgN  >sõnnikoht !22_S	et	f	\N
205238	venemad	?venemad =venema  (PlN  >venem !02_A	et	f	\N
205256	perpertivsed	?perpertivsed =perpertivse  (PlN  >perpertivne !02_A	et	f	\N
205257	õpitavad	õpitavad =õpitava  (PlN  >õpitav !02_A	et	f	\N
205258	õpitavad	"õpitav %õpi  )TAV_vAS  <õppima ;28_V	et	f	\N
205259	õpitavad	õpitavad =tava  (PlN  >õpi+tava !17_S	et	f	\N
205293	reservuarile	?reservuarile =reservuari  (SgAll  >reservuari !16_S	et	f	\N
205294	reservuarile	?reservuarile =reservuari  (SgAll  >reservuar !19_S	et	f	\N
205297	kevitas	?kevitas =kevita  (IndIpfSg3  >kevitama !27_V	et	f	\N
205301	töötavat	töötavat =tööta  (KvtPrPs  >töötama !27_V	et	f	\N
205303	töötavat	töötavat =töötava  (SgP  >töötav !02_A	et	f	\N
205304	töötavat	"töötav %tööta  )V_vA  <töötama ;27_V	et	f	\N
205309	puhustada	?puhustada =puhusta  (Inf  >puhustama !27_V	et	f	\N
205319	kiri-kutse	kiri-kutse =kutse  (SgN  >kiri-kutse !06_S	et	f	\N
205320	kiri-kutse	kiri-kutse =kutse  (SgG  >kiri-kutse !06_S	et	f	\N
205321	kiri-kutse	kiri-kutse =kutse  (PlP  >kiri-kuts !22_S	et	f	\N
205342	eurointegratsiooni	eurointegratsiooni =integratsiooni  (SgG  >euro+integratsioon !22_S	et	f	\N
205343	eurointegratsiooni	eurointegratsiooni =integratsiooni  (SgP  >euro+integratsioon !22_S	et	f	\N
205344	eurointegratsiooni	eurointegratsiooni =integratsiooni  (SgAdt  >euro+integratsioon !22_S	et	f	\N
205349	catherine	?catherine =catherine  (SgN  >catherine !12_A	et	f	\N
205350	catherine	?catherine =catherine  (PlP  >catherin !19_S	et	f	\N
205367	arreteerisid	arreteerisid =arreteeri  (IndIpfSg2  >arreteerima !28_V	et	f	\N
205368	arreteerisid	arreteerisid =arreteeri  (IndIpfPl3  >arreteerima !28_V	et	f	\N
205378	valvatud	valvatud =valva  (PtsPtIps  >valvama !29_V	et	f	\N
205379	valvatud	valvatud =valvatu  (PlN  >valvatu !01_AS	et	f	\N
205380	valvatud	"valvatu %valva  )TU1_vS  <valvama ;29_V	et	f	\N
205381	valvatud	valvatud =valvatud  (ID  >valvatud !41_A	et	f	\N
205382	valvatud	"valvatud %valva  )TUD_vA  <valvama ;29_V	et	f	\N
205383	süzheega	?süzheega =süzhee  (SgKom  >süzhee !26_S	et	f	\N
205384	süzheega	?süzheega =süzheega  (SgN  >süzheega !16_S	et	f	\N
205385	süzheega	?süzheega =süzheega  (SgG  >süzheega !16_S	et	f	\N
205057	kohanemisvõime	kohanemisvõime =võime  (SgG  >kohanemis+võime !06_S	et	f	\N
205058	kohanemisvõime	kohanemisvõime =võime  (PlP  >kohanemis+võim !22_S	et	f	\N
205061	võluks	võluks =võlu  (SgTr  >võlu !17_S	et	f	\N
205062	võluks	võluks =võlu  (PlTr  >võlg !22_S	et	f	\N
205063	võluks	võluks =võlu  (KndPrPs  >võluma !27_V	et	f	\N
205081	bõnesi	?bõnesi =bõnesi  (ID  >bõnesi !41_D	et	f	\N
205085	tegelikkusse	tegelikkusse =tegelikkus  (SgAdt  >tegelikkus !11_S	et	f	\N
205086	tegelikkusse	"tegelikkus %tegelikku  )US_aS  <tegelik ;25_A	et	f	\N
205094	võimatustest	võimatustest =võimatus  (PlEl  >võimatus !11_S	et	f	\N
205095	võimatustest	"võimatus %või  )MATUS_aS  <võima ;37_V	et	f	\N
205096	võimatustest	võimatustest =matus  (PlEl  >või+matus !09_S	et	f	\N
205112	muutumises	muutumises =muutumise  (SgIn  >muutumine !12_S	et	f	\N
205113	muutumises	"muutumine %muutu  )MINE_vS  <muutuma ;27_V	et	f	\N
205121	muutuv	muutuv =muutu  (PtsPrPs  >muutuma !27_V	et	f	\N
205122	muutuv	muutuv =muutuv  (SgN  >muutuv !02_A	et	f	\N
205123	muutuv	"muutuv %muutu  )V_vA  <muutuma ;27_V	et	f	\N
205124	emme	emme =emme  (SgN  >emme !16_S	et	f	\N
205125	emme	emme =emme  (SgG  >emme !16_S	et	f	\N
205126	emme	emme =emme  (SgG  >emm !22_S	et	f	\N
205127	emme	emme =emme  (SgP  >emm !22_S	et	f	\N
205128	emme	emme =emme  (SgAdt  >emm !22_S	et	f	\N
205129	emme	emme =emme  (PlP  >emm !22_S	et	f	\N
205136	lapsekesega	lapsekesega =lapsekese  (SgKom  >lapseke !12_S	et	f	\N
205137	lapsekesega	"lapseke %lapse  )KE_dS  <laps ;14_S	et	f	\N
205138	lapsekesega	lapsekesega =lapsekese  (SgKom  >lapsekene !12_S	et	f	\N
205139	lapsekesega	"lapsekene %lapse  )KENE_dS  <laps ;14_S	et	f	\N
205144	tabu	tabu =tabu  (SgN  >tabu !17_S	et	f	\N
205145	tabu	tabu =tabu  (SgG  >tabu !17_S	et	f	\N
205146	tabu	tabu =tabu  (SgP  >tabu !17_S	et	f	\N
205152	põhiväärtustega	põhiväärtustega =us  (PlKom  >põhi+väärt+uks !14_S	et	f	\N
205153	põhiväärtustega	põhiväärtustega =väärtus  (PlKom  >põhi+väärtus !11~09_S	et	f	\N
205173	asjalikumaks	asjalikumaks =asjalikuma  (SgTr  >asjalikum !02_A	et	f	\N
205174	asjalikumaks	"asjalikum %asjaliku  )M_cA  <asjalik ;25_A	et	f	\N
205175	muutumisprotsessi	muutumisprotsessi =protsessi  (SgG  >muutu+mis+protsess !22_S	et	f	\N
205176	muutumisprotsessi	muutumisprotsessi =protsessi  (SgP  >muutu+mis+protsess !22_S	et	f	\N
205177	muutumisprotsessi	muutumisprotsessi =protsessi  (SgAdt  >muutu+mis+protsess !22_S	et	f	\N
205192	baltui	?baltui =baltui  (SgN  >baltui !26_S	et	f	\N
205193	baltui	?baltui =baltui  (SgG  >baltui !26_S	et	f	\N
205248	loterejas	?loterejas =lotereja  (SgIn  >lotereja !01_S	et	f	\N
205249	loterejas	?loterejas =lotereja  (SgIn  >loterejas !02_A	et	f	\N
205250	loterejas	?loterejas =loterejas  (SgN  >loterejas !02_A	et	f	\N
205270	kegile	?kegile =kegi  (SgAll  >kegi !17_S	et	f	\N
205271	kegile	?kegile =kegile  (IndPrPs_  >kegilema !27_V	et	f	\N
205272	kegile	?kegile =kegile  (ImpPrSg2  >kegilema !27_V	et	f	\N
205276	enesekindelik	?enesekindelik =enesekindelik  (SgN  >enesekindelik !25_A	et	f	\N
205277	enesekindelik	?enesekindelik =kindelik  (SgN  >enese+kindelik !25_A	et	f	\N
205278	ettearvamatu	ettearvamatu =arvamatu  (SgN  >ette+arvamatu !01_A	et	f	\N
205279	ettearvamatu	ettearvamatu =arvamatu  (SgG  >ette+arvamatu !01_A	et	f	\N
205280	idamaal	idamaal =maa  (SgAd  >ida+maa !26_S	et	f	\N
205281	idamaal	idamaal =maal  (SgN  >ida+maal !22_S	et	f	\N
205327	emigratsiooni	emigratsiooni =emigratsiooni  (SgG  >emigratsioon !22_S	et	f	\N
205328	emigratsiooni	emigratsiooni =emigratsiooni  (SgP  >emigratsioon !22_S	et	f	\N
205329	emigratsiooni	emigratsiooni =emigratsiooni  (SgAdt  >emigratsioon !22_S	et	f	\N
205333	osalisi	osalisi =osalisi  (PlP  >osaline !12_SA	et	f	\N
205334	osalisi	"osaline %osa  )LINE_aA  <osa ;17_S	et	f	\N
205345	uusima	"uusim %uus  )IM_sA  <uus ;14_A	et	f	\N
205346	uusima	uusima =ima  (SgN  >uus+ima !17_S	et	f	\N
205347	uusima	uusima =ima  (SgG  >uus+ima !17_S	et	f	\N
205348	uusima	uusima =ima  (SgP  >uus+ima !17_S	et	f	\N
205352	andrejev	?andrejev =andrejev  (SgN  >andrejev !02_A	et	f	\N
205369	praha	?praha =praha  (SgN  >praha !17_S	et	f	\N
205370	praha	?praha =praha  (SgG  >praha !17_S	et	f	\N
205371	praha	?praha =praha  (SgP  >praha !17_S	et	f	\N
205372	praha	?praha =praha  (IndPrPs_  >prahama !27_V	et	f	\N
205373	praha	?praha =praha  (ImpPrSg2  >prahama !27_V	et	f	\N
205377	nandrejev	?nandrejev =nandrejev  (SgN  >nandrejev !02_A	et	f	\N
205428	hilinem	?hilinem =hilinem  (SgN  >hilinem !02_A	et	f	\N
205448	vanadrahvalaulud	?vanadrahvalaulud =vanadrahvalaulu  (IndPrSg2  >vanadrahvalauluma !27_V	et	f	\N
205527	osalejat	osalejat =osaleja  (SgP  >osaleja !01_S	et	f	\N
205528	osalejat	"osaleja %osale  )JA_vS  <osalema ;27_V	et	f	\N
205543	põhjaloodus	põhjaloodus =loodu  (SgIn  >põhja+loodu !01_S	et	f	\N
205544	põhjaloodus	põhjaloodus =loodus  (SgN  >põhja+loodus !11~09_S	et	f	\N
205573	isamaalaulust	isamaalaulust =lust  (SgN  >isa+maa+lau+lust !22_S	et	f	\N
205574	isamaalaulust	isamaalaulust =laulu  (SgEl  >isa+maa+laul !22_S	et	f	\N
205583	rok	### rok	et	f	\N
205584	ansamleid	?ansamleid =ansamle  (PlP  >ansamli !01_S	et	f	\N
205104	kääkirja	?kääkirja =kääkirja  (SgG  >kääkirjas !02_A	et	f	\N
205105	kääkirja	?kääkirja =kääkirja  (SgG  >kääkirja !16_S	et	f	\N
205116	aastakümnete	### aastakümnete	et	f	\N
205130	emme	emme =emme  (SgN  >emme !16_S	et	f	\N
205131	emme	emme =emme  (SgG  >emme !16_S	et	f	\N
205132	emme	emme =emme  (SgG  >emm !22_S	et	f	\N
205133	emme	emme =emme  (SgP  >emm !22_S	et	f	\N
205134	emme	emme =emme  (SgAdt  >emm !22_S	et	f	\N
205135	emme	emme =emme  (PlP  >emm !22_S	et	f	\N
205154	lahutusi	lahutusi =lahutusi  (PlP  >lahutus !11_S	et	f	\N
205155	lahutusi	"lahutus %lahuta  )US_vS  <lahutama ;27_V	et	f	\N
205156	lahutusi	"lahutus %lahu  )TUS2_aS  <lahk ;22_S	et	f	\N
205180	roolis	roolis =rooli  (SgIn  >rool !22_S	et	f	\N
205181	roolis	roolis =rooli  (IndIpfSg3  >roolima !28_V	et	f	\N
205182	mõistva	mõistva =mõistva  (SgG  >mõistev !02_A	et	f	\N
205183	mõistva	"mõistev %mõist  )V_vA  <mõistma ;34_V	et	f	\N
205184	toetav	toetav =toeta  (PtsPrPs  >toetama !27_V	et	f	\N
205185	toetav	toetav =toetav  (SgN  >toetav !02_A	et	f	\N
205186	toetav	"toetav %toeta  )V_vA  <toetama ;27_V	et	f	\N
205215	aimekirjandus	?aimekirjandus =aimekirjandu  (IndIpfSg3  >aimekirjanduma !27_V	et	f	\N
205216	aimekirjandus	?aimekirjandus =aimekirjandus  (SgN  >aimekirjandus !11_S	et	f	\N
205222	k-i	k-i =k  (SgG  >k !xx_Q	et	f	\N
205223	k-i	k-i =k  (SgP  >k !xx_Q	et	f	\N
205224	k-i	k-i =k  (SgAdt  >k !xx_Q	et	f	\N
205240	abisaamiseks	abisaamiseks =saamise  (SgTr  >abi+saamine !12?10_S	et	f	\N
205241	abisaamiseks	"abi+saamine %saami  )NE_aA  <abi+saam ;22_S	et	f	\N
205243	vanemadest	?vanemadest =vanemades  (SgP  >vanemadene !12_A	et	f	\N
205244	vanemadest	?vanemadest =ade  (SgEl  >vanem+ade !16_S	et	f	\N
205245	vanemadest	?vanemadest =ades  (SgP  >vanem+ades !09_S	et	f	\N
205246	vanemadest	?vanemadest =ades  (SgP  >vanem+adene !10_A	et	f	\N
205263	iseloomist	iseloomist =loomi  (SgEl  >ise+loom !22_S	et	f	\N
205264	iseloomist	iseloomist =loomi  (PlEl  >ise+loom !22_S	et	f	\N
205265	iseloomist	iseloomist =loomis  (SgP  >ise+loomis !09_S	et	f	\N
205266	iseloomist	iseloomist =loomis  (SgP  >ise+loomine !12?10_S	et	f	\N
205267	iseloomist	"ise+loomine %loomi  )NE_aA  <ise+loom ;22_S	et	f	\N
205268	sübrad	?sübrad =sübra  (PlN  >sübra !16_S	et	f	\N
205269	sübrad	?sübrad =sübra  (IndPrSg2  >sübrama !27_V	et	f	\N
205282	neiul	neiul =neiu  (SgAd  >neiu !16_S	et	f	\N
205283	neiul	neiul =neiu  (SgAd  >neid !22_S	et	f	\N
205295	nuppule	?nuppule =nuppule  (IndPrPs_  >nuppulema !27_V	et	f	\N
205296	nuppule	?nuppule =nuppule  (ImpPrSg2  >nuppulema !27_V	et	f	\N
205305	niiskust	niiskust =niiskus  (SgP  >niiskus !11~09_S	et	f	\N
205306	niiskust	"niiskus %niiske  )US_aS  <niiske ;01_A	et	f	\N
205307	katlakivist	katlakivist =kivi  (SgEl  >katla+kivi !17_S	et	f	\N
205308	katlakivist	katlakivist =kivis  (SgP  >katla+kivine !10_A	et	f	\N
205310	katlakivist	"katla+kivine %kivi  )NE_aA  <katla+kivi ;17_S	et	f	\N
205311	valimus	valimus =valimus  (SgN  >valimus !11_S	et	f	\N
205312	valimus	"valimus %vali  )MUS_vS  <valima ;27_V	et	f	\N
205318	kõikel	?kõikel =kõikel  (SgN  >kõikel !02_S	et	f	\N
205322	teadusseminari	teadusseminari =seminari  (SgG  >teadus+seminar !19_S	et	f	\N
205323	teadusseminari	teadusseminari =seminari  (SgP  >teadus+seminar !19_S	et	f	\N
205324	teadusseminari	teadusseminari =seminari  (SgAdt  >teadus+seminar !19_S	et	f	\N
205337	ühiskonnategelastevahelise	ühiskonnategelastevahelise =vahelise  (SgG  >ühis+konna+tegelaste+vaheline !12_A	et	f	\N
205338	ühiskonnategelastevahelise	"ühis+konna+tegelaste+vaheline %vahe  )LINE_aA  <ühis+konna+tegelaste+vahe ;16_S	et	f	\N
205339	teadvuses	teadvuses =teadvuse  (SgIn  >teadvus !11~09_S	et	f	\N
205340	teadvuses	"teadvus %tead  )VUS_aS  <teadma ;34_V	et	f	\N
205341	teadvuses	"teadvus %teadva  )US_aS  <teadev ;02_A	et	f	\N
205359	prahasse	?prahasse =praha  (SgIll  >praha !17_S	et	f	\N
205360	prahasse	?prahasse =prahasse  (SgG  >prahasne !02_A	et	f	\N
205361	prahasse	?prahasse =prahasse  (PlP  >prahass !22_S	et	f	\N
205365	nkondakovi	?nkondakovi =nkondakovi  (ID  >nkondakovi !41_D	et	f	\N
205366	nkondakovi	?nkondakovi =nkondakovi  (SgG  >nkondakov !02_A	et	f	\N
205386	konverentsi	konverentsi =konverentsi  (SgG  >konverents !22_S	et	f	\N
205387	konverentsi	konverentsi =konverentsi  (SgP  >konverents !22_S	et	f	\N
205388	konverentsi	konverentsi =konverentsi  (SgAdt  >konverents !22_S	et	f	\N
205405	zanrid	?zanrid =zanri  (PlN  >zanri !16_S	et	f	\N
205406	zanrid	?zanrid =zanri  (PlN  >zanr !22_S	et	f	\N
205407	zanrid	?zanrid =zanri  (IndPrSg2  >zanrima !28_V	et	f	\N
205429	laulut	?laulut =laulu  (SgP  >laulu !16_S	et	f	\N
205430	laulut	?laulut =laulut  (SgN  >laulut !02_S	et	f	\N
205453	siinme	?siinme =siinme  (SgN  >siinme !06_S	et	f	\N
205454	siinme	?siinme =siinme  (SgG  >siinme !06_S	et	f	\N
205455	siinme	?siinme =siinme  (PlP  >siinm !22_S	et	f	\N
205456	siinme	?siinme =siinme  (IndPrPs_  >siinmema !27_V	et	f	\N
205457	siinme	?siinme =siinme  (ImpPrSg2  >siinmema !27_V	et	f	\N
205465	laulipidu	?laulipidu =laulipidu  (IndPrPs_  >laulipiduma !27_V	et	f	\N
205466	laulipidu	?laulipidu =laulipidu  (ImpPrSg2  >laulipiduma !27_V	et	f	\N
205227	usuta	usuta =usu  (SgAb  >usk !22_S	et	f	\N
205228	usuta	usuta =usu  (IndPrIps_  >uskuma !28_V	et	f	\N
205229	usuta	usuta =usuta  (IndPrPs_  >usutama !27_V	et	f	\N
205230	usuta	usuta =usuta  (ImpPrSg2  >usutama !27_V	et	f	\N
205239	niiedasi	?niiedasi =niiedasi  (PlP  >niiedane !12_A	et	f	\N
205242	aprem	?aprem =aprem  (SgN  >aprem !02_A	et	f	\N
205260	seisib	?seisib =seisi  (IndPrSg3  >seisima !28_V	et	f	\N
205284	panellis	?panellis =panelli  (SgIn  >panelli !01_S	et	f	\N
205285	panellis	?panellis =panelli  (SgIn  >panell !22_S	et	f	\N
205286	panellis	?panellis =panelli  (IndIpfSg3  >panellima !28_V	et	f	\N
205287	panellis	?panellis =panellis  (SgN  >panellis !11_S	et	f	\N
205290	kallake	kallake =kalla  (ImpPrPl2  >kallama !29_V	et	f	\N
205291	kallake	kallake =kallake  (SgN  >kallake !12_S	et	f	\N
205292	kallake	"kallake %kalla  )KE_dS  <kalla ;16_S	et	f	\N
205298	keelamine	keelamine =keelamine  (SgN  >keelamine !12_S	et	f	\N
205299	keelamine	"keelamine %keela  )MINE_vS  <keelama ;29_V	et	f	\N
205300	seadet	seadet =seade  (SgP  >seade !05_S	et	f	\N
205302	seadet	seadet =seade  (SgP  >seade !06_S	et	f	\N
205313	sünnikohast	sünnikohast =koha  (SgEl  >sünni+koha !17_S	et	f	\N
205314	sünnikohast	sünnikohast =koha  (SgEl  >sünni+koht !22_S	et	f	\N
205315	sünnikohast	sünnikohast =kohas  (SgP  >sünni+kohane !10_A	et	f	\N
205316	sünnikohast	"sünni+kohane %koha  )NE_aA  <sünni+koha ;17_S	et	f	\N
205317	sünnikohast	"sünni+kohane %koha  )NE_aA  <sünni+koht ;22_S	et	f	\N
205325	vnemaalt	?vnemaalt =vnemaa  (SgAbl  >vnemaa !26_S	et	f	\N
205326	vnemaalt	?vnemaalt =vnemaalt  (ID  >vnemaalt !41_D	et	f	\N
205335	suundumusi	suundumusi =suundumusi  (PlP  >suundumus !11_S	et	f	\N
205336	suundumusi	"suundumus %suundu  )MUS_vS  <suunduma ;27_V	et	f	\N
205362	nandrejevist	?nandrejevist =nandrejevi  (SgEl  >nandrejev !02_A	et	f	\N
205363	nandrejevist	?nandrejevist =nandrejevis  (SgP  >nandrejevis !09_S	et	f	\N
205364	nandrejevist	?nandrejevist =nandrejevist  (SgN  >nandrejevist !22_S	et	f	\N
205397	vokaalnelaulud	?vokaalnelaulud =vokaalnelaulu  (IndPrSg2  >vokaalnelauluma !27_V	et	f	\N
205398	vokaalnelaulud	?vokaalnelaulud =nelaulu  (PlN  >vokaal+nelaulu !01_S	et	f	\N
205408	periiodil	?periiodil =periiodi  (SgAd  >periiodi !16_S	et	f	\N
205409	periiodil	?periiodil =periiodi  (SgAd  >periiot !22_S	et	f	\N
205410	periiodil	?periiodil =periiodil  (SgN  >periiodil !02_S	et	f	\N
205411	regivärsiliset	### regivärsiliset	et	f	\N
205426	vanaajalised	vanaajalised =ajalise  (PlN  >vana+ajaline !12_A	et	f	\N
205427	vanaajalised	"vana+ajaline %aja  )LINE_aA  <vana+aeg ;22_S	et	f	\N
205439	kuultuuri	kuultuuri =tuuri  (SgG  >kuul+tuur !22_S	et	f	\N
205440	kuultuuri	kuultuuri =tuuri  (SgP  >kuul+tuur !22_S	et	f	\N
205441	kuultuuri	kuultuuri =tuuri  (SgAdt  >kuul+tuur !22_S	et	f	\N
205442	kuultuuri	kuultuuri =tuuri  (PlP  >kuul+tuur !22_S	et	f	\N
205443	lõuna-ida	lõuna-ida =ida  (SgN  >lõuna-ida !17_S	et	f	\N
205444	lõuna-ida	lõuna-ida =ida  (SgG  >lõuna-ida !17_S	et	f	\N
205445	lõuna-ida	lõuna-ida =ida  (SgP  >lõuna-ida !17_S	et	f	\N
205462	koigepealt	?koigepealt =koigepea  (SgAbl  >koigepea !26_S	et	f	\N
205463	koigepealt	?koigepealt =koigepealt  (ID  >koigepealt !41_D	et	f	\N
205464	koigepealt	?koigepealt =gepea  (SgAbl  >koi+gepea !26_S	et	f	\N
205469	kohtal	?kohtal =kohtal  (SgN  >kohtal !02_S	et	f	\N
205486	välismaased	?välismaased =välismaase  (PlN  >välismaase !16_S	et	f	\N
205487	välismaased	?välismaased =maase  (PlN  >välis+maane !10_A	et	f	\N
205488	välismaased	?välismaased =maase  (PlN  >välis+maase !06_S	et	f	\N
205489	välismaased	?välismaased =smaase  (PlN  >väli+smaane !10_A	et	f	\N
205490	välismaased	?välismaased =smaase  (PlN  >väli+smaase !06_S	et	f	\N
205502	tugene	?tugene =tugene  (SgN  >tugene !10_A	et	f	\N
205503	tugene	?tugene =tugene  (IndPrPs_  >tugenema !27_V	et	f	\N
205504	tugene	?tugene =tugene  (ImpPrSg2  >tugenema !27_V	et	f	\N
205513	vaatemangu	?vaatemangu =vaatemangu  (SgG  >vaatemang !02_S	et	f	\N
205514	vaatemangu	?vaatemangu =vaatemangu  (IndPrPs_  >vaatemanguma !27_V	et	f	\N
205515	vaatemangu	?vaatemangu =vaatemangu  (ImpPrSg2  >vaatemanguma !27_V	et	f	\N
205516	vaatemangu	?vaatemangu =mangu  (SgP  >vaate+mang !22_S	et	f	\N
205517	vaatemangu	?vaatemangu =mangu  (SgAdt  >vaate+mang !22_S	et	f	\N
205524	üldlaulu-	üldlaulu- =laulu  (SgG  >üld+laul !22_S	et	f	\N
205525	üldlaulu-	üldlaulu- =laulu  (SgP  >üld+laul !22_S	et	f	\N
205526	üldlaulu-	üldlaulu- =laulu  (SgAdt  >üld+laul !22_S	et	f	\N
205534	heelingud	?heelingud =heelingu  (PlN  >heelingu !01_S	et	f	\N
205535	heelingud	?heelingud =heelingu  (PlN  >heeling !02_S	et	f	\N
205536	heelingud	?heelingud =heelingu  (IndPrSg2  >heelinguma !27_V	et	f	\N
205567	läksivad	?läksivad =läksi  (IndPrPl3  >läksima !28_V	et	f	\N
205568	läksivad	?läksivad =läksiva  (PlN  >läksiva !01_S	et	f	\N
205569	läksivad	?läksivad =läksiva  (PlN  >läksiv !02_A	et	f	\N
205580	tantisid	?tantisid =tanti  (PlP  >tant !22_S	et	f	\N
205581	tantisid	?tantisid =tanti  (IndIpfSg2  >tantima !28_V	et	f	\N
205582	tantisid	?tantisid =tanti  (IndIpfPl3  >tantima !28_V	et	f	\N
205587	kukkerpillid	?kukkerpillid =kukkerpilli  (PlN  >kukkerpill !22_S	et	f	\N
205247	abida	?abida =abi  (Inf  >abima !27_V	et	f	\N
205251	kohtla-jerve	?kohtla-jerve =jerve  (SgN  >kohtla-jerve !06_S	et	f	\N
205252	kohtla-jerve	?kohtla-jerve =jerve  (SgG  >kohtla-jerve !06_S	et	f	\N
205253	kohtla-jerve	?kohtla-jerve =jerve  (PlP  >kohtla-jerv !22_S	et	f	\N
205254	kohtla-jerve	?kohtla-jerve =jerve  (IndPrPs_  >kohtla-jervema !27_V	et	f	\N
205255	kohtla-jerve	?kohtla-jerve =jerve  (ImpPrSg2  >kohtla-jervema !27_V	et	f	\N
205261	problema	?problema =proble  (Sup  >problema !30_V	et	f	\N
205262	problema	?problema =problema  (SgG  >problem !02_A	et	f	\N
205273	tingimusest	tingimusest =tingimuse  (SgEl  >tingimus !11_S	et	f	\N
205274	tingimusest	tingimusest =tingimuses  (SgP  >tingimusene !12_A	et	f	\N
205275	tingimusest	"tingimusene %tingimuse  )NE_aA  <tingimus ;11_S	et	f	\N
205288	programmivalija	programmivalija =valija  (SgN  >programmi+valija !01_S	et	f	\N
205289	programmivalija	programmivalija =valija  (SgG  >programmi+valija !01_S	et	f	\N
205330	emigratsiooniprotsessi	emigratsiooniprotsessi =protsessi  (SgG  >emigratsiooni+protsess !22_S	et	f	\N
205331	emigratsiooniprotsessi	emigratsiooniprotsessi =protsessi  (SgP  >emigratsiooni+protsess !22_S	et	f	\N
205332	emigratsiooniprotsessi	emigratsiooniprotsessi =protsessi  (SgAdt  >emigratsiooni+protsess !22_S	et	f	\N
205351	andreyev	?andreyev =andreyev  (SgN  >andreyev !22_S	et	f	\N
205353	11aastaselt	aastaselt =aastase  (SgAbl  >aastane !12~10_A	et	f	\N
205354	11aastaselt	"aastane %aasta  )NE_aA  <aasta ;01_S	et	f	\N
205355	11aastaselt	aastaselt =aastaselt  (ID  >aastaselt !41_D	et	f	\N
205356	11aastaselt	"aastaselt %aasta  )SELT_mD  <aasta ;01_S	et	f	\N
205357	11aastaselt	"aastaselt %aastase  )LT_mD  <aastane ;10_A	et	f	\N
205358	11aastaselt	"aastaselt %aastase  )LT_mD  <aastane ;12_A	et	f	\N
205374	natsivõimust	natsivõimust =must  (SgN  >natsi+või+must !22_AS	et	f	\N
205375	natsivõimust	natsivõimust =võimu  (SgEl  >natsi+võim !22_S	et	f	\N
205376	natsivõimust	natsivõimust =võimus  (SgP  >natsi+võimus !09_S	et	f	\N
205389	töökeeleks	töökeeleks =keele  (SgTr  >töö+keel !13_S	et	f	\N
205390	töökeeleks	töökeeleks =keele  (PlTr  >töö+keeld !22_S	et	f	\N
205394	rahvalauluajaloost	rahvalauluajaloost =loo  (SgEl  >rahva+laulu+aja+lugu !18_S	et	f	\N
205395	rahvalauluajaloost	rahvalauluajaloost =loo  (SgEl  >rahva+laulu+aja+loog !22_S	et	f	\N
205396	rahvalauluajaloost	rahvalauluajaloost =loo  (SgEl  >rahva+laulu+aja+lood !22_S	et	f	\N
205399	laulutraditsioonitel	?laulutraditsioonitel =laulutraditsioonite  (PlAd  >laulutraditsioonitt !22_S	et	f	\N
205400	laulutraditsioonitel	?laulutraditsioonitel =traditsioonite  (PlAd  >laulu+traditsioonitt !22_S	et	f	\N
205401	laulutraditsioonitel	?laulutraditsioonitel =lutraditsioonite  (PlAd  >lau+lutraditsioonitt !22_S	et	f	\N
205402	ravhas	?ravhas =ravha  (SgIn  >ravha !16_S	et	f	\N
205403	ravhas	?ravhas =ravha  (IndIpfSg3  >ravhama !29_V	et	f	\N
205404	ravhas	?ravhas =ravhas  (SgN  >ravhas !07_S	et	f	\N
205437	väljavõetud	väljavõetud =võe  (PtsPtIps  >välja+_võtma !35_V	et	f	\N
205438	väljavõetud	väljavõetud =võetu  (PlN  >välja+võetu !01_S	et	f	\N
205449	võttsid	?võttsid =võttsi  (PlN  >võtts !22_S	et	f	\N
205450	võttsid	?võttsid =võttsi  (IndPrSg2  >võttsima !28_V	et	f	\N
205458	eestirahvast	eestirahvast =rahva  (SgEl  >eesti+rahvas !07_S	et	f	\N
205459	eestirahvast	eestirahvast =rahvas  (SgP  >eesti+rahvas !07_S	et	f	\N
205460	eestirahvast	eestirahvast =rahvas  (SgP  >eesti+rahvane !10_A	et	f	\N
205461	eestirahvast	"eesti+rahvane %rahva  )NE_aA  <eesti+rahvas ;07_S	et	f	\N
205482	monopoolist	monopoolist =pooli  (SgEl  >mono+pool !22_S	et	f	\N
205483	monopoolist	monopoolist =poolis  (SgP  >mono+poolis !09_S	et	f	\N
205484	monopoolist	monopoolist =poolis  (SgP  >mono+pooline !10_S	et	f	\N
205485	monopoolist	"mono+pooline %pooli  )NE_aA  <mono+pool ;22_S	et	f	\N
205537	seelline	?seelline =seelline  (SgN  >seelline !12~10_A	et	f	\N
205538	seelline	?seelline =seelline  (IndPrPs_  >seellinema !27_V	et	f	\N
205539	seelline	?seelline =seelline  (ImpPrSg2  >seellinema !27_V	et	f	\N
205540	alikas	?alikas =alika  (SgIn  >alika !01_S	et	f	\N
205541	alikas	?alikas =alika  (SgIn  >alikas !02_S	et	f	\N
205542	alikas	?alikas =alikas  (SgN  >alikas !02_S	et	f	\N
205545	europasse	europasse =passe  (SgN  >euro+passe !16_S	et	f	\N
205546	europasse	europasse =passe  (SgG  >euro+passe !16_S	et	f	\N
205547	europasse	europasse =passe  (PlP  >euro+pass !22_S	et	f	\N
205548	tantsurahvas	tantsurahvas =rahva  (SgIn  >tantsu+rahvas !07_S	et	f	\N
205549	tantsurahvas	tantsurahvas =rahvas  (SgN  >tantsu+rahvas !07_S	et	f	\N
205571	tehtsad	?tehtsad =tehtsa  (PlN  >tehtsa !01_S	et	f	\N
205572	tehtsad	?tehtsad =tehtsa  (IndPrSg2  >tehtsama !29_V	et	f	\N
205577	näidavad	näidavad =näidava  (PlN  >näidav !02_A	et	f	\N
205578	näidavad	"näidav %näi  )TAV_vAS  <näima ;37_V	et	f	\N
205579	telefonit	?telefonit =fonit  (SgN  >tele+fonit !02_S	et	f	\N
205594	sinad	sinad =sina  (PlN  >sina !17_S	et	f	\N
205595	sinad	sinad =sina  (IndPrSg2  >sinama !27_V	et	f	\N
205600	esitlevad	esitlevad =esitle  (IndPrPl3  >esitlema !27_V	et	f	\N
205601	esitlevad	esitlevad =esitleva  (PlN  >esitlev !02_A	et	f	\N
205602	esitlevad	"esitlev %esitle  )V_vA  <esitlema ;27_V	et	f	\N
205603	määletab	?määletab =määleta  (IndPrSg3  >määletama !27_V	et	f	\N
205618	vennatega	### vennatega	et	f	\N
205391	rahvaajaloost	rahvaajaloost =loo  (SgEl  >rahva+aja+lugu !18_S	et	f	\N
205392	rahvaajaloost	rahvaajaloost =loo  (SgEl  >rahva+aja+loog !22_S	et	f	\N
205393	rahvaajaloost	rahvaajaloost =loo  (SgEl  >rahva+aja+lood !22_S	et	f	\N
205412	rahvalaulut	?rahvalaulut =laulu  (SgP  >rahva+laulu !16_S	et	f	\N
205413	rahvalaulut	?rahvalaulut =laulut  (SgN  >rahva+laulut !02_S	et	f	\N
205414	kultuuriidentiteeti	?kultuuriidentiteeti =kultuuriidentiteeti  (SgN  >kultuuriidentiteeti !16_S	et	f	\N
205415	kultuuriidentiteeti	?kultuuriidentiteeti =kultuuriidentiteeti  (SgG  >kultuuriidentiteeti !16_S	et	f	\N
205416	kultuuriidentiteeti	?kultuuriidentiteeti =kultuuriidentiteeti  (SgP  >kultuuriidentiteet !22_S	et	f	\N
205417	kultuuriidentiteeti	?kultuuriidentiteeti =kultuuriidentiteeti  (SgAdt  >kultuuriidentiteet !22_S	et	f	\N
205418	kultuuriidentiteeti	?kultuuriidentiteeti =identiteeti  (SgN  >kultuuri+identiteeti !16_S	et	f	\N
205419	kultuuriidentiteeti	?kultuuriidentiteeti =identiteeti  (SgG  >kultuuri+identiteeti !16_S	et	f	\N
205420	kultuuriidentiteeti	?kultuuriidentiteeti =identiteeti  (SgP  >kultuuri+identiteet !22_S	et	f	\N
205421	kultuuriidentiteeti	?kultuuriidentiteeti =identiteeti  (SgAdt  >kultuuri+identiteet !22_S	et	f	\N
205422	kultuuriidentiteeti	?kultuuriidentiteeti =iidentiteeti  (SgN  >kultuur+iidentiteeti !16_S	et	f	\N
205423	kultuuriidentiteeti	?kultuuriidentiteeti =iidentiteeti  (SgG  >kultuur+iidentiteeti !16_S	et	f	\N
205424	kultuuriidentiteeti	?kultuuriidentiteeti =iidentiteeti  (SgP  >kultuur+iidentiteet !22_S	et	f	\N
205425	kultuuriidentiteeti	?kultuuriidentiteeti =iidentiteeti  (SgAdt  >kultuur+iidentiteet !22_S	et	f	\N
205431	põhimõtselt	?põhimõtselt =põhimõtse  (SgAbl  >põhimõtne !02_A	et	f	\N
205432	põhimõtselt	?põhimõtselt =põhimõtse  (PlAbl  >põhimõts !22_S	et	f	\N
205433	põhimõtselt	?põhimõtselt =põhimõtselt  (ID  >põhimõtselt !41_D	et	f	\N
205434	põhimõtselt	?põhimõtselt =mõtse  (SgAbl  >põhi+mõtne !02_A	et	f	\N
205435	põhimõtselt	?põhimõtselt =mõtse  (SgAbl  >põhi+mõtse !06_S	et	f	\N
205436	põhimõtselt	?põhimõtselt =mõtse  (PlAbl  >põhi+mõts !22_S	et	f	\N
205446	teguvusena	?teguvusena =teguvuse  (SgEs  >teguvus !11_S	et	f	\N
205447	teguvusena	?teguvusena =vuse  (SgEs  >tegu+vuse !16_S	et	f	\N
205451	lisanduti	lisanduti =lisandu  (IndIpfIps  >lisanduma !27_V	et	f	\N
205452	lisanduti	lisanduti =uti  (SgG  >lisand+utt !22_S	et	f	\N
205470	väljendanud	väljendanud =väljenda  (PtsPtPs  >väljendama !27_V	et	f	\N
205471	väljendanud	väljendanud =väljendanu  (PlN  >väljendanu !01_S	et	f	\N
205472	väljendanud	"väljendanu %väljenda  )NU_vS  <väljendama ;27_V	et	f	\N
205473	väljendanud	väljendanud =väljendanud  (ID  >väljendanud !41_A	et	f	\N
205474	väljendanud	"väljendanud %väljenda  )NUD_vA  <väljendama ;27_V	et	f	\N
205479	vilumus	vilumus =vilumus  (SgN  >vilumus !11_S	et	f	\N
205480	vilumus	"vilumus %vilu  )MUS_vS  <viluma ;27_V	et	f	\N
205481	vilumus	"vilumus %viluma  )US_aS  <vilum ;02_A	et	f	\N
205491	mehikoori	?mehikoori =mehikoori  (SgN  >mehikoori !16_S	et	f	\N
205492	mehikoori	?mehikoori =mehikoori  (SgG  >mehikoori !16_S	et	f	\N
205493	mehikoori	?mehikoori =mehikoori  (SgG  >mehikoor !22_S	et	f	\N
205494	mehikoori	?mehikoori =mehikoori  (SgP  >mehikoor !22_S	et	f	\N
205495	mehikoori	?mehikoori =mehikoori  (SgAdt  >mehikoor !22_S	et	f	\N
205496	mehikoori	?mehikoori =mehikoori  (IndPrPs_  >mehikoorima !28_V	et	f	\N
205497	mehikoori	?mehikoori =mehikoori  (ImpPrSg2  >mehikoorima !28_V	et	f	\N
205506	tragitsioone	?tragitsioone =tragitsioone  (SgN  >tragitsioone !16_S	et	f	\N
205507	tragitsioone	?tragitsioone =tragitsioone  (SgG  >tragitsioone !16_S	et	f	\N
205508	tragitsioone	?tragitsioone =tragitsioone  (PlP  >tragitsioon !22_S	et	f	\N
205509	tragitsioone	?tragitsioone =tsioone  (SgN  >tragi+tsioone !12~10_A	et	f	\N
205510	tragitsioone	?tragitsioone =tsioone  (PlP  >tragi+tsioon !22_S	et	f	\N
205518	spordistadionil	?spordistadionil =spordistadioni  (SgAd  >spordistadioni !16_S	et	f	\N
205519	spordistadionil	?spordistadionil =spordistadioni  (SgAd  >spordistadion !19_S	et	f	\N
205520	spordistadionil	?spordistadionil =spordistadionil  (SgN  >spordistadionil !02_S	et	f	\N
205521	spordistadionil	?spordistadionil =stadioni  (SgAd  >spordi+stadioni !16_S	et	f	\N
205522	spordistadionil	?spordistadionil =stadioni  (SgAd  >spordi+stadion !19_S	et	f	\N
205523	spordistadionil	?spordistadionil =stadionil  (SgN  >spordi+stadionil !02_S	et	f	\N
205559	härma	härma =härma  (ID  >härma !41_D	et	f	\N
205560	härma	härma =härma  (SgG  >härm !22_S	et	f	\N
205561	härma	härma =härma  (SgP  >härm !22_S	et	f	\N
205562	härma	härma =härma  (SgAdt  >härm !22_S	et	f	\N
205563	härma	härma =härma  (IndPrPs_  >härmama !29_V	et	f	\N
205564	härma	härma =härma  (ImpPrSg2  >härmama !29_V	et	f	\N
205565	bentoni	?bentoni =bento  (SgTer  >bento !16_S	et	f	\N
205566	bentoni	?bentoni =bentoni  (SgG  >benton !02_S	et	f	\N
205575	rehvatantsu	?rehvatantsu =rehvatantsu  (IndPrPs_  >rehvatantsuma !27_V	et	f	\N
205576	rehvatantsu	?rehvatantsu =rehvatantsu  (ImpPrSg2  >rehvatantsuma !27_V	et	f	\N
205593	rägime	?rägime =rägi  (IndPrPl1  >rägima !27_V	et	f	\N
205619	spontaalset	?spontaalset =spontaalse  (SgP  >spontaalne !02_A	et	f	\N
205620	programeeritud	?programeeritud =programeeri  (PtsPtIps  >programeerima !28_V	et	f	\N
205621	programeeritud	?programeeritud =programeeritu  (PlN  >programeeritu !01_S	et	f	\N
205622	programeeritud	?programeeritud =programeeritu  (IndPrSg2  >programeerituma !27_V	et	f	\N
205467	laulipidu	?laulipidu =lipidu  (SgN  >lau+lipidu !01_S	et	f	\N
205468	laulipidu	?laulipidu =lipidu  (SgG  >lau+lipidu !01_S	et	f	\N
205475	jututatakse	?jututatakse =jututa  (IndPrIps  >jututama !27_V	et	f	\N
205476	jututatakse	?jututatakse =jututatakse  (SgG  >jututatakne !02_A	et	f	\N
205477	jututatakse	?jututatakse =jututatakse  (PlP  >jututataks !22_S	et	f	\N
205478	jututatakse	?jututatakse =tatakse  (SgG  >jutu+tatakne !02_A	et	f	\N
205498	isamalaulu	?isamalaulu =isamalaulu  (IndPrPs_  >isamalauluma !27_V	et	f	\N
205499	isamalaulu	?isamalaulu =isamalaulu  (ImpPrSg2  >isamalauluma !27_V	et	f	\N
205500	isamalaulu	?isamalaulu =malaulu  (SgN  >isa+malaulu !01_S	et	f	\N
205501	isamalaulu	?isamalaulu =malaulu  (SgG  >isa+malaulu !01_S	et	f	\N
205505	tegelikkult	?tegelikkult =tegelikkult  (ID  >tegelikkult !41_D	et	f	\N
205511	juulikuu	juulikuu =kuu  (SgN  >juuli+kuu !26_S	et	f	\N
205512	juulikuu	juulikuu =kuu  (SgG  >juuli+kuu !26_S	et	f	\N
205529	väljakult	väljakult =väljaku  (SgAbl  >väljak !02_S	et	f	\N
205530	väljakult	väljakult =kult  (SgN  >välja+kult !22_S	et	f	\N
205531	kulavad	?kulavad =kula  (IndPrPl3  >kulama !27_V	et	f	\N
205532	kulavad	?kulavad =kulava  (PlN  >kulava !01_S	et	f	\N
205533	kulavad	?kulavad =kulava  (PlN  >kulav !02_A	et	f	\N
205550	maletavad	maletavad =maleta  (IndPrPl3  >maletama !27_V	et	f	\N
205551	maletavad	maletavad =maletava  (PlN  >maletav !02_A	et	f	\N
205552	maletavad	"maletav %maleta  )V_vA  <maletama ;27_V	et	f	\N
205553	maletavad	maletavad =tava  (PlN  >male+tava !17_S	et	f	\N
205554	miina	?miina =mii  (SgEs  >mii !26_S	et	f	\N
205555	miina	?miina =miina  (SgN  >miina !16_S	et	f	\N
205556	miina	?miina =miina  (SgG  >miina !16_S	et	f	\N
205557	miina	?miina =miina  (IndPrPs_  >miinama !29_V	et	f	\N
205558	miina	?miina =miina  (ImpPrSg2  >miinama !29_V	et	f	\N
205570	määletused	?määletused =määletuse  (PlN  >määletus !11_S	et	f	\N
205612	osavõtlesin	?osavõtlesin =osavõtlesin  (SgN  >osavõtlesin !19_S	et	f	\N
205613	osavõtlesin	?osavõtlesin =võtlesin  (SgN  >osa+võtlesin !19_S	et	f	\N
205626	fokuseritis	?fokuseritis =fokuseriti  (SgIn  >fokuseritt !22_S	et	f	\N
205627	fokuseritis	?fokuseritis =fokuseritis  (SgN  >fokuseritis !09_S	et	f	\N
205634	koidulas	?koidulas =koidula  (SgIn  >koidula !01_S	et	f	\N
205635	koidulas	?koidulas =dula  (SgIn  >koi+dula !17_S	et	f	\N
205636	koidulas	?koidulas =dulas  (SgN  >koi+dulas !09_S	et	f	\N
205637	isamalaulana	?isamalaulana =isamalaula  (SgEs  >isamalaula !01_S	et	f	\N
205638	isamalaulana	?isamalaulana =malaula  (SgEs  >isa+malaula !01_S	et	f	\N
205675	estlastel	?estlastel =estlas  (PlAd  >estlas !07_S	et	f	\N
205676	estlastel	?estlastel =estlas  (PlAd  >estlane !12?10_S	et	f	\N
205679	ümberelada	### ümberelada	et	f	\N
205680	unistamatu	unistamatu =unistamatu  (SgN  >unistamatu !01_A	et	f	\N
205681	unistamatu	"unistamatu %unista  )MATU_vA  <unistama ;27_V	et	f	\N
205682	unistamatu	unistamatu =unistamatu  (SgG  >unistamatu !01_A	et	f	\N
205703	ndal	### ndal	et	f	\N
205721	koosolemine	koosolemine =olemine  (SgN  >koos+olemine !12_S	et	f	\N
205722	koosolemine	"koos+olemine %olemi  )NE_aA  <koos+olem ;02_S	et	f	\N
205749	vabaväljakust	vabaväljakust =kus  (SgP  >vaba+välja+kusi !20_S	et	f	\N
205750	vabaväljakust	vabaväljakust =väljaku  (SgEl  >vaba+väljak !02_S	et	f	\N
205756	rikkavad	?rikkavad =rikka  (IndPrPl3  >rikkama !29_V	et	f	\N
205757	rikkavad	?rikkavad =rikkava  (PlN  >rikkava !01_S	et	f	\N
205758	rikkavad	?rikkavad =rikkava  (PlN  >rikkav !02_A	et	f	\N
205765	viulit	?viulit =viuli  (SgP  >viuli !16_S	et	f	\N
205766	viulit	?viulit =viulit  (SgN  >viulit !02_S	et	f	\N
205788	organiiserida	### organiiserida	et	f	\N
205792	unelaulu	unelaulu =laulu  (SgG  >une+laul !22_S	et	f	\N
205793	unelaulu	unelaulu =laulu  (SgP  >une+laul !22_S	et	f	\N
205794	unelaulu	unelaulu =laulu  (SgAdt  >une+laul !22_S	et	f	\N
205800	raskedel	### raskedel	et	f	\N
205803	südametel	südametel =südame  (PlAd  >süda !04_S	et	f	\N
205804	südametel	südametel =me  (PlAd  >süda+mesi !15_S	et	f	\N
205805	südametel	südametel =mete  (PlAd  >süda+mett !22_S	et	f	\N
205818	ekonoomiliselt	?ekonoomiliselt =ekonoomilise  (SgAbl  >ekonoomiline !12_A	et	f	\N
205819	ekonoomiliselt	?ekonoomiliselt =ekonoomiliselt  (ID  >ekonoomiliselt !41_D	et	f	\N
205824	modern	?modern =modern  (SgN  >modern !22_A	et	f	\N
205828	lapsepõlveni	lapsepõlveni =põlve  (SgTer  >lapse+põlv !22_S	et	f	\N
205829	lapsepõlveni	lapsepõlveni =põlve  (SgTer  >lapse+põli !24_S	et	f	\N
205837	naideid	?naideid =naidei  (PlN  >naidei !26_S	et	f	\N
205838	naideid	?naideid =naidei  (SgP  >naidei !26_S	et	f	\N
205839	naideid	?naideid =naideid  (SgN  >naideid !22_S	et	f	\N
205845	iseennesse	?iseennesse =iseenne  (PlIll  >iseenn !22_S	et	f	\N
205846	iseennesse	?iseennesse =iseennes  (SgAdt  >iseennene !12_A	et	f	\N
205847	iseennesse	?iseennesse =iseennesse  (SgG  >iseennesne !02_A	et	f	\N
205848	iseennesse	?iseennesse =iseennesse  (PlP  >iseenness !22_S	et	f	\N
205849	iseennesse	?iseennesse =enne  (PlIll  >ise+enn !22_S	et	f	\N
205850	iseennesse	?iseennesse =ennesse  (SgG  >ise+ennesne !02_A	et	f	\N
205851	iseennesse	?iseennesse =ennesse  (PlP  >ise+enness !22_S	et	f	\N
205585	ansamleid	?ansamleid =ansamlei  (PlN  >ansamlei !26_S	et	f	\N
205586	ansamleid	?ansamleid =ansamlei  (SgP  >ansamlei !26_S	et	f	\N
205589	omamoodu	?omamoodu =omamoodu  (IndPrPs_  >omamooduma !27_V	et	f	\N
205590	omamoodu	?omamoodu =omamoodu  (ImpPrSg2  >omamooduma !27_V	et	f	\N
205591	omamoodu	?omamoodu =moodu  (SgN  >oma+moodu !16_S	et	f	\N
205592	omamoodu	?omamoodu =moodu  (SgG  >oma+moodu !16_S	et	f	\N
205605	reaalsustega	reaalsustega =reaalsus  (PlKom  >reaalsus !11~09_S	et	f	\N
205606	reaalsustega	"reaalsus %reaalse  )US_aS  <reaalne ;02_A	et	f	\N
205614	akkordeonis	?akkordeonis =akkordeoni  (SgIn  >akkordeoni !16_S	et	f	\N
205615	akkordeonis	?akkordeonis =akkordeoni  (SgIn  >akkordeon !19_S	et	f	\N
205616	akkordeonis	?akkordeonis =akkordeoni  (IndIpfSg3  >akkordeonima !28_V	et	f	\N
205617	akkordeonis	?akkordeonis =akkordeonis  (SgN  >akkordeonis !09_S	et	f	\N
205646	muidsel	?muidsel =muidse  (SgAd  >muidne !02_A	et	f	\N
205647	muidsel	?muidsel =muidse  (SgAd  >muidse !06_S	et	f	\N
205648	muidsel	?muidsel =muidse  (PlAd  >muids !22_S	et	f	\N
205649	muidsel	?muidsel =muidsel  (SgN  >muidsel !02_S	et	f	\N
205658	laulurahvaseks	laulurahvaseks =seks  (SgN  >laulu+rahva+seks !22_S	et	f	\N
205659	laulurahvaseks	laulurahvaseks =rahvase  (SgTr  >laulu+rahvane !10_A	et	f	\N
205660	laulurahvaseks	"laulu+rahvane %rahva  )NE_aA  <laulu+rahvas ;07_S	et	f	\N
205661	valdajadesena	?valdajadesena =valdajadese  (SgEs  >valdajadene !12_A	et	f	\N
205662	valdajadesena	?valdajadesena =dese  (SgEs  >vald+aja+dese !16_S	et	f	\N
205663	valdajadesena	?valdajadesena =ajadese  (SgEs  >vald+ajadene !12_A	et	f	\N
205677	väljendusid	väljendusid =väljendu  (IndIpfSg2  >väljenduma !27_V	et	f	\N
205678	väljendusid	väljendusid =väljendu  (IndIpfPl3  >väljenduma !27_V	et	f	\N
205704	pühistavad	?pühistavad =pühista  (IndPrPl3  >pühistama !27_V	et	f	\N
205705	pühistavad	?pühistavad =pühistava  (PlN  >pühistav !02_A	et	f	\N
205706	pühistavad	?pühistavad =pühistava  (PlN  >pühistava !16_S	et	f	\N
205707	pühistavad	?pühistavad =stava  (PlN  >pühi+stava !17_S	et	f	\N
205708	keruline	?keruline =keruline  (SgN  >keruline !12_A	et	f	\N
205709	keruline	?keruline =keruline  (PlP  >kerulin !19_S	et	f	\N
205710	igapäevased	igapäevased =päevase  (PlN  >iga+päevane !10_A	et	f	\N
205711	igapäevased	"iga+päevane %päeva  )NE_aA  <iga+päev ;22_S	et	f	\N
205732	pidutsedel	?pidutsedel =tsede  (SgAd  >pidu+tsede !16_S	et	f	\N
205733	pidutsedel	?pidutsedel =tsedel  (SgN  >pidu+tsedel !02_S	et	f	\N
205738	lihavõted	### lihavõted	et	f	\N
205739	laulupidused	laulupidused =piduse  (PlN  >laulu+pidune !10_A	et	f	\N
205740	laulupidused	"laulu+pidune %pidu  )NE_aA  <laulu+pidu ;18_S	et	f	\N
205776	pader	?pader =pader  (SgN  >pader !02_S	et	f	\N
205777	komposiitorit	?komposiitorit =komposiitori  (SgP  >komposiitor !02_S	et	f	\N
205778	komposiitorit	?komposiitorit =posiitori  (SgP  >kom+posiitor !02_S	et	f	\N
205782	raskustest	raskustest =raskus  (PlEl  >raskus !11~09_S	et	f	\N
205783	raskustest	"raskus %raske  )US_aS  <raske ;01_A	et	f	\N
205784	raskustest	raskustest =raskus  (PlEl  >raskune !12~10_A	et	f	\N
205785	raskustest	raskustest =test  (SgN  >raskus+test !22_S	et	f	\N
205789	sünniajast	sünniajast =aja  (SgEl  >sünni+aeg !22_S	et	f	\N
205790	sünniajast	sünniajast =ajas  (SgP  >sünni+ajane !10_A	et	f	\N
205791	sünniajast	"sünni+ajane %aja  )NE_aA  <sünni+aeg ;22_S	et	f	\N
205830	õnnes	õnnes =õnne  (SgIn  >õnn !22_S	et	f	\N
205831	õnnes	õnnes =õnne  (PlIn  >õnn !22_S	et	f	\N
205832	nei	?nei =nei  (SgN  >nei !26_S	et	f	\N
205833	nei	?nei =nei  (SgG  >nei !26_S	et	f	\N
205834	festvali	?festvali =festvali  (ID  >festvali !41_D	et	f	\N
205835	festvali	?festvali =festvali  (SgG  >festval !02_S	et	f	\N
205862	esineja	esineja =esineja  (SgN  >esineja !01_S	et	f	\N
205863	esineja	"esineja %esine  )JA_vS  <esinema ;27_V	et	f	\N
205864	esineja	esineja =esineja  (SgG  >esineja !01_S	et	f	\N
205886	väidendada	?väidendada =väidenda  (Inf  >väidendama !27_V	et	f	\N
205910	tänamise	tänamise =tänamise  (SgG  >tänamine !12_S	et	f	\N
205911	tänamise	"tänamine %täna  )MINE_vS  <tänama ;27_V	et	f	\N
205912	pealtvaataja-elamust	pealtvaataja-elamust =elamu  (SgEl  >pealtvaataja-elamu !01_S	et	f	\N
205913	pealtvaataja-elamust	pealtvaataja-elamust =elamus  (SgP  >pealtvaataja-elamus !11_S	et	f	\N
205927	vanevanemad	?vanevanemad =vanevanema  (PlN  >vanevanem !02_A	et	f	\N
205928	laulade	laulade =la  (PlG  >lau+la !26_S	et	f	\N
205929	laulade	laulade =lade  (SgN  >lau+lade !04_S	et	f	\N
205938	tõdeneb	?tõdeneb =tõdene  (IndPrSg3  >tõdenema !27_V	et	f	\N
205945	musitseerisid	musitseerisid =musitseeri  (IndIpfSg2  >musitseerima !28_V	et	f	\N
205946	musitseerisid	musitseerisid =musitseeri  (IndIpfPl3  >musitseerima !28_V	et	f	\N
205958	rock-ansaamblidega	### rock-ansaamblidega	et	f	\N
205972	osajatel	?osajatel =osaja  (PlAd  >osaja !01_S	et	f	\N
205973	osajatel	?osajatel =osaja  (PlAd  >osajas !02_A	et	f	\N
205974	osajatel	?osajatel =osajate  (PlAd  >osajatt !22_S	et	f	\N
205975	osajatel	?osajatel =jate  (PlAd  >osa+jatt !22_S	et	f	\N
205976	osajatel	?osajatel =jatel  (SgN  >osa+jatel !02_S	et	f	\N
205979	seetu	?seetu =seetu  (SgN  >seetu !01_A	et	f	\N
205980	seetu	?seetu =seetu  (SgG  >seetu !01_A	et	f	\N
205588	kukkerpillid	?kukkerpillid =kukkerpilli  (IndPrSg2  >kukkerpillima !28_V	et	f	\N
205596	tänavadel	?tänavadel =ade  (SgAd  >tänav+ade !16_S	et	f	\N
205597	tänavadel	?tänavadel =adel  (SgN  >tänav+adel !02_S	et	f	\N
205598	tänavadel	?tänavadel =vade  (SgAd  >täna+vade !16_S	et	f	\N
205599	tänavadel	?tänavadel =vadel  (SgN  >täna+vadel !02_S	et	f	\N
205604	kõigem	?kõigem =kõigem  (SgN  >kõigem !02_A	et	f	\N
205607	vanakest	vanakest =vanakes  (SgP  >vanake !12_S	et	f	\N
205608	vanakest	"vanake %vana  )KE_dA  <vana ;17_AS	et	f	\N
205609	vanakest	vanakest =vanakes  (SgP  >vanakene !12_S	et	f	\N
205610	vanakest	"vanakene %vana  )KENE_dA  <vana ;17_AS	et	f	\N
205611	vanakest	vanakest =kest  (SgN  >vana+kest !22_S	et	f	\N
205624	spontaalse	?spontaalse =spontaalse  (SgG  >spontaalne !02_A	et	f	\N
205625	spontaalse	?spontaalse =spontaalse  (PlP  >spontaals !22_S	et	f	\N
205628	iseseisvusel	iseseisvusel =seisvuse  (SgAd  >ise+seisvus !11~09_S	et	f	\N
205629	iseseisvusel	"ise+seisvus %seisva  )US_aS  <ise+seisev ;02_A	et	f	\N
205639	tunneda	?tunneda =tunne  (Inf  >tunnema !27_V	et	f	\N
205655	kudumises	kudumises =kudumise  (SgIn  >kudumine !12_S	et	f	\N
205656	kudumises	"kudumine %kudu  )MINE_vS  <kuduma ;28_V	et	f	\N
205657	kudumises	"kudumine %kudumi  )NE_aA  <kudum ;02_S	et	f	\N
205664	rahvuslikuid	?rahvuslikuid =rahvuslikui  (PlN  >rahvuslikui !26_S	et	f	\N
205665	rahvuslikuid	?rahvuslikuid =rahvuslikui  (SgP  >rahvuslikui !26_S	et	f	\N
205666	rahvuslikuid	?rahvuslikuid =slikui  (PlN  >rahvu+slikui !26_S	et	f	\N
205667	rahvuslikuid	?rahvuslikuid =slikui  (SgP  >rahvu+slikui !26_S	et	f	\N
205668	rahvuslikuid	?rahvuslikuid =slikuid  (SgN  >rahvu+slikuid !22_S	et	f	\N
205669	sobis	sobis =sobi  (SgIn  >sobi !17_S	et	f	\N
205670	sobis	sobis =sobi  (IndIpfSg3  >sobima !27_V	et	f	\N
205671	meeldivaid	meeldivaid =meeldiva  (PlP  >meeldiv !02_A	et	f	\N
205672	meeldivaid	"meeldiv %meeldi  )V_vA  <meeldima ;27_V	et	f	\N
205683	serbiasse	?serbiasse =serbia  (SgIll  >serbia !01_S	et	f	\N
205684	serbiasse	?serbiasse =serbias  (SgAdt  >serbias !11_S	et	f	\N
205685	serbiasse	?serbiasse =serbiasse  (SgG  >serbiasne !02_A	et	f	\N
205686	serbiasse	?serbiasse =serbiasse  (PlP  >serbiass !22_S	et	f	\N
205712	rebenud	?rebenud =rebe  (PtsPtPs  >rebema !27_V	et	f	\N
205713	rebenud	?rebenud =rebenu  (PlN  >rebenu !01_S	et	f	\N
205714	rebenud	?rebenud =rebenu  (IndPrSg2  >rebenuma !27_V	et	f	\N
205715	rebenud	?rebenud =rebenud  (ID  >rebenud !41_A	et	f	\N
205723	segakooriga	segakooriga =iga  (SgN  >sega+koor+iga !18_S	et	f	\N
205724	segakooriga	segakooriga =iga  (SgP  >sega+koor+iga !18_S	et	f	\N
205725	segakooriga	segakooriga =koori  (SgKom  >sega+koor !22_S	et	f	\N
205736	pahal	pahal =paha  (SgAd  >paha !17_AS	et	f	\N
205737	pahal	pahal =paha  (SgAd  >pahk !22_S	et	f	\N
205751	ühendatuid	ühendatuid =ühendatu  (PlP  >ühendatu !01_S	et	f	\N
205752	ühendatuid	"ühendatu %ühenda  )TU1_vS  <ühendama ;27_V	et	f	\N
205754	rahvaskultuur	?rahvaskultuur =rahvaskultuur  (SgN  >rahvaskultuur !22_S	et	f	\N
205755	rahvaskultuur	?rahvaskultuur =skultuur  (SgN  >rahva+skultuur !22_S	et	f	\N
205769	bojanit	?bojanit =bojani  (SgP  >bojan !02_S	et	f	\N
205770	tahak	?tahak =tahak  (SgN  >tahak !02_S	et	f	\N
205795	matuselaule	matuselaule =lau  (SgAll  >matuse+laug !22_SA	et	f	\N
205796	matuselaule	matuselaule =laule  (PlP  >matuse+laul !22_S	et	f	\N
205801	positiivsemaks	positiivsemaks =positiivsema  (SgTr  >positiivsem !02_A	et	f	\N
205802	positiivsemaks	"positiivsem %positiivse  )M_cA  <positiivne ;02_A	et	f	\N
205806	keskonna	?keskonna =keskonna  (SgN  >keskonna !16_S	et	f	\N
205807	keskonna	?keskonna =keskonna  (SgG  >keskonna !16_S	et	f	\N
205808	keskonna	?keskonna =keskonna  (SgG  >keskond !22_S	et	f	\N
205809	keskonna	?keskonna =onna  (SgN  >kesk+onna !16_S	et	f	\N
205810	keskonna	?keskonna =onna  (SgG  >kesk+onna !16_S	et	f	\N
205811	leada	?leada =leada  (SgN  >leada !16_S	et	f	\N
205812	leada	?leada =leada  (SgG  >leada !16_S	et	f	\N
205813	leada	?leada =leada  (IndPrPs_  >leadama !29_V	et	f	\N
205814	leada	?leada =leada  (ImpPrSg2  >leadama !29_V	et	f	\N
205825	üritusel	üritusel =ürituse  (SgAd  >üritus !11_S	et	f	\N
205826	üritusel	"üritus %ürita  )US_vS  <üritama ;27_V	et	f	\N
205827	gruppist	?gruppist =gruppist  (SgN  >gruppist !22_S	et	f	\N
205852	ravalaulu	?ravalaulu =ravalaulu  (IndPrPs_  >ravalauluma !27_V	et	f	\N
205853	ravalaulu	?ravalaulu =ravalaulu  (ImpPrSg2  >ravalauluma !27_V	et	f	\N
205857	ülatub	?ülatub =ülatu  (IndPrSg3  >ülatuma !27_V	et	f	\N
205870	flööd	?flööd =flöö  (PlN  >flöö !26_S	et	f	\N
205872	flööd	?flööd =flöö  (SgP  >flöö !26_S	et	f	\N
205874	flööd	?flööd =flööd  (SgN  >flööd !22_S	et	f	\N
205892	laulasin	?laulasin =laula  (IndIpfSg1  >laulama !29_V	et	f	\N
205893	laulasin	?laulasin =laulasin  (SgN  >laulasin !19_S	et	f	\N
205902	laulatud	laulatud =latu  (PlN  >lau+latu !16_S	et	f	\N
205903	laulatud	"lau+latu %la  )TU2_kA  <lau+la ;26_S	et	f	\N
205914	repertuuari	?repertuuari =repertuuari  (SgN  >repertuuari !16_S	et	f	\N
205915	repertuuari	?repertuuari =repertuuari  (SgG  >repertuuari !16_S	et	f	\N
205916	repertuuari	?repertuuari =repertuuari  (SgG  >repertuuar !19_S	et	f	\N
205623	programeeritud	?programeeritud =programeeritud  (ID  >programeeritud !41_A	et	f	\N
205654	naabridele	?naabridele =bride  (SgAll  >naa+bride !16_S	et	f	\N
205687	muusikultuuri	?muusikultuuri =muusikultuuri  (SgN  >muusikultuuri !16_S	et	f	\N
205688	muusikultuuri	?muusikultuuri =muusikultuuri  (SgG  >muusikultuuri !16_S	et	f	\N
205689	muusikultuuri	?muusikultuuri =muusikultuuri  (SgG  >muusikultuur !22_S	et	f	\N
205690	muusikultuuri	?muusikultuuri =muusikultuuri  (SgP  >muusikultuur !22_S	et	f	\N
205691	muusikultuuri	?muusikultuuri =muusikultuuri  (SgAdt  >muusikultuur !22_S	et	f	\N
205692	muusikultuuri	?muusikultuuri =muusikultuuri  (IndPrPs_  >muusikultuurima !28_V	et	f	\N
205693	muusikultuuri	?muusikultuuri =muusikultuuri  (ImpPrSg2  >muusikultuurima !28_V	et	f	\N
205694	muusikultuuri	?muusikultuuri =sikultuuri  (SgN  >muu+sikultuuri !16_S	et	f	\N
205695	muusikultuuri	?muusikultuuri =sikultuuri  (SgG  >muu+sikultuuri !16_S	et	f	\N
205696	muusikultuuri	?muusikultuuri =sikultuuri  (SgG  >muu+sikultuur !22_S	et	f	\N
205697	muusikultuuri	?muusikultuuri =sikultuuri  (SgP  >muu+sikultuur !22_S	et	f	\N
205698	muusikultuuri	?muusikultuuri =sikultuuri  (SgAdt  >muu+sikultuur !22_S	et	f	\N
205699	progresseeris	?progresseeris =progresseeri  (SgIn  >progresseeri !16_S	et	f	\N
205700	progresseeris	?progresseeris =progresseeri  (SgIn  >progresseer !22_S	et	f	\N
205701	progresseeris	?progresseeris =progresseeri  (IndIpfSg3  >progresseerima !28_V	et	f	\N
205702	progresseeris	?progresseeris =progresseeris  (SgN  >progresseeris !09_S	et	f	\N
205716	kulturi	?kulturi =kulturi  (SgN  >kulturi !01_S	et	f	\N
205717	kulturi	?kulturi =kulturi  (SgG  >kulturi !01_S	et	f	\N
205718	kulturi	?kulturi =kulturi  (SgG  >kultur !02_S	et	f	\N
205719	tahtejõud	tahtejõud =jõu  (PlN  >tahte+jõud !22_S	et	f	\N
205720	tahtejõud	tahtejõud =jõud  (SgN  >tahte+jõud !22_S	et	f	\N
205726	kirikutest	kirikutest =kiriku  (PlEl  >kirik !02_S	et	f	\N
205727	kirikutest	kirikutest =test  (SgN  >kiriku+test !22_S	et	f	\N
205728	kirikutest	kirikutest =ute  (SgEl  >kirik+utt !22_S	et	f	\N
205729	kirikutest	kirikutest =ute  (PlEl  >kirik+utt !22_S	et	f	\N
205730	kirikutest	kirikutest =utes  (SgP  >kirik+utene !10_A	et	f	\N
205731	kirikutest	"kirik+utene %ute  )NE_aA  <kirik+utt ;22_S	et	f	\N
205741	folkloori-	folkloori- =folkloori  (SgG  >folkloor !22_S	et	f	\N
205742	folkloori-	folkloori- =folkloori  (SgP  >folkloor !22_S	et	f	\N
205743	folkloori-	folkloori- =folkloori  (SgAdt  >folkloor !22_S	et	f	\N
205744	folkloori-	folkloori- =loori  (SgN  >folk+loori !16_S	et	f	\N
205745	folkloori-	folkloori- =loori  (SgG  >folk+loori !16_S	et	f	\N
205746	folkloori-	folkloori- =loori  (SgG  >folk+loor !22_S	et	f	\N
205747	folkloori-	folkloori- =loori  (SgP  >folk+loor !22_S	et	f	\N
205748	folkloori-	folkloori- =loori  (SgAdt  >folk+loor !22_S	et	f	\N
205753	ajadega	?ajadega =aja  (PlKom  >aja !17_S	et	f	\N
205761	organitsioonis	?organitsioonis =organitsiooni  (SgIn  >organitsiooni !16_S	et	f	\N
205762	organitsioonis	?organitsioonis =organitsiooni  (SgIn  >organitsioon !22_S	et	f	\N
205763	organitsioonis	?organitsioonis =organitsiooni  (IndIpfSg3  >organitsioonima !28_V	et	f	\N
205764	organitsioonis	?organitsioonis =organitsioonis  (SgN  >organitsioonis !09_S	et	f	\N
205779	gimn	?gimn =gimn  (SgN  >gimn !22_S	et	f	\N
205780	komposiitor	?komposiitor =komposiitor  (SgN  >komposiitor !02_S	et	f	\N
205781	komposiitor	?komposiitor =posiitor  (SgN  >kom+posiitor !02_S	et	f	\N
205815	mailmaks	?mailmaks =mailma  (KndPrPs  >mailmama !29_V	et	f	\N
205816	taanel	?taanel =taane  (PlAd  >taan !22_S	et	f	\N
205817	taanel	?taanel =taanel  (SgN  >taanel !02_S	et	f	\N
205836	lalurahv	?lalurahv =lalurahv  (SgN  >lalurahv !22_S	et	f	\N
205854	arusaadavam	arusaadavam =saadavam  (SgN  >aru+saadavam !02_A	et	f	\N
205855	arusaadavam	"aru+saadavam %saadava  )M_cA  <aru+saadav ;02_A	et	f	\N
205856	tuntuda	?tuntuda =tuntu  (Inf  >tuntuma !27_V	et	f	\N
205858	rahvalauluna	rahvalauluna =luna  (SgN  >rahva+lau+luna !17_S	et	f	\N
205859	rahvalauluna	rahvalauluna =luna  (SgG  >rahva+lau+luna !17_S	et	f	\N
205860	rahvalauluna	rahvalauluna =luna  (SgP  >rahva+lau+luna !17_S	et	f	\N
205861	rahvalauluna	rahvalauluna =laulu  (SgEs  >rahva+laul !22_S	et	f	\N
205868	vargan	?vargan =varga  (IndPrSg1  >vargama !29_V	et	f	\N
205869	vargan	?vargan =vargan  (SgN  >vargan !02_S	et	f	\N
205878	räntmuusikuks	?räntmuusikuks =räntmuusiku  (SgTr  >räntmuusik !02_S	et	f	\N
205879	räntmuusikuks	?räntmuusikuks =räntmuusiku  (KndPrPs  >räntmuusikuma !27_V	et	f	\N
205880	laulumaterial	?laulumaterial =laulumateria  (SgAd  >laulumateria !01_S	et	f	\N
205881	laulumaterial	?laulumaterial =laulumaterial  (SgN  >laulumaterial !19_S	et	f	\N
205882	laulumaterial	?laulumaterial =materia  (SgAd  >laulu+materia !01_S	et	f	\N
205883	laulumaterial	?laulumaterial =material  (SgN  >laulu+material !19_S	et	f	\N
205884	laulumaterial	?laulumaterial =lumateria  (SgAd  >lau+lumateria !01_S	et	f	\N
205885	laulumaterial	?laulumaterial =lumaterial  (SgN  >lau+lumaterial !19_S	et	f	\N
205921	segasid	segasid =sega  (IndIpfSg2  >segama !27_V	et	f	\N
205922	segasid	segasid =sega  (IndIpfPl3  >segama !27_V	et	f	\N
205944	sõbralikumaks	sõbralikumaks =sõbralikuma  (SgTr  >sõbralikum !02_A	et	f	\N
205947	sõbralikumaks	"sõbralikum %sõbraliku  )M_cA  <sõbralik ;25_A	et	f	\N
205956	tahatsin	?tahatsin =tahatsi  (IndPrSg1  >tahatsima !28_V	et	f	\N
205630	juubelilaulupeos	juubelilaulupeos =peo  (SgIn  >juubeli+laulu+pidu !18_S	et	f	\N
205631	juubelilaulupeos	juubelilaulupeos =peo  (SgIn  >juubeli+laulu+peo !26_S	et	f	\N
205632	liidias	?liidias =liidia  (SgIn  >liidia !01_S	et	f	\N
205633	liidias	?liidias =liidias  (SgN  >liidias !11_S	et	f	\N
205640	kultuuritraditsiooni	kultuuritraditsiooni =traditsiooni  (SgG  >kultuuri+traditsioon !22_S	et	f	\N
205641	kultuuritraditsiooni	kultuuritraditsiooni =traditsiooni  (SgP  >kultuuri+traditsioon !22_S	et	f	\N
205642	kultuuritraditsiooni	kultuuritraditsiooni =traditsiooni  (SgAdt  >kultuuri+traditsioon !22_S	et	f	\N
205643	epigrafi	?epigrafi =epigrafi  (SgG  >epigraff !22_S	et	f	\N
205644	epigrafi	?epigrafi =epigrafi  (IndPrPs_  >epigraffima !28_V	et	f	\N
205645	epigrafi	?epigrafi =epigrafi  (ImpPrSg2  >epigraffima !28_V	et	f	\N
205650	linnusi	?linnusi =linnusi  (ID  >linnusi !41_D	et	f	\N
205651	linnusi	?linnusi =usi  (SgN  >linn+usi !17_S	et	f	\N
205652	linnusi	?linnusi =usi  (SgG  >linn+usi !17_S	et	f	\N
205653	linnusi	?linnusi =usi  (SgP  >linn+usi !17_S	et	f	\N
205673	kultuurrahvuseks	kultuurrahvuseks =seks  (SgN  >kultuur+rahvu+seks !22_S	et	f	\N
205674	kultuurrahvuseks	kultuurrahvuseks =rahvuse  (SgTr  >kultuur+rahvus !11~09_S	et	f	\N
205734	lõbustasid	lõbustasid =lõbusta  (IndIpfSg2  >lõbustama !27_V	et	f	\N
205735	lõbustasid	lõbustasid =lõbusta  (IndIpfPl3  >lõbustama !27_V	et	f	\N
205759	tedma	?tedma =tedma  (IndPrPs_  >tedmama !29_V	et	f	\N
205760	tedma	?tedma =tedma  (ImpPrSg2  >tedmama !29_V	et	f	\N
205767	pillit	?pillit =pilli  (SgP  >pilli !16_S	et	f	\N
205768	pillit	?pillit =pillit  (SgN  >pillit !02_S	et	f	\N
205771	rahvased	rahvased =rahvase  (PlN  >rahvane !10_A	et	f	\N
205772	rahvased	"rahvane %rahva  )NE_aA  <rahvas ;07_S	et	f	\N
205773	euroviision	?euroviision =euroviision  (SgN  >euroviision !19~02_S	et	f	\N
205774	euroviision	?euroviision =ion  (SgN  >euro+viis+ion !22_S	et	f	\N
205775	euroviision	?euroviision =viision  (SgN  >euro+viision !19~02_S	et	f	\N
205786	liigutamisega	liigutamisega =liigutamise  (SgKom  >liigutamine !12_S	et	f	\N
205787	liigutamisega	"liigutamine %liiguta  )MINE_vS  <liigutama ;27_V	et	f	\N
205797	kuultuursed	?kuultuursed =kuultuurse  (PlN  >kuultuurne !02_A	et	f	\N
205798	kuultuursed	?kuultuursed =tuurse  (PlN  >kuul+tuurne !02_A	et	f	\N
205799	kuultuursed	?kuultuursed =tuurse  (PlN  >kuul+tuurse !06_S	et	f	\N
205820	liigutusi	liigutusi =liigutusi  (PlP  >liigutus !11_S	et	f	\N
205821	liigutusi	"liigutus %liiguta  )US_vS  <liigutama ;27_V	et	f	\N
205822	liigutusi	"liigutus %liigu  )TUS1_aS  <liikuma ;28_V	et	f	\N
205823	liigutusi	"liigutus %liigu  )TUS2_aS  <liik ;22_S	et	f	\N
205840	televisoris	?televisoris =televisori  (SgIn  >televisor !02_S	et	f	\N
205841	televisoris	?televisoris =televisoris  (SgN  >televisoris !09_S	et	f	\N
205842	televisoris	?televisoris =visori  (SgIn  >tele+visori !01_S	et	f	\N
205843	televisoris	?televisoris =visori  (SgIn  >tele+visor !02_S	et	f	\N
205844	televisoris	?televisoris =visoris  (SgN  >tele+visoris !11_S	et	f	\N
205865	esineja	esineja =esineja  (SgN  >esineja !01_S	et	f	\N
205866	esineja	"esineja %esine  )JA_vS  <esinema ;27_V	et	f	\N
205867	esineja	esineja =esineja  (SgG  >esineja !01_S	et	f	\N
205871	välisriigide	?välisriigide =välisriigi  (PlG  >välisriigi !16_S	et	f	\N
205873	välisriigide	?välisriigide =välisriigi  (PlG  >välisriig !22_S	et	f	\N
205875	välisriigide	?välisriigide =riigi  (PlG  >välis+riigi !16_S	et	f	\N
205876	välisriigide	?välisriigide =riigi  (PlG  >välis+riig !22_S	et	f	\N
205887	esteetuline	?esteetuline =esteetuline  (SgN  >esteetuline !12_A	et	f	\N
205888	esteetuline	?esteetuline =esteetuline  (PlP  >esteetulin !19_S	et	f	\N
205894	kuulatud	kuulatud =kuula  (PtsPtIps  >kuulama !29_V	et	f	\N
205895	kuulatud	kuulatud =kuulatu  (PlN  >kuulatu !01_AS	et	f	\N
205896	kuulatud	"kuulatu %kuula  )TU1_vS  <kuulama ;29_V	et	f	\N
205897	kuulatud	kuulatud =kuulatud  (ID  >kuulatud !41_A	et	f	\N
205898	kuulatud	"kuulatud %kuula  )TUD_vA  <kuulama ;29_V	et	f	\N
205899	kuulatud	kuulatud =atu  (PlN  >kuul+att !22_S	et	f	\N
205900	kuulatud	kuulatud =latu  (PlN  >kuu+latu !16_S	et	f	\N
205901	kuulatud	"kuu+latu %la  )TU2_kA  <kuu+la ;26_S	et	f	\N
205923	ühtlast	ühtlast =ühtlas  (SgP  >ühtlane !12?10_A	et	f	\N
205924	ühtlast	ühtlast =la  (SgEl  >üht+la !26_S	et	f	\N
205925	ühtlast	ühtlast =las  (SgP  >üht+laps !14_S	et	f	\N
205926	ühtlast	ühtlast =last  (SgN  >üht+last !22_S	et	f	\N
205930	regivärseline	?regivärseline =regivärseline  (SgN  >regivärseline !12_A	et	f	\N
205931	regivärseline	?regivärseline =regivärseline  (PlP  >regivärselin !19_S	et	f	\N
205932	regivärseline	?regivärseline =värseline  (SgN  >regi+värseline !12_A	et	f	\N
205933	regivärseline	?regivärseline =värseline  (PlP  >regi+värselin !19_S	et	f	\N
205936	ürituseid	?ürituseid =üritusei  (PlN  >üritusei !26_S	et	f	\N
205937	ürituseid	?ürituseid =üritusei  (SgP  >üritusei !26_S	et	f	\N
205939	siuke	siuke =siuke  (SgN  >siuke !12?10_S	et	f	\N
205940	siuke	"siuke %siu  )KE_dS  <siug ;22_S	et	f	\N
205950	lähenemist	lähenemist =lähenemis  (SgP  >lähenemine !12_S	et	f	\N
205951	lähenemist	"lähenemine %lähene  )MINE_vS  <lähenema ;27_V	et	f	\N
205965	regivärselikuks	?regivärselikuks =regivärseliku  (SgTr  >regivärselik !25_A	et	f	\N
205877	proffesionaalsed	?proffesionaalsed =proffesionaalse  (PlN  >proffesionaalne !02_A	et	f	\N
205889	tantsise	?tantsise =tantsise  (SgG  >tantsis !09_S	et	f	\N
205890	tantsise	?tantsise =tantsise  (IndPrPs_  >tantsisema !27_V	et	f	\N
205891	tantsise	?tantsise =tantsise  (ImpPrSg2  >tantsisema !27_V	et	f	\N
205904	kõikiga	kõikiga =iga  (SgN  >kõik+iga !18_S	et	f	\N
205905	kõikiga	kõikiga =iga  (SgP  >kõik+iga !18_S	et	f	\N
205906	vanamuise	?vanamuise =vanamuise  (PlP  >vanamuis !22_S	et	f	\N
205907	vanamuise	?vanamuise =muise  (SgN  >vana+muise !06_S	et	f	\N
205908	vanamuise	?vanamuise =muise  (SgG  >vana+muise !06_S	et	f	\N
205909	vanamuise	?vanamuise =muise  (PlP  >vana+muis !22_S	et	f	\N
205948	musikat	?musikat =musika  (SgP  >musika !01_S	et	f	\N
205949	musikat	?musikat =musika  (SgP  >musikas !02_S	et	f	\N
205952	kasaaegses	?kasaaegses =kasaaegse  (SgIn  >kasaaegne !02_A	et	f	\N
205953	kasaaegses	?kasaaegses =kasaaegse  (PlIn  >kasaaegs !22_S	et	f	\N
205954	kasaaegses	?kasaaegses =aaegse  (SgIn  >kas+aaegne !02_A	et	f	\N
205955	kasaaegses	?kasaaegses =aaegse  (PlIn  >kas+aaegs !22_S	et	f	\N
205959	muusikaalne	?muusikaalne =muusikaalne  (SgN  >muusikaalne !02_A	et	f	\N
205960	muusikaalne	?muusikaalne =muusikaalne  (PlP  >muusikaaln !22_S	et	f	\N
205961	muusikaalne	?muusikaalne =alne  (SgN  >muusika+alne !02_A	et	f	\N
205962	muusikaalne	?muusikaalne =alne  (PlP  >muusika+aln !22_S	et	f	\N
205963	muusikaalne	?muusikaalne =sikaalne  (SgN  >muu+sikaalne !02_A	et	f	\N
205964	muusikaalne	?muusikaalne =sikaalne  (PlP  >muu+sikaaln !22_S	et	f	\N
205983	rock-muusika	rock-muusika =muusika  (SgN  >rock-muusika !01_S	et	f	\N
205984	rock-muusika	rock-muusika =muusika  (SgG  >rock-muusika !01_S	et	f	\N
205987	traditsiioon	?traditsiioon =traditsiioon  (SgN  >traditsiioon !22_S	et	f	\N
205997	rimiline	?rimiline =rimiline  (SgN  >rimiline !12_A	et	f	\N
205998	rimiline	?rimiline =rimiline  (PlP  >rimilin !19_S	et	f	\N
206010	väljandavad	?väljandavad =väljanda  (IndPrPl3  >väljandama !27_V	et	f	\N
206011	väljandavad	?väljandavad =väljandava  (PlN  >väljandav !02_A	et	f	\N
206012	väljandavad	?väljandavad =väljandava  (PlN  >väljandava !16_S	et	f	\N
206025	tele-	tele- =tele  (SgN  >tele !16_S	et	f	\N
206026	tele-	tele- =tele  (SgG  >tele !16_S	et	f	\N
206100	korraldanud	korraldanud =korralda  (PtsPtPs  >korraldama !27_V	et	f	\N
206101	korraldanud	korraldanud =korraldanu  (PlN  >korraldanu !01_S	et	f	\N
206102	korraldanud	"korraldanu %korralda  )NU_vS  <korraldama ;27_V	et	f	\N
206103	korraldanud	korraldanud =korraldanud  (ID  >korraldanud !41_A	et	f	\N
206104	korraldanud	"korraldanud %korralda  )NUD_vA  <korraldama ;27_V	et	f	\N
206116	igaaastane	igaaastane =aastane  (SgN  >iga+aastane !12~10_A	et	f	\N
206117	igaaastane	"iga+aastane %aasta  )NE_aA  <iga+aasta ;01_S	et	f	\N
206121	kahekümnenda	?kahekümnenda =kahekümnenda  (SgN  >kahekümnenda !16_S	et	f	\N
206122	kahekümnenda	?kahekümnenda =kahekümnenda  (SgG  >kahekümnenda !16_S	et	f	\N
206123	kahekümnenda	?kahekümnenda =kahekümnenda  (IndPrPs_  >kahekümnendama !27_V	et	f	\N
206124	kahekümnenda	?kahekümnenda =kahekümnenda  (ImpPrSg2  >kahekümnendama !27_V	et	f	\N
206125	kahekümnenda	?kahekümnenda =kümnenda  (SgN  >kahe+kümnenda !01_S	et	f	\N
206126	kahekümnenda	?kahekümnenda =kümnenda  (SgG  >kahe+kümnenda !01_S	et	f	\N
206134	eelistuses	eelistuses =eelistuse  (SgIn  >eelistus !11_S	et	f	\N
206135	eelistuses	"eelistus %eelista  )US_vS  <eelistama ;27_V	et	f	\N
206136	lõpe	lõpe =lõpe  (SgN  >lõpe !05_S	et	f	\N
206137	lõpe	lõpe =lõpe  (SgN  >lõpe !06_S	et	f	\N
206138	lõpe	lõpe =lõpe  (IndPrPs_  >lõppema !28_V	et	f	\N
206139	lõpe	lõpe =lõpe  (IndPrPs_  >lõpma !35_V	et	f	\N
206140	lõpe	lõpe =lõpe  (ImpPrSg2  >lõppema !28_V	et	f	\N
206141	lõpe	lõpe =lõpe  (ImpPrSg2  >lõpma !35_V	et	f	\N
206144	tähsusega	?tähsusega =tähsuse  (SgKom  >tähsus !11~09_S	et	f	\N
206147	tuttvuma	?tuttvuma =tuttvu  (Sup  >tuttvuma !27_V	et	f	\N
206148	tuttvuma	?tuttvuma =vuma  (SgN  >tutt+vuma !17_S	et	f	\N
206149	tuttvuma	?tuttvuma =vuma  (SgG  >tutt+vuma !17_S	et	f	\N
206150	tuttvuma	?tuttvuma =vuma  (SgP  >tutt+vuma !17_S	et	f	\N
206151	säilimase	?säilimase =säilimase  (SgG  >säilimane !12_A	et	f	\N
206159	muusikaalsed	?muusikaalsed =muusikaalse  (PlN  >muusikaalne !02_A	et	f	\N
206160	muusikaalsed	?muusikaalsed =alse  (PlN  >muusika+alne !02_A	et	f	\N
206161	muusikaalsed	?muusikaalsed =sikaalse  (PlN  >muu+sikaalne !02_A	et	f	\N
206162	kosneb	?kosneb =kosne  (IndPrSg3  >kosnema !27_V	et	f	\N
206184	instrumentita	?instrumentita =instrumentita  (IndPrPs_  >instrumentitama !27_V	et	f	\N
206185	instrumentita	?instrumentita =instrumentita  (ImpPrSg2  >instrumentitama !27_V	et	f	\N
206186	bajaanit	?bajaanit =bajaani  (SgP  >bajaani !16_S	et	f	\N
206217	musikaantid	### musikaantid	et	f	\N
206220	õnelikud	?õnelikud =õneliku  (PlN  >õnelik !25_A	et	f	\N
206221	õnelikud	?õnelikud =õneliku  (IndPrSg2  >õnelikuma !27_V	et	f	\N
206224	suuruürituseks	?suuruürituseks =suuruürituse  (SgTr  >suuruüritus !11?09_S	et	f	\N
206225	suuruürituseks	?suuruürituseks =ruürituse  (SgTr  >suu+ruüritus !11_S	et	f	\N
206282	õiguslikult	õiguslikult =õigusliku  (SgAbl  >õiguslik !25_A	et	f	\N
206283	õiguslikult	õiguslikult =õiguslikult  (ID  >õiguslikult !41_D	et	f	\N
205917	repertuuari	?repertuuari =repertuuari  (SgP  >repertuuar !19_S	et	f	\N
205918	repertuuari	?repertuuari =repertuuari  (SgAdt  >repertuuar !19_S	et	f	\N
205919	repertuuari	?repertuuari =repertuuari  (IndPrPs_  >repertuuarima !28_V	et	f	\N
205920	repertuuari	?repertuuari =repertuuari  (ImpPrSg2  >repertuuarima !28_V	et	f	\N
205934	spontaalne	?spontaalne =spontaalne  (SgN  >spontaalne !02_A	et	f	\N
205935	spontaalne	?spontaalne =spontaalne  (PlP  >spontaaln !22_S	et	f	\N
205941	usuvärtuslikud	?usuvärtuslikud =usuvärtusliku  (PlN  >usuvärtuslik !25_A	et	f	\N
205942	usuvärtuslikud	?usuvärtuslikud =usuvärtusliku  (IndPrSg2  >usuvärtuslikuma !27_V	et	f	\N
205943	usuvärtuslikud	?usuvärtuslikud =värtusliku  (PlN  >usu+värtuslik !25_A	et	f	\N
205977	propagandeerima	?propagandeerima =propagandeeri  (Sup  >propagandeerima !28_V	et	f	\N
205978	propagandeerima	?propagandeerima =propagandeerima  (SgG  >propagandeerim !02_A	et	f	\N
206006	rahvaluuletusi	rahvaluuletusi =luuletusi  (PlP  >rahva+luuletus !11_S	et	f	\N
206007	rahvaluuletusi	"rahva+luuletus %luule  )TUS2_aS  <rahva+luule ;06_S	et	f	\N
206023	klaasikaline	klaasikaline =kaline  (SgN  >klaasi+kaline !10_A	et	f	\N
206024	klaasikaline	"klaasi+kaline %kali  )NE_aA  <klaasi+kali ;17_S	et	f	\N
206029	statiistikat	?statiistikat =statiistika  (SgP  >statiistika !01_S	et	f	\N
206030	statiistikat	?statiistikat =statiistika  (SgP  >statiistikas !02_A	et	f	\N
206038	teatsid	?teatsid =teat  (IndIpfSg2  >teatma !34_V	et	f	\N
206039	teatsid	?teatsid =teat  (IndIpfPl3  >teatma !34_V	et	f	\N
206040	teatsid	?teatsid =teatsi  (PlN  >teats !22_S	et	f	\N
206041	teatsid	?teatsid =teatsi  (IndPrSg2  >teatsima !28_V	et	f	\N
206049	traditsioni	?traditsioni =traditsio  (SgTer  >traditsio !01_S	et	f	\N
206050	traditsioni	?traditsioni =traditsioni  (SgN  >traditsioni !16_S	et	f	\N
206051	traditsioni	?traditsioni =traditsioni  (SgG  >traditsion !19~02_S	et	f	\N
206052	traditsioni	?traditsioni =traditsioni  (SgG  >traditsioni !16_S	et	f	\N
206053	traditsioni	?traditsioni =traditsioni  (SgP  >traditsion !19_S	et	f	\N
206054	traditsioni	?traditsioni =traditsioni  (SgAdt  >traditsion !19_S	et	f	\N
206055	traditsioni	?traditsioni =traditsioni  (IndPrPs_  >traditsionima !28_V	et	f	\N
206056	traditsioni	?traditsioni =traditsioni  (ImpPrSg2  >traditsionima !28_V	et	f	\N
206059	sümfoonia	sümfoonia =sümfoonia  (SgN  >sümfoonia !01_S	et	f	\N
206060	sümfoonia	sümfoonia =sümfoonia  (SgG  >sümfoonia !01_S	et	f	\N
206062	peasid	?peasid =peasi  (PlN  >peasi !16_S	et	f	\N
206063	peasid	?peasid =peasi  (IndPrSg2  >peasima !28_V	et	f	\N
206066	nisugused	?nisugused =nisuguse  (PlN  >nisugus !11_S	et	f	\N
206067	nisugused	?nisugused =guse  (PlN  >nisu+guse !16_S	et	f	\N
206069	sõltnud	?sõltnud =sõltnu  (PlN  >sõltnu !01_S	et	f	\N
206070	sõltnud	?sõltnud =sõltnu  (IndPrSg2  >sõltnuma !27_V	et	f	\N
206071	sõltnud	?sõltnud =sõltnud  (ID  >sõltnud !41_A	et	f	\N
206095	kaunima	kaunima =kaunima  (SgG  >kaunim !02_A	et	f	\N
206096	kaunima	"kaunim %kauni  )M_cA  <kaunis ;05_A	et	f	\N
206097	kaunima	"kaunim %kauni  )M_cA  <kaunis ;07_A	et	f	\N
206109	tüdrukutekoorid	?tüdrukutekoorid =tüdrukutekoori  (PlN  >tüdrukutekoori !16_S	et	f	\N
206110	tüdrukutekoorid	?tüdrukutekoorid =tüdrukutekoori  (PlN  >tüdrukutekoor !22_S	et	f	\N
206111	tüdrukutekoorid	?tüdrukutekoorid =tüdrukutekoori  (IndPrSg2  >tüdrukutekoorima !28_V	et	f	\N
206112	tüdrukutekoorid	?tüdrukutekoorid =tekoori  (PlN  >tüdruku+tekoori !16_S	et	f	\N
206113	tüdrukutekoorid	?tüdrukutekoorid =tekoori  (PlN  >tüdruku+tekoor !22_S	et	f	\N
206114	tüdrukutekoorid	?tüdrukutekoorid =utekoori  (PlN  >tüdruk+utekoori !16_S	et	f	\N
206115	tüdrukutekoorid	?tüdrukutekoorid =utekoori  (PlN  >tüdruk+utekoor !22_S	et	f	\N
206157	19ndal	### 19ndal	et	f	\N
206169	kihistus	kihistus =kihistu  (SgIn  >kihistu !01_S	et	f	\N
206170	kihistus	kihistus =kihistu  (IndIpfSg3  >kihistuma !27_V	et	f	\N
206171	kihistus	kihistus =kihistus  (SgN  >kihistus !11_S	et	f	\N
206172	kihistus	"kihistus %kihista  )US_vS  <kihistama ;27_V	et	f	\N
206175	vookalse	?vookalse =vookalse  (SgG  >vookalne !02_A	et	f	\N
206176	vookalse	?vookalse =vookalse  (PlP  >vookals !22_S	et	f	\N
206177	vookalse	?vookalse =kalse  (SgN  >voo+kalse !06_S	et	f	\N
206178	vookalse	?vookalse =kalse  (SgG  >voo+kalne !02_A	et	f	\N
206179	vookalse	?vookalse =kalse  (PlP  >voo+kals !22_S	et	f	\N
206190	heliloja	?heliloja =heliloja  (SgN  >heliloja !01_S	et	f	\N
206191	heliloja	?heliloja =heliloja  (SgG  >heliloja !01_S	et	f	\N
206192	heliloja	?heliloja =heliloja  (SgG  >helilojas !02_A	et	f	\N
206193	heliloja	?heliloja =loja  (SgN  >heli+loja !17_S	et	f	\N
206194	heliloja	?heliloja =loja  (SgG  >heli+loja !17_S	et	f	\N
206195	heliloja	?heliloja =loja  (SgP  >heli+loja !17_S	et	f	\N
206202	tugivamaid	?tugivamaid =tugivama  (PlP  >tugivam !02_A	et	f	\N
206203	tugivamaid	?tugivamaid =tugivamai  (PlN  >tugivamai !26_S	et	f	\N
206204	tugivamaid	?tugivamaid =tugivamai  (SgP  >tugivamai !26_S	et	f	\N
206205	tugivamaid	?tugivamaid =vamai  (PlN  >tugi+vamai !26_S	et	f	\N
206206	tugivamaid	?tugivamaid =vamai  (SgP  >tugi+vamai !26_S	et	f	\N
206207	tugivamaid	?tugivamaid =vamaid  (SgN  >tugi+vamaid !22_S	et	f	\N
206213	nissugused	?nissugused =nissuguse  (PlN  >nissugus !11_S	et	f	\N
206214	drum	### drum	et	f	\N
206222	avastusega	avastusega =avastuse  (SgKom  >avastus !11_S	et	f	\N
205957	tahatsin	?tahatsin =tahatsin  (SgN  >tahatsin !19_S	et	f	\N
205968	pillissaatega	?pillissaatega =pillissaate  (SgKom  >pillissaate !16_S	et	f	\N
205971	laulupididel	### laulupididel	et	f	\N
205988	tolline	tolline =tolline  (SgN  >tolline !10_A	et	f	\N
205989	tolline	"tolline %tolli  )NE_aA  <toll ;22_S	et	f	\N
206001	zanre	?zanre =zanre  (SgN  >zanre !06_S	et	f	\N
206002	zanre	?zanre =zanre  (SgG  >zanre !06_S	et	f	\N
206003	zanre	?zanre =zanre  (PlP  >zanr !22_S	et	f	\N
206004	zanre	?zanre =zanre  (IndPrPs_  >zanrema !27_V	et	f	\N
206005	zanre	?zanre =zanre  (ImpPrSg2  >zanrema !27_V	et	f	\N
206008	vaheldusega	vaheldusega =vahelduse  (SgKom  >vaheldus !11_S	et	f	\N
206009	vaheldusega	"vaheldus %vahelda  )US_vS  <vaheldama ;27_V	et	f	\N
206017	eluosa	eluosa =osa  (SgN  >elu+osa !17_S	et	f	\N
206018	eluosa	eluosa =osa  (SgG  >elu+osa !17_S	et	f	\N
206019	eluosa	eluosa =osa  (SgP  >elu+osa !17_S	et	f	\N
206031	status	?status =statu  (SgIn  >statu !16_S	et	f	\N
206032	status	?status =statu  (IndIpfSg3  >statuma !27_V	et	f	\N
206033	status	?status =status  (SgN  >status !09_S	et	f	\N
206034	nisugune	?nisugune =nisugune  (SgN  >nisugune !12_A	et	f	\N
206035	nisugune	?nisugune =nisugune  (PlP  >nisugun !19_S	et	f	\N
206036	nisugune	?nisugune =gune  (SgN  >nisu+gune !16_S	et	f	\N
206037	nisugune	?nisugune =gune  (SgG  >nisu+gune !16_S	et	f	\N
206061	requem	?requem =requem  (SgN  >requem !19_S	et	f	\N
206068	vältin	?vältin =vältin  (SgN  >vältin !02_S	et	f	\N
206072	laulupid	?laulupid =laulupi  (PlN  >laulupi !01_S	et	f	\N
206073	laulupid	?laulupid =laulupi  (PlN  >laulup !02_S	et	f	\N
206074	laulupid	?laulupid =laulupi  (PlN  >laulupp !22_S	et	f	\N
206075	laulupid	?laulupid =laulupi  (IndPrSg2  >lauluppima !28_V	et	f	\N
206076	laulupid	?laulupid =lupi  (PlN  >lau+lupi !16_S	et	f	\N
206077	laulupid	?laulupid =lupi  (PlN  >lau+lupp !22_S	et	f	\N
206093	laulamiseks	?laulamiseks =laulamise  (SgTr  >laulamine !12_S	et	f	\N
206094	laulamiseks	?laulamiseks =lamise  (SgTr  >lau+lamine !10_A	et	f	\N
206098	tahtist	?tahtist =tahtis  (SgP  >tahtis !09_S	et	f	\N
206099	tahtist	?tahtist =tahtist  (SgN  >tahtist !22_S	et	f	\N
206105	viikümne	?viikümne =viikümne  (SgN  >viikümne !02_A	et	f	\N
206106	viikümne	?viikümne =viikümne  (PlP  >viikümn !22_S	et	f	\N
206107	viikümne	?viikümne =ümne  (SgN  >viik+ümne !02_A	et	f	\N
206108	viikümne	?viikümne =ümne  (PlP  >viik+ümn !22_S	et	f	\N
206127	ülimaaline	ülimaaline =maaline  (SgN  >üli+maaline !12?10_A	et	f	\N
206128	ülimaaline	"üli+maaline %maa  )LINE_aA  <üli+maa ;26_S	et	f	\N
206129	ülimaaline	"üli+maaline %maali  )NE_aA  <üli+maal ;22_S	et	f	\N
206131	surivad	?surivad =suri  (IndPrPl3  >surima !27_V	et	f	\N
206132	surivad	?surivad =suriva  (PlN  >suriva !01_S	et	f	\N
206133	surivad	?surivad =suriva  (PlN  >suriv !02_A	et	f	\N
206165	rahvamaie	?rahvamaie =rahvamaie  (SgN  >rahvamaie !01_S	et	f	\N
206166	rahvamaie	?rahvamaie =rahvamaie  (SgG  >rahvamaie !01_S	et	f	\N
206167	rahvamaie	?rahvamaie =maie  (SgN  >rahva+maie !06_S	et	f	\N
206168	rahvamaie	?rahvamaie =maie  (SgG  >rahva+maie !06_S	et	f	\N
206173	folklooriansamble	### folklooriansamble	et	f	\N
206174	mudestisi	?mudestisi =mudestisi  (PlP  >mudestis !11_S	et	f	\N
206208	saaredel	saaredel =ede  (SgAd  >saar+ede !16_S	et	f	\N
206209	saaredel	saaredel =edel  (SgN  >saar+edel !02_S	et	f	\N
206216	alternative	### alternative	et	f	\N
206218	muusikaüüritused	muusikaüüritused =üürituse  (PlN  >muusika+üüritus !11_S	et	f	\N
206219	muusikaüüritused	"muusika+üüritus %üüri  )TUS2_aS  <muusika+üür ;22_S	et	f	\N
206231	keerulistest	keerulistest =keerulis  (PlEl  >keeruline !12_A	et	f	\N
206232	keerulistest	"keeruline %keeru  )LINE_aA  <keerd ;22_SA	et	f	\N
206247	laulura	?laulura =laulura  (SgN  >laulura !01_S	et	f	\N
206248	laulura	?laulura =laulura  (SgG  >laulura !01_S	et	f	\N
206249	laulura	?laulura =lura  (SgN  >lau+lura !17_S	et	f	\N
206250	laulura	?laulura =lura  (SgG  >lau+lura !17_S	et	f	\N
206251	laulura	?laulura =lura  (SgP  >lau+lura !17_S	et	f	\N
206286	rahvatantsutega	### rahvatantsutega	et	f	\N
206292	eestilaulu	eestilaulu =laulu  (SgG  >eesti+laul !22_S	et	f	\N
206293	eestilaulu	eestilaulu =laulu  (SgP  >eesti+laul !22_S	et	f	\N
206294	eestilaulu	eestilaulu =laulu  (SgAdt  >eesti+laul !22_S	et	f	\N
206305	teadav	?teadav =teada  (PtsPrPs  >teadama !29_V	et	f	\N
206306	teadav	?teadav =teadav  (SgN  >teadav !02_A	et	f	\N
206307	nuppu	nuppu =nuppu  (ID  >nuppu !41_D	et	f	\N
206308	nuppu	nuppu =nuppu  (SgP  >nupp !22_S	et	f	\N
206309	nuppu	nuppu =nuppu  (SgAdt  >nupp !22_S	et	f	\N
206310	nuppu	nuppu =nuppu  (IndPrPs_  >nuppuma !27_V	et	f	\N
206311	nuppu	nuppu =nuppu  (ImpPrSg2  >nuppuma !27_V	et	f	\N
206320	pisikestele	pisikestele =pisikes  (PlAll  >pisike !12_A	et	f	\N
206321	pisikestele	pisikestele =pisikes  (PlAll  >pisikene !12_A	et	f	\N
206322	pisikestele	pisikestele =keste  (SgAll  >pisi+keste !06_S	et	f	\N
206323	pisikestele	pisikestele =keste  (PlAll  >pisi+kest !22_S	et	f	\N
206332	uinu	uinu =uinu  (IndPrPs_  >uinuma !27_V	et	f	\N
206333	uinu	uinu =uinu  (ImpPrSg2  >uinuma !27_V	et	f	\N
205966	regivärselikuks	?regivärselikuks =regivärseliku  (KndPrPs  >regivärselikuma !27_V	et	f	\N
205967	regivärselikuks	?regivärselikuks =värseliku  (SgTr  >regi+värselik !25_A	et	f	\N
205969	regliaule	?regliaule =regliau  (SgAll  >regliau !26_S	et	f	\N
205970	regliaule	?regliaule =regliaule  (PlP  >regliaul !19_S	et	f	\N
205985	ärkamiseaeg	?ärkamiseaeg =ärkamiseaeg  (SgN  >ärkamiseaeg !22_S	et	f	\N
205986	ärkamiseaeg	?ärkamiseaeg =eaeg  (SgN  >ärkamis+eaeg !02_S	et	f	\N
205990	rahvuline	?rahvuline =rahvuline  (SgN  >rahvuline !12_A	et	f	\N
205991	rahvuline	?rahvuline =rahvuline  (PlP  >rahvulin !19_S	et	f	\N
205999	vookalsed	?vookalsed =vookalse  (PlN  >vookalne !02_A	et	f	\N
206000	vookalsed	?vookalsed =kalse  (PlN  >voo+kalne !02_A	et	f	\N
206016	klarneet	?klarneet =klarneet  (SgN  >klarneet !22_S	et	f	\N
206020	muusikalised	muusikalised =muusikalise  (PlN  >muusikaline !12_A	et	f	\N
206021	muusikalised	"muusikaline %muusika  )LINE_aA  <muusika ;01_S	et	f	\N
206022	muusikalised	"muusikaline %muusikali  )NE_aA  <muusikal ;19_S	et	f	\N
206042	kogusevad	?kogusevad =koguseva  (PlN  >kogusev !02_A	et	f	\N
206043	kogusevad	?kogusevad =koguseva  (PlN  >koguseva !16_S	et	f	\N
206044	kogusevad	?kogusevad =seva  (PlN  >kogu+seva !17_S	et	f	\N
206088	rockband	?rockband =rockband  (SgN  >rockband !02_S	et	f	\N
206089	rockband	?rockband =band  (SgN  >rock+band !22_S	et	f	\N
206130	südades	?südades =süda  (Ger  >südama !27_V	et	f	\N
206142	mängimises	mängimises =mängimise  (SgIn  >mängimine !12_S	et	f	\N
206143	mängimises	"mängimine %mängi  )MINE_vS  <mängima ;28_V	et	f	\N
206145	eestase	eestase =ase  (SgN  >eest+ase !04_S	et	f	\N
206146	eestase	eestase =tase  (SgN  >ees+tase !04_S	et	f	\N
206163	pillinemisest	?pillinemisest =pillinemise  (SgEl  >pillinemine !12_S	et	f	\N
206164	pillinemisest	?pillinemisest =nemise  (SgEl  >pilli+nemine !10_A	et	f	\N
206180	riikilaule	?riikilaule =riikilau  (SgAll  >riikilau !26_S	et	f	\N
206181	riikilaule	?riikilaule =riikilaule  (PlP  >riikilaul !19_S	et	f	\N
206182	riikilaule	?riikilaule =ilau  (SgAll  >riik+ilau !26_S	et	f	\N
206183	riikilaule	?riikilaule =ilaule  (PlP  >riik+ilaul !22_S	et	f	\N
206187	ixx	?ixx =ixx  (SgN  >ixx !22_S	et	f	\N
206188	tõuseaeg	?tõuseaeg =tõuseaeg  (SgN  >tõuseaeg !22_S	et	f	\N
206189	tõuseaeg	?tõuseaeg =seaeg  (SgN  >tõu+seaeg !02_S	et	f	\N
206200	meleolu	?meleolu =meleolu  (IndPrPs_  >meleoluma !27_V	et	f	\N
206201	meleolu	?meleolu =meleolu  (ImpPrSg2  >meleoluma !27_V	et	f	\N
206210	muusikastiili	muusikastiili =stiili  (SgG  >muusika+stiil !22_S	et	f	\N
206211	muusikastiili	muusikastiili =stiili  (SgP  >muusika+stiil !22_S	et	f	\N
206212	muusikastiili	muusikastiili =stiili  (SgAdt  >muusika+stiil !22_S	et	f	\N
206215	bas	### bas	et	f	\N
206226	tõiesti	?tõiesti =tõiesti  (ID  >tõiesti !41_D	et	f	\N
206227	tõiesti	?tõiesti =tõiesti  (IndPrPs_  >tõiestima !28_V	et	f	\N
206228	tõiesti	?tõiesti =tõiesti  (ImpPrSg2  >tõiestima !28_V	et	f	\N
206229	musikaks	?musikaks =musika  (SgTr  >musika !01_S	et	f	\N
206230	musikaks	?musikaks =musika  (SgTr  >musikas !02_S	et	f	\N
206233	meeleldivalt	?meeleldivalt =meeleldiva  (SgAbl  >meeleldiv !02_A	et	f	\N
206234	meeleldivalt	?meeleldivalt =meeleldiva  (SgAbl  >meeleldiva !16_S	et	f	\N
206235	meeleldivalt	?meeleldivalt =meeleldivalt  (ID  >meeleldivalt !41_D	et	f	\N
206236	meeleldivalt	?meeleldivalt =leldiva  (SgAbl  >mee+leldiva !01_S	et	f	\N
206237	meeleldivalt	?meeleldivalt =leldiva  (SgAbl  >mee+leldiv !02_A	et	f	\N
206239	talveõhtu	talveõhtu =õhtu  (SgN  >talve+õhtu !01_S	et	f	\N
206240	talveõhtu	talveõhtu =õhtu  (SgG  >talve+õhtu !01_S	et	f	\N
206241	suuliseid	suuliseid =suulise  (PlP  >suuline !10_AS	et	f	\N
206242	suuliseid	"suuline %suu  )LINE_aA  <suu ;26_S	et	f	\N
206243	mitmeteemalised	mitmeteemalised =malise  (PlN  >mitme+tee+maline !10_A	et	f	\N
206244	mitmeteemalised	"mitme+tee+maline %mali  )NE_aA  <mitme+tee+mali ;17_S	et	f	\N
206245	mitmeteemalised	mitmeteemalised =teemalise  (PlN  >mitme+teemaline !12_A	et	f	\N
206246	mitmeteemalised	"mitme+teemaline %teema  )LINE_aA  <mitme+teema ;16_S	et	f	\N
206254	veenelased	?veenelased =veenelase  (PlN  >veenelane !12_S	et	f	\N
206255	veenelased	?veenelased =nelase  (PlN  >vee+nelane !10_A	et	f	\N
206265	esialguses	esialguses =use  (PlIn  >esi+alg+usk !22_S	et	f	\N
206266	esialguses	esialguses =alguse  (SgIn  >esi+algus !11~09_S	et	f	\N
206271	pillisaadeta	?pillisaadeta =pillisaa  (PlAb  >pillisaa !26_S	et	f	\N
206272	pillisaadeta	?pillisaadeta =pillisaade  (SgAb  >pillisaade !16_S	et	f	\N
206273	pillisaadeta	?pillisaadeta =pillisaadeta  (IndPrPs_  >pillisaadetama !27_V	et	f	\N
206274	pillisaadeta	?pillisaadeta =pillisaadeta  (ImpPrSg2  >pillisaadetama !27_V	et	f	\N
206275	pillisaadeta	?pillisaadeta =saa  (PlAb  >pilli+saa !26_S	et	f	\N
206276	uurimates	?uurimates =uurima  (PlIn  >uurim !02_A	et	f	\N
206277	uurimates	?uurimates =uurimate  (PlIn  >uurimatt !22_S	et	f	\N
206278	toimutati	?toimutati =toimuta  (IndIpfIps  >toimutama !27_V	et	f	\N
206279	toimutati	?toimutati =toimutati  (SgG  >toimutatt !22_S	et	f	\N
206280	toimutati	?toimutati =toimutati  (IndPrPs_  >toimutattima !28_V	et	f	\N
206281	toimutati	?toimutati =toimutati  (ImpPrSg2  >toimutattima !28_V	et	f	\N
206295	aknasse	aknasse =akna  (SgIll  >aken !08_S	et	f	\N
205981	seetu	?seetu =seetu  (IndPrPs_  >seetuma !27_V	et	f	\N
205982	seetu	?seetu =seetu  (ImpPrSg2  >seetuma !27_V	et	f	\N
205992	jagunud	jagunud =jagu  (PtsPtPs  >jaguma !27_V	et	f	\N
205993	jagunud	jagunud =jagunu  (PlN  >jagunu !01_S	et	f	\N
205994	jagunud	"jagunu %jagu  )NU_vS  <jaguma ;27_V	et	f	\N
205995	jagunud	jagunud =jagunud  (ID  >jagunud !41_A	et	f	\N
205996	jagunud	"jagunud %jagu  )NUD_vA  <jaguma ;27_V	et	f	\N
206013	tutvustumine	?tutvustumine =tutvustumine  (SgN  >tutvustumine !12_S	et	f	\N
206014	tutvustumine	?tutvustumine =tutvustumine  (PlP  >tutvustumin !19_S	et	f	\N
206015	tutvustumine	?tutvustumine =tumine  (SgN  >tutvus+tumine !10_A	et	f	\N
206027	kaasaegsetes	kaasaegsetes =sete  (PlIn  >kaas+aeg+sett !22_S	et	f	\N
206028	kaasaegsetes	kaasaegsetes =aegse  (PlIn  >kaas+aegne !02_A	et	f	\N
206045	pidustavad	?pidustavad =pidusta  (IndPrPl3  >pidustama !27_V	et	f	\N
206046	pidustavad	?pidustavad =pidustava  (PlN  >pidustav !02_A	et	f	\N
206047	pidustavad	?pidustavad =pidustava  (PlN  >pidustava !16_S	et	f	\N
206048	pidustavad	?pidustavad =stava  (PlN  >pidu+stava !17_S	et	f	\N
206057	kogumaa	kogumaa =maa  (SgN  >kogu+maa !26_S	et	f	\N
206058	kogumaa	kogumaa =maa  (SgG  >kogu+maa !26_S	et	f	\N
206064	ajalo	?ajalo =ajalo  (SgN  >ajalo !01_S	et	f	\N
206065	ajalo	?ajalo =ajalo  (SgG  >ajalo !01_S	et	f	\N
206078	soveti	?soveti =sove  (IndIpfIps  >sovema !27_V	et	f	\N
206079	soveti	?soveti =soveti  (ID  >soveti !41_D	et	f	\N
206080	soveti	?soveti =soveti  (SgG  >sovett !22_S	et	f	\N
206081	soveti	?soveti =soveti  (IndPrPs_  >sovettima !28_V	et	f	\N
206082	soveti	?soveti =soveti  (ImpPrSg2  >sovettima !28_V	et	f	\N
206083	mõjunud	mõjunud =mõju  (PtsPtPs  >mõjuma !27_V	et	f	\N
206084	mõjunud	mõjunud =mõjunu  (PlN  >mõjunu !01_S	et	f	\N
206085	mõjunud	"mõjunu %mõju  )NU_vS  <mõjuma ;27_V	et	f	\N
206086	mõjunud	mõjunud =mõjunud  (ID  >mõjunud !41_A	et	f	\N
206087	mõjunud	"mõjunud %mõju  )NUD_vA  <mõjuma ;27_V	et	f	\N
206090	settu	?settu =settu  (ID  >settu !41_D	et	f	\N
206091	settu	?settu =settu  (IndPrPs_  >settuma !27_V	et	f	\N
206092	settu	?settu =settu  (ImpPrSg2  >settuma !27_V	et	f	\N
206118	lauli	lauli =lauli  (SgG  >laul !22_S	et	f	\N
206119	lauli	lauli =lauli  (SgP  >laul !22_S	et	f	\N
206120	lauli	lauli =lauli  (SgAdt  >laul !22_S	et	f	\N
206152	nendle	?nendle =nendle  (SgN  >nendle !06_S	et	f	\N
206153	nendle	?nendle =nendle  (SgG  >nendle !06_S	et	f	\N
206154	nendle	?nendle =nendle  (IndPrPs_  >nendlema !30_V	et	f	\N
206155	nendle	?nendle =nendle  (ImpPrSg2  >nendlema !30_V	et	f	\N
206156	kauas	?kauas =kauas  (SgN  >kauas !02_S	et	f	\N
206158	remixid	?remixid =remixi  (PlN  >remixi !01_S	et	f	\N
206196	kultuurisee	?kultuurisee =kultuurisee  (SgN  >kultuurisee !26_S	et	f	\N
206197	kultuurisee	?kultuurisee =kultuurisee  (SgG  >kultuurisee !26_S	et	f	\N
206198	kultuurisee	?kultuurisee =isee  (SgN  >kultuur+isee !26_S	et	f	\N
206199	kultuurisee	?kultuurisee =isee  (SgG  >kultuur+isee !26_S	et	f	\N
206238	pikade	?pikade =pika  (PlG  >pika !16_S	et	f	\N
206252	vanevanematel	?vanevanematel =vanevanema  (PlAd  >vanevanem !02_A	et	f	\N
206253	vanevanematel	?vanevanematel =vanevanemate  (PlAd  >vanevanematt !22_S	et	f	\N
206258	laulukulturi	?laulukulturi =laulukulturi  (SgG  >laulukultur !02_S	et	f	\N
206259	laulukulturi	?laulukulturi =kulturi  (SgN  >laulu+kulturi !01_S	et	f	\N
206260	laulukulturi	?laulukulturi =kulturi  (SgG  >laulu+kulturi !01_S	et	f	\N
206261	laulukulturi	?laulukulturi =kulturi  (SgG  >laulu+kultur !02_S	et	f	\N
206262	laulukulturi	?laulukulturi =lukulturi  (SgG  >lau+lukultur !19_S	et	f	\N
206263	laulukulturi	?laulukulturi =lukulturi  (SgP  >lau+lukultur !19_S	et	f	\N
206264	laulukulturi	?laulukulturi =lukulturi  (SgAdt  >lau+lukultur !19_S	et	f	\N
206302	vaimlikud	?vaimlikud =vaimliku  (PlN  >vaimlik !25_A	et	f	\N
206303	vaimlikud	?vaimlikud =vaimliku  (PlN  >vaimliku !01_S	et	f	\N
206304	vaimlikud	?vaimlikud =vaimliku  (IndPrSg2  >vaimlikuma !27_V	et	f	\N
206312	70-ndates	?-ndates =ndate  (PlIn  >-ndatt !22_S	et	f	\N
206313	70-ndates	?-ndates =ndate  (IndIpfSg3  >-ndatema !27_V	et	f	\N
206315	70-ndates	?-ndates =ndates  (SgN  >-ndates !09_S	et	f	\N
206330	uilikene	?uilikene =uilikene  (SgN  >uilikene !12_S	et	f	\N
206331	uilikene	?uilikene =uilikene  (PlP  >uiliken !19_S	et	f	\N
206334	maarjakene	maarjakene =maarjakene  (SgN  >maarjakene !12_S	et	f	\N
206335	maarjakene	"maarjakene %maarja  )KENE_dS  <maarjas ;02_S	et	f	\N
206338	sõbrustasid	sõbrustasid =sõbrusta  (IndIpfSg2  >sõbrustama !27_V	et	f	\N
206339	sõbrustasid	sõbrustasid =sõbrusta  (IndIpfPl3  >sõbrustama !27_V	et	f	\N
206341	setsmendates	?setsmendates =setsmenda  (PlIn  >setsmenda !01_S	et	f	\N
206342	setsmendates	?setsmendates =setsmendate  (PlIn  >setsmendatt !22_S	et	f	\N
206343	meeldivaim	meeldivaim =meeldivaim  (SgN  >meeldivaim !02_A	et	f	\N
206344	meeldivaim	"meeldivaim %meeldiva  )IM_sA  <meeldiv ;02_A	et	f	\N
206355	omavaheliseid	?omavaheliseid =omavahelisei  (PlN  >omavahelisei !26_S	et	f	\N
206356	omavaheliseid	?omavaheliseid =omavahelisei  (SgP  >omavahelisei !26_S	et	f	\N
206357	omavaheliseid	?omavaheliseid =vahelisei  (PlN  >oma+vahelisei !26_S	et	f	\N
206358	omavaheliseid	?omavaheliseid =vahelisei  (SgP  >oma+vahelisei !26_S	et	f	\N
206223	avastusega	"avastus %avasta  )US_vS  <avastama ;27_V	et	f	\N
206256	tuavad	?tuavad =tuava  (PlN  >tuava !16_S	et	f	\N
206257	tuavad	?tuavad =tuava  (IndPrSg2  >tuavama !29_V	et	f	\N
206267	reegilaulu	?reegilaulu =reegilaulu  (IndPrPs_  >reegilauluma !27_V	et	f	\N
206268	reegilaulu	?reegilaulu =reegilaulu  (ImpPrSg2  >reegilauluma !27_V	et	f	\N
206269	reegilaulu	?reegilaulu =gilaulu  (SgN  >ree+gilaulu !01_S	et	f	\N
206270	reegilaulu	?reegilaulu =gilaulu  (SgG  >ree+gilaulu !01_S	et	f	\N
206285	rüüdik	?rüüdik =rüüdik  (SgN  >rüüdik !02_S	et	f	\N
206287	rahvaluulest	rahvaluulest =lest  (SgN  >rahva+luu+lest !22_S	et	f	\N
206288	rahvaluulest	rahvaluulest =luule  (SgEl  >rahva+luule !06_S	et	f	\N
206289	rahvaluulest	rahvaluulest =luule  (PlEl  >rahva+luul !22_S	et	f	\N
206290	rahvaluulest	rahvaluulest =luules  (SgP  >rahva+luulene !10_A	et	f	\N
206291	rahvaluulest	"rahva+luulene %luule  )NE_aA  <rahva+luule ;06_S	et	f	\N
206298	pisikesele	pisikesele =pisikese  (SgAll  >pisike !12_A	et	f	\N
206299	pisikesele	pisikesele =pisikese  (SgAll  >pisikene !12_A	et	f	\N
206300	südast	?südast =südas  (SgP  >südas !07_S	et	f	\N
206301	südast	?südast =südas  (SgP  >südane !10_A	et	f	\N
206317	liiged	?liiged =liige  (IndPrSg2  >liigema !27_V	et	f	\N
206340	ukraainlased	?ukraainlased =ukraainlase  (PlN  >ukraainlane !12?10_S	et	f	\N
206379	esteetiliselt	esteetiliselt =esteetilise  (SgAbl  >esteetiline !12_A	et	f	\N
206380	esteetiliselt	esteetiliselt =esteetiliselt  (ID  >esteetiliselt !41_D	et	f	\N
206381	esteetiliselt	"esteetiliselt %esteetilise  )LT_mD  <esteetiline ;12_A	et	f	\N
206383	muusikapidusid	muusikapidusid =pidu  (PlP  >muusika+pidu !17_S	et	f	\N
206384	muusikapidusid	muusikapidusid =pidu  (PlP  >muusika+pidu !18_S	et	f	\N
206398	mixi	?mixi =mixi  (SgN  >mixi !16_S	et	f	\N
206399	mixi	?mixi =mixi  (SgG  >mixi !16_S	et	f	\N
206429	töötaded	?töötaded =tade  (PlN  >töö+tade !16_S	et	f	\N
206455	natukes	?natukes =natuke  (PlIn  >natukk !22_S	et	f	\N
206461	viljanli	?viljanli =viljanli  (SgN  >viljanli !01_S	et	f	\N
206462	viljanli	?viljanli =viljanli  (SgG  >viljanli !01_S	et	f	\N
206463	viljanli	?viljanli =viljanli  (SgG  >viljanl !22_S	et	f	\N
206464	viljanli	?viljanli =viljanli  (SgP  >viljanl !22_S	et	f	\N
206465	viljanli	?viljanli =viljanli  (SgAdt  >viljanl !22_S	et	f	\N
206466	viljanli	?viljanli =viljanli  (IndPrPs_  >viljanlima !28_V	et	f	\N
206467	viljanli	?viljanli =viljanli  (ImpPrSg2  >viljanlima !28_V	et	f	\N
206474	laululehte	laululehte =lehte  (SgP  >laulu+leht !22_S	et	f	\N
206475	laululehte	laululehte =lehte  (SgAdt  >laulu+leht !22_S	et	f	\N
206476	laululehte	laululehte =lehte  (PlP  >laulu+leht !22_S	et	f	\N
206508	headusest	headusest =headuse  (SgEl  >headus !11~09_S	et	f	\N
206509	headusest	"headus %hea  )US_aS  <hea ;26_A	et	f	\N
206510	headusest	headusest =headuses  (SgP  >headusene !12_A	et	f	\N
206511	headusest	"headusene %headuse  )NE_aA  <headus ;09_S	et	f	\N
206512	headusest	"headusene %headuse  )NE_aA  <headus ;11_S	et	f	\N
206513	headusest	headusest =use  (PlEl  >head+usk !22_S	et	f	\N
206521	lauapeos	lauapeos =peo  (SgIn  >laua+pidu !18_S	et	f	\N
206522	lauapeos	lauapeos =peo  (SgIn  >laua+peo !26_S	et	f	\N
206528	trollis	trollis =trolli  (SgIn  >trolli !16_S	et	f	\N
206529	trollis	trollis =trolli  (SgIn  >troll !22_S	et	f	\N
206547	reegilaul	?reegilaul =reegilau  (SgAd  >reegilau !26_S	et	f	\N
206548	reegilaul	?reegilaul =reegilaul  (SgN  >reegilaul !19_S	et	f	\N
206549	reegilaul	?reegilaul =gilau  (SgAd  >ree+gilau !26_S	et	f	\N
206550	reegilaul	?reegilaul =gilaul  (SgN  >ree+gilaul !22_S	et	f	\N
206602	tred	### tred	et	f	\N
206619	elendis	?elendis =elendi  (SgIn  >elendi !01_S	et	f	\N
206620	elendis	?elendis =elendi  (SgIn  >elend !02_S	et	f	\N
206621	elendis	?elendis =elendi  (SgIn  >elent !22_S	et	f	\N
206622	elendis	?elendis =elendi  (IndIpfSg3  >elendima !28_V	et	f	\N
206623	elendis	?elendis =elendis  (SgN  >elendis !11_S	et	f	\N
206627	võõrkeeliinglise	?võõrkeeliinglise =võõrkeeliinglise  (SgG  >võõrkeeliingline !12_A	et	f	\N
206628	võõrkeeliinglise	?võõrkeeliinglise =iinglise  (SgG  >võõr+keel+iingline !12~10_A	et	f	\N
206629	võõrkeeliinglise	?võõrkeeliinglise =keeliinglise  (SgG  >võõr+keeliingline !12_A	et	f	\N
206638	erivärvisiled	### erivärvisiled	et	f	\N
206644	susatada	?susatada =susata  (Inf  >susatama !27_V	et	f	\N
206677	sôber	### sôber	et	f	\N
206682	erzählt	?erzählt =erzählt  (SgN  >erzählt !22_S	et	f	\N
206689	jôululaat	### jôululaat	et	f	\N
206698	tôesti	### tôesti	et	f	\N
206701	jôululaadal	### jôululaadal	et	f	\N
206704	sôpradele	### sôpradele	et	f	\N
206710	ida-saksamaal	ida-saksamaal =maa  (SgAd  >ida-saksa+maa !26_S	et	f	\N
206711	ida-saksamaal	ida-saksamaal =maal  (SgN  >ida-saksa+maal !22_S	et	f	\N
206715	mägine	mägine =mägine  (SgN  >mägine !10_A	et	f	\N
206716	mägine	"mägine %mägi  )NE_aA  <mägi ;21_S	et	f	\N
206717	mägirahvas	mägirahvas =rahva  (SgIn  >mägi+rahvas !07_S	et	f	\N
206718	mägirahvas	mägirahvas =rahvas  (SgN  >mägi+rahvas !07_S	et	f	\N
206725	kelgutavad	kelgutavad =kelguta  (IndPrPl3  >kelgutama !27_V	et	f	\N
206726	kelgutavad	kelgutavad =kelgutava  (PlN  >kelgutav !02_A	et	f	\N
206284	õiguslikult	"õiguslikult %õigusliku  )LT_mD  <õiguslik ;25_A	et	f	\N
206314	aastates	aastates =aasta  (PlIn  >aasta !01_S	et	f	\N
206316	aastates	aastates =tate  (PlIn  >aas+tatt !22_S	et	f	\N
206324	salmeid	?salmeid =salme  (PlP  >salme !06_S	et	f	\N
206325	salmeid	?salmeid =salmei  (PlN  >salmei !26_S	et	f	\N
206326	salmeid	?salmeid =salmei  (SgP  >salmei !26_S	et	f	\N
206327	salmeid	?salmeid =salmeid  (SgN  >salmeid !22_S	et	f	\N
206360	üheksateistkümnendal	?üheksateistkümnendal =üheksateistkümnenda  (SgAd  >üheksateistkümnenda !16_S	et	f	\N
206361	üheksateistkümnendal	?üheksateistkümnendal =üheksateistkümnendal  (SgN  >üheksateistkümnendal !02_S	et	f	\N
206362	üheksateistkümnendal	?üheksateistkümnendal =kümnenda  (SgAd  >üheksa+teist+kümnenda !01_S	et	f	\N
206363	üheksateistkümnendal	?üheksateistkümnendal =teistkümnenda  (SgAd  >üheksa+teistkümnenda !16_S	et	f	\N
206364	üheksateistkümnendal	?üheksateistkümnendal =teistkümnendal  (SgN  >üheksa+teistkümnendal !02_S	et	f	\N
206365	üheksateistkümnendal	?üheksateistkümnendal =ateistkümnenda  (SgAd  >üheks+ateistkümnenda !16_S	et	f	\N
206366	üheksateistkümnendal	?üheksateistkümnendal =ateistkümnendal  (SgN  >üheks+ateistkümnendal !02_S	et	f	\N
206367	üheksateistkümnendal	?üheksateistkümnendal =ksateistkümnenda  (SgAd  >ühe+ksateistkümnenda !16_S	et	f	\N
206368	üheksateistkümnendal	?üheksateistkümnendal =ksateistkümnendal  (SgN  >ühe+ksateistkümnendal !02_S	et	f	\N
206390	araneb	?araneb =arane  (IndPrSg3  >aranema !27_V	et	f	\N
206394	probleemitele	?probleemitele =probleemite  (PlAll  >probleemitt !22_S	et	f	\N
206395	probleemitele	?probleemitele =probleemitele  (IndPrPs_  >probleemitelema !36_V	et	f	\N
206396	probleemitele	?probleemitele =probleemitele  (ImpPrSg2  >probleemitelema !36_V	et	f	\N
206397	probleemitele	?probleemitele =ite  (PlAll  >probleem+itt !22_S	et	f	\N
206406	nsvliidus	?nsvliidus =nsvliidu  (SgIn  >nsvliidu !16_S	et	f	\N
206407	nsvliidus	?nsvliidus =nsvliidu  (IndIpfSg3  >nsvliiduma !27_V	et	f	\N
206408	nsvliidus	?nsvliidus =nsvliidus  (SgN  >nsvliidus !11~09_S	et	f	\N
206432	huvitavamak	### huvitavamak	et	f	\N
206442	võistlustest	võistlustest =võistlus  (PlEl  >võistlus !11~09_S	et	f	\N
206443	võistlustest	võistlustest =test  (SgN  >võistlus+test !22_S	et	f	\N
206447	laulurarahvat	?laulurarahvat =laulurarahva  (SgP  >laulurarahva !16_S	et	f	\N
206448	laulurarahvat	?laulurarahvat =rarahva  (SgP  >laulu+rarahva !01_S	et	f	\N
206449	laulurarahvat	?laulurarahvat =lurarahva  (SgP  >lau+lurarahva !16_S	et	f	\N
206451	piilideta	?piilideta =piili  (PlAb  >piili !16_S	et	f	\N
206452	piilideta	?piilideta =piili  (PlAb  >piil !22_S	et	f	\N
206453	piilideta	?piilideta =piilideta  (IndPrPs_  >piilidetama !27_V	et	f	\N
206454	piilideta	?piilideta =piilideta  (ImpPrSg2  >piilidetama !27_V	et	f	\N
206460	teaved	?teaved =teave  (IndPrSg2  >teavema !27_V	et	f	\N
206468	fest	?fest =fest  (SgN  >fest !22_S	et	f	\N
206479	ärkamisperiiod	?ärkamisperiiod =ärkamisperiio  (PlN  >ärkamisperiio !01_S	et	f	\N
206480	ärkamisperiiod	?ärkamisperiiod =ärkamisperiiod  (SgN  >ärkamisperiiod !22_S	et	f	\N
206481	ärkamisperiiod	?ärkamisperiiod =periio  (PlN  >ärkamis+periio !01_S	et	f	\N
206482	ärkamisperiiod	?ärkamisperiiod =periiod  (SgN  >ärkamis+periiod !22_S	et	f	\N
206483	vanalauluks	vanalauluks =luks  (SgN  >vana+lau+luks !22_S	et	f	\N
206484	vanalauluks	vanalauluks =luks  (SgN  >vana+lau+luks !22_SA	et	f	\N
206485	vanalauluks	vanalauluks =laulu  (SgTr  >vana+laul !22_S	et	f	\N
206486	rahvatemaatika	rahvatemaatika =temaatika  (SgN  >rahva+temaatika !01_S	et	f	\N
206487	rahvatemaatika	rahvatemaatika =temaatika  (SgG  >rahva+temaatika !01_S	et	f	\N
206498	telefoneid	?telefoneid =telefonei  (PlN  >telefonei !26_S	et	f	\N
206499	telefoneid	?telefoneid =telefonei  (SgP  >telefonei !26_S	et	f	\N
206500	telefoneid	?telefoneid =eid  (SgN  >telefon+eid !22_S	et	f	\N
206501	telefoneid	?telefoneid =fonei  (PlN  >tele+fonei !26_S	et	f	\N
206502	telefoneid	?telefoneid =fonei  (SgP  >tele+fonei !26_S	et	f	\N
206503	telefoneid	?telefoneid =foneid  (SgN  >tele+foneid !22_S	et	f	\N
206532	puhkpillorkestrit	?puhkpillorkestrit =puhkpillorkestri  (SgP  >puhkpillorkester !02_S	et	f	\N
206533	puhkpillorkestrit	?puhkpillorkestrit =pillorkestri  (SgP  >puhk+pillorkester !02_S	et	f	\N
206534	sükkane	?sükkane =sükkane  (SgN  >sükkane !12~10_A	et	f	\N
206535	sükkane	?sükkane =sükkane  (IndPrPs_  >sükkanema !27_V	et	f	\N
206536	sükkane	?sükkane =sükkane  (ImpPrSg2  >sükkanema !27_V	et	f	\N
206599	nkroonsust	?nkroonsust =nkroonsu  (SgEl  >nkroonsu !01_S	et	f	\N
206600	nkroonsust	?nkroonsust =nkroonsus  (SgP  >nkroonsus !11~09_S	et	f	\N
206611	kaitsmisega	kaitsmisega =kaitsmise  (SgKom  >kaitsmine !12?10_S	et	f	\N
206612	kaitsmisega	"kaitsmine %kaits  )MINE_vS  <kaitsma ;32_V	et	f	\N
206613	fuchs	?fuchs =fuchs  (SgN  >fuchs !22_S	et	f	\N
206615	üldkeeleteadust	üldkeeleteadust =teadu  (SgEl  >üld+keele+tead !22_S	et	f	\N
206616	üldkeeleteadust	üldkeeleteadust =teadus  (SgP  >üld+keele+teadus !11~09_S	et	f	\N
206634	zum	### zum	et	f	\N
206659	jôulupidu	### jôulupidu	et	f	\N
206664	kohtanud	?kohtanud =kohtanu  (PlN  >kohtanu !01_S	et	f	\N
206665	kohtanud	?kohtanud =kohtanu  (IndPrSg2  >kohtanuma !27_V	et	f	\N
206666	kohtanud	?kohtanud =kohtanud  (ID  >kohtanud !41_A	et	f	\N
206667	kohtanud	?kohtanud =anu  (PlN  >koht+anu !17_S	et	f	\N
206296	aknasse	aknasse =aknas  (SgAdt  >aknane !12_A	et	f	\N
206297	aknasse	"aknane %akna  )NE_aA  <aken ;08_S	et	f	\N
206318	lastelaule	lastelaule =lau  (SgAll  >laste+laug !22_SA	et	f	\N
206319	lastelaule	lastelaule =laule  (PlP  >laste+laul !22_S	et	f	\N
206328	uinu	uinu =uinu  (IndPrPs_  >uinuma !27_V	et	f	\N
206329	uinu	uinu =uinu  (ImpPrSg2  >uinuma !27_V	et	f	\N
206336	aktiivsem	aktiivsem =aktiivsem  (SgN  >aktiivsem !02_A	et	f	\N
206337	aktiivsem	"aktiivsem %aktiivse  )M_cA  <aktiivne ;02_A	et	f	\N
206345	estlastele	?estlastele =estlas  (PlAll  >estlas !07_S	et	f	\N
206346	estlastele	?estlastele =estlas  (PlAll  >estlane !12?10_S	et	f	\N
206347	estlastele	?estlastele =estlastele  (IndPrPs_  >estlastelema !36_V	et	f	\N
206348	estlastele	?estlastele =estlastele  (ImpPrSg2  >estlastelema !36_V	et	f	\N
206369	tähtejõudu	?tähtejõudu =tähtejõudu  (IndPrPs_  >tähtejõuduma !27_V	et	f	\N
206370	tähtejõudu	?tähtejõudu =tähtejõudu  (ImpPrSg2  >tähtejõuduma !27_V	et	f	\N
206371	tähtejõudu	?tähtejõudu =ejõudu  (SgN  >täht+ejõudu !01_S	et	f	\N
206372	tähtejõudu	?tähtejõudu =ejõudu  (SgG  >täht+ejõudu !01_S	et	f	\N
206392	külmas	külmas =külma  (SgIn  >külm !22_AS	et	f	\N
206393	külmas	külmas =külma  (IndIpfSg3  >külmama !29_V	et	f	\N
206420	lätimaa	lätimaa =maa  (SgN  >läti+maa !26_S	et	f	\N
206421	lätimaa	lätimaa =maa  (SgG  >läti+maa !26_S	et	f	\N
206430	iseseisvak	?iseseisvak =seisvak  (SgN  >ise+seisvak !02_S	et	f	\N
206436	taasiseisvumisel	?taasiseisvumisel =taasiseisvumise  (SgAd  >taasiseisvumine !12_S	et	f	\N
206437	taasiseisvumisel	?taasiseisvumisel =isvumise  (SgAd  >taas+ise+isvumine !12_S	et	f	\N
206438	taasiseisvumisel	?taasiseisvumisel =iseisvumise  (SgAd  >taas+iseisvumine !12_S	et	f	\N
206458	rahvanna	?rahvanna =rahvanna  (SgN  >rahvanna !16_S	et	f	\N
206459	rahvanna	?rahvanna =rahvanna  (SgG  >rahvanna !16_S	et	f	\N
206490	rõõmsuse	rõõmsuse =rõõmsuse  (SgG  >rõõmsus !11~09_S	et	f	\N
206491	rõõmsuse	"rõõmsus %rõõmsa  )US_aS  <rõõmus ;02_A	et	f	\N
206495	stiiliks	stiiliks =stiili  (SgTr  >stiil !22_S	et	f	\N
206496	stiiliks	stiiliks =stiili  (KndPrPs  >stiilima !28_V	et	f	\N
206514	südamlikust	südamlikust =südamliku  (SgEl  >südamlik !25_A	et	f	\N
206515	südamlikust	südamlikust =südamlikus  (SgP  >südamlikus !11?09_S	et	f	\N
206516	südamlikust	"südamlikus %südamliku  )US_aS  <südamlik ;25_A	et	f	\N
206517	modermsalt	?modermsalt =modermsa  (SgAbl  >modermsa !01_S	et	f	\N
206518	modermsalt	?modermsalt =modermsalt  (ID  >modermsalt !41_D	et	f	\N
206553	reegilaulades	### reegilaulades	et	f	\N
206561	popularseks	?popularseks =popularse  (SgTr  >popularne !02_A	et	f	\N
206562	popularseks	?popularseks =ularse  (SgTr  >pop+ularne !02_A	et	f	\N
206563	popularseks	?popularseks =ularse  (PlTr  >pop+ularss !22_S	et	f	\N
206571	õppekaardi	õppekaardi =kaardi  (SgG  >õppe+kaart !22_S	et	f	\N
206572	õppekaardi	õppekaardi =kaardi  (SgP  >õppe+kaard !22_S	et	f	\N
206573	õppekaardi	õppekaardi =kaardi  (SgAdt  >õppe+kaard !22_S	et	f	\N
206581	e-mailiga	e-mailiga =liga  (SgN  >e-mai+liga !17_S	et	f	\N
206582	e-mailiga	e-mailiga =liga  (SgG  >e-mai+liga !17_S	et	f	\N
206583	e-mailiga	e-mailiga =liga  (SgP  >e-mai+liga !17_S	et	f	\N
206584	subtitreerimisp	?subtitreerimisp =subtitreerimisp  (SgN  >subtitreerimisp !22_S	et	f	\N
206585	subtitreerimisp	?subtitreerimisp =titreerimisp  (SgN  >sub+titreerimisp !22_S	et	f	\N
206598	lke	### lke	et	f	\N
206614	wernigerodis	?wernigerodis =wernigerodis  (SgN  >wernigerodis !09_S	et	f	\N
206631	tärkavad	tärkavad =tärka  (IndPrPl3  >tärkama !29_V	et	f	\N
206632	tärkavad	tärkavad =tärkava  (PlN  >tärkav !02_A	et	f	\N
206633	tärkavad	"tärkav %tärka  )V_vA  <tärkama ;29_V	et	f	\N
206645	jõulufilmi	jõulufilmi =filmi  (SgG  >jõulu+film !22_S	et	f	\N
206646	jõulufilmi	jõulufilmi =filmi  (SgP  >jõulu+film !22_S	et	f	\N
206647	jõulufilmi	jõulufilmi =filmi  (SgAdt  >jõulu+film !22_S	et	f	\N
206656	vaatsin	?vaatsin =vaat  (IndIpfSg1  >vaatma !34_V	et	f	\N
206657	vaatsin	?vaatsin =vaatsi  (IndPrSg1  >vaatsima !28_V	et	f	\N
206658	vaatsin	?vaatsin =vaatsin  (SgN  >vaatsin !02_S	et	f	\N
206671	lôunaajal	### lôunaajal	et	f	\N
206672	sôime	### sôime	et	f	\N
206683	sibylle	?sibylle =sibylle  (PlP  >sibyll !22_S	et	f	\N
206684	sibylle	?sibylle =sibylle  (IndPrPs_  >sibyllema !27_V	et	f	\N
206685	sibylle	?sibylle =sibylle  (ImpPrSg2  >sibyllema !27_V	et	f	\N
206692	sisseosteid	?sisseosteid =sisseostei  (PlN  >sisseostei !26_S	et	f	\N
206693	sisseosteid	?sisseosteid =sisseostei  (SgP  >sisseostei !26_S	et	f	\N
206694	sisseosteid	?sisseosteid =oste  (PlP  >sisse+oste !06_S	et	f	\N
206695	sisseosteid	?sisseosteid =ostei  (PlN  >sisse+ostei !26_S	et	f	\N
206696	sisseosteid	?sisseosteid =ostei  (SgP  >sisse+ostei !26_S	et	f	\N
206697	sisseosteid	?sisseosteid =osteid  (SgN  >sisse+osteid !22_S	et	f	\N
206705	gump	?gump =gump  (SgN  >gump !22_S	et	f	\N
206708	jôuda	### jôuda	et	f	\N
206712	sachsenis	?sachsenis =sachseni  (SgIn  >sachsen !02_S	et	f	\N
206713	sachsenis	?sachsenis =sachsenis  (SgN  >sachsenis !11_S	et	f	\N
206721	maasusatama	?maasusatama =maasusata  (Sup  >maasusatama !27_V	et	f	\N
206722	maasusatama	?maasusatama =maasusatama  (SgG  >maasusatam !02_A	et	f	\N
206349	märkmida	?märkmida =märkmi  (Inf  >märkmima !28_V	et	f	\N
206350	märkmida	?märkmida =mida  (SgN  >märk+mida !17_S	et	f	\N
206351	märkmida	?märkmida =mida  (SgG  >märk+mida !17_S	et	f	\N
206352	märkmida	?märkmida =mida  (SgP  >märk+mida !17_S	et	f	\N
206353	erinevd	?erinevd =erinevd  (SgN  >erinevd !22_S	et	f	\N
206354	erinevd	?erinevd =nevd  (SgN  >eri+nevd !22_S	et	f	\N
206391	patriootsust	?patriootsust =patriootsus  (SgP  >patriootsus !11~09_S	et	f	\N
206400	pärandatud	pärandatud =päranda  (PtsPtIps  >pärandama !27_V	et	f	\N
206401	pärandatud	pärandatud =pärandatu  (PlN  >pärandatu !01_S	et	f	\N
206402	pärandatud	"pärandatu %päranda  )TU1_vS  <pärandama ;27_V	et	f	\N
206403	pärandatud	pärandatud =pärandatud  (ID  >pärandatud !41_A	et	f	\N
206404	pärandatud	"pärandatud %päranda  )TUD_vA  <pärandama ;27_V	et	f	\N
206405	pärandatud	pärandatud =atu  (PlN  >pärand+att !22_S	et	f	\N
206409	aast	?aast =aas  (SgP  >aane !10_A	et	f	\N
206410	aast	?aast =aast  (SgN  >aast !22_S	et	f	\N
206411	määletavad	?määletavad =määleta  (IndPrPl3  >määletama !27_V	et	f	\N
206412	määletavad	?määletavad =määletava  (PlN  >määletav !02_A	et	f	\N
206413	määletavad	?määletavad =määletava  (PlN  >määletava !16_S	et	f	\N
206414	hüüakse	?hüüakse =hüüakse  (SgG  >hüüakne !02_A	et	f	\N
206415	hüüakse	?hüüakse =hüüakse  (PlP  >hüüaks !22_S	et	f	\N
206416	meekoori	meekoori =koor  (PlP  >mee+koor !13_S	et	f	\N
206417	meekoori	meekoori =koori  (SgG  >mee+koor !22_S	et	f	\N
206418	meekoori	meekoori =koori  (SgP  >mee+koor !22_S	et	f	\N
206419	meekoori	meekoori =koori  (SgAdt  >mee+koor !22_S	et	f	\N
206422	suurimatest	"suurim %suuri  )IM_sA  <suur ;13_A	et	f	\N
206423	suurimatest	suurimatest =mate  (SgEl  >suuri+mate !16_S	et	f	\N
206424	suurimatest	suurimatest =mate  (PlEl  >suuri+matt !22_SA	et	f	\N
206425	suurimatest	suurimatest =mates  (SgP  >suuri+matene !10_A	et	f	\N
206426	suurimatest	"suuri+matene %mate  )NE_aA  <suuri+mate ;16_S	et	f	\N
206431	okomponimendiga	?okomponimendiga =okomponimendi  (SgKom  >okomponiment !22_S	et	f	\N
206433	melest	?melest =mele  (SgEl  >mele !16_S	et	f	\N
206434	melest	?melest =meles  (SgP  >meles !09_S	et	f	\N
206435	melest	?melest =meles  (SgP  >melene !10_A	et	f	\N
206444	estlastest	?estlastest =estlas  (PlEl  >estlas !07_S	et	f	\N
206445	estlastest	?estlastest =estlas  (PlEl  >estlane !12?10_S	et	f	\N
206446	estlastest	?estlastest =estlastes  (SgP  >estlastene !12_A	et	f	\N
206450	hauadel	?hauadel =haua  (PlAd  >haua !16_S	et	f	\N
206456	instrumeendid	?instrumeendid =instrumeendi  (PlN  >instrumeent !22_S	et	f	\N
206457	instrumeendid	?instrumeendid =instrumeendi  (IndPrSg2  >instrumeentima !28_V	et	f	\N
206477	trükimine	?trükimine =trükimine  (SgN  >trükimine !12_S	et	f	\N
206478	trükimine	?trükimine =trükimine  (PlP  >trükimin !19_S	et	f	\N
206488	lauluvõistlustest	lauluvõistlustest =test  (SgN  >laulu+võistlus+test !22_S	et	f	\N
206489	lauluvõistlustest	lauluvõistlustest =võistlus  (PlEl  >laulu+võistlus !11~09_S	et	f	\N
206504	väljandada	?väljandada =väljanda  (Inf  >väljandama !27_V	et	f	\N
206530	trammis	trammis =trammi  (SgIn  >tramm !22_S	et	f	\N
206531	trammis	trammis =trammis  (ID  >trammis !41_DA	et	f	\N
206551	reegilaulud	?reegilaulud =reegilaulu  (IndPrSg2  >reegilauluma !27_V	et	f	\N
206552	reegilaulud	?reegilaulud =gilaulu  (PlN  >ree+gilaulu !01_S	et	f	\N
206554	kordnes	?kordnes =kordne  (PlIn  >kordn !22_S	et	f	\N
206555	kordnes	?kordnes =kordne  (IndIpfSg3  >kordnema !27_V	et	f	\N
206556	kordnes	?kordnes =kordnes  (SgN  >kordnes !09_S	et	f	\N
206557	vanarahvalaul	vanarahvalaul =lau  (SgAd  >vana+rahva+laug !22_SA	et	f	\N
206558	vanarahvalaul	vanarahvalaul =laul  (SgN  >vana+rahva+laul !22_S	et	f	\N
206559	jaansen	?jaansen =jaanse  (IndPrSg1  >jaansema !27_V	et	f	\N
206560	jaansen	?jaansen =jaansen  (SgN  >jaansen !02_S	et	f	\N
206574	aines	aines =aine  (SgIn  >aine !06_S	et	f	\N
206575	aines	aines =aine  (PlIn  >ain !22_S	et	f	\N
206576	aines	aines =aines  (SgN  >aines !09_S	et	f	\N
206577	dmis	### dmis	et	f	\N
206578	retsensiooni	retsensiooni =retsensiooni  (SgG  >retsensioon !22_S	et	f	\N
206579	retsensiooni	retsensiooni =retsensiooni  (SgP  >retsensioon !22_S	et	f	\N
206580	retsensiooni	retsensiooni =retsensiooni  (SgAdt  >retsensioon !22_S	et	f	\N
206586	tete	?tete =tete  (SgN  >tete !06_S	et	f	\N
206587	tete	?tete =tete  (IndPrPs_  >tetema !27_V	et	f	\N
206588	tete	?tete =tete  (ImpPrSg2  >tetema !27_V	et	f	\N
206593	sin	### sin	et	f	\N
206604	diat	?diat =diat  (SgN  >diat !22_S	et	f	\N
206605	tometamine	?tometamine =tometamine  (SgN  >tometamine !12_S	et	f	\N
206606	tometamine	?tometamine =tometamine  (PlP  >tometamin !19_S	et	f	\N
206607	edastamine	edastamine =edastamine  (SgN  >edastamine !12_S	et	f	\N
206608	edastamine	"edastamine %edasta  )MINE_vS  <edastama ;27_V	et	f	\N
206609	analüüsid	analüüsid =analüüsi  (PlN  >analüüs !22_S	et	f	\N
206610	analüüsid	analüüsid =analüüsi  (IndPrSg2  >analüüsima !28_V	et	f	\N
206624	esnimi	?esnimi =esnimi  (SgN  >esnimi !01_S	et	f	\N
206625	esnimi	?esnimi =esnimi  (SgG  >esnimi !01_S	et	f	\N
206626	esnimi	?esnimi =esnimi  (SgG  >esnim !02_A	et	f	\N
206359	tugenes	?tugenes =tugene  (IndIpfSg3  >tugenema !27_V	et	f	\N
206373	tugemini	?tugemini =tugemi  (SgTer  >tugemi !01_S	et	f	\N
206374	tugemini	?tugemini =tugemi  (SgTer  >tugem !02_A	et	f	\N
206375	tugemini	?tugemini =tugemini  (ID  >tugemini !41_D	et	f	\N
206376	tugemini	?tugemini =tugemini  (SgG  >tugemin !19_S	et	f	\N
206377	tugemini	?tugemini =tugemini  (SgP  >tugemin !19_S	et	f	\N
206378	tugemini	?tugemini =tugemini  (SgAdt  >tugemin !19_S	et	f	\N
206382	tagisi	?tagisi =tagisi  (ID  >tagisi !41_D	et	f	\N
206385	võitustele	võitustele =võitus  (PlAll  >võitus !11~09_S	et	f	\N
206386	võitustele	"võitus %võita  )US_vS  <võitama ;27_V	et	f	\N
206387	võitustele	"võitus %või  )TUS1_aS  <võidma ;34_V	et	f	\N
206388	võitustele	"võitus %või  )TUS2_aS  <või ;26_S	et	f	\N
206389	võitustele	võitustele =tuste  (PlAll  >või+tust !22_S	et	f	\N
206427	üritamine	üritamine =üritamine  (SgN  >üritamine !12_S	et	f	\N
206428	üritamine	"üritamine %ürita  )MINE_vS  <üritama ;27_V	et	f	\N
206439	taasiseivumisel	?taasiseivumisel =taasiseivumise  (SgAd  >taasiseivumine !12_S	et	f	\N
206440	taasiseivumisel	?taasiseivumisel =ivumise  (SgAd  >taas+ise+ivumine !12_S	et	f	\N
206441	taasiseivumisel	?taasiseivumisel =iseivumise  (SgAd  >taas+iseivumine !12_S	et	f	\N
206469	ansaamblid	?ansaamblid =ansaambli  (PlN  >ansaambli !01_S	et	f	\N
206470	ansaamblid	?ansaamblid =ansaambli  (PlN  >ansaambel !02_S	et	f	\N
206471	ansaamblid	?ansaamblid =ansaambli  (IndPrSg2  >ansaamblima !28_V	et	f	\N
206472	väärtustasid	väärtustasid =väärtusta  (IndIpfSg2  >väärtustama !27_V	et	f	\N
206473	väärtustasid	väärtustasid =väärtusta  (IndIpfPl3  >väärtustama !27_V	et	f	\N
206492	rahvadega	?rahvadega =rahva  (PlKom  >rahva !16_S	et	f	\N
206493	regivärsilise	regivärsilise =värsilise  (SgG  >regi+värsiline !12_A	et	f	\N
206494	regivärsilise	"regi+värsiline %värsi  )LINE_aA  <regi+värss ;22_S	et	f	\N
206497	mehedel	?mehedel =mehe  (PlAd  >mehe !16_S	et	f	\N
206505	halbas	?halbas =halba  (SgIn  >halba !16_S	et	f	\N
206506	halbas	?halbas =halba  (IndIpfSg3  >halbama !29_V	et	f	\N
206507	halbas	?halbas =halbas  (SgN  >halbas !07_S	et	f	\N
206519	võtasin	?võtasin =võta  (IndIpfSg1  >võtama !27_V	et	f	\N
206520	võtasin	?võtasin =võtasin  (SgN  >võtasin !19_S	et	f	\N
206523	esitevad	?esitevad =esiteva  (PlN  >esitev !02_A	et	f	\N
206524	esitevad	?esitevad =esiteva  (PlN  >esiteva !16_S	et	f	\N
206525	esitevad	?esitevad =teva  (PlN  >esi+teva !17_S	et	f	\N
206526	kokkulepel	kokkulepel =lepe  (PlAd  >kokku+lepp !22_S	et	f	\N
206527	kokkulepel	kokkulepel =lepe  (PlAd  >kokku+lepp !22_SA	et	f	\N
206537	sõpruga	### sõpruga	et	f	\N
206538	kooslaulda	?kooslaulda =kooslaulda  (IndPrPs_  >kooslauldama !27_V	et	f	\N
206539	kooslaulda	?kooslaulda =kooslaulda  (ImpPrSg2  >kooslauldama !27_V	et	f	\N
206540	kooslaulda	?kooslaulda =laulda  (SgN  >koos+laulda !01_S	et	f	\N
206541	kooslaulda	?kooslaulda =laulda  (SgG  >koos+laulda !01_S	et	f	\N
206542	liigutasid	liigutasid =liiguta  (IndIpfSg2  >liigutama !27_V	et	f	\N
206543	liigutasid	liigutasid =liiguta  (IndIpfPl3  >liigutama !27_V	et	f	\N
206544	komposeerima	?komposeerima =komposeeri  (Sup  >komposeerima !28_V	et	f	\N
206545	komposeerima	?komposeerima =komposeerima  (SgG  >komposeerim !02_A	et	f	\N
206546	komposeerima	?komposeerima =poseerima  (SgG  >kom+poseerim !02_A	et	f	\N
206564	tereminu	?tereminu =tereminu  (SgN  >tereminu !01_S	et	f	\N
206565	tereminu	?tereminu =tereminu  (SgG  >tereminu !01_S	et	f	\N
206566	tereminu	?tereminu =tereminu  (IndPrPs_  >tereminuma !27_V	et	f	\N
206567	tereminu	?tereminu =tereminu  (ImpPrSg2  >tereminuma !27_V	et	f	\N
206568	tereminu	?tereminu =minu  (SgN  >tere+minu !17_S	et	f	\N
206569	tereminu	?tereminu =minu  (SgG  >tere+minu !17_S	et	f	\N
206570	tereminu	?tereminu =minu  (SgP  >tere+minu !17_S	et	f	\N
206589	levaade	?levaade =levaa  (PlG  >levaa !26_S	et	f	\N
206590	levaade	?levaade =levaade  (SgN  >levaade !16_S	et	f	\N
206591	levaade	?levaade =levaade  (SgG  >levaade !16_S	et	f	\N
206592	levaade	?levaade =levaade  (PlP  >levaad !22_S	et	f	\N
206594	lesehitust	?lesehitust =lesehitu  (SgEl  >lesehitu !01_A	et	f	\N
206595	lesehitust	?lesehitust =lesehitus  (SgP  >lesehitus !11?09_S	et	f	\N
206596	lesehitust	?lesehitust =hitu  (SgEl  >lese+hitu !16_S	et	f	\N
206597	lesehitust	?lesehitust =hitus  (SgP  >lese+hitus !09_S	et	f	\N
206601	tsin	### tsin	et	f	\N
206603	kom	### kom	et	f	\N
206617	insenerbüroos	?insenerbüroos =insenerbüroo  (SgIn  >insenerbüroo !26_S	et	f	\N
206618	insenerbüroos	?insenerbüroos =insenerbüroos  (SgN  >insenerbüroos !22_S	et	f	\N
206630	latinise	?latinise =latinise  (SgG  >latinis !11_S	et	f	\N
206637	helendavad	helendavad =helenda  (IndPrPl3  >helendama !27_V	et	f	\N
206639	helendavad	helendavad =helendava  (PlN  >helendav !02_A	et	f	\N
206640	helendavad	"helendav %helenda  )V_vA  <helendama ;27_V	et	f	\N
206648	ettevalmistama	?ettevalmistama =ettevalmista  (Sup  >ettevalmistama !27_V	et	f	\N
206649	ettevalmistama	?ettevalmistama =ettevalmistama  (SgG  >ettevalmistam !02_A	et	f	\N
206650	ettevalmistama	?ettevalmistama =tama  (SgN  >ette+valmis+tama !17_S	et	f	\N
206651	ettevalmistama	?ettevalmistama =tama  (SgG  >ette+valmis+tama !17_S	et	f	\N
206652	ettevalmistama	?ettevalmistama =tama  (SgP  >ette+valmis+tama !17_S	et	f	\N
206635	osterfest	?osterfest =osterfe  (PlEl  >osterf !22_S	et	f	\N
206636	osterfest	?osterfest =osterfes  (SgP  >osterfene !12_A	et	f	\N
206641	festivalikäia	festivalikäia =käia  (SgG  >festivali+käi !22_S	et	f	\N
206642	festivalikäia	festivalikäia =käia  (SgP  >festivali+käi !22_S	et	f	\N
206643	festivalikäia	festivalikäia =käia  (SgAdt  >festivali+käi !22_S	et	f	\N
206654	jõulukingitustega	jõulukingitustega =kingitus  (PlKom  >jõulu+kingitus !11_S	et	f	\N
206655	jõulukingitustega	"jõulu+kingitus %kingi  )TUS2_aS  <jõulu+kink ;22_S	et	f	\N
206661	kultuuriantropoloogia	kultuuriantropoloogia =antropoloogia  (SgN  >kultuuri+antropoloogia !01_S	et	f	\N
206662	kultuuriantropoloogia	kultuuriantropoloogia =antropoloogia  (SgG  >kultuuri+antropoloogia !01_S	et	f	\N
206676	ôhtul	### ôhtul	et	f	\N
206679	eigentlich	?eigentlich =eigentlich  (SgN  >eigentlich !22_S	et	f	\N
206680	eigentlich	?eigentlich =gentlich  (SgN  >ei+gentlich !22_S	et	f	\N
206690	hôôgveini	### hôôgveini	et	f	\N
206691	vôimalus	### vôimalus	et	f	\N
206699	vôistlused	### vôistlused	et	f	\N
206700	päiket	### päiket	et	f	\N
206703	jôuludeni	### jôuludeni	et	f	\N
206706	ôhtu	### ôhtu	et	f	\N
206719	erzgebirgest	?erzgebirgest =erzgebirge  (PlEl  >erzgebirk !22_S	et	f	\N
206720	erzgebirgest	?erzgebirgest =erzgebirges  (SgP  >erzgebirgene !12_A	et	f	\N
206731	räuchermännchen	?räuchermännchen =räuchermännchen  (SgN  >räuchermännchen !02_S	et	f	\N
206778	halvemusedlinnas	?halvemusedlinnas =halvemusedlinna  (SgIn  >halvemusedlinna !16_S	et	f	\N
206779	punktisse	punktisse =punkti  (SgIll  >punkt !22_S	et	f	\N
206780	punktisse	punktisse =tisse  (PlP  >punk+tiss !22_S	et	f	\N
206783	igaveks	?igaveks =veks  (SgN  >iga+veks !22_S	et	f	\N
206789	eeliseid	eeliseid =eelise  (PlP  >eelis !09_S	et	f	\N
206790	eeliseid	eeliseid =eelise  (PlP  >eeline !10_A	et	f	\N
206791	eeliseid	"eeline %ee  )LINE_aA  <esi ;15_S	et	f	\N
206812	kaitseme	kaitseme =kaitse  (IndPrPl1  >kaitsema !28_V	et	f	\N
206813	kaitseme	kaitseme =kaitse  (IndPrPl1  >kaitsma !32_V	et	f	\N
206819	abieelub	?abieelub =abieelu  (IndPrSg3  >abieeluma !27_V	et	f	\N
206844	rääkija	rääkija =rääkija  (SgN  >rääkija !01_S	et	f	\N
206845	rääkija	"rääkija %rääki  )JA_vS  <rääkima ;28_V	et	f	\N
206846	rääkija	rääkija =rääkija  (SgG  >rääkija !01_S	et	f	\N
206855	eestlanna	eestlanna =eestlanna  (SgN  >eestlanna !16_S	et	f	\N
206856	eestlanna	eestlanna =eestlanna  (SgG  >eestlanna !16_S	et	f	\N
206863	rääkijat	rääkijat =rääkija  (SgP  >rääkija !01_S	et	f	\N
206864	rääkijat	"rääkija %rääki  )JA_vS  <rääkima ;28_V	et	f	\N
206872	tiiule	?tiiule =tiiu  (SgAll  >tiiu !16_S	et	f	\N
206873	tiiule	?tiiule =tiiule  (IndPrPs_  >tiiulema !27_V	et	f	\N
206874	tiiule	?tiiule =tiiule  (ImpPrSg2  >tiiulema !27_V	et	f	\N
206881	vanemas	vanemas =vanema  (SgIn  >vanem !02_AS	et	f	\N
206882	vanemas	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
206884	latinia	?latinia =latinia  (SgN  >latinia !01_S	et	f	\N
206885	latinia	?latinia =latinia  (SgG  >latinia !01_S	et	f	\N
206889	heasti	?heasti =heasti  (ID  >heasti !41_D	et	f	\N
206890	heasti	?heasti =heasti  (SgG  >heast !22_S	et	f	\N
206891	heasti	?heasti =heasti  (SgP  >heast !22_S	et	f	\N
206892	heasti	?heasti =heasti  (SgAdt  >heast !22_S	et	f	\N
206893	heasti	?heasti =heasti  (IndPrPs_  >heastima !28_V	et	f	\N
206894	heasti	?heasti =heasti  (ImpPrSg2  >heastima !28_V	et	f	\N
206898	budapest	?budapest =budape  (PlEl  >budapp !22_S	et	f	\N
206899	budapest	?budapest =budapes  (SgP  >budapene !12_A	et	f	\N
206900	budapest	?budapest =pest  (SgN  >buda+pest !22_S	et	f	\N
206925	budas	?budas =buda  (IndIpfSg3  >budama !27_V	et	f	\N
206926	budas	?budas =budas  (SgN  >budas !07_S	et	f	\N
206933	ypestis	?ypestis =ypesti  (IndIpfSg3  >ypestima !28_V	et	f	\N
206934	ypestis	?ypestis =ypestis  (SgN  >ypestis !11_S	et	f	\N
206935	esimasel	?esimasel =esimase  (SgAd  >esimane !12_A	et	f	\N
206936	esimasel	?esimasel =mase  (SgAd  >esi+mase !16_S	et	f	\N
206937	esimasel	?esimasel =masel  (SgN  >esi+masel !02_S	et	f	\N
206938	toolit	?toolit =tooli  (SgP  >tooli !16_S	et	f	\N
206939	toolit	?toolit =toolit  (SgN  >toolit !02_S	et	f	\N
206961	helrohelised	?helrohelised =helrohelise  (PlN  >helroheline !12_A	et	f	\N
206969	jõki	?jõki =jõki  (SgN  >jõki !16_S	et	f	\N
206971	jõki	?jõki =jõki  (SgG  >jõki !16_S	et	f	\N
206972	jõki	?jõki =jõki  (SgG  >jõkk !22_S	et	f	\N
206974	jõki	?jõki =jõki  (IndPrPs_  >jõkima !27_V	et	f	\N
206976	jõki	?jõki =jõki  (IndPrPs_  >jõkkima !28_V	et	f	\N
206977	jõki	?jõki =jõki  (ImpPrSg2  >jõkima !27_V	et	f	\N
206978	jõki	?jõki =jõki  (ImpPrSg2  >jõkkima !28_V	et	f	\N
206984	budaösis	?budaösis =budaösi  (SgIn  >budaösi !01_S	et	f	\N
206985	budaösis	?budaösis =budaösi  (SgIn  >budaös !22_S	et	f	\N
206986	budaösis	?budaösis =budaösi  (IndIpfSg3  >budaösima !28_V	et	f	\N
206987	budaösis	?budaösis =budaösis  (SgN  >budaösis !09_S	et	f	\N
206988	budaösis	?budaösis =ösi  (SgIn  >buda+ösi !17_S	et	f	\N
206989	budaösis	?budaösis =ösis  (SgN  >buda+ösis !09_S	et	f	\N
206992	taaskas	?taaskas =taaska  (SgIn  >taaska !01_S	et	f	\N
206653	ettevalmistama	?ettevalmistama =valmistama  (SgG  >ette+valmistam !02_A	et	f	\N
206660	ülestôusma	### ülestôusma	et	f	\N
206663	sôpra	### sôpra	et	f	\N
206668	ülikooliraamatukogus	ülikooliraamatukogus =kogu  (SgIn  >üli+kooli+raamatu+kogu !17_S	et	f	\N
206669	ülikooliraamatukogus	ülikooliraamatukogus =kogus  (SgN  >üli+kooli+raamatu+kogus !02_A	et	f	\N
206670	ülikooliraamatukogus	ülikooliraamatukogus =kogus  (SgN  >üli+kooli+raamatu+kogus !09_S	et	f	\N
206678	dir	### dir	et	f	\N
206686	bergist	?bergist =bergi  (SgEl  >berk !22_S	et	f	\N
206687	bergist	?bergist =bergis  (SgP  >bergis !09_S	et	f	\N
206688	bergist	?bergist =bergist  (SgN  >bergist !22_S	et	f	\N
206702	jôuludeks	### jôuludeks	et	f	\N
206707	môtet	### môtet	et	f	\N
206714	erzgebirge	?erzgebirge =erzgebirge  (PlP  >erzgebirg !22_S	et	f	\N
206740	zwönitzi	?zwönitzi =zwönitzi  (SgN  >zwönitzi !01_S	et	f	\N
206741	zwönitzi	?zwönitzi =zwönitzi  (SgG  >zwönitzi !01_S	et	f	\N
206744	jahnsdorfisse	?jahnsdorfisse =jahnsdorfi  (SgIll  >jahnsdorfi !01_S	et	f	\N
206745	jahnsdorfisse	?jahnsdorfisse =jahnsdorfi  (SgIll  >jahnsdorf !22_S	et	f	\N
206746	jahnsdorfisse	?jahnsdorfisse =jahnsdorfis  (SgAdt  >jahnsdorfis !11_S	et	f	\N
206747	jahnsdorfisse	?jahnsdorfisse =jahnsdorfisse  (SgG  >jahnsdorfisne !02_A	et	f	\N
206748	jahnsdorfisse	?jahnsdorfisse =jahnsdorfisse  (PlP  >jahnsdorfiss !22_S	et	f	\N
206754	jahnsdorf	?jahnsdorf =jahnsdorf  (SgN  >jahnsdorf !22_S	et	f	\N
206763	asuks	asuks =asu  (SgTr  >asu !17_S	et	f	\N
206764	asuks	asuks =asu  (PlTr  >ask !22_S	et	f	\N
206765	asuks	asuks =asu  (KndPrPs  >asuma !27_V	et	f	\N
206773	göttingen	?göttingen =göttingen  (SgN  >göttingen !19_S	et	f	\N
206781	jnekõikjal	?jnekõikjal =jnekõikja  (SgAd  >jnekõikja !01_S	et	f	\N
206782	jnekõikjal	?jnekõikjal =jnekõikja  (SgAd  >jnekõikjas !02_A	et	f	\N
206787	vaiksem	vaiksem =vaiksem  (SgN  >vaiksem !02_A	et	f	\N
206788	vaiksem	"vaiksem %vaikse  )M_cA  <vaikne ;02_A	et	f	\N
206797	jean	?jean =jean  (SgN  >jean !22_S	et	f	\N
206798	aususega	aususega =aususe  (SgKom  >ausus !11~09_S	et	f	\N
206799	aususega	"ausus %au  )SUS_aS  <au ;26_S	et	f	\N
206800	aususega	"ausus %ausa  )US_aS  <aus ;02_A	et	f	\N
206804	erikut	?erikut =eriku  (SgP  >eriku !01_S	et	f	\N
206805	erikut	?erikut =eriku  (SgP  >erik !02_S	et	f	\N
206810	püüdmine	püüdmine =püüdmine  (SgN  >püüdmine !12?10_S	et	f	\N
206811	püüdmine	"püüdmine %püüd  )MINE_vS  <püüdma ;34_V	et	f	\N
206839	tõeselus	?tõeselus =tõeselu  (SgIn  >tõeselu !17_S	et	f	\N
206840	tõeselus	?tõeselus =tõeselu  (IndIpfSg3  >tõeseluma !27_V	et	f	\N
206841	tõeselus	?tõeselus =tõeselus  (SgN  >tõeselus !11_S	et	f	\N
206842	tõeselus	?tõeselus =selu  (SgIn  >tõe+selu !17_S	et	f	\N
206843	tõeselus	?tõeselus =selus  (SgN  >tõe+selus !09_S	et	f	\N
206875	tiiul	?tiiul =tiiu  (SgAd  >tiiu !16_S	et	f	\N
206876	tiiul	?tiiul =tiiul  (SgN  >tiiul !02_S	et	f	\N
206886	leedugi	leedugi =leedu  (SgN^  >leedu !16_S	et	f	\N
206887	leedugi	"leedu %lee  )TU1_vS^  <leema ;37_V	et	f	\N
206888	leedugi	leedugi =leedu  (SgG^  >leedu !16_S	et	f	\N
206895	budapest	?budapest =budape  (PlEl  >budapp !22_S	et	f	\N
206896	budapest	?budapest =budapes  (SgP  >budapene !12_A	et	f	\N
206897	budapest	?budapest =pest  (SgN  >buda+pest !22_S	et	f	\N
206901	miljoona	?miljoona =miljoo  (SgEs  >miljoo !26_S	et	f	\N
206902	miljoona	?miljoona =miljoona  (SgN  >miljoona !16_S	et	f	\N
206903	miljoona	?miljoona =miljoona  (SgG  >miljoona !16_S	et	f	\N
206911	venne	?venne =venne  (SgN  >venne !06_S	et	f	\N
206912	venne	?venne =venne  (PlP  >venn !22_S	et	f	\N
206913	venne	?venne =venne  (IndPrPs_  >vennema !27_V	et	f	\N
206914	venne	?venne =venne  (ImpPrSg2  >vennema !27_V	et	f	\N
206918	hundkõer	?hundkõer =hundkõer  (SgN  >hundkõer !22_S	et	f	\N
206922	tubal	?tubal =tubal  (SgN  >tubal !02_S	et	f	\N
206923	budas	?budas =buda  (IndIpfSg3  >budama !27_V	et	f	\N
206924	budas	?budas =budas  (SgN  >budas !07_S	et	f	\N
206931	agast	?agast =agas  (SgP  >agas !07_S	et	f	\N
206932	agast	?agast =agas  (SgP  >agane !10_A	et	f	\N
206957	koska	?koska =koska  (SgN  >koska !16_S	et	f	\N
206958	koska	?koska =koska  (SgG  >koska !16_S	et	f	\N
206959	koska	?koska =koska  (IndPrPs_  >koskama !29_V	et	f	\N
206960	koska	?koska =koska  (ImpPrSg2  >koskama !29_V	et	f	\N
206963	emage	?emage =ema  (ImpPrPl2  >emama !27_V	et	f	\N
206964	natuke-natuke	natuke-natuke =natuke  (ID  >natuke-natuke !41_D	et	f	\N
206965	natuke-natuke	natuke-natuke =natuke  (SgN  >natuke-natuke !12_S	et	f	\N
206967	duna	?duna =duna  (SgN  >duna !17_S	et	f	\N
206968	duna	?duna =duna  (SgG  >duna !17_S	et	f	\N
206970	duna	?duna =duna  (SgP  >duna !17_S	et	f	\N
206973	duna	?duna =duna  (IndPrPs_  >dunama !27_V	et	f	\N
206975	duna	?duna =duna  (ImpPrSg2  >dunama !27_V	et	f	\N
206990	museos	?museos =museo  (SgIn  >museo !01_S	et	f	\N
206991	museos	?museos =museos  (SgN  >museos !22_S	et	f	\N
207004	abelius	?abelius =abeliu  (SgIn  >abeliu !01_S	et	f	\N
207005	abelius	?abelius =abelius  (SgN  >abelius !11_S	et	f	\N
206673	mensas	?mensas =mensa  (SgIn  >mensa !16_S	et	f	\N
206674	mensas	?mensas =mensa  (IndIpfSg3  >mensama !29_V	et	f	\N
206675	mensas	?mensas =mensas  (SgN  >mensas !07_S	et	f	\N
206681	schon	### schon	et	f	\N
206709	erzgebirges	?erzgebirges =erzgebirge  (PlIn  >erzgebirk !22_S	et	f	\N
206760	tõrvas	tõrvas =tõrva  (SgIn  >tõrv !22_S	et	f	\N
206761	tõrvas	tõrvas =tõrva  (IndIpfSg3  >tõrvama !29_V	et	f	\N
206762	tõrvas	tõrvas =tõrvas  (SgN  >tõrvas !09_S	et	f	\N
206766	lõunaeestis	?lõunaeestis =lõunaeesti  (IndIpfSg3  >lõunaeestima !28_V	et	f	\N
206767	lõunaeestis	?lõunaeestis =lõunaeestis  (SgN  >lõunaeestis !09_S	et	f	\N
206768	lõunaeestis	?lõunaeestis =eestis  (SgN  >lõuna+eestis !09_S	et	f	\N
206769	lõunaeestis	?lõunaeestis =naeestis  (SgN  >lõu+naeestis !11_S	et	f	\N
206774	tartupärane	tartupärane =pärane  (SgN  >tartu+pärane !10_A	et	f	\N
206775	tartupärane	"tartu+pärane %pära  )NE_aA  <tartu+pära ;17_S	et	f	\N
206776	elamisel	elamisel =elamise  (SgAd  >elamine !12_S	et	f	\N
206777	elamisel	"elamine %ela  )MINE_vS  <elama ;27_V	et	f	\N
206803	halbbr	?halbbr =halbbr  (SgN  >halbbr !22_S	et	f	\N
206806	mõlemil	?mõlemil =mõlemi  (SgAd  >mõlemi !01_S	et	f	\N
206807	mõlemil	?mõlemil =mõlemi  (SgAd  >mõlem !02_A	et	f	\N
206818	eesbr	?eesbr =eesbr  (SgN  >eesbr !22_S	et	f	\N
206848	kuuldu	kuuldu =kuuldu  (SgN  >kuuldu !01_S	et	f	\N
206849	kuuldu	"kuuldu %kuul  )TU1_vS  <kuulma ;33_V	et	f	\N
206850	kuuldu	kuuldu =kuuldu  (SgG  >kuuldu !01_S	et	f	\N
206851	kuuldu	kuuldu =kuuldu  (SgP  >kuuld !22_S	et	f	\N
206852	kuuldu	kuuldu =kuuldu  (SgAdt  >kuuld !22_S	et	f	\N
206853	kuuldu	kuuldu =kuuldu  (IndPrPs_  >kuulduma !27_V	et	f	\N
206854	kuuldu	kuuldu =kuuldu  (ImpPrSg2  >kuulduma !27_V	et	f	\N
206857	pikaldaselt	pikaldaselt =pikaldase  (SgAbl  >pikaldane !12_A	et	f	\N
206858	pikaldaselt	pikaldaselt =pikaldaselt  (ID  >pikaldaselt !41_D	et	f	\N
206859	pikaldaselt	"pikaldaselt %pikaldase  )LT_mD  <pikaldane ;12_A	et	f	\N
206860	aksendiga	?aksendiga =aksendi  (SgKom  >aksendi !01_S	et	f	\N
206861	aksendiga	?aksendiga =aksendi  (SgKom  >aksend !02_S	et	f	\N
206862	aksendiga	?aksendiga =aksendi  (SgKom  >aksent !22_S	et	f	\N
206865	sünndinud	?sünndinud =sünndi  (PtsPtPs  >sünndima !28_V	et	f	\N
206866	sünndinud	?sünndinud =sünndinu  (PlN  >sünndinu !01_S	et	f	\N
206867	sünndinud	?sünndinud =sünndinu  (IndPrSg2  >sünndinuma !27_V	et	f	\N
206868	sünndinud	?sünndinud =sünndinud  (ID  >sünndinud !41_A	et	f	\N
206879	lauril	?lauril =lauri  (SgAd  >lauri !16_S	et	f	\N
206880	lauril	?lauril =lauri  (SgAd  >laur !22_S	et	f	\N
206883	loan	?loan =loan  (SgN  >loan !22_S	et	f	\N
206904	budapestil	?budapestil =budapestil  (SgN  >budapestil !02_S	et	f	\N
206905	budapestil	?budapestil =pesti  (SgAd  >buda+pesti !16_S	et	f	\N
206906	budapestil	?budapestil =pesti  (SgAd  >buda+pest !22_S	et	f	\N
206919	kõer	?kõer =kõer  (SgN  >kõer !22_S	et	f	\N
206920	roosal	roosal =roosa  (SgAd  >roosa !16_AS	et	f	\N
206921	roosal	roosal =roosa  (SgAd  >roosk !22_S	et	f	\N
206940	raamaturiuli	?raamaturiuli =raamaturiuli  (SgN  >raamaturiuli !16_S	et	f	\N
206941	raamaturiuli	?raamaturiuli =raamaturiuli  (SgG  >raamaturiuli !16_S	et	f	\N
206942	raamaturiuli	?raamaturiuli =raamaturiuli  (SgG  >raamaturiul !19_S	et	f	\N
206943	raamaturiuli	?raamaturiuli =raamaturiuli  (SgP  >raamaturiul !19_S	et	f	\N
206944	raamaturiuli	?raamaturiuli =raamaturiuli  (SgAdt  >raamaturiul !19_S	et	f	\N
206945	raamaturiuli	?raamaturiuli =raamaturiuli  (IndPrPs_  >raamaturiulima !28_V	et	f	\N
206946	raamaturiuli	?raamaturiuli =raamaturiuli  (ImpPrSg2  >raamaturiulima !28_V	et	f	\N
206947	raamaturiuli	?raamaturiuli =riuli  (SgN  >raamatu+riuli !16_S	et	f	\N
206948	raamaturiuli	?raamaturiuli =riuli  (SgG  >raamatu+riuli !16_S	et	f	\N
206949	raamaturiuli	?raamaturiuli =riuli  (SgG  >raamatu+riul !22_S	et	f	\N
206950	raamaturiuli	?raamaturiuli =riuli  (SgP  >raamatu+riul !22_S	et	f	\N
206951	raamaturiuli	?raamaturiuli =riuli  (SgAdt  >raamatu+riul !22_S	et	f	\N
206952	raamaturiuli	?raamaturiuli =aturiuli  (SgN  >raam+aturiuli !16_S	et	f	\N
206953	raamaturiuli	?raamaturiuli =aturiuli  (SgG  >raam+aturiuli !16_S	et	f	\N
206954	raamaturiuli	?raamaturiuli =aturiuli  (SgG  >raam+aturiul !19_S	et	f	\N
206955	raamaturiuli	?raamaturiuli =aturiuli  (SgP  >raam+aturiul !19_S	et	f	\N
206956	raamaturiuli	?raamaturiuli =aturiuli  (SgAdt  >raam+aturiul !19_S	et	f	\N
206966	majit	?majit =majit  (SgN  >majit !02_S	et	f	\N
206979	abidisis	?abidisis =abidisi  (PlIn  >abidis !11_S	et	f	\N
206980	abidisis	?abidisis =abidisis  (SgN  >abidisis !09_S	et	f	\N
206981	abidisis	?abidisis =disi  (SgIn  >abi+disi !17_S	et	f	\N
206982	abidisis	?abidisis =disis  (SgN  >abi+disis !09_S	et	f	\N
206997	uksid	?uksid =uksi  (PlN  >uksi !16_S	et	f	\N
206998	uksid	?uksid =uksi  (IndPrSg2  >uksima !28_V	et	f	\N
207000	rohkane	?rohkane =rohkane  (SgN  >rohkane !12~10_A	et	f	\N
207001	rohkane	?rohkane =rohkane  (IndPrPs_  >rohkanema !27_V	et	f	\N
207002	rohkane	?rohkane =rohkane  (ImpPrSg2  >rohkanema !27_V	et	f	\N
207013	lead	?lead =lea  (PlN  >lea !26_S	et	f	\N
207014	lead	?lead =lea  (SgP  >lea !26_S	et	f	\N
207015	lead	?lead =lead  (SgN  >lead !22_S	et	f	\N
207016	pinkid	### pinkid	et	f	\N
206723	maasusatama	?maasusatama =usatama  (SgG  >maas+usatam !02_A	et	f	\N
206724	maasusatama	?maasusatama =susatama  (SgG  >maa+susatam !02_A	et	f	\N
206734	aknade	### aknade	et	f	\N
206735	thalheimis	?thalheimis =thalheimi  (SgIn  >thalheimi !01_S	et	f	\N
206736	thalheimis	?thalheimis =thalheimi  (SgIn  >thalheim !02_A	et	f	\N
206737	thalheimis	?thalheimis =thalheimi  (IndIpfSg3  >thalheimima !28_V	et	f	\N
206738	thalheimis	?thalheimis =thalheimis  (SgN  >thalheimis !09_S	et	f	\N
206749	thalheimi	?thalheimi =thalheimi  (SgN  >thalheimi !01_S	et	f	\N
206750	thalheimi	?thalheimi =thalheimi  (SgG  >thalheimi !01_S	et	f	\N
206751	thalheimi	?thalheimi =thalheimi  (SgG  >thalheim !02_A	et	f	\N
206752	thalheimi	?thalheimi =thalheimi  (IndPrPs_  >thalheimima !28_V	et	f	\N
206753	thalheimi	?thalheimi =thalheimi  (ImpPrSg2  >thalheimima !28_V	et	f	\N
206755	jahnsdorfi	?jahnsdorfi =jahnsdorfi  (SgN  >jahnsdorfi !01_S	et	f	\N
206756	jahnsdorfi	?jahnsdorfi =jahnsdorfi  (SgG  >jahnsdorfi !01_S	et	f	\N
206757	jahnsdorfi	?jahnsdorfi =jahnsdorfi  (SgG  >jahnsdorf !22_S	et	f	\N
206758	jahnsdorfi	?jahnsdorfi =jahnsdorfi  (SgP  >jahnsdorf !22_S	et	f	\N
206759	jahnsdorfi	?jahnsdorfi =jahnsdorfi  (SgAdt  >jahnsdorf !22_S	et	f	\N
206792	rahulikem	rahulikem =rahulikem  (SgN  >rahulikem !02_A	et	f	\N
206793	rahulikem	"rahulikem %rahulike  )IM_sA  <rahulik ;25_A	et	f	\N
206794	räägiksid	räägiksid =räägi  (KndPrSg2  >rääkima !28_V	et	f	\N
206795	räägiksid	räägiksid =räägi  (KndPrPl3  >rääkima !28_V	et	f	\N
206801	must-valgel	must-valgel =valge  (SgAd  >must-valge !01_AS	et	f	\N
206802	must-valgel	must-valgel =valge  (PlAd  >must-valk !22_S	et	f	\N
206808	lihtsambr	?lihtsambr =lihtsambr  (SgN  >lihtsambr !22_S	et	f	\N
206809	lihtsambr	?lihtsambr =sambr  (SgN  >liht+sambr !22_S	et	f	\N
206814	ebaausamatel	ebaausamatel =mate  (SgAd  >eba+ausa+mate !16_S	et	f	\N
206815	ebaausamatel	ebaausamatel =mate  (PlAd  >eba+ausa+matt !22_SA	et	f	\N
206816	ebaausamatel	ebaausamatel =ausama  (PlAd  >eba+ausam !02_A	et	f	\N
206817	ebaausamatel	"eba+ausam %ausa  )M_cA  <eba+aus ;02_A	et	f	\N
206823	kaduks	### kaduks	et	f	\N
206824	põletavad	põletavad =põleta  (IndPrPl3  >põletama !27_V	et	f	\N
206825	põletavad	põletavad =põletava  (PlN  >põletav !02_A	et	f	\N
206826	põletavad	"põletav %põle  )TAV_vAS  <põlema ;27_V	et	f	\N
206827	põletavad	"põletav %põleta  )V_vA  <põletama ;27_V	et	f	\N
206830	teravillja	?teravillja =teravillja  (SgN  >teravillja !16_S	et	f	\N
206831	teravillja	?teravillja =teravillja  (SgG  >teravilljas !02_A	et	f	\N
206832	teravillja	?teravillja =teravillja  (SgG  >teravillja !16_S	et	f	\N
206833	teravillja	?teravillja =illja  (SgN  >terav+illja !01_S	et	f	\N
206834	teravillja	?teravillja =illja  (SgG  >terav+illja !01_S	et	f	\N
206835	teravillja	?teravillja =illja  (SgG  >terav+illjas !02_A	et	f	\N
206836	teravillja	?teravillja =villja  (SgN  >tera+villja !01_S	et	f	\N
206837	teravillja	?teravillja =villja  (SgG  >tera+villja !01_S	et	f	\N
206838	teravillja	?teravillja =villja  (SgG  >tera+villjas !02_A	et	f	\N
206847	rääkijadel	### rääkijadel	et	f	\N
206869	vahur	?vahur =vahur  (SgN  >vahur !02_S	et	f	\N
206871	tambet	?tambet =tambe  (SgP  >tambe !06_S	et	f	\N
206916	vennel	?vennel =venne  (PlAd  >venn !22_S	et	f	\N
206917	vennel	?vennel =vennel  (SgN  >vennel !02_S	et	f	\N
206962	ungarin	?ungarin =ungarin  (SgN  >ungarin !19_S	et	f	\N
206995	aknid	?aknid =akni  (PlN  >akn !22_S	et	f	\N
206996	aknid	?aknid =akni  (IndPrSg2  >aknima !28_V	et	f	\N
207010	pealinns	?pealinns =pealinns  (SgN  >pealinns !02_S	et	f	\N
207011	pealinns	?pealinns =inns  (SgN  >peal+inns !22_S	et	f	\N
207012	pealinns	?pealinns =linns  (SgN  >pea+linns !22_S	et	f	\N
207023	astoriast	?astoriast =astoria  (SgEl  >astoria !01_S	et	f	\N
207024	astoriast	?astoriast =astorias  (SgP  >astorias !11_S	et	f	\N
207032	tramiga	?tramiga =trami  (SgKom  >trami !17_S	et	f	\N
207045	perekkonnanimi	?perekkonnanimi =perekkonnanimi  (SgG  >perekkonnanim !02_A	et	f	\N
207055	helerohelised	helerohelised =rohelise  (PlN  >hele+roheline !12_A	et	f	\N
207056	helerohelised	"hele+roheline %rohe  )LINE_aA  <hele+rohe ;16_S	et	f	\N
207070	proffesionaalid	?proffesionaalid =proffesionaali  (PlN  >proffesionaali !16_S	et	f	\N
207071	proffesionaalid	?proffesionaalid =proffesionaali  (PlN  >proffesionaal !22_S	et	f	\N
207072	proffesionaalid	?proffesionaalid =proffesionaali  (IndPrSg2  >proffesionaalima !28_V	et	f	\N
207082	eluloo	eluloo =loo  (SgG  >elu+lugu !18_S	et	f	\N
207083	eluloo	eluloo =loo  (SgG  >elu+loog !22_S	et	f	\N
207084	eluloo	eluloo =loo  (SgG  >elu+lood !22_S	et	f	\N
207140	elmise	?elmise =elmise  (SgG  >elmine !10_A	et	f	\N
207141	elmise	?elmise =elmise  (IndPrPs_  >elmisema !27_V	et	f	\N
207142	elmise	?elmise =elmise  (ImpPrSg2  >elmisema !27_V	et	f	\N
207149	lõppetades	?lõppetades =lõppeta  (Ger  >lõppetama !27_V	et	f	\N
207150	lõppetades	?lõppetades =eta  (PlIn  >lõpp+eta !16_S	et	f	\N
207157	disainega	### disainega	et	f	\N
207160	pikkal	?pikkal =pikkal  (SgN  >pikkal !02_S	et	f	\N
207169	gügo	?gügo =gügo  (SgN  >gügo !17~16_S	et	f	\N
207170	gügo	?gügo =gügo  (SgG  >gügo !17~16_S	et	f	\N
207171	gügo	?gügo =gügo  (SgP  >gügo !17_S	et	f	\N
206727	kelgutavad	"kelgutav %kelguta  )V_vA  <kelgutama ;27_V	et	f	\N
206728	kelgutavad	kelgutavad =tava  (PlN  >kelgu+tava !17_S	et	f	\N
206729	käsitöödrahvakunsti	?käsitöödrahvakunsti =käsitöödrahvakunsti  (IndPrPs_  >käsitöödrahvakunstima !28_V	et	f	\N
206730	käsitöödrahvakunsti	?käsitöödrahvakunsti =käsitöödrahvakunsti  (ImpPrSg2  >käsitöödrahvakunstima !28_V	et	f	\N
206732	raachermannln	### raachermannln	et	f	\N
206733	schwibbögenlichterbögen	?schwibbögenlichterbögen =schwibbögenlichterbögen  (SgN  >schwibbögenlichterbögen !19_S	et	f	\N
206739	thalheim	?thalheim =thalheim  (SgN  >thalheim !02_A	et	f	\N
206742	raamatumüüja	raamatumüüja =müüja  (SgN  >raamatu+müüja !01_S	et	f	\N
206743	raamatumüüja	raamatumüüja =müüja  (SgG  >raamatu+müüja !01_S	et	f	\N
206770	kohvikutes	kohvikutes =kohviku  (PlIn  >kohvik !02_S	et	f	\N
206771	kohvikutes	kohvikutes =ute  (SgIn  >kohvik+utt !22_S	et	f	\N
206772	kohvikutes	kohvikutes =ute  (PlIn  >kohvik+utt !22_S	et	f	\N
206784	sõitaaga	?sõitaaga =sõitaa  (SgKom  >sõitaa !26_S	et	f	\N
206785	sõitaaga	?sõitaaga =sõitaaga  (SgN  >sõitaaga !16_S	et	f	\N
206786	sõitaaga	?sõitaaga =sõitaaga  (SgG  >sõitaaga !16_S	et	f	\N
206796	gabinbr	?gabinbr =gabinbr  (SgN  >gabinbr !22_S	et	f	\N
206820	kadestavad	kadestavad =kadesta  (IndPrPl3  >kadestama !27_V	et	f	\N
206821	kadestavad	kadestavad =kadestava  (PlN  >kadestav !02_A	et	f	\N
206822	kadestavad	"kadestav %kadesta  )V_vA  <kadestama ;27_V	et	f	\N
206828	tõenäoline	tõenäoline =näoline  (SgN  >tõe+näoline !12?10_A	et	f	\N
206829	tõenäoline	"tõe+näoline %näo  )LINE_aA  <tõe+nägu ;18_S	et	f	\N
206870	vahur	?vahur =vahur  (SgN  >vahur !02_S	et	f	\N
206877	aegas	?aegas =aega  (IndIpfSg3  >aegama !29_V	et	f	\N
206878	aegas	?aegas =aegas  (SgN  >aegas !07_S	et	f	\N
206907	palatsi	?palatsi =palatsi  (ID  >palatsi !41_D	et	f	\N
206908	palatsi	?palatsi =palatsi  (SgG  >palats !02_S	et	f	\N
206909	palatsi	?palatsi =palatsi  (IndPrPs_  >palatsima !28_V	et	f	\N
206910	palatsi	?palatsi =palatsi  (ImpPrSg2  >palatsima !28_V	et	f	\N
206915	põeg	?põeg =põeg  (SgN  >põeg !22_S	et	f	\N
206927	autojust	?autojust =autoju  (SgEl  >autoju !01_S	et	f	\N
206928	autojust	?autojust =autojus  (SgP  >autojus !11_S	et	f	\N
206929	autojust	?autojust =toju  (SgEl  >au+toju !17_S	et	f	\N
206930	autojust	?autojust =tojus  (SgP  >au+tojus !09_S	et	f	\N
206983	budaös	?budaös =budaös  (SgN  >budaös !22_S	et	f	\N
206999	seinä	### seinä	et	f	\N
207003	vaig	?vaig =vaig  (SgN  >vaig !22_S	et	f	\N
207025	blaha	?blaha =blaha  (SgN  >blaha !17_S	et	f	\N
207026	blaha	?blaha =blaha  (SgG  >blaha !17_S	et	f	\N
207027	blaha	?blaha =blaha  (SgP  >blaha !17_S	et	f	\N
207028	blaha	?blaha =blaha  (IndPrPs_  >blahama !27_V	et	f	\N
207029	blaha	?blaha =blaha  (ImpPrSg2  >blahama !27_V	et	f	\N
207033	kesta	kesta =kest  (Inf  >kestma !34_V	et	f	\N
207034	kesta	kesta =kesta  (SgG  >kest !22_S	et	f	\N
207035	kesta	kesta =kesta  (SgP  >kest !22_S	et	f	\N
207036	kesta	kesta =kesta  (SgAdt  >kest !22_S	et	f	\N
207037	kesta	kesta =kesta  (IndPrPs_  >kestama !29_V	et	f	\N
207038	kesta	kesta =kesta  (IndPrPs_  >kestma !34_V	et	f	\N
207039	kesta	kesta =kesta  (ImpPrSg2  >kestama !29_V	et	f	\N
207040	kesta	kesta =kesta  (ImpPrSg2  >kestma !34_V	et	f	\N
207044	jalakse	?jalakse =jalakse  (SgG  >jalakne !02_A	et	f	\N
207098	signalizatsiooni	?signalizatsiooni =signalizatsioo  (SgTer  >signalizatsioo !26_S	et	f	\N
207099	signalizatsiooni	?signalizatsiooni =signalizatsiooni  (SgN  >signalizatsiooni !16_S	et	f	\N
207100	signalizatsiooni	?signalizatsiooni =signalizatsiooni  (SgG  >signalizatsiooni !16_S	et	f	\N
207101	signalizatsiooni	?signalizatsiooni =signalizatsiooni  (SgG  >signalizatsioon !22_S	et	f	\N
207102	signalizatsiooni	?signalizatsiooni =signalizatsiooni  (SgP  >signalizatsioon !22_S	et	f	\N
207103	signalizatsiooni	?signalizatsiooni =signalizatsiooni  (SgAdt  >signalizatsioon !22_S	et	f	\N
207104	signalizatsiooni	?signalizatsiooni =signalizatsiooni  (IndPrPs_  >signalizatsioonima !28_V	et	f	\N
207105	signalizatsiooni	?signalizatsiooni =signalizatsiooni  (ImpPrSg2  >signalizatsioonima !28_V	et	f	\N
207123	kopsud	kopsud =kopsu  (PlN  >kops !22_S	et	f	\N
207124	kopsud	kopsud =kopsu  (IndPrSg2  >kopsuma !28_V	et	f	\N
207129	veresoonetele	?veresoonetele =veresoonete  (PlAll  >veresoonett !22_S	et	f	\N
207130	veresoonetele	?veresoonetele =veresoonetele  (IndPrPs_  >veresoonetelema !36_V	et	f	\N
207131	veresoonetele	?veresoonetele =veresoonetele  (ImpPrSg2  >veresoonetelema !36_V	et	f	\N
207132	veresoonetele	?veresoonetele =nete  (PlAll  >vere+soo+nett !22_AS	et	f	\N
207133	veresoonetele	?veresoonetele =soonete  (PlAll  >vere+soonett !22_S	et	f	\N
207151	era-lennukidest	?era-lennukidest =lennukides  (SgP  >era-lennukidene !12_A	et	f	\N
207152	era-lennukidest	?era-lennukidest =kide  (SgEl  >era-lennu+kide !16_S	et	f	\N
207153	era-lennukidest	?era-lennukidest =kides  (SgP  >era-lennu+kides !09_S	et	f	\N
207154	era-lennukidest	?era-lennukidest =kides  (SgP  >era-lennu+kidene !10_A	et	f	\N
207173	turustamine	turustamine =turustamine  (SgN  >turustamine !12_S	et	f	\N
207174	turustamine	"turustamine %turusta  )MINE_vS  <turustama ;27_V	et	f	\N
207178	riskid	riskid =riski  (PlN  >risk !22_S	et	f	\N
207179	riskid	riskid =riski  (IndPrSg2  >riskima !28_V	et	f	\N
206993	taaskas	?taaskas =taaska  (IndIpfSg3  >taaskama !29_V	et	f	\N
206994	taaskas	?taaskas =taaskas  (SgN  >taaskas !07_S	et	f	\N
207006	töödavad	?töödavad =tööda  (IndPrPl3  >töödama !29_V	et	f	\N
207007	töödavad	?töödavad =töödava  (PlN  >töödava !01_S	et	f	\N
207008	töödavad	?töödavad =töödava  (PlN  >töödav !02_A	et	f	\N
207009	töödavad	?töödavad =dava  (PlN  >töö+dava !17_S	et	f	\N
207046	igatseva	igatseva =igatseva  (SgG  >igatsev !02_A	et	f	\N
207047	igatseva	"igatsev %igatse  )V_vA  <igatsema ;27_V	et	f	\N
207048	suusahüppet	?suusahüppet =hüppe  (SgP  >suusa+hüppe !06_S	et	f	\N
207073	intervjueerija	intervjueerija =intervjueerija  (SgN  >intervjueerija !01_S	et	f	\N
207074	intervjueerija	"intervjueerija %intervjueeri  )JA_vS  <intervjueerima ;28_V	et	f	\N
207075	intervjueerija	intervjueerija =intervjueerija  (SgG  >intervjueerija !01_S	et	f	\N
207076	raikka	?raikka =raikka  (SgN  >raikka !01_S	et	f	\N
207077	raikka	?raikka =raikka  (SgG  >raikka !01_S	et	f	\N
207078	raikka	?raikka =raikka  (IndPrPs_  >raikkama !29_V	et	f	\N
207079	raikka	?raikka =raikka  (ImpPrSg2  >raikkama !29_V	et	f	\N
207089	käskivad	käskivad =käskiva  (PlN  >käskiv !02_A	et	f	\N
207090	käskivad	"käskiv %käski  )V_vA  <käskima ;28_V	et	f	\N
207091	käskivad	käskivad =iva  (PlN  >käsk+iva !17_S	et	f	\N
207110	jaanalinnul	jaanalinnul =linnu  (SgAd  >jaana+lind !22_S	et	f	\N
207111	jaanalinnul	jaanalinnul =linnu  (PlAd  >jaana+linn !22_S	et	f	\N
207118	valutavad	valutavad =valuta  (IndPrPl3  >valutama !27_V	et	f	\N
207119	valutavad	valutavad =valutava  (PlN  >valutav !02_A	et	f	\N
207120	valutavad	"valutav %valu  )TAV_vAS  <valuma ;27_V	et	f	\N
207121	valutavad	"valutav %valuta  )V_vA  <valutama ;27_V	et	f	\N
207122	valutavad	valutavad =tava  (PlN  >valu+tava !17_S	et	f	\N
207187	kasulikuid	?kasulikuid =kasulikui  (PlN  >kasulikui !26_S	et	f	\N
207189	kasulikuid	?kasulikuid =kasulikui  (SgP  >kasulikui !26_S	et	f	\N
207190	kasulikuid	?kasulikuid =uliku  (PlP  >kas+uliku !01_S	et	f	\N
207191	kasulikuid	?kasulikuid =uliku  (PlP  >kas+ulik !02_S	et	f	\N
207192	kasulikuid	?kasulikuid =ulikui  (PlN  >kas+ulikui !26_S	et	f	\N
207193	kasulikuid	?kasulikuid =ulikui  (SgP  >kas+ulikui !26_S	et	f	\N
207199	jutta	jutta =jutta  (SgP  >jutt !22_S	et	f	\N
207200	jutta	jutta =jutta  (SgAdt  >jutt !22_S	et	f	\N
207210	plussi	plussi =plussi  (SgG  >pluss !22_S	et	f	\N
207211	plussi	plussi =plussi  (SgP  >pluss !22_S	et	f	\N
207212	plussi	plussi =plussi  (SgAdt  >pluss !22_S	et	f	\N
207243	heitgaasiga	heitgaasiga =iga  (SgN  >heit+gaas+iga !18_S	et	f	\N
207244	heitgaasiga	heitgaasiga =iga  (SgP  >heit+gaas+iga !18_S	et	f	\N
207245	heitgaasiga	heitgaasiga =gaasi  (SgKom  >heit+gaas !22_S	et	f	\N
207247	jäätmede	?jäätmede =mede  (SgN  >jäät+mede !16_S	et	f	\N
207248	jäätmede	?jäätmede =mede  (SgG  >jäät+mede !16_S	et	f	\N
207282	olgina	?olgina =olgi  (SgEs  >olk !22_S	et	f	\N
207290	tualetti-	tualetti- =tualetti  (SgP  >tualett !22_S	et	f	\N
207291	tualetti-	tualetti- =tualetti  (SgAdt  >tualett !22_S	et	f	\N
207299	trümoo	trümoo =trümoo  (SgN  >trümoo !26_S	et	f	\N
207300	trümoo	trümoo =trümoo  (SgG  >trümoo !26_S	et	f	\N
207305	õmblumasin	?õmblumasin =õmblumasin  (SgN  >õmblumasin !19_S	et	f	\N
207313	riide-	riide- =riide  (SgG  >riie !06_S	et	f	\N
207314	riide-	riide- =riide  (PlP  >riid !22_S	et	f	\N
207317	rohelisekirju	rohelisekirju =kirju  (SgN  >rohelise+kirju !01_A	et	f	\N
207318	rohelisekirju	rohelisekirju =kirju  (SgN  >rohelise+kirju !16_A	et	f	\N
207319	rohelisekirju	rohelisekirju =kirju  (SgG  >rohelise+kirju !01_A	et	f	\N
207320	rohelisekirju	rohelisekirju =kirju  (SgG  >rohelise+kirju !16_A	et	f	\N
207321	rohelisekirju	rohelisekirju =kirju  (PlP  >rohelise+kiri !24_S	et	f	\N
207326	tõmbukapi	?tõmbukapi =tõmbukapi  (SgG  >tõmbukapp !22_S	et	f	\N
207327	tõmbukapi	?tõmbukapi =tõmbukapi  (IndPrPs_  >tõmbukappima !28_V	et	f	\N
207328	tõmbukapi	?tõmbukapi =tõmbukapi  (ImpPrSg2  >tõmbukappima !28_V	et	f	\N
207329	tõmbukapi	?tõmbukapi =ukapi  (SgN  >tõmb+ukapi !01_S	et	f	\N
207330	tõmbukapi	?tõmbukapi =ukapi  (SgG  >tõmb+ukapi !01_S	et	f	\N
207331	tõmbukapi	?tõmbukapi =ukapi  (SgG  >tõmb+ukap !02_S	et	f	\N
207332	tõmbukapi	?tõmbukapi =ukapi  (SgG  >tõmb+ukapp !22_S	et	f	\N
207341	köögilaud	köögilaud =lau  (PlN  >köögi+laug !22_SA	et	f	\N
207342	köögilaud	köögilaud =laud  (SgN  >köögi+laud !22_S	et	f	\N
207357	riiulidel	?riiulidel =lide  (SgAd  >riiu+lide !16_S	et	f	\N
207358	riiulidel	?riiulidel =lidel  (SgN  >riiu+lidel !02_S	et	f	\N
207368	kirjustuslaual	?kirjustuslaual =kirjustuslaua  (SgAd  >kirjustuslaua !01_S	et	f	\N
207369	kirjustuslaual	?kirjustuslaual =kirjustuslaual  (SgN  >kirjustuslaual !19_S	et	f	\N
207379	tooliga	tooliga =tooli  (SgKom  >tool !22_S	et	f	\N
207380	tooliga	tooliga =liga  (SgN  >too+liga !17_S	et	f	\N
207381	tooliga	tooliga =liga  (SgG  >too+liga !17_S	et	f	\N
207382	tooliga	tooliga =liga  (SgP  >too+liga !17_S	et	f	\N
207385	suhrutoos	?suhrutoos =suhrutoo  (SgIn  >suhrutoo !26_S	et	f	\N
207386	suhrutoos	?suhrutoos =suhrutoos  (SgN  >suhrutoos !22_S	et	f	\N
207409	mööblikombinat	?mööblikombinat =binat  (SgN  >mööbli+kom+binat !02_S	et	f	\N
207017	nyugati	?nyugati =nyuga  (IndIpfIps  >nyukama !29_V	et	f	\N
207018	nyugati	?nyugati =nyugati  (ID  >nyugati !41_D	et	f	\N
207019	nyugati	?nyugati =nyugati  (SgG  >nyugat !02_S	et	f	\N
207020	nyugati	?nyugati =nyugati  (SgG  >nyugatt !22_S	et	f	\N
207021	nyugati	?nyugati =nyugati  (IndPrPs_  >nyugattima !28_V	et	f	\N
207022	nyugati	?nyugati =nyugati  (ImpPrSg2  >nyugattima !28_V	et	f	\N
207030	lujza	?lujza =lujza  (SgN  >lujza !16_S	et	f	\N
207031	lujza	?lujza =lujza  (SgG  >lujza !16_S	et	f	\N
207041	fesenciek-jaama	fesenciek-jaama =jaama  (SgG  >fesenciek-jaam !22_S	et	f	\N
207042	fesenciek-jaama	fesenciek-jaama =jaama  (SgP  >fesenciek-jaam !22_S	et	f	\N
207043	fesenciek-jaama	fesenciek-jaama =jaama  (SgAdt  >fesenciek-jaam !22_S	et	f	\N
207057	helerohelinen	?helerohelinen =helerohelinen  (SgN  >helerohelinen !19_S	et	f	\N
207058	helerohelinen	?helerohelinen =linen  (SgN  >hele+rohe+linen !02_S	et	f	\N
207059	helerohelinen	?helerohelinen =rohelinen  (SgN  >hele+rohelinen !19_S	et	f	\N
207064	kaardin	?kaardin =kaardi  (IndPrSg1  >kaartima !28_V	et	f	\N
207065	kaardin	?kaardin =kaardin  (SgN  >kaardin !02_S	et	f	\N
207068	proovid	proovid =proovi  (PlN  >proov !22_S	et	f	\N
207069	proovid	proovid =proovi  (IndPrSg2  >proovima !28_V	et	f	\N
207080	konkretselt	?konkretselt =konkretse  (SgAbl  >konkretne !02_A	et	f	\N
207081	konkretselt	?konkretselt =konkretselt  (ID  >konkretselt !41_D	et	f	\N
207085	tööintervjueerija	tööintervjueerija =intervjueerija  (SgN  >töö+intervjueerija !01_S	et	f	\N
207086	tööintervjueerija	tööintervjueerija =intervjueerija  (SgG  >töö+intervjueerija !01_S	et	f	\N
207087	idiaalne	?idiaalne =idiaalne  (SgN  >idiaalne !02_A	et	f	\N
207088	idiaalne	?idiaalne =idiaalne  (PlP  >idiaaln !22_S	et	f	\N
207092	korgkoolis	?korgkoolis =korgkooli  (SgIn  >korgkooli !16_S	et	f	\N
207093	korgkoolis	?korgkoolis =korgkooli  (SgIn  >korgkool !22_S	et	f	\N
207094	korgkoolis	?korgkoolis =korgkooli  (IndIpfSg3  >korgkoolima !28_V	et	f	\N
207095	korgkoolis	?korgkoolis =korgkoolis  (SgN  >korgkoolis !09_S	et	f	\N
207096	langemise	langemise =langemise  (SgG  >langemine !12_S	et	f	\N
207097	langemise	"langemine %lange  )MINE_vS  <langema ;27_V	et	f	\N
207106	remondita	remondita =remondi  (SgAb  >remont !22_S	et	f	\N
207107	remondita	remondita =remondi  (IndPrIps_  >remontima !28_V	et	f	\N
207108	kere	kere =kere  (SgN  >kere !16_S	et	f	\N
207109	kere	kere =kere  (SgG  >kere !16_S	et	f	\N
207114	täisverelist	täisverelist =verelis  (SgP  >täis+vereline !12_A	et	f	\N
207115	täisverelist	"täis+vereline %vere  )LINE_aA  <täis+veri ;20_S	et	f	\N
207127	kasjalik	?kasjalik =kasjalik  (SgN  >kasjalik !25_A	et	f	\N
207128	kasjalik	?kasjalik =jalik  (SgN  >kas+jalik !02_S	et	f	\N
207134	säästatud	?säästatud =säästa  (PtsPtIps  >säästama !27_V	et	f	\N
207135	säästatud	?säästatud =säästatu  (PlN  >säästatu !01_S	et	f	\N
207136	säästatud	?säästatud =säästatu  (IndPrSg2  >säästatuma !27_V	et	f	\N
207137	säästatud	?säästatud =säästatud  (ID  >säästatud !41_A	et	f	\N
207143	praagu	?praagu =praagu  (SgN  >praagu !16_S	et	f	\N
207144	praagu	?praagu =praagu  (SgG  >praagu !16_S	et	f	\N
207145	praagu	?praagu =praagu  (IndPrPs_  >praaguma !27_V	et	f	\N
207146	praagu	?praagu =praagu  (IndPrPs_  >praakuma !28_V	et	f	\N
207147	praagu	?praagu =praagu  (ImpPrSg2  >praaguma !27_V	et	f	\N
207148	praagu	?praagu =praagu  (ImpPrSg2  >praakuma !28_V	et	f	\N
207158	rejsijad	?rejsijad =rejsija  (PlN  >rejsija !01_S	et	f	\N
207159	rejsijad	?rejsijad =rejsija  (PlN  >rejsijas !02_A	et	f	\N
207161	interned	### interned	et	f	\N
207172	laptopimonitorilt	?laptopimonitorilt =laptopimonitori  (SgAbl  >laptopimonitor !02_S	et	f	\N
207175	partneriga	partneriga =partneri  (SgKom  >partner !02_S	et	f	\N
207176	partneriga	partneriga =iga  (SgN  >partner+iga !18_S	et	f	\N
207177	partneriga	partneriga =iga  (SgP  >partner+iga !18_S	et	f	\N
207195	põhibr	?põhibr =põhibr  (SgN  >põhibr !22_S	et	f	\N
207209	sky	### sky	et	f	\N
207213	suvepidu	suvepidu =pidu  (SgN  >suve+pidu !17_S	et	f	\N
207214	suvepidu	suvepidu =pidu  (SgN  >suve+pidu !18_S	et	f	\N
207215	suvepidu	suvepidu =pidu  (SgG  >suve+pidu !17_S	et	f	\N
207216	suvepidu	suvepidu =pidu  (SgP  >suve+pidu !17_S	et	f	\N
207217	suvepidu	suvepidu =pidu  (SgP  >suve+pidu !18_S	et	f	\N
207246	euuropas	?euuropas =euuropa  (SgIn  >euuropa !16_S	et	f	\N
207254	manguvaljak	### manguvaljak	et	f	\N
207255	apteekid	?apteekid =apteeki  (PlN  >apteeki !16_S	et	f	\N
207258	lux	### lux	et	f	\N
207302	bokalid	?bokalid =bokali  (PlN  >bokal !02_S	et	f	\N
207303	õmblumasina	?õmblumasina =õmblumasina  (SgG  >õmblumasin !19_S	et	f	\N
207304	õmblumasina	?õmblumasina =õmblumasina  (SgP  >õmblumasin !19_S	et	f	\N
207306	õmblumasina	?õmblumasina =õmblumasina  (SgAdt  >õmblumasin !19_S	et	f	\N
207324	tõmbukapp	?tõmbukapp =tõmbukapp  (SgN  >tõmbukapp !22_S	et	f	\N
207325	tõmbukapp	?tõmbukapp =ukapp  (SgN  >tõmb+ukapp !22_S	et	f	\N
207347	busipeatus	?busipeatus =busipeatu  (SgIn  >busipeatu !01_A	et	f	\N
207348	busipeatus	?busipeatus =busipeatu  (IndIpfSg3  >busipeatuma !27_V	et	f	\N
207349	busipeatus	?busipeatus =busipeatus  (SgN  >busipeatus !11~09_S	et	f	\N
207362	divani	?divani =diva  (SgTer  >diva !17_S	et	f	\N
207049	käsipalli	käsipalli =palli  (SgG  >käsi+pall !22_S	et	f	\N
207050	käsipalli	käsipalli =palli  (SgP  >käsi+pall !22_S	et	f	\N
207051	käsipalli	käsipalli =palli  (SgAdt  >käsi+pall !22_S	et	f	\N
207052	majassa	?majassa =majassa  (SgN  >majassa !01_S	et	f	\N
207053	majassa	?majassa =majassa  (SgG  >majassa !01_S	et	f	\N
207054	esimel	?esimel =esimel  (SgN  >esimel !19_S	et	f	\N
207060	kirjutuslaudda	?kirjutuslaudda =kirjutuslaudda  (SgN  >kirjutuslaudda !16_S	et	f	\N
207061	kirjutuslaudda	?kirjutuslaudda =kirjutuslaudda  (SgG  >kirjutuslaudda !16_S	et	f	\N
207062	kirjutuslaudda	?kirjutuslaudda =laudda  (SgN  >kirjutus+laudda !01_S	et	f	\N
207063	kirjutuslaudda	?kirjutuslaudda =laudda  (SgG  >kirjutus+laudda !01_S	et	f	\N
207066	märkmikud	märkmikud =märkmiku  (PlN  >märkmik !25_S	et	f	\N
207067	märkmikud	märkmikud =miku  (PlN  >märk+mikk !22_S	et	f	\N
207112	koon	koon =koo  (IndPrSg1  >kuduma !28_V	et	f	\N
207113	koon	koon =koon  (SgN  >koon !22_S	et	f	\N
207116	alkoholisõltuvust	alkoholisõltuvust =sõltuvus  (SgP  >alkoholi+sõltuvus !11_S	et	f	\N
207117	alkoholisõltuvust	"alkoholi+sõltuvus %sõltuva  )US_aS  <alkoholi+sõltuv ;02_A	et	f	\N
207125	jood	jood =joo  (IndPrSg2  >jooma !38_V	et	f	\N
207126	jood	jood =jood  (SgN  >jood !22_S	et	f	\N
207138	järgid	järgid =järgi  (PlN  >järk !22_S	et	f	\N
207139	järgid	järgid =järgi  (IndPrSg2  >järgima !27_V	et	f	\N
207155	tsharter-lennikitega	?tsharter-lennikitega =lenniki  (PlKom  >tsharter-lenniki !01_S	et	f	\N
207156	tsharter-lennikitega	?tsharter-lennikitega =lenniki  (PlKom  >tsharter-lennik !02_S	et	f	\N
207162	jalast	jalast =jala  (SgEl  >jalg !22_S	et	f	\N
207163	jalast	jalast =jalas  (SgP  >jalas !09_S	et	f	\N
207164	jalast	jalast =jalas  (SgP  >jalane !10_A	et	f	\N
207165	jalast	"jalane %jala  )NE_aA  <jalg ;22_S	et	f	\N
207166	jalast	jalast =jalast  (ID  >jalast !41_D	et	f	\N
207167	pushkin	?pushkin =pushki  (IndPrSg1  >pushkima !28_V	et	f	\N
207168	pushkin	?pushkin =pushkin  (SgN  >pushkin !02_S	et	f	\N
207196	milelga	?milelga =milelga  (SgN  >milelga !01_S	et	f	\N
207197	milelga	?milelga =milelga  (SgG  >milelga !01_S	et	f	\N
207198	milelga	?milelga =milelga  (SgG  >milelgas !02_S	et	f	\N
207207	tähtusjärje	?tähtusjärje =usjärje  (SgN  >täht+usjärje !16_S	et	f	\N
207208	tähtusjärje	?tähtusjärje =usjärje  (SgG  >täht+usjärje !16_S	et	f	\N
207218	karaoke	?karaoke =karaoke  (SgN  >karaoke !12?10_S	et	f	\N
207219	karaoke	?karaoke =karaoke  (PlP  >karaok !22_S	et	f	\N
207225	tantsijatele	tantsijatele =tantsija  (PlAll  >tantsija !01_S	et	f	\N
207227	tantsijatele	"tantsija %tantsi  )JA_vS  <tantsima ;28_V	et	f	\N
207233	karnevalist	karnevalist =karnevali  (SgEl  >karneval !19_S	et	f	\N
207234	karnevalist	karnevalist =karnevalis  (SgP  >karnevaline !12_A	et	f	\N
207235	karnevalist	"karnevaline %karnevali  )NE_aA  <karneval ;19_S	et	f	\N
207260	vannitua	?vannitua =vannitua  (SgN  >vannitua !01_S	et	f	\N
207261	vannitua	?vannitua =vannitua  (SgG  >vannitua !01_S	et	f	\N
207262	vannitua	?vannitua =tua  (SgN  >vanni+tua !26_S	et	f	\N
207263	vannitua	?vannitua =tua  (SgG  >vanni+tua !26_S	et	f	\N
207264	telerilaud	telerilaud =lau  (PlN  >teleri+laug !22_SA	et	f	\N
207265	telerilaud	telerilaud =laud  (SgN  >teleri+laud !22_S	et	f	\N
207266	tikikot	?tikikot =tikiko  (SgP  >tikiko !16_S	et	f	\N
207274	toidunõded	?toidunõded =nõde  (PlN  >toidu+nõde !16_S	et	f	\N
207278	alustassd	?alustassd =tassd  (SgN  >alus+tassd !22_S	et	f	\N
207279	alustassd	?alustassd =stassd  (SgN  >alu+stassd !22_S	et	f	\N
207283	neljakorruselises	neljakorruselises =korruselise  (SgIn  >nelja+korruseline !12_A	et	f	\N
207284	neljakorruselises	"nelja+korruseline %korruse  )LINE_aA  <nelja+korrus ;09_S	et	f	\N
207285	rahvamaja	rahvamaja =maja  (SgN  >rahva+maja !17_S	et	f	\N
207286	rahvamaja	rahvamaja =maja  (SgG  >rahva+maja !17_S	et	f	\N
207287	rahvamaja	rahvamaja =maja  (SgP  >rahva+maja !17_S	et	f	\N
207295	käteratikud	?käteratikud =käteratiku  (PlN  >käteratik !02_S	et	f	\N
207296	käteratikud	?käteratikud =käteratiku  (IndPrSg2  >käteratikuma !27_V	et	f	\N
207297	käteratikud	?käteratikud =ratiku  (PlN  >käte+ratiku !01_S	et	f	\N
207298	käteratikud	?käteratikud =ratiku  (PlN  >käte+ratik !02_S	et	f	\N
207301	sektsioonikapp	?sektsioonikapp =sektsioonikapp  (SgN  >sektsioonikapp !22_S	et	f	\N
207307	õmblemasinast	?õmblemasinast =õmblemasina  (SgEl  >õmblemasin !19_S	et	f	\N
207308	õmblemasinast	?õmblemasinast =õmblemasinas  (SgP  >õmblemasinane !12_A	et	f	\N
207309	peegeline	peegeline =peegeline  (SgN  >peegeline !12_A	et	f	\N
207310	peegeline	"peegeline %peegeli  )NE_aA  <peegel ;02_S	et	f	\N
207311	peegeline	peegeline =ine  (SgN  >peegel+ine !16_S	et	f	\N
207312	peegeline	peegeline =ine  (SgG  >peegel+ine !16_S	et	f	\N
207337	sool	sool =soo  (SgAd  >sugu !18_S	et	f	\N
207338	sool	sool =soo  (SgAd  >soo !26_S	et	f	\N
207339	sool	sool =sool  (SgN  >sool !13_S	et	f	\N
207340	sool	sool =sool  (SgN  >sool !22_S	et	f	\N
207352	seksionkapp	?seksionkapp =seksionkapp  (SgN  >seksionkapp !22_S	et	f	\N
207353	seksionkapp	?seksionkapp =onkapp  (SgN  >seksi+onkapp !22_S	et	f	\N
207354	seksionkapp	?seksionkapp =ionkapp  (SgN  >seks+ionkapp !22_S	et	f	\N
207403	liumaed	?liumaed =liumae  (PlN  >liumae !26_S	et	f	\N
207180	100-aastaseks	-aastaseks =aastase  (SgTr  >-aastane !12~10_A	et	f	\N
207181	100-aastaseks	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
207182	100-aastaseks	-aastaseks =seks  (SgN  >-aasta+seks !22_S	et	f	\N
207202	mitmme	?mitmme =mitmme  (SgN  >mitmme !06_S	et	f	\N
207203	mitmme	?mitmme =mitmme  (SgG  >mitmme !06_S	et	f	\N
207204	mitmme	?mitmme =mitmme  (PlP  >mitmm !22_S	et	f	\N
207205	mitmme	?mitmme =mitmme  (IndPrPs_  >mitmmema !27_V	et	f	\N
207206	mitmme	?mitmme =mitmme  (ImpPrSg2  >mitmmema !27_V	et	f	\N
207230	esinejate	esinejate =esineja  (PlG  >esineja !01_S	et	f	\N
207231	esinejate	"esineja %esine  )JA_vS  <esinema ;27_V	et	f	\N
207251	patarei	patarei =patarei  (SgN  >patarei !26_S	et	f	\N
207252	patarei	patarei =patarei  (SgG  >patarei !26_S	et	f	\N
207256	soidutee	?soidutee =soidutee  (SgN  >soidutee !26_S	et	f	\N
207257	soidutee	?soidutee =soidutee  (SgG  >soidutee !26_S	et	f	\N
207259	trepikod	?trepikod =trepiko  (PlN  >trepiko !16_S	et	f	\N
207267	pruunikirju	pruunikirju =kirju  (SgN  >pruuni+kirju !01_A	et	f	\N
207268	pruunikirju	pruunikirju =kirju  (SgN  >pruuni+kirju !16_A	et	f	\N
207269	pruunikirju	pruunikirju =kirju  (SgG  >pruuni+kirju !01_A	et	f	\N
207270	pruunikirju	pruunikirju =kirju  (SgG  >pruuni+kirju !16_A	et	f	\N
207271	pruunikirju	pruunikirju =kirju  (PlP  >pruuni+kiri !24_S	et	f	\N
207275	kanusid	?kanusid =kanu  (PlP  >kanu !17_S	et	f	\N
207276	kanusid	?kanusid =kanu  (IndIpfSg2  >kanuma !27_V	et	f	\N
207277	kanusid	?kanusid =kanu  (IndIpfPl3  >kanuma !27_V	et	f	\N
207288	aiad	aiad =aia  (PlN  >aed !22_S	et	f	\N
207289	aiad	aiad =aia  (PlN  >ai !22_S	et	f	\N
207315	lastevoodi	lastevoodi =voodi  (SgN  >laste+voodi !01_S	et	f	\N
207316	lastevoodi	lastevoodi =voodi  (SgG  >laste+voodi !01_S	et	f	\N
207322	elektripliiti	elektripliiti =pliiti  (SgP  >elektri+pliit !22_S	et	f	\N
207323	elektripliiti	elektripliiti =pliiti  (SgAdt  >elektri+pliit !22_S	et	f	\N
207333	arstirohud	arstirohud =rohu  (PlN  >arsti+roht !22_S	et	f	\N
207334	arstirohud	arstirohud =rohu  (PlN  >arsti+rohi !24_S	et	f	\N
207346	pestavtapeetiga	?pestavtapeetiga =pestavtapeeti  (SgKom  >pestavtapeeti !16_S	et	f	\N
207387	pestavtapeega	?pestavtapeega =pestavtapee  (SgKom  >pestavtapee !26_S	et	f	\N
207388	pestavtapeega	?pestavtapeega =pestavtapeega  (SgN  >pestavtapeega !16_S	et	f	\N
207389	pestavtapeega	?pestavtapeega =pestavtapeega  (SgG  >pestavtapeega !16_S	et	f	\N
207426	purkes	?purkes =purke  (SgIn  >purge !06_S	et	f	\N
207427	purkes	?purkes =purke  (IndIpfSg3  >purkema !27_V	et	f	\N
207428	purkes	?purkes =purkes  (SgN  >purkes !09_S	et	f	\N
207442	tualet	?tualet =tuale  (SgP  >tuale !06_S	et	f	\N
207447	pasta	pasta =pasta  (SgN  >pasta !16_S	et	f	\N
207448	pasta	pasta =pasta  (SgG  >pasta !16_S	et	f	\N
207457	tomatipasta	tomatipasta =pasta  (SgN  >tomati+pasta !16_S	et	f	\N
207458	tomatipasta	tomatipasta =pasta  (SgG  >tomati+pasta !16_S	et	f	\N
207460	viinamari	viinamari =mari  (SgN  >viina+mari !17~16_S	et	f	\N
207461	viinamari	viinamari =mari  (SgN  >viina+mari !24_S	et	f	\N
207462	viinamari	viinamari =mari  (SgG  >viina+mari !17~16_S	et	f	\N
207463	viinamari	viinamari =mari  (SgP  >viina+mari !17_S	et	f	\N
207475	dessertluusikad	?dessertluusikad =dessertluusika  (PlN  >dessertluusika !01_S	et	f	\N
207476	dessertluusikad	?dessertluusikad =dessertluusika  (PlN  >dessertluusikas !02_A	et	f	\N
207477	pliitis	?pliitis =pliit  (IndIpfSg3  >pliitma !34_V	et	f	\N
207478	pliitis	?pliitis =pliiti  (IndIpfSg3  >pliitima !28_V	et	f	\N
207479	pliitis	?pliitis =pliitis  (SgN  >pliitis !11~09_S	et	f	\N
207483	maitsestatud	maitsestatud =maitsesta  (PtsPtIps  >maitsestama !27_V	et	f	\N
207484	maitsestatud	maitsestatud =maitsestatu  (PlN  >maitsestatu !01_S	et	f	\N
207485	maitsestatud	"maitsestatu %maitsesta  )TU1_vS  <maitsestama ;27_V	et	f	\N
207486	maitsestatud	maitsestatud =maitsestatud  (ID  >maitsestatud !41_A	et	f	\N
207487	maitsestatud	"maitsestatud %maitsesta  )TUD_vA  <maitsestama ;27_V	et	f	\N
207526	ovalne	?ovalne =ovalne  (SgN  >ovalne !02_A	et	f	\N
207527	ovalne	?ovalne =ovalne  (PlP  >ovaln !22_S	et	f	\N
207538	telleririiulil	?telleririiulil =telleririiuli  (SgAd  >telleririiuli !16_S	et	f	\N
207539	telleririiulil	?telleririiulil =telleririiuli  (SgAd  >telleririiul !19_S	et	f	\N
207540	telleririiulil	?telleririiulil =telleririiulil  (SgN  >telleririiulil !02_S	et	f	\N
207547	panni	panni =panni  (SgG  >pann !22_S	et	f	\N
207548	panni	panni =panni  (SgP  >pann !22_S	et	f	\N
207549	panni	panni =panni  (SgAdt  >pann !22_S	et	f	\N
207556	sahtle	?sahtle =sahtle  (SgN  >sahtle !06_S	et	f	\N
207557	sahtle	?sahtle =sahtle  (SgG  >sahtle !06_S	et	f	\N
207558	sahtle	?sahtle =sahtle  (IndPrPs_  >sahtlema !30_V	et	f	\N
207559	sahtle	?sahtle =sahtle  (ImpPrSg2  >sahtlema !30_V	et	f	\N
207567	viiekorrulised	?viiekorrulised =viiekorrulise  (PlN  >viiekorruline !12_A	et	f	\N
207568	viiekorrulised	?viiekorrulised =korrulise  (PlN  >viie+korruline !12_A	et	f	\N
207569	säästu	säästu =säästu  (SgG  >sääst !22_S	et	f	\N
207570	säästu	säästu =säästu  (SgP  >sääst !22_S	et	f	\N
207571	säästu	säästu =säästu  (SgAdt  >sääst !22_S	et	f	\N
207576	bussipeatused	bussipeatused =peatuse  (PlN  >bussi+peatus !11~09_S	et	f	\N
207183	toidulisaid	?toidulisaid =toidulisai  (PlN  >toidulisai !26_S	et	f	\N
207184	toidulisaid	?toidulisaid =toidulisai  (SgP  >toidulisai !26_S	et	f	\N
207185	toidulisaid	?toidulisaid =lisai  (PlN  >toidu+lisai !26_S	et	f	\N
207186	toidulisaid	?toidulisaid =lisai  (SgP  >toidu+lisai !26_S	et	f	\N
207188	toidulisaid	?toidulisaid =lisaid  (SgN  >toidu+lisaid !22_S	et	f	\N
207194	jäib	?jäib =jäib  (SgN  >jäib !22_S	et	f	\N
207201	sõitame	?sõitame =sõita  (IndPrPl1  >sõitama !27_V	et	f	\N
207220	vahupidu	vahupidu =pidu  (SgN  >vahu+pidu !17_S	et	f	\N
207221	vahupidu	vahupidu =pidu  (SgN  >vahu+pidu !18_S	et	f	\N
207222	vahupidu	vahupidu =pidu  (SgG  >vahu+pidu !17_S	et	f	\N
207223	vahupidu	vahupidu =pidu  (SgP  >vahu+pidu !17_S	et	f	\N
207224	vahupidu	vahupidu =pidu  (SgP  >vahu+pidu !18_S	et	f	\N
207226	tantsurõõmu	tantsurõõmu =rõõmu  (SgG  >tantsu+rõõm !22_S	et	f	\N
207228	tantsurõõmu	tantsurõõmu =rõõmu  (SgP  >tantsu+rõõm !22_S	et	f	\N
207229	tantsurõõmu	tantsurõõmu =rõõmu  (SgAdt  >tantsu+rõõm !22_S	et	f	\N
207232	valifestivalil	?valifestivalil =valifestivali  (SgAd  >valifestival !19_S	et	f	\N
207236	üleeuroopalise	?üleeuroopalise =üleeuroopalise  (SgG  >üleeuroopaline !12_A	et	f	\N
207237	üleeuroopalise	?üleeuroopalise =opalise  (SgG  >üle+euro+opaline !12_A	et	f	\N
207238	ravimise	ravimise =ravimise  (SgG  >ravimine !12_S	et	f	\N
207239	ravimise	"ravimine %ravi  )MINE_vS  <ravima ;27_V	et	f	\N
207240	ravimise	"ravimine %ravimi  )NE_aA  <ravim ;02_S	et	f	\N
207241	saastaks	saastaks =saasta  (SgTr  >saast !22_S	et	f	\N
207242	saastaks	saastaks =saasta  (KndPrPs  >saastama !29~27_V	et	f	\N
207249	paigaldakse	?paigaldakse =paigaldakse  (SgG  >paigaldakne !02_A	et	f	\N
207250	paigaldakse	?paigaldakse =galdakse  (SgG  >pai+galdakne !02_A	et	f	\N
207253	üheksakoruseles	?üheksakoruseles =korusele  (PlIn  >üheksa+korusel !19_S	et	f	\N
207272	esemene	?esemene =esemene  (SgN  >esemene !12_A	et	f	\N
207273	esemene	?esemene =esemene  (PlP  >esemen !19_S	et	f	\N
207280	vaivara	?vaivara =vaivara  (SgN  >vaivara !01_S	et	f	\N
207281	vaivara	?vaivara =vaivara  (SgG  >vaivara !01_S	et	f	\N
207292	läbikäidav	läbikäidav =käi  (PtsPrIps  >läbi+_käima !38_V	et	f	\N
207293	läbikäidav	läbikäidav =käidav  (SgN  >läbi+käidav !02_A	et	f	\N
207294	korterivõitmed	?korterivõitmed =võitme  (PlN  >korteri+võitme !06_S	et	f	\N
207335	dessertlusikad	?dessertlusikad =dessertlusika  (PlN  >dessertlusika !01_S	et	f	\N
207336	dessertlusikad	?dessertlusikad =dessertlusika  (PlN  >dessertlusikas !02_A	et	f	\N
207343	lambikega	?lambikega =kega  (SgN  >lambi+kega !17_S	et	f	\N
207344	lambikega	?lambikega =kega  (SgG  >lambi+kega !17_S	et	f	\N
207345	lambikega	?lambikega =kega  (SgP  >lambi+kega !17_S	et	f	\N
207350	töötuba	töötuba =tuba  (SgN  >töö+tuba !18_S	et	f	\N
207351	töötuba	töötuba =tuba  (SgP  >töö+tuba !18_S	et	f	\N
207355	sektsionkappis	?sektsionkappis =sektsionkappi  (IndIpfSg3  >sektsionkappima !28_V	et	f	\N
207356	sektsionkappis	?sektsionkappis =sektsionkappis  (SgN  >sektsionkappis !09_S	et	f	\N
207359	sektsionkapi	?sektsionkapi =sektsionkapi  (SgG  >sektsionkapp !22_S	et	f	\N
207360	sektsionkapi	?sektsionkapi =sektsionkapi  (IndPrPs_  >sektsionkappima !28_V	et	f	\N
207361	sektsionkapi	?sektsionkapi =sektsionkapi  (ImpPrSg2  >sektsionkappima !28_V	et	f	\N
207364	sektsionkapp	?sektsionkapp =sektsionkapp  (SgN  >sektsionkapp !22_S	et	f	\N
207377	peegali	?peegali =peegali  (ID  >peegali !41_D	et	f	\N
207378	peegali	?peegali =peegali  (SgG  >peegal !02_S	et	f	\N
207390	tabureti	tabureti =tabureti  (SgG  >taburet !22_S	et	f	\N
207391	tabureti	tabureti =tabureti  (SgP  >taburet !22_S	et	f	\N
207392	tabureti	tabureti =tabureti  (SgAdt  >taburet !22_S	et	f	\N
207393	telefonimaksu	telefonimaksu =maksu  (SgG  >telefoni+maks !22_S	et	f	\N
207394	telefonimaksu	telefonimaksu =maksu  (SgP  >telefoni+maks !22_S	et	f	\N
207395	telefonimaksu	telefonimaksu =maksu  (SgAdt  >telefoni+maks !22_S	et	f	\N
207396	telefonimaksu	telefonimaksu =maksu  (PlP  >telefoni+maks !22_S	et	f	\N
207397	ühetoalisess	?ühetoalisess =ühetoalisess  (SgN  >ühetoalisess !22_S	et	f	\N
207398	ühetoalisess	?ühetoalisess =toalisess  (SgN  >ühe+toalisess !22_S	et	f	\N
207401	keeldriruum	?keeldriruum =keeldriruum  (SgN  >keeldriruum !22_S	et	f	\N
207402	keeldriruum	?keeldriruum =driruum  (SgN  >keel+driruum !22_S	et	f	\N
207410	maxima	### maxima	et	f	\N
207416	tapeetiga	?tapeetiga =tapeeti  (SgKom  >tapeeti !16_S	et	f	\N
207419	vaiksevõtu	?vaiksevõtu =vaiksevõtu  (IndPrPs_  >vaiksevõtuma !27_V	et	f	\N
207420	vaiksevõtu	?vaiksevõtu =vaiksevõtu  (ImpPrSg2  >vaiksevõtuma !27_V	et	f	\N
207421	vaiksevõtu	?vaiksevõtu =sevõtu  (SgN  >vaik+sevõtu !01_S	et	f	\N
207422	vaiksevõtu	?vaiksevõtu =sevõtu  (SgG  >vaik+sevõtu !01_S	et	f	\N
207423	tangudiga	?tangudiga =tangudi  (SgKom  >tangudi !01_S	et	f	\N
207429	herkulo	herkulo =herkulo  (SgN  >herkulo !01_S	et	f	\N
207430	herkulo	herkulo =herkulo  (SgG  >herkulo !01_S	et	f	\N
207436	üldmaitseaine	üldmaitseaine =aine  (SgN  >üld+maitse+aine !06_S	et	f	\N
207437	üldmaitseaine	üldmaitseaine =aine  (SgG  >üld+maitse+aine !06_S	et	f	\N
207438	üldmaitseaine	üldmaitseaine =aine  (PlP  >üld+maitse+ain !22_S	et	f	\N
207451	ribi	ribi =ribi  (SgN  >ribi !17_S	et	f	\N
207452	ribi	ribi =ribi  (SgG  >ribi !17_S	et	f	\N
207363	divani	?divani =divani  (SgG  >divan !02_S	et	f	\N
207365	kirjustuslaud	?kirjustuslaud =kirjustuslau  (PlN  >kirjustuslau !26_S	et	f	\N
207366	kirjustuslaud	?kirjustuslaud =kirjustuslau  (SgP  >kirjustuslau !26_S	et	f	\N
207367	kirjustuslaud	?kirjustuslaud =kirjustuslaud  (SgN  >kirjustuslaud !22_S	et	f	\N
207370	külgkardinaid	?külgkardinaid =külgkardinai  (PlN  >külgkardinai !26_S	et	f	\N
207371	külgkardinaid	?külgkardinaid =külgkardinai  (SgP  >külgkardinai !26_S	et	f	\N
207372	külgkardinaid	?külgkardinaid =nai  (PlN  >külg+kardi+nai !26_S	et	f	\N
207373	külgkardinaid	?külgkardinaid =nai  (SgP  >külg+kardi+nai !26_S	et	f	\N
207374	külgkardinaid	?külgkardinaid =naid  (SgN  >külg+kardi+naid !22_S	et	f	\N
207375	külgkardinaid	?külgkardinaid =kardinai  (PlN  >külg+kardinai !26_S	et	f	\N
207376	külgkardinaid	?külgkardinaid =kardinai  (SgP  >külg+kardinai !26_S	et	f	\N
207383	köögikappis	?köögikappis =köögikappi  (IndIpfSg3  >köögikappima !28_V	et	f	\N
207384	köögikappis	?köögikappis =köögikappis  (SgN  >köögikappis !09_S	et	f	\N
207399	keeldriruum	?keeldriruum =keeldriruum  (SgN  >keeldriruum !22_S	et	f	\N
207400	keeldriruum	?keeldriruum =driruum  (SgN  >keel+driruum !22_S	et	f	\N
207412	nurgadiivani	nurgadiivani =diiva  (SgTer  >nurga+diiva !16_S	et	f	\N
207413	nurgadiivani	nurgadiivani =diivani  (SgG  >nurga+diivan !02_S	et	f	\N
207417	lülletan	?lülletan =lülleta  (IndPrSg1  >lülletama !27_V	et	f	\N
207418	lülletan	?lülletan =lülletan  (SgN  >lülletan !19_S	et	f	\N
207431	manna	manna =manna  (SgN  >manna !16_S	et	f	\N
207432	manna	manna =manna  (SgG  >manna !16_S	et	f	\N
207446	tualetit	### tualetit	et	f	\N
207469	eletrivahvli	?eletrivahvli =eletrivahvli  (SgG  >eletrivahvel !02_S	et	f	\N
207470	eletrivahvli	?eletrivahvli =eletrivahvli  (IndPrPs_  >eletrivahvlima !28_V	et	f	\N
207471	eletrivahvli	?eletrivahvli =eletrivahvli  (ImpPrSg2  >eletrivahvlima !28_V	et	f	\N
207472	taevassinine	?taevassinine =taevassinine  (SgN  >taevassinine !12_A	et	f	\N
207473	taevassinine	?taevassinine =taevassinine  (PlP  >taevassinin !19_S	et	f	\N
207474	taevassinine	?taevassinine =sinine  (SgN  >taevas+sinine !10_AS	et	f	\N
207481	võileibad	?võileibad =võileiba  (PlN  >võileiba !01_S	et	f	\N
207482	võileibad	?võileibad =leiba  (PlN  >või+leiba !16_S	et	f	\N
207491	äädikas	äädikas =äädika  (SgIn  >äädikas !02_S	et	f	\N
207492	äädikas	äädikas =äädikas  (SgN  >äädikas !02_S	et	f	\N
207499	tammepuud	tammepuud =puu  (PlN  >tamme+puu !26_S	et	f	\N
207500	tammepuud	tammepuud =puu  (SgP  >tamme+puu !26_S	et	f	\N
207501	tammepuud	tammepuud =puud  (SgN  >tamme+puud !22_S	et	f	\N
207505	pärnapuud	pärnapuud =puu  (PlN  >pärna+puu !26_S	et	f	\N
207506	pärnapuud	pärnapuud =puu  (SgP  >pärna+puu !26_S	et	f	\N
207507	pärnapuud	pärnapuud =puud  (SgN  >pärna+puud !22_S	et	f	\N
207508	viiekorruselised	viiekorruselised =korruselise  (PlN  >viie+korruseline !12_A	et	f	\N
207509	viiekorruselised	"viie+korruseline %korruse  )LINE_aA  <viie+korrus ;09_S	et	f	\N
207510	orion	?orion =orion  (SgN  >orion !19_S	et	f	\N
207511	puuukseid	?puuukseid =puuukse  (PlP  >puuukne !02_A	et	f	\N
207512	puuukseid	?puuukseid =puuuksei  (PlN  >puuuksei !26_S	et	f	\N
207513	puuukseid	?puuukseid =puuuksei  (SgP  >puuuksei !26_S	et	f	\N
207514	puuukseid	?puuukseid =ukse  (PlP  >puu+ukne !02_A	et	f	\N
207515	puuukseid	?puuukseid =ukse  (PlP  >puu+ukse !06_S	et	f	\N
207516	puuukseid	?puuukseid =uksei  (PlN  >puu+uksei !26_S	et	f	\N
207517	puuukseid	?puuukseid =uksei  (SgP  >puu+uksei !26_S	et	f	\N
207518	puuukseid	?puuukseid =ukseid  (SgN  >puu+ukseid !22_S	et	f	\N
207524	riidekappi	riidekappi =kappi  (SgP  >riide+kapp !22_S	et	f	\N
207525	riidekappi	riidekappi =kappi  (SgAdt  >riide+kapp !22_S	et	f	\N
207533	rulikardin	?rulikardin =rulikardi  (IndPrSg1  >rulikartima !28_V	et	f	\N
207534	rulikardin	?rulikardin =rulikardin  (SgN  >rulikardin !02_S	et	f	\N
207541	gaasipliitis	?gaasipliitis =gaasipliiti  (SgIn  >gaasipliiti !16_S	et	f	\N
207542	gaasipliitis	?gaasipliitis =gaasipliiti  (IndIpfSg3  >gaasipliitima !28_V	et	f	\N
207543	gaasipliitis	?gaasipliitis =gaasipliitis  (SgN  >gaasipliitis !09_S	et	f	\N
207544	gaasipliitis	?gaasipliitis =pliitis  (SgN  >gaasi+pliitis !11~09_S	et	f	\N
207545	gaasipliitis	?gaasipliitis =ipliiti  (SgIn  >gaas+ipliiti !16_S	et	f	\N
207546	gaasipliitis	?gaasipliitis =ipliitis  (SgN  >gaas+ipliitis !11_S	et	f	\N
207560	niitnuutlid	?niitnuutlid =niitnuutli  (PlN  >niitnuutli !01_S	et	f	\N
207561	niitnuutlid	?niitnuutlid =niitnuutli  (IndPrSg2  >niitnuutlima !28_V	et	f	\N
207562	niitnuutlid	?niitnuutlid =nuutli  (PlN  >niit+nuutel !02_S	et	f	\N
207563	niitnuutlid	?niitnuutlid =tnuutli  (PlN  >nii+tnuutel !02_S	et	f	\N
207572	statoil	?statoil =statoi  (SgAd  >statoi !26_S	et	f	\N
207573	statoil	?statoil =statoil  (SgN  >statoil !22_S	et	f	\N
207578	trepikodas	?trepikodas =kodas  (SgN  >trepi+kodas !07_S	et	f	\N
207583	kassetid	kassetid =kasseti  (PlN  >kassett !22_S	et	f	\N
207584	kassetid	kassetid =seti  (PlN  >kas+sett !22_S	et	f	\N
207606	köögisessioonkapp	?köögisessioonkapp =köögisessioonkapp  (SgN  >köögisessioonkapp !22_S	et	f	\N
207607	köögisessioonkapp	?köögisessioonkapp =sessioonkapp  (SgN  >köögi+sessioonkapp !22_S	et	f	\N
207624	servantis	?servantis =servanti  (SgIn  >servanti !01_S	et	f	\N
207404	liumaed	?liumaed =liumae  (SgP  >liumae !26_S	et	f	\N
207405	liumaed	?liumaed =liumaed  (SgN  >liumaed !22_S	et	f	\N
207406	liumaed	?liumaed =mae  (PlN  >liu+mae !26_S	et	f	\N
207407	liumaed	?liumaed =mae  (SgP  >liu+mae !26_S	et	f	\N
207408	liumaed	?liumaed =maed  (SgN  >liu+maed !22_S	et	f	\N
207411	soldina	?soldina =soldi  (SgEs  >solt !22_S	et	f	\N
207443	mõturi	?mõturi =mõturi  (SgN  >mõturi !01_S	et	f	\N
207444	mõturi	?mõturi =mõturi  (SgG  >mõturi !01_S	et	f	\N
207445	mõturi	?mõturi =mõturi  (SgG  >mõtur !02_S	et	f	\N
207449	tüülkardin	?tüülkardin =tüülkardi  (IndPrSg1  >tüülkartima !28_V	et	f	\N
207450	tüülkardin	?tüülkardin =tüülkardin  (SgN  >tüülkardin !19_S	et	f	\N
207454	majoneesi	majoneesi =majoneesi  (SgG  >majonees !22_S	et	f	\N
207455	majoneesi	majoneesi =majoneesi  (SgP  >majonees !22_S	et	f	\N
207456	majoneesi	majoneesi =majoneesi  (SgAdt  >majonees !22_S	et	f	\N
207459	mandarinid	?mandarinid =mandarini  (PlN  >mandarin !19_S	et	f	\N
207488	vanilliinsuhkur	?vanilliinsuhkur =vanilliinsuhkur  (SgN  >vanilliinsuhkur !02_S	et	f	\N
207493	pizzajahu	pizzajahu =jahu  (SgN  >pizza+jahu !17_S	et	f	\N
207494	pizzajahu	pizzajahu =jahu  (SgG  >pizza+jahu !17_S	et	f	\N
207495	pizzajahu	pizzajahu =jahu  (SgP  >pizza+jahu !17_S	et	f	\N
207496	y2k	### y2k	et	f	\N
207502	pihlapuud	pihlapuud =puu  (PlN  >pihla+puu !26_S	et	f	\N
207503	pihlapuud	pihlapuud =puu  (SgP  >pihla+puu !26_S	et	f	\N
207504	pihlapuud	pihlapuud =puud  (SgN  >pihla+puud !22_S	et	f	\N
207519	esikas	?esikas =esika  (SgIn  >esika !01_S	et	f	\N
207520	esikas	?esikas =esika  (SgIn  >esikas !02_S	et	f	\N
207521	esikas	?esikas =esikas  (SgN  >esikas !02_S	et	f	\N
207530	priinter	?priinter =priinter  (SgN  >priinter !02_S	et	f	\N
207531	taevasinine	taevasinine =inine  (SgN  >taevas+inine !10_A	et	f	\N
207532	taevasinine	"taevas+inine %ini  )NE_aA  <taevas+ini ;17_S	et	f	\N
207536	sektsionkapis	?sektsionkapis =sektsionkapi  (SgIn  >sektsionkapp !22_S	et	f	\N
207537	sektsionkapis	?sektsionkapis =sektsionkapis  (SgN  >sektsionkapis !09_S	et	f	\N
207574	donalds	?donalds =donalds  (SgN  >donalds !22_S	et	f	\N
207579	tutre	?tutre =tutre  (SgN  >tutre !06_S	et	f	\N
207580	tutre	?tutre =tutre  (SgG  >tudre !06_S	et	f	\N
207581	tutre	?tutre =tutre  (IndPrPs_  >tutrema !27_V	et	f	\N
207582	tutre	?tutre =tutre  (ImpPrSg2  >tutrema !27_V	et	f	\N
207592	fikus	?fikus =fiku  (SgIn  >fiku !16_S	et	f	\N
207593	fikus	?fikus =fiku  (SgIn  >fikk !22_S	et	f	\N
207594	fikus	?fikus =fiku  (IndIpfSg3  >fikuma !27_V	et	f	\N
207595	fikus	?fikus =fikus  (SgN  >fikus !09_S	et	f	\N
207598	riidenagi	riidenagi =nagi  (SgN  >riide+nagi !17_S	et	f	\N
207599	riidenagi	riidenagi =nagi  (SgG  >riide+nagi !17_S	et	f	\N
207600	riidenagi	riidenagi =nagi  (SgP  >riide+nagi !17_S	et	f	\N
207601	riidenagi	riidenagi =riide  (SgEs^  >riie !06_S	et	f	\N
207602	tombekapp	?tombekapp =tombekapp  (SgN  >tombekapp !22_S	et	f	\N
207619	voodide	?voodide =voodi  (PlG  >vood !22_S	et	f	\N
207620	voodide	?voodide =dide  (SgN  >voo+dide !16_S	et	f	\N
207621	voodide	?voodide =dide  (SgG  >voo+dide !16_S	et	f	\N
207636	kompjuter	?kompjuter =kompjuter  (SgN  >kompjuter !19_S	et	f	\N
207651	seb	### seb	et	f	\N
207668	elutoauksest	elutoauksest =ukse  (SgEl  >elu+toa+uks !14_S	et	f	\N
207669	elutoauksest	elutoauksest =ukses  (SgP  >elu+toa+uksene !10_A	et	f	\N
207670	elutoauksest	"elu+toa+uksene %ukse  )NE_aA  <elu+toa+uks ;14_S	et	f	\N
207684	riiulist	riiulist =riiuli  (SgEl  >riiul !02_S	et	f	\N
207685	riiulist	riiulist =riiulis  (SgP  >riiuline !12_A	et	f	\N
207686	riiulist	"riiuline %riiu  )LINE_aA  <riid ;22_S	et	f	\N
207687	riiulist	"riiuline %riiuli  )NE_aA  <riiul ;02_S	et	f	\N
207689	piirilinnas	piirilinnas =linna  (SgIn  >piiri+linn !22_S	et	f	\N
207690	piirilinnas	piirilinnas =linnas  (SgN  >piiri+linnas !09_S	et	f	\N
207700	jalatside	?jalatside =tside  (SgN  >jala+tside !16_S	et	f	\N
207701	jalatside	?jalatside =tside  (SgG  >jala+tside !16_S	et	f	\N
207730	kellad	kellad =kella  (PlN  >kell !22_S	et	f	\N
207731	kellad	kellad =kella  (IndPrSg2  >kellama !29_V	et	f	\N
207746	kirjelauale	?kirjelauale =kirjelaua  (SgAll  >kirjelaua !01_S	et	f	\N
207748	kirjelauale	?kirjelauale =kirjelauale  (PlP  >kirjelaual !19_S	et	f	\N
207755	ummargene	?ummargene =ummargene  (SgN  >ummargene !12_A	et	f	\N
207756	ummargene	?ummargene =ummargene  (PlP  >ummargen !19_S	et	f	\N
207765	salatud	salatud =sala  (PtsPtIps  >salgama !29_V	et	f	\N
207766	salatud	salatud =salatu  (PlN  >salatu !01_AS	et	f	\N
207767	salatud	"salatu %sala  )TU1_vS  <salgama ;29_V	et	f	\N
207768	salatud	"salatu %sala  )TU2_kA  <sala ;17_S	et	f	\N
207769	salatud	salatud =salatud  (ID  >salatud !41_A	et	f	\N
207770	salatud	"salatud %sala  )TUD_vA  <salgama ;29_V	et	f	\N
207773	kefir	?kefir =kefir  (SgN  >kefir !02_S	et	f	\N
207776	köödikombain	?köödikombain =köödikombain  (SgN  >köödikombain !19_S	et	f	\N
207778	gaasiplitil	?gaasiplitil =gaasipliti  (SgAd  >gaasiplitt !22_S	et	f	\N
207779	gaasiplitil	?gaasiplitil =pliti  (SgAd  >gaasi+pliti !16_S	et	f	\N
207781	gaasiplitil	?gaasiplitil =pliti  (SgAd  >gaasi+plitt !22_S	et	f	\N
207414	tüüllkardin	?tüüllkardin =tüüllkardi  (IndPrSg1  >tüüllkartima !28_V	et	f	\N
207415	tüüllkardin	?tüüllkardin =tüüllkardin  (SgN  >tüüllkardin !19_S	et	f	\N
207424	purked	?purked =purke  (PlN  >purge !06_S	et	f	\N
207425	purked	?purked =purke  (IndPrSg2  >purkema !27_V	et	f	\N
207433	juurvilja	juurvilja =vilja  (SgG  >juur+vili !24_S	et	f	\N
207434	juurvilja	juurvilja =vilja  (SgP  >juur+vili !24_S	et	f	\N
207435	juurvilja	juurvilja =vilja  (SgAdt  >juur+vili !24_S	et	f	\N
207439	riipuvad	?riipuvad =riipu  (IndPrPl3  >riipuma !27_V	et	f	\N
207440	riipuvad	?riipuvad =riipuva  (PlN  >riipuva !01_S	et	f	\N
207441	riipuvad	?riipuvad =riipuva  (PlN  >riipuv !02_A	et	f	\N
207467	keksiga	keksiga =keksi  (SgKom  >keks !22_S	et	f	\N
207468	keksiga	keksiga =keksi  (SgKom  >keks !22_A	et	f	\N
207480	pliitit	?pliitit =pliitit  (SgN  >pliitit !02_S	et	f	\N
207490	kakaojuomajuhe	### kakaojuomajuhe	et	f	\N
207497	üheksakorruselise	üheksakorruselise =korruselise  (SgG  >üheksa+korruseline !12_A	et	f	\N
207498	üheksakorruselise	"üheksa+korruseline %korruse  )LINE_aA  <üheksa+korrus ;09_S	et	f	\N
207522	tütretuba	tütretuba =tuba  (SgN  >tütre+tuba !18_S	et	f	\N
207523	tütretuba	tütretuba =tuba  (SgP  >tütre+tuba !18_S	et	f	\N
207552	söögikapides	?söögikapides =kapi  (PlIn  >söögi+kapi !16_S	et	f	\N
207553	veesifilter	?veesifilter =veesifilter  (SgN  >veesifilter !02_S	et	f	\N
207554	veesifilter	?veesifilter =ifilter  (SgN  >vees+ifilter !02_S	et	f	\N
207555	veesifilter	?veesifilter =sifilter  (SgN  >vee+sifilter !02_S	et	f	\N
207575	mc	### mc	et	f	\N
207603	tombekapist	?tombekapist =tombekapi  (SgEl  >tombekapp !22_S	et	f	\N
207604	tombekapist	?tombekapist =tombekapis  (SgP  >tombekapis !09_S	et	f	\N
207605	tombekapist	?tombekapist =tombekapist  (SgN  >tombekapist !22_S	et	f	\N
207622	servant	?servant =servant  (SgN  >servant !22_S	et	f	\N
207627	servanti	?servanti =servanti  (SgN  >servanti !01_S	et	f	\N
207628	servanti	?servanti =servanti  (SgG  >servanti !01_S	et	f	\N
207629	servanti	?servanti =servanti  (SgP  >servant !22_S	et	f	\N
207630	servanti	?servanti =servanti  (SgAdt  >servant !22_S	et	f	\N
207634	kompjuterilaual	?kompjuterilaual =kompjuterilaua  (SgAd  >kompjuterilaua !01_S	et	f	\N
207635	kompjuterilaual	?kompjuterilaual =kompjuterilaual  (SgN  >kompjuterilaual !19_S	et	f	\N
207638	valguskülla	valguskülla =külla  (SgG  >valgus+küll !22_S	et	f	\N
207639	valguskülla	valguskülla =külla  (SgP  >valgus+küll !22_S	et	f	\N
207640	valguskülla	valguskülla =külla  (SgAdt  >valgus+küla !17_S	et	f	\N
207641	valguskülla	valguskülla =külla  (SgAdt  >valgus+küll !22_S	et	f	\N
207648	bensiinijaama	bensiinijaama =jaama  (SgG  >bensiini+jaam !22_S	et	f	\N
207649	bensiinijaama	bensiinijaama =jaama  (SgP  >bensiini+jaam !22_S	et	f	\N
207650	bensiinijaama	bensiinijaama =jaama  (SgAdt  >bensiini+jaam !22_S	et	f	\N
207652	sessekäigus	?sessekäigus =sessekäigu  (IndIpfSg3  >sessekäiguma !27_V	et	f	\N
207653	sessekäigus	?sessekäigus =sessekäigus  (SgN  >sessekäigus !11~09_S	et	f	\N
207654	välis	?välis =väli  (IndIpfSg3  >välima !27_V	et	f	\N
207655	välis	?välis =välis  (SgN  >välis !09_S	et	f	\N
207656	esukus	?esukus =esuku  (SgIn  >esuku !01_S	et	f	\N
207657	esukus	?esukus =esuku  (IndIpfSg3  >esukuma !27_V	et	f	\N
207658	esukus	?esukus =esukus  (SgN  >esukus !11_S	et	f	\N
207659	sarvedel	sarvedel =sarve  (PlAd  >sarv !22_S	et	f	\N
207660	sarvedel	sarvedel =ede  (SgAd  >sarv+ede !16_S	et	f	\N
207661	sarvedel	sarvedel =edel  (SgN  >sarv+edel !02_S	et	f	\N
207662	ahtelis	?ahtelis =ahteli  (SgIn  >ahtel !02_S	et	f	\N
207663	ahtelis	?ahtelis =ahtelis  (SgN  >ahtelis !11_S	et	f	\N
207667	riiutel	### riiutel	et	f	\N
207694	viiekoruselises	?viiekoruselises =viiekoruselise  (SgIn  >viiekoruseline !12_A	et	f	\N
207695	viiekoruselises	?viiekoruselises =koruselise  (SgIn  >viie+koruseline !12_A	et	f	\N
207708	arvitilaud	?arvitilaud =arvitilau  (PlN  >arvitilau !26_S	et	f	\N
207709	arvitilaud	?arvitilaud =arvitilau  (SgP  >arvitilau !26_S	et	f	\N
207710	arvitilaud	?arvitilaud =arvitilaud  (SgN  >arvitilaud !22_S	et	f	\N
207712	arvitilaud	?arvitilaud =itilau  (PlN  >arv+itilau !26_S	et	f	\N
207714	arvitilaud	?arvitilaud =itilau  (SgP  >arv+itilau !26_S	et	f	\N
207716	arvitilaud	?arvitilaud =itilaud  (SgN  >arv+itilaud !22_S	et	f	\N
207727	korbile	korbile =korbi  (SgAll  >korp !22_S	et	f	\N
207728	korbile	korbile =korbi  (PlAll  >korp !22_S	et	f	\N
207732	divvanvoodi	?divvanvoodi =divvanvoodi  (SgN  >divvanvoodi !16_S	et	f	\N
207733	divvanvoodi	?divvanvoodi =divvanvoodi  (SgG  >divvanvoodi !16_S	et	f	\N
207734	divvanvoodi	?divvanvoodi =divvanvoodi  (SgG  >divvanvoot !22_S	et	f	\N
207735	divvanvoodi	?divvanvoodi =divvanvoodi  (SgP  >divvanvood !22_S	et	f	\N
207736	divvanvoodi	?divvanvoodi =divvanvoodi  (SgAdt  >divvanvood !22_S	et	f	\N
207737	divvanvoodi	?divvanvoodi =divvanvoodi  (IndPrPs_  >divvanvootima !28_V	et	f	\N
207738	divvanvoodi	?divvanvoodi =divvanvoodi  (ImpPrSg2  >divvanvootima !28_V	et	f	\N
207747	kirjelaud	?kirjelaud =kirjelau  (PlN  >kirjelau !26_S	et	f	\N
207749	kirjelaud	?kirjelaud =kirjelau  (SgP  >kirjelau !26_S	et	f	\N
207750	kirjelaud	?kirjelaud =kirjelaud  (SgN  >kirjelaud !22_S	et	f	\N
207751	roos	roos =roo  (SgIn  >rood !22_S	et	f	\N
207752	roos	roos =roo  (SgIn  >roog !22_S	et	f	\N
207453	ribi	ribi =ribi  (SgP  >ribi !17_S	et	f	\N
207464	varenikut	### varenikut	et	f	\N
207465	lihatoiduanned	### lihatoiduanned	et	f	\N
207466	tortiga	### tortiga	et	f	\N
207489	tuhksuhkur	?tuhksuhkur =tuhksuhkur  (SgN  >tuhksuhkur !19_S	et	f	\N
207528	arvut	?arvut =arvu  (SgP  >arvu !16_S	et	f	\N
207529	arvut	?arvut =arvut  (SgN  >arvut !02_S	et	f	\N
207535	sektsionikapp	?sektsionikapp =sektsionikapp  (SgN  >sektsionikapp !22_S	et	f	\N
207550	gaasipliiti	gaasipliiti =pliiti  (SgP  >gaasi+pliit !22_S	et	f	\N
207551	gaasipliiti	gaasipliiti =pliiti  (SgAdt  >gaasi+pliit !22_S	et	f	\N
207564	ivanova	?ivanova =ivanova  (SgN  >ivanova !16_S	et	f	\N
207565	ivanova	?ivanova =ivanova  (SgG  >ivanov !02_A	et	f	\N
207566	ivanova	?ivanova =ivanova  (SgG  >ivanova !16_S	et	f	\N
207585	diski	?diski =diski  (SgN  >diski !16_S	et	f	\N
207586	diski	?diski =diski  (SgG  >diski !16_S	et	f	\N
207587	diski	?diski =diski  (SgG  >disk !22_S	et	f	\N
207588	diski	?diski =diski  (SgP  >disk !22_S	et	f	\N
207589	diski	?diski =diski  (SgAdt  >disk !22_S	et	f	\N
207590	diski	?diski =diski  (IndPrPs_  >diskima !28_V	et	f	\N
207591	diski	?diski =diski  (ImpPrSg2  >diskima !28_V	et	f	\N
207596	muusikariiul	muusikariiul =riiu  (SgAd  >muusika+riid !22_S	et	f	\N
207597	muusikariiul	muusikariiul =riiul  (SgN  >muusika+riiul !02_S	et	f	\N
207608	vesifiltr	?vesifiltr =filtr  (SgN  >vesi+filtr !22_S	et	f	\N
207609	pakid	pakid =paki  (PlN  >pakk !22_S	et	f	\N
207610	pakid	pakid =paki  (IndPrSg2  >pakkima !28_V	et	f	\N
207617	naabrine	naabrine =naabrine  (SgN  >naabrine !12~10_A	et	f	\N
207618	naabrine	"naabrine %naabri  )NE_aA  <naaber ;02_S	et	f	\N
207664	köögikappist	?köögikappist =köögikappis  (SgP  >köögikappis !09_S	et	f	\N
207665	köögikappist	?köögikappist =köögikappist  (SgN  >köögikappist !22_S	et	f	\N
207666	köögikappist	?köögikappist =kappist  (SgN  >köögi+kappist !22_S	et	f	\N
207691	erinavad	?erinavad =erinava  (PlN  >erinav !02_A	et	f	\N
207692	erinavad	?erinavad =erinava  (PlN  >erinava !16_S	et	f	\N
207693	erinavad	?erinavad =nava  (PlN  >eri+nava !17_S	et	f	\N
207711	arvutilauale	arvutilauale =ale  (SgN  >arvuti+lau+ale !16_S	et	f	\N
207713	arvutilauale	arvutilauale =ale  (SgG  >arvuti+lau+ale !16_S	et	f	\N
207715	arvutilauale	arvutilauale =laua  (SgAll  >arvuti+laud !22_S	et	f	\N
207721	arvitilauaga	?arvitilauaga =arvitilaua  (SgKom  >arvitilaua !01_S	et	f	\N
207722	arvitilauaga	?arvitilauaga =itilaua  (SgKom  >arv+itilaua !01_S	et	f	\N
207725	sektsioonikappis	?sektsioonikappis =sektsioonikappi  (IndIpfSg3  >sektsioonikappima !28_V	et	f	\N
207726	sektsioonikappis	?sektsioonikappis =sektsioonikappis  (SgN  >sektsioonikappis !09_S	et	f	\N
207729	põrendal	?põrendal =põrenda  (SgAd  >põrenda !01_S	et	f	\N
207739	diivanivoodi	?diivanivoodi =diivanivoodi  (SgN  >diivanivoodi !16_S	et	f	\N
207740	diivanivoodi	?diivanivoodi =diivanivoodi  (SgG  >diivanivoodi !16_S	et	f	\N
207741	diivanivoodi	?diivanivoodi =diivanivoodi  (SgG  >diivanivoot !22_S	et	f	\N
207742	diivanivoodi	?diivanivoodi =diivanivoodi  (SgP  >diivanivood !22_S	et	f	\N
207743	diivanivoodi	?diivanivoodi =diivanivoodi  (SgAdt  >diivanivood !22_S	et	f	\N
207744	diivanivoodi	?diivanivoodi =diivanivoodi  (IndPrPs_  >diivanivootima !28_V	et	f	\N
207745	diivanivoodi	?diivanivoodi =diivanivoodi  (ImpPrSg2  >diivanivootima !28_V	et	f	\N
207771	kohvikoor	kohvikoor =koor  (SgN  >kohvi+koor !13_S	et	f	\N
207772	kohvikoor	kohvikoor =koor  (SgN  >kohvi+koor !22_S	et	f	\N
207775	pannig	### pannig	et	f	\N
207793	teisis	teisis =teisi  (PlIn  >teine !12_OP	et	f	\N
207794	teisis	teisis =teisi  (PlIn  >teise !12_P	et	f	\N
207798	suhkrutoosi	suhkrutoosi =toosi  (SgG  >suhkru+toos !22_S	et	f	\N
207799	suhkrutoosi	suhkrutoosi =toosi  (SgP  >suhkru+toos !22_S	et	f	\N
207800	suhkrutoosi	suhkrutoosi =toosi  (SgAdt  >suhkru+toos !22_S	et	f	\N
207803	güümnaasiumis	?güümnaasiumis =güümnaasiumi  (SgIn  >güümnaasium !19~02_S	et	f	\N
207804	güümnaasiumis	?güümnaasiumis =güümnaasiumi  (SgIn  >güümnaasiumi !16_S	et	f	\N
207805	güümnaasiumis	?güümnaasiumis =güümnaasiumi  (IndIpfSg3  >güümnaasiumima !28_V	et	f	\N
207806	güümnaasiumis	?güümnaasiumis =güümnaasiumis  (SgN  >güümnaasiumis !09_S	et	f	\N
207860	kuursuse	?kuursuse =kuursuse  (SgG  >kuursus !11~09_S	et	f	\N
207892	süstemitehnika	?süstemitehnika =süstemitehnika  (SgN  >süstemitehnika !01_S	et	f	\N
207893	süstemitehnika	?süstemitehnika =süstemitehnika  (SgG  >süstemitehnika !01_S	et	f	\N
207894	süstemitehnika	?süstemitehnika =süstemitehnika  (SgG  >süstemitehnikas !02_A	et	f	\N
207914	kelel	?kelel =kele  (SgAd  >kele !16_S	et	f	\N
207915	kelel	?kelel =kelel  (SgN  >kelel !02_S	et	f	\N
207916	servisil	### servisil	et	f	\N
207918	õppimeene	?õppimeene =õppimeene  (SgN  >õppimeene !16_S	et	f	\N
207919	õppimeene	?õppimeene =õppimeene  (SgG  >õppimeene !16_S	et	f	\N
207920	õppimeene	?õppimeene =õppimeene  (PlP  >õppimeen !22_S	et	f	\N
207924	aastunud	?aastunud =aastu  (PtsPtPs  >aastuma !27_V	et	f	\N
207925	aastunud	?aastunud =aastunu  (PlN  >aastunu !01_S	et	f	\N
207926	aastunud	?aastunud =aastunu  (IndPrSg2  >aastunuma !27_V	et	f	\N
207927	aastunud	?aastunud =aastunud  (ID  >aastunud !41_A	et	f	\N
207928	aastunud	?aastunud =tunu  (PlN  >aas+tunu !17_S	et	f	\N
207577	bussipeatused	"bussi+peatus %pea  )TUS2_aS  <bussi+pea ;26_S	et	f	\N
207611	esikupõrandal	?esikupõrandal =esikupõranda  (SgAd  >esikupõranda !16_S	et	f	\N
207612	esikupõrandal	?esikupõrandal =esikupõrandal  (SgN  >esikupõrandal !02_S	et	f	\N
207613	esikupõrandal	?esikupõrandal =upõranda  (SgAd  >esik+upõranda !16_S	et	f	\N
207614	esikupõrandal	?esikupõrandal =upõrandal  (SgN  >esik+upõrandal !02_S	et	f	\N
207615	esikupõrandal	?esikupõrandal =kupõranda  (SgAd  >esi+kupõranda !16_S	et	f	\N
207616	esikupõrandal	?esikupõrandal =kupõrandal  (SgN  >esi+kupõrandal !02_S	et	f	\N
207623	servantil	?servantil =servanti  (SgAd  >servanti !01_S	et	f	\N
207645	kaetuvad	?kaetuvad =kaetu  (IndPrPl3  >kaetuma !27_V	et	f	\N
207646	kaetuvad	?kaetuvad =kaetuva  (PlN  >kaetuva !01_S	et	f	\N
207647	kaetuvad	?kaetuvad =kaetuva  (PlN  >kaetuv !02_A	et	f	\N
207671	nurgadivanist	?nurgadivanist =nurgadivani  (SgEl  >nurgadivan !19_S	et	f	\N
207672	nurgadivanist	?nurgadivanist =nurgadivanis  (SgP  >nurgadivanis !09_S	et	f	\N
207673	nurgadivanist	?nurgadivanist =nurgadivanist  (SgN  >nurgadivanist !22_S	et	f	\N
207674	nurgadivanist	?nurgadivanist =divani  (SgEl  >nurga+divan !02_S	et	f	\N
207675	nurgadivanist	?nurgadivanist =divanis  (SgP  >nurga+divanis !11_S	et	f	\N
207676	nurgadivanist	?nurgadivanist =divanist  (SgN  >nurga+divanist !22_S	et	f	\N
207677	beez	### beez	et	f	\N
207678	pesukorvi	pesukorvi =korvi  (SgG  >pesu+korv !22_S	et	f	\N
207679	pesukorvi	pesukorvi =korvi  (SgP  >pesu+korv !22_S	et	f	\N
207680	pesukorvi	pesukorvi =korvi  (SgAdt  >pesu+korv !22_S	et	f	\N
207683	sampunid	?sampunid =sampuni  (PlN  >sampun !02_S	et	f	\N
207696	põhjapolne	?põhjapolne =põhjapolne  (SgN  >põhjapolne !02_A	et	f	\N
207697	põhjapolne	?põhjapolne =põhjapolne  (PlP  >põhjapoln !22_S	et	f	\N
207698	põhjapolne	?põhjapolne =polne  (SgN  >põhja+polne !02_A	et	f	\N
207699	põhjapolne	?põhjapolne =polne  (PlP  >põhja+poln !22_S	et	f	\N
207704	vanitoas	?vanitoas =vanitoa  (SgIn  >vanitoa !26_S	et	f	\N
207705	vanitoas	?vanitoas =vanitoas  (SgN  >vanitoas !22_S	et	f	\N
207706	diivanilauale	?diivanilauale =diivanilaua  (SgAll  >diivanilaua !01_S	et	f	\N
207707	diivanilauale	?diivanilauale =diivanilauale  (PlP  >diivanilaual !19_S	et	f	\N
207723	krustal	?krustal =krusta  (SgAd  >krusta !16_S	et	f	\N
207724	krustal	?krustal =krustal  (SgN  >krustal !02_S	et	f	\N
207757	toases	?toases =toase  (SgIn  >toane !10_A	et	f	\N
207758	toases	?toases =toase  (SgIn  >toase !06_S	et	f	\N
207759	toases	?toases =toase  (PlIn  >toas !22_S	et	f	\N
207760	toases	?toases =toase  (IndIpfSg3  >toasema !28_V	et	f	\N
207761	toases	?toases =toases  (SgN  >toases !09_S	et	f	\N
207774	joogurt	?joogurt =joogurt  (SgN  >joogurt !22_S	et	f	\N
207786	püre	?püre =püre  (SgN  >püre !16_S	et	f	\N
207787	püre	?püre =püre  (SgG  >püre !16_S	et	f	\N
207788	püre	?püre =püre  (IndPrPs_  >pürema !27_V	et	f	\N
207789	püre	?püre =püre  (ImpPrSg2  >pürema !27_V	et	f	\N
207791	gaaspliiti	gaaspliiti =pliiti  (SgP  >gaas+pliit !22_S	et	f	\N
207792	gaaspliiti	gaaspliiti =pliiti  (SgAdt  >gaas+pliit !22_S	et	f	\N
207809	informatikat	?informatikat =informatika  (SgP  >informatika !01_S	et	f	\N
207810	informatikat	?informatikat =informatika  (SgP  >informatikas !02_A	et	f	\N
207818	infoormatika	?infoormatika =infoormatika  (SgN  >infoormatika !01_S	et	f	\N
207819	infoormatika	?infoormatika =infoormatika  (SgG  >infoormatika !01_S	et	f	\N
207820	infoormatika	?infoormatika =infoormatika  (SgG  >infoormatikas !02_A	et	f	\N
207821	infoormatika	?infoormatika =ormatika  (SgN  >info+ormatika !01_S	et	f	\N
207822	infoormatika	?infoormatika =ormatika  (SgG  >info+ormatika !01_S	et	f	\N
207823	infoormatika	?infoormatika =ormatika  (SgG  >info+ormatikas !02_A	et	f	\N
207851	misugune	?misugune =misugune  (SgN  >misugune !12_A	et	f	\N
207852	misugune	?misugune =misugune  (PlP  >misugun !19_S	et	f	\N
207853	misugune	?misugune =ugune  (SgN  >mis+ugune !10_A	et	f	\N
207861	tsiviili	tsiviili =tsiviili  (SgG  >tsiviil !22_S	et	f	\N
207862	tsiviili	tsiviili =tsiviili  (SgP  >tsiviil !22_S	et	f	\N
207863	tsiviili	tsiviili =tsiviili  (SgAdt  >tsiviil !22_S	et	f	\N
207864	ingeneeriks	?ingeneeriks =ingeneeri  (SgTr  >ingeneeri !16_S	et	f	\N
207865	ingeneeriks	?ingeneeriks =ingeneeri  (SgTr  >ingeneer !22_S	et	f	\N
207866	ingeneeriks	?ingeneeriks =ingeneeri  (KndPrPs  >ingeneerima !28_V	et	f	\N
207870	loendutelt	?loendutelt =loendu  (PlAbl  >loendu !01_S	et	f	\N
207871	loendutelt	?loendutelt =loendute  (PlAbl  >loendutt !22_S	et	f	\N
207872	loendutelt	?loendutelt =loendutelt  (ID  >loendutelt !41_D	et	f	\N
207880	viitele	viitele =vii  (PlAll  >viis !14_N	et	f	\N
207881	viitele	viitele =viite  (SgAll  >viide !06_S	et	f	\N
207897	kohustlik	?kohustlik =kohustlik  (SgN  >kohustlik !25_A	et	f	\N
207912	kvalitetsid	?kvalitetsid =kvalitetsi  (PlN  >kvalitets !22_S	et	f	\N
207913	kvalitetsid	?kvalitetsid =kvalitetsi  (IndPrSg2  >kvalitetsima !28_V	et	f	\N
207938	füsika	?füsika =füsika  (SgN  >füsika !01_S	et	f	\N
207939	füsika	?füsika =füsika  (SgG  >füsika !01_S	et	f	\N
207940	füsika	?füsika =füsika  (SgG  >füsikas !02_S	et	f	\N
207986	diaagnosija	?diaagnosija =diaagnosija  (SgN  >diaagnosija !01_S	et	f	\N
207987	diaagnosija	?diaagnosija =diaagnosija  (SgG  >diaagnosija !01_S	et	f	\N
207625	servantis	?servantis =servanti  (IndIpfSg3  >servantima !28_V	et	f	\N
207626	servantis	?servantis =servantis  (SgN  >servantis !11_S	et	f	\N
207631	kompjuterilaud	?kompjuterilaud =kompjuterilau  (PlN  >kompjuterilau !26_S	et	f	\N
207632	kompjuterilaud	?kompjuterilaud =kompjuterilau  (SgP  >kompjuterilau !26_S	et	f	\N
207633	kompjuterilaud	?kompjuterilaud =kompjuterilaud  (SgN  >kompjuterilaud !22_S	et	f	\N
207637	kompjuterilauda	### kompjuterilauda	et	f	\N
207642	elektripliites	?elektripliites =elektripliite  (SgIn  >elektripliite !16_S	et	f	\N
207643	elektripliites	?elektripliites =pliite  (SgIn  >elektri+pliide !06_S	et	f	\N
207644	elektripliites	?elektripliites =pliites  (SgN  >elektri+pliites !09_S	et	f	\N
207681	balsamid	?balsamid =balsami  (PlN  >balsami !01_S	et	f	\N
207682	balsamid	?balsamid =balsami  (PlN  >balsam !02_A	et	f	\N
207688	vabarrigis	?vabarrigis =vabarrigis  (SgN  >vabarrigis !09_S	et	f	\N
207702	vasamul	?vasamul =vasamu  (SgAd  >vasamu !01_S	et	f	\N
207703	vasamul	?vasamul =vasamul  (SgN  >vasamul !19_S	et	f	\N
207717	arvitilauale	?arvitilauale =arvitilaua  (SgAll  >arvitilaua !01_S	et	f	\N
207718	arvitilauale	?arvitilauale =arvitilauale  (PlP  >arvitilaual !19_S	et	f	\N
207719	arvitilauale	?arvitilauale =itilaua  (SgAll  >arv+itilaua !01_S	et	f	\N
207720	arvitilauale	?arvitilauale =itilauale  (PlP  >arv+itilaual !19_S	et	f	\N
207762	tualettis	?tualettis =tualetti  (SgIn  >tualetti !01_S	et	f	\N
207763	tualettis	?tualettis =tualetti  (IndIpfSg3  >tualettima !28_V	et	f	\N
207764	tualettis	?tualettis =tualettis  (SgN  >tualettis !11_S	et	f	\N
207777	gaasiplit	?gaasiplit =gaasipli  (SgP  >gaasipli !01_S	et	f	\N
207780	gaasiplit	?gaasiplit =gaasipli  (SgP  >gaasippel !02_S	et	f	\N
207782	gaasiplit	?gaasiplit =ipli  (SgP  >gaas+ippel !02_S	et	f	\N
207784	gaasiplit	?gaasiplit =iplit  (SgN  >gaas+iplit !02_S	et	f	\N
207795	prae-	prae- =prae  (SgG  >praad !22_S	et	f	\N
207796	prae-	prae- =prae  (IndPrPs_  >praadima !28_V	et	f	\N
207797	prae-	prae- =prae  (ImpPrSg2  >praadima !28_V	et	f	\N
207811	programeerine	?programeerine =programeerine  (SgN  >programeerine !10_A	et	f	\N
207814	sobival	sobival =sobiva  (SgAd  >sobiv !02_A	et	f	\N
207815	sobival	"sobiv %sobi  )V_vA  <sobima ;27_V	et	f	\N
207816	iriimaas	?iriimaas =iriimaa  (SgIn  >iriimaa !26_S	et	f	\N
207817	iriimaas	?iriimaas =iriimaas  (SgN  >iriimaas !22_S	et	f	\N
207828	riigikoolist	riigikoolist =kooli  (SgEl  >riigi+kool !22_S	et	f	\N
207829	riigikoolist	riigikoolist =kooli  (PlEl  >riigi+kool !22_S	et	f	\N
207830	riigikoolist	riigikoolist =koolis  (SgP  >riigi+kooline !10_A	et	f	\N
207831	riigikoolist	"riigi+kooline %koo  )LINE_aA  <riigi+kubu ;18_S	et	f	\N
207832	riigikoolist	"riigi+kooline %kooli  )NE_aA  <riigi+kool ;22_S	et	f	\N
207836	üliõpilast	üliõpilast =la  (SgEl  >üli+õpi+la !26_S	et	f	\N
207837	üliõpilast	üliõpilast =las  (SgP  >üli+õpi+laps !14_S	et	f	\N
207838	üliõpilast	üliõpilast =last  (SgN  >üli+õpi+last !22_S	et	f	\N
207839	üliõpilast	üliõpilast =õpilas  (SgP  >üli+õpilane !12_S	et	f	\N
207842	sekretarina	?sekretarina =sekretari  (SgEs  >sekretar !19_S	et	f	\N
207843	sekretarina	?sekretarina =sekretarina  (SgG  >sekretarin !19_S	et	f	\N
207844	sekretarina	?sekretarina =sekretarina  (SgP  >sekretarin !19_S	et	f	\N
207845	sekretarina	?sekretarina =sekretarina  (SgAdt  >sekretarin !19_S	et	f	\N
207847	inglisekeeles	inglisekeeles =keele  (SgIn  >inglise+keel !13_S	et	f	\N
207848	inglisekeeles	inglisekeeles =keele  (PlIn  >inglise+keeld !22_S	et	f	\N
207858	ettevõittluses	?ettevõittluses =ettevõittluse  (SgIn  >ettevõittlus !11~09_S	et	f	\N
207859	ettevõittluses	?ettevõittluses =võittluse  (SgIn  >ette+võittlus !11~09_S	et	f	\N
207878	unistust	unistust =unistus  (SgP  >unistus !11_S	et	f	\N
207879	unistust	"unistus %unista  )US_vS  <unistama ;27_V	et	f	\N
207884	lenusin	?lenusin =lenu  (IndIpfSg1  >lenuma !27_V	et	f	\N
207885	lenusin	?lenusin =lenusin  (SgN  >lenusin !19_S	et	f	\N
207911	fakultedil	### fakultedil	et	f	\N
207917	loengudele	### loengudele	et	f	\N
207951	sillamaelt	?sillamaelt =sillamae  (SgAbl  >sillamae !26_S	et	f	\N
207952	sillamaelt	?sillamaelt =sillamaelt  (ID  >sillamaelt !41_D	et	f	\N
207953	sillamaelt	?sillamaelt =mae  (SgAbl  >silla+mae !26_S	et	f	\N
207954	sillamaelt	?sillamaelt =maelt  (SgN  >silla+maelt !22_S	et	f	\N
207965	õhtukoolis	õhtukoolis =kooli  (SgIn  >õhtu+kool !22_S	et	f	\N
207966	õhtukoolis	õhtukoolis =kooli  (PlIn  >õhtu+kool !22_S	et	f	\N
207967	kaitsen	kaitsen =kaitse  (IndPrSg1  >kaitsema !28_V	et	f	\N
207968	kaitsen	kaitsen =kaitse  (IndPrSg1  >kaitsma !32_V	et	f	\N
207979	dipploomi	?dipploomi =dipploomi  (SgN  >dipploomi !16_S	et	f	\N
207980	dipploomi	?dipploomi =dipploomi  (SgG  >dipploomi !16_S	et	f	\N
207981	dipploomi	?dipploomi =dipploomi  (SgG  >dipploom !22_S	et	f	\N
207982	dipploomi	?dipploomi =dipploomi  (SgP  >dipploom !22_S	et	f	\N
207983	dipploomi	?dipploomi =dipploomi  (SgAdt  >dipploom !22_S	et	f	\N
207984	dipploomi	?dipploomi =dipploomi  (IndPrPs_  >dipploomima !28_V	et	f	\N
207985	dipploomi	?dipploomi =dipploomi  (ImpPrSg2  >dipploomima !28_V	et	f	\N
207990	iatb	?iatb =iatb  (SgN  >iatb !22_S	et	f	\N
208039	peamaja	peamaja =maja  (SgN  >pea+maja !17_S	et	f	\N
208040	peamaja	peamaja =maja  (SgG  >pea+maja !17_S	et	f	\N
207753	roos	roos =roo  (SgIn  >roo !26_S	et	f	\N
207754	roos	roos =roos  (SgN  >roos !22_S	et	f	\N
207807	kassapidaja	kassapidaja =pidaja  (SgN  >kassa+pidaja !01_S	et	f	\N
207808	kassapidaja	kassapidaja =pidaja  (SgG  >kassa+pidaja !01_S	et	f	\N
207849	elistasin	?elistasin =elista  (IndIpfSg1  >elistama !27_V	et	f	\N
207850	elistasin	?elistasin =elistasin  (SgN  >elistasin !19_S	et	f	\N
207854	annda	?annda =annda  (SgN  >annda !01_S	et	f	\N
207855	annda	?annda =annda  (SgG  >annda !01_S	et	f	\N
207856	annda	?annda =annda  (IndPrPs_  >anndama !29_V	et	f	\N
207857	annda	?annda =annda  (ImpPrSg2  >anndama !29_V	et	f	\N
207867	ingeneerid	?ingeneerid =ingeneeri  (PlN  >ingeneeri !16_S	et	f	\N
207868	ingeneerid	?ingeneerid =ingeneeri  (PlN  >ingeneer !22_S	et	f	\N
207869	ingeneerid	?ingeneerid =ingeneeri  (IndPrSg2  >ingeneerima !28_V	et	f	\N
207901	ttusse	?ttusse =ttusse  (SgN  >ttusse !06_S	et	f	\N
207903	ttusse	?ttusse =ttusse  (SgG  >ttusne !02_A	et	f	\N
207905	ttusse	?ttusse =ttusse  (SgG  >ttusse !06_S	et	f	\N
207907	ttusse	?ttusse =ttusse  (PlP  >ttuss !22_S	et	f	\N
207909	ttusse	?ttusse =ttusse  (IndPrPs_  >ttussema !27_V	et	f	\N
207910	ttusse	?ttusse =ttusse  (ImpPrSg2  >ttussema !27_V	et	f	\N
207921	rigikeel	?rigikeel =rigikee  (SgAd  >rigikee !26_S	et	f	\N
207922	rigikeel	?rigikeel =rigikeel  (SgN  >rigikeel !22_S	et	f	\N
207923	tlvl	### tlvl	et	f	\N
207929	füsikale	?füsikale =füsika  (SgAll  >füsika !01_S	et	f	\N
207930	füsikale	?füsikale =füsika  (SgAll  >füsikas !02_S	et	f	\N
207931	füsikale	?füsikale =füsikale  (PlP  >füsikal !19_S	et	f	\N
207932	teaduskonnast	teaduskonnast =teaduskonna  (SgEl  >teaduskond !22_S	et	f	\N
207933	teaduskonnast	teaduskonnast =teaduskonnas  (SgP  >teaduskonnane !12_A	et	f	\N
207934	teaduskonnast	"teaduskonnane %teaduskonna  )NE_aA  <teaduskond ;22_S	et	f	\N
207935	teaduskonnast	teaduskonnast =konna  (SgEl  >teadus+konn !22_S	et	f	\N
207936	teaduskonnast	teaduskonnast =konnas  (SgP  >teadus+konnane !10_A	et	f	\N
207937	teaduskonnast	"teadus+konnane %konna  )NE_aA  <teadus+konn ;22_S	et	f	\N
207941	lõpesin	?lõpesin =lõpe  (IndIpfSg1  >lõpema !27_V	et	f	\N
207942	lõpesin	?lõpesin =lõpesin  (SgN  >lõpesin !19_S	et	f	\N
207945	asutama	asutama =asu  (SupIps  >asuma !27_V	et	f	\N
207946	asutama	asutama =asuta  (Sup  >asutama !27_V	et	f	\N
207947	arusaamavad	?arusaamavad =arusaamava  (PlN  >arusaamav !02_A	et	f	\N
207948	arusaamavad	?arusaamavad =arusaamava  (PlN  >arusaamava !16_S	et	f	\N
207949	arusaamavad	?arusaamavad =saamava  (PlN  >aru+saamava !01_S	et	f	\N
207950	arusaamavad	?arusaamavad =saamava  (PlN  >aru+saamav !02_A	et	f	\N
207956	süstemi	?süstemi =süstemi  (SgN  >süstemi !01_S	et	f	\N
207957	süstemi	?süstemi =süstemi  (SgG  >süstemi !01_S	et	f	\N
207958	süstemi	?süstemi =süstemi  (SgG  >süstem !02_A	et	f	\N
207959	eragünasim	?eragünasim =eragünasim  (SgN  >eragünasim !02_A	et	f	\N
207960	eragünasim	?eragünasim =günasim  (SgN  >era+günasim !02_A	et	f	\N
207961	koorusd	?koorusd =koorusd  (SgN  >koorusd !02_S	et	f	\N
207962	koorusd	?koorusd =usd  (SgN  >koor+usd !22_S	et	f	\N
207969	vabariki	?vabariki =vabariki  (IndPrPs_  >vabarikkima !28_V	et	f	\N
207970	vabariki	?vabariki =vabariki  (ImpPrSg2  >vabarikkima !28_V	et	f	\N
207971	vabariki	?vabariki =riki  (SgN  >vaba+riki !16_S	et	f	\N
207972	vabariki	?vabariki =riki  (SgG  >vaba+riki !16_S	et	f	\N
207973	vabariki	?vabariki =riki  (SgG  >vaba+rikk !22_S	et	f	\N
207974	bataljonis	?bataljonis =bataljoni  (SgIn  >bataljon !19_S	et	f	\N
207975	bataljonis	?bataljonis =bataljonis  (SgN  >bataljonis !09_S	et	f	\N
207991	organisemine	?organisemine =organisemine  (SgN  >organisemine !12_S	et	f	\N
207992	organisemine	?organisemine =organisemine  (PlP  >organisemin !19_S	et	f	\N
208042	korpusedes	### korpusedes	et	f	\N
208059	tegisime	?tegisime =tegi  (IndIpfPl1  >tegima !27_V	et	f	\N
208068	tootmisteehnika	?tootmisteehnika =tootmisteehnika  (SgN  >tootmisteehnika !01_S	et	f	\N
208069	tootmisteehnika	?tootmisteehnika =tootmisteehnika  (SgG  >tootmisteehnika !01_S	et	f	\N
208070	tootmisteehnika	?tootmisteehnika =tootmisteehnika  (SgG  >tootmisteehnikas !02_A	et	f	\N
208071	tootmisteehnika	?tootmisteehnika =teehnika  (SgN  >tootmis+teehnika !01_S	et	f	\N
208072	tootmisteehnika	?tootmisteehnika =teehnika  (SgG  >tootmis+teehnika !01_S	et	f	\N
208073	tootmisteehnika	?tootmisteehnika =teehnika  (SgG  >tootmis+teehnikas !02_S	et	f	\N
208074	spoordihoone	?spoordihoone =spoordihoone  (SgN  >spoordihoone !16_S	et	f	\N
208075	spoordihoone	?spoordihoone =spoordihoone  (SgG  >spoordihoone !16_S	et	f	\N
208076	spoordihoone	?spoordihoone =spoordihoone  (PlP  >spoordihoon !22_S	et	f	\N
208085	tehnikast	tehnikast =tehnika  (SgEl  >tehnika !01_S	et	f	\N
208086	tehnikast	tehnikast =tehnikas  (SgP  >tehnikane !12_A	et	f	\N
208087	tehnikast	"tehnikane %tehnika  )NE_aA  <tehnika ;01_S	et	f	\N
208104	uesti	?uesti =uesti  (ID  >uesti !41_D	et	f	\N
208105	uesti	?uesti =uesti  (SgG  >uest !22_S	et	f	\N
208106	uesti	?uesti =uesti  (SgP  >uest !22_S	et	f	\N
208107	uesti	?uesti =uesti  (SgAdt  >uest !22_S	et	f	\N
208108	uesti	?uesti =uesti  (IndPrPs_  >uestima !28_V	et	f	\N
208109	uesti	?uesti =uesti  (ImpPrSg2  >uestima !28_V	et	f	\N
207783	gaasiplitil	?gaasiplitil =ipliti  (SgAd  >gaas+iplit !02_S	et	f	\N
207785	gaasiplitil	?gaasiplitil =ipliti  (SgAd  >gaas+iplitt !22_S	et	f	\N
207790	kotlettid	?kotlettid =kotletti  (PlN  >kotletti !01_S	et	f	\N
207801	koffee	?koffee =koffee  (SgN  >koffee !26_S	et	f	\N
207802	koffee	?koffee =koffee  (SgG  >koffee !26_S	et	f	\N
207812	konkurentsivõimalised	konkurentsivõimalised =malise  (PlN  >konkurentsi+või+maline !10_A	et	f	\N
207813	konkurentsivõimalised	"konkurentsi+või+maline %mali  )NE_aA  <konkurentsi+või+mali ;17_S	et	f	\N
207824	sõbrakil	?sõbrakil =sõbraki  (SgAd  >sõbraki !01_S	et	f	\N
207825	sõbrakil	?sõbrakil =sõbraki  (SgAd  >sõbrak !02_S	et	f	\N
207826	sõbrakil	?sõbrakil =sõbraki  (SgAd  >sõbrakk !22_S	et	f	\N
207827	sõbrakil	?sõbrakil =sõbrakil  (ID  >sõbrakil !41_DA	et	f	\N
207833	ärindusest	ärindusest =ärinduse  (SgEl  >ärindus !11_S	et	f	\N
207834	ärindusest	ärindusest =ärinduses  (SgP  >ärindusene !12_A	et	f	\N
207835	ärindusest	"ärindusene %ärinduse  )NE_aA  <ärindus ;11_S	et	f	\N
207840	hotellise	hotellise =hotellise  (SgG  >hotelline !12_A	et	f	\N
207841	hotellise	"hotelline %hotelli  )NE_aA  <hotell ;22_S	et	f	\N
207846	lastetarbitega	### lastetarbitega	et	f	\N
207873	sukeldunud	sukeldunud =sukeldu  (PtsPtPs  >sukelduma !27_V	et	f	\N
207874	sukeldunud	sukeldunud =sukeldunu  (PlN  >sukeldunu !01_S	et	f	\N
207875	sukeldunud	"sukeldunu %sukeldu  )NU_vS  <sukelduma ;27_V	et	f	\N
207876	sukeldunud	sukeldunud =sukeldunud  (ID  >sukeldunud !41_A	et	f	\N
207877	sukeldunud	"sukeldunud %sukeldu  )NUD_vA  <sukelduma ;27_V	et	f	\N
207882	ülbe	ülbe =ülbe  (SgN  >ülbe !01_A	et	f	\N
207883	ülbe	ülbe =ülbe  (SgG  >ülbe !01_A	et	f	\N
207886	kolist	kolist =koli  (SgEl  >koli !17_S	et	f	\N
207887	kolist	kolist =kolis  (SgP  >koline !10_A	et	f	\N
207888	kolist	"koline %koli  )NE_aA  <koli ;17_S	et	f	\N
207889	polütehnikumist	polütehnikumist =polütehnikumi  (SgEl  >polütehnikum !19_S	et	f	\N
207890	polütehnikumist	polütehnikumist =polütehnikumis  (SgP  >polütehnikumine !12_S	et	f	\N
207891	polütehnikumist	"polütehnikumine %polütehnikumi  )NE_aA  <polütehnikum ;19_S	et	f	\N
207895	panesin	?panesin =panesin  (SgN  >panesin !19_S	et	f	\N
207896	konstruerib	?konstruerib =konstrueri  (IndPrSg3  >konstruerima !28_V	et	f	\N
207898	audentesse	?audentesse =audentes  (SgAdt  >audentene !12_A	et	f	\N
207899	audentesse	?audentesse =audentesse  (SgG  >audentesne !02_A	et	f	\N
207900	audentesse	?audentesse =audentesse  (PlP  >audentess !22_S	et	f	\N
207902	audentesse	?audentesse =dente  (SgIll  >au+dende !06_S	et	f	\N
207904	audentesse	?audentesse =dentes  (SgAdt  >au+dentene !12_A	et	f	\N
207906	audentesse	?audentesse =dentesse  (SgG  >au+dentesne !02_A	et	f	\N
207908	audentesse	?audentesse =dentesse  (PlP  >au+dentess !22_S	et	f	\N
207955	intenet	### intenet	et	f	\N
207963	lõpitasin	?lõpitasin =lõpita  (IndIpfSg1  >lõpitama !27_V	et	f	\N
207964	lõpitasin	?lõpitasin =lõpitasin  (SgN  >lõpitasin !19_S	et	f	\N
207976	mehatroonika	?mehatroonika =mehatroonika  (SgN  >mehatroonika !01_S	et	f	\N
207977	mehatroonika	?mehatroonika =mehatroonika  (SgG  >mehatroonika !01_S	et	f	\N
207978	mehatroonika	?mehatroonika =mehatroonika  (SgG  >mehatroonikas !02_A	et	f	\N
207989	elektikut	?elektikut =elektiku  (SgP  >elektik !02_S	et	f	\N
207993	gramatikat	?gramatikat =gramatika  (SgP  >gramatika !01_S	et	f	\N
207994	gramatikat	?gramatikat =gramatika  (SgP  >gramatikas !02_A	et	f	\N
208003	põlju	?põlju =põlju  (SgN  >põlju !16_S	et	f	\N
208004	põlju	?põlju =põlju  (SgG  >põlju !16_S	et	f	\N
208005	põlju	?põlju =põlju  (IndPrPs_  >põljuma !27_V	et	f	\N
208006	põlju	?põlju =põlju  (ImpPrSg2  >põljuma !27_V	et	f	\N
208008	ekstimsporti	?ekstimsporti =ekstimsporti  (SgP  >ekstimsport !22_S	et	f	\N
208009	ekstimsporti	?ekstimsporti =ekstimsporti  (SgAdt  >ekstimsport !22_S	et	f	\N
208010	ekstimsporti	?ekstimsporti =timsporti  (SgN  >eks+timsporti !01_S	et	f	\N
208011	ekstimsporti	?ekstimsporti =timsporti  (SgG  >eks+timsporti !01_S	et	f	\N
208012	ekstimsporti	?ekstimsporti =timsporti  (SgP  >eks+timsport !22_S	et	f	\N
208013	ekstimsporti	?ekstimsporti =timsporti  (SgAdt  >eks+timsport !22_S	et	f	\N
208036	programeerija	?programeerija =programeerija  (SgN  >programeerija !01_S	et	f	\N
208037	programeerija	?programeerija =programeerija  (SgG  >programeerija !01_S	et	f	\N
208038	programeerija	?programeerija =programeerija  (SgG  >programeerijas !02_A	et	f	\N
208060	saamut	?saamut =saamu  (SgP  >saamu !16_S	et	f	\N
208061	saamut	?saamut =saamut  (SgN  >saamut !02_S	et	f	\N
208077	tasuva	tasuva =tasuva  (SgG  >tasuv !02_A	et	f	\N
208078	tasuva	"tasuv %tasu  )V_vA  <tasuma ;27_V	et	f	\N
208090	mitmessugused	?mitmessugused =mitmessuguse  (PlN  >mitmessugus !11?09_S	et	f	\N
208093	programeerijaks	?programeerijaks =programeerija  (SgTr  >programeerija !01_S	et	f	\N
208095	programeerijaks	?programeerijaks =programeerija  (SgTr  >programeerijas !02_A	et	f	\N
208103	vanam	?vanam =vanam  (SgN  >vanam !02_A	et	f	\N
208131	lektsionile	?lektsionile =lektsioni  (SgAll  >lektsion !19~02_S	et	f	\N
208132	lektsionile	?lektsionile =lektsioni  (SgAll  >lektsioni !16_S	et	f	\N
208147	paren	?paren =pare  (IndPrSg1  >parema !27_V	et	f	\N
208148	paren	?paren =paren  (SgN  >paren !02_S	et	f	\N
207943	vastuvõetud	vastuvõetud =võe  (PtsPtIps  >vastu+_võtma !35_V	et	f	\N
207944	vastuvõetud	vastuvõetud =võetu  (PlN  >vastu+võetu !01_S	et	f	\N
207995	lugupetumisega	?lugupetumisega =lugupetumise  (SgKom  >lugupetumine !12_S	et	f	\N
207996	lugupetumisega	?lugupetumisega =petumise  (SgKom  >lugu+petumine !12_S	et	f	\N
207997	lapsepõlva	?lapsepõlva =lapsepõlva  (SgN  >lapsepõlva !16_S	et	f	\N
207998	lapsepõlva	?lapsepõlva =lapsepõlva  (SgG  >lapsepõlva !16_S	et	f	\N
207999	lapsepõlva	?lapsepõlva =põlva  (SgN  >lapse+põlva !16_S	et	f	\N
208000	lapsepõlva	?lapsepõlva =põlva  (SgG  >lapse+põlva !16_S	et	f	\N
208001	lapsepõlva	?lapsepõlva =epõlva  (SgN  >laps+epõlva !01_S	et	f	\N
208002	lapsepõlva	?lapsepõlva =epõlva  (SgG  >laps+epõlva !01_S	et	f	\N
208007	raskedes	?raskedes =raske  (Ger  >raskema !27_V	et	f	\N
208014	breakdanceiga	?breakdanceiga =breakdancei  (SgKom  >breakdancei !26_S	et	f	\N
208015	tanapäeva	?tanapäeva =tanapäeva  (SgN  >tanapäeva !16_S	et	f	\N
208016	tanapäeva	?tanapäeva =tanapäeva  (SgG  >tanapäeva !16_S	et	f	\N
208017	eldist	?eldist =eldi  (SgEl  >elt !22_S	et	f	\N
208018	eldist	?eldist =eldis  (SgP  >eldis !09_S	et	f	\N
208019	eldist	?eldist =eldist  (SgN  >eldist !22_S	et	f	\N
208030	suomis	?suomis =suomi  (SgIn  >suomi !16_S	et	f	\N
208031	suomis	?suomis =suomi  (SgIn  >suom !22_S	et	f	\N
208032	suomis	?suomis =suomi  (IndIpfSg3  >suomima !28_V	et	f	\N
208033	suomis	?suomis =suomis  (SgN  >suomis !09_S	et	f	\N
208045	ainest	ainest =aine  (SgEl  >aine !06_S	et	f	\N
208046	ainest	ainest =aine  (PlEl  >ain !22_S	et	f	\N
208047	ainest	ainest =aines  (SgP  >aines !09_S	et	f	\N
208048	ainest	ainest =aines  (SgP  >ainene !10_A	et	f	\N
208049	ainest	"ainene %aine  )NE_aA  <aine ;06_S	et	f	\N
208079	roolli	?roolli =roolli  (ID  >roolli !41_D	et	f	\N
208080	roolli	?roolli =roolli  (SgG  >rooll !22_S	et	f	\N
208081	roolli	?roolli =roolli  (SgP  >rooll !22_S	et	f	\N
208082	roolli	?roolli =roolli  (SgAdt  >rooll !22_S	et	f	\N
208083	roolli	?roolli =roolli  (IndPrPs_  >roollima !28_V	et	f	\N
208084	roolli	?roolli =roolli  (ImpPrSg2  >roollima !28_V	et	f	\N
208094	eetis	?eetis =eet  (IndIpfSg3  >eetma !34_V	et	f	\N
208096	eetis	?eetis =eeti  (IndIpfSg3  >eetima !28_V	et	f	\N
208097	eetis	?eetis =eetis  (SgN  >eetis !11~09_S	et	f	\N
208098	tegima	?tegima =tegi  (Sup  >tegima !27_V	et	f	\N
208099	tegima	?tegima =tegima  (SgG  >tegim !02_A	et	f	\N
208100	töösel	?töösel =tööse  (SgAd  >tööse !06_S	et	f	\N
208101	töösel	?töösel =tööse  (PlAd  >töös !22_S	et	f	\N
208102	töösel	?töösel =töösel  (SgN  >töösel !02_S	et	f	\N
208122	ttüse	?ttüse =ttüse  (SgN  >ttüse !16_S	et	f	\N
208123	ttüse	?ttüse =ttüse  (SgG  >ttüse !16_S	et	f	\N
208124	ttüse	?ttüse =ttüse  (IndPrPs_  >ttüsema !27_V	et	f	\N
208125	ttüse	?ttüse =ttüse  (ImpPrSg2  >ttüsema !27_V	et	f	\N
208141	halbast	?halbast =halba  (SgEl  >halba !16_S	et	f	\N
208142	halbast	?halbast =halbas  (SgP  >halbas !07_S	et	f	\N
208143	halbast	?halbast =halbas  (SgP  >halbane !10_A	et	f	\N
208145	laienda	laienda =laienda  (IndPrPs_  >laiendama !27_V	et	f	\N
208146	laienda	laienda =laienda  (ImpPrSg2  >laiendama !27_V	et	f	\N
208159	äriinfotehnologijat	?äriinfotehnologijat =äriinfotehnologija  (SgP  >äriinfotehnologija !01_S	et	f	\N
208160	äriinfotehnologijat	?äriinfotehnologijat =äriinfotehnologija  (SgP  >äriinfotehnologijas !02_A	et	f	\N
208161	äriinfotehnologijat	?äriinfotehnologijat =logija  (SgP  >äri+info+tehno+logija !01_S	et	f	\N
208162	äriinfotehnologijat	?äriinfotehnologijat =logija  (SgP  >äri+info+tehno+logijas !02_A	et	f	\N
208163	äriinfotehnologijat	?äriinfotehnologijat =tehnologija  (SgP  >äri+info+tehnologija !01_S	et	f	\N
208164	äriinfotehnologijat	?äriinfotehnologijat =tehnologija  (SgP  >äri+info+tehnologijas !02_A	et	f	\N
208165	äriinfotehnologijat	?äriinfotehnologijat =infotehnologija  (SgP  >äri+infotehnologija !01_S	et	f	\N
208166	äriinfotehnologijat	?äriinfotehnologijat =infotehnologija  (SgP  >äri+infotehnologijas !02_A	et	f	\N
208167	arvutiks	arvutiks =arvuti  (SgTr  >arvuti !01_S	et	f	\N
208168	arvutiks	arvutiks =tiks  (SgN  >arvu+tiks !22_S	et	f	\N
208169	arvutiks	arvutiks =uti  (SgTr  >arv+utt !22_S	et	f	\N
208170	arvutiks	arvutiks =uti  (PlTr  >arv+utt !22_S	et	f	\N
208173	oodan	?oodan =ooda  (IndPrSg1  >oodama !29_V	et	f	\N
208174	oodan	?oodan =oodan  (SgN  >oodan !02_S	et	f	\N
208175	inglimaal	inglimaal =maa  (SgAd  >ingli+maa !26_S	et	f	\N
208176	inglimaal	inglimaal =maal  (SgN  >ingli+maal !22_S	et	f	\N
208177	üheksakümend	?üheksakümend =üheksakümend  (SgN  >üheksakümend !22_S	et	f	\N
208178	üheksakümend	?üheksakümend =kümend  (SgN  >üheksa+kümend !02_S	et	f	\N
208179	üheksakümend	?üheksakümend =akümend  (SgN  >üheks+akümend !22_S	et	f	\N
208180	üheksakümend	?üheksakümend =ksakümend  (SgN  >ühe+ksakümend !22_S	et	f	\N
208186	pidatud	?pidatud =pidatu  (PlN  >pidatu !01_S	et	f	\N
208187	pidatud	?pidatud =pidatu  (IndPrSg2  >pidatuma !27_V	et	f	\N
208188	pidatud	?pidatud =pidatud  (ID  >pidatud !41_A	et	f	\N
208191	tagasihoidlikumaks	tagasihoidlikumaks =hoidlikuma  (SgTr  >tagasi+hoidlikum !02_A	et	f	\N
208192	tagasihoidlikumaks	"tagasi+hoidlikum %hoidliku  )M_cA  <tagasi+hoidlik ;25_A	et	f	\N
207988	diaagnosija	?diaagnosija =diaagnosija  (SgG  >diaagnosijas !02_A	et	f	\N
208020	päraseid	päraseid =pärase  (PlP  >pärane !10_A	et	f	\N
208021	päraseid	"pärane %pära  )NE_aA  <pära ;17_S	et	f	\N
208022	valgevenemaaal	?valgevenemaaal =valgevenemaaa  (SgAd  >valgevenemaaa !26_S	et	f	\N
208023	valgevenemaaal	?valgevenemaaal =valgevenemaaal  (SgN  >valgevenemaaal !22_S	et	f	\N
208024	valgevenemaaal	?valgevenemaaal =maaa  (SgAd  >valge+vene+maaa !26_S	et	f	\N
208025	valgevenemaaal	?valgevenemaaal =maaal  (SgN  >valge+vene+maaal !22_S	et	f	\N
208026	valgevenemaaal	?valgevenemaaal =venemaaa  (SgAd  >valge+venemaaa !26_S	et	f	\N
208027	valgevenemaaal	?valgevenemaaal =venemaaal  (SgN  >valge+venemaaal !22_S	et	f	\N
208028	valgevenemaaal	?valgevenemaaal =evenemaaa  (SgAd  >valg+evenemaaa !26_S	et	f	\N
208029	valgevenemaaal	?valgevenemaaal =evenemaaal  (SgN  >valg+evenemaaal !22_S	et	f	\N
208034	sõinad	?sõinad =sõina  (PlN  >sõina !16_S	et	f	\N
208035	sõinad	?sõinad =sõina  (IndPrSg2  >sõinama !29_V	et	f	\N
208058	iabb	?iabb =iabb  (SgN  >iabb !22_S	et	f	\N
208091	sündinut	sündinut =sündinu  (SgP  >sündinu !01_S	et	f	\N
208092	sündinut	"sündinu %sündi  )NU_vS  <sündima ;28_V	et	f	\N
208110	õppilasele	?õppilasele =õppilase  (SgAll  >õppilane !12_S	et	f	\N
208130	planerin	?planerin =planerin  (SgN  >planerin !19_S	et	f	\N
208156	jõesus	?jõesus =jõesu  (SgIn  >jõesu !16_S	et	f	\N
208157	jõesus	?jõesus =jõesu  (IndIpfSg3  >jõesuma !27_V	et	f	\N
208158	jõesus	?jõesus =jõesus  (SgN  >jõesus !11~09_S	et	f	\N
208209	kumnes	?kumnes =kumne  (PlIn  >kumn !22_S	et	f	\N
208210	kumnes	?kumnes =kumne  (IndIpfSg3  >kumnema !27_V	et	f	\N
208211	kumnes	?kumnes =kumnes  (SgN  >kumnes !09_S	et	f	\N
208218	murdes	murdes =murd  (Ger  >murdma !34_V	et	f	\N
208219	murdes	murdes =murde  (SgIn  >murre !06_S	et	f	\N
208286	üheksasaada	?üheksasaada =üheksasaada  (SgN  >üheksasaada !16_S	et	f	\N
208287	üheksasaada	?üheksasaada =üheksasaada  (SgG  >üheksasaada !16_S	et	f	\N
208288	üheksasaada	?üheksasaada =saada  (SgN  >üheksa+saada !16_S	et	f	\N
208289	üheksasaada	?üheksasaada =saada  (SgG  >üheksa+saada !16_S	et	f	\N
208290	üheksasaada	?üheksasaada =asaada  (SgN  >üheks+asaada !16_S	et	f	\N
208291	üheksasaada	?üheksasaada =asaada  (SgG  >üheks+asaada !16_S	et	f	\N
208292	üheksasaada	?üheksasaada =ksasaada  (SgN  >ühe+ksasaada !16_S	et	f	\N
208293	üheksasaada	?üheksasaada =ksasaada  (SgG  >ühe+ksasaada !16_S	et	f	\N
208313	tasamele	?tasamele =tasamele  (PlP  >tasamel !19_S	et	f	\N
208314	tasamele	?tasamele =mele  (SgN  >tasa+mele !16_S	et	f	\N
208315	tasamele	?tasamele =mele  (SgG  >tasa+mele !16_S	et	f	\N
208330	pidistavad	?pidistavad =pidista  (IndPrPl3  >pidistama !27_V	et	f	\N
208331	pidistavad	?pidistavad =pidistava  (PlN  >pidistav !02_A	et	f	\N
208332	pidistavad	?pidistavad =pidistava  (PlN  >pidistava !16_S	et	f	\N
208333	pidistavad	?pidistavad =stava  (PlN  >pidi+stava !17_S	et	f	\N
208364	heaid	?heaid =heaid  (SgN  >heaid !02_S	et	f	\N
208391	lemmikkohti	lemmikkohti =kohti  (SgP  >lemmik+koht !22_S	et	f	\N
208392	lemmikkohti	lemmikkohti =kohti  (SgAdt  >lemmik+koht !22_S	et	f	\N
208393	lemmikkohti	lemmikkohti =kohti  (PlP  >lemmik+koht !22_S	et	f	\N
208398	uus-aastassoovid	?uus-aastassoovid =aastassoovi  (PlN  >uus-aastassoovi !16_S	et	f	\N
208399	uus-aastassoovid	?uus-aastassoovid =aastassoovi  (PlN  >uus-aastassoov !22_S	et	f	\N
208400	uus-aastassoovid	?uus-aastassoovid =aastassoovi  (IndPrSg2  >uus-aastassoovima !28_V	et	f	\N
208401	uus-aastassoovid	?uus-aastassoovid =tassoovi  (PlN  >uus-aas+tassoovi !16_S	et	f	\N
208402	uus-aastassoovid	?uus-aastassoovid =tassoovi  (PlN  >uus-aas+tassoov !22_S	et	f	\N
208407	seitsmene	seitsmene =seitsmene  (SgN  >seitsmene !12~10_A	et	f	\N
208408	seitsmene	"seitsmene %seitsme  )NE_aA  <seitse ;05_N	et	f	\N
208413	võlured	### võlured	et	f	\N
208427	ebarealsed	?ebarealsed =ebarealse  (PlN  >ebarealne !02_A	et	f	\N
208428	ebarealsed	?ebarealsed =realse  (PlN  >eba+realne !02_A	et	f	\N
208429	ebarealsed	?ebarealsed =realse  (PlN  >eba+realse !06_S	et	f	\N
208430	ola	?ola =ola  (SgN  >ola !17_S	et	f	\N
208431	ola	?ola =ola  (SgG  >ola !17_S	et	f	\N
208432	ola	?ola =ola  (SgP  >ola !17_S	et	f	\N
208433	ola	?ola =ola  (IndPrPs_  >olama !27_V	et	f	\N
208434	ola	?ola =ola  (ImpPrSg2  >olama !27_V	et	f	\N
208442	küttus	?küttus =küttu  (IndIpfSg3  >küttuma !27_V	et	f	\N
208443	küttus	?küttus =küttus  (SgN  >küttus !11~09_S	et	f	\N
208474	miinu	?miinu =miinu  (SgN  >miinu !16_S	et	f	\N
208475	miinu	?miinu =miinu  (SgG  >miinu !16_S	et	f	\N
208476	miinu	?miinu =miinu  (IndPrPs_  >miinuma !28_V	et	f	\N
208477	miinu	?miinu =miinu  (ImpPrSg2  >miinuma !28_V	et	f	\N
208482	imiline	?imiline =imiline  (SgN  >imiline !12_A	et	f	\N
208483	imiline	?imiline =imiline  (PlP  >imilin !19_S	et	f	\N
208486	sookoladi	?sookoladi =koladi  (SgN  >soo+koladi !01_S	et	f	\N
208487	sookoladi	?sookoladi =koladi  (SgG  >soo+koladi !01_S	et	f	\N
208492	tenenda	?tenenda =tenenda  (SgN  >tenenda !01_S	et	f	\N
208493	tenenda	?tenenda =tenenda  (SgG  >tenenda !01_S	et	f	\N
208494	tenenda	?tenenda =tenenda  (IndPrPs_  >tenendama !27_V	et	f	\N
208495	tenenda	?tenenda =tenenda  (ImpPrSg2  >tenendama !27_V	et	f	\N
208041	peamaja	peamaja =maja  (SgP  >pea+maja !17_S	et	f	\N
208043	jutusta	jutusta =jutusta  (IndPrPs_  >jutustama !27_V	et	f	\N
208044	jutusta	jutusta =jutusta  (ImpPrSg2  >jutustama !27_V	et	f	\N
208050	äriinfotehnologia	?äriinfotehnologia =äriinfotehnologia  (SgN  >äriinfotehnologia !01_S	et	f	\N
208051	äriinfotehnologia	?äriinfotehnologia =äriinfotehnologia  (SgG  >äriinfotehnologia !01_S	et	f	\N
208052	äriinfotehnologia	?äriinfotehnologia =logia  (SgN  >äri+info+tehno+logia !01_S	et	f	\N
208053	äriinfotehnologia	?äriinfotehnologia =logia  (SgG  >äri+info+tehno+logia !01_S	et	f	\N
208054	äriinfotehnologia	?äriinfotehnologia =tehnologia  (SgN  >äri+info+tehnologia !01_S	et	f	\N
208055	äriinfotehnologia	?äriinfotehnologia =tehnologia  (SgG  >äri+info+tehnologia !01_S	et	f	\N
208056	äriinfotehnologia	?äriinfotehnologia =infotehnologia  (SgN  >äri+infotehnologia !01_S	et	f	\N
208057	äriinfotehnologia	?äriinfotehnologia =infotehnologia  (SgG  >äri+infotehnologia !01_S	et	f	\N
208062	automatik	?automatik =automatik  (SgN  >automatik !02_S	et	f	\N
208063	automatik	?automatik =matik  (SgN  >auto+matik !02_S	et	f	\N
208064	automatik	?automatik =tomatik  (SgN  >au+tomatik !02_S	et	f	\N
208065	tulevikuses	?tulevikuses =tulevikuse  (SgIn  >tulevikus !11?09_S	et	f	\N
208066	tulevikuses	?tulevikuses =ikuse  (SgIn  >tulev+ikus !09_S	et	f	\N
208067	tulevikuses	?tulevikuses =vikuse  (SgIn  >tule+vikus !09_S	et	f	\N
208088	eksamitest	eksamitest =eksami  (PlEl  >eksam !02_S	et	f	\N
208089	eksamitest	eksamitest =test  (SgN  >eksami+test !22_S	et	f	\N
208144	loengudega	### loengudega	et	f	\N
208171	programerijaks	?programerijaks =programerija  (SgTr  >programerija !01_S	et	f	\N
208172	programerijaks	?programerijaks =programerija  (SgTr  >programerijas !02_A	et	f	\N
208215	lõuna-afrikas	?lõuna-afrikas =afrika  (SgIn  >lõuna-afrika !01_S	et	f	\N
208216	lõuna-afrikas	?lõuna-afrikas =afrika  (SgIn  >lõuna-afrikas !02_S	et	f	\N
208217	lõuna-afrikas	?lõuna-afrikas =afrikas  (SgN  >lõuna-afrikas !02_S	et	f	\N
208220	kolmekümnendane	?kolmekümnendane =kolmekümnendane  (SgN  >kolmekümnendane !12_A	et	f	\N
208221	kolmekümnendane	?kolmekümnendane =ane  (SgN  >kolme+kümnend+ane !16_S	et	f	\N
208222	kolmekümnendane	?kolmekümnendane =ane  (SgG  >kolme+kümnend+ane !16_S	et	f	\N
208223	kolmekümnendane	?kolmekümnendane =kümnendane  (SgN  >kolme+kümnendane !12_A	et	f	\N
208224	kolmekümnendane	?kolmekümnendane =kümnendane  (PlP  >kolme+kümnendan !19_S	et	f	\N
208225	kolmekümnendane	?kolmekümnendane =ekümnendane  (SgN  >kolm+ekümnendane !12_A	et	f	\N
208231	ühiksakümend	?ühiksakümend =ühiksakümend  (SgN  >ühiksakümend !22_S	et	f	\N
208235	uheksasaja	?uheksasaja =uheksasaja  (SgN  >uheksasaja !01_S	et	f	\N
208236	uheksasaja	?uheksasaja =uheksasaja  (SgG  >uheksasaja !01_S	et	f	\N
208237	uheksasaja	?uheksasaja =uheksasaja  (SgG  >uheksasajas !02_A	et	f	\N
208239	planerivad	?planerivad =planeriva  (PlN  >planeriv !02_A	et	f	\N
208240	planerivad	?planerivad =planeriva  (PlN  >planeriva !16_S	et	f	\N
208274	tansijad	?tansijad =tansija  (PlN  >tansija !01_S	et	f	\N
208275	tansijad	?tansijad =tansija  (PlN  >tansijas !02_A	et	f	\N
208282	armastasis	?armastasis =armastasi  (PlIn  >armastane !12_A	et	f	\N
208283	armastasis	?armastasis =armastasis  (SgN  >armastasis !09_S	et	f	\N
208326	leija	?leija =leija  (SgN  >leija !01_S	et	f	\N
208327	leija	?leija =leija  (SgG  >leija !01_S	et	f	\N
208328	leija	?leija =leija  (IndPrPs_  >leijama !29_V	et	f	\N
208329	leija	?leija =leija  (ImpPrSg2  >leijama !29_V	et	f	\N
208334	niisuugune	?niisuugune =niisuugune  (SgN  >niisuugune !10_A	et	f	\N
208335	niisuugune	?niisuugune =gune  (SgN  >nii+suu+gune !16_S	et	f	\N
208336	niisuugune	?niisuugune =gune  (SgG  >nii+suu+gune !16_S	et	f	\N
208337	niisuugune	?niisuugune =suugune  (SgN  >nii+suugune !10_A	et	f	\N
208344	peot	?peot =peot  (SgN  >peot !22_S	et	f	\N
208360	lummined	?lummined =lummine  (IndPrSg2  >lumminema !27_V	et	f	\N
208365	laptop	?laptop =laptop  (SgN  >laptop !02_S	et	f	\N
208379	tehnoloogiliselt	tehnoloogiliselt =tehnoloogilise  (SgAbl  >tehnoloogiline !12_A	et	f	\N
208380	tehnoloogiliselt	"tehnoloogiline %tehnoloogi  )LINE_aA  <tehnoloog ;22_S	et	f	\N
208381	tehnoloogiliselt	tehnoloogiliselt =tehnoloogiliselt  (ID  >tehnoloogiliselt !41_D	et	f	\N
208382	tehnoloogiliselt	"tehnoloogiliselt %tehnoloogi  )LISELT_mD  <tehnoloog ;22_S	et	f	\N
208383	tehnoloogiliselt	"tehnoloogiliselt %tehnoloogilise  )LT_mD  <tehnoloogiline ;12_A	et	f	\N
208384	tehnoloogiliselt	tehnoloogiliselt =loogilise  (SgAbl  >tehno+loogiline !12_A	et	f	\N
208385	tehnoloogiliselt	"tehno+loogiline %loogi  )LINE_aA  <tehno+loog ;22_S	et	f	\N
208386	tehnoloogiliselt	"tehno+loogiliselt %loogi  )LISELT_mD  <tehno+loog ;22_S	et	f	\N
208387	tehnoloogiliselt	"tehno+loogiliselt %loogilise  )LT_mD  <tehno+loogiline ;12_A	et	f	\N
208388	plaanisid	plaanisid =plaani  (PlP  >plaan !22_S	et	f	\N
208389	plaanisid	plaanisid =plaani  (IndIpfSg2  >plaanima !28_V	et	f	\N
208390	plaanisid	plaanisid =plaani  (IndIpfPl3  >plaanima !28_V	et	f	\N
208405	jargmiseks	?jargmiseks =jargmise  (SgTr  >jargmine !12?10_A	et	f	\N
208406	jargmiseks	?jargmiseks =jargmise  (KndPrPs  >jargmisema !27_V	et	f	\N
208414	ebarealse	?ebarealse =ebarealse  (SgG  >ebarealne !02_A	et	f	\N
208415	ebarealse	?ebarealse =ebarealse  (PlP  >ebareals !22_S	et	f	\N
208416	ebarealse	?ebarealse =realse  (SgN  >eba+realse !06_S	et	f	\N
208111	suhtmine	?suhtmine =suhtmine  (SgN  >suhtmine !12?10_A	et	f	\N
208112	suhtmine	?suhtmine =suhtmine  (IndPrPs_  >suhtminema !27_V	et	f	\N
208113	suhtmine	?suhtmine =suhtmine  (ImpPrSg2  >suhtminema !27_V	et	f	\N
208114	imotsioni	?imotsioni =imotsio  (SgTer  >imotsio !01_S	et	f	\N
208115	imotsioni	?imotsioni =imotsioni  (SgN  >imotsioni !16_S	et	f	\N
208116	imotsioni	?imotsioni =imotsioni  (SgG  >imotsion !19~02_S	et	f	\N
208117	imotsioni	?imotsioni =imotsioni  (SgG  >imotsioni !16_S	et	f	\N
208118	imotsioni	?imotsioni =imotsioni  (SgP  >imotsion !19_S	et	f	\N
208119	imotsioni	?imotsioni =imotsioni  (SgAdt  >imotsion !19_S	et	f	\N
208120	imotsioni	?imotsioni =imotsioni  (IndPrPs_  >imotsionima !28_V	et	f	\N
208121	imotsioni	?imotsioni =imotsioni  (ImpPrSg2  >imotsionima !28_V	et	f	\N
208126	kursudesse	?kursudesse =kursu  (PlIll  >kursu !16_S	et	f	\N
208127	kursudesse	?kursudesse =kursudes  (SgAdt  >kursudene !12_A	et	f	\N
208128	kursudesse	?kursudesse =kursudesse  (SgG  >kursudesne !02_A	et	f	\N
208129	kursudesse	?kursudesse =kursudesse  (PlP  >kursudess !22_S	et	f	\N
208133	humanitaasium	?humanitaasium =humanitaasium  (SgN  >humanitaasium !19~02_S	et	f	\N
208134	kärjääri	?kärjääri =kärjääri  (SgN  >kärjääri !16_S	et	f	\N
208135	kärjääri	?kärjääri =kärjääri  (SgG  >kärjääri !16_S	et	f	\N
208136	kärjääri	?kärjääri =kärjääri  (SgG  >kärjäär !22_S	et	f	\N
208137	kärjääri	?kärjääri =kärjääri  (SgP  >kärjäär !22_S	et	f	\N
208138	kärjääri	?kärjääri =kärjääri  (SgAdt  >kärjäär !22_S	et	f	\N
208139	kärjääri	?kärjääri =kärjääri  (IndPrPs_  >kärjäärima !28_V	et	f	\N
208140	kärjääri	?kärjääri =kärjääri  (ImpPrSg2  >kärjäärima !28_V	et	f	\N
208189	eeestis	?eeestis =eeesti  (IndIpfSg3  >eeestima !28_V	et	f	\N
208190	eeestis	?eeestis =eeestis  (SgN  >eeestis !11_S	et	f	\N
208193	kolmekumne	?kolmekumne =kolmekumne  (SgN  >kolmekumne !02_A	et	f	\N
208194	kolmekumne	?kolmekumne =kolmekumne  (PlP  >kolmekumn !22_S	et	f	\N
208195	kolmekumne	?kolmekumne =kumne  (SgN  >kolme+kumne !02_A	et	f	\N
208196	kolmekumne	?kolmekumne =kumne  (PlP  >kolme+kumn !22_S	et	f	\N
208197	kolmekumne	?kolmekumne =ekumne  (SgN  >kolm+ekumne !02_A	et	f	\N
208198	kolmekumne	?kolmekumne =ekumne  (PlP  >kolm+ekumn !22_S	et	f	\N
208199	üheksasajas	?üheksasajas =üheksasaja  (SgIn  >üheksasaja !01_S	et	f	\N
208200	üheksasajas	?üheksasajas =üheksasaja  (SgIn  >üheksasajas !02_A	et	f	\N
208201	üheksasajas	?üheksasajas =üheksasajas  (SgN  >üheksasajas !02_A	et	f	\N
208202	üheksasajas	?üheksasajas =saja  (SgIn  >üheksa+saja !17_S	et	f	\N
208203	üheksasajas	?üheksasajas =asaja  (SgIn  >üheks+asaja !01_S	et	f	\N
208204	üheksasajas	?üheksasajas =asaja  (SgIn  >üheks+asajas !02_A	et	f	\N
208205	üheksasajas	?üheksasajas =asajas  (SgN  >üheks+asajas !02_A	et	f	\N
208206	üheksasajas	?üheksasajas =ksasaja  (SgIn  >ühe+ksasaja !01_S	et	f	\N
208207	üheksasajas	?üheksasajas =ksasaja  (SgIn  >ühe+ksasajas !02_A	et	f	\N
208208	üheksasajas	?üheksasajas =ksasajas  (SgN  >ühe+ksasajas !02_A	et	f	\N
208212	planeerist	?planeerist =planeeri  (SgEl  >planeeri !16_S	et	f	\N
208213	planeerist	?planeerist =planeeri  (SgEl  >planeer !22_S	et	f	\N
208214	planeerist	?planeerist =planeeris  (SgP  >planeeris !09_S	et	f	\N
208226	pidides	?pidides =pidi  (Ger  >pidima !27_V	et	f	\N
208230	tagasihoidlikut	?tagasihoidlikut =hoidliku  (SgP  >tagasi+hoidliku !01_S	et	f	\N
208232	tallinnal	?tallinnal =tallinna  (SgAd  >tallinna !16_S	et	f	\N
208238	murdasib	### murdasib	et	f	\N
208248	planeritud	?planeritud =planeritu  (PlN  >planeritu !01_A	et	f	\N
208249	planeritud	?planeritud =planeritu  (IndPrSg2  >planerituma !27_V	et	f	\N
208250	planeritud	?planeritud =planeritud  (ID  >planeritud !41_A	et	f	\N
208279	etenda	etenda =etenda  (IndPrPs_  >etendama !27_V	et	f	\N
208280	etenda	etenda =etenda  (ImpPrSg2  >etendama !27_V	et	f	\N
208281	tagasihoidlijak	### tagasihoidlijak	et	f	\N
208309	eeest	?eeest =eee  (SgEl  >eee !26_S	et	f	\N
208310	eeest	?eeest =eees  (SgP  >eeene !12~10_A	et	f	\N
208316	sõbradena	?sõbradena =sõbra  (PlEs  >sõbra !16_S	et	f	\N
208320	süünnipäev	?süünnipäev =süünnipäev  (SgN  >süünnipäev !22_S	et	f	\N
208350	tennida	?tennida =tenni  (Inf  >tennima !28_V	et	f	\N
208355	kuused	kuused =kuuse  (PlN  >kuune !10_A	et	f	\N
208356	kuused	"kuune %kuu  )NE_aA  <kuu ;26_S	et	f	\N
208357	kuused	kuused =kuuse  (PlN  >kuusk !22_S	et	f	\N
208361	lumesõjat	?lumesõjat =lumesõja  (SgP  >lumesõjas !02_A	et	f	\N
208362	lumesõjat	?lumesõjat =lumesõja  (SgP  >lumesõja !16_S	et	f	\N
208363	lumesõjat	?lumesõjat =sõjat  (SgN  >lume+sõjat !02_S	et	f	\N
208366	oosta	?oosta =oost  (Inf  >oostma !34_V	et	f	\N
208367	oosta	?oosta =oosta  (SgN  >oosta !01_S	et	f	\N
208368	oosta	?oosta =oosta  (SgG  >oosta !01_S	et	f	\N
208369	oosta	?oosta =oosta  (IndPrPs_  >oostama !27_V	et	f	\N
208370	oosta	?oosta =oosta  (ImpPrSg2  >oostama !27_V	et	f	\N
208374	siri	?siri =siri  (SgN  >siri !17_S	et	f	\N
208375	siri	?siri =siri  (SgG  >siri !17_S	et	f	\N
208376	siri	?siri =siri  (SgP  >siri !17_S	et	f	\N
208377	siri	?siri =siri  (IndPrPs_  >sirima !27_V	et	f	\N
208378	siri	?siri =siri  (ImpPrSg2  >sirima !27_V	et	f	\N
208149	gümnasiumi	?gümnasiumi =gümnasiumi  (SgN  >gümnasiumi !16_S	et	f	\N
208150	gümnasiumi	?gümnasiumi =gümnasiumi  (SgG  >gümnasiumi !16_S	et	f	\N
208151	gümnasiumi	?gümnasiumi =gümnasiumi  (SgG  >gümnasium !19_S	et	f	\N
208152	gümnasiumi	?gümnasiumi =gümnasiumi  (SgP  >gümnasium !19_S	et	f	\N
208153	gümnasiumi	?gümnasiumi =gümnasiumi  (SgAdt  >gümnasium !19_S	et	f	\N
208154	gümnasiumi	?gümnasiumi =gümnasiumi  (IndPrPs_  >gümnasiumima !28_V	et	f	\N
208155	gümnasiumi	?gümnasiumi =gümnasiumi  (ImpPrSg2  >gümnasiumima !28_V	et	f	\N
208181	suhutuvad	?suhutuvad =suhutu  (IndPrPl3  >suhutuma !27_V	et	f	\N
208182	suhutuvad	?suhutuvad =suhutuva  (PlN  >suhutuv !02_A	et	f	\N
208183	suhutuvad	?suhutuvad =suhutuva  (PlN  >suhutuva !16_S	et	f	\N
208184	tervest	tervest =terve  (SgEl  >terve !01_AS	et	f	\N
208185	tervest	tervest =terve  (SgEl  >terve !06_AS	et	f	\N
208227	tansides	?tansides =tansi  (PlIn  >tansi !16_S	et	f	\N
208228	tansides	?tansides =tansi  (PlIn  >tans !22_S	et	f	\N
208229	tansides	?tansides =tansi  (Ger  >tansima !28_V	et	f	\N
208234	vabakutselisid	### vabakutselisid	et	f	\N
208241	utle	?utle =utle  (SgN  >utle !06_S	et	f	\N
208242	utle	?utle =utle  (IndPrPs_  >utlema !30_V	et	f	\N
208243	utle	?utle =utle  (ImpPrSg2  >utlema !30_V	et	f	\N
208269	vabakutsevad	?vabakutsevad =vabakutse  (IndPrPl3  >vabakutsema !27_V	et	f	\N
208270	vabakutsevad	?vabakutsevad =vabakutseva  (PlN  >vabakutsev !02_A	et	f	\N
208271	vabakutsevad	?vabakutsevad =vabakutseva  (PlN  >vabakutseva !16_S	et	f	\N
208272	vabakutsevad	?vabakutsevad =kutseva  (PlN  >vaba+kutseva !01_S	et	f	\N
208273	vabakutsevad	?vabakutsevad =kutseva  (PlN  >vaba+kutsev !02_A	et	f	\N
208278	nooresed	?nooresed =noorese  (PlN  >noorene !10_A	et	f	\N
208284	seitsemdast	?seitsemdast =seitsemda  (SgEl  >seitsemda !01_S	et	f	\N
208285	seitsemdast	?seitsemdast =seitsemdas  (SgP  >seitsemdane !12_A	et	f	\N
208306	huhtuvad	?huhtuvad =huhtu  (IndPrPl3  >huhtuma !27_V	et	f	\N
208307	huhtuvad	?huhtuvad =huhtuva  (PlN  >huhtuva !01_S	et	f	\N
208308	huhtuvad	?huhtuvad =huhtuva  (PlN  >huhtuv !02_A	et	f	\N
208311	tasakalule	tasakalule =kalu  (SgAll  >tasa+kalu !17_S	et	f	\N
208312	tasakalule	tasakalule =kalu  (PlAll  >tasa+kala !17_S	et	f	\N
208317	ärgmine	?ärgmine =ärgmine  (SgN  >ärgmine !12?10_A	et	f	\N
208318	ärgmine	?ärgmine =ärgmine  (IndPrPs_  >ärgminema !27_V	et	f	\N
208319	ärgmine	?ärgmine =ärgmine  (ImpPrSg2  >ärgminema !27_V	et	f	\N
208325	surem	?surem =surem  (SgN  >surem !02_A	et	f	\N
208338	englisemaal	?englisemaal =englisemaa  (SgAd  >englisemaa !26_S	et	f	\N
208339	englisemaal	?englisemaal =englisemaal  (SgN  >englisemaal !22_S	et	f	\N
208340	niisugume	?niisugume =niisugu  (IndPrPl1  >niisuguma !27_V	et	f	\N
208341	niisugume	?niisugume =niisugume  (PlP  >niisugum !19_S	et	f	\N
208345	pahat	?pahat =pahat  (SgN  >pahat !02_S	et	f	\N
208353	maalilise	maalilise =maalilise  (SgG  >maaliline !12_A	et	f	\N
208354	maalilise	"maaliline %maali  )LINE_aA  <maal ;22_S	et	f	\N
208371	iraakis	?iraakis =iraaki  (SgIn  >iraaki !16_S	et	f	\N
208372	iraakis	?iraakis =iraaki  (IndIpfSg3  >iraakima !28_V	et	f	\N
208373	iraakis	?iraakis =iraakis  (SgN  >iraakis !11_S	et	f	\N
208410	uskun	?uskun =uskun  (SgN  >uskun !02_S	et	f	\N
208437	koruses	?koruses =koruse  (SgIn  >korus !09_S	et	f	\N
208440	mailmaas	?mailmaas =mailmaa  (SgIn  >mailmaa !26_S	et	f	\N
208441	mailmaas	?mailmaas =mailmaas  (SgN  >mailmaas !22_S	et	f	\N
208444	jorkis	?jorkis =jorki  (IndIpfSg3  >jorkima !28_V	et	f	\N
208445	jorkis	?jorkis =jorkis  (ID  >jorkis !41_DA	et	f	\N
208449	jatkada	### jatkada	et	f	\N
208461	mõlkid	### mõlkid	et	f	\N
208503	simmestri	?simmestri =simmestri  (SgN  >simmestri !01_S	et	f	\N
208504	simmestri	?simmestri =simmestri  (SgG  >simmestri !01_S	et	f	\N
208505	simmestri	?simmestri =simmestri  (SgG  >simmester !02_S	et	f	\N
208506	simmestri	?simmestri =simmestri  (IndPrPs_  >simmestrima !28_V	et	f	\N
208507	simmestri	?simmestri =simmestri  (ImpPrSg2  >simmestrima !28_V	et	f	\N
208508	armastatut	armastatut =armastatu  (SgP  >armastatu !01_S	et	f	\N
208509	armastatut	"armastatu %armasta  )TU1_vS  <armastama ;27_V	et	f	\N
208523	väikeks	väikeks =keks  (SgN  >väi+keks !22_S	et	f	\N
208524	väikeks	väikeks =keks  (SgN  >väi+keks !22_A	et	f	\N
208532	kõikidelt	kõikidelt =kõiki  (PlAbl  >kõik !00_P	et	f	\N
208533	kõikidelt	kõikidelt =kõiki  (PlAbl  >kõik !22_S	et	f	\N
208537	migadi	?migadi =migadi  (SgN  >migadi !01_S	et	f	\N
208538	migadi	?migadi =migadi  (SgG  >migadi !01_S	et	f	\N
208554	öteppäle	?öteppäle =öteppäle  (PlP  >öteppäl !19_S	et	f	\N
208555	sõdan	?sõdan =sõda  (IndPrSg1  >sõdama !27_V	et	f	\N
208556	sõdan	?sõdan =sõdan  (SgN  >sõdan !02_S	et	f	\N
208559	eeksamid	?eeksamid =eeksami  (PlN  >eeksami !01_S	et	f	\N
208560	eeksamid	?eeksamid =eeksami  (PlN  >eeksam !02_A	et	f	\N
208561	eeriti	?eeriti =eeri  (IndIpfIps  >eerima !28_V	et	f	\N
208562	eeriti	?eeriti =eeriti  (ID  >eeriti !41_D	et	f	\N
208563	eeriti	?eeriti =eeriti  (SgG  >eerit !02_S	et	f	\N
208564	eeriti	?eeriti =eeriti  (SgG  >eeritt !22_S	et	f	\N
208565	eeriti	?eeriti =eeriti  (IndPrPs_  >eerittima !28_V	et	f	\N
208233	ükstuhat	?ükstuhat =ükstuha  (SgP  >ükstuha !01_S	et	f	\N
208244	tuhahande	?tuhahande =tuhahande  (PlP  >tuhahand !22_S	et	f	\N
208245	tuhahande	?tuhahande =hande  (SgN  >tuha+hande !06_S	et	f	\N
208246	tuhahande	?tuhahande =hande  (SgG  >tuha+hanne !06_S	et	f	\N
208247	tuhahande	?tuhahande =hande  (PlP  >tuha+hand !22_S	et	f	\N
208251	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =tuhandeüheksasajaüheksakumneseitsmenda  (SgTer  >tuhandeüheksasajaüheksakumneseitsmenda !16_S	et	f	\N
208252	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =tuhandeüheksasajaüheksakumneseitsmendani  (SgG  >tuhandeüheksasajaüheksakumneseitsmendan !02_S	et	f	\N
208253	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =kumneseitsmenda  (SgTer  >tuhande+üheksa+saja+üheksa+kumneseitsmenda !16_S	et	f	\N
208254	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =kumneseitsmendani  (SgG  >tuhande+üheksa+saja+üheksa+kumneseitsmendan !02_S	et	f	\N
208255	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =akumneseitsmenda  (SgTer  >tuhande+üheksa+saja+üheks+akumneseitsmenda !16_S	et	f	\N
208256	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =akumneseitsmendani  (SgG  >tuhande+üheksa+saja+üheks+akumneseitsmendan !02_S	et	f	\N
208257	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =ksakumneseitsmenda  (SgTer  >tuhande+üheksa+saja+ühe+ksakumneseitsmenda !16_S	et	f	\N
208258	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =ksakumneseitsmendani  (SgG  >tuhande+üheksa+saja+ühe+ksakumneseitsmendan !02_S	et	f	\N
208259	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =üheksakumneseitsmenda  (SgTer  >tuhande+üheksa+saja+üheksakumneseitsmenda !16_S	et	f	\N
208260	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =üheksakumneseitsmendani  (SgG  >tuhande+üheksa+saja+üheksakumneseitsmendan !02_S	et	f	\N
208261	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =sajaüheksakumneseitsmenda  (SgTer  >tuhande+üheksa+sajaüheksakumneseitsmenda !16_S	et	f	\N
208262	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =sajaüheksakumneseitsmendani  (SgG  >tuhande+üheksa+sajaüheksakumneseitsmendan !02_S	et	f	\N
208263	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =asajaüheksakumneseitsmenda  (SgTer  >tuhande+üheks+asajaüheksakumneseitsmenda !16_S	et	f	\N
208264	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =asajaüheksakumneseitsmendani  (SgG  >tuhande+üheks+asajaüheksakumneseitsmendan !02_S	et	f	\N
208265	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =ksasajaüheksakumneseitsmenda  (SgTer  >tuhande+ühe+ksasajaüheksakumneseitsmenda !16_S	et	f	\N
208266	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =ksasajaüheksakumneseitsmendani  (SgG  >tuhande+ühe+ksasajaüheksakumneseitsmendan !02_S	et	f	\N
208267	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =üheksasajaüheksakumneseitsmenda  (SgTer  >tuhande+üheksasajaüheksakumneseitsmenda !16_S	et	f	\N
208268	tuhandeüheksasajaüheksakumneseitsmendani	?tuhandeüheksasajaüheksakumneseitsmendani =üheksasajaüheksakumneseitsmendani  (SgG  >tuhande+üheksasajaüheksakumneseitsmendan !02_S	et	f	\N
208276	planerimis	?planerimis =planerimi  (SgIn  >planerim !02_A	et	f	\N
208277	planerimis	?planerimis =planerimis  (SgN  >planerimis !09_S	et	f	\N
208294	üheksakümenda	?üheksakümenda =üheksakümenda  (SgN  >üheksakümenda !16_S	et	f	\N
208295	üheksakümenda	?üheksakümenda =üheksakümenda  (SgG  >üheksakümenda !16_S	et	f	\N
208296	üheksakümenda	?üheksakümenda =üheksakümenda  (IndPrPs_  >üheksakümendama !27_V	et	f	\N
208297	üheksakümenda	?üheksakümenda =üheksakümenda  (ImpPrSg2  >üheksakümendama !27_V	et	f	\N
208298	üheksakümenda	?üheksakümenda =kümenda  (SgN  >üheksa+kümenda !01_S	et	f	\N
208299	üheksakümenda	?üheksakümenda =kümenda  (SgG  >üheksa+kümenda !01_S	et	f	\N
208300	üheksakümenda	?üheksakümenda =akümenda  (SgN  >üheks+akümenda !16_S	et	f	\N
208301	üheksakümenda	?üheksakümenda =akümenda  (SgG  >üheks+akümenda !16_S	et	f	\N
208302	üheksakümenda	?üheksakümenda =ksakümenda  (SgN  >ühe+ksakümenda !16_S	et	f	\N
208303	üheksakümenda	?üheksakümenda =ksakümenda  (SgG  >ühe+ksakümenda !16_S	et	f	\N
208304	teatrises	?teatrises =teatrise  (SgIn  >teatris !09_S	et	f	\N
208305	teatrises	?teatrises =teatrise  (IndIpfSg3  >teatrisema !27_V	et	f	\N
208321	pidustada	?pidustada =pidusta  (Inf  >pidustama !27_V	et	f	\N
208322	pidustada	?pidustada =stada  (SgN  >pidu+stada !17_S	et	f	\N
208323	pidustada	?pidustada =stada  (SgG  >pidu+stada !17_S	et	f	\N
208324	pidustada	?pidustada =stada  (SgP  >pidu+stada !17_S	et	f	\N
208342	unitused	?unitused =unituse  (PlN  >unitus !11_S	et	f	\N
208343	unitused	?unitused =tuse  (PlN  >uni+tuse !16_S	et	f	\N
208346	seesia	?seesia =seesia  (SgN  >seesia !01_S	et	f	\N
208347	seesia	?seesia =seesia  (SgG  >seesia !01_S	et	f	\N
208348	seesia	?seesia =sia  (SgN  >see+sia !26_S	et	f	\N
208349	seesia	?seesia =sia  (SgG  >see+sia !26_S	et	f	\N
208351	iseisav	?iseisav =iseisav  (SgN  >iseisav !02_A	et	f	\N
208352	iseisav	?iseisav =isav  (SgN  >ise+isav !02_A	et	f	\N
208358	tumeroheline	tumeroheline =roheline  (SgN  >tume+roheline !12_A	et	f	\N
208359	tumeroheline	"tume+roheline %rohe  )LINE_aA  <tume+rohe ;16_S	et	f	\N
208394	plaaneerinud	?plaaneerinud =plaaneeri  (PtsPtPs  >plaaneerima !28_V	et	f	\N
208395	plaaneerinud	?plaaneerinud =plaaneerinu  (PlN  >plaaneerinu !01_S	et	f	\N
208396	plaaneerinud	?plaaneerinud =plaaneerinu  (IndPrSg2  >plaaneerinuma !27_V	et	f	\N
208397	plaaneerinud	?plaaneerinud =plaaneerinud  (ID  >plaaneerinud !41_A	et	f	\N
208409	lehege	?lehege =lehe  (ImpPrPl2  >lehema !27_V	et	f	\N
208411	kahekümnes	?kahekümnes =kahekümne  (PlIn  >kahekümn !22_S	et	f	\N
208412	kahekümnes	?kahekümnes =kümne  (PlIn  >kahe+kümn !22_S	et	f	\N
208420	stüpeendia	?stüpeendia =stüpeendia  (SgN  >stüpeendia !01_S	et	f	\N
208421	stüpeendia	?stüpeendia =stüpeendia  (SgG  >stüpeendia !01_S	et	f	\N
208435	ühislamuses	?ühislamuses =ühislamuse  (SgIn  >ühislamus !11?09_S	et	f	\N
208436	ühislamuses	?ühislamuses =lamuse  (SgIn  >ühis+lamus !09_S	et	f	\N
208450	õppeasutusesse	õppeasutusesse =asutuse  (SgIll  >õppe+asutus !11_S	et	f	\N
208451	õppeasutusesse	"õppe+asutus %asu  )TUS2_aS  <õppe+asu ;17_S	et	f	\N
208452	õppeasutusesse	õppeasutusesse =asutuses  (SgAdt  >õppe+asutusene !12_A	et	f	\N
208453	õppeasutusesse	"õppe+asutusene %asutuse  )NE_aA  <õppe+asutus ;11_S	et	f	\N
208459	tudendit	?tudendit =tudendi  (SgP  >tudendi !01_S	et	f	\N
208460	tudendit	?tudendit =tudendi  (SgP  >tudend !02_S	et	f	\N
208462	uus-aastasooviat	?uus-aastasooviat =aastasoovia  (SgP  >uus-aastasoovia !01_S	et	f	\N
208463	uus-aastasooviat	?uus-aastasooviat =aastasooviat  (SgN  >uus-aastasooviat !22_S	et	f	\N
208464	uus-aastasooviat	?uus-aastasooviat =viat  (SgN  >uus-aasta+soo+viat !22_S	et	f	\N
208465	uus-aastasooviat	?uus-aastasooviat =soovia  (SgP  >uus-aasta+soovia !01_S	et	f	\N
208466	uus-aastasooviat	?uus-aastasooviat =sooviat  (SgN  >uus-aasta+sooviat !22_S	et	f	\N
208467	uus-aastasooviat	?uus-aastasooviat =tasoovia  (SgP  >uus-aas+tasoovia !01_S	et	f	\N
208468	uus-aastasooviat	?uus-aastasooviat =tasooviat  (SgN  >uus-aas+tasooviat !22_S	et	f	\N
208469	majat	?majat =majat  (SgN  >majat !02_S	et	f	\N
208478	lihne	?lihne =lihne  (SgN  >lihne !02_A	et	f	\N
208479	lihne	?lihne =lihne  (PlP  >lihn !22_S	et	f	\N
208480	lihne	?lihne =lihne  (IndPrPs_  >lihnema !27_V	et	f	\N
208481	lihne	?lihne =lihne  (ImpPrSg2  >lihnema !27_V	et	f	\N
208484	maatanalüsis	?maatanalüsis =maatanalüsis  (SgN  >maatanalüsis !09_S	et	f	\N
208485	maatanalüsis	?maatanalüsis =tanalüsis  (SgN  >maa+tanalüsis !09_S	et	f	\N
208517	lupus	?lupus =lupu  (SgIn  >lupu !16_S	et	f	\N
208518	lupus	?lupus =lupu  (IndIpfSg3  >lupuma !27_V	et	f	\N
208519	lupus	?lupus =lupus  (SgN  >lupus !09_S	et	f	\N
208527	esimeks	?esimeks =meks  (SgN  >esi+meks !22_S	et	f	\N
208534	rahulikust	rahulikust =rahuliku  (SgEl  >rahulik !25_A	et	f	\N
208535	rahulikust	rahulikust =rahulikus  (SgP  >rahulikus !11?09_S	et	f	\N
208536	rahulikust	"rahulikus %rahuliku  )US_aS  <rahulik ;25_A	et	f	\N
208547	matkata	matkata =matka  (SgAb  >matk !22_S	et	f	\N
208548	matkata	matkata =matka  (Inf  >matkama !29_V	et	f	\N
208549	matkata	matkata =matka  (IndPrIps_  >matkama !29_V	et	f	\N
208557	minnen	?minnen =minne  (IndPrSg1  >minnema !27_V	et	f	\N
208558	minnen	?minnen =minnen  (SgN  >minnen !02_S	et	f	\N
208567	küllustada	?küllustada =küllusta  (Inf  >küllustama !27_V	et	f	\N
208609	lootusi	lootusi =lootusi  (PlP  >lootus !11_S	et	f	\N
208610	lootusi	"lootus %loo  )TUS2_aS  <lugu ;18_S	et	f	\N
208611	lootusi	"lootus %loo  )TUS2_aS  <loog ;22_S	et	f	\N
208612	lootusi	"lootus %loo  )TUS2_aS  <lood ;22_S	et	f	\N
208634	soritan	?soritan =sorita  (IndPrSg1  >soritama !27_V	et	f	\N
208635	soritan	?soritan =soritan  (SgN  >soritan !19_S	et	f	\N
208636	kingitatakse	?kingitatakse =kingita  (IndPrIps  >kingitama !27_V	et	f	\N
208637	kingitatakse	?kingitatakse =kingitatakse  (SgG  >kingitatakne !02_A	et	f	\N
208638	kingitatakse	?kingitatakse =kingitatakse  (PlP  >kingitataks !22_S	et	f	\N
208639	kingitatakse	?kingitatakse =tatakse  (SgG  >kingi+tatakne !02_A	et	f	\N
208640	kingitatakse	?kingitatakse =itatakse  (SgG  >king+itatakne !02_A	et	f	\N
208641	kingitatakse	?kingitatakse =itatakse  (PlP  >king+itataks !22_S	et	f	\N
208643	semptembrist	?semptembrist =semptembri  (SgEl  >semptembri !01_S	et	f	\N
208644	semptembrist	?semptembrist =semptembri  (SgEl  >semptember !02_S	et	f	\N
208645	semptembrist	?semptembrist =semptembris  (SgP  >semptembris !11_S	et	f	\N
208646	semptembrist	?semptembrist =semptembrist  (SgN  >semptembrist !22_S	et	f	\N
208665	võimatut	võimatut =võimatu  (SgP  >võimatu !01_A	et	f	\N
208666	võimatut	"võimatu %või  )MATU_vA  <võima ;37_V	et	f	\N
208673	pegelased	?pegelased =pegelase  (PlN  >pegelane !12_S	et	f	\N
208675	poliitilis	?poliitilis =poliitilis  (SgN  >poliitilis !09_S	et	f	\N
208676	poliitilis	?poliitilis =ili  (SgIn  >poliit+ili !17_S	et	f	\N
208677	poliitilis	?poliitilis =ilis  (SgN  >poliit+ilis !09_S	et	f	\N
208701	nsv-liidus	nsv-liidus =liidu  (SgIn  >nsv-liit !22_S	et	f	\N
208702	nsv-liidus	nsv-liidus =liidus  (SgN  >nsv-liidus !09_S	et	f	\N
208713	hääletamise	hääletamise =hääletamise  (SgG  >hääletamine !12_S	et	f	\N
208714	hääletamise	"hääletamine %hääleta  )MINE_vS  <hääletama ;27_V	et	f	\N
208715	kaitsid	?kaitsid =kait  (IndIpfSg2  >kaitma !34_V	et	f	\N
208716	kaitsid	?kaitsid =kait  (IndIpfPl3  >kaitma !34_V	et	f	\N
208717	kaitsid	?kaitsid =kaitsi  (PlN  >kaits !22_S	et	f	\N
208718	kaitsid	?kaitsid =kaitsi  (IndPrSg2  >kaitsima !28_V	et	f	\N
208719	võiduks	võiduks =või  (KndPtIps  >võima !37_V	et	f	\N
208720	võiduks	võiduks =võidu  (SgTr  >võidu !01_S	et	f	\N
208403	uus-aasta	uus-aasta =aasta  (SgN  >uus-aasta !01_S	et	f	\N
208404	uus-aasta	uus-aasta =aasta  (SgG  >uus-aasta !01_S	et	f	\N
208422	õpeb	?õpeb =õpe  (IndPrSg3  >õpema !27_V	et	f	\N
208425	regestratsionidele	?regestratsionidele =regestratsioni  (PlAll  >regestratsioni !16_S	et	f	\N
208426	regestratsionidele	?regestratsionidele =regestratsioni  (PlAll  >regestratsion !19_S	et	f	\N
208488	jõuluvana	jõuluvana =vana  (SgN  >jõulu+vana !17_AS	et	f	\N
208489	jõuluvana	jõuluvana =vana  (SgG  >jõulu+vana !17_AS	et	f	\N
208490	jõuluvana	jõuluvana =vana  (SgP  >jõulu+vana !17_AS	et	f	\N
208491	õnnelikut	### õnnelikut	et	f	\N
208498	sügi-	?sügi- =sügi  (SgN  >sügi !17_S	et	f	\N
208499	sügi-	?sügi- =sügi  (SgG  >sügi !17_S	et	f	\N
208500	sügi-	?sügi- =sügi  (SgP  >sügi !17_S	et	f	\N
208501	sügi-	?sügi- =sügi  (IndPrPs_  >sügima !27_V	et	f	\N
208502	sügi-	?sügi- =sügi  (ImpPrSg2  >sügima !27_V	et	f	\N
208510	leidaksin	?leidaksin =leida  (KndPrSg1  >leidama !29_V	et	f	\N
208511	leidaksin	?leidaksin =leidaksi  (IndPrSg1  >leidaksima !28_V	et	f	\N
208512	leidaksin	?leidaksin =leidaksin  (SgN  >leidaksin !19_S	et	f	\N
208513	leidaksin	?leidaksin =aksin  (SgN  >leid+aksin !02_S	et	f	\N
208542	saanu	saanu =saanu  (SgN  >saanu !01_S	et	f	\N
208543	saanu	"saanu %saa  )NU_vS  <saama ;37_V	et	f	\N
208544	saanu	saanu =saanu  (SgN  >saanu !06_S	et	f	\N
208545	saanu	saanu =saanu  (SgG  >saanu !01_S	et	f	\N
208546	saanu	saanu =saanu  (SgG  >saanu !06_S	et	f	\N
208571	pskovil	?pskovil =pskovi  (SgAd  >pskovi !17_S	et	f	\N
208583	töidega	?töidega =töi  (PlKom  >töi !26_S	et	f	\N
208588	piimatoid	piimatoid =toi  (PlN  >piima+toi !26_S	et	f	\N
208589	piimatoid	piimatoid =toi  (SgP  >piima+toi !26_S	et	f	\N
208608	barcelona	?barcelona =barcelo  (SgEs  >barcelo !01_S	et	f	\N
208621	türgisse	?türgisse =türgi  (SgIll  >türk !22_S	et	f	\N
208622	türgisse	?türgisse =türgisse  (SgG  >türgisne !02_A	et	f	\N
208623	türgisse	?türgisse =türgisse  (PlP  >türgiss !22_S	et	f	\N
208626	otta	?otta =otta  (ID  >otta !41_D	et	f	\N
208627	otta	?otta =otta  (IndPrPs_  >ottama !29_V	et	f	\N
208628	otta	?otta =otta  (ImpPrSg2  >ottama !29_V	et	f	\N
208647	jõulumeeleolu	jõulumeeleolu =olu  (SgN  >jõulu+meele+olu !17_S	et	f	\N
208648	jõulumeeleolu	jõulumeeleolu =olu  (SgG  >jõulu+meele+olu !17_S	et	f	\N
208649	jõulumeeleolu	jõulumeeleolu =olu  (SgP  >jõulu+meele+olu !17_S	et	f	\N
208654	elamist	elamist =elamis  (SgP  >elamine !12_S	et	f	\N
208655	elamist	"elamine %ela  )MINE_vS  <elama ;27_V	et	f	\N
208669	psühholoogilise	psühholoogilise =psühholoogilise  (SgG  >psühholoogiline !12_A	et	f	\N
208670	psühholoogilise	"psühholoogiline %psühholoogi  )LINE_aA  <psühholoog ;22_S	et	f	\N
208671	psühholoogilise	psühholoogilise =loogilise  (SgG  >psühho+loogiline !12_A	et	f	\N
208672	psühholoogilise	"psühho+loogiline %loogi  )LINE_aA  <psühho+loog ;22_S	et	f	\N
208695	elatutaseme	### elatutaseme	et	f	\N
208698	mhint	?mhint =mhint  (SgN  >mhint !22_S	et	f	\N
208737	idealistlikult	idealistlikult =idealistliku  (SgAbl  >idealistlik !25_A	et	f	\N
208739	idealistlikult	idealistlikult =idealistlikult  (ID  >idealistlikult !41_D	et	f	\N
208741	idealistlikult	"idealistlikult %idealistliku  )LT_mD  <idealistlik ;25_A	et	f	\N
208751	gorbatsev	?gorbatsev =gorbatse  (PtsPrPs  >gorbatsema !27_V	et	f	\N
208752	gorbatsev	?gorbatsev =gorbatsev  (SgN  >gorbatsev !02_A	et	f	\N
208760	peati	?peati =peati  (ID  >peati !41_D	et	f	\N
208761	peati	?peati =peati  (SgP  >peat !22_S	et	f	\N
208762	peati	?peati =peati  (SgAdt  >peat !22_S	et	f	\N
208774	kehast	kehast =keha  (SgEl  >keha !17_S	et	f	\N
208775	kehast	kehast =kehas  (SgP  >kehane !10_A	et	f	\N
208776	kehast	"kehane %keha  )NE_aA  <keha ;17_S	et	f	\N
208791	midaja	?midaja =midaja  (SgN  >midaja !01_S	et	f	\N
208792	midaja	?midaja =midaja  (SgG  >midaja !01_S	et	f	\N
208793	midaja	?midaja =midaja  (SgG  >midajas !02_A	et	f	\N
208820	kuritegujad	?kuritegujad =kuriteguja  (PlN  >kuriteguja !01_S	et	f	\N
208821	kuritegujad	?kuritegujad =kuriteguja  (PlN  >kuritegujas !02_A	et	f	\N
208822	kuritegujad	?kuritegujad =teguja  (PlN  >kuri+teguja !01_S	et	f	\N
208823	kuritegujad	?kuritegujad =teguja  (PlN  >kuri+tegujas !02_A	et	f	\N
208825	vanematedes	?vanematedes =tede  (SgIn  >vanema+tede !16_S	et	f	\N
208826	vanematedes	?vanematedes =tedes  (SgN  >vanema+tedes !09_S	et	f	\N
208833	õpetajata	õpetajata =õpetaja  (SgAb  >õpetaja !01_S	et	f	\N
208834	õpetajata	"õpetaja %õpeta  )JA_vS  <õpetama ;27_V	et	f	\N
208865	pöördasin	?pöördasin =pöörda  (IndIpfSg1  >pöördama !27_V	et	f	\N
208866	pöördasin	?pöördasin =pöördasin  (SgN  >pöördasin !19_S	et	f	\N
208867	pöördasin	?pöördasin =asin  (SgN  >pöörd+asin !02_S	et	f	\N
208884	saadabr	?saadabr =saadabr  (SgN  >saadabr !22_S	et	f	\N
208889	pärilikkus	pärilikkus =pärilikkus  (SgN  >pärilikkus !11~09_S	et	f	\N
208890	pärilikkus	"pärilikkus %pärilikku  )US_aS  <pärilik ;25_A	et	f	\N
208893	jgaüks	?jgaüks =jgaüks  (SgN  >jgaüks !22_S	et	f	\N
208905	mõtlemisest	mõtlemisest =mõtlemise  (SgEl  >mõtlemine !12_S	et	f	\N
208906	mõtlemisest	"mõtlemine %mõtle  )MINE_vS  <mõtlema ;30_V	et	f	\N
208417	ebarealse	?ebarealse =realse  (SgG  >eba+realne !02_A	et	f	\N
208418	ebarealse	?ebarealse =realse  (SgG  >eba+realse !06_S	et	f	\N
208419	ebarealse	?ebarealse =realse  (PlP  >eba+reals !22_S	et	f	\N
208423	erinevadele	?erinevadele =erineva  (PlAll  >erineva !16_S	et	f	\N
208424	erinevadele	?erinevadele =neva  (PlAll  >eri+neva !17_S	et	f	\N
208438	kuldroleks	?kuldroleks =kuldrole  (KndPrPs  >kuldrolema !27_V	et	f	\N
208439	kuldroleks	?kuldroleks =role  (SgTr  >kuld+role !16_S	et	f	\N
208446	astasoovid	?astasoovid =astasoovi  (PlN  >astasoovi !16_S	et	f	\N
208447	astasoovid	?astasoovid =astasoovi  (PlN  >astasoov !22_S	et	f	\N
208448	astasoovid	?astasoovid =astasoovi  (IndPrSg2  >astasoovima !28_V	et	f	\N
208454	kinde	?kinde =kinde  (SgN  >kinde !06_S	et	f	\N
208455	kinde	?kinde =kinde  (SgG  >kinne !06_S	et	f	\N
208456	kinde	?kinde =kinde  (PlP  >kind !22_S	et	f	\N
208457	kinde	?kinde =kinde  (IndPrPs_  >kindema !27_V	et	f	\N
208458	kinde	?kinde =kinde  (ImpPrSg2  >kindema !27_V	et	f	\N
208470	miinu	?miinu =miinu  (SgN  >miinu !16_S	et	f	\N
208471	miinu	?miinu =miinu  (SgG  >miinu !16_S	et	f	\N
208472	miinu	?miinu =miinu  (IndPrPs_  >miinuma !28_V	et	f	\N
208473	miinu	?miinu =miinu  (ImpPrSg2  >miinuma !28_V	et	f	\N
208496	võõrlinnas	võõrlinnas =linna  (SgIn  >võõr+linn !22_S	et	f	\N
208497	võõrlinnas	võõrlinnas =linnas  (SgN  >võõr+linnas !09_S	et	f	\N
208553	kooligid	?kooligid =igi  (PlN  >kool+igi !17_S	et	f	\N
208572	kurskus	?kurskus =kursku  (SgIn  >kursku !01_S	et	f	\N
208573	kurskus	?kurskus =kursku  (IndIpfSg3  >kurskuma !27_V	et	f	\N
208574	kurskus	?kurskus =kurskus  (SgN  >kurskus !11~09_S	et	f	\N
208577	õppenud	?õppenud =õppe  (PtsPtPs  >õppema !27_V	et	f	\N
208578	õppenud	?õppenud =õppenu  (PlN  >õppenu !01_S	et	f	\N
208579	õppenud	?õppenud =õppenu  (IndPrSg2  >õppenuma !27_V	et	f	\N
208580	õppenud	?õppenud =õppenud  (ID  >õppenud !41_A	et	f	\N
208581	organilise	organilise =organilise  (SgG  >organiline !12_A	et	f	\N
208582	organilise	"organiline %organi  )LINE_aA  <organ ;02_S	et	f	\N
208596	koi	koi =koi  (SgN  >koi !26_S	et	f	\N
208597	koi	koi =koi  (SgG  >koi !26_S	et	f	\N
208603	motorattast	motorattast =ratta  (SgEl  >moto+ratas !07_S	et	f	\N
208604	motorattast	motorattast =rattas  (SgP  >moto+rattane !12~10_A	et	f	\N
208605	motorattast	"moto+rattane %ratta  )NE_aA  <moto+ratas ;07_S	et	f	\N
208606	madridi	?madridi =madridi  (SgN  >madridi !01_S	et	f	\N
208607	madridi	?madridi =madridi  (SgG  >madridi !01_S	et	f	\N
208613	reaalseks	reaalseks =reaalse  (SgTr  >reaalne !02_A	et	f	\N
208614	reaalseks	reaalseks =seks  (SgN  >reaal+seks !22_S	et	f	\N
208615	reaalseks	reaalseks =alse  (PlTr  >rea+alss !22_S	et	f	\N
208617	tegivderektorina	?tegivderektorina =tegivderektori  (SgEs  >tegivderektor !02_S	et	f	\N
208618	tegivderektorina	?tegivderektorina =tegivderektorina  (SgG  >tegivderektorin !19_S	et	f	\N
208619	tegivderektorina	?tegivderektorina =tegivderektorina  (SgP  >tegivderektorin !19_S	et	f	\N
208620	tegivderektorina	?tegivderektorina =tegivderektorina  (SgAdt  >tegivderektorin !19_S	et	f	\N
208629	häit	?häit =häit  (SgN  >häit !22_S	et	f	\N
208674	traitsioon	?traitsioon =traitsioon  (SgN  >traitsioon !22_S	et	f	\N
208683	töötati	töötati =tööta  (IndIpfIps  >töötama !27_V	et	f	\N
208685	töötati	töötati =tati  (SgG  >töö+tatt !22_S	et	f	\N
208703	tõsiset	### tõsiset	et	f	\N
208710	iseseisvumisdeklaratsiooni	iseseisvumisdeklaratsiooni =deklaratsiooni  (SgG  >ise+seisvumis+deklaratsioon !22_S	et	f	\N
208711	iseseisvumisdeklaratsiooni	iseseisvumisdeklaratsiooni =deklaratsiooni  (SgP  >ise+seisvumis+deklaratsioon !22_S	et	f	\N
208712	iseseisvumisdeklaratsiooni	iseseisvumisdeklaratsiooni =deklaratsiooni  (SgAdt  >ise+seisvumis+deklaratsioon !22_S	et	f	\N
208728	represseeritud	represseeritud =represseeri  (PtsPtIps  >represseerima !28_V	et	f	\N
208729	represseeritud	represseeritud =represseeritu  (PlN  >represseeritu !01_S	et	f	\N
208730	represseeritud	"represseeritu %represseeri  )TU1_vS  <represseerima ;28_V	et	f	\N
208731	represseeritud	represseeritud =represseeritud  (ID  >represseeritud !41_A	et	f	\N
208732	represseeritud	"represseeritud %represseeri  )TUD_vA  <represseerima ;28_V	et	f	\N
208735	laiendus	laiendus =laiendus  (SgN  >laiendus !11_S	et	f	\N
208736	laiendus	"laiendus %laienda  )US_vS  <laiendama ;27_V	et	f	\N
208758	saavutamises	saavutamises =saavutamise  (SgIn  >saavutamine !12_S	et	f	\N
208759	saavutamises	"saavutamine %saavuta  )MINE_vS  <saavutama ;27_V	et	f	\N
208770	paremina	paremina =paremi  (SgEs  >parem !02_A	et	f	\N
208771	paremina	"parem %pare  )M_cA  <hea ;26_A	et	f	\N
208777	keskealistel	keskealistel =ealis  (PlAd  >kesk+ealine !12?10_A	et	f	\N
208778	keskealistel	"kesk+ealine %ea  )LINE_aA  <kesk+iga ;18_S	et	f	\N
208780	toitmine	toitmine =toitmine  (SgN  >toitmine !12?10_S	et	f	\N
208781	toitmine	"toitmine %toit  )MINE_vS  <toitma ;34_V	et	f	\N
208786	valgu	valgu =valgu  (SgG  >valk !22_S	et	f	\N
208787	valgu	valgu =valgu  (IndPrPs_  >valguma !27_V	et	f	\N
208788	valgu	valgu =valgu  (ImpPrSg2  >valguma !27_V	et	f	\N
208817	etikeet	?etikeet =etikeet  (SgN  >etikeet !22_S	et	f	\N
208824	kollegid	### kollegid	et	f	\N
208827	õppeainedele	?õppeainedele =õppeaine  (PlAll  >õppeaine !16_S	et	f	\N
208514	värvilisem	värvilisem =värvilisem  (SgN  >värvilisem !02_A	et	f	\N
208515	värvilisem	"värvilisem %värvi  )LISEM_cA  <värv ;22_S	et	f	\N
208516	värvilisem	"värvilisem %värvilise  )M_cA  <värviline ;12_A	et	f	\N
208520	aastaas	?aastaas =aastaa  (SgIn  >aastaa !26_S	et	f	\N
208521	aastaas	?aastaas =aastaas  (SgN  >aastaas !22_S	et	f	\N
208522	aastaas	?aastaas =taa  (SgIn  >aas+taa !26_S	et	f	\N
208525	jõulut	?jõulut =jõulu  (SgP  >jõulu !16_S	et	f	\N
208526	jõulut	?jõulut =jõulut  (SgN  >jõulut !02_S	et	f	\N
208528	ühiselamust	ühiselamust =elamu  (SgEl  >ühis+elamu !01_S	et	f	\N
208529	ühiselamust	ühiselamust =elamus  (SgP  >ühis+elamus !11_S	et	f	\N
208530	meelelahetusele	meelelahetusele =lahetuse  (SgAll  >meele+lahetus !11_S	et	f	\N
208531	meelelahetusele	"meele+lahetus %lahe  )TUS2_aS  <meele+laht ;22_S	et	f	\N
208539	eksamisession	?eksamisession =eksamisession  (SgN  >eksamisession !19~02_S	et	f	\N
208540	eksamisession	?eksamisession =session  (SgN  >eksami+session !19~02_S	et	f	\N
208541	eksamisession	?eksamisession =amisession  (SgN  >eks+amisession !19~02_S	et	f	\N
208550	suhtlemisele	suhtlemisele =suhtlemise  (SgAll  >suhtlemine !12_S	et	f	\N
208551	suhtlemisele	"suhtlemine %suhtle  )MINE_vS  <suhtlema ;30_V	et	f	\N
208552	2006a	### 2006a	et	f	\N
208576	eesitada	?eesitada =eesita  (Inf  >eesitama !27_V	et	f	\N
208586	organiline	organiline =organiline  (SgN  >organiline !12_A	et	f	\N
208587	organiline	"organiline %organi  )LINE_aA  <organ ;02_S	et	f	\N
208594	bandil	?bandil =bandi  (SgAd  >bandi !16_S	et	f	\N
208595	bandil	?bandil =bandi  (SgAd  >bant !22_S	et	f	\N
208598	õnnelikkust	õnnelikkust =õnnelikkus  (SgP  >õnnelikkus !11~09_S	et	f	\N
208599	õnnelikkust	"õnnelikkus %õnnelikku  )US_aS  <õnnelik ;25_A	et	f	\N
208600	veedada	?veedada =dada  (SgN  >vee+dada !17_S	et	f	\N
208601	veedada	?veedada =dada  (SgG  >vee+dada !17_S	et	f	\N
208602	veedada	?veedada =dada  (SgP  >vee+dada !17_S	et	f	\N
208630	lunda	?lunda =lunda  (SgN  >lunda !16_S	et	f	\N
208631	lunda	?lunda =lunda  (SgG  >lunda !16_S	et	f	\N
208632	lunda	?lunda =lunda  (IndPrPs_  >lundama !29_V	et	f	\N
208633	lunda	?lunda =lunda  (ImpPrSg2  >lundama !29_V	et	f	\N
208652	lõpetamisega	lõpetamisega =lõpetamise  (SgKom  >lõpetamine !12_S	et	f	\N
208653	lõpetamisega	"lõpetamine %lõpeta  )MINE_vS  <lõpetama ;27_V	et	f	\N
208656	üllatused	üllatused =üllatuse  (PlN  >üllatus !11_S	et	f	\N
208657	üllatused	"üllatus %üllata  )US_vS  <üllatama ;27_V	et	f	\N
208691	õnimõigused	?õnimõigused =õnimõiguse  (PlN  >õnimõigus !11~09_S	et	f	\N
208692	taasiseseisvumisperioodi	taasiseseisvumisperioodi =perioodi  (SgG  >taas+ise+seisvumis+periood !22_S	et	f	\N
208693	taasiseseisvumisperioodi	taasiseseisvumisperioodi =perioodi  (SgP  >taas+ise+seisvumis+periood !22_S	et	f	\N
208694	taasiseseisvumisperioodi	taasiseseisvumisperioodi =perioodi  (SgAdt  >taas+ise+seisvumis+periood !22_S	et	f	\N
208696	lpromet	?lpromet =lprome  (SgP  >lprome !16_S	et	f	\N
208699	kajastusid	kajastusid =kajastu  (IndIpfSg2  >kajastuma !27_V	et	f	\N
208700	kajastusid	kajastusid =kajastu  (IndIpfPl3  >kajastuma !27_V	et	f	\N
208704	rezhiim	?rezhiim =rezhiim  (SgN  >rezhiim !22_S	et	f	\N
208705	oluliste	oluliste =olulis  (PlG  >oluline !12_A	et	f	\N
208706	oluliste	"oluline %olu  )LINE_aA  <olu ;17_S	et	f	\N
208726	hrutshjev	?hrutshjev =hrutshje  (PtsPrPs  >hrutshjema !27_V	et	f	\N
208727	hrutshjev	?hrutshjev =hrutshjev  (SgN  >hrutshjev !02_A	et	f	\N
208749	gorbatsovi	?gorbatsovi =gorbatsovi  (ID  >gorbatsovi !41_D	et	f	\N
208750	gorbatsovi	?gorbatsovi =gorbatsovi  (SgG  >gorbatsov !02_A	et	f	\N
208784	toitmisest	toitmisest =toitmise  (SgEl  >toitmine !12?10_S	et	f	\N
208785	toitmisest	"toitmine %toit  )MINE_vS  <toitma ;34_V	et	f	\N
208789	keskealisedel	### keskealisedel	et	f	\N
208796	keelteoskumine	?keelteoskumine =keelteoskumine  (SgN  >keelteoskumine !12_S	et	f	\N
208797	keelteoskumine	?keelteoskumine =keelteoskumine  (PlP  >keelteoskumin !19_S	et	f	\N
208798	keelteoskumine	?keelteoskumine =skumine  (SgN  >keel+teo+skumine !10_A	et	f	\N
208799	keelteoskumine	?keelteoskumine =oskumine  (SgN  >keelte+oskumine !12_S	et	f	\N
208800	keelteoskumine	?keelteoskumine =oskumine  (PlP  >keelte+oskumin !19_S	et	f	\N
208801	keelteoskumine	?keelteoskumine =teoskumine  (SgN  >keel+teoskumine !12_S	et	f	\N
208802	keelteoskumine	?keelteoskumine =teoskumine  (PlP  >keel+teoskumin !19_S	et	f	\N
208812	olleks	?olleks =olle  (PlTr  >oll !22_S	et	f	\N
208813	olleks	?olleks =olle  (KndPrPs  >ollema !30_V	et	f	\N
208828	musikaõpetus	?musikaõpetus =musikaõpetu  (SgIn  >musikaõpetu !01_A	et	f	\N
208829	musikaõpetus	?musikaõpetus =musikaõpetu  (IndIpfSg3  >musikaõpetuma !27_V	et	f	\N
208830	musikaõpetus	?musikaõpetus =musikaõpetus  (SgN  >musikaõpetus !11?09_S	et	f	\N
208831	musikaõpetus	?musikaõpetus =kaõpetu  (SgIn  >musi+kaõpetu !01_A	et	f	\N
208832	musikaõpetus	?musikaõpetus =kaõpetus  (SgN  >musi+kaõpetus !11_S	et	f	\N
208870	kodutel	?kodutel =kodute  (PlAd  >kodutt !22_S	et	f	\N
208875	kättesaadavust	kättesaadavust =saadavus  (SgP  >kätte+saadavus !11_S	et	f	\N
208876	kättesaadavust	"kätte+saadavus %saadava  )US_aS  <kätte+saadav ;02_A	et	f	\N
208880	millidega	?millidega =milli  (PlKom  >milli !16_S	et	f	\N
208881	millidega	?millidega =milli  (PlKom  >mill !22_S	et	f	\N
208566	eeriti	?eeriti =eeriti  (ImpPrSg2  >eerittima !28_V	et	f	\N
208568	peterbiri	?peterbiri =peterbiri  (SgG  >peterbir !19_S	et	f	\N
208569	peterbiri	?peterbiri =peterbiri  (SgP  >peterbir !19_S	et	f	\N
208570	peterbiri	?peterbiri =peterbiri  (SgAdt  >peterbir !19_S	et	f	\N
208575	pskkovil	?pskkovil =pskkovi  (SgAd  >pskkovi !17_S	et	f	\N
208584	bio	?bio =bio  (SgN  >bio !26_S	et	f	\N
208585	bio	?bio =bio  (SgG  >bio !26_S	et	f	\N
208590	tööles	?tööles =tööle  (SgIn  >tööle !06_S	et	f	\N
208591	tööles	?tööles =tööle  (PlIn  >tööl !22_S	et	f	\N
208592	tööles	?tööles =tööle  (IndIpfSg3  >töölema !27_V	et	f	\N
208593	tööles	?tööles =tööles  (SgN  >tööles !09_S	et	f	\N
208616	neijuga	?neijuga =neiju  (SgKom  >neiju !16_S	et	f	\N
208624	müstamäes	?müstamäes =müstamäe  (SgIn  >müstamäe !26_S	et	f	\N
208625	müstamäes	?müstamäes =müstamäes  (SgN  >müstamäes !22_S	et	f	\N
208642	praktikeerida	?praktikeerida =praktikeeri  (Inf  >praktikeerima !28_V	et	f	\N
208650	riigieelarvelisel	riigieelarvelisel =arvelise  (SgAd  >riigi+eel+arveline !12_A	et	f	\N
208651	riigieelarvelisel	"riigi+eel+arveline %arve  )LINE_aA  <riigi+eel+arve ;06_S	et	f	\N
208658	vedamist	vedamist =vedamis  (SgP  >vedamine !12_S	et	f	\N
208659	vedamist	"vedamine %veda  )MINE_vS  <vedama ;28_V	et	f	\N
208660	võidusse	võidusse =võidu  (SgIll  >võidu !01_S	et	f	\N
208661	võidusse	"võidu %või  )TU1_vS  <võima ;37_V	et	f	\N
208662	võidusse	võidusse =võidu  (SgIll  >võit !22_S	et	f	\N
208663	võidusse	võidusse =võidus  (SgAdt  >võidus !11_S	et	f	\N
208664	võidusse	"võidus %või  )TUS1_aS  <võima ;37_V	et	f	\N
208667	aastattel	?aastattel =tatte  (SgAd  >aas+tate !06_S	et	f	\N
208668	aastattel	?aastattel =tattel  (SgN  >aas+tattel !02_S	et	f	\N
208678	poolitikaelu	?poolitikaelu =poolitikaelu  (SgN  >poolitikaelu !17_S	et	f	\N
208679	poolitikaelu	?poolitikaelu =poolitikaelu  (SgG  >poolitikaelu !17_S	et	f	\N
208680	poolitikaelu	?poolitikaelu =poolitikaelu  (SgP  >poolitikaelu !17_S	et	f	\N
208681	poolitikaelu	?poolitikaelu =poolitikaelu  (IndPrPs_  >poolitikaeluma !27_V	et	f	\N
208682	poolitikaelu	?poolitikaelu =poolitikaelu  (ImpPrSg2  >poolitikaeluma !27_V	et	f	\N
208684	poolitikaelu	?poolitikaelu =tikaelu  (SgN  >pooli+tikaelu !17_S	et	f	\N
208686	poolitikaelu	?poolitikaelu =tikaelu  (SgG  >pooli+tikaelu !17_S	et	f	\N
208687	poolitikaelu	?poolitikaelu =tikaelu  (SgP  >pooli+tikaelu !17_S	et	f	\N
208688	poolitikaelu	?poolitikaelu =itikaelu  (SgN  >pool+itikaelu !17_S	et	f	\N
208689	poolitikaelu	?poolitikaelu =itikaelu  (SgG  >pool+itikaelu !17_S	et	f	\N
208690	poolitikaelu	?poolitikaelu =itikaelu  (SgP  >pool+itikaelu !17_S	et	f	\N
208697	valton	?valton =valton  (SgN  >valton !02_S	et	f	\N
208707	okkupeerimiseks	?okkupeerimiseks =okkupeerimise  (SgTr  >okkupeerimine !12_S	et	f	\N
208708	sõjalise	sõjalise =sõjalise  (SgG  >sõjaline !12_A	et	f	\N
208709	sõjalise	"sõjaline %sõja  )LINE_aA  <sõda ;18_S	et	f	\N
208733	avalikusesse	avalikusesse =avalikuse  (SgIll  >avalikus !11?09_S	et	f	\N
208734	avalikusesse	"avalikus %avaliku  )US_aS  <avalik ;25_A	et	f	\N
208742	teatreitesse	?teatreitesse =teatreites  (SgAdt  >teatreitene !12_A	et	f	\N
208743	teatreitesse	?teatreitesse =teatreitesse  (SgG  >teatreitesne !02_A	et	f	\N
208744	teatreitesse	?teatreitesse =teatreitesse  (PlP  >teatreitess !22_S	et	f	\N
208753	rämpsu	rämpsu =rämpsu  (SgG  >rämps !22_SA	et	f	\N
208754	rämpsu	rämpsu =rämpsu  (SgP  >rämps !22_SA	et	f	\N
208755	rämpsu	rämpsu =rämpsu  (SgAdt  >rämps !22_SA	et	f	\N
208766	klassikalisele	klassikalisele =klassikalise  (SgAll  >klassikaline !12_A	et	f	\N
208767	klassikalisele	"klassikaline %klassika  )LINE_aA  <klassika ;01_S	et	f	\N
208768	klassikalisele	klassikalisele =kalise  (SgAll  >klassi+kaline !10_A	et	f	\N
208769	klassikalisele	"klassi+kaline %kali  )NE_aA  <klassi+kali ;17_S	et	f	\N
208773	muudatab	?muudatab =muudata  (IndPrSg3  >muudatama !27_V	et	f	\N
208803	inimenele	?inimenele =inimene  (PlAll  >inimen !19_S	et	f	\N
208804	inimenele	?inimenele =ene  (SgAll  >inim+ene !16_S	et	f	\N
208805	eri-	eri- =eri  (ID  >eri !41_A	et	f	\N
208806	eri-	eri- =eri  (SgN  >eri !17_S	et	f	\N
208807	eri-	eri- =eri  (SgG  >eri !17_S	et	f	\N
208808	eri-	eri- =eri  (SgP  >eri !17_S	et	f	\N
208810	teineteiste	teineteiste =teis  (PlG  >teine+teise !12_P	et	f	\N
208811	teineteiste	teineteiste =teiste  (PlP  >teine+teist !22_S	et	f	\N
208814	helistavad	helistavad =helista  (IndPrPl3  >helistama !27_V	et	f	\N
208815	helistavad	helistavad =helistava  (PlN  >helistav !02_A	et	f	\N
208816	helistavad	"helistav %helista  )V_vA  <helistama ;27_V	et	f	\N
208818	kelmuma	?kelmuma =kelmu  (Sup  >kelmuma !27_V	et	f	\N
208842	käskkirja	käskkirja =kirja  (SgG  >käsk+kiri !24_S	et	f	\N
208843	käskkirja	käskkirja =kirja  (SgP  >käsk+kiri !24_S	et	f	\N
208844	käskkirja	käskkirja =kirja  (SgAdt  >käsk+kiri !24_S	et	f	\N
208849	kõrvalteele	kõrvalteele =ee  (SgAll  >kõrvalt+esi !15_S	et	f	\N
208850	kõrvalteele	kõrvalteele =tee  (SgAll  >kõrval+tee !26_S	et	f	\N
208853	ületanud	ületanud =ületa  (PtsPtPs  >ületama !27_V	et	f	\N
208854	ületanud	ületanud =ületanu  (PlN  >ületanu !01_S	et	f	\N
208855	ületanud	"ületanu %ületa  )NU_vS  <ületama ;27_V	et	f	\N
208721	võiduks	"võidu %või  )TU1_vS  <võima ;37_V	et	f	\N
208722	võiduks	võiduks =võidu  (SgTr  >võit !22_S	et	f	\N
208723	võiduks	võiduks =võidu  (KndPrPs  >võiduma !27_V	et	f	\N
208724	plenumil	?plenumil =plenumi  (SgAd  >plenumi !01_S	et	f	\N
208725	plenumil	?plenumil =plenumi  (SgAd  >plenum !02_A	et	f	\N
208738	massilised	massilised =massilise  (PlN  >massiline !12_A	et	f	\N
208740	massilised	"massiline %massi  )LINE_aA  <mass ;22_S	et	f	\N
208745	vilnuseni	?vilnuseni =vilnuse  (SgTer  >vilnus !11~09_S	et	f	\N
208746	vilnuseni	?vilnuseni =vilnuseni  (SgG  >vilnusen !19_S	et	f	\N
208747	vilnuseni	?vilnuseni =vilnuseni  (SgP  >vilnusen !19_S	et	f	\N
208748	vilnuseni	?vilnuseni =vilnuseni  (SgAdt  >vilnusen !19_S	et	f	\N
208756	villand	villand =villand  (ID  >villand !41_D	et	f	\N
208757	villand	villand =and  (SgN  >vill+and !22_S	et	f	\N
208763	imelikus	imelikus =imeliku  (SgIn  >imelik !25_A	et	f	\N
208764	imelikus	imelikus =imelikus  (SgN  >imelikus !11?09_S	et	f	\N
208765	imelikus	"imelikus %imeliku  )US_aS  <imelik ;25_A	et	f	\N
208772	treningudel	### treningudel	et	f	\N
208779	lürts	?lürts =lürts  (SgN  >lürts !22_S	et	f	\N
208782	tervislikkust	tervislikkust =tervislikkus  (SgP  >tervislikkus !11~09_S	et	f	\N
208783	tervislikkust	"tervislikkus %tervislikku  )US_aS  <tervislik ;25_A	et	f	\N
208790	steereotüüp	?steereotüüp =steereotüüp  (SgN  >steereotüüp !22_S	et	f	\N
208794	alkogoolism	?alkogoolism =alkogoolism  (SgN  >alkogoolism !22_S	et	f	\N
208795	alkogoolism	?alkogoolism =goolism  (SgN  >alko+goolism !22_S	et	f	\N
208809	zen	### zen	et	f	\N
208819	ohtlikudbr	### ohtlikudbr	et	f	\N
208835	viisakad	viisakad =viisaka  (PlN  >viisakas !02_A	et	f	\N
208836	viisakad	viisakad =aka  (PlN  >viis+aka !16_S	et	f	\N
208837	muudatusest	muudatusest =muudatuse  (SgEl  >muudatus !11_S	et	f	\N
208838	muudatusest	muudatusest =muudatuses  (SgP  >muudatusene !12_A	et	f	\N
208839	muudatusest	"muudatusene %muudatuse  )NE_aA  <muudatus ;11_S	et	f	\N
208840	koolipinke	koolipinke =pinke  (SgG  >kooli+pinge !06_S	et	f	\N
208841	koolipinke	koolipinke =pinke  (PlP  >kooli+pink !22_S	et	f	\N
208845	juhatajadeks	### juhatajadeks	et	f	\N
208848	kabinetisbr	### kabinetisbr	et	f	\N
208851	sündmuskohalt	sündmuskohalt =koha  (SgAbl  >sündmus+koha !17_S	et	f	\N
208852	sündmuskohalt	sündmuskohalt =koha  (SgAbl  >sündmus+koht !22_S	et	f	\N
208898	kõrgemaile	kõrgemaile =kõrgema  (PlAll  >kõrgem !02_A	et	f	\N
208900	kõrgemaile	"kõrgem %kõrge  )M_cA  <kõrge ;01_A	et	f	\N
208902	kõrgemaile	kõrgemaile =ma  (PlAll  >kõrge+maa !26_S	et	f	\N
208903	kõrgemaile	kõrgemaile =mai  (SgAll  >kõrge+mai !26_S	et	f	\N
208904	kõrgemaile	kõrgemaile =emaile  (PlP  >kõrg+email !22_S	et	f	\N
208927	238a	### 238a	et	f	\N
208946	politseid	politseid =politsei  (PlN  >politsei !26_S	et	f	\N
208947	politseid	politseid =politsei  (SgP  >politsei !26_S	et	f	\N
208974	inimestelebr	?inimestelebr =inimestelebr  (SgN  >inimestelebr !22_S	et	f	\N
208975	inimestelebr	?inimestelebr =lebr  (SgN  >inimeste+lebr !22_S	et	f	\N
208976	inimestelebr	?inimestelebr =estelebr  (SgN  >inim+estelebr !22_S	et	f	\N
208977	veetmisest	veetmisest =veetmise  (SgEl  >veetmine !12?10_S	et	f	\N
208978	veetmisest	"veetmine %veet  )MINE_vS  <veetma ;34_V	et	f	\N
208991	variandit	?variandit =andi  (SgP  >vari+andi !16_S	et	f	\N
208992	variandit	?variandit =andit  (SgN  >vari+andit !02_S	et	f	\N
209012	tolmukaitset	tolmukaitset =kaitse  (SgP  >tolmu+kaitse !05_S	et	f	\N
209013	tolmukaitset	tolmukaitset =kaitse  (SgP  >tolmu+kaitse !06_S	et	f	\N
209018	efektiivsust	efektiivsust =efektiivsus  (SgP  >efektiivsus !11~09_S	et	f	\N
209019	efektiivsust	"efektiivsus %efektiivse  )US_aS  <efektiivne ;02_A	et	f	\N
209035	õõ	?õõ =õõ  (SgN  >õõ !26_S	et	f	\N
209036	õõ	?õõ =õõ  (SgG  >õõ !26_S	et	f	\N
209041	norskamini	?norskamini =norskami  (SgTer  >norskami !01_S	et	f	\N
209042	norskamini	?norskamini =norskami  (SgTer  >norskam !02_S	et	f	\N
209043	norskamini	?norskamini =norskamini  (ID  >norskamini !41_D	et	f	\N
209044	norskamini	?norskamini =norskamini  (SgG  >norskamin !19_S	et	f	\N
209045	norskamini	?norskamini =norskamini  (SgP  >norskamin !19_S	et	f	\N
209046	norskamini	?norskamini =norskamini  (SgAdt  >norskamin !19_S	et	f	\N
209049	tuppase	?tuppase =tuppase  (SgG  >tuppane !12~10_A	et	f	\N
209053	travmeerida	?travmeerida =travmeeri  (Inf  >travmeerima !28_V	et	f	\N
209108	ettevõttesse	ettevõttesse =võtte  (SgIll  >ette+võte !06_S	et	f	\N
209109	ettevõttesse	ettevõttesse =võttes  (SgAdt  >ette+võttene !12_A	et	f	\N
209110	ettevõttesse	"ette+võttene %võtte  )NE_aA  <ette+võte ;06_S	et	f	\N
209140	käivitamiseks	käivitamiseks =käivitamise  (SgTr  >käivitamine !12_S	et	f	\N
209141	käivitamiseks	"käivitamine %käivita  )MINE_vS  <käivitama ;27_V	et	f	\N
209142	puidutööpingi	puidutööpingi =pingi  (SgG  >puidu+töö+pink !22_S	et	f	\N
209143	puidutööpingi	puidutööpingi =pingi  (SgP  >puidu+töö+ping !22_S	et	f	\N
209144	puidutööpingi	puidutööpingi =pingi  (SgAdt  >puidu+töö+ping !22_S	et	f	\N
209171	kogutuna	kogutuna =kogutu  (SgEs  >kogutu !01_AS	et	f	\N
209172	kogutuna	"kogutu %kogu  )TU1_vS  <koguma ;27_V	et	f	\N
209173	kogutuna	"kogutu %kogu  )TU2_kA  <kogu ;17_S	et	f	\N
208846	milliga	?milliga =milli  (SgKom  >milli !16_S	et	f	\N
208847	milliga	?milliga =milli  (SgKom  >mill !22_S	et	f	\N
208858	miksri	?miksri =miksri  (SgN  >miksri !01_S	et	f	\N
208859	miksri	?miksri =miksri  (SgG  >miksri !01_S	et	f	\N
208860	miksri	?miksri =miksri  (SgG  >miksr !22_S	et	f	\N
208861	miksri	?miksri =miksri  (SgP  >miksr !22_S	et	f	\N
208862	miksri	?miksri =miksri  (SgAdt  >miksr !22_S	et	f	\N
208863	miksri	?miksri =miksri  (IndPrPs_  >miksrima !28_V	et	f	\N
208864	miksri	?miksri =miksri  (ImpPrSg2  >miksrima !28_V	et	f	\N
208872	jõukust	jõukust =jõukus  (SgP  >jõukus !11~09_S	et	f	\N
208873	jõukust	"jõukus %jõuka  )US_aS  <jõukas ;02_A	et	f	\N
208874	jõukust	jõukust =kus  (SgP  >jõu+kusi !20_S	et	f	\N
208882	kättesaadavus	kättesaadavus =saadavus  (SgN  >kätte+saadavus !11_S	et	f	\N
208883	kättesaadavus	"kätte+saadavus %saadava  )US_aS  <kätte+saadav ;02_A	et	f	\N
208886	inimestegabr	?inimestegabr =inimestegabr  (SgN  >inimestegabr !22_S	et	f	\N
208887	inimestegabr	?inimestegabr =gabr  (SgN  >inimeste+gabr !22_S	et	f	\N
208888	inimestegabr	?inimestegabr =estegabr  (SgN  >inim+estegabr !22_S	et	f	\N
208891	pärilikkusel	pärilikkusel =pärilikkuse  (SgAd  >pärilikkus !11~09_S	et	f	\N
208892	pärilikkusel	"pärilikkus %pärilikku  )US_aS  <pärilik ;25_A	et	f	\N
208894	kooli-	kooli- =kooli  (SgG  >kool !22_S	et	f	\N
208895	kooli-	kooli- =kooli  (SgP  >kool !22_S	et	f	\N
208896	kooli-	kooli- =kooli  (SgAdt  >kool !22_S	et	f	\N
208897	kooli-	kooli- =kooli  (PlP  >kool !22_S	et	f	\N
208909	meditsiniabi	?meditsiniabi =meditsiniabi  (SgN  >meditsiniabi !16_S	et	f	\N
208910	meditsiniabi	?meditsiniabi =meditsiniabi  (SgG  >meditsiniabi !16_S	et	f	\N
208911	meditsiniabi	?meditsiniabi =meditsiniabi  (SgG  >meditsiniap !22_S	et	f	\N
208912	meditsiniabi	?meditsiniabi =meditsiniabi  (SgP  >meditsiniab !22_S	et	f	\N
208913	meditsiniabi	?meditsiniabi =meditsiniabi  (SgAdt  >meditsiniab !22_S	et	f	\N
208914	meditsiniabi	?meditsiniabi =meditsiniabi  (IndPrPs_  >meditsiniapima !28_V	et	f	\N
208915	meditsiniabi	?meditsiniabi =meditsiniabi  (ImpPrSg2  >meditsiniapima !28_V	et	f	\N
208916	meditsiniabi	?meditsiniabi =itsiniabi  (SgN  >med+itsiniabi !16_S	et	f	\N
208917	meditsiniabi	?meditsiniabi =itsiniabi  (SgG  >med+itsiniabi !16_S	et	f	\N
208918	meditsiniabi	?meditsiniabi =itsiniabi  (SgG  >med+itsiniap !22_S	et	f	\N
208919	meditsiniabi	?meditsiniabi =itsiniabi  (SgP  >med+itsiniab !22_S	et	f	\N
208920	meditsiniabi	?meditsiniabi =itsiniabi  (SgAdt  >med+itsiniab !22_S	et	f	\N
208951	veetmist	veetmist =veetmis  (SgP  >veetmine !12?10_S	et	f	\N
208952	veetmist	"veetmine %veet  )MINE_vS  <veetma ;34_V	et	f	\N
208953	mõtes	?mõtes =mõte  (PlIn  >mõtt !22_S	et	f	\N
208954	mõtes	?mõtes =mõte  (IndIpfSg3  >mõtema !27_V	et	f	\N
208955	mõtes	?mõtes =mõtes  (SgN  >mõtes !09_S	et	f	\N
208959	valgud	valgud =valgu  (PlN  >valk !22_S	et	f	\N
208960	valgud	valgud =valgu  (IndPrSg2  >valguma !27_V	et	f	\N
208968	iseenast	?iseenast =iseena  (SgEl  >iseena !16_S	et	f	\N
208969	iseenast	?iseenast =iseenas  (SgP  >iseenane !10_A	et	f	\N
208970	iseenast	?iseenast =enas  (SgP  >ise+enas !09_S	et	f	\N
208971	iseenast	?iseenast =enas  (SgP  >ise+enane !10_A	et	f	\N
208972	tegurist	tegurist =teguri  (SgEl  >tegur !02_S	et	f	\N
208973	tegurist	tegurist =rist  (SgN  >tegu+rist !22_S	et	f	\N
208988	ükskõikselt	ükskõikselt =kõikse  (SgAbl  >üks+kõikne !02_A	et	f	\N
208989	ükskõikselt	"üks+kõikselt %kõikse  )LT_mD  <üks+kõikne ;02_A	et	f	\N
209014	pöörduvatesse	pöörduvatesse =pöörduva  (PlIll  >pöörduv !02_A	et	f	\N
209015	pöörduvatesse	"pöörduv %pöördu  )V_vA  <pöörduma ;27_V	et	f	\N
209034	töönnetusi	?töönnetusi =töönnetusi  (PlP  >töönnetus !11_S	et	f	\N
209037	naabrida	?naabrida =naabri  (Inf  >naabrima !28_V	et	f	\N
209038	naabrida	?naabrida =brida  (SgN  >naa+brida !17_S	et	f	\N
209039	naabrida	?naabrida =brida  (SgG  >naa+brida !17_S	et	f	\N
209040	naabrida	?naabrida =brida  (SgP  >naa+brida !17_S	et	f	\N
209058	töörista	?töörista =töörista  (SgN  >töörista !01_S	et	f	\N
209059	töörista	?töörista =töörista  (SgG  >töörista !01_S	et	f	\N
209060	töörista	?töörista =töörista  (IndPrPs_  >tööristama !27_V	et	f	\N
209061	töörista	?töörista =töörista  (ImpPrSg2  >tööristama !27_V	et	f	\N
209062	töörista	?töörista =rista  (SgN  >töö+rista !16_S	et	f	\N
209063	töörista	?töörista =rista  (SgG  >töö+rista !16_S	et	f	\N
209079	kaitset	kaitset =kaitse  (SgP  >kaitse !05_S	et	f	\N
209080	kaitset	kaitset =kaitse  (SgP  >kaitse !06_S	et	f	\N
209111	taasinvesteeritud	taasinvesteeritud =investeeri  (PtsPtIps  >taas+investeerima !28_V	et	f	\N
209112	taasinvesteeritud	taasinvesteeritud =investeeritu  (PlN  >taas+investeeritu !01_S	et	f	\N
209113	taasinvesteeritud	"taas+investeeritu %investeeri  )TU1_vS  <taas+investeerima ;28_V	et	f	\N
209114	taasinvesteeritud	"taas+investeeritud %investeeri  )TUD_vA  <taas+investeerima ;28_V	et	f	\N
209126	arvutamisel	arvutamisel =arvutamise  (SgAd  >arvutamine !12_S	et	f	\N
209127	arvutamisel	"arvutamine %arvuta  )MINE_vS  <arvutama ;27_V	et	f	\N
209130	pangafirma	pangafirma =firma  (SgN  >panga+firma !16_S	et	f	\N
209131	pangafirma	pangafirma =firma  (SgG  >panga+firma !16_S	et	f	\N
209145	algkapitalist	algkapitalist =tali  (SgEl  >alg+kapi+tali !17_S	et	f	\N
208856	ületanud	ületanud =ületanud  (ID  >ületanud !41_A	et	f	\N
208857	ületanud	"ületanud %ületa  )NUD_vA  <ületama ;27_V	et	f	\N
208868	xyyy	?xyyy =xyyy  (SgN  >xyyy !26_S	et	f	\N
208869	xyyy	?xyyy =xyyy  (SgG  >xyyy !26_S	et	f	\N
208871	võttid	### võttid	et	f	\N
208877	suhtedest	suhtedest =ede  (SgEl  >suht+ede !16_S	et	f	\N
208878	suhtedest	suhtedest =edes  (SgP  >suht+edene !10_A	et	f	\N
208879	suhtedest	"suht+edene %ede  )NE_aA  <suht+ede ;16_S	et	f	\N
208899	astele	astele =aste  (SgAll  >aste !06_S	et	f	\N
208901	astele	astele =aste  (PlAll  >ast !22_S	et	f	\N
208925	tõsiseltbr	### tõsiseltbr	et	f	\N
208926	selver	?selver =selver  (SgN  >selver !02_S	et	f	\N
208928	riieteosakonnast	riieteosakonnast =konna  (SgEl  >riiete+osa+konn !22_S	et	f	\N
208929	riieteosakonnast	riieteosakonnast =konnas  (SgP  >riiete+osa+konnane !10_A	et	f	\N
208930	riieteosakonnast	"riiete+osa+konnane %konna  )NE_aA  <riiete+osa+konn ;22_S	et	f	\N
208931	riieteosakonnast	riieteosakonnast =osakonna  (SgEl  >riiete+osakond !22_S	et	f	\N
208932	riieteosakonnast	riieteosakonnast =osakonnas  (SgP  >riiete+osakonnane !12_A	et	f	\N
208933	riieteosakonnast	"riiete+osakonnane %osakonna  )NE_aA  <riiete+osakond ;22_S	et	f	\N
208937	kuivas	kuivas =kuiva  (SgIn  >kuiv !22_AS	et	f	\N
208938	kuivas	kuivas =kuiva  (IndIpfSg3  >kuivama !28_V	et	f	\N
208939	halliks	halliks =halli  (SgTr  >hall !22_S	et	f	\N
208940	halliks	halliks =halli  (SgTr  >hall !22_AS	et	f	\N
208941	halliks	halliks =iks  (SgN  >hall+iks !22_S	et	f	\N
208948	rööviha	rööviha =iha  (SgN  >rööv+iha !17_S	et	f	\N
208949	rööviha	rööviha =iha  (SgG  >rööv+iha !17_S	et	f	\N
208950	rööviha	rööviha =iha  (SgP  >rööv+iha !17_S	et	f	\N
208963	taimetoitu	taimetoitu =toitu  (SgN  >taime+toitu !01_A	et	f	\N
208964	taimetoitu	"taime+toitu %toi  )TU2_kA  <taime+toi ;26_S	et	f	\N
208965	taimetoitu	taimetoitu =toitu  (SgG  >taime+toitu !01_A	et	f	\N
208966	taimetoitu	taimetoitu =toitu  (SgP  >taime+toit !22_S	et	f	\N
208967	taimetoitu	taimetoitu =toitu  (SgAdt  >taime+toit !22_S	et	f	\N
208986	reosta	reosta =reosta  (IndPrPs_  >reostama !27_V	et	f	\N
208987	reosta	reosta =reosta  (ImpPrSg2  >reostama !27_V	et	f	\N
208990	sedaan	?sedaan =sedaan  (SgN  >sedaan !22_S	et	f	\N
209016	sõlmedesse	sõlmedesse =sõlme  (PlIll  >sõlm !22_S	et	f	\N
209017	sõlmedesse	sõlmedesse =ede  (SgIll  >sõlm+ede !16_S	et	f	\N
209027	tahtmatult	tahtmatult =tahtmatu  (SgAbl  >tahtmatu !01_A	et	f	\N
209028	tahtmatult	"tahtmatu %taht  )MATU_vA  <tahtma ;34_V	et	f	\N
209029	tahtmatult	tahtmatult =tahtmatult  (ID  >tahtmatult !41_D	et	f	\N
209030	tahtmatult	"tahtmatult %taht  )MATULT_mD  <tahtma ;34_V	et	f	\N
209031	tahtmatult	"tahtmatult %tahtmatu  )LT_mD  <tahtmatu ;01_A	et	f	\N
209047	kõrvaltoas	kõrvaltoas =oa  (SgIn  >kõrvalt+uba !18_S	et	f	\N
209048	kõrvaltoas	kõrvaltoas =toa  (SgIn  >kõrval+tuba !18_S	et	f	\N
209050	nabrimeest	?nabrimeest =nabrimee  (SgEl  >nabrimee !26_S	et	f	\N
209066	ohutus	ohutus =ohutu  (SgIn  >ohutu !01_A	et	f	\N
209067	ohutus	"ohutu %ohu  )TU2_kA  <oht ;22_S	et	f	\N
209068	ohutus	ohutus =ohutus  (SgN  >ohutus !11_S	et	f	\N
209069	ohutus	"ohutus %ohuta  )US_vS  <ohutama ;27_V	et	f	\N
209070	ohutus	"ohutus %ohu  )TUS2_aS  <oht ;22_S	et	f	\N
209103	maksuvaba	maksuvaba =vaba  (SgN  >maksu+vaba !17_A	et	f	\N
209104	maksuvaba	maksuvaba =vaba  (SgG  >maksu+vaba !17_A	et	f	\N
209105	maksuvaba	maksuvaba =vaba  (SgP  >maksu+vaba !17_A	et	f	\N
209119	tulumaksu	tulumaksu =maksu  (SgG  >tulu+maks !22_S	et	f	\N
209123	tulumaksu	tulumaksu =maksu  (SgP  >tulu+maks !22_S	et	f	\N
209124	tulumaksu	tulumaksu =maksu  (SgAdt  >tulu+maks !22_S	et	f	\N
209125	tulumaksu	tulumaksu =maksu  (PlP  >tulu+maks !22_S	et	f	\N
209134	juhatusele	juhatusele =juhatuse  (SgAll  >juhatus !11_S	et	f	\N
209135	juhatusele	"juhatus %juhata  )US_vS  <juhatama ;27_V	et	f	\N
209136	juhatusele	"juhatus %juha  )TUS2_aS  <juha ;17_S	et	f	\N
209137	väikefirma	väikefirma =firma  (SgN  >väike+firma !16_S	et	f	\N
209138	väikefirma	väikefirma =firma  (SgG  >väike+firma !16_S	et	f	\N
209166	purustatav	purustatav =purusta  (PtsPrIps  >purustama !27_V	et	f	\N
209167	purustatav	purustatav =purustatav  (SgN  >purustatav !02_A	et	f	\N
209168	purustatav	"purustatav %purusta  )TAV_vAS  <purustama ;27_V	et	f	\N
209180	stratosfääri	stratosfääri =stratosfääri  (SgG  >stratosfäär !22_S	et	f	\N
209181	stratosfääri	stratosfääri =stratosfääri  (SgP  >stratosfäär !22_S	et	f	\N
209182	stratosfääri	stratosfääri =stratosfääri  (SgAdt  >stratosfäär !22_S	et	f	\N
209187	sajatuhandikku	sajatuhandikku =tuhandikku  (SgP  >saja+tuhandik !25_N	et	f	\N
209188	sajatuhandikku	sajatuhandikku =tuhandikku  (SgAdt  >saja+tuhandik !25_N	et	f	\N
209230	suurenemise	suurenemise =suurenemise  (SgG  >suurenemine !12_S	et	f	\N
209231	suurenemise	"suurenemine %suurene  )MINE_vS  <suurenema ;27_V	et	f	\N
209241	õhusaaste	õhusaaste =saaste  (SgN  >õhu+saaste !06_S	et	f	\N
209242	õhusaaste	õhusaaste =saaste  (SgG  >õhu+saaste !06_S	et	f	\N
209243	õhusaaste	õhusaaste =saaste  (PlP  >õhu+saast !22_S	et	f	\N
209263	maksukohuslasi	?maksukohuslasi =maksukohuslasi  (PlP  >maksukohuslane !12_S	et	f	\N
209264	maksukohuslasi	?maksukohuslasi =slasi  (SgN  >maksu+kohu+slasi !17_S	et	f	\N
208885	sündime	?sündime =sündi  (IndPrPl1  >süntima !28_V	et	f	\N
208907	tegutsemine	tegutsemine =tegutsemine  (SgN  >tegutsemine !12_S	et	f	\N
208908	tegutsemine	"tegutsemine %tegutse  )MINE_vS  <tegutsema ;27_V	et	f	\N
208921	pühabr	?pühabr =pühabr  (SgN  >pühabr !22_S	et	f	\N
208934	mütsi	mütsi =mütsi  (SgG  >müts !22_S	et	f	\N
208935	mütsi	mütsi =mütsi  (SgP  >müts !22_S	et	f	\N
208936	mütsi	mütsi =mütsi  (SgAdt  >müts !22_S	et	f	\N
208956	tervislikust	tervislikust =tervisliku  (SgEl  >tervislik !25_A	et	f	\N
208957	tervislikust	tervislikust =tervislikus  (SgP  >tervislikus !11?09_S	et	f	\N
208958	tervislikust	"tervislikus %tervisliku  )US_aS  <tervislik ;25_A	et	f	\N
208983	kattuseta	?kattuseta =kattuse  (SgAb  >kattus !11~09_S	et	f	\N
208984	kattuseta	?kattuseta =kattuseta  (IndPrPs_  >kattusetama !27_V	et	f	\N
208985	kattuseta	?kattuseta =kattuseta  (ImpPrSg2  >kattusetama !27_V	et	f	\N
208993	kaugudeliinide	?kaugudeliinide =kaugudeliini  (PlG  >kaugudeliini !16_S	et	f	\N
208994	kaugudeliinide	?kaugudeliinide =kaugudeliini  (PlG  >kaugudeliin !22_S	et	f	\N
208995	kaugudeliinide	?kaugudeliinide =udeliini  (PlG  >kaug+udeliini !16_S	et	f	\N
208996	kaugudeliinide	?kaugudeliinide =udeliini  (PlG  >kaug+udeliin !22_S	et	f	\N
208997	löös	?löös =löö  (SgIn  >löö !26_S	et	f	\N
208998	löös	?löös =löös  (SgN  >löös !22_S	et	f	\N
208999	elektritööriista	elektritööriista =riista  (SgG  >elektri+töö+riist !22_S	et	f	\N
209000	elektritööriista	elektritööriista =riista  (SgP  >elektri+töö+riist !22_S	et	f	\N
209001	elektritööriista	elektritööriista =riista  (SgAdt  >elektri+töö+riist !22_S	et	f	\N
209002	rikkida	?rikkida =rikki  (Inf  >rikkima !28_V	et	f	\N
209020	turvalisust	turvalisust =turvalisus  (SgP  >turvalisus !11?09_S	et	f	\N
209021	turvalisust	"turvalisus %turva  )LISUS_aS  <turb ;22_SA	et	f	\N
209022	turvalisust	"turvalisus %turva  )LISUS_aS  <turv ;22_S	et	f	\N
209054	tööõnnetus	tööõnnetus =õnnetu  (SgIn  >töö+õnnetu !01_A	et	f	\N
209055	tööõnnetus	"töö+õnnetu %õnne  )TU2_kA  <töö+õnn ;22_S	et	f	\N
209056	tööõnnetus	tööõnnetus =õnnetus  (SgN  >töö+õnnetus !11_S	et	f	\N
209057	tööõnnetus	"töö+õnnetus %õnne  )TUS2_aS  <töö+õnn ;22_S	et	f	\N
209071	rööriista	?rööriista =rööriista  (SgN  >rööriista !01_S	et	f	\N
209072	rööriista	?rööriista =rööriista  (SgG  >rööriista !01_S	et	f	\N
209073	rööriista	?rööriista =rööriista  (IndPrPs_  >rööriistama !27_V	et	f	\N
209074	rööriista	?rööriista =rööriista  (ImpPrSg2  >rööriistama !27_V	et	f	\N
209075	kaitseseade	kaitseseade =seade  (SgN  >kaitse+seade !05_S	et	f	\N
209076	kaitseseade	kaitseseade =seade  (SgN  >kaitse+seade !06_S	et	f	\N
209077	kaitseseade	kaitseseade =seade  (SgG  >kaitse+seade !06_S	et	f	\N
209078	kaitseseade	kaitseseade =seade  (PlP  >kaitse+sead !22_S	et	f	\N
209097	kaivituks	?kaivituks =kaivi  (KndPtIps  >kaivima !28_V	et	f	\N
209098	kaivituks	?kaivituks =kaivitu  (SgTr  >kaivitu !01_AS	et	f	\N
209099	kaivituks	?kaivituks =kaivitu  (KndPrPs  >kaivituma !27_V	et	f	\N
209100	kaivituks	?kaivituks =vitu  (SgTr  >kai+vitu !16_S	et	f	\N
209101	vigastust	vigastust =vigastus  (SgP  >vigastus !11_S	et	f	\N
209102	vigastust	"vigastus %vigasta  )US_vS  <vigastama ;27_V	et	f	\N
209106	maksustava	maksustava =maksustava  (SgG  >maksustav !02_A	et	f	\N
209107	maksustava	"maksustav %maksusta  )V_vA  <maksustama ;27_V	et	f	\N
209115	tulumaksust	tulumaksust =maksu  (SgEl  >tulu+maks !22_S	et	f	\N
209116	tulumaksust	tulumaksust =maksu  (PlEl  >tulu+maks !22_S	et	f	\N
209117	maksjaid	maksjaid =maksja  (PlP  >maksja !01_S	et	f	\N
209118	maksjaid	"maksja %maks  )JA_vS  <maksma ;32_V	et	f	\N
209128	hüvitamisest	hüvitamisest =hüvitamise  (SgEl  >hüvitamine !12_S	et	f	\N
209129	hüvitamisest	"hüvitamine %hüvita  )MINE_vS  <hüvitama ;27_V	et	f	\N
209132	taotlusele	taotlusele =taotluse  (SgAll  >taotlus !11~09_S	et	f	\N
209133	taotlusele	"taotlus %taotle  )US_vS  <taotlema ;27_V	et	f	\N
209158	b-kaart	b-kaart =kaar  (SgP  >b-kaar !13_S	et	f	\N
209159	b-kaart	b-kaart =kaart  (SgN  >b-kaart !22_S	et	f	\N
209162	osoonkiht	?osoonkiht =osoonkiht  (SgN  >osoonkiht !22_S	et	f	\N
209169	kihina	kihina =kihi  (SgEs  >kiht !22_S	et	f	\N
209170	kihina	kihina =kihina  (SgG  >kihin !02_S	et	f	\N
209177	osooni	osooni =osooni  (SgG  >osoon !22_S	et	f	\N
209178	osooni	osooni =osooni  (SgP  >osoon !22_S	et	f	\N
209179	osooni	osooni =osooni  (SgAdt  >osoon !22_S	et	f	\N
209189	ümbritsevast	ümbritsevast =ümbritseva  (SgEl  >ümbritsev !02_A	et	f	\N
209190	ümbritsevast	"ümbritsev %ümbritse  )V_vA  <ümbritsema ;27_V	et	f	\N
209191	asuvatest	asuvatest =asuva  (PlEl  >asuv !02_A	et	f	\N
209192	asuvatest	"asuv %asu  )V_vA  <asuma ;27_V	et	f	\N
209193	asuvatest	asuvatest =vate  (PlEl  >asu+vatt !22_S	et	f	\N
209194	lainepikkus	lainepikkus =pikkus  (SgN  >laine+pikkus !11~09_S	et	f	\N
209195	lainepikkus	"laine+pikkus %pikk  )US_aS  <laine+pikk ;22_AS	et	f	\N
209196	lainepikkusega	lainepikkusega =pikkuse  (SgKom  >laine+pikkus !11~09_S	et	f	\N
209197	lainepikkusega	"laine+pikkus %pikk  )US_aS  <laine+pikk ;22_AS	et	f	\N
209198	lainepikkusega	lainepikkusega =pikkuse  (SgKom  >laine+pikkune !12~10_A	et	f	\N
209211	peegeldatud	peegeldatud =peegelda  (PtsPtIps  >peegeldama !27_V	et	f	\N
208922	tervistebr	?tervistebr =tervistebr  (SgN  >tervistebr !22_S	et	f	\N
208923	tervistebr	?tervistebr =ebr  (SgN  >tervist+ebr !22_S	et	f	\N
208924	tervistebr	?tervistebr =tebr  (SgN  >tervis+tebr !22_S	et	f	\N
208942	osalenule	osalenule =osalenu  (SgAll  >osalenu !01_S	et	f	\N
208943	osalenule	"osalenu %osale  )NU_vS  <osalema ;27_V	et	f	\N
208944	kasei	?kasei =kasei  (SgN  >kasei !26_S	et	f	\N
208945	kasei	?kasei =kasei  (SgG  >kasei !26_S	et	f	\N
208961	rasvad	rasvad =rasva  (PlN  >rasv !22_S	et	f	\N
208962	rasvad	rasvad =rasva  (IndPrSg2  >rasvama !29_V	et	f	\N
208979	ac	### ac	et	f	\N
208980	autoses	?autoses =autose  (SgIn  >autos !11~09_S	et	f	\N
208981	autoses	?autoses =tose  (SgIn  >au+tose !16_S	et	f	\N
208982	autoses	?autoses =toses  (SgN  >au+toses !09_S	et	f	\N
209003	turvasemalt	turvasemalt =turvasema  (SgAbl  >turvasem !02_A	et	f	\N
209004	turvasemalt	"turvasem %turva  )SEM_cA  <turb ;22_SA	et	f	\N
209005	turvasemalt	"turvasem %turva  )SEM_cA  <turv ;22_S	et	f	\N
209006	turvasemalt	turvasemalt =turvasemalt  (ID  >turvasemalt !41_D	et	f	\N
209007	turvasemalt	"turvasemalt %turva  )SEMALT_mD  <turb ;22_SA	et	f	\N
209008	turvasemalt	"turvasemalt %turva  )SEMALT_mD  <turv ;22_S	et	f	\N
209009	tööriista	tööriista =riista  (SgG  >töö+riist !22_S	et	f	\N
209010	tööriista	tööriista =riista  (SgP  >töö+riist !22_S	et	f	\N
209011	tööriista	tööriista =riista  (SgAdt  >töö+riist !22_S	et	f	\N
209023	juhtmest	juhtmest =juhtme  (SgEl  >juhe !05_S	et	f	\N
209024	juhtmest	juhtmest =juhtmes  (SgP  >juhtmene !12~10_A	et	f	\N
209025	juhtmest	"juhtmene %juhtme  )NE_aA  <juhe ;05_S	et	f	\N
209026	juhtmest	juhtmest =mest  (SgN  >juht+mest !22_S	et	f	\N
209032	lisaosi	lisaosi =osi  (SgN  >lisa+osi !24_S	et	f	\N
209033	lisaosi	lisaosi =osi  (PlP  >lisa+osa !17_S	et	f	\N
209051	naabrimees	naabrimees =mee  (SgIn  >naabri+mesi !15_S	et	f	\N
209052	naabrimees	naabrimees =mees  (SgN  >naabri+mees !13_S	et	f	\N
209064	sutades	?sutades =suta  (PlIn  >suta !16_S	et	f	\N
209065	sutades	?sutades =suta  (Ger  >sutama !27_V	et	f	\N
209081	elektriilöögi	?elektriilöögi =elektriilöögi  (SgN  >elektriilöögi !16_S	et	f	\N
209082	elektriilöögi	?elektriilöögi =elektriilöögi  (SgG  >elektriilöögi !16_S	et	f	\N
209083	elektriilöögi	?elektriilöögi =elektriilöögi  (SgG  >elektriilöök !22_S	et	f	\N
209084	elektriilöögi	?elektriilöögi =elektriilöögi  (SgP  >elektriilöög !22_S	et	f	\N
209085	elektriilöögi	?elektriilöögi =elektriilöögi  (SgAdt  >elektriilöög !22_S	et	f	\N
209086	elektriilöögi	?elektriilöögi =elektriilöögi  (IndPrPs_  >elektriilöökima !28_V	et	f	\N
209087	elektriilöögi	?elektriilöögi =elektriilöögi  (ImpPrSg2  >elektriilöökima !28_V	et	f	\N
209088	elektriilöögi	?elektriilöögi =ilöögi  (SgN  >elektri+ilöögi !16_S	et	f	\N
209089	elektriilöögi	?elektriilöögi =ilöögi  (SgG  >elektri+ilöögi !16_S	et	f	\N
209090	elektriilöögi	?elektriilöögi =ilöögi  (SgG  >elektri+ilöök !22_S	et	f	\N
209091	elektriilöögi	?elektriilöögi =ilöögi  (SgP  >elektri+ilöög !22_S	et	f	\N
209092	elektriilöögi	?elektriilöögi =ilöögi  (SgAdt  >elektri+ilöög !22_S	et	f	\N
209093	elektriilöögi	?elektriilöögi =elektriilöö  (SgN^  >elektriilöö !26_S	et	f	\N
209094	elektriilöögi	?elektriilöögi =elektriilöö  (SgG^  >elektriilöö !26_S	et	f	\N
209095	elektriilöögi	?elektriilöögi =ilöö  (SgN^  >elektri+ilöö !26_S	et	f	\N
209096	elektriilöögi	?elektriilöögi =ilöö  (SgG^  >elektri+ilöö !26_S	et	f	\N
209120	kinnipeetava	kinnipeetava =ava  (SgN  >kinni+peet+ava !17_S	et	f	\N
209121	kinnipeetava	kinnipeetava =ava  (SgG  >kinni+peet+ava !17_S	et	f	\N
209122	kinnipeetava	kinnipeetava =ava  (SgP  >kinni+peet+ava !17_S	et	f	\N
209139	omega	?omega =ome  (SgKom  >ome !16_S	et	f	\N
209153	rahastanud	?rahastanud =rahasta  (PtsPtPs  >rahastama !27_V	et	f	\N
209154	rahastanud	?rahastanud =rahastanu  (PlN  >rahastanu !01_S	et	f	\N
209155	rahastanud	?rahastanud =rahastanu  (IndPrSg2  >rahastanuma !27_V	et	f	\N
209156	rahastanud	?rahastanud =rahastanud  (ID  >rahastanud !41_A	et	f	\N
209157	rahastanud	?rahastanud =stanu  (PlN  >raha+stanu !17_S	et	f	\N
209183	kõrgustel	kõrgustel =kõrgus  (PlAd  >kõrgus !11~09_S	et	f	\N
209184	kõrgustel	"kõrgus %kõrge  )US_aS  <kõrge ;01_A	et	f	\N
209185	kõrgustel	kõrgustel =kõrgus  (PlAd  >kõrgune !10~12_A	et	f	\N
209186	kõrgustel	kõrgustel =us  (PlAd  >kõrg+uks !14_S	et	f	\N
209200	surmavalt	surmavalt =surmava  (SgAbl  >surmav !02_A	et	f	\N
209201	surmavalt	"surmav %surma  )V_vA  <surmama ;29_V	et	f	\N
209202	surmavalt	surmavalt =surmavalt  (ID  >surmavalt !41_D	et	f	\N
209203	surmavalt	"surmavalt %surma  )VALT_mD  <surmama ;29_V	et	f	\N
209204	surmavalt	"surmavalt %surmava  )LT_mD  <surmav ;02_A	et	f	\N
209205	surmavalt	surmavalt =ava  (SgAbl  >surm+ava !17_S	et	f	\N
209217	kahjutu	kahjutu =kahjutu  (SgN  >kahjutu !01_A	et	f	\N
209218	kahjutu	"kahjutu %kahju  )TU2_kA  <kahju ;16_S	et	f	\N
209219	kahjutu	"kahjutu %kahju  )TU2_kA  <kahju ;17_S	et	f	\N
209220	kahjutu	"kahjutu %kahju  )TU2_kA  <kahi ;24_S	et	f	\N
209221	kahjutu	kahjutu =kahjutu  (SgG  >kahjutu !01_A	et	f	\N
209235	troposfääris	?troposfääris =troposfääri  (SgIn  >troposfääri !16_S	et	f	\N
209146	algkapitalist	algkapitalist =talis  (SgP  >alg+kapi+taline !10_A	et	f	\N
209147	algkapitalist	"alg+kapi+taline %tali  )NE_aA  <alg+kapi+tali ;24_S	et	f	\N
209148	algkapitalist	"alg+kapi+taline %tali  )NE_aA  <alg+kapi+tali ;17_S	et	f	\N
209149	algkapitalist	algkapitalist =kapitali  (SgEl  >alg+kapital !19_S	et	f	\N
209150	algkapitalist	algkapitalist =kapitalis  (SgP  >alg+kapitaline !12_A	et	f	\N
209151	algkapitalist	"alg+kapitaline %kapitali  )NE_aA  <alg+kapital ;19_S	et	f	\N
209152	algkapitalist	algkapitalist =kapitalist  (SgN  >alg+kapitalist !22_S	et	f	\N
209160	koopia	koopia =koopia  (SgN  >koopia !01_S	et	f	\N
209161	koopia	koopia =koopia  (SgG  >koopia !01_S	et	f	\N
209163	elutegevuseks	elutegevuseks =use  (PlTr  >elu+tegev+usk !22_S	et	f	\N
209164	elutegevuseks	elutegevuseks =tegevuse  (SgTr  >elu+tegevus !11_S	et	f	\N
209165	elutegevuseks	"elu+tegevus %tegeva  )US_aS  <elu+tegev ;02_A	et	f	\N
209199	uv-c	### uv-c	et	f	\N
209206	neeldunud	neeldunud =neeldu  (PtsPtPs  >neelduma !27_V	et	f	\N
209207	neeldunud	neeldunud =neeldunu  (PlN  >neeldunu !01_S	et	f	\N
209208	neeldunud	"neeldunu %neeldu  )NU_vS  <neelduma ;27_V	et	f	\N
209209	neeldunud	neeldunud =neeldunud  (ID  >neeldunud !41_A	et	f	\N
209210	neeldunud	"neeldunud %neeldu  )NUD_vA  <neelduma ;27_V	et	f	\N
209222	kiirgus	kiirgus =kiirgu  (IndIpfSg3  >kiirguma !27_V	et	f	\N
209223	kiirgus	kiirgus =kiirgus  (SgN  >kiirgus !11~09_S	et	f	\N
209239	aerosoolid	aerosoolid =aerosooli  (PlN  >aerosool !22_S	et	f	\N
209240	aerosoolid	aerosoolid =sooli  (PlN  >aero+sool !22_S	et	f	\N
209249	pingutus	pingutus =pingutu  (SgIn  >pingutu !01_AS	et	f	\N
209250	pingutus	"pingutu %pingu  )TU2_kA  <ping ;22_S	et	f	\N
209251	pingutus	pingutus =pingutu  (IndIpfSg3  >pingutuma !27_V	et	f	\N
209252	pingutus	pingutus =pingutus  (SgN  >pingutus !11_S	et	f	\N
209253	pingutus	"pingutus %pinguta  )US_vS  <pingutama ;27_V	et	f	\N
209254	pingutus	"pingutus %pingu  )TUS2_aS  <ping ;22_S	et	f	\N
209257	teostamise	teostamise =teostamise  (SgG  >teostamine !12_S	et	f	\N
209258	teostamise	"teostamine %teosta  )MINE_vS  <teostama ;27_V	et	f	\N
209279	tarnijatele	tarnijatele =tarnija  (PlAll  >tarnija !01_S	et	f	\N
209280	tarnijatele	"tarnija %tarni  )JA_vS  <tarnima ;28_V	et	f	\N
209290	kasutusõigus	kasutusõigus =õigus  (SgN  >kasutus+õigus !11~09_S	et	f	\N
209291	kasutusõigus	"kasutus+õigus %õige  )US_aS  <kasutus+õige ;01_A	et	f	\N
209302	lindistus	lindistus =lindistus  (SgN  >lindistus !11_S	et	f	\N
209303	lindistus	"lindistus %lindista  )US_vS  <lindistama ;27_V	et	f	\N
209304	lindistus	lindistus =istu  (SgIn  >lind+ist !22_S	et	f	\N
209324	lehvitasid	lehvitasid =lehvita  (IndIpfSg2  >lehvitama !27_V	et	f	\N
209325	lehvitasid	lehvitasid =lehvita  (IndIpfPl3  >lehvitama !27_V	et	f	\N
209326	tulevadismid	?tulevadismid =tulevadismi  (PlN  >tulevadism !22_S	et	f	\N
209327	tulevadismid	?tulevadismid =tulevadismi  (IndPrSg2  >tulevadismima !28_V	et	f	\N
209328	tulevadismid	?tulevadismid =adismi  (PlN  >tulev+adismi !01_S	et	f	\N
209329	tulevadismid	?tulevadismid =adismi  (PlN  >tulev+adism !22_S	et	f	\N
209330	tulevadismid	?tulevadismid =vadismi  (PlN  >tule+vadismi !01_S	et	f	\N
209331	tulevadismid	?tulevadismid =vadismi  (PlN  >tule+vadism !22_S	et	f	\N
209348	snowboardiga	?snowboardiga =snowboardi  (SgKom  >snowboardi !01_S	et	f	\N
209349	snowboardiga	?snowboardiga =snowboardi  (SgKom  >snowboard !02_S	et	f	\N
209350	snowboardiga	?snowboardiga =snowboardi  (SgKom  >snowboart !22_S	et	f	\N
209368	kivised	kivised =kivise  (PlN  >kivine !10_A	et	f	\N
209369	kivised	"kivine %kivi  )NE_aA  <kivi ;17_S	et	f	\N
209375	rannades	?rannades =ranna  (PlIn  >ranna !16_S	et	f	\N
209376	riietunud	riietunud =riietu  (PtsPtPs  >riietuma !27_V	et	f	\N
209377	riietunud	riietunud =riietunu  (PlN  >riietunu !01_S	et	f	\N
209378	riietunud	"riietunu %riietu  )NU_vS  <riietuma ;27_V	et	f	\N
209379	riietunud	riietunud =riietunud  (ID  >riietunud !41_A	et	f	\N
209380	riietunud	"riietunud %riietu  )NUD_vA  <riietuma ;27_V	et	f	\N
209383	peterbuurisse	?peterbuurisse =peterbuuri  (SgIll  >peterbuuri !16_S	et	f	\N
209384	peterbuurisse	?peterbuurisse =peterbuuri  (SgIll  >peterbuur !22_S	et	f	\N
209385	peterbuurisse	?peterbuurisse =peterbuurisse  (SgG  >peterbuurisne !02_A	et	f	\N
209386	peterbuurisse	?peterbuurisse =peterbuurisse  (PlP  >peterbuuriss !22_S	et	f	\N
209398	pargides	?pargides =pargi  (PlIn  >parg !22_S	et	f	\N
209399	pargides	?pargides =pargi  (Ger  >pargima !28_V	et	f	\N
209410	piiritas	?piiritas =piirita  (IndIpfSg3  >piiritama !27_V	et	f	\N
209411	piiritas	?piiritas =ita  (SgIn  >piir+ita !16_S	et	f	\N
209412	piiritas	?piiritas =itas  (SgN  >piir+itas !07_S	et	f	\N
209414	karupoja	karupoja =poja  (SgN  >karu+poja !17_S	et	f	\N
209415	karupoja	karupoja =poja  (SgG  >karu+poja !17_S	et	f	\N
209416	karupoja	karupoja =poja  (SgG  >karu+poeg !22_S	et	f	\N
209417	karupoja	karupoja =poja  (SgP  >karu+poja !17_S	et	f	\N
209422	peaegu	?peaegu =peaegu  (IndPrPs_  >peaeguma !27_V	et	f	\N
209423	peaegu	?peaegu =peaegu  (ImpPrSg2  >peaeguma !27_V	et	f	\N
209424	peaegu	?peaegu =egu  (SgN  >pea+egu !17_S	et	f	\N
209425	peaegu	?peaegu =egu  (SgG  >pea+egu !17_S	et	f	\N
209426	peaegu	?peaegu =egu  (SgP  >pea+egu !17_S	et	f	\N
209443	kuldruumi	kuldruumi =ruumi  (SgG  >kuld+ruum !22_S	et	f	\N
209174	paksuse	paksuse =paksuse  (SgG  >paksus !11~09_S	et	f	\N
209175	paksuse	"paksus %paks  )US_aS  <paks ;22_AS	et	f	\N
209176	paksuse	paksuse =paksuse  (SgG  >paksune !10~12_A	et	f	\N
209216	uv-a	### uv-a	et	f	\N
209224	uv-b	### uv-b	et	f	\N
209225	surmav	surmav =surma  (PtsPrPs  >surmama !29_V	et	f	\N
209226	surmav	surmav =surmav  (SgN  >surmav !02_A	et	f	\N
209227	surmav	"surmav %surma  )V_vA  <surmama ;29_V	et	f	\N
209228	kahjustamine	kahjustamine =kahjustamine  (SgN  >kahjustamine !12_S	et	f	\N
209229	kahjustamine	"kahjustamine %kahjusta  )MINE_vS  <kahjustama ;27_V	et	f	\N
209268	palkamisele	palkamisele =palkamise  (SgAll  >palkamine !12_S	et	f	\N
209269	palkamisele	"palkamine %palka  )MINE_vS  <palkama ;29_V	et	f	\N
209294	omandiõigus	omandiõigus =õigus  (SgN  >omandi+õigus !11~09_S	et	f	\N
209295	omandiõigus	"omandi+õigus %õige  )US_aS  <omandi+õige ;01_A	et	f	\N
209311	sinikas	sinikas =sinika  (SgIn  >sinikas !02_S	et	f	\N
209312	sinikas	sinikas =sinikas  (SgN  >sinikas !02_S	et	f	\N
209313	hüpleda	### hüpleda	et	f	\N
209337	känud	?känud =känu  (PlN  >känu !17_S	et	f	\N
209338	känud	?känud =känu  (IndPrSg2  >känuma !27_V	et	f	\N
209360	kievis	?kievis =kievi  (SgIn  >kievi !16_S	et	f	\N
209361	kievis	?kievis =kievi  (SgIn  >kiev !22_S	et	f	\N
209362	kievis	?kievis =kievi  (IndIpfSg3  >kievima !28_V	et	f	\N
209363	kievis	?kievis =kievis  (SgN  >kievis !09_S	et	f	\N
209407	pushkinis	?pushkinis =pushkini  (SgIn  >pushkin !02_S	et	f	\N
209408	pushkinis	?pushkinis =pushkinis  (SgN  >pushkinis !11_S	et	f	\N
209413	päevatasime	?päevatasime =päevata  (IndIpfPl1  >päevatama !27_V	et	f	\N
209418	kardanud	?kardanud =karda  (PtsPtPs  >kartama !29_V	et	f	\N
209419	kardanud	?kardanud =kardanu  (PlN  >kardanu !01_S	et	f	\N
209420	kardanud	?kardanud =kardanu  (IndPrSg2  >kardanuma !27_V	et	f	\N
209421	kardanud	?kardanud =kardanud  (ID  >kardanud !41_A	et	f	\N
209454	küündinud	küündinud =küündi  (PtsPtPs  >küündima !27~28_V	et	f	\N
209455	küündinud	küündinud =küündinu  (PlN  >küündinu !01_S	et	f	\N
209456	küündinud	"küündinu %küündi  )NU_vS  <küündima ;27_V	et	f	\N
209457	küündinud	"küündinu %küündi  )NU_vS  <küündima ;28_V	et	f	\N
209458	küündinud	küündinud =küündinud  (ID  >küündinud !41_A	et	f	\N
209459	küündinud	"küündinud %küündi  )NUD_vA  <küündima ;27_V	et	f	\N
209460	küündinud	"küündinud %küündi  )NUD_vA  <küündima ;28_V	et	f	\N
209522	kodukolle	kodukolle =kolle  (SgN  >kodu+kolle !06_S	et	f	\N
209523	kodukolle	kodukolle =kolle  (PlP  >kodu+koll !22_S	et	f	\N
209527	mõisavana	mõisavana =vana  (SgN  >mõisa+vana !17_AS	et	f	\N
209528	mõisavana	mõisavana =vana  (SgG  >mõisa+vana !17_AS	et	f	\N
209529	mõisavana	mõisavana =vana  (SgP  >mõisa+vana !17_AS	et	f	\N
209541	naese	?naese =naese  (SgN  >naese !06_S	et	f	\N
209542	naese	?naese =naese  (SgG  >naese !06_S	et	f	\N
209543	naese	?naese =naese  (SgG  >naene !10_A	et	f	\N
209544	naese	?naese =naese  (IndPrPs_  >naesema !28_V	et	f	\N
209545	naese	?naese =naese  (ImpPrSg2  >naesema !28_V	et	f	\N
209548	võreldatakse	?võreldatakse =võrelda  (IndPrIps  >võreldama !27_V	et	f	\N
209549	võreldatakse	?võreldatakse =võreldatakse  (SgG  >võreldatakne !02_A	et	f	\N
209550	võreldatakse	?võreldatakse =võreldatakse  (PlP  >võreldataks !22_S	et	f	\N
209569	roomaanis	?roomaanis =roomaani  (SgIn  >roomaani !16_S	et	f	\N
209570	roomaanis	?roomaanis =roomaani  (SgIn  >roomaan !22_S	et	f	\N
209571	roomaanis	?roomaanis =roomaani  (IndIpfSg3  >roomaanima !28_V	et	f	\N
209572	roomaanis	?roomaanis =roomaanis  (SgN  >roomaanis !09_S	et	f	\N
209573	roomaanis	?roomaanis =ani  (SgIn  >rooma+ani !17_S	et	f	\N
209574	roomaanis	?roomaanis =anis  (SgN  >rooma+anis !09_S	et	f	\N
209575	roomaanis	?roomaanis =maani  (SgIn  >roo+maani !16_S	et	f	\N
209576	roomaanis	?roomaanis =maani  (SgIn  >roo+maan !22_S	et	f	\N
209577	roomaanis	?roomaanis =maanis  (SgN  >roo+maanis !09_S	et	f	\N
209582	tõnule	?tõnule =tõnu  (SgAll  >tõnu !17_S	et	f	\N
209583	tõnule	?tõnule =tõnule  (IndPrPs_  >tõnulema !27_V	et	f	\N
209584	tõnule	?tõnule =tõnule  (ImpPrSg2  >tõnulema !27_V	et	f	\N
209616	ohverda	ohverda =ohverda  (IndPrPs_  >ohverdama !27_V	et	f	\N
209617	ohverda	ohverda =ohverda  (ImpPrSg2  >ohverdama !27_V	et	f	\N
209632	prillupile	?prillupile =prillupi  (SgAll  >prillupi !01_S	et	f	\N
209633	prillupile	?prillupile =prillupi  (SgAll  >prillup !02_S	et	f	\N
209634	prillupile	?prillupile =prillupi  (SgAll  >prillupp !22_S	et	f	\N
209635	prillupile	?prillupile =upi  (SgAll  >prill+upi !16_S	et	f	\N
209636	prillupile	?prillupile =upi  (SgAll  >prill+upp !22_S	et	f	\N
209637	prillupit	?prillupit =prillupi  (SgP  >prillupi !01_S	et	f	\N
209638	prillupit	?prillupit =prillupi  (SgP  >prillup !02_S	et	f	\N
209639	prillupit	?prillupit =upi  (SgP  >prill+upi !16_S	et	f	\N
209640	prillupit	?prillupit =upit  (SgN  >prill+upit !02_S	et	f	\N
209644	püüdsib	?püüdsib =püüdsi  (IndPrSg3  >püüdsima !28_V	et	f	\N
209655	nõustunud	nõustunud =nõustu  (PtsPtPs  >nõustuma !27_V	et	f	\N
209656	nõustunud	nõustunud =nõustunu  (PlN  >nõustunu !01_S	et	f	\N
209212	peegeldatud	peegeldatud =peegeldatu  (PlN  >peegeldatu !01_S	et	f	\N
209213	peegeldatud	"peegeldatu %peegelda  )TU1_vS  <peegeldama ;27_V	et	f	\N
209214	peegeldatud	peegeldatud =peegeldatud  (ID  >peegeldatud !41_A	et	f	\N
209215	peegeldatud	"peegeldatud %peegelda  )TUD_vA  <peegeldama ;27_V	et	f	\N
209232	piirata	piirata =piira  (SgAb  >piird !22_S	et	f	\N
209233	piirata	piirata =piira  (Inf  >piirama !29_V	et	f	\N
209234	piirata	piirata =piira  (IndPrIps_  >piirama !29_V	et	f	\N
209261	keerukust	keerukust =keerukus  (SgP  >keerukus !11_S	et	f	\N
209262	keerukust	"keerukus %keeruka  )US_aS  <keerukas ;02_A	et	f	\N
209270	saadava	saadava =saadava  (SgG  >saadav !02_A	et	f	\N
209271	saadava	"saadav %saa  )TAV_vAS  <saama ;37_V	et	f	\N
209275	lühiajalised	lühiajalised =ajalise  (PlN  >lühi+ajaline !12_A	et	f	\N
209276	lühiajalised	"lühi+ajaline %aja  )LINE_aA  <lühi+aeg ;22_S	et	f	\N
209281	eraldised	eraldised =eraldise  (PlN  >eraldis !11_S	et	f	\N
209282	eraldised	eraldised =eraldise  (PlN  >eraldine !12_A	et	f	\N
209283	eraldised	"eraldine %eraldi  )NE_aA  <eraldi ;01_S	et	f	\N
209287	ebaaus	ebaaus =au  (SgIn  >eba+au !26_S	et	f	\N
209288	ebaaus	ebaaus =aus  (SgN  >eba+aus !02_A	et	f	\N
209289	oodavam	?oodavam =oodavam  (SgN  >oodavam !02_A	et	f	\N
209292	sõlmimist	sõlmimist =sõlmimis  (SgP  >sõlmimine !12_S	et	f	\N
209293	sõlmimist	"sõlmimine %sõlmi  )MINE_vS  <sõlmima ;28_V	et	f	\N
209298	õppijakeele	?õppijakeele =õppijakee  (SgAll  >õppijakee !26_S	et	f	\N
209299	õppijakeele	?õppijakeele =õppijakeele  (SgN  >õppijakeele !16_S	et	f	\N
209300	õppijakeele	?õppijakeele =õppijakeele  (SgG  >õppijakeele !16_S	et	f	\N
209301	õppijakeele	?õppijakeele =õppijakeele  (PlP  >õppijakeel !22_S	et	f	\N
209309	rohekas	rohekas =roheka  (SgIn  >rohekas !02_A	et	f	\N
209310	rohekas	rohekas =rohekas  (SgN  >rohekas !02_A	et	f	\N
209316	teegu	?teegu =teegu  (SgN  >teegu !16_S	et	f	\N
209317	teegu	?teegu =teegu  (SgG  >teegu !16_S	et	f	\N
209318	teegu	?teegu =teegu  (IndPrPs_  >teeguma !27_V	et	f	\N
209319	teegu	?teegu =teegu  (IndPrPs_  >teekuma !28_V	et	f	\N
209320	teegu	?teegu =teegu  (ImpPrSg2  >teeguma !27_V	et	f	\N
209321	teegu	?teegu =teegu  (ImpPrSg2  >teekuma !28_V	et	f	\N
209387	peterbuuris	?peterbuuris =peterbuuri  (SgIn  >peterbuuri !16_S	et	f	\N
209388	peterbuuris	?peterbuuris =peterbuuri  (SgIn  >peterbuur !22_S	et	f	\N
209389	peterbuuris	?peterbuuris =peterbuuri  (IndIpfSg3  >peterbuurima !28_V	et	f	\N
209390	peterbuuris	?peterbuuris =peterbuuris  (SgN  >peterbuuris !09_S	et	f	\N
209393	petergoffisse	?petergoffisse =petergoffisse  (SgG  >petergoffisne !02_A	et	f	\N
209394	petergoffisse	?petergoffisse =petergoffisse  (PlP  >petergoffiss !22_S	et	f	\N
209433	tellitud	tellitud =telli  (PtsPtIps  >tellima !28_V	et	f	\N
209434	tellitud	tellitud =tellitu  (PlN  >tellitu !01_AS	et	f	\N
209435	tellitud	"tellitu %telli  )TU1_vS  <tellima ;28_V	et	f	\N
209436	tellitud	tellitud =tellitud  (ID  >tellitud !41_A	et	f	\N
209437	tellitud	"tellitud %telli  )TUD_vA  <tellima ;28_V	et	f	\N
209461	kuueteistkümnendal	?kuueteistkümnendal =kuueteistkümnenda  (SgAd  >kuueteistkümnenda !16_S	et	f	\N
209462	kuueteistkümnendal	?kuueteistkümnendal =kuueteistkümnendal  (SgN  >kuueteistkümnendal !02_S	et	f	\N
209463	kuueteistkümnendal	?kuueteistkümnendal =kümnenda  (SgAd  >kuue+teist+kümnenda !01_S	et	f	\N
209464	kuueteistkümnendal	?kuueteistkümnendal =teistkümnenda  (SgAd  >kuue+teistkümnenda !16_S	et	f	\N
209465	kuueteistkümnendal	?kuueteistkümnendal =teistkümnendal  (SgN  >kuue+teistkümnendal !02_S	et	f	\N
209466	kuueteistkümnendal	?kuueteistkümnendal =eteistkümnenda  (SgAd  >kuu+eteistkümnenda !16_S	et	f	\N
209467	kuueteistkümnendal	?kuueteistkümnendal =eteistkümnendal  (SgN  >kuu+eteistkümnendal !02_S	et	f	\N
209468	realistikuks	?realistikuks =realistiku  (SgTr  >realistik !25_S	et	f	\N
209469	realistikuks	?realistikuks =realistiku  (KndPrPs  >realistikuma !27_V	et	f	\N
209470	realistikuks	?realistikuks =listiku  (SgTr  >rea+listiku !01_S	et	f	\N
209471	realistikuks	?realistikuks =listiku  (SgTr  >rea+listik !02_S	et	f	\N
209478	õnnetud	õnnetud =õnnetu  (PlN  >õnnetu !01_A	et	f	\N
209479	õnnetud	"õnnetu %õnne  )TU2_kA  <õnn ;22_S	et	f	\N
209501	prillupi	?prillupi =prillupi  (SgN  >prillupi !01_S	et	f	\N
209502	prillupi	?prillupi =prillupi  (SgG  >prillupi !01_S	et	f	\N
209503	prillupi	?prillupi =prillupi  (SgG  >prillup !02_S	et	f	\N
209504	prillupi	?prillupi =prillupi  (SgG  >prillupp !22_S	et	f	\N
209505	prillupi	?prillupi =prillupi  (IndPrPs_  >prilluppima !28_V	et	f	\N
209506	prillupi	?prillupi =prillupi  (ImpPrSg2  >prilluppima !28_V	et	f	\N
209507	prillupi	?prillupi =upi  (SgN  >prill+upi !16_S	et	f	\N
209508	prillupi	?prillupi =upi  (SgG  >prill+upi !16_S	et	f	\N
209509	prillupi	?prillupi =upi  (SgG  >prill+upp !22_S	et	f	\N
209514	aimas	aimas =aima  (SgIn  >aim !22_S	et	f	\N
209515	aimas	aimas =aima  (IndIpfSg3  >aimama !29_V	et	f	\N
209518	löösid	?löösid =löö  (PlP  >löö !26_S	et	f	\N
209519	löösid	?löösid =löösi  (PlN  >löösi !16_S	et	f	\N
209520	löösid	?löösid =löösi  (PlN  >löös !22_S	et	f	\N
209521	löösid	?löösid =löösi  (IndPrSg2  >löösima !28_V	et	f	\N
209524	kaitsja	kaitsja =kaitsja  (SgN  >kaitsja !01_S	et	f	\N
209525	kaitsja	"kaitsja %kaits  )JA_vS  <kaitsma ;32_V	et	f	\N
209236	troposfääris	?troposfääris =troposfääri  (SgIn  >troposfäär !22_S	et	f	\N
209237	troposfääris	?troposfääris =troposfääri  (IndIpfSg3  >troposfäärima !28_V	et	f	\N
209238	troposfääris	?troposfääris =troposfääris  (SgN  >troposfääris !09_S	et	f	\N
209244	vähendanud	vähendanud =vähenda  (PtsPtPs  >vähendama !27_V	et	f	\N
209245	vähendanud	vähendanud =vähendanu  (PlN  >vähendanu !01_S	et	f	\N
209246	vähendanud	"vähendanu %vähenda  )NU_vS  <vähendama ;27_V	et	f	\N
209247	vähendanud	vähendanud =vähendanud  (ID  >vähendanud !41_A	et	f	\N
209248	vähendanud	"vähendanud %vähenda  )NUD_vA  <vähendama ;27_V	et	f	\N
209255	suurenemist	suurenemist =suurenemis  (SgP  >suurenemine !12_S	et	f	\N
209256	suurenemist	"suurenemine %suurene  )MINE_vS  <suurenema ;27_V	et	f	\N
209259	haldamise	haldamise =haldamise  (SgG  >haldamine !12_S	et	f	\N
209260	haldamise	"haldamine %halda  )MINE_vS  <haldama ;29_V	et	f	\N
209277	ostjate	ostjate =ostja  (PlG  >ostja !01_S	et	f	\N
209278	ostjate	"ostja %ost  )JA_vS  <ostma ;34_V	et	f	\N
209284	ohustavat	ohustavat =ohusta  (KvtPrPs  >ohustama !27_V	et	f	\N
209285	ohustavat	ohustavat =ohustava  (SgP  >ohustav !02_A	et	f	\N
209286	ohustavat	"ohustav %ohusta  )V_vA  <ohustama ;27_V	et	f	\N
209305	vestlustest	vestlustest =vestlus  (PlEl  >vestlus !11~09_S	et	f	\N
209306	vestlustest	vestlustest =test  (SgN  >vestlus+test !22_S	et	f	\N
209314	rõmustas	?rõmustas =rõmusta  (SgIn  >rõmusta !01_S	et	f	\N
209315	rõmustas	?rõmustas =rõmusta  (IndIpfSg3  >rõmustama !27_V	et	f	\N
209322	peitad	?peitad =peita  (PlN  >peita !16_S	et	f	\N
209323	peitad	?peitad =peita  (IndPrSg2  >peitama !27_V	et	f	\N
209339	juatäis	?juatäis =juatäi  (SgIn  >juatäi !26_S	et	f	\N
209340	juatäis	?juatäis =juatäis  (SgN  >juatäis !22_S	et	f	\N
209351	egiptusesse	?egiptusesse =egiptuse  (SgIll  >egiptus !11_S	et	f	\N
209352	egiptusesse	?egiptusesse =egiptuses  (SgAdt  >egiptusene !12_A	et	f	\N
209353	egiptusesse	?egiptusesse =egiptusesse  (SgG  >egiptusesne !02_A	et	f	\N
209354	egiptusesse	?egiptusesse =egiptusesse  (PlP  >egiptusess !22_S	et	f	\N
209355	odessas	?odessas =odessa  (SgIn  >odessa !01_S	et	f	\N
209366	kuroortne	?kuroortne =kuroortne  (SgN  >kuroortne !02_A	et	f	\N
209367	kuroortne	?kuroortne =kuroortne  (PlP  >kuroortn !22_S	et	f	\N
209395	jalatsime	?jalatsime =jalatsi  (IndPrPl1  >jalatsima !28_V	et	f	\N
209396	jalatsime	?jalatsime =tsime  (SgN  >jala+tsime !16_S	et	f	\N
209397	jalatsime	?jalatsime =tsime  (SgG  >jala+tsime !16_S	et	f	\N
209409	ladoga	?ladoga =lado  (SgKom  >lado !17~16_S	et	f	\N
209485	väärtustest	väärtustest =väärtus  (PlEl  >väärtus !11~09_S	et	f	\N
209486	väärtustest	väärtustest =test  (SgN  >väärtus+test !22_S	et	f	\N
209487	väärtustest	väärtustest =us  (PlEl  >väärt+uks !14_S	et	f	\N
209488	väärtustest	väärtustest =tuste  (PlEl  >väär+tust !22_S	et	f	\N
209537	kujutamises	kujutamises =kujutamise  (SgIn  >kujutamine !12_S	et	f	\N
209538	kujutamises	"kujutamine %kujuta  )MINE_vS  <kujutama ;27_V	et	f	\N
209551	prillup	?prillup =prillup  (SgN  >prillup !02_S	et	f	\N
209557	kremeri	?kremeri =kremeri  (SgN  >kremeri !01_S	et	f	\N
209558	kremeri	?kremeri =kremeri  (SgG  >kremeri !01_S	et	f	\N
209559	kremeri	?kremeri =kremeri  (SgG  >kremer !02_S	et	f	\N
209560	kõhklev	kõhklev =kõhkle  (PtsPrPs  >kõhklema !30_V	et	f	\N
209561	kõhklev	kõhklev =kõhklev  (SgN  >kõhklev !02_A	et	f	\N
209562	kõhklev	"kõhklev %kõhkle  )V_vA  <kõhklema ;30_V	et	f	\N
209567	jultumus	jultumus =jultumus  (SgN  >jultumus !11_S	et	f	\N
209568	jultumus	"jultumus %jultu  )MUS_vS  <jultuma ;27_V	et	f	\N
209593	võstlus	?võstlus =võstlu  (SgIn  >võstlu !01_S	et	f	\N
209594	võstlus	?võstlus =võstlu  (IndIpfSg3  >võstluma !27_V	et	f	\N
209595	võstlus	?võstlus =võstlus  (SgN  >võstlus !11~09_S	et	f	\N
209597	võrraks	?võrraks =võrra  (KndPrPs  >võrrama !29_V	et	f	\N
209628	käitumispsühholoogia	käitumispsühholoogia =psühholoogia  (SgN  >käitumis+psühholoogia !01_S	et	f	\N
209629	käitumispsühholoogia	käitumispsühholoogia =psühholoogia  (SgG  >käitumis+psühholoogia !01_S	et	f	\N
209631	kremer	?kremer =kremer  (SgN  >kremer !02_S	et	f	\N
209646	irvitavad	irvitavad =irvita  (IndPrPl3  >irvitama !27_V	et	f	\N
209647	irvitavad	irvitavad =irvitava  (PlN  >irvitav !02_A	et	f	\N
209648	irvitavad	"irvitav %irvi  )TAV_vAS  <irvima ;28_V	et	f	\N
209649	irvitavad	"irvitav %irvita  )V_vA  <irvitama ;27_V	et	f	\N
209673	perepea	perepea =pea  (SgN  >pere+pea !26_S	et	f	\N
209674	perepea	perepea =pea  (SgG  >pere+pea !26_S	et	f	\N
209682	inemestele	?inemestele =inemes  (PlAll  >inemene !12_A	et	f	\N
209683	inemestele	?inemestele =inemestele  (IndPrPs_  >inemestelema !36_V	et	f	\N
209684	inemestele	?inemestele =inemestele  (ImpPrSg2  >inemestelema !36_V	et	f	\N
209722	hukatus	hukatus =hukatu  (SgIn  >hukatu !01_S	et	f	\N
209723	hukatus	"hukatu %huka  )TU1_vS  <hukkama ;29_V	et	f	\N
209724	hukatus	hukatus =hukatus  (SgN  >hukatus !11_S	et	f	\N
209725	hukatus	"hukatus %huka  )TUS1_aS  <hukkama ;29_V	et	f	\N
209741	nendale	?nendale =nenda  (SgAll  >nenda !16_S	et	f	\N
209742	nendale	?nendale =nendale  (IndPrPs_  >nendalema !27_V	et	f	\N
209743	nendale	?nendale =nendale  (ImpPrSg2  >nendalema !27_V	et	f	\N
209265	maksukohuslasi	?maksukohuslasi =slasi  (SgG  >maksu+kohu+slasi !17_S	et	f	\N
209266	maksukohuslasi	?maksukohuslasi =slasi  (SgP  >maksu+kohu+slasi !17_S	et	f	\N
209267	maksukohuslasi	?maksukohuslasi =kohuslasi  (PlP  >maksu+kohuslane !12_S	et	f	\N
209272	poollegaalselt	poollegaalselt =legaalse  (SgAbl  >pool+legaalne !02_A	et	f	\N
209273	poollegaalselt	poollegaalselt =legaalselt  (ID  >pool+legaalselt !41_D	et	f	\N
209274	poollegaalselt	"pool+legaalselt %legaalse  )LT_mD  <pool+legaalne ;02_A	et	f	\N
209296	tasumist	tasumist =tasumis  (SgP  >tasumine !12_S	et	f	\N
209297	tasumist	"tasumine %tasu  )MINE_vS  <tasuma ;27_V	et	f	\N
209307	punakas	punakas =punaka  (SgIn  >punakas !02_A	et	f	\N
209308	punakas	punakas =punakas  (SgN  >punakas !02_A	et	f	\N
209332	paraegu	?paraegu =paraegu  (IndPrPs_  >paraeguma !27_V	et	f	\N
209333	paraegu	?paraegu =paraegu  (ImpPrSg2  >paraeguma !27_V	et	f	\N
209334	paraegu	?paraegu =egu  (SgN  >para+egu !17_S	et	f	\N
209335	paraegu	?paraegu =egu  (SgG  >para+egu !17_S	et	f	\N
209336	paraegu	?paraegu =egu  (SgP  >para+egu !17_S	et	f	\N
209341	pildituks	pildituks =pilditu  (SgTr  >pilditu !01_AS	et	f	\N
209342	pildituks	"pilditu %pildi  )TU2_kA  <pilt ;22_S	et	f	\N
209343	pildituks	pildituks =tuks  (SgN  >pildi+tuks !22_S	et	f	\N
209344	italiasse	?italiasse =italia  (SgIll  >italia !01_S	et	f	\N
209345	italiasse	?italiasse =italias  (SgAdt  >italias !11_S	et	f	\N
209346	italiasse	?italiasse =italiasse  (SgG  >italiasne !02_A	et	f	\N
209347	italiasse	?italiasse =italiasse  (PlP  >italiass !22_S	et	f	\N
209356	kievis	?kievis =kievi  (SgIn  >kievi !16_S	et	f	\N
209357	kievis	?kievis =kievi  (SgIn  >kiev !22_S	et	f	\N
209358	kievis	?kievis =kievi  (IndIpfSg3  >kievima !28_V	et	f	\N
209359	kievis	?kievis =kievis  (SgN  >kievis !09_S	et	f	\N
209364	odessa	?odessa =odessa  (SgN  >odessa !01_S	et	f	\N
209365	odessa	?odessa =odessa  (SgG  >odessa !01_S	et	f	\N
209370	öökluubid	?öökluubid =öökluubi  (PlN  >öökluubi !16_S	et	f	\N
209371	öökluubid	?öökluubid =öökluubi  (PlN  >öökluup !22_S	et	f	\N
209372	öökluubid	?öökluubid =öökluubi  (IndPrSg2  >öökluupima !28_V	et	f	\N
209373	öökluubid	?öökluubid =kluubi  (PlN  >öö+kluubi !16_S	et	f	\N
209374	öökluubid	?öökluubid =kluubi  (PlN  >öö+kluup !22_S	et	f	\N
209381	huumoristid	?huumoristid =huumoristi  (PlN  >huumorist !22_S	et	f	\N
209382	huumoristid	?huumoristid =huumoristi  (IndPrSg2  >huumoristima !28_V	et	f	\N
209391	arhitektuurilised	arhitektuurilised =arhitektuurilise  (PlN  >arhitektuuriline !12_A	et	f	\N
209392	arhitektuurilised	"arhitektuuriline %arhitektuuri  )LINE_aA  <arhitektuur ;22_S	et	f	\N
209400	neva	?neva =neva  (SgN  >neva !17_S	et	f	\N
209401	neva	?neva =neva  (SgG  >neva !17_S	et	f	\N
209402	neva	?neva =neva  (SgP  >neva !17_S	et	f	\N
209403	neva	?neva =neva  (IndPrPs_  >nevama !27_V	et	f	\N
209404	neva	?neva =neva  (ImpPrSg2  >nevama !27_V	et	f	\N
209405	vanemata	vanemata =vanema  (SgAb  >vanem !02_AS	et	f	\N
209406	vanemata	"vanem %vane  )M_cA  <vana ;17_AS	et	f	\N
209427	maalesõide	?maalesõide =maalesõi  (PlG  >maalesõi !26_S	et	f	\N
209428	maalesõide	?maalesõide =maalesõide  (PlP  >maalesõid !22_S	et	f	\N
209429	maalesõide	?maalesõide =sõi  (PlG  >maale+sõi !26_S	et	f	\N
209430	maalesõide	?maalesõide =sõide  (SgN  >maale+sõide !06_S	et	f	\N
209431	maalesõide	?maalesõide =lesõi  (PlG  >maa+lesõi !26_S	et	f	\N
209432	maalesõide	?maalesõide =lesõide  (PlP  >maa+lesõid !22_S	et	f	\N
209438	öine	öine =öine  (SgN  >öine !10_A	et	f	\N
209439	öine	"öine %öi  )NE_aA  <öö ;26_S	et	f	\N
209440	särasid	särasid =sära  (PlP  >sära !17_S	et	f	\N
209441	särasid	särasid =sära  (IndIpfSg2  >särama !27_V	et	f	\N
209442	särasid	särasid =sära  (IndIpfPl3  >särama !27_V	et	f	\N
209445	eksponeeritud	eksponeeritud =eksponeeri  (PtsPtIps  >eksponeerima !28_V	et	f	\N
209447	eksponeeritud	eksponeeritud =eksponeeritu  (PlN  >eksponeeritu !01_S	et	f	\N
209448	eksponeeritud	"eksponeeritu %eksponeeri  )TU1_vS  <eksponeerima ;28_V	et	f	\N
209449	eksponeeritud	eksponeeritud =eksponeeritud  (ID  >eksponeeritud !41_A	et	f	\N
209450	eksponeeritud	"eksponeeritud %eksponeeri  )TUD_vA  <eksponeerima ;28_V	et	f	\N
209472	riikaks	?riikaks =riika  (SgTr  >riikas !02_A	et	f	\N
209473	riikaks	?riikaks =riika  (SgTr  >riika !16_S	et	f	\N
209474	riikaks	?riikaks =riika  (KndPrPs  >riikama !29_V	et	f	\N
209475	riikaks	?riikaks =aks  (SgN  >riik+aks !22_S	et	f	\N
209480	vaised	?vaised =vaise  (PlN  >vaise !06_S	et	f	\N
209481	vaised	?vaised =vaise  (IndPrSg2  >vaisema !28_V	et	f	\N
209497	maanaine	maanaine =aine  (SgN  >maan+aine !06_S	et	f	\N
209498	maanaine	maanaine =aine  (SgG  >maan+aine !06_S	et	f	\N
209499	maanaine	maanaine =aine  (PlP  >maan+ain !22_S	et	f	\N
209500	maanaine	maanaine =naine  (SgN  >maa+naine !12_S	et	f	\N
209511	tänapäevastega	tänapäevastega =aste  (SgKom  >täna+päev+aste !06_S	et	f	\N
209512	tänapäevastega	tänapäevastega =päevas  (PlKom  >täna+päevane !10_A	et	f	\N
209513	tänapäevastega	"täna+päevane %päeva  )NE_aA  <täna+päev ;22_S	et	f	\N
209546	psüholoogiline	?psüholoogiline =psüholoogiline  (SgN  >psüholoogiline !12_A	et	f	\N
209547	psüholoogiline	?psüholoogiline =psüholoogiline  (PlP  >psüholoogilin !19_S	et	f	\N
209444	kuldruumi	kuldruumi =ruumi  (SgP  >kuld+ruum !22_S	et	f	\N
209446	kuldruumi	kuldruumi =ruumi  (SgAdt  >kuld+ruum !22_S	et	f	\N
209451	meeldivam	meeldivam =meeldivam  (SgN  >meeldivam !02_A	et	f	\N
209452	meeldivam	"meeldivam %meeldi  )VAM_cA  <meeldima ;27_V	et	f	\N
209453	meeldivam	"meeldivam %meeldiva  )M_cA  <meeldiv ;02_A	et	f	\N
209476	riikasteks	riikasteks =aste  (SgTr  >riik+aste !06_S	et	f	\N
209477	riikasteks	riikasteks =aste  (PlTr  >riik+ast !22_S	et	f	\N
209482	väärikust	väärikust =vääriku  (SgEl  >väärik !02_S	et	f	\N
209483	väärikust	väärikust =väärikus  (SgP  >väärikus !11_S	et	f	\N
209484	väärikust	"väärikus %väärika  )US_aS  <väärikas ;02_A	et	f	\N
209489	eduardi	?eduardi =eduardi  (SgG  >eduart !22_S	et	f	\N
209490	eduardi	?eduardi =eduardi  (SgP  >eduard !22_S	et	f	\N
209491	eduardi	?eduardi =eduardi  (SgAdt  >eduard !22_S	et	f	\N
209492	eduardi	?eduardi =eduardi  (IndPrPs_  >eduartima !28_V	et	f	\N
209493	eduardi	?eduardi =eduardi  (ImpPrSg2  >eduartima !28_V	et	f	\N
209494	eduardi	?eduardi =ardi  (SgG  >edu+art !22_S	et	f	\N
209495	eduardi	?eduardi =ardi  (SgP  >edu+ard !22_S	et	f	\N
209496	eduardi	?eduardi =ardi  (SgAdt  >edu+ard !22_S	et	f	\N
209510	lugupidada	### lugupidada	et	f	\N
209516	isekas	isekas =iseka  (SgIn  >isekas !02_A	et	f	\N
209517	isekas	isekas =isekas  (SgN  >isekas !02_A	et	f	\N
209530	hirmustab	?hirmustab =hirmusta  (IndPrSg3  >hirmustama !27_V	et	f	\N
209531	psühhologiline	psühhologiline =logiline  (SgN  >psühho+logiline !12_A	et	f	\N
209532	psühhologiline	"psühho+logiline %logi  )LINE_aA  <psühho+logi ;17_S	et	f	\N
209533	püüdlev	püüdlev =püüdle  (PtsPrPs  >püüdlema !30_V	et	f	\N
209534	püüdlev	püüdlev =püüdlev  (SgN  >püüdlev !02_A	et	f	\N
209535	püüdlev	"püüdlev %püüdle  )V_vA  <püüdlema ;30_V	et	f	\N
209563	kiredalt	?kiredalt =kiredalt  (ID  >kiredalt !41_D	et	f	\N
209564	kiredalt	?kiredalt =dalt  (SgN  >kire+dalt !22_S	et	f	\N
209565	tõnul	?tõnul =tõnu  (SgAd  >tõnu !17_S	et	f	\N
209566	tõnul	?tõnul =tõnul  (SgN  >tõnul !02_S	et	f	\N
209578	vilitsuses	?vilitsuses =vilitsuse  (SgIn  >vilitsus !11_S	et	f	\N
209579	vilitsuses	?vilitsuses =tsuse  (SgIn  >vili+tsuse !16_S	et	f	\N
209580	vilitsuses	?vilitsuses =tsuses  (SgN  >vili+tsuses !09_S	et	f	\N
209588	tõimub	?tõimub =tõimu  (IndPrSg3  >tõimuma !27_V	et	f	\N
209591	armukadedus	armukadedus =kadedus  (SgN  >armu+kadedus !11_S	et	f	\N
209592	armukadedus	"armu+kadedus %kadeda  )US_aS  <armu+kade ;02_A	et	f	\N
209600	hellatundeline	?hellatundeline =hellatundeline  (SgN  >hellatundeline !12_A	et	f	\N
209601	hellatundeline	?hellatundeline =hellatundeline  (PlP  >hellatundelin !19_S	et	f	\N
209621	keedagi	keedagi =kee  (Inf^  >keema !37_V	et	f	\N
209622	keedagi	keedagi =kee  (IndPrIps_^  >keema !37_V	et	f	\N
209623	keedagi	keedagi =keeda  (IndPrPs_^  >keetma !34_V	et	f	\N
209624	keedagi	keedagi =keeda  (ImpPrSg2^  >keetma !34_V	et	f	\N
209625	vildet	?vildet =vilde  (SgP  >vilde !06_S	et	f	\N
209664	sarnsi	?sarnsi =sarnsi  (ID  >sarnsi !41_D	et	f	\N
209665	sarnsi	?sarnsi =sarnsi  (SgG  >sarns !22_S	et	f	\N
209666	sarnsi	?sarnsi =sarnsi  (SgP  >sarns !22_S	et	f	\N
209667	sarnsi	?sarnsi =sarnsi  (SgAdt  >sarns !22_S	et	f	\N
209668	sarnsi	?sarnsi =sarnsi  (IndPrPs_  >sarnsima !28_V	et	f	\N
209669	sarnsi	?sarnsi =sarnsi  (ImpPrSg2  >sarnsima !28_V	et	f	\N
209670	erinuvusi	?erinuvusi =erinuvusi  (PlP  >erinuvus !11_S	et	f	\N
209679	särnased	?särnased =särnase  (PlN  >särnane !10_A	et	f	\N
209680	õnnetee	õnnetee =tee  (SgN  >õnne+tee !26_S	et	f	\N
209681	õnnetee	õnnetee =tee  (SgG  >õnne+tee !26_S	et	f	\N
209685	kremerele	?kremerele =kremerele  (PlP  >kremerel !19_S	et	f	\N
209701	business-womanideks	### business-womanideks	et	f	\N
209762	süüatänapäevased	?süüatänapäevased =süüatänapäevase  (PlN  >süüatänapäevane !12_A	et	f	\N
209763	süüatänapäevased	?süüatänapäevased =atänapäevase  (PlN  >süü+atänapäevane !12_A	et	f	\N
209764	tanapäevane	?tanapäevane =tanapäevane  (SgN  >tanapäevane !12_A	et	f	\N
209766	näine	?näine =näine  (SgN  >näine !10_A	et	f	\N
209767	näine	?näine =näine  (PlP  >näin !22_S	et	f	\N
209768	näine	?näine =näine  (IndPrPs_  >näinema !27_V	et	f	\N
209769	näine	?näine =näine  (ImpPrSg2  >näinema !27_V	et	f	\N
209774	niisuguselt	niisuguselt =suguse  (SgAbl  >nii+sugune !10_P	et	f	\N
209775	niisuguselt	"nii+suguselt %suguse  )LT_mD  <nii+sugune ;10_A	et	f	\N
209787	uhtne	?uhtne =uhtne  (SgN  >uhtne !02_A	et	f	\N
209788	uhtne	?uhtne =uhtne  (PlP  >uhtn !22_S	et	f	\N
209789	uhtne	?uhtne =uhtne  (IndPrPs_  >uhtnema !27_V	et	f	\N
209790	uhtne	?uhtne =uhtne  (ImpPrSg2  >uhtnema !27_V	et	f	\N
209810	lalstel	?lalstel =lalste  (SgAd  >lalste !06_S	et	f	\N
209813	lalstel	?lalstel =lalste  (PlAd  >lalst !22_S	et	f	\N
209814	lalstel	?lalstel =lalstel  (SgN  >lalstel !02_S	et	f	\N
209827	purjuks	?purjuks =purju  (KndPrPs  >purjuma !27_V	et	f	\N
209828	tänapäevasetest	tänapäevasetest =test  (SgN  >täna+päev+ase+test !22_S	et	f	\N
209829	tänapäevasetest	tänapäevasetest =sete  (PlEl  >täna+päeva+sett !22_S	et	f	\N
209851	wilde	?wilde =wilde  (SgN  >wilde !06_S	et	f	\N
209852	wilde	?wilde =wilde  (SgG  >wille !06_S	et	f	\N
209526	kaitsja	kaitsja =kaitsja  (SgG  >kaitsja !01_S	et	f	\N
209536	mõistnik	?mõistnik =mõistnik  (SgN  >mõistnik !25_S	et	f	\N
209539	karvasuse	karvasuse =karvasuse  (SgG  >karvasus !11_S	et	f	\N
209540	karvasuse	"karvasus %karva  )SUS_aS  <karv ;22_S	et	f	\N
209585	kreemeri	kreemeri =eri  (SgN  >kreem+eri !17_S	et	f	\N
209586	kreemeri	kreemeri =eri  (SgG  >kreem+eri !17_S	et	f	\N
209587	kreemeri	kreemeri =eri  (SgP  >kreem+eri !17_S	et	f	\N
209589	lepengut	?lepengut =lepengu  (SgP  >lepengu !01_S	et	f	\N
209590	lepengut	?lepengut =lepengu  (SgP  >lepeng !02_S	et	f	\N
209602	kareeri	kareeri =eri  (SgN  >kare+eri !17_S	et	f	\N
209603	kareeri	kareeri =eri  (SgG  >kare+eri !17_S	et	f	\N
209604	kareeri	kareeri =eri  (SgP  >kare+eri !17_S	et	f	\N
209605	elarõõmus	?elarõõmus =elarõõmu  (IndIpfSg3  >elarõõmuma !27_V	et	f	\N
209606	elarõõmus	?elarõõmus =elarõõmus  (SgN  >elarõõmus !11~09_S	et	f	\N
209608	julgis	julgis =julgi  (SgIn  >julk !22_S	et	f	\N
209609	julgis	julgis =julgi  (PlIn  >julk !22_S	et	f	\N
209618	kellelgi	kellelgi =kelle  (SgAd  >keegi !00_P	et	f	\N
209619	kellelgi	kellelgi =kelle  (SgAd^  >kes !00_P	et	f	\N
209620	kellelgi	kellelgi =kelle  (PlAd^  >kell !22_S	et	f	\N
209626	seostatuna	seostatuna =seostatu  (SgEs  >seostatu !01_S	et	f	\N
209627	seostatuna	"seostatu %seosta  )TU1_vS  <seostama ;27_V	et	f	\N
209630	urick	?urick =urick  (SgN  >urick !22_S	et	f	\N
209645	närts	?närts =närts  (SgN  >närts !22_S	et	f	\N
209662	võrreldan	?võrreldan =võrrelda  (IndPrSg1  >võrreldama !27_V	et	f	\N
209663	võrreldan	?võrreldan =võrreldan  (SgN  >võrreldan !19_S	et	f	\N
209675	tänapaevane	?tänapaevane =tänapaevane  (SgN  >tänapaevane !12_A	et	f	\N
209676	tänapaevane	?tänapaevane =vane  (SgN  >täna+pae+vane !16_S	et	f	\N
209677	tänapaevane	?tänapaevane =vane  (SgG  >täna+pae+vane !16_S	et	f	\N
209678	tänapaevane	?tänapaevane =paevane  (SgN  >täna+paevane !10_A	et	f	\N
209704	peetuvad	peetuvad =peetu  (IndPrPl3  >peetuma !27_V	et	f	\N
209705	peetuvad	peetuvad =peetuva  (PlN  >peetuv !02_A	et	f	\N
209707	peetuvad	"peetuv %peetu  )V_vA  <peetuma ;27_V	et	f	\N
209708	lapse-moodi	lapse-moodi =moodi  (SgP  >lapse-mood !22_S	et	f	\N
209709	lapse-moodi	lapse-moodi =moodi  (SgAdt  >lapse-mood !22_S	et	f	\N
209779	mehedega	?mehedega =mehe  (PlKom  >mehe !16_S	et	f	\N
209818	maari	?maari =maari  (SgN  >maari !16_S	et	f	\N
209819	maari	?maari =maari  (SgG  >maari !16_S	et	f	\N
209820	maari	?maari =maari  (SgG  >maar !22_S	et	f	\N
209821	maari	?maari =maari  (SgP  >maar !22_S	et	f	\N
209822	maari	?maari =maari  (SgAdt  >maar !22_S	et	f	\N
209823	maari	?maari =maari  (IndPrPs_  >maarima !28_V	et	f	\N
209824	maari	?maari =maari  (ImpPrSg2  >maarima !28_V	et	f	\N
209841	aiatööd	aiatööd =töö  (PlN  >aia+töö !26_S	et	f	\N
209842	aiatööd	aiatööd =töö  (SgP  >aia+töö !26_S	et	f	\N
209846	töötuks	töötuks =töötu  (SgTr  >töötu !01_AS	et	f	\N
209847	töötuks	"töötu %töö  )TU2_kA  <töö ;26_S	et	f	\N
209848	töötuks	töötuks =tuks  (SgN  >töö+tuks !22_S	et	f	\N
209885	kanalidel	?kanalidel =lide  (SgAd  >kana+lide !16_S	et	f	\N
209886	kanalidel	?kanalidel =lidel  (SgN  >kana+lidel !02_S	et	f	\N
209902	vallatugi	vallatugi =tugi  (SgN  >valla+tugi !21_S	et	f	\N
209903	vallatugi	vallatugi =vallatu  (SgN^  >vallatu !01_AS	et	f	\N
209904	vallatugi	"vallatu %valla  )TU1_vS^  <valdama ;29_V	et	f	\N
209905	vallatugi	"vallatu %valla  )TU2_kA^  <vald ;22_S	et	f	\N
209906	vallatugi	vallatugi =vallatu  (SgG^  >vallatu !01_AS	et	f	\N
209917	tööte	?tööte =tööte  (SgN  >tööte !06_S	et	f	\N
209919	tööte	?tööte =tööte  (SgG  >tööde !06_S	et	f	\N
209921	tööte	?tööte =tööte  (PlP  >tööt !22_S	et	f	\N
209922	tööte	?tööte =tööte  (IndPrPs_  >töötema !27_V	et	f	\N
209923	tööte	?tööte =tööte  (ImpPrSg2  >töötema !27_V	et	f	\N
209929	usalduse	usalduse =usalduse  (SgG  >usaldus !11_S	et	f	\N
209930	usalduse	"usaldus %usalda  )US_vS  <usaldama ;27_V	et	f	\N
209937	regio	?regio =regio  (SgN  >regio !01_S	et	f	\N
209938	regio	?regio =regio  (SgG  >regio !01_S	et	f	\N
209954	tähis	tähis =tähi  (PlIn  >tähk !22_S	et	f	\N
209955	tähis	tähis =tähi  (PlIn  >täht !22_S	et	f	\N
209956	tähis	tähis =tähis  (SgN  >tähis !09_S	et	f	\N
209966	pidudeks	pidudeks =pidu  (PlTr  >pidu !17_S	et	f	\N
209967	pidudeks	pidudeks =pidu  (PlTr  >pidu !18_S	et	f	\N
209998	igavus	igavus =igavus  (SgN  >igavus !11_S	et	f	\N
209999	igavus	"igavus %igava  )US_aS  <igav ;02_A	et	f	\N
210023	baalti	?baalti =baalti  (ID  >baalti !41_D	et	f	\N
210025	baalti	?baalti =baalti  (SgP  >baalt !22_S	et	f	\N
210027	baalti	?baalti =baalti  (SgAdt  >baalt !22_S	et	f	\N
210049	riikas	?riikas =riika  (SgIn  >riikas !02_A	et	f	\N
210050	riikas	?riikas =riika  (SgIn  >riika !16_S	et	f	\N
210051	riikas	?riikas =riika  (IndIpfSg3  >riikama !29_V	et	f	\N
210052	riikas	?riikas =riikas  (SgN  >riikas !02_A	et	f	\N
210053	puduma	?puduma =pudu  (Sup  >puduma !27_V	et	f	\N
210054	puduma	?puduma =puduma  (SgG  >pudum !02_A	et	f	\N
210065	indeika	?indeika =indeika  (SgN  >indeika !16_S	et	f	\N
209552	haletsemisväärne	?haletsemisväärne =haletsemisväärne  (SgN  >haletsemisväärne !02_A	et	f	\N
209553	haletsemisväärne	?haletsemisväärne =haletsemisväärne  (PlP  >haletsemisväärn !22_S	et	f	\N
209554	haletsemisväärne	?haletsemisväärne =tsemisväärne  (SgN  >hale+tsemisväärne !02_A	et	f	\N
209555	haletsemisväärne	?haletsemisväärne =tsemisväärne  (PlP  >hale+tsemisväärn !22_S	et	f	\N
209556	ulrich	?ulrich =ulrich  (SgN  >ulrich !22_S	et	f	\N
209581	ärgpüks	?ärgpüks =ärgpüks  (SgN  >ärgpüks !02_S	et	f	\N
209596	tõnuga	?tõnuga =tõnu  (SgKom  >tõnu !17_S	et	f	\N
209598	tudev	?tudev =tude  (PtsPrPs  >tudema !27_V	et	f	\N
209599	tudev	?tudev =tudev  (SgN  >tudev !02_A	et	f	\N
209607	lubakse	?lubakse =lubakse  (SgG  >lubakne !02_A	et	f	\N
209610	mõistnikule	?mõistnikule =mõistniku  (SgAll  >mõistnik !25_S	et	f	\N
209611	mõistnikule	?mõistnikule =mõistniku  (SgAll  >mõistniku !01_S	et	f	\N
209612	mõistnikule	?mõistnikule =mõistnikule  (PlP  >mõistnikul !19_S	et	f	\N
209613	hihhab	?hihhab =hihha  (IndPrSg3  >hihhama !29_V	et	f	\N
209614	iseseisvune	?iseseisvune =iseseisvune  (SgN  >iseseisvune !12~10_A	et	f	\N
209615	iseseisvune	?iseseisvune =seisvune  (SgN  >ise+seisvune !12~10_A	et	f	\N
209641	asennata	?asennata =asenna  (SgAb  >asenna !16_S	et	f	\N
209642	asennata	?asennata =asennata  (IndPrPs_  >asennatama !27_V	et	f	\N
209643	asennata	?asennata =asennata  (ImpPrSg2  >asennatama !27_V	et	f	\N
209650	külmus	külmus =külmu  (IndIpfSg3  >külmuma !27_V	et	f	\N
209651	külmus	külmus =külmus  (SgN  >külmus !11~09_S	et	f	\N
209652	külmus	"külmus %külm  )US_aS  <külm ;22_AS	et	f	\N
209653	kujukas	kujukas =kujuka  (SgIn  >kujukas !02_A	et	f	\N
209654	kujukas	kujukas =kujukas  (SgN  >kujukas !02_A	et	f	\N
209660	täielikku	täielikku =täielikku  (SgP  >täielik !25_A	et	f	\N
209661	täielikku	täielikku =täielikku  (SgAdt  >täielik !25_A	et	f	\N
209671	teeninda	teeninda =teeninda  (IndPrPs_  >teenindama !27_V	et	f	\N
209672	teeninda	teeninda =teeninda  (ImpPrSg2  >teenindama !27_V	et	f	\N
209702	trojani	?trojani =troja  (SgTer  >troja !17_S	et	f	\N
209703	trojani	?trojani =trojani  (SgG  >trojan !02_S	et	f	\N
209706	ilut	?ilut =ilut  (SgN  >ilut !02_S	et	f	\N
209719	pearooli	pearooli =rooli  (SgG  >pea+rool !22_S	et	f	\N
209720	pearooli	pearooli =rooli  (SgP  >pea+rool !22_S	et	f	\N
209721	pearooli	pearooli =rooli  (SgAdt  >pea+rool !22_S	et	f	\N
209728	prillupil	?prillupil =prillupi  (SgAd  >prillupi !01_S	et	f	\N
209729	prillupil	?prillupil =prillupi  (SgAd  >prillup !02_S	et	f	\N
209730	prillupil	?prillupil =prillupi  (SgAd  >prillupp !22_S	et	f	\N
209731	prillupil	?prillupil =upi  (SgAd  >prill+upi !16_S	et	f	\N
209732	prillupil	?prillupil =upi  (SgAd  >prill+upp !22_S	et	f	\N
209737	pimamees	?pimamees =pimamee  (SgIn  >pimamee !26_S	et	f	\N
209738	pimamees	?pimamees =pimamees  (SgN  >pimamees !22_S	et	f	\N
209739	kremerile	?kremerile =kremeri  (SgAll  >kremeri !01_S	et	f	\N
209740	kremerile	?kremerile =kremeri  (SgAll  >kremer !02_S	et	f	\N
209744	nejud	?nejud =neju  (PlN  >neju !17_S	et	f	\N
209745	nejud	?nejud =neju  (IndPrSg2  >nejuma !27_V	et	f	\N
209747	rikkast	?rikkast =rikka  (SgEl  >rikas !07_A	et	f	\N
209748	rikkast	?rikkast =rikkas  (SgP  >rikkas !07_S	et	f	\N
209749	rikkast	?rikkast =rikkas  (SgP  >rikkane !12~10_A	et	f	\N
209759	voidleb	?voidleb =voidle  (IndPrSg3  >voidlema !30_V	et	f	\N
209770	kuulaks	kuulaks =kuula  (KndPrPs  >kuulama !29_V	et	f	\N
209771	kuulaks	kuulaks =la  (SgTr  >kuu+la !26_S	et	f	\N
209772	kuulaks	kuulaks =laks  (SgN  >kuu+laks !22_S	et	f	\N
209776	lõõbus	?lõõbus =lõõbu  (SgIn  >lõõbu !16_S	et	f	\N
209777	lõõbus	?lõõbus =lõõbu  (IndIpfSg3  >lõõbuma !27_V	et	f	\N
209778	lõõbus	?lõõbus =lõõbus  (SgN  >lõõbus !11~09_S	et	f	\N
209783	abikaasast	abikaasast =ast  (SgN  >abi+kaas+ast !22_S	et	f	\N
209784	abikaasast	abikaasast =kaasa  (SgEl  >abi+kaasa !16_S	et	f	\N
209785	abikaasast	abikaasast =kaasas  (SgP  >abi+kaasane !10_A	et	f	\N
209786	abikaasast	"abi+kaasane %kaasa  )NE_aA  <abi+kaasa ;16_S	et	f	\N
209791	tegib	?tegib =tegi  (IndPrSg3  >tegima !27_V	et	f	\N
209792	märi	?märi =märi  (SgN  >märi !17_S	et	f	\N
209793	märi	?märi =märi  (SgG  >märi !17_S	et	f	\N
209794	märi	?märi =märi  (SgP  >märi !17_S	et	f	\N
209795	märi	?märi =märi  (IndPrPs_  >märima !27_V	et	f	\N
209796	märi	?märi =märi  (ImpPrSg2  >märima !27_V	et	f	\N
209797	eesiplaanil	?eesiplaanil =eesiplaani  (SgAd  >eesiplaani !16_S	et	f	\N
209798	eesiplaanil	?eesiplaanil =eesiplaani  (SgAd  >eesiplaan !22_S	et	f	\N
209799	eesiplaanil	?eesiplaanil =eesiplaanil  (SgN  >eesiplaanil !02_S	et	f	\N
209800	eesiplaanil	?eesiplaanil =iplaani  (SgAd  >ees+iplaani !16_S	et	f	\N
209801	eesiplaanil	?eesiplaanil =iplaani  (SgAd  >ees+iplaan !22_S	et	f	\N
209802	ööpäeviti	?ööpäeviti =ööpäevi  (IndIpfIps  >ööpäevima !28_V	et	f	\N
209803	ööpäeviti	?ööpäeviti =ööpäeviti  (ID  >ööpäeviti !41_D	et	f	\N
209804	ööpäeviti	?ööpäeviti =ööpäeviti  (SgG  >ööpäevitt !22_S	et	f	\N
209805	ööpäeviti	?ööpäeviti =ööpäeviti  (IndPrPs_  >ööpäevittima !28_V	et	f	\N
209806	ööpäeviti	?ööpäeviti =ööpäeviti  (ImpPrSg2  >ööpäevittima !28_V	et	f	\N
209657	nõustunud	"nõustunu %nõustu  )NU_vS  <nõustuma ;27_V	et	f	\N
209658	nõustunud	nõustunud =nõustunud  (ID  >nõustunud !41_A	et	f	\N
209659	nõustunud	"nõustunud %nõustu  )NUD_vA  <nõustuma ;27_V	et	f	\N
209686	juhanule	?juhanule =juhanu  (SgAll  >juhanu !01_S	et	f	\N
209687	juhanule	?juhanule =juhanule  (PlP  >juhanul !19_S	et	f	\N
209688	juhanule	?juhanule =ule  (SgN  >juhan+ule !16_S	et	f	\N
209689	juhanule	?juhanule =ule  (SgG  >juhan+ule !16_S	et	f	\N
209690	mõnides	?mõnides =mõni  (Ger  >mõnima !27_V	et	f	\N
209691	kaasaagses	?kaasaagses =kaasaagse  (SgIn  >kaasaagne !02_A	et	f	\N
209692	kaasaagses	?kaasaagses =kaasaagse  (PlIn  >kaasaags !22_S	et	f	\N
209693	kaasaagses	?kaasaagses =agse  (SgIn  >kaasa+agne !02_A	et	f	\N
209694	kaasaagses	?kaasaagses =agse  (SgIn  >kaasa+agse !06_S	et	f	\N
209695	kaasaagses	?kaasaagses =agse  (PlIn  >kaasa+ags !22_S	et	f	\N
209696	kaasaagses	?kaasaagses =agses  (SgN  >kaasa+agses !09_S	et	f	\N
209697	kaasaagses	?kaasaagses =aagse  (SgIn  >kaas+aagne !02_A	et	f	\N
209698	kaasaagses	?kaasaagses =aagse  (SgIn  >kaas+aagse !06_S	et	f	\N
209699	kaasaagses	?kaasaagses =aagse  (PlIn  >kaas+aags !22_S	et	f	\N
209700	kaasaagses	?kaasaagses =aagses  (SgN  >kaas+aagses !09_S	et	f	\N
209710	muuretu	muuretu =retu  (SgN  >muu+retu !16_S	et	f	\N
209711	muuretu	"muu+retu %re  )TU2_kA  <muu+re ;26_S	et	f	\N
209712	muuretu	muuretu =retu  (SgG  >muu+retu !16_S	et	f	\N
209713	võreldes	?võreldes =võrel  (Ger  >võrelema !31_V	et	f	\N
209714	mõistniku	?mõistniku =mõistniku  (SgN  >mõistniku !01_S	et	f	\N
209715	mõistniku	?mõistniku =mõistniku  (SgG  >mõistniku !01_S	et	f	\N
209716	mõistniku	?mõistniku =mõistniku  (SgG  >mõistnik !25_S	et	f	\N
209717	mõistniku	?mõistniku =mõistniku  (IndPrPs_  >mõistnikuma !27_V	et	f	\N
209718	mõistniku	?mõistniku =mõistniku  (ImpPrSg2  >mõistnikuma !27_V	et	f	\N
209726	kremeriga	?kremeriga =kremeri  (SgKom  >kremeri !01_S	et	f	\N
209727	kremeriga	?kremeriga =kremeri  (SgKom  >kremer !02_S	et	f	\N
209733	rikkusest	rikkusest =rikkuse  (SgEl  >rikkus !11~09_S	et	f	\N
209734	rikkusest	rikkusest =rikkuses  (SgP  >rikkusene !12_A	et	f	\N
209735	rikkusest	"rikkusene %rikkuse  )NE_aA  <rikkus ;09_S	et	f	\N
209736	rikkusest	"rikkusene %rikkuse  )NE_aA  <rikkus ;11_S	et	f	\N
209746	tõnut	?tõnut =tõnut  (SgN  >tõnut !02_S	et	f	\N
209750	koatab	?koatab =koata  (IndPrSg3  >koatama !27_V	et	f	\N
209751	kumbagi	kumbagi =kumba  (SgAdt  >kumbki !00_P	et	f	\N
209752	kumbagi	kumbagi =kumba  (SgP  >kumbki !00_P	et	f	\N
209753	kumbagi	kumbagi =kumba  (SgP^  >kumb !22_P	et	f	\N
209754	kumbagi	kumbagi =kumba  (SgAdt^  >kumb !22_P	et	f	\N
209758	eripäraset	### eripäraset	et	f	\N
209760	vaper	?vaper =vaper  (SgN  >vaper !02_S	et	f	\N
209765	näisega	?näisega =näise  (SgKom  >näise !06_S	et	f	\N
209825	tõnu-piimamees	tõnu-piimamees =mee  (SgIn  >tõnu-piima+mesi !15_S	et	f	\N
209826	tõnu-piimamees	tõnu-piimamees =mees  (SgN  >tõnu-piima+mees !13_S	et	f	\N
209830	toidukauplustes	toidukauplustes =luste  (SgIn  >toidu+kaup+luste !06_S	et	f	\N
209831	toidukauplustes	toidukauplustes =luste  (PlIn  >toidu+kaup+lust !22_S	et	f	\N
209832	toidukauplustes	toidukauplustes =kauplus  (PlIn  >toidu+kauplus !11~09_S	et	f	\N
209856	suursugusem	suursugusem =sugusem  (SgN  >suur+sugusem !02_A	et	f	\N
209857	suursugusem	"suur+sugusem %suguse  )M_cA  <suur+sugune ;10_A	et	f	\N
209866	lastekaitse	lastekaitse =kaitse  (SgN  >laste+kaitse !05_S	et	f	\N
209867	lastekaitse	lastekaitse =kaitse  (SgN  >laste+kaitse !06_S	et	f	\N
209868	lastekaitse	lastekaitse =kaitse  (SgG  >laste+kaitse !06_S	et	f	\N
209870	koolielus	koolielus =elu  (SgIn  >kooli+elu !17_S	et	f	\N
209871	koolielus	koolielus =elus  (SgN  >kooli+elus !02_A	et	f	\N
209887	ülemusega	ülemusega =ülemuse  (SgKom  >ülemus !11_S	et	f	\N
209888	ülemusega	"ülemus %ülema  )US_aS  <ülem ;02_AS	et	f	\N
209896	küllit	?küllit =külli  (SgP  >külli !16_S	et	f	\N
209897	küllit	?küllit =küllit  (SgN  >küllit !02_S	et	f	\N
209909	ammendamatu	ammendamatu =ammendamatu  (SgN  >ammendamatu !01_A	et	f	\N
209910	ammendamatu	"ammendamatu %ammenda  )MATU_vA  <ammendama ;27_V	et	f	\N
209911	ammendamatu	ammendamatu =ammendamatu  (SgG  >ammendamatu !01_A	et	f	\N
209912	ölikoolis	?ölikoolis =ölikooli  (SgIn  >ölikooli !16_S	et	f	\N
209913	ölikoolis	?ölikoolis =ölikooli  (SgIn  >ölikool !22_S	et	f	\N
209914	ölikoolis	?ölikoolis =ölikooli  (IndIpfSg3  >ölikoolima !28_V	et	f	\N
209915	ölikoolis	?ölikoolis =ölikoolis  (SgN  >ölikoolis !09_S	et	f	\N
209916	päses	?päses =päse  (SgIn  >päse !16_S	et	f	\N
209918	päses	?päses =päse  (IndIpfSg3  >päsema !27_V	et	f	\N
209920	päses	?päses =päses  (SgN  >päses !09_S	et	f	\N
209974	põlestame	?põlestame =põlesta  (IndPrPl1  >põlestama !27_V	et	f	\N
209994	noraalne	?noraalne =noraalne  (SgN  >noraalne !02_A	et	f	\N
209995	noraalne	?noraalne =noraalne  (PlP  >noraaln !22_S	et	f	\N
209996	kuendal	?kuendal =kuenda  (SgAd  >kuenda !01_S	et	f	\N
209997	kuendal	?kuendal =kuendal  (SgN  >kuendal !02_S	et	f	\N
210002	talvepidu	talvepidu =pidu  (SgN  >talve+pidu !17_S	et	f	\N
210003	talvepidu	talvepidu =pidu  (SgN  >talve+pidu !18_S	et	f	\N
210004	talvepidu	talvepidu =pidu  (SgG  >talve+pidu !17_S	et	f	\N
209755	eneseväärikus	eneseväärikus =vääriku  (SgIn  >enese+väärik !02_S	et	f	\N
209756	eneseväärikus	eneseväärikus =väärikus  (SgN  >enese+väärikus !11_S	et	f	\N
209757	eneseväärikus	"enese+väärikus %väärika  )US_aS  <enese+väärikas ;02_A	et	f	\N
209761	elaga	?elaga =ela  (SgKom  >ela !17_S	et	f	\N
209773	sarnasi	?sarnasi =sarnasi  (ID  >sarnasi !41_D	et	f	\N
209780	mehedele	?mehedele =mehe  (PlAll  >mehe !16_S	et	f	\N
209781	beeta	beeta =beeta  (SgN  >beeta !16_S	et	f	\N
209782	beeta	beeta =beeta  (SgG  >beeta !16_S	et	f	\N
209815	tänaelu	tänaelu =elu  (SgN  >täna+elu !17_S	et	f	\N
209816	tänaelu	tänaelu =elu  (SgG  >täna+elu !17_S	et	f	\N
209817	tänaelu	tänaelu =elu  (SgP  >täna+elu !17_S	et	f	\N
209833	jalatseid	?jalatseid =jalatse  (PlP  >jalatne !02_A	et	f	\N
209834	jalatseid	?jalatseid =jalatsei  (PlN  >jalatsei !26_S	et	f	\N
209835	jalatseid	?jalatseid =jalatsei  (SgP  >jalatsei !26_S	et	f	\N
209836	jalatseid	?jalatseid =tsei  (PlN  >jala+tsei !26_S	et	f	\N
209837	jalatseid	?jalatseid =tsei  (SgP  >jala+tsei !26_S	et	f	\N
209838	jalatseid	?jalatseid =tseid  (SgN  >jala+tseid !22_S	et	f	\N
209858	vaeslapse	vaeslapse =lapse  (SgG  >vaes+laps !14_S	et	f	\N
209859	vaeslapse	vaeslapse =lapse  (PlP  >vaes+laps !22_S	et	f	\N
209861	koolivägivallast	koolivägivallast =valla  (SgEl  >kooli+vägi+vald !22_S	et	f	\N
209862	koolivägivallast	koolivägivallast =vallas  (SgP  >kooli+vägi+vallane !10_A	et	f	\N
209863	koolivägivallast	"kooli+vägi+vallane %valla  )NE_aA  <kooli+vägi+vald ;22_S	et	f	\N
209882	kesktasel	?kesktasel =kesktase  (SgAd  >kesktane !12~10_A	et	f	\N
209883	kesktasel	?kesktasel =kesktasel  (SgN  >kesktasel !19_S	et	f	\N
209884	kesktasel	?kesktasel =tasel  (SgN  >kesk+tasel !02_S	et	f	\N
209889	küllaldaselt	küllaldaselt =küllaldase  (SgAbl  >küllaldane !12_A	et	f	\N
209891	küllaldaselt	küllaldaselt =küllaldaselt  (ID  >küllaldaselt !41_D	et	f	\N
209893	küllaldaselt	"küllaldaselt %küllaldase  )LT_mD  <küllaldane ;12_A	et	f	\N
209900	mügiesindajana	?mügiesindajana =mügiesindaja  (SgEs  >mügiesindaja !01_S	et	f	\N
209901	mügiesindajana	?mügiesindajana =mügiesindaja  (SgEs  >mügiesindajas !02_A	et	f	\N
209934	mügiesindaja	?mügiesindaja =mügiesindaja  (SgN  >mügiesindaja !01_S	et	f	\N
209935	mügiesindaja	?mügiesindaja =mügiesindaja  (SgG  >mügiesindaja !01_S	et	f	\N
209936	mügiesindaja	?mügiesindaja =mügiesindaja  (SgG  >mügiesindajas !02_A	et	f	\N
209941	seesija	?seesija =seesija  (SgN  >seesija !01_S	et	f	\N
209942	seesija	?seesija =seesija  (SgG  >seesija !01_S	et	f	\N
209943	seesija	?seesija =seesija  (SgG  >seesijas !02_A	et	f	\N
209944	seesija	?seesija =ija  (SgN  >sees+ija !17_S	et	f	\N
209945	seesija	?seesija =ija  (SgG  >sees+ija !17_S	et	f	\N
209946	seesija	?seesija =ija  (SgP  >sees+ija !17_S	et	f	\N
209947	seesija	?seesija =sija  (SgN  >see+sija !17_S	et	f	\N
209948	seesija	?seesija =sija  (SgG  >see+sija !17_S	et	f	\N
209949	seesija	?seesija =sija  (SgP  >see+sija !17_S	et	f	\N
209957	januaris	?januaris =januari  (SgIn  >januari !16_S	et	f	\N
209958	januaris	?januaris =januari  (SgIn  >januar !19_S	et	f	\N
209959	januaris	?januaris =januari  (IndIpfSg3  >januarima !28_V	et	f	\N
209960	januaris	?januaris =januaris  (SgN  >januaris !09_S	et	f	\N
209961	detsembis	?detsembis =detsembi  (SgIn  >detsembi !01_S	et	f	\N
209962	detsembis	?detsembis =detsembi  (SgIn  >detsemb !02_S	et	f	\N
209963	detsembis	?detsembis =detsembi  (SgIn  >detsemp !22_S	et	f	\N
209964	detsembis	?detsembis =detsembi  (IndIpfSg3  >detsembima !28_V	et	f	\N
209965	detsembis	?detsembis =detsembis  (SgN  >detsembis !11_S	et	f	\N
209968	kaunistavad	kaunistavad =kaunista  (IndPrPl3  >kaunistama !27_V	et	f	\N
209969	kaunistavad	kaunistavad =kaunistava  (PlN  >kaunistav !02_A	et	f	\N
209970	kaunistavad	"kaunistav %kaunista  )V_vA  <kaunistama ;27_V	et	f	\N
209971	kaunistavad	kaunistavad =tava  (PlN  >kaunis+tava !17_S	et	f	\N
209975	künlad	?künlad =künla  (PlN  >künla !16_S	et	f	\N
209976	künlad	?künlad =künla  (IndPrSg2  >künlama !29_V	et	f	\N
209983	valgustusse	valgustusse =valgustus  (SgAdt  >valgustus !11_S	et	f	\N
209984	valgustusse	"valgustus %valgusta  )US_vS  <valgustama ;27_V	et	f	\N
209985	valgustusse	valgustusse =usse  (PlP  >valgust+uss !22_S	et	f	\N
209986	valgustusse	valgustusse =tusse  (PlP  >valgus+tuss !22_S	et	f	\N
209987	valgustusse	valgustusse =ustu  (SgIll  >valg+ustu !01_S	et	f	\N
209992	neljad	neljad =nelja  (PlN  >neljas !02_O	et	f	\N
209993	neljad	neljad =nelja  (PlN  >neli !24_N	et	f	\N
210009	tänavale	tänavale =tänava  (SgAll  >tänav !02_A	et	f	\N
210010	tänavale	"tänav %täna  )V_vA  <tänama ;27_V	et	f	\N
210011	tänavale	tänavale =tänava  (SgAll  >tänav !02_S	et	f	\N
210012	tänavale	tänavale =ale  (SgN  >tänav+ale !16_S	et	f	\N
210013	tänavale	tänavale =ale  (SgG  >tänav+ale !16_S	et	f	\N
210014	tänavale	tänavale =vale  (SgN  >täna+vale !16_SA	et	f	\N
210015	tänavale	tänavale =vale  (SgG  >täna+vale !16_SA	et	f	\N
210016	kuuske	kuuske =kuuske  (SgP  >kuusk !22_S	et	f	\N
210017	kuuske	kuuske =kuuske  (SgAdt  >kuusk !22_S	et	f	\N
210018	kuuske	kuuske =kuuske  (PlP  >kuusk !22_S	et	f	\N
210022	lületame	?lületame =lületa  (IndPrPl1  >lületama !27_V	et	f	\N
209807	ööpäeviti	?ööpäeviti =iti  (SgN  >öö+päev+iti !16_S	et	f	\N
209808	ööpäeviti	?ööpäeviti =iti  (SgG  >öö+päev+iti !16_S	et	f	\N
209809	ööpäeviti	?ööpäeviti =iti  (SgG  >öö+päev+itt !22_S	et	f	\N
209811	ööpäeviti	?ööpäeviti =päeviti  (SgG  >öö+päevit !02_S	et	f	\N
209812	ööpäeviti	?ööpäeviti =päeviti  (SgG  >öö+päevitt !22_S	et	f	\N
209839	väljapandud	väljapandud =pan  (PtsPtIps  >välja+_panema !36_V	et	f	\N
209840	väljapandud	väljapandud =pandu  (PlN  >välja+pandu !01_S	et	f	\N
209843	tilli	tilli =tilli  (SgG  >till !22_S	et	f	\N
209844	tilli	tilli =tilli  (SgP  >till !22_S	et	f	\N
209845	tilli	tilli =tilli  (SgAdt  >till !22_S	et	f	\N
209849	sõltumatud	sõltumatud =sõltumatu  (PlN  >sõltumatu !01_A	et	f	\N
209850	sõltumatud	"sõltumatu %sõltu  )MATU_vA  <sõltuma ;27_V	et	f	\N
209860	kannatuset	?kannatuset =tuse  (SgP  >kanna+tuse !16_S	et	f	\N
209875	järelmaksu	järelmaksu =maksu  (SgG  >järel+maks !22_S	et	f	\N
209876	järelmaksu	järelmaksu =maksu  (SgP  >järel+maks !22_S	et	f	\N
209877	järelmaksu	järelmaksu =maksu  (SgAdt  >järel+maks !22_S	et	f	\N
209878	järelmaksu	järelmaksu =maksu  (PlP  >järel+maks !22_S	et	f	\N
209881	kellt	?kellt =kellt  (SgN  >kellt !22_S	et	f	\N
209894	kaastööd	kaastööd =töö  (PlN  >kaas+töö !26_S	et	f	\N
209895	kaastööd	kaastööd =töö  (SgP  >kaas+töö !26_S	et	f	\N
209931	etemaksem	?etemaksem =etemaksem  (SgN  >etemaksem !02_A	et	f	\N
209932	regio	?regio =regio  (SgN  >regio !01_S	et	f	\N
209933	regio	?regio =regio  (SgG  >regio !01_S	et	f	\N
209952	mangisime	?mangisime =mangi  (IndIpfPl1  >mangima !28_V	et	f	\N
209953	ootome	### ootome	et	f	\N
209977	kingitame	?kingitame =kingita  (IndPrPl1  >kingitama !27_V	et	f	\N
209978	kingitame	?kingitame =tame  (SgN  >kingi+tame !16_S	et	f	\N
209979	kingitame	?kingitame =tame  (SgG  >kingi+tame !16_S	et	f	\N
209980	peolised	peolised =peolise  (PlN  >peoline !12?10_S	et	f	\N
209981	peolised	"peoline %peo  )LINE_aA  <pidu ;18_S	et	f	\N
209982	peolised	"peoline %peo  )LINE_aA  <peo ;26_S	et	f	\N
209988	olevje	### olevje	et	f	\N
209989	jatama	?jatama =jata  (Sup  >jatama !27_V	et	f	\N
209990	jatama	?jatama =jatama  (SgG  >jatam !02_A	et	f	\N
209991	kingitusek	?kingitusek =tusek  (SgN  >kingi+tusek !02_S	et	f	\N
210000	sureparane	?sureparane =sureparane  (SgN  >sureparane !12_A	et	f	\N
210001	sureparane	?sureparane =sureparane  (PlP  >sureparan !19_S	et	f	\N
210019	peolaud	peolaud =lau  (PlN  >peo+laug !22_SA	et	f	\N
210020	peolaud	peolaud =laud  (SgN  >peo+laud !22_S	et	f	\N
210021	peolautaga	?peolautaga =lauta  (SgKom  >peo+lauta !16_S	et	f	\N
210033	reliigasse	?reliigasse =reliiga  (SgIll  >reliiga !16_S	et	f	\N
210034	reliigasse	?reliigasse =reliigasse  (SgG  >reliigasne !02_A	et	f	\N
210035	reliigasse	?reliigasse =reliigasse  (PlP  >reliigass !22_S	et	f	\N
210037	pühistame	?pühistame =pühista  (IndPrPl1  >pühistama !27_V	et	f	\N
210038	pühistame	?pühistame =stame  (SgN  >pühi+stame !16_S	et	f	\N
210039	pühistame	?pühistame =stame  (SgG  >pühi+stame !16_S	et	f	\N
210042	koosolemist	koosolemist =olemi  (SgEl  >koos+olem !02_S	et	f	\N
210043	koosolemist	koosolemist =olemis  (SgP  >koos+olemine !12_S	et	f	\N
210044	koosolemist	"koos+olemine %olemi  )NE_aA  <koos+olem ;02_S	et	f	\N
210061	omaparune	?omaparune =omaparune  (SgN  >omaparune !12_A	et	f	\N
210062	omaparune	?omaparune =omaparune  (PlP  >omaparun !19_S	et	f	\N
210063	omaparune	?omaparune =parune  (SgN  >oma+parune !10_A	et	f	\N
210071	kingima	kingima =ima  (SgN  >king+ima !17_S	et	f	\N
210072	kingima	kingima =ima  (SgG  >king+ima !17_S	et	f	\N
210073	kingima	kingima =ima  (SgP  >king+ima !17_S	et	f	\N
210082	jõuemõtted	### jõuemõtted	et	f	\N
210100	purjuseks	### purjuseks	et	f	\N
210106	vimas	?vimas =vima  (SgIn  >vima !17_S	et	f	\N
210107	vimas	?vimas =vima  (IndIpfSg3  >vimama !27_V	et	f	\N
210108	vimas	?vimas =vimas  (SgN  >vimas !09_S	et	f	\N
210119	piduöö	piduöö =öö  (SgN  >pidu+öö !26_S	et	f	\N
210120	piduöö	piduöö =öö  (SgG  >pidu+öö !26_S	et	f	\N
210142	jõulumõttet	?jõulumõttet =mõtte  (SgP  >jõulu+mõtte !06_S	et	f	\N
210148	peapidu	peapidu =pidu  (SgN  >pea+pidu !17_S	et	f	\N
210149	peapidu	peapidu =pidu  (SgN  >pea+pidu !18_S	et	f	\N
210150	peapidu	peapidu =pidu  (SgG  >pea+pidu !17_S	et	f	\N
210151	peapidu	peapidu =pidu  (SgP  >pea+pidu !17_S	et	f	\N
210152	peapidu	peapidu =pidu  (SgP  >pea+pidu !18_S	et	f	\N
210177	pidustan	?pidustan =pidusta  (IndPrSg1  >pidustama !27_V	et	f	\N
210178	pidustan	?pidustan =pidustan  (SgN  >pidustan !19_S	et	f	\N
210196	kõigede	### kõigede	et	f	\N
210205	väekesi	väekesi =väekesi  (PlP  >väeke !12_S	et	f	\N
210206	väekesi	"väeke %väe  )KE_dS  <vägi ;21_S	et	f	\N
210207	väekesi	väekesi =väekesi  (PlP  >väekene !12_S	et	f	\N
210208	väekesi	"väekene %väe  )KENE_dS  <vägi ;21_S	et	f	\N
210211	pidun	?pidun =pidu  (IndPrSg1  >piduma !27_V	et	f	\N
210212	pidun	?pidun =pidun  (SgN  >pidun !02_S	et	f	\N
210219	kingitema	?kingitema =kingitema  (SgG  >kingitem !02_A	et	f	\N
210220	kingitema	?kingitema =itema  (SgG  >king+item !02_A	et	f	\N
209853	wilde	?wilde =wilde  (PlP  >wild !22_S	et	f	\N
209854	wilde	?wilde =wilde  (IndPrPs_  >wildema !27_V	et	f	\N
209855	wilde	?wilde =wilde  (ImpPrSg2  >wildema !27_V	et	f	\N
209864	kooliprobleemiks	kooliprobleemiks =iks  (SgN  >kooli+probleem+iks !22_S	et	f	\N
209865	kooliprobleemiks	kooliprobleemiks =probleemi  (SgTr  >kooli+probleem !22_S	et	f	\N
209869	nõuanned	### nõuanned	et	f	\N
209872	visklev	visklev =viskle  (PtsPrPs  >visklema !30_V	et	f	\N
209873	visklev	visklev =visklev  (SgN  >visklev !02_A	et	f	\N
209874	visklev	"visklev %viskle  )V_vA  <visklema ;30_V	et	f	\N
209879	sularahaga	sularahaga =raha  (SgKom  >sula+raha !17_S	et	f	\N
209880	sularahaga	sularahaga =raha  (SgKom  >sula+rahk !22_S	et	f	\N
209890	kõnepraktika	kõnepraktika =praktika  (SgN  >kõne+praktika !01_S	et	f	\N
209892	kõnepraktika	kõnepraktika =praktika  (SgG  >kõne+praktika !01_S	et	f	\N
209898	tasakaalukas	tasakaalukas =kaaluka  (SgIn  >tasa+kaalukas !02_A	et	f	\N
209899	tasakaalukas	tasakaalukas =kaalukas  (SgN  >tasa+kaalukas !02_A	et	f	\N
209907	täppi	täppi =täppi  (SgP  >täpp !22_S	et	f	\N
209908	täppi	täppi =täppi  (SgAdt  >täpp !22_S	et	f	\N
209924	tippkohta	tippkohta =kohta  (SgP  >tipp+koht !22_S	et	f	\N
209925	tippkohta	tippkohta =kohta  (SgAdt  >tipp+koht !22_S	et	f	\N
209926	teenindusmaja	teenindusmaja =maja  (SgN  >teenindus+maja !17_S	et	f	\N
209927	teenindusmaja	teenindusmaja =maja  (SgG  >teenindus+maja !17_S	et	f	\N
209928	teenindusmaja	teenindusmaja =maja  (SgP  >teenindus+maja !17_S	et	f	\N
209939	periiod	?periiod =periio  (PlN  >periio !01_S	et	f	\N
209940	periiod	?periiod =periiod  (SgN  >periiod !22_S	et	f	\N
209950	tulimused	?tulimused =tulimuse  (PlN  >tulimus !11_S	et	f	\N
209951	tulimused	?tulimused =muse  (PlN  >tuli+muse !16_S	et	f	\N
209972	kusked	?kusked =kuske  (PlN  >kuske !01_A	et	f	\N
209973	kusked	?kusked =kuske  (IndPrSg2  >kuskema !27_V	et	f	\N
210028	peavalu	peavalu =valu  (SgN  >pea+valu !17_S	et	f	\N
210029	peavalu	peavalu =valu  (SgG  >pea+valu !17_S	et	f	\N
210030	peavalu	peavalu =valu  (SgP  >pea+valu !17_S	et	f	\N
210055	piidu	?piidu =piidu  (SgN  >piidu !16_S	et	f	\N
210056	piidu	?piidu =piidu  (SgG  >piidu !16_S	et	f	\N
210057	piidu	?piidu =piidu  (IndPrPs_  >piiduma !27_V	et	f	\N
210058	piidu	?piidu =piidu  (ImpPrSg2  >piiduma !27_V	et	f	\N
210083	jõue	?jõue =jõue  (SgN  >jõue !06_S	et	f	\N
210084	jõue	?jõue =jõue  (SgG  >jõue !06_S	et	f	\N
210086	jõuele	?jõuele =jõue  (SgAll  >jõue !06_S	et	f	\N
210087	jõuele	?jõuele =jõuele  (IndPrPs_  >jõuelema !27_V	et	f	\N
210088	jõuele	?jõuele =jõuele  (ImpPrSg2  >jõuelema !27_V	et	f	\N
210131	kingitusele	kingitusele =kingituse  (SgAll  >kingitus !11_S	et	f	\N
210132	kingitusele	"kingitus %kingi  )TUS1_aS  <kinkima ;28_V	et	f	\N
210133	kingitusele	"kingitus %kingi  )TUS2_aS  <kink ;22_S	et	f	\N
210169	mõttede	### mõttede	et	f	\N
210182	holitseda	?holitseda =holitse  (Inf  >holitsema !27_V	et	f	\N
210191	jõulupuud	jõulupuud =puu  (PlN  >jõulu+puu !26_S	et	f	\N
210192	jõulupuud	jõulupuud =puu  (SgP  >jõulu+puu !26_S	et	f	\N
210193	jõulupuud	jõulupuud =puud  (SgN  >jõulu+puud !22_S	et	f	\N
210217	pakkivad	pakkivad =pakkiva  (PlN  >pakkiv !02_A	et	f	\N
210218	pakkivad	"pakkiv %pakki  )V_vA  <pakkima ;28_V	et	f	\N
210239	raekojaplatsi	raekojaplatsi =platsi  (SgG  >rae+koja+plats !22_S	et	f	\N
210240	raekojaplatsi	raekojaplatsi =platsi  (SgP  >rae+koja+plats !22_S	et	f	\N
210241	raekojaplatsi	raekojaplatsi =platsi  (SgAdt  >rae+koja+plats !22_S	et	f	\N
210249	2-teisel	-teisel =teise  (SgAd  >-teine !12_OP	et	f	\N
210250	2-teisel	-teisel =teise  (SgAd  >-teise !12_P	et	f	\N
210253	eliktri	?eliktri =eliktri  (SgN  >eliktri !01_S	et	f	\N
210254	eliktri	?eliktri =eliktri  (SgG  >eliktri !01_S	et	f	\N
210255	eliktri	?eliktri =eliktri  (SgG  >eliktr !22_S	et	f	\N
210256	eliktri	?eliktri =eliktri  (SgP  >eliktr !22_S	et	f	\N
210257	eliktri	?eliktri =eliktri  (SgAdt  >eliktr !22_S	et	f	\N
210258	eliktri	?eliktri =eliktri  (IndPrPs_  >eliktrima !28_V	et	f	\N
210259	eliktri	?eliktri =eliktri  (ImpPrSg2  >eliktrima !28_V	et	f	\N
210261	hakkam	?hakkam =hakkam  (SgN  >hakkam !02_A	et	f	\N
210268	lineaaralgebrat	?lineaaralgebrat =lineaaralgebra  (SgP  >lineaaralgebra !16_S	et	f	\N
210271	lumepalli	lumepalli =palli  (SgG  >lume+pall !22_S	et	f	\N
210272	lumepalli	lumepalli =palli  (SgP  >lume+pall !22_S	et	f	\N
210273	lumepalli	lumepalli =palli  (SgAdt  >lume+pall !22_S	et	f	\N
210275	lemehanged	### lemehanged	et	f	\N
210318	tõit	?tõit =tõit  (SgN  >tõit !22_S	et	f	\N
210363	kõigdest	?kõigdest =kõigde  (SgEl  >kõigde !06_S	et	f	\N
210364	kõigdest	?kõigdest =kõigde  (PlEl  >kõigd !22_S	et	f	\N
210365	kõigdest	?kõigdest =kõigdes  (SgP  >kõigdes !09_S	et	f	\N
210367	kõigdest	?kõigdest =kõigdes  (SgP  >kõigdene !12~10_A	et	f	\N
210371	koolilõpetajadele	### koolilõpetajadele	et	f	\N
210389	nelgaga	?nelgaga =nelga  (SgKom  >nelga !16_S	et	f	\N
210406	poissiga	poissiga =iga  (SgN  >poiss+iga !18_S	et	f	\N
210407	poissiga	poissiga =iga  (SgP  >poiss+iga !18_S	et	f	\N
210416	inimesiga	### inimesiga	et	f	\N
210005	talvepidu	talvepidu =pidu  (SgP  >talve+pidu !17_S	et	f	\N
210006	talvepidu	talvepidu =pidu  (SgP  >talve+pidu !18_S	et	f	\N
210007	ilutulestikku	ilutulestikku =tulestikku  (SgP  >ilu+tulestik !25_S	et	f	\N
210008	ilutulestikku	ilutulestikku =tulestikku  (SgAdt  >ilu+tulestik !25_S	et	f	\N
210024	kanaal	?kanaal =kanaa  (SgAd  >kanaa !26_S	et	f	\N
210026	kanaal	?kanaal =kanaal  (SgN  >kanaal !22_S	et	f	\N
210045	teegevad	?teegevad =teege  (IndPrPl3  >teegema !27_V	et	f	\N
210046	teegevad	?teegevad =teegeva  (PlN  >teegeva !01_S	et	f	\N
210047	teegevad	?teegevad =teegeva  (PlN  >teegev !02_A	et	f	\N
210048	teegevad	?teegevad =geva  (PlN  >tee+geva !17_S	et	f	\N
210064	teegib	?teegib =teegi  (IndPrSg3  >teekima !28_V	et	f	\N
210068	seelel	?seelel =seele  (SgAd  >seele !06_S	et	f	\N
210069	seelel	?seelel =seele  (PlAd  >seel !22_S	et	f	\N
210070	seelel	?seelel =seelel  (SgN  >seelel !02_S	et	f	\N
210089	katoline	?katoline =katoline  (SgN  >katoline !12_A	et	f	\N
210090	katoline	?katoline =katoline  (PlP  >katolin !19_S	et	f	\N
210099	soprade	### soprade	et	f	\N
210103	pidust	pidust =pidu  (SgEl  >pidu !17_S	et	f	\N
210104	pidust	pidust =pidus  (SgP  >pidune !10_A	et	f	\N
210105	pidust	"pidune %pidu  )NE_aA  <pidu ;18_S	et	f	\N
210115	naeratused	naeratused =naeratuse  (PlN  >naeratus !11_S	et	f	\N
210116	naeratused	"naeratus %naerata  )US_vS  <naeratama ;27_V	et	f	\N
210121	mõttelda	?mõttelda =mõttelda  (IndPrPs_  >mõtteldama !27_V	et	f	\N
210122	mõttelda	?mõttelda =mõttelda  (ImpPrSg2  >mõtteldama !27_V	et	f	\N
210141	onnelik	?onnelik =onnelik  (SgN  >onnelik !25_A	et	f	\N
210143	katoliklised	?katoliklised =katoliklise  (PlN  >katolikline !12_A	et	f	\N
210153	kingituseid	?kingituseid =kingitusei  (PlN  >kingitusei !26_S	et	f	\N
210154	kingituseid	?kingituseid =kingitusei  (SgP  >kingitusei !26_S	et	f	\N
210155	kingituseid	?kingituseid =tusei  (PlN  >kingi+tusei !26_S	et	f	\N
210156	kingituseid	?kingituseid =tusei  (SgP  >kingi+tusei !26_S	et	f	\N
210157	kingituseid	?kingituseid =tuseid  (SgN  >kingi+tuseid !22_S	et	f	\N
210158	kingituseid	?kingituseid =ituse  (PlP  >king+itus !09_S	et	f	\N
210159	kingituseid	?kingituseid =itusei  (PlN  >king+itusei !26_S	et	f	\N
210160	kingituseid	?kingituseid =itusei  (SgP  >king+itusei !26_S	et	f	\N
210161	pidetsun	?pidetsun =pidetsu  (IndPrSg1  >pidetsuma !27_V	et	f	\N
210162	pidetsun	?pidetsun =pidetsun  (SgN  >pidetsun !19_S	et	f	\N
210170	laplandias	?laplandias =laplandia  (SgIn  >laplandia !01_S	et	f	\N
210171	laplandias	?laplandias =laplandias  (SgN  >laplandias !11_S	et	f	\N
210183	sümbooliseerib	?sümbooliseerib =sümbooliseeri  (IndPrSg3  >sümbooliseerima !28_V	et	f	\N
210197	lastede	### lastede	et	f	\N
210209	piduma	?piduma =pidu  (Sup  >piduma !27_V	et	f	\N
210210	piduma	?piduma =piduma  (SgG  >pidum !02_A	et	f	\N
210213	kallidega	?kallidega =kalli  (PlKom  >kalli !16_S	et	f	\N
210214	kallidega	?kallidega =kalli  (PlKom  >kall !22_S	et	f	\N
210224	jõulupuu	jõulupuu =puu  (SgN  >jõulu+puu !26_S	et	f	\N
210225	jõulupuu	jõulupuu =puu  (SgG  >jõulu+puu !26_S	et	f	\N
210242	hilinevad	hilinevad =hiline  (IndPrPl3  >hilinema !27_V	et	f	\N
210243	hilinevad	hilinevad =hilineva  (PlN  >hilinev !02_A	et	f	\N
210244	hilinevad	"hilinev %hiline  )V_vA  <hilinema ;27_V	et	f	\N
210269	jõulupühid	?jõulupühid =pühi  (PlN  >jõulu+pühi !17_S	et	f	\N
210270	jõulupühid	?jõulupühid =lupühi  (PlN  >jõu+lupühi !01_S	et	f	\N
210274	kohkem	?kohkem =kohkem  (SgN  >kohkem !02_A	et	f	\N
210281	lumehelved	### lumehelved	et	f	\N
210288	kaunistamist	kaunistamist =kaunistamis  (SgP  >kaunistamine !12_S	et	f	\N
210289	kaunistamist	"kaunistamine %kaunista  )MINE_vS  <kaunistama ;27_V	et	f	\N
210301	jõulupeol	jõulupeol =peo  (SgAd  >jõulu+pidu !18_S	et	f	\N
210302	jõulupeol	jõulupeol =peo  (SgAd  >jõulu+peo !26_S	et	f	\N
210319	ebatavalist	ebatavalist =tavalis  (SgP  >eba+tavaline !12_A	et	f	\N
210320	ebatavalist	"eba+tavaline %tava  )LINE_aA  <eba+tava ;17_S	et	f	\N
210339	omades	omades =oma  (PlIn  >oma !17_A	et	f	\N
210341	omades	omades =oma  (Ger  >omama !27_V	et	f	\N
210357	nägesime	### nägesime	et	f	\N
210366	meeldejaatmisest	?meeldejaatmisest =meeldejaatmise  (SgEl  >meeldejaatmine !12_A	et	f	\N
210368	meeldejaatmisest	?meeldejaatmisest =jaatmise  (SgEl  >meelde+jaatmine !12?10_S	et	f	\N
210369	väljalaste	väljalaste =las  (PlG  >välja+laps !14_S	et	f	\N
210370	väljalaste	väljalaste =laste  (PlP  >välja+last !22_S	et	f	\N
210375	minutist	minutist =minuti  (SgEl  >minut !02_S	et	f	\N
210376	minutist	minutist =minutis  (SgP  >minutine !12_A	et	f	\N
210377	minutist	"minutine %minuti  )NE_aA  <minut ;02_S	et	f	\N
210378	lõppetuses	lõppetuses =lõppetuse  (SgIn  >lõppetus !11_S	et	f	\N
210379	lõppetuses	"lõppetus %lõppe  )TUS1_aS  <lõppema ;27_V	et	f	\N
210380	lõppetuses	"lõppetus %lõppe  )TUS2_aS  <lõpe ;06_S	et	f	\N
210391	pepsi	pepsi =pepsi  (SgG  >peps !22_A	et	f	\N
210392	pepsi	pepsi =pepsi  (SgP  >peps !22_A	et	f	\N
210393	pepsi	pepsi =pepsi  (SgAdt  >peps !22_A	et	f	\N
210420	eksamide	?eksamide =ami  (PlG  >eks+ami !17_S	et	f	\N
210439	bush	?bush =bush  (SgN  >bush !22_S	et	f	\N
210442	satusin	?satusin =satu  (IndIpfSg1  >satuma !27_V	et	f	\N
210031	suusatamine	suusatamine =suusatamine  (SgN  >suusatamine !12_S	et	f	\N
210032	suusatamine	"suusatamine %suusata  )MINE_vS  <suusatama ;27_V	et	f	\N
210036	kreeka-katolik	?kreeka-katolik =katolik  (SgN  >kreeka-katolik !25_A	et	f	\N
210040	mõnitlen	?mõnitlen =mõnitle  (IndPrSg1  >mõnitlema !27_V	et	f	\N
210041	mõnitlen	?mõnitlen =mõnitlen  (SgN  >mõnitlen !19_S	et	f	\N
210059	teismoodi	teismoodi =moodi  (SgP  >teis+mood !22_S	et	f	\N
210060	teismoodi	teismoodi =moodi  (SgAdt  >teis+mood !22_S	et	f	\N
210091	pidutsenud	pidutsenud =pidutse  (PtsPtPs  >pidutsema !27_V	et	f	\N
210092	pidutsenud	pidutsenud =pidutsenu  (PlN  >pidutsenu !01_S	et	f	\N
210093	pidutsenud	"pidutsenu %pidutse  )NU_vS  <pidutsema ;27_V	et	f	\N
210094	pidutsenud	pidutsenud =pidutsenud  (ID  >pidutsenud !41_A	et	f	\N
210095	pidutsenud	"pidutsenud %pidutse  )NUD_vA  <pidutsema ;27_V	et	f	\N
210101	pohmakaga	?pohmakaga =pohmaka  (SgKom  >pohmaka !01_S	et	f	\N
210102	pohmakaga	?pohmakaga =pohmaka  (SgKom  >pohmakas !02_S	et	f	\N
210109	joulu	?joulu =joulu  (SgN  >joulu !16_S	et	f	\N
210110	joulu	?joulu =joulu  (SgG  >joulu !16_S	et	f	\N
210111	joulu	?joulu =joulu  (IndPrPs_  >jouluma !28_V	et	f	\N
210112	joulu	?joulu =joulu  (ImpPrSg2  >jouluma !28_V	et	f	\N
210113	jõulumuusika	jõulumuusika =muusika  (SgN  >jõulu+muusika !01_S	et	f	\N
210114	jõulumuusika	jõulumuusika =muusika  (SgG  >jõulu+muusika !01_S	et	f	\N
210117	pidulaud	pidulaud =lau  (PlN  >pidu+laug !22_SA	et	f	\N
210118	pidulaud	pidulaud =laud  (SgN  >pidu+laud !22_S	et	f	\N
210126	rõõmustavad	rõõmustavad =rõõmusta  (IndPrPl3  >rõõmustama !27_V	et	f	\N
210127	rõõmustavad	rõõmustavad =rõõmustava  (PlN  >rõõmustav !02_A	et	f	\N
210128	rõõmustavad	"rõõmustav %rõõmusta  )V_vA  <rõõmustama ;27_V	et	f	\N
210134	täituksid	täituksid =täitu  (KndPrSg2  >täituma !27_V	et	f	\N
210135	täituksid	täituksid =täitu  (KndPrPl3  >täituma !27_V	et	f	\N
210136	täituksid	täituksid =tuksi  (PlN  >täi+tuks !22_S	et	f	\N
210137	laplandiasse	?laplandiasse =laplandia  (SgIll  >laplandia !01_S	et	f	\N
210138	laplandiasse	?laplandiasse =laplandias  (SgAdt  >laplandias !11_S	et	f	\N
210139	laplandiasse	?laplandiasse =laplandiasse  (SgG  >laplandiasne !02_A	et	f	\N
210140	laplandiasse	?laplandiasse =laplandiasse  (PlP  >laplandiass !22_S	et	f	\N
210144	pidetsevad	?pidetsevad =pidetse  (IndPrPl3  >pidetsema !27_V	et	f	\N
210145	pidetsevad	?pidetsevad =pidetseva  (PlN  >pidetsev !02_A	et	f	\N
210146	pidetsevad	?pidetsevad =pidetseva  (PlN  >pidetseva !16_S	et	f	\N
210147	pidetsevad	?pidetsevad =tseva  (PlN  >pide+tseva !17_S	et	f	\N
210163	pidetsuvad	?pidetsuvad =pidetsu  (IndPrPl3  >pidetsuma !27_V	et	f	\N
210164	pidetsuvad	?pidetsuvad =pidetsuva  (PlN  >pidetsuv !02_A	et	f	\N
210166	pidetsuvad	?pidetsuvad =pidetsuva  (PlN  >pidetsuva !16_S	et	f	\N
210167	pidetsuvad	?pidetsuvad =tsuva  (PlN  >pide+tsuva !17_S	et	f	\N
210172	kingitada	?kingitada =kingita  (Inf  >kingitama !27_V	et	f	\N
210173	kingitada	?kingitada =tada  (SgN  >kingi+tada !17_S	et	f	\N
210174	kingitada	?kingitada =tada  (SgG  >kingi+tada !17_S	et	f	\N
210175	kingitada	?kingitada =tada  (SgP  >kingi+tada !17_S	et	f	\N
210176	vabem	?vabem =vabem  (SgN  >vabem !02_A	et	f	\N
210188	katoliiklikust	katoliiklikust =katoliikliku  (SgEl  >katoliiklik !25_A	et	f	\N
210189	katoliiklikust	katoliiklikust =katoliiklikus  (SgP  >katoliiklikus !11?09_S	et	f	\N
210190	katoliiklikust	"katoliiklikus %katoliikliku  )US_aS  <katoliiklik ;25_A	et	f	\N
210198	unistatud	unistatud =unista  (PtsPtIps  >unistama !27_V	et	f	\N
210199	unistatud	unistatud =unistatu  (PlN  >unistatu !01_S	et	f	\N
210200	unistatud	"unistatu %unista  )TU1_vS  <unistama ;27_V	et	f	\N
210201	unistatud	unistatud =unistatud  (ID  >unistatud !41_A	et	f	\N
210202	unistatud	"unistatud %unista  )TUD_vA  <unistama ;27_V	et	f	\N
210215	sessijaks	?sessijaks =sessija  (SgTr  >sessija !01_S	et	f	\N
210216	sessijaks	?sessijaks =sessija  (SgTr  >sessijas !02_A	et	f	\N
210228	künlaid	?künlaid =künlai  (PlN  >künlai !26_S	et	f	\N
210229	künlaid	?künlaid =künlai  (SgP  >künlai !26_S	et	f	\N
210230	künlaid	?künlaid =künlaid  (SgN  >künlaid !22_S	et	f	\N
210233	tudengidele	### tudengidele	et	f	\N
210234	õpitajale	?õpitajale =õpitaja  (SgAll  >õpitaja !01_S	et	f	\N
210235	õpitajale	?õpitajale =õpitaja  (SgAll  >õpitajas !02_A	et	f	\N
210236	õpitajale	?õpitajale =õpitajale  (PlP  >õpitajal !19_S	et	f	\N
210237	õpitajale	?õpitajale =taja  (SgAll  >õpi+taja !17_S	et	f	\N
210251	kinki	kinki =kinki  (SgP  >kink !22_S	et	f	\N
210252	kinki	kinki =kinki  (SgAdt  >kink !22_S	et	f	\N
210265	sessia	?sessia =sessia  (SgN  >sessia !01_S	et	f	\N
210266	sessia	?sessia =sessia  (SgG  >sessia !01_S	et	f	\N
210276	bussi-peatuses	bussi-peatuses =peatuse  (SgIn  >bussi-peatus !11~09_S	et	f	\N
210277	bussi-peatuses	"bussi-peatus %peata  )US_vS  <bussi-peatama ;27_V	et	f	\N
210278	bussi-peatuses	"bussi-peatus %pea  )TUS2_aS  <bussi-pea ;26_S	et	f	\N
210292	jõulutuju	jõulutuju =tuju  (SgN  >jõulu+tuju !17_S	et	f	\N
210293	jõulutuju	jõulutuju =tuju  (SgG  >jõulu+tuju !17_S	et	f	\N
210294	jõulutuju	jõulutuju =tuju  (SgP  >jõulu+tuju !17_S	et	f	\N
210295	toitusi	toitusi =toitusi  (PlP  >toitus !11_S	et	f	\N
210066	indeika	?indeika =indeika  (SgG  >indeikas !02_S	et	f	\N
210067	indeika	?indeika =indeika  (SgG  >indeika !16_S	et	f	\N
210074	soovita	soovita =soovi  (SgAb  >soov !22_S	et	f	\N
210075	soovita	soovita =soovi  (IndPrIps_  >soovima !28_V	et	f	\N
210076	soovita	soovita =soovita  (IndPrPs_  >soovitama !27_V	et	f	\N
210077	soovita	soovita =soovita  (ImpPrSg2  >soovitama !27_V	et	f	\N
210078	valimista	?valimista =valimista  (SgN  >valimista !16_S	et	f	\N
210079	valimista	?valimista =valimista  (SgG  >valimista !16_S	et	f	\N
210080	valimista	?valimista =valimista  (IndPrPs_  >valimistama !27_V	et	f	\N
210081	valimista	?valimista =valimista  (ImpPrSg2  >valimistama !27_V	et	f	\N
210085	soritada	?soritada =sorita  (Inf  >soritama !27_V	et	f	\N
210096	kohustuslikult	kohustuslikult =kohustusliku  (SgAbl  >kohustuslik !25_A	et	f	\N
210097	kohustuslikult	kohustuslikult =kohustuslikult  (ID  >kohustuslikult !41_D	et	f	\N
210098	kohustuslikult	"kohustuslikult %kohustusliku  )LT_mD  <kohustuslik ;25_A	et	f	\N
210123	jõulumõted	### jõulumõted	et	f	\N
210124	elamutest	elamutest =elamu  (PlEl  >elamu !01_S	et	f	\N
210125	elamutest	elamutest =test  (SgN  >elamu+test !22_S	et	f	\N
210129	teine-teisele	teine-teisele =teise  (SgAll  >teine-teine !12_OP	et	f	\N
210130	teine-teisele	teine-teisele =teise  (SgAll  >teine-teise !12_P	et	f	\N
210165	katolikline	?katolikline =katolikline  (SgN  >katolikline !12_A	et	f	\N
210168	probleme	?probleme =proble  (IndPrPl1  >problema !30_V	et	f	\N
210179	alatiselt	alatiselt =alatise  (SgAbl  >alatine !12_A	et	f	\N
210180	alatiselt	alatiselt =alatiselt  (ID  >alatiselt !41_D	et	f	\N
210181	alatiselt	"alatiselt %alatise  )LT_mD  <alatine ;12_A	et	f	\N
210184	mälitatud	?mälitatud =mälita  (PtsPtIps  >mälitama !27_V	et	f	\N
210185	mälitatud	?mälitatud =mälitatu  (PlN  >mälitatu !01_S	et	f	\N
210186	mälitatud	?mälitatud =mälitatu  (IndPrSg2  >mälitatuma !27_V	et	f	\N
210187	mälitatud	?mälitatud =mälitatud  (ID  >mälitatud !41_A	et	f	\N
210194	istumist	istumist =istumis  (SgP  >istumine !12_S	et	f	\N
210195	istumist	"istumine %istu  )MINE_vS  <istuma ;28_V	et	f	\N
210203	päkapikud	päkapikud =piku  (PlN  >päka+pikk !22_S	et	f	\N
210204	päkapikud	päkapikud =piku  (PlN  >päka+pikk !22_AS	et	f	\N
210221	täitusid	täitusid =täitu  (IndIpfSg2  >täituma !27_V	et	f	\N
210222	täitusid	täitusid =täitu  (IndIpfPl3  >täituma !27_V	et	f	\N
210223	katoliklane	?katoliklane =katoliklane  (SgN  >katoliklane !12_S	et	f	\N
210231	juuad	?juuad =juua  (PlN  >juua !16_S	et	f	\N
210232	juuad	?juuad =juuad  (SgN  >juuad !02_S	et	f	\N
210238	taen	?taen =taen  (SgN  >taen !22_S	et	f	\N
210245	küpsitab	?küpsitab =küpsita  (IndPrSg3  >küpsitama !27_V	et	f	\N
210260	kattab	?kattab =katta  (IndPrSg3  >kattama !29_V	et	f	\N
210267	analüüsit	?analüüsit =analüüsi  (SgP  >analüüsi !16_S	et	f	\N
210279	sallis	sallis =salli  (SgIn  >sall !22_S	et	f	\N
210280	sallis	sallis =salli  (IndIpfSg3  >sallima !28_V	et	f	\N
210290	põrumist	põrumist =põrumis  (SgP  >põrumine !12_S	et	f	\N
210291	põrumist	"põrumine %põru  )MINE_vS  <põruma ;27_V	et	f	\N
210310	sankt-peterburgis	?sankt-peterburgis =peterburgi  (SgIn  >sankt-peterburk !22_S	et	f	\N
210311	sankt-peterburgis	?sankt-peterburgis =peterburgi  (IndIpfSg3  >sankt-peterburgima !28_V	et	f	\N
210312	sankt-peterburgis	?sankt-peterburgis =peterburgis  (SgN  >sankt-peterburgis !09_S	et	f	\N
210323	jatas	?jatas =jata  (SgIn  >jata !16_S	et	f	\N
210324	jatas	?jatas =jata  (IndIpfSg3  >jatama !27_V	et	f	\N
210325	jatas	?jatas =jatas  (SgN  >jatas !07_S	et	f	\N
210326	närvilisem	närvilisem =närvilisem  (SgN  >närvilisem !02_A	et	f	\N
210327	närvilisem	"närvilisem %närvi  )LISEM_cA  <närv ;22_S	et	f	\N
210328	närvilisem	"närvilisem %närvilise  )M_cA  <närviline ;12_A	et	f	\N
210329	sms	### sms	et	f	\N
210330	kolmases	?kolmases =kolmase  (SgIn  >kolmane !10_A	et	f	\N
210331	kolmases	?kolmases =ases  (SgN  >kolm+ases !09_S	et	f	\N
210358	melde	?melde =melde  (SgN  >melde !06_S	et	f	\N
210359	melde	?melde =melde  (SgG  >melle !06_S	et	f	\N
210360	melde	?melde =melde  (PlP  >meld !22_S	et	f	\N
210361	melde	?melde =melde  (IndPrPs_  >meldema !27_V	et	f	\N
210362	melde	?melde =melde  (ImpPrSg2  >meldema !27_V	et	f	\N
210381	õppetamise	?õppetamise =õppetamise  (SgG  >õppetamine !12_S	et	f	\N
210382	õppetamise	?õppetamise =tamise  (SgG  >õppe+tamine !10_A	et	f	\N
210390	sõitideses	?sõitideses =sõitidese  (SgIn  >sõitidene !12_A	et	f	\N
210399	rakveresse	?rakveresse =rakveres  (SgAdt  >rakverene !12_A	et	f	\N
210400	rakveresse	?rakveresse =rakveresse  (SgG  >rakveresne !02_A	et	f	\N
210401	rakveresse	?rakveresse =rakveresse  (PlP  >rakveress !22_S	et	f	\N
210402	puhkanud	?puhkanud =puhkanu  (PlN  >puhkanu !01_S	et	f	\N
210403	puhkanud	?puhkanud =puhkanu  (IndPrSg2  >puhkanuma !27_V	et	f	\N
210404	puhkanud	?puhkanud =puhkanud  (ID  >puhkanud !41_A	et	f	\N
210405	puhkanud	?puhkanud =anu  (PlN  >puhk+anu !17_S	et	f	\N
210411	inlise	?inlise =inlise  (SgG  >inline !10_A	et	f	\N
210412	inlise	?inlise =inlise  (IndPrPs_  >inlisema !27_V	et	f	\N
210413	inlise	?inlise =inlise  (ImpPrSg2  >inlisema !27_V	et	f	\N
210421	kardasid	kardasid =karda  (PlP  >kard !22_S	et	f	\N
210226	jõulupuu	jõulupuu =puu  (SgN  >jõulu+puu !26_S	et	f	\N
210227	jõulupuu	jõulupuu =puu  (SgG  >jõulu+puu !26_S	et	f	\N
210246	piparkoogi	piparkoogi =koogi  (SgG  >pipar+kook !22_S	et	f	\N
210247	piparkoogi	piparkoogi =koo  (SgG^  >pipar+kubu !18_S	et	f	\N
210248	pakkin	?pakkin =pakkin  (SgN  >pakkin !02_S	et	f	\N
210262	jõulupäeevad	?jõulupäeevad =jõulupäeeva  (PlN  >jõulupäeeva !16_S	et	f	\N
210263	jõulupäeevad	?jõulupäeevad =päeeva  (PlN  >jõulu+päeeva !16_S	et	f	\N
210264	jõulupäeevad	?jõulupäeevad =lupäeeva  (PlN  >jõu+lupäeeva !16_S	et	f	\N
210282	tulevikkus	?tulevikkus =tulevikku  (IndIpfSg3  >tulevikkuma !27_V	et	f	\N
210283	tulevikkus	?tulevikkus =tulevikkus  (SgN  >tulevikkus !11~09_S	et	f	\N
210284	tulevikkus	?tulevikkus =ikkus  (SgN  >tulev+ikkus !11~09_S	et	f	\N
210285	tulevikkus	?tulevikkus =vikkus  (SgN  >tule+vikkus !11~09_S	et	f	\N
210286	hakan	?hakan =haka  (IndPrSg1  >hakama !27_V	et	f	\N
210287	hakan	?hakan =hakan  (SgN  >hakan !02_S	et	f	\N
210300	suutatada	?suutatada =suutata  (Inf  >suutatama !27_V	et	f	\N
210303	meeldejätmiv	?meeldejätmiv =meeldejätmi  (PtsPrPs  >meeldejätmima !28_V	et	f	\N
210304	meeldejätmiv	?meeldejätmiv =meeldejätmiv  (SgN  >meeldejätmiv !02_A	et	f	\N
210305	meeldejätmiv	?meeldejätmiv =jätmi  (PtsPrPs  >meelde+_jätmima !28_V	et	f	\N
210306	meeldejätmiv	?meeldejätmiv =jätmiv  (SgN  >meelde+jätmiv !02_A	et	f	\N
210332	leeduse	leeduse =leeduse  (SgG  >leedus !11~09_S	et	f	\N
210333	leeduse	"leedus %lee  )TUS1_aS  <leema ;37_V	et	f	\N
210336	tttks	### tttks	et	f	\N
210337	võistusest	?võistusest =võistuse  (SgEl  >võistus !11~09_S	et	f	\N
210338	võistusest	?võistusest =võistuses  (SgP  >võistusene !12_A	et	f	\N
210340	võistusest	?võistusest =stuse  (SgEl  >või+stuse !16_S	et	f	\N
210342	võistusest	?võistusest =stuses  (SgP  >või+stuses !09_S	et	f	\N
210343	võistusest	?võistusest =stuses  (SgP  >või+stusene !10_A	et	f	\N
210350	pojake	pojake =pojake  (SgN  >pojake !12_S	et	f	\N
210351	pojake	"pojake %poja  )KE_dS  <poja ;17_S	et	f	\N
210352	pojake	"pojake %poja  )KE_dS  <poeg ;22_S	et	f	\N
210353	viitna	?viitna =viitna  (SgN  >viitna !01_S	et	f	\N
210354	viitna	?viitna =viitna  (SgG  >viitna !01_S	et	f	\N
210355	viitna	?viitna =viitna  (IndPrPs_  >viitnama !29_V	et	f	\N
210356	viitna	?viitna =viitna  (ImpPrSg2  >viitnama !29_V	et	f	\N
210372	asutumine	?asutumine =asutumine  (SgN  >asutumine !12_S	et	f	\N
210373	asutumine	?asutumine =asutumine  (PlP  >asutumin !19_S	et	f	\N
210374	asutumine	?asutumine =tumine  (SgN  >asu+tumine !10_A	et	f	\N
210383	teostusid	teostusid =teostu  (IndIpfSg2  >teostuma !27_V	et	f	\N
210384	teostusid	teostusid =teostu  (IndIpfPl3  >teostuma !27_V	et	f	\N
210408	suveniiri	suveniiri =suveniiri  (SgG  >suveniir !22_S	et	f	\N
210409	suveniiri	suveniiri =suveniiri  (SgP  >suveniir !22_S	et	f	\N
210410	suveniiri	suveniiri =suveniiri  (SgAdt  >suveniir !22_S	et	f	\N
210414	tuttvusin	?tuttvusin =tuttvu  (IndIpfSg1  >tuttvuma !27_V	et	f	\N
210415	tuttvusin	?tuttvusin =tuttvusin  (SgN  >tuttvusin !19_S	et	f	\N
210417	seline	?seline =seline  (SgN  >seline !10_A	et	f	\N
210418	seline	?seline =seline  (IndPrPs_  >selinema !27_V	et	f	\N
210419	seline	?seline =seline  (ImpPrSg2  >selinema !27_V	et	f	\N
210426	klienditega	?klienditega =kliendi  (PlKom  >kliendi !01_S	et	f	\N
210427	klienditega	?klienditega =kliendi  (PlKom  >kliend !02_S	et	f	\N
210436	2006-ndal	### 2006-ndal	et	f	\N
210440	haiglase	haiglase =haiglase  (SgG  >haiglane !12?10_A	et	f	\N
210441	haiglase	"haiglane %haigla  )NE_aA  <haigla ;01_S	et	f	\N
210483	häälita	häälita =hääli  (IndPrIps_  >häälima !28_V	et	f	\N
210484	häälita	häälita =häälita  (IndPrPs_  >häälitama !27_V	et	f	\N
210485	häälita	häälita =häälita  (ImpPrSg2  >häälitama !27_V	et	f	\N
210488	inmestele	?inmestele =inmes  (PlAll  >inmes !09_S	et	f	\N
210489	inmestele	?inmestele =inmes  (PlAll  >inmene !10_A	et	f	\N
210490	inmestele	?inmestele =inmestele  (IndPrPs_  >inmestelema !36_V	et	f	\N
210491	inmestele	?inmestele =inmestele  (ImpPrSg2  >inmestelema !36_V	et	f	\N
210499	globaalsetest	globaalsetest =globaalse  (PlEl  >globaalne !02_A	et	f	\N
210500	globaalsetest	globaalsetest =sete  (PlEl  >globaal+sett !22_S	et	f	\N
210512	saastavad	saastavad =saasta  (IndPrPl3  >saastama !29~27_V	et	f	\N
210513	saastavad	saastavad =saastava  (PlN  >saastav !02_A	et	f	\N
210514	saastavad	"saastav %saasta  )V_vA  <saastama ;27_V	et	f	\N
210515	saastavad	"saastav %saasta  )V_vA  <saastama ;29_V	et	f	\N
210537	mootoriga	mootoriga =mootori  (SgKom  >mootor !02_S	et	f	\N
210538	mootoriga	mootoriga =iga  (SgN  >mootor+iga !18_S	et	f	\N
210539	mootoriga	mootoriga =iga  (SgP  >mootor+iga !18_S	et	f	\N
210550	beziini	?beziini =bezii  (SgTer  >bezii !26_S	et	f	\N
210551	beziini	?beziini =beziini  (SgN  >beziini !16_S	et	f	\N
210552	beziini	?beziini =beziini  (SgG  >beziini !16_S	et	f	\N
210553	beziini	?beziini =beziini  (SgG  >beziin !22_S	et	f	\N
210554	beziini	?beziini =beziini  (SgP  >beziin !22_S	et	f	\N
210555	beziini	?beziini =beziini  (SgAdt  >beziin !22_S	et	f	\N
210556	beziini	?beziini =beziini  (IndPrPs_  >beziinima !28_V	et	f	\N
210296	toitusi	"toitus %toi  )TUS2_aS  <toi ;26_S	et	f	\N
210297	lolli	lolli =lolli  (SgG  >loll !22_AS	et	f	\N
210298	lolli	lolli =lolli  (SgP  >loll !22_AS	et	f	\N
210299	lolli	lolli =lolli  (SgAdt  >loll !22_AS	et	f	\N
210307	hiilgavad	hiilgavad =hiilga  (IndPrPl3  >hiilgama !29_V	et	f	\N
210308	hiilgavad	hiilgavad =hiilgava  (PlN  >hiilgav !02_A	et	f	\N
210309	hiilgavad	"hiilgav %hiilga  )V_vA  <hiilgama ;29_V	et	f	\N
210313	imestatud	imestatud =imesta  (PtsPtIps  >imestama !27_V	et	f	\N
210314	imestatud	imestatud =imestatu  (PlN  >imestatu !01_S	et	f	\N
210315	imestatud	"imestatu %imesta  )TU1_vS  <imestama ;27_V	et	f	\N
210316	imestatud	imestatud =imestatud  (ID  >imestatud !41_A	et	f	\N
210317	imestatud	"imestatud %imesta  )TUD_vA  <imestama ;27_V	et	f	\N
210321	katastrofid	?katastrofid =katastrofi  (PlN  >katastroff !22_S	et	f	\N
210322	katastrofid	?katastrofid =katastrofi  (IndPrSg2  >katastroffima !28_V	et	f	\N
210334	soidsin	?soidsin =soidsi  (IndPrSg1  >soidsima !28_V	et	f	\N
210335	soidsin	?soidsin =soidsin  (SgN  >soidsin !02_S	et	f	\N
210344	meeskonnast	meeskonnast =meeskonna  (SgEl  >meeskond !22_S	et	f	\N
210345	meeskonnast	meeskonnast =meeskonnas  (SgP  >meeskonnane !12_A	et	f	\N
210346	meeskonnast	"meeskonnane %meeskonna  )NE_aA  <meeskond ;22_S	et	f	\N
210347	meeskonnast	meeskonnast =konna  (SgEl  >mees+konn !22_S	et	f	\N
210348	meeskonnast	meeskonnast =konnas  (SgP  >mees+konnane !10_A	et	f	\N
210349	meeskonnast	"mees+konnane %konna  )NE_aA  <mees+konn ;22_S	et	f	\N
210385	nelisega	?nelisega =nelise  (SgKom  >neline !10_A	et	f	\N
210386	nelisega	?nelisega =sega  (SgN  >neli+sega !17_S	et	f	\N
210387	nelisega	?nelisega =sega  (SgG  >neli+sega !17_S	et	f	\N
210388	nelisega	?nelisega =sega  (SgP  >neli+sega !17_S	et	f	\N
210394	jäärves	?jäärves =jäärve  (SgIn  >jäärve !06_S	et	f	\N
210395	jäärves	?jäärves =jäärve  (PlIn  >jäärv !22_S	et	f	\N
210396	jäärves	?jäärves =jäärve  (IndIpfSg3  >jäärvema !27_V	et	f	\N
210397	jäärves	?jäärves =jäärves  (SgN  >jäärves !09_S	et	f	\N
210398	lobisime	?lobisime =lobi  (IndIpfPl1  >lobima !27_V	et	f	\N
210424	sooritasid	sooritasid =soorita  (IndIpfSg2  >sooritama !27_V	et	f	\N
210425	sooritasid	sooritasid =soorita  (IndIpfPl3  >sooritama !27_V	et	f	\N
210443	oparatsioon	?oparatsioon =oparatsioon  (SgN  >oparatsioon !22_S	et	f	\N
210445	ravimis	ravimis =ravimi  (SgIn  >ravim !02_S	et	f	\N
210446	ravimis	ravimis =mi  (SgIn  >ravi+mi !26_S	et	f	\N
210451	ökoelu	ökoelu =elu  (SgN  >öko+elu !17_S	et	f	\N
210452	ökoelu	ökoelu =elu  (SgG  >öko+elu !17_S	et	f	\N
210453	ökoelu	ökoelu =elu  (SgP  >öko+elu !17_S	et	f	\N
210454	teravaks	teravaks =terava  (SgTr  >terav !02_A	et	f	\N
210455	teravaks	teravaks =vaks  (SgN  >tera+vaks !22_S	et	f	\N
210463	mullaviljakuse	mullaviljakuse =kuse  (SgG  >mulla+vilja+kusi !20_S	et	f	\N
210464	mullaviljakuse	mullaviljakuse =viljakuse  (SgG  >mulla+viljakus !11_S	et	f	\N
210465	mullaviljakuse	"mulla+viljakus %viljaka  )US_aS  <mulla+viljakas ;02_A	et	f	\N
210507	ükokaubad	?ükokaubad =ükokauba  (PlN  >ükokauba !16_S	et	f	\N
210520	oni	?oni =oni  (SgN  >oni !17_S	et	f	\N
210521	oni	?oni =oni  (SgG  >oni !17_S	et	f	\N
210522	oni	?oni =oni  (SgP  >oni !17_S	et	f	\N
210523	oni	?oni =oni  (IndPrPs_  >onima !27_V	et	f	\N
210524	oni	?oni =oni  (ImpPrSg2  >onima !27_V	et	f	\N
210528	saslõket	### saslõket	et	f	\N
210540	benziini	?benziini =benzii  (SgTer  >benzii !26_S	et	f	\N
210541	benziini	?benziini =benziini  (SgN  >benziini !16_S	et	f	\N
210542	benziini	?benziini =benziini  (SgG  >benziini !16_S	et	f	\N
210543	benziini	?benziini =benziini  (SgG  >benziin !22_S	et	f	\N
210544	benziini	?benziini =benziini  (SgP  >benziin !22_S	et	f	\N
210545	benziini	?benziini =benziini  (SgAdt  >benziin !22_S	et	f	\N
210546	benziini	?benziini =benziini  (IndPrPs_  >benziinima !28_V	et	f	\N
210547	benziini	?benziini =benziini  (ImpPrSg2  >benziinima !28_V	et	f	\N
210548	etkahjuks	?etkahjuks =etkahju  (SgTr  >etkahju !01_S	et	f	\N
210549	etkahjuks	?etkahjuks =etkahju  (KndPrPs  >etkahjuma !27_V	et	f	\N
210564	saatsab	?saatsab =saatsa  (IndPrSg3  >saatsama !29_V	et	f	\N
210597	rohkeem	?rohkeem =rohkeem  (SgN  >rohkeem !22_S	et	f	\N
210616	joolsul	?joolsul =joolsu  (SgAd  >joolsu !01_S	et	f	\N
210617	joolsul	?joolsul =joolsul  (SgN  >joolsul !02_S	et	f	\N
210627	ainulad	?ainulad =ainula  (PlN  >ainula !01_S	et	f	\N
210669	uliopilasuhiselamus	?uliopilasuhiselamus =uliopilasuhiselamu  (IndIpfSg3  >uliopilasuhiselamuma !27_V	et	f	\N
210670	uliopilasuhiselamus	?uliopilasuhiselamus =uliopilasuhiselamus  (SgN  >uliopilasuhiselamus !11?09_S	et	f	\N
210697	paiskavad	paiskavad =paiska  (IndPrPl3  >paiskama !29_V	et	f	\N
210698	paiskavad	paiskavad =paiskava  (PlN  >paiskav !02_A	et	f	\N
210699	paiskavad	"paiskav %paiska  )V_vA  <paiskama ;29_V	et	f	\N
210705	häivinud	?häivinud =häivi  (PtsPtPs  >häivima !28_V	et	f	\N
210708	häivinud	?häivinud =häivinu  (PlN  >häivinu !01_S	et	f	\N
210709	häivinud	?häivinud =häivinu  (IndPrSg2  >häivinuma !27_V	et	f	\N
210710	häivinud	?häivinud =häivinud  (ID  >häivinud !41_A	et	f	\N
210714	keskkona	?keskkona =keskko  (SgEs  >keskko !16_S	et	f	\N
210422	kardasid	kardasid =karda  (IndIpfSg2  >kardama !29_V	et	f	\N
210423	kardasid	kardasid =karda  (IndIpfPl3  >kardama !29_V	et	f	\N
210437	usa-presidenti	usa-presidenti =presidenti  (SgP  >usa-president !22_S	et	f	\N
210438	usa-presidenti	usa-presidenti =presidenti  (SgAdt  >usa-president !22_S	et	f	\N
210447	treeninguid	treeninguid =treeningu  (PlP  >treening !02_S	et	f	\N
210448	treeninguid	treeninguid =ui  (PlN  >treening+ui !26_S	et	f	\N
210449	treeninguid	treeninguid =ui  (SgP  >treening+ui !26_S	et	f	\N
210450	treeninguid	treeninguid =uid  (SgN  >treening+uid !22_S	et	f	\N
210471	keskkonnasse	keskkonnasse =keskkonna  (SgIll  >keskkond !22_S	et	f	\N
210472	keskkonnasse	keskkonnasse =keskkonnas  (SgAdt  >keskkonnane !12_A	et	f	\N
210473	keskkonnasse	"keskkonnane %keskkonna  )NE_aA  <keskkond ;22_S	et	f	\N
210477	kasutamisse	kasutamisse =kasutamis  (SgAdt  >kasutamine !12_S	et	f	\N
210478	kasutamisse	"kasutamine %kasuta  )MINE_vS  <kasutama ;27_V	et	f	\N
210492	kultuurselt	kultuurselt =kultuurse  (SgAbl  >kultuurne !02_A	et	f	\N
210493	kultuurselt	kultuurselt =kultuurselt  (ID  >kultuurselt !41_D	et	f	\N
210494	kultuurselt	"kultuurselt %kultuurse  )LT_mD  <kultuurne ;02_A	et	f	\N
210497	metsalagendikut	?metsalagendikut =gendiku  (SgP  >mets+ala+gendiku !01_S	et	f	\N
210498	metsalagendikut	?metsalagendikut =gendiku  (SgP  >mets+ala+gendik !02_S	et	f	\N
210525	tühjat	?tühjat =tühja  (SgP  >tühjas !02_A	et	f	\N
210526	tühjat	?tühjat =tühja  (SgP  >tühja !16_S	et	f	\N
210527	tühjat	?tühjat =tühjat  (SgN  >tühjat !02_S	et	f	\N
210531	glaasist	?glaasist =glaasi  (SgEl  >glaasi !16_S	et	f	\N
210532	glaasist	?glaasist =glaasi  (SgEl  >glaas !22_S	et	f	\N
210533	glaasist	?glaasist =glaasis  (SgP  >glaasis !09_S	et	f	\N
210534	glaasist	?glaasist =glaasist  (SgN  >glaasist !22_S	et	f	\N
210558	vaheneb	?vaheneb =vahene  (IndPrSg3  >vahenema !27_V	et	f	\N
210570	spetsiaalsesse	spetsiaalsesse =spetsiaalse  (SgIll  >spetsiaalne !02_A	et	f	\N
210571	spetsiaalsesse	spetsiaalsesse =sesse  (PlP  >spetsiaal+sess !22_S	et	f	\N
210574	öko	?öko =öko  (SgN  >öko !16_S	et	f	\N
210575	öko	?öko =öko  (SgG  >öko !16_S	et	f	\N
210579	raiska	raiska =raiska  (SgP  >raisk !22_S	et	f	\N
210580	raiska	raiska =raiska  (SgAdt  >raisk !22_S	et	f	\N
210581	raiska	raiska =raiska  (IndPrPs_  >raiskama !29_V	et	f	\N
210582	raiska	raiska =raiska  (ImpPrSg2  >raiskama !29_V	et	f	\N
210596	tranporteerimiseks	?tranporteerimiseks =tranporteerimise  (SgTr  >tranporteerimine !12_S	et	f	\N
210601	sorteerivad	sorteerivad =sorteeri  (IndPrPl3  >sorteerima !28_V	et	f	\N
210602	sorteerivad	sorteerivad =sorteeriva  (PlN  >sorteeriv !02_A	et	f	\N
210603	sorteerivad	"sorteeriv %sorteeri  )V_vA  <sorteerima ;28_V	et	f	\N
210618	automaadile	automaadile =automaadi  (SgAll  >automaat !22_S	et	f	\N
210619	automaadile	automaadile =maadi  (SgAll  >auto+maat !22_S	et	f	\N
210630	okoelu	?okoelu =okoelu  (SgN  >okoelu !17_S	et	f	\N
210631	okoelu	?okoelu =okoelu  (SgG  >okoelu !17_S	et	f	\N
210632	okoelu	?okoelu =okoelu  (SgP  >okoelu !17_S	et	f	\N
210633	okoelu	?okoelu =okoelu  (IndPrPs_  >okoeluma !27_V	et	f	\N
210634	okoelu	?okoelu =okoelu  (ImpPrSg2  >okoeluma !27_V	et	f	\N
210639	prugimaed	?prugimaed =prugimae  (PlN  >prugimae !26_S	et	f	\N
210640	prugimaed	?prugimaed =prugimae  (SgP  >prugimae !26_S	et	f	\N
210641	prugimaed	?prugimaed =prugimaed  (SgN  >prugimaed !22_S	et	f	\N
210645	haralik	?haralik =haralik  (SgN  >haralik !25_A	et	f	\N
210648	teadvusega	teadvusega =teadvuse  (SgKom  >teadvus !11~09_S	et	f	\N
210649	teadvusega	"teadvus %tead  )VUS_aS  <teadma ;34_V	et	f	\N
210650	teadvusega	"teadvus %teadva  )US_aS  <teadev ;02_A	et	f	\N
210660	toksilised	toksilised =toksilise  (PlN  >toksiline !12_A	et	f	\N
210661	toksilised	"toksiline %toksi  )LINE_aA  <toks ;22_S	et	f	\N
210671	soita	?soita =soi  (SgAb  >soi !26_S	et	f	\N
210672	soita	?soita =soit  (Inf  >soitma !34_V	et	f	\N
210673	soita	?soita =soita  (SgN  >soita !16_S	et	f	\N
210674	soita	?soita =soita  (SgG  >soita !16_S	et	f	\N
210675	soita	?soita =soita  (IndPrPs_  >soitama !27_V	et	f	\N
210676	soita	?soita =soita  (ImpPrSg2  >soitama !27_V	et	f	\N
210700	kopsuvähki	kopsuvähki =vähki  (SgP  >kopsu+vähk !22_S	et	f	\N
210701	kopsuvähki	kopsuvähki =vähki  (SgAdt  >kopsu+vähk !22_S	et	f	\N
210711	keemilist	keemilist =keemilis  (SgP  >keemiline !12_A	et	f	\N
210712	keemilist	"keemiline %keemi  )LINE_aA  <keem ;22_S	et	f	\N
210720	eheergiaallikaid	?eheergiaallikaid =eheergiaallika  (PlP  >eheergiaallika !01_S	et	f	\N
210721	eheergiaallikaid	?eheergiaallikaid =eheergiaallika  (PlP  >eheergiaallikas !02_A	et	f	\N
210722	eheergiaallikaid	?eheergiaallikaid =eheergiaallikai  (PlN  >eheergiaallikai !26_S	et	f	\N
210723	eheergiaallikaid	?eheergiaallikaid =eheergiaallikai  (SgP  >eheergiaallikai !26_S	et	f	\N
210738	nissugustel	?nissugustel =nissugus  (PlAd  >nissugus !11_S	et	f	\N
210779	paiskaksid	paiskaksid =paiska  (KndPrSg2  >paiskama !29_V	et	f	\N
210780	paiskaksid	paiskaksid =paiska  (KndPrPl3  >paiskama !29_V	et	f	\N
210781	ökoloogilisest	ökoloogilisest =ökoloogilise  (SgEl  >ökoloogiline !12_A	et	f	\N
210782	ökoloogilisest	"ökoloogiline %ökoloogi  )LINE_aA  <ökoloog ;22_S	et	f	\N
210783	ökoloogilisest	ökoloogilisest =loogilise  (SgEl  >öko+loogiline !12_A	et	f	\N
210428	milioni	?milioni =milio  (SgTer  >milio !01_S	et	f	\N
210429	milioni	?milioni =milioni  (SgN  >milioni !16_S	et	f	\N
210430	milioni	?milioni =milioni  (SgG  >milioni !16_S	et	f	\N
210431	milioni	?milioni =milioni  (SgG  >milion !19_S	et	f	\N
210432	milioni	?milioni =milioni  (SgP  >milion !19_S	et	f	\N
210433	milioni	?milioni =milioni  (SgAdt  >milion !19_S	et	f	\N
210434	milioni	?milioni =milioni  (IndPrPs_  >milionima !28_V	et	f	\N
210435	milioni	?milioni =milioni  (ImpPrSg2  >milionima !28_V	et	f	\N
210459	soojenemine	soojenemine =soojenemine  (SgN  >soojenemine !12_S	et	f	\N
210460	soojenemine	"soojenemine %soojene  )MINE_vS  <soojenema ;27_V	et	f	\N
210466	metsaraie	metsaraie =raie  (SgN  >metsa+raie !05_S	et	f	\N
210467	metsaraie	metsaraie =raie  (SgN  >metsa+raie !06_S	et	f	\N
210468	metsaraie	metsaraie =raie  (SgG  >metsa+raie !06_S	et	f	\N
210469	ebateadlikkus	ebateadlikkus =teadlikkus  (SgN  >eba+teadlikkus !11~09_S	et	f	\N
210470	ebateadlikkus	"eba+teadlikkus %teadlikku  )US_aS  <eba+teadlik ;25_A	et	f	\N
210474	kahjulikku	kahjulikku =kahjulikku  (SgP  >kahjulik !25_A	et	f	\N
210475	kahjulikku	kahjulikku =kahjulikku  (SgAdt  >kahjulik !25_A	et	f	\N
210479	jalgin	?jalgin =jalgi  (IndPrSg1  >jalkima !28_V	et	f	\N
210480	jalgin	?jalgin =jalgin  (SgN  >jalgin !02_S	et	f	\N
210495	väikset	?väikset =väikse  (SgP  >väikne !02_A	et	f	\N
210496	väikset	?väikset =väikse  (SgP  >väikse !06_S	et	f	\N
210508	saastavad	saastavad =saasta  (IndPrPl3  >saastama !29~27_V	et	f	\N
210509	saastavad	saastavad =saastava  (PlN  >saastav !02_A	et	f	\N
210510	saastavad	"saastav %saasta  )V_vA  <saastama ;27_V	et	f	\N
210511	saastavad	"saastav %saasta  )V_vA  <saastama ;29_V	et	f	\N
210516	plasmassist	?plasmassist =plasmassi  (SgEl  >plasmassi !01_S	et	f	\N
210517	plasmassist	?plasmassist =plasmassi  (SgEl  >plasmass !22_S	et	f	\N
210518	plasmassist	?plasmassist =plasmassis  (SgP  >plasmassis !11_S	et	f	\N
210519	plasmassist	?plasmassist =plasmassist  (SgN  >plasmassist !22_S	et	f	\N
210535	trolliga	trolliga =trolli  (SgKom  >trolli !16_S	et	f	\N
210536	trolliga	trolliga =trolli  (SgKom  >troll !22_S	et	f	\N
210559	kordseks	kordseks =kordse  (SgTr  >kordne !02_AS	et	f	\N
210560	kordseks	kordseks =seks  (SgN  >kord+seks !22_S	et	f	\N
210565	saastava	saastava =saastava  (SgG  >saastav !02_A	et	f	\N
210566	saastava	"saastav %saasta  )V_vA  <saastama ;27_V	et	f	\N
210567	saastava	"saastav %saasta  )V_vA  <saastama ;29_V	et	f	\N
210572	kusiklt	?kusiklt =kusiklt  (SgN  >kusiklt !22_S	et	f	\N
210573	kusiklt	?kusiklt =iklt  (SgN  >kus+iklt !22_S	et	f	\N
210576	keskkonnakaitsest	keskkonnakaitsest =kaitse  (SgEl  >kesk+konna+kaitse !06_S	et	f	\N
210577	keskkonnakaitsest	keskkonnakaitsest =kaitses  (SgP  >kesk+konna+kaitsene !12~10_A	et	f	\N
210578	keskkonnakaitsest	"kesk+konna+kaitsene %kaitse  )NE_aA  <kesk+konna+kaitse ;06_S	et	f	\N
210613	naftast	naftast =nafta  (SgEl  >nafta !16_S	et	f	\N
210614	naftast	naftast =naftas  (SgP  >naftane !12~10_A	et	f	\N
210615	naftast	"naftane %nafta  )NE_aA  <nafta ;16_S	et	f	\N
210624	rohlem	?rohlem =rohlem  (SgN  >rohlem !02_A	et	f	\N
210625	laised	?laised =laise  (PlN  >laise !06_S	et	f	\N
210626	laised	?laised =laise  (IndPrSg2  >laisema !28_V	et	f	\N
210637	reostamisest	reostamisest =reostamise  (SgEl  >reostamine !12_S	et	f	\N
210638	reostamisest	"reostamine %reosta  )MINE_vS  <reostama ;27_V	et	f	\N
210642	okoloogiks	?okoloogiks =okoloogi  (SgTr  >okoloogi !16_S	et	f	\N
210643	okoloogiks	?okoloogiks =okoloogi  (SgTr  >okoloog !22_S	et	f	\N
210644	okoloogiks	?okoloogiks =okoloogi  (KndPrPs  >okoloogima !28_V	et	f	\N
210651	prugi	?prugi =prugi  (SgN  >prugi !17_S	et	f	\N
210652	prugi	?prugi =prugi  (SgG  >prugi !17_S	et	f	\N
210653	prugi	?prugi =prugi  (SgP  >prugi !17_S	et	f	\N
210654	prugi	?prugi =prugi  (IndPrPs_  >prugima !27_V	et	f	\N
210655	prugi	?prugi =prugi  (ImpPrSg2  >prugima !27_V	et	f	\N
210658	radioaktiivsed	radioaktiivsed =radioaktiivse  (PlN  >radioaktiivne !02_A	et	f	\N
210659	radioaktiivsed	radioaktiivsed =aktiivse  (PlN  >radio+aktiivne !02_A	et	f	\N
210679	eelkõge	?eelkõge =kõge  (SgN  >eel+kõge !16_S	et	f	\N
210680	eelkõge	?eelkõge =kõge  (SgG  >eel+kõge !16_S	et	f	\N
210702	pöördamatult	?pöördamatult =pöördamatu  (SgAbl  >pöördamatu !01_A	et	f	\N
210703	pöördamatult	?pöördamatult =pöördamatult  (ID  >pöördamatult !41_D	et	f	\N
210704	pöördamatult	?pöördamatult =amatu  (SgAbl  >pöörd+amatu !01_A	et	f	\N
210736	majandused	majandused =majanduse  (PlN  >majandus !11_S	et	f	\N
210737	majandused	"majandus %majanda  )US_vS  <majandama ;27_V	et	f	\N
210741	näfta	?näfta =näfta  (SgN  >näfta !16_S	et	f	\N
210742	näfta	?näfta =näfta  (SgG  >näfta !16_S	et	f	\N
210743	näfta	?näfta =näfta  (IndPrPs_  >näftama !29_V	et	f	\N
210744	näfta	?näfta =näfta  (ImpPrSg2  >näftama !29_V	et	f	\N
210747	riigidele	?riigidele =riigi  (PlAll  >riigi !16_S	et	f	\N
210749	riigidele	?riigidele =riigi  (PlAll  >riig !22_S	et	f	\N
210774	prahi	prahi =prahi  (SgG  >praht !22_S	et	f	\N
210775	prahi	prahi =prahi  (IndPrPs_  >prahtima !28_V	et	f	\N
210776	prahi	prahi =prahi  (ImpPrSg2  >prahtima !28_V	et	f	\N
210789	veendumusel	veendumusel =veendumuse  (SgAd  >veendumus !11_S	et	f	\N
210444	satusin	?satusin =satusin  (SgN  >satusin !19_S	et	f	\N
210456	mageveevaru	mageveevaru =varu  (SgN  >mage+vee+varu !17_S	et	f	\N
210457	mageveevaru	mageveevaru =varu  (SgG  >mage+vee+varu !17_S	et	f	\N
210458	mageveevaru	mageveevaru =varu  (SgP  >mage+vee+varu !17_S	et	f	\N
210461	hõrenemine	hõrenemine =hõrenemine  (SgN  >hõrenemine !12_S	et	f	\N
210462	hõrenemine	"hõrenemine %hõrene  )MINE_vS  <hõrenema ;27_V	et	f	\N
210476	paremiseks	?paremiseks =paremise  (SgTr  >paremine !12_S	et	f	\N
210481	tilgu	tilgu =tilgu  (IndPrPs_  >tilkuma !28_V	et	f	\N
210482	tilgu	tilgu =tilgu  (ImpPrSg2  >tilkuma !28_V	et	f	\N
210486	elektienergiat	?elektienergiat =elektienergia  (SgP  >elektienergia !01_S	et	f	\N
210487	elektienergiat	?elektienergiat =elektienergiat  (SgN  >elektienergiat !22_S	et	f	\N
210501	tulevikusest	?tulevikusest =tulevikuse  (SgEl  >tulevikus !11?09_S	et	f	\N
210502	tulevikusest	?tulevikusest =tulevikuses  (SgP  >tulevikusene !12_A	et	f	\N
210503	tulevikusest	?tulevikusest =ikuse  (SgEl  >tulev+ikus !09_S	et	f	\N
210504	tulevikusest	?tulevikusest =ikuses  (SgP  >tulev+ikusene !12_A	et	f	\N
210505	tulevikusest	?tulevikusest =vikuse  (SgEl  >tule+vikus !09_S	et	f	\N
210506	tulevikusest	?tulevikusest =vikuses  (SgP  >tule+vikusene !12_A	et	f	\N
210529	säästamine	?säästamine =säästamine  (SgN  >säästamine !12_S	et	f	\N
210530	säästamine	?säästamine =säästamine  (PlP  >säästamin !19_S	et	f	\N
210568	visatut	visatut =visatu  (SgP  >visatu !01_AS	et	f	\N
210569	visatut	"visatu %visa  )TU1_vS  <viskama ;29_V	et	f	\N
210586	säästa	säästa =sääst  (Inf  >säästma !34_V	et	f	\N
210587	säästa	säästa =säästa  (IndPrPs_  >säästma !34_V	et	f	\N
210588	säästa	säästa =säästa  (ImpPrSg2  >säästma !34_V	et	f	\N
210589	räägitskse	?räägitskse =räägitskse  (SgG  >räägitskne !02_A	et	f	\N
210620	pesutänavatel	pesutänavatel =ate  (PlAd  >pesu+tänav+att !22_S	et	f	\N
210621	pesutänavatel	pesutänavatel =vate  (PlAd  >pesu+täna+vatt !22_S	et	f	\N
210622	pesutänavatel	pesutänavatel =tänava  (PlAd  >pesu+tänav !02_A	et	f	\N
210623	pesutänavatel	pesutänavatel =tänava  (PlAd  >pesu+tänav !02_S	et	f	\N
210656	poletan	?poletan =poleta  (IndPrSg1  >poletama !27_V	et	f	\N
210657	poletan	?poletan =poletan  (SgN  >poletan !19_S	et	f	\N
210662	dussi	?dussi =dussi  (SgN  >dussi !16_S	et	f	\N
210663	dussi	?dussi =dussi  (SgG  >dussi !16_S	et	f	\N
210664	dussi	?dussi =dussi  (SgG  >duss !22_S	et	f	\N
210665	dussi	?dussi =dussi  (SgP  >duss !22_S	et	f	\N
210666	dussi	?dussi =dussi  (SgAdt  >duss !22_S	et	f	\N
210667	dussi	?dussi =dussi  (IndPrPs_  >dussima !28_V	et	f	\N
210668	dussi	?dussi =dussi  (ImpPrSg2  >dussima !28_V	et	f	\N
210681	haigestumised	haigestumised =haigestumise  (PlN  >haigestumine !12_S	et	f	\N
210682	haigestumised	"haigestumine %haigestu  )MINE_vS  <haigestuma ;27_V	et	f	\N
210686	elektrijaami	elektrijaami =jaami  (SgG  >elektri+jaam !22_S	et	f	\N
210688	elektrijaami	elektrijaami =jaami  (SgP  >elektri+jaam !22_S	et	f	\N
210690	elektrijaami	elektrijaami =jaami  (SgAdt  >elektri+jaam !22_S	et	f	\N
210727	töötleda	### töötleda	et	f	\N
210731	materjalli	?materjalli =materjalli  (SgG  >materjall !22_S	et	f	\N
210732	materjalli	?materjalli =materjalli  (SgP  >materjall !22_S	et	f	\N
210733	materjalli	?materjalli =materjalli  (SgAdt  >materjall !22_S	et	f	\N
210734	materjalli	?materjalli =materjalli  (IndPrPs_  >materjallima !28_V	et	f	\N
210735	materjalli	?materjalli =materjalli  (ImpPrSg2  >materjallima !28_V	et	f	\N
210745	kindlustanud	kindlustanud =kindlusta  (PtsPtPs  >kindlustama !27_V	et	f	\N
210746	kindlustanud	kindlustanud =kindlustanu  (PlN  >kindlustanu !01_S	et	f	\N
210748	kindlustanud	"kindlustanu %kindlusta  )NU_vS  <kindlustama ;27_V	et	f	\N
210750	kindlustanud	kindlustanud =kindlustanud  (ID  >kindlustanud !41_A	et	f	\N
210751	kindlustanud	"kindlustanud %kindlusta  )NUD_vA  <kindlustama ;27_V	et	f	\N
210752	kindlustanud	kindlustanud =tanu  (PlN  >kindlus+tanu !17_S	et	f	\N
210757	keskkonast	?keskkonast =keskkonas  (SgP  >keskkonane !12_A	et	f	\N
210758	keskkonast	?keskkonast =kona  (SgEl  >kesk+kona !17_S	et	f	\N
210759	keskkonast	?keskkonast =konas  (SgP  >kesk+konas !09_S	et	f	\N
210760	keskkonast	?keskkonast =konas  (SgP  >kesk+konane !10_A	et	f	\N
210795	harjamise	harjamise =harjamise  (SgG  >harjamine !12_S	et	f	\N
210796	harjamise	"harjamine %harja  )MINE_vS  <harjama ;29_V	et	f	\N
210801	jooksva	jooksva =jooksva  (SgN  >jooksva !01_S	et	f	\N
210802	jooksva	jooksva =jooksva  (SgG  >jooksva !01_S	et	f	\N
210803	jooksva	jooksva =jooksva  (SgG  >jooksev !02_A	et	f	\N
210804	jooksva	"jooksev %jooks  )V_vA  <jooksma ;32_V	et	f	\N
210805	pesemist	pesemist =pesemis  (SgP  >pesemine !12_S	et	f	\N
210806	pesemist	"pesemine %pese  )MINE_vS  <pesema ;36_V	et	f	\N
210815	vaska	?vaska =vaska  (SgN  >vaska !16_S	et	f	\N
210816	vaska	?vaska =vaska  (SgG  >vaska !16_S	et	f	\N
210817	vaska	?vaska =vaska  (IndPrPs_  >vaskama !29_V	et	f	\N
210818	vaska	?vaska =vaska  (ImpPrSg2  >vaskama !29_V	et	f	\N
210844	gaasi-	gaasi- =gaasi  (SgG  >gaas !22_S	et	f	\N
210845	gaasi-	gaasi- =gaasi  (SgP  >gaas !22_S	et	f	\N
210846	gaasi-	gaasi- =gaasi  (SgAdt  >gaas !22_S	et	f	\N
210853	päikese-	päikese- =päikese  (SgG  >päike !12?10_S	et	f	\N
210557	beziini	?beziini =beziini  (ImpPrSg2  >beziinima !28_V	et	f	\N
210561	vähenev	vähenev =vähene  (PtsPrPs  >vähenema !27_V	et	f	\N
210562	vähenev	vähenev =vähenev  (SgN  >vähenev !02_A	et	f	\N
210563	vähenev	"vähenev %vähene  )V_vA  <vähenema ;27_V	et	f	\N
210583	säästev	säästev =sääst  (PtsPrPs  >säästma !34_V	et	f	\N
210584	säästev	säästev =säästev  (SgN  >säästev !02_A	et	f	\N
210585	säästev	"säästev %sääst  )V_vA  <säästma ;34_V	et	f	\N
210590	arusaamatultvastu	?arusaamatultvastu =arusaamatultvastu  (IndPrPs_  >arusaamatultvastuma !27_V	et	f	\N
210591	arusaamatultvastu	?arusaamatultvastu =arusaamatultvastu  (ImpPrSg2  >arusaamatultvastuma !27_V	et	f	\N
210592	arusaamatultvastu	?arusaamatultvastu =tultvastu  (SgN  >aru+saama+tultvastu !01_S	et	f	\N
210593	arusaamatultvastu	?arusaamatultvastu =tultvastu  (SgG  >aru+saama+tultvastu !01_S	et	f	\N
210594	ümbrikud	ümbrikud =ümbriku  (PlN  >ümbrik !25_S	et	f	\N
210595	ümbrikud	ümbrikud =ümbriku  (PlN  >ümbrik !02_S	et	f	\N
210598	prakteeritakse	?prakteeritakse =prakteeri  (IndPrIps  >prakteerima !28_V	et	f	\N
210599	prakteeritakse	?prakteeritakse =prakteeritakse  (SgG  >prakteeritakne !02_A	et	f	\N
210600	prakteeritakse	?prakteeritakse =prakteeritakse  (PlP  >prakteeritaks !22_S	et	f	\N
210604	prüügi	?prüügi =prüügi  (SgN  >prüügi !16_S	et	f	\N
210605	prüügi	?prüügi =prüügi  (SgG  >prüügi !16_S	et	f	\N
210606	prüügi	?prüügi =prüügi  (SgG  >prüük !22_S	et	f	\N
210607	prüügi	?prüügi =prüügi  (SgP  >prüüg !22_S	et	f	\N
210608	prüügi	?prüügi =prüügi  (SgAdt  >prüüg !22_S	et	f	\N
210609	prüügi	?prüügi =prüügi  (IndPrPs_  >prüükima !28_V	et	f	\N
210610	prüügi	?prüügi =prüügi  (ImpPrSg2  >prüükima !28_V	et	f	\N
210611	prüügi	?prüügi =prüü  (SgN^  >prüü !26_S	et	f	\N
210612	prüügi	?prüügi =prüü  (SgG^  >prüü !26_S	et	f	\N
210628	okoloogia	?okoloogia =okoloogia  (SgN  >okoloogia !01_S	et	f	\N
210629	okoloogia	?okoloogia =okoloogia  (SgG  >okoloogia !01_S	et	f	\N
210635	tanapaeva	?tanapaeva =tanapaeva  (SgN  >tanapaeva !16_S	et	f	\N
210636	tanapaeva	?tanapaeva =tanapaeva  (SgG  >tanapaeva !16_S	et	f	\N
210646	okoelust	?okoelust =okoelu  (SgEl  >okoelu !17_S	et	f	\N
210647	okoelust	?okoelust =okoelus  (SgP  >okoelus !11_S	et	f	\N
210677	mattin	?mattin =mattin  (SgN  >mattin !02_S	et	f	\N
210678	votame	?votame =vota  (IndPrPl1  >votama !27_V	et	f	\N
210683	tööstusettevõteid	?tööstusettevõteid =tööstusettevõtei  (PlN  >tööstusettevõtei !26_S	et	f	\N
210684	tööstusettevõteid	?tööstusettevõteid =tööstusettevõtei  (SgP  >tööstusettevõtei !26_S	et	f	\N
210685	tööstusettevõteid	?tööstusettevõteid =võtei  (PlN  >tööstus+ette+võtei !26_S	et	f	\N
210687	tööstusettevõteid	?tööstusettevõteid =võtei  (SgP  >tööstus+ette+võtei !26_S	et	f	\N
210689	tööstusettevõteid	?tööstusettevõteid =võteid  (SgN  >tööstus+ette+võteid !22_S	et	f	\N
210691	tööstusettevõteid	?tööstusettevõteid =ettevõtei  (PlN  >tööstus+ettevõtei !26_S	et	f	\N
210692	tööstusettevõteid	?tööstusettevõteid =ettevõtei  (SgP  >tööstus+ettevõtei !26_S	et	f	\N
210693	tööstusettevõteid	?tööstusettevõteid =tusettevõtei  (PlN  >töös+tusettevõtei !26_S	et	f	\N
210694	tööstusettevõteid	?tööstusettevõteid =tusettevõtei  (SgP  >töös+tusettevõtei !26_S	et	f	\N
210695	tööstusettevõteid	?tööstusettevõteid =stusettevõtei  (PlN  >töö+stusettevõtei !26_S	et	f	\N
210696	tööstusettevõteid	?tööstusettevõteid =stusettevõtei  (SgP  >töö+stusettevõtei !26_S	et	f	\N
210706	globaalsem	globaalsem =globaalsem  (SgN  >globaalsem !02_A	et	f	\N
210707	globaalsem	"globaalsem %globaalse  )M_cA  <globaalne ;02_A	et	f	\N
210713	säästumise	?säästumise =säästumise  (SgG  >säästumine !12_S	et	f	\N
210728	heitgaasi	heitgaasi =gaasi  (SgG  >heit+gaas !22_S	et	f	\N
210729	heitgaasi	heitgaasi =gaasi  (SgP  >heit+gaas !22_S	et	f	\N
210730	heitgaasi	heitgaasi =gaasi  (SgAdt  >heit+gaas !22_S	et	f	\N
210739	energiaallikatel	energiaallikatel =ate  (PlAd  >energia+allik+att !22_S	et	f	\N
210740	energiaallikatel	energiaallikatel =allika  (PlAd  >energia+allikas !02_S	et	f	\N
210753	millestest	?millestest =milles  (PlEl  >milles !09_S	et	f	\N
210754	millestest	?millestest =milles  (PlEl  >millene !10_A	et	f	\N
210755	millestest	?millestest =millestes  (SgP  >millestene !12_A	et	f	\N
210756	millestest	?millestest =stest  (SgN  >mille+stest !22_S	et	f	\N
210761	taimeid	?taimeid =taime  (PlP  >taime !06_S	et	f	\N
210762	taimeid	?taimeid =taimei  (PlN  >taimei !26_S	et	f	\N
210763	taimeid	?taimeid =taimei  (SgP  >taimei !26_S	et	f	\N
210764	taimeid	?taimeid =taimeid  (SgN  >taimeid !22_S	et	f	\N
210765	taimeid	?taimeid =eid  (SgN  >taim+eid !22_S	et	f	\N
210766	taimeid	?taimeid =mei  (PlN  >tai+mei !26_S	et	f	\N
210767	taimeid	?taimeid =mei  (SgP  >tai+mei !26_S	et	f	\N
210768	taimeid	?taimeid =meid  (SgN  >tai+meid !22_S	et	f	\N
210777	aotosid	?aotosid =aoto  (PlP  >aoto !16_S	et	f	\N
210778	aotosid	?aotosid =tosi  (PlN  >ao+tosi !17_S	et	f	\N
210791	keskkonnasäästamine	?keskkonnasäästamine =keskkonnasäästamine  (SgN  >keskkonnasäästamine !12_S	et	f	\N
210792	keskkonnasäästamine	?keskkonnasäästamine =keskkonnasäästamine  (PlP  >keskkonnasäästamin !19_S	et	f	\N
210793	keskkonnasäästamine	?keskkonnasäästamine =säästamine  (SgN  >kesk+konna+säästamine !12_S	et	f	\N
210715	keskkona	?keskkona =kona  (SgN  >kesk+kona !17_S	et	f	\N
210716	keskkona	?keskkona =kona  (SgG  >kesk+kona !17_S	et	f	\N
210717	keskkona	?keskkona =kona  (SgP  >kesk+kona !17_S	et	f	\N
210718	kaillimaks	?kaillimaks =kailli  (SupTr  >kaillima !28_V	et	f	\N
210719	kaillimaks	?kaillimaks =kaillima  (SgTr  >kaillim !02_A	et	f	\N
210724	turvalisi	turvalisi =turvalisi  (PlP  >turvaline !12_A	et	f	\N
210725	turvalisi	"turvaline %turva  )LINE_aA  <turb ;22_SA	et	f	\N
210726	turvalisi	"turvaline %turva  )LINE_aA  <turv ;22_S	et	f	\N
210769	kustutatud	kustutatud =kustuta  (PtsPtIps  >kustutama !27_V	et	f	\N
210770	kustutatud	kustutatud =kustutatu  (PlN  >kustutatu !01_S	et	f	\N
210771	kustutatud	"kustutatu %kustuta  )TU1_vS  <kustutama ;27_V	et	f	\N
210772	kustutatud	kustutatud =kustutatud  (ID  >kustutatud !41_A	et	f	\N
210773	kustutatud	"kustutatud %kustuta  )TUD_vA  <kustutama ;27_V	et	f	\N
210785	reostamisega	reostamisega =reostamise  (SgKom  >reostamine !12_S	et	f	\N
210786	reostamisega	"reostamine %reosta  )MINE_vS  <reostama ;27_V	et	f	\N
210807	lõplikku	lõplikku =lõplikku  (SgP  >lõplik !25_A	et	f	\N
210808	lõplikku	lõplikku =lõplikku  (SgAdt  >lõplik !25_A	et	f	\N
210847	elektriauto	elektriauto =auto  (SgN  >elektri+auto !16_S	et	f	\N
210848	elektriauto	elektriauto =auto  (SgG  >elektri+auto !16_S	et	f	\N
210868	põletavamaid	põletavamaid =põletavama  (PlP  >põletavam !02_A	et	f	\N
210869	põletavamaid	"põletavam %põle  )TAVAM_cA  <põlema ;27_V	et	f	\N
210870	põletavamaid	"põletavam %põleta  )VAM_cA  <põletama ;27_V	et	f	\N
210871	põletavamaid	"põletavam %põletava  )M_cA  <põletav ;02_A	et	f	\N
210874	mahetooteid	mahetooteid =te  (PlP  >mahe+too+tee !26_S	et	f	\N
210875	mahetooteid	mahetooteid =toote  (PlP  >mahe+toode !06_S	et	f	\N
210888	suuteline	suuteline =suuteline  (SgN  >suuteline !12_A	et	f	\N
210889	suuteline	"suuteline %suute  )LINE_aA  <suude ;06_S	et	f	\N
210892	temaaju	temaaju =aju  (SgN  >tema+aju !17_S	et	f	\N
210894	temaaju	temaaju =aju  (SgG  >tema+aju !17_S	et	f	\N
210896	temaaju	temaaju =aju  (SgP  >tema+aju !17_S	et	f	\N
210907	eluolendik	?eluolendik =eluolendik  (SgN  >eluolendik !25_S	et	f	\N
210908	eluolendik	?eluolendik =olendik  (SgN  >elu+olendik !25_S	et	f	\N
210912	agressiivselt	agressiivselt =agressiivse  (SgAbl  >agressiivne !02_A	et	f	\N
210913	agressiivselt	agressiivselt =agressiivselt  (ID  >agressiivselt !41_D	et	f	\N
210914	agressiivselt	"agressiivselt %agressiivse  )LT_mD  <agressiivne ;02_A	et	f	\N
210921	pühadasteotav	?pühadasteotav =pühadasteota  (PtsPrPs  >pühadasteotama !27_V	et	f	\N
210922	pühadasteotav	?pühadasteotav =pühadasteotav  (SgN  >pühadasteotav !02_A	et	f	\N
210923	pühadasteotav	?pühadasteotav =dasteotav  (SgN  >püha+dasteotav !02_A	et	f	\N
210924	katastroofilise	katastroofilise =katastroofilise  (SgG  >katastroofiline !12_A	et	f	\N
210925	katastroofilise	"katastroofiline %katastroofi  )LINE_aA  <katastroof ;22_S	et	f	\N
210942	ekoloogiliselt	?ekoloogiliselt =ekoloogilise  (SgAbl  >ekoloogiline !12_A	et	f	\N
210943	ekoloogiliselt	?ekoloogiliselt =ekoloogiliselt  (ID  >ekoloogiliselt !41_D	et	f	\N
210950	röövellikult	röövellikult =röövelliku  (SgAbl  >röövellik !25_A	et	f	\N
210951	röövellikult	röövellikult =röövellikult  (ID  >röövellikult !41_D	et	f	\N
210952	röövellikult	"röövellikult %röövelliku  )LT_mD  <röövellik ;25_A	et	f	\N
210972	arutamine	arutamine =arutamine  (SgN  >arutamine !12_S	et	f	\N
210973	arutamine	"arutamine %aruta  )MINE_vS  <arutama ;27_V	et	f	\N
210978	ningei	?ningei =ningei  (SgN  >ningei !26_S	et	f	\N
210979	ningei	?ningei =ningei  (SgG  >ningei !26_S	et	f	\N
210980	ühistransporti	ühistransporti =transporti  (SgP  >ühis+transport !22_S	et	f	\N
210981	ühistransporti	ühistransporti =transporti  (SgAdt  >ühis+transport !22_S	et	f	\N
210991	viskavad	viskavad =viska  (IndPrPl3  >viskama !29_V	et	f	\N
210992	viskavad	viskavad =viskava  (PlN  >viskav !02_A	et	f	\N
210993	viskavad	"viskav %viska  )V_vA  <viskama ;29_V	et	f	\N
211035	sõidurõõmu	sõidurõõmu =rõõmu  (SgG  >sõidu+rõõm !22_S	et	f	\N
211036	sõidurõõmu	sõidurõõmu =rõõmu  (SgP  >sõidu+rõõm !22_S	et	f	\N
211037	sõidurõõmu	sõidurõõmu =rõõmu  (SgAdt  >sõidu+rõõm !22_S	et	f	\N
211040	httpwwwpostimeesee011004esilehtarvamus146156php	### httpwwwpostimeesee011004esilehtarvamus146156php	et	f	\N
211045	taastumatuid	taastumatuid =taastumatu  (PlP  >taastumatu !01_A	et	f	\N
211046	taastumatuid	"taastumatu %taastu  )MATU_vA  <taastuma ;27_V	et	f	\N
211057	mercedesid	### mercedesid	et	f	\N
211059	co2	### co2	et	f	\N
211068	olmeelu	olmeelu =elu  (SgN  >olme+elu !17_S	et	f	\N
211069	olmeelu	olmeelu =elu  (SgG  >olme+elu !17_S	et	f	\N
211070	olmeelu	olmeelu =elu  (SgP  >olme+elu !17_S	et	f	\N
211081	keskonnale	?keskonnale =keskonna  (SgAll  >keskonna !16_S	et	f	\N
211082	keskonnale	?keskonnale =keskonna  (SgAll  >keskond !22_S	et	f	\N
211083	keskonnale	?keskonnale =onna  (SgAll  >kesk+onna !16_S	et	f	\N
211092	kütesevaliku	?kütesevaliku =kütesevaliku  (SgG  >kütesevalik !25_A	et	f	\N
211093	kütesevaliku	?kütesevaliku =kütesevaliku  (IndPrPs_  >kütesevalikuma !27_V	et	f	\N
211094	kütesevaliku	?kütesevaliku =kütesevaliku  (ImpPrSg2  >kütesevalikuma !27_V	et	f	\N
211102	gaasiplitide	?gaasiplitide =pliti  (PlG  >gaasi+pliti !16_S	et	f	\N
210784	ökoloogilisest	"öko+loogiline %loogi  )LINE_aA  <öko+loog ;22_S	et	f	\N
210787	keskkonnateadlikkus	keskkonnateadlikkus =teadlikkus  (SgN  >kesk+konna+teadlikkus !11~09_S	et	f	\N
210788	keskkonnateadlikkus	"kesk+konna+teadlikkus %teadlikku  )US_aS  <kesk+konna+teadlik ;25_A	et	f	\N
210824	tarapunkti	?tarapunkti =tarapunkti  (IndPrPs_  >tarapunktima !28_V	et	f	\N
210825	tarapunkti	?tarapunkti =tarapunkti  (ImpPrSg2  >tarapunktima !28_V	et	f	\N
210826	kultuuritasendist	?kultuuritasendist =kultuuritasendi  (SgEl  >kultuuritasent !22_S	et	f	\N
210827	kultuuritasendist	?kultuuritasendist =kultuuritasendis  (SgP  >kultuuritasendis !09_S	et	f	\N
210828	kultuuritasendist	?kultuuritasendist =kultuuritasendist  (SgN  >kultuuritasendist !22_S	et	f	\N
210829	kultuuritasendist	?kultuuritasendist =tasendi  (SgEl  >kultuuri+tasendi !01_S	et	f	\N
210830	kultuuritasendist	?kultuuritasendist =tasendi  (SgEl  >kultuuri+tasend !02_S	et	f	\N
210831	kultuuritasendist	?kultuuritasendist =tasendi  (SgEl  >kultuuri+tasent !22_S	et	f	\N
210832	kultuuritasendist	?kultuuritasendist =tasendis  (SgP  >kultuuri+tasendis !11_S	et	f	\N
210833	kultuuritasendist	?kultuuritasendist =tasendist  (SgN  >kultuuri+tasendist !22_S	et	f	\N
210834	kultuuritasendist	?kultuuritasendist =itasendi  (SgEl  >kultuur+itasent !22_S	et	f	\N
210835	kultuuritasendist	?kultuuritasendist =itasendis  (SgP  >kultuur+itasendis !09_S	et	f	\N
210836	kultuuritasendist	?kultuuritasendist =itasendist  (SgN  >kultuur+itasendist !22_S	et	f	\N
210851	taastuvaid	taastuvaid =taastuva  (PlP  >taastuv !02_A	et	f	\N
210852	taastuvaid	"taastuv %taastu  )V_vA  <taastuma ;27_V	et	f	\N
210904	proklameerides	?proklameerides =proklameeri  (PlIn  >proklameeri !16_S	et	f	\N
210905	proklameerides	?proklameerides =proklameeri  (PlIn  >proklameer !22_S	et	f	\N
210906	proklameerides	?proklameerides =proklameeri  (Ger  >proklameerima !28_V	et	f	\N
210926	vähenemisi	vähenemisi =vähenemisi  (PlP  >vähenemine !12_S	et	f	\N
210927	vähenemisi	"vähenemine %vähene  )MINE_vS  <vähenema ;27_V	et	f	\N
210939	sudu	sudu =sudu  (SgN  >sudu !17_S	et	f	\N
210940	sudu	sudu =sudu  (SgG  >sudu !17_S	et	f	\N
210941	sudu	sudu =sudu  (SgP  >sudu !17_S	et	f	\N
210953	maavaraseid	maavaraseid =varase  (PlP  >maa+varane !10_A	et	f	\N
210954	maavaraseid	"maa+varane %vara  )NE_aA  <maa+vara ;17_S	et	f	\N
210984	eestimaised	eestimaised =maise  (PlN  >eesti+maine !10_A	et	f	\N
210985	eestimaised	"eesti+maine %mai  )NE_aA  <eesti+maa ;26_S	et	f	\N
211008	eastimaine	?eastimaine =eastimaine  (SgN  >eastimaine !16_S	et	f	\N
211009	eastimaine	?eastimaine =eastimaine  (SgG  >eastimaine !16_S	et	f	\N
211010	eastimaine	?eastimaine =eastimaine  (PlP  >eastimain !19_S	et	f	\N
211011	eastimaine	?eastimaine =stimaine  (SgN  >ea+stimaine !12~10_A	et	f	\N
211012	eastimaine	?eastimaine =stimaine  (PlP  >ea+stimain !22_S	et	f	\N
211019	õnnist	õnnist =õnni  (SgEl  >õnn !22_S	et	f	\N
211020	õnnist	õnnist =õnni  (PlEl  >õnn !22_S	et	f	\N
211021	õnnist	õnnist =õnnis  (SgP  >õnnis !05_A	et	f	\N
211031	lösutava	lösutava =lösutava  (SgG  >lösutav !02_A	et	f	\N
211032	lösutava	"lösutav %lösuta  )V_vA  <lösutama ;27_V	et	f	\N
211047	rast	?rast =rast  (SgN  >rast !22_S	et	f	\N
211048	tootmisel	tootmisel =tootmise  (SgAd  >tootmine !12?10_S	et	f	\N
211049	tootmisel	"tootmine %toot  )MINE_vS  <tootma ;34_V	et	f	\N
211071	harjumuseks	harjumuseks =harjumuse  (SgTr  >harjumus !11_S	et	f	\N
211072	harjumuseks	"harjumus %harju  )MUS_vS  <harjuma ;27_V	et	f	\N
211075	prügiämbressevaid	?prügiämbressevaid =prügiämbresseva  (PlP  >prügiämbressev !02_A	et	f	\N
211076	prügiämbressevaid	?prügiämbressevaid =prügiämbressevai  (PlN  >prügiämbressevai !26_S	et	f	\N
211077	prügiämbressevaid	?prügiämbressevaid =prügiämbressevai  (SgP  >prügiämbressevai !26_S	et	f	\N
211078	prügiämbressevaid	?prügiämbressevaid =ämbresseva  (PlP  >prügi+ämbressev !02_A	et	f	\N
211079	prügiämbressevaid	?prügiämbressevaid =ämbressevai  (PlN  >prügi+ämbressevai !26_S	et	f	\N
211080	prügiämbressevaid	?prügiämbressevaid =ämbressevai  (SgP  >prügi+ämbressevai !26_S	et	f	\N
211086	langune	langune =langune  (SgN  >langune !10_A	et	f	\N
211087	langune	"langune %langu  )NE_aA  <lang ;22_S	et	f	\N
211095	ökosüsteemi	ökosüsteemi =süsteemi  (SgG  >öko+süsteem !22_S	et	f	\N
211096	ökosüsteemi	ökosüsteemi =süsteemi  (SgP  >öko+süsteem !22_S	et	f	\N
211097	ökosüsteemi	ökosüsteemi =süsteemi  (SgAdt  >öko+süsteem !22_S	et	f	\N
211105	prügilasse	prügilasse =la  (SgIll  >prügi+la !26_S	et	f	\N
211106	prügilasse	prügilasse =lasse  (PlP  >prügi+lass !22_S	et	f	\N
211115	keskonnasäästliku	?keskonnasäästliku =keskonnasäästliku  (SgG  >keskonnasäästlik !25_A	et	f	\N
211116	keskonnasäästliku	?keskonnasäästliku =keskonnasäästliku  (IndPrPs_  >keskonnasäästlikuma !27_V	et	f	\N
211117	keskonnasäästliku	?keskonnasäästliku =keskonnasäästliku  (ImpPrSg2  >keskonnasäästlikuma !27_V	et	f	\N
211118	keskonnasäästliku	?keskonnasäästliku =onnasäästliku  (SgG  >kesk+onnasäästlik !25_A	et	f	\N
211130	päaev	?päaev =päaev  (SgN  >päaev !02_S	et	f	\N
211141	alateadlikult	alateadlikult =teadliku  (SgAbl  >ala+teadlik !25_A	et	f	\N
211142	alateadlikult	"ala+teadlikult %teadliku  )LT_mD  <ala+teadlik ;25_A	et	f	\N
211160	statusega	?statusega =statuse  (SgKom  >status !09_S	et	f	\N
211166	geenimuudetuid	?geenimuudetuid =geenimuudetu  (PlP  >geenimuudetu !01_A	et	f	\N
210790	veendumusel	"veendumus %veendu  )MUS_vS  <veenduma ;27_V	et	f	\N
210799	väldi	väldi =väldi  (IndPrPs_  >vältima !28_V	et	f	\N
210800	väldi	väldi =väldi  (ImpPrSg2  >vältima !28_V	et	f	\N
210809	valmimist	valmimist =valmimi  (SgEl  >valmim !02_A	et	f	\N
210810	valmimist	"valmim %valmi  )M_cA  <valmis ;02_A	et	f	\N
210811	valmimist	valmimist =valmimis  (SgP  >valmimine !12_S	et	f	\N
210812	valmimist	"valmimine %valmi  )MINE_vS  <valmima ;27_V	et	f	\N
210823	lähedel	### lähedel	et	f	\N
210837	kütusekulutust	kütusekulutust =tust  (SgN  >kütuse+kulu+tust !22_S	et	f	\N
210838	kütusekulutust	kütusekulutust =kulutu  (SgEl  >kütuse+kulutu !01_AS	et	f	\N
210839	kütusekulutust	"kütuse+kulutu %kulu  )TU2_kA  <kütuse+kulu ;17_S	et	f	\N
210840	kütusekulutust	"kütuse+kulutu %kulu  )TU2_kA  <kütuse+kulg ;22_S	et	f	\N
210841	kütusekulutust	kütusekulutust =kulutus  (SgP  >kütuse+kulutus !11_S	et	f	\N
210842	kütusekulutust	"kütuse+kulutus %kulu  )TUS2_aS  <kütuse+kulu ;17_S	et	f	\N
210843	kütusekulutust	"kütuse+kulutus %kulu  )TUS2_aS  <kütuse+kulg ;22_S	et	f	\N
210855	geotermaalenenergia	?geotermaalenenergia =geotermaalenenergia  (SgN  >geotermaalenenergia !01_S	et	f	\N
210856	geotermaalenenergia	?geotermaalenenergia =geotermaalenenergia  (SgG  >geotermaalenenergia !01_S	et	f	\N
210857	geotermaalenenergia	?geotermaalenenergia =termaalenenergia  (SgN  >geo+termaalenenergia !01_S	et	f	\N
210858	geotermaalenenergia	?geotermaalenenergia =termaalenenergia  (SgG  >geo+termaalenenergia !01_S	et	f	\N
210859	ratifitseerivad	ratifitseerivad =ratifitseeri  (IndPrPl3  >ratifitseerima !28_V	et	f	\N
210860	ratifitseerivad	ratifitseerivad =ratifitseeriva  (PlN  >ratifitseeriv !02_A	et	f	\N
210861	ratifitseerivad	"ratifitseeriv %ratifitseeri  )V_vA  <ratifitseerima ;28_V	et	f	\N
210876	sisseostmeid	?sisseostmeid =sisseostmei  (PlN  >sisseostmei !26_S	et	f	\N
210877	sisseostmeid	?sisseostmeid =sisseostmei  (SgP  >sisseostmei !26_S	et	f	\N
210878	sisseostmeid	?sisseostmeid =ostme  (PlP  >sisse+ostmi !01_S	et	f	\N
210879	sisseostmeid	?sisseostmeid =ostme  (PlP  >sisse+ostme !06_S	et	f	\N
210880	sisseostmeid	?sisseostmeid =ostmei  (PlN  >sisse+ostmei !26_S	et	f	\N
210882	sisseostmeid	?sisseostmeid =ostmei  (SgP  >sisse+ostmei !26_S	et	f	\N
210883	sisseostmeid	?sisseostmeid =ostmeid  (SgN  >sisse+ostmeid !22_S	et	f	\N
210901	hõimugeda	?hõimugeda =geda  (SgN  >hõimu+geda !17_S	et	f	\N
210902	hõimugeda	?hõimugeda =geda  (SgG  >hõimu+geda !17_S	et	f	\N
210903	hõimugeda	?hõimugeda =geda  (SgP  >hõimu+geda !17_S	et	f	\N
210935	miljonide	### miljonide	et	f	\N
210962	õmbritsevad	?õmbritsevad =õmbritse  (IndPrPl3  >õmbritsema !27_V	et	f	\N
210963	õmbritsevad	?õmbritsevad =õmbritseva  (PlN  >õmbritsev !02_A	et	f	\N
210964	õmbritsevad	?õmbritsevad =õmbritseva  (PlN  >õmbritseva !16_S	et	f	\N
210974	elureeglitest	elureeglitest =test  (SgN  >elu+reegli+test !22_S	et	f	\N
210975	elureeglitest	elureeglitest =reegli  (PlEl  >elu+reegel !02_S	et	f	\N
210986	elekroenergiat	?elekroenergiat =elekroenergia  (SgP  >elekroenergia !01_S	et	f	\N
210987	elekroenergiat	?elekroenergiat =elekroenergiat  (SgN  >elekroenergiat !22_S	et	f	\N
210988	globalne	?globalne =globalne  (SgN  >globalne !02_A	et	f	\N
210989	globalne	?globalne =globalne  (PlP  >globaln !22_S	et	f	\N
210994	lehekest	lehekest =lehekes  (SgP  >leheke !12_S	et	f	\N
210995	lehekest	"leheke %lehe  )KE_dS  <leht ;22_S	et	f	\N
210996	lehekest	lehekest =lehekes  (SgP  >lehekene !12_S	et	f	\N
210997	lehekest	"lehekene %lehe  )KENE_dS  <leht ;22_S	et	f	\N
210998	lehekest	lehekest =kest  (SgN  >lehe+kest !22_S	et	f	\N
211013	sisalda	sisalda =sisalda  (IndPrPs_  >sisaldama !27_V	et	f	\N
211014	sisalda	sisalda =sisalda  (ImpPrSg2  >sisaldama !27_V	et	f	\N
211015	proobleem	?proobleem =proobleem  (SgN  >proobleem !22_S	et	f	\N
211022	määri	määri =määri  (SgG  >määr !22_S	et	f	\N
211023	määri	määri =määri  (SgP  >määr !22_S	et	f	\N
211024	määri	määri =määri  (SgAdt  >määr !22_S	et	f	\N
211025	määri	määri =määri  (PlP  >määr !22_S	et	f	\N
211026	määri	määri =määri  (IndPrPs_  >määrima !28_V	et	f	\N
211027	määri	määri =määri  (ImpPrSg2  >määrima !28_V	et	f	\N
211028	haisu	haisu =haisu  (SgG  >hais !22_S	et	f	\N
211029	haisu	haisu =haisu  (SgP  >hais !22_S	et	f	\N
211030	haisu	haisu =haisu  (SgAdt  >hais !22_S	et	f	\N
211033	asotsiaalide	?asotsiaalide =asotsiaali  (PlG  >asotsiaali !16_S	et	f	\N
211034	asotsiaalide	?asotsiaalide =asotsiaali  (PlG  >asotsiaal !22_S	et	f	\N
211073	sorteeriminepudeleid	?sorteeriminepudeleid =sorteeriminepudelei  (PlN  >sorteeriminepudelei !26_S	et	f	\N
211074	sorteeriminepudeleid	?sorteeriminepudeleid =sorteeriminepudelei  (SgP  >sorteeriminepudelei !26_S	et	f	\N
211088	vedelema	vedelema =vedele  (Sup  >vedelema !31~27_V	et	f	\N
211089	vedelema	vedelema =ema  (SgN  >vedel+ema !17_S	et	f	\N
211090	vedelema	vedelema =ema  (SgG  >vedel+ema !17_S	et	f	\N
211091	vedelema	vedelema =ema  (SgP  >vedel+ema !17_S	et	f	\N
211103	lihsalt	?lihsalt =lihsa  (SgAbl  >lihsa !16_S	et	f	\N
211104	lihsalt	?lihsalt =lihsalt  (ID  >lihsalt !41_D	et	f	\N
211109	huuviga	?huuviga =huuvi  (SgKom  >huuvi !16_S	et	f	\N
211110	huuviga	?huuviga =huuvi  (SgKom  >huuv !22_S	et	f	\N
211119	tulevas	tulevas =tuleva  (SgIn  >tulev !02_A	et	f	\N
211120	tulevas	"tulev %tule  )V_vA  <tulema ;36_V	et	f	\N
210794	keskkonnasäästamine	?keskkonnasäästamine =säästamine  (PlP  >kesk+konna+säästamin !19_S	et	f	\N
210797	pesemisel	pesemisel =pesemise  (SgAd  >pesemine !12_S	et	f	\N
210798	pesemisel	"pesemine %pese  )MINE_vS  <pesema ;36_V	et	f	\N
210813	pakkides	pakkides =pakki  (PlIn  >pakk !22_S	et	f	\N
210814	pakkides	pakkides =pakki  (Ger  >pakkima !28_V	et	f	\N
210819	ambrisse	?ambrisse =ambri  (SgIll  >ambri !01_S	et	f	\N
210820	ambrisse	?ambrisse =ambri  (SgIll  >amber !02_S	et	f	\N
210821	ambrisse	?ambrisse =ambrisse  (SgG  >ambrisne !02_A	et	f	\N
210822	ambrisse	?ambrisse =ambrisse  (PlP  >ambriss !22_S	et	f	\N
210849	aktuaalsem	aktuaalsem =aktuaalsem  (SgN  >aktuaalsem !02_A	et	f	\N
210850	aktuaalsem	"aktuaalsem %aktuaalse  )M_cA  <aktuaalne ;02_A	et	f	\N
210881	tehets	?tehets =tehets  (SgN  >tehets !02_S	et	f	\N
210893	täiustus	täiustus =täiustu  (IndIpfSg3  >täiustuma !27_V	et	f	\N
210895	täiustus	täiustus =täiustus  (SgN  >täiustus !11_S	et	f	\N
210897	täiustus	"täiustus %täiusta  )US_vS  <täiustama ;27_V	et	f	\N
210898	täiustus	täiustus =ustu  (SgIn  >täi+ustu !01_S	et	f	\N
210928	hukutamisi	hukutamisi =hukutamisi  (PlP  >hukutamine !12_S	et	f	\N
210929	hukutamisi	"hukutamine %hukuta  )MINE_vS  <hukutama ;27_V	et	f	\N
210930	suppelda	?suppelda =suppelda  (IndPrPs_  >suppeldama !27_V	et	f	\N
210931	suppelda	?suppelda =suppelda  (ImpPrSg2  >suppeldama !27_V	et	f	\N
210932	mürgistavad	mürgistavad =mürgista  (IndPrPl3  >mürgistama !27_V	et	f	\N
210933	mürgistavad	mürgistavad =mürgistava  (PlN  >mürgistav !02_A	et	f	\N
210934	mürgistavad	"mürgistav %mürgista  )V_vA  <mürgistama ;27_V	et	f	\N
210944	tsivilsatsioon	?tsivilsatsioon =tsivilsatsioon  (SgN  >tsivilsatsioon !22_S	et	f	\N
210955	iigsuses	?iigsuses =iigsuse  (SgIn  >iigsus !11~09_S	et	f	\N
210959	varamuses	?varamuses =varamuse  (SgIn  >varamus !11_S	et	f	\N
210960	varamuses	?varamuses =muse  (SgIn  >vara+muse !16_S	et	f	\N
210961	varamuses	?varamuses =muses  (SgN  >vara+muses !09_S	et	f	\N
210965	õppitavad	?õppitavad =õppita  (IndPrPl3  >õppitama !27_V	et	f	\N
210966	õppitavad	?õppitavad =õppitava  (PlN  >õppitav !02_A	et	f	\N
210967	õppitavad	?õppitavad =õppitava  (PlN  >õppitava !16_S	et	f	\N
210968	taimedest	taimedest =taime  (PlEl  >taim !22_S	et	f	\N
210969	taimedest	taimedest =ede  (SgEl  >taim+ede !16_S	et	f	\N
210970	taimedest	taimedest =edes  (SgP  >taim+edene !10_A	et	f	\N
210971	taimedest	"taim+edene %ede  )NE_aA  <taim+ede ;16_S	et	f	\N
210976	raiu	raiu =raiu  (IndPrPs_  >raiuma !28_V	et	f	\N
210977	raiu	raiu =raiu  (ImpPrSg2  >raiuma !28_V	et	f	\N
211016	loomavaguniga	loomavaguniga =iga  (SgN  >looma+vagun+iga !18_S	et	f	\N
211017	loomavaguniga	loomavaguniga =iga  (SgP  >looma+vagun+iga !18_S	et	f	\N
211018	loomavaguniga	loomavaguniga =vaguni  (SgKom  >looma+vagun !02_S	et	f	\N
211041	kasutasa	?kasutasa =kasutasa  (SgN  >kasutasa !16_S	et	f	\N
211042	kasutasa	?kasutasa =kasutasa  (SgG  >kasutasa !16_S	et	f	\N
211043	kasutasa	?kasutasa =utasa  (SgN  >kas+utasa !01_S	et	f	\N
211044	kasutasa	?kasutasa =utasa  (SgG  >kas+utasa !01_S	et	f	\N
211052	saatama	?saatama =saata  (Sup  >saatama !27_V	et	f	\N
211053	saatama	?saatama =saatama  (SgG  >saatam !02_A	et	f	\N
211054	saatama	?saatama =ama  (SgN  >saat+ama !17_S	et	f	\N
211055	saatama	?saatama =ama  (SgG  >saat+ama !17_S	et	f	\N
211056	saatama	?saatama =ama  (SgP  >saat+ama !17_S	et	f	\N
211058	math	?math =math  (SgN  >math !22_S	et	f	\N
211060	gkm	### gkm	et	f	\N
211064	keskonnasäästlikule	?keskonnasäästlikule =keskonnasäästliku  (SgAll  >keskonnasäästlik !25_A	et	f	\N
211065	keskonnasäästlikule	?keskonnasäästlikule =keskonnasäästlikule  (PlP  >keskonnasäästlikul !19_S	et	f	\N
211066	keskonnasäästlikule	?keskonnasäästlikule =onnasäästliku  (SgAll  >kesk+onnasäästlik !25_A	et	f	\N
211067	keskonnasäästlikule	?keskonnasäästlikule =onnasäästlikule  (PlP  >kesk+onnasäästlikul !19_S	et	f	\N
211084	erandtean	?erandtean =erandtean  (SgN  >erandtean !19_S	et	f	\N
211085	erandtean	?erandtean =tean  (SgN  >erand+tean !22_S	et	f	\N
211107	viiakuid	?viiakuid =viiakui  (PlN  >viiakui !26_S	et	f	\N
211108	viiakuid	?viiakuid =viiakui  (SgP  >viiakui !26_S	et	f	\N
211124	keskonnakaitse	?keskonnakaitse =keskonnakaitse  (SgG  >keskonnakaitne !02_A	et	f	\N
211125	keskonnakaitse	?keskonnakaitse =keskonnakaitse  (PlP  >keskonnakaits !22_S	et	f	\N
211126	keskonnakaitse	?keskonnakaitse =keskonnakaitse  (IndPrPs_  >keskonnakaitsema !27_V	et	f	\N
211127	keskonnakaitse	?keskonnakaitse =keskonnakaitse  (ImpPrSg2  >keskonnakaitsema !27_V	et	f	\N
211128	keskonnakaitse	?keskonnakaitse =onnakaitse  (SgG  >kesk+onnakaitne !02_A	et	f	\N
211129	keskonnakaitse	?keskonnakaitse =onnakaitse  (PlP  >kesk+onnakaits !22_S	et	f	\N
211147	inimlaiskus	inimlaiskus =laiskus  (SgN  >inim+laiskus !11~09_S	et	f	\N
211149	inimlaiskus	"inim+laiskus %laisk  )US_aS  <inim+laisk ;22_A	et	f	\N
211153	vajutama	vajutama =vaju  (SupIps  >vajuma !27_V	et	f	\N
211154	vajutama	vajutama =vajuta  (Sup  >vajutama !27_V	et	f	\N
211157	puhtust	puhtust =puhtus  (SgP  >puhtus !11~09_S	et	f	\N
211158	puhtust	"puhtus %puhta  )US_aS  <puhas ;07_A	et	f	\N
211159	puhtust	puhtust =us  (SgP  >puht+uks !14_S	et	f	\N
211205	katastroofiks	katastroofiks =katastroofi  (SgTr  >katastroof !22_S	et	f	\N
210854	päikese-	päikese- =päikese  (SgG  >päikene !12?10_S	et	f	\N
210862	rahvusvaheliseid	?rahvusvaheliseid =rahvusvahelisei  (PlN  >rahvusvahelisei !26_S	et	f	\N
210863	rahvusvaheliseid	?rahvusvaheliseid =rahvusvahelisei  (SgP  >rahvusvahelisei !26_S	et	f	\N
210864	rahvusvaheliseid	?rahvusvaheliseid =vahelisei  (PlN  >rahvus+vahelisei !26_S	et	f	\N
210865	rahvusvaheliseid	?rahvusvaheliseid =vahelisei  (SgP  >rahvus+vahelisei !26_S	et	f	\N
210866	rahvusvaheliseid	?rahvusvaheliseid =svahelisei  (PlN  >rahvu+svahelisei !26_S	et	f	\N
210867	rahvusvaheliseid	?rahvusvaheliseid =svahelisei  (SgP  >rahvu+svahelisei !26_S	et	f	\N
210872	hapevihmad	?hapevihmad =hapevihma  (PlN  >hapevihma !16_S	et	f	\N
210873	mitmekesisuse	?mitmekesisuse =mitmekesisuse  (SgG  >mitmekesisus !11?09_S	et	f	\N
210884	terviselesõbralikud	?terviselesõbralikud =terviselesõbraliku  (PlN  >terviselesõbralik !25_A	et	f	\N
210885	terviselesõbralikud	?terviselesõbralikud =terviselesõbraliku  (IndPrSg2  >terviselesõbralikuma !27_V	et	f	\N
210886	terviselesõbralikud	?terviselesõbralikud =lesõbraliku  (PlN  >tervise+lesõbralik !25_A	et	f	\N
210887	terviselesõbralikud	?terviselesõbralikud =elesõbraliku  (PlN  >tervis+elesõbralik !25_A	et	f	\N
210890	lahendamise	lahendamise =lahendamise  (SgG  >lahendamine !12_S	et	f	\N
210891	lahendamise	"lahendamine %lahenda  )MINE_vS  <lahendama ;27_V	et	f	\N
210899	eiste	eiste =eiste  (SgN  >eiste !06_S	et	f	\N
210900	eiste	eiste =eiste  (SgG  >eiste !06_S	et	f	\N
210909	krooniks	krooniks =krooni  (SgTr  >kroon !22_S	et	f	\N
210910	krooniks	krooniks =krooni  (KndPrPs  >kroonima !28_V	et	f	\N
210911	krooniks	krooniks =iks  (SgN  >kroon+iks !22_S	et	f	\N
210915	kahjulikult	kahjulikult =kahjuliku  (SgAbl  >kahjulik !25_A	et	f	\N
210916	kahjulikult	kahjulikult =kahjulikult  (ID  >kahjulikult !41_D	et	f	\N
210917	kahjulikult	"kahjulikult %kahjuliku  )LT_mD  <kahjulik ;25_A	et	f	\N
210918	kasutuslik	?kasutuslik =kasutuslik  (SgN  >kasutuslik !25_A	et	f	\N
210919	kasutuslik	?kasutuslik =tuslik  (SgN  >kasu+tuslik !25_A	et	f	\N
210920	kasutuslik	?kasutuslik =utuslik  (SgN  >kas+utuslik !25_A	et	f	\N
210936	gassid	?gassid =gassi  (PlN  >gassi !16_S	et	f	\N
210937	gassid	?gassid =gassi  (PlN  >gass !22_S	et	f	\N
210938	gassid	?gassid =gassi  (IndPrSg2  >gassima !28_V	et	f	\N
210945	lõhestatud	lõhestatud =lõhesta  (PtsPtIps  >lõhestama !27_V	et	f	\N
210946	lõhestatud	lõhestatud =lõhestatu  (PlN  >lõhestatu !01_S	et	f	\N
210947	lõhestatud	"lõhestatu %lõhesta  )TU1_vS  <lõhestama ;27_V	et	f	\N
210948	lõhestatud	lõhestatud =lõhestatud  (ID  >lõhestatud !41_A	et	f	\N
210949	lõhestatud	"lõhestatud %lõhesta  )TUD_vA  <lõhestama ;27_V	et	f	\N
210956	rahvatarkuseid	rahvatarkuseid =tarkuse  (PlP  >rahva+tarkus !09_S	et	f	\N
210957	rahvatarkuseid	"rahva+tarkus %tark  )US_aS  <rahva+tark ;22_AS	et	f	\N
210958	rahvatarkuseid	rahvatarkuseid =tarkuse  (PlP  >rahva+tarkune !10_A	et	f	\N
210982	tatlustootteis	?tatlustootteis =tatlustoottei  (SgIn  >tatlustoottei !26_S	et	f	\N
210983	tatlustootteis	?tatlustootteis =tatlustootteis  (SgN  >tatlustootteis !22_S	et	f	\N
210990	indiviidumid	?indiviidumid =indiviidumi  (PlN  >indiviidum !02_A	et	f	\N
210999	raklaami	?raklaami =raklaami  (SgN  >raklaami !16_S	et	f	\N
211000	raklaami	?raklaami =raklaami  (SgG  >raklaami !16_S	et	f	\N
211001	raklaami	?raklaami =raklaami  (SgG  >raklaam !22_S	et	f	\N
211002	raklaami	?raklaami =raklaami  (SgP  >raklaam !22_S	et	f	\N
211003	raklaami	?raklaami =raklaami  (SgAdt  >raklaam !22_S	et	f	\N
211004	raklaami	?raklaami =raklaami  (IndPrPs_  >raklaamima !28_V	et	f	\N
211005	raklaami	?raklaami =raklaami  (ImpPrSg2  >raklaamima !28_V	et	f	\N
211006	paksuks	paksuks =paksu  (SgTr  >paks !22_AS	et	f	\N
211007	paksuks	paksuks =uks  (SgN  >paks+uks !14_S	et	f	\N
211038	kuseloiku	kuseloiku =loiku  (SgP  >kuse+loik !22_S	et	f	\N
211039	kuseloiku	kuseloiku =loiku  (SgAdt  >kuse+loik !22_S	et	f	\N
211050	energiaallikas	energiaallikas =allika  (SgIn  >energia+allikas !02_S	et	f	\N
211051	energiaallikas	energiaallikas =allikas  (SgN  >energia+allikas !02_S	et	f	\N
211061	rohkemja	?rohkemja =rohkemja  (SgN  >rohkemja !01_S	et	f	\N
211062	rohkemja	?rohkemja =rohkemja  (SgG  >rohkemja !01_S	et	f	\N
211063	rohkemja	?rohkemja =rohkemja  (SgG  >rohkemjas !02_A	et	f	\N
211098	rahakottiloodan	?rahakottiloodan =rahakottiloodan  (SgN  >rahakottiloodan !02_S	et	f	\N
211099	rahakottiloodan	?rahakottiloodan =iloodan  (SgN  >raha+kott+iloodan !02_S	et	f	\N
211100	rahakottiloodan	?rahakottiloodan =kottiloodan  (SgN  >raha+kottiloodan !02_S	et	f	\N
211101	külmkapide	?külmkapide =kapi  (PlG  >külm+kapi !16_S	et	f	\N
211111	ainedmis	?ainedmis =ainedmi  (SgIn  >ainedmi !01_S	et	f	\N
211112	ainedmis	?ainedmis =ainedmi  (SgIn  >ainedm !22_S	et	f	\N
211113	ainedmis	?ainedmis =ainedmi  (IndIpfSg3  >ainedmima !28_V	et	f	\N
211114	ainedmis	?ainedmis =ainedmis  (SgN  >ainedmis !11_S	et	f	\N
211131	propageerimine	propageerimine =propageerimine  (SgN  >propageerimine !12_S	et	f	\N
211132	propageerimine	"propageerimine %propageeri  )MINE_vS  <propageerima ;28_V	et	f	\N
211137	hävitavad	hävitavad =hävita  (IndPrPl3  >hävitama !27_V	et	f	\N
211138	hävitavad	hävitavad =hävitava  (PlN  >hävitav !02_A	et	f	\N
211139	hävitavad	"hävitav %hävi  )TAV_vAS  <hävima ;27_V	et	f	\N
211140	hävitavad	"hävitav %hävita  )V_vA  <hävitama ;27_V	et	f	\N
211165	ramatuses	?ramatuses =ramatuse  (SgIn  >ramatus !11_S	et	f	\N
211121	erialagaet	?erialagaet =erialagaet  (SgN  >erialagaet !22_S	et	f	\N
211122	erialagaet	?erialagaet =gaet  (SgN  >eri+ala+gaet !22_S	et	f	\N
211123	erialagaet	?erialagaet =alagaet  (SgN  >eri+alagaet !22_S	et	f	\N
211133	teadvusi	teadvusi =teadvusi  (PlP  >teadvus !11_S	et	f	\N
211134	teadvusi	"teadvus %tead  )VUS_aS  <teadma ;34_V	et	f	\N
211135	teadvusi	"teadvus %teadva  )US_aS  <teadev ;02_A	et	f	\N
211136	planedil	?planedil =planedi  (SgAd  >planedi !01_S	et	f	\N
211151	läbimurre	läbimurre =murre  (SgN  >läbi+murre !05_S	et	f	\N
211152	läbimurre	läbimurre =murre  (SgN  >läbi+murre !06_S	et	f	\N
211161	ajamata	ajamata =aja  (SupAb  >ajama !27_V	et	f	\N
211162	ajamata	ajamata =ajama  (SgAb  >ajam !02_S	et	f	\N
211163	ajamata	ajamata =ajamata  (ID  >ajamata !41_A	et	f	\N
211164	ajamata	"ajamata %aja  )MATA_vA  <ajama ;27_V	et	f	\N
211176	täielikkult	?täielikkult =täielikkult  (ID  >täielikkult !41_D	et	f	\N
211177	täielikkult	?täielikkult =elikku  (SgAbl  >täi+elikku !01_S	et	f	\N
211199	päevatega	### päevatega	et	f	\N
211207	mõtega	### mõtega	et	f	\N
211208	2misugused	?misugused =misuguse  (PlN  >misugus !11_S	et	f	\N
211209	2misugused	?misugused =uguse  (PlN  >mis+ugus !02_A	et	f	\N
211259	huvijad	?huvijad =huvija  (PlN  >huvija !01_S	et	f	\N
211260	huvijad	?huvijad =huvija  (PlN  >huvijas !02_A	et	f	\N
211287	inimise	?inimise =inimise  (SgG  >inimine !12_S	et	f	\N
211290	horoskopisse	?horoskopisse =horoskopi  (SgIll  >horoskopp !22_S	et	f	\N
211291	horoskopisse	?horoskopisse =horoskopisse  (SgG  >horoskopisne !02_A	et	f	\N
211292	horoskopisse	?horoskopisse =horoskopisse  (PlP  >horoskopiss !22_S	et	f	\N
211298	lugemistega	lugemistega =lugemis  (PlKom  >lugemine !12_S	et	f	\N
211299	lugemistega	"lugemine %luge  )MINE_vS  <lugema ;28_V	et	f	\N
211300	lugemistega	"lugemine %lugemi  )NE_aA  <lugem ;02_S	et	f	\N
211316	luab	?luab =luab  (SgN  >luab !22_S	et	f	\N
211341	jahaks	?jahaks =jaha  (SgTr  >jaha !17_S	et	f	\N
211342	jahaks	?jahaks =jaha  (KndPrPs  >jahama !27_V	et	f	\N
211357	isikuomadused	isikuomadused =omaduse  (PlN  >isiku+omadus !11_S	et	f	\N
211358	isikuomadused	"isiku+omadus %oma  )US_aS  <isiku+oma ;17_A	et	f	\N
211361	vanaajadest	?vanaajadest =vanaaja  (PlEl  >vanaaja !16_S	et	f	\N
211362	vanaajadest	?vanaajadest =vanaajades  (SgP  >vanaajadene !12_A	et	f	\N
211363	vanaajadest	?vanaajadest =aja  (PlEl  >vana+aja !17_S	et	f	\N
211364	vanaajadest	?vanaajadest =ajades  (SgP  >vana+ajadene !12_A	et	f	\N
211379	karjari	?karjari =karjari  (SgN  >karjari !01_S	et	f	\N
211380	karjari	?karjari =karjari  (SgG  >karjari !01_S	et	f	\N
211381	karjari	?karjari =karjari  (SgG  >karjar !02_S	et	f	\N
211389	mõjutav	mõjutav =mõju  (PtsPrIps  >mõjuma !27_V	et	f	\N
211390	mõjutav	mõjutav =mõjuta  (PtsPrPs  >mõjutama !27_V	et	f	\N
211391	mõjutav	mõjutav =mõjutav  (SgN  >mõjutav !02_A	et	f	\N
211392	mõjutav	"mõjutav %mõju  )TAV_vAS  <mõjuma ;27_V	et	f	\N
211393	mõjutav	"mõjutav %mõjuta  )V_vA  <mõjutama ;27_V	et	f	\N
211424	takistatud	takistatud =takista  (PtsPtIps  >takistama !27_V	et	f	\N
211425	takistatud	takistatud =takistatu  (PlN  >takistatu !01_S	et	f	\N
211427	takistatud	"takistatu %takista  )TU1_vS  <takistama ;27_V	et	f	\N
211429	takistatud	takistatud =takistatud  (ID  >takistatud !41_A	et	f	\N
211430	takistatud	"takistatud %takista  )TUD_vA  <takistama ;27_V	et	f	\N
211434	elektrienergia	elektrienergia =energia  (SgN  >elektri+energia !01_S	et	f	\N
211435	elektrienergia	elektrienergia =energia  (SgG  >elektri+energia !01_S	et	f	\N
211460	söögiristad	?söögiristad =söögirista  (PlN  >söögirista !16_S	et	f	\N
211461	söögiristad	?söögiristad =söögirista  (IndPrSg2  >söögiristama !27_V	et	f	\N
211462	söögiristad	?söögiristad =rista  (PlN  >söögi+rista !16_S	et	f	\N
211469	kineskoopi	kineskoopi =kineskoopi  (SgP  >kineskoop !22_S	et	f	\N
211470	kineskoopi	kineskoopi =kineskoopi  (SgAdt  >kineskoop !22_S	et	f	\N
211488	valjutage	?valjutage =valjuta  (ImpPrPl2  >valjutama !27_V	et	f	\N
211490	valjutage	?valjutage =tage  (SgN  >valju+tage !16_S	et	f	\N
211491	valjutage	?valjutage =tage  (SgG  >valju+tage !16_S	et	f	\N
211492	elektrisedmeid	?elektrisedmeid =elektrisedmei  (PlN  >elektrisedmei !26_S	et	f	\N
211493	elektrisedmeid	?elektrisedmeid =elektrisedmei  (SgP  >elektrisedmei !26_S	et	f	\N
211494	elektrisedmeid	?elektrisedmeid =sedme  (PlP  >elektri+sedme !06_S	et	f	\N
211495	elektrisedmeid	?elektrisedmeid =sedmei  (PlN  >elektri+sedmei !26_S	et	f	\N
211496	elektrisedmeid	?elektrisedmeid =sedmei  (SgP  >elektri+sedmei !26_S	et	f	\N
211497	elektrisedmeid	?elektrisedmeid =sedmeid  (SgN  >elektri+sedmeid !22_S	et	f	\N
211514	kohvikeetajat	?kohvikeetajat =kohvikeetaja  (SgP  >kohvikeetaja !01_S	et	f	\N
211515	kohvikeetajat	?kohvikeetajat =kohvikeetaja  (SgP  >kohvikeetajas !02_A	et	f	\N
211516	kohvikeetajat	?kohvikeetajat =eetaja  (SgP  >kohvik+eetaja !01_S	et	f	\N
211517	kohvikeetajat	?kohvikeetajat =eetaja  (SgP  >kohvik+eetajas !02_A	et	f	\N
211518	kohvikeetajat	?kohvikeetajat =keetaja  (SgP  >kohvi+keetaja !01_S	et	f	\N
211519	kohvikeetajat	?kohvikeetajat =keetaja  (SgP  >kohvi+keetajas !02_A	et	f	\N
211537	classmsonormalspan	?classmsonormalspan =classmsonormalspan  (SgN  >classmsonormalspan !02_S	et	f	\N
211545	langetemmul	?langetemmul =langetemmul  (SgN  >langetemmul !02_S	et	f	\N
211143	küsimuseta	küsimuseta =küsimuse  (SgAb  >küsimus !11_S	et	f	\N
211144	küsimuseta	"küsimus %küsi  )MUS_vS  <küsima ;27_V	et	f	\N
211145	tehnoloogilise	tehnoloogilise =tehnoloogilise  (SgG  >tehnoloogiline !12_A	et	f	\N
211146	tehnoloogilise	"tehnoloogiline %tehnoloogi  )LINE_aA  <tehnoloog ;22_S	et	f	\N
211148	tehnoloogilise	tehnoloogilise =loogilise  (SgG  >tehno+loogiline !12_A	et	f	\N
211150	tehnoloogilise	"tehno+loogiline %loogi  )LINE_aA  <tehno+loog ;22_S	et	f	\N
211155	koristajale	koristajale =koristaja  (SgAll  >koristaja !01_S	et	f	\N
211156	koristajale	"koristaja %korista  )JA_vS  <koristama ;27_V	et	f	\N
211200	fantastilise	fantastilise =fantastilise  (SgG  >fantastiline !12_A	et	f	\N
211201	fantastilise	"fantastiline %fantasti  )LINE_aA  <fantast ;22_S	et	f	\N
211210	keeltma	?keeltma =keeltma  (IndPrPs_  >keeltmama !29_V	et	f	\N
211211	keeltma	?keeltma =keeltma  (ImpPrSg2  >keeltmama !29_V	et	f	\N
211222	tänapäevaeses	?tänapäevaeses =tänapäevaese  (PlIn  >tänapäevaes !22_S	et	f	\N
211223	tänapäevaeses	?tänapäevaeses =eses  (SgN  >täna+päeva+eses !09_S	et	f	\N
211224	tänapäevaeses	?tänapäevaeses =aese  (SgIn  >täna+päev+aene !10_A	et	f	\N
211225	tänapäevaeses	?tänapäevaeses =aese  (SgIn  >täna+päev+aese !06_S	et	f	\N
211226	tänapäevaeses	?tänapäevaeses =aeses  (SgN  >täna+päev+aeses !09_S	et	f	\N
211227	tänapäevaeses	?tänapäevaeses =päevaese  (SgIn  >täna+päevaene !12~10_A	et	f	\N
211228	tänapäevaeses	?tänapäevaeses =päevaese  (PlIn  >täna+päevaes !22_S	et	f	\N
211237	tunnistuses	tunnistuses =tunnistuse  (SgIn  >tunnistus !11_S	et	f	\N
211238	tunnistuses	"tunnistus %tunnista  )US_vS  <tunnistama ;27_V	et	f	\N
211245	õppumist	?õppumist =õppumi  (SgEl  >õppumi !01_S	et	f	\N
211246	õppumist	?õppumist =õppumi  (SgEl  >õppum !02_S	et	f	\N
211247	õppumist	?õppumist =õppumis  (SgP  >õppumis !11_S	et	f	\N
211248	õppumist	?õppumist =õppumis  (SgP  >õppumine !12_S	et	f	\N
211249	õppumist	?õppumist =õppumist  (SgN  >õppumist !22_S	et	f	\N
211250	tartu-	tartu- =tartu  (SgN  >tartu !01_H	et	f	\N
211251	tartu-	tartu- =tartu  (SgG  >tartu !01_H	et	f	\N
211278	inspiratsioni	?inspiratsioni =inspiratsio  (SgTer  >inspiratsio !01_S	et	f	\N
211279	inspiratsioni	?inspiratsioni =inspiratsioni  (SgN  >inspiratsioni !16_S	et	f	\N
211280	inspiratsioni	?inspiratsioni =inspiratsioni  (SgG  >inspiratsion !19~02_S	et	f	\N
211281	inspiratsioni	?inspiratsioni =inspiratsioni  (SgG  >inspiratsioni !16_S	et	f	\N
211282	inspiratsioni	?inspiratsioni =inspiratsioni  (SgP  >inspiratsion !19_S	et	f	\N
211283	inspiratsioni	?inspiratsioni =inspiratsioni  (SgAdt  >inspiratsion !19_S	et	f	\N
211284	inspiratsioni	?inspiratsioni =inspiratsioni  (IndPrPs_  >inspiratsionima !28_V	et	f	\N
211285	inspiratsioni	?inspiratsioni =inspiratsioni  (ImpPrSg2  >inspiratsionima !28_V	et	f	\N
211293	seleparast	?seleparast =selepara  (SgEl  >selepara !16_S	et	f	\N
211294	seleparast	?seleparast =seleparas  (SgP  >seleparane !12_A	et	f	\N
211295	sõbrali	?sõbrali =sõbrali  (ID  >sõbrali !41_D	et	f	\N
211296	sõbrali	?sõbrali =sõbrali  (SgG  >sõbral !02_S	et	f	\N
211297	ülesanneteg	### ülesanneteg	et	f	\N
211301	venesatele	?venesatele =venesa  (PlAll  >venesa !01_S	et	f	\N
211302	venesatele	?venesatele =venesate  (PlAll  >venesatt !22_S	et	f	\N
211303	venesatele	?venesatele =venesatele  (IndPrPs_  >venesatelema !36_V	et	f	\N
211304	venesatele	?venesatele =venesatele  (ImpPrSg2  >venesatelema !36_V	et	f	\N
211305	venesatele	?venesatele =sate  (PlAll  >vene+satt !22_S	et	f	\N
211307	jatma	?jatma =jatma  (IndPrPs_  >jatmama !29_V	et	f	\N
211309	jatma	?jatma =jatma  (ImpPrSg2  >jatmama !29_V	et	f	\N
211319	jäagi	?jäagi =jäagi  (SgN  >jäagi !16_S	et	f	\N
211321	jäagi	?jäagi =jäagi  (SgG  >jäagi !16_S	et	f	\N
211323	jäagi	?jäagi =jäagi  (SgG  >jäak !22_S	et	f	\N
211325	jäagi	?jäagi =jäagi  (SgP  >jäag !22_S	et	f	\N
211327	jäagi	?jäagi =jäagi  (SgAdt  >jäag !22_S	et	f	\N
211328	jäagi	?jäagi =jäagi  (IndPrPs_  >jäakima !28_V	et	f	\N
211329	jäagi	?jäagi =jäagi  (ImpPrSg2  >jäakima !28_V	et	f	\N
211330	jäagi	?jäagi =jäa  (SgN^  >jäa !26_S	et	f	\N
211331	jäagi	?jäagi =jäa  (SgG^  >jäa !26_S	et	f	\N
211332	tüttu	?tüttu =tüttu  (ID  >tüttu !41_D	et	f	\N
211333	tüttu	?tüttu =tüttu  (IndPrPs_  >tüttuma !27_V	et	f	\N
211334	tüttu	?tüttu =tüttu  (ImpPrSg2  >tüttuma !27_V	et	f	\N
211336	põhjendus	põhjendus =põhjendu  (IndIpfSg3  >põhjenduma !27_V	et	f	\N
211337	põhjendus	põhjendus =põhjendus  (SgN  >põhjendus !11_S	et	f	\N
211338	põhjendus	"põhjendus %põhjenda  )US_vS  <põhjendama ;27_V	et	f	\N
211350	põhjendused	põhjendused =põhjenduse  (PlN  >põhjendus !11_S	et	f	\N
211351	põhjendused	"põhjendus %põhjenda  )US_vS  <põhjendama ;27_V	et	f	\N
211370	lasteelu	lasteelu =elu  (SgN  >laste+elu !17_S	et	f	\N
211371	lasteelu	lasteelu =elu  (SgG  >laste+elu !17_S	et	f	\N
211372	lasteelu	lasteelu =elu  (SgP  >laste+elu !17_S	et	f	\N
211375	karjää	?karjää =karjää  (SgN  >karjää !26_S	et	f	\N
211376	karjää	?karjää =karjää  (SgG  >karjää !26_S	et	f	\N
211386	sihikinel	?sihikinel =sihikine  (PlAd  >sihikin !19_S	et	f	\N
211387	sihikinel	?sihikinel =kine  (SgAd  >sihi+kine !16_S	et	f	\N
211388	sihikinel	?sihikinel =kinel  (SgN  >sihi+kinel !02_S	et	f	\N
211167	geenimuudetuid	?geenimuudetuid =geenimuudetui  (PlN  >geenimuudetui !26_S	et	f	\N
211168	geenimuudetuid	?geenimuudetuid =geenimuudetui  (SgP  >geenimuudetui !26_S	et	f	\N
211178	kanatibuid	?kanatibuid =kanatibui  (PlN  >kanatibui !26_S	et	f	\N
211179	kanatibuid	?kanatibuid =kanatibui  (SgP  >kanatibui !26_S	et	f	\N
211180	kanatibuid	?kanatibuid =tibui  (PlN  >kana+tibui !26_S	et	f	\N
211181	kanatibuid	?kanatibuid =tibui  (SgP  >kana+tibui !26_S	et	f	\N
211182	kanatibuid	?kanatibuid =tibuid  (SgN  >kana+tibuid !22_S	et	f	\N
211183	suurustele	suurustele =suurus  (PlAll  >suurus !11~09_S	et	f	\N
211184	suurustele	"suurus %suur  )US_aS  <suur ;13_A	et	f	\N
211185	suurustele	suurustele =suurus  (PlAll  >suurune !10~12_A	et	f	\N
211186	suurustele	suurustele =suurustele  (IndPrPs_  >suurustelema !36_V	et	f	\N
211187	suurustele	suurustele =suurustele  (ImpPrSg2  >suurustelema !36_V	et	f	\N
211188	suurustele	suurustele =us  (PlAll  >suur+uks !14_S	et	f	\N
211194	eba	?eba =eba  (SgN  >eba !17_S	et	f	\N
211195	eba	?eba =eba  (SgG  >eba !17_S	et	f	\N
211196	eba	?eba =eba  (SgP  >eba !17_S	et	f	\N
211197	eba	?eba =eba  (IndPrPs_  >ebama !27_V	et	f	\N
211198	eba	?eba =eba  (ImpPrSg2  >ebama !27_V	et	f	\N
211202	sündmustikuks	sündmustikuks =sündmustiku  (SgTr  >sündmustik !25_S	et	f	\N
211203	sündmustikuks	sündmustikuks =tiku  (SgTr  >sündmus+tikk !22_S	et	f	\N
211204	sündmustikuks	sündmustikuks =tiku  (PlTr  >sündmus+tikk !22_S	et	f	\N
211214	õppeinformatsiooni	õppeinformatsiooni =informatsiooni  (SgG  >õppe+informatsioon !22_S	et	f	\N
211215	õppeinformatsiooni	õppeinformatsiooni =informatsiooni  (SgP  >õppe+informatsioon !22_S	et	f	\N
211216	õppeinformatsiooni	õppeinformatsiooni =informatsiooni  (SgAdt  >õppe+informatsioon !22_S	et	f	\N
211217	irimaas	?irimaas =irimaa  (SgIn  >irimaa !26_S	et	f	\N
211218	irimaas	?irimaas =irimaas  (SgN  >irimaas !22_S	et	f	\N
211239	ülikooliska	?ülikooliska =ülikooliska  (SgN  >ülikooliska !16_S	et	f	\N
211240	ülikooliska	?ülikooliska =ülikooliska  (SgG  >ülikooliska !16_S	et	f	\N
211241	ülikooliska	?ülikooliska =iska  (SgN  >üli+kool+iska !16_S	et	f	\N
211242	ülikooliska	?ülikooliska =iska  (SgG  >üli+kool+iska !16_S	et	f	\N
211243	ülikooliska	?ülikooliska =kooliska  (SgN  >üli+kooliska !01_S	et	f	\N
211244	ülikooliska	?ülikooliska =kooliska  (SgG  >üli+kooliska !01_S	et	f	\N
211263	kauga	?kauga =kau  (SgKom  >kau !26_S	et	f	\N
211264	kauga	?kauga =kauga  (SgN  >kauga !16_S	et	f	\N
211265	kauga	?kauga =kauga  (SgG  >kauga !16_S	et	f	\N
211266	kauga	?kauga =kauga  (IndPrPs_  >kaugama !29_V	et	f	\N
211267	kauga	?kauga =kauga  (ImpPrSg2  >kaugama !29_V	et	f	\N
211268	tahtsam	?tahtsam =tahtsam  (SgN  >tahtsam !02_A	et	f	\N
211306	parempi	?parempi =parempi  (SgN  >parempi !01_S	et	f	\N
211308	parempi	?parempi =parempi  (SgG  >parempi !01_S	et	f	\N
211310	parempi	?parempi =parempi  (SgP  >paremp !22_S	et	f	\N
211311	parempi	?parempi =parempi  (SgAdt  >paremp !22_S	et	f	\N
211318	jäägi	jäägi =jäägi  (SgG  >jääk !22_S	et	f	\N
211320	jäägi	jäägi =jää  (SgN^  >jää !26_S	et	f	\N
211322	jäägi	jäägi =jää  (SgG^  >jää !26_S	et	f	\N
211324	jäägi	jäägi =jää  (IndPrPs_^  >jääma !37_V	et	f	\N
211326	jäägi	jäägi =jää  (ImpPrSg2^  >jääma !37_V	et	f	\N
211343	tähtsan	?tähtsan =tähtsa  (IndPrSg1  >tähtsama !29_V	et	f	\N
211344	tähtsan	?tähtsan =tähtsan  (SgN  >tähtsan !02_S	et	f	\N
211352	ootamatus	ootamatus =ootamatu  (SgIn  >ootamatu !01_A	et	f	\N
211353	ootamatus	"ootamatu %oota  )MATU_vA  <ootama ;29_V	et	f	\N
211354	ootamatus	ootamatus =ootamatus  (SgN  >ootamatus !11?09_S	et	f	\N
211355	ootamatus	"ootamatus %oota  )MATUS_aS  <ootama ;29_V	et	f	\N
211356	analiseerime	?analiseerime =analiseeri  (IndPrPl1  >analiseerima !28_V	et	f	\N
211359	kiitle	kiitle =kiitle  (IndPrPs_  >kiitlema !30_V	et	f	\N
211360	kiitle	kiitle =kiitle  (ImpPrSg2  >kiitlema !30_V	et	f	\N
211373	inimiseks	?inimiseks =inimise  (SgTr  >inimine !12_S	et	f	\N
211374	tahtsem	?tahtsem =tahtsem  (SgN  >tahtsem !02_A	et	f	\N
211383	blokki	blokki =blokki  (SgP  >blokk !22_S	et	f	\N
211384	blokki	blokki =blokki  (SgAdt  >blokk !22_S	et	f	\N
211403	möödab	?möödab =mööda  (IndPrSg3  >möödama !29_V	et	f	\N
211404	toitejuhe	toitejuhe =juhe  (SgN  >toite+juhe !05_S	et	f	\N
211405	toitejuhe	toitejuhe =juhe  (SgN  >toite+juhe !06_S	et	f	\N
211413	märgistusele	märgistusele =märgistuse  (SgAll  >märgistus !11_S	et	f	\N
211414	märgistusele	"märgistus %märgista  )US_vS  <märgistama ;27_V	et	f	\N
211426	väljavool	väljavool =voo  (SgAd  >välja+voog !22_S	et	f	\N
211428	väljavool	väljavool =vool  (SgN  >välja+vool !22_S	et	f	\N
211436	mikrolaenu	mikrolaenu =laenu  (SgG  >mikro+laen !22_S	et	f	\N
211437	mikrolaenu	mikrolaenu =laenu  (SgP  >mikro+laen !22_S	et	f	\N
211438	mikrolaenu	mikrolaenu =laenu  (SgAdt  >mikro+laen !22_S	et	f	\N
211464	hotke	?hotke =hotke  (SgN  >hotke !06_S	et	f	\N
211465	hotke	?hotke =hotke  (SgG  >hotke !06_S	et	f	\N
211466	hotke	?hotke =hotke  (PlP  >hotk !22_S	et	f	\N
211467	hotke	?hotke =hotke  (IndPrPs_  >hotkema !27_V	et	f	\N
211468	hotke	?hotke =hotke  (ImpPrSg2  >hotkema !27_V	et	f	\N
211472	tahklas	?tahklas =tahkla  (SgIn  >tahkla !01_S	et	f	\N
211169	mõjutus	mõjutus =mõjutu  (SgIn  >mõjutu !01_A	et	f	\N
211170	mõjutus	"mõjutu %mõju  )TU1_vS  <mõjuma ;27_V	et	f	\N
211171	mõjutus	"mõjutu %mõju  )TU2_kA  <mõju ;17_S	et	f	\N
211172	mõjutus	mõjutus =mõjutus  (SgN  >mõjutus !11_S	et	f	\N
211173	mõjutus	"mõjutus %mõjuta  )US_vS  <mõjutama ;27_V	et	f	\N
211174	mõjutus	"mõjutus %mõju  )TUS1_aS  <mõjuma ;27_V	et	f	\N
211175	mõjutus	"mõjutus %mõju  )TUS2_aS  <mõju ;17_S	et	f	\N
211189	kuude	kuude =kuu  (PlG  >kuu !26_S	et	f	\N
211190	kuude	kuude =kuu  (SgAdt  >kuus !14_N	et	f	\N
211191	kanatibu	kanatibu =tibu  (SgN  >kana+tibu !17_S	et	f	\N
211192	kanatibu	kanatibu =tibu  (SgG  >kana+tibu !17_S	et	f	\N
211193	kanatibu	kanatibu =tibu  (SgP  >kana+tibu !17_S	et	f	\N
211213	kõrkharidust	?kõrkharidust =kõrkharidus  (SgP  >kõrkharidus !11?09_S	et	f	\N
211233	firmis	?firmis =firmi  (SgIn  >firmi !16_S	et	f	\N
211234	firmis	?firmis =firmi  (SgIn  >firm !22_S	et	f	\N
211235	firmis	?firmis =firmi  (IndIpfSg3  >firmima !28_V	et	f	\N
211236	firmis	?firmis =firmis  (SgN  >firmis !09_S	et	f	\N
211261	dokumendit	?dokumendit =umendi  (SgP  >dok+umendi !01_S	et	f	\N
211262	dokumendit	?dokumendit =umendi  (SgP  >dok+umend !02_S	et	f	\N
211272	paevikut	?paevikut =paeviku  (SgP  >paeviku !01_S	et	f	\N
211273	paevikut	?paevikut =paeviku  (SgP  >paevik !02_S	et	f	\N
211274	paevikut	?paevikut =viku  (SgP  >pae+viku !16_S	et	f	\N
211275	paevikut	?paevikut =vikut  (SgN  >pae+vikut !02_S	et	f	\N
211286	sirvitada	?sirvitada =sirvita  (Inf  >sirvitama !27_V	et	f	\N
211312	tunnub	?tunnub =tunnu  (IndPrSg3  >tunnuma !27_V	et	f	\N
211313	anavad	?anavad =ana  (IndPrPl3  >anama !27_V	et	f	\N
211314	anavad	?anavad =anava  (PlN  >anava !01_S	et	f	\N
211315	anavad	?anavad =anava  (PlN  >anav !02_A	et	f	\N
211317	ut	### ut	et	f	\N
211339	põhjendusse	põhjendusse =põhjendus  (SgAdt  >põhjendus !11_S	et	f	\N
211340	põhjendusse	"põhjendus %põhjenda  )US_vS  <põhjendama ;27_V	et	f	\N
211365	võieti	?võieti =võieti  (ID  >võieti !41_D	et	f	\N
211366	võieti	?võieti =võieti  (SgG  >võiet !02_S	et	f	\N
211367	võieti	?võieti =eti  (SgN  >või+eti !16_S	et	f	\N
211368	võieti	?võieti =eti  (SgG  >või+eti !16_S	et	f	\N
211369	võieti	?võieti =eti  (SgG  >või+ett !22_S	et	f	\N
211377	õnnustamine	?õnnustamine =õnnustamine  (SgN  >õnnustamine !12_S	et	f	\N
211378	õnnustamine	?õnnustamine =õnnustamine  (PlP  >õnnustamin !19_S	et	f	\N
211382	tõustmisega	?tõustmisega =tõustmise  (SgKom  >tõustmine !12?10_S	et	f	\N
211394	tulekaju	?tulekaju =tulekaju  (IndPrPs_  >tulekajuma !27_V	et	f	\N
211395	tulekaju	?tulekaju =tulekaju  (ImpPrSg2  >tulekajuma !27_V	et	f	\N
211396	tulekaju	?tulekaju =kaju  (SgN  >tule+kaju !17_S	et	f	\N
211397	tulekaju	?tulekaju =kaju  (SgG  >tule+kaju !17_S	et	f	\N
211398	tulekaju	?tulekaju =kaju  (SgP  >tule+kaju !17_S	et	f	\N
211417	kuumutamist	kuumutamist =kuumutamis  (SgP  >kuumutamine !12_S	et	f	\N
211418	kuumutamist	"kuumutamine %kuumuta  )MINE_vS  <kuumutama ;27_V	et	f	\N
211431	elektriseadet	elektriseadet =seade  (SgP  >elektri+seade !05_S	et	f	\N
211432	elektriseadet	elektriseadet =seade  (SgP  >elektri+seade !06_S	et	f	\N
211439	võtage	?võtage =võta  (ImpPrPl2  >võtama !27_V	et	f	\N
211444	kuumi	kuumi =kuumi  (SgG  >kuum !22_AS	et	f	\N
211445	kuumi	kuumi =kuumi  (SgP  >kuum !22_AS	et	f	\N
211446	kuumi	kuumi =kuumi  (SgAdt  >kuum !22_AS	et	f	\N
211447	kuumi	kuumi =kuumi  (PlP  >kuum !22_AS	et	f	\N
211458	savine	savine =savine  (SgN  >savine !10_A	et	f	\N
211459	savine	"savine %savi  )NE_aA  <savi ;17_S	et	f	\N
211487	kaivitusnupp	?kaivitusnupp =kaivitusnupp  (SgN  >kaivitusnupp !22_S	et	f	\N
211489	kaivitusnupp	?kaivitusnupp =vitusnupp  (SgN  >kai+vitusnupp !22_S	et	f	\N
211498	seinakontakdi	?seinakontakdi =seinakontakdi  (SgG  >seinakontakd !22_S	et	f	\N
211499	seinakontakdi	?seinakontakdi =seinakontakdi  (SgP  >seinakontakd !22_S	et	f	\N
211500	seinakontakdi	?seinakontakdi =seinakontakdi  (SgAdt  >seinakontakd !22_S	et	f	\N
211501	seinakontakdi	?seinakontakdi =seinakontakdi  (IndPrPs_  >seinakontakdima !28_V	et	f	\N
211502	seinakontakdi	?seinakontakdi =seinakontakdi  (ImpPrSg2  >seinakontakdima !28_V	et	f	\N
211503	seinakontakdi	?seinakontakdi =akdi  (SgN  >seina+kont+akdi !16_S	et	f	\N
211504	seinakontakdi	?seinakontakdi =akdi  (SgG  >seina+kont+akdi !16_S	et	f	\N
211505	seinakontakdi	?seinakontakdi =akdi  (SgG  >seina+kont+akd !22_S	et	f	\N
211506	seinakontakdi	?seinakontakdi =akdi  (SgP  >seina+kont+akd !22_S	et	f	\N
211507	seinakontakdi	?seinakontakdi =akdi  (SgAdt  >seina+kont+akd !22_S	et	f	\N
211508	seinakontakdi	?seinakontakdi =kontakdi  (SgN  >seina+kontakdi !01_S	et	f	\N
211509	seinakontakdi	?seinakontakdi =kontakdi  (SgG  >seina+kontakdi !01_S	et	f	\N
211510	seinakontakdi	?seinakontakdi =kontakdi  (SgG  >seina+kontakd !02_S	et	f	\N
211520	söögilisu	?söögilisu =söögilisu  (IndPrPs_  >söögilisuma !27_V	et	f	\N
211521	söögilisu	?söögilisu =söögilisu  (ImpPrSg2  >söögilisuma !27_V	et	f	\N
211522	söögilisu	?söögilisu =lisu  (SgN  >söögi+lisu !17_S	et	f	\N
211523	söögilisu	?söögilisu =lisu  (SgG  >söögi+lisu !17_S	et	f	\N
211524	söögilisu	?söögilisu =lisu  (SgP  >söögi+lisu !17_S	et	f	\N
211544	em	### em	et	f	\N
211206	katastroofiks	katastroofiks =iks  (SgN  >katastroof+iks !22_S	et	f	\N
211212	kõrkharidust	?kõrkharidust =kõrkharidus  (SgP  >kõrkharidus !11?09_S	et	f	\N
211219	külusus	?külusus =külusu  (SgIn  >külusu !01_S	et	f	\N
211220	külusus	?külusus =külusu  (IndIpfSg3  >külusuma !27_V	et	f	\N
211221	külusus	?külusus =külusus  (SgN  >külusus !11_S	et	f	\N
211229	edukassee	?edukassee =edukassee  (SgN  >edukassee !26_S	et	f	\N
211230	edukassee	?edukassee =edukassee  (SgG  >edukassee !26_S	et	f	\N
211231	edukassee	?edukassee =kassee  (SgN  >edu+kassee !26_S	et	f	\N
211232	edukassee	?edukassee =kassee  (SgG  >edu+kassee !26_S	et	f	\N
211252	nõukogumise	nõukogumise =kogumise  (SgG  >nõu+kogumine !12_S	et	f	\N
211253	nõukogumise	"nõu+kogumine %kogumi  )NE_aA  <nõu+kogum ;02_S	et	f	\N
211254	majusid	?majusid =maju  (PlP  >maju !17_S	et	f	\N
211255	majusid	?majusid =maju  (IndIpfSg2  >majuma !27_V	et	f	\N
211256	majusid	?majusid =maju  (IndIpfPl3  >majuma !27_V	et	f	\N
211257	inglisi	inglisi =inglisi  (PlP  >ingline !12_A	et	f	\N
211258	inglisi	"ingline %ingli  )NE_aA  <ingel ;02_S	et	f	\N
211269	sootsalt	?sootsalt =sootsa  (SgAbl  >sootsa !01_S	et	f	\N
211270	sootsalt	?sootsalt =sootsalt  (ID  >sootsalt !41_D	et	f	\N
211271	sootsalt	?sootsalt =tsalt  (SgN  >soo+tsalt !22_S	et	f	\N
211276	korusel	?korusel =koruse  (SgAd  >korus !09_S	et	f	\N
211277	korusel	?korusel =korusel  (SgN  >korusel !19_S	et	f	\N
211288	askelduste	askelduste =askeldus  (PlG  >askeldus !11_S	et	f	\N
211289	askelduste	"askeldus %askelda  )US_vS  <askeldama ;27_V	et	f	\N
211335	inspiratsion	?inspiratsion =inspiratsion  (SgN  >inspiratsion !19~02_S	et	f	\N
211345	käju	?käju =käju  (SgN  >käju !17_S	et	f	\N
211346	käju	?käju =käju  (SgG  >käju !17_S	et	f	\N
211347	käju	?käju =käju  (SgP  >käju !17_S	et	f	\N
211348	käju	?käju =käju  (IndPrPs_  >käjuma !27_V	et	f	\N
211349	käju	?käju =käju  (ImpPrSg2  >käjuma !27_V	et	f	\N
211385	katalisaator	?katalisaator =katalisaator  (SgN  >katalisaator !02_S	et	f	\N
211410	õhuvoolu	õhuvoolu =voolu  (SgG  >õhu+vool !22_S	et	f	\N
211411	õhuvoolu	õhuvoolu =voolu  (SgP  >õhu+vool !22_S	et	f	\N
211412	õhuvoolu	õhuvoolu =voolu  (SgAdt  >õhu+vool !22_S	et	f	\N
211415	nõrka	nõrka =nõrka  (SgP  >nõrk !22_A	et	f	\N
211416	nõrka	nõrka =nõrka  (SgAdt  >nõrk !22_A	et	f	\N
211433	uhendada	?uhendada =uhenda  (Inf  >uhendama !27_V	et	f	\N
211440	kuumust	kuumust =kuumus  (SgP  >kuumus !11~09_S	et	f	\N
211441	kuumust	"kuumus %kuum  )US_aS  <kuum ;22_AS	et	f	\N
211442	kuumust	kuumust =us  (SgP  >kuum+uks !14_S	et	f	\N
211443	kuumust	kuumust =must  (SgN  >kuu+must !22_AS	et	f	\N
211471	krimustage	?krimustage =krimusta  (ImpPrPl2  >krimustama !27_V	et	f	\N
211475	pesumasinasse	pesumasinasse =asse  (PlP  >pesu+masin+ass !22_S	et	f	\N
211476	pesumasinasse	pesumasinasse =masina  (SgIll  >pesu+masin !02_S	et	f	\N
211477	pesumasinasse	pesumasinasse =masinas  (SgAdt  >pesu+masinane !12_A	et	f	\N
211478	pesumasinasse	"pesu+masinane %masina  )NE_aA  <pesu+masin ;02_S	et	f	\N
211480	programivalija	?programivalija =programivalija  (SgN  >programivalija !01_S	et	f	\N
211481	programivalija	?programivalija =programivalija  (SgG  >programivalija !01_S	et	f	\N
211482	programivalija	?programivalija =programivalija  (SgG  >programivalijas !02_A	et	f	\N
211548	langetkas	?langetkas =langetka  (SgIn  >langetka !01_S	et	f	\N
211552	langetkus	?langetkus =langetku  (SgIn  >langetku !01_S	et	f	\N
211553	langetkus	?langetkus =langetku  (IndIpfSg3  >langetkuma !27_V	et	f	\N
211554	langetkus	?langetkus =langetkus  (SgN  >langetkus !11_S	et	f	\N
211574	traditsione	?traditsione =traditsione  (SgN  >traditsione !16_S	et	f	\N
211575	traditsione	?traditsione =traditsione  (SgG  >traditsione !16_S	et	f	\N
211576	traditsione	?traditsione =traditsione  (PlP  >traditsion !19_S	et	f	\N
211584	kindluses	kindluses =kindluse  (SgIn  >kindlus !11~09_S	et	f	\N
211585	kindluses	"kindlus %kindla  )US_aS  <kindel ;02_A	et	f	\N
211586	vestervali	### vestervali	et	f	\N
211593	kolmapäeviti	?kolmapäeviti =kolmapäevi  (IndIpfIps  >kolmapäevima !28_V	et	f	\N
211594	kolmapäeviti	?kolmapäeviti =kolmapäeviti  (ID  >kolmapäeviti !41_D	et	f	\N
211595	kolmapäeviti	?kolmapäeviti =kolmapäeviti  (SgG  >kolmapäevitt !22_S	et	f	\N
211597	kolmapäeviti	?kolmapäeviti =kolmapäeviti  (IndPrPs_  >kolmapäevittima !28_V	et	f	\N
211599	kolmapäeviti	?kolmapäeviti =kolmapäeviti  (ImpPrSg2  >kolmapäevittima !28_V	et	f	\N
211601	kolmapäeviti	?kolmapäeviti =iti  (SgN  >kolma+päev+iti !16_S	et	f	\N
211603	kolmapäeviti	?kolmapäeviti =iti  (SgG  >kolma+päev+iti !16_S	et	f	\N
211605	kolmapäeviti	?kolmapäeviti =iti  (SgG  >kolma+päev+itt !22_S	et	f	\N
211607	kolmapäeviti	?kolmapäeviti =päeviti  (SgG  >kolma+päevit !02_S	et	f	\N
211609	kolmapäeviti	?kolmapäeviti =päeviti  (SgG  >kolma+päevitt !22_S	et	f	\N
211615	tualettiruum	?tualettiruum =tualettiruum  (SgN  >tualettiruum !22_S	et	f	\N
211616	tualettiruum	?tualettiruum =iruum  (SgN  >tualett+iruum !22_S	et	f	\N
211631	lemmiklinnast	lemmiklinnast =ast  (SgN  >lemmik+linn+ast !22_S	et	f	\N
211632	lemmiklinnast	lemmiklinnast =linna  (SgEl  >lemmik+linn !22_S	et	f	\N
211633	lemmiklinnast	lemmiklinnast =linnas  (SgP  >lemmik+linnas !09_S	et	f	\N
211399	laualampi	laualampi =lampi  (SgP  >laua+lamp !22_SA	et	f	\N
211400	laualampi	laualampi =lampi  (SgAdt  >laua+lamp !22_SA	et	f	\N
211401	elektriarvesti	elektriarvesti =arvesti  (SgN  >elektri+arvesti !01_S	et	f	\N
211402	elektriarvesti	elektriarvesti =arvesti  (SgG  >elektri+arvesti !01_S	et	f	\N
211406	pistikupessa	?pistikupessa =pistikupessa  (SgN  >pistikupessa !16_S	et	f	\N
211407	pistikupessa	?pistikupessa =pistikupessa  (SgG  >pistikupessa !16_S	et	f	\N
211408	pistikupessa	?pistikupessa =ikupessa  (SgN  >pist+ikupessa !16_S	et	f	\N
211409	pistikupessa	?pistikupessa =ikupessa  (SgG  >pist+ikupessa !16_S	et	f	\N
211419	maksimaalvõimsused	maksimaalvõimsused =võimsuse  (PlN  >maksimaal+võimsus !11~09_S	et	f	\N
211420	maksimaalvõimsused	"maksimaal+võimsus %võimsa  )US_aS  <maksimaal+võimas ;03_A	et	f	\N
211421	seadmesse	seadmesse =seadme  (SgIll  >seade !05_S	et	f	\N
211422	seadmesse	seadmesse =seadmes  (SgAdt  >seadmene !12_A	et	f	\N
211423	seadmesse	"seadmene %seadme  )NE_aA  <seade ;05_S	et	f	\N
211448	peapanelli	?peapanelli =peapanelli  (SgG  >peapanell !22_S	et	f	\N
211449	peapanelli	?peapanelli =peapanelli  (SgP  >peapanell !22_S	et	f	\N
211450	peapanelli	?peapanelli =peapanelli  (SgAdt  >peapanell !22_S	et	f	\N
211451	peapanelli	?peapanelli =peapanelli  (IndPrPs_  >peapanellima !28_V	et	f	\N
211452	peapanelli	?peapanelli =peapanelli  (ImpPrSg2  >peapanellima !28_V	et	f	\N
211453	peapanelli	?peapanelli =panelli  (SgN  >pea+panelli !01_S	et	f	\N
211454	peapanelli	?peapanelli =panelli  (SgG  >pea+panelli !01_S	et	f	\N
211455	peapanelli	?peapanelli =panelli  (SgG  >pea+panell !22_S	et	f	\N
211456	peapanelli	?peapanelli =panelli  (SgP  >pea+panell !22_S	et	f	\N
211457	peapanelli	?peapanelli =panelli  (SgAdt  >pea+panell !22_S	et	f	\N
211463	vaadate	?vaadate =vaada  (IndPrPl2  >vaadama !29_V	et	f	\N
211479	loputusvahedid	### loputusvahedid	et	f	\N
211483	kontrollige	kontrollige =kontrolli  (ImpPrPl2  >kontrollima !28_V	et	f	\N
211484	kontrollige	kontrollige =ige  (SgN  >kont+roll+ige !04_S	et	f	\N
211540	langetemnarva	?langetemnarva =langetemnarva  (SgN  >langetemnarva !16_S	et	f	\N
211541	langetemnarva	?langetemnarva =langetemnarva  (SgG  >langetemnarva !16_S	et	f	\N
211542	langetemnarva	?langetemnarva =temnarva  (SgN  >lange+temnarva !01_S	et	f	\N
211543	langetemnarva	?langetemnarva =temnarva  (SgG  >lange+temnarva !01_S	et	f	\N
211558	langetmulle	?langetmulle =langetmulle  (PlP  >langetmull !22_S	et	f	\N
211560	platsini	platsini =platsi  (SgTer  >plats !22_S	et	f	\N
211561	platsini	platsini =ini  (SgN  >plats+ini !17_S	et	f	\N
211562	platsini	platsini =ini  (SgG  >plats+ini !17_S	et	f	\N
211563	platsini	platsini =ini  (SgP  >plats+ini !17_S	et	f	\N
211564	platsini	platsini =si  (SgTer  >plat+si !26_S	et	f	\N
211571	perennas	?perennas =perenna  (SgIn  >perenna !16_S	et	f	\N
211579	valtrida	?valtrida =valtri  (Inf  >valtrima !28_V	et	f	\N
211580	pojengi	pojengi =pojengi  (SgG  >pojeng !22_S	et	f	\N
211581	pojengi	pojengi =pojengi  (SgP  >pojeng !22_S	et	f	\N
211582	pojengi	pojengi =pojengi  (SgAdt  >pojeng !22_S	et	f	\N
211583	meelib	?meelib =meeli  (IndPrSg3  >meelima !28_V	et	f	\N
211625	servis	servis =servi  (SgIn  >serv !22_S	et	f	\N
211626	servis	servis =servi  (PlIn  >serv !22_S	et	f	\N
211627	servis	servis =servi  (IndIpfSg3  >servima !28_V	et	f	\N
211628	servis	servis =servis  (SgN  >servis !09_S	et	f	\N
211640	ajaloomuseum	?ajaloomuseum =ajaloomuseum  (SgN  >ajaloomuseum !19_S	et	f	\N
211642	ajaloomuseum	?ajaloomuseum =seum  (SgN  >aja+loomu+seum !22_S	et	f	\N
211645	ajaloomuseum	?ajaloomuseum =useum  (SgN  >aja+loom+useum !22_S	et	f	\N
211647	ajaloomuseum	?ajaloomuseum =museum  (SgN  >aja+loo+museum !22_S	et	f	\N
211649	ajaloomuseum	?ajaloomuseum =loomuseum  (SgN  >aja+loomuseum !19_S	et	f	\N
211653	peterburgas	?peterburgas =peterburga  (SgIn  >peterburga !16_S	et	f	\N
211654	pereda	?pereda =pere  (Inf  >perema !27_V	et	f	\N
211694	kosmetoloogia	?kosmetoloogia =kosmetoloogia  (SgN  >kosmetoloogia !01_S	et	f	\N
211695	kosmetoloogia	?kosmetoloogia =kosmetoloogia  (SgG  >kosmetoloogia !01_S	et	f	\N
211703	suuvilasse	?suuvilasse =suuvila  (SgIll  >suuvila !01_S	et	f	\N
211704	suuvilasse	?suuvilasse =suuvilas  (SgAdt  >suuvilane !12_S	et	f	\N
211705	suuvilasse	?suuvilasse =suuvilasse  (SgG  >suuvilasne !02_A	et	f	\N
211706	suuvilasse	?suuvilasse =suuvilasse  (PlP  >suuvilass !22_S	et	f	\N
211707	suuvilasse	?suuvilasse =vila  (SgIll  >suu+vila !17_S	et	f	\N
211708	suuvilasse	?suuvilasse =vilasse  (SgG  >suu+vilasne !02_A	et	f	\N
211709	suuvilasse	?suuvilasse =vilasse  (PlP  >suu+vilass !22_S	et	f	\N
211727	vaatamisvärtused	?vaatamisvärtused =vaatamisvärtuse  (PlN  >vaatamisvärtus !11~09_S	et	f	\N
211728	vaatamisvärtused	?vaatamisvärtused =värtuse  (PlN  >vaatamis+värtus !11~09_S	et	f	\N
211751	telliskivimaja	telliskivimaja =aja  (SgG  >tellis+kivim+aeg !22_S	et	f	\N
211752	telliskivimaja	telliskivimaja =maja  (SgN  >tellis+kivi+maja !17_S	et	f	\N
211753	telliskivimaja	telliskivimaja =maja  (SgG  >tellis+kivi+maja !17_S	et	f	\N
211754	telliskivimaja	telliskivimaja =maja  (SgP  >tellis+kivi+maja !17_S	et	f	\N
211755	viiekümnendas	?viiekümnendas =viiekümnenda  (SgIn  >viiekümnenda !16_S	et	f	\N
211756	viiekümnendas	?viiekümnendas =viiekümnenda  (IndIpfSg3  >viiekümnendama !27_V	et	f	\N
211473	tahklas	?tahklas =tahkla  (IndIpfSg3  >tahklama !29_V	et	f	\N
211474	tahklas	?tahklas =tahklas  (SgN  >tahklas !07_S	et	f	\N
211485	alguskohta	alguskohta =kohta  (SgP  >algus+koht !22_S	et	f	\N
211486	alguskohta	alguskohta =kohta  (SgAdt  >algus+koht !22_S	et	f	\N
211511	kohvimaasin	?kohvimaasin =kohvimaasi  (IndPrSg1  >kohvimaasima !28_V	et	f	\N
211512	kohvimaasin	?kohvimaasin =kohvimaasin  (SgN  >kohvimaasin !02_S	et	f	\N
211513	kohvimaasin	?kohvimaasin =maasin  (SgN  >kohvi+maasin !02_S	et	f	\N
211525	üheksakorrossel	?üheksakorrossel =üheksakorrosse  (SgAd  >üheksakorrosne !02_A	et	f	\N
211526	üheksakorrossel	?üheksakorrossel =üheksakorrosse  (PlAd  >üheksakorross !22_S	et	f	\N
211527	üheksakorrossel	?üheksakorrossel =üheksakorrossel  (SgN  >üheksakorrossel !02_S	et	f	\N
211528	üheksakorrossel	?üheksakorrossel =korrosse  (SgAd  >üheksa+korrosne !02_A	et	f	\N
211529	üheksakorrossel	?üheksakorrossel =korrosse  (PlAd  >üheksa+korross !22_S	et	f	\N
211530	üheksakorrossel	?üheksakorrossel =korrossel  (SgN  >üheksa+korrossel !02_S	et	f	\N
211531	üheksakorrossel	?üheksakorrossel =akorrosse  (SgAd  >üheks+akorrosne !02_A	et	f	\N
211532	üheksakorrossel	?üheksakorrossel =akorrosse  (PlAd  >üheks+akorross !22_S	et	f	\N
211533	üheksakorrossel	?üheksakorrossel =akorrossel  (SgN  >üheks+akorrossel !02_S	et	f	\N
211534	üheksakorrossel	?üheksakorrossel =ksakorrosse  (SgAd  >ühe+ksakorrosne !02_A	et	f	\N
211535	üheksakorrossel	?üheksakorrossel =ksakorrosse  (PlAd  >ühe+ksakorross !22_S	et	f	\N
211536	üheksakorrossel	?üheksakorrossel =ksakorrossel  (SgN  >ühe+ksakorrossel !02_S	et	f	\N
211538	classmsonormalspan	?classmsonormalspan =classmsonormalspan  (SgN  >classmsonormalspan !02_S	et	f	\N
211539	classmsobodytextspan	?classmsobodytextspan =classmsobodytextspan  (SgN  >classmsobodytextspan !02_S	et	f	\N
211549	lemmiktegevusp	?lemmiktegevusp =lemmiktegevusp  (SgN  >lemmiktegevusp !22_S	et	f	\N
211550	lemmiktegevusp	?lemmiktegevusp =usp  (SgN  >lemmik+tegev+usp !22_S	et	f	\N
211551	lemmiktegevusp	?lemmiktegevusp =tegevusp  (SgN  >lemmik+tegevusp !22_S	et	f	\N
211559	paevitamap	### paevitamap	et	f	\N
211568	kaske	kaske =kaske  (SgP  >kask !22_S	et	f	\N
211569	kaske	kaske =kaske  (SgAdt  >kask !22_S	et	f	\N
211570	kaske	kaske =kaske  (PlP  >kask !22_S	et	f	\N
211577	ebameeldivusi	ebameeldivusi =meeldivusi  (PlP  >eba+meeldivus !11_S	et	f	\N
211578	ebameeldivusi	"eba+meeldivus %meeldiva  )US_aS  <eba+meeldiv ;02_A	et	f	\N
211587	kunstigalerii	kunstigalerii =galerii  (SgN  >kunsti+galerii !26_S	et	f	\N
211588	kunstigalerii	kunstigalerii =galerii  (SgG  >kunsti+galerii !26_S	et	f	\N
211589	ilusane	?ilusane =ilusane  (SgN  >ilusane !12_A	et	f	\N
211590	ilusane	?ilusane =ilusane  (PlP  >ilusan !19_S	et	f	\N
211591	ilusane	?ilusane =sane  (SgN  >ilu+sane !16_S	et	f	\N
211592	ilusane	?ilusane =sane  (SgG  >ilu+sane !16_S	et	f	\N
211617	inglisekelt	inglisekelt =kelt  (SgN  >inglise+kelt !22_S	et	f	\N
211618	inglisekelt	inglisekelt =seke  (PlAbl  >ingli+sekk !22_S	et	f	\N
211655	seiping	?seiping =seiping  (SgN  >seiping !02_S	et	f	\N
211670	üheteistkümnes	?üheteistkümnes =üheteistkümne  (PlIn  >üheteistkümn !22_S	et	f	\N
211671	üheteistkümnes	?üheteistkümnes =kümne  (PlIn  >ühe+teist+kümn !22_S	et	f	\N
211672	üheteistkümnes	?üheteistkümnes =teistkümne  (PlIn  >ühe+teistkümn !22_S	et	f	\N
211716	suvelasse	suvelasse =la  (SgIll  >suve+la !26_S	et	f	\N
211717	suvelasse	suvelasse =lasse  (PlP  >suve+lass !22_S	et	f	\N
211734	kunstigaleri	kunstigaleri =eri  (SgN  >kunst+igal+eri !17_S	et	f	\N
211735	kunstigaleri	kunstigaleri =eri  (SgG  >kunst+igal+eri !17_S	et	f	\N
211736	kunstigaleri	kunstigaleri =eri  (SgP  >kunst+igal+eri !17_S	et	f	\N
211737	lihakombinati	?lihakombinati =lihakombinati  (SgG  >lihakombinatt !22_S	et	f	\N
211738	lihakombinati	?lihakombinati =lihakombinati  (IndPrPs_  >lihakombinattima !28_V	et	f	\N
211739	lihakombinati	?lihakombinati =lihakombinati  (ImpPrSg2  >lihakombinattima !28_V	et	f	\N
211740	lihakombinati	?lihakombinati =binati  (SgG  >liha+kom+binat !02_S	et	f	\N
211741	lihakombinati	?lihakombinati =binati  (SgG  >liha+kom+binatt !22_S	et	f	\N
211742	lihakombinati	?lihakombinati =kombinati  (SgG  >liha+kombinatt !22_S	et	f	\N
211747	toalille	toalille =lille  (SgG  >toa+lill !22_S	et	f	\N
211748	toalille	toalille =lille  (SgP  >toa+lill !22_S	et	f	\N
211749	toalille	toalille =lille  (SgAdt  >toa+lill !22_S	et	f	\N
211750	toalille	toalille =lille  (PlP  >toa+lill !22_S	et	f	\N
211765	suvikodu	suvikodu =kodu  (SgN  >suvi+kodu !17_S	et	f	\N
211766	suvikodu	suvikodu =kodu  (SgG  >suvi+kodu !17_S	et	f	\N
211767	suvikodu	suvikodu =kodu  (SgP  >suvi+kodu !17_S	et	f	\N
211782	narva-jõusel	?narva-jõusel =jõuse  (SgAd  >narva-jõuse !06_S	et	f	\N
211783	narva-jõusel	?narva-jõusel =jõusel  (SgN  >narva-jõusel !02_S	et	f	\N
211809	aasovi	?aasovi =aasovi  (ID  >aasovi !41_D	et	f	\N
211810	aasovi	?aasovi =aasovi  (SgG  >aasov !02_A	et	f	\N
211811	aasovi	?aasovi =ovi  (SgN  >aas+ovi !17_S	et	f	\N
211812	aasovi	?aasovi =ovi  (SgG  >aas+ovi !17_S	et	f	\N
211813	aasovi	?aasovi =ovi  (SgP  >aas+ovi !17_S	et	f	\N
211818	kastama	?kastama =kasta  (Sup  >kastama !29_V	et	f	\N
211819	kastama	?kastama =kastama  (SgG  >kastam !02_A	et	f	\N
211820	kastama	?kastama =ama  (SgN  >kast+ama !17_S	et	f	\N
211821	kastama	?kastama =ama  (SgG  >kast+ama !17_S	et	f	\N
211546	langetemmul	?langetemmul =temmu  (SgAd  >lange+temmu !16_S	et	f	\N
211547	langetemmul	?langetemmul =temmul  (SgN  >lange+temmul !02_S	et	f	\N
211555	puhkadp	?puhkadp =puhkadp  (SgN  >puhkadp !22_S	et	f	\N
211556	puhkadp	?puhkadp =adp  (SgN  >puhk+adp !22_S	et	f	\N
211572	lihavõtte	lihavõtte =võtte  (SgG  >liha+võte !06_S	et	f	\N
211573	lihavõtte	lihavõtte =võtte  (PlP  >liha+võtt !22_S	et	f	\N
211596	esmaspäeviti	?esmaspäeviti =esmaspäevi  (IndIpfIps  >esmaspäevima !28_V	et	f	\N
211598	esmaspäeviti	?esmaspäeviti =esmaspäeviti  (ID  >esmaspäeviti !41_D	et	f	\N
211600	esmaspäeviti	?esmaspäeviti =esmaspäeviti  (SgG  >esmaspäevitt !22_S	et	f	\N
211602	esmaspäeviti	?esmaspäeviti =esmaspäeviti  (IndPrPs_  >esmaspäevittima !28_V	et	f	\N
211604	esmaspäeviti	?esmaspäeviti =esmaspäeviti  (ImpPrSg2  >esmaspäevittima !28_V	et	f	\N
211606	esmaspäeviti	?esmaspäeviti =iti  (SgN  >esmas+päev+iti !16_S	et	f	\N
211608	esmaspäeviti	?esmaspäeviti =iti  (SgG  >esmas+päev+iti !16_S	et	f	\N
211610	esmaspäeviti	?esmaspäeviti =iti  (SgG  >esmas+päev+itt !22_S	et	f	\N
211611	esmaspäeviti	?esmaspäeviti =päeviti  (SgG  >esmas+päevit !02_S	et	f	\N
211612	esmaspäeviti	?esmaspäeviti =päeviti  (SgG  >esmas+päevitt !22_S	et	f	\N
211613	esmaspäeviti	?esmaspäeviti =späeviti  (SgG  >esma+späevit !02_S	et	f	\N
211614	esmaspäeviti	?esmaspäeviti =späeviti  (SgG  >esma+späevitt !22_S	et	f	\N
211629	kreenholm	?kreenholm =kreenholm  (SgN  >kreenholm !22_S	et	f	\N
211636	asubjoe	?asubjoe =asubjoe  (SgN  >asubjoe !26_S	et	f	\N
211637	asubjoe	?asubjoe =asubjoe  (SgG  >asubjoe !26_S	et	f	\N
211638	asubjoe	?asubjoe =bjoe  (SgN  >asu+bjoe !26_S	et	f	\N
211639	asubjoe	?asubjoe =bjoe  (SgG  >asu+bjoe !26_S	et	f	\N
211641	kuustigalerii	?kuustigalerii =kuustigalerii  (SgN  >kuustigalerii !26_S	et	f	\N
211643	kuustigalerii	?kuustigalerii =kuustigalerii  (SgG  >kuustigalerii !26_S	et	f	\N
211644	kuustigalerii	?kuustigalerii =tigalerii  (SgN  >kuus+tigalerii !26_S	et	f	\N
211646	kuustigalerii	?kuustigalerii =tigalerii  (SgG  >kuus+tigalerii !26_S	et	f	\N
211648	kuustigalerii	?kuustigalerii =stigalerii  (SgN  >kuu+stigalerii !26_S	et	f	\N
211650	kuustigalerii	?kuustigalerii =stigalerii  (SgG  >kuu+stigalerii !26_S	et	f	\N
211661	tikkida	tikkida =tikki  (Inf  >tikkima !28_V	et	f	\N
211662	tikkida	tikkida =ida  (SgN  >tikk+ida !17_S	et	f	\N
211663	tikkida	tikkida =ida  (SgG  >tikk+ida !17_S	et	f	\N
211664	tikkida	tikkida =ida  (SgP  >tikk+ida !17_S	et	f	\N
211665	fitnes	?fitnes =fitne  (PlIn  >fitn !22_S	et	f	\N
211666	fitnes	?fitnes =fitne  (IndIpfSg3  >fitnema !27_V	et	f	\N
211667	fitnes	?fitnes =fitnes  (SgN  >fitnes !09_S	et	f	\N
211686	toolilli	toolilli =lilli  (SgG  >too+lill !22_S	et	f	\N
211687	toolilli	toolilli =lilli  (SgP  >too+lill !22_S	et	f	\N
211688	toolilli	toolilli =lilli  (SgAdt  >too+lill !22_S	et	f	\N
211689	toolilli	toolilli =lilli  (PlP  >too+lill !22_S	et	f	\N
211690	hotellitenindajana	?hotellitenindajana =hotellitenindaja  (SgEs  >hotellitenindaja !01_S	et	f	\N
211691	hotellitenindajana	?hotellitenindajana =hotellitenindaja  (SgEs  >hotellitenindajas !02_A	et	f	\N
211692	hotellitenindajana	?hotellitenindajana =tenindaja  (SgEs  >hotelli+tenindaja !01_S	et	f	\N
211693	hotellitenindajana	?hotellitenindajana =tenindaja  (SgEs  >hotelli+tenindajas !02_A	et	f	\N
211710	päevetada	?päevetada =päeveta  (Inf  >päevetama !27_V	et	f	\N
211718	s-peterburis	?s-peterburis =peterburi  (SgIn  >s-peterbur !19_S	et	f	\N
211719	s-peterburis	?s-peterburis =peterburis  (SgN  >s-peterburis !09_S	et	f	\N
211720	telerik	?telerik =telerik  (SgN  >telerik !25_S	et	f	\N
211763	dushikabiin	?dushikabiin =dushikabiin  (SgN  >dushikabiin !22_S	et	f	\N
211772	õgi	õgi =õgi  (IndPrPs_  >õgima !27_V	et	f	\N
211773	õgi	õgi =õgi  (ImpPrSg2  >õgima !27_V	et	f	\N
211778	kolmetoalinekorter	?kolmetoalinekorter =kolmetoalinekorter  (SgN  >kolmetoalinekorter !02_S	et	f	\N
211779	kolmetoalinekorter	?kolmetoalinekorter =linekorter  (SgN  >kolme+toa+linekorter !02_S	et	f	\N
211780	kolmetoalinekorter	?kolmetoalinekorter =toalinekorter  (SgN  >kolme+toalinekorter !02_S	et	f	\N
211781	kolmetoalinekorter	?kolmetoalinekorter =etoalinekorter  (SgN  >kolm+etoalinekorter !02_S	et	f	\N
211791	sampo	?sampo =sampo  (SgN  >sampo !16_S	et	f	\N
211792	sampo	?sampo =sampo  (SgG  >sampo !16_S	et	f	\N
211797	konsultaandina	?konsultaandina =konsultaandi  (SgEs  >konsultaant !22_S	et	f	\N
211798	telikat	?telikat =telika  (SgP  >telika !01_S	et	f	\N
211799	telikat	?telikat =telika  (SgP  >telikas !02_S	et	f	\N
211800	suvelas	?suvelas =suvela  (SgIn  >suvela !01_S	et	f	\N
211829	vajanduse	?vajanduse =vajanduse  (SgG  >vajandus !11_S	et	f	\N
211834	vorstike	vorstike =vorstike  (SgN  >vorstike !12_S	et	f	\N
211835	vorstike	"vorstike %vorsti  )KE_dS  <vorst ;22_S	et	f	\N
211836	vorstike	vorstike =ike  (SgN  >vorst+ike !06_S	et	f	\N
211842	meilega	?meilega =meile  (SgKom  >meile !06_S	et	f	\N
211849	suustada	?suustada =suusta  (Inf  >suustama !27_V	et	f	\N
211850	suustada	?suustada =stada  (SgN  >suu+stada !17_S	et	f	\N
211851	suustada	?suustada =stada  (SgG  >suu+stada !17_S	et	f	\N
211852	suustada	?suustada =stada  (SgP  >suu+stada !17_S	et	f	\N
211868	äripäeva	äripäeva =päeva  (SgG  >äri+päev !22_S	et	f	\N
211870	äripäeva	äripäeva =päeva  (SgP  >äri+päev !22_S	et	f	\N
211557	classmsonormalispan	?classmsonormalispan =classmsonormalispan  (SgN  >classmsonormalispan !02_S	et	f	\N
211565	platsi	platsi =platsi  (SgG  >plats !22_S	et	f	\N
211566	platsi	platsi =platsi  (SgP  >plats !22_S	et	f	\N
211567	platsi	platsi =platsi  (SgAdt  >plats !22_S	et	f	\N
211619	kirde	kirde =kir  (SgAdt  >kirs !14_S	et	f	\N
211620	kirde	kirde =kirde  (SgG  >kirre !06_S	et	f	\N
211621	astri-narva	?astri-narva =narva  (SgN  >astri-narva !16_S	et	f	\N
211622	astri-narva	?astri-narva =narva  (SgG  >astri-narva !16_S	et	f	\N
211623	astri-narva	?astri-narva =narva  (IndPrPs_  >astri-narvama !29_V	et	f	\N
211624	astri-narva	?astri-narva =narva  (ImpPrSg2  >astri-narvama !29_V	et	f	\N
211630	meeldil	?meeldil =meeldi  (SgAd  >meelt !22_S	et	f	\N
211658	bastioni	bastioni =bastioni  (SgG  >bastion !19~02_S	et	f	\N
211659	bastioni	bastioni =bastioni  (SgP  >bastion !19_S	et	f	\N
211660	bastioni	bastioni =bastioni  (SgAdt  >bastion !19_S	et	f	\N
211668	roostee	roostee =tee  (SgN  >roos+tee !26_S	et	f	\N
211669	roostee	roostee =tee  (SgG  >roos+tee !26_S	et	f	\N
211673	kolmeteistkumnendal	?kolmeteistkumnendal =kolmeteistkumnenda  (SgAd  >kolmeteistkumnenda !16_S	et	f	\N
211674	kolmeteistkumnendal	?kolmeteistkumnendal =kolmeteistkumnendal  (SgN  >kolmeteistkumnendal !02_S	et	f	\N
211675	kolmeteistkumnendal	?kolmeteistkumnendal =kumnenda  (SgAd  >kolme+teist+kumnenda !01_S	et	f	\N
211676	kolmeteistkumnendal	?kolmeteistkumnendal =teistkumnenda  (SgAd  >kolme+teistkumnenda !16_S	et	f	\N
211677	kolmeteistkumnendal	?kolmeteistkumnendal =teistkumnendal  (SgN  >kolme+teistkumnendal !02_S	et	f	\N
211678	kolmeteistkumnendal	?kolmeteistkumnendal =eteistkumnenda  (SgAd  >kolm+eteistkumnenda !16_S	et	f	\N
211679	kolmeteistkumnendal	?kolmeteistkumnendal =eteistkumnendal  (SgN  >kolm+eteistkumnendal !02_S	et	f	\N
211701	lasteaegs	?lasteaegs =lasteaegs  (SgN  >lasteaegs !22_S	et	f	\N
211702	lasteaegs	?lasteaegs =aegs  (SgN  >laste+aegs !22_S	et	f	\N
211711	vestervalli	?vestervalli =vestervalli  (SgG  >vestervall !22_S	et	f	\N
211712	vestervalli	?vestervalli =vestervalli  (SgP  >vestervall !22_S	et	f	\N
211713	vestervalli	?vestervalli =vestervalli  (SgAdt  >vestervall !22_S	et	f	\N
211714	vestervalli	?vestervalli =vestervalli  (IndPrPs_  >vestervallima !28_V	et	f	\N
211715	vestervalli	?vestervalli =vestervalli  (ImpPrSg2  >vestervallima !28_V	et	f	\N
211729	bastioonid	?bastioonid =bastiooni  (PlN  >bastiooni !16_S	et	f	\N
211731	bastioonid	?bastioonid =bastiooni  (PlN  >bastioon !22_S	et	f	\N
211732	bastioonid	?bastioonid =bastiooni  (IndPrSg2  >bastioonima !28_V	et	f	\N
211758	heele	?heele =heele  (SgN  >heele !06_S	et	f	\N
211759	heele	?heele =heele  (SgG  >heele !06_S	et	f	\N
211760	heele	?heele =heele  (PlP  >heel !22_S	et	f	\N
211761	heele	?heele =heele  (IndPrPs_  >heelema !27_V	et	f	\N
211762	heele	?heele =heele  (ImpPrSg2  >heelema !27_V	et	f	\N
211768	nelikorruselises	nelikorruselises =korruselise  (SgIn  >neli+korruseline !12_A	et	f	\N
211769	nelikorruselises	"neli+korruseline %korruse  )LINE_aA  <neli+korrus ;09_S	et	f	\N
211770	rajajoonis	rajajoonis =jooni  (PlIn  >raja+joon !13_S	et	f	\N
211771	rajajoonis	rajajoonis =joonis  (SgN  >raja+joonis !09_S	et	f	\N
211774	tugevused	tugevused =tugevuse  (PlN  >tugevus !11_S	et	f	\N
211775	tugevused	"tugevus %tuge  )VUS_aS  <tugema ;27_V	et	f	\N
211776	tugevused	"tugevus %tugeva  )US_aS  <tugev ;02_A	et	f	\N
211777	tugevused	tugevused =tugevuse  (PlN  >tugevune !12_A	et	f	\N
211784	suvekodu	suvekodu =kodu  (SgN  >suve+kodu !17_S	et	f	\N
211785	suvekodu	suvekodu =kodu  (SgG  >suve+kodu !17_S	et	f	\N
211786	suvekodu	suvekodu =kodu  (SgP  >suve+kodu !17_S	et	f	\N
211803	suuvilas	?suuvilas =suuvila  (SgIn  >suuvila !01_S	et	f	\N
211804	suuvilas	?suuvilas =vila  (SgIn  >suu+vila !17_S	et	f	\N
211805	suuvilas	?suuvilas =vilas  (SgN  >suu+vilas !09_S	et	f	\N
211830	ametiasutustes	ametiasutustes =tuste  (PlIn  >ameti+asu+tust !22_S	et	f	\N
211831	ametiasutustes	ametiasutustes =asutus  (PlIn  >ameti+asutus !11_S	et	f	\N
211832	ametiasutustes	"ameti+asutus %asu  )TUS2_aS  <ameti+asu ;17_S	et	f	\N
211843	looseni	?looseni =loose  (SgTer  >loose !06_S	et	f	\N
211844	looseni	?looseni =looseni  (SgG  >loosen !02_S	et	f	\N
211858	rippuvad	rippuvad =rippuva  (PlN  >rippuv !02_A	et	f	\N
211859	rippuvad	"rippuv %rippu  )V_vA  <rippuma ;28_V	et	f	\N
211860	kastaanid	?kastaanid =kastaani  (PlN  >kastaani !16_S	et	f	\N
211861	kastaanid	?kastaanid =kastaani  (PlN  >kastaan !22_S	et	f	\N
211862	kastaanid	?kastaanid =kastaani  (IndPrSg2  >kastaanima !28_V	et	f	\N
211863	kastaanid	?kastaanid =aani  (PlN  >kast+aani !16_S	et	f	\N
211864	kastaanid	?kastaanid =aani  (PlN  >kast+aan !22_S	et	f	\N
211865	kastaanid	?kastaanid =taani  (PlN  >kas+taani !16_S	et	f	\N
211866	kastaanid	?kastaanid =taani  (PlN  >kas+taan !22_S	et	f	\N
211873	vedomosti	?vedomosti =vedomosti  (ID  >vedomosti !41_D	et	f	\N
211874	vedomosti	?vedomosti =vedomosti  (IndPrPs_  >vedomostima !28_V	et	f	\N
211875	vedomosti	?vedomosti =vedomosti  (ImpPrSg2  >vedomostima !28_V	et	f	\N
211880	viiskumne	?viiskumne =viiskumne  (SgN  >viiskumne !02_A	et	f	\N
211881	viiskumne	?viiskumne =viiskumne  (PlP  >viiskumn !22_S	et	f	\N
211882	viiskumne	?viiskumne =kumne  (SgN  >viis+kumne !02_A	et	f	\N
211883	viiskumne	?viiskumne =kumne  (PlP  >viis+kumn !22_S	et	f	\N
211634	lemmiklinnast	lemmiklinnast =linnas  (SgP  >lemmik+linnane !10_A	et	f	\N
211635	lemmiklinnast	"lemmik+linnane %linna  )NE_aA  <lemmik+linn ;22_S	et	f	\N
211651	monumentit	### monumentit	et	f	\N
211652	lauldab	?lauldab =laulda  (IndPrSg3  >lauldama !27_V	et	f	\N
211656	glooria	glooria =glooria  (SgN  >glooria !01_S	et	f	\N
211657	glooria	glooria =glooria  (SgG  >glooria !01_S	et	f	\N
211680	natuki	?natuki =natuki  (SgN  >natuki !01_S	et	f	\N
211681	natuki	?natuki =natuki  (SgG  >natuki !01_S	et	f	\N
211682	natuki	?natuki =natuki  (SgG  >natuk !02_S	et	f	\N
211683	natuki	?natuki =natuki  (SgG  >natukk !22_S	et	f	\N
211684	natuki	?natuki =natuki  (IndPrPs_  >natukkima !28_V	et	f	\N
211685	natuki	?natuki =natuki  (ImpPrSg2  >natukkima !28_V	et	f	\N
211696	limmiktegevus	?limmiktegevus =limmiktegevu  (IndIpfSg3  >limmiktegevuma !27_V	et	f	\N
211697	limmiktegevus	?limmiktegevus =limmiktegevus  (SgN  >limmiktegevus !11?09_S	et	f	\N
211698	energijas	?energijas =energija  (SgIn  >energija !01_S	et	f	\N
211699	energijas	?energijas =energija  (SgIn  >energijas !02_A	et	f	\N
211700	energijas	?energijas =energijas  (SgN  >energijas !02_A	et	f	\N
211721	jalatada	?jalatada =jalata  (Inf  >jalatama !27_V	et	f	\N
211722	jalatada	?jalatada =tada  (SgN  >jala+tada !17_S	et	f	\N
211723	jalatada	?jalatada =tada  (SgG  >jala+tada !17_S	et	f	\N
211724	jalatada	?jalatada =tada  (SgP  >jala+tada !17_S	et	f	\N
211725	jola-virumaa	jola-virumaa =maa  (SgN  >jola-viru+maa !26_S	et	f	\N
211726	jola-virumaa	jola-virumaa =maa  (SgG  >jola-viru+maa !26_S	et	f	\N
211730	veehoidla	veehoidla =hoidla  (SgN  >vee+hoidla !01_S	et	f	\N
211733	veehoidla	veehoidla =hoidla  (SgG  >vee+hoidla !01_S	et	f	\N
211743	vestlime	?vestlime =vestli  (IndPrPl1  >vestlima !28_V	et	f	\N
211744	s-peterburgis	?s-peterburgis =peterburgi  (SgIn  >s-peterburk !22_S	et	f	\N
211745	s-peterburgis	?s-peterburgis =peterburgi  (IndIpfSg3  >s-peterburgima !28_V	et	f	\N
211746	s-peterburgis	?s-peterburgis =peterburgis  (SgN  >s-peterburgis !09_S	et	f	\N
211801	konstebel	?konstebel =konstebel  (SgN  >konstebel !19_S	et	f	\N
211814	võtama	?võtama =võta  (Sup  >võtama !27_V	et	f	\N
211815	võtama	?võtama =võtama  (SgG  >võtam !02_A	et	f	\N
211837	lõunalaud	lõunalaud =lau  (PlN  >lõuna+laug !22_SA	et	f	\N
211838	lõunalaud	lõunalaud =laud  (SgN  >lõuna+laud !22_S	et	f	\N
211869	delovõe	?delovõe =delovõe  (SgN  >delovõe !26_S	et	f	\N
211871	delovõe	?delovõe =delovõe  (SgG  >delovõe !26_S	et	f	\N
211877	stpeterburgis	?stpeterburgis =stpeterburgi  (SgIn  >stpeterburk !22_S	et	f	\N
211878	stpeterburgis	?stpeterburgis =stpeterburgi  (IndIpfSg3  >stpeterburgima !28_V	et	f	\N
211879	stpeterburgis	?stpeterburgis =stpeterburgis  (SgN  >stpeterburgis !09_S	et	f	\N
211902	kunstimuuseumi	kunstimuuseumi =muuseumi  (SgG  >kunsti+muuseum !19~02_S	et	f	\N
211903	kunstimuuseumi	kunstimuuseumi =muuseumi  (SgP  >kunsti+muuseum !19_S	et	f	\N
211904	kunstimuuseumi	kunstimuuseumi =muuseumi  (SgAdt  >kunsti+muuseum !19_S	et	f	\N
211916	piildid	?piildid =piildi  (PlN  >piilt !22_S	et	f	\N
211917	piildid	?piildid =piildi  (IndPrSg2  >piiltima !28_V	et	f	\N
211932	sõitsib	?sõitsib =sõitsi  (IndPrSg3  >sõitsima !28_V	et	f	\N
211934	kiikil	### kiikil	et	f	\N
211946	teenindaja	teenindaja =teenindaja  (SgN  >teenindaja !01_S	et	f	\N
211947	teenindaja	"teenindaja %teeninda  )JA_vS  <teenindama ;27_V	et	f	\N
211948	teenindaja	teenindaja =teenindaja  (SgG  >teenindaja !01_S	et	f	\N
211967	ettevõttealuseid	ettevõttealuseid =aluse  (PlP  >ette+võtte+alus !09_S	et	f	\N
211968	ettevõttealuseid	ettevõttealuseid =aluse  (PlP  >ette+võtte+alune !10_AS	et	f	\N
211969	ettevõttealuseid	"ette+võtte+alune %alu  )NE_aA  <ette+võtte+alg ;22_S	et	f	\N
212003	ilustratsioonid	?ilustratsioonid =ilustratsiooni  (PlN  >ilustratsiooni !16_S	et	f	\N
212004	ilustratsioonid	?ilustratsioonid =ilustratsiooni  (PlN  >ilustratsioon !22_S	et	f	\N
212005	ilustratsioonid	?ilustratsioonid =ilustratsiooni  (IndPrSg2  >ilustratsioonima !28_V	et	f	\N
212006	ilustratsioonid	?ilustratsioonid =stratsiooni  (PlN  >ilu+stratsiooni !16_S	et	f	\N
212007	ilustratsioonid	?ilustratsioonid =stratsiooni  (PlN  >ilu+stratsioon !22_S	et	f	\N
212008	eksemplarit	?eksemplarit =emplari  (SgP  >eks+emplari !01_S	et	f	\N
212009	eksemplarit	?eksemplarit =emplari  (SgP  >eks+emplar !02_S	et	f	\N
212025	suurbritaaniast	?suurbritaaniast =suurbritaania  (SgEl  >suurbritaania !01_S	et	f	\N
212026	suurbritaaniast	?suurbritaaniast =suurbritaanias  (SgP  >suurbritaanias !11_S	et	f	\N
212027	suurbritaaniast	?suurbritaaniast =britaania  (SgEl  >suur+britaania !01_S	et	f	\N
212028	suurbritaaniast	?suurbritaaniast =britaanias  (SgP  >suur+britaanias !11_S	et	f	\N
212037	vaiksooga	vaiksooga =soo  (SgKom  >vaik+sugu !18_S	et	f	\N
212038	vaiksooga	vaiksooga =soo  (SgKom  >vaik+soo !26_S	et	f	\N
212065	kommenteeritud	kommenteeritud =kommenteeri  (PtsPtIps  >kommenteerima !28_V	et	f	\N
212066	kommenteeritud	kommenteeritud =kommenteeritu  (PlN  >kommenteeritu !01_S	et	f	\N
212067	kommenteeritud	"kommenteeritu %kommenteeri  )TU1_vS  <kommenteerima ;28_V	et	f	\N
212068	kommenteeritud	kommenteeritud =kommenteeritud  (ID  >kommenteeritud !41_A	et	f	\N
212069	kommenteeritud	"kommenteeritud %kommenteeri  )TUD_vA  <kommenteerima ;28_V	et	f	\N
212078	artiklides	?artiklides =artikli  (PlIn  >artikel !19_S	et	f	\N
211757	viiekümnendas	?viiekümnendas =kümnenda  (SgIn  >viie+kümnenda !01_S	et	f	\N
211764	pesimasin	?pesimasin =pesimasin  (SgN  >pesimasin !19_S	et	f	\N
211787	telliskivimajas	telliskivimajas =aja  (SgIn  >tellis+kivim+aeg !22_S	et	f	\N
211788	telliskivimajas	telliskivimajas =maja  (SgIn  >tellis+kivi+maja !17_S	et	f	\N
211789	siimani	?siimani =siima  (SgTer  >siima !16_S	et	f	\N
211790	siimani	?siimani =siimani  (SgG  >siiman !02_S	et	f	\N
211793	ruuttmeetrit	?ruuttmeetrit =ruuttmeetri  (SgP  >ruuttmeetri !01_S	et	f	\N
211794	ruuttmeetrit	?ruuttmeetrit =ruuttmeetri  (SgP  >ruuttmeeter !02_S	et	f	\N
211795	puudega	puudega =puu  (PlKom  >puu !26_S	et	f	\N
211796	puudega	puudega =puude  (SgKom  >puue !06_S	et	f	\N
211802	elegaantne	?elegaantne =elegaantne  (SgN  >elegaantne !02_A	et	f	\N
211806	kudumine	kudumine =kudumine  (SgN  >kudumine !12_S	et	f	\N
211807	kudumine	"kudumine %kudu  )MINE_vS  <kuduma ;28_V	et	f	\N
211808	kudumine	"kudumine %kudumi  )NE_aA  <kudum ;02_S	et	f	\N
211816	triigima	?triigima =triigi  (Sup  >triigima !28_V	et	f	\N
211817	triigima	?triigima =triigima  (SgG  >triigim !02_A	et	f	\N
211833	praadime	?praadime =praadi  (IndPrPl1  >praatima !28_V	et	f	\N
211839	seksioonikapp	?seksioonikapp =seksioonikapp  (SgN  >seksioonikapp !22_S	et	f	\N
211840	seksioonikapp	?seksioonikapp =oonikapp  (SgN  >seksi+oonikapp !22_S	et	f	\N
211841	seksioonikapp	?seksioonikapp =ioonikapp  (SgN  >seks+ioonikapp !22_S	et	f	\N
211845	jaanilinnas	jaanilinnas =linna  (SgIn  >jaani+linn !22_S	et	f	\N
211846	jaanilinnas	jaanilinnas =linnas  (SgN  >jaani+linnas !09_S	et	f	\N
211847	jõges	?jõges =jõge  (IndIpfSg3  >jõgema !27_V	et	f	\N
211848	jõges	?jõges =jõges  (SgN  >jõges !09_S	et	f	\N
211853	uistada	?uistada =uista  (Inf  >uistama !27_V	et	f	\N
211854	vaabrikus	?vaabrikus =vaabriku  (SgIn  >vaabrik !25_S	et	f	\N
211855	vaabrikus	?vaabrikus =vaabriku  (SgIn  >vaabriku !01_S	et	f	\N
211856	vaabrikus	?vaabrikus =vaabriku  (IndIpfSg3  >vaabrikuma !27_V	et	f	\N
211857	vaabrikus	?vaabrikus =vaabrikus  (SgN  >vaabrikus !11_S	et	f	\N
211867	aleksej	### aleksej	et	f	\N
211889	mittetraditsiooniline	mittetraditsiooniline =traditsiooniline  (SgN  >mitte+traditsiooniline !12_A	et	f	\N
211890	mittetraditsiooniline	"mitte+traditsiooniline %traditsiooni  )LINE_aA  <mitte+traditsioon ;22_S	et	f	\N
211900	narvat	?narvat =narva  (SgP  >narva !16_S	et	f	\N
211901	narvat	?narvat =narvat  (SgN  >narvat !02_S	et	f	\N
211913	forelli	forelli =forelli  (SgG  >forell !22_S	et	f	\N
211914	forelli	forelli =forelli  (SgP  >forell !22_S	et	f	\N
211915	forelli	forelli =forelli  (SgAdt  >forell !22_S	et	f	\N
211918	iidned	?iidned =iidne  (IndPrSg2  >iidnema !27_V	et	f	\N
211926	teesid	teesid =tee  (PlP  >tee !26_S	et	f	\N
211927	teesid	teesid =teesi  (PlN  >tees !22_S	et	f	\N
211928	tumeaes	?tumeaes =tumeae  (SgIn  >tumeae !26_S	et	f	\N
211929	tumeaes	?tumeaes =tumeaes  (SgN  >tumeaes !22_S	et	f	\N
211930	tumeaes	?tumeaes =aes  (SgN  >tume+aes !09_S	et	f	\N
211935	veerema	veerema =veere  (Sup  >veerema !28_V	et	f	\N
211936	veerema	veerema =veerema  (SgG  >veerem !02_S	et	f	\N
211937	veerema	veerema =ema  (SgN  >veer+ema !17_S	et	f	\N
211938	veerema	veerema =ema  (SgG  >veer+ema !17_S	et	f	\N
211939	veerema	veerema =ema  (SgP  >veer+ema !17_S	et	f	\N
211952	esmaabit	?esmaabit =esmaabi  (SgP  >esmaabi !16_S	et	f	\N
211953	esmaabit	?esmaabit =abit  (SgN  >esma+abit !02_S	et	f	\N
211973	aidu	aidu =aidu  (SgN  >aidu !01_S	et	f	\N
211974	aidu	aidu =aidu  (SgG  >aidu !01_S	et	f	\N
211985	eksamenisse	?eksamenisse =eksameni  (SgIll  >eksamen !19_S	et	f	\N
211986	eksamenisse	?eksamenisse =eksamenisse  (SgG  >eksamenisne !02_A	et	f	\N
211987	eksamenisse	?eksamenisse =eksamenisse  (PlP  >eksameniss !22_S	et	f	\N
211988	eksamenisse	?eksamenisse =ameni  (SgIll  >eks+amen !02_S	et	f	\N
211989	eksamenisse	?eksamenisse =amenis  (SgAdt  >eks+amenis !11_S	et	f	\N
211990	eksamenisse	?eksamenisse =amenisse  (SgG  >eks+amenisne !02_A	et	f	\N
211991	eksamenisse	?eksamenisse =amenisse  (PlP  >eks+ameniss !22_S	et	f	\N
211994	sühtlema	?sühtlema =sühtle  (Sup  >sühtlema !30_V	et	f	\N
211995	sühtlema	?sühtlema =sühtlema  (SgG  >sühtlem !02_A	et	f	\N
211996	huvieesti	?huvieesti =huvieesti  (ID  >huvieesti !41_D	et	f	\N
211997	huvieesti	?huvieesti =huvieesti  (IndPrPs_  >huvieestima !28_V	et	f	\N
211998	huvieesti	?huvieesti =huvieesti  (ImpPrSg2  >huvieestima !28_V	et	f	\N
212002	liigendusvõtted	### liigendusvõtted	et	f	\N
212010	autokaitserauda	autokaitserauda =rauda  (SgP  >auto+kaitse+raud !22_S	et	f	\N
212011	autokaitserauda	autokaitserauda =rauda  (SgAdt  >auto+kaitse+raud !22_S	et	f	\N
212017	peksid	peksid =peks  (IndIpfSg2  >peksma !32_V	et	f	\N
212018	peksid	peksid =peks  (IndIpfPl3  >peksma !32_V	et	f	\N
212019	peksid	peksid =peksi  (PlN  >peks !22_S	et	f	\N
212023	rubriigidesei	?rubriigidesei =rubriigidesei  (SgN  >rubriigidesei !26_S	et	f	\N
212024	rubriigidesei	?rubriigidesei =rubriigidesei  (SgG  >rubriigidesei !26_S	et	f	\N
212041	televisooris	?televisooris =televisoori  (SgIn  >televisoori !16_S	et	f	\N
212042	televisooris	?televisooris =televisoori  (SgIn  >televisoor !22_S	et	f	\N
212043	televisooris	?televisooris =televisoori  (IndIpfSg3  >televisoorima !28_V	et	f	\N
211822	kastama	?kastama =ama  (SgP  >kast+ama !17_S	et	f	\N
211823	kastama	?kastama =tama  (SgN  >kas+tama !17_S	et	f	\N
211824	kastama	?kastama =tama  (SgG  >kas+tama !17_S	et	f	\N
211825	kastama	?kastama =tama  (SgP  >kas+tama !17_S	et	f	\N
211826	korteriüüri	korteriüüri =üüri  (SgG  >korteri+üür !22_S	et	f	\N
211827	korteriüüri	korteriüüri =üüri  (SgP  >korteri+üür !22_S	et	f	\N
211828	korteriüüri	korteriüüri =üüri  (SgAdt  >korteri+üür !22_S	et	f	\N
211876	prognoosit	?prognoosit =prognoosi  (SgP  >prognoosi !16_S	et	f	\N
211886	igor	?igor =igor  (SgN  >igor !02_S	et	f	\N
211891	kasesalu	kasesalu =salu  (SgN  >kase+salu !17_S	et	f	\N
211892	kasesalu	kasesalu =salu  (SgG  >kase+salu !17_S	et	f	\N
211893	kasesalu	kasesalu =salu  (SgP  >kase+salu !17_S	et	f	\N
211896	peipsijarv	?peipsijarv =peipsijarv  (SgN  >peipsijarv !22_S	et	f	\N
211897	peipsijarv	?peipsijarv =jarv  (SgN  >peipsi+jarv !22_S	et	f	\N
211898	pühapäevasse	pühapäevasse =asse  (PlP  >püha+päev+ass !22_S	et	f	\N
211899	pühapäevasse	pühapäevasse =päeva  (SgIll  >püha+päev !22_S	et	f	\N
211910	puhketsooni	puhketsooni =tsooni  (SgG  >puhke+tsoon !22_S	et	f	\N
211911	puhketsooni	puhketsooni =tsooni  (SgP  >puhke+tsoon !22_S	et	f	\N
211912	puhketsooni	puhketsooni =tsooni  (SgAdt  >puhke+tsoon !22_S	et	f	\N
211919	skuulptuurid	?skuulptuurid =skuulptuuri  (PlN  >skuulptuuri !16_S	et	f	\N
211920	skuulptuurid	?skuulptuurid =skuulptuuri  (PlN  >skuulptuur !22_S	et	f	\N
211921	skuulptuurid	?skuulptuurid =skuulptuuri  (IndPrSg2  >skuulptuurima !28_V	et	f	\N
211957	asjajamist	?asjajamist =asjajami  (SgEl  >asjajam !02_A	et	f	\N
211958	asjajamist	?asjajamist =asjajamis  (SgP  >asjajamis !09_S	et	f	\N
211959	asjajamist	?asjajamist =asjajamis  (SgP  >asjajamine !12_S	et	f	\N
211960	asjajamist	?asjajamist =asjajamist  (SgN  >asjajamist !22_S	et	f	\N
211961	asjajamist	?asjajamist =jami  (SgEl  >asja+jami !17_S	et	f	\N
211962	asjajamist	?asjajamist =jamis  (SgP  >asja+jamis !09_S	et	f	\N
211963	asjajamist	?asjajamist =jamis  (SgP  >asja+jamine !10_A	et	f	\N
211964	asjajamist	?asjajamist =jamist  (SgN  >asja+jamist !22_S	et	f	\N
211978	sühtlime	?sühtlime =sühtli  (IndPrPl1  >sühtlima !28_V	et	f	\N
211992	lõppetavav	?lõppetavav =lõppetavav  (SgN  >lõppetavav !02_A	et	f	\N
211993	lõppetavav	?lõppetavav =etavav  (SgN  >lõpp+etavav !02_A	et	f	\N
211999	sl	### sl	et	f	\N
212012	enneolematu	enneolematu =olematu  (SgN  >enne+olematu !01_A	et	f	\N
212013	enneolematu	"enne+olematu %olema  )TU2_kA  <enne+olem ;02_S	et	f	\N
212014	enneolematu	enneolematu =olematu  (SgG  >enne+olematu !01_A	et	f	\N
212020	sandiks	sandiks =sandi  (SgTr  >sand !22_S	et	f	\N
212021	sandiks	sandiks =sandi  (SgTr  >sant !22_SA	et	f	\N
212022	sandiks	sandiks =sandi  (KndPrPs  >santima !28_V	et	f	\N
212029	hiinast	?hiinast =hiina  (SgEl  >hiina !16_S	et	f	\N
212030	hiinast	?hiinast =hiinas  (SgP  >hiinas !07_S	et	f	\N
212031	hiinast	?hiinast =hiinas  (SgP  >hiinane !10_A	et	f	\N
212054	isagi	isagi =isa  (SgN^  >isa !17_S	et	f	\N
212055	isagi	isagi =isa  (SgG^  >isa !17_S	et	f	\N
212056	isagi	isagi =isa  (SgP^  >isa !17_S	et	f	\N
212057	infograafika	infograafika =graafika  (SgN  >info+graafika !01_S	et	f	\N
212058	infograafika	infograafika =graafika  (SgG  >info+graafika !01_S	et	f	\N
212083	jaganud	jaganud =jaga  (PtsPtPs  >jagama !27_V	et	f	\N
212084	jaganud	jaganud =jaganu  (PlN  >jaganu !01_S	et	f	\N
212085	jaganud	"jaganu %jaga  )NU_vS  <jagama ;27_V	et	f	\N
212086	jaganud	jaganud =jaganud  (ID  >jaganud !41_A	et	f	\N
212087	jaganud	"jaganud %jaga  )NUD_vA  <jagama ;27_V	et	f	\N
212088	pealdisid	?pealdisid =pealdi  (PlP  >peald !22_S	et	f	\N
212089	pealdisid	?pealdisid =pealdi  (IndIpfSg2  >pealdima !28_V	et	f	\N
212090	pealdisid	?pealdisid =pealdi  (IndIpfPl3  >pealdima !28_V	et	f	\N
212091	pealdisid	?pealdisid =disi  (PlN  >peal+disi !17_S	et	f	\N
212118	maimikale	?maimikale =maimika  (SgAll  >maimika !01_S	et	f	\N
212119	maimikale	?maimikale =maimika  (SgAll  >maimikas !02_S	et	f	\N
212120	maimikale	?maimikale =maimikale  (PlP  >maimikal !19_S	et	f	\N
212121	maimikale	?maimikale =mika  (SgAll  >mai+mika !16_S	et	f	\N
212134	puhkepäeva	puhkepäeva =päeva  (SgG  >puhke+päev !22_S	et	f	\N
212135	puhkepäeva	puhkepäeva =päeva  (SgP  >puhke+päev !22_S	et	f	\N
212136	puhkepäeva	puhkepäeva =päeva  (SgAdt  >puhke+päev !22_S	et	f	\N
212161	joondega	### joondega	et	f	\N
212170	kitjaks	?kitjaks =kitja  (SgTr  >kitja !01_S	et	f	\N
212171	kitjaks	?kitjaks =kitja  (SgTr  >kitjas !02_A	et	f	\N
212172	kitjaks	?kitjaks =kitja  (KndPrPs  >kitjama !29_V	et	f	\N
212174	kirjasuurused	kirjasuurused =suuruse  (PlN  >kirja+suurus !11~09_S	et	f	\N
212175	kirjasuurused	"kirja+suurus %suur  )US_aS  <kirja+suur ;13_A	et	f	\N
212176	kirjasuurused	kirjasuurused =suuruse  (PlN  >kirja+suurune !10~12_A	et	f	\N
212199	kitsendanud	kitsendanud =kitsenda  (PtsPtPs  >kitsendama !27_V	et	f	\N
212200	kitsendanud	kitsendanud =kitsendanu  (PlN  >kitsendanu !01_S	et	f	\N
212201	kitsendanud	"kitsendanu %kitsenda  )NU_vS  <kitsendama ;27_V	et	f	\N
212202	kitsendanud	kitsendanud =kitsendanud  (ID  >kitsendanud !41_A	et	f	\N
212203	kitsendanud	"kitsendanud %kitsenda  )NUD_vA  <kitsendama ;27_V	et	f	\N
211872	äripäeva	äripäeva =päeva  (SgAdt  >äri+päev !22_S	et	f	\N
211908	ümbruskonda	ümbruskonda =ümbruskonda  (SgP  >ümbruskond !22_S	et	f	\N
211909	ümbruskonda	ümbruskonda =ümbruskonda  (SgAdt  >ümbruskond !22_S	et	f	\N
211922	hermanikindlus	?hermanikindlus =hermanikindlu  (IndIpfSg3  >hermanikindluma !27_V	et	f	\N
211923	hermanikindlus	?hermanikindlus =hermanikindlus  (SgN  >hermanikindlus !11~09_S	et	f	\N
211924	hermanikindlus	?hermanikindlus =nikindlu  (SgIn  >herma+nikindlu !01_S	et	f	\N
211925	hermanikindlus	?hermanikindlus =nikindlus  (SgN  >herma+nikindlus !11~09_S	et	f	\N
211942	uiutasime	?uiutasime =uiuta  (IndIpfPl1  >uiutama !27_V	et	f	\N
211954	müüki	müüki =müüki  (SgP  >müük !22_S	et	f	\N
211955	müüki	müüki =müüki  (SgAdt  >müük !22_S	et	f	\N
211970	aluseid	aluseid =aluse  (PlP  >alus !09_S	et	f	\N
211971	aluseid	aluseid =aluse  (PlP  >alune !10_AS	et	f	\N
211972	aluseid	"alune %alu  )NE_aA  <alg ;22_S	et	f	\N
211981	esmaabijat	?esmaabijat =esmaabija  (SgP  >esmaabija !01_S	et	f	\N
211982	esmaabijat	?esmaabijat =esmaabija  (SgP  >esmaabijas !02_A	et	f	\N
211983	esmaabijat	?esmaabijat =abija  (SgP  >esma+abija !01_S	et	f	\N
211984	esmaabijat	?esmaabijat =abija  (SgP  >esma+abijas !02_A	et	f	\N
212000	veerupikkus	veerupikkus =pikkus  (SgN  >veeru+pikkus !11~09_S	et	f	\N
212001	veerupikkus	"veeru+pikkus %pikk  )US_aS  <veeru+pikk ;22_AS	et	f	\N
212034	anntud	?anntud =anntu  (PlN  >anntu !01_S	et	f	\N
212035	anntud	?anntud =anntu  (IndPrSg2  >anntuma !27_V	et	f	\N
212036	anntud	?anntud =anntud  (ID  >anntud !41_A	et	f	\N
212051	edasipärast	edasipärast =pära  (SgEl  >edasi+pära !17_S	et	f	\N
212052	edasipärast	edasipärast =päras  (SgP  >edasi+pärane !10_A	et	f	\N
212053	edasipärast	"edasi+pärane %pära  )NE_aA  <edasi+pära ;17_S	et	f	\N
212062	lugemisele	lugemisele =lugemise  (SgAll  >lugemine !12_S	et	f	\N
212063	lugemisele	"lugemine %luge  )MINE_vS  <lugema ;28_V	et	f	\N
212064	lugemisele	"lugemine %lugemi  )NE_aA  <lugem ;02_S	et	f	\N
212080	ebaühtlaseltveerupikkus	?ebaühtlaseltveerupikkus =ebaühtlaseltveerupikku  (IndIpfSg3  >ebaühtlaseltveerupikkuma !27_V	et	f	\N
212081	ebaühtlaseltveerupikkus	?ebaühtlaseltveerupikkus =ebaühtlaseltveerupikkus  (SgN  >ebaühtlaseltveerupikkus !11~09_S	et	f	\N
212082	ebaühtlaseltveerupikkus	?ebaühtlaseltveerupikkus =ühtlaseltveerupikkus  (SgN  >eba+ühtlaseltveerupikkus !11~09_S	et	f	\N
212100	ülesvõtnud	ülesvõtnud =võt  (PtsPtPs  >üles+_võtma !35_V	et	f	\N
212101	ülesvõtnud	ülesvõtnud =võtnu  (PlN  >üles+võtnu !01_S	et	f	\N
212110	lühiinfo	lühiinfo =info  (SgN  >lühi+info !16_S	et	f	\N
212111	lühiinfo	lühiinfo =info  (SgG  >lühi+info !16_S	et	f	\N
212114	rain	?rain =rain  (SgN  >rain !22_S	et	f	\N
212141	veerusepikkus	?veerusepikkus =veerusepikku  (IndIpfSg3  >veerusepikkuma !27_V	et	f	\N
212142	veerusepikkus	?veerusepikkus =veerusepikkus  (SgN  >veerusepikkus !11~09_S	et	f	\N
212143	veerusepikkus	?veerusepikkus =sepikku  (SgIn  >veeru+sepikku !01_S	et	f	\N
212144	veerusepikkus	?veerusepikkus =sepikkus  (SgN  >veeru+sepikkus !11~09_S	et	f	\N
212145	veerusepikkus	?veerusepikkus =usepikkus  (SgN  >veer+usepikkus !11~09_S	et	f	\N
212146	veerusepikkus	?veerusepikkus =rusepikkus  (SgN  >vee+rusepikkus !11~09_S	et	f	\N
212164	silmatorkav	silmatorkav =torka  (PtsPrPs  >silma+_torkama !29_V	et	f	\N
212165	silmatorkav	silmatorkav =torkav  (SgN  >silma+torkav !02_A	et	f	\N
212186	veerusjaotus	?veerusjaotus =veerusjaotu  (SgIn  >veerusjaotu !01_A	et	f	\N
212187	veerusjaotus	?veerusjaotus =veerusjaotu  (IndIpfSg3  >veerusjaotuma !27_V	et	f	\N
212188	veerusjaotus	?veerusjaotus =veerusjaotus  (SgN  >veerusjaotus !11~09_S	et	f	\N
212189	veerusjaotus	?veerusjaotus =usjaotu  (SgIn  >veer+usjaotu !01_A	et	f	\N
212190	veerusjaotus	?veerusjaotus =usjaotus  (SgN  >veer+usjaotus !11_S	et	f	\N
212191	veerusjaotus	?veerusjaotus =rusjaotu  (SgIn  >vee+rusjaotu !01_A	et	f	\N
212192	veerusjaotus	?veerusjaotus =rusjaotus  (SgN  >vee+rusjaotus !11_S	et	f	\N
212193	hallide	hallide =halli  (PlG  >hall !22_S	et	f	\N
212194	hallide	hallide =halli  (PlG  >hall !22_AS	et	f	\N
212197	pakkuvatest	pakkuvatest =pakkuva  (PlEl  >pakkuv !02_A	et	f	\N
212198	pakkuvatest	"pakkuv %pakku  )V_vA  <pakkuma ;28_V	et	f	\N
212206	ülejäänudelt	?ülejäänudelt =ülejäänudelt  (ID  >ülejäänudelt !41_D	et	f	\N
212207	ülejäänudelt	?ülejäänudelt =nude  (SgAbl  >üle+jää+nude !16_S	et	f	\N
212221	airbaltic	### airbaltic	et	f	\N
212227	kitaariga	?kitaariga =kitaari  (SgKom  >kitaari !16_S	et	f	\N
212228	kitaariga	?kitaariga =kitaari  (SgKom  >kitaar !22_S	et	f	\N
212232	1lk	### 1lk	et	f	\N
212275	liitumiskava	liitumiskava =kava  (SgN  >liitumis+kava !17_S	et	f	\N
212276	liitumiskava	liitumiskava =kava  (SgG  >liitumis+kava !17_S	et	f	\N
212277	liitumiskava	liitumiskava =kava  (SgP  >liitumis+kava !17_S	et	f	\N
212291	kataloogifirmast	kataloogifirmast =firma  (SgEl  >kataloogi+firma !16_S	et	f	\N
212292	kataloogifirmast	kataloogifirmast =firmas  (SgP  >kataloogi+firmane !10_A	et	f	\N
212293	kataloogifirmast	"kataloogi+firmane %firma  )NE_aA  <kataloogi+firma ;16_S	et	f	\N
212298	pooolleheküljel	?pooolleheküljel =pooolleheküljel  (SgN  >pooolleheküljel !02_S	et	f	\N
212310	joonedeks	### joonedeks	et	f	\N
212313	lühikesemat	?lühikesemat =lühikesema  (SgP  >lühikesem !02_A	et	f	\N
212322	paksude	paksude =paksu  (PlG  >paks !22_AS	et	f	\N
211884	õppidata	?õppidata =õppidata  (IndPrPs_  >õppidatama !27_V	et	f	\N
211885	õppidata	?õppidata =õppidata  (ImpPrSg2  >õppidatama !27_V	et	f	\N
211887	juuksuritöö	juuksuritöö =töö  (SgN  >juuksuri+töö !26_S	et	f	\N
211888	juuksuritöö	juuksuritöö =töö  (SgG  >juuksuri+töö !26_S	et	f	\N
211894	armastin	?armastin =armasti  (IndPrSg1  >armastima !28_V	et	f	\N
211895	armastin	?armastin =armastin  (SgN  >armastin !19_S	et	f	\N
211905	lutherikirikus	?lutherikirikus =lutherikiriku  (SgIn  >lutherikirik !02_S	et	f	\N
211906	lutherikirikus	?lutherikirikus =lutherikiriku  (IndIpfSg3  >lutherikirikuma !27_V	et	f	\N
211907	lutherikirikus	?lutherikirikus =lutherikirikus  (SgN  >lutherikirikus !11?09_S	et	f	\N
211931	tivoli	?tivoli =tivoli  (ID  >tivoli !41_D	et	f	\N
211933	tivoli	?tivoli =tivoli  (SgG  >tivol !02_S	et	f	\N
211940	narva-jõesuu	narva-jõesuu =suu  (SgN  >narva-jõe+suu !26_S	et	f	\N
211941	narva-jõesuu	narva-jõesuu =suu  (SgG  >narva-jõe+suu !26_S	et	f	\N
211943	galeeri	galeeri =galeeri  (SgG  >galeer !22_S	et	f	\N
211944	galeeri	galeeri =galeeri  (SgP  >galeer !22_S	et	f	\N
211945	galeeri	galeeri =galeeri  (SgAdt  >galeer !22_S	et	f	\N
211949	tarbijakaitsest	tarbijakaitsest =kaitse  (SgEl  >tarbija+kaitse !06_S	et	f	\N
211950	tarbijakaitsest	tarbijakaitsest =kaitses  (SgP  >tarbija+kaitsene !12~10_A	et	f	\N
211951	tarbijakaitsest	"tarbija+kaitsene %kaitse  )NE_aA  <tarbija+kaitse ;06_S	et	f	\N
211956	käiss	?käiss =käiss  (SgN  >käiss !22_S	et	f	\N
211965	töökaitset	töökaitset =kaitse  (SgP  >töö+kaitse !05_S	et	f	\N
211966	töökaitset	töökaitset =kaitse  (SgP  >töö+kaitse !06_S	et	f	\N
211975	tervides	?tervides =tervi  (PlIn  >tervi !16_S	et	f	\N
211976	tervides	?tervides =tervi  (PlIn  >terv !22_S	et	f	\N
211977	tervides	?tervides =tervi  (Ger  >tervima !28_V	et	f	\N
211979	psüholoogijat	?psüholoogijat =psüholoogija  (SgP  >psüholoogija !01_S	et	f	\N
211980	psüholoogijat	?psüholoogijat =psüholoogija  (SgP  >psüholoogijas !02_A	et	f	\N
212015	autoavariisse	autoavariisse =avari  (PlIll  >auto+avar !02_A	et	f	\N
212016	autoavariisse	autoavariisse =avarii  (SgIll  >auto+avarii !26_S	et	f	\N
212032	arutlused	arutlused =arutluse  (PlN  >arutlus !11_S	et	f	\N
212033	arutlused	"arutlus %arutle  )US_vS  <arutlema ;27_V	et	f	\N
212039	valulistest	valulistest =valulis  (PlEl  >valuline !12_A	et	f	\N
212040	valulistest	"valuline %valu  )LINE_aA  <valu ;17_S	et	f	\N
212048	anektootid	?anektootid =anektooti  (PlN  >anektooti !16_S	et	f	\N
212049	lahendused	lahendused =lahenduse  (PlN  >lahendus !11_S	et	f	\N
212050	lahendused	"lahendus %lahenda  )US_vS  <lahendama ;27_V	et	f	\N
212059	loetavamad	loetavamad =loetavama  (PlN  >loetavam !02_A	et	f	\N
212060	loetavamad	"loetavam %loe  )TAVAM_cA  <lugema ;28_V	et	f	\N
212061	loetavamad	"loetavam %loeta  )VAM_cA  <loetama ;27_V	et	f	\N
212070	veerujagaminelaius	?veerujagaminelaius =veerujagaminelaiu  (SgIn  >veerujagaminelaiu !01_S	et	f	\N
212071	veerujagaminelaius	?veerujagaminelaius =veerujagaminelaius  (SgN  >veerujagaminelaius !11_S	et	f	\N
212072	veerujagaminelaius	?veerujagaminelaius =jagaminelaiu  (SgIn  >veeru+jagaminelaiu !01_S	et	f	\N
212073	veerujagaminelaius	?veerujagaminelaius =jagaminelaius  (SgN  >veeru+jagaminelaius !11_S	et	f	\N
212074	veerujagaminelaius	?veerujagaminelaius =ujagaminelaiu  (SgIn  >veer+ujagaminelaiu !01_S	et	f	\N
212075	veerujagaminelaius	?veerujagaminelaius =ujagaminelaius  (SgN  >veer+ujagaminelaius !11_S	et	f	\N
212076	veerujagaminelaius	?veerujagaminelaius =rujagaminelaiu  (SgIn  >vee+rujagaminelaiu !01_S	et	f	\N
212077	veerujagaminelaius	?veerujagaminelaius =rujagaminelaius  (SgN  >vee+rujagaminelaius !11_S	et	f	\N
212108	päised	päised =päise  (PlN  >päis !09_S	et	f	\N
212109	päised	päised =päise  (PlN  >päine !10_A	et	f	\N
212155	veerust	veerust =veeru  (SgEl  >veerg !22_S	et	f	\N
212156	veerust	veerust =veeru  (SgEl  >veer !22_S	et	f	\N
212157	veerust	veerust =us  (SgP  >veer+uks !14_S	et	f	\N
212168	raamis	raamis =raami  (SgIn  >raam !22_S	et	f	\N
212169	raamis	raamis =raami  (IndIpfSg3  >raamima !28_V	et	f	\N
212181	täidanud	?täidanud =täidanu  (PlN  >täidanu !01_S	et	f	\N
212183	täidanud	?täidanud =täidanu  (IndPrSg2  >täidanuma !27_V	et	f	\N
212184	täidanud	?täidanud =täidanud  (ID  >täidanud !41_A	et	f	\N
212185	täidanud	?täidanud =danu  (PlN  >täi+danu !17_S	et	f	\N
212243	painutuse	painutuse =painutuse  (SgG  >painutus !11_S	et	f	\N
212244	painutuse	"painutus %painuta  )US_vS  <painutama ;27_V	et	f	\N
212245	painutuse	painutuse =nutuse  (SgG  >pai+nutune !10_A	et	f	\N
212246	painutuse	"pai+nutune %nutu  )NE_aA  <pai+nutt ;22_S	et	f	\N
212308	peenikeste	peenikeste =peenikes  (PlG  >peenike !12_A	et	f	\N
212309	peenikeste	peenikeste =peenikes  (PlG  >peenikene !12_A	et	f	\N
212311	täidetakse	täidetakse =täide  (IndPrIps  >täitma !34_V	et	f	\N
212312	täidetakse	täidetakse =takse  (PlP  >täide+taks !22_S	et	f	\N
212316	eristanud	eristanud =erista  (PtsPtPs  >eristama !27_V	et	f	\N
212317	eristanud	eristanud =eristanu  (PlN  >eristanu !01_S	et	f	\N
212318	eristanud	"eristanu %erista  )NU_vS  <eristama ;27_V	et	f	\N
212319	eristanud	eristanud =eristanud  (ID  >eristanud !41_A	et	f	\N
212320	eristanud	"eristanud %erista  )NUD_vA  <eristama ;27_V	et	f	\N
212321	eristanud	eristanud =tanu  (PlN  >eris+tanu !17_S	et	f	\N
212044	televisooris	?televisooris =televisooris  (SgN  >televisooris !09_S	et	f	\N
212045	televisooris	?televisooris =visoori  (SgIn  >tele+visoori !16_S	et	f	\N
212046	televisooris	?televisooris =visoori  (SgIn  >tele+visoor !22_S	et	f	\N
212047	televisooris	?televisooris =visooris  (SgN  >tele+visooris !09_S	et	f	\N
212092	illustratsiooni	illustratsiooni =illustratsiooni  (SgG  >illustratsioon !22_S	et	f	\N
212093	illustratsiooni	illustratsiooni =illustratsiooni  (SgP  >illustratsioon !22_S	et	f	\N
212094	illustratsiooni	illustratsiooni =illustratsiooni  (SgAdt  >illustratsioon !22_S	et	f	\N
212095	sõnastanud	sõnastanud =sõnasta  (PtsPtPs  >sõnastama !27_V	et	f	\N
212096	sõnastanud	sõnastanud =sõnastanu  (PlN  >sõnastanu !01_S	et	f	\N
212097	sõnastanud	"sõnastanu %sõnasta  )NU_vS  <sõnastama ;27_V	et	f	\N
212098	sõnastanud	sõnastanud =sõnastanud  (ID  >sõnastanud !41_A	et	f	\N
212099	sõnastanud	"sõnastanud %sõnasta  )NUD_vA  <sõnastama ;27_V	et	f	\N
212106	moodsama	moodsama =moodsama  (SgG  >moodsam !02_A	et	f	\N
212107	moodsama	"moodsam %moodsa  )M_cA  <moodne ;02_A	et	f	\N
212112	alt-	alt- =alt  (ID  >alt !41_DK	et	f	\N
212113	alt-	alt- =alt  (SgN  >alt !22_S	et	f	\N
212115	tolkale	?tolkale =tolka  (SgAll  >tolka !16_S	et	f	\N
212116	tolkale	?tolkale =tolkale  (IndPrPs_  >tolkalema !27_V	et	f	\N
212117	tolkale	?tolkale =tolkale  (ImpPrSg2  >tolkalema !27_V	et	f	\N
212133	investitsioonilised	?investitsioonilised =investitsioonilise  (PlN  >investitsiooniline !12_A	et	f	\N
212137	pealina	pealina =lina  (SgN  >pea+lina !17_S	et	f	\N
212138	pealina	pealina =lina  (SgG  >pea+lina !17_S	et	f	\N
212139	pealina	pealina =lina  (SgP  >pea+lina !17_S	et	f	\N
212140	puhepäevas	?puhepäevas =puhepäeva  (SgIn  >puhepäeva !16_S	et	f	\N
212147	veeruselaius	?veeruselaius =veeruselaiu  (SgIn  >veeruselaiu !01_S	et	f	\N
212148	veeruselaius	?veeruselaius =veeruselaius  (SgN  >veeruselaius !11_S	et	f	\N
212149	veeruselaius	?veeruselaius =selaiu  (SgIn  >veeru+selaiu !01_S	et	f	\N
212150	veeruselaius	?veeruselaius =selaius  (SgN  >veeru+selaius !11_S	et	f	\N
212151	veeruselaius	?veeruselaius =uselaiu  (SgIn  >veer+uselaiu !01_S	et	f	\N
212152	veeruselaius	?veeruselaius =uselaius  (SgN  >veer+uselaius !11_S	et	f	\N
212153	veeruselaius	?veeruselaius =ruselaiu  (SgIn  >vee+ruselaiu !01_S	et	f	\N
212154	veeruselaius	?veeruselaius =ruselaius  (SgN  >vee+ruselaius !11_S	et	f	\N
212158	üldmusta	üldmusta =musta  (SgG  >üld+must !22_AS	et	f	\N
212159	üldmusta	üldmusta =musta  (SgP  >üld+must !22_AS	et	f	\N
212160	üldmusta	üldmusta =musta  (SgAdt  >üld+must !22_AS	et	f	\N
212177	poolpaksu	poolpaksu =paksu  (SgG  >pool+paks !22_AS	et	f	\N
212178	poolpaksu	poolpaksu =paksu  (SgP  >pool+paks !22_AS	et	f	\N
212179	poolpaksu	poolpaksu =paksu  (SgAdt  >pool+paks !22_AS	et	f	\N
212195	otsimist-leidmist	otsimist-leidmist =leidmis  (SgP  >otsimist-leidmine !12?10_S	et	f	\N
212196	otsimist-leidmist	"otsimist-leidmine %leid  )MINE_vS  <otsimist-leidma ;34_V	et	f	\N
212208	tõsilistele	?tõsilistele =tõsilis  (PlAll  >tõsilis !11_S	et	f	\N
212209	tõsilistele	?tõsilistele =tõsilis  (PlAll  >tõsiline !12_A	et	f	\N
212210	tõsilistele	?tõsilistele =tõsiliste  (PlAll  >tõsilist !22_S	et	f	\N
212211	tõsilistele	?tõsilistele =tõsilistele  (IndPrPs_  >tõsilistelema !36_V	et	f	\N
212212	tõsilistele	?tõsilistele =tõsilistele  (ImpPrSg2  >tõsilistelema !36_V	et	f	\N
212213	tõsilistele	?tõsilistele =liste  (SgAll  >tõsi+liste !06_S	et	f	\N
212214	tõsilistele	?tõsilistele =liste  (PlAll  >tõsi+list !22_S	et	f	\N
212215	palgikoorija	palgikoorija =koorija  (SgN  >palgi+koorija !01_S	et	f	\N
212216	palgikoorija	palgikoorija =koorija  (SgG  >palgi+koorija !01_S	et	f	\N
212222	viivita	viivita =viivi  (SgAb  >viiv !02_A	et	f	\N
212223	viivita	"viiv %vii  )V_vA  <viima ;38_V	et	f	\N
212224	viivita	viivita =viivi  (SgAb  >viiv !22_S	et	f	\N
212225	viivita	viivita =viivita  (IndPrPs_  >viivitama !27_V	et	f	\N
212226	viivita	viivita =viivita  (ImpPrSg2  >viivitama !27_V	et	f	\N
212233	raamid	raamid =raami  (PlN  >raam !22_S	et	f	\N
212234	raamid	raamid =raami  (IndPrSg2  >raamima !28_V	et	f	\N
212239	leheküljedel	### leheküljedel	et	f	\N
212281	köida	köida =köida  (IndPrPs_  >köitma !34_V	et	f	\N
212282	köida	köida =köida  (ImpPrSg2  >köitma !34_V	et	f	\N
212301	lühikene	lühikene =lühikene  (SgN  >lühikene !12_S	et	f	\N
212302	lühikene	"lühikene %lühi  )KENE_dS  <lüht ;22_S	et	f	\N
212333	järgitakse	järgitakse =järgi  (IndPrIps  >järgima !27_V	et	f	\N
212334	järgitakse	järgitakse =takse  (PlP  >järgi+taks !22_S	et	f	\N
212335	informattivsem	?informattivsem =informattivsem  (SgN  >informattivsem !02_A	et	f	\N
212336	tüpograafia	tüpograafia =tüpograafia  (SgN  >tüpograafia !01_S	et	f	\N
212337	tüpograafia	tüpograafia =tüpograafia  (SgG  >tüpograafia !01_S	et	f	\N
212342	kitjutamine	?kitjutamine =kitjutamine  (SgN  >kitjutamine !12_S	et	f	\N
212343	kitjutamine	?kitjutamine =kitjutamine  (PlP  >kitjutamin !19_S	et	f	\N
212357	komentaarid	?komentaarid =komentaari  (PlN  >komentaari !16_S	et	f	\N
212358	komentaarid	?komentaarid =komentaari  (PlN  >komentaar !22_S	et	f	\N
212359	komentaarid	?komentaarid =komentaari  (IndPrSg2  >komentaarima !28_V	et	f	\N
212360	komentaarid	?komentaarid =entaari  (PlN  >kom+entaari !16_S	et	f	\N
212079	artiklides	?artiklides =artikli  (Ger  >artiklima !28_V	et	f	\N
212102	kardinaalselt	kardinaalselt =kardinaalse  (SgAbl  >kardinaalne !02_A	et	f	\N
212103	kardinaalselt	kardinaalselt =kardinaalselt  (ID  >kardinaalselt !41_D	et	f	\N
212104	kardinaalselt	"kardinaalselt %kardinaalse  )LT_mD  <kardinaalne ;02_A	et	f	\N
212105	kardinaalselt	kardinaalselt =alse  (PlAbl  >kardina+alss !22_S	et	f	\N
212122	eestisveel	?eestisveel =eestisvee  (SgAd  >eestisvee !26_S	et	f	\N
212123	eestisveel	?eestisveel =eestisveel  (SgN  >eestisveel !22_S	et	f	\N
212124	eestisveel	?eestisveel =svee  (SgAd  >eesti+svee !26_S	et	f	\N
212125	eestisveel	?eestisveel =sveel  (SgN  >eesti+sveel !22_S	et	f	\N
212126	eestisveel	?eestisveel =isvee  (SgAd  >eest+isvee !26_S	et	f	\N
212127	eestisveel	?eestisveel =isveel  (SgN  >eest+isveel !22_S	et	f	\N
212128	eestisveel	?eestisveel =tisvee  (SgAd  >ees+tisvee !26_S	et	f	\N
212129	eestisveel	?eestisveel =tisveel  (SgN  >ees+tisveel !22_S	et	f	\N
212130	grafikud	?grafikud =grafiku  (PlN  >grafiku !01_S	et	f	\N
212131	grafikud	?grafikud =grafiku  (PlN  >grafik !02_S	et	f	\N
212132	grafikud	?grafikud =grafiku  (IndPrSg2  >grafikuma !27_V	et	f	\N
212162	punktiiriga	punktiiriga =punktiiri  (SgKom  >punktiir !22_S	et	f	\N
212163	punktiiriga	punktiiriga =tiiri  (SgKom  >punk+tiir !22_S	et	f	\N
212166	illustratsionidega	?illustratsionidega =illustratsioni  (PlKom  >illustratsioni !16_S	et	f	\N
212167	illustratsionidega	?illustratsionidega =illustratsioni  (PlKom  >illustratsion !19_S	et	f	\N
212173	arnhem	?arnhem =arnhem  (SgN  >arnhem !02_A	et	f	\N
212180	allteema	allteema =teema  (SgN  >all+teema !16_S	et	f	\N
212182	allteema	allteema =teema  (SgG  >all+teema !16_S	et	f	\N
212204	soovitajatele	soovitajatele =soovitaja  (PlAll  >soovitaja !01_S	et	f	\N
212205	soovitajatele	"soovitaja %soovita  )JA_vS  <soovitama ;27_V	et	f	\N
212240	kleepivad	kleepivad =kleepiva  (PlN  >kleepiv !02_A	et	f	\N
212241	kleepivad	"kleepiv %kleepi  )V_vA  <kleepima ;28_V	et	f	\N
212242	kleepivad	kleepivad =iva  (PlN  >kleep+iva !17_S	et	f	\N
212265	sulgenud	sulgenud =sulge  (PtsPtPs  >sulgema !27~28_V	et	f	\N
212266	sulgenud	sulgenud =sulgenu  (PlN  >sulgenu !01_S	et	f	\N
212267	sulgenud	"sulgenu %sulge  )NU_vS  <sulgema ;27_V	et	f	\N
212268	sulgenud	"sulgenu %sulge  )NU_vS  <sulgema ;28_V	et	f	\N
212269	sulgenud	sulgenud =sulgenud  (ID  >sulgenud !41_A	et	f	\N
212271	sulgenud	"sulgenud %sulge  )NUD_vA  <sulgema ;27_V	et	f	\N
212272	sulgenud	"sulgenud %sulge  )NUD_vA  <sulgema ;28_V	et	f	\N
212273	valuutikursusid	?valuutikursusid =valuutikursu  (IndIpfSg2  >valuutikursuma !27_V	et	f	\N
212274	valuutikursusid	?valuutikursusid =valuutikursu  (IndIpfPl3  >valuutikursuma !27_V	et	f	\N
212283	tegijatele	tegijatele =tegija  (PlAll  >tegija !01_S	et	f	\N
212284	tegijatele	"tegija %tegi  )JA_vS  <tegema ;28_V	et	f	\N
212294	jaotustesse	jaotustesse =jaotus  (PlIll  >jaotus !11~09_S	et	f	\N
212295	jaotustesse	"jaotus %jaota  )US_vS  <jaotama ;27_V	et	f	\N
212296	jaotustesse	"jaotus %jao  )TUS2_aS  <jagu ;18_S	et	f	\N
212297	jaotustesse	jaotustesse =tuste  (PlIll  >jao+tust !22_S	et	f	\N
212299	artiklide	?artiklide =artikli  (PlG  >artikel !19_S	et	f	\N
212303	laiuses	laiuses =laiuse  (SgIn  >laius !11~09_S	et	f	\N
212304	laiuses	"laius %lai  )US_aS  <lai ;22_A	et	f	\N
212305	laiuses	laiuses =laiuse  (SgIn  >laiune !10~12_A	et	f	\N
212306	laiuses	"laiune %laiu  )NE_aA  <laid ;22_S	et	f	\N
212307	laiuses	laiuses =use  (PlIn  >lai+usk !22_S	et	f	\N
212329	põrmugi	põrmugi =põrmugi  (ID  >põrmugi !41_D	et	f	\N
212330	põrmugi	põrmugi =põrmu  (SgG^  >põrm !22_S	et	f	\N
212331	põrmugi	põrmugi =põrmu  (SgP^  >põrm !22_S	et	f	\N
212332	põrmugi	põrmugi =põrmu  (SgAdt^  >põrm !22_S	et	f	\N
212338	värvikasutus	värvikasutus =kasutu  (SgIn  >värvi+kasutu !01_A	et	f	\N
212339	värvikasutus	"värvi+kasutu %kasu  )TU2_kA  <värvi+kasu ;17_S	et	f	\N
212340	värvikasutus	värvikasutus =kasutus  (SgN  >värvi+kasutus !11_S	et	f	\N
212341	värvikasutus	"värvi+kasutus %kasu  )TUS2_aS  <värvi+kasu ;17_S	et	f	\N
212348	kujundusega	kujundusega =kujunduse  (SgKom  >kujundus !11_S	et	f	\N
212349	kujundusega	"kujundus %kujunda  )US_vS  <kujundama ;27_V	et	f	\N
212362	leheküljede	### leheküljede	et	f	\N
212364	märgatud	märgatud =märga  (PtsPtIps  >märkama !29_V	et	f	\N
212365	märgatud	märgatud =märgatu  (PlN  >märgatu !01_AS	et	f	\N
212366	märgatud	"märgatu %märga  )TU1_vS  <märkama ;29_V	et	f	\N
212367	märgatud	märgatud =märgatud  (ID  >märgatud !41_A	et	f	\N
212368	märgatud	"märgatud %märga  )TUD_vA  <märkama ;29_V	et	f	\N
212369	tiraazi	?tiraazi =tiraazi  (SgN  >tiraazi !16_S	et	f	\N
212370	tiraazi	?tiraazi =tiraazi  (SgG  >tiraazi !16_S	et	f	\N
212371	temaatilisteks	temaatilisteks =temaatilis  (PlTr  >temaatiline !12_A	et	f	\N
212372	temaatilisteks	temaatilisteks =atilis  (PlTr  >tema+atiline !12_A	et	f	\N
212373	temaatilisteks	"tema+atiline %ati  )LINE_aA  <tema+att ;22_S	et	f	\N
212374	info-osakonnad	info-osakonnad =osakonna  (PlN  >info-osakond !22_S	et	f	\N
212375	info-osakonnad	info-osakonnad =konna  (PlN  >info-osa+konn !22_S	et	f	\N
212399	ilmateade	ilmateade =teade  (SgN  >ilma+teade !05_S	et	f	\N
212400	ilmateade	ilmateade =teade  (SgN  >ilma+teade !06_S	et	f	\N
212217	intrigeerivalt	intrigeerivalt =intrigeeriva  (SgAbl  >intrigeeriv !02_A	et	f	\N
212218	intrigeerivalt	"intrigeeriv %intrigeeri  )V_vA  <intrigeerima ;28_V	et	f	\N
212219	intrigeerivalt	intrigeerivalt =intrigeerivalt  (ID  >intrigeerivalt !41_D	et	f	\N
212220	intrigeerivalt	"intrigeerivalt %intrigeeri  )VALT_mD  <intrigeerima ;28_V	et	f	\N
212229	jaotused	jaotused =jaotuse  (PlN  >jaotus !11~09_S	et	f	\N
212230	jaotused	"jaotus %jaota  )US_vS  <jaotama ;27_V	et	f	\N
212231	jaotused	"jaotus %jao  )TUS2_aS  <jagu ;18_S	et	f	\N
212235	ebaühtlaselt	ebaühtlaselt =ühtlase  (SgAbl  >eba+ühtlane !12?10_A	et	f	\N
212236	ebaühtlaselt	ebaühtlaselt =ühtlaselt  (ID  >eba+ühtlaselt !41_D	et	f	\N
212237	ebaühtlaselt	"eba+ühtlaselt %ühtlase  )LT_mD  <eba+ühtlane ;10_A	et	f	\N
212238	ebaühtlaselt	"eba+ühtlaselt %ühtlase  )LT_mD  <eba+ühtlane ;12_A	et	f	\N
212247	suuruseid	suuruseid =suuruse  (PlP  >suurus !09_S	et	f	\N
212248	suuruseid	"suurus %suur  )US_aS  <suur ;13_A	et	f	\N
212249	suuruseid	suuruseid =suuruse  (PlP  >suurune !10_A	et	f	\N
212250	lähim	lähim =lähim  (SgN  >lähim !02_A	et	f	\N
212251	lähim	"lähim %lähi  )IM_sA  <lähike ;12_A	et	f	\N
212252	kuulujutteid	?kuulujutteid =kuulujuttei  (PlN  >kuulujuttei !26_S	et	f	\N
212253	kuulujutteid	?kuulujutteid =kuulujuttei  (SgP  >kuulujuttei !26_S	et	f	\N
212254	kuulujutteid	?kuulujutteid =eid  (SgN  >kuulu+jutt+eid !22_S	et	f	\N
212255	kuulujutteid	?kuulujutteid =jutte  (PlP  >kuulu+jute !06_S	et	f	\N
212256	kuulujutteid	?kuulujutteid =juttei  (PlN  >kuulu+juttei !26_S	et	f	\N
212257	kuulujutteid	?kuulujutteid =juttei  (SgP  >kuulu+juttei !26_S	et	f	\N
212258	kuulujutteid	?kuulujutteid =jutteid  (SgN  >kuulu+jutteid !22_S	et	f	\N
212259	kuulujutteid	?kuulujutteid =ujutte  (PlP  >kuul+ujutti !01_S	et	f	\N
212260	kuulujutteid	?kuulujutteid =ujuttei  (PlN  >kuul+ujuttei !26_S	et	f	\N
212261	kuulujutteid	?kuulujutteid =ujuttei  (SgP  >kuul+ujuttei !26_S	et	f	\N
212262	kuulujutteid	?kuulujutteid =lujutte  (PlP  >kuu+lujutti !01_S	et	f	\N
212263	kuulujutteid	?kuulujutteid =lujuttei  (PlN  >kuu+lujuttei !26_S	et	f	\N
212264	kuulujutteid	?kuulujutteid =lujuttei  (SgP  >kuu+lujuttei !26_S	et	f	\N
212270	euromüntiks	### euromüntiks	et	f	\N
212278	kujutusega	kujutusega =kujutuse  (SgKom  >kujutus !11_S	et	f	\N
212279	kujutusega	"kujutus %kujuta  )US_vS  <kujutama ;27_V	et	f	\N
212280	kujutusega	"kujutus %kuju  )TUS2_aS  <kuju ;17_S	et	f	\N
212285	halensi	?halensi =halensi  (SgN  >halensi !01_S	et	f	\N
212286	halensi	?halensi =halensi  (SgG  >halensi !01_S	et	f	\N
212287	halensi	?halensi =halensi  (SgG  >halens !02_S	et	f	\N
212288	halensi	?halensi =halensi  (SgG  >halenss !22_S	et	f	\N
212289	halensi	?halensi =halensi  (IndPrPs_  >halenssima !28_V	et	f	\N
212290	halensi	?halensi =halensi  (ImpPrSg2  >halenssima !28_V	et	f	\N
212300	20ni	### 20ni	et	f	\N
212314	standaartne	?standaartne =standaartne  (SgN  >standaartne !02_A	et	f	\N
212315	standaartne	?standaartne =standaartne  (PlP  >standaartn !22_S	et	f	\N
212324	ühesuguselt	ühesuguselt =suguse  (SgAbl  >ühe+sugune !10_A	et	f	\N
212325	ühesuguselt	"ühe+suguselt %suguse  )LT_mD  <ühe+sugune ;10_A	et	f	\N
212344	vilumust	vilumust =vilumus  (SgP  >vilumus !11_S	et	f	\N
212345	vilumust	"vilumus %vilu  )MUS_vS  <viluma ;27_V	et	f	\N
212346	vilumust	"vilumus %viluma  )US_aS  <vilum ;02_A	et	f	\N
212347	vilumust	vilumust =must  (SgN  >vilu+must !22_AS	et	f	\N
212379	meelelahutusosakonnad	meelelahutusosakonnad =konna  (PlN  >meele+lahutus+osa+konn !22_S	et	f	\N
212380	meelelahutusosakonnad	meelelahutusosakonnad =osakonna  (PlN  >meele+lahutus+osakond !22_S	et	f	\N
212393	vahelduvalt	vahelduvalt =vahelduva  (SgAbl  >vahelduv !02_A	et	f	\N
212394	vahelduvalt	"vahelduv %vaheldu  )V_vA  <vahelduma ;27_V	et	f	\N
212395	vahelduvalt	vahelduvalt =vahelduvalt  (ID  >vahelduvalt !41_D	et	f	\N
212396	vahelduvalt	"vahelduvalt %vaheldu  )VALT_mD  <vahelduma ;27_V	et	f	\N
212397	vahelduvalt	"vahelduvalt %vahelduva  )LT_mD  <vahelduv ;02_A	et	f	\N
212398	vahelduvalt	vahelduvalt =alt  (SgN  >vahelduv+alt !22_S	et	f	\N
212408	kergete	kergete =kerge  (PlG  >kerge !01_A	et	f	\N
212409	kergete	kergete =kerge  (PlG  >kerge !06_S	et	f	\N
212410	kergete	kergete =e  (PlG  >kerg+esi !15_S	et	f	\N
212429	liigendamiseks	liigendamiseks =liigendamise  (SgTr  >liigendamine !12_S	et	f	\N
212430	liigendamiseks	"liigendamine %liigenda  )MINE_vS  <liigendama ;27_V	et	f	\N
212450	fotosi	?fotosi =fotosi  (ID  >fotosi !41_D	et	f	\N
212451	fotosi	?fotosi =fotosi  (PlP  >fotos !11_S	et	f	\N
212467	temaatilise	temaatilise =temaatilise  (SgG  >temaatiline !12_A	et	f	\N
212468	temaatilise	temaatilise =atilise  (SgG  >tema+atiline !12_A	et	f	\N
212469	temaatilise	"tema+atiline %ati  )LINE_aA  <tema+att ;22_S	et	f	\N
212485	servas	servas =serva  (SgIn  >serv !22_S	et	f	\N
212486	servas	servas =serva  (IndIpfSg3  >servama !29_V	et	f	\N
212495	esikaane	esikaane =kaane  (SgG  >esi+kaas !14_S	et	f	\N
212496	esikaane	esikaane =kaane  (PlP  >esi+kaan !22_S	et	f	\N
212499	usaldusväärsem	usaldusväärsem =väärsem  (SgN  >usaldus+väärsem !02_A	et	f	\N
212500	usaldusväärsem	"usaldus+väärsem %väärse  )M_cA  <usaldus+väärne ;02_A	et	f	\N
212527	raami	raami =raami  (SgG  >raam !22_S	et	f	\N
212528	raami	raami =raami  (SgP  >raam !22_S	et	f	\N
212323	paksude	paksude =ude  (SgN  >paks+ude !04_S	et	f	\N
212326	viided	?viided =viide  (IndPrSg2  >viidema !27_V	et	f	\N
212327	kesksete	kesksete =keskse  (PlG  >keskne !02_A	et	f	\N
212328	kesksete	kesksete =sete  (SgN  >kesk+sete !06_S	et	f	\N
212352	ostmisega	ostmisega =ostmise  (SgKom  >ostmine !12?10_S	et	f	\N
212353	ostmisega	"ostmine %ost  )MINE_vS  <ostma ;34_V	et	f	\N
212354	horisontaalselt	horisontaalselt =horisontaalse  (SgAbl  >horisontaalne !02_A	et	f	\N
212355	horisontaalselt	horisontaalselt =horisontaalselt  (ID  >horisontaalselt !41_D	et	f	\N
212356	horisontaalselt	"horisontaalselt %horisontaalse  )LT_mD  <horisontaalne ;02_A	et	f	\N
212384	vabameelsemalt	vabameelsemalt =meelsema  (SgAbl  >vaba+meelsem !02_A	et	f	\N
212385	vabameelsemalt	"vaba+meelsem %meelse  )M_cA  <vaba+meelne ;02_A	et	f	\N
212386	vabameelsemalt	"vaba+meelsemalt %meelse  )MALT_mD  <vaba+meelne ;02_A	et	f	\N
212405	loogilisem	loogilisem =loogilisem  (SgN  >loogilisem !02_A	et	f	\N
212406	loogilisem	"loogilisem %loogi  )LISEM_cA  <loog ;22_S	et	f	\N
212407	loogilisem	"loogilisem %loogilise  )M_cA  <loogiline ;12_A	et	f	\N
212416	kolumnistide	?kolumnistide =kolumnisti  (PlG  >kolumnist !22_S	et	f	\N
212425	olevatesse	olevatesse =oleva  (PlIll  >olev !02_A	et	f	\N
212426	olevatesse	"olev %ole  )V_vA  <olema ;36_V	et	f	\N
212454	konsert	?konsert =konsert  (SgN  >konsert !22_S	et	f	\N
212455	meelelahutuse	meelelahutuse =lahutuse  (SgG  >meele+lahutus !11_S	et	f	\N
212456	meelelahutuse	"meele+lahutus %lahu  )TUS2_aS  <meele+lahk ;22_S	et	f	\N
212463	temaatilistel	temaatilistel =temaatilis  (PlAd  >temaatiline !12_A	et	f	\N
212465	temaatilistel	temaatilistel =atilis  (PlAd  >tema+atiline !12_A	et	f	\N
212466	temaatilistel	"tema+atiline %ati  )LINE_aA  <tema+att ;22_S	et	f	\N
212473	päis	päis =pä  (PlIn  >pea !26_S	et	f	\N
212474	päis	päis =päis  (SgN  >päis !09_S	et	f	\N
212480	asetusel	asetusel =asetuse  (SgAd  >asetus !11_S	et	f	\N
212481	asetusel	"asetus %aseta  )US_vS  <asetama ;27_V	et	f	\N
212482	asetusel	asetusel =use  (PlAd  >aset+usk !22_S	et	f	\N
212483	kuupäevarida	kuupäevarida =rida  (SgN  >kuu+päeva+rida !18_S	et	f	\N
212484	kuupäevarida	kuupäevarida =rida  (SgP  >kuu+päeva+rida !18_S	et	f	\N
212487	arukalt	arukalt =aruka  (SgAbl  >arukas !02_A	et	f	\N
212488	arukalt	arukalt =arukalt  (ID  >arukalt !41_D	et	f	\N
212489	arukalt	"arukalt %aruka  )LT_mD  <arukas ;02_A	et	f	\N
212505	sisukama	sisukama =sisukama  (SgG  >sisukam !02_A	et	f	\N
212506	sisukama	"sisukam %sisuka  )M_cA  <sisukas ;02_A	et	f	\N
212507	sisukama	sisukama =kama  (SgN  >sisu+kama !17_S	et	f	\N
212508	sisukama	sisukama =kama  (SgG  >sisu+kama !17_S	et	f	\N
212509	sisukama	sisukama =kama  (SgP  >sisu+kama !17_S	et	f	\N
212534	esilehtedel	esilehtedel =ede  (SgAd  >esi+leht+ede !16_S	et	f	\N
212535	esilehtedel	esilehtedel =edel  (SgN  >esi+leht+edel !02_S	et	f	\N
212536	esilehtedel	esilehtedel =lehte  (PlAd  >esi+leht !22_S	et	f	\N
212559	sõnavahesse	sõnavahesse =vahe  (SgIll  >sõna+vahe !16_S	et	f	\N
212560	sõnavahesse	sõnavahesse =vahe  (PlIll  >sõna+vahk !22_S	et	f	\N
212561	sõnavahesse	sõnavahesse =vahe  (PlIll  >sõna+vaht !22_S	et	f	\N
212567	vastakleheküljed	### vastakleheküljed	et	f	\N
212633	lehekülgedele	lehekülgedele =ede  (SgAll  >lehe+külg+ede !16_S	et	f	\N
212634	lehekülgedele	lehekülgedele =külge  (PlAll  >lehe+külg !22_S	et	f	\N
212666	kohendatud	kohendatud =kohenda  (PtsPtIps  >kohendama !27_V	et	f	\N
212667	kohendatud	kohendatud =kohendatu  (PlN  >kohendatu !01_S	et	f	\N
212668	kohendatud	"kohendatu %kohenda  )TU1_vS  <kohendama ;27_V	et	f	\N
212669	kohendatud	kohendatud =kohendatud  (ID  >kohendatud !41_A	et	f	\N
212670	kohendatud	"kohendatud %kohenda  )TUD_vA  <kohendama ;27_V	et	f	\N
212713	siluett-foto	siluett-foto =foto  (SgN  >siluett-foto !16_S	et	f	\N
212714	siluett-foto	siluett-foto =foto  (SgG  >siluett-foto !16_S	et	f	\N
212715	lugematafotoallkirjades	?lugematafotoallkirjades =lugematafotoallkirja  (PlIn  >lugematafotoallkirja !16_S	et	f	\N
212732	polyglot	?polyglot =polyglo  (SgP  >polyglo !16_S	et	f	\N
212750	tõmba	tõmba =tõmba  (IndPrPs_  >tõmbama !29_V	et	f	\N
212751	tõmba	tõmba =tõmba  (ImpPrSg2  >tõmbama !29_V	et	f	\N
212758	tappab	?tappab =tappa  (IndPrSg3  >tappama !29_V	et	f	\N
212770	uurimiseks	uurimiseks =uurimise  (SgTr  >uurimine !12_S	et	f	\N
212771	uurimiseks	"uurimine %uuri  )MINE_vS  <uurima ;28_V	et	f	\N
212786	allasurutud	allasurutud =rutu  (PlN  >all+asu+rutt !22_S	et	f	\N
212787	allasurutud	allasurutud =suru  (PtsPtIps  >alla+_suruma !27_V	et	f	\N
212788	allasurutud	allasurutud =surutu  (PlN  >alla+surutu !01_AS	et	f	\N
212789	allasurutud	"alla+surutu %suru  )TU2_kA  <alla+suru ;17_S	et	f	\N
212806	trükikirja	trükikirja =kirja  (SgG  >trüki+kiri !24_S	et	f	\N
212807	trükikirja	trükikirja =kirja  (SgP  >trüki+kiri !24_S	et	f	\N
212808	trükikirja	trükikirja =kirja  (SgAdt  >trüki+kiri !24_S	et	f	\N
212834	märgistatud	märgistatud =märgista  (PtsPtIps  >märgistama !27_V	et	f	\N
212835	märgistatud	märgistatud =märgistatu  (PlN  >märgistatu !01_S	et	f	\N
212836	märgistatud	"märgistatu %märgista  )TU1_vS  <märgistama ;27_V	et	f	\N
212837	märgistatud	märgistatud =märgistatud  (ID  >märgistatud !41_A	et	f	\N
212838	märgistatud	"märgistatud %märgista  )TUD_vA  <märgistama ;27_V	et	f	\N
212350	kuueaasta	kuueaasta =aasta  (SgN  >kuue+aasta !01_S	et	f	\N
212351	kuueaasta	kuueaasta =aasta  (SgG  >kuue+aasta !01_S	et	f	\N
212363	tiraaz	### tiraaz	et	f	\N
212381	nädalõpulood	?nädalõpulood =nädalõpuloo  (PlN  >nädalõpuloo !26_S	et	f	\N
212382	nädalõpulood	?nädalõpulood =nädalõpuloo  (SgP  >nädalõpuloo !26_S	et	f	\N
212383	nädalõpulood	?nädalõpulood =nädalõpulood  (SgN  >nädalõpulood !22_S	et	f	\N
212387	koondatud	koondatud =koonda  (PtsPtIps  >koondama !27_V	et	f	\N
212388	koondatud	koondatud =koondatu  (PlN  >koondatu !01_S	et	f	\N
212389	koondatud	"koondatu %koonda  )TU1_vS  <koondama ;27_V	et	f	\N
212390	koondatud	koondatud =koondatud  (ID  >koondatud !41_A	et	f	\N
212391	koondatud	"koondatud %koonda  )TUD_vA  <koondama ;27_V	et	f	\N
212392	koondatud	koondatud =atu  (PlN  >koond+att !22_S	et	f	\N
212402	telekava	telekava =kava  (SgN  >tele+kava !17_S	et	f	\N
212403	telekava	telekava =kava  (SgG  >tele+kava !17_S	et	f	\N
212404	telekava	telekava =kava  (SgP  >tele+kava !17_S	et	f	\N
212411	päevast-päeva	päevast-päeva =päeva  (SgG  >päevast-päev !22_S	et	f	\N
212412	päevast-päeva	päevast-päeva =päeva  (SgP  >päevast-päev !22_S	et	f	\N
212413	päevast-päeva	päevast-päeva =päeva  (SgAdt  >päevast-päev !22_S	et	f	\N
212423	kujunduselt	kujunduselt =kujunduse  (SgAbl  >kujundus !11_S	et	f	\N
212424	kujunduselt	"kujundus %kujunda  )US_vS  <kujundama ;27_V	et	f	\N
212427	börsiinfo	börsiinfo =info  (SgN  >börsi+info !16_S	et	f	\N
212428	börsiinfo	börsiinfo =info  (SgG  >börsi+info !16_S	et	f	\N
212431	tiiteltähti	tiiteltähti =tähti  (SgP  >tiitel+täht !22_S	et	f	\N
212432	tiiteltähti	tiiteltähti =tähti  (SgAdt  >tiitel+täht !22_S	et	f	\N
212433	tiiteltähti	tiiteltähti =tähti  (PlP  >tiitel+täht !22_S	et	f	\N
212442	otsiva	otsiva =otsiva  (SgG  >otsiv !02_A	et	f	\N
212443	otsiva	"otsiv %otsi  )V_vA  <otsima ;28_V	et	f	\N
212444	otsiva	otsiva =iva  (SgN  >ots+iva !17_S	et	f	\N
212445	otsiva	otsiva =iva  (SgG  >ots+iva !17_S	et	f	\N
212446	otsiva	otsiva =iva  (SgP  >ots+iva !17_S	et	f	\N
212457	pikematele	pikematele =pikema  (PlAll  >pikem !02_A	et	f	\N
212458	pikematele	"pikem %pike  )M_cA  <pikk ;22_AS	et	f	\N
212462	osakonnal	osakonnal =osakonna  (SgAd  >osakond !22_S	et	f	\N
212464	osakonnal	osakonnal =konna  (SgAd  >osa+konn !22_S	et	f	\N
212478	joondusega	joondusega =joonduse  (SgKom  >joondus !11~09_S	et	f	\N
212479	joondusega	"joondus %joonda  )US_vS  <joondama ;27_V	et	f	\N
212490	torka	torka =torka  (IndPrPs_  >torkama !29_V	et	f	\N
212491	torka	torka =torka  (ImpPrSg2  >torkama !29_V	et	f	\N
212497	ratsionaalsem	ratsionaalsem =ratsionaalsem  (SgN  >ratsionaalsem !02_A	et	f	\N
212498	ratsionaalsem	"ratsionaalsem %ratsionaalse  )M_cA  <ratsionaalne ;02_A	et	f	\N
212515	kontrasti	kontrasti =kontrasti  (SgG  >kontrast !22_S	et	f	\N
212516	kontrasti	kontrasti =kontrasti  (SgP  >kontrast !22_S	et	f	\N
212517	kontrasti	kontrasti =kontrasti  (SgAdt  >kontrast !22_S	et	f	\N
212518	kontrasti	kontrasti =kontrasti  (IndPrPs_  >kontrastima !28_V	et	f	\N
212519	kontrasti	kontrasti =kontrasti  (ImpPrSg2  >kontrastima !28_V	et	f	\N
212537	reedese	reedese =reedese  (SgG  >reedene !10~12_A	et	f	\N
212538	reedese	"reedene %reede  )NE_aA  <reede ;01_S	et	f	\N
212539	tähtega	### tähtega	et	f	\N
212545	klammerdatud	klammerdatud =klammerda  (PtsPtIps  >klammerdama !27_V	et	f	\N
212546	klammerdatud	klammerdatud =klammerdatu  (PlN  >klammerdatu !01_S	et	f	\N
212547	klammerdatud	"klammerdatu %klammerda  )TU1_vS  <klammerdama ;27_V	et	f	\N
212548	klammerdatud	klammerdatud =klammerdatud  (ID  >klammerdatud !41_A	et	f	\N
212549	klammerdatud	"klammerdatud %klammerda  )TUD_vA  <klammerdama ;27_V	et	f	\N
212550	lõhu	lõhu =lõhu  (SgG  >lõhk !22_S	et	f	\N
212551	lõhu	lõhu =lõhu  (IndPrPs_  >lõhkuma !28_V	et	f	\N
212552	lõhu	lõhu =lõhu  (ImpPrSg2  >lõhkuma !28_V	et	f	\N
212553	detaili	detaili =detaili  (SgG  >detail !22_S	et	f	\N
212554	detaili	detaili =detaili  (SgP  >detail !22_S	et	f	\N
212555	detaili	detaili =detaili  (SgAdt  >detail !22_S	et	f	\N
212562	vaatamisjärjekorrast	vaatamisjärjekorrast =korra  (SgEl  >vaatamis+järje+kord !22_S	et	f	\N
212563	vaatamisjärjekorrast	vaatamisjärjekorrast =korras  (SgP  >vaatamis+järje+korrane !10_A	et	f	\N
212564	vaatamisjärjekorrast	"vaatamis+järje+korrane %korra  )NE_aA  <vaatamis+järje+kord ;22_S	et	f	\N
212568	fotoreportaazid	?fotoreportaazid =fotoreportaazi  (PlN  >fotoreportaazi !16_S	et	f	\N
212569	fotoreportaazid	?fotoreportaazid =reportaazi  (PlN  >foto+reportaazi !16_S	et	f	\N
212574	veerulaiusena	veerulaiusena =laiuse  (SgEs  >veeru+laius !11~09_S	et	f	\N
212575	veerulaiusena	"veeru+laius %lai  )US_aS  <veeru+lai ;22_A	et	f	\N
212576	veerulaiusena	veerulaiusena =laiuse  (SgEs  >veeru+laiune !10~12_A	et	f	\N
212577	veerulaiusena	"veeru+laiune %laiu  )NE_aA  <veeru+laid ;22_S	et	f	\N
212583	varieerivad	varieerivad =varieeri  (IndPrPl3  >varieerima !28_V	et	f	\N
212584	varieerivad	varieerivad =varieeriva  (PlN  >varieeriv !02_A	et	f	\N
212585	varieerivad	"varieeriv %varieeri  )V_vA  <varieerima ;28_V	et	f	\N
212603	kitsam	kitsam =kitsam  (SgN  >kitsam !02_A	et	f	\N
212604	kitsam	"kitsam %kitsa  )M_cA  <kitsas ;07_A	et	f	\N
212609	veerupikkuse	veerupikkuse =pikkuse  (SgG  >veeru+pikkus !11~09_S	et	f	\N
212361	komentaarid	?komentaarid =entaari  (PlN  >kom+entaar !22_S	et	f	\N
212376	neutralselt	?neutralselt =neutralse  (SgAbl  >neutralne !02_A	et	f	\N
212377	neutralselt	?neutralselt =neutralse  (PlAbl  >neutralss !22_S	et	f	\N
212378	neutralselt	?neutralselt =neutralselt  (ID  >neutralselt !41_D	et	f	\N
212414	toimetajate	toimetajate =toimetaja  (PlG  >toimetaja !01_S	et	f	\N
212415	toimetajate	"toimetaja %toimeta  )JA_vS  <toimetama ;27_V	et	f	\N
212417	karikaturistide	karikaturistide =karikaturisti  (PlG  >karikaturist !22_S	et	f	\N
212418	karikaturistide	karikaturistide =turisti  (PlG  >karika+turist !22_S	et	f	\N
212419	uudistelehekülgedest	uudistelehekülgedest =ede  (SgEl  >uudiste+lehe+külg+ede !16_S	et	f	\N
212420	uudistelehekülgedest	uudistelehekülgedest =edes  (SgP  >uudiste+lehe+külg+edene !10_A	et	f	\N
212421	uudistelehekülgedest	"uudiste+lehe+külg+edene %ede  )NE_aA  <uudiste+lehe+külg+ede ;16_S	et	f	\N
212422	uudistelehekülgedest	uudistelehekülgedest =külge  (PlEl  >uudiste+lehe+külg !22_S	et	f	\N
212438	rahaturgkaubad	?rahaturgkaubad =rahaturgkauba  (PlN  >rahaturgkauba !16_S	et	f	\N
212439	rahaturgkaubad	?rahaturgkaubad =turgkauba  (PlN  >raha+turgkauba !01_S	et	f	\N
212447	diagrammist	diagrammist =diagrammi  (SgEl  >diagramm !22_S	et	f	\N
212448	diagrammist	diagrammist =diagrammis  (SgP  >diagrammine !12_A	et	f	\N
212449	diagrammist	"diagrammine %diagrammi  )NE_aA  <diagramm ;22_S	et	f	\N
212452	kujundusi	kujundusi =kujundusi  (PlP  >kujundus !11_S	et	f	\N
212453	kujundusi	"kujundus %kujunda  )US_vS  <kujundama ;27_V	et	f	\N
212501	vanamoelisem	vanamoelisem =moelisem  (SgN  >vana+moelisem !02_A	et	f	\N
212502	vanamoelisem	"vana+moelisem %moe  )LISEM_cA  <vana+mood ;22_S	et	f	\N
212503	vanamoelisem	"vana+moelisem %moelise  )M_cA  <vana+moeline ;10_A	et	f	\N
212504	vanamoelisem	"vana+moelisem %moelise  )M_cA  <vana+moeline ;12_A	et	f	\N
212520	lehtedest	lehtedest =lehte  (PlEl  >leht !22_S	et	f	\N
212521	lehtedest	lehtedest =ede  (SgEl  >leht+ede !16_S	et	f	\N
212522	lehtedest	lehtedest =edes  (SgP  >leht+edene !10_A	et	f	\N
212523	lehtedest	"leht+edene %ede  )NE_aA  <leht+ede ;16_S	et	f	\N
212524	numbritest	numbritest =numbri  (PlEl  >number !02_S	et	f	\N
212525	numbritest	numbritest =test  (SgN  >numbri+test !22_S	et	f	\N
212541	eriteemalised	eriteemalised =malise  (PlN  >eri+tee+maline !10_A	et	f	\N
212542	eriteemalised	"eri+tee+maline %mali  )NE_aA  <eri+tee+mali ;17_S	et	f	\N
212543	eriteemalised	eriteemalised =teemalise  (PlN  >eri+teemaline !12_A	et	f	\N
212544	eriteemalised	"eri+teemaline %teema  )LINE_aA  <eri+teema ;16_S	et	f	\N
212565	pearõhulisele	pearõhulisele =rõhulise  (SgAll  >pea+rõhuline !12_A	et	f	\N
212566	pearõhulisele	"pea+rõhuline %rõhu  )LINE_aA  <pea+rõhk ;22_S	et	f	\N
212586	veerulaiust	veerulaiust =us  (SgP  >veeru+lai+uks !14_S	et	f	\N
212587	veerulaiust	veerulaiust =laiu  (SgEl  >veeru+laid !22_S	et	f	\N
212588	veerulaiust	veerulaiust =laiu  (PlEl  >veeru+laid !22_S	et	f	\N
212589	veerulaiust	veerulaiust =laiu  (PlEl  >veeru+lai !22_A	et	f	\N
212590	veerulaiust	veerulaiust =laius  (SgP  >veeru+laius !11~09_S	et	f	\N
212591	veerulaiust	"veeru+laius %lai  )US_aS  <veeru+lai ;22_A	et	f	\N
212593	veerulaiust	veerulaiust =laius  (SgP  >veeru+laiune !10~12_A	et	f	\N
212595	veerulaiust	"veeru+laiune %laiu  )NE_aA  <veeru+laid ;22_S	et	f	\N
212605	kitsam	kitsam =kitsam  (SgN  >kitsam !02_A	et	f	\N
212606	kitsam	"kitsam %kitsa  )M_cA  <kitsas ;07_A	et	f	\N
212643	optimalses	?optimalses =optimalse  (SgIn  >optimalne !02_A	et	f	\N
212651	upputanud	?upputanud =upputa  (PtsPtPs  >upputama !27_V	et	f	\N
212652	upputanud	?upputanud =upputanu  (PlN  >upputanu !01_S	et	f	\N
212653	upputanud	?upputanud =upputanu  (IndPrSg2  >upputanuma !27_V	et	f	\N
212654	upputanud	?upputanud =upputanud  (ID  >upputanud !41_A	et	f	\N
212665	kapslides	?kapslides =kapsli  (Ger  >kapslima !28_V	et	f	\N
212681	äratavad	äratavad =ärata  (IndPrPl3  >äratama !27_V	et	f	\N
212682	äratavad	äratavad =äratava  (PlN  >äratav !02_A	et	f	\N
212683	äratavad	"äratav %ärata  )V_vA  <äratama ;27_V	et	f	\N
212684	äratavad	äratavad =tava  (PlN  >ära+tava !17_S	et	f	\N
212748	piiireeet	?piiireeet =piiireeet  (SgN  >piiireeet !22_S	et	f	\N
212761	õhulise	õhulise =õhulise  (SgG  >õhuline !12_A	et	f	\N
212762	õhulise	"õhuline %õhu  )LINE_aA  <õhk ;22_S	et	f	\N
212777	numrit	?numrit =numri  (SgP  >numri !16_S	et	f	\N
212778	numrit	?numrit =numrit  (SgN  >numrit !02_S	et	f	\N
212779	ajalehepea	ajalehepea =pea  (SgN  >aja+lehe+pea !26_S	et	f	\N
212780	ajalehepea	ajalehepea =pea  (SgG  >aja+lehe+pea !26_S	et	f	\N
212794	hallil	hallil =halli  (SgAd  >hall !22_S	et	f	\N
212795	hallil	hallil =halli  (SgAd  >hall !22_AS	et	f	\N
212812	rasvase	rasvase =rasvase  (SgG  >rasvane !10_A	et	f	\N
212813	rasvase	"rasvane %rasva  )NE_aA  <rasv ;22_S	et	f	\N
212814	rasvase	rasvase =ase  (SgN  >rasv+ase !04_S	et	f	\N
212849	ristu	ristu =ristu  (IndPrPs_  >ristuma !27_V	et	f	\N
212850	ristu	ristu =ristu  (ImpPrSg2  >ristuma !27_V	et	f	\N
212860	objektfotod	?objektfotod =objektfoto  (PlN  >objektfoto !16_S	et	f	\N
212875	nähtavad	nähtavad =nähtava  (PlN  >nähtav !02_A	et	f	\N
212876	nähtavad	"nähtav %näh  )TAV_vAS  <nägema ;28_V	et	f	\N
212884	pinguta	pinguta =pingu  (SgAb  >ping !22_S	et	f	\N
212401	ilmateade	ilmateade =teade  (PlP  >ilma+tead !22_S	et	f	\N
212434	eraldamiseks	eraldamiseks =eraldamise  (SgTr  >eraldamine !12_S	et	f	\N
212435	eraldamiseks	"eraldamine %eralda  )MINE_vS  <eraldama ;27_V	et	f	\N
212436	investeerimine	investeerimine =investeerimine  (SgN  >investeerimine !12_S	et	f	\N
212437	investeerimine	"investeerimine %investeeri  )MINE_vS  <investeerima ;28_V	et	f	\N
212440	muutumatuks	muutumatuks =muutumatu  (SgTr  >muutumatu !01_A	et	f	\N
212441	muutumatuks	"muutumatu %muutu  )MATU_vA  <muutuma ;27_V	et	f	\N
212459	dramatismi	dramatismi =dramatismi  (SgG  >dramatism !22_S	et	f	\N
212460	dramatismi	dramatismi =dramatismi  (SgP  >dramatism !22_S	et	f	\N
212461	dramatismi	dramatismi =dramatismi  (SgAdt  >dramatism !22_S	et	f	\N
212470	muutuvateks	muutuvateks =muutuva  (PlTr  >muutuv !02_A	et	f	\N
212471	muutuvateks	"muutuv %muutu  )V_vA  <muutuma ;27_V	et	f	\N
212472	muutuvateks	muutuvateks =vate  (PlTr  >muutu+vatt !22_S	et	f	\N
212475	ülaserva	ülaserva =serva  (SgG  >üla+serv !22_S	et	f	\N
212476	ülaserva	ülaserva =serva  (SgP  >üla+serv !22_S	et	f	\N
212477	ülaserva	ülaserva =serva  (SgAdt  >üla+serv !22_S	et	f	\N
212492	sellene	?sellene =sellene  (SgN  >sellene !10_A	et	f	\N
212493	sellene	?sellene =sellene  (IndPrPs_  >sellenema !27_V	et	f	\N
212494	sellene	?sellene =sellene  (ImpPrSg2  >sellenema !27_V	et	f	\N
212510	õhulisem	õhulisem =õhulisem  (SgN  >õhulisem !02_A	et	f	\N
212511	õhulisem	"õhulisem %õhu  )LISEM_cA  <õhk ;22_S	et	f	\N
212512	õhulisem	"õhulisem %õhulise  )M_cA  <õhuline ;12_A	et	f	\N
212513	tähelist	tähelist =tähelis  (SgP  >täheline !12_A	et	f	\N
212514	tähelist	"täheline %tähe  )LINE_aA  <täht ;22_S	et	f	\N
212526	õhtulehet	?õhtulehet =lehe  (SgP  >õhtu+lehe !16_S	et	f	\N
212532	tavapärasuse	tavapärasuse =pärasuse  (SgG  >tava+pärasus !11_S	et	f	\N
212533	tavapärasuse	"tava+pärasus %pära  )SUS_aS  <tava+pära ;17_S	et	f	\N
212556	veeruvahes	veeruvahes =vahe  (SgIn  >veeru+vahe !16_S	et	f	\N
212557	veeruvahes	veeruvahes =vahe  (PlIn  >veeru+vahk !22_S	et	f	\N
212558	veeruvahes	veeruvahes =vahe  (PlIn  >veeru+vaht !22_S	et	f	\N
212578	loetavuse	loetavuse =loetavuse  (SgG  >loetavus !11_S	et	f	\N
212579	loetavuse	"loetavus %loe  )TAVUS_aS  <lugema ;28_V	et	f	\N
212580	loetavuse	"loetavus %loeta  )VUS_aS  <loetama ;27_V	et	f	\N
212596	osakonniti	?osakonniti =osakonni  (IndIpfIps  >osakonnima !28_V	et	f	\N
212597	osakonniti	?osakonniti =osakonniti  (ID  >osakonniti !41_D	et	f	\N
212598	osakonniti	?osakonniti =osakonniti  (SgG  >osakonnitt !22_S	et	f	\N
212599	osakonniti	?osakonniti =osakonniti  (IndPrPs_  >osakonnittima !28_V	et	f	\N
212600	osakonniti	?osakonniti =osakonniti  (ImpPrSg2  >osakonnittima !28_V	et	f	\N
212601	osakonniti	?osakonniti =konniti  (SgG  >osa+konnit !02_S	et	f	\N
212602	osakonniti	?osakonniti =konniti  (SgG  >osa+konnitt !22_S	et	f	\N
212607	laiemat	laiemat =laiema  (SgP  >laiem !02_A	et	f	\N
212608	laiemat	"laiem %laie  )M_cA  <lai ;22_A	et	f	\N
212614	märkamatud	märkamatud =märkamatu  (PlN  >märkamatu !01_A	et	f	\N
212615	märkamatud	"märkamatu %märka  )MATU_vA  <märkama ;29_V	et	f	\N
212635	elavust	elavust =elavus  (SgP  >elavus !11_S	et	f	\N
212636	elavust	"elavus %ela  )VUS_aS  <elama ;27_V	et	f	\N
212637	elavust	"elavus %elava  )US_aS  <elav ;02_A	et	f	\N
212638	elavust	elavust =us  (SgP  >elav+uks !14_S	et	f	\N
212644	veerulaiused	veerulaiused =laiuse  (PlN  >veeru+laius !11~09_S	et	f	\N
212645	veerulaiused	"veeru+laius %lai  )US_aS  <veeru+lai ;22_A	et	f	\N
212646	veerulaiused	veerulaiused =laiuse  (PlN  >veeru+laiune !10~12_A	et	f	\N
212647	veerulaiused	"veeru+laiune %laiu  )NE_aA  <veeru+laid ;22_S	et	f	\N
212671	teiene	?teiene =teiene  (SgN  >teiene !10_A	et	f	\N
212672	teiene	?teiene =teiene  (IndPrPs_  >teienema !27_V	et	f	\N
212673	teiene	?teiene =teiene  (ImpPrSg2  >teienema !27_V	et	f	\N
212674	suurusele	suurusele =suuruse  (SgAll  >suurus !11~09_S	et	f	\N
212675	suurusele	"suurus %suur  )US_aS  <suur ;13_A	et	f	\N
212676	suurusele	suurusele =suuruse  (SgAll  >suurune !10~12_A	et	f	\N
212677	suurusele	suurusele =use  (PlAll  >suur+usk !22_S	et	f	\N
212678	suurusele	suurusele =ruse  (PlAll  >suu+rusk !22_S	et	f	\N
212685	ärata	ärata =ärata  (IndPrPs_  >äratama !27_V	et	f	\N
212686	ärata	ärata =ärata  (ImpPrSg2  >äratama !27_V	et	f	\N
212698	ebausutava	ebausutava =tava  (SgN  >eba+usu+tava !17_S	et	f	\N
212699	ebausutava	ebausutava =tava  (SgG  >eba+usu+tava !17_S	et	f	\N
212700	ebausutava	ebausutava =tava  (SgP  >eba+usu+tava !17_S	et	f	\N
212701	ebausutava	ebausutava =usutava  (SgG  >eba+usutav !02_A	et	f	\N
212733	state	?state =state  (SgN  >state !06_S	et	f	\N
212734	state	?state =state  (IndPrPs_  >statema !27_V	et	f	\N
212735	state	?state =state  (ImpPrSg2  >statema !27_V	et	f	\N
212738	kosuvad	kosuvad =kosu  (IndPrPl3  >kosuma !27_V	et	f	\N
212739	kosuvad	kosuvad =kosuva  (PlN  >kosuv !02_A	et	f	\N
212740	kosuvad	"kosuv %kosu  )V_vA  <kosuma ;27_V	et	f	\N
212741	suusapuhkusest	suusapuhkusest =use  (PlEl  >suusa+puhk+usk !22_S	et	f	\N
212742	suusapuhkusest	suusapuhkusest =puhkuse  (SgEl  >suusa+puhkus !11~09_S	et	f	\N
212743	suusapuhkusest	suusapuhkusest =puhkuses  (SgP  >suusa+puhkusene !12_A	et	f	\N
212529	raami	raami =raami  (SgAdt  >raam !22_S	et	f	\N
212530	raami	raami =raami  (IndPrPs_  >raamima !28_V	et	f	\N
212531	raami	raami =raami  (ImpPrSg2  >raamima !28_V	et	f	\N
212540	vastakleheküljele	### vastakleheküljele	et	f	\N
212570	samateemalised	samateemalised =malise  (PlN  >sama+tee+maline !10_A	et	f	\N
212571	samateemalised	"sama+tee+maline %mali  )NE_aA  <sama+tee+mali ;17_S	et	f	\N
212572	samateemalised	samateemalised =teemalise  (PlN  >sama+teemaline !12_A	et	f	\N
212573	samateemalised	"sama+teemaline %teema  )LINE_aA  <sama+teema ;16_S	et	f	\N
212581	kokkulükatud	kokkulükatud =lüka  (PtsPtIps  >kokku+_lükkama !29_V	et	f	\N
212582	kokkulükatud	kokkulükatud =lükatu  (PlN  >kokku+lükatu !01_AS	et	f	\N
212592	varieerimist	varieerimist =varieerimis  (SgP  >varieerimine !12_S	et	f	\N
212594	varieerimist	"varieerimine %varieeri  )MINE_vS  <varieerima ;28_V	et	f	\N
212612	otsustamisel	otsustamisel =otsustamise  (SgAd  >otsustamine !12_S	et	f	\N
212613	otsustamisel	"otsustamine %otsusta  )MINE_vS  <otsustama ;27_V	et	f	\N
212616	kaarladu	kaarladu =ladu  (SgN  >kaar+ladu !18_S	et	f	\N
212617	kaarladu	kaarladu =ladu  (SgP  >kaar+ladu !18_S	et	f	\N
212623	kolonidenna	?kolonidenna =kolonidenna  (SgN  >kolonidenna !16_S	et	f	\N
212624	kolonidenna	?kolonidenna =kolonidenna  (SgG  >kolonidenna !16_S	et	f	\N
212625	taandatud	taandatud =taanda  (PtsPtIps  >taandama !27_V	et	f	\N
212626	taandatud	taandatud =taandatu  (PlN  >taandatu !01_S	et	f	\N
212627	taandatud	"taandatu %taanda  )TU1_vS  <taandama ;27_V	et	f	\N
212628	taandatud	taandatud =taandatud  (ID  >taandatud !41_A	et	f	\N
212629	taandatud	"taandatud %taanda  )TUD_vA  <taandama ;27_V	et	f	\N
212630	taandatud	taandatud =atu  (PlN  >taand+att !22_S	et	f	\N
212639	tihedamalt	tihedamalt =tihedama  (SgAbl  >tihedam !02_A	et	f	\N
212640	tihedamalt	"tihedam %tiheda  )M_cA  <tihe ;02_A	et	f	\N
212641	tihedamalt	tihedamalt =tihedamalt  (ID  >tihedamalt !41_D	et	f	\N
212642	tihedamalt	"tihedamalt %tiheda  )MALT_mD  <tihe ;02_A	et	f	\N
212649	hallis	hallis =halli  (SgIn  >hall !22_S	et	f	\N
212650	hallis	hallis =halli  (SgIn  >hall !22_AS	et	f	\N
212658	paksed	?paksed =pakse  (PlN  >pakne !02_A	et	f	\N
212659	paksed	?paksed =pakse  (PlN  >pakse !06_S	et	f	\N
212660	paksed	?paksed =pakse  (IndPrSg2  >paksema !27_V	et	f	\N
212664	tähtevahe	### tähtevahe	et	f	\N
212689	ajahetke	ajahetke =hetke  (SgG  >aja+hetk !22_S	et	f	\N
212690	ajahetke	ajahetke =hetke  (SgP  >aja+hetk !22_S	et	f	\N
212691	ajahetke	ajahetke =hetke  (SgAdt  >aja+hetk !22_S	et	f	\N
212692	ajahetke	ajahetke =hetke  (PlP  >aja+hetk !22_S	et	f	\N
212706	pakku	pakku =pakku  (SgP  >pakk !22_S	et	f	\N
212707	pakku	pakku =pakku  (SgAdt  >pagu !18_S	et	f	\N
212708	pakku	pakku =pakku  (SgAdt  >pakk !22_S	et	f	\N
212719	5-realise	-realise =realise  (SgG  >-realine !12?10_A	et	f	\N
212720	5-realise	"-realine %rea  )LINE_aA  <-rida ;18_S	et	f	\N
212730	väiksemas	väiksemas =väiksema  (SgIn  >väiksem !02_A	et	f	\N
212731	väiksemas	"väiksem %väikse  )M_cA  <väike ;10_A	et	f	\N
212736	universityst	?universityst =universityst  (SgN  >universityst !22_S	et	f	\N
212737	universityst	?universityst =versityst  (SgN  >uni+versityst !22_S	et	f	\N
212749	jess	?jess =jess  (SgN  >jess !22_S	et	f	\N
212752	ninjast	?ninjast =ninja  (SgEl  >ninjas !02_A	et	f	\N
212753	ninjast	?ninjast =ninja  (SgEl  >ninja !16_S	et	f	\N
212754	ninjast	?ninjast =ninjas  (SgP  >ninjane !10_A	et	f	\N
212764	lõppmatu	?lõppmatu =lõppmatu  (SgN  >lõppmatu !01_A	et	f	\N
212765	lõppmatu	?lõppmatu =lõppmatu  (SgG  >lõppmatu !01_A	et	f	\N
212766	lõppmatu	?lõppmatu =lõppmatu  (IndPrPs_  >lõppmatuma !27_V	et	f	\N
212767	lõppmatu	?lõppmatu =lõppmatu  (ImpPrSg2  >lõppmatuma !27_V	et	f	\N
212768	lõppmatu	?lõppmatu =matu  (SgN  >lõpp+matu !16_S	et	f	\N
212769	lõppmatu	?lõppmatu =matu  (SgG  >lõpp+matu !16_S	et	f	\N
212783	äp	### äp	et	f	\N
212803	kohtada	?kohtada =ada  (SgN  >koht+ada !17_S	et	f	\N
212804	kohtada	?kohtada =ada  (SgG  >koht+ada !17_S	et	f	\N
212805	kohtada	?kohtada =ada  (SgP  >koht+ada !17_S	et	f	\N
212817	põhivärvi	põhivärvi =värvi  (SgG  >põhi+värv !22_S	et	f	\N
212818	põhivärvi	põhivärvi =värvi  (SgP  >põhi+värv !22_S	et	f	\N
212819	põhivärvi	põhivärvi =värvi  (SgAdt  >põhi+värv !22_S	et	f	\N
212823	sinist	?sinist =sini  (SgEl  >sini !17_S	et	f	\N
212824	sinist	?sinist =sinis  (SgP  >sinis !09_S	et	f	\N
212825	sinist	?sinist =sinis  (SgP  >sinine !10_AS	et	f	\N
212826	sinist	?sinist =sinist  (SgN  >sinist !22_S	et	f	\N
212839	ärgipäevases	?ärgipäevases =ärgipäevase  (SgIn  >ärgipäevane !12_A	et	f	\N
212840	paigaldanud	paigaldanud =paigalda  (PtsPtPs  >paigaldama !27_V	et	f	\N
212841	paigaldanud	paigaldanud =paigaldanu  (PlN  >paigaldanu !01_S	et	f	\N
212842	paigaldanud	"paigaldanu %paigalda  )NU_vS  <paigaldama ;27_V	et	f	\N
212843	paigaldanud	paigaldanud =paigaldanud  (ID  >paigaldanud !41_A	et	f	\N
212844	paigaldanud	"paigaldanud %paigalda  )NUD_vA  <paigaldama ;27_V	et	f	\N
212855	eritähelepanu	eritähelepanu =panu  (SgN  >eri+tähele+panu !17_S	et	f	\N
212856	eritähelepanu	eritähelepanu =panu  (SgG  >eri+tähele+panu !17_S	et	f	\N
212610	veerupikkuse	"veeru+pikkus %pikk  )US_aS  <veeru+pikk ;22_AS	et	f	\N
212611	veerupikkuse	veerupikkuse =pikkuse  (SgG  >veeru+pikkune !12~10_A	et	f	\N
212618	kulgenud	kulgenud =kulge  (PtsPtPs  >kulgema !27_V	et	f	\N
212619	kulgenud	kulgenud =kulgenu  (PlN  >kulgenu !01_S	et	f	\N
212620	kulgenud	"kulgenu %kulge  )NU_vS  <kulgema ;27_V	et	f	\N
212621	kulgenud	kulgenud =kulgenud  (ID  >kulgenud !41_A	et	f	\N
212622	kulgenud	"kulgenud %kulge  )NUD_vA  <kulgema ;27_V	et	f	\N
212631	kares	?kares =kare  (IndIpfSg3  >karema !27_V	et	f	\N
212632	kares	?kares =kares  (SgN  >kares !09_S	et	f	\N
212648	mõndades	?mõndades =mõnda  (PlIn  >mõnda !16_S	et	f	\N
212655	kergetes	kergetes =kerge  (PlIn  >kerge !01_A	et	f	\N
212656	kergetes	kergetes =kerge  (PlIn  >kerge !06_S	et	f	\N
212657	kergetes	kergetes =e  (PlIn  >kerg+esi !15_S	et	f	\N
212661	õhtulehte	õhtulehte =lehte  (SgP  >õhtu+leht !22_S	et	f	\N
212662	õhtulehte	õhtulehte =lehte  (SgAdt  >õhtu+leht !22_S	et	f	\N
212663	õhtulehte	õhtulehte =lehte  (PlP  >õhtu+leht !22_S	et	f	\N
212679	punktilise	punktilise =punktilise  (SgG  >punktiline !12_A	et	f	\N
212680	punktilise	"punktiline %punkti  )LINE_aA  <punkt ;22_S	et	f	\N
212687	fotograafile	fotograafile =fotograafi  (SgAll  >fotograaf !22_S	et	f	\N
212688	fotograafile	fotograafile =graafi  (SgAll  >foto+graaf !22_S	et	f	\N
212693	poseeritud	poseeritud =poseeri  (PtsPtIps  >poseerima !28_V	et	f	\N
212694	poseeritud	poseeritud =poseeritu  (PlN  >poseeritu !01_S	et	f	\N
212695	poseeritud	"poseeritu %poseeri  )TU1_vS  <poseerima ;28_V	et	f	\N
212696	poseeritud	poseeritud =poseeritud  (ID  >poseeritud !41_A	et	f	\N
212697	poseeritud	"poseeritud %poseeri  )TUD_vA  <poseerima ;28_V	et	f	\N
212702	portreedest	portreedest =portree  (PlEl  >portree !26_S	et	f	\N
212703	portreedest	portreedest =reede  (SgEl  >port+reede !01_S	et	f	\N
212704	portreedest	portreedest =reedes  (SgP  >port+reedene !10~12_A	et	f	\N
212705	portreedest	"port+reedene %reede  )NE_aA  <port+reede ;01_S	et	f	\N
212709	tõukavad	tõukavad =tõuka  (IndPrPl3  >tõukama !29_V	et	f	\N
212710	tõukavad	tõukavad =tõukava  (PlN  >tõukav !02_A	et	f	\N
212711	tõukavad	"tõukav %tõuka  )V_vA  <tõukama ;29_V	et	f	\N
212712	tõukavad	tõukavad =kava  (PlN  >tõu+kava !17_S	et	f	\N
212716	fotoallkirja	fotoallkirja =kirja  (SgG  >foto+all+kiri !24_S	et	f	\N
212717	fotoallkirja	fotoallkirja =kirja  (SgP  >foto+all+kiri !24_S	et	f	\N
212718	fotoallkirja	fotoallkirja =kirja  (SgAdt  >foto+all+kiri !24_S	et	f	\N
212721	laiuselt	laiuselt =laiuse  (SgAbl  >laius !11~09_S	et	f	\N
212722	laiuselt	"laius %lai  )US_aS  <lai ;22_A	et	f	\N
212723	laiuselt	laiuselt =laiuse  (SgAbl  >laiune !10~12_A	et	f	\N
212724	laiuselt	"laiune %laiu  )NE_aA  <laid ;22_S	et	f	\N
212725	laiuselt	laiuselt =laiuselt  (ID  >laiuselt !41_D	et	f	\N
212726	laiuselt	"laiuselt %laiu  )SELT_mD  <laid ;22_S	et	f	\N
212727	laiuselt	"laiuselt %laiuse  )LT_mD  <laiune ;10_A	et	f	\N
212728	laiuselt	"laiuselt %laiuse  )LT_mD  <laiune ;12_A	et	f	\N
212729	laiuselt	laiuselt =use  (PlAbl  >lai+usk !22_S	et	f	\N
212755	veenitab	?veenitab =veenita  (IndPrSg3  >veenitama !27_V	et	f	\N
212759	võrdlemisest	võrdlemisest =võrdlemise  (SgEl  >võrdlemine !12_S	et	f	\N
212760	võrdlemisest	"võrdlemine %võrdle  )MINE_vS  <võrdlema ;30_V	et	f	\N
212781	päise	päise =päise  (SgG  >päis !09_S	et	f	\N
212782	päise	päise =päise  (SgG  >päine !10_A	et	f	\N
212792	veebiadress	?veebiadress =veebiadress  (SgN  >veebiadress !22_S	et	f	\N
212793	veebiadress	?veebiadress =biadress  (SgN  >vee+biadress !22_S	et	f	\N
212796	veebis	?veebis =veebi  (SgIn  >veebi !16_S	et	f	\N
212797	veebis	?veebis =veebi  (SgIn  >veep !22_S	et	f	\N
212798	veebis	?veebis =veebi  (IndIpfSg3  >veebima !27_V	et	f	\N
212799	veebis	?veebis =veebis  (SgN  >veebis !09_S	et	f	\N
212827	helesinist	?helesinist =helesini  (SgEl  >helesin !19_S	et	f	\N
212828	helesinist	?helesinist =helesinis  (SgP  >helesinis !09_S	et	f	\N
212829	helesinist	?helesinist =helesinist  (SgN  >helesinist !22_S	et	f	\N
212830	helesinist	?helesinist =sini  (SgEl  >hele+sini !17_S	et	f	\N
212831	helesinist	?helesinist =sinis  (SgP  >hele+sinis !09_S	et	f	\N
212832	helesinist	?helesinist =sinis  (SgP  >hele+sinine !10_AS	et	f	\N
212833	helesinist	?helesinist =sinist  (SgN  >hele+sinist !22_S	et	f	\N
212858	dünaamiliseid	?dünaamiliseid =dünaamilisei  (PlN  >dünaamilisei !26_S	et	f	\N
212859	dünaamiliseid	?dünaamiliseid =dünaamilisei  (SgP  >dünaamilisei !26_S	et	f	\N
212861	ehitiseid	?ehitiseid =ehitisei  (PlN  >ehitisei !26_S	et	f	\N
212862	ehitiseid	?ehitiseid =ehitisei  (SgP  >ehitisei !26_S	et	f	\N
212863	ehitiseid	?ehitiseid =eid  (SgN  >ehitis+eid !22_S	et	f	\N
212873	arvete	arvete =arve  (PlG  >arve !06_S	et	f	\N
212874	arvete	arvete =e  (PlG  >arv+esi !15_S	et	f	\N
212893	märkav	märkav =märka  (PtsPrPs  >märkama !29_V	et	f	\N
212894	märkav	märkav =märkav  (SgN  >märkav !02_A	et	f	\N
212895	märkav	"märkav %märka  )V_vA  <märkama ;29_V	et	f	\N
212899	artiklipealkirja	artiklipealkirja =kirja  (SgG  >artikli+peal+kiri !24_S	et	f	\N
212900	artiklipealkirja	artiklipealkirja =kirja  (SgP  >artikli+peal+kiri !24_S	et	f	\N
212901	artiklipealkirja	artiklipealkirja =kirja  (SgAdt  >artikli+peal+kiri !24_S	et	f	\N
212744	suusapuhkusest	"suusa+puhkusene %puhkuse  )NE_aA  <suusa+puhkus ;09_S	et	f	\N
212745	suusapuhkusest	"suusa+puhkusene %puhkuse  )NE_aA  <suusa+puhkus ;11_S	et	f	\N
212746	suusatamist	suusatamist =suusatamis  (SgP  >suusatamine !12_S	et	f	\N
212747	suusatamist	"suusatamine %suusata  )MINE_vS  <suusatama ;27_V	et	f	\N
212756	portreedes	portreedes =portree  (PlIn  >portree !26_S	et	f	\N
212757	portreedes	portreedes =reede  (SgIn  >port+reede !01_S	et	f	\N
212763	reportaaz	### reportaaz	et	f	\N
212772	võttsin	?võttsin =võttsi  (IndPrSg1  >võttsima !28_V	et	f	\N
212773	võttsin	?võttsin =võttsin  (SgN  >võttsin !02_S	et	f	\N
212774	nimbrit	?nimbrit =nimbri  (SgP  >nimbri !01_S	et	f	\N
212775	nimbrit	?nimbrit =nimbri  (SgP  >nimber !02_S	et	f	\N
212776	nimbrit	?nimbrit =nimbrit  (SgN  >nimbrit !02_S	et	f	\N
212784	tõsiste	tõsiste =tõsis  (PlG  >tõsine !10_A	et	f	\N
212785	tõsiste	"tõsine %tõsi  )NE_aA  <tõsi ;15_S	et	f	\N
212790	alamisel	?alamisel =alamise  (SgAd  >alamine !12_S	et	f	\N
212791	alamisel	?alamisel =isel  (SgN  >alam+isel !02_S	et	f	\N
212800	kellast	kellast =kella  (SgEl  >kell !22_S	et	f	\N
212801	kellast	kellast =kellas  (SgP  >kellane !10_A	et	f	\N
212802	kellast	"kellane %kella  )NE_aA  <kell ;22_S	et	f	\N
212809	trükikirja	trükikirja =kirja  (SgG  >trüki+kiri !24_S	et	f	\N
212810	trükikirja	trükikirja =kirja  (SgP  >trüki+kiri !24_S	et	f	\N
212811	trükikirja	trükikirja =kirja  (SgAdt  >trüki+kiri !24_S	et	f	\N
212815	lehekulje	?lehekulje =kulje  (SgN  >lehe+kulje !06_S	et	f	\N
212816	lehekulje	?lehekulje =kulje  (SgG  >lehe+kulje !06_S	et	f	\N
212820	võtmata	võtmata =võt  (SupAb  >võtma !35_V	et	f	\N
212821	võtmata	võtmata =võtmata  (ID  >võtmata !41_A	et	f	\N
212822	võtmata	"võtmata %võt  )MATA_vA  <võtma ;35_V	et	f	\N
212845	vertikaalselt	vertikaalselt =vertikaalse  (SgAbl  >vertikaalne !02_A	et	f	\N
212846	vertikaalselt	vertikaalselt =vertikaalselt  (ID  >vertikaalselt !41_D	et	f	\N
212847	vertikaalselt	"vertikaalselt %vertikaalse  )LT_mD  <vertikaalne ;02_A	et	f	\N
212848	jaokspeamiselt	?jaokspeamiselt =jaokspeamise  (SgAbl  >jaokspeamine !10_A	et	f	\N
212851	tõsises	tõsises =tõsise  (SgIn  >tõsine !10_A	et	f	\N
212852	tõsises	"tõsine %tõsi  )NE_aA  <tõsi ;15_S	et	f	\N
212864	portreefotosidühesõnaga	### portreefotosidühesõnaga	et	f	\N
212865	arvetes	arvetes =arve  (PlIn  >arve !06_S	et	f	\N
212866	arvetes	arvetes =e  (PlIn  >arv+esi !15_S	et	f	\N
212887	otstarbelist	otstarbelist =tarbelis  (SgP  >ots+tarbeline !12_A	et	f	\N
212888	otstarbelist	"ots+tarbeline %tarbe  )LINE_aA  <ots+tarve ;06_S	et	f	\N
212896	ärgipäevane	?ärgipäevane =ärgipäevane  (SgN  >ärgipäevane !12_A	et	f	\N
212897	punastes	punastes =punas  (PlIn  >punane !10_AS	et	f	\N
212898	punastes	"punane %puna  )NE_aA  <puna ;17_S	et	f	\N
212904	hellistada	?hellistada =hellista  (Inf  >hellistama !27_V	et	f	\N
212915	sinised-punased	sinised-punased =punase  (PlN  >sinised-punane !10_AS	et	f	\N
212916	sinised-punased	"sinised-punane %puna  )NE_aA  <sinised-puna ;17_S	et	f	\N
212920	kollasel	kollasel =kollase  (SgAd  >kollane !10_A	et	f	\N
212921	kollasel	"kollane %kolla  )NE_aA  <kold ;22_S	et	f	\N
212928	fotosuurust	fotosuurust =us  (SgP  >foto+suur+uks !14_S	et	f	\N
212929	fotosuurust	fotosuurust =suurus  (SgP  >foto+suurus !11~09_S	et	f	\N
212930	fotosuurust	"foto+suurus %suur  )US_aS  <foto+suur ;13_A	et	f	\N
212931	fotosuurust	fotosuurust =suurus  (SgP  >foto+suurune !10~12_A	et	f	\N
212932	kaksiklehekülgedest	kaksiklehekülgedest =ede  (SgEl  >kaksik+lehe+külg+ede !16_S	et	f	\N
212933	kaksiklehekülgedest	kaksiklehekülgedest =edes  (SgP  >kaksik+lehe+külg+edene !10_A	et	f	\N
212934	kaksiklehekülgedest	"kaksik+lehe+külg+edene %ede  )NE_aA  <kaksik+lehe+külg+ede ;16_S	et	f	\N
212935	kaksiklehekülgedest	kaksiklehekülgedest =külge  (PlEl  >kaksik+lehe+külg !22_S	et	f	\N
212971	mõlemadel	### mõlemadel	et	f	\N
212982	etappina	?etappina =etappi  (SgEs  >etappi !01_S	et	f	\N
212992	pikemaks	pikemaks =pikema  (SgTr  >pikem !02_A	et	f	\N
212993	pikemaks	"pikem %pike  )M_cA  <pikk ;22_AS	et	f	\N
212994	äripäevast	äripäevast =ast  (SgN  >äri+päev+ast !22_S	et	f	\N
212995	äripäevast	äripäevast =päeva  (SgEl  >äri+päev !22_S	et	f	\N
212996	äripäevast	äripäevast =päevas  (SgP  >äri+päevane !10_A	et	f	\N
212997	äripäevast	"äri+päevane %päeva  )NE_aA  <äri+päev ;22_S	et	f	\N
213013	sobivase	?sobivase =sobivase  (SgG  >sobivane !12_A	et	f	\N
213025	lehekülgi	lehekülgi =külgi  (SgP  >lehe+külg !22_S	et	f	\N
213026	lehekülgi	lehekülgi =külgi  (SgAdt  >lehe+külg !22_S	et	f	\N
213027	lehekülgi	lehekülgi =külgi  (PlP  >lehe+külg !22_S	et	f	\N
213033	informstsiooni	?informstsiooni =informstsioo  (SgTer  >informstsioo !26_S	et	f	\N
213034	informstsiooni	?informstsiooni =informstsiooni  (SgN  >informstsiooni !16_S	et	f	\N
213035	informstsiooni	?informstsiooni =informstsiooni  (SgG  >informstsiooni !16_S	et	f	\N
213036	informstsiooni	?informstsiooni =informstsiooni  (SgG  >informstsioon !22_S	et	f	\N
213037	informstsiooni	?informstsiooni =informstsiooni  (SgP  >informstsioon !22_S	et	f	\N
213038	informstsiooni	?informstsiooni =informstsiooni  (SgAdt  >informstsioon !22_S	et	f	\N
213039	informstsiooni	?informstsiooni =informstsiooni  (IndPrPs_  >informstsioonima !28_V	et	f	\N
212853	niisiguses	?niisiguses =niisiguse  (SgIn  >niisigus !11_S	et	f	\N
212854	niisiguses	?niisiguses =siguse  (SgIn  >nii+sigus !02_A	et	f	\N
212867	artikkleid	?artikkleid =artikkle  (PlP  >artikkli !01_S	et	f	\N
212868	artikkleid	?artikkleid =artikklei  (PlN  >artikklei !26_S	et	f	\N
212869	artikkleid	?artikkleid =artikklei  (SgP  >artikklei !26_S	et	f	\N
212870	ärimeeste	ärimeeste =mees  (PlG  >äri+meene !10_A	et	f	\N
212871	ärimeeste	"äri+meene %mee  )NE_aA  <äri+mesi ;15_S	et	f	\N
212872	ärimeeste	ärimeeste =mees  (PlG  >äri+mees !13_S	et	f	\N
212889	tegemisvaldkonnas	tegemisvaldkonnas =konna  (SgIn  >tegemis+vald+konn !22_S	et	f	\N
212890	tegemisvaldkonnas	tegemisvaldkonnas =valdkonna  (SgIn  >tegemis+valdkond !22_S	et	f	\N
212902	veebi	veebi =veebi  (SgP  >veeb !22_S	et	f	\N
212903	veebi	veebi =veebi  (SgAdt  >veeb !22_S	et	f	\N
212907	trükikirju	trükikirju =kirju  (SgN  >trüki+kirju !01_A	et	f	\N
212908	trükikirju	trükikirju =kirju  (SgN  >trüki+kirju !16_A	et	f	\N
212909	trükikirju	trükikirju =kirju  (SgG  >trüki+kirju !01_A	et	f	\N
212910	trükikirju	trükikirju =kirju  (SgG  >trüki+kirju !16_A	et	f	\N
212911	trükikirju	trükikirju =kirju  (PlP  >trüki+kiri !24_S	et	f	\N
212922	rohelisel	rohelisel =rohelise  (SgAd  >roheline !12_A	et	f	\N
212923	rohelisel	"roheline %rohe  )LINE_aA  <rohe ;16_S	et	f	\N
212945	võrreldanud	?võrreldanud =võrrelda  (PtsPtPs  >võrreldama !27_V	et	f	\N
212946	võrreldanud	?võrreldanud =võrreldanu  (PlN  >võrreldanu !01_S	et	f	\N
212947	võrreldanud	?võrreldanud =võrreldanu  (IndPrSg2  >võrreldanuma !27_V	et	f	\N
212948	võrreldanud	?võrreldanud =võrreldanud  (ID  >võrreldanud !41_A	et	f	\N
212955	tõepärased	tõepärased =pärase  (PlN  >tõe+pärane !10_A	et	f	\N
212956	tõepärased	"tõe+pärane %pära  )NE_aA  <tõe+pära ;17_S	et	f	\N
213017	lajusega	?lajusega =lajuse  (SgKom  >lajus !09_S	et	f	\N
213031	otsitava	otsitava =otsitava  (SgG  >otsitav !02_AS	et	f	\N
213032	otsitava	"otsitav %otsi  )TAV_vAS  <otsima ;28_V	et	f	\N
213041	tiiteltähte	tiiteltähte =tähte  (SgP  >tiitel+täht !22_S	et	f	\N
213042	tiiteltähte	tiiteltähte =tähte  (SgAdt  >tiitel+täht !22_S	et	f	\N
213043	tiiteltähte	tiiteltähte =tähte  (PlP  >tiitel+täht !22_S	et	f	\N
213071	veeerulaiust	veeerulaiust =us  (SgP  >vee+eru+lai+uks !14_S	et	f	\N
213072	veeerulaiust	veeerulaiust =laiu  (SgEl  >vee+eru+laid !22_S	et	f	\N
213073	veeerulaiust	veeerulaiust =laiu  (PlEl  >vee+eru+laid !22_S	et	f	\N
213074	veeerulaiust	veeerulaiust =laiu  (PlEl  >vee+eru+lai !22_A	et	f	\N
213075	veeerulaiust	veeerulaiust =laius  (SgP  >vee+eru+laius !11~09_S	et	f	\N
213076	veeerulaiust	"vee+eru+laius %lai  )US_aS  <vee+eru+lai ;22_A	et	f	\N
213077	veeerulaiust	veeerulaiust =laius  (SgP  >vee+eru+laiune !10~12_A	et	f	\N
213078	veeerulaiust	"vee+eru+laiune %laiu  )NE_aA  <vee+eru+laid ;22_S	et	f	\N
213082	kirjaks	kirjaks =kirja  (SgTr  >kiri !24_S	et	f	\N
213083	kirjaks	kirjaks =kirja  (KndPrPs  >kirjama !29_V	et	f	\N
213090	esilehekülgedel	esilehekülgedel =ede  (SgAd  >esi+lehe+külg+ede !16_S	et	f	\N
213091	esilehekülgedel	esilehekülgedel =edel  (SgN  >esi+lehe+külg+edel !02_S	et	f	\N
213092	esilehekülgedel	esilehekülgedel =külge  (PlAd  >esi+lehe+külg !22_S	et	f	\N
213098	sisukorda	sisukorda =korda  (SgP  >sisu+kord !22_S	et	f	\N
213099	sisukorda	sisukorda =korda  (SgAdt  >sisu+kord !22_S	et	f	\N
213104	muudised	?muudised =muudise  (PlN  >muudis !09_S	et	f	\N
213105	muudised	?muudised =muudise  (IndPrSg2  >muudisema !27_V	et	f	\N
213106	muudised	?muudised =dise  (PlN  >muu+dise !16_S	et	f	\N
213131	noormeest	noormeest =mee  (SgEl  >noor+mesi !15_S	et	f	\N
213132	noormeest	noormeest =mees  (SgP  >noor+meene !10_A	et	f	\N
213133	noormeest	"noor+meene %mee  )NE_aA  <noor+mesi ;15_S	et	f	\N
213134	noormeest	noormeest =mees  (SgP  >noor+mees !13_S	et	f	\N
213138	objektfotodeks	?objektfotodeks =objektfoto  (PlTr  >objektfoto !16_S	et	f	\N
213149	grupifoto	grupifoto =foto  (SgN  >grupi+foto !16_S	et	f	\N
213150	grupifoto	grupifoto =foto  (SgG  >grupi+foto !16_S	et	f	\N
213168	seotavad	seotavad =seotava  (PlN  >seotav !02_A	et	f	\N
213169	seotavad	"seotav %seo  )TAV_vAS  <siduma ;28_V	et	f	\N
213170	must-	must- =mu  (SgEl  >ma !00_P	et	f	\N
213171	must-	must- =must  (SgN  >must !22_AS	et	f	\N
213195	kuulsaimatest	kuulsaimatest =kuulsaima  (PlEl  >kuulsaim !02_A	et	f	\N
213196	kuulsaimatest	"kuulsaim %kuulsa  )IM_sA  <kuulus ;02_A	et	f	\N
213197	kuulsaimatest	kuulsaimatest =mate  (SgEl  >kuul+sai+mate !16_S	et	f	\N
213198	kuulsaimatest	kuulsaimatest =mate  (PlEl  >kuul+sai+matt !22_SA	et	f	\N
213199	kuulsaimatest	kuulsaimatest =mates  (SgP  >kuul+sai+matene !10_A	et	f	\N
213200	kuulsaimatest	"kuul+sai+matene %mate  )NE_aA  <kuul+sai+mate ;16_S	et	f	\N
213209	bakalaureusõpe	### bakalaureusõpe	et	f	\N
213210	süvitsi	?süvitsi =süvitsi  (ID  >süvitsi !41_D	et	f	\N
213211	süvitsi	?süvitsi =süvitsi  (SgG  >süvits !02_S	et	f	\N
213212	süvitsi	?süvitsi =süvitsi  (IndPrPs_  >süvitsima !28_V	et	f	\N
213213	süvitsi	?süvitsi =süvitsi  (ImpPrSg2  >süvitsima !28_V	et	f	\N
213240	hallituse	hallituse =hallituse  (SgG  >hallitus !11_S	et	f	\N
213241	hallituse	"hallitus %hallita  )US_vS  <hallitama ;27_V	et	f	\N
213242	hallituse	"hallitus %halli  )TUS2_aS  <hall ;22_S	et	f	\N
212857	eritähelepanu	eritähelepanu =panu  (SgP  >eri+tähele+panu !17_S	et	f	\N
212877	e-maili	?e-maili =maili  (SgN  >e-maili !16_S	et	f	\N
212878	e-maili	?e-maili =maili  (SgG  >e-maili !16_S	et	f	\N
212879	e-maili	?e-maili =maili  (SgG  >e-mail !22_S	et	f	\N
212880	e-maili	?e-maili =maili  (SgP  >e-mail !22_S	et	f	\N
212881	e-maili	?e-maili =maili  (SgAdt  >e-mail !22_S	et	f	\N
212882	e-maili	?e-maili =maili  (IndPrPs_  >e-mailima !28_V	et	f	\N
212883	e-maili	?e-maili =maili  (ImpPrSg2  >e-mailima !28_V	et	f	\N
212905	kojukande	kojukande =kande  (SgG  >koju+kanne !06_S	et	f	\N
212906	kojukande	kojukande =kande  (PlP  >koju+kand !22_S	et	f	\N
212912	sinises	?sinises =sinise  (SgIn  >sinis !09_S	et	f	\N
212913	sinises	?sinises =sinise  (SgIn  >sinine !10_AS	et	f	\N
212914	sinises	?sinises =sinise  (IndIpfSg3  >sinisema !27_V	et	f	\N
212924	sinisel-rohelisel	sinisel-rohelisel =rohelise  (SgAd  >sinisel-roheline !12_A	et	f	\N
212925	sinisel-rohelisel	"sinisel-roheline %rohe  )LINE_aA  <sinisel-rohe ;16_S	et	f	\N
212939	veergud	?veergud =veergu  (PlN  >veergu !01_S	et	f	\N
212940	veergud	?veergud =veergu  (IndPrSg2  >veerguma !27_V	et	f	\N
212941	eristamiseks	eristamiseks =eristamise  (SgTr  >eristamine !12_S	et	f	\N
212942	eristamiseks	"eristamine %erista  )MINE_vS  <eristama ;27_V	et	f	\N
212953	poliitikutest	poliitikutest =poliitiku  (PlEl  >poliitik !02_S	et	f	\N
212954	poliitikutest	poliitikutest =test  (SgN  >poliitiku+test !22_S	et	f	\N
212958	kastemis	kastemis =mi  (SgIn  >kaste+mi !26_S	et	f	\N
212959	kastemis	kastemis =emis  (SgN  >kast+emis !09_S	et	f	\N
212966	mõlemades	### mõlemades	et	f	\N
212972	ajalehtedel	ajalehtedel =ede  (SgAd  >aja+leht+ede !16_S	et	f	\N
212973	ajalehtedel	ajalehtedel =edel  (SgN  >aja+leht+edel !02_S	et	f	\N
212974	ajalehtedel	ajalehtedel =lehte  (PlAd  >aja+leht !22_S	et	f	\N
212990	investeerimisest	investeerimisest =investeerimise  (SgEl  >investeerimine !12_S	et	f	\N
212991	investeerimisest	"investeerimine %investeeri  )MINE_vS  <investeerima ;28_V	et	f	\N
212998	lhe	### lhe	et	f	\N
212999	olkes	?olkes =olke  (SgIn  >olge !06_S	et	f	\N
213000	olkes	?olkes =olke  (IndIpfSg3  >olkema !27_V	et	f	\N
213001	olkes	?olkes =olkes  (SgN  >olkes !09_S	et	f	\N
213002	krimi	?krimi =krimi  (SgN  >krimi !17_S	et	f	\N
213003	krimi	?krimi =krimi  (SgG  >krimi !17_S	et	f	\N
213004	krimi	?krimi =krimi  (SgP  >krimi !17_S	et	f	\N
213005	krimi	?krimi =krimi  (IndPrPs_  >krimima !27_V	et	f	\N
213006	krimi	?krimi =krimi  (ImpPrSg2  >krimima !27_V	et	f	\N
213007	kuluvad	kuluvad =kulu  (IndPrPl3  >kuluma !27_V	et	f	\N
213008	kuluvad	kuluvad =kuluva  (PlN  >kuluv !02_A	et	f	\N
213009	kuluvad	"kuluv %kulu  )V_vA  <kuluma ;27_V	et	f	\N
213011	korrastamine	korrastamine =korrastamine  (SgN  >korrastamine !12_S	et	f	\N
213012	korrastamine	"korrastamine %korrasta  )MINE_vS  <korrastama ;27_V	et	f	\N
213014	tekstikirja	tekstikirja =kirja  (SgG  >teksti+kiri !24_S	et	f	\N
213015	tekstikirja	tekstikirja =kirja  (SgP  >teksti+kiri !24_S	et	f	\N
213016	tekstikirja	tekstikirja =kirja  (SgAdt  >teksti+kiri !24_S	et	f	\N
213018	heleroosal	heleroosal =roosa  (SgAd  >hele+roosa !16_AS	et	f	\N
213019	heleroosal	heleroosal =roosa  (SgAd  >hele+roosk !22_S	et	f	\N
213020	kirja-	kirja- =kirja  (SgG  >kiri !24_S	et	f	\N
213021	kirja-	kirja- =kirja  (SgP  >kiri !24_S	et	f	\N
213022	kirja-	kirja- =kirja  (SgAdt  >kiri !24_S	et	f	\N
213023	kirja-	kirja- =kirja  (IndPrPs_  >kirjama !29_V	et	f	\N
213024	kirja-	kirja- =kirja  (ImpPrSg2  >kirjama !29_V	et	f	\N
213028	lihtsus	lihtsus =lihtsus  (SgN  >lihtsus !11~09_S	et	f	\N
213029	lihtsus	"lihtsus %lihtsa  )US_aS  <lihtne ;02_A	et	f	\N
213030	lihtsus	"lihtsus %lihtse  )US_aS  <lihtne ;02_A	et	f	\N
213049	kapslisse	kapslisse =kapsli  (SgIll  >kapsel !02_S	et	f	\N
213050	kapslisse	kapslisse =kapslis  (SgAdt  >kapsline !12_A	et	f	\N
213051	kapslisse	"kapsline %kapsli  )NE_aA  <kapsel ;02_S	et	f	\N
213055	pealkirjsdest	?pealkirjsdest =pealkirjsdes  (SgP  >pealkirjsdene !12_A	et	f	\N
213056	pealkirjsdest	?pealkirjsdest =kirjsde  (SgEl  >peal+kirjsde !06_S	et	f	\N
213057	pealkirjsdest	?pealkirjsdest =kirjsde  (PlEl  >peal+kirjsd !22_S	et	f	\N
213058	pealkirjsdest	?pealkirjsdest =kirjsdes  (SgP  >peal+kirjsdes !09_S	et	f	\N
213059	pealkirjsdest	?pealkirjsdest =kirjsdes  (SgP  >peal+kirjsdene !12~10_A	et	f	\N
213060	lühikesed-	lühikesed- =lühikese  (PlN  >lühike !12_A	et	f	\N
213061	lühikesed-	"lühike %lühi  )KE_dS  <lüht ;22_S	et	f	\N
213062	lühikesed-	lühikesed- =lühikese  (PlN  >lühikene !12_S	et	f	\N
213063	lühikesed-	"lühikene %lühi  )KENE_dS  <lüht ;22_S	et	f	\N
213084	pikemaid	pikemaid =pikema  (PlP  >pikem !02_A	et	f	\N
213085	pikemaid	"pikem %pike  )M_cA  <pikk ;22_AS	et	f	\N
213088	päevakajaline	päevakajaline =kajaline  (SgN  >päeva+kajaline !12_A	et	f	\N
213089	päevakajaline	"päeva+kajaline %kaja  )LINE_aA  <päeva+kaja ;17_S	et	f	\N
213093	televisiooniga	televisiooniga =televisiooni  (SgKom  >televisioon !22_S	et	f	\N
213094	televisiooniga	televisiooniga =visiooni  (SgKom  >tele+visioon !22_S	et	f	\N
213113	numerastioon	?numerastioon =numerastioon  (SgN  >numerastioon !22_S	et	f	\N
213126	reidi	reidi =reidi  (SgG  >reid !22_S	et	f	\N
213127	reidi	reidi =reidi  (SgP  >reid !22_S	et	f	\N
212885	pinguta	pinguta =pinguta  (IndPrPs_  >pingutama !27_V	et	f	\N
212886	pinguta	pinguta =pinguta  (ImpPrSg2  >pingutama !27_V	et	f	\N
212891	äripaev	?äripaev =äripaev  (SgN  >äripaev !22_S	et	f	\N
212892	äripaev	?äripaev =paev  (SgN  >äri+paev !22_S	et	f	\N
212926	karikatuurid	karikatuurid =karikatuuri  (PlN  >karikatuur !22_S	et	f	\N
212927	karikatuurid	karikatuurid =tuuri  (PlN  >karika+tuur !22_S	et	f	\N
212936	väsita	väsita =väsi  (IndPrIps_  >väsima !27_V	et	f	\N
212937	väsita	väsita =väsita  (IndPrPs_  >väsitama !27_V	et	f	\N
212938	väsita	väsita =väsita  (ImpPrSg2  >väsitama !27_V	et	f	\N
212943	kirjakeelele	kirjakeelele =keele  (SgAll  >kirja+keel !13_S	et	f	\N
212944	kirjakeelele	kirjakeelele =keele  (PlAll  >kirja+keeld !22_S	et	f	\N
212957	kujundeidvärvilisi	?kujundeidvärvilisi =kujundeidvärvilisi  (PlP  >kujundeidvärviline !12_A	et	f	\N
212964	teisipäevases	teisipäevases =päevase  (SgIn  >teisi+päevane !10_A	et	f	\N
212965	teisipäevases	"teisi+päevane %päeva  )NE_aA  <teisi+päev ;22_S	et	f	\N
212968	ületavad	ületavad =ületa  (IndPrPl3  >ületama !27_V	et	f	\N
212969	ületavad	ületavad =ületava  (PlN  >ületav !02_A	et	f	\N
212970	ületavad	"ületav %ületa  )V_vA  <ületama ;27_V	et	f	\N
212979	kiirjutan	?kiirjutan =kiirjuta  (IndPrSg1  >kiirjutama !27_V	et	f	\N
212980	kiirjutan	?kiirjutan =kiirjutan  (SgN  >kiirjutan !19_S	et	f	\N
212981	kiirjutan	?kiirjutan =jutan  (SgN  >kiir+jutan !02_S	et	f	\N
212983	trükkitatud	?trükkitatud =trükkita  (PtsPtIps  >trükkitama !27_V	et	f	\N
212984	trükkitatud	?trükkitatud =trükkitatu  (PlN  >trükkitatu !01_S	et	f	\N
212985	trükkitatud	?trükkitatud =trükkitatu  (IndPrSg2  >trükkitatuma !27_V	et	f	\N
212986	trükkitatud	?trükkitatud =trükkitatud  (ID  >trükkitatud !41_A	et	f	\N
212987	trükkitatud	?trükkitatud =tatu  (PlN  >trükki+tatu !16_S	et	f	\N
212988	pangadest	?pangadest =panga  (PlEl  >panga !16_S	et	f	\N
212989	pangadest	?pangadest =pangades  (SgP  >pangadene !12_A	et	f	\N
213044	lõigude	?lõigude =lõigu  (PlG  >lõigu !16_S	et	f	\N
213066	heleroosa	heleroosa =roosa  (SgN  >hele+roosa !16_AS	et	f	\N
213067	heleroosa	heleroosa =roosa  (SgG  >hele+roosa !16_AS	et	f	\N
213068	heleroosa	heleroosa =roosa  (SgG  >hele+roosk !22_S	et	f	\N
213069	varieeri	varieeri =varieeri  (IndPrPs_  >varieerima !28_V	et	f	\N
213070	varieeri	varieeri =varieeri  (ImpPrSg2  >varieerima !28_V	et	f	\N
213095	sisekülgedel	sisekülgedel =ede  (SgAd  >sise+külg+ede !16_S	et	f	\N
213096	sisekülgedel	sisekülgedel =edel  (SgN  >sise+külg+edel !02_S	et	f	\N
213097	sisekülgedel	sisekülgedel =külge  (PlAd  >sise+külg !22_S	et	f	\N
213108	numeratsiooni	numeratsiooni =numeratsiooni  (SgG  >numeratsioon !22_S	et	f	\N
213109	numeratsiooni	numeratsiooni =numeratsiooni  (SgP  >numeratsioon !22_S	et	f	\N
213110	numeratsiooni	numeratsiooni =numeratsiooni  (SgAdt  >numeratsioon !22_S	et	f	\N
213112	ajelehe	### ajelehe	et	f	\N
213114	keskle	?keskle =keskle  (SgN  >keskle !06_S	et	f	\N
213115	keskle	?keskle =keskle  (SgG  >keskle !06_S	et	f	\N
213116	keskle	?keskle =keskle  (IndPrPs_  >kesklema !30_V	et	f	\N
213117	keskle	?keskle =keskle  (ImpPrSg2  >kesklema !30_V	et	f	\N
213145	autoavarii	autoavarii =avarii  (SgN  >auto+avarii !26_S	et	f	\N
213146	autoavarii	autoavarii =avarii  (SgG  >auto+avarii !26_S	et	f	\N
213151	trans	?trans =trans  (SgN  >trans !22_S	et	f	\N
213201	elustunud	elustunud =elustu  (PtsPtPs  >elustuma !27_V	et	f	\N
213202	elustunud	elustunud =elustunu  (PlN  >elustunu !01_S	et	f	\N
213203	elustunud	"elustunu %elustu  )NU_vS  <elustuma ;27_V	et	f	\N
213204	elustunud	elustunud =elustunud  (ID  >elustunud !41_A	et	f	\N
213205	elustunud	"elustunud %elustu  )NUD_vA  <elustuma ;27_V	et	f	\N
213206	saanneid	?saanneid =saannei  (PlN  >saannei !26_S	et	f	\N
213207	saanneid	?saanneid =saannei  (SgP  >saannei !26_S	et	f	\N
213208	saanneid	?saanneid =saanneid  (SgN  >saanneid !22_S	et	f	\N
213223	praktiliseid	?praktiliseid =praktilisei  (PlN  >praktilisei !26_S	et	f	\N
213224	praktiliseid	?praktiliseid =praktilisei  (SgP  >praktilisei !26_S	et	f	\N
213225	auditoorne	?auditoorne =auditoorne  (SgN  >auditoorne !02_A	et	f	\N
213226	auditoorne	?auditoorne =auditoorne  (PlP  >auditoorn !22_S	et	f	\N
213227	auditoorne	?auditoorne =ditoorne  (SgN  >au+ditoorne !02_A	et	f	\N
213228	auditoorne	?auditoorne =ditoorne  (PlP  >au+ditoorn !22_S	et	f	\N
213229	kergemad	kergemad =kergema  (PlN  >kergem !02_A	et	f	\N
213230	kergemad	"kergem %kerge  )M_cA  <kerge ;01_A	et	f	\N
213231	kergemad	kergemad =ema  (PlN  >kerg+ema !17_S	et	f	\N
213234	teravmeelitsesid	teravmeelitsesid =meelitse  (IndIpfSg2  >terav+meelitsema !27_V	et	f	\N
213235	teravmeelitsesid	teravmeelitsesid =meelitse  (IndIpfPl3  >terav+meelitsema !27_V	et	f	\N
213263	kogukonda	kogukonda =kogukonda  (SgP  >kogukond !22_S	et	f	\N
213264	kogukonda	kogukonda =kogukonda  (SgAdt  >kogukond !22_S	et	f	\N
213265	leedukas	?leedukas =leeduka  (SgIn  >leeduka !01_S	et	f	\N
213266	leedukas	?leedukas =leeduka  (SgIn  >leedukas !02_A	et	f	\N
213267	leedukas	?leedukas =leedukas  (SgN  >leedukas !02_A	et	f	\N
213284	õppejoududega	?õppejoududega =joudu  (PlKom  >õppe+joudu !16_S	et	f	\N
213294	sloveenias	?sloveenias =sloveenia  (SgIn  >sloveenia !01_S	et	f	\N
213295	sloveenias	?sloveenias =sloveenias  (SgN  >sloveenias !11_S	et	f	\N
212917	segaselt	segaselt =segase  (SgAbl  >segane !10_A	et	f	\N
212918	segaselt	segaselt =segaselt  (ID  >segaselt !41_D	et	f	\N
212919	segaselt	"segaselt %segase  )LT_mD  <segane ;10_A	et	f	\N
212949	rahvakihide	?rahvakihide =kihi  (PlG  >rahva+kihi !17_S	et	f	\N
212950	kuulsustest	kuulsustest =kuulsus  (PlEl  >kuulsus !11~09_S	et	f	\N
212951	kuulsustest	"kuulsus %kuulsa  )US_aS  <kuulus ;02_A	et	f	\N
212952	kuulsustest	kuulsustest =test  (SgN  >kuulsus+test !22_S	et	f	\N
212960	loeta	loeta =loe  (SgAb  >lood !22_S	et	f	\N
212961	loeta	loeta =loe  (IndPrIps_  >lugema !28_V	et	f	\N
212962	loeta	loeta =loeta  (IndPrPs_  >loetama !27_V	et	f	\N
212963	loeta	loeta =loeta  (ImpPrSg2  >loetama !27_V	et	f	\N
212967	õhtujalehes	### õhtujalehes	et	f	\N
212975	ausameelselt	ausameelselt =meelse  (SgAbl  >ausa+meelne !02_A	et	f	\N
212976	ausameelselt	"ausa+meelselt %meelse  )LT_mD  <ausa+meelne ;02_A	et	f	\N
212977	reedesed	reedesed =reedese  (PlN  >reedene !10~12_A	et	f	\N
212978	reedesed	"reedene %reede  )NE_aA  <reede ;01_S	et	f	\N
213010	repotraazid	?repotraazid =repotraazi  (PlN  >repotraazi !16_S	et	f	\N
213045	vähemolulisi	vähemolulisi =olulisi  (PlP  >vähem+oluline !12_A	et	f	\N
213046	vähemolulisi	"vähem+oluline %olu  )LINE_aA  <vähem+olu ;17_S	et	f	\N
213047	vähemolulisi	vähemolulisi =molulisi  (PlP  >vähe+moluline !12_A	et	f	\N
213048	vähemolulisi	"vähe+moluline %molu  )LINE_aA  <vähe+molu ;17_S	et	f	\N
213079	son	### son	et	f	\N
213086	lugejaks	lugejaks =lugeja  (SgTr  >lugeja !01_S	et	f	\N
213087	lugejaks	"lugeja %luge  )JA_vS  <lugema ;28_V	et	f	\N
213111	tähtsim	?tähtsim =tähtsim  (SgN  >tähtsim !02_A	et	f	\N
213118	vasskpoolse	?vasskpoolse =vasskpoolse  (SgG  >vasskpoolne !02_A	et	f	\N
213119	vasskpoolse	?vasskpoolse =vasskpoolse  (PlP  >vasskpools !22_S	et	f	\N
213124	metsakoolis	metsakoolis =kooli  (SgIn  >metsa+kool !22_S	et	f	\N
213125	metsakoolis	metsakoolis =kooli  (PlIn  >metsa+kool !22_S	et	f	\N
213135	katkev	katkev =katke  (PtsPrPs  >katkema !27_V	et	f	\N
213136	katkev	katkev =katkev  (SgN  >katkev !02_A	et	f	\N
213137	katkev	"katkev %katke  )V_vA  <katkema ;27_V	et	f	\N
213147	ohvriterohke	ohvriterohke =rohke  (SgN  >ohvrite+rohke !01_A	et	f	\N
213148	ohvriterohke	ohvriterohke =rohke  (SgG  >ohvrite+rohke !01_A	et	f	\N
213152	sportlaste	sportlaste =sportlas  (PlG  >sportlane !12?10_S	et	f	\N
213153	sportlaste	sportlaste =las  (PlG  >sport+laps !14_S	et	f	\N
213154	sportlaste	sportlaste =laste  (PlP  >sport+last !22_S	et	f	\N
213155	näoilmele	näoilmele =ilme  (SgAll  >näo+ilme !06_S	et	f	\N
213156	näoilmele	näoilmele =ilme  (PlAll  >näo+ilm !22_S	et	f	\N
213164	dramaatilisemaks	dramaatilisemaks =dramaatilisema  (SgTr  >dramaatilisem !02_A	et	f	\N
213165	dramaatilisemaks	"dramaatilisem %dramaatilise  )M_cA  <dramaatiline ;12_A	et	f	\N
213184	sündmusfoto	sündmusfoto =foto  (SgN  >sündmus+foto !16_S	et	f	\N
213185	sündmusfoto	sündmusfoto =foto  (SgG  >sündmus+foto !16_S	et	f	\N
213214	lühemalt	lühemalt =lühema  (SgAbl  >lühem !02_A	et	f	\N
213215	lühemalt	"lühem %lühe  )M_cA  <lühike ;12_A	et	f	\N
213216	lühemalt	lühemalt =lühemalt  (ID  >lühemalt !41_D	et	f	\N
213217	lühemalt	"lühemalt %lühema  )LT_mD  <lühem ;02_A	et	f	\N
213246	kõrvaleriala	kõrvaleriala =ala  (SgN  >kõrval+eri+ala !17_S	et	f	\N
213247	kõrvaleriala	kõrvaleriala =ala  (SgG  >kõrval+eri+ala !17_S	et	f	\N
213248	kõrvaleriala	kõrvaleriala =ala  (SgP  >kõrval+eri+ala !17_S	et	f	\N
213249	nädalast	nädalast =nädala  (SgEl  >nädal !02_S	et	f	\N
213250	nädalast	nädalast =nädalas  (SgP  >nädalane !12_A	et	f	\N
213251	nädalast	"nädalane %nädala  )NE_aA  <nädal ;02_S	et	f	\N
213268	ujed	?ujed =uje  (IndPrSg2  >ujema !27_V	et	f	\N
213269	üliõpolased	?üliõpolased =üliõpolase  (PlN  >üliõpolane !12_S	et	f	\N
213270	üliõpolased	?üliõpolased =õpolase  (PlN  >üli+õpolane !12_S	et	f	\N
213271	viniuse	?viniuse =viniuse  (SgG  >vinius !11_S	et	f	\N
213285	eksamite-arvestuste	eksamite-arvestuste =arvestus  (PlG  >eksamite-arvestus !11_S	et	f	\N
213286	eksamite-arvestuste	"eksamite-arvestus %arvesta  )US_vS  <eksamite-arvestama ;27_V	et	f	\N
213307	raskim	?raskim =raskim  (SgN  >raskim !02_A	et	f	\N
213321	maitsevat	maitsevat =maitse  (KvtPrPs  >maitsema !28_V	et	f	\N
213322	maitsevat	maitsevat =maitseva  (SgP  >maitsev !02_A	et	f	\N
213323	maitsevat	"maitsev %maits  )V_vA  <maitsma ;32_V	et	f	\N
213324	maitsevat	"maitsev %maitse  )V_vA  <maitsema ;28_V	et	f	\N
213328	tüdrukutega	tüdrukutega =tüdruku  (PlKom  >tüdruk !02_S	et	f	\N
213329	tüdrukutega	tüdrukutega =ute  (SgKom  >tüdruk+utt !22_S	et	f	\N
213330	kauam	?kauam =kauam  (SgN  >kauam !02_S	et	f	\N
213333	ebaviisakad	ebaviisakad =aka  (PlN  >eba+viis+aka !16_S	et	f	\N
213334	ebaviisakad	ebaviisakad =viisaka  (PlN  >eba+viisakas !02_A	et	f	\N
213358	tellnud	?tellnud =tellnu  (PlN  >tellnu !01_S	et	f	\N
213359	tellnud	?tellnud =tellnu  (IndPrSg2  >tellnuma !27_V	et	f	\N
213360	tellnud	?tellnud =tellnud  (ID  >tellnud !41_A	et	f	\N
213363	karttulidega	### karttulidega	et	f	\N
213367	jaalutada	?jaalutada =jaaluta  (Inf  >jaalutama !27_V	et	f	\N
213376	paljuks	paljuks =palju  (SgTr  >palju !16_P	et	f	\N
213377	paljuks	paljuks =paljuks  (ID  >paljuks !41_D	et	f	\N
213040	informstsiooni	?informstsiooni =informstsiooni  (ImpPrSg2  >informstsioonima !28_V	et	f	\N
213052	paksemad	paksemad =paksema  (PlN  >paksem !02_A	et	f	\N
213053	paksemad	"paksem %pakse  )M_cA  <paks ;22_AS	et	f	\N
213054	paksemad	paksemad =ema  (PlN  >paks+ema !17_S	et	f	\N
213064	pelakirju	?pelakirju =pelakirju  (IndPrPs_  >pelakirjuma !27_V	et	f	\N
213065	pelakirju	?pelakirju =pelakirju  (ImpPrSg2  >pelakirjuma !27_V	et	f	\N
213080	äratuntav	äratuntav =tun  (PtsPrIps  >ära+_tundma !34_V	et	f	\N
213081	äratuntav	äratuntav =tuntav  (SgN  >ära+tuntav !02_A	et	f	\N
213100	kiiret	kiiret =kiire  (SgP  >kiire !01_A	et	f	\N
213101	kiiret	kiiret =kiire  (SgP  >kiire !06_S	et	f	\N
213102	kiiret	kiiret =kiire  (SgP  >kiire !06_AS	et	f	\N
213103	23marts	?marts =marts  (SgN  >marts !22_S	et	f	\N
213107	lugejte	?lugejte =lugejte  (PlP  >lugejt !22_S	et	f	\N
213120	parempolne	?parempolne =parempolne  (SgN  >parempolne !02_A	et	f	\N
213121	parempolne	?parempolne =parempolne  (PlP  >parempoln !22_S	et	f	\N
213122	parempolne	?parempolne =polne  (SgN  >parem+polne !02_A	et	f	\N
213123	parempolne	?parempolne =polne  (PlP  >parem+poln !22_S	et	f	\N
213129	õpolast	?õpolast =õpola  (SgEl  >õpola !01_S	et	f	\N
213130	õpolast	?õpolast =õpolas  (SgP  >õpolane !12_S	et	f	\N
213139	kijutatud	?kijutatud =kijuta  (PtsPtIps  >kijutama !27_V	et	f	\N
213140	kijutatud	?kijutatud =kijutatu  (PlN  >kijutatu !01_S	et	f	\N
213141	kijutatud	?kijutatud =kijutatu  (IndPrSg2  >kijutatuma !27_V	et	f	\N
213142	kijutatud	?kijutatud =kijutatud  (ID  >kijutatud !41_A	et	f	\N
213175	pöördama	?pöördama =pöörda  (Sup  >pöördama !27_V	et	f	\N
213176	pöördama	?pöördama =pöördama  (SgG  >pöördam !02_A	et	f	\N
213177	pöördama	?pöördama =ama  (SgN  >pöörd+ama !17_S	et	f	\N
213178	pöördama	?pöördama =ama  (SgG  >pöörd+ama !17_S	et	f	\N
213179	pöördama	?pöördama =ama  (SgP  >pöörd+ama !17_S	et	f	\N
213186	poolpaksus	poolpaksus =paksu  (SgIn  >pool+paks !22_AS	et	f	\N
213187	poolpaksus	poolpaksus =paksus  (SgN  >pool+paksus !11~09_S	et	f	\N
213188	poolpaksus	"pool+paksus %paks  )US_aS  <pool+paks ;22_AS	et	f	\N
213191	puudustele	puudustele =puudus  (PlAll  >puudus !11~09_S	et	f	\N
213192	puudustele	puudustele =duste  (PlAll  >puu+dust !22_S	et	f	\N
213193	sarnasused	sarnasused =sarnasuse  (PlN  >sarnasus !11_S	et	f	\N
213194	sarnasused	"sarnasus %sarna  )SUS_aS  <sarn ;22_S	et	f	\N
213221	peahoonega	peahoonega =hoone  (SgKom  >pea+hoone !06_S	et	f	\N
213222	peahoonega	"pea+hoone %hoo  )NE_aA  <pea+hoog ;22_S	et	f	\N
213252	soovitavaid	soovitavaid =soovitava  (PlP  >soovitav !02_A	et	f	\N
213253	soovitavaid	"soovitav %soovi  )TAV_vAS  <soovima ;28_V	et	f	\N
213254	soovitavaid	"soovitav %soovita  )V_vA  <soovitama ;27_V	et	f	\N
213255	kohalikute	?kohalikute =kohaliku  (IndPrPl2  >kohalikuma !27_V	et	f	\N
213272	preestrid	preestrid =preestri  (PlN  >preester !02_S	et	f	\N
213273	preestrid	preestrid =estri  (PlN  >pre+ester !02_S	et	f	\N
213274	põhihoone	põhihoone =hoone  (SgN  >põhi+hoone !06_S	et	f	\N
213275	põhihoone	"põhi+hoone %hoo  )NE_aA  <põhi+hoog ;22_S	et	f	\N
213276	põhihoone	põhihoone =hoone  (SgG  >põhi+hoone !06_S	et	f	\N
213277	põhihoone	põhihoone =hoone  (PlP  >põhi+hoon !22_A	et	f	\N
213281	sipelgapesa	sipelgapesa =pesa  (SgN  >sipelga+pesa !17_S	et	f	\N
213282	sipelgapesa	sipelgapesa =pesa  (SgG  >sipelga+pesa !17_S	et	f	\N
213283	sipelgapesa	sipelgapesa =pesa  (SgP  >sipelga+pesa !17_S	et	f	\N
213313	külmem	külmem =külmem  (SgN  >külmem !02_A	et	f	\N
213314	külmem	"külmem %külme  )M_cA  <külm ;22_AS	et	f	\N
213317	kaifivad	?kaifivad =kaifi  (IndPrPl3  >kaifima !28_V	et	f	\N
213318	kaifivad	?kaifivad =kaifiva  (PlN  >kaifiva !01_S	et	f	\N
213319	kaifivad	?kaifivad =kaifiva  (PlN  >kaifiv !02_A	et	f	\N
213320	kaifivad	?kaifivad =fiva  (PlN  >kai+fiva !17_S	et	f	\N
213341	järgemisel	?järgemisel =järgemise  (SgAd  >järgemine !12_S	et	f	\N
213342	lahkesed	?lahkesed =lahkese  (PlN  >lahkene !12~10_A	et	f	\N
213347	neljakümnendal	?neljakümnendal =neljakümnenda  (SgAd  >neljakümnenda !16_S	et	f	\N
213348	neljakümnendal	?neljakümnendal =neljakümnendal  (SgN  >neljakümnendal !02_S	et	f	\N
213349	neljakümnendal	?neljakümnendal =kümnenda  (SgAd  >nelja+kümnenda !01_S	et	f	\N
213366	lõuna-tallinnas	?lõuna-tallinnas =tallinna  (SgIn  >lõuna-tallinna !16_S	et	f	\N
213378	tamsalusse	?tamsalusse =tamsalu  (SgIll  >tamsalu !01_S	et	f	\N
213379	tamsalusse	?tamsalusse =tamsalus  (SgAdt  >tamsalus !11_S	et	f	\N
213380	tamsalusse	?tamsalusse =tamsalusse  (SgG  >tamsalusne !02_A	et	f	\N
213381	tamsalusse	?tamsalusse =tamsalusse  (PlP  >tamsaluss !22_S	et	f	\N
213387	hubasid	?hubasid =huba  (PlP  >huba !17_S	et	f	\N
213388	hubasid	?hubasid =huba  (IndIpfSg2  >hubama !27_V	et	f	\N
213389	hubasid	?hubasid =huba  (IndIpfPl3  >hubama !27_V	et	f	\N
213390	kunstigaleriit	?kunstigaleriit =kunstigaleriit  (SgN  >kunstigaleriit !22_S	et	f	\N
213391	kunstigaleriit	?kunstigaleriit =eriit  (SgN  >kunst+igal+eriit !22_S	et	f	\N
213392	kunstigaleriit	?kunstigaleriit =leriit  (SgN  >kunst+iga+leriit !22_S	et	f	\N
213393	kunstigaleriit	?kunstigaleriit =galeriit  (SgN  >kunsti+galeriit !22_S	et	f	\N
213394	kunstigaleriit	?kunstigaleriit =igaleriit  (SgN  >kunst+igaleriit !22_S	et	f	\N
213128	reidi	reidi =reidi  (SgAdt  >reid !22_S	et	f	\N
213143	sokeeriv	?sokeeriv =sokeeri  (PtsPrPs  >sokeerima !28_V	et	f	\N
213144	sokeeriv	?sokeeriv =sokeeriv  (SgN  >sokeeriv !02_A	et	f	\N
213157	standaartsed	?standaartsed =standaartse  (PlN  >standaartne !02_A	et	f	\N
213158	standaartsed	?standaartsed =standaartse  (IndPrSg2  >standaartsema !27_V	et	f	\N
213159	tüütavaks	tüütavaks =tüütava  (SgTr  >tüütav !02_A	et	f	\N
213160	tüütavaks	"tüütav %tüüta  )V_vA  <tüütama ;29_V	et	f	\N
213161	vapustavad	vapustavad =vapusta  (IndPrPl3  >vapustama !27_V	et	f	\N
213162	vapustavad	vapustavad =vapustava  (PlN  >vapustav !02_A	et	f	\N
213163	vapustavad	"vapustav %vapusta  )V_vA  <vapustama ;27_V	et	f	\N
213166	dünaamilisemaks	dünaamilisemaks =dünaamilisema  (SgTr  >dünaamilisem !02_A	et	f	\N
213167	dünaamilisemaks	"dünaamilisem %dünaamilise  )M_cA  <dünaamiline ;12_A	et	f	\N
213172	vahendaja	vahendaja =vahendaja  (SgN  >vahendaja !01_S	et	f	\N
213173	vahendaja	"vahendaja %vahenda  )JA_vS  <vahendama ;27_V	et	f	\N
213174	vahendaja	vahendaja =vahendaja  (SgG  >vahendaja !01_S	et	f	\N
213180	kõrvaline	kõrvaline =kõrvaline  (SgN  >kõrvaline !12_A	et	f	\N
213181	kõrvaline	"kõrvaline %kõrva  )LINE_aA  <kõrv ;22_S	et	f	\N
213182	kõrvaline	kõrvaline =ine  (SgN  >kõrval+ine !16_S	et	f	\N
213183	kõrvaline	kõrvaline =ine  (SgG  >kõrval+ine !16_S	et	f	\N
213189	headning	?headning =headning  (SgN  >headning !02_S	et	f	\N
213190	headning	?headning =dning  (SgN  >hea+dning !22_S	et	f	\N
213218	ammendavad	ammendavad =ammenda  (IndPrPl3  >ammendama !27_V	et	f	\N
213219	ammendavad	ammendavad =ammendava  (PlN  >ammendav !02_A	et	f	\N
213220	ammendavad	"ammendav %ammenda  )V_vA  <ammendama ;27_V	et	f	\N
213232	abivalmid	abivalmid =valmi  (PlN  >abi+valmis !02_A	et	f	\N
213233	abivalmid	abivalmid =valmi  (PlN  >abi+valm !22_S	et	f	\N
213236	sessioonit	?sessioonit =sessiooni  (SgP  >sessiooni !16_S	et	f	\N
213237	haisevad	haisevad =haise  (IndPrPl3  >haisema !28_V	et	f	\N
213238	haisevad	haisevad =haiseva  (PlN  >haisev !02_A	et	f	\N
213239	haisevad	"haisev %haise  )V_vA  <haisema ;28_V	et	f	\N
213256	vahetusüliõpilastega	vahetusüliõpilastega =las  (PlKom  >vahetus+üli+õpi+laps !14_S	et	f	\N
213257	vahetusüliõpilastega	vahetusüliõpilastega =õpilas  (PlKom  >vahetus+üli+õpilane !12_S	et	f	\N
213258	kadestanud	kadestanud =kadesta  (PtsPtPs  >kadestama !27_V	et	f	\N
213259	kadestanud	kadestanud =kadestanu  (PlN  >kadestanu !01_S	et	f	\N
213260	kadestanud	"kadestanu %kadesta  )NU_vS  <kadestama ;27_V	et	f	\N
213261	kadestanud	kadestanud =kadestanud  (ID  >kadestanud !41_A	et	f	\N
213262	kadestanud	"kadestanud %kadesta  )NUD_vA  <kadestama ;27_V	et	f	\N
213292	modernsust	modernsust =modernsus  (SgP  >modernsus !11~09_S	et	f	\N
213293	modernsust	"modernsus %modernse  )US_aS  <modernne ;02_A	et	f	\N
213300	seid	?seid =sei  (PlN  >sei !26_S	et	f	\N
213301	seid	?seid =sei  (SgP  >sei !26_S	et	f	\N
213302	seid	?seid =seid  (SgN  >seid !22_S	et	f	\N
213338	randas	?randas =randa  (SgIn  >randa !16_S	et	f	\N
213339	randas	?randas =randa  (IndIpfSg3  >randama !29_V	et	f	\N
213340	randas	?randas =randas  (SgN  >randas !07_S	et	f	\N
213345	visakad	?visakad =visaka  (PlN  >visaka !01_S	et	f	\N
213346	visakad	?visakad =visaka  (PlN  >visakas !02_A	et	f	\N
213368	jaalutasime	?jaalutasime =jaaluta  (IndIpfPl1  >jaalutama !27_V	et	f	\N
213383	käsitööt	?käsitööt =käsitööt  (SgN  >käsitööt !22_S	et	f	\N
213384	käsitööt	?käsitööt =tööt  (SgN  >käsi+tööt !22_S	et	f	\N
213424	sünnimaale	sünnimaale =maa  (SgAll  >sünni+maa !26_S	et	f	\N
213425	sünnimaale	sünnimaale =maale  (PlP  >sünni+maal !22_S	et	f	\N
213432	hullemat	hullemat =hullema  (SgP  >hullem !02_A	et	f	\N
213433	hullemat	"hullem %hulle  )M_cA  <hull ;22_AS	et	f	\N
213446	laimu	laimu =laimu  (SgG  >laim !22_S	et	f	\N
213447	laimu	laimu =laimu  (SgP  >laim !22_S	et	f	\N
213448	laimu	laimu =laimu  (SgAdt  >laim !22_S	et	f	\N
213449	laimu	laimu =laimu  (PlP  >laim !22_S	et	f	\N
213450	neiu-tiina	?neiu-tiina =tii  (SgEs  >neiu-tii !26_S	et	f	\N
213451	neiu-tiina	?neiu-tiina =tiina  (SgN  >neiu-tiina !16_S	et	f	\N
213452	neiu-tiina	?neiu-tiina =tiina  (SgG  >neiu-tiina !16_S	et	f	\N
213453	neiu-tiina	?neiu-tiina =tiina  (IndPrPs_  >neiu-tiinama !29_V	et	f	\N
213454	neiu-tiina	?neiu-tiina =tiina  (ImpPrSg2  >neiu-tiinama !29_V	et	f	\N
213464	elukidlasti	?elukidlasti =elukidlasti  (ID  >elukidlasti !41_D	et	f	\N
213465	elukidlasti	?elukidlasti =elukidlasti  (SgG  >elukidlast !22_S	et	f	\N
213466	elukidlasti	?elukidlasti =elukidlasti  (SgP  >elukidlast !22_S	et	f	\N
213467	elukidlasti	?elukidlasti =elukidlasti  (SgAdt  >elukidlast !22_S	et	f	\N
213468	elukidlasti	?elukidlasti =elukidlasti  (IndPrPs_  >elukidlastima !28_V	et	f	\N
213469	elukidlasti	?elukidlasti =elukidlasti  (ImpPrSg2  >elukidlastima !28_V	et	f	\N
213470	hästiaga	?hästiaga =hästia  (SgKom  >hästia !01_S	et	f	\N
213475	visakaltma	?visakaltma =visakaltma  (SgN  >visakaltma !16_S	et	f	\N
213476	visakaltma	?visakaltma =visakaltma  (SgG  >visakaltma !16_S	et	f	\N
213512	olenud	?olenud =olenu  (PlN  >olenu !01_S	et	f	\N
213513	olenud	?olenud =olenu  (IndPrSg2  >olenuma !27_V	et	f	\N
213514	olenud	?olenud =olenud  (ID  >olenud !41_A	et	f	\N
213243	loengutele	loengutele =loengu  (PlAll  >loeng !02_S	et	f	\N
213244	loengutele	loengutele =ute  (SgAll  >loeng+utt !22_S	et	f	\N
213245	loengutele	loengutele =ute  (PlAll  >loeng+utt !22_S	et	f	\N
213278	sipelgapesa	sipelgapesa =pesa  (SgN  >sipelga+pesa !17_S	et	f	\N
213279	sipelgapesa	sipelgapesa =pesa  (SgG  >sipelga+pesa !17_S	et	f	\N
213280	sipelgapesa	sipelgapesa =pesa  (SgP  >sipelga+pesa !17_S	et	f	\N
213287	erutatud	erutatud =eruta  (PtsPtIps  >erutama !27_V	et	f	\N
213288	erutatud	erutatud =erutatu  (PlN  >erutatu !01_S	et	f	\N
213289	erutatud	"erutatu %eruta  )TU1_vS  <erutama ;27_V	et	f	\N
213290	erutatud	erutatud =erutatud  (ID  >erutatud !41_A	et	f	\N
213291	erutatud	"erutatud %eruta  )TUD_vA  <erutama ;27_V	et	f	\N
213296	naiskoori	naiskoori =koor  (PlP  >nais+koor !13_S	et	f	\N
213297	naiskoori	naiskoori =koori  (SgG  >nais+koor !22_S	et	f	\N
213298	naiskoori	naiskoori =koori  (SgP  >nais+koor !22_S	et	f	\N
213299	naiskoori	naiskoori =koori  (SgAdt  >nais+koor !22_S	et	f	\N
213311	sloveenia	?sloveenia =sloveenia  (SgN  >sloveenia !01_S	et	f	\N
213312	sloveenia	?sloveenia =sloveenia  (SgG  >sloveenia !01_S	et	f	\N
213331	soolane	soolane =soolane  (SgN  >soolane !10_A	et	f	\N
213332	soolane	"soolane %soola  )NE_aA  <sool ;22_S	et	f	\N
213335	osknud	?osknud =osknu  (PlN  >osknu !01_S	et	f	\N
213336	osknud	?osknud =osknu  (IndPrSg2  >osknuma !27_V	et	f	\N
213337	osknud	?osknud =osknud  (ID  >osknud !41_A	et	f	\N
213343	avastust	avastust =avastus  (SgP  >avastus !11_S	et	f	\N
213344	avastust	"avastus %avasta  )US_vS  <avastama ;27_V	et	f	\N
213364	tarto	?tarto =tarto  (SgN  >tarto !16_S	et	f	\N
213365	tarto	?tarto =tarto  (SgG  >tarto !16_S	et	f	\N
213371	eelimine	?eelimine =eelimine  (SgN  >eelimine !12_S	et	f	\N
213372	eelimine	?eelimine =eelimine  (PlP  >eelimin !19_S	et	f	\N
213373	eelimine	?eelimine =imine  (SgN  >eel+imine !10_A	et	f	\N
213374	täiskohaga	täiskohaga =koha  (SgKom  >täis+koha !17_S	et	f	\N
213375	täiskohaga	täiskohaga =koha  (SgKom  >täis+koht !22_S	et	f	\N
213385	kristiines	?kristiines =kristiine  (PlIn  >kristiin !22_S	et	f	\N
213386	kristiines	?kristiines =kristiine  (IndIpfSg3  >kristiinema !27_V	et	f	\N
213401	vooruseks	vooruseks =vooruse  (SgTr  >voorus !11~09_S	et	f	\N
213402	vooruseks	vooruseks =ruse  (PlTr  >voo+rusk !22_S	et	f	\N
213411	kõigilee	?kõigilee =kõigilee  (SgN  >kõigilee !26_S	et	f	\N
213412	kõigilee	?kõigilee =kõigilee  (SgG  >kõigilee !26_S	et	f	\N
213414	pöörepunkt	### pöörepunkt	et	f	\N
213415	märga	märga =märga  (SgP  >märg !22_AS	et	f	\N
213416	märga	märga =märga  (SgAdt  >märg !22_AS	et	f	\N
213417	märga	märga =märga  (IndPrPs_  >märgama !29_V	et	f	\N
213418	märga	märga =märga  (ImpPrSg2  >märgama !29_V	et	f	\N
213436	usutavad	usutavad =usuta  (IndPrPl3  >usutama !27_V	et	f	\N
213437	usutavad	usutavad =usutava  (PlN  >usutav !02_A	et	f	\N
213438	usutavad	"usutav %usu  )TAV_vAS  <uskuma ;28_V	et	f	\N
213439	usutavad	"usutav %usuta  )V_vA  <usutama ;27_V	et	f	\N
213440	usutavad	usutavad =tava  (PlN  >usu+tava !17_S	et	f	\N
213441	vapustavalt	vapustavalt =vapustava  (SgAbl  >vapustav !02_A	et	f	\N
213442	vapustavalt	"vapustav %vapusta  )V_vA  <vapustama ;27_V	et	f	\N
213443	vapustavalt	vapustavalt =vapustavalt  (ID  >vapustavalt !41_D	et	f	\N
213444	vapustavalt	"vapustavalt %vapusta  )VALT_mD  <vapustama ;27_V	et	f	\N
213445	vapustavalt	"vapustavalt %vapustava  )LT_mD  <vapustav ;02_A	et	f	\N
213477	vastutuslikult	?vastutuslikult =vastutusliku  (SgAbl  >vastutuslik !25_A	et	f	\N
213478	vastutuslikult	?vastutuslikult =vastutuslikult  (ID  >vastutuslikult !41_D	et	f	\N
213479	vastutuslikult	?vastutuslikult =tusliku  (SgAbl  >vastu+tuslik !25_A	et	f	\N
213480	vastutuslikult	?vastutuslikult =tusliku  (SgAbl  >vastu+tusliku !01_S	et	f	\N
213481	vastutuslikult	?vastutuslikult =utusliku  (SgAbl  >vast+utuslik !25_A	et	f	\N
213484	peaimine	?peaimine =peaimine  (SgN  >peaimine !10_A	et	f	\N
213485	peaimine	?peaimine =imine  (SgN  >pea+imine !10_A	et	f	\N
213486	öppetööd	?öppetööd =öppetöö  (PlN  >öppetöö !26_S	et	f	\N
213487	öppetööd	?öppetööd =öppetöö  (SgP  >öppetöö !26_S	et	f	\N
213488	öppetööd	?öppetööd =öppetööd  (SgN  >öppetööd !22_S	et	f	\N
213494	infoabimees	infoabimees =mee  (SgIn  >info+abi+mesi !15_S	et	f	\N
213495	infoabimees	infoabimees =mees  (SgN  >info+abi+mees !13_S	et	f	\N
213498	ericsson	?ericsson =ericsson  (SgN  >ericsson !02_S	et	f	\N
213509	vajuta	vajuta =vaju  (IndPrIps_  >vajuma !27_V	et	f	\N
213510	vajuta	vajuta =vajuta  (IndPrPs_  >vajutama !27_V	et	f	\N
213511	vajuta	vajuta =vajuta  (ImpPrSg2  >vajutama !27_V	et	f	\N
213526	päevarongi	päevarongi =rongi  (SgG  >päeva+rong !22_S	et	f	\N
213527	päevarongi	päevarongi =rongi  (SgP  >päeva+rong !22_S	et	f	\N
213528	päevarongi	päevarongi =rongi  (SgAdt  >päeva+rong !22_S	et	f	\N
213538	loosimised	loosimised =loosimise  (PlN  >loosimine !12_S	et	f	\N
213539	loosimised	"loosimine %loosi  )MINE_vS  <loosima ;28_V	et	f	\N
213550	vahetund	vahetund =un  (SgP  >vahet+uni !20_S	et	f	\N
213551	vahetund	vahetund =und  (SgN  >vahet+und !22_S	et	f	\N
213552	vahetund	vahetund =tund  (SgN  >vahe+tund !22_S	et	f	\N
213303	baltireisi	baltireisi =reis  (PlP  >balti+reis !14_S	et	f	\N
213304	baltireisi	baltireisi =reisi  (SgG  >balti+reis !22_S	et	f	\N
213305	baltireisi	baltireisi =reisi  (SgP  >balti+reis !22_S	et	f	\N
213306	baltireisi	baltireisi =reisi  (SgAdt  >balti+reis !22_S	et	f	\N
213308	püüdud	?püüdud =püüdu  (PlN  >püüdu !16_S	et	f	\N
213309	püüdud	?püüdud =püüdu  (IndPrSg2  >püüduma !27_V	et	f	\N
213310	püüdud	?püüdud =püüdud  (ID  >püüdud !41_A	et	f	\N
213315	kõigal	?kõigal =kõiga  (SgAd  >kõiga !16_S	et	f	\N
213316	kõigal	?kõigal =kõigal  (SgN  >kõigal !02_S	et	f	\N
213325	peaasja	peaasja =asja  (SgG  >pea+asi !24_S	et	f	\N
213326	peaasja	peaasja =asja  (SgP  >pea+asi !24_S	et	f	\N
213327	peaasja	peaasja =asja  (SgAdt  >pea+asi !24_S	et	f	\N
213350	kilpkoonasuppi	?kilpkoonasuppi =kilpkoonasuppi  (SgP  >kilpkoonasupp !22_S	et	f	\N
213351	kilpkoonasuppi	?kilpkoonasuppi =kilpkoonasuppi  (SgAdt  >kilpkoonasupp !22_S	et	f	\N
213352	kilpkoonasuppi	?kilpkoonasuppi =asuppi  (SgN  >kilp+koon+asuppi !01_S	et	f	\N
213353	kilpkoonasuppi	?kilpkoonasuppi =asuppi  (SgG  >kilp+koon+asuppi !01_S	et	f	\N
213354	kilpkoonasuppi	?kilpkoonasuppi =asuppi  (SgP  >kilp+koon+asupp !22_S	et	f	\N
213355	kilpkoonasuppi	?kilpkoonasuppi =asuppi  (SgAdt  >kilp+koon+asupp !22_S	et	f	\N
213356	kilpkoonasuppi	?kilpkoonasuppi =koonasuppi  (SgP  >kilp+koonasupp !22_S	et	f	\N
213357	kilpkoonasuppi	?kilpkoonasuppi =koonasuppi  (SgAdt  >kilp+koonasupp !22_S	et	f	\N
213361	eestland	?eestland =eestland  (SgN  >eestland !02_S	et	f	\N
213362	eestland	?eestland =land  (SgN  >eest+land !22_S	et	f	\N
213369	kohtata	?kohtata =kohtata  (IndPrPs_  >kohtatama !27_V	et	f	\N
213370	kohtata	?kohtata =kohtata  (ImpPrSg2  >kohtatama !27_V	et	f	\N
213395	joonistamist	joonistamist =joonistamis  (SgP  >joonistamine !12_S	et	f	\N
213396	joonistamist	"joonistamine %joonista  )MINE_vS  <joonistama ;27_V	et	f	\N
213403	ülemerenaabrik	?ülemerenaabrik =ülemerenaabrik  (SgN  >ülemerenaabrik !02_S	et	f	\N
213404	ülemerenaabrik	?ülemerenaabrik =naabrik  (SgN  >üle+mere+naabrik !25_S	et	f	\N
213405	ülemerenaabrik	?ülemerenaabrik =erenaabrik  (SgN  >ülem+erenaabrik !02_S	et	f	\N
213406	ülemerenaabrik	?ülemerenaabrik =merenaabrik  (SgN  >üle+merenaabrik !02_S	et	f	\N
213426	katastroofiga	katastroofiga =katastroofi  (SgKom  >katastroof !22_S	et	f	\N
213427	katastroofiga	katastroofiga =iga  (SgN  >katastroof+iga !18_S	et	f	\N
213428	katastroofiga	katastroofiga =iga  (SgP  >katastroof+iga !18_S	et	f	\N
213455	looduslaps	looduslaps =laps  (SgN  >loodus+laps !14_S	et	f	\N
213456	looduslaps	looduslaps =laps  (SgN  >loodus+laps !22_S	et	f	\N
213463	sestet	?sestet =seste  (SgP  >seste !06_S	et	f	\N
213482	oppetöös	?oppetöös =oppetöö  (SgIn  >oppetöö !26_S	et	f	\N
213483	oppetöös	?oppetöös =oppetöös  (SgN  >oppetöös !22_S	et	f	\N
213507	sisestamine	sisestamine =sisestamine  (SgN  >sisestamine !12_S	et	f	\N
213508	sisestamine	"sisestamine %sisesta  )MINE_vS  <sisestama ;27_V	et	f	\N
213517	mõtlisime	?mõtlisime =mõtli  (IndIpfPl1  >mõtlima !28_V	et	f	\N
213518	lumehelbed	lumehelbed =helbe  (PlN  >lume+helve !06_S	et	f	\N
213519	lumehelbed	lumehelbed =helbe  (PlN  >lume+helves !07_S	et	f	\N
213542	jäätsid	?jäätsid =jäät  (IndIpfSg2  >jäätma !34_V	et	f	\N
213543	jäätsid	?jäätsid =jäät  (IndIpfPl3  >jäätma !34_V	et	f	\N
213544	jäätsid	?jäätsid =jäätsi  (PlN  >jääts !22_S	et	f	\N
213545	jäätsid	?jäätsid =jäätsi  (IndPrSg2  >jäätsima !28_V	et	f	\N
213580	tasakalukas	?tasakalukas =tasakaluka  (SgIn  >tasakalukas !02_A	et	f	\N
213581	tasakalukas	?tasakalukas =tasakaluka  (SgIn  >tasakaluka !16_S	et	f	\N
213582	tasakalukas	?tasakalukas =tasakalukas  (SgN  >tasakalukas !02_A	et	f	\N
213583	tasakalukas	?tasakalukas =kaluka  (SgIn  >tasa+kaluka !01_S	et	f	\N
213584	tasakalukas	?tasakalukas =kaluka  (SgIn  >tasa+kalukas !02_A	et	f	\N
213585	tasakalukas	?tasakalukas =kalukas  (SgN  >tasa+kalukas !02_A	et	f	\N
213586	peenetundeline	peenetundeline =tundeline  (SgN  >peene+tundeline !12_A	et	f	\N
213587	peenetundeline	"peene+tundeline %tunde  )LINE_aA  <peene+tunne ;06_S	et	f	\N
213588	peenetundeline	"peene+tundeline %tundeli  )NE_aA  <peene+tundel ;02_S	et	f	\N
213595	kreenholmi	?kreenholmi =kreenholmi  (SgN  >kreenholmi !01_S	et	f	\N
213596	kreenholmi	?kreenholmi =kreenholmi  (SgG  >kreenholmi !01_S	et	f	\N
213597	kreenholmi	?kreenholmi =kreenholmi  (SgG  >kreenholm !22_S	et	f	\N
213598	kreenholmi	?kreenholmi =kreenholmi  (SgP  >kreenholm !22_S	et	f	\N
213599	kreenholmi	?kreenholmi =kreenholmi  (SgAdt  >kreenholm !22_S	et	f	\N
213600	kreenholmi	?kreenholmi =kreenholmi  (IndPrPs_  >kreenholmima !28_V	et	f	\N
213601	kreenholmi	?kreenholmi =kreenholmi  (ImpPrSg2  >kreenholmima !28_V	et	f	\N
213610	cosmopolitan	?cosmopolitan =cosmopolita  (IndPrSg1  >cosmopolitama !27_V	et	f	\N
213611	cosmopolitan	?cosmopolitan =cosmopolitan  (SgN  >cosmopolitan !19_S	et	f	\N
213612	välissündmustest	välissündmustest =test  (SgN  >välis+sündmus+test !22_S	et	f	\N
213613	välissündmustest	välissündmustest =sündmus  (PlEl  >välis+sündmus !11~09_S	et	f	\N
213645	kujutlusmaailma	kujutlusmaailma =ilma  (SgG  >kujutlus+maa+ilm !22_S	et	f	\N
213646	kujutlusmaailma	kujutlusmaailma =ilma  (SgP  >kujutlus+maa+ilm !22_S	et	f	\N
213647	kujutlusmaailma	kujutlusmaailma =ilma  (SgAdt  >kujutlus+maa+ilm !22_S	et	f	\N
213650	hingelistele	hingelistele =hingelis  (PlAll  >hingeline !12_SA	et	f	\N
213382	lõõgatame	?lõõgatame =lõõgata  (IndPrPl1  >lõõgatama !27_V	et	f	\N
213397	kolin	kolin =koli  (IndPrSg1  >kolima !27_V	et	f	\N
213398	kolin	kolin =kolin  (SgN  >kolin !02_S	et	f	\N
213399	tajutakse	tajutakse =taju  (IndPrIps  >tajuma !27_V	et	f	\N
213400	tajutakse	tajutakse =takse  (PlP  >taju+taks !22_S	et	f	\N
213407	viinajuua	?viinajuua =viinajuua  (SgN  >viinajuua !01_S	et	f	\N
213408	viinajuua	?viinajuua =viinajuua  (SgG  >viinajuua !01_S	et	f	\N
213409	viinajuua	?viinajuua =juua  (SgN  >viina+juua !16_S	et	f	\N
213410	viinajuua	?viinajuua =juua  (SgG  >viina+juua !16_S	et	f	\N
213413	hildaga	?hildaga =hilda  (SgKom  >hilda !16_S	et	f	\N
213419	kaotuseks	kaotuseks =kaotuse  (SgTr  >kaotus !11~09_S	et	f	\N
213420	kaotuseks	"kaotus %kaota  )US_vS  <kaotama ;27_V	et	f	\N
213421	kaotuseks	"kaotus %kao  )TUS1_aS  <kaduma ;28_V	et	f	\N
213422	kaotuseks	"kaotus %kao  )TUS2_aS  <kabu ;18_S	et	f	\N
213423	kaotuseks	"kaotus %kao  )TUS2_aS  <kadu ;18_S	et	f	\N
213429	kokkuostu	kokkuostu =ostu  (SgG  >kokku+ost !22_S	et	f	\N
213430	kokkuostu	kokkuostu =ostu  (SgP  >kokku+ost !22_S	et	f	\N
213431	kokkuostu	kokkuostu =ostu  (SgAdt  >kokku+ost !22_S	et	f	\N
213434	võltsid	võltsid =võltsi  (PlN  >võlts !22_A	et	f	\N
213435	võltsid	võltsid =võltsi  (IndPrSg2  >võltsima !28_V	et	f	\N
213457	hullumeelsust	hullumeelsust =meelsus  (SgP  >hullu+meelsus !11~09_S	et	f	\N
213458	hullumeelsust	"hullu+meelsus %meelse  )US_aS  <hullu+meelne ;02_A	et	f	\N
213471	keskeltmõnetes	?keskeltmõnetes =keskeltmõnete  (PlIn  >keskeltmõnett !22_S	et	f	\N
213472	keskeltmõnetes	?keskeltmõnetes =mõnete  (PlIn  >keskelt+mõnett !22_S	et	f	\N
213473	keskeltmõnetes	?keskeltmõnetes =eltmõnete  (PlIn  >kesk+eltmõnett !22_S	et	f	\N
213474	hinnedaga	### hinnedaga	et	f	\N
213489	oppeainetele	?oppeainetele =oppeainete  (PlAll  >oppeainett !22_S	et	f	\N
213490	oppeainetele	?oppeainetele =oppeainetele  (IndPrPs_  >oppeainetelema !36_V	et	f	\N
213491	oppeainetele	?oppeainetele =oppeainetele  (ImpPrSg2  >oppeainetelema !36_V	et	f	\N
213501	ümbriku	ümbriku =ümbriku  (SgG  >ümbrik !02_S	et	f	\N
213502	ümbriku	ümbriku =ümbriku  (SgG  >ümbrik !25_S	et	f	\N
213503	kõneteade	kõneteade =teade  (SgN  >kõne+teade !05_S	et	f	\N
213504	kõneteade	kõneteade =teade  (SgN  >kõne+teade !06_S	et	f	\N
213505	kõneteade	kõneteade =teade  (PlP  >kõne+tead !22_S	et	f	\N
213523	riietusime	riietusime =riietu  (IndIpfPl1  >riietuma !27_V	et	f	\N
213524	riietusime	riietusime =ime  (SgN  >riietus+ime !16_S	et	f	\N
213525	riietusime	riietusime =ime  (SgG  >riietus+ime !16_S	et	f	\N
213529	aulasse	aulasse =aula  (SgIll  >aula !01_S	et	f	\N
213530	aulasse	aulasse =aula  (SgIll  >aula !16_S	et	f	\N
213531	aulasse	aulasse =aulas  (SgAdt  >aulane !12_S	et	f	\N
213532	aulasse	"aulane %aula  )NE_aA  <aula ;01_S	et	f	\N
213533	aulasse	"aulane %aula  )NE_aA  <aula ;16_S	et	f	\N
213534	aulasse	aulasse =la  (SgIll  >au+la !26_S	et	f	\N
213535	aulasse	aulasse =lasse  (PlP  >au+lass !22_S	et	f	\N
213546	määlestused	?määlestused =määlestuse  (PlN  >määlestus !11_S	et	f	\N
213563	vareandiks	?vareandiks =vareandi  (SgTr  >vareant !22_S	et	f	\N
213564	vareandiks	?vareandiks =vareandi  (KndPrPs  >vareantima !28_V	et	f	\N
213568	resultadid	### resultadid	et	f	\N
213575	parimatesse	parimatesse =parima  (PlIll  >parim !02_A	et	f	\N
213576	parimatesse	"parim %pari  )IM_sA  <hea ;26_A	et	f	\N
213577	õppelaenu	õppelaenu =laenu  (SgG  >õppe+laen !22_S	et	f	\N
213578	õppelaenu	õppelaenu =laenu  (SgP  >õppe+laen !22_S	et	f	\N
213579	õppelaenu	õppelaenu =laenu  (SgAdt  >õppe+laen !22_S	et	f	\N
213591	alluvatele	alluvatele =alluva  (PlAll  >alluv !02_AS	et	f	\N
213592	alluvatele	"alluv %allu  )V_vA  <alluma ;27_V	et	f	\N
213593	gorod	?gorod =goro  (PlN  >goro !17~16_S	et	f	\N
213594	gorod	?gorod =gorod  (SgN  >gorod !02_S	et	f	\N
213616	parendamisel	parendamisel =parendamise  (SgAd  >parendamine !12_S	et	f	\N
213617	parendamisel	"parendamine %parenda  )MINE_vS  <parendama ;27_V	et	f	\N
213635	sulamit	sulamit =sulami  (SgP  >sulam !02_S	et	f	\N
213636	sulamit	"sulam %sula  )M_cA  <sula ;17_AS	et	f	\N
213654	elukvaliteeti	elukvaliteeti =kvaliteeti  (SgP  >elu+kvaliteet !22_S	et	f	\N
213655	elukvaliteeti	elukvaliteeti =kvaliteeti  (SgAdt  >elu+kvaliteet !22_S	et	f	\N
213674	pakilised	pakilised =pakilise  (PlN  >pakiline !12_A	et	f	\N
213675	pakilised	"pakiline %paki  )LINE_aA  <pakk ;22_S	et	f	\N
213690	esinemiskultuuri	esinemiskultuuri =kultuuri  (SgG  >esinemis+kultuur !22_S	et	f	\N
213691	esinemiskultuuri	esinemiskultuuri =kultuuri  (SgP  >esinemis+kultuur !22_S	et	f	\N
213692	esinemiskultuuri	esinemiskultuuri =kultuuri  (SgAdt  >esinemis+kultuur !22_S	et	f	\N
213696	hingeliselt	hingeliselt =hingelise  (SgAbl  >hingeline !12_SA	et	f	\N
213697	hingeliselt	"hingeline %hinge  )LINE_aA  <hing ;22_S	et	f	\N
213698	hingeliselt	hingeliselt =hingeliselt  (ID  >hingeliselt !41_D	et	f	\N
213699	hingeliselt	"hingeliselt %hinge  )LISELT_mD  <hing ;22_S	et	f	\N
213710	segeva	?segeva =segeva  (SgN  >segeva !01_S	et	f	\N
213711	segeva	?segeva =segeva  (SgG  >segeva !01_S	et	f	\N
213712	segeva	?segeva =segeva  (SgG  >segev !02_A	et	f	\N
213459	julmust	julmust =julmus  (SgP  >julmus !11~09_S	et	f	\N
213460	julmust	"julmus %julm  )US_aS  <julm ;22_A	et	f	\N
213461	missusused	?missusused =missususe  (PlN  >missusus !11_S	et	f	\N
213462	missusused	?missusused =sususe  (PlN  >mis+susus !09_S	et	f	\N
213492	sootitamisest	?sootitamisest =sootitamise  (SgEl  >sootitamine !12_S	et	f	\N
213493	sootitamisest	?sootitamisest =titamise  (SgEl  >soo+titamine !12_S	et	f	\N
213496	ericssoni	?ericssoni =ericsso  (SgTer  >ericsso !01_S	et	f	\N
213497	ericssoni	?ericssoni =ericssoni  (SgG  >ericsson !02_S	et	f	\N
213499	abimees	abimees =mee  (SgIn  >abi+mesi !15_S	et	f	\N
213500	abimees	abimees =mees  (SgN  >abi+mees !13_S	et	f	\N
213506	etap	?etap =etap  (SgN  >etap !02_S	et	f	\N
213515	üksluine	üksluine =luine  (SgN  >üks+luine !10_A	et	f	\N
213516	üksluine	"üks+luine %lui  )NE_aA  <üks+luu ;26_S	et	f	\N
213520	päkapikke	päkapikke =pikke  (SgG  >päka+pike !06_S	et	f	\N
213521	päkapikke	päkapikke =pikke  (PlP  >päka+pikk !22_S	et	f	\N
213522	päkapikke	päkapikke =pikke  (PlP  >päka+pikk !22_AS	et	f	\N
213536	üksteistele	üksteistele =teis  (PlAll  >üks+teise !12_P	et	f	\N
213537	üksteistele	üksteistele =teiste  (PlAll  >üks+teist !22_S	et	f	\N
213540	disko	?disko =disko  (SgN  >disko !16_S	et	f	\N
213541	disko	?disko =disko  (SgG  >disko !16_S	et	f	\N
213553	vahetunnil	vahetunnil =unni  (PlAd  >vahet+und !22_S	et	f	\N
213554	vahetunnil	vahetunnil =tunni  (SgAd  >vahe+tund !22_S	et	f	\N
213555	koridori	koridori =koridori  (SgG  >koridor !19_S	et	f	\N
213556	koridori	koridori =koridori  (SgP  >koridor !19_S	et	f	\N
213557	koridori	koridori =koridori  (SgAdt  >koridor !19_S	et	f	\N
213571	õpeasutustesse	?õpeasutustesse =õpeasutus  (PlIll  >õpeasutus !11?09_S	et	f	\N
213572	õpeasutustesse	?õpeasutustesse =õpeasutustes  (SgAdt  >õpeasutustene !12_A	et	f	\N
213573	õpeasutustesse	?õpeasutustesse =õpeasutustesse  (SgG  >õpeasutustesne !02_A	et	f	\N
213574	õpeasutustesse	?õpeasutustesse =õpeasutustesse  (PlP  >õpeasutustess !22_S	et	f	\N
213589	kaaslasimõistev	?kaaslasimõistev =kaaslasimõistev  (SgN  >kaaslasimõistev !02_A	et	f	\N
213590	kaaslasimõistev	?kaaslasimõistev =imõistev  (SgN  >kaaslas+imõistev !02_A	et	f	\N
213614	linnavalitsusel	linnavalitsusel =use  (PlAd  >linn+ava+lits+usk !22_S	et	f	\N
213615	linnavalitsusel	linnavalitsusel =valitsuse  (SgAd  >linna+valitsus !11_S	et	f	\N
213618	tegemisi	tegemisi =tegemisi  (PlP  >tegemine !12_S	et	f	\N
213619	tegemisi	"tegemine %tege  )MINE_vS  <tegema ;28_V	et	f	\N
213626	ujumisest	ujumisest =ujumise  (SgEl  >ujumine !12_S	et	f	\N
213627	ujumisest	"ujumine %uju  )MINE_vS  <ujuma ;27_V	et	f	\N
213628	ujumisest	"ujumine %ujumi  )NE_aA  <ujum ;02_S	et	f	\N
213629	moetrendidega	?moetrendidega =trendi  (PlKom  >moe+trendi !16_S	et	f	\N
213630	moetrendidega	?moetrendidega =trendi  (PlKom  >moe+trend !22_S	et	f	\N
213633	kaunitest	kaunitest =kauni  (PlEl  >kaunis !05_A	et	f	\N
213634	kaunitest	kaunitest =test  (SgN  >kauni+test !22_S	et	f	\N
213641	viker	?viker =viker  (SgN  >viker !02_S	et	f	\N
213648	keerulistele	keerulistele =keerulis  (PlAll  >keeruline !12_A	et	f	\N
213649	keerulistele	"keeruline %keeru  )LINE_aA  <keerd ;22_SA	et	f	\N
213720	järjekindluse	järjekindluse =kindluse  (SgG  >järje+kindlus !11~09_S	et	f	\N
213721	järjekindluse	"järje+kindlus %kindla  )US_aS  <järje+kindel ;02_A	et	f	\N
213728	reklaamita	reklaamita =reklaami  (SgAb  >reklaam !22_S	et	f	\N
213729	reklaamita	reklaamita =reklaami  (IndPrIps_  >reklaamima !28_V	et	f	\N
213745	tellijale	tellijale =tellija  (SgAll  >tellija !01_S	et	f	\N
213746	tellijale	"tellija %telli  )JA_vS  <tellima ;28_V	et	f	\N
213747	tellijatelt	tellijatelt =tellija  (PlAbl  >tellija !01_S	et	f	\N
213748	tellijatelt	"tellija %telli  )JA_vS  <tellima ;28_V	et	f	\N
213749	doteerib	?doteerib =doteeri  (IndPrSg3  >doteerima !28_V	et	f	\N
213754	manson	?manson =manson  (SgN  >manson !02_S	et	f	\N
213757	esitajad	esitajad =esitaja  (PlN  >esitaja !01_S	et	f	\N
213759	esitajad	"esitaja %esita  )JA_vS  <esitama ;27_V	et	f	\N
213763	70406a	### 70406a	et	f	\N
213779	toitlustamine	toitlustamine =toitlustamine  (SgN  >toitlustamine !12_S	et	f	\N
213780	toitlustamine	"toitlustamine %toitlusta  )MINE_vS  <toitlustama ;27_V	et	f	\N
213781	nõute	?nõute =nõute  (SgN  >nõute !06_S	et	f	\N
213782	nõute	?nõute =nõute  (SgG  >nõude !06_S	et	f	\N
213783	nõute	?nõute =nõute  (PlP  >nõut !22_S	et	f	\N
213784	nõute	?nõute =nõute  (IndPrPs_  >nõutema !27_V	et	f	\N
213785	nõute	?nõute =nõute  (ImpPrSg2  >nõutema !27_V	et	f	\N
213793	fülosoofiline	?fülosoofiline =fülosoofiline  (SgN  >fülosoofiline !12_A	et	f	\N
213794	fülosoofiline	?fülosoofiline =fülosoofiline  (PlP  >fülosoofilin !19_S	et	f	\N
213836	tagasiside	tagasiside =si  (PlG  >tagasi+si !26_S	et	f	\N
213837	tagasiside	tagasiside =side  (SgN  >tagasi+side !04_S	et	f	\N
213838	tagasiside	tagasiside =side  (SgN  >tagasi+side !16_S	et	f	\N
213839	tagasiside	tagasiside =side  (SgG  >tagasi+side !16_S	et	f	\N
213852	kahepäevasel	kahepäevasel =päevase  (SgAd  >kahe+päevane !10_A	et	f	\N
213853	kahepäevasel	"kahe+päevane %päeva  )NE_aA  <kahe+päev ;22_S	et	f	\N
213862	huvijuhtid	### huvijuhtid	et	f	\N
213547	vahetund	vahetund =un  (SgP  >vahet+uni !20_S	et	f	\N
213548	vahetund	vahetund =und  (SgN  >vahet+und !22_S	et	f	\N
213549	vahetund	vahetund =tund  (SgN  >vahe+tund !22_S	et	f	\N
213558	jälutama	?jälutama =jälu  (SupIps  >jäluma !27_V	et	f	\N
213559	jälutama	?jälutama =jäluta  (Sup  >jälutama !27_V	et	f	\N
213560	jälutama	?jälutama =jälutama  (SgG  >jälutam !02_A	et	f	\N
213561	vahetunnis	vahetunnis =unni  (PlIn  >vahet+und !22_S	et	f	\N
213562	vahetunnis	vahetunnis =tunni  (SgIn  >vahe+tund !22_S	et	f	\N
213565	tasutav	tasutav =tasu  (PtsPrIps  >tasuma !27_V	et	f	\N
213566	tasutav	tasutav =tasutav  (SgN  >tasutav !02_A	et	f	\N
213567	tasutav	"tasutav %tasu  )TAV_vAS  <tasuma ;27_V	et	f	\N
213569	elukorda	elukorda =korda  (SgP  >elu+kord !22_S	et	f	\N
213570	elukorda	elukorda =korda  (SgAdt  >elu+kord !22_S	et	f	\N
213605	gazeta	?gazeta =gaze  (SgAb  >gaze !16_S	et	f	\N
213606	gazeta	?gazeta =gazeta  (IndPrPs_  >gazetama !27_V	et	f	\N
213607	gazeta	?gazeta =gazeta  (ImpPrSg2  >gazetama !27_V	et	f	\N
213608	cool	?cool =coo  (SgAd  >coo !26_S	et	f	\N
213609	cool	?cool =cool  (SgN  >cool !22_S	et	f	\N
213623	võrkpallist	võrkpallist =palli  (SgEl  >võrk+pall !22_S	et	f	\N
213624	võrkpallist	võrkpallist =pallis  (SgP  >võrk+palline !10_A	et	f	\N
213625	võrkpallist	"võrk+palline %palli  )NE_aA  <võrk+pall ;22_S	et	f	\N
213631	rõivastuses	rõivastuses =rõivastuse  (SgIn  >rõivastus !11_S	et	f	\N
213632	rõivastuses	"rõivastus %rõivasta  )US_vS  <rõivastama ;27_V	et	f	\N
213637	reaalsusestumbes	?reaalsusestumbes =reaalsusestumbe  (PlIn  >reaalsusestump !22_S	et	f	\N
213638	reaalsusestumbes	?reaalsusestumbes =estumbe  (PlIn  >reaalsus+estump !22_S	et	f	\N
213639	reaalsusestumbes	?reaalsusestumbes =susestumbe  (PlIn  >reaal+susestump !22_S	et	f	\N
213640	reaalsusestumbes	?reaalsusestumbes =alsusestumbe  (PlIn  >rea+alsusestump !22_S	et	f	\N
213652	inimenese	?inimenese =inimenese  (SgG  >inimenene !12_A	et	f	\N
213653	inimenese	?inimenese =enese  (SgG  >inim+enene !10_A	et	f	\N
213656	motivit	?motivit =motivi  (SgP  >motiv !02_A	et	f	\N
213657	sunas	?sunas =suna  (SgIn  >suna !17_S	et	f	\N
213658	sunas	?sunas =suna  (IndIpfSg3  >sunama !27_V	et	f	\N
213659	sunas	?sunas =sunas  (SgN  >sunas !09_S	et	f	\N
213660	eluõpetaja	eluõpetaja =õpetaja  (SgN  >elu+õpetaja !01_S	et	f	\N
213661	eluõpetaja	eluõpetaja =õpetaja  (SgG  >elu+õpetaja !01_S	et	f	\N
213704	telesaatesse	telesaatesse =saate  (SgIll  >tele+saade !06_S	et	f	\N
213705	telesaatesse	telesaatesse =saates  (SgAdt  >tele+saatene !12_A	et	f	\N
213706	telesaatesse	"tele+saatene %saate  )NE_aA  <tele+saade ;06_S	et	f	\N
213713	telekanali	telekanali =nali  (SgN  >teleka+nali !24_S	et	f	\N
213714	telekanali	telekanali =kanali  (SgG  >tele+kanal !02_S	et	f	\N
213715	ärireklaami	ärireklaami =reklaami  (SgG  >äri+reklaam !22_S	et	f	\N
213716	ärireklaami	ärireklaami =reklaami  (SgP  >äri+reklaam !22_S	et	f	\N
213717	ärireklaami	ärireklaami =reklaami  (SgAdt  >äri+reklaam !22_S	et	f	\N
213730	teavitab	?teavitab =teavita  (IndPrSg3  >teavitama !27_V	et	f	\N
213731	spordi-	spordi- =spordi  (SgG  >sport !22_S	et	f	\N
213732	spordi-	spordi- =spordi  (IndPrPs_  >sportima !28_V	et	f	\N
213733	spordi-	spordi- =spordi  (ImpPrSg2  >sportima !28_V	et	f	\N
213738	reklammi	?reklammi =reklammi  (SgN  >reklammi !01_S	et	f	\N
213739	reklammi	?reklammi =reklammi  (SgG  >reklammi !01_S	et	f	\N
213740	reklammi	?reklammi =reklammi  (SgG  >reklamm !22_S	et	f	\N
213741	reklammi	?reklammi =reklammi  (SgP  >reklamm !22_S	et	f	\N
213742	reklammi	?reklammi =reklammi  (SgAdt  >reklamm !22_S	et	f	\N
213743	reklammi	?reklammi =reklammi  (IndPrPs_  >reklammima !28_V	et	f	\N
213744	reklammi	?reklammi =reklammi  (ImpPrSg2  >reklammima !28_V	et	f	\N
213753	marilyn	?marilyn =marilyn  (SgN  >marilyn !19_S	et	f	\N
213758	improviserivad	?improviserivad =improviseriva  (PlN  >improviseriv !02_A	et	f	\N
213760	improviserivad	?improviserivad =improviseriva  (PlN  >improviseriva !16_S	et	f	\N
213808	teaduslikut	?teaduslikut =sliku  (SgP  >teadu+sliku !16_S	et	f	\N
213809	teaduslikut	?teaduslikut =slikut  (SgN  >teadu+slikut !02_S	et	f	\N
213825	10a	### 10a	et	f	\N
213854	toimutud	toimutud =toimu  (PtsPtIps  >toimuma !27_V	et	f	\N
213855	toimutud	toimutud =toimutu  (PlN  >toimutu !01_AS	et	f	\N
213856	toimutud	"toimutu %toimu  )TU1_vS  <toimuma ;27_V	et	f	\N
213857	toimutud	toimutud =toimutud  (ID  >toimutud !41_A	et	f	\N
213858	toimutud	"toimutud %toimu  )TUD_vA  <toimuma ;27_V	et	f	\N
213880	kaksteistkümmeil	?kaksteistkümmeil =kaksteistkümmei  (SgAd  >kaksteistkümmei !26_S	et	f	\N
213881	kaksteistkümmeil	?kaksteistkümmeil =kaksteistkümmeil  (SgN  >kaksteistkümmeil !19_S	et	f	\N
213882	kaksteistkümmeil	?kaksteistkümmeil =kümmei  (SgAd  >kaks+teist+kümmei !26_S	et	f	\N
213883	kaksteistkümmeil	?kaksteistkümmeil =kümmeil  (SgN  >kaks+teist+kümmeil !22_S	et	f	\N
213884	kaksteistkümmeil	?kaksteistkümmeil =teistkümme  (PlAd  >kaks+teistkümmi !01_S	et	f	\N
213885	kaksteistkümmeil	?kaksteistkümmeil =teistkümmei  (SgAd  >kaks+teistkümmei !26_S	et	f	\N
213886	kaksteistkümmeil	?kaksteistkümmeil =teistkümmeil  (SgN  >kaks+teistkümmeil !19_S	et	f	\N
213887	süüjamist	?süüjamist =süüjami  (SgEl  >süüjami !01_S	et	f	\N
213888	süüjamist	?süüjamist =süüjami  (SgEl  >süüjam !02_A	et	f	\N
213602	narvskaja	?narvskaja =narvskaja  (SgN  >narvskaja !01_S	et	f	\N
213603	narvskaja	?narvskaja =narvskaja  (SgG  >narvskaja !01_S	et	f	\N
213604	narvskaja	?narvskaja =narvskaja  (SgG  >narvskajas !02_A	et	f	\N
213620	jalgpallist	jalgpallist =palli  (SgEl  >jalg+pall !22_S	et	f	\N
213621	jalgpallist	jalgpallist =pallis  (SgP  >jalg+palline !10_A	et	f	\N
213622	jalgpallist	"jalg+palline %palli  )NE_aA  <jalg+pall ;22_S	et	f	\N
213642	sukelduvad	sukelduvad =sukeldu  (IndPrPl3  >sukelduma !27_V	et	f	\N
213643	sukelduvad	sukelduvad =sukelduva  (PlN  >sukelduv !02_A	et	f	\N
213644	sukelduvad	"sukelduv %sukeldu  )V_vA  <sukelduma ;27_V	et	f	\N
213668	eluraskustest	eluraskustest =test  (SgN  >elu+raskus+test !22_S	et	f	\N
213669	eluraskustest	eluraskustest =raskus  (PlEl  >elu+raskus !11~09_S	et	f	\N
213670	eluraskustest	"elu+raskus %raske  )US_aS  <elu+raske ;01_A	et	f	\N
213671	eluraskustest	eluraskustest =raskus  (PlEl  >elu+raskune !12~10_A	et	f	\N
213672	arvutisõltuvus	arvutisõltuvus =sõltuvus  (SgN  >arvuti+sõltuvus !11_S	et	f	\N
213673	arvutisõltuvus	"arvuti+sõltuvus %sõltuva  )US_aS  <arvuti+sõltuv ;02_A	et	f	\N
213676	elektrooniliselt	?elektrooniliselt =elektroonilise  (SgAbl  >elektrooniline !12_A	et	f	\N
213677	elektrooniliselt	?elektrooniliselt =elektrooniliselt  (ID  >elektrooniliselt !41_D	et	f	\N
213678	elektrooniliselt	?elektrooniliselt =onilise  (SgAbl  >elektro+oniline !12_A	et	f	\N
213682	draamit	?draamit =draami  (SgP  >draami !16_S	et	f	\N
213683	draamit	?draamit =draamit  (SgN  >draamit !02_S	et	f	\N
213693	sulamiks	sulamiks =sulami  (SgTr  >sulam !02_S	et	f	\N
213694	sulamiks	"sulam %sula  )M_cA  <sula ;17_AS	et	f	\N
213695	sulamiks	sulamiks =mi  (SgTr  >sula+mi !26_S	et	f	\N
213700	rahuldatult	rahuldatult =rahuldatu  (SgAbl  >rahuldatu !01_S	et	f	\N
213701	rahuldatult	"rahuldatu %rahulda  )TU1_vS  <rahuldama ;27_V	et	f	\N
213702	rahuldatult	rahuldatult =rahuldatult  (ID  >rahuldatult !41_D	et	f	\N
213703	rahuldatult	"rahuldatult %rahulda  )TULT1_mD  <rahuldama ;27_V	et	f	\N
213722	banaalsusega	banaalsusega =banaalsuse  (SgKom  >banaalsus !11~09_S	et	f	\N
213723	banaalsusega	"banaalsus %banaalse  )US_aS  <banaalne ;02_A	et	f	\N
213734	kunstisündmustest	kunstisündmustest =test  (SgN  >kunsti+sündmus+test !22_S	et	f	\N
213735	kunstisündmustest	kunstisündmustest =sündmus  (PlEl  >kunsti+sündmus !11~09_S	et	f	\N
213761	kuulajaskonnaga	kuulajaskonnaga =kuulajaskonna  (SgKom  >kuulajaskond !22_S	et	f	\N
213762	kuulajaskonnaga	kuulajaskonnaga =konna  (SgKom  >kuulajas+konn !22_S	et	f	\N
213790	eakaaslastele	eakaaslastele =las  (PlAll  >ea+kaas+laps !14_S	et	f	\N
213791	eakaaslastele	eakaaslastele =laste  (PlAll  >ea+kaas+last !22_S	et	f	\N
213792	eakaaslastele	eakaaslastele =kaaslas  (PlAll  >ea+kaaslane !12?10_S	et	f	\N
213810	moodustav	moodustav =moodusta  (PtsPrPs  >moodustama !27_V	et	f	\N
213811	moodustav	moodustav =moodustav  (SgN  >moodustav !02_A	et	f	\N
213812	moodustav	"moodustav %moodusta  )V_vA  <moodustama ;27_V	et	f	\N
213813	tööasutuses	tööasutuses =asutuse  (SgIn  >töö+asutus !11_S	et	f	\N
213814	tööasutuses	"töö+asutus %asu  )TUS2_aS  <töö+asu ;17_S	et	f	\N
213818	roa	roa =roa  (SgG  >ruga !18_S	et	f	\N
213819	roa	roa =roa  (SgG  >roog !22_S	et	f	\N
213826	poolaasta	poolaasta =aasta  (SgN  >pool+aasta !01_S	et	f	\N
213827	poolaasta	poolaasta =aasta  (SgG  >pool+aasta !01_S	et	f	\N
213828	seminarist	seminarist =seminari  (SgEl  >seminar !19_S	et	f	\N
213829	seminarist	seminarist =seminarist  (SgN  >seminarist !22_S	et	f	\N
213833	lõppeski	lõppeski =lõpp  (Ger^  >lõpma !35_V	et	f	\N
213834	lõppeski	lõppeski =lõppe  (SgIn^  >lõpe !06_S	et	f	\N
213835	lõppeski	lõppeski =lõppe  (IndIpfSg3^  >lõppema !27~28_V	et	f	\N
213860	läbiiviijad	?läbiiviijad =läbiiviija  (PlN  >läbiiviijas !02_A	et	f	\N
213861	läbiiviijad	?läbiiviijad =läbiiviija  (PlN  >läbiiviija !16_S	et	f	\N
213863	läbiiviijad	?läbiiviijad =iviija  (PlN  >läbi+iviijas !02_A	et	f	\N
213864	läbiiviijad	?läbiiviijad =iviija  (PlN  >läbi+iviija !16_S	et	f	\N
213873	jutustatud	jutustatud =jutusta  (PtsPtIps  >jutustama !27_V	et	f	\N
213874	jutustatud	jutustatud =jutustatu  (PlN  >jutustatu !01_S	et	f	\N
213876	jutustatud	"jutustatu %jutusta  )TU1_vS  <jutustama ;27_V	et	f	\N
213877	jutustatud	jutustatud =jutustatud  (ID  >jutustatud !41_A	et	f	\N
213879	jutustatud	"jutustatud %jutusta  )TUD_vA  <jutustama ;27_V	et	f	\N
213901	lõputas	?lõputas =lõputa  (IndIpfSg3  >lõputama !27_V	et	f	\N
213906	kavast	kavast =kava  (SgEl  >kava !17_S	et	f	\N
213907	kavast	kavast =kavas  (SgP  >kavane !10_A	et	f	\N
213908	kavast	"kavane %kava  )NE_aA  <kava ;17_S	et	f	\N
213919	austamisega	austamisega =austamise  (SgKom  >austamine !12_S	et	f	\N
213920	austamisega	"austamine %austa  )MINE_vS  <austama ;27_V	et	f	\N
213923	võtjad	võtjad =võtja  (PlN  >võtja !01_S	et	f	\N
213924	võtjad	"võtja %võt  )JA_vS  <võtma ;35_V	et	f	\N
213930	kuueteistkümnes	?kuueteistkümnes =kuueteistkümne  (PlIn  >kuueteistkümn !22_S	et	f	\N
213931	kuueteistkümnes	?kuueteistkümnes =kümne  (PlIn  >kuue+teist+kümn !22_S	et	f	\N
213932	kuueteistkümnes	?kuueteistkümnes =teistkümne  (PlIn  >kuue+teistkümn !22_S	et	f	\N
213933	kuueteistkümnes	?kuueteistkümnes =eteistkümne  (PlIn  >kuu+eteistkümn !22_S	et	f	\N
213961	fbi	### fbi	et	f	\N
213651	hingelistele	"hingeline %hinge  )LINE_aA  <hing ;22_S	et	f	\N
213662	igapäevastest	igapäevastest =aste  (SgEl  >iga+päev+aste !06_S	et	f	\N
213663	igapäevastest	igapäevastest =aste  (PlEl  >iga+päev+ast !22_S	et	f	\N
213664	igapäevastest	igapäevastest =astes  (SgP  >iga+päev+astene !12~10_A	et	f	\N
213665	igapäevastest	"iga+päev+astene %aste  )NE_aA  <iga+päev+aste ;06_S	et	f	\N
213666	igapäevastest	igapäevastest =päevas  (PlEl  >iga+päevane !10_A	et	f	\N
213667	igapäevastest	"iga+päevane %päeva  )NE_aA  <iga+päev ;22_S	et	f	\N
213679	soogi	soogi =soo  (SgN^  >soo !26_S	et	f	\N
213680	soogi	soogi =soo  (SgG^  >sugu !18_S	et	f	\N
213681	soogi	soogi =soo  (SgG^  >soo !26_S	et	f	\N
213684	käiä	### käiä	et	f	\N
213685	näitlevad	näitlevad =näitle  (IndPrPl3  >näitlema !30_V	et	f	\N
213686	näitlevad	näitlevad =näitleva  (PlN  >näitlev !02_A	et	f	\N
213687	näitlevad	"näitlev %näitle  )V_vA  <näitlema ;30_V	et	f	\N
213688	juljetta	?juljetta =juljetta  (SgN  >juljetta !01_S	et	f	\N
213689	juljetta	?juljetta =juljetta  (SgG  >juljetta !01_S	et	f	\N
213707	ärritus	ärritus =ärritu  (IndIpfSg3  >ärrituma !27_V	et	f	\N
213708	ärritus	ärritus =ärritus  (SgN  >ärritus !11_S	et	f	\N
213709	ärritus	"ärritus %ärrita  )US_vS  <ärritama ;27_V	et	f	\N
213718	tüütava	tüütava =tüütava  (SgG  >tüütav !02_A	et	f	\N
213719	tüütava	"tüütav %tüüta  )V_vA  <tüütama ;29_V	et	f	\N
213764	festevalist	?festevalist =festevali  (SgEl  >festeval !19_S	et	f	\N
213765	festevalist	?festevalist =festevalis  (SgP  >festevalis !09_S	et	f	\N
213766	festevalist	?festevalist =festevalis  (SgP  >festevaline !12_A	et	f	\N
213767	festevalist	?festevalist =festevalist  (SgN  >festevalist !22_S	et	f	\N
213768	kontrobassi	?kontrobassi =kontrobassi  (SgG  >kontrobass !22_S	et	f	\N
213769	kontrobassi	?kontrobassi =kontrobassi  (SgP  >kontrobass !22_S	et	f	\N
213770	kontrobassi	?kontrobassi =kontrobassi  (SgAdt  >kontrobass !22_S	et	f	\N
213771	kontrobassi	?kontrobassi =kontrobassi  (IndPrPs_  >kontrobassima !28_V	et	f	\N
213772	kontrobassi	?kontrobassi =kontrobassi  (ImpPrSg2  >kontrobassima !28_V	et	f	\N
213773	kontrobassi	?kontrobassi =robassi  (SgN  >kont+robassi !01_S	et	f	\N
213774	kontrobassi	?kontrobassi =robassi  (SgG  >kont+robassi !01_S	et	f	\N
213775	kontrobassi	?kontrobassi =robassi  (SgG  >kont+robass !22_S	et	f	\N
213776	kontrobassi	?kontrobassi =robassi  (SgP  >kont+robass !22_S	et	f	\N
213777	kontrobassi	?kontrobassi =robassi  (SgAdt  >kont+robass !22_S	et	f	\N
213786	täisvanustele	täisvanustele =vanus  (PlAll  >täis+vanus !09_S	et	f	\N
213787	täisvanustele	täisvanustele =vanus  (PlAll  >täis+vanune !10_A	et	f	\N
213796	täisealine	täisealine =ine  (SgN  >täi+seal+ine !16_S	et	f	\N
213797	täisealine	täisealine =ine  (SgG  >täi+seal+ine !16_S	et	f	\N
213798	täisealine	täisealine =ealine  (SgN  >täis+ealine !12?10_A	et	f	\N
213799	täisealine	"täis+ealine %ea  )LINE_aA  <täis+iga ;18_S	et	f	\N
213800	täisealine	täisealine =sealine  (SgN  >täi+sealine !12?10_A	et	f	\N
213801	täisealine	"täi+sealine %sea  )LINE_aA  <täi+siga ;18_SA	et	f	\N
213802	moodustaksid	moodustaksid =moodusta  (KndPrSg2  >moodustama !27_V	et	f	\N
213803	moodustaksid	moodustaksid =moodusta  (KndPrPl3  >moodustama !27_V	et	f	\N
213806	vähemad	vähemad =vähema  (PlN  >vähem !02_A	et	f	\N
213807	vähemad	"vähem %vähe  )M_cA  <väike ;10_A	et	f	\N
213816	temagi	temagi =tema  (SgG^  >tema !00_P	et	f	\N
213817	temagi	temagi =tema  (SgN^  >tema !00_P	et	f	\N
213823	siiri	siiri =siiri  (IndPrPs_  >siirima !28_V	et	f	\N
213824	siiri	siiri =siiri  (ImpPrSg2  >siirima !28_V	et	f	\N
213840	vaabariiklike	?vaabariiklike =vaabariiklike  (SgN  >vaabariiklike !12_S	et	f	\N
213841	vaabariiklike	?vaabariiklike =vaabariiklike  (PlG  >vaabariiklik !25_A	et	f	\N
213850	kahepäevane	kahepäevane =päevane  (SgN  >kahe+päevane !10_A	et	f	\N
213851	kahepäevane	"kahe+päevane %päeva  )NE_aA  <kahe+päev ;22_S	et	f	\N
213865	phare	?phare =phare  (SgN  >phare !16_S	et	f	\N
213866	phare	?phare =phare  (SgG  >phare !16_S	et	f	\N
213867	phare	?phare =phare  (IndPrPs_  >pharema !27_V	et	f	\N
213868	phare	?phare =phare  (ImpPrSg2  >pharema !27_V	et	f	\N
213896	lõppusime	?lõppusime =lõppu  (IndIpfPl1  >lõppuma !27_V	et	f	\N
213904	viibiste	?viibiste =viibis  (PlG  >viibis !09_S	et	f	\N
213905	viibiste	?viibiste =viibiste  (PlP  >viibist !22_S	et	f	\N
213909	hotellisse	hotellisse =hotelli  (SgIll  >hotell !22_S	et	f	\N
213910	hotellisse	hotellisse =hotellis  (SgAdt  >hotelline !12_A	et	f	\N
213911	hotellisse	"hotelline %hotelli  )NE_aA  <hotell ;22_S	et	f	\N
213925	tagasisidest	tagasisidest =si  (PlEl  >tagasi+si !26_S	et	f	\N
213926	tagasisidest	tagasisidest =side  (SgEl  >tagasi+side !16_S	et	f	\N
213927	tagasisidest	tagasisidest =sides  (SgP  >tagasi+sidene !10_A	et	f	\N
213928	tagasisidest	"tagasi+sidene %side  )NE_aA  <tagasi+side ;16_S	et	f	\N
213929	kokkuvõted	### kokkuvõted	et	f	\N
213934	registreerised	?registreerised =registreerise  (PlN  >registreeris !09_S	et	f	\N
213935	jatkus	?jatkus =jatku  (SgIn  >jatku !16_S	et	f	\N
213936	jatkus	?jatkus =jatku  (IndIpfSg3  >jatkuma !27_V	et	f	\N
213937	jatkus	?jatkus =jatkus  (SgN  >jatkus !11~09_S	et	f	\N
213946	soovijad	soovijad =soovija  (PlN  >soovija !01_S	et	f	\N
213724	reklaamida	reklaamida =reklaami  (Inf  >reklaamima !28_V	et	f	\N
213725	reklaamida	reklaamida =ida  (SgN  >reklaam+ida !17_S	et	f	\N
213726	reklaamida	reklaamida =ida  (SgG  >reklaam+ida !17_S	et	f	\N
213727	reklaamida	reklaamida =ida  (SgP  >reklaam+ida !17_S	et	f	\N
213736	läbimüüki	läbimüüki =müüki  (SgP  >läbi+müük !22_S	et	f	\N
213737	läbimüüki	läbimüüki =müüki  (SgAdt  >läbi+müük !22_S	et	f	\N
213750	telereklaami	telereklaami =reklaami  (SgG  >tele+reklaam !22_S	et	f	\N
213751	telereklaami	telereklaami =reklaami  (SgP  >tele+reklaam !22_S	et	f	\N
213752	telereklaami	telereklaami =reklaami  (SgAdt  >tele+reklaam !22_S	et	f	\N
213755	muusikariistaks	muusikariistaks =taks  (SgN  >muusika+riis+taks !22_S	et	f	\N
213756	muusikariistaks	muusikariistaks =riista  (SgTr  >muusika+riist !22_S	et	f	\N
213778	festevalil	?festevalil =festevali  (SgAd  >festeval !19_S	et	f	\N
213788	üksikasjalikult	üksikasjalikult =asjaliku  (SgAbl  >üksik+asjalik !25_A	et	f	\N
213789	üksikasjalikult	"üksik+asjalikult %asjaliku  )LT_mD  <üksik+asjalik ;25_A	et	f	\N
213795	häletada	?häletada =häleta  (Inf  >häletama !27_V	et	f	\N
213804	noorud	?noorud =nooru  (PlN  >nooru !16_S	et	f	\N
213805	noorud	?noorud =nooru  (IndPrSg2  >nooruma !27_V	et	f	\N
213815	kokkamüts	?kokkamüts =kokkamüts  (SgN  >kokkamüts !22_S	et	f	\N
213820	kannatlikult	kannatlikult =kannatliku  (SgAbl  >kannatlik !25_A	et	f	\N
213821	kannatlikult	kannatlikult =kannatlikult  (ID  >kannatlikult !41_D	et	f	\N
213822	kannatlikult	"kannatlikult %kannatliku  )LT_mD  <kannatlik ;25_A	et	f	\N
213830	esimeestele	esimeestele =mees  (PlAll  >esi+meene !10_A	et	f	\N
213831	esimeestele	"esi+meene %mee  )NE_aA  <esi+mesi ;15_S	et	f	\N
213832	esimeestele	esimeestele =mees  (PlAll  >esi+mees !13_S	et	f	\N
213842	ajakirjanikuid	?ajakirjanikuid =ajakirjaniku  (PlP  >ajakirjanik !02_S	et	f	\N
213843	ajakirjanikuid	?ajakirjanikuid =ajakirjanikui  (PlN  >ajakirjanikui !26_S	et	f	\N
213844	ajakirjanikuid	?ajakirjanikuid =ajakirjanikui  (SgP  >ajakirjanikui !26_S	et	f	\N
213845	ajakirjanikuid	?ajakirjanikuid =nikui  (PlN  >aja+kirja+nikui !26_S	et	f	\N
213846	ajakirjanikuid	?ajakirjanikuid =nikui  (SgP  >aja+kirja+nikui !26_S	et	f	\N
213847	ajakirjanikuid	?ajakirjanikuid =nikuid  (SgN  >aja+kirja+nikuid !22_S	et	f	\N
213848	ajakirjanikuid	?ajakirjanikuid =kirjanikui  (PlN  >aja+kirjanikui !26_S	et	f	\N
213849	ajakirjanikuid	?ajakirjanikuid =kirjanikui  (SgP  >aja+kirjanikui !26_S	et	f	\N
213859	esimeested	?esimeested =meeste  (PlN  >esi+meeste !06_S	et	f	\N
213869	reegistreerisime	?reegistreerisime =reegistreeri  (IndIpfPl1  >reegistreerima !28_V	et	f	\N
213900	saaid	?saaid =saaid  (SgN  >saaid !02_S	et	f	\N
213902	juhatajaid	juhatajaid =juhataja  (PlP  >juhataja !01_S	et	f	\N
213903	juhatajaid	"juhataja %juhata  )JA_vS  <juhatama ;27_V	et	f	\N
213974	koila	?koila =koila  (SgN  >koila !16_S	et	f	\N
213975	koila	?koila =koila  (SgG  >koila !16_S	et	f	\N
213976	koila	?koila =koila  (IndPrPs_  >koilama !29_V	et	f	\N
213977	koila	?koila =koila  (ImpPrSg2  >koilama !29_V	et	f	\N
213979	halbasti	?halbasti =halbasti  (ID  >halbasti !41_D	et	f	\N
213980	halbasti	?halbasti =halbasti  (IndPrPs_  >halbastima !28_V	et	f	\N
213981	halbasti	?halbasti =halbasti  (ImpPrSg2  >halbastima !28_V	et	f	\N
213992	hop	### hop	et	f	\N
213994	leningrad	?leningrad =leningra  (PlN  >leningra !01_S	et	f	\N
213997	lilleküla	lilleküla =küla  (SgN  >lille+küla !17_S	et	f	\N
213998	lilleküla	lilleküla =küla  (SgG  >lille+küla !17_S	et	f	\N
213999	lilleküla	lilleküla =küla  (SgP  >lille+küla !17_S	et	f	\N
214005	muusikastüülid	?muusikastüülid =muusikastüüli  (PlN  >muusikastüüli !16_S	et	f	\N
214006	muusikastüülid	?muusikastüülid =muusikastüüli  (PlN  >muusikastüül !22_S	et	f	\N
214007	muusikastüülid	?muusikastüülid =muusikastüüli  (IndPrSg2  >muusikastüülima !28_V	et	f	\N
214008	muusikastüülid	?muusikastüülid =stüüli  (PlN  >muusika+stüüli !16_S	et	f	\N
214009	muusikastüülid	?muusikastüülid =stüüli  (PlN  >muusika+stüül !22_S	et	f	\N
214010	muusikastüülid	?muusikastüülid =sikastüüli  (PlN  >muu+sikastüüli !16_S	et	f	\N
214011	muusikastüülid	?muusikastüülid =sikastüüli  (PlN  >muu+sikastüül !22_S	et	f	\N
214030	roomaantiline	?roomaantiline =roomaantiline  (SgN  >roomaantiline !12_A	et	f	\N
214031	roomaantiline	?roomaantiline =roomaantiline  (PlP  >roomaantilin !19_S	et	f	\N
214032	roomaantiline	?roomaantiline =tiline  (SgN  >roo+maan+tiline !10_A	et	f	\N
214033	roomaantiline	?roomaantiline =antiline  (SgN  >rooma+antiline !12_A	et	f	\N
214034	roomaantiline	?roomaantiline =antiline  (PlP  >rooma+antilin !19_S	et	f	\N
214035	roomaantiline	?roomaantiline =maantiline  (SgN  >roo+maantiline !12_A	et	f	\N
214036	roomaantiline	?roomaantiline =maantiline  (PlP  >roo+maantilin !19_S	et	f	\N
214046	usuge	?usuge =usu  (ImpPrPl2  >usuma !27_V	et	f	\N
214047	lemmikino	?lemmikino =lemmikino  (SgN  >lemmikino !16_S	et	f	\N
214048	lemmikino	?lemmikino =lemmikino  (SgG  >lemmikino !16_S	et	f	\N
214049	lemmikino	?lemmikino =ino  (SgN  >lemmik+ino !17~16_S	et	f	\N
214050	lemmikino	?lemmikino =ino  (SgG  >lemmik+ino !17~16_S	et	f	\N
214051	lemmikino	?lemmikino =ino  (SgP  >lemmik+ino !17_S	et	f	\N
214055	huvatav	?huvatav =huva  (PtsPrIps  >huvama !27_V	et	f	\N
214056	huvatav	?huvatav =huvata  (PtsPrPs  >huvatama !27_V	et	f	\N
213870	tutvustime	?tutvustime =tutvusti  (IndPrPl1  >tutvustima !28_V	et	f	\N
213871	tutvustime	?tutvustime =time  (SgN  >tutvus+time !16_S	et	f	\N
213872	tutvustime	?tutvustime =time  (SgG  >tutvus+time !16_S	et	f	\N
213875	kooolidele	?kooolidele =koooli  (PlAll  >koooli !16_S	et	f	\N
213878	kooolidele	?kooolidele =koooli  (PlAll  >koool !22_S	et	f	\N
213897	seminaarist	?seminaarist =seminaari  (SgEl  >seminaari !16_S	et	f	\N
213898	seminaarist	?seminaarist =seminaari  (SgEl  >seminaar !22_S	et	f	\N
213899	seminaarist	?seminaarist =seminaaris  (SgP  >seminaaris !09_S	et	f	\N
213938	registreerimist	registreerimist =registreerimis  (SgP  >registreerimine !12_S	et	f	\N
213939	registreerimist	"registreerimine %registreeri  )MINE_vS  <registreerima ;28_V	et	f	\N
213948	kaheksateistkümneni	?kaheksateistkümneni =kaheksateistkümneni  (SgG  >kaheksateistkümnen !02_S	et	f	\N
213949	kaheksateistkümneni	?kaheksateistkümneni =kümneni  (SgG  >kaheksa+teist+kümnen !02_S	et	f	\N
213950	kaheksateistkümneni	?kaheksateistkümneni =teistkümneni  (SgG  >kaheksa+teistkümnen !19_S	et	f	\N
213951	kaheksateistkümneni	?kaheksateistkümneni =teistkümneni  (SgP  >kaheksa+teistkümnen !19_S	et	f	\N
213952	kaheksateistkümneni	?kaheksateistkümneni =teistkümneni  (SgAdt  >kaheksa+teistkümnen !19_S	et	f	\N
213953	kaheksateistkümneni	?kaheksateistkümneni =ksateistkümneni  (SgG  >kahe+ksateistkümnen !02_S	et	f	\N
213967	õhtused	õhtused =õhtuse  (PlN  >õhtune !12~10_A	et	f	\N
213968	õhtused	"õhtune %õhtu  )NE_aA  <õhtu ;01_S	et	f	\N
213969	piletiinfo	piletiinfo =info  (SgN  >pileti+info !16_S	et	f	\N
213970	piletiinfo	piletiinfo =info  (SgG  >pileti+info !16_S	et	f	\N
213971	majustus	?majustus =majustu  (SgIn  >majustu !01_S	et	f	\N
213972	majustus	?majustus =majustu  (IndIpfSg3  >majustuma !27_V	et	f	\N
213973	majustus	?majustus =majustus  (SgN  >majustus !11_S	et	f	\N
213989	alternatiivmuusika	alternatiivmuusika =muusika  (SgN  >alternatiiv+muusika !01_S	et	f	\N
213990	alternatiivmuusika	alternatiivmuusika =muusika  (SgG  >alternatiiv+muusika !01_S	et	f	\N
213995	piletiostamisest	?piletiostamisest =piletiostamise  (SgEl  >piletiostamine !12_S	et	f	\N
213996	piletiostamisest	?piletiostamisest =ostamise  (SgEl  >pileti+ostamine !12_S	et	f	\N
214018	kontaktelefon	?kontaktelefon =kontaktelefon  (SgN  >kontaktelefon !19_S	et	f	\N
214019	kontaktelefon	?kontaktelefon =elefon  (SgN  >kontakt+elefon !19_S	et	f	\N
214020	coca	?coca =coca  (SgN  >coca !16_S	et	f	\N
214021	coca	?coca =coca  (SgG  >coca !16_S	et	f	\N
214039	edukuse	edukuse =edukuse  (SgG  >edukus !11_S	et	f	\N
214040	edukuse	"edukus %eduka  )US_aS  <edukas ;02_A	et	f	\N
214041	edukuse	edukuse =kuse  (SgG  >edu+kusi !20_S	et	f	\N
214052	märulifilmid	?märulifilmid =märulifilmi  (PlN  >märulifilm !22_S	et	f	\N
214053	märulifilmid	?märulifilmid =märulifilmi  (IndPrSg2  >märulifilmima !28_V	et	f	\N
214067	titova	?titova =titova  (SgN  >titova !01_S	et	f	\N
214068	titova	?titova =titova  (SgG  >titova !01_S	et	f	\N
214069	titova	?titova =titova  (SgG  >titov !02_A	et	f	\N
214078	lõppuvad	?lõppuvad =lõppu  (IndPrPl3  >lõppuma !27_V	et	f	\N
214079	lõppuvad	?lõppuvad =lõppuva  (PlN  >lõppuva !01_S	et	f	\N
214081	lõppuvad	?lõppuvad =lõppuva  (PlN  >lõppuv !02_A	et	f	\N
214082	lõppuvad	?lõppuvad =uva  (PlN  >lõpp+uva !17_S	et	f	\N
214098	reostavad	reostavad =reosta  (IndPrPl3  >reostama !27_V	et	f	\N
214099	reostavad	reostavad =reostava  (PlN  >reostav !02_A	et	f	\N
214100	reostavad	"reostav %reosta  )V_vA  <reostama ;27_V	et	f	\N
214123	punamütsikeseks	punamütsikeseks =mütsikese  (SgTr  >puna+mütsike !12_S	et	f	\N
214124	punamütsikeseks	"puna+mütsike %mütsi  )KE_dS  <puna+müts ;22_S	et	f	\N
214125	punamütsikeseks	punamütsikeseks =mütsikese  (SgTr  >puna+mütsikene !12_S	et	f	\N
214126	punamütsikeseks	"puna+mütsikene %mütsi  )KENE_dS  <puna+müts ;22_S	et	f	\N
214131	punamütsikesest	punamütsikesest =mütsikese  (SgEl  >puna+mütsike !12_S	et	f	\N
214132	punamütsikesest	"puna+mütsike %mütsi  )KE_dS  <puna+müts ;22_S	et	f	\N
214133	punamütsikesest	punamütsikesest =mütsikese  (SgEl  >puna+mütsikene !12_S	et	f	\N
214134	punamütsikesest	"puna+mütsikene %mütsi  )KENE_dS  <puna+müts ;22_S	et	f	\N
214205	punamustike	punamustike =ike  (SgN  >puna+must+ike !06_S	et	f	\N
214206	punamustike	punamustike =mustike  (SgN  >puna+mustike !12_S	et	f	\N
214207	punamustike	"puna+mustike %musti  )KE_dA  <puna+must ;22_AS	et	f	\N
214231	hund	?hund =hund  (SgN  >hund !22_S	et	f	\N
214241	vaikes	?vaikes =vaike  (SgIn  >vaige !06_S	et	f	\N
214242	vaikes	?vaikes =vaike  (IndIpfSg3  >vaikema !27_V	et	f	\N
214243	vaikes	?vaikes =vaikes  (SgN  >vaikes !09_S	et	f	\N
214245	punamutsikas	?punamutsikas =punamutsika  (SgIn  >punamutsika !01_S	et	f	\N
214246	punamutsikas	?punamutsikas =punamutsika  (SgIn  >punamutsikas !02_A	et	f	\N
214247	punamutsikas	?punamutsikas =punamutsikas  (SgN  >punamutsikas !02_A	et	f	\N
214248	punamutsikas	?punamutsikas =mutsika  (SgIn  >puna+mutsika !01_S	et	f	\N
214249	punamutsikas	?punamutsikas =mutsika  (SgIn  >puna+mutsikas !02_S	et	f	\N
214250	punamutsikas	?punamutsikas =mutsikas  (SgN  >puna+mutsikas !02_S	et	f	\N
214259	punamustikeseks	punamustikeseks =mustikese  (SgTr  >puna+mustike !12_S	et	f	\N
214260	punamustikeseks	"puna+mustike %musti  )KE_dA  <puna+must ;22_AS	et	f	\N
214261	punamustikeseks	punamustikeseks =mustikese  (SgTr  >puna+mustikene !12_S	et	f	\N
213889	süüjamist	?süüjamist =süüjamis  (SgP  >süüjamis !11_S	et	f	\N
213890	süüjamist	?süüjamist =süüjamis  (SgP  >süüjamine !12_S	et	f	\N
213891	süüjamist	?süüjamist =süüjamist  (SgN  >süüjamist !22_S	et	f	\N
213892	süüjamist	?süüjamist =jami  (SgEl  >süü+jami !17_S	et	f	\N
213893	süüjamist	?süüjamist =jamis  (SgP  >süü+jamis !09_S	et	f	\N
213894	süüjamist	?süüjamist =jamis  (SgP  >süü+jamine !10_A	et	f	\N
213895	süüjamist	?süüjamist =jamist  (SgN  >süü+jamist !22_S	et	f	\N
213912	uudi	?uudi =uudi  (SgN  >uudi !16_S	et	f	\N
213913	uudi	?uudi =uudi  (SgG  >uudi !16_S	et	f	\N
213914	uudi	?uudi =uudi  (SgG  >uut !22_S	et	f	\N
213915	uudi	?uudi =uudi  (SgP  >uud !22_S	et	f	\N
213916	uudi	?uudi =uudi  (SgAdt  >uud !22_S	et	f	\N
213917	uudi	?uudi =uudi  (IndPrPs_  >uutima !28_V	et	f	\N
213918	uudi	?uudi =uudi  (ImpPrSg2  >uutima !28_V	et	f	\N
213921	kahepäevasest	kahepäevasest =päevase  (SgEl  >kahe+päevane !10_A	et	f	\N
213922	kahepäevasest	"kahe+päevane %päeva  )NE_aA  <kahe+päev ;22_S	et	f	\N
213940	võimalikuid	?võimalikuid =võimalikui  (PlN  >võimalikui !26_S	et	f	\N
213941	võimalikuid	?võimalikuid =võimalikui  (SgP  >võimalikui !26_S	et	f	\N
213942	võimalikuid	?võimalikuid =maliku  (PlP  >või+maliku !01_S	et	f	\N
213943	võimalikuid	?võimalikuid =maliku  (PlP  >või+malik !02_S	et	f	\N
213944	võimalikuid	?võimalikuid =malikui  (PlN  >või+malikui !26_S	et	f	\N
213945	võimalikuid	?võimalikuid =malikui  (SgP  >või+malikui !26_S	et	f	\N
213959	rühmatöö	rühmatöö =töö  (SgN  >rühma+töö !26_S	et	f	\N
213960	rühmatöö	rühmatöö =töö  (SgG  >rühma+töö !26_S	et	f	\N
213962	muusikafestivali	muusikafestivali =festivali  (SgG  >muusika+festival !19_S	et	f	\N
213963	muusikafestivali	muusikafestivali =festivali  (SgP  >muusika+festival !19_S	et	f	\N
213964	muusikafestivali	muusikafestivali =festivali  (SgAdt  >muusika+festival !19_S	et	f	\N
213993	hard	?hard =hard  (SgN  >hard !22_S	et	f	\N
214000	roskilde	### roskilde	et	f	\N
214014	majutusest	majutusest =majutuse  (SgEl  >majutus !11_S	et	f	\N
214015	majutusest	"majutus %majuta  )US_vS  <majutama ;27_V	et	f	\N
214016	majutusest	majutusest =majutuses  (SgP  >majutusene !12_A	et	f	\N
214017	majutusest	"majutusene %majutuse  )NE_aA  <majutus ;11_S	et	f	\N
214042	edukuse	edukuse =edukuse  (SgG  >edukus !11_S	et	f	\N
214043	edukuse	"edukus %eduka  )US_aS  <edukas ;02_A	et	f	\N
214044	edukuse	edukuse =kuse  (SgG  >edu+kusi !20_S	et	f	\N
214054	hangida	?hangida =hangi  (Inf  >hangima !28_V	et	f	\N
214060	kvalitseetne	?kvalitseetne =kvalitseetne  (SgN  >kvalitseetne !02_A	et	f	\N
214061	kvalitseetne	?kvalitseetne =kvalitseetne  (PlP  >kvalitseetn !22_S	et	f	\N
214063	kaia	?kaia =kaia  (SgN  >kaia !16_S	et	f	\N
214064	kaia	?kaia =kaia  (SgG  >kaia !16_S	et	f	\N
214065	kaia	?kaia =kaia  (IndPrPs_  >kaiama !29_V	et	f	\N
214066	kaia	?kaia =kaia  (ImpPrSg2  >kaiama !29_V	et	f	\N
214072	eluda	?eluda =elu  (Inf  >eluma !27_V	et	f	\N
214101	haruldavaid	?haruldavaid =haruldava  (PlP  >haruldav !02_A	et	f	\N
214102	haruldavaid	?haruldavaid =haruldavai  (PlN  >haruldavai !26_S	et	f	\N
214103	haruldavaid	?haruldavaid =haruldavai  (SgP  >haruldavai !26_S	et	f	\N
214127	punamütsikesele	punamütsikesele =mütsikese  (SgAll  >puna+mütsike !12_S	et	f	\N
214128	punamütsikesele	"puna+mütsike %mütsi  )KE_dS  <puna+müts ;22_S	et	f	\N
214129	punamütsikesele	punamütsikesele =mütsikese  (SgAll  >puna+mütsikene !12_S	et	f	\N
214130	punamütsikesele	"puna+mütsikene %mütsi  )KENE_dS  <puna+müts ;22_S	et	f	\N
214144	häälga	?häälga =häälga  (SgN  >häälga !01_S	et	f	\N
214145	häälga	?häälga =häälga  (SgG  >häälga !01_S	et	f	\N
214146	häälga	?häälga =häälga  (IndPrPs_  >häälgama !29_V	et	f	\N
214147	häälga	?häälga =häälga  (ImpPrSg2  >häälgama !29_V	et	f	\N
214158	jooksib	?jooksib =jooksi  (IndPrSg3  >jooksima !28_V	et	f	\N
214186	mutsi	mutsi =mutsi  (SgG  >muts !22_S	et	f	\N
214187	mutsi	mutsi =mutsi  (SgP  >muts !22_S	et	f	\N
214188	mutsi	mutsi =mutsi  (SgAdt  >muts !22_S	et	f	\N
214189	mutsi	mutsi =mutsi  (IndPrPs_  >mutsima !28_V	et	f	\N
214190	mutsi	mutsi =mutsi  (ImpPrSg2  >mutsima !28_V	et	f	\N
214201	punamutsikest	punamutsikest =mutsikes  (SgP  >puna+mutsike !12_S	et	f	\N
214202	punamutsikest	"puna+mutsike %mutsi  )KE_dS  <puna+muts ;22_S	et	f	\N
214203	punamutsikest	punamutsikest =mutsikes  (SgP  >puna+mutsikene !12_S	et	f	\N
214204	punamutsikest	"puna+mutsikene %mutsi  )KENE_dS  <puna+muts ;22_S	et	f	\N
214208	mõlten	?mõlten =mõlte  (IndPrSg1  >mõltema !27_V	et	f	\N
214209	mõlten	?mõlten =mõlten  (SgN  >mõlten !02_S	et	f	\N
214212	punamüstike	?punamüstike =punamüstike  (SgN  >punamüstike !12_S	et	f	\N
214213	punamüstike	?punamüstike =punamüstike  (PlG  >punamüstik !25_S	et	f	\N
214214	punamüstike	?punamüstike =müstike  (SgN  >puna+müstike !12_S	et	f	\N
214222	utles	?utles =utle  (IndIpfSg3  >utlema !30_V	et	f	\N
214223	utles	?utles =utles  (SgN  >utles !09_S	et	f	\N
214227	buketti	buketti =buketti  (SgP  >bukett !22_S	et	f	\N
214228	buketti	buketti =buketti  (SgAdt  >bukett !22_S	et	f	\N
214229	linki	linki =linki  (SgP  >link !22_S	et	f	\N
214230	linki	linki =linki  (SgAdt  >link !22_S	et	f	\N
213947	soovijad	"soovija %soovi  )JA_vS  <soovima ;28_V	et	f	\N
213954	viieteistkümneni	?viieteistkümneni =viieteistkümneni  (SgG  >viieteistkümnen !02_S	et	f	\N
213955	viieteistkümneni	?viieteistkümneni =kümneni  (SgG  >viie+teist+kümnen !02_S	et	f	\N
213956	viieteistkümneni	?viieteistkümneni =teistkümneni  (SgG  >viie+teistkümnen !19_S	et	f	\N
213957	viieteistkümneni	?viieteistkümneni =teistkümneni  (SgP  >viie+teistkümnen !19_S	et	f	\N
213958	viieteistkümneni	?viieteistkümneni =teistkümneni  (SgAdt  >viie+teistkümnen !19_S	et	f	\N
213965	päevased	päevased =päevase  (PlN  >päevane !10_A	et	f	\N
213966	päevased	"päevane %päeva  )NE_aA  <päev ;22_S	et	f	\N
213982	xxxru	### xxxru	et	f	\N
213991	hip	### hip	et	f	\N
214012	progressivne	?progressivne =progressivne  (SgN  >progressivne !02_A	et	f	\N
214013	progressivne	?progressivne =progressivne  (PlP  >progressivn !22_S	et	f	\N
214022	cola	?cola =cola  (SgN  >cola !17_S	et	f	\N
214023	cola	?cola =cola  (SgG  >cola !17_S	et	f	\N
214024	cola	?cola =cola  (SgP  >cola !17_S	et	f	\N
214025	cola	?cola =cola  (IndPrPs_  >colama !27_V	et	f	\N
214026	cola	?cola =cola  (ImpPrSg2  >colama !27_V	et	f	\N
214045	usuda	?usuda =usu  (Inf  >usuma !27_V	et	f	\N
214058	ekran	?ekran =ekra  (IndPrSg1  >ekrama !29_V	et	f	\N
214059	ekran	?ekran =ekran  (SgN  >ekran !02_S	et	f	\N
214080	räägike	räägike =räägike  (SgN  >räägike !12_S	et	f	\N
214083	räägike	"räägike %räägi  )KE_dS  <rääk ;22_S	et	f	\N
214087	telgid	telgid =telgi  (PlN  >telk !22_S	et	f	\N
214088	telgid	telgid =telgi  (IndPrSg2  >telkima !28_V	et	f	\N
214096	maastikud	maastikud =maastiku  (PlN  >maastik !25_S	et	f	\N
214097	maastikud	maastikud =tiku  (PlN  >maas+tikk !22_S	et	f	\N
214116	armstas	?armstas =armsta  (SgIn  >armsta !01_S	et	f	\N
214117	armstas	?armstas =armsta  (IndIpfSg3  >armstama !29_V	et	f	\N
214118	armstas	?armstas =armstas  (SgN  >armstas !07_S	et	f	\N
214135	vaastas	?vaastas =vaasta  (SgIn  >vaasta !01_S	et	f	\N
214136	vaastas	?vaastas =vaasta  (IndIpfSg3  >vaastama !27_V	et	f	\N
214137	vaastas	?vaastas =vaastas  (SgN  >vaastas !07_S	et	f	\N
214164	tuppas	?tuppas =tuppa  (IndIpfSg3  >tuppama !29_V	et	f	\N
214165	tuppas	?tuppas =tuppas  (SgN  >tuppas !07_S	et	f	\N
214166	hettis	?hettis =hetti  (IndIpfSg3  >hettima !28_V	et	f	\N
214167	hettis	?hettis =hettis  (ID  >hettis !41_DA	et	f	\N
214181	mutsi	mutsi =mutsi  (SgG  >muts !22_S	et	f	\N
214182	mutsi	mutsi =mutsi  (SgP  >muts !22_S	et	f	\N
214183	mutsi	mutsi =mutsi  (SgAdt  >muts !22_S	et	f	\N
214184	mutsi	mutsi =mutsi  (IndPrPs_  >mutsima !28_V	et	f	\N
214185	mutsi	mutsi =mutsi  (ImpPrSg2  >mutsima !28_V	et	f	\N
214191	punamütsikele	?punamütsikele =kele  (SgN  >puna+mütsi+kele !16_S	et	f	\N
214192	punamütsikele	?punamütsikele =kele  (SgG  >puna+mütsi+kele !16_S	et	f	\N
214193	punamütsikele	?punamütsikele =mütsikele  (PlP  >puna+mütsikel !19_S	et	f	\N
214194	roohelises	roohelises =helise  (SgIn  >roo+heline !10_A	et	f	\N
214195	roohelises	"roo+heline %heli  )NE_aA  <roo+heli ;17_S	et	f	\N
214199	näljaste	näljaste =näljas  (PlG  >näljane !10_A	et	f	\N
214200	näljaste	"näljane %nälja  )NE_aA  <nälg ;22_S	et	f	\N
214210	tääl	?tääl =tää  (SgAd  >tää !26_S	et	f	\N
214211	tääl	?tääl =tääl  (SgN  >tääl !22_S	et	f	\N
214215	magusasti	magusasti =magusasti  (ID  >magusasti !41_D	et	f	\N
214216	magusasti	magusasti =asti  (SgG  >magus+ast !22_S	et	f	\N
214217	magusasti	magusasti =asti  (SgP  >magus+ast !22_S	et	f	\N
214218	magusasti	magusasti =asti  (SgAdt  >magus+ast !22_S	et	f	\N
214240	kokkiga	### kokkiga	et	f	\N
214244	kimb	?kimb =kimb  (SgN  >kimb !22_S	et	f	\N
214273	hünt	?hünt =hünt  (SgN  >hünt !22_S	et	f	\N
214281	tupli	?tupli =tupli  (ID  >tupli !41_D	et	f	\N
214282	tupli	?tupli =tupli  (SgG  >tuppel !02_S	et	f	\N
214290	umberjutustus	?umberjutustus =umberjutustu  (IndIpfSg3  >umberjutustuma !27_V	et	f	\N
214291	umberjutustus	?umberjutustus =umberjutustus  (SgN  >umberjutustus !11~09_S	et	f	\N
214292	umberjutustus	?umberjutustus =erjutustus  (SgN  >umb+erjutustus !11~09_S	et	f	\N
214313	panisid	panisid =pani  (PlP  >pani !16_S	et	f	\N
214314	panisid	panisid =pani  (PlP  >pan !19_S	et	f	\N
214326	puurajaujad	?puurajaujad =puurajauja  (PlN  >puurajauja !01_S	et	f	\N
214327	puurajaujad	?puurajaujad =puurajauja  (PlN  >puurajaujas !02_A	et	f	\N
214328	puurajaujad	?puurajaujad =uja  (PlN  >puu+raja+uja !17_S	et	f	\N
214329	puurajaujad	?puurajaujad =ajauja  (PlN  >puur+ajauja !01_S	et	f	\N
214330	puurajaujad	?puurajaujad =ajauja  (PlN  >puur+ajaujas !02_A	et	f	\N
214331	puurajaujad	?puurajaujad =rajauja  (PlN  >puu+rajauja !01_S	et	f	\N
214332	puurajaujad	?puurajaujad =rajauja  (PlN  >puu+rajaujas !02_A	et	f	\N
214344	kulsin	?kulsin =kulsi  (IndPrSg1  >kulssima !28_V	et	f	\N
214345	kulsin	?kulsin =kulsin  (SgN  >kulsin !02_S	et	f	\N
214346	purdi	purdi =purdi  (SgP  >purd !22_S	et	f	\N
214347	purdi	purdi =purdi  (SgAdt  >purd !22_S	et	f	\N
214363	joksis	?joksis =joksi  (SgIn  >joksi !16_S	et	f	\N
214364	joksis	?joksis =joksi  (SgIn  >joks !22_S	et	f	\N
214365	joksis	?joksis =joksi  (IndIpfSg3  >joksima !28_V	et	f	\N
213978	plonk	?plonk =plonk  (SgN  >plonk !22_S	et	f	\N
213983	järelepäremine	?järelepäremine =järelepäremine  (SgN  >järelepäremine !12_S	et	f	\N
213984	järelepäremine	?järelepäremine =järelepäremine  (PlP  >järelepäremin !19_S	et	f	\N
213985	järelepäremine	?järelepäremine =päremine  (SgN  >järele+päremine !12_S	et	f	\N
213986	järelepäremine	?järelepäremine =päremine  (PlP  >järele+päremin !19_S	et	f	\N
213987	järelepäremine	?järelepäremine =epäremine  (SgN  >järel+epäremine !12_S	et	f	\N
213988	järelepäremine	?järelepäremine =epäremine  (PlP  >järel+epäremin !19_S	et	f	\N
214001	taanis	?taanis =taani  (SgIn  >taani !16_S	et	f	\N
214002	taanis	?taanis =taani  (SgIn  >taan !22_S	et	f	\N
214003	taanis	?taanis =taani  (IndIpfSg3  >taanima !28_V	et	f	\N
214004	taanis	?taanis =taanis  (SgN  >taanis !09_S	et	f	\N
214027	plazas	?plazas =plaza  (SgIn  >plaza !17_S	et	f	\N
214028	plazas	?plazas =plaza  (IndIpfSg3  >plazama !27_V	et	f	\N
214029	plazas	?plazas =plazas  (SgN  >plazas !09_S	et	f	\N
214037	vabaa	?vabaa =vabaa  (SgN  >vabaa !26_S	et	f	\N
214038	vabaa	?vabaa =vabaa  (SgG  >vabaa !26_S	et	f	\N
214073	valgs	?valgs =valgs  (SgN  >valgs !22_S	et	f	\N
214074	valastajaid	?valastajaid =valastaja  (PlP  >valastaja !01_S	et	f	\N
214075	valastajaid	?valastajaid =valastaja  (PlP  >valastajas !02_A	et	f	\N
214076	valastajaid	?valastajaid =valastajai  (PlN  >valastajai !26_S	et	f	\N
214077	valastajaid	?valastajaid =valastajai  (SgP  >valastajai !26_S	et	f	\N
214084	restoraanid	?restoraanid =restoraani  (PlN  >restoraani !16_S	et	f	\N
214085	restoraanid	?restoraanid =restoraani  (PlN  >restoraan !22_S	et	f	\N
214086	restoraanid	?restoraanid =restoraani  (IndPrSg2  >restoraanima !28_V	et	f	\N
214092	pahklimae	?pahklimae =pahklimae  (SgN  >pahklimae !26_S	et	f	\N
214093	pahklimae	?pahklimae =pahklimae  (SgG  >pahklimae !26_S	et	f	\N
214094	pahklimae	?pahklimae =limae  (SgN  >pahk+limae !26_S	et	f	\N
214095	pahklimae	?pahklimae =limae  (SgG  >pahk+limae !26_S	et	f	\N
214104	liike	liike =liike  (SgN  >liike !12?10_S	et	f	\N
214105	liike	"liike %lii  )KE_dS  <lii ;26_S	et	f	\N
214106	liike	liike =liike  (PlP  >liik !22_S	et	f	\N
214109	prograami	?prograami =prograami  (SgN  >prograami !16_S	et	f	\N
214110	prograami	?prograami =prograami  (SgG  >prograami !16_S	et	f	\N
214111	prograami	?prograami =prograami  (SgG  >prograam !22_S	et	f	\N
214112	prograami	?prograami =prograami  (SgP  >prograam !22_S	et	f	\N
214113	prograami	?prograami =prograami  (SgAdt  >prograam !22_S	et	f	\N
214114	prograami	?prograami =prograami  (IndPrPs_  >prograamima !28_V	et	f	\N
214115	prograami	?prograami =prograami  (ImpPrSg2  >prograamima !28_V	et	f	\N
214138	liiled	?liiled =liile  (PlN  >liile !06_S	et	f	\N
214139	liiled	?liiled =liile  (IndPrSg2  >liilema !27_V	et	f	\N
214142	peenikese	peenikese =peenikese  (SgG  >peenike !12_A	et	f	\N
214143	peenikese	peenikese =peenikese  (SgG  >peenikene !12_A	et	f	\N
214148	typpa	?typpa =typpa  (ID  >typpa !41_D	et	f	\N
214149	typpa	?typpa =typpa  (IndPrPs_  >typpama !29_V	et	f	\N
214150	typpa	?typpa =typpa  (ImpPrSg2  >typpama !29_V	et	f	\N
214151	kannas	kannas =kanna  (SgIn  >kanna !16_S	et	f	\N
214152	kannas	kannas =kanna  (SgIn  >kand !22_S	et	f	\N
214153	puna	puna =puna  (SgN  >puna !17_S	et	f	\N
214154	puna	puna =puna  (SgG  >puna !17_S	et	f	\N
214155	puna	puna =puna  (SgP  >puna !17_S	et	f	\N
214156	puna	puna =puna  (IndPrPs_  >punama !27_V	et	f	\N
214157	puna	puna =puna  (ImpPrSg2  >punama !27_V	et	f	\N
214159	tuhi	?tuhi =tuhi  (SgN  >tuhi !17_S	et	f	\N
214160	tuhi	?tuhi =tuhi  (SgG  >tuhi !17_S	et	f	\N
214161	tuhi	?tuhi =tuhi  (SgP  >tuhi !17_S	et	f	\N
214162	tuhi	?tuhi =tuhi  (IndPrPs_  >tuhima !27_V	et	f	\N
214163	tuhi	?tuhi =tuhi  (ImpPrSg2  >tuhima !27_V	et	f	\N
214173	niisugunesed	?niisugunesed =niisugunese  (PlN  >niisugunene !12_A	et	f	\N
214174	niisugunesed	?niisugunesed =nese  (PlN  >nii+sugu+nese !16_S	et	f	\N
214175	niisugunesed	?niisugunesed =sugunese  (PlN  >nii+sugunene !12_A	et	f	\N
214196	meetsas	?meetsas =meetsa  (SgIn  >meetsa !01_S	et	f	\N
214197	meetsas	?meetsas =meetsa  (IndIpfSg3  >meetsama !29_V	et	f	\N
214198	meetsas	?meetsas =meetsas  (SgN  >meetsas !07_S	et	f	\N
214225	puteli	?puteli =puteli  (ID  >puteli !41_D	et	f	\N
214226	puteli	?puteli =puteli  (SgG  >puttel !02_S	et	f	\N
214233	kupsis	?kupsis =kupsi  (SgIn  >kupsi !16_S	et	f	\N
214234	kupsis	?kupsis =kupsi  (SgIn  >kups !22_S	et	f	\N
214235	kupsis	?kupsis =kupsi  (IndIpfSg3  >kupsima !28_V	et	f	\N
214236	kupsis	?kupsis =kupsis  (SgN  >kupsis !09_S	et	f	\N
214264	punamüstikesele	?punamüstikesele =punamüstikese  (SgAll  >punamüstike !12_S	et	f	\N
214265	punamüstikesele	?punamüstikesele =punamüstikese  (SgAll  >punamüstikene !12_S	et	f	\N
214266	punamüstikesele	?punamüstikesele =müstikese  (SgAll  >puna+müstike !12_S	et	f	\N
214267	punamüstikesele	?punamüstikesele =müstikese  (SgAll  >puna+müstikene !12_S	et	f	\N
214271	punamustikene	punamustikene =mustikene  (SgN  >puna+mustikene !12_S	et	f	\N
214272	punamustikene	"puna+mustikene %musti  )KENE_dA  <puna+must ;22_AS	et	f	\N
214278	huntil	### huntil	et	f	\N
214286	jaotis	jaotis =jaoti  (SgIn  >jaoti !01_S	et	f	\N
214057	huvatav	?huvatav =huvatav  (SgN  >huvatav !02_A	et	f	\N
214062	tõielukult	?tõielukult =tõielukult  (ID  >tõielukult !41_D	et	f	\N
214070	muured	?muured =muure  (PlN  >muure !06_S	et	f	\N
214071	muured	?muured =muure  (IndPrSg2  >muurema !27_V	et	f	\N
214089	muusikafestivalist	muusikafestivalist =festivali  (SgEl  >muusika+festival !19_S	et	f	\N
214090	muusikafestivalist	muusikafestivalist =festivalis  (SgP  >muusika+festivaline !12_A	et	f	\N
214091	muusikafestivalist	"muusika+festivaline %festivali  )NE_aA  <muusika+festival ;19_S	et	f	\N
214107	spetsialse	?spetsialse =spetsialse  (SgG  >spetsialne !02_A	et	f	\N
214108	spetsialse	?spetsialse =spetsialse  (PlP  >spetsials !22_S	et	f	\N
214119	mütsikese	mütsikese =mütsikese  (SgG  >mütsike !12_S	et	f	\N
214120	mütsikese	"mütsike %mütsi  )KE_dS  <müts ;22_S	et	f	\N
214121	mütsikese	mütsikese =mütsikese  (SgG  >mütsikene !12_S	et	f	\N
214122	mütsikese	"mütsikene %mütsi  )KENE_dS  <müts ;22_S	et	f	\N
214140	etepanikud	?etepanikud =etepaniku  (PlN  >etepanik !02_S	et	f	\N
214141	etepanikud	?etepanikud =etepaniku  (IndPrSg2  >etepanikuma !27_V	et	f	\N
214168	voodille	?voodille =voodille  (PlP  >voodill !22_S	et	f	\N
214169	voodille	?voodille =voodille  (IndPrPs_  >voodillema !27_V	et	f	\N
214170	voodille	?voodille =voodille  (ImpPrSg2  >voodillema !27_V	et	f	\N
214171	voodille	?voodille =dille  (SgN  >voo+dille !06_S	et	f	\N
214172	voodille	?voodille =dille  (PlP  >voo+dill !22_S	et	f	\N
214176	tudruku	?tudruku =tudruku  (SgN  >tudruku !01_S	et	f	\N
214177	tudruku	?tudruku =tudruku  (SgG  >tudruku !01_S	et	f	\N
214178	tudruku	?tudruku =tudruku  (IndPrPs_  >tudrukuma !27_V	et	f	\N
214179	tudruku	?tudruku =tudruku  (ImpPrSg2  >tudrukuma !27_V	et	f	\N
214180	elasi	?elasi =elasi  (ID  >elasi !41_D	et	f	\N
214219	kaed	kaed =kae  (PlN  >kae !26_S	et	f	\N
214220	kaed	kaed =kae  (SgP  >kae !26_S	et	f	\N
214221	kaed	kaed =kae  (IndPrSg2  >kaema !27_V	et	f	\N
214224	siilmad	?siilmad =siilma  (IndPrSg2  >siilmama !29_V	et	f	\N
214237	kokki	kokki =kokki  (SgP  >kokk !22_S	et	f	\N
214238	kokki	kokki =kokki  (SgAdt  >kokk !22_S	et	f	\N
214239	kokki	kokki =kokki  (PlP  >kokk !22_S	et	f	\N
214251	punamutsike	punamutsike =mutsike  (SgN  >puna+mutsike !12_S	et	f	\N
214252	punamutsike	"puna+mutsike %mutsi  )KE_dS  <puna+muts ;22_S	et	f	\N
214253	hakaski	?hakaski =hakaski  (SgG  >hakask !02_S	et	f	\N
214254	hakaski	?hakaski =hakaski  (IndPrPs_  >hakaskima !28_V	et	f	\N
214255	hakaski	?hakaski =hakaski  (ImpPrSg2  >hakaskima !28_V	et	f	\N
214256	hakaski	?hakaski =haka  (SgIn^  >haka !16_S	et	f	\N
214257	hakaski	?hakaski =haka  (IndIpfSg3^  >hakama !27_V	et	f	\N
214258	hakaski	?hakaski =hakas  (SgN^  >hakas !07_S	et	f	\N
214263	küpsutas	?küpsutas =küpsuta  (IndIpfSg3  >küpsutama !27_V	et	f	\N
214274	häige	?häige =häige  (SgN  >häige !06_S	et	f	\N
214275	häige	?häige =häige  (PlP  >häig !22_S	et	f	\N
214276	häige	?häige =häige  (IndPrPs_  >häigema !27_V	et	f	\N
214277	häige	?häige =häige  (ImpPrSg2  >häigema !27_V	et	f	\N
214336	lõhki	lõhki =lõhki  (ID  >lõhki !41_D	et	f	\N
214338	lõhki	lõhki =lõhki  (SgP  >lõhk !22_S	et	f	\N
214340	lõhki	lõhki =lõhki  (SgAdt  >lõhk !22_S	et	f	\N
214355	punamutsikesel	punamutsikesel =mutsikese  (SgAd  >puna+mutsike !12_S	et	f	\N
214356	punamutsikesel	"puna+mutsike %mutsi  )KE_dS  <puna+muts ;22_S	et	f	\N
214357	punamutsikesel	punamutsikesel =mutsikese  (SgAd  >puna+mutsikene !12_S	et	f	\N
214358	punamutsikesel	"puna+mutsikene %mutsi  )KENE_dS  <puna+muts ;22_S	et	f	\N
214367	penikese	penikese =penikese  (SgG  >penike !12_S	et	f	\N
214368	penikese	"penike %peni  )KE_dS  <peni ;17_S	et	f	\N
214369	penikese	penikese =penikese  (SgG  >penikene !12_S	et	f	\N
214370	penikese	"penikene %peni  )KENE_dS  <peni ;17_S	et	f	\N
214378	külmetatud	külmetatud =külmeta  (PtsPtIps  >külmetama !27_V	et	f	\N
214379	külmetatud	külmetatud =külmetatu  (PlN  >külmetatu !01_S	et	f	\N
214380	külmetatud	"külmetatu %külmeta  )TU1_vS  <külmetama ;27_V	et	f	\N
214381	külmetatud	külmetatud =külmetatud  (ID  >külmetatud !41_A	et	f	\N
214382	külmetatud	"külmetatud %külmeta  )TUD_vA  <külmetama ;27_V	et	f	\N
214388	noisi	?noisi =noisi  (SgN  >noisi !16_S	et	f	\N
214389	noisi	?noisi =noisi  (SgG  >noisi !16_S	et	f	\N
214390	noisi	?noisi =noisi  (SgG  >nois !22_S	et	f	\N
214391	noisi	?noisi =noisi  (SgP  >nois !22_S	et	f	\N
214392	noisi	?noisi =noisi  (SgAdt  >nois !22_S	et	f	\N
214393	noisi	?noisi =noisi  (IndPrPs_  >noisima !28_V	et	f	\N
214394	noisi	?noisi =noisi  (ImpPrSg2  >noisima !28_V	et	f	\N
214397	roohkem	?roohkem =roohkem  (SgN  >roohkem !02_A	et	f	\N
214414	jallad	?jallad =jalla  (PlN  >jalla !16_S	et	f	\N
214415	jallad	?jallad =jalla  (IndPrSg2  >jallama !29_V	et	f	\N
214430	kiitas	?kiitas =kiita  (SgIn  >kiita !16_S	et	f	\N
214431	kiitas	?kiitas =kiita  (IndIpfSg3  >kiitama !27_V	et	f	\N
214432	kiitas	?kiitas =kiitas  (SgN  >kiitas !07_S	et	f	\N
214433	maitsevam	maitsevam =maitsevam  (SgN  >maitsevam !02_A	et	f	\N
214434	maitsevam	"maitsevam %maitse  )VAM_cA  <maitsema ;28_V	et	f	\N
214435	maitsevam	"maitsevam %maitseva  )M_cA  <maitsev ;02_A	et	f	\N
214232	kokkid	### kokkid	et	f	\N
214288	norskema	?norskema =norske  (Sup  >norskema !27_V	et	f	\N
214289	norskema	?norskema =norskema  (SgG  >norskem !02_A	et	f	\N
214294	lindud	?lindud =lindu  (IndPrSg2  >linduma !27_V	et	f	\N
214295	lindud	?lindud =lindud  (ID  >lindud !41_A	et	f	\N
214300	kopustas	?kopustas =kopusta  (SgIn  >kopusta !01_S	et	f	\N
214301	kopustas	?kopustas =kopusta  (IndIpfSg3  >kopustama !27_V	et	f	\N
214303	hääliga	### hääliga	et	f	\N
214307	tüdrük	### tüdrük	et	f	\N
214308	puurajujad	puurajujad =ajuja  (PlN  >puur+ajuja !01_S	et	f	\N
214309	puurajujad	puurajujad =ajuja  (PlN  >puur+ajujas !02_A	et	f	\N
214319	pünamütsikele	### pünamütsikele	et	f	\N
214320	halt	?halt =halt  (SgN  >halt !22_S	et	f	\N
214352	lunnud	?lunnud =lunnu  (PlN  >lunnu !16_S	et	f	\N
214353	lunnud	?lunnud =lunnu  (IndPrSg2  >lunnuma !27_V	et	f	\N
214354	lunnud	?lunnud =lunnud  (ID  >lunnud !41_A	et	f	\N
214359	tale	?tale =tale  (SgN  >tale !16_S	et	f	\N
214360	tale	?tale =tale  (SgG  >tale !16_S	et	f	\N
214361	tale	?tale =tale  (IndPrPs_  >talema !27_V	et	f	\N
214362	tale	?tale =tale  (ImpPrSg2  >talema !27_V	et	f	\N
214383	hüppis	?hüppis =hüppi  (IndIpfSg3  >hüppima !28_V	et	f	\N
214384	hüppis	?hüppis =hüppis  (ID  >hüppis !41_DA	et	f	\N
214412	õmblesid	õmblesid =õmble  (IndIpfSg2  >õmblema !30_V	et	f	\N
214413	õmblesid	õmblesid =õmble  (IndIpfPl3  >õmblema !30_V	et	f	\N
214436	huntujahumeest	?huntujahumeest =huntujahumee  (SgEl  >huntujahumee !26_S	et	f	\N
214441	tappid	### tappid	et	f	\N
214456	punamütsi	punamütsi =mütsi  (SgG  >puna+müts !22_S	et	f	\N
214457	punamütsi	punamütsi =mütsi  (SgP  >puna+müts !22_S	et	f	\N
214458	punamütsi	punamütsi =mütsi  (SgAdt  >puna+müts !22_S	et	f	\N
214468	süüjas	?süüjas =süüja  (SgIn  >süüja !01_S	et	f	\N
214469	süüjas	?süüjas =süüja  (IndIpfSg3  >süüjama !29_V	et	f	\N
214470	süüjas	?süüjas =süüjas  (SgN  >süüjas !07_S	et	f	\N
214492	soobis	soobis =soobi  (SgIn  >soop !22_S	et	f	\N
214493	soobis	soobis =soobi  (PlIn  >soop !22_S	et	f	\N
214500	juurda	?juurda =juurda  (SgN  >juurda !01_S	et	f	\N
214501	juurda	?juurda =juurda  (SgG  >juurda !01_S	et	f	\N
214502	juurda	?juurda =juurda  (IndPrPs_  >juurdama !27_V	et	f	\N
214503	juurda	?juurda =juurda  (ImpPrSg2  >juurdama !27_V	et	f	\N
214514	koolipõlvest	koolipõlvest =põlve  (SgEl  >kooli+põlv !22_S	et	f	\N
214515	koolipõlvest	koolipõlvest =põlve  (SgEl  >kooli+põli !24_S	et	f	\N
214516	koolipõlvest	koolipõlvest =põlve  (PlEl  >kooli+põlv !22_S	et	f	\N
214517	koolipõlvest	koolipõlvest =põlves  (SgP  >kooli+põlvene !10_A	et	f	\N
214518	koolipõlvest	"kooli+põlvene %põlve  )NE_aA  <kooli+põlv ;22_S	et	f	\N
214519	koolipõlvest	"kooli+põlvene %põlve  )NE_aA  <kooli+põli ;24_S	et	f	\N
214527	keskstatistiline	keskstatistiline =statistiline  (SgN  >kesk+statistiline !12_A	et	f	\N
214528	keskstatistiline	"kesk+statistiline %statisti  )LINE_aA  <kesk+statist ;22_S	et	f	\N
214533	õppimisprotsessi	õppimisprotsessi =protsessi  (SgG  >õppimis+protsess !22_S	et	f	\N
214534	õppimisprotsessi	õppimisprotsessi =protsessi  (SgP  >õppimis+protsess !22_S	et	f	\N
214535	õppimisprotsessi	õppimisprotsessi =protsessi  (SgAdt  >õppimis+protsess !22_S	et	f	\N
214553	sirguv	sirguv =sirgu  (PtsPrPs  >sirguma !27_V	et	f	\N
214554	sirguv	sirguv =sirguv  (SgN  >sirguv !02_A	et	f	\N
214555	sirguv	"sirguv %sirgu  )V_vA  <sirguma ;27_V	et	f	\N
214557	terased	terased =terase  (PlN  >teras !09_S	et	f	\N
214558	terased	terased =terase  (PlN  >terane !10_A	et	f	\N
214559	terased	"terane %tera  )NE_aA  <tera ;17_S	et	f	\N
214562	õpemist	?õpemist =õpemi  (SgEl  >õpemi !01_S	et	f	\N
214563	õpemist	?õpemist =õpemi  (SgEl  >õpem !02_A	et	f	\N
214564	õpemist	?õpemist =õpemis  (SgP  >õpemis !11_S	et	f	\N
214565	õpemist	?õpemist =õpemis  (SgP  >õpemine !12_S	et	f	\N
214566	õpemist	?õpemist =õpemist  (SgN  >õpemist !22_S	et	f	\N
214578	õpelastega	?õpelastega =õpelas  (PlKom  >õpelane !12_S	et	f	\N
214581	venekoolis	venekoolis =kooli  (SgIn  >vene+kool !22_S	et	f	\N
214582	venekoolis	venekoolis =kooli  (PlIn  >vene+kool !22_S	et	f	\N
214585	nõusse	nõusse =nõu  (SgIll  >nõu !26_S	et	f	\N
214586	nõusse	nõusse =nõusse  (ID  >nõusse !41_D	et	f	\N
214646	koolisin	?koolisin =kooli  (IndIpfSg1  >koolima !28_V	et	f	\N
214647	koolisin	?koolisin =koolisin  (SgN  >koolisin !19_S	et	f	\N
214648	koolisin	?koolisin =isin  (SgN  >kool+isin !02_S	et	f	\N
214661	ootsime	?ootsime =oot  (IndIpfPl1  >ootma !34_V	et	f	\N
214662	ootsime	?ootsime =ootsi  (IndPrPl1  >ootsima !28_V	et	f	\N
214668	allahindasin	?allahindasin =allahinda  (IndIpfSg1  >allahindama !27_V	et	f	\N
214669	allahindasin	?allahindasin =allahindasin  (SgN  >allahindasin !19_S	et	f	\N
214670	allahindasin	?allahindasin =asin  (SgN  >alla+hind+asin !02_S	et	f	\N
214671	allahindasin	?allahindasin =hindasin  (SgN  >alla+hindasin !19_S	et	f	\N
214672	allahindasin	?allahindasin =ahindasin  (SgN  >all+ahindasin !19_S	et	f	\N
214683	viidsid	?viidsid =viidsi  (PlN  >viids !22_S	et	f	\N
214684	viidsid	?viidsid =viidsi  (IndPrSg2  >viidsima !28_V	et	f	\N
214732	ladumine	ladumine =ladumine  (SgN  >ladumine !12_S	et	f	\N
214262	punamustikeseks	"puna+mustikene %musti  )KENE_dA  <puna+must ;22_AS	et	f	\N
214268	päistas	?päistas =päista  (SgIn  >päista !01_S	et	f	\N
214269	päistas	?päistas =päista  (IndIpfSg3  >päistama !27_V	et	f	\N
214270	päistas	?päistas =päistas  (SgN  >päistas !07_S	et	f	\N
214279	suua	?suua =suua  (SgN  >suua !16_S	et	f	\N
214280	suua	?suua =suua  (SgG  >suua !16_S	et	f	\N
214283	lähti	?lähti =lähti  (ID  >lähti !41_D	et	f	\N
214284	lähti	?lähti =lähti  (SgP  >läht !22_S	et	f	\N
214285	lähti	?lähti =lähti  (SgAdt  >läht !22_S	et	f	\N
214296	kimlu	?kimlu =kimlu  (SgN  >kimlu !16_S	et	f	\N
214297	kimlu	?kimlu =kimlu  (SgG  >kimlu !16_S	et	f	\N
214298	kimlu	?kimlu =kimlu  (IndPrPs_  >kimluma !27_V	et	f	\N
214299	kimlu	?kimlu =kimlu  (ImpPrSg2  >kimluma !27_V	et	f	\N
214306	kop-kop	### kop-kop	et	f	\N
214315	mahlat	?mahlat =mahla  (SgP  >mahla !16_S	et	f	\N
214316	mahlat	?mahlat =mahlat  (SgN  >mahlat !02_S	et	f	\N
214348	päistis	?päistis =päist  (IndIpfSg3  >päistma !34_V	et	f	\N
214349	päistis	?päistis =päisti  (SgIn  >päist !22_S	et	f	\N
214350	päistis	?päistis =päisti  (IndIpfSg3  >päistima !28_V	et	f	\N
214351	päistis	?päistis =päistis  (SgN  >päistis !09_S	et	f	\N
214416	mõõda	mõõda =mõõda  (IndPrPs_  >mõõtma !34_V	et	f	\N
214417	mõõda	mõõda =mõõda  (ImpPrSg2  >mõõtma !34_V	et	f	\N
214418	loomilikult	?loomilikult =loomiliku  (SgAbl  >loomilik !25_A	et	f	\N
214419	loomilikult	?loomilikult =loomilikult  (ID  >loomilikult !41_D	et	f	\N
214420	loomilikult	?loomilikult =iliku  (SgAbl  >loom+iliku !01_S	et	f	\N
214421	loomilikult	?loomilikult =iliku  (SgAbl  >loom+ilik !02_S	et	f	\N
214422	loomilikult	?loomilikult =miliku  (SgAbl  >loo+miliku !01_S	et	f	\N
214423	loomilikult	?loomilikult =miliku  (SgAbl  >loo+milik !02_S	et	f	\N
214443	tappid	### tappid	et	f	\N
214453	piirukad	?piirukad =piiruka  (PlN  >piiruka !01_S	et	f	\N
214454	piirukad	?piirukad =piiruka  (PlN  >piirukas !02_A	et	f	\N
214455	piirukad	?piirukad =uka  (PlN  >piir+uka !16_S	et	f	\N
214461	esimeesel	esimeesel =meese  (SgAd  >esi+meene !10_A	et	f	\N
214462	esimeesel	"esi+meene %mee  )NE_aA  <esi+mesi ;15_S	et	f	\N
214463	selele	?selele =sele  (SgAll  >sele !16_S	et	f	\N
214464	selele	?selele =selele  (IndPrPs_  >selelema !31~27_V	et	f	\N
214465	selele	?selele =selele  (ImpPrSg2  >selelema !31~27_V	et	f	\N
214466	tubase	tubase =tubase  (SgG  >tubane !10_A	et	f	\N
214467	tubase	"tubane %tuba  )NE_aA  <tuba ;18_S	et	f	\N
214485	huti	?huti =huti  (SgN  >huti !16_S	et	f	\N
214486	huti	?huti =huti  (SgG  >huti !16_S	et	f	\N
214487	huti	?huti =huti  (SgG  >hutt !22_S	et	f	\N
214488	huti	?huti =huti  (IndPrPs_  >hutima !27_V	et	f	\N
214489	huti	?huti =huti  (IndPrPs_  >huttima !28_V	et	f	\N
214490	huti	?huti =huti  (ImpPrSg2  >hutima !27_V	et	f	\N
214491	huti	?huti =huti  (ImpPrSg2  >huttima !28_V	et	f	\N
214497	kopputas	?kopputas =kopputa  (IndIpfSg3  >kopputama !27_V	et	f	\N
214505	puuraiuad	?puuraiuad =puuraiua  (PlN  >puuraiua !01_S	et	f	\N
214506	puuraiuad	?puuraiuad =puuraiuad  (SgN  >puuraiuad !22_S	et	f	\N
214507	puuraiuad	?puuraiuad =aiua  (PlN  >puur+aiua !16_S	et	f	\N
214508	puuraiuad	?puuraiuad =aiuad  (SgN  >puur+aiuad !02_S	et	f	\N
214509	puuraiuad	?puuraiuad =raiua  (PlN  >puu+raiua !16_S	et	f	\N
214510	puuraiuad	?puuraiuad =raiuad  (SgN  >puu+raiuad !02_S	et	f	\N
214536	õpilastese	?õpilastese =õpilastese  (SgG  >õpilastene !12_A	et	f	\N
214537	õpilastese	?õpilastese =tese  (SgN  >õpilas+tese !16_S	et	f	\N
214538	õpilastese	?õpilastese =tese  (SgG  >õpilas+tese !16_S	et	f	\N
214539	õpilastese	?õpilastese =lastese  (SgG  >õpi+lastene !12~10_A	et	f	\N
214540	õppetulemuste	õppetulemuste =muste  (PlP  >õppe+tule+must !22_AS	et	f	\N
214541	õppetulemuste	õppetulemuste =tulemus  (PlG  >õppe+tulemus !11_S	et	f	\N
214546	lähenemises	lähenemises =lähenemise  (SgIn  >lähenemine !12_S	et	f	\N
214547	lähenemises	"lähenemine %lähene  )MINE_vS  <lähenema ;27_V	et	f	\N
214548	pangalaenu	pangalaenu =laenu  (SgG  >panga+laen !22_S	et	f	\N
214549	pangalaenu	pangalaenu =laenu  (SgP  >panga+laen !22_S	et	f	\N
214550	pangalaenu	pangalaenu =laenu  (SgAdt  >panga+laen !22_S	et	f	\N
214556	õpelesed	?õpelesed =õpelese  (PlN  >õpelene !12_A	et	f	\N
214597	negatiivsemaia	?negatiivsemaia =negatiivsemaia  (SgN  >negatiivsemaia !16_S	et	f	\N
214598	negatiivsemaia	?negatiivsemaia =negatiivsemaia  (SgG  >negatiivsemaia !16_S	et	f	\N
214604	õppilasi	?õppilasi =õppilasi  (PlP  >õppilane !12_S	et	f	\N
214605	sisaldasid	sisaldasid =sisalda  (IndIpfSg2  >sisaldama !27_V	et	f	\N
214606	sisaldasid	sisaldasid =sisalda  (IndIpfPl3  >sisaldama !27_V	et	f	\N
214619	koolilapsepõlvest	koolilapsepõlvest =põlve  (SgEl  >kooli+lapse+põlv !22_S	et	f	\N
214620	koolilapsepõlvest	koolilapsepõlvest =põlve  (SgEl  >kooli+lapse+põli !24_S	et	f	\N
214621	koolilapsepõlvest	koolilapsepõlvest =põlve  (PlEl  >kooli+lapse+põlv !22_S	et	f	\N
214622	koolilapsepõlvest	koolilapsepõlvest =põlves  (SgP  >kooli+lapse+põlvene !10_A	et	f	\N
214623	koolilapsepõlvest	"kooli+lapse+põlvene %põlve  )NE_aA  <kooli+lapse+põlv ;22_S	et	f	\N
214624	koolilapsepõlvest	"kooli+lapse+põlvene %põlve  )NE_aA  <kooli+lapse+põli ;24_S	et	f	\N
214287	jaotis	jaotis =jaotis  (SgN  >jaotis !11~09_S	et	f	\N
214293	tudrük	### tudrük	et	f	\N
214302	kop-kop-kop	### kop-kop-kop	et	f	\N
214304	lahtu	lahtu =lahtu  (IndPrPs_  >lahtuma !27_V	et	f	\N
214305	lahtu	lahtu =lahtu  (ImpPrSg2  >lahtuma !27_V	et	f	\N
214310	lõigasid	?lõigasid =lõiga  (PlP  >lõiga !16_S	et	f	\N
214311	lõigasid	?lõigasid =lõiga  (IndIpfSg2  >lõigama !29_V	et	f	\N
214312	lõigasid	?lõigasid =lõiga  (IndIpfPl3  >lõigama !29_V	et	f	\N
214317	küpsetasid	küpsetasid =küpseta  (IndIpfSg2  >küpsetama !27_V	et	f	\N
214318	küpsetasid	küpsetasid =küpseta  (IndIpfPl3  >küpsetama !27_V	et	f	\N
214321	peenemaks	peenemaks =peenema  (SgTr  >peenem !02_A	et	f	\N
214322	peenemaks	"peenem %peene  )M_cA  <peen ;13_A	et	f	\N
214323	peenemaks	peenemaks =maks  (SgN  >peene+maks !22_S	et	f	\N
214324	peenemaks	peenemaks =ema  (SgTr  >peen+ema !17_S	et	f	\N
214325	kalistada	?kalistada =kalista  (Inf  >kalistama !27_V	et	f	\N
214333	lõikusid	lõikusid =lõiku  (PlP  >lõik !22_S	et	f	\N
214334	lõikusid	lõikusid =lõiku  (IndIpfSg2  >lõikuma !27_V	et	f	\N
214335	lõikusid	lõikusid =lõiku  (IndIpfSg2  >lõikuma !28_V	et	f	\N
214337	lõikusid	lõikusid =lõiku  (IndIpfPl3  >lõikuma !27_V	et	f	\N
214339	lõikusid	lõikusid =lõiku  (IndIpfPl3  >lõikuma !28_V	et	f	\N
214341	purgi	purgi =purgi  (SgG  >purk !22_S	et	f	\N
214342	purgi	purgi =purgi  (IndPrPs_  >purkima !28_V	et	f	\N
214343	purgi	purgi =purgi  (ImpPrSg2  >purkima !28_V	et	f	\N
214374	punanamütsikesest	?punanamütsikesest =punanamütsikese  (SgEl  >punanamütsike !12_S	et	f	\N
214375	punanamütsikesest	?punanamütsikesest =punanamütsikese  (SgEl  >punanamütsikene !12_S	et	f	\N
214376	punanamütsikesest	?punanamütsikesest =namütsikese  (SgEl  >puna+namütsike !12_S	et	f	\N
214377	punanamütsikesest	?punanamütsikesest =namütsikese  (SgEl  >puna+namütsikene !12_S	et	f	\N
214395	tänasid	tänasid =täna  (IndIpfSg2  >tänama !27_V	et	f	\N
214396	tänasid	tänasid =täna  (IndIpfPl3  >tänama !27_V	et	f	\N
214398	liingile	?liingile =liingi  (SgAll  >liink !22_S	et	f	\N
214399	liingile	?liingile =liingile  (IndPrPs_  >liingilema !27_V	et	f	\N
214400	liingile	?liingile =liingile  (ImpPrSg2  >liingilema !27_V	et	f	\N
214401	heittis	?heittis =heitti  (SgIn  >heitt !22_S	et	f	\N
214402	heittis	?heittis =heitti  (IndIpfSg3  >heittima !28_V	et	f	\N
214403	heittis	?heittis =heittis  (ID  >heittis !41_DA	et	f	\N
214411	parenimi	?parenimi =parenimi  (SgG  >parenim !02_A	et	f	\N
214424	lollike	lollike =lollike  (SgN  >lollike !12_AS	et	f	\N
214425	lollike	"lollike %lolli  )KE_dA  <loll ;22_AS	et	f	\N
214426	lollike	lollike =ike  (SgN  >loll+ike !06_S	et	f	\N
214450	ümbles	?ümbles =ümble  (SgIn  >ümble !06_S	et	f	\N
214451	ümbles	?ümbles =ümble  (IndIpfSg3  >ümblema !30_V	et	f	\N
214452	ümbles	?ümbles =ümbles  (SgN  >ümbles !09_S	et	f	\N
214459	lääks	?lääks =lää  (SgTr  >lää !26_S	et	f	\N
214460	lääks	?lääks =lääks  (SgN  >lääks !22_S	et	f	\N
214479	katke	katke =kat  (ImpPrPl2  >katma !35_V	et	f	\N
214480	katke	katke =katke  (SgN  >katke !06_S	et	f	\N
214481	katke	katke =katke  (SgG  >katke !06_S	et	f	\N
214482	katke	katke =katke  (PlP  >katk !22_S	et	f	\N
214483	katke	katke =katke  (IndPrPs_  >katkema !27_V	et	f	\N
214484	katke	katke =katke  (ImpPrSg2  >katkema !27_V	et	f	\N
214504	punamütsiket	### punamütsiket	et	f	\N
214511	punamütsikega	?punamütsikega =kega  (SgN  >puna+mütsi+kega !17_S	et	f	\N
214512	punamütsikega	?punamütsikega =kega  (SgG  >puna+mütsi+kega !17_S	et	f	\N
214513	punamütsikega	?punamütsikega =kega  (SgP  >puna+mütsi+kega !17_S	et	f	\N
214560	autoriteetsust	autoriteetsust =autoriteetsus  (SgP  >autoriteetsus !11~09_S	et	f	\N
214561	autoriteetsust	"autoriteetsus %autoriteetse  )US_aS  <autoriteetne ;02_A	et	f	\N
214570	erenevaid	erenevaid =ereneva  (PlP  >erenev !02_A	et	f	\N
214571	erenevaid	"erenev %erene  )V_vA  <erenema ;27_V	et	f	\N
214587	matemaatike	?matemaatike =matemaatike  (SgN  >matemaatike !12_S	et	f	\N
214592	lahendamine	lahendamine =lahendamine  (SgN  >lahendamine !12_S	et	f	\N
214593	lahendamine	"lahendamine %lahenda  )MINE_vS  <lahendama ;27_V	et	f	\N
214599	kõrgendatud	kõrgendatud =kõrgenda  (PtsPtIps  >kõrgendama !27_V	et	f	\N
214600	kõrgendatud	kõrgendatud =kõrgendatu  (PlN  >kõrgendatu !01_S	et	f	\N
214601	kõrgendatud	"kõrgendatu %kõrgenda  )TU1_vS  <kõrgendama ;27_V	et	f	\N
214602	kõrgendatud	kõrgendatud =kõrgendatud  (ID  >kõrgendatud !41_A	et	f	\N
214603	kõrgendatud	"kõrgendatud %kõrgenda  )TUD_vA  <kõrgendama ;27_V	et	f	\N
214625	elevil	elevil =elevi  (SgAd  >elev !02_A	et	f	\N
214626	elevil	elevil =elevil  (ID  >elevil !41_DA	et	f	\N
214627	kassidega	kassidega =kassi  (PlKom  >kass !22_S	et	f	\N
214628	kassidega	kassidega =si  (PlKom  >kas+si !26_S	et	f	\N
214629	kassidega	kassidega =side  (SgKom  >kas+side !16_S	et	f	\N
214633	koolilapsepõlves	koolilapsepõlves =põlve  (SgIn  >kooli+lapse+põlv !22_S	et	f	\N
214634	koolilapsepõlves	koolilapsepõlves =põlve  (SgIn  >kooli+lapse+põli !24_S	et	f	\N
214635	koolilapsepõlves	koolilapsepõlves =põlve  (PlIn  >kooli+lapse+põlv !22_S	et	f	\N
214637	käiseme	?käiseme =käise  (IndPrPl1  >käisema !28_V	et	f	\N
214366	joksis	?joksis =joksis  (SgN  >joksis !09_S	et	f	\N
214371	vodisse	?vodisse =vodi  (SgIll  >vodi !17_S	et	f	\N
214372	vodisse	?vodisse =vodisse  (SgG  >vodisne !02_A	et	f	\N
214373	vodisse	?vodisse =vodisse  (PlP  >vodiss !22_S	et	f	\N
214385	kulsid	?kulsid =kulsi  (PlN  >kulsi !16_S	et	f	\N
214386	kulsid	?kulsid =kulsi  (PlN  >kulss !22_S	et	f	\N
214387	kulsid	?kulsid =kulsi  (IndPrSg2  >kulssima !28_V	et	f	\N
214404	päha	?päha =päha  (SgN  >päha !17_S	et	f	\N
214405	päha	?päha =päha  (SgG  >päha !17_S	et	f	\N
214406	päha	?päha =päha  (SgP  >päha !17_S	et	f	\N
214407	päha	?päha =päha  (IndPrPs_  >pähama !27_V	et	f	\N
214408	päha	?päha =päha  (ImpPrSg2  >pähama !27_V	et	f	\N
214409	hääljaga	?hääljaga =häälja  (SgKom  >häälja !01_S	et	f	\N
214410	hääljaga	?hääljaga =häälja  (SgKom  >hääljas !02_A	et	f	\N
214427	kimpu	kimpu =kimpu  (ID  >kimpu !41_DK	et	f	\N
214428	kimpu	kimpu =kimpu  (SgP  >kimp !22_S	et	f	\N
214429	kimpu	kimpu =kimpu  (SgAdt  >kimp !22_S	et	f	\N
214437	jahumeest	jahumeest =mee  (SgEl  >jahu+mesi !15_S	et	f	\N
214438	jahumeest	jahumeest =mees  (SgP  >jahu+meene !10_A	et	f	\N
214439	jahumeest	"jahu+meene %mee  )NE_aA  <jahu+mesi ;15_S	et	f	\N
214440	jahumeest	jahumeest =mees  (SgP  >jahu+mees !13_S	et	f	\N
214444	punamütsikeks	punamütsikeks =keks  (SgN  >puna+mütsi+keks !22_S	et	f	\N
214445	punamütsikeks	punamütsikeks =keks  (SgN  >puna+mütsi+keks !22_A	et	f	\N
214446	potti	potti =potti  (SgP  >pott !22_S	et	f	\N
214447	potti	potti =potti  (SgAdt  >pott !22_S	et	f	\N
214448	tulis	?tulis =tuli  (IndIpfSg3  >tulima !27_V	et	f	\N
214449	tulis	?tulis =tulis  (SgN  >tulis !09_S	et	f	\N
214473	lamal	?lamal =lama  (SgAd  >lama !17_S	et	f	\N
214474	lamal	?lamal =lamal  (SgN  >lamal !02_S	et	f	\N
214475	joksuga	?joksuga =joksu  (SgKom  >joksu !16_S	et	f	\N
214494	sõinud	?sõinud =sõinu  (PlN  >sõinu !16_S	et	f	\N
214495	sõinud	?sõinud =sõinu  (IndPrSg2  >sõinuma !28_V	et	f	\N
214496	sõinud	?sõinud =sõinud  (ID  >sõinud !41_A	et	f	\N
214542	märkustest	märkustest =märkus  (PlEl  >märkus !11~09_S	et	f	\N
214543	märkustest	märkustest =us  (PlEl  >märk+uks !14_S	et	f	\N
214544	pojalt	pojalt =poja  (SgAbl  >poja !17_S	et	f	\N
214545	pojalt	pojalt =poja  (SgAbl  >poeg !22_S	et	f	\N
214577	professionalid	?professionalid =professionali  (PlN  >professional !02_S	et	f	\N
214579	tahatsid	?tahatsid =tahatsi  (PlN  >tahats !02_S	et	f	\N
214580	tahatsid	?tahatsid =tahatsi  (IndPrSg2  >tahatsima !28_V	et	f	\N
214583	meelitata	meelitata =meelita  (IndPrIps_  >meelitama !27_V	et	f	\N
214584	meelitata	meelitata =lita  (SgAb  >mee+lita !16_S	et	f	\N
214590	logiliste	logiliste =logilis  (PlG  >logiline !12_A	et	f	\N
214591	logiliste	"logiline %logi  )LINE_aA  <logi ;17_S	et	f	\N
214594	kleopatrast	?kleopatrast =kleopatra  (SgEl  >kleopatra !01_S	et	f	\N
214595	kleopatrast	?kleopatrast =kleopatras  (SgP  >kleopatrane !12_A	et	f	\N
214596	kleopatrast	?kleopatrast =kleopatrast  (SgN  >kleopatrast !22_S	et	f	\N
214656	kelleoskuse	?kelleoskuse =kelleoskuse  (SgG  >kelleoskus !11~09_S	et	f	\N
214693	rikkades	### rikkades	et	f	\N
214700	faktoridega	### faktoridega	et	f	\N
214772	tradistioon	?tradistioon =tradistioon  (SgN  >tradistioon !22_S	et	f	\N
214788	asutusest	asutusest =asutuse  (SgEl  >asutus !11_S	et	f	\N
214789	asutusest	"asutus %asuta  )US_vS  <asutama ;27_V	et	f	\N
214790	asutusest	"asutus %asu  )TUS1_aS  <asuma ;27_V	et	f	\N
214791	asutusest	"asutus %asu  )TUS2_aS  <asu ;17_S	et	f	\N
214792	asutusest	asutusest =asutuses  (SgP  >asutusene !12_A	et	f	\N
214793	asutusest	"asutusene %asutuse  )NE_aA  <asutus ;11_S	et	f	\N
214801	pärimusest	pärimusest =pärimuse  (SgEl  >pärimus !11_S	et	f	\N
214802	pärimusest	"pärimus %päri  )MUS_vS  <pärima ;27_V	et	f	\N
214803	pärimusest	pärimusest =pärimuses  (SgP  >pärimusene !12_A	et	f	\N
214804	pärimusest	"pärimusene %pärimuse  )NE_aA  <pärimus ;11_S	et	f	\N
214826	kohapärimusest	kohapärimusest =pärimuse  (SgEl  >koha+pärimus !11_S	et	f	\N
214827	kohapärimusest	kohapärimusest =pärimuses  (SgP  >koha+pärimusene !12_A	et	f	\N
214828	kohapärimusest	"koha+pärimusene %pärimuse  )NE_aA  <koha+pärimus ;11_S	et	f	\N
214847	ronnie	?ronnie =ronnie  (SgN  >ronnie !01_S	et	f	\N
214848	ronnie	?ronnie =ronnie  (SgG  >ronnie !01_S	et	f	\N
214873	northampronis	?northampronis =northamproni  (SgIn  >northampron !02_S	et	f	\N
214874	northampronis	?northampronis =northampronis  (SgN  >northampronis !09_S	et	f	\N
214883	keskalinnas	?keskalinnas =keskalinna  (SgIn  >keskalinna !16_S	et	f	\N
214884	keskalinnas	?keskalinnas =alinna  (SgIn  >kesk+alinna !16_S	et	f	\N
214912	28-aastaseks	-aastaseks =aastase  (SgTr  >-aastane !12~10_A	et	f	\N
214913	28-aastaseks	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
214914	28-aastaseks	-aastaseks =seks  (SgN  >-aasta+seks !22_S	et	f	\N
214929	bussireis	bussireis =reis  (SgN  >bussi+reis !14_S	et	f	\N
214930	bussireis	bussireis =reis  (SgN  >bussi+reis !22_S	et	f	\N
214935	keramiikaklubis	?keramiikaklubis =keramiikaklubis  (SgN  >keramiikaklubis !09_S	et	f	\N
214936	keramiikaklubis	?keramiikaklubis =miikaklubis  (SgN  >kera+miikaklubis !09_S	et	f	\N
214442	tappin	?tappin =tappin  (SgN  >tappin !02_S	et	f	\N
214471	panas	?panas =pana  (SgIn  >pana !17_S	et	f	\N
214472	panas	?panas =panas  (SgN  >panas !09_S	et	f	\N
214476	norstas	?norstas =norsta  (SgIn  >norsta !01_S	et	f	\N
214477	norstas	?norstas =norsta  (IndIpfSg3  >norstama !29_V	et	f	\N
214478	norstas	?norstas =norstas  (SgN  >norstas !07_S	et	f	\N
214498	lingele	lingele =linge  (PlAll  >ling !22_S	et	f	\N
214499	lingele	lingele =linge  (PlAll  >link !22_S	et	f	\N
214520	koolipõlve	koolipõlve =põlve  (SgG  >kooli+põlv !22_S	et	f	\N
214521	koolipõlve	koolipõlve =põlve  (SgG  >kooli+põli !24_S	et	f	\N
214522	koolipõlve	koolipõlve =põlve  (SgP  >kooli+põlv !22_S	et	f	\N
214523	koolipõlve	koolipõlve =põlve  (SgP  >kooli+põli !24_S	et	f	\N
214524	koolipõlve	koolipõlve =põlve  (SgAdt  >kooli+põlv !22_S	et	f	\N
214525	koolipõlve	koolipõlve =põlve  (SgAdt  >kooli+põli !24_S	et	f	\N
214526	koolipõlve	koolipõlve =põlve  (PlP  >kooli+põlv !22_S	et	f	\N
214529	minumeelest	minumeelest =lest  (SgN  >minu+mee+lest !22_S	et	f	\N
214530	minumeelest	minumeelest =meele  (SgEl  >minu+meel !13_S	et	f	\N
214531	minumeelest	minumeelest =meeles  (SgP  >minu+meelene !10_A	et	f	\N
214532	minumeelest	"minu+meelene %meele  )NE_aA  <minu+meel ;13_S	et	f	\N
214551	õpetajategevus	õpetajategevus =tegevus  (SgN  >õpetaja+tegevus !11_S	et	f	\N
214552	õpetajategevus	"õpetaja+tegevus %tegeva  )US_aS  <õpetaja+tegev ;02_A	et	f	\N
214567	kordada	?kordada =ada  (SgN  >kord+ada !17_S	et	f	\N
214568	kordada	?kordada =ada  (SgG  >kord+ada !17_S	et	f	\N
214569	kordada	?kordada =ada  (SgP  >kord+ada !17_S	et	f	\N
214572	meldinud	meldinud =meldi  (PtsPtPs  >meldima !28_V	et	f	\N
214573	meldinud	meldinud =meldinu  (PlN  >meldinu !01_S	et	f	\N
214574	meldinud	"meldinu %meldi  )NU_vS  <meldima ;28_V	et	f	\N
214575	meldinud	meldinud =meldinud  (ID  >meldinud !41_A	et	f	\N
214576	meldinud	"meldinud %meldi  )NUD_vA  <meldima ;28_V	et	f	\N
214588	arvutamine	arvutamine =arvutamine  (SgN  >arvutamine !12_S	et	f	\N
214589	arvutamine	"arvutamine %arvuta  )MINE_vS  <arvutama ;27_V	et	f	\N
214607	õppematerjaali	?õppematerjaali =õppematerjaali  (SgN  >õppematerjaali !16_S	et	f	\N
214608	õppematerjaali	?õppematerjaali =õppematerjaali  (SgG  >õppematerjaali !16_S	et	f	\N
214609	õppematerjaali	?õppematerjaali =õppematerjaali  (SgG  >õppematerjaal !22_S	et	f	\N
214610	õppematerjaali	?õppematerjaali =õppematerjaali  (SgP  >õppematerjaal !22_S	et	f	\N
214611	õppematerjaali	?õppematerjaali =õppematerjaali  (SgAdt  >õppematerjaal !22_S	et	f	\N
214612	õppematerjaali	?õppematerjaali =õppematerjaali  (IndPrPs_  >õppematerjaalima !28_V	et	f	\N
214613	õppematerjaali	?õppematerjaali =õppematerjaali  (ImpPrSg2  >õppematerjaalima !28_V	et	f	\N
214614	õppematerjaali	?õppematerjaali =materjaali  (SgN  >õppe+materjaali !16_S	et	f	\N
214615	õppematerjaali	?õppematerjaali =materjaali  (SgG  >õppe+materjaali !16_S	et	f	\N
214616	õppematerjaali	?õppematerjaali =materjaali  (SgG  >õppe+materjaal !22_S	et	f	\N
214617	õppematerjaali	?õppematerjaali =materjaali  (SgP  >õppe+materjaal !22_S	et	f	\N
214618	õppematerjaali	?õppematerjaali =materjaali  (SgAdt  >õppe+materjaal !22_S	et	f	\N
214645	hummanitaar	?hummanitaar =hummanitaar  (SgN  >hummanitaar !22_S	et	f	\N
214649	haavasid	haavasid =haava  (PlP  >haav !22_S	et	f	\N
214650	haavasid	haavasid =haava  (IndIpfSg2  >haavama !29_V	et	f	\N
214651	haavasid	haavasid =haava  (IndIpfPl3  >haavama !29_V	et	f	\N
214657	hingestatult	hingestatult =hingestatu  (SgAbl  >hingestatu !01_S	et	f	\N
214658	hingestatult	"hingestatu %hingesta  )TU1_vS  <hingestama ;27_V	et	f	\N
214659	hingestatult	hingestatult =hingestatult  (ID  >hingestatult !41_D	et	f	\N
214660	hingestatult	"hingestatult %hingesta  )TULT1_mD  <hingestama ;27_V	et	f	\N
214663	kannatamatusega	kannatamatusega =kannatamatuse  (SgKom  >kannatamatus !11?09_S	et	f	\N
214664	kannatamatusega	"kannatamatus %kannata  )MATUS_aS  <kannatama ;27_V	et	f	\N
214665	eelisid	?eelisid =eeli  (IndIpfSg2  >eelima !28_V	et	f	\N
214666	eelisid	?eelisid =eeli  (IndIpfPl3  >eelima !28_V	et	f	\N
214667	eelisid	?eelisid =isi  (PlN  >eel+isi !17_S	et	f	\N
214673	hädaseisus	hädaseisus =seisu  (SgIn  >häda+seis !22_S	et	f	\N
214674	hädaseisus	hädaseisus =seisus  (SgN  >häda+seisus !11~09_S	et	f	\N
214676	irvitasid	irvitasid =irvita  (IndIpfSg2  >irvitama !27_V	et	f	\N
214677	irvitasid	irvitasid =irvita  (IndIpfPl3  >irvitama !27_V	et	f	\N
214680	administratsiooni	administratsiooni =administratsiooni  (SgG  >administratsioon !22_S	et	f	\N
214681	administratsiooni	administratsiooni =administratsiooni  (SgP  >administratsioon !22_S	et	f	\N
214682	administratsiooni	administratsiooni =administratsiooni  (SgAdt  >administratsioon !22_S	et	f	\N
214685	lori	lori =lori  (SgN  >lori !17_S	et	f	\N
214686	lori	lori =lori  (SgG  >lori !17_S	et	f	\N
214687	lori	lori =lori  (SgP  >lori !17_S	et	f	\N
214688	lori	lori =lori  (IndPrPs_  >lorima !27_V	et	f	\N
214689	lori	lori =lori  (ImpPrSg2  >lorima !27_V	et	f	\N
214690	tänulikus	tänulikus =tänuliku  (SgIn  >tänulik !25_A	et	f	\N
214691	tänulikus	tänulikus =tänulikus  (SgN  >tänulikus !11?09_S	et	f	\N
214692	tänulikus	"tänulikus %tänuliku  )US_aS  <tänulik ;25_A	et	f	\N
214694	epl	?epl =epl  (SgN  >epl !22_S	et	f	\N
214695	tõusega	?tõusega =sega  (SgN  >tõu+sega !17_S	et	f	\N
214630	koolikaaslaste	koolikaaslaste =las  (PlG  >kooli+kaas+laps !14_S	et	f	\N
214631	koolikaaslaste	koolikaaslaste =laste  (PlP  >kooli+kaas+last !22_S	et	f	\N
214632	koolikaaslaste	koolikaaslaste =kaaslas  (PlG  >kooli+kaaslane !12?10_S	et	f	\N
214636	põnevades	### põnevades	et	f	\N
214640	jarele	?jarele =jare  (SgAll  >jare !16_S	et	f	\N
214641	jarele	?jarele =jarele  (IndPrPs_  >jarelema !31~27_V	et	f	\N
214642	jarele	?jarele =jarele  (ImpPrSg2  >jarelema !31~27_V	et	f	\N
214706	mõjustust	mõjustust =mõjustus  (SgP  >mõjustus !11_S	et	f	\N
214707	mõjustust	"mõjustus %mõjusta  )US_vS  <mõjustama ;27_V	et	f	\N
214713	madalaim	madalaim =madalaim  (SgN  >madalaim !02_A	et	f	\N
214714	madalaim	"madalaim %madala  )IM_sA  <madal ;02_AS	et	f	\N
214715	madalaim	madalaim =aim  (SgN  >madal+aim !22_S	et	f	\N
214725	koondamise	koondamise =koondamise  (SgG  >koondamine !12_S	et	f	\N
214726	koondamise	"koondamine %koonda  )MINE_vS  <koondama ;27_V	et	f	\N
214753	asundused	asundused =asunduse  (PlN  >asundus !11_S	et	f	\N
214754	asundused	"asundus %asunda  )US_vS  <asundama ;27_V	et	f	\N
214768	omanäoline	omanäoline =näoline  (SgN  >oma+näoline !12?10_A	et	f	\N
214769	omanäoline	"oma+näoline %näo  )LINE_aA  <oma+nägu ;18_S	et	f	\N
214773	naaberrahvastelt	naaberrahvastelt =rahvas  (PlAbl  >naaber+rahvas !07_S	et	f	\N
214774	naaberrahvastelt	naaberrahvastelt =rahvas  (PlAbl  >naaber+rahvane !10_A	et	f	\N
214775	naaberrahvastelt	"naaber+rahvane %rahva  )NE_aA  <naaber+rahvas ;07_S	et	f	\N
214776	üigem	?üigem =üigem  (SgN  >üigem !02_A	et	f	\N
214794	kohandusid	kohandusid =kohandu  (IndIpfSg2  >kohanduma !27_V	et	f	\N
214795	kohandusid	kohandusid =kohandu  (IndIpfPl3  >kohanduma !27_V	et	f	\N
214799	kultuurilisest	kultuurilisest =kultuurilise  (SgEl  >kultuuriline !12_A	et	f	\N
214800	kultuurilisest	"kultuuriline %kultuuri  )LINE_aA  <kultuur ;22_S	et	f	\N
214811	laenanud	laenanud =laena  (PtsPtPs  >laenama !29_V	et	f	\N
214812	laenanud	laenanud =laenanu  (PlN  >laenanu !01_S	et	f	\N
214813	laenanud	"laenanu %laena  )NU_vS  <laenama ;29_V	et	f	\N
214814	laenanud	laenanud =laenanud  (ID  >laenanud !41_A	et	f	\N
214815	laenanud	"laenanud %laena  )NUD_vA  <laenama ;29_V	et	f	\N
214816	mõeldav	mõeldav =mõel  (PtsPrIps  >mõtlema !30_V	et	f	\N
214817	mõeldav	mõeldav =mõeldav  (SgN  >mõeldav !02_A	et	f	\N
214818	mõeldav	"mõeldav %mõel  )TAV_vAS  <mõtlema ;30_V	et	f	\N
214819	loomata	loomata =loo  (SupAb  >looma !38_V	et	f	\N
214821	loomata	loomata =looma  (SgAb  >loom !22_S	et	f	\N
214823	loomata	loomata =loomata  (ID  >loomata !41_A	et	f	\N
214824	loomata	"loomata %loo  )MATA_vA  <looma ;38_V	et	f	\N
214831	tekkelood	tekkelood =loo  (PlN  >tekke+lugu !18_S	et	f	\N
214832	tekkelood	tekkelood =loo  (PlN  >tekke+loog !22_S	et	f	\N
214833	tekkelood	tekkelood =loo  (PlN  >tekke+lood !22_S	et	f	\N
214834	tekkelood	tekkelood =lood  (SgN  >tekke+lood !22_S	et	f	\N
214842	leidnus	leidnus =leidnu  (SgIn  >leidnu !01_S	et	f	\N
214843	leidnus	"leidnu %leid  )NU_vS  <leidma ;34_V	et	f	\N
214852	kittarist	?kittarist =kittari  (SgEl  >kittari !01_S	et	f	\N
214853	kittarist	?kittarist =kittari  (SgEl  >kittar !02_S	et	f	\N
214854	kittarist	?kittarist =kittaris  (SgP  >kittaris !11_S	et	f	\N
214855	kittarist	?kittarist =kittarist  (SgN  >kittarist !22_S	et	f	\N
214861	keith	?keith =keith  (SgN  >keith !22_S	et	f	\N
214863	dartfarlis	?dartfarlis =dartfarli  (SgIn  >dartfarli !01_S	et	f	\N
214864	dartfarlis	?dartfarlis =dartfarli  (SgIn  >dartfarl !22_S	et	f	\N
214865	dartfarlis	?dartfarlis =dartfarli  (IndIpfSg3  >dartfarlima !28_V	et	f	\N
214866	dartfarlis	?dartfarlis =dartfarlis  (SgN  >dartfarlis !11_S	et	f	\N
214869	lewis	?lewis =lewi  (SgIn  >lewi !16_S	et	f	\N
214870	lewis	?lewis =lewis  (SgN  >lewis !09_S	et	f	\N
214903	bussijaamast	bussijaamast =jaama  (SgEl  >bussi+jaam !22_S	et	f	\N
214904	bussijaamast	bussijaamast =jaamas  (SgP  >bussi+jaamane !10_A	et	f	\N
214905	bussijaamast	"bussi+jaamane %jaama  )NE_aA  <bussi+jaam ;22_S	et	f	\N
214915	etc	?etc =etc  (SgN  >etc !22_S	et	f	\N
214922	janne	?janne =janne  (SgN  >janne !06_S	et	f	\N
214923	janne	?janne =janne  (PlP  >jann !22_S	et	f	\N
214924	janne	?janne =janne  (IndPrPs_  >jannema !27_V	et	f	\N
214925	janne	?janne =janne  (ImpPrSg2  >jannema !27_V	et	f	\N
214927	millalt	?millalt =milla  (SgAbl  >milla !16_S	et	f	\N
214928	millalt	?millalt =millalt  (ID  >millalt !41_D	et	f	\N
214937	puna-	puna- =puna  (SgN  >puna !17_S	et	f	\N
214938	puna-	puna- =puna  (SgG  >puna !17_S	et	f	\N
214939	puna-	puna- =puna  (SgP  >puna !17_S	et	f	\N
214940	puna-	puna- =puna  (IndPrPs_  >punama !27_V	et	f	\N
214941	puna-	puna- =puna  (ImpPrSg2  >punama !27_V	et	f	\N
214949	savitõed	savitõed =tõe  (PlN  >savi+tõsi !15_S	et	f	\N
214951	savitõed	savitõed =tõe  (PlN  >savi+tõde !18_S	et	f	\N
214958	kraadid	kraadid =kraadi  (PlN  >kraad !22_S	et	f	\N
214959	kraadid	kraadid =kraadi  (IndPrSg2  >kraadima !28_V	et	f	\N
214962	erivärviga	erivärviga =iga  (SgN  >eri+värv+iga !18_S	et	f	\N
214963	erivärviga	erivärviga =iga  (SgP  >eri+värv+iga !18_S	et	f	\N
214964	erivärviga	erivärviga =värvi  (SgKom  >eri+värv !22_S	et	f	\N
214638	igatsus	igatsus =igatsus  (SgN  >igatsus !11_S	et	f	\N
214639	igatsus	"igatsus %igatse  )US_vS  <igatsema ;27_V	et	f	\N
214643	mäletused	mäletused =mäletuse  (PlN  >mäletus !11_S	et	f	\N
214644	mäletused	"mäletus %mäleta  )US_vS  <mäletama ;27_V	et	f	\N
214652	määllu	?määllu =määllu  (SgN  >määllu !01_S	et	f	\N
214653	määllu	?määllu =määllu  (SgG  >määllu !01_S	et	f	\N
214654	määllu	?määllu =määllu  (IndPrPs_  >määlluma !27_V	et	f	\N
214655	määllu	?määllu =määllu  (ImpPrSg2  >määlluma !27_V	et	f	\N
214675	eeskujuliks	?eeskujuliks =eeskujuli  (SgTr  >eeskujul !19_S	et	f	\N
214678	organisatsiooniliseid	?organisatsiooniliseid =organisatsioonilisei  (PlN  >organisatsioonilisei !26_S	et	f	\N
214679	organisatsiooniliseid	?organisatsiooniliseid =organisatsioonilisei  (SgP  >organisatsioonilisei !26_S	et	f	\N
214698	teisede	teisede =ede  (SgN  >teis+ede !16_S	et	f	\N
214699	teisede	teisede =ede  (SgG  >teis+ede !16_S	et	f	\N
214708	rahuldanud	rahuldanud =rahulda  (PtsPtPs  >rahuldama !27_V	et	f	\N
214709	rahuldanud	rahuldanud =rahuldanu  (PlN  >rahuldanu !01_S	et	f	\N
214710	rahuldanud	"rahuldanu %rahulda  )NU_vS  <rahuldama ;27_V	et	f	\N
214711	rahuldanud	rahuldanud =rahuldanud  (ID  >rahuldanud !41_A	et	f	\N
214712	rahuldanud	"rahuldanud %rahulda  )NUD_vA  <rahuldama ;27_V	et	f	\N
214716	statistikaamet	statistikaamet =amet  (SgN  >statistika+amet !02_S	et	f	\N
214717	statistikaamet	statistikaamet =kaame  (SgP  >statisti+kaame !01_A	et	f	\N
214745	abiraha	abiraha =raha  (SgN  >abi+raha !17_S	et	f	\N
214746	abiraha	abiraha =raha  (SgG  >abi+raha !17_S	et	f	\N
214747	abiraha	abiraha =raha  (SgG  >abi+rahk !22_S	et	f	\N
214748	abiraha	abiraha =raha  (SgP  >abi+raha !17_S	et	f	\N
214807	maailmavaatest	maailmavaatest =ate  (PlEl  >maa+ilm+ava+att !22_S	et	f	\N
214808	maailmavaatest	maailmavaatest =vaate  (SgEl  >maa+ilma+vaade !06_S	et	f	\N
214809	maailmavaatest	maailmavaatest =vaates  (SgP  >maa+ilma+vaatene !12~10_A	et	f	\N
214810	maailmavaatest	"maa+ilma+vaatene %vaate  )NE_aA  <maa+ilma+vaade ;06_S	et	f	\N
214839	jutuvormi	jutuvormi =vormi  (SgG  >jutu+vorm !22_S	et	f	\N
214840	jutuvormi	jutuvormi =vormi  (SgP  >jutu+vorm !22_S	et	f	\N
214841	jutuvormi	jutuvormi =vormi  (SgAdt  >jutu+vorm !22_S	et	f	\N
214846	keef	?keef =keef  (SgN  >keef !22_S	et	f	\N
214849	wood	?wood =woo  (PlN  >woo !26_S	et	f	\N
214850	wood	?wood =woo  (SgP  >woo !26_S	et	f	\N
214851	wood	?wood =wood  (SgN  >wood !22_S	et	f	\N
214871	sündinüd	### sündinüd	et	f	\N
214872	hamilton	?hamilton =hamilton  (SgN  >hamilton !19_S	et	f	\N
214879	keskalinna	?keskalinna =keskalinna  (SgN  >keskalinna !16_S	et	f	\N
214880	keskalinna	?keskalinna =keskalinna  (SgG  >keskalinna !16_S	et	f	\N
214881	keskalinna	?keskalinna =alinna  (SgN  >kesk+alinna !16_S	et	f	\N
214882	keskalinna	?keskalinna =alinna  (SgG  >kesk+alinna !16_S	et	f	\N
214895	valiv	valiv =vali  (PtsPrPs  >valima !27_V	et	f	\N
214896	valiv	valiv =valiv  (SgN  >valiv !02_A	et	f	\N
214897	valiv	"valiv %vali  )V_vA  <valima ;27_V	et	f	\N
214947	prosess	?prosess =prosess  (SgN  >prosess !22_S	et	f	\N
214956	ahisse	?ahisse =ahisse  (SgG  >ahisne !02_A	et	f	\N
214957	ahisse	?ahisse =ahisse  (PlP  >ahiss !22_S	et	f	\N
214965	prosessi	?prosessi =prosessi  (SgN  >prosessi !01_S	et	f	\N
214966	prosessi	?prosessi =prosessi  (SgG  >prosessi !01_S	et	f	\N
214967	prosessi	?prosessi =prosessi  (SgG  >prosess !22_S	et	f	\N
214968	prosessi	?prosessi =prosessi  (SgP  >prosess !22_S	et	f	\N
214969	prosessi	?prosessi =prosessi  (SgAdt  >prosess !22_S	et	f	\N
214970	prosessi	?prosessi =prosessi  (IndPrPs_  >prosessima !28_V	et	f	\N
214971	prosessi	?prosessi =prosessi  (ImpPrSg2  >prosessima !28_V	et	f	\N
214992	asjalise	asjalise =asjalise  (SgG  >asjaline !12_SA	et	f	\N
214993	asjalise	"asjaline %asja  )LINE_aA  <asi ;24_S	et	f	\N
214994	kõikumatu	kõikumatu =kõikumatu  (SgN  >kõikumatu !01_A	et	f	\N
214995	kõikumatu	"kõikumatu %kõiku  )MATU_vA  <kõikuma ;28_V	et	f	\N
214996	kõikumatu	kõikumatu =kõikumatu  (SgG  >kõikumatu !01_A	et	f	\N
214999	sajama	?sajama =saja  (Sup  >sajama !27_V	et	f	\N
215000	sajama	?sajama =sajama  (SgG  >sajam !02_A	et	f	\N
215006	paikes	?paikes =paike  (SgIn  >paige !06_S	et	f	\N
215007	paikes	?paikes =paike  (IndIpfSg3  >paikema !27_V	et	f	\N
215008	paikes	?paikes =paikes  (SgN  >paikes !09_S	et	f	\N
215017	ragbi	ragbi =ragbi  (SgN  >ragbi !16_S	et	f	\N
215018	ragbi	ragbi =ragbi  (SgG  >ragbi !16_S	et	f	\N
215026	trofeed	trofeed =trofee  (PlN  >trofee !26_S	et	f	\N
215027	trofeed	trofeed =trofee  (SgP  >trofee !26_S	et	f	\N
215031	sõjamonumenti	sõjamonumenti =monumenti  (SgP  >sõja+monument !22_S	et	f	\N
215032	sõjamonumenti	sõjamonumenti =monumenti  (SgAdt  >sõja+monument !22_S	et	f	\N
215036	pronksöö	pronksöö =öö  (SgN  >pronks+öö !26_S	et	f	\N
215037	pronksöö	pronksöö =öö  (SgG  >pronks+öö !26_S	et	f	\N
215107	tapta	?tapta =tapta  (SgN  >tapta !16_S	et	f	\N
215108	tapta	?tapta =tapta  (SgG  >tapta !16_S	et	f	\N
215109	tapta	?tapta =tapta  (IndPrPs_  >taptama !29_V	et	f	\N
215111	tapta	?tapta =tapta  (ImpPrSg2  >taptama !29_V	et	f	\N
215141	varisemine	varisemine =varisemine  (SgN  >varisemine !12_S	et	f	\N
214696	tõusega	?tõusega =sega  (SgG  >tõu+sega !17_S	et	f	\N
214697	tõusega	?tõusega =sega  (SgP  >tõu+sega !17_S	et	f	\N
214701	eidata	?eidata =eida  (SgAb  >eida !16_S	et	f	\N
214702	eidata	?eidata =eidata  (IndPrPs_  >eidatama !27_V	et	f	\N
214703	eidata	?eidata =eidata  (ImpPrSg2  >eidatama !27_V	et	f	\N
214704	eidata	?eidata =data  (SgN  >ei+data !16_S	et	f	\N
214705	eidata	?eidata =data  (SgG  >ei+data !16_S	et	f	\N
214718	töötuse	töötuse =töötuse  (SgG  >töötus !11~09_S	et	f	\N
214719	töötuse	"töötus %tööta  )US_vS  <töötama ;27_V	et	f	\N
214720	töötuse	"töötus %töö  )TUS2_aS  <töö ;26_S	et	f	\N
214721	maakondi	maakondi =maakondi  (SgP  >maakond !22_S	et	f	\N
214722	maakondi	maakondi =maakondi  (SgAdt  >maakond !22_S	et	f	\N
214723	maakondi	maakondi =maakondi  (PlP  >maakond !22_S	et	f	\N
214724	maakondi	maakondi =kondi  (SgG  >maa+kont !22_S	et	f	\N
214727	müüri	müüri =müüri  (SgG  >müür !22_S	et	f	\N
214728	müüri	müüri =müüri  (SgP  >müür !22_S	et	f	\N
214729	müüri	müüri =müüri  (SgAdt  >müür !22_S	et	f	\N
214730	müüri	müüri =müüri  (IndPrPs_  >müürima !28_V	et	f	\N
214731	müüri	müüri =müüri  (ImpPrSg2  >müürima !28_V	et	f	\N
214737	tööhõivetalituste	tööhõivetalituste =tuste  (PlP  >töö+hõive+tali+tust !22_S	et	f	\N
214738	tööhõivetalituste	tööhõivetalituste =talitus  (PlG  >töö+hõive+talitus !11_S	et	f	\N
214739	tööhõivetalituste	"töö+hõive+talitus %tali  )TUS2_aS  <töö+hõive+tali ;17_S	et	f	\N
214749	hoojatöö	?hoojatöö =hoojatöö  (SgN  >hoojatöö !26_S	et	f	\N
214750	hoojatöö	?hoojatöö =hoojatöö  (SgG  >hoojatöö !26_S	et	f	\N
214751	hoojatöö	?hoojatöö =jatöö  (SgN  >hoo+jatöö !26_S	et	f	\N
214752	hoojatöö	?hoojatöö =jatöö  (SgG  >hoo+jatöö !26_S	et	f	\N
214755	kahanenud	kahanenud =kahane  (PtsPtPs  >kahanema !27_V	et	f	\N
214756	kahanenud	kahanenud =kahanenu  (PlN  >kahanenu !01_S	et	f	\N
214757	kahanenud	"kahanenu %kahane  )NU_vS  <kahanema ;27_V	et	f	\N
214758	kahanenud	kahanenud =kahanenud  (ID  >kahanenud !41_A	et	f	\N
214759	kahanenud	"kahanenud %kahane  )NUD_vA  <kahanema ;27_V	et	f	\N
214762	zhanrites	?zhanrites =zhanrite  (PlIn  >zhanritt !22_S	et	f	\N
214765	seostuv	seostuv =seostu  (PtsPrPs  >seostuma !27_V	et	f	\N
214766	seostuv	seostuv =seostuv  (SgN  >seostuv !02_A	et	f	\N
214767	seostuv	"seostuv %seostu  )V_vA  <seostuma ;27_V	et	f	\N
214770	vahetanutel	vahetanutel =vahetanu  (PlAd  >vahetanu !01_S	et	f	\N
214771	vahetanutel	"vahetanu %vaheta  )NU_vS  <vahetama ;27_V	et	f	\N
214777	käinudki	käinudki =käi  (PtsPtPs^  >käima !38_V	et	f	\N
214778	käinudki	käinudki =käinu  (PlN^  >käinu !01_S	et	f	\N
214779	käinudki	"käinu %käi  )NU_vS^  <käima ;38_V	et	f	\N
214780	käinudki	käinudki =käinu  (PlN^  >käinu !06_S	et	f	\N
214781	käinudki	käinudki =käinud  (ID^  >käinud !41_A	et	f	\N
214782	käinudki	"käinud %käi  )NUD_vA^  <käima ;38_V	et	f	\N
214783	paigutanud	paigutanud =paiguta  (PtsPtPs  >paigutama !27_V	et	f	\N
214784	paigutanud	paigutanud =paigutanu  (PlN  >paigutanu !01_S	et	f	\N
214785	paigutanud	"paigutanu %paiguta  )NU_vS  <paigutama ;27_V	et	f	\N
214786	paigutanud	paigutanud =paigutanud  (ID  >paigutanud !41_A	et	f	\N
214787	paigutanud	"paigutanud %paiguta  )NUD_vA  <paigutama ;27_V	et	f	\N
214796	looduslikust	looduslikust =loodusliku  (SgEl  >looduslik !25_A	et	f	\N
214797	looduslikust	looduslikust =looduslikus  (SgP  >looduslikus !11?09_S	et	f	\N
214798	looduslikust	"looduslikus %loodusliku  )US_aS  <looduslik ;25_A	et	f	\N
214805	kasutajate	kasutajate =kasutaja  (PlG  >kasutaja !01_S	et	f	\N
214806	kasutajate	"kasutaja %kasuta  )JA_vS  <kasutama ;27_V	et	f	\N
214820	siberieestlaste	siberieestlaste =las  (PlG  >siberi+eest+laps !14_S	et	f	\N
214822	siberieestlaste	siberieestlaste =laste  (PlP  >siberi+eest+last !22_S	et	f	\N
214825	siberieestlaste	siberieestlaste =eestlas  (PlG  >siberi+eestlane !12?10_S	et	f	\N
214829	rahvaetümoloogia	rahvaetümoloogia =etümoloogia  (SgN  >rahva+etümoloogia !01_S	et	f	\N
214830	rahvaetümoloogia	rahvaetümoloogia =etümoloogia  (SgG  >rahva+etümoloogia !01_S	et	f	\N
214837	asundustes	asundustes =asundus  (PlIn  >asundus !11_S	et	f	\N
214838	asundustes	"asundus %asunda  )US_vS  <asundama ;27_V	et	f	\N
214856	stones	?stones =stone  (SgIn  >stone !16_S	et	f	\N
214857	stones	?stones =stone  (IndIpfSg3  >stonema !27_V	et	f	\N
214859	stones	?stones =stones  (SgN  >stones !09_S	et	f	\N
214862	richards	?richards =richards  (SgN  >richards !22_S	et	f	\N
214875	tärvis	?tärvis =tärvi  (SgIn  >tärvi !16_S	et	f	\N
214876	tärvis	?tärvis =tärvi  (SgIn  >tärv !22_S	et	f	\N
214877	tärvis	?tärvis =tärvi  (IndIpfSg3  >tärvima !28_V	et	f	\N
214878	tärvis	?tärvis =tärvis  (SgN  >tärvis !09_S	et	f	\N
214901	ameerikast	?ameerikast =ameerika  (SgEl  >ameerikas !02_A	et	f	\N
214902	ameerikast	?ameerikast =ameerikas  (SgP  >ameerikane !12_A	et	f	\N
214906	bussijaamast	bussijaamast =jaama  (SgEl  >bussi+jaam !22_S	et	f	\N
214907	bussijaamast	bussijaamast =jaamas  (SgP  >bussi+jaamane !10_A	et	f	\N
214908	bussijaamast	"bussi+jaamane %jaama  )NE_aA  <bussi+jaam ;22_S	et	f	\N
214909	28-aastaseks	-aastaseks =aastase  (SgTr  >-aastane !12~10_A	et	f	\N
214910	28-aastaseks	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
214733	ladumine	"ladumine %ladu  )MINE_vS  <laduma ;28_V	et	f	\N
214734	ladumine	"ladumine %ladumi  )NE_aA  <ladum ;02_S	et	f	\N
214735	alalist	alalist =alalis  (SgP  >alaline !12_A	et	f	\N
214736	alalist	"alaline %ala  )LINE_aA  <ala ;17_S	et	f	\N
214740	tööturameti	?tööturameti =tööturameti  (SgG  >tööturamett !22_S	et	f	\N
214741	tööturameti	?tööturameti =tööturameti  (IndPrPs_  >tööturamettima !28_V	et	f	\N
214742	tööturameti	?tööturameti =tööturameti  (ImpPrSg2  >tööturamettima !28_V	et	f	\N
214743	tööturameti	?tööturameti =rameti  (SgG  >töötu+ramett !22_S	et	f	\N
214744	tööturameti	?tööturameti =turameti  (SgG  >töö+turamett !22_S	et	f	\N
214760	rände	rände =rände  (SgG  >ränne !06_S	et	f	\N
214761	rände	rände =rände  (PlP  >ränd !22_S	et	f	\N
214763	konkreetsust	konkreetsust =konkreetsus  (SgP  >konkreetsus !11~09_S	et	f	\N
214764	konkreetsust	"konkreetsus %konkreetse  )US_aS  <konkreetne ;02_A	et	f	\N
214835	külanime	külanime =nime  (SgG  >küla+nimi !20_S	et	f	\N
214836	külanime	külanime =nime  (SgP  >küla+nimi !20_S	et	f	\N
214844	ronnie	?ronnie =ronnie  (SgN  >ronnie !01_S	et	f	\N
214845	ronnie	?ronnie =ronnie  (SgG  >ronnie !01_S	et	f	\N
214858	rolling	?rolling =rolling  (SgN  >rolling !02_S	et	f	\N
214860	rolling	?rolling =ing  (SgN  >roll+ing !22_S	et	f	\N
214867	teges	?teges =tege  (SgIn  >tege !16_S	et	f	\N
214868	teges	?teges =teges  (SgN  >teges !09_S	et	f	\N
214885	paisleys	?paisleys =paisleys  (SgN  >paisleys !22_S	et	f	\N
214886	paisleys	?paisleys =sleys  (SgN  >pai+sleys !22_S	et	f	\N
214887	keskalinasse	?keskalinasse =keskalina  (SgIll  >keskalin !19_S	et	f	\N
214888	keskalinasse	?keskalinasse =keskalinas  (SgAdt  >keskalinane !12_A	et	f	\N
214889	keskalinasse	?keskalinasse =keskalinasse  (SgG  >keskalinasne !02_A	et	f	\N
214890	keskalinasse	?keskalinasse =keskalinasse  (PlP  >keskalinass !22_S	et	f	\N
214891	keskalinasse	?keskalinasse =alina  (SgIll  >kesk+alin !02_S	et	f	\N
214892	keskalinasse	?keskalinasse =alinas  (SgAdt  >kesk+alinane !12_A	et	f	\N
214893	keskalinasse	?keskalinasse =alinasse  (SgG  >kesk+alinasne !02_A	et	f	\N
214894	keskalinasse	?keskalinasse =alinasse  (PlP  >kesk+alinass !22_S	et	f	\N
214898	jooksi	jooksi =jooksi  (SgG  >jooks !22_S	et	f	\N
214899	jooksi	jooksi =jooksi  (SgP  >jooks !22_S	et	f	\N
214900	jooksi	jooksi =jooksi  (SgAdt  >jooks !22_S	et	f	\N
214916	edinburgi	?edinburgi =edinburgi  (SgG  >edinburk !22_S	et	f	\N
214917	edinburgi	?edinburgi =edinburgi  (SgP  >edinburg !22_S	et	f	\N
214918	edinburgi	?edinburgi =edinburgi  (SgAdt  >edinburg !22_S	et	f	\N
214919	edinburgi	?edinburgi =edinburgi  (IndPrPs_  >edinburkima !28_V	et	f	\N
214920	edinburgi	?edinburgi =edinburgi  (ImpPrSg2  >edinburkima !28_V	et	f	\N
214921	edinburgi	?edinburgi =edinbur  (SgN^  >edinbur !19_S	et	f	\N
214934	keraamikaklubi	### keraamikaklubi	et	f	\N
214943	elektrilise	elektrilise =elektrilise  (SgG  >elektriline !12_A	et	f	\N
214944	elektrilise	"elektriline %elektri  )LINE_aA  <elekter ;02_S	et	f	\N
214960	põletamise	põletamise =põletamise  (SgG  >põletamine !12_S	et	f	\N
214961	põletamise	"põletamine %põleta  )MINE_vS  <põletama ;27_V	et	f	\N
214972	klaasiminen	?klaasiminen =klaasiminen  (SgN  >klaasiminen !19_S	et	f	\N
214973	klaasiminen	?klaasiminen =minen  (SgN  >klaasi+minen !02_S	et	f	\N
214974	klaasiminen	?klaasiminen =iminen  (SgN  >klaas+iminen !19_S	et	f	\N
214982	issand	issand =issand  (ID  >issand !41_I	et	f	\N
214983	issand	issand =issand  (SgN  >issand !02_S	et	f	\N
214986	varal	varal =vara  (SgAd  >vara !17_S	et	f	\N
214987	varal	varal =varal  (ID  >varal !41_K	et	f	\N
215009	londonist	?londonist =londoni  (SgEl  >london !02_S	et	f	\N
215010	londonist	?londonist =londonis  (SgP  >londonis !11_S	et	f	\N
215011	londonist	?londonist =londonist  (SgN  >londonist !22_S	et	f	\N
215012	fransiscosse	?fransiscosse =fransisco  (SgIll  >fransisco !16_S	et	f	\N
215013	fransiscosse	?fransiscosse =fransiscosse  (SgG  >fransiscosne !02_A	et	f	\N
215014	fransiscosse	?fransiscosse =fransiscosse  (PlP  >fransiscoss !22_S	et	f	\N
215020	ragbimeeskonnas	?ragbimeeskonnas =ragbimeeskonna  (SgIn  >ragbimeeskonna !16_S	et	f	\N
215021	ragbimeeskonnas	?ragbimeeskonnas =ragbimeeskonna  (SgIn  >ragbimeeskond !22_S	et	f	\N
215038	erigeeruti	?erigeeruti =erigeeru  (IndIpfIps  >erigeeruma !27_V	et	f	\N
215039	erigeeruti	?erigeeruti =erigeeruti  (SgG  >erigeerutt !22_S	et	f	\N
215040	erigeeruti	?erigeeruti =erigeeruti  (IndPrPs_  >erigeeruttima !28_V	et	f	\N
215041	erigeeruti	?erigeeruti =erigeeruti  (ImpPrSg2  >erigeeruttima !28_V	et	f	\N
215042	erigeeruti	?erigeeruti =geeruti  (SgN  >eri+geeruti !01_S	et	f	\N
215043	erigeeruti	?erigeeruti =geeruti  (SgG  >eri+geeruti !01_S	et	f	\N
215044	erigeeruti	?erigeeruti =geeruti  (SgG  >eri+geerut !02_S	et	f	\N
215045	erigeeruti	?erigeeruti =geeruti  (SgG  >eri+geerutt !22_S	et	f	\N
215048	uskub	### uskub	et	f	\N
215061	kesklinnast	kesklinnast =ast  (SgN  >kesk+linn+ast !22_S	et	f	\N
215062	kesklinnast	kesklinnast =linna  (SgEl  >kesk+linn !22_S	et	f	\N
215063	kesklinnast	kesklinnast =linnas  (SgP  >kesk+linnas !09_S	et	f	\N
215064	kesklinnast	kesklinnast =linnas  (SgP  >kesk+linnane !10_A	et	f	\N
215065	kesklinnast	"kesk+linnane %linna  )NE_aA  <kesk+linn ;22_S	et	f	\N
214911	28-aastaseks	-aastaseks =seks  (SgN  >-aasta+seks !22_S	et	f	\N
214926	armased	?armased =armase  (PlN  >armane !10_A	et	f	\N
214931	loomaarsti	loomaarsti =arsti  (SgG  >looma+arst !22_S	et	f	\N
214932	loomaarsti	loomaarsti =arsti  (SgP  >looma+arst !22_S	et	f	\N
214933	loomaarsti	loomaarsti =arsti  (SgAdt  >looma+arst !22_S	et	f	\N
214948	kujundakse	?kujundakse =kujundakse  (SgG  >kujundakne !02_A	et	f	\N
214950	tulikuumasse	tulikuumasse =asse  (PlP  >tuli+kuum+ass !22_S	et	f	\N
214952	tulikuumasse	tulikuumasse =masse  (PlP  >tuli+kuu+mass !22_S	et	f	\N
214953	tulikuumasse	tulikuumasse =kuuma  (SgIll  >tuli+kuum !22_AS	et	f	\N
214977	kirsi	kirsi =kirs  (PlP  >kirs !14_S	et	f	\N
214978	kirsi	kirsi =kirsi  (SgG  >kirss !22_S	et	f	\N
214988	kleiti	kleiti =kleiti  (SgP  >kleit !22_S	et	f	\N
214989	kleiti	kleiti =kleiti  (SgAdt  >kleit !22_S	et	f	\N
215001	oavarrest	oavarrest =varre  (SgEl  >oa+vars !14_S	et	f	\N
215002	oavarrest	oavarrest =varre  (PlEl  >oa+varr !22_S	et	f	\N
215003	oavarrest	oavarrest =varres  (SgP  >oa+varrene !10_A	et	f	\N
215004	oavarrest	"oa+varrene %varre  )NE_aA  <oa+vars ;14_S	et	f	\N
215005	sais	?sais =sais  (SgN  >sais !22_S	et	f	\N
215022	peaksite	peaksite =pea  (KndPrPl2  >pida !40_V	et	f	\N
215023	peaksite	peaksite =pea  (KndPrPl2  >pidama !28_V	et	f	\N
215033	monumenti	monumenti =monumenti  (SgP  >monument !22_S	et	f	\N
215034	monumenti	monumenti =monumenti  (SgAdt  >monument !22_S	et	f	\N
215035	monumentil	?monumentil =monumentil  (SgN  >monumentil !02_S	et	f	\N
215054	kasatati	?kasatati =kasata  (IndIpfIps  >kasatama !27_V	et	f	\N
215055	kasatati	?kasatati =kasatati  (SgG  >kasatatt !22_S	et	f	\N
215056	kasatati	?kasatati =kasatati  (IndPrPs_  >kasatattima !28_V	et	f	\N
215057	kasatati	?kasatati =kasatati  (ImpPrSg2  >kasatattima !28_V	et	f	\N
215058	kasatati	?kasatati =atati  (SgG  >kas+atat !02_S	et	f	\N
215059	kasatati	?kasatati =atati  (SgG  >kas+atatt !22_S	et	f	\N
215068	jõudiga	?jõudiga =jõudi  (SgKom  >jõudi !16_S	et	f	\N
215069	jõudiga	?jõudiga =jõudi  (SgKom  >jõut !22_S	et	f	\N
215070	jõudiga	?jõudiga =diga  (SgN  >jõu+diga !17_S	et	f	\N
215071	jõudiga	?jõudiga =diga  (SgG  >jõu+diga !17_S	et	f	\N
215072	jõudiga	?jõudiga =diga  (SgP  >jõu+diga !17_S	et	f	\N
215090	juhtema	juhtema =ema  (SgN  >juht+ema !17_S	et	f	\N
215091	juhtema	juhtema =ema  (SgG  >juht+ema !17_S	et	f	\N
215092	juhtema	juhtema =ema  (SgP  >juht+ema !17_S	et	f	\N
215125	poe	poe =poe  (SgG  >pood !22_S	et	f	\N
215126	poe	poe =poe  (IndPrPs_  >pugema !28_V	et	f	\N
215127	poe	poe =poe  (ImpPrSg2  >pugema !28_V	et	f	\N
215156	müüjanana	?müüjanana =nana  (SgN  >müüja+nana !17_S	et	f	\N
215157	müüjanana	?müüjanana =nana  (SgG  >müüja+nana !17_S	et	f	\N
215158	müüjanana	?müüjanana =nana  (SgP  >müüja+nana !17_S	et	f	\N
215182	rassisti	rassisti =rassisti  (SgG  >rassist !22_S	et	f	\N
215183	rassisti	rassisti =rassisti  (SgP  >rassist !22_S	et	f	\N
215184	rassisti	rassisti =rassisti  (SgAdt  >rassist !22_S	et	f	\N
215206	kedas	?kedas =keda  (SgIn  >keda !17_S	et	f	\N
215207	kedas	?kedas =keda  (IndIpfSg3  >kedama !27_V	et	f	\N
215208	kedas	?kedas =kedas  (SgN  >kedas !07_S	et	f	\N
215220	enimesid	### enimesid	et	f	\N
215244	iraanist	?iraanist =iraani  (SgEl  >iraani !16_S	et	f	\N
215245	iraanist	?iraanist =iraani  (SgEl  >iraan !22_S	et	f	\N
215246	iraanist	?iraanist =iraanis  (SgP  >iraanis !09_S	et	f	\N
215266	suuski	suuski =suuski  (SgG  >suusk !22_S	et	f	\N
215267	suuski	suuski =suuski  (SgP  >suusk !22_S	et	f	\N
215268	suuski	suuski =suuski  (SgAdt  >suusk !22_S	et	f	\N
215269	suuski	suuski =suuski  (PlP  >suusk !22_S	et	f	\N
215270	suuski	suuski =suu  (SgIn^  >suu !26_S	et	f	\N
215298	pesuma	?pesuma =pesu  (Sup  >pesuma !27_V	et	f	\N
215320	animafilmi	animafilmi =filmi  (SgG  >anima+film !22_S	et	f	\N
215321	animafilmi	animafilmi =filmi  (SgP  >anima+film !22_S	et	f	\N
215322	animafilmi	animafilmi =filmi  (SgAdt  >anima+film !22_S	et	f	\N
215327	kuulasis	?kuulasis =kuulasi  (PlIn  >kuulane !12_S	et	f	\N
215328	kuulasis	?kuulasis =kuulasis  (SgN  >kuulasis !11_S	et	f	\N
215329	kuulasis	?kuulasis =asis  (SgN  >kuul+asis !09_S	et	f	\N
215347	hiljam	?hiljam =hiljam  (SgN  >hiljam !02_A	et	f	\N
215351	lõe	?lõe =lõe  (SgN  >lõe !26_S	et	f	\N
215352	lõe	?lõe =lõe  (SgG  >lõe !26_S	et	f	\N
215367	pidani	?pidani =pida  (SgTer  >pida !17_S	et	f	\N
215368	pidani	?pidani =pidani  (SgG  >pidan !02_S	et	f	\N
215383	öpima	?öpima =öpi  (Sup  >öpima !27_V	et	f	\N
215384	öpima	?öpima =öpima  (SgG  >öpim !02_A	et	f	\N
215385	rigalt	?rigalt =riga  (SgAbl  >riga !17_S	et	f	\N
215386	rigalt	?rigalt =rigalt  (ID  >rigalt !41_D	et	f	\N
215399	15-aastane	-aastane =aastane  (SgN  >-aastane !12~10_A	et	f	\N
215400	15-aastane	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
215403	näitada	?näitada =ada  (SgN  >näit+ada !17_S	et	f	\N
215404	näitada	?näitada =ada  (SgG  >näit+ada !17_S	et	f	\N
215405	näitada	?näitada =ada  (SgP  >näit+ada !17_S	et	f	\N
215406	mangisin	?mangisin =mangi  (IndIpfSg1  >mangima !28_V	et	f	\N
215407	mangisin	?mangisin =mangisin  (SgN  >mangisin !19_S	et	f	\N
214942	käsiga	### käsiga	et	f	\N
214945	lillepotid	lillepotid =poti  (PlN  >lille+poti !16_S	et	f	\N
214946	lillepotid	lillepotid =poti  (PlN  >lille+pott !22_S	et	f	\N
214954	kuivat	?kuivat =kuiva  (SgP  >kuiva !16_S	et	f	\N
214955	kuivat	?kuivat =kuivat  (SgN  >kuivat !02_S	et	f	\N
214975	kestava	kestava =kestava  (SgG  >kestav !02_A	et	f	\N
214976	kestava	"kestav %kesta  )V_vA  <kestama ;29_V	et	f	\N
214979	representiivsegina	?representiivsegina =representiivsegina  (SgG  >representiivsegin !19_S	et	f	\N
214980	representiivsegina	?representiivsegina =representiivsegina  (SgP  >representiivsegin !19_S	et	f	\N
214981	representiivsegina	?representiivsegina =representiivsegina  (SgAdt  >representiivsegin !19_S	et	f	\N
214984	andekast	andekast =andeka  (SgEl  >andekas !02_A	et	f	\N
214985	andekast	andekast =kast  (SgN  >ande+kast !22_S	et	f	\N
214990	sobitin	?sobitin =sobiti  (IndPrSg1  >sobittima !28_V	et	f	\N
214991	sobitin	?sobitin =sobitin  (SgN  >sobitin !19_S	et	f	\N
215019	ragbiklube	### ragbiklube	et	f	\N
215024	mängijad	mängijad =mängija  (PlN  >mängija !01_S	et	f	\N
215025	mängijad	"mängija %mängi  )JA_vS  <mängima ;28_V	et	f	\N
215028	aafrika	?aafrika =aafrika  (SgN  >aafrika !01_S	et	f	\N
215029	aafrika	?aafrika =aafrika  (SgG  >aafrika !01_S	et	f	\N
215030	aafrika	?aafrika =aafrika  (SgG  >aafrikas !02_S	et	f	\N
215046	sõdure	### sõdure	et	f	\N
215047	ründati	?ründati =ründa  (IndIpfIps  >rüntama !29_V	et	f	\N
215049	ründati	?ründati =ründati  (ID  >ründati !41_D	et	f	\N
215050	ründati	?ründati =ründati  (SgG  >ründat !02_S	et	f	\N
215051	ründati	?ründati =ründati  (SgG  >ründatt !22_S	et	f	\N
215052	ründati	?ründati =ründati  (IndPrPs_  >ründattima !28_V	et	f	\N
215053	ründati	?ründati =ründati  (ImpPrSg2  >ründattima !28_V	et	f	\N
215060	aprilil	### aprilil	et	f	\N
215087	pruuned	?pruuned =pruune  (IndPrSg2  >pruunema !27_V	et	f	\N
215093	põdri	?põdri =põdri  (SgN  >põdri !16_S	et	f	\N
215094	põdri	?põdri =põdri  (SgG  >põdri !16_S	et	f	\N
215095	põdri	?põdri =põdri  (SgP  >põdr !22_S	et	f	\N
215096	põdri	?põdri =põdri  (SgAdt  >põdr !22_S	et	f	\N
215097	põdri	?põdri =põdri  (IndPrPs_  >põdrima !27_V	et	f	\N
215098	põdri	?põdri =põdri  (IndPrPs_  >põtrima !28_V	et	f	\N
215099	põdri	?põdri =põdri  (ImpPrSg2  >põdrima !27_V	et	f	\N
215100	põdri	?põdri =põdri  (ImpPrSg2  >põtrima !28_V	et	f	\N
215102	pruunsed	?pruunsed =pruunse  (PlN  >pruunne !02_A	et	f	\N
215103	pruunsed	?pruunsed =pruunse  (PlN  >pruunse !06_S	et	f	\N
215104	pruunsed	?pruunsed =pruunse  (IndPrSg2  >pruunsema !27_V	et	f	\N
215122	kostüümi	kostüümi =kostüümi  (SgG  >kostüüm !22_S	et	f	\N
215123	kostüümi	kostüümi =kostüümi  (SgP  >kostüüm !22_S	et	f	\N
215124	kostüümi	kostüümi =kostüümi  (SgAdt  >kostüüm !22_S	et	f	\N
215150	poissimeesteõhtul	?poissimeesteõhtul =poissimeesteõhtul  (SgN  >poissimeesteõhtul !02_S	et	f	\N
215151	poissimeesteõhtul	?poissimeesteõhtul =esteõhtu  (SgAd  >poiss+ime+esteõhtu !01_S	et	f	\N
215152	poissimeesteõhtul	?poissimeesteõhtul =imeesteõhtul  (SgN  >poiss+imeesteõhtul !02_S	et	f	\N
215197	loosunge	?loosunge =sunge  (SgN  >loo+sunge !06_S	et	f	\N
215198	loosunge	?loosunge =sunge  (PlP  >loo+sung !22_S	et	f	\N
215209	raamaturiul	?raamaturiul =raamaturiu  (SgAd  >raamaturiu !01_S	et	f	\N
215210	raamaturiul	?raamaturiul =raamaturiul  (SgN  >raamaturiul !19_S	et	f	\N
215211	raamaturiul	?raamaturiul =riu  (SgAd  >raamatu+riu !26_S	et	f	\N
215212	raamaturiul	?raamaturiul =riul  (SgN  >raamatu+riul !22_S	et	f	\N
215213	raamaturiul	?raamaturiul =aturiu  (SgAd  >raam+aturiu !01_S	et	f	\N
215214	raamaturiul	?raamaturiul =aturiul  (SgN  >raam+aturiul !19_S	et	f	\N
215226	paneda	### paneda	et	f	\N
215247	udmurtimaal	?udmurtimaal =udmurtimaa  (SgAd  >udmurtimaa !26_S	et	f	\N
215248	udmurtimaal	?udmurtimaal =udmurtimaal  (SgN  >udmurtimaal !22_S	et	f	\N
215254	rokk-gruppegagi	?rokk-gruppegagi =gruppe  (SgKom^  >rokk-grupe !06_S	et	f	\N
215280	päivi	?päivi =päivi  (SgN  >päivi !16_S	et	f	\N
215281	päivi	?päivi =päivi  (SgG  >päivi !16_S	et	f	\N
215282	päivi	?päivi =päivi  (SgG  >päiv !22_S	et	f	\N
215283	päivi	?päivi =päivi  (SgP  >päiv !22_S	et	f	\N
215284	päivi	?päivi =päivi  (SgAdt  >päiv !22_S	et	f	\N
215285	päivi	?päivi =päivi  (IndPrPs_  >päivima !28_V	et	f	\N
215286	päivi	?päivi =päivi  (ImpPrSg2  >päivima !28_V	et	f	\N
215287	muutan	?muutan =muuta  (IndPrSg1  >muutama !27_V	et	f	\N
215288	muutan	?muutan =muutan  (SgN  >muutan !02_S	et	f	\N
215302	e-kirju	e-kirju =kirju  (SgN  >e-kirju !01_A	et	f	\N
215303	e-kirju	e-kirju =kirju  (SgN  >e-kirju !16_A	et	f	\N
215304	e-kirju	e-kirju =kirju  (SgG  >e-kirju !01_A	et	f	\N
215305	e-kirju	e-kirju =kirju  (SgG  >e-kirju !16_A	et	f	\N
215306	e-kirju	e-kirju =kirju  (PlP  >e-kiri !24_S	et	f	\N
215307	avasis	?avasis =avasis  (SgN  >avasis !11_S	et	f	\N
215310	astusis	?astusis =astusi  (PlIn  >astus !11_S	et	f	\N
215311	astusis	?astusis =astusis  (SgN  >astusis !11_S	et	f	\N
215323	pärnast	pärnast =pärna  (SgEl  >pärn !22_S	et	f	\N
215324	pärnast	pärnast =pärnas  (SgP  >pärnane !10_A	et	f	\N
215325	pärnast	"pärnane %pärna  )NE_aA  <pärn ;22_S	et	f	\N
214997	pilvesse	pilvesse =pilve  (SgIll  >pilv !22_S	et	f	\N
214998	pilvesse	pilvesse =pilve  (PlIll  >pilv !22_S	et	f	\N
215015	ragbi	ragbi =ragbi  (SgN  >ragbi !16_S	et	f	\N
215016	ragbi	ragbi =ragbi  (SgG  >ragbi !16_S	et	f	\N
215066	märatsejaid	märatsejaid =märatseja  (PlP  >märatseja !01_S	et	f	\N
215067	märatsejaid	"märatseja %märatse  )JA_vS  <märatsema ;27_V	et	f	\N
215080	ganin	?ganin =gani  (IndPrSg1  >ganima !27_V	et	f	\N
215081	ganin	?ganin =ganin  (SgN  >ganin !02_S	et	f	\N
215085	ajaloo-küsimus	ajaloo-küsimus =küsimus  (SgN  >ajaloo-küsimus !11_S	et	f	\N
215086	ajaloo-küsimus	"ajaloo-küsimus %küsi  )MUS_vS  <ajaloo-küsima ;27_V	et	f	\N
215101	jänsed	?jänsed =jänse  (IndPrSg2  >jänsema !27_V	et	f	\N
215128	moodsi	?moodsi =moodsi  (ID  >moodsi !41_D	et	f	\N
215129	moodsi	?moodsi =moodsi  (SgG  >moods !22_S	et	f	\N
215130	moodsi	?moodsi =moodsi  (SgP  >moods !22_S	et	f	\N
215131	moodsi	?moodsi =moodsi  (SgAdt  >moods !22_S	et	f	\N
215132	moodsi	?moodsi =moodsi  (IndPrPs_  >moodsima !28_V	et	f	\N
215133	moodsi	?moodsi =moodsi  (ImpPrSg2  >moodsima !28_V	et	f	\N
215135	okei	?okei =okei  (ID  >okei !41_DI	et	f	\N
215139	sadata	?sadata =sadata  (IndPrPs_  >sadatama !27_V	et	f	\N
215140	sadata	?sadata =sadata  (ImpPrSg2  >sadatama !27_V	et	f	\N
215162	poissimeesteid	?poissimeesteid =poissimeestei  (PlN  >poissimeestei !26_S	et	f	\N
215163	poissimeesteid	?poissimeesteid =poissimeestei  (SgP  >poissimeestei !26_S	et	f	\N
215164	poissimeesteid	?poissimeesteid =este  (PlP  >poiss+ime+este !06_S	et	f	\N
215165	poissimeesteid	?poissimeesteid =estei  (PlN  >poiss+ime+estei !26_S	et	f	\N
215166	poissimeesteid	?poissimeesteid =estei  (SgP  >poiss+ime+estei !26_S	et	f	\N
215167	poissimeesteid	?poissimeesteid =esteid  (SgN  >poiss+ime+esteid !22_S	et	f	\N
215168	poissimeesteid	?poissimeesteid =imeestei  (PlN  >poiss+imeestei !26_S	et	f	\N
215169	poissimeesteid	?poissimeesteid =imeestei  (SgP  >poiss+imeestei !26_S	et	f	\N
215170	sättiks	### sättiks	et	f	\N
215175	teekslevad	?teekslevad =teeksle  (IndPrPl3  >teekslema !30_V	et	f	\N
215176	teekslevad	?teekslevad =teeksleva  (PlN  >teeksleva !01_S	et	f	\N
215177	teekslevad	?teekslevad =teeksleva  (PlN  >teekslev !02_A	et	f	\N
215218	külgal	?külgal =külga  (SgAd  >külga !16_S	et	f	\N
215219	külgal	?külgal =külgal  (SgN  >külgal !02_S	et	f	\N
215251	udmurtis	?udmurtis =udmurti  (SgIn  >udmurti !01_S	et	f	\N
215252	udmurtis	?udmurtis =udmurti  (IndIpfSg3  >udmurtima !28_V	et	f	\N
215253	udmurtis	?udmurtis =udmurtis  (SgN  >udmurtis !11_S	et	f	\N
215258	halid	?halid =hali  (IndPrSg2  >halima !27_V	et	f	\N
215261	ujuvad	ujuvad =uju  (IndPrPl3  >ujuma !27_V	et	f	\N
215262	ujuvad	ujuvad =ujuva  (PlN  >ujuv !02_A	et	f	\N
215263	ujuvad	"ujuv %uju  )V_vA  <ujuma ;27_V	et	f	\N
215278	suvelisi	suvelisi =suvelisi  (PlP  >suveline !12_A	et	f	\N
215279	suvelisi	"suveline %suve  )LINE_aA  <suvi ;20_S	et	f	\N
215291	tervel	tervel =terve  (SgAd  >terve !01_AS	et	f	\N
215292	tervel	tervel =terve  (SgAd  >terve !06_AS	et	f	\N
215294	kuudeks	kuudeks =kuu  (PlTr  >kuu !26_S	et	f	\N
215295	kuudeks	kuudeks =kuude  (PlTr  >kuut !22_S	et	f	\N
215296	korristama	?korristama =korrista  (Sup  >korristama !27_V	et	f	\N
215297	korristama	?korristama =korristama  (SgG  >korristam !02_A	et	f	\N
215299	ärkasis	?ärkasis =ärkasi  (PlIn  >ärkane !12_A	et	f	\N
215300	ärkasis	?ärkasis =ärkasis  (SgN  >ärkasis !11_S	et	f	\N
215313	helistasis	?helistasis =helistasi  (PlIn  >helistane !12_A	et	f	\N
215314	helistasis	?helistasis =helistasis  (SgN  >helistasis !09_S	et	f	\N
215315	helistasis	?helistasis =stasi  (SgIn  >heli+stasi !17_S	et	f	\N
215316	helistasis	?helistasis =stasis  (SgN  >heli+stasis !09_S	et	f	\N
215317	vaatasis	?vaatasis =vaatasi  (PlIn  >vaatane !12_A	et	f	\N
215318	vaatasis	?vaatasis =vaatasis  (SgN  >vaatasis !11_S	et	f	\N
215330	töötasis	?töötasis =töötasi  (PlIn  >töötane !12_A	et	f	\N
215331	töötasis	?töötasis =töötasis  (SgN  >töötasis !11_S	et	f	\N
215332	töötasis	?töötasis =tasi  (SgIn  >töö+tasi !17_S	et	f	\N
215333	töötasis	?töötasis =tasis  (SgN  >töö+tasis !09_S	et	f	\N
215334	jutustasis	?jutustasis =jutustasi  (PlIn  >jutustane !12_A	et	f	\N
215335	jutustasis	?jutustasis =jutustasis  (SgN  >jutustasis !09_S	et	f	\N
215336	jutustasis	?jutustasis =stasi  (SgIn  >jutu+stasi !17_S	et	f	\N
215337	jutustasis	?jutustasis =stasis  (SgN  >jutu+stasis !09_S	et	f	\N
215338	testi	testi =testi  (SgG  >test !22_S	et	f	\N
215339	testi	testi =testi  (SgP  >test !22_S	et	f	\N
215340	testi	testi =testi  (SgAdt  >test !22_S	et	f	\N
215341	testi	testi =testi  (IndPrPs_  >testima !28_V	et	f	\N
215342	testi	testi =testi  (ImpPrSg2  >testima !28_V	et	f	\N
215348	õpetaga	### õpetaga	et	f	\N
215355	jõisid	?jõisid =jõi  (PlP  >jõi !26_S	et	f	\N
215356	jõisid	?jõisid =jõisi  (PlN  >jõisi !16_S	et	f	\N
215357	jõisid	?jõisid =jõisi  (PlN  >jõis !22_S	et	f	\N
215358	jõisid	?jõisid =jõisi  (IndPrSg2  >jõisima !28_V	et	f	\N
215369	läisk	?läisk =läisk  (SgN  >läisk !22_S	et	f	\N
215370	tees	tees =tee  (SgIn  >tee !26_S	et	f	\N
215371	tees	tees =tees  (SgN  >tees !22_S	et	f	\N
215073	tapati	?tapati =tapa  (IndIpfIps  >tapama !27_V	et	f	\N
215074	tapati	?tapati =tapa  (IndIpfIps  >tappama !29_V	et	f	\N
215075	tapati	?tapati =tapati  (ID  >tapati !41_D	et	f	\N
215076	tapati	?tapati =tapati  (SgG  >tapat !02_S	et	f	\N
215077	tapati	?tapati =tapati  (SgG  >tapatt !22_S	et	f	\N
215078	tapati	?tapati =tapati  (IndPrPs_  >tapattima !28_V	et	f	\N
215079	tapati	?tapati =tapati  (ImpPrSg2  >tapattima !28_V	et	f	\N
215082	suris	?suris =suri  (SgIn  >suri !17_S	et	f	\N
215083	suris	?suris =suri  (IndIpfSg3  >surima !27_V	et	f	\N
215084	suris	?suris =suris  (SgN  >suris !09_S	et	f	\N
215088	sarvad	?sarvad =sarva  (PlN  >sarva !16_S	et	f	\N
215089	sarvad	?sarvad =sarva  (IndPrSg2  >sarvama !29_V	et	f	\N
215105	kardetavad	kardetavad =kardetava  (PlN  >kardetav !02_A	et	f	\N
215106	kardetavad	"kardetav %karde  )TAV_vAS  <kartma ;34_V	et	f	\N
215110	inimesti	?inimesti =inimesti  (ID  >inimesti !41_D	et	f	\N
215112	inimesti	?inimesti =inimesti  (IndPrPs_  >inimestima !28_V	et	f	\N
215113	inimesti	?inimesti =inimesti  (ImpPrSg2  >inimestima !28_V	et	f	\N
215114	inimesti	?inimesti =esti  (SgN  >inim+esti !16_S	et	f	\N
215115	inimesti	?inimesti =esti  (SgG  >inim+esti !16_S	et	f	\N
215116	inimesti	?inimesti =esti  (SgG  >inim+est !22_S	et	f	\N
215117	inimesti	?inimesti =esti  (SgP  >inim+est !22_S	et	f	\N
215118	inimesti	?inimesti =esti  (SgAdt  >inim+est !22_S	et	f	\N
215119	metsikad	?metsikad =metsika  (PlN  >metsika !01_S	et	f	\N
215120	metsikad	?metsikad =metsika  (PlN  >metsikas !02_S	et	f	\N
215121	metsikad	?metsikad =ika  (PlN  >mets+ika !16_S	et	f	\N
215134	kallisam	?kallisam =kallisam  (SgN  >kallisam !02_A	et	f	\N
215136	kostüümist	kostüümist =kostüümi  (SgEl  >kostüüm !22_S	et	f	\N
215137	kostüümist	kostüümist =kostüümis  (SgP  >kostüümine !10_A	et	f	\N
215138	kostüümist	"kostüümine %kostüümi  )NE_aA  <kostüüm ;22_S	et	f	\N
215143	poissimeestest	?poissimeestest =poissimeestes  (SgP  >poissimeestene !12~10_A	et	f	\N
215144	poissimeestest	?poissimeestest =este  (SgEl  >poiss+ime+este !06_S	et	f	\N
215145	poissimeestest	?poissimeestest =este  (PlEl  >poiss+ime+est !22_S	et	f	\N
215146	poissimeestest	?poissimeestest =estes  (SgP  >poiss+ime+estes !09_S	et	f	\N
215147	poissimeestest	?poissimeestest =estes  (SgP  >poiss+ime+estene !12~10_A	et	f	\N
215148	poissimeestest	?poissimeestest =imees  (PlEl  >poiss+imeene !12~10_A	et	f	\N
215149	poissimeestest	?poissimeestest =imeestes  (SgP  >poiss+imeestene !12~10_A	et	f	\N
215159	brite	?brite =brite  (SgN  >brite !06_S	et	f	\N
215160	brite	?brite =brite  (IndPrPs_  >britema !27_V	et	f	\N
215161	brite	?brite =brite  (ImpPrSg2  >britema !27_V	et	f	\N
215174	poissimehed	### poissimehed	et	f	\N
215178	publica	?publica =publica  (SgN  >publica !01_S	et	f	\N
215179	publica	?publica =publica  (SgG  >publica !01_S	et	f	\N
215185	protestivad	protestivad =protesti  (IndPrPl3  >protestima !28_V	et	f	\N
215186	protestivad	protestivad =protestiva  (PlN  >protestiv !02_A	et	f	\N
215187	protestivad	"protestiv %protesti  )V_vA  <protestima ;28_V	et	f	\N
215188	meesti	?meesti =meesti  (ID  >meesti !41_D	et	f	\N
215189	meesti	?meesti =meesti  (SgG  >meest !22_S	et	f	\N
215190	meesti	?meesti =meesti  (SgP  >meest !22_S	et	f	\N
215191	meesti	?meesti =meesti  (SgAdt  >meest !22_S	et	f	\N
215192	meesti	?meesti =meesti  (IndPrPs_  >meestima !28_V	et	f	\N
215193	meesti	?meesti =meesti  (ImpPrSg2  >meestima !28_V	et	f	\N
215195	vaiduslikad	?vaiduslikad =vaiduslika  (PlN  >vaiduslika !01_S	et	f	\N
215196	vaiduslikad	?vaiduslikad =vaiduslika  (PlN  >vaiduslikas !02_A	et	f	\N
215199	neegre	?neegre =neegre  (SgN  >neegre !06_S	et	f	\N
215200	neegre	?neegre =neegre  (SgG  >neegre !06_S	et	f	\N
215201	neegre	?neegre =neegre  (IndPrPs_  >neegrema !27_V	et	f	\N
215202	neegre	?neegre =neegre  (ImpPrSg2  >neegrema !27_V	et	f	\N
215204	huumorimeel	huumorimeel =mee  (SgAd  >huumori+mesi !15_S	et	f	\N
215205	huumorimeel	huumorimeel =meel  (SgN  >huumori+meel !13_S	et	f	\N
215227	köögiviljaid	?köögiviljaid =köögivilja  (PlP  >köögiviljas !02_A	et	f	\N
215228	köögiviljaid	?köögiviljaid =köögiviljai  (PlN  >köögiviljai !26_S	et	f	\N
215229	köögiviljaid	?köögiviljaid =köögiviljai  (SgP  >köögiviljai !26_S	et	f	\N
215230	köögiviljaid	?köögiviljaid =vilja  (PlP  >köögi+viljas !02_A	et	f	\N
215231	köögiviljaid	?köögiviljaid =viljai  (PlN  >köögi+viljai !26_S	et	f	\N
215232	köögiviljaid	?köögiviljaid =viljai  (SgP  >köögi+viljai !26_S	et	f	\N
215233	köögiviljaid	?köögiviljaid =viljaid  (SgN  >köögi+viljaid !22_S	et	f	\N
215241	türgist	?türgist =türgi  (SgEl  >türk !22_S	et	f	\N
215242	türgist	?türgist =türgis  (SgP  >türgis !09_S	et	f	\N
215243	türgist	?türgist =türgist  (SgN  >türgist !22_S	et	f	\N
215249	traditsioonilises	traditsioonilises =traditsioonilise  (SgIn  >traditsiooniline !12_A	et	f	\N
215250	traditsioonilises	"traditsiooniline %traditsiooni  )LINE_aA  <traditsioon ;22_S	et	f	\N
215255	õppetajaks	?õppetajaks =õppetaja  (SgTr  >õppetaja !01_S	et	f	\N
215256	õppetajaks	?õppetajaks =õppetaja  (SgTr  >õppetajas !02_A	et	f	\N
215257	õppetajaks	?õppetajaks =taja  (SgTr  >õppe+taja !17_S	et	f	\N
215259	hullut	?hullut =hullu  (SgP  >hullu !16_S	et	f	\N
215142	varisemine	"varisemine %varise  )MINE_vS  <varisema ;27_V	et	f	\N
215153	politikast	?politikast =politika  (SgEl  >politika !01_S	et	f	\N
215154	politikast	?politikast =politika  (SgEl  >politikas !02_A	et	f	\N
215155	politikast	?politikast =politikas  (SgP  >politikane !12_A	et	f	\N
215171	kuulutaks	kuulutaks =kuulu  (KndPrIps  >kuuluma !27_V	et	f	\N
215172	kuulutaks	kuulutaks =kuuluta  (KndPrPs  >kuulutama !27_V	et	f	\N
215173	kuulutaks	kuulutaks =taks  (SgN  >kuulu+taks !22_S	et	f	\N
215180	teekslesid	?teekslesid =teeksle  (IndIpfSg2  >teekslema !30_V	et	f	\N
215181	teekslesid	?teekslesid =teeksle  (IndIpfPl3  >teekslema !30_V	et	f	\N
215194	naljaksad	?naljaksad =naljaksa  (PlN  >naljaksa !01_S	et	f	\N
215203	homoseksuaalte	### homoseksuaalte	et	f	\N
215215	sülearvuti	sülearvuti =uti  (SgG  >süle+arv+utt !22_S	et	f	\N
215216	sülearvuti	sülearvuti =arvuti  (SgN  >süle+arvuti !01_S	et	f	\N
215217	sülearvuti	sülearvuti =arvuti  (SgG  >süle+arvuti !01_S	et	f	\N
215221	misuguseid	?misuguseid =misugusei  (PlN  >misugusei !26_S	et	f	\N
215222	misuguseid	?misuguseid =misugusei  (SgP  >misugusei !26_S	et	f	\N
215223	misuguseid	?misuguseid =uguse  (PlP  >mis+ugus !02_A	et	f	\N
215224	misuguseid	?misuguseid =ugusei  (PlN  >mis+ugusei !26_S	et	f	\N
215225	misuguseid	?misuguseid =ugusei  (SgP  >mis+ugusei !26_S	et	f	\N
215234	puuviljaid	?puuviljaid =puuvilja  (PlP  >puuviljas !02_A	et	f	\N
215235	puuviljaid	?puuviljaid =puuviljai  (PlN  >puuviljai !26_S	et	f	\N
215236	puuviljaid	?puuviljaid =puuviljai  (SgP  >puuviljai !26_S	et	f	\N
215237	puuviljaid	?puuviljaid =vilja  (PlP  >puu+viljas !02_A	et	f	\N
215238	puuviljaid	?puuviljaid =viljai  (PlN  >puu+viljai !26_S	et	f	\N
215239	puuviljaid	?puuviljaid =viljai  (SgP  >puu+viljai !26_S	et	f	\N
215240	puuviljaid	?puuviljaid =viljaid  (SgN  >puu+viljaid !22_S	et	f	\N
215271	metsis	metsis =metsi  (SgIn  >mets !22_S	et	f	\N
215272	metsis	metsis =metsi  (PlIn  >mets !22_S	et	f	\N
215273	metsis	metsis =metsis  (SgN  >metsis !09_S	et	f	\N
215274	kauadaks	?kauadaks =daks  (SgN  >kaua+daks !22_S	et	f	\N
215293	sajasib	### sajasib	et	f	\N
215301	lugesis	?lugesis =lugesis  (SgN  >lugesis !11_S	et	f	\N
215345	seitmeni	?seitmeni =seitme  (SgTer  >seitme !06_S	et	f	\N
215346	seitmeni	?seitmeni =seitmeni  (SgG  >seitmen !02_S	et	f	\N
215349	sõis	?sõis =sõi  (SgIn  >sõi !26_S	et	f	\N
215350	sõis	?sõis =sõis  (SgN  >sõis !22_S	et	f	\N
215376	brokoli	?brokoli =brokoli  (ID  >brokoli !41_D	et	f	\N
215377	brokoli	?brokoli =brokoli  (SgG  >brokol !02_S	et	f	\N
215397	sagelis	?sagelis =sageli  (SgIn  >sagel !02_S	et	f	\N
215398	sagelis	?sagelis =sagelis  (SgN  >sagelis !11_S	et	f	\N
215408	berlinis	?berlinis =berlini  (SgIn  >berlin !02_S	et	f	\N
215409	berlinis	?berlinis =berlinis  (SgN  >berlinis !11_S	et	f	\N
215421	kümme-aastane	kümme-aastane =aastane  (SgN  >kümme-aastane !12~10_A	et	f	\N
215422	kümme-aastane	"kümme-aastane %aasta  )NE_aA  <kümme-aasta ;01_S	et	f	\N
215447	soojalembeseid	soojalembeseid =lembese  (PlP  >sooja+lembene !10_A	et	f	\N
215448	soojalembeseid	"sooja+lembene %lembe  )NE_aA  <sooja+lemme ;06_S	et	f	\N
215449	soojalembeseid	"sooja+lembene %lembe  )NE_aA  <sooja+lemmes ;07_S	et	f	\N
215457	jääkatte	jääkatte =atte  (PlP  >jääk+att !22_S	et	f	\N
215458	jääkatte	jääkatte =katte  (SgG  >jää+kate !06_S	et	f	\N
215459	jääkatte	jääkatte =katte  (PlP  >jää+katt !22_S	et	f	\N
215476	ladestustes	ladestustes =ladestus  (PlIn  >ladestus !11_S	et	f	\N
215478	ladestustes	"ladestus %ladesta  )US_vS  <ladestama ;27_V	et	f	\N
215489	elutum	elutum =elutum  (SgN  >elutum !02_A	et	f	\N
215490	elutum	"elutum %elu  )TUM2_cA  <elu ;17_S	et	f	\N
215491	elutum	"elutum %elutu  )M_cA  <elutu ;01_A	et	f	\N
215492	arendusplaani	arendusplaani =plaani  (SgG  >arendus+plaan !22_S	et	f	\N
215493	arendusplaani	arendusplaani =plaani  (SgP  >arendus+plaan !22_S	et	f	\N
215494	arendusplaani	arendusplaani =plaani  (SgAdt  >arendus+plaan !22_S	et	f	\N
215503	investoritele	?investoritele =investori  (PlAll  >investor !02_S	et	f	\N
215504	investoritele	?investoritele =investorite  (PlAll  >investoritt !22_S	et	f	\N
215505	investoritele	?investoritele =investoritele  (IndPrPs_  >investoritelema !36_V	et	f	\N
215506	investoritele	?investoritele =investoritele  (ImpPrSg2  >investoritelema !36_V	et	f	\N
215522	suplusrannad	?suplusrannad =suplusranna  (PlN  >suplusranna !16_S	et	f	\N
215526	suplusranna	?suplusranna =suplusranna  (SgN  >suplusranna !16_S	et	f	\N
215527	suplusranna	?suplusranna =suplusranna  (SgG  >suplusranna !16_S	et	f	\N
215528	rannamaja	rannamaja =maja  (SgN  >ranna+maja !17_S	et	f	\N
215529	rannamaja	rannamaja =maja  (SgG  >ranna+maja !17_S	et	f	\N
215530	rannamaja	rannamaja =maja  (SgP  >ranna+maja !17_S	et	f	\N
215534	jääsegu	jääsegu =segu  (SgN  >jää+segu !17_S	et	f	\N
215535	jääsegu	jääsegu =segu  (SgG  >jää+segu !17_S	et	f	\N
215536	jääsegu	jääsegu =segu  (SgP  >jää+segu !17_S	et	f	\N
215537	puurimise	puurimise =puurimise  (SgG  >puurimine !12_S	et	f	\N
215538	puurimise	"puurimine %puuri  )MINE_vS  <puurima ;28_V	et	f	\N
215544	sügavusele	sügavusele =sügavuse  (SgAll  >sügavus !11_S	et	f	\N
215545	sügavusele	"sügavus %süga  )VUS_aS  <sügama ;27_V	et	f	\N
215260	hullut	?hullut =hullut  (SgN  >hullut !02_S	et	f	\N
215264	natukune	?natukune =natukune  (SgN  >natukune !12_A	et	f	\N
215265	natukune	?natukune =natukune  (PlP  >natukun !19_S	et	f	\N
215275	kevadelisi	kevadelisi =kevadelisi  (PlP  >kevadeline !12_A	et	f	\N
215276	kevadelisi	"kevadeline %kevade  )LINE_aA  <kevade ;01_S	et	f	\N
215277	kevadelisi	"kevadeline %kevade  )LINE_aA  <kevad ;02_S	et	f	\N
215289	muutan	?muutan =muuta  (IndPrSg1  >muutama !27_V	et	f	\N
215290	muutan	?muutan =muutan  (SgN  >muutan !02_S	et	f	\N
215308	kirjutasis	?kirjutasis =kirjutasi  (PlIn  >kirjutane !12_A	et	f	\N
215309	kirjutasis	?kirjutasis =kirjutasis  (SgN  >kirjutasis !09_S	et	f	\N
215312	spagette	?spagette =spagette  (PlP  >spagett !22_S	et	f	\N
215319	pärnography	### pärnography	et	f	\N
215359	makkaronid	?makkaronid =makkaroni  (PlN  >makkaron !19_S	et	f	\N
215364	tei	?tei =tei  (SgN  >tei !26_S	et	f	\N
215365	tei	?tei =tei  (SgG  >tei !26_S	et	f	\N
215366	mineda	### mineda	et	f	\N
215378	jööma	?jööma =jööma  (SgN  >jööma !16_S	et	f	\N
215379	jööma	?jööma =jööma  (SgG  >jööma !16_S	et	f	\N
215380	jööma	?jööma =jööma  (IndPrPs_  >jöömama !29_V	et	f	\N
215381	jööma	?jööma =jööma  (ImpPrSg2  >jöömama !29_V	et	f	\N
215382	öpida	?öpida =öpi  (Inf  >öpima !27_V	et	f	\N
215392	banan	?banan =bana  (IndPrSg1  >banama !27_V	et	f	\N
215393	banan	?banan =banan  (SgN  >banan !02_S	et	f	\N
215401	lugin	?lugin =lugi  (IndPrSg1  >lugima !27_V	et	f	\N
215402	lugin	?lugin =lugin  (SgN  >lugin !02_S	et	f	\N
215416	hitrone	?hitrone =hitrone  (SgN  >hitrone !12~10_A	et	f	\N
215417	hitrone	?hitrone =hitrone  (IndPrPs_  >hitronema !27_V	et	f	\N
215418	hitrone	?hitrone =hitrone  (ImpPrSg2  >hitronema !27_V	et	f	\N
215440	lilien	?lilien =lilien  (SgN  >lilien !19_S	et	f	\N
215460	puurimisel	puurimisel =puurimise  (SgAd  >puurimine !12_S	et	f	\N
215461	puurimisel	"puurimine %puuri  )MINE_vS  <puurima ;28_V	et	f	\N
215464	jupiteri	jupiteri =jupiteri  (SgG  >jupiter !19_S	et	f	\N
215465	jupiteri	jupiteri =jupiteri  (SgP  >jupiter !19_S	et	f	\N
215466	jupiteri	jupiteri =jupiteri  (SgAdt  >jupiter !19_S	et	f	\N
215467	jupiteri	jupiteri =teri  (PlP  >jupi+tera !17_S	et	f	\N
215470	jäätunud	jäätunud =jäätu  (PtsPtPs  >jäätuma !27_V	et	f	\N
215471	jäätunud	jäätunud =jäätunu  (PlN  >jäätunu !01_S	et	f	\N
215472	jäätunud	"jäätunu %jäätu  )NU_vS  <jäätuma ;27_V	et	f	\N
215473	jäätunud	jäätunud =jäätunud  (ID  >jäätunud !41_A	et	f	\N
215474	jäätunud	"jäätunud %jäätu  )NUD_vA  <jäätuma ;27_V	et	f	\N
215509	näruselt	näruselt =näruse  (SgAbl  >närune !10_A	et	f	\N
215510	näruselt	"närune %näru  )NE_aA  <näru ;17_S	et	f	\N
215511	näruselt	näruselt =näruselt  (ID  >näruselt !41_D	et	f	\N
215512	näruselt	"näruselt %näru  )SELT_mD  <näru ;17_S	et	f	\N
215513	näruselt	"näruselt %näruse  )LT_mD  <närune ;10_A	et	f	\N
215523	rannaala	rannaala =ala  (SgN  >ranna+ala !17_S	et	f	\N
215524	rannaala	rannaala =ala  (SgG  >ranna+ala !17_S	et	f	\N
215525	rannaala	rannaala =ala  (SgP  >ranna+ala !17_S	et	f	\N
215539	termofiilbakterite	?termofiilbakterite =termofiilbakteri  (PlG  >termofiilbakter !02_S	et	f	\N
215540	termofiilbakterite	?termofiilbakterite =fiilbakteri  (PlG  >termo+fiilbakter !02_S	et	f	\N
215543	viieteistkümnete	### viieteistkümnete	et	f	\N
215551	külmunud	külmunud =külmu  (PtsPtPs  >külmuma !27_V	et	f	\N
215552	külmunud	külmunud =külmunu  (PlN  >külmunu !01_S	et	f	\N
215553	külmunud	"külmunu %külmu  )NU_vS  <külmuma ;27_V	et	f	\N
215554	külmunud	külmunud =külmunud  (ID  >külmunud !41_A	et	f	\N
215555	külmunud	"külmunud %külmu  )NUD_vA  <külmuma ;27_V	et	f	\N
215564	soojalembesed	soojalembesed =lembese  (PlN  >sooja+lembene !12~10_A	et	f	\N
215565	soojalembesed	"sooja+lembene %lembe  )NE_aA  <sooja+lemme ;06_S	et	f	\N
215566	soojalembesed	"sooja+lembene %lembe  )NE_aA  <sooja+lemmes ;07_S	et	f	\N
215567	soojalembsete	?soojalembsete =soojalembse  (PlG  >soojalembne !02_A	et	f	\N
215568	soojalembsete	?soojalembsete =lembse  (PlG  >sooja+lembne !02_A	et	f	\N
215569	soojalembsete	?soojalembsete =lembse  (PlG  >sooja+lembse !06_S	et	f	\N
215570	soojalembsete	?soojalembsete =jalembse  (PlG  >soo+jalembne !02_A	et	f	\N
215574	puurimisega	puurimisega =puurimise  (SgKom  >puurimine !12_S	et	f	\N
215575	puurimisega	"puurimine %puuri  )MINE_vS  <puurima ;28_V	et	f	\N
215578	järvet	?järvet =järve  (SgP  >järve !06_S	et	f	\N
215593	joonest	joonest =joone  (SgEl  >joon !13_S	et	f	\N
215594	joonest	joonest =joones  (SgP  >joonene !10_A	et	f	\N
215595	joonest	"joonene %joone  )NE_aA  <joon ;13_S	et	f	\N
215665	valitut	valitut =valitu  (SgP  >valitu !01_S	et	f	\N
215666	valitut	"valitu %vali  )TU1_vS  <valima ;27_V	et	f	\N
215678	tikkimisele	tikkimisele =tikkimise  (SgAll  >tikkimine !12_S	et	f	\N
215679	tikkimisele	"tikkimine %tikki  )MINE_vS  <tikkima ;28_V	et	f	\N
215685	gruupi	?gruupi =gruupi  (ID  >gruupi !41_D	et	f	\N
215686	gruupi	?gruupi =gruupi  (SgP  >gruup !22_S	et	f	\N
215687	gruupi	?gruupi =gruupi  (SgAdt  >gruup !22_S	et	f	\N
215692	olena	?olena =ole  (SgEs  >ole !16_S	et	f	\N
215326	pärnast	pärnast =ast  (SgN  >pärn+ast !22_S	et	f	\N
215343	sõbredega	### sõbredega	et	f	\N
215344	tored	?tored =tore  (IndPrSg2  >torema !27_V	et	f	\N
215353	tõis	?tõis =tõi  (SgIn  >tõi !26_S	et	f	\N
215354	tõis	?tõis =tõis  (SgN  >tõis !22_S	et	f	\N
215360	tereviisorit	?tereviisorit =tereviisori  (SgP  >tereviisor !02_S	et	f	\N
215361	tereviisorit	?tereviisorit =orit  (SgN  >tere+viis+orit !02_S	et	f	\N
215362	tereviisorit	?tereviisorit =viisori  (SgP  >tere+viisori !01_S	et	f	\N
215363	tereviisorit	?tereviisorit =viisori  (SgP  >tere+viisor !02_S	et	f	\N
215374	ülikoolile	ülikoolile =kooli  (SgAll  >üli+kool !22_S	et	f	\N
215375	ülikoolile	ülikoolile =kooli  (PlAll  >üli+kool !22_S	et	f	\N
215387	vilniuselt	?vilniuselt =vilniuse  (SgAbl  >vilnius !11_S	et	f	\N
215388	vilniuselt	?vilniuselt =vilniuselt  (ID  >vilniuselt !41_D	et	f	\N
215412	julatasin	?julatasin =julata  (IndIpfSg1  >julatama !27_V	et	f	\N
215413	julatasin	?julatasin =julatasin  (SgN  >julatasin !19_S	et	f	\N
215441	läänemerile	?läänemerile =läänemeri  (SgAll  >läänemer !19_S	et	f	\N
215442	päikesepäisteline	?päikesepäisteline =päikesepäisteline  (SgN  >päikesepäisteline !12_A	et	f	\N
215443	päikesepäisteline	?päikesepäisteline =päikesepäisteline  (PlP  >päikesepäistelin !19_S	et	f	\N
215444	päikesepäisteline	?päikesepäisteline =teline  (SgN  >päikese+päis+teline !10_A	et	f	\N
215445	päikesepäisteline	?päikesepäisteline =päisteline  (SgN  >päikese+päisteline !12_A	et	f	\N
215446	päikesepäisteline	?päikesepäisteline =päisteline  (PlP  >päikese+päistelin !19_S	et	f	\N
215452	soojalembeste	soojalembeste =lembes  (PlG  >sooja+lembene !12~10_A	et	f	\N
215453	soojalembeste	"sooja+lembene %lembe  )NE_aA  <sooja+lemme ;06_S	et	f	\N
215454	soojalembeste	"sooja+lembene %lembe  )NE_aA  <sooja+lemmes ;07_S	et	f	\N
215455	kolmekilomeetrise	kolmekilomeetrise =meetrise  (SgG  >kolme+kilo+meetrine !12~10_A	et	f	\N
215456	kolmekilomeetrise	"kolme+kilo+meetrine %meetri  )NE_aA  <kolme+kilo+meeter ;02_S	et	f	\N
215462	settekivimi	?settekivimi =settekivimi  (SgG  >settekivim !02_A	et	f	\N
215475	leiduski	leiduski =uski  (SgG  >leid+usk !22_S	et	f	\N
215477	leiduski	leiduski =uski  (SgP  >leid+usk !22_S	et	f	\N
215479	leiduski	leiduski =uski  (SgAdt  >leid+usk !22_S	et	f	\N
215480	leiduski	leiduski =leidu  (IndIpfSg3^  >leiduma !27_V	et	f	\N
215481	leiduski	leiduski =leidus  (SgN^  >leidus !11~09_S	et	f	\N
215483	50-60c	### 50-60c	et	f	\N
215486	lükkavad	lükkavad =lükka  (IndPrPl3  >lükkama !29_V	et	f	\N
215487	lükkavad	lükkavad =lükkava  (PlN  >lükkav !02_A	et	f	\N
215488	lükkavad	"lükkav %lükka  )V_vA  <lükkama ;29_V	et	f	\N
215500	stiihiliselt	stiihiliselt =stiihilise  (SgAbl  >stiihiline !12_A	et	f	\N
215501	stiihiliselt	stiihiliselt =stiihiliselt  (ID  >stiihiliselt !41_D	et	f	\N
215502	stiihiliselt	"stiihiliselt %stiihilise  )LT_mD  <stiihiline ;12_A	et	f	\N
215533	settekivime-	### settekivime-	et	f	\N
215556	settekivime	### settekivime	et	f	\N
215557	külmale	külmale =külma  (SgAll  >külm !22_AS	et	f	\N
215558	külmale	külmale =ale  (SgN  >külm+ale !16_S	et	f	\N
215559	külmale	külmale =ale  (SgG  >külm+ale !16_S	et	f	\N
215579	satteliites	?satteliites =satteliite  (SgIn  >satteliite !16_S	et	f	\N
215580	katkestunud	?katkestunud =katkestu  (PtsPtPs  >katkestuma !27_V	et	f	\N
215581	katkestunud	?katkestunud =katkestunu  (PlN  >katkestunu !01_S	et	f	\N
215582	katkestunud	?katkestunud =katkestunu  (IndPrSg2  >katkestunuma !27_V	et	f	\N
215583	katkestunud	?katkestunud =katkestunud  (ID  >katkestunud !41_A	et	f	\N
215589	reisifirma	reisifirma =firma  (SgN  >reisi+firma !16_S	et	f	\N
215590	reisifirma	reisifirma =firma  (SgG  >reisi+firma !16_S	et	f	\N
215611	ettendust	?ettendust =ettendu  (SgEl  >ettendu !01_S	et	f	\N
215612	ettendust	?ettendust =ettendus  (SgP  >ettendus !11_S	et	f	\N
215621	kestvus	kestvus =kestvus  (SgN  >kestvus !11~09_S	et	f	\N
215622	kestvus	"kestvus %kest  )VUS_aS  <kestma ;34_V	et	f	\N
215623	kestvus	"kestvus %kestva  )US_aS  <kestev ;02_A	et	f	\N
215650	kurjad	?kurjad =kurja  (PlN  >kurjas !02_A	et	f	\N
215651	kurjad	?kurjad =kurja  (PlN  >kurja !16_S	et	f	\N
215652	kurjad	?kurjad =kurja  (PlN  >kuri !24_A	et	f	\N
215653	kurjad	?kurjad =kurja  (IndPrSg2  >kurjama !29_V	et	f	\N
215656	päranduse	päranduse =päranduse  (SgG  >pärandus !11_S	et	f	\N
215657	päranduse	"pärandus %päranda  )US_vS  <pärandama ;27_V	et	f	\N
215659	targeks	targeks =targe  (PlTr  >tark !22_AS	et	f	\N
215660	targeks	targeks =targe  (KndPrPs  >targema !27_V	et	f	\N
215676	pöörguda	?pöörguda =pöörgu  (Inf  >pöörguma !27_V	et	f	\N
215701	kuulutuks	kuulutuks =kuulu  (KndPtIps  >kuuluma !27_V	et	f	\N
215702	kuulutuks	kuulutuks =kuulutu  (SgTr  >kuulutu !01_AS	et	f	\N
215703	kuulutuks	"kuulutu %kuulu  )TU1_vS  <kuuluma ;27_V	et	f	\N
215704	kuulutuks	"kuulutu %kuulu  )TU2_kA  <kuuld ;22_S	et	f	\N
215705	kuulutuks	kuulutuks =tuks  (SgN  >kuulu+tuks !22_S	et	f	\N
215706	kuulutuks	kuulutuks =lutu  (SgTr  >kuu+lutu !16_S	et	f	\N
215707	kuulutuks	kuulutuks =lutu  (SgTr  >kuu+lutt !22_S	et	f	\N
215726	andmetest	andmetest =andme  (PlEl  >anne !05_S	et	f	\N
215727	andmetest	andmetest =test  (SgN  >andme+test !22_S	et	f	\N
215372	jooksesid	?jooksesid =jookse  (IndIpfSg2  >jooksema !27_V	et	f	\N
215373	jooksesid	?jooksesid =jookse  (IndIpfPl3  >jooksema !27_V	et	f	\N
215389	sauce	?sauce =sauce  (SgN  >sauce !06_S	et	f	\N
215390	sauce	?sauce =sauce  (SgG  >sauce !06_S	et	f	\N
215391	sauce	?sauce =sauce  (PlP  >sauc !22_S	et	f	\N
215394	jooksima	?jooksima =jooksi  (Sup  >jooksima !28_V	et	f	\N
215395	jooksima	?jooksima =jooksima  (SgG  >jooksim !02_A	et	f	\N
215396	kuulasit	?kuulasit =asit  (SgN  >kuul+asit !02_S	et	f	\N
215410	berlinis	?berlinis =berlini  (SgIn  >berlin !02_S	et	f	\N
215411	berlinis	?berlinis =berlinis  (SgN  >berlinis !11_S	et	f	\N
215414	ostman	?ostman =ostma  (IndPrSg1  >ostmama !29_V	et	f	\N
215415	ostman	?ostman =ostman  (SgN  >ostman !02_S	et	f	\N
215428	sõitaime	sõitaime =ime  (SgN  >sõita+ime !16_S	et	f	\N
215429	sõitaime	sõitaime =ime  (SgG  >sõita+ime !16_S	et	f	\N
215430	horvaatiale	?horvaatiale =horvaatia  (SgAll  >horvaatia !01_S	et	f	\N
215431	horvaatiale	?horvaatiale =horvaatiale  (PlP  >horvaatial !19_S	et	f	\N
215450	avastuse	avastuse =avastuse  (SgG  >avastus !11_S	et	f	\N
215451	avastuse	"avastus %avasta  )US_vS  <avastama ;27_V	et	f	\N
215463	vostok	?vostok =vostok  (SgN  >vostok !02_S	et	f	\N
215497	arenduskava	arenduskava =kava  (SgN  >arendus+kava !17_S	et	f	\N
215498	arenduskava	arenduskava =kava  (SgG  >arendus+kava !17_S	et	f	\N
215499	arenduskava	arenduskava =kava  (SgP  >arendus+kava !17_S	et	f	\N
215507	2010aastaks	aastaks =aasta  (SgTr  >aasta !01_S	et	f	\N
215508	2010aastaks	aastaks =taks  (SgN  >aas+taks !22_S	et	f	\N
215514	lähiaastail	lähiaastail =tai  (SgAd  >lähi+aas+tai !26_S	et	f	\N
215515	lähiaastail	lähiaastail =aasta  (PlAd  >lähi+aasta !01_S	et	f	\N
215531	avastuse-	avastuse- =avastuse  (SgG  >avastus !11_S	et	f	\N
215532	avastuse-	"avastus %avasta  )US_vS  <avastama ;27_V	et	f	\N
215549	puurimist	puurimist =puurimis  (SgP  >puurimine !12_S	et	f	\N
215550	puurimist	"puurimine %puuri  )MINE_vS  <puurima ;28_V	et	f	\N
215560	võimaldavad	võimaldavad =võimalda  (IndPrPl3  >võimaldama !27_V	et	f	\N
215561	võimaldavad	võimaldavad =võimaldava  (PlN  >võimaldav !02_A	et	f	\N
215562	võimaldavad	"võimaldav %võimalda  )V_vA  <võimaldama ;27_V	et	f	\N
215563	võimaldavad	võimaldavad =maldava  (PlN  >või+maldav !02_A	et	f	\N
215585	kihtid	### kihtid	et	f	\N
215591	tööpõhjus	tööpõhjus =põhju  (PlIn  >töö+põhi !24_S	et	f	\N
215592	tööpõhjus	tööpõhjus =põhjus  (SgN  >töö+põhjus !11~09_S	et	f	\N
215596	soovad	?soovad =soova  (PlN  >soova !16_S	et	f	\N
215597	soovad	?soovad =soova  (IndPrSg2  >soovama !29_V	et	f	\N
215598	rikk	?rikk =rikk  (SgN  >rikk !22_S	et	f	\N
215607	rikus	?rikus =riku  (SgIn  >riku !16_S	et	f	\N
215608	rikus	?rikus =riku  (SgIn  >rikk !22_S	et	f	\N
215609	rikus	?rikus =riku  (IndIpfSg3  >rikuma !27_V	et	f	\N
215610	rikus	?rikus =rikus  (SgN  >rikus !09_S	et	f	\N
215624	nägemisega	nägemisega =nägemise  (SgKom  >nägemine !12_S	et	f	\N
215625	nägemisega	"nägemine %näge  )MINE_vS  <nägema ;28_V	et	f	\N
215627	sobim	?sobim =sobim  (SgN  >sobim !02_A	et	f	\N
215634	soodsamad	soodsamad =soodsama  (PlN  >soodsam !02_A	et	f	\N
215635	soodsamad	"soodsam %soodsa  )M_cA  <soodus ;02_A	et	f	\N
215636	soodsamad	"soodsam %soodsa  )M_cA  <soodne ;02_A	et	f	\N
215639	allahindlust	allahindlust =lust  (SgN  >alla+hind+lust !22_S	et	f	\N
215640	allahindlust	allahindlust =hindlus  (SgP  >alla+hindlus !11~09_S	et	f	\N
215661	saamisse	saamisse =saami  (SgIll  >saam !22_S	et	f	\N
215662	saamisse	saamisse =saamis  (SgAdt  >saamine !12_S	et	f	\N
215663	saamisse	"saamine %saa  )MINE_vS  <saama ;37_V	et	f	\N
215664	saamisse	"saamine %saami  )NE_aA  <saam ;22_S	et	f	\N
215667	saabgi	?saabgi =saabgi  (ID  >saabgi !41_D	et	f	\N
215668	saabgi	?saabgi =saabgi  (SgG  >saabg !22_S	et	f	\N
215669	saabgi	?saabgi =saabgi  (SgP  >saabg !22_S	et	f	\N
215670	saabgi	?saabgi =saabgi  (SgAdt  >saabg !22_S	et	f	\N
215671	saabgi	?saabgi =saabgi  (IndPrPs_  >saabgima !28_V	et	f	\N
215672	saabgi	?saabgi =saabgi  (ImpPrSg2  >saabgima !28_V	et	f	\N
215673	miljonäriks	miljonäriks =miljonäri  (SgTr  >miljonär !19_S	et	f	\N
215674	miljonäriks	miljonäriks =iks  (SgN  >miljonär+iks !22_S	et	f	\N
215696	riidetud	riidetud =riidetu  (PlN  >riidetu !01_AS	et	f	\N
215697	riidetud	"riidetu %riide  )TU2_kA  <riie ;06_S	et	f	\N
215710	heatuju	heatuju =tuju  (SgN  >hea+tuju !17_S	et	f	\N
215711	heatuju	heatuju =tuju  (SgG  >hea+tuju !17_S	et	f	\N
215712	heatuju	heatuju =tuju  (SgP  >hea+tuju !17_S	et	f	\N
215733	muusikasaali	muusikasaali =saali  (SgG  >muusika+saal !22_S	et	f	\N
215734	muusikasaali	muusikasaali =saali  (SgP  >muusika+saal !22_S	et	f	\N
215735	muusikasaali	muusikasaali =saali  (SgAdt  >muusika+saal !22_S	et	f	\N
215748	leidmises	leidmises =leidmise  (SgIn  >leidmine !12?10_S	et	f	\N
215749	leidmises	"leidmine %leid  )MINE_vS  <leidma ;34_V	et	f	\N
215758	kardad	kardad =karda  (IndPrSg2  >kardama !29_V	et	f	\N
215759	kardad	kardad =karda  (IndPrSg2  >kartma !34_V	et	f	\N
215772	asjaajamistega	asjaajamistega =ajamis  (PlKom  >asja+ajamine !12_S	et	f	\N
215773	asjaajamistega	"asja+ajamine %ajami  )NE_aA  <asja+ajam ;02_S	et	f	\N
215419	hoorlanis	?hoorlanis =hoorlani  (SgIn  >hoorlan !02_S	et	f	\N
215420	hoorlanis	?hoorlanis =hoorlanis  (SgN  >hoorlanis !11_S	et	f	\N
215423	koreasse	koreasse =korea  (SgIll  >korea !26_S	et	f	\N
215424	koreasse	koreasse =koreas  (SgAdt  >koreane !12_A	et	f	\N
215425	koreasse	"koreane %korea  )NE_aA  <korea ;26_S	et	f	\N
215426	merisse	?merisse =merisse  (SgG  >merisne !02_A	et	f	\N
215427	merisse	?merisse =merisse  (PlP  >meriss !22_S	et	f	\N
215432	kuuresaare	?kuuresaare =kuuresaare  (SgN  >kuuresaare !16_S	et	f	\N
215433	kuuresaare	?kuuresaare =kuuresaare  (SgG  >kuuresaare !16_S	et	f	\N
215434	kuuresaare	?kuuresaare =kuuresaare  (PlP  >kuuresaar !22_S	et	f	\N
215435	kuuresaare	?kuuresaare =resaare  (SgN  >kuu+resaare !16_S	et	f	\N
215436	kuuresaare	?kuuresaare =resaare  (SgG  >kuu+resaare !16_S	et	f	\N
215437	kuuresaare	?kuuresaare =resaare  (PlP  >kuu+resaar !22_S	et	f	\N
215438	veebruars	?veebruars =veebruars  (SgN  >veebruars !22_S	et	f	\N
215439	veebruars	?veebruars =bruars  (SgN  >vee+bruars !22_S	et	f	\N
215468	europal	?europal =europa  (SgAd  >europa !01_S	et	f	\N
215469	europal	?europal =europal  (SgN  >europal !19_S	et	f	\N
215482	temperatuuri	temperatuuri =temperatuuri  (SgG  >temperatuur !22_S	et	f	\N
215484	temperatuuri	temperatuuri =temperatuuri  (SgP  >temperatuur !22_S	et	f	\N
215485	temperatuuri	temperatuuri =temperatuuri  (SgAdt  >temperatuur !22_S	et	f	\N
215495	20072010aastaks	aastaks =aasta  (SgTr  >aasta !01_S	et	f	\N
215496	20072010aastaks	aastaks =taks  (SgN  >aas+taks !22_S	et	f	\N
215516	tee-ehitus	tee-ehitus =ehitu  (SgIn  >tee-ehitu !01_AS	et	f	\N
215517	tee-ehitus	"tee-ehitu %ehi  )TU1_vS  <tee-ehtima ;28_V	et	f	\N
215518	tee-ehitus	tee-ehitus =ehitu  (IndIpfSg3  >tee-ehituma !27_V	et	f	\N
215519	tee-ehitus	tee-ehitus =ehitus  (SgN  >tee-ehitus !11_S	et	f	\N
215520	tee-ehitus	"tee-ehitus %ehita  )US_vS  <tee-ehitama ;27_V	et	f	\N
215521	tee-ehitus	"tee-ehitus %ehi  )TUS1_aS  <tee-ehtima ;28_V	et	f	\N
215541	hüdrotermaalsed	?hüdrotermaalsed =hüdrotermaalse  (PlN  >hüdrotermaalne !02_A	et	f	\N
215542	hüdrotermaalsed	?hüdrotermaalsed =termaalse  (PlN  >hüdro+termaalne !02_A	et	f	\N
215584	settekivimite	?settekivimite =settekivimi  (PlG  >settekivim !02_A	et	f	\N
215599	tarkusi	tarkusi =tarkusi  (PlP  >tarkus !11_S	et	f	\N
215600	tarkusi	"tarkus %tark  )US_aS  <tark ;22_AS	et	f	\N
215601	tarkusi	tarkusi =tarkusi  (PlP  >tarkune !12_A	et	f	\N
215602	rikat	?rikat =rika  (SgP  >rika !16_S	et	f	\N
215603	rikat	?rikat =rikat  (SgN  >rikat !02_S	et	f	\N
215613	soobivusaeg	?soobivusaeg =soobivusaeg  (SgN  >soobivusaeg !22_S	et	f	\N
215614	soobivusaeg	?soobivusaeg =bivusaeg  (SgN  >soo+bivusaeg !22_S	et	f	\N
215615	teatrireis	teatrireis =reis  (SgN  >teatri+reis !14_S	et	f	\N
215616	teatrireis	teatrireis =reis  (SgN  >teatri+reis !22_S	et	f	\N
215626	tunnites	?tunnites =tunnite  (PlIn  >tunnitt !22_S	et	f	\N
215637	katkesta	katkesta =katkesta  (IndPrPs_  >katkestama !27_V	et	f	\N
215638	katkesta	katkesta =katkesta  (ImpPrSg2  >katkestama !27_V	et	f	\N
215641	kl-si	kl-si =si  (SgN  >kl-si !26_S	et	f	\N
215642	kl-si	kl-si =si  (SgG  >kl-si !26_S	et	f	\N
215643	materjalse	?materjalse =materjalse  (SgG  >materjalne !02_A	et	f	\N
215644	materjalse	?materjalse =materjalse  (PlP  >materjals !22_S	et	f	\N
215645	nigunii	?nigunii =nigunii  (SgN  >nigunii !26_S	et	f	\N
215646	nigunii	?nigunii =nigunii  (SgG  >nigunii !26_S	et	f	\N
215658	materjalset	?materjalset =materjalse  (SgP  >materjalne !02_A	et	f	\N
215688	koolivanem	koolivanem =vanem  (SgN  >kooli+vanem !02_AS	et	f	\N
215689	koolivanem	"kooli+vanem %vane  )M_cA  <kooli+vana ;17_AS	et	f	\N
215693	liiksed	?liiksed =liikse  (PlN  >liikne !02_A	et	f	\N
215694	liiksed	?liiksed =liikse  (PlN  >liikse !06_S	et	f	\N
215695	liiksed	?liiksed =liikse  (IndPrSg2  >liiksema !28_V	et	f	\N
215708	erinemusi	erinemusi =erinemusi  (PlP  >erinemus !11_S	et	f	\N
215709	erinemusi	"erinemus %erine  )MUS_vS  <erinema ;27_V	et	f	\N
215760	juhatajal	juhatajal =juhataja  (SgAd  >juhataja !01_S	et	f	\N
215761	juhatajal	"juhataja %juhata  )JA_vS  <juhatama ;27_V	et	f	\N
215764	juhiabi-asjaajajaks	juhiabi-asjaajajaks =jaks  (SgN  >juhiabi-asja+aja+jaks !22_S	et	f	\N
215765	juhiabi-asjaajajaks	juhiabi-asjaajajaks =ajaja  (SgTr  >juhiabi-asja+ajaja !01_S	et	f	\N
215767	kogust	kogust =kogu  (SgEl  >kogu !17_S	et	f	\N
215768	kogust	kogust =kogus  (SgP  >kogus !09_S	et	f	\N
215776	iisaku	?iisaku =iisa  (ImpPrPs  >iisama !29_V	et	f	\N
215778	iisaku	?iisaku =iisaku  (SgG  >iisak !02_S	et	f	\N
215779	iisaku	?iisaku =iisaku  (IndPrPs_  >iisakuma !27_V	et	f	\N
215781	iisaku	?iisaku =iisaku  (ImpPrSg2  >iisakuma !27_V	et	f	\N
215787	rehielamu	?rehielamu =rehielamu  (IndPrPs_  >rehielamuma !27_V	et	f	\N
215788	rehielamu	?rehielamu =rehielamu  (ImpPrSg2  >rehielamuma !27_V	et	f	\N
215808	sammy	### sammy	et	f	\N
215815	rosso	?rosso =rosso  (SgN  >rosso !16_S	et	f	\N
215816	rosso	?rosso =rosso  (SgG  >rosso !16_S	et	f	\N
215819	erzieherin	?erzieherin =erzieherin  (SgN  >erzieherin !19_S	et	f	\N
215827	lgade	?lgade =lgade  (SgN  >lgade !16_S	et	f	\N
215828	lgade	?lgade =lgade  (SgG  >lgade !16_S	et	f	\N
215829	lgade	?lgade =lgade  (IndPrPs_  >lgadema !27_V	et	f	\N
215546	sügavusele	"sügavus %sügava  )US_aS  <sügav ;02_A	et	f	\N
215547	sügavusele	sügavusele =sügavuse  (SgAll  >sügavune !12_A	et	f	\N
215548	sügavusele	sügavusele =use  (PlAll  >sügav+usk !22_S	et	f	\N
215571	segust	segust =segu  (SgEl  >segu !17_S	et	f	\N
215572	segust	segust =segus  (SgP  >segune !10_A	et	f	\N
215573	segust	"segune %segu  )NE_aA  <segu ;17_S	et	f	\N
215576	termofiiliste	termofiiliste =fiilis  (PlG  >termo+fiiline !10_A	et	f	\N
215577	termofiiliste	"termo+fiiline %fii  )LINE_aA  <termo+fii ;26_S	et	f	\N
215586	bergen	?bergen =berge  (IndPrSg1  >bergema !27_V	et	f	\N
215587	bergen	?bergen =bergen  (SgN  >bergen !02_S	et	f	\N
215588	teatribilet	?teatribilet =bile  (SgP  >teatri+bile !16_S	et	f	\N
215604	ollnud	?ollnud =ollnu  (PlN  >ollnu !01_S	et	f	\N
215605	ollnud	?ollnud =ollnu  (IndPrSg2  >ollnuma !27_V	et	f	\N
215606	ollnud	?ollnud =ollnud  (ID  >ollnud !41_A	et	f	\N
215617	kinnitusega	kinnitusega =kinnituse  (SgKom  >kinnitus !11_S	et	f	\N
215618	kinnitusega	"kinnitus %kinnita  )US_vS  <kinnitama ;27_V	et	f	\N
215619	kõrgetasuline	kõrgetasuline =tasuline  (SgN  >kõrge+tasuline !12_A	et	f	\N
215620	kõrgetasuline	"kõrge+tasuline %tasu  )LINE_aA  <kõrge+tasu ;17_S	et	f	\N
215628	elenringi	?elenringi =elenringi  (SgG  >elenring !02_S	et	f	\N
215629	elenringi	?elenringi =elenringi  (SgG  >elenrink !22_S	et	f	\N
215630	elenringi	?elenringi =elenringi  (IndPrPs_  >elenrinkima !28_V	et	f	\N
215631	elenringi	?elenringi =elenringi  (ImpPrSg2  >elenrinkima !28_V	et	f	\N
215632	elenringi	?elenringi =elenri  (IndPrSg1^  >elenrima !28_V	et	f	\N
215633	elenringi	?elenringi =elenrin  (SgN^  >elenrin !19_S	et	f	\N
215647	niisuguseit	?niisuguseit =niisuguseit  (SgN  >niisuguseit !22_S	et	f	\N
215648	niisuguseit	?niisuguseit =seit  (SgN  >nii+sugu+seit !22_S	et	f	\N
215649	niisuguseit	?niisuguseit =suguseit  (SgN  >nii+suguseit !22_S	et	f	\N
215654	erinevait	?erinevait =erinevait  (SgN  >erinevait !22_S	et	f	\N
215655	erinevait	?erinevait =nevait  (SgN  >eri+nevait !22_S	et	f	\N
215675	katastroff	?katastroff =katastroff  (SgN  >katastroff !22_S	et	f	\N
215677	kunagil	### kunagil	et	f	\N
215680	patsid	patsid =patsi  (PlN  >pats !22_S	et	f	\N
215681	patsid	patsid =patsi  (IndPrSg2  >patsima !28_V	et	f	\N
215682	gruppa	?gruppa =gruppa  (ID  >gruppa !41_D	et	f	\N
215683	gruppa	?gruppa =gruppa  (IndPrPs_  >gruppama !29_V	et	f	\N
215684	gruppa	?gruppa =gruppa  (ImpPrSg2  >gruppama !29_V	et	f	\N
215690	haiglakittelistes	haiglakittelistes =kittelis  (PlIn  >haigla+kitteline !12_A	et	f	\N
215691	haiglakittelistes	"haigla+kitteline %kitteli  )NE_aA  <haigla+kittel ;02_S	et	f	\N
215698	arvumusi	arvumusi =musi  (SgN  >arvu+musi !17_S	et	f	\N
215699	arvumusi	arvumusi =musi  (SgG  >arvu+musi !17_S	et	f	\N
215700	arvumusi	arvumusi =musi  (SgP  >arvu+musi !17_S	et	f	\N
215713	igapärane	igapärane =pärane  (SgN  >iga+pärane !10_A	et	f	\N
215714	igapärane	"iga+pärane %pära  )NE_aA  <iga+pära ;17_S	et	f	\N
215719	teadmisegaja	?teadmisegaja =teadmisegaja  (SgN  >teadmisegaja !01_S	et	f	\N
215720	teadmisegaja	?teadmisegaja =teadmisegaja  (SgG  >teadmisegaja !01_S	et	f	\N
215721	teadmisegaja	?teadmisegaja =teadmisegaja  (SgG  >teadmisegajas !02_A	et	f	\N
215722	teadmisegaja	?teadmisegaja =egaja  (SgN  >teadmis+egaja !01_S	et	f	\N
215723	teadmisegaja	?teadmisegaja =egaja  (SgG  >teadmis+egaja !01_S	et	f	\N
215724	teadmisegaja	?teadmisegaja =egaja  (SgG  >teadmis+egajas !02_A	et	f	\N
215725	skemil	?skemil =skemi  (SgAd  >skemi !17_S	et	f	\N
215738	vastajat	vastajat =vastaja  (SgP  >vastaja !01_S	et	f	\N
215739	vastajat	"vastaja %vasta  )JA_vS  <vastama ;29_V	et	f	\N
215740	küsitletuid	küsitletuid =küsitletu  (PlP  >küsitletu !01_S	et	f	\N
215741	küsitletuid	"küsitletu %küsitle  )TU1_vS  <küsitlema ;27_V	et	f	\N
215742	lapselapsi	lapselapsi =laps  (PlP  >lapse+laps !14_S	et	f	\N
215743	lapselapsi	lapselapsi =lapsi  (SgG  >lapse+laps !22_S	et	f	\N
215744	lapselapsi	lapselapsi =lapsi  (SgP  >lapse+laps !22_S	et	f	\N
215745	lapselapsi	lapselapsi =lapsi  (SgAdt  >lapse+laps !22_S	et	f	\N
215774	kevanduse	?kevanduse =kevanduse  (SgG  >kevandus !11_S	et	f	\N
215775	iisaku	?iisaku =iisa  (ImpPrPs  >iisama !29_V	et	f	\N
215777	iisaku	?iisaku =iisaku  (SgG  >iisak !02_S	et	f	\N
215780	iisaku	?iisaku =iisaku  (IndPrPs_  >iisakuma !27_V	et	f	\N
215782	iisaku	?iisaku =iisaku  (ImpPrSg2  >iisakuma !27_V	et	f	\N
215800	seilenborn	?seilenborn =seilenborn  (SgN  >seilenborn !22_S	et	f	\N
215805	pruuni-	pruuni- =pruuni  (SgG  >pruun !22_AS	et	f	\N
215806	pruuni-	pruuni- =pruuni  (SgP  >pruun !22_AS	et	f	\N
215807	pruuni-	pruuni- =pruuni  (SgAdt  >pruun !22_AS	et	f	\N
215811	belina	?belina =beli  (SgEs  >beli !17_S	et	f	\N
215812	belina	?belina =belina  (SgG  >belin !02_S	et	f	\N
215831	järskkude	### järskkude	et	f	\N
215834	tagap	?tagap =tagap  (SgN  >tagap !02_S	et	f	\N
215868	paljute	?paljute =palju  (IndPrPl2  >paljuma !27_V	et	f	\N
215925	arhitektorina	?arhitektorina =arhitektori  (SgEs  >arhitektor !02_S	et	f	\N
215926	arhitektorina	?arhitektorina =arhitektorina  (SgG  >arhitektorin !19_S	et	f	\N
215927	arhitektorina	?arhitektorina =arhitektorina  (SgP  >arhitektorin !19_S	et	f	\N
215928	arhitektorina	?arhitektorina =arhitektorina  (SgAdt  >arhitektorin !19_S	et	f	\N
215715	liikselt	?liikselt =liikse  (SgAbl  >liikne !02_A	et	f	\N
215716	liikselt	?liikselt =liikse  (SgAbl  >liikse !06_S	et	f	\N
215717	liikselt	?liikselt =liikse  (PlAbl  >liiks !22_S	et	f	\N
215718	liikselt	?liikselt =liikselt  (ID  >liikselt !41_D	et	f	\N
215736	online-küsitluse	online-küsitluse =küsitluse  (SgG  >online-küsitlus !11_S	et	f	\N
215737	online-küsitluse	"online-küsitlus %küsitle  )US_vS  <online-küsitlema ;27_V	et	f	\N
215750	iisakus	?iisakus =iisaku  (SgIn  >iisak !02_S	et	f	\N
215751	iisakus	?iisakus =iisaku  (IndIpfSg3  >iisakuma !27_V	et	f	\N
215752	iisakus	?iisakus =iisakus  (SgN  >iisakus !11_S	et	f	\N
215753	koolituba	koolituba =tuba  (SgN  >kooli+tuba !18_S	et	f	\N
215754	koolituba	koolituba =tuba  (SgP  >kooli+tuba !18_S	et	f	\N
215766	kaevandakse	?kaevandakse =kaevandakse  (SgG  >kaevandakne !02_A	et	f	\N
215801	dinka	?dinka =dinka  (SgN  >dinka !16_S	et	f	\N
215802	dinka	?dinka =dinka  (SgG  >dinka !16_S	et	f	\N
215803	dinka	?dinka =dinka  (IndPrPs_  >dinkama !29_V	et	f	\N
215804	dinka	?dinka =dinka  (ImpPrSg2  >dinkama !29_V	et	f	\N
215821	sürnud	?sürnud =sürnu  (PlN  >sürnu !01_S	et	f	\N
215822	sürnud	?sürnud =sürnu  (IndPrSg2  >sürnuma !27_V	et	f	\N
215823	sürnud	?sürnud =sürnud  (ID  >sürnud !41_A	et	f	\N
215826	fabian	?fabian =fabian  (SgN  >fabian !19_S	et	f	\N
215835	hjas	### hjas	et	f	\N
215850	pimedusest	pimedusest =pimeduse  (SgEl  >pimedus !11_S	et	f	\N
215851	pimedusest	"pimedus %pimeda  )US_aS  <pime ;02_AS	et	f	\N
215852	pimedusest	pimedusest =pimeduses  (SgP  >pimedusene !12_A	et	f	\N
215853	pimedusest	"pimedusene %pimeduse  )NE_aA  <pimedus ;11_S	et	f	\N
215879	terepalun	?terepalun =terepalu  (IndPrSg1  >terepaluma !27_V	et	f	\N
215880	terepalun	?terepalun =terepalun  (SgN  >terepalun !19_S	et	f	\N
215881	terepalun	?terepalun =palun  (SgN  >tere+palun !02_S	et	f	\N
215886	kirjutamata	kirjutamata =kirjuta  (SupAb  >kirjutama !27_V	et	f	\N
215887	kirjutamata	kirjutamata =kirjutamata  (ID  >kirjutamata !41_A	et	f	\N
215888	kirjutamata	"kirjutamata %kirjuta  )MATA_vA  <kirjutama ;27_V	et	f	\N
215893	tahtmised	tahtmised =tahtmise  (PlN  >tahtmine !12?10_S	et	f	\N
215894	tahtmised	"tahtmine %taht  )MINE_vS  <tahtma ;34_V	et	f	\N
215895	panneksin	?panneksin =panne  (KndPrSg1  >pannema !27_V	et	f	\N
215896	panneksin	?panneksin =panneksi  (IndPrSg1  >panneksima !28_V	et	f	\N
215897	panneksin	?panneksin =panneksin  (SgN  >panneksin !19_S	et	f	\N
215898	panneksin	?panneksin =eksin  (SgN  >pann+eksin !02_S	et	f	\N
215902	omadaspan	?omadaspan =omadaspan  (SgN  >omadaspan !02_S	et	f	\N
215903	omadaspan	?omadaspan =daspan  (SgN  >oma+daspan !02_S	et	f	\N
215935	selllest	?selllest =sellle  (SgEl  >sellle !06_S	et	f	\N
215936	selllest	?selllest =sellle  (PlEl  >selll !22_S	et	f	\N
215937	selllest	?selllest =sellles  (SgP  >sellles !09_S	et	f	\N
215938	selllest	?selllest =sellles  (SgP  >selllene !12~10_A	et	f	\N
215954	põhimõtelised	?põhimõtelised =põhimõtelise  (PlN  >põhimõteline !12_A	et	f	\N
215955	põhimõtelised	?põhimõtelised =mõtelise  (PlN  >põhi+mõteline !12_A	et	f	\N
215959	hingamisega	hingamisega =hingamise  (SgKom  >hingamine !12_S	et	f	\N
215960	hingamisega	"hingamine %hinga  )MINE_vS  <hingama ;29_V	et	f	\N
215969	oletavad	oletavad =oleta  (IndPrPl3  >oletama !27_V	et	f	\N
215970	oletavad	oletavad =oletava  (PlN  >oletav !02_A	et	f	\N
215971	oletavad	"oletav %oleta  )V_vA  <oletama ;27_V	et	f	\N
215983	joogivesi	joogivesi =vesi  (SgN  >joogi+vesi !15_S	et	f	\N
215984	joogivesi	joogivesi =vesi  (PlP  >joogi+vesi !15_S	et	f	\N
215992	reostajaid	reostajaid =reostaja  (PlP  >reostaja !01_S	et	f	\N
215993	reostajaid	"reostaja %reosta  )JA_vS  <reostama ;27_V	et	f	\N
215997	kuldbr	?kuldbr =kuldbr  (SgN  >kuldbr !22_S	et	f	\N
216001	loohakaks	?loohakaks =loohaka  (SgTr  >loohaka !01_S	et	f	\N
216002	loohakaks	?loohakaks =loohaka  (SgTr  >loohakas !02_A	et	f	\N
216003	loohakaks	?loohakaks =haka  (SgTr  >loo+haka !16_S	et	f	\N
216004	toituta	toituta =toitu  (SgAb  >toitu !01_A	et	f	\N
216005	toituta	"toitu %toi  )TU2_kA  <toi ;26_S	et	f	\N
216006	toituta	toituta =toitu  (IndPrIps_  >toituma !27_V	et	f	\N
216007	ravineteta	?ravineteta =ravineteta  (IndPrPs_  >ravinetetama !27_V	et	f	\N
216008	ravineteta	?ravineteta =ravineteta  (ImpPrSg2  >ravinetetama !27_V	et	f	\N
216014	õppimiskeel	õppimiskeel =kee  (SgAd  >õppimis+kesi !15_S	et	f	\N
216015	õppimiskeel	õppimiskeel =kee  (SgAd  >õppimis+kee !26_S	et	f	\N
216016	õppimiskeel	õppimiskeel =keel  (SgN  >õppimis+keel !13_S	et	f	\N
216024	kiirega	kiirega =kiire  (SgKom  >kiire !01_A	et	f	\N
216025	kiirega	kiirega =kiire  (SgKom  >kiire !06_S	et	f	\N
216026	kiirega	kiirega =kiire  (SgKom  >kiire !06_AS	et	f	\N
216027	kiirega	kiirega =kiire  (SgKom  >kiir !13_S	et	f	\N
216028	raagi	raagi =raagi  (SgP  >raag !22_S	et	f	\N
216029	raagi	raagi =raagi  (SgAdt  >raag !22_S	et	f	\N
216030	raagi	raagi =raa  (SgN^  >raa !26_S	et	f	\N
216031	raagi	raagi =raa  (SgG^  >raag !22_S	et	f	\N
216032	raagi	raagi =raa  (SgG^  >raa !26_S	et	f	\N
216053	rolton	?rolton =rolton  (SgN  >rolton !02_S	et	f	\N
216054	coca-colat	?coca-colat =colat  (SgN  >coca-colat !02_S	et	f	\N
215728	peamiseltpensionäärid	?peamiseltpensionäärid =peamiseltpensionääri  (PlN  >peamiseltpensionääri !16_S	et	f	\N
215729	peamiseltpensionäärid	?peamiseltpensionäärid =peamiseltpensionääri  (PlN  >peamiseltpensionäär !22_S	et	f	\N
215730	peamiseltpensionäärid	?peamiseltpensionäärid =peamiseltpensionääri  (IndPrSg2  >peamiseltpensionäärima !28_V	et	f	\N
215731	peamiseltpensionäärid	?peamiseltpensionäärid =eltpensionääri  (PlN  >pea+mis+eltpensionääri !16_S	et	f	\N
215732	peamiseltpensionäärid	?peamiseltpensionäärid =eltpensionääri  (PlN  >pea+mis+eltpensionäär !22_S	et	f	\N
215746	5protsenti	protsenti =protsenti  (SgP  >protsent !22_S	et	f	\N
215747	5protsenti	protsenti =protsenti  (SgAdt  >protsent !22_S	et	f	\N
215755	võimlus	?võimlus =võimlu  (SgIn  >võimlu !01_S	et	f	\N
215756	võimlus	?võimlus =võimlu  (IndIpfSg3  >võimluma !27_V	et	f	\N
215757	võimlus	?võimlus =võimlus  (SgN  >võimlus !11~09_S	et	f	\N
215762	õppivate	õppivate =õppiva  (PlG  >õppiv !02_A	et	f	\N
215763	õppivate	"õppiv %õppi  )V_vA  <õppima ;28_V	et	f	\N
215769	elektrijaama	elektrijaama =jaama  (SgG  >elektri+jaam !22_S	et	f	\N
215770	elektrijaama	elektrijaama =jaama  (SgP  >elektri+jaam !22_S	et	f	\N
215771	elektrijaama	elektrijaama =jaama  (SgAdt  >elektri+jaam !22_S	et	f	\N
215783	kaevanduse	kaevanduse =kaevanduse  (SgG  >kaevandus !11_S	et	f	\N
215784	kaevanduse	"kaevandus %kaevanda  )US_vS  <kaevandama ;27_V	et	f	\N
215791	kasselis	kasselis =seli  (PlIn  >kas+selg !22_S	et	f	\N
215792	kasselis	kasselis =selis  (SgN  >kas+selis !09_S	et	f	\N
215793	üldekeeleteadust	?üldekeeleteadust =üldekeeleteadus  (SgP  >üldekeeleteadus !11~09_S	et	f	\N
215794	üldekeeleteadust	?üldekeeleteadust =ekeeleteadus  (SgP  >üld+ekeeleteadus !11~09_S	et	f	\N
215795	skateboardi	?skateboardi =skateboardi  (SgG  >skateboart !22_S	et	f	\N
215796	skateboardi	?skateboardi =skateboardi  (SgP  >skateboard !22_S	et	f	\N
215797	skateboardi	?skateboardi =skateboardi  (SgAdt  >skateboard !22_S	et	f	\N
215798	skateboardi	?skateboardi =skateboardi  (IndPrPs_  >skateboartima !28_V	et	f	\N
215799	skateboardi	?skateboardi =skateboardi  (ImpPrSg2  >skateboartima !28_V	et	f	\N
215813	rubino	?rubino =rubino  (SgN  >rubino !01_S	et	f	\N
215814	rubino	?rubino =rubino  (SgG  >rubino !01_S	et	f	\N
215820	venaema	### venaema	et	f	\N
215824	mthias	?mthias =mthia  (SgIn  >mthia !26_S	et	f	\N
215825	mthias	?mthias =mthias  (SgN  >mthias !22_S	et	f	\N
215836	tumesinised	?tumesinised =tumesinise  (PlN  >tumesinis !09_S	et	f	\N
215837	tumesinised	?tumesinised =sinise  (PlN  >tume+sinis !09_S	et	f	\N
215838	tumesinised	?tumesinised =sinise  (PlN  >tume+sinine !10_AS	et	f	\N
215859	naertusega	?naertusega =naertuse  (SgKom  >naertus !11~09_S	et	f	\N
215860	parisis	?parisis =parisis  (SgN  >parisis !11_S	et	f	\N
215864	japanlast	?japanlast =japanla  (SgEl  >japanla !01_S	et	f	\N
215865	japanlast	?japanlast =japanlas  (SgP  >japanlane !12_S	et	f	\N
215869	laudast	laudast =lauda  (SgEl  >laut !22_S	et	f	\N
215870	laudast	laudast =laudas  (SgP  >laudane !10_A	et	f	\N
215871	laudast	"laudane %lauda  )NE_aA  <laut ;22_S	et	f	\N
215872	laudast	laudast =ast  (SgN  >laud+ast !22_S	et	f	\N
215884	lõputöö	lõputöö =töö  (SgN  >lõpu+töö !26_S	et	f	\N
215885	lõputöö	lõputöö =töö  (SgG  >lõpu+töö !26_S	et	f	\N
215891	suhtumised	suhtumised =suhtumise  (PlN  >suhtumine !12_S	et	f	\N
215892	suhtumised	"suhtumine %suhtu  )MINE_vS  <suhtuma ;27_V	et	f	\N
215906	oskata	?oskata =oska  (SgAb  >oska !16_S	et	f	\N
215907	oskata	?oskata =oskata  (IndPrPs_  >oskatama !27_V	et	f	\N
215908	oskata	?oskata =oskata  (ImpPrSg2  >oskatama !27_V	et	f	\N
215912	spa-protseduuri	spa-protseduuri =protseduuri  (SgG  >spa-protseduur !22_S	et	f	\N
215913	spa-protseduuri	spa-protseduuri =protseduuri  (SgP  >spa-protseduur !22_S	et	f	\N
215914	spa-protseduuri	spa-protseduuri =protseduuri  (SgAdt  >spa-protseduur !22_S	et	f	\N
215915	eraklinnikus	?eraklinnikus =eraklinniku  (SgIn  >eraklinnik !02_S	et	f	\N
215916	eraklinnikus	?eraklinnikus =eraklinniku  (IndIpfSg3  >eraklinnikuma !27_V	et	f	\N
215917	eraklinnikus	?eraklinnikus =eraklinnikus  (SgN  >eraklinnikus !11?09_S	et	f	\N
215918	eraklinnikus	?eraklinnikus =klinniku  (SgIn  >era+klinniku !01_S	et	f	\N
215919	eraklinnikus	?eraklinnikus =klinniku  (SgIn  >era+klinnik !02_S	et	f	\N
215920	eraklinnikus	?eraklinnikus =klinnikus  (SgN  >era+klinnikus !11_S	et	f	\N
215932	proekteerib	?proekteerib =proekteeri  (IndPrSg3  >proekteerima !28_V	et	f	\N
215950	enesetunuseta	?enesetunuseta =enesetunuse  (SgAb  >enesetunus !11?09_S	et	f	\N
215951	enesetunuseta	?enesetunuseta =enesetunuseta  (IndPrPs_  >enesetunusetama !27_V	et	f	\N
215952	enesetunuseta	?enesetunuseta =enesetunuseta  (ImpPrSg2  >enesetunusetama !27_V	et	f	\N
215953	enesetunuseta	?enesetunuseta =tunuse  (SgAb  >enese+tunus !09_S	et	f	\N
215967	mao	mao =mao  (SgG  >madu !18_S	et	f	\N
215968	mao	mao =mao  (SgG  >magu !18_S	et	f	\N
215972	infektsiooni	infektsiooni =infektsiooni  (SgG  >infektsioon !22_S	et	f	\N
215973	infektsiooni	infektsiooni =infektsiooni  (SgP  >infektsioon !22_S	et	f	\N
215974	infektsiooni	infektsiooni =infektsiooni  (SgAdt  >infektsioon !22_S	et	f	\N
215977	intsüfoliit	?intsüfoliit =intsüfoliit  (SgN  >intsüfoliit !22_S	et	f	\N
215998	osake	osake =osa  (ImpPrPl2  >oskama !29_V	et	f	\N
215999	osake	osake =osake  (SgN  >osake !12_S	et	f	\N
215785	kohtla-nõmmel	kohtla-nõmmel =nõmme  (SgAd  >kohtla-nõmm !22_S	et	f	\N
215786	kohtla-nõmmel	kohtla-nõmmel =nõmme  (PlAd  >kohtla-nõmm !22_S	et	f	\N
215789	tuletõrjetuba	tuletõrjetuba =tuba  (SgN  >tule+tõrje+tuba !18_S	et	f	\N
215790	tuletõrjetuba	tuletõrjetuba =tuba  (SgP  >tule+tõrje+tuba !18_S	et	f	\N
215809	farfalla	?farfalla =farfalla  (SgN  >farfalla !16_S	et	f	\N
215810	farfalla	?farfalla =farfalla  (SgG  >farfalla !16_S	et	f	\N
215817	valge-	valge- =valge  (SgN  >valge !01_AS	et	f	\N
215818	valge-	valge- =valge  (SgG  >valge !01_AS	et	f	\N
215832	värved	?värved =värve  (PlN  >värve !06_S	et	f	\N
215833	värved	?värved =värve  (IndPrSg2  >värvema !27_V	et	f	\N
215842	väärtuslikust	väärtuslikust =väärtusliku  (SgEl  >väärtuslik !25_A	et	f	\N
215843	väärtuslikust	väärtuslikust =väärtuslikus  (SgP  >väärtuslikus !11?09_S	et	f	\N
215844	väärtuslikust	"väärtuslikus %väärtusliku  )US_aS  <väärtuslik ;25_A	et	f	\N
215848	heledam	heledam =heledam  (SgN  >heledam !02_A	et	f	\N
215849	heledam	"heledam %heleda  )M_cA  <hele ;02_A	et	f	\N
215861	louvres	?louvres =louvre  (SgIn  >louvre !06_S	et	f	\N
215862	louvres	?louvres =louvre  (IndIpfSg3  >louvrema !27_V	et	f	\N
215863	louvres	?louvres =louvres  (SgN  >louvres !09_S	et	f	\N
215873	vanavanematel	vanavanematel =ate  (PlAd  >vana+vanem+att !22_S	et	f	\N
215874	vanavanematel	vanavanematel =vanema  (PlAd  >vana+vanem !02_AS	et	f	\N
215875	vanavanematel	"vana+vanem %vane  )M_cA  <vana+vana ;17_AS	et	f	\N
215877	vajatan	?vajatan =vajata  (IndPrSg1  >vajatama !27_V	et	f	\N
215878	vajatan	?vajatan =vajatan  (SgN  >vajatan !19_S	et	f	\N
215882	tänasesse	tänasesse =tänase  (SgIll  >tänane !10_A	et	f	\N
215883	tänasesse	tänasesse =sesse  (PlP  >täna+sess !22_S	et	f	\N
215889	juhendamiseks	juhendamiseks =juhendamise  (SgTr  >juhendamine !12_S	et	f	\N
215890	juhendamiseks	"juhendamine %juhenda  )MINE_vS  <juhendama ;27_V	et	f	\N
215899	effektiivselt	?effektiivselt =effektiivse  (SgAbl  >effektiivne !02_A	et	f	\N
215900	effektiivselt	?effektiivselt =effektiivse  (PlAbl  >effektiivs !22_S	et	f	\N
215901	effektiivselt	?effektiivselt =effektiivselt  (ID  >effektiivselt !41_D	et	f	\N
215909	basseini	basseini =basseini  (SgG  >bassein !22_S	et	f	\N
215910	basseini	basseini =basseini  (SgP  >bassein !22_S	et	f	\N
215911	basseini	basseini =basseini  (SgAdt  >bassein !22_S	et	f	\N
215933	parameetrid	parameetrid =parameetri  (PlN  >parameeter !02_S	et	f	\N
215934	parameetrid	parameetrid =meetri  (PlN  >para+meeter !02_S	et	f	\N
215939	võiamlust	?võiamlust =võiamlu  (SgEl  >võiamlu !01_S	et	f	\N
215940	võiamlust	?võiamlust =võiamlus  (SgP  >võiamlus !11_S	et	f	\N
215941	võiamlust	?võiamlust =amlu  (SgEl  >või+amlu !16_S	et	f	\N
215942	võiamlust	?võiamlust =amlus  (SgP  >või+amlus !11~09_S	et	f	\N
215964	muutustele	muutustele =muutus  (PlAll  >muutus !11~09_S	et	f	\N
215965	muutustele	"muutus %muu  )TUS2_aS  <muu ;26_S	et	f	\N
215966	muutustele	muutustele =tuste  (PlAll  >muu+tust !22_S	et	f	\N
215990	riieta	riieta =riieta  (IndPrPs_  >riietama !27_V	et	f	\N
215991	riieta	riieta =riieta  (ImpPrSg2  >riietama !27_V	et	f	\N
215994	säästlikult	säästlikult =säästliku  (SgAbl  >säästlik !25_A	et	f	\N
215995	säästlikult	säästlikult =säästlikult  (ID  >säästlikult !41_D	et	f	\N
215996	säästlikult	"säästlikult %säästliku  )LT_mD  <säästlik ;25_A	et	f	\N
216037	sõidusest	?sõidusest =sõiduse  (SgEl  >sõidus !11~09_S	et	f	\N
216038	sõidusest	?sõidusest =sõiduses  (SgP  >sõidusene !12_A	et	f	\N
216067	coolerit	?coolerit =cooleri  (SgP  >cooleri !01_S	et	f	\N
216068	coolerit	?coolerit =cooleri  (SgP  >cooler !02_S	et	f	\N
215830	lgade	?lgade =lgade  (ImpPrSg2  >lgadema !27_V	et	f	\N
215839	kleid	?kleid =klei  (PlN  >klei !26_S	et	f	\N
215840	kleid	?kleid =klei  (SgP  >klei !26_S	et	f	\N
215841	kleid	?kleid =kleid  (SgN  >kleid !22_S	et	f	\N
215845	kuldselt	kuldselt =kuldse  (SgAbl  >kuldne !02_A	et	f	\N
215846	kuldselt	kuldselt =kuldselt  (ID  >kuldselt !41_D	et	f	\N
215847	kuldselt	"kuldselt %kuldse  )LT_mD  <kuldne ;02_A	et	f	\N
215854	dekoltee	dekoltee =dekoltee  (SgN  >dekoltee !26_S	et	f	\N
215855	dekoltee	dekoltee =dekoltee  (SgG  >dekoltee !26_S	et	f	\N
215856	istatusliku	?istatusliku =istatusliku  (SgG  >istatuslik !25_A	et	f	\N
215857	istatusliku	?istatusliku =istatusliku  (IndPrPs_  >istatuslikuma !27_V	et	f	\N
215858	istatusliku	?istatusliku =istatusliku  (ImpPrSg2  >istatuslikuma !27_V	et	f	\N
215866	fotoapparatidega	### fotoapparatidega	et	f	\N
215867	õltub	?õltub =õltu  (IndPrSg3  >õltuma !27_V	et	f	\N
215876	paljutel	?paljutel =paljute  (PlAd  >paljutt !22_S	et	f	\N
215904	spaneestis	?spaneestis =spaneesti  (IndIpfSg3  >spaneestima !28_V	et	f	\N
215905	spaneestis	?spaneestis =spaneestis  (SgN  >spaneestis !11_S	et	f	\N
215921	tähtus	?tähtus =tähtu  (SgIn  >tähtu !01_S	et	f	\N
215922	tähtus	?tähtus =tähtu  (IndIpfSg3  >tähtuma !27_V	et	f	\N
215923	tähtus	?tähtus =tähtus  (SgN  >tähtus !11~09_S	et	f	\N
215924	initsiatiivsed	?initsiatiivsed =initsiatiivse  (PlN  >initsiatiivne !02_A	et	f	\N
215943	perekondata	?perekondata =perekonda  (SgAb  >perekonda !16_S	et	f	\N
215944	perekondata	?perekondata =perekonda  (IndPrIps_  >perekondama !27_V	et	f	\N
215945	perekondata	?perekondata =perekondata  (IndPrPs_  >perekondatama !27_V	et	f	\N
215946	perekondata	?perekondata =perekondata  (ImpPrSg2  >perekondatama !27_V	et	f	\N
215947	perekondata	?perekondata =konda  (SgAb  >pere+konda !16_S	et	f	\N
215956	mõteid	?mõteid =mõtei  (PlN  >mõtei !26_S	et	f	\N
215957	mõteid	?mõteid =mõtei  (SgP  >mõtei !26_S	et	f	\N
215958	mõteid	?mõteid =mõteid  (SgN  >mõteid !22_S	et	f	\N
215961	reageerivad	reageerivad =reageeri  (IndPrPl3  >reageerima !28_V	et	f	\N
215962	reageerivad	reageerivad =reageeriva  (PlN  >reageeriv !02_A	et	f	\N
215963	reageerivad	"reageeriv %reageeri  )V_vA  <reageerima ;28_V	et	f	\N
215975	malaaria	malaaria =malaaria  (SgN  >malaaria !01_S	et	f	\N
215976	malaaria	malaaria =malaaria  (SgG  >malaaria !01_S	et	f	\N
215978	sagikust	?sagikust =sagiku  (SgEl  >sagiku !01_S	et	f	\N
215979	sagikust	?sagikust =sagiku  (SgEl  >sagik !02_S	et	f	\N
215980	sagikust	?sagikust =sagikus  (SgP  >sagikus !11_S	et	f	\N
215981	kõhutühjust	kõhutühjust =tühjus  (SgP  >kõhu+tühjus !11~09_S	et	f	\N
215982	kõhutühjust	"kõhu+tühjus %tühj  )US_aS  <kõhu+tühi ;24_A	et	f	\N
215988	tootmisjäätmetega	tootmisjäätmetega =me  (PlKom  >tootmis+jäät+mesi !15_S	et	f	\N
215989	tootmisjäätmetega	tootmisjäätmetega =jäätme  (PlKom  >tootmis+jääde !05_S	et	f	\N
216033	suitsuta	suitsuta =suitsu  (SgAb  >suits !22_S	et	f	\N
216034	suitsuta	suitsuta =suitsu  (IndPrIps_  >suitsuma !27_V	et	f	\N
216035	suitsuta	suitsuta =suitsuta  (IndPrPs_  >suitsutama !27_V	et	f	\N
216036	suitsuta	suitsuta =suitsuta  (ImpPrSg2  >suitsutama !27_V	et	f	\N
216045	orbiti	?orbiti =orbi  (IndIpfIps  >orpima !28_V	et	f	\N
216046	orbiti	?orbiti =orbiti  (ID  >orbiti !41_D	et	f	\N
216047	orbiti	?orbiti =orbiti  (SgG  >orbit !02_S	et	f	\N
216048	orbiti	?orbiti =orbiti  (SgG  >orbitt !22_S	et	f	\N
216049	orbiti	?orbiti =orbiti  (IndPrPs_  >orbittima !28_V	et	f	\N
216050	orbiti	?orbiti =orbiti  (ImpPrSg2  >orbittima !28_V	et	f	\N
215929	aspirantuuri	aspirantuuri =aspirantuuri  (SgG  >aspirantuur !22_S	et	f	\N
215930	aspirantuuri	aspirantuuri =aspirantuuri  (SgP  >aspirantuur !22_S	et	f	\N
215931	aspirantuuri	aspirantuuri =aspirantuuri  (SgAdt  >aspirantuur !22_S	et	f	\N
215948	vastuarusaamine	vastuarusaamine =saamine  (SgN  >vastu+aru+saamine !12?10_S	et	f	\N
215949	vastuarusaamine	"vastu+aru+saamine %saami  )NE_aA  <vastu+aru+saam ;22_S	et	f	\N
215985	reostaja	reostaja =reostaja  (SgN  >reostaja !01_S	et	f	\N
215986	reostaja	"reostaja %reosta  )JA_vS  <reostama ;27_V	et	f	\N
215987	reostaja	reostaja =reostaja  (SgG  >reostaja !01_S	et	f	\N
216011	rahuldustunde	rahuldustunde =unde  (PlP  >rahuldust+und !22_S	et	f	\N
216012	rahuldustunde	rahuldustunde =tunde  (SgG  >rahuldus+tunne !06_S	et	f	\N
216013	rahuldustunde	rahuldustunde =tunde  (PlP  >rahuldus+tund !22_S	et	f	\N
216017	õppimiskeelt	õppimiskeelt =kee  (SgAbl  >õppimis+kesi !15_S	et	f	\N
216018	õppimiskeelt	õppimiskeelt =kee  (SgAbl  >õppimis+kee !26_S	et	f	\N
216019	õppimiskeelt	õppimiskeelt =keel  (SgP  >õppimis+keel !13_S	et	f	\N
216042	harmoonia	harmoonia =harmoonia  (SgN  >harmoonia !01_S	et	f	\N
216043	harmoonia	harmoonia =harmoonia  (SgG  >harmoonia !01_S	et	f	\N
216051	jägermeister	?jägermeister =jägermeister  (SgN  >jägermeister !02_S	et	f	\N
216056	13-15aastased	-aastased =aastase  (PlN  >-aastane !12~10_A	et	f	\N
216057	13-15aastased	"-aastane %aasta  )NE_aA  <-aasta ;01_S	et	f	\N
216060	bulli	?bulli =bulli  (SgN  >bulli !16_S	et	f	\N
216061	bulli	?bulli =bulli  (SgG  >bulli !16_S	et	f	\N
216062	bulli	?bulli =bulli  (SgG  >bull !22_S	et	f	\N
216063	bulli	?bulli =bulli  (SgP  >bull !22_S	et	f	\N
216064	bulli	?bulli =bulli  (SgAdt  >bull !22_S	et	f	\N
216065	bulli	?bulli =bulli  (IndPrPs_  >bullima !28_V	et	f	\N
216066	bulli	?bulli =bulli  (ImpPrSg2  >bullima !28_V	et	f	\N
216069	snikersi	?snikersi =snikersi  (SgN  >snikersi !01_S	et	f	\N
216070	snikersi	?snikersi =snikersi  (SgG  >snikersi !01_S	et	f	\N
216071	snikersi	?snikersi =snikersi  (SgG  >snikers !02_S	et	f	\N
216072	snikersi	?snikersi =snikersi  (SgG  >snikerss !22_S	et	f	\N
216073	snikersi	?snikersi =snikersi  (IndPrPs_  >snikerssima !28_V	et	f	\N
216074	snikersi	?snikersi =snikersi  (ImpPrSg2  >snikerssima !28_V	et	f	\N
216000	osake	"osake %osa  )KE_dS  <osa ;17_S	et	f	\N
216009	vaatlustest	vaatlustest =vaatlus  (PlEl  >vaatlus !11~09_S	et	f	\N
216010	vaatlustest	vaatlustest =test  (SgN  >vaatlus+test !22_S	et	f	\N
216020	ettevatlikud	?ettevatlikud =ettevatliku  (PlN  >ettevatlik !25_A	et	f	\N
216021	ettevatlikud	?ettevatlikud =ettevatliku  (IndPrSg2  >ettevatlikuma !27_V	et	f	\N
216022	ettevatlikud	?ettevatlikud =vatliku  (PlN  >ette+vatlik !25_A	et	f	\N
216023	ettevatlikud	?ettevatlikud =vatliku  (PlN  >ette+vatliku !01_S	et	f	\N
216039	staatistika	?staatistika =staatistika  (SgN  >staatistika !01_S	et	f	\N
216040	staatistika	?staatistika =staatistika  (SgG  >staatistika !01_S	et	f	\N
216041	staatistika	?staatistika =staatistika  (SgG  >staatistikas !02_A	et	f	\N
216044	olemema	?olemema =olemema  (SgG  >olemem !02_A	et	f	\N
216052	kaubanimesi	?kaubanimesi =kaubanimesi  (PlP  >kaubanimene !12_A	et	f	\N
216055	nesteat	?nesteat =nesteat  (SgN  >nesteat !22_S	et	f	\N
216075	marlborot	?marlborot =marlboro  (SgP  >marlboro !01_S	et	f	\N
216058	red	red =re  (PlN  >re !26_S	et	f	\N
216059	red	red =re  (SgP  >re !26_S	et	f	\N
130156	1mina	mina =mina  (SgN  >mina !00_P	et	t	\N
130157	1mina	mina =mi  (SgEs  >mi !26_S	et	t	\N
130159	1mina	mina =mina  (SgG  >mina !17_S	et	t	\N
130160	1mina	mina =mina  (SgP  >mina !17_S	et	t	\N
130158	1mina	mina =mina  (SgN  >mina !17_S	et	t	t
\.


--
-- Data for Name: words; Type: TABLE DATA; Schema: public; Owner: evkk
--

COPY words ("ID", word, prim, lemma, category, gram, "language", raw) FROM stdin;
26160	arvamus	arvamus	arvamus	11_S	SgN	et	arvamus =arvamus  (SgN  >arvamus !11_S
26161	lugesin	luge	lugema	28_V	IndIpfSg1	et	lugesin =luge  (IndIpfSg1  >lugema !28_V
26162	suvel	suve	suvi	20_S	SgAd	et	suvel =suve  (SgAd  >suvi !20_S
26163	ma	ma	ma	00_P	SgN	et	ma =ma  (SgN  >ma !00_P
26164	ajalehe	lehe	aja+leht	22_S	SgG	et	ajalehe =lehe  (SgG  >aja+leht !22_S
26165	väga	väga	väga	41_D	ID	et	väga =väga  (ID  >väga !41_D
26166	kus	kus	kus	41_D	ID	et	kus =kus  (ID  >kus !41_D
26167	oli	ol	olema	36_V	IndIpfSg3	et	oli =ol  (IndIpfSg3  >olema !36_V
26168	artikkel	artikkel	artikkel	02_S	SgN	et	artikkel =artikkel  (SgN  >artikkel !02_S
26169	sõbralik	sõbralik	sõbralik	25_A	SgN	et	sõbralik =sõbralik  (SgN  >sõbralik !25_A
26170	ja	ja	ja	41_J	ID	et	ja =ja  (ID  >ja !41_J
26171	kollektiiv	kollektiiv	kollektiiv	22_S	SgN	et	kollektiiv =kollektiiv  (SgN  >kollektiiv !22_S
26172	aastat	aasta	aasta	01_S	SgP	et	aastat =aasta  (SgP  >aasta !01_S
26173	kooliõpilased	õpilase	kooli+õpilane	12_S	PlN	et	kooliõpilased =õpilase  (PlN  >kooli+õpilane !12_S
26174	tagasi	tagasi	tagasi	41_DK	ID	et	tagasi =tagasi  (ID  >tagasi !41_DK
26175	toad	toa	tuba	18_S	PlN	et	toad =toa  (PlN  >tuba !18_S
26176	see	see	see	00_P	SgN	et	see =see  (SgN  >see !00_P
26177	nad	na	ta	00_P	PlN	et	nad =na  (PlN  >ta !00_P
26178	tegema	tege	tegema	28_V	Sup	et	tegema =tege  (Sup  >tegema !28_V
26179	suuri	suur	suur	13_A	PlP	et	suuri =suur  (PlP  >suur !13_A
26180	veega	vee	vesi	15_S	SgKom	et	veega =vee  (SgKom  >vesi !15_S
26181	et	et	et	41_J	ID	et	et =et  (ID  >et !41_J
26182	oleks	ole	olema	36_V	KndPrPs	et	oleks =ole  (KndPrPs  >olema !36_V
26183	hiiglasuuri	suur	hiigla+suur	13_A	PlP	et	hiiglasuuri =suur  (PlP  >hiigla+suur !13_A
26184	lampe	lampe	lamp	22_SA	PlP	et	lampe =lampe  (PlP  >lamp !22_SA
26185	koht	koht	koht	22_S	SgN	et	koht =koht  (SgN  >koht !22_S
26186	toa	toa	tuba	18_S	SgG	et	toa =toa  (SgG  >tuba !18_S
26187	keskel	keskel	keskel	41_DK	ID	et	keskel =keskel  (ID  >keskel !41_DK
26188	troopilised	troopilise	troopiline	12_A	PlN	et	troopilised =troopilise  (PlN  >troopiline !12_A
26189	taimid	taimi	taim	22_S	PlN	et	taimid =taimi  (PlN  >taim !22_S
26190	ilusad	ilusa	ilus	02_A	PlN	et	ilusad =ilusa  (PlN  >ilus !02_A
26191	lilled	lille	lill	22_S	PlN	et	lilled =lille  (PlN  >lill !22_S
26192	aga	aga	aga	41_JD	ID	et	aga =aga  (ID  >aga !41_JD
26193	seisavad	seisa	seisma	32_V	IndPrPl3	et	seisavad =seisa  (IndPrPl3  >seisma !32_V
26194	suured	suure	suur	13_A	PlN	et	suured =suure  (PlN  >suur !13_A
26195	nurgas	nurga	nurk	22_S	SgIn	et	nurgas =nurga  (SgIn  >nurk !22_S
26196	seisab	seisa	seisma	32_V	IndPrSg3	et	seisab =seisa  (IndPrSg3  >seisma !32_V
26197	üks	üks	üks	22_NP	SgN	et	üks =üks  (SgN  >üks !22_NP
26198	suur	suur	suur	13_A	SgN	et	suur =suur  (SgN  >suur !13_A
26199	puur	puur	puur	22_S	SgN	et	puur =puur  (SgN  >puur !22_S
26200	elab	ela	elama	27_V	IndPrSg3	et	elab =ela  (IndPrSg3  >elama !27_V
26201	tiigri	tiigri	tiiger	02_S	SgG	et	tiigri =tiigri  (SgG  >tiiger !02_S
26202	püüton	püüton	püüton	02_S	SgN	et	püüton =püüton  (SgN  >püüton !02_S
26203	kui	kui	kui	41_JD	ID	et	kui =kui  (ID  >kui !41_JD
26204	elektrit	elektri	elekter	02_S	SgP	et	elektrit =elektri  (SgP  >elekter !02_S
26205	vett	ve	vesi	15_S	SgP	et	vett =ve  (SgP  >vesi !15_S
26206	õpilased	õpilase	õpilane	12_S	PlN	et	õpilased =õpilase  (PlN  >õpilane !12_S
26207	viima	vii	viima	38_V	Sup	et	viima =vii  (Sup  >viima !38_V
26208	pudeleid	pudele	pudel	02_S	PlP	et	pudeleid =pudele  (PlP  >pudel !02_S
26209	sureks	sure	surema	36_V	KndPrPs	et	sureks =sure  (KndPrPs  >surema !36_V
26210	näitab	näita	näitama	29_V	IndPrSg3	et	näitab =näita  (IndPrSg3  >näitama !29_V
26211	nagu	nagu	nagu	41_J	ID	et	nagu =nagu  (ID  >nagu !41_J
26212	meeldib	meeldi	meeldima	27_V	IndPrSg3	et	meeldib =meeldi  (IndPrSg3  >meeldima !27_V
26213	sain	sa	saama	37_V	IndIpfSg1	et	sain =sa  (IndIpfSg1  >saama !37_V
26214	teada	tead	teadma	34_V	Inf	et	teada =tead  (Inf  >teadma !34_V
26215	tean	tea	teadma	34_V	IndPrSg1	et	tean =tea  (IndPrSg1  >teadma !34_V
26216	inimesed	inimese	inimene	12_S	PlN	et	inimesed =inimese  (PlN  >inimene !12_S
26217	küsitlesin	küsitle	küsitlema	27_V	IndIpfSg1	et	küsitlesin =küsitle  (IndIpfSg1  >küsitlema !27_V
26218	inimest	inimes	inimene	12_S	SgP	et	inimest =inimes  (SgP  >inimene !12_S
26219	klassist	klassi	klass	22_S	SgEl	et	klassist =klassi  (SgEl  >klass !22_S
26220	tüdrukut	tüdruku	tüdruk	02_S	SgP	et	tüdrukut =tüdruku  (SgP  >tüdruk !02_S
26221	valisin	vali	valima	27_V	IndIpfSg1	et	valisin =vali  (IndIpfSg1  >valima !27_V
26222	minu	minu	mina	00_P	SgG	et	minu =minu  (SgG  >mina !00_P
26229	mõned	mõne	mõni	20_P	PlN	et	mõned =mõne  (PlN  >mõni !20_P
26230	romantiline	romantiline	romantiline	12_A	SgN	et	romantiline =romantiline  (SgN  >romantiline !12_A
26232	eksootilises	eksootilise	eksootiline	12_A	SgIn	et	eksootilises =eksootilise  (SgIn  >eksootiline !12_A
26234	iidse	iidse	iidne	02_A	SgG	et	iidse =iidse  (SgG  >iidne !02_A
26238	loojangut	loojangu	loojang	02_S	SgP	et	loojangut =loojangu  (SgP  >loojang !02_S
26251	läksin	läk	minema	36_V	IndIpfSg1	et	läksin =läk  (IndIpfSg1  >minema !36_V
26256	suurt	suur	suur	13_A	SgP	et	suurt =suur  (SgP  >suur !13_A
26267	pealkiri	kiri	peal+kiri	24_S	SgN	et	pealkiri =kiri  (SgN  >peal+kiri !24_S
26272	õpilasele	õpilase	õpilane	12_S	SgAll	et	õpilasele =õpilase  (SgAll  >õpilane !12_S
26282	infot	info	info	16_S	SgP	et	infot =info  (SgP  >info !16_S
26288	perele	pere	pere	16_S	SgAll	et	perele =pere  (SgAll  >pere !16_S
26289	võimalus	võimalus	võimalus	11_S	SgN	et	võimalus =võimalus  (SgN  >võimalus !11_S
26290	uus	uus	uus	14_A	SgN	et	uus =uus  (SgN  >uus !14_A
26295	nägi	näg	nägema	28_V	IndIpfSg3	et	nägi =näg  (IndIpfSg3  >nägema !28_V
26298	otsitakse	otsi	otsima	28_V	IndPrIps	et	otsitakse =otsi  (IndPrIps  >otsima !28_V
26309	jõuda	jõud	jõudma	34_V	Inf	et	jõuda =jõud  (Inf  >jõudma !34_V
26311	olin	ol	olema	36_V	IndIpfSg1	et	olin =ol  (IndIpfSg1  >olema !36_V
26315	korraliku	korraliku	korralik	25_A	SgG	et	korraliku =korraliku  (SgG  >korralik !25_A
26319	lendama	lenda	lendama	29_V	Sup	et	lendama =lenda  (Sup  >lendama !29_V
26327	võttis	võtt	võtma	35_V	IndIpfSg3	et	võttis =võtt  (IndIpfSg3  >võtma !35_V
26338	eestlased	eestlase	eestlane	12?10_S	PlN	et	eestlased =eestlase  (PlN  >eestlane !12?10_S
26344	mõni	mõni	mõni	20_P	SgN	et	mõni =mõni  (SgN  >mõni !20_P
26346	õpetatakse	õpeta	õpetama	27_V	IndPrIps	et	õpetatakse =õpeta  (IndPrIps  >õpetama !27_V
26347	veidi	veidi	veidi	41_D	ID	et	veidi =veidi  (ID  >veidi !41_D
26352	õpivad	õpi	õppima	28_V	IndPrPl3	et	õpivad =õpi  (IndPrPl3  >õppima !28_V
26358	uued	uue	uus	14_A	PlN	et	uued =uue  (PlN  >uus !14_A
26361	tooma	too	tooma	38_V	Sup	et	tooma =too  (Sup  >tooma !38_V
26362	praegu	praegu	praegu	41_D	ID	et	praegu =praegu  (ID  >praegu !41_D
26367	harjutan	harjuta	harjutama	27_V	IndPrSg1	et	harjutan =harjuta  (IndPrSg1  >harjutama !27_V
26380	igaüks	üks	iga+üks	22_P	SgN	et	igaüks =üks  (SgN  >iga+üks !22_P
26381	teeb	tee	tegema	28_V	IndPrSg3	et	teeb =tee  (IndPrSg3  >tegema !28_V
26383	meesteid	te	mees+tee	26_S	PlP	et	meesteid =te  (PlP  >mees+tee !26_S
26390	võima	või	võima	37_V	Sup	et	võima =või  (Sup  >võima !37_V
26394	tohtima	tohti	tohtima	28_V	Sup	et	tohtima =tohti  (Sup  >tohtima !28_V
26399	puhkama	puhka	puhkama	29_V	Sup	et	puhkama =puhka  (Sup  >puhkama !29_V
26402	tänapäev	päev	täna+päev	22_S	SgN	et	tänapäev =päev  (SgN  >täna+päev !22_S
26404	aparaat	aparaat	aparaat	22_S	SgN	et	aparaat =aparaat  (SgN  >aparaat !22_S
26406	elama	ela	elama	27_V	Sup	et	elama =ela  (Sup  >elama !27_V
26410	pühapäev	päev	püha+päev	22_S	SgN	et	pühapäev =päev  (SgN  >püha+päev !22_S
26413	segama	sega	segama	27_V	Sup	et	segama =sega  (Sup  >segama !27_V
26415	pahandab	pahanda	pahandama	27_V	IndPrSg3	et	pahandab =pahanda  (IndPrSg3  >pahandama !27_V
26423	nõuded	nõude	nõue	06_S	PlN	et	nõuded =nõude  (PlN  >nõue !06_S
26425	arvasin	arva	arvama	29_V	IndIpfSg1	et	arvasin =arva  (IndIpfSg1  >arvama !29_V
26433	haigestuda	haigestu	haigestuma	27_V	Inf	et	haigestuda =haigestu  (Inf  >haigestuma !27_V
26436	töökoht	koht	töö+koht	22_S	SgN	et	töökoht =koht  (SgN  >töö+koht !22_S
26441	muudatustega	muudatus	muudatus	11_S	PlKom	et	muudatustega =muudatus  (PlKom  >muudatus !11_S
26449	külmal	külma	külm	22_AS	SgAd	et	külmal =külma  (SgAd  >külm !22_AS
26454	täitke	täit	täitma	34_V	ImpPrPl2	et	täitke =täit  (ImpPrPl2  >täitma !34_V
26474	seda	se	see	00_P	SgP	et	seda =se  (SgP  >see !00_P
26476	tuldi	tul	tulema	36_V	IndIpfIps	et	tuldi =tul  (IndIpfIps  >tulema !36_V
26485	sportis	sporti	sportima	28_V	IndIpfSg3	et	sportis =sporti  (IndIpfSg3  >sportima !28_V
26486	ilusate	ilusa	ilus	02_A	PlG	et	ilusate =ilusa  (PlG  >ilus !02_A
26489	muudatusi	muudatusi	muudatus	11_S	PlP	et	muudatusi =muudatusi  (PlP  >muudatus !11_S
26491	külasse	küla	küla	17_S	SgIll	et	külasse =küla  (SgIll  >küla !17_S
26492	hoos	hoo	hoog	22_S	SgIn	et	hoos =hoo  (SgIn  >hoog !22_S
26495	saadetakse	saade	saatma	34_V	IndPrIps	et	saadetakse =saade  (IndPrIps  >saatma !34_V
26223	sõbrad	sõbra	sõber	24_S	PlN	et	sõbrad =sõbra  (PlN  >sõber !24_S
26225	istume	istu	istuma	28_V	IndPrPl1	et	istume =istu  (IndPrPl1  >istuma !28_V
26228	omamoodi	omamoodi	oma+moodi	41_DA	ID	et	omamoodi =omamoodi  (ID  >oma+moodi !41_DA
26237	inimesega	inimese	inimene	12_S	SgKom	et	inimesega =inimese  (SgKom  >inimene !12_S
26243	mitte	mitte	mitte	41_D	ID	et	mitte =mitte  (ID  >mitte !41_D
26253	nägin	näg	nägema	28_V	IndIpfSg1	et	nägin =näg  (IndIpfSg1  >nägema !28_V
26255	aknal	akna	aken	08_S	SgAd	et	aknal =akna  (SgAd  >aken !08_S
26259	kaasaegne	aegne	kaas+aegne	02_A	SgN	et	kaasaegne =aegne  (SgN  >kaas+aegne !02_A
26261	igasugulased	sugulase	iga+sugulane	12_S	PlN	et	igasugulased =sugulase  (PlN  >iga+sugulane !12_S
26263	millised	millise	milline	10_P	PlN	et	millised =millise  (PlN  >milline !10_P
26264	kasuliku	kasuliku	kasulik	25_A	SgG	et	kasuliku =kasuliku  (SgG  >kasulik !25_A
26268	arvutipood	pood	arvuti+pood	22_S	SgN	et	arvutipood =pood  (SgN  >arvuti+pood !22_S
26278	kontakttelefon	telefon	kontakt+telefon	19_S	SgN	et	kontakttelefon =telefon  (SgN  >kontakt+telefon !19_S
26279	need	nee	see	00_P	PlN	et	need =nee  (PlN  >see !00_P
26283	inter	inter	inter	02_S	SgN	et	inter =inter  (SgN  >inter !02_S
26284	arvan	arva	arvama	29_V	IndPrSg1	et	arvan =arva  (IndPrSg1  >arvama !29_V
26286	kasulik	kasulik	kasulik	25_A	SgN	et	kasulik =kasulik  (SgN  >kasulik !25_A
26293	naine	naine	naine	12_S	SgN	et	naine =naine  (SgN  >naine !12_S
26300	konkurss	konkurss	konkurss	22_S	SgN	et	konkurss =konkurss  (SgN  >konkurss !22_S
26303	üle	üle	üle	41_DK	ID	et	üle =üle  (ID  >üle !41_DK
26314	vastu	vastu	vastu	41_DK	ID	et	vastu =vastu  (ID  >vastu !41_DK
26317	maaliti	maali	maalima	28_V	IndIpfIps	et	maaliti =maali  (IndIpfIps  >maalima !28_V
26320	lind	lind	lind	22_S	SgN	et	lind =lind  (SgN  >lind !22_S
26329	kartuleid	kartule	kartul	02_S	PlP	et	kartuleid =kartule  (PlP  >kartul !02_S
26332	kartul	kartul	kartul	02_S	SgN	et	kartul =kartul  (SgN  >kartul !02_S
26340	kuidagi	kuidagi	kuidagi	41_D	ID	et	kuidagi =kuidagi  (ID  >kuidagi !41_D
26348	inimene	inimene	inimene	12_S	SgN	et	inimene =inimene  (SgN  >inimene !12_S
26351	sõnul	sõnu	sõna	17_S	PlAd	et	sõnul =sõnu  (PlAd  >sõna !17_S
26363	päevad	päeva	päev	22_S	PlN	et	päevad =päeva  (PlN  >päev !22_S
26372	naerab	naera	naerma	33_V	IndPrSg3	et	naerab =naera  (IndPrSg3  >naerma !33_V
26373	valmistuma	valmistu	valmistuma	27_V	Sup	et	valmistuma =valmistu  (Sup  >valmistuma !27_V
26376	laused	lause	lause	06_S	PlN	et	laused =lause  (PlN  >lause !06_S
26379	mehed	mehe	mees	13_S	PlN	et	mehed =mehe  (PlN  >mees !13_S
26382	naisi	naisi	naine	12_S	PlP	et	naisi =naisi  (PlP  >naine !12_S
26403	nii	nii	nii	41_D	ID	et	nii =nii  (ID  >nii !41_D
26405	hingama	hinga	hingama	29_V	Sup	et	hingama =hinga  (Sup  >hingama !29_V
26414	lõunasöök	söök	lõuna+söök	22_S	SgN	et	lõunasöök =söök  (SgN  >lõuna+söök !22_S
26416	aeg	aeg	aeg	22_S	SgN	et	aeg =aeg  (SgN  >aeg !22_S
26418	varahommiku	hommiku	vara+hommik	02_S	SgG	et	varahommiku =hommiku  (SgG  >vara+hommik !02_S
26426	sport	sport	sport	22_S	SgN	et	sport =sport  (SgN  >sport !22_S
26432	oht	oht	oht	22_S	SgN	et	oht =oht  (SgN  >oht !22_S
26435	tüdinesin	tüdine	tüdinema	27_V	IndIpfSg1	et	tüdinesin =tüdine  (IndIpfSg1  >tüdinema !27_V
26439	piirdusime	piirdu	piirduma	27_V	IndIpfPl1	et	piirdusime =piirdu  (IndIpfPl1  >piirduma !27_V
26446	kleepus	kleepu	kleepuma	27_V	IndIpfSg3	et	kleepus =kleepu  (IndIpfSg3  >kleepuma !27_V
26451	tunnen	tunne	tundma	34_V	IndPrSg1	et	tunnen =tunne  (IndPrSg1  >tundma !34_V
26453	lüngad	lünga	lünk	22_S	PlN	et	lüngad =lünga  (PlN  >lünk !22_S
26455	sidenditega	sidendi	sidend	02_S	PlKom	et	sidenditega =sidendi  (PlKom  >sidend !02_S
26457	just	just	just	41_D	ID	et	just =just  (ID  >just !41_D
26459	hoopis	hoopis	hoopis	41_D	ID	et	hoopis =hoopis  (ID  >hoopis !41_D
26464	baaris	baari	baar	22_S	SgIn	et	baaris =baari  (SgIn  >baar !22_S
26467	kas	kas	kas	41_D	ID	et	kas =kas  (ID  >kas !41_D
26479	sojad	soja	soja	17_S	PlN	et	sojad =soja  (PlN  >soja !17_S
26483	pinget	pinge	pinge	06_S	SgP	et	pinget =pinge  (SgP  >pinge !06_S
26488	autode	auto	auto	16_S	PlG	et	autode =auto  (PlG  >auto !16_S
26503	telesaate	saate	tele+saade	06_S	SgG	et	telesaate =saate  (SgG  >tele+saade !06_S
26505	autosid	auto	auto	16_S	PlP	et	autosid =auto  (PlP  >auto !16_S
26509	püksidesse	püksi	püks	22_S	PlIll	et	püksidesse =püksi  (PlIll  >püks !22_S
26514	algab	alga	algama	29_V	IndPrSg3	et	algab =alga  (IndPrSg3  >algama !29_V
26224	klassis	klassi	klass	22_S	SgIn	et	klassis =klassi  (SgIn  >klass !22_S
26226	võib	või	võima	37_V	IndPrSg3	et	võib =või  (IndPrSg3  >võima !37_V
26235	inimesele	inimese	inimene	12_S	SgAll	et	inimesele =inimese  (SgAll  >inimene !12_S
26239	jalutada	jaluta	jalutama	27_V	Inf	et	jalutada =jaluta  (Inf  >jalutama !27_V
26247	inimesel	inimese	inimene	12_S	SgAd	et	inimesel =inimese  (SgAd  >inimene !12_S
26249	elamusi	elamusi	elamus	11_S	PlP	et	elamusi =elamusi  (PlP  >elamus !11_S
26250	esmaspäeval	päeva	esmas+päev	22_S	SgAd	et	esmaspäeval =päeva  (SgAd  >esmas+päev !22_S
26254	kauplus	kauplus	kauplus	11~09_S	SgN	et	kauplus =kauplus  (SgN  >kauplus !11~09_S
26257	plakatit	plakati	plakat	02_S	SgP	et	plakatit =plakati  (SgP  >plakat !02_S
26265	töötab	tööta	töötama	27_V	IndPrSg3	et	töötab =tööta  (IndPrSg3  >töötama !27_V
26269	mikromaailm	ilm	mikro+maa+ilm	22_S	SgN	et	mikromaailm =ilm  (SgN  >mikro+maa+ilm !22_S
26275	ka	ka	ka	41_D	ID	et	ka =ka  (ID  >ka !41_D
26281	leida	leid	leidma	34_V	Inf	et	leida =leid  (Inf  >leidma !34_V
26287	teha	teh	tegema	28_V	Inf	et	teha =teh  (Inf  >tegema !28_V
26294	nägema	näge	nägema	28_V	Sup	et	nägema =näge  (Sup  >nägema !28_V
26297	külas	küla	küla	17_S	SgIn	et	külas =küla  (SgIn  >küla !17_S
26301	juba	juba	juba	41_D	ID	et	juba =juba  (ID  >juba !41_D
26310	üsna	üsna	üsna	41_D	ID	et	üsna =üsna  (ID  >üsna !41_D
26318	pilt	pilt	pilt	22_S	SgN	et	pilt =pilt  (SgN  >pilt !22_S
26333	salv	salv	salv	22_S	SgN	et	salv =salv  (SgN  >salv !22_S
26335	täie	täie	täis	14_AS	SgG	et	täie =täie  (SgG  >täis !14_AS
26343	vaid	vaid	vaid	41_JD	ID	et	vaid =vaid  (ID  >vaid !41_JD
26357	saatma	saat	saatma	34_V	Sup	et	saatma =saat  (Sup  >saatma !34_V
26359	õpikud	õpiku	õpik	02_S	PlN	et	õpikud =õpiku  (PlN  >õpik !02_S
26364	soojad	sooja	soe	24_AS	PlN	et	soojad =sooja  (PlN  >soe !24_AS
26365	jahe	jahe	jahe	02_AS	SgN	et	jahe =jahe  (SgN  >jahe !02_AS
26369	ostan	osta	ostma	34_V	IndPrSg1	et	ostan =osta  (IndPrSg1  >ostma !34_V
26370	külapood	pood	küla+pood	22_S	SgN	et	külapood =pood  (SgN  >küla+pood !22_S
26378	naised	naise	naine	12_S	PlN	et	naised =naise  (PlN  >naine !12_S
26385	paras	paras	paras	02_A	SgN	et	paras =paras  (SgN  >paras !02_A
26387	panema	pane	panema	36_V	Sup	et	panema =pane  (Sup  >panema !36_V
26389	lisakoormus	koormus	lisa+koormus	11~09_S	SgN	et	lisakoormus =koormus  (SgN  >lisa+koormus !11~09_S
26407	elada	ela	elama	27_V	Inf	et	elada =ela  (Inf  >elama !27_V
26408	telefonihelin	helin	telefoni+helin	02_S	SgN	et	telefonihelin =helin  (SgN  >telefoni+helin !02_S
26412	uni	uni	uni	20_S	SgN	et	uni =uni  (SgN  >uni !20_S
26420	lõunasöögi	söögi	lõuna+söök	22_S	SgG	et	lõunasöögi =söögi  (SgG  >lõuna+söök !22_S
26422	artikli	artikli	artikkel	02_S	SgG	et	artikli =artikli  (SgG  >artikkel !02_S
26430	kiirtele	kiir	kiir	13_S	PlAll	et	kiirtele =kiir  (PlAll  >kiir !13_S
26440	muudatused	muudatuse	muudatus	11_S	PlN	et	muudatused =muudatuse  (PlN  >muudatus !11_S
26445	närimiskumm	kumm	närimis+kumm	22_S	SgN	et	närimiskumm =kumm  (SgN  >närimis+kumm !22_S
26460	teatrisse	teatri	teater	02_S	SgIll	et	teatrisse =teatri  (SgIll  >teater !02_S
26462	siis	siis	siis	41_D	ID	et	siis =siis  (ID  >siis !41_D
26472	test	test	test	22_S	SgN	et	test =test  (SgN  >test !22_S
26478	karta	kart	kartma	34_V	Inf	et	karta =kart  (Inf  >kartma !34_V
26482	ülekoormusel	koormuse	üle+koormus	11~09_S	SgAd	et	ülekoormusel =koormuse  (SgAd  >üle+koormus !11~09_S
26494	mõnd	mõn	mõni	20_P	SgP	et	mõnd =mõn  (SgP  >mõni !20_P
26497	igaüht	üht	iga+üks	22_P	SgP	et	igaüht =üht  (SgP  >iga+üks !22_P
26498	tagajärjeks	järje	taga+järg	22_S	SgTr	et	tagajärjeks =järje  (SgTr  >taga+järg !22_S
26500	tänapäevaks	päeva	täna+päev	22_S	SgTr	et	tänapäevaks =päeva  (SgTr  >täna+päev !22_S
26502	varahommikul	hommiku	vara+hommik	02_S	SgAd	et	varahommikul =hommiku  (SgAd  >vara+hommik !02_S
26516	mõnega	mõne	mõni	20_P	SgKom	et	mõnega =mõne  (SgKom  >mõni !20_P
26518	naiseks	naise	naine	12_S	SgTr	et	naiseks =naise  (SgTr  >naine !12_S
26519	autodeks	auto	auto	16_S	PlTr	et	autodeks =auto  (PlTr  >auto !16_S
26528	milline	milline	milline	10_P	SgN	et	milline =milline  (SgN  >milline !10_P
26529	tal	ta	ta	00_P	SgAd	et	tal =ta  (SgAd  >ta !00_P
26530	nüüdisajal	aja	nüüdis+aeg	22_S	SgAd	et	nüüdisajal =aja  (SgAd  >nüüdis+aeg !22_S
26537	peaaegu	peaaegu	pea+aegu	41_D	ID	et	peaaegu =peaaegu  (ID  >pea+aegu !41_D
26538	teatrites	teatri	teater	02_S	PlIn	et	teatrites =teatri  (PlIn  >teater !02_S
26539	majas	maja	maja	17_S	SgIn	et	majas =maja  (SgIn  >maja !17_S
26227	olla	oll	olema	36_V	Inf	et	olla =oll  (Inf  >olema !36_V
26236	reisida	reisi	reisima	28_V	Inf	et	reisida =reisi  (Inf  >reisima !28_V
26241	kaldal	kalda	kallas	07_S	SgAd	et	kaldal =kalda  (SgAd  >kallas !07_S
26244	reisil	reisi	reis	22_S	SgAd	et	reisil =reisi  (SgAd  >reis !22_S
26245	võimalused	võimaluse	võimalus	11_S	PlN	et	võimalused =võimaluse  (PlN  >võimalus !11_S
26252	kodusse	kodu	kodu	17_S	SgIll	et	kodusse =kodu  (SgIll  >kodu !17_S
26262	asjad	asja	asi	24_S	PlN	et	asjad =asja  (PlN  >asi !24_S
26273	ülikooliõpilasele	õpilase	üli+kooli+õpilane	12_S	SgAll	et	ülikooliõpilasele =õpilase  (SgAll  >üli+kooli+õpilane !12_S
26276	sul	su	sa	00_P	SgAd	et	sul =su  (SgAd  >sa !00_P
26280	tahavad	taha	tahtma	34_V	IndPrPl3	et	tahavad =taha  (IndPrPl3  >tahtma !34_V
26292	ettevõtlik	võtlik	ette+võtlik	25_A	SgN	et	ettevõtlik =võtlik  (SgN  >ette+võtlik !25_A
26296	ajalehes	lehe	aja+leht	22_S	SgIn	et	ajalehes =lehe  (SgIn  >aja+leht !22_S
26304	nädalat	nädala	nädal	02_S	SgP	et	nädalat =nädala  (SgP  >nädal !02_S
26305	õpetama	õpeta	õpetama	27_V	Sup	et	õpetama =õpeta  (Sup  >õpetama !27_V
26307	tundis	tund	tundma	34_V	IndIpfSg3	et	tundis =tund  (IndIpfSg3  >tundma !34_V
26308	jõudma	jõud	jõudma	34_V	Sup	et	jõudma =jõud  (Sup  >jõudma !34_V
26312	üllatuma	üllatu	üllatuma	27_V	Sup	et	üllatuma =üllatu  (Sup  >üllatuma !27_V
26321	ega	ega	ega	41_JD	ID	et	ega =ega  (ID  >ega !41_JD
26324	polnud	pol	olema	36_V	IndIpfPsN	et	polnud =pol  (IndIpfPsN  >olema !36_V
26325	algama	alga	algama	29_V	Sup	et	algama =alga  (Sup  >algama !29_V
26328	kartulivõtt	võtt	kartuli+võtt	22_S	SgN	et	kartulivõtt =võtt  (SgN  >kartuli+võtt !22_S
26330	sügisel	sügise	sügis	09_S	SgAd	et	sügisel =sügise  (SgAd  >sügis !09_S
26331	ettevõtmine	võtmine	ette+võtmine	12?10_S	SgN	et	ettevõtmine =võtmine  (SgN  >ette+võtmine !12?10_S
26334	käib	käi	käima	38_V	IndPrSg3	et	käib =käi  (IndPrSg3  >käima !38_V
26337	hoog	hoog	hoog	22_S	SgN	et	hoog =hoog  (SgN  >hoog !22_S
26342	aktsent	aktsent	aktsent	22_S	SgN	et	aktsent =aktsent  (SgN  >aktsent !22_S
26345	ained	aine	aine	06_S	PlN	et	ained =aine  (PlN  >aine !06_S
26350	rääkida	rääki	rääkima	28_V	Inf	et	rääkida =rääki  (Inf  >rääkima !28_V
26353	lapsed	lapse	laps	14_S	PlN	et	lapsed =lapse  (PlN  >laps !14_S
26354	raamatuid	raamatu	raamat	02_S	PlP	et	raamatuid =raamatu  (PlP  >raamat !02_S
26360	kartma	kart	kartma	34_V	Sup	et	kartma =kart  (Sup  >kartma !34_V
26377	kasutades	kasuta	kasutama	27_V	Ger	et	kasutades =kasuta  (Ger  >kasutama !27_V
26384	igaükse	ükse	iga+üks	22_P	PlP	et	igaükse =ükse  (PlP  >iga+üks !22_P
26386	stress	stress	stress	22_S	SgN	et	stress =stress  (SgN  >stress !22_S
26388	tegutsema	tegutse	tegutsema	27_V	Sup	et	tegutsema =tegutse  (Sup  >tegutsema !27_V
26395	laskma	lask	laskma	34_V	Sup	et	laskma =lask  (Sup  >laskma !34_V
26397	tekkima	tekki	tekkima	27~28_V	Sup	et	tekkima =tekki  (Sup  >tekkima !27~28_V
26398	maandama	maanda	maandama	27_V	Sup	et	maandama =maanda  (Sup  >maandama !27_V
26400	tekkida	tekki	tekkima	27~28_V	Inf	et	tekkida =tekki  (Inf  >tekkima !27~28_V
26409	katkestama	katkesta	katkestama	27_V	Sup	et	katkestama =katkesta  (Sup  >katkestama !27_V
26417	katkestab	katkesta	katkestama	27_V	IndPrSg3	et	katkestab =katkesta  (IndPrSg3  >katkestama !27_V
26424	nõudeid	nõude	nõue	06_S	PlP	et	nõudeid =nõude  (PlP  >nõue !06_S
26434	difteeriaga	difteeria	difteeria	01_S	SgKom	et	difteeriaga =difteeria  (SgKom  >difteeria !01_S
26438	kiiresti	kiiresti	kiiresti	41_D	ID	et	kiiresti =kiiresti  (ID  >kiiresti !41_D
26443	teine	teine	teine	12_OP	SgN	et	teine =teine  (SgN  >teine !12_OP
26444	valdkond	valdkond	valdkond	22_S	SgN	et	valdkond =valdkond  (SgN  >valdkond !22_S
26448	pükstele	püks	püks	23_S	PlAll	et	pükstele =püks  (PlAll  >püks !23_S
26450	hoiduma	hoidu	hoiduma	27_V	Sup	et	hoiduma =hoidu  (Sup  >hoiduma !27_V
26461	lõpetage	lõpeta	lõpetama	27_V	ImpPrPl2	et	lõpetage =lõpeta  (ImpPrPl2  >lõpetama !27_V
26463	jalutama	jaluta	jalutama	27_V	Sup	et	jalutama =jaluta  (Sup  >jalutama !27_V
26468	sõidad	sõida	sõitma	34_V	IndPrSg2	et	sõidad =sõida  (IndPrSg2  >sõitma !34_V
26470	ukse	ukse	uks	14_S	SgG	et	ukse =ukse  (SgG  >uks !14_S
26475	õpetamas	õpeta	õpetama	27_V	SupIn	et	õpetamas =õpeta  (SupIn  >õpetama !27_V
26477	võtis	võti	võtt	22_S	SgIn	et	võtis =võti  (SgIn  >võtt !22_S
26481	mehe	mehe	mees	13_S	SgG	et	mehe =mehe  (SgG  >mees !13_S
26484	tänapäeval	päeva	täna+päev	22_S	SgAd	et	tänapäeval =päeva  (SgAd  >täna+päev !22_S
26490	kaua	kaua	kaua	41_D	ID	et	kaua =kaua  (ID  >kaua !41_D
26496	mehi	mehi	mees	13_S	PlP	et	mehi =mehi  (PlP  >mees !13_S
26231	sa	sa	sa	00_P	SgN	et	sa =sa  (SgN  >sa !00_P
26233	hulkuda	hulku	hulkuma	28_V	Inf	et	hulkuda =hulku  (Inf  >hulkuma !28_V
26240	mere	mere	meri	20_S	SgG	et	mere =mere  (SgG  >meri !20_S
26242	igal	iga	iga	17_P	SgAd	et	igal =iga  (SgAd  >iga !17_P
26246	kokkuvõttes	võtte	kokku+võte	06_S	SgIn	et	kokkuvõttes =võtte  (SgIn  >kokku+võte !06_S
26248	uusi	uus	uus	14_A	PlP	et	uusi =uus  (PlP  >uus !14_A
26258	plakatil	plakati	plakat	02_S	SgAd	et	plakatil =plakati  (SgAd  >plakat !02_S
26260	printer	printer	printer	02_S	SgN	et	printer =printer  (SgN  >printer !02_S
26266	reklaamil	reklaami	reklaam	22_S	SgAd	et	reklaamil =reklaami  (SgAd  >reklaam !22_S
26270	inimestele	inimes	inimene	12_S	PlAll	et	inimestele =inimes  (PlAll  >inimene !12_S
26271	ostavad	osta	ostma	34_V	IndPrPl3	et	ostavad =osta  (IndPrPl3  >ostma !34_V
26274	kuni	kuni	kuni	41_JK	ID	et	kuni =kuni  (ID  >kuni !41_JK
26277	asub	asu	asuma	27_V	IndPrSg3	et	asub =asu  (IndPrSg3  >asuma !27_V
26285	reklaam	reklaam	reklaam	22_S	SgN	et	reklaam =reklaam  (SgN  >reklaam !22_S
26291	õigesse	õige	õige	01_A	SgIll	et	õigesse =õige  (SgIll  >õige !01_A
26299	võitis	võit	võitma	34_V	IndIpfSg3	et	võitis =võit  (IndIpfSg3  >võitma !34_V
26302	nädal	nädal	nädal	02_S	SgN	et	nädal =nädal  (SgN  >nädal !02_S
26306	õpetab	õpeta	õpetama	27_V	IndPrSg3	et	õpetab =õpeta  (IndPrSg3  >õpetama !27_V
26313	korralik	korralik	korralik	25_A	SgN	et	korralik =korralik  (SgN  >korralik !25_A
26316	audiga	audi	aut	22_S	SgKom	et	audiga =audi  (SgKom  >aut !22_S
26322	noor	noor	noor	13_AS	SgN	et	noor =noor  (SgN  >noor !13_AS
26323	jõudis	jõud	jõudma	34_V	IndIpfSg3	et	jõudis =jõud  (IndIpfSg3  >jõudma !34_V
26326	võtma	võt	võtma	35_V	Sup	et	võtma =võt  (Sup  >võtma !35_V
26336	siinsed	siinse	siinne	02_A	PlN	et	siinsed =siinse  (PlN  >siinne !02_A
26339	räägivad	räägi	rääkima	28_V	IndPrPl3	et	räägivad =räägi  (IndPrPl3  >rääkima !28_V
26341	teistmoodi	teistmoodi	teist+moodi	41_DA	ID	et	teistmoodi =teistmoodi  (ID  >teist+moodi !41_DA
26349	saab	saa	saama	37_V	IndPrSg3	et	saab =saa  (IndPrSg3  >saama !37_V
26355	varsti	varsti	varsti	41_D	ID	et	varsti =varsti  (ID  >varsti !41_D
26356	eestist	eesti	eesti	16_H	SgEl	et	eestist =eesti  (SgEl  >eesti !16_H
26366	jahedad	jaheda	jahe	02_AS	PlN	et	jahedad =jaheda  (PlN  >jahe !02_AS
26368	suure	suure	suur	13_A	SgG	et	suure =suure  (SgG  >suur !13_A
26371	müüdagi	müü	müüma	38_V	IndPrIps_^	et	müüdagi =müü  (IndPrIps_^  >müüma !38_V
26374	moodustage	moodusta	moodustama	27_V	ImpPrPl2	et	moodustage =moodusta  (ImpPrPl2  >moodustama !27_V
26375	sõnadest	sõna	sõna	17_S	PlEl	et	sõnadest =sõna  (PlEl  >sõna !17_S
26391	tagajärg	järg	taga+järg	22_S	SgN	et	tagajärg =järg  (SgN  >taga+järg !22_S
26392	paneb	pane	panema	36_V	IndPrSg3	et	paneb =pane  (IndPrSg3  >panema !36_V
26393	tuua	tuu	tooma	38_V	Inf	et	tuua =tuu  (Inf  >tooma !38_V
26396	ülekoormus	koormus	üle+koormus	11~09_S	SgN	et	ülekoormus =koormus  (SgN  >üle+koormus !11~09_S
26401	telefon	telefon	telefon	19_S	SgN	et	telefon =telefon  (SgN  >telefon !19_S
26411	varahommik	hommik	vara+hommik	02_S	SgN	et	varahommik =hommik  (SgN  >vara+hommik !02_S
26419	segab	sega	segama	27_V	IndPrSg3	et	segab =sega  (IndPrSg3  >segama !27_V
26421	kohandasin	kohanda	kohandama	27_V	IndIpfSg1	et	kohandasin =kohanda  (IndIpfSg1  >kohandama !27_V
26427	tunned	tunne	tundma	34_V	IndPrSg2	et	tunned =tunne  (IndPrSg2  >tundma !34_V
26428	autod	auto	auto	16_S	PlN	et	autod =auto  (PlN  >auto !16_S
26429	naistele	nais	naine	12_S	PlAll	et	naistele =nais  (PlAll  >naine !12_S
26431	autodele	auto	auto	16_S	PlAll	et	autodele =auto  (PlAll  >auto !16_S
26437	uue	uue	uus	14_A	SgG	et	uue =uue  (SgG  >uus !14_A
26442	kuulub	kuulu	kuuluma	27_V	IndPrSg3	et	kuulub =kuulu  (IndPrSg3  >kuuluma !27_V
26447	püksid	püksi	püks	23?22_S	PlN	et	püksid =püksi  (PlN  >püks !23?22_S
26452	päike	päike	päike	12?10_S	SgN	et	päike =päike  (SgN  >päike !12?10_S
26456	paluti	palu	paluma	27_V	IndIpfIps	et	paluti =palu  (IndIpfIps  >paluma !27_V
26458	läheb	lähe	minema	36_V	IndPrSg3	et	läheb =lähe  (IndPrSg3  >minema !36_V
26465	suitsetada	suitseta	suitsetama	27_V	Inf	et	suitsetada =suitseta  (Inf  >suitsetama !27_V
26466	tarbida	tarbi	tarbima	27_V	Inf	et	tarbida =tarbi  (Inf  >tarbima !27_V
26469	avasin	ava	avama	27_V	IndIpfSg1	et	avasin =ava  (IndIpfSg1  >avama !27_V
26471	kuulsin	kuul	kuulma	33_V	IndIpfSg1	et	kuulsin =kuul  (IndIpfSg1  >kuulma !33_V
26473	nädala	nädala	nädal	02_S	SgG	et	nädala =nädala  (SgG  >nädal !02_S
26480	naise	naise	naine	12_S	SgG	et	naise =naise  (SgG  >naine !12_S
26487	naiste	nais	naine	12_S	PlG	et	naiste =nais  (PlG  >naine !12_S
26493	aktsendiga	aktsendi	aktsent	22_S	SgKom	et	aktsendiga =aktsendi  (SgKom  >aktsent !22_S
26499	maandada	maanda	maandama	27_V	Inf	et	maandada =maanda  (Inf  >maandama !27_V
26501	pühapäeval	päeva	püha+päev	22_S	SgAd	et	pühapäeval =päeva  (SgAd  >püha+päev !22_S
26504	ilusaid	ilusa	ilus	02_A	PlP	et	ilusaid =ilusa  (PlP  >ilus !02_A
26508	pükside	püksi	püks	22_S	PlG	et	pükside =püksi  (PlG  >püks !22_S
26511	naa	naa	naa	41_D	ID	et	naa =naa  (ID  >naa !41_D
26517	hingab	hinga	hingama	29_V	IndPrSg3	et	hingab =hinga  (IndPrSg3  >hingama !29_V
26532	vajalik	vajalik	vajalik	25_A	SgN	et	vajalik =vajalik  (SgN  >vajalik !25_A
26536	ööklubid	klubi	öö+klubi	17_S	PlN	et	ööklubid =klubi  (PlN  >öö+klubi !17_S
26540	naaber	naaber	naaber	02_S	SgN	et	naaber =naaber  (SgN  >naaber !02_S
26545	otsustasin	otsusta	otsustama	27_V	IndIpfSg1	et	otsustasin =otsusta  (IndIpfSg1  >otsustama !27_V
26564	praeguse	praeguse	praegune	10~12_A	SgG	et	praeguse =praeguse  (SgG  >praegune !10~12_A
26571	tekkis	tekki	tekkima	27~28_V	IndIpfSg3	et	tekkis =tekki  (IndIpfSg3  >tekkima !27~28_V
26577	novembril	novembri	november	02_S	SgAd	et	novembril =novembri  (SgAd  >november !02_S
26579	sinna	sinna	sinna	41_D	ID	et	sinna =sinna  (ID  >sinna !41_D
26589	neljakordne	kordne	nelja+kordne	02_AS	SgN	et	neljakordne =kordne  (SgN  >nelja+kordne !02_AS
26591	territooriumil	territooriumi	territoorium	19~02_S	SgAd	et	territooriumil =territooriumi  (SgAd  >territoorium !19~02_S
26593	mõisa	mõisa	mõis	02_S	SgG	et	mõisa =mõisa  (SgG  >mõis !02_S
26603	viiakse	vii	viima	38_V	IndPrIps	et	viiakse =vii  (IndPrIps  >viima !38_V
26605	andmed	andme	anne	05_S	PlN	et	andmed =andme  (PlN  >anne !05_S
26620	rajati	raja	rajama	27_V	IndIpfIps	et	rajati =raja  (IndIpfIps  >rajama !27_V
26626	arheoloog	arheoloog	arheoloog	22_S	SgN	et	arheoloog =arheoloog  (SgN  >arheoloog !22_S
26628	ärkas	ärka	ärkama	29_V	IndIpfSg3	et	ärkas =ärka  (IndIpfSg3  >ärkama !29_V
26634	viibis	viibi	viibima	27_V	IndIpfSg3	et	viibis =viibi  (IndIpfSg3  >viibima !27_V
26637	mõne	mõne	mõni	20_P	SgG	et	mõne =mõne  (SgG  >mõni !20_P
26642	ehitati	ehita	ehitama	27_V	IndIpfIps	et	ehitati =ehita  (IndIpfIps  >ehitama !27_V
26646	esines	esine	esinema	27_V	IndIpfSg3	et	esines =esine  (IndIpfSg3  >esinema !27_V
26650	kuningliku	kuningliku	kuninglik	25_A	SgG	et	kuningliku =kuningliku  (SgG  >kuninglik !25_A
26655	kurb	kurb	kurb	22_A	SgN	et	kurb =kurb  (SgN  >kurb !22_A
26666	ehk	ehk	ehk	41_JD	ID	et	ehk =ehk  (ID  >ehk !41_JD
26691	vaieldakse	vaiel	vaidlema	30_V	IndPrIps	et	vaieldakse =vaiel  (IndPrIps  >vaidlema !30_V
26699	saladuslik	saladuslik	saladuslik	25_A	SgN	et	saladuslik =saladuslik  (SgN  >saladuslik !25_A
26712	ingel	ingel	ingel	02_S	SgN	et	ingel =ingel  (SgN  >ingel !02_S
26719	viinis	viini	viin	22_S	SgIn	et	viinis =viini  (SgIn  >viin !22_S
26732	heroilised	heroilise	heroiline	12?10_A	PlN	et	heroilised =heroilise  (PlN  >heroiline !12?10_A
26734	mehaaniline	mehaaniline	mehaaniline	12_A	SgN	et	mehaaniline =mehaaniline  (SgN  >mehaaniline !12_A
26737	klaveri	klaveri	klaver	02_S	SgG	et	klaveri =klaveri  (SgG  >klaver !02_S
26739	büstid	büsti	büst	22_S	PlN	et	büstid =büsti  (PlN  >büst !22_S
26741	koopiat	koopia	koopia	01_S	SgP	et	koopiat =koopia  (SgP  >koopia !01_S
26742	mitmesugused	suguse	mitme+sugune	10_A	PlN	et	mitmesugused =suguse  (PlN  >mitme+sugune !10_A
26750	kuivõrd	kuivõrd	kui+võrd	41_D	ID	et	kuivõrd =kuivõrd  (ID  >kui+võrd !41_D
26751	loomingust	loomingu	looming	02_S	SgEl	et	loomingust =loomingu  (SgEl  >looming !02_S
26752	probleemid	probleemi	probleem	22_S	PlN	et	probleemid =probleemi  (PlN  >probleem !22_S
26756	lahutaks	lahuta	lahutama	27_V	KndPrPs	et	lahutaks =lahuta  (KndPrPs  >lahutama !27_V
26761	jaanuaril	jaanuari	jaanuar	19_S	SgAd	et	jaanuaril =jaanuari  (SgAd  >jaanuar !19_S
26765	novembriks	novembri	november	02_S	SgTr	et	novembriks =novembri  (SgTr  >november !02_S
26767	emotsionaalne	emotsionaalne	emotsionaalne	02_A	SgN	et	emotsionaalne =emotsionaalne  (SgN  >emotsionaalne !02_A
26772	suareesid	suaree	suaree	26_S	PlP	et	suareesid =suaree  (PlP  >suaree !26_S
26773	esineb	esine	esinema	27_V	IndPrSg3	et	esineb =esine  (IndPrSg3  >esinema !27_V
26790	perekond	perekond	perekond	22_S	SgN	et	perekond =perekond  (SgN  >perekond !22_S
26798	temale	tema	tema	00_P	SgAll	et	temale =tema  (SgAll  >tema !00_P
26802	tunnistab	tunnista	tunnistama	27_V	IndPrSg3	et	tunnistab =tunnista  (IndPrSg3  >tunnistama !27_V
26806	soon	soon	soon	13_S	SgN	et	soon =soon  (SgN  >soon !13_S
26814	vahetevahel	vahetevahel	vahete+vahel	41_D	ID	et	vahetevahel =vahetevahel  (ID  >vahete+vahel !41_D
26816	ilmub	ilmu	ilmuma	27_V	IndPrSg3	et	ilmub =ilmu  (IndPrSg3  >ilmuma !27_V
26506	difteeriaks	difteeria	difteeria	01_S	SgTr	et	difteeriaks =difteeria  (SgTr  >difteeria !01_S
26512	kuigi	kuigi	kuigi	41_JD	ID	et	kuigi =kuigi  (ID  >kuigi !41_JD
26525	nüüdisaeg	aeg	nüüdis+aeg	22_S	SgN	et	nüüdisaeg =aeg  (SgN  >nüüdis+aeg !22_S
26527	esimesest	esimese	esimene	12_OP	SgEl	et	esimesest =esimese  (SgEl  >esimene !12_OP
26550	minevikus	mineviku	minevik	25_S	SgIn	et	minevikus =mineviku  (SgIn  >minevik !25_S
26551	missugune	sugune	mis+sugune	10_P	SgN	et	missugune =sugune  (SgN  >mis+sugune !10_P
26552	väärtus	väärtus	väärtus	11~09_S	SgN	et	väärtus =väärtus  (SgN  >väärtus !11~09_S
26559	milliseid	millise	milline	10_P	PlP	et	milliseid =millise  (PlP  >milline !10_P
26565	territooriumid	territooriumi	territoorium	19~02_S	PlN	et	territooriumid =territooriumi  (PlN  >territoorium !19~02_S
26568	endise	endise	endine	10~12_A	SgG	et	endise =endise  (SgG  >endine !10~12_A
26574	kakumäe	mäe	kaku+mägi	21_S	SgG	et	kakumäe =mäe  (SgG  >kaku+mägi !21_S
26575	õismäe	mäe	õis+mägi	21_S	SgG	et	õismäe =mäe  (SgG  >õis+mägi !21_S
26576	kadaka	kadaka	kadakas	02_S	SgG	et	kadaka =kadaka  (SgG  >kadakas !02_S
26585	temast	tema	tema	00_P	SgEl	et	temast =tema  (SgEl  >tema !00_P
26590	mõisad	mõisa	mõis	02_S	PlN	et	mõisad =mõisa  (PlN  >mõis !02_S
26592	peetri	peetri	peeter	02_S	SgG	et	peetri =peetri  (SgG  >peeter !02_S
26598	kultuurile	kultuuri	kultuur	22_S	SgAll	et	kultuurile =kultuuri  (SgAll  >kultuur !22_S
26606	kloostri	kloostri	klooster	02_S	SgG	et	kloostri =kloostri  (SgG  >klooster !02_S
26611	millal	millal	millal	41_D	ID	et	millal =millal  (ID  >millal !41_D
26613	aastani	aasta	aasta	01_S	SgTer	et	aastani =aasta  (SgTer  >aasta !01_S
26614	omanikeks	omanike	omanik	25_S	PlTr	et	omanikeks =omanike  (PlTr  >omanik !25_S
26617	ligi	ligi	ligi	41_DK	ID	et	ligi =ligi  (ID  >ligi !41_DK
26621	ainulaadne	laadne	ainu+laadne	02_AS	SgN	et	ainulaadne =laadne  (SgN  >ainu+laadne !02_AS
26624	reas	rea	rida	18_S	SgIn	et	reas =rea  (SgIn  >rida !18_S
26629	saksamaalt	maa	saksa+maa	26_S	SgAbl	et	saksamaalt =maa  (SgAbl  >saksa+maa !26_S
26630	diplomaatide	diplomaati	diplomaat	22_S	PlG	et	diplomaatide =diplomaati  (PlG  >diplomaat !22_S
26632	diplomaat	diplomaat	diplomaat	22_S	SgN	et	diplomaat =diplomaat  (SgN  >diplomaat !22_S
26651	põhjamaade	maa	põhja+maa	26_S	PlG	et	põhjamaade =maa  (PlG  >põhja+maa !26_S
26653	mõisaga	mõisa	mõis	02_S	SgKom	et	mõisaga =mõisa  (SgKom  >mõis !02_S
26674	kirjadest	kirja	kiri	24_S	PlEl	et	kirjadest =kirja  (PlEl  >kiri !24_S
26676	peategelaste	tegelas	pea+tegelane	12_S	PlG	et	peategelaste =tegelas  (PlG  >pea+tegelane !12_S
26679	pärit	pärit	pärit	41_D	ID	et	pärit =pärit  (ID  >pärit !41_D
26684	tippmuusikutega	muusiku	tipp+muusik	02_S	PlKom	et	tippmuusikutega =muusiku  (PlKom  >tipp+muusik !02_S
26688	omakorda	omakorda	oma+korda	41_D	ID	et	omakorda =omakorda  (ID  >oma+korda !41_D
26692	esitakse	takse	esi+taks	22_S	PlP	et	esitakse =takse  (PlP  >esi+taks !22_S
26697	muusikateadlased	teadlase	muusika+teadlane	12?10_S	PlN	et	muusikateadlased =teadlase  (PlN  >muusika+teadlane !12?10_S
26701	tunnetest	tunne	tunne	06_S	PlEl	et	tunnetest =tunne  (PlEl  >tunne !06_S
26702	traagikaga	traagika	traagika	01_S	SgKom	et	traagikaga =traagika  (SgKom  >traagika !01_S
26703	tõepoolest	tõepoolest	tõe+poolest	41_D	ID	et	tõepoolest =tõepoolest  (ID  >tõe+poolest !41_D
26705	lugeda	luge	lugema	28_V	Inf	et	lugeda =luge  (Inf  >lugema !28_V
26707	muidu	muidu	muidu	41_D	ID	et	muidu =muidu  (ID  >muidu !41_D
26709	kirjade	kirja	kiri	24_S	PlG	et	kirjade =kirja  (PlG  >kiri !24_S
26713	alles	alles	alles	41_D	ID	et	alles =alles  (ID  >alles !41_D
26714	ridadega	rida	rida	18_S	PlKom	et	ridadega =rida  (PlKom  >rida !18_S
26716	kahe	kahe	kaks	22_N	SgG	et	kahe =kahe  (SgG  >kaks !22_N
26720	leiab	leia	leidma	34_V	IndPrSg3	et	leiab =leia  (IndPrSg3  >leidma !34_V
26722	tüdruk	tüdruk	tüdruk	02_S	SgN	et	tüdruk =tüdruk  (SgN  >tüdruk !02_S
26728	läkitab	läkita	läkitama	27_V	IndPrSg3	et	läkitab =läkita  (IndPrSg3  >läkitama !27_V
26730	kunstikambrit	kambri	kunsti+kamber	02_S	SgP	et	kunstikambrit =kambri  (SgP  >kunsti+kamber !02_S
26735	kanaarilind	lind	kanaari+lind	22_S	SgN	et	kanaarilind =lind  (SgN  >kanaari+lind !22_S
26736	isemängiva	mängiva	ise+mängiv	02_A	SgG	et	isemängiva =mängiva  (SgG  >ise+mängiv !02_A
26743	pakuvad	paku	pakkuma	28_V	IndPrPl3	et	pakuvad =paku  (IndPrPl3  >pakkuma !28_V
26746	abiellumise	ellumise	abi+ellumine	12_S	SgG	et	abiellumise =ellumise  (SgG  >abi+ellumine !12_S
26747	oktoobris	oktoobri	oktoober	02_S	SgIn	et	oktoobris =oktoobri  (SgIn  >oktoober !02_S
26755	abielust	elu	abi+elu	17_S	SgEl	et	abielust =elu  (SgEl  >abi+elu !17_S
26757	raskel	raske	raske	01_A	SgAd	et	raskel =raske  (SgAd  >raske !01_A
26507	muudatusega	muudatuse	muudatus	11_S	SgKom	et	muudatusega =muudatuse  (SgKom  >muudatus !11_S
26510	suvest	suve	suvi	20_S	SgEl	et	suvest =suve  (SgEl  >suvi !20_S
26513	tuleb	tule	tulema	36_V	IndPrSg3	et	tuleb =tule  (IndPrSg3  >tulema !36_V
26521	kuna	kuna	kuna	41_JD	ID	et	kuna =kuna  (ID  >kuna !41_JD
26524	traditsioon	traditsioon	traditsioon	22_S	SgN	et	traditsioon =traditsioon  (SgN  >traditsioon !22_S
26534	igasugused	suguse	iga+sugune	10_A	PlN	et	igasugused =suguse  (PlN  >iga+sugune !10_A
26535	diskoõhtud	õhtu	disko+õhtu	01_S	PlN	et	diskoõhtud =õhtu  (PlN  >disko+õhtu !01_S
26544	mõisate	mõisa	mõis	02_S	PlG	et	mõisate =mõisa  (PlG  >mõis !02_S
26548	uurida	uuri	uurima	28_V	Inf	et	uurida =uuri  (Inf  >uurima !28_V
26553	minevikul	mineviku	minevik	25_S	SgAd	et	minevikul =mineviku  (SgAd  >minevik !25_S
26554	sündmuste	sündmus	sündmus	11~09_S	PlG	et	sündmuste =sündmus  (PlG  >sündmus !11~09_S
26560	väärtusi	väärtusi	väärtus	11_S	PlP	et	väärtusi =väärtusi  (PlP  >väärtus !11_S
26569	kihelkonna	kihelkonna	kihelkond	22_S	SgG	et	kihelkonna =kihelkonna  (SgG  >kihelkond !22_S
26581	laabi	laabi	laap	22_S	SgG	et	laabi =laabi  (SgG  >laap !22_S
26583	adra	adra	ader	24_S	SgG	et	adra =adra  (SgG  >ader !24_S
26594	julgesti	julgesti	julgesti	41_D	ID	et	julgesti =julgesti  (ID  >julgesti !41_D
26601	enamik	enamik	enamik	25_S	SgN	et	enamik =enamik  (SgN  >enamik !25_S
26604	esimesed	esimese	esimene	12_OP	PlN	et	esimesed =esimese  (PlN  >esimene !12_OP
26607	munkade	munka	munk	22_S	PlG	et	munkade =munka  (PlG  >munk !22_S
26609	kirjalikud	kirjaliku	kirjalik	25_A	PlN	et	kirjalikud =kirjaliku  (PlN  >kirjalik !25_A
26610	teated	teate	teade	06_S	PlN	et	teated =teate  (PlN  >teade !06_S
26612	vendade	venda	vend	22_S	PlG	et	vendade =venda  (PlG  >vend !22_S
26615	edasi	edasi	edasi	41_DK	ID	et	edasi =edasi  (ID  >edasi !41_DK
26619	tänuks	tänu	tänu	17_S	SgTr	et	tänuks =tänu  (SgTr  >tänu !17_S
26623	parun	parun	parun	02_S	SgN	et	parun =parun  (SgN  >parun !02_S
26633	õpingud	õpingu	õping	02_S	PlN	et	õpingud =õpingu  (PlN  >õping !02_S
26635	teadusreisidel	reisi	teadus+reis	22_S	PlAd	et	teadusreisidel =reisi  (PlAd  >teadus+reis !22_S
26639	avaldas	avalda	avaldama	27_V	IndIpfSg3	et	avaldas =avalda  (IndIpfSg3  >avaldama !27_V
26644	eriti	eriti	eriti	41_D	ID	et	eriti =eriti  (ID  >eriti !41_D
26649	kunstide	kunsti	kunst	22_S	PlG	et	kunstide =kunsti  (PlG  >kunst !22_S
26656	tragöödiaks	tragöödia	tragöödia	01_S	SgTr	et	tragöödiaks =tragöödia  (SgTr  >tragöödia !01_S
26658	toimud	toimu	toimuma	27_V	IndPrSg2	et	toimud =toimu  (IndPrSg2  >toimuma !27_V
26659	tunded	tunde	tunne	06_S	PlN	et	tunded =tunde  (PlN  >tunne !06_S
26661	kindlasti	kindlasti	kindlasti	41_D	ID	et	kindlasti =kindlasti  (ID  >kindlasti !41_D
26662	tool	tool	tool	22_S	SgN	et	tool =tool  (SgN  >tool !22_S
26663	peategelasteks	tegelas	pea+tegelane	12_S	PlTr	et	peategelasteks =tegelas  (PlTr  >pea+tegelane !12_S
26665	tõestusmaterjal	materjal	tõestus+materjal	19_S	SgN	et	tõestusmaterjal =materjal  (SgN  >tõestus+materjal !19_S
26673	väljalõigud	lõigu	välja+lõik	22_S	PlN	et	väljalõigud =lõigu  (PlN  >välja+lõik !22_S
26675	anda	and	andma	34_V	Inf	et	anda =and  (Inf  >andma !34_V
26677	tundeid	tunde	tunne	06_S	PlP	et	tundeid =tunde  (PlP  >tunne !06_S
26681	asutas	asuta	asutama	27_V	IndIpfSg3	et	asutas =asuta  (IndIpfSg3  >asutama !27_V
26687	kandidaatide	kandidaati	kandidaat	22_S	PlG	et	kandidaatide =kandidaati  (PlG  >kandidaat !22_S
26694	algas	alga	algama	29_V	IndIpfSg3	et	algas =alga  (IndIpfSg3  >algama !29_V
26700	kirjutas	kirjuta	kirjutama	27_V	IndIpfSg3	et	kirjutas =kirjuta  (IndIpfSg3  >kirjutama !27_V
26704	oligi	ol	olema	36_V	IndIpfSg3^	et	oligi =ol  (IndIpfSg3^  >olema !36_V
26708	seletada	seleta	seletama	27_V	Inf	et	seletada =seleta  (Inf  >seletama !27_V
26726	õele	õe	õde	18_S	SgAll	et	õele =õe  (SgAll  >õde !18_S
26727	abiellumist	ellumis	abi+ellumine	12_S	SgP	et	abiellumist =ellumis  (SgP  >abi+ellumine !12_S
26733	vahakujud-	kuju	vaha+kuju	17_S	PlN	et	vahakujud- =kuju  (PlN  >vaha+kuju !17_S
26738	kõrgeltsündinud	sündinu	kõrgelt+sündinu	01_S	PlN	et	kõrgeltsündinud =sündinu  (PlN  >kõrgelt+sündinu !01_S
26745	tuttav	tuttav	tuttav	02_AS	SgN	et	tuttav =tuttav  (SgN  >tuttav !02_AS
26753	soovib	soovi	soovima	28_V	IndPrSg3	et	soovib =soovi  (IndPrSg3  >soovima !28_V
26758	perioodil	perioodi	periood	22_S	SgAd	et	perioodil =perioodi  (SgAd  >periood !22_S
26762	tiisikusse	tiisikus	tiisikus	11_S	SgAdt	et	tiisikusse =tiisikus  (SgAdt  >tiisikus !11_S
26769	paraneb	parane	paranema	27_V	IndPrSg3	et	paraneb =parane  (IndPrSg3  >paranema !27_V
26770	korraldab	korralda	korraldama	27_V	IndPrSg3	et	korraldab =korralda  (IndPrSg3  >korraldama !27_V
26515	võtab	võta	võtma	35_V	IndPrSg3	et	võtab =võta  (IndPrSg3  >võtma !35_V
26520	püksidele	püksi	püks	22_S	PlAll	et	püksidele =püksi  (PlAll  >püks !22_S
26522	seejärel	seejärel	see+järel	41_D	ID	et	seejärel =seejärel  (ID  >see+järel !41_D
26523	referaat	referaat	referaat	22_S	SgN	et	referaat =referaat  (SgN  >referaat !22_S
26526	kaks	kaks	kaks	22_N	SgN	et	kaks =kaks  (SgN  >kaks !22_N
26531	üldse	üldse	üldse	41_D	ID	et	üldse =üldse  (ID  >üldse !41_D
26533	inimestel	inimes	inimene	12_S	PlAd	et	inimestel =inimes  (PlAd  >inimene !12_S
26542	aegade	aega	aeg	22_S	PlG	et	aegade =aega  (PlG  >aeg !22_S
26547	ning	ning	ning	41_J	ID	et	ning =ning  (ID  >ning !41_J
26549	mille	mille	mis	00_P	SgG	et	mille =mille  (SgG  >mis !00_P
26555	kunagi	kunagi	kunagi	41_D	ID	et	kunagi =kunagi  (ID  >kunagi !41_D
26557	kuidas	kuidas	kuidas	41_D	ID	et	kuidas =kuidas  (ID  >kuidas !41_D
26558	millega	mille	mis	00_P	SgKom	et	millega =mille  (SgKom  >mis !00_P
26562	ülivaade	vaade	üli+vaade	06_S	SgN	et	ülivaade =vaade  (SgN  >üli+vaade !06_S
26563	mereäärne	äärne	mere+äärne	02_A	SgN	et	mereäärne =äärne  (SgN  >mere+äärne !02_A
26570	pöördume	pöördu	pöörduma	27_V	IndPrPl1	et	pöördume =pöördu  (IndPrPl1  >pöörduma !27_V
26572	alla	alla	alla	41_DK	ID	et	alla =alla  (ID  >alla !41_DK
26578	aastal	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
26580	rannamõisa	mõisa	ranna+mõis	02_S	SgG	et	rannamõisa =mõisa  (SgG  >ranna+mõis !02_S
26584	külad	küla	küla	17_S	PlN	et	külad =küla  (PlN  >küla !17_S
26588	arv	arv	arv	22_S	SgN	et	arv =arv  (SgN  >arv !22_S
26595	nimetada	nimeta	nimetama	27_V	Inf	et	nimetada =nimeta  (Inf  >nimetama !27_V
26597	millel	mille	mis	00_P	SgAd	et	millel =mille  (SgAd  >mis !00_P
26602	sündmusi	sündmusi	sündmus	11_S	PlP	et	sündmusi =sündmusi  (PlP  >sündmus !11_S
26608	vanimad	vani	vana	17_AS	IM_sA	et	"vanim %vani  )IM_sA  <vana ;17_AS
26616	sattus	sattu	sattuma	27~28_V	IndIpfSg3	et	sattus =sattu  (IndIpfSg3  >sattuma !27~28_V
26622	barokkansambel	ansambel	barokk+ansambel	02_S	SgN	et	barokkansambel =ansambel  (SgN  >barokk+ansambel !02_S
26627	poisil	poisi	poiss	23?22_S	SgAd	et	poisil =poisi  (SgAd  >poiss !23?22_S
26631	eeskujul	kuju	ees+kuju	17_S	SgAd	et	eeskujul =kuju  (SgAd  >ees+kuju !17_S
26638	vang	vang	vang	22_S	SgN	et	vang =vang  (SgN  >vang !22_S
26640	teoseid	teose	teos	09_S	PlP	et	teoseid =teose  (PlP  >teos !09_S
26641	täiendas	täienda	täiendama	27_V	IndIpfSg3	et	täiendas =täienda  (IndIpfSg3  >täiendama !27_V
26645	antiikkunst	kunst	antiik+kunst	22_S	SgN	et	antiikkunst =kunst  (SgN  >antiik+kunst !22_S
26647	kunstiühingute	ühingu	kunsti+ühing	02_S	PlG	et	kunstiühingute =ühingu  (PlG  >kunsti+ühing !02_S
26652	voes	voe	voos	14_S	SgIn	et	voes =voe  (SgIn  >voos !14_S
26654	samal	sama	sama	17_P	SgAd	et	samal =sama  (SgAd  >sama !17_P
26660	siit	siit	siit	41_D	ID	et	siit =siit  (ID  >siit !41_D
26664	peamine	peamine	peamine	12?10_A	SgN	et	peamine =peamine  (SgN  >peamine !12?10_A
26667	saksakeeltes	keel	saksa+keel	13_S	PlIn	et	saksakeeltes =keel  (PlIn  >saksa+keel !13_S
26668	romaan	romaan	romaan	22_S	SgN	et	romaan =romaan  (SgN  >romaan !22_S
26670	arenes	arene	arenema	27_V	IndIpfSg3	et	arenes =arene  (IndIpfSg3  >arenema !27_V
26683	suareedel	suaree	suaree	26_S	PlAd	et	suareedel =suaree  (PlAd  >suaree !26_S
26686	paljude	palju	palju	16_P	PlG	et	paljude =palju  (PlG  >palju !16_P
26693	versioone	versioone	versioon	22_S	PlP	et	versioone =versioone  (PlP  >versioon !22_S
26698	tihti	tihti	tihti	41_D	ID	et	tihti =tihti  (ID  >tihti !41_D
26706	näeb	näe	nägema	28_V	IndPrSg3	et	näeb =näe  (IndPrSg3  >nägema !28_V
26710	sõnadega	sõna	sõna	17_S	PlKom	et	sõnadega =sõna  (PlKom  >sõna !17_S
26717	tütardega	tütar	tütar	08_S	PlKom	et	tütardega =tütar  (PlKom  >tütar !08_S
26721	kellega	kelle	kes	00_P	SgKom	et	kellega =kelle  (SgKom  >kes !00_P
26724	pulmadeks	pulma	pulm	22_S	PlTr	et	pulmadeks =pulma  (PlTr  >pulm !22_S
26729	naisele	naise	naine	12_S	SgAll	et	naisele =naise  (SgAll  >naine !12_S
26731	eksootilised	eksootilise	eksootiline	12_A	PlN	et	eksootilised =eksootilise  (PlN  >eksootiline !12_A
26744	muusikat	muusika	muusika	01_S	SgP	et	muusikat =muusika  (SgP  >muusika !01_S
26754	tütar	tütar	tütar	08_S	SgN	et	tütar =tütar  (SgN  >tütar !08_S
26760	sureb	sure	surema	36_V	IndPrSg3	et	sureb =sure  (IndPrSg3  >surema !36_V
26778	perioodist	perioodi	periood	22_S	SgEl	et	perioodist =perioodi  (SgEl  >periood !22_S
26785	näha	näh	nägema	28_V	Inf	et	näha =näh  (Inf  >nägema !28_V
26541	uurimisobjekt	objekt	uurimis+objekt	22_S	SgN	et	uurimisobjekt =objekt  (SgN  >uurimis+objekt !22_S
26543	vald	vald	vald	22_S	SgN	et	vald =vald  (SgN  >vald !22_S
26546	võtta	võtt	võtma	35_V	Inf	et	võtta =võtt  (Inf  >võtma !35_V
26556	kuulsad	kuulsa	kuulus	02_A	PlN	et	kuulsad =kuulsa  (PlN  >kuulus !02_A
26561	teatakse	tea	teadma	34_V	IndPrIps	et	teatakse =tea  (IndPrIps  >teadma !34_V
26566	vallad	valla	vald	22_S	PlN	et	vallad =valla  (PlN  >vald !22_S
26567	mõlemad	mõlema	mõlema	02_P	PlN	et	mõlemad =mõlema  (PlN  >mõlema !02_P
26573	hiljem	hiljem	hiljem	41_D	ID	et	hiljem =hiljem  (ID  >hiljem !41_D
26582	humala	humala	humal	02_S	SgG	et	humala =humala  (SgG  >humal !02_S
26586	sügiseni	sügise	sügis	09_S	SgTer	et	sügiseni =sügise  (SgTer  >sügis !09_S
26587	elanike	elanike	elanik	25_S	PlG	et	elanike =elanike  (PlG  >elanik !25_S
26596	turismiobjektiks	objekti	turismi+objekt	22_S	SgTr	et	turismiobjektiks =objekti  (SgTr  >turismi+objekt !22_S
26599	väänas	vääna	väänama	29_V	IndIpfSg3	et	väänas =vääna  (IndIpfSg3  >väänama !29_V
26600	vallas	valla	vald	22_S	SgIn	et	vallas =valla  (SgIn  >vald !22_S
26618	aastasajaks	jaks	aas+tasa+jaks	22_S	SgN	et	aastasajaks =jaks  (SgN  >aas+tasa+jaks !22_S
26625	kunstnik	kunstnik	kunstnik	25_S	SgN	et	kunstnik =kunstnik  (SgN  >kunstnik !25_S
26636	piraatide	piraati	piraat	22_S	PlG	et	piraatide =piraati  (PlG  >piraat !22_S
26643	kabel-mausoleum	mausoleum	kabel-mausoleum	22_S	SgN	et	kabel-mausoleum =mausoleum  (SgN  >kabel-mausoleum !22_S
26648	töös	töö	töö	26_S	SgIn	et	töös =töö  (SgIn  >töö !26_S
26657	pole	pole	olema	36_V	IndPrPsN	et	pole =pole  (IndPrPsN  >olema !36_V
26669	alguse	alguse	algus	11~09_S	SgG	et	alguse =alguse  (SgG  >algus !11~09_S
26671	lõpp	lõpp	lõpp	22_SA	SgN	et	lõpp =lõpp  (SgN  >lõpp !22_SA
26672	püüan	püüa	püüdma	34_V	IndPrSg1	et	püüan =püüa  (IndPrSg1  >püüdma !34_V
26678	salalaekas	laeka	sala+laegas	07_S	SgIn	et	salalaekas =laeka  (SgIn  >sala+laegas !07_S
26680	vanast	vana	vana	17_AS	SgEl	et	vanast =vana  (SgEl  >vana !17_AS
26682	pianist	pianist	pianist	22_S	SgN	et	pianist =pianist  (SgN  >pianist !22_S
26685	õpilane	õpilane	õpilane	12_S	SgN	et	õpilane =õpilane  (SgN  >õpilane !12_S
26689	muusikateadlaste	teadlas	muusika+teadlane	12?10_S	PlG	et	muusikateadlaste =teadlas  (PlG  >muusika+teadlane !12?10_S
26690	saladus	saladus	saladus	11_S	SgN	et	saladus =saladus  (SgN  >saladus !11_S
26695	leiti	lei	leidma	34_V	IndIpfIps	et	leiti =lei  (IndIpfIps  >leidma !34_V
26696	kirjutuslaua	laua	kirjutus+laud	22_S	SgG	et	kirjutuslaua =laua  (SgG  >kirjutus+laud !22_S
26711	mu	mu	ma	00_P	SgG	et	mu =mu  (SgG  >ma !00_P
26715	sinu	sinu	sina	00_P	SgG	et	sinu =sinu  (SgG  >sina !00_P
26718	peigmehed	mehe	peig+mees	13_S	PlN	et	peigmehed =mehe  (PlN  >peig+mees !13_S
26723	abiellubki	ellu	abi+elluma	27_V	IndPrSg3^	et	abiellubki =ellu  (IndPrSg3^  >abi+elluma !27_V
26725	pühendab	pühenda	pühendama	27_V	IndPrSg3	et	pühendab =pühenda  (IndPrSg3  >pühendama !27_V
26740	antiikkujude	kuju	antiik+kuju	17_S	PlG	et	antiikkujude =kuju  (PlG  >antiik+kuju !17_S
26748	kirjutab	kirjuta	kirjutama	27_V	IndPrSg3	et	kirjutab =kirjuta  (IndPrSg3  >kirjutama !27_V
26749	räägib	räägi	rääkima	28_V	IndPrSg3	et	räägib =räägi  (IndPrSg3  >rääkima !28_V
26763	rasedana	raseda	rase	02_AS	SgEs	et	rasedana =raseda  (SgEs  >rase !02_AS
26768	seisund	seisund	seisund	02_S	SgN	et	seisund =seisund  (SgN  >seisund !02_S
26776	järeldada	järelda	järeldama	27_V	Inf	et	järeldada =järelda  (Inf  >järeldama !27_V
26780	millele	mille	mis	00_P	SgAll	et	millele =mille  (SgAll  >mis !00_P
26781	kiri	kiri	kiri	24_S	SgN	et	kiri =kiri  (SgN  >kiri !24_S
26784	ohtlikeks	ohtlike	ohtlik	25_A	PlTr	et	ohtlikeks =ohtlike  (PlTr  >ohtlik !25_A
26787	murelik	murelik	murelik	25_A	SgN	et	murelik =murelik  (SgN  >murelik !25_A
26788	sõnadele	sõna	sõna	17_S	PlAll	et	sõnadele =sõna  (PlAll  >sõna !17_S
26803	mõtleb	mõtle	mõtlema	30_V	IndPrSg3	et	mõtleb =mõtle  (IndPrSg3  >mõtlema !30_V
26804	no	no	no	41_I	ID	et	no =no  (ID  >no !41_I
26820	hüvastijätt	jätt	hüvasti+jätt	22_S	SgN	et	hüvastijätt =jätt  (SgN  >hüvasti+jätt !22_S
26823	lahkub	lahku	lahkuma	27_V	IndPrSg3	et	lahkub =lahku  (IndPrSg3  >lahkuma !27_V
26824	lastega	las	laps	14_S	PlKom	et	lastega =las  (PlKom  >laps !14_S
26827	mõisas	mõisa	mõis	02_S	SgIn	et	mõisas =mõisa  (SgIn  >mõis !02_S
26841	took	took	took	22_S	SgN	et	took =took  (SgN  >took !22_S
26853	aadlivastane	vastane	aadli+vastane	10_AS	SgN	et	aadlivastane =vastane  (SgN  >aadli+vastane !10_AS
26855	abielludes	ellu	abi+elluma	27_V	Ger	et	abielludes =ellu  (Ger  >abi+elluma !27_V
26759	sõber	sõber	sõber	24_S	SgN	et	sõber =sõber  (SgN  >sõber !24_S
26764	tekivad	teki	tekkima	28_V	IndPrPl3	et	tekivad =teki  (IndPrPl3  >tekkima !28_V
26766	krahvina	krahvi	krahv	22_S	SgEs	et	krahvina =krahvi  (SgEs  >krahv !22_S
26775	and	and	and	22_S	SgN	et	and =and  (SgN  >and !22_S
26779	algabki	alga	algama	29_V	IndPrSg3^	et	algabki =alga  (IndPrSg3^  >algama !29_V
26782	nimetab	nimeta	nimetama	27_V	IndPrSg3	et	nimetab =nimeta  (IndPrSg3  >nimetama !27_V
26786	kirjades	kirja	kiri	24_S	PlIn	et	kirjades =kirja  (PlIn  >kiri !24_S
26793	patroon	patroon	patroon	22_S	SgN	et	patroon =patroon  (SgN  >patroon !22_S
26794	kiitis	kiit	kiitma	34_V	IndIpfSg3	et	kiitis =kiit  (IndIpfSg3  >kiitma !34_V
26795	arvas	arva	arvama	29_V	IndIpfSg3	et	arvas =arva  (IndIpfSg3  >arvama !29_V
26797	inspireerib	inspireeri	inspireerima	28_V	IndPrSg3	et	inspireerib =inspireeri  (IndPrSg3  >inspireerima !28_V
26799	sonaate	sonaate	sonaat	22_S	PlP	et	sonaate =sonaate  (PlP  >sonaat !22_S
26801	unistab	unista	unistama	27_V	IndPrSg3	et	unistab =unista  (IndPrSg3  >unistama !27_V
26810	poor	poor	poor	22_S	SgN	et	poor =poor  (SgN  >poor !22_S
26813	made	made	made	04_S	SgN	et	made =made  (SgN  >made !04_S
26815	annab	anna	andma	34_V	IndPrSg3	et	annab =anna  (IndPrSg3  >andma !34_V
26822	hurt	hurt	hurt	22_S	SgN	et	hurt =hurt  (SgN  >hurt !22_S
26828	taas	taas	taas	41_D	ID	et	taas =taas  (ID  >taas !41_D
26830	fail	fail	fail	22_S	SgN	et	fail =fail  (SgN  >fail !22_S
26834	suareel	suaree	suaree	26_S	SgAd	et	suareel =suaree  (SgAd  >suaree !26_S
26838	intsident	intsident	intsident	22_S	SgN	et	intsident =intsident  (SgN  >intsident !22_S
26850	ühiskond	ühiskond	ühiskond	22_S	SgN	et	ühiskond =ühiskond  (SgN  >ühiskond !22_S
26851	demokraat	demokraat	demokraat	22_S	SgN	et	demokraat =demokraat  (SgN  >demokraat !22_S
26859	sündis	sündi	sündima	28_V	IndIpfSg3	et	sündis =sündi  (IndIpfSg3  >sündima !28_V
26861	õppis	õppi	õppima	28_V	IndIpfSg3	et	õppis =õppi  (IndIpfSg3  >õppima !28_V
26864	rahvakooliõpetajate	õpetaja	rahva+kooli+õpetaja	01_S	PlG	et	rahvakooliõpetajate =õpetaja  (PlG  >rahva+kooli+õpetaja !01_S
26867	fakt	fakt	fakt	22_S	SgN	et	fakt =fakt  (SgN  >fakt !22_S
26874	levima	levi	levima	27_V	Sup	et	levima =levi  (Sup  >levima !27_V
26876	demokraatlik	demokraatlik	demokraatlik	25_A	SgN	et	demokraatlik =demokraatlik  (SgN  >demokraatlik !25_A
26879	levikut	leviku	levik	02_S	SgP	et	levikut =leviku  (SgP  >levik !02_S
26881	andis	and	andma	34_V	IndIpfSg3	et	andis =and  (IndIpfSg3  >andma !34_V
26889	mõisnike	mõisnike	mõisnik	25_S	PlG	et	mõisnike =mõisnike  (PlG  >mõisnik !25_S
26890	mõjule	mõju	mõju	17_S	SgAll	et	mõjule =mõju  (SgAll  >mõju !17_S
26891	asutaski	asuta	asutama	27_V	IndIpfSg3^	et	asutaski =asuta  (IndIpfSg3^  >asutama !27_V
26892	tegutses	tegutse	tegutsema	27_V	IndIpfSg3	et	tegutses =tegutse  (IndIpfSg3  >tegutsema !27_V
26901	saadab	saada	saatma	34_V	IndPrSg3	et	saadab =saada  (IndPrSg3  >saatma !34_V
26904	ju	ju	ju	41_D	ID	et	ju =ju  (ID  >ju !41_D
26906	tõesti	tõesti	tõesti	41_D	ID	et	tõesti =tõesti  (ID  >tõesti !41_D
26909	tundele	tunde	tunne	06_S	SgAll	et	tundele =tunde  (SgAll  >tunne !06_S
26913	kahtlen	kahtle	kahtlema	30_V	IndPrSg1	et	kahtlen =kahtle  (IndPrSg1  >kahtlema !30_V
26915	vastus	vastus	vastus	09_S	SgN	et	vastus =vastus  (SgN  >vastus !09_S
26928	perioodideks	perioodi	periood	22_S	PlTr	et	perioodideks =perioodi  (PlTr  >periood !22_S
26931	pöördub	pöördu	pöörduma	27_V	IndPrSg3	et	pöördub =pöördu  (IndPrSg3  >pöörduma !27_V
26937	isaga	isa	isa	17_S	SgKom	et	isaga =isa  (SgKom  >isa !17_S
26939	unustama	unusta	unustama	27_V	Sup	et	unustama =unusta  (Sup  >unustama !27_V
26944	taustaks	tausta	taust	22_S	SgTr	et	taustaks =tausta  (SgTr  >taust !22_S
26950	stseene	stseene	stseen	22_S	PlP	et	stseene =stseene  (PlP  >stseen !22_S
26957	tervikuna	terviku	tervik	02_S	SgEs	et	tervikuna =terviku  (SgEs  >tervik !02_S
26960	jääb	jää	jääma	37_V	IndPrSg3	et	jääb =jää  (IndPrSg3  >jääma !37_V
26964	rikkalik	rikkalik	rikkalik	25_A	SgN	et	rikkalik =rikkalik  (SgN  >rikkalik !25_A
26969	omanikud	omaniku	omanik	25_S	PlN	et	omanikud =omaniku  (PlN  >omanik !25_S
26970	mõis	mõis	mõis	02_S	SgN	et	mõis =mõis  (SgN  >mõis !02_S
26973	soomekeelsest	keelse	soome+keelne	02_A	SgEl	et	soomekeelsest =keelse  (SgEl  >soome+keelne !02_A
26982	hunnik	hunnik	hunnik	02_S	SgN	et	hunnik =hunnik  (SgN  >hunnik !02_S
26985	maalehe	lehe	maa+leht	22_S	SgG	et	maalehe =lehe  (SgG  >maa+leht !22_S
26990	arvamust	arvamus	arvamus	11_S	SgP	et	arvamust =arvamus  (SgP  >arvamus !11_S
26993	ürikus	üriku	ürik	02_S	SgIn	et	ürikus =üriku  (SgIn  >ürik !02_S
26771	jälle	jälle	jälle	41_D	ID	et	jälle =jälle  (ID  >jälle !41_D
26774	samuti	samuti	samuti	41_D	ID	et	samuti =samuti  (ID  >samuti !41_D
26777	kasvab	kasva	kasvama	28_V	IndPrSg3	et	kasvab =kasva  (IndPrSg3  >kasvama !28_V
26783	tunnid	tunni	tund	22_S	PlN	et	tunnid =tunni  (PlN  >tund !22_S
26791	jutustab	jutusta	jutustama	27_V	IndPrSg3	et	jutustab =jutusta  (IndPrSg3  >jutustama !27_V
26792	prints	prints	prints	22_S	SgN	et	prints =prints  (SgN  >prints !22_S
26796	loomingu	loomingu	looming	02_S	SgG	et	loomingu =loomingu  (SgG  >looming !02_S
26800	klaverisonaadi	sonaadi	klaveri+sonaat	22_S	SgG	et	klaverisonaadi =sonaadi  (SgG  >klaveri+sonaat !22_S
26805	all	all	all	41_DK	ID	et	all =all  (ID  >all !41_DK
26807	are	are	are	02_A	SgN	et	are =are  (SgN  >are !02_A
26809	feel	fee	fee	26_S	SgAd	et	feel =fee  (SgAd  >fee !26_S
26811	ühepoolsed	poolse	ühe+poolne	02_A	PlN	et	ühepoolsed =poolse  (PlN  >ühe+poolne !02_A
26812	vastab	vasta	vastama	29_V	IndPrSg3	et	vastab =vasta  (IndPrSg3  >vastama !29_V
26833	päeval	päeva	päev	22_S	SgAd	et	päeval =päeva  (SgAd  >päev !22_S
26835	juhtub	juhtu	juhtuma	27_V	IndPrSg3	et	juhtub =juhtu  (IndPrSg3  >juhtuma !27_V
26846	mispärast	mispärast	mis+pärast	41_D	ID	et	mispärast =mispärast  (ID  >mis+pärast !41_D
26849	nimega	nime	nimi	20_S	SgKom	et	nimega =nime  (SgKom  >nimi !20_S
26852	liberaal	liberaal	liberaal	22_S	SgN	et	liberaal =liberaal  (SgN  >liberaal !22_S
26858	puutuda	puutu	puutuma	27_V	Inf	et	puutuda =puutu  (Inf  >puutuma !27_V
26885	kokkuhoidliku	hoidliku	kokku+hoidlik	25_A	SgG	et	kokkuhoidliku =hoidliku  (SgG  >kokku+hoidlik !25_A
26886	kirikule	kiriku	kirik	02_S	SgAll	et	kirikule =kiriku  (SgAll  >kirik !02_S
26888	mäss	mäss	mäss	22_S	SgN	et	mäss =mäss  (SgN  >mäss !22_S
26907	ohverdas	ohverda	ohverdama	27_V	IndIpfSg3	et	ohverdas =ohverda  (IndIpfSg3  >ohverdama !27_V
26910	lõppuni	uni	lõpp+uni	20_S	SgN	et	lõppuni =uni  (SgN  >lõpp+uni !20_S
26912	oletada	oleta	oletama	27_V	Inf	et	oletada =oleta  (Inf  >oletama !27_V
26917	juunis	juuni	juuni	16_S	SgIn	et	juunis =juuni  (SgIn  >juuni !16_S
26929	nõuab	nõua	nõudma	34_V	IndPrSg3	et	nõuab =nõua  (IndPrSg3  >nõudma !34_V
26933	mehega	mehe	mees	13_S	SgKom	et	mehega =mehe  (SgKom  >mees !13_S
26936	lapsega	lapse	laps	14_S	SgKom	et	lapsega =lapse  (SgKom  >laps !14_S
26940	romaanide	romaani	romaan	22_S	PlG	et	romaanide =romaani  (PlG  >romaan !22_S
26945	vahepaladeks	pala	vahe+pala	17_S	PlTr	et	vahepaladeks =pala  (PlTr  >vahe+pala !17_S
26949	tegelased	tegelase	tegelane	12_S	PlN	et	tegelased =tegelase  (PlN  >tegelane !12_S
26953	organiseeriks	organiseeri	organiseerima	28_V	KndPrPs	et	organiseeriks =organiseeri  (KndPrPs  >organiseerima !28_V
26956	oskas	oska	oskama	29_V	IndIpfSg3	et	oskas =oska  (IndIpfSg3  >oskama !29_V
26958	peategelast	tegelas	pea+tegelane	12_S	SgP	et	peategelast =tegelas  (SgP  >pea+tegelane !12_S
26961	ärkab	ärka	ärkama	29_V	IndPrSg3	et	ärkab =ärka  (IndPrSg3  >ärkama !29_V
26962	seinad	seina	sein	23?22_S	PlN	et	seinad =seina  (PlN  >sein !23?22_S
26963	draamale	draama	draama	16_S	SgAll	et	draamale =draama  (SgAll  >draama !16_S
26968	renditi	rendi	rentima	28_V	IndIpfIps	et	renditi =rendi  (IndIpfIps  >rentima !28_V
26978	ajaarvamist	arvamis	aja+arvamine	12_S	SgP	et	ajaarvamist =arvamis  (SgP  >aja+arvamine !12_S
26995	ordumõisa	mõisa	ordu+mõis	02_S	SgG	et	ordumõisa =mõisa  (SgG  >ordu+mõis !02_S
26997	mainitakse	maini	mainima	28_V	IndPrIps	et	mainitakse =maini  (IndPrIps  >mainima !28_V
26999	taanlaste	taanlas	taanlane	12?10_S	PlG	et	taanlaste =taanlas  (PlG  >taanlane !12?10_S
27008	käsitöölisel	töölise	käsi+tööline	12?10_S	SgAd	et	käsitöölisel =töölise  (SgAd  >käsi+tööline !12?10_S
27011	sõjani	sõja	sõda	18_S	SgTer	et	sõjani =sõja  (SgTer  >sõda !18_S
27013	ordulinnusena	linnuse	ordu+linnus	09_S	SgEs	et	ordulinnusena =linnuse  (SgEs  >ordu+linnus !09_S
27022	etendab	etenda	etendama	27_V	IndPrSg3	et	etendab =etenda  (IndPrSg3  >etendama !27_V
27024	sõjakomissarile	komissari	sõja+komissar	19_S	SgAll	et	sõjakomissarile =komissari  (SgAll  >sõja+komissar !19_S
27025	katk	katk	katk	22_S	SgN	et	katk =katk  (SgN  >katk !22_S
27035	vägedele	väge	vägi	21_S	PlAll	et	vägedele =väge  (PlAll  >vägi !21_S
27040	kurikuulsa	kuulsa	kuri+kuulus	02_A	SgG	et	kurikuulsa =kuulsa  (SgG  >kuri+kuulus !02_A
27043	sõjaväele	väe	sõja+vägi	21_S	SgAll	et	sõjaväele =väe  (SgAll  >sõja+vägi !21_S
27044	valitses	valitse	valitsema	27_V	IndIpfSg3	et	valitses =valitse  (IndIpfSg3  >valitsema !27_V
27051	niimoodi	niimoodi	nii+moodi	41_D	ID	et	niimoodi =niimoodi  (ID  >nii+moodi !41_D
27053	korrastustöid	tö	korrastus+töö	26_S	PlP	et	korrastustöid =tö  (PlP  >korrastus+töö !26_S
26789	lähedased	lähedase	lähedane	12_AS	PlN	et	lähedased =lähedase  (PlN  >lähedane !12_AS
26808	real	rea	rida	18_S	SgAd	et	real =rea  (SgAd  >rida !18_S
26818	kõlab	kõla	kõlama	27_V	IndPrSg3	et	kõlab =kõla  (IndPrSg3  >kõlama !27_V
26821	protest	protest	protest	22_S	SgN	et	protest =protest  (SgN  >protest !22_S
26836	palub	palu	paluma	27_V	IndPrSg3	et	palub =palu  (IndPrSg3  >paluma !27_V
26839	vabandab	vabanda	vabandama	27_V	IndPrSg3	et	vabandab =vabanda  (IndPrSg3  >vabandama !27_V
26847	õpilase	õpilase	õpilane	12_S	SgG	et	õpilase =õpilase  (SgG  >õpilane !12_S
26848	müür	müür	müür	22_S	SgN	et	müür =müür  (SgN  >müür !22_S
26854	aadli	aadli	aadel	02_S	SgG	et	aadli =aadli  (SgG  >aadel !02_S
26865	euroopas	euroopa	euroopa	01_H	SgIn	et	euroopas =euroopa  (SgIn  >euroopa !01_H
26866	abielluski	ellu	abi+elluma	27_V	IndIpfSg3^	et	abielluski =ellu  (IndIpfSg3^  >abi+elluma !27_V
26869	religioosne	religioosne	religioosne	02_A	SgN	et	religioosne =religioosne  (SgN  >religioosne !02_A
26873	eestis	eesti	eesti	16_H	SgIn	et	eestis =eesti  (SgIn  >eesti !16_H
26875	rahvalik	rahvalik	rahvalik	25_A	SgN	et	rahvalik =rahvalik  (SgN  >rahvalik !25_A
26877	vennastekogudus	kogudus	vennaste+kogudus	11_S	SgN	et	vennastekogudus =kogudus  (SgN  >vennaste+kogudus !11_S
26887	koosolekud	oleku	koos+olek	02_S	PlN	et	koosolekud =oleku  (PlN  >koos+olek !02_S
26896	veebruaril	veebruari	veebruar	19_S	SgAd	et	veebruaril =veebruari  (SgAd  >veebruar !19_S
26898	katoliiklane	katoliiklane	katoliiklane	12?10_S	SgN	et	katoliiklane =katoliiklane  (SgN  >katoliiklane !12?10_S
26903	vaatab	vaata	vaatama	29_V	IndPrSg3	et	vaatab =vaata  (IndPrSg3  >vaatama !29_V
26905	sümbol	sümbol	sümbol	02_S	SgN	et	sümbol =sümbol  (SgN  >sümbol !02_S
26908	jäi	jä	jääma	37_V	IndIpfSg3	et	jäi =jä  (IndIpfSg3  >jääma !37_V
26916	eestit	eesti	eesti	16_H	SgP	et	eestit =eesti  (SgP  >eesti !16_H
26918	toimus	toimu	toimuma	27_V	IndIpfSg3	et	toimus =toimu  (IndIpfSg3  >toimuma !27_V
26919	abielukriis	kriis	abi+elu+kriis	22_S	SgN	et	abielukriis =kriis  (SgN  >abi+elu+kriis !22_S
26922	erines	erine	erinema	27_V	IndIpfSg3	et	erines =erine  (IndIpfSg3  >erinema !27_V
26923	õdedest	õde	õde	18_S	PlEl	et	õdedest =õde  (PlEl  >õde !18_S
26925	klaveripedagoog	pedagoog	klaveri+pedagoog	22_S	SgN	et	klaveripedagoog =pedagoog  (SgN  >klaveri+pedagoog !22_S
26932	toole	toole	tool	22_S	PlP	et	toole =toole  (PlP  >tool !22_S
26938	peategelased	tegelase	pea+tegelane	12_S	PlN	et	peategelased =tegelase  (PlN  >pea+tegelane !12_S
26941	traagikaks	traagika	traagika	01_S	SgTr	et	traagikaks =traagika  (SgTr  >traagika !01_S
26943	rajada	raja	rajama	27_V	Inf	et	rajada =raja  (Inf  >rajama !27_V
26946	ekraanil	ekraani	ekraan	22_S	SgAd	et	ekraanil =ekraani  (SgAd  >ekraan !22_S
26947	pilte	pilte	pilt	22_S	PlP	et	pilte =pilte  (PlP  >pilt !22_S
26967	kingiti	kingi	kinkima	28_V	IndIpfIps	et	kingiti =kingi  (IndIpfIps  >kinkima !28_V
26979	teoses	teose	teos	09_S	SgIn	et	teoses =teose  (SgIn  >teos !09_S
26980	raamat	raamat	raamat	02_S	SgN	et	raamat =raamat  (SgN  >raamat !02_S
26987	joale	joa	juga	18_S	SgAll	et	joale =joa  (SgAll  >juga !18_S
26989	ajaloolased	loolase	aja+loolane	12?10_S	PlN	et	ajaloolased =loolase  (PlN  >aja+loolane !12?10_S
26992	mõnes	mõne	mõni	20_P	SgIn	et	mõnes =mõne  (SgIn  >mõni !20_P
27000	juulikuus	kuu	juuli+kuu	26_S	SgIn	et	juulikuus =kuu  (SgIn  >juuli+kuu !26_S
27003	järgnes	järgne	järgnema	27_V	IndIpfSg3	et	järgnes =järgne  (IndIpfSg3  >järgnema !27_V
27004	harkus	harku	harkuma	27_V	IndIpfSg3	et	harkus =harku  (IndIpfSg3  >harkuma !27_V
27006	mõnel	mõne	mõni	20_P	SgAd	et	mõnel =mõne  (SgAd  >mõni !20_P
27030	kindralleitnant	leitnant	kindral+leitnant	22_S	SgN	et	kindralleitnant =leitnant  (SgN  >kindral+leitnant !22_S
27033	kapitulatsioonile	kapitulatsiooni	kapitulatsioon	22_S	SgAll	et	kapitulatsioonile =kapitulatsiooni  (SgAll  >kapitulatsioon !22_S
27036	lõppeb	lõppe	lõppema	27_V	IndPrSg3	et	lõppeb =lõppe  (IndPrSg3  >lõppema !27_V
27037	poeg	poeg	poeg	22_S	SgN	et	poeg =poeg  (SgN  >poeg !22_S
27041	teenis	teeni	teenima	28_V	IndIpfSg3	et	teenis =teeni  (IndIpfSg3  >teenima !28_V
27045	majanduskriis	kriis	majandus+kriis	22_S	SgN	et	majanduskriis =kriis  (SgN  >majandus+kriis !22_S
27050	maaomanik	omanik	maa+omanik	25_S	SgN	et	maaomanik =omanik  (SgN  >maa+omanik !25_S
27052	võetakse	võe	võtma	35_V	IndPrIps	et	võetakse =võe  (IndPrIps  >võtma !35_V
27055	haruldasi	haruldasi	haruldane	12_A	PlP	et	haruldasi =haruldasi  (PlP  >haruldane !12_A
27058	muudetakse	muude	muutma	34_V	IndPrIps	et	muudetakse =muude  (IndPrIps  >muutma !34_V
27061	majapidamisharuks	haru	maja+pidamis+haru	17_S	SgTr	et	majapidamisharuks =haru  (SgTr  >maja+pidamis+haru !17_S
27072	sepp	sepp	sepp	22_S	SgN	et	sepp =sepp  (SgN  >sepp !22_S
26817	viimastes	viimas	viimane	10_A	PlIn	et	viimastes =viimas  (PlIn  >viimane !10_A
26819	lahkumiskiri	kiri	lahku+mis+kiri	24_S	SgN	et	lahkumiskiri =kiri  (SgN  >lahku+mis+kiri !24_S
26825	viinist	viini	viin	22_S	SgEl	et	viinist =viini  (SgEl  >viin !22_S
26826	viibib	viibi	viibima	27_V	IndPrSg3	et	viibib =viibi  (IndPrSg3  >viibima !27_V
26829	talk	talk	talk	22_S	SgN	et	talk =talk  (SgN  >talk !22_S
26831	arvatavasti	arvatavasti	arvatavasti	41_D	ID	et	arvatavasti =arvatavasti  (ID  >arvatavasti !41_D
26832	järgmisel	järgmise	järgmine	12?10_A	SgAd	et	järgmisel =järgmise  (SgAd  >järgmine !12?10_A
26837	toimub	toimu	toimuma	27_V	IndPrSg3	et	toimub =toimu  (IndPrSg3  >toimuma !27_V
26840	insult	insult	insult	22_S	SgN	et	insult =insult  (SgN  >insult !22_S
26842	room	room	room	22_S	SgN	et	room =room  (SgN  >room !22_S
26843	mine	mine	minema	36_V	ImpPrSg2	et	mine =mine  (ImpPrSg2  >minema !36_V
26844	külmadeks	külma	külm	22_AS	PlTr	et	külmadeks =külma  (PlTr  >külm !22_AS
26845	iks	iks	iks	22_S	SgN	et	iks =iks  (SgN  >iks !22_S
26856	kodanlikuga	kodanliku	kodanlik	25_A	SgKom	et	kodanlikuga =kodanliku  (SgKom  >kodanlik !25_A
26862	direktoriks	direktori	direktor	02_S	SgTr	et	direktoriks =direktori  (SgTr  >direktor !02_S
26868	vennaskoguduse	koguduse	vennas+kogudus	11_S	SgG	et	vennaskoguduse =koguduse  (SgG  >vennas+kogudus !11_S
26871	mõte	mõte	mõte	06_S	SgN	et	mõte =mõte  (SgN  >mõte !06_S
26872	hakkab	hakka	hakkama	29_V	IndPrSg3	et	hakkab =hakka  (IndPrSg3  >hakkama !29_V
26880	talupoegade	poega	talu+poeg	22_S	PlG	et	talupoegade =poega  (PlG  >talu+poeg !22_S
26882	tekitas	tekita	tekitama	27_V	IndIpfSg3	et	tekitas =tekita  (IndIpfSg3  >tekitama !27_V
26883	pasunakooride	koori	pasuna+koor	22_S	PlG	et	pasunakooride =koori  (PlG  >pasuna+koor !22_S
26884	sellega	selle	see	00_P	SgKom	et	sellega =selle  (SgKom  >see !00_P
26895	põhjuseks	põhjuse	põhjus	11~09_S	SgTr	et	põhjuseks =põhjuse  (SgTr  >põhjus !11~09_S
26911	teemal	teema	teema	16_S	SgAd	et	teemal =teema  (SgAd  >teema !16_S
26924	muusik	muusik	muusik	02_S	SgN	et	muusik =muusik  (SgN  >muusik !02_S
26926	kolm	kolm	kolm	22_N	SgN	et	kolm =kolm  (SgN  >kolm !22_N
26930	voodist	voodi	voodi	01_S	SgEl	et	voodist =voodi  (SgEl  >voodi !01_S
26934	eemal	eemal	eemal	41_D	ID	et	eemal =eemal  (ID  >eemal !41_D
26935	viimseid	viimse	viimne	02_A	PlP	et	viimseid =viimse  (PlP  >viimne !02_A
26948	asju	asju	asi	24_S	PlP	et	asju =asju  (PlP  >asi !24_S
26951	reaalsed	reaalse	reaalne	02_A	PlN	et	reaalsed =reaalse  (PlN  >reaalne !02_A
26965	orduloss	loss	ordu+loss	22_S	SgN	et	orduloss =loss  (SgN  >ordu+loss !22_S
26966	instituut	instituut	instituut	22_S	SgN	et	instituut =instituut  (SgN  >instituut !22_S
26971	esimene	esimene	esimene	12_OP	SgN	et	esimene =esimene  (SgN  >esimene !12_OP
26976	soome	soome	soome	41_G	ID	et	soome =soome  (ID  >soome !41_G
26981	ütleb	ütle	ütlema	30_V	IndPrSg3	et	ütleb =ütle  (IndPrSg3  >ütlema !30_V
26983	tähendab	tähenda	tähendama	27_V	IndPrSg3	et	tähendab =tähenda  (IndPrSg3  >tähendama !27_V
26986	tallinnast	ast	tallinn+ast	22_S	SgN	et	tallinnast =ast  (SgN  >tallinn+ast !22_S
26991	eeltoodud	toodu	eel+toodu	01_S	PlN	et	eeltoodud =toodu  (PlN  >eel+toodu !01_S
26998	ümbruse	ümbruse	ümbrus	11~09_S	SgG	et	ümbruse =ümbruse  (SgG  >ümbrus !11~09_S
27010	saatus	saatus	saatus	11~09_S	SgN	et	saatus =saatus  (SgN  >saatus !11~09_S
27016	marga	marga	mark	22_S	SgG	et	marga =marga  (SgG  >mark !22_S
27018	talude	talu	talu	17_S	PlG	et	talude =talu  (PlG  >talu !17_S
27021	edaspidi	edaspidi	edas+pidi	41_D	ID	et	edaspidi =edaspidi  (ID  >edas+pidi !41_D
27029	vägede	väge	vägi	21_S	PlG	et	vägede =väge  (PlG  >vägi !21_S
27038	ostab	osta	ostma	34_V	IndPrSg3	et	ostab =osta  (IndPrSg3  >ostma !34_V
27047	võimalik	võimalik	võimalik	25_A	SgN	et	võimalik =võimalik  (SgN  >võimalik !25_A
27063	lammaste	lammas	lammas	07_S	PlG	et	lammaste =lammas  (PlG  >lammas !07_S
27068	sellepärast	sellepärast	selle+pärast	41_D	ID	et	sellepärast =sellepärast  (ID  >selle+pärast !41_D
27076	mõisniku	mõisniku	mõisnik	25_S	SgG	et	mõisniku =mõisniku  (SgG  >mõisnik !25_S
27079	külastas	külasta	külastama	27_V	IndIpfSg3	et	külastas =külasta  (IndIpfSg3  >külastama !27_V
27089	rahvajutud	jutu	rahva+jutt	22_S	PlN	et	rahvajutud =jutu  (PlN  >rahva+jutt !22_S
27091	sedagi	se	see	00_P	SgP^	et	sedagi =se  (SgP^  >see !00_P
27095	aastate	aasta	aasta	01_S	PlG	et	aastate =aasta  (PlG  >aasta !01_S
27104	piiritusevabriku	vabriku	piirituse+vabrik	02_S	SgG	et	piiritusevabriku =vabriku  (SgG  >piirituse+vabrik !02_S
27105	majapidamisega	pidamise	maja+pidamine	12_S	SgKom	et	majapidamisega =pidamise  (SgKom  >maja+pidamine !12_S
26857	kokku	kokku	kokku	41_D	ID	et	kokku =kokku  (ID  >kokku !41_D
26860	lõpetas	lõpeta	lõpetama	27_V	IndIpfSg3	et	lõpetas =lõpeta  (IndIpfSg3  >lõpetama !27_V
26863	koolikorralduse	korralduse	kooli+korraldus	11_S	SgG	et	koolikorralduse =korralduse  (SgG  >kooli+korraldus !11_S
26870	loosung	loosung	loosung	02_S	SgN	et	loosung =loosung  (SgN  >loosung !02_S
26878	soodustas	soodusta	soodustama	27_V	IndIpfSg3	et	soodustas =soodusta  (IndIpfSg3  >soodustama !27_V
26893	rahva	rahva	rahvas	07_S	SgG	et	rahva =rahva  (SgG  >rahvas !07_S
26894	demokraatlikud	demokraatliku	demokraatlik	25_A	PlN	et	demokraatlikud =demokraatliku  (PlN  >demokraatlik !25_A
26897	problemaatiline	problemaatiline	problemaatiline	12_A	SgN	et	problemaatiline =problemaatiline  (SgN  >problemaatiline !12_A
26899	protestant	protestant	protestant	22_S	SgN	et	protestant =protestant  (SgN  >protestant !22_S
26900	unustas	unusta	unustama	27_V	IndIpfSg3	et	unustas =unusta  (IndIpfSg3  >unustama !27_V
26902	milles	mille	mis	00_P	SgIn	et	milles =mille  (SgIn  >mis !00_P
26914	leidub	leidu	leiduma	27_V	IndPrSg3	et	leidub =leidu  (IndPrSg3  >leiduma !27_V
26920	aprillil	aprilli	aprill	22_S	SgAd	et	aprillil =aprilli  (SgAd  >aprill !22_S
26921	räägiti	räägi	rääkima	28_V	IndIpfIps	et	räägiti =räägi  (IndIpfIps  >rääkima !28_V
26927	tüdruku	tüdruku	tüdruk	02_S	SgG	et	tüdruku =tüdruku  (SgG  >tüdruk !02_S
26942	planeerib	planeeri	planeerima	28_V	IndPrSg3	et	planeerib =planeeri  (IndPrSg3  >planeerima !28_V
26952	läbiviimiseks	viimise	läbi+viimine	12?10_S	SgTr	et	läbiviimiseks =viimise  (SgTr  >läbi+viimine !12?10_S
26954	kavatsetakse	kavatse	kavatsema	27_V	IndPrIps	et	kavatsetakse =kavatse  (IndPrIps  >kavatsema !27_V
26955	suhe	suhe	suhe	06_S	SgN	et	suhe =suhe  (SgN  >suhe !06_S
26959	lisauuringuid	uuringu	lisa+uuring	02_S	PlP	et	lisauuringuid =uuringu  (PlP  >lisa+uuring !02_S
26972	tuleneb	tulene	tulenema	27_V	IndPrSg3	et	tuleneb =tulene  (IndPrSg3  >tulenema !27_V
26974	kivipank	pank	kivi+pank	22_S	SgN	et	kivipank =pank  (SgN  >kivi+pank !22_S
26975	pärineb	pärine	pärinema	27_V	IndPrSg3	et	pärineb =pärine  (IndPrSg3  >pärinema !27_V
26977	ligikaudu	ligikaudu	ligi+kaudu	41_D	ID	et	ligikaudu =ligikaudu  (ID  >ligi+kaudu !41_D
26984	hulk	hulk	hulk	22_S	SgN	et	hulk =hulk  (SgN  >hulk !22_S
26988	kivikamakat	kamaka	kivi+kamakas	02_S	SgP	et	kivikamakat =kamaka  (SgP  >kivi+kamakas !02_S
26996	harke	harke	hark	22_S	PlP	et	harke =harke  (PlP  >hark !22_S
27001	sugukonnamõis	mõis	sugu+konna+mõis	02_S	SgN	et	sugukonnamõis =mõis  (SgN  >sugu+konna+mõis !02_S
27002	viimasele	viimase	viimane	10_A	SgAll	et	viimasele =viimase  (SgAll  >viimane !10_A
27005	fakte	fakte	fakt	22_S	PlP	et	fakte =fakte  (PlP  >fakt !22_S
27014	eraomandina	omandi	era+omand	02_S	SgEs	et	eraomandina =omandi  (SgEs  >era+omand !02_S
27015	omanik	omanik	omanik	25_S	SgN	et	omanik =omanik  (SgN  >omanik !25_S
27019	külade	küla	küla	17_S	PlG	et	külade =küla  (PlG  >küla !17_S
27026	lesele	lese	lesk	22_S	SgAll	et	lesele =lese  (SgAll  >lesk !22_S
27028	lesk	lesk	lesk	22_S	SgN	et	lesk =lesk  (SgN  >lesk !22_S
27031	peakorter	korter	pea+korter	02_S	SgN	et	peakorter =korter  (SgN  >pea+korter !02_S
27034	garnison	garnison	garnison	19_S	SgN	et	garnison =garnison  (SgN  >garnison !19_S
27046	paljud	palju	palju	16_P	PlN	et	paljud =palju  (PlN  >palju !16_P
27049	suurim	suuri	suur	13_A	IM_sA	et	"suurim %suuri  )IM_sA  <suur ;13_A
27057	süvendatakse	süvenda	süvendama	27_V	IndPrIps	et	süvendatakse =süvenda  (IndPrIps  >süvendama !27_V
27060	peamiseks	peamise	peamine	12?10_A	SgTr	et	peamiseks =peamise  (SgTr  >peamine !12?10_A
27077	kohtades	kohta	koht	22_S	PlIn	et	kohtades =kohta  (PlIn  >koht !22_S
27084	hauale	haua	haud	22_S	SgAll	et	hauale =haua  (SgAll  >haud !22_S
27085	monument	monument	monument	22_S	SgN	et	monument =monument  (SgN  >monument !22_S
27093	lugudega	lugu	lugu	18_S	PlKom	et	lugudega =lugu  (PlKom  >lugu !18_S
27094	kuldmõõk	mõõk	kuld+mõõk	22_S	SgN	et	kuldmõõk =mõõk  (SgN  >kuld+mõõk !22_S
27099	püüab	püüa	püüdma	34_V	IndPrSg3	et	püüab =püüa  (IndPrSg3  >püüdma !34_V
27101	tegeleti	tegele	tegelema	27_V	IndIpfIps	et	tegeleti =tegele  (IndIpfIps  >tegelema !27_V
27102	karjakasvatamisega	kasvatamise	karja+kasvatamine	12_S	SgKom	et	karjakasvatamisega =kasvatamise  (SgKom  >karja+kasvatamine !12_S
27108	arvepidamist	pidamis	arve+pidamine	12_S	SgP	et	arvepidamist =pidamis  (SgP  >arve+pidamine !12_S
27113	majapidamist	pidamis	maja+pidamine	12_S	SgP	et	majapidamist =pidamis  (SgP  >maja+pidamine !12_S
27120	majapidamise	pidamise	maja+pidamine	12_S	SgG	et	majapidamise =pidamise  (SgG  >maja+pidamine !12_S
27126	põldroose	roose	põld+roos	22_S	PlP	et	põldroose =roose  (PlP  >põld+roos !22_S
27129	küljel	külje	külg	22_S	SgAd	et	küljel =külje  (SgAd  >külg !22_S
26994	siinset	siinse	siinne	02_A	SgP	et	siinset =siinse  (SgP  >siinne !02_A
27007	harkust	us	hark+uks	14_S	SgP	et	harkust =us  (SgP  >hark+uks !14_S
27009	kiviraidur	raidur	kivi+raidur	02_S	SgN	et	kiviraidur =raidur  (SgN  >kivi+raidur !02_S
27012	sajandil	sajandi	sajand	02_S	SgAd	et	sajandil =sajandi  (SgAd  >sajand !02_S
27017	noore	noore	noor	13_AS	SgG	et	noore =noore  (SgG  >noor !13_AS
27020	tekkib	tekki	tekkima	27_V	IndPrSg3	et	tekkib =tekki  (IndPrSg3  >tekkima !27_V
27023	kingib	kingi	kinkima	28_V	IndPrSg3	et	kingib =kingi  (IndPrSg3  >kinkima !28_V
27027	pärisomandina	omandi	päris+omand	02_S	SgEs	et	pärisomandina =omandi  (SgEs  >päris+omand !02_S
27032	septembril	septembri	september	02_S	SgAd	et	septembril =septembri  (SgAd  >september !02_S
27039	mõisat	mõisa	mõis	02_S	SgP	et	mõisat =mõisa  (SgP  >mõis !02_S
27042	kasumit	kasumi	kasum	02_S	SgP	et	kasumit =kasumi  (SgP  >kasum !02_S
27048	tast	ta	ta	00_P	SgEl	et	tast =ta  (SgEl  >ta !00_P
27065	rahvajutt	jutt	rahva+jutt	22_S	SgN	et	rahvajutt =jutt  (SgN  >rahva+jutt !22_S
27067	vandenõusse	nõu	vande+nõu	26_S	SgIll	et	vandenõusse =nõu  (SgIll  >vande+nõu !26_S
27071	endine	endine	endine	10~12_A	SgN	et	endine =endine  (SgN  >endine !10~12_A
27073	viimase	viimase	viimane	10_A	SgG	et	viimase =viimase  (SgG  >viimane !10_A
27087	praegugi	praegu	praegu	41_D	ID^	et	praegugi =praegu  (ID^  >praegu !41_D
27088	monumendi	monumendi	monument	22_S	SgG	et	monumendi =monumendi  (SgG  >monument !22_S
27111	muudab	muuda	muutma	34_V	IndPrSg3	et	muudab =muuda  (IndPrSg3  >muutma !34_V
27112	ajab	aja	ajama	27_V	IndPrSg3	et	ajab =aja  (IndPrSg3  >ajama !27_V
27114	park	park	park	22_S	SgN	et	park =park  (SgN  >park !22_S
27117	lihtrahval	rahva	liht+rahvas	07_S	SgAd	et	lihtrahval =rahva  (SgAd  >liht+rahvas !07_S
27118	minek	minek	minek	02_S	SgN	et	minek =minek  (SgN  >minek !02_S
27124	naisega	naise	naine	12_S	SgKom	et	naisega =naise  (SgKom  >naine !12_S
27128	radu	radu	rada	18_S	PlP	et	radu =radu  (PlP  >rada !18_S
27130	tunnikell	kell	tunni+kell	22_S	SgN	et	tunnikell =kell  (SgN  >tunni+kell !22_S
27132	pime	pime	pime	02_AS	SgN	et	pime =pime  (SgN  >pime !02_AS
27135	märgas	märga	märgama	29_V	IndIpfSg3	et	märgas =märga  (IndIpfSg3  >märgama !29_V
27147	kodanliku	kodanliku	kodanlik	25_A	SgG	et	kodanliku =kodanliku  (SgG  >kodanlik !25_A
27148	osakond	osakond	osakond	22_S	SgN	et	osakond =osakond  (SgN  >osakond !22_S
27150	vange	vange	vang	22_S	PlP	et	vange =vange  (PlP  >vang !22_S
27161	teaduste	teadus	teadus	11~09_S	PlG	et	teaduste =teadus  (PlG  >teadus !11~09_S
27165	asupaik	paik	asu+paik	22_S	SgN	et	asupaik =paik  (SgN  >asu+paik !22_S
27174	omaaegsest	aegse	oma+aegne	02_A	SgEl	et	omaaegsest =aegse  (SgEl  >oma+aegne !02_A
27184	vaatamas	vaata	vaatama	29_V	SupIn	et	vaatamas =vaata  (SupIn  >vaatama !29_V
27188	fotoarhiivis	arhiivi	foto+arhiiv	22_S	SgIn	et	fotoarhiivis =arhiivi  (SgIn  >foto+arhiiv !22_S
27196	tammesid	tamme	tamm	22_S	PlP	et	tammesid =tamme  (PlP  >tamm !22_S
27201	lugusid	lugu	lugu	18_S	PlP	et	lugusid =lugu  (PlP  >lugu !18_S
27210	fantaasiast	fantaasia	fantaasia	01_S	SgEl	et	fantaasiast =fantaasia  (SgEl  >fantaasia !01_S
27219	rahvajutu	jutu	rahva+jutt	22_S	SgG	et	rahvajutu =jutu  (SgG  >rahva+jutt !22_S
27224	mõisaansambel	ansambel	mõisa+ansambel	02_S	SgN	et	mõisaansambel =ansambel  (SgN  >mõisa+ansambel !02_S
27228	õukonna-	õukonna	õukond	22_S	SgG	et	õukonna- =õukonna  (SgG  >õukond !22_S
27229	riigiteenistuses	teenistuse	riigi+teenistus	11_S	SgIn	et	riigiteenistuses =teenistuse  (SgIn  >riigi+teenistus !11_S
27231	puuehitis	ehitis	puu+ehitis	11_S	SgN	et	puuehitis =ehitis  (SgN  >puu+ehitis !11_S
27236	paigutati	paiguta	paigutama	27_V	IndIpfIps	et	paigutati =paiguta  (IndIpfIps  >paigutama !27_V
27242	parunid	paruni	parun	02_S	PlN	et	parunid =paruni  (PlN  >parun !02_S
27245	andekad	andeka	andekas	02_A	PlN	et	andekad =andeka  (PlN  >andekas !02_A
27252	võimupositsioonidele	positsiooni	võimu+positsioon	22_S	PlAll	et	võimupositsioonidele =positsiooni  (PlAll  >võimu+positsioon !22_S
27255	dünastiaga	dünastia	dünastia	01_S	SgKom	et	dünastiaga =dünastia  (SgKom  >dünastia !01_S
27257	hõimukolooniat	koloonia	hõimu+koloonia	01_S	SgP	et	hõimukolooniat =koloonia  (SgP  >hõimu+koloonia !01_S
27259	sõpru	sõpru	sõber	24_S	PlP	et	sõpru =sõpru  (PlP  >sõber !24_S
27269	aknaga	akna	aken	08_S	SgKom	et	aknaga =akna  (SgKom  >aken !08_S
27275	andma	and	andma	34_V	Sup	et	andma =and  (Sup  >andma !34_V
27282	vabameelsete	meelse	vaba+meelne	02_A	PlG	et	vabameelsete =meelse  (PlG  >vaba+meelne !02_A
27289	segiläbi	segiläbi	segi+läbi	41_D	ID	et	segiläbi =segiläbi  (ID  >segi+läbi !41_D
27293	suviti	suviti	suviti	41_D	ID	et	suviti =suviti  (ID  >suviti !41_D
27054	istutakse	istu	istuma	28_V	IndPrIps	et	istutakse =istu  (IndPrIps  >istuma !28_V
27056	looduslik	looduslik	looduslik	25_A	SgN	et	looduslik =looduslik  (SgN  >looduslik !25_A
27059	tiigiks	tiigi	tiik	22_S	SgTr	et	tiigiks =tiigi  (SgTr  >tiik !22_S
27062	tegeletakse	tegele	tegelema	27_V	IndPrIps	et	tegeletakse =tegele  (IndPrIps  >tegelema !27_V
27064	viimane	viimane	viimane	10_A	SgN	et	viimane =viimane  (SgN  >viimane !10_A
27066	keisritapmise	tapmise	keisri+tapmine	12?10_S	SgG	et	keisritapmise =tapmise  (SgG  >keisri+tapmine !12?10_S
27069	metsas	metsa	mets	22_S	SgIn	et	metsas =metsa  (SgIn  >mets !22_S
27070	kinnitas	kinnita	kinnitama	27_V	IndIpfSg3	et	kinnitas =kinnita  (IndIpfSg3  >kinnitama !27_V
27075	varandust	varandus	varandus	11_S	SgP	et	varandust =varandus  (SgP  >varandus !11_S
27090	püüavad	püüa	püüdma	34_V	IndPrPl3	et	püüavad =püüa  (IndPrPl3  >püüdma !34_V
27096	müüb	müü	müüma	38_V	IndPrSg3	et	müüb =müü  (IndPrSg3  >müüma !38_V
27098	peremehed	mehe	pere+mees	13_S	PlN	et	peremehed =mehe  (PlN  >pere+mees !13_S
27103	ehitab	ehita	ehitama	27_V	IndPrSg3	et	ehitab =ehita  (IndPrSg3  >ehitama !27_V
27109	omanikule	omaniku	omanik	25_S	SgAll	et	omanikule =omaniku  (SgAll  >omanik !25_S
27116	puhtad	puhta	puhas	07_A	PlN	et	puhtad =puhta  (PlN  >puhas !07_A
27119	ratsapiitsaga	piitsa	ratsa+piits	22_S	SgKom	et	ratsapiitsaga =piitsa  (SgKom  >ratsa+piits !22_S
27122	mõisnik	mõisnik	mõisnik	25_S	SgN	et	mõisnik =mõisnik  (SgN  >mõisnik !25_S
27123	kinnitab	kinnita	kinnitama	27_V	IndPrSg3	et	kinnitab =kinnita  (IndPrSg3  >kinnitama !27_V
27133	meister	meister	meister	02_S	SgN	et	meister =meister  (SgN  >meister !02_S
27143	kell	kell	kell	22_S	SgN	et	kell =kell  (SgN  >kell !22_S
27151	turbatöödeks	töö	turba+töö	26_S	PlTr	et	turbatöödeks =töö  (PlTr  >turba+töö !26_S
27153	liivamägedes	mäge	liiva+mägi	21_S	PlIn	et	liivamägedes =mäge  (PlIn  >liiva+mägi !21_S
27163	tammed	tamme	tamm	22_S	PlN	et	tammed =tamme  (PlN  >tamm !22_S
27166	toetub	toetu	toetuma	27_V	IndPrSg3	et	toetub =toetu  (IndPrSg3  >toetuma !27_V
27167	motiividele	motiivi	motiiv	22_S	PlAll	et	motiividele =motiivi  (PlAll  >motiiv !22_S
27168	kindlaks	kindla	kindel	02_A	SgTr	et	kindlaks =kindla  (SgTr  >kindel !02_A
27171	muistendid	muistendi	muistend	02_S	PlN	et	muistendid =muistendi  (PlN  >muistend !02_S
27175	ehkki	ehkki	ehkki	41_J	ID	et	ehkki =ehkki  (ID  >ehkki !41_J
27185	tehti	teh	tegema	28_V	IndIpfIps	et	tehti =teh  (IndIpfIps  >tegema !28_V
27190	legend	legend	legend	22_S	SgN	et	legend =legend  (SgN  >legend !22_S
27192	elujõus	jõu	elu+jõud	22_S	SgIn	et	elujõus =jõu  (SgIn  >elu+jõud !22_S
27195	endistviisi	endistviisi	endist+viisi	41_D	ID	et	endistviisi =endistviisi  (ID  >endist+viisi !41_D
27199	tollases	tollase	tollane	10_A	SgIn	et	tollases =tollase  (SgIn  >tollane !10_A
27214	kirjanik	kirjanik	kirjanik	25_S	SgN	et	kirjanik =kirjanik  (SgN  >kirjanik !25_S
27215	paik	paik	paik	22_S	SgN	et	paik =paik  (SgN  >paik !22_S
27217	rahvasuust	suu	rahva+suu	26_S	SgEl	et	rahvasuust =suu  (SgEl  >rahva+suu !26_S
27223	asjatundlikul	tundliku	asja+tundlik	25_A	SgAd	et	asjatundlikul =tundliku  (SgAd  >asja+tundlik !25_A
27235	neoklassitsistlik	klassitsistlik	neo+klassitsistlik	25_A	SgN	et	neoklassitsistlik =klassitsistlik  (SgN  >neo+klassitsistlik !25_A
27241	häärberis	häärberi	häärber	02_S	SgIn	et	häärberis =häärberi  (SgIn  >häärber !02_S
27243	enamlased	enamlase	enamlane	12_S	PlN	et	enamlased =enamlase  (PlN  >enamlane !12_S
27246	talent	talent	talent	22_S	SgN	et	talent =talent  (SgN  >talent !22_S
27264	majandusliku	majandusliku	majanduslik	25_A	SgG	et	majandusliku =majandusliku  (SgG  >majanduslik !25_A
27270	taimelavade	lava	taime+lava	17_S	PlG	et	taimelavade =lava  (PlG  >taime+lava !17_S
27274	koguneti	kogune	kogunema	27_V	IndIpfIps	et	koguneti =kogune  (IndIpfIps  >kogunema !27_V
27276	lõdvaks	lõdva	lõtv	22_A	SgTr	et	lõdvaks =lõdva  (SgTr  >lõtv !22_A
27278	hoiakuga	hoiaku	hoiak	02_S	SgKom	et	hoiakuga =hoiaku  (SgKom  >hoiak !02_S
27281	tolerants	tolerants	tolerants	22_S	SgN	et	tolerants =tolerants  (SgN  >tolerants !22_S
27285	segadik	segadik	segadik	25_S	SgN	et	segadik =segadik  (SgN  >segadik !25_S
27306	turureisidel	reisi	turu+reis	22_S	PlAd	et	turureisidel =reisi  (PlAd  >turu+reis !22_S
27310	panuse	panuse	panus	09_S	SgG	et	panuse =panuse  (SgG  >panus !09_S
27315	õhtuni	õhtu	õhtu	01_S	SgTer	et	õhtuni =õhtu  (SgTer  >õhtu !01_S
27322	mäletatakse	mäleta	mäletama	27_V	IndPrIps	et	mäletatakse =mäleta  (IndPrIps  >mäletama !27_V
27325	vabahärrade	härra	vaba+härra	16_S	PlG	et	vabahärrade =härra  (PlG  >vaba+härra !16_S
27332	viimased	viimase	viimane	10_A	PlN	et	viimased =viimase  (PlN  >viimane !10_A
27335	suursaadiku	saadiku	suur+saadik	02_S	SgG	et	suursaadiku =saadiku  (SgG  >suur+saadik !02_S
27074	mõisnikuga	mõisniku	mõisnik	25_S	SgKom	et	mõisnikuga =mõisniku  (SgKom  >mõisnik !25_S
27078	elas	ela	elama	27_V	IndIpfSg3	et	elas =ela  (IndIpfSg3  >elama !27_V
27080	jättis	jätt	jätma	35_V	IndIpfSg3	et	jättis =jätt  (IndIpfSg3  >jätma !35_V
27081	ataman	ataman	ataman	19_S	SgN	et	ataman =ataman  (SgN  >ataman !19_S
27082	maeti	mae	matma	35_V	IndIpfIps	et	maeti =mae  (IndIpfIps  >matma !35_V
27083	pargis	pargi	park	22_S	SgIn	et	pargis =pargi  (SgIn  >park !22_S
27086	mägi	mägi	mägi	21_S	SgN	et	mägi =mägi  (SgN  >mägi !21_S
27092	siduda	sidu	siduma	28_V	Inf	et	siduda =sidu  (Inf  >siduma !28_V
27097	endised	endise	endine	10~12_A	PlN	et	endised =endise  (PlN  >endine !10~12_A
27100	pigistada	pigista	pigistama	27_V	Inf	et	pigistada =pigista  (Inf  >pigistama !27_V
27106	turul	turu	turg	22_S	SgAd	et	turul =turu  (SgAd  >turg !22_S
27110	eraomanik	omanik	era+omanik	25_S	SgN	et	eraomanik =omanik  (SgN  >era+omanik !25_S
27121	võimalusi	võimalusi	võimalus	11_S	PlP	et	võimalusi =võimalusi  (PlP  >võimalus !11_S
27131	ehitas	ehita	ehitama	27_V	IndIpfSg3	et	ehitas =ehita  (IndIpfSg3  >ehitama !27_V
27134	meistrit	meistri	meister	02_S	SgP	et	meistrit =meistri  (SgP  >meister !02_S
27137	kohendada	kohenda	kohendama	27_V	Inf	et	kohendada =kohenda  (Inf  >kohendama !27_V
27140	uuesti	uuesti	uuesti	41_D	ID	et	uuesti =uuesti  (ID  >uuesti !41_D
27156	kalmukünkaid	künka	kalmu+küngas	07_S	PlP	et	kalmukünkaid =künka  (PlP  >kalmu+küngas !07_S
27158	inimestelt	inimes	inimene	12_S	PlAbl	et	inimestelt =inimes  (PlAbl  >inimene !12_S
27159	andmeid	andme	anne	05_S	PlP	et	andmeid =andme  (PlP  >anne !05_S
27160	vanglas	vangla	vangla	01_S	SgIn	et	vanglas =vangla  (SgIn  >vangla !01_S
27162	tänapäevani	päeva	täna+päev	22_S	SgTer	et	tänapäevani =päeva  (SgTer  >täna+päev !22_S
27169	sealkandis	kandi	seal+kant	22_S	SgIn	et	sealkandis =kandi  (SgIn  >seal+kant !22_S
27178	saksakeelsest	keelse	saksa+keelne	02_A	SgEl	et	saksakeelsest =keelse  (SgEl  >saksa+keelne !02_A
27181	keldrit	keldri	kelder	02_S	SgP	et	keldrit =keldri  (SgP  >kelder !02_S
27193	pargist	pargi	park	22_S	SgEl	et	pargist =pargi  (SgEl  >park !22_S
27197	rahvapärimused	pärimuse	rahva+pärimus	11_S	PlN	et	rahvapärimused =pärimuse  (PlN  >rahva+pärimus !11_S
27203	aitas	aita	aitama	29_V	IndIpfSg3	et	aitas =aita  (IndIpfSg3  >aitama !29_V
27208	suures	suure	suur	13_A	SgIn	et	suures =suure  (SgIn  >suur !13_A
27211	legendid	legendi	legend	22_S	PlN	et	legendid =legendi  (PlN  >legend !22_S
27216	liikumas	liiku	liikuma	28_V	SupIn	et	liikumas =liiku  (SupIn  >liikuma !28_V
27220	praegusel	praeguse	praegune	10~12_A	SgAd	et	praegusel =praeguse  (SgAd  >praegune !10~12_A
27221	mälestusmärkide	märki	mälestus+märk	22_S	PlG	et	mälestusmärkide =märki  (PlG  >mälestus+märk !22_S
27222	organiseerida	organiseeri	organiseerima	28_V	Inf	et	organiseerida =organiseeri  (Inf  >organiseerima !28_V
27225	alates	ala	algama	29_V	Ger	et	alates =ala  (Ger  >algama !29_V
27227	lõpuni	lõpu	lõpp	22_SA	SgTer	et	lõpuni =lõpu  (SgTer  >lõpp !22_SA
27233	iseloomulikud	loomuliku	ise+loomulik	25_A	PlN	et	iseloomulikud =loomuliku  (PlN  >ise+loomulik !25_A
27239	korterimajana	maja	korteri+maja	17_S	SgEs	et	korterimajana =maja  (SgEs  >korteri+maja !17_S
27244	kirjeldab	kirjelda	kirjeldama	27_V	IndPrSg3	et	kirjeldab =kirjelda  (IndPrSg3  >kirjeldama !27_V
27247	sageli	sageli	sageli	41_D	ID	et	sageli =sageli  (ID  >sageli !41_D
27249	usust	usu	usk	22_S	SgEl	et	usust =usu  (SgEl  >usk !22_S
27250	teenistusse	teenistus	teenistus	11_S	SgAdt	et	teenistusse =teenistus  (SgAdt  >teenistus !11_S
27253	suurvürstliku	vürstliku	suur+vürstlik	25_A	SgG	et	suurvürstliku =vürstliku  (SgG  >suur+vürstlik !25_A
27261	seadusega	seaduse	seadus	11~09_S	SgKom	et	seadusega =seaduse  (SgKom  >seadus !11~09_S
27263	olukorra	korra	olu+kord	22_S	SgG	et	olukorra =korra  (SgG  >olu+kord !22_S
27266	käed	käe	käsi	15_S	PlN	et	käed =käe  (PlN  >käsi !15_S
27272	töötas	tööta	töötama	27_V	IndIpfSg3	et	töötas =tööta  (IndIpfSg3  >töötama !27_V
27277	boheemliku	boheemliku	boheemlik	25_A	SgG	et	boheemliku =boheemliku  (SgG  >boheemlik !25_A
27279	individualistid	individualisti	individualist	22_S	PlN	et	individualistid =individualisti  (PlN  >individualist !22_S
27280	venelik	venelik	venelik	25_A	SgN	et	venelik =venelik  (SgN  >venelik !25_A
27284	interjöör	interjöör	interjöör	22_S	SgN	et	interjöör =interjöör  (SgN  >interjöör !22_S
27286	muistsest	muistse	muistne	02_A	SgEl	et	muistsest =muistse  (SgEl  >muistne !02_A
27287	praegusest	praeguse	praegune	10~12_A	SgEl	et	praegusest =praeguse  (SgEl  >praegune !10~12_A
27290	pulktoolidega	tooli	pulk+tool	22_S	PlKom	et	pulktoolidega =tooli  (PlKom  >pulk+tool !22_S
27107	õiget	õige	õige	01_A	SgP	et	õiget =õige  (SgP  >õige !01_A
27115	hästi	hästi	hästi	41_D	ID	et	hästi =hästi  (ID  >hästi !41_D
27125	nähtub	nähtu	nähtuma	27_V	IndPrSg3	et	nähtub =nähtu  (IndPrSg3  >nähtuma !27_V
27127	põhjapoolsel	poolse	põhja+poolne	02_A	SgAd	et	põhjapoolsel =poolse  (SgAd  >põhja+poolne !02_A
27136	pettust	pettus	pettus	11~09_S	SgP	et	pettust =pettus  (SgP  >pettus !11~09_S
27139	meistreid	meistre	meister	02_S	PlP	et	meistreid =meistre  (PlP  >meister !02_S
27141	legendis	legendi	legend	22_S	SgIn	et	legendis =legendi  (SgIn  >legend !22_S
27142	vastuolud	olu	vastu+olu	17_S	PlN	et	vastuolud =olu  (PlN  >vastu+olu !17_S
27144	kindrali	kindrali	kindral	02_S	SgG	et	kindrali =kindrali  (SgG  >kindral !02_S
27152	lähedalasuvas	asuva	lähedal+asuv	02_A	SgIn	et	lähedalasuvas =asuva  (SgIn  >lähedal+asuv !02_A
27155	tegelike	tegelike	tegelik	25_A	PlG	et	tegelike =tegelike  (PlG  >tegelik !25_A
27164	tädipoeg	poeg	tädi+poeg	22_S	SgN	et	tädipoeg =poeg  (SgN  >tädi+poeg !22_S
27170	jüriööga	öö	jüri+öö	26_S	SgKom	et	jüriööga =öö  (SgKom  >jüri+öö !26_S
27172	vanad	vana	vana	17_AS	PlN	et	vanad =vana  (PlN  >vana !17_AS
27173	nimest	nime	nimi	20_S	SgEl	et	nimest =nime  (SgEl  >nimi !20_S
27176	kirjandusloolased	loolase	kirjandus+loolane	12?10_S	PlN	et	kirjandusloolased =loolase  (PlN  >kirjandus+loolane !12?10_S
27180	näitama	näita	näitama	29_V	Sup	et	näitama =näita  (Sup  >näitama !29_V
27183	käidi	käi	käima	38_V	IndIpfIps	et	käidi =käi  (IndIpfIps  >käima !38_V
27186	lossist	lossi	loss	22_S	SgEl	et	lossist =lossi  (SgEl  >loss !22_S
27187	fotod	foto	foto	16_S	PlN	et	fotod =foto  (PlN  >foto !16_S
27189	kännudki	kännu	känd	22_S	PlN^	et	kännudki =kännu  (PlN^  >känd !22_S
27200	ajakirjanduses	kirjanduse	aja+kirjandus	11_S	SgIn	et	ajakirjanduses =kirjanduse  (SgIn  >aja+kirjandus !11_S
27202	tõsiasjadena	asja	tõsi+asi	24_S	PlEs	et	tõsiasjadena =asja  (PlEs  >tõsi+asi !24_S
27204	levikule	leviku	levik	02_S	SgAll	et	levikule =leviku  (SgAll  >levik !02_S
27230	olles	oll	olema	36_V	Ger	et	olles =oll  (Ger  >olema !36_V
27232	arvukad	arvuka	arvukas	02_A	PlN	et	arvukad =arvuka  (PlN  >arvukas !02_A
27238	osakonnakeskuse	keskuse	osa+konna+keskus	11~09_S	SgG	et	osakonnakeskuse =keskuse  (SgG  >osa+konna+keskus !11~09_S
27240	pansionaat	pansionaat	pansionaat	22_S	SgN	et	pansionaat =pansionaat  (SgN  >pansionaat !22_S
27248	luterlane	luterlane	luterlane	12_S	SgN	et	luterlane =luterlane  (SgN  >luterlane !12_S
27258	võeti	võe	võtma	35_V	IndIpfIps	et	võeti =võe  (IndIpfIps  >võtma !35_V
27267	hoida	hoid	hoidma	34_V	Inf	et	hoida =hoid  (Inf  >hoidma !34_V
27271	parunessid	parunessi	paruness	22_S	PlN	et	parunessid =parunessi  (PlN  >paruness !22_S
27283	kunstnikuloomuga	loomu	kunstniku+loom	22_S	SgKom	et	kunstnikuloomuga =loomu  (SgKom  >kunstniku+loom !22_S
27288	rokokoomööbel	mööbel	rokokoo+mööbel	02_S	SgN	et	rokokoomööbel =mööbel  (SgN  >rokokoo+mööbel !02_S
27291	sooviti	soovi	soovima	28_V	IndIpfIps	et	sooviti =soovi  (IndIpfIps  >soovima !28_V
27292	uksed	ukse	uks	14_S	PlN	et	uksed =ukse  (PlN  >uks !14_S
27294	maalt	maa	maa	26_S	SgAbl	et	maalt =maa  (SgAbl  >maa !26_S
27295	noorele	noore	noor	13_AS	SgAll	et	noorele =noore  (SgAll  >noor !13_AS
27307	abistamas	abista	abistama	27_V	SupIn	et	abistamas =abista  (SupIn  >abistama !27_V
27309	kohtadest	kohta	koht	22_S	PlEl	et	kohtadest =kohta  (PlEl  >koht !22_S
27320	kunstlikest	kunstlike	kunstlik	25_A	PlEl	et	kunstlikest =kunstlike  (PlEl  >kunstlik !25_A
27329	tõi	tõ	tooma	38_V	IndIpfSg3	et	tõi =tõ  (IndIpfSg3  >tooma !38_V
27330	intensiivne	intensiivne	intensiivne	02_A	SgN	et	intensiivne =intensiivne  (SgN  >intensiivne !02_A
27338	sõideti	sõide	sõitma	34_V	IndIpfIps	et	sõideti =sõide  (IndIpfIps  >sõitma !34_V
27340	kiriku	kiriku	kirik	02_S	SgG	et	kiriku =kiriku  (SgG  >kirik !02_S
27343	lemm	lemm	lemm	22_S	SgN	et	lemm =lemm  (SgN  >lemm !22_S
27356	sepa-	sepa	sepp	22_S	SgG	et	sepa- =sepa  (SgG  >sepp !22_S
27357	omased	omase	omane	10_A	PlN	et	omased =omase  (PlN  >omane !10_A
27361	kogudusse	kogudus	kogudus	11_S	SgAdt	et	kogudusse =kogudus  (SgAdt  >kogudus !11_S
27366	palvetunnid	tunni	palve+tund	22_S	PlN	et	palvetunnid =tunni  (PlN  >palve+tund !22_S
27369	sajandite	sajandi	sajand	02_S	PlG	et	sajandite =sajandi  (PlG  >sajand !02_S
27372	üheks	ühe	üks	22_NP	SgTr	et	üheks =ühe  (SgTr  >üks !22_NP
27373	neorenessanss-	renessanss	neo+renessanss	22_S	SgN	et	neorenessanss- =renessanss  (SgN  >neo+renessanss !22_S
27376	sõja	sõja	sõda	18_S	SgG	et	sõja =sõja  (SgG  >sõda !18_S
27382	mölderile	mölderi	mölder	02_S	SgAll	et	mölderile =mölderi  (SgAll  >mölder !02_S
27388	vennad	venna	vend	22_S	PlN	et	vennad =venna  (PlN  >vend !22_S
27138	seisma	seis	seisma	32_V	Sup	et	seisma =seis  (Sup  >seisma !32_V
27145	harkusse	usse	hark+uss	22_S	PlP	et	harkusse =usse  (PlP  >hark+uss !22_S
27146	kurjategijate	tegija	kurja+tegija	01_S	PlG	et	kurjategijate =tegija  (PlG  >kurja+tegija !01_S
27149	kuhu	kuhu	kuhu	41_D	ID	et	kuhu =kuhu  (ID  >kuhu !41_D
27154	määratleda	määratle	määratlema	27_V	Inf	et	määratleda =määratle  (Inf  >määratlema !27_V
27157	buldooseriga	buldooseri	buldooser	02_S	SgKom	et	buldooseriga =buldooseri  (SgKom  >buldooser !02_S
27177	nimi	nimi	nimi	20_S	SgN	et	nimi =nimi  (SgN  >nimi !20_S
27179	elanikud	elaniku	elanik	25_S	PlN	et	elanikud =elaniku  (PlN  >elanik !25_S
27182	näidati	näida	näitama	29_V	IndIpfIps	et	näidati =näida  (IndIpfIps  >näitama !29_V
27191	täies	täie	täis	14_AS	SgIn	et	täies =täie  (SgIn  >täis !14_AS
27194	väärikate	väärika	väärikas	02_A	PlG	et	väärikate =väärika  (PlG  >väärikas !02_A
27198	esimese	esimese	esimene	12_OP	SgG	et	esimese =esimese  (SgG  >esimene !12_OP
27205	kirjandusteoseid	teose	kirjandus+teos	09_S	PlP	et	kirjandusteoseid =teose  (PlP  >kirjandus+teos !09_S
27206	faktidele	fakti	fakt	22_S	PlAll	et	faktidele =fakti  (PlAll  >fakt !22_S
27207	koosneb	koosne	koosnema	27_V	IndPrSg3	et	koosneb =koosne  (IndPrSg3  >koosnema !27_V
27209	kirjaniku	kirjaniku	kirjanik	25_S	SgG	et	kirjaniku =kirjaniku  (SgG  >kirjanik !25_S
27212	kangelane	kangelane	kangelane	12_S	SgN	et	kangelane =kangelane  (SgN  >kangelane !12_S
27213	saatusega	saatuse	saatus	11~09_S	SgKom	et	saatusega =saatuse  (SgKom  >saatus !11~09_S
27218	kirjeldada	kirjelda	kirjeldama	27_V	Inf	et	kirjeldada =kirjelda  (Inf  >kirjeldama !27_V
27226	mõisa-	mõisa	mõis	02_S	SgG	et	mõisa- =mõisa  (SgG  >mõis !02_S
27234	puidust	puidu	puit	22_S	SgEl	et	puidust =puidu  (SgEl  >puit !22_S
27237	mõisasse	mõisa	mõis	02_S	SgIll	et	mõisasse =mõisa  (SgIll  >mõis !02_S
27251	õukonnas	õukonna	õukond	22_S	SgIn	et	õukonnas =õukonna  (SgIn  >õukond !22_S
27254	kaudu	kaudu	kaudu	41_DK	ID	et	kaudu =kaudu  (ID  >kaudu !41_DK
27256	ootama	oota	ootama	29_V	Sup	et	ootama =oota  (Sup  >ootama !29_V
27260	sugulasi	sugulasi	sugulane	12_S	PlP	et	sugulasi =sugulasi  (PlP  >sugulane !12_S
27262	mõisasüda	süda	mõisa+süda	04_S	SgN	et	mõisasüda =süda  (SgN  >mõisa+süda !04_S
27265	mõisaelanikel	elanike	mõisa+elanik	25_S	PlAd	et	mõisaelanikel =elanike  (PlAd  >mõisa+elanik !25_S
27268	hektari	hektari	hektar	02_S	SgG	et	hektari =hektari  (SgG  >hektar !02_S
27273	neli	neli	neli	24_N	SgN	et	neli =neli  (SgN  >neli !24_N
27297	flirtimiseas	ea	flirtimis+iga	18_S	SgIn	et	flirtimiseas =ea  (SgIn  >flirtimis+iga !18_S
27299	hind	hind	hind	22_S	SgN	et	hind =hind  (SgN  >hind !22_S
27301	abistama	abista	abistama	27_V	Sup	et	abistama =abista  (Sup  >abistama !27_V
27303	atmosfäär	atmosfäär	atmosfäär	22_S	SgN	et	atmosfäär =atmosfäär  (SgN  >atmosfäär !22_S
27305	tädiga	tädi	tädi	17_S	SgKom	et	tädiga =tädi  (SgKom  >tädi !17_S
27321	kütketest	kütke	kütke	06_S	PlEl	et	kütketest =kütke  (PlEl  >kütke !06_S
27323	rannamõisat	mõisa	ranna+mõis	02_S	SgP	et	rannamõisat =mõisa  (SgP  >ranna+mõis !02_S
27331	suvilate	suvila	suvila	01_S	PlG	et	suvilate =suvila  (PlG  >suvila !01_S
27334	ümberehitusi	ehitusi	ümber+ehitus	11_S	PlP	et	ümberehitusi =ehitusi  (PlP  >ümber+ehitus !11_S
27336	residents	residents	residents	22_S	SgN	et	residents =residents  (SgN  >residents !22_S
27341	juulil	juuli	juuli	16_S	SgAd	et	juulil =juuli  (SgAd  >juuli !16_S
27347	autor	autor	autor	02_S	SgN	et	autor =autor  (SgN  >autor !02_S
27350	ranna	ranna	rand	22_S	SgG	et	ranna =ranna  (SgG  >rand !22_S
27354	kirikuõpetajaks	õpetaja	kiriku+õpetaja	01_S	SgTr	et	kirikuõpetajaks =õpetaja  (SgTr  >kiriku+õpetaja !01_S
27358	vabu	vabu	vaba	17_A	PlP	et	vabu =vabu  (PlP  >vaba !17_A
27362	jumalateenistused	teenistuse	jumala+teenistus	11_S	PlN	et	jumalateenistused =teenistuse  (PlN  >jumala+teenistus !11_S
27363	õhtuti	õhtuti	õhtuti	41_D	ID	et	õhtuti =õhtuti  (ID  >õhtuti !41_D
27367	tegutseb	tegutse	tegutsema	27_V	IndPrSg3	et	tegutseb =tegutse  (IndPrSg3  >tegutsema !27_V
27371	peetakse	pee	pidama	28_V	IndPrIps	et	peetakse =pee  (IndPrIps  >pidama !28_V
27374	ilmega	ilme	ilme	06_S	SgKom	et	ilmega =ilme  (SgKom  >ilme !06_S
27375	kasutas	kasuta	kasutama	27_V	IndIpfSg3	et	kasutas =kasuta  (IndIpfSg3  >kasutama !27_V
27377	orbudeks	orbu	orb	22_S	PlTr	et	orbudeks =orbu  (PlTr  >orb !22_S
27379	rist	rist	rist	22_S	SgN	et	rist =rist  (SgN  >rist !22_S
27384	vahelagedeta	lage	vahe+lagi	21_S	PlAb	et	vahelagedeta =lage  (PlAb  >vahe+lagi !21_S
27391	kirjanikud	kirjaniku	kirjanik	25_S	PlN	et	kirjanikud =kirjaniku  (PlN  >kirjanik !25_S
27395	triloogias	triloogia	triloogia	01_S	SgIn	et	triloogias =triloogia  (SgIn  >triloogia !01_S
27296	kolooniasse	koloonia	koloonia	01_S	SgIll	et	kolooniasse =koloonia  (SgIll  >koloonia !01_S
27302	majapidamises	pidamise	maja+pidamine	12_S	SgIn	et	majapidamises =pidamise  (SgIn  >maja+pidamine !12_S
27304	aednikust	aedniku	aednik	25_S	SgEl	et	aednikust =aedniku  (SgEl  >aednik !25_S
27311	noored	noore	noor	13_AS	PlN	et	noored =noore  (PlN  >noor !13_AS
27312	balalaikamäng	mäng	balalaika+mäng	22_S	SgN	et	balalaikamäng =mäng  (SgN  >balalaika+mäng !22_S
27313	noortele	noor	noor	13_AS	PlAll	et	noortele =noor  (PlAll  >noor !13_AS
27314	meeldis	meeldi	meeldima	27_V	IndIpfSg3	et	meeldis =meeldi  (IndIpfSg3  >meeldima !27_V
27317	pilv	pilv	pilv	22_S	SgN	et	pilv =pilv  (SgN  >pilv !22_S
27327	panga	panga	pank	22_S	SgG	et	panga =panga  (SgG  >pank !22_S
27333	aastad	aasta	aasta	01_S	PlN	et	aastad =aasta  (PlN  >aasta !01_S
27337	puhkepaik	paik	puhke+paik	22_S	SgN	et	puhkepaik =paik  (SgN  >puhke+paik !22_S
27344	pühitses	pühitse	pühitsema	27_V	IndIpfSg3	et	pühitses =pühitse  (IndIpfSg3  >pühitsema !27_V
27345	arhitekt	arhitekt	arhitekt	22_S	SgN	et	arhitekt =arhitekt  (SgN  >arhitekt !22_S
27346	taevaminek	minek	taeva+minek	02_S	SgN	et	taevaminek =minek  (SgN  >taeva+minek !02_S
27352	septembri	septembri	september	02_S	SgG	et	septembri =septembri  (SgG  >september !02_S
27370	mõisahäärberi	häärberi	mõisa+häärber	02_S	SgG	et	mõisahäärberi =häärberi  (SgG  >mõisa+häärber !02_S
27378	likvideeriti	likvideeri	likvideerima	28_V	IndIpfIps	et	likvideeriti =likvideeri  (IndIpfIps  >likvideerima !28_V
27380	ekslinnapeale	pea	eks+linna+pea	26_S	SgAll	et	ekslinnapeale =pea  (SgAll  >eks+linna+pea !26_S
27383	veebruaris	veebruari	veebruar	19_S	SgIn	et	veebruaris =veebruari  (SgIn  >veebruar !19_S
27389	aedniku	aedniku	aednik	25_S	SgG	et	aedniku =aedniku  (SgG  >aednik !25_S
27402	lähtus	lähtu	lähtuma	27_V	IndIpfSg3	et	lähtus =lähtu  (IndIpfSg3  >lähtuma !27_V
27404	kujundas	kujunda	kujundama	27_V	IndIpfSg3	et	kujundas =kujunda  (IndIpfSg3  >kujundama !27_V
27406	lakoonilise	lakoonilise	lakooniline	12_A	SgG	et	lakoonilise =lakoonilise  (SgG  >lakooniline !12_A
27409	ühiskonnategelastes	tegelas	ühis+konna+tegelane	12_S	PlIn	et	ühiskonnategelastes =tegelas  (PlIn  >ühis+konna+tegelane !12_S
27412	ühiskonnakriitilise	kriitilise	ühis+konna+kriitiline	12_A	SgG	et	ühiskonnakriitilise =kriitilise  (SgG  >ühis+konna+kriitiline !12_A
27414	olge	ol	olema	36_V	ImpPrPl2	et	olge =ol  (ImpPrPl2  >olema !36_V
27419	tuluüritused	ürituse	tulu+üritus	11_S	PlN	et	tuluüritused =ürituse  (PlN  >tulu+üritus !11_S
27423	õpis	õpi	õpp	22_S	SgIn	et	õpis =õpi  (SgIn  >õpp !22_S
27427	ajakirjades	kirja	aja+kiri	24_S	PlIn	et	ajakirjades =kirja  (PlIn  >aja+kiri !24_S
27428	päevaleht	leht	päeva+leht	22_S	SgN	et	päevaleht =leht  (SgN  >päeva+leht !22_S
27429	poliitiliste	poliitilis	poliitiline	12_A	PlG	et	poliitiliste =poliitilis  (PlG  >poliitiline !12_A
27434	tööpaigaks	paiga	töö+paik	22_S	SgTr	et	tööpaigaks =paiga  (SgTr  >töö+paik !22_S
27438	ajakirjanik	kirjanik	aja+kirjanik	25_S	SgN	et	ajakirjanik =kirjanik  (SgN  >aja+kirjanik !25_S
27439	lühiproosat	proosa	lühi+proosa	16_S	SgP	et	lühiproosat =proosa  (SgP  >lühi+proosa !16_S
27445	foon	foon	foon	22_S	SgN	et	foon =foon  (SgN  >foon !22_S
27448	isiku	isiku	isik	02_S	SgG	et	isiku =isiku  (SgG  >isik !02_S
27451	laiali	laiali	laiali	41_D	ID	et	laiali =laiali  (ID  >laiali !41_D
27455	niisugune	sugune	nii+sugune	10_P	SgN	et	niisugune =sugune  (SgN  >nii+sugune !10_P
27456	inimeses	inimese	inimene	12_S	SgIn	et	inimeses =inimese  (SgIn  >inimene !12_S
27459	kusagile	kusagile	kusagile	41_D	ID	et	kusagile =kusagile  (ID  >kusagile !41_D
27466	romaanid	romaani	romaan	22_S	PlN	et	romaanid =romaani  (PlN  >romaan !22_S
27468	kalle	kalle	kalle	06_S	SgN	et	kalle =kalle  (SgN  >kalle !06_S
27474	vähe	vähe	vähe	41_D	ID	et	vähe =vähe  (ID  >vähe !41_D
27496	suhted	suhte	suhe	06_S	PlN	et	suhted =suhte  (PlN  >suhe !06_S
27498	peegeldab	peegelda	peegeldama	27_V	IndPrSg3	et	peegeldab =peegelda  (IndPrSg3  >peegeldama !27_V
27500	kommenteeris	kommenteeri	kommenteerima	28_V	IndIpfSg3	et	kommenteeris =kommenteeri  (IndIpfSg3  >kommenteerima !28_V
27511	kriitikut	kriitiku	kriitik	02_S	SgP	et	kriitikut =kriitiku  (SgP  >kriitik !02_S
27512	sõnadel	sõna	sõna	17_S	PlAd	et	sõnadel =sõna  (PlAd  >sõna !17_S
27514	jälgib	jälgi	jälgima	27_V	IndPrSg3	et	jälgib =jälgi  (IndPrSg3  >jälgima !27_V
27517	eetilise	eetilise	eetiline	12_A	SgG	et	eetilise =eetilise  (SgG  >eetiline !12_A
27519	katsumusi	katsumusi	katsumus	11_S	PlP	et	katsumusi =katsumusi  (PlP  >katsumus !11_S
27521	järgses	järgse	järgne	02_A	SgIn	et	järgses =järgse  (SgIn  >järgne !02_A
27530	keskusena	keskuse	keskus	11~09_S	SgEs	et	keskusena =keskuse  (SgEs  >keskus !11~09_S
27531	regionaalse	regionaalse	regionaalne	02_A	SgG	et	regionaalse =regionaalse  (SgG  >regionaalne !02_A
27298	noort	noor	noor	13_AS	SgP	et	noort =noor  (SgP  >noor !13_AS
27300	soodne	soodne	soodne	02_A	SgN	et	soodne =soodne  (SgN  >soodne !02_A
27308	tilgaks	tilga	tilk	22_S	SgTr	et	tilgaks =tilga  (SgTr  >tilk !22_S
27316	otsekui	otsekui	otse+kui	41_J	ID	et	otsekui =otsekui  (ID  >otse+kui !41_J
27318	tsivilisatsioonist	tsivilisatsiooni	tsivilisatsioon	22_S	SgEl	et	tsivilisatsioonist =tsivilisatsiooni  (SgEl  >tsivilisatsioon !22_S
27319	armastusväärne	väärne	armastus+väärne	02_A	SgN	et	armastusväärne =väärne  (SgN  >armastus+väärne !02_A
27324	tsaarivalitsuse	valitsuse	tsaari+valitsus	11_S	SgG	et	tsaarivalitsuse =valitsuse  (SgG  >tsaari+valitsus !11_S
27326	eraomand	omand	era+omand	02_S	SgN	et	eraomand =omand  (SgN  >era+omand !02_S
27328	suvitusmõis	mõis	suvitus+mõis	02_S	SgN	et	suvitusmõis =mõis  (SgN  >suvitus+mõis !02_S
27348	allus	allu	alluma	27_V	IndIpfSg3	et	allus =allu  (IndIpfSg3  >alluma !27_V
27349	kogudusele	koguduse	kogudus	11_S	SgAll	et	kogudusele =koguduse  (SgAll  >kogudus !11_S
27360	probleem	probleem	probleem	22_S	SgN	et	probleem =probleem  (SgN  >probleem !22_S
27365	kirikus	kiriku	kirik	02_S	SgIn	et	kirikus =kiriku  (SgIn  >kirik !02_S
27390	omal	oma	oma	17_A	SgAd	et	omal =oma  (SgAd  >oma !17_A
27393	korrashoidmine	hoidmine	korras+hoidmine	12?10_S	SgN	et	korrashoidmine =hoidmine  (SgN  >korras+hoidmine !12?10_S
27401	albumile	albumi	album	02_S	SgAll	et	albumile =albumi  (SgAll  >album !02_S
27403	eeskujust	kuju	ees+kuju	17_S	SgEl	et	eeskujust =kuju  (SgEl  >ees+kuju !17_S
27407	joonekäsitluse	käsitluse	joone+käsitlus	11_S	SgG	et	joonekäsitluse =käsitluse  (SgG  >joone+käsitlus !11_S
27411	eeskätt	eeskätt	ees+kätt	41_D	ID	et	eeskätt =eeskätt  (ID  >ees+kätt !41_D
27413	loominguga	loomingu	looming	02_S	SgKom	et	loominguga =loomingu  (SgKom  >looming !02_S
27415	rõõmsad	rõõmsa	rõõmus	02_A	PlN	et	rõõmsad =rõõmsa  (PlN  >rõõmus !02_A
27416	seedin	seedi	seedima	27_V	IndPrSg1	et	seedin =seedi  (IndPrSg1  >seedima !27_V
27417	tööde	töö	töö	26_S	PlG	et	tööde =töö  (PlG  >töö !26_S
27421	kasvas	kasva	kasvama	28_V	IndIpfSg3	et	kasvas =kasva  (IndIpfSg3  >kasvama !28_V
27436	hääl	hääl	hääl	13_S	SgN	et	hääl =hääl  (SgN  >hääl !13_S
27440	ajakirjade	kirja	aja+kiri	24_S	PlG	et	ajakirjade =kirja  (PlG  >aja+kiri !24_S
27443	tihe	tihe	tihe	02_A	SgN	et	tihe =tihe  (SgN  >tihe !02_A
27446	esiplaanis	plaani	esi+plaan	22_S	SgIn	et	esiplaanis =plaani  (SgIn  >esi+plaan !22_S
27449	toimetulek	tulek	toime+tulek	02_S	SgN	et	toimetulek =tulek  (SgN  >toime+tulek !02_S
27452	maailmas	ilma	maa+ilm	22_S	SgIn	et	maailmas =ilma  (SgIn  >maa+ilm !22_S
27464	kokkusattumusi	sattumusi	kokku+sattumus	11_S	PlP	et	kokkusattumusi =sattumusi  (PlP  >kokku+sattumus !11_S
27473	kordustrükke	trükke	kordus+trükk	22_S	PlP	et	kordustrükke =trükke  (PlP  >kordus+trükk !22_S
27476	akna	akna	aken	08_S	SgG	et	akna =akna  (SgG  >aken !08_S
27478	tegeleb	tegele	tegelema	31~27_V	IndPrSg3	et	tegeleb =tegele  (IndPrSg3  >tegelema !31~27_V
27487	rõhk	rõhk	rõhk	22_S	SgN	et	rõhk =rõhk  (SgN  >rõhk !22_S
27488	külale	küla	küla	17_S	SgAll	et	külale =küla  (SgAll  >küla !17_S
27492	samasused	samasuse	samasus	11_S	PlN	et	samasused =samasuse  (PlN  >samasus !11_S
27499	sealelava	elava	seal+elav	02_A	SgG	et	sealelava =elava  (SgG  >seal+elav !02_A
27502	niisugust	sugus	nii+sugune	10_P	SgP	et	niisugust =sugus  (SgP  >nii+sugune !10_P
27507	kaaselatud	elatu	kaas+elatu	01_S	PlN	et	kaaselatud =elatu  (PlN  >kaas+elatu !01_S
27513	raamatutes	raamatu	raamat	02_S	PlIn	et	raamatutes =raamatu  (PlIn  >raamat !02_S
27522	olustik	olustik	olustik	25_S	SgN	et	olustik =olustik  (SgN  >olustik !25_S
27526	tasub	tasu	tasuma	27_V	IndPrSg3	et	tasub =tasu  (IndPrSg3  >tasuma !27_V
27528	tähtpäeval	päeva	täht+päev	22_S	SgAd	et	tähtpäeval =päeva  (SgAd  >täht+päev !22_S
27537	sõnade	sõna	sõna	17_S	PlG	et	sõnade =sõna  (PlG  >sõna !17_S
27538	reforme	reforme	reform	22_S	PlP	et	reforme =reforme  (PlP  >reform !22_S
27546	hindade	hinda	hind	22_S	PlG	et	hindade =hinda  (PlG  >hind !22_S
27548	liit	liit	liit	22_S	SgN	et	liit =liit  (SgN  >liit !22_S
27549	ülesanneks	anne	üles+and	22_S	PlTr	et	ülesanneks =anne  (PlTr  >üles+and !22_S
27553	demokratiseeriti	demokratiseeri	demokratiseerima	28_V	IndIpfIps	et	demokratiseeriti =demokratiseeri  (IndIpfIps  >demokratiseerima !28_V
27555	riikides	riiki	riik	22_S	PlIn	et	riikides =riiki  (PlIn  >riik !22_S
27556	kampaaniat	kampaania	kampaania	01_S	SgP	et	kampaaniat =kampaania  (SgP  >kampaania !01_S
27557	minna	minn	minema	36_V	Inf	et	minna =minn  (Inf  >minema !36_V
27565	rahumeelsed	meelse	rahu+meelne	02_A	PlN	et	rahumeelsed =meelse  (PlN  >rahu+meelne !02_A
27573	lauldi	laul	laulma	33_V	IndIpfIps	et	lauldi =laul  (IndIpfIps  >laulma !33_V
27339	kirik	kirik	kirik	02_S	SgN	et	kirik =kirik  (SgN  >kirik !02_S
27342	kindralsuperintendent	intendent	kindral+super+intendent	22_S	SgN	et	kindralsuperintendent =intendent  (SgN  >kindral+super+intendent !22_S
27351	kabeli	kabeli	kabel	02_S	SgG	et	kabeli =kabeli  (SgG  >kabel !02_S
27353	ametis	ameti	amet	02_S	SgIn	et	ametis =ameti  (SgIn  >amet !02_S
27355	puhm	puhm	puhm	22_S	SgN	et	puhm =puhm  (SgN  >puhm !22_S
27359	kalmistul	kalmistu	kalmistu	01_S	SgAd	et	kalmistul =kalmistu  (SgAd  >kalmistu !01_S
27364	piibli-	piibli	piibel	02_S	SgG	et	piibli- =piibli  (SgG  >piibel !02_S
27368	kontserte	kontserte	kontsert	22_S	PlP	et	kontserte =kontserte  (PlP  >kontsert !22_S
27381	jaan	jaan	jaan	22_S	SgN	et	jaan =jaan  (SgN  >jaan !22_S
27385	üles	üles	üles	41_D	ID	et	üles =üles  (ID  >üles !41_D
27386	kultuurimaailmas	ilma	kultuuri+maa+ilm	22_S	SgIn	et	kultuurimaailmas =ilma  (SgIn  >kultuuri+maa+ilm !22_S
27387	isikud	isiku	isik	02_S	PlN	et	isikud =isiku  (PlN  >isik !02_S
27394	teostes	teos	teos	09_S	PlIn	et	teostes =teos  (PlIn  >teos !09_S
27405	stiilse	stiilse	stiilne	02_A	SgG	et	stiilse =stiilse  (SgG  >stiilne !02_A
27447	moraalne	moraalne	moraalne	02_A	SgN	et	moraalne =moraalne  (SgN  >moraalne !02_A
27454	vaatlusobjektiks	objekti	vaatlus+objekt	22_S	SgTr	et	vaatlusobjektiks =objekti  (SgTr  >vaatlus+objekt !22_S
27457	varema	varema	varem	02_A	SgG	et	varema =varema  (SgG  >varem !02_A
27462	valeks	vale	vale	16_SA	SgTr	et	valeks =vale  (SgTr  >vale !16_SA
27469	novellikogud	kogu	novelli+kogu	17_S	PlN	et	novellikogud =kogu  (PlN  >novelli+kogu !17_S
27471	hädaohtlik	ohtlik	häda+ohtlik	25_A	SgN	et	hädaohtlik =ohtlik  (SgN  >häda+ohtlik !25_A
27477	kordustrükina	trüki	kordus+trükk	22_S	SgEs	et	kordustrükina =trüki  (SgEs  >kordus+trükk !22_S
27479	kordustrükkide	trükki	kordus+trükk	22_S	PlG	et	kordustrükkide =trükki  (PlG  >kordus+trükk !22_S
27485	läks	läk	minema	36_V	IndIpfSg3	et	läks =läk  (IndIpfSg3  >minema !36_V
27489	teosed	teose	teos	09_S	PlN	et	teosed =teose  (PlN  >teos !09_S
27491	peategelane	tegelane	pea+tegelane	12_S	SgN	et	peategelane =tegelane  (SgN  >pea+tegelane !12_S
27493	taustas	tausta	taust	22_S	SgIn	et	taustas =tausta  (SgIn  >taust !22_S
27494	külainimeste	inimes	küla+inimene	12_S	PlG	et	külainimeste =inimes  (PlG  >küla+inimene !12_S
27497	vahekord	kord	vahe+kord	22_S	SgN	et	vahekord =kord  (SgN  >vahe+kord !22_S
27504	eristada	erista	eristama	27_V	Inf	et	eristada =erista  (Inf  >eristama !27_V
27505	sündmused	sündmuse	sündmus	11~09_S	PlN	et	sündmused =sündmuse  (PlN  >sündmus !11~09_S
27506	autoriga	autori	autor	02_S	SgKom	et	autoriga =autori  (SgKom  >autor !02_S
27509	käekõrval	käekõrval	käe+kõrval	41_D	ID	et	käekõrval =käekõrval  (ID  >käe+kõrval !41_D
27515	eelkõige	eelkõige	eel+kõige	41_D	ID	et	eelkõige =eelkõige  (ID  >eel+kõige !41_D
27520	maailmasõja	sõja	maa+ilma+sõda	18_S	SgG	et	maailmasõja =sõja  (SgG  >maa+ilma+sõda !18_S
27524	rahvusliku	rahvusliku	rahvuslik	25_A	SgG	et	rahvusliku =rahvusliku  (SgG  >rahvuslik !25_A
27536	taasiseseisvumisel	seisvumise	taas+ise+seisvumine	12_S	SgAd	et	taasiseseisvumisel =seisvumise  (SgAd  >taas+ise+seisvumine !12_S
27539	riigis	riigi	riik	22_S	SgIn	et	riigis =riigi  (SgIn  >riik !22_S
27543	maailmakaardil	kaardi	maa+ilma+kaart	22_S	SgAd	et	maailmakaardil =kaardi  (SgAd  >maa+ilma+kaart !22_S
27545	kommunismivastaseid	vastase	kommunismi+vastane	10_AS	PlP	et	kommunismivastaseid =vastase  (PlP  >kommunismi+vastane !10_AS
27550	riigi	riigi	riik	22_S	SgG	et	riigi =riigi  (SgG  >riik !22_S
27559	keskkonnaprobleemid	probleemi	kesk+konna+probleem	22_S	PlN	et	keskkonnaprobleemid =probleemi  (PlN  >kesk+konna+probleem !22_S
27566	meeleavaldused	avalduse	meele+avaldus	11_S	PlN	et	meeleavaldused =avalduse  (PlN  >meele+avaldus !11_S
27579	kirjutada	kirjuta	kirjutama	27_V	Inf	et	kirjutada =kirjuta  (Inf  >kirjutama !27_V
27588	kõrgkoolide	kooli	kõrg+kool	22_S	PlG	et	kõrgkoolide =kooli  (PlG  >kõrg+kool !22_S
27598	luik	luik	luik	22_S	SgN	et	luik =luik  (SgN  >luik !22_S
27600	muusikas	muusika	muusika	01_S	SgIn	et	muusikas =muusika  (SgIn  >muusika !01_S
27608	tasemel	taseme	tase	04_S	SgAd	et	tasemel =taseme  (SgAd  >tase !04_S
27610	õppida	õppi	õppima	28_V	Inf	et	õppida =õppi  (Inf  >õppima !28_V
27611	filmikunst	kunst	filmi+kunst	22_S	SgN	et	filmikunst =kunst  (SgN  >filmi+kunst !22_S
27615	heliplaadid	plaadi	heli+plaat	22_S	PlN	et	heliplaadid =plaadi  (PlN  >heli+plaat !22_S
27619	olen	ole	olema	36_V	IndPrSg1	et	olen =ole  (IndPrSg1  >olema !36_V
27626	tahtsime	taht	tahtma	34_V	IndIpfPl1	et	tahtsime =taht  (IndIpfPl1  >tahtma !34_V
27628	sõita	sõit	sõitma	34_V	Inf	et	sõita =sõit  (Inf  >sõitma !34_V
27631	sugulastemajas	maja	sugu+laste+maja	17_S	SgIn	et	sugulastemajas =maja  (SgIn  >sugu+laste+maja !17_S
27392	lillepeenarde	peenar	lille+peenar	08_S	PlG	et	lillepeenarde =peenar  (PlG  >lille+peenar !08_S
27396	esimeses	esimese	esimene	12_OP	SgIn	et	esimeses =esimese  (SgIn  >esimene !12_OP
27398	raudnõges	nõges	raud+nõges	09_S	SgN	et	raudnõges =nõges  (SgN  >raud+nõges !09_S
27399	juunil	juuni	juuni	16_S	SgAd	et	juunil =juuni  (SgAd  >juuni !16_S
27408	humoristlikke	humoristlikke	humoristlik	25_A	PlP	et	humoristlikke =humoristlikke  (PlP  >humoristlik !25_A
27418	ballid	balli	ball	22_S	PlN	et	ballid =balli  (PlN  >ball !22_S
27420	korraldati	korralda	korraldama	27_V	IndIpfIps	et	korraldati =korralda  (IndIpfIps  >korraldama !27_V
27425	kodusõjas	sõja	kodu+sõda	18_S	SgIn	et	kodusõjas =sõja  (SgIn  >kodu+sõda !18_S
27433	staatus	staatus	staatus	11~09_S	SgN	et	staatus =staatus  (SgN  >staatus !11~09_S
27437	eluaegne	aegne	elu+aegne	02_A	SgN	et	eluaegne =aegne  (SgN  >elu+aegne !02_A
27441	loomingus	loomingu	looming	02_S	SgIn	et	loomingus =loomingu  (SgIn  >looming !02_S
27444	humanism	humanism	humanism	22_S	SgN	et	humanism =humanism  (SgN  >humanism !22_S
27453	tähele	tähe	täht	22_S	SgAll	et	tähele =tähe  (SgAll  >täht !22_S
27463	olemus	olemus	olemus	11_S	SgN	et	olemus =olemus  (SgN  >olemus !11_S
27467	õilis	õilis	õilis	03~05_A	SgN	et	õilis =õilis  (SgN  >õilis !03~05_A
27475	laev	laev	laev	22_S	SgN	et	laev =laev  (SgN  >laev !22_S
27481	artiklis	artikli	artikkel	02_S	SgIn	et	artiklis =artikli  (SgIn  >artikkel !02_S
27486	pärines	pärine	pärinema	27_V	IndIpfSg3	et	pärines =pärine  (IndIpfSg3  >pärinema !27_V
27490	perekondlikeks	perekondlike	perekondlik	25_A	PlTr	et	perekondlikeks =perekondlike  (PlTr  >perekondlik !25_A
27503	teostest	teos	teos	09_S	PlEl	et	teostest =teos  (PlEl  >teos !09_S
27510	laagrite	laagri	laager	02_S	PlG	et	laagrite =laagri  (PlG  >laager !02_S
27516	siseprobleeme	probleeme	sise+probleem	22_S	PlP	et	siseprobleeme =probleeme  (PlP  >sise+probleem !22_S
27525	varanduse	varanduse	varandus	11_S	SgG	et	varanduse =varanduse  (SgG  >varandus !11_S
27527	tänasel	tänase	tänane	10_A	SgAd	et	tänasel =tänase  (SgAd  >tänane !10_A
27529	keila-joale	joa	keila-juga	18_S	SgAll	et	keila-joale =joa  (SgAll  >keila-juga !18_S
27533	arengu	arengu	areng	02_S	SgG	et	arengu =arengu  (SgG  >areng !02_S
27542	liidu	liidu	liit	22_S	SgG	et	liidu =liidu  (SgG  >liit !22_S
27547	majandusblokaadiga	blokaadi	majandus+blokaad	22_S	SgKom	et	majandusblokaadiga =blokaadi  (SgKom  >majandus+blokaad !22_S
27551	pankrotist	pankroti	pankrot	22_S	SgEl	et	pankrotist =pankroti  (SgEl  >pankrot !22_S
27560	keskkonnakaitseklubid	klubi	kesk+konna+kaitse+klubi	17_S	PlN	et	keskkonnakaitseklubid =klubi  (PlN  >kesk+konna+kaitse+klubi !17_S
27563	saavutada	saavuta	saavutama	27_V	Inf	et	saavutada =saavuta  (Inf  >saavutama !27_V
27564	lauluväljakul	väljaku	laulu+väljak	02_S	SgAd	et	lauluväljakul =väljaku  (SgAd  >laulu+väljak !02_S
27567	avalikud	avaliku	avalik	25_A	PlN	et	avalikud =avaliku  (PlN  >avalik !25_A
27568	tahab	taha	tahtma	34_V	IndPrSg3	et	tahab =taha  (IndPrSg3  >tahtma !34_V
27574	isamaast	maa	isa+maa	26_S	SgEl	et	isamaast =maa  (SgEl  >isa+maa !26_S
27576	tugevnes	tugevne	tugevnema	27_V	IndIpfSg3	et	tugevnes =tugevne  (IndIpfSg3  >tugevnema !27_V
27582	koolides	kooli	kool	22_S	PlIn	et	koolides =kooli  (PlIn  >kool !22_S
27587	keskharidus	haridus	kesk+haridus	11_S	SgN	et	keskharidus =haridus  (SgN  >kesk+haridus !11_S
27591	iseseisvaks	seisva	ise+seisev	02_A	SgTr	et	iseseisvaks =seisva  (SgTr  >ise+seisev !02_A
27593	osakaal	kaal	osa+kaal	22_S	SgN	et	osakaal =kaal  (SgN  >osa+kaal !22_S
27595	kirjanikke	kirjanikke	kirjanik	25_S	PlP	et	kirjanikke =kirjanikke  (PlP  >kirjanik !25_S
27609	kusjuures	kusjuures	kus+juures	41_D	ID	et	kusjuures =kusjuures  (ID  >kus+juures !41_D
27617	defitsiit	defitsiit	defitsiit	22_S	SgN	et	defitsiit =defitsiit  (SgN  >defitsiit !22_S
27622	lennukiga	lennuki	lennuk	02_S	SgKom	et	lennukiga =lennuki  (SgKom  >lennuk !02_S
27624	eelistan	eelista	eelistama	27_V	IndPrSg1	et	eelistan =eelista  (IndPrSg1  >eelistama !27_V
27648	imetlesime	imetle	imetlema	27_V	IndIpfPl1	et	imetlesime =imetle  (IndIpfPl1  >imetlema !27_V
27649	tulime	tul	tulema	36_V	IndIpfPl1	et	tulime =tul  (IndIpfPl1  >tulema !36_V
27651	suvi	suvi	suvi	20_S	SgN	et	suvi =suvi  (SgN  >suvi !20_S
27657	jäätab	jääta	jäätama	27_V	IndPrSg3	et	jäätab =jääta  (IndPrSg3  >jäätama !27_V
27658	rannad	ranna	rand	22_S	PlN	et	rannad =ranna  (PlN  >rand !22_S
27664	mul	mu	ma	00_P	SgAd	et	mul =mu  (SgAd  >ma !00_P
27670	silmasin	silma	silmama	29_V	IndIpfSg1	et	silmasin =silma  (IndIpfSg1  >silmama !29_V
27684	kinod	kino	kino	17_S	PlN	et	kinod =kino  (PlN  >kino !17_S
27689	nõrgendab	nõrgenda	nõrgendama	27_V	IndPrSg3	et	nõrgendab =nõrgenda  (IndPrSg3  >nõrgendama !27_V
27698	millest	mille	mis	00_P	SgEl	et	millest =mille  (SgEl  >mis !00_P
27397	torn	torn	torn	22_S	SgN	et	torn =torn  (SgN  >torn !22_S
27400	joonistas	joonista	joonistama	27_V	IndIpfSg3	et	joonistas =joonista  (IndIpfSg3  >joonistama !27_V
27410	suri	sur	surema	36_V	IndIpfSg3	et	suri =sur  (IndIpfSg3  >surema !36_V
27422	põhjarannikul	ranniku	põhja+rannik	02_S	SgAd	et	põhjarannikul =ranniku  (SgAd  >põhja+rannik !02_S
27424	punaarmees	armee	puna+armee	26_S	SgIn	et	punaarmees =armee  (SgIn  >puna+armee !26_S
27426	ajakirjanikuna	kirjaniku	aja+kirjanik	25_S	SgEs	et	ajakirjanikuna =kirjaniku  (SgEs  >aja+kirjanik !25_S
27430	kodumaalt	maa	kodu+maa	26_S	SgAbl	et	kodumaalt =maa  (SgAbl  >kodu+maa !26_S
27431	usa-sse	usa	usa	xx_Q	SgIll	et	usa-sse =usa  (SgIll  >usa !xx_Q
27432	põgeniku	põgeniku	põgenik	25_S	SgG	et	põgeniku =põgeniku  (SgG  >põgenik !25_S
27435	ameerika	ameerika	ameerika	41_G	ID	et	ameerika =ameerika  (ID  >ameerika !41_G
27442	romaane	romaane	romaan	22_S	PlP	et	romaane =romaane  (PlP  >romaan !22_S
27450	enesesäilitamine	säilitamine	enese+säilitamine	12_S	SgN	et	enesesäilitamine =säilitamine  (SgN  >enese+säilitamine !12_S
27458	niivõrd	niivõrd	nii+võrd	41_D	ID	et	niivõrd =niivõrd  (ID  >nii+võrd !41_D
27460	patu	patu	patt	22_S	SgG	et	patu =patu  (SgG  >patt !22_S
27461	õilsaks	õilsa	õilis	03~05_A	SgTr	et	õilsaks =õilsa  (SgTr  >õilis !03~05_A
27465	paradokse	paradokse	paradoks	22_S	PlP	et	paradokse =paradokse  (PlP  >paradoks !22_S
27470	käega	käe	käsi	15_S	SgKom	et	käega =käe  (SgKom  >käsi !15_S
27472	eluajal	aja	elu+aeg	22_S	SgAd	et	eluajal =aja  (SgAd  >elu+aeg !22_S
27480	järelsõnade	sõna	järel+sõna	17_S	PlG	et	järelsõnade =sõna  (PlG  >järel+sõna !17_S
27482	kirjanikuks	kirjaniku	kirjanik	25_S	SgTr	et	kirjanikuks =kirjaniku  (SgTr  >kirjanik !25_S
27483	lendab	lenda	lendama	29_V	IndPrSg3	et	lendab =lenda  (IndPrSg3  >lendama !29_V
27484	romaanides	romaani	romaan	22_S	PlIn	et	romaanides =romaani  (PlIn  >romaan !22_S
27495	mõisarahva	rahva	mõisa+rahvas	07_S	SgG	et	mõisarahva =rahva  (SgG  >mõisa+rahvas !07_S
27501	elust	elu	elu	17_S	SgEl	et	elust =elu  (SgEl  >elu !17_S
27508	silmapilk	pilk	silma+pilk	22_S	SgN	et	silmapilk =pilk  (SgN  >silma+pilk !22_S
27518	kogemusi	kogemusi	kogemus	11_S	PlP	et	kogemusi =kogemusi  (PlP  >kogemus !11_S
27523	maailmavaade	vaade	maa+ilma+vaade	06_S	SgN	et	maailmavaade =vaade  (SgN  >maa+ilma+vaade !06_S
27532	kohaliku	kohaliku	kohalik	25_AS	SgG	et	kohaliku =kohaliku  (SgG  >kohalik !25_AS
27534	reisijuht	juht	reisi+juht	22_S	SgN	et	reisijuht =juht  (SgN  >reisi+juht !22_S
27535	a-te	a	a	xx_Q	PlG	et	a-te =a  (PlG  >a !xx_Q
27544	võidurelvastust	relvastus	võidu+relvastus	11_S	SgP	et	võidurelvastust =relvastus  (SgP  >võidu+relvastus !11_S
27552	väljaviimine	viimine	välja+viimine	12?10_S	SgN	et	väljaviimine =viimine  (SgN  >välja+viimine !12?10_S
27554	balti	balti	balti	41_G	ID	et	balti =balti  (ID  >balti !41_G
27562	oleme	ole	olema	36_V	IndPrPl1	et	oleme =ole  (IndPrPl1  >olema !36_V
27577	tsensuur	tsensuur	tsensuur	22_S	SgN	et	tsensuur =tsensuur  (SgN  >tsensuur !22_S
27578	enesetsensuur	tsensuur	enese+tsensuur	22_S	SgN	et	enesetsensuur =tsensuur  (SgN  >enese+tsensuur !22_S
27581	geograafiale	geograafia	geograafia	01_S	SgAll	et	geograafiale =geograafia  (SgAll  >geograafia !01_S
27585	kommunistlikud	kommunistliku	kommunistlik	25_A	PlN	et	kommunistlikud =kommunistliku  (PlN  >kommunistlik !25_A
27586	ühingud	ühingu	ühing	02_S	PlN	et	ühingud =ühingu  (PlN  >ühing !02_S
27589	kitsa	kitsa	kitsas	07_A	SgG	et	kitsa =kitsa  (SgG  >kitsas !07_A
27597	värsi	värsi	värss	22_S	SgG	et	värsi =värsi  (SgG  >värss !22_S
27604	harrastati	harrasta	harrastama	27_V	IndIpfIps	et	harrastati =harrasta  (IndIpfIps  >harrastama !27_V
27605	reaal	reaal	reaal	22_S	SgN	et	reaal =reaal  (SgN  >reaal !22_S
27612	raadiosaateid	saate	raadio+saade	06_S	PlP	et	raadiosaateid =saate  (PlP  >raadio+saade !06_S
27614	mõjutas	mõjuta	mõjutama	27_V	IndIpfSg3	et	mõjutas =mõjuta  (IndIpfSg3  >mõjutama !27_V
27620	tehnikaareng	areng	tehnika+areng	02_S	SgN	et	tehnikaareng =areng  (SgN  >tehnika+areng !02_S
27633	tundsin	tund	tundma	34_V	IndIpfSg1	et	tundsin =tund  (IndIpfSg1  >tundma !34_V
27636	linn	linn	linn	22_S	SgN	et	linn =linn  (SgN  >linn !22_S
27641	ööpäevas	päeva	öö+päev	22_S	SgIn	et	ööpäevas =päeva  (SgIn  >öö+päev !22_S
27645	ere	ere	ere	02_A	SgN	et	ere =ere  (SgN  >ere !02_A
27659	erisugused	suguse	eri+sugune	10_A	PlN	et	erisugused =suguse  (PlN  >eri+sugune !10_A
27661	usk	usk	usk	22_S	SgN	et	usk =usk  (SgN  >usk !22_S
27669	koduloomad	looma	kodu+loom	22_S	PlN	et	koduloomad =looma  (PlN  >kodu+loom !22_S
27673	tualett	tualett	tualett	22_S	SgN	et	tualett =tualett  (SgN  >tualett !22_S
27691	võin	või	võima	37_V	IndPrSg1	et	võin =või  (IndPrSg1  >võima !37_V
27540	riigid	riigi	riik	22_S	PlN	et	riigid =riigi  (PlN  >riik !22_S
27541	nõukogude	nõukogude	nõu+kogude	41_G	ID	et	nõukogude =nõukogude  (ID  >nõu+kogude !41_G
27558	avaldati	avalda	avaldama	27_V	IndIpfIps	et	avaldati =avalda  (IndIpfIps  >avaldama !27_V
27561	ühtekuuluvustunnet	tunne	ühte+kuuluvus+tunne	06_S	SgP	et	ühtekuuluvustunnet =tunne  (SgP  >ühte+kuuluvus+tunne !06_S
27569	vabaks	vaba	vaba	17_A	SgTr	et	vabaks =vaba  (SgTr  >vaba !17_A
27570	toetas	toeta	toetama	27_V	IndIpfSg3	et	toetas =toeta  (IndIpfSg3  >toetama !27_V
27571	kogunes	kogune	kogunema	27_V	IndIpfSg3	et	kogunes =kogune  (IndIpfSg3  >kogunema !27_V
27572	rahvalippe	lippe	rahva+lipp	22_S	PlP	et	rahvalippe =lippe  (PlP  >rahva+lipp !22_S
27575	heasse	hea	hea	26_AS	SgIll	et	heasse =hea  (SgIll  >hea !26_AS
27580	õpikutes	õpiku	õpik	02_S	PlIn	et	õpikutes =õpiku  (PlIn  >õpik !02_S
27584	propagandat	propaganda	propaganda	16_S	SgP	et	propagandat =propaganda  (SgP  >propaganda !16_S
27592	venekeelseid	keelse	vene+keelne	02_A	PlP	et	venekeelseid =keelse  (PlP  >vene+keelne !02_A
27596	kassetipõlvkond	põlvkond	kasseti+põlvkond	22_S	SgN	et	kassetipõlvkond =põlvkond  (SgN  >kasseti+põlvkond !22_S
27601	loobuti	loobu	loobuma	27_V	IndIpfIps	et	loobuti =loobu  (IndIpfIps  >loobuma !27_V
27602	skeemidest	skeemi	skeem	22_S	PlEl	et	skeemidest =skeemi  (PlEl  >skeem !22_S
27603	dodekafooniat	dodekafoonia	dodekafoonia	01_S	SgP	et	dodekafooniat =dodekafoonia  (SgP  >dodekafoonia !01_S
27606	kunst	kunst	kunst	22_S	SgN	et	kunst =kunst  (SgN  >kunst !22_S
27607	professionaalsel	professionaalse	professionaalne	02_A	SgAd	et	professionaalsel =professionaalse  (SgAd  >professionaalne !02_A
27616	näts	näts	näts	22_S	SgN	et	näts =näts  (SgN  >näts !22_S
27618	põlvkond	põlvkond	põlvkond	22_S	SgN	et	põlvkond =põlvkond  (SgN  >põlvkond !22_S
27623	autoga	auto	auto	16_S	SgKom	et	autoga =auto  (SgKom  >auto !16_S
27625	mugav	mugav	mugav	02_A	SgN	et	mugav =mugav  (SgN  >mugav !02_A
27630	ööbis	ööbi	ööbima	27_V	IndIpfSg3	et	ööbis =ööbi  (IndIpfSg3  >ööbima !27_V
27632	külastasin	külasta	külastama	27_V	IndIpfSg1	et	külastasin =külasta  (IndIpfSg1  >külastama !27_V
27635	pildid	pildi	pilt	22_S	PlN	et	pildid =pildi  (PlN  >pilt !22_S
27637	hämmastas	hämmasta	hämmastama	27_V	IndIpfSg3	et	hämmastas =hämmasta  (IndIpfSg3  >hämmastama !27_V
27647	suplesime	suple	suplema	30_V	IndIpfPl1	et	suplesime =suple  (IndIpfPl1  >suplema !30_V
27652	tunnetuslik	tunnetuslik	tunnetuslik	25_A	SgN	et	tunnetuslik =tunnetuslik  (SgN  >tunnetuslik !25_A
27655	lähen	lähe	minema	36_V	IndPrSg1	et	lähen =lähe  (IndPrSg1  >minema !36_V
27656	riik	riik	riik	22_S	SgN	et	riik =riik  (SgN  >riik !22_S
27672	äraolek	olek	ära+olek	02_S	SgN	et	äraolek =olek  (SgN  >ära+olek !02_S
27679	rahvused	rahvuse	rahvus	11~09_S	PlN	et	rahvused =rahvuse  (PlN  >rahvus !11~09_S
27688	istuda	istu	istuma	28_V	Inf	et	istuda =istu  (Inf  >istuma !28_V
27696	tulla	tull	tulema	36_V	Inf	et	tulla =tull  (Inf  >tulema !36_V
27699	tahan	taha	tahtma	34_V	IndPrSg1	et	tahan =taha  (IndPrSg1  >tahtma !34_V
27711	põnevaid	põneva	põnev	02_A	PlP	et	põnevaid =põneva  (PlP  >põnev !02_A
27713	nädalad	nädala	nädal	02_S	PlN	et	nädalad =nädala  (PlN  >nädal !02_S
27717	lennuk	lennuk	lennuk	02_S	SgN	et	lennuk =lennuk  (SgN  >lennuk !02_S
27723	sel	se	see	00_P	SgAd	et	sel =se  (SgAd  >see !00_P
27724	teavad	tea	teadma	34_V	IndPrPl3	et	teavad =tea  (IndPrPl3  >teadma !34_V
27728	elasime	ela	elama	27_V	IndIpfPl1	et	elasime =ela  (IndIpfPl1  >elama !27_V
27731	muuseumis	muuseumi	muuseum	19~02_S	SgIn	et	muuseumis =muuseumi  (SgIn  >muuseum !19~02_S
27734	ühel	ühe	üks	22_NP	SgAd	et	ühel =ühe  (SgAd  >üks !22_NP
27735	tore	tore	tore	02_A	SgN	et	tore =tore  (SgN  >tore !02_A
27739	öeldes	öel	ütlema	30_V	Ger	et	öeldes =öel  (Ger  >ütlema !30_V
27745	soovite	soovi	soovima	28_V	IndPrPl2	et	soovite =soovi  (IndPrPl2  >soovima !28_V
27753	lehed	lehe	leht	22_S	PlN	et	lehed =lehe  (PlN  >leht !22_S
27758	alustasin	alusta	alustama	27_V	IndIpfSg1	et	alustasin =alusta  (IndIpfSg1  >alustama !27_V
27763	sõpradega	sõpra	sõber	24_S	PlKom	et	sõpradega =sõpra  (PlKom  >sõber !24_S
27765	vestlesime	vestle	vestlema	30_V	IndIpfPl1	et	vestlesime =vestle  (IndIpfPl1  >vestlema !30_V
27769	väga-väga	väga	väga-väga	41_D	ID	et	väga-väga =väga  (ID  >väga-väga !41_D
27772	juuksur	juuksur	juuksur	02_S	SgN	et	juuksur =juuksur  (SgN  >juuksur !02_S
27781	kirikuga	kiriku	kirik	02_S	SgKom	et	kirikuga =kiriku  (SgKom  >kirik !02_S
27790	lennujaam	jaam	lennu+jaam	22_S	SgN	et	lennujaam =jaam  (SgN  >lennu+jaam !22_S
27791	pealinn	linn	pea+linn	22_S	SgN	et	pealinn =linn  (SgN  >pea+linn !22_S
27583	ateistliku	ateistliku	ateistlik	25_A	SgG	et	ateistliku =ateistliku  (SgG  >ateistlik !25_A
27590	spetsialiste	spetsialiste	spetsialist	22_S	PlP	et	spetsialiste =spetsialiste  (PlP  >spetsialist !22_S
27594	noorte	noor	noor	13_AS	PlG	et	noorte =noor  (PlG  >noor !13_AS
27599	traat	traat	traat	22_S	SgN	et	traat =traat  (SgN  >traat !22_S
27613	läänekultuur	kultuur	lääne+kultuur	22_S	SgN	et	läänekultuur =kultuur  (SgN  >lääne+kultuur !22_S
27621	reisima	reisi	reisima	28_V	Sup	et	reisima =reisi  (Sup  >reisima !28_V
27627	meri	meri	meri	20_S	SgN	et	meri =meri  (SgN  >meri !20_S
27629	linnades	linna	linn	22_S	PlIn	et	linnades =linna  (PlIn  >linn !22_S
27634	silmades	silma	silm	22_S	PlIn	et	silmades =silma  (PlIn  >silm !22_S
27638	arhitektuuriga	arhitektuuri	arhitektuur	22_S	SgKom	et	arhitektuuriga =arhitektuuri  (SgKom  >arhitektuur !22_S
27639	suurestest	reste	suu+rest	22_S	PlEl	et	suurestest =reste  (PlEl  >suu+rest !22_S
27640	peakirik	kirik	pea+kirik	02_S	SgN	et	peakirik =kirik  (SgN  >pea+kirik !02_S
27642	kuplid	kupli	kuppel	02_S	PlN	et	kuplid =kupli  (PlN  >kuppel !02_S
27654	maailm	ilm	maa+ilm	22_S	SgN	et	maailm =ilm  (SgN  >maa+ilm !22_S
27660	kultuurid	kultuuri	kultuur	22_S	PlN	et	kultuurid =kultuuri  (PlN  >kultuur !22_S
27662	ehitusstiilid	stiili	ehitus+stiil	22_S	PlN	et	ehitusstiilid =stiili  (PlN  >ehitus+stiil !22_S
27663	ilm	ilm	ilm	22_S	SgN	et	ilm =ilm  (SgN  >ilm !22_S
27665	sõit	sõit	sõit	22_S	SgN	et	sõit =sõit  (SgN  >sõit !22_S
27668	ümber	ümber	ümber	41_DK	ID	et	ümber =ümber  (ID  >ümber !41_DK
27671	lehm	lehm	lehm	22_S	SgN	et	lehm =lehm  (SgN  >lehm !22_S
27676	eluga	elu	elu	17_S	SgKom	et	eluga =elu  (SgKom  >elu !17_S
27678	rongijaamaga	jaama	rongi+jaam	22_S	SgKom	et	rongijaamaga =jaama  (SgKom  >rongi+jaam !22_S
27680	tahtsin	taht	tahtma	34_V	IndIpfSg1	et	tahtsin =taht  (IndIpfSg1  >tahtma !34_V
27682	igas	iga	iga	17_P	SgIn	et	igas =iga  (SgIn  >iga !17_P
27690	kinos	kino	kino	17_S	SgIn	et	kinos =kino  (SgIn  >kino !17_S
27695	oled	ole	olema	36_V	IndPrSg2	et	oled =ole  (IndPrSg2  >olema !36_V
27697	suurel	suure	suur	13_A	SgAd	et	suurel =suure  (SgAd  >suur !13_A
27704	sellisid	selli	sell	22_S	PlP	et	sellisid =selli  (PlP  >sell !22_S
27705	peaga	pea	pea	26_S	SgKom	et	peaga =pea  (SgKom  >pea !26_S
27709	loodan	looda	lootma	34_V	IndPrSg1	et	loodan =looda  (IndPrSg1  >lootma !34_V
27716	veepark	park	vee+park	22_S	SgN	et	veepark =park  (SgN  >vee+park !22_S
27718	kinni	kinni	kinni	41_D	ID	et	kinni =kinni  (ID  >kinni !41_D
27721	laupäeval	päeva	lau+päev	22_S	SgAd	et	laupäeval =päeva  (SgAd  >lau+päev !22_S
27727	perega	pere	pere	16_S	SgKom	et	perega =pere  (SgKom  >pere !16_S
27730	möödus	möödu	mööduma	27_V	IndIpfSg3	et	möödus =möödu  (IndIpfSg3  >mööduma !27_V
27738	muuseum	muuseum	muuseum	19~02_S	SgN	et	muuseum =muuseum  (SgN  >muuseum !19~02_S
27744	lõpu	lõpu	lõpp	22_SA	SgG	et	lõpu =lõpu  (SgG  >lõpp !22_SA
27749	sügis	sügis	sügis	09_S	SgN	et	sügis =sügis  (SgN  >sügis !09_S
27759	majja	majja	maja	17_S	SgAdt	et	majja =majja  (SgAdt  >maja !17_S
27766	süda	süda	süda	04_S	SgN	et	süda =süda  (SgN  >süda !04_S
27768	hingepõhjas	põhja	hinge+põhi	24_S	SgIn	et	hingepõhjas =põhja  (SgIn  >hinge+põhi !24_S
27770	armastan	armasta	armastama	27_V	IndPrSg1	et	armastan =armasta  (IndPrSg1  >armastama !27_V
27779	silmadega	silma	silm	22_S	PlKom	et	silmadega =silma  (PlKom  >silm !22_S
27785	linnad	linna	linn	22_S	PlN	et	linnad =linna  (PlN  >linn !22_S
27789	võistluses	võistluse	võistlus	11~09_S	SgIn	et	võistluses =võistluse  (SgIn  >võistlus !11~09_S
27793	tahaksin	taha	tahtma	34_V	KndPrSg1	et	tahaksin =taha  (KndPrSg1  >tahtma !34_V
27799	kaupluse	kaupluse	kauplus	11~09_S	SgG	et	kaupluse =kaupluse  (SgG  >kauplus !11~09_S
27801	jalgrattad	ratta	jalg+ratas	07_S	PlN	et	jalgrattad =ratta  (PlN  >jalg+ratas !07_S
27803	minuti	minuti	minut	02_S	SgG	et	minuti =minuti  (SgG  >minut !02_S
27804	rootslased	rootslase	rootslane	12?10_S	PlN	et	rootslased =rootslase  (PlN  >rootslane !12?10_S
27816	põleb	põle	põlema	27_V	IndPrSg3	et	põleb =põle  (IndPrSg3  >põlema !27_V
27823	tund	tund	tund	22_S	SgN	et	tund =tund  (SgN  >tund !22_S
27832	ilused	iluse	ilus	02_A	PlN	et	ilused =iluse  (PlN  >ilus !02_A
27837	tegin	teg	tegema	28_V	IndIpfSg1	et	tegin =teg  (IndIpfSg1  >tegema !28_V
27841	kirjanduse	kirjanduse	kirjandus	11_S	SgG	et	kirjanduse =kirjanduse  (SgG  >kirjandus !11_S
27842	hooaja	aja	hoo+aeg	22_S	SgG	et	hooaja =aja  (SgG  >hoo+aeg !22_S
27849	uuega	uue	uus	14_A	SgKom	et	uuega =uue  (SgKom  >uus !14_A
27643	lisavalgustuse	valgustuse	lisa+valgustus	11_S	SgG	et	lisavalgustuse =valgustuse  (SgG  >lisa+valgustus !11_S
27644	vaatepilt	pilt	vaate+pilt	22_S	SgN	et	vaatepilt =pilt  (SgN  >vaate+pilt !22_S
27646	päevitasime	päevita	päevitama	27_V	IndIpfPl1	et	päevitasime =päevita  (IndIpfPl1  >päevitama !27_V
27650	koju	koju	koju	41_D	ID	et	koju =koju  (ID  >koju !41_D
27653	aitab	aita	aitama	29_V	IndPrSg3	et	aitab =aita  (IndPrSg3  >aitama !29_V
27666	sõitsime	sõit	sõitma	34_V	IndIpfPl1	et	sõitsime =sõit  (IndIpfPl1  >sõitma !34_V
27667	imelik	imelik	imelik	25_A	SgN	et	imelik =imelik  (SgN  >imelik !25_A
27674	puhkuse	puhkuse	puhkus	11~09_S	SgG	et	puhkuse =puhkuse  (SgG  >puhkus !11~09_S
27675	elanik	elanik	elanik	25_S	SgN	et	elanik =elanik  (SgN  >elanik !25_S
27677	esiteks	esiteks	esiteks	41_D	ID	et	esiteks =esiteks  (ID  >esiteks !41_D
27681	kaaslasega	kaaslase	kaaslane	12?10_S	SgKom	et	kaaslasega =kaaslase  (SgKom  >kaaslane !12?10_S
27683	baarid	baari	baar	22_S	PlN	et	baarid =baari  (PlN  >baar !22_S
27685	teatrid	teatri	teater	02_S	PlN	et	teatrid =teatri  (PlN  >teater !02_S
27686	lemmikkoht	koht	lemmik+koht	22_S	SgN	et	lemmikkoht =koht  (SgN  >lemmik+koht !22_S
27687	armastab	armasta	armastama	27_V	IndPrSg3	et	armastab =armasta  (IndPrSg3  >armastama !27_V
27693	tahaks	taha	tahtma	34_V	KndPrPs	et	tahaks =taha  (KndPrPs  >tahtma !34_V
27701	seeni	seen	seen	13_S	PlP	et	seeni =seen  (PlP  >seen !13_S
27706	valged	valge	valge	01_AS	PlN	et	valged =valge  (PlN  >valge !01_AS
27708	külastan	külasta	külastama	27_V	IndPrSg1	et	külastan =külasta  (IndPrSg1  >külastama !27_V
27710	jätkan	jätka	jätkama	29_V	IndPrSg1	et	jätkan =jätka  (IndPrSg1  >jätkama !29_V
27715	lõpes	lõpe	lõpp	22_SA	PlIn	et	lõpes =lõpe  (PlIn  >lõpp !22_SA
27729	päev	päev	päev	22_S	SgN	et	päev =päev  (SgN  >päev !22_S
27746	sõitke	sõit	sõitma	34_V	ImpPrPl2	et	sõitke =sõit  (ImpPrPl2  >sõitma !34_V
27751	paistis	paist	paistma	34_V	IndIpfSg3	et	paistis =paist  (IndIpfSg3  >paistma !34_V
27752	tuul	tuul	tuul	13_S	SgN	et	tuul =tuul  (SgN  >tuul !13_S
27756	matk	matk	matk	22_S	SgN	et	matk =matk  (SgN  >matk !22_S
27762	leppisin	leppi	leppima	28_V	IndIpfSg1	et	leppisin =leppi  (IndIpfSg1  >leppima !28_V
27767	armas	armas	armas	03~05_A	SgN	et	armas =armas  (SgN  >armas !03~05_A
27783	panin	pan	panema	36_V	IndIpfSg1	et	panin =pan  (IndIpfSg1  >panema !36_V
27787	rootsis	rootsi	roots	22_S	SgIn	et	rootsis =rootsi  (SgIn  >roots !22_S
27796	maksab	maksa	maksma	32_V	IndPrSg3	et	maksab =maksa  (IndPrSg3  >maksma !32_V
27807	sõjaväest	väe	sõja+vägi	21_S	SgEl	et	sõjaväest =väe  (SgEl  >sõja+vägi !21_S
27812	reamehed	mehe	rea+mees	13_S	PlN	et	reamehed =mehe  (PlN  >rea+mees !13_S
27815	valvama	valva	valvama	29_V	Sup	et	valvama =valva  (Sup  >valvama !29_V
27820	asjadega	asja	asi	24_S	PlKom	et	asjadega =asja  (PlKom  >asi !24_S
27821	sõnaga	sõna	sõna	17_S	SgKom	et	sõnaga =sõna  (SgKom  >sõna !17_S
27829	jalgpalliga	palli	jalg+pall	22_S	SgKom	et	jalgpalliga =palli  (SgKom  >jalg+pall !22_S
27830	võtsin	võt	võtma	35_V	IndIpfSg1	et	võtsin =võt  (IndIpfSg1  >võtma !35_V
27839	igav	igav	igav	02_A	SgN	et	igav =igav  (SgN  >igav !02_A
27846	kel	ke	kes	00_P	SgAd	et	kel =ke  (SgAd  >kes !00_P
27851	seitse	seitse	seitse	05_N	SgN	et	seitse =seitse  (SgN  >seitse !05_N
27861	tahate	taha	tahtma	34_V	IndPrPl2	et	tahate =taha  (IndPrPl2  >tahtma !34_V
27867	esse	esse	ess	22_S	PlP	et	esse =esse  (PlP  >ess !22_S
27869	koguaeg	aeg	kogu+aeg	22_S	SgN	et	koguaeg =aeg  (SgN  >kogu+aeg !22_S
27875	tudengid	tudengi	tudeng	02_S	PlN	et	tudengid =tudengi  (PlN  >tudeng !02_S
27881	temal	tema	tema	00_P	SgAd	et	temal =tema  (SgAd  >tema !00_P
27892	puhkus	puhkus	puhkus	11~09_S	SgN	et	puhkus =puhkus  (SgN  >puhkus !11~09_S
27893	sõpradele	sõpra	sõber	24_S	PlAll	et	sõpradele =sõpra  (PlAll  >sõber !24_S
27902	palun	palu	paluma	27_V	IndPrSg1	et	palun =palu  (IndPrSg1  >paluma !27_V
27905	minule	minu	mina	00_P	SgAll	et	minule =minu  (SgAll  >mina !00_P
27907	proovin	proovi	proovima	28_V	IndPrSg1	et	proovin =proovi  (IndPrSg1  >proovima !28_V
27911	sillamäe	mäe	silla+mägi	21_S	SgG	et	sillamäe =mäe  (SgG  >silla+mägi !21_S
27912	pärnus	pärnu	pärnu	01_H	SgIn	et	pärnus =pärnu  (SgIn  >pärnu !01_H
27913	tartus	tartu	tartu	01_H	SgIn	et	tartus =tartu  (SgIn  >tartu !01_H
27915	hakkan	hakka	hakkama	29_V	IndPrSg1	et	hakkan =hakka  (IndPrSg1  >hakkama !29_V
27916	silmaring	ring	silma+ring	22_S	SgN	et	silmaring =ring  (SgN  >silma+ring !22_S
27922	venelane	venelane	venelane	12_S	SgN	et	venelane =venelane  (SgN  >venelane !12_S
27924	õppisin	õppi	õppima	28_V	IndIpfSg1	et	õppisin =õppi  (IndIpfSg1  >õppima !28_V
27692	hinnad	hinna	hind	22_S	PlN	et	hinnad =hinna  (PlN  >hind !22_S
27694	jutustada	jutusta	jutustama	27_V	Inf	et	jutustada =jutusta  (Inf  >jutustama !27_V
27700	mets	mets	mets	22_S	SgN	et	mets =mets  (SgN  >mets !22_S
27702	kärbseseene	seene	kärbse+seen	13_S	SgG	et	kärbseseene =seene  (SgG  >kärbse+seen !13_S
27707	säilitada	säilita	säilitama	27_V	Inf	et	säilitada =säilita  (Inf  >säilitama !27_V
27712	laupäev	päev	lau+päev	22_S	SgN	et	laupäev =päev  (SgN  >lau+päev !22_S
27714	vihm	vihm	vihm	22_S	SgN	et	vihm =vihm  (SgN  >vihm !22_S
27719	lennuki	lennuki	lennuk	02_S	SgG	et	lennuki =lennuki  (SgG  >lennuk !02_S
27720	olime	ol	olema	36_V	IndIpfPl1	et	olime =ol  (IndIpfPl1  >olema !36_V
27722	pildistan	pildista	pildistama	27_V	IndPrSg1	et	pildistan =pildista  (IndPrSg1  >pildistama !27_V
27732	meelde	meel	meel	13_S	SgAdt	et	meelde =meel  (SgAdt  >meel !13_S
27736	järgmine	järgmine	järgmine	12?10_A	SgN	et	järgmine =järgmine  (SgN  >järgmine !12?10_A
27737	veetsime	veet	veetma	34_V	IndIpfPl1	et	veetsime =veet  (IndIpfPl1  >veetma !34_V
27740	vendadele	venda	vend	22_S	PlAll	et	vendadele =venda  (PlAll  >vend !22_S
27743	meega	mee	mesi	15_S	SgKom	et	meega =mee  (SgKom  >mesi !15_S
27748	nädalal	nädala	nädal	02_S	SgAd	et	nädalal =nädala  (SgAd  >nädal !02_S
27750	kuldsel	kuldse	kuldne	02_A	SgAd	et	kuldsel =kuldse  (SgAd  >kuldne !02_A
27757	ääresse	ääre	äär	13_S	SgIll	et	ääresse =ääre  (SgIll  >äär !13_S
27760	ehitada	ehita	ehitama	27_V	Inf	et	ehitada =ehita  (Inf  >ehitama !27_V
27764	jalutasime	jaluta	jalutama	27_V	IndIpfPl1	et	jalutasime =jaluta  (IndIpfPl1  >jalutama !27_V
27773	tulin	tul	tulema	36_V	IndIpfSg1	et	tulin =tul  (IndIpfSg1  >tulema !36_V
27774	eesmärk	märk	ees+märk	22_S	SgN	et	eesmärk =märk  (SgN  >ees+märk !22_S
27777	mäletan	mäleta	mäletama	27_V	IndPrSg1	et	mäletan =mäleta  (IndPrSg1  >mäletama !27_V
27780	teleris	teleri	teler	02_S	SgIn	et	teleris =teleri  (SgIn  >teler !02_S
27792	korralikud	korraliku	korralik	25_A	PlN	et	korralikud =korraliku  (PlN  >korralik !25_A
27794	tooted	toote	toode	06_S	PlN	et	tooted =toote  (PlN  >toode !06_S
27795	kallid	kalli	kallis	05~07_A	PlN	et	kallid =kalli  (PlN  >kallis !05~07_A
27810	kursus	kursus	kursus	11~09_S	SgN	et	kursus =kursus  (SgN  >kursus !11~09_S
27813	ahivalvurina	valvuri	ahi+valvur	02_S	SgEs	et	ahivalvurina =valvuri  (SgEs  >ahi+valvur !02_S
27818	minutit	minuti	minut	02_S	SgP	et	minutit =minuti  (SgP  >minut !02_S
27819	tegelema	tegele	tegelema	31~27_V	Sup	et	tegelema =tegele  (Sup  >tegelema !31~27_V
27822	jalutasin	jaluta	jalutama	27_V	IndIpfSg1	et	jalutasin =jaluta  (IndIpfSg1  >jalutama !27_V
27827	sportlik	sportlik	sportlik	25_A	SgN	et	sportlik =sportlik  (SgN  >sportlik !25_A
27831	saime	sa	saama	37_V	IndIpfPl1	et	saime =sa  (IndIpfPl1  >saama !37_V
27834	treener	treener	treener	02_S	SgN	et	treener =treener  (SgN  >treener !02_S
27835	proovisime	proovi	proovima	28_V	IndIpfPl1	et	proovisime =proovi  (IndIpfPl1  >proovima !28_V
27838	september	september	september	02_S	SgN	et	september =september  (SgN  >september !02_S
27840	seepärast	seepärast	see+pärast	41_D	ID	et	seepärast =seepärast  (ID  >see+pärast !41_D
27843	külastada	külasta	külastama	27_V	Inf	et	külastada =külasta  (Inf  >külastama !27_V
27844	juhtus	juhtu	juhtuma	27_V	IndIpfSg3	et	juhtus =juhtu  (IndIpfSg3  >juhtuma !27_V
27845	õhtul	õhtu	õhtu	01_S	SgAd	et	õhtul =õhtu  (SgAd  >õhtu !01_S
27847	korteris	korteri	korter	02_S	SgIn	et	korteris =korteri  (SgIn  >korter !02_S
27854	ootasime	oota	ootama	29_V	IndIpfPl1	et	ootasime =oota  (IndIpfPl1  >ootama !29_V
27856	lähme	läh	minema	36_V	IndPrPl1	et	lähme =läh  (IndPrPl1  >minema !36_V
27860	mõtlen	mõtle	mõtlema	30_V	IndPrSg1	et	mõtlen =mõtle  (IndPrSg1  >mõtlema !30_V
27863	täisminevik	minevik	täis+minevik	25_S	SgN	et	täisminevik =minevik  (SgN  >täis+minevik !25_S
27868	kirjutama	kirjuta	kirjutama	27_V	Sup	et	kirjutama =kirjuta  (Sup  >kirjutama !27_V
27871	seale	sea	siga	18_SA	SgAll	et	seale =sea  (SgAll  >siga !18_SA
27873	minust	minu	mina	00_P	SgEl	et	minust =minu  (SgEl  >mina !00_P
27880	näib	näi	näima	37_V	IndPrSg3	et	näib =näi  (IndPrSg3  >näima !37_V
27883	mõtled	mõtle	mõtlema	30_V	IndPrSg2	et	mõtled =mõtle  (IndPrSg2  >mõtlema !30_V
27901	tantsisin	tantsi	tantsima	28_V	IndIpfSg1	et	tantsisin =tantsi  (IndIpfSg1  >tantsima !28_V
27910	elan	ela	elama	27_V	IndPrSg1	et	elan =ela  (IndPrSg1  >elama !27_V
27917	avanes	avane	avanema	27_V	IndIpfSg3	et	avanes =avane  (IndIpfSg3  >avanema !27_V
27925	lõpetan	lõpeta	lõpetama	27_V	IndPrSg1	et	lõpetan =lõpeta  (IndPrSg1  >lõpetama !27_V
27937	põnev	põnev	põnev	02_A	SgN	et	põnev =põnev  (SgN  >põnev !02_A
27703	iludusega	iluduse	iludus	11_S	SgKom	et	iludusega =iluduse  (SgKom  >iludus !11_S
27725	sõitsin	sõit	sõitma	34_V	IndIpfSg1	et	sõitsin =sõit  (IndIpfSg1  >sõitma !34_V
27726	bussiga	bussi	buss	22_S	SgKom	et	bussiga =bussi  (SgKom  >buss !22_S
27733	muinashauakambri	kambri	muinas+haua+kamber	02_S	SgG	et	muinashauakambri =kambri  (SgG  >muinas+haua+kamber !02_S
27741	paar	paar	paar	22_NS	SgN	et	paar =paar  (SgN  >paar !22_NS
27742	määrisime	määri	määrima	28_V	IndIpfPl1	et	määrisime =määri  (IndIpfPl1  >määrima !28_V
27747	eelmisel	eelmise	eelmine	12?10_A	SgAd	et	eelmisel =eelmise  (SgAd  >eelmine !12?10_A
27754	rändlinnud	linnu	ränd+lind	22_S	PlN	et	rändlinnud =linnu  (PlN  >ränd+lind !22_S
27755	teele	tee	tee	26_S	SgAll	et	teele =tee  (SgAll  >tee !26_S
27761	luiged	luige	luik	22_S	PlN	et	luiged =luige  (PlN  >luik !22_S
27771	professionaalne	professionaalne	professionaalne	02_A	SgN	et	professionaalne =professionaalne  (SgN  >professionaalne !02_A
27775	parendada	parenda	parendama	27_V	Inf	et	parendada =parenda  (Inf  >parendama !27_V
27776	oskust	oskus	oskus	11~09_S	SgP	et	oskust =oskus  (SgP  >oskus !11~09_S
27778	imestasin	imesta	imestama	27_V	IndIpfSg1	et	imestasin =imesta  (IndIpfSg1  >imestama !27_V
27782	märkama	märka	märkama	29_V	Sup	et	märkama =märka  (Sup  >märkama !29_V
27784	olete	ole	olema	36_V	IndPrPl2	et	olete =ole  (IndPrPl2  >olema !36_V
27786	elurütm	rütm	elu+rütm	22_S	SgN	et	elurütm =rütm  (SgN  >elu+rütm !22_S
27788	tegelen	tegele	tegelema	31~27_V	IndPrSg1	et	tegelen =tegele  (IndPrSg1  >tegelema !31~27_V
27798	sõidavad	sõida	sõitma	34_V	IndPrPl3	et	sõidavad =sõida  (IndPrPl3  >sõitma !34_V
27802	viie	viie	viis	14_N	SgG	et	viie =viie  (SgG  >viis !14_N
27805	jutustan	jutusta	jutustama	27_V	IndPrSg1	et	jutustan =jutusta  (IndPrSg1  >jutustama !27_V
27808	sõduri	sõduri	sõdur	02_S	SgG	et	sõduri =sõduri  (SgG  >sõdur !02_S
27811	telkis	telki	telkima	28_V	IndIpfSg3	et	telkis =telki  (IndIpfSg3  >telkima !28_V
27817	istusin	istu	istuma	28_V	IndIpfSg1	et	istusin =istu  (IndIpfSg1  >istuma !28_V
27824	mõtlesin	mõtle	mõtlema	30_V	IndIpfSg1	et	mõtlesin =mõtle  (IndIpfSg1  >mõtlema !30_V
27826	magama	maga	magama	27_V	Sup	et	magama =maga  (Sup  >magama !27_V
27833	rannas	ranna	rand	22_S	SgIn	et	rannas =ranna  (SgIn  >rand !22_S
27848	hilineb	hiline	hilinema	27_V	IndPrSg3	et	hilineb =hiline  (IndPrSg3  >hilinema !27_V
27850	inimestega	inimes	inimene	12_S	PlKom	et	inimestega =inimes  (PlKom  >inimene !12_S
27855	atmosfäärne	atmosfäärne	atmosfäärne	02_A	SgN	et	atmosfäärne =atmosfäärne  (SgN  >atmosfäärne !02_A
27857	muljate	mulja	muljas	02_A	PlG	et	muljate =mulja  (PlG  >muljas !02_A
27858	ttü-s	ttü	ttü	xx_Q	SgIn	et	ttü-s =ttü  (SgIn  >ttü !xx_Q
27878	kuulama	kuula	kuulama	29_V	Sup	et	kuulama =kuula  (Sup  >kuulama !29_V
27879	ärkama	ärka	ärkama	29_V	Sup	et	ärkama =ärka  (Sup  >ärkama !29_V
27887	jäin	jä	jääma	37_V	IndIpfSg1	et	jäin =jä  (IndIpfSg1  >jääma !37_V
27888	eksperimendi	eksperimendi	eksperiment	22_S	SgG	et	eksperimendi =eksperimendi  (SgG  >eksperiment !22_S
27890	reedel	reede	reede	01_S	SgAd	et	reedel =reede  (SgAd  >reede !01_S
27894	käisin	käi	käima	38_V	IndIpfSg1	et	käisin =käi  (IndIpfSg1  >käima !38_V
27897	telerit	teleri	teler	02_S	SgP	et	telerit =teleri  (SgP  >teler !02_S
27899	leiutada	leiuta	leiutama	27_V	Inf	et	leiutada =leiuta  (Inf  >leiutama !27_V
27900	jõin	jõ	jooma	38_V	IndIpfSg1	et	jõin =jõ  (IndIpfSg1  >jooma !38_V
27904	vihastuge	vihastu	vihastuma	27_V	ImpPrPl2	et	vihastuge =vihastu  (ImpPrPl2  >vihastuma !27_V
27908	eesnimi	nimi	ees+nimi	20_S	SgN	et	eesnimi =nimi  (SgN  >ees+nimi !20_S
27914	poiss	poiss	poiss	23?22_S	SgN	et	poiss =poiss  (SgN  >poiss !23?22_S
27933	ttü-st	ttü	ttü	xx_Q	SgEl	et	ttü-st =ttü  (SgEl  >ttü !xx_Q
27939	sõidan	sõida	sõitma	34_V	IndPrSg1	et	sõidan =sõida  (IndPrSg1  >sõitma !34_V
27947	alustada	alusta	alustama	27_V	Inf	et	alustada =alusta  (Inf  >alustama !27_V
27948	areneb	arene	arenema	27_V	IndPrSg3	et	areneb =arene  (IndPrSg3  >arenema !27_V
27956	lõvid	lõvi	lõvi	17_S	PlN	et	lõvid =lõvi  (PlN  >lõvi !17_S
27958	ütlesin	ütle	ütlema	30_V	IndIpfSg1	et	ütlesin =ütle  (IndIpfSg1  >ütlema !30_V
27962	ilmad	ilma	ilm	22_S	PlN	et	ilmad =ilma  (PlN  >ilm !22_S
27963	samad	sama	sama	17_P	PlN	et	samad =sama  (PlN  >sama !17_P
27967	vanaemal	ema	vana+ema	17_S	SgAd	et	vanaemal =ema  (SgAd  >vana+ema !17_S
27986	näevad	näe	nägema	28_V	IndPrPl3	et	näevad =näe  (IndPrPl3  >nägema !28_V
27991	seetõttu	seetõttu	see+tõttu	41_D	ID	et	seetõttu =seetõttu  (ID  >see+tõttu !41_D
27996	raamatukogud	kogu	raamatu+kogu	17_S	PlN	et	raamatukogud =kogu  (PlN  >raamatu+kogu !17_S
27797	jalgrattaga	ratta	jalg+ratas	07_S	SgKom	et	jalgrattaga =ratta  (SgKom  >jalg+ratas !07_S
27800	ess	ess	ess	22_S	SgN	et	ess =ess  (SgN  >ess !22_S
27806	sõjaväes	väe	sõja+vägi	21_S	SgIn	et	sõjaväes =väe  (SgIn  >sõja+vägi !21_S
27809	baas	baas	baas	22_S	SgN	et	baas =baas  (SgN  >baas !22_S
27814	ahivalvur	valvur	ahi+valvur	02_S	SgN	et	ahivalvur =valvur  (SgN  >ahi+valvur !02_S
27825	kaotasin	kaota	kaotama	27_V	IndIpfSg1	et	kaotasin =kaota  (IndIpfSg1  >kaotama !27_V
27828	tegelesin	tegele	tegelema	31~27_V	IndIpfSg1	et	tegelesin =tegele  (IndIpfSg1  >tegelema !31~27_V
27836	õlu	õlu	õlu	24_S	SgN	et	õlu =õlu  (SgN  >õlu !24_S
27852	alustas	alusta	alustama	27_V	IndIpfSg3	et	alustas =alusta  (IndIpfSg3  >alustama !27_V
27859	sõbrale	sõbra	sõber	24_S	SgAll	et	sõbrale =sõbra  (SgAll  >sõber !24_S
27865	mõtlete	mõtle	mõtlema	30_V	IndPrPl2	et	mõtlete =mõtle  (IndPrPl2  >mõtlema !30_V
27874	valima	vali	valima	27_V	Sup	et	valima =vali  (Sup  >valima !27_V
27876	vaatama	vaata	vaatama	29_V	Sup	et	vaatama =vaata  (Sup  >vaatama !29_V
27882	mõtlema	mõtle	mõtlema	30_V	Sup	et	mõtlema =mõtle  (Sup  >mõtlema !30_V
27885	eksperimendid	eksperimendi	eksperiment	22_S	PlN	et	eksperimendid =eksperimendi  (PlN  >eksperiment !22_S
27895	korter	korter	korter	02_S	SgN	et	korter =korter  (SgN  >korter !02_S
27903	ärge	är	ära	--_V	ImpPrPl2N	et	ärge =är  (ImpPrPl2N  >ära !--_V
27906	ütelge	ütel	ütlema	30_V	ImpPrPl2	et	ütelge =ütel  (ImpPrPl2  >ütlema !30_V
27920	tutvustan	tutvusta	tutvustama	27_V	IndPrSg1	et	tutvustan =tutvusta  (IndPrSg1  >tutvustama !27_V
27923	kontserdid	kontserdi	kontsert	22_S	PlN	et	kontserdid =kontserdi  (PlN  >kontsert !22_S
27927	õpin	õpi	õppima	28_V	IndPrSg1	et	õpin =õpi  (IndPrSg1  >õppima !28_V
27928	soov	soov	soov	22_S	SgN	et	soov =soov  (SgN  >soov !22_S
27929	esmaspäev	päev	esmas+päev	22_S	SgN	et	esmaspäev =päev  (SgN  >esmas+päev !22_S
27936	laisk	laisk	laisk	22_A	SgN	et	laisk =laisk  (SgN  >laisk !22_A
27941	hiiglane	hiiglane	hiiglane	12?10_S	SgN	et	hiiglane =hiiglane  (SgN  >hiiglane !12?10_S
27942	kõrged	kõrge	kõrge	01_A	PlN	et	kõrged =kõrge  (PlN  >kõrge !01_A
27943	mäe	mäe	mägi	21_S	SgG	et	mäe =mäe  (SgG  >mägi !21_S
27945	sipelgad	sipelga	sipelgas	02_S	PlN	et	sipelgad =sipelga  (PlN  >sipelgas !02_S
27946	vaade	vaade	vaade	06_S	SgN	et	vaade =vaade  (SgN  >vaade !06_S
27949	nautima	nauti	nautima	28_V	Sup	et	nautima =nauti  (Sup  >nautima !28_V
27950	sugulased	sugulase	sugulane	12_S	PlN	et	sugulased =sugulase  (PlN  >sugulane !12_S
27953	kõigepealt	kõigepealt	kõige+pealt	41_D	ID	et	kõigepealt =kõigepealt  (ID  >kõige+pealt !41_D
27955	lõpetades	lõpeta	lõpetama	27_V	Ger	et	lõpetades =lõpeta  (Ger  >lõpetama !27_V
27957	puutub	puutu	puutuma	27_V	IndPrSg3	et	puutub =puutu  (IndPrSg3  >puutuma !27_V
27960	veetama	vee	vedama	28_V	SupIps	et	veetama =vee  (SupIps  >vedama !28_V
27975	kontsert	kontsert	kontsert	22_S	SgN	et	kontsert =kontsert  (SgN  >kontsert !22_S
27978	reisisin	reisi	reisima	28_V	IndIpfSg1	et	reisisin =reisi  (IndIpfSg1  >reisima !28_V
27993	sõbra	sõbra	sõber	24_S	SgG	et	sõbra =sõbra  (SgG  >sõber !24_S
28000	eestil	eesti	eesti	16_H	SgAd	et	eestil =eesti  (SgAd  >eesti !16_H
28022	kassid	kassi	kass	22_S	PlN	et	kassid =kassi  (PlN  >kass !22_S
28025	piletid	pileti	pilet	02_S	PlN	et	piletid =pileti  (PlN  >pilet !02_S
28026	pehmed	pehme	pehme	01_A	PlN	et	pehmed =pehme  (PlN  >pehme !01_A
28052	kasutame	kasuta	kasutama	27_V	IndPrPl1	et	kasutame =kasuta  (IndPrPl1  >kasutama !27_V
28053	telerita	teleri	teler	02_S	SgAb	et	telerita =teleri  (SgAb  >teler !02_S
28057	perenaisele	naise	pere+naine	12_S	SgAll	et	perenaisele =naise  (SgAll  >pere+naine !12_S
28059	tööl	töö	töö	26_S	SgAd	et	tööl =töö  (SgAd  >töö !26_S
28064	jõudsime	jõud	jõudma	34_V	IndIpfPl1	et	jõudsime =jõud  (IndIpfPl1  >jõudma !34_V
28068	palk	palk	palk	22_S	SgN	et	palk =palk  (SgN  >palk !22_S
28076	peamised	peamise	peamine	12?10_A	PlN	et	peamised =peamise  (PlN  >peamine !12?10_A
28081	otsustas	otsusta	otsustama	27_V	IndIpfSg3	et	otsustas =otsusta  (IndIpfSg3  >otsustama !27_V
28083	jumalat	jumala	jumal	02_S	SgP	et	jumalat =jumala  (SgP  >jumal !02_S
28084	seadused	seaduse	seadus	11~09_S	PlN	et	seadused =seaduse  (PlN  >seadus !11~09_S
28091	kohustuslik	kohustuslik	kohustuslik	25_A	SgN	et	kohustuslik =kohustuslik  (SgN  >kohustuslik !25_A
28095	ühtne	ühtne	ühtne	02_A	SgN	et	ühtne =ühtne  (SgN  >ühtne !02_A
28099	tugevasti	tugevasti	tugevasti	41_D	ID	et	tugevasti =tugevasti  (ID  >tugevasti !41_D
28106	tänases	tänase	tänane	10_A	SgIn	et	tänases =tänase  (SgIn  >tänane !10_A
28110	tahtis	taht	tahtma	34_V	IndIpfSg3	et	tahtis =taht  (IndIpfSg3  >tahtma !34_V
27853	lüürilised	lüürilise	lüüriline	12_A	PlN	et	lüürilised =lüürilise  (PlN  >lüüriline !12_A
27862	lihtminevik	minevik	liht+minevik	25_S	SgN	et	lihtminevik =minevik  (SgN  >liht+minevik !25_S
27864	enneminevik	minevik	enne+minevik	25_S	SgN	et	enneminevik =minevik  (SgN  >enne+minevik !25_S
27866	teen	tee	tegema	28_V	IndPrSg1	et	teen =tee  (IndPrSg1  >tegema !28_V
27870	teisepäeval	päeva	teise+päev	22_S	SgAd	et	teisepäeval =päeva  (SgAd  >teise+päev !22_S
27872	inimeste	inimes	inimene	12_S	PlG	et	inimeste =inimes  (PlG  >inimene !12_S
27877	kodutööga	töö	kodu+töö	26_S	SgKom	et	kodutööga =töö  (SgKom  >kodu+töö !26_S
27884	hommikul	hommiku	hommik	02_S	SgAd	et	hommikul =hommiku  (SgAd  >hommik !02_S
27886	füüsikas	füüsika	füüsika	01_S	SgIn	et	füüsikas =füüsika  (SgIn  >füüsika !01_S
27889	võlg	võlg	võlg	22_S	SgN	et	võlg =võlg  (SgN  >võlg !22_S
27891	puhkused	puhkuse	puhkus	11~09_S	PlN	et	puhkused =puhkuse  (PlN  >puhkus !11~09_S
27896	puhkasin	puhka	puhkama	29_V	IndIpfSg1	et	puhkasin =puhka  (IndIpfSg1  >puhkama !29_V
27898	hakkasin	hakka	hakkama	29_V	IndIpfSg1	et	hakkasin =hakka  (IndIpfSg1  >hakkama !29_V
27909	perekonnanimi	nimi	pere+konna+nimi	20_S	SgN	et	perekonnanimi =nimi  (SgN  >pere+konna+nimi !20_S
27918	vanas	vana	vana	17_AS	SgIn	et	vanas =vana  (SgIn  >vana !17_AS
27919	toredad	toreda	tore	02_A	PlN	et	toredad =toreda  (PlN  >tore !02_A
27921	suhtlen	suhtle	suhtlema	30_V	IndPrSg1	et	suhtlen =suhtle  (IndPrSg1  >suhtlema !30_V
27930	keelega	keele	keel	13_S	SgKom	et	keelega =keele  (SgKom  >keel !13_S
27935	tunnile	tunni	tund	22_S	SgAll	et	tunnile =tunni  (SgAll  >tund !22_S
27944	näis	näi	näima	37_V	IndIpfSg3	et	näis =näi  (IndIpfSg3  >näima !37_V
27951	relvad	relva	relv	22_S	PlN	et	relvad =relva  (PlN  >relv !22_S
27954	venelased	venelase	venelane	12_S	PlN	et	venelased =venelase  (PlN  >venelane !12_S
27971	klubides	klubi	klubi	17_S	PlIn	et	klubides =klubi  (PlIn  >klubi !17_S
27979	reisin	reisi	reisima	28_V	IndPrSg1	et	reisin =reisi  (IndPrSg1  >reisima !28_V
27980	tartul	tartu	tartu	01_H	SgAd	et	tartul =tartu  (SgAd  >tartu !01_H
27982	vahvat	vahva	vahva	01_A	SgP	et	vahvat =vahva  (SgP  >vahva !01_A
27984	käisime	käi	käima	38_V	IndIpfPl1	et	käisime =käi  (IndIpfPl1  >käima !38_V
27995	muuseumid	muuseumi	muuseum	19~02_S	PlN	et	muuseumid =muuseumi  (PlN  >muuseum !19~02_S
28005	ootasin	oota	ootama	29_V	IndIpfSg1	et	ootasin =oota  (IndIpfSg1  >ootama !29_V
28007	garderoobisse	garderoobi	garderoob	22_S	SgIll	et	garderoobisse =garderoobi  (SgIll  >garderoob !22_S
28013	vaatas	vaata	vaatama	29_V	IndIpfSg3	et	vaatas =vaata  (IndIpfSg3  >vaatama !29_V
28016	pidin	pid	pida	40_V	IndIpfSg1	et	pidin =pid  (IndIpfSg1  >pida !40_V
28017	kuulatlesin	kuulatle	kuulatlema	27_V	IndIpfSg1	et	kuulatlesin =kuulatle  (IndIpfSg1  >kuulatlema !27_V
28018	akadeemilise	akadeemilise	akadeemiline	12_A	SgG	et	akadeemilise =akadeemilise  (SgG  >akadeemiline !12_A
28020	teisipäev	päev	teisi+päev	22_S	SgN	et	teisipäev =päev  (SgN  >teisi+päev !22_S
28021	kassinäitus	näitus	kassi+näitus	11~09_S	SgN	et	kassinäitus =näitus  (SgN  >kassi+näitus !11~09_S
28023	lemmik	lemmik	lemmik	02_S	SgN	et	lemmik =lemmik  (SgN  >lemmik !02_S
28033	toit	toit	toit	22_S	SgN	et	toit =toit  (SgN  >toit !22_S
28040	tööle	töö	töö	26_S	SgAll	et	tööle =töö  (SgAll  >töö !26_S
28043	triikisin	triiki	triikima	28_V	IndIpfSg1	et	triikisin =triiki  (IndIpfSg1  >triikima !28_V
28049	teler	teler	teler	02_S	SgN	et	teler =teler  (SgN  >teler !02_S
28050	pliit	pliit	pliit	22_S	SgN	et	pliit =pliit  (SgN  >pliit !22_S
28055	külmikuta	külmiku	külmik	02_S	SgAb	et	külmikuta =külmiku  (SgAb  >külmik !02_S
28056	köögimasinad	masina	köögi+masin	02_S	PlN	et	köögimasinad =masina  (PlN  >köögi+masin !02_S
28058	köögis	köögi	köök	22_S	SgIn	et	köögis =köögi  (SgIn  >köök !22_S
28072	elektroonikat	elektroonika	elektroonika	01_S	SgP	et	elektroonikat =elektroonika  (SgP  >elektroonika !01_S
28073	arengus	arengu	areng	02_S	SgIn	et	arengus =arengu  (SgIn  >areng !02_S
28074	poliitilist	poliitilis	poliitiline	12_A	SgP	et	poliitilist =poliitilis  (SgP  >poliitiline !12_A
28078	poliitiline	poliitiline	poliitiline	12_A	SgN	et	poliitiline =poliitiline  (SgN  >poliitiline !12_A
28080	juhtis	juhti	juhtima	28_V	IndIpfSg3	et	juhtis =juhti  (IndIpfSg3  >juhtima !28_V
28088	kolhoos	kolhoos	kolhoos	22_S	SgN	et	kolhoos =kolhoos  (SgN  >kolhoos !22_S
28090	talumehed	mehe	talu+mees	13_S	PlN	et	talumehed =mehe  (PlN  >talu+mees !13_S
28092	tehaseid	tehase	tehas	09_S	PlP	et	tehaseid =tehase  (PlP  >tehas !09_S
28100	ülikoolid	kooli	üli+kool	22_S	PlN	et	ülikoolid =kooli  (PlN  >üli+kool !22_S
28102	olgem	ol	olema	36_V	ImpPrPl1	et	olgem =ol  (ImpPrPl1  >olema !36_V
27926	paraku	paraku	paraku	41_D	ID	et	paraku =paraku  (ID  >paraku !41_D
27931	suhtlesin	suhtle	suhtlema	30_V	IndIpfSg1	et	suhtlesin =suhtle  (IndIpfSg1  >suhtlema !30_V
27932	jutustasin	jutusta	jutustama	27_V	IndIpfSg1	et	jutustasin =jutusta  (IndIpfSg1  >jutustama !27_V
27934	kindel	kindel	kindel	02_A	SgN	et	kindel =kindel  (SgN  >kindel !02_A
27938	kirg	kirg	kirg	22_S	SgN	et	kirg =kirg  (SgN  >kirg !22_S
27940	loss	loss	loss	22_S	SgN	et	loss =loss  (SgN  >loss !22_S
27959	restoranis	restorani	restoran	19_S	SgIn	et	restoranis =restorani  (SgIn  >restoran !19_S
27965	puuvilju	vilju	puu+vili	24_S	PlP	et	puuvilju =vilju  (PlP  >puu+vili !24_S
27966	juurvilju	vilju	juur+vili	24_S	PlP	et	juurvilju =vilju  (PlP  >juur+vili !24_S
27970	marju	marju	mari	24_S	PlP	et	marju =marju  (PlP  >mari !24_S
27972	klubid	klubi	klubi	17_S	PlN	et	klubid =klubi  (PlN  >klubi !17_S
27973	köök	köök	köök	22_S	SgN	et	köök =köök  (SgN  >köök !22_S
27983	vennaga	venna	vend	22_S	SgKom	et	vennaga =venna  (SgKom  >vend !22_S
27987	arhitektuur	arhitektuur	arhitektuur	22_S	SgN	et	arhitektuur =arhitektuur  (SgN  >arhitektuur !22_S
27990	osad	osa	osa	17_S	PlN	et	osad =osa  (PlN  >osa !17_S
27992	soove	soove	soov	22_S	PlP	et	soove =soove  (PlP  >soov !22_S
27997	vaatasime	vaata	vaatama	29_V	IndIpfPl1	et	vaatasime =vaata  (IndIpfPl1  >vaatama !29_V
28004	buss	buss	buss	22_S	SgN	et	buss =buss  (SgN  >buss !22_S
28010	poolkaheline	kaheline	pool+kaheline	12_AS	SgN	et	poolkaheline =kaheline  (SgN  >pool+kaheline !12_AS
28014	võrdles	võrdle	võrdlema	30_V	IndIpfSg3	et	võrdles =võrdle  (IndIpfSg3  >võrdlema !30_V
28015	tunni	tunni	tund	22_S	SgG	et	tunni =tunni  (SgG  >tund !22_S
28024	loomad	looma	loom	22_S	PlN	et	loomad =looma  (PlN  >loom !22_S
28027	ilusa	ilusa	ilus	02_A	SgG	et	ilusa =ilusa  (SgG  >ilus !02_A
28029	milleta	mille	mis	00_P	SgAb	et	milleta =mille  (SgAb  >mis !00_P
28044	äkki	äkki	äkki	41_D	ID	et	äkki =äkki  (ID  >äkki !41_D
28046	katkis	katki	katk	22_S	SgIn	et	katkis =katki  (SgIn  >katk !22_S
28061	sugulase	sugulase	sugulane	12_S	SgG	et	sugulase =sugulase  (SgG  >sugulane !12_S
28071	raadiot	raadio	raadio	01_S	SgP	et	raadiot =raadio  (SgP  >raadio !01_S
28082	majanduslikke	majanduslikke	majanduslik	25_A	PlP	et	majanduslikke =majanduslikke  (PlP  >majanduslik !25_A
28085	otsused	otsuse	otsus	09_S	PlN	et	otsused =otsuse  (PlN  >otsus !09_S
28089	riigile	riigi	riik	22_S	SgAll	et	riigile =riigi  (SgAll  >riik !22_S
28097	eitada	eita	eitama	27_V	Inf	et	eitada =eita  (Inf  >eitama !27_V
28105	aktuaalne	aktuaalne	aktuaalne	02_A	SgN	et	aktuaalne =aktuaalne  (SgN  >aktuaalne !02_A
28107	iseseisvumine	seisvumine	ise+seisvumine	12_S	SgN	et	iseseisvumine =seisvumine  (SgN  >ise+seisvumine !12_S
28112	integreerida	integreeri	integreerima	28_V	Inf	et	integreerida =integreeri  (Inf  >integreerima !28_V
28116	kultuur	kultuur	kultuur	22_S	SgN	et	kultuur =kultuur  (SgN  >kultuur !22_S
28119	liikmeks	liikme	liige	05_S	SgTr	et	liikmeks =liikme  (SgTr  >liige !05_S
28123	riigil	riigi	riik	22_S	SgAd	et	riigil =riigi  (SgAd  >riik !22_S
28129	edasiliikumine	liikumine	edasi+liikumine	12_S	SgN	et	edasiliikumine =liikumine  (SgN  >edasi+liikumine !12_S
28133	ühiskondliku	ühiskondliku	ühiskondlik	25_A	SgG	et	ühiskondliku =ühiskondliku  (SgG  >ühiskondlik !25_A
28137	segadused	segaduse	segadus	11_S	PlN	et	segadused =segaduse  (PlN  >segadus !11_S
28138	kultuurielule	elu	kultuuri+elu	17_S	SgAll	et	kultuurielule =elu  (SgAll  >kultuuri+elu !17_S
28144	poliitilise	poliitilise	poliitiline	12_A	SgG	et	poliitilise =poliitilise  (SgG  >poliitiline !12_A
28147	rahvaks	rahva	rahvas	07_S	SgTr	et	rahvaks =rahva  (SgTr  >rahvas !07_S
28151	ajakirjandus	kirjandus	aja+kirjandus	11_S	SgN	et	ajakirjandus =kirjandus  (SgN  >aja+kirjandus !11_S
28165	luts	luts	luts	22_S	SgN	et	luts =luts  (SgN  >luts !22_S
28167	revolutsioon	revolutsioon	revolutsioon	22_S	SgN	et	revolutsioon =revolutsioon  (SgN  >revolutsioon !22_S
28172	ülemineku	mineku	üle+minek	02_S	SgG	et	ülemineku =mineku  (SgG  >üle+minek !02_S
28183	täiesti	täiesti	täiesti	41_D	ID	et	täiesti =täiesti  (ID  >täiesti !41_D
28186	ettevõtted	võtte	ette+võte	06_S	PlN	et	ettevõtted =võtte  (PlN  >ette+võte !06_S
28187	süsteemiga	süsteemi	süsteem	22_S	SgKom	et	süsteemiga =süsteemi  (SgKom  >süsteem !22_S
28194	eluase	ase	elu+ase	04_S	SgN	et	eluase =ase  (SgN  >elu+ase !04_S
28198	samasugused	suguse	sama+sugune	10_P	PlN	et	samasugused =suguse  (PlN  >sama+sugune !10_P
28200	eesmärgid	märgi	ees+märk	22_S	PlN	et	eesmärgid =märgi  (PlN  >ees+märk !22_S
28203	maadega	maa	maa	26_S	PlKom	et	maadega =maa  (PlKom  >maa !26_S
28211	võimaluse	võimaluse	võimalus	11_S	SgG	et	võimaluse =võimaluse  (SgG  >võimalus !11_S
27952	lahked	lahke	lahke	01_A	PlN	et	lahked =lahke  (PlN  >lahke !01_A
27961	esses	esse	ess	22_S	PlIn	et	esses =esse  (PlIn  >ess !22_S
27964	sõin	sõ	sööma	38_V	IndIpfSg1	et	sõin =sõ  (IndIpfSg1  >sööma !38_V
27968	aed	aed	aed	22_S	SgN	et	aed =aed  (SgN  >aed !22_S
27969	igasuguseid	suguse	iga+sugune	10_A	PlP	et	igasuguseid =suguse  (PlP  >iga+sugune !10_A
27974	ilutulestik	tulestik	ilu+tulestik	25_S	SgN	et	ilutulestik =tulestik  (SgN  >ilu+tulestik !25_S
27976	raekoeplatsil	platsi	rae+koe+plats	22_S	SgAd	et	raekoeplatsil =platsi  (SgAd  >rae+koe+plats !22_S
27977	meldis	meldi	meldima	28_V	IndIpfSg3	et	meldis =meldi  (IndIpfSg3  >meldima !28_V
27981	migagi	mi	mi	26_S	SgKom^	et	migagi =mi  (SgKom^  >mi !26_S
27985	ekskursioon	ekskursioon	ekskursioon	22_S	SgN	et	ekskursioon =ekskursioon  (SgN  >ekskursioon !22_S
27988	lisan	lisa	lisama	27_V	IndPrSg1	et	lisan =lisa  (IndPrSg1  >lisama !27_V
27989	töötada	tööta	töötama	27_V	Inf	et	töötada =tööta  (Inf  >töötama !27_V
27994	spordiklubisid	klubi	spordi+klubi	17_S	PlP	et	spordiklubisid =klubi  (PlP  >spordi+klubi !17_S
27998	ostsin	ost	ostma	34_V	IndIpfSg1	et	ostsin =ost  (IndIpfSg1  >ostma !34_V
27999	sõidu	sõidu	sõit	22_S	SgG	et	sõidu =sõidu  (SgG  >sõit !22_S
28001	autos	auto	auto	16_S	SgIn	et	autos =auto  (SgIn  >auto !16_S
28003	loeng	loeng	loeng	02_S	SgN	et	loeng =loeng  (SgN  >loeng !02_S
28009	loengu	loengu	loeng	02_S	SgG	et	loengu =loengu  (SgG  >loeng !02_S
28011	vaheaeg	aeg	vahe+aeg	22_S	SgN	et	vaheaeg =aeg  (SgN  >vahe+aeg !22_S
28012	ütles	ütle	ütlema	30_V	IndIpfSg3	et	ütles =ütle  (IndIpfSg3  >ütlema !30_V
28019	sõitis	sõit	sõitma	34_V	IndIpfSg3	et	sõitis =sõit  (IndIpfSg3  >sõitma !34_V
28030	saaks	saa	saama	37_V	KndPrPs	et	saaks =saa  (KndPrPs  >saama !37_V
28031	hambahari	hari	hamba+hari	24_S	SgN	et	hambahari =hari  (SgN  >hamba+hari !24_S
28034	kahv	kahv	kahv	22_S	SgN	et	kahv =kahv  (SgN  >kahv !22_S
28036	elektriga	elektri	elekter	02_S	SgKom	et	elektriga =elektri  (SgKom  >elekter !02_S
28037	riided	riide	riie	06_S	PlN	et	riided =riide  (PlN  >riie !06_S
28038	külm	külm	külm	22_AS	SgN	et	külm =külm  (SgN  >külm !22_AS
28054	pesumasinata	masina	pesu+masin	02_S	SgAb	et	pesumasinata =masina  (SgAb  >pesu+masin !02_S
28060	helistame	helista	helistama	27_V	IndPrPl1	et	helistame =helista  (IndPrPl1  >helistama !27_V
28062	kohtumis	mi	kohtu+mi	26_S	SgIn	et	kohtumis =mi  (SgIn  >kohtu+mi !26_S
28063	tänas	täna	tänama	27_V	IndIpfSg3	et	tänas =täna  (IndIpfSg3  >tänama !27_V
28066	õppima	õppi	õppima	28_V	Sup	et	õppima =õppi  (Sup  >õppima !28_V
28070	praegune	praegune	praegune	10~12_A	SgN	et	praegune =praegune  (SgN  >praegune !10~12_A
28077	põhjused	põhjuse	põhjus	11~09_S	PlN	et	põhjused =põhjuse  (PlN  >põhjus !11~09_S
28079	süsteem	süsteem	süsteem	22_S	SgN	et	süsteem =süsteem  (SgN  >süsteem !22_S
28093	süsteemis	süsteemi	süsteem	22_S	SgIn	et	süsteemis =süsteemi  (SgIn  >süsteem !22_S
28094	meeles	meele	meel	13_S	SgIn	et	meeles =meele  (SgIn  >meel !13_S
28096	vaim	vaim	vaim	22_S	SgN	et	vaim =vaim  (SgN  >vaim !22_S
28098	tol	to	too	00_P	SgAd	et	tol =to  (SgAd  >too !00_P
28103	saagem	saa	saama	37_V	ImpPrPl1	et	saagem =saa  (ImpPrPl1  >saama !37_V
28108	looming	looming	looming	02_S	SgN	et	looming =looming  (SgN  >looming !02_S
28121	sotsiaalsfääris	sfääri	sotsiaal+sfäär	22_S	SgIn	et	sotsiaalsfääris =sfääri  (SgIn  >sotsiaal+sfäär !22_S
28125	toob	too	tooma	38_V	IndPrSg3	et	toob =too  (IndPrSg3  >tooma !38_V
28126	häid	hä	hea	26_A	PlP	et	häid =hä  (PlP  >hea !26_A
28132	tulemusel	tulemuse	tulemus	11_S	SgAd	et	tulemusel =tulemuse  (SgAd  >tulemus !11_S
28142	hakkas	hakka	hakkama	29_V	IndIpfSg3	et	hakkas =hakka  (IndIpfSg3  >hakkama !29_V
28146	faktor	faktor	faktor	02_S	SgN	et	faktor =faktor  (SgN  >faktor !02_S
28152	teatrikunst	kunst	teatri+kunst	22_S	SgN	et	teatrikunst =kunst  (SgN  >teatri+kunst !22_S
28153	tammsaare	saare	tamm+saar	13_S	SgG	et	tammsaare =saare  (SgG  >tamm+saar !13_S
28154	sündima	sündi	sündima	28_V	Sup	et	sündima =sündi  (Sup  >sündima !28_V
28157	tavad	tava	tava	17_S	PlN	et	tavad =tava  (PlN  >tava !17_S
28161	inimestest	inimes	inimene	12_S	PlEl	et	inimestest =inimes  (PlEl  >inimene !12_S
28163	kunstnikutest	test	kunstniku+test	22_S	SgN	et	kunstnikutest =test  (SgN  >kunstniku+test !22_S
28164	traditsioonide	traditsiooni	traditsioon	22_S	PlG	et	traditsioonide =traditsiooni  (PlG  >traditsioon !22_S
28175	savisaar	saar	savi+saar	13_S	SgN	et	savisaar =saar  (SgN  >savi+saar !13_S
28177	hakkati	ati	hakk+att	22_S	SgG	et	hakkati =ati  (SgG  >hakk+att !22_S
28179	isemajandav	majandav	ise+majandav	02_A	SgN	et	isemajandav =majandav  (SgN  >ise+majandav !02_A
28002	algusega	alguse	algus	11~09_S	SgKom	et	algusega =alguse  (SgKom  >algus !11~09_S
28006	astus	astu	astuma	28_V	IndIpfSg3	et	astus =astu  (IndIpfSg3  >astuma !28_V
28008	loengus	loengu	loeng	02_S	SgIn	et	loengus =loengu  (SgIn  >loeng !02_S
28028	tõug	tõug	tõug	22_S	SgN	et	tõug =tõug  (SgN  >tõug !22_S
28032	kasutan	kasuta	kasutama	27_V	IndPrSg1	et	kasutan =kasuta  (IndPrSg1  >kasutama !27_V
28035	elekter	elekter	elekter	02_S	SgN	et	elekter =elekter  (SgN  >elekter !02_S
28039	riideta	riide	riie	06_S	SgAb	et	riideta =riide  (SgAb  >riie !06_S
28041	mugavusetega	e	mugavus+esi	15_S	PlKom	et	mugavusetega =e  (PlKom  >mugavus+esi !15_S
28042	eile	eile	eile	41_D	ID	et	eile =eile  (ID  >eile !41_D
28045	triikraud	raud	triik+raud	22_S	SgN	et	triikraud =raud  (SgN  >triik+raud !22_S
28047	elektrivõrk	võrk	elektri+võrk	22_S	SgN	et	elektrivõrk =võrk  (SgN  >elektri+võrk !22_S
28048	külmkapp	kapp	külm+kapp	22_S	SgN	et	külmkapp =kapp  (SgN  >külm+kapp !22_S
28051	seadmed	seadme	seade	05_S	PlN	et	seadmed =seadme  (PlN  >seade !05_S
28065	spordiklubisse	klubi	spordi+klubi	17_S	SgIll	et	spordiklubisse =klubi  (SgIll  >spordi+klubi !17_S
28067	kaupluses	kaupluse	kauplus	11~09_S	SgIn	et	kaupluses =kaupluse  (SgIn  >kauplus !11~09_S
28069	elektri	elektri	elekter	02_S	SgG	et	elektri =elektri  (SgG  >elekter !02_S
28075	vabadussõja	sõja	vabadus+sõda	18_S	SgG	et	vabadussõja =sõja  (SgG  >vabadus+sõda !18_S
28086	kolhoosile	kolhoosi	kolhoos	22_S	SgAll	et	kolhoosile =kolhoosi  (SgAll  >kolhoos !22_S
28087	sovhoosile	sovhoosi	sovhoos	22_S	SgAll	et	sovhoosile =sovhoosi  (SgAll  >sovhoos !22_S
28101	erialal	ala	eri+ala	17_S	SgAd	et	erialal =ala  (SgAd  >eri+ala !17_S
28118	tehakse	teh	tegema	28_V	IndPrIps	et	tehakse =teh  (IndPrIps  >tegema !28_V
28120	majanduspoliitikas	poliitika	majandus+poliitika	01_S	SgIn	et	majanduspoliitikas =poliitika  (SgIn  >majandus+poliitika !01_S
28124	sisseastumine	astumine	sisse+astumine	12_S	SgN	et	sisseastumine =astumine  (SgN  >sisse+astumine !12_S
28127	halbu	halbu	halb	22_A	PlP	et	halbu =halbu  (PlP  >halb !22_A
28128	tundub	tundu	tunduma	27_V	IndPrSg3	et	tundub =tundu  (IndPrSg3  >tunduma !27_V
28134	poliitilisis	poliitilisi	poliitiline	12_A	PlIn	et	poliitilisis =poliitilisi  (PlIn  >poliitiline !12_A
28150	kirjandus	kirjandus	kirjandus	11_S	SgN	et	kirjandus =kirjandus  (SgN  >kirjandus !11_S
28162	kirjanikutest	test	kirjaniku+test	22_S	SgN	et	kirjanikutest =test  (SgN  >kirjaniku+test !22_S
28166	poliitilises	poliitilise	poliitiline	12_A	SgIn	et	poliitilises =poliitilise  (SgIn  >poliitiline !12_A
28170	hakkama	hakka	hakkama	29_V	Sup	et	hakkama =hakka  (Sup  >hakkama !29_V
28171	vabariigi	riigi	vaba+riik	22_S	SgG	et	vabariigi =riigi  (SgG  >vaba+riik !22_S
28173	periood	periood	periood	22_S	SgN	et	periood =periood  (SgN  >periood !22_S
28176	tunnistas	tunnista	tunnistama	27_V	IndIpfSg3	et	tunnistas =tunnista  (IndIpfSg3  >tunnistama !27_V
28185	orienteeruda	orienteeru	orienteeruma	27_V	Inf	et	orienteeruda =orienteeru  (Inf  >orienteeruma !27_V
28189	reform	reform	reform	22_S	SgN	et	reform =reform  (SgN  >reform !22_S
28193	sokiks	soki	sokk	22_S	SgTr	et	sokiks =soki  (SgTr  >sokk !22_S
28196	territooriumit	territooriumi	territoorium	02_S	SgP	et	territooriumit =territooriumi  (SgP  >territoorium !02_S
28199	huvid	huvi	huvi	17_S	PlN	et	huvid =huvi  (PlN  >huvi !17_S
28201	sõlmiti	sõlmi	sõlmima	28_V	IndIpfIps	et	sõlmiti =sõlmi  (IndIpfIps  >sõlmima !28_V
28204	ümberehitamine	ehitamine	ümber+ehitamine	12_S	SgN	et	ümberehitamine =ehitamine  (SgN  >ümber+ehitamine !12_S
28209	ignoreerida	ignoreeri	ignoreerima	28_V	Inf	et	ignoreerida =ignoreeri  (Inf  >ignoreerima !28_V
28212	rahvuse	rahvuse	rahvus	11~09_S	SgG	et	rahvuse =rahvuse  (SgG  >rahvus !11~09_S
28228	kirjakultuur	kultuur	kirja+kultuur	22_S	SgN	et	kirjakultuur =kultuur  (SgN  >kirja+kultuur !22_S
28230	leping	leping	leping	02_S	SgN	et	leping =leping  (SgN  >leping !02_S
28233	teraviljas	vilja	tera+vili	24_S	SgIn	et	teraviljas =vilja  (SgIn  >tera+vili !24_S
28235	jäälahing	lahing	jää+lahing	02_S	SgN	et	jäälahing =lahing  (SgN  >jää+lahing !02_S
28240	taanlased	taanlase	taanlane	12?10_S	PlN	et	taanlased =taanlase  (PlN  >taanlane !12?10_S
28242	jagatakse	jaga	jagama	27_V	IndPrIps	et	jagatakse =jaga  (IndPrIps  >jagama !27_V
28246	ordule	ordu	ordu	16_S	SgAll	et	ordule =ordu  (SgAll  >ordu !16_S
28250	valitseda	valitse	valitsema	27_V	Inf	et	valitseda =valitse  (Inf  >valitsema !27_V
28253	piiskopkond	piiskopkond	piiskopkond	22_S	SgN	et	piiskopkond =piiskopkond  (SgN  >piiskopkond !22_S
28260	mentaliteet	mentaliteet	mentaliteet	22_S	SgN	et	mentaliteet =mentaliteet  (SgN  >mentaliteet !22_S
28265	hakatakse	haka	hakkama	29_V	IndPrIps	et	hakatakse =haka  (IndPrIps  >hakkama !29_V
28269	kloostreid	kloostre	klooster	02_S	PlP	et	kloostreid =kloostre  (PlP  >klooster !02_S
28104	eurooplasteks	eurooplas	eurooplane	12?10_S	PlTr	et	eurooplasteks =eurooplas  (PlTr  >eurooplane !12?10_S
28109	ew-s	ew	ew	xx_Q	SgIn	et	ew-s =ew  (SgIn  >ew !xx_Q
28111	jätta	jätt	jätma	35_V	Inf	et	jätta =jätt  (Inf  >jätma !35_V
28114	euroopaga	euroopa	euroopa	01_H	SgKom	et	euroopaga =euroopa  (SgKom  >euroopa !01_H
28117	oskusi	oskusi	oskus	11_S	PlP	et	oskusi =oskusi  (PlP  >oskus !11_S
28122	oludes	olu	olu	17_S	PlIn	et	oludes =olu  (PlIn  >olu !17_S
28130	alustan	alusta	alustama	27_V	IndPrSg1	et	alustan =alusta  (IndPrSg1  >alustama !27_V
28139	parandada	paranda	parandama	27_V	Inf	et	parandada =paranda  (Inf  >parandama !27_V
28145	sotsiaalsed	sotsiaalse	sotsiaalne	02_A	PlN	et	sotsiaalsed =sotsiaalse  (PlN  >sotsiaalne !02_A
28148	omandama	omanda	omandama	27_V	Sup	et	omandama =omanda  (Sup  >omandama !27_V
28149	paljudest	palju	palju	16_P	PlEl	et	paljudest =palju  (PlEl  >palju !16_P
28158	traditsioonid	traditsiooni	traditsioon	22_S	PlN	et	traditsioonid =traditsiooni  (PlN  >traditsioon !22_S
28159	kuulen	kuule	kuulma	33_V	IndPrSg1	et	kuulen =kuule  (IndPrSg1  >kuulma !33_V
28160	meenutan	meenuta	meenutama	27_V	IndPrSg1	et	meenutan =meenuta  (IndPrSg1  >meenutama !27_V
28168	edasiarenemine	arenemine	edasi+arenemine	12_S	SgN	et	edasiarenemine =arenemine  (SgN  >edasi+arenemine !12_S
28169	rõõm	rõõm	rõõm	22_S	SgN	et	rõõm =rõõm  (SgN  >rõõm !22_S
28182	tööstus	tööstus	tööstus	11~09_S	SgN	et	tööstus =tööstus  (SgN  >tööstus !11~09_S
28188	kohandada	kohanda	kohandama	27_V	Inf	et	kohandada =kohanda  (Inf  >kohandama !27_V
28191	kurss	kurss	kurss	22_S	SgN	et	kurss =kurss  (SgN  >kurss !22_S
28197	pidurdas	pidurda	pidurdama	27_V	IndIpfSg3	et	pidurdas =pidurda  (IndIpfSg3  >pidurdama !27_V
28206	rahvarinne	rinne	rahva+rinne	06_S	SgN	et	rahvarinne =rinne  (SgN  >rahva+rinne !06_S
28207	ühendas	ühenda	ühendama	27_V	IndIpfSg3	et	ühendas =ühenda  (IndIpfSg3  >ühendama !27_V
28210	püüdlused	püüdluse	püüdlus	11~09_S	PlN	et	püüdlused =püüdluse  (PlN  >püüdlus !11~09_S
28213	eneseväljendamiseks	väljendamise	enese+väljendamine	12_S	SgTr	et	eneseväljendamiseks =väljendamise  (SgTr  >enese+väljendamine !12_S
28221	ristisõdijad	sõdija	risti+sõdija	01_S	PlN	et	ristisõdijad =sõdija  (PlN  >risti+sõdija !01_S
28223	mõõgavendade	venda	mõõga+vend	22_S	PlG	et	mõõgavendade =venda  (PlG  >mõõga+vend !22_S
28238	piirid	piiri	piir	22_S	PlN	et	piirid =piiri  (PlN  >piir !22_S
28239	siinsest	siinse	siinne	02_A	SgEl	et	siinsest =siinse  (SgEl  >siinne !02_A
28244	igaühel	ühe	iga+üks	22_P	SgAd	et	igaühel =ühe  (SgAd  >iga+üks !22_P
28245	kesk-	kesk	kesk	41_K	ID	et	kesk- =kesk  (ID  >kesk !41_K
28248	saared	saare	saar	13_S	PlN	et	saared =saare  (PlN  >saar !13_S
28255	eestlane	eestlane	eestlane	12?10_S	SgN	et	eestlane =eestlane  (SgN  >eestlane !12?10_S
28258	kombed	kombe	komme	06_S	PlN	et	kombed =kombe  (PlN  >komme !06_S
28264	talupoegadelt	poega	talu+poeg	22_S	PlAbl	et	talupoegadelt =poega  (PlAbl  >talu+poeg !22_S
28266	aastas	aasta	aasta	01_S	SgIn	et	aastas =aasta  (SgIn  >aasta !01_S
28271	mitmenaisepidamisest	pidamise	mitme+naise+pidamine	12_S	SgEl	et	mitmenaisepidamisest =pidamise  (SgEl  >mitme+naise+pidamine !12_S
28274	varustama	varusta	varustama	27_V	Sup	et	varustama =varusta  (Sup  >varustama !27_V
28281	rändmungad	munga	ränd+munk	22_S	PlN	et	rändmungad =munga  (PlN  >ränd+munk !22_S
28285	haridus	haridus	haridus	11_S	SgN	et	haridus =haridus  (SgN  >haridus !11_S
28292	ilmastus	ilmastu	ilmastuma	27_V	IndIpfSg3	et	ilmastus =ilmastu  (IndIpfSg3  >ilmastuma !27_V
28301	sündmus	sündmus	sündmus	11~09_S	SgN	et	sündmus =sündmus  (SgN  >sündmus !11~09_S
28302	muudeti	muude	muutma	34_V	IndIpfIps	et	muudeti =muude  (IndIpfIps  >muutma !34_V
28304	nimed	nime	nimi	20_S	PlN	et	nimed =nime  (PlN  >nimi !20_S
28309	katedraal	katedraal	katedraal	22_S	SgN	et	katedraal =katedraal  (SgN  >katedraal !22_S
28314	minnakse	minn	minema	36_V	IndPrIps	et	minnakse =minn  (IndPrIps  >minema !36_V
28321	kaob	kao	kaduma	28_V	IndPrSg3	et	kaob =kao  (IndPrSg3  >kaduma !28_V
28323	räägitakse	räägi	rääkima	28_V	IndPrIps	et	räägitakse =räägi  (IndPrIps  >rääkima !28_V
28327	kultuurisuhted	suhte	kultuuri+suhe	06_S	PlN	et	kultuurisuhted =suhte  (PlN  >kultuuri+suhe !06_S
28334	piiriäärne	äärne	piiri+äärne	02_A	SgN	et	piiriäärne =äärne  (SgN  >piiri+äärne !02_A
28336	sfääris	sfääri	sfäär	22_S	SgIn	et	sfääris =sfääri  (SgIn  >sfäär !22_S
28339	arvutit	arvuti	arvuti	01_S	SgP	et	arvutit =arvuti  (SgP  >arvuti !01_S
28341	ohtlik	ohtlik	ohtlik	25_A	SgN	et	ohtlik =ohtlik  (SgN  >ohtlik !25_A
28342	õigel	õige	õige	01_A	SgAd	et	õigel =õige  (SgAd  >õige !01_A
28343	kaduda	kadu	kaduma	28_V	Inf	et	kaduda =kadu  (Inf  >kaduma !28_V
28113	euroopasse	euroopa	euroopa	01_H	SgIll	et	euroopasse =euroopa  (SgIll  >euroopa !01_H
28115	kõrgharidus	haridus	kõrg+haridus	11_S	SgN	et	kõrgharidus =haridus  (SgN  >kõrg+haridus !11_S
28131	revolutsioonide	revolutsiooni	revolutsioon	22_S	PlG	et	revolutsioonide =revolutsiooni  (PlG  >revolutsioon !22_S
28135	eestile	eesti	eesti	16_H	SgAll	et	eestile =eesti  (SgAll  >eesti !16_H
28136	sõjad	sõja	sõda	18_S	PlN	et	sõjad =sõja  (PlN  >sõda !18_S
28140	silmade	silma	silm	22_S	PlG	et	silmade =silma  (PlG  >silm !22_S
28141	võim	võim	võim	22_S	SgN	et	võim =võim  (SgN  >võim !22_S
28143	nõudma	nõud	nõudma	34_V	Sup	et	nõudma =nõud  (Sup  >nõudma !34_V
28155	auhinna	hinna	au+hind	22_S	SgG	et	auhinna =hinna  (SgG  >au+hind !22_S
28156	roomani	rooma	room	22_S	SgTer	et	roomani =rooma  (SgTer  >room !22_S
28174	uut	uu	uus	14_A	SgP	et	uut =uu  (SgP  >uus !14_A
28178	poliitikat	poliitika	poliitika	01_S	SgP	et	poliitikat =poliitika  (SgP  >poliitika !01_S
28180	elluviimine	viimine	ellu+viimine	12?10_S	SgN	et	elluviimine =viimine  (SgN  >ellu+viimine !12?10_S
28184	ümberehitamisest	ehitamise	ümber+ehitamine	12_S	SgEl	et	ümberehitamisest =ehitamise  (SgEl  >ümber+ehitamine !12_S
28190	kroon	kroon	kroon	22_S	SgN	et	kroon =kroon  (SgN  >kroon !22_S
28195	halvenes	halvene	halvenema	27_V	IndIpfSg3	et	halvenes =halvene  (IndIpfSg3  >halvenema !27_V
28202	kontaktid	kontakti	kontakt	22_S	PlN	et	kontaktid =kontakti  (PlN  >kontakt !22_S
28205	etapiks	etapi	etapp	22_S	SgTr	et	etapiks =etapi  (SgTr  >etapp !22_S
28208	rahvamasse	masse	rahva+mass	22_S	PlP	et	rahvamasse =masse  (PlP  >rahva+mass !22_S
28214	ristiusustamise	usustamise	risti+usustamine	12_S	SgG	et	ristiusustamise =usustamise  (SgG  >risti+usustamine !12_S
28216	reformatsioon	reformatsioon	reformatsioon	22_S	SgN	et	reformatsioon =reformatsioon  (SgN  >reformatsioon !22_S
28219	loobub	loobu	loobuma	27_V	IndPrSg3	et	loobub =loobu  (IndPrSg3  >loobuma !27_V
28220	ristiusustada	ususta	risti+usustama	27_V	Inf	et	ristiusustada =ususta  (Inf  >risti+usustama !27_V
28222	pattudest	pattu	patt	22_S	PlEl	et	pattudest =pattu  (PlEl  >patt !22_S
28225	lätlaste	lätlas	lätlane	12?10_S	PlG	et	lätlaste =lätlas  (PlG  >lätlane !12?10_S
28226	sunniti	sunni	sundima	28_V	IndIpfIps	et	sunniti =sunni  (IndIpfIps  >sundima !28_V
28232	lubati	luba	lubama	27_V	IndIpfIps	et	lubati =luba  (IndIpfIps  >lubama !27_V
28237	otsustab	otsusta	otsustama	27_V	IndPrSg3	et	otsustab =otsusta  (IndPrSg3  >otsustama !27_V
28252	moodustatakse	moodusta	moodustama	27_V	IndPrIps	et	moodustatakse =moodusta  (IndPrIps  >moodustama !27_V
28257	sakslane	sakslane	sakslane	12?10_S	SgN	et	sakslane =sakslane  (SgN  >sakslane !12?10_S
28262	püsima	püsi	püsima	27_V	Sup	et	püsima =püsi  (Sup  >püsima !27_V
28270	loobuma	loobu	loobuma	27_V	Sup	et	loobuma =loobu  (Sup  >loobuma !27_V
28283	rahvale	rahva	rahvas	07_S	SgAll	et	rahvale =rahva  (SgAll  >rahvas !07_S
28286	keskajal	aja	kesk+aeg	22_S	SgAd	et	keskajal =aja  (SgAd  >kesk+aeg !22_S
28289	eesmärgiks	märgi	ees+märk	22_S	SgTr	et	eesmärgiks =märgi  (SgTr  >ees+märk !22_S
28291	hingega	hinge	hing	22_S	SgKom	et	hingega =hinge  (SgKom  >hing !22_S
28296	lõhuti	lõhu	lõhkuma	28_V	IndIpfIps	et	lõhuti =lõhu  (IndIpfIps  >lõhkuma !28_V
28305	nimetama	nimeta	nimetama	27_V	Sup	et	nimetama =nimeta  (Sup  >nimetama !27_V
28307	klass	klass	klass	22_S	SgN	et	klass =klass  (SgN  >klass !22_S
28313	kursuse	kursuse	kursus	11~09_S	SgG	et	kursuse =kursuse  (SgG  >kursus !11~09_S
28315	ainekavadele	kava	aine+kava	17_S	PlAll	et	ainekavadele =kava  (PlAll  >aine+kava !17_S
28320	selts	selts	selts	22_S	SgN	et	selts =selts  (SgN  >selts !22_S
28345	liikmed	liikme	liige	05_S	PlN	et	liikmed =liikme  (PlN  >liige !05_S
28348	arusaamad	saama	aru+saam	22_S	PlN	et	arusaamad =saama  (PlN  >aru+saam !22_S
28356	reklaame	reklaame	reklaam	22_S	PlP	et	reklaame =reklaame  (PlP  >reklaam !22_S
28373	vastuvõtjat	võtja	vastu+võtja	01_S	SgP	et	vastuvõtjat =võtja  (SgP  >vastu+võtja !01_S
28386	kooliõpetajaks	õpetaja	kooli+õpetaja	01_S	SgTr	et	kooliõpetajaks =õpetaja  (SgTr  >kooli+õpetaja !01_S
28390	kultuuriõppimisega	õppimise	kultuuri+õppimine	12_S	SgKom	et	kultuuriõppimisega =õppimise  (SgKom  >kultuuri+õppimine !12_S
28399	korraldan	korralda	korraldama	27_V	IndPrSg1	et	korraldan =korralda  (IndPrSg1  >korraldama !27_V
28401	esile	esile	esile	41_D	ID	et	esile =esile  (ID  >esile !41_D
28408	kvalitatiivsed	kvalitatiivse	kvalitatiivne	02_A	PlN	et	kvalitatiivsed =kvalitatiivse  (PlN  >kvalitatiivne !02_A
28413	rahvapärimuse	pärimuse	rahva+pärimus	11_S	SgG	et	rahvapärimuse =pärimuse  (SgG  >rahva+pärimus !11_S
28417	minevikust	mineviku	minevik	25_S	SgEl	et	minevikust =mineviku  (SgEl  >minevik !25_S
28421	eestlase	eestlase	eestlane	12?10_S	SgG	et	eestlase =eestlase  (SgG  >eestlane !12?10_S
28181	probleemne	probleemne	probleemne	02_A	SgN	et	probleemne =probleemne  (SgN  >probleemne !02_A
28192	margaga	marga	mark	22_S	SgKom	et	margaga =marga  (SgKom  >mark !22_S
28217	ristiusustamisega	usustamise	risti+usustamine	12_S	SgKom	et	ristiusustamisega =usustamise  (SgKom  >risti+usustamine !12_S
28229	kirjalik	kirjalik	kirjalik	25_A	SgN	et	kirjalik =kirjalik  (SgN  >kirjalik !25_A
28236	valul	valu	valu	17_S	SgAd	et	valul =valu  (SgAd  >valu !17_S
28241	kaasneb	kaasne	kaasnema	27_V	IndPrSg3	et	kaasneb =kaasne  (IndPrSg3  >kaasnema !27_V
28243	omaette	omaette	oma+ette	41_D	ID	et	omaette =omaette  (ID  >oma+ette !41_D
28249	piiskopkonna	piiskopkonna	piiskopkond	22_S	SgG	et	piiskopkonna =piiskopkonna  (SgG  >piiskopkond !22_S
28254	kujuneb	kujune	kujunema	27_V	IndPrSg3	et	kujuneb =kujune  (IndPrSg3  >kujunema !27_V
28256	ülemkiht	kiht	ülem+kiht	22_S	SgN	et	ülemkiht =kiht  (SgN  >ülem+kiht !22_S
28259	ühiskondlik	ühiskondlik	ühiskondlik	25_A	SgN	et	ühiskondlik =ühiskondlik  (SgN  >ühiskondlik !25_A
28261	stabiilne	stabiilne	stabiilne	02_A	SgN	et	stabiilne =stabiilne  (SgN  >stabiilne !02_A
28267	kümnist	kümnis	kümnis	11~09_S	SgP	et	kümnist =kümnis  (SgP  >kümnis !11~09_S
28277	agraarühiskond	ühiskond	agraar+ühiskond	22_S	SgN	et	agraarühiskond =ühiskond  (SgN  >agraar+ühiskond !22_S
28280	kirikukihelkond	kihelkond	kiriku+kihelkond	22_S	SgN	et	kirikukihelkond =kihelkond  (SgN  >kiriku+kihelkond !22_S
28282	misjonitööga	töö	misjoni+töö	26_S	SgKom	et	misjonitööga =töö  (SgKom  >misjoni+töö !26_S
28284	töövõtteid	võtte	töö+võte	06_S	PlP	et	töövõtteid =võtte  (PlP  >töö+võte !06_S
28287	katoliku	katoliku	katoliku	41_G	ID	et	katoliku =katoliku  (ID  >katoliku !41_G
28293	pildirüüsted	rüüste	pildi+rüüste	06_S	PlN	et	pildirüüsted =rüüste  (PlN  >pildi+rüüste !06_S
28295	ikoone	ikoone	ikoon	22_S	PlP	et	ikoone =ikoone  (PlP  >ikoon !22_S
28297	kirikureformid	reformi	kiriku+reform	22_S	PlN	et	kirikureformid =reformi  (PlN  >kiriku+reform !22_S
28306	gümnaasiumiks	gümnaasiumi	gümnaasium	19~02_S	SgTr	et	gümnaasiumiks =gümnaasiumi  (SgTr  >gümnaasium !19~02_S
28308	ülikoolides	kooli	üli+kool	22_S	PlIn	et	ülikoolides =kooli  (PlIn  >üli+kool !22_S
28311	taastatakse	taasta	taastama	27_V	IndPrIps	et	taastatakse =taasta  (IndPrIps  >taastama !27_V
28319	vastupidi	vastupidi	vastu+pidi	41_D	ID	et	vastupidi =vastupidi  (ID  >vastu+pidi !41_D
28324	erialaseltse	seltse	eri+ala+selts	22_S	PlP	et	erialaseltse =seltse  (PlP  >eri+ala+selts !22_S
28332	üht	üht	üks	22_NP	SgP	et	üht =üht  (SgP  >üks !22_NP
28338	preemiat	preemia	preemia	01_S	SgP	et	preemiat =preemia  (SgP  >preemia !01_S
28340	mobiiltelefone	telefone	mobiil+telefon	19_S	PlP	et	mobiiltelefone =telefone  (PlP  >mobiil+telefon !19_S
28349	ettepoole	ettepoole	ette+poole	41_DK	ID	et	ettepoole =ettepoole  (ID  >ette+poole !41_DK
28350	pööratakse	pööra	pöörama	29_V	IndPrIps	et	pööratakse =pööra  (IndPrIps  >pöörama !29_V
28355	näen	näe	nägema	28_V	IndPrSg1	et	näen =näe  (IndPrSg1  >nägema !28_V
28358	raadiost	raadio	raadio	01_S	SgEl	et	raadiost =raadio  (SgEl  >raadio !01_S
28360	kuulab	kuula	kuulama	29_V	IndPrSg3	et	kuulab =kuula  (IndPrSg3  >kuulama !29_V
28384	pakub	paku	pakkuma	28_V	IndPrSg3	et	pakub =paku  (IndPrSg3  >pakkuma !28_V
28387	õppekavas	kava	õppe+kava	17_S	SgIn	et	õppekavas =kava  (SgIn  >õppe+kava !17_S
28391	olukord	kord	olu+kord	22_S	SgN	et	olukord =kord  (SgN  >olu+kord !22_S
28394	lahendada	lahenda	lahendama	27_V	Inf	et	lahendada =lahenda  (Inf  >lahendama !27_V
28414	näo	näo	nägu	18_S	SgG	et	näo =näo  (SgG  >nägu !18_S
28416	kohalikud	kohaliku	kohalik	25_AS	PlN	et	kohalikud =kohaliku  (PlN  >kohalik !25_AS
28422	vaimuilm	ilm	vaimu+ilm	22_S	SgN	et	vaimuilm =ilm  (SgN  >vaimu+ilm !22_S
28428	viitab	viita	viitama	29_V	IndPrSg3	et	viitab =viita  (IndPrSg3  >viitama !29_V
28432	metsade	metsa	mets	22_S	PlG	et	metsade =metsa  (PlG  >mets !22_S
28435	kultuurivaldkondade	valdkonda	kultuuri+valdkond	22_S	PlG	et	kultuurivaldkondade =valdkonda  (PlG  >kultuuri+valdkond !22_S
28438	rajajooneks	joone	raja+joon	13_S	SgTr	et	rajajooneks =joone  (SgTr  >raja+joon !13_S
28448	ühisjooni	joon	ühis+joon	13_S	PlP	et	ühisjooni =joon  (PlP  >ühis+joon !13_S
28462	tekkeks	tekke	teke	06_S	SgTr	et	tekkeks =tekke  (SgTr  >teke !06_S
28465	uute	uu	uus	14_A	PlG	et	uute =uu  (PlG  >uus !14_A
28466	arusaamade	saama	aru+saam	22_S	PlG	et	arusaamade =saama  (PlG  >aru+saam !22_S
28467	aeganõudev	nõudev	aega+nõudev	02_A	SgN	et	aeganõudev =nõudev  (SgN  >aega+nõudev !02_A
28470	aset	ase	ase	04_S	SgP	et	aset =ase  (SgP  >ase !04_S
28471	ajendiks	ajendi	ajend	02_S	SgTr	et	ajendiks =ajendi  (SgTr  >ajend !02_S
28476	teravaid	terava	terav	02_A	PlP	et	teravaid =terava  (PlP  >terav !02_A
28482	ürgne	ürgne	ürgne	02_A	SgN	et	ürgne =ürgne  (SgN  >ürgne !02_A
28215	ühiskonnakorraldusele	korralduse	ühis+konna+korraldus	11_S	SgAll	et	ühiskonnakorraldusele =korralduse  (SgAll  >ühis+konna+korraldus !11_S
28218	kaasnes	kaasne	kaasnema	27_V	IndIpfSg3	et	kaasnes =kaasne  (IndIpfSg3  >kaasnema !27_V
28224	alistati	alista	alistama	27_V	IndIpfIps	et	alistati =alista  (IndIpfIps  >alistama !27_V
28227	ristiusustamine	usustamine	risti+usustamine	12_S	SgN	et	ristiusustamine =usustamine  (SgN  >risti+usustamine !12_S
28231	saarlased	saarlase	saarlane	12?10_S	PlN	et	saarlased =saarlase  (PlN  >saarlane !12?10_S
28234	varguselt	varguse	vargus	11~09_S	SgAbl	et	varguselt =varguse  (SgAbl  >vargus !11~09_S
28247	põhja-eestit	eesti	põhja-eesti	16_H	SgP	et	põhja-eestit =eesti  (SgP  >põhja-eesti !16_H
28251	kagu-eestis	eesti	kagu-eesti	16_H	SgIn	et	kagu-eestis =eesti  (SgIn  >kagu-eesti !16_H
28263	poliitiliseks	poliitilise	poliitiline	12_A	SgTr	et	poliitiliseks =poliitilise  (SgTr  >poliitiline !12_A
28268	kirikud	kiriku	kirik	02_S	PlN	et	kirikud =kiriku  (PlN  >kirik !02_S
28273	toiduga	toidu	toit	22_S	SgKom	et	toiduga =toidu  (SgKom  >toit !22_S
28276	maaharimine	harimine	maa+harimine	12_S	SgN	et	maaharimine =harimine  (SgN  >maa+harimine !12_S
28278	mitmesajaks	saja	mitme+sajas	02_N	SgTr	et	mitmesajaks =saja  (SgTr  >mitme+sajas !02_N
28279	muudkui	muudkui	muud+kui	41_D	ID	et	muudkui =muudkui  (ID  >muud+kui !41_D
28288	tundus	tundu	tunduma	27_V	IndIpfSg3	et	tundus =tundu  (IndIpfSg3  >tunduma !27_V
28294	purustati	purusta	purustama	27_V	IndIpfIps	et	purustati =purusta  (IndIpfIps  >purustama !27_V
28298	kohalikelt	kohalike	kohalik	25_AS	PlAbl	et	kohalikelt =kohalike  (PlAbl  >kohalik !25_AS
28299	emakeelne	keelne	ema+keelne	02_A	SgN	et	emakeelne =keelne  (SgN  >ema+keelne !02_A
28303	koolidele	kooli	kool	22_S	PlAll	et	koolidele =kooli  (PlAll  >kool !22_S
28312	nl-s	nl	nl	xx_Q	SgIn	et	nl-s =nl  (SgIn  >nl !xx_Q
28317	toimuma	toimu	toimuma	27_V	Sup	et	toimuma =toimu  (Sup  >toimuma !27_V
28318	välismaalt	maa	välis+maa	26_S	SgAbl	et	välismaalt =maa  (SgAbl  >välis+maa !26_S
28322	koolivorm	vorm	kooli+vorm	22_S	SgN	et	koolivorm =vorm  (SgN  >kooli+vorm !22_S
28325	ats	ats	ats	22_S	SgN	et	ats =ats  (SgN  >ats !22_S
28326	normaliseeruda	normaliseeru	normaliseeruma	27_V	Inf	et	normaliseeruda =normaliseeru  (Inf  >normaliseeruma !27_V
28328	välismaaga	maa	välis+maa	26_S	SgKom	et	välismaaga =maa  (SgKom  >välis+maa !26_S
28333	hakati	haka	hakkama	29_V	IndIpfIps	et	hakati =haka  (IndIpfIps  >hakkama !29_V
28335	õigeusu	usu	õige+usk	22_S	SgG	et	õigeusu =usu  (SgG  >õige+usk !22_S
28337	kõrgkultuur	kultuur	kõrg+kultuur	22_S	SgN	et	kõrgkultuur =kultuur  (SgN  >kõrg+kultuur !22_S
28346	õigesti	õigesti	õigesti	41_D	ID	et	õigesti =õigesti  (ID  >õigesti !41_D
28362	sõnum	sõnum	sõnum	02_S	SgN	et	sõnum =sõnum  (SgN  >sõnum !02_S
28365	sõnumit	sõnumi	sõnum	02_S	SgP	et	sõnumit =sõnumi  (SgP  >sõnum !02_S
28369	naist	nais	naine	12_S	SgP	et	naist =nais  (SgP  >naine !12_S
28375	vaataks	vaata	vaatama	29_V	KndPrPs	et	vaataks =vaata  (KndPrPs  >vaatama !29_V
28379	sisukord	kord	sisu+kord	22_S	SgN	et	sisukord =kord  (SgN  >sisu+kord !22_S
28382	testianalüüs	analüüs	testi+analüüs	22_S	SgN	et	testianalüüs =analüüs  (SgN  >testi+analüüs !22_S
28388	kultuuriõpe	õpe	kultuuri+õpe	06_S	SgN	et	kultuuriõpe =õpe  (SgN  >kultuuri+õpe !06_S
28392	integratsioonist	integratsiooni	integratsioon	22_S	SgEl	et	integratsioonist =integratsiooni  (SgEl  >integratsioon !22_S
28396	tööeesmärgiks	märgi	töö+ees+märk	22_S	SgTr	et	tööeesmärgiks =märgi  (SgTr  >töö+ees+märk !22_S
28400	teste	teste	test	22_S	PlP	et	teste =teste  (PlP  >test !22_S
28409	kirjanduseallikad	allika	kirjanduse+allikas	02_S	PlN	et	kirjanduseallikad =allika  (PlN  >kirjanduse+allikas !02_S
28410	rahvapärimus	pärimus	rahva+pärimus	11_S	SgN	et	rahvapärimus =pärimus  (SgN  >rahva+pärimus !11_S
28423	kristlikud	kristliku	kristlik	25_A	PlN	et	kristlikud =kristliku  (PlN  >kristlik !25_A
28427	lähialadega	ala	lähi+ala	17_S	PlKom	et	lähialadega =ala  (PlKom  >lähi+ala !17_S
28429	lai	lai	lai	22_A	SgN	et	lai =lai  (SgN  >lai !22_A
28433	soode	soo	soo	26_S	PlG	et	soode =soo  (PlG  >soo !26_S
28441	sajandist	sajandi	sajand	02_S	SgEl	et	sajandist =sajandi  (SgEl  >sajand !02_S
28444	ääremaaks	maa	ääre+maa	26_S	SgTr	et	ääremaaks =maa  (SgTr  >ääre+maa !26_S
28447	talupojakultuuril	kultuuri	talu+poja+kultuur	22_S	SgAd	et	talupojakultuuril =kultuuri  (SgAd  >talu+poja+kultuur !22_S
28450	tüüpilist	tüüpilis	tüüpiline	12_A	SgP	et	tüüpilist =tüüpilis  (SgP  >tüüpiline !12_A
28451	pehmet	pehme	pehme	01_A	SgP	et	pehmet =pehme  (SgP  >pehme !01_A
28455	selgesti	selgesti	selgesti	41_D	ID	et	selgesti =selgesti  (ID  >selgesti !41_D
28456	seisusliku	seisusliku	seisuslik	25_A	SgG	et	seisusliku =seisusliku  (SgG  >seisuslik !25_A
28272	matma	mat	matma	35_V	Sup	et	matma =mat  (Sup  >matma !35_V
28275	tööoskused	oskuse	töö+oskus	11~09_S	PlN	et	tööoskused =oskuse  (PlN  >töö+oskus !11~09_S
28290	nõudis	nõud	nõudma	34_V	IndIpfSg3	et	nõudis =nõud  (IndIpfSg3  >nõudma !34_V
28300	jumalateenistus	teenistus	jumala+teenistus	11_S	SgN	et	jumalateenistus =teenistus  (SgN  >jumala+teenistus !11_S
28310	õppetool	tool	õppe+tool	22_S	SgN	et	õppetool =tool  (SgN  >õppe+tool !22_S
28316	viimasel	viimase	viimane	10_A	SgAd	et	viimasel =viimase  (SgAd  >viimane !10_A
28329	regionaalne	regionaalne	regionaalne	02_A	SgN	et	regionaalne =regionaalne  (SgN  >regionaalne !02_A
28330	kultuurilelule	lelu	kultuuri+lelu	17_S	SgAll	et	kultuurilelule =lelu  (SgAll  >kultuuri+lelu !17_S
28331	kasutama	kasuta	kasutama	27_V	Sup	et	kasutama =kasuta  (Sup  >kasutama !27_V
28347	valida	vali	valima	27_V	Inf	et	valida =vali  (Inf  >valima !27_V
28352	sotsiaaltöötajad	töötaja	sotsiaal+töötaja	01_S	PlN	et	sotsiaaltöötajad =töötaja  (PlN  >sotsiaal+töötaja !01_S
28353	püüdlust	püüdlus	püüdlus	11~09_S	SgP	et	püüdlust =püüdlus  (SgP  >püüdlus !11~09_S
28359	kanalid	kanali	kanal	02_S	PlN	et	kanalid =kanali  (PlN  >kanal !02_S
28366	kasutatakse	kasuta	kasutama	27_V	IndPrIps	et	kasutatakse =kasuta  (IndPrIps  >kasutama !27_V
28368	ilusat	ilusa	ilus	02_A	SgP	et	ilusat =ilusa  (SgP  >ilus !02_A
28370	uhket	uhke	uhke	01_A	SgP	et	uhket =uhke  (SgP  >uhke !01_A
28371	mitagi	mi	mi	26_S	SgAb^	et	mitagi =mi  (SgAb^  >mi !26_S
28372	läheneda	lähene	lähenema	27_V	Inf	et	läheneda =lähene  (Inf  >lähenema !27_V
28376	teaduskond	teaduskond	teaduskond	22_S	SgN	et	teaduskond =teaduskond  (SgN  >teaduskond !22_S
28380	rahvuspärimus	pärimus	rahvus+pärimus	11_S	SgN	et	rahvuspärimus =pärimus  (SgN  >rahvus+pärimus !11_S
28383	kokkuvõte	võte	kokku+võte	06_S	SgN	et	kokkuvõte =võte  (SgN  >kokku+võte !06_S
28385	kavatsen	kavatse	kavatsema	27_V	IndPrSg1	et	kavatsen =kavatse  (IndPrSg1  >kavatsema !27_V
28389	õpetada	õpeta	õpetama	27_V	Inf	et	õpetada =õpeta  (Inf  >õpetama !27_V
28393	protsess	protsess	protsess	22_S	SgN	et	protsess =protsess  (SgN  >protsess !22_S
28395	riigiõppekavas	kava	riigi+õppe+kava	17_S	SgIn	et	riigiõppekavas =kava  (SgIn  >riigi+õppe+kava !17_S
28397	selgitada	selgita	selgitama	27_V	Inf	et	selgitada =selgita  (Inf  >selgitama !27_V
28402	tõestada	tõesta	tõestama	27_V	Inf	et	tõestada =tõesta  (Inf  >tõestama !27_V
28403	puudutab	puuduta	puudutama	27_V	IndPrSg3	et	puudutab =puuduta  (IndPrSg3  >puudutama !27_V
28404	vestlen	vestle	vestlema	30_V	IndPrSg1	et	vestlen =vestle  (IndPrSg1  >vestlema !30_V
28406	meetodid	meetodi	meetod	02_S	PlN	et	meetodid =meetodi  (PlN  >meetod !02_S
28407	uuringus	uuringu	uuring	02_S	SgIn	et	uuringus =uuringu  (SgIn  >uuring !02_S
28411	sajandeid	sajande	sajand	02_S	PlP	et	sajandeid =sajande  (PlP  >sajand !02_S
28419	tulebki	tule	tulema	36_V	IndPrSg3^	et	tulebki =tule  (IndPrSg3^  >tulema !36_V
28425	mõlematega	mõlema	mõlema	02_P	PlKom	et	mõlematega =mõlema  (PlKom  >mõlema !02_P
28431	kattub	kattu	kattuma	27_V	IndPrSg3	et	kattub =kattu  (IndPrSg3  >kattuma !27_V
28434	vööndiga	vööndi	vöönd	02_S	SgKom	et	vööndiga =vööndi  (SgKom  >vöönd !02_S
28437	naabritega	naabri	naaber	02_S	PlKom	et	naabritega =naabri  (PlKom  >naaber !02_S
28440	kaubanduskeskuse	keskuse	kaubandus+keskus	11~09_S	SgG	et	kaubanduskeskuse =keskuse  (SgG  >kaubandus+keskus !11~09_S
28452	külvinädalate	nädala	külvi+nädal	02_S	PlG	et	külvinädalate =nädala  (PlG  >külvi+nädal !02_S
28453	hingedeaeg	aeg	hingede+aeg	22_S	SgN	et	hingedeaeg =aeg  (SgN  >hingede+aeg !22_S
28459	tingimused	tingimuse	tingimus	11_S	PlN	et	tingimused =tingimuse  (PlN  >tingimus !11_S
28468	sajandi	sajandi	sajand	02_S	SgG	et	sajandi =sajandi  (SgG  >sajand !02_S
28474	klooster	klooster	klooster	02_S	SgN	et	klooster =klooster  (SgN  >klooster !02_S
28480	kultuuris	kultuuri	kultuur	22_S	SgIn	et	kultuuris =kultuuri  (SgIn  >kultuur !22_S
28485	tundide	tundi	tund	22_S	PlG	et	tundide =tundi  (PlG  >tund !22_S
28487	koolid	kooli	kool	22_S	PlN	et	koolid =kooli  (PlN  >kool !22_S
28488	initsiatiiv	initsiatiiv	initsiatiiv	22_S	SgN	et	initsiatiiv =initsiatiiv  (SgN  >initsiatiiv !22_S
28495	põhimõtted	mõtte	põhi+mõte	06_S	PlN	et	põhimõtted =mõtte  (PlN  >põhi+mõte !06_S
28504	esmased	esmase	esmane	10_A	PlN	et	esmased =esmase  (PlN  >esmane !10_A
28506	rahvakalendri	kalendri	rahva+kalender	02_S	SgG	et	rahvakalendri =kalendri  (SgG  >rahva+kalender !02_S
28508	mardipäev	päev	mardi+päev	22_S	SgN	et	mardipäev =päev  (SgN  >mardi+päev !22_S
28512	kooliastmel	astme	kooli+aste	05_S	SgAd	et	kooliastmel =astme  (SgAd  >kooli+aste !05_S
28528	kultuurielust	elu	kultuuri+elu	17_S	SgEl	et	kultuurielust =elu  (SgEl  >kultuuri+elu !17_S
28539	naljanditest	naljandi	naljand	02_S	PlEl	et	naljanditest =naljandi  (PlEl  >naljand !02_S
28344	potentsiaalsed	potentsiaalse	potentsiaalne	02_A	PlN	et	potentsiaalsed =potentsiaalse  (PlN  >potentsiaalne !02_A
28351	sotsiaalprobleemidele	probleemi	sotsiaal+probleem	22_S	PlAll	et	sotsiaalprobleemidele =probleemi  (PlAll  >sotsiaal+probleem !22_S
28354	probleemidele	probleemi	probleem	22_S	PlAll	et	probleemidele =probleemi  (PlAll  >probleem !22_S
28357	rasket	raske	raske	01_A	SgP	et	rasket =raske  (SgP  >raske !01_A
28361	enam-vähem	enam-vähem	enam+-vähem	41_D	ID	et	enam-vähem =enam-vähem  (ID  >enam+-vähem !41_D
28363	reklaamide	reklaami	reklaam	22_S	PlG	et	reklaamide =reklaami  (PlG  >reklaam !22_S
28364	viise	viise	viis	22_S	PlP	et	viise =viise  (PlP  >viis !22_S
28367	alasti	alasti	alasti	41_DA	ID	et	alasti =alasti  (ID  >alasti !41_DA
28374	lüüakse	lüü	lööma	38_V	IndPrIps	et	lüüakse =lüü  (IndPrIps  >lööma !38_V
28377	rahvuspärimuse	pärimuse	rahvus+pärimus	11_S	SgG	et	rahvuspärimuse =pärimuse  (SgG  >rahvus+pärimus !11_S
28378	venekeelses	keelse	vene+keelne	02_A	SgIn	et	venekeelses =keelse  (SgIn  >vene+keelne !02_A
28381	tegurid	teguri	tegur	02_S	PlN	et	tegurid =teguri  (PlN  >tegur !02_S
28398	kultuurist	kultuuri	kultuur	22_S	SgEl	et	kultuurist =kultuuri  (SgEl  >kultuur !22_S
28405	avaldan	avalda	avaldama	27_V	IndPrSg1	et	avaldan =avalda  (IndPrSg1  >avaldama !27_V
28412	asend	asend	asend	02_S	SgN	et	asend =asend  (SgN  >asend !02_S
28415	kaugest	kauge	kauge	01_A	SgEl	et	kaugest =kauge  (SgEl  >kauge !01_A
28418	erijooned	joone	eri+joon	13_S	PlN	et	erijooned =joone  (PlN  >eri+joon !13_S
28420	tõdeda	tõde	tõdema	27_V	Inf	et	tõdeda =tõde  (Inf  >tõdema !27_V
28439	tähtsa	tähtsa	tähtis	02_A	SgG	et	tähtsa =tähtsa  (SgG  >tähtis !02_A
28442	tunda	tund	tundma	34_V	Inf	et	tunda =tund  (Inf  >tundma !34_V
28443	seevastu	seevastu	see+vastu	41_D	ID	et	seevastu =seevastu  (ID  >see+vastu !41_D
28445	piirkondlikest	piirkondlike	piirkondlik	25_A	PlEl	et	piirkondlikest =piirkondlike  (PlEl  >piirkondlik !25_A
28460	eestikeelse	keelse	eesti+keelne	02_A	SgG	et	eestikeelse =keelse  (SgG  >eesti+keelne !02_A
28473	rõhutada	rõhuta	rõhutama	27_V	Inf	et	rõhutada =rõhuta  (Inf  >rõhutama !27_V
28475	vältida	välti	vältima	28_V	Inf	et	vältida =välti  (Inf  >vältima !28_V
28481	sulatada	sulata	sulatama	27_V	Inf	et	sulatada =sulata  (Inf  >sulatama !27_V
28483	teadma	tead	teadma	34_V	Sup	et	teadma =tead  (Sup  >teadma !34_V
28502	klassile	klassi	klass	22_S	SgAll	et	klassile =klassi  (SgAll  >klass !22_S
28511	emadepäev	päev	emade+päev	22_S	SgN	et	emadepäev =päev  (SgN  >emade+päev !22_S
28514	õpib	õpi	õppima	28_V	IndPrSg3	et	õpib =õpi  (IndPrSg3  >õppima !28_V
28524	keskendutakse	keskendu	keskenduma	27_V	IndPrIps	et	keskendutakse =keskendu  (IndPrIps  >keskenduma !27_V
28527	aktiivset	aktiivse	aktiivne	02_A	SgP	et	aktiivset =aktiivse  (SgP  >aktiivne !02_A
28533	kultuurpaikkonna	paikkonna	kultuur+paikkond	22_S	SgG	et	kultuurpaikkonna =paikkonna  (SgG  >kultuur+paikkond !22_S
28534	objektid	objekti	objekt	22_S	PlN	et	objektid =objekti  (PlN  >objekt !22_S
28538	muistenditest	muistendi	muistend	02_S	PlEl	et	muistenditest =muistendi  (PlEl  >muistend !02_S
28547	kursuste	kursus	kursus	11~09_S	PlG	et	kursuste =kursus  (PlG  >kursus !11~09_S
28548	fikseeritakse	fikseeri	fikseerima	28_V	IndPrIps	et	fikseeritakse =fikseeri  (IndPrIps  >fikseerima !28_V
28553	sünd	sünd	sünd	22_S	SgN	et	sünd =sünd  (SgN  >sünd !22_S
28554	teatri	teatri	teater	02_S	SgG	et	teatri =teatri  (SgG  >teater !02_S
28562	printsiibid	printsiibi	printsiip	22_S	PlN	et	printsiibid =printsiibi  (PlN  >printsiip !22_S
28565	tõlkekirjandus	kirjandus	tõlke+kirjandus	11_S	SgN	et	tõlkekirjandus =kirjandus  (SgN  >tõlke+kirjandus !11_S
28566	1klass	klass	klass	22_S	SgN	et	klass =klass  (SgN  >klass !22_S
28567	tekste	tekste	tekst	22_S	PlP	et	tekste =tekste  (PlP  >tekst !22_S
28571	rahvussümboolikat	sümboolika	rahvus+sümboolika	01_S	SgP	et	rahvussümboolikat =sümboolika  (SgP  >rahvus+sümboolika !01_S
28600	kadrisantidel	santi	kadri+sant	22_SA	PlAd	et	kadrisantidel =santi  (PlAd  >kadri+sant !22_SA
28609	päevaga	päeva	päev	22_S	SgKom	et	päevaga =päeva  (SgKom  >päev !22_S
28610	tähistatakse	tähista	tähistama	27_V	IndPrIps	et	tähistatakse =tähista  (IndPrIps  >tähistama !27_V
28621	lütseumis	lütseumi	lütseum	19~02_S	SgIn	et	lütseumis =lütseumi  (SgIn  >lütseum !19~02_S
28622	äratada	ärata	äratama	27_V	Inf	et	äratada =ärata  (Inf  >äratama !27_V
28623	elatakse	ela	elama	27_V	IndPrIps	et	elatakse =ela  (IndPrIps  >elama !27_V
28624	loevad	loe	lugema	28_V	IndPrPl3	et	loevad =loe  (IndPrPl3  >lugema !28_V
28633	viktoriinid	viktoriini	viktoriin	22_S	PlN	et	viktoriinid =viktoriini  (PlN  >viktoriin !22_S
28644	lastekirjanikega	kirjanike	laste+kirjanik	25_S	PlKom	et	lastekirjanikega =kirjanike  (PlKom  >laste+kirjanik !25_S
28424	paganlikud	paganliku	paganlik	25_A	PlN	et	paganlikud =paganliku  (PlN  >paganlik !25_A
28426	jaguneb	jagune	jagunema	27_V	IndPrSg3	et	jaguneb =jagune  (IndPrSg3  >jagunema !27_V
28430	ulatub	ulatu	ulatuma	27_V	IndPrSg3	et	ulatub =ulatu  (IndPrSg3  >ulatuma !27_V
28436	looduslikest	looduslike	looduslik	25_A	PlEl	et	looduslikest =looduslike  (PlEl  >looduslik !25_A
28446	vanal	vana	vana	17_AS	SgAd	et	vanal =vana  (SgAd  >vana !17_AS
28449	elamut	elamu	elamu	01_S	SgP	et	elamut =elamu  (SgP  >elamu !01_S
28454	rahvakultuuris	kultuuri	rahva+kultuur	22_S	SgIn	et	rahvakultuuris =kultuuri  (SgIn  >rahva+kultuur !22_S
28458	eestikeelne	keelne	eesti+keelne	02_A	SgN	et	eestikeelne =keelne  (SgN  >eesti+keelne !02_A
28461	kooliõpetuse	õpetuse	kooli+õpetus	11_S	SgG	et	kooliõpetuse =õpetuse  (SgG  >kooli+õpetus !11_S
28463	kirjaoskusele	oskuse	kirja+oskus	11~09_S	SgAll	et	kirjaoskusele =oskuse  (SgAll  >kirja+oskus !11~09_S
28472	päriseksostmine	ostmine	päri+seks+ostmine	12?10_S	SgN	et	päriseksostmine =ostmine  (SgN  >päri+seks+ostmine !12?10_S
28477	vastuolusid	olu	vastu+olu	17_S	PlP	et	vastuolusid =olu  (PlP  >vastu+olu !17_S
28479	materiaalses	materiaalse	materiaalne	02_A	SgIn	et	materiaalses =materiaalse  (SgIn  >materiaalne !02_A
28490	muutma	muut	muutma	34_V	Sup	et	muutma =muut  (Sup  >muutma !34_V
28493	määrab	määra	määrama	29_V	IndPrSg3	et	määrab =määra  (IndPrSg3  >määrama !29_V
28496	õppekorralduse	korralduse	õppe+korraldus	11_S	SgG	et	õppekorralduse =korralduse  (SgG  >õppe+korraldus !11_S
28498	õppeained	aine	õppe+aine	06_S	PlN	et	õppeained =aine  (PlN  >õppe+aine !06_S
28499	kooliastmete	astme	kooli+aste	05_S	PlG	et	kooliastmete =astme  (PlG  >kooli+aste !05_S
28501	seisundist	seisundi	seisund	02_S	SgEl	et	seisundist =seisundi  (SgEl  >seisund !02_S
28505	rahvussümbolikast	kast	rahvus+sümboli+kast	22_S	SgN	et	rahvussümbolikast =kast  (SgN  >rahvus+sümboli+kast !22_S
28509	jõulud	jõulu	jõul	22_S	PlN	et	jõulud =jõulu  (PlN  >jõul !22_S
28515	jutustama	jutusta	jutustama	27_V	Sup	et	jutustama =jutusta  (Sup  >jutustama !27_V
28519	riigipühad	püha	riigi+püha	17_SA	PlN	et	riigipühad =püha  (PlN  >riigi+püha !17_SA
28537	muinasjuttudest	juttu	muinas+jutt	22_S	PlEl	et	muinasjuttudest =juttu  (PlEl  >muinas+jutt !22_S
28550	kursust	kursus	kursus	11~09_S	SgP	et	kursust =kursus  (SgP  >kursus !11~09_S
28551	kursusena	kursuse	kursus	11~09_S	SgEs	et	kursusena =kursuse  (SgEs  >kursus !11~09_S
28556	muusikategelase	tegelase	muusika+tegelane	12_S	SgG	et	muusikategelase =tegelase  (SgG  >muusika+tegelane !12_S
28560	keeled	keele	keel	13_S	PlN	et	keeled =keele  (PlN  >keel !13_S
28568	sünnipäevakutseid	kutse	sünni+päeva+kutse	06_S	PlP	et	sünnipäevakutseid =kutse  (PlP  >sünni+päeva+kutse !06_S
28574	tähtpäevade	päeva	täht+päev	22_S	PlG	et	tähtpäevade =päeva  (PlG  >täht+päev !22_S
28575	õpilasel	õpilase	õpilane	12_S	SgAd	et	õpilasel =õpilase  (SgAd  >õpilane !12_S
28579	praktilist	praktilis	praktiline	12_A	SgP	et	praktilist =praktilis  (SgP  >praktiline !12_A
28581	häälega	hääle	hääl	13_S	SgKom	et	häälega =hääle  (SgKom  >hääl !13_S
28592	mõistavad	mõista	mõistma	34_V	IndPrPl3	et	mõistavad =mõista  (IndPrPl3  >mõistma !34_V
28598	roll	roll	roll	22_S	SgN	et	roll =roll  (SgN  >roll !22_S
28601	vilja-ja	ja	vilja-ja	41_J	ID	et	vilja-ja =ja  (ID  >vilja-ja !41_J
28612	tunneb	tunne	tundma	34_V	IndPrSg3	et	tunneb =tunne  (IndPrSg3  >tundma !34_V
28614	sümboolikat	sümboolika	sümboolika	01_S	SgP	et	sümboolikat =sümboolika  (SgP  >sümboolika !01_S
28620	teemat	teema	teema	16_S	SgP	et	teemat =teema  (SgP  >teema !16_S
28628	riigipühadest	püha	riigi+püha	17_SA	PlEl	et	riigipühadest =püha  (PlEl  >riigi+püha !17_SA
28634	oskad	oska	oskama	29_V	IndPrSg2	et	oskad =oska  (IndPrSg2  >oskama !29_V
28636	täiendada	täienda	täiendama	27_V	Inf	et	täiendada =täienda  (Inf  >täiendama !27_V
28638	lastekirjanikke	kirjanikke	laste+kirjanik	25_S	PlP	et	lastekirjanikke =kirjanikke  (PlP  >laste+kirjanik !25_S
28642	nukuteatrit	teatri	nuku+teater	02_S	SgP	et	nukuteatrit =teatri  (SgP  >nuku+teater !02_S
28657	ajakirjad	kirja	aja+kiri	24_S	PlN	et	ajakirjad =kirja  (PlN  >aja+kiri !24_S
28666	õnn	õnn	õnn	22_S	SgN	et	õnn =õnn  (SgN  >õnn !22_S
28668	tegelastega	tegelas	tegelane	12_S	PlKom	et	tegelastega =tegelas  (PlKom  >tegelane !12_S
28678	töölehed	lehe	töö+leht	22_S	PlN	et	töölehed =lehe  (PlN  >töö+leht !22_S
28680	ristsõnad	sõna	rist+sõna	17_S	PlN	et	ristsõnad =sõna  (PlN  >rist+sõna !17_S
28689	teemasid	teema	teema	16_S	PlP	et	teemasid =teema  (PlP  >teema !16_S
28691	loodusõpetust	õpetus	loodus+õpetus	11_S	SgP	et	loodusõpetust =õpetus  (SgP  >loodus+õpetus !11_S
28693	taotleb	taotle	taotlema	27_V	IndPrSg3	et	taotleb =taotle  (IndPrSg3  >taotlema !27_V
28695	hindama	hinda	hindama	29_V	Sup	et	hindama =hinda  (Sup  >hindama !29_V
28457	murrangu	murrangu	murrang	02_S	SgG	et	murrangu =murrangu  (SgG  >murrang !02_S
28464	etendas	etenda	etendama	27_V	IndIpfSg3	et	etendas =etenda  (IndIpfSg3  >etendama !27_V
28469	lõpul	lõpu	lõpp	22_SA	SgAd	et	lõpul =lõpu  (SgAd  >lõpp !22_SA
28478	vaimses	vaimse	vaimne	02_A	SgIn	et	vaimses =vaimse  (SgIn  >vaimne !02_A
28492	riiklik	riiklik	riiklik	25_A	SgN	et	riiklik =riiklik  (SgN  >riiklik !25_A
28497	kohustuslikud	kohustusliku	kohustuslik	25_A	PlN	et	kohustuslikud =kohustusliku  (PlN  >kohustuslik !25_A
28503	omandab	omanda	omandama	27_V	IndPrSg3	et	omandab =omanda  (IndPrSg3  >omandama !27_V
28507	tähtpäevadest	päeva	täht+päev	22_S	PlEl	et	tähtpäevadest =päeva  (PlEl  >täht+päev !22_S
28513	teadvustab	teadvusta	teadvustama	27_V	IndPrSg3	et	teadvustab =teadvusta  (IndPrSg3  >teadvustama !27_V
28517	vanasõnadest	sõna	vana+sõna	17_S	PlEl	et	vanasõnadest =sõna  (PlEl  >vana+sõna !17_S
28522	sümboleid	sümbole	sümbol	02_S	PlP	et	sümboleid =sümbole  (PlP  >sümbol !02_S
28523	koliastmel	astme	koli+aste	05_S	SgAd	et	koliastmel =astme  (SgAd  >koli+aste !05_S
28525	kultuurilugusenisest	senise	kultuuri+lugu+senine	10_A	SgEl	et	kultuurilugusenisest =senise  (SgEl  >kultuuri+lugu+senine !10_A
28526	pakutakse	paku	pakkuma	28_V	IndPrIps	et	pakutakse =paku  (IndPrIps  >pakkuma !28_V
28529	korraldatakse	korralda	korraldama	27_V	IndPrIps	et	korraldatakse =korralda  (IndPrIps  >korraldama !27_V
28530	eestikeelseid	keelse	eesti+keelne	02_A	PlP	et	eestikeelseid =keelse  (PlP  >eesti+keelne !02_A
28531	käiakse	käi	käima	38_V	IndPrIps	et	käiakse =käi  (IndPrIps  >käima !38_V
28532	muuseumides	muuseumi	muuseum	19_S	PlIn	et	muuseumides =muuseumi  (PlIn  >muuseum !19_S
28544	liigendub	liigendu	liigenduma	27_V	IndPrSg3	et	liigendub =liigendu  (IndPrSg3  >liigenduma !27_V
28559	teatrietenduse	etenduse	teatri+etendus	11_S	SgG	et	teatrietenduse =etenduse  (SgG  >teatri+etendus !11_S
28563	kultuuride	kultuuri	kultuur	22_S	PlG	et	kultuuride =kultuuri  (PlG  >kultuur !22_S
28572	tunnis	tunni	tund	22_S	SgIn	et	tunnis =tunni  (SgIn  >tund !22_S
28577	kontakt	kontakt	kontakt	22_S	SgN	et	kontakt =kontakt  (SgN  >kontakt !22_S
28580	keskmes	keskme	kese	05_S	SgIn	et	keskmes =keskme  (SgIn  >kese !05_S
28582	täiendab	täienda	täiendama	27_V	IndPrSg3	et	täiendab =täienda  (IndPrSg3  >täiendama !27_V
28583	rahvuslind	lind	rahvus+lind	22_S	SgN	et	rahvuslind =lind  (SgN  >rahvus+lind !22_S
28594	tavasid	tava	tava	17_S	PlP	et	tavasid =tava  (PlP  >tava !17_S
28595	laulma	laul	laulma	33_V	Sup	et	laulma =laul  (Sup  >laulma !33_V
28596	tantsima	tantsi	tantsima	28_V	Sup	et	tantsima =tantsi  (Sup  >tantsima !28_V
28599	mardisantidel	santi	mardi+sant	22_SA	PlAd	et	mardisantidel =santi  (PlAd  >mardi+sant !22_SA
28603	õppeeesmärgideks	märgi	õppe+ees+märg	22_AS	PlTr	et	õppeeesmärgideks =märgi  (PlTr  >õppe+ees+märg !22_AS
28604	oskab	oska	oskama	29_V	IndPrSg3	et	oskab =oska  (IndPrSg3  >oskama !29_V
28606	rakendada	rakenda	rakendama	27_V	Inf	et	rakendada =rakenda  (Inf  >rakendama !27_V
28608	lisandub	lisandu	lisanduma	27_V	IndPrSg3	et	lisandub =lisandu  (IndPrSg3  >lisanduma !27_V
28611	sõnajalaõit	õi	sõna+jala+õis	14_S	SgP	et	sõnajalaõit =õi  (SgP  >sõna+jala+õis !14_S
28630	vapp	vapp	vapp	22_S	SgN	et	vapp =vapp  (SgN  >vapp !22_S
28631	vastlad	vastla	vastel	02_S	PlN	et	vastlad =vastla  (PlN  >vastel !02_S
28632	võistlused	võistluse	võistlus	11~09_S	PlN	et	võistlused =võistluse  (PlN  >võistlus !11~09_S
28635	olümpiaadid	olümpiaadi	olümpiaad	22_S	PlN	et	olümpiaadid =olümpiaadi  (PlN  >olümpiaad !22_S
28645	tundides	tundi	tund	22_S	PlIn	et	tundides =tundi  (PlIn  >tund !22_S
28649	initsiatiivil	initsiatiivi	initsiatiiv	22_S	SgAd	et	initsiatiivil =initsiatiivi  (SgAd  >initsiatiiv !22_S
28663	naksitrallid	tralli	naksi+trall	22_S	PlN	et	naksitrallid =tralli  (PlN  >naksi+trall !22_S
28675	viktoriin	viktoriin	viktoriin	22_S	SgN	et	viktoriin =viktoriin  (SgN  >viktoriin !22_S
28682	sõnastikud	sõnastiku	sõnastik	25_S	PlN	et	sõnastikud =sõnastiku  (PlN  >sõnastik !25_S
28687	arvamusel	arvamuse	arvamus	11_S	SgAd	et	arvamusel =arvamuse  (SgAd  >arvamus !11_S
28694	mõistma	mõist	mõistma	34_V	Sup	et	mõistma =mõist  (Sup  >mõistma !34_V
28697	ajaloofakte	fakte	aja+loo+fakt	22_S	PlP	et	ajaloofakte =fakte  (PlP  >aja+loo+fakt !22_S
28702	eripärale	pära	eri+pära	17_S	SgAll	et	eripärale =pära  (SgAll  >eri+pära !17_S
28703	senisest	senise	senine	10_A	SgEl	et	senisest =senise  (SgEl  >senine !10_A
28709	algklassides	klassi	alg+klass	22_S	PlIn	et	algklassides =klassi  (PlIn  >alg+klass !22_S
28719	naljandid	naljandi	naljand	02_S	PlN	et	naljandid =naljandi  (PlN  >naljand !02_S
28724	valmistada	valmista	valmistama	27_V	Inf	et	valmistada =valmista  (Inf  >valmistama !27_V
28732	kultuuriõppimisele	õppimise	kultuuri+õppimine	12_S	SgAll	et	kultuuriõppimisele =õppimise  (SgAll  >kultuuri+õppimine !12_S
28484	kummaline	kummaline	kummaline	12_A	SgN	et	kummaline =kummaline  (SgN  >kummaline !12_A
28486	lühiülevaade	vaade	lühi+üle+vaade	06_S	SgN	et	lühiülevaade =vaade  (SgN  >lühi+üle+vaade !06_S
28489	haridusministeeriumilt	ministeeriumi	haridus+ministeerium	19~02_S	SgAbl	et	haridusministeeriumilt =ministeeriumi  (SgAbl  >haridus+ministeerium !19~02_S
28491	riiklik	riiklik	riiklik	25_A	SgN	et	riiklik =riiklik  (SgN  >riiklik !25_A
28494	riikliku	riikliku	riiklik	25_A	SgG	et	riikliku =riikliku  (SgG  >riiklik !25_A
28500	ülesehituse	ehituse	üles+ehitus	11_S	SgG	et	ülesehituse =ehituse  (SgG  >üles+ehitus !11_S
28510	sõbrapäev	päev	sõbra+päev	22_S	SgN	et	sõbrapäev =päev  (SgN  >sõbra+päev !22_S
28516	paikkonna	paikkonna	paikkond	22_S	SgG	et	paikkonna =paikkonna  (SgG  >paikkond !22_S
28518	kõnekäändusest	use	kõne+käänd+usk	22_S	PlEl	et	kõnekäändusest =use  (PlEl  >kõne+käänd+usk !22_S
28520	president	president	president	22_S	SgN	et	president =president  (SgN  >president !22_S
28521	teab	tea	teadma	34_V	IndPrSg3	et	teab =tea  (IndPrSg3  >teadma !34_V
28535	kultuuritegelased	tegelase	kultuuri+tegelane	12_S	PlN	et	kultuuritegelased =tegelase  (PlN  >kultuuri+tegelane !12_S
28536	näiteid	näite	näide	06_S	PlP	et	näiteid =näite  (PlP  >näide !06_S
28540	legendidest	legendi	legend	22_S	PlEl	et	legendidest =legendi  (PlEl  >legend !22_S
28541	objekte	objekte	objekt	22_S	PlP	et	objekte =objekte  (PlP  >objekt !22_S
28545	kursuseks	kursuse	kursus	11~09_S	SgTr	et	kursuseks =kursuse  (SgTr  >kursus !11~09_S
28549	kooliõppekavas	kava	kooli+õppe+kava	17_S	SgIn	et	kooliõppekavas =kava  (SgIn  >kooli+õppe+kava !17_S
28552	ärkamisaegne	aegne	ärkamis+aegne	02_A	SgN	et	ärkamisaegne =aegne  (SgN  >ärkamis+aegne !02_A
28555	filmilinal	lina	filmi+lina	17_S	SgAd	et	filmilinal =lina  (SgAd  >filmi+lina !17_S
28557	kunstniku	kunstniku	kunstnik	25_S	SgG	et	kunstniku =kunstniku  (SgG  >kunstnik !25_S
28558	kultuurisaate	saate	kultuuri+saade	06_S	SgG	et	kultuurisaate =saate  (SgG  >kultuuri+saade !06_S
28561	keeleteadlase	teadlase	keele+teadlane	12?10_S	SgG	et	keeleteadlase =teadlase  (SgG  >keele+teadlane !12?10_S
28564	seosed	seose	seos	09_S	PlN	et	seosed =seose  (PlN  >seos !09_S
28569	kommentaar	kommentaar	kommentaar	22_S	SgN	et	kommentaar =kommentaar  (SgN  >kommentaar !22_S
28573	jõulutraditsioone	traditsioone	jõulu+traditsioon	22_S	PlP	et	jõulutraditsioone =traditsioone  (PlP  >jõulu+traditsioon !22_S
28576	tekib	teki	tekkima	28_V	IndPrSg3	et	tekib =teki  (IndPrSg3  >tekkima !28_V
28585	jaanipäev	päev	jaani+päev	22_S	SgN	et	jaanipäev =päev  (SgN  >jaani+päev !22_S
28587	arenguks	arengu	areng	02_S	SgTr	et	arenguks =arengu  (SgTr  >areng !02_S
28589	tiritamm	tamm	tiri+tamm	22_S	SgN	et	tiritamm =tamm  (SgN  >tiri+tamm !22_S
28591	kommentaarid	kommentaari	kommentaar	22_S	PlN	et	kommentaarid =kommentaari  (PlN  >kommentaar !22_S
28593	päevadega	päeva	päev	22_S	PlKom	et	päevadega =päeva  (PlKom  >päev !22_S
28602	nemad	nema	tema	00_P	PlN	et	nemad =nema  (PlN  >tema !00_P
28613	kolmanda	kolmanda	kolmas	02_O	SgG	et	kolmanda =kolmanda  (SgG  >kolmas !02_O
28619	tähtpäevadega	päeva	täht+päev	22_S	PlKom	et	tähtpäevadega =päeva  (PlKom  >täht+päev !22_S
28626	kõnekäändudest	käändu	kõne+käänd	22_S	PlEl	et	kõnekäändudest =käändu  (PlEl  >kõne+käänd !22_S
28629	lipp	lipp	lipp	22_S	SgN	et	lipp =lipp  (SgN  >lipp !22_S
28637	ülevaade	vaade	üle+vaade	06_S	SgN	et	ülevaade =vaade  (SgN  >üle+vaade !06_S
28639	lasteraamatut	raamatu	laste+raamat	02_S	SgP	et	lasteraamatut =raamatu  (SgP  >laste+raamat !02_S
28640	neljanda	neljanda	neljas	02_O	SgG	et	neljanda =neljanda  (SgG  >neljas !02_O
28653	raamatute	raamatu	raamat	02_S	PlG	et	raamatute =raamatu  (PlG  >raamat !02_S
28658	raadiosaated	saate	raadio+saade	06_S	PlN	et	raadiosaated =saate  (PlN  >raadio+saade !06_S
28665	pealiskaudne	kaudne	pealis+kaudne	02_A	SgN	et	pealiskaudne =kaudne  (SgN  >pealis+kaudne !02_A
28672	kirjandust	kirjandus	kirjandus	11_S	SgP	et	kirjandust =kirjandus  (SgP  >kirjandus !11_S
28674	ajalootunnid	tunni	aja+loo+tund	22_S	PlN	et	ajalootunnid =tunni  (PlN  >aja+loo+tund !22_S
28679	juhised	juhise	juhis	09_S	PlN	et	juhised =juhise  (PlN  >juhis !09_S
28685	grammatikale	grammatika	grammatika	01_S	SgAll	et	grammatikale =grammatika  (SgAll  >grammatika !01_S
28699	kaasaegsest	aegse	kaas+aegne	02_A	SgEl	et	kaasaegsest =aegse  (SgEl  >kaas+aegne !02_A
28701	mõtte-	mõtte	mõte	06_S	SgG	et	mõtte- =mõtte  (SgG  >mõte !06_S
28704	objektidest	objekti	objekt	22_S	PlEl	et	objektidest =objekti  (PlEl  >objekt !22_S
28710	valmistab	valmista	valmistama	27_V	IndPrSg3	et	valmistab =valmista  (IndPrSg3  >valmistama !27_V
28717	kultuuritegelastestõpilane	õpilane	kultuuri+tegelas+test+õpilane	12_S	SgN	et	kultuuritegelastestõpilane =õpilane  (SgN  >kultuuri+tegelas+test+õpilane !12_S
28718	noorsookirjandust	kirjandus	noor+soo+kirjandus	11_S	SgP	et	noorsookirjandust =kirjandus  (SgP  >noor+soo+kirjandus !11_S
28542	eluolust	olu	elu+olu	17_S	SgEl	et	eluolust =olu  (SgEl  >elu+olu !17_S
28543	gümnaasiumile	gümnaasiumi	gümnaasium	19~02_S	SgAll	et	gümnaasiumile =gümnaasiumi  (SgAll  >gümnaasium !19~02_S
28546	maht	maht	maht	22_S	SgN	et	maht =maht  (SgN  >maht !22_S
28570	tundma	tund	tundma	34_V	Sup	et	tundma =tund  (Sup  >tundma !34_V
28578	keeleõppes	õppe	keele+õpe	06_S	SgIn	et	keeleõppes =õppe  (SgIn  >keele+õpe !06_S
28584	lill	lill	lill	22_S	SgN	et	lill =lill  (SgN  >lill !22_S
28586	projektid	projekti	projekt	22_S	PlN	et	projektid =projekti  (PlN  >projekt !22_S
28588	õppekavajärgseid	järgse	õppe+kava+järgne	02_A	PlP	et	õppekavajärgseid =järgse  (PlP  >õppe+kava+järgne !02_A
28590	muinasjutte	jutte	muinas+jutt	22_S	PlP	et	muinasjutte =jutte  (PlP  >muinas+jutt !22_S
28597	antakse	an	andma	34_V	IndPrIps	et	antakse =an  (IndPrIps  >andma !34_V
28605	praktikal	praktika	praktika	01_S	SgAd	et	praktikal =praktika  (SgAd  >praktika !01_S
28607	jõulupühade	püha	jõulu+püha	17_SA	PlG	et	jõulupühade =püha  (PlG  >jõulu+püha !17_SA
28615	mõnedest	mõne	mõni	20_P	PlEl	et	mõnedest =mõne  (PlEl  >mõni !20_P
28616	kadripäev	päev	kadri+päev	22_S	SgN	et	kadripäev =päev  (SgN  >kadri+päev !22_S
28617	koolisisestel	sises	kooli+sisene	10_A	PlAd	et	koolisisestel =sises  (PlAd  >kooli+sisene !10_A
28618	sümboolikaga	sümboolika	sümboolika	01_S	SgKom	et	sümboolikaga =sümboolika  (SgKom  >sümboolika !01_S
28625	jutte	jutte	jutt	22_S	PlP	et	jutte =jutte  (PlP  >jutt !22_S
28627	arendatakse	arenda	arendama	27_V	IndPrIps	et	arendatakse =arenda  (IndPrIps  >arendama !27_V
28641	lasteraamatutega	raamatu	laste+raamat	02_S	PlKom	et	lasteraamatutega =raamatu  (PlKom  >laste+raamat !02_S
28643	telesaateid	saate	tele+saade	06_S	PlP	et	telesaateid =saate  (PlP  >tele+saade !06_S
28647	kirjanikest	kirjanike	kirjanik	25_S	PlEl	et	kirjanikest =kirjanike  (PlEl  >kirjanik !25_S
28650	kutsuda	kutsu	kutsuma	28_V	Inf	et	kutsuda =kutsu  (Inf  >kutsuma !28_V
28655	5klass	klass	klass	22_S	SgN	et	klass =klass  (SgN  >klass !22_S
28660	viiendas	viienda	viies	02_O	SgIn	et	viiendas =viienda  (SgIn  >viies !02_O
28662	loomingut	loomingu	looming	02_S	SgP	et	loomingut =loomingu  (SgP  >looming !02_S
28664	raua	raua	raud	22_S	SgG	et	raua =raua  (SgG  >raud !22_S
28667	suudavad	suuda	suutma	34_V	IndPrPl3	et	suudavad =suuda  (IndPrPl3  >suutma !34_V
28669	tutvutakse	tutvu	tutvuma	27_V	IndPrIps	et	tutvutakse =tutvu  (IndPrIps  >tutvuma !27_V
28670	loetakse	loe	lugema	28_V	IndPrIps	et	loetakse =loe  (IndPrIps  >lugema !28_V
28673	muistsed	muistse	muistne	02_A	PlN	et	muistsed =muistse  (PlN  >muistne !02_A
28684	vanasõnu	sõnu	vana+sõna	17_S	PlP	et	vanasõnu =sõnu  (PlP  >vana+sõna !17_S
28686	teemadele	teema	teema	16_S	PlAll	et	teemadele =teema  (PlAll  >teema !16_S
28690	minnes	minn	minema	36_V	Ger	et	minnes =minn  (Ger  >minema !36_V
28706	katkendeid	katkende	katkend	02_S	PlP	et	katkendeid =katkende  (PlP  >katkend !02_S
28707	rakendab	rakenda	rakendama	27_V	IndPrSg3	et	rakendab =rakenda  (IndPrSg3  >rakendama !27_V
28711	kultuuritegelasi	tegelasi	kultuuri+tegelane	12_S	PlP	et	kultuuritegelasi =tegelasi  (PlP  >kultuuri+tegelane !12_S
28713	muuseume	muuseume	muuseum	19_S	PlP	et	muuseume =muuseume  (PlP  >muuseum !19_S
28715	koolide	kooli	kool	22_S	PlG	et	koolide =kooli  (PlG  >kool !22_S
28716	laiendab	laienda	laiendama	27_V	IndPrSg3	et	laiendab =laienda  (IndPrSg3  >laiendama !27_V
28727	sooritab	soorita	sooritama	27_V	IndPrSg3	et	sooritab =soorita  (IndPrSg3  >sooritama !27_V
28729	eksami	eksami	eksam	02_S	SgG	et	eksami =eksami  (SgG  >eksam !02_S
28733	taotletakse	taotle	taotlema	27_V	IndPrIps	et	taotletakse =taotle  (IndPrIps  >taotlema !27_V
28738	1õppe-eesmärgid	märgi	õppe-ees+märk	22_S	PlN	et	õppe-eesmärgid =märgi  (PlN  >õppe-ees+märk !22_S
28744	osana	osa	osa	17_S	SgEs	et	osana =osa  (SgEs  >osa !17_S
28745	rikkusena	rikkuse	rikkus	11~09_S	SgEs	et	rikkusena =rikkuse  (SgEs  >rikkus !11~09_S
28748	täiustab	täiusta	täiustama	27_V	IndPrSg3	et	täiustab =täiusta  (IndPrSg3  >täiustama !27_V
28751	kultuuriprotsessidest	protsessi	kultuuri+protsess	22_S	PlEl	et	kultuuriprotsessidest =protsessi  (PlEl  >kultuuri+protsess !22_S
28754	arendab	arenda	arendama	27_V	IndPrSg3	et	arendab =arenda  (IndPrSg3  >arendama !27_V
28758	protsesse	protsesse	protsess	22_S	PlP	et	protsesse =protsesse  (PlP  >protsess !22_S
28760	andmetega	andme	anne	05_S	PlKom	et	andmetega =andme  (PlKom  >anne !05_S
28761	üldistatakse	üldista	üldistama	27_V	IndPrIps	et	üldistatakse =üldista  (IndPrIps  >üldistama !27_V
28767	võtteid	võtte	võte	06_S	PlP	et	võtteid =võtte  (PlP  >võte !06_S
28779	leksikon	leksikon	leksikon	19_S	SgN	et	leksikon =leksikon  (SgN  >leksikon !19_S
28780	sõnaraamat	raamat	sõna+raamat	02_S	SgN	et	sõnaraamat =raamat  (SgN  >sõna+raamat !02_S
28646	põgusa	põgusa	põgus	02_S	SgG	et	põgusa =põgusa  (SgG  >põgus !02_S
28648	lastekirjanduse	kirjanduse	laste+kirjandus	11_S	SgG	et	lastekirjanduse =kirjanduse  (SgG  >laste+kirjandus !11_S
28651	lastekirjanike	kirjanike	laste+kirjanik	25_S	PlG	et	lastekirjanike =kirjanike  (PlG  >laste+kirjanik !25_S
28652	tekitada	tekita	tekitama	27_V	Inf	et	tekitada =tekita  (Inf  >tekitama !27_V
28654	käo	käo	kägu	18_S	SgG	et	käo =käo  (SgG  >kägu !18_S
28656	abiks	abi	abi	17_S	SgTr	et	abiks =abi  (SgTr  >abi !17_S
28659	videofilmid	filmi	video+film	22_S	PlN	et	videofilmid =filmi  (PlN  >video+film !22_S
28661	aur	aur	aur	22_S	SgN	et	aur =aur  (SgN  >aur !22_S
28671	autorite	autori	autor	02_S	PlG	et	autorite =autori  (PlG  >autor !02_S
28676	meetmed	meetme	meede	05_S	PlN	et	meetmed =meetme  (PlN  >meede !05_S
28677	arvutiprogrammid	programmi	arvuti+programm	22_S	PlN	et	arvutiprogrammid =programmi  (PlN  >arvuti+programm !22_S
28681	ajalehed	lehe	aja+leht	22_S	PlN	et	ajalehed =lehe  (PlN  >aja+leht !22_S
28683	teatmeteosed	teose	teatme+teos	09_S	PlN	et	teatmeteosed =teose  (PlN  >teatme+teos !09_S
28688	mõtet	mõte	mõte	06_S	SgP	et	mõtet =mõte  (SgP  >mõte !06_S
28692	valikainena	aine	valik+aine	06_S	SgEs	et	valikainena =aine  (SgEs  >valik+aine !06_S
28696	püsiväärtusi	väärtusi	püsi+väärtus	11_S	PlP	et	püsiväärtusi =väärtusi  (PlP  >püsi+väärtus !11_S
28698	huvitub	huvitu	huvituma	27_V	IndPrSg3	et	huvitub =huvitu  (IndPrSg3  >huvituma !27_V
28700	rikastab	rikasta	rikastama	27_V	IndPrSg3	et	rikastab =rikasta  (IndPrSg3  >rikastama !27_V
28705	loeb	loe	lugema	28_V	IndPrSg3	et	loeb =loe  (IndPrSg3  >lugema !28_V
28708	õppematerjalid	materjali	õppe+materjal	19_S	PlN	et	õppematerjalid =materjali  (PlN  >õppe+materjal !19_S
28714	näitusi	näitusi	näitus	11_S	PlP	et	näitusi =näitusi  (PlP  >näitus !11_S
28721	tundidest	tundi	tund	22_S	PlEl	et	tundidest =tundi  (PlEl  >tund !22_S
28723	originaaltekstid	teksti	originaal+tekst	22_S	PlN	et	originaaltekstid =teksti  (PlN  >originaal+tekst !22_S
28731	gümnaasiumiastmel	astme	gümnaasiumi+aste	05_S	SgAd	et	gümnaasiumiastmel =astme  (SgAd  >gümnaasiumi+aste !05_S
28734	orienteerub	orienteeru	orienteeruma	27_V	IndPrSg3	et	orienteerub =orienteeru  (IndPrSg3  >orienteeruma !27_V
28739	suhtub	suhtu	suhtuma	27_V	IndPrSg3	et	suhtub =suhtu  (IndPrSg3  >suhtuma !27_V
28741	tunnustades	tunnusta	tunnustama	27_V	Ger	et	tunnustades =tunnusta  (Ger  >tunnustama !27_V
28747	erivormina	vormi	eri+vorm	22_S	SgEs	et	erivormina =vormi  (SgEs  >eri+vorm !22_S
28763	õppeprotsessis	protsessi	õppe+protsess	22_S	SgIn	et	õppeprotsessis =protsessi  (SgIn  >õppe+protsess !22_S
28765	vorme	vorme	vorm	22_S	PlP	et	vorme =vorme  (PlP  >vorm !22_S
28769	juhan	juhan	juhan	02_S	SgN	et	juhan =juhan  (SgN  >juhan !02_S
28776	õppevahendid	vahendi	õppe+vahend	02_S	PlN	et	õppevahendid =vahendi  (PlN  >õppe+vahend !02_S
28778	kirjanike	kirjanike	kirjanik	25_S	PlG	et	kirjanike =kirjanike  (PlG  >kirjanik !25_S
28783	läbib	läbi	läbima	27_V	IndPrSg3	et	läbib =läbi  (IndPrSg3  >läbima !27_V
28789	teaks	tea	teadma	34_V	KndPrPs	et	teaks =tea  (KndPrPs  >teadma !34_V
28797	anonüümne	anonüümne	anonüümne	02_A	SgN	et	anonüümne =anonüümne  (SgN  >anonüümne !02_A
28805	32st	st	st	41_I	ID	et	st =st  (ID  >st !41_I
28811	rahvussümbolid	sümboli	rahvus+sümbol	02_S	PlN	et	rahvussümbolid =sümboli  (PlN  >rahvus+sümbol !02_S
28812	1klassist	klassi	klass	22_S	SgEl	et	klassist =klassi  (SgEl  >klass !22_S
28822	puudutas	puuduta	puudutama	27_V	IndIpfSg3	et	puudutas =puuduta  (IndIpfSg3  >puudutama !27_V
28835	lisada	lisa	lisama	27_V	Inf	et	lisada =lisa  (Inf  >lisama !27_V
28839	vanasõnadega	sõna	vana+sõna	17_S	PlKom	et	vanasõnadega =sõna  (PlKom  >vana+sõna !17_S
28844	sisuga	sisu	sisu	17_S	SgKom	et	sisuga =sisu  (SgKom  >sisu !17_S
28846	järgmiseks	järgmise	järgmine	12?10_A	SgTr	et	järgmiseks =järgmise  (SgTr  >järgmine !12?10_A
28849	nimesid	nime	nimi	20_S	PlP	et	nimesid =nime  (PlP  >nimi !20_S
28853	teati	tea	teadma	34_V	IndIpfIps	et	teati =tea  (IndIpfIps  >teadma !34_V
28856	mardi-ja	ja	mardi-ja	41_J	ID	et	mardi-ja =ja  (ID  >mardi-ja !41_J
28858	pühasid	püha	püha	17_SA	PlP	et	pühasid =püha  (PlP  >püha !17_SA
28864	põhjusel	põhjuse	põhjus	11~09_S	SgAd	et	põhjusel =põhjuse  (SgAd  >põhjus !11~09_S
28868	midagieelviimaseks	viimase	midagi+eel+viimane	10_A	SgTr	et	midagieelviimaseks =viimase  (SgTr  >midagi+eel+viimane !10_A
28869	õpilased99	õpilase	õpilane	12_S	PlN	et	õpilased =õpilase  (PlN  >õpilane !12_S
28872	kosmos	kosmos	kosmos	11~09_S	SgN	et	kosmos =kosmos  (SgN  >kosmos !11~09_S
28881	täieliku	täieliku	täielik	25_A	SgG	et	täieliku =täieliku  (SgG  >täielik !25_A
28884	konkreetsed	konkreetse	konkreetne	02_A	PlN	et	konkreetsed =konkreetse  (PlN  >konkreetne !02_A
28712	teatreid	teatre	teater	02_S	PlP	et	teatreid =teatre  (PlP  >teater !02_S
28722	needki	nee	see	00_P	PlN^	et	needki =nee  (PlN^  >see !00_P
28725	õpilasi	õpilasi	õpilane	12_S	PlP	et	õpilasi =õpilasi  (PlP  >õpilane !12_S
28726	eksamiks	eksami	eksam	02_S	SgTr	et	eksamiks =eksami  (SgTr  >eksam !02_S
28728	algtaseme	taseme	alg+tase	04_S	SgG	et	algtaseme =taseme  (SgG  >alg+tase !04_S
28740	kirjandusse	kirjandus	kirjandus	11_S	SgAdt	et	kirjandusse =kirjandus  (SgAdt  >kirjandus !11_S
28742	vaimse	vaimse	vaimne	02_A	SgG	et	vaimse =vaimse  (SgG  >vaimne !02_A
28750	küllaldase	küllaldase	küllaldane	12_A	SgG	et	küllaldase =küllaldase  (SgG  >küllaldane !12_A
28752	otsingute	otsingu	otsing	02_S	PlG	et	otsingute =otsingu  (PlG  >otsing !02_S
28753	seostest	seos	seos	09_S	PlEl	et	seostest =seos  (PlEl  >seos !09_S
28759	süveneb	süvene	süvenema	27_V	IndPrSg3	et	süveneb =süvene  (IndPrSg3  >süvenema !27_V
28774	kivirähk	rähk	kivi+rähk	22_S	SgN	et	kivirähk =rähk  (SgN  >kivi+rähk !22_S
28775	õppekirjandus	kirjandus	õppe+kirjandus	11_S	SgN	et	õppekirjandus =kirjandus  (SgN  >õppe+kirjandus !11_S
28781	kirjanduslikke	kirjanduslikke	kirjanduslik	25_A	PlP	et	kirjanduslikke =kirjanduslikke  (PlP  >kirjanduslik !25_A
28782	riigieksamile	eksami	riigi+eksam	02_S	SgAll	et	riigieksamile =eksami  (SgAll  >riigi+eksam !02_S
28787	lipuvärve	värve	lipu+värv	22_S	PlP	et	lipuvärve =värve  (PlP  >lipu+värv !22_S
28788	lipu	lipu	lipp	22_S	SgG	et	lipu =lipu  (SgG  >lipp !22_S
28790	nädalas	nädala	nädal	02_S	SgIn	et	nädalas =nädala  (SgIn  >nädal !02_S
28793	sõltub	sõltu	sõltuma	27_V	IndPrSg3	et	sõltub =sõltu  (IndPrSg3  >sõltuma !27_V
28799	koosnes	koosne	koosnema	27_V	IndIpfSg3	et	koosnes =koosne  (IndIpfSg3  >koosnema !27_V
28801	esimeseks	esimese	esimene	12_OP	SgTr	et	esimeseks =esimese  (SgTr  >esimene !12_OP
28803	vapi	vapi	vapp	22_S	SgG	et	vapi =vapi  (SgG  >vapp !22_S
28804	vastuseid	vastuse	vastus	09_S	PlP	et	vastuseid =vastuse  (PlP  >vastus !09_S
28807	tulemus	tulemus	tulemus	11_S	SgN	et	tulemus =tulemus  (SgN  >tulemus !11_S
28813	sümbolid	sümboli	sümbol	02_S	PlN	et	sümbolid =sümboli  (PlN  >sümbol !02_S
28814	õpikute	õpiku	õpik	02_S	PlG	et	õpikute =õpiku  (PlG  >õpik !02_S
28818	suvevaheajal	aja	suve+vahe+aeg	22_S	SgAd	et	suvevaheajal =aja  (SgAd  >suve+vahe+aeg !22_S
28836	audiomaterjale	materjale	audio+materjal	19_S	PlP	et	audiomaterjale =materjale  (PlP  >audio+materjal !19_S
28852	missuguseid	suguse	mis+sugune	10_P	PlP	et	missuguseid =suguse  (PlP  >mis+sugune !10_P
28861	peode	peo	peo	26_S	PlG	et	peode =peo  (PlG  >peo !26_S
28873	sõpruslavastusi	lavastusi	sõprus+lavastus	11_S	PlP	et	sõpruslavastusi =lavastusi  (PlP  >sõprus+lavastus !11_S
28878	tõestab	tõesta	tõestama	27_V	IndPrSg3	et	tõestab =tõesta  (IndPrSg3  >tõestama !27_V
28891	vastupiditestisse	testi	vastu+pidi+test	22_S	SgIll	et	vastupiditestisse =testi  (SgIll  >vastu+pidi+test !22_S
28906	variante	variante	variant	22_S	PlP	et	variante =variante  (PlP  >variant !22_S
28907	räpp	räpp	räpp	22_S	SgN	et	räpp =räpp  (SgN  >räpp !22_S
28910	rahvuslaulude	laulu	rahvus+laul	22_S	PlG	et	rahvuslaulude =laulu  (PlG  >rahvus+laul !22_S
28921	spetsiaalses	spetsiaalse	spetsiaalne	02_A	SgIn	et	spetsiaalses =spetsiaalse  (SgIn  >spetsiaalne !02_A
28927	ketist	keti	kett	22_S	SgEl	et	ketist =keti  (SgEl  >kett !22_S
28928	tollast	tollas	tollane	10_A	SgP	et	tollast =tollas  (SgP  >tollane !10_A
28944	korraldama	korralda	korraldama	27_V	Sup	et	korraldama =korralda  (Sup  >korraldama !27_V
28954	tulemusigümnaasiumiastmes	astme	tule+musi+gümnaasiumi+aste	05_S	SgIn	et	tulemusigümnaasiumiastmes =astme  (SgIn  >tule+musi+gümnaasiumi+aste !05_S
28957	ekskursioonidel	ekskursiooni	ekskursioon	22_S	PlAd	et	ekskursioonidel =ekskursiooni  (PlAd  >ekskursioon !22_S
28958	õppekavaga	kava	õppe+kava	17_S	SgKom	et	õppekavaga =kava  (SgKom  >õppe+kava !17_S
28961	situatsioon	situatsioon	situatsioon	22_S	SgN	et	situatsioon =situatsioon  (SgN  >situatsioon !22_S
28966	põhjendada	põhjenda	põhjendama	27_V	Inf	et	põhjendada =põhjenda  (Inf  >põhjendama !27_V
28968	kaasaaegsed	aegse	kaasa+aegne	02_A	PlN	et	kaasaaegsed =aegse  (PlN  >kaasa+aegne !02_A
28971	terminist	termini	termin	02_S	SgEl	et	terminist =termini  (SgEl  >termin !02_S
28973	arvamustega	arvamus	arvamus	11_S	PlKom	et	arvamustega =arvamus  (PlKom  >arvamus !11_S
28976	teenib	teeni	teenima	28_V	IndPrSg3	et	teenib =teeni  (IndPrSg3  >teenima !28_V
28977	missugused	suguse	mis+sugune	10_P	PlN	et	missugused =suguse  (PlN  >mis+sugune !10_P
28979	kain	kain	kain	22_S	SgN	et	kain =kain  (SgN  >kain !22_S
28982	vabastati	vabasta	vabastama	27_V	IndIpfIps	et	vabastati =vabasta  (IndIpfIps  >vabastama !27_V
28984	rektoriks	rektori	rektor	02_S	SgTr	et	rektoriks =rektori  (SgTr  >rektor !02_S
28988	arvab	arva	arvama	29_V	IndPrSg3	et	arvab =arva  (IndPrSg3  >arvama !29_V
28720	ah	ah	ah	41_I	ID	et	ah =ah  (ID  >ah !41_I
28730	pannakse	pann	panema	36_V	IndPrIps	et	pannakse =pann  (IndPrIps  >panema !36_V
28746	suhtluse	suhtluse	suhtlus	11~09_S	SgG	et	suhtluse =suhtluse  (SgG  >suhtlus !11~09_S
28749	kommunikatiivseid	kommunikatiivse	kommunikatiivne	02_A	PlP	et	kommunikatiivseid =kommunikatiivse  (PlP  >kommunikatiivne !02_A
28756	maitset	maitse	maitse	06_S	SgP	et	maitset =maitse  (SgP  >maitse !06_S
28764	eelistatakse	eelista	eelistama	27_V	IndPrIps	et	eelistatakse =eelista  (IndPrIps  >eelistama !27_V
28768	arengut	arengu	areng	02_S	SgP	et	arengut =arengu  (SgP  >areng !02_S
28770	liiv	liiv	liiv	22_S	SgN	et	liiv =liiv  (SgN  >liiv !22_S
28786	hümn	hümn	hümn	22_S	SgN	et	hümn =hümn  (SgN  >hümn !22_S
28792	üpris	üpris	üpris	41_D	ID	et	üpris =üpris  (ID  >üpris !41_D
28795	uues	uue	uus	14_A	SgIn	et	uues =uue  (SgIn  >uus !14_A
28806	paljudel	palju	palju	16_P	PlAd	et	paljudel =palju  (PlAd  >palju !16_P
28815	muudküsimus	küsimus	muud+küsimus	11_S	SgN	et	muudküsimus =küsimus  (SgN  >muud+küsimus !11_S
28816	täpset	täpse	täpne	02_A	SgP	et	täpset =täpse  (SgP  >täpne !02_A
28819	korraldada	korralda	korraldama	27_V	Inf	et	korraldada =korralda  (Inf  >korraldama !27_V
28827	põhjustas	põhjusta	põhjustama	27_V	IndIpfSg3	et	põhjustas =põhjusta  (IndIpfSg3  >põhjustama !27_V
28829	küsisin	küsi	küsima	27_V	IndIpfSg1	et	küsisin =küsi  (IndIpfSg1  >küsima !27_V
28842	rikastada	rikasta	rikastama	27_V	Inf	et	rikastada =rikasta  (Inf  >rikastama !27_V
28845	omavahel	omavahel	oma+vahel	41_D	ID	et	omavahel =omavahel  (ID  >oma+vahel !41_D
28847	nõrgal	nõrga	nõrk	22_A	SgAd	et	nõrgal =nõrga  (SgAd  >nõrk !22_A
28854	reedet	reede	reede	01_S	SgP	et	reedet =reede  (SgP  >reede !01_S
28860	põhjalikud	põhjaliku	põhjalik	25_A	PlN	et	põhjalikud =põhjaliku  (PlN  >põhjalik !25_A
28862	näidatakse	näida	näitama	29_V	IndPrIps	et	näidatakse =näida  (IndPrIps  >näitama !29_V
28863	järgmises	järgmise	järgmine	12?10_A	SgIn	et	järgmises =järgmise  (SgIn  >järgmine !12?10_A
28865	astrid	astri	aster	02_S	PlN	et	astrid =astri  (PlN  >aster !02_S
28870	teater	teater	teater	02_S	SgN	et	teater =teater  (SgN  >teater !02_S
28876	teatrielust	elu	teatri+elu	17_S	SgEl	et	teatrielust =elu  (SgEl  >teatri+elu !17_S
28887	muuseumidest	muuseumi	muuseum	19_S	PlEl	et	muuseumidest =muuseumi  (PlEl  >muuseum !19_S
28890	keelestruktuuridega	struktuuri	keele+struktuur	22_S	PlKom	et	keelestruktuuridega =struktuuri  (PlKom  >keele+struktuur !22_S
28894	riigisümboleid	sümbole	riigi+sümbol	02_S	PlP	et	riigisümboleid =sümbole  (PlP  >riigi+sümbol !02_S
28898	sõnadeautori	autori	sõnade+autor	02_S	SgG	et	sõnadeautori =autori  (SgG  >sõnade+autor !02_S
28901	sõnadeautor	autor	sõnade+autor	02_S	SgN	et	sõnadeautor =autor  (SgN  >sõnade+autor !02_S
28903	baasteadmised	teadmise	baas+teadmine	12?10_S	PlN	et	baasteadmised =teadmise  (PlN  >baas+teadmine !12?10_S
28911	hümnijärgmises	järgmise	hümni+järgmine	12?10_A	SgIn	et	hümnijärgmises =järgmise  (SgIn  >hümni+järgmine !12?10_A
28912	muistsete	muistse	muistne	02_A	PlG	et	muistsete =muistse  (PlG  >muistne !02_A
28919	19sajandi	sajandi	sajand	02_S	SgG	et	sajandi =sajandi  (SgG  >sajand !02_S
28922	kultuuriprogrammis	programmi	kultuuri+programm	22_S	SgIn	et	kultuuriprogrammis =programmi  (SgIn  >kultuuri+programm !22_S
28926	filme	filme	film	22_S	PlP	et	filme =filme  (PlP  >film !22_S
28929	järgmised13	järgmise	järgmine	12?10_A	PlN	et	järgmised =järgmise  (PlN  >järgmine !12?10_A
28946	pidustusi	pidustusi	pidustus	11_S	PlP	et	pidustusi =pidustusi  (PlP  >pidustus !11_S
28949	6klassis	klassi	klass	22_S	SgIn	et	klassis =klassi  (SgIn  >klass !22_S
28951	õppeaeg	aeg	õppe+aeg	22_S	SgN	et	õppeaeg =aeg  (SgN  >õppe+aeg !22_S
28959	keeleõppimiseks	õppimise	keele+õppimine	12_S	SgTr	et	keeleõppimiseks =õppimise  (SgTr  >keele+õppimine !12_S
28960	kultuuriõppimine	õppimine	kultuuri+õppimine	12_S	SgN	et	kultuuriõppimine =õppimine  (SgN  >kultuuri+õppimine !12_S
28980	teenida	teeni	teenima	28_V	Inf	et	teenida =teeni  (Inf  >teenima !28_V
28981	haridus-	haridus	haridus	11_S	SgN	et	haridus- =haridus  (SgN  >haridus !11_S
28985	pooldab	poolda	pooldama	27_V	IndPrSg3	et	pooldab =poolda  (IndPrSg3  >pooldama !27_V
28998	kirjaviisis	viisi	kirja+viis	22_S	SgIn	et	kirjaviisis =viisi  (SgIn  >kirja+viis !22_S
29002	vahetada	vaheta	vahetama	27_V	Inf	et	vahetada =vaheta  (Inf  >vahetama !27_V
29005	venemaalt	maa	vene+maa	26_S	SgAbl	et	venemaalt =maa  (SgAbl  >vene+maa !26_S
29006	kohtukorraldust	korraldus	kohtu+korraldus	11_S	SgP	et	kohtukorraldust =korraldus  (SgP  >kohtu+korraldus !11_S
29013	toodangut	toodangu	toodang	02_S	SgP	et	toodangut =toodangu  (SgP  >toodang !02_S
29025	avati	ava	avama	27_V	IndIpfIps	et	avati =ava  (IndIpfIps  >avama !27_V
29029	riikidest	riiki	riik	22_S	PlEl	et	riikidest =riiki  (PlEl  >riik !22_S
28735	luulet	luule	luule	06_S	SgP	et	luulet =luule  (SgP  >luule !06_S
28736	iseloomulikke	loomulikke	ise+loomulik	25_A	PlP	et	iseloomulikke =loomulikke  (PlP  >ise+loomulik !25_A
28737	suhtlemisnorme	norme	suhtlemis+norm	22_S	PlP	et	suhtlemisnorme =norme  (PlP  >suhtlemis+norm !22_S
28743	allika	allika	allikas	02_S	SgG	et	allika =allika  (SgG  >allikas !02_S
28755	esteetilist	esteetilis	esteetiline	12_A	SgP	et	esteetilist =esteetilis  (SgP  >esteetiline !12_A
28757	võimeid	võime	võime	06_S	PlP	et	võimeid =võime  (PlP  >võime !06_S
28762	kirjandusteoreetilisi	teoreetilisi	kirjandus+teoreetiline	12_A	PlP	et	kirjandusteoreetilisi =teoreetilisi  (PlP  >kirjandus+teoreetiline !12_A
28766	meetodeid	meetode	meetod	02_S	PlP	et	meetodeid =meetode  (PlP  >meetod !02_S
28771	suits	suits	suits	22_S	SgN	et	suits =suits  (SgN  >suits !22_S
28772	kross	kross	kross	22_S	SgN	et	kross =kross  (SgN  >kross !22_S
28773	andrus	andru	andur	02_S	SgIn	et	andrus =andru  (SgIn  >andur !02_S
28777	koolikirjandus	kirjandus	kooli+kirjandus	11_S	SgN	et	koolikirjandus =kirjandus  (SgN  >kooli+kirjandus !11_S
28784	piirdubki	piirdu	piirduma	27_V	IndPrSg3^	et	piirdubki =piirdu  (IndPrSg3^  >piirduma !27_V
28785	valib	vali	valima	27_V	IndPrSg3	et	valib =vali  (IndPrSg3  >valima !27_V
28791	kirjandusega	kirjanduse	kirjandus	11_S	SgKom	et	kirjandusega =kirjanduse  (SgKom  >kirjandus !11_S
28794	muutub	muutu	muutuma	27_V	IndPrSg3	et	muutub =muutu  (IndPrSg3  >muutuma !27_V
28796	korraldasin	korralda	korraldama	27_V	IndIpfSg1	et	korraldasin =korralda  (IndIpfSg1  >korraldama !27_V
28800	küsimutest	mute	küsi+mutt	22_S	PlEl	et	küsimutest =mute  (PlEl  >küsi+mutt !22_S
28817	absurdseid	absurdse	absurdne	02_A	PlP	et	absurdseid =absurdse  (PlP  >absurdne !02_A
28820	kummalist	kummalis	kummaline	12_A	SgP	et	kummalist =kummalis  (SgP  >kummaline !12_A
28821	veebruar	veebruar	veebruar	19_S	SgN	et	veebruar =veebruar  (SgN  >veebruar !19_S
28828	vastuse	vastuse	vastus	09_S	SgG	et	vastuse =vastuse  (SgG  >vastus !09_S
28830	raskeid	raske	raske	01_A	PlP	et	raskeid =raske  (PlP  >raske !01_A
28832	mitmesuguseid	suguse	mitme+sugune	10_A	PlP	et	mitmesuguseid =suguse  (PlP  >mitme+sugune !10_A
28833	tulemuse	tulemuse	tulemus	11_S	SgG	et	tulemuse =tulemuse  (SgG  >tulemus !11_S
28834	muutuda	muutu	muutuma	27_V	Inf	et	muutuda =muutu  (Inf  >muutuma !27_V
28837	kujutleda	kujutle	kujutlema	27_V	Inf	et	kujutleda =kujutle  (Inf  >kujutlema !27_V
28841	kommenteerida	kommenteeri	kommenteerima	28_V	Inf	et	kommenteerida =kommenteeri  (Inf  >kommenteerima !28_V
28843	pühendada	pühenda	pühendama	27_V	Inf	et	pühendada =pühenda  (Inf  >pühendama !27_V
28857	kadripäevperedes	pere	kadri+päev+pere	16_S	PlIn	et	kadripäevperedes =pere  (PlIn  >kadri+päev+pere !16_S
28867	kirjutatakse	kirjuta	kirjutama	27_V	IndPrIps	et	kirjutatakse =kirjuta  (IndPrIps  >kirjutama !27_V
28871	vanalinnastuudiost	stuudio	vana+linna+stuudio	01_S	SgEl	et	vanalinnastuudiost =stuudio  (SgEl  >vana+linna+stuudio !01_S
28874	tulemused	tulemuse	tulemus	11_S	PlN	et	tulemused =tulemuse  (PlN  >tulemus !11_S
28877	veelkord	kord	veel+kord	22_S	SgN	et	veelkord =kord  (SgN  >veel+kord !22_S
28879	kultuuriõppimiseksviimane	viimane	kultuuri+õppimis+eks+viimane	10_A	SgN	et	kultuuriõppimiseksviimane =viimane  (SgN  >kultuuri+õppimis+eks+viimane !10_A
28880	rahakupüüridel	kupüüri	raha+kupüür	22_S	PlAd	et	rahakupüüridel =kupüüri  (PlAd  >raha+kupüür !22_S
28882	originaalne	originaalne	originaalne	02_A	SgN	et	originaalne =originaalne  (SgN  >originaalne !02_A
28888	sealolev	olev	seal+olev	02_A	SgN	et	sealolev =olev  (SgN  >seal+olev !02_A
28895	rahvasümbolid	sümboli	rahva+sümbol	02_S	PlN	et	rahvasümbolid =sümboli  (PlN  >rahva+sümbol !02_S
28904	30st	st	st	41_I	ID	et	st =st  (ID  >st !41_I
28908	mainida	maini	mainima	28_V	Inf	et	mainida =maini  (Inf  >mainima !28_V
28915	ühtele	ühte	ühe	06_S	SgAll	et	ühtele =ühte  (SgAll  >ühe !06_S
28916	seitsmendal	seitsmenda	seitsmes	02_O	SgAd	et	seitsmendal =seitsmenda  (SgAd  >seitsmes !02_O
28923	headjärgmises	järgmise	head+järgmine	12?10_A	SgIn	et	headjärgmises =järgmise  (SgIn  >head+järgmine !12?10_A
28930	lisaandmed	andme	lisa+anne	05_S	PlN	et	lisaandmed =andme  (PlN  >lisa+anne !05_S
28932	õppeastmel	astme	õppe+aste	05_S	SgAd	et	õppeastmel =astme  (SgAd  >õppe+aste !05_S
28940	tantsust	tantsu	tants	22_S	SgEl	et	tantsust =tantsu  (SgEl  >tants !22_S
28943	silm	silm	silm	22_S	SgN	et	silm =silm  (SgN  >silm !22_S
28952	põhikoolieksam	eksam	põhi+kooli+eksam	02_S	SgN	et	põhikoolieksam =eksam  (SgN  >põhi+kooli+eksam !02_S
28962	kultuuriteadmine	teadmine	kultuuri+teadmine	12?10_S	SgN	et	kultuuriteadmine =teadmine  (SgN  >kultuuri+teadmine !12?10_S
28964	keeleõppimine	õppimine	keele+õppimine	12_S	SgN	et	keeleõppimine =õppimine  (SgN  >keele+õppimine !12_S
28974	tõestasin	tõesta	tõestama	27_V	IndIpfSg1	et	tõestasin =tõesta  (IndIpfSg1  >tõestama !27_V
28798	pingutada	pinguta	pingutama	27_V	Inf	et	pingutada =pinguta  (Inf  >pingutama !27_V
28802	riigisümbolid	sümboli	riigi+sümbol	02_S	PlN	et	riigisümbolid =sümboli  (PlN  >riigi+sümbol !02_S
28808	õiged	õige	õige	01_A	PlN	et	õiged =õige  (PlN  >õige !01_A
28809	vastused	vastuse	vastus	09_S	PlN	et	vastused =vastuse  (PlN  >vastus !09_S
28810	õigeid	õige	õige	01_A	PlP	et	õigeid =õige  (PlP  >õige !01_A
28823	rahvuseepose	eepose	rahvus+eepos	11~09_S	SgG	et	rahvuseepose =eepose  (SgG  >rahvus+eepos !11~09_S
28824	kalev	kalev	kalev	02_S	SgN	et	kalev =kalev  (SgN  >kalev !02_S
28825	eepost	eepos	eepos	11~09_S	SgP	et	eepost =eepos  (SgP  >eepos !11~09_S
28826	5klassis	klassi	klass	22_S	SgIn	et	klassis =klassi  (SgIn  >klass !22_S
28831	pidas	pida	pidama	28_V	IndIpfSg3	et	pidas =pida  (IndIpfSg3  >pidama !28_V
28838	rahvuslaulud	laulu	rahvus+laul	22_S	PlN	et	rahvuslaulud =laulu  (PlN  >rahvus+laul !22_S
28840	rahvamõistatusi	mõistatusi	rahva+mõistatus	11_S	PlP	et	rahvamõistatusi =mõistatusi  (PlP  >rahva+mõistatus !11_S
28848	jumalate	jumala	jumal	02_S	PlG	et	jumalate =jumala  (PlG  >jumal !02_S
28850	naljakad	naljaka	naljakas	02_A	PlN	et	naljakad =naljaka  (PlN  >naljakas !02_A
28851	palusin	palu	paluma	27_V	IndIpfSg1	et	palusin =palu  (IndIpfSg1  >paluma !27_V
28855	vastlapäevajärgnev	järgnev	vastla+päeva+järgnev	02_A	SgN	et	vastlapäevajärgnev =järgnev  (SgN  >vastla+päeva+järgnev !02_A
28859	pühadest	püha	püha	17_SA	PlEl	et	pühadest =püha  (PlEl  >püha !17_SA
28866	nimetas	nimeta	nimetama	27_V	IndIpfSg3	et	nimetas =nimeta  (IndIpfSg3  >nimetama !27_V
28875	viletsad	viletsa	vilets	02_A	PlN	et	viletsad =viletsa  (PlN  >vilets !02_A
28883	küsides	küsi	küsima	27_V	Ger	et	küsides =küsi  (Ger  >küsima !27_V
28885	vanasõnad	sõna	vana+sõna	17_S	PlN	et	vanasõnad =sõna  (PlN  >vana+sõna !17_S
28892	hoopiski	hoopis	hoopis	41_D	ID^	et	hoopiski =hoopis  (ID^  >hoopis !41_D
28893	lisasin	lisa	lisama	27_V	IndIpfSg1	et	lisasin =lisa  (IndIpfSg1  >lisama !27_V
28897	7klassiga	klassi	klass	22_S	SgKom	et	klassiga =klassi  (SgKom  >klass !22_S
28900	võrra	võrra	võrra	41_DK	ID	et	võrra =võrra  (ID  >võrra !41_DK
28909	piir	piir	piir	22_S	SgN	et	piir =piir  (SgN  >piir !22_S
28914	hakkama18	hakka	hakkama	29_V	Sup	et	hakkama =hakka  (Sup  >hakkama !29_V
28920	kaasaegseid	aegse	kaas+aegne	02_A	PlP	et	kaasaegseid =aegse  (PlP  >kaas+aegne !02_A
28924	teatriteadmised	teadmise	teatri+teadmine	12?10_S	PlN	et	teatriteadmised =teadmise  (PlN  >teatri+teadmine !12?10_S
28925	filmidest	filmi	film	22_S	PlEl	et	filmidest =filmi  (PlEl  >film !22_S
28935	nõrgad	nõrga	nõrk	22_A	PlN	et	nõrgad =nõrga  (PlN  >nõrk !22_A
28937	aabits	aabits	aabits	02_S	SgN	et	aabits =aabits  (SgN  >aabits !02_S
28942	öeldakse	öel	ütlema	30_V	IndPrIps	et	öeldakse =öel  (IndPrIps  >ütlema !30_V
28950	aegaõpetajad	õpetaja	aega+õpetaja	01_S	PlN	et	aegaõpetajad =õpetaja  (PlN  >aega+õpetaja !01_S
28953	grammatikat	grammatika	grammatika	01_S	SgP	et	grammatikat =grammatika  (SgP  >grammatika !01_S
28955	parandama	paranda	parandama	27_V	Sup	et	parandama =paranda  (Sup  >parandama !27_V
28967	mingit	mingi	mingi	01_P	SgP	et	mingit =mingi  (SgP  >mingi !01_P
28970	situatsioonis	situatsiooni	situatsioon	22_S	SgIn	et	situatsioonis =situatsiooni  (SgIn  >situatsioon !22_S
28972	termin	termin	termin	02_S	SgN	et	termin =termin  (SgN  >termin !02_S
28991	talupoegadel	poega	talu+poeg	22_S	PlAd	et	talupoegadel =poega  (PlAd  >talu+poeg !22_S
28993	olda	ol	olema	36_V	IndPrIps_	et	olda =ol  (IndPrIps_  >olema !36_V
28996	lektor	lektor	lektor	02_S	SgN	et	lektor =lektor  (SgN  >lektor !02_S
28997	trükiseid	trükise	trükis	09_S	PlP	et	trükiseid =trükise  (PlP  >trükis !09_S
29000	lepinguid	lepingu	leping	02_S	PlP	et	lepinguid =lepingu  (PlP  >leping !02_S
29003	talupoeg	poeg	talu+poeg	22_S	SgN	et	talupoeg =poeg  (SgN  >talu+poeg !22_S
29010	kasvama	kasva	kasvama	28_V	Sup	et	kasvama =kasva  (Sup  >kasvama !28_V
29015	maata	maa	maa	26_S	SgAb	et	maata =maa  (SgAb  >maa !26_S
29018	maksma	maks	maksma	32_V	Sup	et	maksma =maks  (Sup  >maksma !32_V
29020	tasandil	tasandi	tasand	02_S	SgAd	et	tasandil =tasandi  (SgAd  >tasand !02_S
29027	teadlased	teadlase	teadlane	12?10_S	PlN	et	teadlased =teadlase  (PlN  >teadlane !12?10_S
29028	tartust	tartu	tartu	01_H	SgEl	et	tartust =tartu  (SgEl  >tartu !01_H
29034	toll	toll	toll	22_S	SgN	et	toll =toll  (SgN  >toll !22_S
29037	paljudes	palju	palju	16_P	PlIn	et	paljudes =palju  (PlIn  >palju !16_P
29041	seadustada	seadusta	seadustama	27_V	Inf	et	seadustada =seadusta  (Inf  >seadustama !27_V
29043	vee	vee	vesi	15_S	SgG	et	vee =vee  (SgG  >vesi !15_S
29044	töömehe	mehe	töö+mees	13_S	SgG	et	töömehe =mehe  (SgG  >töö+mees !13_S
28886	vesteldes	vestel	vestlema	30_V	Ger	et	vesteldes =vestel  (Ger  >vestlema !30_V
28889	tegeldakse	tegel	tegelema	31_V	IndPrIps	et	tegeldakse =tegel  (IndPrIps  >tegelema !31_V
28896	võrreldes	võrrel	võrdlema	30_V	Ger	et	võrreldes =võrrel  (Ger  >võrdlema !30_V
28899	suurendas	suurenda	suurendama	27_V	IndIpfSg3	et	suurendas =suurenda  (IndIpfSg3  >suurendama !27_V
28902	rahvuspuudaga	puuda	rahvus+puud	22_S	SgKom	et	rahvuspuudaga =puuda  (SgKom  >rahvus+puud !22_S
28905	11klassis	klassi	klass	22_S	SgIn	et	klassis =klassi  (SgIn  >klass !22_S
28913	vanaisajärgmise	järgmise	vana+isa+järgmine	12?10_A	SgG	et	vanaisajärgmise =järgmise  (SgG  >vana+isa+järgmine !12?10_A
28917	huvitas	huvita	huvitama	27_V	IndIpfSg3	et	huvitas =huvita  (IndIpfSg3  >huvitama !27_V
28918	kolmandal	kolmanda	kolmas	02_O	SgAd	et	kolmandal =kolmanda  (SgAd  >kolmas !02_O
28931	keskmisest	keskmise	keskmine	12?10_A	SgEl	et	keskmisest =keskmise  (SgEl  >keskmine !12?10_A
28933	st	st	st	41_I	ID	et	st =st  (ID  >st !41_I
28934	keeleõppimisele	õppimise	keele+õppimine	12_S	SgAll	et	keeleõppimisele =õppimise  (SgAll  >keele+õppimine !12_S
28936	kultuuriteadmises	teadmise	kultuuri+teadmine	12?10_S	SgIn	et	kultuuriteadmises =teadmise  (SgIn  >kultuuri+teadmine !12?10_S
28938	kaasaaegne	aegne	kaasa+aegne	02_A	SgN	et	kaasaaegne =aegne  (SgN  >kaasa+aegne !02_A
28939	vanasõnade	sõna	vana+sõna	17_S	PlG	et	vanasõnade =sõna  (PlG  >vana+sõna !17_S
28941	testide	testi	test	22_S	PlG	et	testide =testi  (PlG  >test !22_S
28945	mitmesugusid	sugu	mitme+sugu	18_S	PlP	et	mitmesugusid =sugu  (PlP  >mitme+sugu !18_S
28947	koolilõpetajad	lõpetaja	kooli+lõpetaja	01_S	PlN	et	koolilõpetajad =lõpetaja  (PlN  >kooli+lõpetaja !01_S
28948	kultuuriõppimist	õppimis	kultuuri+õppimine	12_S	SgP	et	kultuuriõppimist =õppimis  (SgP  >kultuuri+õppimine !12_S
28956	kursusel	kursuse	kursus	11~09_S	SgAd	et	kursusel =kursuse  (SgAd  >kursus !11~09_S
28963	tähtsal	tähtsa	tähtis	02_A	SgAd	et	tähtsal =tähtsa  (SgAd  >tähtis !02_A
28965	ebapiisavad	piisava	eba+piisav	02_A	PlN	et	ebapiisavad =piisava  (PlN  >eba+piisav !02_A
28969	kasutada	kasuta	kasutama	27_V	Inf	et	kasutada =kasuta  (Inf  >kasutama !27_V
28983	tähendas	tähenda	tähendama	27_V	IndIpfSg3	et	tähendas =tähenda  (IndIpfSg3  >tähendama !27_V
28987	ideid	ide	idee	26_S	PlP	et	ideid =ide  (PlP  >idee !26_S
28994	mõisale	mõisa	mõis	02_S	SgAll	et	mõisale =mõisa  (SgAll  >mõis !02_S
29011	vabrikud	vabriku	vabrik	02_S	PlN	et	vabrikud =vabriku  (PlN  >vabrik !02_S
29014	teoorjus	orjus	teo+orjus	11~09_S	SgN	et	teoorjus =orjus  (SgN  >teo+orjus !11~09_S
29016	taluomanikuga	omaniku	talu+omanik	25_S	SgKom	et	taluomanikuga =omaniku  (SgKom  >talu+omanik !25_S
29021	rasketele	raske	raske	01_A	PlAll	et	rasketele =raske  (PlAll  >raske !01_A
29024	aegadele	aega	aeg	22_S	PlAll	et	aegadele =aega  (PlAll  >aeg !22_S
29030	keskus	keskus	keskus	11~09_S	SgN	et	keskus =keskus  (SgN  >keskus !11~09_S
29031	astronoom	astronoom	astronoom	22_S	SgN	et	astronoom =astronoom  (SgN  >astronoom !22_S
29033	valgustusideaalidest	ideaali	valgustus+ideaal	22_S	PlEl	et	valgustusideaalidest =ideaali  (PlEl  >valgustus+ideaal !22_S
29035	arengule	arengu	areng	02_S	SgAll	et	arengule =arengu  (SgAll  >areng !02_S
29040	põhjustel	põhjus	põhjus	11~09_S	PlAd	et	põhjustel =põhjus  (PlAd  >põhjus !11~09_S
29049	puudun	puudu	puuduma	27_V	IndPrSg1	et	puudun =puudu  (IndPrSg1  >puuduma !27_V
29055	jalutab	jaluta	jalutama	27_V	IndPrSg3	et	jalutab =jaluta  (IndPrSg3  >jalutama !27_V
29059	esimeselt	esimese	esimene	12_OP	SgAbl	et	esimeselt =esimese  (SgAbl  >esimene !12_OP
29067	auhind	hind	au+hind	22_S	SgN	et	auhind =hind  (SgN  >au+hind !22_S
29075	venekeelset	keelse	vene+keelne	02_A	SgP	et	venekeelset =keelse  (SgP  >vene+keelne !02_A
29079	aastalt	aasta	aasta	01_S	SgAbl	et	aastalt =aasta  (SgAbl  >aasta !01_S
29082	ravib	ravi	ravima	27_V	IndPrSg3	et	ravib =ravi  (IndPrSg3  >ravima !27_V
29084	liitrit	liitri	liiter	02_S	SgP	et	liitrit =liitri  (SgP  >liiter !02_S
29086	rahustab	rahusta	rahustama	27_V	IndPrSg3	et	rahustab =rahusta  (IndPrSg3  >rahustama !27_V
29091	ametlik	ametlik	ametlik	25_A	SgN	et	ametlik =ametlik  (SgN  >ametlik !25_A
29096	trükiste	trükis	trükis	09_S	PlG	et	trükiste =trükis  (PlG  >trükis !09_S
29106	ootan	oota	ootama	29_V	IndPrSg1	et	ootan =oota  (IndPrSg1  >ootama !29_V
29107	poolset	poolse	poolne	02_A	SgP	et	poolset =poolse  (SgP  >poolne !02_A
29114	niisugused	suguse	nii+sugune	10_P	PlN	et	niisugused =suguse  (PlN  >nii+sugune !10_P
29124	käin	käi	käima	38_V	IndPrSg1	et	käin =käi  (IndPrSg1  >käima !38_V
29126	joonistada	joonista	joonistama	27_V	Inf	et	joonistada =joonista  (Inf  >joonistama !27_V
29128	hing	hing	hing	22_S	SgN	et	hing =hing  (SgN  >hing !22_S
29131	psüühikaga	psüühika	psüühika	01_S	SgKom	et	psüühikaga =psüühika  (SgKom  >psüühika !01_S
28975	hariduse	hariduse	haridus	11_S	SgG	et	hariduse =hariduse  (SgG  >haridus !11_S
28978	omandada	omanda	omandama	27_V	Inf	et	omandada =omanda  (Inf  >omandama !27_V
28986	valgustuslikke	valgustuslikke	valgustuslik	25_A	PlP	et	valgustuslikke =valgustuslikke  (PlP  >valgustuslik !25_A
28989	pärisorjus	orjus	päris+orjus	11~09_S	SgN	et	pärisorjus =orjus  (SgN  >päris+orjus !11~09_S
28992	tingimusel	tingimuse	tingimus	11_S	SgAd	et	tingimusel =tingimuse  (SgAd  >tingimus !11_S
28999	vabad	vaba	vaba	17_A	PlN	et	vabad =vaba  (PlN  >vaba !17_A
29001	müüa	müü	müüma	38_V	Inf	et	müüa =müü  (Inf  >müüma !38_V
29007	ihunuhtlus	nuhtlus	ihu+nuhtlus	11~09_S	SgN	et	ihunuhtlus =nuhtlus  (SgN  >ihu+nuhtlus !11~09_S
29009	pärisorjuse	orjuse	päris+orjus	11~09_S	SgG	et	pärisorjuse =orjuse  (SgG  >päris+orjus !11~09_S
29017	tööga	töö	töö	26_S	SgKom	et	tööga =töö  (SgKom  >töö !26_S
29019	omavalitsuse	valitsuse	oma+valitsus	11_S	SgG	et	omavalitsuse =valitsuse  (SgG  >oma+valitsus !11_S
29022	elutingimuste	tingimus	elu+tingimus	11_S	PlG	et	elutingimuste =tingimus  (PlG  >elu+tingimus !11_S
29023	vastutas	vastuta	vastutama	27_V	IndIpfSg3	et	vastutas =vastuta  (IndIpfSg3  >vastutama !27_V
29036	uuringuid	uuringu	uuring	02_S	PlP	et	uuringuid =uuringu  (PlP  >uuring !02_S
29039	arendama	arenda	arendama	27_V	Sup	et	arendama =arenda  (Sup  >arendama !27_V
29042	situatsioonid	situatsiooni	situatsioon	22_S	PlN	et	situatsioonid =situatsiooni  (PlN  >situatsioon !22_S
29051	mõnikord	mõnikord	mõni+kord	41_D	ID	et	mõnikord =mõnikord  (ID  >mõni+kord !41_D
29057	ülalpool	ülalpool	ülal+pool	41_DK	ID	et	ülalpool =ülalpool  (ID  >ülal+pool !41_DK
29062	fotoga	foto	foto	16_S	SgKom	et	fotoga =foto  (SgKom  >foto !16_S
29064	leheküljel	külje	lehe+külg	22_S	SgAd	et	leheküljel =külje  (SgAd  >lehe+külg !22_S
29069	kolmekümnendalt	alt	kolme+kümnend+alt	22_S	SgN	et	kolmekümnendalt =alt  (SgN  >kolme+kümnend+alt !22_S
29074	eestikeelset	keelse	eesti+keelne	02_A	SgP	et	eestikeelset =keelse  (SgP  >eesti+keelne !02_A
29077	artiklit	artikli	artikkel	02_S	SgP	et	artiklit =artikli  (SgP  >artikkel !02_S
29080	number	number	number	02_S	SgN	et	number =number  (SgN  >number !02_S
29087	närve	närve	närv	22_S	PlP	et	närve =närve  (PlP  >närv !22_S
29104	tulemustega	tulemus	tulemus	11_S	PlKom	et	tulemustega =tulemus  (PlKom  >tulemus !11_S
29110	makilindilt	lindi	maki+lint	22_S	SgAbl	et	makilindilt =lindi  (SgAbl  >maki+lint !22_S
29118	jalutan	jaluta	jalutama	27_V	IndPrSg1	et	jalutan =jaluta  (IndPrSg1  >jalutama !27_V
29119	rokkmuusikat	muusika	rokk+muusika	01_S	SgP	et	rokkmuusikat =muusika  (SgP  >rokk+muusika !01_S
29123	kunstistuudios	stuudio	kunsti+stuudio	01_S	SgIn	et	kunstistuudios =stuudio  (SgIn  >kunsti+stuudio !01_S
29130	inimesest	inimese	inimene	12_S	SgEl	et	inimesest =inimese  (SgEl  >inimene !12_S
29135	kannatlik	kannatlik	kannatlik	25_A	SgN	et	kannatlik =kannatlik  (SgN  >kannatlik !25_A
29137	sis	si	si	26_S	SgIn	et	sis =si  (SgIn  >si !26_S
29142	andeid	ande	anne	06_S	PlP	et	andeid =ande  (PlP  >anne !06_S
29143	töötama	tööta	töötama	27_V	Sup	et	töötama =tööta  (Sup  >töötama !27_V
29163	jäätist	jäätis	jäätis	11~09_S	SgP	et	jäätist =jäätis  (SgP  >jäätis !11~09_S
29180	tere	tere	tere	41_I	ID	et	tere =tere  (ID  >tere !41_I
29190	seletuskiri	kiri	seletus+kiri	24_S	SgN	et	seletuskiri =kiri  (SgN  >seletus+kiri !24_S
29191	momendil	momendi	moment	22_S	SgAd	et	momendil =momendi  (SgAd  >moment !22_S
29193	autot	auto	auto	16_S	SgP	et	autot =auto  (SgP  >auto !16_S
29195	autost	auto	auto	16_S	SgEl	et	autost =auto  (SgEl  >auto !16_S
29207	tervislik	tervislik	tervislik	25_A	SgN	et	tervislik =tervislik  (SgN  >tervislik !25_A
29211	valmistuda	valmistu	valmistuma	27_V	Inf	et	valmistuda =valmistu  (Inf  >valmistuma !27_V
29214	välimus	välimus	välimus	11_S	SgN	et	välimus =välimus  (SgN  >välimus !11_S
29215	annavad	anna	andma	34_V	IndPrPl3	et	annavad =anna  (IndPrPl3  >andma !34_V
29231	elektriseadmetega	seadme	elektri+seade	05_S	PlKom	et	elektriseadmetega =seadme  (PlKom  >elektri+seade !05_S
29238	kloostrist	kloostri	klooster	02_S	SgEl	et	kloostrist =kloostri  (SgEl  >klooster !02_S
29243	kroonikas	kroonika	kroonika	01_S	SgIn	et	kroonikas =kroonika  (SgIn  >kroonika !01_S
29245	kohanimesid	nime	koha+nimi	20_S	PlP	et	kohanimesid =nime  (PlP  >koha+nimi !20_S
29246	väljendeid	väljende	väljend	02_S	PlP	et	väljendeid =väljende  (PlP  >väljend !02_S
29251	jumalad	jumala	jumal	02_S	PlN	et	jumalad =jumala  (PlN  >jumal !02_S
29262	arenema	arene	arenema	27_V	Sup	et	arenema =arene  (Sup  >arenema !27_V
29263	tekst	tekst	tekst	22_S	SgN	et	tekst =tekst  (SgN  >tekst !22_S
29268	vaimulikud	vaimuliku	vaimulik	25_AS	PlN	et	vaimulikud =vaimuliku  (PlN  >vaimulik !25_AS
29274	viikingiaeg	aeg	viikingi+aeg	22_S	SgN	et	viikingiaeg =aeg  (SgN  >viikingi+aeg !22_S
28990	kaotada	kaota	kaotama	27_V	Inf	et	kaotada =kaota  (Inf  >kaotama !27_V
28995	kohtule	kohtu	kohus	05_S	SgAll	et	kohtule =kohtu  (SgAll  >kohus !05_S
29004	linnadesse	linna	linn	22_S	PlIll	et	linnadesse =linna  (PlIll  >linn !22_S
29008	kaotati	kaota	kaotama	27_V	IndIpfIps	et	kaotati =kaota  (IndIpfIps  >kaotama !27_V
29012	päriseksostmise	ostmise	päri+seks+ostmine	12?10_S	SgG	et	päriseksostmise =ostmise  (SgG  >päri+seks+ostmine !12?10_S
29026	professorid	professori	professor	02_S	PlN	et	professorid =professori  (PlN  >professor !02_S
29045	matus	matus	matus	09_S	SgN	et	matus =matus  (SgN  >matus !09_S
29047	pulmad	pulma	pulm	22_S	PlN	et	pulmad =pulma  (PlN  >pulm !22_S
29050	tundidel	tundi	tund	22_S	PlAd	et	tundidel =tundi  (PlAd  >tund !22_S
29052	halvasti	halvasti	halvasti	41_D	ID	et	halvasti =halvasti  (ID  >halvasti !41_D
29054	järjekorrad	korra	järje+kord	22_S	PlN	et	järjekorrad =korra  (PlN  >järje+kord !22_S
29063	viiendal	viienda	viies	02_O	SgAd	et	viiendal =viienda  (SgAd  >viies !02_O
29073	kanalit	kanali	kanal	02_S	SgP	et	kanalit =kanali  (SgP  >kanal !02_S
29076	viimastel	viimas	viimane	10_A	PlAd	et	viimastel =viimas  (PlAd  >viimane !10_A
29078	neljandalt	neljanda	neljas	02_O	SgAbl	et	neljandalt =neljanda  (SgAbl  >neljas !02_O
29090	venekeelne	keelne	vene+keelne	02_A	SgN	et	venekeelne =keelne  (SgN  >vene+keelne !02_A
29094	järelepärimine	pärimine	järele+pärimine	12_S	SgN	et	järelepärimine =pärimine  (SgN  >järele+pärimine !12_S
29098	küsida	küsi	küsima	27_V	Inf	et	küsida =küsi  (Inf  >küsima !27_V
29108	aadressil	aadressi	aadress	22_S	SgAd	et	aadressil =aadressi  (SgAd  >aadress !22_S
29112	millist	millis	milline	10_P	SgP	et	millist =millis  (SgP  >milline !10_P
29116	cd-l	cd	cd	xx_Q	SgAd	et	cd-l =cd  (SgAd  >cd !xx_Q
29120	rokklauludel	laulu	rokk+laul	22_S	PlAd	et	rokklauludel =laulu  (PlAd  >rokk+laul !22_S
29132	lahtine	lahtine	lahtine	12~10_A	SgN	et	lahtine =lahtine  (SgN  >lahtine !12~10_A
29144	plaanin	plaani	plaanima	28_V	IndPrSg1	et	plaanin =plaani  (IndPrSg1  >plaanima !28_V
29146	laagri	laagri	laager	02_S	SgG	et	laagri =laagri  (SgG  >laager !02_S
29147	kunstikoolide	kooli	kunsti+kool	22_S	PlG	et	kunstikoolide =kooli  (PlG  >kunsti+kool !22_S
29148	voolida	vooli	voolima	28_V	Inf	et	voolida =vooli  (Inf  >voolima !28_V
29152	kooliajal	aja	kooli+aeg	22_S	SgAd	et	kooliajal =aja  (SgAd  >kooli+aeg !22_S
29156	tutvusin	tutvu	tutvuma	27_V	IndIpfSg1	et	tutvusin =tutvu  (IndIpfSg1  >tutvuma !27_V
29164	väited	väite	väide	06_S	PlN	et	väited =väite  (PlN  >väide !06_S
29166	kaitsma	kaits	kaitsma	32_V	Sup	et	kaitsma =kaits  (Sup  >kaitsma !32_V
29167	korterisse	korteri	korter	02_S	SgIll	et	korterisse =korteri  (SgIll  >korter !02_S
29168	kurjategijatel	tegija	kurja+tegija	01_S	PlAd	et	kurjategijatel =tegija  (PlAd  >kurja+tegija !01_S
29169	soodumus	soodumus	soodumus	11_S	SgN	et	soodumus =soodumus  (SgN  >soodumus !11_S
29178	altkäemaksad	maksa	alt+käe+maks	22_S	PlN	et	altkäemaksad =maksa  (PlN  >alt+käe+maks !22_S
29187	kaebus	kaebus	kaebus	11~09_S	SgN	et	kaebus =kaebus  (SgN  >kaebus !11~09_S
29194	väljutasin	väljuta	väljutama	27_V	IndIpfSg1	et	väljutasin =väljuta  (IndIpfSg1  >väljutama !27_V
29203	tingimustega	tingimus	tingimus	11_S	PlKom	et	tingimustega =tingimus  (PlKom  >tingimus !11_S
29221	kampsun	kampsun	kampsun	02_S	SgN	et	kampsun =kampsun  (SgN  >kampsun !02_S
29225	erineb	erine	erinema	27_V	IndPrSg3	et	erineb =erine  (IndPrSg3  >erinema !27_V
29239	kroonikat	kroonika	kroonika	01_S	SgP	et	kroonikat =kroonika  (SgP  >kroonika !01_S
29241	käsikiri	kiri	käsi+kiri	24_S	SgN	et	käsikiri =kiri  (SgN  >käsi+kiri !24_S
29242	ümberkirjutiste	kirjutis	ümber+kirjutis	11_S	PlG	et	ümberkirjutiste =kirjutis  (PlG  >ümber+kirjutis !11_S
29247	lauseid	lause	lause	06_S	PlP	et	lauseid =lause  (PlP  >lause !06_S
29248	usundi	usundi	usund	02_S	SgG	et	usundi =usundi  (SgG  >usund !02_S
29249	pühad	püha	püha	17_SA	PlN	et	pühad =püha  (PlN  >püha !17_SA
29255	jumala	jumala	jumal	02_S	SgG	et	jumala =jumala  (SgG  >jumal !02_S
29258	kohtade	kohta	koht	22_S	PlG	et	kohtade =kohta  (PlG  >koht !22_S
29264	katekismus	katekismus	katekismus	11~09_S	SgN	et	katekismus =katekismus  (SgN  >katekismus !11~09_S
29265	vaimuliku	vaimuliku	vaimulik	25_AS	SgG	et	vaimuliku =vaimuliku  (SgG  >vaimulik !25_AS
29273	mõisnikule	mõisniku	mõisnik	25_S	SgAll	et	mõisnikule =mõisniku  (SgAll  >mõisnik !25_S
29275	muinasaeg	aeg	muinas+aeg	22_S	SgN	et	muinasaeg =aeg  (SgN  >muinas+aeg !22_S
29277	toodeks	toode	toot	22_S	PlTr	et	toodeks =toode  (PlTr  >toot !22_S
29279	ehted	ehte	ehe	06_S	PlN	et	ehted =ehte  (PlN  >ehe !06_S
29288	org	org	org	22_S	SgN	et	org =org  (SgN  >org !22_S
29293	rajab	raja	rajama	27_V	IndPrSg3	et	rajab =raja  (IndPrSg3  >rajama !27_V
29032	ülikolis	koli	üli+koli	17_S	SgIn	et	ülikolis =koli  (SgIn  >üli+koli !17_S
29038	valdkondades	valdkonda	valdkond	22_S	PlIn	et	valdkondades =valdkonda  (PlIn  >valdkond !22_S
29046	rõõmsate	rõõmsa	rõõmus	02_A	PlG	et	rõõmsate =rõõmsa  (PlG  >rõõmus !02_A
29048	tähtpäevad	päeva	täht+päev	22_S	PlN	et	tähtpäevad =päeva  (PlN  >täht+päev !22_S
29065	mäng	mäng	mäng	22_S	SgN	et	mäng =mäng  (SgN  >mäng !22_S
29066	auhinnad	hinna	au+hind	22_S	PlN	et	auhinnad =hinna  (PlN  >au+hind !22_S
29068	järgmistel	järgmis	järgmine	12?10_A	PlAd	et	järgmistel =järgmis  (PlAd  >järgmine !12?10_A
29070	novembrilt	novembri	november	02_S	SgAbl	et	novembrilt =novembri  (SgAbl  >november !02_S
29071	viienda	viienda	viies	02_O	SgG	et	viienda =viienda  (SgG  >viies !02_O
29083	peamõte	mõte	pea+mõte	06_S	SgN	et	peamõte =mõte  (SgN  >pea+mõte !06_S
29085	piim	piim	piim	22_S	SgN	et	piim =piim  (SgN  >piim !22_S
29088	spetsialistid	spetsialisti	spetsialist	22_S	PlN	et	spetsialistid =spetsialisti  (PlN  >spetsialist !22_S
29089	defektidega	defekti	defekt	22_S	PlKom	et	defektidega =defekti  (PlKom  >defekt !22_S
29093	metsalinn	linn	metsa+linn	22_S	SgN	et	metsalinn =linn  (SgN  >metsa+linn !22_S
29100	külastasime	külasta	külastama	27_V	IndIpfPl1	et	külastasime =külasta  (IndIpfPl1  >külastama !27_V
29101	fotosid	foto	foto	16_S	PlP	et	fotosid =foto  (PlP  >foto !16_S
29103	must-valgeid	valge	must-valge	01_AS	PlP	et	must-valgeid =valge  (PlP  >must-valge !01_AS
29111	cd-lt	cd	cd	xx_Q	SgAbl	et	cd-lt =cd  (SgAbl  >cd !xx_Q
29115	kontserdile	kontserdi	kontsert	22_S	SgAll	et	kontserdile =kontserdi  (SgAll  >kontsert !22_S
29122	tahad	taha	tahtma	34_V	IndPrSg2	et	tahad =taha  (IndPrSg2  >tahtma !34_V
29125	rokk	rokk	rokk	22_S	SgN	et	rokk =rokk  (SgN  >rokk !22_S
29127	lõõgastada	lõõgasta	lõõgastama	27_V	Inf	et	lõõgastada =lõõgasta  (Inf  >lõõgastama !27_V
29129	igast	iga	iga	17_P	SgEl	et	igast =iga  (SgEl  >iga !17_P
29133	huumorimeelne	meelne	huumori+meelne	02_A	SgN	et	huumorimeelne =meelne  (SgN  >huumori+meelne !02_A
29145	kolivaheajal	aja	koli+vahe+aeg	22_S	SgAd	et	kolivaheajal =aja  (SgAd  >koli+vahe+aeg !22_S
29149	tutvuda	tutvu	tutvuma	27_V	Inf	et	tutvuda =tutvu  (Inf  >tutvuma !27_V
29151	hiljemini	hiljemini	hiljemini	41_D	ID	et	hiljemini =hiljemini  (ID  >hiljemini !41_D
29157	puhkan	puhka	puhkama	29_V	IndPrSg1	et	puhkan =puhka  (IndPrSg1  >puhkama !29_V
29161	päevitada	päevita	päevitama	27_V	Inf	et	päevitada =päevita  (Inf  >päevitama !27_V
29165	kuritegude	tegu	kuri+tegu	18_S	PlG	et	kuritegude =tegu  (PlG  >kuri+tegu !18_S
29170	geneetiline	geneetiline	geneetiline	12_A	SgN	et	geneetiline =geneetiline  (SgN  >geneetiline !12_A
29171	ebanormaalne	normaalne	eba+normaalne	02_A	SgN	et	ebanormaalne =normaalne  (SgN  >eba+normaalne !02_A
29172	kuritegelikule	tegeliku	kuri+tegelik	25_A	SgAll	et	kuritegelikule =tegeliku  (SgAll  >kuri+tegelik !25_A
29174	kooliharidus	haridus	kooli+haridus	11_S	SgN	et	kooliharidus =haridus  (SgN  >kooli+haridus !11_S
29179	direktori	direktori	direktor	02_S	SgG	et	direktori =direktori  (SgG  >direktor !02_S
29183	kolmas	kolmas	kolmas	02_O	SgN	et	kolmas =kolmas  (SgN  >kolmas !02_O
29185	tänan	täna	tänama	27_V	IndPrSg1	et	tänan =täna  (IndPrSg1  >tänama !27_V
29186	soovin	soovi	soovima	28_V	IndPrSg1	et	soovin =soovi  (IndPrSg1  >soovima !28_V
29188	föön	föön	föön	22_S	SgN	et	föön =föön  (SgN  >föön !22_S
29200	lapsell	ell	laps+ell	22_S	SgN	et	lapsell =ell  (SgN  >laps+ell !22_S
29202	tervistkahjustav	kahjustav	tervist+kahjustav	02_A	SgN	et	tervistkahjustav =kahjustav  (SgN  >tervist+kahjustav !02_A
29205	kannatab	kannata	kannatama	27_V	IndPrSg3	et	kannatab =kannata  (IndPrSg3  >kannatama !27_V
29213	lakoonilised	lakoonilise	lakooniline	12_A	PlN	et	lakoonilised =lakoonilise  (PlN  >lakooniline !12_A
29217	jah	jah	jah	41_I	ID	et	jah =jah  (ID  >jah !41_I
29220	tarbijakaitseametis	ameti	tarbija+kaitse+amet	02_S	SgIn	et	tarbijakaitseametis =ameti  (SgIn  >tarbija+kaitse+amet !02_S
29222	tõmbas	tõmba	tõmbama	29_V	IndIpfSg3	et	tõmbas =tõmba  (IndIpfSg3  >tõmbama !29_V
29223	korrektsele	korrektse	korrektne	02_A	SgAll	et	korrektsele =korrektse  (SgAll  >korrektne !02_A
29226	vaalima	vaali	vaalima	28_V	Sup	et	vaalima =vaali  (Sup  >vaalima !28_V
29228	ohvriks	ohvri	ohver	02_S	SgTr	et	ohvriks =ohvri  (SgTr  >ohver !02_S
29233	abikaasaga	kaasa	abi+kaasa	16_S	SgKom	et	abikaasaga =kaasa  (SgKom  >abi+kaasa !16_S
29240	originaal	originaal	originaal	22_S	SgN	et	originaal =originaal  (SgN  >originaal !22_S
29252	jumalaks	jumala	jumal	02_S	SgTr	et	jumalaks =jumala  (SgTr  >jumal !02_S
29253	skandinaavlaste	skandinaavlas	skandinaavlane	12?10_S	PlG	et	skandinaavlaste =skandinaavlas  (PlG  >skandinaavlane !12?10_S
29261	vägiveod	veo	vägi+vedu	18_S	PlN	et	vägiveod =veo  (PlN  >vägi+vedu !18_S
29053	palavik	palavik	palavik	25_S	SgN	et	palavik =palavik  (SgN  >palavik !25_S
29056	juhtum	juhtum	juhtum	02_S	SgN	et	juhtum =juhtum  (SgN  >juhtum !02_S
29058	ajaleht	leht	aja+leht	22_S	SgN	et	ajaleht =leht  (SgN  >aja+leht !22_S
29060	leheküljeni	külje	lehe+külg	22_S	SgTer	et	leheküljeni =külje  (SgTer  >lehe+külg !22_S
29061	uudised	uudise	uudis	09_S	PlN	et	uudised =uudise  (PlN  >uudis !09_S
29072	detsembrini	detsembri	detsember	02_S	SgTer	et	detsembrini =detsembri  (SgTer  >detsember !02_S
29081	kits	kits	kits	22_S	SgN	et	kits =kits  (SgN  >kits !22_S
29092	maasika	maasika	maasikas	02_S	SgG	et	maasika =maasika  (SgG  >maasikas !02_S
29095	osaleda	osale	osalema	27_V	Inf	et	osaleda =osale  (Inf  >osalema !27_V
29097	tahame	taha	tahtma	34_V	IndPrPl1	et	tahame =taha  (IndPrPl1  >tahtma !34_V
29099	lisainfot	info	lisa+info	16_S	SgP	et	lisainfot =info  (SgP  >lisa+info !16_S
29102	sisaldama	sisalda	sisaldama	27_V	Sup	et	sisaldama =sisalda  (Sup  >sisaldama !27_V
29105	aitäh	aitäh	aitäh	41_I	ID	et	aitäh =aitäh  (ID  >aitäh !41_I
29109	eelistate	eelista	eelistama	27_V	IndPrPl2	et	eelistate =eelista  (IndPrPl2  >eelistama !27_V
29113	lemmiklauljate	laulja	lemmik+laulja	01_S	PlG	et	lemmiklauljate =laulja  (PlG  >lemmik+laulja !01_S
29117	lemmiklaulude	laulu	lemmik+laul	22_S	PlG	et	lemmiklaulude =laulu  (PlG  >lemmik+laul !22_S
29121	milledest	mille	mis	00_P	PlEl	et	milledest =mille  (PlEl  >mis !00_P
29134	täht	täht	täht	22_S	SgN	et	täht =täht  (SgN  >täht !22_S
29136	püüdlik	püüdlik	püüdlik	25_A	SgN	et	püüdlik =püüdlik  (SgN  >püüdlik !25_A
29139	välimuse	välimuse	välimus	11_S	SgG	et	välimuse =välimuse  (SgG  >välimus !11_S
29140	treenida	treeni	treenima	28_V	Inf	et	treenida =treeni  (Inf  >treenima !28_V
29141	pöörduda	pöördu	pöörduma	27_V	Inf	et	pöörduda =pöördu  (Inf  >pöörduma !27_V
29150	öökull	kull	öö+kull	22_S	SgN	et	öökull =kull  (SgN  >öö+kull !22_S
29153	vaheajal	aja	vahe+aeg	22_S	SgAd	et	vaheajal =aja  (SgAd  >vahe+aeg !22_S
29154	magada	maga	magama	27_V	Inf	et	magada =maga  (Inf  >magama !27_V
29160	ujuda	uju	ujuma	27_V	Inf	et	ujuda =uju  (Inf  >ujuma !27_V
29173	lähevad	lähe	minema	36_V	IndPrPl3	et	lähevad =lähe  (IndPrPl3  >minema !36_V
29175	mõjuda	mõju	mõjuma	27_V	Inf	et	mõjuda =mõju  (Inf  >mõjuma !27_V
29176	politseinikke	politseinikke	politseinik	25_S	PlP	et	politseinikke =politseinikke  (PlP  >politseinik !25_S
29177	võtavad	võta	võtma	35_V	IndPrPl3	et	võtavad =võta  (IndPrPl3  >võtma !35_V
29182	anta	an	andma	34_V	IndPrIps_	et	anta =an  (IndPrIps_  >andma !34_V
29192	rääkisin	rääki	rääkima	28_V	IndIpfSg1	et	rääkisin =rääki  (IndIpfSg1  >rääkima !28_V
29196	vigastas	vigasta	vigastama	27_V	IndIpfSg3	et	vigastas =vigasta  (IndIpfSg3  >vigastama !27_V
29197	erialad	ala	eri+ala	17_S	PlN	et	erialad =ala  (PlN  >eri+ala !17_S
29199	täiskasvanuna	kasvanu	täis+kasvanu	01_S	SgEs	et	täiskasvanuna =kasvanu  (SgEs  >täis+kasvanu !01_S
29218	räägite	räägi	rääkima	28_V	IndPrPl2	et	räägite =räägi  (IndPrPl2  >rääkima !28_V
29224	tarbijakaitseamet	amet	tarbija+kaitse+amet	02_S	SgN	et	tarbijakaitseamet =amet  (SgN  >tarbija+kaitse+amet !02_S
29234	suvilas	suvila	suvila	01_S	SgIn	et	suvilas =suvila  (SgIn  >suvila !01_S
29236	allikad	allika	allikas	02_S	PlN	et	allikad =allika  (PlN  >allikas !02_S
29244	keelseid	keelse	keelne	02_A	PlP	et	keelseid =keelse  (PlP  >keelne !02_A
29254	pikse	pikse	pikne	02_S	SgG	et	pikse =pikse  (SgG  >pikne !02_S
29257	tõlges	tõlge	tõlk	22_S	PlIn	et	tõlges =tõlge  (PlIn  >tõlk !22_S
29259	kohtuda	kohtu	kohtuma	27_V	Inf	et	kohtuda =kohtu  (Inf  >kohtuma !27_V
29260	teateid	teate	teade	06_S	PlP	et	teateid =teate  (PlP  >teade !06_S
29267	katekismuse	katekismuse	katekismus	11~09_S	SgG	et	katekismuse =katekismuse  (SgG  >katekismus !11~09_S
29269	laulud	laulu	laul	22_S	PlN	et	laulud =laulu  (PlN  >laul !22_S
29271	füüsiline	füüsiline	füüsiline	12_A	SgN	et	füüsiline =füüsiline  (SgN  >füüsiline !12_A
29272	tootis	toot	tootma	34_V	IndIpfSg3	et	tootis =toot  (IndIpfSg3  >tootma !34_V
29276	kaupmehed	mehe	kaup+mees	13_S	PlN	et	kaupmehed =mehe  (PlN  >kaup+mees !13_S
29283	ajale	aja	aeg	22_S	SgAll	et	ajale =aja  (SgAll  >aeg !22_S
29291	lugulaulud	laulu	lugu+laul	22_S	PlN	et	lugulaulud =laulu  (PlN  >lugu+laul !22_S
29295	slaavi	slaavi	slaavi	41_G	ID	et	slaavi =slaavi  (ID  >slaavi !41_G
29305	oder	oder	oder	24_S	SgN	et	oder =oder  (SgN  >oder !24_S
29309	muinasusundi	usundi	muinas+usund	02_S	SgG	et	muinasusundi =usundi  (SgG  >muinas+usund !02_S
29315	põranda	põranda	põrand	02_S	SgG	et	põranda =põranda  (SgG  >põrand !02_S
29319	ehte	ehte	ehe	06_S	SgG	et	ehte =ehte  (SgG  >ehe !06_S
29138	hoolitseb	hoolitse	hoolitsema	27_V	IndPrSg3	et	hoolitseb =hoolitse  (IndPrSg3  >hoolitsema !27_V
29155	tallinnasse	asse	tallinn+ass	22_S	PlP	et	tallinnasse =asse  (PlP  >tallinn+ass !22_S
29158	suveks	suve	suvi	20_S	SgTr	et	suveks =suve  (SgTr  >suvi !20_S
29159	meres	mere	meri	20_S	SgIn	et	meres =mere  (SgIn  >meri !20_S
29162	süüa	süü	sööma	38_V	Inf	et	süüa =süü  (Inf  >sööma !38_V
29181	koduülesandeid	ande	kodu+üles+anne	06_S	PlP	et	koduülesandeid =ande  (PlP  >kodu+üles+anne !06_S
29184	määran	määra	määrama	29_V	IndPrSg1	et	määran =määra  (IndPrSg1  >määrama !29_V
29189	kaupluselt	kaupluse	kauplus	11~09_S	SgAbl	et	kaupluselt =kaupluse  (SgAbl  >kauplus !11~09_S
29198	tunnevad	tunne	tundma	34_V	IndPrPl3	et	tunnevad =tunne  (IndPrPl3  >tundma !34_V
29201	otsustama	otsusta	otsustama	27_V	Sup	et	otsustama =otsusta  (Sup  >otsustama !27_V
29204	täiskasvanute	kasvanu	täis+kasvanu	01_S	PlG	et	täiskasvanute =kasvanu  (PlG  >täis+kasvanu !01_S
29206	areng	areng	areng	02_S	SgN	et	areng =areng  (SgN  >areng !02_S
29208	mõjutab	mõjuta	mõjutama	27_V	IndPrSg3	et	mõjutab =mõjuta  (IndPrSg3  >mõjutama !27_V
29209	pingeid	pinge	pinge	06_S	PlP	et	pingeid =pinge  (PlP  >pinge !06_S
29210	tööintervjuuks	intervjuu	töö+intervjuu	26_S	SgTr	et	tööintervjuuks =intervjuu  (SgTr  >töö+intervjuu !26_S
29212	rääkima	rääki	rääkima	28_V	Sup	et	rääkima =rääki  (Sup  >rääkima !28_V
29216	tööintervjuul	intervjuu	töö+intervjuu	26_S	SgAd	et	tööintervjuul =intervjuu  (SgAd  >töö+intervjuu !26_S
29219	informatsioon	informatsioon	informatsioon	22_S	SgN	et	informatsioon =informatsioon  (SgN  >informatsioon !22_S
29227	vähendada	vähenda	vähendama	27_V	Inf	et	vähendada =vähenda  (Inf  >vähendama !27_V
29229	font-variant	variant	font-variant	22_S	SgN	et	font-variant =variant  (SgN  >font-variant !22_S
29230	odavad	odava	odav	02_A	PlN	et	odavad =odava  (PlN  >odav !02_A
29232	töötate	tööta	töötama	27_V	IndPrPl2	et	töötate =tööta  (IndPrPl2  >töötama !27_V
29235	transport	transport	transport	22_S	SgN	et	transport =transport  (SgN  >transport !22_S
29237	muistse	muistse	muistne	02_A	SgG	et	muistse =muistse  (SgG  >muistne !02_A
29250	matmistoit	toit	matmis+toit	22_S	SgN	et	matmistoit =toit  (SgN  >matmis+toit !22_S
29256	variant	variant	variant	22_S	SgN	et	variant =variant  (SgN  >variant !22_S
29287	orjatar	orjatar	orjatar	19_S	SgN	et	orjatar =orjatar  (SgN  >orjatar !19_S
29299	hobuloomad	looma	hobu+loom	22_S	PlN	et	hobuloomad =looma  (PlN  >hobu+loom !22_S
29301	veekogude	kogu	vee+kogu	17_S	PlG	et	veekogude =kogu  (PlG  >vee+kogu !17_S
29306	põllumajandust	majandus	põllu+majandus	11_S	SgP	et	põllumajandust =majandus  (SgP  >põllu+majandus !11_S
29310	alepõllundus	põllundus	ale+põllundus	11_S	SgN	et	alepõllundus =põllundus  (SgN  >ale+põllundus !11_S
29314	püstkoja	koja	püst+koda	18_S	SgG	et	püstkoja =koja  (SgG  >püst+koda !18_S
29316	tööriistu	riistu	töö+riist	22_S	PlP	et	tööriistu =riistu  (PlP  >töö+riist !22_S
29318	amuleti	amuleti	amulett	22_S	SgG	et	amuleti =amuleti  (SgG  >amulett !22_S
29336	konfliktide	konflikti	konflikt	22_S	PlG	et	konfliktide =konflikti  (PlG  >konflikt !22_S
29343	jõkke	jõkke	jõgi	21_S	SgAdt	et	jõkke =jõkke  (SgAdt  >jõgi !21_S
29348	rahvad	rahva	rahvas	07_S	PlN	et	rahvad =rahva  (PlN  >rahvas !07_S
29351	päevani	päeva	päev	22_S	SgTer	et	päevani =päeva  (SgTer  >päev !22_S
29365	vägi	vägi	vägi	21_S	SgN	et	vägi =vägi  (SgN  >vägi !21_S
29366	puid	pu	puu	26_S	PlP	et	puid =pu  (PlP  >puu !26_S
29369	pühaks	püha	püha	17_SA	SgTr	et	pühaks =püha  (SgTr  >püha !17_SA
29371	ehteid	ehte	ehe	06_S	PlP	et	ehteid =ehte  (PlP  >ehe !06_S
29374	matusepaigad	paiga	matuse+paik	22_S	PlN	et	matusepaigad =paiga  (PlN  >matuse+paik !22_S
29375	oad	oa	uba	18_S	PlN	et	oad =oa  (PlN  >uba !18_S
29383	mõjub	mõju	mõjuma	27_V	IndPrSg3	et	mõjub =mõju  (IndPrSg3  >mõjuma !27_V
29388	heast	hea	hea	26_AS	SgEl	et	heast =hea  (SgEl  >hea !26_AS
29393	haua	haua	haud	22_S	SgG	et	haua =haua  (SgG  >haud !22_S
29395	selges	selge	selge	01_A	SgIn	et	selges =selge  (SgIn  >selge !01_A
29412	mängis	mängi	mängima	28_V	IndIpfSg3	et	mängis =mängi  (IndIpfSg3  >mängima !28_V
29416	aspekt	aspekt	aspekt	22_S	SgN	et	aspekt =aspekt  (SgN  >aspekt !22_S
29417	poliitilisel	poliitilise	poliitiline	12_A	SgAd	et	poliitilisel =poliitilise  (SgAd  >poliitiline !12_A
29419	taasiseseisvumisprotsessis	protsessi	taas+ise+seisvumis+protsess	22_S	SgIn	et	taasiseseisvumisprotsessis =protsessi  (SgIn  >taas+ise+seisvumis+protsess !22_S
29429	nädalaks	nädala	nädal	02_S	SgTr	et	nädalaks =nädala  (SgTr  >nädal !02_S
29430	küsima	küsi	küsima	27_V	Sup	et	küsima =küsi  (Sup  >küsima !27_V
29433	tehnikas	tehnika	tehnika	01_S	SgIn	et	tehnikas =tehnika  (SgIn  >tehnika !01_S
29266	tõlgis	tõlgi	tõlk	22_S	SgIn	et	tõlgis =tõlgi  (SgIn  >tõlk !22_S
29270	puutahvlil	tahvli	puu+tahvel	02_S	SgAd	et	puutahvlil =tahvli  (SgAd  >puu+tahvel !02_S
29278	vaht	vaht	vaht	22_S	SgN	et	vaht =vaht  (SgN  >vaht !22_S
29280	metall	metall	metall	22_S	SgN	et	metall =metall  (SgN  >metall !22_S
29282	münte	münte	münt	22_S	PlP	et	münte =münte  (PlP  >münt !22_S
29284	maksti	maks	maksma	32_V	IndIpfIps	et	maksti =maks  (IndIpfIps  >maksma !32_V
29289	skandinaavlastega	skandinaavlas	skandinaavlane	12?10_S	PlKom	et	skandinaavlastega =skandinaavlas  (PlKom  >skandinaavlane !12?10_S
29290	saagades	saaga	saaga	16_S	PlIn	et	saagades =saaga  (PlIn  >saaga !16_S
29297	kaal	kaal	kaal	22_S	SgN	et	kaal =kaal  (SgN  >kaal !22_S
29298	aktiivsed	aktiivse	aktiivne	02_A	PlN	et	aktiivsed =aktiivse  (PlN  >aktiivne !02_A
29320	funktsioonis	funktsiooni	funktsioon	22_S	SgIn	et	funktsioonis =funktsiooni  (SgIn  >funktsioon !22_S
29326	selili	selili	selili	41_D	ID	et	selili =selili  (ID  >selili !41_D
29332	kirst	kirst	kirst	22_S	SgN	et	kirst =kirst  (SgN  >kirst !22_S
29333	keskmine	keskmine	keskmine	12?10_A	SgN	et	keskmine =keskmine  (SgN  >keskmine !12?10_A
29335	sõdade	sõda	sõda	18_S	PlG	et	sõdade =sõda  (PlG  >sõda !18_S
29341	hiljemalt	hiljemalt	hiljemalt	41_D	ID	et	hiljemalt =hiljemalt  (ID  >hiljemalt !41_D
29344	rauaajal	aja	raua+aeg	22_S	SgAd	et	rauaajal =aja  (SgAd  >raua+aeg !22_S
29350	muinasusklikuna	uskliku	muinas+usklik	25_AS	SgEs	et	muinasusklikuna =uskliku  (SgEs  >muinas+usklik !25_AS
29352	tagamaaks	maa	taga+maa	26_S	SgTr	et	tagamaaks =maa  (SgTr  >taga+maa !26_S
29355	raiuti	raiu	raiuma	28_V	IndIpfIps	et	raiuti =raiu  (IndIpfIps  >raiuma !28_V
29356	põletati	põleta	põletama	27_V	IndIpfIps	et	põletati =põleta  (IndIpfIps  >põletama !27_V
29359	kasvatati	kasvata	kasvatama	27_V	IndIpfIps	et	kasvatati =kasvata  (IndIpfIps  >kasvatama !27_V
29360	iseloomulik	loomulik	ise+loomulik	25_A	SgN	et	iseloomulik =loomulik  (SgN  >ise+loomulik !25_A
29362	usuti	usu	uskuma	28_V	IndIpfIps	et	usuti =usu  (IndIpfIps  >uskuma !28_V
29363	eluta	elu	elu	17_S	SgAb	et	eluta =elu  (SgAb  >elu !17_S
29367	kive	kive	kivi	17_S	PlP	et	kive =kive  (PlP  >kivi !17_S
29370	loodusobjektidele	objekti	loodus+objekt	22_S	PlAll	et	loodusobjektidele =objekti  (PlAll  >loodus+objekt !22_S
29373	ristiusustamist	usustamis	risti+usustamine	12_S	SgP	et	ristiusustamist =usustamis  (SgP  >risti+usustamine !12_S
29385	vaimud	vaimu	vaim	22_S	PlN	et	vaimud =vaimu  (PlN  >vaim !22_S
29390	äike	äike	äike	12?10_S	SgN	et	äike =äike  (SgN  >äike !12?10_S
29403	religiooniga	religiooni	religioon	22_S	SgKom	et	religiooniga =religiooni  (SgKom  >religioon !22_S
29404	näitabki	näita	näitama	29_V	IndPrSg3^	et	näitabki =näita  (IndPrSg3^  >näitama !29_V
29409	alepõllundusega	põllunduse	ale+põllundus	11_S	SgKom	et	alepõllundusega =põllunduse  (SgKom  >ale+põllundus !11_S
29410	mõisted	mõiste	mõiste	06_S	PlN	et	mõisted =mõiste  (PlN  >mõiste !06_S
29418	astmel	astme	aste	05_S	SgAd	et	astmel =astme  (SgAd  >aste !05_S
29421	laostama	laosta	laostama	27_V	Sup	et	laostama =laosta  (Sup  >laostama !27_V
29424	koolimütse	mütse	kooli+müts	22_S	PlP	et	koolimütse =mütse  (PlP  >kooli+müts !22_S
29431	kirjaliku	kirjaliku	kirjalik	25_A	SgG	et	kirjaliku =kirjaliku  (SgG  >kirjalik !25_A
29435	muusikakeskuseid	keskuse	muusika+keskus	09_S	PlP	et	muusikakeskuseid =keskuse  (PlP  >muusika+keskus !09_S
29436	astub	astu	astuma	28_V	IndPrSg3	et	astub =astu  (IndPrSg3  >astuma !28_V
29439	organisatsioonina	organisatsiooni	organisatsioon	22_S	SgEs	et	organisatsioonina =organisatsiooni  (SgEs  >organisatsioon !22_S
29443	poliitikuid	poliitiku	poliitik	02_S	PlP	et	poliitikuid =poliitiku  (PlP  >poliitik !02_S
29444	taotledes	taotle	taotlema	27_V	Ger	et	taotledes =taotle  (Ger  >taotlema !27_V
29447	hoiak	hoiak	hoiak	02_S	SgN	et	hoiak =hoiak  (SgN  >hoiak !02_S
29457	revolutsiooniks	revolutsiooni	revolutsioon	22_S	SgTr	et	revolutsiooniks =revolutsiooni  (SgTr  >revolutsioon !22_S
29461	otsuseid	otsuse	otsus	09_S	PlP	et	otsuseid =otsuse  (PlP  >otsus !09_S
29474	ühistud	ühistu	ühistu	01_S	PlN	et	ühistud =ühistu  (PlN  >ühistu !01_S
29476	meetmeid	meetme	meede	05_S	PlP	et	meetmeid =meetme  (PlP  >meede !05_S
29491	linnavalitsuse	valitsuse	linna+valitsus	11_S	SgG	et	linnavalitsuse =valitsuse  (SgG  >linna+valitsus !11_S
29500	võimuesindajad	esindaja	võimu+esindaja	01_S	PlN	et	võimuesindajad =esindaja  (PlN  >võimu+esindaja !01_S
29502	administratiivse	administratiivse	administratiivne	02_A	SgG	et	administratiivse =administratiivse  (SgG  >administratiivne !02_A
29510	tagajärgu	järgu	taga+järk	22_S	SgG	et	tagajärgu =järgu  (SgG  >taga+järk !22_S
29522	algamas	alga	algama	29_V	SupIn	et	algamas =alga  (SupIn  >algama !29_V
29525	kõikjal	kõikjal	kõikjal	41_D	ID	et	kõikjal =kõikjal  (ID  >kõikjal !41_D
29281	hõbe	hõbe	hõbe	02_S	SgN	et	hõbe =hõbe  (SgN  >hõbe !02_S
29285	toodete	toode	toode	06_S	PlG	et	toodete =toode  (PlG  >toode !06_S
29286	hõbedat	hõbeda	hõbe	02_S	SgP	et	hõbedat =hõbeda  (SgP  >hõbe !02_S
29292	tark	tark	tark	22_AS	SgN	et	tark =tark  (SgN  >tark !22_AS
29294	asulad	asula	asula	01_S	PlN	et	asulad =asula  (PlN  >asula !01_S
29296	kaalusüsteem	süsteem	kaalu+süsteem	22_S	SgN	et	kaalusüsteem =süsteem  (SgN  >kaalu+süsteem !22_S
29303	teraga	tera	tera	17_S	SgKom	et	teraga =tera  (SgKom  >tera !17_S
29304	sirp	sirp	sirp	22_S	SgN	et	sirp =sirp  (SgN  >sirp !22_S
29311	ajajärk	järk	aja+järk	22_S	SgN	et	ajajärk =järk  (SgN  >aja+järk !22_S
29312	hauatagusest	taguse	haua+tagune	10_AS	SgEl	et	hauatagusest =taguse  (SgEl  >haua+tagune !10_AS
29321	merevaik	vaik	mere+vaik	22_S	SgN	et	merevaik =vaik  (SgN  >mere+vaik !22_S
29322	hõimudeni	hõimu	hõim	22_S	PlTer	et	hõimudeni =hõimu  (PlTer  >hõim !22_S
29323	kalmed	kalme	kalme	06_S	PlN	et	kalmed =kalme  (PlN  >kalme !06_S
29328	mugavas	mugava	mugav	02_A	SgIn	et	mugavas =mugava  (SgIn  >mugav !02_A
29331	rajutati	tati	raju+tatt	22_S	SgG	et	rajutati =tati  (SgG  >raju+tatt !22_S
29342	tööriist	riist	töö+riist	22_S	SgN	et	tööriist =riist  (SgN  >töö+riist !22_S
29347	baltimaade	maa	balti+maa	26_S	PlG	et	baltimaade =maa  (PlG  >balti+maa !26_S
29361	animism	animism	animism	22_S	SgN	et	animism =animism  (SgN  >animism !22_S
29364	kividel	kivi	kivi	17_S	PlAd	et	kividel =kivi  (PlAd  >kivi !17_S
29378	kalmistupühad	püha	kalmistu+püha	17_SA	PlN	et	kalmistupühad =püha  (PlN  >kalmistu+püha !17_SA
29380	valati	vala	valama	27_V	IndIpfIps	et	valati =vala  (IndIpfIps  >valama !27_V
29381	allikaveele	vee	allika+vesi	15_S	SgAll	et	allikaveele =vee  (SgAll  >allika+vesi !15_S
29387	majanduslik	majanduslik	majanduslik	25_A	SgN	et	majanduslik =majanduslik  (SgN  >majanduslik !25_A
29391	surm	surm	surm	22_S	SgN	et	surm =surm  (SgN  >surm !22_S
29399	tuule	tuule	tuul	13_S	SgG	et	tuule =tuule  (SgG  >tuul !13_S
29401	esemed	eseme	ese	04_S	PlN	et	esemed =eseme  (PlN  >ese !04_S
29406	maaharimise	harimise	maa+harimine	12_S	SgG	et	maaharimise =harimise  (SgG  >maa+harimine !12_S
29411	võib-olla	võib-olla	võib+-olla	41_D	ID	et	võib-olla =võib-olla  (ID  >võib+-olla !41_D
29415	julgustama	julgusta	julgustama	27_V	Sup	et	julgustama =julgusta  (Sup  >julgustama !27_V
29420	programm	programm	programm	22_S	SgN	et	programm =programm  (SgN  >programm !22_S
29422	taasiseseisvaks	seisva	taas+ise+seisev	02_A	SgTr	et	taasiseseisvaks =seisva  (SgTr  >taas+ise+seisev !02_A
29426	kandma	kand	kandma	34_V	Sup	et	kandma =kand  (Sup  >kandma !34_V
29427	gümnaasiumiteks	gümnaasiumi	gümnaasium	02_S	PlTr	et	gümnaasiumiteks =gümnaasiumi  (PlTr  >gümnaasium !02_S
29441	koondas	koonda	koondama	27_V	IndIpfSg3	et	koondas =koonda  (IndIpfSg3  >koondama !27_V
29450	interliikumisel	liikumise	inter+liikumine	12_S	SgAd	et	interliikumisel =liikumise  (SgAd  >inter+liikumine !12_S
29462	juht	juht	juht	22_S	SgN	et	juht =juht  (SgN  >juht !22_S
29466	moskva-meelseks	meelse	moskva-meelne	02_A	SgTr	et	moskva-meelseks =meelse  (SgTr  >moskva-meelne !02_A
29470	terminit	termini	termin	02_S	SgP	et	terminit =termini  (SgP  >termin !02_S
29480	käsikäes	käsikäes	käsi+käes	41_D	ID	et	käsikäes =käsikäes  (ID  >käsi+käes !41_D
29484	jagama	jaga	jagama	27_V	Sup	et	jagama =jaga  (Sup  >jagama !27_V
29485	piirkondadeks	piirkonda	piirkond	22_S	PlTr	et	piirkondadeks =piirkonda  (PlTr  >piirkond !22_S
29487	ordumeister	meister	ordu+meister	02_S	SgN	et	ordumeister =meister  (SgN  >ordu+meister !02_S
29489	piiskopkonnale	piiskopkonna	piiskopkond	22_S	SgAll	et	piiskopkonnale =piiskopkonna  (SgAll  >piiskopkond !22_S
29493	linnakodanike	kodanike	linna+kodanik	25_S	PlG	et	linnakodanike =kodanike  (PlG  >linna+kodanik !25_S
29497	tsunftis	tsunfti	tsunft	22_S	SgIn	et	tsunftis =tsunfti  (SgIn  >tsunft !22_S
29503	kirikukihelkondadeks	kihelkonda	kiriku+kihelkond	22_S	PlTr	et	kirikukihelkondadeks =kihelkonda  (PlTr  >kiriku+kihelkond !22_S
29505	võitlus	võitlus	võitlus	11~09_S	SgN	et	võitlus =võitlus  (SgN  >võitlus !11~09_S
29517	hingaks	hinga	hingama	29_V	KndPrPs	et	hingaks =hinga  (KndPrPs  >hingama !29_V
29519	kiirte	kiir	kiir	13_S	PlG	et	kiirte =kiir  (PlG  >kiir !13_S
29530	uuesse	uue	uus	14_A	SgIll	et	uuesse =uue  (SgIll  >uus !14_A
29540	tullakse	tull	tulema	36_V	IndPrIps	et	tullakse =tull  (IndPrIps  >tulema !36_V
29546	oktoobril	oktoobri	oktoober	02_S	SgAd	et	oktoobril =oktoobri  (SgAd  >oktoober !02_S
29550	valvur	valvur	valvur	02_S	SgN	et	valvur =valvur  (SgN  >valvur !02_S
29552	tunnil	tunni	tund	22_S	SgAd	et	tunnil =tunni  (SgAd  >tund !22_S
29555	tulekut	tuleku	tulek	02_S	SgP	et	tulekut =tuleku  (SgP  >tulek !02_S
29300	vajalikud	vajaliku	vajalik	25_A	PlN	et	vajalikud =vajaliku  (PlN  >vajalik !25_A
29302	tööriistad	riista	töö+riist	22_S	PlN	et	tööriistad =riista  (PlN  >töö+riist !22_S
29307	areneda	arene	arenema	27_V	Inf	et	areneda =arene  (Inf  >arenema !27_V
29308	ajavahemik	vahemik	aja+vahemik	25_S	SgN	et	ajavahemik =vahemik  (SgN  >aja+vahemik !25_S
29313	territooriumile	territooriumi	territoorium	19~02_S	SgAll	et	territooriumile =territooriumi  (SgAll  >territoorium !19~02_S
29317	tarbeesemeid	eseme	tarbe+ese	04_S	PlP	et	tarbeesemeid =eseme  (PlP  >tarbe+ese !04_S
29324	väljaspool	väljaspool	väljas+pool	41_DK	ID	et	väljaspool =väljaspool  (ID  >väljas+pool !41_DK
29325	sängitati	sängita	sängitama	27_V	IndIpfIps	et	sängitati =sängita  (IndIpfIps  >sängitama !27_V
29330	tarbeesemed	eseme	tarbe+ese	04_S	PlN	et	tarbeesemed =eseme  (PlN  >tarbe+ese !04_S
29334	rauaaeg	aeg	raua+aeg	22_S	SgN	et	rauaaeg =aeg  (SgN  >raua+aeg !22_S
29337	haudadest	hauda	haud	22_S	PlEl	et	haudadest =hauda  (PlEl  >haud !22_S
29338	vere	vere	veri	20_S	SgG	et	vere =vere  (SgG  >veri !20_S
29340	ohverdati	ohverda	ohverdama	27_V	IndIpfIps	et	ohverdati =ohverda  (IndIpfIps  >ohverdama !27_V
29345	elatusalaks	ala	elatus+ala	17_S	SgTr	et	elatusalaks =ala  (SgTr  >elatus+ala !17_S
29346	toimingud	toimingu	toiming	02_S	PlN	et	toimingud =toimingu  (PlN  >toiming !02_S
29349	tänase	tänase	tänane	10_A	SgG	et	tänase =tänase  (SgG  >tänane !10_A
29357	tuhk	tuhk	tuhk	22_S	SgN	et	tuhk =tuhk  (SgN  >tuhk !22_S
29358	väetiseks	väetise	väetis	11~09_S	SgTr	et	väetiseks =väetise  (SgTr  >väetis !11~09_S
29372	põletusmatus	matus	põletus+matus	09_S	SgN	et	põletusmatus =matus  (SgN  >põletus+matus !09_S
29377	hingedele	hinge	hing	22_S	PlAll	et	hingedele =hinge  (PlAll  >hing !22_S
29386	taarat	taara	taara	16_S	SgP	et	taarat =taara  (SgP  >taara !16_S
29389	loodusjõuks	jõu	loodus+jõud	22_S	SgTr	et	loodusjõuks =jõu  (SgTr  >loodus+jõud !22_S
29392	asendis	asendi	asend	02_S	SgIn	et	asendis =asendi  (SgIn  >asend !02_S
29394	hauapanuseid	panuse	haua+panus	09_S	PlP	et	hauapanuseid =panuse  (PlP  >haua+panus !09_S
29396	religioon	religioon	religioon	22_S	SgN	et	religioon =religioon  (SgN  >religioon !22_S
29397	tähtsad	tähtsa	tähtis	02_A	PlN	et	tähtsad =tähtsa  (PlN  >tähtis !02_A
29398	arvatakse	arva	arvama	29_V	IndPrIps	et	arvatakse =arva  (IndPrIps  >arvama !29_V
29402	huvitama	huvita	huvitama	27_V	Sup	et	huvitama =huvita  (Sup  >huvitama !27_V
29408	alustatakse	alusta	alustama	27_V	IndPrIps	et	alustatakse =alusta  (IndPrIps  >alustama !27_V
29413	rahvaga	rahva	rahvas	07_S	SgKom	et	rahvaga =rahva  (SgKom  >rahvas !07_S
29414	võitlema	võitle	võitlema	30_V	Sup	et	võitlema =võitle  (Sup  >võitlema !30_V
29423	uures	uure	uur	22_S	PlIn	et	uures =uure  (PlIn  >uur !22_S
29432	hiv-positiivne	positiivne	hiv-positiivne	02_A	SgN	et	hiv-positiivne =positiivne  (SgN  >hiv-positiivne !02_A
29440	etteotsa	etteotsa	ette+otsa	41_D	ID	et	etteotsa =etteotsa  (ID  >ette+otsa !41_D
29451	rahvarinnet	rinne	rahva+rinne	06_S	SgP	et	rahvarinnet =rinne  (SgP  >rahva+rinne !06_S
29452	interliikumist	liikumis	inter+liikumine	12_S	SgP	et	interliikumist =liikumis  (SgP  >inter+liikumine !12_S
29455	interrinne	rinne	inter+rinne	06_S	SgN	et	interrinne =rinne  (SgN  >inter+rinne !06_S
29475	kooperatiivid	kooperatiivi	kooperatiiv	22_S	PlN	et	kooperatiivid =kooperatiivi  (PlN  >kooperatiiv !22_S
29477	kriis	kriis	kriis	22_S	SgN	et	kriis =kriis  (SgN  >kriis !22_S
29481	tekkeni	tekke	teke	06_S	SgTer	et	tekkeni =tekke  (SgTer  >teke !06_S
29486	mee	mee	mesi	15_S	SgG	et	mee =mee  (SgG  >mesi !15_S
29488	rannik	rannik	rannik	02_S	SgN	et	rannik =rannik  (SgN  >rannik !02_S
29490	seadustega	seadus	seadus	11~09_S	PlKom	et	seadustega =seadus  (PlKom  >seadus !11~09_S
29496	käsitöölised	töölise	käsi+tööline	12?10_S	PlN	et	käsitöölised =töölise  (PlN  >käsi+tööline !12?10_S
29499	käsitöömeistrid	meistri	käsi+töö+meister	02_S	PlN	et	käsitöömeistrid =meistri  (PlN  >käsi+töö+meister !02_S
29501	korraldas	korralda	korraldama	27_V	IndIpfSg3	et	korraldas =korralda  (IndIpfSg3  >korraldama !27_V
29504	kihelkonnal	kihelkonna	kihelkond	22_S	SgAd	et	kihelkonnal =kihelkonna  (SgAd  >kihelkond !22_S
29507	korruptsiooniga	korruptsiooni	korruptsioon	22_S	SgKom	et	korruptsiooniga =korruptsiooni  (SgKom  >korruptsioon !22_S
29520	difteeriat	difteeria	difteeria	01_S	SgP	et	difteeriat =difteeria  (SgP  >difteeria !01_S
29531	pükste	püks	püks	23_S	PlG	et	pükste =püks  (PlG  >püks !23_S
29547	ameti	ameti	amet	02_S	SgG	et	ameti =ameti  (SgG  >amet !02_S
29549	saabus	saabu	saabuma	27_V	IndIpfSg3	et	saabus =saabu  (IndIpfSg3  >saabuma !27_V
29553	pidemiku	miku	pide+mikk	22_S	SgG	et	pidemiku =miku  (SgG  >pide+mikk !22_S
29564	objektidele	objekti	objekt	22_S	PlAll	et	objektidele =objekti  (PlAll  >objekt !22_S
29327	poosis	poosi	poos	22_S	SgIn	et	poosis =poosi  (SgIn  >poos !22_S
29329	hauapanused	panuse	haua+panus	09_S	PlN	et	hauapanused =panuse  (PlN  >haua+panus !09_S
29339	muinasaja	aja	muinas+aeg	22_S	SgG	et	muinasaja =aja  (SgG  >muinas+aeg !22_S
29353	suurendada	suurenda	suurendama	27_V	Inf	et	suurendada =suurenda  (Inf  >suurendama !27_V
29354	väge	väge	vägi	21_S	SgP	et	väge =väge  (SgP  >vägi !21_S
29368	allikaid	allika	allikas	02_S	PlP	et	allikaid =allika  (PlP  >allikas !02_S
29376	herned	herne	hernes	07_S	PlN	et	herned =herne  (PlN  >hernes !07_S
29379	juurtele	juur	juur	13_S	PlAll	et	juurtele =juur  (PlAll  >juur !13_S
29382	allikavee	vee	allika+vesi	15_S	SgG	et	allikavee =vee  (SgG  >allika+vesi !15_S
29384	tervisele	tervise	tervis	09~11_S	SgAll	et	tervisele =tervise  (SgAll  >tervis !09~11_S
29400	anti	an	andma	34_V	IndIpfIps	et	anti =an  (IndIpfIps  >andma !34_V
29405	vaimne	vaimne	vaimne	02_A	SgN	et	vaimne =vaimne  (SgN  >vaimne !02_A
29407	põletatakse	põleta	põletama	27_V	IndPrIps	et	põletatakse =põleta  (IndPrIps  >põletama !27_V
29425	mõnedes	mõne	mõni	20_P	PlIn	et	mõnedes =mõne  (PlIn  >mõni !20_P
29428	minisuguse	suguse	mini+sugune	10_A	SgG	et	minisuguse =suguse  (SgG  >mini+sugune !10_A
29434	telekad	teleka	telekas	02_S	PlN	et	telekad =teleka  (PlN  >telekas !02_S
29449	vastukaaluks	kaalu	vastu+kaal	22_S	SgTr	et	vastukaaluks =kaalu  (SgTr  >vastu+kaal !22_S
29454	proletariaat	proletariaat	proletariaat	22_S	SgN	et	proletariaat =proletariaat  (SgN  >proletariaat !22_S
29463	peaministri	ministri	pea+minister	02_S	SgG	et	peaministri =ministri  (SgG  >pea+minister !02_S
29464	savisaare	saare	savi+saar	13_S	SgG	et	savisaare =saare  (SgG  >savi+saar !13_S
29465	reetlikuks	reetliku	reetlik	25_A	SgTr	et	reetlikuks =reetliku  (SgTr  >reetlik !25_A
29467	ratsionaalne	ratsionaalne	ratsionaalne	02_A	SgN	et	ratsionaalne =ratsionaalne  (SgN  >ratsionaalne !02_A
29468	ometi	ometi	ometi	41_D	ID	et	ometi =ometi  (ID  >ometi !41_D
29473	repressioonidest	repressiooni	repressioon	22_S	PlEl	et	repressioonidest =repressiooni  (PlEl  >repressioon !22_S
29478	liidul	liidu	liit	22_S	SgAd	et	liidul =liidu  (SgAd  >liit !22_S
29479	võimalust	võimalus	võimalus	11_S	SgP	et	võimalust =võimalus  (SgP  >võimalus !11_S
29483	ühiskonnakorraldus	korraldus	ühis+konna+korraldus	11_S	SgN	et	ühiskonnakorraldus =korraldus  (SgN  >ühis+konna+korraldus !11_S
29506	usupuhastus	puhastus	usu+puhastus	11_S	SgN	et	usupuhastus =puhastus  (SgN  >usu+puhastus !11_S
29514	parajas	paraja	paras	02_A	SgIn	et	parajas =paraja  (SgIn  >paras !02_A
29515	aparaadiks	aparaadi	aparaat	22_S	SgTr	et	aparaadiks =aparaadi  (SgTr  >aparaat !22_S
29521	uuest	uue	uus	14_A	SgEl	et	uuest =uue  (SgEl  >uus !14_A
29527	maandata	maanda	maandama	27_V	IndPrIps_	et	maandata =maanda  (IndPrIps_  >maandama !27_V
29533	kõigega	kõige	kõik	00_P	SgKom	et	kõigega =kõige  (SgKom  >kõik !00_P
29536	puhates	puha	puhkama	29_V	Ger	et	puhates =puha  (Ger  >puhkama !29_V
29538	difteeriasse	difteeria	difteeria	01_S	SgIll	et	difteeriasse =difteeria  (SgIll  >difteeria !01_S
29548	juurdlus	juurdlus	juurdlus	11~09_S	SgN	et	juurdlus =juurdlus  (SgN  >juurdlus !11~09_S
29551	päevikus	päeviku	päevik	02_S	SgIn	et	päevikus =päeviku  (SgIn  >päevik !02_S
29556	valvesignalisatsioon	signalisatsioon	valve+signalisatsioon	22_S	SgN	et	valvesignalisatsioon =signalisatsioon  (SgN  >valve+signalisatsioon !22_S
29562	teatas	teata	teatama	27_V	IndIpfSg3	et	teatas =teata  (IndIpfSg3  >teatama !27_V
29573	raadiusi	raadiusi	raadius	11_S	PlP	et	raadiusi =raadiusi  (PlP  >raadius !11_S
29580	tundud	tundu	tunduma	27_V	IndPrSg2	et	tundud =tundu  (IndPrSg2  >tunduma !27_V
29589	puhkepäev	päev	puhke+päev	22_S	SgN	et	puhkepäev =päev  (SgN  >puhke+päev !22_S
29600	rahvuslikud	rahvusliku	rahvuslik	25_A	PlN	et	rahvuslikud =rahvusliku  (PlN  >rahvuslik !25_A
29608	kartuli	kartuli	kartul	02_S	SgG	et	kartuli =kartuli  (SgG  >kartul !02_S
29615	pooltootlik	tootlik	pool+tootlik	25_A	SgN	et	pooltootlik =tootlik  (SgN  >pool+tootlik !25_A
29618	laienes	laiene	laienema	27_V	IndIpfSg3	et	laienes =laiene  (IndIpfSg3  >laienema !27_V
29620	jahutööstuse	tööstuse	jahu+tööstus	11~09_S	SgG	et	jahutööstuse =tööstuse  (SgG  >jahu+tööstus !11~09_S
29622	kriisid	kriisi	kriis	22_S	PlN	et	kriisid =kriisi  (PlN  >kriis !22_S
29625	novelle	novelle	novell	22_S	PlP	et	novelle =novelle  (PlP  >novell !22_S
29630	ametnikud	ametniku	ametnik	25_S	PlN	et	ametnikud =ametniku  (PlN  >ametnik !25_S
29641	albumit	albumi	album	02_S	SgP	et	albumit =albumi  (SgP  >album !02_S
29647	trükiti	trüki	trükkima	28_V	IndIpfIps	et	trükiti =trüki  (IndIpfIps  >trükkima !28_V
29659	rahuldab	rahulda	rahuldama	27_V	IndPrSg3	et	rahuldab =rahulda  (IndPrSg3  >rahuldama !27_V
29664	kursuses	kursuse	kursus	11~09_S	SgIn	et	kursuses =kursuse  (SgIn  >kursus !11~09_S
29437	iseseisvumisajal	aja	ise+seisvumis+aeg	22_S	SgAd	et	iseseisvumisajal =aja  (SgAd  >ise+seisvumis+aeg !22_S
29438	omaalgatusliku	algatusliku	oma+algatuslik	25_A	SgG	et	omaalgatusliku =algatusliku  (SgG  >oma+algatuslik !25_A
29442	vabameelseid	meelse	vaba+meelne	02_A	PlP	et	vabameelseid =meelse  (PlP  >vaba+meelne !02_A
29445	pigem	pigem	pigem	41_D	ID	et	pigem =pigem  (ID  >pigem !41_D
29446	staatuse	staatuse	staatus	11~09_S	SgG	et	staatuse =staatuse  (SgG  >staatus !11~09_S
29448	poliitikutel	poliitiku	poliitik	02_S	PlAd	et	poliitikutel =poliitiku  (PlAd  >poliitik !02_S
29453	siinne	siinne	siinne	02_A	SgN	et	siinne =siinne  (SgN  >siinne !02_A
29456	öid	ö	öö	26_S	PlP	et	öid =ö  (PlP  >öö !26_S
29458	püüdis	püüd	püüdma	34_V	IndIpfSg3	et	püüdis =püüd  (IndIpfSg3  >püüdma !34_V
29459	isemajandava	majandava	ise+majandav	02_A	SgG	et	isemajandava =majandava  (SgG  >ise+majandav !02_A
29460	rahvusrinne	rinne	rahvus+rinne	06_S	SgN	et	rahvusrinne =rinne  (SgN  >rahvus+rinne !06_S
29469	taasiseseisvumine	seisvumine	taas+ise+seisvumine	12_S	SgN	et	taasiseseisvumine =seisvumine  (SgN  >taas+ise+seisvumine !12_S
29471	võimule	võimu	võim	22_S	SgAll	et	võimule =võimu  (SgAll  >võim !22_S
29472	aegses	aegse	aegne	02_A	SgIn	et	aegses =aegse  (SgIn  >aegne !02_A
29482	iseseisev	seisev	ise+seisev	02_A	SgN	et	iseseisev =seisev  (SgN  >ise+seisev !02_A
29492	magistraat	magistraat	magistraat	22_S	SgN	et	magistraat =magistraat  (SgN  >magistraat !22_S
29494	linnaelanikud	elaniku	linna+elanik	25_S	PlN	et	linnaelanikud =elaniku  (PlN  >linna+elanik !25_S
29495	gildisse	gildi	gild	22_S	SgIll	et	gildisse =gildi  (SgIll  >gild !22_S
29498	sakslased	sakslase	sakslane	12?10_S	PlN	et	sakslased =sakslase  (PlN  >sakslane !12?10_S
29508	hooga	hoo	hoog	22_S	SgKom	et	hooga =hoo  (SgKom  >hoog !22_S
29509	valmistub	valmistu	valmistuma	27_V	IndPrSg3	et	valmistub =valmistu  (IndPrSg3  >valmistuma !27_V
29511	une	une	uni	20_S	SgG	et	une =une  (SgG  >uni !20_S
29512	difteeriad	difteeria	difteeria	01_S	PlN	et	difteeriad =difteeria  (PlN  >difteeria !01_S
29513	konkursi	konkursi	konkurss	22_S	SgG	et	konkursi =konkursi  (SgG  >konkurss !22_S
29516	elaks	ela	elama	27_V	KndPrPs	et	elaks =ela  (KndPrPs  >elama !27_V
29518	spordist	spordi	sport	22_S	SgEl	et	spordist =spordi  (SgEl  >sport !22_S
29523	mahlakaselt	kase	mahla+kask	22_S	SgAbl	et	mahlakaselt =kase  (SgAbl  >mahla+kask !22_S
29524	aktsendita	aktsendi	aktsent	22_S	SgAb	et	aktsendita =aktsendi  (SgAb  >aktsent !22_S
29532	jõudes	jõud	jõudma	34_V	Ger	et	jõudes =jõud  (Ger  >jõudma !34_V
29535	ülekoormuse	koormuse	üle+koormus	11~09_S	SgG	et	ülekoormuse =koormuse  (SgG  >üle+koormus !11~09_S
29539	pükstesse	püks	püks	23_S	PlIll	et	pükstesse =püks  (PlIll  >püks !23_S
29543	saadakse	saa	saama	37_V	IndPrIps	et	saadakse =saa  (IndPrIps  >saama !37_V
29544	pükstes	püks	püks	23_S	PlIn	et	pükstes =püks  (PlIn  >püks !23_S
29545	alevik	alevik	alevik	25_S	SgN	et	alevik =alevik  (SgN  >alevik !25_S
29565	sektsioon	sektsioon	sektsioon	22_S	SgN	et	sektsioon =sektsioon  (SgN  >sektsioon !22_S
29566	objektile	objekti	objekt	22_S	SgAll	et	objektile =objekti  (SgAll  >objekt !22_S
29574	sektsioonid	sektsiooni	sektsioon	22_S	PlN	et	sektsioonid =sektsiooni  (PlN  >sektsioon !22_S
29578	andurile	anduri	andur	02_S	SgAll	et	andurile =anduri  (SgAll  >andur !02_S
29582	z-le	z	z	xx_Q	SgAll	et	z-le =z  (SgAll  >z !xx_Q
29584	kordpidajale	pidaja	kord+pidaja	01_S	SgAll	et	kordpidajale =pidaja  (SgAll  >kord+pidaja !01_S
29587	alkohooli	hool	alko+hool	13_S	PlP	et	alkohooli =hool  (PlP  >alko+hool !13_S
29591	ümbermineku	mineku	ümber+minek	02_S	SgG	et	ümbermineku =mineku  (SgG  >ümber+minek !02_S
29594	eelõhtul	õhtu	eel+õhtu	01_S	SgAd	et	eelõhtul =õhtu  (SgAd  >eel+õhtu !01_S
29601	tase	tase	tase	04_S	SgN	et	tase =tase  (SgN  >tase !04_S
29609	aadliga	aadli	aadel	02_S	SgKom	et	aadliga =aadli  (SgKom  >aadel !02_S
29612	rahvastik	rahvastik	rahvastik	25_S	SgN	et	rahvastik =rahvastik  (SgN  >rahvastik !25_S
29614	tööstuslik	tööstuslik	tööstuslik	25_A	SgN	et	tööstuslik =tööstuslik  (SgN  >tööstuslik !25_A
29619	masinatööstus	tööstus	masina+tööstus	11~09_S	SgN	et	masinatööstus =tööstus  (SgN  >masina+tööstus !11~09_S
29629	asendati	asenda	asendama	27_V	IndIpfIps	et	asendati =asenda  (IndIpfIps  >asendama !27_V
29638	revolutsioonist	revolutsiooni	revolutsioon	22_S	SgEl	et	revolutsioonist =revolutsiooni  (SgEl  >revolutsioon !22_S
29639	kirjandusorganisatsioon	organisatsioon	kirjandus+organisatsioon	22_S	SgN	et	kirjandusorganisatsioon =organisatsioon  (SgN  >kirjandus+organisatsioon !22_S
29640	tutvustada	tutvusta	tutvustama	27_V	Inf	et	tutvustada =tutvusta  (Inf  >tutvustama !27_V
29642	haridustingimused	tingimuse	haridus+tingimus	11_S	PlN	et	haridustingimused =tingimuse  (PlN  >haridus+tingimus !11_S
29526	ülekoormusele	koormuse	üle+koormus	11~09_S	SgAll	et	ülekoormusele =koormuse  (SgAll  >üle+koormus !11~09_S
29528	ilusatest	ilusa	ilus	02_A	PlEl	et	ilusatest =ilusa  (PlEl  >ilus !02_A
29529	autodest	auto	auto	16_S	PlEl	et	autodest =auto  (PlEl  >auto !16_S
29534	tagajärje	järje	taga+järg	22_S	SgG	et	tagajärje =järje  (SgG  >taga+järg !22_S
29537	hingatakse	hinga	hingama	29_V	IndPrIps	et	hingatakse =hinga  (IndPrIps  >hingama !29_V
29541	aineid	aine	aine	06_S	PlP	et	aineid =aine  (PlP  >aine !06_S
29542	raamatutega	raamatu	raamat	02_S	PlKom	et	raamatutega =raamatu  (PlKom  >raamat !02_S
29554	lülitas	lülita	lülitama	27_V	IndIpfSg3	et	lülitas =lülita  (IndIpfSg3  >lülitama !27_V
29560	valvurit	valvuri	valvur	02_S	SgP	et	valvurit =valvuri  (SgP  >valvur !02_S
29568	selgitas	selgita	selgitama	27_V	IndIpfSg3	et	selgitas =selgita  (IndIpfSg3  >selgitama !27_V
29570	kehaehitusega	ehituse	keha+ehitus	11_S	SgKom	et	kehaehitusega =ehituse  (SgKom  >keha+ehitus !11_S
29575	spetsiaalset	spetsiaalse	spetsiaalne	02_A	SgP	et	spetsiaalset =spetsiaalse  (SgP  >spetsiaalne !02_A
29583	märkis	märki	märkima	28_V	IndIpfSg3	et	märkis =märki  (IndIpfSg3  >märkima !28_V
29586	patrull	patrull	patrull	22_S	SgN	et	patrull =patrull  (SgN  >patrull !22_S
29593	viiner	viiner	viiner	02_S	SgN	et	viiner =viiner  (SgN  >viiner !02_S
29603	rahumeelsete	meelse	rahu+meelne	02_A	PlG	et	rahumeelsete =meelse  (PlG  >rahu+meelne !02_A
29606	demokraatlikke	demokraatlikke	demokraatlik	25_A	PlP	et	demokraatlikke =demokraatlikke  (PlP  >demokraatlik !25_A
29616	mittetootlik	tootlik	mitte+tootlik	25_A	SgN	et	mittetootlik =tootlik  (SgN  >mitte+tootlik !25_A
29626	autorid	autori	autor	02_S	PlN	et	autorid =autori  (PlN  >autor !02_S
29628	asualad	ala	asu+ala	17_S	PlN	et	asualad =ala  (PlN  >asu+ala !17_S
29631	otsustati	otsusta	otsustama	27_V	IndIpfIps	et	otsustati =otsusta  (IndIpfIps  >otsustama !27_V
29633	päts	päts	päts	22_S	SgN	et	päts =päts  (SgN  >päts !22_S
29643	tekis	teki	tekk	22_S	SgIn	et	tekis =teki  (SgIn  >tekk !22_S
29651	otsustada	otsusta	otsustama	27_V	Inf	et	otsustada =otsusta  (Inf  >otsustama !27_V
29656	raskesti	raskesti	raskesti	41_D	ID	et	raskesti =raskesti  (ID  >raskesti !41_D
29657	maailmasõjal	sõja	maa+ilma+sõda	18_S	SgAd	et	maailmasõjal =sõja  (SgAd  >maa+ilma+sõda !18_S
29660	vajadusi	vajadusi	vajadus	11_S	PlP	et	vajadusi =vajadusi  (PlP  >vajadus !11_S
29670	väärtused	väärtuse	väärtus	11~09_S	PlN	et	väärtused =väärtuse  (PlN  >väärtus !11~09_S
29672	keskkonnas	keskkonna	keskkond	22_S	SgIn	et	keskkonnas =keskkonna  (SgIn  >keskkond !22_S
29673	esialgu	esialgu	esi+algu	41_D	ID	et	esialgu =esialgu  (ID  >esi+algu !41_D
29677	iseendal	enda	ise+enda	00_P	SgAd	et	iseendal =enda  (SgAd  >ise+enda !00_P
29680	tegeleda	tegele	tegelema	27_V	Inf	et	tegeleda =tegele  (Inf  >tegelema !27_V
29685	spordiga	spordi	sport	22_S	SgKom	et	spordiga =spordi  (SgKom  >sport !22_S
29688	kelleta	kelle	kes	00_P	SgAb	et	kelleta =kelle  (SgAb  >kes !00_P
29689	pidutseme	pidutse	pidutsema	27_V	IndPrPl1	et	pidutseme =pidutse  (IndPrPl1  >pidutsema !27_V
29695	keeleoskusi	oskusi	keele+oskus	11_S	PlP	et	keeleoskusi =oskusi  (PlP  >keele+oskus !11_S
29697	firmad	firma	firma	16_S	PlN	et	firmad =firma  (PlN  >firma !16_S
29699	keskmise	keskmise	keskmine	12?10_A	SgG	et	keskmise =keskmise  (SgG  >keskmine !12?10_A
29711	puhkame	puhka	puhkama	29_V	IndPrPl1	et	puhkame =puhka  (IndPrPl1  >puhkama !29_V
29713	õhkus	õhku	õhkuma	27_V	IndIpfSg3	et	õhkus =õhku  (IndIpfSg3  >õhkuma !27_V
29717	toetada	toeta	toetama	27_V	Inf	et	toetada =toeta  (Inf  >toetama !27_V
29719	korteri	korteri	korter	02_S	SgG	et	korteri =korteri  (SgG  >korter !02_S
29727	hädavajaliku	vajaliku	häda+vajalik	25_A	SgG	et	hädavajaliku =vajaliku  (SgG  >häda+vajalik !25_A
29730	jõuan	jõua	jõudma	34_V	IndPrSg1	et	jõuan =jõua  (IndPrSg1  >jõudma !34_V
29735	raamatupidajat	pidaja	raamatu+pidaja	01_S	SgP	et	raamatupidajat =pidaja  (SgP  >raamatu+pidaja !01_S
29736	ettevõtteid	võtte	ette+võte	06_S	PlP	et	ettevõtteid =võtte  (PlP  >ette+võte !06_S
29738	vastan	vasta	vastama	29_V	IndPrSg1	et	vastan =vasta  (IndPrSg1  >vastama !29_V
29740	töötan	tööta	töötama	27_V	IndPrSg1	et	töötan =tööta  (IndPrSg1  >töötama !27_V
29749	haridusega	hariduse	haridus	11_S	SgKom	et	haridusega =hariduse  (SgKom  >haridus !11_S
29752	tööturul	turu	töö+turg	22_S	SgAd	et	tööturul =turu  (SgAd  >töö+turg !22_S
29763	korterit	korteri	korter	02_S	SgP	et	korterit =korteri  (SgP  >korter !02_S
29766	sinul	sinu	sina	00_P	SgAd	et	sinul =sinu  (SgAd  >sina !00_P
29767	kollektiivis	kollektiivi	kollektiiv	22_S	SgIn	et	kollektiivis =kollektiivi  (SgIn  >kollektiiv !22_S
29773	mobiiltelefon	telefon	mobiil+telefon	19_S	SgN	et	mobiiltelefon =telefon  (SgN  >mobiil+telefon !19_S
29557	ringkäik	käik	ring+käik	22_S	SgN	et	ringkäik =käik  (SgN  >ring+käik !22_S
29558	signalisatsioon	signalisatsioon	signalisatsioon	22_S	SgN	et	signalisatsioon =signalisatsioon  (SgN  >signalisatsioon !22_S
29559	veeretas	veereta	veeretama	27_V	IndIpfSg3	et	veeretas =veereta  (IndIpfSg3  >veeretama !27_V
29561	viskas	viska	viskama	29_V	IndIpfSg3	et	viskas =viska  (IndIpfSg3  >viskama !29_V
29563	saatis	saat	saatma	34_V	IndIpfSg3	et	saatis =saat  (IndIpfSg3  >saatma !34_V
29567	avastada	avasta	avastama	27_V	Inf	et	avastada =avasta  (Inf  >avastama !27_V
29571	riietud	riietu	riietuma	27_V	IndPrSg2	et	riietud =riietu  (IndPrSg2  >riietuma !27_V
29576	keskmisel	keskmise	keskmine	12?10_A	SgAd	et	keskmisel =keskmise  (SgAd  >keskmine !12?10_A
29590	vahetab	vaheta	vahetama	27_V	IndPrSg3	et	vahetab =vaheta  (IndPrSg3  >vahetama !27_V
29596	juhtumit	juhtumi	juhtum	02_S	SgP	et	juhtumit =juhtumi  (SgP  >juhtum !02_S
29597	lugupidamisega	pidamise	lugu+pidamine	12_S	SgKom	et	lugupidamisega =pidamise  (SgKom  >lugu+pidamine !12_S
29602	madalaks	madala	madal	02_AS	SgTr	et	madalaks =madala  (SgTr  >madal !02_AS
29604	demonstrantide	demonstranti	demonstrant	22_S	PlG	et	demonstrantide =demonstranti  (PlG  >demonstrant !22_S
29607	suurendati	suurenda	suurendama	27_V	IndIpfIps	et	suurendati =suurenda  (IndIpfIps  >suurendama !27_V
29611	põllumajanduslik	majanduslik	põllu+majanduslik	25_A	SgN	et	põllumajanduslik =majanduslik  (SgN  >põllu+majanduslik !25_A
29613	vähenes	vähene	vähenema	27_V	IndIpfSg3	et	vähenes =vähene  (IndIpfSg3  >vähenema !27_V
29617	elualadel	ala	elu+ala	17_S	PlAd	et	elualadel =ala  (PlAd  >elu+ala !17_S
29632	kehtestada	kehtesta	kehtestama	27_V	Inf	et	kehtestada =kehtesta  (Inf  >kehtestama !27_V
29634	kokkuvarisemisel	varisemise	kokku+varisemine	12_S	SgAd	et	kokkuvarisemisel =varisemise  (SgAd  >kokku+varisemine !12_S
29635	tulemusena	tulemuse	tulemus	11_S	SgEs	et	tulemusena =tulemuse  (SgEs  >tulemus !11_S
29637	pärastsõjajärgne	järgne	pärast+sõja+järgne	02_A	SgN	et	pärastsõjajärgne =järgne  (SgN  >pärast+sõja+järgne !02_A
29645	populaarne	populaarne	populaarne	02_A	SgN	et	populaarne =populaarne  (SgN  >populaarne !02_A
29649	sovhoose	sovhoose	sovhoos	22_S	PlP	et	sovhoose =sovhoose  (PlP  >sovhoos !22_S
29654	elanikust	elaniku	elanik	25_S	SgEl	et	elanikust =elaniku  (SgEl  >elanik !25_S
29658	esimesel	esimese	esimene	12_OP	SgAd	et	esimesel =esimese  (SgAd  >esimene !12_OP
29663	lemmikraamatuteta	raamatu	lemmik+raamat	02_S	PlAb	et	lemmikraamatuteta =raamatu  (PlAb  >lemmik+raamat !02_S
29665	püsida	püsi	püsima	27_V	Inf	et	püsida =püsi  (Inf  >püsima !27_V
29667	laua	laua	laud	22_S	SgG	et	laua =laua  (SgG  >laud !22_S
29669	minul	minu	mina	00_P	SgAd	et	minul =minu  (SgAd  >mina !00_P
29671	elame	ela	elama	27_V	IndPrPl1	et	elame =ela  (IndPrPl1  >elama !27_V
29684	toitlustasime	toitlusta	toitlustama	27_V	IndIpfPl1	et	toitlustasime =toitlusta  (IndIpfPl1  >toitlustama !27_V
29701	õnnelik	õnnelik	õnnelik	25_A	SgN	et	õnnelik =õnnelik  (SgN  >õnnelik !25_A
29702	tais	tai	tai	26_S	SgIn	et	tais =tai  (SgIn  >tai !26_S
29703	rõõmustada	rõõmusta	rõõmustama	27_V	Inf	et	rõõmustada =rõõmusta  (Inf  >rõõmustama !27_V
29705	muutakse	takse	muu+taks	22_S	PlP	et	muutakse =takse  (PlP  >muu+taks !22_S
29706	käesoleval	oleva	käes+olev	02_A	SgAd	et	käesoleval =oleva  (SgAd  >käes+olev !02_A
29707	vabariigis	riigi	vaba+riik	22_S	SgIn	et	vabariigis =riigi  (SgIn  >vaba+riik !22_S
29708	samamoodi	samamoodi	sama+moodi	41_D	ID	et	samamoodi =samamoodi  (ID  >sama+moodi !41_D
29709	arendada	arenda	arendama	27_V	Inf	et	arendada =arenda  (Inf  >arendama !27_V
29714	ujume	uju	ujuma	27_V	IndPrPl1	et	ujume =uju  (IndPrPl1  >ujuma !27_V
29720	riideid	riide	riie	06_S	PlP	et	riideid =riide  (PlP  >riie !06_S
29721	kinno	kinno	kino	17_S	SgAdt	et	kinno =kinno  (SgAdt  >kino !17_S
29725	tervise	tervise	tervis	09~11_S	SgG	et	tervise =tervise  (SgG  >tervis !09~11_S
29732	aegsel	aegse	aegne	02_A	SgAd	et	aegsel =aegse  (SgAd  >aegne !02_A
29741	arvutioperaatorina	operaatori	arvuti+operaator	02_S	SgEs	et	arvutioperaatorina =operaatori  (SgEs  >arvuti+operaator !02_S
29745	halb	halb	halb	22_A	SgN	et	halb =halb  (SgN  >halb !22_A
29755	invaliidide	invaliidi	invaliid	22_S	PlG	et	invaliidide =invaliidi  (PlG  >invaliid !22_S
29757	raamatut	raamatu	raamat	02_S	SgP	et	raamatut =raamatu  (SgP  >raamat !02_S
29764	seisneb	seisne	seisnema	27_V	IndPrSg3	et	seisneb =seisne  (IndPrSg3  >seisnema !27_V
29769	kvaliteetne	kvaliteetne	kvaliteetne	02_A	SgN	et	kvaliteetne =kvaliteetne  (SgN  >kvaliteetne !02_A
29770	keeleoskus	oskus	keele+oskus	11~09_S	SgN	et	keeleoskus =oskus  (SgN  >keele+oskus !11~09_S
29771	tekitab	tekita	tekitama	27_V	IndPrSg3	et	tekitab =tekita  (IndPrSg3  >tekitama !27_V
29772	peres	pere	pere	16_S	SgIn	et	peres =pere  (SgIn  >pere !16_S
29776	puhtaks	puhta	puhas	07_A	SgTr	et	puhtaks =puhta  (SgTr  >puhas !07_A
29569	sportliku	sportliku	sportlik	25_A	SgG	et	sportliku =sportliku  (SgG  >sportlik !25_A
29572	tumedas	tumeda	tume	02_A	SgIn	et	tumedas =tumeda  (SgIn  >tume !02_A
29577	mittesaavutav	saavutav	mitte+saavutav	02_A	SgN	et	mittesaavutav =saavutav  (SgN  >mitte+saavutav !02_A
29579	kurjategijale	tegija	kurja+tegija	01_S	SgAll	et	kurjategijale =tegija  (SgAll  >kurja+tegija !01_S
29581	valvurile	valvuri	valvur	02_S	SgAll	et	valvurile =valvuri  (SgAll  >valvur !02_S
29585	patrull	patrull	patrull	22_S	SgN	et	patrull =patrull  (SgN  >patrull !22_S
29588	joobetunnustega	tunnus	joobe+tunnus	09_S	PlKom	et	joobetunnustega =tunnus  (PlKom  >joobe+tunnus !09_S
29592	seinalt	seina	sein	23?22_S	SgAbl	et	seinalt =seina  (SgAbl  >sein !23?22_S
29595	samasugust	sugus	sama+sugune	10_P	SgP	et	samasugust =sugus  (SgP  >sama+sugune !10_P
29598	turvateenistus	teenistus	turva+teenistus	11_S	SgN	et	turvateenistus =teenistus  (SgN  >turva+teenistus !11_S
29599	poliitilised	poliitilise	poliitiline	12_A	PlN	et	poliitilised =poliitilise  (PlN  >poliitiline !12_A
29605	manifest	manifest	manifest	22_S	SgN	et	manifest =manifest  (SgN  >manifest !22_S
29610	võrdseid	võrdse	võrdne	02_A	PlP	et	võrdseid =võrdse  (PlP  >võrdne !02_A
29621	majanduslikud	majandusliku	majanduslik	25_A	PlN	et	majanduslikud =majandusliku  (PlN  >majanduslik !25_A
29623	tarbekaupade	kaupa	tarbe+kaup	22_S	PlG	et	tarbekaupade =kaupa  (PlG  >tarbe+kaup !22_S
29624	teadlasi	teadlasi	teadlane	12_S	PlP	et	teadlasi =teadlasi  (PlP  >teadlane !12_S
29627	kubermangukomissar	komissar	kubermangu+komissar	19_S	SgN	et	kubermangukomissar =komissar  (SgN  >kubermangu+komissar !19_S
29636	kirjutati	kirjuta	kirjutama	27_V	IndIpfIps	et	kirjutati =kirjuta  (IndIpfIps  >kirjutama !27_V
29644	haritlaskond	haritlaskond	haritlaskond	22_S	SgN	et	haritlaskond =haritlaskond  (SgN  >haritlaskond !22_S
29652	saatuse	saatuse	saatus	11~09_S	SgG	et	saatuse =saatuse  (SgG  >saatus !11~09_S
29653	kaotas	kaota	kaotama	27_V	IndIpfSg3	et	kaotas =kaota  (IndIpfSg3  >kaotama !27_V
29655	maast	maa	maa	26_S	SgEl	et	maast =maa  (SgEl  >maa !26_S
29661	tervis	tervis	tervis	09~11_S	SgN	et	tervis =tervis  (SgN  >tervis !09~11_S
29666	huvitan	huvita	huvitama	27_V	IndPrSg1	et	huvitan =huvita  (IndPrSg1  >huvitama !27_V
29668	abikaasal	kaasa	abi+kaasa	16_S	SgAd	et	abikaasal =kaasa  (SgAd  >abi+kaasa !16_S
29683	toitlustada	toitlusta	toitlustama	27_V	Inf	et	toitlustada =toitlusta  (Inf  >toitlustama !27_V
29690	sünnipäevad	päeva	sünni+päev	22_S	PlN	et	sünnipäevad =päeva  (PlN  >sünni+päev !22_S
29698	keelte	keel	keel	13_S	PlG	et	keelte =keel  (PlG  >keel !13_S
29700	mängib	mängi	mängima	28_V	IndPrSg3	et	mängib =mängi  (IndPrSg3  >mängima !28_V
29712	jalutame	jaluta	jalutama	27_V	IndPrPl1	et	jalutame =jaluta  (IndPrPl1  >jalutama !27_V
29715	saartel	saar	saar	13_S	PlAd	et	saartel =saar  (PlAd  >saar !13_S
29722	sõprade	sõpra	sõber	24_S	PlG	et	sõprade =sõpra  (PlG  >sõber !24_S
29724	probleeme	probleeme	probleem	22_S	PlP	et	probleeme =probleeme  (PlP  >probleem !22_S
29726	võimaliku	võimaliku	võimalik	25_A	SgG	et	võimaliku =võimaliku  (SgG  >võimalik !25_A
29731	valdab	valda	valdama	29_V	IndPrSg3	et	valdab =valda  (IndPrSg3  >valdama !29_V
29742	uudiseid	uudise	uudis	09_S	PlP	et	uudiseid =uudise  (PlP  >uudis !09_S
29747	toidu	toidu	toit	22_S	SgG	et	toidu =toidu  (SgG  >toit !22_S
29753	tervisega	tervise	tervis	09~11_S	SgKom	et	tervisega =tervise  (SgKom  >tervis !09~11_S
29761	tõuseb	tõuse	tõusma	32_V	IndPrSg3	et	tõuseb =tõuse  (IndPrSg3  >tõusma !32_V
29762	kohvikus	kohviku	kohvik	02_S	SgIn	et	kohvikus =kohviku  (SgIn  >kohvik !02_S
29768	sulle	su	sa	00_P	SgAll	et	sulle =su  (SgAll  >sa !00_P
29775	rahulik	rahulik	rahulik	25_A	SgN	et	rahulik =rahulik  (SgN  >rahulik !25_A
29784	staadionil	staadioni	staadion	19~02_S	SgAd	et	staadionil =staadioni  (SgAd  >staadion !19~02_S
29790	seadusi	seadusi	seadus	11_S	PlP	et	seadusi =seadusi  (PlP  >seadus !11_S
29793	täpne	täpne	täpne	02_A	SgN	et	täpne =täpne  (SgN  >täpne !02_A
29797	inimesena	inimese	inimene	12_S	SgEs	et	inimesena =inimese  (SgEs  >inimene !12_S
29810	artikleid	artikle	artikkel	02_S	PlP	et	artikleid =artikle  (PlP  >artikkel !02_S
29814	eksameid	eksame	eksam	02_S	PlP	et	eksameid =eksame  (PlP  >eksam !02_S
29816	auditooriumis	auditooriumi	auditoorium	19~02_S	SgIn	et	auditooriumis =auditooriumi  (SgIn  >auditoorium !19~02_S
29818	ravivõimlemise	võimlemise	ravi+võimlemine	12_S	SgG	et	ravivõimlemise =võimlemise  (SgG  >ravi+võimlemine !12_S
29823	spordipüksid	püksi	spordi+püks	23?22_S	PlN	et	spordipüksid =püksi  (PlN  >spordi+püks !23?22_S
29827	optimistlik	optimistlik	optimistlik	25_A	SgN	et	optimistlik =optimistlik  (SgN  >optimistlik !25_A
29831	suurte	suur	suur	13_A	PlG	et	suurte =suur  (PlG  >suur !13_A
29834	ettevaatust	vaatus	ette+vaatus	11~09_S	SgP	et	ettevaatust =vaatus  (SgP  >ette+vaatus !11~09_S
29646	munderi	munderi	munder	02_S	SgG	et	munderi =munderi  (SgG  >munder !02_S
29648	sulgeda	sulge	sulgema	27~28_V	Inf	et	sulgeda =sulge  (Inf  >sulgema !27~28_V
29650	niisugusel	suguse	nii+sugune	10_P	SgAd	et	niisugusel =suguse  (SgAd  >nii+sugune !10_P
29662	sõpradeta	sõpra	sõber	24_S	PlAb	et	sõpradeta =sõpra  (PlAb  >sõber !24_S
29679	kõrghariduse	hariduse	kõrg+haridus	11_S	SgG	et	kõrghariduse =hariduse  (SgG  >kõrg+haridus !11_S
29681	lemmiku	lemmiku	lemmik	02_S	SgG	et	lemmiku =lemmiku  (SgG  >lemmik !02_S
29682	teatris	teatri	teater	02_S	SgIn	et	teatris =teatri  (SgIn  >teater !02_S
29693	ümbritseb	ümbritse	ümbritsema	27_V	IndPrSg3	et	ümbritseb =ümbritse  (IndPrSg3  >ümbritsema !27_V
29694	võrkkeelte	keel	võrk+keel	13_S	PlG	et	võrkkeelte =keel  (PlG  >võrk+keel !13_S
29696	tööostjate	ostja	töö+ostja	01_S	PlG	et	tööostjate =ostja  (PlG  >töö+ostja !01_S
29710	terviseta	tervise	tervis	09~11_S	SgAb	et	terviseta =tervise  (SgAb  >tervis !09~11_S
29716	hoidma	hoid	hoidma	34_V	Sup	et	hoidma =hoid  (Sup  >hoidma !34_V
29723	arutada	aruta	arutama	27_V	Inf	et	arutada =aruta  (Inf  >arutama !27_V
29733	kasutab	kasuta	kasutama	27_V	IndPrSg3	et	kasutab =kasuta  (IndPrSg3  >kasutama !27_V
29737	saadeti	saade	saatma	34_V	IndIpfIps	et	saadeti =saade  (IndIpfIps  >saatma !34_V
29739	ootame	oota	ootama	29_V	IndPrPl1	et	ootame =oota  (IndPrPl1  >ootama !29_V
29743	sõidame	sõida	sõitma	34_V	IndPrPl1	et	sõidame =sõida  (IndPrPl1  >sõitma !34_V
29750	sinult	sinu	sina	00_P	SgAbl	et	sinult =sinu  (SgAbl  >sina !00_P
29760	paneksin	pane	panema	36_V	KndPrSg1	et	paneksin =pane  (KndPrSg1  >panema !36_V
29778	sportlane	sportlane	sportlane	12?10_S	SgN	et	sportlane =sportlane  (SgN  >sportlane !12?10_S
29781	osalema	osale	osalema	27_V	Sup	et	osalema =osale  (Sup  >osalema !27_V
29782	töövahendid	vahendi	töö+vahend	02_S	PlN	et	töövahendid =vahendi  (PlN  >töö+vahend !02_S
29785	spordisaalis	saali	spordi+saal	22_S	SgIn	et	spordisaalis =saali  (SgIn  >spordi+saal !22_S
29794	juhib	juhi	juhtima	28_V	IndPrSg3	et	juhib =juhi  (IndPrSg3  >juhtima !28_V
29801	vahendid	vahendi	vahend	02_S	PlN	et	vahendid =vahendi  (PlN  >vahend !02_S
29802	paber	paber	paber	02_S	SgN	et	paber =paber  (SgN  >paber !02_S
29807	kõmuuudiste	uudis	kõmu+uudis	09_S	PlG	et	kõmuuudiste =uudis  (PlG  >kõmu+uudis !09_S
29813	suhtlemisoskust	oskus	suhtlemis+oskus	11~09_S	SgP	et	suhtlemisoskust =oskus  (SgP  >suhtlemis+oskus !11~09_S
29819	ujulas	ujula	ujula	01_S	SgIn	et	ujulas =ujula  (SgIn  >ujula !01_S
29822	ülesandeid	ande	üles+anne	06_S	PlP	et	ülesandeid =ande  (PlP  >üles+anne !06_S
29824	t-särk	särk	t-särk	22_S	SgN	et	t-särk =särk  (SgN  >t-särk !22_S
29826	meeldima	meeldi	meeldima	27_V	Sup	et	meeldima =meeldi  (Sup  >meeldima !27_V
29829	probleemidest	probleemi	probleem	22_S	PlEl	et	probleemidest =probleemi  (PlEl  >probleem !22_S
29830	haiglas	haigla	haigla	01_S	SgIn	et	haiglas =haigla  (SgIn  >haigla !01_S
29836	kombet	kombe	kombe	06_S	SgP	et	kombet =kombe  (SgP  >kombe !06_S
29841	edukaks	eduka	edukas	02_A	SgTr	et	edukaks =eduka  (SgTr  >edukas !02_A
29844	kliendi	kliendi	klient	22_S	SgG	et	kliendi =kliendi  (SgG  >klient !22_S
29845	oskused	oskuse	oskus	11~09_S	PlN	et	oskused =oskuse  (PlN  >oskus !11~09_S
29850	erafirmas	firma	era+firma	16_S	SgIn	et	erafirmas =firma  (SgIn  >era+firma !16_S
29860	plastiliin	plastiliin	plastiliin	22_S	SgN	et	plastiliin =plastiliin  (SgN  >plastiliin !22_S
29861	betoon	betoon	betoon	22_S	SgN	et	betoon =betoon  (SgN  >betoon !22_S
29869	kohustuslikuna	kohustusliku	kohustuslik	25_A	SgEs	et	kohustuslikuna =kohustusliku  (SgEs  >kohustuslik !25_A
29873	puhast	puhas	puhas	07_A	SgP	et	puhast =puhas  (SgP  >puhas !07_A
29878	valvab	valva	valvama	29_V	IndPrSg3	et	valvab =valva  (IndPrSg3  >valvama !29_V
29894	lõpetasin	lõpeta	lõpetama	27_V	IndIpfSg1	et	lõpetasin =lõpeta  (IndIpfSg1  >lõpetama !27_V
29895	paekaare	kaare	pae+kaar	13_S	SgG	et	paekaare =kaare  (SgG  >pae+kaar !13_S
29897	tuhande	tuhande	tuhat	02_N	SgG	et	tuhande =tuhande  (SgG  >tuhat !02_N
29901	veedan	veeda	veetma	34_V	IndPrSg1	et	veedan =veeda  (IndPrSg1  >veetma !34_V
29907	tulen	tule	tulema	36_V	IndPrSg1	et	tulen =tule  (IndPrSg1  >tulema !36_V
29917	autojuhatamine	juhatamine	auto+juhatamine	12_S	SgN	et	autojuhatamine =juhatamine  (SgN  >auto+juhatamine !12_S
29920	muljet	mulje	mulje	06_S	SgP	et	muljet =mulje  (SgP  >mulje !06_S
29926	telliskive	kive	tellis+kivi	17_S	PlP	et	telliskive =kive  (PlP  >tellis+kivi !17_S
29930	juhtuda	juhtu	juhtuma	27_V	Inf	et	juhtuda =juhtu  (Inf  >juhtuma !27_V
29934	mõjustab	mõjusta	mõjustama	27_V	IndPrSg3	et	mõjustab =mõjusta  (IndPrSg3  >mõjustama !27_V
29935	süveneda	süvene	süvenema	27_V	Inf	et	süveneda =süvene  (Inf  >süvenema !27_V
29674	arvestama	arvesta	arvestama	27_V	Sup	et	arvestama =arvesta  (Sup  >arvestama !27_V
29675	tänavu	tänavu	tänavu	41_D	ID	et	tänavu =tänavu  (ID  >tänavu !41_D
29676	hariduseta	hariduse	haridus	11_S	SgAb	et	hariduseta =hariduse  (SgAb  >haridus !11_S
29678	omada	oma	omama	27_V	Inf	et	omada =oma  (Inf  >omama !27_V
29686	jätkub	jätku	jätkuma	27_V	IndPrSg3	et	jätkub =jätku  (IndPrSg3  >jätkuma !27_V
29687	hobiga	hobi	hobi	17_S	SgKom	et	hobiga =hobi  (SgKom  >hobi !17_S
29691	pereta	pere	pere	16_S	SgAb	et	pereta =pere  (SgAb  >pere !16_S
29692	selleta	selle	see	00_P	SgAb	et	selleta =selle  (SgAb  >see !00_P
29704	elude	elu	elu	17_S	PlG	et	elude =elu  (PlG  >elu !17_S
29718	instituudis	instituudi	instituut	22_S	SgIn	et	instituudis =instituudi  (SgIn  >instituut !22_S
29728	autodeta	auto	auto	16_S	PlAb	et	autodeta =auto  (PlAb  >auto !16_S
29729	jalad	jala	jalg	22_S	PlN	et	jalad =jala  (PlN  >jalg !22_S
29734	firmat	firma	firma	16_S	SgP	et	firmat =firma  (SgP  >firma !16_S
29744	hoiab	hoia	hoidma	34_V	IndPrSg3	et	hoiab =hoia  (IndPrSg3  >hoidma !34_V
29746	toiduainet	aine	toidu+aine	06_S	SgP	et	toiduainet =aine  (SgP  >toidu+aine !06_S
29748	perenaine	naine	pere+naine	12_S	SgN	et	perenaine =naine  (SgN  >pere+naine !12_S
29751	elate	ela	elama	27_V	IndPrPl2	et	elate =ela  (IndPrPl2  >elama !27_V
29754	reisib	reisi	reisima	28_V	IndPrSg3	et	reisib =reisi  (IndPrSg3  >reisima !28_V
29756	informatsioonita	informatsiooni	informatsioon	22_S	SgAb	et	informatsioonita =informatsiooni  (SgAb  >informatsioon !22_S
29758	mobiiltelefonita	telefoni	mobiil+telefon	19_S	SgAb	et	mobiiltelefonita =telefoni  (SgAb  >mobiil+telefon !19_S
29759	vahvad	vahva	vahva	01_A	PlN	et	vahvad =vahva  (PlN  >vahva !01_A
29765	eluviis	viis	elu+viis	22_S	SgN	et	eluviis =viis  (SgN  >elu+viis !22_S
29783	spordisisustus	sisustus	spordi+sisustus	11_S	SgN	et	spordisisustus =sisustus  (SgN  >spordi+sisustus !11_S
29792	õiglane	õiglane	õiglane	12?10_A	SgN	et	õiglane =õiglane  (SgN  >õiglane !12?10_A
29795	koostab	koosta	koostama	27_V	IndPrSg3	et	koostab =koosta  (IndPrSg3  >koostama !27_V
29798	materjale	materjale	materjal	19_S	PlP	et	materjale =materjale  (PlP  >materjal !19_S
29800	kujundab	kujunda	kujundama	27_V	IndPrSg3	et	kujundab =kujunda  (IndPrSg3  >kujundama !27_V
29805	töökohustused	kohustuse	töö+kohustus	11_S	PlN	et	töökohustused =kohustuse  (PlN  >töö+kohustus !11_S
29808	kõmuajakirjanikul	kirjaniku	kõmu+aja+kirjanik	25_S	SgAd	et	kõmuajakirjanikul =kirjaniku  (SgAd  >kõmu+aja+kirjanik !25_S
29809	rasked	raske	raske	01_A	PlN	et	rasked =raske  (PlN  >raske !01_A
29811	kabinet	kabinet	kabinet	22_S	SgN	et	kabinet =kabinet  (SgN  >kabinet !22_S
29812	kõmuajakirjaniku	kirjaniku	kõmu+aja+kirjanik	25_S	SgG	et	kõmuajakirjaniku =kirjaniku  (SgG  >kõmu+aja+kirjanik !25_S
29815	loengukonspektid	konspekti	loengu+konspekt	22_S	PlN	et	loengukonspektid =konspekti  (PlN  >loengu+konspekt !22_S
29825	treenerile	treeneri	treener	02_S	SgAll	et	treenerile =treeneri  (SgAll  >treener !02_S
29828	unustada	unusta	unustama	27_V	Inf	et	unustada =unusta  (Inf  >unustama !27_V
29833	ehitusoskusi	oskusi	ehitus+oskus	11_S	PlP	et	ehitusoskusi =oskusi  (PlP  >ehitus+oskus !11_S
29843	ametnikul	ametniku	ametnik	25_S	SgAd	et	ametnikul =ametniku  (SgAd  >ametnik !25_S
29856	joonistama	joonista	joonistama	27_V	Sup	et	joonistama =joonista  (Sup  >joonistama !27_V
29863	riigiametnik	ametnik	riigi+ametnik	25_S	SgN	et	riigiametnik =ametnik  (SgN  >riigi+ametnik !25_S
29864	paberitega	paberi	paber	02_S	PlKom	et	paberitega =paberi  (PlKom  >paber !02_S
29865	ametnikuna	ametniku	ametnik	25_S	SgEs	et	ametnikuna =ametniku  (SgEs  >ametnik !25_S
29866	intelligentne	intelligentne	intelligentne	02_A	SgN	et	intelligentne =intelligentne  (SgN  >intelligentne !02_A
29867	arst	arst	arst	22_S	SgN	et	arst =arst  (SgN  >arst !22_S
29874	töövandid	vandi	töö+vant	22_S	PlN	et	töövandid =vandi  (PlN  >töö+vant !22_S
29876	ehituskraan	kraan	ehitus+kraan	22_S	SgN	et	ehituskraan =kraan  (SgN  >ehitus+kraan !22_S
29877	tolm	tolm	tolm	22_S	SgN	et	tolm =tolm  (SgN  >tolm !22_S
29880	firmajuht	juht	firma+juht	22_S	SgN	et	firmajuht =juht  (SgN  >firma+juht !22_S
29888	abivalmis	abivalmis	abi+valmis	41_A	ID	et	abivalmis =abivalmis  (ID  >abi+valmis !41_A
29902	operatsioon	operatsioon	operatsioon	22_S	SgN	et	operatsioon =operatsioon  (SgN  >operatsioon !22_S
29903	muljed	mulje	mulje	06_S	PlN	et	muljed =mulje  (PlN  >mulje !06_S
29905	loengud	loengu	loeng	02_S	PlN	et	loengud =loengu  (PlN  >loeng !02_S
29923	madal	madal	madal	02_AS	SgN	et	madal =madal  (SgN  >madal !02_AS
29924	oleneb	olene	olenema	27_V	IndPrSg3	et	oleneb =olene  (IndPrSg3  >olenema !27_V
29932	avada	ava	avama	27_V	Inf	et	avada =ava  (Inf  >avama !27_V
29944	vened	vene	vene	16_S	PlN	et	vened =vene  (PlN  >vene !16_S
29774	ühistransport	transport	ühis+transport	22_S	SgN	et	ühistransport =transport  (SgN  >ühis+transport !22_S
29777	ametite	ameti	amet	02_S	PlG	et	ametite =ameti  (PlG  >amet !02_S
29779	treeningul	treeningu	treening	02_S	SgAd	et	treeningul =treeningu  (SgAd  >treening !02_S
29780	võistlustel	võistlus	võistlus	11~09_S	PlAd	et	võistlustel =võistlus  (PlAd  >võistlus !11~09_S
29786	jõusaalis	saali	jõu+saal	22_S	SgIn	et	jõusaalis =saali  (SgIn  >jõu+saal !22_S
29787	enesekindel	kindel	enese+kindel	02_A	SgN	et	enesekindel =kindel  (SgN  >enese+kindel !02_A
29788	sihikindel	kindel	sihi+kindel	02_A	SgN	et	sihikindel =kindel  (SgN  >sihi+kindel !02_A
29789	kohtunik	kohtunik	kohtunik	25_S	SgN	et	kohtunik =kohtunik  (SgN  >kohtunik !25_S
29791	kuulma	kuul	kuulma	33_V	Sup	et	kuulma =kuul  (Sup  >kuulma !33_V
29796	aktiivse	aktiivse	aktiivne	02_A	SgG	et	aktiivse =aktiivse  (SgG  >aktiivne !02_A
29799	projekteerib	projekteeri	projekteerima	28_V	IndPrSg3	et	projekteerib =projekteeri  (IndPrSg3  >projekteerima !28_V
29803	arhitektil	arhitekti	arhitekt	22_S	SgAd	et	arhitektil =arhitekti  (SgAd  >arhitekt !22_S
29806	kõmuajakirjanik	kirjanik	kõmu+aja+kirjanik	25_S	SgN	et	kõmuajakirjanik =kirjanik  (SgN  >kõmu+aja+kirjanik !25_S
29817	tahvel	tahvel	tahvel	02_S	SgN	et	tahvel =tahvel  (SgN  >tahvel !02_S
29821	ribad	riba	riba	17_S	PlN	et	ribad =riba  (PlN  >riba !17_S
29839	mõnedele	mõne	mõni	20_P	PlAll	et	mõnedele =mõne  (PlAll  >mõni !20_P
29840	jooksuga	jooksu	jooks	22_S	SgKom	et	jooksuga =jooksu  (SgKom  >jooks !22_S
29848	üliõpilasi	õpilasi	üli+õpilane	12_S	PlP	et	üliõpilasi =õpilasi  (PlP  >üli+õpilane !12_S
29851	toidud	toidu	toit	22_S	PlN	et	toidud =toidu  (PlN  >toit !22_S
29852	kuskil	kuskil	kuskil	41_D	ID	et	kuskil =kuskil  (ID  >kuskil !41_D
29855	kunstnikuna	kunstniku	kunstnik	25_S	SgEs	et	kunstnikuna =kunstniku  (SgEs  >kunstnik !25_S
29859	tööst	töö	töö	26_S	SgEl	et	tööst =töö  (SgEl  >töö !26_S
29872	valget	valge	valge	01_AS	SgP	et	valget =valge  (SgP  >valge !01_AS
29882	suhtlema	suhtle	suhtlema	30_V	Sup	et	suhtlema =suhtle  (Sup  >suhtlema !30_V
29885	riskantne	riskantne	riskantne	02_A	SgN	et	riskantne =riskantne  (SgN  >riskantne !02_A
29887	amet	amet	amet	02_S	SgN	et	amet =amet  (SgN  >amet !02_S
29891	terminis	termini	termin	02_S	SgIn	et	terminis =termini  (SgIn  >termin !02_S
29893	paljuga	palju	palju	16_P	SgKom	et	paljuga =palju  (SgKom  >palju !16_P
29899	mängisin	mängi	mängima	28_V	IndIpfSg1	et	mängisin =mängi  (IndIpfSg1  >mängima !28_V
29908	targad	targa	tark	22_AS	PlN	et	targad =targa  (PlN  >tark !22_AS
29910	astusin	astu	astuma	28_V	IndIpfSg1	et	astusin =astu  (IndIpfSg1  >astuma !28_V
29913	minuga	minu	mina	00_P	SgKom	et	minuga =minu  (SgKom  >mina !00_P
29927	kaheksateistkümnene	kümnene	kaheksa+teist+kümnene	10~12_AS	SgN	et	kaheksateistkümnene =kümnene  (SgN  >kaheksa+teist+kümnene !10~12_AS
29929	matemaatikat	matemaatika	matemaatika	01_S	SgP	et	matemaatikat =matemaatika  (SgP  >matemaatika !01_S
29931	raamatupidajana	pidaja	raamatu+pidaja	01_S	SgEs	et	raamatupidajana =pidaja  (SgEs  >raamatu+pidaja !01_S
29933	majandusetundjad	tundja	majanduse+tundja	01_S	PlN	et	majandusetundjad =tundja  (PlN  >majanduse+tundja !01_S
29936	suudan	suuda	suutma	34_V	IndPrSg1	et	suudan =suuda  (IndPrSg1  >suutma !34_V
29942	tehnilise	tehnilise	tehniline	12_A	SgG	et	tehnilise =tehnilise  (SgG  >tehniline !12_A
29946	valesti	valesti	valesti	41_D	ID	et	valesti =valesti  (ID  >valesti !41_D
29957	minutid	minuti	minut	02_S	PlN	et	minutid =minuti  (PlN  >minut !02_S
29971	energiat	energia	energia	01_S	SgP	et	energiat =energia  (SgP  >energia !01_S
29974	auditooriumid	auditooriumi	auditoorium	19~02_S	PlN	et	auditooriumid =auditooriumi  (PlN  >auditoorium !19~02_S
29975	korpuseid	korpuse	korpus	09_S	PlP	et	korpuseid =korpuse  (PlP  >korpus !09_S
29986	sõbraga	sõbra	sõber	24_S	SgKom	et	sõbraga =sõbra  (SgKom  >sõber !24_S
29991	iseendale	enda	ise+enda	00_P	SgAll	et	iseendale =enda  (SgAll  >ise+enda !00_P
29996	makstakse	maks	maksma	32_V	IndPrIps	et	makstakse =maks  (IndPrIps  >maksma !32_V
30007	ootab	oota	ootama	29_V	IndPrSg3	et	ootab =oota  (IndPrSg3  >ootama !29_V
30009	keeltega	keel	keel	13_S	PlKom	et	keeltega =keel  (PlKom  >keel !13_S
30012	soojustehnik	tehnik	soojus+tehnik	02_S	SgN	et	soojustehnik =tehnik  (SgN  >soojus+tehnik !02_S
30018	aitan	aita	aitama	29_V	IndPrSg1	et	aitan =aita  (IndPrSg1  >aitama !29_V
30019	fänn	fänn	fänn	22_S	SgN	et	fänn =fänn  (SgN  >fänn !22_S
30023	õismäel	mäe	õis+mägi	21_S	SgAd	et	õismäel =mäe  (SgAd  >õis+mägi !21_S
30025	jalgpallis	palli	jalg+pall	22_S	SgIn	et	jalgpallis =palli  (SgIn  >jalg+pall !22_S
30026	kümme	kümme	kümme	05_N	SgN	et	kümme =kümme  (SgN  >kümme !05_N
29804	kujund	kujund	kujund	02_S	SgN	et	kujund =kujund  (SgN  >kujund !02_S
29820	vaibad	vaiba	vaip	22_S	PlN	et	vaibad =vaiba  (PlN  >vaip !22_S
29832	teevad	tee	tegema	28_V	IndPrPl3	et	teevad =tee  (IndPrPl3  >tegema !28_V
29838	valik	valik	valik	02_S	SgN	et	valik =valik  (SgN  >valik !02_S
29842	treenima	treeni	treenima	28_V	Sup	et	treenima =treeni  (Sup  >treenima !28_V
29846	vihikud	vihiku	vihik	02_S	PlN	et	vihikud =vihiku  (PlN  >vihik !02_S
29854	sööb	söö	sööma	38_V	IndPrSg3	et	sööb =söö  (IndPrSg3  >sööma !38_V
29858	kujundada	kujunda	kujundama	27_V	Inf	et	kujundada =kujunda  (Inf  >kujundama !27_V
29879	vastutab	vastuta	vastutama	27_V	IndPrSg3	et	vastutab =vastuta  (IndPrSg3  >vastutama !27_V
29889	gps-iga	gps	gps	xx_Q	SgKom	et	gps-iga =gps  (SgKom  >gps !xx_Q
29892	töötad	tööta	töötama	27_V	IndPrSg2	et	töötad =tööta  (IndPrSg2  >töötama !27_V
29896	gümnaasium	gümnaasium	gümnaasium	19~02_S	SgN	et	gümnaasium =gümnaasium  (SgN  >gümnaasium !19~02_S
29898	kuuendal	kuuenda	kuues	02_O	SgAd	et	kuuendal =kuuenda  (SgAd  >kuues !02_O
29914	ida-virumaas	maa	ida-viru+maa	26_S	SgIn	et	ida-virumaas =maa  (SgIn  >ida-viru+maa !26_S
29915	osakondes	konde	osa+kont	22_S	PlIn	et	osakondes =konde  (PlIn  >osa+kont !22_S
29916	hobisid	hobi	hobi	17_S	PlP	et	hobisid =hobi  (PlP  >hobi !17_S
29922	võrdne	võrdne	võrdne	02_A	SgN	et	võrdne =võrdne  (SgN  >võrdne !02_A
29928	ekskursioonis	ekskursiooni	ekskursioon	22_S	SgIn	et	ekskursioonis =ekskursiooni  (SgIn  >ekskursioon !22_S
29948	riigieksamid	eksami	riigi+eksam	02_S	PlN	et	riigieksamid =eksami  (PlN  >riigi+eksam !02_S
29962	kirjutasin	kirjuta	kirjutama	27_V	IndIpfSg1	et	kirjutasin =kirjuta  (IndIpfSg1  >kirjutama !27_V
29965	ööklubis	klubi	öö+klubi	17_S	SgIn	et	ööklubis =klubi  (SgIn  >öö+klubi !17_S
29973	ttü-sse	ttü	ttü	xx_Q	SgIll	et	ttü-sse =ttü  (SgIll  >ttü !xx_Q
29976	tudengeid	tudenge	tudeng	02_S	PlP	et	tudengeid =tudenge  (PlP  >tudeng !02_S
29978	füüsikaga	füüsika	füüsika	01_S	SgKom	et	füüsikaga =füüsika  (SgKom  >füüsika !01_S
29980	võrkpallis	palli	võrk+pall	22_S	SgIn	et	võrkpallis =palli  (SgIn  >võrk+pall !22_S
29982	valin	vali	valima	27_V	IndPrSg1	et	valin =vali  (IndPrSg1  >valima !27_V
30003	muusikaga	muusika	muusika	01_S	SgKom	et	muusikaga =muusika  (SgKom  >muusika !01_S
30011	jalgpall	pall	jalg+pall	22_S	SgN	et	jalgpall =pall  (SgN  >jalg+pall !22_S
30015	tsiviilehituse	ehituse	tsiviil+ehitus	11_S	SgG	et	tsiviilehituse =ehituse  (SgG  >tsiviil+ehitus !11_S
30017	aktiivne	aktiivne	aktiivne	02_A	SgN	et	aktiivne =aktiivne  (SgN  >aktiivne !02_A
30032	vanani	vana	vana	17_AS	SgTer	et	vanani =vana  (SgTer  >vana !17_AS
30042	söön	söö	sööma	38_V	IndPrSg1	et	söön =söö  (IndPrSg1  >sööma !38_V
30050	tähistama	tähista	tähistama	27_V	Sup	et	tähistama =tähista  (Sup  >tähistama !27_V
30051	jaanuaris	jaanuari	jaanuar	19_S	SgIn	et	jaanuaris =jaanuari  (SgIn  >jaanuar !19_S
30054	koristan	korista	koristama	27_V	IndPrSg1	et	koristan =korista  (IndPrSg1  >koristama !27_V
30060	tennist	tennis	tennis	09_S	SgP	et	tennist =tennis  (SgP  >tennis !09_S
30063	käiaksin	käia	käiama	29_V	KndPrSg1	et	käiaksin =käia  (KndPrSg1  >käiama !29_V
30065	oskan	oska	oskama	29_V	IndPrSg1	et	oskan =oska  (IndPrSg1  >oskama !29_V
30066	kõndida	kõndi	kõndima	28_V	Inf	et	kõndida =kõndi  (Inf  >kõndima !28_V
30073	ilusas	ilusa	ilus	02_A	SgIn	et	ilusas =ilusa  (SgIn  >ilus !02_A
30074	tamm	tamm	tamm	22_S	SgN	et	tamm =tamm  (SgN  >tamm !22_S
30079	meeldiksin	meeldi	meeldima	27_V	KndPrSg1	et	meeldiksin =meeldi  (KndPrSg1  >meeldima !27_V
30088	hiina	hii	hii	26_S	SgEs	et	hiina =hii  (SgEs  >hii !26_S
30095	kalevi	kalevi	kalev	02_S	SgG	et	kalevi =kalevi  (SgG  >kalev !02_S
30103	alaskasse	kasse	alas+kass	22_S	PlP	et	alaskasse =kasse  (PlP  >alas+kass !22_S
30106	küllaldane	küllaldane	küllaldane	12_A	SgN	et	küllaldane =küllaldane  (SgN  >küllaldane !12_A
30110	kohtun	kohtu	kohtuma	27_V	IndPrSg1	et	kohtun =kohtu  (IndPrSg1  >kohtuma !27_V
30111	viinisse	viini	viin	22_S	SgIll	et	viinisse =viini  (SgIll  >viin !22_S
30122	omaseid	omase	omane	10_A	PlP	et	omaseid =omase  (PlP  >omane !10_A
30130	metamorfoos	metamorfoos	metamorfoos	22_S	SgN	et	metamorfoos =metamorfoos  (SgN  >metamorfoos !22_S
30140	kommunism	kommunism	kommunism	22_S	SgN	et	kommunism =kommunism  (SgN  >kommunism !22_S
30142	otsing	otsing	otsing	02_S	SgN	et	otsing =otsing  (SgN  >otsing !02_S
30145	osaks	osa	osa	17_S	SgTr	et	osaks =osa  (SgTr  >osa !17_S
30160	töödes	töö	töö	26_S	PlIn	et	töödes =töö  (PlIn  >töö !26_S
30166	kunstis	kunsti	kunst	22_S	SgIn	et	kunstis =kunsti  (SgIn  >kunst !22_S
30171	ekspressionistid	ekspressionisti	ekspressionist	22_S	PlN	et	ekspressionistid =ekspressionisti  (PlN  >ekspressionist !22_S
29835	niipalju	niipalju	nii+palju	41_D	ID	et	niipalju =niipalju  (ID  >nii+palju !41_D
29837	ilusti	ilusti	ilusti	41_D	ID	et	ilusti =ilusti  (ID  >ilusti !41_D
29847	temaga	tema	tema	00_P	SgKom	et	temaga =tema  (SgKom  >tema !00_P
29849	ärijuht	juht	äri+juht	22_S	SgN	et	ärijuht =juht  (SgN  >äri+juht !22_S
29853	ebastabiilne	stabiilne	eba+stabiilne	02_A	SgN	et	ebastabiilne =stabiilne  (SgN  >eba+stabiilne !02_A
29857	oskama	oska	oskama	29_V	Sup	et	oskama =oska  (Sup  >oskama !29_V
29862	ametnik	ametnik	ametnik	25_S	SgN	et	ametnik =ametnik  (SgN  >ametnik !25_S
29868	täpsena	täpse	täpne	02_A	SgEs	et	täpsena =täpse  (SgEs  >täpne !02_A
29870	asjatundjana	tundja	asja+tundja	01_S	SgEs	et	asjatundjana =tundja  (SgEs  >asja+tundja !01_S
29871	töövahend	vahend	töö+vahend	02_S	SgN	et	töövahend =vahend  (SgN  >töö+vahend !02_S
29875	saak	saak	saak	22_S	SgN	et	saak =saak  (SgN  >saak !22_S
29881	esinduslik	esinduslik	esinduslik	25_A	SgN	et	esinduslik =esinduslik  (SgN  >esinduslik !25_A
29883	igaks	iga	iga	17_P	SgTr	et	igaks =iga  (SgTr  >iga !17_P
29884	olukorraks	korra	olu+kord	22_S	SgTr	et	olukorraks =korra  (SgTr  >olu+kord !22_S
29886	kogemuste	kogemus	kogemus	11_S	PlG	et	kogemuste =kogemus  (PlG  >kogemus !11_S
29890	maapinna	pinna	maa+pind	22_S	SgG	et	maapinna =pinna  (SgG  >maa+pind !22_S
29900	viiuli	viiuli	viiul	02_S	SgG	et	viiuli =viiuli  (SgG  >viiul !02_S
29904	lektorid	lektori	lektor	02_S	PlN	et	lektorid =lektori  (PlN  >lektor !02_S
29906	elasin	ela	elama	27_V	IndIpfSg1	et	elasin =ela  (IndIpfSg1  >elama !27_V
29909	töötasin	tööta	töötama	27_V	IndIpfSg1	et	töötasin =tööta  (IndIpfSg1  >töötama !27_V
29911	meeldin	meeldi	meeldima	27_V	IndPrSg1	et	meeldin =meeldi  (IndPrSg1  >meeldima !27_V
29912	energeetikusse	energeetiku	energeetik	02_S	SgIll	et	energeetikusse =energeetiku  (SgIll  >energeetik !02_S
29918	elusuund	suund	elu+suund	22_S	SgN	et	elusuund =suund  (SgN  >elu+suund !22_S
29919	reeglid	reegli	reegel	02_S	PlN	et	reeglid =reegli  (PlN  >reegel !02_S
29921	arusaadavat	saadava	aru+saadav	02_A	SgP	et	arusaadavat =saadava  (SgP  >aru+saadav !02_A
29925	ehitusplatsil	platsi	ehitus+plats	22_S	SgAd	et	ehitusplatsil =platsi  (SgAd  >ehitus+plats !22_S
29937	pähklimäe	mäe	pähkli+mägi	21_S	SgG	et	pähklimäe =mäe  (SgG  >pähkli+mägi !21_S
29939	erialas	ala	eri+ala	17_S	SgIn	et	erialas =ala  (SgIn  >eri+ala !17_S
29941	praaktika	tika	praak+tikk	22_S	SgG	et	praaktika =tika  (SgG  >praak+tikk !22_S
29943	räägin	räägi	rääkima	28_V	IndPrSg1	et	räägin =räägi  (IndPrSg1  >rääkima !28_V
29945	nimetakse	takse	nime+taks	22_S	PlP	et	nimetakse =takse  (PlP  >nime+taks !22_S
29947	sooritasin	soorita	sooritama	27_V	IndIpfSg1	et	sooritasin =soorita  (IndIpfSg1  >sooritama !27_V
29952	loengule	loengu	loeng	02_S	SgAll	et	loengule =loengu  (SgAll  >loeng !02_S
29953	sööklad	söökla	söökla	01_S	PlN	et	sööklad =söökla  (PlN  >söökla !01_S
29954	staadion	staadion	staadion	19~02_S	SgN	et	staadion =staadion  (SgN  >staadion !19~02_S
29955	ümberehitamist	ehitamis	ümber+ehitamine	12_S	SgP	et	ümberehitamist =ehitamis  (SgP  >ümber+ehitamine !12_S
29958	pluss	pluss	pluss	22_S	SgN	et	pluss =pluss  (SgN  >pluss !22_S
29961	ütlen	ütle	ütlema	30_V	IndPrSg1	et	ütlen =ütle  (IndPrSg1  >ütlema !30_V
29963	eksaamid	aami	eks+aam	22_S	PlN	et	eksaamid =aami  (PlN  >eks+aam !22_S
29967	klubisse	klubi	klubi	17_S	SgIll	et	klubisse =klubi  (SgIll  >klubi !17_S
29969	kõrgharidusi	haridusi	kõrg+haridus	11_S	PlP	et	kõrgharidusi =haridusi  (PlP  >kõrg+haridus !11_S
29977	tuhad	tuha	tuhk	22_S	PlN	et	tuhad =tuha  (PlN  >tuhk !22_S
29993	hakkad	hakka	hakkama	29_V	IndPrSg2	et	hakkad =hakka  (IndPrSg2  >hakkama !29_V
29995	jagan	jaga	jagama	27_V	IndPrSg1	et	jagan =jaga  (IndPrSg1  >jagama !27_V
29999	andsin	and	andma	34_V	IndIpfSg1	et	andsin =and  (IndIpfSg1  >andma !34_V
30002	huvitab	huvita	huvitama	27_V	IndPrSg3	et	huvitab =huvita  (IndPrSg3  >huvitama !27_V
30006	geodeesiat	geodeesia	geodeesia	01_S	SgP	et	geodeesiat =geodeesia  (SgP  >geodeesia !01_S
30010	erialaga	ala	eri+ala	17_S	SgKom	et	erialaga =ala  (SgKom  >eri+ala !17_S
30014	tööstus-	tööstus	tööstus	11~09_S	SgN	et	tööstus- =tööstus  (SgN  >tööstus !11~09_S
30021	praktikat	praktika	praktika	01_S	SgP	et	praktikat =praktika  (SgP  >praktika !01_S
30027	kolmast	ast	kolm+ast	22_S	SgN	et	kolmast =ast  (SgN  >kolm+ast !22_S
30033	koer	koer	koer	23?22_SA	SgN	et	koer =koer  (SgN  >koer !23?22_SA
30057	juuksed	juukse	juus	09_S	PlN	et	juuksed =juukse  (PlN  >juus !09_S
30061	ujun	uju	ujuma	27_V	IndPrSg1	et	ujun =uju  (IndPrSg1  >ujuma !27_V
30062	päevitan	päevita	päevitama	27_V	IndPrSg1	et	päevitan =päevita  (IndPrSg1  >päevitama !27_V
29938	unustasin	unusta	unustama	27_V	IndIpfSg1	et	unustasin =unusta  (IndIpfSg1  >unustama !27_V
29940	tehnikat	tehnika	tehnika	01_S	SgP	et	tehnikat =tehnika  (SgP  >tehnika !01_S
29949	spetsialistide	spetsialisti	spetsialist	22_S	PlG	et	spetsialistide =spetsialisti  (PlG  >spetsialist !22_S
29950	perspektiivne	perspektiivne	perspektiivne	02_A	SgN	et	perspektiivne =perspektiivne  (SgN  >perspektiivne !02_A
29959	negatiivne	negatiivne	negatiivne	02_A	SgN	et	negatiivne =negatiivne  (SgN  >negatiivne !02_A
29972	kordas	korda	kordama	29_V	IndIpfSg3	et	kordas =korda  (IndIpfSg3  >kordama !29_V
29981	mängida	mängi	mängima	28_V	Inf	et	mängida =mängi  (Inf  >mängima !28_V
29985	klassikaaslased	kaaslase	klassi+kaaslane	12?10_S	PlN	et	klassikaaslased =kaaslase  (PlN  >klassi+kaaslane !12?10_S
29989	erinema	erine	erinema	27_V	Sup	et	erinema =erine  (Sup  >erinema !27_V
29994	õnnestub	õnnestu	õnnestuma	27_V	IndPrSg3	et	õnnestub =õnnestu  (IndPrSg3  >õnnestuma !27_V
29998	tantsin	tantsi	tantsima	28_V	IndPrSg1	et	tantsin =tantsi  (IndPrSg1  >tantsima !28_V
30000	kõrk	kõrk	kõrk	22_A	SgN	et	kõrk =kõrk  (SgN  >kõrk !22_A
30005	kümnendas	kümnenda	kümnes	02_O	SgIn	et	kümnendas =kümnenda  (SgIn  >kümnes !02_O
30013	oskus	oskus	oskus	11~09_S	SgN	et	oskus =oskus  (SgN  >oskus !11~09_S
30022	tallinnass	ass	tallinn+ass	22_S	SgN	et	tallinnass =ass  (SgN  >tallinn+ass !22_S
30024	jalgpallur	pallur	jalg+pallur	02_S	SgN	et	jalgpallur =pallur  (SgN  >jalg+pallur !02_S
30028	odav	odav	odav	02_A	SgN	et	odav =odav  (SgN  >odav !02_A
30035	läheks	lähe	minema	36_V	KndPrPs	et	läheks =lähe  (KndPrPs  >minema !36_V
30039	õlid	õli	õli	17_S	PlN	et	õlid =õli  (PlN  >õli !17_S
30040	jutt	jutt	jutt	22_S	SgN	et	jutt =jutt  (SgN  >jutt !22_S
30041	homme	homme	homme	41_D	ID	et	homme =homme  (ID  >homme !41_D
30046	tomatit	tomati	tomat	02_S	SgP	et	tomatit =tomati  (SgP  >tomat !02_S
30052	vaatan	vaata	vaatama	29_V	IndPrSg1	et	vaatan =vaata  (IndPrSg1  >vaatama !29_V
30055	perekonnaringis	ringi	pere+konna+ring	22_S	SgIn	et	perekonnaringis =ringi  (SgIn  >pere+konna+ring !22_S
30056	pruunid	pruuni	pruun	22_AS	PlN	et	pruunid =pruuni  (PlN  >pruun !22_AS
30058	prillid	prilli	prill	22_S	PlN	et	prillid =prilli  (PlN  >prill !22_S
30064	sõpradeks	sõpra	sõber	24_S	PlTr	et	sõpradeks =sõpra  (PlTr  >sõber !24_S
30068	prantsuse	prantsuse	prantsuse	41_G	ID	et	prantsuse =prantsuse  (ID  >prantsuse !41_G
30082	jäätis	jäätis	jäätis	11~09_S	SgN	et	jäätis =jäätis  (SgN  >jäätis !11~09_S
30124	vormivõtteid	võtte	vormi+võte	06_S	PlP	et	vormivõtteid =võtte  (PlP  >vormi+võte !06_S
30127	tekstidest	teksti	tekst	22_S	PlEl	et	tekstidest =teksti  (PlEl  >tekst !22_S
30128	tekstile	teksti	tekst	22_S	SgAll	et	tekstile =teksti  (SgAll  >tekst !22_S
30131	stepihunt	hunt	stepi+hunt	22_S	SgN	et	stepihunt =hunt  (SgN  >stepi+hunt !22_S
30133	kirjandusele	kirjanduse	kirjandus	11_S	SgAll	et	kirjandusele =kirjanduse  (SgAll  >kirjandus !11_S
30137	lüürikat	lüürika	lüürika	01_S	SgP	et	lüürikat =lüürika  (SgP  >lüürika !01_S
30144	jagada	jaga	jagama	27_V	Inf	et	jagada =jaga  (Inf  >jagama !27_V
30148	teemad	teema	teema	16_S	PlN	et	teemad =teema  (PlN  >teema !16_S
30151	vajab	vaja	vajama	27_V	IndPrSg3	et	vajab =vaja  (IndPrSg3  >vajama !27_V
30154	vigadeta	viga	viga	18_S	PlAb	et	vigadeta =viga  (PlAb  >viga !18_S
30164	defineerida	defineeri	defineerima	28_V	Inf	et	defineerida =defineeri  (Inf  >defineerima !28_V
30170	eeldas	eelda	eeldama	27_V	IndIpfSg3	et	eeldas =eelda  (IndIpfSg3  >eeldama !27_V
30173	ajakiri	kiri	aja+kiri	24_S	SgN	et	ajakiri =kiri  (SgN  >aja+kiri !24_S
30184	vorm	vorm	vorm	22_S	SgN	et	vorm =vorm  (SgN  >vorm !22_S
30188	keelekriitikat	kriitika	keele+kriitika	01_S	SgP	et	keelekriitikat =kriitika  (SgP  >keele+kriitika !01_S
30191	bager	bager	bager	02_S	SgN	et	bager =bager  (SgN  >bager !02_S
30202	naisluuletajad	luuletaja	nais+luuletaja	01_S	PlN	et	naisluuletajad =luuletaja  (PlN  >nais+luuletaja !01_S
30204	üksindust	üksindus	üksindus	11_S	SgP	et	üksindust =üksindus  (SgP  >üksindus !11_S
30208	traagilised	traagilise	traagiline	12_A	PlN	et	traagilised =traagilise  (PlN  >traagiline !12_A
30216	sotsialistid	sotsialisti	sotsialist	22_S	PlN	et	sotsialistid =sotsialisti  (PlN  >sotsialist !22_S
30223	rütm	rütm	rütm	22_S	SgN	et	rütm =rütm  (SgN  >rütm !22_S
30228	omane	omane	omane	10_A	SgN	et	omane =omane  (SgN  >omane !10_A
30229	mõtted	mõtte	mõte	06_S	PlN	et	mõtted =mõtte  (PlN  >mõte !06_S
30242	näeme	näe	nägema	28_V	IndPrPl1	et	näeme =näe  (IndPrPl1  >nägema !28_V
30249	kasvust	kasvu	kasv	22_S	SgEl	et	kasvust =kasvu  (SgEl  >kasv !22_S
30254	hundi	hundi	hunt	22_S	SgG	et	hundi =hundi  (SgG  >hunt !22_S
29951	kohtad	kohta	kohtama	29_V	IndPrSg2	et	kohtad =kohta  (IndPrSg2  >kohtama !29_V
29956	üliõpilane	õpilane	üli+õpilane	12_S	SgN	et	üliõpilane =õpilane  (SgN  >üli+õpilane !12_S
29960	üheksani	üheksa	üheksa	01_N	SgTer	et	üheksani =üheksa  (SgTer  >üheksa !01_N
29964	lihtsal	lihtsa	lihtne	02_A	SgAd	et	lihtsal =lihtsa  (SgAd  >lihtne !02_A
29966	tüdrukud	tüdruku	tüdruk	02_S	PlN	et	tüdrukud =tüdruku  (PlN  >tüdruk !02_S
29968	teiega	teie	sina	00_P	PlKom	et	teiega =teie  (PlKom  >sina !00_P
29970	energeetikat	energeetika	energeetika	01_S	SgP	et	energeetikat =energeetika  (SgP  >energeetika !01_S
29979	matemaatikaga	matemaatika	matemaatika	01_S	SgKom	et	matemaatikaga =matemaatika  (SgKom  >matemaatika !01_S
29983	robotid	roboti	robot	02_S	PlN	et	robotid =roboti  (PlN  >robot !02_S
29984	sõbralikud	sõbraliku	sõbralik	25_A	PlN	et	sõbralikud =sõbraliku  (PlN  >sõbralik !25_A
29987	lehekülg	külg	lehe+külg	22_S	SgN	et	lehekülg =külg  (SgN  >lehe+külg !22_S
29988	üliõpilaseks	õpilase	üli+õpilane	12_S	SgTr	et	üliõpilaseks =õpilase  (SgTr  >üli+õpilane !12_S
29990	loengul	loengu	loeng	02_S	SgAd	et	loengul =loengu  (SgAd  >loeng !02_S
29992	selja	selja	selg	22_S	SgG	et	selja =selja  (SgG  >selg !22_S
29997	raskejõustik	jõustik	raske+jõustik	25_S	SgN	et	raskejõustik =jõustik  (SgN  >raske+jõustik !25_S
30001	vaikne	vaikne	vaikne	02_A	SgN	et	vaikne =vaikne  (SgN  >vaikne !02_A
30004	mängin	mängi	mängima	28_V	IndPrSg1	et	mängin =mängi  (IndPrSg1  >mängima !28_V
30008	keelne	keelne	keelne	02_A	SgN	et	keelne =keelne  (SgN  >keelne !02_A
30016	veetma	veet	veetma	34_V	Sup	et	veetma =veet  (Sup  >veetma !34_V
30020	lauatennist	tennis	laua+tennis	09_S	SgP	et	lauatennist =tennis  (SgP  >laua+tennis !09_S
30034	loomusega	loomuse	loomus	11~09_S	SgKom	et	loomusega =loomuse  (SgKom  >loomus !11~09_S
30044	vannis	vanni	vann	22_S	SgIn	et	vannis =vanni  (SgIn  >vann !22_S
30045	poes	poe	pood	22_S	SgIn	et	poes =poe  (SgIn  >pood !22_S
30049	kuulan	kuula	kuulama	29_V	IndPrSg1	et	kuulan =kuula  (IndPrSg1  >kuulama !29_V
30053	telekat	teleka	telekas	02_S	SgP	et	telekat =teleka  (SgP  >telekas !02_S
30069	organisatsioonis	organisatsiooni	organisatsioon	22_S	SgIn	et	organisatsioonis =organisatsiooni  (SgIn  >organisatsioon !22_S
30070	tulevikuplaanid	plaani	tuleviku+plaan	22_S	PlN	et	tulevikuplaanid =plaani  (PlN  >tuleviku+plaan !22_S
30075	audi	audi	aut	22_S	SgG	et	audi =audi  (SgG  >aut !22_S
30078	pakkuma	pakku	pakkuma	28_V	Sup	et	pakkuma =pakku  (Sup  >pakkuma !28_V
30083	loen	loe	lugema	28_V	IndPrSg1	et	loen =loe  (IndPrSg1  >lugema !28_V
30084	parkis	parki	parkima	28_V	IndIpfSg3	et	parkis =parki  (IndIpfSg3  >parkima !28_V
30089	kogemus	kogemus	kogemus	11_S	SgN	et	kogemus =kogemus  (SgN  >kogemus !11_S
30097	leidma	leid	leidma	34_V	Sup	et	leidma =leid  (Sup  >leidma !34_V
30098	rahvuslik	rahvuslik	rahvuslik	25_A	SgN	et	rahvuslik =rahvuslik  (SgN  >rahvuslik !25_A
30099	üllatasin	üllata	üllatama	27_V	IndIpfSg1	et	üllatasin =üllata  (IndIpfSg1  >üllatama !27_V
30107	suhkruta	suhkru	suhkur	02_S	SgAb	et	suhkruta =suhkru  (SgAb  >suhkur !02_S
30108	psühholoogiana	psühholoogia	psühholoogia	01_S	SgEs	et	psühholoogiana =psühholoogia  (SgEs  >psühholoogia !01_S
30109	jään	jää	jääma	37_V	IndPrSg1	et	jään =jää  (IndPrSg1  >jääma !37_V
30112	muuseumisse	muuseumi	muuseum	19~02_S	SgIll	et	muuseumisse =muuseumi  (SgIll  >muuseum !19~02_S
30113	perfektne	perfektne	perfektne	02_A	SgN	et	perfektne =perfektne  (SgN  >perfektne !02_A
30119	aitame	aita	aitama	29_V	IndPrPl1	et	aitame =aita  (IndPrPl1  >aitama !29_V
30120	eksam	eksam	eksam	02_S	SgN	et	eksam =eksam  (SgN  >eksam !02_S
30134	tunnused	tunnuse	tunnus	09_S	PlN	et	tunnused =tunnuse  (PlN  >tunnus !09_S
30138	faktorid	faktori	faktor	02_S	PlN	et	faktorid =faktori  (PlN  >faktor !02_S
30141	normide	normi	norm	22_S	PlG	et	normide =normi  (PlG  >norm !22_S
30157	ball	ball	ball	22_S	SgN	et	ball =ball  (SgN  >ball !22_S
30158	radikaalsed	radikaalse	radikaalne	02_A	PlN	et	radikaalsed =radikaalse  (PlN  >radikaalne !02_A
30161	ekspressionism	ekspressionism	ekspressionism	22_S	SgN	et	ekspressionism =ekspressionism  (SgN  >ekspressionism !22_S
30165	gruppe	gruppe	grupp	22_S	PlP	et	gruppe =gruppe  (PlP  >grupp !22_S
30167	lüürikas	lüürika	lüürika	01_S	SgIn	et	lüürikas =lüürika  (SgIn  >lüürika !01_S
30168	emotsioone	emotsioone	emotsioon	22_S	PlP	et	emotsioone =emotsioone  (PlP  >emotsioon !22_S
30175	grupp	grupp	grupp	22_S	SgN	et	grupp =grupp  (SgN  >grupp !22_S
30182	totaalset	totaalse	totaalne	02_A	SgP	et	totaalset =totaalse  (SgP  >totaalne !02_A
30186	dadaismis	dadaismi	dadaism	22_S	SgIn	et	dadaismis =dadaismi  (SgIn  >dadaism !22_S
30190	mõtlemisvõimalusi	võimalusi	mõtlemis+võimalus	11_S	PlP	et	mõtlemisvõimalusi =võimalusi  (PlP  >mõtlemis+võimalus !11_S
30029	loendud	loendu	loenduma	27_V	IndPrSg2	et	loendud =loendu  (IndPrSg2  >loenduma !27_V
30030	õpetaks	õpeta	õpetama	27_V	KndPrPs	et	õpetaks =õpeta  (KndPrPs  >õpetama !27_V
30031	lapsid	lapsi	laps	22_S	PlN	et	lapsid =lapsi  (PlN  >laps !22_S
30036	matkama	matka	matkama	29_V	Sup	et	matkama =matka  (Sup  >matkama !29_V
30037	igapäeval	päeva	iga+päev	22_S	SgAd	et	igapäeval =päeva  (SgAd  >iga+päev !22_S
30038	ostaks	osta	ostma	34_V	KndPrPs	et	ostaks =osta  (KndPrPs  >ostma !34_V
30043	magan	maga	magama	27_V	IndPrSg1	et	magan =maga  (IndPrSg1  >magama !27_V
30047	pudel	pudel	pudel	02_S	SgN	et	pudel =pudel  (SgN  >pudel !02_S
30048	lõunat	lõuna	lõuna	06_S	SgP	et	lõunat =lõuna  (SgP  >lõuna !06_S
30059	pesen	pese	pesema	36_V	IndPrSg1	et	pesen =pese  (IndPrSg1  >pesema !36_V
30076	kass	kass	kass	22_S	SgN	et	kass =kass  (SgN  >kass !22_S
30077	kohev	kohev	kohev	02_A	SgN	et	kohev =kohev  (SgN  >kohev !02_A
30081	teenima	teeni	teenima	28_V	Sup	et	teenima =teeni  (Sup  >teenima !28_V
30085	tants	tants	tants	22_S	SgN	et	tants =tants  (SgN  >tants !22_S
30087	sõbragi	sõbra	sõber	24_S	SgG^	et	sõbragi =sõbra  (SgG^  >sõber !24_S
30090	puumajale	maja	puu+maja	17_S	SgAll	et	puumajale =maja  (SgAll  >puu+maja !17_S
30091	emaga	ema	ema	17_S	SgKom	et	emaga =ema  (SgKom  >ema !17_S
30092	vootaks	taks	voo+taks	22_S	SgN	et	vootaks =taks  (SgN  >voo+taks !22_S
30100	mäletama	mäleta	mäletama	27_V	Sup	et	mäletama =mäleta  (Sup  >mäletama !27_V
30101	sünnipäev	päev	sünni+päev	22_S	SgN	et	sünnipäev =päev  (SgN  >sünni+päev !22_S
30114	abiellun	ellu	abi+elluma	27_V	IndPrSg1	et	abiellun =ellu  (IndPrSg1  >abi+elluma !27_V
30116	ostame	osta	ostma	34_V	IndPrPl1	et	ostame =osta  (IndPrPl1  >ostma !34_V
30117	mängitakse	mängi	mängima	28_V	IndPrIps	et	mängitakse =mängi  (IndPrIps  >mängima !28_V
30121	lüürikale	lüürika	lüürika	01_S	SgAll	et	lüürikale =lüürika  (SgAll  >lüürika !01_S
30123	teemakomplekse	komplekse	teema+kompleks	22_S	PlP	et	teemakomplekse =komplekse  (PlP  >teema+kompleks !22_S
30125	tooge	too	tooma	38_V	ImpPrPl2	et	tooge =too  (ImpPrPl2  >tooma !38_V
30126	rahvuskirjanduste	kirjandus	rahvus+kirjandus	11_S	PlG	et	rahvuskirjanduste =kirjandus  (PlG  >rahvus+kirjandus !11_S
30129	toetudes	toetu	toetuma	27_V	Ger	et	toetudes =toetu  (Ger  >toetuma !27_V
30132	sein	sein	sein	23?22_S	SgN	et	sein =sein  (SgN  >sein !23?22_S
30135	tekstinäiteid	näite	teksti+näide	06_S	PlP	et	tekstinäiteid =näite  (PlP  >teksti+näide !06_S
30143	kirjanduses	kirjanduse	kirjandus	11_S	SgIn	et	kirjanduses =kirjanduse  (SgIn  >kirjandus !11_S
30149	eelmiste	eelmis	eelmine	12?10_A	PlG	et	eelmiste =eelmis  (PlG  >eelmine !12?10_A
30150	kaasaegsed	aegse	kaas+aegne	02_A	PlN	et	kaasaegsed =aegse  (PlN  >kaas+aegne !02_A
30159	destruktsioon	destruktsioon	destruktsioon	22_S	SgN	et	destruktsioon =destruktsioon  (SgN  >destruktsioon !22_S
30162	peaesindajad	esindaja	pea+esindaja	01_S	PlN	et	peaesindajad =esindaja  (PlN  >pea+esindaja !01_S
30163	trakt	trakt	trakt	22_S	SgN	et	trakt =trakt  (SgN  >trakt !22_S
30177	hõlmab	hõlma	hõlmama	29_V	IndPrSg3	et	hõlmab =hõlma  (IndPrSg3  >hõlmama !29_V
30179	jäeta	jäe	jätma	35_V	IndPrIps_	et	jäeta =jäe  (IndPrIps_  >jätma !35_V
30181	sürrealistide	sürrealisti	sürrealist	22_S	PlG	et	sürrealistide =sürrealisti  (PlG  >sürrealist !22_S
30192	lumi	lumi	lumi	20_S	SgN	et	lumi =lumi  (SgN  >lumi !20_S
30196	figuure	figuure	figuur	22_S	PlP	et	figuure =figuure  (PlP  >figuur !22_S
30199	matemaatikud	matemaatiku	matemaatik	02_S	PlN	et	matemaatikud =matemaatiku  (PlN  >matemaatik !02_S
30200	keeleeksperimentidega	eksperimenti	keele+eksperiment	22_S	PlKom	et	keeleeksperimentidega =eksperimenti  (PlKom  >keele+eksperiment !22_S
30201	igavesed	igavese	igavene	12_A	PlN	et	igavesed =igavese  (PlN  >igavene !12_A
30203	humanistlik	humanistlik	humanistlik	25_A	SgN	et	humanistlik =humanistlik  (SgN  >humanistlik !25_A
30206	naisluuletajatest	luuletaja	nais+luuletaja	01_S	PlEl	et	naisluuletajatest =luuletaja  (PlEl  >nais+luuletaja !01_S
30213	kriitikaga	kriitika	kriitika	01_S	SgKom	et	kriitikaga =kriitika  (SgKom  >kriitika !01_S
30219	unikaalse	unikaalse	unikaalne	02_A	SgG	et	unikaalse =unikaalse  (SgG  >unikaalne !02_A
30233	lemmikud	lemmiku	lemmik	02_S	PlN	et	lemmikud =lemmiku  (PlN  >lemmik !02_S
30234	absurdsed	absurdse	absurdne	02_A	PlN	et	absurdsed =absurdse  (PlN  >absurdne !02_A
30236	tegelaste	tegelas	tegelane	12_S	PlG	et	tegelaste =tegelas  (PlG  >tegelane !12_S
30241	metamorfoosis	metamorfoosi	metamorfoos	22_S	SgIn	et	metamorfoosis =metamorfoosi  (SgIn  >metamorfoos !22_S
30244	põlgust	põlgus	põlgus	11~09_S	SgP	et	põlgust =põlgus  (SgP  >põlgus !11~09_S
30246	venna	venna	vend	22_S	SgG	et	venna =venna  (SgG  >vend !22_S
30067	sooviksin	soovi	soovima	28_V	KndPrSg1	et	sooviksin =soovi  (KndPrSg1  >soovima !28_V
30071	tulevik	tulevik	tulevik	25_S	SgN	et	tulevik =tulevik  (SgN  >tulevik !25_S
30072	ajakirjanikuks	kirjaniku	aja+kirjanik	25_S	SgTr	et	ajakirjanikuks =kirjaniku  (SgTr  >aja+kirjanik !25_S
30080	elatist	elatis	elatis	11_S	SgP	et	elatist =elatis  (SgP  >elatis !11_S
30086	kutsun	kutsu	kutsuma	28_V	IndPrSg1	et	kutsun =kutsu  (IndPrSg1  >kutsuma !28_V
30093	kõneleda	kõnele	kõnelema	27_V	Inf	et	kõneleda =kõnele  (Inf  >kõnelema !27_V
30094	pereks	pere	pere	16_S	SgTr	et	pereks =pere  (SgTr  >pere !16_S
30096	kuum	kuum	kuum	22_AS	SgN	et	kuum =kuum  (SgN  >kuum !22_AS
30102	pühitsetakse	pühitse	pühitsema	27_V	IndPrIps	et	pühitsetakse =pühitse  (IndPrIps  >pühitsema !27_V
30104	jaht	jaht	jaht	22_S	SgN	et	jaht =jaht  (SgN  >jaht !22_S
30105	kompaniis	kompanii	kompanii	26_S	SgIn	et	kompaniis =kompanii  (SgIn  >kompanii !26_S
30115	kaksikud	kaksiku	kaksik	02_SA	PlN	et	kaksikud =kaksiku  (PlN  >kaksik !02_SA
30118	süütakse	takse	süü+taks	22_S	PlP	et	süütakse =takse  (PlP  >süü+taks !22_S
30136	kasutage	kasuta	kasutama	27_V	ImpPrPl2	et	kasutage =kasuta  (ImpPrPl2  >kasutama !27_V
30139	urbanisatsioon	urbanisatsioon	urbanisatsioon	22_S	SgN	et	urbanisatsioon =urbanisatsioon  (SgN  >urbanisatsioon !22_S
30146	suund	suund	suund	22_S	SgN	et	suund =suund  (SgN  >suund !22_S
30147	sotsiaal-poliitilised	poliitilise	sotsiaal-poliitiline	12_A	PlN	et	sotsiaal-poliitilised =poliitilise  (PlN  >sotsiaal-poliitiline !12_A
30152	norme	norme	norm	22_S	PlP	et	norme =norme  (PlP  >norm !22_S
30153	mineviku	mineviku	minevik	25_S	SgG	et	mineviku =mineviku  (SgG  >minevik !25_S
30155	esimestena	esimes	esimene	12_OP	PlEs	et	esimestena =esimes  (PlEs  >esimene !12_OP
30156	arp	arp	arp	22_S	SgN	et	arp =arp  (SgN  >arp !22_S
30169	sotsiaalkriitikat	kriitika	sotsiaal+kriitika	01_S	SgP	et	sotsiaalkriitikat =kriitika  (SgP  >sotsiaal+kriitika !01_S
30172	klubidesse	klubi	klubi	17_S	PlIll	et	klubidesse =klubi  (PlIll  >klubi !17_S
30174	lahkarvamused	arvamuse	lahk+arvamus	11_S	PlN	et	lahkarvamused =arvamuse  (PlN  >lahk+arvamus !11_S
30176	sürrealistid	sürrealisti	sürrealist	22_S	PlN	et	sürrealistid =sürrealisti  (PlN  >sürrealist !22_S
30178	fotograafiat	fotograafia	fotograafia	01_S	SgP	et	fotograafiat =fotograafia  (SgP  >fotograafia !01_S
30183	sürrealism	sürrealism	sürrealism	22_S	SgN	et	sürrealism =sürrealism  (SgN  >sürrealism !22_S
30185	eeskujud	kuju	ees+kuju	17_S	PlN	et	eeskujud =kuju  (PlN  >ees+kuju !17_S
30187	sürrealismis	sürrealismi	sürrealism	22_S	SgIn	et	sürrealismis =sürrealismi  (SgIn  >sürrealism !22_S
30189	piirab	piira	piirama	29_V	IndPrSg3	et	piirab =piira  (IndPrSg3  >piirama !29_V
30193	väljendada	väljenda	väljendama	27_V	Inf	et	väljendada =väljenda  (Inf  >väljendama !27_V
30197	tegeles	tegele	tegelema	31~27_V	IndIpfSg3	et	tegeles =tegele  (IndIpfSg3  >tegelema !31~27_V
30198	eksperimentidega	eksperimenti	eksperiment	22_S	PlKom	et	eksperimentidega =eksperimenti  (PlKom  >eksperiment !22_S
30217	humanistid	humanisti	humanist	22_S	PlN	et	humanistid =humanisti  (PlN  >humanist !22_S
30218	hääletoruks	toru	hääle+toru	17_S	SgTr	et	hääletoruks =toru  (SgTr  >hääle+toru !17_S
30220	rääkis	rääki	rääkima	28_V	IndIpfSg3	et	rääkis =rääki  (IndIpfSg3  >rääkima !28_V
30227	produktiivse	produktiivse	produktiivne	02_A	SgG	et	produktiivse =produktiivse  (SgG  >produktiivne !02_A
30232	konventsioonide	konventsiooni	konventsioon	22_S	PlG	et	konventsioonide =konventsiooni  (PlG  >konventsioon !22_S
30240	valiku	valiku	valik	02_S	SgG	et	valiku =valiku  (SgG  >valik !02_S
30243	pereliikmete	liikme	pere+liige	05_S	PlG	et	pereliikmete =liikme  (PlG  >pere+liige !05_S
30258	olekute	oleku	olek	02_S	PlG	et	olekute =oleku  (PlG  >olek !02_S
30266	realistlikud	realistliku	realistlik	25_A	PlN	et	realistlikud =realistliku  (PlN  >realistlik !25_A
30269	seaduse	seaduse	seadus	11~09_S	SgG	et	seaduse =seaduse  (SgG  >seadus !11~09_S
30284	sürrealistlik	sürrealistlik	sürrealistlik	25_A	SgN	et	sürrealistlik =sürrealistlik  (SgN  >sürrealistlik !25_A
30287	usub	usu	uskuma	28_V	IndPrSg3	et	usub =usu  (IndPrSg3  >uskuma !28_V
30291	tsirkust	tsirkus	tsirkus	11~09_S	SgP	et	tsirkust =tsirkus  (SgP  >tsirkus !11~09_S
30293	väravavaht	vaht	värava+vaht	22_S	SgN	et	väravavaht =vaht  (SgN  >värava+vaht !22_S
30294	värav	värav	värav	02_S	SgN	et	värav =värav  (SgN  >värav !02_S
30297	bürokraatlik	bürokraatlik	bürokraatlik	25_A	SgN	et	bürokraatlik =bürokraatlik  (SgN  >bürokraatlik !25_A
30300	lubab	luba	lubama	27_V	IndPrSg3	et	lubab =luba  (IndPrSg3  >lubama !27_V
30310	olek	olek	olek	02_S	SgN	et	olek =olek  (SgN  >olek !02_S
30312	ootuste	ootus	ootus	11~09_S	PlG	et	ootuste =ootus  (PlG  >ootus !11~09_S
30323	mõistuse	mõistuse	mõistus	11~09_S	SgG	et	mõistuse =mõistuse  (SgG  >mõistus !11~09_S
30180	filmitegijat	tegija	filmi+tegija	01_S	SgP	et	filmitegijat =tegija  (SgP  >filmi+tegija !01_S
30194	poeem	poeem	poeem	22_S	SgN	et	poeem =poeem  (SgN  >poeem !22_S
30195	osade	osa	osa	17_S	PlG	et	osade =osa  (PlG  >osa !17_S
30205	poeeme	poeeme	poeem	22_S	PlP	et	poeeme =poeeme  (PlP  >poeem !22_S
30207	marina	mari	mari	17~16_S	SgEs	et	marina =mari  (SgEs  >mari !17~16_S
30209	armastas	armasta	armastama	27_V	IndIpfSg3	et	armastas =armasta  (IndIpfSg3  >armastama !27_V
30214	sotsiaalprobleeme	probleeme	sotsiaal+probleem	22_S	PlP	et	sotsiaalprobleeme =probleeme  (PlP  >sotsiaal+probleem !22_S
30221	süüdistas	süüdista	süüdistama	27_V	IndIpfSg3	et	süüdistas =süüdista  (IndIpfSg3  >süüdistama !27_V
30222	rüümidega	mi	rüü+mi	26_S	PlKom	et	rüümidega =mi  (PlKom  >rüü+mi !26_S
30226	autori	autori	autor	02_S	SgG	et	autori =autori  (SgG  >autor !02_S
30231	võõrad	võõra	võõras	07_AS	PlN	et	võõrad =võõra  (PlN  >võõras !07_AS
30237	olukordades	korda	olu+kord	22_S	PlIn	et	olukordades =korda  (PlIn  >olu+kord !22_S
30238	protsesside	protsessi	protsess	22_S	PlG	et	protsesside =protsessi  (PlG  >protsess !22_S
30245	tunnet	tunne	tunne	06_S	SgP	et	tunnet =tunne  (SgP  >tunne !06_S
30248	stepihundis	hundi	stepi+hunt	22_S	SgIn	et	stepihundis =hundi  (SgIn  >stepi+hunt !22_S
30250	igavast	igava	igav	02_A	SgEl	et	igavast =igava  (SgEl  >igav !02_A
30251	kirjanikust	kirjaniku	kirjanik	25_S	SgEl	et	kirjanikust =kirjaniku  (SgEl  >kirjanik !25_S
30256	viib	vii	viima	38_V	IndPrSg3	et	viib =vii  (IndPrSg3  >viima !38_V
30257	kompromissile	kompromissi	kompromiss	22_S	SgAll	et	kompromissile =kompromissi  (SgAll  >kompromiss !22_S
30261	seisundit	seisundi	seisund	02_S	SgP	et	seisundit =seisundi  (SgP  >seisund !02_S
30267	elementide	elementi	element	22_S	PlG	et	elementide =elementi  (PlG  >element !22_S
30270	traktaat	traktaat	traktaat	22_S	SgN	et	traktaat =traktaat  (SgN  >traktaat !22_S
30274	meelitab	meelita	meelitama	27_V	IndPrSg3	et	meelitab =meelita  (IndPrSg3  >meelitama !27_V
30277	romaanist	romaani	romaan	22_S	SgEl	et	romaanist =romaani  (SgEl  >romaan !22_S
30283	paistab	paista	paistma	34_V	IndPrSg3	et	paistab =paista  (IndPrSg3  >paistma !34_V
30295	lõhkuda	lõhku	lõhkuma	28_V	Inf	et	lõhkuda =lõhku  (Inf  >lõhkuma !28_V
30296	väravavahi	vahi	värava+vaht	22_S	SgG	et	väravavahi =vahi  (SgG  >värava+vaht !22_S
30303	eks	eks	eks	41_D	ID	et	eks =eks  (ID  >eks !41_D
30306	tegude	tegu	tegu	18_S	PlG	et	tegude =tegu  (PlG  >tegu !18_S
30308	mingeid	minge	mingi	01_P	PlP	et	mingeid =minge  (PlP  >mingi !01_P
30321	seletab	seleta	seletama	27_V	IndPrSg3	et	seletab =seleta  (IndPrSg3  >seletama !27_V
30333	kultuuriruumile	ruumi	kultuuri+ruum	22_S	SgAll	et	kultuuriruumile =ruumi  (SgAll  >kultuuri+ruum !22_S
30342	kaheksandas	kaheksanda	kaheksas	02_O	SgIn	et	kaheksandas =kaheksanda  (SgIn  >kaheksas !02_O
30344	professori	professori	professor	02_S	SgG	et	professori =professori  (SgG  >professor !02_S
30346	motiiv	motiiv	motiiv	22_S	SgN	et	motiiv =motiiv  (SgN  >motiiv !22_S
30352	vastasseisund	seisund	vastas+seisund	02_S	SgN	et	vastasseisund =seisund  (SgN  >vastas+seisund !02_S
30358	argument	argument	argument	22_S	SgN	et	argument =argument  (SgN  >argument !22_S
30362	tunnuseid	tunnuse	tunnus	09_S	PlP	et	tunnuseid =tunnuse  (PlP  >tunnus !09_S
30367	võidab	võida	võitma	34_V	IndPrSg3	et	võidab =võida  (IndPrSg3  >võitma !34_V
30381	sahvris	sahvri	sahver	02_S	SgIn	et	sahvris =sahvri  (SgIn  >sahver !02_S
30384	sõi	sõ	sööma	38_V	IndIpfSg3	et	sõi =sõ  (IndIpfSg3  >sööma !38_V
30395	järgemööda	järgemööda	järge+mööda	41_D	ID	et	järgemööda =järgemööda  (ID  >järge+mööda !41_D
30399	liiva-annus	annus	liiva-annus	09_S	SgN	et	liiva-annus =annus  (SgN  >liiva-annus !09_S
30401	jätab	jäta	jätma	35_V	IndPrSg3	et	jätab =jäta  (IndPrSg3  >jätma !35_V
30411	ootused	ootuse	ootus	11~09_S	PlN	et	ootused =ootuse  (PlN  >ootus !11~09_S
30421	vaevab	vaeva	vaevama	29_V	IndPrSg3	et	vaevab =vaeva  (IndPrSg3  >vaevama !29_V
30425	tõlge	tõlge	tõlge	06_S	SgN	et	tõlge =tõlge  (SgN  >tõlge !06_S
30426	õudset	õudse	õudne	02_A	SgP	et	õudset =õudse  (SgP  >õudne !02_A
30435	informeerida	informeeri	informeerima	28_V	Inf	et	informeerida =informeeri  (Inf  >informeerima !28_V
30436	krattidesse	kratti	kratt	22_S	PlIll	et	krattidesse =kratti  (PlIll  >kratt !22_S
30437	mõjutada	mõjuta	mõjutama	27_V	Inf	et	mõjutada =mõjuta  (Inf  >mõjutama !27_V
30438	küsib	küsi	küsima	27_V	IndPrSg3	et	küsib =küsi  (IndPrSg3  >küsima !27_V
30445	elliptiline	elliptiline	elliptiline	12_A	SgN	et	elliptiline =elliptiline  (SgN  >elliptiline !12_A
30454	isikus	isiku	isik	02_S	SgIn	et	isikus =isiku  (SgIn  >isik !02_S
30457	tähistada	tähista	tähistama	27_V	Inf	et	tähistada =tähista  (Inf  >tähistama !27_V
30210	kannatada	kannata	kannatama	27_V	Inf	et	kannatada =kannata  (Inf  >kannatama !27_V
30211	maksimalism	maksimalism	maksimalism	22_S	SgN	et	maksimalism =maksimalism  (SgN  >maksimalism !22_S
30212	loomulik	loomulik	loomulik	25_A	SgN	et	loomulik =loomulik  (SgN  >loomulik !25_A
30215	bürokraatiat	bürokraatia	bürokraatia	01_S	SgP	et	bürokraatiat =bürokraatia  (SgP  >bürokraatia !01_S
30224	energiline	energiline	energiline	12_A	SgN	et	energiline =energiline  (SgN  >energiline !12_A
30225	nähtavasti	nähtavasti	nähtavasti	41_D	ID	et	nähtavasti =nähtavasti  (ID  >nähtavasti !41_D
30230	hingeta	hinge	hing	22_S	SgAb	et	hingeta =hinge  (SgAb  >hing !22_S
30235	olukorrad	korra	olu+kord	22_S	PlN	et	olukorrad =korra  (PlN  >olu+kord !22_S
30239	kritiseerib	kritiseeri	kritiseerima	28_V	IndPrSg3	et	kritiseerib =kritiseeri  (IndPrSg3  >kritiseerima !28_V
30260	füüsilist	füüsilis	füüsiline	12_A	SgP	et	füüsilist =füüsilis  (SgP  >füüsiline !12_A
30275	jälgida	jälgi	jälgima	27_V	Inf	et	jälgida =jälgi  (Inf  >jälgima !27_V
30276	interpretatsioon	interpretatsioon	interpretatsioon	22_S	SgN	et	interpretatsioon =interpretatsioon  (SgN  >interpretatsioon !22_S
30278	kriitikud	kriitiku	kriitik	02_S	PlN	et	kriitikud =kriitiku  (PlN  >kriitik !02_S
30280	moraal	moraal	moraal	22_S	SgN	et	moraal =moraal  (SgN  >moraal !22_S
30292	isikustab	isikusta	isikustama	27_V	IndPrSg3	et	isikustab =isikusta  (IndPrSg3  >isikustama !27_V
30302	siseneda	sisene	sisenema	27_V	Inf	et	siseneda =sisene  (Inf  >sisenema !27_V
30305	vastutada	vastuta	vastutama	27_V	Inf	et	vastutada =vastuta  (Inf  >vastutama !27_V
30309	välisjõude	jõude	välis+jõud	22_S	PlP	et	välisjõude =jõude  (PlP  >välis+jõud !22_S
30318	pääseda	pääse	pääsema	28_V	Inf	et	pääseda =pääse  (Inf  >pääsema !28_V
30319	väravate	värava	värav	02_S	PlG	et	väravate =värava  (PlG  >värav !02_S
30320	surmani	surma	surm	22_S	SgTer	et	surmani =surma  (SgTer  >surm !22_S
30322	sissepääs	pääs	sisse+pääs	22_S	SgN	et	sissepääs =pääs  (SgN  >sisse+pääs !22_S
30327	munad	muna	muna	17_S	PlN	et	munad =muna  (PlN  >muna !17_S
30328	hääled	hääle	hääl	13_S	PlN	et	hääled =hääle  (PlN  >hääl !13_S
30330	vastasseisuni	seisu	vastas+seis	22_S	SgTer	et	vastasseisuni =seisu  (SgTer  >vastas+seis !22_S
30340	laulab	laula	laulma	33_V	IndPrSg3	et	laulab =laula  (IndPrSg3  >laulma !33_V
30347	võrdleb	võrdle	võrdlema	30_V	IndPrSg3	et	võrdleb =võrdle  (IndPrSg3  >võrdlema !30_V
30349	konflikt	konflikt	konflikt	22_S	SgN	et	konflikt =konflikt  (SgN  >konflikt !22_S
30351	niisiis	niisiis	nii+siis	41_D	ID	et	niisiis =niisiis  (ID  >nii+siis !41_D
30361	tekstis	teksti	tekst	22_S	SgIn	et	tekstis =teksti  (SgIn  >tekst !22_S
30365	hunt	hunt	hunt	22_S	SgN	et	hunt =hunt  (SgN  >hunt !22_S
30372	katkendi	katkendi	katkend	02_S	SgG	et	katkendi =katkendi  (SgG  >katkend !02_S
30378	küsis	küsi	küsima	27_V	IndIpfSg3	et	küsis =küsi  (IndIpfSg3  >küsima !27_V
30387	rumalad	rumala	rumal	02_A	PlN	et	rumalad =rumala  (PlN  >rumal !02_A
30388	teinekord	teinekord	teine+kord	41_D	ID	et	teinekord =teinekord  (ID  >teine+kord !41_D
30392	lõikas	lõika	lõikama	29_V	IndIpfSg3	et	lõikas =lõika  (IndIpfSg3  >lõikama !29_V
30394	igaühele	ühe	iga+üks	22_P	SgAll	et	igaühele =ühe  (SgAll  >iga+üks !22_P
30396	küünal	küünal	küünal	08_S	SgN	et	küünal =küünal  (SgN  >küünal !08_S
30400	veab	vea	vedama	28_V	IndPrSg3	et	veab =vea  (IndPrSg3  >vedama !28_V
30407	romaanis	romaani	romaan	22_S	SgIn	et	romaanis =romaani  (SgIn  >romaan !22_S
30412	tõlkega	tõlke	tõlge	06_S	SgKom	et	tõlkega =tõlke  (SgKom  >tõlge !06_S
30415	tegelane	tegelane	tegelane	12_S	SgN	et	tegelane =tegelane  (SgN  >tegelane !12_S
30416	röövib	röövi	röövima	28_V	IndPrSg3	et	röövib =röövi  (IndPrSg3  >röövima !28_V
30419	vargustega	vargus	vargus	11~09_S	PlKom	et	vargustega =vargus  (PlKom  >vargus !11~09_S
30420	liik	liik	liik	22_S	SgN	et	liik =liik  (SgN  >liik !22_S
30433	kujutab	kujuta	kujutama	27_V	IndPrSg3	et	kujutab =kujuta  (IndPrSg3  >kujutama !27_V
30443	situatsioonile	situatsiooni	situatsioon	22_S	SgAll	et	situatsioonile =situatsiooni  (SgAll  >situatsioon !22_S
30444	ühistele	ühis	ühine	10_A	PlAll	et	ühistele =ühis  (PlAll  >ühine !10_A
30448	ellips	ellips	ellips	02_S	SgN	et	ellips =ellips  (SgN  >ellips !02_S
30451	isik	isik	isik	02_S	SgN	et	isik =isik  (SgN  >isik !02_S
30463	leksikaalsete	leksikaalse	leksikaalne	02_A	PlG	et	leksikaalsete =leksikaalse  (PlG  >leksikaalne !02_A
30486	põhjus-tagajärg	järg	põhjus-taga+järg	22_S	SgN	et	põhjus-tagajärg =järg  (SgN  >põhjus-taga+järg !22_S
30488	piinleb	piinle	piinlema	30_V	IndPrSg3	et	piinleb =piinle  (IndPrSg3  >piinlema !30_V
30494	pragmaatiline	pragmaatiline	pragmaatiline	12_A	SgN	et	pragmaatiline =pragmaatiline  (SgN  >pragmaatiline !12_A
30247	psühhoanalüüsiga	analüüsi	psühho+analüüs	22_S	SgKom	et	psühhoanalüüsiga =analüüsi  (SgKom  >psühho+analüüs !22_S
30252	eluarmastajani	armastaja	elu+armastaja	01_S	SgTer	et	eluarmastajani =armastaja  (SgTer  >elu+armastaja !01_S
30253	võitlust	võitlus	võitlus	11~09_S	SgP	et	võitlust =võitlus  (SgP  >võitlus !11~09_S
30255	avardab	avarda	avardama	27_V	IndPrSg3	et	avardab =avarda  (IndPrSg3  >avardama !27_V
30262	puute	puute	puude	06_S	SgG	et	puute =puute  (SgG  >puude !06_S
30263	teoste	teos	teos	09_S	PlG	et	teoste =teos  (PlG  >teos !09_S
30264	struktuur	struktuur	struktuur	22_S	SgN	et	struktuur =struktuur  (SgN  >struktuur !22_S
30268	mõistujutt	jutt	mõistu+jutt	22_S	SgN	et	mõistujutt =jutt  (SgN  >mõistu+jutt !22_S
30271	stepihundist	hundi	stepi+hunt	22_S	SgEl	et	stepihundist =hundi  (SgEl  >stepi+hunt !22_S
30273	peamist	peamis	peamine	12?10_A	SgP	et	peamist =peamis  (SgP  >peamine !12?10_A
30279	mõistujutus	jutu	mõistu+jutt	22_S	SgIn	et	mõistujutus =jutu  (SgIn  >mõistu+jutt !22_S
30281	vormistas	vormista	vormistama	27_V	IndIpfSg3	et	vormistas =vormista  (IndIpfSg3  >vormistama !27_V
30304	puudub	puudu	puuduma	27_V	IndPrSg3	et	puudub =puudu  (IndPrSg3  >puuduma !27_V
30307	laseb	lase	laskma	34_V	IndPrSg3	et	laseb =lase  (IndPrSg3  >laskma !34_V
30311	mõistete	mõiste	mõiste	06_S	PlG	et	mõistete =mõiste  (PlG  >mõiste !06_S
30314	hirmuga	hirmu	hirm	22_S	SgKom	et	hirmuga =hirmu  (SgKom  >hirm !22_S
30315	valvurite	valvuri	valvur	02_S	PlG	et	valvurite =valvuri  (PlG  >valvur !02_S
30316	südames	südame	süda	04_S	SgIn	et	südames =südame  (SgIn  >süda !04_S
30326	saatuslikud	saatusliku	saatuslik	25_A	PlN	et	saatuslikud =saatusliku  (PlN  >saatuslik !25_A
30335	skitseerige	skitseeri	skitseerima	28_V	ImpPrPl2	et	skitseerige =skitseeri  (ImpPrPl2  >skitseerima !28_V
30336	kirjeldage	kirjelda	kirjeldama	27_V	ImpPrPl2	et	kirjeldage =kirjelda  (ImpPrPl2  >kirjeldama !27_V
30337	põhjendage	põhjenda	põhjendama	27_V	ImpPrPl2	et	põhjendage =põhjenda  (ImpPrPl2  >põhjendama !27_V
30338	naisest	naise	naine	12_S	SgEl	et	naisest =naise  (SgEl  >naine !12_S
30341	professor	professor	professor	02_S	SgN	et	professor =professor  (SgN  >professor !02_S
30343	tapab	tapa	tapma	35_V	IndPrSg3	et	tapab =tapa  (IndPrSg3  >tapma !35_V
30345	patriarhaalne	patriarhaalne	patriarhaalne	02_A	SgN	et	patriarhaalne =patriarhaalne  (SgN  >patriarhaalne !02_A
30350	surmaga	surma	surm	22_S	SgKom	et	surmaga =surma  (SgKom  >surm !22_S
30353	konfliktist	konflikti	konflikt	22_S	SgEl	et	konfliktist =konflikti  (SgEl  >konflikt !22_S
30355	traagiline	traagiline	traagiline	12_A	SgN	et	traagiline =traagiline  (SgN  >traagiline !12_A
30356	niisuguse	suguse	nii+sugune	10_P	SgG	et	niisuguse =suguse  (SgG  >nii+sugune !10_P
30359	oodates	ooda	ootama	29_V	Ger	et	oodates =ooda  (Ger  >ootama !29_V
30369	loogikale	loogika	loogika	01_S	SgAll	et	loogikale =loogika  (SgAll  >loogika !01_S
30370	vastased	vastase	vastane	10_AS	PlN	et	vastased =vastase  (PlN  >vastane !10_AS
30375	pakkus	pakku	pakkuma	28_V	IndIpfSg3	et	pakkus =pakku  (IndIpfSg3  >pakkuma !28_V
30402	vedama	veda	vedama	28_V	Sup	et	vedama =veda  (Sup  >vedama !28_V
30408	eelteadmisi	teadmisi	eel+teadmine	12_S	PlP	et	eelteadmisi =teadmisi  (PlP  >eel+teadmine !12_S
30409	kindlate	kindla	kindel	02_A	PlG	et	kindlate =kindla  (PlG  >kindel !02_A
30410	tekstide	teksti	tekst	22_S	PlG	et	tekstide =teksti  (PlG  >tekst !22_S
30413	mütoloogias	mütoloogia	mütoloogia	01_S	SgIn	et	mütoloogias =mütoloogia  (SgIn  >mütoloogia !01_S
30414	tulesabaga	saba	tule+saba	17_S	SgKom	et	tulesabaga =saba  (SgKom  >tule+saba !17_S
30417	peremehele	mehe	pere+mees	13_S	SgAll	et	peremehele =mehe  (SgAll  >pere+mees !13_S
30427	vigastada	vigasta	vigastama	27_V	Inf	et	vigastada =vigasta  (Inf  >vigastama !27_V
30429	ründas	ründa	ründama	29_V	IndIpfSg3	et	ründas =ründa  (IndIpfSg3  >ründama !29_V
30432	tekstilõik	lõik	teksti+lõik	22_S	SgN	et	tekstilõik =lõik  (SgN  >teksti+lõik !22_S
30441	repliikide	repliiki	repliik	22_S	PlG	et	repliikide =repliiki  (PlG  >repliik !22_S
30449	kordused	korduse	kordus	11~09_S	PlN	et	kordused =korduse  (PlN  >kordus !11~09_S
30453	kolmandas	kolmanda	kolmas	02_O	SgIn	et	kolmandas =kolmanda  (SgIn  >kolmas !02_O
30455	tegelastesse	tegelas	tegelane	12_S	PlIll	et	tegelastesse =tegelas  (PlIll  >tegelane !12_S
30459	nõuandmisest	andmise	nõu+andmine	12?10_S	SgEl	et	nõuandmisest =andmise  (SgEl  >nõu+andmine !12?10_S
30461	targaks	targa	tark	22_AS	SgTr	et	targaks =targa  (SgTr  >tark !22_AS
30471	iseloomule	loomu	ise+loom	22_S	SgAll	et	iseloomule =loomu  (SgAll  >ise+loom !22_S
30474	hiljutine	hiljutine	hiljutine	12_A	SgN	et	hiljutine =hiljutine  (SgN  >hiljutine !12_A
30483	saavutatakse	saavuta	saavutama	27_V	IndPrIps	et	saavutatakse =saavuta  (IndPrIps  >saavutama !27_V
30259	peategelasega	tegelase	pea+tegelane	12_S	SgKom	et	peategelasega =tegelase  (SgKom  >pea+tegelane !12_S
30265	kasvõi	kasvõi	kas+või	41_D	ID	et	kasvõi =kasvõi  (ID  >kas+või !41_D
30272	sisaldab	sisalda	sisaldama	27_V	IndPrSg3	et	sisaldab =sisalda  (IndPrSg3  >sisaldama !27_V
30282	umber	umber	umber	02_S	SgN	et	umber =umber  (SgN  >umber !02_S
30285	peategelasele	tegelase	pea+tegelane	12_S	SgAll	et	peategelasele =tegelase  (SgAll  >pea+tegelane !12_S
30286	esitatakse	esita	esitama	27_V	IndPrIps	et	esitatakse =esita  (IndPrIps  >esitama !27_V
30288	kohtuprotsess	protsess	kohtu+protsess	22_S	SgN	et	kohtuprotsess =protsess  (SgN  >kohtu+protsess !22_S
30289	lõpetada	lõpeta	lõpetama	27_V	Inf	et	lõpetada =lõpeta  (Inf  >lõpetama !27_V
30290	absurdset	absurdse	absurdne	02_A	SgP	et	absurdset =absurdse  (SgP  >absurdne !02_A
30298	kehastab	kehasta	kehastama	27_V	IndPrSg3	et	kehastab =kehasta  (IndPrSg3  >kehastama !27_V
30299	väljastpoolt	väljastpoolt	väljast+poolt	41_DK	ID	et	väljastpoolt =väljastpoolt  (ID  >väljast+poolt !41_DK
30301	mehele	mehe	mees	13_S	SgAll	et	mehele =mehe  (SgAll  >mees !13_S
30313	õigustades	õigusta	õigustama	27_V	Ger	et	õigustades =õigusta  (Ger  >õigustama !27_V
30317	kohut	kohu	kohus	05_S	SgP	et	kohut =kohu  (SgP  >kohus !05_S
30325	modernistliku	modernistliku	modernistlik	25_A	SgG	et	modernistliku =modernistliku  (SgG  >modernistlik !25_A
30348	mõttes	mõtte	mõte	06_S	SgIn	et	mõttes =mõtte  (SgIn  >mõte !06_S
30360	absurdikirjandusele	kirjanduse	absurdi+kirjandus	11_S	SgAll	et	absurdikirjandusele =kirjanduse  (SgAll  >absurdi+kirjandus !11_S
30363	stiil	stiil	stiil	22_S	SgN	et	stiil =stiil  (SgN  >stiil !22_S
30364	reaalne	reaalne	reaalne	02_A	SgN	et	reaalne =reaalne  (SgN  >reaalne !02_A
30366	kumb	kumb	kumb	22_P	SgN	et	kumb =kumb  (SgN  >kumb !22_P
30368	reaalset	reaalse	reaalne	02_A	SgP	et	reaalset =reaalse  (SgP  >reaalne !02_A
30374	november	november	november	02_S	SgN	et	november =november  (SgN  >november !02_S
30380	prussakal	prussaka	prussakas	02_S	SgAd	et	prussakal =prussaka  (SgAd  >prussakas !02_S
30385	eh-eh-hee	hee	eh-eh-hee	41_I	ID	et	eh-eh-hee =hee  (ID  >eh-eh-hee !41_I
30386	suuga	suu	suu	26_S	SgKom	et	suuga =suu  (SgKom  >suu !26_S
30389	ükspäev	päev	üks+päev	22_S	SgN	et	ükspäev =päev  (SgN  >üks+päev !22_S
30391	küünlaid	küünla	küünal	08_S	PlP	et	küünlaid =küünla  (PlP  >küünal !08_S
30397	mauk	mauk	mauk	22_S	SgN	et	mauk =mauk  (SgN  >mauk !22_S
30398	sooled	soole	sool	13_S	PlN	et	sooled =soole  (PlN  >sool !13_S
30404	eelteadmistega	teadmis	eel+teadmine	12?10_S	PlKom	et	eelteadmistega =teadmis  (PlKom  >eel+teadmine !12?10_S
30405	püsitegelane	tegelane	püsi+tegelane	12_S	SgN	et	püsitegelane =tegelane  (SgN  >püsi+tegelane !12_S
30406	rahvakalendris	kalendri	rahva+kalender	02_S	SgIn	et	rahvakalendris =kalendri  (SgIn  >rahva+kalender !02_S
30422	piinab	piina	piinama	29_V	IndPrSg3	et	piinab =piina  (IndPrSg3  >piinama !29_V
30423	peremehe	mehe	pere+mees	13_S	SgG	et	peremehe =mehe  (SgG  >pere+mees !13_S
30424	kannab	kanna	kandma	34_V	IndPrSg3	et	kannab =kanna  (IndPrSg3  >kandma !34_V
30428	originaalis	originaali	originaal	22_S	SgIn	et	originaalis =originaali  (SgIn  >originaal !22_S
30431	füüsilise	füüsilise	füüsiline	12_A	SgG	et	füüsilise =füüsilise  (SgG  >füüsiline !12_A
30434	tekstil	teksti	tekst	22_S	SgAd	et	tekstil =teksti  (SgAd  >tekst !22_S
30440	vestlus	vestlus	vestlus	11~09_S	SgN	et	vestlus =vestlus  (SgN  >vestlus !11~09_S
30446	varastamas	varasta	varastama	27_V	SupIn	et	varastamas =varasta  (SupIn  >varastama !27_V
30456	fraasist	fraasi	fraas	22_S	SgEl	et	fraasist =fraasi  (SgEl  >fraas !22_S
30460	võetagi	võe	võtma	35_V	IndPrIps_^	et	võetagi =võe  (IndPrIps_^  >võtma !35_V
30464	vahendite	vahendi	vahend	02_S	PlG	et	vahendite =vahendi  (PlG  >vahend !02_S
30468	kurjalt	kurjalt	kurjalt	41_D	ID	et	kurjalt =kurjalt  (ID  >kurjalt !41_D
30470	viidates	viida	viitama	29_V	Ger	et	viidates =viida  (Ger  >viitama !29_V
30472	kohatasandil	tasandi	koha+tasand	02_S	SgAd	et	kohatasandil =tasandi  (SgAd  >koha+tasand !02_S
30473	hetk	hetk	hetk	22_S	SgN	et	hetk =hetk  (SgN  >hetk !22_S
30476	sahver	sahver	sahver	02_S	SgN	et	sahver =sahver  (SgN  >sahver !02_S
30477	lihtminevikus	mineviku	liht+minevik	25_S	SgIn	et	lihtminevikus =mineviku  (SgIn  >liht+minevik !25_S
30481	olevikus	oleviku	olevik	25_S	SgIn	et	olevikus =oleviku  (SgIn  >olevik !25_S
30482	oleviku	oleviku	olevik	25_S	SgG	et	oleviku =oleviku  (SgG  >olevik !25_S
30485	originaalile	originaali	originaal	22_S	SgAll	et	originaalile =originaali  (SgAll  >originaal !22_S
30489	arutleb	arutle	arutlema	27_V	IndPrSg3	et	arutleb =arutle  (IndPrSg3  >arutlema !27_V
30491	tõdeb	tõde	tõdema	27_V	IndPrSg3	et	tõdeb =tõde  (IndPrSg3  >tõdema !27_V
30324	tahtejõu	jõu	tahte+jõud	22_S	SgG	et	tahtejõu =jõu  (SgG  >tahte+jõud !22_S
30329	üksikisiku	isiku	üksik+isik	02_S	SgG	et	üksikisiku =isiku  (SgG  >üksik+isik !02_S
30331	üldinimlike	inimlike	üld+inimlik	25_A	PlG	et	üldinimlike =inimlike  (PlG  >üld+inimlik !25_A
30332	probleemidega	probleemi	probleem	22_S	PlKom	et	probleemidega =probleemi  (PlKom  >probleem !22_S
30334	iseloomulike	loomulike	ise+loomulik	25_A	PlG	et	iseloomulike =loomulike  (PlG  >ise+loomulik !25_A
30339	teose	teose	teos	09_S	SgG	et	teose =teose  (SgG  >teos !09_S
30354	kultuuriruumil	ruumi	kultuuri+ruum	22_S	SgAd	et	kultuuriruumil =ruumi  (SgAd  >kultuuri+ruum !22_S
30357	inimeseta	inimese	inimene	12_S	SgAb	et	inimeseta =inimese  (SgAb  >inimene !12_S
30371	analüüs	analüüs	analüüs	22_S	SgN	et	analüüs =analüüs  (SgN  >analüüs !22_S
30373	rehepapp	papp	rehe+papp	22_S	SgN	et	rehepapp =papp  (SgN  >rehe+papp !22_S
30376	kratt	kratt	kratt	22_S	SgN	et	kratt =kratt  (SgN  >kratt !22_S
30377	noh	noh	noh	41_I	ID	et	noh =noh  (ID  >noh !41_I
30379	sulasel	sulase	sulane	10_S	SgAd	et	sulasel =sulase  (SgAd  >sulane !10_S
30382	maiustamas	maiusta	maiustama	27_V	SupIn	et	maiustamas =maiusta  (SupIn  >maiustama !27_V
30383	poleks	pole	olema	36_V	KndPrPsN	et	poleks =pole  (KndPrPsN  >olema !36_V
30390	toomas	too	tooma	38_V	SupIn	et	toomas =too  (SupIn  >tooma !38_V
30393	vahaküünlaid	küünla	vaha+küünal	08_S	PlP	et	vahaküünlaid =küünla  (PlP  >vaha+küünal !08_S
30403	seos	seos	seos	09_S	SgN	et	seos =seos  (SgN  >seos !09_S
30418	rikkust	rikkus	rikkus	11~09_S	SgP	et	rikkust =rikkus  (SgP  >rikkus !11~09_S
30430	füüsilisi	füüsilisi	füüsiline	12_A	PlP	et	füüsilisi =füüsilisi  (PlP  >füüsiline !12_A
30439	sulasega	sulase	sulane	10_S	SgKom	et	sulasega =sulase  (SgKom  >sulane !10_S
30442	vestluses	vestluse	vestlus	11~09_S	SgIn	et	vestluses =vestluse  (SgIn  >vestlus !11~09_S
30447	sihukene	sihukene	sihukene	12_P	SgN	et	sihukene =sihukene  (SgN  >sihukene !12_P
30450	leksikaalsed	leksikaalse	leksikaalne	02_A	PlN	et	leksikaalsed =leksikaalse  (PlN  >leksikaalne !02_A
30452	subjektiga	subjekti	subjekt	22_S	SgKom	et	subjektiga =subjekti  (SgKom  >subjekt !22_S
30462	inimeseks	inimese	inimene	12_S	SgTr	et	inimeseks =inimese  (SgTr  >inimene !12_S
30475	minevik	minevik	minevik	25_S	SgN	et	minevik =minevik  (SgN  >minevik !25_S
30484	tõlketekst	tekst	tõlke+tekst	22_S	SgN	et	tõlketekst =tekst  (SgN  >tõlke+tekst !22_S
30487	struktuuriga	struktuuri	struktuur	22_S	SgKom	et	struktuuriga =struktuuri  (SgKom  >struktuur !22_S
30490	hädade	häda	häda	17_S	PlG	et	hädade =häda  (PlG  >häda !17_S
30496	erikord	kord	eri+kord	22_S	SgN	et	erikord =kord  (SgN  >eri+kord !22_S
30501	kirikul	kiriku	kirik	02_S	SgAd	et	kirikul =kiriku  (SgAd  >kirik !02_S
30509	esimeheks	mehe	esi+mees	13_S	SgTr	et	esimeheks =mehe  (SgTr  >esi+mees !13_S
30510	õhtud	õhtu	õhtu	01_S	PlN	et	õhtud =õhtu  (PlN  >õhtu !01_S
30520	häbimärk	märk	häbi+märk	22_S	SgN	et	häbimärk =märk  (SgN  >häbi+märk !22_S
30524	püüti	püü	püüdma	34_V	IndIpfIps	et	püüti =püü  (IndIpfIps  >püüdma !34_V
30526	jõuab	jõua	jõudma	34_V	IndPrSg3	et	jõuab =jõua  (IndPrSg3  >jõudma !34_V
30527	päästis	pääst	päästma	34_V	IndIpfSg3	et	päästis =pääst  (IndIpfSg3  >päästma !34_V
30560	ametnikega	ametnike	ametnik	25_S	PlKom	et	ametnikega =ametnike  (PlKom  >ametnik !25_S
30564	kubermangude	kubermangu	kubermang	22_S	PlG	et	kubermangude =kubermangu  (PlG  >kubermang !22_S
30565	tollipiirid	piiri	tolli+piir	22_S	PlN	et	tollipiirid =piiri  (PlN  >tolli+piir !22_S
30576	erikorra	korra	eri+kord	22_S	SgG	et	erikorra =korra  (SgG  >eri+kord !22_S
30580	näit	näit	näit	22_S	SgN	et	näit =näit  (SgN  >näit !22_S
30581	täheldada	tähelda	täheldama	27_V	Inf	et	täheldada =tähelda  (Inf  >täheldama !27_V
30583	minema	mine	minema	36_V	Sup	et	minema =mine  (Sup  >minema !36_V
30587	pooleni	poole	pool	13_NS	SgTer	et	pooleni =poole  (SgTer  >pool !13_NS
30600	hommikusöögi	söögi	hommiku+söök	22_S	SgG	et	hommikusöögi =söögi  (SgG  >hommiku+söök !22_S
30602	rahvuspargisse	pargi	rahvus+park	22_S	SgIll	et	rahvuspargisse =pargi  (SgIll  >rahvus+park !22_S
30606	tühi	tühi	tühi	24_A	SgN	et	tühi =tühi  (SgN  >tühi !24_A
30609	narva-jõesuusse	suu	narva-jõe+suu	26_S	SgIll	et	narva-jõesuusse =suu  (SgIll  >narva-jõe+suu !26_S
30610	hotellis	hotelli	hotell	22_S	SgIn	et	hotellis =hotelli  (SgIn  >hotell !22_S
30611	salatit	salati	salat	02_S	SgP	et	salatit =salati  (SgP  >salat !02_S
30616	jagas	jaga	jagama	27_V	IndIpfSg3	et	jagas =jaga  (IndIpfSg3  >jagama !27_V
30621	toimetas	toimeta	toimetama	27_V	IndIpfSg3	et	toimetas =toimeta  (IndIpfSg3  >toimetama !27_V
30626	ilusalonge	salonge	ilu+salong	22_S	PlP	et	ilusalonge =salonge  (PlP  >ilu+salong !22_S
30458	sulase	sulase	sulane	10_S	SgG	et	sulase =sulase  (SgG  >sulane !10_S
30465	lauses	lause	lause	06_S	SgIn	et	lauses =lause  (SgIn  >lause !06_S
30466	tähendada	tähenda	tähendama	27_V	Inf	et	tähendada =tähenda  (Inf  >tähendama !27_V
30467	vastandada	vastanda	vastandama	27_V	Inf	et	vastandada =vastanda  (Inf  >vastandama !27_V
30469	heitlikule	heitliku	heitlik	25_A	SgAll	et	heitlikule =heitliku  (SgAll  >heitlik !25_A
30478	kandub	kandu	kanduma	27_V	IndPrSg3	et	kandub =kandu  (IndPrSg3  >kanduma !27_V
30479	tõlkes	tõlke	tõlge	06_S	SgIn	et	tõlkes =tõlke  (SgIn  >tõlge !06_S
30480	ajaga	aja	aeg	22_S	SgKom	et	ajaga =aja  (SgKom  >aeg !22_S
30493	krattide	kratti	kratt	22_S	PlG	et	krattide =kratti  (PlG  >kratt !22_S
30495	usaldama	usalda	usaldama	27_V	Sup	et	usaldama =usalda  (Sup  >usaldama !27_V
30504	omavalitsussüsteem	süsteem	oma+valitsus+süsteem	22_S	SgN	et	omavalitsussüsteem =süsteem  (SgN  >oma+valitsus+süsteem !22_S
30507	sisekubermangude	kubermangu	sise+kubermang	22_S	PlG	et	sisekubermangude =kubermangu  (PlG  >sise+kubermang !22_S
30508	tegelaseks	tegelase	tegelane	12_S	SgTr	et	tegelaseks =tegelase  (SgTr  >tegelane !12_S
30514	isanda	isanda	isand	02_S	SgG	et	isanda =isanda  (SgG  >isand !02_S
30523	süvendada	süvenda	süvendama	27_V	Inf	et	süvendada =süvenda  (Inf  >süvendama !27_V
30525	vabastada	vabasta	vabastama	27_V	Inf	et	vabastada =vabasta  (Inf  >vabastama !27_V
30533	valgustusfilosoofiat	filosoofia	valgustus+filosoofia	01_S	SgP	et	valgustusfilosoofiat =filosoofia  (SgP  >valgustus+filosoofia !01_S
30537	ratsionalism	ratsionalism	ratsionalism	22_S	SgN	et	ratsionalism =ratsionalism  (SgN  >ratsionalism !22_S
30540	alas	ala	ala	17_S	SgIn	et	alas =ala  (SgIn  >ala !17_S
30541	maksimaalse	maksimaalse	maksimaalne	02_A	SgG	et	maksimaalse =maksimaalse  (SgG  >maksimaalne !02_A
30553	senised	senise	senine	10_A	PlN	et	senised =senise  (PlN  >senine !10_A
30558	kubermanguvalimise	valimise	kubermangu+valimine	12_S	SgG	et	kubermanguvalimise =valimise  (SgG  >kubermangu+valimine !12_S
30566	erikorrale	korra	eri+kord	22_S	SgAll	et	erikorrale =korra  (SgAll  >eri+kord !22_S
30567	positiivne	positiivne	positiivne	02_A	SgN	et	positiivne =positiivne  (SgN  >positiivne !02_A
30571	põlisrahva	rahva	põlis+rahvas	07_S	SgG	et	põlisrahva =rahva  (SgG  >põlis+rahvas !07_S
30575	võimalikuks	võimaliku	võimalik	25_A	SgTr	et	võimalikuks =võimaliku  (SgTr  >võimalik !25_A
30579	elanikes	elanike	elanik	25_S	PlIn	et	elanikes =elanike  (PlIn  >elanik !25_S
30590	uurima	uuri	uurima	28_V	Sup	et	uurima =uuri  (Sup  >uurima !28_V
30604	kartsin	kart	kartma	34_V	IndIpfSg1	et	kartsin =kart  (IndIpfSg1  >kartma !34_V
30605	uudishimulik	himulik	uudis+himulik	25_A	SgN	et	uudishimulik =himulik  (SgN  >uudis+himulik !25_A
30612	õlut	õlu	õlu	24_S	SgP	et	õlut =õlu  (SgP  >õlu !24_S
30620	tehases	tehase	tehas	09_S	SgIn	et	tehases =tehase  (SgIn  >tehas !09_S
30622	lihtne	lihtne	lihtne	02_A	SgN	et	lihtne =lihtne  (SgN  >lihtne !02_A
30624	lokis	loki	lokk	22_S	SgIn	et	lokis =loki  (SgIn  >lokk !22_S
30628	mõtles	mõtle	mõtlema	30_V	IndIpfSg3	et	mõtles =mõtle  (IndIpfSg3  >mõtlema !30_V
30634	sõrmust	sõrmus	sõrmus	09_S	SgP	et	sõrmust =sõrmus  (SgP  >sõrmus !09_S
30644	voodis	voodi	voodi	01_S	SgIn	et	voodis =voodi  (SgIn  >voodi !01_S
30651	kambaga	kamba	kamp	22_S	SgKom	et	kambaga =kamba  (SgKom  >kamp !22_S
30652	nüüdsest	nüüdse	nüüdne	02_A	SgEl	et	nüüdsest =nüüdse  (SgEl  >nüüdne !02_A
30654	tähtpäev	päev	täht+päev	22_S	SgN	et	tähtpäev =päev  (SgN  >täht+päev !22_S
30656	päevas	päeva	päev	22_S	SgIn	et	päevas =päeva  (SgIn  >päev !22_S
30657	riietuda	riietu	riietuma	27_V	Inf	et	riietuda =riietu  (Inf  >riietuma !27_V
30682	ostma	ost	ostma	34_V	Sup	et	ostma =ost  (Sup  >ostma !34_V
30690	nimeks	nime	nimi	20_S	SgTr	et	nimeks =nime  (SgTr  >nimi !20_S
30694	kaheksandal	kaheksanda	kaheksas	02_O	SgAd	et	kaheksandal =kaheksanda  (SgAd  >kaheksas !02_O
30700	järgmisena	järgmise	järgmine	12?10_A	SgEs	et	järgmisena =järgmise  (SgEs  >järgmine !12?10_A
30702	kohtas	kohta	kohtama	29_V	IndIpfSg3	et	kohtas =kohta  (IndIpfSg3  >kohtama !29_V
30704	ühelt	ühe	üks	22_NP	SgAbl	et	ühelt =ühe  (SgAbl  >üks !22_NP
30708	pilguga	pilgu	pilk	22_S	SgKom	et	pilguga =pilgu  (SgKom  >pilk !22_S
30710	aknaid	akna	aken	08_S	PlP	et	aknaid =akna  (PlP  >aken !08_S
30715	tuhkatriinut	triinu	tuhka+triinu	16_S	SgP	et	tuhkatriinut =triinu  (SgP  >tuhka+triinu !16_S
30717	igatses	igatse	igatsema	27_V	IndIpfSg3	et	igatses =igatse  (IndIpfSg3  >igatsema !27_V
30723	võõrkeeli	keel	võõr+keel	13_S	PlP	et	võõrkeeli =keel  (PlP  >võõr+keel !13_S
30733	salongis	salongi	salong	22_S	SgIn	et	salongis =salongi  (SgIn  >salong !22_S
30735	põneva	põneva	põnev	02_A	SgG	et	põneva =põneva  (SgG  >põnev !02_A
30492	vabastama	vabasta	vabastama	27_V	Sup	et	vabastama =vabasta  (Sup  >vabastama !27_V
30498	saksakeelne	keelne	saksa+keelne	02_A	SgN	et	saksakeelne =keelne  (SgN  >saksa+keelne !02_A
30499	õigussüsteem	süsteem	õigus+süsteem	22_S	SgN	et	õigussüsteem =süsteem  (SgN  >õigus+süsteem !22_S
30503	autonoomne	autonoomne	autonoomne	02_A	SgN	et	autonoomne =autonoomne  (SgN  >autonoomne !02_A
30506	omavalitsust	valitsus	oma+valitsus	11_S	SgP	et	omavalitsust =valitsus  (SgP  >oma+valitsus !11_S
30513	langeb	lange	langema	27_V	IndPrSg3	et	langeb =lange  (IndPrSg3  >langema !27_V
30515	taheti	tahe	tahtma	34_V	IndIpfIps	et	taheti =tahe  (IndIpfIps  >tahtma !34_V
30517	rootsiaja	aja	rootsi+aeg	22_S	SgG	et	rootsiaja =aja  (SgG  >rootsi+aeg !22_S
30519	mõisnikele	mõisnike	mõisnik	25_S	PlAll	et	mõisnikele =mõisnike  (PlAll  >mõisnik !25_S
30529	talupoegadega	poega	talu+poeg	22_S	PlKom	et	talupoegadega =poega  (PlKom  >talu+poeg !22_S
30531	võrdsed	võrdse	võrdne	02_A	PlN	et	võrdsed =võrdse  (PlN  >võrdne !02_A
30532	levik	levik	levik	02_S	SgN	et	levik =levik  (SgN  >levik !02_S
30535	kirikut	kiriku	kirik	02_S	SgP	et	kirikut =kiriku  (SgP  >kirik !02_S
30538	tugines	tugine	tuginema	27_V	IndIpfSg3	et	tugines =tugine  (IndIpfSg3  >tuginema !27_V
30542	peeter	peeter	peeter	02_S	SgN	et	peeter =peeter  (SgN  >peeter !02_S
30543	eestirahva	rahva	eesti+rahvas	07_S	SgG	et	eestirahva =rahva  (SgG  >eesti+rahvas !07_S
30545	eestirahvaga	rahva	eesti+rahvas	07_S	SgKom	et	eestirahvaga =rahva  (SgKom  >eesti+rahvas !07_S
30555	üksnes	üksnes	üksnes	41_D	ID	et	üksnes =üksnes  (ID  >üksnes !41_D
30556	asjade	asja	asi	24_S	PlG	et	asjade =asja  (PlG  >asi !24_S
30559	täideti	täide	täitma	34_V	IndIpfIps	et	täideti =täide  (IndIpfIps  >täitma !34_V
30577	talurahva	rahva	talu+rahvas	07_S	SgG	et	talurahva =rahva  (SgG  >talu+rahvas !07_S
30584	põhjasõja-järgsel	järgse	põhjasõja-järgne	02_A	SgAd	et	põhjasõja-järgsel =järgse  (SgAd  >põhjasõja-järgne !02_A
30585	kehtis	kehti	kehtima	27_V	IndIpfSg3	et	kehtis =kehti  (IndIpfSg3  >kehtima !27_V
30589	õpetlased	õpetlase	õpetlane	12_S	PlN	et	õpetlased =õpetlase  (PlN  >õpetlane !12_S
30598	mustamäel	mäe	musta+mägi	21_S	SgAd	et	mustamäel =mäe  (SgAd  >musta+mägi !21_S
30599	usun	usu	uskuma	28_V	IndPrSg1	et	usun =usu  (IndPrSg1  >uskuma !28_V
30603	tudeng	tudeng	tudeng	02_S	SgN	et	tudeng =tudeng  (SgN  >tudeng !02_S
30607	kusagil	kusagil	kusagil	41_D	ID	et	kusagil =kusagil  (ID  >kusagil !41_D
30614	kaunitar	kaunitar	kaunitar	19_S	SgN	et	kaunitar =kaunitar  (SgN  >kaunitar !19_S
30619	köögiga	köögi	köök	22_S	SgKom	et	köögiga =köögi  (SgKom  >köök !22_S
30625	kosmeetikat	kosmeetika	kosmeetika	01_S	SgP	et	kosmeetikat =kosmeetika  (SgP  >kosmeetika !01_S
30627	tantsimas	tantsi	tantsima	28_V	SupIn	et	tantsimas =tantsi  (SupIn  >tantsima !28_V
30629	klassikaaslasi	kaaslasi	klassi+kaaslane	12_S	PlP	et	klassikaaslasi =kaaslasi  (PlP  >klassi+kaaslane !12_S
30631	üllatas	üllata	üllatama	27_V	IndIpfSg3	et	üllatas =üllata  (IndIpfSg3  >üllatama !27_V
30636	aluspesuga	pesu	alus+pesu	17_S	SgKom	et	aluspesuga =pesu  (SgKom  >alus+pesu !17_S
30638	minestas	minesta	minestama	27_V	IndIpfSg3	et	minestas =minesta  (IndIpfSg3  >minestama !27_V
30642	aken	aken	aken	08_S	SgN	et	aken =aken  (SgN  >aken !08_S
30646	heleroosadeks	roosa	hele+roosa	16_AS	PlTr	et	heleroosadeks =roosa  (PlTr  >hele+roosa !16_AS
30665	võõrase	ase	võõr+ase	04_S	SgN	et	võõrase =ase  (SgN  >võõr+ase !04_S
30668	kartke	kart	kartma	34_V	ImpPrPl2	et	kartke =kart  (ImpPrPl2  >kartma !34_V
30670	võtan	võta	võtma	35_V	IndPrSg1	et	võtan =võta  (IndPrSg1  >võtma !35_V
30671	lumemajja	majja	lume+maja	17_S	SgAdt	et	lumemajja =majja  (SgAdt  >lume+maja !17_S
30675	tülitseb	tülitse	tülitsema	27_V	IndPrSg3	et	tülitseb =tülitse  (IndPrSg3  >tülitsema !27_V
30678	kulges	kulge	kulgema	27_V	IndIpfSg3	et	kulges =kulge  (IndIpfSg3  >kulgema !27_V
30687	naisel	naise	naine	12_S	SgAd	et	naisel =naise  (SgAd  >naine !12_S
30692	lahkuda	lahku	lahkuma	27_V	Inf	et	lahkuda =lahku  (Inf  >lahkuma !27_V
30699	näitan	näita	näitama	29_V	IndPrSg1	et	näitan =näita  (IndPrSg1  >näitama !29_V
30701	erand	erand	erand	02_S	SgN	et	erand =erand  (SgN  >erand !02_S
30718	tütred	tütre	tütar	08_S	PlN	et	tütred =tütre  (PlN  >tütar !08_S
30719	kasuõed	õe	kasu+õde	18_S	PlN	et	kasuõed =õe  (PlN  >kasu+õde !18_S
30725	hoolitseda	hoolitse	hoolitsema	27_V	Inf	et	hoolitseda =hoolitse  (Inf  >hoolitsema !27_V
30726	prille	prille	prill	22_S	PlP	et	prille =prille  (PlP  >prill !22_S
30734	kunstjuuksed	juukse	kunst+juus	09_S	PlN	et	kunstjuuksed =juukse  (PlN  >kunst+juus !09_S
30740	unes	une	uni	20_S	SgIn	et	unes =une  (SgIn  >uni !20_S
30751	vanainimesed	inimese	vana+inimene	12_S	PlN	et	vanainimesed =inimese  (PlN  >vana+inimene !12_S
30497	kubermangudeks	kubermangu	kubermang	22_S	PlTr	et	kubermangudeks =kubermangu  (PlTr  >kubermang !22_S
30505	aastateni	aasta	aasta	01_S	PlTer	et	aastateni =aasta  (PlTer  >aasta !01_S
30512	edendas	edenda	edendama	27_V	IndIpfSg3	et	edendas =edenda  (IndIpfSg3  >edendama !27_V
30516	pärisorjadeks	orja	päris+ori	24_S	PlTr	et	pärisorjadeks =orja  (PlTr  >päris+ori !24_S
30534	kritiseeris	kritiseeri	kritiseerima	28_V	IndIpfSg3	et	kritiseeris =kritiseeri  (IndIpfSg3  >kritiseerima !28_V
30539	loodusteaduste	teadus	loodus+teadus	11~09_S	PlG	et	loodusteaduste =teadus  (PlG  >loodus+teadus !11~09_S
30544	tähtsate	tähtsa	tähtis	02_A	PlG	et	tähtsate =tähtsa  (PlG  >tähtis !02_A
30546	elu-ja	ja	elu-ja	41_J	ID	et	elu-ja =ja  (ID  >elu-ja !41_J
30548	poliitik	poliitik	poliitik	02_S	SgN	et	poliitik =poliitik  (SgN  >poliitik !02_S
30549	vaimulik	vaimulik	vaimulik	25_AS	SgN	et	vaimulik =vaimulik  (SgN  >vaimulik !25_AS
30550	materiaalne	materiaalne	materiaalne	02_A	SgN	et	materiaalne =materiaalne  (SgN  >materiaalne !02_A
30554	maksud	maksu	maks	22_S	PlN	et	maksud =maksu  (PlN  >maks !22_S
30557	institutsioonidest	institutsiooni	institutsioon	22_S	PlEl	et	institutsioonidest =institutsiooni  (PlEl  >institutsioon !22_S
30563	ikke	ikke	ike	06_S	SgG	et	ikke =ikke  (SgG  >ike !06_S
30569	ägedale	ägeda	äge	02_A	SgAll	et	ägedale =ägeda  (SgAll  >äge !02_A
30578	maakoolide	kooli	maa+kool	22_S	PlG	et	maakoolide =kooli  (PlG  >maa+kool !22_S
30586	väheste	vähes	vähene	10_A	PlG	et	väheste =vähes  (PlG  >vähene !10_A
30588	ent	ent	ent	41_J	ID	et	ent =ent  (ID  >ent !41_J
30591	avalik	avalik	avalik	25_A	SgN	et	avalik =avalik  (SgN  >avalik !25_A
30593	ärkasin	ärka	ärkama	29_V	IndIpfSg1	et	ärkasin =ärka  (IndIpfSg1  >ärkama !29_V
30594	lendasime	lenda	lendama	29_V	IndIpfPl1	et	lendasime =lenda  (IndIpfPl1  >lendama !29_V
30597	hotell	hotell	hotell	22_S	SgN	et	hotell =hotell  (SgN  >hotell !22_S
30601	läksime	läk	minema	36_V	IndIpfPl1	et	läksime =läk  (IndIpfPl1  >minema !36_V
30613	jõime	jõ	jooma	38_V	IndIpfPl1	et	jõime =jõ  (IndIpfPl1  >jooma !38_V
30615	paneelmajas	maja	paneel+maja	17_S	SgIn	et	paneelmajas =maja  (SgIn  >paneel+maja !17_S
30618	tingimustes	tingimus	tingimus	11_S	PlIn	et	tingimustes =tingimus  (PlIn  >tingimus !11_S
30639	muretsema	muretse	muretsema	27_V	Sup	et	muretsema =muretse  (Sup  >muretsema !27_V
30640	magamistuppa	tuppa	magamis+tuba	18_S	SgAdt	et	magamistuppa =tuppa  (SgAdt  >magamis+tuba !18_S
30650	teeskles	teeskle	teesklema	30_V	IndIpfSg3	et	teeskles =teeskle  (IndIpfSg3  >teesklema !30_V
30653	kalendris	kalendri	kalender	02_S	SgIn	et	kalendris =kalendri  (SgIn  >kalender !02_S
30661	rannal	ranna	rand	22_S	SgAd	et	rannal =ranna  (SgAd  >rand !22_S
30662	lumest	lume	lumi	20_S	SgEl	et	lumest =lume  (SgEl  >lumi !20_S
30663	elanikke	elanikke	elanik	25_S	PlP	et	elanikke =elanikke  (PlP  >elanik !25_S
30666	vaikite	vaiki	vaikima	27_V	IndPrPl2	et	vaikite =vaiki  (IndPrPl2  >vaikima !27_V
30672	oh	oh	oh	41_I	ID	et	oh =oh  (ID  >oh !41_I
30673	kõneles	kõnele	kõnelema	31~27_V	IndIpfSg3	et	kõneles =kõnele  (IndIpfSg3  >kõnelema !31~27_V
30674	varastas	varasta	varastama	27_V	IndIpfSg3	et	varastas =varasta  (IndIpfSg3  >varastama !27_V
30679	riietub	riietu	riietuma	27_V	IndPrSg3	et	riietub =riietu  (IndPrSg3  >riietuma !27_V
30691	mutandi	mutandi	mutant	22_S	SgG	et	mutandi =mutandi  (SgG  >mutant !22_S
30696	kehaosasid	osa	keha+osa	17_S	PlP	et	kehaosasid =osa  (PlP  >keha+osa !17_S
30698	lasnamäe	mäe	lasna+mägi	21_S	SgG	et	lasnamäe =mäe  (SgG  >lasna+mägi !21_S
30703	loom	loom	loom	22_S	SgN	et	loom =loom  (SgN  >loom !22_S
30709	õnnelikud	õnneliku	õnnelik	25_A	PlN	et	õnnelikud =õnneliku  (PlN  >õnnelik !25_A
30711	tööalkohoolik	alkohoolik	töö+alkohoolik	02_S	SgN	et	tööalkohoolik =alkohoolik  (SgN  >töö+alkohoolik !02_S
30714	tütrega	tütre	tütar	08_S	SgKom	et	tütrega =tütre  (SgKom  >tütar !08_S
30727	solaariumis	solaariumi	solaarium	19~02_S	SgIn	et	solaariumis =solaariumi  (SgIn  >solaarium !19~02_S
30731	noormehe	mehe	noor+mees	13_S	SgG	et	noormehe =mehe  (SgG  >noor+mees !13_S
30732	hoolega	hoole	hool	13_S	SgKom	et	hoolega =hoole  (SgKom  >hool !13_S
30738	isand	isand	isand	02_S	SgN	et	isand =isand  (SgN  >isand !02_S
30745	temasse	tema	tema	00_P	SgIll	et	temasse =tema  (SgIll  >tema !00_P
30746	omandiks	omandi	omand	02_S	SgTr	et	omandiks =omandi  (SgTr  >omand !02_S
30754	mikrolaineahjust	ahju	mikro+laine+ahi	24_S	SgEl	et	mikrolaineahjust =ahju  (SgEl  >mikro+laine+ahi !24_S
30756	nali	nali	nali	24_S	SgN	et	nali =nali  (SgN  >nali !24_S
30760	lõpule	lõpu	lõpp	22_SA	SgAll	et	lõpule =lõpu  (SgAll  >lõpp !22_SA
30761	hüüatas	hüüata	hüüatama	27_V	IndIpfSg3	et	hüüatas =hüüata  (IndIpfSg3  >hüüatama !27_V
30500	luteri	luteri	luteri	41_G	ID	et	luteri =luteri  (ID  >luteri !41_G
30502	aadlil	aadli	aadel	02_S	SgAd	et	aadlil =aadli  (SgAd  >aadel !02_S
30511	ärkamisajal	aja	ärkamis+aeg	22_S	SgAd	et	ärkamisajal =aja  (SgAd  >ärkamis+aeg !22_S
30518	maaaadlikud	aadliku	maa+aadlik	25_S	PlN	et	maaaadlikud =aadliku  (PlN  >maa+aadlik !25_S
30521	kehale	keha	keha	17_S	SgAll	et	kehale =keha  (SgAll  >keha !17_S
30522	entsüklopeediat	entsüklopeedia	entsüklopeedia	01_S	SgP	et	entsüklopeediat =entsüklopeedia  (SgP  >entsüklopeedia !01_S
30528	balti-sakslased	sakslase	balti-sakslane	12?10_S	PlN	et	balti-sakslased =sakslase  (PlN  >balti-sakslane !12?10_S
30530	hernhuutlased	hernhuutlase	hernhuutlane	12?10_S	PlN	et	hernhuutlased =hernhuutlase  (PlN  >hernhuutlane !12?10_S
30536	pärisorjust	orjus	päris+orjus	11~09_S	SgP	et	pärisorjust =orjus  (SgP  >päris+orjus !11~09_S
30547	vilets	vilets	vilets	02_A	SgN	et	vilets =vilets  (SgN  >vilets !02_A
30551	juurdus	juurdu	juurduma	27_V	IndIpfSg3	et	juurdus =juurdu  (IndIpfSg3  >juurduma !27_V
30552	kehtima	kehti	kehtima	27_V	Sup	et	kehtima =kehti  (Sup  >kehtima !27_V
30561	kubermangud	kubermangu	kubermang	22_S	PlN	et	kubermangud =kubermangu  (PlN  >kubermang !22_S
30562	baltisakslase	sakslase	balti+sakslane	12?10_S	SgG	et	baltisakslase =sakslase  (SgG  >balti+sakslane !12?10_S
30568	külg	külg	külg	22_S	SgN	et	külg =külg  (SgN  >külg !22_S
30570	vastupanule	panu	vastu+panu	17_S	SgAll	et	vastupanule =panu  (SgAll  >vastu+panu !17_S
30572	õpetati	õpeta	õpetama	27_V	IndIpfIps	et	õpetati =õpeta  (IndIpfIps  >õpetama !27_V
30573	elementaarset	elementaarse	elementaarne	02_A	SgP	et	elementaarset =elementaarse  (SgP  >elementaarne !02_A
30574	algteadmisi	teadmisi	alg+teadmine	12_S	PlP	et	algteadmisi =teadmisi  (PlP  >alg+teadmine !12_S
30582	nekrutisse	nekruti	nekrut	02_S	SgIll	et	nekrutisse =nekruti  (SgIll  >nekrut !02_S
30592	päevik	päevik	päevik	02_S	SgN	et	päevik =päevik  (SgN  >päevik !02_S
30595	linnud	linnu	lind	22_S	PlN	et	linnud =linnu  (PlN  >lind !22_S
30596	lennujaamasse	jaama	lennu+jaam	22_S	SgIll	et	lennujaamasse =jaama  (SgIll  >lennu+jaam !22_S
30608	roose	roose	roos	22_S	PlP	et	roose =roose  (PlP  >roos !22_S
30617	vanaemaga	ema	vana+ema	17_S	SgKom	et	vanaemaga =ema  (SgKom  >vana+ema !17_S
30623	siidpehmed	pehme	siid+pehme	01_A	PlN	et	siidpehmed =pehme  (PlN  >siid+pehme !01_A
30635	kinkekaardidega	kaardi	kinke+kaard	22_S	PlKom	et	kinkekaardidega =kaardi  (PlKom  >kinke+kaard !22_S
30641	diivanile	diivani	diivan	02_S	SgAll	et	diivanile =diivani  (SgAll  >diivan !02_S
30645	huuled	huule	huul	13_S	PlN	et	huuled =huule  (PlN  >huul !13_S
30648	huuli	huul	huul	13_S	PlP	et	huuli =huul  (PlP  >huul !13_S
30655	mererannas	ranna	mere+rand	22_S	SgIn	et	mererannas =ranna  (SgIn  >mere+rand !22_S
30658	arvutimängude	mängu	arvuti+mäng	22_S	PlG	et	arvutimängude =mängu  (PlG  >arvuti+mäng !22_S
30659	küpsetas	küpseta	küpsetama	27_V	IndIpfSg3	et	küpsetas =küpseta  (IndIpfSg3  >küpsetama !27_V
30664	rannale	ranna	rand	22_S	SgAll	et	rannale =ranna  (SgAll  >rand !22_S
30667	vanaemale	ema	vana+ema	17_S	SgAll	et	vanaemale =ema  (SgAll  >vana+ema !17_S
30669	uks	uks	uks	14_S	SgN	et	uks =uks  (SgN  >uks !14_S
30676	kutsub	kutsu	kutsuma	28_V	IndPrSg3	et	kutsub =kutsu  (IndPrSg3  >kutsuma !28_V
30677	helistas	helista	helistama	27_V	IndIpfSg3	et	helistas =helista  (IndIpfSg3  >helistama !27_V
30680	ükskord	ükskord	üks+kord	41_D	ID	et	ükskord =ükskord  (ID  >üks+kord !41_D
30686	niisama	niisama	nii+sama	41_D	ID	et	niisama =niisama  (ID  >nii+sama !41_D
30688	püsti	püsti	püsti	41_D	ID	et	püsti =püsti  (ID  >püsti !41_D
30689	viia	vii	viima	38_V	Inf	et	viia =vii  (Inf  >viima !38_V
30705	pileteid	pilete	pilet	02_S	PlP	et	pileteid =pilete  (PlP  >pilet !02_S
30712	hukkus	hukku	hukkuma	27~28_V	IndIpfSg3	et	hukkus =hukku  (IndIpfSg3  >hukkuma !27~28_V
30720	pidutseda	pidutse	pidutsema	27_V	Inf	et	pidutseda =pidutse  (Inf  >pidutsema !27_V
30721	kleite	kleite	kleit	22_S	PlP	et	kleite =kleite  (PlP  >kleit !22_S
30722	luges	luge	lugema	28_V	IndIpfSg3	et	luges =luge  (IndIpfSg3  >lugema !28_V
30724	ballitantsuga	tantsu	balli+tants	22_S	SgKom	et	ballitantsuga =tantsu  (SgKom  >balli+tants !22_S
30728	juuksuris	juuksuri	juuksur	02_S	SgIn	et	juuksuris =juuksuri  (SgIn  >juuksur !02_S
30729	õed	õe	õde	18_S	PlN	et	õed =õe  (PlN  >õde !18_S
30750	lainete	laine	laine	06_S	PlG	et	lainete =laine  (PlG  >laine !06_S
30752	teatele	teate	teade	06_S	SgAll	et	teatele =teate  (SgAll  >teade !06_S
30757	särama	sära	särama	27_V	Sup	et	särama =sära  (Sup  >särama !27_V
30762	tagastada	tagasta	tagastama	27_V	Inf	et	tagastada =tagasta  (Inf  >tagastama !27_V
30763	tuppa	tuppa	tuba	18_S	SgAdt	et	tuppa =tuppa  (SgAdt  >tuba !18_S
30630	poisi	poisi	poiss	23?22_S	SgG	et	poisi =poisi  (SgG  >poiss !23?22_S
30632	sümpaatne	sümpaatne	sümpaatne	02_A	SgN	et	sümpaatne =sümpaatne  (SgN  >sümpaatne !02_A
30633	kinkis	kinki	kinkima	28_V	IndIpfSg3	et	kinkis =kinki  (IndIpfSg3  >kinkima !28_V
30637	nuusutas	nuusuta	nuusutama	27_V	IndIpfSg3	et	nuusutas =nuusuta  (IndIpfSg3  >nuusutama !27_V
30643	lamas	lama	lamama	27_V	IndIpfSg3	et	lamas =lama  (IndIpfSg3  >lamama !27_V
30647	suudles	suudle	suudlema	30_V	IndIpfSg3	et	suudles =suudle  (IndIpfSg3  >suudlema !30_V
30649	bell	bell	bell	22_S	SgN	et	bell =bell  (SgN  >bell !22_S
30660	pirukaid	piruka	pirukas	02_S	PlP	et	pirukaid =piruka  (PlP  >pirukas !02_S
30681	pitsaks	pitsa	pitsa	16_S	SgTr	et	pitsaks =pitsa  (SgTr  >pitsa !16_S
30683	taigna	taigna	taigen	02_S	SgG	et	taigna =taigna  (SgG  >taigen !02_S
30684	hull	hull	hull	22_AS	SgN	et	hull =hull  (SgN  >hull !22_AS
30685	seekord	seekord	see+kord	41_D	ID	et	seekord =seekord  (ID  >see+kord !41_D
30693	aknad	akna	aken	08_S	PlN	et	aknad =akna  (PlN  >aken !08_S
30695	korrusel	korruse	korrus	09_S	SgAd	et	korrusel =korruse  (SgAd  >korrus !09_S
30697	hüppas	hüppa	hüppama	29_V	IndIpfSg3	et	hüppas =hüppa  (IndIpfSg3  >hüppama !29_V
30706	kodunt	kodunt	kodunt	41_D	ID	et	kodunt =kodunt  (ID  >kodunt !41_D
30707	imeliku	imeliku	imelik	25_A	SgG	et	imeliku =imeliku  (SgG  >imelik !25_A
30713	kasuemaga	ema	kasu+ema	17_S	SgKom	et	kasuemaga =ema  (SgKom  >kasu+ema !17_S
30716	õnnelikuks	õnneliku	õnnelik	25_A	SgTr	et	õnnelikuks =õnneliku  (SgTr  >õnnelik !25_A
30730	elaski	ela	elama	27_V	IndIpfSg3^	et	elaski =ela  (IndIpfSg3^  >elama !27_V
30736	raamatupidajalt	pidaja	raamatu+pidaja	01_S	SgAbl	et	raamatupidajalt =pidaja  (SgAbl  >raamatu+pidaja !01_S
30741	sisemisest	sisemise	sisemine	12_A	SgEl	et	sisemisest =sisemise  (SgEl  >sisemine !12_A
30758	huviga	huvi	huvi	17_S	SgKom	et	huviga =huvi  (SgKom  >huvi !17_S
30766	kukkus	kukku	kukkuma	28_V	IndIpfSg3	et	kukkus =kukku  (IndIpfSg3  >kukkuma !28_V
30773	vaielge	vaiel	vaidlema	30_V	ImpPrPl2	et	vaielge =vaiel  (ImpPrPl2  >vaidlema !30_V
30777	linnani	linna	linn	22_S	SgTer	et	linnani =linna  (SgTer  >linn !22_S
30780	liiguvad	liigu	liikuma	28_V	IndPrPl3	et	liiguvad =liigu  (IndPrPl3  >liikuma !28_V
30798	pudelites	pudeli	pudel	02_S	PlIn	et	pudelites =pudeli  (PlIn  >pudel !02_S
30801	karjatas	karjata	karjatama	27_V	IndIpfSg3	et	karjatas =karjata  (IndIpfSg3  >karjatama !27_V
30802	pomm	pomm	pomm	22_S	SgN	et	pomm =pomm  (SgN  >pomm !22_S
30804	otsisin	otsi	otsima	28_V	IndIpfSg1	et	otsisin =otsi  (IndIpfSg1  >otsima !28_V
30812	sõidukaaslased	kaaslase	sõidu+kaaslane	12?10_S	PlN	et	sõidukaaslased =kaaslase  (PlN  >sõidu+kaaslane !12?10_S
30814	iseloomuga	loomu	ise+loom	22_S	SgKom	et	iseloomuga =loomu  (SgKom  >ise+loom !22_S
30818	asendades	asenda	asendama	27_V	Ger	et	asendades =asenda  (Ger  >asendama !27_V
30837	vanaaegsatest	aegsa	vana+aegus	02_A	PlEl	et	vanaaegsatest =aegsa  (PlEl  >vana+aegus !02_A
30839	teosteni	teos	teos	09_S	PlTer	et	teosteni =teos  (PlTer  >teos !09_S
30849	teatab	teata	teatama	27_V	IndPrSg3	et	teatab =teata  (IndPrSg3  >teatama !27_V
30857	kommentaare	kommentaare	kommentaar	22_S	PlP	et	kommentaare =kommentaare  (PlP  >kommentaar !22_S
30861	hinnangul	hinnangu	hinnang	02_S	SgAd	et	hinnangul =hinnangu  (SgAd  >hinnang !02_S
30864	ebaühtlane	ühtlane	eba+ühtlane	12?10_A	SgN	et	ebaühtlane =ühtlane  (SgN  >eba+ühtlane !12?10_A
30872	kulude	kulu	kulu	17_S	PlG	et	kulude =kulu  (PlG  >kulu !17_S
30883	autodesse	auto	auto	16_S	PlIll	et	autodesse =auto  (PlIll  >auto !16_S
30887	koostöös	töö	koos+töö	26_S	SgIn	et	koostöös =töö  (SgIn  >koos+töö !26_S
30895	koolinoorte	noor	kooli+noor	13_AS	PlG	et	koolinoorte =noor  (PlG  >kooli+noor !13_AS
30899	informatiiv-kultuurset	kultuurse	informatiiv-kultuurne	02_A	SgP	et	informatiiv-kultuurset =kultuurse  (SgP  >informatiiv-kultuurne !02_A
30911	programmide	programmi	programm	22_S	PlG	et	programmide =programmi  (PlG  >programm !22_S
30916	novembris	novembri	november	02_S	SgIn	et	novembris =novembri  (SgIn  >november !02_S
30920	autonoomiat	autonoomia	autonoomia	01_S	SgP	et	autonoomiat =autonoomia  (SgP  >autonoomia !01_S
30929	tunduks	tundu	tunduma	27_V	KndPrPs	et	tunduks =tundu  (KndPrPs  >tunduma !27_V
30932	õiges	õige	õige	01_A	SgIn	et	õiges =õige  (SgIn  >õige !01_A
30942	saartele	saar	saar	13_S	PlAll	et	saartele =saar  (PlAll  >saar !13_S
30943	kümnendi	kümnendi	kümnend	02_S	SgG	et	kümnendi =kümnendi  (SgG  >kümnend !02_S
30951	ekkeri	ekkeri	ekker	02_S	SgG	et	ekkeri =ekkeri  (SgG  >ekker !02_S
30955	kümnendil	kümnendi	kümnend	02_S	SgAd	et	kümnendil =kümnendi  (SgAd  >kümnend !02_S
30956	mingisugune	sugune	mingi+sugune	10_P	SgN	et	mingisugune =sugune  (SgN  >mingi+sugune !10_P
30737	punastas	punasta	punastama	27_V	IndIpfSg3	et	punastas =punasta  (IndIpfSg3  >punastama !27_V
30739	noormehele	mehe	noor+mees	13_S	SgAll	et	noormehele =mehe  (SgAll  >noor+mees !13_S
30742	ilust	ilu	ilu	17_S	SgEl	et	ilust =ilu  (SgEl  >ilu !17_S
30743	sisemine	sisemine	sisemine	12_A	SgN	et	sisemine =sisemine  (SgN  >sisemine !12_A
30744	protseduurid	protseduuri	protseduur	22_S	PlN	et	protseduurid =protseduuri  (PlN  >protseduur !22_S
30747	teleri	teleri	teler	02_S	SgG	et	teleri =teleri  (SgG  >teler !02_S
30748	mikrolaineahi	ahi	mikro+laine+ahi	24_S	SgN	et	mikrolaineahi =ahi  (SgN  >mikro+laine+ahi !24_S
30749	öeldi	öel	ütlema	30_V	IndIpfIps	et	öeldi =öel  (IndIpfIps  >ütlema !30_V
30753	avastas	avasta	avastama	27_V	IndIpfSg3	et	avastas =avasta  (IndIpfSg3  >avastama !27_V
30755	kuldse	kuldse	kuldne	02_A	SgG	et	kuldse =kuldse  (SgG  >kuldne !02_A
30759	mured	mure	mure	16_S	PlN	et	mured =mure  (PlN  >mure !16_S
30767	põrandal	põranda	põrand	02_S	SgAd	et	põrandal =põranda  (SgAd  >põrand !02_S
30769	patus	patu	patt	22_S	SgIn	et	patus =patu  (SgIn  >patt !22_S
30770	nutt	nutt	nutt	22_S	SgN	et	nutt =nutt  (SgN  >nutt !22_S
30772	imelikud	imeliku	imelik	25_A	PlN	et	imelikud =imeliku  (PlN  >imelik !25_A
30786	silmadest	silma	silm	22_S	PlEl	et	silmadest =silma  (PlEl  >silm !22_S
30789	rongipidurite	piduri	rongi+pidur	02_S	PlG	et	rongipidurite =piduri  (PlG  >rongi+pidur !02_S
30806	ehmusin	ehmu	ehmuma	27_V	IndIpfSg1	et	ehmusin =ehmu  (IndIpfSg1  >ehmuma !27_V
30807	tarvis	tarvis	tarvis	41_DK	ID	et	tarvis =tarvis  (ID  >tarvis !41_DK
30810	igale	iga	iga	17_P	SgAll	et	igale =iga  (SgAll  >iga !17_P
30824	õppisime	õppi	õppima	28_V	IndIpfPl1	et	õppisime =õppi  (IndIpfPl1  >õppima !28_V
30827	praeguses	praeguse	praegune	10~12_A	SgIn	et	praeguses =praeguse  (SgIn  >praegune !10~12_A
30833	koorikollektiivides	kollektiivi	koori+kollektiiv	22_S	PlIn	et	koorikollektiivides =kollektiivi  (PlIn  >koori+kollektiiv !22_S
30836	repertuaaris	repertuaari	repertuaar	22_S	SgIn	et	repertuaaris =repertuaari  (SgIn  >repertuaar !22_S
30838	kirikulauludest	laulu	kiriku+laul	22_S	PlEl	et	kirikulauludest =laulu  (PlEl  >kiriku+laul !22_S
30845	kontserdil	kontserdi	kontsert	22_S	SgAd	et	kontserdil =kontserdi  (SgAd  >kontsert !22_S
30850	aseesimehe	mehe	ase+esi+mees	13_S	SgG	et	aseesimehe =mehe  (SgG  >ase+esi+mees !13_S
30853	seisundis	seisundi	seisund	02_S	SgIn	et	seisundis =seisundi  (SgIn  >seisund !02_S
30855	taseme	taseme	tase	04_S	SgG	et	taseme =taseme  (SgG  >tase !04_S
30869	teaduslikule	teadusliku	teaduslik	25_A	SgAll	et	teaduslikule =teadusliku  (SgAll  >teaduslik !25_A
30875	tehnoloogiate	tehnoloogia	tehnoloogia	01_S	PlG	et	tehnoloogiate =tehnoloogia  (PlG  >tehnoloogia !01_S
30885	muuseumiga	muuseumi	muuseum	19~02_S	SgKom	et	muuseumiga =muuseumi  (SgKom  >muuseum !19~02_S
30889	turistimarsruudi	marsruudi	turisti+marsruut	22_S	SgG	et	turistimarsruudi =marsruudi  (SgG  >turisti+marsruut !22_S
30893	doktorikraadiga	kraadi	doktori+kraad	22_S	SgKom	et	doktorikraadiga =kraadi  (SgKom  >doktori+kraad !22_S
30897	väljapanekuga	paneku	välja+panek	02_S	SgKom	et	väljapanekuga =paneku  (SgKom  >välja+panek !02_S
30898	projektist	projekti	projekt	22_S	SgEl	et	projektist =projekti  (SgEl  >projekt !22_S
30900	põhineb	põhine	põhinema	27_V	IndPrSg3	et	põhineb =põhine  (IndPrSg3  >põhinema !27_V
30902	kogemusel	kogemuse	kogemus	11_S	SgAd	et	kogemusel =kogemuse  (SgAd  >kogemus !11_S
30915	2006aastal	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
30922	kongress	kongress	kongress	22_S	SgN	et	kongress =kongress  (SgN  >kongress !22_S
30923	kinnitada	kinnita	kinnitama	27_V	Inf	et	kinnitada =kinnita  (Inf  >kinnitama !27_V
30926	suursaadikute	saadiku	suur+saadik	02_S	PlG	et	suursaadikute =saadiku  (PlG  >suur+saadik !02_S
30935	rõhutades	rõhuta	rõhutama	27_V	Ger	et	rõhutades =rõhuta  (Ger  >rõhutama !27_V
30941	venemaast	maa	vene+maa	26_S	SgEl	et	venemaast =maa  (SgEl  >vene+maa !26_S
30946	oktoobri	oktoobri	oktoober	02_S	SgG	et	oktoobri =oktoobri  (SgG  >oktoober !02_S
30950	järeltulijaid	tulija	järel+tulija	01_S	PlP	et	järeltulijaid =tulija  (PlP  >järel+tulija !01_S
30952	korrespondendile	korrespondendi	korrespondent	22_S	SgAll	et	korrespondendile =korrespondendi  (SgAll  >korrespondent !22_S
30963	summutada	summuta	summutama	27_V	Inf	et	summutada =summuta  (Inf  >summutama !27_V
30965	elanikuga	elaniku	elanik	25_S	SgKom	et	elanikuga =elaniku  (SgKom  >elanik !25_S
30972	süüakse	süü	sööma	38_V	IndPrIps	et	süüakse =süü  (IndPrIps  >sööma !38_V
30974	ahjud	ahju	ahi	24_S	PlN	et	ahjud =ahju  (PlN  >ahi !24_S
30984	pilk	pilk	pilk	22_S	SgN	et	pilk =pilk  (SgN  >pilk !22_S
30990	tempel	tempel	tempel	02_S	SgN	et	tempel =tempel  (SgN  >tempel !02_S
31003	projektide	projekti	projekt	22_S	PlG	et	projektide =projekti  (PlG  >projekt !22_S
30764	munaga	muna	muna	17_S	SgKom	et	munaga =muna  (SgKom  >muna !17_S
30775	kupees	kupee	kupee	26_S	SgIn	et	kupees =kupee  (SgIn  >kupee !26_S
30778	asun	asu	asuma	27_V	IndPrSg1	et	asun =asu  (IndPrSg1  >asuma !27_V
30779	mürin	mürin	mürin	02_S	SgN	et	mürin =mürin  (SgN  >mürin !02_S
30781	kõrvalistuvast	istuva	kõrval+istuv	02_A	SgEl	et	kõrvalistuvast =istuva  (SgEl  >kõrval+istuv !02_A
30782	eemale	eemale	eemale	41_D	ID	et	eemale =eemale  (ID  >eemale !41_D
30784	metsades	metsa	mets	22_S	PlIn	et	metsades =metsa  (PlIn  >mets !22_S
30794	kohver	kohver	kohver	02_S	SgN	et	kohver =kohver  (SgN  >kohver !02_S
30796	püstol	püstol	püstol	02_S	SgN	et	püstol =püstol  (SgN  >püstol !02_S
30803	ohkas	ohka	ohkama	29_V	IndIpfSg3	et	ohkas =ohka  (IndIpfSg3  >ohkama !29_V
30813	kaassõitjate	sõitja	kaas+sõitja	01_S	PlG	et	kaassõitjate =sõitja  (PlG  >kaas+sõitja !01_S
30815	lõunaossa	ossa	lõuna+osa	17_S	SgAdt	et	lõunaossa =ossa  (SgAdt  >lõuna+osa !17_S
30820	h-ga	h	h	xx_Q	SgKom	et	h-ga =h  (SgKom  >h !xx_Q
30821	hääldada	häälda	hääldama	27_V	Inf	et	hääldada =häälda  (Inf  >hääldama !27_V
30822	hääldasime	häälda	hääldama	27_V	IndIpfPl1	et	hääldasime =häälda  (IndIpfPl1  >hääldama !27_V
30825	austama	austa	austama	27_V	Sup	et	austama =austa  (Sup  >austama !27_V
30831	kavas	kava	kava	17_S	SgIn	et	kavas =kava  (SgIn  >kava !17_S
30832	lauluansambel	ansambel	laulu+ansambel	02_S	SgN	et	lauluansambel =ansambel  (SgN  >laulu+ansambel !02_S
30834	ooperiteatrites	teatri	ooperi+teater	02_S	PlIn	et	ooperiteatrites =teatri  (PlIn  >ooperi+teater !02_S
30847	sabas	saba	saba	17_S	SgIn	et	sabas =saba  (SgIn  >saba !17_S
30848	sörgib	sörgi	sörkima	28_V	IndPrSg3	et	sörgib =sörgi  (IndPrSg3  >sörkima !28_V
30851	dünaamikas	dünaamika	dünaamika	01_S	SgIn	et	dünaamikas =dünaamika  (SgIn  >dünaamika !01_S
30852	absoluutses	absoluutse	absoluutne	02_A	SgIn	et	absoluutses =absoluutse  (SgIn  >absoluutne !02_A
30858	uuringu	uuringu	uuring	02_S	SgG	et	uuringu =uuringu  (SgG  >uuring !02_S
30863	nõrk	nõrk	nõrk	22_A	SgN	et	nõrk =nõrk  (SgN  >nõrk !22_A
30865	investeeringu	investeeringu	investeering	02_S	SgG	et	investeeringu =investeeringu  (SgG  >investeering !02_S
30868	ettevõtete	võte	ette+võte	06_S	PlG	et	ettevõtete =võte  (PlG  >ette+võte !06_S
30874	erialade	ala	eri+ala	17_S	PlG	et	erialade =ala  (PlG  >eri+ala !17_S
30876	tagasihoidlikul	hoidliku	tagasi+hoidlik	25_A	SgAd	et	tagasihoidlikul =hoidliku  (SgAd  >tagasi+hoidlik !25_A
30877	teostama	teosta	teostama	27_V	Sup	et	teostama =teosta  (Sup  >teostama !27_V
30884	inimesse	inimes	inimene	12_S	SgAdt	et	inimesse =inimes  (SgAdt  >inimene !12_S
30901	edukal	eduka	edukas	02_A	SgAd	et	edukal =eduka  (SgAd  >edukas !02_A
30904	virtuaalne	virtuaalne	virtuaalne	02_A	SgN	et	virtuaalne =virtuaalne  (SgN  >virtuaalne !02_A
30907	eesmärgil	märgi	ees+märk	22_S	SgAd	et	eesmärgil =märgi  (SgAd  >ees+märk !22_S
30908	aastaga	aasta	aasta	01_S	SgKom	et	aastaga =aasta  (SgKom  >aasta !01_S
30910	virtuaalsete	virtuaalse	virtuaalne	02_A	PlG	et	virtuaalsete =virtuaalse  (PlG  >virtuaalne !02_A
30931	tehniline	tehniline	tehniline	12_A	SgN	et	tehniline =tehniline  (SgN  >tehniline !12_A
30933	eesmargiks	margi	ees+mark	22_S	SgTr	et	eesmargiks =margi  (SgTr  >ees+mark !22_S
30934	neidudega	neidu	neid	22_S	PlKom	et	neidudega =neidu  (PlKom  >neid !22_S
30936	lovel	love	lovi	20_S	SgAd	et	lovel =love  (SgAd  >lovi !20_S
30937	ihkan	ihka	ihkama	29_V	IndPrSg1	et	ihkan =ihka  (IndPrSg1  >ihkama !29_V
30940	lühend	lühend	lühend	02_S	SgN	et	lühend =lühend  (SgN  >lühend !02_S
30948	ohvitseride	ohvitseri	ohvitser	19_S	PlG	et	ohvitseride =ohvitseri  (PlG  >ohvitser !19_S
30954	perekonnanimega	nime	pere+konna+nimi	20_S	SgKom	et	perekonnanimega =nime  (SgKom  >pere+konna+nimi !20_S
30964	saarte	saar	saar	13_S	PlG	et	saarte =saar  (PlG  >saar !13_S
30966	kujuneda	kujune	kujunema	27_V	Inf	et	kujuneda =kujune  (Inf  >kujunema !27_V
30967	naudinguks	naudingu	nauding	02_S	SgTr	et	naudinguks =naudingu  (SgTr  >nauding !02_S
30973	ehtsat	ehtsa	ehtne	02_A	SgP	et	ehtsat =ehtsa  (SgP  >ehtne !02_A
30977	muuseas	muuseas	muu+seas	41_D	ID	et	muuseas =muuseas  (ID  >muu+seas !41_D
30979	selgeks	selge	selge	01_A	SgTr	et	selgeks =selge  (SgTr  >selge !01_A
30989	kujuga	kuju	kuju	17_S	SgKom	et	kujuga =kuju  (SgKom  >kuju !17_S
30991	samasugune	sugune	sama+sugune	10_P	SgN	et	samasugune =sugune  (SgN  >sama+sugune !10_P
30994	jõulupühi	pühi	jõulu+püha	17_SA	PlP	et	jõulupühi =pühi  (PlP  >jõulu+püha !17_SA
31000	neljapäeval	päeva	nelja+päev	22_S	SgAd	et	neljapäeval =päeva  (SgAd  >nelja+päev !22_S
31002	konkreetsete	konkreetse	konkreetne	02_A	PlG	et	konkreetsete =konkreetse  (PlG  >konkreetne !02_A
30765	komistas	komista	komistama	27_V	IndIpfSg3	et	komistas =komista  (IndIpfSg3  >komistama !27_V
30768	nutma	nut	nutma	35_V	Sup	et	nutma =nut  (Sup  >nutma !35_V
30771	köögist	köögi	köök	22_S	SgEl	et	köögist =köögi  (SgEl  >köök !22_S
30774	munen	mune	munema	27_V	IndPrSg1	et	munen =mune  (IndPrSg1  >munema !27_V
30776	vaadates	vaada	vaatama	29_V	Ger	et	vaadates =vaada  (Ger  >vaatama !29_V
30785	üksteisega	teise	üks+teise	12_P	SgKom	et	üksteisega =teise  (SgKom  >üks+teise !12_P
30787	mõtteid	mõtte	mõte	06_S	PlP	et	mõtteid =mõtte  (PlP  >mõte !06_S
30788	mõttetest	test	mõtte+test	22_S	SgN	et	mõttetest =test  (SgN  >mõtte+test !22_S
30792	põrandale	põranda	põrand	02_S	SgAll	et	põrandale =põranda  (SgAll  >põrand !02_S
30800	terroristid	terroristi	terrorist	22_S	PlN	et	terroristid =terroristi  (PlN  >terrorist !22_S
30805	korjas	korja	korjama	29_V	IndIpfSg3	et	korjas =korja  (IndIpfSg3  >korjama !29_V
30808	kõndis	kõndi	kõndima	28_V	IndIpfSg3	et	kõndis =kõndi  (IndIpfSg3  >kõndima !28_V
30809	toibudes	toibu	toibuma	27_V	Ger	et	toibudes =toibu  (Ger  >toibuma !27_V
30811	tänulik	tänulik	tänulik	25_A	SgN	et	tänulik =tänulik  (SgN  >tänulik !25_A
30819	häälikut	hääliku	häälik	02_S	SgP	et	häälikut =hääliku  (SgP  >häälik !02_S
30823	g-na	g	g	xx_Q	SgEs	et	g-na =g  (SgEs  >g !xx_Q
30828	kosmopoliitses	kosmopoliitse	kosmopoliitne	02_A	SgIn	et	kosmopoliitses =kosmopoliitse  (SgIn  >kosmopoliitne !02_A
30830	lauluansambli	ansambli	laulu+ansambel	02_S	SgG	et	lauluansambli =ansambli  (SgG  >laulu+ansambel !02_S
30835	solistidena	solisti	solist	22_S	PlEs	et	solistidena =solisti  (PlEs  >solist !22_S
30840	esitab	esita	esitama	27_V	IndPrSg3	et	esitab =esita  (IndPrSg3  >esitama !27_V
30842	kuulsate	kuulsa	kuulus	02_A	PlG	et	kuulsate =kuulsa  (PlG  >kuulus !02_A
30844	liikmete	liikme	liige	05_S	PlG	et	liikmete =liikme  (PlG  >liige !05_S
30846	äripäev	päev	äri+päev	22_S	SgN	et	äripäev =päev  (SgN  >äri+päev !22_S
30862	liidritega	liidri	liider	02_S	PlKom	et	liidritega =liidri  (PlKom  >liider !02_S
30867	esikolmikus	kolmiku	esi+kolmik	02_S	SgIn	et	esikolmikus =kolmiku  (SgIn  >esi+kolmik !02_S
30871	uurimustööle	töö	uurimus+töö	26_S	SgAll	et	uurimustööle =töö  (SgAll  >uurimus+töö !26_S
30873	loodus-teaduslike	teaduslike	loodus-teaduslik	25_A	PlG	et	loodus-teaduslike =teaduslike  (PlG  >loodus-teaduslik !25_A
30878	teaduslike	teaduslike	teaduslik	25_A	PlG	et	teaduslike =teaduslike  (PlG  >teaduslik !25_A
30879	strateegiat	strateegia	strateegia	01_S	SgP	et	strateegiat =strateegia  (SgP  >strateegia !01_S
30881	ettevõtjad	võtja	ette+võtja	01_S	PlN	et	ettevõtjad =võtja  (PlN  >ette+võtja !01_S
30882	investeerima	investeeri	investeerima	28_V	Sup	et	investeerima =investeeri  (Sup  >investeerima !28_V
30886	põlevkivimuuseum	muuseum	põlev+kivi+muuseum	19~02_S	SgN	et	põlevkivimuuseum =muuseum  (SgN  >põlev+kivi+muuseum !19~02_S
30888	linnavalitsusega	valitsuse	linna+valitsus	11_S	SgKom	et	linnavalitsusega =valitsuse  (SgKom  >linna+valitsus !11_S
30891	projekt	projekt	projekt	22_S	SgN	et	projekt =projekt  (SgN  >projekt !22_S
30894	viime	vii	viima	38_V	IndPrPl1	et	viime =vii  (IndPrPl1  >viima !38_V
30903	strukturaalseks	strukturaalse	strukturaalne	02_A	SgTr	et	strukturaalseks =strukturaalse  (SgTr  >strukturaalne !02_A
30905	filiaal	filiaal	filiaal	22_S	SgN	et	filiaal =filiaal  (SgN  >filiaal !22_S
30912	virtuaalses	virtuaalse	virtuaalne	02_A	SgIn	et	virtuaalses =virtuaalse  (SgIn  >virtuaalne !02_A
30918	avaneb	avane	avanema	27_V	IndPrSg3	et	avaneb =avane  (IndPrSg3  >avanema !27_V
30919	töögrupi	grupi	töö+grupp	22_S	SgG	et	töögrupi =grupi  (SgG  >töö+grupp !22_S
30924	läbirääkimised	rääkimise	läbi+rääkimine	12_S	PlN	et	läbirääkimised =rääkimise  (PlN  >läbi+rääkimine !12_S
30925	saarele	saare	saar	13_S	SgAll	et	saarele =saare  (SgAll  >saar !13_S
30927	major	major	major	02_S	SgN	et	major =major  (SgN  >major !02_S
30930	sõjaväe	väe	sõja+vägi	21_S	SgG	et	sõjaväe =väe  (SgG  >sõja+vägi !21_S
30938	väljendist	väljendi	väljend	02_S	SgEl	et	väljendist =väljendi  (SgEl  >väljend !02_S
30939	murdis	murd	murdma	34_V	IndIpfSg3	et	murdis =murd  (IndIpfSg3  >murdma !34_V
30945	sõjas	sõja	sõda	18_S	SgIn	et	sõjas =sõja  (SgIn  >sõda !18_S
30958	toimetatakse	toimeta	toimetama	27_V	IndPrIps	et	toimetatakse =toimeta  (IndPrIps  >toimetama !27_V
30959	samadeks	sama	sama	17_P	PlTr	et	samadeks =sama  (PlTr  >sama !17_P
30961	vana-vanaisade	isa	vana-vana+isa	17_S	PlG	et	vana-vanaisade =isa  (PlG  >vana-vana+isa !17_S
30968	att	att	att	22_S	SgN	et	att =att  (SgN  >att !22_S
30969	suust	suu	suu	26_S	SgEl	et	suust =suu  (SgEl  >suu !26_S
30970	kuur	kuur	kuur	22_S	SgN	et	kuur =kuur  (SgN  >kuur !22_S
30985	heita	heit	heitma	34_V	Inf	et	heita =heit  (Inf  >heitma !34_V
30783	meenutas	meenuta	meenutama	27_V	IndIpfSg3	et	meenutas =meenuta  (IndIpfSg3  >meenutama !27_V
30790	rong	rong	rong	22_S	SgN	et	rong =rong  (SgN  >rong !22_S
30791	hoogsa	hoogsa	hoogne	02_A	SgG	et	hoogsa =hoogsa  (SgG  >hoogne !02_A
30793	pruun	pruun	pruun	22_AS	SgN	et	pruun =pruun  (SgN  >pruun !22_AS
30795	silmaga	silma	silm	22_S	SgKom	et	silmaga =silma  (SgKom  >silm !22_S
30797	vedelik	vedelik	vedelik	25_S	SgN	et	vedelik =vedelik  (SgN  >vedelik !25_S
30799	nöör	nöör	nöör	22_S	SgN	et	nöör =nöör  (SgN  >nöör !22_S
30816	pingil	pingi	pink	22_S	SgAd	et	pingil =pingi  (SgAd  >pink !22_S
30817	looduseannetega	anne	looduse+anne	06_S	PlKom	et	looduseannetega =anne  (PlKom  >looduse+anne !06_S
30826	rahvustele	rahvus	rahvus	11~09_S	PlAll	et	rahvustele =rahvus  (PlAll  >rahvus !11~09_S
30829	sagedasti	sagedasti	sagedasti	41_D	ID	et	sagedasti =sagedasti  (ID  >sagedasti !41_D
30841	lüürilisi	lüürilisi	lüüriline	12_A	PlP	et	lüürilisi =lüürilisi  (PlP  >lüüriline !12_A
30843	ansambli	ansambli	ansambel	02_S	SgG	et	ansambli =ansambli  (SgG  >ansambel !02_S
30854	täpsustada	täpsusta	täpsustama	27_V	Inf	et	täpsustada =täpsusta  (Inf  >täpsustama !27_V
30856	poolast	ast	pool+ast	22_S	SgN	et	poolast =ast  (SgN  >pool+ast !22_S
30859	teenistuse	teenistuse	teenistus	11_S	SgG	et	teenistuse =teenistuse  (SgG  >teenistus !11_S
30860	positsioonid	positsiooni	positsioon	22_S	PlN	et	positsioonid =positsiooni  (PlN  >positsioon !22_S
30866	kõrgharidusega	hariduse	kõrg+haridus	11_S	SgKom	et	kõrgharidusega =hariduse  (SgKom  >kõrg+haridus !11_S
30870	erasektori	sektori	era+sektor	02_S	SgG	et	erasektori =sektori  (SgG  >era+sektor !02_S
30880	parlamendi	parlamendi	parlament	22_S	SgG	et	parlamendi =parlamendi  (SgG  >parlament !22_S
30890	virtuaalse	virtuaalse	virtuaalne	02_A	SgG	et	virtuaalse =virtuaalse  (SgG  >virtuaalne !02_A
30892	jätkame	jätka	jätkama	29_V	IndPrPl1	et	jätkame =jätka  (IndPrPl1  >jätkama !29_V
30896	visiidi	visiidi	visiit	22_S	SgG	et	visiidi =visiidi  (SgG  >visiit !22_S
30906	abiga	abi	abi	17_S	SgKom	et	abiga =abi  (SgKom  >abi !17_S
30909	õppekursust	kursus	õppe+kursus	11~09_S	SgP	et	õppekursust =kursus  (SgP  >õppe+kursus !11~09_S
30913	filiaalis	filiaali	filiaal	22_S	SgIn	et	filiaalis =filiaali  (SgIn  >filiaal !22_S
30914	kursi	kursi	kurss	22_S	SgG	et	kursi =kursi  (SgG  >kurss !22_S
30917	olümpiaadist	olümpiaadi	olümpiaad	22_S	SgEl	et	olümpiaadist =olümpiaadi  (SgEl  >olümpiaad !22_S
30921	auks	au	au	26_S	SgTr	et	auks =au  (SgTr  >au !26_S
30928	käe	käe	käsi	15_S	SgG	et	käe =käe  (SgG  >käsi !15_S
30944	lammutati	lammuta	lammutama	27_V	IndIpfIps	et	lammutati =lammuta  (IndIpfIps  >lammutama !27_V
30947	revolutsioonini	revolutsiooni	revolutsioon	22_S	SgTer	et	revolutsioonini =revolutsiooni  (SgTer  >revolutsioon !22_S
30949	meistrite	meistri	meister	02_S	PlG	et	meistrite =meistri  (PlG  >meister !02_S
30953	tendentsist	tendentsi	tendents	22_S	SgEl	et	tendentsist =tendentsi  (SgEl  >tendents !22_S
30957	buum	buum	buum	22_S	SgN	et	buum =buum  (SgN  >buum !22_S
30960	lahenes	lahene	lahenema	27_V	IndIpfSg3	et	lahenes =lahene  (IndIpfSg3  >lahenema !27_V
30980	õhuakende	aken	õhu+aken	08_S	PlG	et	õhuakende =aken  (PlG  >õhu+aken !08_S
30981	lihtsustas	lihtsusta	lihtsustama	27_V	IndIpfSg3	et	lihtsustas =lihtsusta  (IndIpfSg3  >lihtsustama !27_V
30983	imestage	imesta	imestama	27_V	ImpPrPl2	et	imestage =imesta  (ImpPrPl2  >imestama !27_V
30987	medalit	medali	medal	02_S	SgP	et	medalit =medali  (SgP  >medal !02_S
30993	hakatigi	haka	hakkama	29_V	IndIpfIps^	et	hakatigi =haka  (IndIpfIps^  >hakkama !29_V
30995	istungil	istungi	istung	02_S	SgAd	et	istungil =istungi  (SgAd  >istung !02_S
30997	peamisteks	peamis	peamine	12?10_A	PlTr	et	peamisteks =peamis  (PlTr  >peamine !12?10_A
30999	seni	seni	seni	41_D	ID	et	seni =seni  (ID  >seni !41_D
31001	eesmärkidele	märki	ees+märk	22_S	PlAll	et	eesmärkidele =märki  (PlAll  >ees+märk !22_S
31008	taastada	taasta	taastama	27_V	Inf	et	taastada =taasta  (Inf  >taastama !27_V
31010	maju	maju	maja	17_S	PlP	et	maju =maju  (PlP  >maja !17_S
31019	eelseisva	seisva	eel+seisev	02_A	SgG	et	eelseisva =seisva  (SgG  >eel+seisev !02_A
31023	kvartali	kvartali	kvartal	02_S	SgG	et	kvartali =kvartali  (SgG  >kvartal !02_S
31028	teatavasti	teatavasti	teatavasti	41_D	ID	et	teatavasti =teatavasti  (ID  >teatavasti !41_D
31032	mahukad	mahuka	mahukas	02_A	PlN	et	mahukad =mahuka  (PlN  >mahukas !02_A
31036	kimbutama	kimbuta	kimbutama	27_V	Sup	et	kimbutama =kimbuta  (Sup  >kimbutama !27_V
31041	sotsiaalobjektide	objekti	sotsiaal+objekt	22_S	PlG	et	sotsiaalobjektide =objekti  (PlG  >sotsiaal+objekt !22_S
31042	munitsipaalkoolid	kooli	munitsipaal+kool	22_S	PlN	et	munitsipaalkoolid =kooli  (PlN  >munitsipaal+kool !22_S
31053	supelrannad	ranna	supel+rand	22_S	PlN	et	supelrannad =ranna  (PlN  >supel+rand !22_S
30962	kõnet	kõne	kõne	16_S	SgP	et	kõnet =kõne  (SgP  >kõne !16_S
30971	leib	leib	leib	22_S	SgN	et	leib =leib  (SgN  >leib !22_S
30975	pirukad	piruka	pirukas	02_S	PlN	et	pirukad =piruka  (PlN  >pirukas !02_S
30976	õhuaken	aken	õhu+aken	08_S	SgN	et	õhuaken =aken  (SgN  >õhu+aken !08_S
30978	elanikele	elanike	elanik	25_S	PlAll	et	elanikele =elanike  (PlAll  >elanik !25_S
30982	külakost	kost	küla+kost	22_S	SgN	et	külakost =kost  (SgN  >küla+kost !22_S
30992	medalitel	medali	medal	02_S	PlAd	et	medalitel =medali  (PlAd  >medal !02_S
31004	eelseisvaks	seisva	eel+seisev	02_A	SgTr	et	eelseisvaks =seisva  (SgTr  >eel+seisev !02_A
31007	lammutada	lammuta	lammutama	27_V	Inf	et	lammutada =lammuta  (Inf  >lammutama !27_V
31012	rajatisi	rajatisi	rajatis	11_S	PlP	et	rajatisi =rajatisi  (PlP  >rajatis !11_S
31016	väljanägemisega	nägemise	välja+nägemine	12_S	SgKom	et	väljanägemisega =nägemise  (SgKom  >välja+nägemine !12_S
31031	lähiaastate	aasta	lähi+aasta	01_S	PlG	et	lähiaastate =aasta  (PlG  >lähi+aasta !01_S
31039	transpordisõlm	sõlm	transpordi+sõlm	22_S	SgN	et	transpordisõlm =sõlm  (SgN  >transpordi+sõlm !22_S
31043	tehnikavahenditega	vahendi	tehnika+vahend	02_S	PlKom	et	tehnikavahenditega =vahendi  (PlKom  >tehnika+vahend !02_S
31052	meelispuhkepaik	paik	meelis+puhke+paik	22_S	SgN	et	meelispuhkepaik =paik  (SgN  >meelis+puhke+paik !22_S
31056	rannajoon	joon	ranna+joon	13_S	SgN	et	rannajoon =joon  (SgN  >ranna+joon !13_S
31059	heakorrastada	korrasta	hea+korrastama	27_V	Inf	et	heakorrastada =korrasta  (Inf  >hea+korrastama !27_V
31060	supelrannale	ranna	supel+rand	22_S	SgAll	et	supelrannale =ranna  (SgAll  >supel+rand !22_S
31063	kadriorus	oru	kadri+org	22_S	SgIn	et	kadriorus =oru  (SgIn  >kadri+org !22_S
31081	kohvikukontserte	kontserte	kohviku+kontsert	22_S	PlP	et	kohvikukontserte =kontserte  (PlP  >kohviku+kontsert !22_S
31087	sisekujunduse	kujunduse	sise+kujundus	11_S	SgG	et	sisekujunduse =kujunduse  (SgG  >sise+kujundus !11_S
31088	argipäevadel	päeva	argi+päev	22_S	PlAd	et	argipäevadel =päeva  (PlAd  >argi+päev !22_S
31094	iidsed	iidse	iidne	02_A	PlN	et	iidsed =iidse  (PlN  >iidne !02_A
31098	harvaesitatud	esitatu	harva+esitatu	01_S	PlN	et	harvaesitatud =esitatu  (PlN  >harva+esitatu !01_S
31099	ansambel	ansambel	ansambel	02_S	SgN	et	ansambel =ansambel  (SgN  >ansambel !02_S
31103	kogunisti	kogunisti	kogunisti	41_D	ID	et	kogunisti =kogunisti  (ID  >kogunisti !41_D
31114	üldsegi	üldse	üldse	41_D	ID^	et	üldsegi =üldse  (ID^  >üldse !41_D
31117	jätkab	jätka	jätkama	29_V	IndPrSg3	et	jätkab =jätka  (IndPrSg3  >jätkama !29_V
31126	noori	noor	noor	13_AS	PlP	et	noori =noor  (PlP  >noor !13_AS
31133	eduka	eduka	edukas	02_A	SgG	et	eduka =eduka  (SgG  >edukas !02_A
31139	hoogustada	hoogusta	hoogustama	27_V	Inf	et	hoogustada =hoogusta  (Inf  >hoogustama !27_V
31141	põhjalikul	põhjaliku	põhjalik	25_A	SgAd	et	põhjalikul =põhjaliku  (SgAd  >põhjalik !25_A
31144	tudengite	tudengi	tudeng	02_S	PlG	et	tudengite =tudengi  (PlG  >tudeng !02_S
31150	publiku	publiku	publik	02_S	SgG	et	publiku =publiku  (SgG  >publik !02_S
31160	saarel	saare	saar	13_S	SgAd	et	saarel =saare  (SgAd  >saar !13_S
31161	linnak	linnak	linnak	02_S	SgN	et	linnak =linnak  (SgN  >linnak !02_S
31167	tähendama	tähenda	tähendama	27_V	Sup	et	tähendama =tähenda  (Sup  >tähendama !27_V
31168	asunikud	asuniku	asunik	25_S	PlN	et	asunikud =asuniku  (PlN  >asunik !25_S
31187	suus	suu	suu	26_S	SgIn	et	suus =suu  (SgIn  >suu !26_S
31193	õhuaknad	akna	õhu+aken	08_S	PlN	et	õhuaknad =akna  (PlN  >õhu+aken !08_S
31195	elamute	elamu	elamu	01_S	PlG	et	elamute =elamu  (PlG  >elamu !01_S
31202	medal	medal	medal	02_S	SgN	et	medal =medal  (SgN  >medal !02_S
31205	saatkonnalinn	linn	saat+konna+linn	22_S	SgN	et	saatkonnalinn =linn  (SgN  >saat+konna+linn !22_S
31208	armastusavaldusi	avaldusi	armastus+avaldus	11_S	PlP	et	armastusavaldusi =avaldusi  (PlP  >armastus+avaldus !11_S
31209	noormehed	mehe	noor+mees	13_S	PlN	et	noormehed =mehe  (PlN  >noor+mees !13_S
31210	lõhub	lõhu	lõhkuma	28_V	IndPrSg3	et	lõhub =lõhu  (IndPrSg3  >lõhkuma !28_V
31211	krimmisõja	sõja	krimmi+sõda	18_S	SgG	et	krimmisõja =sõja  (SgG  >krimmi+sõda !18_S
31217	uuena	uue	uus	14_A	SgEs	et	uuena =uue  (SgEs  >uus !14_A
31227	õhuaknaid	akna	õhu+aken	08_S	PlP	et	õhuaknaid =akna  (PlP  >õhu+aken !08_S
31229	präänik	präänik	präänik	02_S	SgN	et	präänik =präänik  (SgN  >präänik !02_S
31230	kirjaga	kirja	kiri	24_S	SgKom	et	kirjaga =kirja  (SgKom  >kiri !24_S
31243	koristada	korista	koristama	27_V	Inf	et	koristada =korista  (Inf  >koristama !27_V
31244	majahoidjad	hoidja	maja+hoidja	01_S	PlN	et	majahoidjad =hoidja  (PlN  >maja+hoidja !01_S
31251	õhul	õhu	õhk	22_S	SgAd	et	õhul =õhu  (SgAd  >õhk !22_S
30986	hoopisordenit	ordeni	hoopis+orden	02_S	SgP	et	hoopisordenit =ordeni  (SgP  >hoopis+orden !02_S
30988	präänikute	prääniku	präänik	02_S	PlG	et	präänikute =prääniku  (PlG  >präänik !02_S
30996	põhjapoolne	poolne	põhja+poolne	02_A	SgN	et	põhjapoolne =poolne  (SgN  >põhja+poolne !02_A
30998	asjaoludeks	olu	asja+olu	17_S	PlTr	et	asjaoludeks =olu  (PlTr  >asja+olu !17_S
31011	väärtuslikke	väärtuslikke	väärtuslik	25_A	PlP	et	väärtuslikke =väärtuslikke  (PlP  >väärtuslik !25_A
31013	munitsipaalomandis	omandi	munitsipaal+omand	02_S	SgIn	et	munitsipaalomandis =omandi  (SgIn  >munitsipaal+omand !02_S
31017	sotsiaalmajade	maja	sotsiaal+maja	17_S	PlG	et	sotsiaalmajade =maja  (PlG  >sotsiaal+maja !17_S
31018	hooldekodude	kodu	hoolde+kodu	17_S	PlG	et	hooldekodude =kodu  (PlG  >hoolde+kodu !17_S
31029	märkimisväärsed	väärse	märki+mis+väärne	02_A	PlN	et	märkimisväärsed =väärse  (PlN  >märki+mis+väärne !02_A
31037	teede	tee	tee	26_S	PlG	et	teede =tee  (PlG  >tee !26_S
31038	ümbersõidud	sõidu	ümber+sõit	22_S	PlN	et	ümbersõidud =sõidu  (PlN  >ümber+sõit !22_S
31045	õppe-ning	ning	õppe-ning	41_J	ID	et	õppe-ning =ning  (ID  >õppe-ning !41_J
31046	sõle	sõle	sõlg	22_S	SgG	et	sõle =sõle  (SgG  >sõlg !22_S
31047	ehitustöödega	töö	ehitus+töö	26_S	PlKom	et	ehitustöödega =töö  (PlKom  >ehitus+töö !26_S
31048	olemasolevate	oleva	olemas+olev	02_A	PlG	et	olemasolevate =oleva  (PlG  >olemas+olev !02_A
31050	luuakse	luu	looma	38_V	IndPrIps	et	luuakse =luu  (IndPrIps  >looma !38_V
31054	tallinlasi	tallinlasi	tallinlane	12_S	PlP	et	tallinlasi =tallinlasi  (PlP  >tallinlane !12_S
31061	rannapark	park	ranna+park	22_S	SgN	et	rannapark =park  (SgN  >ranna+park !22_S
31068	paikneb	paikne	paiknema	27_V	IndPrSg3	et	paikneb =paikne  (IndPrSg3  >paiknema !27_V
31072	kohviku	kohviku	kohvik	02_S	SgG	et	kohviku =kohviku  (SgG  >kohvik !02_S
31077	ettekandjate	kandja	ette+kandja	01_S	PlG	et	ettekandjate =kandja  (PlG  >ette+kandja !01_S
31083	jõululaada	laada	jõulu+laat	22_S	SgG	et	jõululaada =laada  (SgG  >jõulu+laat !22_S
31084	vabaõhuüritusi	üritusi	vaba+õhu+üritus	11_S	PlP	et	vabaõhuüritusi =üritusi  (PlP  >vaba+õhu+üritus !11_S
31085	renoveerimistöid	tö	renoveerimis+töö	26_S	PlP	et	renoveerimistöid =tö  (PlP  >renoveerimis+töö !26_S
31092	ansamblil	ansambli	ansambel	02_S	SgAd	et	ansamblil =ansambli  (SgAd  >ansambel !02_S
31102	eelkäijate	käija	eel+käija	01_S	PlG	et	eelkäijate =käija  (PlG  >eel+käija !01_S
31109	valitsusajal	aja	valitsus+aeg	22_S	SgAd	et	valitsusajal =aja  (SgAd  >valitsus+aeg !22_S
31111	üha	üha	üha	41_D	ID	et	üha =üha  (ID  >üha !41_D
31112	hulgal	hulga	hulk	22_S	SgAd	et	hulgal =hulga  (SgAd  >hulk !22_S
31122	võrgu-	võrgu	võrk	22_S	SgG	et	võrgu- =võrgu  (SgG  >võrk !22_S
31123	doktor	doktor	doktor	02_S	SgN	et	doktor =doktor  (SgN  >doktor !02_S
31148	loengutsükkel	tsükkel	loengu+tsükkel	02_S	SgN	et	loengutsükkel =tsükkel  (SgN  >loengu+tsükkel !02_S
31154	projektijuht	juht	projekti+juht	22_S	SgN	et	projektijuht =juht  (SgN  >projekti+juht !22_S
31158	seadusliku	seadusliku	seaduslik	25_A	SgG	et	seadusliku =seadusliku  (SgG  >seaduslik !25_A
31169	oktoobrirevolutsioonini	revolutsiooni	oktoobri+revolutsioon	22_S	SgTer	et	oktoobrirevolutsioonini =revolutsiooni  (SgTer  >oktoobri+revolutsioon !22_S
31171	järglasi	järglasi	järglane	12_S	PlP	et	järglasi =järglasi  (PlP  >järglane !12_S
31174	muide	muide	muide	41_D	ID	et	muide =muide  (ID  >muide !41_D
31178	aastakümnendil	kümnendi	aasta+kümnend	02_S	SgAd	et	aastakümnendil =kümnendi  (SgAd  >aasta+kümnend !02_S
31185	harrastada	harrasta	harrastama	27_V	Inf	et	harrastada =harrasta  (Inf  >harrastama !27_V
31200	kõnepruugis	pruugi	kõne+pruuk	22_S	SgIn	et	kõnepruugis =pruugi  (SgIn  >kõne+pruuk !22_S
31203	präänikutele	prääniku	präänik	02_S	PlAll	et	präänikutele =prääniku  (PlAll  >präänik !02_S
31214	kaupmehi	mehi	kaup+mees	13_S	PlP	et	kaupmehi =mehi  (PlP  >kaup+mees !13_S
31221	tuletama	tuleta	tuletama	27_V	Sup	et	tuletama =tuleta  (Sup  >tuletama !27_V
31222	esiisade	isa	esi+isa	17_S	PlG	et	esiisade =isa  (PlG  >esi+isa !17_S
31223	turistide	turisti	turist	22_S	PlG	et	turistide =turisti  (PlG  >turist !22_S
31224	nauding	nauding	nauding	02_S	SgN	et	nauding =nauding  (SgN  >nauding !02_S
31232	põhja-euroopas	euroopa	põhja-euroopa	01_H	SgIn	et	põhja-euroopas =euroopa  (SgIn  >põhja-euroopa !01_H
31236	rõõmustas	rõõmusta	rõõmustama	27_V	IndIpfSg3	et	rõõmustas =rõõmusta  (IndIpfSg3  >rõõmustama !27_V
31240	tänavapuhastuse	puhastuse	tänava+puhastus	11_S	SgG	et	tänavapuhastuse =puhastuse  (SgG  >tänava+puhastus !11_S
31241	lund	lun	lumi	20_S	SgP	et	lund =lun  (SgP  >lumi !20_S
31249	tegevusalaga	ala	tegevus+ala	17_S	SgKom	et	tegevusalaga =ala  (SgKom  >tegevus+ala !17_S
31261	traditsioone	traditsioone	traditsioon	22_S	PlP	et	traditsioone =traditsioone  (PlP  >traditsioon !22_S
31005	tähtaegadega	aega	täht+aeg	22_S	PlKom	et	tähtaegadega =aega  (PlKom  >täht+aeg !22_S
31009	omanike	omanike	omanik	25_S	PlG	et	omanike =omanike  (PlG  >omanik !25_S
31015	paneelelamud	elamu	paneel+elamu	01_S	PlN	et	paneelelamud =elamu  (PlN  >paneel+elamu !01_S
31020	plaanideks	plaani	plaan	22_S	PlTr	et	plaanideks =plaani  (PlTr  >plaan !22_S
31025	kopli	kopli	koppel	02_S	SgG	et	kopli =kopli  (SgG  >koppel !02_S
31030	tehnovõrkudega	võrku	tehno+võrk	22_S	PlKom	et	tehnovõrkudega =võrku  (PlKom  >tehno+võrk !22_S
31034	kalamajas	maja	kala+maja	17_S	SgIn	et	kalamajas =maja  (SgIn  >kala+maja !17_S
31040	arengukavas	kava	arengu+kava	17_S	SgIn	et	arengukavas =kava  (SgIn  >arengu+kava !17_S
31044	täiustada	täiusta	täiustama	27_V	Inf	et	täiustada =täiusta  (Inf  >täiustama !27_V
31049	spordirajatiste	rajatis	spordi+rajatis	11_S	PlG	et	spordirajatiste =rajatis  (PlG  >spordi+rajatis !11_S
31051	linlaste	linlas	linlane	12?10_S	PlG	et	linlaste =linlas  (PlG  >linlane !12?10_S
31058	ennekõike	ennekõike	enne+kõike	41_D	ID	et	ennekõike =ennekõike  (ID  >enne+kõike !41_D
31062	merimets	mets	meri+mets	22_S	SgN	et	merimets =mets  (SgN  >meri+mets !22_S
31065	tiigi	tiigi	tiik	22_S	SgG	et	tiigi =tiigi  (SgG  >tiik !22_S
31066	luigetiigi	tiigi	luige+tiik	22_S	SgG	et	luigetiigi =tiigi  (SgG  >luige+tiik !22_S
31067	traditsioonis	traditsiooni	traditsioon	22_S	SgIn	et	traditsioonis =traditsiooni  (SgIn  >traditsioon !22_S
31073	suveterrass	terrass	suve+terrass	22_S	SgN	et	suveterrass =terrass  (SgN  >suve+terrass !22_S
31079	piknikukorvide	korvi	pikniku+korv	22_S	PlG	et	piknikukorvide =korvi  (PlG  >pikniku+korv !22_S
31080	müügipunkt	punkt	müügi+punkt	22_S	SgN	et	müügipunkt =punkt  (SgN  >müügi+punkt !22_S
31082	tulevikuplaanides	plaani	tuleviku+plaan	22_S	PlIn	et	tulevikuplaanides =plaani  (PlIn  >tuleviku+plaan !22_S
31086	teostas	teosta	teostama	27_V	IndIpfSg3	et	teostas =teosta  (IndIpfSg3  >teostama !27_V
31091	muusikateosed	teose	muusika+teos	09_S	PlN	et	muusikateosed =teose  (PlN  >muusika+teos !09_S
31093	sealhulgas	sealhulgas	seal+hulgas	41_D	ID	et	sealhulgas =sealhulgas  (ID  >seal+hulgas !41_D
31100	heliloojad	looja	heli+looja	01_S	PlN	et	heliloojad =looja  (PlN  >heli+looja !01_S
31107	üsnagi	üsna	üsna	41_D	ID^	et	üsnagi =üsna  (ID^  >üsna !41_D
31113	äkitselt	äkitselt	äkitselt	41_D	ID	et	äkitselt =äkitselt  (ID  >äkitselt !41_D
31115	ordenit	ordeni	orden	02_S	SgP	et	ordenit =ordeni  (SgP  >orden !02_S
31116	kuninglik	kuninglik	kuninglik	25_A	SgN	et	kuninglik =kuninglik  (SgN  >kuninglik !25_A
31120	aastale	aasta	aasta	01_S	SgAll	et	aastale =aasta  (SgAll  >aasta !01_S
31128	informatiivne	informatiivne	informatiivne	02_A	SgN	et	informatiivne =informatiivne  (SgN  >informatiivne !02_A
31131	internetipõhise	põhise	interneti+põhis	09_S	SgG	et	internetipõhise =põhise  (SgG  >interneti+põhis !09_S
31132	võrgupõhise	põhise	võrgu+põhis	09_S	SgG	et	võrgupõhise =põhise  (SgG  >võrgu+põhis !09_S
31134	kogemuse	kogemuse	kogemus	11_S	SgG	et	kogemuse =kogemuse  (SgG  >kogemus !11_S
31135	juhtkond	juhtkond	juhtkond	22_S	SgN	et	juhtkond =juhtkond  (SgN  >juhtkond !22_S
31140	kultuuriväärtused	väärtuse	kultuuri+väärtus	11~09_S	PlN	et	kultuuriväärtused =väärtuse  (PlN  >kultuuri+väärtus !11~09_S
31142	selekteerida	selekteeri	selekteerima	28_V	Inf	et	selekteerida =selekteeri  (Inf  >selekteerima !28_V
31143	sõeluda	sõelu	sõeluma	28_V	Inf	et	sõeluda =sõelu  (Inf  >sõeluma !28_V
31145	võrgupõhiste	põhis	võrgu+põhis	09_S	PlG	et	võrgupõhiste =põhis  (PlG  >võrgu+põhis !09_S
31149	pälvis	pälvi	pälvima	28_V	IndIpfSg3	et	pälvis =pälvi  (IndIpfSg3  >pälvima !28_V
31153	avar	avar	avar	02_A	SgN	et	avar =avar  (SgN  >avar !02_A
31163	taustaga	tausta	taust	22_S	SgKom	et	taustaga =tausta  (SgKom  >taust !22_S
31164	armutunnete	tunne	armu+tunne	06_S	PlG	et	armutunnete =tunne  (PlG  >armu+tunne !06_S
31166	sõnale	sõna	sõna	17_S	SgAll	et	sõnale =sõna  (SgAll  >sõna !17_S
31173	veidrast	veidra	veider	02_A	SgEl	et	veidrast =veidra  (SgEl  >veider !02_A
31177	postisaajat	saaja	posti+saaja	01_S	SgP	et	postisaajat =saaja  (SgP  >posti+saaja !01_S
31179	nimedega	nime	nimi	20_S	PlKom	et	nimedega =nime  (PlKom  >nimi !20_S
31180	elanikkond	elanikkond	elanikkond	22_S	SgN	et	elanikkond =elanikkond  (SgN  >elanikkond !22_S
31181	samaks	sama	sama	17_P	SgTr	et	samaks =sama  (SgTr  >sama !17_P
31183	turistid	turisti	turist	22_S	PlN	et	turistid =turisti  (PlN  >turist !22_S
31184	meeleldi	meeleldi	meeleldi	41_D	ID	et	meeleldi =meeleldi  (ID  >meeleldi !41_D
31189	kaheksanurkne	nurkne	kaheksa+nurkne	02_A	SgN	et	kaheksanurkne =nurkne  (SgN  >kaheksa+nurkne !02_A
31196	imestada	imesta	imestama	27_V	Inf	et	imestada =imesta  (Inf  >imestama !27_V
31197	ahvenamaalane	maalane	ahvena+maalane	12?10_S	SgN	et	ahvenamaalane =maalane  (SgN  >ahvena+maalane !12?10_S
31006	ehitised	ehitise	ehitis	11_S	PlN	et	ehitised =ehitise  (PlN  >ehitis !11_S
31014	ühiselamud	elamu	ühis+elamu	01_S	PlN	et	ühiselamud =elamu  (PlN  >ühis+elamu !01_S
31021	liinide	liini	liin	22_S	PlG	et	liinide =liini  (PlG  >liin !22_S
31022	sirbi-vasara	vasara	sirbi-vasar	02_S	SgG	et	sirbi-vasara =vasara  (SgG  >sirbi-vasar !02_S
31024	renoveerimisprojektid	projekti	renoveerimis+projekt	22_S	PlN	et	renoveerimisprojektid =projekti  (PlN  >renoveerimis+projekt !22_S
31026	põhja-tallinnast	ast	põhja-tallinn+ast	22_S	SgN	et	põhja-tallinnast =ast  (SgN  >põhja-tallinn+ast !22_S
31027	kvartalid	kvartali	kvartal	02_S	PlN	et	kvartalid =kvartali  (PlN  >kvartal !02_S
31033	veevärgi	värgi	vee+värk	22_S	SgG	et	veevärgi =värgi  (SgG  >vee+värk !22_S
31035	koplis	kopli	koppel	02_S	SgIn	et	koplis =kopli  (SgIn  >koppel !02_S
31055	piirkondadest	piirkonda	piirkond	22_S	PlEl	et	piirkondadest =piirkonda  (PlEl  >piirkond !22_S
31064	kohvik	kohvik	kohvik	02_S	SgN	et	kohvik =kohvik  (SgN  >kohvik !02_S
31069	pargivahi	vahi	pargi+vaht	22_S	SgG	et	pargivahi =vahi  (SgG  >pargi+vaht !22_S
31071	kohviku	kohviku	kohvik	02_S	SgG	et	kohviku =kohviku  (SgG  >kohvik !02_S
31074	60-le			xx_Q	SgAll	et	-le =  (SgAll  > !xx_Q
31075	pargivaadetega	vaade	pargi+vaade	06_S	PlKom	et	pargivaadetega =vaade  (PlKom  >pargi+vaade !06_S
31090	majamuuseumid	muuseumi	maja+muuseum	19~02_S	PlN	et	majamuuseumid =muuseumi  (PlN  >maja+muuseum !19~02_S
31095	õigeusukiriku	kiriku	õige+usu+kirik	02_S	SgG	et	õigeusukiriku =kiriku  (SgG  >õige+usu+kirik !02_S
31096	heliloojate	looja	heli+looja	01_S	PlG	et	heliloojate =looja  (PlG  >heli+looja !01_S
31101	komponistide	komponisti	komponist	22_S	PlG	et	komponistide =komponisti  (PlG  >komponist !22_S
31104	saadikute	saadiku	saadik	02_S	PlG	et	saadikute =saadiku  (PlG  >saadik !02_S
31105	peetri-aegsed	aegse	peetri-aegne	02_A	PlN	et	peetri-aegsed =aegse  (PlN  >peetri-aegne !02_A
31110	reporterile	reporteri	reporter	02_S	SgAll	et	reporterile =reporteri  (SgAll  >reporter !02_S
31121	ületab	ületa	ületama	27_V	IndPrSg3	et	ületab =ületa  (IndPrSg3  >ületama !27_V
31129	toode	toode	toode	06_S	SgN	et	toode =toode  (SgN  >toode !06_S
31137	harumuuseum	muuseum	haru+muuseum	19~02_S	SgN	et	harumuuseum =muuseum  (SgN  >haru+muuseum !19~02_S
31138	tihendada	tihenda	tihendama	27_V	Inf	et	tihendada =tihenda  (Inf  >tihendama !27_V
31147	loengukursuse	kursuse	loengu+kursus	11~09_S	SgG	et	loengukursuse =kursuse  (SgG  >loengu+kursus !11~09_S
31151	gümnaasiumide	gümnaasiumi	gümnaasium	19_S	PlG	et	gümnaasiumide =gümnaasiumi  (PlG  >gümnaasium !19_S
31152	eriolümpiaadis	olümpiaadi	eri+olümpiaad	22_S	SgIn	et	eriolümpiaadis =olümpiaadi  (SgIn  >eri+olümpiaad !22_S
31155	saarestik	saarestik	saarestik	25_S	SgN	et	saarestik =saarestik  (SgN  >saarestik !25_S
31159	põhjasõja	sõja	põhja+sõda	18_S	SgG	et	põhjasõja =sõja  (SgG  >põhja+sõda !18_S
31162	kõnepruuk	pruuk	kõne+pruuk	22_S	SgN	et	kõnepruuk =pruuk  (SgN  >kõne+pruuk !22_S
31165	asetades	aseta	asetama	27_V	Ger	et	asetades =aseta  (Ger  >asetama !27_V
31172	äkkere	ere	äkk+ere	02_A	SgN	et	äkkere =ere  (SgN  >äkk+ere !02_A
31191	tolleaegsed	aegse	tolle+aegne	02_A	PlN	et	tolleaegsed =aegse  (PlN  >tolle+aegne !02_A
31194	kergendab	kergenda	kergendama	27_V	IndPrSg3	et	kergendab =kergenda  (IndPrSg3  >kergendama !27_V
31198	präänikut	prääniku	präänik	02_S	SgP	et	präänikut =prääniku  (SgP  >präänik !02_S
31204	kinnistama	kinnista	kinnistama	27_V	Sup	et	kinnistama =kinnista  (Sup  >kinnistama !27_V
31212	sõdureid	sõdure	sõdur	02_S	PlP	et	sõdureid =sõdure  (PlP  >sõdur !02_S
31213	ohvitsere	ohvitsere	ohvitser	19_S	PlP	et	ohvitsere =ohvitsere  (PlP  >ohvitser !19_S
31215	käsitöölisi	töölisi	käsi+tööline	12_S	PlP	et	käsitöölisi =töölisi  (PlP  >käsi+tööline !12_S
31225	järgmised	järgmise	järgmine	12?10_A	PlN	et	järgmised =järgmise  (PlN  >järgmine !12?10_A
31233	talv	talv	talv	22_S	SgN	et	talv =talv  (SgN  >talv !22_S
31238	autoomanikele	omanike	auto+omanik	25_S	PlAll	et	autoomanikele =omanike  (PlAll  >auto+omanik !25_S
31242	lund	lun	lumi	20_S	SgP	et	lund =lun  (SgP  >lumi !20_S
31246	labidad	labida	labidas	02_S	PlN	et	labidad =labida  (PlN  >labidas !02_S
31253	kutsutakse	kutsu	kutsuma	28_V	IndPrIps	et	kutsutakse =kutsu  (IndPrIps  >kutsuma !28_V
31259	tiigiäärne	äärne	tiigi+äärne	02_A	SgN	et	tiigiäärne =äärne  (SgN  >tiigi+äärne !02_A
31260	järgib	järgi	järgima	27_V	IndPrSg3	et	järgib =järgi  (IndPrSg3  >järgima !27_V
31262	vahiputkas	putka	vahi+putka	16_S	SgIn	et	vahiputkas =putka  (SgIn  >vahi+putka !16_S
31271	müüma	müü	müüma	38_V	Sup	et	müüma =müü  (Sup  >müüma !38_V
31285	ülesannete	anne	üles+anne	06_S	PlG	et	ülesannete =anne  (PlG  >üles+anne !06_S
31287	teostamisaeg	aeg	teostamis+aeg	22_S	SgN	et	teostamisaeg =aeg  (SgN  >teostamis+aeg !22_S
31057	linlastele	linlas	linlane	12?10_S	PlAll	et	linlastele =linlas  (PlAll  >linlane !12?10_S
31070	40-le			xx_Q	SgAll	et	-le =  (SgAll  > !xx_Q
31076	gravüürid	gravüüri	gravüür	22_S	PlN	et	gravüürid =gravüüri  (PlN  >gravüür !22_S
31078	pakkuda	pakku	pakkuma	28_V	Inf	et	pakkuda =pakku  (Inf  >pakkuma !28_V
31089	kadrioru	oru	kadri+org	22_S	SgG	et	kadrioru =oru  (SgG  >kadri+org !22_S
31097	vähetuntud	tuntu	vähe+tuntu	01_S	PlN	et	vähetuntud =tuntu  (PlN  >vähe+tuntu !01_S
31106	kaardiväelased	väelase	kaardi+väelane	12?10_S	PlN	et	kaardiväelased =väelase  (PlN  >kaardi+väelane !12?10_S
31108	venekeelsest	keelse	vene+keelne	02_A	SgEl	et	venekeelsest =keelse  (SgEl  >vene+keelne !02_A
31118	eestvedamisel	vedamise	eest+vedamine	12_S	SgAd	et	eestvedamisel =vedamise  (SgAd  >eest+vedamine !12_S
31119	2-le			xx_Q	SgAll	et	-le =  (SgAll  > !xx_Q
31124	külaskäigu	käigu	külas+käik	22_S	SgG	et	külaskäigu =käigu  (SgG  >külas+käik !22_S
31125	külaskäik	käik	külas+käik	22_S	SgN	et	külaskäik =käik  (SgN  >külas+käik !22_S
31127	teabeprodukt	produkt	teabe+produkt	22_S	SgN	et	teabeprodukt =produkt  (SgN  >teabe+produkt !22_S
31130	kultuuriväärtus	väärtus	kultuuri+väärtus	11~09_S	SgN	et	kultuuriväärtus =väärtus  (SgN  >kultuuri+väärtus !11~09_S
31136	allüksusena	üksuse	all+üksus	11~09_S	SgEs	et	allüksusena =üksuse  (SgEs  >all+üksus !11~09_S
31146	arvutiprogrammide	programmi	arvuti+programm	22_S	PlG	et	arvutiprogrammide =programmi  (PlG  >arvuti+programm !22_S
31156	suurriigi	riigi	suur+riik	22_S	SgG	et	suurriigi =riigi  (SgG  >suur+riik !22_S
31157	saarestikul	saarestiku	saarestik	25_S	SgAd	et	saarestikul =saarestiku  (SgAd  >saarestik !25_S
31170	saarestikule	saarestiku	saarestik	25_S	SgAll	et	saarestikule =saarestiku  (SgAll  >saarestik !25_S
31175	postijaam	jaam	posti+jaam	22_S	SgN	et	postijaam =jaam  (SgN  >posti+jaam !22_S
31176	väljanägemise	nägemise	välja+nägemine	12_S	SgG	et	väljanägemise =nägemise  (SgG  >välja+nägemine !12_S
31182	puhtvenelaslikud	venelasliku	puht+venelaslik	25_A	PlN	et	puhtvenelaslikud =venelasliku  (PlN  >puht+venelaslik !25_A
31186	vabas	vaba	vaba	17_A	SgIn	et	vabas =vaba  (SgIn  >vaba !17_A
31188	armsaks	armsa	armas	03~05_A	SgTr	et	armsaks =armsa  (SgTr  >armas !03~05_A
31190	siiamaani	siiamaani	siia+maani	41_D	ID	et	siiamaani =siiamaani  (ID  >siia+maani !41_D
31192	küpsetusahjud	ahju	küpsetus+ahi	24_S	PlN	et	küpsetusahjud =ahju  (PlN  >küpsetus+ahi !24_S
31199	tsaarilt	tsaari	tsaar	22_S	SgAbl	et	tsaarilt =tsaari  (SgAbl  >tsaar !22_S
31207	esialgses	algse	esi+algne	02_A	SgIn	et	esialgses =algse  (SgIn  >esi+algne !02_A
31216	impeeriumistiilis	stiili	impeeriumi+stiil	22_S	SgIn	et	impeeriumistiilis =stiili  (SgIn  >impeeriumi+stiil !22_S
31234	kauaoodatud	oodatu	kaua+oodatu	01_S	PlN	et	kauaoodatud =oodatu  (PlN  >kaua+oodatu !01_S
31235	sadada	sada	sadama	28_V	Inf	et	sadada =sada  (Inf  >sadama !28_V
31237	muresid	mure	mure	16_S	PlP	et	muresid =mure  (PlP  >mure !16_S
31245	unarusse	unarus	unarus	11_S	SgAdt	et	unarusse =unarus  (SgAdt  >unarus !11_S
31247	majade	maja	maja	17_S	PlG	et	majade =maja  (PlG  >maja !17_S
31254	lastemäeks	mäe	laste+mägi	21_S	SgTr	et	lastemäeks =mäe  (SgTr  >laste+mägi !21_S
31256	liuväli	väli	liu+väli	24_S	SgN	et	liuväli =väli  (SgN  >liu+väli !24_S
31257	talvetulek	tulek	talve+tulek	02_S	SgN	et	talvetulek =tulek  (SgN  >talve+tulek !02_S
31267	kelnerite	kelneri	kelner	02_S	PlG	et	kelnerite =kelneri  (PlG  >kelner !02_S
31273	maksumus	maksumus	maksumus	11_S	SgN	et	maksumus =maksumus  (SgN  >maksumus !11_S
31274	sisekujundamisel	kujundamise	sise+kujundamine	12_S	SgAd	et	sisekujundamisel =kujundamise  (SgAd  >sise+kujundamine !12_S
31276	pargikohvik	kohvik	pargi+kohvik	02_S	SgN	et	pargikohvik =kohvik  (SgN  >pargi+kohvik !02_S
31282	piirkond	piirkond	piirkond	22_S	SgN	et	piirkond =piirkond  (SgN  >piirkond !22_S
31284	faktoriks	faktori	faktor	02_S	SgTr	et	faktoriks =faktori  (SgTr  >faktor !02_S
31292	munitsipaalelamute	elamu	munitsipaal+elamu	01_S	PlG	et	munitsipaalelamute =elamu  (PlG  >munitsipaal+elamu !01_S
31296	kommunikatsioonidega	kommunikatsiooni	kommunikatsioon	22_S	PlKom	et	kommunikatsioonidega =kommunikatsiooni  (PlKom  >kommunikatsioon !22_S
31302	materiaal-tehnilist	tehnilis	materiaal-tehniline	12_A	SgP	et	materiaal-tehnilist =tehnilis  (SgP  >materiaal-tehniline !12_A
31309	metsapark	park	metsa+park	22_S	SgN	et	metsapark =park  (SgN  >metsa+park !22_S
31310	ranniku	ranniku	rannik	02_S	SgG	et	ranniku =ranniku  (SgG  >rannik !02_S
31311	lähiajal	aja	lähi+aeg	22_S	SgAd	et	lähiajal =aja  (SgAd  >lähi+aeg !22_S
31315	miljonit	miljoni	miljon	02_N	SgP	et	miljonit =miljoni  (SgP  >miljon !02_N
31316	tutvustatakse	tutvusta	tutvustama	27_V	IndPrIps	et	tutvustatakse =tutvusta  (IndPrIps  >tutvustama !27_V
31322	muuseumide	muuseumi	muuseum	19_S	PlG	et	muuseumide =muuseumi  (PlG  >muuseum !19_S
31201	orden	orden	orden	02_S	SgN	et	orden =orden  (SgN  >orden !02_S
31206	sõja-	sõja	sõda	18_S	SgG	et	sõja- =sõja  (SgG  >sõda !18_S
31218	kummalisest	kummalise	kummaline	12_A	SgEl	et	kummalisest =kummalise  (SgEl  >kummaline !12_A
31219	perekonnanimedega	nime	pere+konna+nimi	20_S	PlKom	et	perekonnanimedega =nime  (PlKom  >pere+konna+nimi !20_S
31220	adressaate	adressaate	adressaat	22_S	PlP	et	adressaate =adressaate  (PlP  >adressaat !22_S
31226	saarlasi	saarlasi	saarlane	12_S	PlP	et	saarlasi =saarlasi  (PlP  >saarlane !12_S
31228	kinnitama	kinnita	kinnitama	27_V	Sup	et	kinnitama =kinnita  (Sup  >kinnitama !27_V
31231	talvekülmad	külma	talve+külm	22_AS	PlN	et	talvekülmad =külma  (PlN  >talve+külm !22_AS
31239	lumeummistusega	ummistuse	lume+ummistus	11_S	SgKom	et	lumeummistusega =ummistuse  (SgKom  >lume+ummistus !11_S
31248	koristama	korista	koristama	27_V	Sup	et	koristama =korista  (Sup  >koristama !27_V
31250	rahvarohkeks	rohke	rahva+rohke	01_A	SgTr	et	rahvarohkeks =rohke  (SgTr  >rahva+rohke !01_A
31255	linnaelanikke	elanikke	linna+elanik	25_S	PlP	et	linnaelanikke =elanikke  (PlP  >linna+elanik !25_S
31264	seest	seest	seest	41_DK	ID	et	seest =seest  (ID  >seest !41_DK
31265	vanade	vana	vana	17_AS	PlG	et	vanade =vana  (PlG  >vana !17_AS
31268	miljööle	miljöö	miljöö	26_S	SgAll	et	miljööle =miljöö  (SgAll  >miljöö !26_S
31270	piknikukorve	korve	pikniku+korv	22_S	PlP	et	piknikukorve =korve  (PlP  >pikniku+korv !22_S
31275	tööpäevadel	päeva	töö+päev	22_S	PlAd	et	tööpäevadel =päeva  (PlAd  >töö+päev !22_S
31279	tulekul	tuleku	tulek	02_S	SgAd	et	tulekul =tuleku  (SgAd  >tulek !02_S
31280	lastemuuseum	muuseum	laste+muuseum	19~02_S	SgN	et	lastemuuseum =muuseum  (SgN  >laste+muuseum !19~02_S
31288	2010-l			xx_Q	SgAd	et	-l =  (SgAd  > !xx_Q
31289	korrastada	korrasta	korrastama	27_V	Inf	et	korrastada =korrasta  (Inf  >korrastama !27_V
31293	ehitatakse	ehita	ehitama	27_V	IndPrIps	et	ehitatakse =ehita  (IndPrIps  >ehitama !27_V
31299	arenguprogrammis	programmi	arengu+programm	22_S	SgIn	et	arenguprogrammis =programmi  (SgIn  >arengu+programm !22_S
31303	spordikeskuse	keskuse	spordi+keskus	11~09_S	SgG	et	spordikeskuse =keskuse  (SgG  >spordi+keskus !11~09_S
31324	kultuurse	kultuurse	kultuurne	02_A	SgG	et	kultuurse =kultuurse  (SgG  >kultuurne !02_A
31327	gümnaasiumiõpilased	õpilase	gümnaasiumi+õpilane	12_S	PlN	et	gümnaasiumiõpilased =õpilase  (PlN  >gümnaasiumi+õpilane !12_S
31333	kasvasin	kasva	kasvama	28_V	IndIpfSg1	et	kasvasin =kasva  (IndIpfSg1  >kasvama !28_V
31343	andestasin	andesta	andestama	27_V	IndIpfSg1	et	andestasin =andesta  (IndIpfSg1  >andestama !27_V
31348	arendasin	arenda	arendama	27_V	IndIpfSg1	et	arendasin =arenda  (IndIpfSg1  >arendama !27_V
31349	ulule	ulu	ulg	22_S	SgAll	et	ulule =ulu  (SgAll  >ulg !22_S
31358	tollal	tollal	tollal	41_D	ID	et	tollal =tollal  (ID  >tollal !41_D
31361	isal	isa	isa	17_S	SgAd	et	isal =isa  (SgAd  >isa !17_S
31365	jäime	jä	jääma	37_V	IndIpfPl1	et	jäime =jä  (IndIpfPl1  >jääma !37_V
31371	esimesele	esimese	esimene	12_OP	SgAll	et	esimesele =esimese  (SgAll  >esimene !12_OP
31381	kolisime	koli	kolima	27_V	IndIpfPl1	et	kolisime =koli  (IndIpfPl1  >kolima !27_V
31389	ühist	ühis	ühine	10_A	SgP	et	ühist =ühis  (SgP  >ühine !10_A
31395	kuldmedaliga	medali	kuld+medal	02_S	SgKom	et	kuldmedaliga =medali  (SgKom  >kuld+medal !02_S
31396	tuletan	tuleta	tuletama	27_V	IndPrSg1	et	tuletan =tuleta  (IndPrSg1  >tuletama !27_V
31398	langused	languse	langus	11~09_S	PlN	et	langused =languse  (PlN  >langus !11~09_S
31407	plekkplaadi	plaadi	plekk+plaat	22_S	SgG	et	plekkplaadi =plaadi  (SgG  >plekk+plaat !22_S
31409	gümnaasiumis	gümnaasiumi	gümnaasium	19~02_S	SgIn	et	gümnaasiumis =gümnaasiumi  (SgIn  >gümnaasium !19~02_S
31411	erialale	ala	eri+ala	17_S	SgAll	et	erialale =ala  (SgAll  >eri+ala !17_S
31416	katkestasin	katkesta	katkestama	27_V	IndIpfSg1	et	katkestasin =katkesta  (IndIpfSg1  >katkestama !27_V
31417	kontrollöörina	ööri	kont+roll+öör	22_S	SgEs	et	kontrollöörina =ööri  (SgEs  >kont+roll+öör !22_S
31423	õppesuunasse	suuna	õppe+suund	22_S	SgIll	et	õppesuunasse =suuna  (SgIll  >õppe+suund !22_S
31426	gruppidega	gruppi	grupp	22_S	PlKom	et	gruppidega =gruppi  (PlKom  >grupp !22_S
31428	karateni	karate	karate	01_S	SgTer	et	karateni =karate  (SgTer  >karate !01_S
31433	klassisse	klassi	klass	22_S	SgIll	et	klassisse =klassi  (SgIll  >klass !22_S
31438	turismiettevõtmisele	võtmise	turismi+ette+võtmine	12?10_S	SgAll	et	turismiettevõtmisele =võtmise  (SgAll  >turismi+ette+võtmine !12?10_S
31441	dokumendid	dokumendi	dokument	22_S	PlN	et	dokumendid =dokumendi  (PlN  >dokument !22_S
31443	sooritada	soorita	sooritama	27_V	Inf	et	sooritada =soorita  (Inf  >sooritama !27_V
31446	möödas	möödas	möödas	41_D	ID	et	möödas =möödas  (ID  >möödas !41_D
31448	vend	vend	vend	22_S	SgN	et	vend =vend  (SgN  >vend !22_S
31252	munamäel	mäe	muna+mägi	21_S	SgAd	et	munamäel =mäe  (SgAd  >muna+mägi !21_S
31258	enamikule	enamiku	enamik	25_S	SgAll	et	enamikule =enamiku  (SgAll  >enamik !25_S
31263	mahutab	mahuta	mahutama	27_V	IndPrSg3	et	mahutab =mahuta  (IndPrSg3  >mahutama !27_V
31269	pargikülastajatele	külastaja	pargi+külastaja	01_S	PlAll	et	pargikülastajatele =külastaja  (PlAll  >pargi+külastaja !01_S
31278	kunstimuuseum	muuseum	kunsti+muuseum	19~02_S	SgN	et	kunstimuuseum =muuseum  (SgN  >kunsti+muuseum !19~02_S
31281	linnavalitsus	valitsus	linna+valitsus	11_S	SgN	et	linnavalitsus =valitsus  (SgN  >linna+valitsus !11_S
31283	kontrollile	kontrolli	kontroll	22_S	SgAll	et	kontrollile =kontrolli  (SgAll  >kontroll !22_S
31286	dokument	dokument	dokument	22_S	SgN	et	dokument =dokument  (SgN  >dokument !22_S
31298	prioriteediks	prioriteedi	prioriteet	22_S	SgTr	et	prioriteediks =prioriteedi  (SgTr  >prioriteet !22_S
31305	olemasolevaid	oleva	olemas+olev	02_A	PlP	et	olemasolevaid =oleva  (PlP  >olemas+olev !02_A
31306	sportsaale	saale	sport+saal	22_S	PlP	et	sportsaale =saale  (PlP  >sport+saal !22_S
31314	noortega	noor	noor	13_AS	PlKom	et	noortega =noor  (PlKom  >noor !13_AS
31318	kokkupuutumisest	puutumise	kokku+puutumine	12_S	SgEl	et	kokkupuutumisest =puutumise  (SgEl  >kokku+puutumine !12_S
31319	kogemused	kogemuse	kogemus	11_S	PlN	et	kogemused =kogemuse  (PlN  >kogemus !11_S
31320	tugineb	tugine	tuginema	27_V	IndPrSg3	et	tugineb =tugine  (IndPrSg3  >tuginema !27_V
31323	spetsiaalse	spetsiaalse	spetsiaalne	02_A	SgG	et	spetsiaalse =spetsiaalse  (SgG  >spetsiaalne !02_A
31328	olümpiaadis	olümpiaadi	olümpiaad	22_S	SgIn	et	olümpiaadis =olümpiaadi  (SgIn  >olümpiaad !22_S
31329	kultuuripärandi	pärandi	kultuuri+pärand	02_S	SgG	et	kultuuripärandi =pärandi  (SgG  >kultuuri+pärand !02_S
31338	klassil	klassi	klass	22_S	SgAd	et	klassil =klassi  (SgAd  >klass !22_S
31344	merd	mer	meri	20_S	SgP	et	merd =mer  (SgP  >meri !20_S
31346	naudingu	naudingu	nauding	02_S	SgG	et	naudingu =naudingu  (SgG  >nauding !02_S
31350	mullu	mullu	mullu	41_D	ID	et	mullu =mullu  (ID  >mullu !41_D
31354	astuda	astu	astuma	28_V	Inf	et	astuda =astu  (Inf  >astuma !28_V
31356	pall	pall	pall	22_S	SgN	et	pall =pall  (SgN  >pall !22_S
31363	eksamid	eksami	eksam	02_S	PlN	et	eksamid =eksami  (PlN  >eksam !02_S
31367	uusaastal	aasta	uus+aasta	01_S	SgAd	et	uusaastal =aasta  (SgAd  >uus+aasta !01_S
31377	lihtsad	lihtsa	lihtne	02_A	PlN	et	lihtsad =lihtsa  (PlN  >lihtne !02_A
31383	kinnine	kinnine	kinnine	10~12_A	SgN	et	kinnine =kinnine  (SgN  >kinnine !10~12_A
31393	konkurssidest	konkurssi	konkurss	22_S	PlEl	et	konkurssidest =konkurssi  (PlEl  >konkurss !22_S
31402	negatiivseid	negatiivse	negatiivne	02_A	PlP	et	negatiivseid =negatiivse  (PlP  >negatiivne !02_A
31403	eksite	eksi	eksima	28_V	IndPrPl2	et	eksite =eksi  (IndPrPl2  >eksima !28_V
31404	mustade	musta	must	22_AS	PlG	et	mustade =musta  (PlG  >must !22_AS
31408	muusikaks	muusika	muusika	01_S	SgTr	et	muusikaks =muusika  (SgTr  >muusika !01_S
31414	treeneri	treeneri	treener	02_S	SgG	et	treeneri =treeneri  (SgG  >treener !02_S
31415	ebameeldiva	meeldiva	eba+meeldiv	02_A	SgG	et	ebameeldiva =meeldiva  (SgG  >eba+meeldiv !02_A
31429	seitsme	seitsme	seitse	05_N	SgG	et	seitsme =seitsme  (SgG  >seitse !05_N
31430	septembrist	septembri	september	02_S	SgEl	et	septembrist =septembri  (SgEl  >september !02_S
31434	hiigelsuured	suure	hiigel+suur	13_A	PlN	et	hiigelsuured =suure  (PlN  >hiigel+suur !13_A
31442	mõlematesse	mõlema	mõlema	02_P	PlIll	et	mõlematesse =mõlema  (PlIll  >mõlema !02_P
31450	jaamakorraldajana	korraldaja	jaama+korraldaja	01_S	SgEs	et	jaamakorraldajana =korraldaja  (SgEs  >jaama+korraldaja !01_S
31464	valmistama	valmista	valmistama	27_V	Sup	et	valmistama =valmista  (Sup  >valmistama !27_V
31466	sisseastumiseks	astumise	sisse+astumine	12_S	SgTr	et	sisseastumiseks =astumise  (SgTr  >sisse+astumine !12_S
31467	graafik	graafik	graafik	02_S	SgN	et	graafik =graafik  (SgN  >graafik !02_S
31468	kursustel	kursus	kursus	11~09_S	PlAd	et	kursustel =kursus  (PlAd  >kursus !11~09_S
31469	suutsin	suut	suutma	34_V	IndIpfSg1	et	suutsin =suut  (IndIpfSg1  >suutma !34_V
31471	rahuliku	rahuliku	rahulik	25_A	SgG	et	rahuliku =rahuliku  (SgG  >rahulik !25_A
31474	sisseastumiskatsed	katse	sisse+astumis+katse	06_S	PlN	et	sisseastumiskatsed =katse  (PlN  >sisse+astumis+katse !06_S
31483	punkte	punkte	punkt	22_S	PlP	et	punkte =punkte  (PlP  >punkt !22_S
31497	vastuvõtt	võtt	vastu+võtt	22_S	SgN	et	vastuvõtt =võtt  (SgN  >vastu+võtt !22_S
31499	seisin	seis	seisma	32_V	IndIpfSg1	et	seisin =seis  (IndIpfSg1  >seisma !32_V
31501	elurõõmsad	rõõmsa	elu+rõõmus	02_A	PlN	et	elurõõmsad =rõõmsa  (PlN  >elu+rõõmus !02_A
31507	pae	pae	paas	22_S	SgG	et	pae =pae  (SgG  >paas !22_S
31508	kudusin	kudu	kuduma	28_V	IndIpfSg1	et	kudusin =kudu  (IndIpfSg1  >kuduma !28_V
31511	kirjutan	kirjuta	kirjutama	27_V	IndPrSg1	et	kirjutan =kirjuta  (IndPrSg1  >kirjutama !27_V
31266	gravüüridega	gravüüri	gravüür	22_S	PlKom	et	gravüüridega =gravüüri  (PlKom  >gravüür !22_S
31272	sisetöid	tö	sise+töö	26_S	PlP	et	sisetöid =tö  (PlP  >sise+töö !26_S
31277	muuseumiks	muuseumi	muuseum	19~02_S	SgTr	et	muuseumiks =muuseumi  (SgTr  >muuseum !19~02_S
31291	paneelmajad	maja	paneel+maja	17_S	PlN	et	paneelmajad =maja  (PlN  >paneel+maja !17_S
31294	sotsiaalmaju	maju	sotsiaal+maja	17_S	PlP	et	sotsiaalmaju =maju  (PlP  >sotsiaal+maja !17_S
31295	rekonstruktsioon	rekonstruktsioon	rekonstruktsioon	22_S	SgN	et	rekonstruktsioon =rekonstruktsioon  (SgN  >rekonstruktsioon !22_S
31300	mäel	mäe	mägi	21_S	SgAd	et	mäel =mäe  (SgAd  >mägi !21_S
31312	ilmuma	ilmu	ilmuma	27_V	Sup	et	ilmuma =ilmu  (Sup  >ilmuma !27_V
31317	väljapanekuid	paneku	välja+panek	02_S	PlP	et	väljapanekuid =paneku  (PlP  >välja+panek !02_S
31321	töökogemusel	kogemuse	töö+kogemus	11_S	SgAd	et	töökogemusel =kogemuse  (SgAd  >töö+kogemus !11_S
31330	jutustas	jutusta	jutustama	27_V	IndIpfSg3	et	jutustas =jutusta  (IndIpfSg3  >jutustama !27_V
31331	sündisin	sündi	sündima	28_V	IndIpfSg1	et	sündisin =sündi  (IndIpfSg1  >sündima !28_V
31336	küüst	küü	küü	26_S	SgEl	et	küüst =küü  (SgEl  >küü !26_S
31341	sündmust	sündmus	sündmus	11~09_S	SgP	et	sündmust =sündmus  (SgP  >sündmus !11~09_S
31342	kukkuma	kukku	kukkuma	28_V	Sup	et	kukkuma =kukku  (Sup  >kukkuma !28_V
31345	purjetasin	purjeta	purjetama	27_V	IndIpfSg1	et	purjetasin =purjeta  (IndIpfSg1  >purjetama !27_V
31353	mängus	mängu	mäng	22_S	SgIn	et	mängus =mängu  (SgIn  >mäng !22_S
31368	kadus	kadu	kaduma	28_V	IndIpfSg3	et	kadus =kadu  (IndIpfSg3  >kaduma !28_V
31379	riigieksam	eksam	riigi+eksam	02_S	SgN	et	riigieksam =eksam  (SgN  >riigi+eksam !02_S
31382	harjuda	harju	harjuma	27_V	Inf	et	harjuda =harju  (Inf  >harjuma !27_V
31384	leidsin	leid	leidma	34_V	IndIpfSg1	et	leidsin =leid  (IndIpfSg1  >leidma !34_V
31385	hoian	hoia	hoidma	34_V	IndPrSg1	et	hoian =hoia  (IndPrSg1  >hoidma !34_V
31412	elukogemusi	kogemusi	elu+kogemus	11_S	PlP	et	elukogemusi =kogemusi  (PlP  >elu+kogemus !11_S
31425	lubas	luba	lubama	27_V	IndIpfSg3	et	lubas =luba  (IndIpfSg3  >lubama !27_V
31427	väljaõmblemisest	õmblemise	välja+õmblemine	12_S	SgEl	et	väljaõmblemisest =õmblemise  (SgEl  >välja+õmblemine !12_S
31435	klassiga	klassi	klass	22_S	SgKom	et	klassiga =klassi  (SgKom  >klass !22_S
31436	üksikolend	olend	üksik+olend	02_S	SgN	et	üksikolend =olend  (SgN  >üksik+olend !02_S
31445	nimekirjas	kirja	nime+kiri	24_S	SgIn	et	nimekirjas =kirja  (SgIn  >nime+kiri !24_S
31447	sessioon	sessioon	sessioon	22_S	SgN	et	sessioon =sessioon  (SgN  >sessioon !22_S
31452	operaatorina	operaatori	operaator	02_S	SgEs	et	operaatorina =operaatori  (SgEs  >operaator !02_S
31459	osalesin	osale	osalema	27_V	IndIpfSg1	et	osalesin =osale  (IndIpfSg1  >osalema !27_V
31460	esinesin	esine	esinema	27_V	IndIpfSg1	et	esinesin =esine  (IndIpfSg1  >esinema !27_V
31462	korterite	korteri	korter	02_S	PlG	et	korterite =korteri  (PlG  >korter !02_S
31463	disain	disain	disain	22_S	SgN	et	disain =disain  (SgN  >disain !22_S
31465	töid	tö	töö	26_S	PlP	et	töid =tö  (PlP  >töö !26_S
31470	joonistamas	joonista	joonistama	27_V	SupIn	et	joonistamas =joonista  (SupIn  >joonistama !27_V
31477	vastuvõtukomisjonile	komisjoni	vastu+võtu+komisjon	19_S	SgAll	et	vastuvõtukomisjonile =komisjoni  (SgAll  >vastu+võtu+komisjon !19_S
31479	üritasin	ürita	üritama	27_V	IndIpfSg1	et	üritasin =ürita  (IndIpfSg1  >üritama !27_V
31480	eksamit	eksami	eksam	02_S	SgP	et	eksamit =eksami  (SgP  >eksam !02_S
31488	infotehnoloogiat	tehnoloogia	info+tehnoloogia	01_S	SgP	et	infotehnoloogiat =tehnoloogia  (SgP  >info+tehnoloogia !01_S
31500	kompetentsed	kompetentse	kompetentne	02_A	PlN	et	kompetentsed =kompetentse  (PlN  >kompetentne !02_A
31504	temalt	tema	tema	00_P	SgAbl	et	temalt =tema  (SgAbl  >tema !00_P
31512	trennis	trenni	trenn	22_S	SgIn	et	trennis =trenni  (SgIn  >trenn !22_S
31518	mänguasjade	asja	mängu+asi	24_S	PlG	et	mänguasjade =asja  (PlG  >mängu+asi !24_S
31522	kergesti	kergesti	kergesti	41_D	ID	et	kergesti =kergesti  (ID  >kergesti !41_D
31524	võisin	või	võima	37_V	IndIpfSg1	et	võisin =või  (IndIpfSg1  >võima !37_V
31527	lööb	löö	lööma	38_V	IndPrSg3	et	lööb =löö  (IndPrSg3  >lööma !38_V
31533	langen	lange	langema	27_V	IndPrSg1	et	langen =lange  (IndPrSg1  >langema !27_V
31537	isiksuse	isiksuse	isiksus	11_S	SgG	et	isiksuse =isiksuse  (SgG  >isiksus !11_S
31543	üheksandas	üheksanda	üheksas	02_O	SgIn	et	üheksandas =üheksanda  (SgIn  >üheksas !02_O
31548	ajaviitmine	viitmine	aja+viitmine	12?10_S	SgN	et	ajaviitmine =viitmine  (SgN  >aja+viitmine !12?10_S
31552	vanaemaks	ema	vana+ema	17_S	SgTr	et	vanaemaks =ema  (SgTr  >vana+ema !17_S
31554	negatiivset	negatiivse	negatiivne	02_A	SgP	et	negatiivset =negatiivse  (SgP  >negatiivne !02_A
31290	väärtuslikud	väärtusliku	väärtuslik	25_A	PlN	et	väärtuslikud =väärtusliku  (PlN  >väärtuslik !25_A
31297	veevarustuse	varustuse	vee+varustus	11_S	SgG	et	veevarustuse =varustuse  (SgG  >vee+varustus !11_S
31301	rekonstrueeritakse	rekonstrueeri	rekonstrueerima	28_V	IndPrIps	et	rekonstrueeritakse =rekonstrueeri  (IndPrIps  >rekonstrueerima !28_V
31304	uuendatakse	uuenda	uuendama	27_V	IndPrIps	et	uuendatakse =uuenda  (IndPrIps  >uuendama !27_V
31307	platse	platse	plats	22_S	PlP	et	platse =platse  (PlP  >plats !22_S
31308	iseenda	enda	ise+enda	00_P	SgG	et	iseenda =enda  (SgG  >ise+enda !00_P
31313	turismimarsruudi	marsruudi	turismi+marsruut	22_S	SgG	et	turismimarsruudi =marsruudi  (SgG  >turismi+marsruut !22_S
31325	valitakse	vali	valima	27_V	IndPrIps	et	valitakse =vali  (IndPrIps  >valima !27_V
31326	väljaõpe	õpe	välja+õpe	06_S	SgN	et	väljaõpe =õpe  (SgN  >välja+õpe !06_S
31355	mull	mull	mull	22_S	SgN	et	mull =mull  (SgN  >mull !22_S
31360	emal	ema	ema	17_S	SgAd	et	emal =ema  (SgAd  >ema !17_S
31362	rõõmustasin	rõõmusta	rõõmustama	27_V	IndIpfSg1	et	rõõmustasin =rõõmusta  (IndIpfSg1  >rõõmustama !27_V
31364	lõppuks	uks	lõpp+uks	14_S	SgN	et	lõppuks =uks  (SgN  >lõpp+uks !14_S
31369	kohtasin	kohta	kohtama	29_V	IndIpfSg1	et	kohtasin =kohta  (IndIpfSg1  >kohtama !29_V
31372	tutvused	tutvuse	tutvus	11~09_S	PlN	et	tutvused =tutvuse  (PlN  >tutvus !11~09_S
31373	filoloogias	filoloogia	filoloogia	01_S	SgIn	et	filoloogias =filoloogia  (SgIn  >filoloogia !01_S
31374	proovida	proovi	proovima	28_V	Inf	et	proovida =proovi  (Inf  >proovima !28_V
31375	keelteõppimise	õppimise	keelte+õppimine	12_S	SgG	et	keelteõppimise =õppimise  (SgG  >keelte+õppimine !12_S
31376	loobuda	loobu	loobuma	27_V	Inf	et	loobuda =loobu  (Inf  >loobuma !27_V
31378	filoloogiks	filoloogi	filoloog	22_S	SgTr	et	filoloogiks =filoloogi  (SgTr  >filoloog !22_S
31380	kandideerida	kandideeri	kandideerima	28_V	Inf	et	kandideerida =kandideeri  (Inf  >kandideerima !28_V
31386	kontakte	kontakte	kontakt	22_S	PlP	et	kontakte =kontakte  (PlP  >kontakt !22_S
31388	proovisin	proovi	proovima	28_V	IndIpfSg1	et	proovisin =proovi  (IndIpfSg1  >proovima !28_V
31390	klaveriõpetajaga	õpetaja	klaveri+õpetaja	01_S	SgKom	et	klaveriõpetajaga =õpetaja  (SgKom  >klaveri+õpetaja !01_S
31392	võitsin	võit	võitma	34_V	IndIpfSg1	et	võitsin =võit  (IndIpfSg1  >võitma !34_V
31394	muutusin	muutu	muutuma	27_V	IndIpfSg1	et	muutusin =muutu  (IndIpfSg1  >muutuma !27_V
31400	muretsesin	muretse	muretsema	27_V	IndIpfSg1	et	muretsesin =muretse  (IndIpfSg1  >muretsema !27_V
31406	joontest	joon	joon	13_S	PlEl	et	joontest =joon  (PlEl  >joon !13_S
31413	kioskis	kioski	kiosk	02_S	SgIn	et	kioskis =kioski  (SgIn  >kiosk !02_S
31418	armastasin	armasta	armastama	27_V	IndIpfSg1	et	armastasin =armasta  (IndIpfSg1  >armastama !27_V
31420	püüdsin	püüd	püüdma	34_V	IndIpfSg1	et	püüdsin =püüd  (IndIpfSg1  >püüdma !34_V
31421	lõpueksameid	eksame	lõpu+eksam	02_S	PlP	et	lõpueksameid =eksame  (PlP  >lõpu+eksam !02_S
31422	idamaade	maa	ida+maa	26_S	PlG	et	idamaade =maa  (PlG  >ida+maa !26_S
31424	kokkulangemine	langemine	kokku+langemine	12_S	SgN	et	kokkulangemine =langemine  (SgN  >kokku+langemine !12_S
31431	klassid	klassi	klass	22_S	PlN	et	klassid =klassi  (PlN  >klass !22_S
31432	pöörati	pööra	pöörama	29_V	IndIpfIps	et	pöörati =pööra  (IndIpfIps  >pöörama !29_V
31440	kolmandat	kolmanda	kolmas	02_O	SgP	et	kolmandat =kolmanda  (SgP  >kolmas !02_O
31444	medaleid	medale	medal	02_S	PlP	et	medaleid =medale  (PlP  >medal !02_S
31451	raudteejaamas	jaama	raud+tee+jaam	22_S	SgIn	et	raudteejaamas =jaama  (SgIn  >raud+tee+jaam !22_S
31456	kelgutada	kelguta	kelgutama	27_V	Inf	et	kelgutada =kelguta  (Inf  >kelgutama !27_V
31458	klassini	klassi	klass	22_S	SgTer	et	klassini =klassi  (SgTer  >klass !22_S
31461	kontsertidel	kontserti	kontsert	22_S	PlAd	et	kontsertidel =kontserti  (PlAd  >kontsert !22_S
31473	riigieksameid	eksame	riigi+eksam	02_S	PlP	et	riigieksameid =eksame  (PlP  >riigi+eksam !02_S
31475	etapist	etapi	etapp	22_S	SgEl	et	etapist =etapi  (SgEl  >etapp !22_S
31490	tegingi	teg	tegema	28_V	IndIpfSg1^	et	tegingi =teg  (IndIpfSg1^  >tegema !28_V
31492	juhul	juhu	juht	22_S	SgAd	et	juhul =juhu  (SgAd  >juht !22_S
31496	abiturientide	abiturienti	abiturient	22_S	PlG	et	abiturientide =abiturienti  (PlG  >abiturient !22_S
31513	kergejõustiku	jõustiku	kerge+jõustik	25_S	SgG	et	kergejõustiku =jõustiku  (SgG  >kerge+jõustik !25_S
31515	pooleli	pooleli	pooleli	41_D	ID	et	pooleli =pooleli  (ID  >pooleli !41_D
31521	leian	leia	leidma	34_V	IndPrSg1	et	leian =leia  (IndPrSg1  >leidma !34_V
31534	negatiivsed	negatiivse	negatiivne	02_A	PlN	et	negatiivsed =negatiivse  (PlN  >negatiivne !02_A
31541	tõendab	tõenda	tõendama	27_V	IndPrSg3	et	tõendab =tõenda  (IndPrSg3  >tõendama !27_V
31542	asjal	asja	asi	24_S	SgAd	et	asjal =asja  (SgAd  >asi !24_S
31332	augustil	augusti	august	02_S	SgAd	et	augustil =augusti  (SgAd  >august !02_S
31334	vahetasin	vaheta	vahetama	27_V	IndIpfSg1	et	vahetasin =vaheta  (IndIpfSg1  >vahetama !27_V
31335	juudi	juudi	juut	22_S	SgG	et	juudi =juudi  (SgG  >juut !22_S
31337	neljandal	neljanda	neljas	02_O	SgAd	et	neljandal =neljanda  (SgAd  >neljas !02_O
31339	pois	poi	poi	26_S	SgIn	et	pois =poi  (SgIn  >poi !26_S
31340	lõhkus	lõhku	lõhkuma	28_V	IndIpfSg3	et	lõhkus =lõhku  (IndIpfSg3  >lõhkuma !28_V
31347	firmas	firma	firma	16_S	SgIn	et	firmas =firma  (SgIn  >firma !16_S
31351	vedus	vedus	vedus	02_A	SgN	et	vedus =vedus  (SgN  >vedus !02_A
31352	reisisime	reisi	reisima	28_V	IndIpfPl1	et	reisisime =reisi  (IndIpfPl1  >reisima !28_V
31357	raamastusin	raamastu	raamastuma	27_V	IndIpfSg1	et	raamastusin =raamastu  (IndIpfSg1  >raamastuma !27_V
31359	sisseastumiseksamid	eksami	sisse+astumis+eksam	02_S	PlN	et	sisseastumiseksamid =eksami  (PlN  >sisse+astumis+eksam !02_S
31366	tegime	teg	tegema	28_V	IndIpfPl1	et	tegime =teg  (IndIpfPl1  >tegema !28_V
31370	kursusele	kursuse	kursus	11~09_S	SgAll	et	kursusele =kursuse  (SgAll  >kursus !11~09_S
31387	soovitas	soovita	soovitama	27_V	IndIpfSg3	et	soovitas =soovita  (IndIpfSg3  >soovitama !27_V
31391	emaks	ema	ema	17_S	SgTr	et	emaks =ema  (SgTr  >ema !17_S
31397	tõused	tõuse	tõusma	32_V	IndPrSg2	et	tõused =tõuse  (IndPrSg2  >tõusma !32_V
31399	ebaõnneliku	õnneliku	eba+õnnelik	25_A	SgG	et	ebaõnneliku =õnneliku  (SgG  >eba+õnnelik !25_A
31401	tunduda	tundu	tunduma	27_V	Inf	et	tunduda =tundu  (Inf  >tunduma !27_V
31405	joontega	joon	joon	13_S	PlKom	et	joontega =joon  (PlKom  >joon !13_S
31410	juriidiliste	juriidilis	juriidiline	12_A	PlG	et	juriidiliste =juriidilis  (PlG  >juriidiline !12_A
31419	tantsuga	tantsu	tants	22_S	SgKom	et	tantsuga =tantsu  (SgKom  >tants !22_S
31437	turismiga	turismi	turism	22_S	SgKom	et	turismiga =turismi  (SgKom  >turism !22_S
31439	idakeeli	keel	ida+keel	13_S	PlP	et	idakeeli =keel  (PlP  >ida+keel !13_S
31449	aktsiaseltsis	seltsi	aktsia+selts	22_S	SgIn	et	aktsiaseltsis =seltsi  (SgIn  >aktsia+selts !22_S
31454	maalida	maali	maalima	28_V	Inf	et	maalida =maali  (Inf  >maalima !28_V
31457	gümnaasiumisse	gümnaasiumi	gümnaasium	19~02_S	SgIll	et	gümnaasiumisse =gümnaasiumi  (SgIll  >gümnaasium !19~02_S
31476	etapp	etapp	etapp	22_S	SgN	et	etapp =etapp  (SgN  >etapp !22_S
31478	etapil	etapi	etapp	22_S	SgAd	et	etapil =etapi  (SgAd  >etapp !22_S
31481	sooritama	soorita	sooritama	27_V	Sup	et	sooritama =soorita  (Sup  >sooritama !27_V
31484	konkursis	konkursi	konkurss	22_S	SgIn	et	konkursis =konkursi  (SgIn  >konkurss !22_S
31487	nutumaik	maik	nutu+maik	22_S	SgN	et	nutumaik =maik  (SgN  >nutu+maik !22_S
31489	püüda	püüd	püüdma	34_V	Inf	et	püüda =püüd  (Inf  >püüdma !34_V
31491	ettevalmistus	valmistus	ette+valmistus	11_S	SgN	et	ettevalmistus =valmistus  (SgN  >ette+valmistus !11_S
31502	hobiks	hobi	hobi	17_S	SgTr	et	hobiks =hobi  (SgTr  >hobi !17_S
31506	otsustasingi	otsusta	otsustama	27_V	IndIpfSg1^	et	otsustasingi =otsusta  (IndIpfSg1^  >otsustama !27_V
31510	tellimusi	tellimusi	tellimus	11_S	PlP	et	tellimusi =tellimusi  (PlP  >tellimus !11_S
31520	tantsida	tantsi	tantsima	28_V	Inf	et	tantsida =tantsi  (Inf  >tantsima !28_V
31525	valjusti	valjusti	valjusti	41_D	ID	et	valjusti =valjusti  (ID  >valjusti !41_D
31529	sündmusele	sündmuse	sündmus	11~09_S	SgAll	et	sündmusele =sündmuse  (SgAll  >sündmus !11~09_S
31530	elukatsed	katse	elu+katse	06_S	PlN	et	elukatsed =katse  (PlN  >elu+katse !06_S
31535	sündmusel	sündmuse	sündmus	11~09_S	SgAd	et	sündmusel =sündmuse  (SgAd  >sündmus !11~09_S
31540	positiivsed	positiivse	positiivne	02_A	PlN	et	positiivsed =positiivse  (PlN  >positiivne !02_A
31546	kursused	kursuse	kursus	11~09_S	PlN	et	kursused =kursuse  (PlN  >kursus !11~09_S
31547	filoloogiat	filoloogia	filoloogia	01_S	SgP	et	filoloogiat =filoloogia  (SgP  >filoloogia !01_S
31550	positiivset	positiivse	positiivne	02_A	SgP	et	positiivset =positiivse  (SgP  >positiivne !02_A
31555	klaveril	klaveri	klaver	02_S	SgAd	et	klaveril =klaveri  (SgAd  >klaver !02_S
31559	ebaõnnestumine	õnnestumine	eba+õnnestumine	12_S	SgN	et	ebaõnnestumine =õnnestumine  (SgN  >eba+õnnestumine !12_S
31568	kurvad	kurva	kurb	22_A	PlN	et	kurvad =kurva  (PlN  >kurb !22_A
31573	sõbrana	sõbra	sõber	24_S	SgEs	et	sõbrana =sõbra  (SgEs  >sõber !24_S
31579	lõpetab	lõpeta	lõpetama	27_V	IndPrSg3	et	lõpetab =lõpeta  (IndPrSg3  >lõpetama !27_V
31581	üheksanda	üheksanda	üheksas	02_O	SgG	et	üheksanda =üheksanda  (SgG  >üheksas !02_O
31582	hirmsasti	hirmsasti	hirmsasti	41_D	ID	et	hirmsasti =hirmsasti  (ID  >hirmsasti !41_D
31589	mängima	mängi	mängima	28_V	Sup	et	mängima =mängi  (Sup  >mängima !28_V
31592	meistriliigas	liiga	meistri+liiga	16_S	SgIn	et	meistriliigas =liiga  (SgIn  >meistri+liiga !16_S
31453	kaheksanda	kaheksanda	kaheksas	02_O	SgG	et	kaheksanda =kaheksanda  (SgG  >kaheksas !02_O
31455	kiikuda	kiiku	kiikuma	28_V	Inf	et	kiikuda =kiiku  (Inf  >kiikuma !28_V
31472	valiksin	vali	valima	27_V	KndPrSg1	et	valiksin =vali  (KndPrSg1  >valima !27_V
31482	vajalikke	vajalikke	vajalik	25_A	PlP	et	vajalikke =vajalikke  (PlP  >vajalik !25_A
31485	langesin	lange	langema	27_V	IndIpfSg1	et	langesin =lange  (IndIpfSg1  >langema !27_V
31486	sisseastumist	astumis	sisse+astumine	12_S	SgP	et	sisseastumist =astumis  (SgP  >sisse+astumine !12_S
31493	jõudsin	jõud	jõudma	34_V	IndIpfSg1	et	jõudsin =jõud  (IndIpfSg1  >jõudma !34_V
31494	kutsumus	kutsumus	kutsumus	11_S	SgN	et	kutsumus =kutsumus  (SgN  >kutsumus !11_S
31495	elukutseid	kutse	elu+kutse	06_S	PlP	et	elukutseid =kutse  (PlP  >elu+kutse !06_S
31498	põllumajandus	majandus	põllu+majandus	11_S	SgN	et	põllumajandus =majandus  (SgN  >põllu+majandus !11_S
31503	tööoskuse	oskuse	töö+oskus	11~09_S	SgG	et	tööoskuse =oskuse  (SgG  >töö+oskus !11~09_S
31505	armastada	armasta	armastama	27_V	Inf	et	armastada =armasta  (Inf  >armastama !27_V
31509	kampsunit	kampsuni	kampsun	02_S	SgP	et	kampsunit =kampsuni  (SgP  >kampsun !02_S
31514	jätsin	jät	jätma	35_V	IndIpfSg1	et	jätsin =jät  (IndIpfSg1  >jätma !35_V
31526	karjusin	karju	karjuma	28_V	IndIpfSg1	et	karjusin =karju  (IndIpfSg1  >karjuma !28_V
31531	unustan	unusta	unustama	27_V	IndPrSg1	et	unustan =unusta  (IndPrSg1  >unustama !27_V
31532	tundlik	tundlik	tundlik	25_A	SgN	et	tundlik =tundlik  (SgN  >tundlik !25_A
31536	impulsi	impulsi	impulss	22_S	SgG	et	impulsi =impulsi  (SgG  >impulss !22_S
31545	ajakirjanduse	kirjanduse	aja+kirjandus	11_S	SgG	et	ajakirjanduse =kirjanduse  (SgG  >aja+kirjandus !11_S
31564	kassapidajana	pidaja	kassa+pidaja	01_S	SgEs	et	kassapidajana =pidaja  (SgEs  >kassa+pidaja !01_S
31572	nägime	näg	nägema	28_V	IndIpfPl1	et	nägime =näg  (IndIpfPl1  >nägema !28_V
31575	mustmeres	mere	must+meri	20_S	SgIn	et	mustmeres =mere  (SgIn  >must+meri !20_S
31585	suhu	su	suu	26_S	SgAdt	et	suhu =su  (SgAdt  >suu !26_S
31593	tihtipeale	tihtipeale	tihti+peale	41_D	ID	et	tihtipeale =tihtipeale  (ID  >tihti+peale !41_D
31598	sünnipäevaks	päeva	sünni+päev	22_S	SgTr	et	sünnipäevaks =päeva  (SgTr  >sünni+päev !22_S
31616	rõõmust	rõõmu	rõõm	22_S	SgEl	et	rõõmust =rõõmu  (SgEl  >rõõm !22_S
31618	lõpuaktuseks	aktuse	lõpu+aktus	11~09_S	SgTr	et	lõpuaktuseks =aktuse  (SgTr  >lõpu+aktus !11~09_S
31636	ebameeldiv	meeldiv	eba+meeldiv	02_A	SgN	et	ebameeldiv =meeldiv  (SgN  >eba+meeldiv !02_A
31647	suunab	suuna	suunama	29_V	IndPrSg3	et	suunab =suuna  (IndPrSg3  >suunama !29_V
31648	planeerin	planeeri	planeerima	28_V	IndPrSg1	et	planeerin =planeeri  (IndPrSg1  >planeerima !28_V
31650	suhtuda	suhtu	suhtuma	27_V	Inf	et	suhtuda =suhtu  (Inf  >suhtuma !27_V
31656	õppimas	õppi	õppima	28_V	SupIn	et	õppimas =õppi  (SupIn  >õppima !28_V
31658	analüüsisin	analüüsi	analüüsima	28_V	IndIpfSg1	et	analüüsisin =analüüsi  (IndIpfSg1  >analüüsima !28_V
31667	tagasitulekut	tuleku	tagasi+tulek	02_S	SgP	et	tagasitulekut =tuleku  (SgP  >tagasi+tulek !02_S
31673	täitsa	täitsa	täitsa	41_D	ID	et	täitsa =täitsa  (ID  >täitsa !41_D
31674	redeli	redeli	redel	02_S	SgG	et	redeli =redeli  (SgG  >redel !02_S
31683	elukoht	koht	elu+koht	22_S	SgN	et	elukoht =koht  (SgN  >elu+koht !22_S
31684	jõe	jõe	jõgi	21_S	SgG	et	jõe =jõe  (SgG  >jõgi !21_S
31690	tõstab	tõsta	tõstma	34_V	IndPrSg3	et	tõstab =tõsta  (IndPrSg3  >tõstma !34_V
31693	küttepuid	pu	kütte+puu	26_S	PlP	et	küttepuid =pu  (PlP  >kütte+puu !26_S
31702	lambad	lamba	lammas	07_S	PlN	et	lambad =lamba  (PlN  >lammas !07_S
31704	valvekoerad	koera	valve+koer	23?22_SA	PlN	et	valvekoerad =koera  (PlN  >valve+koer !23?22_SA
31710	ahv	ahv	ahv	22_S	SgN	et	ahv =ahv  (SgN  >ahv !22_S
31713	istusime	istu	istuma	28_V	IndIpfPl1	et	istusime =istu  (IndIpfPl1  >istuma !28_V
31716	lõbusad	lõbusa	lõbus	02_A	PlN	et	lõbusad =lõbusa  (PlN  >lõbus !02_A
31718	õuele	õue	õu	22_S	SgAll	et	õuele =õue  (SgAll  >õu !22_S
31722	sõbrannad	sõbranna	sõbranna	16_S	PlN	et	sõbrannad =sõbranna  (PlN  >sõbranna !16_S
31726	moodsad	moodsa	moodne	02_A	PlN	et	moodsad =moodsa  (PlN  >moodne !02_A
31730	minut	minut	minut	02_S	SgN	et	minut =minut  (SgN  >minut !02_S
31737	plusse	plusse	pluss	22_S	PlP	et	plusse =plusse  (PlP  >pluss !22_S
31745	hinnaga	hinna	hind	22_S	SgKom	et	hinnaga =hinna  (SgKom  >hind !22_S
31749	toidupood	pood	toidu+pood	22_S	SgN	et	toidupood =pood  (SgN  >toidu+pood !22_S
31751	lemmikloomadele	looma	lemmik+loom	22_S	PlAll	et	lemmikloomadele =looma  (PlAll  >lemmik+loom !22_S
31755	naudin	naudi	nautima	28_V	IndPrSg1	et	naudin =naudi  (IndPrSg1  >nautima !28_V
31762	hilja	hilja	hilja	41_D	ID	et	hilja =hilja  (ID  >hilja !41_D
31516	ballett	ballett	ballett	22_S	SgN	et	ballett =ballett  (SgN  >ballett !22_S
31517	pehmete	pehme	pehme	01_A	PlG	et	pehmete =pehme  (PlG  >pehme !01_A
31519	pidime	pid	pida	40_V	IndIpfPl1	et	pidime =pid  (IndIpfPl1  >pida !40_V
31523	reageerida	reageeri	reageerima	28_V	Inf	et	reageerida =reageeri  (Inf  >reageerima !28_V
31528	etapi	etapi	etapp	22_S	SgG	et	etapi =etapi  (SgG  >etapp !22_S
31538	haav	haav	haav	22_S	SgN	et	haav =haav  (SgN  >haav !22_S
31539	ärajooks	jooks	ära+jooks	22_S	SgN	et	ärajooks =jooks  (SgN  >ära+jooks !22_S
31544	stuudios	stuudio	stuudio	01_S	SgIn	et	stuudios =stuudio  (SgIn  >stuudio !01_S
31553	õie	õie	õis	14_S	SgG	et	õie =õie  (SgG  >õis !14_S
31557	tpü-sse	tpü	tpü	xx_Q	SgIll	et	tpü-sse =tpü  (SgIll  >tpü !xx_Q
31558	poolasse	asse	pool+ass	22_S	PlP	et	poolasse =asse  (PlP  >pool+ass !22_S
31560	onul	onu	onu	17_S	SgAd	et	onul =onu  (SgAd  >onu !17_S
31565	töölt	töö	töö	26_S	SgAbl	et	töölt =töö  (SgAbl  >töö !26_S
31566	lõbusaid	lõbusa	lõbus	02_A	PlP	et	lõbusaid =lõbusa  (PlP  >lõbus !02_A
31567	momente	momente	moment	22_S	PlP	et	momente =momente  (PlP  >moment !22_S
31578	väärtustama	väärtusta	väärtustama	27_V	Sup	et	väärtustama =väärtusta  (Sup  >väärtustama !27_V
31586	neljandast	neljanda	neljas	02_O	SgEl	et	neljandast =neljanda  (SgEl  >neljas !02_O
31588	praeguseks	praeguse	praegune	10~12_A	SgTr	et	praeguseks =praeguse  (SgTr  >praegune !10~12_A
31591	hele	hele	hele	02_A	SgN	et	hele =hele  (SgN  >hele !02_A
31596	treeneriga	treeneri	treener	02_S	SgKom	et	treeneriga =treeneri  (SgKom  >treener !02_S
31600	kutsusin	kutsu	kutsuma	28_V	IndIpfSg1	et	kutsusin =kutsu  (IndIpfSg1  >kutsuma !28_V
31601	rulluiskudega	uisku	rull+uisk	22_S	PlKom	et	rulluiskudega =uisku  (PlKom  >rull+uisk !22_S
31615	hüppasin	hüppa	hüppama	29_V	IndIpfSg1	et	hüppasin =hüppa  (IndIpfSg1  >hüppama !29_V
31622	situatsioone	situatsioone	situatsioon	22_S	PlP	et	situatsioone =situatsioone  (PlP  >situatsioon !22_S
31625	medali	medali	medal	02_S	SgG	et	medali =medali  (SgG  >medal !02_S
31629	heade	hea	hea	26_AS	PlG	et	heade =hea  (PlG  >hea !26_AS
31631	ettevõtes	võte	ette+võtt	22_S	PlIn	et	ettevõtes =võte  (PlIn  >ette+võtt !22_S
31634	kurvastas	kurvasta	kurvastama	27_V	IndIpfSg3	et	kurvastas =kurvasta  (IndIpfSg3  >kurvastama !27_V
31638	mõnele	mõne	mõni	20_P	SgAll	et	mõnele =mõne  (SgAll  >mõni !20_P
31640	otsisime	otsi	otsima	28_V	IndIpfPl1	et	otsisime =otsi  (IndIpfPl1  >otsima !28_V
31643	üliõnnelik	õnnelik	üli+õnnelik	25_A	SgN	et	üliõnnelik =õnnelik  (SgN  >üli+õnnelik !25_A
31644	elabki	ela	elama	27_V	IndPrSg3^	et	elabki =ela  (IndPrSg3^  >elama !27_V
31646	elukogemust	kogemus	elu+kogemus	11_S	SgP	et	elukogemust =kogemus  (SgP  >elu+kogemus !11_S
31649	elusse	elu	elu	17_S	SgIll	et	elusse =elu  (SgIll  >elu !17_S
31652	üleõnnelik	õnnelik	üle+õnnelik	25_A	SgN	et	üleõnnelik =õnnelik  (SgN  >üle+õnnelik !25_A
31655	energiliseks	energilise	energiline	12_A	SgTr	et	energiliseks =energilise  (SgTr  >energiline !12_A
31663	kohtadesse	kohta	koht	22_S	PlIll	et	kohtadesse =kohta  (PlIll  >koht !22_S
31665	kaitseväes	väe	kaitse+vägi	21_S	SgIn	et	kaitseväes =väe  (SgIn  >kaitse+vägi !21_S
31666	väkke	väkke	vägi	21_S	SgAdt	et	väkke =väkke  (SgAdt  >vägi !21_S
31669	toredat	toreda	tore	02_A	SgP	et	toredat =toreda  (SgP  >tore !02_A
31676	hakkame	hakka	hakkama	29_V	IndPrPl1	et	hakkame =hakka  (IndPrPl1  >hakkama !29_V
31678	vaatasin	vaata	vaatama	29_V	IndIpfSg1	et	vaatasin =vaata  (IndIpfSg1  >vaatama !29_V
31689	saunasse	sauna	saun	22_S	SgIll	et	saunasse =sauna  (SgIll  >saun !22_S
31697	puuviljad	vilja	puu+vili	24_S	PlN	et	puuviljad =vilja  (PlN  >puu+vili !24_S
31709	ahviga	ahvi	ahv	22_S	SgKom	et	ahviga =ahvi  (SgKom  >ahv !22_S
31719	toas	toa	tuba	18_S	SgIn	et	toas =toa  (SgIn  >tuba !18_S
31720	arvasime	arva	arvama	29_V	IndIpfPl1	et	arvasime =arva  (IndIpfPl1  >arvama !29_V
31723	kaubad	kauba	kaup	22_S	PlN	et	kaubad =kauba  (PlN  >kaup !22_S
31724	kvaliteetsed	kvaliteetse	kvaliteetne	02_A	PlN	et	kvaliteetsed =kvaliteetse  (PlN  >kvaliteetne !02_A
31727	heal	hea	hea	26_AS	SgAd	et	heal =hea  (SgAd  >hea !26_AS
31731	turult	turu	turg	22_S	SgAbl	et	turult =turu  (SgAbl  >turg !22_S
31733	ehmatada	ehmata	ehmatama	27_V	Inf	et	ehmatada =ehmata  (Inf  >ehmatama !27_V
31735	originaalsed	originaalse	originaalne	02_A	PlN	et	originaalsed =originaalse  (PlN  >originaalne !02_A
31738	maitsele	maitse	maitse	06_S	SgAll	et	maitsele =maitse  (SgAll  >maitse !06_S
31740	eakad	eaka	eakas	02_A	PlN	et	eakad =eaka  (PlN  >eakas !02_A
31748	keskusega	keskuse	keskus	11~09_S	SgKom	et	keskusega =keskuse  (SgKom  >keskus !11~09_S
31549	algklasside	klassi	alg+klass	22_S	PlG	et	algklasside =klassi  (PlG  >alg+klass !22_S
31551	sünniaeg	aeg	sünni+aeg	22_S	SgN	et	sünniaeg =aeg  (SgN  >sünni+aeg !22_S
31556	elule	elu	elu	17_S	SgAll	et	elule =elu  (SgAll  >elu !17_S
31562	kottis	kottis	kottis	41_DA	ID	et	kottis =kottis  (ID  >kottis !41_DA
31563	koolimuusikat	muusika	kooli+muusika	01_S	SgP	et	koolimuusikat =muusika  (SgP  >kooli+muusika !01_S
31569	ebameeldivaid	meeldiva	eba+meeldiv	02_A	PlP	et	ebameeldivaid =meeldiva  (PlP  >eba+meeldiv !02_A
31576	nautida	nauti	nautima	28_V	Inf	et	nautida =nauti  (Inf  >nautima !28_V
31577	hetkega	hetke	hetk	22_S	SgKom	et	hetkega =hetke  (SgKom  >hetk !22_S
31580	saati	saati	saati	41_DK	ID	et	saati =saati  (ID  >saati !41_DK
31583	põhieesmärgiks	märgi	põhi+ees+märk	22_S	SgTr	et	põhieesmärgiks =märgi  (SgTr  >põhi+ees+märk !22_S
31584	teadsin	tead	teadma	34_V	IndIpfSg1	et	teadsin =tead  (IndIpfSg1  >teadma !34_V
31587	korvpalliga	palli	korv+pall	22_S	SgKom	et	korvpalliga =palli  (SgKom  >korv+pall !22_S
31590	sündmusena	sündmuse	sündmus	11~09_S	SgEs	et	sündmusena =sündmuse  (SgEs  >sündmus !11~09_S
31606	paljassaare	saare	paljas+saar	13_S	SgG	et	paljassaare =saare  (SgG  >paljas+saar !13_S
31609	rõõmsameelne	meelne	rõõmsa+meelne	02_A	SgN	et	rõõmsameelne =meelne  (SgN  >rõõmsa+meelne !02_A
31614	võistlusel	võistluse	võistlus	11~09_S	SgAd	et	võistlusel =võistluse  (SgAd  >võistlus !11~09_S
31621	õpetlike	õpetlike	õpetlik	25_A	PlG	et	õpetlike =õpetlike  (PlG  >õpetlik !25_A
31624	lõputunnistused	tunnistuse	lõpu+tunnistus	11_S	PlN	et	lõputunnistused =tunnistuse  (PlN  >lõpu+tunnistus !11_S
31627	seon	seo	siduma	28_V	IndPrSg1	et	seon =seo  (IndPrSg1  >siduma !28_V
31637	hilinesin	hiline	hilinema	27_V	IndIpfSg1	et	hilinesin =hiline  (IndIpfSg1  >hilinema !27_V
31641	hakkasime	hakka	hakkama	29_V	IndIpfPl1	et	hakkasime =hakka  (IndIpfPl1  >hakkama !29_V
31642	kurvastasin	kurvasta	kurvastama	27_V	IndIpfSg1	et	kurvastasin =kurvasta  (IndIpfSg1  >kurvastama !27_V
31651	rõõmustan	rõõmusta	rõõmustama	27_V	IndPrSg1	et	rõõmustan =rõõmusta  (IndPrSg1  >rõõmustama !27_V
31654	muutis	muut	muutma	34_V	IndIpfSg3	et	muutis =muut  (IndIpfSg3  >muutma !34_V
31660	põhjusi	põhjusi	põhjus	11_S	PlP	et	põhjusi =põhjusi  (PlP  >põhjus !11_S
31664	autole	auto	auto	16_S	SgAll	et	autole =auto  (SgAll  >auto !16_S
31670	lõbusat	lõbusa	lõbus	02_A	SgP	et	lõbusat =lõbusa  (SgP  >lõbus !02_A
31675	eramajja	majja	era+maja	17_S	SgAdt	et	eramajja =majja  (SgAdt  >era+maja !17_S
31677	armastasime	armasta	armastama	27_V	IndIpfPl1	et	armastasime =armasta  (IndIpfPl1  >armastama !27_V
31679	lamab	lama	lamama	27_V	IndPrSg3	et	lamab =lama  (IndPrSg3  >lamama !27_V
31680	liigub	liigu	liikuma	28_V	IndPrSg3	et	liigub =liigu  (IndPrSg3  >liikuma !28_V
31681	kast	kast	kast	22_S	SgN	et	kast =kast  (SgN  >kast !22_S
31686	rahulikud	rahuliku	rahulik	25_A	PlN	et	rahulikud =rahuliku  (PlN  >rahulik !25_A
31691	eramajas	maja	era+maja	17_S	SgIn	et	eramajas =maja  (SgIn  >era+maja !17_S
31699	plussid	plussi	pluss	22_S	PlN	et	plussid =plussi  (PlN  >pluss !22_S
31705	naabri	naabri	naaber	02_S	SgG	et	naabri =naabri  (SgG  >naaber !02_S
31715	banaan	banaan	banaan	22_S	SgN	et	banaan =banaan  (SgN  >banaan !22_S
31717	näod	näo	nägu	18_S	PlN	et	näod =näo  (PlN  >nägu !18_S
31721	avasime	ava	avama	27_V	IndIpfPl1	et	avasime =ava  (IndIpfPl1  >avama !27_V
31729	häirib	häiri	häirima	28_V	IndPrSg3	et	häirib =häiri  (IndPrSg3  >häirima !28_V
31741	keskuse	keskuse	keskus	11~09_S	SgG	et	keskuse =keskuse  (SgG  >keskus !11~09_S
31742	riietega	riie	riie	06_S	PlKom	et	riietega =riie  (PlKom  >riie !06_S
31743	moodsat	moodsa	moodne	02_A	SgP	et	moodsat =moodsa  (SgP  >moodne !02_A
31744	allahindlused	hindluse	alla+hindlus	11~09_S	PlN	et	allahindlused =hindluse  (PlN  >alla+hindlus !11~09_S
31753	eelis	eelis	eelis	09_S	SgN	et	eelis =eelis  (SgN  >eelis !09_S
31758	tipptundidel	tundi	tipp+tund	22_S	PlAd	et	tipptundidel =tundi  (PlAd  >tipp+tund !22_S
31760	tööaeg	aeg	töö+aeg	22_S	SgN	et	tööaeg =aeg  (SgN  >töö+aeg !22_S
31768	ninul	ninu	nina	17_S	PlAd	et	ninul =ninu  (PlAd  >nina !17_S
31772	klaverit	klaveri	klaver	02_S	SgP	et	klaverit =klaveri  (SgP  >klaver !02_S
31793	muusikaõpetajana	õpetaja	muusika+õpetaja	01_S	SgEs	et	muusikaõpetajana =õpetaja  (SgEs  >muusika+õpetaja !01_S
31797	kahekesi	kahekesi	kahekesi	41_D	ID	et	kahekesi =kahekesi  (ID  >kahekesi !41_D
31803	tutvusi	tutvusi	tutvus	11_S	PlP	et	tutvusi =tutvusi  (PlP  >tutvus !11_S
31815	polikliinik	polikliinik	polikliinik	02_S	SgN	et	polikliinik =polikliinik  (SgN  >polikliinik !02_S
31822	käiks	käi	käima	38_V	KndPrPs	et	käiks =käi  (KndPrPs  >käima !38_V
31823	naabrid	naabri	naaber	02_S	PlN	et	naabrid =naabri  (PlN  >naaber !02_S
31561	isata	isa	isa	17_S	SgAb	et	isata =isa  (SgAb  >isa !17_S
31570	toimuski	toimu	toimuma	27_V	IndIpfSg3^	et	toimuski =toimu  (IndIpfSg3^  >toimuma !27_V
31571	parata	parata	parata	41_D	ID	et	parata =parata  (ID  >parata !41_D
31574	puhkasime	puhka	puhkama	29_V	IndIpfPl1	et	puhkasime =puhka  (IndIpfPl1  >puhkama !29_V
31594	sant	sant	sant	22_SA	SgN	et	sant =sant  (SgN  >sant !22_SA
31597	tülisid	tüli	tüli	17_S	PlP	et	tülisid =tüli  (PlP  >tüli !17_S
31599	rulluisud	uisu	rull+uisk	22_S	PlN	et	rulluisud =uisu  (PlN  >rull+uisk !22_S
31602	uisutasime	uisuta	uisutama	27_V	IndIpfPl1	et	uisutasime =uisuta  (IndIpfPl1  >uisutama !27_V
31605	loengut	loengu	loeng	02_S	SgP	et	loengut =loengu  (SgP  >loeng !02_S
31608	iseloomult	loomu	ise+loom	22_S	SgAbl	et	iseloomult =loomu  (SgAbl  >ise+loom !22_S
31612	tippsportlaseks	sportlase	tipp+sportlane	12?10_S	SgTr	et	tippsportlaseks =sportlase  (SgTr  >tipp+sportlane !12?10_S
31620	püüdsime	püüd	püüdma	34_V	IndIpfPl1	et	püüdsime =püüd  (IndIpfPl1  >püüdma !34_V
31628	nõnda	nõnda	nõnda	41_D	ID	et	nõnda =nõnda  (ID  >nõnda !41_D
31630	asusin	asu	asuma	27_V	IndIpfSg1	et	asusin =asu  (IndIpfSg1  >asuma !27_V
31632	meeskond	meeskond	meeskond	22_S	SgN	et	meeskond =meeskond  (SgN  >meeskond !22_S
31635	annan	anna	andma	34_V	IndPrSg1	et	annan =anna  (IndPrSg1  >andma !34_V
31653	praktikas	praktika	praktika	01_S	SgIn	et	praktikas =praktika  (SgIn  >praktika !01_S
31657	katsed	katse	katse	06_S	PlN	et	katsed =katse  (PlN  >katse !06_S
31659	ebaõnnestumise	õnnestumise	eba+õnnestumine	12_S	SgG	et	ebaõnnestumise =õnnestumise  (SgG  >eba+õnnestumine !12_S
31662	paljudesse	palju	palju	16_P	PlIll	et	paljudesse =palju  (PlIll  >palju !16_P
31671	ülejärgmisel	järgmise	üle+järgmine	12?10_A	SgAd	et	ülejärgmisel =järgmise  (SgAd  >üle+järgmine !12?10_A
31682	naeratas	naerata	naeratama	27_V	IndIpfSg3	et	naeratas =naerata  (IndIpfSg3  >naeratama !27_V
31685	heatundlikud	tundliku	hea+tundlik	25_A	PlN	et	heatundlikud =tundliku  (PlN  >hea+tundlik !25_A
31688	saun	saun	saun	22_S	SgN	et	saun =saun  (SgN  >saun !22_S
31694	kamini	kamini	kamin	02_S	SgG	et	kamini =kamini  (SgG  >kamin !02_S
31696	juurviljad	vilja	juur+vili	24_S	PlN	et	juurviljad =vilja  (PlN  >juur+vili !24_S
31703	kanad	kana	kana	17_S	PlN	et	kanad =kana  (PlN  >kana !17_S
31708	ostsime	ost	ostma	34_V	IndIpfPl1	et	ostsime =ost  (IndIpfPl1  >ostma !34_V
31711	toolis	tooli	tool	22_S	SgIn	et	toolis =tooli  (SgIn  >tool !22_S
31714	isale	isa	isa	17_S	SgAll	et	isale =isa  (SgAll  >isa !17_S
31725	asjaga	asja	asi	24_S	SgKom	et	asjaga =asja  (SgKom  >asi !24_S
31734	turg	turg	turg	22_S	SgN	et	turg =turg  (SgN  >turg !22_S
31736	kvaliteet	kvaliteet	kvaliteet	22_S	SgN	et	kvaliteet =kvaliteet  (SgN  >kvaliteet !22_S
31746	ütlema	ütle	ütlema	30_V	Sup	et	ütlema =ütle  (Sup  >ütlema !30_V
31747	parast	paras	paras	02_A	SgP	et	parast =paras  (SgP  >paras !02_A
31750	kaup	kaup	kaup	22_S	SgN	et	kaup =kaup  (SgN  >kaup !22_S
31759	ümberkorraldamist	korraldamis	ümber+korraldamine	12_S	SgP	et	ümberkorraldamist =korraldamis  (SgP  >ümber+korraldamine !12_S
31761	avab	ava	avama	27_V	IndPrSg3	et	avab =ava  (IndPrSg3  >avama !27_V
31777	rõõmsat	rõõmsa	rõõmus	02_A	SgP	et	rõõmsat =rõõmsa  (SgP  >rõõmus !02_A
31783	sõjaväkke	väkke	sõja+vägi	21_S	SgAdt	et	sõjaväkke =väkke  (SgAdt  >sõja+vägi !21_S
31784	klaver	klaver	klaver	02_S	SgN	et	klaver =klaver  (SgN  >klaver !02_S
31788	asutasin	asuta	asutama	27_V	IndIpfSg1	et	asutasin =asuta  (IndIpfSg1  >asutama !27_V
31790	valmistasin	valmista	valmistama	27_V	IndIpfSg1	et	valmistasin =valmista  (IndIpfSg1  >valmistama !27_V
31792	täiskasvatuse	kasvatuse	täis+kasvatus	11_S	SgG	et	täiskasvatuse =kasvatuse  (SgG  >täis+kasvatus !11_S
31799	tungiti	tungi	tungima	28_V	IndIpfIps	et	tungiti =tungi  (IndIpfIps  >tungima !28_V
31800	külastamas	külasta	külastama	27_V	SupIn	et	külastamas =külasta  (SupIn  >külastama !27_V
31804	valutas	valuta	valutama	27_V	IndIpfSg3	et	valutas =valuta  (IndIpfSg3  >valutama !27_V
31809	lukus	luku	lukk	22_S	SgIn	et	lukus =luku  (SgIn  >lukk !22_S
31813	busside	bussi	buss	22_S	PlG	et	busside =bussi  (PlG  >buss !22_S
31814	busse	busse	buss	22_S	PlP	et	busse =busse  (PlP  >buss !22_S
31817	seisukord	kord	seisu+kord	22_S	SgN	et	seisukord =kord  (SgN  >seisu+kord !22_S
31818	puhas	puhas	puhas	07_A	SgN	et	puhas =puhas  (SgN  >puhas !07_A
31820	ukselukk	lukk	ukse+lukk	22_S	SgN	et	ukselukk =lukk  (SgN  >ukse+lukk !22_S
31824	külaskäiguks	käigu	külas+käik	22_S	SgTr	et	külaskäiguks =käigu  (SgTr  >külas+käik !22_S
31826	normaalse	normaalse	normaalne	02_A	SgG	et	normaalse =normaalse  (SgG  >normaalne !02_A
31829	ruum	ruum	ruum	22_S	SgN	et	ruum =ruum  (SgN  >ruum !22_S
31595	tülitsesime	tülitse	tülitsema	27_V	IndIpfPl1	et	tülitsesime =tülitse  (IndIpfPl1  >tülitsema !27_V
31603	kukkusin	kukku	kukkuma	28_V	IndIpfSg1	et	kukkusin =kukku  (IndIpfSg1  >kukkuma !28_V
31604	trennisid	trenni	trenn	22_S	PlP	et	trennisid =trenni  (PlP  >trenn !22_S
31607	laohoidjana	hoidja	lao+hoidja	01_S	SgEs	et	laohoidjana =hoidja  (SgEs  >lao+hoidja !01_S
31610	soojendab	soojenda	soojendama	27_V	IndPrSg3	et	soojendab =soojenda  (IndPrSg3  >soojendama !27_V
31611	võistlust	võistlus	võistlus	11~09_S	SgP	et	võistlust =võistlus  (SgP  >võistlus !11~09_S
31613	positiivsetest	positiivse	positiivne	02_A	PlEl	et	positiivsetest =positiivse  (PlEl  >positiivne !02_A
31617	positiivsete	positiivse	positiivne	02_A	PlG	et	positiivsete =positiivse  (PlG  >positiivne !02_A
31619	kontserdi	kontserdi	kontsert	22_S	SgG	et	kontserdi =kontserdi  (SgG  >kontsert !22_S
31623	formaalne	formaalne	formaalne	02_A	SgN	et	formaalne =formaalne  (SgN  >formaalne !02_A
31626	samm	samm	samm	22_S	SgN	et	samm =samm  (SgN  >samm !22_S
31633	kasulikke	kasulikke	kasulik	25_A	PlP	et	kasulikke =kasulikke  (PlP  >kasulik !25_A
31639	vastutustundlik	tundlik	vastutus+tundlik	25_A	SgN	et	vastutustundlik =tundlik  (SgN  >vastutus+tundlik !25_A
31645	järjekordset	kordse	järje+kordne	02_AS	SgP	et	järjekordset =kordse  (SgP  >järje+kordne !02_AS
31661	hädavajalik	vajalik	häda+vajalik	25_A	SgN	et	hädavajalik =vajalik  (SgN  >häda+vajalik !25_A
31668	koduloom	loom	kodu+loom	22_S	SgN	et	koduloom =loom  (SgN  >kodu+loom !22_S
31672	puhkas	puhka	puhkama	29_V	IndIpfSg3	et	puhkas =puhka  (IndIpfSg3  >puhkama !29_V
31687	õhuga	õhu	õhk	22_S	SgKom	et	õhuga =õhu  (SgKom  >õhk !22_S
31692	küte	küte	küte	06_S	SgN	et	küte =küte  (SgN  >küte !06_S
31695	keelsed	keelse	keelne	02_A	PlN	et	keelsed =keelse  (PlN  >keelne !02_A
31698	kasvatame	kasvata	kasvatama	27_V	IndPrPl1	et	kasvatame =kasvata  (IndPrPl1  >kasvatama !27_V
31700	asendada	asenda	asendama	27_V	Inf	et	asendada =asenda  (Inf  >asendama !27_V
31701	naabril	naabri	naaber	02_S	SgAd	et	naabril =naabri  (SgAd  >naaber !02_S
31706	koerad	koera	koer	23?22_SA	PlN	et	koerad =koera  (PlN  >koer !23?22_SA
31707	veri	veri	veri	20_S	SgN	et	veri =veri  (SgN  >veri !20_S
31712	otsustasime	otsusta	otsustama	27_V	IndIpfPl1	et	otsustasime =otsusta  (IndIpfPl1  >otsustama !27_V
31728	pisut	pisut	pisut	41_D	ID	et	pisut =pisut  (ID  >pisut !41_D
31732	miinused	miinuse	miinus	09_S	PlN	et	miinused =miinuse  (PlN  >miinus !09_S
31739	turu	turu	turg	22_S	SgG	et	turu =turu  (SgG  >turg !22_S
31752	suurtele	suur	suur	13_A	PlAll	et	suurtele =suur  (PlAll  >suur !13_A
31756	kassapidajat	pidaja	kassa+pidaja	01_S	SgP	et	kassapidajat =pidaja  (SgP  >kassa+pidaja !01_S
31757	riiete	riie	riie	06_S	PlG	et	riiete =riie  (PlG  >riie !06_S
31763	rõõmsaks	rõõmsa	rõõmus	02_A	SgTr	et	rõõmsaks =rõõmsa  (SgTr  >rõõmus !02_A
31765	elukutset	kutse	elu+kutse	06_S	SgP	et	elukutset =kutse  (SgP  >elu+kutse !06_S
31769	keelekursustel	kursus	keele+kursus	11~09_S	PlAd	et	keelekursustel =kursus  (PlAd  >keele+kursus !11~09_S
31775	viiulit	viiuli	viiul	02_S	SgP	et	viiulit =viiuli  (SgP  >viiul !02_S
31776	saksofon	saksofon	saksofon	19_S	SgN	et	saksofon =saksofon  (SgN  >saksofon !19_S
31779	mängisime	mängi	mängima	28_V	IndIpfPl1	et	mängisime =mängi  (IndIpfPl1  >mängima !28_V
31786	segaduses	segaduse	segadus	11_S	SgIn	et	segaduses =segaduse  (SgIn  >segadus !11_S
31789	uudist	uudis	uudis	09_S	SgP	et	uudist =uudis  (SgP  >uudis !09_S
31791	lasnamäel	mäe	lasna+mägi	21_S	SgAd	et	lasnamäel =mäe  (SgAd  >lasna+mägi !21_S
31798	kiirustada	kiirusta	kiirustama	27_V	Inf	et	kiirustada =kiirusta  (Inf  >kiirustama !27_V
31807	heas	hea	hea	26_AS	SgIn	et	heas =hea  (SgIn  >hea !26_AS
31810	kehv	kehv	kehv	22_A	SgN	et	kehv =kehv  (SgN  >kehv !22_A
31811	kõndima	kõndi	kõndima	28_V	Sup	et	kõndima =kõndi  (Sup  >kõndima !28_V
31819	mugavaks	mugava	mugav	02_A	SgTr	et	mugavaks =mugava  (SgTr  >mugav !02_A
31821	trepikojas	koja	trepi+koda	18_S	SgIn	et	trepikojas =koja  (SgIn  >trepi+koda !18_S
31831	uksega	ukse	uks	14_S	SgKom	et	uksega =ukse  (SgKom  >uks !14_S
31832	esik	esik	esik	02_S	SgN	et	esik =esik  (SgN  >esik !02_S
31836	diivaniga	diivani	diivan	02_S	SgKom	et	diivaniga =diivani  (SgKom  >diivan !02_S
31840	liikuda	liiku	liikuma	28_V	Inf	et	liikuda =liiku  (Inf  >liikuma !28_V
31842	korteriga	korteri	korter	02_S	SgKom	et	korteriga =korteri  (SgKom  >korter !02_S
31859	sobib	sobi	sobima	27_V	IndPrSg3	et	sobib =sobi  (IndPrSg3  >sobima !27_V
31862	jalgsi	jalgsi	jalgsi	41_D	ID	et	jalgsi =jalgsi  (ID  >jalgsi !41_D
31867	elektripliit	pliit	elektri+pliit	22_S	SgN	et	elektripliit =pliit  (SgN  >elektri+pliit !22_S
31868	gaas	gaas	gaas	22_S	SgN	et	gaas =gaas  (SgN  >gaas !22_S
31754	toiduained	aine	toidu+aine	06_S	PlN	et	toiduained =aine  (PlN  >toidu+aine !06_S
31771	noodi	noodi	noot	22_S	SgG	et	noodi =noodi  (SgG  >noot !22_S
31774	algasin	alga	algama	29_V	IndIpfSg1	et	algasin =alga  (IndIpfSg1  >algama !29_V
31778	nukrat	nukra	nukker	02_A	SgP	et	nukrat =nukra  (SgP  >nukker !02_A
31782	jätkuda	jätku	jätkuma	27_V	Inf	et	jätkuda =jätku  (Inf  >jätkuma !27_V
31787	varastada	varasta	varastama	27_V	Inf	et	varastada =varasta  (Inf  >varastama !27_V
31795	augustis	augusti	august	02_S	SgIn	et	augustis =augusti  (SgIn  >august !02_S
31796	vormistasin	vormista	vormistama	27_V	IndIpfSg1	et	vormistasin =vormista  (IndIpfSg1  >vormistama !27_V
31802	lepingu	lepingu	leping	02_S	SgG	et	lepingu =lepingu  (SgG  >leping !02_S
31805	kurk	kurk	kurk	22_S	SgN	et	kurk =kurk  (SgN  >kurk !22_S
31812	hoolitsetakse	hoolitse	hoolitsema	27_V	IndPrIps	et	hoolitsetakse =hoolitse  (IndPrIps  >hoolitsema !27_V
31816	minutiga	minuti	minut	02_S	SgKom	et	minutiga =minuti  (SgKom  >minut !02_S
31837	rõdule	rõdu	rõdu	17_S	SgAll	et	rõdule =rõdu  (SgAll  >rõdu !17_S
31854	külmeks	külme	külm	22_AS	PlTr	et	külmeks =külme  (PlTr  >külm !22_AS
31861	mustamäes	mäe	musta+mägi	21_S	SgIn	et	mustamäes =mäe  (SgIn  >musta+mägi !21_S
31878	agressiivne	agressiivne	agressiivne	02_A	SgN	et	agressiivne =agressiivne  (SgN  >agressiivne !02_A
31881	mõistan	mõista	mõistma	34_V	IndPrSg1	et	mõistan =mõista  (IndPrSg1  >mõistma !34_V
31891	arvutifirmas	firma	arvuti+firma	16_S	SgIn	et	arvutifirmas =firma  (SgIn  >arvuti+firma !16_S
31893	osavõttega	võtte	osa+võte	06_S	SgKom	et	osavõttega =võtte  (SgKom  >osa+võte !06_S
31895	ettevalmiskursustele	kursus	ette+valmis+kursus	11~09_S	PlAll	et	ettevalmiskursustele =kursus  (PlAll  >ette+valmis+kursus !11~09_S
31897	saavutas	saavuta	saavutama	27_V	IndIpfSg3	et	saavutas =saavuta  (IndIpfSg3  >saavutama !27_V
31906	rajoonisse	rajooni	rajoon	22_S	SgIll	et	rajoonisse =rajooni  (SgIll  >rajoon !22_S
31909	jalaluumurd	murd	jala+luu+murd	22_S	SgN	et	jalaluumurd =murd  (SgN  >jala+luu+murd !22_S
31910	murdsin	murd	murdma	34_V	IndIpfSg1	et	murdsin =murd  (IndIpfSg1  >murdma !34_V
31912	pidasin	pida	pidama	28_V	IndIpfSg1	et	pidasin =pida  (IndIpfSg1  >pidama !28_V
31915	iseseisvat	seisva	ise+seisev	02_A	SgP	et	iseseisvat =seisva  (SgP  >ise+seisev !02_A
31930	kahtlesin	kahtle	kahtlema	30_V	IndIpfSg1	et	kahtlesin =kahtle  (IndIpfSg1  >kahtlema !30_V
31932	usaldada	usalda	usaldama	27_V	Inf	et	usaldada =usalda  (Inf  >usaldama !27_V
31933	võiksin	või	võima	37_V	KndPrSg1	et	võiksin =või  (KndPrSg1  >võima !37_V
31936	tuttavaid	tuttava	tuttav	02_AS	PlP	et	tuttavaid =tuttava  (PlP  >tuttav !02_AS
31937	meelesse	meele	meel	13_S	SgIll	et	meelesse =meele  (SgIll  >meel !13_S
31962	lapsena	lapse	laps	14_S	SgEs	et	lapsena =lapse  (SgEs  >laps !14_S
31976	naabrite	naabri	naaber	02_S	PlG	et	naabrite =naabri  (PlG  >naaber !02_S
31977	koletis	koletis	koletis	11_S	SgN	et	koletis =koletis  (SgN  >koletis !11_S
31993	sarvega	sarve	sarv	22_S	SgKom	et	sarvega =sarve  (SgKom  >sarv !22_S
31999	melodramaatilise	dramaatilise	melo+dramaatiline	12_A	SgG	et	melodramaatilise =dramaatilise  (SgG  >melo+dramaatiline !12_A
32005	pisiasjade	asja	pisi+asi	24_S	PlG	et	pisiasjade =asja  (PlG  >pisi+asi !24_S
32006	norida	nori	norima	27_V	Inf	et	norida =nori  (Inf  >norima !27_V
32007	ekraanile	ekraani	ekraan	22_S	SgAll	et	ekraanile =ekraani  (SgAll  >ekraan !22_S
32024	dialooge	dialooge	dialoog	22_S	PlP	et	dialooge =dialooge  (PlP  >dialoog !22_S
32026	küsitite	tite	küsi+titt	22_S	SgG	et	küsitite =tite  (SgG  >küsi+titt !22_S
32027	õigekirjutust	kirjutus	õige+kirjutus	11_S	SgP	et	õigekirjutust =kirjutus  (SgP  >õige+kirjutus !11_S
32034	lemmikfilm	film	lemmik+film	22_S	SgN	et	lemmikfilm =film  (SgN  >lemmik+film !22_S
32036	kadettide	kadetti	kadett	22_S	PlG	et	kadettide =kadetti  (PlG  >kadett !22_S
32037	sõnaühend	ühend	sõna+ühend	02_S	SgN	et	sõnaühend =ühend  (SgN  >sõna+ühend !02_S
32038	söör	söör	söör	22_S	SgN	et	söör =söör  (SgN  >söör !22_S
32039	eestikeelsed	keelse	eesti+keelne	02_A	PlN	et	eestikeelsed =keelse  (PlN  >eesti+keelne !02_A
32045	porgandit	porgandi	porgand	02_S	SgP	et	porgandit =porgandi  (SgP  >porgand !02_S
32046	hiirte	hiir	hiir	13_S	PlG	et	hiirte =hiir  (PlG  >hiir !13_S
32048	aimasin	aima	aimama	29_V	IndIpfSg1	et	aimasin =aima  (IndIpfSg1  >aimama !29_V
32059	haukuma	hauku	haukuma	28_V	Sup	et	haukuma =hauku  (Sup  >haukuma !28_V
32060	siilid	siili	siil	22_S	PlN	et	siilid =siili  (PlN  >siil !22_S
32070	seinadega	seina	sein	22_S	PlKom	et	seinadega =seina  (PlKom  >sein !22_S
32077	reegel	reegel	reegel	02_S	SgN	et	reegel =reegel  (SgN  >reegel !02_S
32078	seitsmeni	seitsme	seitse	05_N	SgTer	et	seitsmeni =seitsme  (SgTer  >seitse !05_N
31764	moment	moment	moment	22_S	SgN	et	moment =moment  (SgN  >moment !22_S
31766	instituudi	instituudi	instituut	22_S	SgG	et	instituudi =instituudi  (SgG  >instituut !22_S
31767	tutvustasin	tutvusta	tutvustama	27_V	IndIpfSg1	et	tutvustasin =tutvusta  (IndIpfSg1  >tutvustama !27_V
31770	välismaalis	maali	välis+maal	22_S	SgIn	et	välismaalis =maali  (SgIn  >välis+maal !22_S
31773	instrument	instrument	instrument	22_S	SgN	et	instrument =instrument  (SgN  >instrument !22_S
31780	orkestriga	orkestri	orkester	02_S	SgKom	et	orkestriga =orkestri  (SgKom  >orkester !02_S
31781	avakontserdil	kontserdi	ava+kontsert	22_S	SgAd	et	avakontserdil =kontserdi  (SgAd  >ava+kontsert !22_S
31785	sündmuseid	sündmuse	sündmus	09_S	PlP	et	sündmuseid =sündmuse  (PlP  >sündmus !09_S
31794	kolmekesi	kolmekesi	kolmekesi	41_D	ID	et	kolmekesi =kolmekesi  (ID  >kolmekesi !41_D
31801	firmaga	firma	firma	16_S	SgKom	et	firmaga =firma  (SgKom  >firma !16_S
31806	ravimeid	ravime	ravim	02_S	PlP	et	ravimeid =ravime  (PlP  >ravim !02_S
31808	kauplusi	kauplusi	kauplus	11_S	PlP	et	kauplusi =kauplusi  (PlP  >kauplus !11_S
31830	pöördes	pöörde	pööre	06_S	SgIn	et	pöördes =pöörde  (SgIn  >pööre !06_S
31834	ebamugav	mugav	eba+mugav	02_A	SgN	et	ebamugav =mugav  (SgN  >eba+mugav !02_A
31841	koeraga	koera	koer	23?22_SA	SgKom	et	koeraga =koera  (SgKom  >koer !23?22_SA
31848	ümbrusele	ümbruse	ümbrus	11~09_S	SgAll	et	ümbrusele =ümbruse  (SgAll  >ümbrus !11~09_S
31849	paigad	paiga	paik	22_S	PlN	et	paigad =paiga  (PlN  >paik !22_S
31850	korteriperenaine	naine	korteri+pere+naine	12_S	SgN	et	korteriperenaine =naine  (SgN  >korteri+pere+naine !12_S
31851	kehvas	kehva	kehv	22_A	SgIn	et	kehvas =kehva  (SgIn  >kehv !22_A
31852	seisukorras	korra	seisu+kord	22_S	SgIn	et	seisukorras =korra  (SgIn  >seisu+kord !22_S
31864	raudtaraga	tara	raud+tara	17_S	SgKom	et	raudtaraga =tara  (SgKom  >raud+tara !17_S
31866	arvatest	ate	arv+att	22_S	PlEl	et	arvatest =ate  (PlEl  >arv+att !22_S
31874	seinas	seina	sein	23?22_S	SgIn	et	seinas =seina  (SgIn  >sein !23?22_S
31875	posterid	eri	post+eri	17_S	PlN	et	posterid =eri  (PlN  >post+eri !17_S
31886	sõbrustama	sõbrusta	sõbrustama	27_V	Sup	et	sõbrustama =sõbrusta  (Sup  >sõbrustama !27_V
31898	kätt	kä	käsi	15_S	SgP	et	kätt =kä  (SgP  >käsi !15_S
31900	eksamitele	eksami	eksam	02_S	PlAll	et	eksamitele =eksami  (PlAll  >eksam !02_S
31901	kaduge	kadu	kaduma	28_V	ImpPrPl2	et	kaduge =kadu  (ImpPrPl2  >kaduma !28_V
31902	eksamite	eksami	eksam	02_S	PlG	et	eksamite =eksami  (PlG  >eksam !02_S
31908	igatsesin	igatse	igatsema	27_V	IndIpfSg1	et	igatsesin =igatse  (IndIpfSg1  >igatsema !27_V
31911	sõbrannaga	sõbranna	sõbranna	16_S	SgKom	et	sõbrannaga =sõbranna  (SgKom  >sõbranna !16_S
31918	läänemere	mere	lääne+meri	20_S	SgG	et	läänemere =mere  (SgG  >lääne+meri !20_S
31920	ajakirjandust	kirjandus	aja+kirjandus	11_S	SgP	et	ajakirjandust =kirjandus  (SgP  >aja+kirjandus !11_S
31924	kehtib	kehti	kehtima	27_V	IndPrSg3	et	kehtib =kehti  (IndPrSg3  >kehtima !27_V
31927	vihkasin	vihka	vihkama	29_V	IndIpfSg1	et	vihkasin =vihka  (IndIpfSg1  >vihkama !29_V
31939	tudengina	tudengi	tudeng	02_S	SgEs	et	tudengina =tudengi  (SgEs  >tudeng !02_S
31946	informatsioone	informatsioone	informatsioon	22_S	PlP	et	informatsioone =informatsioone  (PlP  >informatsioon !22_S
31948	rasketes	raske	raske	01_A	PlIn	et	rasketes =raske  (PlIn  >raske !01_A
31952	nõusid	nõu	nõu	26_S	PlP	et	nõusid =nõu  (PlP  >nõu !26_S
31964	karbis	karbi	karp	22_S	SgIn	et	karbis =karbi  (SgIn  >karp !22_S
31965	igapäev	päev	iga+päev	22_S	SgN	et	igapäev =päev  (SgN  >iga+päev !22_S
31972	tuttavat	tuttava	tuttav	02_AS	SgP	et	tuttavat =tuttava  (SgP  >tuttav !02_AS
31979	küünistab	küünista	küünistama	27_V	IndPrSg3	et	küünistab =küünista  (IndPrSg3  >küünistama !27_V
31983	jälitasin	jälita	jälitama	27_V	IndIpfSg1	et	jälitasin =jälita  (IndIpfSg1  >jälitama !27_V
31986	keskaegses	aegse	kesk+aegne	02_A	SgIn	et	keskaegses =aegse  (SgIn  >kesk+aegne !02_A
31989	eramajad	maja	era+maja	17_S	PlN	et	eramajad =maja  (PlN  >era+maja !17_S
31992	jätkas	jätka	jätkama	29_V	IndIpfSg3	et	jätkas =jätka  (IndIpfSg3  >jätkama !29_V
31996	koostan	koosta	koostama	27_V	IndPrSg1	et	koostan =koosta  (IndPrSg1  >koostama !27_V
32011	märkasin	märka	märkama	29_V	IndIpfSg1	et	märkasin =märka  (IndIpfSg1  >märkama !29_V
32012	praktilised	praktilise	praktiline	12_A	PlN	et	praktilised =praktilise  (PlN  >praktiline !12_A
32022	tõlkis	tõlki	tõlkima	28_V	IndIpfSg3	et	tõlkis =tõlki  (IndIpfSg3  >tõlkima !28_V
32042	närilisi	närilisi	näriline	12_S	PlP	et	närilisi =närilisi  (PlP  >näriline !12_S
32050	ninna	ninna	nina	17_S	SgAdt	et	ninna =ninna  (SgAdt  >nina !17_S
32057	kartis	kart	kartma	34_V	IndIpfSg3	et	kartis =kart  (IndIpfSg3  >kartma !34_V
31825	esikus	esiku	esik	02_S	SgIn	et	esikus =esiku  (SgIn  >esik !02_S
31827	seinakapiga	kapi	seina+kapp	22_S	SgKom	et	seinakapiga =kapi  (SgKom  >seina+kapp !22_S
31828	peegliga	peegli	peegel	02_S	SgKom	et	peegliga =peegli  (SgKom  >peegel !02_S
31838	vaip	vaip	vaip	22_S	SgN	et	vaip =vaip  (SgN  >vaip !22_S
31839	koerale	koera	koer	23?22_SA	SgAll	et	koerale =koera  (SgAll  >koer !23?22_SA
31843	kolisin	koli	kolima	27_V	IndIpfSg1	et	kolisin =koli  (IndIpfSg1  >kolima !27_V
31844	ühiselamuses	elamuse	ühis+elamus	11_S	SgIn	et	ühiselamuses =elamuse  (SgIn  >ühis+elamus !11_S
31845	valikut	valiku	valik	02_S	SgP	et	valikut =valiku  (SgP  >valik !02_S
31847	adapteerida	adapteeri	adapteerima	28_V	Inf	et	adapteerida =adapteeri  (Inf  >adapteerima !28_V
31860	küljed	külje	külg	22_S	PlN	et	küljed =külje  (PlN  >külg !22_S
31865	gaasipliit	pliit	gaasi+pliit	22_S	SgN	et	gaasipliit =pliit  (SgN  >gaasi+pliit !22_S
31871	uude	uu	uus	14_A	SgAdt	et	uude =uu  (SgAdt  >uus !14_A
31872	kolime	koli	kolima	27_V	IndPrPl1	et	kolime =koli  (IndPrPl1  >kolima !27_V
31879	põnevat	põneva	põnev	02_A	SgP	et	põnevat =põneva  (SgP  >põnev !02_A
31885	vaenlased	vaenlase	vaenlane	12?10_S	PlN	et	vaenlased =vaenlase  (PlN  >vaenlane !12?10_S
31892	tõnismäe	mäe	tõnis+mägi	21_S	SgG	et	tõnismäe =mäe  (SgG  >tõnis+mägi !21_S
31894	kunstnikuks	kunstniku	kunstnik	25_S	SgTr	et	kunstnikuks =kunstniku  (SgTr  >kunstnik !25_S
31903	südamega	südame	süda	04_S	SgKom	et	südamega =südame  (SgKom  >süda !04_S
31904	lapsepõlv	põlv	lapse+põlv	22_S	SgN	et	lapsepõlv =põlv  (SgN  >lapse+põlv !22_S
31905	hinded	hinde	hinne	06_S	PlN	et	hinded =hinde  (PlN  >hinne !06_S
31916	augusti	augusti	august	02_S	SgG	et	augusti =augusti  (SgG  >august !02_S
31917	iseseisvas	seisva	ise+seisev	02_A	SgIn	et	iseseisvas =seisva  (SgIn  >ise+seisev !02_A
31922	negatiivsest	negatiivse	negatiivne	02_A	SgEl	et	negatiivsest =negatiivse  (SgEl  >negatiivne !02_A
31925	normaalsed	normaalse	normaalne	02_A	PlN	et	normaalsed =normaalse  (PlN  >normaalne !02_A
31931	saavutasin	saavuta	saavutama	27_V	IndIpfSg1	et	saavutasin =saavuta  (IndIpfSg1  >saavutama !27_V
31940	huvidega	huvi	huvi	17_S	PlKom	et	huvidega =huvi  (PlKom  >huvi !17_S
31941	teistsugused	suguse	teist+sugune	10_P	PlN	et	teistsugused =suguse  (PlN  >teist+sugune !10_P
31949	tuiksoonel	soone	tuik+soon	13_S	SgAd	et	tuiksoonel =soone  (SgAd  >tuik+soon !13_S
31957	arvama	arva	arvama	29_V	Sup	et	arvama =arva  (Sup  >arvama !29_V
31960	keemiaga	keemia	keemia	01_S	SgKom	et	keemiaga =keemia  (SgKom  >keemia !01_S
31966	lendas	lenda	lendama	29_V	IndIpfSg3	et	lendas =lenda  (IndIpfSg3  >lendama !29_V
31970	võtmed	võtme	võti	05_S	PlN	et	võtmed =võtme  (PlN  >võti !05_S
31998	töösse	töö	töö	26_S	SgIll	et	töösse =töö  (SgIll  >töö !26_S
32000	vaprad	vapra	vapper	02_A	PlN	et	vaprad =vapra  (PlN  >vapper !02_A
32001	dramaatilise	dramaatilise	dramaatiline	12_A	SgG	et	dramaatilise =dramaatilise  (SgG  >dramaatiline !12_A
32002	kutsuge	kutsu	kutsuma	28_V	ImpPrPl2	et	kutsuge =kutsu  (ImpPrPl2  >kutsuma !28_V
32004	mõnede	mõne	mõni	20_P	PlG	et	mõnede =mõne  (PlG  >mõni !20_P
32014	heledal	heleda	hele	02_A	SgAd	et	heledal =heleda  (SgAd  >hele !02_A
32016	tegelase	tegelase	tegelane	12_S	SgG	et	tegelase =tegelase  (SgG  >tegelane !12_S
32017	ebaselgeks	selge	eba+selge	01_A	SgTr	et	ebaselgeks =selge  (SgTr  >eba+selge !01_A
32021	ebakorrektne	korrektne	eba+korrektne	02_A	SgN	et	ebakorrektne =korrektne  (SgN  >eba+korrektne !02_A
32030	tõlkida	tõlki	tõlkima	28_V	Inf	et	tõlkida =tõlki  (Inf  >tõlkima !28_V
32041	tukastama	tukasta	tukastama	27_V	Sup	et	tukastama =tukasta  (Sup  >tukastama !27_V
32053	jahivad	jahi	jahtima	28_V	IndPrPl3	et	jahivad =jahi  (IndPrPl3  >jahtima !28_V
32065	kuulas	kuula	kuulama	29_V	IndIpfSg3	et	kuulas =kuula  (IndIpfSg3  >kuulama !29_V
32068	vannitoas	toa	vanni+tuba	18_S	SgIn	et	vannitoas =toa  (SgIn  >vanni+tuba !18_S
32079	iseloomad	looma	ise+loom	22_S	PlN	et	iseloomad =looma  (PlN  >ise+loom !22_S
32080	sõbralikule	sõbraliku	sõbralik	25_A	SgAll	et	sõbralikule =sõbraliku  (SgAll  >sõbralik !25_A
32088	mõlemat	mõlema	mõlema	02_P	SgP	et	mõlemat =mõlema  (SgP  >mõlema !02_P
32090	viimaseid	viimase	viimane	10_A	PlP	et	viimaseid =viimase  (PlP  >viimane !10_A
32093	kirjanikule	kirjaniku	kirjanik	25_S	SgAll	et	kirjanikule =kirjaniku  (SgAll  >kirjanik !25_S
32103	täpsed	täpse	täpne	02_A	PlN	et	täpsed =täpse  (PlN  >täpne !02_A
32107	lõplik	lõplik	lõplik	25_A	SgN	et	lõplik =lõplik  (SgN  >lõplik !25_A
32110	valikus	valiku	valik	02_S	SgIn	et	valikus =valiku  (SgIn  >valik !02_S
32112	sattun	sattu	sattuma	27_V	IndPrSg1	et	sattun =sattu  (IndPrSg1  >sattuma !27_V
32124	teatada	teata	teatama	27_V	Inf	et	teatada =teata  (Inf  >teatama !27_V
31833	köögi	köögi	köök	22_S	SgG	et	köögi =köögi  (SgG  >köök !22_S
31835	tüüpiline	tüüpiline	tüüpiline	12_A	SgN	et	tüüpiline =tüüpiline  (SgN  >tüüpiline !12_A
31846	üürime	üüri	üürima	28_V	IndPrPl1	et	üürime =üüri  (IndPrPl1  >üürima !28_V
31853	ahjuküte	küte	ahju+küte	06_S	SgN	et	ahjuküte =küte  (SgN  >ahju+küte !06_S
31855	põrand	põrand	põrand	02_S	SgN	et	põrand =põrand  (SgN  >põrand !02_S
31856	liiklus	liiklus	liiklus	11~09_S	SgN	et	liiklus =liiklus  (SgN  >liiklus !11~09_S
31857	lärm	lärm	lärm	22_S	SgN	et	lärm =lärm  (SgN  >lärm !22_S
31858	kõvasti	kõvasti	kõvasti	41_D	ID	et	kõvasti =kõvasti  (ID  >kõvasti !41_D
31863	prügikastid	kasti	prügi+kast	22_S	PlN	et	prügikastid =kasti  (PlN  >prügi+kast !22_S
31873	petma	pet	petma	35_V	Sup	et	petma =pet  (Sup  >petma !35_V
31882	hoolitsen	hoolitse	hoolitsema	27_V	IndPrSg1	et	hoolitsen =hoolitse  (IndPrSg1  >hoolitsema !27_V
31883	suhtun	suhtu	suhtuma	27_V	IndPrSg1	et	suhtun =suhtu  (IndPrSg1  >suhtuma !27_V
31887	õega	õe	õde	18_S	SgKom	et	õega =õe  (SgKom  >õde !18_S
31896	akadeemias	akadeemia	akadeemia	01_S	SgIn	et	akadeemias =akadeemia  (SgIn  >akadeemia !01_S
31899	häbiks	häbi	häbi	17_S	SgTr	et	häbiks =häbi  (SgTr  >häbi !17_S
31907	vahetama	vaheta	vahetama	27_V	Sup	et	vahetama =vaheta  (Sup  >vahetama !27_V
31914	ujuma	uju	ujuma	27_V	Sup	et	ujuma =uju  (Sup  >ujuma !27_V
31919	diplomiga	diplomi	diplom	02_S	SgKom	et	diplomiga =diplomi  (SgKom  >diplom !02_S
31921	igati	igati	igati	41_D	ID	et	igati =igati  (ID  >igati !41_D
31923	usaldaksin	usalda	usaldama	27_V	KndPrSg1	et	usaldaksin =usalda  (KndPrSg1  >usaldama !27_V
31928	palliga	palli	pall	22_S	SgKom	et	palliga =palli  (SgKom  >pall !22_S
31929	poolaastal	aasta	pool+aasta	01_S	SgAd	et	poolaastal =aasta  (SgAd  >pool+aasta !01_S
31934	väheneda	vähene	vähenema	27_V	Inf	et	väheneda =vähene  (Inf  >vähenema !27_V
31938	rõõmsaid	rõõmsa	rõõmus	02_A	PlP	et	rõõmsaid =rõõmsa  (PlP  >rõõmus !02_A
31942	ülikooliaastad	aasta	üli+kooli+aasta	01_S	PlN	et	ülikooliaastad =aasta  (PlN  >üli+kooli+aasta !01_S
31950	laiendada	laienda	laiendama	27_V	Inf	et	laiendada =laienda  (Inf  >laiendama !27_V
31963	rumal	rumal	rumal	02_A	SgN	et	rumal =rumal  (SgN  >rumal !02_A
31968	karjuma	karju	karjuma	28_V	Sup	et	karjuma =karju  (Sup  >karjuma !28_V
31969	sõbral	sõbra	sõber	24_S	SgAd	et	sõbral =sõbra  (SgAd  >sõber !24_S
31971	jalutades	jaluta	jalutama	27_V	Ger	et	jalutades =jaluta  (Ger  >jalutama !27_V
31975	sõbraks	sõbra	sõber	24_S	SgTr	et	sõbraks =sõbra  (SgTr  >sõber !24_S
31982	lasin	las	laskma	34_V	IndIpfSg1	et	lasin =las  (IndIpfSg1  >laskma !34_V
31984	õuel	õue	õu	22_S	SgAd	et	õuel =õue  (SgAd  >õu !22_S
31985	astusime	astu	astuma	28_V	IndIpfPl1	et	astusime =astu  (IndIpfPl1  >astuma !28_V
31987	ümbruses	ümbruse	ümbrus	11~09_S	SgIn	et	ümbruses =ümbruse  (SgIn  >ümbrus !11~09_S
31990	emakits	kits	ema+kits	22_S	SgN	et	emakits =kits  (SgN  >ema+kits !22_S
31997	analüüsin	analüüsi	analüüsima	28_V	IndPrSg1	et	analüüsin =analüüsi  (IndPrSg1  >analüüsima !28_V
32003	komöödiat	komöödia	komöödia	01_S	SgP	et	komöödiat =komöödia  (SgP  >komöödia !01_S
32008	ekraanilt	ekraani	ekraan	22_S	SgAbl	et	ekraanilt =ekraani  (SgAbl  >ekraan !22_S
32009	ebatäpne	täpne	eba+täpne	02_A	SgN	et	ebatäpne =täpne  (SgN  >eba+täpne !02_A
32010	pisiasjad	asja	pisi+asi	24_S	PlN	et	pisiasjad =asja  (PlN  >pisi+asi !24_S
32013	eelmises	eelmise	eelmine	12?10_A	SgIn	et	eelmises =eelmise  (SgIn  >eelmine !12?10_A
32015	taustal	tausta	taust	22_S	SgAd	et	taustal =tausta  (SgAd  >taust !22_S
32018	endamisi	endamisi	endamisi	41_D	ID	et	endamisi =endamisi  (ID  >endamisi !41_D
32023	pisiasju	asju	pisi+asi	24_S	PlP	et	pisiasju =asju  (PlP  >pisi+asi !24_S
32028	tõlget	tõlge	tõlge	06_S	SgP	et	tõlget =tõlge  (SgP  >tõlge !06_S
32031	film	film	film	22_S	SgN	et	film =film  (SgN  >film !22_S
32033	korrektne	korrektne	korrektne	02_A	SgN	et	korrektne =korrektne  (SgN  >korrektne !02_A
32040	kipub	kipu	kippuma	28_V	IndPrSg3	et	kipub =kipu  (IndPrSg3  >kippuma !28_V
32043	tõusin	tõus	tõusma	32_V	IndIpfSg1	et	tõusin =tõus  (IndIpfSg1  >tõusma !32_V
32044	sibulat	sibula	sibul	02_S	SgP	et	sibulat =sibula  (SgP  >sibul !02_S
32047	rea	rea	rida	18_S	SgG	et	rea =rea  (SgG  >rida !18_S
32054	juhtumeid	juhtume	juhtum	02_S	PlP	et	juhtumeid =juhtume  (PlP  >juhtum !02_S
32055	jahib	jahi	jahtima	28_V	IndPrSg3	et	jahib =jahi  (IndPrSg3  >jahtima !28_V
32058	limukaid	limuka	limukas	02_S	PlP	et	limukaid =limuka  (PlP  >limukas !02_S
32062	vihastas	vihasta	vihastama	27_V	IndIpfSg3	et	vihastas =vihasta  (IndIpfSg3  >vihastama !27_V
31869	vot	vot	vot	41_D	ID	et	vot =vot  (ID  >vot !41_D
31870	proovige	proovi	proovima	28_V	ImpPrPl2	et	proovige =proovi  (ImpPrPl2  >proovima !28_V
31876	rand	rand	rand	22_S	SgN	et	rand =rand  (SgN  >rand !22_S
31877	eluperiood	periood	elu+periood	22_S	SgN	et	eluperiood =periood  (SgN  >elu+periood !22_S
31880	pisarad	pisara	pisar	02_S	PlN	et	pisarad =pisara  (PlN  >pisar !02_S
31884	sõbrannat	sõbranna	sõbranna	16_S	SgP	et	sõbrannat =sõbranna  (SgP  >sõbranna !16_S
31888	mõistame	mõista	mõistma	34_V	IndPrPl1	et	mõistame =mõista  (IndPrPl1  >mõistma !34_V
31889	tallinnase	ase	tallinn+ase	04_S	SgN	et	tallinnase =ase  (SgN  >tallinn+ase !04_S
31890	ühesõnaga	ühesõnaga	ühe+sõnaga	41_D	ID	et	ühesõnaga =ühesõnaga  (ID  >ühe+sõnaga !41_D
31913	magasime	maga	magama	27_V	IndIpfPl1	et	magasime =maga  (IndIpfPl1  >magama !27_V
31926	kujutada	kujuta	kujutama	27_V	Inf	et	kujutada =kujuta  (Inf  >kujutama !27_V
31935	maksan	maksa	maksma	32_V	IndPrSg1	et	maksan =maksa  (IndPrSg1  >maksma !32_V
31943	jõuad	jõua	jõudma	34_V	IndPrSg2	et	jõuad =jõua  (IndPrSg2  >jõudma !34_V
31944	algan	alga	algama	29_V	IndPrSg1	et	algan =alga  (IndPrSg1  >algama !29_V
31945	dotsent	dotsent	dotsent	22_S	SgN	et	dotsent =dotsent  (SgN  >dotsent !22_S
31947	heatahtlikuks	tahtliku	hea+tahtlik	25_A	SgTr	et	heatahtlikuks =tahtliku  (SgTr  >hea+tahtlik !25_A
31951	maailmavaadet	vaade	maa+ilma+vaade	06_S	SgP	et	maailmavaadet =vaade  (SgP  >maa+ilma+vaade !06_S
31953	tüdrukuna	tüdruku	tüdruk	02_S	SgEs	et	tüdrukuna =tüdruku  (SgEs  >tüdruk !02_S
31954	kõrghariduseta	hariduse	kõrg+haridus	11_S	SgAb	et	kõrghariduseta =hariduse  (SgAb  >kõrg+haridus !11_S
31955	telliskivilt	kivi	tellis+kivi	17_S	SgAbl	et	telliskivilt =kivi  (SgAbl  >tellis+kivi !17_S
31956	kaldun	kaldu	kalduma	27_V	IndPrSg1	et	kaldun =kaldu  (IndPrSg1  >kalduma !27_V
31958	lapsedega	ede	laps+ede	16_S	SgKom	et	lapsedega =ede  (SgKom  >laps+ede !16_S
31959	valdkonnadest	konna	vald+konn	22_S	PlEl	et	valdkonnadest =konna  (PlEl  >vald+konn !22_S
31961	humanitaarsed	humanitaarse	humanitaarne	02_A	PlN	et	humanitaarsed =humanitaarse  (PlN  >humanitaarne !02_A
31967	rõdul	rõdu	rõdu	17_S	SgAd	et	rõdul =rõdu  (SgAd  >rõdu !17_S
31973	kingisid	kingi	king	22_S	PlP	et	kingisid =kingi  (PlP  >king !22_S
31974	nimetasin	nimeta	nimetama	27_V	IndIpfSg1	et	nimetasin =nimeta  (IndIpfSg1  >nimetama !27_V
31978	tapas	tapa	tapp	22_S	SgIn	et	tapas =tapa  (SgIn  >tapp !22_S
31980	varblane	varblane	varblane	12?10_S	SgN	et	varblane =varblane  (SgN  >varblane !12?10_S
31981	segas	sega	segama	27_V	IndIpfSg3	et	segas =sega  (IndIpfSg3  >segama !27_V
31988	seisisid	seisi	seis	22_S	PlP	et	seisisid =seisi  (PlP  >seis !22_S
31991	kitsapoeg	poeg	kitsa+poeg	22_S	SgN	et	kitsapoeg =poeg  (SgN  >kitsa+poeg !22_S
31994	karistas	karista	karistama	27_V	IndIpfSg3	et	karistas =karista  (IndIpfSg3  >karistama !27_V
31995	telekanalite	kanali	tele+kanal	02_S	PlG	et	telekanalite =kanali  (PlG  >tele+kanal !02_S
32019	kursiiviga	kursiivi	kursiiv	22_S	SgKom	et	kursiiviga =kursiivi  (SgKom  >kursiiv !22_S
32020	seejuures	seejuures	see+juures	41_D	ID	et	seejuures =seejuures  (ID  >see+juures !41_D
32025	hirmsat	hirmsa	hirmus	02_A	SgP	et	hirmsat =hirmsa  (SgP  >hirmus !02_A
32029	järelikult	järelikult	järelikult	41_D	ID	et	järelikult =järelikult  (ID  >järelikult !41_D
32032	perefilm	film	pere+film	22_S	SgN	et	perefilm =film  (SgN  >pere+film !22_S
32035	sõnadeta	sõna	sõna	17_S	PlAb	et	sõnadeta =sõna  (PlAb  >sõna !17_S
32049	kangekaelne	kaelne	kange+kaelne	02_A	SgN	et	kangekaelne =kaelne  (SgN  >kange+kaelne !02_A
32051	hiired	hiire	hiir	13_S	PlN	et	hiired =hiire  (PlN  >hiir !13_S
32052	minult	minu	mina	00_P	SgAbl	et	minult =minu  (SgAbl  >mina !00_P
32056	sülekoer	koer	süle+koer	23?22_SA	SgN	et	sülekoer =koer  (SgN  >süle+koer !23?22_SA
32066	elaksin	ela	elama	27_V	KndPrSg1	et	elaksin =ela  (KndPrSg1  >elama !27_V
32072	kommunaalmakseid	makse	kommunaal+makse	06_S	PlP	et	kommunaalmakseid =makse  (PlP  >kommunaal+makse !06_S
32074	na	na	na	41_D	ID	et	na =na  (ID  >na !41_D
32076	närveerib	närveeri	närveerima	28_V	IndPrSg3	et	närveerib =närveeri  (IndPrSg3  >närveerima !28_V
32081	konfliktid	konflikti	konflikt	22_S	PlN	et	konfliktid =konflikti  (PlN  >konflikt !22_S
32086	asjas	asja	asi	24_S	SgIn	et	asjas =asja  (SgIn  >asi !24_S
32089	paberile	paberi	paber	02_S	SgAll	et	paberile =paberi  (SgAll  >paber !02_S
32100	eneseväljendamise	väljendamise	enese+väljendamine	12_S	SgG	et	eneseväljendamise =väljendamise  (SgG  >enese+väljendamine !12_S
32104	tõenähtav	nähtav	tõe+nähtav	02_A	SgN	et	tõenähtav =nähtav  (SgN  >tõe+nähtav !02_A
32122	ajakirjaniku	kirjaniku	aja+kirjanik	25_S	SgG	et	ajakirjaniku =kirjaniku  (SgG  >aja+kirjanik !25_S
32131	vahendada	vahenda	vahendama	27_V	Inf	et	vahendada =vahenda  (Inf  >vahendama !27_V
32061	juua	juu	jooma	38_V	Inf	et	juua =juu  (Inf  >jooma !38_V
32063	peresõpradel	sõpra	pere+sõber	24_S	PlAd	et	peresõpradel =sõpra  (PlAd  >pere+sõber !24_S
32064	nokaga	noka	nokk	22_S	SgKom	et	nokaga =noka  (SgKom  >nokk !22_S
32069	mugavasti	mugavasti	mugavasti	41_D	ID	et	mugavasti =mugavasti  (ID  >mugavasti !41_D
32071	üür	üür	üür	22_S	SgN	et	üür =üür  (SgN  >üür !22_S
32083	lamp	lamp	lamp	22_SA	SgN	et	lamp =lamp  (SgN  >lamp !22_SA
32099	iseloom	loom	ise+loom	22_S	SgN	et	iseloom =loom  (SgN  >ise+loom !22_S
32109	tõestan	tõesta	tõestama	27_V	IndPrSg1	et	tõestan =tõesta  (IndPrSg1  >tõestama !27_V
32111	vahet	vahe	vahe	16_S	SgP	et	vahet =vahe  (SgP  >vahe !16_S
32113	ajakirjas	kirja	aja+kiri	24_S	SgIn	et	ajakirjas =kirja  (SgIn  >aja+kiri !24_S
32114	raadios	raadio	raadio	01_S	SgIn	et	raadios =raadio  (SgIn  >raadio !01_S
32117	kättedega	ede	kätt+ede	16_S	SgKom	et	kättedega =ede  (SgKom  >kätt+ede !16_S
32121	valisingi	vali	valima	27_V	IndIpfSg1^	et	valisingi =vali  (IndIpfSg1^  >valima !27_V
32135	artikliga	artikli	artikkel	02_S	SgKom	et	artikliga =artikli  (SgKom  >artikkel !02_S
32140	atavad	ata	atma	35_V	IndPrPl3	et	atavad =ata  (IndPrPl3  >atma !35_V
32146	banaalsed	banaalse	banaalne	02_A	PlN	et	banaalsed =banaalse  (PlN  >banaalne !02_A
32150	eluvaade	vaade	elu+vaade	06_S	SgN	et	eluvaade =vaade  (SgN  >elu+vaade !06_S
32155	astudes	astu	astuma	28_V	Ger	et	astudes =astu  (Ger  >astuma !28_V
32157	tegemas	tege	tegema	28_V	SupIn	et	tegemas =tege  (SupIn  >tegema !28_V
32158	tuttavate	tuttava	tuttav	02_AS	PlG	et	tuttavate =tuttava  (PlG  >tuttav !02_AS
32167	aruka	aruka	arukas	02_A	SgG	et	aruka =aruka  (SgG  >arukas !02_A
32172	oskuse	oskuse	oskus	11~09_S	SgG	et	oskuse =oskuse  (SgG  >oskus !11~09_S
32175	sõnal	sõna	sõna	17_S	SgAd	et	sõnal =sõna  (SgAd  >sõna !17_S
32177	tarkade	tarka	tark	22_AS	PlG	et	tarkade =tarka  (PlG  >tark !22_AS
32181	vabandan	vabanda	vabandama	27_V	IndPrSg1	et	vabandan =vabanda  (IndPrSg1  >vabandama !27_V
32184	ennustas	ennusta	ennustama	27_V	IndIpfSg3	et	ennustas =ennusta  (IndIpfSg3  >ennustama !27_V
32186	registreerusin	registreeru	registreeruma	27_V	IndIpfSg1	et	registreerusin =registreeru  (IndIpfSg1  >registreeruma !27_V
32192	uurib	uuri	uurima	28_V	IndPrSg3	et	uurib =uuri  (IndPrSg3  >uurima !28_V
32199	kogemusele	kogemuse	kogemus	11_S	SgAll	et	kogemusele =kogemuse  (SgAll  >kogemus !11_S
32200	otsus	otsus	otsus	09_S	SgN	et	otsus =otsus  (SgN  >otsus !09_S
32213	hüvasti	hüvasti	hüvasti	41_I	ID	et	hüvasti =hüvasti  (ID  >hüvasti !41_I
32216	juristiks	juristi	jurist	22_S	SgTr	et	juristiks =juristi  (SgTr  >jurist !22_S
32219	muljeid	mulje	mulje	06_S	PlP	et	muljeid =mulje  (PlP  >mulje !06_S
32223	ajakirjanikke	kirjanikke	aja+kirjanik	25_S	PlP	et	ajakirjanikke =kirjanikke  (PlP  >aja+kirjanik !25_S
32231	suhtlemisvõimalusi	võimalusi	suhtlemis+võimalus	11_S	PlP	et	suhtlemisvõimalusi =võimalusi  (PlP  >suhtlemis+võimalus !11_S
32236	teoorias	teooria	teooria	01_S	SgIn	et	teoorias =teooria  (SgIn  >teooria !01_S
32246	esimesena	esimese	esimene	12_OP	SgEs	et	esimesena =esimese  (SgEs  >esimene !12_OP
32247	suhtled	suhtle	suhtlema	30_V	IndPrSg2	et	suhtled =suhtle  (IndPrSg2  >suhtlema !30_V
32248	tutvustad	tutvusta	tutvustama	27_V	IndPrSg2	et	tutvustad =tutvusta  (IndPrSg2  >tutvustama !27_V
32265	tutvun	tutvu	tutvuma	27_V	IndPrSg1	et	tutvun =tutvu  (IndPrSg1  >tutvuma !27_V
32267	aitaks	aita	aitama	29_V	KndPrPs	et	aitaks =aita  (KndPrPs  >aitama !29_V
32269	lasnamäele	mäe	lasna+mägi	21_S	SgAll	et	lasnamäele =mäe  (SgAll  >lasna+mägi !21_S
32271	eas	ea	iga	18_S	SgIn	et	eas =ea  (SgIn  >iga !18_S
32276	kohusetunne	tunne	kohuse+tunne	06_S	SgN	et	kohusetunne =tunne  (SgN  >kohuse+tunne !06_S
32279	võõrkeelena	keele	võõr+keel	13_S	SgEs	et	võõrkeelena =keele  (SgEs  >võõr+keel !13_S
32282	numbri	numbri	number	02_S	SgG	et	numbri =numbri  (SgG  >number !02_S
32290	võluatmosfäär	atmosfäär	võlu+atmosfäär	22_S	SgN	et	võluatmosfäär =atmosfäär  (SgN  >võlu+atmosfäär !22_S
32291	lähedaseks	lähedase	lähedane	12_AS	SgTr	et	lähedaseks =lähedase  (SgTr  >lähedane !12_AS
32296	lõpparvestus	arvestus	lõpp+arvestus	11_S	SgN	et	lõpparvestus =arvestus  (SgN  >lõpp+arvestus !11_S
32299	saateid	saate	saade	06_S	PlP	et	saateid =saate  (PlP  >saade !06_S
32311	näide	näide	näide	06_S	SgN	et	näide =näide  (SgN  >näide !06_S
32317	põhimõtte	mõtte	põhi+mõte	06_S	SgG	et	põhimõtte =mõtte  (SgG  >põhi+mõte !06_S
32320	vaidlusteni	vaidlus	vaidlus	11~09_S	PlTer	et	vaidlusteni =vaidlus  (PlTer  >vaidlus !11~09_S
32322	kuulturist	turist	kuul+turist	22_S	SgN	et	kuulturist =turist  (SgN  >kuul+turist !22_S
32325	suheldama	suhel	suhtlema	30_V	SupIps	et	suheldama =suhel  (SupIps  >suhtlema !30_V
32067	remont	remont	remont	22_S	SgN	et	remont =remont  (SgN  >remont !22_S
32073	õpilaskodus	kodu	õpilas+kodu	17_S	SgIn	et	õpilaskodus =kodu  (SgIn  >õpilas+kodu !17_S
32075	vabanetakse	vabane	vabanema	27_V	IndPrIps	et	vabanetakse =vabane  (IndPrIps  >vabanema !27_V
32082	voodid	voodi	voodi	01_S	PlN	et	voodid =voodi  (PlN  >voodi !01_S
32085	formuleerida	formuleeri	formuleerima	28_V	Inf	et	formuleerida =formuleeri  (Inf  >formuleerima !28_V
32087	ajakirjanikule	kirjaniku	aja+kirjanik	25_S	SgAll	et	ajakirjanikule =kirjaniku  (SgAll  >aja+kirjanik !25_S
32091	ajakirjanikud	kirjaniku	aja+kirjanik	25_S	PlN	et	ajakirjanikud =kirjaniku  (PlN  >aja+kirjanik !25_S
32098	referaadid	referaadi	referaat	22_S	PlN	et	referaadid =referaadi  (PlN  >referaat !22_S
32101	abita	abi	abi	17_S	SgAb	et	abita =abi  (SgAb  >abi !17_S
32102	humanitaarteadused	teaduse	humanitaar+teadus	11~09_S	PlN	et	humanitaarteadused =teaduse  (PlN  >humanitaar+teadus !11~09_S
32106	kogemust	kogemus	kogemus	11_S	SgP	et	kogemust =kogemus  (SgP  >kogemus !11_S
32108	kaasamõtlejaid	mõtleja	kaasa+mõtleja	01_S	PlP	et	kaasamõtlejaid =mõtleja  (PlP  >kaasa+mõtleja !01_S
32115	lehe	lehe	leht	22_S	SgG	et	lehe =lehe  (SgG  >leht !22_S
32116	vaadest	vaade	vaat	22_S	PlEl	et	vaadest =vaade  (PlEl  >vaat !22_S
32123	tunniga	tunni	tund	22_S	SgKom	et	tunniga =tunni  (SgKom  >tund !22_S
32127	tulingi	tul	tulema	36_V	IndIpfSg1^	et	tulingi =tul  (IndIpfSg1^  >tulema !36_V
32138	sõbralikuks	sõbraliku	sõbralik	25_A	SgTr	et	sõbralikuks =sõbraliku  (SgTr  >sõbralik !25_A
32162	ideesid	idee	idee	26_S	PlP	et	ideesid =idee  (PlP  >idee !26_S
32169	laieneb	laiene	laienema	27_V	IndPrSg3	et	laieneb =laiene  (IndPrSg3  >laienema !27_V
32179	ühendasin	ühenda	ühendama	27_V	IndIpfSg1	et	ühendasin =ühenda  (IndIpfSg1  >ühendama !27_V
32180	sunnitööle	töö	sunni+töö	26_S	SgAll	et	sunnitööle =töö  (SgAll  >sunni+töö !26_S
32190	ülipõnev	põnev	üli+põnev	02_A	SgN	et	ülipõnev =põnev  (SgN  >üli+põnev !02_A
32193	nimetatakse	nimeta	nimetama	27_V	IndPrIps	et	nimetatakse =nimeta  (IndPrIps  >nimetama !27_V
32194	imetleda	imetle	imetlema	27_V	Inf	et	imetleda =imetle  (Inf  >imetlema !27_V
32196	üksikasju	asju	üksik+asi	24_S	PlP	et	üksikasju =asju  (PlP  >üksik+asi !24_S
32207	lemmikajakirjanikud	kirjaniku	lemmik+aja+kirjanik	25_S	PlN	et	lemmikajakirjanikud =kirjaniku  (PlN  >lemmik+aja+kirjanik !25_S
32210	kahtlema	kahtle	kahtlema	30_V	Sup	et	kahtlema =kahtle  (Sup  >kahtlema !30_V
32212	koostada	koosta	koostama	27_V	Inf	et	koostada =koosta  (Inf  >koostama !27_V
32217	heatahtlik	tahtlik	hea+tahtlik	25_A	SgN	et	heatahtlik =tahtlik  (SgN  >hea+tahtlik !25_A
32220	kirjandeid	kirjande	kirjand	02_S	PlP	et	kirjandeid =kirjande  (PlP  >kirjand !02_S
32221	südant	südan	süda	04_S	SgP	et	südant =südan  (SgP  >süda !04_S
32226	raadiol	raadio	raadio	01_S	SgAd	et	raadiol =raadio  (SgAd  >raadio !01_S
32228	saatejuhina	juhi	saate+juht	22_S	SgEs	et	saatejuhina =juhi  (SgEs  >saate+juht !22_S
32237	videostuudios	stuudio	video+stuudio	01_S	SgIn	et	videostuudios =stuudio  (SgIn  >video+stuudio !01_S
32238	realiseerida	realiseeri	realiseerima	28_V	Inf	et	realiseerida =realiseeri  (Inf  >realiseerima !28_V
32245	edukad	eduka	edukas	02_A	PlN	et	edukad =eduka  (PlN  >edukas !02_A
32251	tulemusele	tulemuse	tulemus	11_S	SgAll	et	tulemusele =tulemuse  (SgAll  >tulemus !11_S
32253	bensiin	bensiin	bensiin	22_S	SgN	et	bensiin =bensiin  (SgN  >bensiin !22_S
32254	diskussioonisse	diskussiooni	diskussioon	22_S	SgIll	et	diskussioonisse =diskussiooni  (SgIll  >diskussioon !22_S
32262	maailmauudised	uudise	maa+ilma+uudis	09_S	PlN	et	maailmauudised =uudise  (PlN  >maa+ilma+uudis !09_S
32266	otsusin	usin	ots+usin	02_A	SgN	et	otsusin =usin  (SgN  >ots+usin !02_A
32268	paljudele	palju	palju	16_P	PlAll	et	paljudele =palju  (PlAll  >palju !16_P
32284	kutsuti	kutsu	kutsuma	28_V	IndIpfIps	et	kutsuti =kutsu  (IndIpfIps  >kutsuma !28_V
32289	kauemaks	kauema	kauem	02_A	SgTr	et	kauemaks =kauema  (SgTr  >kauem !02_A
32292	igatsen	igatse	igatsema	27_V	IndPrSg1	et	igatsen =igatse  (IndPrSg1  >igatsema !27_V
32297	seost	seos	seos	09_S	SgP	et	seost =seos  (SgP  >seos !09_S
32300	kõnekäitumist	käitumis	kõne+käitumine	12_S	SgP	et	kõnekäitumist =käitumis  (SgP  >kõne+käitumine !12_S
32302	grammatikas	grammatika	grammatika	01_S	SgIn	et	grammatikas =grammatika  (SgIn  >grammatika !01_S
32303	vestluspartner	partner	vestlus+partner	02_S	SgN	et	vestluspartner =partner  (SgN  >vestlus+partner !02_S
32313	juhime	juhi	juhtima	28_V	IndPrPl1	et	juhime =juhi  (IndPrPl1  >juhtima !28_V
32330	kommunikatsioon	kommunikatsioon	kommunikatsioon	22_S	SgN	et	kommunikatsioon =kommunikatsioon  (SgN  >kommunikatsioon !22_S
32331	vaatame	vaata	vaatama	29_V	IndPrPl1	et	vaatame =vaata  (IndPrPl1  >vaatama !29_V
32344	kultuuridest	kultuuri	kultuur	22_S	PlEl	et	kultuuridest =kultuuri  (PlEl  >kultuur !22_S
32084	pluusid	pluusi	pluus	22_S	PlN	et	pluusid =pluusi  (PlN  >pluus !22_S
32092	artiklid	artikli	artikkel	02_S	PlN	et	artiklid =artikli  (PlN  >artikkel !02_S
32094	suhtlemisoskusega	oskuse	suhtlemis+oskus	11~09_S	SgKom	et	suhtlemisoskusega =oskuse  (SgKom  >suhtlemis+oskus !11~09_S
32095	referaate	referaate	referaat	22_S	PlP	et	referaate =referaate  (PlP  >referaat !22_S
32096	asjadest	asja	asi	24_S	PlEl	et	asjadest =asja  (PlEl  >asi !24_S
32097	igavad	igava	igav	02_A	PlN	et	igavad =igava  (PlN  >igav !02_A
32105	õppekeelega	keele	õppe+keel	13_S	SgKom	et	õppekeelega =keele  (SgKom  >õppe+keel !13_S
32118	elud	elu	elu	17_S	PlN	et	elud =elu  (PlN  >elu !17_S
32119	hävitada	hävita	hävitama	27_V	Inf	et	hävitada =hävita  (Inf  >hävitama !27_V
32120	reaalse	reaalse	reaalne	02_A	SgG	et	reaalse =reaalse  (SgG  >reaalne !02_A
32125	missuguse	suguse	mis+sugune	10_P	SgG	et	missuguse =suguse  (SgG  >mis+sugune !10_P
32132	leht	leht	leht	22_S	SgN	et	leht =leht  (SgN  >leht !22_S
32134	hoidsin	hoid	hoidma	34_V	IndIpfSg1	et	hoidsin =hoid  (IndIpfSg1  >hoidma !34_V
32139	omandan	omanda	omandama	27_V	IndPrSg1	et	omandan =omanda  (IndPrSg1  >omandama !27_V
32142	spetsialistiks	spetsialisti	spetsialist	22_S	SgTr	et	spetsialistiks =spetsialisti  (SgTr  >spetsialist !22_S
32154	eesmärkideni	märki	ees+märk	22_S	PlTer	et	eesmärkideni =märki  (PlTer  >ees+märk !22_S
32159	õppejõudude	jõudu	õppe+jõud	22_S	PlG	et	õppejõudude =jõudu  (PlG  >õppe+jõud !22_S
32160	antaks	an	andma	34_V	KndPrIps	et	antaks =an  (KndPrIps  >andma !34_V
32170	juhtud	juhtu	juhtuma	27_V	IndPrSg2	et	juhtud =juhtu  (IndPrSg2  >juhtuma !27_V
32171	noppida	noppi	noppima	28_V	Inf	et	noppida =noppi  (Inf  >noppima !28_V
32173	osav	osav	osav	02_A	SgN	et	osav =osav  (SgN  >osav !02_A
32174	eludega	elu	elu	17_S	PlKom	et	eludega =elu  (PlKom  >elu !17_S
32183	arstina	arsti	arst	22_S	SgEs	et	arstina =arsti  (SgEs  >arst !22_S
32185	viisin	vii	viima	38_V	IndIpfSg1	et	viisin =vii  (IndIpfSg1  >viima !38_V
32189	kursustekaaslased	kaaslase	kursuste+kaaslane	12?10_S	PlN	et	kursustekaaslased =kaaslase  (PlN  >kursuste+kaaslane !12?10_S
32195	spetsialistina	spetsialisti	spetsialist	22_S	SgEs	et	spetsialistina =spetsialisti  (SgEs  >spetsialist !22_S
32197	momendilt	momendi	moment	22_S	SgAbl	et	momendilt =momendi  (SgAbl  >moment !22_S
32198	ilusasti	ilusasti	ilusasti	41_D	ID	et	ilusasti =ilusasti  (ID  >ilusasti !41_D
32202	proovima	proovi	proovima	28_V	Sup	et	proovima =proovi  (Sup  >proovima !28_V
32204	ütleksin	ütle	ütlema	30_V	KndPrSg1	et	ütleksin =ütle  (KndPrSg1  >ütlema !30_V
32227	lainetel	laine	laine	06_S	PlAd	et	lainetel =laine  (PlAd  >laine !06_S
32230	suheldes	suhel	suhtlema	30_V	Ger	et	suheldes =suhel  (Ger  >suhtlema !30_V
32234	reporter	reporter	reporter	02_S	SgN	et	reporter =reporter  (SgN  >reporter !02_S
32240	meeldid	meeldi	meeldima	27_V	IndPrSg2	et	meeldid =meeldi  (IndPrSg2  >meeldima !27_V
32242	momendis	momendi	moment	22_S	SgIn	et	momendis =momendi  (SgIn  >moment !22_S
32258	tööks	töö	töö	26_S	SgTr	et	tööks =töö  (SgTr  >töö !26_S
32259	ülikoolik	koolik	üli+koolik	02_S	SgN	et	ülikoolik =koolik  (SgN  >üli+koolik !02_S
32270	kolisimegi	koli	kolima	27_V	IndIpfPl1^	et	kolisimegi =koli  (IndIpfPl1^  >kolima !27_V
32275	seltskondlikuks	seltskondliku	seltskondlik	25_A	SgTr	et	seltskondlikuks =seltskondliku  (SgTr  >seltskondlik !25_A
32281	meeleheites	heite	meele+heide	06_S	SgIn	et	meeleheites =heite  (SgIn  >meele+heide !06_S
32285	vestlusele	vestluse	vestlus	11~09_S	SgAll	et	vestlusele =vestluse  (SgAll  >vestlus !11~09_S
32287	sõitma	sõit	sõitma	34_V	Sup	et	sõitma =sõit  (Sup  >sõitma !34_V
32293	ajakirjandusi	kirjandusi	aja+kirjandus	11_S	PlP	et	ajakirjandusi =kirjandusi  (PlP  >aja+kirjandus !11_S
32298	tähtsustada	tähtsusta	tähtsustama	27_V	Inf	et	tähtsustada =tähtsusta  (Inf  >tähtsustama !27_V
32305	välismaalasega	maalase	välis+maalane	12?10_S	SgKom	et	välismaalasega =maalase  (SgKom  >välis+maalane !12?10_S
32307	teoreetilisi	teoreetilisi	teoreetiline	12_A	PlP	et	teoreetilisi =teoreetilisi  (PlP  >teoreetiline !12_A
32310	väärtushinnangud	hinnangu	väärtus+hinnang	02_S	PlN	et	väärtushinnangud =hinnangu  (PlN  >väärtus+hinnang !02_S
32314	kasvatatakse	kasvata	kasvatama	27_V	IndPrIps	et	kasvatatakse =kasvata  (IndPrIps  >kasvatama !27_V
32316	idaloogikas	loogika	ida+loogika	01_S	SgIn	et	idaloogikas =loogika  (SgIn  >ida+loogika !01_S
32319	hinna	hinna	hind	22_S	SgG	et	hinna =hinna  (SgG  >hind !22_S
32323	laiendama	laienda	laiendama	27_V	Sup	et	laiendama =laienda  (Sup  >laiendama !27_V
32328	keelebarjäär	barjäär	keele+barjäär	22_S	SgN	et	keelebarjäär =barjäär  (SgN  >keele+barjäär !22_S
32333	absoluutne	absoluutne	absoluutne	02_A	SgN	et	absoluutne =absoluutne  (SgN  >absoluutne !02_A
32336	teistsugune	sugune	teist+sugune	10_P	SgN	et	teistsugune =sugune  (SgN  >teist+sugune !10_P
32126	ideaalne	ideaalne	ideaalne	02_A	SgN	et	ideaalne =ideaalne  (SgN  >ideaalne !02_A
32128	looduslikud	loodusliku	looduslik	25_A	PlN	et	looduslikud =loodusliku  (PlN  >looduslik !25_A
32129	selleparast	paras	selle+paras	02_A	SgP	et	selleparast =paras  (SgP  >selle+paras !02_A
32130	saaksin	saa	saama	37_V	KndPrSg1	et	saaksin =saa  (KndPrSg1  >saama !37_V
32133	ajalehesse	lehe	aja+leht	22_S	SgIll	et	ajalehesse =lehe  (SgIll  >aja+leht !22_S
32136	ajakirjanike	kirjanike	aja+kirjanik	25_S	PlG	et	ajakirjanike =kirjanike  (PlG  >aja+kirjanik !25_S
32143	tallina	talli	tall	22_S	SgEs	et	tallina =talli  (SgEs  >tall !22_S
32144	näidised	näidise	näidis	09_S	PlN	et	näidised =näidise  (PlN  >näidis !09_S
32147	tudengi	tudengi	tudeng	02_S	SgG	et	tudengi =tudengi  (SgG  >tudeng !02_S
32148	meist	me	ma	00_P	PlEl	et	meist =me  (PlEl  >ma !00_P
32149	kraad	kraad	kraad	22_S	SgN	et	kraad =kraad  (SgN  >kraad !22_S
32152	saades	saa	saama	37_V	Ger	et	saades =saa  (Ger  >saama !37_V
32161	luulejaks	jaks	luule+jaks	22_S	SgN	et	luulejaks =jaks  (SgN  >luule+jaks !22_S
32164	kirjand	kirjand	kirjand	02_S	SgN	et	kirjand =kirjand  (SgN  >kirjand !02_S
32178	koonduda	koondu	koonduma	27_V	Inf	et	koonduda =koondu  (Inf  >koonduma !27_V
32182	otsib	otsi	otsima	28_V	IndPrSg3	et	otsib =otsi  (IndPrSg3  >otsima !28_V
32191	loob	loo	looma	38_V	IndPrSg3	et	loob =loo  (IndPrSg3  >looma !38_V
32201	paberi	paberi	paber	02_S	SgG	et	paberi =paberi  (SgG  >paber !02_S
32205	üleüldse	üleüldse	üle+üldse	41_D	ID	et	üleüldse =üleüldse  (ID  >üle+üldse !41_D
32208	lemmikajalehed	lehe	lemmik+aja+leht	22_S	PlN	et	lemmikajalehed =lehe  (PlN  >lemmik+aja+leht !22_S
32209	kooliaeg	aeg	kooli+aeg	22_S	SgN	et	kooliaeg =aeg  (SgN  >kooli+aeg !22_S
32211	registreerisin	registreeri	registreerima	28_V	IndIpfSg1	et	registreerisin =registreeri  (IndIpfSg1  >registreerima !28_V
32218	avaaktusel	aktuse	ava+aktus	11~09_S	SgAd	et	avaaktusel =aktuse  (SgAd  >ava+aktus !11~09_S
32225	kandidaat	kandidaat	kandidaat	22_S	SgN	et	kandidaat =kandidaat  (SgN  >kandidaat !22_S
32229	kasulikud	kasuliku	kasulik	25_A	PlN	et	kasulikud =kasuliku  (PlN  >kasulik !25_A
32235	jätkasin	jätka	jätkama	29_V	IndIpfSg1	et	jätkasin =jätka  (IndIpfSg1  >jätkama !29_V
32241	ajalehel	lehe	aja+leht	22_S	SgAd	et	ajalehel =lehe  (SgAd  >aja+leht !22_S
32243	punktide	punkti	punkt	22_S	PlG	et	punktide =punkti  (PlG  >punkt !22_S
32249	nõuga	nõu	nõu	26_S	SgKom	et	nõuga =nõu  (SgKom  >nõu !26_S
32250	arvamuses	arvamuse	arvamus	11_S	SgIn	et	arvamuses =arvamuse  (SgIn  >arvamus !11_S
32252	tudengitele	tudengi	tudeng	02_S	PlAll	et	tudengitele =tudengi  (PlAll  >tudeng !02_S
32260	uudishimuliku	himuliku	uudis+himulik	25_A	SgG	et	uudishimuliku =himuliku  (SgG  >uudis+himulik !25_A
32261	iseloomujooned	joone	ise+loomu+joon	13_S	PlN	et	iseloomujooned =joone  (PlN  >ise+loomu+joon !13_S
32263	teatatakse	teata	teatama	27_V	IndPrIps	et	teatatakse =teata  (IndPrIps  >teatama !27_V
32274	imelikuks	imeliku	imelik	25_A	SgTr	et	imelikuks =imeliku  (SgTr  >imelik !25_A
32283	helistasin	helista	helistama	27_V	IndIpfSg1	et	helistasin =helista  (IndIpfSg1  >helistama !27_V
32286	ruttasin	rutta	ruttama	29_V	IndIpfSg1	et	ruttasin =rutta  (IndIpfSg1  >ruttama !29_V
32288	läksingi	läk	minema	36_V	IndIpfSg1^	et	läksingi =läk  (IndIpfSg1^  >minema !36_V
32295	tegeleme	tegele	tegelema	31~27_V	IndPrPl1	et	tegeleme =tegele  (IndPrPl1  >tegelema !31~27_V
32304	mõistab	mõista	mõistma	34_V	IndPrSg3	et	mõistab =mõista  (IndPrSg3  >mõistma !34_V
32306	käitub	käitu	käituma	27_V	IndPrSg3	et	käitub =käitu  (IndPrSg3  >käituma !27_V
32309	kultuuriterritoorium	territoorium	kultuuri+territoorium	19~02_S	SgN	et	kultuuriterritoorium =territoorium  (SgN  >kultuuri+territoorium !19~02_S
32312	igapäevatoimingud	toimingu	iga+päeva+toiming	02_S	PlN	et	igapäevatoimingud =toimingu  (PlN  >iga+päeva+toiming !02_S
32315	orientatsioon	orientatsioon	orientatsioon	22_S	SgN	et	orientatsioon =orientatsioon  (SgN  >orientatsioon !22_S
32318	püütakse	püü	püüdma	34_V	IndPrIps	et	püütakse =püü  (IndPrIps  >püüdma !34_V
32321	konfliktideni	konflikti	konflikt	22_S	PlTer	et	konfliktideni =konflikti  (PlTer  >konflikt !22_S
32324	koguma	kogu	koguma	27_V	Sup	et	koguma =kogu  (Sup  >koguma !27_V
32326	võõraga	võõra	võõras	07_AS	SgKom	et	võõraga =võõra  (SgKom  >võõras !07_AS
32327	andestab	andesta	andestama	27_V	IndPrSg3	et	andestab =andesta  (IndPrSg3  >andestama !27_V
32332	teooriad	teooria	teooria	01_S	PlN	et	teooriad =teooria  (PlN  >teooria !01_S
32334	väärtustatakse	väärtusta	väärtustama	27_V	IndPrIps	et	väärtustatakse =väärtusta  (IndPrIps  >väärtustama !27_V
32335	polegi	pole	olema	36_V	IndPrPsN^	et	polegi =pole  (IndPrPsN^  >olema !36_V
32349	põhilised	põhilise	põhiline	12_A	PlN	et	põhilised =põhilise  (PlN  >põhiline !12_A
32137	rühm	rühm	rühm	22_S	SgN	et	rühm =rühm  (SgN  >rühm !22_S
32141	õppeaineid	aine	õppe+aine	06_S	PlP	et	õppeaineid =aine  (PlP  >õppe+aine !06_S
32145	omaenda	enda	oma+enda	41_P	SgG	et	omaenda =enda  (SgG  >oma+enda !41_P
32151	kindlustada	kindlusta	kindlustama	27_V	Inf	et	kindlustada =kindlusta  (Inf  >kindlustama !27_V
32153	kindla	kindla	kindel	02_A	SgG	et	kindla =kindla  (SgG  >kindel !02_A
32156	lihtsa	lihtsa	lihtne	02_A	SgG	et	lihtsa =lihtsa  (SgG  >lihtne !02_A
32163	täisväärtuslik	väärtuslik	täis+väärtuslik	25_A	SgN	et	täisväärtuslik =väärtuslik  (SgN  >täis+väärtuslik !25_A
32165	humanitaarteadmised	teadmise	humanitaar+teadmine	12?10_S	PlN	et	humanitaarteadmised =teadmise  (PlN  >humanitaar+teadmine !12?10_S
32166	selleni	selle	see	00_P	SgTer	et	selleni =selle  (SgTer  >see !00_P
32168	valdkondadest	valdkonda	valdkond	22_S	PlEl	et	valdkondadest =valdkonda  (PlEl  >valdkond !22_S
32176	mainisin	maini	mainima	28_V	IndIpfSg1	et	mainisin =maini  (IndIpfSg1  >mainima !28_V
32187	kursustele	kursus	kursus	11~09_S	PlAll	et	kursustele =kursus  (PlAll  >kursus !11~09_S
32188	heameelsed	meelse	hea+meelne	02_A	PlN	et	heameelsed =meelse  (PlN  >hea+meelne !02_A
32203	kokkuvõtteks	võtte	kokku+võte	06_S	SgTr	et	kokkuvõtteks =võtte  (SgTr  >kokku+võte !06_S
32206	kavatsed	kavatse	kavatsema	27_V	IndPrSg2	et	kavatsed =kavatse  (IndPrSg2  >kavatsema !27_V
32214	heale	hea	hea	26_AS	SgAll	et	heale =hea  (SgAll  >hea !26_AS
32215	perspektiivset	perspektiivse	perspektiivne	02_A	SgP	et	perspektiivset =perspektiivse  (SgP  >perspektiivne !02_A
32222	tutvuseid	tutvuse	tutvus	09_S	PlP	et	tutvuseid =tutvuse  (PlP  >tutvus !09_S
32224	otselt	otse	ots	22_S	PlAbl	et	otselt =otse  (PlAbl  >ots !22_S
32232	kasulikuna	kasuliku	kasulik	25_A	SgEs	et	kasulikuna =kasuliku  (SgEs  >kasulik !25_A
32233	seitsmendas	seitsmenda	seitsmes	02_O	SgIn	et	seitsmendas =seitsmenda  (SgIn  >seitsmes !02_O
32239	kümnendal	kümnenda	kümnes	02_O	SgAd	et	kümnendal =kümnenda  (SgAd  >kümnes !02_O
32244	teadusi	teadusi	teadus	11_S	PlP	et	teadusi =teadusi  (PlP  >teadus !11_S
32255	üliõpilased	õpilase	üli+õpilane	12_S	PlN	et	üliõpilased =õpilase  (PlN  >üli+õpilane !12_S
32256	üksmeelne	meelne	üks+meelne	02_A	SgN	et	üksmeelne =meelne  (SgN  >üks+meelne !02_A
32257	töötame	tööta	töötama	27_V	IndPrPl1	et	töötame =tööta  (IndPrPl1  >töötama !27_V
32264	tööpakkumised	pakkumise	töö+pakkumine	12_S	PlN	et	tööpakkumised =pakkumise  (PlN  >töö+pakkumine !12_S
32272	tihedat	tiheda	tihe	02_A	SgP	et	tihedat =tiheda  (SgP  >tihe !02_A
32273	seljataga	seljataga	selja+taga	41_D	ID	et	seljataga =seljataga  (ID  >selja+taga !41_D
32277	vastuvõtueksamitel	eksami	vastu+võtu+eksam	02_S	PlAd	et	vastuvõtueksamitel =eksami  (PlAd  >vastu+võtu+eksam !02_S
32278	lapsehoidjana	hoidja	lapse+hoidja	01_S	SgEs	et	lapsehoidjana =hoidja  (SgEs  >lapse+hoidja !01_S
32280	äärmises	äärmise	äärmine	12?10_A	SgIn	et	äärmises =äärmise  (SgIn  >äärmine !12?10_A
32294	olukorras	korra	olu+kord	22_S	SgIn	et	olukorras =korra  (SgIn  >olu+kord !22_S
32301	vigu	vigu	viga	18_S	PlP	et	vigu =vigu  (PlP  >viga !18_S
32308	inimeselt	inimese	inimene	12_S	SgAbl	et	inimeselt =inimese  (SgAbl  >inimene !12_S
32337	enesearendamiseks	arendamise	enese+arendamine	12_S	SgTr	et	enesearendamiseks =arendamise  (SgTr  >enese+arendamine !12_S
32339	mõtteviisis	viisi	mõtte+viis	22_S	SgIn	et	mõtteviisis =viisi  (SgIn  >mõtte+viis !22_S
32341	stereotüüpidest	stereotüüpi	stereotüüp	22_S	PlEl	et	stereotüüpidest =stereotüüpi  (PlEl  >stereotüüp !22_S
32345	austada	austa	austama	27_V	Inf	et	austada =austa  (Inf  >austama !27_V
32353	usuvad	usu	uskuma	28_V	IndPrPl3	et	usuvad =usu  (IndPrPl3  >uskuma !28_V
32361	usundid	usundi	usund	02_S	PlN	et	usundid =usundi  (PlN  >usund !02_S
32368	rituaalid	rituaali	rituaal	22_S	PlN	et	rituaalid =rituaali  (PlN  >rituaal !22_S
32372	usundeid	usunde	usund	02_S	PlP	et	usundeid =usunde  (PlP  >usund !02_S
32378	valdame	valda	valdama	29_V	IndPrPl1	et	valdame =valda  (IndPrPl1  >valdama !29_V
32383	suheldakse	suhel	suhtlema	30_V	IndPrIps	et	suheldakse =suhel  (IndPrIps  >suhtlema !30_V
32390	keskkonnale	keskkonna	keskkond	22_S	SgAll	et	keskkonnale =keskkonna  (SgAll  >keskkond !22_S
32392	võõrkeelsena	keelse	võõr+keelne	02_A	SgEs	et	võõrkeelsena =keelse  (SgEs  >võõr+keelne !02_A
32394	kolmekeelne	keelne	kolme+keelne	02_A	SgN	et	kolmekeelne =keelne  (SgN  >kolme+keelne !02_A
32399	tagurpidi	tagurpidi	tagur+pidi	41_D	ID	et	tagurpidi =tagurpidi  (ID  >tagur+pidi !41_D
32401	koguda	kogu	koguma	27_V	Inf	et	koguda =kogu  (Inf  >koguma !27_V
32407	läänemast	mast	lääne+mast	22_S	SgN	et	läänemast =mast  (SgN  >lääne+mast !22_S
32411	keeloskusega	oskuse	keel+oskus	11~09_S	SgKom	et	keeloskusega =oskuse  (SgKom  >keel+oskus !11~09_S
32417	võõrkeelega	keele	võõr+keel	13_S	SgKom	et	võõrkeelega =keele  (SgKom  >võõr+keel !13_S
32329	mõtteviis	viis	mõtte+viis	22_S	SgN	et	mõtteviis =viis  (SgN  >mõtte+viis !22_S
32338	rituaaliga	rituaali	rituaal	22_S	SgKom	et	rituaaliga =rituaali  (SgKom  >rituaal !22_S
32342	väärtustada	väärtusta	väärtustama	27_V	Inf	et	väärtustada =väärtusta  (Inf  >väärtustama !27_V
32343	hädavajalikud	vajaliku	häda+vajalik	25_A	PlN	et	hädavajalikud =vajaliku  (PlN  >häda+vajalik !25_A
32346	võõrmaainimene	inimene	võõr+maa+inimene	12_S	SgN	et	võõrmaainimene =inimene  (SgN  >võõr+maa+inimene !12_S
32355	absoluutse	absoluutse	absoluutne	02_A	SgG	et	absoluutse =absoluutse  (SgG  >absoluutne !02_A
32380	inglismaalane	maalane	inglis+maalane	12?10_S	SgN	et	inglismaalane =maalane  (SgN  >inglis+maalane !12?10_S
32381	keeleoskused	oskuse	keele+oskus	11~09_S	PlN	et	keeleoskused =oskuse  (PlN  >keele+oskus !11~09_S
32382	tühjad	tühja	tühi	24_A	PlN	et	tühjad =tühja  (PlN  >tühi !24_A
32384	märgatakse	märga	märkama	29_V	IndPrIps	et	märgatakse =märga  (IndPrIps  >märkama !29_V
32386	ühendriigid	riigi	ühend+riik	22_S	PlN	et	ühendriigid =riigi  (PlN  >ühend+riik !22_S
32396	harjuma	harju	harjuma	27_V	Sup	et	harjuma =harju  (Sup  >harjuma !27_V
32398	keeleoskusega	oskuse	keele+oskus	11~09_S	SgKom	et	keeleoskusega =oskuse  (SgKom  >keele+oskus !11~09_S
32410	pooled	poole	pool	13_NS	PlN	et	pooled =poole  (PlN  >pool !13_NS
32423	praktilise	praktilise	praktiline	12_A	SgG	et	praktilise =praktilise  (SgG  >praktiline !12_A
32425	rägin	rägin	rägin	02_S	SgN	et	rägin =rägin  (SgN  >rägin !02_S
32447	tervislikud	tervisliku	tervislik	25_A	PlN	et	tervislikud =tervisliku  (PlN  >tervislik !25_A
32454	veendusin	veendu	veenduma	27_V	IndIpfSg1	et	veendusin =veendu  (IndIpfSg1  >veenduma !27_V
32459	aknas	akna	aken	08_S	SgIn	et	aknas =akna  (SgIn  >aken !08_S
32460	mööbel	mööbel	mööbel	02_S	SgN	et	mööbel =mööbel  (SgN  >mööbel !02_S
32480	diplomi	diplomi	diplom	02_S	SgG	et	diplomi =diplomi  (SgG  >diplom !02_S
32491	proov	proov	proov	22_S	SgN	et	proov =proov  (SgN  >proov !22_S
32493	näoga	näo	nägu	18_S	SgKom	et	näoga =näo  (SgKom  >nägu !18_S
32495	pikendame	pikenda	pikendama	27_V	IndPrPl1	et	pikendame =pikenda  (IndPrPl1  >pikendama !27_V
32501	tagasihoidlik	hoidlik	tagasi+hoidlik	25_A	SgN	et	tagasihoidlik =hoidlik  (SgN  >tagasi+hoidlik !25_A
32503	arusaadavad	saadava	aru+saadav	02_A	PlN	et	arusaadavad =saadava  (PlN  >aru+saadav !02_A
32508	õpingut	õpingu	õping	02_S	SgP	et	õpingut =õpingu  (SgP  >õping !02_S
32511	ebaadekvaatne	adekvaatne	eba+adekvaatne	02_A	SgN	et	ebaadekvaatne =adekvaatne  (SgN  >eba+adekvaatne !02_A
32523	üldteadmisi	teadmisi	üld+teadmine	12_S	PlP	et	üldteadmisi =teadmisi  (PlP  >üld+teadmine !12_S
32533	humanitaarainet	aine	humanitaar+aine	06_S	SgP	et	humanitaarainet =aine  (SgP  >humanitaar+aine !06_S
32545	teaksin	tea	teadma	34_V	KndPrSg1	et	teaksin =tea  (KndPrSg1  >teadma !34_V
32549	kaaskursustega	kursus	kaas+kursus	11~09_S	PlKom	et	kaaskursustega =kursus  (PlKom  >kaas+kursus !11~09_S
32551	ärijuhtimine	juhtimine	äri+juhtimine	12_S	SgN	et	ärijuhtimine =juhtimine  (SgN  >äri+juhtimine !12_S
32556	teeviit	viit	tee+viit	22_S	SgN	et	teeviit =viit  (SgN  >tee+viit !22_S
32560	populaarsed	populaarse	populaarne	02_A	PlN	et	populaarsed =populaarse  (PlN  >populaarne !02_A
32565	õppekavad	kava	õppe+kava	17_S	PlN	et	õppekavad =kava  (PlN  >õppe+kava !17_S
32569	sündmuse	sündmuse	sündmus	11~09_S	SgG	et	sündmuse =sündmuse  (SgG  >sündmus !11~09_S
32571	maksimaalne	maksimaalne	maksimaalne	02_A	SgN	et	maksimaalne =maksimaalne  (SgN  >maksimaalne !02_A
32572	konsulteerisin	konsulteeri	konsulteerima	28_V	IndIpfSg1	et	konsulteerisin =konsulteeri  (IndIpfSg1  >konsulteerima !28_V
32577	telekommunikatsioonid	kommunikatsiooni	tele+kommunikatsioon	22_S	PlN	et	telekommunikatsioonid =kommunikatsiooni  (PlN  >tele+kommunikatsioon !22_S
32578	täpsustasin	täpsusta	täpsustama	27_V	IndIpfSg1	et	täpsustasin =täpsusta  (IndIpfSg1  >täpsustama !27_V
32583	moodne	moodne	moodne	02_A	SgN	et	moodne =moodne  (SgN  >moodne !02_A
32585	kirjanikuna	kirjaniku	kirjanik	25_S	SgEs	et	kirjanikuna =kirjaniku  (SgEs  >kirjanik !25_S
32587	agent	agent	agent	22_S	SgN	et	agent =agent  (SgN  >agent !22_S
32590	plaan	plaan	plaan	22_S	SgN	et	plaan =plaan  (SgN  >plaan !22_S
32592	kirjandid	kirjandi	kirjand	02_S	PlN	et	kirjandid =kirjandi  (PlN  >kirjand !02_S
32596	leidsisin	sisin	leid+sisin	02_S	SgN	et	leidsisin =sisin  (SgN  >leid+sisin !02_S
32613	veetsin	veet	veetma	34_V	IndIpfSg1	et	veetsin =veet  (IndIpfSg1  >veetma !34_V
32616	täiega	täie	täis	14_AS	SgKom	et	täiega =täie  (SgKom  >täis !14_AS
32619	süsteemid	süsteemi	süsteem	22_S	PlN	et	süsteemid =süsteemi  (PlN  >süsteem !22_S
32623	päikeseline	päikeseline	päikeseline	12_A	SgN	et	päikeseline =päikeseline  (SgN  >päikeseline !12_A
32625	mängimas	mängi	mängima	28_V	SupIn	et	mängimas =mängi  (SupIn  >mängima !28_V
32340	hoiduda	hoidu	hoiduma	27_V	Inf	et	hoiduda =hoidu  (Inf  >hoiduma !27_V
32352	arendame	arenda	arendama	27_V	IndPrPl1	et	arendame =arenda  (IndPrPl1  >arendama !27_V
32356	eraldab	eralda	eraldama	27_V	IndPrSg3	et	eraldab =eralda  (IndPrSg3  >eraldama !27_V
32357	võtame	võta	võtma	35_V	IndPrPl1	et	võtame =võta  (IndPrPl1  >võtma !35_V
32375	elutavades	tava	elu+tava	17_S	PlIn	et	elutavades =tava  (PlIn  >elu+tava !17_S
32389	ühed	ühe	üks	22_NP	PlN	et	ühed =ühe  (PlN  >üks !22_NP
32391	soome-ugri	soome-ugri	soome+-ugri	41_G	ID	et	soome-ugri =soome-ugri  (ID  >soome+-ugri !41_G
32403	prantslastest	prantslas	prantslane	12?10_S	PlEl	et	prantslastest =prantslas  (PlEl  >prantslane !12?10_S
32404	märk	märk	märk	22_S	SgN	et	märk =märk  (SgN  >märk !22_S
32406	sureme	sure	surema	36_V	IndPrPl1	et	sureme =sure  (IndPrPl1  >surema !36_V
32414	andeks	ande	anne	06_S	SgTr	et	andeks =ande  (SgTr  >anne !06_S
32415	pered	pere	pere	16_S	PlN	et	pered =pere  (PlN  >pere !16_S
32419	suhtlus	suhtlus	suhtlus	11~09_S	SgN	et	suhtlus =suhtlus  (SgN  >suhtlus !11~09_S
32420	võrkeele	ee	võrk+esi	15_S	SgAll	et	võrkeele =ee  (SgAll  >võrk+esi !15_S
32430	arvamuse	arvamuse	arvamus	11_S	SgG	et	arvamuse =arvamuse  (SgG  >arvamus !11_S
32433	lektorit	lektori	lektor	02_S	SgP	et	lektorit =lektori  (SgP  >lektor !02_S
32436	ajakirjandusena	kirjanduse	aja+kirjandus	11_S	SgEs	et	ajakirjandusena =kirjanduse  (SgEs  >aja+kirjandus !11_S
32437	veedab	veeda	veetma	34_V	IndPrSg3	et	veedab =veeda  (IndPrSg3  >veetma !34_V
32438	soobi	soobi	soop	22_S	SgG	et	soobi =soobi  (SgG  >soop !22_S
32440	lõpetaksin	lõpeta	lõpetama	27_V	KndPrSg1	et	lõpetaksin =lõpeta  (KndPrSg1  >lõpetama !27_V
32445	alustab	alusta	alustama	27_V	IndPrSg3	et	alustab =alusta  (IndPrSg3  >alustama !27_V
32446	aidati	aida	aitama	29_V	IndIpfIps	et	aidati =aida  (IndIpfIps  >aitama !29_V
32451	emale	ema	ema	17_S	SgAll	et	emale =ema  (SgAll  >ema !17_S
32468	hindeid	hinde	hinne	06_S	PlP	et	hindeid =hinde  (PlP  >hinne !06_S
32477	uutest	uu	uus	14_A	PlEl	et	uutest =uu  (PlEl  >uus !14_A
32479	taset	tase	tase	04_S	SgP	et	taset =tase  (SgP  >tase !04_S
32488	sõprus	sõprus	sõprus	11~09_S	SgN	et	sõprus =sõprus  (SgN  >sõprus !11~09_S
32494	jõuaks	jõua	jõudma	34_V	KndPrPs	et	jõuaks =jõua  (KndPrPs  >jõudma !34_V
32497	tudengil	tudengi	tudeng	02_S	SgAd	et	tudengil =tudengi  (SgAd  >tudeng !02_S
32514	riikide	riiki	riik	22_S	PlG	et	riikide =riiki  (PlG  >riik !22_S
32515	saabub	saabu	saabuma	27_V	IndPrSg3	et	saabub =saabu  (IndPrSg3  >saabuma !27_V
32519	teostega	teos	teos	09_S	PlKom	et	teostega =teos  (PlKom  >teos !09_S
32524	täiskasvanutega	kasvanu	täis+kasvanu	01_S	PlKom	et	täiskasvanutega =kasvanu  (PlKom  >täis+kasvanu !01_S
32525	rutiin	rutiin	rutiin	22_S	SgN	et	rutiin =rutiin  (SgN  >rutiin !22_S
32526	robot	robot	robot	02_S	SgN	et	robot =robot  (SgN  >robot !02_S
32528	mitmesugune	sugune	mitme+sugune	10_A	SgN	et	mitmesugune =sugune  (SgN  >mitme+sugune !10_A
32530	palgaga	palga	palk	22_S	SgKom	et	palgaga =palga  (SgKom  >palk !22_S
32531	haridused	hariduse	haridus	11_S	PlN	et	haridused =hariduse  (PlN  >haridus !11_S
32532	mänguasjadele	asja	mängu+asi	24_S	PlAll	et	mänguasjadele =asja  (PlAll  >mängu+asi !24_S
32547	viimati	viimati	viimati	41_D	ID	et	viimati =viimati  (ID  >viimati !41_D
32553	erialavalikul	valiku	eri+ala+valik	02_S	SgAd	et	erialavalikul =valiku  (SgAd  >eri+ala+valik !02_S
32555	riigieksami	eksami	riigi+eksam	02_S	SgG	et	riigieksami =eksami  (SgG  >riigi+eksam !02_S
32557	sõpradest	sõpra	sõber	24_S	PlEl	et	sõpradest =sõpra  (PlEl  >sõber !24_S
32561	missuguses	suguse	mis+sugune	10_P	SgIn	et	missuguses =suguse  (SgIn  >mis+sugune !10_P
32567	järgmiseid	järgmise	järgmine	10_A	PlP	et	järgmiseid =järgmise  (PlP  >järgmine !10_A
32568	tutvustab	tutvusta	tutvustama	27_V	IndPrSg3	et	tutvustab =tutvusta  (IndPrSg3  >tutvustama !27_V
32573	kabinetis	kabineti	kabinet	22_S	SgIn	et	kabinetis =kabineti  (SgIn  >kabinet !22_S
32586	pressiesindajana	esindaja	pressi+esindaja	01_S	SgEs	et	pressiesindajana =esindaja  (SgEs  >pressi+esindaja !01_S
32589	aktuaalsed	aktuaalse	aktuaalne	02_A	PlN	et	aktuaalsed =aktuaalse  (PlN  >aktuaalne !02_A
32591	räägis	räägi	rääk	22_S	SgIn	et	räägis =räägi  (SgIn  >rääk !22_S
32593	septembris	septembri	september	02_S	SgIn	et	septembris =septembri  (SgIn  >september !02_S
32602	laager	laager	laager	02_S	SgN	et	laager =laager  (SgN  >laager !02_S
32603	juunist	juuni	juuni	16_S	SgEl	et	juunist =juuni  (SgEl  >juuni !16_S
32610	võtsime	võt	võtma	35_V	IndIpfPl1	et	võtsime =võt  (IndIpfPl1  >võtma !35_V
32615	tohin	tohi	tohtima	28_V	IndPrSg1	et	tohin =tohi  (IndPrSg1  >tohtima !28_V
32622	erilahenduse	lahenduse	eri+lahendus	11_S	SgG	et	erilahenduse =lahenduse  (SgG  >eri+lahendus !11_S
32347	eksib	eksi	eksima	28_V	IndPrSg3	et	eksib =eksi  (IndPrSg3  >eksima !28_V
32348	grammatikaga	grammatika	grammatika	01_S	SgKom	et	grammatikaga =grammatika  (SgKom  >grammatika !01_S
32350	väärtushinnangutes	hinnangu	väärtus+hinnang	02_S	PlIn	et	väärtushinnangutes =hinnangu  (PlIn  >väärtus+hinnang !02_S
32354	kultuurides	kultuuri	kultuur	22_S	PlIn	et	kultuurides =kultuuri  (PlIn  >kultuur !22_S
32358	ütleme	ütle	ütlema	30_V	IndPrPl1	et	ütleme =ütle  (IndPrPl1  >ütlema !30_V
32364	olemasolul	olu	olemas+olu	17_S	SgAd	et	olemasolul =olu  (SgAd  >olemas+olu !17_S
32367	mõtteviisid	viisi	mõtte+viis	22_S	PlN	et	mõtteviisid =viisi  (PlN  >mõtte+viis !22_S
32371	pühenduda	pühendu	pühenduma	27_V	Inf	et	pühenduda =pühendu  (Inf  >pühenduma !27_V
32376	loogikas	loogika	loogika	01_S	SgIn	et	loogikas =loogika  (SgIn  >loogika !01_S
32377	vastandid	vastandi	vastand	02_S	PlN	et	vastandid =vastandi  (PlN  >vastand !02_S
32385	kannatlikud	kannatliku	kannatlik	25_A	PlN	et	kannatlikud =kannatliku  (PlN  >kannatlik !25_A
32388	kujutage	kujuta	kujutama	27_V	ImpPrPl2	et	kujutage =kujuta  (ImpPrPl2  >kujutama !27_V
32393	kahekeelne	keelne	kahe+keelne	02_A	SgN	et	kahekeelne =keelne  (SgN  >kahe+keelne !02_A
32395	välismaalane	maalane	välis+maalane	12?10_S	SgN	et	välismaalane =maalane  (SgN  >välis+maalane !12?10_S
32400	õpime	õpi	õppima	28_V	IndPrPl1	et	õpime =õpi  (IndPrPl1  >õppima !28_V
32402	territoorium	territoorium	territoorium	19~02_S	SgN	et	territoorium =territoorium  (SgN  >territoorium !19~02_S
32405	paganausk	usk	pagana+usk	22_S	SgN	et	paganausk =usk  (SgN  >pagana+usk !22_S
32408	idamast	mast	ida+mast	22_S	SgN	et	idamast =mast  (SgN  >ida+mast !22_S
32409	mõtteviisil	viisi	mõtte+viis	22_S	SgAd	et	mõtteviisil =viisi  (SgAd  >mõtte+viis !22_S
32412	vestluspartneri	partneri	vestlus+partner	02_S	SgG	et	vestluspartneri =partneri  (SgG  >vestlus+partner !02_S
32418	oskuseta	oskuse	oskus	11~09_S	SgAb	et	oskuseta =oskuse  (SgAb  >oskus !11~09_S
32422	artistid	artisti	artist	22_S	PlN	et	artistid =artisti  (PlN  >artist !22_S
32424	võõrkeeled	keele	võõr+keel	13_S	PlN	et	võõrkeeled =keele  (PlN  >võõr+keel !13_S
32426	teaduskonnades	konna	teadus+konn	22_S	PlIn	et	teaduskonnades =konna  (PlIn  >teadus+konn !22_S
32431	üliõpilase	õpilase	üli+õpilane	12_S	SgG	et	üliõpilase =õpilase  (SgG  >üli+õpilane !12_S
32439	haridusele	hariduse	haridus	11_S	SgAll	et	haridusele =hariduse  (SgAll  >haridus !11_S
32443	ärijuhtimise	juhtimise	äri+juhtimine	12_S	SgG	et	ärijuhtimise =juhtimise  (SgG  >äri+juhtimine !12_S
32453	õppeprogramm	programm	õppe+programm	22_S	SgN	et	õppeprogramm =programm  (SgN  >õppe+programm !22_S
32456	juured	juure	juur	13_S	PlN	et	juured =juure  (PlN  >juur !13_S
32464	nukuga	nuku	nukk	22_S	SgKom	et	nukuga =nuku  (SgKom  >nukk !22_S
32467	mänguasjadega	asja	mängu+asi	24_S	PlKom	et	mänguasjadega =asja  (PlKom  >mängu+asi !24_S
32471	klassides	klassi	klass	22_S	PlIn	et	klassides =klassi  (PlIn  >klass !22_S
32474	maailmakirjandus	kirjandus	maa+ilma+kirjandus	11_S	SgN	et	maailmakirjandus =kirjandus  (SgN  >maa+ilma+kirjandus !11_S
32476	tulengi	tule	tulema	36_V	IndPrSg1^	et	tulengi =tule  (IndPrSg1^  >tulema !36_V
32496	jõuame	jõua	jõudma	34_V	IndPrPl1	et	jõuame =jõua  (IndPrPl1  >jõudma !34_V
32504	näidiseks	näidise	näidis	09_S	SgTr	et	näidiseks =näidise  (SgTr  >näidis !09_S
32505	pärisolek	olek	päris+olek	02_S	SgN	et	pärisolek =olek  (SgN  >päris+olek !02_S
32506	nõud	nõu	nõu	26_S	PlN	et	nõud =nõu  (PlN  >nõu !26_S
32510	hindamisviis	viis	hinda+mis+viis	22_S	SgN	et	hindamisviis =viis  (SgN  >hinda+mis+viis !22_S
32516	objektiivne	objektiivne	objektiivne	02_A	SgN	et	objektiivne =objektiivne  (SgN  >objektiivne !02_A
32517	aidaks	aida	ait	22_S	SgTr	et	aidaks =aida  (SgTr  >ait !22_S
32518	biograafiaga	biograafia	biograafia	01_S	SgKom	et	biograafiaga =biograafia  (SgKom  >biograafia !01_S
32521	unistasin	unista	unistama	27_V	IndIpfSg1	et	unistasin =unista  (IndIpfSg1  >unistama !27_V
32522	igasugune	sugune	iga+sugune	10_A	SgN	et	igasugune =sugune  (SgN  >iga+sugune !10_A
32527	koduasju	asju	kodu+asi	24_S	PlP	et	koduasju =asju  (PlP  >kodu+asi !24_S
32529	saata	saat	saatma	34_V	Inf	et	saata =saat  (Inf  >saatma !34_V
32535	telekommunikatsioon	kommunikatsioon	tele+kommunikatsioon	22_S	SgN	et	telekommunikatsioon =kommunikatsioon  (SgN  >tele+kommunikatsioon !22_S
32543	tõlkjana	tõlkja	tõlkjas	02_S	SgEs	et	tõlkjana =tõlkja  (SgEs  >tõlkjas !02_S
32550	tabelit	tabeli	tabel	02_S	SgP	et	tabelit =tabeli  (SgP  >tabel !02_S
32558	firmades	firma	firma	16_S	PlIn	et	firmades =firma  (PlIn  >firma !16_S
32559	mood	mood	mood	22_S	SgN	et	mood =mood  (SgN  >mood !22_S
32563	analüüsida	analüüsi	analüüsima	28_V	Inf	et	analüüsida =analüüsi  (Inf  >analüüsima !28_V
32594	töökohade	koha	töö+koha	17_S	PlG	et	töökohade =koha  (PlG  >töö+koha !17_S
32351	käitume	käitu	käituma	27_V	IndPrPl1	et	käitume =käitu  (IndPrPl1  >käituma !27_V
32359	eluvaldkond	valdkond	elu+valdkond	22_S	SgN	et	eluvaldkond =valdkond  (SgN  >elu+valdkond !22_S
32360	mõtteviisile	viisi	mõtte+viis	22_S	SgAll	et	mõtteviisile =viisi  (SgAll  >mõtte+viis !22_S
32362	igapäevatoiminguid	toimingu	iga+päeva+toiming	02_S	PlP	et	igapäevatoiminguid =toimingu  (PlP  >iga+päeva+toiming !02_S
32363	teooriaid	teooria	teooria	01_S	PlP	et	teooriaid =teooria  (PlP  >teooria !01_S
32365	milleni	mille	mis	00_P	SgTer	et	milleni =mille  (SgTer  >mis !00_P
32366	usklikud	uskliku	usklik	25_AS	PlN	et	usklikud =uskliku  (PlN  >usklik !25_AS
32369	elutavasid	tava	elu+tava	17_S	PlP	et	elutavasid =tava  (PlP  >elu+tava !17_S
32370	tolerantne	tolerantne	tolerantne	02_A	SgN	et	tolerantne =tolerantne  (SgN  >tolerantne !02_A
32373	usundeist	usunde	usund	02_S	PlEl	et	usundeist =usunde  (PlEl  >usund !02_S
32374	rituaalidest	rituaali	rituaal	22_S	PlEl	et	rituaalidest =rituaali  (PlEl  >rituaal !22_S
32379	teame	tea	teadma	34_V	IndPrPl1	et	teame =tea  (IndPrPl1  >teadma !34_V
32387	kultuuriesindajad	esindaja	kultuuri+esindaja	01_S	PlN	et	kultuuriesindajad =esindaja  (PlN  >kultuuri+esindaja !01_S
32397	harjub	harju	harjuma	27_V	IndPrSg3	et	harjub =harju  (IndPrSg3  >harjuma !27_V
32413	sõnumi	sõnumi	sõnum	02_S	SgG	et	sõnumi =sõnumi  (SgG  >sõnum !02_S
32416	allati	ati	all+att	22_S	SgG	et	allati =ati  (SgG  >all+att !22_S
32421	keeleveaks	vea	keele+viga	18_S	SgTr	et	keeleveaks =vea  (SgTr  >keele+viga !18_S
32428	kõrgkoolid	kooli	kõrg+kool	22_S	PlN	et	kõrgkoolid =kooli  (PlN  >kõrg+kool !22_S
32432	missugusel	suguse	mis+sugune	10_P	SgAd	et	missugusel =suguse  (SgAd  >mis+sugune !10_P
32434	rektor	rektor	rektor	02_S	SgN	et	rektor =rektor  (SgN  >rektor !02_S
32442	teega	tee	tee	26_S	SgKom	et	teega =tee  (SgKom  >tee !26_S
32444	ärijuhtimiseks	juhtimise	äri+juhtimine	12_S	SgTr	et	ärijuhtimiseks =juhtimise  (SgTr  >äri+juhtimine !12_S
32448	vajadus	vajadus	vajadus	11_S	SgN	et	vajadus =vajadus  (SgN  >vajadus !11_S
32455	ükskõik	ükskõik	üks+kõik	41_D	ID	et	ükskõik =ükskõik  (ID  >üks+kõik !41_D
32458	dekaanil	dekaani	dekaan	22_S	SgAd	et	dekaanil =dekaani  (SgAd  >dekaan !22_S
32469	üheksandast	üheksanda	üheksas	02_O	SgEl	et	üheksandast =üheksanda  (SgEl  >üheksas !02_O
32472	ilukirjandus	kirjandus	ilu+kirjandus	11_S	SgN	et	ilukirjandus =kirjandus  (SgN  >ilu+kirjandus !11_S
32478	professionaalset	professionaalse	professionaalne	02_A	SgP	et	professionaalset =professionaalse  (SgP  >professionaalne !02_A
32482	rõõmuks	rõõmu	rõõm	22_S	SgTr	et	rõõmuks =rõõmu  (SgTr  >rõõm !22_S
32483	kasvatusteadused	teaduse	kasvatus+teadus	11~09_S	PlN	et	kasvatusteadused =teaduse  (PlN  >kasvatus+teadus !11~09_S
32484	eripedagoogikat	pedagoogika	eri+pedagoogika	01_S	SgP	et	eripedagoogikat =pedagoogika  (SgP  >eri+pedagoogika !01_S
32485	koormusega	koormuse	koormus	11~09_S	SgKom	et	koormusega =koormuse  (SgKom  >koormus !11~09_S
32486	ainet	aine	aine	06_S	SgP	et	ainet =aine  (SgP  >aine !06_S
32487	koputada	koputa	koputama	27_V	Inf	et	koputada =koputa  (Inf  >koputama !27_V
32537	tulemuseni	tulemuse	tulemus	11_S	SgTer	et	tulemuseni =tulemuse  (SgTer  >tulemus !11_S
32538	dokumente	dokumente	dokument	22_S	PlP	et	dokumente =dokumente  (PlP  >dokument !22_S
32541	magistri	magistri	magister	02_S	SgG	et	magistri =magistri  (SgG  >magister !02_S
32542	tõlkjaks	tõlkja	tõlkjas	02_S	SgTr	et	tõlkjaks =tõlkja  (SgTr  >tõlkjas !02_S
32544	tõlgin	tõlgi	tõlkima	28_V	IndPrSg1	et	tõlgin =tõlgi  (IndPrSg1  >tõlkima !28_V
32546	kaasaaeglased	aeglase	kaasa+aeglane	12?10_A	PlN	et	kaasaaeglased =aeglase  (PlN  >kaasa+aeglane !12?10_A
32554	motivatsioonid	motivatsiooni	motivatsioon	22_S	PlN	et	motivatsioonid =motivatsiooni  (PlN  >motivatsioon !22_S
32562	valis	vali	valima	27_V	IndIpfSg3	et	valis =vali  (IndIpfSg3  >valima !27_V
32564	faktid	fakti	fakt	22_S	PlN	et	faktid =fakti  (PlN  >fakt !22_S
32574	siht	siht	siht	22_S	SgN	et	siht =siht  (SgN  >siht !22_S
32575	tausttegur	tegur	taust+tegur	02_S	SgN	et	tausttegur =tegur  (SgN  >taust+tegur !02_S
32576	valikul	valiku	valik	02_S	SgAd	et	valikul =valiku  (SgAd  >valik !02_S
32581	sõpradelt	sõpra	sõber	24_S	PlAbl	et	sõpradelt =sõpra  (PlAbl  >sõber !24_S
32582	tuttavatelt	tuttava	tuttav	02_AS	PlAbl	et	tuttavatelt =tuttava  (PlAbl  >tuttav !02_AS
32597	vaike	vaike	vaik	22_S	PlP	et	vaike =vaike  (PlP  >vaik !22_S
32598	veesport	sport	vee+sport	22_S	SgN	et	veesport =sport  (SgN  >vee+sport !22_S
32600	maastikumäng	mäng	maas+tiku+mäng	22_S	SgN	et	maastikumäng =mäng  (SgN  >maas+tiku+mäng !22_S
32611	magab	maga	magama	27_V	IndPrSg3	et	magab =maga  (IndPrSg3  >magama !27_V
32612	hundikoer	koer	hundi+koer	23?22_SA	SgN	et	hundikoer =koer  (SgN  >hundi+koer !23?22_SA
32427	eraülikoolid	kooli	era+üli+kool	22_S	PlN	et	eraülikoolid =kooli  (PlN  >era+üli+kool !22_S
32429	üheksandal	üheksanda	üheksas	02_O	SgAd	et	üheksandal =üheksanda  (SgAd  >üheksas !02_O
32435	probleemil	probleemi	probleem	22_S	SgAd	et	probleemil =probleemi  (SgAd  >probleem !22_S
32441	oleksin	ole	olema	36_V	KndPrSg1	et	oleksin =ole  (KndPrSg1  >olema !36_V
32449	tutvuma	tutvu	tutvuma	27_V	Sup	et	tutvuma =tutvu  (Sup  >tutvuma !27_V
32450	tv-s	tv	tv	xx_Q	SgIn	et	tv-s =tv  (SgIn  >tv !xx_Q
32452	põhiline	põhiline	põhiline	12_A	SgN	et	põhiline =põhiline  (SgN  >põhiline !12_A
32457	rühmaga	rühma	rühm	22_S	SgKom	et	rühmaga =rühma  (SgKom  >rühm !22_S
32461	õppeaastat	aasta	õppe+aasta	01_S	SgP	et	õppeaastat =aasta  (SgP  >õppe+aasta !01_S
32462	maade	maa	maa	26_S	PlG	et	maade =maa  (PlG  >maa !26_S
32463	tähtsaid	tähtsa	tähtis	02_A	PlP	et	tähtsaid =tähtsa  (PlP  >tähtis !02_A
32465	töötamas	tööta	töötama	27_V	SupIn	et	töötamas =tööta  (SupIn  >töötama !27_V
32466	teadmused	teadmuse	teadmus	11~09_S	PlN	et	teadmused =teadmuse  (PlN  >teadmus !11~09_S
32470	teadmusi	teadmusi	teadmus	11_S	PlP	et	teadmusi =teadmusi  (PlP  >teadmus !11_S
32473	teaduskirjandus	kirjandus	teadus+kirjandus	11_S	SgN	et	teaduskirjandus =kirjandus  (SgN  >teadus+kirjandus !11_S
32475	meelsasti	meelsasti	meelsasti	41_D	ID	et	meelsasti =meelsasti  (ID  >meelsasti !41_D
32481	magistritööst	töö	magistri+töö	26_S	SgEl	et	magistritööst =töö  (SgEl  >magistri+töö !26_S
32489	tehta	teh	tegema	28_V	IndPrIps_	et	tehta =teh  (IndPrIps_  >tegema !28_V
32490	esmakursuslasena	kursuslase	esma+kursuslane	12_S	SgEs	et	esmakursuslasena =kursuslase  (SgEs  >esma+kursuslane !12_S
32492	õigeks	õige	õige	01_A	SgTr	et	õigeks =õige  (SgTr  >õige !01_A
32498	suurendab	suurenda	suurendama	27_V	IndPrSg3	et	suurendab =suurenda  (IndPrSg3  >suurendama !27_V
32499	kuulturi	turi	kuul+turi	24_S	SgN	et	kuulturi =turi  (SgN  >kuul+turi !24_S
32500	kellena	kelle	kes	00_P	SgEs	et	kellena =kelle  (SgEs  >kes !00_P
32502	lasteajas	aja	laste+aeg	22_S	SgIn	et	lasteajas =aja  (SgIn  >laste+aeg !22_S
32507	arvestades	arvesta	arvestama	27_V	Ger	et	arvestades =arvesta  (Ger  >arvestama !27_V
32509	protsessist	protsessi	protsess	22_S	SgEl	et	protsessist =protsessi  (SgEl  >protsess !22_S
32512	millesse	mille	mis	00_P	SgIll	et	millesse =mille  (SgIll  >mis !00_P
32513	ebameeldivaks	meeldiva	eba+meeldiv	02_A	SgTr	et	ebameeldivaks =meeldiva  (SgTr  >eba+meeldiv !02_A
32520	valiks	vali	valima	27_V	KndPrPs	et	valiks =vali  (KndPrPs  >valima !27_V
32534	sisseastumise	astumise	sisse+astumine	12_S	SgG	et	sisseastumise =astumise  (SgG  >sisse+astumine !12_S
32536	ülikoolidesse	kooli	üli+kool	22_S	PlIll	et	ülikoolidesse =kooli  (PlIll  >üli+kool !22_S
32539	enesekindlustatud	kindlustatu	enese+kindlustatu	01_S	PlN	et	enesekindlustatud =kindlustatu  (PlN  >enese+kindlustatu !01_S
32540	haridusteel	tee	haridus+tee	26_S	SgAd	et	haridusteel =tee  (SgAd  >haridus+tee !26_S
32548	konsulteerida	konsulteeri	konsulteerima	28_V	Inf	et	konsulteerida =konsulteeri  (Inf  >konsulteerima !28_V
32552	agronoom	agronoom	agronoom	22_S	SgN	et	agronoom =agronoom  (SgN  >agronoom !22_S
32566	lõpetame	lõpeta	lõpetama	27_V	IndPrPl1	et	lõpetame =lõpeta  (IndPrPl1  >lõpetama !27_V
32570	ajakirjandusele	kirjanduse	aja+kirjandus	11_S	SgAll	et	ajakirjandusele =kirjanduse  (SgAll  >aja+kirjandus !11_S
32579	raadiole	raadio	raadio	01_S	SgAll	et	raadiole =raadio  (SgAll  >raadio !01_S
32580	lehele	lehe	leht	22_S	SgAll	et	lehele =lehe  (SgAll  >leht !22_S
32584	korrektorina	korrektori	korrektor	02_S	SgEs	et	korrektorina =korrektori  (SgEs  >korrektor !02_S
32588	suhete	suhe	suhe	06_S	PlG	et	suhete =suhe  (PlG  >suhe !06_S
32599	korvpall	pall	korv+pall	22_S	SgN	et	korvpall =pall  (SgN  >korv+pall !22_S
32605	juulis	juuli	juuli	16_S	SgIn	et	juulis =juuli  (SgIn  >juuli !16_S
32606	suplesin	suple	suplema	30_V	IndIpfSg1	et	suplesin =suple  (IndIpfSg1  >suplema !30_V
32608	jões	jõe	jõgi	21_S	SgIn	et	jões =jõe  (SgIn  >jõgi !21_S
32609	haug	haug	haug	22_S	SgN	et	haug =haug  (SgN  >haug !22_S
32617	rinnaga	rinna	rind	22_S	SgKom	et	rinnaga =rinna  (SgKom  >rind !22_S
32618	arendusprojektid	projekti	arendus+projekt	22_S	PlN	et	arendusprojektid =projekti  (PlN  >arendus+projekt !22_S
32620	helistada	helista	helistama	27_V	Inf	et	helistada =helista  (Inf  >helistama !27_V
32628	joal	joa	juga	18_S	SgAd	et	joal =joa  (SgAd  >juga !18_S
32641	lasteaedu	aedu	laste+aed	22_S	PlP	et	lasteaedu =aedu  (PlP  >laste+aed !22_S
32643	vägivald	vald	vägi+vald	22_S	SgN	et	vägivald =vald  (SgN  >vägi+vald !22_S
32650	suitsukonisid	koni	suitsu+koni	17_S	PlP	et	suitsukonisid =koni  (PlP  >suitsu+koni !17_S
32652	vähendab	vähenda	vähendama	27_V	IndPrSg3	et	vähendab =vähenda  (IndPrSg3  >vähendama !27_V
32595	eludeviis	deviis	elu+deviis	22_S	SgN	et	eludeviis =deviis  (SgN  >elu+deviis !22_S
32601	laagrit	laagri	laager	02_S	SgP	et	laagrit =laagri  (SgP  >laager !02_S
32604	turvafirmas	firma	turva+firma	16_S	SgIn	et	turvafirmas =firma  (SgIn  >turva+firma !16_S
32607	vanaisaga	isa	vana+isa	17_S	SgKom	et	vanaisaga =isa  (SgKom  >vana+isa !17_S
32621	vajadusel	vajaduse	vajadus	11_S	SgAd	et	vajadusel =vajaduse  (SgAd  >vajadus !11_S
32636	järgmist	järgmis	järgmine	12?10_A	SgP	et	järgmist =järgmis  (SgP  >järgmine !12?10_A
32638	valgemeri	meri	valge+meri	20_S	SgN	et	valgemeri =meri  (SgN  >valge+meri !20_S
32642	lohakad	lohaka	lohakas	02_A	PlN	et	lohakad =lohaka  (PlN  >lohakas !02_A
32654	ebaoskus	oskus	eba+oskus	11~09_S	SgN	et	ebaoskus =oskus  (SgN  >eba+oskus !11~09_S
32656	reageerima	reageeri	reageerima	28_V	Sup	et	reageerima =reageeri  (Sup  >reageerima !28_V
32667	missugust	sugus	mis+sugune	10_P	SgP	et	missugust =sugus  (SgP  >mis+sugune !10_P
32672	trükkida	trükki	trükkima	28_V	Inf	et	trükkida =trükki  (Inf  >trükkima !28_V
32674	hiiliks	hiili	hiilima	28_V	KndPrPs	et	hiiliks =hiili  (KndPrPs  >hiilima !28_V
32676	tantsiga	tantsi	tants	22_S	SgKom	et	tantsiga =tantsi  (SgKom  >tants !22_S
32677	ebavõimalik	võimalik	eba+võimalik	25_A	SgN	et	ebavõimalik =võimalik  (SgN  >eba+võimalik !25_A
32678	korjama	korja	korjama	29_V	Sup	et	korjama =korja  (Sup  >korjama !29_V
32684	näituse	näituse	näitus	11~09_S	SgG	et	näituse =näituse  (SgG  >näitus !11~09_S
32690	aitama	aita	aitama	29_V	Sup	et	aitama =aita  (Sup  >aitama !29_V
32691	telefoninumbrit	numbri	telefoni+number	02_S	SgP	et	telefoninumbrit =numbri  (SgP  >telefoni+number !02_S
32692	telefoninumbri	numbri	telefoni+number	02_S	SgG	et	telefoninumbri =numbri  (SgG  >telefoni+number !02_S
32695	kahtles	kahtle	kahtlema	30_V	IndIpfSg3	et	kahtles =kahtle  (IndIpfSg3  >kahtlema !30_V
32701	valmistusin	valmistu	valmistuma	27_V	IndIpfSg1	et	valmistusin =valmistu  (IndIpfSg1  >valmistuma !27_V
32705	teenin	teeni	teenima	28_V	IndPrSg1	et	teenin =teeni  (IndPrSg1  >teenima !28_V
32723	eelistas	eelista	eelistama	27_V	IndIpfSg3	et	eelistas =eelista  (IndIpfSg3  >eelistama !27_V
32731	kadestama	kadesta	kadestama	27_V	Sup	et	kadestama =kadesta  (Sup  >kadestama !27_V
32739	harutada	haruta	harutama	27_V	Inf	et	harutada =haruta  (Inf  >harutama !27_V
32741	mööbli	mööbli	mööbel	02_S	SgG	et	mööbli =mööbli  (SgG  >mööbel !02_S
32751	mõnusa	mõnusa	mõnus	02_A	SgG	et	mõnusa =mõnusa  (SgG  >mõnus !02_A
32758	vahepeale	pea	vahe+pea	26_S	SgAll	et	vahepeale =pea  (SgAll  >vahe+pea !26_S
32759	läbisin	läbi	läbima	27_V	IndIpfSg1	et	läbisin =läbi  (IndIpfSg1  >läbima !27_V
32761	toredate	toreda	tore	02_A	PlG	et	toredate =toreda  (PlG  >tore !02_A
32775	koristasin	korista	koristama	27_V	IndIpfSg1	et	koristasin =korista  (IndIpfSg1  >koristama !27_V
32783	üürile	üüri	üür	22_S	SgAll	et	üürile =üüri  (SgAll  >üür !22_S
32784	elangi	ela	elama	27_V	IndPrSg1^	et	elangi =ela  (IndPrSg1^  >elama !27_V
32790	komandeering	komandeering	komandeering	02_S	SgN	et	komandeering =komandeering  (SgN  >komandeering !02_S
32793	ma-	ma	ma	00_P	SgN	et	ma- =ma  (SgN  >ma !00_P
32796	hilinema	hiline	hilinema	27_V	Sup	et	hilinema =hiline  (Sup  >hilinema !27_V
32799	mitmuse	mitmuse	mitmus	11~09_S	SgG	et	mitmuse =mitmuse  (SgG  >mitmus !11~09_S
32815	hilisõhtuni	õhtu	hilis+õhtu	01_S	SgTer	et	hilisõhtuni =õhtu  (SgTer  >hilis+õhtu !01_S
32823	komandeeringusse	komandeeringu	komandeering	02_S	SgIll	et	komandeeringusse =komandeeringu  (SgIll  >komandeering !02_S
32826	jõed	jõe	jõgi	21_S	PlN	et	jõed =jõe  (PlN  >jõgi !21_S
32829	pangakaardiga	kaardi	panga+kaart	22_S	SgKom	et	pangakaardiga =kaardi  (SgKom  >panga+kaart !22_S
32837	võõredes	ede	võõr+ede	16_S	SgIn	et	võõredes =ede  (SgIn  >võõr+ede !16_S
32861	teadlikud	teadliku	teadlik	25_A	PlN	et	teadlikud =teadliku  (PlN  >teadlik !25_A
32864	katastroofidest	katastroofi	katastroof	22_S	PlEl	et	katastroofidest =katastroofi  (PlEl  >katastroof !22_S
32866	eseme	eseme	ese	04_S	SgG	et	eseme =eseme  (SgG  >ese !04_S
32871	tohiks	tohi	tohtima	28_V	KndPrPs	et	tohiks =tohi  (KndPrPs  >tohtima !28_V
32874	luksusi	luksusi	luksus	11_S	PlP	et	luksusi =luksusi  (PlP  >luksus !11_S
32878	otseühendus	ühendus	otse+ühendus	11_S	SgN	et	otseühendus =ühendus  (SgN  >otse+ühendus !11_S
32881	tingimusteta	tingimus	tingimus	11_S	PlAb	et	tingimusteta =tingimus  (PlAb  >tingimus !11_S
32886	toimubki	toimu	toimuma	27_V	IndPrSg3^	et	toimubki =toimu  (IndPrSg3^  >toimuma !27_V
32888	närvesööv	sööv	närve+sööv	02_A	SgN	et	närvesööv =sööv  (SgN  >närve+sööv !02_A
32894	võtaks	võta	võtma	35_V	KndPrPs	et	võtaks =võta  (KndPrPs  >võtma !35_V
32896	lubada	luba	lubama	27_V	Inf	et	lubada =luba  (Inf  >lubama !27_V
32614	lõõgastasin	lõõgasta	lõõgastama	27_V	IndIpfSg1	et	lõõgastasin =lõõgasta  (IndIpfSg1  >lõõgastama !27_V
32626	moodustas	moodusta	moodustama	27_V	IndIpfSg3	et	moodustas =moodusta  (IndIpfSg3  >moodustama !27_V
32635	lained	laine	laine	06_S	PlN	et	lained =laine  (PlN  >laine !06_S
32640	lasteaed	aed	laste+aed	22_S	SgN	et	lasteaed =aed  (SgN  >laste+aed !22_S
32651	kahjulik	kahjulik	kahjulik	25_A	SgN	et	kahjulik =kahjulik  (SgN  >kahjulik !25_A
32658	lasteaedades	aeda	laste+aed	22_S	PlIn	et	lasteaedades =aeda  (PlIn  >laste+aed !22_S
32660	politseisse	politsei	politsei	26_S	SgIll	et	politseisse =politsei  (SgIll  >politsei !26_S
32671	mõnesid	mõne	mõni	20_P	PlP	et	mõnesid =mõne  (PlP  >mõni !20_P
32679	laulumäng	mäng	laulu+mäng	22_S	SgN	et	laulumäng =mäng  (SgN  >laulu+mäng !22_S
32683	mõlema	mõlema	mõlema	02_P	SgG	et	mõlema =mõlema  (SgG  >mõlema !02_P
32689	kohtuma	kohtu	kohtuma	27_V	Sup	et	kohtuma =kohtu  (Sup  >kohtuma !27_V
32698	kurvaks	kurva	kurb	22_A	SgTr	et	kurvaks =kurva  (SgTr  >kurb !22_A
32706	rõõmutunne	tunne	rõõmu+tunne	06_S	SgN	et	rõõmutunne =tunne  (SgN  >rõõmu+tunne !06_S
32708	eritunni	tunni	eri+tund	22_S	SgG	et	eritunni =tunni  (SgG  >eri+tund !22_S
32710	kunstiakadeemiasse	akadeemia	kunsti+akadeemia	01_S	SgIll	et	kunstiakadeemiasse =akadeemia  (SgIll  >kunsti+akadeemia !01_S
32716	kardis	kardi	kart	22_S	SgIn	et	kardis =kardi  (SgIn  >kart !22_S
32724	voodisse	voodi	voodi	01_S	SgIll	et	voodisse =voodi  (SgIll  >voodi !01_S
32728	hambad	hamba	hammas	07_S	PlN	et	hambad =hamba  (PlN  >hammas !07_S
32733	kiitma	kiit	kiitma	34_V	Sup	et	kiitma =kiit  (Sup  >kiitma !34_V
32745	kullalt	kulla	kuld	22_S	SgAbl	et	kullalt =kulla  (SgAbl  >kuld !22_S
32746	madalad	madala	madal	02_AS	PlN	et	madalad =madala  (PlN  >madal !02_AS
32747	kauba	kauba	kaup	22_S	SgG	et	kauba =kauba  (SgG  >kaup !22_S
32753	mittevajalikud	vajaliku	mitte+vajalik	25_A	PlN	et	mittevajalikud =vajaliku  (PlN  >mitte+vajalik !25_A
32766	kummalised	kummalise	kummaline	12_A	PlN	et	kummalised =kummalise  (PlN  >kummaline !12_A
32768	eskalaatoris	eskalaatori	eskalaator	02_S	SgIn	et	eskalaatoris =eskalaatori  (SgIn  >eskalaator !02_S
32778	töökaaslased	kaaslase	töö+kaaslane	12?10_S	PlN	et	töökaaslased =kaaslase  (PlN  >töö+kaaslane !12?10_S
32785	kevadsemestri	semestri	kevad+semester	02_S	SgG	et	kevadsemestri =semestri  (SgG  >kevad+semester !02_S
32789	abistan	abista	abistama	27_V	IndPrSg1	et	abistan =abista  (IndPrSg1  >abistama !27_V
32797	järgmisi	järgmisi	järgmine	12_A	PlP	et	järgmisi =järgmisi  (PlP  >järgmine !12_A
32813	jahtub	jahtu	jahtuma	27_V	IndPrSg3	et	jahtub =jahtu  (IndPrSg3  >jahtuma !27_V
32814	keetma	keet	keetma	34_V	Sup	et	keetma =keet  (Sup  >keetma !34_V
32817	jahtus	jahtu	jahtuma	27_V	IndIpfSg3	et	jahtus =jahtu  (IndIpfSg3  >jahtuma !27_V
32827	järved	järve	järv	22_S	PlN	et	järved =järve  (PlN  >järv !22_S
32842	keetsin	keet	keetma	34_V	IndIpfSg1	et	keetsin =keet  (IndIpfSg1  >keetma !34_V
32847	sünnib	sünni	sündima	28_V	IndPrSg3	et	sünnib =sünni  (IndPrSg3  >sündima !28_V
32848	armastusromaanideta	romaani	armastus+romaan	22_S	PlAb	et	armastusromaanideta =romaani  (PlAb  >armastus+romaan !22_S
32850	tõotatakse	tõota	tõotama	27_V	IndPrIps	et	tõotatakse =tõota  (IndPrIps  >tõotama !27_V
32854	ohud	ohu	oht	22_S	PlN	et	ohud =ohu  (PlN  >oht !22_S
32856	trennid	trenni	trenn	22_S	PlN	et	trennid =trenni  (PlN  >trenn !22_S
32858	surfilaagrist	laagri	surfi+laager	02_S	SgEl	et	surfilaagrist =laagri  (SgEl  >surfi+laager !02_S
32862	hädaohtudest	ohtu	häda+oht	22_S	PlEl	et	hädaohtudest =ohtu  (PlEl  >häda+oht !22_S
32863	vallandudes	vallandu	vallanduma	27_V	Ger	et	vallandudes =vallandu  (Ger  >vallanduma !27_V
32867	kahjulikke	kahjulikke	kahjulik	25_A	PlP	et	kahjulikke =kahjulikke  (PlP  >kahjulik !25_A
32870	ajendil	ajendi	ajend	02_S	SgAd	et	ajendil =ajendi  (SgAd  >ajend !02_S
32877	pidev	pidev	pidev	02_A	SgN	et	pidev =pidev  (SgN  >pidev !02_A
32879	elektrile	elektri	elekter	02_S	SgAll	et	elektrile =elektri  (SgAll  >elekter !02_S
32884	kiviaja	aja	kivi+aeg	22_S	SgG	et	kiviaja =aja  (SgG  >kivi+aeg !22_S
32890	kraanist	kraani	kraan	22_S	SgEl	et	kraanist =kraani  (SgEl  >kraan !22_S
32897	rännakute	rännaku	rännak	02_S	PlG	et	rännakute =rännaku  (PlG  >rännak !02_S
32901	postitõllaga	tõlla	posti+tõld	22_S	SgKom	et	postitõllaga =tõlla  (SgKom  >posti+tõld !22_S
32908	aparaadid	aparaadi	aparaat	22_S	PlN	et	aparaadid =aparaadi  (PlN  >aparaat !22_S
32945	nõukogulike	kogulike	nõu+kogulik	25_A	PlG	et	nõukogulike =kogulike  (PlG  >nõu+kogulik !25_A
32947	lääne-euroopaga	euroopa	lääne-euroopa	01_H	SgKom	et	lääne-euroopaga =euroopa  (SgKom  >lääne-euroopa !01_H
32948	venemaaga	maa	vene+maa	26_S	SgKom	et	venemaaga =maa  (SgKom  >vene+maa !26_S
32624	taldrik	taldrik	taldrik	02_S	SgN	et	taldrik =taldrik  (SgN  >taldrik !02_S
32629	mujal	mujal	mujal	41_D	ID	et	mujal =mujal  (ID  >mujal !41_D
32631	avameres	mere	ava+meri	20_S	SgIn	et	avameres =mere  (SgIn  >ava+meri !20_S
32632	tuuled	tuule	tuul	13_S	PlN	et	tuuled =tuule  (PlN  >tuul !13_S
32633	kõvad	kõva	kõva	17_A	PlN	et	kõvad =kõva  (PlN  >kõva !17_A
32637	teenisin	teeni	teenima	28_V	IndIpfSg1	et	teenisin =teeni  (IndIpfSg1  >teenima !28_V
32639	pisiasjadele	asja	pisi+asi	24_S	PlAll	et	pisiasjadele =asja  (PlAll  >pisi+asi !24_S
32644	uuringutes	uuringu	uuring	02_S	PlIn	et	uuringutes =uuringu  (PlIn  >uuring !02_S
32645	vargused	varguse	vargus	11~09_S	PlN	et	vargused =varguse  (PlN  >vargus !11~09_S
32648	jätavad	jäta	jätma	35_V	IndPrPl3	et	jätavad =jäta  (IndPrPl3  >jätma !35_V
32655	situatsioonidele	situatsiooni	situatsioon	22_S	PlAll	et	situatsioonidele =situatsiooni  (PlAll  >situatsioon !22_S
32661	personal	personal	personal	19_S	SgN	et	personal =personal  (SgN  >personal !19_S
32665	ahjus	ahju	ahi	24_S	SgIn	et	ahjus =ahju  (SgIn  >ahi !24_S
32666	lõhn	lõhn	lõhn	22_S	SgN	et	lõhn =lõhn  (SgN  >lõhn !22_S
32675	telefonil	telefoni	telefon	19_S	SgAd	et	telefonil =telefoni  (SgAd  >telefon !19_S
32680	mõlemate	mõlema	mõlema	02_P	PlG	et	mõlemate =mõlema  (PlG  >mõlema !02_P
32685	millise	millise	milline	10_P	SgG	et	millise =millise  (SgG  >milline !10_P
32693	suitsetakse	suitse	suitsema	28_V	IndPrIps	et	suitsetakse =suitse  (IndPrIps  >suitsema !28_V
32703	ajakirjandusega	kirjanduse	aja+kirjandus	11_S	SgKom	et	ajakirjandusega =kirjanduse  (SgKom  >aja+kirjandus !11_S
32704	elul	elu	elu	17_S	SgAd	et	elul =elu  (SgAd  >elu !17_S
32713	ümberjutustus	jutustus	ümber+jutustus	11_S	SgN	et	ümberjutustus =jutustus  (SgN  >ümber+jutustus !11_S
32717	ründab	ründa	ründama	29_V	IndPrSg3	et	ründab =ründa  (IndPrSg3  >ründama !29_V
32719	niipea	niipea	nii+pea	41_D	ID	et	niipea =niipea  (ID  >nii+pea !41_D
32722	uskus	usku	uskuma	28_V	IndIpfSg3	et	uskus =usku  (IndIpfSg3  >uskuma !28_V
32729	korvist	korvi	korv	22_S	SgEl	et	korvist =korvi  (SgEl  >korv !22_S
32748	kvaliteediga	kvaliteedi	kvaliteet	22_S	SgKom	et	kvaliteediga =kvaliteedi  (SgKom  >kvaliteet !22_S
32750	nurgad	nurga	nurk	22_S	PlN	et	nurgad =nurga  (PlN  >nurk !22_S
32755	järjekord	kord	järje+kord	22_S	SgN	et	järjekord =kord  (SgN  >järje+kord !22_S
32767	metrooga	metroo	metroo	26_S	SgKom	et	metrooga =metroo  (SgKom  >metroo !26_S
32770	hapukurke	kurke	hapu+kurk	22_S	PlP	et	hapukurke =kurke  (PlP  >hapu+kurk !22_S
32771	õunu	õunu	õun	23?22_S	PlP	et	õunu =õunu  (PlP  >õun !23?22_S
32773	tiitel	tiitel	tiitel	02_S	SgN	et	tiitel =tiitel  (SgN  >tiitel !02_S
32776	jooksmas	jooks	jooksma	32_V	SupIn	et	jooksmas =jooks  (SupIn  >jooksma !32_V
32777	kitsaid	kitsa	kitsas	07_A	PlP	et	kitsaid =kitsa  (PlP  >kitsas !07_A
32787	koristab	korista	koristama	27_V	IndPrSg3	et	koristab =korista  (IndPrSg3  >koristama !27_V
32798	tegusõnu	sõnu	tegu+sõna	17_S	PlP	et	tegusõnu =sõnu  (PlP  >tegu+sõna !17_S
32802	metsad	metsa	mets	22_S	PlN	et	metsad =metsa  (PlN  >mets !22_S
32806	liigse	liigse	liigne	02_A	SgG	et	liigse =liigse  (SgG  >liigne !02_A
32824	külastama	külasta	külastama	27_V	Sup	et	külastama =külasta  (Sup  >külastama !27_V
32830	komandeeringus	komandeeringu	komandeering	02_S	SgIn	et	komandeeringus =komandeeringu  (SgIn  >komandeering !02_S
32838	küllas	külla	küll	22_S	SgIn	et	küllas =külla  (SgIn  >küll !22_S
32841	mäkke	mäkke	mägi	21_S	SgAdt	et	mäkke =mäkke  (SgAdt  >mägi !21_S
32844	sajand	sajand	sajand	02_S	SgN	et	sajand =sajand  (SgN  >sajand !02_S
32846	leiutised	leiutise	leiutis	11_S	PlN	et	leiutised =leiutise  (PlN  >leiutis !11_S
32849	pisaraid	pisara	pisar	02_S	PlP	et	pisaraid =pisara  (PlP  >pisar !02_S
32851	kindlat	kindla	kindel	02_A	SgP	et	kindlat =kindla  (SgP  >kindel !02_A
32853	mõistet	mõiste	mõiste	06_S	SgP	et	mõistet =mõiste  (SgP  >mõiste !06_S
32869	juhtudest	juhtu	juht	22_S	PlEl	et	juhtudest =juhtu  (PlEl  >juht !22_S
32873	tänapäevainimene	inimene	täna+päeva+inimene	12_S	SgN	et	tänapäevainimene =inimene  (SgN  >täna+päeva+inimene !12_S
32882	praegusaeg	aeg	praegus+aeg	22_S	SgN	et	praegusaeg =aeg  (SgN  >praegus+aeg !22_S
32885	kõrgepinget	pinge	kõrge+pinge	06_S	SgP	et	kõrgepinget =pinge  (SgP  >kõrge+pinge !06_S
32895	lihtinimesed	inimese	liht+inimene	12_S	PlN	et	lihtinimesed =inimese  (PlN  >liht+inimene !12_S
32898	puudulik	puudulik	puudulik	25_A	SgN	et	puudulik =puudulik  (SgN  >puudulik !25_A
32911	lõbuks	lõbu	lõbu	17_S	SgTr	et	lõbuks =lõbu  (SgTr  >lõbu !17_S
32921	televiisorita	televiisori	televiisor	02_S	SgAb	et	televiisorita =televiisori  (SgAb  >televiisor !02_S
32922	autota	auto	auto	16_S	SgAb	et	autota =auto  (SgAb  >auto !16_S
32627	nõval	nõva	nõva	17_S	SgAd	et	nõval =nõva  (SgAd  >nõva !17_S
32630	purjelauaga	laua	purje+laud	22_S	SgKom	et	purjelauaga =laua  (SgKom  >purje+laud !22_S
32634	sügise	sügise	sügis	09_S	SgG	et	sügise =sügise  (SgG  >sügis !09_S
32646	vandalism	vandalism	vandalism	22_S	SgN	et	vandalism =vandalism  (SgN  >vandalism !22_S
32647	narkomaanid	narkomaani	narkomaan	22_S	PlN	et	narkomaanid =narkomaani  (PlN  >narkomaan !22_S
32649	süstlaid	süstla	süstal	08_S	PlP	et	süstlaid =süstla  (PlP  >süstal !08_S
32657	lasteaiade	aia	laste+ai	22_S	PlG	et	lasteaiade =aia  (PlG  >laste+ai !22_S
32659	lasteaiatöötajad	töötaja	laste+aia+töötaja	01_S	PlN	et	lasteaiatöötajad =töötaja  (PlN  >laste+aia+töötaja !01_S
32662	järgneb	järgne	järgnema	27_V	IndPrSg3	et	järgneb =järgne  (IndPrSg3  >järgnema !27_V
32681	kätega	kä	käsi	15_S	PlKom	et	kätega =kä  (PlKom  >käsi !15_S
32687	hinne	hinne	hinne	06_S	SgN	et	hinne =hinne  (SgN  >hinne !06_S
32694	suitsetatakse	suitseta	suitsetama	27_V	IndPrIps	et	suitsetatakse =suitseta  (IndPrIps  >suitsetama !27_V
32696	kahtles	kahtle	kahtlema	30_V	IndIpfSg3	et	kahtles =kahtle  (IndIpfSg3  >kahtlema !30_V
32707	ootusärev	ärev	ootus+ärev	02_A	SgN	et	ootusärev =ärev  (SgN  >ootus+ärev !02_A
32711	treeningus	treeningu	treening	02_S	SgIn	et	treeningus =treeningu  (SgIn  >treening !02_S
32712	kogemusse	kogemus	kogemus	11_S	SgAdt	et	kogemusse =kogemus  (SgAdt  >kogemus !11_S
32714	tuletas	tuleta	tuletama	27_V	IndIpfSg3	et	tuletas =tuleta  (IndIpfSg3  >tuletama !27_V
32718	silla	silla	sild	22_S	SgG	et	silla =silla  (SgG  >sild !22_S
32721	su	su	sa	00_P	SgG	et	su =su  (SgG  >sa !00_P
32734	ulguma	ulgu	ulguma	28_V	Sup	et	ulguma =ulgu  (Sup  >ulguma !28_V
32738	tapis	tapi	tapp	22_S	SgIn	et	tapis =tapi  (SgIn  >tapp !22_S
32744	värv	värv	värv	22_S	SgN	et	värv =värv  (SgN  >värv !22_S
32749	firmade	firma	firma	16_S	PlG	et	firmade =firma  (PlG  >firma !16_S
32756	õdesid	õde	õde	18_S	PlP	et	õdesid =õde  (PlP  >õde !18_S
32760	vastuvõtueksami	eksami	vastu+võtu+eksam	02_S	SgG	et	vastuvõtueksami =eksami  (SgG  >vastu+võtu+eksam !02_S
32763	vahetusõpilaseks	õpilase	vahetus+õpilane	12_S	SgTr	et	vahetusõpilaseks =õpilase  (SgTr  >vahetus+õpilane !12_S
32764	armustasin	armusta	armustama	27_V	IndIpfSg1	et	armustasin =armusta  (IndIpfSg1  >armustama !27_V
32769	metroos	metroo	metroo	26_S	SgIn	et	metroos =metroo  (SgIn  >metroo !26_S
32774	assistent	assistent	assistent	22_S	SgN	et	assistent =assistent  (SgN  >assistent !22_S
32779	õpinguid	õpingu	õping	02_S	PlP	et	õpinguid =õpingu  (PlP  >õping !02_S
32780	büroodes	büroo	büroo	26_S	PlIn	et	büroodes =büroo  (PlIn  >büroo !26_S
32781	vahetusõpilaseeks	ee	vahetus+õpilas+esi	15_S	SgTr	et	vahetusõpilaseeks =ee  (SgTr  >vahetus+õpilas+esi !15_S
32782	tüdrukuga	tüdruku	tüdruk	02_S	SgKom	et	tüdrukuga =tüdruku  (SgKom  >tüdruk !02_S
32788	väikevend	vend	väike+vend	22_S	SgN	et	väikevend =vend  (SgN  >väike+vend !22_S
32792	tegusõnaga	sõna	tegu+sõna	17_S	SgKom	et	tegusõnaga =sõna  (SgKom  >tegu+sõna !17_S
32795	läheme	lähe	minema	36_V	IndPrPl1	et	läheme =lähe  (IndPrPl1  >minema !36_V
32801	järv	järv	järv	22_S	SgN	et	järv =järv  (SgN  >järv !22_S
32803	järvid	järvi	järv	22_S	PlN	et	järvid =järvi  (PlN  >järv !22_S
32808	minevikuga	mineviku	minevik	25_S	SgKom	et	minevikuga =mineviku  (SgKom  >minevik !25_S
32809	tordi	tordi	tort	22_S	SgG	et	tordi =tordi  (SgG  >tort !22_S
32810	võileibu	leibu	või+leib	22_S	PlP	et	võileibu =leibu  (PlP  >või+leib !22_S
32816	jääs	jää	jää	26_S	SgIn	et	jääs =jää  (SgIn  >jää !26_S
32818	tules	tule	tuli	20_S	SgIn	et	tules =tule  (SgIn  >tuli !20_S
32820	kuulasime	kuula	kuulama	29_V	IndIpfPl1	et	kuulasime =kuula  (IndIpfPl1  >kuulama !29_V
32821	lillide	lilli	lill	22_S	PlG	et	lillide =lilli  (PlG  >lill !22_S
32822	väikevenna	venna	väike+vend	22_S	SgG	et	väikevenna =venna  (SgG  >väike+vend !22_S
32831	maasid	maa	maa	26_S	PlP	et	maasid =maa  (PlP  >maa !26_S
32833	võileivad	leiva	või+leib	22_S	PlN	et	võileivad =leiva  (PlN  >või+leib !22_S
32834	kaas	kaas	kaas	14_S	SgN	et	kaas =kaas  (SgN  >kaas !14_S
32836	väikevennale	venna	väike+vend	22_S	SgAll	et	väikevennale =venna  (SgAll  >väike+vend !22_S
32839	kuulsime	kuul	kuulma	33_V	IndIpfPl1	et	kuulsime =kuul  (IndIpfPl1  >kuulma !33_V
32840	jõge	jõge	jõgi	21_S	SgP	et	jõge =jõge  (SgP  >jõgi !21_S
32843	tuhandeid	tuhande	tuhat	02_N	PlP	et	tuhandeid =tuhande  (PlP  >tuhat !02_N
32855	ütlus	ütlus	ütlus	11~09_S	SgN	et	ütlus =ütlus  (SgN  >ütlus !11~09_S
32859	sealset	sealse	sealne	02_A	SgP	et	sealset =sealse  (SgP  >sealne !02_A
32653	infopuudus	puudus	info+puudus	11~09_S	SgN	et	infopuudus =puudus  (SgN  >info+puudus !11~09_S
32663	reageering	reageering	reageering	02_S	SgN	et	reageering =reageering  (SgN  >reageering !02_S
32664	sibirist	rist	sibi+rist	22_S	SgN	et	sibirist =rist  (SgN  >sibi+rist !22_S
32668	normaalne	normaalne	normaalne	02_A	SgN	et	normaalne =normaalne  (SgN  >normaalne !02_A
32669	vahend	vahend	vahend	02_S	SgN	et	vahend =vahend  (SgN  >vahend !02_S
32670	parandage	paranda	parandama	27_V	ImpPrPl2	et	parandage =paranda  (ImpPrPl2  >parandama !27_V
32673	hiilis	hiili	hiilima	28_V	IndIpfSg3	et	hiilis =hiili  (IndIpfSg3  >hiilima !28_V
32682	seene	seene	seen	13_S	SgG	et	seene =seene  (SgG  >seen !13_S
32686	numbrit	numbri	number	02_S	SgP	et	numbrit =numbri  (SgP  >number !02_S
32688	kohtama	kohta	kohtama	29_V	Sup	et	kohtama =kohta  (Sup  >kohtama !29_V
32697	temas	tema	tema	00_P	SgIn	et	temas =tema  (SgIn  >tema !00_P
32699	teinegi	teine	teine	12_OP	SgN^	et	teinegi =teine  (SgN^  >teine !12_OP
32700	hoolsasti	hoolsasti	hoolsasti	41_D	ID	et	hoolsasti =hoolsasti  (ID  >hoolsasti !41_D
32702	kahetsen	kahetse	kahetsema	27_V	IndPrSg1	et	kahetsen =kahetse  (IndPrSg1  >kahetsema !27_V
32709	muutsin	muut	muutma	34_V	IndIpfSg1	et	muutsin =muut  (IndIpfSg1  >muutma !34_V
32715	hoiatas	hoiata	hoiatama	27_V	IndIpfSg3	et	hoiatas =hoiata  (IndIpfSg3  >hoiatama !27_V
32720	korvakest	kest	korva+kest	22_S	SgN	et	korvakest =kest  (SgN  >korva+kest !22_S
32725	ootas	oota	ootama	29_V	IndIpfSg3	et	ootas =oota  (IndIpfSg3  >ootama !29_V
32726	tervitada	tervita	tervitama	27_V	Inf	et	tervitada =tervita  (Inf  >tervitama !27_V
32727	kõrvad	kõrva	kõrv	22_S	PlN	et	kõrvad =kõrva  (PlN  >kõrv !22_S
32730	imetlema	imetle	imetlema	27_V	Sup	et	imetlema =imetle  (Sup  >imetlema !27_V
32732	kallistama	kallista	kallistama	27_V	Sup	et	kallistama =kallista  (Sup  >kallistama !27_V
32735	hüüdis	hüüd	hüüdma	34_V	IndIpfSg3	et	hüüdis =hüüd  (IndIpfSg3  >hüüdma !34_V
32736	kõht	kõht	kõht	22_S	SgN	et	kõht =kõht  (SgN  >kõht !22_S
32737	kõhu	kõhu	kõht	22_S	SgG	et	kõhu =kõhu  (SgG  >kõht !22_S
32740	senist	senis	senine	10_A	SgP	et	senist =senis  (SgP  >senine !10_A
32742	plokkidest	plokki	plokk	22_S	PlEl	et	plokkidest =plokki  (PlEl  >plokk !22_S
32743	ärritab	ärrita	ärritama	27_V	IndPrSg3	et	ärritab =ärrita  (IndPrSg3  >ärritama !27_V
32752	kohvikuga	kohviku	kohvik	02_S	SgKom	et	kohvikuga =kohviku  (SgKom  >kohvik !02_S
32754	allapoole	allapoole	alla+poole	41_DK	ID	et	allapoole =allapoole  (ID  >alla+poole !41_DK
32757	sekretärina	sekretäri	sekretär	19_S	SgEs	et	sekretärina =sekretäri  (SgEs  >sekretär !19_S
32762	turiste	turiste	turist	22_S	PlP	et	turiste =turiste  (PlP  >turist !22_S
32765	minnagi	minn	minema	36_V	Inf^	et	minnagi =minn  (Inf^  >minema !36_V
32772	teateris	teateri	teater	02_S	SgIn	et	teateris =teateri  (SgIn  >teater !02_S
32786	ostude	ostu	ost	22_S	PlG	et	ostude =ostu  (PlG  >ost !22_S
32791	välismaalase	maalase	välis+maalane	12?10_S	SgG	et	välismaalase =maalase  (SgG  >välis+maalane !12?10_S
32794	postkontorisse	kontori	post+kontor	02_S	SgIll	et	postkontorisse =kontori  (SgIll  >post+kontor !02_S
32800	jõgi	jõgi	jõgi	21_S	SgN	et	jõgi =jõgi  (SgN  >jõgi !21_S
32804	käekiri	kiri	käe+kiri	24_S	SgN	et	käekiri =kiri  (SgN  >käe+kiri !24_S
32805	liigne	liigne	liigne	02_A	SgN	et	liigne =liigne  (SgN  >liigne !02_A
32807	olevik	olevik	olevik	25_S	SgN	et	olevik =olevik  (SgN  >olevik !25_S
32811	keedan	keeda	keetma	34_V	IndPrSg1	et	keedan =keeda  (IndPrSg1  >keetma !34_V
32812	hiljaks	hiljaks	hiljaks	41_D	ID	et	hiljaks =hiljaks  (ID  >hiljaks !41_D
32819	toos	toos	toos	22_S	SgN	et	toos =toos  (SgN  >toos !22_S
32825	hilineda	hiline	hilinema	27_V	Inf	et	hilineda =hiline  (Inf  >hilinema !27_V
32828	mäed	mäe	mägi	21_S	PlN	et	mäed =mäe  (PlN  >mägi !21_S
32832	liigset	liigse	liigne	02_A	SgP	et	liigset =liigse  (SgP  >liigne !02_A
32835	võõra	võõra	võõras	07_AS	SgG	et	võõra =võõra  (SgG  >võõras !07_AS
32845	vähesed	vähese	vähene	10_A	PlN	et	vähesed =vähese  (PlN  >vähene !10_A
32852	valemit	valemi	valem	02_S	SgP	et	valemit =valemi  (SgP  >valem !02_S
32857	teisiti	teisiti	teisiti	41_D	ID	et	teisiti =teisiti  (ID  >teisiti !41_D
32865	rikub	riku	rikkuma	28_V	IndPrSg3	et	rikub =riku  (IndPrSg3  >rikkuma !28_V
32892	transpordivahenditeta	vahendi	transpordi+vahend	02_S	PlAb	et	transpordivahenditeta =vahendi  (PlAb  >transpordi+vahend !02_S
32900	pakisaatmine	saatmine	paki+saatmine	12?10_S	SgN	et	pakisaatmine =saatmine  (SgN  >paki+saatmine !12?10_S
32902	kanalisatsioon	kanalisatsioon	kanalisatsioon	22_S	SgN	et	kanalisatsioon =kanalisatsioon  (SgN  >kanalisatsioon !22_S
32904	keskajas	aja	kesk+aeg	22_S	SgIn	et	keskajas =aja  (SgIn  >kesk+aeg !22_S
32860	maailmakodanikud	kodaniku	maa+ilma+kodanik	25_S	PlN	et	maailmakodanikud =kodaniku  (PlN  >maa+ilma+kodanik !25_S
32868	90-protsendil	protsendi	-protsent	22_S	SgAd	et	-protsendil =protsendi  (SgAd  >-protsent !22_S
32872	mitmekülgse	külgse	mitme+külgne	02_A	SgG	et	mitmekülgse =külgse  (SgG  >mitme+külgne !02_A
32875	huvipakkuv	pakkuv	huvi+pakkuv	02_A	SgN	et	huvipakkuv =pakkuv  (SgN  >huvi+pakkuv !02_A
32876	üritan	ürita	üritama	27_V	IndPrSg1	et	üritan =ürita  (IndPrSg1  >üritama !27_V
32880	elektrita	elektri	elekter	02_S	SgAb	et	elektrita =elektri  (SgAb  >elekter !02_S
32883	taaskord	kord	taas+kord	22_S	SgN	et	taaskord =kord  (SgN  >taas+kord !22_S
32887	kokkuvarisemine	varisemine	kokku+varisemine	12_S	SgN	et	kokkuvarisemine =varisemine  (SgN  >kokku+varisemine !12_S
32889	kuivkäimlaga	käimla	kuiv+käimla	01_S	SgKom	et	kuivkäimlaga =käimla  (SgKom  >kuiv+käimla !01_S
32891	veevärgita	värgi	vee+värk	22_S	SgAb	et	veevärgita =värgi  (SgAb  >vee+värk !22_S
32893	maaalad	ala	maa+ala	17_S	PlN	et	maaalad =ala  (PlN  >maa+ala !17_S
32899	aeglane	aeglane	aeglane	12?10_A	SgN	et	aeglane =aeglane  (SgN  >aeglane !12?10_A
32903	transpordivahendid	vahendi	transpordi+vahend	02_S	PlN	et	transpordivahendid =vahendi  (PlN  >transpordi+vahend !02_S
32909	põhimõttel	mõtte	põhi+mõte	06_S	SgAd	et	põhimõttel =mõtte  (SgAd  >põhi+mõte !06_S
32912	masinad	masina	masin	02_S	PlN	et	masinad =masina  (PlN  >masin !02_S
32913	hakkaks	hakka	hakkama	29_V	KndPrPs	et	hakkaks =hakka  (KndPrPs  >hakkama !29_V
32918	teistsugusena	suguse	teist+sugune	10_P	SgEs	et	teistsugusena =suguse  (SgEs  >teist+sugune !10_P
32919	modernses	modernse	modernne	02_A	SgIn	et	modernses =modernse  (SgIn  >modernne !02_A
32923	televiisorit	televiisori	televiisor	02_S	SgP	et	televiisorit =televiisori  (SgP  >televiisor !02_S
32924	tänapäevainimesed	inimese	täna+päeva+inimene	12_S	PlN	et	tänapäevainimesed =inimese  (PlN  >täna+päeva+inimene !12_S
32927	trepist	trepi	trepp	22_S	SgEl	et	trepist =trepi  (SgEl  >trepp !22_S
32928	liftiga	lifti	lift	22_S	SgKom	et	liftiga =lifti  (SgKom  >lift !22_S
32930	vallutada	valluta	vallutama	27_V	Inf	et	vallutada =valluta  (Inf  >vallutama !27_V
32938	tagalas	tagala	tagala	01_S	SgIn	et	tagalas =tagala  (SgIn  >tagala !01_S
32941	määral	määra	määr	22_S	SgAd	et	määral =määra  (SgAd  >määr !22_S
32944	kapp	kapp	kapp	22_S	SgN	et	kapp =kapp  (SgN  >kapp !22_S
32951	repressioonid	repressiooni	repressioon	22_S	PlN	et	repressioonid =repressiooni  (PlN  >repressioon !22_S
32968	kapitalism	kapitalism	kapitalism	22_S	SgN	et	kapitalism =kapitalism  (SgN  >kapitalism !22_S
32974	okas	okas	okas	07_S	SgN	et	okas =okas  (SgN  >okas !07_S
32978	pleenum	pleenum	pleenum	02_S	SgN	et	pleenum =pleenum  (SgN  >pleenum !02_S
32981	uuele	uue	uus	14_A	SgAll	et	uuele =uue  (SgAll  >uus !14_A
32983	kaadriametnikega	ametnike	kaadri+ametnik	25_S	PlKom	et	kaadriametnikega =ametnike  (PlKom  >kaadri+ametnik !25_S
32987	raamatuhävitamine	hävitamine	raamatu+hävitamine	12_S	SgN	et	raamatuhävitamine =hävitamine  (SgN  >raamatu+hävitamine !12_S
32989	sulaperiood	periood	sula+periood	22_S	SgN	et	sulaperiood =periood  (SgN  >sula+periood !22_S
32995	tõlked	tõlke	tõlge	06_S	PlN	et	tõlked =tõlke  (PlN  >tõlge !06_S
32997	vasar	vasar	vasar	02_S	SgN	et	vasar =vasar  (SgN  >vasar !02_S
33001	poeetidest	poeeti	poeet	22_S	PlEl	et	poeetidest =poeeti  (PlEl  >poeet !22_S
33002	domineeris	domineeri	domineerima	28_V	IndIpfSg3	et	domineeris =domineeri  (IndIpfSg3  >domineerima !28_V
33016	järvede	järve	järv	22_S	PlG	et	järvede =järve  (PlG  >järv !22_S
33024	indiaanlaste	indiaanlas	indiaanlane	12?10_S	PlG	et	indiaanlaste =indiaanlas  (PlG  >indiaanlane !12?10_S
33034	varemed	vareme	vare	04_S	PlN	et	varemed =vareme  (PlN  >vare !04_S
33053	vaatuste	vaatus	vaatus	11~09_S	PlG	et	vaatuste =vaatus  (PlG  >vaatus !11~09_S
33064	soeng	soeng	soeng	02_S	SgN	et	soeng =soeng  (SgN  >soeng !02_S
33067	kollektsiooniks	kollektsiooni	kollektsioon	22_S	SgTr	et	kollektsiooniks =kollektsiooni  (SgTr  >kollektsioon !22_S
33069	romantilises	romantilise	romantiline	12_A	SgIn	et	romantilises =romantilise  (SgIn  >romantiline !12_A
33074	vamp	vamp	vamp	22_S	SgN	et	vamp =vamp  (SgN  >vamp !22_S
33075	kullad	kulla	kuld	22_S	PlN	et	kullad =kulla  (PlN  >kuld !22_S
33088	etno-stiil	stiil	etno-stiil	22_S	SgN	et	etno-stiil =stiil  (SgN  >etno-stiil !22_S
33094	kaasaegse	aegse	kaas+aegne	02_A	SgG	et	kaasaegse =aegse  (SgG  >kaas+aegne !02_A
33099	seksuaalsed	seksuaalse	seksuaalne	02_A	PlN	et	seksuaalsed =seksuaalse  (PlN  >seksuaalne !02_A
33100	etteütlemine	ütlemine	ette+ütlemine	12_S	SgN	et	etteütlemine =ütlemine  (SgN  >ette+ütlemine !12_S
33102	peodel	peo	peo	26_S	PlAd	et	peodel =peo  (PlAd  >peo !26_S
33108	õigeaegne	aegne	õige+aegne	02_A	SgN	et	õigeaegne =aegne  (SgN  >õige+aegne !02_A
32905	kiviajas	aja	kivi+aeg	22_S	SgIn	et	kiviajas =aja  (SgIn  >kivi+aeg !22_S
32906	sajandis	sajandi	sajand	02_S	SgIn	et	sajandis =sajandi  (SgIn  >sajand !02_S
32907	tehnikata	tehnika	tehnika	01_S	SgAb	et	tehnikata =tehnika  (SgAb  >tehnika !01_S
32914	katastroofid	katastroofi	katastroof	22_S	PlN	et	katastroofid =katastroofi  (PlN  >katastroof !22_S
32920	tehnoloogiata	tehnoloogia	tehnoloogia	01_S	SgAb	et	tehnoloogiata =tehnoloogia  (SgAb  >tehnoloogia !01_S
32925	hädavajalikul	vajaliku	häda+vajalik	25_A	SgAd	et	hädavajalikul =vajaliku  (SgAd  >häda+vajalik !25_A
32926	asjadeta	asja	asi	24_S	PlAb	et	asjadeta =asja  (PlAb  >asi !24_S
32932	ületada	ületa	ületama	27_V	Inf	et	ületada =ületa  (Inf  >ületama !27_V
32933	petab	peta	petma	35_V	IndPrSg3	et	petab =peta  (IndPrSg3  >petma !35_V
32934	haiget	haige	haige	01_AS	SgP	et	haiget =haige  (SgP  >haige !01_AS
32937	oskaks	oska	oskama	29_V	KndPrPs	et	oskaks =oska  (KndPrPs  >oskama !29_V
32940	sotsialistide	sotsialisti	sotsialist	22_S	PlG	et	sotsialistide =sotsialisti  (PlG  >sotsialist !22_S
32942	religioosseid	religioosse	religioosne	02_A	PlP	et	religioosseid =religioosse  (PlP  >religioosne !02_A
32946	kultuurimudelite	mudeli	kultuuri+mudel	02_S	PlG	et	kultuurimudelite =mudeli  (PlG  >kultuuri+mudel !02_S
32949	mahuvad	mahu	mahtuma	28_V	IndPrPl3	et	mahuvad =mahu  (IndPrPl3  >mahtuma !28_V
32952	seoti	seo	siduma	28_V	IndIpfIps	et	seoti =seo  (IndIpfIps  >siduma !28_V
32959	teatrit	teatri	teater	02_S	SgP	et	teatrit =teatri  (SgP  >teater !02_S
32967	kujutamisobjektiks	objekti	kujutamis+objekt	22_S	SgTr	et	kujutamisobjektiks =objekti  (SgTr  >kujutamis+objekt !22_S
32975	heliloojaid	looja	heli+looja	01_S	PlP	et	heliloojaid =looja  (PlP  >heli+looja !01_S
32977	märtsis	märtsi	märts	22_S	SgIn	et	märtsis =märtsi  (SgIn  >märts !22_S
32979	seostati	seosta	seostama	27_V	IndIpfIps	et	seostati =seosta  (IndIpfIps  >seostama !27_V
32994	töölised	töölise	tööline	12?10_S	PlN	et	töölised =töölise  (PlN  >tööline !12?10_S
33000	rituaalseks	rituaalse	rituaalne	02_A	SgTr	et	rituaalseks =rituaalse  (SgTr  >rituaalne !02_A
33006	soojalembesid	lembe	sooja+lemb	22_S	PlP	et	soojalembesid =lembe  (PlP  >sooja+lemb !22_S
33017	pinnad	pinna	pind	22_S	PlN	et	pinnad =pinna  (PlN  >pind !22_S
33023	püramiid	püramiid	püramiid	22_S	SgN	et	püramiid =püramiid  (SgN  >püramiid !22_S
33025	teadlaste	teadlas	teadlane	12?10_S	PlG	et	teadlaste =teadlas  (PlG  >teadlane !12?10_S
33028	esitas	esita	esitama	27_V	IndIpfSg3	et	esitas =esita  (IndIpfSg3  >esitama !27_V
33040	lihavõtetele	võte	liha+võte	06_S	PlAll	et	lihavõtetele =võte  (PlAll  >liha+võte !06_S
33048	piinadest	piina	piin	22_S	PlEl	et	piinadest =piina  (PlEl  >piin !22_S
33057	disainerid	disaineri	disainer	02_S	PlN	et	disainerid =disaineri  (PlN  >disainer !02_S
33066	sügis-talv	talv	sügis-talv	22_S	SgN	et	sügis-talv =talv  (SgN  >sügis-talv !22_S
33068	soengud	soengu	soeng	02_S	PlN	et	soengud =soengu  (PlN  >soeng !02_S
33080	kleit	kleit	kleit	22_S	SgN	et	kleit =kleit  (SgN  >kleit !22_S
33085	rihmaga	rihma	rihm	22_S	SgKom	et	rihmaga =rihma  (SgKom  >rihm !22_S
33092	seelikud	seeliku	seelik	02_S	PlN	et	seelikud =seeliku  (PlN  >seelik !02_S
33093	motiividega	motiivi	motiiv	22_S	PlKom	et	motiividega =motiivi  (PlKom  >motiiv !22_S
33095	moesse	moe	mood	22_S	SgIll	et	moesse =moe  (SgIll  >mood !22_S
33096	kauneid	kaune	kaunis	05~07_A	PlP	et	kauneid =kaune  (PlP  >kaunis !05~07_A
33111	kehatoonikuga	tooniku	keha+toonik	02_S	SgKom	et	kehatoonikuga =tooniku  (SgKom  >keha+toonik !02_S
33115	rõõmustab	rõõmusta	rõõmustama	27_V	IndPrSg3	et	rõõmustab =rõõmusta  (IndPrSg3  >rõõmustama !27_V
33122	figuurid	figuuri	figuur	22_S	PlN	et	figuurid =figuuri  (PlN  >figuur !22_S
33124	unustage	unusta	unustama	27_V	ImpPrPl2	et	unustage =unusta  (ImpPrPl2  >unustama !27_V
33126	kink	kink	kink	22_S	SgN	et	kink =kink  (SgN  >kink !22_S
33130	karusnahku	nahku	karus+nahk	22_S	PlP	et	karusnahku =nahku  (PlP  >karus+nahk !22_S
33134	9-10s			xx_Q	SgIn	et	-s =  (SgIn  > !xx_Q
33136	slaavlastega	slaavlas	slaavlane	12?10_S	PlKom	et	slaavlastega =slaavlas  (PlKom  >slaavlane !12?10_S
33141	käsitööga	töö	käsi+töö	26_S	SgKom	et	käsitööga =töö  (SgKom  >käsi+töö !26_S
33145	ader	ader	ader	24_S	SgN	et	ader =ader  (SgN  >ader !24_S
33148	jutustati	jutusta	jutustama	27_V	IndIpfIps	et	jutustati =jutusta  (IndIpfIps  >jutustama !27_V
33157	riigiks	riigi	riik	22_S	SgTr	et	riigiks =riigi  (SgTr  >riik !22_S
33171	põhiliseks	põhilise	põhiline	12_A	SgTr	et	põhiliseks =põhilise  (SgTr  >põhiline !12_A
33178	rahvus	rahvus	rahvus	11~09_S	SgN	et	rahvus =rahvus  (SgN  >rahvus !11~09_S
33179	sini	si	si	26_S	SgTer	et	sini =si  (SgTer  >si !26_S
33181	liidab	liida	liitma	34_V	IndPrSg3	et	liidab =liida  (IndPrSg3  >liitma !34_V
32910	aladel	ala	ala	17_S	PlAd	et	aladel =ala  (PlAd  >ala !17_S
32915	vajadused	vajaduse	vajadus	11_S	PlN	et	vajadused =vajaduse  (PlN  >vajadus !11_S
32916	kauaks	kauaks	kauaks	41_D	ID	et	kauaks =kauaks  (ID  >kauaks !41_D
32917	tänapäevamaailm	ilm	täna+päeva+maa+ilm	22_S	SgN	et	tänapäevamaailm =ilm  (SgN  >täna+päeva+maa+ilm !22_S
32929	seovad	seo	siduma	28_V	IndPrPl3	et	seovad =seo  (IndPrPl3  >siduma !28_V
32935	tehes	teh	tegema	28_V	Ger	et	tehes =teh  (Ger  >tegema !28_V
32936	unikaalsed	unikaalse	unikaalne	02_A	PlN	et	unikaalsed =unikaalse  (PlN  >unikaalne !02_A
32939	kajastub	kajastu	kajastuma	27_V	IndPrSg3	et	kajastub =kajastu  (IndPrSg3  >kajastuma !27_V
32950	sõjameeleolud	olu	sõja+meele+olu	17_S	PlN	et	sõjameeleolud =olu  (PlN  >sõja+meele+olu !17_S
32955	sotsialistlik	sotsialistlik	sotsialistlik	25_A	SgN	et	sotsialistlik =sotsialistlik  (SgN  >sotsialistlik !25_A
32958	eksiilkirjanikud	kirjaniku	eksiil+kirjanik	25_S	PlN	et	eksiilkirjanikud =kirjaniku  (PlN  >eksiil+kirjanik !25_S
32966	natsionalismiga	natsionalismi	natsionalism	22_S	SgKom	et	natsionalismiga =natsionalismi  (SgKom  >natsionalism !22_S
32970	tantsuansambel	ansambel	tantsu+ansambel	02_S	SgN	et	tantsuansambel =ansambel  (SgN  >tantsu+ansambel !02_S
32971	draamakollektiiv	kollektiiv	draama+kollektiiv	22_S	SgN	et	draamakollektiiv =kollektiiv  (SgN  >draama+kollektiiv !22_S
32972	raud	raud	raud	22_S	SgN	et	raud =raud  (SgN  >raud !22_S
32973	kunstnikke	kunstnikke	kunstnik	25_S	PlP	et	kunstnikke =kunstnikke  (PlP  >kunstnik !25_S
32976	õppekombinaadi	kombinaadi	õppe+kombinaat	22_S	SgG	et	õppekombinaadi =kombinaadi  (SgG  >õppe+kombinaat !22_S
32980	erialaspetsialistid	spetsialisti	eri+ala+spetsialist	22_S	PlN	et	erialaspetsialistid =spetsialisti  (PlN  >eri+ala+spetsialist !22_S
32993	käsumajandus	majandus	käsu+majandus	11_S	SgN	et	käsumajandus =majandus  (SgN  >käsu+majandus !11_S
32998	viisnurk	nurk	viis+nurk	22_S	SgN	et	viisnurk =nurk  (SgN  >viis+nurk !22_S
33003	draamakirjanikest	kirjanike	draama+kirjanik	25_S	PlEl	et	draamakirjanikest =kirjanike  (PlEl  >draama+kirjanik !25_S
33005	leidud	leidu	leiduma	27_V	IndPrSg2	et	leidud =leidu  (IndPrSg2  >leiduma !27_V
33007	bakterid	bakteri	bakter	02_S	PlN	et	bakterid =bakteri  (PlN  >bakter !02_S
33008	teadlastele	teadlas	teadlane	12?10_S	PlAll	et	teadlastele =teadlas  (PlAll  >teadlane !12?10_S
33009	bakterite	bakteri	bakter	02_S	PlG	et	bakterite =bakteri  (PlG  >bakter !02_S
33013	aukudest	auku	auk	22_S	PlEl	et	aukudest =auku  (PlEl  >auk !22_S
33014	hooajal	aja	hoo+aeg	22_S	SgAd	et	hooajal =aja  (SgAd  >hoo+aeg !22_S
33015	jääproovid	proovi	jää+proov	22_S	PlN	et	jääproovid =proovi  (PlN  >jää+proov !22_S
33020	pind	pind	pind	22_S	SgN	et	pind =pind  (SgN  >pind !22_S
33027	meetrit	meetri	meeter	02_S	SgP	et	meetrit =meetri  (SgP  >meeter !02_S
33029	press	press	press	22_S	SgN	et	press =press  (SgN  >press !22_S
33032	kultuuritempel	tempel	kultuuri+tempel	02_S	SgN	et	kultuuritempel =tempel  (SgN  >kultuuri+tempel !02_S
33039	künkaga	künka	küngas	07_S	SgKom	et	künkaga =künka  (SgKom  >küngas !07_S
33041	vaatusi	vaatusi	vaatus	11_S	PlP	et	vaatusi =vaatusi  (PlP  >vaatus !11_S
33049	miljoni	miljoni	miljon	02_N	SgG	et	miljoni =miljoni  (SgG  >miljon !02_N
33056	kuusk	kuusk	kuusk	22_S	SgN	et	kuusk =kuusk  (SgN  >kuusk !22_S
33061	pidulik	pidulik	pidulik	25_A	SgN	et	pidulik =pidulik  (SgN  >pidulik !25_A
33062	uuendada	uuenda	uuendama	27_V	Inf	et	uuendada =uuenda  (Inf  >uuendama !27_V
33065	juuksurid	juuksuri	juuksur	02_S	PlN	et	juuksurid =juuksuri  (PlN  >juuksur !02_S
33070	jälgitakse	jälgi	jälgima	27_V	IndPrIps	et	jälgitakse =jälgi  (IndPrIps  >jälgima !27_V
33072	stiilne	stiilne	stiilne	02_A	SgN	et	stiilne =stiilne  (SgN  >stiilne !02_A
33078	tagastab	tagasta	tagastama	27_V	IndPrSg3	et	tagastab =tagasta  (IndPrSg3  >tagastama !27_V
33083	kuldne	kuldne	kuldne	02_A	SgN	et	kuldne =kuldne  (SgN  >kuldne !02_A
33084	käekott	kott	käe+kott	22_S	SgN	et	käekott =kott  (SgN  >käe+kott !22_S
33086	kaunistada	kaunista	kaunistama	27_V	Inf	et	kaunistada =kaunista  (Inf  >kaunistama !27_V
33098	mugavad	mugava	mugav	02_A	PlN	et	mugavad =mugava  (PlN  >mugav !02_A
33103	maskid	maski	mask	22_S	PlN	et	maskid =maski  (PlN  >mask !22_S
33105	värvide	värvi	värv	22_S	PlG	et	värvide =värvi  (PlG  >värv !22_S
33106	violett	violett	violett	22_S	SgN	et	violett =violett  (SgN  >violett !22_S
33107	näeks	näe	nägema	28_V	KndPrPs	et	näeks =näe  (KndPrPs  >nägema !28_V
33113	armsale	armsa	armas	03~05_A	SgAll	et	armsale =armsa  (SgAll  >armas !03~05_A
33119	kaardid	kaardi	kaart	22_S	PlN	et	kaardid =kaardi  (PlN  >kaart !22_S
33123	võidukindel	kindel	võidu+kindel	02_A	SgN	et	võidukindel =kindel  (SgN  >võidu+kindel !02_A
33132	välismaariideid	riide	välis+maa+riie	06_S	PlP	et	välismaariideid =riide  (PlP  >välis+maa+riie !06_S
32931	ookeane	ookeane	ookean	19_S	PlP	et	ookeane =ookeane  (PlP  >ookean !19_S
32943	direktor	direktor	direktor	02_S	SgN	et	direktor =direktor  (SgN  >direktor !02_S
32954	kirjandusstiil	stiil	kirjandus+stiil	22_S	SgN	et	kirjandusstiil =stiil  (SgN  >kirjandus+stiil !22_S
32956	realism	realism	realism	22_S	SgN	et	realism =realism  (SgN  >realism !22_S
32961	näidendeid	näidende	näidend	02_S	PlP	et	näidendeid =näidende  (PlP  >näidend !02_S
32962	näitekirjanikutest	test	näite+kirjaniku+test	22_S	SgN	et	näitekirjanikutest =test  (SgN  >näite+kirjaniku+test !22_S
32964	kodaniku	kodaniku	kodanik	25_S	SgG	et	kodaniku =kodaniku  (SgG  >kodanik !25_S
32969	kunstiansamblite	ansambli	kunsti+ansambel	02_S	PlG	et	kunstiansamblite =ansambli  (PlG  >kunsti+ansambel !02_S
32982	korrale	korra	kord	22_S	SgAll	et	korrale =korra  (SgAll  >kord !22_S
32984	põhjalik	põhjalik	põhjalik	25_A	SgN	et	põhjalik =põhjalik  (SgN  >põhjalik !25_A
32988	raamatukogudes	kogu	raamatu+kogu	17_S	PlIn	et	raamatukogudes =kogu  (PlIn  >raamatu+kogu !17_S
32991	eksiilkirjandus	kirjandus	eksiil+kirjandus	11_S	SgN	et	eksiilkirjandus =kirjandus  (SgN  >eksiil+kirjandus !11_S
32992	kontroll	kontroll	kontroll	22_S	SgN	et	kontroll =kontroll  (SgN  >kontroll !22_S
33004	kooliprogrammis	programmi	kooli+programm	22_S	SgIn	et	kooliprogrammis =programmi  (SgIn  >kooli+programm !22_S
33010	jäljed	jälje	jälg	22_S	PlN	et	jäljed =jälje  (PlN  >jälg !22_S
33011	segus	segu	segu	17_S	SgIn	et	segus =segu  (SgIn  >segu !17_S
33012	pinnal	pinna	pind	22_S	SgAd	et	pinnal =pinna  (SgAd  >pind !22_S
33018	kattud	kattu	kattuma	27_V	IndPrSg2	et	kattud =kattu  (IndPrSg2  >kattuma !27_V
33019	jääga	jää	jää	26_S	SgKom	et	jääga =jää  (SgKom  >jää !26_S
33021	ruut	ruut	ruut	22_S	SgN	et	ruut =ruut  (SgN  >ruut !22_S
33030	agentuur	agentuur	agentuur	22_S	SgN	et	agentuur =agentuur  (SgN  >agentuur !22_S
33031	künka	künka	küngas	07_S	SgG	et	künka =künka  (SgG  >küngas !07_S
33033	fragmendid	fragmendi	fragment	22_S	PlN	et	fragmendid =fragmendi  (PlN  >fragment !22_S
33037	kraavid	kraavi	kraav	22_S	PlN	et	kraavid =kraavi  (PlN  >kraav !22_S
33038	loomuliku	loomuliku	loomulik	25_A	SgG	et	loomuliku =loomuliku  (SgG  >loomulik !25_A
33043	meeter	meeter	meeter	02_S	SgN	et	meeter =meeter  (SgN  >meeter !02_S
33045	seotakse	seo	siduma	28_V	IndPrIps	et	seotakse =seo  (IndPrIps  >siduma !28_V
33046	vabatahtlik	tahtlik	vaba+tahtlik	25_A	SgN	et	vabatahtlik =tahtlik  (SgN  >vaba+tahtlik !25_A
33047	kristuse	kristuse	kristus	11~09_S	SgG	et	kristuse =kristuse  (SgG  >kristus !11~09_S
33050	reeglina	reegli	reegel	02_S	SgEs	et	reeglina =reegli  (SgEs  >reegel !02_S
33054	kokkusattumuseks	sattumuse	kokku+sattumus	11_S	SgTr	et	kokkusattumuseks =sattumuse  (SgTr  >kokku+sattumus !11_S
33058	tume	tume	tume	02_A	SgN	et	tume =tume  (SgN  >tume !02_A
33059	vein	vein	vein	22_S	SgN	et	vein =vein  (SgN  >vein !22_S
33063	kollektsioon	kollektsioon	kollektsioon	22_S	SgN	et	kollektsioon =kollektsioon  (SgN  >kollektsioon !22_S
33073	tüdruku-nooruki	nooruki	tüdruku-nooruk	02_S	SgG	et	tüdruku-nooruki =nooruki  (SgG  >tüdruku-nooruk !02_S
33077	metsmaasika	maasika	mets+maasikas	02_S	SgG	et	metsmaasika =maasika  (SgG  >mets+maasikas !02_S
33082	kuld	kuld	kuld	22_S	SgN	et	kuld =kuld  (SgN  >kuld !22_S
33087	aksessuaaridega	aksessuaari	aksessuaar	22_S	PlKom	et	aksessuaaridega =aksessuaari  (PlKom  >aksessuaar !22_S
33091	kollektsioonides	kollektsiooni	kollektsioon	22_S	PlIn	et	kollektsioonides =kollektsiooni  (PlIn  >kollektsioon !22_S
33101	uueaastakarneval	karneval	uue+aasta+karneval	19_S	SgN	et	uueaastakarneval =karneval  (SgN  >uue+aasta+karneval !19_S
33104	soengu	soengu	soeng	02_S	SgG	et	soengu =soengu  (SgG  >soeng !02_S
33110	komplektid	komplekti	komplekt	22_S	PlN	et	komplektid =komplekti  (PlN  >komplekt !22_S
33114	komplekt	komplekt	komplekt	22_S	SgN	et	komplekt =komplekt  (SgN  >komplekt !22_S
33117	konkurentsita	konkurentsi	konkurents	22_S	SgAb	et	konkurentsita =konkurentsi  (SgAb  >konkurents !22_S
33125	element	element	element	22_S	SgN	et	element =element  (SgN  >element !22_S
33131	orje	orje	ori	24_S	PlP	et	orje =orje  (PlP  >ori !24_S
33133	pärandama	päranda	pärandama	27_V	Sup	et	pärandama =päranda  (Sup  >pärandama !27_V
33135	konflikte	konflikte	konflikt	22_S	PlP	et	konflikte =konflikte  (PlP  >konflikt !22_S
33143	kirved	kirve	kirves	07_S	PlN	et	kirved =kirve  (PlN  >kirves !07_S
33146	potikedrad	kedra	poti+keder	24_S	PlN	et	potikedrad =kedra  (PlN  >poti+keder !24_S
33149	matused	matuse	matus	09_S	PlN	et	matused =matuse  (PlN  >matus !09_S
33153	kiviaeg	aeg	kivi+aeg	22_S	SgN	et	kiviaeg =aeg  (SgN  >kivi+aeg !22_S
33160	teletorn	torn	tele+torn	22_S	SgN	et	teletorn =torn  (SgN  >tele+torn !22_S
33174	väliseestlased	eestlase	välis+eestlane	12?10_S	PlN	et	väliseestlased =eestlase  (PlN  >välis+eestlane !12?10_S
32953	mudeli	mudeli	mudel	02_S	SgG	et	mudeli =mudeli  (SgG  >mudel !02_S
32957	ülemaailmne	ilmne	üle+maa+ilmne	02_A	SgN	et	ülemaailmne =ilmne  (SgN  >üle+maa+ilmne !02_A
32960	lavamängudes	mängu	lava+mäng	22_S	PlIn	et	lavamängudes =mängu  (PlIn  >lava+mäng !22_S
32963	satiir	satiir	satiir	22_S	SgN	et	satiir =satiir  (SgN  >satiir !22_S
32965	imperialismiga	imperialismi	imperialism	22_S	SgKom	et	imperialismiga =imperialismi  (SgKom  >imperialism !22_S
32985	uudiskirjandus	kirjandus	uudis+kirjandus	11_S	SgN	et	uudiskirjandus =kirjandus  (SgN  >uudis+kirjandus !11_S
32986	ulatuslik	ulatuslik	ulatuslik	25_A	SgN	et	ulatuslik =ulatuslik  (SgN  >ulatuslik !25_A
32990	jagunes	jagune	jagunema	27_V	IndIpfSg3	et	jagunes =jagune  (IndIpfSg3  >jagunema !27_V
32996	võõrkeelset	keelse	võõr+keelne	02_A	SgP	et	võõrkeelset =keelse  (SgP  >võõr+keelne !02_A
32999	autoriks	autori	autor	02_S	SgTr	et	autoriks =autori  (SgTr  >autor !02_S
33022	iidne	iidne	iidne	02_A	SgN	et	iidne =iidne  (SgN  >iidne !02_A
33026	ehitise	ehitise	ehitis	11_S	SgG	et	ehitise =ehitise  (SgG  >ehitis !11_S
33035	püramiidist	püramiidi	püramiid	22_S	SgEl	et	püramiidist =püramiidi  (SgEl  >püramiid !22_S
33036	arheoloogid	arheoloogi	arheoloog	22_S	PlN	et	arheoloogid =arheoloogi  (PlN  >arheoloog !22_S
33042	märgina	märgi	märk	22_S	SgEs	et	märgina =märgi  (SgEs  >märk !22_S
33044	püstitakse	takse	püsti+taks	22_S	PlP	et	püstitakse =takse  (PlP  >püsti+taks !22_S
33051	hispaanlased	hispaanlase	hispaanlane	12?10_S	PlN	et	hispaanlased =hispaanlase  (PlN  >hispaanlane !12?10_S
33052	templid	templi	tempel	02_S	PlN	et	templid =templi  (PlN  >tempel !02_S
33055	stilist	stilist	stilist	22_S	SgN	et	stilist =stilist  (SgN  >stilist !22_S
33060	kombineerida	kombineeri	kombineerima	28_V	Inf	et	kombineerida =kombineeri  (Inf  >kombineerima !28_V
33071	moodsed	moodse	moodne	02_A	PlN	et	moodsed =moodse  (PlN  >moodne !02_A
33076	blond	blond	blond	22_SA	SgN	et	blond =blond  (SgN  >blond !22_SA
33079	elegantne	elegantne	elegantne	02_A	SgN	et	elegantne =elegantne  (SgN  >elegantne !02_A
33081	näete	näe	nägema	28_V	IndPrPl2	et	näete =näe  (IndPrPl2  >nägema !28_V
33089	moe	moe	mood	22_S	SgG	et	moe =moe  (SgG  >mood !22_S
33090	riidemudelite	mudeli	riide+mudel	02_S	PlG	et	riidemudelite =mudeli  (PlG  >riide+mudel !02_S
33097	kujud	kuju	kuju	17_S	PlN	et	kujud =kuju  (PlN  >kuju !17_S
33116	uueks	uue	uus	14_A	SgTr	et	uueks =uue  (SgTr  >uus !14_A
33120	pöörduge	pöördu	pöörduma	27_V	ImpPrPl2	et	pöörduge =pöördu  (ImpPrPl2  >pöörduma !27_V
33121	käsitsi	käsitsi	käsitsi	41_D	ID	et	käsitsi =käsitsi  (ID  >käsitsi !41_D
33127	pakkimispaber	paber	pakkimis+paber	02_S	SgN	et	pakkimispaber =paber  (SgN  >pakkimis+paber !02_S
33129	hõbedas	hõbeda	hõbe	02_S	SgIn	et	hõbedas =hõbeda  (SgIn  >hõbe !02_S
33138	slaavlased	slaavlase	slaavlane	12?10_S	PlN	et	slaavlased =slaavlase  (PlN  >slaavlane !12?10_S
33155	taasiseseisvumas	seisvu	taas+ise+seisvuma	27_V	SupIn	et	taasiseseisvumas =seisvu  (SupIn  >taas+ise+seisvuma !27_V
33156	aegadel	aega	aeg	22_S	PlAd	et	aegadel =aega  (PlAd  >aeg !22_S
33158	kajastab	kajasta	kajastama	27_V	IndPrSg3	et	kajastab =kajasta  (IndPrSg3  >kajastama !27_V
33161	sihtpunkt	punkt	siht+punkt	22_S	SgN	et	sihtpunkt =punkt  (SgN  >siht+punkt !22_S
33163	lõpud	lõpu	lõpp	22_SA	PlN	et	lõpud =lõpu  (PlN  >lõpp !22_SA
33164	tagajärjed	järje	taga+järg	22_S	PlN	et	tagajärjed =järje  (PlN  >taga+järg !22_S
33168	toompeal	pea	toom+pea	26_S	SgAd	et	toompeal =pea  (SgAd  >toom+pea !26_S
33169	venelasi	venelasi	venelane	12_S	PlP	et	venelasi =venelasi  (PlP  >venelane !12_S
33170	arendas	arenda	arendama	27_V	IndIpfSg3	et	arendas =arenda  (IndIpfSg3  >arendama !27_V
33177	maik	maik	maik	22_S	SgN	et	maik =maik  (SgN  >maik !22_S
33190	olude	olu	olu	17_S	PlG	et	olude =olu  (PlG  >olu !17_S
33191	valja	valja	valjas	07_S	SgG	et	valja =valja  (SgG  >valjas !07_S
33192	kiirendas	kiirenda	kiirendama	27_V	IndIpfSg3	et	kiirendas =kiirenda  (IndIpfSg3  >kiirendama !27_V
33203	erakordset	kordse	era+kordne	02_AS	SgP	et	erakordset =kordse  (SgP  >era+kordne !02_AS
33215	aadlikud	aadliku	aadlik	25_S	PlN	et	aadlikud =aadliku  (PlN  >aadlik !25_S
33225	hernhuutlikud	hernhuutliku	hernhuutlik	25_A	PlN	et	hernhuutlikud =hernhuutliku  (PlN  >hernhuutlik !25_A
33228	hernhuutlaste	hernhuutlas	hernhuutlane	12?10_S	PlG	et	hernhuutlaste =hernhuutlas  (PlG  >hernhuutlane !12?10_S
33235	kolmapäeval	päeva	kolma+päev	22_S	SgAd	et	kolmapäeval =päeva  (SgAd  >kolma+päev !22_S
33242	täielikuks	täieliku	täielik	25_A	SgTr	et	täielikuks =täieliku  (SgTr  >täielik !25_A
33250	aabitsaid	aabitsa	aabits	02_S	PlP	et	aabitsaid =aabitsa  (PlP  >aabits !02_S
33262	seltsidesse	seltsi	selts	22_S	PlIll	et	seltsidesse =seltsi  (PlIll  >selts !22_S
33109	detsembri	detsembri	detsember	02_S	SgG	et	detsembri =detsembri  (SgG  >detsember !02_S
33112	kingite	kingi	kinkima	28_V	IndPrPl2	et	kingite =kingi  (IndPrPl2  >kinkima !28_V
33118	antistress	stress	anti+stress	22_S	SgN	et	antistress =stress  (SgN  >anti+stress !22_S
33128	retked	retke	retk	22_S	PlN	et	retked =retke  (PlN  >retk !22_S
33137	kohapeal	kohapeal	koha+peal	41_D	ID	et	kohapeal =kohapeal  (ID  >koha+peal !41_D
33139	siinseid	siinse	siinne	02_A	PlP	et	siinseid =siinse  (PlP  >siinne !02_A
33140	rahvusele	rahvuse	rahvus	11~09_S	SgAll	et	rahvusele =rahvuse  (SgAll  >rahvus !11~09_S
33142	põllumajandusega	majanduse	põllu+majandus	11_S	SgKom	et	põllumajandusega =majanduse  (SgKom  >põllu+majandus !11_S
33147	saagid-	saagi	saak	22_S	PlN	et	saagid- =saagi  (PlN  >saak !22_S
33152	algne	algne	algne	02_A	SgN	et	algne =algne  (SgN  >algne !02_A
33154	pronksiaeg	aeg	pronksi+aeg	22_S	SgN	et	pronksiaeg =aeg  (SgN  >pronksi+aeg !22_S
33162	eitahtnud	tahtnu	ei+tahtnu	01_S	PlN	et	eitahtnud =tahtnu  (PlN  >ei+tahtnu !01_S
33167	kartes	kart	kartma	34_V	Ger	et	kartes =kart  (Ger  >kartma !34_V
33172	arrak	arrak	arrak	02_S	SgN	et	arrak =arrak  (SgN  >arrak !02_S
33175	enesetsensuuriga	tsensuuri	enese+tsensuur	22_S	SgKom	et	enesetsensuuriga =tsensuuri  (SgKom  >enese+tsensuur !22_S
33182	igasugusele	suguse	iga+sugune	10_A	SgAll	et	igasugusele =suguse  (SgAll  >iga+sugune !10_A
33185	revolutsioonil	revolutsiooni	revolutsioon	22_S	SgAd	et	revolutsioonil =revolutsiooni  (SgAd  >revolutsioon !22_S
33197	tähendabki	tähenda	tähendama	27_V	IndPrSg3^	et	tähendabki =tähenda  (IndPrSg3^  >tähendama !27_V
33200	üritas	ürita	üritama	27_V	IndIpfSg3	et	üritas =ürita  (IndIpfSg3  >üritama !27_V
33201	avalikustama	avalikusta	avalikustama	27_V	Sup	et	avalikustama =avalikusta  (Sup  >avalikustama !27_V
33207	sidekanalit	kanali	side+kanal	02_S	SgP	et	sidekanalit =kanali  (SgP  >side+kanal !02_S
33208	peades	pea	pea	26_S	PlIn	et	peades =pea  (PlIn  >pea !26_S
33209	kokkupõrked	põrke	kokku+põrge	06_S	PlN	et	kokkupõrked =põrke  (PlN  >kokku+põrge !06_S
33213	satuvad	satu	sattuma	28_V	IndPrPl3	et	satuvad =satu  (IndPrPl3  >sattuma !28_V
33222	suudab	suuda	suutma	34_V	IndPrSg3	et	suudab =suuda  (IndPrSg3  >suutma !34_V
33236	arutama	aruta	arutama	27_V	Sup	et	arutama =aruta  (Sup  >arutama !27_V
33246	keiser	keiser	keiser	02_S	SgN	et	keiser =keiser  (SgN  >keiser !02_S
33252	koostama	koosta	koostama	27_V	Sup	et	koostama =koosta  (Sup  >koostama !27_V
33267	algkoolid	kooli	alg+kool	22_S	PlN	et	algkoolid =kooli  (PlN  >alg+kool !22_S
33272	suka-	suka	sukk	22_S	SgG	et	suka- =suka  (SgG  >sukk !22_S
33275	brutotoodangu	toodangu	bruto+toodang	02_S	SgG	et	brutotoodangu =toodangu  (SgG  >bruto+toodang !02_S
33278	majanduskasv	kasv	majandus+kasv	22_S	SgN	et	majanduskasv =kasv  (SgN  >majandus+kasv !22_S
33282	industriaalsed	industriaalse	industriaalne	02_A	PlN	et	industriaalsed =industriaalse  (PlN  >industriaalne !02_A
33290	riigikorraldus	korraldus	riigi+korraldus	11_S	SgN	et	riigikorraldus =korraldus  (SgN  >riigi+korraldus !11_S
33292	perioodiga	perioodi	periood	22_S	SgKom	et	perioodiga =perioodi  (SgKom  >periood !22_S
33298	kremlis	kremli	kreml	02_S	SgIn	et	kremlis =kremli  (SgIn  >kreml !02_S
33300	parteisse	partei	partei	26_S	SgIll	et	parteisse =partei  (SgIll  >partei !26_S
33304	propageeriti	propageeri	propageerima	28_V	IndIpfIps	et	propageeriti =propageeri  (IndIpfIps  >propageerima !28_V
33315	üldstreigid	streigi	üld+streik	22_S	PlN	et	üldstreigid =streigi  (PlN  >üld+streik !22_S
33316	haripunkt	punkt	hari+punkt	22_S	SgN	et	haripunkt =punkt  (SgN  >hari+punkt !22_S
33317	levikuga	leviku	levik	02_S	SgKom	et	levikuga =leviku  (SgKom  >levik !02_S
33324	kirjanikkude	kirjanikku	kirjanik	25_S	PlG	et	kirjanikkude =kirjanikku  (PlG  >kirjanik !25_S
33331	annist	anni	and	22_S	SgEl	et	annist =anni  (SgEl  >and !22_S
33336	arveid	arve	arve	06_S	PlP	et	arveid =arve  (PlP  >arve !06_S
33340	kolhoosidesse	kolhoosi	kolhoos	22_S	PlIll	et	kolhoosidesse =kolhoosi  (PlIll  >kolhoos !22_S
33342	meetod	meetod	meetod	02_S	SgN	et	meetod =meetod  (SgN  >meetod !02_S
33343	klassivõitlus	võitlus	klassi+võitlus	11~09_S	SgN	et	klassivõitlus =võitlus  (SgN  >klassi+võitlus !11~09_S
33345	progressiivne	progressiivne	progressiivne	02_A	SgN	et	progressiivne =progressiivne  (SgN  >progressiivne !02_A
33352	rahvusi	rahvusi	rahvus	11_S	PlP	et	rahvusi =rahvusi  (PlP  >rahvus !11_S
33354	aspekte	aspekte	aspekt	22_S	PlP	et	aspekte =aspekte  (PlP  >aspekt !22_S
33360	bajaan	bajaan	bajaan	22_S	SgN	et	bajaan =bajaan  (SgN  >bajaan !22_S
33363	kiigutades	kiiguta	kiigutama	27_V	Ger	et	kiigutades =kiiguta  (Ger  >kiigutama !27_V
33370	tegeldes	tegel	tegelema	31_V	Ger	et	tegeldes =tegel  (Ger  >tegelema !31_V
33373	rahvalaulud	laulu	rahva+laul	22_S	PlN	et	rahvalaulud =laulu  (PlN  >rahva+laul !22_S
33144	saagid	saagi	saak	22_S	PlN	et	saagid =saagi  (PlN  >saak !22_S
33150	praeguste	praegus	praegune	10~12_A	PlG	et	praeguste =praegus  (PlG  >praegune !10~12_A
33151	kliimaga	kliima	kliima	16_S	SgKom	et	kliimaga =kliima  (SgKom  >kliima !16_S
33159	vägagi	väga	väga	41_D	ID^	et	vägagi =väga  (ID^  >väga !41_D
33165	iseseisvaid	seisva	ise+seisev	02_A	PlP	et	iseseisvaid =seisva  (PlP  >ise+seisev !02_A
33166	tanke	tanke	tank	22_S	PlP	et	tanke =tanke  (PlP  >tank !22_S
33173	larin	larin	larin	02_S	SgN	et	larin =larin  (SgN  >larin !02_S
33176	survet	surve	surve	06_S	SgP	et	survet =surve  (SgP  >surve !06_S
33180	lehvib	lehvi	lehvima	28_V	IndPrSg3	et	lehvib =lehvi  (IndPrSg3  >lehvima !28_V
33183	ideoloogiale	ideoloogia	ideoloogia	01_S	SgAll	et	ideoloogiale =ideoloogia  (SgAll  >ideoloogia !01_S
33187	näitas	näita	näitama	29_V	IndIpfSg3	et	näitas =näita  (IndIpfSg3  >näitama !29_V
33198	isikukultuse	kultuse	isiku+kultus	11~09_S	SgG	et	isikukultuse =kultuse  (SgG  >isiku+kultus !11~09_S
33224	omandas	omanda	omandama	27_V	IndIpfSg3	et	omandas =omanda  (IndIpfSg3  >omandama !27_V
33232	mässama	mässa	mässama	29_V	Sup	et	mässama =mässa  (Sup  >mässama !29_V
33233	mõisnikke	mõisnikke	mõisnik	25_S	PlP	et	mõisnikke =mõisnikke  (PlP  >mõisnik !25_S
33234	nuhtlema	nuhtle	nuhtlema	30_V	Sup	et	nuhtlema =nuhtle  (Sup  >nuhtlema !30_V
33240	täielik	täielik	täielik	25_A	SgN	et	täielik =täielik  (SgN  >täielik !25_A
33241	kapitalistlik	kapitalistlik	kapitalistlik	25_A	SgN	et	kapitalistlik =kapitalistlik  (SgN  >kapitalistlik !25_A
33247	erikorraga	korra	eri+kord	22_S	SgKom	et	erikorraga =korra  (SgKom  >eri+kord !22_S
33251	liider	liider	liider	02_S	SgN	et	liider =liider  (SgN  >liider !02_S
33256	ühiskonnakorralduses	korralduse	ühis+konna+korraldus	11_S	SgIn	et	ühiskonnakorralduses =korralduse  (SgIn  >ühis+konna+korraldus !11_S
33260	käsklusi	käsklusi	käsklus	11_S	PlP	et	käsklusi =käsklusi  (PlP  >käsklus !11_S
33261	mingitesse	mingi	mingi	01_P	PlIll	et	mingitesse =mingi  (PlIll  >mingi !01_P
33266	kodanikud	kodaniku	kodanik	25_S	PlN	et	kodanikud =kodaniku  (PlN  >kodanik !25_S
33274	suurtööstuse	tööstuse	suur+tööstus	11~09_S	SgG	et	suurtööstuse =tööstuse  (SgG  >suur+tööstus !11~09_S
33283	harud	haru	haru	17_S	PlN	et	harud =haru  (PlN  >haru !17_S
33286	kolhoose	kolhoose	kolhoos	22_S	PlP	et	kolhoose =kolhoose  (PlP  >kolhoos !22_S
33297	vaimueluga	elu	vaimu+elu	17_S	SgKom	et	vaimueluga =elu  (SgKom  >vaimu+elu !17_S
33302	keelsele	keelse	keelne	02_A	SgAll	et	keelsele =keelse  (SgAll  >keelne !02_A
33303	segakoolide	kooli	sega+kool	22_S	PlG	et	segakoolide =kooli  (PlG  >sega+kool !22_S
33307	võimul	võimu	võim	22_S	SgAd	et	võimul =võimu  (SgAd  >võim !22_S
33312	avaldub	avaldu	avalduma	27_V	IndPrSg3	et	avaldub =avaldu  (IndPrSg3  >avalduma !27_V
33321	usuõpetuse	õpetuse	usu+õpetus	11_S	SgG	et	usuõpetuse =õpetuse  (SgG  >usu+õpetus !11_S
33325	akadeemiline	akadeemiline	akadeemiline	12_A	SgN	et	akadeemiline =akadeemiline  (SgN  >akadeemiline !12_A
33326	tegelik	tegelik	tegelik	25_A	SgN	et	tegelik =tegelik  (SgN  >tegelik !25_A
33329	ooper	ooper	ooper	02_S	SgN	et	ooper =ooper  (SgN  >ooper !02_S
33334	õiendatakse	õienda	õiendama	27_V	IndPrIps	et	õiendatakse =õienda  (IndPrIps  >õiendama !27_V
33347	laulurahva	rahva	laulu+rahvas	07_S	SgG	et	laulurahva =rahva  (SgG  >laulu+rahvas !07_S
33349	lugemistekstis	teksti	lugemis+tekst	22_S	SgIn	et	lugemistekstis =teksti  (SgIn  >lugemis+tekst !22_S
33350	illustreerida	illustreeri	illustreerima	28_V	Inf	et	illustreerida =illustreeri  (Inf  >illustreerima !28_V
33353	konkreetne	konkreetne	konkreetne	02_A	SgN	et	konkreetne =konkreetne  (SgN  >konkreetne !02_A
33368	missugustel	sugus	mis+sugune	10_P	PlAd	et	missugustel =sugus  (PlAd  >mis+sugune !10_P
33371	regilaulul	laulu	regi+laul	22_S	SgAd	et	regilaulul =laulu  (SgAd  >regi+laul !22_S
33402	laulurahvus	rahvus	laulu+rahvus	11~09_S	SgN	et	laulurahvus =rahvus  (SgN  >laulu+rahvus !11~09_S
33403	ühineb	ühine	ühinema	27_V	IndPrSg3	et	ühineb =ühine  (IndPrSg3  >ühinema !27_V
33405	osales	osale	osalema	27_V	IndIpfSg3	et	osales =osale  (IndIpfSg3  >osalema !27_V
33411	kujunes	kujune	kujunema	27_V	IndIpfSg3	et	kujunes =kujune  (IndIpfSg3  >kujunema !27_V
33412	kordab	korda	kordama	29_V	IndPrSg3	et	kordab =korda  (IndPrSg3  >kordama !29_V
33419	võimaldab	võimalda	võimaldama	27_V	IndPrSg3	et	võimaldab =võimalda  (IndPrSg3  >võimaldama !27_V
33421	veres	vere	veri	20_S	SgIn	et	veres =vere  (SgIn  >veri !20_S
33423	teistedes	ede	teist+ede	16_S	SgIn	et	teistedes =ede  (SgIn  >teist+ede !16_S
33432	värsimõõdult	mõõdu	värsi+mõõt	22_S	SgAbl	et	värsimõõdult =mõõdu  (SgAbl  >värsi+mõõt !22_S
33435	salmialbumid	albumi	salmi+album	02_S	PlN	et	salmialbumid =albumi  (PlN  >salmi+album !02_S
33439	ansamblid	ansambli	ansambel	02_S	PlN	et	ansamblid =ansambli  (PlN  >ansambel !02_S
33184	põhimõte	mõte	põhi+mõte	06_S	SgN	et	põhimõte =mõte  (SgN  >põhi+mõte !06_S
33188	kriisist	kriisi	kriis	22_S	SgEl	et	kriisist =kriisi  (SgEl  >kriis !22_S
33189	pidevast	pideva	pidev	02_A	SgEl	et	pidevast =pideva  (SgEl  >pidev !02_A
33194	situatsiooniga	situatsiooni	situatsioon	22_S	SgKom	et	situatsiooniga =situatsiooni  (SgKom  >situatsioon !22_S
33195	käivitas	käivita	käivitama	27_V	IndIpfSg3	et	käivitas =käivita  (IndIpfSg3  >käivitama !27_V
33204	sattutakse	sattu	sattuma	27_V	IndPrIps	et	sattutakse =sattu  (IndPrIps  >sattuma !27_V
33205	ootamas	oota	ootama	29_V	SupIn	et	ootamas =oota  (SupIn  >ootama !29_V
33206	iseseisvana	seisva	ise+seisev	02_A	SgEs	et	iseseisvana =seisva  (SgEs  >ise+seisev !02_A
33210	üritab	ürita	üritama	27_V	IndPrSg3	et	üritab =ürita  (IndPrSg3  >üritama !27_V
33211	lahutada	lahuta	lahutama	27_V	Inf	et	lahutada =lahuta  (Inf  >lahutama !27_V
33212	säilitas	säilita	säilitama	27_V	IndIpfSg3	et	säilitas =säilita  (IndIpfSg3  >säilitama !27_V
33214	tsaar	tsaar	tsaar	22_S	SgN	et	tsaar =tsaar  (SgN  >tsaar !22_S
33216	maa-aadlikud	aadliku	maa-aadlik	25_S	PlN	et	maa-aadlikud =aadliku  (PlN  >maa-aadlik !25_S
33219	talupoegadele	poega	talu+poeg	22_S	PlAll	et	talupoegadele =poega  (PlAll  >talu+poeg !22_S
33221	valgustusaeg	aeg	valgustus+aeg	22_S	SgN	et	valgustusaeg =aeg  (SgN  >valgustus+aeg !22_S
33229	jumalasõnaraamatuid	raamatu	jumala+sõna+raamat	02_S	PlP	et	jumalasõnaraamatuid =raamatu  (PlP  >jumala+sõna+raamat !02_S
33239	aadlikke	aadlikke	aadlik	25_S	PlP	et	aadlikke =aadlikke  (PlP  >aadlik !25_S
33243	mõisnikul	mõisniku	mõisnik	25_S	SgAd	et	mõisnikul =mõisniku  (SgAd  >mõisnik !25_S
33244	sakslastest	sakslas	sakslane	12?10_S	PlEl	et	sakslastest =sakslas  (PlEl  >sakslane !12?10_S
33245	saksastuks	saksastu	saksastuma	27_V	KndPrPs	et	saksastuks =saksastu  (KndPrPs  >saksastuma !27_V
33248	venestuspoliitikat	poliitika	venestus+poliitika	01_S	SgP	et	venestuspoliitikat =poliitika  (SgP  >venestus+poliitika !01_S
33249	lõunaeesti	eesti	lõuna+eesti	41_G	ID	et	lõunaeesti =eesti  (ID  >lõuna+eesti !41_G
33254	keeleteadlane	teadlane	keele+teadlane	12?10_S	SgN	et	keeleteadlane =teadlane  (SgN  >keele+teadlane !12?10_S
33258	kõneldakse	kõnel	kõnelema	31_V	IndPrIps	et	kõneldakse =kõnel  (IndPrIps  >kõnelema !31_V
33259	riigikorraldust	korraldus	riigi+korraldus	11_S	SgP	et	riigikorraldust =korraldus  (SgP  >riigi+korraldus !11_S
33268	gümnaasiumid	gümnaasiumi	gümnaasium	19~02_S	PlN	et	gümnaasiumid =gümnaasiumi  (PlN  >gümnaasium !19~02_S
33277	rahareform	reform	raha+reform	22_S	SgN	et	rahareform =reform  (SgN  >raha+reform !22_S
33288	hävitati	hävita	hävitama	27_V	IndIpfIps	et	hävitati =hävita  (IndIpfIps  >hävitama !27_V
33291	tööstuses	tööstuse	tööstus	11~09_S	SgIn	et	tööstuses =tööstuse  (SgIn  >tööstus !11~09_S
33299	takistati	takista	takistama	27_V	IndIpfIps	et	takistati =takista  (IndIpfIps  >takistama !27_V
33301	üleminek	minek	üle+minek	02_S	SgN	et	üleminek =minek  (SgN  >üle+minek !02_S
33309	keskkonnaprobleemidest	probleemi	kesk+konna+probleem	22_S	PlEl	et	keskkonnaprobleemidest =probleemi  (PlEl  >kesk+konna+probleem !22_S
33310	rahvusteaduste	teadus	rahvus+teadus	11~09_S	PlG	et	rahvusteaduste =teadus  (PlG  >rahvus+teadus !11~09_S
33313	sotsiaaldemokraatlikud	demokraatliku	sotsiaal+demokraatlik	25_A	PlN	et	sotsiaaldemokraatlikud =demokraatliku  (PlN  >sotsiaal+demokraatlik !25_A
33314	väljendas	väljenda	väljendama	27_V	IndIpfSg3	et	väljendas =väljenda  (IndIpfSg3  >väljendama !27_V
33318	abinõusid	nõu	abi+nõu	26_S	PlP	et	abinõusid =nõu  (PlP  >abi+nõu !26_S
33320	ukaas	ukaas	ukaas	22_S	SgN	et	ukaas =ukaas  (SgN  >ukaas !22_S
33327	teaduspublikatsioonide	publikatsiooni	teadus+publikatsioon	22_S	PlG	et	teaduspublikatsioonide =publikatsiooni  (PlG  >teadus+publikatsioon !22_S
33330	operett	operett	operett	22_S	SgN	et	operett =operett  (SgN  >operett !22_S
33332	muinasteadused	teaduse	muinas+teadus	11~09_S	PlN	et	muinasteadused =teaduse  (PlN  >muinas+teadus !11~09_S
33337	ässitatakse	ässita	ässitama	27_V	IndPrIps	et	ässitatakse =ässita  (IndPrIps  >ässitama !27_V
33341	kohtadel	kohta	koht	22_S	PlAd	et	kohtadel =kohta  (PlAd  >koht !22_S
33344	linnaproletariaadi	proletariaadi	linna+proletariaat	22_S	SgG	et	linnaproletariaadi =proletariaadi  (SgG  >linna+proletariaat !22_S
33346	kirjutage	kirjuta	kirjutama	27_V	ImpPrPl2	et	kirjutage =kirjuta  (ImpPrPl2  >kirjutama !27_V
33348	tuginema	tugine	tuginema	27_V	Sup	et	tuginema =tugine  (Sup  >tuginema !27_V
33358	koorega	koore	koor	13_S	SgKom	et	koorega =koore  (SgKom  >koor !13_S
33359	instrumentaariumit	instrumentaariumi	instrumentaarium	02_S	SgP	et	instrumentaariumit =instrumentaariumi  (SgP  >instrumentaarium !02_S
33361	neel	neel	neel	22_S	SgN	et	neel =neel  (SgN  >neel !22_S
33365	läänemeresoome	läänemeresoome	lääne+mere+soome	41_G	ID	et	läänemeresoome =läänemeresoome  (ID  >lääne+mere+soome !41_G
33369	laulujumal	jumal	laulu+jumal	02_S	SgN	et	laulujumal =jumal  (SgN  >laulu+jumal !02_S
33186	juhtugu	juhtu	juhtuma	27_V	ImpPrPs	et	juhtugu =juhtu  (ImpPrPs  >juhtuma !27_V
33193	otsuse	otsuse	otsus	09_S	SgG	et	otsuse =otsuse  (SgG  >otsus !09_S
33196	elatustase	tase	elatus+tase	04_S	SgN	et	elatustase =tase  (SgN  >elatus+tase !04_S
33199	hukkamõistmine	mõistmine	hukka+mõistmine	12?10_S	SgN	et	hukkamõistmine =mõistmine  (SgN  >hukka+mõistmine !12?10_S
33202	taasiseseisvumissündmused	sündmuse	taas+ise+seisvumis+sündmus	11~09_S	PlN	et	taasiseseisvumissündmused =sündmuse  (PlN  >taas+ise+seisvumis+sündmus !11~09_S
33217	poolvabad	vaba	pool+vaba	17_A	PlN	et	poolvabad =vaba  (PlN  >pool+vaba !17_A
33218	aegsed	aegse	aegne	02_A	PlN	et	aegsed =aegse  (PlN  >aegne !02_A
33220	ihunuhtlust	nuhtlus	ihu+nuhtlus	11~09_S	SgP	et	ihunuhtlust =nuhtlus  (SgP  >ihu+nuhtlus !11~09_S
33223	privileegid	privileegi	privileeg	22_S	PlN	et	privileegid =privileegi  (PlN  >privileeg !22_S
33226	vaated	vaate	vaade	06_S	PlN	et	vaated =vaate  (PlN  >vaade !06_S
33227	mõisnikud	mõisniku	mõisnik	25_S	PlN	et	mõisnikud =mõisniku  (PlN  >mõisnik !25_S
33230	vennastekoguduse	koguduse	vennaste+kogudus	11_S	SgG	et	vennastekoguduse =koguduse  (SgG  >vennaste+kogudus !11_S
33231	mõtetest	mõte	mõte	06_S	PlEl	et	mõtetest =mõte  (PlEl  >mõte !06_S
33237	eepose	eepose	eepos	11~09_S	SgG	et	eepose =eepose  (SgG  >eepos !11~09_S
33238	õhtuid	õhtu	õhtu	01_S	PlP	et	õhtuid =õhtu  (PlP  >õhtu !01_S
33253	kalevipoeg	poeg	kalevi+poeg	22_S	SgN	et	kalevipoeg =poeg  (SgN  >kalevi+poeg !22_S
33255	kaaslasi	kaaslasi	kaaslane	12_S	PlP	et	kaaslasi =kaaslasi  (PlP  >kaaslane !12_S
33257	mõeldakse	mõel	mõtlema	30_V	IndPrIps	et	mõeldakse =mõel  (IndPrIps  >mõtlema !30_V
33269	alluma	allu	alluma	27_V	Sup	et	alluma =allu  (Sup  >alluma !27_V
33279	põlevkivitööstuse	tööstuse	põlev+kivi+tööstus	11~09_S	SgG	et	põlevkivitööstuse =tööstuse  (SgG  >põlev+kivi+tööstus !11~09_S
33296	arm	arm	arm	22_S	SgN	et	arm =arm  (SgN  >arm !22_S
33305	rahvaliikumiste	liikumis	rahva+liikumine	12_S	PlG	et	rahvaliikumiste =liikumis  (PlG  >rahva+liikumine !12_S
33306	meelevaldus	valdus	meele+valdus	11~09_S	SgN	et	meelevaldus =valdus  (SgN  >meele+valdus !11~09_S
33308	sundis	sundi	sundima	28_V	IndIpfSg3	et	sundis =sundi  (IndIpfSg3  >sundima !28_V
33319	töölisklass	klass	töölis+klass	22_S	SgN	et	töölisklass =klass  (SgN  >töölis+klass !22_S
33322	tehnilistel	tehnilis	tehniline	12_A	PlAd	et	tehnilistel =tehnilis  (PlAd  >tehniline !12_A
33328	sõnalavastusele	lavastuse	sõna+lavastus	11_S	SgAll	et	sõnalavastusele =lavastuse  (SgAll  >sõna+lavastus !11_S
33333	sageneb	sagene	sagenema	27_V	IndPrSg3	et	sageneb =sagene  (IndPrSg3  >sagenema !27_V
33335	pealekaebamine	kaebamine	peale+kaebamine	12_S	SgN	et	pealekaebamine =kaebamine  (SgN  >peale+kaebamine !12_S
33351	näidetega	näide	näide	06_S	PlKom	et	näidetega =näide  (PlKom  >näide !06_S
33356	hauani	haua	haud	22_S	SgTer	et	hauani =haua  (SgTer  >haud !22_S
33362	töötades	tööta	töötama	27_V	Ger	et	töötades =tööta  (Ger  >töötama !27_V
33364	esindab	esinda	esindama	27_V	IndPrSg3	et	esindab =esinda  (IndPrSg3  >esindama !27_V
33379	sotsiaalne	sotsiaalne	sotsiaalne	02_A	SgN	et	sotsiaalne =sotsiaalne  (SgN  >sotsiaalne !02_A
33389	summer	summer	summer	02_S	SgN	et	summer =summer  (SgN  >summer !02_S
33390	veedavad	veeda	veetma	34_V	IndPrPl3	et	veedavad =veeda  (IndPrPl3  >veetma !34_V
33401	eestirahvus	rahvus	eesti+rahvus	11~09_S	SgN	et	eestirahvus =rahvus  (SgN  >eesti+rahvus !11~09_S
33415	lõbuse	lõbuse	lõbus	02_A	SgG	et	lõbuse =lõbuse  (SgG  >lõbus !02_A
33416	tujuga	tuju	tuju	17_S	SgKom	et	tujuga =tuju  (SgKom  >tuju !17_S
33424	huvialad	ala	huvi+ala	17_S	PlN	et	huvialad =ala  (PlN  >huvi+ala !17_S
33427	sündmuseks	sündmuse	sündmus	11~09_S	SgTr	et	sündmuseks =sündmuse  (SgTr  >sündmus !11~09_S
33428	suursündmus	sündmus	suur+sündmus	11~09_S	SgN	et	suursündmus =sündmus  (SgN  >suur+sündmus !11~09_S
33429	meeliülendavaiks	ülendava	meeli+ülendav	02_A	PlTr	et	meeliülendavaiks =ülendava  (PlTr  >meeli+ülendav !02_A
33430	nõukogudeaegsed	aegse	nõu+kogude+aegne	02_A	PlN	et	nõukogudeaegsed =aegse  (PlN  >nõu+kogude+aegne !02_A
33437	muusikainstrumente	instrumente	muusika+instrument	22_S	PlP	et	muusikainstrumente =instrumente  (PlP  >muusika+instrument !22_S
33438	vanim	vani	vana	17_AS	IM_sA	et	"vanim %vani  )IM_sA  <vana ;17_AS
33440	esitada	esita	esitama	27_V	Inf	et	esitada =esita  (Inf  >esitama !27_V
33444	laulsin	laul	laulma	33_V	IndIpfSg1	et	laulsin =laul  (IndIpfSg1  >laulma !33_V
33453	kaasaegses	aegse	kaas+aegne	02_A	SgIn	et	kaasaegses =aegse  (SgIn  >kaas+aegne !02_A
33466	soome-	soome	soome	41_G	ID	et	soome- =soome  (ID  >soome !41_G
33467	tantsib	tantsi	tantsima	28_V	IndPrSg3	et	tantsib =tantsi  (IndPrSg3  >tantsima !28_V
33473	väljendusvahed	vahe	väljendus+vahe	16_S	PlN	et	väljendusvahed =vahe  (PlN  >väljendus+vahe !16_S
33263	seltside	seltsi	selts	22_S	PlG	et	seltside =seltsi  (PlG  >selts !22_S
33264	haritlasi	haritlasi	haritlane	12_S	PlP	et	haritlasi =haritlasi  (PlP  >haritlane !12_S
33265	moodustati	moodusta	moodustama	27_V	IndIpfIps	et	moodustati =moodusta  (IndIpfIps  >moodustama !27_V
33270	välisturgude	turgu	välis+turg	22_S	PlG	et	välisturgude =turgu  (PlG  >välis+turg !22_S
33271	tööstusharud	haru	tööstus+haru	17_S	PlN	et	tööstusharud =haru  (PlN  >tööstus+haru !17_S
33273	siidikoevabrik	vabrik	siidi+koe+vabrik	02_S	SgN	et	siidikoevabrik =vabrik  (SgN  >siidi+koe+vabrik !02_S
33276	kahekordistamine	kordistamine	kahe+kordistamine	12_S	SgN	et	kahekordistamine =kordistamine  (SgN  >kahe+kordistamine !12_S
33280	metallitööstusega	tööstuse	metalli+tööstus	11~09_S	SgKom	et	metallitööstusega =tööstuse  (SgKom  >metalli+tööstus !11~09_S
33281	rajama	raja	rajama	27_V	Sup	et	rajama =raja  (Sup  >rajama !27_V
33284	rahvamajanduses	majanduse	rahva+majandus	11_S	SgIn	et	rahvamajanduses =majanduse  (SgIn  >rahva+majandus !11_S
33285	põllumajanduses	majanduse	põllu+majandus	11_S	SgIn	et	põllumajanduses =majanduse  (SgIn  >põllu+majandus !11_S
33287	seltse	seltse	selts	22_S	PlP	et	seltse =seltse  (PlP  >selts !22_S
33289	suruda	suru	suruma	27_V	Inf	et	suruda =suru  (Inf  >suruma !27_V
33293	stalini-aegne	aegne	stalini-aegne	02_A	SgN	et	stalini-aegne =aegne  (SgN  >stalini-aegne !02_A
33294	hirm	hirm	hirm	22_S	SgN	et	hirm =hirm  (SgN  >hirm !22_S
33295	elavnes	elavne	elavnema	27_V	IndIpfSg3	et	elavnes =elavne  (IndIpfSg3  >elavnema !27_V
33311	loomismeetod	meetod	loo+mis+meetod	02_S	SgN	et	loomismeetod =meetod  (SgN  >loo+mis+meetod !02_S
33323	humanitaaraladel	ala	humanitaar+ala	17_S	PlAd	et	humanitaaraladel =ala  (PlAd  >humanitaar+ala !17_S
33338	kustutada	kustuta	kustutama	27_V	Inf	et	kustutada =kustuta  (Inf  >kustutama !27_V
33339	intelligents	intelligents	intelligents	22_S	SgN	et	intelligents =intelligents  (SgN  >intelligents !22_S
33355	rahvalauludeski	laulu	rahva+laul	22_S	PlIn^	et	rahvalauludeski =laulu  (PlIn^  >rahva+laul !22_S
33357	piibliast	ast	piibli+ast	22_S	SgN	et	piibliast =ast  (SgN  >piibli+ast !22_S
33366	eestlasi	eestlasi	eestlane	12_S	PlP	et	eestlasi =eestlasi  (PlP  >eestlane !12_S
33367	muinastest	test	muinas+test	22_S	SgN	et	muinastest =test  (SgN  >muinas+test !22_S
33375	ots	ots	ots	23?22_S	SgN	et	ots =ots  (SgN  >ots !23?22_S
33378	esteetiline	esteetiline	esteetiline	12_A	SgN	et	esteetiline =esteetiline  (SgN  >esteetiline !12_A
33384	halval	halva	halb	22_A	SgAd	et	halval =halva  (SgAd  >halb !22_A
33385	pidutsedes	pidutse	pidutsema	27_V	Ger	et	pidutsedes =pidutse  (Ger  >pidutsema !27_V
33387	kirikulaulmine	laulmine	kiriku+laulmine	12?10_S	SgN	et	kirikulaulmine =laulmine  (SgN  >kiriku+laulmine !12?10_S
33393	rahvatantsidega	tantsi	rahva+tants	22_S	PlKom	et	rahvatantsidega =tantsi  (PlKom  >rahva+tants !22_S
33394	rahvalauludega	laulu	rahva+laul	22_S	PlKom	et	rahvalauludega =laulu  (PlKom  >rahva+laul !22_S
33395	loodushääled	hääle	loodus+hääl	13_S	PlN	et	loodushääled =hääle  (PlN  >loodus+hääl !13_S
33398	rahvalaulmist	laulmis	rahva+laulmine	12?10_S	SgP	et	rahvalaulmist =laulmis  (SgP  >rahva+laulmine !12?10_S
33399	rahvariided	riide	rahva+riie	06_S	PlN	et	rahvariided =riide  (PlN  >rahva+riie !06_S
33400	vanadel	vana	vana	17_AS	PlAd	et	vanadel =vana  (PlAd  >vana !17_AS
33413	koorilaulud	laulu	koori+laul	22_S	PlN	et	koorilaulud =laulu  (PlN  >koori+laul !22_S
33420	seostub	seostu	seostuma	27_V	IndPrSg3	et	seostub =seostu  (IndPrSg3  >seostuma !27_V
33434	laululehed	lehe	laulu+leht	22_S	PlN	et	laululehed =lehe  (PlN  >laulu+leht !22_S
33443	esinesime	esine	esinema	27_V	IndIpfPl1	et	esinesime =esine  (IndIpfPl1  >esinema !27_V
33448	puul	puu	puu	26_S	SgAd	et	puul =puu  (SgAd  >puu !26_S
33449	kirikulaulud	laulu	kiriku+laul	22_S	PlN	et	kirikulaulud =laulu  (PlN  >kiriku+laul !22_S
33454	väljaspoolsed	poolse	väljas+poolne	02_A	PlN	et	väljaspoolsed =poolse  (PlN  >väljas+poolne !02_A
33460	näitus	näitus	näitus	11~09_S	SgN	et	näitus =näitus  (SgN  >näitus !11~09_S
33461	instrumendiga	instrumendi	instrument	22_S	SgKom	et	instrumendiga =instrumendi  (SgKom  >instrument !22_S
33462	tantsidega	tantsi	tants	22_S	PlKom	et	tantsidega =tantsi  (PlKom  >tants !22_S
33463	lauludega	laulu	laul	22_S	PlKom	et	lauludega =laulu  (PlKom  >laul !22_S
33464	osavõtjad	võtja	osa+võtja	01_S	PlN	et	osavõtjad =võtja  (PlN  >osa+võtja !01_S
33469	publikule	publiku	publik	02_S	SgAll	et	publikule =publiku  (SgAll  >publik !02_S
33477	laulurevolutsioon	revolutsioon	laulu+revolutsioon	22_S	SgN	et	laulurevolutsioon =revolutsioon  (SgN  >laulu+revolutsioon !22_S
33480	regatil	regati	regatt	22_S	SgAd	et	regatil =regati  (SgAd  >regatt !22_S
33483	pillimäng	mäng	pilli+mäng	22_S	SgN	et	pillimäng =mäng  (SgN  >pilli+mäng !22_S
33485	esmakordsed	kordse	esma+kordne	02_AS	PlN	et	esmakordsed =kordse  (PlN  >esma+kordne !02_AS
33372	lauladki	laula	laulma	33_V	IndPrSg2^	et	lauladki =laula  (IndPrSg2^  >laulma !33_V
33377	sümboliteks	sümboli	sümbol	02_S	PlTr	et	sümboliteks =sümboli  (PlTr  >sümbol !02_S
33381	instrumente	instrumente	instrument	22_S	PlP	et	instrumente =instrumente  (PlP  >instrument !22_S
33386	ristiusuga	usu	risti+usk	22_S	SgKom	et	ristiusuga =usu  (SgKom  >risti+usk !22_S
33388	mitmehäälset	häälse	mitme+häälne	02_A	SgP	et	mitmehäälset =häälse  (SgP  >mitme+häälne !02_A
33391	telefonid	telefoni	telefon	19_S	PlN	et	telefonid =telefoni  (PlN  >telefon !19_S
33392	televiisorid	televiisori	televiisor	02_S	PlN	et	televiisorid =televiisori  (PlN  >televiisor !02_S
33396	emad	ema	ema	17_S	PlN	et	emad =ema  (PlN  >ema !17_S
33397	rahuldada	rahulda	rahuldama	27_V	Inf	et	rahuldada =rahulda  (Inf  >rahuldama !27_V
33404	laulupidul	pidu	laulu+pidu	17_S	SgAd	et	laulupidul =pidu  (SgAd  >laulu+pidu !17_S
33406	puhkpilliorkestrit	orkestri	puhk+pilli+orkester	02_S	SgP	et	puhkpilliorkestrit =orkestri  (SgP  >puhk+pilli+orkester !02_S
33407	üksina	üksi	üks	22_NP	SgEs	et	üksina =üksi  (SgEs  >üks !22_NP
33408	jälje	jälje	jälg	22_S	SgG	et	jälje =jälje  (SgG  >jälg !22_S
33414	põllutööajal	aja	põllu+töö+aeg	22_S	SgAd	et	põllutööajal =aja  (SgAd  >põllu+töö+aeg !22_S
33418	kontaktis	kontakti	kontakt	22_S	SgIn	et	kontaktis =kontakti  (SgIn  >kontakt !22_S
33422	õhu	õhu	õhk	22_S	SgG	et	õhu =õhu  (SgG  >õhk !22_S
33425	rahvalauludes	laulu	rahva+laul	22_S	PlIn	et	rahvalauludes =laulu  (PlIn  >rahva+laul !22_S
33426	mistõttu	mistõttu	mis+tõttu	41_D	ID	et	mistõttu =mistõttu  (ID  >mis+tõttu !41_D
33431	euroopast	euroopa	euroopa	01_H	SgEl	et	euroopast =euroopa  (SgEl  >euroopa !01_H
33455	tähistame	tähista	tähistama	27_V	IndPrPl1	et	tähistame =tähista  (IndPrPl1  >tähistama !27_V
33470	kuulajaskond	kuulajaskond	kuulajaskond	22_S	SgN	et	kuulajaskond =kuulajaskond  (SgN  >kuulajaskond !22_S
33472	samu	samu	sama	17_P	PlP	et	samu =samu  (PlP  >sama !17_P
33474	põllu	põllu	põld	22_S	SgG	et	põllu =põllu  (SgG  >põld !22_S
33475	merel	mere	meri	20_S	SgAd	et	merel =mere  (SgAd  >meri !20_S
33482	tähtsat	tähtsa	tähtis	02_A	SgP	et	tähtsat =tähtsa  (SgP  >tähtis !02_A
33499	ärkamisajaga	aja	ärkamis+aeg	22_S	SgKom	et	ärkamisajaga =aja  (SgKom  >ärkamis+aeg !22_S
33501	taasiseseisvumisele	seisvumise	taas+ise+seisvumine	12_S	SgAll	et	taasiseseisvumisele =seisvumise  (SgAll  >taas+ise+seisvumine !12_S
33508	ranged	range	range	01_A	PlN	et	ranged =range  (PlN  >range !01_A
33510	eepostest	eepos	eepos	11~09_S	PlEl	et	eepostest =eepos  (PlEl  >eepos !11~09_S
33520	flööt	flööt	flööt	22_S	SgN	et	flööt =flööt  (SgN  >flööt !22_S
33528	rahvakultuurist	kultuuri	rahva+kultuur	22_S	SgEl	et	rahvakultuurist =kultuuri  (SgEl  >rahva+kultuur !22_S
33529	osal	osa	osa	17_S	SgAd	et	osal =osa  (SgAd  >osa !17_S
33542	laulutraditsioonidest	traditsiooni	laulu+traditsioon	22_S	PlEl	et	laulutraditsioonidest =traditsiooni  (PlEl  >laulu+traditsioon !22_S
33547	rahvatraditsioonid	traditsiooni	rahva+traditsioon	22_S	PlN	et	rahvatraditsioonid =traditsiooni  (PlN  >rahva+traditsioon !22_S
33558	eestlasest	eestlase	eestlane	12?10_S	SgEl	et	eestlasest =eestlase  (SgEl  >eestlane !12?10_S
33565	taasiseseisvumiseni	seisvumise	taas+ise+seisvumine	12_S	SgTer	et	taasiseseisvumiseni =seisvumise  (SgTer  >taas+ise+seisvumine !12_S
33570	eelmisest	eelmise	eelmine	12?10_A	SgEl	et	eelmisest =eelmise  (SgEl  >eelmine !12?10_A
33572	elad	ela	elama	27_V	IndPrSg2	et	elad =ela  (IndPrSg2  >elama !27_V
33573	laulufestivalid	festivali	laulu+festival	19_S	PlN	et	laulufestivalid =festivali  (PlN  >laulu+festival !19_S
33576	koored	koore	koor	13_S	PlN	et	koored =koore  (PlN  >koor !13_S
33577	lastekoored	koore	laste+koor	13_S	PlN	et	lastekoored =koore  (PlN  >laste+koor !13_S
33578	osavõtjana	võtja	osa+võtja	01_S	SgEs	et	osavõtjana =võtja  (SgEs  >osa+võtja !01_S
33579	osavõtjate	võtja	osa+võtja	01_S	PlG	et	osavõtjate =võtja  (PlG  >osa+võtja !01_S
33580	valgevenelased	venelase	valge+venelane	12_S	PlN	et	valgevenelased =venelase  (PlN  >valge+venelane !12_S
33582	festivale	festivale	festival	19_S	PlP	et	festivale =festivale  (PlP  >festival !19_S
33588	laulad	laula	laulma	33_V	IndPrSg2	et	laulad =laula  (IndPrSg2  >laulma !33_V
33589	laulate	laula	laulma	33_V	IndPrPl2	et	laulate =laula  (IndPrPl2  >laulma !33_V
33591	solistidele	solisti	solist	22_S	PlAll	et	solistidele =solisti  (PlAll  >solist !22_S
33593	regioonides	regiooni	regioon	22_S	PlIn	et	regioonides =regiooni  (PlIn  >regioon !22_S
33597	armastama	armasta	armastama	27_V	Sup	et	armastama =armasta  (Sup  >armastama !27_V
33601	lauladeta	la	lau+la	26_S	PlAb	et	lauladeta =la  (PlAb  >lau+la !26_S
33608	välismaalased	maalase	välis+maalane	12?10_S	PlN	et	välismaalased =maalase  (PlN  >välis+maalane !12?10_S
33615	väljendusvahendid	vahendi	väljendus+vahend	02_S	PlN	et	väljendusvahendid =vahendi  (PlN  >väljendus+vahend !02_S
33374	laudes	laude	laut	22_S	PlIn	et	laudes =laude  (PlIn  >laut !22_S
33376	rahvuslikeks	rahvuslike	rahvuslik	25_A	PlTr	et	rahvuslikeks =rahvuslike  (PlTr  >rahvuslik !25_A
33380	tuttavadega	ava	tutt+ava	17_S	PlKom	et	tuttavadega =ava  (PlKom  >tutt+ava !17_S
33382	muusikata	muusika	muusika	01_S	SgAb	et	muusikata =muusika  (SgAb  >muusika !01_S
33383	projektides	projekti	projekt	22_S	PlIn	et	projektides =projekti  (PlIn  >projekt !22_S
33409	olud	olu	olu	17_S	PlN	et	olud =olu  (PlN  >olu !17_S
33410	rahvamuusikat	muusika	rahva+muusika	01_S	SgP	et	rahvamuusikat =muusika  (SgP  >rahva+muusika !01_S
33417	nõukogudeajal	aja	nõu+kogude+aeg	22_S	SgAd	et	nõukogudeajal =aja  (SgAd  >nõu+kogude+aeg !22_S
33433	ülestähendus	tähendus	üles+tähendus	11_S	SgN	et	ülestähendus =tähendus  (SgN  >üles+tähendus !11_S
33436	pulmades	pulma	pulm	22_S	PlIn	et	pulmades =pulma  (PlIn  >pulm !22_S
33441	lauldes	laul	laulma	33_V	Ger	et	lauldes =laul  (Ger  >laulma !33_V
33445	rahval	rahva	rahvas	07_S	SgAd	et	rahval =rahva  (SgAd  >rahvas !07_S
33446	jumalaid	jumala	jumal	02_S	PlP	et	jumalaid =jumala  (PlP  >jumal !02_S
33447	kivil	kivi	kivi	17_S	SgAd	et	kivil =kivi  (SgAd  >kivi !17_S
33450	emalaulud	laulu	ema+laul	22_S	PlN	et	emalaulud =laulu  (PlN  >ema+laul !22_S
33451	elamistingimused	tingimuse	elamis+tingimus	11_S	PlN	et	elamistingimused =tingimuse  (PlN  >elamis+tingimus !11_S
33456	laval	lava	lava	17_S	SgAd	et	laval =lava  (SgAd  >lava !17_S
33457	tantsudest	tantsu	tants	22_S	PlEl	et	tantsudest =tantsu  (PlEl  >tants !22_S
33458	tantsud	tantsu	tants	22_S	PlN	et	tantsud =tantsu  (PlN  >tants !22_S
33459	tantsus	tantsu	tants	22_S	SgIn	et	tantsus =tantsu  (SgIn  >tants !22_S
33465	veedad	veeda	veetma	34_V	IndPrSg2	et	veedad =veeda  (IndPrSg2  >veetma !34_V
33471	tuhandete	tuhande	tuhat	02_N	PlG	et	tuhandete =tuhande  (PlG  >tuhat !02_N
33476	laulukultuur	kultuur	laulu+kultuur	22_S	SgN	et	laulukultuur =kultuur  (SgN  >laulu+kultuur !22_S
33478	võtad	võta	võtma	35_V	IndPrSg2	et	võtad =võta  (IndPrSg2  >võtma !35_V
33479	muhu	muhu	muhk	22_S	SgG	et	muhu =muhu  (SgG  >muhk !22_S
33481	surfilaagrisse	laagri	surfi+laager	02_S	SgIll	et	surfilaagrisse =laagri  (SgIll  >surfi+laager !02_S
33484	esmaalguse	alguse	esma+algus	11~09_S	SgG	et	esmaalguse =alguse  (SgG  >esma+algus !11~09_S
33492	üheskoos	üheskoos	ühes+koos	41_DK	ID	et	üheskoos =üheskoos  (ID  >ühes+koos !41_DK
33496	tähelepanuväärne	väärne	tähele+panu+väärne	02_A	SgN	et	tähelepanuväärne =väärne  (SgN  >tähele+panu+väärne !02_A
33503	avanema	avane	avanema	27_V	Sup	et	avanema =avane  (Sup  >avanema !27_V
33505	naiskoorid	koori	nais+koor	22_S	PlN	et	naiskoorid =koori  (PlN  >nais+koor !22_S
33514	sedapuhku	sedapuhku	seda+puhku	41_D	ID	et	sedapuhku =sedapuhku  (ID  >seda+puhku !41_D
33515	laulusid	laulu	laul	22_S	PlP	et	laulusid =laulu  (PlP  >laul !22_S
33517	pulm	pulm	pulm	22_S	SgN	et	pulm =pulm  (SgN  >pulm !22_S
33531	mäletab	mäleta	mäletama	27_V	IndPrSg3	et	mäletab =mäleta  (IndPrSg3  >mäletama !27_V
33533	tutvub	tutvu	tutvuma	27_V	IndPrSg3	et	tutvub =tutvu  (IndPrSg3  >tutvuma !27_V
33535	laulude	laulu	laul	22_S	PlG	et	laulude =laulu  (PlG  >laul !22_S
33537	sümbolitele	sümboli	sümbol	02_S	PlAll	et	sümbolitele =sümboli  (PlAll  >sümbol !02_S
33539	eestlasel	eestlase	eestlane	12?10_S	SgAd	et	eestlasel =eestlase  (SgAd  >eestlane !12?10_S
33540	laulutraditsiooniseks	seks	laulu+traditsiooni+seks	22_S	SgN	et	laulutraditsiooniseks =seks  (SgN  >laulu+traditsiooni+seks !22_S
33541	viiendat	viienda	viies	02_O	SgP	et	viiendat =viienda  (SgP  >viies !02_O
33544	laulupeodest	peo	laulu+peo	26_S	PlEl	et	laulupeodest =peo  (PlEl  >laulu+peo !26_S
33546	rahvatraditsioon	traditsioon	rahva+traditsioon	22_S	SgN	et	rahvatraditsioon =traditsioon  (SgN  >rahva+traditsioon !22_S
33552	ühendab	ühenda	ühendama	27_V	IndPrSg3	et	ühendab =ühenda  (IndPrSg3  >ühendama !27_V
33555	lemmikuim	uim	lemmik+uim	22_S	SgN	et	lemmikuim =uim  (SgN  >lemmik+uim !22_S
33563	kommunistliku	kommunistliku	kommunistlik	25_A	SgG	et	kommunistliku =kommunistliku  (SgG  >kommunistlik !25_A
33564	sisaldas	sisalda	sisaldama	27_V	IndIpfSg3	et	sisaldas =sisalda  (IndIpfSg3  >sisaldama !27_V
33567	repertuaar	repertuaar	repertuaar	22_S	SgN	et	repertuaar =repertuaar  (SgN  >repertuaar !22_S
33569	esindas	esinda	esindama	27_V	IndIpfSg3	et	esindas =esinda  (IndIpfSg3  >esindama !27_V
33574	põllus	põllu	põld	22_S	SgIn	et	põllus =põllu  (SgIn  >põld !22_S
33585	põhi	põhi	põhi	24_S	SgN	et	põhi =põhi  (SgN  >põhi !24_S
33592	omab	oma	omama	27_V	IndPrSg3	et	omab =oma  (IndPrSg3  >omama !27_V
33595	kirikuste	us	kirik+uks	14_S	PlG	et	kirikuste =us  (PlG  >kirik+uks !14_S
33603	ühines	ühine	ühinema	27_V	IndIpfSg3	et	ühines =ühine  (IndIpfSg3  >ühinema !27_V
33442	ansamblis	ansambli	ansambel	02_S	SgIn	et	ansamblis =ansambli  (SgIn  >ansambel !02_S
33452	härrad	härra	härra	16_S	PlN	et	härrad =härra  (PlN  >härra !16_S
33468	jõulupühad	püha	jõulu+püha	17_SA	PlN	et	jõulupühad =püha  (PlN  >jõulu+püha !17_SA
33486	kihnus	kihnu	kihn	22_S	SgIn	et	kihnus =kihnu  (SgIn  >kihn !22_S
33487	bänd	bänd	bänd	22_S	SgN	et	bänd =bänd  (SgN  >bänd !22_S
33489	nurkadest	nurka	nurk	22_S	PlEl	et	nurkadest =nurka  (PlEl  >nurk !22_S
33491	tartusse	tartu	tartu	01_H	SgIll	et	tartusse =tartu  (SgIll  >tartu !01_H
33500	sammudest	sammu	samm	22_S	PlEl	et	sammudest =sammu  (PlEl  >samm !22_S
33506	lastekoorid	koori	laste+koor	22_S	PlN	et	lastekoorid =koori  (PlN  >laste+koor !22_S
33507	kehtestati	kehtesta	kehtestama	27_V	IndIpfIps	et	kehtestati =kehtesta  (IndIpfIps  >kehtestama !27_V
33509	propagandistlikke	propagandistlikke	propagandistlik	25_A	PlP	et	propagandistlikke =propagandistlikke  (PlP  >propagandistlik !25_A
33511	loomingutes	loomingu	looming	02_S	PlIn	et	loomingutes =loomingu  (PlIn  >looming !02_S
33513	lauluväljakule	väljaku	laulu+väljak	02_S	SgAll	et	lauluväljakule =väljaku  (SgAll  >laulu+väljak !02_S
33516	muinasjutt	jutt	muinas+jutt	22_S	SgN	et	muinasjutt =jutt  (SgN  >muinas+jutt !22_S
33518	mutte	mutte	mutt	22_S	PlP	et	mutte =mutte  (PlP  >mutt !22_S
33530	suureneda	suurene	suurenema	27_V	Inf	et	suureneda =suurene  (Inf  >suurenema !27_V
33532	natsionaalne	natsionaalne	natsionaalne	02_A	SgN	et	natsionaalne =natsionaalne  (SgN  >natsionaalne !02_A
33536	identiteeditunne	tunne	identiteedi+tunne	06_S	SgN	et	identiteeditunne =tunne  (SgN  >identiteedi+tunne !06_S
33538	isaalt	alt	isa+alt	22_S	SgN	et	isaalt =alt  (SgN  >isa+alt !22_S
33545	seesama	seesama	seesam	02_S	SgG	et	seesama =seesama  (SgG  >seesam !02_S
33549	laulurahvaks	rahva	laulu+rahvas	07_S	SgTr	et	laulurahvaks =rahva  (SgTr  >laulu+rahvas !07_S
33551	tujud	tuju	tuju	17_S	PlN	et	tujud =tuju  (PlN  >tuju !17_S
33568	traditsioonile	traditsiooni	traditsioon	22_S	SgAll	et	traditsioonile =traditsiooni  (SgAll  >traditsioon !22_S
33571	käsitleda	käsitle	käsitlema	27_V	Inf	et	käsitleda =käsitle  (Inf  >käsitlema !27_V
33599	traditsioonidega	traditsiooni	traditsioon	22_S	PlKom	et	traditsioonidega =traditsiooni  (PlKom  >traditsioon !22_S
33606	edastada	edasta	edastama	27_V	Inf	et	edastada =edasta  (Inf  >edastama !27_V
33607	vanasti	vanasti	vanasti	41_D	ID	et	vanasti =vanasti  (ID  >vanasti !41_D
33609	soomlased	soomlase	soomlane	12?10_S	PlN	et	soomlased =soomlase  (PlN  >soomlane !12?10_S
33611	sõrm	sõrm	sõrm	22_S	SgN	et	sõrm =sõrm  (SgN  >sõrm !22_S
33612	pulmas	pulma	pulm	22_S	SgIn	et	pulmas =pulma  (SgIn  >pulm !22_S
33622	istub	istu	istuma	28_V	IndPrSg3	et	istub =istu  (IndPrSg3  >istuma !28_V
33623	kalapüüdmisel	püüdmise	kala+püüdmine	12?10_S	SgAd	et	kalapüüdmisel =püüdmise  (SgAd  >kala+püüdmine !12?10_S
33625	laulavana	lava	lau+lava	17_S	SgEs	et	laulavana =lava  (SgEs  >lau+lava !17_S
33630	pillimängijani	mängija	pilli+mängija	01_S	SgTer	et	pillimängijani =mängija  (SgTer  >pilli+mängija !01_S
33634	manifestatsioon	manifestatsioon	manifestatsioon	22_S	SgN	et	manifestatsioon =manifestatsioon  (SgN  >manifestatsioon !22_S
33647	kihnul	kihnu	kihn	22_S	SgAd	et	kihnul =kihnu  (SgAd  >kihn !22_S
33651	vokaal	vokaal	vokaal	22_S	SgN	et	vokaal =vokaal  (SgN  >vokaal !22_S
33665	meestekoorid	koori	meeste+koor	22_S	PlN	et	meestekoorid =koori  (PlN  >meeste+koor !22_S
33673	liigus	liigu	liik	22_S	SgIn	et	liigus =liigu  (SgIn  >liik !22_S
33677	mures	mure	mure	16_S	SgIn	et	mures =mure  (SgIn  >mure !16_S
33678	tutvume	tutvu	tutvuma	27_V	IndPrPl1	et	tutvume =tutvu  (IndPrPl1  >tutvuma !27_V
33682	poistekoorid	koori	poiste+koor	22_S	PlN	et	poistekoorid =koori  (PlN  >poiste+koor !22_S
33683	orkestreid	orkestre	orkester	02_S	PlP	et	orkestreid =orkestre  (PlP  >orkester !02_S
33684	laulutraditsioonist	traditsiooni	laulu+traditsioon	22_S	SgEl	et	laulutraditsioonist =traditsiooni  (SgEl  >laulu+traditsioon !22_S
33685	abistas	abista	abistama	27_V	IndIpfSg3	et	abistas =abista  (IndIpfSg3  >abistama !27_V
33690	vanadest	vana	vana	17_AS	PlEl	et	vanadest =vana  (PlEl  >vana !17_AS
33700	nimel	nime	nimi	20_S	SgAd	et	nimel =nime  (SgAd  >nimi !20_S
33710	kuuendast	kuuenda	kuues	02_O	SgEl	et	kuuendast =kuuenda  (SgEl  >kuues !02_O
33711	rahvafestivalid	festivali	rahva+festival	19_S	PlN	et	rahvafestivalid =festivali  (PlN  >rahva+festival !19_S
33716	iseväljendamine	väljendamine	ise+väljendamine	12_S	SgN	et	iseväljendamine =väljendamine  (SgN  >ise+väljendamine !12_S
33719	tantsime	tantsi	tantsima	28_V	IndPrPl1	et	tantsime =tantsi  (IndPrPl1  >tantsima !28_V
33721	seisukoht	koht	seisu+koht	22_S	SgN	et	seisukoht =koht  (SgN  >seisu+koht !22_S
33722	lauluharrastusega	harrastuse	laulu+harrastus	11_S	SgKom	et	lauluharrastusega =harrastuse  (SgKom  >laulu+harrastus !11_S
33488	koguneb	kogune	kogunema	27_V	IndPrSg3	et	koguneb =kogune  (IndPrSg3  >kogunema !27_V
33495	tantsutraditsioonidele	traditsiooni	tantsu+traditsioon	22_S	PlAll	et	tantsutraditsioonidele =traditsiooni  (PlAll  >tantsu+traditsioon !22_S
33497	laulutraditsioonid	traditsiooni	laulu+traditsioon	22_S	PlN	et	laulutraditsioonid =traditsiooni  (PlN  >laulu+traditsioon !22_S
33498	trükitati	tati	trüki+tatt	22_S	SgG	et	trükitati =tati  (SgG  >trüki+tatt !22_S
33519	akordion	akordion	akordion	19~02_S	SgN	et	akordion =akordion  (SgN  >akordion !19~02_S
33526	akordionit	akordioni	akordion	02_S	SgP	et	akordionit =akordioni  (SgP  >akordion !02_S
33534	rahvariietusega	riietuse	rahva+riietus	11_S	SgKom	et	rahvariietusega =riietuse  (SgKom  >rahva+riietus !11_S
33543	laulupeodel	peo	laulu+peo	26_S	PlAd	et	laulupeodel =peo  (PlAd  >laulu+peo !26_S
33548	identiteeditunnete	tunne	identiteedi+tunne	06_S	PlG	et	identiteeditunnete =tunne  (PlG  >identiteedi+tunne !06_S
33550	eurovisioonil	visiooni	euro+visioon	22_S	SgAd	et	eurovisioonil =visiooni  (SgAd  >euro+visioon !22_S
33554	laulurahvata	rahva	laulu+rahvas	07_S	SgAb	et	laulurahvata =rahva  (SgAb  >laulu+rahvas !07_S
33557	vanaisad	isa	vana+isa	17_S	PlN	et	vanaisad =isa  (PlN  >vana+isa !17_S
33559	traditsiooniks	traditsiooni	traditsioon	22_S	SgTr	et	traditsiooniks =traditsiooni  (SgTr  >traditsioon !22_S
33560	musikaalseid	musikaalse	musikaalne	02_A	PlP	et	musikaalseid =musikaalse  (PlP  >musikaalne !02_A
33575	koored	koore	koor	13_S	PlN	et	koored =koore  (PlN  >koor !13_S
33584	kultuuril	kultuuri	kultuur	22_S	SgAd	et	kultuuril =kultuuri  (SgAd  >kultuur !22_S
33590	koorikultuuris	kultuuri	koori+kultuur	22_S	SgIn	et	koorikultuuris =kultuuri  (SgIn  >koori+kultuur !22_S
33598	rahvalaulude	laulu	rahva+laul	22_S	PlG	et	rahvalaulude =laulu  (PlG  >rahva+laul !22_S
33602	kogunema	kogune	kogunema	27_V	Sup	et	kogunema =kogune  (Sup  >kogunema !27_V
33605	lauluta	laulu	laul	22_S	SgAb	et	lauluta =laulu  (SgAb  >laul !22_S
33616	emotsionaalsed	emotsionaalse	emotsionaalne	02_A	PlN	et	emotsionaalsed =emotsionaalse  (PlN  >emotsionaalne !02_A
33621	puuoksadega	oksa	puu+oks	22_S	PlKom	et	puuoksadega =oksa  (PlKom  >puu+oks !22_S
33624	moes	moe	mood	22_S	SgIn	et	moes =moe  (SgIn  >mood !22_S
33635	saksad	saksa	saks	23?22_S	PlN	et	saksad =saksa  (PlN  >saks !23?22_S
33637	ajagu	aja	ajama	27_V	ImpPrPs	et	ajagu =aja  (ImpPrPs  >ajama !27_V
33643	koordus	koordu	koorduma	27_V	IndIpfSg3	et	koordus =koordu  (IndIpfSg3  >koorduma !27_V
33646	vanalaulud	laulu	vana+laul	22_S	PlN	et	vanalaulud =laulu  (PlN  >vana+laul !22_S
33648	tänapäevaajal	aja	täna+päeva+aeg	22_S	SgAd	et	tänapäevaajal =aja  (SgAd  >täna+päeva+aeg !22_S
33654	vaimulike	vaimulike	vaimulik	25_AS	PlG	et	vaimulike =vaimulike  (PlG  >vaimulik !25_AS
33659	tasemele	taseme	tase	04_S	SgAll	et	tasemele =taseme  (SgAll  >tase !04_S
33660	nurkades	nurka	nurk	22_S	PlIn	et	nurkades =nurka  (PlIn  >nurk !22_S
33663	tuntakse	tun	tundma	34_V	IndPrIps	et	tuntakse =tun  (IndPrIps  >tundma !34_V
33666	tuhandet	tuhande	tuhat	02_N	SgP	et	tuhandet =tuhande  (SgP  >tuhat !02_N
33667	rahuneb	rahune	rahunema	27_V	IndPrSg3	et	rahuneb =rahune  (IndPrSg3  >rahunema !27_V
33672	rahvalaulmise	laulmise	rahva+laulmine	12?10_S	SgG	et	rahvalaulmise =laulmise  (SgG  >rahva+laulmine !12?10_S
33674	juubel	juubel	juubel	02_S	SgN	et	juubel =juubel  (SgN  >juubel !02_S
33679	pulmal	pulma	pulm	22_S	SgAd	et	pulmal =pulma  (SgAd  >pulm !22_S
33695	suhtlemisviis	viis	suhtlemis+viis	22_S	SgN	et	suhtlemisviis =viis  (SgN  >suhtlemis+viis !22_S
33696	mitmus	mitmus	mitmus	11~09_S	SgN	et	mitmus =mitmus  (SgN  >mitmus !11~09_S
33698	väljend	väljend	väljend	02_S	SgN	et	väljend =väljend  (SgN  >väljend !02_S
33709	lauluteel	tee	laulu+tee	26_S	SgAd	et	lauluteel =tee  (SgAd  >laulu+tee !26_S
33712	rahvamuusikaga	muusika	rahva+muusika	01_S	SgKom	et	rahvamuusikaga =muusika  (SgKom  >rahva+muusika !01_S
33713	vanadelt	vana	vana	17_AS	PlAbl	et	vanadelt =vana  (PlAbl  >vana !17_AS
33714	lastelaulud	laulu	laste+laul	22_S	PlN	et	lastelaulud =laulu  (PlN  >laste+laul !22_S
33720	tuttavatega	tuttava	tuttav	02_AS	PlKom	et	tuttavatega =tuttava  (PlKom  >tuttav !02_AS
33726	eeslauljaga	laulja	ees+laulja	01_S	SgKom	et	eeslauljaga =laulja  (SgKom  >ees+laulja !01_S
33728	külakoolid	kooli	küla+kool	22_S	PlN	et	külakoolid =kooli  (PlN  >küla+kool !22_S
33729	puhkpilliorkestrite	orkestri	puhk+pilli+orkester	02_S	PlG	et	puhkpilliorkestrite =orkestri  (PlG  >puhk+pilli+orkester !02_S
33734	torupillipäevad	päeva	toru+pilli+päev	22_S	PlN	et	torupillipäevad =päeva  (PlN  >toru+pilli+päev !22_S
33740	vajame	vaja	vajama	27_V	IndPrPl1	et	vajame =vaja  (IndPrPl1  >vajama !27_V
33741	momentide	momenti	moment	22_S	PlG	et	momentide =momenti  (PlG  >moment !22_S
33748	töörütm	rütm	töö+rütm	22_S	SgN	et	töörütm =rütm  (SgN  >töö+rütm !22_S
33754	südameid	südame	süda	04_S	PlP	et	südameid =südame  (PlP  >süda !04_S
33490	ühtehoidmise	hoidmise	ühte+hoidmine	12?10_S	SgG	et	ühtehoidmise =hoidmise  (SgG  >ühte+hoidmine !12?10_S
33493	laialdase	laialdase	laialdane	12_A	SgG	et	laialdase =laialdase  (SgG  >laialdane !12_A
33494	pärandi	pärandi	pärand	02_S	SgG	et	pärandi =pärandi  (SgG  >pärand !02_S
33502	põllul	põllu	põld	22_S	SgAd	et	põllul =põllu  (SgAd  >põld !22_S
33504	esineda	esine	esinema	27_V	Inf	et	esineda =esine  (Inf  >esinema !27_V
33512	tuhanded	tuhande	tuhat	02_N	PlN	et	tuhanded =tuhande  (PlN  >tuhat !02_N
33521	kalluste	kallus	kallus	11~09_S	PlG	et	kalluste =kallus  (PlG  >kallus !11~09_S
33522	instrumendi	instrumendi	instrument	22_S	SgG	et	instrumendi =instrumendi  (SgG  >instrument !22_S
33523	rahvaliku	rahvaliku	rahvalik	25_A	SgG	et	rahvaliku =rahvaliku  (SgG  >rahvalik !25_A
33524	saar	saar	saar	13_S	SgN	et	saar =saar  (SgN  >saar !13_S
33525	saamal	saama	saam	22_S	SgAd	et	saamal =saama  (SgAd  >saam !22_S
33527	laulutraditsioon	traditsioon	laulu+traditsioon	22_S	SgN	et	laulutraditsioon =traditsioon  (SgN  >laulu+traditsioon !22_S
33553	organiseeritakse	organiseeri	organiseerima	28_V	IndPrIps	et	organiseeritakse =organiseeri  (IndPrIps  >organiseerima !28_V
33556	vanaemad	ema	vana+ema	17_S	PlN	et	vanaemad =ema  (PlN  >vana+ema !17_S
33561	suurüritusteks	üritus	suur+üritus	11_S	PlTr	et	suurüritusteks =üritus  (PlTr  >suur+üritus !11_S
33562	pidustused	pidustuse	pidustus	11_S	PlN	et	pidustused =pidustuse  (PlN  >pidustus !11_S
33566	ärkamisaja	aja	ärkamis+aeg	22_S	SgG	et	ärkamisaja =aja  (SgG  >ärkamis+aeg !22_S
33581	laulutraditsioonile	traditsiooni	laulu+traditsioon	22_S	SgAll	et	laulutraditsioonile =traditsiooni  (SgAll  >laulu+traditsioon !22_S
33583	teeme	tee	tegema	28_V	IndPrPl1	et	teeme =tee  (IndPrPl1  >tegema !28_V
33586	maales	maale	maal	22_S	PlIn	et	maales =maale  (PlIn  >maal !22_S
33587	eluaspektid	aspekti	elu+aspekt	22_S	PlN	et	eluaspektid =aspekti  (PlN  >elu+aspekt !22_S
33594	laulutes	lute	lau+lutt	22_S	PlIn	et	laulutes =lute  (PlIn  >lau+lutt !22_S
33596	unistama	unista	unistama	27_V	Sup	et	unistama =unista  (Sup  >unistama !27_V
33600	vanaajas	aja	vana+aeg	22_S	SgIn	et	vanaajas =aja  (SgIn  >vana+aeg !22_S
33613	meloodiad	meloodia	meloodia	01_S	PlN	et	meloodiad =meloodia  (PlN  >meloodia !01_S
33614	esteetilised	esteetilise	esteetiline	12_A	PlN	et	esteetilised =esteetilise  (PlN  >esteetiline !12_A
33619	konkursil	konkursi	konkurss	22_S	SgAd	et	konkursil =konkursi  (SgAd  >konkurss !22_S
33632	pealtvaatajale	vaataja	pealt+vaataja	01_S	SgAll	et	pealtvaatajale =vaataja  (SgAll  >pealt+vaataja !01_S
33633	eestiline	eestiline	eestiline	12_A	SgN	et	eestiline =eestiline  (SgN  >eestiline !12_A
33640	kirikused	kuse	kiri+kusi	20_S	PlN	et	kirikused =kuse  (PlN  >kiri+kusi !20_S
33642	regilaulud	laulu	regi+laul	22_S	PlN	et	regilaulud =laulu  (PlN  >regi+laul !22_S
33645	setul	setu	setu	16_S	SgAd	et	setul =setu  (SgAd  >setu !16_S
33652	ebamäletavad	mäletava	eba+mäletav	02_A	PlN	et	ebamäletavad =mäletava  (PlN  >eba+mäletav !02_A
33656	pidul	pidu	pidu	17_S	SgAd	et	pidul =pidu  (SgAd  >pidu !17_S
33664	laulus	laulu	laul	22_S	SgIn	et	laulus =laulu  (SgIn  >laul !22_S
33668	nüüdne	nüüdne	nüüdne	02_A	SgN	et	nüüdne =nüüdne  (SgN  >nüüdne !02_A
33670	jutus	jutu	jutt	22_S	SgIn	et	jutus =jutu  (SgIn  >jutt !22_S
33671	kõrghetk	hetk	kõrg+hetk	22_S	SgN	et	kõrghetk =hetk  (SgN  >kõrg+hetk !22_S
33675	ülerahva	rahva	üle+rahvas	07_S	SgG	et	ülerahva =rahva  (SgG  >üle+rahvas !07_S
33692	primitiivsed	primitiivse	primitiivne	02_A	PlN	et	primitiivsed =primitiivse  (PlN  >primitiivne !02_A
33694	paganad	pagana	pagan	02_S	PlN	et	paganad =pagana  (PlN  >pagan !02_S
33703	rahvaärkamine	ärkamine	rahva+ärkamine	12_S	SgN	et	rahvaärkamine =ärkamine  (SgN  >rahva+ärkamine !12_S
33705	harrastusüritused	ürituse	harrastus+üritus	11_S	PlN	et	harrastusüritused =ürituse  (PlN  >harrastus+üritus !11_S
33715	rahvaluuled	luule	rahva+luule	06_S	PlN	et	rahvaluuled =luule  (PlN  >rahva+luule !06_S
33718	tantsuringis	ringi	tantsu+ring	22_S	SgIn	et	tantsuringis =ringi  (SgIn  >tantsu+ring !22_S
33749	koduloomadega	looma	kodu+loom	22_S	PlKom	et	koduloomadega =looma  (PlKom  >kodu+loom !22_S
33751	lauldakse	laul	laulma	33_V	IndPrIps	et	lauldakse =laul  (IndPrIps  >laulma !33_V
33757	vanaisal	isa	vana+isa	17_S	SgAd	et	vanaisal =isa  (SgAd  >vana+isa !17_S
33761	emalaulaulud	laulu	ema+lau+laul	22_S	PlN	et	emalaulaulud =laulu  (PlN  >ema+lau+laul !22_S
33764	kultuuriraamatuid	raamatu	kultuuri+raamat	02_S	PlP	et	kultuuriraamatuid =raamatu  (PlP  >kultuuri+raamat !02_S
33770	täname	täna	tänama	27_V	IndPrPl1	et	täname =täna  (IndPrPl1  >tänama !27_V
33779	kuulad	kuula	kuulama	29_V	IndPrSg2	et	kuulad =kuula  (IndPrSg2  >kuulama !29_V
33786	saateks	saate	saade	06_S	SgTr	et	saateks =saate  (SgTr  >saade !06_S
33794	käivitada	käivita	käivitama	27_V	Inf	et	käivitada =käivita  (Inf  >käivitama !27_V
33604	austab	austa	austama	27_V	IndPrSg3	et	austab =austa  (IndPrSg3  >austama !27_V
33610	naudingut	naudingu	nauding	02_S	SgP	et	naudingut =naudingu  (SgP  >nauding !02_S
33617	põlvides	põlvi	põlv	22_S	PlIn	et	põlvides =põlvi  (PlIn  >põlv !22_S
33618	konkursid	konkursi	konkurss	22_S	PlN	et	konkursid =konkursi  (PlN  >konkurss !22_S
33620	loks	loks	loks	22_S	SgN	et	loks =loks  (SgN  >loks !22_S
33626	tingimustest	tingimus	tingimus	11_S	PlEl	et	tingimustest =tingimus  (PlEl  >tingimus !11_S
33627	kavva	kavva	kava	17_S	SgAdt	et	kavva =kavva  (SgAdt  >kava !17_S
33628	lastekooride	koori	laste+koor	22_S	PlG	et	lastekooride =koori  (PlG  >laste+koor !22_S
33631	ühtekokku	ühtekokku	ühte+kokku	41_D	ID	et	ühtekokku =ühtekokku  (ID  >ühte+kokku !41_D
33639	lauludes	laulu	laul	22_S	PlIn	et	lauludes =laulu  (PlIn  >laul !22_S
33641	laulul	laulu	laul	22_S	SgAd	et	laulul =laulu  (SgAd  >laul !22_S
33649	üheksal	üheksa	üheksa	01_N	SgAd	et	üheksal =üheksa  (SgAd  >üheksa !01_N
33658	muusikaõpetus	õpetus	muusika+õpetus	11_S	SgN	et	muusikaõpetus =õpetus  (SgN  >muusika+õpetus !11_S
33662	massiharrastuseks	harrastuse	massi+harrastus	11_S	SgTr	et	massiharrastuseks =harrastuse  (SgTr  >massi+harrastus !11_S
33669	võistlema	võistle	võistlema	30_V	Sup	et	võistlema =võistle  (Sup  >võistlema !30_V
33681	lisama	lisa	lisama	27_V	Sup	et	lisama =lisa  (Sup  >lisama !27_V
33686	mäletada	mäleta	mäletama	27_V	Inf	et	mäletada =mäleta  (Inf  >mäletama !27_V
33688	rõõmsameelsed	meelse	rõõmsa+meelne	02_A	PlN	et	rõõmsameelsed =meelse  (PlN  >rõõmsa+meelne !02_A
33689	lapselapsed	lapse	lapse+laps	14_S	PlN	et	lapselapsed =lapse  (PlN  >lapse+laps !14_S
33693	rahvalaulmisele	laulmise	rahva+laulmine	12?10_S	SgAll	et	rahvalaulmisele =laulmise  (SgAll  >rahva+laulmine !12?10_S
33697	rahvalauludest	laulu	rahva+laul	22_S	PlEl	et	rahvalauludest =laulu  (PlEl  >rahva+laul !22_S
33699	abistab	abista	abistama	27_V	IndPrSg3	et	abistab =abista  (IndPrSg3  >abistama !27_V
33701	koorilaulmine	laulmine	koori+laulmine	12?10_S	SgN	et	koorilaulmine =laulmine  (SgN  >koori+laulmine !12?10_S
33702	mitmekülgne	külgne	mitme+külgne	02_A	SgN	et	mitmekülgne =külgne  (SgN  >mitme+külgne !02_A
33704	ühtse	ühtse	ühtne	02_A	SgG	et	ühtse =ühtse  (SgG  >ühtne !02_A
33706	motiive	motiive	motiiv	22_S	PlP	et	motiive =motiive  (PlP  >motiiv !22_S
33730	kõrgehetk	hetk	kõrge+hetk	22_S	SgN	et	kõrgehetk =hetk  (SgN  >kõrge+hetk !22_S
33735	festivalid	festivali	festival	19_S	PlN	et	festivalid =festivali  (PlN  >festival !19_S
33736	missuguste	sugus	mis+sugune	10_P	PlG	et	missuguste =sugus  (PlG  >mis+sugune !10_P
33739	rahvaansamblid	ansambli	rahva+ansambel	02_S	PlN	et	rahvaansamblid =ansambli  (PlN  >rahva+ansambel !02_S
33743	tähelepanuväärsed	väärse	tähele+panu+väärne	02_A	PlN	et	tähelepanuväärsed =väärse  (PlN  >tähele+panu+väärne !02_A
33753	meestekooride	koori	meeste+koor	22_S	PlG	et	meestekooride =koori  (PlG  >meeste+koor !22_S
33759	arhiivis	arhiivi	arhiiv	22_S	SgIn	et	arhiivis =arhiivi  (SgIn  >arhiiv !22_S
33765	dekaan	dekaan	dekaan	22_S	SgN	et	dekaan =dekaan  (SgN  >dekaan !22_S
33773	ühendada	ühenda	ühendama	27_V	Inf	et	ühendada =ühenda  (Inf  >ühendama !27_V
33774	inimsõbralik	sõbralik	inim+sõbralik	25_A	SgN	et	inimsõbralik =sõbralik  (SgN  >inim+sõbralik !25_A
33775	ukrainlane	ukrainlane	ukrainlane	12?10_S	SgN	et	ukrainlane =ukrainlane  (SgN  >ukrainlane !12?10_S
33778	kevad	kevad	kevad	02_S	SgN	et	kevad =kevad  (SgN  >kevad !02_S
33782	jalustrabav	rabav	jalust+rabav	02_A	SgN	et	jalustrabav =rabav  (SgN  >jalust+rabav !02_A
33783	laulge	laul	laulma	33_V	ImpPrPl2	et	laulge =laul  (ImpPrPl2  >laulma !33_V
33784	rahvalauluring	ring	rahva+laulu+ring	22_S	SgN	et	rahvalauluring =ring  (SgN  >rahva+laulu+ring !22_S
33785	osavõtjatena	võtja	osa+võtja	01_S	PlEs	et	osavõtjatena =võtja  (PlEs  >osa+võtja !01_S
33787	kandus	kandu	kanduma	27_V	IndIpfSg3	et	kandus =kandu  (IndIpfSg3  >kanduma !27_V
33789	e-post	post	e-post	22_S	SgN	et	e-post =post  (SgN  >e-post !22_S
33801	koduleht	leht	kodu+leht	22_S	SgN	et	koduleht =leht  (SgN  >kodu+leht !22_S
33804	jututoad	toa	jutu+tuba	18_S	PlN	et	jututoad =toa  (PlN  >jutu+tuba !18_S
33807	päevauudised	uudise	päeva+uudis	09_S	PlN	et	päevauudised =uudise  (PlN  >päeva+uudis !09_S
33814	uudiste	uudis	uudis	09_S	PlG	et	uudiste =uudis  (PlG  >uudis !09_S
33826	võimaldame	võimalda	võimaldama	27_V	IndPrPl1	et	võimaldame =võimalda  (IndPrPl1  >võimaldama !27_V
33829	kaitsega	kaitse	kaitse	06_S	SgKom	et	kaitsega =kaitse  (SgKom  >kaitse !06_S
33831	sinus	sinu	sina	00_P	SgIn	et	sinus =sinu  (SgIn  >sina !00_P
33835	koduni	kodu	kodu	17_S	SgTer	et	koduni =kodu  (SgTer  >kodu !17_S
33837	keemiatooted	toote	keemia+toode	06_S	PlN	et	keemiatooted =toote  (PlN  >keemia+toode !06_S
33629	poistekooride	koori	poiste+koor	22_S	PlG	et	poistekooride =koori  (PlG  >poiste+koor !22_S
33636	muinasjutud	jutu	muinas+jutt	22_S	PlN	et	muinasjutud =jutu  (PlN  >muinas+jutt !22_S
33638	õpetasime	õpeta	õpetama	27_V	IndIpfPl1	et	õpetasime =õpeta  (IndIpfPl1  >õpetama !27_V
33644	rahvalaulul	laulu	rahva+laul	22_S	SgAd	et	rahvalaulul =laulu  (SgAd  >rahva+laul !22_S
33650	eriloojad	looja	eri+looja	01_S	PlN	et	eriloojad =looja  (PlN  >eri+looja !01_S
33653	väljendusvahend	vahend	väljendus+vahend	02_S	SgN	et	väljendusvahend =vahend  (SgN  >väljendus+vahend !02_S
33655	tekkes	tekke	teke	06_S	SgIn	et	tekkes =tekke  (SgIn  >teke !06_S
33657	muut	muut	muut	22_S	SgN	et	muut =muut  (SgN  >muut !22_S
33661	puhkpilliorkesteri	orkesteri	puhk+pilli+orkester	02_S	SgG	et	puhkpilliorkesteri =orkesteri  (SgG  >puhk+pilli+orkester !02_S
33676	rahvana	rahva	rahvas	07_S	SgEs	et	rahvana =rahva  (SgEs  >rahvas !07_S
33680	esitama	esita	esitama	27_V	Sup	et	esitama =esita  (Sup  >esitama !27_V
33687	kuuleb	kuule	kuulma	33_V	IndPrSg3	et	kuuleb =kuule  (IndPrSg3  >kuulma !33_V
33691	laulurahvana	rahva	laulu+rahvas	07_S	SgEs	et	laulurahvana =rahva  (SgEs  >laulu+rahvas !07_S
33707	minekusse	mineku	minek	02_S	SgIll	et	minekusse =mineku  (SgIll  >minek !02_S
33708	pillideta	pilli	pill	22_S	PlAb	et	pillideta =pilli  (PlAb  >pill !22_S
33717	fantaasiat	fantaasia	fantaasia	01_S	SgP	et	fantaasiat =fantaasia  (SgP  >fantaasia !01_S
33725	laululiigist	liigi	laulu+liik	22_S	SgEl	et	laululiigist =liigi  (SgEl  >laulu+liik !22_S
33732	noortel	noor	noor	13_AS	PlAd	et	noortel =noor  (PlAd  >noor !13_AS
33738	kollektiive	kollektiive	kollektiiv	22_S	PlP	et	kollektiive =kollektiive  (PlP  >kollektiiv !22_S
33745	värsse	värsse	värss	22_S	PlP	et	värsse =värsse  (PlP  >värss !22_S
33746	uskuda	usku	uskuma	28_V	Inf	et	uskuda =usku  (Inf  >uskuma !28_V
33747	kultuure	kultuure	kultuur	22_S	PlP	et	kultuure =kultuure  (PlP  >kultuur !22_S
33755	koosnetakse	koosne	koosnema	27_V	IndPrIps	et	koosnetakse =koosne  (IndPrIps  >koosnema !27_V
33756	rõõmused	rõõmuse	rõõmus	02_A	PlN	et	rõõmused =rõõmuse  (PlN  >rõõmus !02_A
33758	pulmade	pulma	pulm	22_S	PlG	et	pulmade =pulma  (PlG  >pulm !22_S
33760	emaarmus	armu	ema+arm	22_S	SgIn	et	emaarmus =armu  (SgIn  >ema+arm !22_S
33763	kõigepeaks	pea	kõige+pea	26_S	SgTr	et	kõigepeaks =pea  (SgTr  >kõige+pea !26_S
33772	toimib	toimi	toimima	28_V	IndPrSg3	et	toimib =toimi  (IndPrSg3  >toimima !28_V
33788	minusse	minu	mina	00_P	SgIll	et	minusse =minu  (SgIll  >mina !00_P
33791	failide	faili	fail	22_S	PlG	et	failide =faili  (PlG  >fail !22_S
33792	väljasaatmine	saatmine	välja+saatmine	12?10_S	SgN	et	väljasaatmine =saatmine  (SgN  >välja+saatmine !12?10_S
33795	koduleheküljele	külje	kodu+lehe+külg	22_S	SgAll	et	koduleheküljele =külje  (SgAll  >kodu+lehe+külg !22_S
33798	kalendrit	kalendri	kalender	02_S	SgP	et	kalendrit =kalendri  (SgP  >kalender !02_S
33805	foorumid	foorumi	foorum	02_S	PlN	et	foorumid =foorumi  (PlN  >foorum !02_S
33808	prognoos	prognoos	prognoos	22_S	SgN	et	prognoos =prognoos  (SgN  >prognoos !22_S
33812	rannailm	ilm	ranna+ilm	22_S	SgN	et	rannailm =ilm  (SgN  >ranna+ilm !22_S
33821	sõnumid	sõnumi	sõnum	02_S	PlN	et	sõnumid =sõnumi  (PlN  >sõnum !02_S
33825	internet-võimalus	võimalus	internet-võimalus	11_S	SgN	et	internet-võimalus =võimalus  (SgN  >internet-võimalus !11_S
33833	rääkisime	rääki	rääkima	28_V	IndIpfPl1	et	rääkisime =rääki  (IndIpfPl1  >rääkima !28_V
33852	valgusallikad	allika	valgus+allikas	02_S	PlN	et	valgusallikad =allika  (PlN  >valgus+allikas !02_S
33853	katted	katte	kate	06_S	PlN	et	katted =katte  (PlN  >kate !06_S
33854	eemaldada	eemalda	eemaldama	27_V	Inf	et	eemaldada =eemalda  (Inf  >eemaldama !27_V
33855	lühitutvustus	tutvustus	lühi+tutvustus	11_S	SgN	et	lühitutvustus =tutvustus  (SgN  >lühi+tutvustus !11_S
33865	värvieelistused	eelistuse	värvi+eelistus	11_S	PlN	et	värvieelistused =eelistuse  (PlN  >värvi+eelistus !11_S
33869	stressisoodumus	soodumus	stressi+soodumus	11_S	SgN	et	stressisoodumus =soodumus  (SgN  >stressi+soodumus !11_S
33870	psüühilise	psüühilise	psüühiline	12_A	SgG	et	psüühilise =psüühilise  (SgG  >psüühiline !12_A
33880	istme	istme	iste	05_S	SgG	et	istme =istme  (SgG  >iste !05_S
33887	sundasend	asend	sund+asend	02_S	SgN	et	sundasend =asend  (SgN  >sund+asend !02_S
33890	kontoris	kontori	kontor	02_S	SgIn	et	kontoris =kontori  (SgIn  >kontor !02_S
33892	seinte	sein	sein	23_S	PlG	et	seinte =sein  (PlG  >sein !23_S
33895	teostab	teosta	teostama	27_V	IndPrSg3	et	teostab =teosta  (IndPrSg3  >teostama !27_V
33898	korrigeerige	korrigeeri	korrigeerima	28_V	ImpPrPl2	et	korrigeerige =korrigeeri  (ImpPrPl2  >korrigeerima !28_V
33906	servaga	serva	serv	22_S	SgKom	et	servaga =serva  (SgKom  >serv !22_S
33907	töötasapinna	pinna	töö+tasa+pind	22_S	SgG	et	töötasapinna =pinna  (SgG  >töö+tasa+pind !22_S
33723	vaiksed	vaikse	vaikne	02_A	PlN	et	vaiksed =vaikse  (PlN  >vaikne !02_A
33724	heliloominguga	loomingu	heli+looming	02_S	SgKom	et	heliloominguga =loomingu  (SgKom  >heli+looming !02_S
33727	laulide	lauli	laul	22_S	PlG	et	laulide =lauli  (PlG  >laul !22_S
33731	tänapäevadel	päeva	täna+päev	22_S	PlAd	et	tänapäevadel =päeva  (PlAd  >täna+päev !22_S
33733	folklooriüritused	ürituse	folkloori+üritus	11_S	PlN	et	folklooriüritused =ürituse  (PlN  >folkloori+üritus !11_S
33737	ansamblit	ansambli	ansambel	02_S	SgP	et	ansamblit =ansambli  (SgP  >ansambel !02_S
33742	niisuguste	sugus	nii+sugune	10_P	PlG	et	niisuguste =sugus  (PlG  >nii+sugune !10_P
33744	kultuurinähtused	nähtuse	kultuuri+nähtus	11~09_S	PlN	et	kultuurinähtused =nähtuse  (PlN  >kultuuri+nähtus !11~09_S
33750	faktidega	fakti	fakt	22_S	PlKom	et	faktidega =fakti  (PlKom  >fakt !22_S
33752	naistekoorid	koori	naiste+koor	22_S	PlN	et	naistekoorid =koori  (PlN  >naiste+koor !22_S
33766	pisikene	pisikene	pisikene	12_A	SgN	et	pisikene =pisikene  (SgN  >pisikene !12_A
33767	kiigutab	kiiguta	kiigutama	27_V	IndPrSg3	et	kiigutab =kiiguta  (IndPrSg3  >kiigutama !27_V
33769	olemal	olema	olem	02_S	SgAd	et	olemal =olema  (SgAd  >olem !02_S
33771	kuuled	kuule	kuulma	33_V	IndPrSg2	et	kuuled =kuule  (IndPrSg2  >kuulma !33_V
33777	kujutlege	kujutle	kujutlema	27_V	ImpPrPl2	et	kujutlege =kujutle  (ImpPrPl2  >kujutlema !27_V
33780	lauluväljak	väljak	laulu+väljak	02_S	SgN	et	lauluväljak =väljak  (SgN  >laulu+väljak !02_S
33781	eurovisioon	visioon	euro+visioon	22_S	SgN	et	eurovisioon =visioon  (SgN  >euro+visioon !22_S
33802	kodulehekülje	külje	kodu+lehe+külg	22_S	SgG	et	kodulehekülje =külje  (SgG  >kodu+lehe+külg !22_S
33810	ekraanist	ekraani	ekraan	22_S	SgEl	et	ekraanist =ekraani  (SgEl  >ekraan !22_S
33817	kalender	kalender	kalender	02_S	SgN	et	kalender =kalender  (SgN  >kalender !02_S
33820	puhkepäevad	päeva	puhke+päev	22_S	PlN	et	puhkepäevad =päeva  (PlN  >puhke+päev !22_S
33828	tõlkjaga	tõlkja	tõlkjas	02_S	SgKom	et	tõlkjaga =tõlkja  (SgKom  >tõlkjas !02_S
33830	otsingu	otsingu	otsing	02_S	SgG	et	otsingu =otsingu  (SgG  >otsing !02_S
33834	hinnatest	test	hinna+test	22_S	SgN	et	hinnatest =test  (SgN  >hinna+test !22_S
33838	ohtlikud	ohtliku	ohtlik	25_A	PlN	et	ohtlikud =ohtliku  (PlN  >ohtlik !25_A
33846	heledates	heleda	hele	02_A	PlIn	et	heledates =heleda  (PlIn  >hele !02_A
33856	töötingimuste	tingimus	töö+tingimus	11_S	PlG	et	töötingimuste =tingimus  (PlG  >töö+tingimus !11_S
33861	teabe	teabe	teave	06_S	SgG	et	teabe =teabe  (SgG  >teave !06_S
33863	värvivalikul	valiku	värvi+valik	02_S	SgAd	et	värvivalikul =valiku  (SgAd  >värvi+valik !02_S
33879	seljatoega	toe	selja+tugi	21_S	SgKom	et	seljatoega =toe  (SgKom  >selja+tugi !21_S
33883	praktilisi	praktilisi	praktiline	12_A	PlP	et	praktilisi =praktilisi  (PlP  >praktiline !12_A
33888	käte	kä	käsi	15_S	PlG	et	käte =kä  (PlG  >käsi !15_S
33902	veenduda	veendu	veenduma	27_V	Inf	et	veenduda =veendu  (Inf  >veenduma !27_V
33910	asendisse	asendi	asend	02_S	SgIll	et	asendisse =asendi  (SgIll  >asend !02_S
33914	kurdetakse	kurde	kurtma	34_V	IndPrIps	et	kurdetakse =kurde  (IndPrIps  >kurtma !34_V
33915	selja-	selja	selg	22_S	SgG	et	selja- =selja  (SgG  >selg !22_S
33919	asetseb	asetse	asetsema	27_V	IndPrSg3	et	asetseb =asetse  (IndPrSg3  >asetsema !27_V
33921	valude	valu	valu	17_S	PlG	et	valude =valu  (PlG  >valu !17_S
33923	kätel	kä	käsi	15_S	PlAd	et	kätel =kä  (PlAd  >käsi !15_S
33926	töökeskkonnaspetsialist	spetsialist	töö+kesk+konna+spetsialist	22_S	SgN	et	töökeskkonnaspetsialist =spetsialist  (SgN  >töö+kesk+konna+spetsialist !22_S
33935	võimalusel	võimaluse	võimalus	11_S	SgAd	et	võimalusel =võimaluse  (SgAd  >võimalus !11_S
33937	puhastada	puhasta	puhastama	27_V	Inf	et	puhastada =puhasta  (Inf  >puhastama !27_V
33942	istmepatju	patju	istme+padi	24_S	PlP	et	istmepatju =patju  (PlP  >istme+padi !24_S
33946	kaldub	kaldu	kalduma	27_V	IndPrSg3	et	kaldub =kaldu  (IndPrSg3  >kalduma !27_V
33948	tahapoole	tahapoole	taha+poole	41_DK	ID	et	tahapoole =tahapoole  (ID  >taha+poole !41_DK
33952	asendit	asendi	asend	02_S	SgP	et	asendit =asendi  (SgP  >asend !02_S
33959	keskkond	keskkond	keskkond	22_S	SgN	et	keskkond =keskkond  (SgN  >keskkond !22_S
33964	täistööajaga	aja	täis+töö+aeg	22_S	SgKom	et	täistööajaga =aja  (SgKom  >täis+töö+aeg !22_S
33965	värvilahendused	lahenduse	värvi+lahendus	11_S	PlN	et	värvilahendused =lahenduse  (PlN  >värvi+lahendus !11_S
33969	menüüst	menüü	menüü	26_S	SgEl	et	menüüst =menüü  (SgEl  >menüü !26_S
33973	lisandid	lisandi	lisand	02_S	PlN	et	lisandid =lisandi  (PlN  >lisand !02_S
33978	kohv	kohv	kohv	22_S	SgN	et	kohv =kohv  (SgN  >kohv !22_S
33981	alkohoolsed	alkohoolse	alkohoolne	02_A	PlN	et	alkohoolsed =alkohoolse  (PlN  >alkohoolne !02_A
33762	sõjal	sõja	sõda	18_S	SgAd	et	sõjal =sõja  (SgAd  >sõda !18_S
33768	protestiga	protesti	protest	22_S	SgKom	et	protestiga =protesti  (SgKom  >protest !22_S
33776	lauluriik	riik	laulu+riik	22_S	SgN	et	lauluriik =riik  (SgN  >laulu+riik !22_S
33790	sms-ide	sms	sms	xx_Q	PlG	et	sms-ide =sms  (PlG  >sms !xx_Q
33793	peamenüüs	menüü	pea+menüü	26_S	SgIn	et	peamenüüs =menüü  (SgIn  >pea+menüü !26_S
33796	e-teenused	teenuse	e-teenus	09_S	PlN	et	e-teenused =teenuse  (PlN  >e-teenus !09_S
33800	otsingu-mootoreid	mootore	otsingu-mootor	02_S	PlP	et	otsingu-mootoreid =mootore  (PlP  >otsingu-mootor !02_S
33803	lehekülje	külje	lehe+külg	22_S	SgG	et	lehekülje =külje  (SgG  >lehe+külg !22_S
33806	standardvarustused	varustuse	standard+varustus	11_S	PlN	et	standardvarustused =varustuse  (PlN  >standard+varustus !11_S
33811	lisateenused	teenuse	lisa+teenus	09_S	PlN	et	lisateenused =teenuse  (PlN  >lisa+teenus !09_S
33813	spordiuudised	uudise	spordi+uudis	09_S	PlN	et	spordiuudised =uudise  (PlN  >spordi+uudis !09_S
33816	tänane	tänane	tänane	10_A	SgN	et	tänane =tänane  (SgN  >tänane !10_A
33822	postiteenistus	teenistus	posti+teenistus	11_S	SgN	et	postiteenistus =teenistus  (SgN  >posti+teenistus !11_S
33823	portaalidest	portaali	portaal	22_S	PlEl	et	portaalidest =portaali  (PlEl  >portaal !22_S
33824	auditoorium	auditoorium	auditoorium	19~02_S	SgN	et	auditoorium =auditoorium  (SgN  >auditoorium !19~02_S
33827	postikast	kast	posti+kast	22_S	SgN	et	postikast =kast  (SgN  >posti+kast !22_S
33836	kohtume	kohtu	kohtuma	27_V	IndPrPl1	et	kohtume =kohtu  (IndPrPl1  >kohtuma !27_V
33839	infost	info	info	16_S	SgEl	et	infost =info  (SgEl  >info !16_S
33842	toimet	toime	toime	06_S	SgP	et	toimet =toime  (SgP  >toime !06_S
33844	valetab	valeta	valetama	27_V	IndPrSg3	et	valetab =valeta  (IndPrSg3  >valetama !27_V
33845	juhend	juhend	juhend	02_S	SgN	et	juhend =juhend  (SgN  >juhend !02_S
33848	nägemisväljas	välja	nägemis+väli	24_S	SgIn	et	nägemisväljas =välja  (SgIn  >nägemis+väli !24_S
33851	paigutada	paiguta	paigutama	27_V	Inf	et	paigutada =paiguta  (Inf  >paigutama !27_V
33857	seen	seen	seen	13_S	SgN	et	seen =seen  (SgN  >seen !13_S
33858	lihtsaid	lihtsa	lihtne	02_A	PlP	et	lihtsaid =lihtsa  (PlP  >lihtne !02_A
33859	odavaid	odava	odav	02_A	PlP	et	odavaid =odava  (PlP  >odav !02_A
33860	teejuht	juht	tee+juht	22_S	SgN	et	teejuht =juht  (SgN  >tee+juht !22_S
33862	väsitab	väsita	väsitama	27_V	IndPrSg3	et	väsitab =väsita  (IndPrSg3  >väsitama !27_V
33867	hüsteeriasse	hüsteeria	hüsteeria	01_S	SgIll	et	hüsteeriasse =hüsteeria  (SgIll  >hüsteeria !01_S
33872	võtted	võtte	võte	06_S	PlN	et	võtted =võtte  (PlN  >võte !06_S
33873	praktiline	praktiline	praktiline	12_A	SgN	et	praktiline =praktiline  (SgN  >praktiline !12_A
33877	kaldteedel	tee	kald+tee	26_S	PlAd	et	kaldteedel =tee  (PlAd  >kald+tee !26_S
33881	kaasaegset	aegse	kaas+aegne	02_A	SgP	et	kaasaegset =aegse  (SgP  >kaas+aegne !02_A
33900	stressivastaseid	vastase	stressi+vastane	10_AS	PlP	et	stressivastaseid =vastase  (PlP  >stressi+vastane !10_AS
33901	tugevdage	tugevda	tugevdama	27_V	ImpPrPl2	et	tugevdage =tugevda  (ImpPrPl2  >tugevdama !27_V
33903	kitsendaks	kitsenda	kitsendama	27_V	KndPrPs	et	kitsendaks =kitsenda  (KndPrPs  >kitsendama !27_V
33905	alumise	alumise	alumine	12_A	SgG	et	alumise =alumise  (SgG  >alumine !12_A
33916	kontoritöötajail	töötaja	kontori+töötaja	01_S	PlAd	et	kontoritöötajail =töötaja  (PlAd  >kontori+töötaja !01_S
33918	arvutitöökoht	koht	arvuti+töö+koht	22_S	SgN	et	arvutitöökoht =koht  (SgN  >arvuti+töö+koht !22_S
33920	pingega	pinge	pinge	06_S	SgKom	et	pingega =pinge  (SgKom  >pinge !06_S
33925	käel	käe	käsi	15_S	SgAd	et	käel =käe  (SgAd  >käsi !15_S
33927	töökeskkonna	keskkonna	töö+keskkond	22_S	SgG	et	töökeskkonna =keskkonna  (SgG  >töö+keskkond !22_S
33930	töökeskkonnaõpetust	õpetus	töö+kesk+konna+õpetus	11_S	SgP	et	töökeskkonnaõpetust =õpetus  (SgP  >töö+kesk+konna+õpetus !11_S
33931	spetsialist	spetsialist	spetsialist	22_S	SgN	et	spetsialist =spetsialist  (SgN  >spetsialist !22_S
33934	energiale	energia	energia	01_S	SgAll	et	energiale =energia  (SgAll  >energia !01_S
33943	põrandapinna	pinna	põranda+pind	22_S	SgG	et	põrandapinna =pinna  (SgG  >põranda+pind !22_S
33947	toolil	tooli	tool	22_S	SgAd	et	toolil =tooli  (SgAd  >tool !22_S
33951	tööülesannete	anne	töö+üles+anne	06_S	PlG	et	tööülesannete =anne  (PlG  >töö+üles+anne !06_S
33955	ratastega	ratas	ratas	07_S	PlKom	et	ratastega =ratas  (PlKom  >ratas !07_S
33956	tavahind	hind	tava+hind	22_S	SgN	et	tavahind =hind  (SgN  >tava+hind !22_S
33961	siilil	siili	siil	22_S	SgAd	et	siilil =siili  (SgAd  >siil !22_S
33962	udus	udu	udu	17_S	SgIn	et	udus =udu  (SgIn  >udu !17_S
33968	läheksin	lähe	minema	36_V	KndPrSg1	et	läheksin =lähe  (KndPrSg1  >minema !36_V
33797	postkast	kast	post+kast	22_S	SgN	et	postkast =kast  (SgN  >post+kast !22_S
33799	otsingu-võimalus	võimalus	otsingu-võimalus	11_S	SgN	et	otsingu-võimalus =võimalus  (SgN  >otsingu-võimalus !11_S
33809	pildil	pildi	pilt	22_S	SgAd	et	pildil =pildi  (SgAd  >pilt !22_S
33815	arhiiv	arhiiv	arhiiv	22_S	SgN	et	arhiiv =arhiiv  (SgN  >arhiiv !22_S
33818	post	post	post	22_S	SgN	et	post =post  (SgN  >post !22_S
33819	gb-ga	gb	gb	xx_Q	SgKom	et	gb-ga =gb  (SgKom  >gb !xx_Q
33832	vestlust	vestlus	vestlus	11~09_S	SgP	et	vestlust =vestlus  (SgP  >vestlus !11~09_S
33840	leiavad	leia	leidma	34_V	IndPrPl3	et	leiavad =leia  (IndPrPl3  >leidma !34_V
33849	valgustada	valgusta	valgustama	27_V	Inf	et	valgustada =valgusta  (Inf  >valgustama !27_V
33850	viibida	viibi	viibima	27_V	Inf	et	viibida =viibi  (Inf  >viibima !27_V
33864	arvestada	arvesta	arvestama	27_V	Inf	et	arvestada =arvesta  (Inf  >arvestama !27_V
33874	arvutimaailm	ilm	arvuti+maa+ilm	22_S	SgN	et	arvutimaailm =ilm  (SgN  >arvuti+maa+ilm !22_S
33882	julgustada	julgusta	julgustama	27_V	Inf	et	julgustada =julgusta  (Inf  >julgustama !27_V
33884	mitmesugustes	sugus	mitme+sugune	10_A	PlIn	et	mitmesugustes =sugus  (PlIn  >mitme+sugune !10_A
33886	kontoritöös	töö	kontori+töö	26_S	SgIn	et	kontoritöös =töö  (SgIn  >kontori+töö !26_S
33889	soovitatakse	soovita	soovitama	27_V	IndPrIps	et	soovitatakse =soovita  (IndPrIps  >soovitama !27_V
33894	tööinspektor	inspektor	töö+inspektor	02_S	SgN	et	tööinspektor =inspektor  (SgN  >töö+inspektor !02_S
33899	eluhoiakut	hoiaku	elu+hoiak	02_S	SgP	et	eluhoiakut =hoiaku  (SgP  >elu+hoiak !02_S
33913	töökohtade	kohta	töö+koht	22_S	PlG	et	töökohtade =kohta  (PlG  >töö+koht !22_S
33922	tõenäosust	näosus	tõe+näosus	11~09_S	SgP	et	tõenäosust =näosus  (SgP  >tõe+näosus !11~09_S
33924	arvutihiirt	hiir	arvuti+hiir	13_S	SgP	et	arvutihiirt =hiir  (SgP  >arvuti+hiir !13_S
33929	insener	insener	insener	19_S	SgN	et	insener =insener  (SgN  >insener !19_S
33932	ettevõttes	võtte	ette+võte	06_S	SgIn	et	ettevõttes =võtte  (SgIn  >ette+võte !06_S
33936	liigutada	liiguta	liigutama	27_V	Inf	et	liigutada =liiguta  (Inf  >liigutama !27_V
33940	alternatiivina	alternatiivi	alternatiiv	22_S	SgEs	et	alternatiivina =alternatiivi  (SgEs  >alternatiiv !22_S
33945	alumist	alumis	alumine	12_A	SgP	et	alumist =alumis  (SgP  >alumine !12_A
33953	tehtavate	teh	tegema	28_V	TAV_vAS	et	"tehtav %teh  )TAV_vAS  <tegema ;28_V
33957	jalatuge	tuge	jala+tugi	21_S	SgP	et	jalatuge =tuge  (SgP  >jala+tugi !21_S
33970	salatid	salati	salat	02_S	PlN	et	salatid =salati  (PlN  >salat !02_S
33972	supid	supi	supp	22_S	PlN	et	supid =supi  (PlN  >supp !22_S
33984	juustuga	juustu	juust	22_S	SgKom	et	juustuga =juustu  (SgKom  >juust !22_S
33994	õunamahl	mahl	õuna+mahl	22_S	SgN	et	õunamahl =mahl  (SgN  >õuna+mahl !22_S
33996	eskalopp	eskalopp	eskalopp	22_S	SgN	et	eskalopp =eskalopp  (SgN  >eskalopp !22_S
33998	vorstid	vorsti	vorst	22_S	PlN	et	vorstid =vorsti  (PlN  >vorst !22_S
34002	mahlad	mahla	mahl	22_S	PlN	et	mahlad =mahla  (PlN  >mahl !22_S
34009	laevades	laeva	laev	22_S	PlIn	et	laevades =laeva  (PlIn  >laev !22_S
34012	korraldasime	korralda	korraldama	27_V	IndIpfPl1	et	korraldasime =korralda  (IndIpfPl1  >korraldama !27_V
34018	pidulikel	pidulike	pidulik	25_A	PlAd	et	pidulikel =pidulike  (PlAd  >pidulik !25_A
34020	tass	tass	tass	22_S	SgN	et	tass =tass  (SgN  >tass !22_S
34026	lisandeid	lisande	lisand	02_S	PlP	et	lisandeid =lisande  (PlP  >lisand !02_S
34035	ebakultuurne	kultuurne	eba+kultuurne	02_A	SgN	et	ebakultuurne =kultuurne  (SgN  >eba+kultuurne !02_A
34050	saatsin	saat	saatma	34_V	IndIpfSg1	et	saatsin =saat  (IndIpfSg1  >saatma !34_V
34052	helistan	helista	helistama	27_V	IndPrSg1	et	helistan =helista  (IndPrSg1  >helistama !27_V
34062	vaheleht	leht	vahe+leht	22_S	SgN	et	vaheleht =leht  (SgN  >vahe+leht !22_S
34065	võtke	võt	võtma	35_V	ImpPrPl2	et	võtke =võt  (ImpPrPl2  >võtma !35_V
34068	helistab	helista	helistama	27_V	IndPrSg3	et	helistab =helista  (IndPrSg3  >helistama !27_V
34084	nõupesumasina	masina	nõu+pesu+masin	02_S	SgG	et	nõupesumasina =masina  (SgG  >nõu+pesu+masin !02_S
34085	lülitada	lülita	lülitama	27_V	Inf	et	lülitada =lülita  (Inf  >lülitama !27_V
34087	hiiumaalt	maa	hiiu+maa	26_S	SgAbl	et	hiiumaalt =maa  (SgAbl  >hiiu+maa !26_S
34094	sõdur	sõdur	sõdur	02_S	SgN	et	sõdur =sõdur  (SgN  >sõdur !02_S
34100	laual	laua	laud	22_S	SgAd	et	laual =laua  (SgAd  >laud !22_S
34107	söök	söök	söök	22_S	SgN	et	söök =söök  (SgN  >söök !22_S
34108	valamus	valamu	valamu	01_S	SgIn	et	valamus =valamu  (SgIn  >valamu !01_S
34111	taldrikus	taldriku	taldrik	02_S	SgIn	et	taldrikus =taldriku  (SgIn  >taldrik !02_S
34117	puudused	puuduse	puudus	11~09_S	PlN	et	puudused =puuduse  (PlN  >puudus !11~09_S
33841	keemiatoode	toode	keemia+toode	06_S	SgN	et	keemiatoode =toode  (SgN  >keemia+toode !06_S
33843	meditsiinis	meditsiini	meditsiin	22_S	SgIn	et	meditsiinis =meditsiini  (SgIn  >meditsiin !22_S
33847	värvitoonides	tooni	värvi+toon	22_S	PlIn	et	värvitoonides =tooni  (PlIn  >värvi+toon !22_S
33866	mõnegi	mõne	mõni	20_P	SgG^	et	mõnegi =mõne  (SgG^  >mõni !20_P
33868	ajada	aja	ajama	27_V	Inf	et	ajada =aja  (Inf  >ajama !27_V
33871	alustades	alusta	alustama	27_V	Ger	et	alustades =alusta  (Ger  >alustama !27_V
33875	koridorides	koridori	koridor	19_S	PlIn	et	koridorides =koridori  (PlIn  >koridor !19_S
33876	treppidel	treppi	trepp	22_S	PlAd	et	treppidel =treppi  (PlAd  >trepp !22_S
33878	kohtvalgustid	valgusti	koht+valgusti	01_S	PlN	et	kohtvalgustid =valgusti  (PlN  >koht+valgusti !01_S
33885	käsiraamat	raamat	käsi+raamat	02_S	SgN	et	käsiraamat =raamat  (SgN  >käsi+raamat !02_S
33891	heledad	heleda	hele	02_A	PlN	et	heledad =heleda  (PlN  >hele !02_A
33893	toone	toone	toon	22_S	PlP	et	toone =toone  (PlP  >toon !22_S
33896	järelevalvet	valve	järele+valve	06_S	SgP	et	järelevalvet =valve  (SgP  >järele+valve !06_S
33897	õigusaktide	akti	õigus+akt	22_S	PlG	et	õigusaktide =akti  (PlG  >õigus+akt !22_S
33904	põlvekedra	kedra	põlve+keder	24_S	SgG	et	põlvekedra =kedra  (SgG  >põlve+keder !24_S
33917	valusad	valusa	valus	02_A	PlN	et	valusad =valusa  (PlN  >valus !02_A
33928	pädev	pädev	pädev	02_A	SgN	et	pädev =pädev  (SgN  >pädev !02_A
33938	hooldada	hoolda	hooldama	27_V	Inf	et	hooldada =hoolda  (Inf  >hooldama !27_V
33939	toolid	tooli	tool	22_S	PlN	et	toolid =tooli  (PlN  >tool !22_S
33944	seljatugesid	tuge	selja+tugi	21_S	PlP	et	seljatugesid =tuge  (PlP  >selja+tugi !21_S
33950	istumisasendit	asendi	istumis+asend	02_S	SgP	et	istumisasendit =asendi  (SgP  >istumis+asend !02_S
33954	viiejalgsed	jalgse	viie+jalgne	02_AS	PlN	et	viiejalgsed =jalgse  (PlN  >viie+jalgne !02_AS
33958	steriilne	steriilne	steriilne	02_A	SgN	et	steriilne =steriilne  (SgN  >steriilne !02_A
33967	restorane	restorane	restoran	19_S	PlP	et	restorane =restorane  (PlP  >restoran !19_S
33974	keedukartul	kartul	keedu+kartul	02_S	SgN	et	keedukartul =kartul  (SgN  >keedu+kartul !02_S
33977	salat	salat	salat	02_S	SgN	et	salat =salat  (SgN  >salat !02_S
33983	viinad	viina	viin	22_S	PlN	et	viinad =viina  (PlN  >viin !22_S
33991	onud	onu	onu	17_S	PlN	et	onud =onu  (PlN  >onu !17_S
33999	singid	singi	sink	22_S	PlN	et	singid =singi  (PlN  >sink !22_S
34004	krabid	krabi	krabi	17_S	PlN	et	krabid =krabi  (PlN  >krabi !17_S
34008	kokk	kokk	kokk	22_S	SgN	et	kokk =kokk  (SgN  >kokk !22_S
34036	kastmega	kastme	kaste	05_S	SgKom	et	kastmega =kastme  (SgKom  >kaste !05_S
34039	maguskastmega	kastme	magus+kaste	05_S	SgKom	et	maguskastmega =kastme  (SgKom  >magus+kaste !05_S
34045	lauad	laua	laud	22_S	PlN	et	lauad =laua  (PlN  >laud !22_S
34046	makaronidega	makaroni	makaron	19_S	PlKom	et	makaronidega =makaroni  (PlKom  >makaron !19_S
34047	tellida	telli	tellima	28_V	Inf	et	tellida =telli  (Inf  >tellima !28_V
34051	leppisime	leppi	leppima	28_V	IndIpfPl1	et	leppisime =leppi  (IndIpfPl1  >leppima !28_V
34055	baarisse	baari	baar	22_S	SgIll	et	baarisse =baari  (SgIll  >baar !22_S
34057	pahasoovijaga	soovija	paha+soovija	01_S	SgKom	et	pahasoovijaga =soovija  (SgKom  >paha+soovija !01_S
34059	karul	karu	karu	17_S	SgAd	et	karul =karu  (SgAd  >karu !17_S
34061	porgandi	porgandi	porgand	02_S	SgG	et	porgandi =porgandi  (SgG  >porgand !02_S
34066	kontrabass	bass	kontra+bass	22_S	SgN	et	kontrabass =bass  (SgN  >kontra+bass !22_S
34070	bassivõimuga	võimu	bassi+võim	22_S	SgKom	et	bassivõimuga =võimu  (SgKom  >bassi+võim !22_S
34073	pill	pill	pill	22_S	SgN	et	pill =pill  (SgN  >pill !22_S
34075	paned	pane	panema	36_V	IndPrSg2	et	paned =pane  (IndPrSg2  >panema !36_V
34078	pilliga	pilli	pill	22_S	SgKom	et	pilliga =pilli  (SgKom  >pill !22_S
34081	masina	masina	masin	02_S	SgG	et	masina =masina  (SgG  >masin !02_S
34088	plaanima	plaani	plaanima	28_V	Sup	et	plaanima =plaani  (Sup  >plaanima !28_V
34093	tunnus	tunnus	tunnus	09_S	SgN	et	tunnus =tunnus  (SgN  >tunnus !09_S
34097	ajalooarhiiv	arhiiv	aja+loo+arhiiv	22_S	SgN	et	ajalooarhiiv =arhiiv  (SgN  >aja+loo+arhiiv !22_S
34099	ajalooarhiivil	arhiivi	aja+loo+arhiiv	22_S	SgAd	et	ajalooarhiivil =arhiivi  (SgAd  >aja+loo+arhiiv !22_S
34103	laualiina	lii	laua+lii	26_S	SgEs	et	laualiina =lii  (SgEs  >laua+lii !26_S
34105	ajalooarhiivis	arhiivi	aja+loo+arhiiv	22_S	SgIn	et	ajalooarhiivis =arhiivi  (SgIn  >aja+loo+arhiiv !22_S
34113	klahvel	klahve	klahv	22_S	PlAd	et	klahvel =klahve  (PlAd  >klahv !22_S
34116	puudused	puuduse	puudus	11~09_S	PlN	et	puudused =puuduse  (PlN  >puudus !11~09_S
34118	vain	vain	vain	22_S	SgN	et	vain =vain  (SgN  >vain !22_S
33908	küünarnukkidega	nukki	küünar+nukk	22_S	PlKom	et	küünarnukkidega =nukki  (PlKom  >küünar+nukk !22_S
33909	kuvari	kuvari	kuvar	02_S	SgG	et	kuvari =kuvari  (SgG  >kuvar !02_S
33911	kehaasendi	asendi	keha+asend	02_S	SgG	et	kehaasendi =asendi  (SgG  >keha+asend !02_S
33912	küsimustik	küsimustik	küsimustik	25_S	SgN	et	küsimustik =küsimustik  (SgN  >küsimustik !25_S
33933	täitma	täit	täitma	34_V	Sup	et	täitma =täit  (Sup  >täitma !34_V
33941	jalatugesid	tuge	jala+tugi	21_S	PlP	et	jalatugesid =tuge  (PlP  >jala+tugi !21_S
33949	juhusliku	juhusliku	juhuslik	25_A	SgG	et	juhusliku =juhusliku  (SgG  >juhuslik !25_A
33960	laiutab	laiuta	laiutama	27_V	IndPrSg3	et	laiutab =laiuta  (IndPrSg3  >laiutama !27_V
33963	pimedates	pimeda	pime	02_AS	PlIn	et	pimedates =pimeda  (PlIn  >pime !02_AS
33966	töötervishoiu-	hoiu	töö+tervis+hoid	22_S	SgG	et	töötervishoiu- =hoiu  (SgG  >töö+tervis+hoid !22_S
33971	krabisalat	salat	krabi+salat	02_S	SgN	et	krabisalat =salat  (SgN  >krabi+salat !02_S
33975	riis	riis	riis	22_S	SgN	et	riis =riis  (SgN  >riis !22_S
33979	mahl	mahl	mahl	22_S	SgN	et	mahl =mahl  (SgN  >mahl !22_S
33988	lauas	laua	laud	22_S	SgIn	et	lauas =laua  (SgIn  >laud !22_S
33990	õepoeg	poeg	õe+poeg	22_S	SgN	et	õepoeg =poeg  (SgN  >õe+poeg !22_S
33992	kartulisalati	salati	kartuli+salat	02_S	SgG	et	kartulisalati =salati  (SgG  >kartuli+salat !02_S
33993	kartuliga	kartuli	kartul	02_S	SgKom	et	kartuliga =kartuli  (SgKom  >kartul !02_S
34011	ploomimoosidega	moosi	ploomi+moos	22_S	PlKom	et	ploomimoosidega =moosi  (PlKom  >ploomi+moos !22_S
34013	kutsusime	kutsu	kutsuma	28_V	IndIpfPl1	et	kutsusime =kutsu  (IndIpfPl1  >kutsuma !28_V
34014	kastmes	kastme	kaste	05_S	SgIn	et	kastmes =kastme  (SgIn  >kaste !05_S
34015	ananassiga	ananassi	ananass	22_S	SgKom	et	ananassiga =ananassi  (SgKom  >ananass !22_S
34017	joogideks	joogi	joogi	16_S	PlTr	et	joogideks =joogi  (PlTr  >joogi !16_S
34024	magustoidud	toidu	magus+toit	22_S	PlN	et	magustoidud =toidu  (PlN  >magus+toit !22_S
34025	tomatid	tomati	tomat	02_S	PlN	et	tomatid =tomati  (PlN  >tomat !02_S
34033	jäätise	jäätise	jäätis	11~09_S	SgG	et	jäätise =jäätise  (SgG  >jäätis !11~09_S
34034	krõpsudega	krõpsu	krõps	22_S	PlKom	et	krõpsudega =krõpsu  (PlKom  >krõps !22_S
34038	karamellikastmega	kastme	karamelli+kaste	05_S	SgKom	et	karamellikastmega =kastme  (SgKom  >karamelli+kaste !05_S
34040	baar	baar	baar	22_S	SgN	et	baar =baar  (SgN  >baar !22_S
34063	laevandusfirmasse	firma	laevandus+firma	16_S	SgIll	et	laevandusfirmasse =firma  (SgIll  >laevandus+firma !16_S
34067	isiklik	isiklik	isiklik	25_A	SgN	et	isiklik =isiklik  (SgN  >isiklik !25_A
34069	puhastama	puhasta	puhastama	27_V	Sup	et	puhastama =puhasta  (Sup  >puhastama !27_V
34079	resultaat	resultaat	resultaat	22_S	SgN	et	resultaat =resultaat  (SgN  >resultaat !22_S
34080	kuiv	kuiv	kuiv	22_AS	SgN	et	kuiv =kuiv  (SgN  >kuiv !22_AS
34083	magamistoad	toa	magamis+tuba	18_S	PlN	et	magamistoad =toa  (PlN  >magamis+tuba !18_S
34091	stipendiumiga	stipendiumi	stipendium	19~02_S	SgKom	et	stipendiumiga =stipendiumi  (SgKom  >stipendium !19~02_S
34092	harjutada	harjuta	harjutama	27_V	Inf	et	harjutada =harjuta  (Inf  >harjutama !27_V
34096	arvud	arvu	arv	22_S	PlN	et	arvud =arvu  (PlN  >arv !22_S
34101	sajab	saja	sadama	28_V	IndPrSg3	et	sajab =saja  (IndPrSg3  >sadama !28_V
34102	kardin	kardin	kardin	02_S	SgN	et	kardin =kardin  (SgN  >kardin !02_S
34104	viiendast	viienda	viies	02_O	SgEl	et	viiendast =viienda  (SgEl  >viies !02_O
34106	võrkpalliga	palli	võrk+pall	22_S	SgKom	et	võrkpalliga =palli  (SgKom  >võrk+pall !22_S
34110	puhub	puhu	puhuma	27_V	IndPrSg3	et	puhub =puhu  (IndPrSg3  >puhuma !27_V
34119	koolisüsteemis	süsteemi	kooli+süsteem	22_S	SgIn	et	koolisüsteemis =süsteemi  (SgIn  >kooli+süsteem !22_S
34121	võistlus	võistlus	võistlus	11~09_S	SgN	et	võistlus =võistlus  (SgN  >võistlus !11~09_S
34131	majandusteaduse	teaduse	majandus+teadus	11~09_S	SgG	et	majandusteaduse =teaduse  (SgG  >majandus+teadus !11~09_S
34132	õigusteaduse	teaduse	õigus+teadus	11~09_S	SgG	et	õigusteaduse =teaduse  (SgG  >õigus+teadus !11~09_S
34139	ring	ring	ring	22_S	SgN	et	ring =ring  (SgN  >ring !22_S
34141	madis	madis	madis	09_S	SgN	et	madis =madis  (SgN  >madis !09_S
34144	kokaraamatut	raamatu	koka+raamat	02_S	SgP	et	kokaraamatut =raamatu  (SgP  >koka+raamat !02_S
34147	tunnistama	tunnista	tunnistama	27_V	Sup	et	tunnistama =tunnista  (Sup  >tunnistama !27_V
34150	ühesse	ühe	üks	22_NP	SgIll	et	ühesse =ühe  (SgIll  >üks !22_NP
34160	piparmünt	münt	pipar+münt	22_S	SgN	et	piparmünt =münt  (SgN  >pipar+münt !22_S
34166	küüslauk	lauk	küüs+lauk	22_SA	SgN	et	küüslauk =lauk  (SgN  >küüs+lauk !22_SA
34168	mõlemal	mõlema	mõlema	02_P	SgAd	et	mõlemal =mõlema  (SgAd  >mõlema !02_P
33976	jogurti-	jogurti	jogurt	02_S	SgG	et	jogurti- =jogurti  (SgG  >jogurt !02_S
33980	limonaadid	limonaadi	limonaad	22_S	PlN	et	limonaadid =limonaadi  (PlN  >limonaad !22_S
33982	konjak	konjak	konjak	02_S	SgN	et	konjak =konjak  (SgN  >konjak !02_S
33989	sünnipäevas	päeva	sünni+päev	22_S	SgIn	et	sünnipäevas =päeva  (SgIn  >sünni+päev !22_S
33995	tellime	telli	tellima	28_V	IndPrPl1	et	tellime =telli  (IndPrPl1  >tellima !28_V
33997	tort	tort	tort	22_S	SgN	et	tort =tort  (SgN  >tort !22_S
34000	puuviljadega	vilja	puu+vili	24_S	PlKom	et	puuviljadega =vilja  (PlKom  >puu+vili !24_S
34003	restoranist	restorani	restoran	19_S	SgEl	et	restoranist =restorani  (SgEl  >restoran !19_S
34005	virsik	virsik	virsik	02_S	SgN	et	virsik =virsik  (SgN  >virsik !02_S
34007	banaanikastmega	kastme	banaani+kaste	05_S	SgKom	et	banaanikastmega =kastme  (SgKom  >banaani+kaste !05_S
34021	restoran	restoran	restoran	19_S	SgN	et	restoran =restoran  (SgN  >restoran !19_S
34030	magus	magus	magus	02_A	SgN	et	magus =magus  (SgN  >magus !02_A
34031	singiga	singi	sink	22_S	SgKom	et	singiga =singi  (SgKom  >sink !22_S
34032	sõbrannadega	sõbranna	sõbranna	16_S	PlKom	et	sõbrannadega =sõbranna  (PlKom  >sõbranna !16_S
34041	kohvikud	kohviku	kohvik	02_S	PlN	et	kohvikud =kohviku  (PlN  >kohvik !02_S
34042	ebameeldivate	meeldiva	eba+meeldiv	02_A	PlG	et	ebameeldivate =meeldiva  (PlG  >eba+meeldiv !02_A
34043	kutsehariduskeskuse	keskuse	kutse+haridus+keskus	11~09_S	SgG	et	kutsehariduskeskuse =keskuse  (SgG  >kutse+haridus+keskus !11~09_S
34044	keldrikorrusel	korruse	keldri+korrus	09_S	SgAd	et	keldrikorrusel =korruse  (SgAd  >keldri+korrus !09_S
34048	jooke	jooke	jook	22_S	PlP	et	jooke =jooke  (PlP  >jook !22_S
34054	lõunad	lõuna	lõuna	06_S	PlN	et	lõunad =lõuna  (PlN  >lõuna !06_S
34056	poisiga	poisi	poiss	23?22_S	SgKom	et	poisiga =poisi  (SgKom  >poiss !23?22_S
34060	kartuli-singi	singi	kartuli-sink	22_S	SgG	et	kartuli-singi =singi  (SgG  >kartuli-sink !22_S
34071	küsime	küsi	küsima	27_V	IndPrPl1	et	küsime =küsi  (IndPrPl1  >küsima !27_V
34072	võimud	võimu	võim	22_S	PlN	et	võimud =võimu  (PlN  >võim !22_S
34076	pillidele	pilli	pill	22_S	PlAll	et	pillidele =pilli  (PlAll  >pill !22_S
34086	viiralt	alt	viir+alt	22_S	SgN	et	viiralt =alt  (SgN  >viir+alt !22_S
34089	kultuurkapital	kapital	kultuur+kapital	19_S	SgN	et	kultuurkapital =kapital  (SgN  >kultuur+kapital !19_S
34095	meelis	meeli	meel	13_S	PlIn	et	meelis =meeli  (PlIn  >meel !13_S
34098	üheksakümnest	kümnes	üheksa+kümnene	10~12_AS	SgP	et	üheksakümnest =kümnes  (SgP  >üheksa+kümnene !10~12_AS
34114	paks	paks	paks	22_AS	SgN	et	paks =paks  (SgN  >paks !22_AS
34122	haarab	haara	haarama	29_V	IndPrSg3	et	haarab =haara  (IndPrSg3  >haarama !29_V
34128	täiskasvanuteks	kasvanu	täis+kasvanu	01_S	PlTr	et	täiskasvanuteks =kasvanu  (PlTr  >täis+kasvanu !01_S
34134	tulemuseks	tulemuse	tulemus	11_S	SgTr	et	tulemuseks =tulemuse  (SgTr  >tulemus !11_S
34135	lasteaiakasvatajad	kasvataja	laste+aia+kasvataja	01_S	PlN	et	lasteaiakasvatajad =kasvataja  (PlN  >laste+aia+kasvataja !01_S
34138	kurade	kura	kura	17_A	PlG	et	kurade =kura  (PlG  >kura !17_A
34140	kooliprobleeme	probleeme	kooli+probleem	22_S	PlP	et	kooliprobleeme =probleeme  (PlP  >kooli+probleem !22_S
34146	sõjaplats	plats	sõja+plats	22_S	SgN	et	sõjaplats =plats  (SgN  >sõja+plats !22_S
34155	madisele	madise	madis	09_S	SgAll	et	madisele =madise  (SgAll  >madis !09_S
34156	madise	madise	madis	09_S	SgG	et	madise =madise  (SgG  >madis !09_S
34159	piparmünt	münt	pipar+münt	22_S	SgN	et	piparmünt =münt  (SgN  >pipar+münt !22_S
34165	piparmündil	mündi	pipar+münt	22_S	SgAd	et	piparmündil =mündi  (SgAd  >pipar+münt !22_S
34167	vererõhuprobleemide	probleemi	vere+rõhu+probleem	22_S	PlG	et	vererõhuprobleemide =probleemi  (PlG  >vere+rõhu+probleem !22_S
34180	majal	maja	maja	17_S	SgAd	et	majal =maja  (SgAd  >maja !17_S
34182	tüdrukul	tüdruku	tüdruk	02_S	SgAd	et	tüdrukul =tüdruku  (SgAd  >tüdruk !02_S
34183	vees	vee	vesi	15_S	SgIn	et	vees =vee  (SgIn  >vesi !15_S
34192	sunnib	sunni	sundima	28_V	IndPrSg3	et	sunnib =sunni  (IndPrSg3  >sundima !28_V
34194	eneseteostamiseks	teostamise	enese+teostamine	12_S	SgTr	et	eneseteostamiseks =teostamise  (SgTr  >enese+teostamine !12_S
34196	poolaastat	aasta	pool+aasta	01_S	SgP	et	poolaastat =aasta  (SgP  >pool+aasta !01_S
34198	pärastlõunal	lõuna	pärast+lõuna	06_S	SgAd	et	pärastlõunal =lõuna  (SgAd  >pärast+lõuna !06_S
34212	töökohades	koha	töö+koha	17_S	PlIn	et	töökohades =koha  (PlIn  >töö+koha !17_S
34214	intervjuus	intervjuu	intervjuu	26_S	SgIn	et	intervjuus =intervjuu  (SgIn  >intervjuu !26_S
34216	mingisugust	sugus	mingi+sugune	10_P	SgP	et	mingisugust =sugus  (SgP  >mingi+sugune !10_P
34221	email	email	email	22_S	SgN	et	email =email  (SgN  >email !22_S
34225	naiselehed	lehe	naise+leht	22_S	PlN	et	naiselehed =lehe  (PlN  >naise+leht !22_S
33985	heeringa	heeringa	heeringas	02_S	SgG	et	heeringa =heeringa  (SgG  >heeringas !02_S
33986	kohvivahukoorega	koore	kohvi+vahu+koor	13_S	SgKom	et	kohvivahukoorega =koore  (SgKom  >kohvi+vahu+koor !13_S
33987	valmistas	valmista	valmistama	27_V	IndIpfSg3	et	valmistas =valmista  (IndIpfSg3  >valmistama !27_V
34001	kolaga	kola	kola	17_S	SgKom	et	kolaga =kola  (SgKom  >kola !17_S
34006	roog	roog	roog	22_S	SgN	et	roog =roog  (SgN  >roog !22_S
34010	peakokk	kokk	pea+kokk	22_S	SgN	et	peakokk =kokk  (SgN  >pea+kokk !22_S
34016	küüslauguga	laugu	küüs+lauk	22_SA	SgKom	et	küüslauguga =laugu  (SgKom  >küüs+lauk !22_SA
34019	juhtudel	juhtu	juht	22_S	PlAd	et	juhtudel =juhtu  (PlAd  >juht !22_S
34022	mõõdukad	mõõduka	mõõdukas	02_A	PlN	et	mõõdukad =mõõduka  (PlN  >mõõdukas !02_A
34023	menüüs	menüü	menüü	26_S	SgIn	et	menüüs =menüü  (SgIn  >menüü !26_S
34027	veinid	veini	vein	22_S	PlN	et	veinid =veini  (PlN  >vein !22_S
34028	limonaad	limonaad	limonaad	22_S	SgN	et	limonaad =limonaad  (SgN  >limonaad !22_S
34029	tomati	tomati	tomat	02_S	SgG	et	tomati =tomati  (SgG  >tomat !02_S
34037	banaanid	banaani	banaan	22_S	PlN	et	banaanid =banaani  (PlN  >banaan !22_S
34049	tehnikumis	tehnikumi	tehnikum	19_S	SgIn	et	tehnikumis =tehnikumi  (SgIn  >tehnikum !19_S
34053	jalutamas	jaluta	jalutama	27_V	SupIn	et	jalutamas =jaluta  (SupIn  >jalutama !27_V
34058	hernesupp	supp	herne+supp	22_S	SgN	et	hernesupp =supp  (SgN  >herne+supp !22_S
34064	laeval	laeva	laev	22_S	SgAd	et	laeval =laeva  (SgAd  >laev !22_S
34074	tahvlile	tahvli	tahvel	02_S	SgAll	et	tahvlile =tahvli  (SgAll  >tahvel !02_S
34077	panen	pane	panema	36_V	IndPrSg1	et	panen =pane  (IndPrSg1  >panema !36_V
34082	meeldiks	meeldi	meeldima	27_V	KndPrPs	et	meeldiks =meeldi  (KndPrPs  >meeldima !27_V
34090	võimaldas	võimalda	võimaldama	27_V	IndIpfSg3	et	võimaldas =võimalda  (IndIpfSg3  >võimaldama !27_V
34109	tuhandeüheksasajaüheksakümnest	kümnes	tuhande+üheksa+saja+üheksa+kümnene	10~12_AS	SgP	et	tuhandeüheksasajaüheksakümnest =kümnes  (SgP  >tuhande+üheksa+saja+üheksa+kümnene !10~12_AS
34112	klaas	klaas	klaas	22_S	SgN	et	klaas =klaas  (SgN  >klaas !22_S
34115	koolisüsteeme	süsteeme	kooli+süsteem	22_S	PlP	et	koolisüsteeme =süsteeme  (PlP  >kooli+süsteem !22_S
34126	toodangu	toodangu	toodang	02_S	SgG	et	toodangu =toodangu  (SgG  >toodang !02_S
34129	astuma	astu	astuma	28_V	Sup	et	astuma =astu  (Sup  >astuma !28_V
34137	juristid	juristi	jurist	22_S	PlN	et	juristid =juristi  (PlN  >jurist !22_S
34145	kukuvad	kuku	kukkuma	28_V	IndPrPl3	et	kukuvad =kuku  (IndPrPl3  >kukkuma !28_V
34148	korterist	korteri	korter	02_S	SgEl	et	korterist =korteri  (SgEl  >korter !02_S
34149	kiirustades	kiirusta	kiirustama	27_V	Ger	et	kiirustades =kiirusta  (Ger  >kiirustama !27_V
34151	söögu	söö	sööma	38_V	ImpPrPs	et	söögu =söö  (ImpPrPs  >sööma !38_V
34153	sööklas	söökla	söökla	01_S	SgIn	et	sööklas =söökla  (SgIn  >söökla !01_S
34154	lõunaaeg	aeg	lõuna+aeg	22_S	SgN	et	lõunaaeg =aeg  (SgN  >lõuna+aeg !22_S
34158	kadrile	kadri	kadri	16_S	SgAll	et	kadrile =kadri  (SgAll  >kadri !16_S
34169	abikätt	kä	abi+käsi	15_S	SgP	et	abikätt =kä  (SgP  >abi+käsi !15_S
34178	kinosse	kino	kino	17_S	SgIll	et	kinosse =kino  (SgIll  >kino !17_S
34184	majale	maja	maja	17_S	SgAll	et	majale =maja  (SgAll  >maja !17_S
34193	peresid	pere	pere	16_S	PlP	et	peresid =pere  (PlP  >pere !16_S
34199	kartulisalatit	salati	kartuli+salat	02_S	SgP	et	kartulisalatit =salati  (SgP  >kartuli+salat !02_S
34200	jaanile	jaani	jaan	22_S	SgAll	et	jaanile =jaani  (SgAll  >jaan !22_S
34201	jaanil	jaani	jaan	22_S	SgAd	et	jaanil =jaani  (SgAd  >jaan !22_S
34202	paksud	paksu	paks	22_AS	PlN	et	paksud =paksu  (PlN  >paks !22_AS
34203	naisteajakirjades	kirja	naiste+aja+kiri	24_S	PlIn	et	naisteajakirjades =kirja  (PlIn  >naiste+aja+kiri !24_S
34207	pinnapealne	pealne	pinna+pealne	02_AS	SgN	et	pinnapealne =pealne  (SgN  >pinna+pealne !02_AS
34211	pinnapealsed	pealse	pinna+pealne	02_AS	PlN	et	pinnapealsed =pealse  (PlN  >pinna+pealne !02_AS
34226	asjades	asja	asi	24_S	PlIn	et	asjades =asja  (PlIn  >asi !24_S
34230	pidutsema	pidutse	pidutsema	27_V	Sup	et	pidutsema =pidutse  (Sup  >pidutsema !27_V
34231	mõlemates	mõlema	mõlema	02_P	PlIn	et	mõlemates =mõlema  (PlIn  >mõlema !02_P
34232	kreemid	kreemi	kreem	22_SA	PlN	et	kreemid =kreemi  (PlN  >kreem !22_SA
34234	parfüüm	parfüüm	parfüüm	22_S	SgN	et	parfüüm =parfüüm  (SgN  >parfüüm !22_S
34241	vennanaisena	naise	venna+naine	12_S	SgEs	et	vennanaisena =naise  (SgEs  >venna+naine !12_S
34244	rätikuta	rätiku	rätik	02_S	SgAb	et	rätikuta =rätiku  (SgAb  >rätik !02_S
34245	näkku	näkku	nägu	18_S	SgAdt	et	näkku =näkku  (SgAdt  >nägu !18_S
34248	naiivne	naiivne	naiivne	02_A	SgN	et	naiivne =naiivne  (SgN  >naiivne !02_A
34120	seehulgas	hulga	see+hulk	22_S	SgIn	et	seehulgas =hulga  (SgIn  >see+hulk !22_S
34123	kannavad	kanna	kandma	34_V	IndPrPl3	et	kannavad =kanna  (IndPrPl3  >kandma !34_V
34125	haridussüsteeme	süsteeme	haridus+süsteem	22_S	PlP	et	haridussüsteeme =süsteeme  (PlP  >haridus+süsteem !22_S
34127	vaimset	vaimse	vaimne	02_A	SgP	et	vaimset =vaimse  (SgP  >vaimne !02_A
34130	vastuvõtmise	võtmise	vastu+võtmine	12?10_S	SgG	et	vastuvõtmise =võtmise  (SgG  >vastu+võtmine !12?10_S
34133	lasteaiakasvatajate	kasvataja	laste+aia+kasvataja	01_S	PlG	et	lasteaiakasvatajate =kasvataja  (PlG  >laste+aia+kasvataja !01_S
34136	majandusteadlased	teadlase	majandus+teadlane	12?10_S	PlN	et	majandusteadlased =teadlase  (PlN  >majandus+teadlane !12?10_S
34142	ettevalmistusi	valmistusi	ette+valmistus	11_S	PlP	et	ettevalmistusi =valmistusi  (PlP  >ette+valmistus !11_S
34152	kõneleb	kõnele	kõnelema	31~27_V	IndPrSg3	et	kõneleb =kõnele  (IndPrSg3  >kõnelema !31~27_V
34161	põletikuvastane	vastane	põletiku+vastane	10_AS	SgN	et	põletikuvastane =vastane  (SgN  >põletiku+vastane !10_AS
34162	piparmündi	mündi	pipar+münt	22_S	SgG	et	piparmündi =mündi  (SgG  >pipar+münt !22_S
34163	leevendab	leevenda	leevendama	27_V	IndPrSg3	et	leevendab =leevenda  (IndPrSg3  >leevendama !27_V
34164	üleminekuajaga	aja	üle+mineku+aeg	22_S	SgKom	et	üleminekuajaga =aja  (SgKom  >üle+mineku+aeg !22_S
34172	pildis	pildi	pilt	22_S	SgIn	et	pildis =pildi  (SgIn  >pilt !22_S
34173	ungarlane	ungarlane	ungarlane	12_S	SgN	et	ungarlane =ungarlane  (SgN  >ungarlane !12_S
34174	madist	madis	madis	09_S	SgP	et	madist =madis  (SgP  >madis !09_S
34179	turule	turu	turg	22_S	SgAll	et	turule =turu  (SgAll  >turg !22_S
34188	faktide	fakti	fakt	22_S	PlG	et	faktide =fakti  (PlG  >fakt !22_S
34189	toodetakse	toode	tootma	34_V	IndPrIps	et	toodetakse =toode  (IndPrIps  >tootma !34_V
34209	meesteajakirjad	kirja	meeste+aja+kiri	24_S	PlN	et	meesteajakirjad =kirja  (PlN  >meeste+aja+kiri !24_S
34217	taktikat	taktika	taktika	01_S	SgP	et	taktikat =taktika  (SgP  >taktika !01_S
34219	veider	veider	veider	02_A	SgN	et	veider =veider  (SgN  >veider !02_A
34227	lehtes	lehtes	lehtes	41_DA	ID	et	lehtes =lehtes  (ID  >lehtes !41_DA
34233	juuksevärv	värv	juukse+värv	22_S	SgN	et	juuksevärv =värv  (SgN  >juukse+värv !22_S
34237	mehedki	mehe	mees	13_S	PlN^	et	mehedki =mehe  (PlN^  >mees !13_S
34238	piinlik	piinlik	piinlik	25_A	SgN	et	piinlik =piinlik  (SgN  >piinlik !25_A
34239	lennukis	lennuki	lennuk	02_S	SgIn	et	lennukis =lennuki  (SgIn  >lennuk !02_S
34242	ladin	ladin	ladin	02_S	SgN	et	ladin =ladin  (SgN  >ladin !02_S
34246	hapet	hape	hape	06_S	SgP	et	hapet =hape  (SgP  >hape !06_S
34249	kommenteeriks	kommenteeri	kommenteerima	28_V	KndPrPs	et	kommenteeriks =kommenteeri  (KndPrPs  >kommenteerima !28_V
34253	seinal	seina	sein	23?22_S	SgAd	et	seinal =seina  (SgAd  >sein !23?22_S
34257	raamaturiiuli	riiuli	raamatu+riiul	02_S	SgG	et	raamaturiiuli =riiuli  (SgG  >raamatu+riiul !02_S
34264	kirjutuslaual	laua	kirjutus+laud	22_S	SgAd	et	kirjutuslaual =laua  (SgAd  >kirjutus+laud !22_S
34269	jänest	jänes	jänes	09_S	SgP	et	jänest =jänes  (SgP  >jänes !09_S
34273	maatundmine	tundmine	maa+tundmine	12?10_S	SgN	et	maatundmine =tundmine  (SgN  >maa+tundmine !12?10_S
34287	juur-	juur	juur	13_S	SgN	et	juur- =juur  (SgN  >juur !13_S
34291	koogisse	koogi	kook	22_S	SgIll	et	koogisse =koogi  (SgIll  >kook !22_S
34295	rahvatantsud	tantsu	rahva+tants	22_S	PlN	et	rahvatantsud =tantsu  (PlN  >rahva+tants !22_S
34299	sisseoste	oste	sisse+ost	22_S	PlP	et	sisseoste =oste  (PlP  >sisse+ost !22_S
34300	tõusma	tõus	tõusma	32_V	Sup	et	tõusma =tõus  (Sup  >tõusma !32_V
34301	maaoskus	oskus	maa+oskus	11~09_S	SgN	et	maaoskus =oskus  (SgN  >maa+oskus !11~09_S
34302	liblika	liblika	liblikas	02_S	SgG	et	liblika =liblika  (SgG  >liblikas !02_S
34303	liblikal	liblika	liblikas	02_S	SgAd	et	liblikal =liblika  (SgAd  >liblikas !02_S
34307	siduma	sidu	siduma	28_V	Sup	et	siduma =sidu  (Sup  >siduma !28_V
34311	enamikul	enamiku	enamik	25_S	SgAd	et	enamikul =enamiku  (SgAd  >enamik !25_S
34312	läikis	läiki	läikima	28_V	IndIpfSg3	et	läikis =läiki  (IndIpfSg3  >läikima !28_V
34313	oi	oi	oi	41_I	ID	et	oi =oi  (ID  >oi !41_I
34317	uss	uss	uss	22_S	SgN	et	uss =uss  (SgN  >uss !22_S
34322	kadastiku	kadastiku	kadastik	25_S	SgG	et	kadastiku =kadastiku  (SgG  >kadastik !25_S
34328	võrrelge	võrrel	võrdlema	30_V	ImpPrPl2	et	võrrelge =võrrel  (ImpPrPl2  >võrdlema !30_V
34330	pärastsõjajärgset	järgse	pärast+sõja+järgne	02_A	SgP	et	pärastsõjajärgset =järgse  (SgP  >pärast+sõja+järgne !02_A
34333	arheoloogiast	arheoloogia	arheoloogia	01_S	SgEl	et	arheoloogiast =arheoloogia  (SgEl  >arheoloogia !01_S
34335	filmikunstis	kunsti	filmi+kunst	22_S	SgIn	et	filmikunstis =kunsti  (SgIn  >filmi+kunst !22_S
34338	stiile	stiile	stiil	22_S	PlP	et	stiile =stiile  (PlP  >stiil !22_S
34124	prooviti	proovi	proovima	28_V	IndIpfIps	et	prooviti =proovi  (IndIpfIps  >proovima !28_V
34143	toolile	tooli	tool	22_S	SgAll	et	toolile =tooli  (SgAll  >tool !22_S
34157	sõbratar	sõbratar	sõbratar	19_S	SgN	et	sõbratar =sõbratar  (SgN  >sõbratar !19_S
34170	poissed	poisse	poise	06_S	PlN	et	poissed =poisse  (PlN  >poise !06_S
34176	kalad	kala	kala	17_S	PlN	et	kalad =kala  (PlN  >kala !17_S
34177	katusel	katuse	katus	09_S	SgAd	et	katusel =katuse  (SgAd  >katus !09_S
34181	trepp	trepp	trepp	22_S	SgN	et	trepp =trepp  (SgN  >trepp !22_S
34185	aknet	akne	akne	01_S	SgP	et	aknet =akne  (SgP  >akne !01_S
34187	rõhutatakse	rõhuta	rõhutama	27_V	IndPrIps	et	rõhutatakse =rõhuta  (IndPrIps  >rõhutama !27_V
34190	täiskasvanutel	kasvanu	täis+kasvanu	01_S	PlAd	et	täiskasvanutel =kasvanu  (PlAd  >täis+kasvanu !01_S
34195	kadril	kadri	kadri	16_S	SgAd	et	kadril =kadri  (SgAd  >kadri !16_S
34208	tüüpilised	tüüpilise	tüüpiline	12_A	PlN	et	tüüpilised =tüüpilise  (PlN  >tüüpiline !12_A
34210	naisteajakirjadega	kirja	naiste+aja+kiri	24_S	PlKom	et	naisteajakirjadega =kirja  (PlKom  >naiste+aja+kiri !24_S
34218	rõivaese	ese	rõiva+ese	04_S	SgN	et	rõivaese =ese  (SgN  >rõiva+ese !04_S
34220	plaadilt	plaadi	plaat	22_S	SgAbl	et	plaadilt =plaadi  (SgAbl  >plaat !22_S
34223	taimetoitlased	toitlase	taime+toitlane	12?10_S	PlN	et	taimetoitlased =toitlase  (PlN  >taime+toitlane !12?10_S
34243	saudi-araabiast	ast	saudi-ara+abi+ast	22_S	SgN	et	saudi-araabiast =ast  (SgN  >saudi-ara+abi+ast !22_S
34251	heatahtlikud	tahtliku	hea+tahtlik	25_A	PlN	et	heatahtlikud =tahtliku  (PlN  >hea+tahtlik !25_A
34252	pild	pild	pild	22_S	SgN	et	pild =pild  (SgN  >pild !22_S
34260	riidekapp	kapp	riide+kapp	22_S	SgN	et	riidekapp =kapp  (SgN  >riide+kapp !22_S
34261	voodit	voodi	voodi	01_S	SgP	et	voodit =voodi  (SgP  >voodi !01_S
34289	marjad	marja	mari	24_S	PlN	et	marjad =marja  (PlN  >mari !24_S
34290	sidrunit	sidruni	sidrun	02_S	SgP	et	sidrunit =sidruni  (SgP  >sidrun !02_S
34297	kolmapäev	päev	kolma+päev	22_S	SgN	et	kolmapäev =päev  (SgN  >kolma+päev !22_S
34304	kiirustab	kiirusta	kiirustama	27_V	IndPrSg3	et	kiirustab =kiirusta  (IndPrSg3  >kiirustama !27_V
34305	kohtub	kohtu	kohtuma	27_V	IndPrSg3	et	kohtub =kohtu  (IndPrSg3  >kohtuma !27_V
34306	kõrtsisse	kõrtsi	kõrts	22_S	SgIll	et	kõrtsisse =kõrtsi  (SgIll  >kõrts !22_S
34314	hommik	hommik	hommik	02_S	SgN	et	hommik =hommik  (SgN  >hommik !02_S
34325	ainemetoodikat	metoodika	aine+metoodika	01_S	SgP	et	ainemetoodikat =metoodika  (SgP  >aine+metoodika !01_S
34326	pedagoogikat	pedagoogika	pedagoogika	01_S	SgP	et	pedagoogikat =pedagoogika  (SgP  >pedagoogika !01_S
34342	atlase	atlase	atlas	11~09_S	SgG	et	atlase =atlase  (SgG  >atlas !11~09_S
34345	liikumisvahendiks	vahendi	liikumis+vahend	02_S	SgTr	et	liikumisvahendiks =vahendi  (SgTr  >liikumis+vahend !02_S
34348	lahutatakse	lahuta	lahutama	27_V	IndPrIps	et	lahutatakse =lahuta  (IndPrIps  >lahutama !27_V
34352	kultuuritegelastega	tegelas	kultuuri+tegelane	12_S	PlKom	et	kultuuritegelastega =tegelas  (PlKom  >kultuuri+tegelane !12_S
34354	represseeriti	represseeri	represseerima	28_V	IndIpfIps	et	represseeriti =represseeri  (IndIpfIps  >represseerima !28_V
34355	monumendid	monumendi	monument	22_S	PlN	et	monumendid =monumendi  (PlN  >monument !22_S
34356	kristlikke	kristlikke	kristlik	25_A	PlP	et	kristlikke =kristlikke  (PlP  >kristlik !25_A
34363	märtsil	märtsi	märts	22_S	SgAd	et	märtsil =märtsi  (SgAd  >märts !22_S
34376	mark	mark	mark	22_S	SgN	et	mark =mark  (SgN  >mark !22_S
34385	rasketööstus	tööstus	raske+tööstus	11~09_S	SgN	et	rasketööstus =tööstus  (SgN  >raske+tööstus !11~09_S
34386	toodang	toodang	toodang	02_S	SgN	et	toodang =toodang  (SgN  >toodang !02_S
34389	plaanimajanduse	majanduse	plaani+majandus	11_S	SgG	et	plaanimajanduse =majanduse  (SgG  >plaani+majandus !11_S
34393	annas	anna	anna	16_S	SgIn	et	annas =anna  (SgIn  >anna !16_S
34398	ensv-s	ensv	ensv	xx_Q	SgIn	et	ensv-s =ensv  (SgIn  >ensv !xx_Q
34399	peosid	peo	peo	26_S	PlP	et	peosid =peo  (PlP  >peo !26_S
34405	okupatsioon	okupatsioon	okupatsioon	22_S	SgN	et	okupatsioon =okupatsioon  (SgN  >okupatsioon !22_S
34406	valiti	vali	valima	27_V	IndIpfIps	et	valiti =vali  (IndIpfIps  >valima !27_V
34407	riigipeaks	pea	riigi+pea	26_S	SgTr	et	riigipeaks =pea  (SgTr  >riigi+pea !26_S
34411	parlamentaarsele	parlamentaarse	parlamentaarne	02_A	SgAll	et	parlamentaarsele =parlamentaarse  (SgAll  >parlamentaarne !02_A
34418	rahvust	rahvus	rahvus	11~09_S	SgP	et	rahvust =rahvus  (SgP  >rahvus !11~09_S
34420	läände	lään	lääs	14_S	SgAdt	et	läände =lään  (SgAdt  >lääs !14_S
34422	juhikultus	kultus	juhi+kultus	11~09_S	SgN	et	juhikultus =kultus  (SgN  >juhi+kultus !11~09_S
34431	arengust	arengu	areng	02_S	SgEl	et	arengust =arengu  (SgEl  >areng !02_S
34171	poissed	poisse	poise	06_S	PlN	et	poissed =poisse  (PlN  >poise !06_S
34175	teatrist	teatri	teater	02_S	SgEl	et	teatrist =teatri  (SgEl  >teater !02_S
34186	koolisüsteem	süsteem	kooli+süsteem	22_S	SgN	et	koolisüsteem =süsteem  (SgN  >kooli+süsteem !22_S
34191	teadustase	tase	teadus+tase	04_S	SgN	et	teadustase =tase  (SgN  >teadus+tase !04_S
34197	leena	lee	lee	26_S	SgEs	et	leena =lee  (SgEs  >lee !26_S
34204	teemadest	teema	teema	16_S	PlEl	et	teemadest =teema  (PlEl  >teema !16_S
34205	meik	meik	meik	22_S	SgN	et	meik =meik  (SgN  >meik !22_S
34206	raskest	raske	raske	01_A	SgEl	et	raskest =raske  (SgEl  >raske !01_A
34213	käituma	käitu	käituma	27_V	Sup	et	käituma =käitu  (Sup  >käituma !27_V
34215	küsiti	küsi	küsima	27_V	IndIpfIps	et	küsiti =küsi  (IndIpfIps  >küsima !27_V
34222	moslemid	moslemi	moslem	02_S	PlN	et	moslemid =moslemi  (PlN  >moslem !02_S
34224	kuulsatest	kuulsa	kuulus	02_A	PlEl	et	kuulsatest =kuulsa  (PlEl  >kuulus !02_A
34228	sportidest	sporti	sport	22_S	PlEl	et	sportidest =sporti  (PlEl  >sport !22_S
34240	bussis	bussi	buss	22_S	SgIn	et	bussis =bussi  (SgIn  >buss !22_S
34247	viskama	viska	viskama	29_V	Sup	et	viskama =viska  (Sup  >viskama !29_V
34250	armsad	armsa	armas	03~05_A	PlN	et	armsad =armsa  (PlN  >armas !03~05_A
34259	riiuli	riiuli	riiul	02_S	SgG	et	riiuli =riiuli  (SgG  >riiul !02_S
34262	toal	toa	tuba	18_S	SgAd	et	toal =toa  (SgAd  >tuba !18_S
34263	pliiatsit	pliiatsi	pliiats	02_S	SgP	et	pliiatsit =pliiatsi  (SgP  >pliiats !02_S
34266	sahtlil	sahtli	sahtel	02_S	SgAd	et	sahtlil =sahtli  (SgAd  >sahtel !02_S
34268	voodil	voodi	voodi	01_S	SgAd	et	voodil =voodi  (SgAd  >voodi !01_S
34272	laplane	laplane	laplane	12?10_S	SgN	et	laplane =laplane  (SgN  >laplane !12?10_S
34279	kohtan	kohta	kohtama	29_V	IndPrSg1	et	kohtan =kohta  (IndPrSg1  >kohtama !29_V
34281	ülesast	ast	üles+ast	22_S	SgN	et	ülesast =ast  (SgN  >üles+ast !22_S
34284	puuvili	vili	puu+vili	24_S	SgN	et	puuvili =vili  (SgN  >puu+vili !24_S
34292	riie	riie	riie	06_S	SgN	et	riie =riie  (SgN  >riie !06_S
34293	armastame	armasta	armastama	27_V	IndPrPl1	et	armastame =armasta  (IndPrPl1  >armastama !27_V
34294	tõusen	tõuse	tõusma	32_V	IndPrSg1	et	tõusen =tõuse  (IndPrSg1  >tõusma !32_V
34296	praktikum	praktikum	praktikum	19_S	SgN	et	praktikum =praktikum  (SgN  >praktikum !19_S
34308	sõbrannasid	sõbranna	sõbranna	16_S	PlP	et	sõbrannasid =sõbranna  (PlP  >sõbranna !16_S
34316	mesilat	mesila	mesila	01_S	SgP	et	mesilat =mesila  (SgP  >mesila !01_S
34320	nautis	nauti	nautima	28_V	IndIpfSg3	et	nautis =nauti  (IndIpfSg3  >nautima !28_V
34324	lastepsühholoogiat	psühholoogia	laste+psühholoogia	01_S	SgP	et	lastepsühholoogiat =psühholoogia  (SgP  >laste+psühholoogia !01_S
34327	liikmeteks	liikme	liige	05_S	PlTr	et	liikmeteks =liikme  (PlTr  >liige !05_S
34331	vabariigiks	riigi	vaba+riik	22_S	SgTr	et	vabariigiks =riigi  (SgTr  >vaba+riik !22_S
34339	murdeid	murde	murre	06_S	PlP	et	murdeid =murde  (PlP  >murre !06_S
34341	murrete	murre	murre	06_S	PlG	et	murrete =murre  (PlG  >murre !06_S
34344	muusikad	muusika	muusika	01_S	PlN	et	muusikad =muusika  (PlN  >muusika !01_S
34350	suvepäevad	päeva	suve+päev	22_S	PlN	et	suvepäevad =päeva  (PlN  >suve+päev !22_S
34351	seltsidest	seltsi	selts	22_S	PlEl	et	seltsidest =seltsi  (PlEl  >selts !22_S
34359	maavaraks	vara	maa+vara	17_S	SgTr	et	maavaraks =vara  (SgTr  >maa+vara !17_S
34360	tolleaegseid	aegse	tolle+aegne	02_A	PlP	et	tolleaegseid =aegse  (PlP  >tolle+aegne !02_A
34361	kiik	kiik	kiik	22_S	SgN	et	kiik =kiik  (SgN  >kiik !22_S
34364	norm	norm	norm	22_S	SgN	et	norm =norm  (SgN  >norm !22_S
34365	hariduses	hariduse	haridus	11_S	SgIn	et	hariduses =hariduse  (SgIn  >haridus !11_S
34370	kirjandusteostes	teos	kirjandus+teos	09_S	PlIn	et	kirjandusteostes =teos  (PlIn  >kirjandus+teos !09_S
34372	õppeprogrammis	programmi	õppe+programm	22_S	SgIn	et	õppeprogrammis =programmi  (SgIn  >õppe+programm !22_S
34388	vanurid	vanuri	vanur	02_S	PlN	et	vanurid =vanuri  (PlN  >vanur !02_S
34396	kontrolliti	kontrolli	kontrollima	28_V	IndIpfIps	et	kontrolliti =kontrolli  (IndIpfIps  >kontrollima !28_V
34400	laulupeosid	peo	laulu+peo	26_S	PlP	et	laulupeosid =peo  (PlP  >laulu+peo !26_S
34403	rehabiliteeriti	rehabiliteeri	rehabiliteerima	28_V	IndIpfIps	et	rehabiliteeriti =rehabiliteeri  (IndIpfIps  >rehabiliteerima !28_V
34414	taasavati	ava	taas+avama	27_V	IndIpfIps	et	taasavati =ava  (IndIpfIps  >taas+avama !27_V
34416	teadused	teaduse	teadus	11~09_S	PlN	et	teadused =teaduse  (PlN  >teadus !11~09_S
34417	rahvusteadused	teaduse	rahvus+teadus	11~09_S	PlN	et	rahvusteadused =teaduse  (PlN  >rahvus+teadus !11~09_S
34425	tõsteti	tõste	tõstma	34_V	IndIpfIps	et	tõsteti =tõste  (IndIpfIps  >tõstma !34_V
34229	riiet	riie	riie	06_S	SgP	et	riiet =riie  (SgP  >riie !06_S
34235	alkohol	alkohol	alkohol	19_S	SgN	et	alkohol =alkohol  (SgN  >alkohol !19_S
34236	spordiasjad	asja	spordi+asi	24_S	PlN	et	spordiasjad =asja  (PlN  >spordi+asi !24_S
34255	televiisor	televiisor	televiisor	02_S	SgN	et	televiisor =televiisor  (SgN  >televiisor !02_S
34267	vihikut	vihiku	vihik	02_S	SgP	et	vihikut =vihiku  (SgP  >vihik !02_S
34270	riiulil	riiuli	riiul	02_S	SgAd	et	riiulil =riiuli  (SgAd  >riiul !02_S
34274	õpetan	õpeta	õpetama	27_V	IndPrSg1	et	õpetan =õpeta  (IndPrSg1  >õpetama !27_V
34275	tüdrukule	tüdruku	tüdruk	02_S	SgAll	et	tüdrukule =tüdruku  (SgAll  >tüdruk !02_S
34276	teisipäeval	päeva	teisi+päev	22_S	SgAd	et	teisipäeval =päeva  (SgAd  >teisi+päev !22_S
34277	luuletusõpetus	õpetus	luuletus+õpetus	11_S	SgN	et	luuletusõpetus =õpetus  (SgN  >luuletus+õpetus !11_S
34278	seminar	seminar	seminar	19_S	SgN	et	seminar =seminar  (SgN  >seminar !19_S
34282	kartulit	kartuli	kartul	02_S	SgP	et	kartulit =kartuli  (SgP  >kartul !02_S
34283	hapukoort	koor	hapu+koor	13_S	SgP	et	hapukoort =koor  (SgP  >hapu+koor !13_S
34286	leivad	leiva	leib	22_S	PlN	et	leivad =leiva  (PlN  >leib !22_S
34288	aedviljad	vilja	aed+vili	24_S	PlN	et	aedviljad =vilja  (PlN  >aed+vili !24_S
34315	teeksin	tee	tegema	28_V	KndPrSg1	et	teeksin =tee  (KndPrSg1  >tegema !28_V
34337	arhitektuuris	arhitektuuri	arhitektuur	22_S	SgIn	et	arhitektuuris =arhitektuuri  (SgIn  >arhitektuur !22_S
34346	jalgratas	ratas	jalg+ratas	07_S	SgN	et	jalgratas =ratas  (SgN  >jalg+ratas !07_S
34357	tõlgendas	tõlgenda	tõlgendama	27_V	IndIpfSg3	et	tõlgendas =tõlgenda  (IndIpfSg3  >tõlgendama !27_V
34366	ankeet	ankeet	ankeet	22_S	SgN	et	ankeet =ankeet  (SgN  >ankeet !22_S
34367	sorteeriti	sorteeri	sorteerima	28_V	IndIpfIps	et	sorteeriti =sorteeri  (IndIpfIps  >sorteerima !28_V
34371	kommunistideks	kommunisti	kommunist	22_S	PlTr	et	kommunistideks =kommunisti  (PlTr  >kommunist !22_S
34373	ülikoolide	kooli	üli+kool	22_S	PlG	et	ülikoolide =kooli  (PlG  >üli+kool !22_S
34374	väärtuslikuks	väärtusliku	väärtuslik	25_A	SgTr	et	väärtuslikuks =väärtusliku  (SgTr  >väärtuslik !25_A
34377	rahvateaduse	teaduse	rahva+teadus	11~09_S	SgG	et	rahvateaduse =teaduse  (SgG  >rahva+teadus !11~09_S
34384	plaanimajandus	majandus	plaani+majandus	11_S	SgN	et	plaanimajandus =majandus  (SgN  >plaani+majandus !11_S
34394	rootsisse	rootsi	roots	22_S	SgIll	et	rootsisse =rootsi  (SgIll  >roots !22_S
34409	demokraatliku	demokraatliku	demokraatlik	25_A	SgG	et	demokraatliku =demokraatliku  (SgG  >demokraatlik !25_A
34421	surutis	surutis	surutis	11_S	SgN	et	surutis =surutis  (SgN  >surutis !11_S
34423	hirmuseisund	seisund	hirmu+seisund	02_S	SgN	et	hirmuseisund =seisund  (SgN  >hirmu+seisund !02_S
34434	kampaaniad	kampaania	kampaania	01_S	PlN	et	kampaaniad =kampaania  (PlN  >kampaania !01_S
34441	dissidendid	dissidendi	dissident	22_S	PlN	et	dissidendid =dissidendi  (PlN  >dissident !22_S
34448	andsite	and	andma	34_V	IndIpfPl2	et	andsite =and  (IndIpfPl2  >andma !34_V
34449	verbid	verbi	verb	22_S	PlN	et	verbid =verbi  (PlN  >verb !22_S
34453	verbide	verbi	verb	22_S	PlG	et	verbide =verbi  (PlG  >verb !22_S
34454	metalliaeg	aeg	metalli+aeg	22_S	SgN	et	metalliaeg =aeg  (SgN  >metalli+aeg !22_S
34455	pronks	pronks	pronks	22_S	SgN	et	pronks =pronks  (SgN  >pronks !22_S
34461	õpiti	õpi	õppima	28_V	IndIpfIps	et	õpiti =õpi  (IndIpfIps  >õppima !28_V
34466	kõblas	kõblas	kõblas	07_S	SgN	et	kõblas =kõblas  (SgN  >kõblas !07_S
34477	sõdu	sõdu	sõda	18_S	PlP	et	sõdu =sõdu  (PlP  >sõda !18_S
34480	vargad	varga	varas	07_S	PlN	et	vargad =varga  (PlN  >varas !07_S
34482	maaharimisega	harimise	maa+harimine	12_S	SgKom	et	maaharimisega =harimise  (SgKom  >maa+harimine !12_S
34489	metalliajale	aja	metalli+aeg	22_S	SgAll	et	metalliajale =aja  (SgAll  >metalli+aeg !22_S
34496	lambaid	lamba	lammas	07_S	PlP	et	lambaid =lamba  (PlP  >lammas !07_S
34502	rannikul	ranniku	rannik	02_S	SgAd	et	rannikul =ranniku  (SgAd  >rannik !02_S
34507	luuplaadist	plaadi	luu+plaat	22_S	SgEl	et	luuplaadist =plaadi  (SgEl  >luu+plaat !22_S
34512	olendite	olendi	olend	02_S	PlG	et	olendite =olendi  (PlG  >olend !02_S
34517	erakondade	erakonda	erakond	22_S	PlG	et	erakondade =erakonda  (PlG  >erakond !22_S
34518	peitub	peitu	peituma	27_V	IndPrSg3	et	peitub =peitu  (IndPrSg3  >peituma !27_V
34523	pastoriks	pastori	pastor	02_S	SgTr	et	pastoriks =pastori  (SgTr  >pastor !02_S
34525	lõpuaastad	aasta	lõpu+aasta	01_S	PlN	et	lõpuaastad =aasta  (PlN  >lõpu+aasta !01_S
34535	vallasvarale	vara	vallas+vara	17_S	SgAll	et	vallasvarale =vara  (SgAll  >vallas+vara !17_S
34536	pärandada	päranda	pärandama	27_V	Inf	et	pärandada =päranda  (Inf  >pärandama !27_V
34549	eesmärgiga	märgi	ees+märk	22_S	SgKom	et	eesmärgiga =märgi  (SgKom  >ees+märk !22_S
34254	kapil	kapi	kapp	22_S	SgAd	et	kapil =kapi  (SgAd  >kapp !22_S
34256	raamaturiiulil	riiuli	raamatu+riiul	02_S	SgAd	et	raamaturiiulil =riiuli  (SgAd  >raamatu+riiul !02_S
34258	raamaturiiulit	riiuli	raamatu+riiul	02_S	SgP	et	raamaturiiulit =riiuli  (SgP  >raamatu+riiul !02_S
34265	pastapliiatsit	pliiatsi	pasta+pliiats	02_S	SgP	et	pastapliiatsit =pliiatsi  (SgP  >pasta+pliiats !02_S
34271	semestri	semestri	semester	02_S	SgG	et	semestri =semestri  (SgG  >semester !02_S
34280	lõunal	lõuna	lõuna	06_S	SgAd	et	lõunal =lõuna  (SgAd  >lõuna !06_S
34285	piimasaadused	saaduse	piima+saadus	11~09_S	PlN	et	piimasaadused =saaduse  (PlN  >piima+saadus !11~09_S
34298	neljapäev	päev	nelja+päev	22_S	SgN	et	neljapäev =päev  (SgN  >nelja+päev !22_S
34309	kohtab	kohta	kohtama	29_V	IndPrSg3	et	kohtab =kohta  (IndPrSg3  >kohtama !29_V
34310	puhkab	puhka	puhkama	29_V	IndPrSg3	et	puhkab =puhka  (IndPrSg3  >puhkama !29_V
34318	tüdines	tüdine	tüdinema	27_V	IndIpfSg3	et	tüdines =tüdine  (IndIpfSg3  >tüdinema !27_V
34319	mõtiskles	mõtiskle	mõtisklema	27_V	IndIpfSg3	et	mõtiskles =mõtiskle  (IndIpfSg3  >mõtisklema !27_V
34321	lahedal	laheda	lahe	02_A	SgAd	et	lahedal =laheda  (SgAd  >lahe !02_A
34323	heameelega	meele	hea+meel	13_S	SgKom	et	heameelega =meele  (SgKom  >hea+meel !13_S
34329	aegsest	aegse	aegne	02_A	SgEl	et	aegsest =aegse  (SgEl  >aegne !02_A
34332	rahvuskirjandus	kirjandus	rahvus+kirjandus	11_S	SgN	et	rahvuskirjandus =kirjandus  (SgN  >rahvus+kirjandus !11_S
34334	kõrgkoolideni	kooli	kõrg+kool	22_S	PlTer	et	kõrgkoolideni =kooli  (PlTer  >kõrg+kool !22_S
34336	kinodes	kino	kino	17_S	PlIn	et	kinodes =kino  (PlIn  >kino !17_S
34358	toodeti	toode	tootma	34_V	IndIpfIps	et	toodeti =toode  (IndIpfIps  >tootma !34_V
34362	kolhoosid	kolhoosi	kolhoos	22_S	PlN	et	kolhoosid =kolhoosi  (PlN  >kolhoos !22_S
34368	metsavennad	venna	metsa+vend	22_S	PlN	et	metsavennad =venna  (PlN  >metsa+vend !22_S
34369	dikteeris	dikteeri	dikteerima	28_V	IndIpfSg3	et	dikteeris =dikteeri  (IndIpfSg3  >dikteerima !28_V
34375	haritlased	haritlase	haritlane	12_S	PlN	et	haritlased =haritlase  (PlN  >haritlane !12_S
34379	organisatsioonid	organisatsiooni	organisatsioon	22_S	PlN	et	organisatsioonid =organisatsiooni  (PlN  >organisatsioon !22_S
34383	kommunistlik	kommunistlik	kommunistlik	25_A	SgN	et	kommunistlik =kommunistlik  (SgN  >kommunistlik !25_A
34387	kokkuvõteks	võte	kokku+võtt	22_S	PlTr	et	kokkuvõteks =võte  (PlTr  >kokku+võtt !22_S
34390	ainsaks	ainsa	ainus	03~05_AS	SgTr	et	ainsaks =ainsa  (SgTr  >ainus !03~05_AS
34391	riigistati	riigista	riigistama	27_V	IndIpfIps	et	riigistati =riigista  (IndIpfIps  >riigistama !27_V
34392	natsionaliseeriti	natsionaliseeri	natsionaliseerima	28_V	IndIpfIps	et	natsionaliseeriti =natsionaliseeri  (IndIpfIps  >natsionaliseerima !28_V
34395	soomesse	messe	soo+mess	22_S	PlP	et	soomesse =messe  (PlP  >soo+mess !22_S
34397	lahutati	lahuta	lahutama	27_V	IndIpfIps	et	lahutati =lahuta  (IndIpfIps  >lahutama !27_V
34402	isikut	isiku	isik	02_S	SgP	et	isikut =isiku  (SgP  >isik !02_S
34404	pöörduma	pöördu	pöörduma	27_V	Sup	et	pöörduma =pöördu  (Sup  >pöörduma !27_V
34408	erakondadest	erakonda	erakond	22_S	PlEl	et	erakondadest =erakonda  (PlEl  >erakond !22_S
34412	kriisile	kriisi	kriis	22_S	SgAll	et	kriisile =kriisi  (SgAll  >kriis !22_S
34413	vastane	vastane	vastane	10_AS	SgN	et	vastane =vastane  (SgN  >vastane !10_AS
34415	konservatoorium	konservatoorium	konservatoorium	19~02_S	SgN	et	konservatoorium =konservatoorium  (SgN  >konservatoorium !19~02_S
34424	arendati	arenda	arendama	27_V	IndIpfIps	et	arendati =arenda  (IndIpfIps  >arendama !27_V
34430	ideeks	idee	idee	26_S	SgTr	et	ideeks =idee  (SgTr  >idee !26_S
34439	paranes	parane	paranema	27_V	IndIpfSg3	et	paranes =parane  (IndIpfSg3  >paranema !27_V
34445	valitsemisperiood	periood	valitsemis+periood	22_S	SgN	et	valitsemisperiood =periood  (SgN  >valitsemis+periood !22_S
34451	mõningad	mõninga	mõningas	02_P	PlN	et	mõningad =mõninga  (PlN  >mõningas !02_P
34468	veekogudes	kogu	vee+kogu	17_S	PlIn	et	veekogudes =kogu  (PlIn  >vee+kogu !17_S
34470	jahuks	jahu	jahu	17_S	SgTr	et	jahuks =jahu  (SgTr  >jahu !17_S
34471	jahvatada	jahvata	jahvatama	27_V	Inf	et	jahvatada =jahvata  (Inf  >jahvatama !27_V
34472	tekstiilileiud	leiu	tekstiili+leid	22_S	PlN	et	tekstiilileiud =leiu  (PlN  >tekstiili+leid !22_S
34473	haualt	haua	haud	22_S	SgAbl	et	haualt =haua  (SgAbl  >haud !22_S
34494	omaniku	omaniku	omanik	25_S	SgG	et	omaniku =omaniku  (SgG  >omanik !25_S
34499	eluvaldkondades	valdkonda	elu+valdkond	22_S	PlIn	et	eluvaldkondades =valdkonda  (PlIn  >elu+valdkond !22_S
34501	varandused	varanduse	varandus	11_S	PlN	et	varandused =varanduse  (PlN  >varandus !11_S
34510	animistlike	animistlike	animistlik	25_A	PlG	et	animistlike =animistlike  (PlG  >animistlik !25_A
34513	ohustada	ohusta	ohustama	27_V	Inf	et	ohustada =ohusta  (Inf  >ohustama !27_V
34340	tendentse	tendentse	tendents	22_S	PlP	et	tendentse =tendentse  (PlP  >tendents !22_S
34343	kaardistas	kaardista	kaardistama	27_V	IndIpfSg3	et	kaardistas =kaardista  (IndIpfSg3  >kaardistama !27_V
34347	primitiivne	primitiivne	primitiivne	02_A	SgN	et	primitiivne =primitiivne  (SgN  >primitiivne !02_A
34349	riigist	riigi	riik	22_S	SgEl	et	riigist =riigi  (SgEl  >riik !22_S
34353	paljusid	palju	palju	16_P	PlP	et	paljusid =palju  (PlP  >palju !16_P
34378	ühiskondlikud	ühiskondliku	ühiskondlik	25_A	PlN	et	ühiskondlikud =ühiskondliku  (PlN  >ühiskondlik !25_A
34380	kaitseliit	liit	kaitse+liit	22_S	SgN	et	kaitseliit =liit  (SgN  >kaitse+liit !22_S
34381	tuletõrjujate	tõrjuja	tule+tõrjuja	01_S	PlG	et	tuletõrjujate =tõrjuja  (PlG  >tule+tõrjuja !01_S
34382	reguleeris	reguleeri	reguleerima	28_V	IndIpfSg3	et	reguleeris =reguleeri  (IndIpfSg3  >reguleerima !28_V
34401	tööstuse	tööstuse	tööstus	11~09_S	SgG	et	tööstuse =tööstuse  (SgG  >tööstus !11~09_S
34410	depressioon	depressioon	depressioon	22_S	SgN	et	depressioon =depressioon  (SgN  >depressioon !22_S
34419	alaks	ala	ala	17_S	SgTr	et	alaks =ala  (SgTr  >ala !17_S
34428	ensv-ga	ensv	ensv	xx_Q	SgKom	et	ensv-ga =ensv  (SgKom  >ensv !xx_Q
34429	nsvl-s	nsvl	nsvl	xx_Q	SgIn	et	nsvl-s =nsvl  (SgIn  >nsvl !xx_Q
34432	vägivalla	valla	vägi+vald	22_S	SgG	et	vägivalla =valla  (SgG  >vägi+vald !22_S
34436	sellepärastki	sellepärast	selle+pärast	41_D	ID^	et	sellepärastki =sellepärast  (ID^  >selle+pärast !41_D
34447	imperfektiivne	imperfektiivne	imperfektiivne	02_A	SgN	et	imperfektiivne =imperfektiivne  (SgN  >imperfektiivne !02_A
34456	vask	vask	vask	22_S	SgN	et	vask =vask  (SgN  >vask !22_S
34457	lähis-idas	ida	lähis-ida	17_S	SgIn	et	lähis-idas =ida  (SgIn  >lähis-ida !17_S
34465	maaharimisvahend	vahend	maa+hari+mis+vahend	02_S	SgN	et	maaharimisvahend =vahend  (SgN  >maa+hari+mis+vahend !02_S
34467	koristati	korista	koristama	27_V	IndIpfIps	et	koristati =korista  (IndIpfIps  >koristama !27_V
34474	egiptlaste	egiptlas	egiptlane	12?10_S	PlG	et	egiptlaste =egiptlas  (PlG  >egiptlane !12?10_S
34479	kividega	kivi	kivi	17_S	PlKom	et	kividega =kivi  (PlKom  >kivi !17_S
34484	viljaga	vilja	vili	24_S	SgKom	et	viljaga =vilja  (SgKom  >vili !24_S
34486	linnakultuur	kultuur	linna+kultuur	22_S	SgN	et	linnakultuur =kultuur  (SgN  >linna+kultuur !22_S
34487	asjadel	asja	asi	24_S	PlAd	et	asjadel =asja  (PlAd  >asi !24_S
34490	pronksiaja	aja	pronksi+aeg	22_S	SgG	et	pronksiaja =aja  (SgG  >pronksi+aeg !22_S
34498	viljelusmajandusele	majanduse	viljelus+majandus	11_S	SgAll	et	viljelusmajandusele =majanduse  (SgAll  >viljelus+majandus !11_S
34500	odra	odra	oder	24_S	SgG	et	odra =odra  (SgG  >oder !24_S
34506	muinasuskumustega	uskumus	muinas+uskumus	11_S	PlKom	et	muinasuskumustega =uskumus  (PlKom  >muinas+uskumus !11_S
34511	kujutelmadega	kujutelma	kujutelm	22_S	PlKom	et	kujutelmadega =kujutelma  (PlKom  >kujutelm !22_S
34514	ühisfirmade	firma	ühis+firma	16_S	PlG	et	ühisfirmade =firma  (PlG  >ühis+firma !16_S
34519	vaimustas	vaimusta	vaimustama	27_V	IndIpfSg3	et	vaimustas =vaimusta  (IndIpfSg3  >vaimustama !27_V
34520	kultuuritegelane	tegelane	kultuuri+tegelane	12_S	SgN	et	kultuuritegelane =tegelane  (SgN  >kultuuri+tegelane !12_S
34522	estofiilid	estofiili	estofiil	22_S	PlN	et	estofiilid =estofiili  (PlN  >estofiil !22_S
34527	peaülesanneks	anne	pea+üles+and	22_S	PlTr	et	peaülesanneks =anne  (PlTr  >pea+üles+and !22_S
34533	taasavada	ava	taas+avama	27_V	Inf	et	taasavada =ava  (Inf  >taas+avama !27_V
34539	vallakohused	kohuse	valla+kohus	09_S	PlN	et	vallakohused =kohuse  (PlN  >valla+kohus !09_S
34544	leheks	lehe	leht	22_S	SgTr	et	leheks =lehe  (SgTr  >leht !22_S
34561	eestimaat	maat	eesti+maat	22_S	SgN	et	eestimaat =maat  (SgN  >eesti+maat !22_S
34571	relvakonflikte	konflikte	relva+konflikt	22_S	PlP	et	relvakonflikte =konflikte  (PlP  >relva+konflikt !22_S
34579	maahärrad	härra	maa+härra	16_S	PlN	et	maahärrad =härra  (PlN  >maa+härra !16_S
34586	pühakute	pühaku	pühak	02_S	PlG	et	pühakute =pühaku  (PlG  >pühak !02_S
34589	säilitati	säilita	säilitama	27_V	IndIpfIps	et	säilitati =säilita  (IndIpfIps  >säilitama !27_V
34590	uskumused	uskumuse	uskumus	11_S	PlN	et	uskumused =uskumuse  (PlN  >uskumus !11_S
34591	maagiaga	maagia	maagia	01_S	SgKom	et	maagiaga =maagia  (SgKom  >maagia !01_S
34596	küladesse	küla	küla	17_S	PlIll	et	küladesse =küla  (PlIll  >küla !17_S
34599	matta	matt	matma	35_V	Inf	et	matta =matt  (Inf  >matma !35_V
34614	väljak	väljak	väljak	02_S	SgN	et	väljak =väljak  (SgN  >väljak !02_S
34617	kunstnikud	kunstniku	kunstnik	25_S	PlN	et	kunstnikud =kunstniku  (PlN  >kunstnik !25_S
34628	solaarium	solaarium	solaarium	19~02_S	SgN	et	solaarium =solaarium  (SgN  >solaarium !19~02_S
34629	suusa-	suusa	suusk	22_S	SgG	et	suusa- =suusa  (SgG  >suusk !22_S
34640	talule	talu	talu	17_S	SgAll	et	talule =talu  (SgAll  >talu !17_S
34426	metsavendlus	vendlus	metsa+vendlus	11~09_S	SgN	et	metsavendlus =vendlus  (SgN  >metsa+vendlus !11~09_S
34427	taasiseseisvumisega	seisvumise	taas+ise+seisvumine	12_S	SgKom	et	taasiseseisvumisega =seisvumise  (SgKom  >taas+ise+seisvumine !12_S
34433	ümberkorraldused	korralduse	ümber+korraldus	11_S	PlN	et	ümberkorraldused =korralduse  (PlN  >ümber+korraldus !11_S
34435	võimukandjad	kandja	võimu+kandja	01_S	PlN	et	võimukandjad =kandja  (PlN  >võimu+kandja !01_S
34438	valitsemisperioodil	perioodi	valitsemis+periood	22_S	SgAd	et	valitsemisperioodil =perioodi  (SgAd  >valitsemis+periood !22_S
34440	reformidele	reformi	reform	22_S	PlAll	et	reformidele =reformi  (PlAll  >reform !22_S
34450	sõnastiku	sõnastiku	sõnastik	25_S	SgG	et	sõnastiku =sõnastiku  (SgG  >sõnastik !25_S
34459	skandinaaviast	ast	skandinaavi+ast	22_S	SgN	et	skandinaaviast =ast  (SgN  >skandinaavi+ast !22_S
34460	pronksesemed	eseme	pronks+ese	04_S	PlN	et	pronksesemed =eseme  (PlN  >pronks+ese !04_S
34469	osati	osa	oskama	29_V	IndIpfIps	et	osati =osa  (IndIpfIps  >oskama !29_V
34476	tegemiskombed	kombe	tegemis+komme	06_S	PlN	et	tegemiskombed =kombe  (PlN  >tegemis+komme !06_S
34481	lõuna-eestis	eesti	lõuna-eesti	16_H	SgIn	et	lõuna-eestis =eesti  (SgIn  >lõuna-eesti !16_H
34491	pronksesemeid	eseme	pronks+ese	04_S	PlP	et	pronksesemeid =eseme  (PlP  >pronks+ese !04_S
34492	odaotsad	otsa	oda+ots	23?22_S	PlN	et	odaotsad =otsa  (PlN  >oda+ots !23?22_S
34493	materjal	materjal	materjal	19_S	SgN	et	materjal =materjal  (SgN  >materjal !19_S
34495	koduloomapidamine	pidamine	kodu+looma+pidamine	12_S	SgN	et	koduloomapidamine =pidamine  (SgN  >kodu+looma+pidamine !12_S
34497	veoloomadena	looma	veo+loom	22_S	PlEs	et	veoloomadena =looma  (PlEs  >veo+loom !22_S
34503	matmiskombed	kombe	matmis+komme	06_S	PlN	et	matmiskombed =kombe  (PlN  >matmis+komme !06_S
34504	kiviring	ring	kivi+ring	22_S	SgN	et	kiviring =ring  (SgN  >kivi+ring !22_S
34505	keskele	keskele	keskele	41_DK	ID	et	keskele =keskele  (ID  >keskele !41_DK
34509	põtru	põtru	põder	24_S	PlP	et	põtru =põtru  (PlP  >põder !24_S
34516	süsteemile	süsteemi	süsteem	22_S	SgAll	et	süsteemile =süsteemi  (SgAll  >süsteem !22_S
34521	rahatähe	tähe	raha+täht	22_S	SgG	et	rahatähe =tähe  (SgG  >raha+täht !22_S
34529	mängiti	mängi	mängima	28_V	IndIpfIps	et	mängiti =mängi  (IndIpfIps  >mängima !28_V
34541	perekonnanimesid	nime	pere+konna+nimi	20_S	PlP	et	perekonnanimesid =nime  (PlP  >pere+konna+nimi !20_S
34542	rentima	renti	rentima	28_V	Sup	et	rentima =renti  (Sup  >rentima !28_V
34543	rent	rent	rent	22_S	SgN	et	rent =rent  (SgN  >rent !22_S
34546	kontaktidest	kontakti	kontakt	22_S	PlEl	et	kontaktidest =kontakti  (PlEl  >kontakt !22_S
34548	palvekirjade	kirja	palve+kiri	24_S	PlG	et	palvekirjade =kirja  (PlG  >palve+kiri !24_S
34551	salakoosolekul	oleku	sala+koos+olek	02_S	SgAd	et	salakoosolekul =oleku  (SgAd  >sala+koos+olek !02_S
34556	kuulsa	kuulsa	kuulus	02_A	SgG	et	kuulsa =kuulsa  (SgG  >kuulus !02_A
34559	rahvaluulet	luule	rahva+luule	06_S	SgP	et	rahvaluulet =luule  (SgP  >rahva+luule !06_S
34560	liivimaat	maat	liivi+maat	22_S	SgN	et	liivimaat =maat  (SgN  >liivi+maat !22_S
34563	linnadeks	linna	linn	22_S	PlTr	et	linnadeks =linna  (PlTr  >linn !22_S
34565	linnadega	linna	linn	22_S	PlKom	et	linnadega =linna  (PlKom  >linn !22_S
34570	linlased	linlase	linlane	12?10_S	PlN	et	linlased =linlase  (PlN  >linlane !12?10_S
34575	esemete	eseme	ese	04_S	PlG	et	esemete =eseme  (PlG  >ese !04_S
34576	viikingiaja	aja	viikingi+aeg	22_S	SgG	et	viikingiaja =aja  (SgG  >viikingi+aeg !22_S
34578	kloostrid	kloostri	klooster	02_S	PlN	et	kloostrid =kloostri  (PlN  >klooster !02_S
34584	talupoegadest	poega	talu+poeg	22_S	PlEl	et	talupoegadest =poega  (PlEl  >talu+poeg !22_S
34601	rändmunkadena	munka	ränd+munk	22_S	PlEs	et	rändmunkadena =munka  (PlEs  >ränd+munk !22_S
34610	majad	maja	maja	17_S	PlN	et	majad =maja  (PlN  >maja !17_S
34611	õhutemperatuur	temperatuur	õhu+temperatuur	22_S	SgN	et	õhutemperatuur =temperatuur  (SgN  >õhu+temperatuur !22_S
34612	magusad	magusa	magus	02_A	PlN	et	magusad =magusa  (PlN  >magus !02_A
34618	oru	oru	org	22_S	SgG	et	oru =oru  (SgG  >org !22_S
34621	tõstukitega	tõstuki	tõstuk	02_S	PlKom	et	tõstukitega =tõstuki  (PlKom  >tõstuk !02_S
34623	novembrist	novembri	november	02_S	SgEl	et	novembrist =novembri  (SgEl  >november !02_S
34633	energiavarusid	varu	energia+varu	17_S	PlP	et	energiavarusid =varu  (PlP  >energia+varu !17_S
34635	kalastada	kalasta	kalastama	27_V	Inf	et	kalastada =kalasta  (Inf  >kalastama !27_V
34638	turismitalus	talu	turismi+talu	17_S	SgIn	et	turismitalus =talu  (SgIn  >turismi+talu !17_S
34643	hobusetalus	talu	hobuse+talu	17_S	SgIn	et	hobusetalus =talu  (SgIn  >hobuse+talu !17_S
34650	lõikeplats	plats	lõike+plats	22_S	SgN	et	lõikeplats =plats  (SgN  >lõike+plats !22_S
34659	ojad	oja	oja	17_S	PlN	et	ojad =oja  (PlN  >oja !17_S
34437	kõrgintelligentsiga	intelligentsi	kõrg+intelligents	22_S	SgKom	et	kõrgintelligentsiga =intelligentsi  (SgKom  >kõrg+intelligents !22_S
34442	elamisrajoone	rajoone	elamis+rajoon	22_S	PlP	et	elamisrajoone =rajoone  (PlP  >elamis+rajoon !22_S
34443	endises	endise	endine	10~12_A	SgIn	et	endises =endise  (SgIn  >endine !10~12_A
34444	sulale	sula	sula	17_AS	SgAll	et	sulale =sula  (SgAll  >sula !17_AS
34446	stagnatsioon	stagnatsioon	stagnatsioon	22_S	SgN	et	stagnatsioon =stagnatsioon  (SgN  >stagnatsioon !22_S
34452	hädas	häda	häda	17_S	SgIn	et	hädas =häda  (SgIn  >häda !17_S
34458	valgast	ast	valg+ast	22_S	SgN	et	valgast =ast  (SgN  >valg+ast !22_S
34462	töötlema	töötle	töötlema	30_V	Sup	et	töötlema =töötle  (Sup  >töötlema !30_V
34463	veiseid	veise	veis	09_S	PlP	et	veiseid =veise  (PlP  >veis !09_S
34464	sigu	sigu	siga	18_SA	PlP	et	sigu =sigu  (PlP  >siga !18_SA
34475	kalmete	kalme	kalme	06_S	PlG	et	kalmete =kalme  (PlG  >kalme !06_S
34478	kivikalmed	kalme	kivi+kalme	06_S	PlN	et	kivikalmed =kalme  (PlN  >kivi+kalme !06_S
34483	vikat	vikat	vikat	02_S	SgN	et	vikat =vikat  (SgN  >vikat !02_S
34485	kaubandus	kaubandus	kaubandus	11_S	SgN	et	kaubandus =kaubandus  (SgN  >kaubandus !11_S
34488	majadel	maja	maja	17_S	PlAd	et	majadel =maja  (PlAd  >maja !17_S
34508	karusid	karu	karu	17_S	PlP	et	karusid =karu  (PlP  >karu !17_S
34524	tantsuselts	selts	tantsu+selts	22_S	SgN	et	tantsuselts =selts  (SgN  >tantsu+selts !22_S
34528	silmapaistvaid	paistva	silma+paistev	02_A	PlP	et	silmapaistvaid =paistva  (PlP  >silma+paistev !02_A
34532	tsaarile	tsaari	tsaar	22_S	SgAll	et	tsaarile =tsaari  (SgAll  >tsaar !22_S
34538	raetakse	takse	rae+taks	22_S	PlP	et	raetakse =takse  (PlP  >rae+taks !22_S
34547	isamaaga	maa	isa+maa	26_S	SgKom	et	isamaaga =maa  (SgKom  >isa+maa !26_S
34550	keisrile	keisri	keiser	02_S	SgAll	et	keisrile =keisri  (SgAll  >keiser !02_S
34554	tahet	tahe	tahe	06_S	SgP	et	tahet =tahe  (SgP  >tahe !06_S
34555	mänguselts	selts	mängu+selts	22_S	SgN	et	mänguselts =selts  (SgN  >mängu+selts !22_S
34562	territooriumitest	territooriumi	territoorium	02_S	PlEl	et	territooriumitest =territooriumi  (PlEl  >territoorium !02_S
34581	mitmenaisepidamine	pidamine	mitme+naise+pidamine	12_S	SgN	et	mitmenaisepidamine =pidamine  (SgN  >mitme+naise+pidamine !12_S
34582	põllumajandusse	majandus	põllu+majandus	11_S	SgAdt	et	põllumajandusse =majandus  (SgAdt  >põllu+majandus !11_S
34587	säilmete	säilme	säile	05_S	PlG	et	säilmete =säilme  (PlG  >säile !05_S
34592	naisetõmbamine	tõmbamine	naise+tõmbamine	12_S	SgN	et	naisetõmbamine =tõmbamine  (SgN  >naise+tõmbamine !12_S
34593	ajapikku	ajapikku	aja+pikku	41_D	ID	et	ajapikku =ajapikku  (ID  >aja+pikku !41_D
34595	jutlused	jutluse	jutlus	11~09_S	PlN	et	jutlused =jutluse  (PlN  >jutlus !11~09_S
34609	hansapäevad	päeva	hansa+päev	22_S	PlN	et	hansapäevad =päeva  (PlN  >hansa+päev !22_S
34613	kliimal	kliima	kliima	16_S	SgAd	et	kliimal =kliima  (SgAd  >kliima !16_S
34615	toitsin	toit	toitma	34_V	IndIpfSg1	et	toitsin =toit  (IndIpfSg1  >toitma !34_V
34627	spordikeskus	keskus	spordi+keskus	11~09_S	SgN	et	spordikeskus =keskus  (SgN  >spordi+keskus !11~09_S
34636	hobusetalud	talu	hobuse+talu	17_S	PlN	et	hobusetalud =talu  (PlN  >hobuse+talu !17_S
34641	lehtmets	mets	leht+mets	22_S	SgN	et	lehtmets =mets  (SgN  >leht+mets !22_S
34651	grillkoht	koht	grill+koht	22_S	SgN	et	grillkoht =koht  (SgN  >grill+koht !22_S
34652	paadid	paadi	paat	22_S	PlN	et	paadid =paadi  (PlN  >paat !22_S
34654	lõkkeplatsil	platsi	lõkke+plats	22_S	SgAd	et	lõkkeplatsil =platsi  (SgAd  >lõkke+plats !22_S
34656	keskaegne	aegne	kesk+aegne	02_A	SgN	et	keskaegne =aegne  (SgN  >kesk+aegne !02_A
34663	imepuhas	puhas	ime+puhas	07_A	SgN	et	imepuhas =puhas  (SgN  >ime+puhas !07_A
34678	viibides	viibi	viibima	27_V	Ger	et	viibides =viibi  (Ger  >viibima !27_V
34679	kantonis	kantoni	kanton	02_S	SgIn	et	kantonis =kantoni  (SgIn  >kanton !02_S
34703	sante	sante	sant	22_SA	PlP	et	sante =sante  (PlP  >sant !22_SA
34707	platsis	platsi	plats	22_S	SgIn	et	platsis =platsi  (SgIn  >plats !22_S
34724	ukrainlased	ukrainlase	ukrainlane	12?10_S	PlN	et	ukrainlased =ukrainlase  (PlN  >ukrainlane !12?10_S
34727	ameeriklastega	ameeriklas	ameeriklane	12_S	PlKom	et	ameeriklastega =ameeriklas  (PlKom  >ameeriklane !12_S
34738	perekompleks	kompleks	pere+kompleks	22_S	SgN	et	perekompleks =kompleks  (SgN  >pere+kompleks !22_S
34748	maastik	maastik	maastik	25_S	SgN	et	maastik =maastik  (SgN  >maastik !25_S
34750	virumaalt	maa	viru+maa	26_S	SgAbl	et	virumaalt =maa  (SgAbl  >viru+maa !26_S
34754	putukad	putuka	putukas	02_S	PlN	et	putukad =putuka  (PlN  >putukas !02_S
34761	meenub	meenu	meenuma	27_V	IndPrSg3	et	meenub =meenu  (IndPrSg3  >meenuma !27_V
34763	rahvakultuur	kultuur	rahva+kultuur	22_S	SgN	et	rahvakultuur =kultuur  (SgN  >rahva+kultuur !22_S
34515	isemajandamisele	majandamise	ise+majandamine	12_S	SgAll	et	isemajandamisele =majandamise  (SgAll  >ise+majandamine !12_S
34526	näidendid	näidendi	näidend	02_S	PlN	et	näidendid =näidendi  (PlN  >näidend !02_S
34530	kaastegijad	tegija	kaas+tegija	01_S	PlN	et	kaastegijad =tegija  (PlN  >kaas+tegija !01_S
34531	seisundi	seisundi	seisund	02_S	SgG	et	seisundi =seisundi  (SgG  >seisund !02_S
34534	määrus	määrus	määrus	11~09_S	SgN	et	määrus =määrus  (SgN  >määrus !11~09_S
34537	majapidamine	pidamine	maja+pidamine	12_S	SgN	et	majapidamine =pidamine  (SgN  >maja+pidamine !12_S
34540	kaebustega	kaebus	kaebus	11~09_S	PlKom	et	kaebustega =kaebus  (PlKom  >kaebus !11~09_S
34545	patriootide	patriooti	patrioot	22_S	PlG	et	patriootide =patriooti  (PlG  >patrioot !22_S
34552	liikus	liiku	liikuma	28_V	IndIpfSg3	et	liikus =liiku  (IndIpfSg3  >liikuma !28_V
34558	võitles	võitle	võitlema	30_V	IndIpfSg3	et	võitles =võitle  (IndIpfSg3  >võitlema !30_V
34566	kaubanduslinnade	linna	kaubandus+linn	22_S	PlG	et	kaubanduslinnade =linna  (PlG  >kaubandus+linn !22_S
34567	kaubanduskeskus	keskus	kaubandus+keskus	11~09_S	SgN	et	kaubanduskeskus =keskus  (SgN  >kaubandus+keskus !11~09_S
34568	kunagine	kunagine	kunagine	12_A	SgN	et	kunagine =kunagine  (SgN  >kunagine !12_A
34577	kehtestas	kehtesta	kehtestama	27_V	IndIpfSg3	et	kehtestas =kehtesta  (IndIpfSg3  >kehtestama !27_V
34580	abielud	elu	abi+elu	17_S	PlN	et	abielud =elu  (PlN  >abi+elu !17_S
34585	kogukondlased	kogukondlase	kogukondlane	12?10_S	PlN	et	kogukondlased =kogukondlase  (PlN  >kogukondlane !12?10_S
34594	jutlustel	jutlus	jutlus	11~09_S	PlAd	et	jutlustel =jutlus  (PlAd  >jutlus !11~09_S
34600	tõlkidena	tõlki	tõlk	22_S	PlEs	et	tõlkidena =tõlki  (PlEs  >tõlk !22_S
34603	suurkaupmeheks	mehe	suur+kaup+mees	13_S	SgTr	et	suurkaupmeheks =mehe  (SgTr  >suur+kaup+mees !13_S
34605	suudeti	suude	suutma	34_V	IndIpfIps	et	suudeti =suude  (IndIpfIps  >suutma !34_V
34607	jõekaubandus	kaubandus	jõe+kaubandus	11_S	SgN	et	jõekaubandus =kaubandus  (SgN  >jõe+kaubandus !11_S
34608	tuludest	tulu	tulu	17_S	PlEl	et	tuludest =tulu  (PlEl  >tulu !17_S
34619	tipus	tipu	tipp	22_S	SgIn	et	tipus =tipu  (SgIn  >tipp !22_S
34622	suusapiirkond	piirkond	suusa+piirkond	22_S	SgN	et	suusapiirkond =piirkond  (SgN  >suusa+piirkond !22_S
34624	ööeluga	elu	öö+elu	17_S	SgKom	et	ööeluga =elu  (SgKom  >öö+elu !17_S
34625	baare	baare	baar	22_S	PlP	et	baare =baare  (PlP  >baar !22_S
34631	fännid	fänni	fänn	22_S	PlN	et	fännid =fänni  (PlN  >fänn !22_S
34634	taluturism	turism	talu+turism	22_S	SgN	et	taluturism =turism  (SgN  >talu+turism !22_S
34647	puitmajas	maja	puit+maja	17_S	SgIn	et	puitmajas =maja  (SgIn  >puit+maja !17_S
34657	horisondini	horisondi	horisont	22_S	SgTer	et	horisondini =horisondi  (SgTer  >horisont !22_S
34658	künkad	künka	küngas	07_S	PlN	et	künkad =künka  (PlN  >küngas !07_S
34661	mustvee	vee	must+vesi	15_S	SgG	et	mustvee =vee  (SgG  >must+vesi !15_S
34666	lõkkel	lõkke	lõke	06_S	SgAd	et	lõkkel =lõkke  (SgAd  >lõke !06_S
34667	puhtas	puhta	puhas	07_A	SgIn	et	puhtas =puhta  (SgIn  >puhas !07_A
34668	puhtal	puhta	puhas	07_A	SgAd	et	puhtal =puhta  (SgAd  >puhas !07_A
34669	puhkusekoht	koht	puhkuse+koht	22_S	SgN	et	puhkusekoht =koht  (SgN  >puhkuse+koht !22_S
34682	ekskursioonid	ekskursiooni	ekskursioon	22_S	PlN	et	ekskursioonid =ekskursiooni  (PlN  >ekskursioon !22_S
34683	temperatuur	temperatuur	temperatuur	22_S	SgN	et	temperatuur =temperatuur  (SgN  >temperatuur !22_S
34684	vanalinn	linn	vana+linn	22_S	SgN	et	vanalinn =linn  (SgN  >vana+linn !22_S
34687	telgis	telgi	telk	22_S	SgIn	et	telgis =telgi  (SgIn  >telk !22_S
34692	kaunitel	kauni	kaunis	05_A	PlAd	et	kaunitel =kauni  (PlAd  >kaunis !05_A
34697	torm	torm	torm	22_SA	SgN	et	torm =torm  (SgN  >torm !22_SA
34698	praam	praam	praam	22_S	SgN	et	praam =praam  (SgN  >praam !22_S
34699	kõikus	kõiku	kõikuma	28_V	IndIpfSg3	et	kõikus =kõiku  (IndIpfSg3  >kõikuma !28_V
34700	taldrikud	taldriku	taldrik	02_S	PlN	et	taldrikud =taldriku  (PlN  >taldrik !02_S
34702	ööbisime	ööbi	ööbima	27_V	IndIpfPl1	et	ööbisime =ööbi  (IndIpfPl1  >ööbima !27_V
34704	imetlusväärne	väärne	imetlus+väärne	02_A	SgN	et	imetlusväärne =väärne  (SgN  >imetlus+väärne !02_A
34711	gondeliga	gondeli	gondel	02_S	SgKom	et	gondeliga =gondeli  (SgKom  >gondel !02_S
34712	vabriku	vabriku	vabrik	02_S	SgG	et	vabriku =vabriku  (SgG  >vabrik !02_S
34721	minetage	mineta	minetama	27_V	ImpPrPl2	et	minetage =mineta  (ImpPrPl2  >minetama !27_V
34730	loomapuur	puur	looma+puur	22_S	SgN	et	loomapuur =puur  (SgN  >looma+puur !22_S
34734	viisidest	viisi	viis	22_S	PlEl	et	viisidest =viisi  (PlEl  >viis !22_S
34744	jäätise-	jäätise	jäätis	11~09_S	SgG	et	jäätise- =jäätise  (SgG  >jäätis !11~09_S
34746	suveniirid	suveniiri	suveniir	22_S	PlN	et	suveniirid =suveniiri  (PlN  >suveniir !22_S
34553	rahvaliikumise	liikumise	rahva+liikumine	12_S	SgG	et	rahvaliikumise =liikumise  (SgG  >rahva+liikumine !12_S
34557	tegelasi	tegelasi	tegelane	12_S	PlP	et	tegelasi =tegelasi  (PlP  >tegelane !12_S
34564	keskaja	aja	kesk+aeg	22_S	SgG	et	keskaja =aja  (SgG  >kesk+aeg !22_S
34569	l-e	l	l	xx_Q	PlP	et	l-e =l  (PlP  >l !xx_Q
34572	nõuti	nõu	nõudma	34_V	IndIpfIps	et	nõuti =nõu  (IndIpfIps  >nõudma !34_V
34573	misjonär	misjonär	misjonär	19_S	SgN	et	misjonär =misjonär  (SgN  >misjonär !19_S
34574	levitas	levita	levitama	27_V	IndIpfSg3	et	levitas =levita  (IndIpfSg3  >levitama !27_V
34583	käsitöövõtteid	võtte	käsi+töö+võte	06_S	PlP	et	käsitöövõtteid =võtte  (PlP  >käsi+töö+võte !06_S
34588	usund	usund	usund	02_S	SgN	et	usund =usund  (SgN  >usund !02_S
34597	piiblit	piibli	piibel	02_S	SgP	et	piiblit =piibli  (SgP  >piibel !02_S
34598	palvet	palve	palve	06_S	SgP	et	palvet =palve  (SgP  >palve !06_S
34602	notarina	notari	notar	02_S	SgEs	et	notarina =notari  (SgEs  >notar !02_S
34604	konkurents	konkurents	konkurents	22_S	SgN	et	konkurents =konkurents  (SgN  >konkurents !22_S
34606	vaos	vao	vagu	18_S	SgIn	et	vaos =vao  (SgIn  >vagu !18_S
34616	tuvisid	tuvi	tuvi	17_S	PlP	et	tuvisid =tuvi  (PlP  >tuvi !17_S
34620	suusakuurort	kuurort	suusa+kuurort	22_S	SgN	et	suusakuurort =kuurort  (SgN  >suusa+kuurort !22_S
34626	baaride	baari	baar	22_S	PlG	et	baaride =baari  (PlG  >baar !22_S
34630	lumelaua	laua	lume+laud	22_S	SgG	et	lumelaua =laua  (SgG  >lume+laud !22_S
34632	lõõgastuda	lõõgastu	lõõgastuma	27_V	Inf	et	lõõgastuda =lõõgastu  (Inf  >lõõgastuma !27_V
34637	ratsutada	ratsuta	ratsutama	27_V	Inf	et	ratsutada =ratsuta  (Inf  >ratsutama !27_V
34639	külje	külje	külg	22_S	SgG	et	külje =külje  (SgG  >külg !22_S
34642	ujumis	ujumi	ujum	02_S	SgIn	et	ujumis =ujumi  (SgIn  >ujum !02_S
34644	kõikvõimalikke	võimalikke	kõik+võimalik	25_A	PlP	et	kõikvõimalikke =võimalikke  (PlP  >kõik+võimalik !25_A
34645	teenuseid	teenuse	teenus	09_S	PlP	et	teenuseid =teenuse  (PlP  >teenus !09_S
34648	teleri-	teleri	teler	02_S	SgG	et	teleri- =teleri  (SgG  >teler !02_S
34655	infovaegus	vaegus	info+vaegus	11~09_S	SgN	et	infovaegus =vaegus  (SgN  >info+vaegus !11~09_S
34660	veespordi	spordi	vee+sport	22_S	SgG	et	veespordi =spordi  (SgG  >vee+sport !22_S
34673	kauget	kauge	kauge	01_A	SgP	et	kauget =kauge  (SgP  >kauge !01_A
34675	vahejuhtumitega	juhtumi	vahe+juhtum	02_S	PlKom	et	vahejuhtumitega =juhtumi  (PlKom  >vahe+juhtum !02_S
34677	kulgeb	kulge	kulgema	27_V	IndPrSg3	et	kulgeb =kulge  (IndPrSg3  >kulgema !27_V
34681	vedada	veda	vedama	28_V	Inf	et	vedada =veda  (Inf  >vedama !28_V
34688	kaamelis	kaameli	kaamel	02_S	SgIn	et	kaamelis =kaameli  (SgIn  >kaamel !02_S
34689	puutusime	puutu	puutuma	27_V	IndIpfPl1	et	puutusime =puutu  (IndIpfPl1  >puutuma !27_V
34690	soolajärv	järv	soola+järv	22_S	SgN	et	soolajärv =järv  (SgN  >soola+järv !22_S
34693	liivarandadel	randa	liiva+rand	22_S	PlAd	et	liivarandadel =randa  (PlAd  >liiva+rand !22_S
34695	kuldpruun	pruun	kuld+pruun	22_AS	SgN	et	kuldpruun =pruun  (SgN  >kuld+pruun !22_AS
34696	müstiline	müstiline	müstiline	12_A	SgN	et	müstiline =müstiline  (SgN  >müstiline !12_A
34710	paadiga	paadi	paat	22_S	SgKom	et	paadiga =paadi  (SgKom  >paat !22_S
34722	laadal	laada	laat	22_S	SgAd	et	laadal =laada  (SgAd  >laat !22_S
34723	linnadest	linna	linn	22_S	PlEl	et	linnadest =linna  (PlEl  >linn !22_S
34725	miss	miss	miss	22_S	SgN	et	miss =miss  (SgN  >miss !22_S
34726	meenutasin	meenuta	meenutama	27_V	IndIpfSg1	et	meenutasin =meenuta  (IndIpfSg1  >meenutama !27_V
34729	loomaaed	aed	looma+aed	22_S	SgN	et	loomaaed =aed  (SgN  >looma+aed !22_S
34731	betoonist	betooni	betoon	22_S	SgEl	et	betoonist =betooni  (SgEl  >betoon !22_S
34732	tingimuses	tingimuse	tingimus	11_S	SgIn	et	tingimuses =tingimuse  (SgIn  >tingimus !11_S
34733	ajaveetmise	veetmise	aja+veetmine	12?10_S	SgG	et	ajaveetmise =veetmise  (SgG  >aja+veetmine !12?10_S
34736	matkamas	matka	matkama	29_V	SupIn	et	matkamas =matka  (SupIn  >matkama !29_V
34737	vaatamisväärtusi	väärtusi	vaatamis+väärtus	11_S	PlP	et	vaatamisväärtusi =väärtusi  (PlP  >vaatamis+väärtus !11_S
34742	raekojaplats	plats	rae+koja+plats	22_S	SgN	et	raekojaplats =plats  (SgN  >rae+koja+plats !22_S
34743	platsid	platsi	plats	22_S	PlN	et	platsid =platsi  (PlN  >plats !22_S
34749	kohtadele	kohta	koht	22_S	PlAll	et	kohtadele =kohta  (PlAll  >koht !22_S
34755	raidi	raidi	rait	22_S	SgG	et	raidi =raidi  (SgG  >rait !22_S
34757	tapma	tap	tapma	35_V	Sup	et	tapma =tap  (Sup  >tapma !35_V
34765	kaotab	kaota	kaotama	27_V	IndPrSg3	et	kaotab =kaota  (IndPrSg3  >kaotama !27_V
34767	ühingus	ühingu	ühing	02_S	SgIn	et	ühingus =ühingu  (SgIn  >ühing !02_S
34646	ratsamatkale	matka	ratsa+matk	22_S	SgAll	et	ratsamatkale =matka  (SgAll  >ratsa+matk !22_S
34649	voodiga	voodi	voodi	01_S	SgKom	et	voodiga =voodi  (SgKom  >voodi !01_S
34653	kalapüügivahendid	vahendi	kala+püügi+vahend	02_S	PlN	et	kalapüügivahendid =vahendi  (PlN  >kala+püügi+vahend !02_S
34662	jumalik	jumalik	jumalik	25_A	SgN	et	jumalik =jumalik  (SgN  >jumalik !25_A
34664	võõraid	võõra	võõras	07_AS	PlP	et	võõraid =võõra  (PlP  >võõras !07_AS
34671	suurtesse	suur	suur	13_A	PlIll	et	suurtesse =suur  (PlIll  >suur !13_A
34680	kantoni	kantoni	kanton	02_S	SgG	et	kantoni =kantoni  (SgG  >kanton !02_S
34685	pühapäevadeni	päeva	püha+päev	22_S	PlTer	et	pühapäevadeni =päeva  (PlTer  >püha+päev !22_S
34691	olgu	ol	olema	36_V	ImpPrPs	et	olgu =ol  (ImpPrPs  >olema !36_V
34701	hotellides	hotelli	hotell	22_S	PlIn	et	hotellides =hotelli  (PlIn  >hotell !22_S
34709	katedraalis	katedraali	katedraal	22_S	SgIn	et	katedraalis =katedraali  (SgIn  >katedraal !22_S
34714	reisime	reisi	reisima	28_V	IndPrPl1	et	reisime =reisi  (IndPrPl1  >reisima !28_V
34716	koolivaheajal	aja	kooli+vahe+aeg	22_S	SgAd	et	koolivaheajal =aja  (SgAd  >kooli+vahe+aeg !22_S
34718	tornis	torni	torn	22_S	SgIn	et	tornis =torni  (SgIn  >torn !22_S
34719	tantsisime	tantsi	tantsima	28_V	IndIpfPl1	et	tantsisime =tantsi  (IndIpfPl1  >tantsima !28_V
34728	sakslastega	sakslas	sakslane	12?10_S	PlKom	et	sakslastega =sakslas  (PlKom  >sakslane !12?10_S
34739	atraktsioone	atraktsioone	atraktsioon	22_S	PlP	et	atraktsioone =atraktsioone  (PlP  >atraktsioon !22_S
34747	kleebitakse	kleebi	kleepima	28_V	IndPrIps	et	kleebitakse =kleebi  (IndPrIps  >kleepima !28_V
34751	merele	mere	meri	20_S	SgAll	et	merele =mere  (SgAll  >meri !20_S
34758	verb	verb	verb	22_S	SgN	et	verb =verb  (SgN  >verb !22_S
34759	tuleme	tule	tulema	36_V	IndPrPl1	et	tuleme =tule  (IndPrPl1  >tulema !36_V
34764	rahvalooming	looming	rahva+looming	02_S	SgN	et	rahvalooming =looming  (SgN  >rahva+looming !02_S
34769	tubakat	tubaka	tubakas	02_S	SgP	et	tubakat =tubaka  (SgP  >tubakas !02_S
34775	istungeid	istunge	istung	02_S	PlP	et	istungeid =istunge  (PlP  >istung !02_S
34789	sakslaste	sakslas	sakslane	12?10_S	PlG	et	sakslaste =sakslas  (PlG  >sakslane !12?10_S
34794	kroonikakirjanik	kirjanik	kroonika+kirjanik	25_S	SgN	et	kroonikakirjanik =kirjanik  (SgN  >kroonika+kirjanik !25_S
34799	julmaks	julma	julm	22_A	SgTr	et	julmaks =julma  (SgTr  >julm !22_A
34800	naelutas	naeluta	naelutama	27_V	IndIpfSg3	et	naelutas =naeluta  (IndIpfSg3  >naelutama !27_V
34803	usundit	usundi	usund	02_S	SgP	et	usundit =usundi  (SgP  >usund !02_S
34804	katoliiklikud	katoliikliku	katoliiklik	25_A	PlN	et	katoliiklikud =katoliikliku  (PlN  >katoliiklik !25_A
34807	kihelkonnas	kihelkonna	kihelkond	22_S	SgIn	et	kihelkonnas =kihelkonna  (SgIn  >kihelkond !22_S
34814	rukist	rukis	rukis	07_S	SgP	et	rukist =rukis  (SgP  >rukis !07_S
34817	hajakülad	küla	haja+küla	17_S	PlN	et	hajakülad =küla  (PlN  >haja+küla !17_S
34831	sõnastada	sõnasta	sõnastama	27_V	Inf	et	sõnastada =sõnasta  (Inf  >sõnastama !27_V
34835	võrus	võru	võru	17_S	SgIn	et	võrus =võru  (SgIn  >võru !17_S
34838	aktsioon	aktsioon	aktsioon	22_S	SgN	et	aktsioon =aktsioon  (SgN  >aktsioon !22_S
34841	teravate	terava	terav	02_A	PlG	et	teravate =terava  (PlG  >terav !02_A
34842	kirjutistega	kirjutis	kirjutis	11_S	PlKom	et	kirjutistega =kirjutis  (PlKom  >kirjutis !11_S
34843	ronisime	roni	ronima	27_V	IndIpfPl1	et	ronisime =roni  (IndIpfPl1  >ronima !27_V
34849	leiva	leiva	leib	22_S	SgG	et	leiva =leiva  (SgG  >leib !22_S
34851	sügist	sügis	sügis	09_S	SgP	et	sügist =sügis  (SgP  >sügis !09_S
34855	kefiiriga	kefiiri	kefiir	22_S	SgKom	et	kefiiriga =kefiiri  (SgKom  >kefiir !22_S
34856	kodulinn	linn	kodu+linn	22_S	SgN	et	kodulinn =linn  (SgN  >kodu+linn !22_S
34857	terviseks	tervise	tervis	09~11_S	SgTr	et	terviseks =tervise  (SgTr  >tervis !09~11_S
34860	linnamüür	müür	linna+müür	22_S	SgN	et	linnamüür =müür  (SgN  >linna+müür !22_S
34870	hubane	hubane	hubane	10_A	SgN	et	hubane =hubane  (SgN  >hubane !10_A
34873	pühapäevaks	päeva	püha+päev	22_S	SgTr	et	pühapäevaks =päeva  (SgTr  >püha+päev !22_S
34874	piimaga	piima	piim	22_S	SgKom	et	piimaga =piima  (SgKom  >piim !22_S
34890	pidupäeval	päeva	pidu+päev	22_S	SgAd	et	pidupäeval =päeva  (SgAd  >pidu+päev !22_S
34893	ajalooperioodil	perioodi	aja+loo+periood	22_S	SgAd	et	ajalooperioodil =perioodi  (SgAd  >aja+loo+periood !22_S
34904	värvingud	värvingu	värving	02_S	PlN	et	värvingud =värvingu  (PlN  >värving !02_S
34914	telekanalitel	kanali	tele+kanal	02_S	PlAd	et	telekanalitel =kanali  (PlAd  >tele+kanal !02_S
34915	ilvest	ilves	ilves	09_S	SgP	et	ilvest =ilves  (SgP  >ilves !09_S
34924	peodele	peo	peo	26_S	PlAll	et	peodele =peo  (PlAll  >peo !26_S
34665	telk	telk	telk	22_S	SgN	et	telk =telk  (SgN  >telk !22_S
34670	soojadele	sooja	soe	24_AS	PlAll	et	soojadele =sooja  (PlAll  >soe !24_AS
34672	sõidaks	sõida	sõitma	34_V	KndPrPs	et	sõidaks =sõida  (KndPrPs  >sõitma !34_V
34674	mõningate	mõninga	mõningas	02_P	PlG	et	mõningate =mõninga  (PlG  >mõningas !02_P
34676	eksootiline	eksootiline	eksootiline	12_A	SgN	et	eksootiline =eksootiline  (SgN  >eksootiline !12_A
34686	laat	laat	laat	22_S	SgN	et	laat =laat  (SgN  >laat !22_S
34694	lesides	lesi	lesima	27_V	Ger	et	lesides =lesi  (Ger  >lesima !27_V
34705	monumente	monumente	monument	22_S	PlP	et	monumente =monumente  (PlP  >monument !22_S
34706	fontään	fontään	fontään	22_S	SgN	et	fontään =fontään  (SgN  >fontään !22_S
34708	koliseisis	seisi	koli+seis	22_S	SgIn	et	koliseisis =seisi  (SgIn  >koli+seis !22_S
34713	suveniire	suveniire	suveniir	22_S	PlP	et	suveniire =suveniire  (PlP  >suveniir !22_S
34715	auster	auster	auster	02_S	SgN	et	auster =auster  (SgN  >auster !02_S
34717	saatsime	saat	saatma	34_V	IndIpfPl1	et	saatsime =saat  (IndIpfPl1  >saatma !34_V
34720	organisatsioone	organisatsioone	organisatsioon	22_S	PlP	et	organisatsioone =organisatsioone  (PlP  >organisatsioon !22_S
34735	eelmine	eelmine	eelmine	12?10_A	SgN	et	eelmine =eelmine  (SgN  >eelmine !12?10_A
34740	viiekesi	viiekesi	viiekesi	41_D	ID	et	viiekesi =viiekesi  (ID  >viiekesi !41_D
34741	platsil	platsi	plats	22_S	SgAd	et	platsil =platsi  (SgAd  >plats !22_S
34745	kokteilid	kokteili	kokteil	22_S	PlN	et	kokteilid =kokteili  (PlN  >kokteil !22_S
34752	taimed	taime	taim	22_S	PlN	et	taimed =taime  (PlN  >taim !22_S
34779	toomehärrad	härra	toome+härra	16_S	PlN	et	toomehärrad =härra  (PlN  >toome+härra !16_S
34781	läbiviidi	viidi	läbi+viit	22_S	SgG	et	läbiviidi =viidi  (SgG  >läbi+viit !22_S
34784	kohalikude	kohaliku	kohalik	25_AS	PlG	et	kohalikude =kohaliku  (PlG  >kohalik !25_AS
34787	relvavalmistamine	valmistamine	relva+valmistamine	12_S	SgN	et	relvavalmistamine =valmistamine  (SgN  >relva+valmistamine !12_S
34802	sajandini	sajandi	sajand	02_S	SgTer	et	sajandini =sajandi  (SgTer  >sajand !02_S
34805	lapsetele	e	laps+esi	15_S	PlAll	et	lapsetele =e  (PlAll  >laps+esi !15_S
34811	kabelid	kabeli	kabel	02_S	PlN	et	kabelid =kabeli  (PlN  >kabel !02_S
34815	oldi	ol	olema	36_V	IndIpfIps	et	oldi =ol  (IndIpfIps  >olema !36_V
34819	teke	teke	teke	06_S	SgN	et	teke =teke  (SgN  >teke !06_S
34824	visitatsioone	visitatsioone	visitatsioon	22_S	PlP	et	visitatsioone =visitatsioone  (PlP  >visitatsioon !22_S
34827	elati	ela	elama	27_V	IndIpfIps	et	elati =ela  (IndIpfIps  >elama !27_V
34829	koguduse	koguduse	kogudus	11_S	SgG	et	koguduse =koguduse  (SgG  >kogudus !11_S
34840	kooliraamatute	raamatu	kooli+raamat	02_S	PlG	et	kooliraamatute =raamatu  (PlG  >kooli+raamat !02_S
34844	piletit	pileti	pilet	02_S	SgP	et	piletit =pileti  (SgP  >pilet !02_S
34850	pudeli	pudeli	pudel	02_S	SgG	et	pudeli =pudeli  (SgG  >pudel !02_S
34858	saavutan	saavuta	saavutama	27_V	IndPrSg1	et	saavutan =saavuta  (IndPrSg1  >saavutama !27_V
34861	keskaeg	aeg	kesk+aeg	22_S	SgN	et	keskaeg =aeg  (SgN  >kesk+aeg !22_S
34863	kohupiim	piim	kohu+piim	22_S	SgN	et	kohupiim =piim  (SgN  >kohu+piim !22_S
34871	baltimaadega	maa	balti+maa	26_S	PlKom	et	baltimaadega =maa  (PlKom  >balti+maa !26_S
34876	kingad	kinga	king	22_S	PlN	et	kingad =kinga  (PlN  >king !22_S
34877	heeringad	heeringa	heeringas	02_S	PlN	et	heeringad =heeringa  (PlN  >heeringas !02_S
34885	aeglased	aeglase	aeglane	12?10_A	PlN	et	aeglased =aeglase  (PlN  >aeglane !12?10_A
34891	sellejuures	juure	selle+juur	13_S	SgIn	et	sellejuures =juure  (SgIn  >selle+juur !13_S
34892	taoline	taoline	taoline	12?10_A	SgN	et	taoline =taoline  (SgN  >taoline !12?10_A
34898	kanalitel	kanali	kanal	02_S	PlAd	et	kanalitel =kanali  (PlAd  >kanal !02_S
34901	üldlaulupeodel	peo	üld+laulu+peo	26_S	PlAd	et	üldlaulupeodel =peo  (PlAd  >üld+laulu+peo !26_S
34902	eristab	erista	eristama	27_V	IndPrSg3	et	eristab =erista  (IndPrSg3  >eristama !27_V
34905	säilitab	säilita	säilitama	27_V	IndPrSg3	et	säilitab =säilita  (IndPrSg3  >säilitama !27_V
34906	olemust	olemus	olemus	11_S	SgP	et	olemust =olemus  (SgP  >olemus !11_S
34909	vabal	vaba	vaba	17_A	SgAd	et	vabal =vaba  (SgAd  >vaba !17_A
34912	kõrgpoliitikud	poliitiku	kõrg+poliitik	02_S	PlN	et	kõrgpoliitikud =poliitiku  (PlN  >kõrg+poliitik !02_S
34917	raekoja	koja	rae+koda	18_S	SgG	et	raekoja =koja  (SgG  >rae+koda !18_S
34922	konstruktsioon	konstruktsioon	konstruktsioon	22_S	SgN	et	konstruktsioon =konstruktsioon  (SgN  >konstruktsioon !22_S
34927	lauluväljaku	väljaku	laulu+väljak	02_S	SgG	et	lauluväljaku =väljaku  (SgG  >laulu+väljak !02_S
34929	salmik	salmik	salmik	02_S	SgN	et	salmik =salmik  (SgN  >salmik !02_S
34942	rahustas	rahusta	rahustama	27_V	IndIpfSg3	et	rahustas =rahusta  (IndIpfSg3  >rahustama !27_V
34753	uskuma	usku	uskuma	28_V	Sup	et	uskuma =usku  (Sup  >uskuma !28_V
34756	putukaid	putuka	putukas	02_S	PlP	et	putukaid =putuka  (PlP  >putukas !02_S
34760	sõimab	sõima	sõimama	29_V	IndPrSg3	et	sõimab =sõima  (IndPrSg3  >sõimama !29_V
34762	kultuurne	kultuurne	kultuurne	02_A	SgN	et	kultuurne =kultuurne  (SgN  >kultuurne !02_A
34771	heeringat	heeringa	heeringas	02_S	SgP	et	heeringat =heeringa  (SgP  >heeringas !02_S
34773	kaitsemüürid	müüri	kaitse+müür	22_S	PlN	et	kaitsemüürid =müüri  (PlN  >kaitse+müür !22_S
34774	raekojas	koja	rae+koda	18_S	SgIn	et	raekojas =koja  (SgIn  >rae+koda !18_S
34776	raehärrad	härra	rae+härra	16_S	PlN	et	raehärrad =härra  (PlN  >rae+härra !16_S
34777	linnaga	linna	linn	22_S	SgKom	et	linnaga =linna  (SgKom  >linn !22_S
34785	meistriks	meistri	meister	02_S	SgTr	et	meistriks =meistri  (SgTr  >meister !02_S
34786	varandus	varandus	varandus	11_S	SgN	et	varandus =varandus  (SgN  >varandus !11_S
34790	karusnahke	nahke	karus+nahk	22_S	PlP	et	karusnahke =nahke  (PlP  >karus+nahk !22_S
34792	kaunistas	kaunista	kaunistama	27_V	IndIpfSg3	et	kaunistas =kaunista  (IndIpfSg3  >kaunistama !27_V
34795	kümnendik	kümnendik	kümnendik	25_N	SgN	et	kümnendik =kümnendik  (SgN  >kümnendik !25_N
34806	tõenäosusega	näosuse	tõe+näosus	11~09_S	SgKom	et	tõenäosusega =näosuse  (SgKom  >tõe+näosus !11~09_S
34813	kuuluma	kuulu	kuuluma	27_V	Sup	et	kuuluma =kuulu  (Sup  >kuuluma !27_V
34821	sakste	saks	saks	23_S	PlG	et	sakste =saks  (PlG  >saks !23_S
34822	sal-st	sal	sal	xx_Q	SgEl	et	sal-st =sal  (SgEl  >sal !xx_Q
34826	linnavõimude	võimu	linna+võim	22_S	PlG	et	linnavõimude =võimu  (PlG  >linna+võim !22_S
34828	pärisorjuslik	orjuslik	päris+orjuslik	25_A	SgN	et	pärisorjuslik =orjuslik  (SgN  >päris+orjuslik !25_A
34832	ümberrahvastamise	rahvastamise	ümber+rahvastamine	12_S	SgG	et	ümberrahvastamise =rahvastamise  (SgG  >ümber+rahvastamine !12_S
34836	maalikunstnik	kunstnik	maali+kunstnik	25_S	SgN	et	maalikunstnik =kunstnik  (SgN  >maali+kunstnik !25_S
34839	rahvusliikumise	liikumise	rahvus+liikumine	12_S	SgG	et	rahvusliikumise =liikumise  (SgG  >rahvus+liikumine !12_S
34845	ules	ule	ulg	22_S	PlIn	et	ules =ule  (PlIn  >ulg !22_S
34865	õppetööle	töö	õppe+töö	26_S	SgAll	et	õppetööle =töö  (SgAll  >õppe+töö !26_S
34872	tuuline	tuuline	tuuline	10_A	SgN	et	tuuline =tuuline  (SgN  >tuuline !10_A
34878	soid	so	soo	26_S	PlP	et	soid =so  (PlP  >soo !26_S
34881	pastat	pasta	pasta	16_S	SgP	et	pastat =pasta  (SgP  >pasta !16_S
34888	toimuti	toimu	toimuma	27_V	IndIpfIps	et	toimuti =toimu  (IndIpfIps  >toimuma !27_V
34889	töötegemisel	tegemise	töö+tegemine	12_S	SgAd	et	töötegemisel =tegemise  (SgAd  >töö+tegemine !12_S
34894	tunnes	tunne	tund	22_S	PlIn	et	tunnes =tunne  (PlIn  >tund !22_S
34895	relvaga	relva	relv	22_S	SgKom	et	relvaga =relva  (SgKom  >relv !22_S
34903	ühehäälne	häälne	ühe+häälne	02_A	SgN	et	ühehäälne =häälne  (SgN  >ühe+häälne !02_A
34908	suutis	suut	suutma	34_V	IndIpfSg3	et	suutis =suut  (IndIpfSg3  >suutma !34_V
34910	eluaeg	aeg	elu+aeg	22_S	SgN	et	eluaeg =aeg  (SgN  >elu+aeg !22_S
34911	lindistatakse	lindista	lindistama	27_V	IndPrIps	et	lindistatakse =lindista  (IndPrIps  >lindistama !27_V
34913	sümboolikad	sümboolika	sümboolika	01_S	PlN	et	sümboolikad =sümboolika  (PlN  >sümboolika !01_S
34918	orkester	orkester	orkester	02_S	SgN	et	orkester =orkester  (SgN  >orkester !02_S
34919	pisar	pisar	pisar	02_S	SgN	et	pisar =pisar  (SgN  >pisar !02_S
34921	kolmnurkne	nurkne	kolm+nurkne	02_A	SgN	et	kolmnurkne =nurkne  (SgN  >kolm+nurkne !02_A
34926	paraadile	paraadi	paraad	22_S	SgAll	et	paraadile =paraadi  (SgAll  >paraad !22_S
34930	aegadest	aega	aeg	22_S	PlEl	et	aegadest =aega  (PlEl  >aeg !22_S
34933	laulikud	lauliku	laulik	02_S	PlN	et	laulikud =lauliku  (PlN  >laulik !02_S
34937	inimsaatuse	saatuse	inim+saatus	11~09_S	SgG	et	inimsaatuse =saatuse  (SgG  >inim+saatus !11~09_S
34940	vilgas	vilgas	vilgas	07_A	SgN	et	vilgas =vilgas  (SgN  >vilgas !07_A
34952	armastati	armasta	armastama	27_V	IndIpfIps	et	armastati =armasta  (IndIpfIps  >armastama !27_V
34954	karjas	karja	kari	24_S	SgIn	et	karjas =karja  (SgIn  >kari !24_S
34965	kirjaoskuse	oskuse	kirja+oskus	11~09_S	SgG	et	kirjaoskuse =oskuse  (SgG  >kirja+oskus !11~09_S
34991	karjades	karja	kari	24_S	PlIn	et	karjades =karja  (PlIn  >kari !24_S
34993	pulme	pulme	pulm	22_S	PlP	et	pulme =pulme  (PlP  >pulm !22_S
35004	rahuneda	rahune	rahunema	27_V	Inf	et	rahuneda =rahune  (Inf  >rahunema !27_V
35007	kaasnema	kaasne	kaasnema	27_V	Sup	et	kaasnema =kaasne  (Sup  >kaasnema !27_V
35011	traditsioonidest	traditsiooni	traditsioon	22_S	PlEl	et	traditsioonidest =traditsiooni  (PlEl  >traditsioon !22_S
35022	lauluväljal	välja	laulu+väli	24_S	SgAd	et	lauluväljal =välja  (SgAd  >laulu+väli !24_S
35026	relvata	relva	relv	22_S	SgAb	et	relvata =relva  (SgAb  >relv !22_S
34766	kesk	kesk	kesk	41_K	ID	et	kesk =kesk  (ID  >kesk !41_K
34768	kaubandusega	kaubanduse	kaubandus	11_S	SgKom	et	kaubandusega =kaubanduse  (SgKom  >kaubandus !11_S
34778	hariduskeskused	keskuse	haridus+keskus	11~09_S	PlN	et	hariduskeskused =keskuse  (PlN  >haridus+keskus !11~09_S
34782	messe	messe	mess	22_S	PlP	et	messe =messe  (PlP  >mess !22_S
34783	meistrid	meistri	meister	02_S	PlN	et	meistrid =meistri  (PlN  >meister !02_S
34793	altareid	altare	altar	02_S	PlP	et	altareid =altare  (PlP  >altar !02_S
34798	jumal	jumal	jumal	02_S	SgN	et	jumal =jumal  (SgN  >jumal !02_S
34801	uksele	ukse	uks	14_S	SgAll	et	uksele =ukse  (SgAll  >uks !14_S
34808	haiglaid	haigla	haigla	01_S	PlP	et	haiglaid =haigla  (PlP  >haigla !01_S
34816	sugukondliku	sugukondliku	sugukondlik	25_A	SgG	et	sugukondliku =sugukondliku  (SgG  >sugukondlik !25_A
34820	sissetulekutelt	tuleku	sisse+tulek	02_S	PlAbl	et	sissetulekutelt =tuleku  (PlAbl  >sisse+tulek !02_S
34823	talurahvaks	rahva	talu+rahvas	07_S	SgTr	et	talurahvaks =rahva  (SgTr  >talu+rahvas !07_S
34825	ristiusu	usu	risti+usk	22_S	SgG	et	ristiusu =usu  (SgG  >risti+usk !22_S
34834	kooride	koori	koor	22_S	PlG	et	kooride =koori  (PlG  >koor !22_S
34846	teisepäev	päev	teise+päev	22_S	SgN	et	teisepäev =päev  (SgN  >teise+päev !22_S
34847	viieni	viie	viis	14_N	SgTer	et	viieni =viie  (SgTer  >viis !14_N
34859	venesse	vene	vene	16_S	SgIll	et	venesse =vene  (SgIll  >vene !16_S
34862	joogikäitumine	käitumine	joogi+käitumine	12_S	SgN	et	joogikäitumine =käitumine  (SgN  >joogi+käitumine !12_S
34864	kohuke	kohuke	kohuke	12_S	SgN	et	kohuke =kohuke  (SgN  >kohuke !12_S
34866	jaanuarist	jaanuari	jaanuar	19_S	SgEl	et	jaanuarist =jaanuari  (SgEl  >jaanuar !19_S
34868	suhtud	suhtu	suhtuma	27_V	IndPrSg2	et	suhtud =suhtu  (IndPrSg2  >suhtuma !27_V
34880	päikeseloojang	loojang	päikese+loojang	02_S	SgN	et	päikeseloojang =loojang  (SgN  >päikese+loojang !02_S
34883	kogeda	koge	kogema	27_V	Inf	et	kogeda =koge  (Inf  >kogema !27_V
34884	iseendas	enda	ise+enda	00_P	SgIn	et	iseendas =enda  (SgIn  >ise+enda !00_P
34886	pulmadest	pulma	pulm	22_S	PlEl	et	pulmadest =pulma  (PlEl  >pulm !22_S
34887	tervitati	tervita	tervitama	27_V	IndIpfIps	et	tervitati =tervita  (IndIpfIps  >tervitama !27_V
34897	rahvapille	pille	rahva+pill	22_S	PlP	et	rahvapille =pille  (PlP  >rahva+pill !22_S
34899	raadiosaatetel	e	raadio+saat+esi	15_S	PlAd	et	raadiosaatetel =e  (PlAd  >raadio+saat+esi !15_S
34900	laulmas	laul	laulma	33_V	SupIn	et	laulmas =laul  (SupIn  >laulma !33_V
34907	muistset	muistse	muistne	02_A	SgP	et	muistset =muistse  (SgP  >muistne !02_A
34916	rahvariietuses	riietuse	rahva+riietus	11_S	SgIn	et	rahvariietuses =riietuse  (SgIn  >rahva+riietus !11_S
34934	ärkamisaeg	aeg	ärkamis+aeg	22_S	SgN	et	ärkamisaeg =aeg  (SgN  >ärkamis+aeg !22_S
34938	kultuurinähtuseid	nähtuse	kultuuri+nähtus	09_S	PlP	et	kultuurinähtuseid =nähtuse  (PlP  >kultuuri+nähtus !09_S
34941	teebki	tee	tegema	28_V	IndPrSg3^	et	teebki =tee  (IndPrSg3^  >tegema !28_V
34947	riim	riim	riim	22_S	SgN	et	riim =riim  (SgN  >riim !22_S
34948	silbil	silbi	silp	22_S	SgAd	et	silbil =silbi  (SgAd  >silp !22_S
34949	kajastama	kajasta	kajastama	27_V	Sup	et	kajastama =kajasta  (Sup  >kajastama !27_V
34963	kirikukoorid	koori	kiriku+koor	22_S	PlN	et	kirikukoorid =koori  (PlN  >kiriku+koor !22_S
34967	pillisaatega	saate	pilli+saade	06_S	SgKom	et	pillisaatega =saate  (SgKom  >pilli+saade !06_S
34971	kultuurses	kultuurse	kultuurne	02_A	SgIn	et	kultuurses =kultuurse  (SgIn  >kultuurne !02_A
34975	toetades	toeta	toetama	27_V	Ger	et	toetades =toeta  (Ger  >toetama !27_V
34984	laulikuid	lauliku	laulik	02_S	PlP	et	laulikuid =lauliku  (PlP  >laulik !02_S
34988	võtteks	võtte	võte	06_S	SgTr	et	võtteks =võtte  (SgTr  >võte !06_S
34996	koosajaga	aja	koos+aeg	22_S	SgKom	et	koosajaga =aja  (SgKom  >koos+aeg !22_S
35000	õpikutesse	õpiku	õpik	02_S	PlIll	et	õpikutesse =õpiku  (PlIll  >õpik !02_S
35001	sammub	sammu	sammuma	28_V	IndPrSg3	et	sammub =sammu  (IndPrSg3  >sammuma !28_V
35003	püüaks	püüa	püüdma	34_V	KndPrPs	et	püüaks =püüa  (KndPrPs  >püüdma !34_V
35008	puhkpilliorkester	orkester	puhk+pilli+orkester	02_S	SgN	et	puhkpilliorkester =orkester  (SgN  >puhk+pilli+orkester !02_S
35009	peoorganiseerimine	organiseerimine	peo+organiseerimine	12_S	SgN	et	peoorganiseerimine =organiseerimine  (SgN  >peo+organiseerimine !12_S
35013	professionaalse	professionaalse	professionaalne	02_A	SgG	et	professionaalse =professionaalse  (SgG  >professionaalne !02_A
35021	pille	pille	pill	22_S	PlP	et	pille =pille  (PlP  >pill !22_S
35023	alustame	alusta	alustama	27_V	IndPrPl1	et	alustame =alusta  (IndPrPl1  >alustama !27_V
35027	laulurahvakultuur	kultuur	laulu+rahva+kultuur	22_S	SgN	et	laulurahvakultuur =kultuur  (SgN  >laulu+rahva+kultuur !22_S
35040	rahvatantsiga	tantsi	rahva+tants	22_S	SgKom	et	rahvatantsiga =tantsi  (SgKom  >rahva+tants !22_S
34770	vürtse	vürtse	vürts	22_S	PlP	et	vürtse =vürtse  (PlP  >vürts !22_S
34772	terist	teri	tera	17_S	PlEl	et	terist =teri  (PlEl  >tera !17_S
34780	toomekirikus	kiriku	toome+kirik	02_S	SgIn	et	toomekirikus =kiriku  (SgIn  >toome+kirik !02_S
34788	ehtevalmistamine	valmistamine	ehte+valmistamine	12_S	SgN	et	ehtevalmistamine =valmistamine  (SgN  >ehte+valmistamine !12_S
34791	koel	koe	kude	18_S	SgAd	et	koel =koe  (SgAd  >kude !18_S
34796	elukohavahetamine	vahetamine	elu+koha+vahetamine	12_S	SgN	et	elukohavahetamine =vahetamine  (SgN  >elu+koha+vahetamine !12_S
34797	hingeelule	elu	hinge+elu	17_S	SgAll	et	hingeelule =elu  (SgAll  >hinge+elu !17_S
34809	lihtrahvale	rahva	liht+rahvas	07_S	SgAll	et	lihtrahvale =rahva  (SgAll  >liht+rahvas !07_S
34810	kirikukihelkonnad	kihelkonna	kiriku+kihelkond	22_S	PlN	et	kirikukihelkonnad =kihelkonna  (PlN  >kiriku+kihelkond !22_S
34812	maakondadena	maakonda	maakond	22_S	PlEs	et	maakondadena =maakonda  (PlEs  >maakond !22_S
34818	linnade	linna	linn	22_S	PlG	et	linnade =linna  (PlG  >linn !22_S
34830	teelased	teelase	teelane	12?10_S	PlN	et	teelased =teelase  (PlN  >teelane !12?10_S
34833	lähenes	lähene	lähenema	27_V	IndIpfSg3	et	lähenes =lähene  (IndIpfSg3  >lähenema !27_V
34837	grupi	grupi	grupp	22_S	SgG	et	grupi =grupi  (SgG  >grupp !22_S
34848	ujusin	uju	ujuma	27_V	IndIpfSg1	et	ujusin =uju  (IndIpfSg1  >ujuma !27_V
34852	keelis	keeli	keel	13_S	PlIn	et	keelis =keeli  (PlIn  >keel !13_S
34853	kultuuripärand	pärand	kultuuri+pärand	02_S	SgN	et	kultuuripärand =pärand  (SgN  >kultuuri+pärand !02_S
34854	trammiga	trammi	tramm	22_S	SgKom	et	trammiga =trammi  (SgKom  >tramm !22_S
34867	margareeta	ree	marga+regi	21_S	SgAb	et	margareeta =ree  (SgAb  >marga+regi !21_S
34869	ida-eestis	eesti	ida-eesti	16_H	SgIn	et	ida-eestis =eesti  (SgIn  >ida-eesti !16_H
34875	reisist	reisi	reis	22_S	SgEl	et	reisist =reisi  (SgEl  >reis !22_S
34879	randasse	asse	rand+ass	22_S	PlP	et	randasse =asse  (PlP  >rand+ass !22_S
34882	kuuks	kuu	kuu	26_S	SgTr	et	kuuks =kuu  (SgTr  >kuu !26_S
34896	jõuga	jõu	jõud	22_S	SgKom	et	jõuga =jõu  (SgKom  >jõud !22_S
34920	seeliku	seeliku	seelik	02_S	SgG	et	seeliku =seeliku  (SgG  >seelik !02_S
34923	staadiumil	staadiumi	staadium	19~02_S	SgAd	et	staadiumil =staadiumi  (SgAd  >staadium !19~02_S
34932	armastatakse	armasta	armastama	27_V	IndPrIps	et	armastatakse =armasta  (IndPrIps  >armastama !27_V
34943	edastas	edasta	edastama	27_V	IndIpfSg3	et	edastas =edasta  (IndIpfSg3  >edastama !27_V
34944	kajastas	kajasta	kajastama	27_V	IndIpfSg3	et	kajastas =kajasta  (IndIpfSg3  >kajastama !27_V
34951	kiideti	kiide	kiitma	34_V	IndIpfIps	et	kiideti =kiide  (IndIpfIps  >kiitma !34_V
34955	üksteisele	teise	üks+teise	12_P	SgAll	et	üksteisele =teise  (SgAll  >üks+teise !12_P
34958	saateta	saate	saade	06_S	SgAb	et	saateta =saate  (SgAb  >saade !06_S
34960	kajastuda	kajastu	kajastuma	27_V	Inf	et	kajastuda =kajastu  (Inf  >kajastuma !27_V
34962	leviga	levi	levi	17_S	SgKom	et	leviga =levi  (SgKom  >levi !17_S
34964	üldise	üldise	üldine	10~12_A	SgG	et	üldise =üldise  (SgG  >üldine !10~12_A
34966	lõpuriim	riim	lõpu+riim	22_S	SgN	et	lõpuriim =riim  (SgN  >lõpu+riim !22_S
34968	teguritega	teguri	tegur	02_S	PlKom	et	teguritega =teguri  (PlKom  >tegur !02_S
34969	kuukaks	kuuka	kuukama	29_V	KndPrPs	et	kuukaks =kuuka  (KndPrPs  >kuukama !29_V
34970	õitsema	õitse	õitsema	28_V	Sup	et	õitsema =õitse  (Sup  >õitsema !28_V
34978	pidades	pida	pidama	28_V	Ger	et	pidades =pida  (Ger  >pidama !28_V
34981	mitmekesi	mitmekesi	mitmekesi	41_D	ID	et	mitmekesi =mitmekesi  (ID  >mitmekesi !41_D
34982	piduõhtutel	õhtu	pidu+õhtu	01_S	PlAd	et	piduõhtutel =õhtu  (PlAd  >pidu+õhtu !01_S
34994	muistendeid	muistende	muistend	02_S	PlP	et	muistendeid =muistende  (PlP  >muistend !02_S
35012	tsaristliku	tsaristliku	tsaristlik	25_A	SgG	et	tsaristliku =tsaristliku  (SgG  >tsaristlik !25_A
35016	lastekooridega	koori	laste+koor	22_S	PlKom	et	lastekooridega =koori  (PlKom  >laste+koor !22_S
35024	leiame	leia	leidma	34_V	IndPrPl1	et	leiame =leia  (IndPrPl1  >leidma !34_V
35034	pulmadel	pulma	pulm	22_S	PlAd	et	pulmadel =pulma  (PlAd  >pulm !22_S
35037	vanaaja	aja	vana+aeg	22_S	SgG	et	vanaaja =aja  (SgG  >vana+aeg !22_S
35045	heleloojad	looja	hele+looja	01_S	PlN	et	heleloojad =looja  (PlN  >hele+looja !01_S
35054	organiseerid	organiseeri	organiseerima	28_V	IndPrSg2	et	organiseerid =organiseeri  (IndPrSg2  >organiseerima !28_V
35066	tänast	tänas	tänane	10_A	SgP	et	tänast =tänas  (SgP  >tänane !10_A
35079	rahvariideid	riide	rahva+riie	06_S	PlP	et	rahvariideid =riide  (PlP  >rahva+riie !06_S
35084	keskaegseid	aegse	kesk+aegne	02_A	PlP	et	keskaegseid =aegse  (PlP  >kesk+aegne !02_A
35100	geniaalsed	geniaalse	geniaalne	02_A	PlN	et	geniaalsed =geniaalse  (PlN  >geniaalne !02_A
34925	saadikud	saadiku	saadik	02_S	PlN	et	saadikud =saadiku  (PlN  >saadik !02_S
34928	koorilaulmisega	laulmise	koori+laulmine	12?10_S	SgKom	et	koorilaulmisega =laulmise  (SgKom  >koori+laulmine !12?10_S
34931	tähistades	tähista	tähistama	27_V	Ger	et	tähistades =tähista  (Ger  >tähistama !27_V
34935	iseäranis	iseäranis	ise+äranis	41_D	ID	et	iseäranis =iseäranis  (ID  >ise+äranis !41_D
34936	uuritakse	uuri	uurima	28_V	IndPrIps	et	uuritakse =uuri  (IndPrIps  >uurima !28_V
34939	silmapaistvaks	paistva	silma+paistev	02_A	SgTr	et	silmapaistvaks =paistva  (SgTr  >silma+paistev !02_A
34946	arhailised	arhailise	arhailine	12?10_A	PlN	et	arhailised =arhailise  (PlN  >arhailine !12?10_A
34953	turvatunnet	tunne	turva+tunne	06_S	SgP	et	turvatunnet =tunne  (SgP  >turva+tunne !06_S
34956	omaga	oma	oma	17_A	SgKom	et	omaga =oma  (SgKom  >oma !17_A
34959	rahvuste	rahvus	rahvus	11~09_S	PlG	et	rahvuste =rahvus  (PlG  >rahvus !11~09_S
34973	enesehinnanguid	hinnangu	enese+hinnang	02_S	PlP	et	enesehinnanguid =hinnangu  (PlP  >enese+hinnang !02_S
34974	protestida	protesti	protestima	28_V	Inf	et	protestida =protesti  (Inf  >protestima !28_V
34979	matuseid	matuse	matus	09_S	PlP	et	matuseid =matuse  (PlP  >matus !09_S
34980	jäljendada	jäljenda	jäljendama	27_V	Inf	et	jäljendada =jäljenda  (Inf  >jäljendama !27_V
34983	kirjaoskus	oskus	kirja+oskus	11~09_S	SgN	et	kirjaoskus =oskus  (SgN  >kirja+oskus !11~09_S
34986	häält	hääl	hääl	13_S	SgP	et	häält =hääl  (SgP  >hääl !13_S
34987	demonstreerimas	demonstreeri	demonstreerima	28_V	SupIn	et	demonstreerimas =demonstreeri  (SupIn  >demonstreerima !28_V
34989	tuginedes	tugine	tuginema	27_V	Ger	et	tuginedes =tugine  (Ger  >tuginema !27_V
34990	traditsioonidele	traditsiooni	traditsioon	22_S	PlAll	et	traditsioonidele =traditsiooni  (PlAll  >traditsioon !22_S
34995	unikaalne	unikaalne	unikaalne	02_A	SgN	et	unikaalne =unikaalne  (SgN  >unikaalne !02_A
34997	kultuuridega	kultuuri	kultuur	22_S	PlKom	et	kultuuridega =kultuuri  (PlKom  >kultuur !22_S
34998	igasugustel	sugus	iga+sugune	10_A	PlAd	et	igasugustel =sugus  (PlAd  >iga+sugune !10_A
35015	mister	mister	mister	02_S	SgN	et	mister =mister  (SgN  >mister !02_S
35019	muusikatunnis	tunni	muusika+tund	22_S	SgIn	et	muusikatunnis =tunni  (SgIn  >muusika+tund !22_S
35025	eurovisioonis	visiooni	euro+visioon	22_S	SgIn	et	eurovisioonis =visiooni  (SgIn  >euro+visioon !22_S
35028	poetess	poetess	poetess	22_S	SgN	et	poetess =poetess  (SgN  >poetess !22_S
35032	ilmuda	ilmu	ilmuma	27_V	Inf	et	ilmuda =ilmu  (Inf  >ilmuma !27_V
35033	vanaajal	aja	vana+aeg	22_S	SgAd	et	vanaajal =aja  (SgAd  >vana+aeg !22_S
35038	jälgisin	jälgi	jälgima	27_V	IndIpfSg1	et	jälgisin =jälgi  (IndIpfSg1  >jälgima !27_V
35039	rahvaluulega	luule	rahva+luule	06_S	SgKom	et	rahvaluulega =luule  (SgKom  >rahva+luule !06_S
35042	liikuma	liiku	liikuma	28_V	Sup	et	liikuma =liiku  (Sup  >liikuma !28_V
35043	laulusaated	saate	laulu+saade	06_S	PlN	et	laulusaated =saate  (PlN  >laulu+saade !06_S
35046	lahendama	lahenda	lahendama	27_V	Sup	et	lahendama =lahenda  (Sup  >lahendama !27_V
35049	vilistati	vilista	vilistama	27_V	IndIpfIps	et	vilistati =vilista  (IndIpfIps  >vilistama !27_V
35051	naistel	nais	naine	12_S	PlAd	et	naistel =nais  (PlAd  >naine !12_S
35057	vanaisadega	isa	vana+isa	17_S	PlKom	et	vanaisadega =isa  (PlKom  >vana+isa !17_S
35059	meelelahutuslikke	lahutuslikke	meele+lahutuslik	25_A	PlP	et	meelelahutuslikke =lahutuslikke  (PlP  >meele+lahutuslik !25_A
35061	muusikaharrastusega	harrastuse	muusika+harrastus	11_S	SgKom	et	muusikaharrastusega =harrastuse  (SgKom  >muusika+harrastus !11_S
35067	säilitakse	säili	säilima	28_V	IndPrIps	et	säilitakse =säili  (IndPrIps  >säilima !28_V
35068	saaremal	ema	saar+ema	17_S	SgAd	et	saaremal =ema  (SgAd  >saar+ema !17_S
35071	jutust	jutu	jutt	22_S	SgEl	et	jutust =jutu  (SgEl  >jutt !22_S
35072	laulurahvad	rahva	laulu+rahvas	07_S	PlN	et	laulurahvad =rahva  (PlN  >laulu+rahvas !07_S
35075	üle-eestiline	eestiline	üle-eestiline	12_A	SgN	et	üle-eestiline =eestiline  (SgN  >üle-eestiline !12_A
35076	laulsime	laul	laulma	33_V	IndIpfPl1	et	laulsime =laul  (IndIpfPl1  >laulma !33_V
35080	puhkepilliorkestri	orkestri	puhke+pilli+orkester	02_S	SgG	et	puhkepilliorkestri =orkestri  (SgG  >puhke+pilli+orkester !02_S
35086	isadest	isa	isa	17_S	PlEl	et	isadest =isa  (PlEl  >isa !17_S
35088	situatsioonist	situatsiooni	situatsioon	22_S	SgEl	et	situatsioonist =situatsiooni  (SgEl  >situatsioon !22_S
35091	nõukogudeliidu	liidu	nõu+kogude+liit	22_S	SgG	et	nõukogudeliidu =liidu  (SgG  >nõu+kogude+liit !22_S
35092	väljaminek	minek	välja+minek	02_S	SgN	et	väljaminek =minek  (SgN  >välja+minek !02_S
35093	meloodiline	meloodiline	meloodiline	12_A	SgN	et	meloodiline =meloodiline  (SgN  >meloodiline !12_A
35098	kirikukoolides	kooli	kiriku+kool	22_S	PlIn	et	kirikukoolides =kooli  (PlIn  >kiriku+kool !22_S
35104	koidulale	la	koidu+la	26_S	SgAll	et	koidulale =la  (SgAll  >koidu+la !26_S
34945	vaadeldes	vaadel	vaatlema	30_V	Ger	et	vaadeldes =vaadel  (Ger  >vaatlema !30_V
34950	rahustades	rahusta	rahustama	27_V	Ger	et	rahustades =rahusta  (Ger  >rahustama !27_V
34957	tunnuseks	tunnuse	tunnus	09_S	SgTr	et	tunnuseks =tunnuse  (SgTr  >tunnus !09_S
34961	rahvamuusikas	muusika	rahva+muusika	01_S	SgIn	et	rahvamuusikas =muusika  (SgIn  >rahva+muusika !01_S
34972	ansamblite	ansambli	ansambel	02_S	PlG	et	ansamblite =ansambli  (PlG  >ansambel !02_S
34976	eluosana	osa	elu+osa	17_S	SgEs	et	eluosana =osa  (SgEs  >elu+osa !17_S
34977	aidas	aida	ait	22_S	SgIn	et	aidas =aida  (SgIn  >ait !22_S
34985	trükkima	trükki	trükkima	28_V	Sup	et	trükkima =trükki  (Sup  >trükkima !28_V
34992	kiiguti	kiigu	kiikuma	28_V	IndIpfIps	et	kiiguti =kiigu  (IndIpfIps  >kiikuma !28_V
34999	soomest	mest	soo+mest	22_S	SgN	et	soomest =mest  (SgN  >soo+mest !22_S
35002	kiigutada	kiiguta	kiigutama	27_V	Inf	et	kiigutada =kiiguta  (Inf  >kiigutama !27_V
35005	rahulikuks	rahuliku	rahulik	25_A	SgTr	et	rahulikuks =rahuliku  (SgTr  >rahulik !25_A
35006	külakoolides	kooli	küla+kool	22_S	PlIn	et	külakoolides =kooli  (PlIn  >küla+kool !22_S
35010	kaasaegsel	aegse	kaas+aegne	02_A	SgAd	et	kaasaegsel =aegse  (SgAd  >kaas+aegne !02_A
35014	otsaga	otsa	ots	23?22_S	SgKom	et	otsaga =otsa  (SgKom  >ots !23?22_S
35017	õrnad	õrna	õrn	22_A	PlN	et	õrnad =õrna  (PlN  >õrn !22_A
35018	kenad	kena	kena	17_A	PlN	et	kenad =kena  (PlN  >kena !17_A
35020	rühmades	rühma	rühm	22_S	PlIn	et	rühmades =rühma  (PlIn  >rühm !22_S
35029	suursündmust	sündmus	suur+sündmus	11~09_S	SgP	et	suursündmust =sündmus  (SgP  >suur+sündmus !11~09_S
35030	hümniks	hümni	hümn	22_S	SgTr	et	hümniks =hümni  (SgTr  >hümn !22_S
35031	emade	ema	ema	17_S	PlG	et	emade =ema  (PlG  >ema !17_S
35035	tantsitakse	tantsi	tantsima	28_V	IndPrIps	et	tantsitakse =tantsi  (IndPrIps  >tantsima !28_V
35041	pidud	pidu	pidu	17_S	PlN	et	pidud =pidu  (PlN  >pidu !17_S
35050	usklik	usklik	usklik	25_AS	SgN	et	usklik =usklik  (SgN  >usklik !25_AS
35058	vanaemadega	ema	vana+ema	17_S	PlKom	et	vanaemadega =ema  (PlKom  >vana+ema !17_S
35063	elurõõm	rõõm	elu+rõõm	22_S	SgN	et	elurõõm =rõõm  (SgN  >elu+rõõm !22_S
35064	jalapõrutused	põrutuse	jala+põrutus	11_S	PlN	et	jalapõrutused =põrutuse  (PlN  >jala+põrutus !11_S
35069	loomadega	looma	loom	22_S	PlKom	et	loomadega =looma  (PlKom  >loom !22_S
35081	rahvatunne	tunne	rahva+tunne	06_S	SgN	et	rahvatunne =tunne  (SgN  >rahva+tunne !06_S
35083	musikaalne	musikaalne	musikaalne	02_A	SgN	et	musikaalne =musikaalne  (SgN  >musikaalne !02_A
35085	kaheksateistkümnest	kümnes	kaheksa+teist+kümnene	10~12_AS	SgP	et	kaheksateistkümnest =kümnes  (SgP  >kaheksa+teist+kümnene !10~12_AS
35087	laulustiile	stiile	laulu+stiil	22_S	PlP	et	laulustiile =stiile  (PlP  >laulu+stiil !22_S
35089	instrumendita	instrumendi	instrument	22_S	SgAb	et	instrumendita =instrumendi  (SgAb  >instrument !22_S
35094	informatsioonivahend	vahend	informatsiooni+vahend	02_S	SgN	et	informatsioonivahend =vahend  (SgN  >informatsiooni+vahend !02_S
35108	levida	levi	levima	27_V	Inf	et	levida =levi  (Inf  >levima !27_V
35131	tantsupeodele	peo	tantsu+peo	26_S	PlAll	et	tantsupeodele =peo  (PlAll  >tantsu+peo !26_S
35137	instrumentidega	instrumenti	instrument	22_S	PlKom	et	instrumentidega =instrumenti  (PlKom  >instrument !22_S
35138	venemoodne	moodne	vene+moodne	02_A	SgN	et	venemoodne =moodne  (SgN  >vene+moodne !02_A
35144	muusikaseltse	seltse	muusika+selts	22_S	PlP	et	muusikaseltse =seltse  (PlP  >muusika+selts !22_S
35145	laulutraditsioonis	traditsiooni	laulu+traditsioon	22_S	SgIn	et	laulutraditsioonis =traditsiooni  (SgIn  >laulu+traditsioon !22_S
35152	paleoliitikum	paleoliitikum	paleoliitikum	19_S	SgN	et	paleoliitikum =paleoliitikum  (SgN  >paleoliitikum !19_S
35156	pähkleid	pähkle	pähkel	02_S	PlP	et	pähkleid =pähkle  (PlP  >pähkel !02_S
35159	kütiti	küti	küttima	28_V	IndIpfIps	et	kütiti =küti  (IndIpfIps  >küttima !28_V
35164	küpsetati	küpseta	küpsetama	27_V	IndIpfIps	et	küpsetati =küpseta  (IndIpfIps  >küpsetama !27_V
35165	tarberiistad	riista	tarbe+riist	22_S	PlN	et	tarberiistad =riista  (PlN  >tarbe+riist !22_S
35166	püstkojad	koja	püst+koda	18_S	PlN	et	püstkojad =koja  (PlN  >püst+koda !18_S
35185	kalmetest	kalme	kalme	06_S	PlEl	et	kalmetest =kalme  (PlEl  >kalme !06_S
35188	inimgrupile	grupi	inim+grupp	22_S	SgAll	et	inimgrupile =grupi  (SgAll  >inim+grupp !22_S
35192	eksis	eksi	eksima	28_V	IndIpfSg3	et	eksis =eksi  (IndIpfSg3  >eksima !28_V
35194	annotatsioon	annotatsioon	annotatsioon	22_S	SgN	et	annotatsioon =annotatsioon  (SgN  >annotatsioon !22_S
35198	printsiibil	printsiibi	printsiip	22_S	SgAd	et	printsiibil =printsiibi  (SgAd  >printsiip !22_S
35202	kalapüügist	püügi	kala+püük	22_S	SgEl	et	kalapüügist =püügi  (SgEl  >kala+püük !22_S
35204	humoristliku	humoristliku	humoristlik	25_A	SgG	et	humoristliku =humoristliku  (SgG  >humoristlik !25_A
35036	meenutada	meenuta	meenutama	27_V	Inf	et	meenutada =meenuta  (Inf  >meenutama !27_V
35044	lauluoskusi	oskusi	laulu+oskus	11_S	PlP	et	lauluoskusi =oskusi  (PlP  >laulu+oskus !11_S
35047	kalapüüdmine	püüdmine	kala+püüdmine	12?10_S	SgN	et	kalapüüdmine =püüdmine  (SgN  >kala+püüdmine !12?10_S
35053	tegur	tegur	tegur	02_S	SgN	et	tegur =tegur  (SgN  >tegur !02_S
35055	arutleda	arutle	arutlema	27_V	Inf	et	arutleda =arutle  (Inf  >arutlema !27_V
35065	naiste-	nais	naine	12_S	PlG	et	naiste- =nais  (PlG  >naine !12_S
35070	saatavad	ava	saat+ava	17_S	PlN	et	saatavad =ava  (PlN  >saat+ava !17_S
35074	linnapäevad	päeva	linna+päev	22_S	PlN	et	linnapäevad =päeva  (PlN  >linna+päev !22_S
35077	räägime	räägi	rääkima	28_V	IndPrPl1	et	räägime =räägi  (IndPrPl1  >rääkima !28_V
35082	loovatud	atu	loov+att	22_S	PlN	et	loovatud =atu  (PlN  >loov+att !22_S
35095	sõdurid	sõduri	sõdur	02_S	PlN	et	sõdurid =sõduri  (PlN  >sõdur !02_S
35096	motiivid	motiivi	motiiv	22_S	PlN	et	motiivid =motiivi  (PlN  >motiiv !22_S
35097	rütmid	rütmi	rütm	22_S	PlN	et	rütmid =rütmi  (PlN  >rütm !22_S
35102	lauludel	laulu	laul	22_S	PlAd	et	lauludel =laulu  (PlAd  >laul !22_S
35103	rütmiga	rütmi	rütm	22_S	SgKom	et	rütmiga =rütmi  (SgKom  >rütm !22_S
35106	hingas	hinga	hingama	29_V	IndIpfSg3	et	hingas =hinga  (IndIpfSg3  >hingama !29_V
35114	album	album	album	02_S	SgN	et	album =album  (SgN  >album !02_S
35119	saadeteks	saade	saade	06_S	PlTr	et	saadeteks =saade  (PlTr  >saade !06_S
35121	kaare	kaare	kaar	13_S	SgG	et	kaare =kaare  (SgG  >kaar !13_S
35123	tantsudes	tantsu	tants	22_S	PlIn	et	tantsudes =tantsu  (PlIn  >tants !22_S
35129	mälule	mälu	mälu	17_S	SgAll	et	mälule =mälu  (SgAll  >mälu !17_S
35132	õmbleme	õmble	õmblema	30_V	IndPrPl1	et	õmbleme =õmble  (IndPrPl1  >õmblema !30_V
35146	õrn	õrn	õrn	22_A	SgN	et	õrn =õrn  (SgN  >õrn !22_A
35153	keskpaik	paik	kesk+paik	22_S	SgN	et	keskpaik =paik  (SgN  >kesk+paik !22_S
35161	torkeodadega	oda	torke+oda	17_S	PlKom	et	torkeodadega =oda  (PlKom  >torke+oda !17_S
35162	kogukondades	kogukonda	kogukond	22_S	PlIn	et	kogukondades =kogukonda  (PlIn  >kogukond !22_S
35173	liiklusteedena	tee	liiklus+tee	26_S	PlEs	et	liiklusteedena =tee  (PlEs  >liiklus+tee !26_S
35177	valmistamisvõtted	võtte	valmistamis+võte	06_S	PlN	et	valmistamisvõtted =võtte  (PlN  >valmistamis+võte !06_S
35181	neoliitikumis	neoliitikumi	neoliitikum	19_S	SgIn	et	neoliitikumis =neoliitikumi  (SgIn  >neoliitikum !19_S
35182	külili	külili	külili	41_D	ID	et	külili =külili  (ID  >külili !41_D
35184	teispoolses	poolse	teis+poolne	02_A	SgIn	et	teispoolses =poolse  (SgIn  >teis+poolne !02_A
35193	loengusele	use	loeng+usk	22_S	PlAll	et	loengusele =use  (PlAll  >loeng+usk !22_S
35206	tekstid	teksti	tekst	22_S	PlN	et	tekstid =teksti  (PlN  >tekst !22_S
35209	etnoloogidele	loogi	etno+loog	22_S	PlAll	et	etnoloogidele =loogi  (PlAll  >etno+loog !22_S
35213	kohanema	kohane	kohanema	27_V	Sup	et	kohanema =kohane  (Sup  >kohanema !27_V
35215	ehitusmeistrid	meistri	ehitus+meister	02_S	PlN	et	ehitusmeistrid =meistri  (PlN  >ehitus+meister !02_S
35231	kalapüügiga	püügi	kala+püük	22_S	SgKom	et	kalapüügiga =püügi  (SgKom  >kala+püük !22_S
35233	kalasaak	saak	kala+saak	22_S	SgN	et	kalasaak =saak  (SgN  >kala+saak !22_S
35240	lülide	lüli	lüli	17_S	PlG	et	lülide =lüli  (PlG  >lüli !17_S
35246	objektiks	objekti	objekt	22_S	SgTr	et	objektiks =objekti  (SgTr  >objekt !22_S
35251	idakalda	kalda	ida+kallas	07_S	SgG	et	idakalda =kalda  (SgG  >ida+kallas !07_S
35252	kuuseokstest	oks	kuuse+oks	23_S	PlEl	et	kuuseokstest =oks  (PlEl  >kuuse+oks !23_S
35253	püügiks	püügi	püük	22_S	SgTr	et	püügiks =püügi  (SgTr  >püük !22_S
35255	sügiseti	sügiseti	sügiseti	41_D	ID	et	sügiseti =sügiseti  (ID  >sügiseti !41_D
35257	mootorite	mootori	mootor	02_S	PlG	et	mootorite =mootori  (PlG  >mootor !02_S
35265	saagile	saagi	saak	22_S	SgAll	et	saagile =saagi  (SgAll  >saak !22_S
35266	kalurite	kaluri	kalur	02_S	PlG	et	kalurite =kaluri  (PlG  >kalur !02_S
35268	paatidel	paati	paat	22_S	PlAd	et	paatidel =paati  (PlAd  >paat !22_S
35273	ohtude	ohtu	oht	22_S	PlG	et	ohtude =ohtu  (PlG  >oht !22_S
35274	riskidega	riski	risk	22_S	PlKom	et	riskidega =riski  (PlKom  >risk !22_S
35301	üldjuhul	juhu	üld+juht	22_S	SgAd	et	üldjuhul =juhu  (SgAd  >üld+juht !22_S
35313	läänerannikul	ranniku	lääne+rannik	02_S	SgAd	et	läänerannikul =ranniku  (SgAd  >lääne+rannik !02_S
35318	elemente	elemente	element	22_S	PlP	et	elemente =elemente  (PlP  >element !22_S
35320	pruut	pruut	pruut	22_S	SgN	et	pruut =pruut  (SgN  >pruut !22_S
35321	rätik	rätik	rätik	02_S	SgN	et	rätik =rätik  (SgN  >rätik !02_S
35322	sõrmus	sõrmus	sõrmus	09_S	SgN	et	sõrmus =sõrmus  (SgN  >sõrmus !09_S
35048	mõtleme	mõtle	mõtlema	30_V	IndPrPl1	et	mõtleme =mõtle  (IndPrPl1  >mõtlema !30_V
35052	lauluid	lu	lau+luu	26_S	PlP	et	lauluid =lu  (PlP  >lau+luu !26_S
35056	eestimaalt	maa	eesti+maa	26_S	SgAbl	et	eestimaalt =maa  (SgAbl  >eesti+maa !26_S
35060	programme	programme	programm	22_S	PlP	et	programme =programme  (PlP  >programm !22_S
35062	arhiivil	arhiivi	arhiiv	22_S	SgAd	et	arhiivil =arhiivi  (SgAd  >arhiiv !22_S
35073	arutleme	arutle	arutlema	27_V	IndPrPl1	et	arutleme =arutle  (IndPrPl1  >arutlema !27_V
35078	tuletab	tuleta	tuletama	27_V	IndPrSg3	et	tuletab =tuleta  (IndPrSg3  >tuletama !27_V
35090	rahvusärkamisaeg	aeg	rahvus+ärkamis+aeg	22_S	SgN	et	rahvusärkamisaeg =aeg  (SgN  >rahvus+ärkamis+aeg !22_S
35099	põnevaks	põneva	põnev	02_A	SgTr	et	põnevaks =põneva  (SgTr  >põnev !02_A
35112	verd	ver	veri	20_S	SgP	et	verd =ver  (SgP  >veri !20_S
35113	eelnes	eelne	eelnema	27_V	IndIpfSg3	et	eelnes =eelne  (IndIpfSg3  >eelnema !27_V
35115	läbimärjad	märja	läbi+märg	22_AS	PlN	et	läbimärjad =märja  (PlN  >läbi+märg !22_AS
35128	pillisaateta	saate	pilli+saade	06_S	SgAb	et	pillisaateta =saate  (SgAb  >pilli+saade !06_S
35134	muster	muster	muster	02_S	SgN	et	muster =muster  (SgN  >muster !02_S
35136	lauluteks	lute	lau+lutt	22_S	PlTr	et	lauluteks =lute  (PlTr  >lau+lutt !22_S
35139	sõjast	sõja	sõda	18_S	SgEl	et	sõjast =sõja  (SgEl  >sõda !18_S
35141	rahvakuulturi	turi	rahva+kuul+turi	24_S	SgN	et	rahvakuulturi =turi  (SgN  >rahva+kuul+turi !24_S
35142	jalapõrutusega	põrutuse	jala+põrutus	11_S	SgKom	et	jalapõrutusega =põrutuse  (SgKom  >jala+põrutus !11_S
35143	rahvuslikke	rahvuslikke	rahvuslik	25_A	PlP	et	rahvuslikke =rahvuslikke  (PlP  >rahvuslik !25_A
35147	kuulatada	kuulata	kuulatama	27_V	Inf	et	kuulatada =kuulata  (Inf  >kuulatama !27_V
35149	laulades	la	lau+la	26_S	PlIn	et	laulades =la  (PlIn  >lau+la !26_S
35154	loodusandide	andi	loodus+and	22_S	PlG	et	loodusandide =andi  (PlG  >loodus+and !22_S
35155	korjati	korja	korjama	29_V	IndIpfIps	et	korjati =korja  (IndIpfIps  >korjama !29_V
35160	viske-	viske	vise	06_S	SgG	et	viske- =viske  (SgG  >vise !06_S
35163	püstkodades	koda	püst+koda	18_S	PlIn	et	püstkodades =koda  (PlIn  >püst+koda !18_S
35167	nahaga	naha	nahk	22_S	SgKom	et	nahaga =naha  (SgKom  >nahk !22_S
35169	mätastega	mätas	mätas	07_S	PlKom	et	mätastega =mätas  (PlKom  >mätas !07_S
35170	soojem	sooje	soe	24_AS	M_cA	et	"soojem %sooje  )M_cA  <soe ;24_AS
35172	siid	siid	siid	22_S	SgN	et	siid =siid  (SgN  >siid !22_S
35178	kivilihvimine	lihvimine	kivi+lihvimine	12_S	SgN	et	kivilihvimine =lihvimine  (SgN  >kivi+lihvimine !12_S
35179	keraamikat	keraamika	keraamika	01_S	SgP	et	keraamikat =keraamika  (SgP  >keraamika !01_S
35190	muistised	muistise	muistis	09_S	PlN	et	muistised =muistise  (PlN  >muistis !09_S
35191	õppekaardis	kaardi	õppe+kaart	22_S	SgIn	et	õppekaardis =kaardi  (SgIn  >õppe+kaart !22_S
35201	olme-perekondliku	perekondliku	olme-perekondlik	25_A	SgG	et	olme-perekondliku =perekondliku  (SgG  >olme-perekondlik !25_A
35212	hektarit	hektari	hektar	02_S	SgP	et	hektarit =hektari  (SgP  >hektar !02_S
35222	aiandusega	aianduse	aiandus	11_S	SgKom	et	aiandusega =aianduse  (SgKom  >aiandus !11_S
35223	müügiks	müügi	müük	22_S	SgTr	et	müügiks =müügi  (SgTr  >müük !22_S
35227	põllutöödel	töö	põllu+töö	26_S	PlAd	et	põllutöödel =töö  (PlAd  >põllu+töö !26_S
35229	põllumajandussaadustega	saadus	põllu+majandus+saadus	11~09_S	PlKom	et	põllumajandussaadustega =saadus  (PlKom  >põllu+majandus+saadus !11~09_S
35230	kalapüük	püük	kala+püük	22_S	SgN	et	kalapüük =püük  (SgN  >kala+püük !22_S
35234	täiustades	täiusta	täiustama	27_V	Ger	et	täiustades =täiusta  (Ger  >täiustama !27_V
35237	iseka	iseka	isekas	02_A	SgG	et	iseka =iseka  (SgG  >isekas !02_A
35239	mereks	mere	meri	20_S	SgTr	et	mereks =mere  (SgTr  >meri !20_S
35242	marsruut	marsruut	marsruut	22_S	SgN	et	marsruut =marsruut  (SgN  >marsruut !22_S
35247	liikmetele	liikme	liige	05_S	PlAll	et	liikmetele =liikme  (PlAll  >liige !05_S
35256	osteti	oste	ostma	34_V	IndIpfIps	et	osteti =oste  (IndIpfIps  >ostma !34_V
35258	sõidukeid	sõiduke	sõiduk	02_S	PlP	et	sõidukeid =sõiduke  (PlP  >sõiduk !02_S
35263	sõidukite	sõiduki	sõiduk	02_S	PlG	et	sõidukite =sõiduki  (PlG  >sõiduk !02_S
35264	jääkuhjatisi	kuhjatisi	jää+kuhjatis	11_S	PlP	et	jääkuhjatisi =kuhjatisi  (PlP  >jää+kuhjatis !11_S
35272	linnakaupu	kaupu	linna+kaup	22_S	PlP	et	linnakaupu =kaupu  (PlP  >linna+kaup !22_S
35279	lähiminevikus	mineviku	lähi+minevik	25_S	SgIn	et	lähiminevikus =mineviku  (SgIn  >lähi+minevik !25_S
35280	hädad	häda	häda	17_S	PlN	et	hädad =häda  (PlN  >häda !17_S
35287	skandaalid	skandaali	skandaal	22_S	PlN	et	skandaalid =skandaali  (PlN  >skandaal !22_S
35288	võrgud	võrgu	võrk	22_S	PlN	et	võrgud =võrgu  (PlN  >võrk !22_S
35101	printsiip	printsiip	printsiip	22_S	SgN	et	printsiip =printsiip  (SgN  >printsiip !22_S
35107	väljendub	väljendu	väljenduma	27_V	IndPrSg3	et	väljendub =väljendu  (IndPrSg3  >väljenduma !27_V
35109	valitseb	valitse	valitsema	27_V	IndPrSg3	et	valitseb =valitse  (IndPrSg3  >valitsema !27_V
35110	armuga	armu	arm	22_S	SgKom	et	armuga =armu  (SgKom  >arm !22_S
35117	laulukaare	kaare	laulu+kaar	13_S	SgG	et	laulukaare =kaare  (SgG  >laulu+kaar !13_S
35122	mängudes	mängu	mäng	22_S	PlIn	et	mängudes =mängu  (PlIn  >mäng !22_S
35125	iseseisvad	seisva	ise+seisev	02_A	PlN	et	iseseisvad =seisva  (PlN  >ise+seisev !02_A
35126	vanades	vana	vana	17_AS	PlIn	et	vanades =vana  (PlIn  >vana !17_AS
35135	kudum	kudum	kudum	02_S	SgN	et	kudum =kudum  (SgN  >kudum !02_S
35157	kalapüügiks	püügi	kala+püük	22_S	SgTr	et	kalapüügiks =püügi  (SgTr  >kala+püük !22_S
35158	ahingut	ahingu	ahing	02_S	SgP	et	ahingut =ahingu  (SgP  >ahing !02_S
35176	tulekiviesemed	eseme	tule+kivi+ese	04_S	PlN	et	tulekiviesemed =eseme  (PlN  >tule+kivi+ese !04_S
35180	segati	sega	segama	27_V	IndIpfIps	et	segati =sega  (IndIpfIps  >segama !27_V
35186	loomahambaid	hamba	looma+hammas	07_S	PlP	et	loomahambaid =hamba  (PlP  >looma+hammas !07_S
35196	teaduslik	teaduslik	teaduslik	25_A	SgN	et	teaduslik =teaduslik  (SgN  >teaduslik !25_A
35197	lääneranniku	ranniku	lääne+rannik	02_S	SgG	et	lääneranniku =ranniku  (SgG  >lääne+rannik !02_S
35200	religioosse	religioosse	religioosne	02_A	SgG	et	religioosse =religioosse  (SgG  >religioosne !02_A
35216	müüritöödel	töö	müüri+töö	26_S	PlAd	et	müüritöödel =töö  (PlAd  >müüri+töö !26_S
35228	tasuti	tasu	tasuma	27_V	IndIpfIps	et	tasuti =tasu  (IndIpfIps  >tasuma !27_V
35236	kohanedes	kohane	kohanema	27_V	Ger	et	kohanedes =kohane  (Ger  >kohanema !27_V
35243	kalapüügiriistade	riista	kala+püügi+riist	22_S	PlG	et	kalapüügiriistade =riista  (PlG  >kala+püügi+riist !22_S
35248	kalamehed	mehe	kala+mees	13_S	PlN	et	kalamehed =mehe  (PlN  >kala+mees !13_S
35260	traktori	traktori	traktor	02_S	SgG	et	traktori =traktori  (SgG  >traktor !02_S
35267	artellid	artelli	artell	22_S	PlN	et	artellid =artelli  (PlN  >artell !22_S
35269	realiseeriti	realiseeri	realiseerima	28_V	IndIpfIps	et	realiseeriti =realiseeri  (IndIpfIps  >realiseerima !28_V
35271	kaluri	kaluri	kalur	02_S	SgG	et	kaluri =kaluri  (SgG  >kalur !02_S
35282	õigsust	õigsus	õigsus	11~09_S	SgP	et	õigsust =õigsus  (SgP  >õigsus !11~09_S
35284	hiilida	hiili	hiilima	28_V	Inf	et	hiilida =hiili  (Inf  >hiilima !28_V
35302	vetevaimuga	vaimu	vete+vaim	22_S	SgKom	et	vetevaimuga =vaimu  (SgKom  >vete+vaim !22_S
35309	olendeid	olende	olend	02_S	PlP	et	olendeid =olende  (PlP  >olend !02_S
35312	juute	juute	juut	22_S	PlP	et	juute =juute  (PlP  >juut !22_S
35314	sõbramehe	mehe	sõbra+mees	13_S	SgG	et	sõbramehe =mehe  (SgG  >sõbra+mees !13_S
35315	toimingutes	toimingu	toiming	02_S	PlIn	et	toimingutes =toimingu  (PlIn  >toiming !02_S
35358	folkloorimaterjalid	materjali	folkloori+materjal	19_S	PlN	et	folkloorimaterjalid =materjali  (PlN  >folkloori+materjal !19_S
35361	kuke	kuke	kukk	22_S	SgG	et	kuke =kuke  (SgG  >kukk !22_S
35365	selletaolist	taolis	selle+taoline	12?10_A	SgP	et	selletaolist =taolis  (SgP  >selle+taoline !12?10_A
35369	leviku	leviku	levik	02_S	SgG	et	leviku =leviku  (SgG  >levik !02_S
35377	laisast	laisa	laisk	22_A	SgEl	et	laisast =laisa  (SgEl  >laisk !22_A
35384	keeleteadlaste	teadlas	keele+teadlane	12?10_S	PlG	et	keeleteadlaste =teadlas  (PlG  >keele+teadlane !12?10_S
35388	ükshaaval	ükshaaval	üks+haaval	41_D	ID	et	ükshaaval =ükshaaval  (ID  >üks+haaval !41_D
35395	panemas	pane	panema	36_V	SupIn	et	panemas =pane  (SupIn  >panema !36_V
35400	lugudest	lugu	lugu	18_S	PlEl	et	lugudest =lugu  (PlEl  >lugu !18_S
35413	viimsest	viimse	viimne	02_A	SgEl	et	viimsest =viimse  (SgEl  >viimne !02_A
35414	anus	anu	anuma	27_V	IndIpfSg3	et	anus =anu  (IndIpfSg3  >anuma !27_V
35417	tsaaritar	tsaaritar	tsaaritar	19_S	SgN	et	tsaaritar =tsaaritar  (SgN  >tsaaritar !19_S
35418	saagu	saa	saama	37_V	ImpPrPs	et	saagu =saa  (ImpPrPs  >saama !37_V
35419	sirutan	siruta	sirutama	27_V	IndPrSg1	et	sirutan =siruta  (IndPrSg1  >sirutama !27_V
35421	iidseid	iidse	iidne	02_A	PlP	et	iidseid =iidse  (PlP  >iidne !02_A
35436	trükikoopiad	koopia	trüki+koopia	01_S	PlN	et	trükikoopiad =koopia  (PlN  >trüki+koopia !01_S
35438	salmide	salmi	salm	22_S	PlG	et	salmide =salmi  (PlG  >salm !22_S
35443	lauluviis	viis	laulu+viis	22_S	SgN	et	lauluviis =viis  (SgN  >laulu+viis !22_S
35449	puhtakspestud	pestu	puhtaks+pestu	01_S	PlN	et	puhtakspestud =pestu  (PlN  >puhtaks+pestu !01_S
35451	sulased	sulase	sulane	10_S	PlN	et	sulased =sulase  (PlN  >sulane !10_S
35454	moodsas	moodsa	moodne	02_A	SgIn	et	moodsas =moodsa  (SgIn  >moodne !02_A
35105	lauludest	laulu	laul	22_S	PlEl	et	lauludest =laulu  (PlEl  >laul !22_S
35111	rahvusriik	riik	rahvus+riik	22_S	SgN	et	rahvusriik =riik  (SgN  >rahvus+riik !22_S
35116	ilmaga	ilma	ilm	22_S	SgKom	et	ilmaga =ilma  (SgKom  >ilm !22_S
35118	hetked	hetke	hetk	22_S	PlN	et	hetked =hetke  (PlN  >hetk !22_S
35120	eurovisioonile	visiooni	euro+visioon	22_S	SgAll	et	eurovisioonile =visiooni  (SgAll  >euro+visioon !22_S
35124	lauluseltsid	seltsi	laulu+selts	22_S	PlN	et	lauluseltsid =seltsi  (PlN  >laulu+selts !22_S
35127	muusikapille	pille	muusika+pill	22_S	PlP	et	muusikapille =pille  (PlP  >muusika+pill !22_S
35130	musitseeriti	musitseeri	musitseerima	28_V	IndIpfIps	et	musitseeriti =musitseeri  (IndIpfIps  >musitseerima !28_V
35133	küladest	küla	küla	17_S	PlEl	et	küladest =küla  (PlEl  >küla !17_S
35140	pidus	pidu	pidu	17_S	SgIn	et	pidus =pidu  (SgIn  >pidu !17_S
35148	rahustada	rahusta	rahustama	27_V	Inf	et	rahustada =rahusta  (Inf  >rahustama !27_V
35150	laulurahvaga	rahva	laulu+rahvas	07_S	SgKom	et	laulurahvaga =rahva  (SgKom  >laulu+rahvas !07_S
35151	tunneme	tunne	tundma	34_V	IndPrPl1	et	tunneme =tunne  (IndPrPl1  >tundma !34_V
35168	okastega	okas	okas	07_S	PlKom	et	okastega =okas  (PlKom  >okas !07_S
35171	loodusressursid	ressursi	loodus+ressurss	22_S	PlN	et	loodusressursid =ressursi  (PlN  >loodus+ressurss !22_S
35174	kiviajal	aja	kivi+aeg	22_S	SgAd	et	kiviajal =aja  (SgAd  >kivi+aeg !22_S
35175	sarvidest	sarvi	sarv	22_S	PlEl	et	sarvidest =sarvi  (PlEl  >sarv !22_S
35183	tarbeese	ese	tarbe+ese	04_S	SgN	et	tarbeese =ese  (SgN  >tarbe+ese !04_S
35187	kihvu	kihvu	kihv	22_S	PlP	et	kihvu =kihvu  (PlP  >kihv !22_S
35189	leiul	leiu	leid	22_S	SgAd	et	leiul =leiu  (SgAd  >leid !22_S
35195	käesolev	olev	käes+olev	02_A	SgN	et	käesolev =olev  (SgN  >käes+olev !02_A
35199	värsid	värsi	värss	22_S	PlN	et	värsid =värsi  (PlN  >värss !22_S
35203	kalendri-	kalendri	kalender	02_S	SgG	et	kalendri- =kalendri  (SgG  >kalender !02_S
35208	filoloogidele	filoloogi	filoloog	22_S	PlAll	et	filoloogidele =filoloogi  (PlAll  >filoloog !22_S
35210	folklooritraditsioon	traditsioon	folkloori+traditsioon	22_S	SgN	et	folklooritraditsioon =traditsioon  (SgN  >folkloori+traditsioon !22_S
35214	majandusharusid	haru	majandus+haru	17_S	PlP	et	majandusharusid =haru  (PlP  >majandus+haru !17_S
35218	ehitusmeistrite	meistri	ehitus+meister	02_S	PlG	et	ehitusmeistrite =meistri  (PlG  >ehitus+meister !02_S
35220	ehitustöödel	töö	ehitus+töö	26_S	PlAd	et	ehitustöödel =töö  (PlAd  >ehitus+töö !26_S
35221	kodumajanduses	majanduse	kodu+majandus	11_S	SgIn	et	kodumajanduses =majanduse  (SgIn  >kodu+majandus !11_S
35225	köögivilju	vilju	köögi+vili	24_S	PlP	et	köögivilju =vilju  (PlP  >köögi+vili !24_S
35226	alguseni	alguse	algus	11~09_S	SgTer	et	alguseni =alguse  (SgTer  >algus !11~09_S
35232	peredes	pere	pere	16_S	PlIn	et	peredes =pere  (PlIn  >pere !16_S
35238	loomuga	loomu	loom	22_S	SgKom	et	loomuga =loomu  (SgKom  >loom !22_S
35244	kalaliigist	liigi	kala+liik	22_S	SgEl	et	kalaliigist =liigi  (SgEl  >kala+liik !22_S
35250	imestamapanevat	paneva	imestama+panev	02_A	SgP	et	imestamapanevat =paneva  (SgP  >imestama+panev !02_A
35254	lube	lube	luba	18_S	PlP	et	lube =lube  (PlP  >luba !18_S
35270	tagasiteel	tee	tagasi+tee	26_S	SgAd	et	tagasiteel =tee  (SgAd  >tagasi+tee !26_S
35275	ebaõnn	õnn	eba+õnn	22_S	SgN	et	ebaõnn =õnn  (SgN  >eba+õnn !22_S
35276	kõuerohkeks	rohke	kõue+rohke	01_A	SgTr	et	kõuerohkeks =rohke  (SgTr  >kõue+rohke !01_A
35277	kaasani	kaasa	kaasa	16_S	SgTer	et	kaasani =kaasa  (SgTer  >kaasa !16_S
35281	ebausu	usu	eba+usk	22_S	SgG	et	ebausu =usu  (SgG  >eba+usk !22_S
35285	kalale	kala	kala	17_S	SgAll	et	kalale =kala  (SgAll  >kala !17_S
35286	vaidluste	vaidlus	vaidlus	11~09_S	PlG	et	vaidluste =vaidlus  (PlG  >vaidlus !11~09_S
35290	vilistada	vilista	vilistama	27_V	Inf	et	vilistada =vilista  (Inf  >vilistama !27_V
35292	paat	paat	paat	22_S	SgN	et	paat =paat  (SgN  >paat !22_S
35294	väljaminekut	mineku	välja+minek	02_S	SgP	et	väljaminekut =mineku  (SgP  >välja+minek !02_S
35296	lääs	lääs	lääs	14_S	SgN	et	lääs =lääs  (SgN  >lääs !14_S
35297	imestama	imesta	imestama	27_V	Sup	et	imestama =imesta  (Sup  >imestama !27_V
35300	väljamõeldisse	mõeldis	välja+mõeldis	11_S	SgAdt	et	väljamõeldisse =mõeldis  (SgAdt  >välja+mõeldis !11_S
35304	näkineidudest	neidu	näki+neid	22_S	PlEl	et	näkineidudest =neidu  (PlEl  >näki+neid !22_S
35308	ohtlikuks	ohtliku	ohtlik	25_A	SgTr	et	ohtlikuks =ohtliku  (SgTr  >ohtlik !25_A
35317	külades	küla	küla	17_S	PlIn	et	külades =küla  (PlIn  >küla !17_S
35319	kinnitades	kinnita	kinnitama	27_V	Ger	et	kinnitades =kinnita  (Ger  >kinnitama !27_V
35325	kimbu	kimbu	kimp	22_S	SgG	et	kimbu =kimbu  (SgG  >kimp !22_S
35329	sümbolite	sümboli	sümbol	02_S	PlG	et	sümbolite =sümboli  (PlG  >sümbol !02_S
35205	nõiasõnad	sõna	nõia+sõna	17_S	PlN	et	nõiasõnad =sõna  (PlN  >nõia+sõna !17_S
35207	kogumik	kogumik	kogumik	25_S	SgN	et	kogumik =kogumik  (SgN  >kogumik !25_S
35211	saabudes	saabu	saabuma	27_V	Ger	et	saabudes =saabu  (Ger  >saabuma !27_V
35217	mõisates	mõisa	mõis	02_S	PlIn	et	mõisates =mõisa  (PlIn  >mõis !02_S
35219	tsaariajal	aja	tsaari+aeg	22_S	SgAd	et	tsaariajal =aja  (SgAd  >tsaari+aeg !22_S
35224	kurke	kurke	kurk	22_S	PlP	et	kurke =kurke  (PlP  >kurk !22_S
35235	kalapüügiriistu	riistu	kala+püügi+riist	22_S	PlP	et	kalapüügiriistu =riistu  (PlP  >kala+püügi+riist !22_S
35241	artellide	artelli	artell	22_S	PlG	et	artellide =artelli  (PlG  >artell !22_S
35245	parajasti	parajasti	parajasti	41_D	ID	et	parajasti =parajasti  (ID  >parajasti !41_D
35249	alistades	alista	alistama	27_V	Ger	et	alistades =alista  (Ger  >alistama !27_V
35259	mootorrattaid	ratta	mootor+ratas	07_S	PlP	et	mootorrattaid =ratta  (PlP  >mootor+ratas !07_S
35261	võistlusi	võistlusi	võistlus	11_S	PlP	et	võistlusi =võistlusi  (PlP  >võistlus !11_S
35262	isetehtud	tehtu	ise+tehtu	01_S	PlN	et	isetehtud =tehtu  (PlN  >ise+tehtu !01_S
35278	kalur	kalur	kalur	02_S	SgN	et	kalur =kalur  (SgN  >kalur !02_S
35283	eelistades	eelista	eelistama	27_V	Ger	et	eelistades =eelista  (Ger  >eelistama !27_V
35289	tühjaks	tühja	tühi	24_A	SgTr	et	tühjaks =tühja  (SgTr  >tühi !24_A
35295	tuultelegi	tuul	tuul	13_S	PlAll^	et	tuultelegi =tuul  (PlAll^  >tuul !13_S
35299	kirjapanekutes	paneku	kirja+panek	02_S	PlIn	et	kirjapanekutes =paneku  (PlIn  >kirja+panek !02_S
35303	vetevaim	vaim	vete+vaim	22_S	SgN	et	vetevaim =vaim  (SgN  >vete+vaim !22_S
35305	tiheda	tiheda	tihe	02_A	SgG	et	tiheda =tiheda  (SgG  >tihe !02_A
35316	kõrvutades	kõrvuta	kõrvutama	27_V	Ger	et	kõrvutades =kõrvuta  (Ger  >kõrvutama !27_V
35326	lintidega	linti	lint	22_S	PlKom	et	lintidega =linti  (PlKom  >lint !22_S
35327	valas	vala	valama	27_V	IndIpfSg3	et	valas =vala  (IndIpfSg3  >valama !27_V
35332	idarannikul	ranniku	ida+rannik	02_S	SgAd	et	idarannikul =ranniku  (SgAd  >ida+rannik !02_S
35334	ülistuslaulud	laulu	ülistus+laul	22_S	PlN	et	ülistuslaulud =laulu  (PlN  >ülistus+laul !22_S
35337	ülistati	ülista	ülistama	27_V	IndIpfIps	et	ülistati =ülista  (IndIpfIps  >ülistama !27_V
35338	kaks-kolm	kolm	kaks-kolm	22_N	SgN	et	kaks-kolm =kolm  (SgN  >kaks-kolm !22_N
35345	pruudist	pruudi	pruut	22_S	SgEl	et	pruudist =pruudi  (SgEl  >pruut !22_S
35348	mineraalveega	vee	mineraal+vesi	15_S	SgKom	et	mineraalveega =vee  (SgKom  >mineraal+vesi !15_S
35364	vaimulikke	vaimulikke	vaimulik	25_AS	PlP	et	vaimulikke =vaimulikke  (PlP  >vaimulik !25_AS
35366	muinasjuttudega	juttu	muinas+jutt	22_S	PlKom	et	muinasjuttudega =juttu  (PlKom  >muinas+jutt !22_S
35367	tavandeid	tavande	tavand	02_S	PlP	et	tavandeid =tavande  (PlP  >tavand !02_S
35374	olustiku	olustiku	olustik	25_S	SgG	et	olustiku =olustiku  (SgG  >olustik !25_S
35376	abielunaisest	naise	abi+elu+naine	12_S	SgEl	et	abielunaisest =naise  (SgEl  >abi+elu+naine !12_S
35382	legende	legende	legend	22_S	PlP	et	legende =legende  (PlP  >legend !22_S
35387	puistas	puista	puistama	29_V	IndIpfSg3	et	puistas =puista  (IndIpfSg3  >puistama !29_V
35389	käputäiega	täie	käpu+täis	14_AS	SgKom	et	käputäiega =täie  (SgKom  >käpu+täis !14_AS
35391	tegelaskujudest	kuju	tegelas+kuju	17_S	PlEl	et	tegelaskujudest =kuju  (PlEl  >tegelas+kuju !17_S
35392	jutud	jutu	jutt	22_S	PlN	et	jutud =jutu  (PlN  >jutt !22_S
35396	tänades	täna	tänama	27_V	Ger	et	tänades =täna  (Ger  >tänama !27_V
35397	pühakut	pühaku	pühak	02_S	SgP	et	pühakut =pühaku  (SgP  >pühak !02_S
35401	kujutist	kujutis	kujutis	11_S	SgP	et	kujutist =kujutis  (SgP  >kujutis !11_S
35424	arusaamal	saama	aru+saam	22_S	SgAd	et	arusaamal =saama  (SgAd  >aru+saam !22_S
35429	jälitades	jälita	jälitama	27_V	Ger	et	jälitades =jälita  (Ger  >jälitama !27_V
35430	sattub	sattu	sattuma	27_V	IndPrSg3	et	sattub =sattu  (IndPrSg3  >sattuma !27_V
35444	tüüpilisi	tüüpilisi	tüüpiline	12_A	PlP	et	tüüpilisi =tüüpilisi  (PlP  >tüüpiline !12_A
35446	religioossetes	religioosse	religioosne	02_A	PlIn	et	religioossetes =religioosse  (PlIn  >religioosne !02_A
35448	pühakojas	koja	püha+koda	18_S	SgIn	et	pühakojas =koja  (SgIn  >püha+koda !18_S
35452	heideti	heide	heitma	34_V	IndIpfIps	et	heideti =heide  (IndIpfIps  >heitma !34_V
35464	ninaossa	ossa	nina+osa	17_S	SgAdt	et	ninaossa =ossa  (SgAdt  >nina+osa !17_S
35466	eelmise	eelmise	eelmine	12?10_A	SgG	et	eelmise =eelmise  (SgG  >eelmine !12?10_A
35472	kodukiriku	kiriku	kodu+kirik	02_S	SgG	et	kodukiriku =kiriku  (SgG  >kodu+kirik !02_S
35474	jumalateenistusega	teenistuse	jumala+teenistus	11_S	SgKom	et	jumalateenistusega =teenistuse  (SgKom  >jumala+teenistus !11_S
35475	pajuoksad	oksa	paju+oks	23?22_S	PlN	et	pajuoksad =oksa  (PlN  >paju+oks !23?22_S
35291	koorik	koorik	koorik	02_S	SgN	et	koorik =koorik  (SgN  >koorik !02_S
35293	toiminguid	toimingu	toiming	02_S	PlP	et	toiminguid =toimingu  (PlP  >toiming !02_S
35298	arhiivimaterjalides	materjali	arhiivi+materjal	19_S	PlIn	et	arhiivimaterjalides =materjali  (PlIn  >arhiivi+materjal !19_S
35306	mägede	mäge	mägi	21_S	PlG	et	mägede =mäge  (PlG  >mägi !21_S
35307	urgudes	urgu	urg	22_S	PlIn	et	urgudes =urgu  (PlIn  >urg !22_S
35310	ida-slaavlaste	slaavlas	ida-slaavlane	12?10_S	PlG	et	ida-slaavlaste =slaavlas  (PlG  >ida-slaavlane !12?10_S
35311	seostatakse	seosta	seostama	27_V	IndPrIps	et	seostatakse =seosta  (IndPrIps  >seostama !27_V
35330	ausa	ausa	aus	02_A	SgG	et	ausa =ausa  (SgG  >aus !02_A
35341	eripäraks	pära	eri+pära	17_S	SgTr	et	eripäraks =pära  (SgTr  >eri+pära !17_S
35342	motiivide	motiivi	motiiv	22_S	PlG	et	motiivide =motiivi  (PlG  >motiiv !22_S
35349	peigmehe	mehe	peig+mees	13_S	SgG	et	peigmehe =mehe  (SgG  >peig+mees !13_S
35353	patside	patsi	pats	22_S	PlG	et	patside =patsi  (PlG  >pats !22_S
35354	trepiastme	astme	trepi+aste	05_S	SgG	et	trepiastme =astme  (SgG  >trepi+aste !05_S
35359	küsitlusleht	leht	küsitlus+leht	22_S	SgN	et	küsitlusleht =leht  (SgN  >küsitlus+leht !22_S
35363	meenutati	meenuta	meenutama	27_V	IndIpfIps	et	meenutati =meenuta  (IndIpfIps  >meenutama !27_V
35371	esmajoones	esmajoones	esma+joones	41_D	ID	et	esmajoones =esmajoones  (ID  >esma+joones !41_D
35375	rahvaanekdoodid	anekdoodi	rahva+anekdoot	22_S	PlN	et	rahvaanekdoodid =anekdoodi  (PlN  >rahva+anekdoot !22_S
35379	vahepealse	pealse	vahe+pealne	02_AS	SgG	et	vahepealse =pealse  (SgG  >vahe+pealne !02_AS
35390	kristlikest	kristlike	kristlik	25_A	PlEl	et	kristlikest =kristlike  (PlEl  >kristlik !25_A
35393	palvelas	palvela	palvela	01_S	SgIn	et	palvelas =palvela  (SgIn  >palvela !01_S
35403	võtme	võtme	võti	05_S	SgG	et	võtme =võtme  (SgG  >võti !05_S
35405	kuratlikke	kuratlikke	kuratlik	25_A	PlP	et	kuratlikke =kuratlikke  (PlP  >kuratlik !25_A
35409	ülemaailmsest	ilmse	üle+maa+ilmne	02_A	SgEl	et	ülemaailmsest =ilmse  (SgEl  >üle+maa+ilmne !02_A
35410	elulugudel	lugu	elu+lugu	18_S	PlAd	et	elulugudel =lugu  (PlAd  >elu+lugu !18_S
35433	mainita	maini	mainima	28_V	IndPrIps_	et	mainita =maini  (IndPrIps_  >mainima !28_V
35434	värssideks	värssi	värss	22_S	PlTr	et	värssideks =värssi  (PlTr  >värss !22_S
35445	stereotüüpe	stereotüüpe	stereotüüp	22_S	PlP	et	stereotüüpe =stereotüüpe  (PlP  >stereotüüp !22_S
35450	viirukiga	viiruki	viiruk	02_S	SgKom	et	viirukiga =viiruki  (SgKom  >viiruk !02_S
35460	maailmatunnetusega	tunnetuse	maa+ilma+tunnetus	11_S	SgKom	et	maailmatunnetusega =tunnetuse  (SgKom  >maa+ilma+tunnetus !11_S
35478	kirikupühadega	püha	kiriku+püha	17_SA	PlKom	et	kirikupühadega =püha  (PlKom  >kiriku+püha !17_SA
35482	pesed	pese	pesema	36_V	IndPrSg2	et	pesed =pese  (IndPrSg2  >pesema !36_V
35484	anumates	anuma	anum	02_S	PlIn	et	anumates =anuma  (PlIn  >anum !02_S
35489	ämblik	ämblik	ämblik	25_S	SgN	et	ämblik =ämblik  (SgN  >ämblik !25_S
35491	koopa	koopa	koobas	07_S	SgG	et	koopa =koopa  (SgG  >koobas !07_S
35495	patte	patte	patt	22_S	PlP	et	patte =patte  (PlP  >patt !22_S
35497	kinnitatakse	kinnita	kinnitama	27_V	IndPrIps	et	kinnitatakse =kinnita  (IndPrIps  >kinnitama !27_V
35501	lahtiütlemine	ütlemine	lahti+ütlemine	12_S	SgN	et	lahtiütlemine =ütlemine  (SgN  >lahti+ütlemine !12_S
35503	vargus	vargus	vargus	11~09_S	SgN	et	vargus =vargus  (SgN  >vargus !11~09_S
35510	kujundid	kujundi	kujund	02_S	PlN	et	kujundid =kujundi  (PlN  >kujund !02_S
35516	hoiatab	hoiata	hoiatama	27_V	IndPrSg3	et	hoiatab =hoiata  (IndPrSg3  >hoiatama !27_V
35519	nõial	nõia	nõid	22_S	SgAd	et	nõial =nõia  (SgAd  >nõid !22_S
35523	ussidele	ussi	uss	22_S	PlAll	et	ussidele =ussi  (PlAll  >uss !22_S
35525	kodule	kodu	kodu	17_S	SgAll	et	kodule =kodu  (SgAll  >kodu !17_S
35526	lihavõttesaiad	saia	liha+võtte+sai	22_S	PlN	et	lihavõttesaiad =saia  (PlN  >liha+võtte+sai !22_S
35531	arusaamadega	saama	aru+saam	22_S	PlKom	et	arusaamadega =saama  (PlKom  >aru+saam !22_S
35537	kuradit	kuradi	kurat	02_S	SgP	et	kuradit =kuradi  (SgP  >kurat !02_S
35542	rasedusajaga	aja	rasedus+aeg	22_S	SgKom	et	rasedusajaga =aja  (SgKom  >rasedus+aeg !22_S
35548	puudutada	puuduta	puudutama	27_V	Inf	et	puudutada =puuduta  (Inf  >puudutama !27_V
35551	nimepanemise	panemise	nime+panemine	12_S	SgG	et	nimepanemise =panemise  (SgG  >nime+panemine !12_S
35561	lepivad	lepi	leppima	28_V	IndPrPl3	et	lepivad =lepi  (IndPrPl3  >leppima !28_V
35570	tavandid	tavandi	tavand	02_S	PlN	et	tavandid =tavandi  (PlN  >tavand !02_S
35572	õmmeldakse	õmmel	õmblema	30_V	IndPrIps	et	õmmeldakse =õmmel  (IndPrIps  >õmblema !30_V
35574	lastakse	las	laskma	34_V	IndPrIps	et	lastakse =las  (IndPrIps  >laskma !34_V
35578	kodukülas	küla	kodu+küla	17_S	SgIn	et	kodukülas =küla  (SgIn  >kodu+küla !17_S
35323	ese	ese	ese	04_S	SgN	et	ese =ese  (SgN  >ese !04_S
35324	pruudile	pruudi	pruut	22_S	SgAll	et	pruudile =pruudi  (SgAll  >pruut !22_S
35328	saunakividele	kivi	sauna+kivi	17_S	PlAll	et	saunakividele =kivi  (PlAll  >sauna+kivi !17_S
35335	ülistuslaulude	laulu	ülistus+laul	22_S	PlG	et	ülistuslaulude =laulu  (PlG  >ülistus+laul !22_S
35336	pulmalauludele	laulu	pulma+laul	22_S	PlAll	et	pulmalauludele =laulu  (PlAll  >pulma+laul !22_S
35339	naerdi	naer	naerma	33_V	IndIpfIps	et	naerdi =naer  (IndIpfIps  >naerma !33_V
35340	regioonis	regiooni	regioon	22_S	SgIn	et	regioonis =regiooni  (SgIn  >regioon !22_S
35346	jumalateenistust	teenistus	jumala+teenistus	11_S	SgP	et	jumalateenistust =teenistus  (SgP  >jumala+teenistus !11_S
35347	pudeliga	pudeli	pudel	02_S	SgKom	et	pudeliga =pudeli  (SgKom  >pudel !02_S
35351	kergitama	kergita	kergitama	27_V	Sup	et	kergitama =kergita  (Sup  >kergitama !27_V
35352	pruudi	pruudi	pruut	22_S	SgG	et	pruudi =pruudi  (SgG  >pruut !22_S
35355	juhuseid	juhuse	juhus	09_S	PlP	et	juhuseid =juhuse  (PlP  >juhus !09_S
35356	pruute	pruute	pruut	22_S	PlP	et	pruute =pruute  (PlP  >pruut !22_S
35370	kohalikes	kohalike	kohalik	25_AS	PlIn	et	kohalikes =kohalike  (PlIn  >kohalik !25_AS
35372	kubermangus	kubermangu	kubermang	22_S	SgIn	et	kubermangus =kubermangu  (SgIn  >kubermang !22_S
35373	raame	raame	raam	22_S	PlP	et	raame =raame  (PlP  >raam !22_S
35378	võlumuinasjutu	jutu	võlu+muinas+jutt	22_S	SgG	et	võlumuinasjutu =jutu  (SgG  >võlu+muinas+jutt !22_S
35383	segased	segase	segane	10_A	PlN	et	segased =segase  (PlN  >segane !10_A
35385	artiklitel	artikli	artikkel	02_S	PlAd	et	artiklitel =artikli  (PlAd  >artikkel !02_S
35398	legendide	legendi	legend	22_S	PlG	et	legendide =legendi  (PlG  >legend !22_S
35399	piibli	piibli	piibel	02_S	SgG	et	piibli =piibli  (SgG  >piibel !02_S
35404	ilmalikke	ilmalikke	ilmalik	25_A	PlP	et	ilmalikke =ilmalikke  (PlP  >ilmalik !25_A
35407	argipäeviti	argipäeviti	argi+päeviti	41_D	ID	et	argipäeviti =argipäeviti  (ID  >argi+päeviti !41_D
35411	jüngritest	jüngri	jünger	02_S	PlEl	et	jüngritest =jüngri  (PlEl  >jünger !02_S
35412	värss	värss	värss	22_S	SgN	et	värss =värss  (SgN  >värss !22_S
35416	värsisüsteem	süsteem	värsi+süsteem	22_S	SgN	et	värsisüsteem =süsteem  (SgN  >värsi+süsteem !22_S
35423	noorest	noore	noor	13_AS	SgEl	et	noorest =noore  (SgEl  >noor !13_AS
35425	maailmades	ilma	maa+ilm	22_S	PlIn	et	maailmades =ilma  (PlIn  >maa+ilm !22_S
35426	võlumuinasjutte	jutte	võlu+muinas+jutt	22_S	PlP	et	võlumuinasjutte =jutte  (PlP  >võlu+muinas+jutt !22_S
35427	rahvajutte	jutte	rahva+jutt	22_S	PlP	et	rahvajutte =jutte  (PlP  >rahva+jutt !22_S
35428	rännakust	rännaku	rännak	02_S	SgEl	et	rännakust =rännaku  (SgEl  >rännak !02_S
35431	tunniks	tunni	tund	22_S	SgTr	et	tunniks =tunni  (SgTr  >tund !22_S
35435	värsside	värssi	värss	22_S	PlG	et	värsside =värssi  (PlG  >värss !22_S
35439	väljajätmises	jätmise	välja+jätmine	12?10_S	SgIn	et	väljajätmises =jätmise  (SgIn  >välja+jätmine !12?10_S
35447	palvega	palve	palve	06_S	SgKom	et	palvega =palve  (SgKom  >palve !06_S
35453	jumalateenistusele	teenistuse	jumala+teenistus	11_S	SgAll	et	jumalateenistusele =teenistuse  (SgAll  >jumala+teenistus !11_S
35459	jõi	jõ	jooma	38_V	IndIpfSg3	et	jõi =jõ  (IndIpfSg3  >jooma !38_V
35461	rahvatavandid	tavandi	rahva+tavand	02_S	PlN	et	rahvatavandid =tavandi  (PlN  >rahva+tavand !02_S
35467	ulutöödelt	töö	ulu+töö	26_S	PlAbl	et	ulutöödelt =töö  (PlAbl  >ulu+töö !26_S
35471	pühaga	püha	püha	17_SA	SgKom	et	pühaga =püha  (SgKom  >püha !17_SA
35473	lõpetati	lõpeta	lõpetama	27_V	IndIpfIps	et	lõpetati =lõpeta  (IndIpfIps  >lõpetama !27_V
35476	põllu-	põllu	põld	22_S	SgG	et	põllu- =põllu  (SgG  >põld !22_S
35479	istutati	istuta	istutama	27_V	IndIpfIps	et	istutati =istuta  (IndIpfIps  >istutama !27_V
35485	supleks	suple	suplema	30_V	KndPrPs	et	supleks =suple  (KndPrPs  >suplema !30_V
35494	traditsioonileselt	lese	traditsiooni+lesk	22_S	SgAbl	et	traditsioonileselt =lese  (SgAbl  >traditsiooni+lesk !22_S
35500	ikoonide	ikooni	ikoon	22_S	PlG	et	ikoonide =ikooni  (PlG  >ikoon !22_S
35502	müük	müük	müük	22_S	SgN	et	müük =müük  (SgN  >müük !22_S
35505	purjuspäi	purjuspäi	purjus+päi	41_D	ID	et	purjuspäi =purjuspäi  (ID  >purjus+päi !41_D
35507	eluohtlikke	ohtlikke	elu+ohtlik	25_A	PlP	et	eluohtlikke =ohtlikke  (PlP  >elu+ohtlik !25_A
35511	paganlikega	paganlike	paganlik	25_A	PlKom	et	paganlikega =paganlike  (PlKom  >paganlik !25_A
35521	mindi	min	minema	36_V	IndIpfIps	et	mindi =min  (IndIpfIps  >minema !36_V
35529	võpatab	võpata	võpatama	27_V	IndPrSg3	et	võpatab =võpata  (IndPrSg3  >võpatama !27_V
35544	tsükkel	tsükkel	tsükkel	02_S	SgN	et	tsükkel =tsükkel  (SgN  >tsükkel !02_S
35331	pulmakomete	e	pulma+kom+esi	15_S	PlG	et	pulmakomete =e  (PlG  >pulma+kom+esi !15_S
35333	rannakülades	küla	ranna+küla	17_S	PlIn	et	rannakülades =küla  (PlIn  >ranna+küla !17_S
35343	viinapudeliga	pudeli	viina+pudel	02_S	SgKom	et	viinapudeliga =pudeli  (SgKom  >viina+pudel !02_S
35344	alustama	alusta	alustama	27_V	Sup	et	alustama =alusta  (Sup  >alustama !27_V
35350	kukrut	kukru	kukkur	02_S	SgP	et	kukrut =kukru  (SgP  >kukkur !02_S
35357	vargsi	vargsi	vargsi	41_D	ID	et	vargsi =vargsi  (ID  >vargsi !41_D
35360	vestluskaaslane	kaaslane	vestlus+kaaslane	12?10_S	SgN	et	vestluskaaslane =kaaslane  (SgN  >vestlus+kaaslane !12?10_S
35362	teradega	tera	tera	17_S	PlKom	et	teradega =tera  (PlKom  >tera !17_S
35368	pajatades	pajata	pajatama	27_V	Ger	et	pajatades =pajata  (Ger  >pajatama !27_V
35380	tekstides	teksti	tekst	22_S	PlIn	et	tekstides =teksti  (PlIn  >tekst !22_S
35381	kohalik	kohalik	kohalik	25_AS	SgN	et	kohalik =kohalik  (SgN  >kohalik !25_AS
35386	rahvarohketes	rohke	rahva+rohke	01_A	PlIn	et	rahvarohketes =rohke  (PlIn  >rahva+rohke !01_A
35394	küünalt	küünal	küünal	08_S	SgP	et	küünalt =küünal  (SgP  >küünal !08_S
35402	maailmatunnetus	tunnetus	maa+ilma+tunnetus	11_S	SgN	et	maailmatunnetus =tunnetus  (SgN  >maa+ilma+tunnetus !11_S
35406	pühade	püha	püha	17_SA	PlG	et	pühade =püha  (PlG  >püha !17_SA
35408	testamendist	testamendi	testament	22_S	SgEl	et	testamendist =testamendi  (SgEl  >testament !22_S
35415	hiljaaegu	hiljaaegu	hilja+aegu	41_D	ID	et	hiljaaegu =hiljaaegu  (ID  >hilja+aegu !41_D
35420	katteks	katte	kate	06_S	SgTr	et	katteks =katte  (SgTr  >kate !06_S
35422	kujundeid	kujunde	kujund	02_S	PlP	et	kujundeid =kujunde  (PlP  >kujund !02_S
35432	möödub	möödu	mööduma	27_V	IndPrSg3	et	möödub =möödu  (IndPrSg3  >mööduma !27_V
35437	koopiates	koopia	koopia	01_S	PlIn	et	koopiates =koopia  (PlIn  >koopia !01_S
35440	väljendite	väljendi	väljend	02_S	PlG	et	väljendite =väljendi  (PlG  >väljend !02_S
35441	kirikuviisidel	viisi	kiriku+viis	22_S	PlAd	et	kirikuviisidel =viisi  (PlAd  >kiriku+viis !22_S
35442	lüüriliste	lüürilis	lüüriline	12_A	PlG	et	lüüriliste =lüürilis  (PlG  >lüüriline !12_A
35455	mantlis	mantli	mantel	02_S	SgIn	et	mantlis =mantli  (SgIn  >mantel !02_S
35457	vältimaks	välti	vältima	28_V	SupTr	et	vältimaks =välti  (SupTr  >vältima !28_V
35458	ilmalikud	ilmaliku	ilmalik	25_A	PlN	et	ilmalikud =ilmaliku  (PlN  >ilmalik !25_A
35465	imetegijale	tegija	ime+tegija	01_S	SgAll	et	imetegijale =tegija  (SgAll  >ime+tegija !01_S
35469	pühakojale	koja	püha+koda	18_S	SgAll	et	pühakojale =koja  (SgAll  >püha+koda !18_S
35487	kuradiga	kuradi	kurat	02_S	SgKom	et	kuradiga =kuradi  (SgKom  >kurat !02_S
35490	maskeeris	maskeeri	maskeerima	28_V	IndIpfSg3	et	maskeeris =maskeeri  (IndIpfSg3  >maskeerima !28_V
35499	halbade	halba	halb	22_A	PlG	et	halbade =halba  (PlG  >halb !22_A
35504	joodikutest	joodiku	joodik	02_SA	PlEl	et	joodikutest =joodiku  (PlEl  >joodik !02_SA
35506	seavad	sea	seadma	34_V	IndPrPl3	et	seavad =sea  (IndPrPl3  >seadma !34_V
35508	olukordadesse	korda	olu+kord	22_S	PlIll	et	olukordadesse =korda  (PlIll  >olu+kord !22_S
35512	rahvalausumiste	lausumis	rahva+lausumine	12_S	PlG	et	rahvalausumiste =lausumis  (PlG  >rahva+lausumine !12_S
35515	majavaim	vaim	maja+vaim	22_S	SgN	et	majavaim =vaim  (SgN  >maja+vaim !22_S
35524	puukidele	puuki	puuk	22_S	PlAll	et	puukidele =puuki  (PlAll  >puuk !22_S
35527	siledad	sileda	sile	02_A	PlN	et	siledad =sileda  (PlN  >sile !02_A
35534	nimele	nime	nimi	20_S	SgAll	et	nimele =nime  (SgAll  >nimi !20_S
35538	vaenlane	vaenlane	vaenlane	12?10_S	SgN	et	vaenlane =vaenlane  (SgN  >vaenlane !12?10_S
35539	ketser	ketser	ketser	02_S	SgN	et	ketser =ketser  (SgN  >ketser !02_S
35540	kihtide	kihti	kiht	22_S	PlG	et	kihtide =kihti  (PlG  >kiht !22_S
35550	järgida	järgi	järgima	27_V	Inf	et	järgida =järgi  (Inf  >järgima !27_V
35552	kaitsja-ingel	ingel	kaitsja-ingel	02_S	SgN	et	kaitsja-ingel =ingel  (SgN  >kaitsja-ingel !02_S
35560	usul	usu	usk	22_S	SgAd	et	usul =usu  (SgAd  >usk !22_S
35566	patuta	patu	patt	22_S	SgAb	et	patuta =patu  (SgAb  >patt !22_S
35575	rättidel	rätti	rätt	22_S	PlAd	et	rättidel =rätti  (PlAd  >rätt !22_S
35576	viljateraga	tera	vilja+tera	17_S	SgKom	et	viljateraga =tera  (SgKom  >vilja+tera !17_S
35581	tülitama	tülita	tülitama	27_V	Sup	et	tülitama =tülita  (Sup  >tülitama !27_V
35582	ilmsi	ilmsi	ilmsi	41_D	ID	et	ilmsi =ilmsi  (ID  >ilmsi !41_D
35583	ligidasi	ligidasi	ligidane	12_A	PlP	et	ligidasi =ligidasi  (PlP  >ligidane !12_A
35587	kalmistult	kalmistu	kalmistu	01_S	SgAbl	et	kalmistult =kalmistu  (SgAbl  >kalmistu !01_S
35588	kirstud	kirstu	kirst	22_S	PlN	et	kirstud =kirstu  (PlN  >kirst !22_S
35589	haruldased	haruldase	haruldane	12_A	PlN	et	haruldased =haruldase  (PlN  >haruldane !12_A
35456	lõhikuga	lõhiku	lõhik	02_S	SgKom	et	lõhikuga =lõhiku  (SgKom  >lõhik !02_S
35462	kalurid	kaluri	kalur	02_S	PlN	et	kalurid =kaluri  (PlN  >kalur !02_S
35463	paatide	paati	paat	22_S	PlG	et	paatide =paati  (PlG  >paat !22_S
35468	kinkida	kinki	kinkima	28_V	Inf	et	kinkida =kinki  (Inf  >kinkima !28_V
35470	tuletõrjeühingu	ühingu	tule+tõrje+ühing	02_S	SgG	et	tuletõrjeühingu =ühingu  (SgG  >tule+tõrje+ühing !02_S
35480	ilmaennustus	ennustus	ilma+ennustus	11_S	SgN	et	ilmaennustus =ennustus  (SgN  >ilma+ennustus !11_S
35513	variantides	varianti	variant	22_S	PlIn	et	variantides =varianti  (PlIn  >variant !22_S
35517	äratab	ärata	äratama	27_V	IndPrSg3	et	äratab =ärata  (IndPrSg3  >äratama !27_V
35518	unest	une	uni	20_S	SgEl	et	unest =une  (SgEl  >uni !20_S
35522	metsaga	metsa	mets	22_S	SgKom	et	metsaga =metsa  (SgKom  >mets !22_S
35528	uskumus	uskumus	uskumus	11_S	SgN	et	uskumus =uskumus  (SgN  >uskumus !11_S
35532	keeld	keeld	keeld	22_S	SgN	et	keeld =keeld  (SgN  >keeld !22_S
35541	perekonnatavades	tava	pere+konna+tava	17_S	PlIn	et	perekonnatavades =tava  (PlIn  >pere+konna+tava !17_S
35546	vältima	välti	vältima	28_V	Sup	et	vältima =välti  (Sup  >vältima !28_V
35554	võlumuinasjuttudest	juttu	võlu+muinas+jutt	22_S	PlEl	et	võlumuinasjuttudest =juttu  (PlEl  >võlu+muinas+jutt !22_S
35563	süles	süle	süli	20_S	SgIn	et	süles =süle  (SgIn  >süli !20_S
35568	valgevenes	vene	valge+vene	16_S	SgIn	et	valgevenes =vene  (SgIn  >valge+vene !16_S
35569	matuse	matuse	matus	09_S	SgG	et	matuse =matuse  (SgG  >matus !09_S
35573	suririided	riide	suri+riie	06_S	PlN	et	suririided =riide  (PlN  >suri+riie !06_S
35577	hõljub	hõlju	hõljuma	28_V	IndPrSg3	et	hõljub =hõlju  (IndPrSg3  >hõljuma !28_V
35593	siinkandis	siinkandis	siin+kandis	41_D	ID	et	siinkandis =siinkandis  (ID  >siin+kandis !41_D
35594	matustel	matus	matus	09_S	PlAd	et	matustel =matus  (PlAd  >matus !09_S
35598	näed	näe	nägema	28_V	IndPrSg2	et	näed =näe  (IndPrSg2  >nägema !28_V
35600	keldrisse	keldri	kelder	02_S	SgIll	et	keldrisse =keldri  (SgIll  >kelder !02_S
35602	seebile	seebi	seep	22_S	SgAll	et	seebile =seebi  (SgAll  >seep !22_S
35605	enesetapjaid	tapja	enese+tapja	01_S	PlP	et	enesetapjaid =tapja  (PlP  >enese+tapja !01_S
35609	kehaga	keha	keha	17_S	SgKom	et	kehaga =keha  (SgKom  >keha !17_S
35610	värava	värava	värav	02_S	SgG	et	värava =värava  (SgG  >värav !02_S
35611	väravad	värava	värav	02_S	PlN	et	väravad =värava  (PlN  >värav !02_S
35617	näitlik	näitlik	näitlik	25_A	SgN	et	näitlik =näitlik  (SgN  >näitlik !25_A
35618	avastab	avasta	avastama	27_V	IndPrSg3	et	avastab =avasta  (IndPrSg3  >avastama !27_V
35623	kahhelplaadil	plaadi	kahhel+plaat	22_S	SgAd	et	kahhelplaadil =plaadi  (SgAd  >kahhel+plaat !22_S
35627	salasepitsustega	sepitsus	sala+sepitsus	11_S	PlKom	et	salasepitsustega =sepitsus  (PlKom  >sala+sepitsus !11_S
35634	kitsetaoline	taoline	kitse+taoline	12?10_A	SgN	et	kitsetaoline =taoline  (SgN  >kitse+taoline !12?10_A
35643	madudest	madu	madu	18_S	PlEl	et	madudest =madu  (PlEl  >madu !18_S
35645	nõiaraamatute	raamatu	nõia+raamat	02_S	PlG	et	nõiaraamatute =raamatu  (PlG  >nõia+raamat !02_S
35657	abielusõrmuses	sõrmuse	abi+elu+sõrmus	09_S	SgIn	et	abielusõrmuses =sõrmuse  (SgIn  >abi+elu+sõrmus !09_S
35658	jüripäeval	päeva	jüri+päev	22_S	SgAd	et	jüripäeval =päeva  (SgAd  >jüri+päev !22_S
35663	seitsevennapäeval	päeva	seitse+venna+päev	22_S	SgAd	et	seitsevennapäeval =päeva  (SgAd  >seitse+venna+päev !22_S
35666	riietes	riie	riie	06_S	PlIn	et	riietes =riie  (PlIn  >riie !06_S
35677	madisepäev	päev	madise+päev	22_S	SgN	et	madisepäev =päev  (SgN  >madise+päev !22_S
35678	kalendri	kalendri	kalender	02_S	SgG	et	kalendri =kalendri  (SgG  >kalender !02_S
35681	poiste	pois	poiss	23_S	PlG	et	poiste =pois  (PlG  >poiss !23_S
35689	tarad	tara	tara	17_S	PlN	et	tarad =tara  (PlN  >tara !17_S
35695	tünnid	tünni	tünn	22_S	PlN	et	tünnid =tünni  (PlN  >tünn !22_S
35701	pererahva	rahva	pere+rahvas	07_S	SgG	et	pererahva =rahva  (SgG  >pere+rahvas !07_S
35713	meelismängudega	mängu	meelis+mäng	22_S	PlKom	et	meelismängudega =mängu  (PlKom  >meelis+mäng !22_S
35716	kiivrites	kiivri	kiiver	02_S	PlIn	et	kiivrites =kiivri  (PlIn  >kiiver !02_S
35725	rullib	rulli	rullima	28_V	IndPrSg3	et	rullib =rulli  (IndPrSg3  >rullima !28_V
35727	tõmbab	tõmba	tõmbama	29_V	IndPrSg3	et	tõmbab =tõmba  (IndPrSg3  >tõmbama !29_V
35735	lõbusate	lõbusa	lõbus	02_A	PlG	et	lõbusate =lõbusa  (PlG  >lõbus !02_A
35743	detailide	detaili	detail	22_S	PlG	et	detailide =detaili  (PlG  >detail !22_S
35755	ennustab	ennusta	ennustama	27_V	IndPrSg3	et	ennustab =ennusta  (IndPrSg3  >ennustama !27_V
35761	sealsed	sealse	sealne	02_A	PlN	et	sealsed =sealse  (PlN  >sealne !02_A
35769	laenudega	laenu	laen	22_S	PlKom	et	laenudega =laenu  (PlKom  >laen !22_S
35477	aiatöödega	töö	aia+töö	26_S	PlKom	et	aiatöödega =töö  (PlKom  >aia+töö !26_S
35481	saunas	sauna	saun	22_S	SgIn	et	saunas =sauna  (SgIn  >saun !22_S
35483	verega	vere	veri	20_S	SgKom	et	verega =vere  (SgKom  >veri !20_S
35486	sõbrunes	sõbrune	sõbrunema	27_V	IndIpfSg3	et	sõbrunes =sõbrune  (IndIpfSg3  >sõbrunema !27_V
35488	patt	patt	patt	22_S	SgN	et	patt =patt  (SgN  >patt !22_S
35492	võrguga	võrgu	võrk	22_S	SgKom	et	võrguga =võrgu  (SgKom  >võrk !22_S
35493	ida-slaavlased	slaavlase	ida-slaavlane	12?10_S	PlN	et	ida-slaavlased =slaavlase  (PlN  >ida-slaavlane !12?10_S
35496	käitumisreeglid	reegli	käitumis+reegel	02_S	PlN	et	käitumisreeglid =reegli  (PlN  >käitumis+reegel !02_S
35498	lugude	lugu	lugu	18_S	PlG	et	lugude =lugu  (PlG  >lugu !18_S
35509	atribuudid	atribuudi	atribuut	22_S	PlN	et	atribuudid =atribuudi  (PlN  >atribuut !22_S
35514	palvete	palve	palve	06_S	PlG	et	palvete =palve  (PlG  >palve !06_S
35520	tondid	tondi	tont	22_S	PlN	et	tondid =tondi  (PlN  >tont !22_S
35530	arhailiste	arhailis	arhailine	12?10_A	PlG	et	arhailiste =arhailis  (PlG  >arhailine !12?10_A
35533	ohtlikke	ohtlikke	ohtlik	25_A	PlP	et	ohtlikke =ohtlikke  (PlP  >ohtlik !25_A
35535	surra	surr	surema	36_V	Inf	et	surra =surr  (Inf  >surema !36_V
35536	paganat	pagana	pagan	02_S	SgP	et	paganat =pagana  (SgP  >pagan !02_S
35543	keelude	ude	keel+ude	04_S	SgN	et	keelude =ude  (SgN  >keel+ude !04_S
35545	tulevane	tulevane	tulevane	12_AS	SgN	et	tulevane =tulevane  (SgN  >tulevane !12_AS
35549	peredest	pere	pere	16_S	PlEl	et	peredest =pere  (PlEl  >pere !16_S
35556	soendada	soenda	soendama	27_V	Inf	et	soendada =soenda  (Inf  >soendama !27_V
35558	viljateradega	tera	vilja+tera	17_S	PlKom	et	viljateradega =tera  (PlKom  >vilja+tera !17_S
35559	rituaalsed	rituaalse	rituaalne	02_A	PlN	et	rituaalsed =rituaalse  (PlN  >rituaalne !02_A
35564	kuradite	kuradi	kurat	02_S	PlG	et	kuradite =kuradi  (PlG  >kurat !02_S
35565	salasepitsusi	sepitsusi	sala+sepitsus	11_S	PlP	et	salasepitsusi =sepitsusi  (PlP  >sala+sepitsus !11_S
35567	edela	edela	edel	02_S	SgG	et	edela =edela  (SgG  >edel !02_S
35571	aegsasti	aegsasti	aegsasti	41_D	ID	et	aegsasti =aegsasti  (ID  >aegsasti !41_D
35580	kõrvalekaldumine	kaldumine	kõrvale+kaldumine	12_S	SgN	et	kõrvalekaldumine =kaldumine  (SgN  >kõrvale+kaldumine !12_S
35586	sigaretid	sigareti	sigaret	22_S	PlN	et	sigaretid =sigareti  (PlN  >sigaret !22_S
35603	matusteks	matus	matus	09_S	PlTr	et	matusteks =matus  (PlTr  >matus !09_S
35604	seebiga	seebi	seep	22_S	SgKom	et	seebiga =seebi  (SgKom  >seep !22_S
35606	üldreeglina	reegli	üld+reegel	02_S	SgEs	et	üldreeglina =reegli  (SgEs  >üld+reegel !02_S
35614	analoogina	analoogi	analoog	22_S	SgEs	et	analoogina =analoogi  (SgEs  >analoog !22_S
35615	materjalid	materjali	materjal	19_S	PlN	et	materjalid =materjali  (PlN  >materjal !19_S
35630	kuradid	kuradi	kurat	02_S	PlN	et	kuradid =kuradi  (PlN  >kurat !02_S
35632	jälitab	jälita	jälitama	27_V	IndPrSg3	et	jälitab =jälita  (IndPrSg3  >jälitama !27_V
35642	aarete	aare	aare	06_S	PlG	et	aarete =aare  (PlG  >aare !06_S
35644	koduloomadest	looma	kodu+loom	22_S	PlEl	et	koduloomadest =looma  (PlEl  >kodu+loom !22_S
35651	tüüpiliste	tüüpilis	tüüpiline	12_A	PlG	et	tüüpiliste =tüüpilis  (PlG  >tüüpiline !12_A
35654	juuksekamme	kamme	juukse+kamm	22_S	PlP	et	juuksekamme =kamme  (PlP  >juukse+kamm !22_S
35673	külalislahked	lahke	külalis+lahke	01_A	PlN	et	külalislahked =lahke  (PlN  >külalis+lahke !01_A
35682	tempudesse	tempu	temp	22_S	PlIll	et	tempudesse =tempu  (PlIll  >temp !22_S
35690	saanid	saani	saan	22_S	PlN	et	saanid =saani  (PlN  >saan !22_S
35691	tiriti	tiri	tirima	27_V	IndIpfIps	et	tiriti =tiri  (IndIpfIps  >tirima !27_V
35696	soolahoidistega	hoidis	soola+hoidis	09_S	PlKom	et	soolahoidistega =hoidis  (PlKom  >soola+hoidis !09_S
35702	võistlusmänge	mänge	võistlus+mäng	22_S	PlP	et	võistlusmänge =mänge  (PlP  >võistlus+mäng !22_S
35703	mustvees	vee	must+vesi	15_S	SgIn	et	mustvees =vee  (SgIn  >must+vesi !15_S
35707	pidupäevadel	päeva	pidu+päev	22_S	PlAd	et	pidupäevadel =päeva  (PlAd  >pidu+päev !22_S
35712	iidsete	iidse	iidne	02_A	PlG	et	iidsete =iidse  (PlG  >iidne !02_A
35715	puhkpilliorkestri	orkestri	puhk+pilli+orkester	02_S	SgG	et	puhkpilliorkestri =orkestri  (SgG  >puhk+pilli+orkester !02_S
35717	medalid	medali	medal	02_S	PlN	et	medalid =medali  (PlN  >medal !02_S
35720	pidustustes	pidustus	pidustus	11_S	PlIn	et	pidustustes =pidustus  (PlIn  >pidustus !11_S
35721	tuletõrjesalkade	salka	tule+tõrje+salk	22_S	PlG	et	tuletõrjesalkade =salka  (PlG  >tule+tõrje+salk !22_S
35729	käsipumba	pumba	käsi+pump	22_S	SgG	et	käsipumba =pumba  (SgG  >käsi+pump !22_S
35731	demonstreeriti	demonstreeri	demonstreerima	28_V	IndIpfIps	et	demonstreeriti =demonstreeri  (IndIpfIps  >demonstreerima !28_V
35547	stressisituatsioone	situatsioone	stressi+situatsioon	22_S	PlP	et	stressisituatsioone =situatsioone  (PlP  >stressi+situatsioon !22_S
35553	tiivad	tiiva	tiib	22_S	PlN	et	tiivad =tiiva  (PlN  >tiib !22_S
35555	arusaam	saam	aru+saam	22_S	SgN	et	arusaam =saam  (SgN  >aru+saam !22_S
35557	veeks	vee	vesi	15_S	SgTr	et	veeks =vee  (SgTr  >vesi !15_S
35562	vanaaastaõhtul	õhtu	vana+aasta+õhtu	01_S	SgAd	et	vanaaastaõhtul =õhtu  (SgAd  >vana+aasta+õhtu !01_S
35584	üldtunnustatud	tunnustatu	üld+tunnustatu	01_S	PlN	et	üldtunnustatud =tunnustatu  (PlN  >üld+tunnustatu !01_S
35590	kirjapanekuid	paneku	kirja+panek	02_S	PlP	et	kirjapanekuid =paneku  (PlP  >kirja+panek !02_S
35595	peietel	peie	peie	06_S	PlAd	et	peietel =peie  (PlAd  >peie !06_S
35597	vastumeelsed	meelse	vastu+meelne	02_A	PlN	et	vastumeelsed =meelse  (PlN  >vastu+meelne !02_A
35601	omistati	omista	omistama	27_V	IndIpfIps	et	omistati =omista  (IndIpfIps  >omistama !27_V
35613	kujutatakse	kujuta	kujutama	27_V	IndPrIps	et	kujutatakse =kujuta  (IndPrIps  >kujutama !27_V
35619	vürst	vürst	vürst	22_S	SgN	et	vürst =vürst  (SgN  >vürst !22_S
35620	televiisoriga	televiisori	televiisor	02_S	SgKom	et	televiisoriga =televiisori  (SgKom  >televiisor !02_S
35629	hirmudest	hirmu	hirm	22_S	PlEl	et	hirmudest =hirmu  (PlEl  >hirm !22_S
35631	veskis	veski	veski	01_S	SgIn	et	veskis =veski  (SgIn  >veski !01_S
35637	sabaga	saba	saba	17_S	SgKom	et	sabaga =saba  (SgKom  >saba !17_S
35649	erandi	erandi	erand	02_S	SgG	et	erandi =erandi  (SgG  >erand !02_S
35653	padja	padja	padi	24_S	SgG	et	padja =padja  (SgG  >padi !24_S
35656	meesterahvale	rahva	meeste+rahvas	07_S	SgAll	et	meesterahvale =rahva  (SgAll  >meeste+rahvas !07_S
35665	rituaalsetele	rituaalse	rituaalne	02_A	PlAll	et	rituaalsetele =rituaalse  (PlAll  >rituaalne !02_A
35670	naaberküladest	küla	naaber+küla	17_S	PlEl	et	naaberküladest =küla  (PlEl  >naaber+küla !17_S
35671	juhuks	juhu	juht	22_S	SgTr	et	juhuks =juhu  (SgTr  >juht !22_S
35674	piirissaare	saare	piiris+saar	13_S	SgG	et	piirissaare =saare  (SgG  >piiris+saar !13_S
35676	pannkookide	kooki	pann+kook	22_S	PlG	et	pannkookide =kooki  (PlG  >pann+kook !22_S
35680	tembud	tembu	temp	22_S	PlN	et	tembud =tembu  (PlN  >temp !22_S
35683	tempudeks	tempu	temp	22_S	PlTr	et	tempudeks =tempu  (PlTr  >temp !22_S
35687	põhuga	põhu	põhk	22_S	SgKom	et	põhuga =põhu  (SgKom  >põhk !22_S
35693	esitrepi	trepi	esi+trepp	22_S	SgG	et	esitrepi =trepi  (SgG  >esi+trepp !22_S
35694	keldris	keldri	kelder	02_S	SgIn	et	keldris =keldri  (SgIn  >kelder !02_S
35698	paadi	paadi	paat	22_S	SgG	et	paadi =paadi  (SgG  >paat !22_S
35700	katta	katt	katma	35_V	Inf	et	katta =katt  (Inf  >katma !35_V
35706	ümberpiiramist	piiramis	ümber+piiramine	12_S	SgP	et	ümberpiiramist =piiramis  (SgP  >ümber+piiramine !12_S
35711	rusikavõitlustega	võitlus	rusika+võitlus	11~09_S	PlKom	et	rusikavõitlustega =võitlus  (PlKom  >rusika+võitlus !11~09_S
35719	poistesalk	salk	poiste+salk	22_S	SgN	et	poistesalk =salk  (SgN  >poiste+salk !22_S
35722	imiteeriti	imiteeri	imiteerima	28_V	IndIpfIps	et	imiteeriti =imiteeri  (IndIpfIps  >imiteerima !28_V
35728	järveni	järve	järv	22_S	SgTer	et	järveni =järve  (SgTer  >järv !22_S
35730	kustutab	kustuta	kustutama	27_V	IndPrSg3	et	kustutab =kustuta  (IndPrSg3  >kustutama !27_V
35741	pardid	pardi	part	22_S	PlN	et	pardid =pardi  (PlN  >part !22_S
35749	aarde	aarde	aare	06_S	SgG	et	aarde =aarde  (SgG  >aare !06_S
35752	keskpäeval	päeva	kesk+päev	22_S	SgAd	et	keskpäeval =päeva  (SgAd  >kesk+päev !22_S
35779	kaadrist	kaadri	kaader	02_S	SgEl	et	kaadrist =kaadri  (SgEl  >kaader !02_S
35781	kalendritavanditele	tavandi	kalendri+tavand	02_S	PlAll	et	kalendritavanditele =tavandi  (PlAll  >kalendri+tavand !02_S
35783	fikseerida	fikseeri	fikseerima	28_V	Inf	et	fikseerida =fikseeri  (Inf  >fikseerima !28_V
35784	ääre	ääre	äär	13_S	SgG	et	ääre =ääre  (SgG  >äär !13_S
35795	folklooritekste	tekste	folkloori+tekst	22_S	PlP	et	folklooritekste =tekste  (PlP  >folkloori+tekst !22_S
35799	silmapiirist	piiri	silma+piir	22_S	SgEl	et	silmapiirist =piiri  (SgEl  >silma+piir !22_S
35801	etikett	etikett	etikett	22_S	SgN	et	etikett =etikett  (SgN  >etikett !22_S
35802	komponente	komponente	komponent	22_S	PlP	et	komponente =komponente  (PlP  >komponent !22_S
35803	väärib	vääri	väärima	28_V	IndPrSg3	et	väärib =vääri  (IndPrSg3  >väärima !28_V
35806	tööpõlluks	põllu	töö+põld	22_S	SgTr	et	tööpõlluks =põllu  (SgTr  >töö+põld !22_S
35828	transkriptsioonist	transkriptsiooni	transkriptsioon	22_S	SgEl	et	transkriptsioonist =transkriptsiooni  (SgEl  >transkriptsioon !22_S
35829	folklooritekstide	teksti	folkloori+tekst	22_S	PlG	et	folklooritekstide =teksti  (PlG  >folkloori+tekst !22_S
35837	mõningaid	mõninga	mõningas	02_P	PlP	et	mõningaid =mõninga  (PlP  >mõningas !02_P
35579	tavade	tava	tava	17_S	PlG	et	tavade =tava  (PlG  >tava !17_S
35585	kõlbluskaanonitega	kaanoni	kõlblus+kaanon	02_S	PlKom	et	kõlbluskaanonitega =kaanoni  (PlKom  >kõlblus+kaanon !02_S
35612	muistendites	muistendi	muistend	02_S	PlIn	et	muistendites =muistendi  (PlIn  >muistend !02_S
35616	muistendite	muistendi	muistend	02_S	PlG	et	muistendite =muistendi  (PlG  >muistend !02_S
35621	vaipadega	vaipa	vaip	22_S	PlKom	et	vaipadega =vaipa  (PlKom  >vaip !22_S
35624	väikelapsed	lapse	väike+laps	14_S	PlN	et	väikelapsed =lapse  (PlN  >väike+laps !14_S
35626	maapeal	pea	maa+pea	26_S	SgAd	et	maapeal =pea  (SgAd  >maa+pea !26_S
35636	paadis	paadi	paat	22_S	SgIn	et	paadis =paadi  (SgIn  >paat !22_S
35641	nemadki	nema	tema	00_P	PlN^	et	nemadki =nema  (PlN^  >tema !00_P
35646	saatanlike	saatanlike	saatanlik	25_A	PlG	et	saatanlike =saatanlike  (PlG  >saatanlik !25_A
35650	konspektiivsed	konspektiivse	konspektiivne	02_A	PlN	et	konspektiivsed =konspektiivse  (PlN  >konspektiivne !02_A
35655	tikkudest	tikku	tikk	22_S	PlEl	et	tikkudest =tikku  (PlEl  >tikk !22_S
35659	lüpsiku	lüpsiku	lüpsik	02_S	SgG	et	lüpsiku =lüpsiku  (SgG  >lüpsik !02_S
35669	kodukirikupühadel	püha	kodu+kiriku+püha	17_SA	PlAd	et	kodukirikupühadel =püha  (PlAd  >kodu+kiriku+püha !17_SA
35675	lõbusa	lõbusa	lõbus	02_A	SgG	et	lõbusa =lõbusa  (SgG  >lõbus !02_A
35685	koduustele	us	kodu+uks	14_S	PlAll	et	koduustele =us  (PlAll  >kodu+uks !14_S
35686	topiti	topi	toppima	28_V	IndIpfIps	et	topiti =topi  (IndIpfIps  >toppima !28_V
35688	kaltsudega	kaltsu	kalts	22_S	PlKom	et	kaltsudega =kaltsu  (PlKom  >kalts !22_S
35692	kollektiivseid	kollektiivse	kollektiivne	02_A	PlP	et	kollektiivseid =kollektiivse  (PlP  >kollektiivne !02_A
35697	katusele	katuse	katus	09_S	SgAll	et	katusele =katuse  (SgAll  >katus !09_S
35699	tirida	tiri	tirima	27_V	Inf	et	tirida =tiri  (Inf  >tirima !27_V
35705	linnuse	linnuse	linnus	09_S	SgG	et	linnuse =linnuse  (SgG  >linnus !09_S
35709	oletatavasti	oletatavasti	oletatavasti	41_D	ID	et	oletatavasti =oletatavasti  (ID  >oletatavasti !41_D
35710	rituaalsete	rituaalse	rituaalne	02_A	PlG	et	rituaalsete =rituaalse  (PlG  >rituaalne !02_A
35723	ametivennad	venna	ameti+vend	22_S	PlN	et	ametivennad =venna  (PlN  >ameti+vend !22_S
35733	pidusaiade	saia	pidu+sai	22_S	PlG	et	pidusaiade =saia  (PlG  >pidu+sai !22_S
35734	pühademunade	muna	pühade+muna	17_S	PlG	et	pühademunade =muna  (PlG  >pühade+muna !17_S
35745	tööriistade	riista	töö+riist	22_S	PlG	et	tööriistade =riista  (PlG  >töö+riist !22_S
35757	abielunaistel	nais	abi+elu+naine	12_S	PlAd	et	abielunaistel =nais  (PlAd  >abi+elu+naine !12_S
35758	vastsündinule	sündinu	vast+sündinu	01_S	SgAll	et	vastsündinule =sündinu  (SgAll  >vast+sündinu !01_S
35762	põliselanikelt	elanike	põlis+elanik	25_S	PlAbl	et	põliselanikelt =elanike  (PlAbl  >põlis+elanik !25_S
35764	käsikirjas	kirja	käsi+kiri	24_S	SgIn	et	käsikirjas =kirja  (SgIn  >käsi+kiri !24_S
35765	tõvesõnad	sõna	tõve+sõna	17_S	PlN	et	tõvesõnad =sõna  (PlN  >tõve+sõna !17_S
35766	dialoog	dialoog	dialoog	22_S	SgN	et	dialoog =dialoog  (SgN  >dialoog !22_S
35767	otseste	otses	otsene	10_A	PlG	et	otseste =otses  (PlG  >otsene !10_A
35772	ajaloouuringutes	uuringu	aja+loo+uuring	02_S	PlIn	et	ajaloouuringutes =uuringu  (PlIn  >aja+loo+uuring !02_S
35774	publikatsiooniks	publikatsiooni	publikatsioon	22_S	SgTr	et	publikatsiooniks =publikatsiooni  (SgTr  >publikatsioon !22_S
35778	kirjeldas	kirjelda	kirjeldama	27_V	IndIpfSg3	et	kirjeldas =kirjelda  (IndIpfSg3  >kirjeldama !27_V
35786	rahvatraditsioonide	traditsiooni	rahva+traditsioon	22_S	PlG	et	rahvatraditsioonide =traditsiooni  (PlG  >rahva+traditsioon !22_S
35790	kodukandis	kandi	kodu+kant	22_S	SgIn	et	kodukandis =kandi  (SgIn  >kodu+kant !22_S
35793	folklooriekspeditsioon	ekspeditsioon	folkloori+ekspeditsioon	22_S	SgN	et	folklooriekspeditsioon =ekspeditsioon  (SgN  >folkloori+ekspeditsioon !22_S
35796	kvaliteetseid	kvaliteetse	kvaliteetne	02_A	PlP	et	kvaliteetseid =kvaliteetse  (PlP  >kvaliteetne !02_A
35800	teatad	teata	teatama	27_V	IndPrSg2	et	teatad =teata  (IndPrSg2  >teatama !27_V
35808	kihist	kihi	kiht	22_S	SgEl	et	kihist =kihi  (SgEl  >kiht !22_S
35809	arhiivimaterjalid	materjali	arhiivi+materjal	19_S	PlN	et	arhiivimaterjalid =materjali  (PlN  >arhiivi+materjal !19_S
35814	peatükkides	tükki	pea+tükk	22_S	PlIn	et	peatükkides =tükki  (PlIn  >pea+tükk !22_S
35816	nägemuse	nägemuse	nägemus	11_S	SgG	et	nägemuse =nägemuse  (SgG  >nägemus !11_S
35819	tinglik	tinglik	tinglik	25_A	SgN	et	tinglik =tinglik  (SgN  >tinglik !25_A
35824	kasutasime	kasuta	kasutama	27_V	IndIpfPl1	et	kasutasime =kasuta  (IndIpfPl1  >kasutama !27_V
35826	kohalikule	kohaliku	kohalik	25_AS	SgAll	et	kohalikule =kohaliku  (SgAll  >kohalik !25_AS
35833	kirjavigu	vigu	kirja+viga	18_S	PlP	et	kirjavigu =vigu  (PlP  >kirja+viga !18_S
35835	materjalide	materjali	materjal	19_S	PlG	et	materjalide =materjali  (PlG  >materjal !19_S
35591	jõululaupäev	päev	jõulu+lau+päev	22_S	SgN	et	jõululaupäev =päev  (SgN  >jõulu+lau+päev !22_S
35592	puder	puder	puder	24_S	SgN	et	puder =puder  (SgN  >puder !24_S
35596	hinged	hinge	hing	22_S	PlN	et	hinged =hinge  (PlN  >hing !22_S
35599	pesti	pes	pesema	36_V	IndIpfIps	et	pesti =pes  (IndIpfIps  >pesema !36_V
35607	maetakse	mae	matma	35_V	IndPrIps	et	maetakse =mae  (IndPrIps  >matma !35_V
35608	põhjapoolses	poolse	põhja+poolne	02_A	SgIn	et	põhjapoolses =poolse  (SgIn  >põhja+poolne !02_A
35622	kahhelplaatidega	plaati	kahhel+plaat	22_S	PlKom	et	kahhelplaatidega =plaati  (PlKom  >kahhel+plaat !22_S
35625	pimedad	pimeda	pime	02_AS	PlN	et	pimedad =pimeda  (PlN  >pime !02_AS
35628	vaimudest	vaimu	vaim	22_S	PlEl	et	vaimudest =vaimu  (PlEl  >vaim !22_S
35633	viirastub	viirastu	viirastuma	27_V	IndPrSg3	et	viirastub =viirastu  (IndPrSg3  >viirastuma !27_V
35635	olend	olend	olend	02_S	SgN	et	olend =olend  (SgN  >olend !02_S
35638	sõidab	sõida	sõitma	34_V	IndPrSg3	et	sõidab =sõida  (IndPrSg3  >sõitma !34_V
35639	rattaga	ratta	ratas	07_S	SgKom	et	rattaga =ratta  (SgKom  >ratas !07_S
35640	vankri	vankri	vanker	02_S	SgG	et	vankri =vankri  (SgG  >vanker !02_S
35647	nõia	nõia	nõid	22_S	SgG	et	nõia =nõia  (SgG  >nõid !22_S
35648	hirmsast	hirmsa	hirmus	02_A	SgEl	et	hirmsast =hirmsa  (SgEl  >hirmus !02_A
35652	kalendripühade	püha	kalendri+püha	17_SA	PlG	et	kalendripühade =püha  (PlG  >kalendri+püha !17_SA
35660	likku	likku	ligu	18_S	SgAdt	et	likku =likku  (SgAdt  >ligu !18_S
35661	lehmad	lehma	lehm	22_S	PlN	et	lehmad =lehma  (PlN  >lehm !22_S
35662	olevipäeval	päeva	olevi+päev	22_S	SgAd	et	olevipäeval =päeva  (SgAd  >olevi+päev !22_S
35664	vette	ve	vesi	15_S	SgAdt	et	vette =ve  (SgAdt  >vesi !15_S
35667	suvehooaja	aja	suve+hoo+aeg	22_S	SgG	et	suvehooaja =aja  (SgG  >suve+hoo+aeg !22_S
35668	vetes	ve	vesi	15_S	PlIn	et	vetes =ve  (PlIn  >vesi !15_S
35672	kodudes	kodu	kodu	17_S	PlIn	et	kodudes =kodu  (PlIn  >kodu !17_S
35679	naljad	nalja	nali	24_S	PlN	et	naljad =nalja  (PlN  >nali !24_S
35684	erisuguseid	suguse	eri+sugune	10_A	PlP	et	erisuguseid =suguse  (PlP  >eri+sugune !10_A
35704	lahingut	lahingu	lahing	02_S	SgP	et	lahingut =lahingu  (SgP  >lahing !02_S
35708	piiril	piiri	piir	22_S	SgAd	et	piiril =piiri  (SgAd  >piir !22_S
35714	analooge	analooge	analoog	22_S	PlP	et	analooge =analooge  (PlP  >analoog !22_S
35718	tulega	tule	tuli	20_S	SgKom	et	tulega =tule  (SgKom  >tuli !20_S
35724	võisteldi	võistel	võistlema	30_V	IndIpfIps	et	võisteldi =võistel  (IndIpfIps  >võistlema !30_V
35726	vooliku	vooliku	voolik	02_S	SgG	et	vooliku =vooliku  (SgG  >voolik !02_S
35732	rahvarõivaid	rõiva	rahva+rõivas	07_S	PlP	et	rahvarõivaid =rõiva  (PlP  >rahva+rõivas !07_S
35737	rahvaanekdootide	anekdooti	rahva+anekdoot	22_S	PlG	et	rahvaanekdootide =anekdooti  (PlG  >rahva+anekdoot !22_S
35739	kirglik	kirglik	kirglik	25_A	SgN	et	kirglik =kirglik  (SgN  >kirglik !25_A
35747	foneetilises	foneetilise	foneetiline	12_A	SgIn	et	foneetilises =foneetilise  (SgIn  >foneetiline !12_A
35748	materjalides	materjali	materjal	19_S	PlIn	et	materjalides =materjali  (PlIn  >materjal !19_S
35750	variandis	variandi	variant	22_S	SgIn	et	variandis =variandi  (SgIn  >variant !22_S
35751	informaatorid	informaatori	informaator	02_S	PlN	et	informaatorid =informaatori  (PlN  >informaator !02_S
35753	materiaalset	materiaalse	materiaalne	02_A	SgP	et	materiaalset =materiaalse  (SgP  >materiaalne !02_A
35756	rituaalne	rituaalne	rituaalne	02_A	SgN	et	rituaalne =rituaalne  (SgN  >rituaalne !02_A
35759	oblastis	oblasti	oblast	02_S	SgIn	et	oblastis =oblasti  (SgIn  >oblast !02_S
35763	juhustest	juhus	juhus	09_S	PlEl	et	juhustest =juhus  (PlEl  >juhus !09_S
35768	folklooriteoste	teos	folkloori+teos	09_S	PlG	et	folklooriteoste =teos  (PlG  >folkloori+teos !09_S
35770	väljaannete	anne	välja+anne	06_S	PlG	et	väljaannete =anne  (PlG  >välja+anne !06_S
35776	sissejuhatavas	juhatava	sisse+juhatav	02_A	SgIn	et	sissejuhatavas =juhatava  (SgIn  >sisse+juhatav !02_A
35782	tööoskusi	oskusi	töö+oskus	11_S	PlP	et	tööoskusi =oskusi  (PlP  >töö+oskus !11_S
35787	väljaandes	ande	välja+anne	06_S	SgIn	et	väljaandes =ande  (SgIn  >välja+anne !06_S
35791	kahetsusväärne	väärne	kahetsus+väärne	02_A	SgN	et	kahetsusväärne =väärne  (SgN  >kahetsus+väärne !02_A
35804	edasist	edasis	edasine	12_A	SgP	et	edasist =edasis  (SgP  >edasine !12_A
35805	läänerannik	rannik	lääne+rannik	02_S	SgN	et	läänerannik =rannik  (SgN  >lääne+rannik !02_S
35807	folklooriuurijatele	uurija	folkloori+uurija	01_S	PlAll	et	folklooriuurijatele =uurija  (PlAll  >folkloori+uurija !01_S
35817	kombestiku	kombestiku	kombestik	25_S	SgG	et	kombestiku =kombestiku  (SgG  >kombestik !25_S
35821	lõppkokkuvõttes	võtte	lõpp+kokku+võte	06_S	SgIn	et	lõppkokkuvõttes =võtte  (SgIn  >lõpp+kokku+võte !06_S
35736	folkloriseerimises	seerimise	folk+lori+seerimine	12_S	SgIn	et	folkloriseerimises =seerimise  (SgIn  >folk+lori+seerimine !12_S
35738	pillirootihniku	tihniku	pilli+roo+tihnik	02_S	SgG	et	pillirootihniku =tihniku  (SgG  >pilli+roo+tihnik !02_S
35740	pillirootihnikus	tihniku	pilli+roo+tihnik	02_S	SgIn	et	pillirootihnikus =tihniku  (SgIn  >pilli+roo+tihnik !02_S
35742	pesitsema	pesitse	pesitsema	27_V	Sup	et	pesitsema =pesitse  (Sup  >pesitsema !27_V
35744	peipsiääre	ääre	peipsi+äär	13_S	SgG	et	peipsiääre =ääre  (SgG  >peipsi+äär !13_S
35746	tarbeesemete	eseme	tarbe+ese	04_S	PlG	et	tarbeesemete =eseme  (PlG  >tarbe+ese !04_S
35754	loojangul	loojangu	loojang	02_S	SgAd	et	loojangul =loojangu  (SgAd  >loojang !02_S
35760	analoogne	analoogne	analoogne	02_A	SgN	et	analoogne =analoogne  (SgN  >analoogne !02_A
35773	senini	senini	senini	41_D	ID	et	senini =senini  (ID  >senini !41_D
35775	muinasjutu	jutu	muinas+jutt	22_S	SgG	et	muinasjutu =jutu  (SgG  >muinas+jutt !22_S
35777	lünk	lünk	lünk	22_S	SgN	et	lünk =lünk  (SgN  >lünk !22_S
35780	huvipakkuvaid	pakkuva	huvi+pakkuv	02_A	PlP	et	huvipakkuvaid =pakkuva  (PlP  >huvi+pakkuv !02_A
35785	kirjapanekud	paneku	kirja+panek	02_S	PlN	et	kirjapanekud =paneku  (PlN  >kirja+panek !02_S
35794	nädalaga	nädala	nädal	02_S	SgKom	et	nädalaga =nädala  (SgKom  >nädal !02_S
35798	kirjandusmuuseumisse	muuseumi	kirjandus+muuseum	19~02_S	SgIll	et	kirjandusmuuseumisse =muuseumi  (SgIll  >kirjandus+muuseum !19~02_S
35813	esitamisviisist	viisi	esitamis+viis	22_S	SgEl	et	esitamisviisist =viisi  (SgEl  >esitamis+viis !22_S
35815	paigutasime	paiguta	paigutama	27_V	IndIpfPl1	et	paigutasime =paiguta  (IndIpfPl1  >paigutama !27_V
35818	anname	anna	andma	34_V	IndPrPl1	et	anname =anna  (IndPrPl1  >andma !34_V
35820	võrdsel	võrdse	võrdne	02_A	SgAd	et	võrdsel =võrdse  (SgAd  >võrdne !02_A
35822	peatükkide	tükki	pea+tükk	22_S	PlG	et	peatükkide =tükki  (PlG  >pea+tükk !22_S
35838	kupüüre	kupüüre	kupüür	22_S	PlP	et	kupüüre =kupüüre  (PlP  >kupüür !22_S
35840	ümarsulgudes	sulgu	ümar+sulg	22_S	PlIn	et	ümarsulgudes =sulgu  (PlIn  >ümar+sulg !22_S
35843	nurksulgudes	sulgu	nurk+sulg	22_S	PlIn	et	nurksulgudes =sulgu  (PlIn  >nurk+sulg !22_S
35850	entusiaste-koduloolasi	loolasi	entusiaste-kodu+loolane	12_S	PlP	et	entusiaste-koduloolasi =loolasi  (PlP  >entusiaste-kodu+loolane !12_S
35854	kaudne	kaudne	kaudne	02_A	SgN	et	kaudne =kaudne  (SgN  >kaudne !02_A
35858	ulmekirjanikest	kirjanike	ulme+kirjanik	25_S	PlEl	et	ulmekirjanikest =kirjanike  (PlEl  >ulme+kirjanik !25_S
35859	kirjutabki	kirjuta	kirjutama	27_V	IndPrSg3^	et	kirjutabki =kirjuta  (IndPrSg3^  >kirjutama !27_V
35860	seiklused	seikluse	seiklus	11~09_S	PlN	et	seiklused =seikluse  (PlN  >seiklus !11~09_S
35868	lühijutte	jutte	lühi+jutt	22_S	PlP	et	lühijutte =jutte  (PlP  >lühi+jutt !22_S
35873	arvutisimulatsioonis	simulatsiooni	arvuti+simulatsioon	22_S	SgIn	et	arvutisimulatsioonis =simulatsiooni  (SgIn  >arvuti+simulatsioon !22_S
35876	hiiglaslik	hiiglaslik	hiiglaslik	25_A	SgN	et	hiiglaslik =hiiglaslik  (SgN  >hiiglaslik !25_A
35877	helendab	helenda	helendama	27_V	IndPrSg3	et	helendab =helenda  (IndPrSg3  >helendama !27_V
35881	tõmban	tõmba	tõmbama	29_V	IndPrSg1	et	tõmban =tõmba  (IndPrSg1  >tõmbama !29_V
35890	pealkirjaga	kirja	peal+kiri	24_S	SgKom	et	pealkirjaga =kirja  (SgKom  >peal+kiri !24_S
35899	varjab	varja	varjama	29_V	IndPrSg3	et	varjab =varja  (IndPrSg3  >varjama !29_V
35902	mitmekülgsed	külgse	mitme+külgne	02_A	PlN	et	mitmekülgsed =külgse  (PlN  >mitme+külgne !02_A
35916	arvutimängudega	mängu	arvuti+mäng	22_S	PlKom	et	arvutimängudega =mängu  (PlKom  >arvuti+mäng !22_S
35917	värvuse	värvuse	värvus	11~09_S	SgG	et	värvuse =värvuse  (SgG  >värvus !11~09_S
35919	vajadusega	vajaduse	vajadus	11_S	SgKom	et	vajadusega =vajaduse  (SgKom  >vajadus !11_S
35920	vastena	vaste	vaste	06_S	SgEs	et	vastena =vaste  (SgEs  >vaste !06_S
35923	huvides	huvi	huvi	17_S	PlIn	et	huvides =huvi  (PlIn  >huvi !17_S
35925	lõigus	lõigu	lõik	22_S	SgIn	et	lõigus =lõigu  (SgIn  >lõik !22_S
35928	muinasjuttudes	juttu	muinas+jutt	22_S	PlIn	et	muinasjuttudes =juttu  (PlIn  >muinas+jutt !22_S
35932	kantakse	kan	kandma	34_V	IndPrIps	et	kantakse =kan  (IndPrIps  >kandma !34_V
35944	vähemosavat	osava	vähem+osav	02_A	SgP	et	vähemosavat =osava  (SgP  >vähem+osav !02_A
35945	võrdluse	võrdluse	võrdlus	11~09_S	SgG	et	võrdluse =võrdluse  (SgG  >võrdlus !11~09_S
35965	antonüüm	antonüüm	antonüüm	22_S	SgN	et	antonüüm =antonüüm  (SgN  >antonüüm !22_S
35966	relatiivsetel	relatiivse	relatiivne	02_A	PlAd	et	relatiivsetel =relatiivse  (PlAd  >relatiivne !02_A
35967	komplementaarsel	komplementaarse	komplementaarne	02_A	SgAd	et	komplementaarsel =komplementaarse  (SgAd  >komplementaarne !02_A
35968	ewn-s	ewn	ewn	xx_Q	SgIn	et	ewn-s =ewn  (SgIn  >ewn !xx_Q
35969	suhte	suhte	suhe	06_S	SgG	et	suhte =suhte  (SgG  >suhe !06_S
35970	märgendiks	märgendi	märgend	02_S	SgTr	et	märgendiks =märgendi  (SgTr  >märgend !02_S
35771	erandjuhtudel	juhtu	erand+juht	22_S	PlAd	et	erandjuhtudel =juhtu  (PlAd  >erand+juht !22_S
35788	materjalidest	materjali	materjal	19_S	PlEl	et	materjalidest =materjali  (PlEl  >materjal !19_S
35789	perekonnanimede	nime	pere+konna+nimi	20_S	PlG	et	perekonnanimede =nime  (PlG  >pere+konna+nimi !20_S
35792	esimehe	mehe	esi+mees	13_S	SgG	et	esimehe =mehe  (SgG  >esi+mees !13_S
35797	helisalvestusi	salvestusi	heli+salvestus	11_S	PlP	et	helisalvestusi =salvestusi  (PlP  >heli+salvestus !11_S
35810	folkloorimaterjale	materjale	folkloori+materjal	19_S	PlP	et	folkloorimaterjale =materjale  (PlP  >folkloori+materjal !19_S
35811	struktuuris	struktuuri	struktuur	22_S	SgIn	et	struktuuris =struktuuri  (SgIn  >struktuur !22_S
35812	loobusime	loobu	loobuma	27_V	IndIpfPl1	et	loobusime =loobu  (IndIpfPl1  >loobuma !27_V
35831	põhimõtteid	mõtte	põhi+mõte	06_S	PlP	et	põhimõtteid =mõtte  (PlP  >põhi+mõte !06_S
35836	foneetiline	foneetiline	foneetiline	12_A	SgN	et	foneetiline =foneetiline  (SgN  >foneetiline !12_A
35845	kirjapaneku	paneku	kirja+panek	02_S	SgG	et	kirjapaneku =paneku  (SgG  >kirja+panek !02_S
35847	põhjaliku	põhjaliku	põhjalik	25_A	SgG	et	põhjaliku =põhjaliku  (SgG  >põhjalik !25_A
35849	mingisugused	suguse	mingi+sugune	10_P	PlN	et	mingisugused =suguse  (PlN  >mingi+sugune !10_P
35855	tõend	tõend	tõend	02_S	SgN	et	tõend =tõend  (SgN  >tõend !02_S
35856	tõlkeanalüüs	analüüs	tõlke+analüüs	22_S	SgN	et	tõlkeanalüüs =analüüs  (SgN  >tõlke+analüüs !22_S
35867	loomingusse	loomingu	looming	02_S	SgIll	et	loomingusse =loomingu  (SgIll  >looming !02_S
35869	populaarset	populaarse	populaarne	02_A	SgP	et	populaarset =populaarse  (SgP  >populaarne !02_A
35870	järg	järg	järg	22_S	SgN	et	järg =järg  (SgN  >järg !22_S
35879	õõnde	õõn	õõs	14_S	SgAdt	et	õõnde =õõn  (SgAdt  >õõs !14_S
35885	peidiku	peidiku	peidik	02_S	SgG	et	peidiku =peidiku  (SgG  >peidik !02_S
35886	raudteede	tee	raud+tee	26_S	PlG	et	raudteede =tee  (PlG  >raud+tee !26_S
35893	küberruumis	ruumi	küber+ruum	22_S	SgIn	et	küberruumis =ruumi  (SgIn  >küber+ruum !22_S
35895	tahkudele	tahku	tahk	22_S	PlAll	et	tahkudele =tahku  (PlAll  >tahk !22_S
35897	peeglite	peegli	peegel	02_S	PlG	et	peeglite =peegli  (PlG  >peegel !02_S
35901	minasid	mina	mina	17_S	PlP	et	minasid =mina  (PlP  >mina !17_S
35907	lauset	lause	lause	06_S	SgP	et	lauset =lause  (SgP  >lause !06_S
35908	tähistab	tähista	tähistama	27_V	IndPrSg3	et	tähistab =tähista  (IndPrSg3  >tähistama !27_V
35910	nõidust	nõidus	nõidus	11~09_S	SgP	et	nõidust =nõidus  (SgP  >nõidus !11~09_S
35912	heasoovliku	soovliku	hea+soovlik	25_A	SgG	et	heasoovliku =soovliku  (SgG  >hea+soovlik !25_A
35914	puuga	puu	puu	26_S	SgKom	et	puuga =puu  (SgKom  >puu !26_S
35921	stabiilset	stabiilse	stabiilne	02_A	SgP	et	stabiilset =stabiilse  (SgP  >stabiilne !02_A
35924	sidesõnaga	sõna	side+sõna	17_S	SgKom	et	sidesõnaga =sõna  (SgKom  >side+sõna !17_S
35929	särgid	särgi	särk	22_S	PlN	et	särgid =särgi  (PlN  >särk !22_S
35936	kõikvõimaliku	võimaliku	kõik+võimalik	25_A	SgG	et	kõikvõimaliku =võimaliku  (SgG  >kõik+võimalik !25_A
35938	kraamiga	kraami	kraam	22_S	SgKom	et	kraamiga =kraami  (SgKom  >kraam !22_S
35939	väljendab	väljenda	väljendama	27_V	IndPrSg3	et	väljendab =väljenda  (IndPrSg3  >väljendama !27_V
35941	asjasse	asja	asi	24_S	SgIll	et	asjasse =asja  (SgIll  >asi !24_S
35942	originaaltekstis	teksti	originaal+tekst	22_S	SgIn	et	originaaltekstis =teksti  (SgIn  >originaal+tekst !22_S
35943	peategelase	tegelase	pea+tegelane	12_S	SgG	et	peategelase =tegelase  (SgG  >pea+tegelane !12_S
35949	vastet	vaste	vaste	06_S	SgP	et	vastet =vaste  (SgP  >vaste !06_S
35950	vasteks	vaste	vaste	06_S	SgTr	et	vasteks =vaste  (SgTr  >vaste !06_S
35954	tähenduskomponendi	komponendi	tähendus+komponent	22_S	SgG	et	tähenduskomponendi =komponendi  (SgG  >tähendus+komponent !22_S
36003	tagada	taga	tagama	27_V	Inf	et	tagada =taga  (Inf  >tagama !27_V
36016	eksperimente	eksperimente	eksperiment	22_S	PlP	et	eksperimente =eksperimente  (PlP  >eksperiment !22_S
36030	paluksin	palu	paluma	27_V	KndPrSg1	et	paluksin =palu  (KndPrSg1  >paluma !27_V
36035	ebamugavaks	mugava	eba+mugav	02_A	SgTr	et	ebamugavaks =mugava  (SgTr  >eba+mugav !02_A
36062	toost	toost	toost	22_S	SgN	et	toost =toost  (SgN  >toost !22_S
36074	piltlike	piltlike	piltlik	25_A	PlG	et	piltlike =piltlike  (PlG  >piltlik !25_A
36077	võidakse	või	võima	37_V	IndPrIps	et	võidakse =või  (IndPrIps  >võima !37_V
36078	fraseologismide	fraseologismi	fraseologism	22_S	PlG	et	fraseologismide =fraseologismi  (PlG  >fraseologism !22_S
36083	kõnekäänd	käänd	kõne+käänd	22_S	SgN	et	kõnekäänd =käänd  (SgN  >kõne+käänd !22_S
36087	keeliti	keeliti	keeliti	41_D	ID	et	keeliti =keeliti  (ID  >keeliti !41_D
36088	võiksime	või	võima	37_V	KndPrPl1	et	võiksime =või  (KndPrPl1  >võima !37_V
35823	pealkirjades	kirja	peal+kiri	24_S	PlIn	et	pealkirjades =kirja  (PlIn  >peal+kiri !24_S
35825	välitöödel	töö	väli+töö	26_S	PlAd	et	välitöödel =töö  (PlAd  >väli+töö !26_S
35827	sõnarõhk	rõhk	sõna+rõhk	22_S	SgN	et	sõnarõhk =rõhk  (SgN  >sõna+rõhk !22_S
35830	raskendab	raskenda	raskendama	27_V	IndPrSg3	et	raskendab =raskenda  (IndPrSg3  >raskendama !27_V
35832	arhiivimaterjalide	materjali	arhiivi+materjal	19_S	PlG	et	arhiivimaterjalide =materjali  (PlG  >arhiivi+materjal !19_S
35834	foneetilist	foneetilis	foneetiline	12_A	SgP	et	foneetilist =foneetilis  (SgP  >foneetiline !12_A
35839	märgiga	märgi	märk	22_S	SgKom	et	märgiga =märgi  (SgKom  >märk !22_S
35844	arhiivimaterjalidest	materjali	arhiivi+materjal	19_S	PlEl	et	arhiivimaterjalidest =materjali  (PlEl  >arhiivi+materjal !19_S
35857	labürint	labürint	labürint	22_S	SgN	et	labürint =labürint  (SgN  >labürint !22_S
35863	arenguvõimalused	võimaluse	arengu+võimalus	11_S	PlN	et	arenguvõimalused =võimaluse  (PlN  >arengu+võimalus !11_S
35878	pistan	pista	pistma	34_V	IndPrSg1	et	pistan =pista  (IndPrSg1  >pistma !34_V
35880	riietun	riietu	riietuma	27_V	IndPrSg1	et	riietun =riietu  (IndPrSg1  >riietuma !27_V
35884	taskus	tasku	tasku	01_S	SgIn	et	taskus =tasku  (SgIn  >tasku !01_S
35891	vihjab	vihja	vihjama	29_V	IndPrSg3	et	vihjab =vihja  (IndPrSg3  >vihjama !29_V
35898	labürindis	labürindi	labürint	22_S	SgIn	et	labürindis =labürindi  (SgIn  >labürint !22_S
35903	võrdlesin	võrdle	võrdlema	30_V	IndIpfSg1	et	võrdlesin =võrdle  (IndIpfSg1  >võrdlema !30_V
35904	sõna-sõnalt	sõna-sõnalt	sõna+-sõnalt	41_D	ID	et	sõna-sõnalt =sõna-sõnalt  (ID  >sõna+-sõnalt !41_D
35906	otsetõlge	tõlge	otse+tõlge	06_S	SgN	et	otsetõlge =tõlge  (SgN  >otse+tõlge !06_S
35926	rahvarõivasärg	särg	rahva+rõiva+särg	22_S	SgN	et	rahvarõivasärg =särg  (SgN  >rahva+rõiva+särg !22_S
35934	peakangelane	kangelane	pea+kangelane	12_S	SgN	et	peakangelane =kangelane  (SgN  >pea+kangelane !12_S
35935	seiklema	seikle	seiklema	30_V	Sup	et	seiklema =seikle  (Sup  >seiklema !30_V
35951	tähendusnüansse	nüansse	tähendus+nüanss	22_S	PlP	et	tähendusnüansse =nüansse  (PlP  >tähendus+nüanss !22_S
35952	semantilise	semantilise	semantiline	12_A	SgG	et	semantilise =semantilise  (SgG  >semantiline !12_A
35955	mõõt	mõõt	mõõt	22_S	SgN	et	mõõt =mõõt  (SgN  >mõõt !22_S
35957	antonüümide	antonüümi	antonüüm	22_S	PlG	et	antonüümide =antonüümi  (PlG  >antonüüm !22_S
35961	antonüümiat	antonüümia	antonüümia	01_S	SgP	et	antonüümiat =antonüümia  (SgP  >antonüümia !01_S
35963	tunnuse	tunnuse	tunnus	09_S	SgG	et	tunnuse =tunnuse  (SgG  >tunnus !09_S
35985	referaadi	referaadi	referaat	22_S	SgG	et	referaadi =referaadi  (SgG  >referaat !22_S
35986	kasutasin	kasuta	kasutama	27_V	IndIpfSg1	et	kasutasin =kasuta  (IndIpfSg1  >kasutama !27_V
36011	aprillis	aprilli	aprill	22_S	SgIn	et	aprillis =aprilli  (SgIn  >aprill !22_S
36013	neide	neide	neid	22_S	PlP	et	neide =neide  (PlP  >neid !22_S
36024	realiseeruma	realiseeru	realiseeruma	27_V	Sup	et	realiseeruma =realiseeru  (Sup  >realiseeruma !27_V
36027	materjalimaht	maht	materjali+maht	22_S	SgN	et	materjalimaht =maht  (SgN  >materjali+maht !22_S
36031	kiirpilet	pilet	kiir+pilet	02_S	SgN	et	kiirpilet =pilet  (SgN  >kiir+pilet !02_S
36039	jõululinn	linn	jõulu+linn	22_S	SgN	et	jõululinn =linn  (SgN  >jõulu+linn !22_S
36043	raekojaplatsil	platsi	rae+koja+plats	22_S	SgAd	et	raekojaplatsil =platsi  (SgAd  >rae+koja+plats !22_S
36056	vastuargumente	argumente	vastu+argument	22_S	PlP	et	vastuargumente =argumente  (PlP  >vastu+argument !22_S
36059	kontorisse	kontori	kontor	02_S	SgIll	et	kontorisse =kontori  (SgIll  >kontor !02_S
36069	operaator	operaator	operaator	02_S	SgN	et	operaator =operaator  (SgN  >operaator !02_S
36071	arvate	arva	arvama	29_V	IndPrPl2	et	arvate =arva  (IndPrPl2  >arvama !29_V
36073	fraseologismidest	fraseologismi	fraseologism	22_S	PlEl	et	fraseologismidest =fraseologismi  (PlEl  >fraseologism !22_S
36084	kõnekeelne	keelne	kõne+keelne	02_A	SgN	et	kõnekeelne =keelne  (SgN  >kõne+keelne !02_A
36089	lähtuda	lähtu	lähtuma	27_V	Inf	et	lähtuda =lähtu  (Inf  >lähtuma !27_V
36090	idiomaatilisi	idiomaatilisi	idiomaatiline	12_A	PlP	et	idiomaatilisi =idiomaatilisi  (PlP  >idiomaatiline !12_A
36124	neljandas	neljanda	neljas	02_O	SgIn	et	neljandas =neljanda  (SgIn  >neljas !02_O
36125	peatükis	tüki	pea+tükk	22_S	SgIn	et	peatükis =tüki  (SgIn  >pea+tükk !22_S
36131	vaatluste	vaatlus	vaatlus	11~09_S	PlG	et	vaatluste =vaatlus  (PlG  >vaatlus !11~09_S
36132	koolitüübi	tüübi	kooli+tüüp	22_S	SgG	et	koolitüübi =tüübi  (SgG  >kooli+tüüp !22_S
36143	poststrukturalistlikud	strukturalistliku	post+strukturalistlik	25_A	PlN	et	poststrukturalistlikud =strukturalistliku  (PlN  >post+strukturalistlik !25_A
36150	retsensendi	retsensendi	retsensent	22_S	SgG	et	retsensendi =retsensendi  (SgG  >retsensent !22_S
36151	piirduda	piirdu	piirduma	27_V	Inf	et	piirduda =piirdu  (Inf  >piirduma !27_V
35841	haruldaste	haruldas	haruldane	12_A	PlG	et	haruldaste =haruldas  (PlG  >haruldane !12_A
35846	kirjapanekute	paneku	kirja+panek	02_S	PlG	et	kirjapanekute =paneku  (PlG  >kirja+panek !02_S
35848	kõnekäänded	käände	kõne+kääne	06_S	PlN	et	kõnekäänded =käände  (PlN  >kõne+kääne !06_S
35862	alternatiivsed	alternatiivse	alternatiivne	02_A	PlN	et	alternatiivsed =alternatiivse  (PlN  >alternatiivne !02_A
35864	põhiolemuselt	olemuse	põhi+olemus	11_S	SgAbl	et	põhiolemuselt =olemuse  (SgAbl  >põhi+olemus !11_S
35871	tegevustik	tegevustik	tegevustik	25_S	SgN	et	tegevustik =tegevustik  (SgN  >tegevustik !25_S
35872	kübermaailmas	ilma	küber+maa+ilm	22_S	SgIn	et	kübermaailmas =ilma  (SgIn  >küber+maa+ilm !22_S
35874	lõik	lõik	lõik	22_S	SgN	et	lõik =lõik  (SgN  >lõik !22_S
35875	ahaa	ahaa	ahaa	41_I	ID	et	ahaa =ahaa  (ID  >ahaa !41_I
35883	mõõk	mõõk	mõõk	22_S	SgN	et	mõõk =mõõk  (SgN  >mõõk !22_S
35889	otsetõlkena	tõlke	otse+tõlge	06_S	SgEs	et	otsetõlkena =tõlke  (SgEs  >otse+tõlge !06_S
35894	inimloomuse	loomuse	inim+loomus	11~09_S	SgG	et	inimloomuse =loomuse  (SgG  >inim+loomus !11~09_S
35896	peegelpilt	pilt	peegel+pilt	22_S	SgN	et	peegelpilt =pilt  (SgN  >peegel+pilt !22_S
35911	arvutimängudes	mängu	arvuti+mäng	22_S	PlIn	et	arvutimängudes =mängu  (PlIn  >arvuti+mäng !22_S
35913	rõhutab	rõhuta	rõhutama	27_V	IndPrSg3	et	rõhutab =rõhuta  (IndPrSg3  >rõhutama !27_V
35918	tähendusliku	tähendusliku	tähenduslik	25_A	SgG	et	tähendusliku =tähendusliku  (SgG  >tähenduslik !25_A
35922	nimisõnaga	sõna	nimi+sõna	17_S	SgKom	et	nimisõnaga =sõna  (SgKom  >nimi+sõna !17_S
35927	särk	särk	särk	22_S	SgN	et	särk =särk  (SgN  >särk !22_S
35930	särgil	särgi	särk	22_S	SgAd	et	särgil =särgi  (SgAd  >särk !22_S
35931	rahvarõivavööga	vöö	rahva+rõiva+vöö	26_S	SgKom	et	rahvarõivavööga =vöö  (SgKom  >rahva+rõiva+vöö !26_S
35937	vajaliku	vajaliku	vajalik	25_A	SgG	et	vajaliku =vajaliku  (SgG  >vajalik !25_A
35946	püüdliku	püüdliku	püüdlik	25_A	SgG	et	püüdliku =püüdliku  (SgG  >püüdlik !25_A
35947	otsetõlkega	tõlke	otse+tõlge	06_S	SgKom	et	otsetõlkega =tõlke  (SgKom  >otse+tõlge !06_S
35964	antonüümid	antonüümi	antonüüm	22_S	PlN	et	antonüümid =antonüümi  (PlN  >antonüüm !22_S
35974	reaalseid	reaalse	reaalne	02_A	PlP	et	reaalseid =reaalse  (PlP  >reaalne !02_A
35977	tekstist	teksti	tekst	22_S	SgEl	et	tekstist =teksti  (SgEl  >tekst !22_S
35982	konverents	konverents	konverents	22_S	SgN	et	konverents =konverents  (SgN  >konverents !22_S
35994	tekstivaliku	valiku	teksti+valik	02_S	SgG	et	tekstivaliku =valiku  (SgG  >teksti+valik !02_S
36002	põhimääruse	määruse	põhi+määrus	11~09_S	SgG	et	põhimääruse =määruse  (SgG  >põhi+määrus !11~09_S
36005	ülesanded	ande	üles+anne	06_S	PlN	et	ülesanded =ande  (PlN  >üles+anne !06_S
36008	väljatöötamine	töötamine	välja+töötamine	12_S	SgN	et	väljatöötamine =töötamine  (SgN  >välja+töötamine !12_S
36010	hollandlased	hollandlase	hollandlane	12_S	PlN	et	hollandlased =hollandlase  (PlN  >hollandlane !12_S
36014	tunniplaanis	plaani	tunni+plaan	22_S	SgIn	et	tunniplaanis =plaani  (SgIn  >tunni+plaan !22_S
36017	joonistasime	joonista	joonistama	27_V	IndIpfPl1	et	joonistasime =joonista  (IndIpfPl1  >joonistama !27_V
36021	praaktikana	tika	praak+tikk	22_S	SgEs	et	praaktikana =tika  (SgEs  >praak+tikk !22_S
36038	peakirikut	kiriku	pea+kirik	02_S	SgP	et	peakirikut =kiriku  (SgP  >pea+kirik !02_S
36040	kesklinn	linn	kesk+linn	22_S	SgN	et	kesklinn =linn  (SgN  >kesk+linn !22_S
36046	teaduskondadest	teaduskonda	teaduskond	22_S	PlEl	et	teaduskondadest =teaduskonda  (PlEl  >teaduskond !22_S
36050	farmaatsiaettevõtes	võte	farmaatsia+ette+võtt	22_S	PlIn	et	farmaatsiaettevõtes =võte  (PlIn  >farmaatsia+ette+võtt !22_S
36060	töölepingut	lepingu	töö+leping	02_S	SgP	et	töölepingut =lepingu  (SgP  >töö+leping !02_S
36063	mäest	mäe	mägi	21_S	SgEl	et	mäest =mäe  (SgEl  >mägi !21_S
36072	ka-	ka	ka	41_D	ID	et	ka- =ka  (ID  >ka !41_D
36082	fraseoloogilisi	fraseoloogilisi	fraseoloogiline	12_A	PlP	et	fraseoloogilisi =fraseoloogilisi  (PlP  >fraseoloogiline !12_A
36095	fraseoloogilist	fraseoloogilis	fraseoloogiline	12_A	SgP	et	fraseoloogilist =fraseoloogilis  (SgP  >fraseoloogiline !12_A
36096	uurin	uuri	uurima	28_V	IndPrSg1	et	uurin =uuri  (IndPrSg1  >uurima !28_V
36097	anatoomiast	anatoomia	anatoomia	01_S	SgEl	et	anatoomiast =anatoomia  (SgEl  >anatoomia !01_S
36098	sõnaühendeid	ühende	sõna+ühend	02_S	PlP	et	sõnaühendeid =ühende  (PlP  >sõna+ühend !02_S
36111	antonüüme	antonüüme	antonüüm	22_S	PlP	et	antonüüme =antonüüme  (PlP  >antonüüm !22_S
36112	fraseoloogilised	fraseoloogilise	fraseoloogiline	12_A	PlN	et	fraseoloogilised =fraseoloogilise  (PlN  >fraseoloogiline !12_A
36113	liitsõnad	sõna	liit+sõna	17_S	PlN	et	liitsõnad =sõna  (PlN  >liit+sõna !17_S
36117	moodustada	moodusta	moodustama	27_V	Inf	et	moodustada =moodusta  (Inf  >moodustama !27_V
35842	murdesõnade	sõna	murde+sõna	17_S	PlG	et	murdesõnade =sõna  (PlG  >murde+sõna !17_S
35851	pideva	pideva	pidev	02_A	SgG	et	pideva =pideva  (SgG  >pidev !02_A
35852	informeeris	informeeri	informeerima	28_V	IndIpfSg3	et	informeeris =informeeri  (IndIpfSg3  >informeerima !28_V
35853	potentsiaalsetest	potentsiaalse	potentsiaalne	02_A	PlEl	et	potentsiaalsetest =potentsiaalse  (PlEl  >potentsiaalne !02_A
35861	kosmoses	kosmose	kosmos	11~09_S	SgIn	et	kosmoses =kosmose  (SgIn  >kosmos !11~09_S
35865	seiklustele	seiklus	seiklus	11~09_S	PlAll	et	seiklustele =seiklus  (PlAll  >seiklus !11~09_S
35866	inimlikud	inimliku	inimlik	25_A	PlN	et	inimlikud =inimliku  (PlN  >inimlik !25_A
35882	vööle	vöö	vöö	26_S	SgAll	et	vööle =vöö  (SgAll  >vöö !26_S
35887	transpordiameti	ameti	transpordi+amet	02_S	SgG	et	transpordiameti =ameti  (SgG  >transpordi+amet !02_S
35888	võrdlus	võrdlus	võrdlus	11~09_S	SgN	et	võrdlus =võrdlus  (SgN  >võrdlus !11~09_S
35892	otsenähtavale	nähtava	otse+nähtav	02_A	SgAll	et	otsenähtavale =nähtava  (SgAll  >otse+nähtav !02_A
35900	olemusi	olemusi	olemus	11_S	PlP	et	olemusi =olemusi  (PlP  >olemus !11_S
35905	keelset	keelse	keelne	02_A	SgP	et	keelset =keelse  (SgP  >keelne !02_A
35909	maagiat	maagia	maagia	01_S	SgP	et	maagiat =maagia  (SgP  >maagia !01_S
35915	kursis	kursi	kurss	22_S	SgIn	et	kursis =kursi  (SgIn  >kurss !22_S
35933	kehastub	kehastu	kehastuma	27_V	IndPrSg3	et	kehastub =kehastu  (IndPrSg3  >kehastuma !27_V
35940	ettevõtmiseks	võtmise	ette+võtmine	12?10_S	SgTr	et	ettevõtmiseks =võtmise  (SgTr  >ette+võtmine !12?10_S
35948	keelse	keelse	keelne	02_A	SgG	et	keelse =keelse  (SgG  >keelne !02_A
35953	tunnusjoone	joone	tunnus+joon	13_S	SgG	et	tunnusjoone =joone  (SgG  >tunnus+joon !13_S
35956	semantiline	semantiline	semantiline	12_A	SgN	et	semantiline =semantiline  (SgN  >semantiline !12_A
35958	liikme	liikme	liige	05_S	SgG	et	liikme =liikme  (SgG  >liige !05_S
35959	vastandub	vastandu	vastanduma	27_V	IndPrSg3	et	vastandub =vastandu  (IndPrSg3  >vastanduma !27_V
35960	sümmeetriline	sümmeetriline	sümmeetriline	12_A	SgN	et	sümmeetriline =sümmeetriline  (SgN  >sümmeetriline !12_A
35962	vastandatakse	vastanda	vastandama	27_V	IndPrIps	et	vastandatakse =vastanda  (IndPrIps  >vastandama !27_V
35973	noomenite	noomeni	noomen	02_S	PlG	et	noomenite =noomeni  (PlG  >noomen !02_S
35975	esemeid	eseme	ese	04_S	PlP	et	esemeid =eseme  (PlP  >ese !04_S
35978	terviku	terviku	tervik	02_S	SgG	et	terviku =terviku  (SgG  >tervik !02_S
35980	proovile	proovi	proov	22_S	SgAll	et	proovile =proovi  (SgAll  >proov !22_S
35981	kokkuleppele	leppe	kokku+lepe	06_S	SgAll	et	kokkuleppele =leppe  (SgAll  >kokku+lepe !06_S
35987	käesoleva	oleva	käes+olev	02_A	SgG	et	käesoleva =oleva  (SgG  >käes+olev !02_A
35989	korpuse	korpuse	korpus	11~09_S	SgG	et	korpuse =korpuse  (SgG  >korpus !11~09_S
35991	baaskorpus	korpus	baas+korpus	11~09_S	SgN	et	baaskorpus =korpus  (SgN  >baas+korpus !11~09_S
35993	selgitatakse	selgita	selgitama	27_V	IndPrIps	et	selgitatakse =selgita  (IndPrIps  >selgitama !27_V
35997	segakorpuse	korpuse	sega+korpus	11~09_S	SgG	et	segakorpuse =korpuse  (SgG  >sega+korpus !11~09_S
35998	tekstiklassid	klassi	teksti+klass	22_S	PlN	et	tekstiklassid =klassi  (PlN  >teksti+klass !22_S
35999	paraleele	lee	para+lee	26_S	SgAll	et	paraleele =lee  (SgAll  >para+lee !26_S
36000	baaskorpuse	korpuse	baas+korpus	11~09_S	SgG	et	baaskorpuse =korpuse  (SgG  >baas+korpus !11~09_S
36001	valitsemisalas	ala	valitsemis+ala	17_S	SgIn	et	valitsemisalas =ala  (SgIn  >valitsemis+ala !17_S
36007	arengukavade	kava	arengu+kava	17_S	PlG	et	arengukavade =kava  (PlG  >arengu+kava !17_S
36009	arengukavadega	kava	arengu+kava	17_S	PlKom	et	arengukavadega =kava  (PlKom  >arengu+kava !17_S
36012	sõbrannal	sõbranna	sõbranna	16_S	SgAd	et	sõbrannal =sõbranna  (SgAd  >sõbranna !16_S
36018	perepäevad	päeva	pere+päev	22_S	PlN	et	perepäevad =päeva  (PlN  >pere+päev !22_S
36020	tuletada	tuleta	tuletama	27_V	Inf	et	tuletada =tuleta  (Inf  >tuletama !27_V
36022	piltsellel	selle	pilt+sell	22_S	PlAd	et	piltsellel =selle  (PlAd  >pilt+sell !22_S
36023	tuletorn	torn	tule+torn	22_S	SgN	et	tuletorn =torn  (SgN  >tule+torn !22_S
36026	edusid	edu	edu	17_S	PlP	et	edusid =edu  (PlP  >edu !17_S
36029	vastama	vasta	vastama	29_V	Sup	et	vastama =vasta  (Sup  >vastama !29_V
36032	ümberistumisega	istumise	ümber+istumine	12_S	SgKom	et	ümberistumisega =istumise  (SgKom  >ümber+istumine !12_S
36036	tutvustas	tutvusta	tutvustama	27_V	IndIpfSg3	et	tutvustas =tutvusta  (IndIpfSg3  >tutvustama !27_V
36037	küllastasime	küllasta	küllastama	27_V	IndIpfPl1	et	küllastasime =küllasta  (IndIpfPl1  >küllastama !27_V
36041	sell	sell	sell	22_S	SgN	et	sell =sell  (SgN  >sell !22_S
36042	jõuluehted	ehte	jõulu+ehe	06_S	PlN	et	jõuluehted =ehte  (PlN  >jõulu+ehe !06_S
36045	majandusteaduskond	teaduskond	majandus+teaduskond	22_S	SgN	et	majandusteaduskond =teaduskond  (SgN  >majandus+teaduskond !22_S
35971	ühtemoodi	ühtemoodi	ühte+moodi	41_DA	ID	et	ühtemoodi =ühtemoodi  (ID  >ühte+moodi !41_DA
35972	suhetegagi	suhe	suhe	06_S	PlKom^	et	suhetegagi =suhe  (PlKom^  >suhe !06_S
35976	leksikaalne	leksikaalne	leksikaalne	02_A	SgN	et	leksikaalne =leksikaalne  (SgN  >leksikaalne !02_A
35979	teemaga	teema	teema	16_S	SgKom	et	teemaga =teema  (SgKom  >teema !16_S
35983	referaadiga	referaadi	referaat	22_S	SgKom	et	referaadiga =referaadi  (SgKom  >referaat !22_S
35984	põhikomponendid	komponendi	põhi+komponent	22_S	PlN	et	põhikomponendid =komponendi  (PlN  >põhi+komponent !22_S
35988	korpustest	korpus	korpus	11~09_S	PlEl	et	korpustest =korpus  (PlEl  >korpus !11~09_S
35990	andmaks	and	andma	34_V	SupTr	et	andmaks =and  (SupTr  >andma !34_V
35992	läbilõikekorpustega	korpus	läbi+lõike+korpus	11~09_S	PlKom	et	läbilõikekorpustega =korpus  (PlKom  >läbi+lõike+korpus !11~09_S
35995	kriteeriumite	kriteeriumi	kriteerium	02_S	PlG	et	kriteeriumite =kriteeriumi  (PlG  >kriteerium !02_S
35996	tekstiklasside	klassi	teksti+klass	22_S	PlG	et	tekstiklasside =klassi  (PlG  >teksti+klass !22_S
36004	efektiivne	efektiivne	efektiivne	02_A	SgN	et	efektiivne =efektiivne  (SgN  >efektiivne !02_A
36006	elluviimise	viimise	ellu+viimine	12?10_S	SgG	et	elluviimise =viimise  (SgG  >ellu+viimine !12?10_S
36015	õppeainet	aine	õppe+aine	06_S	SgP	et	õppeainet =aine  (SgP  >õppe+aine !06_S
36019	ekskursioone	ekskursioone	ekskursioon	22_S	PlP	et	ekskursioone =ekskursioone  (PlP  >ekskursioon !22_S
36025	puudusin	puudu	puuduma	27_V	IndIpfSg1	et	puudusin =puudu  (IndIpfSg1  >puuduma !27_V
36028	vigade	viga	viga	18_S	PlG	et	vigade =viga  (PlG  >viga !18_S
36033	taksojuhile	juhi	takso+juht	22_S	SgAll	et	taksojuhile =juhi  (SgAll  >takso+juht !22_S
36034	vanaemade	ema	vana+ema	17_S	PlG	et	vanaemade =ema  (PlG  >vana+ema !17_S
36044	näikse	näikse	näikse	41_X	ID	et	näikse =näikse  (ID  >näikse !41_X
36051	ravimite	ravimi	ravim	02_S	PlG	et	ravimite =ravimi  (PlG  >ravim !02_S
36052	paluma	palu	paluma	27_V	Sup	et	paluma =palu  (Sup  >paluma !27_V
36053	õppimast	õppi	õppima	28_V	SupEl	et	õppimast =õppi  (SupEl  >õppima !28_V
36058	õigsuses	õigsuse	õigsus	11~09_S	SgIn	et	õigsuses =õigsuse  (SgIn  >õigsus !11~09_S
36068	filmide	filmi	film	22_S	PlG	et	filmide =filmi  (PlG  >film !22_S
36070	geniaalne	geniaalne	geniaalne	02_A	SgN	et	geniaalne =geniaalne  (SgN  >geniaalne !02_A
36076	sõnaühenditest	ühendi	sõna+ühend	02_S	PlEl	et	sõnaühenditest =ühendi  (PlEl  >sõna+ühend !02_S
36079	fraseoloogiaks	fraseoloogia	fraseoloogia	01_S	SgTr	et	fraseoloogiaks =fraseoloogia  (SgTr  >fraseoloogia !01_S
36085	fraseologism	fraseologism	fraseologism	22_S	SgN	et	fraseologism =fraseologism  (SgN  >fraseologism !22_S
36091	kvalifitseerida	kvalifitseeri	kvalifitseerima	28_V	Inf	et	kvalifitseerida =kvalifitseeri  (Inf  >kvalifitseerima !28_V
36092	fraseologismidena	fraseologismi	fraseologism	22_S	PlEs	et	fraseologismidena =fraseologismi  (PlEs  >fraseologism !22_S
36093	referaadis	referaadi	referaat	22_S	SgIn	et	referaadis =referaadi  (SgIn  >referaat !22_S
36094	käsitlen	käsitle	käsitlema	27_V	IndPrSg1	et	käsitlen =käsitle  (IndPrSg1  >käsitlema !27_V
36099	tõin	tõ	tooma	38_V	IndIpfSg1	et	tõin =tõ  (IndIpfSg1  >tooma !38_V
36104	käsitleb	käsitle	käsitlema	27_V	IndPrSg3	et	käsitleb =käsitle  (IndPrSg3  >käsitlema !27_V
36105	siinkohal	siinkohal	siin+kohal	41_D	ID	et	siinkohal =siinkohal  (ID  >siin+kohal !41_D
36106	eesmärkide	märki	ees+märk	22_S	PlG	et	eesmärkide =märki  (PlG  >ees+märk !22_S
36107	primaarseid	primaarse	primaarne	02_A	PlP	et	primaarseid =primaarse  (PlP  >primaarne !02_A
36109	pööran	pööra	pöörama	29_V	IndPrSg1	et	pööran =pööra  (IndPrSg1  >pöörama !29_V
36115	liitsõnu	sõnu	liit+sõna	17_S	PlP	et	liitsõnu =sõnu  (PlP  >liit+sõna !17_S
36119	mittekorrektne	korrektne	mitte+korrektne	02_A	SgN	et	mittekorrektne =korrektne  (SgN  >mitte+korrektne !02_A
36123	peatükina	tüki	pea+tükk	22_S	SgEs	et	peatükina =tüki  (SgEs  >pea+tükk !22_S
36127	iseseisva	seisva	ise+seisev	02_A	SgG	et	iseseisva =seisva  (SgG  >ise+seisev !02_A
36129	keelekümbluses	kümbluse	keele+kümblus	11~09_S	SgIn	et	keelekümbluses =kümbluse  (SgIn  >keele+kümblus !11~09_S
36130	uuring	uuring	uuring	02_S	SgN	et	uuring =uuring  (SgN  >uuring !02_S
36138	kaudseid	kaudse	kaudne	02_A	PlP	et	kaudseid =kaudse  (PlP  >kaudne !02_A
36146	uurimus	uurimus	uurimus	11_S	SgN	et	uurimus =uurimus  (SgN  >uurimus !11_S
36162	tabel	tabel	tabel	02_S	SgN	et	tabel =tabel  (SgN  >tabel !02_S
36164	kähku	kähku	kähku	41_D	ID	et	kähku =kähku  (ID  >kähku !41_D
36168	allikat	allika	allikas	02_S	SgP	et	allikat =allika  (SgP  >allikas !02_S
36169	seab	sea	seadma	34_V	IndPrSg3	et	seab =sea  (IndPrSg3  >seadma !34_V
36176	kakskeelne	keelne	kaks+keelne	02_A	SgN	et	kakskeelne =keelne  (SgN  >kaks+keelne !02_A
36180	metslang	lang	mets+lang	22_S	SgN	et	metslang =lang  (SgN  >mets+lang !22_S
36047	ülalpeetav	pee	ülal+_pidama	28_V	PtsPrIps	et	ülalpeetav =pee  (PtsPrIps  >ülal+_pidama !28_V
36048	sõltuma	sõltu	sõltuma	27_V	Sup	et	sõltuma =sõltu  (Sup  >sõltuma !27_V
36049	teisipäevati	ati	teisi+päev+att	22_S	SgG	et	teisipäevati =ati  (SgG  >teisi+päev+att !22_S
36054	segada	sega	segama	27_V	Inf	et	segada =sega  (Inf  >segama !27_V
36055	osakoormusega	koormuse	osa+koormus	11~09_S	SgKom	et	osakoormusega =koormuse  (SgKom  >osa+koormus !11~09_S
36057	jätma	jät	jätma	35_V	Sup	et	jätma =jät  (Sup  >jätma !35_V
36061	atraktsioon	atraktsioon	atraktsioon	22_S	SgN	et	atraktsioon =atraktsioon  (SgN  >atraktsioon !22_S
36064	laskuda	lasku	laskuma	27_V	Inf	et	laskuda =lasku  (Inf  >laskuma !27_V
36065	venitasin	venita	venitama	27_V	IndIpfSg1	et	venitasin =venita  (IndIpfSg1  >venitama !27_V
36066	puutusin	puutu	puutuma	27_V	IndIpfSg1	et	puutusin =puutu  (IndIpfSg1  >puutuma !27_V
36067	filmidega	filmi	film	22_S	PlKom	et	filmidega =filmi  (PlKom  >film !22_S
36075	terviklike	terviklike	terviklik	25_A	PlG	et	terviklike =terviklike  (PlG  >terviklik !25_A
36080	sõnakõlkse	kõlkse	sõna+kõlks	22_S	PlP	et	sõnakõlkse =kõlkse  (PlP  >sõna+kõlks !22_S
36081	katteta	katte	kate	06_S	SgAb	et	katteta =katte  (SgAb  >kate !06_S
36086	keeleteadlased	teadlase	keele+teadlane	12?10_S	PlN	et	keeleteadlased =teadlase  (PlN  >keele+teadlane !12?10_S
36101	kõnekäänud	käänu	kõne+käänd	22_S	PlN	et	kõnekäänud =käänu  (PlN  >kõne+käänd !22_S
36103	magistritööle	töö	magistri+töö	26_S	SgAll	et	magistritööle =töö  (SgAll  >magistri+töö !26_S
36110	sünonüüme	sünonüüme	sünonüüm	22_S	PlP	et	sünonüüme =sünonüüme  (PlP  >sünonüüm !22_S
36118	sisusse	sisu	sisu	17_S	SgIll	et	sisusse =sisu  (SgIll  >sisu !17_S
36121	peatükk	tükk	pea+tükk	22_S	SgN	et	peatükk =tükk  (SgN  >pea+tükk !22_S
36126	analüüsib	analüüsi	analüüsima	28_V	IndPrSg3	et	analüüsib =analüüsi  (IndPrSg3  >analüüsima !28_V
36133	sisule	sisu	sisu	17_S	SgAll	et	sisule =sisu  (SgAll  >sisu !17_S
36134	kontekstis	konteksti	kontekst	22_S	SgIn	et	kontekstis =konteksti  (SgIn  >kontekst !22_S
36136	otseseid	otsese	otsene	10_A	PlP	et	otseseid =otsese  (PlP  >otsene !10_A
36137	seoseid	seose	seos	09_S	PlP	et	seoseid =seose  (PlP  >seos !09_S
36145	keeleomandamisele	omandamise	keele+omandamine	12_S	SgAll	et	keeleomandamisele =omandamise  (SgAll  >keele+omandamine !12_S
36148	ilmselgeid	selge	ilm+selge	01_A	PlP	et	ilmselgeid =selge  (PlP  >ilm+selge !01_A
36149	obligatoorne	obligatoorne	obligatoorne	02_A	SgN	et	obligatoorne =obligatoorne  (SgN  >obligatoorne !02_A
36154	omandamisprotsesside	protsessi	omandamis+protsess	22_S	PlG	et	omandamisprotsesside =protsessi  (PlG  >omandamis+protsess !22_S
36160	konn	konn	konn	22_S	SgN	et	konn =konn  (SgN  >konn !22_S
36161	emakeelega	keele	ema+keel	13_S	SgKom	et	emakeelega =keele  (SgKom  >ema+keel !13_S
36174	väljaanded	ande	välja+anne	06_S	PlN	et	väljaanded =ande  (PlN  >välja+anne !06_S
36179	keeleoskuse	oskuse	keele+oskus	11~09_S	SgG	et	keeleoskuse =oskuse  (SgG  >keele+oskus !11~09_S
36185	keelekümblus	kümblus	keele+kümblus	11~09_S	SgN	et	keelekümblus =kümblus  (SgN  >keele+kümblus !11~09_S
36187	strateegiad	strateegia	strateegia	01_S	PlN	et	strateegiad =strateegia  (PlN  >strateegia !01_S
36190	integratsioonile	integratsiooni	integratsioon	22_S	SgAll	et	integratsioonile =integratsiooni  (SgAll  >integratsioon !22_S
36196	väljaandele	ande	välja+anne	06_S	SgAll	et	väljaandele =ande  (SgAll  >välja+anne !06_S
36198	rohkesti	rohkesti	rohkesti	41_D	ID	et	rohkesti =rohkesti  (ID  >rohkesti !41_D
36216	kõnekeelseid	keelse	kõne+keelne	02_A	PlP	et	kõnekeelseid =keelse  (PlP  >kõne+keelne !02_A
36217	lihtlauseid	lause	liht+lause	06_S	PlP	et	lihtlauseid =lause  (PlP  >liht+lause !06_S
36218	üldsõnavaraga	vara	üld+sõna+vara	17_S	SgKom	et	üldsõnavaraga =vara  (SgKom  >üld+sõna+vara !17_S
36223	väitluse	väitluse	väitlus	11~09_S	SgG	et	väitluse =väitluse  (SgG  >väitlus !11~09_S
36226	võõrkeeleõpetuse	õpetuse	võõr+keele+õpetus	11_S	SgG	et	võõrkeeleõpetuse =õpetuse  (SgG  >võõr+keele+õpetus !11_S
36229	millistele	millis	milline	10_P	PlAll	et	millistele =millis  (PlAll  >milline !10_P
36235	kirjutate	kirjuta	kirjutama	27_V	IndPrPl2	et	kirjutate =kirjuta  (IndPrPl2  >kirjutama !27_V
36238	uurimisküsimuse	küsimuse	uurimis+küsimus	11_S	SgG	et	uurimisküsimuse =küsimuse  (SgG  >uurimis+küsimus !11_S
36243	keeleõpetamise	õpetamise	keele+õpetamine	12_S	SgG	et	keeleõpetamise =õpetamise  (SgG  >keele+õpetamine !12_S
36258	puhthariduslike	hariduslike	puht+hariduslik	25_A	PlG	et	puhthariduslike =hariduslike  (PlG  >puht+hariduslik !25_A
36262	ettevalmistamiseks	valmistamise	ette+valmistamine	12_S	SgTr	et	ettevalmistamiseks =valmistamise  (SgTr  >ette+valmistamine !12_S
36267	segane	segane	segane	10_A	SgN	et	segane =segane  (SgN  >segane !10_A
36275	niiviisi	niiviisi	nii+viisi	41_D	ID	et	niiviisi =niiviisi  (ID  >nii+viisi !41_D
36100	fraseologismid	fraseologismi	fraseologism	22_S	PlN	et	fraseologismid =fraseologismi  (PlN  >fraseologism !22_S
36102	retsensioon	retsensioon	retsensioon	22_S	SgN	et	retsensioon =retsensioon  (SgN  >retsensioon !22_S
36108	sekundaarseid	sekundaarse	sekundaarne	02_A	PlP	et	sekundaarseid =sekundaarse  (PlP  >sekundaarne !02_A
36114	praktilises	praktilise	praktiline	12_A	SgIn	et	praktilises =praktilise  (SgIn  >praktiline !12_A
36116	tuletised	tuletise	tuletis	11_S	PlN	et	tuletised =tuletise  (PlN  >tuletis !11_S
36120	peatükist	tüki	pea+tükk	22_S	SgEl	et	peatükist =tüki  (SgEl  >pea+tükk !22_S
36135	retsensent	retsensent	retsensent	22_S	SgN	et	retsensent =retsensent  (SgN  >retsensent !22_S
36139	lahtiseletamise	seletamise	lahti+seletamine	12_S	SgG	et	lahtiseletamise =seletamise  (SgG  >lahti+seletamine !12_S
36140	peatüki	tüki	pea+tükk	22_S	SgG	et	peatüki =tüki  (SgG  >pea+tükk !22_S
36144	uurimissuund	suund	uurimis+suund	22_S	SgN	et	uurimissuund =suund  (SgN  >uurimis+suund !22_S
36147	keelekümbluse	kümbluse	keele+kümblus	11~09_S	SgG	et	keelekümbluse =kümbluse  (SgG  >keele+kümblus !11~09_S
36155	hinnangu	hinnangu	hinnang	02_S	SgG	et	hinnangu =hinnangu  (SgG  >hinnang !02_S
36156	analüütiline	analüütiline	analüütiline	12_A	SgN	et	analüütiline =analüütiline  (SgN  >analüütiline !12_A
36159	keelekümblejat	kümbleja	keele+kümbleja	01_S	SgP	et	keelekümblejat =kümbleja  (SgP  >keele+kümbleja !01_S
36163	sõnavaraga	vara	sõna+vara	17_S	SgKom	et	sõnavaraga =vara  (SgKom  >sõna+vara !17_S
36165	mittetundmine	tundmine	mitte+tundmine	12?10_S	SgN	et	mittetundmine =tundmine  (SgN  >mitte+tundmine !12?10_S
36166	bibliograafias	bibliograafia	bibliograafia	01_S	SgIn	et	bibliograafias =bibliograafia  (SgIn  >bibliograafia !01_S
36167	ingliskeelne	keelne	inglis+keelne	02_A	SgN	et	ingliskeelne =keelne  (SgN  >inglis+keelne !02_A
36171	magistrikraadile	kraadi	magistri+kraad	22_S	SgAll	et	magistrikraadile =kraadi  (SgAll  >magistri+kraad !22_S
36181	helle	helle	hell	22_A	PlP	et	helle =helle  (PlP  >hell !22_A
36182	elle	elle	ell	22_S	PlP	et	elle =elle  (PlP  >ell !22_S
36191	toimetised	toimetise	toimetis	11_S	PlN	et	toimetised =toimetise  (PlN  >toimetis !11_S
36192	ülaltooduga	toodu	ülal+toodu	01_S	SgKom	et	ülaltooduga =toodu  (SgKom  >ülal+toodu !01_S
36194	loetelus	loetelu	loetelu	17_S	SgIn	et	loetelus =loetelu  (SgIn  >loetelu !17_S
36201	sõnavaral	vara	sõna+vara	17_S	SgAd	et	sõnavaral =vara  (SgAd  >sõna+vara !17_S
36202	olemasolevad	oleva	olemas+olev	02_A	PlN	et	olemasolevad =oleva  (PlN  >olemas+olev !02_A
36205	mõtteskeemiga	skeemi	mõtte+skeem	22_S	SgKom	et	mõtteskeemiga =skeemi  (SgKom  >mõtte+skeem !22_S
36209	uueneb	uuene	uuenema	27_V	IndPrSg3	et	uueneb =uuene  (IndPrSg3  >uuenema !27_V
36212	neutraalsed	neutraalse	neutraalne	02_A	PlN	et	neutraalsed =neutraalse  (PlN  >neutraalne !02_A
36214	tautoloogiat	tautoloogia	tautoloogia	01_S	SgP	et	tautoloogiat =tautoloogia  (SgP  >tautoloogia !01_S
36224	väidate	väida	väitma	34_V	IndPrPl2	et	väidate =väida  (IndPrPl2  >väitma !34_V
36230	uuringutele	uuringu	uuring	02_S	PlAll	et	uuringutele =uuringu  (PlAll  >uuring !02_S
36232	kakskeelse	keelse	kaks+keelne	02_A	SgG	et	kakskeelse =keelse  (SgG  >kaks+keelne !02_A
36254	magistritöödele	töö	magistri+töö	26_S	PlAll	et	magistritöödele =töö  (PlAll  >magistri+töö !26_S
36255	eestikeelsele	keelse	eesti+keelne	02_A	SgAll	et	eestikeelsele =keelse  (SgAll  >eesti+keelne !02_A
36261	seeläbi	seeläbi	see+läbi	41_D	ID	et	seeläbi =seeläbi  (ID  >see+läbi !41_D
36263	uurimismeetodina	meetodi	uurimis+meetod	02_S	SgEs	et	uurimismeetodina =meetodi  (SgEs  >uurimis+meetod !02_S
36265	koolijuhtide	juhti	kooli+juht	22_S	PlG	et	koolijuhtide =juhti  (PlG  >kooli+juht !22_S
36273	ilmneb	ilmne	ilmnema	27_V	IndPrSg3	et	ilmneb =ilmne  (IndPrSg3  >ilmnema !27_V
36281	teoreetikutele	teoreetiku	teoreetik	02_S	PlAll	et	teoreetikutele =teoreetiku  (PlAll  >teoreetik !02_S
36282	kokkuvõtliku	võtliku	kokku+võtlik	25_A	SgG	et	kokkuvõtliku =võtliku  (SgG  >kokku+võtlik !25_A
36284	kommunikatsioonistrateegiaid	strateegia	kommunikatsiooni+strateegia	01_S	PlP	et	kommunikatsioonistrateegiaid =strateegia  (PlP  >kommunikatsiooni+strateegia !01_S
36285	raskesse	raske	raske	01_A	SgIll	et	raskesse =raske  (SgIll  >raske !01_A
36291	meediakajastusi	kajastusi	meedia+kajastus	11_S	PlP	et	meediakajastusi =kajastusi  (PlP  >meedia+kajastus !11_S
36292	värvikad	värvika	värvikas	02_A	PlN	et	värvikad =värvika  (PlN  >värvikas !02_A
36295	pealkirjade	kirja	peal+kiri	24_S	PlG	et	pealkirjade =kirja  (PlG  >peal+kiri !24_S
36297	kirjutiste	kirjutis	kirjutis	11_S	PlG	et	kirjutiste =kirjutis  (PlG  >kirjutis !11_S
36299	koolidesse	kooli	kool	22_S	PlIll	et	koolidesse =kooli  (PlIll  >kool !22_S
36305	hoiakuid	hoiaku	hoiak	02_S	PlP	et	hoiakuid =hoiaku  (PlP  >hoiak !02_S
36306	kaardistada	kaardista	kaardistama	27_V	Inf	et	kaardistada =kaardista  (Inf  >kaardistama !27_V
36307	infovajadused	vajaduse	info+vajadus	11_S	PlN	et	infovajadused =vajaduse  (PlN  >info+vajadus !11_S
36122	kaaluma	kaalu	kaaluma	28_V	Sup	et	kaaluma =kaalu  (Sup  >kaaluma !28_V
36128	keelekümblus-	kümblus	keele+kümblus	11~09_S	SgN	et	keelekümblus- =kümblus  (SgN  >keele+kümblus !11~09_S
36141	teooriate	teooria	teooria	01_S	PlG	et	teooriate =teooria  (PlG  >teooria !01_S
36142	mudel	mudel	mudel	02_S	SgN	et	mudel =mudel  (SgN  >mudel !02_S
36153	meetoditest	meetodi	meetod	02_S	PlEl	et	meetoditest =meetodi  (PlEl  >meetod !02_S
36158	kaugeleulatuvaid	ulatuva	kaugele+ulatuv	02_A	PlP	et	kaugeleulatuvaid =ulatuva  (PlP  >kaugele+ulatuv !02_A
36172	soliidne	soliidne	soliidne	02_A	SgN	et	soliidne =soliidne  (SgN  >soliidne !02_A
36173	teoreetiline	teoreetiline	teoreetiline	12_A	SgN	et	teoreetiline =teoreetiline  (SgN  >teoreetiline !12_A
36175	multilingual	lingua	multi+lingua	01_S	SgAd	et	multilingual =lingua  (SgAd  >multi+lingua !01_S
36177	kikerpill	pill	kiker+pill	22_S	SgN	et	kikerpill =pill  (SgN  >kiker+pill !22_S
36183	keelehärm	härm	keele+härm	22_S	SgN	et	keelehärm =härm  (SgN  >keele+härm !22_S
36188	õppes	õppe	õpe	06_S	SgIn	et	õppes =õppe  (SgIn  >õpe !06_S
36206	temapoolset	poolse	tema+poolne	02_A	SgP	et	temapoolset =poolse  (SgP  >tema+poolne !02_A
36213	keelendid	keelendi	keelend	02_S	PlN	et	keelendid =keelendi  (PlN  >keelend !02_S
36219	tegevõpetajale	õpetaja	tegev+õpetaja	01_S	SgAll	et	tegevõpetajale =õpetaja  (SgAll  >tegev+õpetaja !01_S
36220	võrdluskeelendid	keelendi	võrdlus+keelend	02_S	PlN	et	võrdluskeelendid =keelendi  (PlN  >võrdlus+keelend !02_S
36221	liitnimisõnade	sõna	liit+nimi+sõna	17_S	PlG	et	liitnimisõnade =sõna  (PlG  >liit+nimi+sõna !17_S
36222	omadussõnade	sõna	omadus+sõna	17_S	PlG	et	omadussõnade =sõna  (PlG  >omadus+sõna !17_S
36227	kommunikatiivsete	kommunikatiivse	kommunikatiivne	02_A	PlG	et	kommunikatiivsete =kommunikatiivse  (PlG  >kommunikatiivne !02_A
36231	viidet	viide	viide	06_S	SgP	et	viidet =viide  (SgP  >viide !06_S
36233	tähelepanek	panek	tähele+panek	02_S	SgN	et	tähelepanek =panek  (SgN  >tähele+panek !02_S
36236	missugustele	sugus	mis+sugune	10_P	PlAll	et	missugustele =sugus  (PlAll  >mis+sugune !10_P
36239	võte	võte	võte	06_S	SgN	et	võte =võte  (SgN  >võte !06_S
36240	konkreetseid	konkreetse	konkreetne	02_A	PlP	et	konkreetseid =konkreetse  (PlP  >konkreetne !02_A
36241	lähedane	lähedane	lähedane	12_AS	SgN	et	lähedane =lähedane  (SgN  >lähedane !12_AS
36242	viited	viite	viide	06_S	PlN	et	viited =viite  (PlN  >viide !06_S
36248	niisuguseid	suguse	nii+sugune	10_P	PlP	et	niisuguseid =suguse  (PlP  >nii+sugune !10_P
36249	tõlkeülesanded	ande	tõlke+üles+anne	06_S	PlN	et	tõlkeülesanded =ande  (PlN  >tõlke+üles+anne !06_S
36260	sihtrühmade	rühma	siht+rühm	22_S	PlG	et	sihtrühmade =rühma  (PlG  >siht+rühm !22_S
36264	süvaintervjuusid	intervjuu	süva+intervjuu	26_S	PlP	et	süvaintervjuusid =intervjuu  (PlP  >süva+intervjuu !26_S
36266	aineõpetajate	õpetaja	aine+õpetaja	01_S	PlG	et	aineõpetajate =õpetaja  (PlG  >aine+õpetaja !01_S
36270	ingliskeelset	keelse	inglis+keelne	02_A	SgP	et	ingliskeelset =keelse  (SgP  >inglis+keelne !02_A
36272	pealkirjad	kirja	peal+kiri	24_S	PlN	et	pealkirjad =kirja  (PlN  >peal+kiri !24_S
36274	koosnebki	koosne	koosnema	27_V	IndPrSg3^	et	koosnebki =koosne  (IndPrSg3^  >koosnema !27_V
36286	autoripoolsed	poolse	autori+poolne	02_A	PlN	et	autoripoolsed =poolse  (PlN  >autori+poolne !02_A
36294	silmatorkava	torkava	silma+torkav	02_A	SgG	et	silmatorkava =torkava  (SgG  >silma+torkav !02_A
36302	hoiakutest	hoiaku	hoiak	02_S	PlEl	et	hoiakutest =hoiaku  (PlEl  >hoiak !02_S
36308	pedagoogid	pedagoogi	pedagoog	22_S	PlN	et	pedagoogid =pedagoogi  (PlN  >pedagoog !22_S
36312	sõnumite	sõnumi	sõnum	02_S	PlG	et	sõnumite =sõnumi  (PlG  >sõnum !02_S
36320	hakkate	hakka	hakkama	29_V	IndPrPl2	et	hakkate =hakka  (IndPrPl2  >hakkama !29_V
36323	missugustest	sugus	mis+sugune	10_P	PlEl	et	missugustest =sugus  (PlEl  >mis+sugune !10_P
36337	seostate	seosta	seostama	27_V	IndPrPl2	et	seostate =seosta  (IndPrPl2  >seostama !27_V
36340	sillamäel	mäe	silla+mägi	21_S	SgAd	et	sillamäel =mäe  (SgAd  >silla+mägi !21_S
36342	kantseleilik	kantseleilik	kantseleilik	25_A	SgN	et	kantseleilik =kantseleilik  (SgN  >kantseleilik !25_A
36352	hoiakut	hoiaku	hoiak	02_S	SgP	et	hoiakut =hoiaku  (SgP  >hoiak !02_S
36356	leksikaalsetest	leksikaalse	leksikaalne	02_A	PlEl	et	leksikaalsetest =leksikaalse  (PlEl  >leksikaalne !02_A
36359	võtmesõnad	sõna	võtme+sõna	17_S	PlN	et	võtmesõnad =sõna  (PlN  >võtme+sõna !17_S
36362	täissünonüüm	sünonüüm	täis+sünonüüm	22_S	SgN	et	täissünonüüm =sünonüüm  (SgN  >täis+sünonüüm !22_S
36363	grammatiline	grammatiline	grammatiline	12_A	SgN	et	grammatiline =grammatiline  (SgN  >grammatiline !12_A
36365	loetellu	loetellu	loetelu	17_S	SgAdt	et	loetellu =loetellu  (SgAdt  >loetelu !17_S
36369	emalt	ema	ema	17_S	SgAbl	et	emalt =ema  (SgAbl  >ema !17_S
36372	sõbrannalt	sõbranna	sõbranna	16_S	SgAbl	et	sõbrannalt =sõbranna  (SgAbl  >sõbranna !16_S
36152	kirjeldama	kirjelda	kirjeldama	27_V	Sup	et	kirjeldama =kirjelda  (Sup  >kirjeldama !27_V
36157	eelarvamusega	arvamuse	eel+arvamus	11_S	SgKom	et	eelarvamusega =arvamuse  (SgKom  >eel+arvamus !11_S
36170	allikate	allika	allikas	02_S	PlG	et	allikate =allika  (PlG  >allikas !02_S
36178	rõigas	rõigas	rõigas	07_S	SgN	et	rõigas =rõigas  (SgN  >rõigas !07_S
36186	mitteverbaalsed	verbaalse	mitte+verbaalne	02_A	PlN	et	mitteverbaalsed =verbaalse  (PlN  >mitte+verbaalne !02_A
36193	magistritöös	töö	magistri+töö	26_S	SgIn	et	magistritöös =töö  (SgIn  >magistri+töö !26_S
36195	nimistus	nimistu	nimistu	01_S	SgIn	et	nimistus =nimistu  (SgIn  >nimistu !01_S
36197	mart	mart	mart	22_S	SgN	et	mart =mart  (SgN  >mart !22_S
36203	haakavad	ava	haak+ava	17_S	PlN	et	haakavad =ava  (PlN  >haak+ava !17_S
36207	tingimustele	tingimus	tingimus	11_S	PlAll	et	tingimustele =tingimus  (PlAll  >tingimus !11_S
36211	sõnavormis	vormi	sõna+vorm	22_S	SgIn	et	sõnavormis =vormi  (SgIn  >sõna+vorm !22_S
36215	retoorilisi	retoorilisi	retooriline	12_A	PlP	et	retoorilisi =retoorilisi  (PlP  >retooriline !12_A
36225	huviorbiidist	orbiidi	huvi+orbiit	22_S	SgEl	et	huviorbiidist =orbiidi  (SgEl  >huvi+orbiit !22_S
36237	kavatsete	kavatse	kavatsema	27_V	IndPrPl2	et	kavatsete =kavatse  (IndPrPl2  >kavatsema !27_V
36244	metoodikas	metoodika	metoodika	01_S	SgIn	et	metoodikas =metoodika  (SgIn  >metoodika !01_S
36246	arvamused	arvamuse	arvamus	11_S	PlN	et	arvamused =arvamuse  (PlN  >arvamus !11_S
36247	nendite	nendi	nentima	28_V	IndPrPl2	et	nendite =nendi  (IndPrPl2  >nentima !28_V
36251	ingliskeelse	keelse	inglis+keelne	02_A	SgG	et	ingliskeelse =keelse  (SgG  >inglis+keelne !02_A
36253	representatiivne	representatiivne	representatiivne	02_A	SgN	et	representatiivne =representatiivne  (SgN  >representatiivne !02_A
36257	põhimõtete	mõte	põhi+mõte	06_S	PlG	et	põhimõtete =mõte  (PlG  >põhi+mõte !06_S
36268	kolmandik	kolmandik	kolmandik	25_N	SgN	et	kolmandik =kolmandik  (SgN  >kolmandik !25_N
36269	ingliskeelsed	keelse	inglis+keelne	02_A	PlN	et	ingliskeelsed =keelse  (PlN  >inglis+keelne !02_A
36276	kivide	kivi	kivi	17_S	PlG	et	kivide =kivi  (PlG  >kivi !17_S
36288	rohkeid	rohke	rohke	01_A	PlP	et	rohkeid =rohke  (PlP  >rohke !01_A
36290	joonised	joonise	joonis	09_S	PlN	et	joonised =joonise  (PlN  >joonis !09_S
36313	sihtgruppidel	gruppi	siht+grupp	22_S	PlAd	et	sihtgruppidel =gruppi  (PlAd  >siht+grupp !22_S
36319	sihtrühmadest	rühma	siht+rühm	22_S	PlEl	et	sihtrühmadest =rühma  (PlEl  >siht+rühm !22_S
36321	tutvustate	tutvusta	tutvustama	27_V	IndPrPl2	et	tutvustate =tutvusta  (IndPrPl2  >tutvustama !27_V
36322	teadliku	teadliku	teadlik	25_A	SgG	et	teadliku =teadliku  (SgG  >teadlik !25_A
36327	sihtgruppide	gruppi	siht+grupp	22_S	PlG	et	sihtgruppide =gruppi  (PlG  >siht+grupp !22_S
36328	haridusvõimaluste	võimalus	haridus+võimalus	11_S	PlG	et	haridusvõimaluste =võimalus  (PlG  >haridus+võimalus !11_S
36336	etnilist	etnilis	etniline	12_A	SgP	et	etnilist =etnilis  (SgP  >etniline !12_A
36339	sihtrühmasid	rühma	siht+rühm	22_S	PlP	et	sihtrühmasid =rühma  (PlP  >siht+rühm !22_S
36345	perioodidel	perioodi	periood	22_S	PlAd	et	perioodidel =perioodi  (PlAd  >periood !22_S
36349	eestvedajate	vedaja	eest+vedaja	01_S	PlG	et	eestvedajate =vedaja  (PlG  >eest+vedaja !01_S
36351	kriitilist	kriitilis	kriitiline	12_A	SgP	et	kriitilist =kriitilis  (SgP  >kriitiline !12_A
36354	hinnet	hinne	hinne	06_S	SgP	et	hinnet =hinne  (SgP  >hinne !06_S
36357	kategooriatest	kategooria	kategooria	01_S	PlEl	et	kategooriatest =kategooria  (PlEl  >kategooria !01_S
36364	stiilisünonüüm	sünonüüm	stiili+sünonüüm	22_S	SgN	et	stiilisünonüüm =sünonüüm  (SgN  >stiili+sünonüüm !22_S
36383	valikained	aine	valik+aine	06_S	PlN	et	valikained =aine  (PlN  >valik+aine !06_S
36385	ametit	ameti	amet	02_S	SgP	et	ametit =ameti  (SgP  >amet !02_S
36396	pandeemilisest	pandeemilise	pandeemiline	12_A	SgEl	et	pandeemilisest =pandeemilise  (SgEl  >pandeemiline !12_A
36398	tervishoiuamet	amet	tervis+hoiu+amet	02_S	SgN	et	tervishoiuamet =amet  (SgN  >tervis+hoiu+amet !02_S
36399	sotsiaalministeerium	ministeerium	sotsiaal+ministeerium	19~02_S	SgN	et	sotsiaalministeerium =ministeerium  (SgN  >sotsiaal+ministeerium !19~02_S
36400	pandeemiline	pandeemiline	pandeemiline	12_A	SgN	et	pandeemiline =pandeemiline  (SgN  >pandeemiline !12_A
36403	ühineda	ühine	ühinema	27_V	Inf	et	ühineda =ühine  (Inf  >ühinema !27_V
36404	pandeemiat	pandeemia	pandeemia	01_S	SgP	et	pandeemiat =pandeemia  (SgP  >pandeemia !01_S
36405	muteeruma	muteeru	muteeruma	27_V	Sup	et	muteeruma =muteeru  (Sup  >muteeruma !27_V
36406	pandeemilise	pandeemilise	pandeemiline	12_A	SgG	et	pandeemilise =pandeemilise  (SgG  >pandeemiline !12_A
36407	gripi	gripi	gripp	22_S	SgG	et	gripi =gripi  (SgG  >gripp !22_S
36429	lühendab	lühenda	lühendama	27_V	IndPrSg3	et	lühendab =lühenda  (IndPrSg3  >lühendama !27_V
36430	protsent	protsent	protsent	22_S	SgN	et	protsent =protsent  (SgN  >protsent !22_S
36184	probleemseid	probleemse	probleemne	02_A	PlP	et	probleemseid =probleemse  (PlP  >probleemne !02_A
36189	keelekeskkonna	keskkonna	keele+keskkond	22_S	SgG	et	keelekeskkonna =keskkonna  (SgG  >keele+keskkond !22_S
36199	näpuvigu	vigu	näpu+viga	18_S	PlP	et	näpuvigu =vigu  (PlP  >näpu+viga !18_S
36200	apse	apse	aps	22_S	PlP	et	apse =apse  (PlP  >aps !22_S
36204	arvestab	arvesta	arvestama	27_V	IndPrSg3	et	arvestab =arvesta  (IndPrSg3  >arvestama !27_V
36208	isikuga	isiku	isik	02_S	SgKom	et	isikuga =isiku  (SgKom  >isik !02_S
36210	edastatakse	edasta	edastama	27_V	IndPrIps	et	edastatakse =edasta  (IndPrIps  >edastama !27_V
36228	oskuste	oskus	oskus	11~09_S	PlG	et	oskuste =oskus  (PlG  >oskus !11~09_S
36234	viiteid	viite	viide	06_S	PlP	et	viiteid =viite  (PlP  >viide !06_S
36245	oskate	oska	oskama	29_V	IndPrPl2	et	oskate =oska  (IndPrPl2  >oskama !29_V
36250	keeleõppijate	õppija	keele+õppija	01_S	PlG	et	keeleõppijate =õppija  (PlG  >keele+õppija !01_S
36252	ingliskeelseid	keelse	inglis+keelne	02_A	PlP	et	ingliskeelseid =keelse  (PlP  >inglis+keelne !02_A
36256	aineõppele	õppe	aine+õpe	06_S	SgAll	et	aineõppele =õppe  (SgAll  >aine+õpe !06_S
36259	probleemide	probleemi	probleem	22_S	PlG	et	probleemide =probleemi  (PlG  >probleem !22_S
36271	selgub	selgu	selguma	27_V	IndPrSg3	et	selgub =selgu  (IndPrSg3  >selguma !27_V
36289	kommunikatsioonimudeleid	mudele	kommunikatsiooni+mudel	02_S	PlP	et	kommunikatsioonimudeleid =mudele  (PlP  >kommunikatsiooni+mudel !02_S
36293	sobilik	sobilik	sobilik	25_A	SgN	et	sobilik =sobilik  (SgN  >sobilik !25_A
36296	võrrelgem	võrrel	võrdlema	30_V	ImpPrPl1	et	võrrelgem =võrrel  (ImpPrPl1  >võrdlema !30_V
36298	omadega	oma	oma	17_A	PlKom	et	omadega =oma  (PlKom  >oma !17_A
36300	aineõpetajat	õpetaja	aine+õpetaja	01_S	SgP	et	aineõpetajat =õpetaja  (SgP  >aine+õpetaja !01_S
36304	hoiakute	hoiaku	hoiak	02_S	PlG	et	hoiakute =hoiaku  (PlG  >hoiak !02_S
36318	artiklite	artikli	artikkel	02_S	PlG	et	artiklite =artikli  (PlG  >artikkel !02_S
36324	mitte-eestlased	eestlase	mitte-eestlane	12?10_S	PlN	et	mitte-eestlased =eestlase  (PlN  >mitte-eestlane !12?10_S
36326	tulevikuvaateid	vaate	tuleviku+vaade	06_S	PlP	et	tulevikuvaateid =vaate  (PlP  >tuleviku+vaade !06_S
36331	ebapiisava	piisava	eba+piisav	02_A	SgG	et	ebapiisava =piisava  (SgG  >eba+piisav !02_A
36334	kardeti	karde	kartma	34_V	IndIpfIps	et	kardeti =karde  (IndIpfIps  >kartma !34_V
36335	kahjustab	kahjusta	kahjustama	27_V	IndPrSg3	et	kahjustab =kahjusta  (IndPrSg3  >kahjustama !27_V
36344	mõtete	mõte	mõte	06_S	PlG	et	mõtete =mõte  (PlG  >mõte !06_S
36346	uuringud	uuringu	uuring	02_S	PlN	et	uuringud =uuringu  (PlN  >uuring !02_S
36347	infovajadus	vajadus	info+vajadus	11_S	SgN	et	infovajadus =vajadus  (SgN  >info+vajadus !11_S
36358	keeletundjate	tundja	keele+tundja	01_S	PlG	et	keeletundjate =tundja  (PlG  >keele+tundja !01_S
36367	väljavõtted	võtte	välja+võte	06_S	PlN	et	väljavõtted =võtte  (PlN  >välja+võte !06_S
36374	suurteks	suur	suur	13_A	PlTr	et	suurteks =suur  (PlTr  >suur !13_A
36377	avaldab	avalda	avaldama	27_V	IndPrSg3	et	avaldab =avalda  (IndPrSg3  >avaldama !27_V
36384	huvist	huvi	huvi	17_S	SgEl	et	huvist =huvi  (SgEl  >huvi !17_S
36387	päevalehes	lehe	päeva+leht	22_S	SgIn	et	päevalehes =lehe  (SgIn  >päeva+leht !22_S
36388	nakatuda	nakatu	nakatuma	27_V	Inf	et	nakatuda =nakatu  (Inf  >nakatuma !27_V
36390	linnugripi	gripi	linnu+gripp	22_S	SgG	et	linnugripi =gripi  (SgG  >linnu+gripp !22_S
36408	pandeemiaks	pandeemia	pandeemia	01_S	SgTr	et	pandeemiaks =pandeemia  (SgTr  >pandeemia !01_S
36410	levib	levi	levima	27_V	IndPrSg3	et	levib =levi  (IndPrSg3  >levima !27_V
36421	repetiitorina	repetiitori	repetiitor	02_S	SgEs	et	repetiitorina =repetiitori  (SgEs  >repetiitor !02_S
36425	kutsika	kutsika	kutsikas	02_S	SgG	et	kutsika =kutsika  (SgG  >kutsikas !02_S
36426	puhkepäevadel	päeva	puhke+päev	22_S	PlAd	et	puhkepäevadel =päeva  (PlAd  >puhke+päev !22_S
36434	töötingimused	tingimuse	töö+tingimus	11_S	PlN	et	töötingimused =tingimuse  (PlN  >töö+tingimus !11_S
36440	tubakaga	tubaka	tubakas	02_S	SgKom	et	tubakaga =tubaka  (SgKom  >tubakas !02_S
36443	ületöötamisega	töötamise	üle+töötamine	12_S	SgKom	et	ületöötamisega =töötamise  (SgKom  >üle+töötamine !12_S
36448	ohuga	ohu	oht	22_S	SgKom	et	ohuga =ohu  (SgKom  >oht !22_S
36452	elukeskkonnale	keskkonna	elu+keskkond	22_S	SgAll	et	elukeskkonnale =keskkonna  (SgAll  >elu+keskkond !22_S
36457	gruppide	gruppi	grupp	22_S	PlG	et	gruppide =gruppi  (PlG  >grupp !22_S
36459	ebatervislik	tervislik	eba+tervislik	25_A	SgN	et	ebatervislik =tervislik  (SgN  >eba+tervislik !25_A
36474	keskkonna	keskkonna	keskkond	22_S	SgG	et	keskkonna =keskkonna  (SgG  >keskkond !22_S
36477	osalemast	osale	osalema	27_V	SupEl	et	osalemast =osale  (SupEl  >osalema !27_V
36478	projektile	projekti	projekt	22_S	SgAll	et	projektile =projekti  (SgAll  >projekt !22_S
36277	kändude	kändu	känd	22_S	PlG	et	kändude =kändu  (PlG  >känd !22_S
36278	sissejuhatava	juhatava	sisse+juhatav	02_A	SgG	et	sissejuhatava =juhatava  (SgG  >sisse+juhatav !02_A
36279	põhjendatakse	põhjenda	põhjendama	27_V	IndPrIps	et	põhjendatakse =põhjenda  (IndPrIps  >põhjendama !27_V
36280	käsitledes	käsitle	käsitlema	27_V	Ger	et	käsitledes =käsitle  (Ger  >käsitlema !27_V
36283	loetleb	loetle	loetlema	27_V	IndPrSg3	et	loetleb =loetle  (IndPrSg3  >loetlema !27_V
36287	kuhupoole	kuhupoole	kuhu+poole	41_DK	ID	et	kuhupoole =kuhupoole  (ID  >kuhu+poole !41_DK
36301	ainuüksi	ainuüksi	ainu+üksi	41_D	ID	et	ainuüksi =ainuüksi  (ID  >ainu+üksi !41_D
36303	õppele	õppe	õpe	06_S	SgAll	et	õppele =õppe  (SgAll  >õpe !06_S
36309	aineõppega	õppe	aine+õpe	06_S	SgKom	et	aineõppega =õppe  (SgKom  >aine+õpe !06_S
36310	märksa	märksa	märksa	41_D	ID	et	märksa =märksa  (ID  >märksa !41_D
36316	meenutagem	meenuta	meenutama	27_V	ImpPrPl1	et	meenutagem =meenuta  (ImpPrPl1  >meenutama !27_V
36329	piirangute	piirangu	piirang	02_S	PlG	et	piirangute =piirangu  (PlG  >piirang !02_S
36330	kohaneda	kohane	kohanema	27_V	Inf	et	kohaneda =kohane  (Inf  >kohanema !27_V
36332	puuduse	puuduse	puudus	11~09_S	SgG	et	puuduse =puuduse  (SgG  >puudus !11~09_S
36333	tagajärgede	järge	taga+järg	22_S	PlG	et	tagajärgede =järge  (PlG  >taga+järg !22_S
36343	suhtuma	suhtu	suhtuma	27_V	Sup	et	suhtuma =suhtu  (Sup  >suhtuma !27_V
36350	arusaame	saame	aru+saam	22_S	PlP	et	arusaame =saame  (PlP  >aru+saam !22_S
36355	vaatluse	vaatluse	vaatlus	11~09_S	SgG	et	vaatluse =vaatluse  (SgG  >vaatlus !11~09_S
36366	leheküljed	külje	lehe+külg	22_S	PlN	et	leheküljed =külje  (PlN  >lehe+külg !22_S
36378	stabiilse	stabiilse	stabiilne	02_A	SgG	et	stabiilse =stabiilse  (SgG  >stabiilne !02_A
36379	materiaalse	materiaalse	materiaalne	02_A	SgG	et	materiaalse =materiaalse  (SgG  >materiaalne !02_A
36382	õigele	õige	õige	01_A	SgAll	et	õigele =õige  (SgAll  >õige !01_A
36386	mehaanikat	mehaanika	mehaanika	01_S	SgP	et	mehaanikat =mehaanika  (SgP  >mehaanika !01_S
36392	tervishoiuameti	ameti	tervis+hoiu+amet	02_S	SgG	et	tervishoiuameti =ameti  (SgG  >tervis+hoiu+amet !02_S
36394	täpsustas	täpsusta	täpsustama	27_V	IndIpfSg3	et	täpsustas =täpsusta  (IndIpfSg3  >täpsustama !27_V
36395	kommentaaris	kommentaari	kommentaar	22_S	SgIn	et	kommentaaris =kommentaari  (SgIn  >kommentaar !22_S
36397	gripist	gripi	gripp	22_S	SgEl	et	gripist =gripi  (SgEl  >gripp !22_S
36402	tavagripp	gripp	tava+gripp	22_S	SgN	et	tavagripp =gripp  (SgN  >tava+gripp !22_S
36413	riike	riike	riik	22_S	PlP	et	riike =riike  (PlP  >riik !22_S
36418	gripipandeemiaks	pandeemia	gripi+pandeemia	01_S	SgTr	et	gripipandeemiaks =pandeemia  (SgTr  >gripi+pandeemia !01_S
36420	gripipuhangud	puhangu	gripi+puhang	02_S	PlN	et	gripipuhangud =puhangu  (PlN  >gripi+puhang !02_S
36424	rahvaköök	köök	rahva+köök	22_S	SgN	et	rahvaköök =köök  (SgN  >rahva+köök !22_S
36432	eluviisid	viisi	elu+viis	22_S	PlN	et	eluviisid =viisi  (PlN  >elu+viis !22_S
36437	taeva	taeva	taevas	07_S	SgG	et	taeva =taeva  (SgG  >taevas !07_S
36442	ebatervisliku	tervisliku	eba+tervislik	25_A	SgG	et	ebatervisliku =tervisliku  (SgG  >eba+tervislik !25_A
36447	ohus	ohu	oht	22_S	SgIn	et	ohus =ohu  (SgIn  >oht !22_S
36466	valutab	valuta	valutama	27_V	IndPrSg3	et	valutab =valuta  (IndPrSg3  >valutama !27_V
36467	seltskonnas	seltskonna	seltskond	22_S	SgIn	et	seltskonnas =seltskonna  (SgIn  >seltskond !22_S
36469	teedel	tee	tee	26_S	PlAd	et	teedel =tee  (PlAd  >tee !26_S
36473	takistab	takista	takistama	27_V	IndPrSg3	et	takistab =takista  (IndPrSg3  >takistama !27_V
36475	keskkonnapuhastamises	puhastamise	kesk+konna+puhastamine	12_S	SgIn	et	keskkonnapuhastamises =puhastamise  (SgIn  >kesk+konna+puhastamine !12_S
36484	meigivahendid	vahendi	meigi+vahend	02_S	PlN	et	meigivahendid =vahendi  (PlN  >meigi+vahend !02_S
36490	murelikuks	mureliku	murelik	25_A	SgTr	et	murelikuks =mureliku  (SgTr  >murelik !25_A
36491	muret	mure	mure	16_S	SgP	et	muret =mure  (SgP  >mure !16_S
36499	sugused	suguse	sugune	10_A	PlN	et	sugused =suguse  (PlN  >sugune !10_A
36501	illegaalse	illegaalse	illegaalne	02_A	SgG	et	illegaalse =illegaalse  (SgG  >illegaalne !02_A
36508	käsitleksin	käsitle	käsitlema	27_V	KndPrSg1	et	käsitleksin =käsitle  (KndPrSg1  >käsitlema !27_V
36509	politseitööst	töö	politsei+töö	26_S	SgEl	et	politseitööst =töö  (SgEl  >politsei+töö !26_S
36512	sellejärel	järe	selle+järg	22_S	PlAd	et	sellejärel =järe  (PlAd  >selle+järg !22_S
36521	abituriendid	abituriendi	abiturient	22_S	PlN	et	abituriendid =abituriendi  (PlN  >abiturient !22_S
36522	tarbima	tarbi	tarbima	27_V	Sup	et	tarbima =tarbi  (Sup  >tarbima !27_V
36523	alkohoolseid	alkohoolse	alkohoolne	02_A	PlP	et	alkohoolseid =alkohoolse  (PlP  >alkohoolne !02_A
36524	plaanil	plaani	plaan	22_S	SgAd	et	plaanil =plaani  (SgAd  >plaan !22_S
36311	üleminekusse	mineku	üle+minek	02_S	SgIll	et	üleminekusse =mineku  (SgIll  >üle+minek !02_S
36314	üleminekust	mineku	üle+minek	02_S	SgEl	et	üleminekust =mineku  (SgEl  >üle+minek !02_S
36315	konkreetset	konkreetse	konkreetne	02_A	SgP	et	konkreetset =konkreetse  (SgP  >konkreetne !02_A
36317	laita	lait	laitma	34_V	Inf	et	laita =lait  (Inf  >laitma !34_V
36325	üleminekuga	mineku	üle+minek	02_S	SgKom	et	üleminekuga =mineku  (SgKom  >üle+minek !02_S
36338	üleminekut	mineku	üle+minek	02_S	SgP	et	üleminekut =mineku  (SgP  >üle+minek !02_S
36341	adekvaatseks	adekvaatse	adekvaatne	02_A	SgTr	et	adekvaatseks =adekvaatse  (SgTr  >adekvaatne !02_A
36348	vajalikul	vajaliku	vajalik	25_A	SgAd	et	vajalikul =vajaliku  (SgAd  >vajalik !25_A
36353	üldjäreldusi	järeldusi	üld+järeldus	11_S	PlP	et	üldjäreldusi =järeldusi  (PlP  >üld+järeldus !11_S
36360	sünonüüm	sünonüüm	sünonüüm	22_S	SgN	et	sünonüüm =sünonüüm  (SgN  >sünonüüm !22_S
36361	osasünonüüm	sünonüüm	osa+sünonüüm	22_S	SgN	et	osasünonüüm =sünonüüm  (SgN  >osa+sünonüüm !22_S
36368	pakus	paku	pakk	22_S	SgIn	et	pakus =paku  (SgIn  >pakk !22_S
36370	rahvamajandust	majandus	rahva+majandus	11_S	SgP	et	rahvamajandust =majandus  (SgP  >rahva+majandus !11_S
36371	ärindust	ärindus	ärindus	11_S	SgP	et	ärindust =ärindus  (SgP  >ärindus !11_S
36373	semester	semester	semester	02_S	SgN	et	semester =semester  (SgN  >semester !02_S
36375	klassijuhatajat	juhataja	klassi+juhataja	01_S	SgP	et	klassijuhatajat =juhataja  (SgP  >klassi+juhataja !01_S
36389	elanikest	elanike	elanik	25_S	PlEl	et	elanikest =elanike  (PlEl  >elanik !25_S
36393	kaljumäe	mäe	kalju+mägi	21_S	SgG	et	kaljumäe =mäe  (SgG  >kalju+mägi !21_S
36401	linnugripp	gripp	linnu+gripp	22_S	SgN	et	linnugripp =gripp  (SgN  >linnu+gripp !22_S
36409	epideemiat	epideemia	epideemia	01_S	SgP	et	epideemiat =epideemia  (SgP  >epideemia !01_S
36412	haarates	haara	haarama	29_V	Ger	et	haarates =haara  (Ger  >haarama !29_V
36414	kontinente	kontinente	kontinent	22_S	PlP	et	kontinente =kontinente  (PlP  >kontinent !22_S
36415	suremus	suremus	suremus	11_S	SgN	et	suremus =suremus  (SgN  >suremus !11_S
36416	inimeselt-inimesele	inimese	inimeselt-inimene	12_S	SgAll	et	inimeselt-inimesele =inimese  (SgAll  >inimeselt-inimene !12_S
36417	suremusega	suremuse	suremus	11_S	SgKom	et	suremusega =suremuse  (SgKom  >suremus !11_S
36423	rublad	rubla	rubla	16~17_S	PlN	et	rublad =rubla  (PlN  >rubla !16~17_S
36427	fotot	foto	foto	16_S	SgP	et	fotot =foto  (SgP  >foto !16_S
36428	uurimuse	uurimuse	uurimus	11_S	SgG	et	uurimuse =uurimuse  (SgG  >uurimus !11_S
36436	avara	avara	avar	02_A	SgG	et	avara =avara  (SgG  >avar !02_A
36439	ületöötamine	töötamine	üle+töötamine	12_S	SgN	et	ületöötamine =töötamine  (SgN  >üle+töötamine !12_S
36450	põhjustele	põhjus	põhjus	11~09_S	PlAll	et	põhjustele =põhjus  (PlAll  >põhjus !11~09_S
36451	kriipsutada	kriipsuta	kriipsutama	27_V	Inf	et	kriipsutada =kriipsuta  (Inf  >kriipsutama !27_V
36453	mõjust	mõju	mõju	17_S	SgEl	et	mõjust =mõju  (SgEl  >mõju !17_S
36461	siinjuures	siinjuures	siin+juures	41_D	ID	et	siinjuures =siinjuures  (ID  >siin+juures !41_D
36462	mitteregulaarsest	regulaarse	mitte+regulaarne	02_A	SgEl	et	mitteregulaarsest =regulaarse  (SgEl  >mitte+regulaarne !02_A
36465	tarvitades	tarvita	tarvitama	27_V	Ger	et	tarvitades =tarvita  (Ger  >tarvitama !27_V
36471	imestan	imesta	imestama	27_V	IndPrSg1	et	imestan =imesta  (IndPrSg1  >imestama !27_V
36486	projekte	projekte	projekt	22_S	PlP	et	projekte =projekte  (PlP  >projekt !22_S
36487	loodusesõbrad	sõbra	looduse+sõber	24_S	PlN	et	loodusesõbrad =sõbra  (PlN  >looduse+sõber !24_S
36488	läbiviimise	viimise	läbi+viimine	12?10_S	SgG	et	läbiviimise =viimise  (SgG  >läbi+viimine !12?10_S
36494	narkomaane	narkomaane	narkomaan	22_S	PlP	et	narkomaane =narkomaane  (PlP  >narkomaan !22_S
36496	valimiskorraga	korra	valimis+kord	22_S	SgKom	et	valimiskorraga =korra  (SgKom  >valimis+kord !22_S
36497	välimisel	välimise	välimine	12_A	SgAd	et	välimisel =välimise  (SgAd  >välimine !12_A
36500	viimases	viimase	viimane	10_A	SgIn	et	viimases =viimase  (SgIn  >viimane !10_A
36504	teatan	teata	teatama	27_V	IndPrSg1	et	teatan =teata  (IndPrSg1  >teatama !27_V
36517	ehitan	ehita	ehitama	27_V	IndPrSg1	et	ehitan =ehita  (IndPrSg1  >ehitama !27_V
36531	nõudleb	nõudle	nõudlema	30_V	IndPrSg3	et	nõudleb =nõudle  (IndPrSg3  >nõudlema !30_V
36533	avan	ava	avama	27_V	IndPrSg1	et	avan =ava  (IndPrSg1  >avama !27_V
36540	soovidest	soovi	soov	22_S	PlEl	et	soovidest =soovi  (PlEl  >soov !22_S
36543	kassapidajaid	pidaja	kassa+pidaja	01_S	PlP	et	kassapidajaid =pidaja  (PlP  >kassa+pidaja !01_S
36547	pakume	paku	pakkuma	28_V	IndPrPl1	et	pakume =paku  (IndPrPl1  >pakkuma !28_V
36549	töötingimusi	tingimusi	töö+tingimus	11_S	PlP	et	töötingimusi =tingimusi  (PlP  >töö+tingimus !11_S
36563	inglis	ingli	ingel	02_S	SgIn	et	inglis =ingli  (SgIn  >ingel !02_S
36376	mehaanikainseneriks	inseneri	mehaanika+insener	19_S	SgTr	et	mehaanikainseneriks =inseneri  (SgTr  >mehaanika+insener !19_S
36380	vaesusemata	ema	vaesus+ema	17_S	SgAb	et	vaesusemata =ema  (SgAb  >vaesus+ema !17_S
36381	plaane	plaane	plaan	22_S	PlP	et	plaane =plaane  (PlP  >plaan !22_S
36391	tüvi	tüvi	tüvi	20_S	SgN	et	tüvi =tüvi  (SgN  >tüvi !20_S
36411	riigipiiride	piiri	riigi+piir	22_S	PlG	et	riigipiiride =piiri  (PlG  >riigi+piir !22_S
36419	haigusjuhuga	juhu	haigus+juht	22_S	SgKom	et	haigusjuhuga =juhu  (SgKom  >haigus+juht !22_S
36422	suhtleme	suhtle	suhtlema	30_V	IndPrPl1	et	suhtleme =suhtle  (IndPrPl1  >suhtlema !30_V
36431	ebatervislikud	tervisliku	eba+tervislik	25_A	PlN	et	ebatervislikud =tervisliku  (PlN  >eba+tervislik !25_A
36435	mürgitusainetega	aine	mürgitus+aine	06_S	PlKom	et	mürgitusainetega =aine  (PlKom  >mürgitus+aine !06_S
36438	ebaregulaarset	regulaarse	eba+regulaarne	02_A	SgP	et	ebaregulaarset =regulaarse  (SgP  >eba+regulaarne !02_A
36441	tubaka	tubaka	tubakas	02_S	SgG	et	tubaka =tubaka  (SgG  >tubakas !02_S
36444	töökohtadel	kohta	töö+koht	22_S	PlAd	et	töökohtadel =kohta  (PlAd  >töö+koht !22_S
36446	peresuhted	suhte	pere+suhe	06_S	PlN	et	peresuhted =suhte  (PlN  >pere+suhe !06_S
36454	elueale	ea	elu+iga	18_S	SgAll	et	elueale =ea  (SgAll  >elu+iga !18_S
36455	allpool	allpool	all+pool	41_DK	ID	et	allpool =allpool  (ID  >all+pool !41_DK
36460	peamisest	peamise	peamine	12?10_A	SgEl	et	peamisest =peamise  (SgEl  >peamine !12?10_A
36464	vajalike	vajalike	vajalik	25_A	PlG	et	vajalike =vajalike  (PlG  >vajalik !25_A
36470	kaht	kaht	kaks	22_N	SgP	et	kaht =kaht  (SgP  >kaks !22_N
36476	projektis	projekti	projekt	22_S	SgIn	et	projektis =projekti  (SgIn  >projekt !22_S
36479	pastaga	pasta	pasta	16_S	SgKom	et	pastaga =pasta  (SgKom  >pasta !16_S
36480	reklaamib	reklaami	reklaamima	28_V	IndPrSg3	et	reklaamib =reklaami  (IndPrSg3  >reklaamima !28_V
36482	juukseid	juukse	juus	09_S	PlP	et	juukseid =juukse  (PlP  >juus !09_S
36489	kõigepeale	pea	kõige+pea	26_S	SgAll	et	kõigepeale =pea  (SgAll  >kõige+pea !26_S
36503	lähendama	lähenda	lähendama	27_V	Sup	et	lähendama =lähenda  (Sup  >lähendama !27_V
36514	kardama	karda	kardama	29_V	Sup	et	kardama =karda  (Sup  >kardama !29_V
36515	tudengitega	tudengi	tudeng	02_S	PlKom	et	tudengitega =tudengi  (PlKom  >tudeng !02_S
36519	hamburgerid	hamburgeri	hamburger	02_S	PlN	et	hamburgerid =hamburgeri  (PlN  >hamburger !02_S
36525	erialaks	ala	eri+ala	17_S	SgTr	et	erialaks =ala  (SgTr  >eri+ala !17_S
36535	tutvustage	tutvusta	tutvustama	27_V	ImpPrPl2	et	tutvustage =tutvusta  (ImpPrPl2  >tutvustama !27_V
36539	hobid	hobi	hobi	17_S	PlN	et	hobid =hobi  (PlN  >hobi !17_S
36541	töögraafik	graafik	töö+graafik	02_S	SgN	et	töögraafik =graafik  (SgN  >töö+graafik !02_S
36542	toidukauplus	kauplus	toidu+kauplus	11~09_S	SgN	et	toidukauplus =kauplus  (SgN  >toidu+kauplus !11~09_S
36552	meditsiinikoosolekud	oleku	meditsiini+koos+olek	02_S	PlN	et	meditsiinikoosolekud =oleku  (PlN  >meditsiini+koos+olek !02_S
36561	ettepanekud	paneku	ette+panek	02_S	PlN	et	ettepanekud =paneku  (PlN  >ette+panek !02_S
36565	infopress	press	info+press	22_S	SgN	et	infopress =press  (SgN  >info+press !22_S
36577	oskame	oska	oskama	29_V	IndPrPl1	et	oskame =oska  (IndPrPl1  >oskama !29_V
36586	kursuseid	kursuse	kursus	09_S	PlP	et	kursuseid =kursuse  (PlP  >kursus !09_S
36588	arvutioskused	oskuse	arvuti+oskus	11~09_S	PlN	et	arvutioskused =oskuse  (PlN  >arvuti+oskus !11~09_S
36594	töölise	töölise	tööline	12?10_S	SgG	et	töölise =töölise  (SgG  >tööline !12?10_S
36595	sured	sure	surema	36_V	IndPrSg2	et	sured =sure  (IndPrSg2  >surema !36_V
36601	ööbite	ööbi	ööbima	27_V	IndPrPl2	et	ööbite =ööbi  (IndPrPl2  >ööbima !27_V
36602	millistes	millis	milline	10_P	PlIn	et	millistes =millis  (PlIn  >milline !10_P
36604	elektrirong	rong	elektri+rong	22_S	SgN	et	elektrirong =rong  (SgN  >elektri+rong !22_S
36606	ööbin	ööbi	ööbima	27_V	IndPrSg1	et	ööbin =ööbi  (IndPrSg1  >ööbima !27_V
36608	elevad	eleva	elev	02_A	PlN	et	elevad =eleva  (PlN  >elev !02_A
36612	aite	aite	ait	22_S	PlP	et	aite =aite  (PlP  >ait !22_S
36617	turismikeskus	keskus	turismi+keskus	11~09_S	SgN	et	turismikeskus =keskus  (SgN  >turismi+keskus !11~09_S
36623	lennuga	lennu	lend	22_S	SgKom	et	lennuga =lennu  (SgKom  >lend !22_S
36625	sugulasel	sugulase	sugulane	12_S	SgAd	et	sugulasel =sugulase  (SgAd  >sugulane !12_S
36626	vabandage	vabanda	vabandama	27_V	ImpPrPl2	et	vabandage =vabanda  (ImpPrPl2  >vabandama !27_V
36640	õunad	õuna	õun	23?22_S	PlN	et	õunad =õuna  (PlN  >õun !23?22_S
36648	autobussiga	bussi	auto+buss	22_S	SgKom	et	autobussiga =bussi  (SgKom  >auto+buss !22_S
36651	balleti	balleti	ballett	22_S	SgG	et	balleti =balleti  (SgG  >ballett !22_S
36662	kurjategijad	tegija	kurja+tegija	01_S	PlN	et	kurjategijad =tegija  (PlN  >kurja+tegija !01_S
36433	diivanil	diivani	diivan	02_S	SgAd	et	diivanil =diivani  (SgAd  >diivan !02_S
36445	puhkuseta	puhkuse	puhkus	11~09_S	SgAb	et	puhkuseta =puhkuse  (SgAb  >puhkus !11~09_S
36449	varaga	vara	vara	17_S	SgKom	et	varaga =vara  (SgKom  >vara !17_S
36456	skeemilt	skeemi	skeem	22_S	SgAbl	et	skeemilt =skeemi  (SgAbl  >skeem !22_S
36458	moodustab	moodusta	moodustama	27_V	IndPrSg3	et	moodustab =moodusta  (IndPrSg3  >moodustama !27_V
36463	peret	pere	pere	16_S	SgP	et	peret =pere  (SgP  >pere !16_S
36468	autosõit	sõit	auto+sõit	22_S	SgN	et	autosõit =sõit  (SgN  >auto+sõit !22_S
36472	haiseb	haise	haisema	28_V	IndPrSg3	et	haiseb =haise  (IndPrSg3  >haisema !28_V
36483	juukseid	juukse	juus	09_S	PlP	et	juukseid =juukse  (PlP  >juus !09_S
36485	müüakse	müü	müüma	38_V	IndPrIps	et	müüakse =müü  (IndPrIps  >müüma !38_V
36498	elukeskkond	keskkond	elu+keskkond	22_S	SgN	et	elukeskkond =keskkond  (SgN  >elu+keskkond !22_S
36502	regioonid	regiooni	regioon	22_S	PlN	et	regioonid =regiooni  (PlN  >regioon !22_S
36507	räägiksin	räägi	rääkima	28_V	KndPrSg1	et	räägiksin =räägi  (KndPrSg1  >rääkima !28_V
36510	käituda	käitu	käituma	27_V	Inf	et	käituda =käitu  (Inf  >käituma !27_V
36528	lugege	luge	lugema	28_V	ImpPrPl2	et	lugege =luge  (ImpPrPl2  >lugema !28_V
36529	esitage	esita	esitama	27_V	ImpPrPl2	et	esitage =esita  (ImpPrPl2  >esitama !27_V
36537	keelteoskus	oskus	keelte+oskus	11~09_S	SgN	et	keelteoskus =oskus  (SgN  >keelte+oskus !11~09_S
36548	mugavaid	mugava	mugav	02_A	PlP	et	mugavaid =mugava  (PlP  >mugav !02_A
36554	radiost	ost	radi+ost	22_S	SgN	et	radiost =ost  (SgN  >radi+ost !22_S
36560	majanduskursusel	kursuse	majandus+kursus	11~09_S	SgAd	et	majanduskursusel =kursuse  (SgAd  >majandus+kursus !11~09_S
36570	instruktsioonid	instruktsiooni	instruktsioon	22_S	PlN	et	instruktsioonid =instruktsiooni  (PlN  >instruktsioon !22_S
36573	laborandina	laborandi	laborant	22_S	SgEs	et	laborandina =laborandi  (SgEs  >laborant !22_S
36575	firmadest	firma	firma	16_S	PlEl	et	firmadest =firma  (PlEl  >firma !16_S
36578	meditsiiniõena	õe	meditsiini+õde	18_S	SgEs	et	meditsiiniõena =õe  (SgEs  >meditsiini+õde !18_S
36583	võrgkeelte	keel	võrg+keel	13_S	PlG	et	võrgkeelte =keel  (PlG  >võrg+keel !13_S
36589	joonistan	joonista	joonistama	27_V	IndPrSg1	et	joonistan =joonista  (IndPrSg1  >joonistama !27_V
36591	kõnes	kõne	kõne	16_S	SgIn	et	kõnes =kõne  (SgIn  >kõne !16_S
36592	arvutioskamine	oskamine	arvuti+oskamine	12_S	SgN	et	arvutioskamine =oskamine  (SgN  >arvuti+oskamine !12_S
36596	8-st			xx_Q	SgEl	et	-st =  (SgEl  > !xx_Q
36599	plaanite	plaani	plaanima	28_V	IndPrPl2	et	plaanite =plaani  (IndPrPl2  >plaanima !28_V
36603	uudis	uudis	uudis	09_S	SgN	et	uudis =uudis  (SgN  >uudis !09_S
36619	ooperi	ooperi	ooper	02_S	SgG	et	ooperi =ooperi  (SgG  >ooper !02_S
36624	kullas	kulla	kuld	22_S	SgIn	et	kullas =kulla  (SgIn  >kuld !22_S
36628	omale	oma	oma	17_A	SgAll	et	omale =oma  (SgAll  >oma !17_A
36629	hommiku	hommiku	hommik	02_S	SgG	et	hommiku =hommiku  (SgG  >hommik !02_S
36631	kunstlinik	linik	kunst+linik	02_S	SgN	et	kunstlinik =linik  (SgN  >kunst+linik !02_S
36644	soodust	dust	soo+dust	22_S	SgN	et	soodust =dust  (SgN  >soo+dust !22_S
36647	kontsertisaalis	alis	kontsert+isa+alis	09_S	SgN	et	kontsertisaalis =alis  (SgN  >kontsert+isa+alis !09_S
36652	tulge	tul	tulema	36_V	ImpPrPl2	et	tulge =tul  (ImpPrPl2  >tulema !36_V
36654	naistegelane	tegelane	nais+tegelane	12_S	SgN	et	naistegelane =tegelane  (SgN  >nais+tegelane !12_S
36655	narkoäriga	äri	narko+äri	17_S	SgKom	et	narkoäriga =äri  (SgKom  >narko+äri !17_S
36660	piirivalvur	valvur	piiri+valvur	02_S	SgN	et	piirivalvur =valvur  (SgN  >piiri+valvur !02_S
36674	järgmise	järgmise	järgmine	12?10_A	SgG	et	järgmise =järgmise  (SgG  >järgmine !12?10_A
36678	toiduaineid	aine	toidu+aine	06_S	PlP	et	toiduaineid =aine  (PlP  >toidu+aine !06_S
36688	väitis	väit	väitma	34_V	IndIpfSg3	et	väitis =väit  (IndIpfSg3  >väitma !34_V
36693	süüdistatakse	süüdista	süüdistama	27_V	IndPrIps	et	süüdistatakse =süüdista  (IndPrIps  >süüdistama !27_V
36695	informatsioonivoolajaks	voolaja	informatsiooni+voolaja	01_S	SgTr	et	informatsioonivoolajaks =voolaja  (SgTr  >informatsiooni+voolaja !01_S
36699	pehmendas	pehmenda	pehmendama	27_V	IndIpfSg3	et	pehmendas =pehmenda  (IndIpfSg3  >pehmendama !27_V
36706	paberid	paberi	paber	02_S	PlN	et	paberid =paberi  (PlN  >paber !02_S
36711	liitub	liitu	liituma	27_V	IndPrSg3	et	liitub =liitu  (IndPrSg3  >liituma !27_V
36717	tänata	täna	tänama	27_V	IndPrIps_	et	tänata =täna  (IndPrIps_  >tänama !27_V
36722	keeldub	keeldu	keelduma	27_V	IndPrSg3	et	keeldub =keeldu  (IndPrSg3  >keelduma !27_V
36728	meediavahend	vahend	meedia+vahend	02_S	SgN	et	meediavahend =vahend  (SgN  >meedia+vahend !02_S
36738	püss	püss	püss	22_S	SgN	et	püss =püss  (SgN  >püss !22_S
36481	puhastab	puhasta	puhastama	27_V	IndPrSg3	et	puhastab =puhasta  (IndPrSg3  >puhastama !27_V
36492	välimiskord	kord	väli+mis+kord	22_S	SgN	et	välimiskord =kord  (SgN  >väli+mis+kord !22_S
36493	vahetub	vahetu	vahetuma	27_V	IndPrSg3	et	vahetub =vahetu  (IndPrSg3  >vahetuma !27_V
36495	võimuga	võimu	võim	22_S	SgKom	et	võimuga =võimu  (SgKom  >võim !22_S
36505	valimiskord	kord	valimis+kord	22_S	SgN	et	valimiskord =kord  (SgN  >valimis+kord !22_S
36506	tõsineid	neid	tõsi+neid	22_S	SgN	et	tõsineid =neid  (SgN  >tõsi+neid !22_S
36511	spetsialistiga	spetsialisti	spetsialist	22_S	SgKom	et	spetsialistiga =spetsialisti  (SgKom  >spetsialist !22_S
36513	kardasin	karda	kardama	29_V	IndIpfSg1	et	kardasin =karda  (IndIpfSg1  >kardama !29_V
36516	õpingust	õpingu	õping	02_S	SgEl	et	õpingust =õpingu  (SgEl  >õping !02_S
36518	jõududele	jõudu	jõud	22_S	PlAll	et	jõududele =jõudu  (PlAll  >jõud !22_S
36520	nuudlid	nuudli	nuudel	02_S	PlN	et	nuudlid =nuudli  (PlN  >nuudel !02_S
36526	siinpool	siinpool	siin+pool	41_DK	ID	et	siinpool =siinpool  (ID  >siin+pool !41_DK
36527	väidet	väide	väide	06_S	SgP	et	väidet =väide  (SgP  >väide !06_S
36532	istun	istu	istuma	28_V	IndPrSg1	et	istun =istu  (IndPrSg1  >istuma !28_V
36536	töökogemused	kogemuse	töö+kogemus	11_S	PlN	et	töökogemused =kogemuse  (PlN  >töö+kogemus !11_S
36538	arvutioskus	oskus	arvuti+oskus	11~09_S	SgN	et	arvutioskus =oskus  (SgN  >arvuti+oskus !11~09_S
36546	arvutikasutamisoskus	oskus	arvuti+kasutamis+oskus	11~09_S	SgN	et	arvutikasutamisoskus =oskus  (SgN  >arvuti+kasutamis+oskus !11~09_S
36551	töökogemus	kogemus	töö+kogemus	11_S	SgN	et	töökogemus =kogemus  (SgN  >töö+kogemus !11_S
36553	konverentsid	konverentsi	konverents	22_S	PlN	et	konverentsid =konverentsi  (PlN  >konverents !22_S
36556	põhjarannik	rannik	põhja+rannik	02_S	SgN	et	põhjarannik =rannik  (SgN  >põhja+rannik !02_S
36557	vajan	vaja	vajama	27_V	IndPrSg1	et	vajan =vaja  (IndPrSg1  >vajama !27_V
36558	suhtlemisatis	ati	suhtlemis+att	22_S	SgIn	et	suhtlemisatis =ati  (SgIn  >suhtlemis+att !22_S
36559	arvutitunnistuse	tunnistuse	arvuti+tunnistus	11_S	SgG	et	arvutitunnistuse =tunnistuse  (SgG  >arvuti+tunnistus !11_S
36564	maleva	maleva	malev	02_S	SgG	et	maleva =maleva  (SgG  >malev !02_S
36569	seadmete	seadme	seade	05_S	PlG	et	seadmete =seadme  (PlG  >seade !05_S
36571	juhendid	juhendi	juhend	02_S	PlN	et	juhendid =juhendi  (PlN  >juhend !02_S
36572	võõrkeeleoskus	oskus	võõr+keele+oskus	11~09_S	SgN	et	võõrkeeleoskus =oskus  (SgN  >võõr+keele+oskus !11~09_S
36574	välismaalide	maali	välis+maal	22_S	PlG	et	välismaalide =maali  (PlG  >välis+maal !22_S
36576	euroliigis	liigi	euro+liik	22_S	SgIn	et	euroliigis =liigi  (SgIn  >euro+liik !22_S
36580	teineteisele	teise	teine+teise	12_P	SgAll	et	teineteisele =teise  (SgAll  >teine+teise !12_P
36585	sõpruse	sõpruse	sõprus	11~09_S	SgG	et	sõpruse =sõpruse  (SgG  >sõprus !11~09_S
36600	reisite	reisi	reisima	28_V	IndPrPl2	et	reisite =reisi  (IndPrPl2  >reisima !28_V
36609	ööreisiga	reisi	öö+reis	22_S	SgKom	et	ööreisiga =reisi  (SgKom  >öö+reis !22_S
36610	reisipilet	pilet	reisi+pilet	02_S	SgN	et	reisipilet =pilet  (SgN  >reisi+pilet !02_S
36615	suurlinn	linn	suur+linn	22_S	SgN	et	suurlinn =linn  (SgN  >suur+linn !22_S
36618	balletiteater	teater	balleti+teater	02_S	SgN	et	balletiteater =teater  (SgN  >balleti+teater !02_S
36621	vanaväljakud	väljaku	vana+väljak	02_S	PlN	et	vanaväljakud =väljaku  (PlN  >vana+väljak !02_S
36630	muuseimus	seimu	muu+seim	22_S	PlIn	et	muuseimus =seimu  (PlIn  >muu+seim !22_S
36632	purskkaevud	kaevu	pursk+kaev	22_S	PlN	et	purskkaevud =kaevu  (PlN  >pursk+kaev !22_S
36633	helistage	helista	helistama	27_V	ImpPrPl2	et	helistage =helista  (ImpPrPl2  >helistama !27_V
36636	tervisi	tervisi	tervis	11_S	PlP	et	tervisi =tervisi  (PlP  >tervis !11_S
36639	liivarand	rand	liiva+rand	22_S	SgN	et	liivarand =rand  (SgN  >liiva+rand !22_S
36642	pirnid	pirni	pirn	22_S	PlN	et	pirnid =pirni  (PlN  >pirn !22_S
36643	peatame	peata	peatama	27_V	IndPrPl1	et	peatame =peata  (IndPrPl1  >peatama !27_V
36656	kuulutas	kuuluta	kuulutama	27_V	IndIpfSg3	et	kuulutas =kuuluta  (IndIpfSg3  >kuulutama !27_V
36658	piiritusevedajad	vedaja	piirituse+vedaja	01_S	PlN	et	piiritusevedajad =vedaja  (PlN  >piirituse+vedaja !01_S
36661	tabama	taba	tabama	27_V	Sup	et	tabama =taba  (Sup  >tabama !27_V
36663	tabada	taba	tabama	27_V	Inf	et	tabada =taba  (Inf  >tabama !27_V
36668	fraas	fraas	fraas	22_S	SgN	et	fraas =fraas  (SgN  >fraas !22_S
36673	kaasaaegse	aegse	kaasa+aegne	02_A	SgG	et	kaasaaegse =aegse  (SgG  >kaasa+aegne !02_A
36675	deviis	deviis	deviis	22_S	SgN	et	deviis =deviis  (SgN  >deviis !22_S
36685	kuningaid	kuninga	kuningas	02_S	PlP	et	kuningaid =kuninga  (PlP  >kuningas !02_S
36687	pealtkuulamisaparaadid	aparaadi	pealt+kuulamis+aparaat	22_S	PlN	et	pealtkuulamisaparaadid =aparaadi  (PlN  >pealt+kuulamis+aparaat !22_S
36530	võõrkeelte	keel	võõr+keel	13_S	PlG	et	võõrkeelte =keel  (PlG  >võõr+keel !13_S
36534	vastake	vasta	vastama	29_V	ImpPrPl2	et	vastake =vasta  (ImpPrPl2  >vastama !29_V
36544	turvamehi	mehi	turva+mees	13_S	PlP	et	turvamehi =mehi  (PlP  >turva+mees !13_S
36545	kandidaatidelt	kandidaati	kandidaat	22_S	PlAbl	et	kandidaatidelt =kandidaati  (PlAbl  >kandidaat !22_S
36550	töögraafikut	graafiku	töö+graafik	02_S	SgP	et	töögraafikut =graafiku  (SgP  >töö+graafik !02_S
36555	voolab	voola	voolama	29_V	IndPrSg3	et	voolab =voola  (IndPrSg3  >voolama !29_V
36562	tööpalk	palk	töö+palk	22_S	SgN	et	tööpalk =palk  (SgN  >töö+palk !22_S
36567	toidukaupluses	kaupluse	toidu+kauplus	11~09_S	SgIn	et	toidukaupluses =kaupluse  (SgIn  >toidu+kauplus !11~09_S
36579	patsiendid	patsiendi	patsient	22_S	PlN	et	patsiendid =patsiendi  (PlN  >patsient !22_S
36581	kirjutame	kirjuta	kirjutama	27_V	IndPrPl1	et	kirjutame =kirjuta  (IndPrPl1  >kirjutama !27_V
36587	töökogemust	kogemus	töö+kogemus	11_S	SgP	et	töökogemust =kogemus  (SgP  >töö+kogemus !11_S
36593	ett	e	esi	15_S	SgP	et	ett =e  (SgP  >esi !15_S
36597	21-ni			xx_Q	SgTer	et	-ni =  (SgTer  > !xx_Q
36598	kelte	kelte	kelt	22_S	PlP	et	kelte =kelte  (PlP  >kelt !22_S
36605	mihkel	mihkel	mihkel	02_SA	SgN	et	mihkel =mihkel  (SgN  >mihkel !02_SA
36607	irina	irina	irin	02_S	SgG	et	irina =irina  (SgG  >irin !02_S
36611	koolisõbrana	sõbra	kooli+sõber	24_S	SgEs	et	koolisõbrana =sõbra  (SgEs  >kooli+sõber !24_S
36613	küsin	küsi	küsima	27_V	IndPrSg1	et	küsin =küsi  (IndPrSg1  >küsima !27_V
36616	sadamalinn	linn	sadama+linn	22_S	SgN	et	sadamalinn =linn  (SgN  >sadama+linn !22_S
36620	lasteteater	teater	laste+teater	02_S	SgN	et	lasteteater =teater  (SgN  >laste+teater !02_S
36637	numbris	numbri	number	02_S	SgIn	et	numbris =numbri  (SgIn  >number !02_S
36638	mererannal	ranna	mere+rand	22_S	SgAd	et	mererannal =ranna  (SgAd  >mere+rand !22_S
36641	viinamarjad	marja	viina+mari	24_S	PlN	et	viinamarjad =marja  (PlN  >viina+mari !24_S
36645	suudlen	suudle	suudlema	30_V	IndPrSg1	et	suudlen =suudle  (IndPrSg1  >suudlema !30_V
36646	pileti	pileti	pilet	02_S	SgG	et	pileti =pileti  (SgG  >pilet !02_S
36650	teatrietendust	etendus	teatri+etendus	11_S	SgP	et	teatrietendust =etendus  (SgP  >teatri+etendus !11_S
36659	äris	äri	äri	17_S	SgIn	et	äris =äri  (SgIn  >äri !17_S
36665	juuliust	us	juuli+uks	14_S	SgP	et	juuliust =us  (SgP  >juuli+uks !14_S
36680	tarvitama	tarvita	tarvitama	27_V	Sup	et	tarvitama =tarvita  (Sup  >tarvitama !27_V
36682	niiviisil	viisi	nii+viis	22_S	SgAd	et	niiviisil =viisi  (SgAd  >nii+viis !22_S
36683	tarbisime	tarbi	tarbima	27_V	IndIpfPl1	et	tarbisime =tarbi  (IndIpfPl1  >tarbima !27_V
36684	riigivõim	võim	riigi+võim	22_S	SgN	et	riigivõim =võim  (SgN  >riigi+võim !22_S
36686	keskbüroosse	büroo	kesk+büroo	26_S	SgIll	et	keskbüroosse =büroo  (SgIll  >kesk+büroo !26_S
36691	raiutakse	raiu	raiuma	28_V	IndPrIps	et	raiutakse =raiu  (IndPrIps  >raiuma !28_V
36700	kurgud	kurgu	kurk	22_S	PlN	et	kurgud =kurgu  (PlN  >kurk !22_S
36703	valimiskampaanias	kampaania	valimis+kampaania	01_S	SgIn	et	valimiskampaanias =kampaania  (SgIn  >valimis+kampaania !01_S
36708	lubadusi	lubadusi	lubadus	11_S	PlP	et	lubadusi =lubadusi  (PlP  >lubadus !11_S
36712	organ	organ	organ	02_S	SgN	et	organ =organ  (SgN  >organ !02_S
36714	kuningaks	kuninga	kuningas	02_S	SgTr	et	kuningaks =kuninga  (SgTr  >kuningas !02_S
36725	saladused	saladuse	saladus	11_S	PlN	et	saladused =saladuse  (PlN  >saladus !11_S
36734	mingisuguseid	suguse	mingi+sugune	10_P	PlP	et	mingisuguseid =suguse  (PlP  >mingi+sugune !10_P
36744	tähelegi	tähe	täht	22_S	SgAll^	et	tähelegi =tähe  (SgAll^  >täht !22_S
36746	vapratest	vapra	vapper	02_A	PlEl	et	vapratest =vapra  (PlEl  >vapper !02_A
36760	tähtisad	isa	täht+isa	17_S	PlN	et	tähtisad =isa  (PlN  >täht+isa !17_S
36761	ärritama	ärrita	ärritama	27_V	Sup	et	ärritama =ärrita  (Sup  >ärritama !27_V
36769	televiisoris	televiisori	televiisor	02_S	SgIn	et	televiisoris =televiisori  (SgIn  >televiisor !02_S
36772	nooreks	noore	noor	13_AS	SgTr	et	nooreks =noore  (SgTr  >noor !13_AS
36776	omakeelne	keelne	oma+keelne	02_A	SgN	et	omakeelne =keelne  (SgN  >oma+keelne !02_A
36778	riigipeana	pea	riigi+pea	26_S	SgEs	et	riigipeana =pea  (SgEs  >riigi+pea !26_S
36781	kaheteistkümnest	kümnes	kahe+teist+kümnene	10~12_AS	SgP	et	kaheteistkümnest =kümnes  (SgP  >kahe+teist+kümnene !10~12_AS
36782	analoogseid	analoogse	analoogne	02_A	PlP	et	analoogseid =analoogse  (PlP  >analoogne !02_A
36793	meeleavaldusi	avaldusi	meele+avaldus	11_S	PlP	et	meeleavaldusi =avaldusi  (PlP  >meele+avaldus !11_S
36795	saated	saate	saade	06_S	PlN	et	saated =saate  (PlN  >saade !06_S
36797	tõkestatakse	tõkesta	tõkestama	27_V	IndPrIps	et	tõkestatakse =tõkesta  (IndPrIps  >tõkestama !27_V
36566	sertifikaadi	sertifikaadi	sertifikaat	22_S	SgG	et	sertifikaadi =sertifikaadi  (SgG  >sertifikaat !22_S
36568	laboriteenistuses	teenistuse	labori+teenistus	11_S	SgIn	et	laboriteenistuses =teenistuse  (SgIn  >labori+teenistus !11_S
36582	sõnastikuga	sõnastiku	sõnastik	25_S	SgKom	et	sõnastikuga =sõnastiku  (SgKom  >sõnastik !25_S
36584	kakule	kaku	kakk	22_S	SgAll	et	kakule =kaku  (SgAll  >kakk !22_S
36590	sobin	sobi	sobima	27_V	IndPrSg1	et	sobin =sobi  (IndPrSg1  >sobima !27_V
36614	pilet	pilet	pilet	02_S	SgN	et	pilet =pilet  (SgN  >pilet !02_S
36622	sinuga	sinu	sina	00_P	SgKom	et	sinuga =sinu  (SgKom  >sina !00_P
36627	kirjatanud	tanu	kirja+tanu	17_S	PlN	et	kirjatanud =tanu  (PlN  >kirja+tanu !17_S
36634	marija	marija	marijas	02_A	SgG	et	marija =marija  (SgG  >marijas !02_A
36635	augustist	augusti	august	02_S	SgEl	et	augustist =augusti  (SgEl  >august !02_S
36649	külastame	külasta	külastama	27_V	IndPrPl1	et	külastame =külasta  (IndPrPl1  >külastama !27_V
36653	väljendit	väljendi	väljend	02_S	SgP	et	väljendit =väljendi  (SgP  >väljend !02_S
36657	vastaskaldal	kalda	vastas+kallas	07_S	SgAd	et	vastaskaldal =kalda  (SgAd  >vastas+kallas !07_S
36667	sekkuks	sekku	sekkuma	27_V	KndPrPs	et	sekkuks =sekku  (KndPrPs  >sekkuma !27_V
36670	looduslikke	looduslikke	looduslik	25_A	PlP	et	looduslikke =looduslikke  (PlP  >looduslik !25_A
36671	lõppeda	lõppe	lõppema	27~28_V	Inf	et	lõppeda =lõppe  (Inf  >lõppema !27~28_V
36672	muinasajad	aja	muinas+aeg	22_S	PlN	et	muinasajad =aja  (PlN  >muinas+aeg !22_S
36676	kaasaaegsel	aegse	kaasa+aegne	02_A	SgAd	et	kaasaaegsel =aegse  (SgAd  >kaasa+aegne !02_A
36677	eksisteerida	eksisteeri	eksisteerima	28_V	Inf	et	eksisteerida =eksisteeri  (Inf  >eksisteerima !28_V
36679	tarvitada	tarvita	tarvitama	27_V	Inf	et	tarvitada =tarvita  (Inf  >tarvitama !27_V
36681	kuritarvitada	tarvita	kuri+tarvitama	27_V	Inf	et	kuritarvitada =tarvita  (Inf  >kuri+tarvitama !27_V
36690	pätt	pätt	pätt	22_S	SgN	et	pätt =pätt  (SgN  >pätt !22_S
36697	luureagent	agent	luure+agent	22_S	SgN	et	luureagent =agent  (SgN  >luure+agent !22_S
36702	skandaal	skandaal	skandaal	22_S	SgN	et	skandaal =skandaal  (SgN  >skandaal !22_S
36704	salajasi	salajasi	salajane	12_A	PlP	et	salajasi =salajasi  (PlP  >salajane !12_A
36705	pabereid	pabere	paber	02_S	PlP	et	pabereid =pabere  (PlP  >paber !02_S
36707	toonase	toonase	toonane	10_A	SgG	et	toonase =toonase  (SgG  >toonane !10_A
36710	ühendriikidele	riiki	ühend+riik	22_S	PlAll	et	ühendriikidele =riiki  (PlAll  >ühend+riik !22_S
36715	narr	narr	narr	22_SA	SgN	et	narr =narr  (SgN  >narr !22_SA
36720	väikekodanlik	kodanlik	väike+kodanlik	25_A	SgN	et	väikekodanlik =kodanlik  (SgN  >väike+kodanlik !25_A
36721	mainimast	maini	mainima	28_V	SupEl	et	mainimast =maini  (SupEl  >mainima !28_V
36724	suguelundid	elundi	sugu+elund	02_S	PlN	et	suguelundid =elundi  (PlN  >sugu+elund !02_S
36729	vahendiks	vahendi	vahend	02_S	SgTr	et	vahendiks =vahendi  (SgTr  >vahend !02_S
36732	seriaalid	seriaali	seriaal	22_S	PlN	et	seriaalid =seriaali  (PlN  >seriaal !22_S
36733	kaklus	kaklus	kaklus	11~09_S	SgN	et	kaklus =kaklus  (SgN  >kaklus !11~09_S
36736	sangarid	sangari	sangar	02_S	PlN	et	sangarid =sangari  (PlN  >sangar !02_S
36755	turus	turu	turg	22_S	SgIn	et	turus =turu  (SgIn  >turg !22_S
36764	tavas	tava	tava	17_S	SgIn	et	tavas =tava  (SgIn  >tava !17_S
36767	kavad	kava	kava	17_S	PlN	et	kavad =kava  (PlN  >kava !17_S
36768	tajusin	taju	tajuma	27_V	IndIpfSg1	et	tajusin =taju  (IndIpfSg1  >tajuma !27_V
36784	igavaid	igava	igav	02_A	PlP	et	igavaid =igava  (PlP  >igav !02_A
36785	päevakajasaateid	saate	päeva+kaja+saade	06_S	PlP	et	päevakajasaateid =saate  (PlP  >päeva+kaja+saade !06_S
36787	esitusaja	aja	esitus+aeg	22_S	SgG	et	esitusaja =aja  (SgG  >esitus+aeg !22_S
36792	loodetavasti	loodetavasti	loodetavasti	41_D	ID	et	loodetavasti =loodetavasti  (ID  >loodetavasti !41_D
36800	rinnale	rinna	rind	22_S	SgAll	et	rinnale =rinna  (SgAll  >rind !22_S
36810	kirjutised	kirjutise	kirjutis	11_S	PlN	et	kirjutised =kirjutise  (PlN  >kirjutis !11_S
36828	massikommunikatsioonivahend	vahend	massi+kommunikatsiooni+vahend	02_S	SgN	et	massikommunikatsioonivahend =vahend  (SgN  >massi+kommunikatsiooni+vahend !02_S
36835	universumiks	universumi	universum	02_S	SgTr	et	universumiks =universumi  (SgTr  >universum !02_S
36836	meediate	meedia	meedia	01_S	PlG	et	meediate =meedia  (PlG  >meedia !01_S
36837	informatsioonist	informatsiooni	informatsioon	22_S	SgEl	et	informatsioonist =informatsiooni  (SgEl  >informatsioon !22_S
36838	usaldusväärne	väärne	usaldus+väärne	02_A	SgN	et	usaldusväärne =väärne  (SgN  >usaldus+väärne !02_A
36845	seisukorra	korra	seisu+kord	22_S	SgG	et	seisukorra =korra  (SgG  >seisu+kord !22_S
36853	aeglustada	aeglusta	aeglustama	27_V	Inf	et	aeglustada =aeglusta  (Inf  >aeglustama !27_V
36854	kirjutataks	kirjuta	kirjutama	27_V	KndPrIps	et	kirjutataks =kirjuta  (KndPrIps  >kirjutama !27_V
36664	niidid	niidi	niit	22_S	PlN	et	niidid =niidi  (PlN  >niit !22_S
36666	positsioonist	positsiooni	positsioon	22_S	SgEl	et	positsioonist =positsiooni  (SgEl  >positsioon !22_S
36669	tarbib	tarbi	tarbima	27_V	IndPrSg3	et	tarbib =tarbi  (IndPrSg3  >tarbima !27_V
36694	asepresident	president	ase+president	22_S	SgN	et	asepresident =president  (SgN  >ase+president !22_S
36696	paljastas	paljasta	paljastama	27_V	IndIpfSg3	et	paljastas =paljasta  (IndIpfSg3  >paljastama !27_V
36698	informatsiooniallikat	allika	informatsiooni+allikas	02_S	SgP	et	informatsiooniallikat =allika  (SgP  >informatsiooni+allikas !02_S
36709	osaleb	osale	osalema	27_V	IndPrSg3	et	osaleb =osale  (IndPrSg3  >osalema !27_V
36716	viieminuti	minuti	viie+minut	02_S	SgG	et	viieminuti =minuti  (SgG  >viie+minut !02_S
36718	tõsieluprogramme	programme	tõsi+elu+programm	22_S	PlP	et	tõsieluprogramme =programme  (PlP  >tõsi+elu+programm !22_S
36719	salaarmsates	armsa	sala+armas	03~05_A	PlIn	et	salaarmsates =armsa  (PlIn  >sala+armas !03~05_A
36726	reaalajas	aja	reaal+aeg	22_S	SgIn	et	reaalajas =aja  (SgIn  >reaal+aeg !22_S
36742	filmidele	filmi	film	22_S	PlAll	et	filmidele =filmi  (PlAll  >film !22_S
36754	pangaarvet	arve	panga+arve	06_S	SgP	et	pangaarvet =arve  (SgP  >panga+arve !06_S
36771	kuuldub	kuuldu	kuulduma	27_V	IndPrSg3	et	kuuldub =kuuldu  (IndPrSg3  >kuulduma !27_V
36774	linnaosas	osa	linna+osa	17_S	SgIn	et	linnaosas =osa  (SgIn  >linna+osa !17_S
36779	naaberriigis	riigi	naaber+riik	22_S	SgIn	et	naaberriigis =riigi  (SgIn  >naaber+riik !22_S
36783	tõsielusarjad	sarja	tõsi+elu+sari	24_S	PlN	et	tõsielusarjad =sarja  (PlN  >tõsi+elu+sari !24_S
36786	komöödiasarju	sarju	komöödia+sari	24_S	PlP	et	komöödiasarju =sarju  (PlP  >komöödia+sari !24_S
36789	aegnõudevaid	nõudeva	aeg+nõudev	02_A	PlP	et	aegnõudevaid =nõudeva  (PlP  >aeg+nõudev !02_A
36791	õhtulgi	õhtu	õhtu	01_S	SgAd^	et	õhtulgi =õhtu  (SgAd^  >õhtu !01_S
36796	kompenseeritakse	kompenseeri	kompenseerima	28_V	IndPrIps	et	kompenseeritakse =kompenseeri  (IndPrIps  >kompenseerima !28_V
36799	ordenid	ordeni	orden	02_S	PlN	et	ordenid =ordeni  (PlN  >orden !02_S
36802	õukondade	õukonda	õukond	22_S	PlG	et	õukondade =õukonda  (PlG  >õukond !22_S
36808	leiutis	leiutis	leiutis	11_S	SgN	et	leiutis =leiutis  (SgN  >leiutis !11_S
36811	informatsioonikanalid	kanali	informatsiooni+kanal	02_S	PlN	et	informatsioonikanalid =kanali  (PlN  >informatsiooni+kanal !02_S
36814	trükioskuse	oskuse	trüki+oskus	11~09_S	SgG	et	trükioskuse =oskuse  (SgG  >trüki+oskus !11~09_S
36815	tööriistana	riista	töö+riist	22_S	SgEs	et	tööriistana =riista  (SgEs  >töö+riist !22_S
36818	elutuppa	tuppa	elu+tuba	18_S	SgAdt	et	elutuppa =tuppa  (SgAdt  >elu+tuba !18_S
36824	digitaalne	digitaalne	digitaalne	02_A	SgN	et	digitaalne =digitaalne  (SgN  >digitaalne !02_A
36832	nüüdsel	nüüdse	nüüdne	02_A	SgAd	et	nüüdsel =nüüdse  (SgAd  >nüüdne !02_A
36840	germanistina	germanisti	germanist	22_S	SgEs	et	germanistina =germanisti  (SgEs  >germanist !22_S
36850	keeletüpoloogias	tüpoloogia	keele+tüpoloogia	01_S	SgIn	et	keeletüpoloogias =tüpoloogia  (SgIn  >keele+tüpoloogia !01_S
36856	habe	habe	habe	04_S	SgN	et	habe =habe  (SgN  >habe !04_S
36865	junnil	junni	junn	22_S	SgAd	et	junnil =junni  (SgAd  >junn !22_S
36867	peaminister	minister	pea+minister	02_S	SgN	et	peaminister =minister  (SgN  >pea+minister !02_S
36874	golfiväljak	väljak	golfi+väljak	02_S	SgN	et	golfiväljak =väljak  (SgN  >golfi+väljak !02_S
36888	naelid	naeli	nael	22_S	PlN	et	naelid =naeli  (PlN  >nael !22_S
36891	loeksin	loe	lugema	28_V	KndPrSg1	et	loeksin =loe  (KndPrSg1  >lugema !28_V
36894	kreen	kreen	kreen	22_S	SgN	et	kreen =kreen  (SgN  >kreen !22_S
36895	natsest	natse	nats	22_S	PlEl	et	natsest =natse  (PlEl  >nats !22_S
36906	ragbit	ragbi	ragbi	16_S	SgP	et	ragbit =ragbi  (SgP  >ragbi !16_S
36910	puhkusid	puhku	puhk	22_S	PlP	et	puhkusid =puhku  (PlP  >puhk !22_S
36914	parklad	parkla	parkla	01_S	PlN	et	parklad =parkla  (PlN  >parkla !01_S
36923	lahkuma	lahku	lahkuma	27_V	Sup	et	lahkuma =lahku  (Sup  >lahkuma !27_V
36924	kõrtsid	kõrtsi	kõrts	22_S	PlN	et	kõrtsid =kõrtsi  (PlN  >kõrts !22_S
36932	jõulupäev	päev	jõulu+päev	22_S	SgN	et	jõulupäev =päev  (SgN  >jõulu+päev !22_S
36936	laenama	laena	laenama	29_V	Sup	et	laenama =laena  (Sup  >laenama !29_V
36940	purju	purju	purju	41_D	ID	et	purju =purju  (ID  >purju !41_D
36944	sohvade	sohva	sohva	16_S	PlG	et	sohvade =sohva  (PlG  >sohva !16_S
36958	setulastega	las	setu+laps	14_S	PlKom	et	setulastega =las  (PlKom  >setu+laps !14_S
36961	priit	priit	priit	22_S	SgN	et	priit =priit  (SgN  >priit !22_S
36965	filmiga	filmi	film	22_S	SgKom	et	filmiga =filmi  (SgKom  >film !22_S
36970	märkimisväärne	väärne	märki+mis+väärne	02_A	SgN	et	märkimisväärne =väärne  (SgN  >märki+mis+väärne !02_A
36689	päid	pä	pea	26_S	PlP	et	päid =pä  (PlP  >pea !26_S
36692	nõuniku	nõuniku	nõunik	25_S	SgG	et	nõuniku =nõuniku  (SgG  >nõunik !25_S
36701	vallandati	vallanda	vallandama	27_V	IndIpfIps	et	vallandati =vallanda  (IndIpfIps  >vallandama !27_V
36713	veedeti	veede	veetma	34_V	IndIpfIps	et	veedeti =veede  (IndIpfIps  >veetma !34_V
36723	tobedad	tobeda	tobe	02_A	PlN	et	tobedad =tobeda  (PlN  >tobe !02_A
36727	meediatüüpe	tüüpe	meedia+tüüp	22_S	PlP	et	meediatüüpe =tüüpe  (PlP  >meedia+tüüp !22_S
36730	viiekümnendatel	ate	viie+kümnend+att	22_S	PlAd	et	viiekümnendatel =ate  (PlAd  >viie+kümnend+att !22_S
36731	praegused	praeguse	praegune	10~12_A	PlN	et	praegused =praeguse  (PlN  >praegune !10~12_A
36735	ümbrus	ümbrus	ümbrus	11~09_S	SgN	et	ümbrus =ümbrus  (SgN  >ümbrus !11~09_S
36737	paugub	paugu	paukuma	28_V	IndPrSg3	et	paugub =paugu  (IndPrSg3  >paukuma !28_V
36743	tohib	tohi	tohtima	28_V	IndPrSg3	et	tohib =tohi  (IndPrSg3  >tohtima !28_V
36747	ajatakse	takse	aja+taks	22_S	PlP	et	ajatakse =takse  (PlP  >aja+taks !22_S
36752	meediavahendid	vahendi	meedia+vahend	02_S	PlN	et	meediavahendid =vahendi  (PlN  >meedia+vahend !02_S
36753	reisipileteid	pilete	reisi+pilet	02_S	PlP	et	reisipileteid =pilete  (PlP  >reisi+pilet !02_S
36759	kriitikad	kriitika	kriitika	01_S	PlN	et	kriitikad =kriitika  (PlN  >kriitika !01_S
36770	kavu	kavu	kava	17_S	PlP	et	kavu =kavu  (PlP  >kava !17_S
36773	kõnekavad	kava	kõne+kava	17_S	PlN	et	kõnekavad =kava  (PlN  >kõne+kava !17_S
36777	tv-saateid	saate	tv-saade	06_S	PlP	et	tv-saateid =saate  (PlP  >tv-saade !06_S
36780	valitsemissüsteem	süsteem	valitsemis+süsteem	22_S	SgN	et	valitsemissüsteem =süsteem  (SgN  >valitsemis+süsteem !22_S
36803	narride	narri	narr	22_SA	PlG	et	narride =narri  (PlG  >narr !22_SA
36805	kirikuõpetajate	õpetaja	kiriku+õpetaja	01_S	PlG	et	kirikuõpetajate =õpetaja  (PlG  >kiriku+õpetaja !01_S
36817	vahepeal	vahepeal	vahe+peal	41_D	ID	et	vahepeal =vahepeal  (ID  >vahe+peal !41_D
36823	abivahendeid	vahende	abi+vahend	02_S	PlP	et	abivahendeid =vahende  (PlP  >abi+vahend !02_S
36826	meedium	meedium	meedium	19~02_S	SgN	et	meedium =meedium  (SgN  >meedium !19~02_S
36833	massikommunikatsioonivahendite	vahendi	massi+kommunikatsiooni+vahend	02_S	PlG	et	massikommunikatsioonivahendite =vahendi  (PlG  >massi+kommunikatsiooni+vahend !02_S
36834	naabrimaade	maa	naabri+maa	26_S	PlG	et	naabrimaade =maa  (PlG  >naabri+maa !26_S
36842	linnupoeg	poeg	linnu+poeg	22_S	SgN	et	linnupoeg =poeg  (SgN  >linnu+poeg !22_S
36847	asetutakse	asetu	asetuma	27_V	IndPrIps	et	asetutakse =asetu  (IndPrIps  >asetuma !27_V
36855	ilukirjandust	kirjandus	ilu+kirjandus	11_S	SgP	et	ilukirjandust =kirjandus  (SgP  >ilu+kirjandus !11_S
36859	agentuuris	agentuuri	agentuur	22_S	SgIn	et	agentuuris =agentuuri  (SgIn  >agentuur !22_S
36862	hommikusöök	söök	hommiku+söök	22_S	SgN	et	hommikusöök =söök  (SgN  >hommiku+söök !22_S
36866	impeerium	impeerium	impeerium	19~02_S	SgN	et	impeerium =impeerium  (SgN  >impeerium !19~02_S
36868	uuendata	uuenda	uuendama	27_V	IndPrIps_	et	uuendata =uuenda  (IndPrIps_  >uuendama !27_V
36869	pageda	page	pagema	27_V	Inf	et	pageda =page  (Inf  >pagema !27_V
36870	riigireetmisega	reetmise	riigi+reetmine	12?10_S	SgKom	et	riigireetmisega =reetmise  (SgKom  >riigi+reetmine !12?10_S
36872	ungarlased	ungarlase	ungarlane	12_S	PlN	et	ungarlased =ungarlase  (PlN  >ungarlane !12_S
36875	telekasid	telekasi	telekas	02_S	PlN	et	telekasid =telekasi  (PlN  >telekas !02_S
36876	tennis	tennis	tennis	09_S	SgN	et	tennis =tennis  (SgN  >tennis !09_S
36878	juhuslik	juhuslik	juhuslik	25_A	SgN	et	juhuslik =juhuslik  (SgN  >juhuslik !25_A
36900	mudel-ronge	ronge	mudel-rong	22_S	PlP	et	mudel-ronge =ronge  (PlP  >mudel-rong !22_S
36907	lendur	lendur	lendur	02_S	SgN	et	lendur =lendur  (SgN  >lendur !02_S
36908	mudel-lennuk	lennuk	mudel-lennuk	02_S	SgN	et	mudel-lennuk =lennuk  (SgN  >mudel-lennuk !02_S
36912	mehena	mehe	mees	13_S	SgEs	et	mehena =mehe  (SgEs  >mees !13_S
36922	politseis	politsei	politsei	26_S	SgIn	et	politseis =politsei  (SgIn  >politsei !26_S
36926	aastaaeg	aeg	aasta+aeg	22_S	SgN	et	aastaaeg =aeg  (SgN  >aasta+aeg !22_S
36928	külmim	külmi	külm	22_AS	IM_sA	et	"külmim %külmi  )IM_sA  <külm ;22_AS
36934	tarvitan	tarvita	tarvitama	27_V	IndPrSg1	et	tarvitan =tarvita  (IndPrSg1  >tarvitama !27_V
36935	juustiga	juusti	juust	22_S	SgKom	et	juustiga =juusti  (SgKom  >juust !22_S
36937	kitarr	kitarr	kitarr	22_S	SgN	et	kitarr =kitarr  (SgN  >kitarr !22_S
36950	sõidid	sõidi	sõit	22_S	PlN	et	sõidid =sõidi  (PlN  >sõit !22_S
36951	külalt	küla	küla	17_S	SgAbl	et	külalt =küla  (SgAbl  >küla !17_S
36952	kägu-eestis	eesti	kägu-eesti	16_H	SgIn	et	kägu-eestis =eesti  (SgIn  >kägu-eesti !16_H
36953	vankeritega	vankeri	vanker	02_S	PlKom	et	vankeritega =vankeri  (PlKom  >vanker !02_S
36954	öödel	öö	öö	26_S	PlAd	et	öödel =öö  (PlAd  >öö !26_S
36739	istuma	istu	istuma	28_V	Sup	et	istuma =istu  (Sup  >istuma !28_V
36740	vahtida	vahti	vahtima	28_V	Inf	et	vahtida =vahti  (Inf  >vahtima !28_V
36741	erakordseid	kordse	era+kordne	02_AS	PlP	et	erakordseid =kordse  (PlP  >era+kordne !02_AS
36745	seintele	sein	sein	23_S	PlAll	et	seintele =sein  (PlAll  >sein !23_S
36748	süüdistada	süüdista	süüdistama	27_V	Inf	et	süüdistada =süüdista  (Inf  >süüdistama !27_V
36749	meediat	meedia	meedia	01_S	SgP	et	meediat =meedia  (SgP  >meedia !01_S
36750	meediavahenditest	vahendi	meedia+vahend	02_S	PlEl	et	meediavahenditest =vahendi  (PlEl  >meedia+vahend !02_S
36751	mõjukad	mõjuka	mõjukas	02_A	PlN	et	mõjukad =mõjuka  (PlN  >mõjukas !02_A
36756	nondes	non	too	00_P	PlIn	et	nondes =non  (PlIn  >too !00_P
36757	ümbrusega	ümbruse	ümbrus	11~09_S	SgKom	et	ümbrusega =ümbruse  (SgKom  >ümbrus !11~09_S
36758	jalaaseme	aseme	jala+ase	04_S	SgG	et	jalaaseme =aseme  (SgG  >jala+ase !04_S
36762	arvamustesse	arvamus	arvamus	11_S	PlIll	et	arvamustesse =arvamus  (PlIll  >arvamus !11_S
36763	objektiivsest	objektiivse	objektiivne	02_A	SgEl	et	objektiivsest =objektiivse  (SgEl  >objektiivne !02_A
36765	tellisin	telli	tellima	28_V	IndIpfSg1	et	tellisin =telli  (IndIpfSg1  >tellima !28_V
36766	igatahes	igatahes	iga+tahes	41_D	ID	et	igatahes =igatahes  (ID  >iga+tahes !41_D
36775	omakeelseid	keelse	oma+keelne	02_A	PlP	et	omakeelseid =keelse  (PlP  >oma+keelne !02_A
36788	käsivad	käsi	käskima	28_V	IndPrPl3	et	käsivad =käsi  (IndPrPl3  >käskima !28_V
36790	õhtutel	õhtu	õhtu	01_S	PlAd	et	õhtutel =õhtu  (PlAd  >õhtu !01_S
36794	lööminguid	löömingu	lööming	02_S	PlP	et	lööminguid =löömingu  (PlP  >lööming !02_S
36798	revolutsioone	revolutsioone	revolutsioon	22_S	PlP	et	revolutsioone =revolutsioone  (PlP  >revolutsioon !22_S
36806	kõnedel	kõne	kõne	16_S	PlAd	et	kõnedel =kõne  (PlAd  >kõne !16_S
36807	mõjutaski	mõjuta	mõjutama	27_V	IndIpfSg3^	et	mõjutaski =mõjuta  (IndIpfSg3^  >mõjutama !27_V
36809	trükioskus	oskus	trüki+oskus	11~09_S	SgN	et	trükioskus =oskus  (SgN  >trüki+oskus !11~09_S
36812	võit	võit	võit	22_S	SgN	et	võit =võit  (SgN  >võit !22_S
36813	meediatega	meedia	meedia	01_S	PlKom	et	meediatega =meedia  (PlKom  >meedia !01_S
36816	eelkäijad	käija	eel+käija	01_S	PlN	et	eelkäijad =käija  (PlN  >eel+käija !01_S
36819	militaarses	militaarse	militaarne	02_A	SgIn	et	militaarses =militaarse  (SgIn  >militaarne !02_A
36822	tehnilisi	tehnilisi	tehniline	12_A	PlP	et	tehnilisi =tehnilisi  (PlP  >tehniline !12_A
36829	massikommunikatsioon	kommunikatsioon	massi+kommunikatsioon	22_S	SgN	et	massikommunikatsioon =kommunikatsioon  (SgN  >massi+kommunikatsioon !22_S
36831	massikommunikatsioonil	kommunikatsiooni	massi+kommunikatsioon	22_S	SgAd	et	massikommunikatsioonil =kommunikatsiooni  (SgAd  >massi+kommunikatsioon !22_S
36839	telepropagandal	propaganda	tele+propaganda	16_S	SgAd	et	telepropagandal =propaganda  (SgAd  >tele+propaganda !16_S
36841	millises	millise	milline	10_P	SgIn	et	millises =millise  (SgIn  >milline !10_P
36844	meediakanalid	kanali	meedia+kanal	02_S	PlN	et	meediakanalid =kanali  (PlN  >meedia+kanal !02_S
36852	suurimat	suuri	suur	13_A	IM_sA	et	"suurim %suuri  )IM_sA  <suur ;13_A
36861	ärkan	ärka	ärkama	29_V	IndPrSg1	et	ärkan =ärka  (IndPrSg1  >ärkama !29_V
36871	salajane	salajane	salajane	12_A	SgN	et	salajane =salajane  (SgN  >salajane !12_A
36885	sisseostude	ostu	sisse+ost	22_S	PlG	et	sisseostude =ostu  (PlG  >sisse+ost !22_S
36889	pulloverid	pulloveri	pullover	19_S	PlN	et	pulloverid =pulloveri  (PlN  >pullover !19_S
36898	irooniline	irooniline	irooniline	12_A	SgN	et	irooniline =irooniline  (SgN  >irooniline !12_A
36899	ase	ase	ase	04_S	SgN	et	ase =ase  (SgN  >ase !04_S
36905	poksisin	poksi	poksima	28_V	IndIpfSg1	et	poksisin =poksi  (IndIpfSg1  >poksima !28_V
36911	nõudlik	nõudlik	nõudlik	25_A	SgN	et	nõudlik =nõudlik  (SgN  >nõudlik !25_A
36919	ostaksin	osta	ostma	34_V	KndPrSg1	et	ostaksin =osta  (KndPrSg1  >ostma !34_V
36921	sõidutaksin	sõiduta	sõidutama	27_V	KndPrSg1	et	sõidutaksin =sõiduta  (KndPrSg1  >sõidutama !27_V
36929	vennatütar	tütar	venna+tütar	08_S	SgN	et	vennatütar =tütar  (SgN  >venna+tütar !08_S
36941	tubakorter	korter	tuba+korter	02_S	SgN	et	tubakorter =korter  (SgN  >tuba+korter !02_S
36942	aadress	aadress	aadress	22_S	SgN	et	aadress =aadress  (SgN  >aadress !22_S
36947	käpp	käpp	käpp	22_S	SgN	et	käpp =käpp  (SgN  >käpp !22_S
36948	teispäev	päev	teis+päev	22_S	SgN	et	teispäev =päev  (SgN  >teis+päev !22_S
36949	elustada	elusta	elustama	27_V	Inf	et	elustada =elusta  (Inf  >elustama !27_V
36955	laageris	laageri	laager	02_S	SgIn	et	laageris =laageri  (SgIn  >laager !02_S
36957	festivalis	festivali	festival	19_S	SgIn	et	festivalis =festivali  (SgIn  >festival !19_S
36966	kirjastas	kirjasta	kirjastama	27_V	IndIpfSg3	et	kirjastas =kirjasta  (IndIpfSg3  >kirjastama !27_V
36801	kommunikatsioonivahendid	vahendi	kommunikatsiooni+vahend	02_S	PlN	et	kommunikatsioonivahendid =vahendi  (PlN  >kommunikatsiooni+vahend !02_S
36804	teatrinäidenditel	näidendi	teatri+näidend	02_S	PlAd	et	teatrinäidenditel =näidendi  (PlAd  >teatri+näidend !02_S
36820	kinofilmid	filmi	kino+film	22_S	PlN	et	kinofilmid =filmi  (PlN  >kino+film !22_S
36821	spekter	spekter	spekter	02_S	SgN	et	spekter =spekter  (SgN  >spekter !02_S
36825	term	term	term	22_S	SgN	et	term =term  (SgN  >term !22_S
36827	ametkonna	ametkonna	ametkond	22_S	SgG	et	ametkonna =ametkonna  (SgG  >ametkond !22_S
36830	eespool	eespool	ees+pool	41_DK	ID	et	eespool =eespool  (ID  >ees+pool !41_DK
36843	mõtiskleme	mõtiskle	mõtisklema	27_V	IndPrPl1	et	mõtiskleme =mõtiskle  (IndPrPl1  >mõtisklema !27_V
36846	kahetised	kahetise	kahetine	12_A	PlN	et	kahetised =kahetise  (PlN  >kahetine !12_A
36848	millisena	millise	milline	10_P	SgEs	et	millisena =millise  (SgEs  >milline !10_P
36849	üldises	üldise	üldine	10~12_A	SgIn	et	üldises =üldise  (SgIn  >üldine !10~12_A
36851	palveraamat	raamat	palve+raamat	02_S	SgN	et	palveraamat =raamat  (SgN  >palve+raamat !02_S
36857	alkoholiprobleemid	probleemi	alkoholi+probleem	22_S	PlN	et	alkoholiprobleemid =probleemi  (PlN  >alkoholi+probleem !22_S
36864	küpsetan	küpseta	küpsetama	27_V	IndPrSg1	et	küpsetan =küpseta  (IndPrSg1  >küpsetama !27_V
36881	viibin	viibi	viibima	27_V	IndPrSg1	et	viibin =viibi  (IndPrSg1  >viibima !27_V
36883	nädalid	nädali	nädal	02_S	PlN	et	nädalid =nädali  (PlN  >nädal !02_S
36884	sinust	sinu	sina	00_P	SgEl	et	sinust =sinu  (SgEl  >sina !00_P
36886	t-sark	sark	t-sark	22_S	SgN	et	t-sark =sark  (SgN  >t-sark !22_S
36887	maksavad	maksa	maksma	32_V	IndPrPl3	et	maksavad =maksa  (IndPrPl3  >maksma !32_V
36890	poliitilisi	poliitilisi	poliitiline	12_A	PlP	et	poliitilisi =poliitilisi  (PlP  >poliitiline !12_A
36893	kirjandi	kirjandi	kirjand	02_S	SgG	et	kirjandi =kirjandi  (SgG  >kirjand !02_S
36897	hüüd	hüüd	hüüd	22_S	SgN	et	hüüd =hüüd  (SgN  >hüüd !22_S
36901	bokser	bokser	bokser	02_S	SgN	et	bokser =bokser  (SgN  >bokser !02_S
36904	telekasit	telekasi	telekas	02_S	SgP	et	telekasit =telekasi  (SgP  >telekas !02_S
36909	sõjaväelased	väelase	sõja+väelane	12?10_S	PlN	et	sõjaväelased =väelase  (PlN  >sõja+väelane !12?10_S
36916	töötaski	tööta	töötama	27_V	IndIpfSg3^	et	töötaski =tööta  (IndIpfSg3^  >töötama !27_V
36917	tuleksin	tule	tulema	36_V	KndPrSg1	et	tuleksin =tule  (KndPrSg1  >tulema !36_V
36918	lõõgastaksin	lõõgasta	lõõgastama	27_V	KndPrSg1	et	lõõgastaksin =lõõgasta  (KndPrSg1  >lõõgastama !27_V
36927	detsembril	detsembri	detsember	02_S	SgAd	et	detsembril =detsembri  (SgAd  >detsember !02_S
36931	kõrts	kõrts	kõrts	22_S	SgN	et	kõrts =kõrts  (SgN  >kõrts !22_S
36933	jõulupühal	püha	jõulu+püha	17_SA	SgAd	et	jõulupühal =püha  (SgAd  >jõulu+püha !17_SA
36938	keskpäevaeines	eine	kesk+päeva+eine	06_S	SgIn	et	keskpäevaeines =eine  (SgIn  >kesk+päeva+eine !06_S
36945	seinade	seina	sein	22_S	PlG	et	seinade =seina  (PlG  >sein !22_S
36946	rüül	rüü	rüü	26_S	SgAd	et	rüül =rüü  (SgAd  >rüü !26_S
36959	vestlusi	vestlusi	vestlus	11_S	PlP	et	vestlusi =vestlusi  (PlP  >vestlus !11_S
36960	ortodoksiat	ortodoksia	ortodoksia	01_S	SgP	et	ortodoksiat =ortodoksia  (SgP  >ortodoksia !01_S
36963	priit	priit	priit	22_S	SgN	et	priit =priit  (SgN  >priit !22_S
36964	karjäär	karjäär	karjäär	22_S	SgN	et	karjäär =karjäär  (SgN  >karjäär !22_S
36969	kolmnurk	nurk	kolm+nurk	22_S	SgN	et	kolmnurk =nurk  (SgN  >kolm+nurk !22_S
36971	võitas	võita	võitama	27_V	IndIpfSg3	et	võitas =võita  (IndIpfSg3  >võitama !27_V
36974	tippjuht	juht	tipp+juht	22_S	SgN	et	tippjuht =juht  (SgN  >tipp+juht !22_S
36975	eu-referendumi	referendumi	eu-referendum	02_S	SgG	et	eu-referendumi =referendumi  (SgG  >eu-referendum !02_S
36978	koomik	koomik	koomik	02_S	SgN	et	koomik =koomik  (SgN  >koomik !02_S
36985	mehevend	vend	mehe+vend	22_S	SgN	et	mehevend =vend  (SgN  >mehe+vend !22_S
36986	vennapoeg	poeg	venna+poeg	22_S	SgN	et	vennapoeg =poeg  (SgN  >venna+poeg !22_S
36991	niivaikne	vaikne	nii+vaikne	02_A	SgN	et	niivaikne =vaikne  (SgN  >nii+vaikne !02_A
36996	filosoofiadoktor	doktor	filosoofia+doktor	02_S	SgN	et	filosoofiadoktor =doktor  (SgN  >filosoofia+doktor !02_S
36999	reisile	reisi	reis	22_S	SgAll	et	reisile =reisi  (SgAll  >reis !22_S
37001	iirimasse	masse	iiri+mass	22_S	PlP	et	iirimasse =masse  (PlP  >iiri+mass !22_S
37005	püüdlema	püüdle	püüdlema	30_V	Sup	et	püüdlema =püüdle  (Sup  >püüdlema !30_V
37012	aedsalat	salat	aed+salat	02_S	SgN	et	aedsalat =salat  (SgN  >aed+salat !02_S
37019	tahtma	taht	tahtma	34_V	Sup	et	tahtma =taht  (Sup  >tahtma !34_V
37022	hilist	hilis	hiline	10_A	SgP	et	hilist =hilis  (SgP  >hiline !10_A
37028	linnapealt	pea	linna+pea	26_S	SgAbl	et	linnapealt =pea  (SgAbl  >linna+pea !26_S
36858	töökohita	kohi	töö+kohi	17_SA	SgAb	et	töökohita =kohi  (SgAb  >töö+kohi !17_SA
36860	eelmistel	eelmis	eelmine	12?10_A	PlAd	et	eelmistel =eelmis  (PlAd  >eelmine !12?10_A
36863	raamatukogusse	kogu	raamatu+kogu	17_S	SgIll	et	raamatukogusse =kogu  (SgIll  >raamatu+kogu !17_S
36873	sõidetakse	sõide	sõitma	34_V	IndPrIps	et	sõidetakse =sõide  (IndPrIps  >sõitma !34_V
36877	kirjatäht	täht	kirja+täht	22_S	SgN	et	kirjatäht =täht  (SgN  >kirja+täht !22_S
36879	ee	ee	esi	15_S	SgG	et	ee =ee  (SgG  >esi !15_S
36880	hei	hei	hei	41_I	ID	et	hei =hei  (ID  >hei !41_I
36882	kahtlustan	kahtlusta	kahtlustama	27_V	IndPrSg1	et	kahtlustan =kahtlusta  (IndPrSg1  >kahtlustama !27_V
36892	noorena	noore	noor	13_AS	SgEs	et	noorena =noore  (SgEs  >noor !13_AS
36896	lemmikraamat	raamat	lemmik+raamat	02_S	SgN	et	lemmikraamat =raamat  (SgN  >lemmik+raamat !02_S
36902	arvutimänge	mänge	arvuti+mäng	22_S	PlP	et	arvutimänge =mänge  (PlP  >arvuti+mäng !22_S
36903	bokseriga	bokseri	bokser	02_S	SgKom	et	bokseriga =bokseri  (SgKom  >bokser !02_S
36913	kontorid	kontori	kontor	02_S	PlN	et	kontorid =kontori  (PlN  >kontor !02_S
36915	ligilähedane	lähedane	ligi+lähedane	12_AS	SgN	et	ligilähedane =lähedane  (SgN  >ligi+lähedane !12_AS
36920	sportautod	auto	sport+auto	16_S	PlN	et	sportautod =auto  (PlN  >sport+auto !16_S
36925	eksamad	eksama	eksam	02_S	PlN	et	eksamad =eksama  (PlN  >eksam !02_S
36930	palavikus	palaviku	palavik	25_S	SgIn	et	palavikus =palaviku  (SgIn  >palavik !25_S
36939	vaatlen	vaatle	vaatlema	30_V	IndPrSg1	et	vaatlen =vaatle  (IndPrSg1  >vaatlema !30_V
36943	telefoninumber	number	telefoni+number	02_S	SgN	et	telefoninumber =number  (SgN  >telefoni+number !02_S
36962	pärn	pärn	pärn	22_S	SgN	et	pärn =pärn  (SgN  >pärn !22_S
36973	võisime	või	võima	37_V	IndIpfPl1	et	võisime =või  (IndIpfPl1  >võima !37_V
36976	laisklust	lust	laisk+lust	22_S	SgN	et	laisklust =lust  (SgN  >laisk+lust !22_S
36979	draamat	draama	draama	16_S	SgP	et	draamat =draama  (SgP  >draama !16_S
36981	abiellus	ellu	abi+elluma	27_V	IndIpfSg3	et	abiellus =ellu  (IndIpfSg3  >abi+elluma !27_V
36983	hommikujõulud	jõulu	hommiku+jõul	22_S	PlN	et	hommikujõulud =jõulu  (PlN  >hommiku+jõul !22_S
36989	jõuluvanana	vana	jõulu+vana	17_AS	SgEs	et	jõuluvanana =vana  (SgEs  >jõulu+vana !17_AS
36998	tolknema	tolkne	tolknema	27_V	Sup	et	tolknema =tolkne  (Sup  >tolknema !27_V
37000	prantsusmaasse	maa	prantsus+maa	26_S	SgIll	et	prantsusmaasse =maa  (SgIll  >prantsus+maa !26_S
37015	kartong	kartong	kartong	22_S	SgN	et	kartong =kartong  (SgN  >kartong !22_S
37016	kurg	kurg	kurg	22_S	SgN	et	kurg =kurg  (SgN  >kurg !22_S
37018	tinad	tina	tina	17_S	PlN	et	tinad =tina  (PlN  >tina !17_S
37020	suhkur	suhkur	suhkur	02_S	SgN	et	suhkur =suhkur  (SgN  >suhkur !02_S
37036	peekoniks	peekoni	peekon	02_S	SgTr	et	peekoniks =peekoni  (SgTr  >peekon !02_S
37038	grillahi	ahi	grill+ahi	24_S	SgN	et	grillahi =ahi  (SgN  >grill+ahi !24_S
37042	röstima	rösti	röstima	28_V	Sup	et	röstima =rösti  (Sup  >röstima !28_V
37043	asetab	aseta	asetama	27_V	IndPrSg3	et	asetab =aseta  (IndPrSg3  >asetama !27_V
37053	allkiri	kiri	all+kiri	24_S	SgN	et	allkiri =kiri  (SgN  >all+kiri !24_S
37058	säärased	säärase	säärane	10_P	PlN	et	säärased =säärase  (PlN  >säärane !10_P
37067	nägusaid	nägusa	nägus	02_A	PlP	et	nägusaid =nägusa  (PlP  >nägus !02_A
37071	suvele	suve	suvi	20_S	SgAll	et	suvele =suve  (SgAll  >suvi !20_S
37080	võidumeheks	mehe	võidu+mees	13_S	SgTr	et	võidumeheks =mehe  (SgTr  >võidu+mees !13_S
37082	luudest	luu	luu	26_S	PlEl	et	luudest =luu  (PlEl  >luu !26_S
37086	töömeeleolus	olu	töö+meele+olu	17_S	SgIn	et	töömeeleolus =olu  (SgIn  >töö+meele+olu !17_S
37090	kaubamajas	maja	kauba+maja	17_S	SgIn	et	kaubamajas =maja  (SgIn  >kauba+maja !17_S
37091	hm	hm	hm	41_I	ID	et	hm =hm  (ID  >hm !41_I
37094	kaubamärk	märk	kauba+märk	22_S	SgN	et	kaubamärk =märk  (SgN  >kauba+märk !22_S
37098	kalkunil	kalkuni	kalkun	02_S	SgAd	et	kalkunil =kalkuni  (SgAd  >kalkun !02_S
37100	sattuma	sattu	sattuma	27~28_V	Sup	et	sattuma =sattu  (Sup  >sattuma !27~28_V
37102	rase	rase	rase	02_AS	SgN	et	rase =rase  (SgN  >rase !02_AS
37106	saabuma	saabu	saabuma	27_V	Sup	et	saabuma =saabu  (Sup  >saabuma !27_V
37121	palja	palja	paljas	07_A	SgG	et	palja =palja  (SgG  >paljas !07_A
37124	dialekt	dialekt	dialekt	22_S	SgN	et	dialekt =dialekt  (SgN  >dialekt !22_S
37128	väljuma	välju	väljuma	27_V	Sup	et	väljuma =välju  (Sup  >väljuma !27_V
37129	deklareerimas	deklareeri	deklareerima	28_V	SupIn	et	deklareerimas =deklareeri  (SupIn  >deklareerima !28_V
37133	määrama	määra	määrama	29_V	Sup	et	määrama =määra  (Sup  >määrama !29_V
37142	esiku	esiku	esik	02_S	SgG	et	esiku =esiku  (SgG  >esik !02_S
36956	endistes	endis	endine	10~12_A	PlIn	et	endistes =endis  (PlIn  >endine !10~12_A
36968	kuulusi	kuulusi	kuulus	02_A	SgG	et	kuulusi =kuulusi  (SgG  >kuulus !02_A
36977	saavutad	saavuta	saavutama	27_V	IndPrSg2	et	saavutad =saavuta  (IndPrSg2  >saavutama !27_V
36980	varupaik	paik	varu+paik	22_S	SgN	et	varupaik =paik  (SgN  >varu+paik !22_S
36982	jahisaak	saak	jahi+saak	22_S	SgN	et	jahisaak =saak  (SgN  >jahi+saak !22_S
36992	osastasin	osasta	osastama	27_V	IndIpfSg1	et	osastasin =osasta  (IndIpfSg1  >osastama !27_V
36993	keskne-	keskne	keskne	02_A	SgN	et	keskne- =keskne  (SgN  >keskne !02_A
36995	lootma	loot	lootma	34_V	Sup	et	lootma =loot  (Sup  >lootma !34_V
37002	festival	festival	festival	19_S	SgN	et	festival =festival  (SgN  >festival !19_S
37007	vihkan	vihka	vihkama	29_V	IndPrSg1	et	vihkan =vihka  (IndPrSg1  >vihkama !29_V
37009	purk	purk	purk	22_S	SgN	et	purk =purk  (SgN  >purk !22_S
37011	peekonit	peekoni	peekon	02_S	SgP	et	peekonit =peekoni  (SgP  >peekon !02_S
37041	leivas	leiva	leib	22_S	SgIn	et	leivas =leiva  (SgIn  >leib !22_S
37056	sünged	sünge	sünge	01_A	PlN	et	sünged =sünge  (PlN  >sünge !01_A
37057	eelistama	eelista	eelistama	27_V	Sup	et	eelistama =eelista  (Sup  >eelistama !27_V
37059	lambatall	tall	lamba+tall	22_S	SgN	et	lambatall =tall  (SgN  >lamba+tall !22_S
37060	ameeriklane	ameeriklane	ameeriklane	12_S	SgN	et	ameeriklane =ameeriklane  (SgN  >ameeriklane !12_S
37063	põhinema	põhine	põhinema	27_V	Sup	et	põhinema =põhine  (Sup  >põhinema !27_V
37064	seerias	seeria	seeria	01_S	SgIn	et	seerias =seeria  (SgIn  >seeria !01_S
37068	vendasid	venda	vend	22_S	PlP	et	vendasid =venda  (PlP  >vend !22_S
37069	ärev	ärev	ärev	02_A	SgN	et	ärev =ärev  (SgN  >ärev !02_A
37073	lubamasin	masin	luba+masin	02_S	SgN	et	lubamasin =masin  (SgN  >luba+masin !02_S
37075	naljatama	naljata	naljatama	27_V	Sup	et	naljatama =naljata  (Sup  >naljatama !27_V
37076	kindlustama	kindlusta	kindlustama	27_V	Sup	et	kindlustama =kindlusta  (Sup  >kindlustama !27_V
37087	rõõmuga	rõõmu	rõõm	22_S	SgKom	et	rõõmuga =rõõmu  (SgKom  >rõõm !22_S
37092	lõikama	lõika	lõikama	29_V	Sup	et	lõikama =lõika  (Sup  >lõikama !29_V
37095	ebaharilik	harilik	eba+harilik	25_A	SgN	et	ebaharilik =harilik  (SgN  >eba+harilik !25_A
37096	nõustuma	nõustu	nõustuma	27_V	Sup	et	nõustuma =nõustu  (Sup  >nõustuma !27_V
37104	tähtaeg	aeg	täht+aeg	22_S	SgN	et	tähtaeg =aeg  (SgN  >täht+aeg !22_S
37115	väljakul	väljaku	väljak	02_S	SgAd	et	väljakul =väljaku  (SgAd  >väljak !02_S
37116	vasaku	vasaku	vasak	02_A	SgG	et	vasaku =vasaku  (SgG  >vasak !02_A
37117	pst	pst	pst	41_I	ID	et	pst =pst  (ID  >pst !41_I
37123	kumme	kumme	kumm	22_S	PlP	et	kumme =kumme  (PlP  >kumm !22_S
37135	kuldmedal	medal	kuld+medal	02_S	SgN	et	kuldmedal =medal  (SgN  >kuld+medal !02_S
37138	öökapp	kapp	öö+kapp	22_S	SgN	et	öökapp =kapp  (SgN  >öö+kapp !22_S
37140	tööpind	pind	töö+pind	22_S	SgN	et	tööpind =pind  (SgN  >töö+pind !22_S
37146	korterinumber	number	korteri+number	02_S	SgN	et	korterinumber =number  (SgN  >korteri+number !02_S
37154	katarina	katari	katar	02_S	SgEs	et	katarina =katari  (SgEs  >katar !02_S
37159	lemmikloom	loom	lemmik+loom	22_S	SgN	et	lemmikloom =loom  (SgN  >lemmik+loom !22_S
37161	ametipostil	posti	ameti+post	22_S	SgAd	et	ametipostil =posti  (SgAd  >ameti+post !22_S
37168	saabumas	saabu	saabuma	27_V	SupIn	et	saabumas =saabu  (SupIn  >saabuma !27_V
37184	koduteel	tee	kodu+tee	26_S	SgAd	et	koduteel =tee  (SgAd  >kodu+tee !26_S
37187	kobama	koba	kobama	27_V	Sup	et	kobama =koba  (Sup  >kobama !27_V
37189	käiseid	käise	käis	09_S	PlP	et	käiseid =käise  (PlP  >käis !09_S
37190	varitsema	varitse	varitsema	27_V	Sup	et	varitsema =varitse  (Sup  >varitsema !27_V
37195	viltu	viltu	viltu	41_D	ID	et	viltu =viltu  (ID  >viltu !41_D
37196	kujule	kuju	kuju	17_S	SgAll	et	kujule =kuju  (SgAll  >kuju !17_S
37199	püstitada	püstita	püstitama	27_V	Inf	et	püstitada =püstita  (Inf  >püstitama !27_V
37213	ühingu	ühingu	ühing	02_S	SgG	et	ühingu =ühingu  (SgG  >ühing !02_S
37214	vägilane	vägilane	vägilane	12_S	SgN	et	vägilane =vägilane  (SgN  >vägilane !12_S
37222	vaidlusealust	lust	vaidlus+ea+lust	22_S	SgN	et	vaidlusealust =lust  (SgN  >vaidlus+ea+lust !22_S
37223	pooldama	poolda	pooldama	27_V	Sup	et	pooldama =poolda  (Sup  >pooldama !27_V
37228	põhjendab	põhjenda	põhjendama	27_V	IndPrSg3	et	põhjendab =põhjenda  (IndPrSg3  >põhjendama !27_V
37237	mh	mh	mh	41_I	ID	et	mh =mh  (ID  >mh !41_I
37239	vägistas	vägista	vägistama	27_V	IndIpfSg3	et	vägistas =vägista  (IndIpfSg3  >vägistama !27_V
37245	kangelase	kangelase	kangelane	12_S	SgG	et	kangelase =kangelase  (SgG  >kangelane !12_S
36967	kaalutleme	kaalutle	kaalutlema	27_V	IndPrPl1	et	kaalutleme =kaalutle  (IndPrPl1  >kaalutlema !27_V
36972	alapealkiri	kiri	ala+peal+kiri	24_S	SgN	et	alapealkiri =kiri  (SgN  >ala+peal+kiri !24_S
36987	tundusin	tundu	tunduma	27_V	IndIpfSg1	et	tundusin =tundu  (IndIpfSg1  >tunduma !27_V
36990	kinkisin	kinki	kinkima	28_V	IndIpfSg1	et	kinkisin =kinki  (IndIpfSg1  >kinkima !28_V
37006	helepruunile	pruuni	hele+pruun	22_AS	SgAll	et	helepruunile =pruuni  (SgAll  >hele+pruun !22_AS
37013	toober	toober	toober	02_S	SgN	et	toober =toober  (SgN  >toober !02_S
37014	riisipuder	puder	riisi+puder	24_S	SgN	et	riisipuder =puder  (SgN  >riisi+puder !24_S
37017	tomatipüreesupp	supp	tomati+püree+supp	22_S	SgN	et	tomatipüreesupp =supp  (SgN  >tomati+püree+supp !22_S
37023	puudumasin	masin	puudu+masin	02_S	SgN	et	puudumasin =masin  (SgN  >puudu+masin !02_S
37024	tõlkisime	tõlki	tõlkima	28_V	IndIpfPl1	et	tõlkisime =tõlki  (IndIpfPl1  >tõlkima !28_V
37026	õnneliku	õnneliku	õnnelik	25_A	SgG	et	õnneliku =õnneliku  (SgG  >õnnelik !25_A
37027	alandaksin	alanda	alandama	27_V	KndPrSg1	et	alandaksin =alanda  (KndPrSg1  >alandama !27_V
37045	asetama	aseta	asetama	27_V	Sup	et	asetama =aseta  (Sup  >asetama !27_V
37048	pensionile	pensioni	pension	19~02_S	SgAll	et	pensionile =pensioni  (SgAll  >pension !19~02_S
37049	ellukutsumine	kutsumine	ellu+kutsumine	12_S	SgN	et	ellukutsumine =kutsumine  (SgN  >ellu+kutsumine !12_S
37054	põnevusromaanid	romaani	põnevus+romaan	22_S	PlN	et	põnevusromaanid =romaani  (PlN  >põnevus+romaan !22_S
37065	bestseller	bestseller	bestseller	02_S	SgN	et	bestseller =bestseller  (SgN  >bestseller !02_S
37070	sügiseid	sügise	sügis	09_S	PlP	et	sügiseid =sügise  (PlP  >sügis !09_S
37078	üldharidus	haridus	üld+haridus	11_S	SgN	et	üldharidus =haridus  (SgN  >üld+haridus !11_S
37081	vihmaga	vihma	vihm	22_S	SgKom	et	vihmaga =vihma  (SgKom  >vihm !22_S
37083	videvik	videvik	videvik	25_S	SgN	et	videvik =videvik  (SgN  >videvik !25_S
37101	lõppis	lõpp	lõpma	35_V	IndIpfSg3	et	lõppis =lõpp  (IndIpfSg3  >lõpma !35_V
37103	hellitama	hellita	hellitama	27_V	Sup	et	hellitama =hellita  (Sup  >hellitama !27_V
37109	saaksime	saa	saama	37_V	KndPrPl1	et	saaksime =saa  (KndPrPl1  >saama !37_V
37110	majasse	maja	maja	17_S	SgIll	et	majasse =maja  (SgIll  >maja !17_S
37113	töötamasin	masin	tööta+masin	02_S	SgN	et	töötamasin =masin  (SgN  >tööta+masin !02_S
37122	köökus	köökus	köökus	41_DA	ID	et	köökus =köökus  (ID  >köökus !41_DA
37126	piirjoon	joon	piir+joon	13_S	SgN	et	piirjoon =joon  (SgN  >piir+joon !13_S
37127	heitlema	heitle	heitlema	30_V	Sup	et	heitlema =heitle  (Sup  >heitlema !30_V
37134	üldkehtiv	kehtiv	üld+kehtiv	02_A	SgN	et	üldkehtiv =kehtiv  (SgN  >üld+kehtiv !02_A
37137	padi	padi	padi	24_S	SgN	et	padi =padi  (SgN  >padi !24_S
37141	tugitool	tool	tugi+tool	22_S	SgN	et	tugitool =tool  (SgN  >tugi+tool !22_S
37145	majanumber	number	maja+number	02_S	SgN	et	majanumber =number  (SgN  >maja+number !02_S
37155	igalt	iga	iga	17_P	SgAbl	et	igalt =iga  (SgAbl  >iga !17_P
37170	majutada	majuta	majutama	27_V	Inf	et	majutada =majuta  (Inf  >majutama !27_V
37177	peavaluga	valu	pea+valu	17_S	SgKom	et	peavaluga =valu  (SgKom  >pea+valu !17_S
37178	ehtne	ehtne	ehtne	02_A	SgN	et	ehtne =ehtne  (SgN  >ehtne !02_A
37186	hirmuäratav	äratav	hirmu+äratav	02_A	SgN	et	hirmuäratav =äratav  (SgN  >hirmu+äratav !02_A
37188	ülikiiresti	ülikiiresti	üli+kiiresti	41_D	ID	et	ülikiiresti =ülikiiresti  (ID  >üli+kiiresti !41_D
37191	kartulid	kartuli	kartul	02_S	PlN	et	kartulid =kartuli  (PlN  >kartul !02_S
37192	jaa	jaa	jaa	41_DI	ID	et	jaa =jaa  (ID  >jaa !41_DI
37194	kunstnike	kunstnike	kunstnik	25_S	PlG	et	kunstnike =kunstnike  (PlG  >kunstnik !25_S
37201	rahvaeepose	eepose	rahva+eepos	11~09_S	SgG	et	rahvaeepose =eepose  (SgG  >rahva+eepos !11~09_S
37208	sangaritele	sangari	sangar	02_S	PlAll	et	sangaritele =sangari  (PlAll  >sangar !02_S
37209	obelisk	obelisk	obelisk	22_S	SgN	et	obelisk =obelisk  (SgN  >obelisk !22_S
37210	rannatrepid	trepi	ranna+trepp	22_S	PlN	et	rannatrepid =trepi  (PlN  >ranna+trepp !22_S
37212	kujurite	kujuri	kujur	02_S	PlG	et	kujurite =kujuri  (PlG  >kujur !02_S
37218	kunstnikliige	ige	kunst+nikli+ige	04_S	SgN	et	kunstnikliige =ige  (SgN  >kunst+nikli+ige !04_S
37220	parke	parke	park	22_S	PlP	et	parke =parke  (PlP  >park !22_S
37221	isaks	isa	isa	17_S	SgTr	et	isaks =isa  (SgTr  >isa !17_S
37224	ettepanek	panek	ette+panek	02_S	SgN	et	ettepanek =panek  (SgN  >ette+panek !02_S
37227	kalkuleerisime	kalkuleeri	kalkuleerima	28_V	IndIpfPl1	et	kalkuleerisime =kalkuleeri  (IndIpfPl1  >kalkuleerima !28_V
37230	sangari	sangari	sangar	02_S	SgG	et	sangari =sangari  (SgG  >sangar !02_S
37231	kojutulek	tulek	koju+tulek	02_S	SgN	et	kojutulek =tulek  (SgN  >koju+tulek !02_S
36984	vahetasime	vaheta	vahetama	27_V	IndIpfPl1	et	vahetasime =vaheta  (IndIpfPl1  >vahetama !27_V
36988	riietusin	riietu	riietuma	27_V	IndIpfSg1	et	riietusin =riietu  (IndIpfSg1  >riietuma !27_V
36994	jätkama	jätka	jätkama	29_V	Sup	et	jätkama =jätka  (Sup  >jätkama !29_V
36997	päevitatakse	päevita	päevitama	27_V	IndPrIps	et	päevitatakse =päevita  (IndPrIps  >päevitama !27_V
37003	aastaajad	aja	aasta+aeg	22_S	PlN	et	aastaajad =aja  (PlN  >aasta+aeg !22_S
37004	vastik	vastik	vastik	02_A	SgN	et	vastik =vastik  (SgN  >vastik !02_A
37008	iganädal	nädal	iga+nädal	02_S	SgN	et	iganädal =nädal  (SgN  >iga+nädal !02_S
37010	pakk	pakk	pakk	22_S	SgN	et	pakk =pakk  (SgN  >pakk !22_S
37021	sigaret	sigaret	sigaret	22_S	SgN	et	sigaret =sigaret  (SgN  >sigaret !22_S
37025	ühiskonnateaduse	teaduse	ühis+konna+teadus	11~09_S	SgG	et	ühiskonnateaduse =teaduse  (SgG  >ühis+konna+teadus !11~09_S
37030	põhjustama	põhjusta	põhjustama	27_V	Sup	et	põhjustama =põhjusta  (Sup  >põhjustama !27_V
37031	keelaksin	keela	keelama	29_V	KndPrSg1	et	keelaksin =keela  (KndPrSg1  >keelama !29_V
37040	võiga	või	või	26_S	SgKom	et	võiga =või  (SgKom  >või !26_S
37047	töökoormus	koormus	töö+koormus	11~09_S	SgN	et	töökoormus =koormus  (SgN  >töö+koormus !11~09_S
37050	avameelne	meelne	ava+meelne	02_A	SgN	et	avameelne =meelne  (SgN  >ava+meelne !02_A
37052	naljaasi	asi	nalja+asi	24_S	SgN	et	naljaasi =asi  (SgN  >nalja+asi !24_S
37055	biograafiad	biograafia	biograafia	01_S	PlN	et	biograafiad =biograafia  (PlN  >biograafia !01_S
37066	raskes	raske	raske	01_A	SgIn	et	raskes =raske  (SgIn  >raske !01_A
37072	laudu	laudu	laud	22_S	PlP	et	laudu =laudu  (PlP  >laud !22_S
37074	keelustama	keelusta	keelustama	27_V	Sup	et	keelustama =keelusta  (Sup  >keelustama !27_V
37077	jäänused	jäänuse	jäänus	09_S	PlN	et	jäänused =jäänuse  (PlN  >jäänus !09_S
37079	pühitsema	pühitse	pühitsema	27_V	Sup	et	pühitsema =pühitse  (Sup  >pühitsema !27_V
37088	oste	oste	ost	22_S	PlP	et	oste =oste  (PlP  >ost !22_S
37099	võlgadesse	võlga	võlg	22_S	PlIll	et	võlgadesse =võlga  (PlIll  >võlg !22_S
37108	lapsevoodis	voodi	lapse+voodi	01_S	SgIn	et	lapsevoodis =voodi  (SgIn  >lapse+voodi !01_S
37111	detsember	detsember	detsember	02_S	SgN	et	detsember =detsember  (SgN  >detsember !02_S
37120	naer	naer	naer	22_S	SgN	et	naer =naer  (SgN  >naer !22_S
37130	kuningriik	riik	kuning+riik	22_S	SgN	et	kuningriik =riik  (SgN  >kuning+riik !22_S
37131	kohaliks	iks	kohal+iks	22_S	SgN	et	kohaliks =iks  (SgN  >kohal+iks !22_S
37132	porgandite	porgandi	porgand	02_S	PlG	et	porgandite =porgandi  (PlG  >porgand !02_S
37136	õpetas	õpeta	õpetama	27_V	IndIpfSg3	et	õpetas =õpeta  (IndIpfSg3  >õpetama !27_V
37139	pesumasin	masin	pesu+masin	02_S	SgN	et	pesumasin =masin  (SgN  >pesu+masin !02_S
37143	kummut	kummut	kummut	02_S	SgN	et	kummut =kummut  (SgN  >kummut !02_S
37149	nädalapäev	päev	nädala+päev	22_S	SgN	et	nädalapäev =päev  (SgN  >nädala+päev !22_S
37151	kinooperaator	operaator	kino+operaator	02_S	SgN	et	kinooperaator =operaator  (SgN  >kino+operaator !02_S
37153	toetama	toeta	toetama	27_V	Sup	et	toetama =toeta  (Sup  >toetama !27_V
37157	kopsuvähktõbi	tõbi	kopsu+vähk+tõbi	21_S	SgN	et	kopsuvähktõbi =tõbi  (SgN  >kopsu+vähk+tõbi !21_S
37165	varajane	varajane	varajane	12_A	SgN	et	varajane =varajane  (SgN  >varajane !12_A
37169	vilt	vilt	vilt	22_S	SgN	et	vilt =vilt  (SgN  >vilt !22_S
37174	auk	auk	auk	22_S	SgN	et	auk =auk  (SgN  >auk !22_S
37176	lõunastama	lõunasta	lõunastama	27_V	Sup	et	lõunastama =lõunasta  (Sup  >lõunastama !27_V
37182	pakkima	pakki	pakkima	28_V	Sup	et	pakkima =pakki  (Sup  >pakkima !28_V
37193	suuremeelne	meelne	suure+meelne	02_A	SgN	et	suuremeelne =meelne  (SgN  >suure+meelne !02_A
37198	plaanile	plaani	plaan	22_S	SgAll	et	plaanile =plaani  (SgAll  >plaan !22_S
37203	konkursile	konkursi	konkurss	22_S	SgAll	et	konkursile =konkursi  (SgAll  >konkurss !22_S
37211	skulptorite	skulptori	skulptor	02_S	PlG	et	skulptorite =skulptori  (PlG  >skulptor !02_S
37215	nõukogudeaja	aja	nõu+kogude+aeg	22_S	SgG	et	nõukogudeaja =aja  (SgG  >nõu+kogude+aeg !22_S
37217	ametnikkude	ametnikku	ametnik	25_S	PlG	et	ametnikkude =ametnikku  (PlG  >ametnik !25_S
37226	maarjamäe	mäe	maarja+mägi	21_S	SgG	et	maarjamäe =mäe  (SgG  >maarja+mägi !21_S
37235	ühing	ühing	ühing	02_S	SgN	et	ühing =ühing  (SgN  >ühing !02_S
37241	avaldatakse	avalda	avaldama	27_V	IndPrIps	et	avaldatakse =avalda  (IndPrIps  >avaldama !27_V
37247	esmaspäevaks	päeva	esmas+päev	22_S	SgTr	et	esmaspäevaks =päeva  (SgTr  >esmas+päev !22_S
37251	lahkhelid	heli	lahk+heli	17_S	PlN	et	lahkhelid =heli  (PlN  >lahk+heli !17_S
37253	skulptorite-	skulptori	skulptor	02_S	PlG	et	skulptorite- =skulptori  (PlG  >skulptor !02_S
37269	hanget	hange	hange	06_S	SgP	et	hanget =hange  (SgP  >hange !06_S
37029	keelustaksin	keelusta	keelustama	27_V	KndPrSg1	et	keelustaksin =keelusta  (KndPrSg1  >keelustama !27_V
37032	võitma	võit	võitma	34_V	Sup	et	võitma =võit  (Sup  >võitma !34_V
37033	sügises	sügise	sügis	09_S	SgIn	et	sügises =sügise  (SgIn  >sügis !09_S
37034	tagasiteele	tee	tagasi+tee	26_S	SgAll	et	tagasiteele =tee  (SgAll  >tagasi+tee !26_S
37035	retsept	retsept	retsept	22_S	SgN	et	retsept =retsept  (SgN  >retsept !22_S
37037	praepannis	panni	prae+pann	22_S	SgIn	et	praepannis =panni  (SgIn  >prae+pann !22_S
37039	määrib	määri	määrima	28_V	IndPrSg3	et	määrib =määri  (IndPrSg3  >määrima !28_V
37044	peekoni	peekoni	peekon	02_S	SgG	et	peekoni =peekoni  (SgG  >peekon !02_S
37046	iirimaalt	maa	iiri+maa	26_S	SgAbl	et	iirimaalt =maa  (SgAbl  >iiri+maa !26_S
37051	suremas	sure	surema	36_V	SupIn	et	suremas =sure  (SupIn  >surema !36_V
37061	ühendriikides	riiki	ühend+riik	22_S	PlIn	et	ühendriikides =riiki  (PlIn  >ühend+riik !22_S
37062	osariigis	riigi	osa+riik	22_S	SgIn	et	osariigis =riigi  (SgIn  >osa+riik !22_S
37084	tõlgitsema	tõlgitse	tõlgitsema	27_V	Sup	et	tõlgitsema =tõlgitse  (Sup  >tõlgitsema !27_V
37085	kellgi	kell	kell	22_S	SgN^	et	kellgi =kell  (SgN^  >kell !22_S
37089	aegajalt	aja	aeg+aeg	22_S	SgAbl	et	aegajalt =aja  (SgAbl  >aeg+aeg !22_S
37093	spetsiaalne	spetsiaalne	spetsiaalne	02_A	SgN	et	spetsiaalne =spetsiaalne  (SgN  >spetsiaalne !02_A
37097	produtseerima	produtseeri	produtseerima	28_V	Sup	et	produtseerima =produtseeri  (Sup  >produtseerima !28_V
37105	jaanuar	jaanuar	jaanuar	19_S	SgN	et	jaanuar =jaanuar  (SgN  >jaanuar !19_S
37107	omamasin	masin	oma+masin	02_S	SgN	et	omamasin =masin  (SgN  >oma+masin !02_S
37112	üliväsinud	väsinu	üli+väsinu	01_S	PlN	et	üliväsinud =väsinu  (PlN  >üli+väsinu !01_S
37114	nimestik	nimestik	nimestik	25_S	SgN	et	nimestik =nimestik  (SgN  >nimestik !25_S
37118	teelahkmel	lahkme	tee+lahe	05_S	SgAd	et	teelahkmel =lahkme  (SgAd  >tee+lahe !05_S
37119	maarja	maarja	maarjas	02_S	SgG	et	maarja =maarja  (SgG  >maarjas !02_S
37125	ortodoksne	ortodoksne	ortodoksne	02_A	SgN	et	ortodoksne =ortodoksne  (SgN  >ortodoksne !02_A
37144	null	null	null	22_NS	SgN	et	null =null  (SgN  >null !22_NS
37147	anni	anni	and	22_S	SgG	et	anni =anni  (SgG  >and !22_S
37148	lubasin	luba	lubama	27_V	IndIpfSg1	et	lubasin =luba  (IndIpfSg1  >lubama !27_V
37152	pensionil	pensioni	pension	19~02_S	SgAd	et	pensionil =pensioni  (SgAd  >pension !19~02_S
37156	üheksakümnendatel	ate	üheksa+kümnend+att	22_S	PlAd	et	üheksakümnendatel =ate  (PlAd  >üheksa+kümnend+att !22_S
37158	inspiratsioon	inspiratsioon	inspiratsioon	22_S	SgN	et	inspiratsioon =inspiratsioon  (SgN  >inspiratsioon !22_S
37162	artikkeli	artikkeli	artikkel	02_S	SgG	et	artikkeli =artikkeli  (SgG  >artikkel !02_S
37163	teekond	teekond	teekond	22_S	SgN	et	teekond =teekond  (SgN  >teekond !22_S
37164	ines	ine	ine	16_S	SgIn	et	ines =ine  (SgIn  >ine !16_S
37172	itaallased	itaallase	itaallane	12?10_S	PlN	et	itaallased =itaallase  (PlN  >itaallane !12?10_S
37173	judinad	judina	judin	02_S	PlN	et	judinad =judina  (PlN  >judin !02_S
37175	pisarsilmi	pisarsilmi	pisar+silmi	41_D	ID	et	pisarsilmi =pisarsilmi  (ID  >pisar+silmi !41_D
37185	sööt	sööt	sööt	22_S	SgN	et	sööt =sööt  (SgN  >sööt !22_S
37202	vägilase	vägilase	vägilane	12_S	SgG	et	vägilase =vägilase  (SgG  >vägilane !12_S
37204	tähtaja	aja	täht+aeg	22_S	SgG	et	tähtaja =aja  (SgG  >täht+aeg !22_S
37207	meetri	meetri	meeter	02_S	SgG	et	meetri =meetri  (SgG  >meeter !02_S
37219	maastikuarhitekt	arhitekt	maas+tiku+arhitekt	22_S	SgN	et	maastikuarhitekt =arhitekt  (SgN  >maas+tiku+arhitekt !22_S
37225	meetrini	meetri	meeter	02_S	SgTer	et	meetrini =meetri  (SgTer  >meeter !02_S
37233	inimolendid	olendi	inim+olend	02_S	PlN	et	inimolendid =olendi  (PlN  >inim+olend !02_S
37238	vaenlaste	vaenlas	vaenlane	12?10_S	PlG	et	vaenlaste =vaenlas  (PlG  >vaenlane !12?10_S
37240	võistluse	võistluse	võistlus	11~09_S	SgG	et	võistluse =võistluse  (SgG  >võistlus !11~09_S
37243	ülejärgmise	järgmise	üle+järgmine	12?10_A	SgG	et	ülejärgmise =järgmise  (SgG  >üle+järgmine !12?10_A
37246	tähtajaks	aja	täht+aeg	22_S	SgTr	et	tähtajaks =aja  (SgTr  >täht+aeg !22_S
37250	skulptuur	skulptuur	skulptuur	22_S	SgN	et	skulptuur =skulptuur  (SgN  >skulptuur !22_S
37252	nõukogudeaegse	aegse	nõu+kogude+aegne	02_A	SgG	et	nõukogudeaegse =aegse  (SgG  >nõu+kogude+aegne !02_A
37254	kohtunike	kohtunike	kohtunik	25_S	PlG	et	kohtunike =kohtunike  (PlG  >kohtunik !25_S
37255	kunstnikust	kunstniku	kunstnik	25_S	SgEl	et	kunstnikust =kunstniku  (SgEl  >kunstnik !25_S
37260	arvutasime	arvuta	arvutama	27_V	IndIpfPl1	et	arvutasime =arvuta  (IndIpfPl1  >arvutama !27_V
37261	paistaks	paista	paistma	34_V	KndPrPs	et	paistaks =paista  (KndPrPs  >paistma !34_V
37263	esitles	esitle	esitlema	27_V	IndIpfSg3	et	esitles =esitle  (IndIpfSg3  >esitlema !27_V
37150	fotoreporter	reporter	foto+reporter	02_S	SgN	et	fotoreporter =reporter  (SgN  >foto+reporter !02_S
37160	hamster	hamster	hamster	02_S	SgN	et	hamster =hamster  (SgN  >hamster !02_S
37166	hommikus	hommiku	hommik	02_S	SgIn	et	hommikus =hommiku  (SgIn  >hommik !02_S
37167	nädalalõpp	lõpp	nädala+lõpp	22_SA	SgN	et	nädalalõpp =lõpp  (SgN  >nädala+lõpp !22_SA
37171	poevargus	vargus	poe+vargus	11~09_S	SgN	et	poevargus =vargus  (SgN  >poe+vargus !11~09_S
37179	jäämasin	masin	jää+masin	02_S	SgN	et	jäämasin =masin  (SgN  >jää+masin !02_S
37180	puhvetilett	lett	puhveti+lett	22_S	SgN	et	puhvetilett =lett  (SgN  >puhveti+lett !22_S
37181	jalaga	jala	jalg	22_S	SgKom	et	jalaga =jala  (SgKom  >jalg !22_S
37183	õhkutõusmine	tõusmine	õhku+tõusmine	12?10_S	SgN	et	õhkutõusmine =tõusmine  (SgN  >õhku+tõusmine !12?10_S
37197	jäeti	jäe	jätma	35_V	IndIpfIps	et	jäeti =jäe  (IndIpfIps  >jätma !35_V
37200	meetrid	meetri	meeter	02_S	PlN	et	meetrid =meetri  (PlN  >meeter !02_S
37205	konkursiettepanekud	paneku	konkursi+ette+panek	02_S	PlN	et	konkursiettepanekud =paneku  (PlN  >konkursi+ette+panek !02_S
37206	merre	merre	meri	20_S	SgAdt	et	merre =merre  (SgAdt  >meri !20_S
37216	arhitektide	arhitekti	arhitekt	22_S	PlG	et	arhitektide =arhitekti  (PlG  >arhitekt !22_S
37229	sümboliseerib	sümboliseeri	sümboliseerima	28_V	IndPrSg3	et	sümboliseerib =sümboliseeri  (IndPrSg3  >sümboliseerima !28_V
37232	sangaril	sangari	sangar	02_S	SgAd	et	sangaril =sangari  (SgAd  >sangar !02_S
37242	töödest	töö	töö	26_S	PlEl	et	töödest =töö  (PlEl  >töö !26_S
37244	liidud	liidu	liit	22_S	PlN	et	liidud =liidu  (PlN  >liit !22_S
37248	nõukogudeaegne	aegne	nõu+kogude+aegne	02_A	SgN	et	nõukogudeaegne =aegne  (SgN  >nõu+kogude+aegne !02_A
37249	mälestusmärk	märk	mälestus+märk	22_S	SgN	et	mälestusmärk =märk  (SgN  >mälestus+märk !22_S
37262	galeriis	galerii	galerii	26_S	SgIn	et	galeriis =galerii  (SgIn  >galerii !26_S
37270	mõjuvõimas	võimas	mõju+võimas	03~05_A	SgN	et	mõjuvõimas =võimas  (SgN  >mõju+võimas !03~05_A
37272	ainsana	ainsa	ainus	03~05_AS	SgEs	et	ainsana =ainsa  (SgEs  >ainus !03~05_AS
37273	parteina	partei	partei	26_S	SgEs	et	parteina =partei  (SgEs  >partei !26_S
37274	keskerakond	erakond	kesk+erakond	22_S	SgN	et	keskerakond =erakond  (SgN  >kesk+erakond !22_S
37276	kujuhanke	hanke	kuju+hange	06_S	SgG	et	kujuhanke =hanke  (SgG  >kuju+hange !06_S
37279	pildus	pildu	pilduma	28_V	IndIpfSg3	et	pildus =pildu  (IndIpfSg3  >pilduma !28_V
37281	kalevipoeg-konkursi	konkursi	kalevipoeg-konkurss	22_S	SgG	et	kalevipoeg-konkursi =konkursi  (SgG  >kalevipoeg-konkurss !22_S
37300	tassib	tassi	tassima	28_V	IndPrSg3	et	tassib =tassi  (IndPrSg3  >tassima !28_V
37301	kojunaasmist	naasmis	koju+naasmine	12?10_S	SgP	et	kojunaasmist =naasmis  (SgP  >koju+naasmine !12?10_S
37303	ainuvõimul	võimu	ainu+võim	22_S	SgAd	et	ainuvõimul =võimu  (SgAd  >ainu+võim !22_S
37304	skulptuurtehingu	tehingu	skulptuur+tehing	02_S	SgG	et	skulptuurtehingu =tehingu  (SgG  >skulptuur+tehing !02_S
37310	ületas	ületa	ületama	27_V	IndIpfSg3	et	ületas =ületa  (IndIpfSg3  >ületama !27_V
37320	helsingi-fotodest	foto	helsingi-foto	16_S	PlEl	et	helsingi-fotodest =foto  (PlEl  >helsingi-foto !16_S
37322	kavatseti	kavatse	kavatsema	27_V	IndIpfIps	et	kavatseti =kavatse  (IndIpfIps  >kavatsema !27_V
37323	puumajad	maja	puu+maja	17_S	PlN	et	puumajad =maja  (PlN  >puu+maja !17_S
37329	köögivili	vili	köögi+vili	24_S	SgN	et	köögivili =vili  (SgN  >köögi+vili !24_S
37331	pildile	pildi	pilt	22_S	SgAll	et	pildile =pildi  (SgAll  >pilt !22_S
37333	järeldades	järelda	järeldama	27_V	Ger	et	järeldades =järelda  (Ger  >järeldama !27_V
37334	äratas	ärata	äratama	27_V	IndIpfSg3	et	äratas =ärata  (IndIpfSg3  >äratama !27_V
37336	haruldane	haruldane	haruldane	12_A	SgN	et	haruldane =haruldane  (SgN  >haruldane !12_A
37338	trammirööbaste	rööbas	trammi+rööbas	07_S	PlG	et	trammirööbaste =rööbas  (PlG  >trammi+rööbas !07_S
37339	rakmeid	rakme	rake	05_S	PlP	et	rakmeid =rakme  (PlP  >rake !05_S
37341	töölösse	lösse	töö+löss	22_S	PlP	et	töölösse =lösse  (PlP  >töö+löss !22_S
37349	üleviimine	viimine	üle+viimine	12?10_S	SgN	et	üleviimine =viimine  (SgN  >üle+viimine !12?10_S
37351	legendaarne	legendaarne	legendaarne	02_A	SgN	et	legendaarne =legendaarne  (SgN  >legendaarne !02_A
37359	ametnikke	ametnikke	ametnik	25_S	PlP	et	ametnikke =ametnikke  (PlP  >ametnik !25_S
37361	maastiku-arhitekt	arhitekt	maastiku-arhitekt	22_S	SgN	et	maastiku-arhitekt =arhitekt  (SgN  >maastiku-arhitekt !22_S
37374	hiigelsuure	suure	hiigel+suur	13_A	SgG	et	hiigelsuure =suure  (SgG  >hiigel+suur !13_A
37377	kaldatrepp	trepp	kalda+trepp	22_S	SgN	et	kaldatrepp =trepp  (SgN  >kalda+trepp !22_S
37380	ülekaal	kaal	üle+kaal	22_S	SgN	et	ülekaal =kaal  (SgN  >üle+kaal !22_S
37387	varjama	varja	varjama	29_V	Sup	et	varjama =varja  (Sup  >varjama !29_V
37234	kojutulekut	tuleku	koju+tulek	02_S	SgP	et	kojutulekut =tuleku  (SgP  >koju+tulek !02_S
37236	vaidleb	vaidle	vaidlema	30_V	IndPrSg3	et	vaidleb =vaidle  (IndPrSg3  >vaidlema !30_V
37256	skulptor	skulptor	skulptor	02_S	SgN	et	skulptor =skulptor  (SgN  >skulptor !02_S
37257	plaanide	plaani	plaan	22_S	PlG	et	plaanide =plaani  (PlG  >plaan !22_S
37264	reisilt	reisi	reis	22_S	SgAbl	et	reisilt =reisi  (SgAbl  >reis !22_S
37265	inimkujud	kuju	inim+kuju	17_S	PlN	et	inimkujud =kuju  (PlN  >inim+kuju !17_S
37284	loomeühendused	ühenduse	loome+ühendus	11_S	PlN	et	loomeühendused =ühenduse  (PlN  >loome+ühendus !11_S
37287	memoriaalkompleks	kompleks	memoriaal+kompleks	22_S	SgN	et	memoriaalkompleks =kompleks  (SgN  >memoriaal+kompleks !22_S
37292	maismaaarhitekt	arhitekt	mais+maa+arhitekt	22_S	SgN	et	maismaaarhitekt =arhitekt  (SgN  >mais+maa+arhitekt !22_S
37295	kavandis	kavandi	kavand	02_S	SgIn	et	kavandis =kavandi  (SgIn  >kavand !02_S
37296	asukoht	koht	asu+koht	22_S	SgN	et	asukoht =koht  (SgN  >asu+koht !22_S
37297	sanatooriumisse	sanatooriumi	sanatoorium	19~02_S	SgIll	et	sanatooriumisse =sanatooriumi  (SgIll  >sanatoorium !19~02_S
37298	ateljees	ateljee	ateljee	26_S	SgIn	et	ateljees =ateljee  (SgIn  >ateljee !26_S
37302	skulptuurtehingut	tehingu	skulptuur+tehing	02_S	SgP	et	skulptuurtehingut =tehingu  (SgP  >skulptuur+tehing !02_S
37311	kasv	kasv	kasv	22_S	SgN	et	kasv =kasv  (SgN  >kasv !22_S
37312	puumajade	maja	puu+maja	17_S	PlG	et	puumajade =maja  (PlG  >puu+maja !17_S
37316	linnamuuseum	muuseum	linna+muuseum	19~02_S	SgN	et	linnamuuseum =muuseum  (SgN  >linna+muuseum !19~02_S
37317	fotodest	foto	foto	16_S	PlEl	et	fotodest =foto  (PlEl  >foto !16_S
37318	põhinedes	põhine	põhinema	27_V	Ger	et	põhinedes =põhine  (Ger  >põhinema !27_V
37325	arhitektuuripildistamisega	pildistamise	arhitektuuri+pildistamine	12_S	SgKom	et	arhitektuuripildistamisega =pildistamise  (SgKom  >arhitektuuri+pildistamine !12_S
37326	üksikasjad	asja	üksik+asi	24_S	PlN	et	üksikasjad =asja  (PlN  >üksik+asi !24_S
37347	nõrgenema	nõrgene	nõrgenema	27_V	Sup	et	nõrgenema =nõrgene  (Sup  >nõrgenema !27_V
37348	viitikse	ikse	viit+iks	22_S	PlP	et	viitikse =ikse  (PlP  >viit+iks !22_S
37353	kunstnikude	kunstniku	kunstnik	25_S	PlG	et	kunstnikude =kunstniku  (PlG  >kunstnik !25_S
37355	esmaspäevani	päeva	esmas+päev	22_S	SgTer	et	esmaspäevani =päeva  (SgTer  >esmas+päev !22_S
37357	asu-paik	paik	asu-paik	22_S	SgN	et	asu-paik =paik  (SgN  >asu-paik !22_S
37358	aegase	ase	aeg+ase	04_S	SgN	et	aegase =ase  (SgN  >aeg+ase !04_S
37370	peodega	peo	peo	26_S	PlKom	et	peodega =peo  (PlKom  >peo !26_S
37375	laekus	laeku	laekuma	27_V	IndIpfSg3	et	laekus =laeku  (IndIpfSg3  >laekuma !27_V
37378	ametiühingud	ühingu	ameti+ühing	02_S	PlN	et	ametiühingud =ühingu  (PlN  >ameti+ühing !02_S
37382	ratas	ratas	ratas	07_S	SgN	et	ratas =ratas  (SgN  >ratas !07_S
37389	äranägemise	nägemise	ära+nägemine	12_S	SgG	et	äranägemise =nägemise  (SgG  >ära+nägemine !12_S
37406	tuumaks	tuuma	tuum	22_S	SgTr	et	tuumaks =tuuma  (SgTr  >tuum !22_S
37411	õhinaga	õhina	õhin	02_S	SgKom	et	õhinaga =õhina  (SgKom  >õhin !02_S
37418	detailid	detaili	detail	22_S	PlN	et	detailid =detaili  (PlN  >detail !22_S
37419	politseinike	politseinike	politseinik	25_S	PlG	et	politseinike =politseinike  (PlG  >politseinik !25_S
37425	taguses	taguse	tagune	10_AS	SgIn	et	taguses =taguse  (SgIn  >tagune !10_AS
37426	nurga	nurga	nurk	22_S	SgG	et	nurga =nurga  (SgG  >nurk !22_S
37433	hullumajja	majja	hullu+maja	17_S	SgAdt	et	hullumajja =majja  (SgAdt  >hullu+maja !17_S
37435	sõjatingimustes	tingimus	sõja+tingimus	11_S	PlIn	et	sõjatingimustes =tingimus  (PlIn  >sõja+tingimus !11_S
37445	juhatas	juhata	juhatama	27_V	IndIpfSg3	et	juhatas =juhata  (IndIpfSg3  >juhatama !27_V
37450	ateljeetööst	töö	ateljee+töö	26_S	SgEl	et	ateljeetööst =töö  (SgEl  >ateljee+töö !26_S
37462	linnaekskursioonil	ekskursiooni	linna+ekskursioon	22_S	SgAd	et	linnaekskursioonil =ekskursiooni  (SgAd  >linna+ekskursioon !22_S
37464	lihtsast	lihtsa	lihtne	02_A	SgEl	et	lihtsast =lihtsa  (SgEl  >lihtne !02_A
37469	talletama	talleta	talletama	27_V	Sup	et	talletama =talleta  (Sup  >talletama !27_V
37478	matkal	matka	matk	22_S	SgAd	et	matkal =matka  (SgAd  >matk !22_S
37479	retk	retk	retk	22_S	SgN	et	retk =retk  (SgN  >retk !22_S
37481	riid	riid	riid	22_S	SgN	et	riid =riid  (SgN  >riid !22_S
37496	jutu	jutu	jutt	22_S	SgG	et	jutu =jutu  (SgG  >jutt !22_S
37499	kangelasisiku	isiku	kangelas+isik	02_S	SgG	et	kangelasisiku =isiku  (SgG  >kangelas+isik !02_S
37518	hindel	hinde	hinne	06_S	SgAd	et	hindel =hinde  (SgAd  >hinne !06_S
37522	fotoärides	äri	foto+äri	17_S	PlIn	et	fotoärides =äri  (PlIn  >foto+äri !17_S
37534	kalevipoja-kujule	kuju	kalevipoja-kuju	17_S	SgAll	et	kalevipoja-kujule =kuju  (SgAll  >kalevipoja-kuju !17_S
37546	kujuüritust	üritus	kuju+üritus	11_S	SgP	et	kujuüritust =üritus  (SgP  >kuju+üritus !11_S
37258	ettepanekul	paneku	ette+panek	02_S	SgAd	et	ettepanekul =paneku  (SgAd  >ette+panek !02_S
37259	lisati	lisa	lisama	27_V	IndIpfIps	et	lisati =lisa  (IndIpfIps  >lisama !27_V
37266	kojujõudmist	jõudmis	koju+jõudmine	12?10_S	SgP	et	kojujõudmist =jõudmis  (SgP  >koju+jõudmine !12?10_S
37267	liidule	liidu	liit	22_S	SgAll	et	liidule =liidu  (SgAll  >liit !22_S
37277	kriitikat	kriitika	kriitika	01_S	SgP	et	kriitikat =kriitika  (SgP  >kriitika !01_S
37286	kalda	kalda	kallas	07_S	SgG	et	kalda =kalda  (SgG  >kallas !07_S
37288	rannatrepp	trepp	ranna+trepp	22_S	SgN	et	rannatrepp =trepp  (SgN  >ranna+trepp !22_S
37289	eriarvamused	arvamuse	eri+arvamus	11_S	PlN	et	eriarvamused =arvamuse  (PlN  >eri+arvamus !11_S
37291	komisjonist	komisjoni	komisjon	19_S	SgEl	et	komisjonist =komisjoni  (SgEl  >komisjon !19_S
37294	algses	algse	algne	02_A	SgIn	et	algses =algse  (SgIn  >algne !02_A
37306	vaenlast	vaenlas	vaenlane	12?10_S	SgP	et	vaenlast =vaenlas  (SgP  >vaenlane !12?10_S
37307	süüdlane	süüdlane	süüdlane	12?10_S	SgN	et	süüdlane =süüdlane  (SgN  >süüdlane !12?10_S
37313	palkas	palka	palkama	29_V	IndIpfSg3	et	palkas =palka  (IndIpfSg3  >palkama !29_V
37314	kaugeleulatuvaks	ulatuva	kaugele+ulatuv	02_A	SgTr	et	kaugeleulatuvaks =ulatuva  (SgTr  >kaugele+ulatuv !02_A
37332	tujust	tuju	tuju	17_S	SgEl	et	tujust =tuju  (SgEl  >tuju !17_S
37345	linnaümbruse	ümbruse	linna+ümbrus	11~09_S	SgG	et	linnaümbruse =ümbruse  (SgG  >linna+ümbrus !11~09_S
37346	mõisaid	mõisa	mõis	02_S	PlP	et	mõisaid =mõisa  (PlP  >mõis !02_S
37352	patsientide	patsienti	patsient	22_S	PlG	et	patsientide =patsienti  (PlG  >patsient !22_S
37354	lõppeni	lõppe	lõpe	06_S	SgTer	et	lõppeni =lõppe  (SgTer  >lõpe !06_S
37365	äärel	ääre	äär	13_S	SgAd	et	äärel =ääre  (SgAd  >äär !13_S
37366	häireks	häire	häire	06_S	SgTr	et	häireks =häire  (SgTr  >häire !06_S
37367	siluetile	silueti	siluett	22_S	SgAll	et	siluetile =silueti  (SgAll  >siluett !22_S
37368	innuga	innu	ind	22_S	SgKom	et	innuga =innu  (SgKom  >ind !22_S
37369	suurde	suur	suur	13_A	SgAdt	et	suurde =suur  (SgAdt  >suur !13_A
37371	inimfiguurid	figuuri	inim+figuur	22_S	PlN	et	inimfiguurid =figuuri  (PlN  >inim+figuur !22_S
37381	ametnike	ametnike	ametnik	25_S	PlG	et	ametnike =ametnike  (PlG  >ametnik !25_S
37385	kalkulatsioone	kalkulatsioone	kalkulatsioon	22_S	PlP	et	kalkulatsioone =kalkulatsioone  (PlP  >kalkulatsioon !22_S
37392	ainsa	ainsa	ainus	03~05_AS	SgG	et	ainsa =ainsa  (SgG  >ainus !03~05_AS
37408	pühendatakse	pühenda	pühendama	27_V	IndPrIps	et	pühendatakse =pühenda  (IndPrIps  >pühendama !27_V
37424	ekspeditsioon	ekspeditsioon	ekspeditsioon	22_S	SgN	et	ekspeditsioon =ekspeditsioon  (SgN  >ekspeditsioon !22_S
37428	maakoht	koht	maa+koht	22_S	SgN	et	maakoht =koht  (SgN  >maa+koht !22_S
37429	tüliõunaks	õuna	tüli+õun	23?22_S	SgTr	et	tüliõunaks =õuna  (SgTr  >tüli+õun !23?22_S
37441	perspektiivikaks	perspektiivika	perspektiivikas	02_A	SgTr	et	perspektiivikaks =perspektiivika  (SgTr  >perspektiivikas !02_A
37444	linnapiltide	pilti	linna+pilt	22_S	PlG	et	linnapiltide =pilti  (PlG  >linna+pilt !22_S
37447	taanduma	taandu	taanduma	27_V	Sup	et	taanduma =taandu  (Sup  >taanduma !27_V
37449	joonistusõpetajaks	õpetaja	joonistus+õpetaja	01_S	SgTr	et	joonistusõpetajaks =õpetaja  (SgTr  >joonistus+õpetaja !01_S
37454	paigalseisva	seisva	paigal+seisev	02_A	SgG	et	paigalseisva =seisva  (SgG  >paigal+seisev !02_A
37459	esitleda	esitle	esitlema	27_V	Inf	et	esitleda =esitle  (Inf  >esitlema !27_V
37471	teadur	teadur	teadur	02_S	SgN	et	teadur =teadur  (SgN  >teadur !02_S
37473	mühinaga	mühina	mühin	02_S	SgKom	et	mühinaga =mühina  (SgKom  >mühin !02_S
37489	torkaks	torka	torkama	29_V	KndPrPs	et	torkaks =torka  (KndPrPs  >torkama !29_V
37491	suurtes	suur	suur	13_A	PlIn	et	suurtes =suur  (PlIn  >suur !13_A
37493	nägemusena	nägemuse	nägemus	11_S	SgEs	et	nägemusena =nägemuse  (SgEs  >nägemus !11_S
37494	inimfiguuriga	figuuri	inim+figuur	22_S	SgKom	et	inimfiguuriga =figuuri  (SgKom  >inim+figuur !22_S
37500	võitlusele	võitluse	võitlus	11~09_S	SgAll	et	võitlusele =võitluse  (SgAll  >võitlus !11~09_S
37511	kakleb	kakle	kaklema	30_V	IndPrSg3	et	kakleb =kakle  (IndPrSg3  >kaklema !30_V
37517	linnaplaneerimist	planeerimis	linna+planeerimine	12_S	SgP	et	linnaplaneerimist =planeerimis  (SgP  >linna+planeerimine !12_S
37519	oskusliku	oskusliku	oskuslik	25_A	SgG	et	oskusliku =oskusliku  (SgG  >oskuslik !25_A
37520	maastikupildistajana	pildistaja	maas+tiku+pildistaja	01_S	SgEs	et	maastikupildistajana =pildistaja  (SgEs  >maas+tiku+pildistaja !01_S
37525	piltidesse	pilti	pilt	22_S	PlIll	et	piltidesse =pilti  (PlIll  >pilt !22_S
37529	kaasaegsele	aegse	kaas+aegne	02_A	SgAll	et	kaasaegsele =aegse  (SgAll  >kaas+aegne !02_A
37539	1990aastate	aasta	aasta	01_S	PlG	et	aastate =aasta  (PlG  >aasta !01_S
37541	selgitasime	selgita	selgitama	27_V	IndIpfPl1	et	selgitasime =selgita  (IndIpfPl1  >selgitama !27_V
37268	boikoteerib	boikoteeri	boikoteerima	28_V	IndPrSg3	et	boikoteerib =boikoteeri  (IndPrSg3  >boikoteerima !28_V
37271	muuhulgas	hulga	muu+hulk	22_S	SgIn	et	muuhulgas =hulga  (SgIn  >muu+hulk !22_S
37275	ehitistele	ehitis	ehitis	11_S	PlAll	et	ehitistele =ehitis  (PlAll  >ehitis !11_S
37282	avalikustatakse	avalikusta	avalikustama	27_V	IndPrIps	et	avalikustatakse =avalikusta  (IndPrIps  >avalikustama !27_V
37283	püstitatama	püstita	püstitama	27_V	SupIps	et	püstitatama =püstita  (SupIps  >püstitama !27_V
37290	ideekonkursi	konkursi	idee+konkurss	22_S	SgG	et	ideekonkursi =konkursi  (SgG  >idee+konkurss !22_S
37293	merineitsiga	neitsi	meri+neitsi	01_S	SgKom	et	merineitsiga =neitsi  (SgKom  >meri+neitsi !01_S
37305	loopis	loopi	loopima	28_V	IndIpfSg3	et	loopis =loopi  (IndIpfSg3  >loopima !28_V
37321	asjatundjad	tundja	asja+tundja	01_S	PlN	et	asjatundjad =tundja  (PlN  >asja+tundja !01_S
37327	piltide	pilti	pilt	22_S	PlG	et	piltide =pilti  (PlG  >pilt !22_S
37328	piltidel	pilti	pilt	22_S	PlAd	et	piltidel =pilti  (PlAd  >pilt !22_S
37335	helsinglaste	helsinglas	helsinglane	12_S	PlG	et	helsinglaste =helsinglas  (PlG  >helsinglane !12_S
37337	detail	detail	detail	22_S	SgN	et	detail =detail  (SgN  >detail !22_S
37340	linnaosadesse	osa	linna+osa	17_S	PlIll	et	linnaosadesse =osa  (PlIll  >linna+osa !17_S
37342	vaatevinkel	vinkel	vaate+vinkel	02_S	SgN	et	vaatevinkel =vinkel  (SgN  >vaate+vinkel !02_S
37350	segases	segase	segane	10_A	SgIn	et	segases =segase  (SgIn  >segane !10_A
37360	komisjonis	komisjoni	komisjon	19_S	SgIn	et	komisjonis =komisjoni  (SgIn  >komisjon !19_S
37362	kujur	kujur	kujur	02_S	SgN	et	kujur =kujur  (SgN  >kujur !02_S
37363	teime	teime	teim	22_S	PlP	et	teime =teime  (PlP  >teim !22_S
37379	protestina	protesti	protest	22_S	SgEs	et	protestina =protesti  (SgEs  >protest !22_S
37383	kõrvutada	kõrvuta	kõrvutama	27_V	Inf	et	kõrvutada =kõrvuta  (Inf  >kõrvutama !27_V
37386	turistidele	turisti	turist	22_S	PlAll	et	turistidele =turisti  (PlAll  >turist !22_S
37390	kojutuleku	tuleku	koju+tulek	02_S	SgG	et	kojutuleku =tuleku  (SgG  >koju+tulek !02_S
37391	ühingule	ühingu	ühing	02_S	SgAll	et	ühingule =ühingu  (SgAll  >ühing !02_S
37396	legendaarse	legendaarse	legendaarne	02_A	SgG	et	legendaarse =legendaarse  (SgG  >legendaarne !02_A
37398	rahvaarv	arv	rahva+arv	22_S	SgN	et	rahvaarv =arv  (SgN  >rahva+arv !22_S
37400	arhitekte	arhitekte	arhitekt	22_S	PlP	et	arhitekte =arhitekte  (PlP  >arhitekt !22_S
37402	eesmargi	margi	ees+mark	22_S	SgG	et	eesmargi =margi  (SgG  >ees+mark !22_S
37405	kaugenägelikuna	nägeliku	kauge+nägelik	25_A	SgEs	et	kaugenägelikuna =nägeliku  (SgEs  >kauge+nägelik !25_A
37407	pildiga	pildi	pilt	22_S	SgKom	et	pildiga =pildi  (SgKom  >pilt !22_S
37414	fotostuudiotes	stuudio	foto+stuudio	01_S	PlIn	et	fotostuudiotes =stuudio  (PlIn  >foto+stuudio !01_S
37417	saladuseks	saladuse	saladus	11_S	SgTr	et	saladuseks =saladuse  (SgTr  >saladus !11_S
37430	süstemaatiline	süstemaatiline	süstemaatiline	12_A	SgN	et	süstemaatiline =süstemaatiline  (SgN  >süstemaatiline !12_A
37434	vaimsest	vaimse	vaimne	02_A	SgEl	et	vaimsest =vaimse  (SgEl  >vaimne !02_A
37436	patsiendi	patsiendi	patsient	22_S	SgG	et	patsiendi =patsiendi  (SgG  >patsient !22_S
37439	arhitektid	arhitekti	arhitekt	22_S	PlN	et	arhitektid =arhitekti  (PlN  >arhitekt !22_S
37446	mühinal	mühina	mühin	02_S	SgAd	et	mühinal =mühina  (SgAd  >mühin !02_S
37448	teelt	tee	tee	26_S	SgAbl	et	teelt =tee  (SgAbl  >tee !26_S
37455	igasugu	igasugu	iga+sugu	41_A	ID	et	igasugu =igasugu  (ID  >iga+sugu !41_A
37465	taasalgas	alga	taas+algama	29_V	IndIpfSg3	et	taasalgas =alga  (IndIpfSg3  >taas+algama !29_V
37467	sõjaoludes	olu	sõja+olu	17_S	PlIn	et	sõjaoludes =olu  (PlIn  >sõja+olu !17_S
37468	tagust	tagus	tagune	10_AS	SgP	et	tagust =tagus  (SgP  >tagune !10_AS
37476	möödakäijaid	käija	mööda+käija	01_S	PlP	et	möödakäijaid =käija  (PlP  >mööda+käija !01_S
37480	linnaossa	ossa	linna+osa	17_S	SgAdt	et	linnaossa =ossa  (SgAdt  >linna+osa !17_S
37486	maailmasõjas	sõja	maa+ilma+sõda	18_S	SgIn	et	maailmasõjas =sõja  (SgIn  >maa+ilma+sõda !18_S
37488	lõpptulemusena	tulemuse	lõpp+tulemus	11_S	SgEs	et	lõpptulemusena =tulemuse  (SgEs  >lõpp+tulemus !11_S
37495	konkursitööde	töö	konkursi+töö	26_S	PlG	et	konkursitööde =töö  (PlG  >konkursi+töö !26_S
37497	kunstiühingud	ühingu	kunsti+ühing	02_S	PlN	et	kunstiühingud =ühingu  (PlN  >kunsti+ühing !02_S
37501	võistlusettepanekut	paneku	võistlus+ette+panek	02_S	SgP	et	võistlusettepanekut =paneku  (SgP  >võistlus+ette+panek !02_S
37503	paistavad	paista	paistma	34_V	IndPrPl3	et	paistavad =paista  (IndPrPl3  >paistma !34_V
37506	ettepaneku	paneku	ette+panek	02_S	SgG	et	ettepaneku =paneku  (SgG  >ette+panek !02_S
37509	inimisikud	isiku	inim+isik	02_S	PlN	et	inimisikud =isiku  (PlN  >inim+isik !02_S
37278	muistendi	muistendi	muistend	02_S	SgG	et	muistendi =muistendi  (SgG  >muistend !02_S
37280	vaenlasi	vaenlasi	vaenlane	12_S	PlP	et	vaenlasi =vaenlasi  (PlP  >vaenlane !12_S
37285	hiiglaslikule	hiiglasliku	hiiglaslik	25_A	SgAll	et	hiiglaslikule =hiiglasliku  (SgAll  >hiiglaslik !25_A
37299	õhkkond	õhkkond	õhkkond	22_S	SgN	et	õhkkond =õhkkond  (SgN  >õhkkond !22_S
37308	võitlustöödest	töö	võitlus+töö	26_S	PlEl	et	võitlustöödest =töö  (PlEl  >võitlus+töö !26_S
37309	legendaarsest	legendaarse	legendaarne	02_A	SgEl	et	legendaarsest =legendaarse  (SgEl  >legendaarne !02_A
37315	pildistas	pildista	pildistama	27_V	IndIpfSg3	et	pildistas =pildista  (IndIpfSg3  >pildistama !27_V
37319	fotodel	foto	foto	16_S	PlAd	et	fotodel =foto  (PlAd  >foto !16_S
37324	selleaegse	aegse	selle+aegne	02_A	SgG	et	selleaegse =aegse  (SgG  >selle+aegne !02_A
37330	helsinglastele	helsinglas	helsinglane	12_S	PlAll	et	helsinglastele =helsinglas  (PlAll  >helsinglane !12_S
37343	nüüdislugejale	lugeja	nüüdis+lugeja	01_S	SgAll	et	nüüdislugejale =lugeja  (SgAll  >nüüdis+lugeja !01_S
37344	aastakümneiks	iks	aasta+kümne+iks	22_S	SgN	et	aastakümneiks =iks  (SgN  >aasta+kümne+iks !22_S
37356	konkursikavandit	kavandi	konkursi+kavand	02_S	SgP	et	konkursikavandit =kavandi  (SgP  >konkursi+kavand !02_S
37364	meetrile	meetri	meeter	02_S	SgAll	et	meetrile =meetri  (SgAll  >meeter !02_S
37372	ideekonkursile	konkursi	idee+konkurss	22_S	SgAll	et	ideekonkursile =konkursi  (SgAll  >idee+konkurss !22_S
37373	järgmiste	järgmis	järgmine	12?10_A	PlG	et	järgmiste =järgmis  (PlG  >järgmine !12?10_A
37376	võistlusele	võistluse	võistlus	11~09_S	SgAll	et	võistlusele =võistluse  (SgAll  >võistlus !11~09_S
37384	originaalplaanis	plaani	originaal+plaan	22_S	SgIn	et	originaalplaanis =plaani  (SgIn  >originaal+plaan !22_S
37395	võistlustöödest	töö	võistlus+töö	26_S	PlEl	et	võistlustöödest =töö  (PlEl  >võistlus+töö !26_S
37397	taguse	taguse	tagune	10_AS	SgG	et	taguse =taguse  (SgG  >tagune !10_AS
37399	elaniku	elaniku	elanik	25_S	SgG	et	elaniku =elaniku  (SgG  >elanik !25_S
37404	targa	targa	tark	22_AS	SgG	et	targa =targa  (SgG  >tark !22_AS
37410	komisjon	komisjon	komisjon	19_S	SgN	et	komisjon =komisjon  (SgN  >komisjon !19_S
37412	enesestmõistetav	mõistetav	enesest+mõistetav	02_A	SgN	et	enesestmõistetav =mõistetav  (SgN  >enesest+mõistetav !02_A
37413	osava	osava	osav	02_A	SgG	et	osava =osava  (SgG  >osav !02_A
37416	tehnikaga	tehnika	tehnika	01_S	SgKom	et	tehnikaga =tehnika  (SgKom  >tehnika !01_S
37420	peatuda	peatu	peatuma	27_V	Inf	et	peatuda =peatu  (Inf  >peatuma !27_V
37423	rakmeteta	rakme	rake	05_S	PlAb	et	rakmeteta =rakme  (PlAb  >rake !05_S
37431	linnakeskkonna	keskkonna	linna+keskkond	22_S	SgG	et	linnakeskkonna =keskkonna  (SgG  >linna+keskkond !22_S
37432	silmanägemine	nägemine	silma+nägemine	12_S	SgN	et	silmanägemine =nägemine  (SgN  >silma+nägemine !12_S
37438	linnaekskursioonile	ekskursiooni	linna+ekskursioon	22_S	SgAll	et	linnaekskursioonile =ekskursiooni  (SgAll  >linna+ekskursioon !22_S
37440	jäädvustama	jäädvusta	jäädvustama	27_V	Sup	et	jäädvustama =jäädvusta  (Sup  >jäädvustama !27_V
37443	piltidest	pilti	pilt	22_S	PlEl	et	piltidest =pilti  (PlEl  >pilt !22_S
37451	fotofirmades	firma	foto+firma	16_S	PlIn	et	fotofirmades =firma  (PlIn  >foto+firma !16_S
37452	tolleaegse	aegse	tolle+aegne	02_A	SgG	et	tolleaegse =aegse  (SgG  >tolle+aegne !02_A
37453	maastikupilte	pilte	maas+tiku+pilt	22_S	PlP	et	maastikupilte =pilte  (PlP  >maas+tiku+pilt !22_S
37456	pisidetailid	detaili	pisi+detail	22_S	PlN	et	pisidetailid =detaili  (PlN  >pisi+detail !22_S
37457	fotode	foto	foto	16_S	PlG	et	fotode =foto  (PlG  >foto !16_S
37460	pikantne	pikantne	pikantne	02_A	SgN	et	pikantne =pikantne  (SgN  >pikantne !02_A
37461	trammirööbastel	rööbas	trammi+rööbas	07_S	PlAd	et	trammirööbastel =rööbas  (PlAd  >trammi+rööbas !07_S
37470	ettenägevaks	nägeva	ette+nägev	02_A	SgTr	et	ettenägevaks =nägeva  (SgTr  >ette+nägev !02_A
37474	fotoateljeedes	ateljee	foto+ateljee	26_S	PlIn	et	fotoateljeedes =ateljee  (PlIn  >foto+ateljee !26_S
37475	välitöödele	töö	väli+töö	26_S	PlAll	et	välitöödele =töö  (PlAll  >väli+töö !26_S
37482	halvenema	halvene	halvenema	27_V	Sup	et	halvenema =halvene  (Sup  >halvenema !27_V
37483	ümberpaigutamine	paigutamine	ümber+paigutamine	12_S	SgN	et	ümberpaigutamine =paigutamine  (SgN  >ümber+paigutamine !12_S
37484	segastes	segas	segane	10_A	PlIn	et	segastes =segas  (PlIn  >segane !10_A
37485	hiiglasliku	hiiglasliku	hiiglaslik	25_A	SgG	et	hiiglasliku =hiiglasliku  (SgG  >hiiglaslik !25_A
37504	kunstnikuliikmeks	liikme	kunstniku+liige	05_S	SgTr	et	kunstnikuliikmeks =liikme  (SgTr  >kunstniku+liige !05_S
37510	ühingut	ühingu	ühing	02_S	SgP	et	ühingut =ühingu  (SgP  >ühing !02_S
37524	tollase	tollase	tollane	10_A	SgG	et	tollase =tollase  (SgG  >tollane !10_A
37532	ümberpaigutamise	paigutamise	ümber+paigutamine	12_S	SgG	et	ümberpaigutamise =paigutamise  (SgG  >ümber+paigutamine !12_S
37388	kandmas	kand	kandma	34_V	SupIn	et	kandmas =kand  (SupIn  >kandma !34_V
37393	kõrgeid	kõrge	kõrge	01_A	PlP	et	kõrgeid =kõrge  (PlP  >kõrge !01_A
37394	ehitisi	ehitisi	ehitis	11_S	PlP	et	ehitisi =ehitisi  (PlP  >ehitis !11_S
37401	dokumenteerima	dokumenteeri	dokumenteerima	28_V	Sup	et	dokumenteerima =dokumenteeri  (Sup  >dokumenteerima !28_V
37403	asutada	asuta	asutama	27_V	Inf	et	asutada =asuta  (Inf  >asutama !27_V
37409	pildiraamat	raamat	pildi+raamat	02_S	SgN	et	pildiraamat =raamat  (SgN  >pildi+raamat !02_S
37415	kohmaka	kohmaka	kohmakas	02_A	SgG	et	kohmaka =kohmaka  (SgG  >kohmakas !02_A
37421	nägudest	nägu	nägu	18_S	PlEl	et	nägudest =nägu  (PlEl  >nägu !18_S
37422	pikantseks	pikantse	pikantne	02_A	SgTr	et	pikantseks =pikantse  (SgTr  >pikantne !02_A
37427	vaadet	vaade	vaade	06_S	SgP	et	vaadet =vaade  (SgP  >vaade !06_S
37437	patsientidega	patsienti	patsient	22_S	PlKom	et	patsientidega =patsienti  (PlKom  >patsient !22_S
37442	tuumik	tuumik	tuumik	02_S	SgN	et	tuumik =tuumik  (SgN  >tuumik !02_S
37458	pildistada	pildista	pildistama	27_V	Inf	et	pildistada =pildista  (Inf  >pildistama !27_V
37463	linnajagudesse	jagu	linna+jagu	18_S	PlIll	et	linnajagudesse =jagu  (PlIll  >linna+jagu !18_S
37466	tagajärjel	järje	taga+järg	22_S	SgAd	et	tagajärjel =järje  (SgAd  >taga+järg !22_S
37472	linnaplaneerimise	planeerimise	linna+planeerimine	12_S	SgG	et	linnaplaneerimise =planeerimise  (SgG  >linna+planeerimine !12_S
37477	trammirööpaid	rööpa	trammi+rööbas	07_S	PlP	et	trammirööpaid =rööpa  (PlP  >trammi+rööbas !07_S
37487	hindasime	hinda	hindama	29_V	IndIpfPl1	et	hindasime =hinda  (IndIpfPl1  >hindama !29_V
37490	sõites	sõit	sõitma	34_V	Ger	et	sõites =sõit  (Ger  >sõitma !34_V
37492	pihkudes	pihku	pihk	22_S	PlIn	et	pihkudes =pihku  (PlIn  >pihk !22_S
37498	kavale	kava	kava	17_S	SgAll	et	kavale =kava  (SgAll  >kava !17_S
37502	mälestusmärgikompleks	kompleks	mälestus+märgi+kompleks	22_S	SgN	et	mälestusmärgikompleks =kompleks  (SgN  >mälestus+märgi+kompleks !22_S
37505	turustada	turusta	turustama	27_V	Inf	et	turustada =turusta  (Inf  >turustama !27_V
37507	mõtlesime	mõtle	mõtlema	30_V	IndIpfPl1	et	mõtlesime =mõtle  (IndIpfPl1  >mõtlema !30_V
37508	supelranna	ranna	supel+rand	22_S	SgG	et	supelranna =ranna  (SgG  >supel+rand !22_S
37523	väljale	välja	väli	24_S	SgAll	et	väljale =välja  (SgAll  >väli !24_S
37527	raudteerööpaid	rööpa	raud+tee+rööbas	07_S	PlP	et	raudteerööpaid =rööpa  (PlP  >raud+tee+rööbas !07_S
37530	lahkhelide	heli	lahk+heli	17_S	PlG	et	lahkhelide =heli  (PlG  >lahk+heli !17_S
37533	kunstnikuühendused	ühenduse	kunstniku+ühendus	11_S	PlN	et	kunstnikuühendused =ühenduse  (PlN  >kunstniku+ühendus !11_S
37536	aegse	aegse	aegne	02_A	SgG	et	aegse =aegse  (SgG  >aegne !02_A
37537	bürokratismiga	bürokratismi	bürokratism	22_S	SgKom	et	bürokratismiga =bürokratismi  (SgKom  >bürokratism !22_S
37540	mereneitsiga	neitsi	mere+neitsi	01_S	SgKom	et	mereneitsiga =neitsi  (SgKom  >mere+neitsi !01_S
37555	pildistama	pildista	pildistama	27_V	Sup	et	pildistama =pildista  (Sup  >pildistama !27_V
37561	nüanssid	nüanssi	nüanss	22_S	PlN	et	nüanssid =nüanssi  (PlN  >nüanss !22_S
37569	linnaosadeni	osa	linna+osa	17_S	PlTer	et	linnaosadeni =osa  (PlTer  >linna+osa !17_S
37576	üle100	üle	üle	41_DK	ID	et	üle =üle  (ID  >üle !41_DK
37580	19sajangi	saja	sadama	28_V	IndPrSg1^	et	sajangi =saja  (IndPrSg1^  >sadama !28_V
37581	müüride	müüri	müür	22_S	PlG	et	müüride =müüri  (PlG  >müür !22_S
37582	arvestas	arvesta	arvestama	27_V	IndIpfSg3	et	arvestas =arvesta  (IndIpfSg3  >arvestama !27_V
37589	linnaosadele	osa	linna+osa	17_S	PlAll	et	linnaosadele =osa  (PlAll  >linna+osa !17_S
37595	ümberpaigutus	paigutus	ümber+paigutus	11_S	SgN	et	ümberpaigutus =paigutus  (SgN  >ümber+paigutus !11_S
37597	seesugust	sugus	see+sugune	10_P	SgP	et	seesugust =sugus  (SgP  >see+sugune !10_P
37600	ametiliidud	liidu	ameti+liit	22_S	PlN	et	ametiliidud =liidu  (PlN  >ameti+liit !22_S
37604	uurisime	uuri	uurima	28_V	IndIpfPl1	et	uurisime =uuri  (IndIpfPl1  >uurima !28_V
37606	peopesadega	pesa	peo+pesa	17_S	PlKom	et	peopesadega =pesa  (PlKom  >peo+pesa !17_S
37607	kivisid	kivi	kivi	17_S	PlP	et	kivisid =kivi  (PlP  >kivi !17_S
37611	juurte	juur	juur	13_S	PlG	et	juurte =juur  (PlG  >juur !13_S
37612	esialgse	algse	esi+algne	02_A	SgG	et	esialgse =algse  (SgG  >esi+algne !02_A
37613	mälestusmargi	margi	mälestus+mark	22_S	SgG	et	mälestusmargi =margi  (SgG  >mälestus+mark !22_S
37616	sümpaatiat	sümpaatia	sümpaatia	01_S	SgP	et	sümpaatiat =sümpaatia  (SgP  >sümpaatia !01_S
37619	tulemukseks	mukse	tule+muks	22_S	PlTr	et	tulemukseks =mukse  (PlTr  >tule+muks !22_S
37621	pildidest	pildi	pild	22_S	PlEl	et	pildidest =pildi  (PlEl  >pild !22_S
37627	maastikufotografeerimise	fotografeerimise	maas+tiku+fotografeerimine	12_S	SgG	et	maastikufotografeerimise =fotografeerimise  (SgG  >maas+tiku+fotografeerimine !12_S
37512	kalevipoja-konkursi	konkursi	kalevipoja-konkurss	22_S	SgG	et	kalevipoja-konkursi =konkursi  (SgG  >kalevipoja-konkurss !22_S
37513	ringsõidule	sõidu	ring+sõit	22_S	SgAll	et	ringsõidule =sõidu  (SgAll  >ring+sõit !22_S
37514	piltidele	pilti	pilt	22_S	PlAll	et	piltidele =pilti  (PlAll  >pilt !22_S
37515	muinsuskaitsekomisjonis	komisjoni	muinsus+kaitse+komisjon	19_S	SgIn	et	muinsuskaitsekomisjonis =komisjoni  (SgIn  >muinsus+kaitse+komisjon !19_S
37516	asjatundjaid	tundja	asja+tundja	01_S	PlP	et	asjatundjaid =tundja  (PlP  >asja+tundja !01_S
37521	ateljeetöös	töö	ateljee+töö	26_S	SgIn	et	ateljeetöös =töö  (SgIn  >ateljee+töö !26_S
37526	haruldus	haruldus	haruldus	11_S	SgN	et	haruldus =haruldus  (SgN  >haruldus !11_S
37528	ringsõidul	sõidu	ring+sõit	22_S	SgAd	et	ringsõidul =sõidu  (SgAd  >ring+sõit !22_S
37531	pooltel	pool	pool	13_NS	PlAd	et	pooltel =pool  (PlAd  >pool !13_NS
37535	mereni	mere	meri	20_S	SgTer	et	mereni =mere  (SgTer  >meri !20_S
37538	vaidlust	vaidlus	vaidlus	11~09_S	SgP	et	vaidlust =vaidlus  (SgP  >vaidlus !11~09_S
37543	tervisekeskuse	keskuse	tervise+keskus	11~09_S	SgG	et	tervisekeskuse =keskuse  (SgG  >tervise+keskus !11~09_S
37547	kalevipoeg-võistluse	võistluse	kalevipoeg-võistlus	11~09_S	SgG	et	kalevipoeg-võistluse =võistluse  (SgG  >kalevipoeg-võistlus !11~09_S
37556	millistesse	millis	milline	10_P	PlIll	et	millistesse =millis  (PlIll  >milline !10_P
37559	lääne-soomest	mest	lääne-soo+mest	22_S	SgN	et	lääne-soomest =mest  (SgN  >lääne-soo+mest !22_S
37560	fotoäris	äri	foto+äri	17_S	SgIn	et	fotoäris =äri  (SgIn  >foto+äri !17_S
37565	inimestes	inimes	inimene	12_S	PlIn	et	inimestes =inimes  (PlIn  >inimene !12_S
37568	ringkäigust	käigu	ring+käik	22_S	SgEl	et	ringkäigust =käigu  (SgEl  >ring+käik !22_S
37575	tutvustamaks	tutvusta	tutvustama	27_V	SupTr	et	tutvustamaks =tutvusta  (SupTr  >tutvustama !27_V
37579	pöördeid	pöörde	pööre	06_S	PlP	et	pöördeid =pöörde  (PlP  >pööre !06_S
37583	võimet	võime	võime	06_S	SgP	et	võimet =võime  (SgP  >võime !06_S
37588	ringkäigul	käigu	ring+käik	22_S	SgAd	et	ringkäigul =käigu  (SgAd  >ring+käik !22_S
37592	põhjuse	põhjuse	põhjus	11~09_S	SgG	et	põhjuse =põhjuse  (SgG  >põhjus !11~09_S
37593	kahtleb	kahtle	kahtlema	30_V	IndPrSg3	et	kahtleb =kahtle  (IndPrSg3  >kahtlema !30_V
37596	tasakaalust	kaalu	tasa+kaal	22_S	SgEl	et	tasakaalust =kaalu  (SgEl  >tasa+kaal !22_S
37602	parkide	parki	park	22_S	PlG	et	parkide =parki  (PlG  >park !22_S
37610	samanimega	nime	sama+nimi	20_S	SgKom	et	samanimega =nime  (SgKom  >sama+nimi !20_S
37615	boikoteeris	boikoteeri	boikoteerima	28_V	IndIpfSg3	et	boikoteeris =boikoteeri  (IndIpfSg3  >boikoteerima !28_V
37623	fotost	foto	foto	16_S	SgEl	et	fotost =foto  (SgEl  >foto !16_S
37624	sisalduks	sisaldu	sisalduma	27_V	KndPrPs	et	sisalduks =sisaldu  (KndPrPs  >sisalduma !27_V
37630	esindades	esinda	esindama	27_V	Ger	et	esindades =esinda  (Ger  >esindama !27_V
37632	selgitab	selgita	selgitama	27_V	IndPrSg3	et	selgitab =selgita  (IndPrSg3  >selgitama !27_V
37635	vaimsel	vaimse	vaimne	02_A	SgAd	et	vaimsel =vaimse  (SgAd  >vaimne !02_A
37643	puuduks	puudu	puuduma	27_V	KndPrPs	et	puuduks =puudu  (KndPrPs  >puuduma !27_V
37658	kangelasel	kangelase	kangelane	12_S	SgAd	et	kangelasel =kangelase  (SgAd  >kangelane !12_S
37682	siseküsimused	küsimuse	sise+küsimus	11_S	PlN	et	siseküsimused =küsimuse  (PlN  >sise+küsimus !11_S
37686	mõõtmel	mõõtme	mõõde	05_S	SgAd	et	mõõtmel =mõõtme  (SgAd  >mõõde !05_S
37691	keskkonnapartnerluse	partnerluse	kesk+konna+partnerlus	11_S	SgG	et	keskkonnapartnerluse =partnerluse  (SgG  >kesk+konna+partnerlus !11_S
37698	euroni	euro	euro	16_S	SgTer	et	euroni =euro  (SgTer  >euro !16_S
37712	äsja	äsja	äsja	41_D	ID	et	äsja =äsja  (ID  >äsja !41_D
37726	toimingule	toimingu	toiming	02_S	SgAll	et	toimingule =toimingu  (SgAll  >toiming !02_S
37736	sotsiaalprobleemidest	probleemi	sotsiaal+probleem	22_S	PlEl	et	sotsiaalprobleemidest =probleemi  (PlEl  >sotsiaal+probleem !22_S
37740	vöiks	vö	vöö	26_S	PlTr	et	vöiks =vö  (PlTr  >vöö !26_S
37752	ülatasandil	tasandi	üla+tasand	02_S	SgAd	et	ülatasandil =tasandi  (SgAd  >üla+tasand !02_S
37758	partnerlusprojektidena	projekti	partnerlus+projekt	22_S	PlEs	et	partnerlusprojektidena =projekti  (PlEs  >partnerlus+projekt !22_S
37760	sotsiaalse	sotsiaalse	sotsiaalne	02_A	SgG	et	sotsiaalse =sotsiaalse  (SgG  >sotsiaalne !02_A
37761	kogumaksumus	maksumus	kogu+maksumus	11_S	SgN	et	kogumaksumus =maksumus  (SgN  >kogu+maksumus !11_S
37772	millepärast	millepärast	mille+pärast	41_D	ID	et	millepärast =millepärast  (ID  >mille+pärast !41_D
37784	idabloki	bloki	ida+blokk	22_S	SgG	et	idabloki =bloki  (SgG  >ida+blokk !22_S
37786	memuaarkirjandust	kirjandus	memuaar+kirjandus	11_S	SgP	et	memuaarkirjandust =kirjandus  (SgP  >memuaar+kirjandus !11_S
37792	suhtus	suhtu	suhtuma	27_V	IndIpfSg3	et	suhtus =suhtu  (IndIpfSg3  >suhtuma !27_V
37542	pidasime	pida	pidama	28_V	IndIpfPl1	et	pidasime =pida  (IndIpfPl1  >pidama !28_V
37545	vaatenurga	nurga	vaate+nurk	22_S	SgG	et	vaatenurga =nurga  (SgG  >vaate+nurk !22_S
37552	salvestama	salvesta	salvestama	27_V	Sup	et	salvestama =salvesta  (Sup  >salvestama !27_V
37558	kivimajade	maja	kivi+maja	17_S	PlG	et	kivimajade =maja  (PlG  >kivi+maja !17_S
37564	nägude	nägu	nägu	18_S	PlG	et	nägude =nägu  (PlG  >nägu !18_S
37570	linnakodanikele	kodanike	linna+kodanik	25_S	PlAll	et	linnakodanikele =kodanike  (PlAll  >linna+kodanik !25_S
37572	regulaarne	regulaarne	regulaarne	02_A	SgN	et	regulaarne =regulaarne  (SgN  >regulaarne !02_A
37585	piltides	pilti	pilt	22_S	PlIn	et	piltides =pilti  (PlIn  >pilt !22_S
37590	jalutuskäik	käik	jalutus+käik	22_S	SgN	et	jalutuskäik =käik  (SgN  >jalutus+käik !22_S
37594	sõltuda	sõltu	sõltuma	27_V	Inf	et	sõltuda =sõltu  (Inf  >sõltuma !27_V
37598	tallinnalahele	hele	tallinn+ala+hele	02_A	SgN	et	tallinnalahele =hele  (SgN  >tallinn+ala+hele !02_A
37601	ametnikest	ametnike	ametnik	25_S	PlEl	et	ametnikest =ametnike  (PlEl  >ametnik !25_S
37603	kahtlase	kahtlase	kahtlane	12?10_A	SgG	et	kahtlase =kahtlase  (SgG  >kahtlane !12?10_A
37608	kavanditest	kavandi	kavand	02_S	PlEl	et	kavanditest =kavandi  (PlEl  >kavand !02_S
37614	põhjendas	põhjenda	põhjendama	27_V	IndIpfSg3	et	põhjendas =põhjenda  (IndIpfSg3  >põhjendama !27_V
37618	fotografeeris	fotografeeri	fotografeerima	28_V	IndIpfSg3	et	fotografeeris =fotografeeri  (IndIpfSg3  >fotografeerima !28_V
37626	puit	puit	puit	22_S	SgN	et	puit =puit  (SgN  >puit !22_S
37640	paljuvaieldud	vaieldu	palju+vaieldu	01_S	PlN	et	paljuvaieldud =vaieldu  (PlN  >palju+vaieldu !01_S
37642	kalevipoeg-ettevõtet	võte	kalevipoeg-ette+võte	06_S	SgP	et	kalevipoeg-ettevõtet =võte  (SgP  >kalevipoeg-ette+võte !06_S
37644	marsruudile	marsruudi	marsruut	22_S	SgAll	et	marsruudile =marsruudi  (SgAll  >marsruut !22_S
37655	planeeriti	planeeri	planeerima	28_V	IndIpfIps	et	planeeriti =planeeri  (IndIpfIps  >planeerima !28_V
37657	maailmarännakut	rännaku	maa+ilma+rännak	02_S	SgP	et	maailmarännakut =rännaku  (SgP  >maa+ilma+rännak !02_S
37659	eriarvamusel	arvamuse	eri+arvamus	11_S	SgAd	et	eriarvamusel =arvamuse  (SgAd  >eri+arvamus !11_S
37662	pihkudega	pihku	pihk	22_S	PlKom	et	pihkudega =pihku  (PlKom  >pihk !22_S
37664	endisest	endise	endine	10~12_A	SgEl	et	endisest =endise  (SgEl  >endine !10~12_A
37668	erkki	erk	erk	22_AS	SgN^	et	erkki =erk  (SgN^  >erk !22_AS
37669	kirde-euroopas	euroopa	kirde-euroopa	01_H	SgIn	et	kirde-euroopas =euroopa  (SgIn  >kirde-euroopa !01_H
37671	liikmesriigid	riigi	liikmes+riik	22_S	PlN	et	liikmesriigid =riigi  (PlN  >liikmes+riik !22_S
37676	inimkapital	kapital	inim+kapital	19_S	SgN	et	inimkapital =kapital  (SgN  >inim+kapital !19_S
37678	sotsiaalküsimused	küsimuse	sotsiaal+küsimus	11_S	PlN	et	sotsiaalküsimused =küsimuse  (PlN  >sotsiaal+küsimus !11_S
37681	tuumaturvaküsimused	küsimuse	tuuma+turva+küsimus	11_S	PlN	et	tuumaturvaküsimused =küsimuse  (PlN  >tuuma+turva+küsimus !11_S
37684	kõnedes	kõne	kõne	16_S	PlIn	et	kõnedes =kõne  (PlIn  >kõne !16_S
37690	tervisepartnerlus	partnerlus	tervise+partnerlus	11_S	SgN	et	tervisepartnerlus =partnerlus  (SgN  >tervise+partnerlus !11_S
37692	jäätme	jäätme	jääde	05_S	SgG	et	jäätme =jäätme  (SgG  >jääde !05_S
37696	lisaprojektide	projekti	lisa+projekt	22_S	PlG	et	lisaprojektide =projekti  (PlG  >lisa+projekt !22_S
37705	el-riigid	riigi	el-riik	22_S	PlN	et	el-riigid =riigi  (PlN  >el-riik !22_S
37707	partnerid	partneri	partner	02_S	PlN	et	partnerid =partneri  (PlN  >partner !02_S
37709	veepuhastusjaam	jaam	vee+puhastus+jaam	22_S	SgN	et	veepuhastusjaam =jaam  (SgN  >vee+puhastus+jaam !22_S
37714	dimensioon	dimensioon	dimensioon	22_S	SgN	et	dimensioon =dimensioon  (SgN  >dimensioon !22_S
37716	ministrite	ministri	minister	02_S	PlG	et	ministrite =ministri  (PlG  >minister !02_S
37722	finantseerimisallikate	allika	finantseerimis+allikas	02_S	PlG	et	finantseerimisallikate =allika  (PlG  >finantseerimis+allikas !02_S
37723	dimensioonil	dimensiooni	dimensioon	22_S	SgAd	et	dimensioonil =dimensiooni  (SgAd  >dimensioon !22_S
37727	sellelaadses	laadse	selle+laadne	02_AS	SgIn	et	sellelaadses =laadse  (SgIn  >selle+laadne !02_AS
37731	organisatsioonidest	organisatsiooni	organisatsioon	22_S	PlEl	et	organisatsioonidest =organisatsiooni  (PlEl  >organisatsioon !22_S
37733	väheneb	vähene	vähenema	27_V	IndPrSg3	et	väheneb =vähene  (IndPrSg3  >vähenema !27_V
37737	avardatakse	avarda	avardama	27_V	IndPrIps	et	avardatakse =avarda  (IndPrIps  >avardama !27_V
37742	väheneks	vähene	vähenema	27_V	KndPrPs	et	väheneks =vähene  (KndPrPs  >vähenema !27_V
37749	nõukogud	kogu	nõu+kogu	17_S	PlN	et	nõukogud =kogu  (PlN  >nõu+kogu !17_S
37753	põhjadimensioon	dimensioon	põhja+dimensioon	22_S	SgN	et	põhjadimensioon =dimensioon  (SgN  >põhja+dimensioon !22_S
37756	mitmesuguste	sugus	mitme+sugune	10_A	PlG	et	mitmesuguste =sugus  (PlG  >mitme+sugune !10_A
37544	kujuri	kujuri	kujur	02_S	SgG	et	kujuri =kujuri  (SgG  >kujur !02_S
37548	kuulutatakse	kuuluta	kuulutama	27_V	IndPrIps	et	kuulutatakse =kuuluta  (IndPrIps  >kuulutama !27_V
37550	juhatab	juhata	juhatama	27_V	IndPrSg3	et	juhatab =juhata  (IndPrSg3  >juhatama !27_V
37554	põhiosaks	osa	põhi+osa	17_S	SgTr	et	põhiosaks =osa  (SgTr  >põhi+osa !17_S
37562	politseinikuid	politseiniku	politseinik	02_S	PlP	et	politseinikuid =politseiniku  (PlP  >politseinik !02_S
37567	lehekülgetel	e	lehe+külg+esi	15_S	PlAd	et	lehekülgetel =e  (PlAd  >lehe+külg+esi !15_S
37573	silmasisese	sisese	silma+sisene	10_A	SgG	et	silmasisese =sisese  (SgG  >silma+sisene !10_A
37578	20sajandi	sajandi	sajand	02_S	SgG	et	sajandi =sajandi  (SgG  >sajand !02_S
37584	näopiltide	pilti	näo+pilt	22_S	PlG	et	näopiltide =pilti  (PlG  >näo+pilt !22_S
37605	peidaks	peida	peitma	34_V	KndPrPs	et	peidaks =peida  (KndPrPs  >peitma !34_V
37622	fotodele	foto	foto	16_S	PlAll	et	fotodele =foto  (PlAll  >foto !16_S
37625	töötass	tass	töö+tass	22_S	SgN	et	töötass =tass  (SgN  >töö+tass !22_S
37628	kunstiõpetajaks	õpetaja	kunsti+õpetaja	01_S	SgTr	et	kunstiõpetajaks =õpetaja  (SgTr  >kunsti+õpetaja !01_S
37634	nõrgenemaks	nõrgene	nõrgenema	27_V	SupTr	et	nõrgenemaks =nõrgene  (SupTr  >nõrgenema !27_V
37638	ettepanekut	paneku	ette+panek	02_S	SgP	et	ettepanekut =paneku  (SgP  >ette+panek !02_S
37647	merelegi	mere	meri	20_S	SgAll^	et	merelegi =mere  (SgAll^  >meri !20_S
37648	hindamiskomisjonist	komisjoni	hinda+mis+komisjon	19_S	SgEl	et	hindamiskomisjonist =komisjoni  (SgEl  >hinda+mis+komisjon !19_S
37663	kaasatulek	tulek	kaasa+tulek	02_S	SgN	et	kaasatulek =tulek  (SgN  >kaasa+tulek !02_S
37667	urmas	urma	urm	22_S	SgIn	et	urmas =urma  (SgIn  >urm !22_S
37670	osavõtjateks	võtja	osa+võtja	01_S	PlTr	et	osavõtjateks =võtja  (PlTr  >osa+võtja !01_S
37674	euroarktiline	arktiline	euro+arktiline	12_A	SgN	et	euroarktiline =arktiline  (SgN  >euro+arktiline !12_A
37677	tervise-	tervise	tervis	09~11_S	SgG	et	tervise- =tervise  (SgG  >tervis !09~11_S
37679	keskkonna-	keskkonna	keskkond	22_S	SgG	et	keskkonna- =keskkonna  (SgG  >keskkond !22_S
37683	poliitilistes	poliitilis	poliitiline	12_A	PlIn	et	poliitilistes =poliitilis  (PlIn  >poliitiline !12_A
37687	ettevõtmistes	võtmis	ette+võtmine	12?10_S	PlIn	et	ettevõtmistes =võtmis  (PlIn  >ette+võtmine !12?10_S
37688	partnerprojektides	projekti	partner+projekt	22_S	PlIn	et	partnerprojektides =projekti  (PlIn  >partner+projekt !22_S
37693	hoiule	hoiu	hoid	22_S	SgAll	et	hoiule =hoiu  (SgAll  >hoid !22_S
37702	algkapital	kapital	alg+kapital	19_S	SgN	et	algkapital =kapital  (SgN  >alg+kapital !19_S
37704	fondist	fondi	fond	22_S	SgEl	et	fondist =fondi  (SgEl  >fond !22_S
37710	jäätmekoormus	koormus	jäätme+koormus	11~09_S	SgN	et	jäätmekoormus =koormus  (SgN  >jäätme+koormus !11~09_S
37720	kagu-euroopasse	euroopa	kagu-euroopa	01_H	SgIll	et	kagu-euroopasse =euroopa  (SgIll  >kagu-euroopa !01_H
37721	tasandi	tasandi	tasand	02_S	SgG	et	tasandi =tasandi  (SgG  >tasand !02_S
37724	partnerlusprojekt	projekt	partnerlus+projekt	22_S	SgN	et	partnerlusprojekt =projekt  (SgN  >partnerlus+projekt !22_S
37728	vee-	vee	vesi	15_S	SgG	et	vee- =vee  (SgG  >vesi !15_S
37738	tervisehoid	hoid	tervise+hoid	22_S	SgN	et	tervisehoid =hoid  (SgN  >tervise+hoid !22_S
37744	piiriületuspunktide	punkti	piiri+ületus+punkt	22_S	PlG	et	piiriületuspunktide =punkti  (PlG  >piiri+ületus+punkt !22_S
37745	kaubaveo	veo	kauba+vedu	18_S	SgG	et	kaubaveo =veo  (SgG  >kauba+vedu !18_S
37750	läänemeremaade	maa	lääne+mere+maa	26_S	PlG	et	läänemeremaade =maa  (PlG  >lääne+mere+maa !26_S
37763	lähipiirkondades	piirkonda	lähi+piirkond	22_S	PlIn	et	lähipiirkondades =piirkonda  (PlIn  >lähi+piirkond !22_S
37770	saastekoormus	koormus	saaste+koormus	11~09_S	SgN	et	saastekoormus =koormus  (SgN  >saaste+koormus !11~09_S
37773	täidab	täida	täitma	34_V	IndPrSg3	et	täidab =täida  (IndPrSg3  >täitma !34_V
37777	genotsiidide	genotsiidi	genotsiid	22_S	PlG	et	genotsiidide =genotsiidi  (PlG  >genotsiid !22_S
37780	juutide	juuti	juut	22_S	PlG	et	juutide =juuti  (PlG  >juut !22_S
37785	terrorit	terrori	terror	02_S	SgP	et	terrorit =terrori  (SgP  >terror !02_S
37787	vangilaagrikirjanduse	kirjanduse	vangi+laagri+kirjandus	11_S	SgG	et	vangilaagrikirjanduse =kirjanduse  (SgG  >vangi+laagri+kirjandus !11_S
37788	idanostalgiasse	nostalgia	ida+nostalgia	01_S	SgIll	et	idanostalgiasse =nostalgia  (SgIll  >ida+nostalgia !01_S
37793	liidusse	liidu	liit	22_S	SgIll	et	liidusse =liidu  (SgIll  >liit !22_S
37794	vangilaagrikirjandus	kirjandus	vangi+laagri+kirjandus	11_S	SgN	et	vangilaagrikirjandus =kirjandus  (SgN  >vangi+laagri+kirjandus !11_S
37795	tegudest	tegu	tegu	18_S	PlEl	et	tegudest =tegu  (PlEl  >tegu !18_S
37799	ida-saksamaaga	maa	ida-saksa+maa	26_S	SgKom	et	ida-saksamaaga =maa  (SgKom  >ida-saksa+maa !26_S
37806	genotsiididega	genotsiidi	genotsiid	22_S	PlKom	et	genotsiididega =genotsiidi  (PlKom  >genotsiid !22_S
37816	memuaare	memuaare	memuaar	22_S	PlP	et	memuaare =memuaare  (PlP  >memuaar !22_S
37549	võistlustööde	töö	võistlus+töö	26_S	PlG	et	võistlustööde =töö  (PlG  >võistlus+töö !26_S
37551	ringkäigule	käigu	ring+käik	22_S	SgAll	et	ringkäigule =käigu  (SgAll  >ring+käik !22_S
37553	puumaju	maju	puu+maja	17_S	PlP	et	puumaju =maju  (PlP  >puu+maja !17_S
37557	tasapisi	tasapisi	tasa+pisi	41_D	ID	et	tasapisi =tasapisi  (ID  >tasa+pisi !41_D
37563	elanikudele	elaniku	elanik	25_S	PlAll	et	elanikudele =elaniku  (PlAll  >elanik !25_S
37566	fotografeerime	fotografeeri	fotografeerima	28_V	IndPrPl1	et	fotografeerime =fotografeeri  (IndPrPl1  >fotografeerima !28_V
37571	dokumentidest	dokumenti	dokument	22_S	PlEl	et	dokumentidest =dokumenti  (PlEl  >dokument !22_S
37574	väidetakse	väide	väitma	34_V	IndPrIps	et	väidetakse =väide  (IndPrIps  >väitma !34_V
37577	ettenägelikuks	nägeliku	ette+nägelik	25_A	SgTr	et	ettenägelikuks =nägeliku  (SgTr  >ette+nägelik !25_A
37586	üksikasi	asi	üksik+asi	24_S	SgN	et	üksikasi =asi  (SgN  >üksik+asi !24_S
37587	raudteerööpaile	rööpa	raud+tee+rööbas	07_S	PlAll	et	raudteerööpaile =rööpa  (PlAll  >raud+tee+rööbas !07_S
37591	provints	provints	provints	22_S	SgN	et	provints =provints  (SgN  >provints !22_S
37599	mälestuskompleks	kompleks	mälestus+kompleks	22_S	SgN	et	mälestuskompleks =kompleks  (SgN  >mälestus+kompleks !22_S
37609	kunstnikuliidud	liidu	kunstniku+liit	22_S	PlN	et	kunstnikuliidud =liidu  (PlN  >kunstniku+liit !22_S
37617	puitmajadest	maja	puit+maja	17_S	PlEl	et	puitmajadest =maja  (PlEl  >puit+maja !17_S
37620	tuumaparemiku	paremiku	tuuma+paremik	25_S	SgG	et	tuumaparemiku =paremiku  (SgG  >tuuma+paremik !25_S
37631	rööpaid	rööpa	rööbas	07_S	PlP	et	rööpaid =rööpa  (PlP  >rööbas !07_S
37633	aastal1913	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
37637	kunstnikkude	kunstnikku	kunstnik	25_S	PlG	et	kunstnikkude =kunstnikku  (PlG  >kunstnik !25_S
37639	protesteerida	protesteeri	protesteerima	28_V	Inf	et	protesteerida =protesteeri  (Inf  >protesteerima !28_V
37641	turustama	turusta	turustama	27_V	Sup	et	turustama =turusta  (Sup  >turustama !27_V
37645	kloostrisse	kloostri	klooster	02_S	SgIll	et	kloostrisse =kloostri  (SgIll  >klooster !02_S
37646	kunstnikeliidud	liidu	kunstnike+liit	22_S	PlN	et	kunstnikeliidud =liidu  (PlN  >kunstnike+liit !22_S
37649	hindamiskomisjonis	komisjoni	hinda+mis+komisjon	19_S	SgIn	et	hindamiskomisjonis =komisjoni  (SgIn  >hinda+mis+komisjon !19_S
37653	poleemikat	poleemika	poleemika	01_S	SgP	et	poleemikat =poleemika  (SgP  >poleemika !01_S
37656	21meetrini	meetri	meeter	02_S	SgTer	et	meetrini =meetri  (SgTer  >meeter !02_S
37660	planeeritakse	planeeri	planeerima	28_V	IndPrIps	et	planeeritakse =planeeri  (IndPrIps  >planeerima !28_V
37661	nõukoguaegse	aegse	nõu+kogu+aegne	02_A	SgG	et	nõukoguaegse =aegse  (SgG  >nõu+kogu+aegne !02_A
37672	partnerriigid	riigi	partner+riik	22_S	PlN	et	partnerriigid =riigi  (PlN  >partner+riik !22_S
37673	regionaalnõukogud	kogu	regionaal+nõu+kogu	17_S	PlN	et	regionaalnõukogud =kogu  (PlN  >regionaal+nõu+kogu !17_S
37694	miljardit	miljardi	miljard	02_N	SgP	et	miljardit =miljardi  (SgP  >miljard !02_N
37695	eurot	euro	euro	16_S	SgP	et	eurot =euro  (SgP  >euro !16_S
37697	miljardi	miljardi	miljard	02_N	SgG	et	miljardi =miljardi  (SgG  >miljard !02_N
37701	finantseeritakse	finantseeri	finantseerima	28_V	IndPrIps	et	finantseeritakse =finantseeri  (IndPrIps  >finantseerima !28_V
37703	partnerluse	partnerluse	partnerlus	11_S	SgG	et	partnerluse =partnerluse  (SgG  >partnerlus !11_S
37708	poolsed	poolse	poolne	02_A	PlN	et	poolsed =poolse  (PlN  >poolne !02_A
37715	piirkondlikud	piirkondliku	piirkondlik	25_A	PlN	et	piirkondlikud =piirkondliku  (PlN  >piirkondlik !25_A
37717	tuumaohutusküsimused	küsimuse	tuuma+ohutus+küsimus	11_S	PlN	et	tuumaohutusküsimused =küsimuse  (PlN  >tuuma+ohutus+küsimus !11_S
37734	tervisepartnerluse	partnerluse	tervise+partnerlus	11_S	SgG	et	tervisepartnerluse =partnerluse  (SgG  >tervise+partnerlus !11_S
37735	vastaseid	vastase	vastane	10_AS	PlP	et	vastaseid =vastase  (PlP  >vastane !10_AS
37751	justiits-	justiits	justiits	22_S	SgN	et	justiits- =justiits  (SgN  >justiits !22_S
37757	projektidena	projekti	projekt	22_S	PlEs	et	projektidena =projekti  (PlEs  >projekt !22_S
37759	rahvatervise	tervise	rahva+tervis	09~11_S	SgG	et	rahvatervise =tervise  (SgG  >rahva+tervis !09~11_S
37769	edelapoolne	poolne	edela+poolne	02_A	SgN	et	edelapoolne =poolne  (SgN  >edela+poolne !02_A
37771	kiirgusohu	ohu	kiirgus+oht	22_S	SgG	et	kiirgusohu =ohu  (SgG  >kiirgus+oht !22_S
37781	genotsiidile	genotsiidi	genotsiid	22_S	SgAll	et	genotsiidile =genotsiidi  (SgAll  >genotsiid !22_S
37782	piibellik	piibellik	piibellik	25_A	SgN	et	piibellik =piibellik  (SgN  >piibellik !25_A
37800	sakslastel	sakslas	sakslane	12?10_S	PlAd	et	sakslastel =sakslas  (PlAd  >sakslane !12?10_S
37804	lähtekoht	koht	lähte+koht	22_S	SgN	et	lähtekoht =koht  (SgN  >lähte+koht !22_S
37814	nöukogude-aegse	aegse	nöukogude-aegne	02_A	SgG	et	nöukogude-aegse =aegse  (SgG  >nöukogude-aegne !02_A
37629	tolleaegses	aegse	tolle+aegne	02_A	SgIn	et	tolleaegses =aegse  (SgIn  >tolle+aegne !02_A
37636	tervisel	tervise	tervis	09~11_S	SgAd	et	tervisel =tervise  (SgAd  >tervis !09~11_S
37650	hiigelsuur	suur	hiigel+suur	13_A	SgN	et	hiigelsuur =suur  (SgN  >hiigel+suur !13_A
37651	memoriaal	memoriaal	memoriaal	22_S	SgN	et	memoriaal =memoriaal  (SgN  >memoriaal !22_S
37652	eestkostjad	kostja	eest+kostja	01_S	PlN	et	eestkostjad =kostja  (PlN  >eest+kostja !01_S
37654	1990-aastate	aasta	-aasta	01_S	PlG	et	-aastate =aasta  (PlG  >-aasta !01_S
37665	mõõtme	mõõtme	mõõde	05_S	SgG	et	mõõtme =mõõtme  (SgG  >mõõde !05_S
37666	teenäitajateks	näitaja	tee+näitaja	01_S	PlTr	et	teenäitajateks =näitaja  (PlTr  >tee+näitaja !01_S
37675	finantsorganisatsioonid	organisatsiooni	finants+organisatsioon	22_S	PlN	et	finantsorganisatsioonid =organisatsiooni  (PlN  >finants+organisatsioon !22_S
37680	piiriülene	ülene	piiri+ülene	10_A	SgN	et	piiriülene =ülene  (SgN  >piiri+ülene !10_A
37685	finantsallikate	allika	finants+allikas	02_S	PlG	et	finantsallikate =allika  (PlG  >finants+allikas !02_S
37689	keskkonnapartnerlus	partnerlus	kesk+konna+partnerlus	11_S	SgN	et	keskkonnapartnerlus =partnerlus  (SgN  >kesk+konna+partnerlus !11_S
37699	teostatakse	teosta	teostama	27_V	IndPrIps	et	teostatakse =teosta  (IndPrIps  >teostama !27_V
37700	lähiümbruses	ümbruse	lähi+ümbrus	11~09_S	SgIn	et	lähiümbruses =ümbruse  (SgIn  >lähi+ümbrus !11~09_S
37706	finantsorganisatsioonidelt	organisatsiooni	finants+organisatsioon	22_S	PlAbl	et	finantsorganisatsioonidelt =organisatsiooni  (PlAbl  >finants+organisatsioon !22_S
37711	tuumajäätmeprojektid	projekti	tuuma+jäätme+projekt	22_S	PlN	et	tuumajäätmeprojektid =projekti  (PlN  >tuuma+jäätme+projekt !22_S
37713	kiirguse	kiirguse	kiirgus	11~09_S	SgG	et	kiirguse =kiirguse  (SgG  >kiirgus !11~09_S
37718	siseasjad	asja	sise+asi	24_S	PlN	et	siseasjad =asja  (PlN  >sise+asi !24_S
37719	poliitikaks	poliitika	poliitika	01_S	SgTr	et	poliitikaks =poliitika  (SgTr  >poliitika !01_S
37725	partnerlus	partnerlus	partnerlus	11_S	SgN	et	partnerlus =partnerlus  (SgN  >partnerlus !11_S
37729	el-le	el	el	xx_Q	SgAll	et	el-le =el  (SgAll  >el !xx_Q
37730	partnerite	partneri	partner	02_S	PlG	et	partnerite =partneri  (PlG  >partner !02_S
37732	kohalikest	kohalike	kohalik	25_AS	PlEl	et	kohalikest =kohalike  (PlEl  >kohalik !25_AS
37739	vangide	vangi	vang	22_S	PlG	et	vangide =vangi  (PlG  >vang !22_S
37741	partnerlusprogramm	programm	partnerlus+programm	22_S	SgN	et	partnerlusprogramm =programm  (SgN  >partnerlus+programm !22_S
37743	partnerlusega	partnerluse	partnerlus	11_S	SgKom	et	partnerlusega =partnerluse  (SgKom  >partnerlus !11_S
37746	põhjadimensioonist	dimensiooni	põhja+dimensioon	22_S	SgEl	et	põhjadimensioonist =dimensiooni  (SgEl  >põhja+dimensioon !22_S
37747	välissuhete	suhe	välis+suhe	06_S	PlG	et	välissuhete =suhe  (PlG  >välis+suhe !06_S
37748	el-l	el	el	xx_Q	SgAd	et	el-l =el  (SgAd  >el !xx_Q
37754	kirde-euroopale	euroopa	kirde-euroopa	01_H	SgAll	et	kirde-euroopale =euroopa  (SgAll  >kirde-euroopa !01_H
37755	ülatasandi	tasandi	üla+tasand	02_S	SgG	et	ülatasandi =tasandi  (SgG  >üla+tasand !02_S
37764	toetusfondist	fondi	toetus+fond	22_S	SgEl	et	toetusfondist =fondi  (SgEl  >toetus+fond !22_S
37765	liikmesriike	riike	liikmes+riik	22_S	PlP	et	liikmesriike =riike  (PlP  >liikmes+riik !22_S
37766	regionaalsed	regionaalse	regionaalne	02_A	PlN	et	regionaalsed =regionaalse  (PlN  >regionaalne !02_A
37774	haakrist	rist	haak+rist	22_S	SgN	et	haakrist =rist  (SgN  >haak+rist !22_S
37776	juutidel	juuti	juut	22_S	PlAd	et	juutidel =juuti  (PlAd  >juut !22_S
37783	ümberasutamist	asutamis	ümber+asutamine	12_S	SgP	et	ümberasutamist =asutamis  (SgP  >ümber+asutamine !12_S
37790	idas	ida	ida	17_S	SgIn	et	idas =ida  (SgIn  >ida !17_S
37791	lugejaskonna	lugejaskonna	lugejaskond	22_S	SgG	et	lugejaskonna =lugejaskonna  (SgG  >lugejaskond !22_S
37796	natsionaalsotsialism	sotsialism	natsionaal+sotsialism	22_S	SgN	et	natsionaalsotsialism =sotsialism  (SgN  >natsionaal+sotsialism !22_S
37797	tempoga	tempo	tempo	16_S	SgKom	et	tempoga =tempo  (SgKom  >tempo !16_S
37802	kommunismiga	kommunismi	kommunism	22_S	SgKom	et	kommunismiga =kommunismi  (SgKom  >kommunism !22_S
37807	tagakiusamisega	kiusamise	taga+kiusamine	12_S	SgKom	et	tagakiusamisega =kiusamise  (SgKom  >taga+kiusamine !12_S
37808	traditsioonist	traditsiooni	traditsioon	22_S	SgEl	et	traditsioonist =traditsiooni  (SgEl  >traditsioon !22_S
37809	genotsiidil	genotsiidi	genotsiid	22_S	SgAd	et	genotsiidil =genotsiidi  (SgAd  >genotsiid !22_S
37811	sundviisil	viisi	sund+viis	22_S	SgAd	et	sundviisil =viisi  (SgAd  >sund+viis !22_S
37812	rahvastiku	rahvastiku	rahvastik	25_S	SgG	et	rahvastiku =rahvastiku  (SgG  >rahvastik !25_S
37826	väärtustab	väärtusta	väärtustama	27_V	IndPrSg3	et	väärtustab =väärtusta  (IndPrSg3  >väärtustama !27_V
37829	kriitilised	kriitilise	kriitiline	12_A	PlN	et	kriitilised =kriitilise  (PlN  >kriitiline !12_A
37833	meis	me	ma	00_P	PlIn	et	meis =me  (PlIn  >ma !00_P
37762	realiseeritakse	realiseeri	realiseerima	28_V	IndPrIps	et	realiseeritakse =realiseeri  (IndPrIps  >realiseerima !28_V
37767	omavalitsused	valitsuse	oma+valitsus	11_S	PlN	et	omavalitsused =valitsuse  (PlN  >oma+valitsus !11_S
37768	laenude	laenu	laen	22_S	PlG	et	laenude =laenu  (PlG  >laen !22_S
37775	naerma	naer	naerma	33_V	Sup	et	naerma =naer  (Sup  >naerma !33_V
37778	ohvrid	ohvri	ohver	02_S	PlN	et	ohvrid =ohvri  (PlN  >ohver !02_S
37779	kaanon	kaanon	kaanon	02_S	SgN	et	kaanon =kaanon  (SgN  >kaanon !02_S
37789	huumor	huumor	huumor	02_S	SgN	et	huumor =huumor  (SgN  >huumor !02_S
37798	suhet	suhe	suhe	06_S	SgP	et	suhet =suhe  (SgP  >suhe !06_S
37801	vahendeid	vahende	vahend	02_S	PlP	et	vahendeid =vahende  (PlP  >vahend !02_S
37803	natsiminevikuga	mineviku	natsi+minevik	25_S	SgKom	et	natsiminevikuga =mineviku  (SgKom  >natsi+minevik !25_S
37805	väljendamaks	väljenda	väljendama	27_V	SupTr	et	väljendamaks =väljenda  (SupTr  >väljendama !27_V
37820	humoorikat	humoorika	humoorikas	02_A	SgP	et	humoorikat =humoorika  (SgP  >humoorikas !02_A
37821	huumorit	huumori	huumor	02_S	SgP	et	huumorit =huumori  (SgP  >huumor !02_S
37827	klaarib	klaari	klaarima	28_V	IndPrSg3	et	klaarib =klaari  (IndPrSg3  >klaarima !28_V
37844	alatooniga	tooni	ala+toon	22_S	SgKom	et	alatooniga =tooni  (SgKom  >ala+toon !22_S
37861	sundteisaldamine	teisaldamine	sund+teisaldamine	12_S	SgN	et	sundteisaldamine =teisaldamine  (SgN  >sund+teisaldamine !12_S
37862	idablokiriikides	riiki	ida+bloki+riik	22_S	PlIn	et	idablokiriikides =riiki  (PlIn  >ida+bloki+riik !22_S
37865	huumorimeelse	meelse	huumori+meelne	02_A	SgG	et	huumorimeelse =meelse  (SgG  >huumori+meelne !02_A
37866	nostalgiaga	nostalgia	nostalgia	01_S	SgKom	et	nostalgiaga =nostalgia  (SgKom  >nostalgia !01_S
37869	maadlema	maadle	maadlema	30_V	Sup	et	maadlema =maadle  (Sup  >maadlema !30_V
37870	kriitilisi	kriitilisi	kriitiline	12_A	PlP	et	kriitilisi =kriitilisi  (PlP  >kriitiline !12_A
37875	rituaalides	rituaali	rituaal	22_S	PlIn	et	rituaalides =rituaali  (PlIn  >rituaal !22_S
37879	mulgist	mulgi	mulk	22_S	SgEl	et	mulgist =mulgi  (SgEl  >mulk !22_S
37881	sõnnik	sõnnik	sõnnik	02_S	SgN	et	sõnnik =sõnnik  (SgN  >sõnnik !02_S
37889	hõimudega	hõimu	hõim	22_S	PlKom	et	hõimudega =hõimu  (PlKom  >hõim !22_S
37909	töötasime	tööta	töötama	27_V	IndIpfPl1	et	töötasime =tööta  (IndIpfPl1  >töötama !27_V
37910	personaliosakond	osakond	personali+osakond	22_S	SgN	et	personaliosakond =osakond  (SgN  >personali+osakond !22_S
37912	kutsute	kutsu	kutsuma	28_V	IndPrPl2	et	kutsute =kutsu  (IndPrPl2  >kutsuma !28_V
37924	meeskonnatöödes	töö	mees+konna+töö	26_S	PlIn	et	meeskonnatöödes =töö  (PlIn  >mees+konna+töö !26_S
37930	suhtlemisoskuse	oskuse	suhtlemis+oskus	11~09_S	SgG	et	suhtlemisoskuse =oskuse  (SgG  >suhtlemis+oskus !11~09_S
37947	kooskõlas	kõla	koos+kõla	17_S	SgIn	et	kooskõlas =kõla  (SgIn  >koos+kõla !17_S
37952	alljärgnevatest	järgneva	all+järgnev	02_A	PlEl	et	alljärgnevatest =järgneva  (PlEl  >all+järgnev !02_A
37957	paberite	paberi	paber	02_S	PlG	et	paberite =paberi  (PlG  >paber !02_S
37958	aktsiad	aktsia	aktsia	01_S	PlN	et	aktsiad =aktsia  (PlN  >aktsia !01_S
37962	25detsember	detsember	detsember	02_S	SgN	et	detsember =detsember  (SgN  >detsember !02_S
37967	käesolevale	oleva	käes+olev	02_A	SgAll	et	käesolevale =oleva  (SgAll  >käes+olev !02_A
37971	omandisse	omandi	omand	02_S	SgIll	et	omandisse =omandi  (SgIll  >omand !02_S
37975	äriselts	selts	äri+selts	22_S	SgN	et	äriselts =selts  (SgN  >äri+selts !22_S
37983	registri	registri	register	02_S	SgG	et	registri =registri  (SgG  >register !02_S
37995	kommertsettevõte	võte	kommerts+ette+võte	06_S	SgN	et	kommertsettevõte =võte  (SgN  >kommerts+ette+võte !06_S
37997	ostu-müügilepingule	lepingu	ostu-müügi+leping	02_S	SgAll	et	ostu-müügilepingule =lepingu  (SgAll  >ostu-müügi+leping !02_S
38000	tasuda	tasu	tasuma	27_V	Inf	et	tasuda =tasu  (Inf  >tasuma !27_V
38003	vaidlusi	vaidlusi	vaidlus	11_S	PlP	et	vaidlusi =vaidlusi  (PlP  >vaidlus !11_S
38007	autojuhtidele	juhti	auto+juht	22_S	PlAll	et	autojuhtidele =juhti  (PlAll  >auto+juht !22_S
38014	katest	kate	katt	22_S	PlEl	et	katest =kate  (PlEl  >katt !22_S
38020	uus-metall	metall	uus-metall	22_S	SgN	et	uus-metall =metall  (SgN  >uus-metall !22_S
38028	põlvikutega	põlviku	põlvik	02_S	PlKom	et	põlvikutega =põlviku  (PlKom  >põlvik !02_S
38032	trummar	trummar	trummar	02_S	SgN	et	trummar =trummar  (SgN  >trummar !02_S
38038	autoriteetse	autoriteetse	autoriteetne	02_A	SgG	et	autoriteetse =autoriteetse  (SgG  >autoriteetne !02_A
38039	edetabeli	tabeli	ede+tabel	02_S	SgG	et	edetabeli =tabeli  (SgG  >ede+tabel !02_S
38042	majamuuseum	muuseum	maja+muuseum	19~02_S	SgN	et	majamuuseum =muuseum  (SgN  >maja+muuseum !19~02_S
38047	dokumentides	dokumenti	dokument	22_S	PlIn	et	dokumentides =dokumenti  (PlIn  >dokument !22_S
38054	kulm	kulm	kulm	22_S	SgN	et	kulm =kulm  (SgN  >kulm !22_S
37810	läbielanute	elanu	läbi+elanu	01_S	PlG	et	läbielanute =elanu  (PlG  >läbi+elanu !01_S
37813	ümberpaigutusi	paigutusi	ümber+paigutus	11_S	PlP	et	ümberpaigutusi =paigutusi  (PlP  >ümber+paigutus !11_S
37815	nöukogude-aegset	aegse	nöukogude-aegne	02_A	SgP	et	nöukogude-aegset =aegse  (SgP  >nöukogude-aegne !02_A
37817	koonduslaagri	laagri	koondus+laager	02_S	SgG	et	koonduslaagri =laagri  (SgG  >koondus+laager !02_S
37822	lääne-kui	kui	lääne-kui	41_JD	ID	et	lääne-kui =kui  (ID  >lääne-kui !41_JD
37824	kogema	koge	kogema	27_V	Sup	et	kogema =koge  (Sup  >kogema !27_V
37825	koonduslaagreid	laagre	koondus+laager	02_S	PlP	et	koonduslaagreid =laagre  (PlP  >koondus+laager !02_S
37828	suhteid	suhte	suhe	06_S	PlP	et	suhteid =suhte  (PlP  >suhe !06_S
37832	sümbolina	sümboli	sümbol	02_S	SgEs	et	sümbolina =sümboli  (SgEs  >sümbol !02_S
37834	õudust	õudus	õudus	11~09_S	SgP	et	õudust =õudus  (SgP  >õudus !11~09_S
37836	nendib	nendi	nentima	28_V	IndPrSg3	et	nendib =nendi  (IndPrSg3  >nentima !28_V
37840	mälestuskirjandust	kirjandus	mälestus+kirjandus	11_S	SgP	et	mälestuskirjandust =kirjandus  (SgP  >mälestus+kirjandus !11_S
37847	lugejaskond	lugejaskond	lugejaskond	22_S	SgN	et	lugejaskond =lugejaskond  (SgN  >lugejaskond !22_S
37856	natsimineviku	mineviku	natsi+minevik	25_S	SgG	et	natsimineviku =mineviku  (SgG  >natsi+minevik !25_S
37857	juurdlema	juurdle	juurdlema	30_V	Sup	et	juurdlema =juurdle  (Sup  >juurdlema !30_V
37859	massimõrvade	mõrva	massi+mõrv	22_S	PlG	et	massimõrvade =mõrva  (PlG  >massi+mõrv !22_S
37874	põlluriistad	riista	põllu+riist	22_S	PlN	et	põlluriistad =riista  (PlN  >põllu+riist !22_S
37877	viljandimaamehed	mehe	viljandi+maa+mees	13_S	PlN	et	viljandimaamehed =mehe  (PlN  >viljandi+maa+mees !13_S
37890	p-e	p	p	xx_Q	PlP	et	p-e =p  (PlP  >p !xx_Q
37898	kostitas	kostita	kostitama	27_V	IndIpfSg3	et	kostitas =kostita  (IndIpfSg3  >kostitama !27_V
37901	seitsmeks	seitsme	seitse	05_N	SgTr	et	seitsmeks =seitsme  (SgTr  >seitse !05_N
37907	otsin	otsi	otsima	28_V	IndPrSg1	et	otsin =otsi  (IndPrSg1  >otsima !28_V
37923	suhtlemisoskuses	oskuse	suhtlemis+oskus	11~09_S	SgIn	et	suhtlemisoskuses =oskuse  (SgIn  >suhtlemis+oskus !11~09_S
37931	töökõver	kõver	töö+kõver	02_AS	SgN	et	töökõver =kõver  (SgN  >töö+kõver !02_AS
37935	aktsiate	aktsia	aktsia	01_S	PlG	et	aktsiate =aktsia  (PlG  >aktsia !01_S
37936	pass	pass	pass	22_S	SgN	et	pass =pass  (SgN  >pass !22_S
37937	juriidiline	juriidiline	juriidiline	12_A	SgN	et	juriidiline =juriidiline  (SgN  >juriidiline !12_A
37939	korporatiivsete	sete	korporatiiv+sete	06_S	SgN	et	korporatiivsete =sete  (SgN  >korporatiiv+sete !06_S
37942	föderatsioon	föderatsioon	föderatsioon	22_S	SgN	et	föderatsioon =föderatsioon  (SgN  >föderatsioon !22_S
37944	juriidilisest	juriidilise	juriidiline	12_A	SgEl	et	juriidilisest =juriidilise  (SgEl  >juriidiline !12_A
37946	ettevõte	võte	ette+võte	06_S	SgN	et	ettevõte =võte  (SgN  >ette+võte !06_S
37949	kohustub	kohustu	kohustuma	27_V	IndPrSg3	et	kohustub =kohustu  (IndPrSg3  >kohustuma !27_V
37953	objekt	objekt	objekt	22_S	SgN	et	objekt =objekt  (SgN  >objekt !22_S
37956	järgmistest	järgmis	järgmine	12?10_A	PlEl	et	järgmistest =järgmis  (PlEl  >järgmine !12?10_A
37974	kõiksugustest	sugus	kõik+sugune	10_A	PlEl	et	kõiksugustest =sugus  (PlEl  >kõik+sugune !10_A
37976	juriidiliseks	juriidilise	juriidiline	12_A	SgTr	et	juriidiliseks =juriidilise  (SgTr  >juriidiline !12_A
37980	neitsisaared	saare	neitsi+saar	13_S	PlN	et	neitsisaared =saare  (PlN  >neitsi+saar !13_S
37985	saartega	saar	saar	13_S	PlKom	et	saartega =saar  (PlKom  >saar !13_S
37986	registraatoriks	registraatori	registraator	02_S	SgTr	et	registraatoriks =registraatori  (SgTr  >registraator !02_S
37990	aadressiga	aadressi	aadress	22_S	SgKom	et	aadressiga =aadressi  (SgKom  >aadress !22_S
37992	tingimuste	tingimus	tingimus	11_S	PlG	et	tingimuste =tingimus  (PlG  >tingimus !11_S
37996	seadusele	seaduse	seadus	11~09_S	SgAll	et	seadusele =seaduse  (SgAll  >seadus !11~09_S
38009	korjates	korja	korjama	29_V	Ger	et	korjates =korja  (Ger  >korjama !29_V
38019	10veebruaril	veebruari	veebruar	19_S	SgAd	et	veebruaril =veebruari  (SgAd  >veebruar !19_S
38021	agressiivse	agressiivse	agressiivne	02_A	SgG	et	agressiivse =agressiivse  (SgG  >agressiivne !02_A
38030	turneele	turnee	turnee	26_S	SgAll	et	turneele =turnee  (SgAll  >turnee !26_S
38033	kuuendalt	kuuenda	kuues	02_O	SgAbl	et	kuuendalt =kuuenda  (SgAbl  >kuues !02_O
38050	kased	kase	kask	22_S	PlN	et	kased =kase  (PlN  >kask !22_S
38056	klassipäevik	päevik	klassi+päevik	02_S	SgN	et	klassipäevik =päevik  (SgN  >klassi+päevik !02_S
38058	raamatupidajad	pidaja	raamatu+pidaja	01_S	PlN	et	raamatupidajad =pidaja  (PlN  >raamatu+pidaja !01_S
38060	palku	palku	palk	22_S	PlP	et	palku =palku  (PlP  >palk !22_S
38062	rahakott	kott	raha+kott	22_S	SgN	et	rahakott =kott  (SgN  >raha+kott !22_S
37818	kirjandusliku	kirjandusliku	kirjanduslik	25_A	SgG	et	kirjandusliku =kirjandusliku  (SgG  >kirjanduslik !25_A
37831	mõlgub	mõlgu	mõlkuma	28_V	IndPrSg3	et	mõlgub =mõlgu  (IndPrSg3  >mõlkuma !28_V
37835	käimalükkamiseks	lükkamise	käima+lükkamine	12_S	SgTr	et	käimalükkamiseks =lükkamise  (SgTr  >käima+lükkamine !12_S
37843	humoorika	humoorika	humoorikas	02_A	SgG	et	humoorika =humoorika  (SgG  >humoorikas !02_A
37845	kategooriasse	kategooria	kategooria	01_S	SgIll	et	kategooriasse =kategooria  (SgIll  >kategooria !01_S
37846	nostalgiat	nostalgia	nostalgia	01_S	SgP	et	nostalgiat =nostalgia  (SgP  >nostalgia !01_S
37855	kriitilise	kriitilise	kriitiline	12_A	SgG	et	kriitilise =kriitilise  (SgG  >kriitiline !12_A
37858	täitab	täita	täitama	27_V	IndPrSg3	et	täitab =täita  (IndPrSg3  >täitama !27_V
37867	ida-nostalgiaga	nostalgia	ida-nostalgia	01_S	SgKom	et	ida-nostalgiaga =nostalgia  (SgKom  >ida-nostalgia !01_S
37868	tunnetama	tunneta	tunnetama	27_V	Sup	et	tunnetama =tunneta  (Sup  >tunnetama !27_V
37873	veeloomadena	looma	vee+loom	22_S	PlEs	et	veeloomadena =looma  (PlEs  >vee+loom !22_S
37882	linnuseid	linnuse	linnus	09_S	PlP	et	linnuseid =linnuse  (PlP  >linnus !09_S
37887	germaani	germaani	germaani	41_G	ID	et	germaani =germaani  (ID  >germaani !41_G
37888	põld	põld	põld	22_S	SgN	et	põld =põld  (SgN  >põld !22_S
37891	lamasin	lama	lamama	27_V	IndIpfSg1	et	lamasin =lama  (IndIpfSg1  >lamama !27_V
37893	alustasime	alusta	alustama	27_V	IndIpfPl1	et	alustasime =alusta  (IndIpfPl1  >alustama !27_V
37903	uudisteajakirjanikuna	kirjaniku	uudiste+aja+kirjanik	25_S	SgEs	et	uudisteajakirjanikuna =kirjaniku  (SgEs  >uudiste+aja+kirjanik !25_S
37913	kesktaseme	taseme	kesk+tase	04_S	SgG	et	kesktaseme =taseme  (SgG  >kesk+tase !04_S
37914	võtate	võta	võtma	35_V	IndPrPl2	et	võtate =võta  (IndPrPl2  >võtma !35_V
37917	grupis	grupi	grupp	22_S	SgIn	et	grupis =grupi  (SgIn  >grupp !22_S
37918	fotofirmas	firma	foto+firma	16_S	SgIn	et	fotofirmas =firma  (SgIn  >foto+firma !16_S
37929	suhtlemisoskuste	oskus	suhtlemis+oskus	11~09_S	PlG	et	suhtlemisoskuste =oskus  (PlG  >suhtlemis+oskus !11~09_S
37933	vaatlete	vaatle	vaatlema	30_V	IndPrPl2	et	vaatlete =vaatle  (IndPrPl2  >vaatlema !30_V
37941	väärpaberid	paberi	väär+paber	02_S	PlN	et	väärpaberid =paberi  (PlN  >väär+paber !02_S
37943	aprill	aprill	aprill	22_S	SgN	et	aprill =aprill  (SgN  >aprill !22_S
37945	kommerts	kommerts	kommerts	22_S	SgN	et	kommerts =kommerts  (SgN  >kommerts !22_S
37959	registrinumber	number	registri+number	02_S	SgN	et	registrinumber =number  (SgN  >registri+number !02_S
37963	passinumber	number	passi+number	02_S	SgN	et	passinumber =number  (SgN  >passi+number !02_S
37966	lepinguese	ese	lepingu+ese	04_S	SgN	et	lepinguese =ese  (SgN  >lepingu+ese !04_S
37970	väärtpaberid	paberi	väärt+paber	02_S	PlN	et	väärtpaberid =paberi  (PlN  >väärt+paber !02_S
37973	lepinguobjekt	objekt	lepingu+objekt	22_S	SgN	et	lepinguobjekt =objekt  (SgN  >lepingu+objekt !22_S
37981	põhiseaduse	seaduse	põhi+seadus	11~09_S	SgG	et	põhiseaduse =seaduse  (SgG  >põhi+seadus !11~09_S
37982	alljärgnevast	järgneva	all+järgnev	02_A	SgEl	et	alljärgnevast =järgneva  (SgEl  >all+järgnev !02_A
37984	registraatoriga	registraatori	registraator	02_S	SgKom	et	registraatoriga =registraatori  (SgKom  >registraator !02_S
37988	seadusandluse	andluse	seadus+andlus	11~09_S	SgG	et	seadusandluse =andluse  (SgG  >seadus+andlus !11~09_S
37993	ostu-müügileping	leping	ostu-müügi+leping	02_S	SgN	et	ostu-müügileping =leping  (SgN  >ostu-müügi+leping !02_S
37998	alljärgnevas	järgneva	all+järgnev	02_A	SgIn	et	alljärgnevas =järgneva  (SgIn  >all+järgnev !02_A
38001	esemeks	eseme	ese	04_S	SgTr	et	esemeks =eseme  (SgTr  >ese !04_S
38022	13jaanuaril	jaanuari	jaanuar	19_S	SgAd	et	jaanuaril =jaanuari  (SgAd  >jaanuar !19_S
38040	parkmuuseumiks	muuseumi	park+muuseum	19~02_S	SgTr	et	parkmuuseumiks =muuseumi  (SgTr  >park+muuseum !19~02_S
38041	hannsen-tammsaare	saare	hannsen-tamm+saar	13_S	SgG	et	hannsen-tammsaare =saare  (SgG  >hannsen-tamm+saar !13_S
38043	järjekorras	korra	järje+kord	22_S	SgIn	et	järjekorras =korra  (SgIn  >järje+kord !22_S
38045	emajõgi	jõgi	ema+jõgi	21_S	SgN	et	emajõgi =jõgi  (SgN  >ema+jõgi !21_S
38046	tartut	tartu	tartu	01_H	SgP	et	tartut =tartu  (SgP  >tartu !01_H
38049	rahvusteater	teater	rahvus+teater	02_S	SgN	et	rahvusteater =teater  (SgN  >rahvus+teater !02_S
38057	kohusetundlik	tundlik	kohuse+tundlik	25_A	SgN	et	kohusetundlik =tundlik  (SgN  >kohuse+tundlik !25_A
38064	milliste	millis	milline	10_P	PlG	et	milliste =millis  (PlG  >milline !10_P
38080	emalisal	lisa	ema+lisa	17_S	SgAd	et	emalisal =lisa  (SgAd  >ema+lisa !17_S
38081	lahjasid	lahja	lahja	16_A	PlP	et	lahjasid =lahja  (PlP  >lahja !16_A
38085	pikendab	pikenda	pikendama	27_V	IndPrSg3	et	pikendab =pikenda  (IndPrSg3  >pikendama !27_V
38091	kaasatundlikud	tundliku	kaasa+tundlik	25_A	PlN	et	kaasatundlikud =tundliku  (PlN  >kaasa+tundlik !25_A
37819	idanostalgiat	nostalgia	ida+nostalgia	01_S	SgP	et	idanostalgiat =nostalgia  (SgP  >ida+nostalgia !01_S
37823	poolehoid	hoid	poole+hoid	22_S	SgN	et	poolehoid =hoid  (SgN  >poole+hoid !22_S
37830	käsitlemaks	käsitle	käsitlema	27_V	SupTr	et	käsitlemaks =käsitle  (SupTr  >käsitlema !27_V
37839	ohvrite	ohvri	ohver	02_S	PlG	et	ohvrite =ohvri  (PlG  >ohver !02_S
37842	vangilaagreid	laagre	vangi+laager	02_S	PlP	et	vangilaagreid =laagre  (PlP  >vangi+laager !02_S
37848	rüvetata	rüveta	rüvetama	27_V	IndPrIps_	et	rüvetata =rüveta  (IndPrIps_  >rüvetama !27_V
37864	seostada	seosta	seostama	27_V	Inf	et	seostada =seosta  (Inf  >seostama !27_V
37871	kaubeldi	kaubel	kauplema	30_V	IndIpfIps	et	kaubeldi =kaubel  (IndIpfIps  >kauplema !30_V
37880	hülgepüügiga	püügi	hülge+püük	22_S	SgKom	et	hülgepüügiga =püügi  (SgKom  >hülge+püük !22_S
37883	matusetraditsioon	traditsioon	matuse+traditsioon	22_S	SgN	et	matusetraditsioon =traditsioon  (SgN  >matuse+traditsioon !22_S
37884	pärib	päri	pärima	27_V	IndPrSg3	et	pärib =päri  (IndPrSg3  >pärima !27_V
37885	kivikirst	kirst	kivi+kirst	22_S	SgN	et	kivikirst =kirst  (SgN  >kivi+kirst !22_S
37895	valmistasime	valmista	valmistama	27_V	IndIpfPl1	et	valmistasime =valmista  (IndIpfPl1  >valmistama !27_V
37900	pirukatega	piruka	pirukas	02_S	PlKom	et	pirukatega =piruka  (PlKom  >pirukas !02_S
37905	kooliõppimise	õppimise	kooli+õppimine	12_S	SgG	et	kooliõppimise =õppimise  (SgG  >kooli+õppimine !12_S
37908	intervjuule	intervjuu	intervjuu	26_S	SgAll	et	intervjuule =intervjuu  (SgAll  >intervjuu !26_S
37911	postimehes	mehe	posti+mees	13_S	SgIn	et	postimehes =mehe  (SgIn  >posti+mees !13_S
37915	tammesaar	saar	tamme+saar	13_S	SgN	et	tammesaar =saar  (SgN  >tamme+saar !13_S
37916	venekell	kell	vene+kell	22_S	SgN	et	venekell =kell  (SgN  >vene+kell !22_S
37926	müügiesindajana	esindaja	müügi+esindaja	01_S	SgEs	et	müügiesindajana =esindaja  (SgEs  >müügi+esindaja !01_S
37940	registraatori	registraatori	registraator	02_S	SgG	et	registraatori =registraatori  (SgG  >registraator !02_S
37950	väärtpabereid	pabere	väärt+paber	02_S	PlP	et	väärtpabereid =pabere  (PlP  >väärt+paber !02_S
37951	lähtudes	lähtu	lähtuma	27_V	Ger	et	lähtudes =lähtu  (Ger  >lähtuma !27_V
37954	omandi	omandi	omand	02_S	SgG	et	omandi =omandi  (SgG  >omand !02_S
37955	igasugustest	sugus	iga+sugune	10_A	PlEl	et	igasugustest =sugus  (PlEl  >iga+sugune !10_A
37965	alljärgneva	järgneva	all+järgnev	02_A	SgG	et	alljärgneva =järgneva  (SgG  >all+järgnev !02_A
37977	neitsisaarte	saar	neitsi+saar	13_S	PlG	et	neitsisaarte =saar  (PlG  >neitsi+saar !13_S
37978	registrisse	registri	register	02_S	SgIll	et	registrisse =registri  (SgIll  >register !02_S
37979	korporatsiooniküsimustega	küsimus	korporatsiooni+küsimus	11_S	PlKom	et	korporatsiooniküsimustega =küsimus  (PlKom  >korporatsiooni+küsimus !11_S
37987	allajärgnevates	järgneva	alla+järgnev	02_A	PlIn	et	allajärgnevates =järgneva  (PlIn  >alla+järgnev !02_A
37989	numbriga	numbri	number	02_S	SgKom	et	numbriga =numbri  (SgKom  >number !02_S
37991	kohustab	kohusta	kohustama	27_V	IndPrSg3	et	kohustab =kohusta  (IndPrSg3  >kohustama !27_V
38002	omand	omand	omand	02_S	SgN	et	omand =omand  (SgN  >omand !02_S
38005	tüüp	tüüp	tüüp	22_S	SgN	et	tüüp =tüüp  (SgN  >tüüp !22_S
38006	pakasel	pakase	pakane	10_S	SgAd	et	pakasel =pakase  (SgAd  >pakane !10_S
38008	kommunaaltöötajad	töötaja	kommunaal+töötaja	01_S	PlN	et	kommunaaltöötajad =töötaja  (PlN  >kommunaal+töötaja !01_S
38010	teedele	tee	tee	26_S	PlAll	et	teedele =tee  (PlAll  >tee !26_S
38013	hoove	hoove	hoov	22_S	PlP	et	hoove =hoove  (PlP  >hoov !22_S
38015	raekülas	küla	rae+küla	17_S	SgIn	et	raekülas =küla  (SgIn  >rae+küla !17_S
38016	õhule	õhu	õhk	22_S	SgAll	et	õhule =õhu  (SgAll  >õhk !22_S
38017	suusatada	suusata	suusatama	27_V	Inf	et	suusatada =suusata  (Inf  >suusatama !27_V
38023	turneel	turnee	turnee	26_S	SgAd	et	turneel =turnee  (SgAd  >turnee !26_S
38025	27veebruaril	veebruari	veebruar	19_S	SgAd	et	veebruaril =veebruari  (SgAd  >veebruar !19_S
38029	fännide	fänni	fänn	22_S	PlG	et	fännide =fänni  (PlG  >fänn !22_S
38031	asendas	asenda	asendama	27_V	IndIpfSg3	et	asendas =asenda  (IndIpfSg3  >asendama !27_V
38036	publikul	publiku	publik	02_S	SgAd	et	publikul =publiku  (SgAd  >publik !02_S
38037	vokalistiga	vokalisti	vokalist	22_S	SgKom	et	vokalistiga =vokalisti  (SgKom  >vokalist !22_S
38044	emajõe	jõe	ema+jõgi	21_S	SgG	et	emajõe =jõe  (SgG  >ema+jõgi !21_S
38048	mainiti	maini	mainima	28_V	IndIpfIps	et	mainiti =maini  (IndIpfIps  >mainima !28_V
38053	ülikoolilinn	linn	üli+kooli+linn	22_S	SgN	et	ülikoolilinn =linn  (SgN  >üli+kooli+linn !22_S
38063	leiutisteta	leiutis	leiutis	11_S	PlAb	et	leiutisteta =leiutis  (PlAb  >leiutis !11_S
38066	sekundit	sekundi	sekund	02_S	SgP	et	sekundit =sekundi  (SgP  >sekund !02_S
38067	kõnesid	kõne	kõne	16_S	PlP	et	kõnesid =kõne  (PlP  >kõne !16_S
37837	kaanoni	kaanoni	kaanon	02_S	SgG	et	kaanoni =kaanoni  (SgG  >kaanon !02_S
37838	piibliga	piibli	piibel	02_S	SgKom	et	piibliga =piibli  (SgKom  >piibel !02_S
37841	liigitada	liigita	liigitama	27_V	Inf	et	liigitada =liigita  (Inf  >liigitama !27_V
37849	minevikuihaldus	ihaldus	mineviku+ihaldus	11_S	SgN	et	minevikuihaldus =ihaldus  (SgN  >mineviku+ihaldus !11_S
37850	rahvussotsialism	sotsialism	rahvus+sotsialism	22_S	SgN	et	rahvussotsialism =sotsialism  (SgN  >rahvus+sotsialism !22_S
37851	linateostes	teos	lina+teos	09_S	PlIn	et	linateostes =teos  (PlIn  >lina+teos !09_S
37852	minevikuvarjud	varju	mineviku+vari	24_S	PlN	et	minevikuvarjud =varju  (PlN  >mineviku+vari !24_S
37853	jälitama	jälita	jälitama	27_V	Sup	et	jälitama =jälita  (Sup  >jälitama !27_V
37854	lepitamas	lepita	lepitama	27_V	SupIn	et	lepitamas =lepita  (SupIn  >lepitama !27_V
37860	lastelapsed	lapse	laste+laps	14_S	PlN	et	lastelapsed =lapse  (PlN  >laste+laps !14_S
37863	terrori	terrori	terror	02_S	SgG	et	terrori =terrori  (SgG  >terror !02_S
37872	lõunas	lõuna	lõuna	06_S	SgIn	et	lõunas =lõuna  (SgIn  >lõuna !06_S
37876	kultuurtaimed	taime	kultuur+taim	22_S	PlN	et	kultuurtaimed =taime  (PlN  >kultuur+taim !22_S
37878	mulk	mulk	mulk	22_S	SgN	et	mulk =mulk  (SgN  >mulk !22_S
37886	kaaned	kaane	kaas	14_S	PlN	et	kaaned =kaane  (PlN  >kaas !14_S
37892	hommikusöögiks	söögi	hommiku+söök	22_S	SgTr	et	hommikusöögiks =söögi  (SgTr  >hommiku+söök !22_S
37894	elutoas	toa	elu+tuba	18_S	SgIn	et	elutoas =toa  (SgIn  >elu+tuba !18_S
37896	lihaga	liha	liha	17_S	SgKom	et	lihaga =liha  (SgKom  >liha !17_S
37897	ajasime	aja	ajama	27_V	IndIpfPl1	et	ajasime =aja  (IndIpfPl1  >ajama !27_V
37899	suitsukalasalatit	salati	suitsu+kala+salat	02_S	SgP	et	suitsukalasalatit =salati  (SgP  >suitsu+kala+salat !02_S
37902	uinusin	uinu	uinuma	27_V	IndIpfSg1	et	uinusin =uinu  (IndIpfSg1  >uinuma !27_V
37904	valdan	valda	valdama	29_V	IndPrSg1	et	valdan =valda  (IndPrSg1  >valdama !29_V
37906	kooliajalehes	lehe	kooli+aja+leht	22_S	SgIn	et	kooliajalehes =lehe  (SgIn  >kooli+aja+leht !22_S
37919	lisakursustel	kursus	lisa+kursus	11~09_S	PlAd	et	lisakursustel =kursus  (PlAd  >lisa+kursus !11~09_S
37920	meeskonnatööga	töö	mees+konna+töö	26_S	SgKom	et	meeskonnatööga =töö  (SgKom  >mees+konna+töö !26_S
37921	tammsaar	saar	tamm+saar	13_S	SgN	et	tammsaar =saar  (SgN  >tamm+saar !13_S
37922	esitata	esita	esitama	27_V	IndPrIps_	et	esitata =esita  (IndPrIps_  >esitama !27_V
37925	müügiesindajale	esindaja	müügi+esindaja	01_S	SgAll	et	müügiesindajale =esindaja  (SgAll  >müügi+esindaja !01_S
37927	spordikaupluses	kaupluse	spordi+kauplus	11~09_S	SgIn	et	spordikaupluses =kaupluse  (SgIn  >spordi+kauplus !11~09_S
37928	oman	oma	omama	27_V	IndPrSg1	et	oman =oma  (IndPrSg1  >omama !27_V
37932	töövorm	vorm	töö+vorm	22_S	SgN	et	töövorm =vorm  (SgN  >töö+vorm !22_S
37934	kandidatuur	kandidatuur	kandidatuur	22_S	SgN	et	kandidatuur =kandidatuur  (SgN  >kandidatuur !22_S
37938	seadusandlusega	andluse	seadus+andlus	11~09_S	SgKom	et	seadusandlusega =andluse  (SgKom  >seadus+andlus !11~09_S
37948	virgini	virgi	virk	22_A	SgTer	et	virgini =virgi  (SgTer  >virk !22_A
37960	põhikiri	kiri	põhi+kiri	24_S	SgN	et	põhikiri =kiri  (SgN  >põhi+kiri !24_S
37961	väärtpaberite	paberi	väärt+paber	02_S	PlG	et	väärtpaberite =paberi  (PlG  >väärt+paber !02_S
37964	põhikirjaga	kirja	põhi+kiri	24_S	SgKom	et	põhikirjaga =kirja  (SgKom  >põhi+kiri !24_S
37968	lepingule	lepingu	leping	02_S	SgAll	et	lepingule =lepingu  (SgAll  >leping !02_S
37969	lepinguga	lepingu	leping	02_S	SgKom	et	lepinguga =lepingu  (SgKom  >leping !02_S
37972	tasuma	tasu	tasuma	27_V	Sup	et	tasuma =tasu  (Sup  >tasuma !27_V
37994	25detsembril	detsembri	detsember	02_S	SgAd	et	detsembril =detsembri  (SgAd  >detsember !02_S
37999	aktsiaid	aktsia	aktsia	01_S	PlP	et	aktsiaid =aktsia  (PlP  >aktsia !01_S
38004	alltoodud	toodu	all+toodu	01_S	PlN	et	alltoodud =toodu  (PlN  >all+toodu !01_S
38011	kojamehed	mehe	koja+mees	13_S	PlN	et	kojamehed =mehe  (PlN  >koja+mees !13_S
38012	eramajade	maja	era+maja	17_S	PlG	et	eramajade =maja  (PlG  >era+maja !17_S
38018	suudadki	suuda	suutma	34_V	IndPrSg2^	et	suudadki =suuda  (IndPrSg2^  >suutma !34_V
38024	linnasid	linna	linn	22_S	PlP	et	linnasid =linna  (PlP  >linn !22_S
38026	lavale	lava	lava	17_S	SgAll	et	lavale =lava  (SgAll  >lava !17_S
38027	vokalist	vokalist	vokalist	22_S	SgN	et	vokalist =vokalist  (SgN  >vokalist !22_S
38034	albumilt	albumi	album	02_S	SgAbl	et	albumilt =albumi  (SgAbl  >album !02_S
38035	look	look	look	22_S	SgN	et	look =look  (SgN  >look !22_S
38051	puhkamas	puhka	puhkama	29_V	SupIn	et	puhkamas =puhka  (SupIn  >puhkama !29_V
38052	armastaks	armasta	armastama	27_V	KndPrPs	et	armastaks =armasta  (KndPrPs  >armastama !27_V
38065	säästab	säästa	säästma	34_V	IndPrSg3	et	säästab =säästa  (IndPrSg3  >säästma !34_V
38055	varasid	vara	vara	17_S	PlP	et	varasid =vara  (PlP  >vara !17_S
38059	raamatupidamise	pidamise	raamatu+pidamine	12_S	SgG	et	raamatupidamise =pidamise  (SgG  >raamatu+pidamine !12_S
38061	haridussüsteemis	süsteemi	haridus+süsteem	22_S	SgIn	et	haridussüsteemis =süsteemi  (SgIn  >haridus+süsteem !22_S
38071	kuritegijate	tegija	kuri+tegija	01_S	PlG	et	kuritegijate =tegija  (PlG  >kuri+tegija !01_S
38073	hindan	hinda	hindama	29_V	IndPrSg1	et	hindan =hinda  (IndPrSg1  >hindama !29_V
38074	mänguasjad	asja	mängu+asi	24_S	PlN	et	mänguasjad =asja  (PlN  >mängu+asi !24_S
38078	harus	haru	haru	17_S	SgIn	et	harus =haru  (SgIn  >haru !17_S
38083	meditsiin	meditsiin	meditsiin	22_S	SgN	et	meditsiin =meditsiin  (SgN  >meditsiin !22_S
38090	turvasüsteem	süsteem	turva+süsteem	22_S	SgN	et	turvasüsteem =süsteem  (SgN  >turva+süsteem !22_S
38097	kauaaegsed	aegse	kaua+aegne	02_A	PlN	et	kauaaegsed =aegse  (PlN  >kaua+aegne !02_A
38102	väljatuleks	tule	välja+tuli	20_S	SgTr	et	väljatuleks =tule  (SgTr  >välja+tuli !20_S
38109	treeningut	treeningu	treening	02_S	SgP	et	treeningut =treeningu  (SgP  >treening !02_S
38111	keskkonnasõbralik	sõbralik	kesk+konna+sõbralik	25_A	SgN	et	keskkonnasõbralik =sõbralik  (SgN  >kesk+konna+sõbralik !25_A
38116	vägisi	vägisi	vägisi	41_D	ID	et	vägisi =vägisi  (ID  >vägisi !41_D
38123	lakooniline	lakooniline	lakooniline	12_A	SgN	et	lakooniline =lakooniline  (SgN  >lakooniline !12_A
38126	seadme	seadme	seade	05_S	SgG	et	seadme =seadme  (SgG  >seade !05_S
38130	kohtudes	kohtu	kohtuma	27_V	Ger	et	kohtudes =kohtu  (Ger  >kohtuma !27_V
38135	tööandjale	andja	töö+andja	01_S	SgAll	et	tööandjale =andja  (SgAll  >töö+andja !01_S
38159	plastik	plastik	plastik	02_S	SgN	et	plastik =plastik  (SgN  >plastik !02_S
38164	lõhnab	lõhna	lõhnama	29_V	IndPrSg3	et	lõhnab =lõhna  (IndPrSg3  >lõhnama !29_V
38165	mugava	mugava	mugav	02_A	SgG	et	mugava =mugava  (SgG  >mugav !02_A
38171	käterätikud	rätiku	käte+rätik	02_S	PlN	et	käterätikud =rätiku  (PlN  >käte+rätik !02_S
38177	kättesaadavas	saadava	kätte+saadav	02_A	SgIn	et	kättesaadavas =saadava  (SgIn  >kätte+saadav !02_A
38180	liustikud	liustiku	liustik	25_S	PlN	et	liustikud =liustiku  (PlN  >liustik !25_S
38188	õppeprotsess	protsess	õppe+protsess	22_S	SgN	et	õppeprotsess =protsess  (SgN  >õppe+protsess !22_S
38190	väljakutsuvat	kutsuva	välja+kutsuv	02_A	SgP	et	väljakutsuvat =kutsuva  (SgP  >välja+kutsuv !02_A
38193	edasiõppimiseelistustega	eelistus	edasi+õppimis+eelistus	11_S	PlKom	et	edasiõppimiseelistustega =eelistus  (PlKom  >edasi+õppimis+eelistus !11_S
38202	praktiseeris	praktiseeri	praktiseerima	28_V	IndIpfSg3	et	praktiseeris =praktiseeri  (IndIpfSg3  >praktiseerima !28_V
38206	eelkäiaks	käia	eel+käi	22_S	SgTr	et	eelkäiaks =käia  (SgTr  >eel+käi !22_S
38207	vajalikuks	vajaliku	vajalik	25_A	SgTr	et	vajalikuks =vajaliku  (SgTr  >vajalik !25_A
38209	õigusteaduskond	teaduskond	õigus+teaduskond	22_S	SgN	et	õigusteaduskond =teaduskond  (SgN  >õigus+teaduskond !22_S
38210	arstiteaduskond	teaduskond	arsti+teaduskond	22_S	SgN	et	arstiteaduskond =teaduskond  (SgN  >arsti+teaduskond !22_S
38217	rootsist	rootsi	roots	22_S	SgEl	et	rootsist =rootsi  (SgEl  >roots !22_S
38233	rätsepad	rätsepa	rätsep	02_S	PlN	et	rätsepad =rätsepa  (PlN  >rätsep !02_S
38241	palga	palga	palk	22_S	SgG	et	palga =palga  (SgG  >palk !22_S
38248	linnaelanike	elanike	linna+elanik	25_S	PlG	et	linnaelanike =elanike  (PlG  >linna+elanik !25_S
38251	riiste	riiste	riist	22_S	PlP	et	riiste =riiste  (PlP  >riist !22_S
38263	iseseisvumisele	seisvumise	ise+seisvumine	12_S	SgAll	et	iseseisvumisele =seisvumise  (SgAll  >ise+seisvumine !12_S
38268	koosolekul	oleku	koos+olek	02_S	SgAd	et	koosolekul =oleku  (SgAd  >koos+olek !02_S
38285	vendlust	vendlus	vendlus	11~09_S	SgP	et	vendlust =vendlus  (SgP  >vendlus !11~09_S
38288	matuste	matus	matus	09_S	PlG	et	matuste =matus  (PlG  >matus !09_S
38289	ube	ube	uba	18_S	PlP	et	ube =ube  (PlP  >uba !18_S
38291	juuakse	juu	jooma	38_V	IndPrIps	et	juuakse =juu  (IndPrIps  >jooma !38_V
38295	surmasümbol	sümbol	surma+sümbol	02_S	SgN	et	surmasümbol =sümbol  (SgN  >surma+sümbol !02_S
38310	millelt	mille	mis	00_P	SgAbl	et	millelt =mille  (SgAbl  >mis !00_P
38314	merevaigul	vaigu	mere+vaik	22_S	SgAd	et	merevaigul =vaigu  (SgAd  >mere+vaik !22_S
38320	põhjusega	põhjuse	põhjus	11~09_S	SgKom	et	põhjusega =põhjuse  (SgKom  >põhjus !11~09_S
38329	muinasinimesed	inimese	muinas+inimene	12_S	PlN	et	muinasinimesed =inimese  (PlN  >muinas+inimene !12_S
38338	viimaseks	viimase	viimane	10_A	SgTr	et	viimaseks =viimase  (SgTr  >viimane !10_A
38339	ajani	aja	aeg	22_S	SgTer	et	ajani =aja  (SgTer  >aeg !22_S
38341	homsest	homse	homne	02_A	SgEl	et	homsest =homse  (SgEl  >homne !02_A
38344	pidur	pidur	pidur	02_S	SgN	et	pidur =pidur  (SgN  >pidur !02_S
38349	kirjutamisoskused	oskuse	kirjutamis+oskus	11~09_S	PlN	et	kirjutamisoskused =oskuse  (PlN  >kirjutamis+oskus !11~09_S
38068	elektriseadmeid	seadme	elektri+seade	05_S	PlP	et	elektriseadmeid =seadme  (PlP  >elektri+seade !05_S
38069	hoiavad	hoia	hoidma	34_V	IndPrPl3	et	hoiavad =hoia  (IndPrPl3  >hoidma !34_V
38082	meditsiinist	meditsiini	meditsiin	22_S	SgEl	et	meditsiinist =meditsiini  (SgEl  >meditsiin !22_S
38084	headega	hea	hea	26_AS	PlKom	et	headega =hea  (PlKom  >hea !26_AS
38093	bmw-s	bmw	bmw	xx_Q	SgIn	et	bmw-s =bmw  (SgIn  >bmw !xx_Q
38094	istmed	istme	iste	05_S	PlN	et	istmed =istme  (PlN  >iste !05_S
38096	firmal	firma	firma	16_S	SgAd	et	firmal =firma  (SgAd  >firma !16_S
38098	kliendid	kliendi	klient	22_S	PlN	et	kliendid =kliendi  (PlN  >klient !22_S
38100	positsioon	positsioon	positsioon	22_S	SgN	et	positsioon =positsioon  (SgN  >positsioon !22_S
38101	siseturul	turu	sise+turg	22_S	SgAd	et	siseturul =turu  (SgAd  >sise+turg !22_S
38106	jalgrattas	ratta	jalg+ratas	07_S	SgIn	et	jalgrattas =ratta  (SgIn  >jalg+ratas !07_S
38107	füüsilises	füüsilise	füüsiline	12_A	SgIn	et	füüsilises =füüsilise  (SgIn  >füüsiline !12_A
38110	koormused	koormuse	koormus	11~09_S	PlN	et	koormused =koormuse  (PlN  >koormus !11~09_S
38112	depressioonis	depressiooni	depressioon	22_S	SgIn	et	depressioonis =depressiooni  (SgIn  >depressioon !22_S
38114	narkootikumide	narkootikumi	narkootikum	19_S	PlG	et	narkootikumide =narkootikumi  (PlG  >narkootikum !19_S
38121	roti	roti	rott	22_S	SgG	et	roti =roti  (SgG  >rott !22_S
38127	kukkuda	kukku	kukkuma	28_V	Inf	et	kukkuda =kukku  (Inf  >kukkuma !28_V
38134	juhtme	juhtme	juhe	05_S	SgG	et	juhtme =juhtme  (SgG  >juhe !05_S
38136	töötage	tööta	töötama	27_V	ImpPrPl2	et	töötage =tööta  (ImpPrPl2  >töötama !27_V
38137	elektrimasin	masin	elektri+masin	02_S	SgN	et	elektrimasin =masin  (SgN  >elektri+masin !02_S
38138	masin	masin	masin	02_S	SgN	et	masin =masin  (SgN  >masin !02_S
38140	andurid	anduri	andur	02_S	PlN	et	andurid =anduri  (PlN  >andur !02_S
38142	töökal	tööka	töökas	02_A	SgAd	et	töökal =tööka  (SgAd  >töökas !02_A
38155	lärmiga	lärmi	lärm	22_S	SgKom	et	lärmiga =lärmi  (SgKom  >lärm !22_S
38174	baktereid	baktere	bakter	02_S	PlP	et	baktereid =baktere  (PlP  >bakter !02_S
38178	väidan	väida	väitma	34_V	IndPrSg1	et	väidan =väida  (IndPrSg1  >väitma !34_V
38179	kodukeemial	keemia	kodu+keemia	01_S	SgAd	et	kodukeemial =keemia  (SgAd  >kodu+keemia !01_S
38181	merevee	vee	mere+vesi	15_S	SgG	et	merevee =vee  (SgG  >mere+vesi !15_S
38182	äärmuslik	äärmuslik	äärmuslik	25_A	SgN	et	äärmuslik =äärmuslik  (SgN  >äärmuslik !25_A
38184	põud	põud	põud	22_S	SgN	et	põud =põud  (SgN  >põud !22_S
38185	kliimat	kliima	kliima	16_S	SgP	et	kliimat =kliima  (SgP  >kliima !16_S
38196	läbiviimist	viimis	läbi+viimine	12?10_S	SgP	et	läbiviimist =viimis  (SgP  >läbi+viimine !12?10_S
38197	maasikad	maasika	maasikas	02_S	PlN	et	maasikad =maasika  (PlN  >maasikas !02_S
38204	jesuiitide	jesuiiti	jesuiit	22_S	PlG	et	jesuiitide =jesuiiti  (PlG  >jesuiit !22_S
38211	usuteaduskond	teaduskond	usu+teaduskond	22_S	SgN	et	usuteaduskond =teaduskond  (SgN  >usu+teaduskond !22_S
38213	üliõpilasel	õpilase	üli+õpilane	12_S	SgAd	et	üliõpilasel =õpilase  (SgAd  >üli+õpilane !12_S
38214	ainetes	aine	aine	06_S	PlIn	et	ainetes =aine  (PlIn  >aine !06_S
38219	ühistoidul	toidu	ühis+toit	22_S	SgAd	et	ühistoidul =toidu  (SgAd  >ühis+toit !22_S
38220	stipendiume	stipendiume	stipendium	19_S	PlP	et	stipendiume =stipendiume  (PlP  >stipendium !19_S
38221	noorim	noori	noor	13_AS	IM_sA	et	"noorim %noori  )IM_sA  <noor ;13_AS
38222	kunstistiiliks	stiili	kunsti+stiil	22_S	SgTr	et	kunstistiiliks =stiili  (SgTr  >kunsti+stiil !22_S
38224	kivisild	sild	kivi+sild	22_S	SgN	et	kivisild =sild  (SgN  >kivi+sild !22_S
38226	ülistama	ülista	ülistama	27_V	Sup	et	ülistama =ülista  (Sup  >ülistama !27_V
38232	kanepit	kanepi	kanep	02_S	SgP	et	kanepit =kanepi  (SgP  >kanep !02_S
38235	kanga	kanga	kangas	07_S	SgG	et	kanga =kanga  (SgG  >kangas !07_S
38237	tekstiil	tekstiil	tekstiil	22_S	SgN	et	tekstiil =tekstiil  (SgN  >tekstiil !22_S
38247	väljaostmine	ostmine	välja+ostmine	12?10_S	SgN	et	väljaostmine =ostmine  (SgN  >välja+ostmine !12?10_S
38249	rätsepaks	rätsepa	rätsep	02_S	SgTr	et	rätsepaks =rätsepa  (SgTr  >rätsep !02_S
38250	postsepaks	sepa	post+sepp	22_S	SgTr	et	postsepaks =sepa  (SgTr  >post+sepp !22_S
38252	tööpuudus	puudus	töö+puudus	11~09_S	SgN	et	tööpuudus =puudus  (SgN  >töö+puudus !11~09_S
38269	visandid	visandi	visand	02_S	PlN	et	visandid =visandi  (PlN  >visand !02_S
38272	papaks	papa	papa	16_S	SgTr	et	papaks =papa  (SgTr  >papa !16_S
38286	austati	austa	austama	27_V	IndIpfIps	et	austati =austa  (IndIpfIps  >austama !27_V
38287	põletusmatused	matuse	põletus+matus	09_S	PlN	et	põletusmatused =matuse  (PlN  >põletus+matus !09_S
38292	allikavett	ve	allika+vesi	15_S	SgP	et	allikavett =ve  (SgP  >allika+vesi !15_S
38070	kuritegijat	tegija	kuri+tegija	01_S	SgP	et	kuritegijat =tegija  (SgP  >kuri+tegija !01_S
38077	kasum	kasum	kasum	02_S	SgN	et	kasum =kasum  (SgN  >kasum !02_S
38086	säilitatakse	säilita	säilitama	27_V	IndPrIps	et	säilitatakse =säilita  (IndPrIps  >säilitama !27_V
38087	köögielektriseadmeid	seadme	köögi+elektri+seade	05_S	PlP	et	köögielektriseadmeid =seadme  (PlP  >köögi+elektri+seade !05_S
38092	vanglat	vangla	vangla	01_S	SgP	et	vanglat =vangla  (SgP  >vangla !01_S
38095	kvalifikatsiooniga	kvalifikatsiooni	kvalifikatsioon	22_S	SgKom	et	kvalifikatsiooniga =kvalifikatsiooni  (SgKom  >kvalifikatsioon !22_S
38104	füüsilised	füüsilise	füüsiline	12_A	PlN	et	füüsilised =füüsilise  (PlN  >füüsiline !12_A
38108	nõuda	nõud	nõudma	34_V	Inf	et	nõuda =nõud  (Inf  >nõudma !34_V
38113	sekkuma	sekku	sekkuma	27_V	Sup	et	sekkuma =sekku  (Sup  >sekkuma !27_V
38117	pikkalt	alt	pikk+alt	22_S	SgN	et	pikkalt =alt  (SgN  >pikk+alt !22_S
38118	vakke	vakke	vakk	22_S	PlP	et	vakke =vakke  (PlP  >vakk !22_S
38119	valid	vali	valima	27_V	IndPrSg2	et	valid =vali  (IndPrSg2  >valima !27_V
38120	fraase	fraase	fraas	22_S	PlP	et	fraase =fraase  (PlP  >fraas !22_S
38132	tõmmake	tõmma	tõmbama	29_V	ImpPrPl2	et	tõmmake =tõmma  (ImpPrPl2  >tõmbama !29_V
38147	riskiaeg	aeg	riski+aeg	22_S	SgN	et	riskiaeg =aeg  (SgN  >riski+aeg !22_S
38148	spordiriietus	riietus	spordi+riietus	11_S	SgN	et	spordiriietus =riietus  (SgN  >spordi+riietus !11_S
38154	käraga	kära	kära	17_S	SgKom	et	käraga =kära  (SgKom  >kära !17_S
38157	kisaga	kisa	kisa	17_S	SgKom	et	kisaga =kisa  (SgKom  >kisa !17_S
38160	korteriuhis	uhi	korteri+uhk	22_S	PlIn	et	korteriuhis =uhi  (PlIn  >korteri+uhk !22_S
38163	vahendit	vahendi	vahend	02_S	SgP	et	vahendit =vahendi  (SgP  >vahend !02_S
38166	kombates	komba	kompama	29_V	Ger	et	kombates =komba  (Ger  >kompama !29_V
38167	paljuerinevaid	erineva	palju+erinev	02_A	PlP	et	paljuerinevaid =erineva  (PlP  >palju+erinev !02_A
38169	plaate	plaate	plaat	22_S	PlP	et	plaate =plaate  (PlP  >plaat !22_S
38172	poleerida	poleeri	poleerima	28_V	Inf	et	poleerida =poleeri  (Inf  >poleerima !28_V
38175	keemiavahendid	vahendi	keemia+vahend	02_S	PlN	et	keemiavahendid =vahendi  (PlN  >keemia+vahend !02_S
38176	juhendi	juhendi	juhend	02_S	SgG	et	juhendi =juhendi  (SgG  >juhend !02_S
38183	tormid	tormi	torm	22_SA	PlN	et	tormid =tormi  (PlN  >torm !22_SA
38187	ootate	oota	ootama	29_V	IndPrPl2	et	ootate =oota  (IndPrPl2  >ootama !29_V
38200	aitasin	aita	aitama	29_V	IndIpfSg1	et	aitasin =aita  (IndIpfSg1  >aitama !29_V
38201	laagris	laagri	laager	02_S	SgIn	et	laagris =laagri  (SgIn  >laager !02_S
38208	provintsides	provintsi	provints	22_S	PlIn	et	provintsides =provintsi  (PlIn  >provints !22_S
38216	linnakodanikud	kodaniku	linna+kodanik	25_S	PlN	et	linnakodanikud =kodaniku  (PlN  >linna+kodanik !25_S
38223	barokk	barokk	barokk	22_S	SgN	et	barokk =barokk  (SgN  >barokk !22_S
38225	romantism	romantism	romantism	22_S	SgN	et	romantism =romantism  (SgN  >romantism !22_S
38256	alade	ala	ala	17_S	PlG	et	alade =ala  (PlG  >ala !17_S
38257	perioodiks	perioodi	periood	22_S	SgTr	et	perioodiks =perioodi  (SgTr  >periood !22_S
38258	talurahvaseadused	seaduse	talu+rahva+seadus	11~09_S	PlN	et	talurahvaseadused =seaduse  (PlN  >talu+rahva+seadus !11~09_S
38259	haridusolud	olu	haridus+olu	17_S	PlN	et	haridusolud =olu  (PlN  >haridus+olu !17_S
38260	rahvakoolide	kooli	rahva+kool	22_S	PlG	et	rahvakoolide =kooli  (PlG  >rahva+kool !22_S
38265	ajastul	ajastu	ajastu	01_S	SgAd	et	ajastul =ajastu  (SgAd  >ajastu !01_S
38267	veskit	veski	veski	01_S	SgP	et	veskit =veski  (SgP  >veski !01_S
38275	säärane	säärane	säärane	10_P	SgN	et	säärane =säärane  (SgN  >säärane !10_P
38277	reformidega	reformi	reform	22_S	PlKom	et	reformidega =reformi  (PlKom  >reform !22_S
38278	tekkiski	tekki	tekkima	27~28_V	IndIpfSg3^	et	tekkiski =tekki  (IndIpfSg3^  >tekkima !27~28_V
38281	keelemehed	mehe	keele+mees	13_S	PlN	et	keelemehed =mehe  (PlN  >keele+mees !13_S
38282	sajandile	sajandi	sajand	02_S	SgAll	et	sajandile =sajandi  (SgAll  >sajand !02_S
38294	silmanägemise	nägemise	silma+nägemine	12_S	SgG	et	silmanägemise =nägemise  (SgG  >silma+nägemine !12_S
38296	haudasi	asi	haud+asi	24_S	SgN	et	haudasi =asi  (SgN  >haud+asi !24_S
38297	lõuna-eestist	eesti	lõuna-eesti	16_H	SgEl	et	lõuna-eestist =eesti  (SgEl  >lõuna-eesti !16_H
38299	mõnedel	mõne	mõni	20_P	PlAd	et	mõnedel =mõne  (PlAd  >mõni !20_P
38301	kanep	kanep	kanep	02_S	SgN	et	kanep =kanep  (SgN  >kanep !02_S
38304	väärtuslik	väärtuslik	väärtuslik	25_A	SgN	et	väärtuslik =väärtuslik  (SgN  >väärtuslik !25_A
38311	jooneks	joone	joon	13_S	SgTr	et	jooneks =joone  (SgTr  >joon !13_S
38335	pahatahtliku	tahtliku	paha+tahtlik	25_A	SgG	et	pahatahtliku =tahtliku  (SgG  >paha+tahtlik !25_A
38072	kvaliteetset	kvaliteetse	kvaliteetne	02_A	SgP	et	kvaliteetset =kvaliteetse  (SgP  >kvaliteetne !02_A
38075	konkurentsist	konkurentsi	konkurents	22_S	SgEl	et	konkurentsist =konkurentsi  (SgEl  >konkurents !22_S
38076	käive	käive	käive	06_S	SgN	et	käive =käive  (SgN  >käive !06_S
38079	põdeda	põde	põdema	28_V	Inf	et	põdeda =põde  (Inf  >põdema !28_V
38088	mikser	mikser	mikser	02_S	SgN	et	mikser =mikser  (SgN  >mikser !02_S
38089	elektriseadmed	seadme	elektri+seade	05_S	PlN	et	elektriseadmed =seadme  (PlN  >elektri+seade !05_S
38115	kallaletung	tung	kallale+tung	22_S	SgN	et	kallaletung =tung  (SgN  >kallale+tung !22_S
38122	intervjuul	intervjuu	intervjuu	26_S	SgAd	et	intervjuul =intervjuu  (SgAd  >intervjuu !26_S
38125	semestril	semestri	semester	02_S	SgAd	et	semestril =semestri  (SgAd  >semester !02_S
38129	vältige	välti	vältima	28_V	ImpPrPl2	et	vältige =välti  (ImpPrPl2  >vältima !28_V
38143	tööandjad	andja	töö+andja	01_S	PlN	et	tööandjad =andja  (PlN  >töö+andja !01_S
38146	tänavalis	alis	tänav+alis	09_S	SgN	et	tänavalis =alis  (SgN  >tänav+alis !09_S
38149	naudib	naudi	nautima	28_V	IndPrSg3	et	naudib =naudi  (IndPrSg3  >nautima !28_V
38151	läbiviimine	viimine	läbi+viimine	12?10_S	SgN	et	läbiviimine =viimine  (SgN  >läbi+viimine !12?10_S
38152	meelitame	meelita	meelitama	27_V	IndPrPl1	et	meelitame =meelita  (IndPrPl1  >meelitama !27_V
38153	looduseprobleemidest	probleemi	looduse+probleem	22_S	PlEl	et	looduseprobleemidest =probleemi  (PlEl  >looduse+probleem !22_S
38156	müraga	müra	müra	17_S	SgKom	et	müraga =müra  (SgKom  >müra !17_S
38158	lõhuvad	lõhu	lõhkuma	28_V	IndPrPl3	et	lõhuvad =lõhu  (IndPrPl3  >lõhkuma !28_V
38170	kangaid	kanga	kangas	07_S	PlP	et	kangaid =kanga  (PlP  >kangas !07_S
38186	prognoositakse	prognoosi	prognoosima	28_V	IndPrIps	et	prognoositakse =prognoosi  (IndPrIps  >prognoosima !28_V
38191	kseroks	ksero	ksero	17~16_S	SgTr	et	kseroks =ksero  (SgTr  >ksero !17~16_S
38192	hobidele	hobi	hobi	17_S	PlAll	et	hobidele =hobi  (PlAll  >hobi !17_S
38194	kodakondsus	kodakondsus	kodakondsus	11~09_S	SgN	et	kodakondsus =kodakondsus  (SgN  >kodakondsus !11~09_S
38195	meigivahendeid	vahende	meigi+vahend	02_S	PlP	et	meigivahendeid =vahende  (PlP  >meigi+vahend !02_S
38198	rohima	rohi	rohima	27_V	Sup	et	rohima =rohi  (Sup  >rohima !27_V
38203	rahuolev	olev	rahu+olev	02_A	SgN	et	rahuolev =olev  (SgN  >rahu+olev !02_A
38215	eksamil	eksami	eksam	02_S	SgAd	et	eksamil =eksami  (SgAd  >eksam !02_S
38227	troonile	trooni	troon	22_S	SgAll	et	troonile =trooni  (SgAll  >troon !22_S
38234	müürsepad	sepa	müür+sepp	22_S	PlN	et	müürsepad =sepa  (PlN  >müür+sepp !22_S
38236	sits	sits	sits	22_S	SgN	et	sits =sits  (SgN  >sits !22_S
38242	rektori	rektori	rektor	02_S	SgG	et	rektori =rektori  (SgG  >rektor !02_S
38246	jõukad	jõuka	jõukas	02_A	PlN	et	jõukad =jõuka  (PlN  >jõukas !02_A
38266	silmapaistvad	paistva	silma+paistev	02_A	PlN	et	silmapaistvad =paistva  (PlN  >silma+paistev !02_A
38271	ühislooming	looming	ühis+looming	02_S	SgN	et	ühislooming =looming  (SgN  >ühis+looming !02_S
38274	näidendi	näidendi	näidend	02_S	SgG	et	näidendi =näidendi  (SgG  >näidend !02_S
38280	allikal	allika	allikas	02_S	SgAd	et	allikal =allika  (SgAd  >allikas !02_S
38293	parandab	paranda	parandama	27_V	IndPrSg3	et	parandab =paranda  (IndPrSg3  >parandama !27_V
38298	usundist	usundi	usund	02_S	SgEl	et	usundist =usundi  (SgEl  >usund !02_S
38306	võrdub	võrdu	võrduma	27_V	IndPrSg3	et	võrdub =võrdu  (IndPrSg3  >võrduma !27_V
38312	matmispaikadelt	paika	matmis+paik	22_S	PlAbl	et	matmispaikadelt =paika  (PlAbl  >matmis+paik !22_S
38316	merevaigu	vaigu	mere+vaik	22_S	SgG	et	merevaigu =vaigu  (SgG  >mere+vaik !22_S
38317	jõu	jõu	jõud	22_S	SgG	et	jõu =jõu  (SgG  >jõud !22_S
38318	töövahendeid	vahende	töö+vahend	02_S	PlP	et	töövahendeid =vahende  (PlP  >töö+vahend !02_S
38319	loodusjõude	jõude	loodus+jõud	22_S	PlP	et	loodusjõude =jõude  (PlP  >loodus+jõud !22_S
38321	lugupidamisele	pidamise	lugu+pidamine	12_S	SgAll	et	lugupidamisele =pidamise  (SgAll  >lugu+pidamine !12_S
38322	religioonist	religiooni	religioon	22_S	SgEl	et	religioonist =religiooni  (SgEl  >religioon !22_S
38323	800-1030aa	aa	-aa	41_I	ID	et	-aa =aa  (ID  >-aa !41_I
38326	jõulude	jõulu	jõul	22_S	PlG	et	jõulude =jõulu  (PlG  >jõul !22_S
38331	kolmeväljasüsteem	süsteem	kolme+välja+süsteem	22_S	SgN	et	kolmeväljasüsteem =süsteem  (SgN  >kolme+välja+süsteem !22_S
38332	koosneski	koosne	koosnema	27_V	IndIpfSg3^	et	koosneski =koosne  (IndIpfSg3^  >koosnema !27_V
38337	kolmandale	kolmanda	kolmas	02_O	SgAll	et	kolmandale =kolmanda  (SgAll  >kolmas !02_O
38345	mõtte	mõtte	mõte	06_S	SgG	et	mõtte =mõtte  (SgG  >mõte !06_S
38346	abistada	abista	abistama	27_V	Inf	et	abistada =abista  (Inf  >abistama !27_V
38350	rokkstaar	staar	rokk+staar	22_S	SgN	et	rokkstaar =staar  (SgN  >rokk+staar !22_S
38099	firmale	firma	firma	16_S	SgAll	et	firmale =firma  (SgAll  >firma !16_S
38103	välisturgudele	turgu	välis+turg	22_S	PlAll	et	välisturgudele =turgu  (PlAll  >välis+turg !22_S
38105	treeningud	treeningu	treening	02_S	PlN	et	treeningud =treeningu  (PlN  >treening !02_S
38124	kevad-	kevad	kevad	02_S	SgN	et	kevad- =kevad  (SgN  >kevad !02_S
38128	juukse	juukse	juus	09_S	SgG	et	juukse =juukse  (SgG  >juus !09_S
38131	tuntuvat	tun	tundma	34_V	KvtPtIps	et	tuntuvat =tun  (KvtPtIps  >tundma !34_V
38133	stepsli	stepsli	stepsel	02_S	SgG	et	stepsli =stepsli  (SgG  >stepsel !02_S
38139	remondile	remondi	remont	22_S	SgAll	et	remondile =remondi  (SgAll  >remont !22_S
38141	minutis	minuti	minut	02_S	SgIn	et	minutis =minuti  (SgIn  >minut !02_S
38144	tulete	tule	tulema	36_V	IndPrPl2	et	tulete =tule  (IndPrPl2  >tulema !36_V
38145	väidavad	väida	väitma	34_V	IndPrPl3	et	väidavad =väida  (IndPrPl3  >väitma !34_V
38150	paigaldama	paigalda	paigaldama	27_V	Sup	et	paigaldama =paigalda  (Sup  >paigaldama !27_V
38161	puhastusvahendid	vahendi	puhastus+vahend	02_S	PlN	et	puhastusvahendid =vahendi  (PlN  >puhastus+vahend !02_S
38162	pesuvahendid	vahendi	pesu+vahend	02_S	PlN	et	pesuvahendid =vahendi  (PlN  >pesu+vahend !02_S
38168	vaipu	vaipu	vaip	22_S	PlP	et	vaipu =vaipu  (PlP  >vaip !22_S
38173	tugevdada	tugevda	tugevdama	27_V	Inf	et	tugevdada =tugevda  (Inf  >tugevdama !27_V
38189	koolivormiriietust	riietus	kooli+vormi+riietus	11_S	SgP	et	koolivormiriietust =riietus  (SgP  >kooli+vormi+riietus !11_S
38199	põllutöökogemust	kogemus	põllu+töö+kogemus	11_S	SgP	et	põllutöökogemust =kogemus  (SgP  >põllu+töö+kogemus !11_S
38205	koolitada	koolita	koolitama	27_V	Inf	et	koolitada =koolita  (Inf  >koolitama !27_V
38212	professorit	professori	professor	02_S	SgP	et	professorit =professori  (SgP  >professor !02_S
38218	diplom	diplom	diplom	02_S	SgN	et	diplom =diplom  (SgN  >diplom !02_S
38228	priiks	prii	prii	26_A	SgTr	et	priiks =prii  (SgTr  >prii !26_A
38229	laevanduse	laevanduse	laevandus	11_S	SgG	et	laevanduse =laevanduse  (SgG  >laevandus !11_S
38230	arenguga	arengu	areng	02_S	SgKom	et	arenguga =arengu  (SgKom  >areng !02_S
38231	vajati	vaja	vajama	27_V	IndIpfIps	et	vajati =vaja  (IndIpfIps  >vajama !27_V
38238	vabrik	vabrik	vabrik	02_S	SgN	et	vabrik =vabrik  (SgN  >vabrik !02_S
38239	paberivabrik	vabrik	paberi+vabrik	02_S	SgN	et	paberivabrik =vabrik  (SgN  >paberi+vabrik !02_S
38240	filosoofiat	filosoofia	filosoofia	01_S	SgP	et	filosoofiat =filosoofia  (SgP  >filosoofia !01_S
38243	lõuna-eestit	eesti	lõuna-eesti	16_H	SgP	et	lõuna-eestit =eesti  (SgP  >lõuna-eesti !16_H
38244	pukk	pukk	pukk	22_S	SgN	et	pukk =pukk  (SgN  >pukk !22_S
38245	rahateenimisvõimalus	võimalus	raha+teenimis+võimalus	11_S	SgN	et	rahateenimisvõimalus =võimalus  (SgN  >raha+teenimis+võimalus !11_S
38253	poodnikud	poodniku	poodnik	25_S	PlN	et	poodnikud =poodniku  (PlN  >poodnik !25_S
38254	postkontorid	kontori	post+kontor	02_S	PlN	et	postkontorid =kontori  (PlN  >post+kontor !02_S
38255	postijaamad	jaama	posti+jaam	22_S	PlN	et	postijaamad =jaama  (PlN  >posti+jaam !22_S
38261	kirikukoolid	kooli	kiriku+kool	22_S	PlN	et	kirikukoolid =kooli  (PlN  >kiriku+kool !22_S
38262	seminaris	seminari	seminar	19_S	SgIn	et	seminaris =seminari  (SgIn  >seminar !19_S
38264	iseseisvumise	seisvumise	ise+seisvumine	12_S	SgG	et	iseseisvumise =seisvumise  (SgG  >ise+seisvumine !12_S
38270	õpetliku	õpetliku	õpetlik	25_A	SgG	et	õpetliku =õpetliku  (SgG  >õpetlik !25_A
38273	lõpliku	lõpliku	lõplik	25_A	SgG	et	lõpliku =lõpliku  (SgG  >lõplik !25_A
38276	seostas	seosta	seostama	27_V	IndIpfSg3	et	seostas =seosta  (IndIpfSg3  >seostama !27_V
38279	edasiandmisel	andmise	edasi+andmine	12?10_S	SgAd	et	edasiandmisel =andmise  (SgAd  >edasi+andmine !12?10_S
38283	propageeris	propageeri	propageerima	28_V	IndIpfSg3	et	propageeris =propageeri  (IndIpfSg3  >propageerima !28_V
38284	sotsiaalset	sotsiaalse	sotsiaalne	02_A	SgP	et	sotsiaalset =sotsiaalse  (SgP  >sotsiaalne !02_A
38290	herneid	herne	hernes	07_S	PlP	et	herneid =herne  (PlP  >hernes !07_S
38300	kasvatada	kasvata	kasvatama	27_V	Inf	et	kasvatada =kasvata  (Inf  >kasvatama !27_V
38307	tõendeid	tõende	tõend	02_S	PlP	et	tõendeid =tõende  (PlP  >tõend !02_S
38315	toimedesse	toime	toim	22_S	PlIll	et	toimedesse =toime  (PlIll  >toim !22_S
38324	usuga	usu	usk	22_S	SgKom	et	usuga =usu  (SgKom  >usk !22_S
38325	matmispaik	paik	matmis+paik	22_S	SgN	et	matmispaik =paik  (SgN  >matmis+paik !22_S
38330	põlluharimine	harimine	põllu+harimine	12_S	SgN	et	põlluharimine =harimine  (SgN  >põllu+harimine !12_S
38333	linade	lina	lina	17_S	PlG	et	linade =lina  (PlG  >lina !17_S
38334	polütehnikumis	polütehnikumi	polütehnikum	19_S	SgIn	et	polütehnikumis =polütehnikumi  (SgIn  >polütehnikum !19_S
38351	passiivne	passiivne	passiivne	02_A	SgN	et	passiivne =passiivne  (SgN  >passiivne !02_A
38302	hirss	hirss	hirss	22_S	SgN	et	hirss =hirss  (SgN  >hirss !22_S
38303	tuder	tuder	tuder	24_S	SgN	et	tuder =tuder  (SgN  >tuder !24_S
38305	õlitaim	taim	õli+taim	22_S	SgN	et	õlitaim =taim  (SgN  >õli+taim !22_S
38308	leiud	leiu	leid	22_S	PlN	et	leiud =leiu  (PlN  >leid !22_S
38309	sirpe	sirpe	sirp	22_S	PlP	et	sirpe =sirpe  (PlP  >sirp !22_S
38313	kristlaste	kristlas	kristlane	12?10_S	PlG	et	kristlaste =kristlas  (PlG  >kristlane !12?10_S
38327	põllunduse	põllunduse	põllundus	11_S	SgG	et	põllunduse =põllunduse  (SgG  >põllundus !11_S
38328	tipphetk	hetk	tipp+hetk	22_S	SgN	et	tipphetk =hetk  (SgN  >tipp+hetk !22_S
38336	ebatäpse	täpse	eba+täpne	02_A	SgG	et	ebatäpse =täpse  (SgG  >eba+täpne !02_A
38340	planeerime	planeeri	planeerima	28_V	IndPrPl1	et	planeerime =planeeri  (IndPrPl1  >planeerima !28_V
38342	lähed	lähe	minema	36_V	IndPrSg2	et	lähed =lähe  (IndPrSg2  >minema !36_V
38343	autol	auto	auto	16_S	SgAd	et	autol =auto  (SgAd  >auto !16_S
38357	arendaks	arenda	arendama	27_V	KndPrPs	et	arendaks =arenda  (KndPrPs  >arendama !27_V
38363	ettevõtlikuks	võtliku	ette+võtlik	25_A	SgTr	et	ettevõtlikuks =võtliku  (SgTr  >ette+võtlik !25_A
38367	ankeete	ankeete	ankeet	22_S	PlP	et	ankeete =ankeete  (PlP  >ankeet !22_S
38379	eestlasega	eestlase	eestlane	12?10_S	SgKom	et	eestlasega =eestlase  (SgKom  >eestlane !12?10_S
38384	lätlane	lätlane	lätlane	12?10_S	SgN	et	lätlane =lätlane  (SgN  >lätlane !12?10_S
38387	õpe	õpe	õpe	06_S	SgN	et	õpe =õpe  (SgN  >õpe !06_S
38400	spordiväljak	väljak	spordi+väljak	02_S	SgN	et	spordiväljak =väljak  (SgN  >spordi+väljak !02_S
38405	sõnumitega	sõnumi	sõnum	02_S	PlKom	et	sõnumitega =sõnumi  (PlKom  >sõnum !02_S
38408	jäle	jäle	jäle	02_A	SgN	et	jäle =jäle  (SgN  >jäle !02_A
38416	allkirjutatud	kirjutatu	all+kirjutatu	01_S	PlN	et	allkirjutatud =kirjutatu  (PlN  >all+kirjutatu !01_S
38418	kaubandusleping	leping	kaubandus+leping	02_S	SgN	et	kaubandusleping =leping  (SgN  >kaubandus+leping !02_S
38428	tööstuskaupade	kaupa	tööstus+kaup	22_S	PlG	et	tööstuskaupade =kaupa  (PlG  >tööstus+kaup !22_S
38432	keskküte	küte	kesk+küte	06_S	SgN	et	keskküte =küte  (SgN  >kesk+küte !06_S
38434	peegelustega	us	peegel+uks	14_S	PlKom	et	peegelustega =us  (PlKom  >peegel+uks !14_S
38435	peegel	peegel	peegel	02_S	SgN	et	peegel =peegel  (SgN  >peegel !02_S
38436	vaas	vaas	vaas	22_S	SgN	et	vaas =vaas  (SgN  >vaas !22_S
38473	pingid	pingi	pink	22_S	PlN	et	pingid =pingi  (PlN  >pink !22_S
38477	üksest	ükse	üks	22_NP	PlEl	et	üksest =ükse  (PlEl  >üks !22_NP
38478	nagis	nagi	nagi	17_S	SgIn	et	nagis =nagi  (SgIn  >nagi !17_S
38481	vasak	vasak	vasak	02_A	SgN	et	vasak =vasak  (SgN  >vasak !02_A
38491	köögikapp	kapp	köögi+kapp	22_S	SgN	et	köögikapp =kapp  (SgN  >köögi+kapp !22_S
38495	teekann	kann	tee+kann	22_S	SgN	et	teekann =kann  (SgN  >tee+kann !22_S
38497	piimakann	kann	piima+kann	22_S	SgN	et	piimakann =kann  (SgN  >piima+kann !22_S
38503	kahvlid	kahvli	kahvel	02_S	PlN	et	kahvlid =kahvli  (PlN  >kahvel !02_S
38509	köögiaken	aken	köögi+aken	08_S	SgN	et	köögiaken =aken  (SgN  >köögi+aken !08_S
38515	pesukapp	kapp	pesu+kapp	22_S	SgN	et	pesukapp =kapp  (SgN  >pesu+kapp !22_S
38520	seljatugedega	tuge	selja+tugi	21_S	PlKom	et	seljatugedega =tuge  (PlKom  >selja+tugi !21_S
38523	muusikakeskus	keskus	muusika+keskus	11~09_S	SgN	et	muusikakeskus =keskus  (SgN  >muusika+keskus !11~09_S
38528	sahtel	sahtel	sahtel	02_S	SgN	et	sahtel =sahtel  (SgN  >sahtel !02_S
38541	pinged	pinge	pinge	06_S	PlN	et	pinged =pinge  (PlN  >pinge !06_S
38556	ametlikud	ametliku	ametlik	25_A	PlN	et	ametlikud =ametliku  (PlN  >ametlik !25_A
38571	veekann	kann	vee+kann	22_S	SgN	et	veekann =kann  (SgN  >vee+kann !22_S
38597	majapidamisinventar	inventar	maja+pidamis+inventar	19_S	SgN	et	majapidamisinventar =inventar  (SgN  >maja+pidamis+inventar !19_S
38598	matt	matt	matt	22_SA	SgN	et	matt =matt  (SgN  >matt !22_SA
38602	astri	astri	aster	02_S	SgG	et	astri =astri  (SgG  >aster !02_S
38613	pesemisvahendid	vahendi	pesemis+vahend	02_S	PlN	et	pesemisvahendid =vahendi  (PlN  >pesemis+vahend !02_S
38614	pesupulbrid	pulbri	pesu+pulber	02_S	PlN	et	pesupulbrid =pulbri  (PlN  >pesu+pulber !02_S
38619	riiulites	riiuli	riiul	02_S	PlIn	et	riiulites =riiuli  (PlIn  >riiul !02_S
38621	magamistoas	toa	magamis+tuba	18_S	SgIn	et	magamistoas =toa  (SgIn  >magamis+tuba !18_S
38622	riidekapis	kapi	riide+kapp	22_S	SgIn	et	riidekapis =kapi  (SgIn  >riide+kapp !22_S
38631	toidukaupade	kaupa	toidu+kaup	22_S	PlG	et	toidukaupade =kaupa  (PlG  >toidu+kaup !22_S
38637	köögikapi	kapi	köögi+kapp	22_S	SgG	et	köögikapi =kapi  (SgG  >köögi+kapp !22_S
38643	elutoa	toa	elu+tuba	18_S	SgG	et	elutoa =toa  (SgG  >elu+tuba !18_S
38644	pesukorv	korv	pesu+korv	22_S	SgN	et	pesukorv =korv  (SgN  >pesu+korv !22_S
38347	rollimängud	mängu	rolli+mäng	22_S	PlN	et	rollimängud =mängu  (PlN  >rolli+mäng !22_S
38348	probleemita	probleemi	probleem	22_S	SgAb	et	probleemita =probleemi  (SgAb  >probleem !22_S
38352	aktiivsena	aktiivse	aktiivne	02_A	SgEs	et	aktiivsena =aktiivse  (SgEs  >aktiivne !02_A
38353	iseendast	enda	ise+enda	00_P	SgEl	et	iseendast =enda  (SgEl  >ise+enda !00_P
38356	degradeerib	degradeeri	degradeerima	28_V	IndPrSg3	et	degradeerib =degradeeri  (IndPrSg3  >degradeerima !28_V
38358	tehnoloogiat	tehnoloogia	tehnoloogia	01_S	SgP	et	tehnoloogiat =tehnoloogia  (SgP  >tehnoloogia !01_S
38373	püüdma	püüd	püüdma	34_V	Sup	et	püüdma =püüd  (Sup  >püüdma !34_V
38375	aruannes	anne	aru+and	22_S	PlIn	et	aruannes =anne  (PlIn  >aru+and !22_S
38380	sõprades	sõpra	sõber	24_S	PlIn	et	sõprades =sõpra  (PlIn  >sõber !24_S
38386	saadet	saade	saade	06_S	SgP	et	saadet =saade  (SgP  >saade !06_S
38388	doklaadid	laadi	dok+laad	22_S	PlN	et	doklaadid =laadi  (PlN  >dok+laad !22_S
38390	mõõtke	mõõt	mõõtma	34_V	ImpPrPl2	et	mõõtke =mõõt  (ImpPrPl2  >mõõtma !34_V
38391	sulgege	sulge	sulgema	27~28_V	ImpPrPl2	et	sulgege =sulge  (ImpPrPl2  >sulgema !27~28_V
38395	täiteventiil	ventiil	täite+ventiil	22_S	SgN	et	täiteventiil =ventiil  (SgN  >täite+ventiil !22_S
38396	pistke	pist	pistma	34_V	ImpPrPl2	et	pistke =pist  (ImpPrPl2  >pistma !34_V
38406	spordialad	ala	spordi+ala	17_S	PlN	et	spordialad =ala  (PlN  >spordi+ala !17_S
38409	muudatustest	muudatus	muudatus	11_S	PlEl	et	muudatustest =muudatus  (PlEl  >muudatus !11_S
38410	taasiseseisvumist	seisvumis	taas+ise+seisvumine	12_S	SgP	et	taasiseseisvumist =seisvumis  (SgP  >taas+ise+seisvumine !12_S
38420	referendum	referendum	referendum	02_S	SgN	et	referendum =referendum  (SgN  >referendum !02_S
38421	isamaalaulud	laulu	isa+maa+laul	22_S	PlN	et	isamaalaulud =laulu  (PlN  >isa+maa+laul !22_S
38424	põõsad	põõsa	põõsas	07_S	PlN	et	põõsad =põõsa  (PlN  >põõsas !07_S
38427	toidu-	toidu	toit	22_S	SgG	et	toidu- =toidu  (SgG  >toit !22_S
38439	hambaharjad	harja	hamba+hari	24_S	PlN	et	hambaharjad =harja  (PlN  >hamba+hari !24_S
38444	öökapiga	kapi	öö+kapp	22_S	SgKom	et	öökapiga =kapi  (SgKom  >öö+kapp !22_S
38446	diivan	diivan	diivan	02_S	SgN	et	diivan =diivan  (SgN  >diivan !02_S
38448	toalill	lill	toa+lill	22_S	SgN	et	toalill =lill  (SgN  >toa+lill !22_S
38457	prügiämber	ämber	prügi+ämber	02_S	SgN	et	prügiämber =ämber  (SgN  >prügi+ämber !02_S
38461	kahvelit	kahveli	kahvel	02_S	SgP	et	kahvelit =kahveli  (SgP  >kahvel !02_S
38463	teelusikat	lusika	tee+lusikas	02_S	SgP	et	teelusikat =lusika  (SgP  >tee+lusikas !02_S
38468	külmkapi	kapi	külm+kapp	22_S	SgG	et	külmkapi =kapi  (SgG  >külm+kapp !22_S
38474	umbruses	ruse	umb+rusk	22_S	PlIn	et	umbruses =ruse  (PlIn  >umb+rusk !22_S
38475	hekk	hekk	hekk	22_S	SgN	et	hekk =hekk  (SgN  >hekk !22_S
38487	pesupulber	pulber	pesu+pulber	02_S	SgN	et	pesupulber =pulber  (SgN  >pesu+pulber !02_S
38489	südakorter	korter	süda+korter	02_S	SgN	et	südakorter =korter  (SgN  >süda+korter !02_S
38490	köögikapp	kapp	köögi+kapp	22_S	SgN	et	köögikapp =kapp  (SgN  >köögi+kapp !22_S
38496	kohikann	kann	kohi+kann	22_S	SgN	et	kohikann =kann  (SgN  >kohi+kann !22_S
38498	kastrulid	kastruli	kastrul	02_S	PlN	et	kastrulid =kastruli  (PlN  >kastrul !02_S
38500	võileivagrill	grill	või+leiva+grill	22_S	SgN	et	võileivagrill =grill  (SgN  >või+leiva+grill !22_S
38504	ripub	ripu	rippuma	28_V	IndPrSg3	et	ripub =ripu  (IndPrSg3  >rippuma !28_V
38505	riiv	riiv	riiv	22_S	SgN	et	riiv =riiv  (SgN  >riiv !22_S
38507	kulp	kulp	kulp	22_S	SgN	et	kulp =kulp  (SgN  >kulp !22_S
38513	taburetid	tabureti	taburet	22_S	PlN	et	taburetid =tabureti  (PlN  >taburet !22_S
38518	laualamp	lamp	laua+lamp	22_SA	SgN	et	laualamp =lamp  (SgN  >laua+lamp !22_SA
38521	tugitoolid	tooli	tugi+tool	22_S	PlN	et	tugitoolid =tooli  (PlN  >tugi+tool !22_S
38524	teeserviis	serviis	tee+serviis	22_S	SgN	et	teeserviis =serviis  (SgN  >tee+serviis !22_S
38526	kristall	kristall	kristall	22_S	SgN	et	kristall =kristall  (SgN  >kristall !22_S
38530	külgmine	külgmine	külgmine	12?10_A	SgN	et	külgmine =külgmine  (SgN  >külgmine !12?10_A
38531	ümmargune	ümmargune	ümmargune	12_A	SgN	et	ümmargune =ümmargune  (SgN  >ümmargune !12_A
38534	haamer	haamer	haamer	02_S	SgN	et	haamer =haamer  (SgN  >haamer !02_S
38538	pintsel	pintsel	pintsel	02_S	SgN	et	pintsel =pintsel  (SgN  >pintsel !02_S
38539	korrust	korrus	korrus	09_S	SgP	et	korrust =korrus  (SgP  >korrus !09_S
38543	ümberringi	ümberringi	ümber+ringi	41_D	ID	et	ümberringi =ümberringi  (ID  >ümber+ringi !41_D
38545	idapoolne	poolne	ida+poolne	02_A	SgN	et	idapoolne =poolne  (SgN  >ida+poolne !02_A
38548	tugitoolidel	tooli	tugi+tool	22_S	PlAd	et	tugitoolidel =tooli  (PlAd  >tugi+tool !22_S
38567	kausid	kausi	kauss	22_S	PlN	et	kausid =kausi  (PlN  >kauss !22_S
38354	riietada	riieta	riietama	27_V	Inf	et	riietada =riieta  (Inf  >riietama !27_V
38355	ebanormaalses	normaalse	eba+normaalne	02_A	SgIn	et	ebanormaalses =normaalse  (SgIn  >eba+normaalne !02_A
38361	sugust	sugus	sugune	10_A	SgP	et	sugust =sugus  (SgP  >sugune !10_A
38362	igat	iga	iga	17_P	SgP	et	igat =iga  (SgP  >iga !17_P
38366	automaatikaseadmed	seadme	automaatika+seade	05_S	PlN	et	automaatikaseadmed =seadme  (PlN  >automaatika+seade !05_S
38371	kordaminekuid	mineku	korda+minek	02_S	PlP	et	kordaminekuid =mineku  (PlP  >korda+minek !02_S
38372	klubis	klubi	klubi	17_S	SgIn	et	klubis =klubi  (SgIn  >klubi !17_S
38376	edukat	eduka	edukas	02_A	SgP	et	edukat =eduka  (SgP  >edukas !02_A
38381	õppusega	õppuse	õppus	11~09_S	SgKom	et	õppusega =õppuse  (SgKom  >õppus !11~09_S
38389	naabriga	naabri	naaber	02_S	SgKom	et	naabriga =naabri  (SgKom  >naaber !02_S
38392	pesumasina	masina	pesu+masin	02_S	SgG	et	pesumasina =masina  (SgG  >pesu+masin !02_S
38394	avage	ava	avama	27_V	ImpPrPl2	et	avage =ava  (ImpPrPl2  >avama !27_V
38399	teineteisega	teise	teine+teise	12_P	SgKom	et	teineteisega =teise  (SgKom  >teine+teise !12_P
38401	sportlased	sportlase	sportlane	12?10_S	PlN	et	sportlased =sportlase  (PlN  >sportlane !12?10_S
38411	majandusreform	reform	majandus+reform	22_S	SgN	et	majandusreform =reform  (SgN  >majandus+reform !22_S
38417	liiduga	liidu	liit	22_S	SgKom	et	liiduga =liidu  (SgKom  >liit !22_S
38419	riikidega	riiki	riik	22_S	PlKom	et	riikidega =riiki  (PlKom  >riik !22_S
38422	meeleavaldus	avaldus	meele+avaldus	11_S	SgN	et	meeleavaldus =avaldus  (SgN  >meele+avaldus !11_S
38423	uuel	uue	uus	14_A	SgAd	et	uuel =uue  (SgAd  >uus !14_A
38425	mänguväljak	väljak	mängu+väljak	02_S	SgN	et	mänguväljak =väljak  (SgN  >mängu+väljak !02_S
38433	esikud	esiku	esik	02_S	PlN	et	esikud =esiku  (PlN  >esik !02_S
38443	tüllkardin	kardin	tüll+kardin	02_S	SgN	et	tüllkardin =kardin  (SgN  >tüll+kardin !02_S
38445	magamistoa	toa	magamis+tuba	18_S	SgG	et	magamistoa =toa  (SgG  >magamis+tuba !18_S
38447	arvutilaual	laua	arvuti+laud	22_S	SgAd	et	arvutilaual =laua  (SgAd  >arvuti+laud !22_S
38451	kaktuse	kaktuse	kaktus	11~09_S	SgG	et	kaktuse =kaktuse  (SgG  >kaktus !11~09_S
38454	kapis	kapi	kapp	22_S	SgIn	et	kapis =kapi  (SgIn  >kapp !22_S
38455	kannud	kannu	kann	22_S	PlN	et	kannud =kannu  (PlN  >kann !22_S
38456	köögikraan	kraan	köögi+kraan	22_S	SgN	et	köögikraan =kraan  (SgN  >köögi+kraan !22_S
38458	pannid	panni	pann	22_S	PlN	et	pannid =panni  (PlN  >pann !22_S
38467	elektrikann	kann	elektri+kann	22_S	SgN	et	elektrikann =kann  (SgN  >elektri+kann !22_S
38469	toalilled	lille	toa+lill	22_S	PlN	et	toalilled =lille  (PlN  >toa+lill !22_S
38476	sissekäigus	käigu	sisse+käik	22_S	SgIn	et	sissekäigus =käigu  (SgIn  >sisse+käik !22_S
38479	ripuvad	ripu	rippuma	28_V	IndPrPl3	et	ripuvad =ripu  (IndPrPl3  >rippuma !28_V
38480	mütsid	mütsi	müts	22_S	PlN	et	mütsid =mütsi  (PlN  >müts !22_S
38483	ruutmeetrit	meetri	ruut+meeter	02_S	SgP	et	ruutmeetrit =meetri  (SgP  >ruut+meeter !02_S
38485	vannitoa	toa	vanni+tuba	18_S	SgG	et	vannitoa =toa  (SgG  >vanni+tuba !18_S
38488	rippuma	rippu	rippuma	28_V	Sup	et	rippuma =rippu  (Sup  >rippuma !28_V
38493	serviis	serviis	serviis	22_S	SgN	et	serviis =serviis  (SgN  >serviis !22_S
38501	lusikad	lusika	lusikas	02_S	PlN	et	lusikad =lusika  (PlN  >lusikas !02_S
38502	noad	noa	nuga	18_S	PlN	et	noad =noa  (PlN  >nuga !18_S
38506	sõel	sõel	sõel	23?22_S	SgN	et	sõel =sõel  (SgN  >sõel !23?22_S
38508	potilapp	lapp	poti+lapp	22_S	SgN	et	potilapp =lapp  (SgN  >poti+lapp !22_S
38522	tugitoolid	tooli	tugi+tool	22_S	PlN	et	tugitoolid =tooli  (PlN  >tugi+tool !22_S
38529	sahtel	sahtel	sahtel	02_S	SgN	et	sahtel =sahtel  (SgN  >sahtel !02_S
38533	tööinstrument	instrument	töö+instrument	22_S	SgN	et	tööinstrument =instrument  (SgN  >töö+instrument !22_S
38535	metallipuurid	puuri	metalli+puur	22_S	PlN	et	metallipuurid =puuri  (PlN  >metalli+puur !22_S
38546	tugitoolide	tooli	tugi+tool	22_S	PlG	et	tugitoolide =tooli  (PlG  >tugi+tool !22_S
38547	põrandalamp	lamp	põranda+lamp	22_SA	SgN	et	põrandalamp =lamp  (SgN  >põranda+lamp !22_SA
38550	küünlajalad	jala	küünla+jalg	22_S	PlN	et	küünlajalad =jala  (PlN  >küünla+jalg !22_S
38555	seinakell	kell	seina+kell	22_S	SgN	et	seinakell =kell  (SgN  >seina+kell !22_S
38564	valamuga	valamu	valamu	01_S	SgKom	et	valamuga =valamu  (SgKom  >valamu !01_S
38565	kühvel	kühvel	kühvel	02_S	SgN	et	kühvel =kühvel  (SgN  >kühvel !02_S
38570	hakklihamasin	masin	hakk+liha+masin	02_S	SgN	et	hakklihamasin =masin  (SgN  >hakk+liha+masin !02_S
38575	köögitarbed	tarbe	köögi+tarve	06_S	PlN	et	köögitarbed =tarbe  (PlN  >köögi+tarve !06_S
38576	ülemises	ülemise	ülemine	12_A	SgIn	et	ülemises =ülemise  (SgIn  >ülemine !12_A
38359	suhtleb	suhtle	suhtlema	30_V	IndPrSg3	et	suhtleb =suhtle  (IndPrSg3  >suhtlema !30_V
38365	rakenduskõrgharidus	haridus	rakendus+kõrg+haridus	11_S	SgN	et	rakenduskõrgharidus =haridus  (SgN  >rakendus+kõrg+haridus !11_S
38369	ostusid	ostu	ost	22_S	PlP	et	ostusid =ostu  (PlP  >ost !22_S
38378	hääldata	häälda	hääldama	27_V	IndPrIps_	et	hääldata =häälda  (IndPrIps_  >hääldama !27_V
38383	sünnikoht	koht	sünni+koht	22_S	SgN	et	sünnikoht =koht  (SgN  >sünni+koht !22_S
38398	kuivatage	kuivata	kuivatama	27_V	ImpPrPl2	et	kuivatage =kuivata  (ImpPrPl2  >kuivatama !27_V
38402	suhtlusi	suhtlusi	suhtlus	11_S	PlP	et	suhtlusi =suhtlusi  (PlP  >suhtlus !11_S
38403	heitlik	heitlik	heitlik	25_A	SgN	et	heitlik =heitlik  (SgN  >heitlik !25_A
38413	paremtsentristlik	tsentristlik	parem+tsentristlik	25_A	SgN	et	paremtsentristlik =tsentristlik  (SgN  >parem+tsentristlik !25_A
38414	isamaaliit	liit	isa+maa+liit	22_S	SgN	et	isamaaliit =liit  (SgN  >isa+maa+liit !22_S
38426	segamets	mets	sega+mets	22_S	SgN	et	segamets =mets  (SgN  >sega+mets !22_S
38438	seebid	seebi	seep	22_S	PlN	et	seebid =seebi  (PlN  >seep !22_S
38440	lastetoas	toa	laste+tuba	18_S	SgIn	et	lastetoas =toa  (SgIn  >laste+tuba !18_S
38441	nurgadiivan	diivan	nurga+diivan	02_S	SgN	et	nurgadiivan =diivan  (SgN  >nurga+diivan !02_S
38459	sahtlis	sahtli	sahtel	02_S	SgIn	et	sahtlis =sahtli  (SgIn  >sahtel !02_S
38462	supilusikat	lusika	supi+lusikas	02_S	SgP	et	supilusikat =lusika  (SgP  >supi+lusikas !02_S
38470	piirilinn	linn	piiri+linn	22_S	SgN	et	piirilinn =linn  (SgN  >piiri+linn !22_S
38471	äärelinn	linn	ääre+linn	22_S	SgN	et	äärelinn =linn  (SgN  >ääre+linn !22_S
38492	riiulid	riiuli	riiul	02_S	PlN	et	riiulid =riiuli  (PlN  >riiul !02_S
38494	suhkrutoos	toos	suhkru+toos	22_S	SgN	et	suhkrutoos =toos  (SgN  >suhkru+toos !22_S
38499	röster	röster	röster	02_S	SgN	et	röster =röster  (SgN  >röster !02_S
38510	aknalauad	laua	akna+laud	22_S	PlN	et	aknalauad =laua  (PlN  >akna+laud !22_S
38514	seitsetest	test	seitse+test	22_S	SgN	et	seitsetest =test  (SgN  >seitse+test !22_S
38516	pesukapp	kapp	pesu+kapp	22_S	SgN	et	pesukapp =kapp  (SgN  >pesu+kapp !22_S
38525	salvrätikud	rätiku	salv+rätik	02_S	PlN	et	salvrätikud =rätiku  (PlN  >salv+rätik !02_S
38527	pitsid	pitsi	pits	22_S	PlN	et	pitsid =pitsi  (PlN  >pits !22_S
38536	puupuurid	puuri	puu+puur	22_S	PlN	et	puupuurid =puuri  (PlN  >puu+puur !22_S
38540	gaasiboilerid	boileri	gaasi+boiler	02_S	PlN	et	gaasiboilerid =boileri  (PlN  >gaasi+boiler !02_S
38549	padjad	padja	padi	24_S	PlN	et	padjad =padja  (PlN  >padi !24_S
38554	voodiümbrusvaibad	vaiba	voodi+ümbrus+vaip	22_S	PlN	et	voodiümbrusvaibad =vaiba  (PlN  >voodi+ümbrus+vaip !22_S
38559	kasvad	kasva	kasvama	28_V	IndPrSg2	et	kasvad =kasva  (IndPrSg2  >kasvama !28_V
38560	köögikomplekt	komplekt	köögi+komplekt	22_S	SgN	et	köögikomplekt =komplekt  (SgN  >köögi+komplekt !22_S
38561	kappide	kappi	kapp	22_S	PlG	et	kappide =kappi  (PlG  >kapp !22_S
38562	seinakapid	kapi	seina+kapp	22_S	PlN	et	seinakapid =kapi  (PlN  >seina+kapp !22_S
38566	kruusid	kruusi	kruus	22_S	PlN	et	kruusid =kruusi  (PlN  >kruus !22_S
38569	kapiplaadil	plaadi	kapi+plaat	22_S	SgAd	et	kapiplaadil =plaadi  (SgAd  >kapi+plaat !22_S
38578	köögikombain	kombain	köögi+kombain	22_S	SgN	et	köögikombain =kombain  (SgN  >köögi+kombain !22_S
38580	juurviljadega	vilja	juur+vili	24_S	PlKom	et	juurviljadega =vilja  (PlKom  >juur+vili !24_S
38600	olus	olu	olu	17_S	SgIn	et	olus =olu  (SgIn  >olu !17_S
38605	sirelid	sireli	sirel	02_S	PlN	et	sirelid =sireli  (PlN  >sirel !02_S
38611	hoiame	hoia	hoidma	34_V	IndPrPl1	et	hoiame =hoia  (IndPrPl1  >hoidma !34_V
38615	välisriided	riide	välis+riie	06_S	PlN	et	välisriided =riide  (PlN  >välis+riie !06_S
38616	ripplagi	lagi	ripp+lagi	21_S	SgN	et	ripplagi =lagi  (SgN  >ripp+lagi !21_S
38620	seinalamp	lamp	seina+lamp	22_SA	SgN	et	seinalamp =lamp  (SgN  >seina+lamp !22_SA
38623	riiulitel	riiuli	riiul	02_S	PlAd	et	riiulitel =riiuli  (PlAd  >riiul !02_S
38627	külmkapil	kapi	külm+kapp	22_S	SgAd	et	külmkapil =kapi  (SgAd  >külm+kapp !22_S
38628	ämber	ämber	ämber	02_S	SgN	et	ämber =ämber  (SgN  >ämber !02_S
38641	vannituppa	tuppa	vanni+tuba	18_S	SgAdt	et	vannituppa =tuppa  (SgAdt  >vanni+tuba !18_S
38658	raamatusektsioon	sektsioon	raamatu+sektsioon	22_S	SgN	et	raamatusektsioon =sektsioon  (SgN  >raamatu+sektsioon !22_S
38666	nurgadiivaniga	diivani	nurga+diivan	02_S	SgKom	et	nurgadiivaniga =diivani  (SgKom  >nurga+diivan !02_S
38674	peegli	peegli	peegel	02_S	SgG	et	peegli =peegli  (SgG  >peegel !02_S
38675	esikpõrand	põrand	esik+põrand	02_S	SgN	et	esikpõrand =põrand  (SgN  >esik+põrand !02_S
38690	hansapank	pank	hansa+pank	22_S	SgN	et	hansapank =pank  (SgN  >hansa+pank !22_S
38694	supp	supp	supp	22_S	SgN	et	supp =supp  (SgN  >supp !22_S
38360	haridusete	e	haridus+esi	15_S	PlG	et	haridusete =e  (PlG  >haridus+esi !15_S
38364	kursuselle	elle	kursus+ell	22_S	PlP	et	kursuselle =elle  (PlP  >kursus+ell !22_S
38368	vastate	vasta	vastama	29_V	IndPrPl2	et	vastate =vasta  (IndPrPl2  >vastama !29_V
38370	mõõta	mõõt	mõõtma	34_V	Inf	et	mõõta =mõõt  (Inf  >mõõtma !34_V
38374	sirvida	sirvi	sirvima	28_V	Inf	et	sirvida =sirvi  (Inf  >sirvima !28_V
38377	nutta	nutt	nutma	35_V	Inf	et	nutta =nutt  (Inf  >nutma !35_V
38382	sümpaatsed	sümpaatse	sümpaatne	02_A	PlN	et	sümpaatsed =sümpaatse  (PlN  >sümpaatne !02_A
38385	sisemaailm	ilm	sise+maa+ilm	22_S	SgN	et	sisemaailm =ilm  (SgN  >sise+maa+ilm !22_S
38393	luuk	luuk	luuk	22_S	SgN	et	luuk =luuk  (SgN  >luuk !22_S
38397	pistik	pistik	pistik	02_S	SgN	et	pistik =pistik  (SgN  >pistik !02_S
38404	üksindus	üksindus	üksindus	11_S	SgN	et	üksindus =üksindus  (SgN  >üksindus !11_S
38407	elusega	eluse	elus	02_A	SgKom	et	elusega =eluse  (SgKom  >elus !02_A
38412	põhiseaduslikud	seadusliku	põhi+seaduslik	25_A	PlN	et	põhiseaduslikud =seadusliku  (PlN  >põhi+seaduslik !25_A
38415	euroopale	euroopa	euroopa	01_H	SgAll	et	euroopale =euroopa  (SgAll  >euroopa !01_H
38429	kauplused	kaupluse	kauplus	11~09_S	PlN	et	kauplused =kaupluse  (PlN  >kauplus !11~09_S
38430	kaubakeskus	keskus	kauba+keskus	11~09_S	SgN	et	kaubakeskus =keskus  (SgN  >kauba+keskus !11~09_S
38431	apteek	apteek	apteek	22_S	SgN	et	apteek =apteek  (SgN  >apteek !22_S
38437	vann	vann	vann	22_S	SgN	et	vann =vann  (SgN  >vann !22_S
38442	nukud	nuku	nukk	22_S	PlN	et	nukud =nuku  (PlN  >nukk !22_S
38449	vähel	vähe	vähk	22_S	PlAd	et	vähel =vähe  (PlAd  >vähk !22_S
38450	aknalaual	laua	akna+laud	22_S	SgAd	et	aknalaual =laua  (SgAd  >akna+laud !22_S
38452	elutoast	toa	elu+tuba	18_S	SgEl	et	elutoast =toa  (SgEl  >elu+tuba !18_S
38453	külmkapis	kapi	külm+kapp	22_S	SgIn	et	külmkapis =kapi  (SgIn  >külm+kapp !22_S
38460	korgitser	korgitser	korgitser	19_S	SgN	et	korgitser =korgitser  (SgN  >korgitser !19_S
38464	tõmbekapp	kapp	tõmbe+kapp	22_S	SgN	et	tõmbekapp =kapp  (SgN  >tõmbe+kapp !22_S
38465	kodumasinad	masina	kodu+masin	02_S	PlN	et	kodumasinad =masina  (PlN  >kodu+masin !02_S
38466	mahlapress	press	mahla+press	22_S	SgN	et	mahlapress =press  (SgN  >mahla+press !22_S
38472	paneel	paneel	paneel	22_S	SgN	et	paneel =paneel  (SgN  >paneel !22_S
38482	linoleumiga	linoleumi	linoleum	22_S	SgKom	et	linoleumiga =linoleumi  (SgKom  >linoleum !22_S
38484	käterätik	rätik	käte+rätik	02_S	SgN	et	käterätik =rätik  (SgN  >käte+rätik !02_S
38486	kahhelkiviga	kivi	kahhel+kivi	17_S	SgKom	et	kahhelkiviga =kivi  (SgKom  >kahhel+kivi !17_S
38511	lage	lage	lagi	21_S	SgP	et	lage =lage  (SgP  >lagi !21_S
38512	laelamp	lamp	lae+lamp	22_SA	SgN	et	laelamp =lamp  (SgN  >lae+lamp !22_SA
38517	laudlinad	lina	laud+lina	17_S	PlN	et	laudlinad =lina  (PlN  >laud+lina !17_S
38519	õmblusmasin	masin	õmblus+masin	02_S	SgN	et	õmblusmasin =masin  (SgN  >õmblus+masin !02_S
38532	sahtelid	sahteli	sahtel	02_S	PlN	et	sahtelid =sahteli  (PlN  >sahtel !02_S
38537	betoonpuurid	puuri	betoon+puur	22_S	PlN	et	betoonpuurid =puuri  (PlN  >betoon+puur !22_S
38542	toidukauplused	kaupluse	toidu+kauplus	11~09_S	PlN	et	toidukauplused =kaupluse  (PlN  >toidu+kauplus !11~09_S
38544	tubade	tuba	tuba	18_S	PlG	et	tubade =tuba  (PlG  >tuba !18_S
38551	teleriga	teleri	teler	02_S	SgKom	et	teleriga =teleri  (SgKom  >teler !02_S
38552	peeglitega	peegli	peegel	02_S	PlKom	et	peeglitega =peegli  (PlKom  >peegel !02_S
38553	öökappidel	kappi	öö+kapp	22_S	PlAd	et	öökappidel =kappi  (PlAd  >öö+kapp !22_S
38557	raamaturiiulid	riiuli	raamatu+riiul	02_S	PlN	et	raamaturiiulid =riiuli  (PlN  >raamatu+riiul !02_S
38558	tugitoll	toll	tugi+toll	22_S	SgN	et	tugitoll =toll  (SgN  >tugi+toll !22_S
38563	söögilaua	laua	söögi+laud	22_S	SgG	et	söögilaua =laua  (SgG  >söögi+laud !22_S
38568	sõelad	sõela	sõel	23?22_S	PlN	et	sõelad =sõela  (PlN  >sõel !23?22_S
38572	seinakapis	kapi	seina+kapp	22_S	SgIn	et	seinakapis =kapi  (SgIn  >seina+kapp !22_S
38579	keskmises	keskmise	keskmine	12?10_A	SgIn	et	keskmises =keskmise  (SgIn  >keskmine !12?10_A
38582	porgandeid	porgande	porgand	02_S	PlP	et	porgandeid =porgande  (PlP  >porgand !02_S
38585	tualetis	tualeti	tualett	22_S	SgIn	et	tualetis =tualeti  (SgIn  >tualett !22_S
38586	põrandad	põranda	põrand	02_S	PlN	et	põrandad =põranda  (PlN  >põrand !02_S
38591	kraanikausi	kausi	kraani+kauss	22_S	SgG	et	kraanikausi =kausi  (SgG  >kraani+kauss !22_S
38594	gaasiboiler	boiler	gaasi+boiler	02_S	SgN	et	gaasiboiler =boiler  (SgN  >gaasi+boiler !02_S
38596	seinakapp	kapp	seina+kapp	22_S	SgN	et	seinakapp =kapp  (SgN  >seina+kapp !22_S
38606	kastanid	kastani	kastan	02_S	PlN	et	kastanid =kastani  (PlN  >kastan !02_S
38573	sahtlit	sahtli	sahtel	02_S	SgP	et	sahtlit =sahtli  (SgP  >sahtel !02_S
38574	kulbid	kulbi	kulp	22_S	PlN	et	kulbid =kulbi  (PlN  >kulp !22_S
38581	alumises	alumise	alumine	12_A	SgIn	et	alumises =alumise  (SgIn  >alumine !12_A
38583	sibulaid	sibula	sibul	02_S	PlP	et	sibulaid =sibula  (PlP  >sibul !02_S
38584	gaasipliidi	pliidi	gaasi+pliit	22_S	SgG	et	gaasipliidi =pliidi  (SgG  >gaasi+pliit !22_S
38587	alumiste	alumis	alumine	12_A	PlG	et	alumiste =alumis  (PlG  >alumine !12_A
38588	kraanikauss	kauss	kraani+kauss	22_S	SgN	et	kraanikauss =kauss  (SgN  >kraani+kauss !22_S
38592	vannikapp	kapp	vanni+kapp	22_S	SgN	et	vannikapp =kapp  (SgN  >vanni+kapp !22_S
38595	vannitoamatt	matt	vanni+toa+matt	22_SA	SgN	et	vannitoamatt =matt  (SgN  >vanni+toa+matt !22_SA
38607	paplid	papli	pappel	02_S	PlN	et	paplid =papli  (PlN  >pappel !02_S
38608	põõsaid	põõsa	põõsas	07_S	PlP	et	põõsaid =põõsa  (PlP  >põõsas !07_S
38612	talveriideid	riide	talve+riie	06_S	PlP	et	talveriideid =riide  (PlP  >talve+riie !06_S
38618	sahtlid	sahtli	sahtel	02_S	PlN	et	sahtlid =sahtli  (PlN  >sahtel !02_S
38624	kohvimasin	masin	kohvi+masin	02_S	SgN	et	kohvimasin =masin  (SgN  >kohvi+masin !02_S
38625	köögiakna	akna	köögi+aken	08_S	SgG	et	köögiakna =akna  (SgG  >köögi+aken !08_S
38626	söögilaual	laua	söögi+laud	22_S	SgAd	et	söögilaual =laua  (SgAd  >söögi+laud !22_S
38630	pink	pink	pink	22_S	SgN	et	pink =pink  (SgN  >pink !22_S
38634	lastemänguasjad	asja	laste+mängu+asi	24_S	PlN	et	lastemänguasjad =asja  (PlN  >laste+mängu+asi !24_S
38635	põrandas	põranda	põrand	02_S	SgIn	et	põrandas =põranda  (SgIn  >põrand !02_S
38639	köögipõrand	põrand	köögi+põrand	02_S	SgN	et	köögipõrand =põrand  (SgN  >köögi+põrand !02_S
38640	tualeti	tualeti	tualett	22_S	SgG	et	tualeti =tualeti  (SgG  >tualett !22_S
38649	arvutitool	tool	arvuti+tool	22_S	SgN	et	arvutitool =tool  (SgN  >arvuti+tool !22_S
38653	kummit	kummi	kummi	16_S	SgP	et	kummit =kummi  (SgP  >kummi !16_S
38661	akvaarium	akvaarium	akvaarium	19~02_S	SgN	et	akvaarium =akvaarium  (SgN  >akvaarium !19~02_S
38663	kappis	kappi	kappima	28_V	IndIpfSg3	et	kappis =kappi  (IndIpfSg3  >kappima !28_V
38670	köögikapid	kapi	köögi+kapp	22_S	PlN	et	köögikapid =kapi  (PlN  >köögi+kapp !22_S
38671	söögitoas	toa	söögi+tuba	18_S	SgIn	et	söögitoas =toa  (SgIn  >söögi+tuba !18_S
38681	rätikud	rätiku	rätik	02_S	PlN	et	rätikud =rätiku  (PlN  >rätik !02_S
38685	bensiinijaam	jaam	bensiini+jaam	22_S	SgN	et	bensiinijaam =jaam  (SgN  >bensiini+jaam !22_S
38687	lillid	lilli	lill	22_S	PlN	et	lillid =lilli  (PlN  >lill !22_S
38689	õmbluses	õmbluse	õmblus	11~09_S	SgIn	et	õmbluses =õmbluse  (SgIn  >õmblus !11~09_S
38693	pliidil	pliidi	pliit	22_S	SgAd	et	pliidil =pliidi  (SgAd  >pliit !22_S
38698	indiviid	indiviid	indiviid	22_S	SgN	et	indiviid =indiviid  (SgN  >indiviid !22_S
38704	juurutama	juuruta	juurutama	27_V	Sup	et	juurutama =juuruta  (Sup  >juurutama !27_V
38721	kohvipausini	pausi	kohvi+paus	22_S	SgTer	et	kohvipausini =pausi  (SgTer  >kohvi+paus !22_S
38730	looduskeskkond	keskkond	loodus+keskkond	22_S	SgN	et	looduskeskkond =keskkond  (SgN  >loodus+keskkond !22_S
38736	õpetamast	õpeta	õpetama	27_V	SupEl	et	õpetamast =õpeta  (SupEl  >õpetama !27_V
38739	valmistudes	valmistu	valmistuma	27_V	Ger	et	valmistudes =valmistu  (Ger  >valmistuma !27_V
38744	salakaubanduse	kaubanduse	sala+kaubandus	11_S	SgG	et	salakaubanduse =kaubanduse  (SgG  >sala+kaubandus !11_S
38747	konterbant	konterbant	konterbant	22_S	SgN	et	konterbant =konterbant  (SgN  >konterbant !22_S
38749	siseminister	minister	sise+minister	02_S	SgN	et	siseminister =minister  (SgN  >sise+minister !02_S
38751	sibul	sibul	sibul	02_S	SgN	et	sibul =sibul  (SgN  >sibul !02_S
38758	teeksite	tee	tegema	28_V	KndPrPl2	et	teeksite =tee  (KndPrPl2  >tegema !28_V
38762	ülal	ülal	ülal	41_D	ID	et	ülal =ülal  (ID  >ülal !41_D
38766	neoliitikumiks	neoliitikumi	neoliitikum	19_S	SgTr	et	neoliitikumiks =neoliitikumi  (SgTr  >neoliitikum !19_S
38781	tarkemaks	ema	tark+ema	17_S	SgTr	et	tarkemaks =ema  (SgTr  >tark+ema !17_S
38782	küttide	kütti	kütt	22_S	PlG	et	küttide =kütti  (PlG  >kütt !22_S
38783	korilaste	korilas	korilane	12_S	PlG	et	korilaste =korilas  (PlG  >korilane !12_S
38784	õitseaeg	aeg	õitse+aeg	22_S	SgN	et	õitseaeg =aeg  (SgN  >õitse+aeg !22_S
38785	kujunema	kujune	kujunema	27_V	Sup	et	kujunema =kujune  (Sup  >kujunema !27_V
38788	kivipudru	pudru	kivi+puder	24_S	SgG	et	kivipudru =pudru  (SgG  >kivi+puder !24_S
38798	aa	aa	aa	41_I	ID	et	aa =aa  (ID  >aa !41_I
38802	rääbis	rääbis	rääbis	09_S	SgN	et	rääbis =rääbis  (SgN  >rääbis !09_S
38804	puitkodades	koda	puit+koda	18_S	PlIn	et	puitkodades =koda  (PlIn  >puit+koda !18_S
38805	puuokstest	oks	puu+oks	23_S	PlEl	et	puuokstest =oks  (PlEl  >puu+oks !23_S
38577	lõunaserviis	serviis	lõuna+serviis	22_S	SgN	et	lõunaserviis =serviis  (SgN  >lõuna+serviis !22_S
38589	kapiga	kapi	kapp	22_S	SgKom	et	kapiga =kapi  (SgKom  >kapp !22_S
38590	automaatpesumasin	masin	automaat+pesu+masin	02_S	SgN	et	automaatpesumasin =masin  (SgN  >automaat+pesu+masin !02_S
38593	seinanagides	nagi	seina+nagi	17_S	PlIn	et	seinanagides =nagi  (PlIn  >seina+nagi !17_S
38599	prospekt	prospekt	prospekt	22_S	SgN	et	prospekt =prospekt  (SgN  >prospekt !22_S
38601	tiik	tiik	tiik	22_S	SgN	et	tiik =tiik  (SgN  >tiik !22_S
38603	mänguväljakul	väljaku	mängu+väljak	02_S	SgAd	et	mänguväljakul =väljaku  (SgAd  >mängu+väljak !02_S
38604	ronimisredelid	redeli	roni+mis+redel	02_S	PlN	et	ronimisredelid =redeli  (PlN  >roni+mis+redel !02_S
38609	päikesepoolne	poolne	päikese+poolne	02_A	SgN	et	päikesepoolne =poolne  (SgN  >päikese+poolne !02_A
38632	lastelaual	laua	laste+laud	22_S	SgAd	et	lastelaual =laua  (SgAd  >laste+laud !22_S
38633	videomagnetofon	magnetofon	video+magnetofon	19_S	SgN	et	videomagnetofon =magnetofon  (SgN  >video+magnetofon !19_S
38638	köögikapil	kapi	köögi+kapp	22_S	SgAd	et	köögikapil =kapi  (SgAd  >köögi+kapp !22_S
38642	uste	us	uks	14_S	PlG	et	uste =us  (PlG  >uks !14_S
38645	vannitoaga	toa	vanni+tuba	18_S	SgKom	et	vannitoaga =toa  (SgKom  >vanni+tuba !18_S
38646	nuustikud	nuustiku	nuustik	02_S	PlN	et	nuustikud =nuustiku  (PlN  >nuustik !02_S
38647	lastesektsioon	sektsioon	laste+sektsioon	22_S	SgN	et	lastesektsioon =sektsioon  (SgN  >laste+sektsioon !22_S
38652	voodikate	kate	voodi+kate	06_S	SgN	et	voodikate =kate  (SgN  >voodi+kate !06_S
38660	sektsioonil	sektsiooni	sektsioon	22_S	SgAd	et	sektsioonil =sektsiooni  (SgAd  >sektsioon !22_S
38662	akvaarium	akvaarium	akvaarium	19~02_S	SgN	et	akvaarium =akvaarium  (SgN  >akvaarium !19~02_S
38664	kappis	kappi	kappima	28_V	IndIpfSg3	et	kappis =kappi  (IndIpfSg3  >kappima !28_V
38668	harjaga	harja	hari	24_S	SgKom	et	harjaga =harja  (SgKom  >hari !24_S
38672	köögipuumööbel	mööbel	köögi+puu+mööbel	02_S	SgN	et	köögipuumööbel =mööbel  (SgN  >köögi+puu+mööbel !02_S
38673	nõudepesuvahend	vahend	nõude+pesu+vahend	02_S	SgN	et	nõudepesuvahend =vahend  (SgN  >nõude+pesu+vahend !02_S
38678	uksel	ukse	uks	14_S	SgAd	et	uksel =ukse  (SgAd  >uks !14_S
38679	vannipõrand	põrand	vanni+põrand	02_S	SgN	et	vannipõrand =põrand  (SgN  >vanni+põrand !02_S
38695	pann	pann	pann	22_S	SgN	et	pann =pann  (SgN  >pann !22_S
38696	pannil	panni	pann	22_S	SgAd	et	pannil =panni  (SgAd  >pann !22_S
38702	väikeriigi	riigi	väike+riik	22_S	SgG	et	väikeriigi =riigi  (SgG  >väike+riik !22_S
38708	elusfäärile	sfääri	elu+sfäär	22_S	SgAll	et	elusfäärile =sfääri  (SgAll  >elu+sfäär !22_S
38715	talupidamine	pidamine	talu+pidamine	12_S	SgN	et	talupidamine =pidamine  (SgN  >talu+pidamine !12_S
38716	talupojadele	poja	talu+poja	17_S	PlAll	et	talupojadele =poja  (PlAll  >talu+poja !17_S
38726	risk	risk	risk	22_S	SgN	et	risk =risk  (SgN  >risk !22_S
38732	koosmõjul	mõju	koos+mõju	17_S	SgAd	et	koosmõjul =mõju  (SgAd  >koos+mõju !17_S
38741	aparaadi	aparaadi	aparaat	22_S	SgG	et	aparaadi =aparaadi  (SgG  >aparaat !22_S
38742	telesaatele	saate	tele+saade	06_S	SgAll	et	telesaatele =saate  (SgAll  >tele+saade !06_S
38745	salakaubavedamisega	vedamise	sala+kauba+vedamine	12_S	SgKom	et	salakaubavedamisega =vedamise  (SgKom  >sala+kauba+vedamine !12_S
38750	salakauba	kauba	sala+kaup	22_S	SgG	et	salakauba =kauba  (SgG  >sala+kaup !22_S
38756	pealekaebajaks	kaebaja	peale+kaebaja	01_S	SgTr	et	pealekaebajaks =kaebaja  (SgTr  >peale+kaebaja !01_S
38761	ütleks	ütle	ütlema	30_V	KndPrPs	et	ütleks =ütle  (KndPrPs  >ütlema !30_V
38765	paleoliitikumiks	paleoliitikumi	paleoliitikum	19_S	SgTr	et	paleoliitikumiks =paleoliitikumi  (SgTr  >paleoliitikum !19_S
38767	peatuspaiku	paiku	peatus+paik	22_S	PlP	et	peatuspaiku =paiku  (PlP  >peatus+paik !22_S
38775	põder	põder	põder	24_S	SgN	et	põder =põder  (SgN  >põder !24_S
38776	juustega	juus	juus	09_S	PlKom	et	juustega =juus  (PlKom  >juus !09_S
38778	kalade	kala	kala	17_S	PlG	et	kalade =kala  (PlG  >kala !17_S
38787	jämedast	jämeda	jäme	02_A	SgEl	et	jämedast =jämeda  (SgEl  >jäme !02_A
38793	veised	veise	veis	09_S	PlN	et	veised =veise  (PlN  >veis !09_S
38796	hoolitseti	hoolitse	hoolitsema	27_V	IndIpfIps	et	hoolitseti =hoolitse  (IndIpfIps  >hoolitsema !27_V
38799	metsaandide	andi	metsa+and	22_S	PlG	et	metsaandide =andi  (PlG  >metsa+and !22_S
38803	jahiriistu	riistu	jahi+riist	22_S	PlP	et	jahiriistu =riistu  (PlP  >jahi+riist !22_S
38807	püstkojas	koja	püst+koda	18_S	SgIn	et	püstkojas =koja  (SgIn  >püst+koda !18_S
38813	põhjaga	põhja	põhi	24_S	SgKom	et	põhjaga =põhja  (SgKom  >põhi !24_S
38819	ühele	ühe	üks	22_NP	SgAll	et	ühele =ühe  (SgAll  >üks !22_NP
38825	tõlgiti	tõlgi	tõlkima	28_V	IndIpfIps	et	tõlgiti =tõlgi  (IndIpfIps  >tõlkima !28_V
38610	põhjapoolsed	poolse	põhja+poolne	02_A	PlN	et	põhjapoolsed =poolse  (PlN  >põhja+poolne !02_A
38617	vaasis	vaasi	vaas	22_S	SgIn	et	vaasis =vaasi  (SgIn  >vaas !22_S
38629	kahhelkividega	kivi	kahhel+kivi	17_S	PlKom	et	kahhelkividega =kivi  (PlKom  >kahhel+kivi !17_S
38636	köögikapis	kapi	köögi+kapp	22_S	SgIn	et	köögikapis =kapi  (SgIn  >köögi+kapp !22_S
38651	voodile	voodi	voodi	01_S	SgAll	et	voodile =voodi  (SgAll  >voodi !01_S
38654	tapeet	tapeet	tapeet	22_S	SgN	et	tapeet =tapeet  (SgN  >tapeet !22_S
38655	kristalllühter	lühter	kristall+lühter	02_S	SgN	et	kristalllühter =lühter  (SgN  >kristall+lühter !02_S
38656	nahkdiivan	diivan	nahk+diivan	02_S	SgN	et	nahkdiivan =diivan  (SgN  >nahk+diivan !02_S
38657	vassis	vassi	vassima	28_V	IndIpfSg3	et	vassis =vassi  (IndIpfSg3  >vassima !28_V
38665	kodukonservid	konservi	kodu+konserv	22_S	PlN	et	kodukonservid =konservi  (PlN  >kodu+konserv !22_S
38667	pühin	pühi	pühkima	28_V	IndPrSg1	et	pühin =pühi  (IndPrSg1  >pühkima !28_V
38669	köögipõrandad	põranda	köögi+põrand	02_S	PlN	et	köögipõrandad =põranda  (PlN  >köögi+põrand !02_S
38682	lastepott	pott	laste+pott	22_S	SgN	et	lastepott =pott  (SgN  >laste+pott !22_S
38683	elumajad	maja	elu+maja	17_S	PlN	et	elumajad =maja  (PlN  >elu+maja !17_S
38684	karina	kari	kari	17_S	SgEs	et	karina =kari  (SgEs  >kari !17_S
38691	kingaparandus	parandus	kinga+parandus	11_S	SgN	et	kingaparandus =parandus  (SgN  >kinga+parandus !11_S
38692	pott	pott	pott	22_S	SgN	et	pott =pott  (SgN  >pott !22_S
38697	kann	kann	kann	22_S	SgN	et	kann =kann  (SgN  >kann !22_S
38699	elulugudes	lugu	elu+lugu	18_S	PlIn	et	elulugudes =lugu  (PlIn  >elu+lugu !18_S
38700	riiklikul	riikliku	riiklik	25_A	SgAd	et	riiklikul =riikliku  (SgAd  >riiklik !25_A
38701	rahvuslikul	rahvusliku	rahvuslik	25_A	SgAd	et	rahvuslikul =rahvusliku  (SgAd  >rahvuslik !25_A
38706	11-st			xx_Q	SgEl	et	-st =  (SgEl  > !xx_Q
38707	huvidele	huvi	huvi	17_S	PlAll	et	huvidele =huvi  (PlAll  >huvi !17_S
38717	ameteid	amete	amet	02_S	PlP	et	ameteid =amete  (PlP  >amet !02_S
38719	riigitööl	töö	riigi+töö	26_S	SgAd	et	riigitööl =töö  (SgAd  >riigi+töö !26_S
38738	külapoes	poe	küla+pood	22_S	SgIn	et	külapoes =poe  (SgIn  >küla+pood !22_S
38743	autodega	auto	auto	16_S	PlKom	et	autodega =auto  (PlKom  >auto !16_S
38748	kapten	kapten	kapten	02_S	SgN	et	kapten =kapten  (SgN  >kapten !02_S
38752	salakaubandusega	kaubanduse	sala+kaubandus	11_S	SgKom	et	salakaubandusega =kaubanduse  (SgKom  >sala+kaubandus !11_S
38754	kartused	kartuse	kartus	11~09_S	PlN	et	kartused =kartuse  (PlN  >kartus !11~09_S
38759	ähvardati	ähvarda	ähvardama	27_V	IndIpfIps	et	ähvardati =ähvarda  (IndIpfIps  >ähvardama !27_V
38768	kultuurikiht	kiht	kultuuri+kiht	22_S	SgN	et	kultuurikiht =kiht  (SgN  >kultuuri+kiht !22_S
38773	elatusaladeks	ala	elatus+ala	17_S	PlTr	et	elatusaladeks =ala  (PlTr  >elatus+ala !17_S
38774	hülged	hülge	hüljes	07_S	PlN	et	hülged =hülge  (PlN  >hüljes !07_S
38777	elementidega	elementi	element	22_S	PlKom	et	elementidega =elementi  (PlKom  >element !22_S
38795	surmust	us	surm+uks	14_S	SgP	et	surmust =us  (SgP  >surm+uks !14_S
38801	siig	siig	siig	22_S	SgN	et	siig =siig  (SgN  >siig !22_S
38808	usundite	usundi	usund	02_S	PlG	et	usundite =usundi  (PlG  >usund !02_S
38809	animistlik	animistlik	animistlik	25_A	SgN	et	animistlik =animistlik  (SgN  >animistlik !25_A
38818	pereliikmeid	liikme	pere+liige	05_S	PlP	et	pereliikmeid =liikme  (PlP  >pere+liige !05_S
38834	riskantse	riskantse	riskantne	02_A	SgG	et	riskantse =riskantse  (SgG  >riskantne !02_A
38836	veoga	veo	vedu	18_S	SgKom	et	veoga =veo  (SgKom  >vedu !18_S
38839	südamelt	südame	süda	04_S	SgAbl	et	südamelt =südame  (SgAbl  >süda !04_S
38847	ministri	ministri	minister	02_S	SgG	et	ministri =ministri  (SgG  >minister !02_S
38860	koeraomaniku	omaniku	koera+omanik	25_S	SgG	et	koeraomaniku =omaniku  (SgG  >koera+omanik !25_S
38864	libahunt	hunt	liba+hunt	22_S	SgN	et	libahunt =hunt  (SgN  >liba+hunt !22_S
38867	taluperre	perre	talu+pere	16_S	SgAdt	et	taluperre =perre  (SgAdt  >talu+pere !16_S
38869	orjarahva	rahva	orja+rahvas	07_S	SgG	et	orjarahva =rahva  (SgG  >orja+rahvas !07_S
38876	lähtub	lähtu	lähtuma	27_V	IndPrSg3	et	lähtub =lähtu  (IndPrSg3  >lähtuma !27_V
38882	laar	laar	laar	22_S	SgN	et	laar =laar  (SgN  >laar !22_S
38896	sõjalaevad	laeva	sõja+laev	22_S	PlN	et	sõjalaevad =laeva  (PlN  >sõja+laev !22_S
38901	kindralid	kindrali	kindral	02_S	PlN	et	kindralid =kindrali  (PlN  >kindral !02_S
38903	toompealt	pea	toom+pea	26_S	SgAbl	et	toompealt =pea  (SgAbl  >toom+pea !26_S
38905	sisendab	sisenda	sisendama	27_V	IndPrSg3	et	sisendab =sisenda  (IndPrSg3  >sisendama !27_V
38910	meeleolud	olu	meele+olu	17_S	PlN	et	meeleolud =olu  (PlN  >meele+olu !17_S
38648	lauga	lau	laug	22_SA	SgKom	et	lauga =lau  (SgKom  >laug !22_SA
38650	lühter	lühter	lühter	02_S	SgN	et	lühter =lühter  (SgN  >lühter !02_S
38659	sektsioonis	sektsiooni	sektsioon	22_S	SgIn	et	sektsioonis =sektsiooni  (SgIn  >sektsioon !22_S
38676	jalatsid	jalatsi	jalats	02_S	PlN	et	jalatsid =jalatsi  (PlN  >jalats !02_S
38677	pesukorvis	korvi	pesu+korv	22_S	SgIn	et	pesukorvis =korvi  (SgIn  >pesu+korv !22_S
38680	pesupulberid	pulberi	pesu+pulber	02_S	PlN	et	pesupulberid =pulberi  (PlN  >pesu+pulber !02_S
38686	lift	lift	lift	22_S	SgN	et	lift =lift  (SgN  >lift !22_S
38688	kooliraamat	raamat	kooli+raamat	02_S	SgN	et	kooliraamat =raamat  (SgN  >kooli+raamat !02_S
38705	ideoloogiat	ideoloogia	ideoloogia	01_S	SgP	et	ideoloogiat =ideoloogia  (SgP  >ideoloogia !01_S
38709	õppusi	õppusi	õppus	11_S	PlP	et	õppusi =õppusi  (PlP  >õppus !11_S
38710	soovitada	soovita	soovitama	27_V	Inf	et	soovitada =soovita  (Inf  >soovitama !27_V
38711	parteiorganisatsioonidesse	organisatsiooni	part+ei+organisatsioon	22_S	PlIll	et	parteiorganisatsioonidesse =organisatsiooni  (PlIll  >part+ei+organisatsioon !22_S
38718	iseloomustas	musta	ise+loo+must	22_AS	SgIn	et	iseloomustas =musta  (SgIn  >ise+loo+must !22_AS
38723	pidevas	pideva	pidev	02_A	SgIn	et	pidevas =pideva  (SgIn  >pidev !02_A
38724	stressis	stressi	stress	22_S	SgIn	et	stressis =stressi  (SgIn  >stress !22_S
38725	suureneb	suurene	suurenema	27_V	IndPrSg3	et	suureneb =suurene  (IndPrSg3  >suurenema !27_V
38727	tegelete	tegele	tegelema	31~27_V	IndPrPl2	et	tegelete =tegele  (IndPrPl2  >tegelema !31~27_V
38728	paranete	parane	paranema	27_V	IndPrPl2	et	paranete =parane  (IndPrPl2  >paranema !27_V
38729	keskmist	keskmis	keskmine	12?10_A	SgP	et	keskmist =keskmis  (SgP  >keskmine !12?10_A
38734	igaühes	ühe	iga+üks	22_P	SgIn	et	igaühes =ühe  (SgIn  >iga+üks !22_P
38740	puhkusega	puhkuse	puhkus	11~09_S	SgKom	et	puhkusega =puhkuse  (SgKom  >puhkus !11~09_S
38755	ausad	ausa	aus	02_A	PlN	et	ausad =ausa  (PlN  >aus !02_A
38760	avaldate	avalda	avaldama	27_V	IndPrPl2	et	avaldate =avalda  (IndPrPl2  >avaldama !27_V
38764	mesoliitikumiks	mesoliitikumi	mesoliitikum	19_S	SgTr	et	mesoliitikumiks =mesoliitikumi  (SgTr  >mesoliitikum !19_S
38772	noolotsad	otsa	nool+ots	23?22_S	PlN	et	noolotsad =otsa  (PlN  >nool+ots !23?22_S
38780	neoliitikum	neoliitikum	neoliitikum	19_S	SgN	et	neoliitikum =neoliitikum  (SgN  >neoliitikum !19_S
38786	paikkondlik	paikkondlik	paikkondlik	25_A	SgN	et	paikkondlik =paikkondlik  (SgN  >paikkondlik !25_A
38789	esemetel	eseme	ese	04_S	PlAd	et	esemetel =eseme  (PlAd  >ese !04_S
38791	vahendil	vahendi	vahend	02_S	SgAd	et	vahendil =vahendi  (SgAd  >vahend !02_S
38792	hilisneoliitikum	neoliitikum	hilis+neoliitikum	19_S	SgN	et	hilisneoliitikum =neoliitikum  (SgN  >hilis+neoliitikum !19_S
38794	tarbeks	tarbe	tarve	06_S	SgTr	et	tarbeks =tarbe  (SgTr  >tarve !06_S
38797	asulas	asula	asula	01_S	SgIn	et	asulas =asula  (SgIn  >asula !01_S
38810	silmadele	silma	silm	22_S	PlAll	et	silmadele =silma  (PlAll  >silm !22_S
38814	kujunditega	kujundi	kujund	02_S	PlKom	et	kujunditega =kujundi  (PlKom  >kujund !02_S
38815	aukudega	auku	auk	22_S	PlKom	et	aukudega =auku  (PlKom  >auk !22_S
38816	mustriga	mustri	muster	02_S	SgKom	et	mustriga =mustri  (SgKom  >muster !02_S
38817	venekirved	kirve	vene+kirves	07_S	PlN	et	venekirved =kirve  (PlN  >vene+kirves !07_S
38820	käigul	käigu	käik	22_S	SgAd	et	käigul =käigu  (SgAd  >käik !22_S
38821	grammatilist	grammatilis	grammatiline	12_A	SgP	et	grammatilist =grammatilis  (SgP  >grammatiline !12_A
38823	kaadrisse	kaadri	kaader	02_S	SgIll	et	kaadrisse =kaadri  (SgIll  >kaader !02_S
38828	laulutekst	tekst	laulu+tekst	22_S	SgN	et	laulutekst =tekst  (SgN  >laulu+tekst !22_S
38829	telefonivestlus	vestlus	telefoni+vestlus	11~09_S	SgN	et	telefonivestlus =vestlus  (SgN  >telefoni+vestlus !11~09_S
38831	pälvib	pälvi	pälvima	28_V	IndPrSg3	et	pälvib =pälvi  (IndPrSg3  >pälvima !28_V
38833	hulljulged	julge	hull+julge	01_A	PlN	et	hulljulged =julge  (PlN  >hull+julge !01_A
38837	vait	vait	vait	41_DI	ID	et	vait =vait  (ID  >vait !41_DI
38840	ausaid	ausa	aus	02_A	PlP	et	ausaid =ausa  (PlP  >aus !02_A
38848	piirivalvurile	valvuri	piiri+valvur	02_S	SgAll	et	piirivalvurile =valvuri  (SgAll  >piiri+valvur !02_S
38853	lähedasest	lähedase	lähedane	12_AS	SgEl	et	lähedasest =lähedase  (SgEl  >lähedane !12_AS
38854	koeraomanik	omanik	koera+omanik	25_S	SgN	et	koeraomanik =omanik  (SgN  >koera+omanik !25_S
38857	libe	libe	libe	02_AS	SgN	et	libe =libe  (SgN  >libe !02_AS
38859	pidurite	piduri	pidur	02_S	PlG	et	pidurite =piduri  (PlG  >pidur !02_S
38868	libahundiks	hundi	liba+hunt	22_S	SgTr	et	libahundiks =hundi  (SgTr  >liba+hunt !22_S
38870	põgeneb	põgene	põgenema	27_V	IndPrSg3	et	põgeneb =põgene  (IndPrSg3  >põgenema !27_V
38872	jooned	joone	joon	13_S	PlN	et	jooned =joone  (PlN  >joon !13_S
38703	riigikord	kord	riigi+kord	22_S	SgN	et	riigikord =kord  (SgN  >riigi+kord !22_S
38712	lobises	lobise	lobisema	27_V	IndIpfSg3	et	lobises =lobise  (IndIpfSg3  >lobisema !27_V
38713	büroodel	büroo	büroo	26_S	PlAd	et	büroodel =büroo  (PlAd  >büroo !26_S
38714	naistega	nais	naine	12_S	PlKom	et	naistega =nais  (PlKom  >naine !12_S
38720	kohvipausist	pausi	kohvi+paus	22_S	SgEl	et	kohvipausist =pausi  (SgEl  >kohvi+paus !22_S
38722	tegusõnad	sõna	tegu+sõna	17_S	PlN	et	tegusõnad =sõna  (PlN  >tegu+sõna !17_S
38731	tegurite	teguri	tegur	02_S	PlG	et	tegurite =teguri  (PlG  >tegur !02_S
38733	omadele	oma	oma	17_A	PlAll	et	omadele =oma  (PlAll  >oma !17_A
38735	ilusatele	ilusa	ilus	02_A	PlAll	et	ilusatele =ilusa  (PlAll  >ilus !02_A
38737	kütta	kütt	kütma	35_V	Inf	et	kütta =kütt  (Inf  >kütma !35_V
38746	võitleb	võitle	võitlema	30_V	IndPrSg3	et	võitleb =võitle  (IndPrSg3  >võitlema !30_V
38753	ebavõrdne	võrdne	eba+võrdne	02_A	SgN	et	ebavõrdne =võrdne  (SgN  >eba+võrdne !02_A
38757	ülesandjaks	andja	üles+andja	01_S	SgTr	et	ülesandjaks =andja  (SgTr  >üles+andja !01_S
38763	karistatakse	karista	karistama	27_V	IndPrIps	et	karistatakse =karista  (IndPrIps  >karistama !27_V
38769	mesoliitikum	mesoliitikum	mesoliitikum	19_S	SgN	et	mesoliitikum =mesoliitikum  (SgN  >mesoliitikum !19_S
38770	mesoliitikumis	mesoliitikumi	mesoliitikum	19_S	SgIn	et	mesoliitikumis =mesoliitikumi  (SgIn  >mesoliitikum !19_S
38771	kalevid	kalevi	kalev	02_S	PlN	et	kalevid =kalevi  (PlN  >kalev !02_S
38779	neem	neem	neem	22_S	SgN	et	neem =neem  (SgN  >neem !22_S
38790	loodusmotiive	motiive	loodus+motiiv	22_S	PlP	et	loodusmotiive =motiive  (PlP  >loodus+motiiv !22_S
38800	tolt	to	too	00_P	SgAbl	et	tolt =to  (SgAbl  >too !00_P
38806	ehitistes	ehitis	ehitis	11_S	PlIn	et	ehitistes =ehitis  (PlIn  >ehitis !11_S
38811	keraamikaga	keraamika	keraamika	01_S	SgKom	et	keraamikaga =keraamika  (SgKom  >keraamika !01_S
38822	kursiivis	kursiivi	kursiiv	22_S	SgIn	et	kursiivis =kursiivi  (SgIn  >kursiiv !22_S
38838	hukkuda	hukku	hukkuma	27~28_V	Inf	et	hukkuda =hukku  (Inf  >hukkuma !27~28_V
38842	piirivalvurist	valvuri	piiri+valvur	02_S	SgEl	et	piirivalvurist =valvuri  (SgEl  >piiri+valvur !02_S
38845	tapetakse	tape	tapma	35_V	IndPrIps	et	tapetakse =tape  (IndPrIps  >tapma !35_V
38850	valetada	valeta	valetama	27_V	Inf	et	valetada =valeta  (Inf  >valetama !27_V
38858	jalgrattur	rattur	jalg+rattur	02_S	SgN	et	jalgrattur =rattur  (SgN  >jalg+rattur !02_S
38861	jalgratturil	ratturi	jalg+rattur	02_S	SgAd	et	jalgratturil =ratturi  (SgAd  >jalg+rattur !02_S
38873	margus	margu	mark	22_S	PlIn	et	margus =margu  (PlIn  >mark !22_S
38875	õigustada	õigusta	õigustama	27_V	Inf	et	õigustada =õigusta  (Inf  >õigustama !27_V
38887	mitteametlikuks	ametliku	mitte+ametlik	25_A	SgTr	et	mitteametlikuks =ametliku  (SgTr  >mitte+ametlik !25_A
38890	ametlikuks	ametliku	ametlik	25_A	SgTr	et	ametlikuks =ametliku  (SgTr  >ametlik !25_A
38898	proovib	proovi	proovima	28_V	IndPrSg3	et	proovib =proovi  (IndPrSg3  >proovima !28_V
38899	segadus	segadus	segadus	11_S	SgN	et	segadus =segadus  (SgN  >segadus !11_S
38918	kritiseeriti	kritiseeri	kritiseerima	28_V	IndIpfIps	et	kritiseeriti =kritiseeri  (IndIpfIps  >kritiseerima !28_V
38919	lugedes	luge	lugema	28_V	Ger	et	lugedes =luge  (Ger  >lugema !28_V
38924	rääts	rääts	rääts	22_S	SgN	et	rääts =rääts  (SgN  >rääts !22_S
38926	edusamme	samme	edu+samm	22_S	PlP	et	edusamme =samme  (PlP  >edu+samm !22_S
38928	moodsate	moodsa	moodne	02_A	PlG	et	moodsate =moodsa  (PlG  >moodne !02_A
38930	poolekunstis	kunsti	poole+kunst	22_S	SgIn	et	poolekunstis =kunsti  (SgIn  >poole+kunst !22_S
38934	areenil	areeni	areen	22_S	SgAd	et	areenil =areeni  (SgAd  >areen !22_S
38940	filmimaailm	ilm	filmi+maa+ilm	22_S	SgN	et	filmimaailm =ilm  (SgN  >filmi+maa+ilm !22_S
38941	rännu	rännu	ränd	22_S	SgG	et	rännu =rännu  (SgG  >ränd !22_S
38945	soosaare	saare	soo+saar	13_S	SgG	et	soosaare =saare  (SgG  >soo+saar !13_S
38951	emotsioonid	emotsiooni	emotsioon	22_S	PlN	et	emotsioonid =emotsiooni  (PlN  >emotsioon !22_S
38957	põhinebki	põhine	põhinema	27_V	IndPrSg3^	et	põhinebki =põhine  (IndPrSg3^  >põhinema !27_V
38960	koit	koit	koit	22_S	SgN	et	koit =koit  (SgN  >koit !22_S
38992	liusatakse	liusa	liuskama	29_V	IndPrIps	et	liusatakse =liusa  (IndPrIps  >liuskama !29_V
38997	isiklikke	isiklikke	isiklik	25_A	PlP	et	isiklikke =isiklikke  (PlP  >isiklik !25_A
39007	unistadagi	unista	unistama	27_V	Inf^	et	unistadagi =unista  (Inf^  >unistama !27_V
39008	abist	abi	abi	17_S	SgEl	et	abist =abi  (SgEl  >abi !17_S
39017	hävib	hävi	hävima	27_V	IndPrSg3	et	hävib =hävi  (IndPrSg3  >hävima !27_V
39022	maavärinad	värina	maa+värin	02_S	PlN	et	maavärinad =värina  (PlN  >maa+värin !02_S
39026	muretseda	muretse	muretsema	27_V	Inf	et	muretseda =muretse  (Inf  >muretsema !27_V
38812	terava	terava	terav	02_A	SgG	et	terava =terava  (SgG  >terav !02_A
38824	häiris	häiri	häirima	28_V	IndIpfSg3	et	häiris =häiri  (IndIpfSg3  >häirima !28_V
38826	mängufilme	filme	mängu+film	22_S	PlP	et	mängufilme =filme  (PlP  >mängu+film !22_S
38827	läbitähega	tähe	läbi+täht	22_S	SgKom	et	läbitähega =tähe  (SgKom  >läbi+täht !22_S
38835	ülemerenaabrite	naabri	üle+mere+naaber	02_S	PlG	et	ülemerenaabrite =naabri  (PlG  >üle+mere+naaber !02_S
38844	satub	satu	sattuma	28_V	IndPrSg3	et	satub =satu  (IndPrSg3  >sattuma !28_V
38846	käsul	käsu	käsk	22_S	SgAd	et	käsul =käsu  (SgAd  >käsk !22_S
38849	austatakse	austa	austama	27_V	IndPrIps	et	austatakse =austa  (IndPrIps  >austama !27_V
38851	kurvast	kurva	kurb	22_A	SgEl	et	kurvast =kurva  (SgEl  >kurb !22_A
38852	armastad	armasta	armastama	27_V	IndPrSg2	et	armastad =armasta  (IndPrSg2  >armastama !27_V
38855	jalutas	jaluta	jalutama	27_V	IndIpfSg3	et	jalutas =jaluta  (IndIpfSg3  >jalutama !27_V
38856	pidurdada	pidurda	pidurdama	27_V	Inf	et	pidurdada =pidurda  (Inf  >pidurdama !27_V
38862	pidurdama	pidurda	pidurdama	27_V	Sup	et	pidurdama =pidurda  (Sup  >pidurdama !27_V
38863	lõhkusin	lõhku	lõhkuma	28_V	IndIpfSg1	et	lõhkusin =lõhku  (IndIpfSg1  >lõhkuma !28_V
38865	jutustatakse	jutusta	jutustama	27_V	IndPrIps	et	jutustatakse =jutusta  (IndPrIps  >jutustama !27_V
38877	süüdistati	süüdista	süüdistama	27_V	IndIpfIps	et	süüdistati =süüdista  (IndIpfIps  >süüdistama !27_V
38880	ühiskondlik-poliitilised	poliitilise	ühiskondlik-poliitiline	12_A	PlN	et	ühiskondlik-poliitilised =poliitilise  (PlN  >ühiskondlik-poliitiline !12_A
38888	maareform	reform	maa+reform	22_S	SgN	et	maareform =reform  (SgN  >maa+reform !22_S
38893	sündmustega	sündmus	sündmus	11~09_S	PlKom	et	sündmustega =sündmus  (PlKom  >sündmus !11~09_S
38900	rüütel	rüütel	rüütel	02_S	SgN	et	rüütel =rüütel  (SgN  >rüütel !02_S
38909	pehmenes	pehmene	pehmenema	27_V	IndIpfSg3	et	pehmenes =pehmene  (IndIpfSg3  >pehmenema !27_V
38911	optimistlikud	optimistliku	optimistlik	25_A	PlN	et	optimistlikud =optimistliku  (PlN  >optimistlik !25_A
38921	viljeldi	viljel	viljelema	31_V	IndIpfIps	et	viljeldi =viljel  (IndIpfIps  >viljelema !31_V
38923	sink	sink	sink	22_S	SgN	et	sink =sink  (SgN  >sink !22_S
38925	teaduse	teaduse	teadus	11~09_S	SgG	et	teaduse =teaduse  (SgG  >teadus !11~09_S
38931	viimne	viimne	viimne	02_A	SgN	et	viimne =viimne  (SgN  >viimne !02_A
38936	suudetakse	suude	suutma	34_V	IndPrIps	et	suudetakse =suude  (IndPrIps  >suutma !34_V
38946	sugulasrahvad	rahva	sugulas+rahvas	07_S	PlN	et	sugulasrahvad =rahva  (PlN  >sugulas+rahvas !07_S
38952	tollasele	tollase	tollane	10_A	SgAll	et	tollasele =tollase  (SgAll  >tollane !10_A
38962	linnused	linnuse	linnus	09_S	PlN	et	linnused =linnuse  (PlN  >linnus !09_S
38974	kullameistrid	meistri	kulla+meister	02_S	PlN	et	kullameistrid =meistri  (PlN  >kulla+meister !02_S
38982	gildid	gildi	gild	22_S	PlN	et	gildid =gildi  (PlN  >gild !22_S
38986	hariti	hari	harima	27_V	IndIpfIps	et	hariti =hari  (IndIpfIps  >harima !27_V
38993	õigeuskliku	uskliku	õige+usklik	25_AS	SgG	et	õigeuskliku =uskliku  (SgG  >õige+usklik !25_AS
38995	suudluse	suudluse	suudlus	11~09_S	SgG	et	suudluse =suudluse  (SgG  >suudlus !11~09_S
38998	intiimsest	intiimse	intiimne	02_A	SgEl	et	intiimsest =intiimse  (SgEl  >intiimne !02_A
38999	privaatne	privaatne	privaatne	02_A	SgN	et	privaatne =privaatne  (SgN  >privaatne !02_A
39004	transpordivahend	vahend	transpordi+vahend	02_S	SgN	et	transpordivahend =vahend  (SgN  >transpordi+vahend !02_S
39011	olendid	olendi	olend	02_S	PlN	et	olendid =olendi  (PlN  >olend !02_S
39015	peatada	peata	peatama	27_V	Inf	et	peatada =peata  (Inf  >peatama !27_V
39018	füüsikat	füüsika	füüsika	01_S	SgP	et	füüsikat =füüsika  (SgP  >füüsika !01_S
39023	rasketel	raske	raske	01_A	PlAd	et	rasketel =raske  (PlAd  >raske !01_A
39033	suudame	suuda	suutma	34_V	IndPrPl1	et	suudame =suuda  (IndPrPl1  >suutma !34_V
39034	põgeneda	põgene	põgenema	27_V	Inf	et	põgeneda =põgene  (Inf  >põgenema !27_V
39045	julgen	julge	julgema	27_V	IndPrSg1	et	julgen =julge  (IndPrSg1  >julgema !27_V
39048	mobiilita	mobiili	mobiil	22_S	SgAb	et	mobiilita =mobiili  (SgAb  >mobiil !22_S
39050	eluaja	aja	elu+aeg	22_S	SgG	et	eluaja =aja  (SgG  >elu+aeg !22_S
39054	uisutada	uisuta	uisutama	27_V	Inf	et	uisutada =uisuta  (Inf  >uisutama !27_V
39065	esmalt	esmalt	esmalt	41_D	ID	et	esmalt =esmalt  (ID  >esmalt !41_D
39068	teaduses	teaduse	teadus	11~09_S	SgIn	et	teaduses =teaduse  (SgIn  >teadus !11~09_S
39070	kaastunne	tunne	kaas+tunne	06_S	SgN	et	kaastunne =tunne  (SgN  >kaas+tunne !06_S
39075	investeeringutega	investeeringu	investeering	02_S	PlKom	et	investeeringutega =investeeringu  (PlKom  >investeering !02_S
39084	üleni	üleni	üleni	41_D	ID	et	üleni =üleni  (ID  >üleni !41_D
38830	hüüab	hüüa	hüüdma	34_V	IndPrSg3	et	hüüab =hüüa  (IndPrSg3  >hüüdma !34_V
38832	rannakülas	küla	ranna+küla	17_S	SgIn	et	rannakülas =küla  (SgIn  >ranna+küla !17_S
38841	salakaubavedajatest	vedaja	sala+kauba+vedaja	01_S	PlEl	et	salakaubavedajatest =vedaja  (PlEl  >sala+kauba+vedaja !01_S
38843	piirivalvurid	valvuri	piiri+valvur	02_S	PlN	et	piirivalvurid =valvuri  (PlN  >piiri+valvur !02_S
38866	orjaaegsest	aegse	orja+aegne	02_A	SgEl	et	orjaaegsest =aegse  (SgEl  >orja+aegne !02_A
38871	romantilised	romantilise	romantiline	12_A	PlN	et	romantilised =romantilise  (PlN  >romantiline !12_A
38874	margust	margu	mark	22_S	PlEl	et	margust =margu  (PlEl  >mark !22_S
38879	kultuuritarbimist	tarbimis	kultuuri+tarbimine	12_S	SgP	et	kultuuritarbimist =tarbimis  (SgP  >kultuuri+tarbimine !12_S
38884	kujundama	kujunda	kujundama	27_V	Sup	et	kujundama =kujunda  (Sup  >kujundama !27_V
38885	sotsialistliku	sotsialistliku	sotsialistlik	25_A	SgG	et	sotsialistliku =sotsialistliku  (SgG  >sotsialistlik !25_A
38886	vabavärss	värss	vaba+värss	22_S	SgN	et	vabavärss =värss  (SgN  >vaba+värss !22_S
38894	dokumentaalsed	dokumentaalse	dokumentaalne	02_A	PlN	et	dokumentaalsed =dokumentaalse  (PlN  >dokumentaalne !02_A
38895	kaadrid	kaadri	kaader	02_S	PlN	et	kaadrid =kaadri  (PlN  >kaader !02_S
38902	pealinnade	linna	pea+linn	22_S	PlG	et	pealinnade =linna  (PlG  >pea+linn !22_S
38907	sulaperioodil	perioodi	sula+periood	22_S	SgAd	et	sulaperioodil =perioodi  (SgAd  >sula+periood !22_S
38908	vaadetega	vaade	vaade	06_S	PlKom	et	vaadetega =vaade  (PlKom  >vaade !06_S
38922	munder	munder	munder	02_S	SgN	et	munder =munder  (SgN  >munder !02_S
38927	raam	raam	raam	22_S	SgN	et	raam =raam  (SgN  >raam !22_S
38929	teadusharudega	haru	teadus+haru	17_S	PlKom	et	teadusharudega =haru  (PlKom  >teadus+haru !17_S
38935	rahumeelsel	meelse	rahu+meelne	02_A	SgAd	et	rahumeelsel =meelse  (SgAd  >rahu+meelne !02_A
38937	välisriigid	riigi	välis+riik	22_S	PlN	et	välisriigid =riigi  (PlN  >välis+riik !22_S
38938	kajastatakse	kajasta	kajastama	27_V	IndPrIps	et	kajastatakse =kajasta  (IndPrIps  >kajastama !27_V
38947	taasiseseisvumise	seisvumise	taas+ise+seisvumine	12_S	SgG	et	taasiseseisvumise =seisvumise  (SgG  >taas+ise+seisvumine !12_S
38948	päevalehe	lehe	päeva+leht	22_S	SgG	et	päevalehe =lehe  (SgG  >päeva+leht !22_S
38953	kodanikule	kodaniku	kodanik	25_S	SgAll	et	kodanikule =kodaniku  (SgAll  >kodanik !25_S
38954	järeldan	järelda	järeldama	27_V	IndPrSg1	et	järeldan =järelda  (IndPrSg1  >järeldama !27_V
38955	põhisündmused	sündmuse	põhi+sündmus	11~09_S	PlN	et	põhisündmused =sündmuse  (PlN  >põhi+sündmus !11~09_S
38964	metallid	metalli	metall	22_S	PlN	et	metallid =metalli  (PlN  >metall !22_S
38968	kividest	kivi	kivi	17_S	PlEl	et	kividest =kivi  (PlEl  >kivi !17_S
38969	rändjutustajad	jutustaja	ränd+jutustaja	01_S	PlN	et	rändjutustajad =jutustaja  (PlN  >ränd+jutustaja !01_S
38973	mujalt	mujalt	mujalt	41_D	ID	et	mujalt =mujalt  (ID  >mujalt !41_D
38975	oidusid	oidu	oid	22_S	PlP	et	oidusid =oidu  (PlP  >oid !22_S
38979	siseasjadega	asja	sise+asi	24_S	PlKom	et	siseasjadega =asja  (PlKom  >sise+asi !24_S
38980	elanikuks	elaniku	elanik	25_S	SgTr	et	elanikuks =elaniku  (SgTr  >elanik !25_S
38983	tsunftid	tsunfti	tsunft	22_S	PlN	et	tsunftid =tsunfti  (PlN  >tsunft !22_S
38987	kaubandust	kaubandus	kaubandus	11_S	SgP	et	kaubandust =kaubandus  (SgP  >kaubandus !11_S
38990	metalle	metalle	metall	22_S	PlP	et	metalle =metalle  (PlP  >metall !22_S
38994	ettekäänete	kääne	ette+kääne	06_S	PlG	et	ettekäänete =kääne  (PlG  >ette+kääne !06_S
38996	läbielamised	elamise	läbi+elamine	12_S	PlN	et	läbielamised =elamise  (PlN  >läbi+elamine !12_S
39006	sünnivad	sünni	sündima	28_V	IndPrPl3	et	sünnivad =sünni  (IndPrPl3  >sündima !28_V
39009	teenused	teenuse	teenus	09_S	PlN	et	teenused =teenuse  (PlN  >teenus !09_S
39012	kataklüsmid	kataklüsmi	kataklüsm	22_S	PlN	et	kataklüsmid =kataklüsmi  (PlN  >kataklüsm !22_S
39020	mõeldes	mõel	mõtlema	30_V	Ger	et	mõeldes =mõel  (Ger  >mõtlema !30_V
39025	küttima	kütti	küttima	28_V	Sup	et	küttima =kütti  (Sup  >küttima !28_V
39041	mingisugusest	suguse	mingi+sugune	10_P	SgEl	et	mingisugusest =suguse  (SgEl  >mingi+sugune !10_P
39042	veast	vea	viga	18_S	SgEl	et	veast =vea  (SgEl  >viga !18_S
39044	pluusile	pluusi	pluus	22_S	SgAll	et	pluusile =pluusi  (SgAll  >pluus !22_S
39053	igasse	iga	iga	17_P	SgIll	et	igasse =iga  (SgIll  >iga !17_P
39058	miskit	miski	miski	01_S	SgP	et	miskit =miski  (SgP  >miski !01_S
39059	halvale	halva	halb	22_A	SgAll	et	halvale =halva  (SgAll  >halb !22_A
39072	naudivad	naudi	nautima	28_V	IndPrPl3	et	naudivad =naudi  (IndPrPl3  >nautima !28_V
39074	ebainimlik	inimlik	eba+inimlik	25_A	SgN	et	ebainimlik =inimlik  (SgN  >eba+inimlik !25_A
39080	ohust	ohu	oht	22_S	SgEl	et	ohust =ohu  (SgEl  >oht !22_S
38878	tapeti	tape	tapma	35_V	IndIpfIps	et	tapeti =tape  (IndIpfIps  >tapma !35_V
38881	nimetage	nimeta	nimetama	27_V	ImpPrPl2	et	nimetage =nimeta  (ImpPrPl2  >nimetama !27_V
38883	plaatide	plaati	plaat	22_S	PlG	et	plaatide =plaati  (PlG  >plaat !22_S
38889	organisatsioon	organisatsioon	organisatsioon	22_S	SgN	et	organisatsioon =organisatsioon  (SgN  >organisatsioon !22_S
38891	vabadusearmastus	armastus	vabaduse+armastus	11_S	SgN	et	vabadusearmastus =armastus  (SgN  >vabaduse+armastus !11_S
38892	pealkirjadega	kirja	peal+kiri	24_S	PlKom	et	pealkirjadega =kirja  (PlKom  >peal+kiri !24_S
38897	tankid	tanki	tank	22_S	PlN	et	tankid =tanki  (PlN  >tank !22_S
38904	ahel	ahel	ahel	02_S	SgN	et	ahel =ahel  (SgN  >ahel !02_S
38906	millisest	millise	milline	10_P	SgEl	et	millisest =millise  (SgEl  >milline !10_P
38914	elutahet	tahe	elu+tahe	06_S	SgP	et	elutahet =tahe  (SgP  >elu+tahe !06_S
38915	läänega	lääne	lääs	14_S	SgKom	et	läänega =lääne  (SgKom  >lääs !14_S
38916	otsiti	otsi	otsima	28_V	IndIpfIps	et	otsiti =otsi  (IndIpfIps  >otsima !28_V
38917	harmoonilist	harmoonilis	harmooniline	12_A	SgP	et	harmoonilist =harmoonilis  (SgP  >harmooniline !12_A
38932	mrp-st	mrp	mrp	xx_Q	SgEl	et	mrp-st =mrp  (SgEl  >mrp !xx_Q
38933	riikidele	riiki	riik	22_S	PlAll	et	riikidele =riiki  (PlAll  >riik !22_S
38942	kihk	kihk	kihk	22_S	SgN	et	kihk =kihk  (SgN  >kihk !22_S
38943	inimsuhted	suhte	inim+suhe	06_S	PlN	et	inimsuhted =suhte  (PlN  >inim+suhe !06_S
38949	osasid	osa	osa	17_S	PlP	et	osasid =osa  (PlP  >osa !17_S
38950	kõhklused	kõhkluse	kõhklus	11~09_S	PlN	et	kõhklused =kõhkluse  (PlN  >kõhklus !11~09_S
38958	raag	raag	raag	22_S	SgN	et	raag =raag  (SgN  >raag !22_S
38959	säärast	sääras	säärane	10_P	SgP	et	säärast =sääras  (SgP  >säärane !10_P
38965	tegevusalaks	ala	tegevus+ala	17_S	SgTr	et	tegevusalaks =ala  (SgTr  >tegevus+ala !17_S
38967	gruppidena	gruppi	grupp	22_S	PlEs	et	gruppidena =gruppi  (PlEs  >grupp !22_S
38971	muinasajaks	aja	muinas+aeg	22_S	SgTr	et	muinasajaks =aja  (SgTr  >muinas+aeg !22_S
38972	talupojade	poja	talu+poja	17_S	PlG	et	talupojade =poja  (PlG  >talu+poja !17_S
38976	võimuorgan	organ	võimu+organ	02_S	SgN	et	võimuorgan =organ  (SgN  >võimu+organ !02_S
38977	raehärrat	härra	rae+härra	16_S	SgP	et	raehärrat =härra  (SgP  >rae+härra !16_S
38978	raehärrasid	härra	rae+härra	16_S	PlP	et	raehärrasid =härra  (PlP  >rae+härra !16_S
38985	maaga	maa	maa	26_S	SgKom	et	maaga =maa  (SgKom  >maa !26_S
38988	humalaid	humala	humal	02_S	PlP	et	humalaid =humala  (PlP  >humal !02_S
38991	pääs	pääs	pääs	22_S	SgN	et	pääs =pääs  (SgN  >pääs !22_S
39000	suudlus	suudlus	suudlus	11~09_S	SgN	et	suudlus =suudlus  (SgN  >suudlus !11~09_S
39001	meenutab	meenuta	meenutama	27_V	IndPrSg3	et	meenutab =meenuta  (IndPrSg3  >meenutama !27_V
39002	sõltume	sõltu	sõltuma	27_V	IndPrPl1	et	sõltume =sõltu  (IndPrPl1  >sõltuma !27_V
39005	leiutas	leiuta	leiutama	27_V	IndIpfSg3	et	leiutas =leiuta  (IndIpfSg3  >leiutama !27_V
39021	loodusnähtusi	nähtusi	loodus+nähtus	11_S	PlP	et	loodusnähtusi =nähtusi  (PlP  >loodus+nähtus !11_S
39027	sissetulekut	tuleku	sisse+tulek	02_S	SgP	et	sissetulekut =tuleku  (SgP  >sisse+tulek !02_S
39037	saatusliku	saatusliku	saatuslik	25_A	SgG	et	saatusliku =saatusliku  (SgG  >saatuslik !25_A
39038	demonstreeris	demonstreeri	demonstreerima	28_V	IndIpfSg3	et	demonstreeris =demonstreeri  (IndIpfSg3  >demonstreerima !28_V
39040	välk	välk	välk	22_S	SgN	et	välk =välk  (SgN  >välk !22_S
39055	jääst	jää	jää	26_S	SgEl	et	jääst =jää  (SgEl  >jää !26_S
39057	märg	märg	märg	22_AS	SgN	et	märg =märg  (SgN  >märg !22_AS
39064	kirjandiga	kirjandi	kirjand	02_S	SgKom	et	kirjandiga =kirjandi  (SgKom  >kirjand !02_S
39066	mõtleks	mõtle	mõtlema	30_V	KndPrPs	et	mõtleks =mõtle  (KndPrPs  >mõtlema !30_V
39076	haletseda	haletse	haletsema	27_V	Inf	et	haletseda =haletse  (Inf  >haletsema !27_V
39077	isiksused	isiksuse	isiksus	11_S	PlN	et	isiksused =isiksuse  (PlN  >isiksus !11_S
39079	looduskatastroofid	katastroofi	loodus+katastroof	22_S	PlN	et	looduskatastroofid =katastroofi  (PlN  >loodus+katastroof !22_S
39083	meremehel	mehe	mere+mees	13_S	SgAd	et	meremehel =mehe  (SgAd  >mere+mees !13_S
39085	roboti	roboti	robot	02_S	SgG	et	roboti =roboti  (SgG  >robot !02_S
39097	väljapanek	panek	välja+panek	02_S	SgN	et	väljapanek =panek  (SgN  >välja+panek !02_S
39100	töökohustusena	kohustuse	töö+kohustus	11_S	SgEs	et	töökohustusena =kohustuse  (SgEs  >töö+kohustus !11_S
39108	töökohustusi	kohustusi	töö+kohustus	11_S	PlP	et	töökohustusi =kohustusi  (PlP  >töö+kohustus !11_S
39111	eksisin	eksi	eksima	28_V	IndIpfSg1	et	eksisin =eksi  (IndIpfSg1  >eksima !28_V
39113	lisapäevaaastal	aasta	lisa+päeva+aasta	01_S	SgAd	et	lisapäevaaastal =aasta  (SgAd  >lisa+päeva+aasta !01_S
38912	ebademokraatiat	demokraatia	eba+demokraatia	01_S	SgP	et	ebademokraatiat =demokraatia  (SgP  >eba+demokraatia !01_S
38913	heldena	helde	helde	01_A	SgEs	et	heldena =helde  (SgEs  >helde !01_A
38920	uttu	uttu	udu	17_S	SgAdt	et	uttu =uttu  (SgAdt  >udu !17_S
38939	selleaja	aja	selle+aeg	22_S	SgG	et	selleaja =aja  (SgG  >selle+aeg !22_S
38944	dokumentaalfilme	filme	dokumentaal+film	22_S	PlP	et	dokumentaalfilme =filme  (PlP  >dokumentaal+film !22_S
38956	sündmustel	sündmus	sündmus	11~09_S	PlAd	et	sündmustel =sündmus  (PlAd  >sündmus !11~09_S
38961	külmavärinad	värina	külma+värin	02_S	PlN	et	külmavärinad =värina  (PlN  >külma+värin !02_S
38963	kaubanduslik	kaubanduslik	kaubanduslik	25_A	SgN	et	kaubanduslik =kaubanduslik  (SgN  >kaubanduslik !25_A
38966	tatra	tatra	tatar	08_S	SgG	et	tatra =tatra  (SgG  >tatar !08_S
38970	kolima	koli	kolima	27_V	Sup	et	kolima =koli  (Sup  >kolima !27_V
38981	linnal	linna	linn	22_S	SgAd	et	linnal =linna  (SgAd  >linn !22_S
38984	lihttöölised	töölise	liht+tööline	12?10_S	PlN	et	lihttöölised =töölise  (PlN  >liht+tööline !12?10_S
38989	veine	veine	vein	22_S	PlP	et	veine =veine  (PlP  >vein !22_S
39003	nüüdisaegsele	aegse	nüüdis+aegne	02_A	SgAll	et	nüüdisaegsele =aegse  (SgAll  >nüüdis+aegne !02_A
39010	paanikas	paanika	paanika	01_S	SgIn	et	paanikas =paanika  (SgIn  >paanika !01_S
39013	signaal	signaal	signaal	22_S	SgN	et	signaal =signaal  (SgN  >signaal !22_S
39014	tehnoloogiaga	tehnoloogia	tehnoloogia	01_S	SgKom	et	tehnoloogiaga =tehnoloogia  (SgKom  >tehnoloogia !01_S
39016	valime	vali	valima	27_V	IndPrPl1	et	valime =vali  (IndPrPl1  >valima !27_V
39019	geograafiat	geograafia	geograafia	01_S	SgP	et	geograafiat =geograafia  (SgP  >geograafia !01_S
39024	vaevama	vaeva	vaevama	29_V	Sup	et	vaevama =vaeva  (Sup  >vaevama !29_V
39028	paberis	paberi	paber	02_S	SgIn	et	paberis =paberi  (SgIn  >paber !02_S
39029	peituda	peitu	peituma	27_V	Inf	et	peituda =peitu  (Inf  >peituma !27_V
39031	ülestöötamiseta	töötamise	üles+töötamine	12_S	SgAb	et	ülestöötamiseta =töötamise  (SgAb  >üles+töötamine !12_S
39032	maakeral	kera	maa+kera	17_S	SgAd	et	maakeral =kera  (SgAd  >maa+kera !17_S
39036	primaat	primaat	primaat	22_S	SgN	et	primaat =primaat  (SgN  >primaat !22_S
39043	inimkond	inimkond	inimkond	22_S	SgN	et	inimkond =inimkond  (SgN  >inimkond !22_S
39049	hoolitakse	hooli	hoolima	28_V	IndPrIps	et	hoolitakse =hooli  (IndPrIps  >hoolima !28_V
39052	lampvõimendiga	võimendi	lamp+võimendi	01_S	SgKom	et	lampvõimendiga =võimendi  (SgKom  >lamp+võimendi !01_S
39061	langeda	lange	langema	27_V	Inf	et	langeda =lange  (Inf  >langema !27_V
39062	toitumisharjumised	harjumise	toitumis+harjumine	12_S	PlN	et	toitumisharjumised =harjumise  (PlN  >toitumis+harjumine !12_S
39067	spordis	spordi	sport	22_S	SgIn	et	spordis =spordi  (SgIn  >sport !22_S
39069	poliitikas	poliitika	poliitika	01_S	SgIn	et	poliitikas =poliitika  (SgIn  >poliitika !01_S
39089	kindad	kinda	kinnas	07_S	PlN	et	kindad =kinda  (PlN  >kinnas !07_S
39090	trell	trell	trell	22_S	SgN	et	trell =trell  (SgN  >trell !22_S
39092	lepinguta	lepingu	leping	02_S	SgAb	et	lepinguta =lepingu  (SgAb  >leping !02_S
39094	töökohustusel	kohustuse	töö+kohustus	11_S	SgAd	et	töökohustusel =kohustuse  (SgAd  >töö+kohustus !11_S
39099	välimusega	välimuse	välimus	11_S	SgKom	et	välimusega =välimuse  (SgKom  >välimus !11_S
39102	õpikut	õpiku	õpik	02_S	SgP	et	õpikut =õpiku  (SgP  >õpik !02_S
39106	karistada	karista	karistama	27_V	Inf	et	karistada =karista  (Inf  >karistama !27_V
39119	granaadi	granaadi	granaat	22_S	SgG	et	granaadi =granaadi  (SgG  >granaat !22_S
39125	nukk	nukk	nukk	22_S	SgN	et	nukk =nukk  (SgN  >nukk !22_S
39134	ülesandega	ande	üles+anne	06_S	SgKom	et	ülesandega =ande  (SgKom  >üles+anne !06_S
39155	telke	telke	telk	22_S	PlP	et	telke =telke  (PlP  >telk !22_S
39167	paigaldaksin	paigalda	paigaldama	27_V	KndPrSg1	et	paigaldaksin =paigalda  (KndPrSg1  >paigaldama !27_V
39177	kaubakeskused	keskuse	kauba+keskus	11~09_S	PlN	et	kaubakeskused =keskuse  (PlN  >kauba+keskus !11~09_S
39178	kopsudega	kopsu	kops	22_S	PlKom	et	kopsudega =kopsu  (PlKom  >kops !22_S
39181	sünnitada	sünnita	sünnitama	27_V	Inf	et	sünnitada =sünnita  (Inf  >sünnitama !27_V
39185	suurettevõtete	võte	suur+ette+võte	06_S	PlG	et	suurettevõtete =võte  (PlG  >suur+ette+võte !06_S
39189	asfalteerima	asfalteeri	asfalteerima	28_V	Sup	et	asfalteerima =asfalteeri  (Sup  >asfalteerima !28_V
39190	augud	augu	auk	22_S	PlN	et	augud =augu  (PlN  >auk !22_S
39193	elamurajoonides	rajooni	elamu+rajoon	22_S	PlIn	et	elamurajoonides =rajooni  (PlIn  >elamu+rajoon !22_S
39208	allergiat	allergia	allergia	01_S	SgP	et	allergiat =allergia  (SgP  >allergia !01_S
39212	praguneb	pragune	pragunema	27_V	IndPrSg3	et	praguneb =pragune  (IndPrSg3  >pragunema !27_V
39030	paljutki	palju	palju	16_P	SgP^	et	paljutki =palju  (SgP^  >palju !16_P
39035	hädaolukordades	korda	häda+olu+kord	22_S	PlIn	et	hädaolukordades =korda  (PlIn  >häda+olu+kord !22_S
39039	väljendisse	väljendi	väljend	02_S	SgIll	et	väljendisse =väljendi  (SgIll  >väljend !02_S
39046	suudaks	suuda	suutma	34_V	KndPrPs	et	suudaks =suuda  (KndPrPs  >suutma !34_V
39047	sellepeale	pea	selle+pea	26_S	SgAll	et	sellepeale =pea  (SgAll  >selle+pea !26_S
39051	masinate	masina	masin	02_S	PlG	et	masinate =masina  (PlG  >masin !02_S
39056	maapind	pind	maa+pind	22_S	SgN	et	maapind =pind  (SgN  >maa+pind !22_S
39060	raadiota	raadio	raadio	01_S	SgAb	et	raadiota =raadio  (SgAb  >raadio !01_S
39063	tahaksingi	taha	tahtma	34_V	KndPrSg1^	et	tahaksingi =taha  (KndPrSg1^  >tahtma !34_V
39071	kadedad	kadeda	kade	02_A	PlN	et	kadedad =kadeda  (PlN  >kade !02_A
39073	ebaõnnestub	õnnestu	eba+õnnestuma	27_V	IndPrSg3	et	ebaõnnestub =õnnestu  (IndPrSg3  >eba+õnnestuma !27_V
39078	kunas	kunas	kunas	41_D	ID	et	kunas =kunas  (ID  >kunas !41_D
39091	supler	supler	supler	02_S	SgN	et	supler =supler  (SgN  >supler !02_S
39098	kliendile	kliendi	klient	22_S	SgAll	et	kliendile =kliendi  (SgAll  >klient !22_S
39109	fantaasialend	lend	fantaasia+lend	22_S	SgN	et	fantaasialend =lend  (SgN  >fantaasia+lend !22_S
39117	liblikad	liblika	liblikas	02_S	PlN	et	liblikad =liblika  (PlN  >liblikas !02_S
39127	käsitud	käsitu	käsitu	01_A	PlN	et	käsitud =käsitu  (PlN  >käsitu !01_A
39137	puue	puue	puue	06_S	SgN	et	puue =puue  (SgN  >puue !06_S
39145	paarikaaslase	kaaslase	paari+kaaslane	12?10_S	SgG	et	paarikaaslase =kaaslase  (SgG  >paari+kaaslane !12?10_S
39153	suvepuhkuse	puhkuse	suve+puhkus	11~09_S	SgG	et	suvepuhkuse =puhkuse  (SgG  >suve+puhkus !11~09_S
39154	püstitas	püstita	püstitama	27_V	IndIpfSg3	et	püstitas =püstita  (IndIpfSg3  >püstitama !27_V
39156	töökogemuse	kogemuse	töö+kogemus	11_S	SgG	et	töökogemuse =kogemuse  (SgG  >töö+kogemus !11_S
39158	laiendas	laienda	laiendama	27_V	IndIpfSg3	et	laiendas =laienda  (IndIpfSg3  >laiendama !27_V
39168	viskaks	viska	viskama	29_V	KndPrPs	et	viskaks =viska  (KndPrPs  >viskama !29_V
39174	trükiksin	trüki	trükkima	28_V	KndPrSg1	et	trükiksin =trüki  (KndPrSg1  >trükkima !28_V
39176	loodusekaitsmist	kaitsmis	looduse+kaitsmine	12?10_S	SgP	et	loodusekaitsmist =kaitsmis  (SgP  >looduse+kaitsmine !12?10_S
39182	õhk	õhk	õhk	22_S	SgN	et	õhk =õhk  (SgN  >õhk !22_S
39183	saatatud	atu	saat+att	22_S	PlN	et	saatatud =atu  (PlN  >saat+att !22_S
39184	heitgaasidega	gaasi	heit+gaas	22_S	PlKom	et	heitgaasidega =gaasi  (PlKom  >heit+gaas !22_S
39198	puhastame	puhasta	puhastama	27_V	IndPrPl1	et	puhastame =puhasta  (IndPrPl1  >puhastama !27_V
39200	hambapastaga	pasta	hamba+pasta	16_S	SgKom	et	hambapastaga =pasta  (SgKom  >hamba+pasta !16_S
39204	kloor	kloor	kloor	22_S	SgN	et	kloor =kloor  (SgN  >kloor !22_S
39206	puhastamisvahendite	vahendi	puhastamis+vahend	02_S	PlG	et	puhastamisvahendite =vahendi  (PlG  >puhastamis+vahend !02_S
39209	kahjulikud	kahjuliku	kahjulik	25_A	PlN	et	kahjulikud =kahjuliku  (PlN  >kahjulik !25_A
39210	nahale	naha	nahk	22_S	SgAll	et	nahale =naha  (SgAll  >nahk !22_S
39213	ainetega	aine	aine	06_S	PlKom	et	ainetega =aine  (PlKom  >aine !06_S
39226	paberit	paberi	paber	02_S	SgP	et	paberit =paberi  (SgP  >paber !02_S
39227	planeet	planeet	planeet	22_S	SgN	et	planeet =planeet  (SgN  >planeet !22_S
39230	liivarannal	ranna	liiva+rand	22_S	SgAd	et	liivarannal =ranna  (SgAd  >liiva+rand !22_S
39231	suvevaheaeg	aeg	suve+vahe+aeg	22_S	SgN	et	suvevaheaeg =aeg  (SgN  >suve+vahe+aeg !22_S
39235	eestiperes	pere	eesti+pere	16_S	SgIn	et	eestiperes =pere  (SgIn  >eesti+pere !16_S
39240	lahendab	lahenda	lahendama	27_V	IndPrSg3	et	lahendab =lahenda  (IndPrSg3  >lahendama !27_V
39241	tarakanidega	tarakani	tarakan	19_S	PlKom	et	tarakanidega =tarakani  (PlKom  >tarakan !19_S
39250	videolaenamine	laenamine	video+laenamine	12_S	SgN	et	videolaenamine =laenamine  (SgN  >video+laenamine !12_S
39253	hindadega	hinda	hind	22_S	PlKom	et	hindadega =hinda  (PlKom  >hind !22_S
39254	kaubakeskuse	keskuse	kauba+keskus	11~09_S	SgG	et	kaubakeskuse =keskuse  (SgG  >kauba+keskus !11~09_S
39256	loendab	loenda	loendama	27_V	IndPrSg3	et	loendab =loenda  (IndPrSg3  >loendama !27_V
39257	äkilisena	äkilise	äkiline	12_A	SgEs	et	äkilisena =äkilise  (SgEs  >äkiline !12_A
39260	narva-jõesuus	suu	narva-jõe+suu	26_S	SgIn	et	narva-jõesuus =suu  (SgIn  >narva-jõe+suu !26_S
39261	toila-orus	oru	toila-org	22_S	SgIn	et	toila-orus =oru  (SgIn  >toila-org !22_S
39264	veeskutteriga	kutteri	vees+kutter	02_S	SgKom	et	veeskutteriga =kutteri  (SgKom  >vees+kutter !02_S
39267	parteide	partei	partei	26_S	PlG	et	parteide =partei  (PlG  >partei !26_S
39274	tutvuste	tutvus	tutvus	11~09_S	PlG	et	tutvuste =tutvus  (PlG  >tutvus !11~09_S
39283	põllumajanduse	majanduse	põllu+majandus	11_S	SgG	et	põllumajanduse =majanduse  (SgG  >põllu+majandus !11_S
39081	looduskatastroof	katastroof	loodus+katastroof	22_S	SgN	et	looduskatastroof =katastroof  (SgN  >loodus+katastroof !22_S
39082	ilmtingimata	ilmtingimata	ilm+tingimata	41_D	ID	et	ilmtingimata =ilmtingimata  (ID  >ilm+tingimata !41_D
39087	tagasilennupiletit	pileti	tagasi+lennu+pilet	02_S	SgP	et	tagasilennupiletit =pileti  (SgP  >tagasi+lennu+pilet !02_S
39088	kiiver	kiiver	kiiver	02_S	SgN	et	kiiver =kiiver  (SgN  >kiiver !02_S
39093	klassiruumis	ruumi	klassi+ruum	22_S	SgIn	et	klassiruumis =ruumi  (SgIn  >klassi+ruum !22_S
39095	kaupade	kaupa	kaup	22_S	PlG	et	kaupade =kaupa  (PlG  >kaup !22_S
39101	töövahendina	vahendi	töö+vahend	02_S	SgEs	et	töövahendina =vahendi  (SgEs  >töö+vahend !02_S
39104	klassikabinetid	kabineti	klassi+kabinet	22_S	PlN	et	klassikabinetid =kabineti  (PlN  >klassi+kabinet !22_S
39105	piiririkkujaid	rikkuja	piiri+rikkuja	01_S	PlP	et	piiririkkujaid =rikkuja  (PlP  >piiri+rikkuja !01_S
39107	trahvida	trahvi	trahvima	28_V	Inf	et	trahvida =trahvi  (Inf  >trahvima !28_V
39110	sattuda	sattu	sattuma	27~28_V	Inf	et	sattuda =sattu  (Inf  >sattuma !27~28_V
39112	ekslesin	eksle	ekslema	30_V	IndIpfSg1	et	ekslesin =eksle  (IndIpfSg1  >ekslema !30_V
39114	meelsamini	meelsamini	meelsamini	41_D	ID	et	meelsamini =meelsamini  (ID  >meelsamini !41_D
39116	eredad	ereda	ere	02_A	PlN	et	eredad =ereda  (PlN  >ere !02_A
39122	uudne	uudne	uudne	02_A	SgN	et	uudne =uudne  (SgN  >uudne !02_A
39123	lehvidega	lehvi	lehv	22_S	PlKom	et	lehvidega =lehvi  (PlKom  >lehv !22_S
39124	pärliteradega	tera	pärli+tera	17_S	PlKom	et	pärliteradega =tera  (PlKom  >pärli+tera !17_S
39131	tõenäosus	näosus	tõe+näosus	11~09_S	SgN	et	tõenäosus =näosus  (SgN  >tõe+näosus !11~09_S
39136	linnugripist	gripi	linnu+gripp	22_S	SgEl	et	linnugripist =gripi  (SgEl  >linnu+gripp !22_S
39139	mõnusad	mõnusa	mõnus	02_A	PlN	et	mõnusad =mõnusa  (PlN  >mõnus !02_A
39141	üldarenguks	arengu	üld+areng	02_S	SgTr	et	üldarenguks =arengu  (SgTr  >üld+areng !02_S
39147	paarikaaslane	kaaslane	paari+kaaslane	12?10_S	SgN	et	paarikaaslane =kaaslane  (SgN  >paari+kaaslane !12?10_S
39150	suhtles	suhtle	suhtlema	30_V	IndIpfSg3	et	suhtles =suhtle  (IndIpfSg3  >suhtlema !30_V
39152	teenindasin	teeninda	teenindama	27_V	IndIpfSg1	et	teenindasin =teeninda  (IndIpfSg1  >teenindama !27_V
39157	planeerisime	planeeri	planeerima	28_V	IndIpfPl1	et	planeerisime =planeeri  (IndIpfPl1  >planeerima !28_V
39162	finantseeriksin	finantseeri	finantseerima	28_V	KndPrSg1	et	finantseeriksin =finantseeri  (KndPrSg1  >finantseerima !28_V
39163	mängudeks	mängu	mäng	22_S	PlTr	et	mängudeks =mängu  (PlTr  >mäng !22_S
39173	viiksin	vii	viima	38_V	KndPrSg1	et	viiksin =vii  (KndPrSg1  >viima !38_V
39192	ehitaksin	ehita	ehitama	27_V	KndPrSg1	et	ehitaksin =ehita  (KndPrSg1  >ehitama !27_V
39195	väitega	väite	väide	06_S	SgKom	et	väitega =väite  (SgKom  >väide !06_S
39197	efektiivsed	efektiivse	efektiivne	02_A	PlN	et	efektiivsed =efektiivse  (PlN  >efektiivne !02_A
39199	hambaid	hamba	hammas	07_S	PlP	et	hambaid =hamba  (PlP  >hammas !07_S
39201	peseme	pese	pesema	36_V	IndPrPl1	et	peseme =pese  (IndPrPl1  >pesema !36_V
39205	pesuvalgendite	valgendi	pesu+valgendi	01_S	PlG	et	pesuvalgendite =valgendi  (PlG  >pesu+valgendi !01_S
39219	pimedal	pimeda	pime	02_AS	SgAd	et	pimedal =pimeda  (SgAd  >pime !02_AS
39224	papp	papp	papp	22_S	SgN	et	papp =papp  (SgN  >papp !22_S
39228	lapsepõlvast	ast	lapse+põlv+ast	22_S	SgN	et	lapsepõlvast =ast  (SgN  >lapse+põlv+ast !22_S
39233	keskaegse	aegse	kesk+aegne	02_A	SgG	et	keskaegse =aegse  (SgG  >kesk+aegne !02_A
39236	naljaka	naljaka	naljakas	02_A	SgG	et	naljaka =naljaka  (SgG  >naljakas !02_A
39242	tarakane	tarakane	tarakan	19_S	PlP	et	tarakane =tarakane  (PlP  >tarakan !19_S
39245	intervjueerisin	intervjueeri	intervjueerima	28_V	IndIpfSg1	et	intervjueerisin =intervjueeri  (IndIpfSg1  >intervjueerima !28_V
39247	võimalustest	võimalus	võimalus	11_S	PlEl	et	võimalustest =võimalus  (PlEl  >võimalus !11_S
39249	praktiseerida	praktiseeri	praktiseerima	28_V	Inf	et	praktiseerida =praktiseeri  (Inf  >praktiseerima !28_V
39251	sissetulekuga	tuleku	sisse+tulek	02_S	SgKom	et	sissetulekuga =tuleku  (SgKom  >sisse+tulek !02_S
39258	alkoholita	alkoholi	alkohol	19_S	SgAb	et	alkoholita =alkoholi  (SgAb  >alkohol !19_S
39262	toilo-orus	oru	toilo-org	22_S	SgIn	et	toilo-orus =oru  (SgIn  >toilo-org !22_S
39266	esindusorganeid	organe	esindus+organ	02_S	PlP	et	esindusorganeid =organe  (PlP  >esindus+organ !02_S
39268	ladviku	ladviku	ladvik	02_SA	SgG	et	ladviku =ladviku  (SgG  >ladvik !02_SA
39269	ühiskonnamudel	mudel	ühis+konna+mudel	02_S	SgN	et	ühiskonnamudel =mudel  (SgN  >ühis+konna+mudel !02_S
39280	käskudele	käsku	käsk	22_S	PlAll	et	käskudele =käsku  (PlAll  >käsk !22_S
39287	viljanormidega	normi	vilja+norm	22_S	PlKom	et	viljanormidega =normi  (PlKom  >vilja+norm !22_S
39289	kulakud	kulaku	kulak	02_S	PlN	et	kulakud =kulaku  (PlN  >kulak !02_S
39086	katastroof	katastroof	katastroof	22_S	SgN	et	katastroof =katastroof  (SgN  >katastroof !22_S
39096	klientidega	klienti	klient	22_S	PlKom	et	klientidega =klienti  (PlKom  >klient !22_S
39103	pastakat	pastaka	pastakas	02_S	SgP	et	pastakat =pastaka  (SgP  >pastakas !02_S
39120	jõhvikad	jõhvika	jõhvikas	02_S	PlN	et	jõhvikad =jõhvika  (PlN  >jõhvikas !02_S
39126	tähistasin	tähista	tähistama	27_V	IndIpfSg1	et	tähistasin =tähista  (IndIpfSg1  >tähistama !27_V
39128	peolauas	laua	peo+laud	22_S	SgIn	et	peolauas =laua  (SgIn  >peo+laud !22_S
39130	marsil	marsi	marss	22_S	SgAd	et	marsil =marsi  (SgAd  >marss !22_S
39133	kelguga	kelgu	kelk	22_S	SgKom	et	kelguga =kelgu  (SgKom  >kelk !22_S
39135	lühiinformatsioon	informatsioon	lühi+informatsioon	22_S	SgN	et	lühiinformatsioon =informatsioon  (SgN  >lühi+informatsioon !22_S
39142	e-ga	e	e	xx_Q	SgKom	et	e-ga =e  (SgKom  >e !xx_Q
39144	suvekoolivaheaeg	aeg	suve+kooli+vahe+aeg	22_S	SgN	et	suvekoolivaheaeg =aeg  (SgN  >suve+kooli+vahe+aeg !22_S
39146	suvega	suve	suvi	20_S	SgKom	et	suvega =suve  (SgKom  >suvi !20_S
39151	võõrkeelseid	keelse	võõr+keelne	02_A	PlP	et	võõrkeelseid =keelse  (PlP  >võõr+keelne !02_A
39160	veetaimed	taime	vee+taim	22_S	PlN	et	veetaimed =taime  (PlN  >vee+taim !22_S
39165	hädaohus	ohu	häda+oht	22_S	SgIn	et	hädaohus =ohu  (SgIn  >häda+oht !22_S
39170	klaasile	klaasi	klaas	22_S	SgAll	et	klaasile =klaasi  (SgAll  >klaas !22_S
39171	paberitele	paberi	paber	02_S	PlAll	et	paberitele =paberi  (PlAll  >paber !02_S
39172	jäätmeid	jäätme	jääde	05_S	PlP	et	jäätmeid =jäätme  (PlP  >jääde !05_S
39175	propageerida	propageeri	propageerima	28_V	Inf	et	propageerida =propageeri  (Inf  >propageerima !28_V
39179	hingamisteede	tee	hingamis+tee	26_S	PlG	et	hingamisteede =tee  (PlG  >hingamis+tee !26_S
39180	allergiad	allergia	allergia	01_S	PlN	et	allergiad =allergia  (PlN  >allergia !01_S
39186	haljastada	haljasta	haljastama	27_V	Inf	et	haljastada =haljasta  (Inf  >haljastama !27_V
39187	elamurajoone	rajoone	elamu+rajoon	22_S	PlP	et	elamurajoone =rajoone  (PlP  >elamu+rajoon !22_S
39188	hapniku	hapniku	hapnik	25_S	SgG	et	hapniku =hapniku  (SgG  >hapnik !25_S
39194	suurtel	suur	suur	13_A	PlAd	et	suurtel =suur  (PlAd  >suur !13_A
39196	kosmeetilised	kosmeetilise	kosmeetiline	12_A	PlN	et	kosmeetilised =kosmeetilise  (PlN  >kosmeetiline !12_A
39202	nõudepesuvahendiga	vahendi	nõude+pesu+vahend	02_S	SgKom	et	nõudepesuvahendiga =vahendi  (SgKom  >nõude+pesu+vahend !02_S
39211	nahk	nahk	nahk	22_S	SgN	et	nahk =nahk  (SgN  >nahk !22_S
39215	koduümbrusega	ümbruse	kodu+ümbrus	11~09_S	SgKom	et	koduümbrusega =ümbruse  (SgKom  >kodu+ümbrus !11~09_S
39216	kodukoht	koht	kodu+koht	22_S	SgN	et	kodukoht =koht  (SgN  >kodu+koht !22_S
39222	soovidega	soovi	soov	22_S	PlKom	et	soovidega =soovi  (PlKom  >soov !22_S
39237	jagad	jaga	jagama	27_V	IndPrSg2	et	jagad =jaga  (IndPrSg2  >jagama !27_V
39246	nädalani	nädala	nädal	02_S	SgTer	et	nädalani =nädala  (SgTer  >nädal !02_S
39248	positiivseid	positiivse	positiivne	02_A	PlP	et	positiivseid =positiivse  (PlP  >positiivne !02_A
39263	praktiseerisin	praktiseeri	praktiseerima	28_V	IndIpfSg1	et	praktiseerisin =praktiseeri  (IndIpfSg1  >praktiseerima !28_V
39265	totalitaarne	totalitaarne	totalitaarne	02_A	SgN	et	totalitaarne =totalitaarne  (SgN  >totalitaarne !02_A
39272	hüved	hüve	hüve	16_S	PlN	et	hüved =hüve  (PlN  >hüve !16_S
39284	piirides	piiri	piir	22_S	PlIn	et	piirides =piiri  (PlIn  >piir !22_S
39291	tendents	tendents	tendents	22_S	SgN	et	tendents =tendents  (SgN  >tendents !22_S
39292	teadusearendajad	arendaja	teaduse+arendaja	01_S	PlN	et	teadusearendajad =arendaja  (PlN  >teaduse+arendaja !01_S
39294	proletariaadi	proletariaadi	proletariaat	22_S	SgG	et	proletariaadi =proletariaadi  (SgG  >proletariaat !22_S
39295	perekondadest	perekonda	perekond	22_S	PlEl	et	perekondadest =perekonda  (PlEl  >perekond !22_S
39311	demokraatlikele	demokraatlike	demokraatlik	25_A	PlAll	et	demokraatlikele =demokraatlike  (PlAll  >demokraatlik !25_A
39321	aktiviseerub	aktiviseeru	aktiviseeruma	27_V	IndPrSg3	et	aktiviseerub =aktiviseeru  (IndPrSg3  >aktiviseeruma !27_V
39323	muistseks	muistse	muistne	02_A	SgTr	et	muistseks =muistse  (SgTr  >muistne !02_A
39329	iseloomuliku	loomuliku	ise+loomulik	25_A	SgG	et	iseloomuliku =loomuliku  (SgG  >ise+loomulik !25_A
39341	rauaajaga	aja	raua+aeg	22_S	SgKom	et	rauaajaga =aja  (SgKom  >raua+aeg !22_S
39342	metalliaja	aja	metalli+aeg	22_S	SgG	et	metalliaja =aja  (SgG  >metalli+aeg !22_S
39348	mängufilm	film	mängu+film	22_S	SgN	et	mängufilm =film  (SgN  >mängu+film !22_S
39355	luksuskaubad	kauba	luksus+kaup	22_S	PlN	et	luksuskaubad =kauba  (PlN  >luksus+kaup !22_S
39358	vastuvõtu	võtu	vastu+võtt	22_S	SgG	et	vastuvõtu =võtu  (SgG  >vastu+võtt !22_S
39359	kaheni	kahe	kaks	22_N	SgTer	et	kaheni =kahe  (SgTer  >kaks !22_N
39360	sekretär	sekretär	sekretär	19_S	SgN	et	sekretär =sekretär  (SgN  >sekretär !19_S
39115	paberist	paberi	paber	02_S	SgEl	et	paberist =paberi  (SgEl  >paber !02_S
39118	lemmikjook	jook	lemmik+jook	22_S	SgN	et	lemmikjook =jook  (SgN  >lemmik+jook !22_S
39121	suhkrus	suhkru	suhkur	02_S	SgIn	et	suhkrus =suhkru  (SgIn  >suhkur !02_S
39129	planeedis	planeedi	planeet	22_S	SgIn	et	planeedis =planeedi  (SgIn  >planeet !22_S
39132	ootus	ootus	ootus	11~09_S	SgN	et	ootus =ootus  (SgN  >ootus !11~09_S
39138	tublid	tubli	tubli	16_A	PlN	et	tublid =tubli  (PlN  >tubli !16_A
39140	üldtuntud	tuntu	üld+tuntu	01_S	PlN	et	üldtuntud =tuntu  (PlN  >üld+tuntu !01_S
39143	meenutame	meenuta	meenutama	27_V	IndPrPl1	et	meenutame =meenuta  (IndPrPl1  >meenutama !27_V
39148	pinginaaber	naaber	pingi+naaber	02_S	SgN	et	pinginaaber =naaber  (SgN  >pingi+naaber !02_S
39149	võõrkeeleoskust	oskus	võõr+keele+oskus	11~09_S	SgP	et	võõrkeeleoskust =oskus  (SgP  >võõr+keele+oskus !11~09_S
39159	veelomad	oma	veel+oma	17_A	PlN	et	veelomad =oma  (PlN  >veel+oma !17_A
39161	hukuvad	huku	hukkuma	28_V	IndPrPl3	et	hukuvad =huku  (IndPrPl3  >hukkuma !28_V
39164	rajaksin	raja	rajama	27_V	KndPrSg1	et	rajaksin =raja  (KndPrSg1  >rajama !27_V
39166	säiliks	säili	säilima	28_V	KndPrPs	et	säiliks =säili  (KndPrPs  >säilima !28_V
39169	spetsiaalseid	spetsiaalse	spetsiaalne	02_A	PlP	et	spetsiaalseid =spetsiaalse  (PlP  >spetsiaalne !02_A
39191	spetsiaalsed	spetsiaalse	spetsiaalne	02_A	PlN	et	spetsiaalsed =spetsiaalse  (PlN  >spetsiaalne !02_A
39203	kahjutavad	tava	kahju+tava	17_S	PlN	et	kahjutavad =tava  (PlN  >kahju+tava !17_S
39207	koostises	koostise	koostis	11~09_S	SgIn	et	koostises =koostise  (SgIn  >koostis !11~09_S
39214	leheküljelt	külje	lehe+külg	22_S	SgAbl	et	leheküljelt =külje  (SgAbl  >lehe+külg !22_S
39218	laternaid	laterna	latern	02_S	PlP	et	laternaid =laterna  (PlP  >latern !02_S
39221	haljastama	haljasta	haljastama	27_V	Sup	et	haljastama =haljasta  (Sup  >haljastama !27_V
39223	virmalise	virmalise	virmaline	12_S	SgG	et	virmalise =virmalise  (SgG  >virmaline !12_S
39229	globaalsest	globaalse	globaalne	02_A	SgEl	et	globaalsest =globaalse  (SgEl  >globaalne !02_A
39232	rootsil	rootsi	roots	22_S	SgAd	et	rootsil =rootsi  (SgAd  >roots !22_S
39234	eestikeeleoskuse	oskuse	eesti+keele+oskus	11~09_S	SgG	et	eestikeeleoskuse =oskuse  (SgG  >eesti+keele+oskus !11~09_S
39238	tarakan	tarakan	tarakan	19_S	SgN	et	tarakan =tarakan  (SgN  >tarakan !19_S
39239	super	super	super	02_S	SgN	et	super =super  (SgN  >super !02_S
39244	kasutaksin	kasuta	kasutama	27_V	KndPrSg1	et	kasutaksin =kasuta  (KndPrSg1  >kasutama !27_V
39255	suitsutada	suitsuta	suitsutama	27_V	Inf	et	suitsutada =suitsuta  (Inf  >suitsutama !27_V
39270	sidemed	sideme	side	04_S	PlN	et	sidemed =sideme  (PlN  >side !04_S
39271	majatarbekaubad	kauba	maja+tarbe+kaup	22_S	PlN	et	majatarbekaubad =kauba  (PlN  >maja+tarbe+kaup !22_S
39273	defitsiitsed	defitsiitse	defitsiitne	02_A	PlN	et	defitsiitsed =defitsiitse  (PlN  >defitsiitne !02_A
39275	kuuludes	kuulu	kuuluma	27_V	Ger	et	kuuludes =kuulu  (Ger  >kuuluma !27_V
39277	hüvesid	hüve	hüve	16_S	PlP	et	hüvesid =hüve  (PlP  >hüve !16_S
39279	päevanormid	normi	päeva+norm	22_S	PlN	et	päevanormid =normi  (PlN  >päeva+norm !22_S
39282	oludega	olu	olu	17_S	PlKom	et	oludega =olu  (PlKom  >olu !17_S
39298	riigiametniku	ametniku	riigi+ametnik	25_S	SgG	et	riigiametniku =ametniku  (SgG  >riigi+ametnik !25_S
39301	kapitalistlikel	kapitalistlike	kapitalistlik	25_A	PlAd	et	kapitalistlikel =kapitalistlike  (PlAd  >kapitalistlik !25_A
39306	turumajandus	majandus	turu+majandus	11_S	SgN	et	turumajandus =majandus  (SgN  >turu+majandus !11_S
39318	esseid	esse	essee	26_S	PlP	et	esseid =esse  (PlP  >essee !26_S
39322	dissidentide	dissidenti	dissident	22_S	PlG	et	dissidentide =dissidenti  (PlG  >dissident !22_S
39324	aladele	ala	ala	17_S	PlAll	et	aladele =ala  (PlAll  >ala !17_S
39331	tunti	tun	tundma	34_V	IndIpfIps	et	tunti =tun  (IndIpfIps  >tundma !34_V
39336	metalliajal	aja	metalli+aeg	22_S	SgAd	et	metalliajal =aja  (SgAd  >metalli+aeg !22_S
39338	rauaajale	aja	raua+aeg	22_S	SgAll	et	rauaajale =aja  (SgAll  >raua+aeg !22_S
39351	väliskirjandusega	kirjanduse	välis+kirjandus	11_S	SgKom	et	väliskirjandusega =kirjanduse  (SgKom  >välis+kirjandus !11_S
39357	läänte	lään	lääs	14_S	PlG	et	läänte =lään  (PlG  >lääs !14_S
39363	sekundiga	sekundi	sekund	02_S	SgKom	et	sekundiga =sekundi  (SgKom  >sekund !02_S
39388	väljakannatamatuks	kannatamatu	välja+kannatamatu	01_A	SgTr	et	väljakannatamatuks =kannatamatu  (SgTr  >välja+kannatamatu !01_A
39397	kaunisjärsk	järsk	kaunis+järsk	22_A	SgN	et	kaunisjärsk =järsk  (SgN  >kaunis+järsk !22_A
39398	kastides	kasti	kast	22_S	PlIn	et	kastides =kasti  (PlIn  >kast !22_S
39400	kojuveetud	veetu	koju+veetu	01_SA	PlN	et	kojuveetud =veetu  (PlN  >koju+veetu !01_SA
39419	korstenist	korsteni	korsten	02_S	SgEl	et	korstenist =korsteni  (SgEl  >korsten !02_S
39217	jalgrattasõitjad	sõitja	jalg+ratta+sõitja	01_S	PlN	et	jalgrattasõitjad =sõitja  (PlN  >jalg+ratta+sõitja !01_S
39220	vähendaks	vähenda	vähendama	27_V	KndPrPs	et	vähendaks =vähenda  (KndPrPs  >vähendama !27_V
39225	taastöödeldavaid	töödel	taas+töötlema	30_V	TAV_vAS	et	"taas+töödeldav %töödel  )TAV_vAS  <taas+töötlema ;30_V
39243	huumoriga	huumori	huumor	02_S	SgKom	et	huumoriga =huumori  (SgKom  >huumor !02_S
39252	kaupu	kaupu	kaup	22_S	PlP	et	kaupu =kaupu  (PlP  >kaup !22_S
39259	ebakasulik	kasulik	eba+kasulik	25_A	SgN	et	ebakasulik =kasulik  (SgN  >eba+kasulik !25_A
39276	näilised	näilise	näiline	12?10_A	PlN	et	näilised =näilise  (PlN  >näiline !12?10_A
39278	kolhooside	kolhoosi	kolhoos	22_S	PlG	et	kolhooside =kolhoosi  (PlG  >kolhoos !22_S
39281	pädevad	pädeva	pädev	02_A	PlN	et	pädevad =pädeva  (PlN  >pädev !02_A
39285	suruti	suru	suruma	27_V	IndIpfIps	et	suruti =suru  (IndIpfIps  >suruma !27_V
39288	soovil	soovi	soov	22_S	SgAd	et	soovil =soovi  (SgAd  >soov !22_S
39296	teeneka	teeneka	teenekas	02_A	SgG	et	teeneka =teeneka  (SgG  >teenekas !02_A
39297	järglane	järglane	järglane	12?10_S	SgN	et	järglane =järglane  (SgN  >järglane !12?10_S
39300	ateism	ateism	ateism	22_S	SgN	et	ateism =ateism  (SgN  >ateism !22_S
39305	seltsiliikumist	liikumis	seltsi+liikumine	12_S	SgP	et	seltsiliikumist =liikumis  (SgP  >seltsi+liikumine !12_S
39307	kapitalistlikud	kapitalistliku	kapitalistlik	25_A	PlN	et	kapitalistlikud =kapitalistliku  (PlN  >kapitalistlik !25_A
39308	tootmissuhted	suhte	tootmis+suhe	06_S	PlN	et	tootmissuhted =suhte  (PlN  >tootmis+suhe !06_S
39319	tõlkekirjandust	kirjandus	tõlke+kirjandus	11_S	SgP	et	tõlkekirjandust =kirjandus  (SgP  >tõlke+kirjandus !11_S
39327	loomakasvatusega	kasvatuse	looma+kasvatus	11_S	SgKom	et	loomakasvatusega =kasvatuse  (SgKom  >looma+kasvatus !11_S
39337	iseloomulikuks	loomuliku	ise+loomulik	25_A	SgTr	et	iseloomulikuks =loomuliku  (SgTr  >ise+loomulik !25_A
39339	rauaaja	aja	raua+aeg	22_S	SgG	et	rauaaja =aja  (SgG  >raua+aeg !22_S
39345	muinasajale	aja	muinas+aeg	22_S	SgAll	et	muinasajale =aja  (SgAll  >muinas+aeg !22_S
39350	huumorifilm	film	huumori+film	22_S	SgN	et	huumorifilm =film  (SgN  >huumori+film !22_S
39354	miniriigid	riigi	mini+riik	22_S	PlN	et	miniriigid =riigi  (PlN  >mini+riik !22_S
39365	klient	klient	klient	22_S	SgN	et	klient =klient  (SgN  >klient !22_S
39366	viieteistkümnest	kümnes	viie+teist+kümnene	10~12_AS	SgP	et	viieteistkümnest =kümnes  (SgP  >viie+teist+kümnene !10~12_AS
39368	tütart	tütar	tütar	08_S	SgP	et	tütart =tütar  (SgP  >tütar !08_S
39369	inglitega	ingli	ingel	02_S	PlKom	et	inglitega =ingli  (PlKom  >ingel !02_S
39370	pulgale	pulga	pulk	22_S	SgAll	et	pulgale =pulga  (SgAll  >pulk !22_S
39376	tütreid	tütre	tütar	08_S	PlP	et	tütreid =tütre  (PlP  >tütar !08_S
39384	raadioaparaadi	aparaadi	raadio+aparaat	22_S	SgG	et	raadioaparaadi =aparaadi  (SgG  >raadio+aparaat !22_S
39386	omalaadne	laadne	oma+laadne	02_AS	SgN	et	omalaadne =laadne  (SgN  >oma+laadne !02_AS
39392	seisatab	seisata	seisatama	27_V	IndPrSg3	et	seisatab =seisata  (IndPrSg3  >seisatama !27_V
39401	täismehe	mehe	täis+mees	13_S	SgG	et	täismehe =mehe  (SgG  >täis+mees !13_S
39402	mihkelil	mihkeli	mihkel	02_SA	SgAd	et	mihkelil =mihkeli  (SgAd  >mihkel !02_SA
39408	jaamas	jaama	jaam	22_S	SgIn	et	jaamas =jaama  (SgIn  >jaam !22_S
39420	seenemajal	maja	seene+maja	17_S	SgAd	et	seenemajal =maja  (SgAd  >seene+maja !17_S
39428	viibite	viibi	viibima	27_V	IndPrPl2	et	viibite =viibi  (IndPrPl2  >viibima !27_V
39445	kutsid	kutsi	kuts	22_S	PlN	et	kutsid =kutsi  (PlN  >kuts !22_S
39456	taksod	takso	takso	16_S	PlN	et	taksod =takso  (PlN  >takso !16_S
39459	lõhikut	lõhiku	lõhik	02_S	SgP	et	lõhikut =lõhiku  (SgP  >lõhik !02_S
39466	jõulu-asjad	asja	jõulu-asi	24_S	PlN	et	jõulu-asjad =asja  (PlN  >jõulu-asi !24_S
39468	toasse	toa	tuba	18_S	SgIll	et	toasse =toa  (SgIll  >tuba !18_S
39471	äratasin	ärata	äratama	27_V	IndIpfSg1	et	äratasin =ärata  (IndIpfSg1  >äratama !27_V
39473	laevas	laeva	laev	22_S	SgIn	et	laevas =laeva  (SgIn  >laev !22_S
39476	võõrastekodus	kodu	võõraste+kodu	17_S	SgIn	et	võõrastekodus =kodu  (SgIn  >võõraste+kodu !17_S
39481	tulesid	tule	tuli	20_S	PlP	et	tulesid =tule  (PlP  >tuli !20_S
39484	hõõgvein	vein	hõõg+vein	22_S	SgN	et	hõõgvein =vein  (SgN  >hõõg+vein !22_S
39490	põdra	põdra	põder	24_S	SgG	et	põdra =põdra  (SgG  >põder !24_S
39501	läänepoolse	poolse	lääne+poolne	02_A	SgG	et	läänepoolse =poolse  (SgG  >lääne+poolne !02_A
39506	peaministriks	ministri	pea+minister	02_S	SgTr	et	peaministriks =ministri  (SgTr  >pea+minister !02_S
39513	esmaplaan	plaan	esma+plaan	22_S	SgN	et	esmaplaan =plaan  (SgN  >esma+plaan !22_S
39515	kinkima	kinki	kinkima	28_V	Sup	et	kinkima =kinki  (Sup  >kinkima !28_V
39521	asetas	aseta	asetama	27_V	IndIpfSg3	et	asetas =aseta  (IndIpfSg3  >asetama !27_V
39286	maksudega	maksu	maks	22_S	PlKom	et	maksudega =maksu  (PlKom  >maks !22_S
39290	küüditamislained	laine	küüditamis+laine	06_S	PlN	et	küüditamislained =laine  (PlN  >küüditamis+laine !06_S
39293	vene-eestlased	eestlase	vene-eestlane	12?10_S	PlN	et	vene-eestlased =eestlase  (PlN  >vene-eestlane !12?10_S
39303	meediaallikate	allika	meedia+allikas	02_S	PlG	et	meediaallikate =allika  (PlG  >meedia+allikas !02_S
39309	stiimul	stiimul	stiimul	02_S	SgN	et	stiimul =stiimul  (SgN  >stiimul !02_S
39312	tarvitses	tarvitse	tarvitsema	27_V	IndIpfSg3	et	tarvitses =tarvitse  (IndIpfSg3  >tarvitsema !27_V
39316	inimesteni	inimes	inimene	12_S	PlTer	et	inimesteni =inimes  (PlTer  >inimene !12_S
39325	pronksiajal	aja	pronksi+aeg	22_S	SgAd	et	pronksiajal =aja  (SgAd  >pronksi+aeg !22_S
39326	tegeldi	tegel	tegelema	31_V	IndIpfIps	et	tegeldi =tegel  (IndIpfIps  >tegelema !31_V
39328	kiviajale	aja	kivi+aeg	22_S	SgAll	et	kiviajale =aja  (SgAll  >kivi+aeg !22_S
39332	maapealsed	pealse	maa+pealne	02_AS	PlN	et	maapealsed =pealse  (PlN  >maa+pealne !02_AS
39333	muinaslinnused	linnuse	muinas+linnus	09_S	PlN	et	muinaslinnused =linnuse  (PlN  >muinas+linnus !09_S
39335	maailmavaated	vaate	maa+ilma+vaade	06_S	PlN	et	maailmavaated =vaate  (PlN  >maa+ilma+vaade !06_S
39340	päiksed	päikse	päike	10_S	PlN	et	päiksed =päikse  (PlN  >päike !10_S
39343	murrang	murrang	murrang	02_S	SgN	et	murrang =murrang  (SgN  >murrang !02_S
39344	kergendas	kergenda	kergendama	27_V	IndIpfSg3	et	kergendas =kergenda  (IndIpfSg3  >kergendama !27_V
39346	totemistlik	totemistlik	totemistlik	25_A	SgN	et	totemistlik =totemistlik  (SgN  >totemistlik !25_A
39347	lähisvälismaana	maa	lähis+välis+maa	26_S	SgEs	et	lähisvälismaana =maa  (SgEs  >lähis+välis+maa !26_S
39353	näitemajandeid	majande	näite+majand	02_S	PlP	et	näitemajandeid =majande  (PlP  >näite+majand !02_S
39356	järelmaksuga	maksu	järel+maks	22_S	SgKom	et	järelmaksuga =maksu  (SgKom  >järel+maks !22_S
39361	kaheksat	kaheksa	kaheksa	01_N	SgP	et	kaheksat =kaheksa  (SgP  >kaheksa !01_N
39362	akent	aken	aken	08_S	SgP	et	akent =aken  (SgP  >aken !08_S
39364	relviga	relvi	relv	22_S	SgKom	et	relviga =relvi  (SgKom  >relv !22_S
39367	voorused	vooruse	voorus	11~09_S	PlN	et	voorused =vooruse  (PlN  >voorus !11~09_S
39374	võimaldada	võimalda	võimaldama	27_V	Inf	et	võimaldada =võimalda  (Inf  >võimaldama !27_V
39377	märkas	märka	märkama	29_V	IndIpfSg3	et	märkas =märka  (IndIpfSg3  >märkama !29_V
39379	pudeliski	pudeli	pudel	02_S	SgIn^	et	pudeliski =pudeli  (SgIn^  >pudel !02_S
39380	pöidla	pöidla	pöial	08_S	SgG	et	pöidla =pöidla  (SgG  >pöial !08_S
39390	kirjandusolümpiaad	olümpiaad	kirjandus+olümpiaad	22_S	SgN	et	kirjandusolümpiaad =olümpiaad  (SgN  >kirjandus+olümpiaad !22_S
39391	sisukat	sisuka	sisukas	02_A	SgP	et	sisukat =sisuka  (SgP  >sisukas !02_A
39394	rivis	rivi	rivi	17_S	SgIn	et	rivis =rivi  (SgIn  >rivi !17_S
39395	kaalumis	mi	kaalu+mi	26_S	SgIn	et	kaalumis =mi  (SgIn  >kaalu+mi !26_S
39396	soolamisruum	ruum	soola+mis+ruum	22_S	SgN	et	soolamisruum =ruum  (SgN  >soola+mis+ruum !22_S
39404	ärijuhtimist	juhtimis	äri+juhtimine	12_S	SgP	et	ärijuhtimist =juhtimis  (SgP  >äri+juhtimine !12_S
39405	keerake	keera	keerama	29_V	ImpPrPl2	et	keerake =keera  (ImpPrPl2  >keerama !29_V
39417	martsipanidega	martsipani	martsipan	19_S	PlKom	et	martsipanidega =martsipani  (PlKom  >martsipan !19_S
39429	puhkusereisil	reisi	puhkuse+reis	22_S	SgAd	et	puhkusereisil =reisi  (SgAd  >puhkuse+reis !22_S
39434	ämm	ämm	ämm	22_S	SgN	et	ämm =ämm  (SgN  >ämm !22_S
39437	vasis	vasi	vask	22_S	PlIn	et	vasis =vasi  (PlIn  >vask !22_S
39439	kodulilled	lille	kodu+lill	22_S	PlN	et	kodulilled =lille  (PlN  >kodu+lill !22_S
39441	kolleegid	kolleegi	kolleeg	22_S	PlN	et	kolleegid =kolleegi  (PlN  >kolleeg !22_S
39444	üleeile	üleeile	üle+eile	41_D	ID	et	üleeile =üleeile  (ID  >üle+eile !41_D
39457	kesklinnaga	linna	kesk+linn	22_S	SgKom	et	kesklinnaga =linna  (SgKom  >kesk+linn !22_S
39464	soome-ugrilased	ugrilase	soome-ugrilane	12_S	PlN	et	soome-ugrilased =ugrilase  (PlN  >soome-ugrilane !12_S
39465	nädalalõpuks	lõpu	nädala+lõpp	22_SA	SgTr	et	nädalalõpuks =lõpu  (SgTr  >nädala+lõpp !22_SA
39474	tagas	taga	tagama	27_V	IndIpfSg3	et	tagas =taga  (IndIpfSg3  >tagama !27_V
39479	sobrad	sobra	sobrama	27_V	IndPrSg2	et	sobrad =sobra  (IndPrSg2  >sobrama !27_V
39486	kadriorg	org	kadri+org	22_S	SgN	et	kadriorg =org  (SgN  >kadri+org !22_S
39492	pirukasid	pirukasi	pirukas	02_S	PlN	et	pirukasid =pirukasi  (PlN  >pirukas !02_S
39498	lõunatada	lõunata	lõunatama	27_V	Inf	et	lõunatada =lõunata  (Inf  >lõunatama !27_V
39511	ülesehitamisele	ehitamise	üles+ehitamine	12_S	SgAll	et	ülesehitamisele =ehitamise  (SgAll  >üles+ehitamine !12_S
39514	valitsema	valitse	valitsema	27_V	Sup	et	valitsema =valitse  (Sup  >valitsema !27_V
39520	protsessile	protsessi	protsess	22_S	SgAll	et	protsessile =protsessi  (SgAll  >protsess !22_S
39299	usutunnistus	tunnistus	usu+tunnistus	11_S	SgN	et	usutunnistus =tunnistus  (SgN  >usu+tunnistus !11_S
39302	mugandati	muganda	mugandama	27_V	IndIpfIps	et	mugandati =muganda  (IndIpfIps  >mugandama !27_V
39304	töörahva	rahva	töö+rahvas	07_S	SgG	et	töörahva =rahva  (SgG  >töö+rahvas !07_S
39310	väljavaated	vaate	välja+vaade	06_S	PlN	et	väljavaated =vaate  (PlN  >välja+vaade !06_S
39313	peremee	mee	pere+mesi	15_S	SgG	et	peremee =mee  (SgG  >pere+mesi !15_S
39314	merilaas	laas	meri+laas	14_S	SgN	et	merilaas =laas  (SgN  >meri+laas !14_S
39315	lõdvenes	lõdvene	lõdvenema	27_V	IndIpfSg3	et	lõdvenes =lõdvene  (IndIpfSg3  >lõdvenema !27_V
39317	paguluskirjanikega	kirjanike	pagulus+kirjanik	25_S	PlKom	et	paguluskirjanikega =kirjanike  (PlKom  >pagulus+kirjanik !25_S
39320	kultuurikontaktid	kontakti	kultuuri+kontakt	22_S	PlN	et	kultuurikontaktid =kontakti  (PlN  >kultuuri+kontakt !22_S
39330	kalandus	kalandus	kalandus	11_S	SgN	et	kalandus =kalandus  (SgN  >kalandus !11_S
39334	kasutuselevõtt	võtt	kasutusele+võtt	22_S	SgN	et	kasutuselevõtt =võtt  (SgN  >kasutusele+võtt !22_S
39349	ajaloodokument	dokument	aja+loo+dokument	22_S	SgN	et	ajaloodokument =dokument  (SgN  >aja+loo+dokument !22_S
39352	klassik	klassik	klassik	02_S	SgN	et	klassik =klassik  (SgN  >klassik !02_S
39381	jämedune	jämedune	jämedune	12_A	SgN	et	jämedune =jämedune  (SgN  >jämedune !12_A
39383	piimanõusid	nõu	piima+nõu	26_S	PlP	et	piimanõusid =nõu  (PlP  >piima+nõu !26_S
39389	muhu-saarel	saare	muhu-saar	13_S	SgAd	et	muhu-saarel =saare  (SgAd  >muhu-saar !13_S
39406	pimedas	pimeda	pime	02_AS	SgIn	et	pimedas =pimeda  (SgIn  >pime !02_AS
39407	kõnniteepeal	pea	kõnni+tee+pea	26_S	SgAd	et	kõnniteepeal =pea  (SgAd  >kõnni+tee+pea !26_S
39410	maasikaid	maasika	maasikas	02_S	PlP	et	maasikaid =maasika  (PlP  >maasikas !02_S
39414	korvidesse	korvi	korv	22_S	PlIll	et	korvidesse =korvi  (PlIll  >korv !22_S
39421	koputas	koputa	koputama	27_V	IndIpfSg3	et	koputas =koputa  (IndIpfSg3  >koputama !27_V
39422	maasikat	maasika	maasikas	02_S	SgP	et	maasikat =maasika  (SgP  >maasikas !02_S
39426	lõbusasti	lõbusasti	lõbusasti	41_D	ID	et	lõbusasti =lõbusasti  (ID  >lõbusasti !41_D
39430	saadate	saada	saatma	34_V	IndPrPl2	et	saadate =saada  (IndPrPl2  >saatma !34_V
39432	raamatupidamises	pidamise	raamatu+pidamine	12_S	SgIn	et	raamatupidamises =pidamise  (SgIn  >raamatu+pidamine !12_S
39435	äi	äi	äi	22_S	SgN	et	äi =äi  (SgN  >äi !22_S
39440	kolleegidega	kolleegi	kolleeg	22_S	PlKom	et	kolleegidega =kolleegi  (PlKom  >kolleeg !22_S
39448	pliidi	pliidi	pliit	22_S	SgG	et	pliidi =pliidi  (SgG  >pliit !22_S
39452	koduümbrus	ümbrus	kodu+ümbrus	11~09_S	SgN	et	koduümbrus =ümbrus  (SgN  >kodu+ümbrus !11~09_S
39455	bussid	bussi	buss	22_S	PlN	et	bussid =bussi  (PlN  >buss !22_S
39475	nädalavahetusal	tusa	nädala+vahe+tusk	22_S	SgAd	et	nädalavahetusal =tusa  (SgAd  >nädala+vahe+tusk !22_S
39478	öömajas	maja	öö+maja	17_S	SgIn	et	öömajas =maja  (SgIn  >öö+maja !17_S
39487	kõnelesin	kõnele	kõnelema	31~27_V	IndIpfSg1	et	kõnelesin =kõnele  (IndIpfSg1  >kõnelema !31~27_V
39497	autobussis	bussi	auto+buss	22_S	SgIn	et	autobussis =bussi  (SgIn  >auto+buss !22_S
39503	loomeikka	ikka	loome+iga	18_S	SgAdt	et	loomeikka =ikka  (SgAdt  >loome+iga !18_S
39504	kultuurieluks	elu	kultuuri+elu	17_S	SgTr	et	kultuurieluks =elu  (SgTr  >kultuuri+elu !17_S
39507	hõlmus	hõlmu	hõlm	22_S	PlIn	et	hõlmus =hõlmu  (PlIn  >hõlm !22_S
39509	elueesmärgile	märgi	elu+ees+märk	22_S	SgAll	et	elueesmärgile =märgi  (SgAll  >elu+ees+märk !22_S
39510	suurvabariigi	riigi	suur+vaba+riik	22_S	SgG	et	suurvabariigi =riigi  (SgG  >suur+vaba+riik !22_S
39527	pühendas	pühenda	pühendama	27_V	IndIpfSg3	et	pühendas =pühenda  (IndIpfSg3  >pühendama !27_V
39528	kangelasi	kangelasi	kangelane	12_S	PlP	et	kangelasi =kangelasi  (PlP  >kangelane !12_S
39531	rumala	rumala	rumal	02_A	SgG	et	rumala =rumala  (SgG  >rumal !02_A
39534	kaltsakad	kaltsaka	kaltsakas	02_SA	PlN	et	kaltsakad =kaltsaka  (PlN  >kaltsakas !02_SA
39539	segi	segi	segi	41_D	ID	et	segi =segi  (ID  >segi !41_D
39540	silmides	silmi	silm	22_S	PlIn	et	silmides =silmi  (PlIn  >silm !22_S
39543	kangelasest	kangelase	kangelane	12_S	SgEl	et	kangelasest =kangelase  (SgEl  >kangelane !12_S
39544	kujutlesin	kujutle	kujutlema	27_V	IndIpfSg1	et	kujutlesin =kujutle  (IndIpfSg1  >kujutlema !27_V
39551	pärand	pärand	pärand	02_S	SgN	et	pärand =pärand  (SgN  >pärand !02_S
39561	suitsusaun	saun	suitsu+saun	22_S	SgN	et	suitsusaun =saun  (SgN  >suitsu+saun !22_S
39563	tumedates	tumeda	tume	02_A	PlIn	et	tumedates =tumeda  (PlIn  >tume !02_A
39564	huvitundev	tundev	huvi+tundev	02_A	SgN	et	huvitundev =tundev  (SgN  >huvi+tundev !02_A
39566	lähedase	lähedase	lähedane	12_AS	SgG	et	lähedase =lähedase  (SgG  >lähedane !12_AS
39568	kingin	kingi	kinkima	28_V	IndPrSg1	et	kingin =kingi  (IndPrSg1  >kinkima !28_V
39371	tütarde	tütar	tütar	08_S	PlG	et	tütarde =tütar  (PlG  >tütar !08_S
39372	tõmbuma	tõmbu	tõmbuma	27_V	Sup	et	tõmbuma =tõmbu  (Sup  >tõmbuma !27_V
39373	tütardele	tütar	tütar	08_S	PlAll	et	tütardele =tütar  (PlAll  >tütar !08_S
39375	näilik	näilik	näilik	25_A	SgN	et	näilik =näilik  (SgN  >näilik !25_A
39378	poisijõnglane	jõnglane	poisi+jõnglane	12?10_S	SgN	et	poisijõnglane =jõnglane  (SgN  >poisi+jõnglane !12?10_S
39382	tulipalavat	palava	tuli+palav	02_A	SgP	et	tulipalavat =palava  (SgP  >tuli+palav !02_A
39385	roolikambrisse	kambri	rooli+kamber	02_S	SgIll	et	roolikambrisse =kambri  (SgIll  >rooli+kamber !02_S
39387	keerd	keerd	keerd	22_SA	SgN	et	keerd =keerd  (SgN  >keerd !22_SA
39393	kolmnurkses	nurkse	kolm+nurkne	02_A	SgIn	et	kolmnurkses =nurkse  (SgIn  >kolm+nurkne !02_A
39399	heinad	heina	hein	23?22_S	PlN	et	heinad =heina  (PlN  >hein !23?22_S
39403	pintsakud	pintsaku	pintsak	02_S	PlN	et	pintsakud =pintsaku  (PlN  >pintsak !02_S
39409	korjatakse	korja	korjama	29_V	IndPrIps	et	korjatakse =korja  (IndPrIps  >korjama !29_V
39411	keedakse	kee	keema	37_V	IndPrIps	et	keedakse =kee  (IndPrIps  >keema !37_V
39412	külalapsed	lapse	küla+laps	14_S	PlN	et	külalapsed =lapse  (PlN  >küla+laps !14_S
39413	suurete	e	suur+esi	15_S	PlG	et	suurete =e  (PlG  >suur+esi !15_S
39415	sünnipäeval	päeva	sünni+päev	22_S	SgAd	et	sünnipäeval =päeva  (SgAd  >sünni+päev !22_S
39416	kaunistan	kaunista	kaunistama	27_V	IndPrSg1	et	kaunistan =kaunista  (IndPrSg1  >kaunistama !27_V
39418	lausega	lause	lause	06_S	SgKom	et	lausega =lause  (SgKom  >lause !06_S
39425	ende	ende	enne	06_S	SgG	et	ende =ende  (SgG  >enne !06_S
39433	pensionär	pensionär	pensionär	19_S	SgN	et	pensionär =pensionär  (SgN  >pensionär !19_S
39438	elutoad	toa	elu+tuba	18_S	PlN	et	elutoad =toa  (PlN  >elu+tuba !18_S
39446	saunal	sauna	saun	22_S	SgAd	et	saunal =sauna  (SgAd  >saun !22_S
39447	kuuni	kuu	kuu	26_S	SgTer	et	kuuni =kuu  (SgTer  >kuu !26_S
39450	elektriküte	küte	elektri+küte	06_S	SgN	et	elektriküte =küte  (SgN  >elektri+küte !06_S
39453	rajoon	rajoon	rajoon	22_S	SgN	et	rajoon =rajoon  (SgN  >rajoon !22_S
39460	mugavat	mugava	mugav	02_A	SgP	et	mugavat =mugava  (SgP  >mugav !02_A
39463	soome-ugrilaselt	ugrilase	soome-ugrilane	12_S	SgAbl	et	soome-ugrilaselt =ugrilase  (SgAbl  >soome-ugrilane !12_S
39470	purjus	purjus	purjus	41_DA	ID	et	purjus =purjus  (ID  >purjus !41_DA
39472	tohiksin	tohi	tohtima	28_V	KndPrSg1	et	tohiksin =tohi  (KndPrSg1  >tohtima !28_V
39482	korterid	korteri	korter	02_S	PlN	et	korterid =korteri  (PlN  >korter !02_S
39485	lugesime	luge	lugema	28_V	IndIpfPl1	et	lugesime =luge  (IndIpfPl1  >lugema !28_V
39488	lõunastasime	lõunasta	lõunastama	27_V	IndIpfPl1	et	lõunastasime =lõunasta  (IndIpfPl1  >lõunastama !27_V
39489	jõuluturule	turu	jõulu+turg	22_S	SgAll	et	jõuluturule =turu  (SgAll  >jõulu+turg !22_S
39491	laksime	laksi	laksima	28_V	IndPrPl1	et	laksime =laksi  (IndPrPl1  >laksima !28_V
39493	sauel	saue	sau	22_S	SgAd	et	sauel =saue  (SgAd  >sau !22_S
39496	jõuluturul	turu	jõulu+turg	22_S	SgAd	et	jõuluturul =turu  (SgAd  >jõulu+turg !22_S
39500	kunstikultuur	kultuur	kunsti+kultuur	22_S	SgN	et	kunstikultuur =kultuur  (SgN  >kunsti+kultuur !22_S
39502	kultuuriareaaliga	areaali	kultuuri+areaal	22_S	SgKom	et	kultuuriareaaliga =areaali  (SgKom  >kultuuri+areaal !22_S
39508	seisukohtade	kohta	seisu+koht	22_S	PlG	et	seisukohtade =kohta  (PlG  >seisu+koht !22_S
39512	saksavalitsuse	valitsuse	saksa+valitsus	11_S	SgG	et	saksavalitsuse =valitsuse  (SgG  >saksa+valitsus !11_S
39516	sarnasid	sarna	sarn	22_S	PlP	et	sarnasid =sarna  (PlP  >sarn !22_S
39517	liidriga	liidri	liider	02_S	SgKom	et	liidriga =liidri  (SgKom  >liider !02_S
39522	teisikuga	teisiku	teisik	02_S	SgKom	et	teisikuga =teisiku  (SgKom  >teisik !02_S
39524	teisikud	teisiku	teisik	02_S	PlN	et	teisikud =teisiku  (PlN  >teisik !02_S
39535	mõrtsukad	mõrtsuka	mõrtsukas	02_S	PlN	et	mõrtsukad =mõrtsuka  (PlN  >mõrtsukas !02_S
39541	tabab	taba	tabama	27_V	IndPrSg3	et	tabab =taba  (IndPrSg3  >tabama !27_V
39542	teisiku	teisiku	teisik	02_S	SgG	et	teisiku =teisiku  (SgG  >teisik !02_S
39548	tall	tall	tall	22_S	SgN	et	tall =tall  (SgN  >tall !22_S
39549	inimestesse	inimes	inimene	12_S	PlIll	et	inimestesse =inimes  (PlIll  >inimene !12_S
39557	poeesiat	poeesia	poeesia	01_S	SgP	et	poeesiat =poeesia  (SgP  >poeesia !01_S
39558	keeleuurimused	uurimuse	keele+uurimus	11_S	PlN	et	keeleuurimused =uurimuse  (PlN  >keele+uurimus !11_S
39570	võimuses	võimuse	võimus	09_S	SgIn	et	võimuses =võimuse  (SgIn  >võimus !09_S
39571	arvutitaga	tita	arvu+tita	16_S	SgKom	et	arvutitaga =tita  (SgKom  >arvu+tita !16_S
39572	heasüdamlik	südamlik	hea+südamlik	25_A	SgN	et	heasüdamlik =südamlik  (SgN  >hea+südamlik !25_A
39423	seenemajale	maja	seene+maja	17_S	SgAll	et	seenemajale =maja  (SgAll  >seene+maja !17_S
39424	nuttis	nutt	nutma	35_V	IndIpfSg3	et	nuttis =nutt  (IndIpfSg3  >nutma !35_V
39427	koristas	korista	koristama	27_V	IndIpfSg3	et	koristas =korista  (IndIpfSg3  >koristama !27_V
39431	saabute	saabu	saabuma	27_V	IndPrPl2	et	saabute =saabu  (IndPrPl2  >saabuma !27_V
39436	pensionärid	pensionäri	pensionär	19_S	PlN	et	pensionärid =pensionäri  (PlN  >pensionär !19_S
39442	energilised	energilise	energiline	12_A	PlN	et	energilised =energilise  (PlN  >energiline !12_A
39443	professionaalsed	professionaalse	professionaalne	02_A	PlN	et	professionaalsed =professionaalse  (PlN  >professionaalne !02_A
39449	keskkütet	küte	kesk+küte	06_S	SgP	et	keskkütet =küte  (SgP  >kesk+küte !06_S
39451	ahjuküttega	kütte	ahju+küte	06_S	SgKom	et	ahjuküttega =kütte  (SgKom  >ahju+küte !06_S
39454	joa	joa	juga	18_S	SgG	et	joa =joa  (SgG  >juga !18_S
39458	liiklusega	liikluse	liiklus	11~09_S	SgKom	et	liiklusega =liikluse  (SgKom  >liiklus !11~09_S
39461	kelt	kelt	kelt	22_S	SgN	et	kelt =kelt  (SgN  >kelt !22_S
39462	soome-ugrilase	ugrilase	soome-ugrilane	12_S	SgG	et	soome-ugrilase =ugrilase  (SgG  >soome-ugrilane !12_S
39467	lotte	lotte	lott	22_S	PlP	et	lotte =lotte  (PlP  >lott !22_S
39469	pidutsesin	pidutse	pidutsema	27_V	IndIpfSg1	et	pidutsesin =pidutse  (IndIpfSg1  >pidutsema !27_V
39477	laksin	laksi	laksima	28_V	IndPrSg1	et	laksin =laksi  (IndPrSg1  >laksima !28_V
39480	taksiga	taksi	taks	22_S	SgKom	et	taksiga =taksi  (SgKom  >taks !22_S
39483	virukeskus	keskus	viru+keskus	11~09_S	SgN	et	virukeskus =keskus  (SgN  >viru+keskus !11~09_S
39494	teleka	teleka	telekas	02_S	SgG	et	teleka =teleka  (SgG  >telekas !02_S
39495	õhtupoolikul	pooliku	õhtu+poolik	02_AS	SgAd	et	õhtupoolikul =pooliku  (SgAd  >õhtu+poolik !02_AS
39499	19701980a-te	a	a	xx_Q	PlG	et	a-te =a  (PlG  >a !xx_Q
39505	ajajooksul	jooksu	aja+jooks	22_S	SgAd	et	ajajooksul =jooksu  (SgAd  >aja+jooks !22_S
39518	koolitas	koolita	koolitama	27_V	IndIpfSg3	et	koolitas =koolita  (IndIpfSg3  >koolitama !27_V
39519	sotsiaaldemokraatide	demokraati	sotsiaal+demokraat	22_S	PlG	et	sotsiaaldemokraatide =demokraati  (PlG  >sotsiaal+demokraat !22_S
39537	inimpattude	pattu	inim+patt	22_S	PlG	et	inimpattude =pattu  (PlG  >inim+patt !22_S
39555	keerleb	keerle	keerlema	30_V	IndPrSg3	et	keerleb =keerle  (IndPrSg3  >keerlema !30_V
39576	emmale	emma	emb	22_P	SgAll	et	emmale =emma  (SgAll  >emb !22_P
39578	lõunatan	lõunata	lõunatama	27_V	IndPrSg1	et	lõunatan =lõunata  (IndPrSg1  >lõunatama !27_V
39579	käik	käik	käik	22_S	SgN	et	käik =käik  (SgN  >käik !22_S
39587	väisama	väisa	väisama	29_V	Sup	et	väisama =väisa  (Sup  >väisama !29_V
39595	jõhvis	jõhvi	jõhv	22_S	SgIn	et	jõhvis =jõhvi  (SgIn  >jõhv !22_S
39596	esilehe	lehe	esi+leht	22_S	SgG	et	esilehe =lehe  (SgG  >esi+leht !22_S
39597	esiküljele	külje	esi+külg	22_S	SgAll	et	esiküljele =külje  (SgAll  >esi+külg !22_S
39599	argikäitumisega	käitumise	argi+käitumine	12_S	SgKom	et	argikäitumisega =käitumise  (SgKom  >argi+käitumine !12_S
39600	vetel	ve	vesi	15_S	PlAd	et	vetel =ve  (PlAd  >vesi !15_S
39604	pulmakombed	kombe	pulma+komme	06_S	PlN	et	pulmakombed =kombe  (PlN  >pulma+komme !06_S
39608	kohanimestik	nimestik	koha+nimestik	25_S	SgN	et	kohanimestik =nimestik  (SgN  >koha+nimestik !25_S
39611	baptist	baptist	baptist	22_S	SgN	et	baptist =baptist  (SgN  >baptist !22_S
39614	mandrijääst	jää	mandri+jää	26_S	SgEl	et	mandrijääst =jää  (SgEl  >mandri+jää !26_S
39615	vabanes	vabane	vabanema	27_V	IndIpfSg3	et	vabanes =vabane  (IndIpfSg3  >vabanema !27_V
39619	ajajärg	järg	aja+järg	22_S	SgN	et	ajajärg =järg  (SgN  >aja+järg !22_S
39621	lätlased	lätlase	lätlane	12?10_S	PlN	et	lätlased =lätlase  (PlN  >lätlane !12?10_S
39625	toota	toot	tootma	34_V	Inf	et	toota =toot  (Inf  >tootma !34_V
39631	toodanguid	toodangu	toodang	02_S	PlP	et	toodanguid =toodangu  (PlP  >toodang !02_S
39632	pärisorjuseks	orjuse	päris+orjus	11~09_S	SgTr	et	pärisorjuseks =orjuse  (SgTr  >päris+orjus !11~09_S
39635	visati	visa	viskama	29_V	IndIpfIps	et	visati =visa  (IndIpfIps  >viskama !29_V
39638	tahendab	tahenda	tahendama	27_V	IndPrSg3	et	tahendab =tahenda  (IndPrSg3  >tahendama !27_V
39645	pahupidi	pahupidi	pahu+pidi	41_D	ID	et	pahupidi =pahupidi  (ID  >pahu+pidi !41_D
39646	karusnahaga	naha	karus+nahk	22_S	SgKom	et	karusnahaga =naha  (SgKom  >karus+nahk !22_S
39648	kodudest	kodu	kodu	17_S	PlEl	et	kodudest =kodu  (PlEl  >kodu !17_S
39652	erksatesse	erksa	ergas	03~05_A	PlIll	et	erksatesse =erksa  (PlIll  >ergas !03~05_A
39654	kostüümidesse	kostüümi	kostüüm	22_S	PlIll	et	kostüümidesse =kostüümi  (PlIll  >kostüüm !22_S
39656	varustati	varusta	varustama	27_V	IndIpfIps	et	varustati =varusta  (IndIpfIps  >varustama !27_V
39663	veeretati	veereta	veeretama	27_V	IndIpfIps	et	veeretati =veereta  (IndIpfIps  >veeretama !27_V
39523	uppus	uppu	uppuma	28_V	IndIpfSg3	et	uppus =uppu  (IndIpfSg3  >uppuma !28_V
39526	sangar	sangar	sangar	02_S	SgN	et	sangar =sangar  (SgN  >sangar !02_S
39530	jõhkra	jõhkra	jõhker	02_A	SgG	et	jõhkra =jõhkra  (SgG  >jõhker !02_A
39536	mõistsin	mõist	mõistma	34_V	IndIpfSg1	et	mõistsin =mõist  (IndIpfSg1  >mõistma !34_V
39546	poeedid	poeedi	poeet	22_S	PlN	et	poeedid =poeedi  (PlN  >poeet !22_S
39547	õdede	õde	õde	18_S	PlG	et	õdede =õde  (PlG  >õde !18_S
39550	samasuguseid	suguse	sama+sugune	10_P	PlP	et	samasuguseid =suguse  (PlP  >sama+sugune !10_P
39552	iidsetest	iidse	iidne	02_A	PlEl	et	iidsetest =iidse  (PlEl  >iidne !02_A
39554	toitumistavasid	tava	toitumis+tava	17_S	PlP	et	toitumistavasid =tava  (PlP  >toitumis+tava !17_S
39574	treening	treening	treening	02_S	SgN	et	treening =treening  (SgN  >treening !02_S
39577	paitsi	paitsi	paitsi	41_J	ID	et	paitsi =paitsi  (ID  >paitsi !41_J
39582	pitskohvikus	kohviku	pits+kohvik	02_S	SgIn	et	pitskohvikus =kohviku  (SgIn  >pits+kohvik !02_S
39586	meeleolule	olu	meele+olu	17_S	SgAll	et	meeleolule =olu  (SgAll  >meele+olu !17_S
39590	teissugune	sugune	teis+sugune	10_A	SgN	et	teissugune =sugune  (SgN  >teis+sugune !10_A
39601	tüüpilisest	tüüpilise	tüüpiline	12_A	SgEl	et	tüüpilisest =tüüpilise  (SgEl  >tüüpiline !12_A
39609	res	re	re	26_S	SgIn	et	res =re  (SgIn  >re !26_S
39617	laibaga	laiba	laip	22_S	SgKom	et	laibaga =laiba  (SgKom  >laip !22_S
39626	iseenese	enese	ise+enese	00_P	SgG	et	iseenese =enese  (SgG  >ise+enese !00_P
39633	perekonnanimed	nime	pere+konna+nimi	20_S	PlN	et	perekonnanimed =nime  (PlN  >pere+konna+nimi !20_S
39639	foneetikas	foneetika	foneetika	01_S	SgIn	et	foneetikas =foneetika  (SgIn  >foneetika !01_S
39642	naisena	naise	naine	12_S	SgEs	et	naisena =naise  (SgEs  >naine !12_S
39649	nukke	nukke	nukk	22_S	PlP	et	nukke =nukke  (PlP  >nukk !22_S
39650	kulmud	kulmu	kulm	22_S	PlN	et	kulmud =kulmu  (PlN  >kulm !22_S
39651	riietati	riieta	riietama	27_V	IndIpfIps	et	riietati =riieta  (IndIpfIps  >riietama !27_V
39653	pidulikkesse	kesse	pidulik+kess	22_S	PlP	et	pidulikkesse =kesse  (PlP  >pidulik+kess !22_S
39667	talunik	talunik	talunik	25_S	SgN	et	talunik =talunik  (SgN  >talunik !25_S
39669	rekvisiitidega	rekvisiiti	rekvisiit	22_S	PlKom	et	rekvisiitidega =rekvisiiti  (PlKom  >rekvisiit !22_S
39671	põllule	põllu	põld	22_S	SgAll	et	põllule =põllu  (SgAll  >põld !22_S
39672	ühekülainimesed	inimese	ühe+küla+inimene	12_S	PlN	et	ühekülainimesed =inimese  (PlN  >ühe+küla+inimene !12_S
39675	vihk	vihk	vihk	22_S	SgN	et	vihk =vihk  (SgN  >vihk !22_S
39677	latt	latt	latt	22_S	SgN	et	latt =latt  (SgN  >latt !22_S
39696	etteastega	aste	ette+aste	06_S	SgKom	et	etteastega =aste  (SgKom  >ette+aste !06_S
39699	matkamajas	maja	matka+maja	17_S	SgIn	et	matkamajas =maja  (SgIn  >matka+maja !17_S
39705	lauluviisid	viisi	laulu+viis	22_S	PlN	et	lauluviisid =viisi  (PlN  >laulu+viis !22_S
39708	palved	palve	palve	06_S	PlN	et	palved =palve  (PlN  >palve !06_S
39710	2sajandil	sajandi	sajand	02_S	SgAd	et	sajandil =sajandi  (SgAd  >sajand !02_S
39712	mittevaimulikud	vaimuliku	mitte+vaimulik	25_AS	PlN	et	mittevaimulikud =vaimuliku  (PlN  >mitte+vaimulik !25_AS
39717	viljalõikuse	lõikuse	vilja+lõikus	11~09_S	SgG	et	viljalõikuse =lõikuse  (SgG  >vilja+lõikus !11~09_S
39718	kosutas	kosuta	kosutama	27_V	IndIpfSg3	et	kosutas =kosuta  (IndIpfSg3  >kosutama !27_V
39719	laabus	laabu	laabuma	27_V	IndIpfSg3	et	laabus =laabu  (IndIpfSg3  >laabuma !27_V
39721	religioosse-eestilise	eestilise	religioosse-eestiline	12_A	SgG	et	religioosse-eestilise =eestilise  (SgG  >religioosse-eestiline !12_A
39735	lauluhääl	hääl	laulu+hääl	13_S	SgN	et	lauluhääl =hääl  (SgN  >laulu+hääl !13_S
39737	tegevdirektor	direktor	tegev+direktor	02_S	SgN	et	tegevdirektor =direktor  (SgN  >tegev+direktor !02_S
39739	teete	tee	tegema	28_V	IndPrPl2	et	teete =tee  (IndPrPl2  >tegema !28_V
39741	lisage	lisa	lisama	27_V	ImpPrPl2	et	lisage =lisa  (ImpPrPl2  >lisama !27_V
39744	luulepäevadel	päeva	luule+päev	22_S	PlAd	et	luulepäevadel =päeva  (PlAd  >luule+päev !22_S
39748	kartlik	kartlik	kartlik	25_A	SgN	et	kartlik =kartlik  (SgN  >kartlik !25_A
39754	umbusklik	usklik	umb+usklik	25_AS	SgN	et	umbusklik =usklik  (SgN  >umb+usklik !25_AS
39763	tehtes	tehte	tehe	06_S	SgIn	et	tehtes =tehte  (SgIn  >tehe !06_S
39765	sünonüümid	sünonüümi	sünonüüm	22_S	PlN	et	sünonüümid =sünonüümi  (PlN  >sünonüüm !22_S
39768	üritada	ürita	üritama	27_V	Inf	et	üritada =ürita  (Inf  >üritama !27_V
39772	maakler	maakler	maakler	02_S	SgN	et	maakler =maakler  (SgN  >maakler !02_S
39773	läbiajas	aja	läbi+aeg	22_S	SgIn	et	läbiajas =aja  (SgIn  >läbi+aeg !22_S
39775	kasutusjuhendis	juhendi	kasutus+juhend	02_S	SgIn	et	kasutusjuhendis =juhendi  (SgIn  >kasutus+juhend !02_S
39525	patriotism	patriotism	patriotism	22_S	SgN	et	patriotism =patriotism  (SgN  >patriotism !22_S
39529	kinematograafias	kinematograafia	kinematograafia	01_S	SgIn	et	kinematograafias =kinematograafia  (SgIn  >kinematograafia !01_S
39532	joodikuna	joodiku	joodik	02_SA	SgEs	et	joodikuna =joodiku  (SgEs  >joodik !02_SA
39533	kaklused	kakluse	kaklus	11~09_S	PlN	et	kaklused =kakluse  (PlN  >kaklus !11~09_S
39538	pahed	pahe	pahe	16_S	PlN	et	pahed =pahe  (PlN  >pahe !16_S
39545	meheks	mehe	mees	13_S	SgTr	et	meheks =mehe  (SgTr  >mees !13_S
39553	dikteerib	dikteeri	dikteerima	28_V	IndPrSg3	et	dikteerib =dikteeri  (IndPrSg3  >dikteerima !28_V
39556	ilmset	ilmse	ilmne	02_A	SgP	et	ilmset =ilmse  (SgP  >ilmne !02_A
39559	rahvustoiduks	toidu	rahvus+toit	22_S	SgTr	et	rahvustoiduks =toidu  (SgTr  >rahvus+toit !22_S
39560	vargamäe	mäe	varga+mägi	21_S	SgG	et	vargamäe =mäe  (SgG  >varga+mägi !21_S
39562	iluga	ilu	ilu	17_S	SgKom	et	iluga =ilu  (SgKom  >ilu !17_S
39565	tõstavad	tõsta	tõstma	34_V	IndPrPl3	et	tõstavad =tõsta  (IndPrPl3  >tõstma !34_V
39567	samasuguses	suguse	sama+sugune	10_P	SgIn	et	samasuguses =suguse  (SgIn  >sama+sugune !10_P
39569	päevades	päeva	päev	22_S	PlIn	et	päevades =päeva  (PlIn  >päev !22_S
39575	tähistan	tähista	tähistama	27_V	IndPrSg1	et	tähistan =tähista  (IndPrSg1  >tähistama !27_V
39581	kursusekaaslasega	kaaslase	kursuse+kaaslane	12?10_S	SgKom	et	kursusekaaslasega =kaaslase  (SgKom  >kursuse+kaaslane !12?10_S
39592	sõbrannale	sõbranna	sõbranna	16_S	SgAll	et	sõbrannale =sõbranna  (SgAll  >sõbranna !16_S
39594	moosiga	moosi	moos	22_S	SgKom	et	moosiga =moosi  (SgKom  >moos !22_S
39598	läänerannikule	ranniku	lääne+rannik	02_S	SgAll	et	läänerannikule =ranniku  (SgAll  >lääne+rannik !02_S
39603	kombestik	kombestik	kombestik	25_S	SgN	et	kombestik =kombestik  (SgN  >kombestik !25_S
39606	idadest	ida	ida	17_S	PlEl	et	idadest =ida  (PlEl  >ida !17_S
39618	ümbritses	ümbritse	ümbritsema	27_V	IndIpfSg3	et	ümbritses =ümbritse  (IndIpfSg3  >ümbritsema !27_V
39622	väljapaistvad	paistva	välja+paistev	02_A	PlN	et	väljapaistvad =paistva  (PlN  >välja+paistev !02_A
39624	üksikud	üksiku	üksik	02_A	PlN	et	üksikud =üksiku  (PlN  >üksik !02_A
39634	kõrtsmikud	kõrtsmiku	kõrtsmik	25_S	PlN	et	kõrtsmikud =kõrtsmiku  (PlN  >kõrtsmik !25_S
39640	transkriptsioonid	transkriptsiooni	transkriptsioon	22_S	PlN	et	transkriptsioonid =transkriptsiooni  (PlN  >transkriptsioon !22_S
39657	atribuutidega	atribuuti	atribuut	22_S	PlKom	et	atribuutidega =atribuuti  (PlKom  >atribuut !22_S
39658	kulbiga	kulbi	kulp	22_S	SgKom	et	kulbiga =kulbi  (SgKom  >kulp !22_S
39703	südamlikud	südamliku	südamlik	25_A	PlN	et	südamlikud =südamliku  (PlN  >südamlik !25_A
39723	1993aastal	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
39725	14novembril	novembri	november	02_S	SgAd	et	novembril =novembri  (SgAd  >november !02_S
39726	preilis	preili	preili	16_S	SgIn	et	preilis =preili  (SgIn  >preili !16_S
39727	pärandist	pärandi	pärand	02_S	SgEl	et	pärandist =pärandi  (SgEl  >pärand !02_S
39730	1999aastal	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
39733	east	ea	iga	18_S	SgEl	et	east =ea  (SgEl  >iga !18_S
39740	kelgutasime	kelguta	kelgutama	27_V	IndIpfPl1	et	kelgutasime =kelguta  (IndIpfPl1  >kelgutama !27_V
39742	pakuti	paku	pakkuma	28_V	IndIpfIps	et	pakuti =paku  (IndIpfIps  >pakkuma !28_V
39743	barankasid	baranka	baranka	16_S	PlP	et	barankasid =baranka  (PlP  >baranka !16_S
39747	nõustute	nõustu	nõustuma	27_V	IndPrPl2	et	nõustute =nõustu  (IndPrPl2  >nõustuma !27_V
39752	taipama	taipa	taipama	29_V	Sup	et	taipama =taipa  (Sup  >taipama !29_V
39755	peibutama	peibuta	peibutama	27_V	Sup	et	peibutama =peibuta  (Sup  >peibutama !27_V
39756	venima	veni	venima	27_V	Sup	et	venima =veni  (Sup  >venima !27_V
39771	haldab	halda	haldama	29_V	IndPrSg3	et	haldab =halda  (IndPrSg3  >haldama !29_V
39776	üleolevad	oleva	üle+olev	02_A	PlN	et	üleolevad =oleva  (PlN  >üle+olev !02_A
39778	lahtise	lahtise	lahtine	12~10_A	SgG	et	lahtise =lahtise  (SgG  >lahtine !12~10_A
39782	viieliigne	liigne	viie+liigne	02_A	SgN	et	viieliigne =liigne  (SgN  >viie+liigne !02_A
39783	tervistama	tervista	tervistama	27_V	Sup	et	tervistama =tervista  (Sup  >tervistama !27_V
39794	laskes	laske	lase	06_S	SgIn	et	laskes =laske  (SgIn  >lase !06_S
39799	kliendil	kliendi	klient	22_S	SgAd	et	kliendil =kliendi  (SgAd  >klient !22_S
39801	vaheajata	aja	vahe+aeg	22_S	SgAb	et	vaheajata =aja  (SgAb  >vahe+aeg !22_S
39803	valmisriided	riide	valmis+riie	06_S	PlN	et	valmisriided =riide  (PlN  >valmis+riie !06_S
39811	kauplusse	kauplus	kauplus	11_S	SgAdt	et	kauplusse =kauplus  (SgAdt  >kauplus !11_S
39823	supleme	suple	suplema	30_V	IndPrPl1	et	supleme =suple  (IndPrPl1  >suplema !30_V
39824	lõppetama	lõppe	lõppema	27_V	SupIps	et	lõppetama =lõppe  (SupIps  >lõppema !27_V
39573	spordiklubis	klubi	spordi+klubi	17_S	SgIn	et	spordiklubis =klubi  (SgIn  >spordi+klubi !17_S
39583	piisab	piisa	piisama	29_V	IndPrSg3	et	piisab =piisa  (IndPrSg3  >piisama !29_V
39584	ärritan	ärrita	ärritama	27_V	IndPrSg1	et	ärritan =ärrita  (IndPrSg1  >ärritama !27_V
39588	millegipärast	millegipärast	millegi+pärast	41_D	ID	et	millegipärast =millegipärast  (ID  >millegi+pärast !41_D
39591	magusroogadega	rooga	magus+roog	22_S	PlKom	et	magusroogadega =rooga  (PlKom  >magus+roog !22_S
39605	rahvameditsiin	meditsiin	rahva+meditsiin	22_S	SgN	et	rahvameditsiin =meditsiin  (SgN  >rahva+meditsiin !22_S
39610	riistade	riista	riist	22_S	PlG	et	riistade =riista  (PlG  >riist !22_S
39612	lades	la	la	26_S	PlIn	et	lades =la  (PlIn  >la !26_S
39620	sakslastele	sakslas	sakslane	12?10_S	PlAll	et	sakslastele =sakslas  (PlAll  >sakslane !12?10_S
39637	foneetikal	foneetika	foneetika	01_S	SgAd	et	foneetikal =foneetika  (SgAd  >foneetika !01_S
39644	tõmmati	tõmma	tõmbama	29_V	IndIpfIps	et	tõmmati =tõmma  (IndIpfIps  >tõmbama !29_V
39662	lumememmena	memme	lume+memm	22_S	SgEs	et	lumememmena =memme  (SgEs  >lume+memm !22_S
39673	kasutata	kasuta	kasutama	27_V	IndPrIps_	et	kasutata =kasuta  (IndPrIps_  >kasutama !27_V
39678	vastuvõtmine	võtmine	vastu+võtmine	12?10_S	SgN	et	vastuvõtmine =võtmine  (SgN  >vastu+võtmine !12?10_S
39679	erk	erk	erk	22_AS	SgN	et	erk =erk  (SgN  >erk !22_AS
39680	kavaleht	leht	kava+leht	22_S	SgN	et	kavaleht =leht  (SgN  >kava+leht !22_S
39684	90-te			xx_Q	PlG	et	-te =  (PlG  > !xx_Q
39687	1997aastal	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
39689	1998aastal	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
39692	repertuaarist	repertuaari	repertuaar	22_S	SgEl	et	repertuaarist =repertuaari  (SgEl  >repertuaar !22_S
39700	südamed	südame	süda	04_S	PlN	et	südamed =südame  (PlN  >süda !04_S
39701	kauakestev	kestev	kaua+kestev	02_A	SgN	et	kauakestev =kestev  (SgN  >kaua+kestev !02_A
39716	heinaniidu	niidu	heina+niit	22_S	SgG	et	heinaniidu =niidu  (SgG  >heina+niit !22_S
39728	koorilauljad	laulja	koori+laulja	01_S	PlN	et	koorilauljad =laulja  (PlN  >koori+laulja !01_S
39731	ajaloolase	loolase	aja+loolane	12?10_S	SgG	et	ajaloolase =loolase  (SgG  >aja+loolane !12?10_S
39734	kirikulaulmise	laulmise	kiriku+laulmine	12?10_S	SgG	et	kirikulaulmise =laulmise  (SgG  >kiriku+laulmine !12?10_S
39749	tõlkige	tõlki	tõlkima	28_V	ImpPrPl2	et	tõlkige =tõlki  (ImpPrPl2  >tõlkima !28_V
39751	tuvastama	tuvasta	tuvastama	27_V	Sup	et	tuvastama =tuvasta  (Sup  >tuvastama !27_V
39764	liiget	liige	liige	05_S	SgP	et	liiget =liige  (SgP  >liige !05_S
39767	loeti	loe	lugema	28_V	IndIpfIps	et	loeti =loe  (IndIpfIps  >lugema !28_V
39780	ebakvaliteetsed	kvaliteetse	eba+kvaliteetne	02_A	PlN	et	ebakvaliteetsed =kvaliteetse  (PlN  >eba+kvaliteetne !02_A
39786	kvaliteedi	kvaliteedi	kvaliteet	22_S	SgG	et	kvaliteedi =kvaliteedi  (SgG  >kvaliteet !22_S
39787	lahenema	lahene	lahenema	27_V	Sup	et	lahenema =lahene  (Sup  >lahenema !27_V
39813	toiduainete	aine	toidu+aine	06_S	PlG	et	toiduainete =aine  (PlG  >toidu+aine !06_S
39829	tehnik	tehnik	tehnik	02_S	SgN	et	tehnik =tehnik  (SgN  >tehnik !02_S
39841	tööotsimine	otsimine	töö+otsimine	12_S	SgN	et	tööotsimine =otsimine  (SgN  >töö+otsimine !12_S
39846	tööseadusandluse	andluse	töö+seadus+andlus	11~09_S	SgG	et	tööseadusandluse =andluse  (SgG  >töö+seadus+andlus !11~09_S
39853	mööblisalong	salong	mööbli+salong	22_S	SgN	et	mööblisalong =salong  (SgN  >mööbli+salong !22_S
39855	sinule	sinu	sina	00_P	SgAll	et	sinule =sinu  (SgAll  >sina !00_P
39857	psühholoogiat	psühholoogia	psühholoogia	01_S	SgP	et	psühholoogiat =psühholoogia  (SgP  >psühholoogia !01_S
39872	seadusandlus	andlus	seadus+andlus	11~09_S	SgN	et	seadusandlus =andlus  (SgN  >seadus+andlus !11~09_S
39877	produktsioon	produktsioon	produktsioon	22_S	SgN	et	produktsioon =produktsioon  (SgN  >produktsioon !22_S
39880	käsin	käsi	käskima	28_V	IndPrSg1	et	käsin =käsi  (IndPrSg1  >käskima !28_V
39883	edasines	ine	edas+ine	16_S	SgIn	et	edasines =ine  (SgIn  >edas+ine !16_S
39892	dokumendi	dokumendi	dokument	22_S	SgG	et	dokumendi =dokumendi  (SgG  >dokument !22_S
39897	peatse	peatse	peatne	02_A	SgG	et	peatse =peatse  (SgG  >peatne !02_A
39900	arvutik	utik	arv+utik	02_S	SgN	et	arvutik =utik  (SgN  >arv+utik !02_S
39902	meldima	meldi	meldima	28_V	Sup	et	meldima =meldi  (Sup  >meldima !28_V
39914	praktikaga	praktika	praktika	01_S	SgKom	et	praktikaga =praktika  (SgKom  >praktika !01_S
39917	praktikus	praktiku	praktik	02_S	SgIn	et	praktikus =praktiku  (SgIn  >praktik !02_S
39918	ehituskauplus	kauplus	ehitus+kauplus	11~09_S	SgN	et	ehituskauplus =kauplus  (SgN  >ehitus+kauplus !11~09_S
39924	toimuda	toimu	toimuma	27_V	Inf	et	toimuda =toimu  (Inf  >toimuma !27_V
39929	loodame	looda	lootma	34_V	IndPrPl1	et	loodame =looda  (IndPrPl1  >lootma !34_V
39580	pitsakohvikus	kohviku	pitsa+kohvik	02_S	SgIn	et	pitsakohvikus =kohviku  (SgIn  >pitsa+kohvik !02_S
39585	üritatakse	ürita	üritama	27_V	IndPrIps	et	üritatakse =ürita  (IndPrIps  >üritama !27_V
39589	saiaga	saia	sai	22_S	SgKom	et	saiaga =saia  (SgKom  >sai !22_S
39593	maksame	maksa	maksma	32_V	IndPrPl1	et	maksame =maksa  (IndPrPl1  >maksma !32_V
39602	humanitaarteaduste	teadus	humanitaar+teadus	11~09_S	PlG	et	humanitaarteaduste =teadus  (PlG  >humanitaar+teadus !11~09_S
39607	esitajate-ja	ja	esitajate-ja	41_J	ID	et	esitajate-ja =ja  (ID  >esitajate-ja !41_J
39613	isid	isi	iskima	28_V	IndPrSg2	et	isid =isi  (IndPrSg2  >iskima !28_V
39616	jahil	jahi	jaht	22_S	SgAd	et	jahil =jahi  (SgAd  >jaht !22_S
39623	sammuti	sammu	sammuma	28_V	IndIpfIps	et	sammuti =sammu  (IndIpfIps  >sammuma !28_V
39627	töölisi	töölisi	tööline	12_S	PlP	et	töölisi =töölisi  (PlP  >tööline !12_S
39628	puumeistrina	meistri	puu+meister	02_S	SgEs	et	puumeistrina =meistri  (SgEs  >puu+meister !02_S
39629	soetab	soeta	soetama	27_V	IndPrSg3	et	soetab =soeta  (IndPrSg3  >soetama !27_V
39630	tootma	toot	tootma	34_V	Sup	et	tootma =toot  (Sup  >tootma !34_V
39636	keeleteaduse	teaduse	keele+teadus	11~09_S	SgG	et	keeleteaduse =teaduse  (SgG  >keele+teadus !11~09_S
39641	hääldama	häälda	hääldama	27_V	Sup	et	hääldama =häälda  (Sup  >hääldama !27_V
39643	rõivad	rõiva	rõivas	07_S	PlN	et	rõivad =rõiva  (PlN  >rõivas !07_S
39647	väljapoole	väljapoole	välja+poole	41_DK	ID	et	väljapoole =väljapoole  (ID  >välja+poole !41_DK
39655	nuku	nuku	nukk	22_S	SgG	et	nuku =nuku  (SgG  >nukk !22_S
39659	pingile	pingi	pink	22_S	SgAll	et	pingile =pingi  (SgAll  >pink !22_S
39660	rituaal	rituaal	rituaal	22_S	SgN	et	rituaal =rituaal  (SgN  >rituaal !22_S
39661	kubermangudes	kubermangu	kubermang	22_S	PlIn	et	kubermangudes =kubermangu  (PlIn  >kubermang !22_S
39665	piirkondades	piirkonda	piirkond	22_S	PlIn	et	piirkondades =piirkonda  (PlIn  >piirkond !22_S
39666	hernehirmutise	hirmutise	herne+hirmutis	11_S	SgG	et	hernehirmutise =hirmutise  (SgG  >herne+hirmutis !11_S
39674	rehad	reha	reha	17_S	PlN	et	rehad =reha  (PlN  >reha !17_S
39681	mustpeade	pea	must+pea	26_S	PlG	et	mustpeade =pea  (PlG  >must+pea !26_S
39697	vähemusrahvuste	rahvus	vähemus+rahvus	11~09_S	PlG	et	vähemusrahvuste =rahvus  (PlG  >vähemus+rahvus !11~09_S
39704	tänusõnad	sõna	tänu+sõna	17_S	PlN	et	tänusõnad =sõna  (PlN  >tänu+sõna !17_S
39707	kodumaast	maa	kodu+maa	26_S	SgEl	et	kodumaast =maa  (SgEl  >kodu+maa !26_S
39713	poeetide	poeeti	poeet	22_S	PlG	et	poeetide =poeeti  (PlG  >poeet !22_S
39714	varakristlaste	kristlas	vara+kristlane	12?10_S	PlG	et	varakristlaste =kristlas  (PlG  >vara+kristlane !12?10_S
39715	põllutööde	töö	põllu+töö	26_S	PlG	et	põllutööde =töö  (PlG  >põllu+töö !26_S
39722	viiside	viisi	viis	22_S	PlG	et	viiside =viisi  (PlG  >viis !22_S
39724	teadlase	teadlase	teadlane	12?10_S	SgG	et	teadlase =teadlase  (SgG  >teadlane !12?10_S
39753	kohtlema	kohtle	kohtlema	30_V	Sup	et	kohtlema =kohtle  (Sup  >kohtlema !30_V
39757	hallitama	hallita	hallitama	27_V	Sup	et	hallitama =hallita  (Sup  >hallitama !27_V
39761	suhtlete	suhtle	suhtlema	30_V	IndPrPl2	et	suhtlete =suhtle  (IndPrPl2  >suhtlema !30_V
39762	maaklerist	maakleri	maakler	02_S	SgEl	et	maaklerist =maakleri  (SgEl  >maakler !02_S
39766	paranema	parane	paranema	27_V	Sup	et	paranema =parane  (Sup  >paranema !27_V
39769	püsikliendid	kliendi	püsi+klient	22_S	PlN	et	püsikliendid =kliendi  (PlN  >püsi+klient !22_S
39779	tervenema	tervene	tervenema	27_V	Sup	et	tervenema =tervene  (Sup  >tervenema !27_V
39781	püsiklientidel	klienti	püsi+klient	22_S	PlAd	et	püsiklientidel =klienti  (PlAd  >püsi+klient !22_S
39795	lepingute	lepingu	leping	02_S	PlG	et	lepingute =lepingu  (PlG  >leping !02_S
39802	ehitis	ehitis	ehitis	11_S	SgN	et	ehitis =ehitis  (SgN  >ehitis !11_S
39805	juurvili	vili	juur+vili	24_S	SgN	et	juurvili =vili  (SgN  >juur+vili !24_S
39806	vaikid	vaiki	vaikima	27_V	IndPrSg2	et	vaikid =vaiki  (IndPrSg2  >vaikima !27_V
39809	kalli-kalli	kalli	kalli-kallis	05~07_A	SgG	et	kalli-kalli =kalli  (SgG  >kalli-kallis !05~07_A
39815	arvutikursused	kursuse	arvuti+kursus	11~09_S	PlN	et	arvutikursused =kursuse  (PlN  >arvuti+kursus !11~09_S
39816	autojuhi	juhi	auto+juht	22_S	SgG	et	autojuhi =juhi  (SgG  >auto+juht !22_S
39818	kastanud	tanu	kas+tanu	17_S	PlN	et	kastanud =tanu  (PlN  >kas+tanu !17_S
39820	lapsidega	lapsi	laps	22_S	PlKom	et	lapsidega =lapsi  (PlKom  >laps !22_S
39821	spordisaal	saal	spordi+saal	22_S	SgN	et	spordisaal =saal  (SgN  >spordi+saal !22_S
39822	kalal	kala	kala	17_S	SgAd	et	kalal =kala  (SgAd  >kala !17_S
39828	kesktase	tase	kesk+tase	04_S	SgN	et	kesktase =tase  (SgN  >kesk+tase !04_S
39831	kesk-tehniline	tehniline	kesk-tehniline	12_A	SgN	et	kesk-tehniline =tehniline  (SgN  >kesk-tehniline !12_A
39664	kelkudega	kelku	kelk	22_S	PlKom	et	kelkudega =kelku  (PlKom  >kelk !22_S
39668	tobedate	tobeda	tobe	02_A	PlG	et	tobedate =tobeda  (PlG  >tobe !02_A
39670	liikumisvahenditega	vahendi	liikumis+vahend	02_S	PlKom	et	liikumisvahenditega =vahendi  (PlKom  >liikumis+vahend !02_S
39676	ritv	ritv	ritv	22_S	SgN	et	ritv =ritv  (SgN  >ritv !22_S
39682	koorijuht	juht	koori+juht	22_S	SgN	et	koorijuht =juht  (SgN  >koori+juht !22_S
39683	vanausu	usu	vana+usk	22_S	SgG	et	vanausu =usu  (SgG  >vana+usk !22_S
39685	rahvamajas	maja	rahva+maja	17_S	SgIn	et	rahvamajas =maja  (SgIn  >rahva+maja !17_S
39686	dirigent	dirigent	dirigent	22_S	SgN	et	dirigent =dirigent  (SgN  >dirigent !22_S
39688	pärg	pärg	pärg	22_S	SgN	et	pärg =pärg  (SgN  >pärg !22_S
39690	folkloorifestivalil	festivali	folkloori+festival	19_S	SgAd	et	folkloorifestivalil =festivali  (SgAd  >folkloori+festival !19_S
39691	palveid	palve	palve	06_S	PlP	et	palveid =palve  (PlP  >palve !06_S
39693	2000aastal	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
39694	pidustustel	pidustus	pidustus	11_S	PlAd	et	pidustustel =pidustus  (PlAd  >pidustus !11_S
39695	2003aastal	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
39698	23septembril	septembri	september	02_S	SgAd	et	septembril =septembri  (SgAd  >september !02_S
39702	aplaus	aplaus	aplaus	22_S	SgN	et	aplaus =aplaus  (SgN  >aplaus !22_S
39706	kristus	kristus	kristus	11~09_S	SgN	et	kristus =kristus  (SgN  >kristus !11~09_S
39709	lauluviise	viise	laulu+viis	22_S	PlP	et	lauluviise =viise  (PlP  >laulu+viis !22_S
39711	mungad	munga	munk	22_S	PlN	et	mungad =munga  (PlN  >munk !22_S
39720	kerged	kerge	kerge	01_A	PlN	et	kerged =kerge  (PlN  >kerge !01_A
39729	jumalateenistuslik	teenistuslik	jumala+teenistuslik	25_A	SgN	et	jumalateenistuslik =teenistuslik  (SgN  >jumala+teenistuslik !25_A
39732	mõttekaaslane	kaaslane	mõtte+kaaslane	12?10_S	SgN	et	mõttekaaslane =kaaslane  (SgN  >mõtte+kaaslane !12?10_S
39736	kultuurivalgustusliku	valgustusliku	kultuuri+valgustuslik	25_A	SgG	et	kultuurivalgustusliku =valgustusliku  (SgG  >kultuuri+valgustuslik !25_A
39738	koolivaheaeg	aeg	kooli+vahe+aeg	22_S	SgN	et	koolivaheaeg =aeg  (SgN  >kooli+vahe+aeg !22_S
39745	rahvatants	tants	rahva+tants	22_S	SgN	et	rahvatants =tants  (SgN  >rahva+tants !22_S
39746	õhtule	õhtu	õhtu	01_S	SgAll	et	õhtule =õhtu  (SgAll  >õhtu !01_S
39750	takistama	takista	takistama	27_V	Sup	et	takistama =takista  (Sup  >takistama !27_V
39758	küünistama	küünista	küünistama	27_V	Sup	et	küünistama =küünista  (Sup  >küünistama !27_V
39759	sõlmite	sõlmi	sõlmima	28_V	IndPrPl2	et	sõlmite =sõlmi  (IndPrPl2  >sõlmima !28_V
39760	lepingut	lepingu	leping	02_S	SgP	et	lepingut =lepingu  (SgP  >leping !02_S
39770	valed	vale	vale	16_SA	PlN	et	valed =vale  (PlN  >vale !16_SA
39774	hiilima	hiili	hiilima	28_V	Sup	et	hiilima =hiili  (Sup  >hiilima !28_V
39777	jookseb	jookse	jooksma	32_V	IndPrSg3	et	jookseb =jookse  (IndPrSg3  >jooksma !32_V
39785	nõuati	ati	nõu+att	22_S	SgG	et	nõuati =ati  (SgG  >nõu+att !22_S
39789	kaupadel	kaupa	kaup	22_S	PlAd	et	kaupadel =kaupa  (PlAd  >kaup !22_S
39790	klientidel	klienti	klient	22_S	PlAd	et	klientidel =klienti  (PlAd  >klient !22_S
39791	kiusama	kiusa	kiusama	29_V	Sup	et	kiusama =kiusa  (Sup  >kiusama !29_V
39792	äraminek	minek	ära+minek	02_S	SgN	et	äraminek =minek  (SgN  >ära+minek !02_S
39804	konditeri	teri	kondi+tera	17_S	PlP	et	konditeri =teri  (PlP  >kondi+tera !17_S
39807	soovitan	soovita	soovitama	27_V	IndPrSg1	et	soovitan =soovita  (IndPrSg1  >soovitama !27_V
39808	kiosk	kiosk	kiosk	02_S	SgN	et	kiosk =kiosk  (SgN  >kiosk !02_S
39814	viskad	viska	viskama	29_V	IndPrSg2	et	viskad =viska  (IndPrSg2  >viskama !29_V
39819	märgin	märgi	märkima	28_V	IndPrSg1	et	märgin =märgi  (IndPrSg1  >märkima !28_V
39837	käid	käi	käima	38_V	IndPrSg2	et	käid =käi  (IndPrSg2  >käima !38_V
39839	müügisekretär	sekretär	müügi+sekretär	19_S	SgN	et	müügisekretär =sekretär  (SgN  >müügi+sekretär !19_S
39858	algtase	tase	alg+tase	04_S	SgN	et	algtase =tase  (SgN  >alg+tase !04_S
39861	vormistada	vormista	vormistama	27_V	Inf	et	vormistada =vormista  (Inf  >vormistama !27_V
39862	küsid	küsi	küsima	27_V	IndPrSg2	et	küsid =küsi  (IndPrSg2  >küsima !27_V
39864	hulgimüük	müük	hulgi+müük	22_S	SgN	et	hulgimüük =müük  (SgN  >hulgi+müük !22_S
39868	tööbörsist	börsi	töö+börs	22_S	SgEl	et	tööbörsist =börsi  (SgEl  >töö+börs !22_S
39869	võtluse	võtluse	võtlus	11~09_S	SgG	et	võtluse =võtluse  (SgG  >võtlus !11~09_S
39874	töötervishoid	hoid	töö+tervis+hoid	22_S	SgN	et	töötervishoid =hoid  (SgN  >töö+tervis+hoid !22_S
39885	keraamilised	keraamilise	keraamiline	12_A	PlN	et	keraamilised =keraamilise  (PlN  >keraamiline !12_A
39888	oktoober	oktoober	oktoober	02_S	SgN	et	oktoober =oktoober  (SgN  >oktoober !02_S
39784	lisandama	lisanda	lisandama	27_V	Sup	et	lisandama =lisanda  (Sup  >lisandama !27_V
39788	ostud	ostu	ost	22_S	PlN	et	ostud =ostu  (PlN  >ost !22_S
39793	looedes	ede	loo+ede	16_S	SgIn	et	looedes =ede  (SgIn  >loo+ede !16_S
39796	sõlmudes	sõlmu	sõlmuma	27_V	Ger	et	sõlmudes =sõlmu  (Ger  >sõlmuma !27_V
39797	kataloogiga	kataloogi	kataloog	22_S	SgKom	et	kataloogiga =kataloogi  (SgKom  >kataloog !22_S
39798	tutvustama	tutvusta	tutvustama	27_V	Sup	et	tutvustama =tutvusta  (Sup  >tutvustama !27_V
39800	järelmaksudes	maksu	järel+maks	22_S	PlIn	et	järelmaksudes =maksu  (PlIn  >järel+maks !22_S
39810	vastusin	usin	vast+usin	02_A	SgN	et	vastusin =usin  (SgN  >vast+usin !02_A
39812	müügil	müügi	müük	22_S	SgAd	et	müügil =müügi  (SgAd  >müük !22_S
39817	kastma	kast	kastma	34_V	Sup	et	kastma =kast  (Sup  >kastma !34_V
39827	kuupäev	päev	kuu+päev	22_S	SgN	et	kuupäev =päev  (SgN  >kuu+päev !22_S
39830	kodumajandus	majandus	kodu+majandus	11_S	SgN	et	kodumajandus =majandus  (SgN  >kodu+majandus !11_S
39832	virurand	rand	viru+rand	22_S	SgN	et	virurand =rand  (SgN  >viru+rand !22_S
39836	viru-rand	rand	viru-rand	22_S	SgN	et	viru-rand =rand  (SgN  >viru-rand !22_S
39838	praktikale	praktika	praktika	01_S	SgAll	et	praktikale =praktika  (SgAll  >praktika !01_S
39840	ettevõtluse	võtluse	ette+võtlus	11~09_S	SgG	et	ettevõtluse =võtluse  (SgG  >ette+võtlus !11~09_S
39844	mingisuguse	suguse	mingi+sugune	10_P	SgG	et	mingisuguse =suguse  (SgG  >mingi+sugune !10_P
39856	müügisekretäriks	sekretäri	müügi+sekretär	19_S	SgTr	et	müügisekretäriks =sekretäri  (SgTr  >müügi+sekretär !19_S
39879	kursusetööga	töö	kursuse+töö	26_S	SgKom	et	kursusetööga =töö  (SgKom  >kursuse+töö !26_S
39882	ettevõttepraaktika	tika	ette+võtte+praak+tikk	22_S	SgG	et	ettevõttepraaktika =tika  (SgG  >ette+võtte+praak+tikk !22_S
39893	kaubandusse	kaubandus	kaubandus	11_S	SgAdt	et	kaubandusse =kaubandus  (SgAdt  >kaubandus !11_S
39895	firmasid	firma	firma	16_S	PlP	et	firmasid =firma  (PlP  >firma !16_S
39896	koosnema	koosne	koosnema	27_V	Sup	et	koosnema =koosne  (Sup  >koosnema !27_V
39906	säilib	säili	säilima	28_V	IndPrSg3	et	säilib =säili  (IndPrSg3  >säilima !28_V
39907	hulgiladus	ladus	hulgi+ladus	02_A	SgN	et	hulgiladus =ladus  (SgN  >hulgi+ladus !02_A
39925	õppe-klass	klass	õppe-klass	22_S	SgN	et	õppe-klass =klass  (SgN  >õppe-klass !22_S
39928	võimalikud	võimaliku	võimalik	25_A	PlN	et	võimalikud =võimaliku  (PlN  >võimalik !25_A
39930	keeleoskust	oskus	keele+oskus	11~09_S	SgP	et	keeleoskust =oskus  (SgP  >keele+oskus !11~09_S
39933	koolitussekretäriga	sekretäri	koolitus+sekretär	19_S	SgKom	et	koolitussekretäriga =sekretäri  (SgKom  >koolitus+sekretär !19_S
39940	saaksite	saa	saama	37_V	KndPrPl2	et	saaksite =saa  (KndPrPl2  >saama !37_V
39946	linnaekskursioon	ekskursioon	linna+ekskursioon	22_S	SgN	et	linnaekskursioon =ekskursioon  (SgN  >linna+ekskursioon !22_S
39953	kommunaalkulude	kulu	kommunaal+kulu	17_S	PlG	et	kommunaalkulude =kulu  (PlG  >kommunaal+kulu !17_S
39955	õigusteaduses	teaduse	õigus+teadus	11~09_S	SgIn	et	õigusteaduses =teaduse  (SgIn  >õigus+teadus !11~09_S
39968	ettevõtmise	võtmise	ette+võtmine	12?10_S	SgG	et	ettevõtmise =võtmise  (SgG  >ette+võtmine !12?10_S
39975	kutsutama	kutsu	kutsuma	28_V	SupIps	et	kutsutama =kutsu  (SupIps  >kutsuma !28_V
39979	euroremont	remont	euro+remont	22_S	SgN	et	euroremont =remont  (SgN  >euro+remont !22_S
39981	kodutehnikat	tehnika	kodu+tehnika	01_S	SgP	et	kodutehnikat =tehnika  (SgP  >kodu+tehnika !01_S
39983	vasara	vasara	vasar	02_S	SgG	et	vasara =vasara  (SgG  >vasar !02_S
40000	reise	reise	reis	22_S	PlP	et	reise =reise  (PlP  >reis !22_S
40001	valisite	vali	valima	27_V	IndIpfPl2	et	valisite =vali  (IndIpfPl2  >valima !27_V
40004	laevasõit	sõit	laeva+sõit	22_S	SgN	et	laevasõit =sõit  (SgN  >laeva+sõit !22_S
40008	küllastada	küllasta	küllastama	27_V	Inf	et	küllastada =küllasta  (Inf  >küllastama !27_V
40011	koolikaaslased	kaaslase	kooli+kaaslane	12?10_S	PlN	et	koolikaaslased =kaaslase  (PlN  >kooli+kaaslane !12?10_S
40015	suhtlemiskeelena	keele	suhtlemis+keel	13_S	SgEs	et	suhtlemiskeelena =keele  (SgEs  >suhtlemis+keel !13_S
40018	ametireisidesse	reisi	ameti+reis	22_S	PlIll	et	ametireisidesse =reisi  (PlIll  >ameti+reis !22_S
40020	programmidega	programmi	programm	22_S	PlKom	et	programmidega =programmi  (PlKom  >programm !22_S
40022	koopiad	koopia	koopia	01_S	PlN	et	koopiad =koopia  (PlN  >koopia !01_S
40027	rõõmes	rõõme	rõõm	22_S	PlIn	et	rõõmes =rõõme  (PlIn  >rõõm !22_S
40033	mängime	mängi	mängima	28_V	IndPrPl1	et	mängime =mängi  (IndPrPl1  >mängima !28_V
40042	perekonnanimele	nime	pere+konna+nimi	20_S	SgAll	et	perekonnanimele =nime  (SgAll  >pere+konna+nimi !20_S
40043	eraldada	eralda	eraldama	27_V	Inf	et	eraldada =eralda  (Inf  >eraldama !27_V
40045	infinitiividest	infinitiivi	infinitiiv	22_S	PlEl	et	infinitiividest =infinitiivi  (PlEl  >infinitiiv !22_S
39825	tehnikum	tehnikum	tehnikum	19_S	SgN	et	tehnikum =tehnikum  (SgN  >tehnikum !19_S
39826	töötasite	tööta	töötama	27_V	IndIpfPl2	et	töötasite =tööta  (IndIpfPl2  >töötama !27_V
39843	ehitusmaterjalid	materjali	ehitus+materjal	19_S	PlN	et	ehitusmaterjalid =materjali  (PlN  >ehitus+materjal !19_S
39845	arvutiõpetus	õpetus	arvuti+õpetus	11_S	SgN	et	arvutiõpetus =õpetus  (SgN  >arvuti+õpetus !11_S
39849	mööblisalongis	salongi	mööbli+salong	22_S	SgIn	et	mööblisalongis =salongi  (SgIn  >mööbli+salong !22_S
39850	mööblit	mööbli	mööbel	02_S	SgP	et	mööblit =mööbli  (SgP  >mööbel !02_S
39851	mööblifurnituur	furnituur	mööbli+furnituur	22_S	SgN	et	mööblifurnituur =furnituur  (SgN  >mööbli+furnituur !22_S
39852	meier	meier	meier	02_S	SgN	et	meier =meier  (SgN  >meier !02_S
39859	toidukaubad	kauba	toidu+kaup	22_S	PlN	et	toidukaubad =kauba  (PlN  >toidu+kaup !22_S
39860	maksedokumendi	dokumendi	makse+dokument	22_S	SgG	et	maksedokumendi =dokumendi  (SgG  >makse+dokument !22_S
39863	jaemüük	müük	jae+müük	22_S	SgN	et	jaemüük =müük  (SgN  >jae+müük !22_S
39866	homseni	homse	homne	02_A	SgTer	et	homseni =homse  (SgTer  >homne !02_A
39871	suhtlemistreening	treening	suhtlemis+treening	02_S	SgN	et	suhtlemistreening =treening  (SgN  >suhtlemis+treening !02_S
39873	kaubanduses	kaubanduse	kaubandus	11_S	SgIn	et	kaubanduses =kaubanduse  (SgIn  >kaubandus !11_S
39884	müügisekretärina	sekretäri	müügi+sekretär	19_S	SgEs	et	müügisekretärina =sekretäri  (SgEs  >müügi+sekretär !19_S
39887	müügipraaktika	tika	müügi+praak+tikk	22_S	SgG	et	müügipraaktika =tika  (SgG  >müügi+praak+tikk !22_S
39890	müügiga	müügi	müük	22_S	SgKom	et	müügiga =müügi  (SgKom  >müük !22_S
39903	kalis	kali	kali	17_S	SgIn	et	kalis =kali  (SgIn  >kali !17_S
39905	teib	teib	teib	22_S	SgN	et	teib =teib  (SgN  >teib !22_S
39919	vormistama	vormista	vormistama	27_V	Sup	et	vormistama =vormista  (Sup  >vormistama !27_V
39921	turisme	turisme	turism	22_S	PlP	et	turisme =turisme  (PlP  >turism !22_S
39927	teavet	teave	teave	06_S	SgP	et	teavet =teave  (SgP  >teave !06_S
39931	ülekandega	kande	üle+kanne	06_S	SgKom	et	ülekandega =kande  (SgKom  >üle+kanne !06_S
39936	siil	siil	siil	22_S	SgN	et	siil =siil  (SgN  >siil !22_S
39937	sponsor	sponsor	sponsor	02_S	SgN	et	sponsor =sponsor  (SgN  >sponsor !02_S
39938	teatrireisile	reisi	teatri+reis	22_S	SgAll	et	teatrireisile =reisi  (SgAll  >teatri+reis !22_S
39942	edasi-tagasi	tagasi	edasi-tagasi	41_DK	ID	et	edasi-tagasi =tagasi  (ID  >edasi-tagasi !41_DK
39943	rongipilet	pilet	rongi+pilet	02_S	SgN	et	rongipilet =pilet  (SgN  >rongi+pilet !02_S
39951	hoidun	hoidu	hoiduma	27_V	IndPrSg1	et	hoidun =hoidu  (IndPrSg1  >hoiduma !27_V
39958	kant	kant	kant	22_S	SgN	et	kant =kant  (SgN  >kant !22_S
39960	kohtuasjades	asja	kohtu+asi	24_S	PlIn	et	kohtuasjades =asja  (PlIn  >kohtu+asi !24_S
39965	järgin	järgi	järgima	27_V	IndPrSg1	et	järgin =järgi  (IndPrSg1  >järgima !27_V
39966	horoskoope	horoskoope	horoskoop	22_S	PlP	et	horoskoope =horoskoope  (PlP  >horoskoop !22_S
39967	jurist	jurist	jurist	22_S	SgN	et	jurist =jurist  (SgN  >jurist !22_S
39977	karp	karp	karp	22_S	SgN	et	karp =karp  (SgN  >karp !22_S
39985	käite	käi	käima	38_V	IndPrPl2	et	käite =käi  (IndPrPl2  >käima !38_V
39987	suplema	suple	suplema	30_V	Sup	et	suplema =suple  (Sup  >suplema !30_V
39994	klienditeenindajana	teenindaja	kliendi+teenindaja	01_S	SgEs	et	klienditeenindajana =teenindaja  (SgEs  >kliendi+teenindaja !01_S
39995	konsultandina	konsultandi	konsultant	22_S	SgEs	et	konsultandina =konsultandi  (SgEs  >konsultant !22_S
39999	võiksite	või	võima	37_V	KndPrPl2	et	võiksite =või  (KndPrPl2  >võima !37_V
40003	hinnaalandus	alandus	hinna+alandus	11_S	SgN	et	hinnaalandus =alandus  (SgN  >hinna+alandus !11_S
40007	teal	teal	teal	41_D	ID	et	teal =teal  (ID  >teal !41_D
40009	valige	vali	valima	27_V	ImpPrPl2	et	valige =vali  (ImpPrPl2  >valima !27_V
40010	otstarbekad	tarbeka	ots+tarbekas	02_A	PlN	et	otstarbekad =tarbeka  (PlN  >ots+tarbekas !02_A
40012	reisiaeg	aeg	reisi+aeg	22_S	SgN	et	reisiaeg =aeg  (SgN  >reisi+aeg !22_S
40024	lõbutseda	lõbutse	lõbutsema	27_V	Inf	et	lõbutseda =lõbutse  (Inf  >lõbutsema !27_V
40025	inimistega	iste	inim+iste	06_S	SgKom	et	inimistega =iste  (SgKom  >inim+iste !06_S
40028	korjame	korja	korjama	29_V	IndPrPl1	et	korjame =korja  (IndPrPl1  >korjama !29_V
40038	tehe	tehe	tehe	06_S	SgN	et	tehe =tehe  (SgN  >tehe !06_S
40041	olukorraga	korra	olu+kord	22_S	SgKom	et	olukorraga =korra  (SgKom  >olu+kord !22_S
40044	vanemteadur	teadur	vanem+teadur	02_S	SgN	et	vanemteadur =teadur  (SgN  >vanem+teadur !02_S
40048	grammatilistest	grammatilis	grammatiline	12_A	PlEl	et	grammatilistest =grammatilis  (PlEl  >grammatiline !12_A
40049	kategooriad	kategooria	kategooria	01_S	PlN	et	kategooriad =kategooria  (PlN  >kategooria !01_S
39833	kraanajuht	juht	kraana+juht	22_S	SgN	et	kraanajuht =juht  (SgN  >kraana+juht !22_S
39834	põhi-haridus	haridus	põhi-haridus	11_S	SgN	et	põhi-haridus =haridus  (SgN  >põhi-haridus !11_S
39835	õmleja-kursuse	kursuse	õmleja-kursus	11~09_S	SgG	et	õmleja-kursuse =kursuse  (SgG  >õmleja-kursus !11~09_S
39842	turunduse	turunduse	turundus	11_S	SgG	et	turunduse =turunduse  (SgG  >turundus !11_S
39847	kirjutasime	kirjuta	kirjutama	27_V	IndIpfPl1	et	kirjutasime =kirjuta  (IndIpfPl1  >kirjutama !27_V
39848	äri-plaan	plaan	äri-plaan	22_S	SgN	et	äri-plaan =plaan  (SgN  >äri-plaan !22_S
39854	mööblid	mööbli	mööbel	02_S	PlN	et	mööblid =mööbli  (PlN  >mööbel !02_S
39865	juhtajaga	aja	juht+aeg	22_S	SgKom	et	juhtajaga =aja  (SgKom  >juht+aeg !22_S
39867	soovide	soovi	soov	22_S	PlG	et	soovide =soovi  (PlG  >soov !22_S
39870	maksedokumentide	dokumenti	makse+dokument	22_S	PlG	et	maksedokumentide =dokumenti  (PlG  >makse+dokument !22_S
39875	liin	liin	liin	22_S	SgN	et	liin =liin  (SgN  >liin !22_S
39876	mittevajalik	vajalik	mitte+vajalik	25_A	SgN	et	mittevajalik =vajalik  (SgN  >mitte+vajalik !25_A
39878	majakaup	kaup	maja+kaup	22_S	SgN	et	majakaup =kaup  (SgN  >maja+kaup !22_S
39881	tööjõuturg	turg	töö+jõu+turg	22_S	SgN	et	tööjõuturg =turg  (SgN  >töö+jõu+turg !22_S
39886	aia-mööbel	mööbel	aia-mööbel	02_S	SgN	et	aia-mööbel =mööbel  (SgN  >aia-mööbel !02_S
39889	kursusse	kursus	kursus	11_S	SgAdt	et	kursusse =kursus  (SgAdt  >kursus !11_S
39894	raamatupidamisega	pidamise	raamatu+pidamine	12_S	SgKom	et	raamatupidamisega =pidamise  (SgKom  >raamatu+pidamine !12_S
39899	sekretäriks	sekretäri	sekretär	19_S	SgTr	et	sekretäriks =sekretäri  (SgTr  >sekretär !19_S
39908	arale	ara	arg	22_A	SgAll	et	arale =ara  (SgAll  >arg !22_A
39909	kallistades	kallista	kallistama	27_V	Ger	et	kallistades =kallista  (Ger  >kallistama !27_V
39923	oktoober-kuni	kuni	oktoober-kuni	41_JK	ID	et	oktoober-kuni =kuni  (ID  >oktoober-kuni !41_JK
39926	tehnilised	tehnilise	tehniline	12_A	PlN	et	tehnilised =tehnilise  (PlN  >tehniline !12_A
39934	sakse	sakse	saks	22_S	PlP	et	sakse =sakse  (PlP  >saks !22_S
39935	koostööle	töö	koos+töö	26_S	SgAll	et	koostööle =töö  (SgAll  >koos+töö !26_S
39939	tahaksime	taha	tahtma	34_V	KndPrPl1	et	tahaksime =taha  (KndPrPl1  >tahtma !34_V
39941	oleksime	ole	olema	36_V	KndPrPl1	et	oleksime =ole  (KndPrPl1  >olema !36_V
39947	tahtsite	taht	tahtma	34_V	IndIpfPl2	et	tahtsite =taht  (IndIpfPl2  >tahtma !34_V
39950	sööst	sööst	sööst	22_S	SgN	et	sööst =sööst  (SgN  >sööst !22_S
39952	kulub	kulu	kuluma	27_V	IndPrSg3	et	kulub =kulu  (IndPrSg3  >kuluma !27_V
39956	lemmikpaik	paik	lemmik+paik	22_S	SgN	et	lemmikpaik =paik  (SgN  >lemmik+paik !22_S
39957	peipsi-äärne	äärne	peipsi-äärne	02_A	SgN	et	peipsi-äärne =äärne  (SgN  >peipsi-äärne !02_A
39963	küljeks	külje	külg	22_S	SgTr	et	küljeks =külje  (SgTr  >külg !22_S
39969	horoskoopidesse	horoskoopi	horoskoop	22_S	PlIll	et	horoskoopidesse =horoskoopi  (PlIll  >horoskoop !22_S
39974	veedame	veeda	veetma	34_V	IndPrPl1	et	veedame =veeda  (IndPrPl1  >veetma !34_V
39980	elektrotehnikat	tehnika	elektro+tehnika	01_S	SgP	et	elektrotehnikat =tehnika  (SgP  >elektro+tehnika !01_S
39982	hamburger	hamburger	hamburger	02_S	SgN	et	hamburger =hamburger  (SgN  >hamburger !02_S
39991	turism	turism	turism	22_S	SgN	et	turism =turism  (SgN  >turism !22_S
39997	oktoobrist	oktoobri	oktoober	02_S	SgEl	et	oktoobrist =oktoobri  (SgEl  >oktoober !02_S
40002	grupile	grupi	grupp	22_S	SgAll	et	grupile =grupi  (SgAll  >grupp !22_S
40005	rongipiletit	pileti	rongi+pilet	02_S	SgP	et	rongipiletit =pileti  (SgP  >rongi+pilet !02_S
40006	paevaks	vaks	pae+vaks	22_S	SgN	et	paevaks =vaks  (SgN  >pae+vaks !22_S
40017	asjalik	asjalik	asjalik	25_A	SgN	et	asjalik =asjalik  (SgN  >asjalik !25_A
40026	huvialasedega	ede	huvi+alas+ede	16_S	SgKom	et	huvialasedega =ede  (SgKom  >huvi+alas+ede !16_S
40030	kogusin	kogu	koguma	27_V	IndIpfSg1	et	kogusin =kogu  (IndIpfSg1  >koguma !27_V
40032	joonistasin	joonista	joonistama	27_V	IndIpfSg1	et	joonistasin =joonista  (IndIpfSg1  >joonistama !27_V
40034	malet	male	male	16_S	SgP	et	malet =male  (SgP  >male !16_S
40035	koristame	korista	koristama	27_V	IndPrPl1	et	koristame =korista  (IndPrPl1  >koristama !27_V
40039	käskkirjad	kirja	käsk+kiri	24_S	PlN	et	käskkirjad =kirja  (PlN  >käsk+kiri !24_S
40051	tegusõnade	sõna	tegu+sõna	17_S	PlG	et	tegusõnade =sõna  (PlG  >tegu+sõna !17_S
40052	infinitiivide	infinitiivi	infinitiiv	22_S	PlG	et	infinitiivide =infinitiivi  (PlG  >infinitiiv !22_S
40053	püsiühenditega	ühendi	püsi+ühend	02_S	PlKom	et	püsiühenditega =ühendi  (PlKom  >püsi+ühend !02_S
40055	interferentsist	interferentsi	interferents	22_S	SgEl	et	interferentsist =interferentsi  (SgEl  >interferents !22_S
40057	sekka	sekka	sekka	41_DK	ID	et	sekka =sekka  (ID  >sekka !41_DK
39891	kauputega	ute	kaup+utt	22_S	SgKom	et	kauputega =ute  (SgKom  >kaup+utt !22_S
39898	inna	inna	ind	22_S	SgG	et	inna =inna  (SgG  >ind !22_S
39901	mööblikauplus	kauplus	mööbli+kauplus	11~09_S	SgN	et	mööblikauplus =kauplus  (SgN  >mööbli+kauplus !11~09_S
39904	aktivise	vise	akti+vise	06_S	SgN	et	aktivise =vise  (SgN  >akti+vise !06_S
39910	tegeled	tegele	tegelema	31~27_V	IndPrSg2	et	tegeled =tegele  (IndPrSg2  >tegelema !31~27_V
39911	klienditeenindust	teenindus	kliendi+teenindus	11_S	SgP	et	klienditeenindust =teenindus  (SgP  >kliendi+teenindus !11_S
39912	seletati	seleta	seletama	27_V	IndIpfIps	et	seletati =seleta  (IndIpfIps  >seletama !27_V
39913	kidas	kida	kida	17_S	SgIn	et	kidas =kida  (SgIn  >kida !17_S
39915	tuletaksime	tuleta	tuletama	27_V	KndPrPl1	et	tuletaksime =tuleta  (KndPrPl1  >tuletama !27_V
39916	kultuurikeskus	keskus	kultuuri+keskus	11~09_S	SgN	et	kultuurikeskus =keskus  (SgN  >kultuuri+keskus !11~09_S
39920	valgavad	ava	valg+ava	17_S	PlN	et	valgavad =ava  (PlN  >valg+ava !17_S
39922	lugupetud	petu	lugu+pett	22_S	PlN	et	lugupetud =petu  (PlN  >lugu+pett !22_S
39932	edaspidise	pidise	edas+pidine	10_A	SgG	et	edaspidise =pidise  (SgG  >edas+pidine !10_A
39944	teatripiletid	pileti	teatri+pilet	02_S	PlN	et	teatripiletid =pileti  (PlN  >teatri+pilet !02_S
39945	hommiku-	hommiku	hommik	02_S	SgG	et	hommiku- =hommiku  (SgG  >hommik !02_S
39961	loomult	loomu	loom	22_S	SgAbl	et	loomult =loomu  (SgAbl  >loom !22_S
39964	ettevõtmisi	võtmisi	ette+võtmine	12_S	PlP	et	ettevõtmisi =võtmisi  (PlP  >ette+võtmine !12_S
39973	postkontor	kontor	post+kontor	02_S	SgN	et	postkontor =kontor  (SgN  >post+kontor !02_S
39978	kergejõustik	jõustik	kerge+jõustik	25_S	SgN	et	kergejõustik =jõustik  (SgN  >kerge+jõustik !25_S
39984	pensionäridele	pensionäri	pensionär	19_S	PlAll	et	pensionäridele =pensionäri  (PlAll  >pensionär !19_S
39986	huvialade	ala	huvi+ala	17_S	PlG	et	huvialade =ala  (PlG  >huvi+ala !17_S
39989	seened	seene	seen	13_S	PlN	et	seened =seene  (PlN  >seen !13_S
39990	tervitades	tervita	tervitama	27_V	Ger	et	tervitades =tervita  (Ger  >tervitama !27_V
39996	jaanuarini	jaanuari	jaanuar	19_S	SgTer	et	jaanuarini =jaanuari  (SgTer  >jaanuar !19_S
40013	reisiga	reisi	reis	22_S	SgKom	et	reisiga =reisi  (SgKom  >reis !22_S
40023	võimleme	võimle	võimlema	30_V	IndPrPl1	et	võimleme =võimle  (IndPrPl1  >võimlema !30_V
40029	lõkke	lõkke	lõke	06_S	SgG	et	lõkke =lõkke  (SgG  >lõke !06_S
40050	infinitiiviga	infinitiivi	infinitiiv	22_S	SgKom	et	infinitiiviga =infinitiivi  (SgKom  >infinitiiv !22_S
40056	da-infinitiiv	infinitiiv	da-infinitiiv	22_S	SgN	et	da-infinitiiv =infinitiiv  (SgN  >da-infinitiiv !22_S
40065	grammatikad	grammatika	grammatika	01_S	PlN	et	grammatikad =grammatika  (PlN  >grammatika !01_S
40066	mölder	mölder	mölder	02_S	SgN	et	mölder =mölder  (SgN  >mölder !02_S
40070	uurimusi	uurimusi	uurimus	11_S	PlP	et	uurimusi =uurimusi  (PlP  >uurimus !11_S
40071	viieks	viie	viis	14_N	SgTr	et	viieks =viie  (SgTr  >viis !14_N
40079	funktsioone	funktsioone	funktsioon	22_S	PlP	et	funktsioone =funktsioone  (PlP  >funktsioon !22_S
40086	keeletasemed	taseme	keele+tase	04_S	PlN	et	keeletasemed =taseme  (PlN  >keele+tase !04_S
40089	kõrgtasemeni	taseme	kõrg+tase	04_S	SgTer	et	kõrgtasemeni =taseme  (SgTer  >kõrg+tase !04_S
40094	keelenditest	keelendi	keelend	02_S	PlEl	et	keelenditest =keelendi  (PlEl  >keelend !02_S
40096	eksitatakse	eksita	eksitama	27_V	IndPrIps	et	eksitatakse =eksita  (IndPrIps  >eksitama !27_V
40099	väljaselgitamine	selgitamine	välja+selgitamine	12_S	SgN	et	väljaselgitamine =selgitamine  (SgN  >välja+selgitamine !12_S
40109	esinema	esine	esinema	27_V	Sup	et	esinema =esine  (Sup  >esinema !27_V
40113	infinitiividel	infinitiivi	infinitiiv	22_S	PlAd	et	infinitiividel =infinitiivi  (PlAd  >infinitiiv !22_S
40119	subjektina	subjekti	subjekt	22_S	SgEs	et	subjektina =subjekti  (SgEs  >subjekt !22_S
40120	funktsioonid	funktsiooni	funktsioon	22_S	PlN	et	funktsioonid =funktsiooni  (PlN  >funktsioon !22_S
40127	jooksma	jooks	jooksma	32_V	Sup	et	jooksma =jooks  (Sup  >jooksma !32_V
40130	usin	usin	usin	02_A	SgN	et	usin =usin  (SgN  >usin !02_A
40133	da-infinitiivile	infinitiivi	da-infinitiiv	22_S	SgAll	et	da-infinitiivile =infinitiivi  (SgAll  >da-infinitiiv !22_S
40138	infinitiivil	infinitiivi	infinitiiv	22_S	SgAd	et	infinitiivil =infinitiivi  (SgAd  >infinitiiv !22_S
40141	värvinguga	värvingu	värving	02_S	SgKom	et	värvinguga =värvingu  (SgKom  >värving !02_S
40145	ma-infinitiivil	infinitiivi	ma-infinitiiv	22_S	SgAd	et	ma-infinitiivil =infinitiivi  (SgAd  >ma-infinitiiv !22_S
40147	aktiivis	aktiivi	aktiiv	22_S	SgIn	et	aktiivis =aktiivi  (SgIn  >aktiiv !22_S
40150	elatiiv	elatiiv	elatiiv	22_S	SgN	et	elatiiv =elatiiv  (SgN  >elatiiv !22_S
40159	üksiku	üksiku	üksik	02_A	SgG	et	üksiku =üksiku  (SgG  >üksik !02_A
40162	konstruktsioone	konstruktsioone	konstruktsioon	22_S	PlP	et	konstruktsioone =konstruktsioone  (PlP  >konstruktsioon !22_S
39948	köitis	köit	köitma	34_V	IndIpfSg3	et	köitis =köit  (IndIpfSg3  >köitma !34_V
39949	tolleaegne	aegne	tolle+aegne	02_A	SgN	et	tolleaegne =aegne  (SgN  >tolle+aegne !02_A
39954	tahaksite	taha	tahtma	34_V	KndPrPl2	et	tahaksite =taha  (KndPrPl2  >tahtma !34_V
39959	alajõe	jõe	ala+jõgi	21_S	SgG	et	alajõe =jõe  (SgG  >ala+jõgi !21_S
39962	hilistel	hilis	hiline	10_A	PlAd	et	hilistel =hilis  (PlAd  >hiline !10_A
39970	kuningriigi	riigi	kuning+riik	22_S	SgG	et	kuningriigi =riigi  (SgG  >kuning+riik !22_S
39971	suursaatkond	saatkond	suur+saatkond	22_S	SgN	et	suursaatkond =saatkond  (SgN  >suur+saatkond !22_S
39972	elukohariik	riik	elu+koha+riik	22_S	SgN	et	elukohariik =riik  (SgN  >elu+koha+riik !22_S
39976	ütled	ütle	ütlema	30_V	IndPrSg2	et	ütled =ütle  (IndPrSg2  >ütlema !30_V
39988	päevitama	päevita	päevitama	27_V	Sup	et	päevitama =päevita  (Sup  >päevitama !27_V
39992	keelekeskus	keskus	keele+keskus	11~09_S	SgN	et	keelekeskus =keskus  (SgN  >keele+keskus !11~09_S
39993	turismifirmas	firma	turismi+firma	16_S	SgIn	et	turismifirmas =firma  (SgIn  >turismi+firma !16_S
39998	lugesite	luge	lugema	28_V	IndIpfPl2	et	lugesite =luge  (IndIpfPl2  >lugema !28_V
40014	veedaksime	veeda	veetma	34_V	KndPrPl1	et	veedaksime =veeda  (KndPrPl1  >veetma !34_V
40016	virk	virk	virk	22_A	SgN	et	virk =virk  (SgN  >virk !22_A
40019	kohtla-järv	järv	kohtla-järv	22_S	SgN	et	kohtla-järv =järv  (SgN  >kohtla-järv !22_S
40021	suhtlemisoskus	oskus	suhtlemis+oskus	11~09_S	SgN	et	suhtlemisoskus =oskus  (SgN  >suhtlemis+oskus !11~09_S
40031	postmarke	marke	post+mark	22_S	PlP	et	postmarke =marke  (PlP  >post+mark !22_S
40036	meeldime	meeldi	meeldima	27_V	IndPrPl1	et	meeldime =meeldi  (IndPrPl1  >meeldima !27_V
40037	jook	jook	jook	22_S	SgN	et	jook =jook  (SgN  >jook !22_S
40040	avaldada	avalda	avaldama	27_V	Inf	et	avaldada =avalda  (Inf  >avaldama !27_V
40046	infinitiivist	infinitiivi	infinitiiv	22_S	SgEl	et	infinitiivist =infinitiivi  (SgEl  >infinitiiv !22_S
40047	valikuga	valiku	valik	02_S	SgKom	et	valikuga =valiku  (SgKom  >valik !02_S
40054	vigadest	viga	viga	18_S	PlEl	et	vigadest =viga  (PlEl  >viga !18_S
40064	ülevaadet	vaade	üle+vaade	06_S	SgP	et	ülevaadet =vaade  (SgP  >üle+vaade !06_S
40068	etniline	etniline	etniline	12_A	SgN	et	etniline =etniline  (SgN  >etniline !12_A
40077	grammatilisi	grammatilisi	grammatiline	12_A	PlP	et	grammatilisi =grammatilisi  (PlP  >grammatiline !12_A
40083	näidete	näide	näide	06_S	PlG	et	näidete =näide  (PlG  >näide !06_S
40088	alatest	test	ala+test	22_S	SgN	et	alatest =test  (SgN  >ala+test !22_S
40095	tüüpilistest	tüüpilis	tüüpiline	12_A	PlEl	et	tüüpilistest =tüüpilis  (PlEl  >tüüpiline !12_A
40101	kategooriaid	kategooria	kategooria	01_S	PlP	et	kategooriaid =kategooria  (PlP  >kategooria !01_S
40110	komponendina	komponendi	komponent	22_S	SgEs	et	komponendina =komponendi  (SgEs  >komponent !22_S
40116	kõlbab	kõlba	kõlbama	29_V	IndPrSg3	et	kõlbab =kõlba  (IndPrSg3  >kõlbama !29_V
40117	kutsuma	kutsu	kutsuma	28_V	Sup	et	kutsuma =kutsu  (Sup  >kutsuma !28_V
40118	meelitama	meelita	meelitama	27_V	Sup	et	meelitama =meelita  (Sup  >meelitama !27_V
40121	verbil	verbi	verb	22_S	SgAd	et	verbil =verbi  (SgAd  >verb !22_S
40125	prefiksi	prefiksi	prefiks	02_S	SgG	et	prefiksi =prefiksi  (SgG  >prefiks !02_S
40134	verbist	verbi	verb	22_S	SgEl	et	verbist =verbi  (SgEl  >verb !22_S
40137	lauseliikmena	liikme	lause+liige	05_S	SgEs	et	lauseliikmena =liikme  (SgEs  >lause+liige !05_S
40140	modaalse	modaalse	modaalne	02_A	SgG	et	modaalse =modaalse  (SgG  >modaalne !02_A
40142	niihästi	niihästi	nii+hästi	41_D	ID	et	niihästi =niihästi  (ID  >nii+hästi !41_D
40143	ma-infinitiiviga	infinitiivi	ma-infinitiiv	22_S	SgKom	et	ma-infinitiiviga =infinitiivi  (SgKom  >ma-infinitiiv !22_S
40146	supiinil	ini	supi+ini	17_S	SgAd	et	supiinil =ini  (SgAd  >supi+ini !17_S
40156	mas-vorm	vorm	mas-vorm	22_S	SgN	et	mas-vorm =vorm  (SgN  >mas-vorm !22_S
40157	samaaegset	aegse	sama+aegne	02_A	SgP	et	samaaegset =aegse  (SgP  >sama+aegne !02_A
40172	keeldusin	keeldu	keelduma	27_V	IndIpfSg1	et	keeldusin =keeldu  (IndIpfSg1  >keelduma !27_V
40175	tänama	täna	tänama	27_V	Sup	et	tänama =täna  (Sup  >tänama !27_V
40177	väsima	väsi	väsima	27_V	Sup	et	väsima =väsi  (Sup  >väsima !27_V
40188	tüdisin	tüdi	tüdima	27_V	IndIpfSg1	et	tüdisin =tüdi  (IndIpfSg1  >tüdima !27_V
40192	minemast	mine	minema	36_V	SupEl	et	minemast =mine  (SupEl  >minema !36_V
40207	hüppama	hüppa	hüppama	29_V	Sup	et	hüppama =hüppa  (Sup  >hüppama !29_V
40209	ehmatas	ehmata	ehmatama	27_V	IndIpfSg3	et	ehmatas =ehmata  (IndIpfSg3  >ehmatama !27_V
40213	aimama	aima	aimama	29_V	Sup	et	aimama =aima  (Sup  >aimama !29_V
40219	da-infinitiivil	infinitiivi	da-infinitiiv	22_S	SgAd	et	da-infinitiivil =infinitiivi  (SgAd  >da-infinitiiv !22_S
40058	infinitiiv	infinitiiv	infinitiiv	22_S	SgN	et	infinitiiv =infinitiiv  (SgN  >infinitiiv !22_S
40063	põhilist	põhilis	põhiline	12_A	SgP	et	põhilist =põhilis  (SgP  >põhiline !12_A
40067	mõlemaid	mõlema	mõlema	02_P	PlP	et	mõlemaid =mõlema  (PlP  >mõlema !02_P
40078	süntaktilisi	süntaktilisi	süntaktiline	12_A	PlP	et	süntaktilisi =süntaktilisi  (PlP  >süntaktiline !12_A
40090	keelevaldkondades	valdkonda	keele+valdkond	22_S	PlIn	et	keelevaldkondades =valdkonda  (PlIn  >keele+valdkond !22_S
40092	retsensioonid	retsensiooni	retsensioon	22_S	PlN	et	retsensioonid =retsensiooni  (PlN  >retsensioon !22_S
40103	aktisse	akti	akt	22_S	SgIll	et	aktisse =akti  (SgIll  >akt !22_S
40105	tähenduslikke	tähenduslikke	tähenduslik	25_A	PlP	et	tähenduslikke =tähenduslikke  (PlP  >tähenduslik !25_A
40107	tegumoe	moe	tegu+mood	22_S	SgG	et	tegumoe =moe  (SgG  >tegu+mood !22_S
40112	finiitse	finiitse	finiitne	02_A	SgG	et	finiitse =finiitse  (SgG  >finiitne !02_A
40124	predikaadi	predikaadi	predikaat	22_S	SgG	et	predikaadi =predikaadi  (SgG  >predikaat !22_S
40128	finiitne	finiitne	finiitne	02_A	SgN	et	finiitne =finiitne  (SgN  >finiitne !02_A
40131	adverbiga	adverbi	adverb	22_S	SgKom	et	adverbiga =adverbi  (SgKom  >adverb !22_S
40144	da-infinitiiviga	infinitiivi	da-infinitiiv	22_S	SgKom	et	da-infinitiiviga =infinitiivi  (SgKom  >da-infinitiiv !22_S
40148	inessiiv	inessiiv	inessiiv	22_S	SgN	et	inessiiv =inessiiv  (SgN  >inessiiv !22_S
40149	mast-	mast	mast	22_S	SgN	et	mast- =mast  (SgN  >mast !22_S
40151	maks-	maks	maks	22_S	SgN	et	maks- =maks  (SgN  >maks !22_S
40163	minemas	mine	minema	36_V	SupIn	et	minemas =mine  (SupIn  >minema !36_V
40168	väljutakse	välju	väljuma	27_V	IndPrIps	et	väljutakse =välju  (IndPrIps  >väljuma !27_V
40179	hoiatama	hoiata	hoiatama	27_V	Sup	et	hoiatama =hoiata  (Sup  >hoiatama !27_V
40180	jooksmast	jooks	jooksma	32_V	SupEl	et	jooksmast =jooks  (SupEl  >jooksma !32_V
40186	väsisime	väsi	väsima	27_V	IndIpfPl1	et	väsisime =väsi  (IndIpfPl1  >väsima !27_V
40189	ootamast	oota	ootama	29_V	SupEl	et	ootamast =oota  (SupEl  >ootama !29_V
40193	maks-vorm	vorm	maks-vorm	22_S	SgN	et	maks-vorm =vorm  (SgN  >maks-vorm !22_S
40194	otstarvet	tarve	ots+tarve	06_S	SgP	et	otstarvet =tarve  (SgP  >ots+tarve !06_S
40198	kõrvuti	kõrvuti	kõrvuti	41_D	ID	et	kõrvuti =kõrvuti  (ID  >kõrvuti !41_D
40199	otstarbemäärusena	määruse	ots+tarbe+määrus	11~09_S	SgEs	et	otstarbemäärusena =määruse  (SgEs  >ots+tarbe+määrus !11~09_S
40201	osutab	osuta	osutama	27_V	IndPrSg3	et	osutab =osuta  (IndPrSg3  >osutama !27_V
40214	kippuma	kippu	kippuma	28_V	Sup	et	kippuma =kippu  (Sup  >kippuma !28_V
40215	päll	päll	päll	22_S	SgN	et	päll =päll  (SgN  >päll !22_S
40217	jutustatama	jutusta	jutustama	27_V	SupIps	et	jutustatama =jutusta  (SupIps  >jutustama !27_V
40225	himustama	himusta	himustama	27_V	Sup	et	himustama =himusta  (Sup  >himustama !27_V
40229	raatsima	raatsi	raatsima	28_V	Sup	et	raatsima =raatsi  (Sup  >raatsima !28_V
40236	predikaadiga	predikaadi	predikaat	22_S	SgKom	et	predikaadiga =predikaadi  (SgKom  >predikaat !22_S
40246	passiivse	passiivse	passiivne	02_A	SgG	et	passiivse =passiivse  (SgG  >passiivne !02_A
40247	transitiivne	transitiivne	transitiivne	02_A	SgN	et	transitiivne =transitiivne  (SgN  >transitiivne !02_A
40248	sufiks	sufiks	sufiks	02_S	SgN	et	sufiks =sufiks  (SgN  >sufiks !02_S
40258	kokkulangevused	langevuse	kokku+langevus	11_S	PlN	et	kokkulangevused =langevuse  (PlN  >kokku+langevus !11_S
40262	väljendusviisid	viisi	väljendus+viis	22_S	PlN	et	väljendusviisid =viisi  (PlN  >väljendus+viis !22_S
40269	fraasiga	fraasi	fraas	22_S	SgKom	et	fraasiga =fraasi  (SgKom  >fraas !22_S
40282	puhuma	puhu	puhuma	27_V	Sup	et	puhuma =puhu  (Sup  >puhuma !27_V
40293	püüame	püüa	püüdma	34_V	IndPrPl1	et	püüame =püüa  (IndPrPl1  >püüdma !34_V
40296	mittesoovitatavat	soovitatava	mitte+soovitatav	02_A	SgP	et	mittesoovitatavat =soovitatava  (SgP  >mitte+soovitatav !02_A
40303	vennale	venna	vend	22_S	SgAll	et	vennale =venna  (SgAll  >vend !22_S
40305	püsiühendid	ühendi	püsi+ühend	02_S	PlN	et	püsiühendid =ühendi  (PlN  >püsi+ühend !02_S
40307	uurimustele	uurimus	uurimus	11_S	PlAll	et	uurimustele =uurimus  (PlAll  >uurimus !11_S
40312	emotsionaalse	emotsionaalse	emotsionaalne	02_A	SgG	et	emotsionaalse =emotsionaalse  (SgG  >emotsionaalne !02_A
40329	lasksin	lask	laskma	34_V	IndIpfSg1	et	lasksin =lask  (IndIpfSg1  >laskma !34_V
40335	perfektiivne	perfektiivne	perfektiivne	02_A	SgN	et	perfektiivne =perfektiivne  (SgN  >perfektiivne !02_A
40344	kõnelema	kõnele	kõnelema	31~27_V	Sup	et	kõnelema =kõnele  (Sup  >kõnelema !31~27_V
40348	armastamast	armasta	armastama	27_V	SupEl	et	armastamast =armasta  (SupEl  >armastama !27_V
40355	perfektiivse	perfektiivse	perfektiivne	02_A	SgG	et	perfektiivse =perfektiivse  (SgG  >perfektiivne !02_A
40360	passiivses	passiivse	passiivne	02_A	SgIn	et	passiivses =passiivse  (SgIn  >passiivne !02_A
40059	keelekursuste	kursus	keele+kursus	11~09_S	PlG	et	keelekursuste =kursus  (PlG  >keele+kursus !11~09_S
40060	kasutusreegleid	reegle	kasutus+reegel	02_S	PlP	et	kasutusreegleid =reegle  (PlP  >kasutus+reegel !02_S
40062	strateegiaid	strateegia	strateegia	01_S	PlP	et	strateegiaid =strateegia  (PlP  >strateegia !01_S
40072	infinitiivid	infinitiivi	infinitiiv	22_S	PlN	et	infinitiivid =infinitiivi  (PlN  >infinitiiv !22_S
40073	praktilistel	praktilis	praktiline	12_A	PlAd	et	praktilistel =praktilis  (PlAd  >praktiline !12_A
40074	käsitletakse	käsitle	käsitlema	27_V	IndPrIps	et	käsitletakse =käsitle  (IndPrIps  >käsitlema !27_V
40075	infinitiive	infinitiive	infinitiiv	22_S	PlP	et	infinitiive =infinitiive  (PlP  >infinitiiv !22_S
40081	vaadeldakse	vaadel	vaatlema	30_V	IndPrIps	et	vaadeldakse =vaadel  (IndPrIps  >vaatlema !30_V
40082	käesolevas	oleva	käes+olev	02_A	SgIn	et	käesolevas =oleva  (SgIn  >käes+olev !02_A
40084	näidet	näide	näide	06_S	SgP	et	näidet =näide  (SgP  >näide !06_S
40085	kirjalikest	kirjalike	kirjalik	25_A	PlEl	et	kirjalikest =kirjalike  (PlEl  >kirjalik !25_A
40087	algtasemest	taseme	alg+tase	04_S	SgEl	et	algtasemest =taseme  (SgEl  >alg+tase !04_S
40100	ühtseid	ühtse	ühtne	02_A	PlP	et	ühtseid =ühtse  (PlP  >ühtne !02_A
40102	mõlemas	mõlema	mõlema	02_P	SgIn	et	mõlemas =mõlema  (SgIn  >mõlema !02_P
40104	arvule	arvu	arv	22_S	SgAll	et	arvule =arvu  (SgAll  >arv !22_S
40106	sisaldada	sisalda	sisaldama	27_V	Inf	et	sisaldada =sisalda  (Inf  >sisaldama !27_V
40114	ühiseid	ühise	ühine	10_A	PlP	et	ühiseid =ühise  (PlP  >ühine !10_A
40122	mõisteid	mõiste	mõiste	06_S	PlP	et	mõisteid =mõiste  (PlP  >mõiste !06_S
40129	adjektiiviga	adjektiivi	adjektiiv	22_S	SgKom	et	adjektiiviga =adjektiivi  (SgKom  >adjektiiv !22_S
40136	õun	õun	õun	23?22_S	SgN	et	õun =õun  (SgN  >õun !23?22_S
40139	neutraalset	neutraalse	neutraalne	02_A	SgP	et	neutraalset =neutraalse  (SgP  >neutraalne !02_A
40152	abessiiv	abessiiv	abessiiv	22_S	SgN	et	abessiiv =abessiiv  (SgN  >abessiiv !22_S
40154	määrusena	määruse	määrus	11~09_S	SgEs	et	määrusena =määruse  (SgEs  >määrus !11~09_S
40155	öeldisena	öeldise	öeldis	11~09_S	SgEs	et	öeldisena =öeldise  (SgEs  >öeldis !11~09_S
40158	korjamas	korja	korjama	29_V	SupIn	et	korjamas =korja  (SupIn  >korjama !29_V
40160	verbiga	verbi	verb	22_S	SgKom	et	verbiga =verbi  (SgKom  >verb !22_S
40161	viibima	viibi	viibima	27_V	Sup	et	viibima =viibi  (Sup  >viibima !27_V
40164	aasal	aasa	aas	22_S	SgAd	et	aasal =aasa  (SgAd  >aas !22_S
40166	mast-vorm	vorm	mast-vorm	22_S	SgN	et	mast-vorm =vorm  (SgN  >mast-vorm !22_S
40171	lakkas	lakka	lakkama	29_V	IndIpfSg3	et	lakkas =lakka  (IndIpfSg3  >lakkama !29_V
40181	tänasin	täna	tänama	27_V	IndIpfSg1	et	tänasin =täna  (IndIpfSg1  >tänama !27_V
40182	keeldus	keeldu	keelduma	27_V	IndIpfSg3	et	keeldus =keeldu  (IndIpfSg3  >keelduma !27_V
40187	mängimast	mängi	mängima	28_V	SupEl	et	mängimast =mängi  (SupEl  >mängima !28_V
40190	hoiatati	hoiata	hoiatama	27_V	IndIpfIps	et	hoiatati =hoiata  (IndIpfIps  >hoiatama !27_V
40204	vennal	venna	vend	22_S	SgAd	et	vennal =venna  (SgAd  >vend !22_S
40205	asuma	asu	asuma	27_V	Sup	et	asuma =asu  (Sup  >asuma !27_V
40210	põgenema	põgene	põgenema	27_V	Sup	et	põgenema =põgene  (Sup  >põgenema !27_V
40211	käsk	käsk	käsk	22_S	SgN	et	käsk =käsk  (SgN  >käsk !22_S
40212	nõusolek	olek	nõus+olek	02_S	SgN	et	nõusolek =olek  (SgN  >nõus+olek !02_S
40218	ostetama	oste	ostma	34_V	SupIps	et	ostetama =oste  (SupIps  >ostma !34_V
40220	da-vorm	vorm	da-vorm	22_S	SgN	et	da-vorm =vorm  (SgN  >da-vorm !22_S
40223	suutma	suut	suutma	34_V	Sup	et	suutma =suut  (Sup  >suutma !34_V
40228	põlgama	põlga	põlgama	29_V	Sup	et	põlgama =põlga  (Sup  >põlgama !29_V
40230	katsuma	katsu	katsuma	28_V	Sup	et	katsuma =katsu  (Sup  >katsuma !28_V
40231	keelama	keela	keelama	29_V	Sup	et	keelama =keela  (Sup  >keelama !29_V
40232	ähvardama	ähvarda	ähvardama	27_V	Sup	et	ähvardama =ähvarda  (Sup  >ähvardama !27_V
40234	hinnangut	hinnangu	hinnang	02_S	SgP	et	hinnangut =hinnangu  (SgP  >hinnang !02_S
40235	küsisõnadega	sõna	küsi+sõna	17_S	PlKom	et	küsisõnadega =sõna  (PlKom  >küsi+sõna !17_S
40237	seismas	seis	seisma	32_V	SupIn	et	seismas =seis  (SupIn  >seisma !32_V
40239	kübar	kübar	kübar	02_S	SgN	et	kübar =kübar  (SgN  >kübar !02_S
40241	tärkas	tärka	tärkama	29_V	IndIpfSg3	et	tärkas =tärka  (IndIpfSg3  >tärkama !29_V
40251	fraaside	fraasi	fraas	22_S	PlG	et	fraaside =fraasi  (PlG  >fraas !22_S
40256	pöördusime	pöördu	pöörduma	27_V	IndIpfPl1	et	pöördusime =pöördu  (IndIpfPl1  >pöörduma !27_V
40266	juhtumitel	juhtumi	juhtum	02_S	PlAd	et	juhtumitel =juhtumi  (PlAd  >juhtum !02_S
40267	tegusõnafraasiga	fraasi	tegu+sõna+fraas	22_S	SgKom	et	tegusõnafraasiga =fraasi  (SgKom  >tegu+sõna+fraas !22_S
40061	täiskasvanutele	kasvanu	täis+kasvanu	01_S	PlAll	et	täiskasvanutele =kasvanu  (PlAll  >täis+kasvanu !01_S
40069	sihtrühmaks	rühma	siht+rühm	22_S	SgTr	et	sihtrühmaks =rühma  (SgTr  >siht+rühm !22_S
40076	kirjeldatakse	kirjelda	kirjeldama	27_V	IndPrIps	et	kirjeldatakse =kirjelda  (IndPrIps  >kirjeldama !27_V
40080	venekeelsed	keelse	vene+keelne	02_A	PlN	et	venekeelsed =keelse  (PlN  >vene+keelne !02_A
40091	kindlal	kindla	kindel	02_A	SgAd	et	kindlal =kindla  (SgAd  >kindel !02_A
40093	keeleteaduses	teaduse	keele+teadus	11~09_S	SgIn	et	keeleteaduses =teaduse  (SgIn  >keele+teadus !11~09_S
40097	keeleõppijatele	õppija	keele+õppija	01_S	PlAll	et	keeleõppijatele =õppija  (PlAll  >keele+õppija !01_S
40098	põhjuste	põhjus	põhjus	11~09_S	PlG	et	põhjuste =põhjus  (PlG  >põhjus !11~09_S
40108	tunnust	tunnus	tunnus	09_S	SgP	et	tunnust =tunnus  (SgP  >tunnus !09_S
40111	õpitama	õpi	õppima	28_V	SupIps	et	õpitama =õpi  (SupIps  >õppima !28_V
40115	ma-infinitiiv	infinitiiv	ma-infinitiiv	22_S	SgN	et	ma-infinitiiv =infinitiiv  (SgN  >ma-infinitiiv !22_S
40123	väljendatakse	väljenda	väljendama	27_V	IndPrIps	et	väljendatakse =väljenda  (IndPrIps  >väljendama !27_V
40126	uinus	uinu	uinuma	27_V	IndIpfSg3	et	uinus =uinu  (IndIpfSg3  >uinuma !27_V
40132	infinitiivile	infinitiivi	infinitiiv	22_S	SgAll	et	infinitiivile =infinitiivi  (SgAll  >infinitiiv !22_S
40135	substantiiv	substantiiv	substantiiv	22_S	SgN	et	substantiiv =substantiiv  (SgN  >substantiiv !22_S
40153	ma-vorm	vorm	ma-vorm	22_S	SgN	et	ma-vorm =vorm  (SgN  >ma-vorm !22_S
40165	niitmas	niit	niitma	34_V	SupIn	et	niitmas =niit  (SupIn  >niitma !34_V
40167	märgib	märgi	märkima	28_V	IndPrSg3	et	märgib =märgi  (IndPrSg3  >märkima !28_V
40169	loobutakse	loobu	loobuma	27_V	IndPrIps	et	loobutakse =loobu  (IndPrIps  >loobuma !27_V
40170	lakatakse	laka	lakkama	29_V	IndPrIps	et	lakatakse =laka  (IndPrIps  >lakkama !29_V
40173	kõnelemast	kõnele	kõnelema	31~27_V	SupEl	et	kõnelemast =kõnele  (SupEl  >kõnelema !31~27_V
40183	võtmast	võt	võtma	35_V	SupEl	et	võtmast =võt  (SupEl  >võtma !35_V
40185	ütlemast	ütle	ütlema	30_V	SupEl	et	ütlemast =ütle  (SupEl  >ütlema !30_V
40196	et-lauset	lause	et-lause	06_S	SgP	et	et-lauset =lause  (SgP  >et-lause !06_S
40200	mata-vorm	vorm	mata-vorm	22_S	SgN	et	mata-vorm =vorm  (SgN  >mata-vorm !22_S
40202	partitsiibi	partitsiibi	partitsiip	22_S	SgG	et	partitsiibi =partitsiibi  (SgG  >partitsiip !22_S
40221	tunnusel	tunnuse	tunnus	09_S	SgAd	et	tunnusel =tunnuse  (SgAd  >tunnus !09_S
40222	des-vorm	vorm	des-vorm	22_S	SgN	et	des-vorm =vorm  (SgN  >des-vorm !22_S
40238	sihitisena	sihitise	sihitis	11_S	SgEs	et	sihitisena =sihitise  (SgEs  >sihitis !11_S
40244	perfektiivset	perfektiivse	perfektiivne	02_A	SgP	et	perfektiivset =perfektiivse  (SgP  >perfektiivne !02_A
40245	imperfektiivset	imperfektiivse	imperfektiivne	02_A	SgP	et	imperfektiivset =imperfektiivse  (SgP  >imperfektiivne !02_A
40253	vormide	vormi	vorm	22_S	PlG	et	vormide =vormi  (PlG  >vorm !22_S
40254	konkreetses	konkreetse	konkreetne	02_A	SgIn	et	konkreetses =konkreetse  (SgIn  >konkreetne !02_A
40260	asjaolust	olu	asja+olu	17_S	SgEl	et	asjaolust =olu  (SgEl  >asja+olu !17_S
40264	kõrvallauses	lause	kõrval+lause	06_S	SgIn	et	kõrvallauses =lause  (SgIn  >kõrval+lause !06_S
40272	konstruktsioonid	konstruktsiooni	konstruktsioon	22_S	PlN	et	konstruktsioonid =konstruktsiooni  (PlN  >konstruktsioon !22_S
40273	finiitsete	finiitse	finiitne	02_A	PlG	et	finiitsete =finiitse  (PlG  >finiitne !02_A
40274	vormidega	vormi	vorm	22_S	PlKom	et	vormidega =vormi  (PlKom  >vorm !22_S
40277	finiitsest	finiitse	finiitne	02_A	SgEl	et	finiitsest =finiitse  (SgEl  >finiitne !02_A
40281	vahtima	vahti	vahtima	28_V	Sup	et	vahtima =vahti  (Sup  >vahtima !28_V
40283	analüütilise	analüütilise	analüütiline	12_A	SgG	et	analüütilise =analüütilise  (SgG  >analüütiline !12_A
40291	alistuma	alistu	alistuma	27_V	Sup	et	alistuma =alistu  (Sup  >alistuma !27_V
40298	katsuge	katsu	katsuma	28_V	ImpPrPl2	et	katsuge =katsu  (ImpPrPl2  >katsuma !28_V
40308	kestuse	kestuse	kestus	11~09_S	SgG	et	kestuse =kestuse  (SgG  >kestus !11~09_S
40309	resultatiivseid	resultatiivse	resultatiivne	02_A	PlP	et	resultatiivseid =resultatiivse  (PlP  >resultatiivne !02_A
40311	intensiivset	intensiivse	intensiivne	02_A	SgP	et	intensiivset =intensiivse  (SgP  >intensiivne !02_A
40315	asutab	asuta	asutama	27_V	IndPrSg3	et	asutab =asuta  (IndPrSg3  >asutama !27_V
40316	esikomponent	komponent	esi+komponent	22_S	SgN	et	esikomponent =komponent  (SgN  >esi+komponent !22_S
40321	kasutusreeglid	reegli	kasutus+reegel	02_S	PlN	et	kasutusreeglid =reegli  (PlN  >kasutus+reegel !02_S
40326	kausatiivne	kausatiivne	kausatiivne	02_A	SgN	et	kausatiivne =kausatiivne  (SgN  >kausatiivne !02_A
40343	supletiivsed	supletiivse	supletiivne	02_A	PlN	et	supletiivsed =supletiivse  (PlN  >supletiivne !02_A
40345	sufiksid	sufiksi	sufiks	02_S	PlN	et	sufiksid =sufiksi  (PlN  >sufiks !02_S
40174	verbe	verbe	verb	22_S	PlP	et	verbe =verbe  (PlP  >verb !22_S
40176	keelduma	keeldu	keelduma	27_V	Sup	et	keelduma =keeldu  (Sup  >keelduma !27_V
40178	tüdima	tüdi	tüdima	27_V	Sup	et	tüdima =tüdi  (Sup  >tüdima !27_V
40184	hoidus	hoidu	hoiduma	27_V	IndIpfSg3	et	hoidus =hoidu  (IndIpfSg3  >hoiduma !27_V
40191	vales	vale	vale	16_SA	SgIn	et	vales =vale  (SgIn  >vale !16_SA
40195	kõrvallauset	lause	kõrval+lause	06_S	SgP	et	kõrvallauset =lause  (SgP  >kõrval+lause !06_S
40197	satuks	satu	sattuma	28_V	KndPrPs	et	satuks =satu  (KndPrPs  >sattuma !28_V
40203	kaasusena	kaasuse	kaasus	11~09_S	SgEs	et	kaasusena =kaasuse  (SgEs  >kaasus !11~09_S
40206	lõppeesmärgiks	märgi	lõpp+ees+märk	22_S	SgTr	et	lõppeesmärgiks =märgi  (SgTr  >lõpp+ees+märk !22_S
40208	ehmatama	ehmata	ehmatama	27_V	Sup	et	ehmatama =ehmata  (Sup  >ehmatama !27_V
40216	passiivis	passiivi	passiiv	22_S	SgIn	et	passiivis =passiivi  (SgIn  >passiiv !22_S
40224	kannatama	kannata	kannatama	27_V	Sup	et	kannatama =kannata  (Sup  >kannatama !27_V
40250	tüvel	tüve	tüvi	20_S	SgAd	et	tüvel =tüve  (SgAd  >tüvi !20_S
40252	eeldab	eelda	eeldama	27_V	IndPrSg3	et	eeldab =eelda  (IndPrSg3  >eeldama !27_V
40255	spikerdamas	spikerda	spikerdama	27_V	SupIn	et	spikerdamas =spikerda  (SupIn  >spikerdama !27_V
40265	otstarbe	tarbe	ots+tarve	06_S	SgG	et	otstarbe =tarbe  (SgG  >ots+tarve !06_S
40271	kontekst	kontekst	kontekst	22_S	SgN	et	kontekst =kontekst  (SgN  >kontekst !22_S
40275	seisundisse	seisundi	seisund	02_S	SgIll	et	seisundisse =seisundi  (SgIll  >seisund !02_S
40285	heietama	heieta	heietama	27_V	Sup	et	heietama =heieta  (Sup  >heietama !27_V
40300	da-infinitiivis	infinitiivi	da-infinitiiv	22_S	SgIn	et	da-infinitiivis =infinitiivi  (SgIn  >da-infinitiiv !22_S
40306	fraseoloogilise	fraseoloogilise	fraseoloogiline	12_A	SgG	et	fraseoloogilise =fraseoloogilise  (SgG  >fraseoloogiline !12_A
40310	külviga	külvi	külv	22_S	SgKom	et	külviga =külvi  (SgKom  >külv !22_S
40313	nõrgaga	nõrga	nõrk	22_A	SgKom	et	nõrgaga =nõrga  (SgKom  >nõrk !22_A
40314	töinama	töina	töinama	29_V	Sup	et	töinama =töina  (Sup  >töinama !29_V
40320	erandlikud	erandliku	erandlik	25_A	PlN	et	erandlikud =erandliku  (PlN  >erandlik !25_A
40328	kausatiivseid	kausatiivse	kausatiivne	02_A	PlP	et	kausatiivseid =kausatiivse  (PlP  >kausatiivne !02_A
40332	tegutseda	tegutse	tegutsema	27_V	Inf	et	tegutseda =tegutse  (Inf  >tegutsema !27_V
40333	juhtivisiku	isiku	juhtiv+isik	02_S	SgG	et	juhtivisiku =isiku  (SgG  >juhtiv+isik !02_S
40336	protsessuaalsele	protsessuaalse	protsessuaalne	02_A	SgAll	et	protsessuaalsele =protsessuaalse  (SgAll  >protsessuaalne !02_A
40340	aktsendi	aktsendi	aktsent	22_S	SgG	et	aktsendi =aktsendi  (SgG  >aktsent !22_S
40342	ühend	ühend	ühend	02_S	SgN	et	ühend =ühend  (SgN  >ühend !02_S
40346	adverbid	adverbi	adverb	22_S	PlN	et	adverbid =adverbi  (PlN  >adverb !22_S
40347	tegevuslaadid	laadi	tegevus+laad	22_S	PlN	et	tegevuslaadid =laadi  (PlN  >tegevus+laad !22_S
40358	vaipade	vaipa	vaip	22_S	PlG	et	vaipade =vaipa  (PlG  >vaip !22_S
40359	töökogemusega	kogemuse	töö+kogemus	11_S	SgKom	et	töökogemusega =kogemuse  (SgKom  >töö+kogemus !11_S
40371	määruse	määruse	määrus	11~09_S	SgG	et	määruse =määruse  (SgG  >määrus !11~09_S
40373	otstarbekõrvallauses	lause	ots+tarbe+kõrval+lause	06_S	SgIn	et	otstarbekõrvallauses =lause  (SgIn  >ots+tarbe+kõrval+lause !06_S
40380	reeglite	reegli	reegel	02_S	PlG	et	reeglite =reegli  (PlG  >reegel !02_S
40383	homseks	homse	homne	02_A	SgTr	et	homseks =homse  (SgTr  >homne !02_A
40396	tähelepanekuid	paneku	tähele+panek	02_S	PlP	et	tähelepanekuid =paneku  (PlP  >tähele+panek !02_S
40409	jäängi	jää	jääma	37_V	IndPrSg1^	et	jäängi =jää  (IndPrSg1^  >jääma !37_V
40412	tuttavatele	tuttava	tuttav	02_AS	PlAll	et	tuttavatele =tuttava  (PlAll  >tuttav !02_AS
40413	filoloogiateaduskond	teaduskond	filoloogia+teaduskond	22_S	SgN	et	filoloogiateaduskond =teaduskond  (SgN  >filoloogia+teaduskond !22_S
40416	keeleoskustase	tase	keele+oskus+tase	04_S	SgN	et	keeleoskustase =tase  (SgN  >keele+oskus+tase !04_S
40429	sisseütlevat	ütleva	sisse+ütlev	02_A	SgP	et	sisseütlevat =ütleva  (SgP  >sisse+ütlev !02_A
40440	paronüümidega	paronüümi	paronüüm	22_S	PlKom	et	paronüümidega =paronüümi  (PlKom  >paronüüm !22_S
40444	sõnaühendite	ühendi	sõna+ühend	02_S	PlG	et	sõnaühendite =ühendi  (PlG  >sõna+ühend !02_S
40445	abielluma	ellu	abi+elluma	27_V	Sup	et	abielluma =ellu  (Sup  >abi+elluma !27_V
40447	tervikud	terviku	tervik	02_S	PlN	et	tervikud =terviku  (PlN  >tervik !02_S
40456	kenasti	kenasti	kenasti	41_D	ID	et	kenasti =kenasti  (ID  >kenasti !41_D
40457	personaalsed	personaalse	personaalne	02_A	PlN	et	personaalsed =personaalse  (PlN  >personaalne !02_A
40461	rubriigi	rubriigi	rubriik	22_S	SgG	et	rubriigi =rubriigi  (SgG  >rubriik !22_S
40465	ringkonnakohtu	kohtu	ring+konna+kohus	05_S	SgG	et	ringkonnakohtu =kohtu  (SgG  >ring+konna+kohus !05_S
40226	ihaldama	ihalda	ihaldama	27_V	Sup	et	ihaldama =ihalda  (Sup  >ihaldama !27_V
40227	vihkama	vihka	vihkama	29_V	Sup	et	vihkama =vihka  (Sup  >vihkama !29_V
40233	pärima	päri	pärima	27_V	Sup	et	pärima =päri  (Sup  >pärima !27_V
40240	maris	mari	mari	17~16_S	SgIn	et	maris =mari  (SgIn  >mari !17~16_S
40242	subjekt	subjekt	subjekt	22_S	SgN	et	subjekt =subjekt  (SgN  >subjekt !22_S
40243	kategooriat	kategooria	kategooria	01_S	SgP	et	kategooriat =kategooria  (SgP  >kategooria !01_S
40249	konsonandi	konsonandi	konsonant	22_S	SgG	et	konsonandi =konsonandi  (SgG  >konsonant !22_S
40257	raskeks	raske	raske	01_A	SgTr	et	raskeks =raske  (SgTr  >raske !01_A
40259	ekslik	ekslik	ekslik	25_A	SgN	et	ekslik =ekslik  (SgN  >ekslik !25_A
40261	kategooriate	kategooria	kategooria	01_S	PlG	et	kategooriate =kategooria  (PlG  >kategooria !01_S
40263	keeltes	keel	keel	13_S	PlIn	et	keeltes =keel  (PlIn  >keel !13_S
40268	leksikaalse	leksikaalse	leksikaalne	02_A	SgG	et	leksikaalse =leksikaalse  (SgG  >leksikaalne !02_A
40278	inhoatiivide	inhoatiivi	inhoatiiv	22_S	PlG	et	inhoatiivide =inhoatiivi  (PlG  >inhoatiiv !22_S
40279	verbidega	verbi	verb	22_S	PlKom	et	verbidega =verbi  (PlKom  >verb !22_S
40280	pesema	pese	pesema	36_V	Sup	et	pesema =pese  (Sup  >pesema !36_V
40290	peksma	peks	peksma	32_V	Sup	et	peksma =peks  (Sup  >peksma !32_V
40292	katset	katse	katse	06_S	SgP	et	katset =katse  (SgP  >katse !06_S
40295	keelatakse	keela	keelama	29_V	IndPrIps	et	keelatakse =keela  (IndPrIps  >keelama !29_V
40297	kartust	kartus	kartus	11~09_S	SgP	et	kartust =kartus  (SgP  >kartus !11~09_S
40301	õuelaskmise	laskmise	õue+laskmine	12?10_S	SgG	et	õuelaskmise =laskmise  (SgG  >õue+laskmine !12?10_S
40317	komponendi	komponendi	komponent	22_S	SgG	et	komponendi =komponendi  (SgG  >komponent !22_S
40322	sõnaühendid	ühendi	sõna+ühend	02_S	PlN	et	sõnaühendid =ühendi  (PlN  >sõna+ühend !02_S
40324	sõnatähendus	tähendus	sõna+tähendus	11_S	SgN	et	sõnatähendus =tähendus  (SgN  >sõna+tähendus !11_S
40330	kleidi	kleidi	kleit	22_S	SgG	et	kleidi =kleidi  (SgG  >kleit !22_S
40331	mootoril	mootori	mootor	02_S	SgAd	et	mootoril =mootori  (SgAd  >mootor !02_S
40337	väljendusviis	viis	väljendus+viis	22_S	SgN	et	väljendusviis =viis  (SgN  >väljendus+viis !22_S
40341	väljendusvõimaluste	võimalus	väljendus+võimalus	11_S	PlG	et	väljendusvõimaluste =võimalus  (PlG  >väljendus+võimalus !11_S
40352	noomeni	noomeni	noomen	02_S	SgG	et	noomeni =noomeni  (SgG  >noomen !02_S
40353	pronoomeni	pronoomeni	pronoomen	02_S	SgG	et	pronoomeni =pronoomeni  (SgG  >pronoomen !02_S
40354	lükkas	lükka	lükkama	29_V	IndIpfSg3	et	lükkas =lükka  (IndIpfSg3  >lükkama !29_V
40362	künda	künd	kündma	34_V	Inf	et	künda =künd  (Inf  >kündma !34_V
40363	ülikooliharidus	haridus	üli+kooli+haridus	11_S	SgN	et	ülikooliharidus =haridus  (SgN  >üli+kooli+haridus !11_S
40367	hoiatasime	hoiata	hoiatama	27_V	IndIpfPl1	et	hoiatasime =hoiata  (IndIpfPl1  >hoiatama !27_V
40377	marmortahvlil	tahvli	marmor+tahvel	02_S	SgAd	et	marmortahvlil =tahvli  (SgAd  >marmor+tahvel !02_S
40381	reegleid	reegle	reegel	02_S	PlP	et	reegleid =reegle  (PlP  >reegel !02_S
40382	mus	mu	ma	00_P	SgIn	et	mus =mu  (SgIn  >ma !00_P
40398	näited	näite	näide	06_S	PlN	et	näited =näite  (PlN  >näide !06_S
40404	sõtta	sõtta	sõda	18_S	SgAdt	et	sõtta =sõtta  (SgAdt  >sõda !18_S
40405	interjööris	interjööri	interjöör	22_S	SgIn	et	interjööris =interjööri  (SgIn  >interjöör !22_S
40406	välguga	välgu	välk	22_S	SgKom	et	välguga =välgu  (SgKom  >välk !22_S
40407	eksamites	eksami	eksam	02_S	PlIn	et	eksamites =eksami  (PlIn  >eksam !02_S
40419	mõjuga	mõju	mõju	17_S	SgKom	et	mõjuga =mõju  (SgKom  >mõju !17_S
40433	kontrolltööks	töö	kont+roll+töö	26_S	SgTr	et	kontrolltööks =töö  (SgTr  >kont+roll+töö !26_S
40437	aeti	ae	ajama	27_V	IndIpfIps	et	aeti =ae  (IndIpfIps  >ajama !27_V
40451	reale	rea	rida	18_S	SgAll	et	reale =rea  (SgAll  >rida !18_S
40459	plokk-kiri	kiri	plokk-kiri	24_S	SgN	et	plokk-kiri =kiri  (SgN  >plokk-kiri !24_S
40464	ajalehele	lehe	aja+leht	22_S	SgAll	et	ajalehele =lehe  (SgAll  >aja+leht !22_S
40469	samasuguse	suguse	sama+sugune	10_P	SgG	et	samasuguse =suguse  (SgG  >sama+sugune !10_P
40474	vahepealkiri	kiri	vahe+peal+kiri	24_S	SgN	et	vahepealkiri =kiri  (SgN  >vahe+peal+kiri !24_S
40478	põhitekst	tekst	põhi+tekst	22_S	SgN	et	põhitekst =tekst  (SgN  >põhi+tekst !22_S
40483	plokk-kirjana	kirja	plokk-kiri	24_S	SgEs	et	plokk-kirjana =kirja  (SgEs  >plokk-kiri !24_S
40492	osutada	osuta	osutama	27_V	Inf	et	osutada =osuta  (Inf  >osutama !27_V
40493	kohtutäitur	täitur	kohtu+täitur	02_S	SgN	et	kohtutäitur =täitur  (SgN  >kohtu+täitur !02_S
40495	vastupidine	pidine	vastu+pidine	10_A	SgN	et	vastupidine =pidine  (SgN  >vastu+pidine !10_A
40270	va	va	va	41_A	ID	et	va =va  (ID  >va !41_A
40276	sõnaühenditega	ühendi	sõna+ühend	02_S	PlKom	et	sõnaühenditega =ühendi  (PlKom  >sõna+ühend !02_S
40284	konstruktsiooniga	konstruktsiooni	konstruktsioon	22_S	SgKom	et	konstruktsiooniga =konstruktsiooni  (SgKom  >konstruktsioon !22_S
40286	rõhupartikli	partikli	rõhu+partikkel	02_S	SgG	et	rõhupartikli =partikli  (SgG  >rõhu+partikkel !02_S
40287	modaalsete	modaalse	modaalne	02_A	PlG	et	modaalsete =modaalse  (PlG  >modaalne !02_A
40288	vastutama	vastuta	vastutama	27_V	Sup	et	vastutama =vastuta  (Sup  >vastutama !27_V
40289	valmisolekut	oleku	valmis+olek	02_S	SgP	et	valmisolekut =oleku  (SgP  >valmis+olek !02_S
40294	naljatada	naljata	naljatama	27_V	Inf	et	naljatada =naljata  (Inf  >naljatama !27_V
40299	ma-infinitiivis	infinitiivi	ma-infinitiiv	22_S	SgIn	et	ma-infinitiivis =infinitiivi  (SgIn  >ma-infinitiiv !22_S
40302	jätan	jäta	jätma	35_V	IndPrSg1	et	jätan =jäta  (IndPrSg1  >jätma !35_V
40304	kasutusvõimalused	võimaluse	kasutus+võimalus	11_S	PlN	et	kasutusvõimalused =võimaluse  (PlN  >kasutus+võimalus !11_S
40318	tähendussfäär	sfäär	tähendus+sfäär	22_S	SgN	et	tähendussfäär =sfäär  (SgN  >tähendus+sfäär !22_S
40319	konstruktsioonides	konstruktsiooni	konstruktsioon	22_S	PlIn	et	konstruktsioonides =konstruktsiooni  (PlIn  >konstruktsioon !22_S
40323	fraasid	fraasi	fraas	22_S	PlN	et	fraasid =fraasi  (PlN  >fraas !22_S
40325	kumma	kumma	kumb	22_P	SgG	et	kumma =kumma  (SgG  >kumb !22_P
40327	mootori	mootori	mootor	02_S	SgG	et	mootori =mootori  (SgG  >mootor !02_S
40334	aspektilt	aspekti	aspekt	22_S	SgAbl	et	aspektilt =aspekti  (SgAbl  >aspekt !22_S
40338	sufiksite	sufiksi	sufiks	02_S	PlG	et	sufiksite =sufiksi  (PlG  >sufiks !02_S
40339	prefiksite	prefiksi	prefiks	02_S	PlG	et	prefiksite =prefiksi  (PlG  >prefiks !02_S
40349	ühendverbid	verbi	ühend+verb	22_S	PlN	et	ühendverbid =verbi  (PlN  >ühend+verb !22_S
40356	kihistas	kihista	kihistama	27_V	IndIpfSg3	et	kihistas =kihista  (IndIpfSg3  >kihistama !27_V
40361	konstruktsioonis	konstruktsiooni	konstruktsioon	22_S	SgIn	et	konstruktsioonis =konstruktsiooni  (SgIn  >konstruktsioon !22_S
40364	keeletundmist	tundmis	keele+tundmine	12?10_S	SgP	et	keeletundmist =tundmis  (SgP  >keele+tundmine !12?10_S
40366	liituda	liitu	liituma	27_V	Inf	et	liituda =liitu  (Inf  >liituma !27_V
40374	avastama	avasta	avastama	27_V	Sup	et	avastama =avasta  (Sup  >avastama !27_V
40375	arengutase	tase	arengu+tase	04_S	SgN	et	arengutase =tase  (SgN  >arengu+tase !04_S
40376	kätes	kä	käsi	15_S	PlIn	et	kätes =kä  (PlIn  >käsi !15_S
40378	gümnasistid	gümnasisti	gümnasist	22_S	PlN	et	gümnasistid =gümnasisti  (PlN  >gümnasist !22_S
40379	eesmärkidesse	märki	ees+märk	22_S	PlIll	et	eesmärkidesse =märki  (PlIll  >ees+märk !22_S
40384	allolevates	oleva	all+olev	02_A	PlIn	et	allolevates =oleva  (PlIn  >all+olev !02_A
40385	tabelites	tabeli	tabel	02_S	PlIn	et	tabelites =tabeli  (PlIn  >tabel !02_S
40388	kiputakse	kipu	kippuma	28_V	IndPrIps	et	kiputakse =kipu  (IndPrIps  >kippuma !28_V
40393	rõhutame	rõhuta	rõhutama	27_V	IndPrPl1	et	rõhutame =rõhuta  (IndPrPl1  >rõhutama !27_V
40399	luban	luba	lubama	27_V	IndPrSg1	et	luban =luba  (IndPrSg1  >lubama !27_V
40401	ohverdama	ohverda	ohverdama	27_V	Sup	et	ohverdama =ohverda  (Sup  >ohverdama !27_V
40402	jõuks	jõu	jõud	22_S	SgTr	et	jõuks =jõu  (SgTr  >jõud !22_S
40417	tõlgib	tõlgi	tõlkima	28_V	IndPrSg3	et	tõlgib =tõlgi  (IndPrSg3  >tõlkima !28_V
40418	reeglit	reegli	reegel	02_S	SgP	et	reeglit =reegli  (SgP  >reegel !02_S
40421	nõrga	nõrga	nõrk	22_A	SgG	et	nõrga =nõrga  (SgG  >nõrk !22_A
40422	tehnikad	tehnika	tehnika	01_S	PlN	et	tehnikad =tehnika  (PlN  >tehnika !01_S
40423	mitmuses	mitmuse	mitmus	11~09_S	SgIn	et	mitmuses =mitmuse  (SgIn  >mitmus !11~09_S
40426	ettevaatlik	vaatlik	ette+vaatlik	25_A	SgN	et	ettevaatlik =vaatlik  (SgN  >ette+vaatlik !25_A
40431	tegevusnimi	nimi	tegevus+nimi	20_S	SgN	et	tegevusnimi =nimi  (SgN  >tegevus+nimi !20_S
40435	lõõgastama	lõõgasta	lõõgastama	27_V	Sup	et	lõõgastama =lõõgasta  (Sup  >lõõgastama !27_V
40441	keeleõppijal	õppija	keele+õppija	01_S	SgAd	et	keeleõppijal =õppija  (SgAd  >keele+õppija !01_S
40442	sõnavaravead	vea	sõna+vara+viga	18_S	PlN	et	sõnavaravead =vea  (PlN  >sõna+vara+viga !18_S
40452	tekstiveergude	veergu	teksti+veerg	22_S	PlG	et	tekstiveergude =veergu  (PlG  >teksti+veerg !22_S
40454	ülaloleva	oleva	ülal+olev	02_A	SgG	et	ülaloleva =oleva  (SgG  >ülal+olev !02_A
40473	õieti	õieti	õieti	41_D	ID	et	õieti =õieti  (ID  >õieti !41_D
40476	plokk-kirjaga	kirja	plokk-kiri	24_S	SgKom	et	plokk-kirjaga =kirja  (SgKom  >plokk-kiri !24_S
40486	põhitekstide	teksti	põhi+tekst	22_S	PlG	et	põhitekstide =teksti  (PlG  >põhi+tekst !22_S
40501	stamp	stamp	stamp	22_S	SgN	et	stamp =stamp  (SgN  >stamp !22_S
40518	pisiinfot	info	pisi+info	16_S	SgP	et	pisiinfot =info  (SgP  >pisi+info !16_S
40350	ühendid	ühendi	ühend	02_S	PlN	et	ühendid =ühendi  (PlN  >ühend !02_S
40351	kihutas	kihuta	kihutama	27_V	IndIpfSg3	et	kihutas =kihuta  (IndIpfSg3  >kihutama !27_V
40357	löristas	lörista	löristama	27_V	IndIpfSg3	et	löristas =lörista  (IndIpfSg3  >löristama !27_V
40365	fraasis	fraasi	fraas	22_S	SgIn	et	fraasis =fraasi  (SgIn  >fraas !22_S
40392	stabiilsed	stabiilse	stabiilne	02_A	PlN	et	stabiilsed =stabiilse  (PlN  >stabiilne !02_A
40394	konkreetse	konkreetse	konkreetne	02_A	SgG	et	konkreetse =konkreetse  (SgG  >konkreetne !02_A
40397	analüüsist	analüüsi	analüüs	22_S	SgEl	et	analüüsist =analüüsi  (SgEl  >analüüs !22_S
40408	kipuvad	kipu	kippuma	28_V	IndPrPl3	et	kipuvad =kipu  (IndPrPl3  >kippuma !28_V
40415	teemadel	teema	teema	16_S	PlAd	et	teemadel =teema  (PlAd  >teema !16_S
40420	keeleoskustasemega	taseme	keele+oskus+tase	04_S	SgKom	et	keeleoskustasemega =taseme  (SgKom  >keele+oskus+tase !04_S
40424	väidega	väi	väi	26_S	PlKom	et	väidega =väi  (PlKom  >väi !26_S
40430	poodides	poodi	pood	22_S	PlIn	et	poodides =poodi  (PlIn  >pood !22_S
40434	verbidel	verbi	verb	22_S	PlAd	et	verbidel =verbi  (PlAd  >verb !22_S
40449	heroiin	heroiin	heroiin	22_S	SgN	et	heroiin =heroiin  (SgN  >heroiin !22_S
40450	sisult	sisu	sisu	17_S	SgAbl	et	sisult =sisu  (SgAbl  >sisu !17_S
40455	konservatiivne	konservatiivne	konservatiivne	02_A	SgN	et	konservatiivne =konservatiivne  (SgN  >konservatiivne !02_A
40458	spordiosas	osa	spordi+osa	17_S	SgIn	et	spordiosas =osa  (SgIn  >spordi+osa !17_S
40462	jagab	jaga	jagama	27_V	IndPrSg3	et	jagab =jaga  (IndPrSg3  >jagama !27_V
40463	rubriik	rubriik	rubriik	22_S	SgN	et	rubriik =rubriik  (SgN  >rubriik !22_S
40471	kontserdisaalile	saali	kontserdi+saal	22_S	SgAll	et	kontserdisaalile =saali  (SgAll  >kontserdi+saal !22_S
40472	veerudesse	veeru	veer	22_S	PlIll	et	veerudesse =veeru  (PlIll  >veer !22_S
40477	mahub	mahu	mahtuma	28_V	IndPrSg3	et	mahub =mahu  (IndPrSg3  >mahtuma !28_V
40479	eelistab	eelista	eelistama	27_V	IndPrSg3	et	eelistab =eelista  (IndPrSg3  >eelistama !27_V
40480	kirjana	kirja	kiri	24_S	SgEs	et	kirjana =kirja  (SgEs  >kiri !24_S
40487	ühesugune	sugune	ühe+sugune	10_A	SgN	et	ühesugune =sugune  (SgN  >ühe+sugune !10_A
40490	segase	segase	segane	10_A	SgG	et	segase =segase  (SgG  >segane !10_A
40491	elatise	elatise	elatis	11_S	SgG	et	elatise =elatise  (SgG  >elatis !11_S
40498	elustiiliga	stiili	elu+stiil	22_S	SgKom	et	elustiiliga =stiili  (SgKom  >elu+stiil !22_S
40499	nõrgestuma	nõrgestu	nõrgestuma	27_V	Sup	et	nõrgestuma =nõrgestu  (Sup  >nõrgestuma !27_V
40500	põhjarannikus	ranniku	põhja+rannik	02_S	SgIn	et	põhjarannikus =ranniku  (SgIn  >põhja+rannik !02_S
40513	allkirjadeta	kirja	all+kiri	24_S	PlAb	et	allkirjadeta =kirja  (PlAb  >all+kiri !24_S
40522	ranget	range	range	01_A	SgP	et	ranget =range  (SgP  >range !01_A
40523	kriteeriume	kriteeriume	kriteerium	19_S	PlP	et	kriteeriume =kriteeriume  (PlP  >kriteerium !19_S
40524	leheküljele	külje	lehe+külg	22_S	SgAll	et	leheküljele =külje  (SgAll  >lehe+külg !22_S
40525	elemendid	elemendi	element	22_S	PlN	et	elemendid =elemendi  (PlN  >element !22_S
40526	haagivad	haagi	haakima	28_V	IndPrPl3	et	haagivad =haagi  (IndPrPl3  >haakima !28_V
40543	hääldatakse	häälda	hääldama	27_V	IndPrIps	et	hääldatakse =häälda  (IndPrIps  >hääldama !27_V
40552	klaveriga	klaveri	klaver	02_S	SgKom	et	klaveriga =klaveri  (SgKom  >klaver !02_S
40555	kasutuskoht	koht	kasutus+koht	22_S	SgN	et	kasutuskoht =koht  (SgN  >kasutus+koht !22_S
40556	sisekohakäänete	kääne	sise+koha+kääne	06_S	PlG	et	sisekohakäänete =kääne  (PlG  >sise+koha+kääne !06_S
40561	väliskohakäänete	kääne	välis+koha+kääne	06_S	PlG	et	väliskohakäänete =kääne  (PlG  >välis+koha+kääne !06_S
40564	arvus	arvu	arv	22_S	SgIn	et	arvus =arvu  (SgIn  >arv !22_S
40565	ühildatakse	ühilda	ühildama	27_V	IndPrIps	et	ühildatakse =ühilda  (IndPrIps  >ühildama !27_V
40566	käänded	käände	kääne	06_S	PlN	et	käänded =käände  (PlN  >kääne !06_S
40567	huvitasin	huvita	huvitama	27_V	IndIpfSg1	et	huvitasin =huvita  (IndIpfSg1  >huvitama !27_V
40572	komistuskiviks	kivi	komistus+kivi	17_S	SgTr	et	komistuskiviks =kivi  (SgTr  >komistus+kivi !17_S
40573	emakeelekõnelejatele	kõneleja	ema+keele+kõneleja	01_S	PlAll	et	emakeelekõnelejatele =kõneleja  (PlAll  >ema+keele+kõneleja !01_S
40574	tellib	telli	tellima	28_V	IndPrSg3	et	tellib =telli  (IndPrSg3  >tellima !28_V
40575	tellima	telli	tellima	28_V	Sup	et	tellima =telli  (Sup  >tellima !28_V
40579	kommid	kommi	komm	22_S	PlN	et	kommid =kommi  (PlN  >komm !22_S
40581	sõjaväelaseks	väelase	sõja+väelane	12?10_S	SgTr	et	sõjaväelaseks =väelase  (SgTr  >sõja+väelane !12?10_S
40589	huvitada	huvita	huvitama	27_V	Inf	et	huvitada =huvita  (Inf  >huvitama !27_V
40590	täiskasvanuid	kasvanu	täis+kasvanu	01_S	PlP	et	täiskasvanuid =kasvanu  (PlP  >täis+kasvanu !01_S
40368	maandage	maanda	maandama	27_V	ImpPrPl2	et	maandage =maanda  (ImpPrPl2  >maandama !27_V
40369	öeldist	öeldis	öeldis	11~09_S	SgP	et	öeldist =öeldis  (SgP  >öeldis !11~09_S
40370	sihitise	sihitise	sihitis	11_S	SgG	et	sihitise =sihitise  (SgG  >sihitis !11_S
40372	täiendina	täiendi	täiend	02_S	SgEs	et	täiendina =täiendi  (SgEs  >täiend !02_S
40386	alanüüs	nüü	ala+nüü	26_S	SgIn	et	alanüüs =nüü  (SgIn  >ala+nüü !26_S
40387	võrdse	võrdse	võrdne	02_A	SgG	et	võrdse =võrdse  (SgG  >võrdne !02_A
40389	üldistama	üldista	üldistama	27_V	Sup	et	üldistama =üldista  (Sup  >üldistama !27_V
40390	verbidest	verbi	verb	22_S	PlEl	et	verbidest =verbi  (PlEl  >verb !22_S
40391	märkame	märka	märkama	29_V	IndPrPl1	et	märkame =märka  (IndPrPl1  >märkama !29_V
40395	üldistada	üldista	üldistama	27_V	Inf	et	üldistada =üldista  (Inf  >üldistama !27_V
40400	arhitektuurisse	arhitektuuri	arhitektuur	22_S	SgIll	et	arhitektuurisse =arhitektuuri  (SgIll  >arhitektuur !22_S
40403	klassivendadega	venda	klassi+vend	22_S	PlKom	et	klassivendadega =venda  (PlKom  >klassi+vend !22_S
40410	vestlema	vestle	vestlema	30_V	Sup	et	vestlema =vestle  (Sup  >vestlema !30_V
40411	pulmadele	pulma	pulm	22_S	PlAll	et	pulmadele =pulma  (PlAll  >pulm !22_S
40414	kirjalikke	kirjalikke	kirjalik	25_A	PlP	et	kirjalikke =kirjalikke  (PlP  >kirjalik !25_A
40425	kohakäänete	kääne	koha+kääne	06_S	PlG	et	kohakäänete =kääne  (PlG  >koha+kääne !06_S
40427	prospektis	prospekti	prospekt	22_S	SgIn	et	prospektis =prospekti  (SgIn  >prospekt !22_S
40428	seestütleva	ütleva	seest+ütlev	02_A	SgG	et	seestütleva =ütleva  (SgG  >seest+ütlev !02_A
40432	tahta	taht	tahtma	34_V	Inf	et	tahta =taht  (Inf  >tahtma !34_V
40436	lõõgastuma	lõõgastu	lõõgastuma	27_V	Sup	et	lõõgastuma =lõõgastu  (Sup  >lõõgastuma !27_V
40438	unustatakse	unusta	unustama	27_V	IndPrIps	et	unustatakse =unusta  (IndPrIps  >unustama !27_V
40439	sõnatasandi	tasandi	sõna+tasand	02_S	SgG	et	sõnatasandi =tasandi  (SgG  >sõna+tasand !02_S
40443	ajaviitmise	viitmise	aja+viitmine	12?10_S	SgG	et	ajaviitmise =viitmise  (SgG  >aja+viitmine !12?10_S
40446	põhjaranniku	ranniku	põhja+rannik	02_S	SgG	et	põhjaranniku =ranniku  (SgG  >põhja+rannik !02_S
40448	osadeks	osa	osa	17_S	PlTr	et	osadeks =osa  (PlTr  >osa !17_S
40453	seostuma	seostu	seostuma	27_V	Sup	et	seostuma =seostu  (Sup  >seostuma !27_V
40460	lisale	lisa	lisa	17_S	SgAll	et	lisale =lisa  (SgAll  >lisa !17_S
40470	märts	märts	märts	22_S	SgN	et	märts =märts  (SgN  >märts !22_S
40482	kaksikleheküljel	külje	kaksik+lehe+külg	22_S	SgAd	et	kaksikleheküljel =külje  (SgAd  >kaksik+lehe+külg !22_S
40484	reavahega	vahe	rea+vahe	16_S	SgKom	et	reavahega =vahe  (SgKom  >rea+vahe !16_S
40485	antiikvas	antiikva	antiikva	16_S	SgIn	et	antiikvas =antiikva  (SgIn  >antiikva !16_S
40488	minimaalne	minimaalne	minimaalne	02_A	SgN	et	minimaalne =minimaalne  (SgN  >minimaalne !02_A
40494	langetada	langeta	langetama	27_V	Inf	et	langetada =langeta  (Inf  >langetama !27_V
40496	põhjarannikuga	ranniku	põhja+rannik	02_S	SgKom	et	põhjarannikuga =ranniku  (SgKom  >põhja+rannik !02_S
40502	toetab	toeta	toetama	27_V	IndPrSg3	et	toetab =toeta  (IndPrSg3  >toetama !27_V
40503	sündmusfotod	foto	sündmus+foto	16_S	PlN	et	sündmusfotod =foto  (PlN  >sündmus+foto !16_S
40504	staatiline	staatiline	staatiline	12_A	SgN	et	staatiline =staatiline  (SgN  >staatiline !12_A
40506	stampfotod	foto	stamp+foto	16_S	PlN	et	stampfotod =foto  (PlN  >stamp+foto !16_S
40507	sündmusfotosid	foto	sündmus+foto	16_S	PlP	et	sündmusfotosid =foto  (PlP  >sündmus+foto !16_S
40508	fotol	foto	foto	16_S	SgAd	et	fotol =foto  (SgAd  >foto !16_S
40509	fotoallkiri	kiri	foto+all+kiri	24_S	SgN	et	fotoallkiri =kiri  (SgN  >foto+all+kiri !24_S
40512	ümberjutustavad	jutustava	ümber+jutustav	02_A	PlN	et	ümberjutustavad =jutustava  (PlN  >ümber+jutustav !02_A
40521	provintsiaalne	provintsiaalne	provintsiaalne	02_A	SgN	et	provintsiaalne =provintsiaalne  (SgN  >provintsiaalne !02_A
40527	hajumast	haju	hajuma	27_V	SupEl	et	hajumast =haju  (SupEl  >hajuma !27_V
40530	mordvalaste	mordvalas	mordvalane	12_S	PlG	et	mordvalaste =mordvalas  (PlG  >mordvalane !12_S
40531	mordvalased	mordvalase	mordvalane	12_S	PlN	et	mordvalased =mordvalase  (PlN  >mordvalane !12_S
40548	käändeid	käände	kääne	06_S	PlP	et	käändeid =käände  (PlP  >kääne !06_S
40549	kääne	kääne	kääne	06_S	SgN	et	kääne =kääne  (SgN  >kääne !06_S
40550	roosikimbi	kimbi	roosi+kimp	22_S	SgG	et	roosikimbi =kimbi  (SgG  >roosi+kimp !22_S
40551	põhjusteks	põhjus	põhjus	11~09_S	PlTr	et	põhjusteks =põhjus  (PlTr  >põhjus !11~09_S
40560	saksamaas	maa	saksa+maa	26_S	SgIn	et	saksamaas =maa  (SgIn  >saksa+maa !26_S
40568	kasutataks	kasuta	kasutama	27_V	KndPrIps	et	kasutataks =kasuta  (KndPrIps  >kasutama !27_V
40585	sõnatasandil	tasandi	sõna+tasand	02_S	SgAd	et	sõnatasandil =tasandi  (SgAd  >sõna+tasand !02_S
40466	mitteametliku	ametliku	mitte+ametlik	25_A	SgG	et	mitteametliku =ametliku  (SgG  >mitte+ametlik !25_A
40467	sõbralikuna	sõbraliku	sõbralik	25_A	SgEs	et	sõbralikuna =sõbraliku  (SgEs  >sõbralik !25_A
40468	read	rea	rida	18_S	PlN	et	read =rea  (PlN  >rida !18_S
40475	vahepealkirjad	kirja	vahe+peal+kiri	24_S	PlN	et	vahepealkirjad =kirja  (PlN  >vahe+peal+kiri !24_S
40481	antiikvat	antiikva	antiikva	16_S	SgP	et	antiikvat =antiikva  (SgP  >antiikva !16_S
40489	mahutada	mahuta	mahutama	27_V	Inf	et	mahutada =mahuta  (Inf  >mahutama !27_V
40497	harjusime	harju	harjuma	27_V	IndIpfPl1	et	harjusime =harju  (IndIpfPl1  >harjuma !27_V
40505	portreefotod	foto	port+ree+foto	16_S	PlN	et	portreefotod =foto  (PlN  >port+ree+foto !16_S
40510	kehvad	kehva	kehv	22_A	PlN	et	kehvad =kehva  (PlN  >kehv !22_A
40511	allkirjad	kirja	all+kiri	24_S	PlN	et	allkirjad =kirja  (PlN  >all+kiri !24_S
40515	tähed	tähe	täht	22_S	PlN	et	tähed =tähe  (PlN  >täht !22_S
40516	ühetaolise	taolise	ühe+taoline	12?10_A	SgG	et	ühetaolise =taolise  (SgG  >ühe+taoline !12?10_A
40517	lehel	lehe	leht	22_S	SgAd	et	lehel =lehe  (SgAd  >leht !22_S
40520	pisiinfos	info	pisi+info	16_S	SgIn	et	pisiinfos =info  (SgIn  >pisi+info !16_S
40528	paremapoolsele	poolse	parema+poolne	02_A	SgAll	et	paremapoolsele =poolse  (SgAll  >parema+poolne !02_A
40529	rubriigid	rubriigi	rubriik	22_S	PlN	et	rubriigid =rubriigi  (PlN  >rubriik !22_S
40532	rääkimas	rääki	rääkima	28_V	SupIn	et	rääkimas =rääki  (SupIn  >rääkima !28_V
40533	töödeks	töö	töö	26_S	PlTr	et	töödeks =töö  (PlTr  >töö !26_S
40536	juhuslikud	juhusliku	juhuslik	25_A	PlN	et	juhuslikud =juhusliku  (PlN  >juhuslik !25_A
40544	teguriks	teguri	tegur	02_S	SgTr	et	teguriks =teguri  (SgTr  >tegur !02_S
40545	õppurite	õppuri	õppur	02_S	PlG	et	õppurite =õppuri  (PlG  >õppur !02_S
40557	atmosfääris	atmosfääri	atmosfäär	22_S	SgIn	et	atmosfääris =atmosfääri  (SgIn  >atmosfäär !22_S
40558	restoranisse	restorani	restoran	19_S	SgIll	et	restoranisse =restorani  (SgIll  >restoran !19_S
40559	kohakääne	kääne	koha+kääne	06_S	SgN	et	kohakääne =kääne  (SgN  >koha+kääne !06_S
40562	põhjale	põhja	põhi	24_S	SgAll	et	põhjale =põhja  (SgAll  >põhi !24_S
40569	leksikaalsest	leksikaalse	leksikaalne	02_A	SgEl	et	leksikaalsest =leksikaalse  (SgEl  >leksikaalne !02_A
40571	rektsioon	rektsioon	rektsioon	22_S	SgN	et	rektsioon =rektsioon  (SgN  >rektsioon !22_S
40576	toidab	toida	toitma	34_V	IndPrSg3	et	toidab =toida  (IndPrSg3  >toitma !34_V
40578	joob	joo	jooma	38_V	IndPrSg3	et	joob =joo  (IndPrSg3  >jooma !38_V
40580	seened-korjama	korja	seened-korjama	29_V	Sup	et	seened-korjama =korja  (Sup  >seened-korjama !29_V
40582	kirjandit	kirjandi	kirjand	02_S	SgP	et	kirjandit =kirjandi  (SgP  >kirjand !02_S
40588	paigutasin	paiguta	paigutama	27_V	IndIpfSg1	et	paigutasin =paiguta  (IndIpfSg1  >paigutama !27_V
40597	põhjapanevaid	paneva	põhja+panev	02_A	PlP	et	põhjapanevaid =paneva  (PlP  >põhja+panev !02_A
40598	loend	loend	loend	02_S	SgN	et	loend =loend  (SgN  >loend !02_S
40603	valestimõistmist	mõistmis	valesti+mõistmine	12?10_S	SgP	et	valestimõistmist =mõistmis  (SgP  >valesti+mõistmine !12?10_S
40606	toimida	toimi	toimima	28_V	Inf	et	toimida =toimi  (Inf  >toimima !28_V
40625	ühendverbiga	verbi	ühend+verb	22_S	SgKom	et	ühendverbiga =verbi  (SgKom  >ühend+verb !22_S
40626	liittegusõnad	sõna	liit+tegu+sõna	17_S	PlN	et	liittegusõnad =sõna  (PlN  >liit+tegu+sõna !17_S
40628	ühendtegusõnad	sõna	ühend+tegu+sõna	17_S	PlN	et	ühendtegusõnad =sõna  (PlN  >ühend+tegu+sõna !17_S
40635	söötma	sööt	söötma	34_V	Sup	et	söötma =sööt  (Sup  >söötma !34_V
40636	nimisõnu	sõnu	nimi+sõna	17_S	PlP	et	nimisõnu =sõnu  (PlP  >nimi+sõna !17_S
40641	omadussõnadel	sõna	omadus+sõna	17_S	PlAd	et	omadussõnadel =sõna  (PlAd  >omadus+sõna !17_S
40649	keskvõrde	võrde	kesk+võrre	06_S	SgG	et	keskvõrde =võrde  (SgG  >kesk+võrre !06_S
40661	asesõnade	sõna	ase+sõna	17_S	PlG	et	asesõnade =sõna  (PlG  >ase+sõna !17_S
40662	põhifunktsioon	funktsioon	põhi+funktsioon	22_S	SgN	et	põhifunktsioon =funktsioon  (SgN  >põhi+funktsioon !22_S
40668	kaassõnad	sõna	kaas+sõna	17_S	PlN	et	kaassõnad =sõna  (PlN  >kaas+sõna !17_S
40671	kontekstides	konteksti	kontekst	22_S	PlIn	et	kontekstides =konteksti  (PlIn  >kontekst !22_S
40672	muretsege	muretse	muretsema	27_V	ImpPrPl2	et	muretsege =muretse  (ImpPrPl2  >muretsema !27_V
40680	osasihitis	sihitis	osa+sihitis	11_S	SgN	et	osasihitis =sihitis  (SgN  >osa+sihitis !11_S
40685	õhtuks	õhtu	õhtu	01_S	SgTr	et	õhtuks =õhtu  (SgTr  >õhtu !01_S
40686	kõneviis	viis	kõne+viis	22_S	SgN	et	kõneviis =viis  (SgN  >kõne+viis !22_S
40690	õmbleksin	õmble	õmblema	30_V	KndPrSg1	et	õmbleksin =õmble  (KndPrSg1  >õmblema !30_V
40697	oo-uu	uu	oo-uu	41_I	ID	et	oo-uu =uu  (ID  >oo-uu !41_I
40514	fotoallkirjad	kirja	foto+all+kiri	24_S	PlN	et	fotoallkirjad =kirja  (PlN  >foto+all+kiri !24_S
40539	mordvalastega	mordvalas	mordvalane	12_S	PlKom	et	mordvalastega =mordvalas  (PlKom  >mordvalane !12_S
40540	eestlasele	eestlase	eestlane	12?10_S	SgAll	et	eestlasele =eestlase  (SgAll  >eestlane !12?10_S
40542	kaashäälikuid	hääliku	kaas+häälik	02_S	PlP	et	kaashäälikuid =hääliku  (PlP  >kaas+häälik !02_S
40546	verbides	verbi	verb	22_S	PlIn	et	verbides =verbi  (PlIn  >verb !22_S
40547	nimisõnades	sõna	nimi+sõna	17_S	PlIn	et	nimisõnades =sõna  (PlIn  >nimi+sõna !17_S
40553	autojuhina	juhi	auto+juht	22_S	SgEs	et	autojuhina =juhi  (SgEs  >auto+juht !22_S
40570	heitma	heit	heitma	34_V	Sup	et	heitma =heit  (Sup  >heitma !34_V
40577	toitma	toit	toitma	34_V	Sup	et	toitma =toit  (Sup  >toitma !34_V
40583	kontekstist	konteksti	kontekst	22_S	SgEl	et	kontekstist =konteksti  (SgEl  >kontekst !22_S
40586	sõnajärg	järg	sõna+järg	22_S	SgN	et	sõnajärg =järg  (SgN  >sõna+järg !22_S
40587	asesõnavea	vea	ase+sõna+viga	18_S	SgG	et	asesõnavea =vea  (SgG  >ase+sõna+viga !18_S
40591	avame	ava	avama	27_V	IndPrPl1	et	avame =ava  (IndPrPl1  >avama !27_V
40596	käänete	kääne	kääne	06_S	PlG	et	käänete =kääne  (PlG  >kääne !06_S
40600	andke	and	andma	34_V	ImpPrPl2	et	andke =and  (ImpPrPl2  >andma !34_V
40601	kõrvalekalle	kalle	kõrvale+kalle	06_S	SgN	et	kõrvalekalle =kalle  (SgN  >kõrvale+kalle !06_S
40608	õigekirjavead	vea	õige+kirja+viga	18_S	PlN	et	õigekirjavead =vea  (PlN  >õige+kirja+viga !18_S
40614	tänada	täna	tänama	27_V	Inf	et	tänada =täna  (Inf  >tänama !27_V
40617	järje	järje	järg	22_S	SgG	et	järje =järje  (SgG  >järg !22_S
40618	kirjalikul	kirjaliku	kirjalik	25_A	SgAd	et	kirjalikul =kirjaliku  (SgAd  >kirjalik !25_A
40620	parandades	paranda	parandama	27_V	Ger	et	parandades =paranda  (Ger  >parandama !27_V
40627	tüvest	tüve	tüvi	20_S	SgEl	et	tüvest =tüve  (SgEl  >tüvi !20_S
40644	arvsõnade	sõna	arv+sõna	17_S	PlG	et	arvsõnade =sõna  (PlG  >arv+sõna !17_S
40653	arvsõnad	sõna	arv+sõna	17_S	PlN	et	arvsõnad =sõna  (PlN  >arv+sõna !17_S
40657	köögipugerikus	pugeriku	köögi+pugerik	25_S	SgIn	et	köögipugerikus =pugeriku  (SgIn  >köögi+pugerik !25_S
40658	seesütleva	ütleva	sees+ütlev	02_A	SgG	et	seesütleva =ütleva  (SgG  >sees+ütlev !02_A
40660	astme	astme	aste	05_S	SgG	et	astme =astme  (SgG  >aste !05_S
40669	mittetäistähenduslikud	tähendusliku	mitte+täis+tähenduslik	25_A	PlN	et	mittetäistähenduslikud =tähendusliku  (PlN  >mitte+täis+tähenduslik !25_A
40670	sealjuures	sealjuures	seal+juures	41_D	ID	et	sealjuures =sealjuures  (ID  >seal+juures !41_D
40677	suusse	suu	suu	26_S	SgIll	et	suusse =suu  (SgIll  >suu !26_S
40678	pesasse	pesa	pesa	17_S	SgIll	et	pesasse =pesa  (SgIll  >pesa !17_S
40683	siile	siile	siil	22_S	PlP	et	siile =siile  (PlP  >siil !22_S
40689	peseksin	pese	pesema	36_V	KndPrSg1	et	peseksin =pese  (KndPrSg1  >pesema !36_V
40695	murtakse	mur	murdma	34_V	IndPrIps	et	murtakse =mur  (IndPrIps  >murdma !34_V
40696	jooma-tüübis	tüübi	jooma-tüüp	22_S	SgIn	et	jooma-tüübis =tüübi  (SgIn  >jooma-tüüp !22_S
40702	tarvitsema	tarvitse	tarvitsema	27_V	Sup	et	tarvitsema =tarvitse  (Sup  >tarvitsema !27_V
40711	nimisõnade	sõna	nimi+sõna	17_S	PlG	et	nimisõnade =sõna  (PlG  >nimi+sõna !17_S
40717	põrandavärvimine	värvimine	põranda+värvimine	12_S	SgN	et	põrandavärvimine =värvimine  (SgN  >põranda+värvimine !12_S
40720	miljoniline	miljoniline	miljoniline	12_A	SgN	et	miljoniline =miljoniline  (SgN  >miljoniline !12_A
40725	paikneda	paikne	paiknema	27_V	Inf	et	paikneda =paikne  (Inf  >paiknema !27_V
40729	selgeid	selge	selge	01_A	PlP	et	selgeid =selge  (PlP  >selge !01_A
40732	1996funktsionaalse	funktsionaalse	funktsionaalne	02_A	SgG	et	funktsionaalse =funktsionaalse  (SgG  >funktsionaalne !02_A
40735	valides	vali	valima	27_V	Ger	et	valides =vali  (Ger  >valima !27_V
40741	grandioossed	grandioosse	grandioosne	02_A	PlN	et	grandioossed =grandioosse  (PlN  >grandioosne !02_A
40744	mitteametlik	ametlik	mitte+ametlik	25_A	SgN	et	mitteametlik =ametlik  (SgN  >mitte+ametlik !25_A
40746	tüüpartikleid	artikle	tüüp+artikkel	02_S	PlP	et	tüüpartikleid =artikle  (PlP  >tüüp+artikkel !02_S
40752	numbreid	numbre	number	02_S	PlP	et	numbreid =numbre  (PlP  >number !02_S
40756	ajakirjanikkudest	kirjanikku	aja+kirjanik	25_S	PlEl	et	ajakirjanikkudest =kirjanikku  (PlEl  >aja+kirjanik !25_S
40761	poolmõisat	mõisa	pool+mõis	02_S	SgP	et	poolmõisat =mõisa  (SgP  >pool+mõis !02_S
40783	rahvaluuleteaduse	teaduse	rahva+luule+teadus	11~09_S	SgG	et	rahvaluuleteaduse =teaduse  (SgG  >rahva+luule+teadus !11~09_S
40784	laulid	lauli	laul	22_S	PlN	et	laulid =lauli  (PlN  >laul !22_S
40789	teaduslikud	teadusliku	teaduslik	25_A	PlN	et	teaduslikud =teadusliku  (PlN  >teaduslik !25_A
40790	vestlusringid	ringi	vestlus+ring	22_S	PlN	et	vestlusringid =ringi  (PlN  >vestlus+ring !22_S
40519	ost-müük	müük	ost-müük	22_S	SgN	et	ost-müük =müük  (SgN  >ost-müük !22_S
40534	õigekiri	kiri	õige+kiri	24_S	SgN	et	õigekiri =kiri  (SgN  >õige+kiri !24_S
40535	õigekirjavigu	vigu	õige+kirja+viga	18_S	PlP	et	õigekirjavigu =vigu  (PlP  >õige+kirja+viga !18_S
40537	vokaale	vokaale	vokaal	22_S	PlP	et	vokaale =vokaale  (PlP  >vokaal !22_S
40538	õigekirjavigade	viga	õige+kirja+viga	18_S	PlG	et	õigekirjavigade =viga  (PlG  >õige+kirja+viga !18_S
40541	aktsendina	aktsendi	aktsent	22_S	SgEs	et	aktsendina =aktsendi  (SgEs  >aktsent !22_S
40554	sisekohakääne	kääne	sise+koha+kääne	06_S	SgN	et	sisekohakääne =kääne  (SgN  >sise+koha+kääne !06_S
40563	käändes	käände	kääne	06_S	SgIn	et	käändes =käände  (SgIn  >kääne !06_S
40584	täismineviku	mineviku	täis+minevik	25_S	SgG	et	täismineviku =mineviku  (SgG  >täis+minevik !25_S
40592	avastame	avasta	avastama	27_V	IndPrPl1	et	avastame =avasta  (IndPrPl1  >avastama !27_V
40594	varjundiga	varjundi	varjund	02_S	SgKom	et	varjundiga =varjundi  (SgKom  >varjund !02_S
40604	loog	loog	loog	22_S	SgN	et	loog =loog  (SgN  >loog !22_S
40609	kirjandite	kirjandi	kirjand	02_S	PlG	et	kirjandite =kirjandi  (PlG  >kirjand !02_S
40610	kodutööde	töö	kodu+töö	26_S	PlG	et	kodutööde =töö  (PlG  >kodu+töö !26_S
40615	koolipoolset	poolse	kooli+poolne	02_A	SgP	et	koolipoolset =poolse  (SgP  >kooli+poolne !02_A
40619	silmatorkavaks	torkava	silma+torkav	02_A	SgTr	et	silmatorkavaks =torkava  (SgTr  >silma+torkav !02_A
40630	koormama	koorma	koormama	29_V	Sup	et	koormama =koorma  (Sup  >koormama !29_V
40631	ristküsitlema	küsitle	rist+küsitlema	27_V	Sup	et	ristküsitlema =küsitle  (Sup  >rist+küsitlema !27_V
40632	küsitlema	küsitle	küsitlema	27_V	Sup	et	küsitlema =küsitle  (Sup  >küsitlema !27_V
40634	liigun	liigu	liikuma	28_V	IndPrSg1	et	liigun =liigu  (IndPrSg1  >liikuma !28_V
40654	üksikjuhtudel	juhtu	üksik+juht	22_S	PlAd	et	üksikjuhtudel =juhtu  (PlAd  >üksik+juht !22_S
40655	rikkaliku	rikkaliku	rikkalik	25_A	SgG	et	rikkaliku =rikkaliku  (SgG  >rikkalik !25_A
40656	torude	toru	toru	17_S	PlG	et	torude =toru  (PlG  >toru !17_S
40663	pronoomeniga	pronoomeni	pronoomen	02_S	SgKom	et	pronoomeniga =pronoomeni  (SgKom  >pronoomen !02_S
40665	omamistähendus	tähendus	oma+mis+tähendus	11_S	SgN	et	omamistähendus =tähendus  (SgN  >oma+mis+tähendus !11_S
40676	köögisse	köögi	köök	22_S	SgIll	et	köögisse =köögi  (SgIll  >köök !22_S
40681	sõnatüübist	tüübi	sõna+tüüp	22_S	SgEl	et	sõnatüübist =tüübi  (SgEl  >sõna+tüüp !22_S
40682	küünla	küünla	küünal	08_S	SgG	et	küünla =küünla  (SgG  >küünal !08_S
40691	tegumood	mood	tegu+mood	22_S	SgN	et	tegumood =mood  (SgN  >tegu+mood !22_S
40692	täisminevikus	mineviku	täis+minevik	25_S	SgIn	et	täisminevikus =mineviku  (SgIn  >täis+minevik !25_S
40693	silpide	silpi	silp	22_S	PlG	et	silpide =silpi  (PlG  >silp !22_S
40694	ostetakse	oste	ostma	34_V	IndPrIps	et	ostetakse =oste  (IndPrIps  >ostma !34_V
40703	rektsioone	rektsioone	rektsioon	22_S	PlP	et	rektsioone =rektsioone  (PlP  >rektsioon !22_S
40712	kokku-	kokku	kokku	41_D	ID	et	kokku- =kokku  (ID  >kokku !41_D
40713	lahkukirjutamine	kirjutamine	lahku+kirjutamine	12_S	SgN	et	lahkukirjutamine =kirjutamine  (SgN  >lahku+kirjutamine !12_S
40714	kingsepa	sepa	king+sepp	22_S	SgG	et	kingsepa =sepa  (SgG  >king+sepp !22_S
40715	olümpiapurjespordikeskus	keskus	olümpia+purje+spordi+keskus	11~09_S	SgN	et	olümpiapurjespordikeskus =keskus  (SgN  >olümpia+purje+spordi+keskus !11~09_S
40718	vaibapuhastus	puhastus	vaiba+puhastus	11_S	SgN	et	vaibapuhastus =puhastus  (SgN  >vaiba+puhastus !11_S
40721	miljardik	miljardik	miljardik	25_N	SgN	et	miljardik =miljardik  (SgN  >miljardik !25_N
40726	meeldejäävad	jääva	meelde+jääv	02_A	PlN	et	meeldejäävad =jääva  (PlN  >meelde+jääv !02_A
40736	ootushorisont	horisont	ootus+horisont	22_S	SgN	et	ootushorisont =horisont  (SgN  >ootus+horisont !22_S
40740	tütrele	tütre	tütar	08_S	SgAll	et	tütrele =tütre  (SgAll  >tütar !08_S
40743	küljelt	külje	külg	22_S	SgAbl	et	küljelt =külje  (SgAbl  >külg !22_S
40747	haritlastele	haritlas	haritlane	12_S	PlAll	et	haritlastele =haritlas  (PlAll  >haritlane !12_S
40753	emakeelena	keele	ema+keel	13_S	SgEs	et	emakeelena =keele  (SgEs  >ema+keel !13_S
40757	kohapärimused	pärimuse	koha+pärimus	11_S	PlN	et	kohapärimused =pärimuse  (PlN  >koha+pärimus !11_S
40759	peamõisat	mõisa	pea+mõis	02_S	SgP	et	peamõisat =mõisa  (SgP  >pea+mõis !02_S
40768	aladest	ala	ala	17_S	PlEl	et	aladest =ala  (PlEl  >ala !17_S
40769	vallaga	valla	vald	22_S	SgKom	et	vallaga =valla  (SgKom  >vald !22_S
40776	ringleb	ringle	ringlema	30_V	IndPrSg3	et	ringleb =ringle  (IndPrSg3  >ringlema !30_V
40792	seltsiga	seltsi	selts	22_S	SgKom	et	seltsiga =seltsi  (SgKom  >selts !22_S
40794	veerandil	veerandi	veerand	02_NS	SgAd	et	veerandil =veerandi  (SgAd  >veerand !02_NS
40593	negatiivse	negatiivse	negatiivne	02_A	SgG	et	negatiivse =negatiivse  (SgG  >negatiivne !02_A
40595	pronoomenite	pronoomeni	pronoomen	02_S	PlG	et	pronoomenite =pronoomeni  (PlG  >pronoomen !02_S
40611	kontrolltööde	töö	kont+roll+töö	26_S	PlG	et	kontrolltööde =töö  (PlG  >kont+roll+töö !26_S
40622	põllumajandussaated	saate	põllu+majandus+saade	06_S	PlN	et	põllumajandussaated =saate  (PlN  >põllu+majandus+saade !06_S
40624	ühendtegusõnade	sõna	ühend+tegu+sõna	17_S	PlG	et	ühendtegusõnade =sõna  (PlG  >ühend+tegu+sõna !17_S
40633	liigutan	liiguta	liigutama	27_V	IndPrSg1	et	liigutan =liiguta  (IndPrSg1  >liigutama !27_V
40637	jõulud-	jõulu	jõul	22_S	PlN	et	jõulud- =jõulu  (PlN  >jõul !22_S
40638	rõugud	rõugu	rõuk	22_S	PlN	et	rõugud =rõugu  (PlN  >rõuk !22_S
40640	aetakse	ae	ajama	27_V	IndPrIps	et	aetakse =ae  (IndPrIps  >ajama !27_V
40642	sõnaliigil	liigi	sõna+liik	22_S	SgAd	et	sõnaliigil =liigi  (SgAd  >sõna+liik !22_S
40643	ühisosad	osa	ühis+osa	17_S	PlN	et	ühisosad =osa  (PlN  >ühis+osa !17_S
40645	nimisõnadega	sõna	nimi+sõna	17_S	PlKom	et	nimisõnadega =sõna  (PlKom  >nimi+sõna !17_S
40648	võrdlusastmete	astme	võrdlus+aste	05_S	PlG	et	võrdlusastmete =astme  (PlG  >võrdlus+aste !05_S
40651	tüvele	tüve	tüvi	20_S	SgAll	et	tüvele =tüve  (SgAll  >tüvi !20_S
40659	käändega	käände	kääne	06_S	SgKom	et	käändega =käände  (SgKom  >kääne !06_S
40664	väliskohakäänetes	kääne	välis+koha+kääne	06_S	PlIn	et	väliskohakäänetes =kääne  (PlIn  >välis+koha+kääne !06_S
40667	lõunaeestilist	eestilis	lõuna+eestiline	12_A	SgP	et	lõunaeestilist =eestilis  (SgP  >lõuna+eestiline !12_A
40673	vahetatakse	vaheta	vahetama	27_V	IndPrIps	et	vahetatakse =vaheta  (IndPrIps  >vahetama !27_V
40674	küsisõnaga	sõna	küsi+sõna	17_S	SgKom	et	küsisõnaga =sõna  (SgKom  >küsi+sõna !17_S
40679	pessa	pessa	pesa	17_S	SgAdt	et	pessa =pessa  (SgAdt  >pesa !17_S
40687	teeksime	tee	tegema	28_V	KndPrPl1	et	teeksime =tee  (KndPrPl1  >tegema !28_V
40688	puhkaksime	puhka	puhkama	29_V	KndPrPl1	et	puhkaksime =puhka  (KndPrPl1  >puhkama !29_V
40701	tarvitseda	tarvitse	tarvitsema	27_V	Inf	et	tarvitseda =tarvitse  (Inf  >tarvitsema !27_V
40706	kahetsema	kahetse	kahetsema	27_V	Sup	et	kahetsema =kahetse  (Sup  >kahetsema !27_V
40709	baseeruma	baseeru	baseeruma	27_V	Sup	et	baseeruma =baseeru  (Sup  >baseeruma !27_V
40716	purjespordikeskus	keskus	purje+spordi+keskus	11~09_S	SgN	et	purjespordikeskus =keskus  (SgN  >purje+spordi+keskus !11~09_S
40723	põhjustada	põhjusta	põhjustama	27_V	Inf	et	põhjustada =põhjusta  (Inf  >põhjustama !27_V
40727	üldkehtivat	kehtiva	üld+kehtiv	02_A	SgP	et	üldkehtivat =kehtiva  (SgP  >üld+kehtiv !02_A
40728	keelevigu	vigu	keele+viga	18_S	PlP	et	keelevigu =vigu  (PlP  >keele+viga !18_S
40734	asjaks	asja	asi	24_S	SgTr	et	asjaks =asja  (SgTr  >asi !24_S
40750	tükk	tükk	tükk	22_S	SgN	et	tükk =tükk  (SgN  >tükk !22_S
40751	tsitaate	tsitaate	tsitaat	22_S	PlP	et	tsitaate =tsitaate  (PlP  >tsitaat !22_S
40754	trükkiveo-	veo	trükki+vedu	18_S	SgG	et	trükkiveo- =veo  (SgG  >trükki+vedu !18_S
40755	eraldaks	eralda	eraldama	27_V	KndPrPs	et	eraldaks =eralda  (KndPrPs  >eraldama !27_V
40758	kirikumõis	mõis	kiriku+mõis	02_S	SgN	et	kirikumõis =mõis  (SgN  >kiriku+mõis !02_S
40762	karjamõisat	mõisa	karja+mõis	02_S	SgP	et	karjamõisat =mõisa  (SgP  >karja+mõis !02_S
40772	kujutelmades	kujutelma	kujutelm	22_S	PlIn	et	kujutelmades =kujutelma  (PlIn  >kujutelm !22_S
40773	allikaks	allika	allikas	02_S	SgTr	et	allikaks =allika  (SgTr  >allikas !02_S
40774	elunähtused	nähtuse	elu+nähtus	11~09_S	PlN	et	elunähtused =nähtuse  (PlN  >elu+nähtus !11~09_S
40778	varieeritakse	varieeri	varieerima	28_V	IndPrIps	et	varieeritakse =varieeri  (IndPrIps  >varieerima !28_V
40779	arenemisfaasid	faasi	arenemis+faas	22_S	PlN	et	arenemisfaasid =faasi  (PlN  >arenemis+faas !22_S
40781	kollektiivne	kollektiivne	kollektiivne	02_A	SgN	et	kollektiivne =kollektiivne  (SgN  >kollektiivne !02_A
40785	mängude	mängu	mäng	22_S	PlG	et	mängude =mängu  (PlG  >mäng !22_S
40787	rahvapillidega	pilli	rahva+pill	22_S	PlKom	et	rahvapillidega =pilli  (PlKom  >rahva+pill !22_S
40797	hurda1839-1907	hurda	hurt	22_S	SgG	et	hurda- =hurda  (SgG  >hurt !22_S
40802	postimehe	mehe	posti+mees	13_S	SgG	et	postimehe =mehe  (SgG  >posti+mees !13_S
40804	ulatuslikud	ulatusliku	ulatuslik	25_A	PlN	et	ulatuslikud =ulatusliku  (PlN  >ulatuslik !25_A
40816	printsiibi	printsiibi	printsiip	22_S	SgG	et	printsiibi =printsiibi  (SgG  >printsiip !22_S
40825	õlgadel	õlga	õlg	22_S	PlAd	et	õlgadel =õlga  (PlAd  >õlg !22_S
40832	1907aastal	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
40840	1936aastal	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
40841	avaldama	avalda	avaldama	27_V	Sup	et	avaldama =avalda  (Sup  >avaldama !27_V
40842	küsitluskavu	kavu	küsitlus+kava	17_S	PlP	et	küsitluskavu =kavu  (PlP  >küsitlus+kava !17_S
40599	muinasjutul	jutu	muinas+jutt	22_S	SgAd	et	muinasjutul =jutu  (SgAd  >muinas+jutt !22_S
40602	põhjustab	põhjusta	põhjustama	27_V	IndPrSg3	et	põhjustab =põhjusta  (IndPrSg3  >põhjustama !27_V
40605	süstemaatilist	süstemaatilis	süstemaatiline	12_A	SgP	et	süstemaatilist =süstemaatilis  (SgP  >süstemaatiline !12_A
40607	hõlpsasti	hõlpsasti	hõlpsasti	41_D	ID	et	hõlpsasti =hõlpsasti  (ID  >hõlpsasti !41_D
40612	kesktasemega	taseme	kesk+tase	04_S	SgKom	et	kesktasemega =taseme  (SgKom  >kesk+tase !04_S
40613	püüdsingi	püüd	püüdma	34_V	IndIpfSg1^	et	püüdsingi =püüd  (IndIpfSg1^  >püüdma !34_V
40616	märkab	märka	märkama	29_V	IndPrSg3	et	märkab =märka  (IndPrSg3  >märkama !29_V
40621	keeletasandid	tasandi	keele+tasand	02_S	PlN	et	keeletasandid =tasandi  (PlN  >keele+tasand !02_S
40623	liit-	liit	liit	22_S	SgN	et	liit- =liit  (SgN  >liit !22_S
40629	alakoormama	koorma	ala+koormama	29_V	Sup	et	alakoormama =koorma  (Sup  >ala+koormama !29_V
40639	tangud	tangu	tang	22_S	PlN	et	tangud =tangu  (PlN  >tang !22_S
40646	jooksen	jookse	jooksma	32_V	IndPrSg1	et	jooksen =jookse  (IndPrSg1  >jooksma !32_V
40647	sisenege-ohtlik	ohtlik	sisenege-ohtlik	25_A	SgN	et	sisenege-ohtlik =ohtlik  (SgN  >sisenege-ohtlik !25_A
40650	algvõrde	võrde	alg+võrre	06_S	SgG	et	algvõrde =võrde  (SgG  >alg+võrre !06_S
40652	ülivõrde	võrde	üli+võrre	06_S	SgG	et	ülivõrde =võrde  (SgG  >üli+võrre !06_S
40666	paljaks	palja	paljas	07_A	SgTr	et	paljaks =palja  (SgTr  >paljas !07_A
40675	noortesaadetes	saade	noorte+saade	06_S	PlIn	et	noortesaadetes =saade  (PlIn  >noorte+saade !06_S
40684	koerasid	koera	koer	23?22_SA	PlP	et	koerasid =koera  (PlP  >koer !23?22_SA
40700	ülesannetest	anne	üles+anne	06_S	PlEl	et	ülesannetest =anne  (PlEl  >üles+anne !06_S
40704	reeglitele	reegli	reegel	02_S	PlAll	et	reeglitele =reegli  (PlAll  >reegel !02_S
40705	häirima	häiri	häirima	28_V	Sup	et	häirima =häiri  (Sup  >häirima !28_V
40707	sarnanema	sarnane	sarnanema	27_V	Sup	et	sarnanema =sarnane  (Sup  >sarnanema !27_V
40710	õigekirjas	kirja	õige+kiri	24_S	SgIn	et	õigekirjas =kirja  (SgIn  >õige+kiri !24_S
40719	kolmemiljoniline	miljoniline	kolme+miljoniline	12_A	SgN	et	kolmemiljoniline =miljoniline  (SgN  >kolme+miljoniline !12_A
40722	süntaks	süntaks	süntaks	02_S	SgN	et	süntaks =süntaks  (SgN  >süntaks !02_S
40731	eksperimenteerida	eksperimenteeri	eksperimenteerima	28_V	Inf	et	eksperimenteerida =eksperimenteeri  (Inf  >eksperimenteerima !28_V
40748	võõrsõnu	sõnu	võõr+sõna	17_S	PlP	et	võõrsõnu =sõnu  (PlP  >võõr+sõna !17_S
40763	munalaskme	laskme	muna+lase	05_S	SgG	et	munalaskme =laskme  (SgG  >muna+lase !05_S
40765	rüütlimõis	mõis	rüütli+mõis	02_S	SgN	et	rüütlimõis =mõis  (SgN  >rüütli+mõis !02_S
40775	omasugune	sugune	oma+sugune	10_A	SgN	et	omasugune =sugune  (SgN  >oma+sugune !10_A
40780	keskkonnaga	keskkonna	keskkond	22_S	SgKom	et	keskkonnaga =keskkonna  (SgKom  >keskkond !22_S
40786	mõnevõrra	mõnevõrra	mõne+võrra	41_D	ID	et	mõnevõrra =mõnevõrra  (ID  >mõne+võrra !41_D
40788	laugaste	laugas	laugas	07_S	PlG	et	laugaste =laugas  (PlG  >laugas !07_S
40799	tõmmates	tõmma	tõmbama	29_V	Ger	et	tõmmates =tõmma  (Ger  >tõmbama !29_V
40809	rahvaluuleliigid	liigi	rahva+luule+liik	22_S	PlN	et	rahvaluuleliigid =liigi  (PlN  >rahva+luule+liik !22_S
40810	1875aastal	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
40812	seltsile	seltsi	selts	22_S	SgAll	et	seltsile =seltsi  (SgAll  >selts !22_S
40814	rahvaviisid	viisi	rahva+viis	22_S	PlN	et	rahvaviisid =viisi  (PlN  >rahva+viis !22_S
40817	hurdaga	hurda	hurt	22_S	SgKom	et	hurdaga =hurda  (SgKom  >hurt !22_S
40820	uurimused	uurimuse	uurimus	11_S	PlN	et	uurimused =uurimuse  (PlN  >uurimus !11_S
40822	eriettevalmistusega	valmistuse	eri+ette+valmistus	11_S	SgKom	et	eriettevalmistusega =valmistuse  (SgKom  >eri+ette+valmistus !11_S
40823	rahvaluuleteadlaseks	teadlase	rahva+luule+teadlane	12?10_S	SgTr	et	rahvaluuleteadlaseks =teadlase  (SgTr  >rahva+luule+teadlane !12?10_S
40824	teadusseltside	seltsi	teadus+selts	22_S	PlG	et	teadusseltside =seltsi  (PlG  >teadus+selts !22_S
40826	kogumistööst	töö	kogu+mis+töö	26_S	SgEl	et	kogumistööst =töö  (SgEl  >kogu+mis+töö !26_S
40844	juubeli-	juubeli	juubel	02_S	SgG	et	juubeli- =juubeli  (SgG  >juubel !02_S
40849	19311932õppeaastal	aasta	õppe+aasta	01_S	SgAd	et	õppeaastal =aasta  (SgAd  >õppe+aasta !01_S
40858	ergutada	erguta	ergutama	27_V	Inf	et	ergutada =erguta  (Inf  >ergutama !27_V
40861	ülemärkimine	märkimine	üle+märkimine	12_S	SgN	et	ülemärkimine =märkimine  (SgN  >üle+märkimine !12_S
40864	rahvaluulekogujaile	koguja	rahva+luule+koguja	01_S	PlAll	et	rahvaluulekogujaile =koguja  (PlAll  >rahva+luule+koguja !01_S
40866	küljele	külje	külg	22_S	SgAll	et	küljele =külje  (SgAll  >külg !22_S
40867	rahvaluule-tekstide	teksti	rahvaluule-tekst	22_S	PlG	et	rahvaluule-tekstide =teksti  (PlG  >rahvaluule-tekst !22_S
40698	tuuakse	tuu	tooma	38_V	IndPrIps	et	tuuakse =tuu  (IndPrIps  >tooma !38_V
40699	ma-ja	ja	ma-ja	41_J	ID	et	ma-ja =ja  (ID  >ma-ja !41_J
40708	muganema	mugane	muganema	27_V	Sup	et	muganema =mugane  (Sup  >muganema !27_V
40724	viisimäärus	määrus	viisi+määrus	11~09_S	SgN	et	viisimäärus =määrus  (SgN  >viisi+määrus !11~09_S
40730	paindlik	paindlik	paindlik	25_A	SgN	et	paindlik =paindlik  (SgN  >paindlik !25_A
40733	sirvides	sirvi	sirvima	28_V	Ger	et	sirvides =sirvi  (Ger  >sirvima !28_V
40737	järgneda	järgne	järgnema	27_V	Inf	et	järgneda =järgne  (Inf  >järgnema !27_V
40738	meelitada	meelita	meelitama	27_V	Inf	et	meelitada =meelita  (Inf  >meelitama !27_V
40739	korraldades	korralda	korraldama	27_V	Ger	et	korraldades =korralda  (Ger  >korraldama !27_V
40742	kitsendab	kitsenda	kitsendama	27_V	IndPrSg3	et	kitsendab =kitsenda  (IndPrSg3  >kitsendama !27_V
40745	ajakirjadest	kirja	aja+kiri	24_S	PlEl	et	ajakirjadest =kirja  (PlEl  >aja+kiri !24_S
40749	adressaadile	adressaadi	adressaat	22_S	SgAll	et	adressaadile =adressaadi  (SgAll  >adressaat !22_S
40760	kõrvalmõisaga	mõisa	kõrval+mõis	02_S	SgKom	et	kõrvalmõisaga =mõisa  (SgKom  >kõrval+mõis !02_S
40764	kõrvalmõis	mõis	kõrval+mõis	02_S	SgN	et	kõrvalmõis =mõis  (SgN  >kõrval+mõis !02_S
40766	poolmõis	mõis	pool+mõis	02_S	SgN	et	poolmõis =mõis  (SgN  >pool+mõis !02_S
40767	vardi	vardi	vart	22_S	SgG	et	vardi =vardi  (SgG  >vart !22_S
40770	mõisatega	mõisa	mõis	02_S	PlKom	et	mõisatega =mõisa  (PlKom  >mõis !02_S
40771	üldist	üldis	üldine	10~12_A	SgP	et	üldist =üldis  (SgP  >üldine !10~12_A
40777	inimgruppides	gruppi	inim+grupp	22_S	PlIn	et	inimgruppides =gruppi  (PlIn  >inim+grupp !22_S
40782	kunstilooming	looming	kunsti+looming	02_S	SgN	et	kunstilooming =looming  (SgN  >kunsti+looming !02_S
40791	inspektor	inspektor	inspektor	02_S	SgN	et	inspektor =inspektor  (SgN  >inspektor !02_S
40795	talurahvani	rahva	talu+rahvas	07_S	SgTer	et	talurahvani =rahva  (SgTer  >talu+rahvas !07_S
40801	kodu-uurimuslik	uurimuslik	kodu-uurimuslik	25_A	SgN	et	kodu-uurimuslik =uurimuslik  (SgN  >kodu-uurimuslik !25_A
40803	lisalehe	lehe	lisa+leht	22_S	SgG	et	lisalehe =lehe  (SgG  >lisa+leht !22_S
40806	üleskutsetes	kutse	üles+kutse	06_S	PlIn	et	üleskutsetes =kutse  (PlIn  >üles+kutse !06_S
40811	poegadele	poega	poeg	22_S	PlAll	et	poegadele =poega  (PlAll  >poeg !22_S
40818	publitseeris	publitseeri	publitseerima	28_V	IndIpfSg3	et	publitseeris =publitseeri  (IndIpfSg3  >publitseerima !28_V
40831	teaduslikkudesse	teaduslikku	teaduslik	25_A	PlIll	et	teaduslikkudesse =teaduslikku  (PlIll  >teaduslik !25_A
40834	omandina	omandi	omand	02_S	SgEs	et	omandina =omandi  (SgEs  >omand !02_S
40847	jõuti	jõu	jõudma	34_V	IndIpfIps	et	jõuti =jõu  (IndIpfIps  >jõudma !34_V
40850	ringküsitlus	küsitlus	ring+küsitlus	11_S	SgN	et	ringküsitlus =küsitlus  (SgN  >ring+küsitlus !11_S
40851	korrespondentidele	korrespondenti	korrespondent	22_S	PlAll	et	korrespondentidele =korrespondenti  (PlAll  >korrespondent !22_S
40852	maa-algkoolidele	kooli	maa-alg+kool	22_S	PlAll	et	maa-algkoolidele =kooli  (PlAll  >maa-alg+kool !22_S
40857	kogumisvõistluse	võistluse	kogu+mis+võistlus	11~09_S	SgG	et	kogumisvõistluse =võistluse  (SgG  >kogu+mis+võistlus !11~09_S
40862	1940aastal	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
40863	tööjuhiseid	juhise	töö+juhis	09_S	PlP	et	tööjuhiseid =juhise  (PlP  >töö+juhis !09_S
40870	kohalugusid	lugu	koha+lugu	18_S	PlP	et	kohalugusid =lugu  (PlP  >koha+lugu !18_S
40874	lühidas	lühida	lühida	02_A	SgIn	et	lühidas =lühida  (SgIn  >lühida !02_A
40886	veekogud	kogu	vee+kogu	17_S	PlN	et	veekogud =kogu  (PlN  >vee+kogu !17_S
40891	aruandes	ande	aru+anne	06_S	SgIn	et	aruandes =ande  (SgIn  >aru+anne !06_S
40892	kogumisaktsioon	aktsioon	kogu+mis+aktsioon	22_S	SgN	et	kogumisaktsioon =aktsioon  (SgN  >kogu+mis+aktsioon !22_S
40893	võistlustöödes	töö	võistlus+töö	26_S	PlIn	et	võistlustöödes =töö  (PlIn  >võistlus+töö !26_S
40895	ohvrikohtadest	kohta	ohvri+koht	22_S	PlEl	et	ohvrikohtadest =kohta  (PlEl  >ohvri+koht !22_S
40897	ekspeditsioonis	ekspeditsiooni	ekspeditsioon	22_S	SgIn	et	ekspeditsioonis =ekspeditsiooni  (SgIn  >ekspeditsioon !22_S
40899	muistend	muistend	muistend	02_S	SgN	et	muistend =muistend  (SgN  >muistend !02_S
40905	rändrahnud	rahnu	ränd+rahn	22_S	PlN	et	rändrahnud =rahnu  (PlN  >ränd+rahn !22_S
40908	muistendit	muistendi	muistend	02_S	SgP	et	muistendit =muistendi  (SgP  >muistend !02_S
40909	lapidaarne	lapidaarne	lapidaarne	02_A	SgN	et	lapidaarne =lapidaarne  (SgN  >lapidaarne !02_A
40912	eepilise	eepilise	eepiline	12_A	SgG	et	eepilise =eepilise  (SgG  >eepiline !12_A
40915	tõsiasi	asi	tõsi+asi	24_S	SgN	et	tõsiasi =asi  (SgN  >tõsi+asi !24_S
40918	saabki	saa	saama	37_V	IndPrSg3^	et	saabki =saa  (IndPrSg3^  >saama !37_V
40925	katkumuistendid	muistendi	katku+muistend	02_S	PlN	et	katkumuistendid =muistendi  (PlN  >katku+muistend !02_S
40793	kirjanduslik	kirjanduslik	kirjanduslik	25_A	SgN	et	kirjanduslik =kirjanduslik  (SgN  >kirjanduslik !25_A
40796	pastor	pastor	pastor	02_S	SgN	et	pastor =pastor  (SgN  >pastor !02_S
40800	hurda	hurda	hurt	22_S	SgG	et	hurda =hurda  (SgG  >hurt !22_S
40805	üleskutsed	kutse	üles+kutse	06_S	PlN	et	üleskutsed =kutse  (PlN  >üles+kutse !06_S
40807	artiklites	artikli	artikkel	02_S	PlIn	et	artiklites =artikli  (PlIn  >artikkel !02_S
40813	kavatses	kavatse	kavatsema	27_V	IndIpfSg3	et	kavatses =kavatse  (IndIpfSg3  >kavatsema !27_V
40815	trükise	trükise	trükis	09_S	SgG	et	trükise =trükise  (SgG  >trükis !09_S
40821	tedre	tedre	teder	24_S	SgG	et	tedre =tedre  (SgG  >teder !24_S
40829	organiseeris	organiseeri	organiseerima	28_V	IndIpfSg3	et	organiseeris =organiseeri  (IndIpfSg3  >organiseerima !28_V
40835	järelkorjandusel	korjanduse	järel+korjandus	11_S	SgAd	et	järelkorjandusel =korjanduse  (SgAd  >järel+korjandus !11_S
40837	kihelkondadele	kihelkonda	kihelkond	22_S	PlAll	et	kihelkondadele =kihelkonda  (PlAll  >kihelkond !22_S
40845	mälestuskirjutisi	kirjutisi	mälestus+kirjutis	11_S	PlP	et	mälestuskirjutisi =kirjutisi  (PlP  >mälestus+kirjutis !11_S
40853	lastehirmutised	hirmutise	laste+hirmutis	11_S	PlN	et	lastehirmutised =hirmutise  (PlN  >laste+hirmutis !11_S
40854	aktsiooniks	aktsiooni	aktsioon	22_S	SgTr	et	aktsiooniks =aktsiooni  (SgTr  >aktsioon !22_S
40855	19381939õppeaastal	aasta	õppe+aasta	01_S	SgAd	et	õppeaastal =aasta  (SgAd  >õppe+aasta !01_S
40856	kohamuistendite	muistendi	koha+muistend	02_S	PlG	et	kohamuistendite =muistendi  (PlG  >koha+muistend !02_S
40859	tundmaõppimisel	õppimise	tundma+õppimine	12_S	SgAd	et	tundmaõppimisel =õppimise  (SgAd  >tundma+õppimine !12_S
40875	lahingukoht	koht	lahingu+koht	22_S	SgN	et	lahingukoht =koht  (SgN  >lahingu+koht !22_S
40876	kohamuistenditele	muistendi	koha+muistend	02_S	PlAll	et	kohamuistenditele =muistendi  (PlAll  >koha+muistend !02_S
40880	küsitluslehed	lehe	küsitlus+leht	22_S	PlN	et	küsitluslehed =lehe  (PlN  >küsitlus+leht !22_S
40882	rahvajuttudest	juttu	rahva+jutt	22_S	PlEl	et	rahvajuttudest =juttu  (PlEl  >rahva+jutt !22_S
40884	kivid	kivi	kivi	17_S	PlN	et	kivid =kivi  (PlN  >kivi !17_S
40885	orud	oru	org	22_S	PlN	et	orud =oru  (PlN  >org !22_S
40894	paikadest	paika	paik	22_S	PlEl	et	paikadest =paika  (PlEl  >paik !22_S
40896	põldmäe	mäe	põld+mägi	21_S	SgG	et	põldmäe =mäe  (SgG  >põld+mägi !21_S
40902	primitiivse	primitiivse	primitiivne	02_A	SgG	et	primitiivse =primitiivse  (SgG  >primitiivne !02_A
40906	sündmustik	sündmustik	sündmustik	25_S	SgN	et	sündmustik =sündmustik  (SgN  >sündmustik !25_S
40907	tegelasega	tegelase	tegelane	12_S	SgKom	et	tegelasega =tegelase  (SgKom  >tegelane !12_S
40919	seletusmuistendid	muistendi	seletus+muistend	02_S	PlN	et	seletusmuistendid =muistendi  (PlN  >seletus+muistend !02_S
40927	kohanimede	nime	koha+nimi	20_S	PlG	et	kohanimede =nime  (PlG  >koha+nimi !20_S
40928	teket	teke	teke	06_S	SgP	et	teket =teke  (SgP  >teke !06_S
40929	nimede	nime	nimi	20_S	PlG	et	nimede =nime  (PlG  >nimi !20_S
40936	kalmetega	kalme	kalme	06_S	PlKom	et	kalmetega =kalme  (PlKom  >kalme !06_S
40939	jaam	jaam	jaam	22_S	SgN	et	jaam =jaam  (SgN  >jaam !22_S
40945	hiie	hiie	hiis	14_S	SgG	et	hiie =hiie  (SgG  >hiis !14_S
40946	maalinnuse	linnuse	maa+linnus	09_S	SgG	et	maalinnuse =linnuse  (SgG  >maa+linnus !09_S
40950	tanner	tanner	tanner	03_S	SgN	et	tanner =tanner  (SgN  >tanner !03_S
40953	mõisaase	ase	mõisa+ase	04_S	SgN	et	mõisaase =ase  (SgN  >mõisa+ase !04_S
40962	vaod	vao	vagu	18_S	PlN	et	vaod =vao  (PlN  >vagu !18_S
40968	tütardest	tütar	tütar	08_S	PlEl	et	tütardest =tütar  (PlEl  >tütar !08_S
40972	s1942a	sa	sa	00_P	SgN	et	sa =sa  (SgN  >sa !00_P
40977	kõmises	kõmise	kõmisema	27_V	IndIpfSg3	et	kõmises =kõmise  (IndIpfSg3  >kõmisema !27_V
40982	pand	pand	pand	22_S	SgN	et	pand =pand  (SgN  >pand !22_S
40986	iketega	ike	ike	06_S	PlKom	et	iketega =ike  (PlKom  >ike !06_S
40987	nahas	naha	nahk	22_S	SgIn	et	nahas =naha  (SgIn  >nahk !22_S
40992	põllud	põllu	põld	22_S	PlN	et	põllud =põllu  (PlN  >põld !22_S
40997	kõrsi	kõrs	kõrs	14_S	PlP	et	kõrsi =kõrs  (PlP  >kõrs !14_S
41007	surnuluid	lu	surnu+luu	26_S	PlP	et	surnuluid =lu  (PlP  >surnu+luu !26_S
41010	katkuhaldjat	haldja	katku+haldjas	02_S	SgP	et	katkuhaldjat =haldja  (SgP  >katku+haldjas !02_S
41012	poisina	poisi	poiss	23?22_S	SgEs	et	poisina =poisi  (SgEs  >poiss !23?22_S
41021	soolavett	ve	soola+vesi	15_S	SgP	et	soolavett =ve  (SgP  >soola+vesi !15_S
41023	naljandites	naljandi	naljand	02_S	PlIn	et	naljandites =naljandi  (PlIn  >naljand !02_S
41026	pulbrit	pulbri	pulber	02_S	SgP	et	pulbrit =pulbri  (SgP  >pulber !02_S
41031	lihasoolvett	ve	liha+sool+vesi	15_S	SgP	et	lihasoolvett =ve  (SgP  >liha+sool+vesi !15_S
40798	kodukihelkonnas	kihelkonna	kodu+kihelkond	22_S	SgIn	et	kodukihelkonnas =kihelkonna  (SgIn  >kodu+kihelkond !22_S
40808	fikseerib	fikseeri	fikseerima	28_V	IndPrSg3	et	fikseerib =fikseeri  (IndPrSg3  >fikseerima !28_V
40819	tõsiteaduslikud	teadusliku	tõsi+teaduslik	25_A	PlN	et	tõsiteaduslikud =teadusliku  (PlN  >tõsi+teaduslik !25_A
40827	korrespondentide	korrespondenti	korrespondent	22_S	PlG	et	korrespondentide =korrespondenti  (PlG  >korrespondent !22_S
40828	hankis	hanki	hankima	28_V	IndIpfSg3	et	hankis =hanki  (IndIpfSg3  >hankima !28_V
40830	stipendiaatide	stipendiaati	stipendiaat	22_S	PlG	et	stipendiaatide =stipendiaati  (PlG  >stipendiaat !22_S
40833	kopeeriti	kopeeri	kopeerima	28_V	IndIpfIps	et	kopeeriti =kopeeri  (IndIpfIps  >kopeerima !28_V
40836	keskenduti	keskendu	keskenduma	27_V	IndIpfIps	et	keskenduti =keskendu  (IndIpfIps  >keskenduma !27_V
40838	nappis	nappi	nappima	28_V	IndIpfSg3	et	nappis =nappi  (IndIpfSg3  >nappima !28_V
40839	kaastöölised	töölise	kaas+tööline	12?10_S	PlN	et	kaastöölised =töölise  (PlN  >kaas+tööline !12?10_S
40846	kogumiskanalitesse	kanali	kogu+mis+kanal	02_S	PlIll	et	kogumiskanalitesse =kanali  (PlIll  >kogu+mis+kanal !02_S
40848	proovikiviks	kivi	proovi+kivi	17_S	SgTr	et	proovikiviks =kivi  (SgTr  >proovi+kivi !17_S
40860	kohtadega	kohta	koht	22_S	PlKom	et	kohtadega =kohta  (PlKom  >koht !22_S
40887	nälja	nälja	nälg	22_S	SgG	et	nälja =nälja  (SgG  >nälg !22_S
40903	olendi	olendi	olend	02_S	SgG	et	olendi =olendi  (SgG  >olend !02_S
40904	olemasoleva	oleva	olemas+olev	02_A	SgG	et	olemasoleva =oleva  (SgG  >olemas+olev !02_A
40916	pealtvaatajana	vaataja	pealt+vaataja	01_S	SgEs	et	pealtvaatajana =vaataja  (SgEs  >pealt+vaataja !01_S
40921	kohamuistendid	muistendi	koha+muistend	02_S	PlN	et	kohamuistendid =muistendi  (PlN  >koha+muistend !02_S
40923	kindlad	kindla	kindel	02_A	PlN	et	kindlad =kindla  (PlN  >kindel !02_A
40926	ehitistega	ehitis	ehitis	11_S	PlKom	et	ehitistega =ehitis  (PlKom  >ehitis !11_S
40935	matmispaikadega	paika	matmis+paik	22_S	PlKom	et	matmispaikadega =paika  (PlKom  >matmis+paik !22_S
40943	maidla	maidla	maidel	02_S	SgG	et	maidla =maidla  (SgG  >maidel !02_S
40949	saapa	saapa	saabas	07_S	SgG	et	saapa =saapa  (SgG  >saabas !07_S
40951	osmik	osmik	osmik	02_S	SgN	et	osmik =osmik  (SgN  >osmik !02_S
40957	kuller	kuller	kuller	02_S	SgN	et	kuller =kuller  (SgN  >kuller !02_S
40959	tülisse	tüli	tüli	17_S	SgIll	et	tülisse =tüli  (SgIll  >tüli !17_S
40978	mõisakoht	koht	mõisa+koht	22_S	SgN	et	mõisakoht =koht  (SgN  >mõisa+koht !22_S
40983	kolinat	kolina	kolin	02_S	SgP	et	kolinat =kolina  (SgP  >kolin !02_S
40990	niisi	niis	niis	14_S	PlP	et	niisi =niis  (PlP  >niis !14_S
40991	jaanilinn	linn	jaani+linn	22_S	SgN	et	jaanilinn =linn  (SgN  >jaani+linn !22_S
40995	vaenlasele	vaenlase	vaenlane	12?10_S	SgAll	et	vaenlasele =vaenlase  (SgAll  >vaenlane !12?10_S
40996	juure	juure	juur	13_S	SgG	et	juure =juure  (SgG  >juur !13_S
40999	jäämann	mann	jää+mann	22_S	SgN	et	jäämann =mann  (SgN  >jää+mann !22_S
41005	kubuna	kubu	kubu	17_S	SgEs	et	kubuna =kubu  (SgEs  >kubu !17_S
41008	luukerele	kere	luu+kere	16_S	SgAll	et	luukerele =kere  (SgAll  >luu+kere !16_S
41015	kepiga	kepi	kepp	22_S	SgKom	et	kepiga =kepi  (SgKom  >kepp !22_S
41016	ärkvel	ärkvel	ärkvel	41_DA	ID	et	ärkvel =ärkvel  (ID  >ärkvel !41_DA
41030	kõhutõbe	tõbe	kõhu+tõbi	21_S	SgP	et	kõhutõbe =tõbe  (SgP  >kõhu+tõbi !21_S
41032	umberg	erg	umb+erg	22_S	SgN	et	umberg =erg  (SgN  >umb+erg !22_S
41038	suure-jaagu	jaagu	suure-jaak	22_S	SgG	et	suure-jaagu =jaagu  (SgG  >suure-jaak !22_S
41040	istumas	istu	istuma	28_V	SupIn	et	istumas =istu  (SupIn  >istuma !28_V
41044	tuules	tuule	tuul	13_S	SgIn	et	tuules =tuule  (SgIn  >tuul !13_S
41054	haigestub	haigestu	haigestuma	27_V	IndPrSg3	et	haigestub =haigestu  (IndPrSg3  >haigestuma !27_V
41060	sedamoodi	sedamoodi	seda+moodi	41_D	ID	et	sedamoodi =sedamoodi  (ID  >seda+moodi !41_D
41061	aiged-suremas	sure	aiged-surema	36_V	SupIn	et	aiged-suremas =sure  (SupIn  >aiged-surema !36_V
41063	visand	visand	visand	02_S	SgN	et	visand =visand  (SgN  >visand !02_S
41078	trahter	trahter	trahter	02_S	SgN	et	trahter =trahter  (SgN  >trahter !02_S
41089	aisadest	aisa	ais	22_S	PlEl	et	aisadest =aisa  (PlEl  >ais !22_S
41091	kottu	kottu	kottu	41_D	ID	et	kottu =kottu  (ID  >kottu !41_D
41095	vanajutt	jutt	vana+jutt	22_S	SgN	et	vanajutt =jutt  (SgN  >vana+jutt !22_S
41097	iial	iial	iial	41_D	ID	et	iial =iial  (ID  >iial !41_D
41100	tõld	tõld	tõld	22_S	SgN	et	tõld =tõld  (SgN  >tõld !22_S
41102	jungile	jungi	jung	22_S	PlAll	et	jungile =jungi  (PlAll  >jung !22_S
41105	katkujärgsed	järgse	katku+järgne	02_A	PlN	et	katkujärgsed =järgse  (PlN  >katku+järgne !02_A
41108	suur-jaak	jaak	suur-jaak	22_S	SgN	et	suur-jaak =jaak  (SgN  >suur-jaak !22_S
40843	ülevaateid	vaate	üle+vaade	06_S	PlP	et	ülevaateid =vaate  (PlP  >üle+vaade !06_S
40865	pöörab	pööra	pöörama	29_V	IndPrSg3	et	pöörab =pööra  (IndPrSg3  >pöörama !29_V
40868	üleskirjutistes	kirjutis	üles+kirjutis	11_S	PlIn	et	üleskirjutistes =kirjutis  (PlIn  >üles+kirjutis !11_S
40869	materjalis	materjali	materjal	19_S	SgIn	et	materjalis =materjali  (SgIn  >materjal !19_S
40871	kirjapanijale	panija	kirja+panija	01_S	SgAll	et	kirjapanijale =panija  (SgAll  >kirja+panija !01_S
40872	senises	senise	senine	10_A	SgIn	et	senises =senise  (SgIn  >senine !10_A
40873	üleskirjutistest	kirjutis	üles+kirjutis	11_S	PlEl	et	üleskirjutistest =kirjutis  (PlEl  >üles+kirjutis !11_S
40878	kogumisaktsioonideks	aktsiooni	kogu+mis+aktsioon	22_S	PlTr	et	kogumisaktsioonideks =aktsiooni  (PlTr  >kogu+mis+aktsioon !22_S
40881	kaaskirjad-juhendid	juhendi	kaaskirjad-juhend	02_S	PlN	et	kaaskirjad-juhendid =juhendi  (PlN  >kaaskirjad-juhend !02_S
40883	teemadena	teema	teema	16_S	PlEs	et	teemadena =teema  (PlEs  >teema !16_S
40888	tänutäheks	tähe	tänu+täht	22_S	SgTr	et	tänutäheks =tähe  (SgTr  >tänu+täht !22_S
40889	kihelkondadest	kihelkonda	kihelkond	22_S	PlEl	et	kihelkondadest =kihelkonda  (PlEl  >kihelkond !22_S
40898	muistend	muistend	muistend	02_S	SgN	et	muistend =muistend  (SgN  >muistend !02_S
40900	muinasjutust	jutu	muinas+jutt	22_S	SgEl	et	muinasjutust =jutu  (SgEl  >muinas+jutt !22_S
40901	muistendis	muistendi	muistend	02_S	SgIn	et	muistendis =muistendi  (SgIn  >muistend !02_S
40913	üksikpilte	pilte	üksik+pilt	22_S	PlP	et	üksikpilte =pilte  (PlP  >üksik+pilt !22_S
40914	mittekaheldav	kaheldav	mitte+kaheldav	02_A	SgN	et	mittekaheldav =kaheldav  (SgN  >mitte+kaheldav !02_A
40922	liikide	liiki	liik	22_S	PlG	et	liikide =liiki  (PlG  >liik !22_S
40940	veeti	vee	vedama	28_V	IndIpfIps	et	veeti =vee  (IndIpfIps  >vedama !28_V
40942	pätse	pätse	päts	22_S	PlP	et	pätse =pätse  (PlP  >päts !22_S
40944	sarv	sarv	sarv	22_S	SgN	et	sarv =sarv  (SgN  >sarv !22_S
40947	mall	mall	mall	22_S	SgN	et	mall =mall  (SgN  >mall !22_S
40948	hiiemäe	mäe	hiie+mägi	21_S	SgG	et	hiiemäe =mäe  (SgG  >hiie+mägi !21_S
40954	kablil	kabli	kabli	16_S	SgAd	et	kablil =kabli  (SgAd  >kabli !16_S
40958	karjamõisa	mõisa	karja+mõis	02_S	SgG	et	karjamõisa =mõisa  (SgG  >karja+mõis !02_S
40961	orjaaeg	aeg	orja+aeg	22_S	SgN	et	orjaaeg =aeg  (SgN  >orja+aeg !22_S
40970	s1912a	sa	sa	00_P	SgN	et	sa =sa  (SgN  >sa !00_P
40973	kalmukoht	koht	kalmu+koht	22_S	SgN	et	kalmukoht =koht  (SgN  >kalmu+koht !22_S
40980	kuristik	kuristik	kuristik	25_S	SgN	et	kuristik =kuristik  (SgN  >kuristik !25_S
40984	veesoon	soon	vee+soon	13_S	SgN	et	veesoon =soon  (SgN  >vee+soon !13_S
41000	siinsamas	siinsamas	siin+samas	41_D	ID	et	siinsamas =siinsamas  (ID  >siin+samas !41_D
41001	s1916a	sa	sa	00_P	SgN	et	sa =sa  (SgN  >sa !00_P
41003	mõisarehi	rehi	mõisa+rehi	24_S	SgN	et	mõisarehi =rehi  (SgN  >mõisa+rehi !24_S
41004	mõisarehe	rehe	mõisa+rehi	24_S	SgG	et	mõisarehe =rehe  (SgG  >mõisa+rehi !24_S
41009	aegne	aegne	aegne	02_A	SgN	et	aegne =aegne  (SgN  >aegne !02_A
41017	katkuhaldja	haldja	katku+haldjas	02_S	SgG	et	katkuhaldja =haldja  (SgG  >katku+haldjas !02_S
41018	pääseb	pääse	pääsema	28_V	IndPrSg3	et	pääseb =pääse  (IndPrSg3  >pääsema !28_V
41022	katkupärimus	pärimus	katku+pärimus	11_S	SgN	et	katkupärimus =pärimus  (SgN  >katku+pärimus !11_S
41027	koolerakülvajaiks	külvaja	kool+era+külvaja	01_S	PlTr	et	koolerakülvajaiks =külvaja  (PlTr  >kool+era+külvaja !01_S
41028	katkuga	katku	katk	22_S	SgKom	et	katkuga =katku  (SgKom  >katk !22_S
41045	surnumägi	mägi	surnu+mägi	21_S	SgN	et	surnumägi =mägi  (SgN  >surnu+mägi !21_S
41046	hääle	hääle	hääl	13_S	SgG	et	hääle =hääle  (SgG  >hääl !13_S
41047	isesugused	suguse	ise+sugune	10_P	PlN	et	isesugused =suguse  (PlN  >ise+sugune !10_P
41051	võigast	võigas	võigas	07_A	SgP	et	võigast =võigas  (SgP  >võigas !07_A
41059	sõtkub	sõtku	sõtkuma	28_V	IndPrSg3	et	sõtkub =sõtku  (IndPrSg3  >sõtkuma !28_V
41062	surmand	and	surm+and	22_S	SgN	et	surmand =and  (SgN  >surm+and !22_S
41064	kordamööda	kordamööda	korda+mööda	41_D	ID	et	kordamööda =kordamööda  (ID  >korda+mööda !41_D
41073	piits	piits	piits	22_S	SgN	et	piits =piits  (SgN  >piits !22_S
41075	südaöösel	südaöösel	süda+öösel	41_D	ID	et	südaöösel =südaöösel  (ID  >süda+öösel !41_D
41087	ühekorra	korra	ühe+kord	22_S	SgG	et	ühekorra =korra  (SgG  >ühe+kord !22_S
41090	suule	suu	suu	26_S	SgAll	et	suule =suu  (SgAll  >suu !26_S
41096	tõllaga	tõlla	tõld	22_S	SgKom	et	tõllaga =tõlla  (SgKom  >tõld !22_S
41098	harvaks	harva	harv	22_A	SgTr	et	harvaks =harva  (SgTr  >harv !22_A
41103	isaisad	isa	isa+isa	17_S	PlN	et	isaisad =isa  (PlN  >isa+isa !17_S
41113	varade	vara	vara	17_S	PlG	et	varade =vara  (PlG  >vara !17_S
40877	omajoonistatud	joonistatu	oma+joonistatu	01_S	PlN	et	omajoonistatud =joonistatu  (PlN  >oma+joonistatu !01_S
40879	kahesugused	suguse	kahe+sugune	10_A	PlN	et	kahesugused =suguse  (PlN  >kahe+sugune !10_A
40890	mitmesugustest	sugus	mitme+sugune	10_A	PlEl	et	mitmesugustest =sugus  (PlEl  >mitme+sugune !10_A
40910	täpse	täpse	täpne	02_A	SgG	et	täpse =täpse  (SgG  >täpne !02_A
40911	kõigub	kõigu	kõikuma	28_V	IndPrSg3	et	kõigub =kõigu  (IndPrSg3  >kõikuma !28_V
40917	silmnähtav	nähtav	silm+nähtav	02_A	SgN	et	silmnähtav =nähtav  (SgN  >silm+nähtav !02_A
40920	hiiu-	hiiu	hiid	22_S	SgG	et	hiiu- =hiiu  (SgG  >hiid !22_S
40924	rühmadesse	rühma	rühm	22_S	PlIll	et	rühmadesse =rühma  (PlIll  >rühm !22_S
40930	kohamuistendeid	muistende	koha+muistend	02_S	PlP	et	kohamuistendeid =muistende  (PlP  >koha+muistend !02_S
40931	muinaslinnadest	linna	muinas+linn	22_S	PlEl	et	muinaslinnadest =linna  (PlEl  >muinas+linn !22_S
40932	rohumäest	mäe	rohu+mägi	21_S	SgEl	et	rohumäest =mäe  (SgEl  >rohu+mägi !21_S
40933	teedest	tee	tee	26_S	PlEl	et	teedest =tee  (PlEl  >tee !26_S
40934	rühmana	rühma	rühm	22_S	SgEs	et	rühmana =rühma  (SgEs  >rühm !22_S
40952	vast	vast	vast	41_D	ID	et	vast =vast  (ID  >vast !41_D
40955	nuudilt	nuudi	nuut	22_S	SgAbl	et	nuudilt =nuudi  (SgAbl  >nuut !22_S
40956	jaagu	jaagu	jaak	22_S	SgG	et	jaagu =jaagu  (SgG  >jaak !22_S
40960	justkui	justkui	just+kui	41_J	ID	et	justkui =justkui  (ID  >just+kui !41_J
40963	väljataguse	taguse	välja+tagune	10_AS	SgG	et	väljataguse =taguse  (SgG  >välja+tagune !10_AS
40964	villem	villem	villem	02_S	SgN	et	villem =villem  (SgN  >villem !02_S
40965	juta	juta	jutt	22_S	SgG	et	juta =juta  (SgG  >jutt !22_S
40974	magister	magister	magister	02_S	SgN	et	magister =magister  (SgN  >magister !02_S
40975	laid	laid	laid	22_S	SgN	et	laid =laid  (SgN  >laid !22_S
40976	luid	lu	luu	26_S	PlP	et	luid =lu  (PlP  >luu !26_S
40979	vanatoa	toa	vana+tuba	18_S	SgG	et	vanatoa =toa  (SgG  >vana+tuba !18_S
40988	haned	hane	hani	20_S	PlN	et	haned =hane  (PlN  >hani !20_S
40989	rohumäele	mäe	rohu+mägi	21_S	SgAll	et	rohumäele =mäe  (SgAll  >rohu+mägi !21_S
40994	kants	kants	kants	22_S	SgN	et	kants =kants  (SgN  >kants !22_S
40998	jääkelder	kelder	jää+kelder	02_S	SgN	et	jääkelder =kelder  (SgN  >jää+kelder !02_S
41006	kaasiku	kaasiku	kaasik	02_S	SgG	et	kaasiku =kaasiku  (SgG  >kaasik !02_S
41011	deemonit	deemoni	deemon	02_S	SgP	et	deemonit =deemoni  (SgP  >deemon !02_S
41014	torkab	torka	torkama	29_V	IndPrSg3	et	torkab =torka  (IndPrSg3  >torkama !29_V
41020	tõrjeks	tõrje	tõrje	06_S	SgTr	et	tõrjeks =tõrje  (SgTr  >tõrje !06_S
41037	katkulevitajad	levitaja	katku+levitaja	01_S	PlN	et	katkulevitajad =levitaja  (PlN  >katku+levitaja !01_S
41039	surnumäeks	mäe	surnu+mägi	21_S	SgTr	et	surnumäeks =mäe  (SgTr  >surnu+mägi !21_S
41042	jalapöiad	pöia	jala+pöid	22_S	PlN	et	jalapöiad =pöia  (PlN  >jala+pöid !22_S
41048	puult	puu	puu	26_S	SgAbl	et	puult =puu  (SgAbl  >puu !26_S
41049	puule	puu	puu	26_S	SgAll	et	puule =puu  (SgAll  >puu !26_S
41050	isesugust	sugus	ise+sugune	10_P	SgP	et	isesugust =sugus  (SgP  >ise+sugune !10_P
41057	tuld	tul	tuli	20_S	SgP	et	tuld =tul  (SgP  >tuli !20_S
41058	astjas	astja	astja	01_S	SgIn	et	astjas =astja  (SgIn  >astja !01_S
41066	tropp	tropp	tropp	22_S	SgN	et	tropp =tropp  (SgN  >tropp !22_S
41068	pisike	pisike	pisike	12_A	SgN	et	pisike =pisike  (SgN  >pisike !12_A
41069	võtt	võtt	võtt	22_S	SgN	et	võtt =võtt  (SgN  >võtt !22_S
41080	katkumägi	mägi	katku+mägi	21_S	SgN	et	katkumägi =mägi  (SgN  >katku+mägi !21_S
41081	katkuhaiged	haige	katku+haige	01_AS	PlN	et	katkuhaiged =haige  (PlN  >katku+haige !01_AS
41082	katkukalmetega	kalme	katku+kalme	06_S	PlKom	et	katkukalmetega =kalme  (PlKom  >katku+kalme !06_S
41084	ilmingud	ilmingu	ilming	02_S	PlN	et	ilmingud =ilmingu  (PlN  >ilming !02_S
41088	kõrvas	kõrva	kõrv	22_S	SgIn	et	kõrvas =kõrva  (SgIn  >kõrv !22_S
41092	magamisviis	viis	magamis+viis	22_S	SgN	et	magamisviis =viis  (SgN  >magamis+viis !22_S
41094	katkuhaudu	haudu	katku+haud	22_S	PlP	et	katkuhaudu =haudu  (PlP  >katku+haud !22_S
41099	tuult	tuul	tuul	13_S	SgP	et	tuult =tuul  (SgP  >tuul !13_S
41107	kobru	kobru	kober	24_S	SgG	et	kobru =kobru  (SgG  >kober !24_S
41109	järeltulijaist	tulija	järel+tulija	01_S	PlEl	et	järeltulijaist =tulija  (PlEl  >järel+tulija !01_S
41111	meeltesse	meel	meel	13_S	PlIll	et	meeltesse =meel  (PlIll  >meel !13_S
41114	sissidest	sissi	siss	22_S	PlEl	et	sissidest =sissi  (PlEl  >siss !22_S
41116	peninukkidest	nukki	peni+nukk	22_S	PlEl	et	peninukkidest =nukki  (PlEl  >peni+nukk !22_S
41128	vahetas	vaheta	vahetama	27_V	IndIpfSg3	et	vahetas =vaheta  (IndIpfSg3  >vahetama !27_V
40937	elektrijaam	jaam	elektri+jaam	22_S	SgN	et	elektrijaam =jaam  (SgN  >elektri+jaam !22_S
40938	jaamaülema	ülema	jaama+ülem	02_AS	SgG	et	jaamaülema =ülema  (SgG  >jaama+ülem !02_AS
40941	algil	algi	alk	22_S	SgAd	et	algil =algi  (SgAd  >alk !22_S
40966	noorperenaine	naine	noor+pere+naine	12_S	SgN	et	noorperenaine =naine  (SgN  >noor+pere+naine !12_S
40967	mismoodi	mismoodi	mis+moodi	41_D	ID	et	mismoodi =mismoodi  (ID  >mis+moodi !41_D
40969	s1919a	sa	sa	00_P	SgN	et	sa =sa  (SgN  >sa !00_P
40971	metsjõe	jõe	mets+jõgi	21_S	SgG	et	metsjõe =jõe  (SgG  >mets+jõgi !21_S
40981	kuuland	and	kuul+and	22_S	SgN	et	kuuland =and  (SgN  >kuul+and !22_S
40985	härg	härg	härg	22_S	SgN	et	härg =härg  (SgN  >härg !22_S
40993	kaevuauk	auk	kaevu+auk	22_S	SgN	et	kaevuauk =auk  (SgN  >kaevu+auk !22_S
41002	kivikangur	kangur	kivi+kangur	02_S	SgN	et	kivikangur =kangur  (SgN  >kivi+kangur !02_S
41013	vanamehena	mehe	vana+mees	13_S	SgEs	et	vanamehena =mehe  (SgEs  >vana+mees !13_S
41019	vete	ve	vesi	15_S	PlG	et	vete =ve  (PlG  >vesi !15_S
41024	talurahvale	rahva	talu+rahvas	07_S	SgAll	et	talurahvale =rahva  (SgAll  >talu+rahvas !07_S
41025	käsilased	käsilase	käsilane	12_S	PlN	et	käsilased =käsilase  (PlN  >käsilane !12_S
41029	ravimid	ravimi	ravim	02_S	PlN	et	ravimid =ravimi  (PlN  >ravim !02_S
41033	katkutoovat	toova	katku+toov	02_A	SgP	et	katkutoovat =toova  (SgP  >katku+toov !02_A
41036	usti	us	uskuma	28_V	IndIpfIps	et	usti =us  (IndIpfIps  >uskuma !28_V
41043	mäele	mäe	mägi	21_S	SgAll	et	mäele =mäe  (SgAll  >mägi !21_S
41053	nokk	nokk	nokk	22_S	SgN	et	nokk =nokk  (SgN  >nokk !22_S
41055	katkueset	ese	katku+ese	04_S	SgP	et	katkueset =ese  (SgP  >katku+ese !04_S
41071	koledasti	koledasti	koledasti	41_D	ID	et	koledasti =koledasti  (ID  >koledasti !41_D
41076	ammudes	ammu	ammuma	28_V	Ger	et	ammudes =ammu  (Ger  >ammuma !28_V
41077	mõisaomanik	omanik	mõisa+omanik	25_S	SgN	et	mõisaomanik =omanik  (SgN  >mõisa+omanik !25_S
41079	katkukalmed	kalme	katku+kalme	06_S	PlN	et	katkukalmed =kalme  (PlN  >katku+kalme !06_S
41083	üleloomulikud	loomuliku	üle+loomulik	25_A	PlN	et	üleloomulikud =loomuliku  (PlN  >üle+loomulik !25_A
41086	katkuaeg	aeg	katku+aeg	22_S	SgN	et	katkuaeg =aeg  (SgN  >katku+aeg !22_S
41104	elukäik	käik	elu+käik	22_S	SgN	et	elukäik =käik  (SgN  >elu+käik !22_S
41106	munalaskmes	laskme	muna+lase	05_S	SgIn	et	munalaskmes =laskme  (SgIn  >muna+lase !05_S
41125	kääbaste	kääbas	kääbas	07_S	PlG	et	kääbaste =kääbas  (PlG  >kääbas !07_S
41126	laadaröövlid	röövli	laada+röövel	02_S	PlN	et	laadaröövlid =röövli  (PlN  >laada+röövel !02_S
41130	põhjasõjaga	sõja	põhja+sõda	18_S	SgKom	et	põhjasõjaga =sõja  (SgKom  >põhja+sõda !18_S
41131	karjavärav	värav	karja+värav	02_S	SgN	et	karjavärav =värav  (SgN  >karja+värav !02_S
41132	sõjavägede	väge	sõja+vägi	21_S	PlG	et	sõjavägede =väge  (PlG  >sõja+vägi !21_S
41147	sugustki	sugus	sugune	10_A	SgP^	et	sugustki =sugus  (SgP^  >sugune !10_A
41153	hooldas	hoolda	hooldama	27_V	IndIpfSg3	et	hooldas =hoolda  (IndIpfSg3  >hooldama !27_V
41155	mänd	mänd	mänd	22_S	SgN	et	mänd =mänd  (SgN  >mänd !22_S
41159	rahvausundiga	usundi	rahva+usund	02_S	SgKom	et	rahvausundiga =usundi  (SgKom  >rahva+usund !02_S
41162	rahvausundit	usundi	rahva+usund	02_S	SgP	et	rahvausundit =usundi  (SgP  >rahva+usund !02_S
41165	paavst	paavst	paavst	22_S	SgN	et	paavst =paavst  (SgN  >paavst !22_S
41175	siinse	siinse	siinne	02_A	SgG	et	siinse =siinse  (SgG  >siinne !02_A
41179	ohvriajad	aja	ohvri+aeg	22_S	PlN	et	ohvriajad =aja  (PlN  >ohvri+aeg !22_S
41181	hiiemetsaga	metsa	hiie+mets	22_S	SgKom	et	hiiemetsaga =metsa  (SgKom  >hiie+mets !22_S
41184	ähvardas	ähvarda	ähvardama	27_V	IndIpfSg3	et	ähvardas =ähvarda  (IndIpfSg3  >ähvardama !27_V
41192	mäekinkudel	kinku	mäe+kink	22_S	PlAd	et	mäekinkudel =kinku  (PlAd  >mäe+kink !22_S
41194	ohvreid	ohvre	ohver	02_S	PlP	et	ohvreid =ohvre  (PlP  >ohver !02_S
41200	kahed	kahe	kaks	22_N	PlN	et	kahed =kahe  (PlN  >kaks !22_N
41201	ohvritammed	tamme	ohvri+tamm	22_S	PlN	et	ohvritammed =tamme  (PlN  >ohvri+tamm !22_S
41213	jõetõusme	tõusme	jõe+tõuse	05_S	SgG	et	jõetõusme =tõusme  (SgG  >jõe+tõuse !05_S
41215	tünnilauad	laua	tünni+laud	22_S	PlN	et	tünnilauad =laua  (PlN  >tünni+laud !22_S
41232	umbjärv	järv	umb+järv	22_S	SgN	et	umbjärv =järv  (SgN  >umb+järv !22_S
41238	neelukoht	koht	neelu+koht	22_S	SgN	et	neelukoht =koht  (SgN  >neelu+koht !22_S
41248	lamedad	lameda	lame	02_A	PlN	et	lamedad =lameda  (PlN  >lame !02_A
41250	kunstlike	kunstlike	kunstlik	25_A	PlG	et	kunstlike =kunstlike  (PlG  >kunstlik !25_A
41252	hiiekivideks	kivi	hiie+kivi	17_S	PlTr	et	hiiekivideks =kivi  (PlTr  >hiie+kivi !17_S
41034	külvatakse	külva	külvama	29_V	IndPrIps	et	külvatakse =külva  (IndPrIps  >külvama !29_V
41035	luht	luht	luht	22_S	SgN	et	luht =luht  (SgN  >luht !22_S
41041	vaadake	vaada	vaatama	29_V	ImpPrPl2	et	vaadake =vaada  (ImpPrPl2  >vaatama !29_V
41052	käskjalad	jala	käsk+jalg	22_S	PlN	et	käskjalad =jala  (PlN  >käsk+jalg !22_S
41056	eit	eit	eit	22_S	SgN	et	eit =eit  (SgN  >eit !22_S
41065	harju-madise	madise	harju-madis	09_S	SgG	et	harju-madise =madise  (SgG  >harju-madis !09_S
41067	surema	sure	surema	36_V	Sup	et	surema =sure  (Sup  >surema !36_V
41070	r-põldmäe	mäe	r-põld+mägi	21_S	SgG	et	r-põldmäe =mäe  (SgG  >r-põld+mägi !21_S
41072	kanana	kana	kana	17_S	SgEs	et	kanana =kana  (SgEs  >kana !17_S
41074	piitsaga	piitsa	piits	22_S	SgKom	et	piitsaga =piitsa  (SgKom  >piits !22_S
41085	liivaaugud	augu	liiva+auk	22_S	PlN	et	liivaaugud =augu  (PlN  >liiva+auk !22_S
41093	vanker	vanker	vanker	02_S	SgN	et	vanker =vanker  (SgN  >vanker !02_S
41101	katkumäeks	mäe	katku+mägi	21_S	SgTr	et	katkumäeks =mäe  (SgTr  >katku+mägi !21_S
41110	sõjaröövlimuistendid	muistendi	sõja+röövli+muistend	02_S	PlN	et	sõjaröövlimuistendid =muistendi  (PlN  >sõja+röövli+muistend !02_S
41112	sõjaröövlid	röövli	sõja+röövel	02_S	PlN	et	sõjaröövlid =röövli  (PlN  >sõja+röövel !02_S
41129	s1923a	sa	sa	00_P	SgN	et	sa =sa  (SgN  >sa !00_P
41141	peidus	peidu	peit	22_S	SgIn	et	peidus =peidu  (SgIn  >peit !22_S
41145	otsind	ind	ots+ind	22_S	SgN	et	otsind =ind  (SgN  >ots+ind !22_S
41146	peidusolijatega	olija	peidus+olija	01_S	PlKom	et	peidusolijatega =olija  (PlKom  >peidus+olija !01_S
41148	keldrimäe	mäe	keldri+mägi	21_S	SgG	et	keldrimäe =mäe  (SgG  >keldri+mägi !21_S
41149	laitamm	tamm	lai+tamm	22_S	SgN	et	laitamm =tamm  (SgN  >lai+tamm !22_S
41160	loodusobjektid	objekti	loodus+objekt	22_S	PlN	et	loodusobjektid =objekti  (PlN  >loodus+objekt !22_S
41161	liigid	liigi	liik	22_S	PlN	et	liigid =liigi  (PlN  >liik !22_S
41171	loomadele	looma	loom	22_S	PlAll	et	loomadele =looma  (PlAll  >loom !22_S
41172	vetele	ve	vesi	15_S	PlAll	et	vetele =ve  (PlAll  >vesi !15_S
41173	ebapuhastele	puhas	eba+puhas	07_A	PlAll	et	ebapuhastele =puhas  (PlAll  >eba+puhas !07_A
41188	asukat	asuka	asukas	02_S	SgP	et	asukat =asuka  (SgP  >asukas !02_S
41189	metsanurga	nurga	metsa+nurk	22_S	SgG	et	metsanurga =nurga  (SgG  >metsa+nurk !22_S
41197	inimesedki	inimese	inimene	12_S	PlN^	et	inimesedki =inimese  (PlN^  >inimene !12_S
41199	vallil	valli	vall	22_S	SgAd	et	vallil =valli  (SgAd  >vall !22_S
41214	jõetõusmes	tõusme	jõe+tõuse	05_S	SgIn	et	jõetõusmes =tõusme  (SgIn  >jõe+tõuse !05_S
41216	tünn	tünn	tünn	22_S	SgN	et	tünn =tünn  (SgN  >tünn !22_S
41217	sooserv	serv	soo+serv	22_S	SgN	et	sooserv =serv  (SgN  >soo+serv !22_S
41219	allikaveega	vee	allika+vesi	15_S	SgKom	et	allikaveega =vee  (SgKom  >allika+vesi !15_S
41221	haigeid	haige	haige	01_AS	PlP	et	haigeid =haige  (PlP  >haige !01_AS
41228	virukülas	küla	viru+küla	17_S	SgIn	et	virukülas =küla  (SgIn  >viru+küla !17_S
41234	jõetõusmel	tõusme	jõe+tõuse	05_S	SgAd	et	jõetõusmel =tõusme  (SgAd  >jõe+tõuse !05_S
41240	salajõgi	jõgi	sala+jõgi	21_S	SgN	et	salajõgi =jõgi  (SgN  >sala+jõgi !21_S
41246	kevaditi	kevaditi	kevaditi	41_D	ID	et	kevaditi =kevaditi  (ID  >kevaditi !41_D
41247	läbimõõduga	mõõdu	läbi+mõõt	22_S	SgKom	et	läbimõõduga =mõõdu  (SgKom  >läbi+mõõt !22_S
41257	niis	niis	niis	14_S	SgN	et	niis =niis  (SgN  >niis !14_S
41262	mätliku	mätliku	mätlik	25_A	SgG	et	mätliku =mätliku  (SgG  >mätlik !25_A
41268	s1893a	sa	sa	00_P	SgN	et	sa =sa  (SgN  >sa !00_P
41269	metstukk	tukk	mets+tukk	22_S	SgN	et	metstukk =tukk  (SgN  >mets+tukk !22_S
41272	ussimägi	mägi	ussi+mägi	21_S	SgN	et	ussimägi =mägi  (SgN  >ussi+mägi !21_S
41275	männiku	männiku	männik	02_S	SgG	et	männiku =männiku  (SgG  >männik !02_S
41288	liivamäe	mäe	liiva+mägi	21_S	SgG	et	liivamäe =mäe  (SgG  >liiva+mägi !21_S
41291	linnamäele	mäe	linna+mägi	21_S	SgAll	et	linnamäele =mäe  (SgAll  >linna+mägi !21_S
41292	lubjaaugu	augu	lubja+auk	22_S	SgG	et	lubjaaugu =augu  (SgG  >lubja+auk !22_S
41295	mägesid	mäge	mägi	21_S	PlP	et	mägesid =mäge  (PlP  >mägi !21_S
41299	ehitamislugusid	lugu	ehitamis+lugu	18_S	PlP	et	ehitamislugusid =lugu  (PlP  >ehitamis+lugu !18_S
41310	pärgasi	asi	pärg+asi	24_S	SgN	et	pärgasi =asi  (SgN  >pärg+asi !24_S
41311	siidilintisid	linti	siidi+lint	22_S	PlP	et	siidilintisid =linti  (PlP  >siidi+lint !22_S
41318	karjamõisaks	mõisa	karja+mõis	02_S	SgTr	et	karjamõisaks =mõisa  (SgTr  >karja+mõis !02_S
41336	kuppel-	kuppel	kuppel	02_S	SgN	et	kuppel- =kuppel  (SgN  >kuppel !02_S
41340	madrusekleidis	kleidi	madruse+kleit	22_S	SgIn	et	madrusekleidis =kleidi  (SgIn  >madruse+kleit !22_S
41115	pardiajajaist	ajaja	pardi+ajaja	01_S	PlEl	et	pardiajajaist =ajaja  (PlEl  >pardi+ajaja !01_S
41118	antiikaja	aja	antiik+aeg	22_S	SgG	et	antiikaja =aja  (SgG  >antiik+aeg !22_S
41119	ajaloomuistenditeks	muistendi	aja+loo+muistend	02_S	PlTr	et	ajaloomuistenditeks =muistendi  (PlTr  >aja+loo+muistend !02_S
41120	pardiajajatest	ajaja	pardi+ajaja	01_S	PlEl	et	pardiajajatest =ajaja  (PlEl  >pardi+ajaja !01_S
41121	tuletis	tuletis	tuletis	11_S	SgN	et	tuletis =tuletis  (SgN  >tuletis !11_S
41122	proosapärimuse	pärimuse	proosa+pärimus	11_S	SgG	et	proosapärimuse =pärimuse  (SgG  >proosa+pärimus !11_S
41123	olustikuga	olustiku	olustik	25_S	SgKom	et	olustikuga =olustiku  (SgKom  >olustik !25_S
41124	röövlitega	röövli	röövel	02_S	PlKom	et	röövlitega =röövli  (PlKom  >röövel !02_S
41127	peremehega	mehe	pere+mees	13_S	SgKom	et	peremehega =mehe  (SgKom  >pere+mees !13_S
41137	leivakünasse	küna	leiva+küna	17_S	SgIll	et	leivakünasse =küna  (SgIll  >leiva+küna !17_S
41140	soldatid	soldati	soldat	02_S	PlN	et	soldatid =soldati  (PlN  >soldat !02_S
41142	arvand	and	arv+and	22_S	SgN	et	arvand =and  (SgN  >arv+and !22_S
41143	küün	küün	küün	22_S	SgN	et	küün =küün  (SgN  >küün !22_S
41144	sõjamehed	mehe	sõja+mees	13_S	PlN	et	sõjamehed =mehe  (PlN  >sõja+mees !13_S
41150	rahvapärimuses	pärimuse	rahva+pärimus	11_S	SgIn	et	rahvapärimuses =pärimuse  (SgIn  >rahva+pärimus !11_S
41151	lahing	lahing	lahing	02_S	SgN	et	lahing =lahing  (SgN  >lahing !02_S
41157	metsavendadest	venda	metsa+vend	22_S	PlEl	et	metsavendadest =venda  (PlEl  >metsa+vend !22_S
41168	ristisõtta	sõtta	risti+sõda	18_S	SgAdt	et	ristisõtta =sõtta  (SgAdt  >risti+sõda !18_S
41170	mõistuseta	mõistuse	mõistus	11~09_S	SgAb	et	mõistuseta =mõistuse  (SgAb  >mõistus !11~09_S
41177	pühapaigad	paiga	püha+paik	22_S	PlN	et	pühapaigad =paiga  (PlN  >püha+paik !22_S
41178	ohvrikivid	kivi	ohvri+kivi	17_S	PlN	et	ohvrikivid =kivi  (PlN  >ohvri+kivi !17_S
41182	lõunaosas	osa	lõuna+osa	17_S	SgIn	et	lõunaosas =osa  (SgIn  >lõuna+osa !17_S
41186	tabud	tabu	tabu	17_S	PlN	et	tabud =tabu  (PlN  >tabu !17_S
41187	valk	valk	valk	22_S	SgN	et	valk =valk  (SgN  >valk !22_S
41191	hiius	hiiu	hiid	22_S	SgIn	et	hiius =hiiu  (SgIn  >hiid !22_S
41193	ladvani	ladva	latv	22_S	SgTer	et	ladvani =ladva  (SgTer  >latv !22_S
41195	kuldking	king	kuld+king	22_S	SgN	et	kuldking =king  (SgN  >kuld+king !22_S
41196	kummalisi	kummalisi	kummaline	12_A	PlP	et	kummalisi =kummalisi  (PlP  >kummaline !12_A
41198	hiietammastik	astik	hiie+tamm+astik	02_S	SgN	et	hiietammastik =astik  (SgN  >hiie+tamm+astik !02_S
41203	veekogudest	kogu	vee+kogu	17_S	PlEl	et	veekogudest =kogu  (PlEl  >vee+kogu !17_S
41204	funktsioonide	funktsiooni	funktsioon	22_S	PlG	et	funktsioonide =funktsiooni  (PlG  >funktsioon !22_S
41207	raviallikaid	allika	ravi+allikas	02_S	PlP	et	raviallikaid =allika  (PlP  >ravi+allikas !02_S
41209	viljateri	teri	vilja+tera	17_S	PlP	et	viljateri =teri  (PlP  >vilja+tera !17_S
41224	väheks	vähe	vähk	22_S	PlTr	et	väheks =vähe  (PlTr  >vähk !22_S
41226	mehel	mehe	mees	13_S	SgAd	et	mehel =mehe  (SgAd  >mees !13_S
41229	saelt	sae	saag	22_S	SgAbl	et	saelt =sae  (SgAbl  >saag !22_S
41253	ohvri	ohvri	ohver	02_S	SgG	et	ohvri =ohvri  (SgG  >ohver !02_S
41259	ussid	ussi	uss	22_S	PlN	et	ussid =ussi  (PlN  >uss !22_S
41260	üleloomulikest	loomulike	üle+loomulik	25_A	PlEl	et	üleloomulikest =loomulike  (PlEl  >üle+loomulik !25_A
41271	karud	karu	karu	17_S	PlN	et	karud =karu  (PlN  >karu !17_S
41274	veskimägi	mägi	veski+mägi	21_S	SgN	et	veskimägi =mägi  (SgN  >veski+mägi !21_S
41279	matust	matus	matus	09_S	SgP	et	matust =matus  (SgP  >matus !09_S
41280	männid	männi	mänd	22_S	PlN	et	männid =männi  (PlN  >mänd !22_S
41282	rahaauk	auk	raha+auk	22_S	SgN	et	rahaauk =auk  (SgN  >raha+auk !22_S
41294	sinivee	vee	sini+vesi	15_S	SgG	et	sinivee =vee  (SgG  >sini+vesi !15_S
41300	ebaloomulike	loomulike	eba+loomulik	25_A	PlG	et	ebaloomulike =loomulike  (PlG  >eba+loomulik !25_A
41306	kondid	kondi	kont	22_S	PlN	et	kondid =kondi  (PlN  >kont !22_S
41320	klassitsistlik	klassitsistlik	klassitsistlik	25_A	SgN	et	klassitsistlik =klassitsistlik  (SgN  >klassitsistlik !25_A
41324	joonia	joonia	joonia	41_G	ID	et	joonia =joonia  (ID  >joonia !41_G
41327	skulptuuride	skulptuuri	skulptuur	22_S	PlG	et	skulptuuride =skulptuuri  (PlG  >skulptuur !22_S
41331	asetses	asetse	asetsema	27_V	IndIpfSg3	et	asetses =asetse  (IndIpfSg3  >asetsema !27_V
41332	uksekarniisid	karniisi	ukse+karniis	22_S	PlN	et	uksekarniisid =karniisi  (PlN  >ukse+karniis !22_S
41333	motiividelt	motiivi	motiiv	22_S	PlAbl	et	motiividelt =motiivi  (PlAbl  >motiiv !22_S
41334	töötluselt	töötluse	töötlus	11~09_S	SgAbl	et	töötluselt =töötluse  (SgAbl  >töötlus !11~09_S
41339	katma	kat	katma	35_V	Sup	et	katma =kat  (Sup  >katma !35_V
41117	peninukkide	nukki	peni+nukk	22_S	PlG	et	peninukkide =nukki  (PlG  >peni+nukk !22_S
41134	peitis	peit	peitma	34_V	IndIpfSg3	et	peitis =peit  (IndIpfSg3  >peitma !34_V
41136	puges	puge	pugema	28_V	IndIpfSg3	et	puges =puge  (IndIpfSg3  >pugema !28_V
41138	hüpates	hüpa	hüppama	29_V	Ger	et	hüpates =hüpa  (Ger  >hüppama !29_V
41152	istutas	istuta	istutama	27_V	IndIpfSg3	et	istutas =istuta  (IndIpfSg3  >istutama !27_V
41154	talukoht	koht	talu+koht	22_S	SgN	et	talukoht =koht  (SgN  >talu+koht !22_S
41158	kummitab	kummita	kummitama	27_V	IndPrSg3	et	kummitab =kummita  (IndPrSg3  >kummitama !27_V
41166	bullas	bulla	bulla	16_S	SgIn	et	bullas =bulla  (SgIn  >bulla !16_S
41167	kristlasi	kristlasi	kristlane	12_S	PlP	et	kristlasi =kristlasi  (PlP  >kristlane !12_S
41174	vaimudele	vaimu	vaim	22_S	PlAll	et	vaimudele =vaimu  (PlAll  >vaim !22_S
41176	ajaperioodid	perioodi	aja+periood	22_S	PlN	et	ajaperioodid =perioodi  (PlN  >aja+periood !22_S
41180	lääne-eestis	eesti	lääne-eesti	16_H	SgIn	et	lääne-eestis =eesti  (SgIn  >lääne-eesti !16_H
41206	hiie-	hiie	hiis	14_S	SgG	et	hiie- =hiie  (SgG  >hiis !14_S
41208	hõbevalget	valge	hõbe+valge	01_AS	SgP	et	hõbevalget =valge  (SgP  >hõbe+valge !01_AS
41220	silmapesemise	pesemise	silma+pesemine	12_S	SgG	et	silmapesemise =pesemise  (SgG  >silma+pesemine !12_S
41222	pesemas	pese	pesema	36_V	SupIn	et	pesemas =pese  (SupIn  >pesema !36_V
41223	1937aastal	aasta	aasta	01_S	SgAd	et	aastal =aasta  (SgAd  >aasta !01_S
41231	seinu	seinu	sein	23?22_S	PlP	et	seinu =seinu  (PlP  >sein !23?22_S
41235	selgroog	roog	selg+roog	22_S	SgN	et	selgroog =roog  (SgN  >selg+roog !22_S
41237	tõmband	and	tõmb+and	22_S	SgN	et	tõmband =and  (SgN  >tõmb+and !22_S
41239	jõega	jõe	jõgi	21_S	SgKom	et	jõega =jõe  (SgKom  >jõgi !21_S
41241	kohinat	kohina	kohin	02_S	SgP	et	kohinat =kohina  (SgP  >kohin !02_S
41242	jutluse	jutluse	jutlus	11~09_S	SgG	et	jutluse =jutluse  (SgG  >jutlus !11~09_S
41249	looduslike	looduslike	looduslik	25_A	PlG	et	looduslike =looduslike  (PlG  >looduslik !25_A
41251	vihmaveega	vee	vihma+vesi	15_S	SgKom	et	vihmaveega =vee  (SgKom  >vihma+vesi !15_S
41255	ohverdamas	ohverda	ohverdama	27_V	SupIn	et	ohverdamas =ohverda  (SupIn  >ohverdama !27_V
41261	olenditest	olendi	olend	02_S	PlEl	et	olenditest =olendi  (PlEl  >olend !02_S
41277	kääpa	kääpa	kääbas	07_S	SgG	et	kääpa =kääpa  (SgG  >kääbas !07_S
41278	matmispaigad	paiga	matmis+paik	22_S	PlN	et	matmispaigad =paiga  (PlN  >matmis+paik !22_S
41283	uluma	ulu	uluma	27_V	Sup	et	uluma =ulu  (Sup  >uluma !27_V
41293	lubjaahjud	ahju	lubja+ahi	24_S	PlN	et	lubjaahjud =ahju  (PlN  >lubja+ahi !24_S
41301	olenditega	olendi	olend	02_S	PlKom	et	olenditega =olendi  (PlKom  >olend !02_S
41303	kiu	kiu	kiud	22_S	SgG	et	kiu =kiu  (SgG  >kiud !22_S
41319	vilumäele	mäe	vilu+mägi	21_S	SgAll	et	vilumäele =mäe  (SgAll  >vilu+mägi !21_S
41323	reisikirjeldused	kirjelduse	reisi+kirjeldus	11_S	PlN	et	reisikirjeldused =kirjelduse  (PlN  >reisi+kirjeldus !11_S
41326	seintes	sein	sein	23_S	PlIn	et	seintes =sein  (PlIn  >sein !23_S
41335	klassitsistlikud	klassitsistliku	klassitsistlik	25_A	PlN	et	klassitsistlikud =klassitsistliku  (PlN  >klassitsistlik !25_A
41337	ehitisega	ehitise	ehitis	11_S	SgKom	et	ehitisega =ehitise  (SgKom  >ehitis !11_S
41343	piinamas	piina	piinama	29_V	SupIn	et	piinamas =piina  (SupIn  >piinama !29_V
41347	pikne	pikne	pikne	02_S	SgN	et	pikne =pikne  (SgN  >pikne !02_S
41350	katuseta	katuse	katus	09_S	SgAb	et	katuseta =katuse  (SgAb  >katus !09_S
41352	müüriti	müüri	müürima	28_V	IndIpfIps	et	müüriti =müüri  (IndIpfIps  >müürima !28_V
41353	mõisnikest	mõisnike	mõisnik	25_S	PlEl	et	mõisnikest =mõisnike  (PlEl  >mõisnik !25_S
41356	vestleme	vestle	vestlema	30_V	IndPrPl1	et	vestleme =vestle  (IndPrPl1  >vestlema !30_V
41361	4laua	laua	laud	22_S	SgG	et	laua =laua  (SgG  >laud !22_S
41367	viiekümnekuues	kuue	viie+kümne+kuub	22_S	SgIn	et	viiekümnekuues =kuue  (SgIn  >viie+kümne+kuub !22_S
41375	postkardid	kardi	post+kart	22_S	PlN	et	postkardid =kardi  (PlN  >post+kart !22_S
41378	pildidega	pildi	pild	22_S	PlKom	et	pildidega =pildi  (PlKom  >pild !22_S
41384	muutuksite	muutu	muutuma	27_V	KndPrPl2	et	muutuksite =muutu  (KndPrPl2  >muutuma !27_V
41390	koolielule	elu	kooli+elu	17_S	SgAll	et	koolielule =elu  (SgAll  >kooli+elu !17_S
41409	inter-	inter	inter	02_S	SgN	et	inter- =inter  (SgN  >inter !02_S
41415	opositsioon	opositsioon	opositsioon	22_S	SgN	et	opositsioon =opositsioon  (SgN  >opositsioon !22_S
41417	kvantitatiivse	kvantitatiivse	kvantitatiivne	02_A	SgG	et	kvantitatiivse =kvantitatiivse  (SgG  >kvantitatiivne !02_A
41421	vokaalid	vokaali	vokaal	22_S	PlN	et	vokaalid =vokaali  (PlN  >vokaal !22_S
41431	tarindis	tarindi	tarind	02_S	SgIn	et	tarindis =tarindi  (SgIn  >tarind !02_S
41133	põgenes	põgene	põgenema	27_V	IndIpfSg3	et	põgenes =põgene  (IndIpfSg3  >põgenema !27_V
41135	tallu	tallu	talu	17_S	SgAdt	et	tallu =tallu  (SgAdt  >talu !17_S
41139	talusse	talu	talu	17_S	SgIll	et	talusse =talu  (SgIll  >talu !17_S
41156	lähiminevik	minevik	lähi+minevik	25_S	SgN	et	lähiminevik =minevik  (SgN  >lähi+minevik !25_S
41163	rahvausundi	usundi	rahva+usund	02_S	SgG	et	rahvausundi =usundi  (SgG  >rahva+usund !02_S
41164	tunnusjooneks	joone	tunnus+joon	13_S	SgTr	et	tunnusjooneks =joone  (SgTr  >tunnus+joon !13_S
41169	jumalale	jumala	jumal	02_S	SgAll	et	jumalale =jumala  (SgAll  >jumal !02_S
41183	mände	mände	mänd	22_S	PlP	et	mände =mände  (PlP  >mänd !22_S
41185	surmaoht	oht	surma+oht	22_S	SgN	et	surmaoht =oht  (SgN  >surma+oht !22_S
41190	hiidlane	hiidlane	hiidlane	12?10_S	SgN	et	hiidlane =hiidlane  (SgN  >hiidlane !12?10_S
41202	kultuslikest	kultuslike	kultuslik	25_A	PlEl	et	kultuslikest =kultuslike  (PlEl  >kultuslik !25_A
41205	jaotada	jaota	jaotama	27_V	Inf	et	jaotada =jaota  (Inf  >jaotama !27_V
41210	ehteasju	asju	ehte+asi	24_S	PlP	et	ehteasju =asju  (PlP  >ehte+asi !24_S
41211	võtmas	võt	võtma	35_V	SupIn	et	võtmas =võt  (SupIn  >võtma !35_V
41212	saks	saks	saks	23?22_S	SgN	et	saks =saks  (SgN  >saks !23?22_S
41218	küngas	küngas	küngas	07_S	SgN	et	küngas =küngas  (SgN  >küngas !07_S
41225	vahutas	vahuta	vahutama	27_V	IndIpfSg3	et	vahutas =vahuta  (IndIpfSg3  >vahutama !27_V
41227	haiged	haige	haige	01_AS	PlN	et	haiged =haige  (PlN  >haige !01_AS
41230	lubjati	lubja	lupjama	29_V	IndIpfIps	et	lubjati =lubja  (IndIpfIps  >lupjama !29_V
41233	veetõmme	tõmme	vee+tõmme	06_S	SgN	et	veetõmme =tõmme  (SgN  >vee+tõmme !06_S
41236	vallasant	sant	valla+sant	22_SA	SgN	et	vallasant =sant  (SgN  >valla+sant !22_SA
41243	lehmakell	kell	lehma+kell	22_S	SgN	et	lehmakell =kell  (SgN  >lehma+kell !22_S
41244	põldusid	põldu	põld	22_S	PlP	et	põldusid =põldu  (PlP  >põld !22_S
41245	kogunemiskoht	koht	kogunemis+koht	22_S	SgN	et	kogunemiskoht =koht  (SgN  >kogunemis+koht !22_S
41254	pidamas	pida	pidama	28_V	SupIn	et	pidamas =pida  (SupIn  >pidama !28_V
41263	ööse	ööse	öös	22_S	PlP	et	ööse =ööse  (PlP  >öös !22_S
41264	kotka	kotka	kotkas	07_S	SgG	et	kotka =kotka  (SgG  >kotkas !07_S
41265	nädalapäevadel	päeva	nädala+päev	22_S	PlAd	et	nädalapäevadel =päeva  (PlAd  >nädala+päev !22_S
41266	juttudega	juttu	jutt	22_S	PlKom	et	juttudega =juttu  (PlKom  >jutt !22_S
41267	rass	rass	rass	22_S	SgN	et	rass =rass  (SgN  >rass !22_S
41273	pärnad	pärna	pärn	22_S	PlN	et	pärnad =pärna  (PlN  >pärn !22_S
41276	müürisepp	sepp	müüri+sepp	22_S	SgN	et	müürisepp =sepp  (SgN  >müüri+sepp !22_S
41285	kondimägi	mägi	kondi+mägi	21_S	SgN	et	kondimägi =mägi  (SgN  >kondi+mägi !21_S
41286	männitukk	tukk	männi+tukk	22_S	SgN	et	männitukk =tukk  (SgN  >männi+tukk !22_S
41287	liivaauk	auk	liiva+auk	22_S	SgN	et	liivaauk =auk  (SgN  >liiva+auk !22_S
41307	koledat	koleda	kole	02_A	SgP	et	koledat =koleda  (SgP  >kole !02_A
41308	kabelis	kabeli	kabel	02_S	SgIn	et	kabelis =kabeli  (SgIn  >kabel !02_S
41314	s1921a	sa	sa	00_P	SgN	et	sa =sa  (SgN  >sa !00_P
41321	kolga	kolga	kolk	22_S	SgG	et	kolga =kolga  (SgG  >kolk !22_S
41322	näidiste	näidis	näidis	09_S	PlG	et	näidiste =näidis  (PlG  >näidis !09_S
41328	korrusele	korruse	korrus	09_S	SgAll	et	korrusele =korruse  (SgAll  >korrus !09_S
41329	kuppelsaal	saal	kuppel+saal	22_S	SgN	et	kuppelsaal =saal  (SgN  >kuppel+saal !22_S
41330	peosaal	saal	peo+saal	22_S	SgN	et	peosaal =saal  (SgN  >peo+saal !22_S
41341	katan	kata	katma	35_V	IndPrSg1	et	katan =kata  (IndPrSg1  >katma !35_V
41349	trepi	trepi	trepp	22_S	SgG	et	trepi =trepi  (SgG  >trepp !22_S
41351	vaasid	vaasi	vaas	22_S	PlN	et	vaasid =vaasi  (PlN  >vaas !22_S
41355	tuuli	tuul	tuul	13_S	PlP	et	tuuli =tuul  (PlP  >tuul !13_S
41373	hääldusbaas	baas	hääldus+baas	22_S	SgN	et	hääldusbaas =baas  (SgN  >hääldus+baas !22_S
41374	hääliku	hääliku	häälik	02_S	SgG	et	hääliku =hääliku  (SgG  >häälik !02_S
41386	koolikartlikule	kartliku	kooli+kartlik	25_A	SgAll	et	koolikartlikule =kartliku  (SgAll  >kooli+kartlik !25_A
41393	hinnete	hinne	hinne	06_S	PlG	et	hinnete =hinne  (PlG  >hinne !06_S
41400	lühikirjandeid	kirjande	lühi+kirjand	02_S	PlP	et	lühikirjandeid =kirjande  (PlP  >lühi+kirjand !02_S
41405	grammatikatasandil	tasandi	grammatika+tasand	02_S	SgAd	et	grammatikatasandil =tasandi  (SgAd  >grammatika+tasand !02_S
41410	keeletasandi	tasandi	keele+tasand	02_S	SgG	et	keeletasandi =tasandi  (SgG  >keele+tasand !02_S
41418	rõhuga	rõhu	rõhk	22_S	SgKom	et	rõhuga =rõhu  (SgKom  >rõhk !22_S
41423	kirjapilt	pilt	kirja+pilt	22_S	SgN	et	kirjapilt =pilt  (SgN  >kirja+pilt !22_S
41256	ronida	roni	ronima	27_V	Inf	et	ronida =roni  (Inf  >ronima !27_V
41258	hiiemets	mets	hiie+mets	22_S	SgN	et	hiiemets =mets  (SgN  >hiie+mets !22_S
41270	tasuja-aegne	aegne	tasuja-aegne	02_A	SgN	et	tasuja-aegne =aegne  (SgN  >tasuja-aegne !02_A
41281	vahtkonnas	vahtkonna	vahtkond	22_S	SgIn	et	vahtkonnas =vahtkonna  (SgIn  >vahtkond !22_S
41284	härgasid	härga	härg	22_S	PlP	et	härgasid =härga  (PlP  >härg !22_S
41289	surnukonte	konte	surnu+kont	22_S	PlP	et	surnukonte =konte  (PlP  >surnu+kont !22_S
41290	linnamägi	mägi	linna+mägi	21_S	SgN	et	linnamägi =mägi  (SgN  >linna+mägi !21_S
41296	mägedemetsas	metsa	mägede+mets	22_S	SgIn	et	mägedemetsas =metsa  (SgIn  >mägede+mets !22_S
41297	männimets	mets	männi+mets	22_S	SgN	et	männimets =mets  (SgN  >männi+mets !22_S
41298	lau-augud	augu	lau-auk	22_S	PlN	et	lau-augud =augu  (PlN  >lau-auk !22_S
41302	puukirik	kirik	puu+kirik	02_S	SgN	et	puukirik =kirik  (SgN  >puu+kirik !02_S
41304	puukabeli	kabeli	puu+kabel	02_S	SgG	et	puukabeli =kabeli  (SgG  >puu+kabel !02_S
41305	taht	taht	taht	22_S	SgN	et	taht =taht  (SgN  >taht !22_S
41309	vanaaegseid	aegse	vana+aegne	02_A	PlP	et	vanaaegseid =aegse  (PlP  >vana+aegne !02_A
41312	kukub	kuku	kukkuma	28_V	IndPrSg3	et	kukub =kuku  (IndPrSg3  >kukkuma !28_V
41313	urgete	urge	urge	06_S	PlG	et	urgete =urge  (PlG  >urge !06_S
41315	vaimusid	vaimu	vaim	22_S	PlP	et	vaimusid =vaimu  (PlP  >vaim !22_S
41316	lauluraamat	raamat	laulu+raamat	02_S	SgN	et	lauluraamat =raamat  (SgN  >laulu+raamat !02_S
41317	heleda	heleda	hele	02_A	SgG	et	heleda =heleda  (SgG  >hele !02_A
41325	kaunistab	kaunista	kaunistama	27_V	IndPrSg3	et	kaunistab =kaunista  (IndPrSg3  >kaunistama !27_V
41338	ead	ea	iga	18_S	PlN	et	ead =ea  (PlN  >iga !18_S
41345	rõhuma	rõhu	rõhuma	27_V	Sup	et	rõhuma =rõhu  (Sup  >rõhuma !27_V
41346	õilme	õilme	õile	05_S	SgG	et	õilme =õilme  (SgG  >õile !05_S
41358	toast	toa	tuba	18_S	SgEl	et	toast =toa  (SgEl  >tuba !18_S
41359	küsisõnad	sõna	küsi+sõna	17_S	PlN	et	küsisõnad =sõna  (PlN  >küsi+sõna !17_S
41371	suusatama	suusata	suusatama	27_V	Sup	et	suusatama =suusata  (Sup  >suusatama !27_V
41372	1ma	ma	ma	00_P	SgN	et	ma =ma  (SgN  >ma !00_P
41380	hommikult	hommiku	hommik	02_S	SgAbl	et	hommikult =hommiku  (SgAbl  >hommik !02_S
41387	rollimängudes	mängu	rolli+mäng	22_S	PlIn	et	rollimängudes =mängu  (PlIn  >rolli+mäng !22_S
41388	kvaliteetsest	kvaliteetse	kvaliteetne	02_A	SgEl	et	kvaliteetsest =kvaliteetse  (SgEl  >kvaliteetne !02_A
41391	metsadega	metsa	mets	22_S	PlKom	et	metsadega =metsa  (PlKom  >mets !22_S
41395	edasises	edasise	edasine	12_A	SgIn	et	edasises =edasise  (SgIn  >edasine !12_A
41396	keeleõppimises	õppimise	keele+õppimine	12_S	SgIn	et	keeleõppimises =õppimise  (SgIn  >keele+õppimine !12_S
41398	kooliastme	astme	kooli+aste	05_S	SgG	et	kooliastme =astme  (SgG  >kooli+aste !05_S
41399	loovtöid	tö	loov+töö	26_S	PlP	et	loovtöid =tö  (PlP  >loov+töö !26_S
41407	vormivalikuvigu	vigu	vormi+valiku+viga	18_S	PlP	et	vormivalikuvigu =vigu  (PlP  >vormi+valiku+viga !18_S
41408	toorlaen	laen	toor+laen	22_S	SgN	et	toorlaen =laen  (SgN  >toor+laen !22_S
41411	silbile	silbi	silp	22_S	SgAll	et	silbile =silbi  (SgAll  >silp !22_S
41412	kvantitatiivne	kvantitatiivne	kvantitatiivne	02_A	SgN	et	kvantitatiivne =kvantitatiivne  (SgN  >kvantitatiivne !02_A
41414	häälikute	hääliku	häälik	02_S	PlG	et	häälikute =hääliku  (PlG  >häälik !02_S
41416	omase	omase	omane	10_A	SgG	et	omase =omase  (SgG  >omane !10_A
41420	põhilisi	põhilisi	põhiline	12_A	PlP	et	põhilisi =põhilisi  (PlP  >põhiline !12_A
41429	vormivaliku	valiku	vormi+valik	02_S	SgG	et	vormivaliku =valiku  (SgG  >vormi+valik !02_S
41435	tarindite	tarindi	tarind	02_S	PlG	et	tarindite =tarindi  (PlG  >tarind !02_S
41437	parasjagu	parasjagu	paras+jagu	41_D	ID	et	parasjagu =parasjagu  (ID  >paras+jagu !41_D
41450	isikulõpp	lõpp	isiku+lõpp	22_SA	SgN	et	isikulõpp =lõpp  (SgN  >isiku+lõpp !22_SA
41451	liitega	liite	liide	06_S	SgKom	et	liitega =liite  (SgKom  >liide !06_S
41454	lumiinimene	inimene	lumi+inimene	12_S	SgN	et	lumiinimene =inimene  (SgN  >lumi+inimene !12_S
41461	ta-liidet	liide	ta-liide	06_S	SgP	et	ta-liidet =liide  (SgP  >ta-liide !06_S
41463	ammutab	ammuta	ammutama	27_V	IndPrSg3	et	ammutab =ammuta  (IndPrSg3  >ammutama !27_V
41468	soomlane	soomlane	soomlane	12?10_S	SgN	et	soomlane =soomlane  (SgN  >soomlane !12?10_S
41469	õppeaastal	aasta	õppe+aasta	01_S	SgAd	et	õppeaastal =aasta  (SgAd  >õppe+aasta !01_S
41474	e-kirjadega	kirja	e-kiri	24_S	PlKom	et	e-kirjadega =kirja  (PlKom  >e-kiri !24_S
41479	hulganisti	hulganisti	hulganisti	41_D	ID	et	hulganisti =hulganisti  (ID  >hulganisti !41_D
41491	hääldub	hääldu	häälduma	27_V	IndPrSg3	et	hääldub =hääldu  (IndPrSg3  >häälduma !27_V
41342	peretoas	toa	pere+tuba	18_S	SgIn	et	peretoas =toa  (SgIn  >pere+tuba !18_S
41354	hiigla	hiigla	hiigla	41_D	ID	et	hiigla =hiigla  (ID  >hiigla !41_D
41357	riiule	riiu	riid	22_S	SgAll	et	riiule =riiu  (SgAll  >riid !22_S
41362	5poeg	poeg	poeg	22_S	SgN	et	poeg =poeg  (SgN  >poeg !22_S
41364	8koer	koer	koer	23?22_SA	SgN	et	koer =koer  (SgN  >koer !23?22_SA
41365	9sõidame	sõida	sõitma	34_V	IndPrPl1	et	sõidame =sõida  (IndPrPl1  >sõitma !34_V
41368	mitmendal	mitmenda	mitmes	02_P	SgAd	et	mitmendal =mitmenda  (SgAd  >mitmes !02_P
41370	suusatamast	suusata	suusatama	27_V	SupEl	et	suusatamast =suusata  (SupEl  >suusatama !27_V
41381	tunnisse	tunni	tund	22_S	SgIll	et	tunnisse =tunni  (SgIll  >tund !22_S
41389	tüütama	tüüta	tüütama	29_V	Sup	et	tüütama =tüüta  (Sup  >tüütama !29_V
41404	töödega	töö	töö	26_S	PlKom	et	töödega =töö  (PlKom  >töö !26_S
41406	vormimoodustus-	moodustus	vormi+moodustus	11_S	SgN	et	vormimoodustus- =moodustus  (SgN  >vormi+moodustus !11_S
41419	kirjutusviis	viis	kirjutus+viis	22_S	SgN	et	kirjutusviis =viis  (SgN  >kirjutus+viis !22_S
41422	hääldusenergiat	energia	hääldus+energia	01_S	SgP	et	hääldusenergiat =energia  (SgP  >hääldus+energia !01_S
41425	kaevur	kaevur	kaevur	02_S	SgN	et	kaevur =kaevur  (SgN  >kaevur !02_S
41426	ränk	ränk	ränk	22_A	SgN	et	ränk =ränk  (SgN  >ränk !22_A
41427	grammatikatasandi	tasandi	grammatika+tasand	02_S	SgG	et	grammatikatasandi =tasandi  (SgG  >grammatika+tasand !02_S
41432	hirmutab	hirmuta	hirmutama	27_V	IndPrSg3	et	hirmutab =hirmuta  (IndPrSg3  >hirmutama !27_V
41434	laiendid	laiendi	laiend	02_S	PlN	et	laiendid =laiendi  (PlN  >laiend !02_S
41436	süstemaatilised	süstemaatilise	süstemaatiline	12_A	PlN	et	süstemaatilised =süstemaatilise  (PlN  >süstemaatiline !12_A
41441	käänet	kääne	kääne	06_S	SgP	et	käänet =kääne  (SgP  >kääne !06_S
41452	väljendid	väljendi	väljend	02_S	PlN	et	väljendid =väljendi  (PlN  >väljend !02_S
41455	omastavalise	omastavalise	omastavaline	12_A	SgG	et	omastavalise =omastavalise  (SgG  >omastavaline !12_A
41467	kirjal	kirja	kiri	24_S	SgAd	et	kirjal =kirja  (SgAd  >kiri !24_S
41472	keelekeskkonnas	keskkonna	keele+keskkond	22_S	SgIn	et	keelekeskkonnas =keskkonna  (SgIn  >keele+keskkond !22_S
41473	kõnekeelsed	keelse	kõne+keelne	02_A	PlN	et	kõnekeelsed =keelse  (PlN  >kõne+keelne !02_A
41482	mitteametlike	ametlike	mitte+ametlik	25_A	PlG	et	mitteametlike =ametlike  (PlG  >mitte+ametlik !25_A
41483	klusiilide	klusiili	klusiil	22_S	PlG	et	klusiilide =klusiili  (PlG  >klusiil !22_S
41484	soomlastest	soomlas	soomlane	12?10_S	PlEl	et	soomlastest =soomlas  (PlEl  >soomlane !12?10_S
41485	vormimoodustusega	moodustuse	vormi+moodustus	11_S	SgKom	et	vormimoodustusega =moodustuse  (SgKom  >vormi+moodustus !11_S
41486	klusiilidega	klusiili	klusiil	22_S	PlKom	et	klusiilidega =klusiili  (PlKom  >klusiil !22_S
41487	kahtlustada	kahtlusta	kahtlustama	27_V	Inf	et	kahtlustada =kahtlusta  (Inf  >kahtlustama !27_V
41490	maani	maa	maa	26_S	SgTer	et	maani =maa  (SgTer  >maa !26_S
41493	mõnigi	mõni	mõni	20_P	SgN^	et	mõnigi =mõni  (SgN^  >mõni !20_P
41494	kusagilt	kusagilt	kusagilt	41_D	ID	et	kusagilt =kusagilt  (ID  >kusagilt !41_D
41502	sõnatasand	tasand	sõna+tasand	02_S	SgN	et	sõnatasand =tasand  (SgN  >sõna+tasand !02_S
41516	morfeemide	morfeemi	morfeem	22_S	PlG	et	morfeemide =morfeemi  (PlG  >morfeem !22_S
41517	palatalisatsioon	palatalisatsioon	palatalisatsioon	22_S	SgN	et	palatalisatsioon =palatalisatsioon  (SgN  >palatalisatsioon !22_S
41519	konspektist	konspekti	konspekt	22_S	SgEl	et	konspektist =konspekti  (SgEl  >konspekt !22_S
41523	õppejõu	jõu	õppe+jõud	22_S	SgG	et	õppejõu =jõu  (SgG  >õppe+jõud !22_S
41526	murele	mure	mure	16_S	SgAll	et	murele =mure  (SgAll  >mure !16_S
41527	komponentidest	komponenti	komponent	22_S	PlEl	et	komponentidest =komponenti  (PlEl  >komponent !22_S
41557	pöörama	pööra	pöörama	29_V	Sup	et	pöörama =pööra  (Sup  >pöörama !29_V
41558	rahvusärkamisajal	aja	rahvus+ärkamis+aeg	22_S	SgAd	et	rahvusärkamisajal =aja  (SgAd  >rahvus+ärkamis+aeg !22_S
41560	poplauljad	laulja	pop+laulja	01_S	PlN	et	poplauljad =laulja  (PlN  >pop+laulja !01_S
41561	ühetaoline	taoline	ühe+taoline	12?10_A	SgN	et	ühetaoline =taoline  (SgN  >ühe+taoline !12?10_A
41565	tänased	tänase	tänane	10_A	PlN	et	tänased =tänase  (PlN  >tänane !10_A
41569	kohaneb	kohane	kohanema	27_V	IndPrSg3	et	kohaneb =kohane  (IndPrSg3  >kohanema !27_V
41573	eatükk	tükk	ea+tükk	22_S	SgN	et	eatükk =tükk  (SgN  >ea+tükk !22_S
41578	ast	ast	ast	22_S	SgN	et	ast =ast  (SgN  >ast !22_S
41580	iil	iil	iil	22_S	SgN	et	iil =iil  (SgN  >iil !22_S
41592	tasemeeksamiteks	eksami	taseme+eksam	02_S	PlTr	et	tasemeeksamiteks =eksami  (PlTr  >taseme+eksam !02_S
41607	parasiitsõnu	sõnu	para+siit+sõna	17_S	PlP	et	parasiitsõnu =sõnu  (PlP  >para+siit+sõna !17_S
41344	rõhub	rõhu	rõhuma	27_V	IndPrSg3	et	rõhub =rõhu  (IndPrSg3  >rõhuma !27_V
41348	kase	kase	kask	22_S	SgG	et	kase =kase  (SgG  >kask !22_S
41360	tagasõnad	sõna	taga+sõna	17_S	PlN	et	tagasõnad =sõna  (PlN  >taga+sõna !17_S
41363	koputab	koputa	koputama	27_V	IndPrSg3	et	koputab =koputa  (IndPrSg3  >koputama !27_V
41366	10jalutame	jaluta	jalutama	27_V	IndPrPl1	et	jalutame =jaluta  (IndPrPl1  >jalutama !27_V
41369	mast	mast	mast	22_S	SgN	et	mast =mast  (SgN  >mast !22_S
41376	ö-e	ö	ö	xx_Q	PlP	et	ö-e =ö  (PlP  >ö !xx_Q
41377	rühmitada	rühmita	rühmitama	27_V	Inf	et	rühmitada =rühmita  (Inf  >rühmitama !27_V
41379	loon	loo	looma	38_V	IndPrSg1	et	loon =loo  (IndPrSg1  >looma !38_V
41382	asendab	asenda	asendama	27_V	IndPrSg3	et	asendab =asenda  (IndPrSg3  >asendama !27_V
41383	objektiivsed	objektiivse	objektiivne	02_A	PlN	et	objektiivsed =objektiivse  (PlN  >objektiivne !02_A
41385	meilt	me	ma	00_P	PlAbl	et	meilt =me  (PlAbl  >ma !00_P
41392	huumori	huumori	huumor	02_S	SgG	et	huumori =huumori  (SgG  >huumor !02_S
41394	abivahend	vahend	abi+vahend	02_S	SgN	et	abivahend =vahend  (SgN  >abi+vahend !02_S
41397	keelenähtustega	nähtus	keele+nähtus	11~09_S	PlKom	et	keelenähtustega =nähtus  (PlKom  >keele+nähtus !11~09_S
41401	keeletasandite	tasandi	keele+tasand	02_S	PlG	et	keeletasandite =tasandi  (PlG  >keele+tasand !02_S
41402	hääldusvigu	vigu	hääldus+viga	18_S	PlP	et	hääldusvigu =vigu  (PlP  >hääldus+viga !18_S
41403	kirjalike	kirjalike	kirjalik	25_A	PlG	et	kirjalike =kirjalike  (PlG  >kirjalik !25_A
41413	kuske	kus	kusema	36_V	ImpPrPl2	et	kuske =kus  (ImpPrPl2  >kusema !36_V
41428	grammatikatasandi	tasandi	grammatika+tasand	02_S	SgG	et	grammatikatasandi =tasandi  (SgG  >grammatika+tasand !02_S
41430	lumememm	memm	lume+memm	22_S	SgN	et	lumememm =memm  (SgN  >lume+memm !22_S
41439	näitena	näite	näide	06_S	SgEs	et	näitena =näite  (SgEs  >näide !06_S
41442	lõpuvalikuvigu	vigu	lõpu+valiku+viga	18_S	PlP	et	lõpuvalikuvigu =vigu  (PlP  >lõpu+valiku+viga !18_S
41443	eelmisega	eelmise	eelmine	12?10_A	SgKom	et	eelmisega =eelmise  (SgKom  >eelmine !12?10_A
41447	lõpuvalikuveale	vea	lõpu+valiku+viga	18_S	SgAll	et	lõpuvalikuveale =vea  (SgAll  >lõpu+valiku+viga !18_S
41457	lumepalle	palle	lume+pall	22_S	PlP	et	lumepalle =palle  (PlP  >lume+pall !22_S
41471	tudengiks	tudengi	tudeng	02_S	SgTr	et	tudengiks =tudengi  (SgTr  >tudeng !02_S
41475	lähenebki	lähene	lähenema	27_V	IndPrSg3^	et	lähenebki =lähene  (IndPrSg3^  >lähenema !27_V
41476	grafeemid	grafeemi	grafeem	22_S	PlN	et	grafeemid =grafeemi  (PlN  >grafeem !22_S
41478	m-l	m	m	xx_Q	SgAd	et	m-l =m  (SgAd  >m !xx_Q
41495	vai	vai	vai	22_S	SgN	et	vai =vai  (SgN  >vai !22_S
41497	sõnajärjega	järje	sõna+järg	22_S	SgKom	et	sõnajärjega =järje  (SgKom  >sõna+järg !22_S
41498	ühendverb	verb	ühend+verb	22_S	SgN	et	ühendverb =verb  (SgN  >ühend+verb !22_S
41499	puhkudel	puhku	puhk	22_S	PlAd	et	puhkudel =puhku  (PlAd  >puhk !22_S
41504	e-kirjades	kirja	e-kiri	24_S	PlIn	et	e-kirjades =kirja  (PlIn  >e-kiri !24_S
41506	soomekeelne	keelne	soome+keelne	02_A	SgN	et	soomekeelne =keelne  (SgN  >soome+keelne !02_A
41507	välistada	välista	välistama	27_V	Inf	et	välistada =välista  (Inf  >välistama !27_V
41508	soomekeelsele	keelse	soome+keelne	02_A	SgAll	et	soomekeelsele =keelse  (SgAll  >soome+keelne !02_A
41509	vastele	vaste	vaste	06_S	SgAll	et	vastele =vaste  (SgAll  >vaste !06_S
41514	vabapäevad	päeva	vaba+päev	22_S	PlN	et	vabapäevad =päeva  (PlN  >vaba+päev !22_S
41518	terminite	termini	termin	02_S	PlG	et	terminite =termini  (PlG  >termin !02_S
41536	ameeriklaste	ameeriklas	ameeriklane	12_S	PlG	et	ameeriklaste =ameeriklas  (PlG  >ameeriklane !12_S
41555	rahvuskultuur	kultuur	rahvus+kultuur	22_S	SgN	et	rahvuskultuur =kultuur  (SgN  >rahvus+kultuur !22_S
41584	lindistada	lindista	lindistama	27_V	Inf	et	lindistada =lindista  (Inf  >lindistama !27_V
41585	eraõpilase	õpilase	era+õpilane	12_S	SgG	et	eraõpilase =õpilase  (SgG  >era+õpilane !12_S
41586	spontaanset	spontaanse	spontaanne	02_A	SgP	et	spontaanset =spontaanse  (SgP  >spontaanne !02_A
41591	läbis	läbi	läbima	27_V	IndIpfSg3	et	läbis =läbi  (IndIpfSg3  >läbima !27_V
41599	enesehinnang	hinnang	enese+hinnang	02_S	SgN	et	enesehinnang =hinnang  (SgN  >enese+hinnang !02_S
41601	kriitiline	kriitiline	kriitiline	12_A	SgN	et	kriitiline =kriitiline  (SgN  >kriitiline !12_A
41603	grammatikareegleid	reegle	grammatika+reegel	02_S	PlP	et	grammatikareegleid =reegle  (PlP  >grammatika+reegel !02_S
41605	grammatikavigu	vigu	grammatika+viga	18_S	PlP	et	grammatikavigu =vigu  (PlP  >grammatika+viga !18_S
41613	intonatsioon	intonatsioon	intonatsioon	22_S	SgN	et	intonatsioon =intonatsioon  (SgN  >intonatsioon !22_S
41614	lindilt	lindi	lint	22_S	SgAbl	et	lindilt =lindi  (SgAbl  >lint !22_S
41424	eestikeelses	keelse	eesti+keelne	02_A	SgIn	et	eestikeelses =keelse  (SgIn  >eesti+keelne !02_A
41433	laiendi	laiendi	laiend	02_S	SgG	et	laiendi =laiendi  (SgG  >laiend !02_S
41438	veaga	vea	viga	18_S	SgKom	et	veaga =vea  (SgKom  >viga !18_S
41445	nõrgale	nõrga	nõrk	22_A	SgAll	et	nõrgale =nõrga  (SgAll  >nõrk !22_A
41453	üllatusin	üllatu	üllatuma	27_V	IndIpfSg1	et	üllatusin =üllatu  (IndIpfSg1  >üllatuma !27_V
41460	peletama	peleta	peletama	27_V	Sup	et	peletama =peleta  (Sup  >peletama !27_V
41462	vormivalikuveaga	vea	vormi+valiku+viga	18_S	SgKom	et	vormivalikuveaga =vea  (SgKom  >vormi+valiku+viga !18_S
41480	komasid	koma	koma	17_S	PlP	et	komasid =koma  (PlP  >koma !17_S
41488	vormimoodustus	moodustus	vormi+moodustus	11_S	SgN	et	vormimoodustus =moodustus  (SgN  >vormi+moodustus !11_S
41489	kahtlane	kahtlane	kahtlane	12?10_A	SgN	et	kahtlane =kahtlane  (SgN  >kahtlane !12?10_A
41496	soomlastes	soomlas	soomlane	12?10_S	PlIn	et	soomlastes =soomlas  (PlIn  >soomlane !12?10_S
41512	arvad	arva	arvama	29_V	IndPrSg2	et	arvad =arva  (IndPrSg2  >arvama !29_V
41513	morganist	morganist	morganist	22_S	SgN	et	morganist =morganist  (SgN  >morganist !22_S
41520	tulevikutöös	töö	tuleviku+töö	26_S	SgIn	et	tulevikutöös =töö  (SgIn  >tuleviku+töö !26_S
41525	kaebas	kaeba	kaebama	29_V	IndIpfSg3	et	kaebas =kaeba  (IndIpfSg3  >kaebama !29_V
41529	progress	progress	progress	22_S	SgN	et	progress =progress  (SgN  >progress !22_S
41532	arhailist	arhailis	arhailine	12?10_A	SgP	et	arhailist =arhailis  (SgP  >arhailine !12?10_A
41534	rahvatoiduks	toidu	rahva+toit	22_S	SgTr	et	rahvatoiduks =toidu  (SgTr  >rahva+toit !22_S
41535	hamburgereid	hamburgere	hamburger	02_S	PlP	et	hamburgereid =hamburgere  (PlP  >hamburger !02_S
41540	essees	essee	essee	26_S	SgIn	et	essees =essee  (SgIn  >essee !26_S
41546	temperamentne	temperamentne	temperamentne	02_A	SgN	et	temperamentne =temperamentne  (SgN  >temperamentne !02_A
41551	rahvalaulule	laulu	rahva+laul	22_S	SgAll	et	rahvalaulule =laulu  (SgAll  >rahva+laul !22_S
41552	edasisele	edasise	edasine	12_A	SgAll	et	edasisele =edasise  (SgAll  >edasine !12_A
41554	üldisele	üldise	üldine	10~12_A	SgAll	et	üldisele =üldise  (SgAll  >üldine !10~12_A
41559	laulusse	laulu	laul	22_S	SgIll	et	laulusse =laulu  (SgIll  >laul !22_S
41575	tas	ta	ta	00_P	SgIn	et	tas =ta  (SgIn  >ta !00_P
41577	unud	unu	unuma	27_V	IndPrSg2	et	unud =unu  (IndPrSg2  >unuma !27_V
41590	intensiivkursustel	kursus	intensiiv+kursus	11~09_S	PlAd	et	intensiivkursustel =kursus  (PlAd  >intensiiv+kursus !11~09_S
41597	loeme	loe	lugema	28_V	IndPrPl1	et	loeme =loe  (IndPrPl1  >lugema !28_V
41598	õpimotivatsioon	motivatsioon	õpi+motivatsioon	22_S	SgN	et	õpimotivatsioon =motivatsioon  (SgN  >õpi+motivatsioon !22_S
41600	motivatsioon	motivatsioon	motivatsioon	22_S	SgN	et	motivatsioon =motivatsioon  (SgN  >motivatsioon !22_S
41604	grammatikaülesandeid	ande	grammatika+üles+anne	06_S	PlP	et	grammatikaülesandeid =ande  (PlP  >grammatika+üles+anne !06_S
41606	sidesõnadest	sõna	side+sõna	17_S	PlEl	et	sidesõnadest =sõna  (PlEl  >side+sõna !17_S
41616	sõiduks	sõidu	sõit	22_S	SgTr	et	sõiduks =sõidu  (SgTr  >sõit !22_S
41617	väljume	välju	väljuma	27_V	IndPrPl1	et	väljume =välju  (IndPrPl1  >väljuma !27_V
41619	tagastame	tagasta	tagastama	27_V	IndPrPl1	et	tagastame =tagasta  (IndPrPl1  >tagastama !27_V
41627	helistaks	helista	helistama	27_V	KndPrPs	et	helistaks =helista  (KndPrPs  >helistama !27_V
41631	sõidus	sõidu	sõit	22_S	SgIn	et	sõidus =sõidu  (SgIn  >sõit !22_S
41639	hääldab	häälda	hääldama	27_V	IndPrSg3	et	hääldab =häälda  (IndPrSg3  >hääldama !27_V
41642	ühesuguse	suguse	ühe+sugune	10_A	SgG	et	ühesuguse =suguse  (SgG  >ühe+sugune !10_A
41644	loomaaedomastava	omastava	looma+aed+omastav	02_A	SgG	et	loomaaedomastava =omastava  (SgG  >looma+aed+omastav !02_A
41647	torusid	toru	toru	17_S	PlP	et	torusid =toru  (PlP  >toru !17_S
41648	ehitusfirmas	firma	ehitus+firma	16_S	SgIn	et	ehitusfirmas =firma  (SgIn  >ehitus+firma !16_S
41649	sõnaühendit	ühendi	sõna+ühend	02_S	SgP	et	sõnaühendit =ühendi  (SgP  >sõna+ühend !02_S
41659	kaudse	kaudse	kaudne	02_A	SgG	et	kaudse =kaudse  (SgG  >kaudne !02_A
41660	asume	asu	asuma	27_V	IndPrPl1	et	asume =asu  (IndPrPl1  >asuma !27_V
41668	keraamilise	keraamilise	keraamiline	12_A	SgG	et	keraamilise =keraamilise  (SgG  >keraamiline !12_A
41676	nöps	nöps	nöps	22_S	SgN	et	nöps =nöps  (SgN  >nöps !22_S
41679	ühesugused	suguse	ühe+sugune	10_A	PlN	et	ühesugused =suguse  (PlN  >ühe+sugune !10_A
41685	kokku-ja	ja	kokku-ja	41_J	ID	et	kokku-ja =ja  (ID  >kokku-ja !41_J
41690	sõidukist	sõiduki	sõiduk	02_S	SgEl	et	sõidukist =sõiduki  (SgEl  >sõiduk !02_S
41696	väljuda	välju	väljuma	27_V	Inf	et	väljuda =välju  (Inf  >väljuma !27_V
41705	olemasolevatest	oleva	olemas+olev	02_A	PlEl	et	olemasolevatest =oleva  (PlEl  >olemas+olev !02_A
41440	seestütlevat	ütleva	seest+ütlev	02_A	SgP	et	seestütlevat =ütleva  (SgP  >seest+ütlev !02_A
41444	kardas	karda	kardama	29_V	IndIpfSg3	et	kardas =karda  (IndIpfSg3  >kardama !29_V
41446	sisseütleva	ütleva	sisse+ütlev	02_A	SgG	et	sisseütleva =ütleva  (SgG  >sisse+ütlev !02_A
41448	näites	näite	näide	06_S	SgIn	et	näites =näite  (SgIn  >näide !06_S
41449	vormile	vormi	vorm	22_S	SgAll	et	vormile =vormi  (SgAll  >vorm !22_S
41456	uusmoodustiste	moodustis	uus+moodustis	11_S	PlG	et	uusmoodustiste =moodustis  (PlG  >uus+moodustis !11_S
41458	lumepall	pall	lume+pall	22_S	SgN	et	lumepall =pall  (SgN  >lume+pall !22_S
41459	keeletasandile	tasandi	keele+tasand	02_S	SgAll	et	keeletasandile =tasandi  (SgAll  >keele+tasand !02_S
41464	skulptuurilt	skulptuuri	skulptuur	22_S	SgAbl	et	skulptuurilt =skulptuuri  (SgAbl  >skulptuur !22_S
41465	kinnistub	kinnistu	kinnistuma	27_V	IndPrSg3	et	kinnistub =kinnistu  (IndPrSg3  >kinnistuma !27_V
41466	pastakaga	pastaka	pastakas	02_S	SgKom	et	pastakaga =pastaka  (SgKom  >pastakas !02_S
41470	vahetusüliõpilasena	õpilase	vahetus+üli+õpilane	12_S	SgEs	et	vahetusüliõpilasena =õpilase  (SgEs  >vahetus+üli+õpilane !12_S
41477	kirjavahemärgid	märgi	kirja+vahe+märk	22_S	PlN	et	kirjavahemärgid =märgi  (PlN  >kirja+vahe+märk !22_S
41481	analüüsima	analüüsi	analüüsima	28_V	Sup	et	analüüsima =analüüsi  (Sup  >analüüsima !28_V
41500	seestütlev	ütlev	seest+ütlev	02_A	SgN	et	seestütlev =ütlev  (SgN  >seest+ütlev !02_A
41501	välistab	välista	välistama	27_V	IndPrSg3	et	välistab =välista  (IndPrSg3  >välistama !27_V
41511	vaiba	vaiba	vaip	22_S	SgG	et	vaiba =vaiba  (SgG  >vaip !22_S
41515	terminid	termini	termin	02_S	PlN	et	terminid =termini  (PlN  >termin !02_S
41521	unustab	unusta	unustama	27_V	IndPrSg3	et	unustab =unusta  (IndPrSg3  >unustama !27_V
41522	olemasolust	olu	olemas+olu	17_S	SgEl	et	olemasolust =olu  (SgEl  >olemas+olu !17_S
41524	mait	mait	mait	22_S	SgN	et	mait =mait  (SgN  >mait !22_S
41528	säilitame	säilita	säilitama	27_V	IndPrPl1	et	säilitame =säilita  (IndPrPl1  >säilitama !27_V
41530	toimima	toimi	toimima	28_V	Sup	et	toimima =toimi  (Sup  >toimima !28_V
41537	eluviisile	viisi	elu+viis	22_S	SgAll	et	eluviisile =viisi  (SgAll  >elu+viis !22_S
41543	pühalik	pühalik	pühalik	25_A	SgN	et	pühalik =pühalik  (SgN  >pühalik !25_A
41547	valjud	valju	vali	24_A	PlN	et	valjud =valju  (PlN  >vali !24_A
41548	üldised	üldise	üldine	10~12_A	PlN	et	üldised =üldise  (PlN  >üldine !10~12_A
41549	viimsele	viimse	viimne	02_A	SgAll	et	viimsele =viimse  (SgAll  >viimne !02_A
41550	värvingut	värvingu	värving	02_S	SgP	et	värvingut =värvingu  (SgP  >värving !02_S
41553	okupatsioonid	okupatsiooni	okupatsioon	22_S	PlN	et	okupatsioonid =okupatsiooni  (PlN  >okupatsioon !22_S
41562	kaotamas	kaota	kaotama	27_V	SupIn	et	kaotamas =kaota  (SupIn  >kaotama !27_V
41563	ansambleid	ansamble	ansambel	02_S	PlP	et	ansambleid =ansamble  (PlP  >ansambel !02_S
41564	ajajärgu	järgu	aja+järk	22_S	SgG	et	ajajärgu =järgu  (SgG  >aja+järk !22_S
41567	esitleb	esitle	esitlema	27_V	IndPrSg3	et	esitleb =esitle  (IndPrSg3  >esitlema !27_V
41588	edaspidist	pidis	edas+pidine	10_A	SgP	et	edaspidist =pidis  (SgP  >edas+pidine !10_A
41593	ühised	ühise	ühine	10_A	PlN	et	ühised =ühise  (PlN  >ühine !10_A
41596	tööpäev	päev	töö+päev	22_S	SgN	et	tööpäev =päev  (SgN  >töö+päev !22_S
41611	probleemsed	probleemse	probleemne	02_A	PlN	et	probleemsed =probleemse  (PlN  >probleemne !02_A
41612	jõu-	jõu	jõud	22_S	SgG	et	jõu- =jõu  (SgG  >jõud !22_S
41623	õudne	õudne	õudne	02_A	SgN	et	õudne =õudne  (SgN  >õudne !02_A
41624	haamri	haamri	haamer	02_S	SgG	et	haamri =haamri  (SgG  >haamer !02_S
41628	solvusin	solvu	solvuma	27_V	IndIpfSg1	et	solvusin =solvu  (IndIpfSg1  >solvuma !27_V
41630	tulek	tulek	tulek	02_S	SgN	et	tulek =tulek  (SgN  >tulek !02_S
41641	pearõhk	rõhk	pea+rõhk	22_S	SgN	et	pearõhk =rõhk  (SgN  >pea+rõhk !22_S
41643	veepargi	pargi	vee+park	22_S	SgG	et	veepargi =pargi  (SgG  >vee+park !22_S
41646	assotsieerub	assotsieeru	assotsieeruma	27_V	IndPrSg3	et	assotsieerub =assotsieeru  (IndPrSg3  >assotsieeruma !27_V
41663	keraamiline	keraamiline	keraamiline	12_A	SgN	et	keraamiline =keraamiline  (SgN  >keraamiline !12_A
41680	kokkukirjutamises	kirjutamise	kokku+kirjutamine	12_S	SgIn	et	kokkukirjutamises =kirjutamise  (SgIn  >kokku+kirjutamine !12_S
41682	täppidega	täppi	täpp	22_S	PlKom	et	täppidega =täppi  (PlKom  >täpp !22_S
41687	maksmast	maks	maksma	32_V	SupEl	et	maksmast =maks  (SupEl  >maksma !32_V
41697	takse	takse	taks	22_S	PlP	et	takse =takse  (PlP  >taks !22_S
41698	jõuluajal	aja	jõulu+aeg	22_S	SgAd	et	jõuluajal =aja  (SgAd  >jõulu+aeg !22_S
41701	põhisõnaga	sõna	põhi+sõna	17_S	SgKom	et	põhisõnaga =sõna  (SgKom  >põhi+sõna !17_S
41719	eripärad	pära	eri+pära	17_S	PlN	et	eripärad =pära  (PlN  >eri+pära !17_S
41492	välismaalasele	maalase	välis+maalane	12?10_S	SgAll	et	välismaalasele =maalase  (SgAll  >välis+maalane !12?10_S
41503	stiilivead	vea	stiili+viga	18_S	PlN	et	stiilivead =vea  (PlN  >stiili+viga !18_S
41505	sõnavead	vea	sõna+viga	18_S	PlN	et	sõnavead =vea  (PlN  >sõna+viga !18_S
41510	interjöörist	interjööri	interjöör	22_S	SgEl	et	interjöörist =interjööri  (SgEl  >interjöör !22_S
41531	üldkultuur	kultuur	üld+kultuur	22_S	SgN	et	üldkultuur =kultuur  (SgN  >üld+kultuur !22_S
41533	ameeriklased	ameeriklase	ameeriklane	12_S	PlN	et	ameeriklased =ameeriklase  (PlN  >ameeriklane !12_S
41538	katoliiklased	katoliiklase	katoliiklane	12?10_S	PlN	et	katoliiklased =katoliiklase  (PlN  >katoliiklane !12?10_S
41539	sektidesse	sekti	sekt	22_S	PlIll	et	sektidesse =sekti  (PlIll  >sekt !22_S
41541	mõtiskleda	mõtiskle	mõtisklema	27_V	Inf	et	mõtiskleda =mõtiskle  (Inf  >mõtisklema !27_V
41542	iseäralik	äralik	ise+äralik	25_A	SgN	et	iseäralik =äralik  (SgN  >ise+äralik !25_A
41544	omadest	oma	oma	17_A	PlEl	et	omadest =oma  (PlEl  >oma !17_A
41545	kurvameelse	meelse	kurva+meelne	02_A	SgG	et	kurvameelse =meelse  (SgG  >kurva+meelne !02_A
41556	rahvuslikule	rahvusliku	rahvuslik	25_A	SgAll	et	rahvuslikule =rahvusliku  (SgAll  >rahvuslik !25_A
41566	üldkultuurile	kultuuri	üld+kultuur	22_S	SgAll	et	üldkultuurile =kultuuri  (SgAll  >üld+kultuur !22_S
41568	võistlustele	võistlus	võistlus	11~09_S	PlAll	et	võistlustele =võistlus  (PlAll  >võistlus !11~09_S
41570	hävitab	hävita	hävitama	27_V	IndPrSg3	et	hävitab =hävita  (IndPrSg3  >hävitama !27_V
41571	entusiastidele	entusiasti	entusiast	22_S	PlAll	et	entusiastidele =entusiasti  (PlAll  >entusiast !22_S
41572	kaua-kaua	kaua	kaua-kaua	41_D	ID	et	kaua-kaua =kaua  (ID  >kaua-kaua !41_D
41574	oo	oo	oo	41_I	ID	et	oo =oo  (ID  >oo !41_I
41576	uur	uur	uur	22_S	SgN	et	uur =uur  (SgN  >uur !22_S
41579	ih	ih	ih	41_I	ID	et	ih =ih  (ID  >ih !41_I
41581	uru	uru	urg	22_S	SgG	et	uru =uru  (SgG  >urg !22_S
41582	ea	ea	iga	18_S	SgG	et	ea =ea  (SgG  >iga !18_S
41583	uu	uu	uu	41_I	ID	et	uu =uu  (ID  >uu !41_I
41587	novembri	novembri	november	02_S	SgG	et	novembri =novembri  (SgG  >november !02_S
41589	õpiku	õpiku	õpik	02_S	SgG	et	õpiku =õpiku  (SgG  >õpik !02_S
41594	hakkasingi	hakka	hakkama	29_V	IndIpfSg1^	et	hakkasingi =hakka  (IndIpfSg1^  >hakkama !29_V
41595	päevade	päeva	päev	22_S	PlG	et	päevade =päeva  (PlG  >päev !22_S
41602	hädasti	hädasti	hädasti	41_D	ID	et	hädasti =hädasti  (ID  >hädasti !41_D
41609	lihtlaused	lause	liht+lause	06_S	PlN	et	lihtlaused =lause  (PlN  >liht+lause !06_S
41610	sagedased	sagedase	sagedane	12_A	PlN	et	sagedased =sagedase  (PlN  >sagedane !12_A
41620	elektripirnid	pirni	elektri+pirn	22_S	PlN	et	elektripirnid =pirni  (PlN  >elektri+pirn !22_S
41621	veenäiteid	näite	vee+näide	06_S	PlP	et	veenäiteid =näite  (PlP  >vee+näide !06_S
41625	vannas	vannas	vannas	07_S	SgN	et	vannas =vannas  (SgN  >vannas !07_S
41629	üheksandani	üheksanda	üheksas	02_O	SgTer	et	üheksandani =üheksanda  (SgTer  >üheksas !02_O
41638	hääldusvead	vea	hääldus+viga	18_S	PlN	et	hääldusvead =vea  (PlN  >hääldus+viga !18_S
41650	bussisõidu	sõidu	bussi+sõit	22_S	SgG	et	bussisõidu =sõidu  (SgG  >bussi+sõit !22_S
41651	lapimaalt	maa	lapi+maa	26_S	SgAbl	et	lapimaalt =maa  (SgAbl  >lapi+maa !26_S
41652	üheteistkümnest	kümnes	ühe+teist+kümnene	10~12_AS	SgP	et	üheteistkümnest =kümnes  (SgP  >ühe+teist+kümnene !10~12_AS
41654	kuuenda	kuuenda	kuues	02_O	SgG	et	kuuenda =kuuenda  (SgG  >kuues !02_O
41655	reegli	reegli	reegel	02_S	SgG	et	reegli =reegli  (SgG  >reegel !02_S
41658	öeldise	öeldise	öeldis	11~09_S	SgG	et	öeldise =öeldise  (SgG  >öeldis !11~09_S
41661	tõlkelaenud	laenu	tõlke+laen	22_S	PlN	et	tõlkelaenud =laenu  (PlN  >tõlke+laen !22_S
41664	vepslased	vepslase	vepslane	12?10_S	PlN	et	vepslased =vepslase  (PlN  >vepslane !12?10_S
41665	läbime	läbi	läbima	27_V	IndPrPl1	et	läbime =läbi  (IndPrPl1  >läbima !27_V
41666	polaarjoone	joone	polaar+joon	13_S	SgG	et	polaarjoone =joone  (SgG  >polaar+joon !13_S
41681	tähe	tähe	täht	22_S	SgG	et	tähe =tähe  (SgG  >täht !22_S
41686	lahkukirjutamises	kirjutamise	lahku+kirjutamine	12_S	SgIn	et	lahkukirjutamises =kirjutamise  (SgIn  >lahku+kirjutamine !12_S
41702	öeldis	öeldis	öeldis	11~09_S	SgN	et	öeldis =öeldis  (SgN  >öeldis !11~09_S
41721	liigsed	liigse	liigne	02_A	PlN	et	liigsed =liigse  (PlN  >liigne !02_A
41732	ebakorrektsed	korrektse	eba+korrektne	02_A	PlN	et	ebakorrektsed =korrektse  (PlN  >eba+korrektne !02_A
41738	tangud-	tangu	tang	22_S	PlN	et	tangud- =tangu  (PlN  >tang !22_S
41741	pärlid	pärli	pärl	02_S	PlN	et	pärlid =pärli  (PlN  >pärl !02_S
41762	purustada	purusta	purustama	27_V	Inf	et	purustada =purusta  (Inf  >purustama !27_V
41608	emotsionaalseks	emotsionaalse	emotsionaalne	02_A	SgTr	et	emotsionaalseks =emotsionaalse  (SgTr  >emotsionaalne !02_A
41618	võrru	võrru	võru	17_S	SgAdt	et	võrru =võrru  (SgAdt  >võru !17_S
41622	torud	toru	toru	17_S	PlN	et	torud =toru  (PlN  >toru !17_S
41634	bassein	bassein	bassein	22_S	SgN	et	bassein =bassein  (SgN  >bassein !22_S
41635	sõidaksin	sõida	sõitma	34_V	KndPrSg1	et	sõidaksin =sõida  (KndPrSg1  >sõitma !34_V
41653	neljateistkümnest	kümnes	nelja+teist+kümnene	10~12_AS	SgP	et	neljateistkümnest =kümnes  (SgP  >nelja+teist+kümnene !10~12_AS
41656	täiendi	täiendi	täiend	02_S	SgG	et	täiendi =täiendi  (SgG  >täiend !02_S
41657	grammatikareeglite	reegli	grammatika+reegel	02_S	PlG	et	grammatikareeglite =reegli  (PlG  >grammatika+reegel !02_S
41662	plaat	plaat	plaat	22_S	SgN	et	plaat =plaat  (SgN  >plaat !22_S
41667	valmistun	valmistu	valmistuma	27_V	IndPrSg1	et	valmistun =valmistu  (IndPrSg1  >valmistuma !27_V
41669	plaadiga	plaadi	plaat	22_S	SgKom	et	plaadiga =plaadi  (SgKom  >plaat !22_S
41671	etteütlustest	ütlus	ette+ütlus	11~09_S	PlEl	et	etteütlustest =ütlus  (PlEl  >ette+ütlus !11~09_S
41672	keelekursustele	kursus	keele+kursus	11~09_S	PlAll	et	keelekursustele =kursus  (PlAll  >keele+kursus !11~09_S
41673	minekut	mineku	minek	02_S	SgP	et	minekut =mineku  (SgP  >minek !02_S
41689	seesütlev	ütlev	sees+ütlev	02_A	SgN	et	seesütlev =ütlev  (SgN  >sees+ütlev !02_A
41691	hamstrid	hamstri	hamster	02_S	PlN	et	hamstrid =hamstri  (PlN  >hamster !02_S
41693	trepis	trepi	trepp	22_S	SgIn	et	trepis =trepi  (SgIn  >trepp !22_S
41694	tüüpilise	tüüpilise	tüüpiline	12_A	SgG	et	tüüpilise =tüüpilise  (SgG  >tüüpiline !12_A
41704	otsetõlkes	tõlke	otse+tõlge	06_S	SgIn	et	otsetõlkes =tõlke  (SgIn  >otse+tõlge !06_S
41707	välde	välde	välde	06_S	SgN	et	välde =välde  (SgN  >välde !06_S
41715	konstruktsioonilt	konstruktsiooni	konstruktsioon	22_S	SgAbl	et	konstruktsioonilt =konstruktsiooni  (SgAbl  >konstruktsioon !22_S
41716	vajalikuna	vajaliku	vajalik	25_A	SgEs	et	vajalikuna =vajaliku  (SgEs  >vajalik !25_A
41727	lubja	lubja	lubi	24_S	SgG	et	lubja =lubja  (SgG  >lubi !24_S
41737	rõuged-	rõuge	rõuge	01_S	PlN	et	rõuged- =rõuge  (PlN  >rõuge !01_S
41740	vanaaegne	aegne	vana+aegne	02_A	SgN	et	vanaaegne =aegne  (SgN  >vana+aegne !02_A
41746	pöördetunnus	tunnus	pöörde+tunnus	09_S	SgN	et	pöördetunnus =tunnus  (SgN  >pöörde+tunnus !09_S
41749	kvalifikatsioonikeskus	keskus	kvalifikatsiooni+keskus	11~09_S	SgN	et	kvalifikatsioonikeskus =keskus  (SgN  >kvalifikatsiooni+keskus !11~09_S
41755	atest	ate	att	22_S	PlEl	et	atest =ate  (PlEl  >att !22_S
41763	rahvaid	rahva	rahvas	07_S	PlP	et	rahvaid =rahva  (PlP  >rahvas !07_S
41766	sõdadel	sõda	sõda	18_S	PlAd	et	sõdadel =sõda  (PlAd  >sõda !18_S
41771	põlvili	põlvili	põlvili	41_D	ID	et	põlvili =põlvili  (ID  >põlvili !41_D
41772	sirbid	sirbi	sirp	22_S	PlN	et	sirbid =sirbi  (PlN  >sirp !22_S
41801	omajagu	omajagu	oma+jagu	41_D	ID	et	omajagu =omajagu  (ID  >oma+jagu !41_D
41805	tõsiseltvõetava	võetava	tõsiselt+võetav	02_A	SgG	et	tõsiseltvõetava =võetava  (SgG  >tõsiselt+võetav !02_A
41811	kinolinal	lina	kino+lina	17_S	SgAd	et	kinolinal =lina  (SgAd  >kino+lina !17_S
41818	nagunii	nagunii	nagu+nii	41_D	ID	et	nagunii =nagunii  (ID  >nagu+nii !41_D
41819	armeele	armee	armee	26_S	SgAll	et	armeele =armee  (SgAll  >armee !26_S
41820	arvamusküljel	külje	arvamus+külg	22_S	SgAd	et	arvamusküljel =külje  (SgAd  >arvamus+külg !22_S
41822	filmitegijad	tegija	filmi+tegija	01_S	PlN	et	filmitegijad =tegija  (PlN  >filmi+tegija !01_S
41824	pagulaskirjandust	kirjandus	pagulas+kirjandus	11_S	SgP	et	pagulaskirjandust =kirjandus  (SgP  >pagulas+kirjandus !11_S
41827	klassikuteks	klassiku	klassik	02_S	PlTr	et	klassikuteks =klassiku  (PlTr  >klassik !02_S
41831	sõjavägi	vägi	sõja+vägi	21_S	SgN	et	sõjavägi =vägi  (SgN  >sõja+vägi !21_S
41834	jagati	jaga	jagama	27_V	IndIpfIps	et	jagati =jaga  (IndIpfIps  >jagama !27_V
41835	vabadusvõitlejatele	võitleja	vabadus+võitleja	01_SA	PlAll	et	vabadusvõitlejatele =võitleja  (PlAll  >vabadus+võitleja !01_SA
41841	väed	väe	vägi	21_S	PlN	et	väed =väe  (PlN  >vägi !21_S
41846	jaotas	jaota	jaotama	27_V	IndIpfSg3	et	jaotas =jaota  (IndIpfSg3  >jaotama !27_V
41848	okupeeriti	okupeeri	okupeerima	28_V	IndIpfIps	et	okupeeriti =okupeeri  (IndIpfIps  >okupeerima !28_V
41855	muusikapäevad	päeva	muusika+päev	22_S	PlN	et	muusikapäevad =päeva  (PlN  >muusika+päev !22_S
41861	esindusorganiks	organi	esindus+organ	02_S	SgTr	et	esindusorganiks =organi  (SgTr  >esindus+organ !02_S
41865	eluks	elu	elu	17_S	SgTr	et	eluks =elu  (SgTr  >elu !17_S
41870	astmele	astme	aste	05_S	SgAll	et	astmele =astme  (SgAll  >aste !05_S
41872	kirjandusklassikas	klassika	kirjandus+klassika	01_S	SgIn	et	kirjandusklassikas =klassika  (SgIn  >kirjandus+klassika !01_S
41615	valmistan	valmista	valmistama	27_V	IndPrSg1	et	valmistan =valmista  (IndPrSg1  >valmistama !27_V
41626	detsembris	detsembri	detsember	02_S	SgIn	et	detsembris =detsembri  (SgIn  >detsember !02_S
41632	ringist	ringi	ring	22_S	SgEl	et	ringist =ringi  (SgEl  >ring !22_S
41633	kaheksandani	kaheksanda	kaheksas	02_O	SgTer	et	kaheksandani =kaheksanda  (SgTer  >kaheksas !02_O
41636	karjalased	karjalase	karjalane	12_S	PlN	et	karjalased =karjalase  (PlN  >karjalane !12_S
41637	soomlastega	soomlas	soomlane	12?10_S	PlKom	et	soomlastega =soomlas  (PlKom  >soomlane !12?10_S
41640	esisilp	silp	esi+silp	22_S	SgN	et	esisilp =silp  (SgN  >esi+silp !22_S
41645	kordadel	korda	kord	22_S	PlAd	et	kordadel =korda  (PlAd  >kord !22_S
41670	helistaksin	helista	helistama	27_V	KndPrSg1	et	helistaksin =helista  (KndPrSg1  >helistama !27_V
41674	põhilisteks	põhilis	põhiline	12_A	PlTr	et	põhilisteks =põhilis  (PlTr  >põhiline !12_A
41675	vormidest	vormi	vorm	22_S	PlEl	et	vormidest =vormi  (PlEl  >vorm !22_S
41677	tähelepanematusest	panematuse	tähele+panematus	11?09_S	SgEl	et	tähelepanematusest =panematuse  (SgEl  >tähele+panematus !11?09_S
41678	häälikud	hääliku	häälik	02_S	PlN	et	häälikud =hääliku  (PlN  >häälik !02_S
41683	järgmisest	järgmise	järgmine	12?10_A	SgEl	et	järgmisest =järgmise  (SgEl  >järgmine !12?10_A
41684	sõidukis	sõiduki	sõiduk	02_S	SgIn	et	sõidukis =sõiduki  (SgIn  >sõiduk !02_S
41688	ühissõiduk	sõiduk	ühis+sõiduk	02_S	SgN	et	ühissõiduk =sõiduk  (SgN  >ühis+sõiduk !02_S
41692	purgis	purgi	purk	22_S	SgIn	et	purgis =purgi  (SgIn  >purk !22_S
41695	orienteerudes	orienteeru	orienteeruma	27_V	Ger	et	orienteerudes =orienteeru  (Ger  >orienteeruma !27_V
41699	süüdatakse	süüda	süütama	29_V	IndPrIps	et	süüdatakse =süüda  (IndPrIps  >süütama !29_V
41700	prefiks	prefiks	prefiks	02_S	SgN	et	prefiks =prefiks  (SgN  >prefiks !02_S
41703	verbile	verbi	verb	22_S	SgAll	et	verbile =verbi  (SgAll  >verb !22_S
41708	sukk	sukk	sukk	22_S	SgN	et	sukk =sukk  (SgN  >sukk !22_S
41709	välteid	välte	välde	06_S	PlP	et	välteid =välte  (PlP  >välde !06_S
41711	lausemoodustuses	moodustuse	lause+moodustus	11_S	SgIn	et	lausemoodustuses =moodustuse  (SgIn  >lause+moodustus !11_S
41713	ike	ike	ike	06_S	SgN	et	ike =ike  (SgN  >ike !06_S
41717	kordub	kordu	korduma	27_V	IndPrSg3	et	kordub =kordu  (IndPrSg3  >korduma !27_V
41718	käändele	käände	kääne	06_S	SgAll	et	käändele =käände  (SgAll  >kääne !06_S
41722	tunta	tun	tundma	34_V	IndPrIps_	et	tunta =tun  (IndPrIps_  >tundma !34_V
41723	kaubalaevad	laeva	kauba+laev	22_S	PlN	et	kaubalaevad =laeva  (PlN  >kauba+laev !22_S
41729	tööriietusel	riietuse	töö+riietus	11_S	SgAd	et	tööriietusel =riietuse  (SgAd  >töö+riietus !11_S
41743	i-ga	i	i	xx_Q	SgKom	et	i-ga =i  (SgKom  >i !xx_Q
41744	viitamaks	viita	viitama	29_V	SupTr	et	viitamaks =viita  (SupTr  >viitama !29_V
41748	eksami-	eksami	eksam	02_S	SgG	et	eksami- =eksami  (SgG  >eksam !02_S
41752	ses	se	see	00_P	SgIn	et	ses =se  (SgIn  >see !00_P
41754	se11e	see	see	00_P	SgN	et	see =see  (SgN  >see !00_P
41757	kirjandusteose	teose	kirjandus+teos	09_S	SgG	et	kirjandusteose =teose  (SgG  >kirjandus+teos !09_S
41758	kivikase	kase	kivi+kask	22_S	SgG	et	kivikase =kase  (SgG  >kivi+kask !22_S
41765	tehnikal	tehnika	tehnika	01_S	SgAd	et	tehnikal =tehnika  (SgAd  >tehnika !01_S
41767	revolutsioonidel	revolutsiooni	revolutsioon	22_S	PlAd	et	revolutsioonidel =revolutsiooni  (PlAd  >revolutsioon !22_S
41787	minus	minu	mina	00_P	SgIn	et	minus =minu  (SgIn  >mina !00_P
41791	tulevikustsenaarium	stsenaarium	tuleviku+stsenaarium	19~02_S	SgN	et	tulevikustsenaarium =stsenaarium  (SgN  >tuleviku+stsenaarium !19~02_S
41793	kinosaal	saal	kino+saal	22_S	SgN	et	kinosaal =saal  (SgN  >kino+saal !22_S
41794	aplodeeris	aplodeeri	aplodeerima	28_V	IndIpfSg3	et	aplodeeris =aplodeeri  (IndIpfSg3  >aplodeerima !28_V
41796	liigutuspisarat	pisara	liigutus+pisar	02_S	SgP	et	liigutuspisarat =pisara  (SgP  >liigutus+pisar !02_S
41806	ida-virumaalt	maa	ida-viru+maa	26_S	SgAbl	et	ida-virumaalt =maa  (SgAbl  >ida-viru+maa !26_S
41808	koolipoisil	poisi	kooli+poiss	23?22_S	SgAd	et	koolipoisil =poisi  (SgAd  >kooli+poiss !23?22_S
41813	väärtushinnangu	hinnangu	väärtus+hinnang	02_S	SgG	et	väärtushinnangu =hinnangu  (SgG  >väärtus+hinnang !02_S
41825	pagulaskirjandus	kirjandus	pagulas+kirjandus	11_S	SgN	et	pagulaskirjandus =kirjandus  (SgN  >pagulas+kirjandus !11_S
41826	pagulasluuletajad	luuletaja	pagulas+luuletaja	01_S	PlN	et	pagulasluuletajad =luuletaja  (PlN  >pagulas+luuletaja !01_S
41828	klassikute	klassiku	klassik	02_S	PlG	et	klassikute =klassiku  (PlG  >klassik !02_S
41832	rõdult	rõdu	rõdu	17_S	SgAbl	et	rõdult =rõdu  (SgAbl  >rõdu !17_S
41852	vabariikidel	riiki	vaba+riik	22_S	PlAd	et	vabariikidel =riiki  (PlAd  >vaba+riik !22_S
41853	aktiviseerus	aktiviseeru	aktiviseeruma	27_V	IndIpfSg3	et	aktiviseerus =aktiviseeru  (IndIpfSg3  >aktiviseeruma !27_V
41706	tavadest	tava	tava	17_S	PlEl	et	tavadest =tava  (PlEl  >tava !17_S
41710	algetapil	etapi	alg+etapp	22_S	SgAd	et	algetapil =etapi  (SgAd  >alg+etapp !22_S
41712	inimesteks	inimes	inimene	12_S	PlTr	et	inimesteks =inimes  (PlTr  >inimene !12_S
41714	väsitada	väsita	väsitama	27_V	Inf	et	väsitada =väsita  (Inf  >väsitama !27_V
41724	vigadega	viga	viga	18_S	PlKom	et	vigadega =viga  (PlKom  >viga !18_S
41725	sukad	suka	sukk	22_S	PlN	et	sukad =suka  (PlN  >sukk !22_S
41730	interferents	interferents	interferents	22_S	SgN	et	interferents =interferents  (SgN  >interferents !22_S
41735	välted	välte	välde	06_S	PlN	et	välted =välte  (PlN  >välde !06_S
41736	areneks	arene	arenema	27_V	KndPrPs	et	areneks =arene  (KndPrPs  >arenema !27_V
41739	lihavõtted-	võtte	liha+võte	06_S	PlN	et	lihavõtted- =võtte  (PlN  >liha+võte !06_S
41742	sisenege-	sisene	sisenema	27_V	ImpPrPl2	et	sisenege- =sisene  (ImpPrPl2  >sisenema !27_V
41747	üksikjuhtumiga	juhtumi	üksik+juhtum	02_S	SgKom	et	üksikjuhtumiga =juhtumi  (SgKom  >üksik+juhtum !02_S
41750	oos	oos	oos	22_S	SgN	et	oos =oos  (SgN  >oos !22_S
41759	ajaloopeegel	peegel	aja+loo+peegel	02_S	SgN	et	ajaloopeegel =peegel  (SgN  >aja+loo+peegel !02_S
41760	suurfilmile	filmi	suur+film	22_S	SgAll	et	suurfilmile =filmi  (SgAll  >suur+film !22_S
41764	hullumeelsel	meelse	hullu+meelne	02_A	SgAd	et	hullumeelsel =meelse  (SgAd  >hullu+meelne !02_A
41768	isehakanud	hakanu	ise+hakanu	01_S	PlN	et	isehakanud =hakanu  (PlN  >ise+hakanu !01_S
41776	klassivendade	venda	klassi+vend	22_S	PlG	et	klassivendade =venda  (PlG  >klassi+vend !22_S
41777	naeruväärsetena	väärse	naeru+väärne	02_A	PlEs	et	naeruväärsetena =väärse  (PlEs  >naeru+väärne !02_A
41778	mõnelgi	mõne	mõni	20_P	SgAd^	et	mõnelgi =mõne  (SgAd^  >mõni !20_P
41779	noorel	noore	noor	13_AS	SgAd	et	noorel =noore  (SgAd  >noor !13_AS
41786	kõlari	kõlari	kõlar	02_S	SgG	et	kõlari =kõlari  (SgG  >kõlar !02_S
41788	sooje	sooje	soe	24_AS	PlP	et	sooje =sooje  (PlP  >soe !24_AS
41789	vabadussõjale	sõja	vabadus+sõda	18_S	SgAll	et	vabadussõjale =sõja  (SgAll  >vabadus+sõda !18_S
41800	paljut	palju	palju	16_P	SgP	et	paljut =palju  (SgP  >palju !16_P
41804	teatrilavastused	lavastuse	teatri+lavastus	11_S	PlN	et	teatrilavastused =lavastuse  (PlN  >teatri+lavastus !11_S
41807	võitluseks	võitluse	võitlus	11~09_S	SgTr	et	võitluseks =võitluse  (SgTr  >võitlus !11~09_S
41809	linateose	teose	lina+teos	09_S	SgG	et	linateose =teose  (SgG  >lina+teos !09_S
41816	enamat	enama	enam	02_A	SgP	et	enamat =enama  (SgP  >enam !02_A
41833	ülesehitamise	ehitamise	üles+ehitamine	12_S	SgG	et	ülesehitamise =ehitamise  (SgG  >üles+ehitamine !12_S
41837	mõõnadega	mõõna	mõõn	22_S	PlKom	et	mõõnadega =mõõna  (PlKom  >mõõn !22_S
41839	pakt	pakt	pakt	22_S	SgN	et	pakt =pakt  (SgN  >pakt !22_S
41844	loomavagunites	vaguni	looma+vagun	02_S	PlIn	et	loomavagunites =vaguni  (PlIn  >looma+vagun !02_S
41850	järsk	järsk	järsk	22_A	SgN	et	järsk =järsk  (SgN  >järsk !22_A
41857	16novembril	novembri	november	02_S	SgAd	et	novembril =novembri  (SgAd  >november !02_S
41862	valitsemisorganid	organi	valitsemis+organ	02_S	PlN	et	valitsemisorganid =organi  (PlN  >valitsemis+organ !02_S
41867	tulud	tulu	tulu	17_S	PlN	et	tulud =tulu  (PlN  >tulu !17_S
41877	mõõdus	mõõdu	mõõt	22_S	SgIn	et	mõõdus =mõõdu  (SgIn  >mõõt !22_S
41878	moonamajas	maja	moona+maja	17_S	SgIn	et	moonamajas =maja  (SgIn  >moona+maja !17_S
41880	kaardile	kaardi	kaart	22_S	SgAll	et	kaardile =kaardi  (SgAll  >kaart !22_S
41886	koolipoisist	poisi	kooli+poiss	23?22_S	SgEl	et	koolipoisist =poisi  (SgEl  >kooli+poiss !23?22_S
41893	haavadest	haava	haav	22_S	PlEl	et	haavadest =haava  (PlEl  >haav !22_S
41907	teadlane	teadlane	teadlane	12?10_S	SgN	et	teadlane =teadlane  (SgN  >teadlane !12?10_S
41909	koduperenaise	naise	kodu+pere+naine	12_S	SgG	et	koduperenaise =naise  (SgG  >kodu+pere+naine !12_S
41916	sakslasi	sakslasi	sakslane	12_S	PlP	et	sakslasi =sakslasi  (PlP  >sakslane !12_S
41918	tulistada	tulista	tulistama	27_V	Inf	et	tulistada =tulista  (Inf  >tulistama !27_V
41923	ükskõikne	kõikne	üks+kõikne	02_A	SgN	et	ükskõikne =kõikne  (SgN  >üks+kõikne !02_A
41924	perenaise	naise	pere+naine	12_S	SgG	et	perenaise =naise  (SgG  >pere+naine !12_S
41937	perioodis	perioodi	periood	22_S	SgIn	et	perioodis =perioodi  (SgIn  >periood !22_S
41944	rahvuspark	park	rahvus+park	22_S	SgN	et	rahvuspark =park  (SgN  >rahvus+park !22_S
41948	sõjaväebaaside	baasi	sõja+väe+baas	22_S	PlG	et	sõjaväebaaside =baasi  (PlG  >sõja+väe+baas !22_S
41950	reostusoht	oht	reostus+oht	22_S	SgN	et	reostusoht =oht  (SgN  >reostus+oht !22_S
41955	maapidamist	pidamis	maa+pidamine	12_S	SgP	et	maapidamist =pidamis  (SgP  >maa+pidamine !12_S
41958	harrastataksegi	harrasta	harrastama	27_V	IndPrIps^	et	harrastataksegi =harrasta  (IndPrIps^  >harrastama !27_V
41720	tüvega	tüve	tüvi	20_S	SgKom	et	tüvega =tüve  (SgKom  >tüvi !20_S
41726	ülikond	ülikond	ülikond	22_S	SgN	et	ülikond =ülikond  (SgN  >ülikond !22_S
41728	tehas	tehas	tehas	09_S	SgN	et	tehas =tehas  (SgN  >tehas !09_S
41731	otsetõlget	tõlge	otse+tõlge	06_S	SgP	et	otsetõlget =tõlge  (SgP  >otse+tõlge !06_S
41733	stiililt	stiili	stiil	22_S	SgAbl	et	stiililt =stiili  (SgAbl  >stiil !22_S
41734	väliskohakäänded	käände	välis+koha+kääne	06_S	PlN	et	väliskohakäänded =käände  (PlN  >välis+koha+kääne !06_S
41745	ara	ara	arg	22_A	SgG	et	ara =ara  (SgG  >arg !22_A
41751	uh	uh	uh	41_I	ID	et	uh =uh  (ID  >uh !41_I
41753	ates	ate	att	22_S	PlIn	et	ates =ate  (PlIn  >att !22_S
41756	nihu	nihu	nihu	41_D	ID	et	nihu =nihu  (ID  >nihu !41_D
41761	kirjandusklassikul	klassiku	kirjandus+klassik	02_S	SgAd	et	kirjandusklassikul =klassiku  (SgAd  >kirjandus+klassik !02_S
41770	ideoloogial	ideoloogia	ideoloogia	01_S	SgAd	et	ideoloogial =ideoloogia  (SgAd  >ideoloogia !01_S
41781	vanaisade	isa	vana+isa	17_S	PlG	et	vanaisade =isa  (PlG  >vana+isa !17_S
41784	filmiversioon	versioon	filmi+versioon	22_S	SgN	et	filmiversioon =versioon  (SgN  >filmi+versioon !22_S
41790	ümberkirjutamine	kirjutamine	ümber+kirjutamine	12_S	SgN	et	ümberkirjutamine =kirjutamine  (SgN  >ümber+kirjutamine !12_S
41795	suurfilmid	filmi	suur+film	22_S	PlN	et	suurfilmid =filmi  (PlN  >suur+film !22_S
41798	olevikule	oleviku	olevik	25_S	SgAll	et	olevikule =oleviku  (SgAll  >olevik !25_S
41803	lavastada	lavasta	lavastama	27_V	Inf	et	lavastada =lavasta  (Inf  >lavastama !27_V
41810	kangelasliku	kangelasliku	kangelaslik	25_A	SgG	et	kangelasliku =kangelasliku  (SgG  >kangelaslik !25_A
41814	sõnumiga	sõnumi	sõnum	02_S	SgKom	et	sõnumiga =sõnumi  (SgKom  >sõnum !02_S
41829	kolk	kolk	kolk	22_S	SgN	et	kolk =kolk  (SgN  >kolk !22_S
41838	demokraatias	demokraatia	demokraatia	01_S	SgIn	et	demokraatias =demokraatia  (SgIn  >demokraatia !01_S
41842	1septembril	septembri	september	02_S	SgAd	et	septembril =septembri  (SgAd  >september !02_S
41849	euroopat	euroopa	euroopa	01_H	SgP	et	euroopat =euroopa  (SgP  >euroopa !01_H
41859	taastama	taasta	taastama	27_V	Sup	et	taastama =taasta  (Sup  >taastama !27_V
41863	struktuuridesse	struktuuri	struktuur	22_S	PlIll	et	struktuuridesse =struktuuri  (PlIll  >struktuur !22_S
41864	kodanikel	kodanike	kodanik	25_S	PlAd	et	kodanikel =kodanike  (PlAd  >kodanik !25_S
41884	aateid	aate	aade	06_S	PlP	et	aateid =aate  (PlP  >aade !06_S
41888	punaarmeenlaste	armeenlas	puna+armeenlane	12?10_S	PlG	et	punaarmeenlaste =armeenlas  (PlG  >puna+armeenlane !12?10_S
41890	vaenlase	vaenlase	vaenlane	12?10_S	SgG	et	vaenlase =vaenlase  (SgG  >vaenlane !12?10_S
41904	ohvitser	ohvitser	ohvitser	19_S	SgN	et	ohvitser =ohvitser  (SgN  >ohvitser !19_S
41920	seadmeid	seadme	seade	05_S	PlP	et	seadmeid =seadme  (PlP  >seade !05_S
41921	botaanik	botaanik	botaanik	02_S	SgN	et	botaanik =botaanik  (SgN  >botaanik !02_S
41927	kavandama	kavanda	kavandama	27_V	Sup	et	kavandama =kavanda  (Sup  >kavandama !27_V
41934	kuldhambad	hamba	kuld+hammas	07_S	PlN	et	kuldhambad =hamba  (PlN  >kuld+hammas !07_S
41935	vangidest	vangi	vang	22_S	PlEl	et	vangidest =vangi  (PlEl  >vang !22_S
41938	kolmandad	kolmanda	kolmas	02_O	PlN	et	kolmandad =kolmanda  (PlN  >kolmas !02_O
41939	reeturid	reeturi	reetur	02_S	PlN	et	reeturid =reeturi  (PlN  >reetur !02_S
41942	loodusvaradega	vara	loodus+vara	17_S	PlKom	et	loodusvaradega =vara  (PlKom  >loodus+vara !17_S
41943	võõrtöölisi	töölisi	võõr+tööline	12_S	PlP	et	võõrtöölisi =töölisi  (PlP  >võõr+tööline !12_S
41945	lahemere	mere	lahe+meri	20_S	SgG	et	lahemere =mere  (SgG  >lahe+meri !20_S
41946	segakoolid	kooli	sega+kool	22_S	PlN	et	segakoolid =kooli  (PlN  >sega+kool !22_S
41952	fosforiidikaevanduse	kaevanduse	fosforiidi+kaevandus	11_S	SgG	et	fosforiidikaevanduse =kaevanduse  (SgG  >fosforiidi+kaevandus !11_S
41956	planeerida	planeeri	planeerima	28_V	Inf	et	planeerida =planeeri  (Inf  >planeerima !28_V
41959	kujundati	kujunda	kujundama	27_V	IndIpfIps	et	kujundati =kujunda  (IndIpfIps  >kujundama !27_V
41964	ühise	ühise	ühine	10_A	SgG	et	ühise =ühise  (SgG  >ühine !10_A
41979	semestris	semestri	semester	02_S	SgIn	et	semestris =semestri  (SgIn  >semester !02_S
41990	tooksin	too	tooma	38_V	KndPrSg1	et	tooksin =too  (KndPrSg1  >tooma !38_V
42002	süüpingis	pingi	süü+pink	22_S	SgIn	et	süüpingis =pingi  (SgIn  >süü+pink !22_S
42006	hirmsaist	hirmsa	hirmus	02_A	PlEl	et	hirmsaist =hirmsa  (PlEl  >hirmus !02_A
42007	vennaverega	vere	venna+veri	20_S	SgKom	et	vennaverega =vere  (SgKom  >venna+veri !20_S
42008	üksikuina	ui	üksik+ui	26_S	SgEs	et	üksikuina =ui  (SgEs  >üksik+ui !26_S
42010	redus	redu	redu	17_S	SgIn	et	redus =redu  (SgIn  >redu !17_S
42026	käsitlema	käsitle	käsitlema	27_V	Sup	et	käsitlema =käsitle  (Sup  >käsitlema !27_V
41769	jumalustel	jumalus	jumalus	11_S	PlAd	et	jumalustel =jumalus  (PlAd  >jumalus !11_S
41773	mõõkadeks	mõõka	mõõk	22_S	PlTr	et	mõõkadeks =mõõka  (PlTr  >mõõk !22_S
41774	üldisest	üldise	üldine	10~12_A	SgEl	et	üldisest =üldise  (SgEl  >üldine !10~12_A
41775	rabeleda	rabele	rabelema	27_V	Inf	et	rabeleda =rabele  (Inf  >rabelema !27_V
41780	väärtushoiakuid	hoiaku	väärtus+hoiak	02_S	PlP	et	väärtushoiakuid =hoiaku  (PlP  >väärtus+hoiak !02_S
41782	eeskujude	kuju	ees+kuju	17_S	PlG	et	eeskujude =kuju  (PlG  >ees+kuju !17_S
41783	ülekohut	kohu	üle+kohus	05_S	SgP	et	ülekohut =kohu  (SgP  >üle+kohus !05_S
41785	üldhäälestatud	häälestatu	üld+häälestatu	01_S	PlN	et	üldhäälestatud =häälestatu  (PlN  >üld+häälestatu !01_S
41792	lahkudest	lahku	lahk	22_S	PlEl	et	lahkudest =lahku  (PlEl  >lahk !22_S
41797	minevikule	mineviku	minevik	25_S	SgAll	et	minevikule =mineviku  (SgAll  >minevik !25_S
41799	poeetiline	poeetiline	poeetiline	12_A	SgN	et	poeetiline =poeetiline  (SgN  >poeetiline !12_A
41802	viimaste	viimas	viimane	10_A	PlG	et	viimaste =viimas  (PlG  >viimane !10_A
41812	enesemüümise	müümise	enese+müümine	12?10_S	SgG	et	enesemüümise =müümise  (SgG  >enese+müümine !12?10_S
41815	blondiin	blondiin	blondiin	22_S	SgN	et	blondiin =blondiin  (SgN  >blondiin !22_S
41817	vinguma	vingu	vinguma	28_V	Sup	et	vinguma =vingu  (Sup  >vinguma !28_V
41821	vabadussõjast	sõja	vabadus+sõda	18_S	SgEl	et	vabadussõjast =sõja  (SgEl  >vabadus+sõda !18_S
41823	vaikiti	vaiki	vaikima	27_V	IndIpfIps	et	vaikiti =vaiki  (IndIpfIps  >vaikima !27_V
41830	eksiilluuletajate	luuletaja	eksiil+luuletaja	01_S	PlG	et	eksiilluuletajate =luuletaja  (PlG  >eksiil+luuletaja !01_S
41836	tõusude	tõusu	tõus	22_S	PlG	et	tõusude =tõusu  (PlG  >tõus !22_S
41840	riikidesse	riiki	riik	22_S	PlIll	et	riikidesse =riiki  (PlIll  >riik !22_S
41843	küüditati	küüdita	küüditama	27_V	IndIpfIps	et	küüditati =küüdita  (IndIpfIps  >küüditama !27_V
41845	kodud	kodu	kodu	17_S	PlN	et	kodud =kodu  (PlN  >kodu !17_S
41847	sõdis	sõdi	sõdima	27_V	IndIpfSg3	et	sõdis =sõdi  (IndIpfSg3  >sõdima !27_V
41851	vabariik	riik	vaba+riik	22_S	SgN	et	vabariik =riik  (SgN  >vaba+riik !22_S
41854	eetrisse	eetri	eeter	02_S	SgIll	et	eetrisse =eetri  (SgIll  >eeter !02_S
41856	vanalinnapäevad	päeva	vana+linna+päev	22_S	PlN	et	vanalinnapäevad =päeva  (PlN  >vana+linna+päev !22_S
41858	praegust	praegus	praegune	10~12_A	SgP	et	praegust =praegus  (SgP  >praegune !10~12_A
41868	sotsiaalsfäär	sfäär	sotsiaal+sfäär	22_S	SgN	et	sotsiaalsfäär =sfäär  (SgN  >sotsiaal+sfäär !22_S
41869	lokkab	lokka	lokkama	29_V	IndPrSg3	et	lokkab =lokka  (IndPrSg3  >lokkama !29_V
41873	kaasakiskuva	kiskuva	kaasa+kiskuv	02_A	SgG	et	kaasakiskuva =kiskuva  (SgG  >kaasa+kiskuv !02_A
41875	võitlusse	võitlus	võitlus	11_S	SgAdt	et	võitlusse =võitlus  (SgAdt  >võitlus !11_S
41876	alevis	alevi	alev	02_S	SgIn	et	alevis =alevi  (SgIn  >alev !02_S
41897	vaateväljas	välja	vaate+väli	24_S	SgIn	et	vaateväljas =välja  (SgIn  >vaate+väli !24_S
41898	ainestik	ainestik	ainestik	25_S	SgN	et	ainestik =ainestik  (SgN  >ainestik !25_S
41908	teadlasel	teadlase	teadlane	12?10_S	SgAd	et	teadlasel =teadlase  (SgAd  >teadlane !12?10_S
41914	hospital	hospital	hospital	19_S	SgN	et	hospital =hospital  (SgN  >hospital !19_S
41917	pettub	pettu	pettuma	27_V	IndPrSg3	et	pettub =pettu  (IndPrSg3  >pettuma !27_V
41931	pidutseb	pidutse	pidutsema	27_V	IndPrSg3	et	pidutseb =pidutse  (IndPrSg3  >pidutsema !27_V
41932	tulistatakse	tulista	tulistama	27_V	IndPrIps	et	tulistatakse =tulista  (IndPrIps  >tulistama !27_V
41936	ohvitseridele	ohvitseri	ohvitser	19_S	PlAll	et	ohvitseridele =ohvitseri  (PlAll  >ohvitser !19_S
41940	kodakondsusega	kodakondsuse	kodakondsus	11~09_S	SgKom	et	kodakondsusega =kodakondsuse  (SgKom  >kodakondsus !11~09_S
41949	kontseptsioon	kontseptsioon	kontseptsioon	22_S	SgN	et	kontseptsioon =kontseptsioon  (SgN  >kontseptsioon !22_S
41951	fosforväetised	väetise	fosfor+väetis	11~09_S	PlN	et	fosforväetised =väetise  (PlN  >fosfor+väetis !11~09_S
41954	maainimesed	inimese	maa+inimene	12_S	PlN	et	maainimesed =inimese  (PlN  >maa+inimene !12_S
41960	üldkasutatavaks	kasutatava	üld+kasutatav	02_A	SgTr	et	üldkasutatavaks =kasutatava  (SgTr  >üld+kasutatav !02_A
41967	kapellide	kapelli	kapell	22_S	PlG	et	kapellide =kapelli  (PlG  >kapell !22_S
41969	kinost	kino	kino	17_S	SgEl	et	kinost =kino  (SgEl  >kino !17_S
41974	väljamõtlemisel	mõtlemise	välja+mõtlemine	12_S	SgAd	et	väljamõtlemisel =mõtlemise  (SgAd  >välja+mõtlemine !12_S
41988	teosele	teose	teos	09_S	SgAll	et	teosele =teose  (SgAll  >teos !09_S
41992	runge	runge	rung	22_S	PlP	et	runge =runge  (PlP  >rung !22_S
41997	maksudest	maksu	maks	22_S	PlEl	et	maksudest =maksu  (PlEl  >maks !22_S
41999	kahtlustad	kahtlusta	kahtlustama	27_V	IndPrSg2	et	kahtlustad =kahtlusta  (IndPrSg2  >kahtlustama !27_V
41860	seadusandlust	andlus	seadus+andlus	11~09_S	SgP	et	seadusandlust =andlus  (SgP  >seadus+andlus !11~09_S
41866	seada	sead	seadma	34_V	Inf	et	seada =sead  (Inf  >seadma !34_V
41871	ainetel	aine	aine	06_S	PlAd	et	ainetel =aine  (PlAd  >aine !06_S
41879	punaarmeenlane	armeenlane	puna+armeenlane	12?10_S	SgN	et	punaarmeenlane =armeenlane  (SgN  >puna+armeenlane !12?10_S
41882	koolinoored	noore	kooli+noor	13_AS	PlN	et	koolinoored =noore  (PlN  >kooli+noor !13_AS
41889	pettis	pett	petma	35_V	IndIpfSg3	et	pettis =pett  (IndIpfSg3  >petma !35_V
41891	sündmustele	sündmus	sündmus	11~09_S	PlAll	et	sündmustele =sündmus  (PlAll  >sündmus !11~09_S
41892	vabadussõjaaegades	aega	vabadus+sõja+aeg	22_S	PlIn	et	vabadussõjaaegades =aega  (PlIn  >vabadus+sõja+aeg !22_S
41901	sügispäev	päev	sügis+päev	22_S	SgN	et	sügispäev =päev  (SgN  >sügis+päev !22_S
41906	miilas	miila	miilama	29_V	IndIpfSg3	et	miilas =miila  (IndIpfSg3  >miilama !29_V
41913	tänuseks	seks	tänu+seks	22_S	SgN	et	tänuseks =seks  (SgN  >tänu+seks !22_S
41919	ohvitserid	ohvitseri	ohvitser	19_S	PlN	et	ohvitserid =ohvitseri  (PlN  >ohvitser !19_S
41922	professoril	professori	professor	02_S	SgAd	et	professoril =professori  (SgAd  >professor !02_S
41925	suren	sure	surema	36_V	IndPrSg1	et	suren =sure  (IndPrSg1  >surema !36_V
41926	pangahärrad	härra	panga+härra	16_S	PlN	et	pangahärrad =härra  (PlN  >panga+härra !16_S
41928	sõdima	sõdi	sõdima	27_V	Sup	et	sõdima =sõdi  (Sup  >sõdima !27_V
41929	päästma	pääst	päästma	34_V	Sup	et	päästma =pääst  (Sup  >päästma !34_V
41933	kuldehted	ehte	kuld+ehe	06_S	PlN	et	kuldehted =ehte  (PlN  >kuld+ehe !06_S
41947	koolilapsed	lapse	kooli+laps	14_S	PlN	et	koolilapsed =lapse  (PlN  >kooli+laps !14_S
41957	sini-must-valget	valge	sini-must-valge	01_AS	SgP	et	sini-must-valget =valge  (SgP  >sini-must-valge !01_AS
41961	sõnadena	sõna	sõna	17_S	PlEs	et	sõnadena =sõna  (PlEs  >sõna !17_S
41963	potentsiaalsete	potentsiaalse	potentsiaalne	02_A	PlG	et	potentsiaalsete =potentsiaalse  (PlG  >potentsiaalne !02_A
41965	keeleta	keele	keel	13_S	SgAb	et	keeleta =keele  (SgAb  >keel !13_S
41971	kultus	kultus	kultus	11~09_S	SgN	et	kultus =kultus  (SgN  >kultus !11~09_S
41972	definitsioonid	definitsiooni	definitsioon	22_S	PlN	et	definitsioonid =definitsiooni  (PlN  >definitsioon !22_S
41976	riigiga	riigi	riik	22_S	SgKom	et	riigiga =riigi  (SgKom  >riik !22_S
41980	taotleda	taotle	taotlema	27_V	Inf	et	taotleda =taotle  (Inf  >taotlema !27_V
41983	tõsielule	elu	tõsi+elu	17_S	SgAll	et	tõsielule =elu  (SgAll  >tõsi+elu !17_S
41985	võrsetest	võrse	võrse	06_S	PlEl	et	võrsetest =võrse  (PlEl  >võrse !06_S
41993	vao	vao	vagu	18_S	SgG	et	vao =vao  (SgG  >vagu !18_S
41994	külaelanikud	elaniku	küla+elanik	25_S	PlN	et	külaelanikud =elaniku  (PlN  >küla+elanik !25_S
42000	kurvest	kurve	kurv	22_S	PlEl	et	kurvest =kurve  (PlEl  >kurv !22_S
42011	rahvuskangelased	kangelase	rahvus+kangelane	12_S	PlN	et	rahvuskangelased =kangelase  (PlN  >rahvus+kangelane !12_S
42012	eeskujuks	kuju	ees+kuju	17_S	SgTr	et	eeskujuks =kuju  (SgTr  >ees+kuju !17_S
42013	vaev	vaev	vaev	22_S	SgN	et	vaev =vaev  (SgN  >vaev !22_S
42016	võrreldakse	võrrel	võrdlema	30_V	IndPrIps	et	võrreldakse =võrrel  (IndPrIps  >võrdlema !30_V
42019	elatustaseme	taseme	elatus+tase	04_S	SgG	et	elatustaseme =taseme  (SgG  >elatus+tase !04_S
42020	elatustaset	tase	elatus+tase	04_S	SgP	et	elatustaset =tase  (SgP  >elatus+tase !04_S
42021	motiveerimaks	motiveeri	motiveerima	28_V	SupTr	et	motiveerimaks =motiveeri  (SupTr  >motiveerima !28_V
42022	meelakkumine-	lakkumine	mee+lakkumine	12_S	SgN	et	meelakkumine- =lakkumine  (SgN  >mee+lakkumine !12_S
42031	põhitugi	tugi	põhi+tugi	21_S	SgN	et	põhitugi =tugi  (SgN  >põhi+tugi !21_S
42042	taluperel	pere	talu+pere	16_S	SgAd	et	taluperel =pere  (SgAd  >talu+pere !16_S
42045	maatükilt	tüki	maa+tükk	22_S	SgAbl	et	maatükilt =tüki  (SgAbl  >maa+tükk !22_S
42047	vajaminevatest	mineva	vaja+minev	02_A	PlEl	et	vajaminevatest =mineva  (PlEl  >vaja+minev !02_A
42048	tööriistadest	riista	töö+riist	22_S	PlEl	et	tööriistadest =riista  (PlEl  >töö+riist !22_S
42052	taluperes	pere	talu+pere	16_S	SgIn	et	taluperes =pere  (SgIn  >talu+pere !16_S
42068	sulaseid	sulase	sulane	10_S	PlP	et	sulaseid =sulase  (PlP  >sulane !10_S
42069	palgati	palga	palkama	29_V	IndIpfIps	et	palgati =palga  (IndIpfIps  >palkama !29_V
42075	mõisameheks	mehe	mõisa+mees	13_S	SgTr	et	mõisameheks =mehe  (SgTr  >mõisa+mees !13_S
42089	linnapered	pere	linna+pere	16_S	PlN	et	linnapered =pere  (PlN  >linna+pere !16_S
42101	edasiandmiseks	andmise	edasi+andmine	12?10_S	SgTr	et	edasiandmiseks =andmise  (SgTr  >edasi+andmine !12?10_S
42104	äärealadel	ala	ääre+ala	17_S	PlAd	et	äärealadel =ala  (PlAd  >ääre+ala !17_S
42107	elatada	elata	elatama	27_V	Inf	et	elatada =elata  (Inf  >elatama !27_V
41874	koolipingist	pingi	kooli+pink	22_S	SgEl	et	koolipingist =pingi  (SgEl  >kooli+pink !22_S
41881	sõdurite	sõduri	sõdur	02_S	PlG	et	sõdurite =sõduri  (PlG  >sõdur !02_S
41883	kaitstes	kaits	kaitsma	32_V	Ger	et	kaitstes =kaits  (Ger  >kaitsma !32_V
41885	punaarmeenlased	armeenlase	puna+armeenlane	12?10_S	PlN	et	punaarmeenlased =armeenlase  (PlN  >puna+armeenlane !12?10_S
41887	lahingud	lahingu	lahing	02_S	PlN	et	lahingud =lahingu  (PlN  >lahing !02_S
41894	staabikirjutajana	kirjutaja	staabi+kirjutaja	01_S	SgEs	et	staabikirjutajana =kirjutaja  (SgEs  >staabi+kirjutaja !01_S
41895	riitadena	riita	riit	22_S	PlEs	et	riitadena =riita  (PlEs  >riit !22_S
41896	boheemkonnaga	boheemkonna	boheemkond	22_S	SgKom	et	boheemkonnaga =boheemkonna  (SgKom  >boheemkond !22_S
41899	edasiandmine	andmine	edasi+andmine	12?10_S	SgN	et	edasiandmine =andmine  (SgN  >edasi+andmine !12?10_S
41900	lähedaste	lähedas	lähedane	12_AS	PlG	et	lähedaste =lähedas  (PlG  >lähedane !12_AS
41902	avaras	avara	avar	02_A	SgIn	et	avaras =avara  (SgIn  >avar !02_A
41903	tsitadellis	tsitadelli	tsitadell	22_S	SgIn	et	tsitadellis =tsitadelli  (SgIn  >tsitadell !22_S
41905	professoriga	professori	professor	02_S	SgKom	et	professoriga =professori  (SgKom  >professor !02_S
41910	peita	peit	peitma	34_V	Inf	et	peita =peit  (Inf  >peitma !34_V
41911	ohvitseridest	ohvitseri	ohvitser	19_S	PlEl	et	ohvitseridest =ohvitseri  (PlEl  >ohvitser !19_S
41912	teadusega	teaduse	teadus	11~09_S	SgKom	et	teadusega =teaduse  (SgKom  >teadus !11~09_S
41915	uudisega	uudise	uudis	09_S	SgKom	et	uudisega =uudise  (SgKom  >uudis !09_S
41930	ravida	ravi	ravima	27_V	Inf	et	ravida =ravi  (Inf  >ravima !27_V
41941	rahatähel	tähe	raha+täht	22_S	SgAd	et	rahatähel =tähe  (SgAd  >raha+täht !22_S
41953	protesteeriti	protesteeri	protesteerima	28_V	IndIpfIps	et	protesteeriti =protesteeri  (IndIpfIps  >protesteerima !28_V
41962	objektiivseid	objektiivse	objektiivne	02_A	PlP	et	objektiivseid =objektiivse  (PlP  >objektiivne !02_A
41975	sotsiaalmajanduslikke	majanduslikke	sotsiaal+majanduslik	25_A	PlP	et	sotsiaalmajanduslikke =majanduslikke  (PlP  >sotsiaal+majanduslik !25_A
41978	religioonide	religiooni	religioon	22_S	PlG	et	religioonide =religiooni  (PlG  >religioon !22_S
41984	sõjajärgses	järgse	sõja+järgne	02_A	SgIn	et	sõjajärgses =järgse  (SgIn  >sõja+järgne !02_A
41987	milledes	mille	mis	00_P	PlIn	et	milledes =mille  (PlIn  >mis !00_P
41996	sulitempude	tempu	suli+temp	22_S	PlG	et	sulitempude =tempu  (PlG  >suli+temp !22_S
41998	kõrvalehiilimise	hiilimise	kõrvale+hiilimine	12_S	SgG	et	kõrvalehiilimise =hiilimise  (SgG  >kõrvale+hiilimine !12_S
42003	propagandaga	propaganda	propaganda	16_S	SgKom	et	propagandaga =propaganda  (SgKom  >propaganda !16_S
42014	naerdakse	naer	naerma	33_V	IndPrIps	et	naerdakse =naer  (IndPrIps  >naerma !33_V
42017	sulaste	sulas	sulane	10_S	PlG	et	sulaste =sulas  (PlG  >sulane !10_S
42023	rahvalt	rahva	rahvas	07_S	SgAbl	et	rahvalt =rahva  (SgAbl  >rahvas !07_S
42025	sunniviisiselt	viisi	sunni+viis	22_S	SELT_mD	et	"sunni+viisiselt %viisi  )SELT_mD  <sunni+viis ;22_S
42027	ühiskonnategelasi	tegelasi	ühis+konna+tegelane	12_S	PlP	et	ühiskonnategelasi =tegelasi  (PlP  >ühis+konna+tegelane !12_S
42033	arusaamu	saamu	aru+saam	22_S	PlP	et	arusaamu =saamu  (PlP  >aru+saam !22_S
42053	töökogemusi	kogemusi	töö+kogemus	11_S	PlP	et	töökogemusi =kogemusi  (PlP  >töö+kogemus !11_S
42058	vendade-õdede	õde	vendade-õde	18_S	PlG	et	vendade-õdede =õde  (PlG  >vendade-õde !18_S
42060	kaugeid	kauge	kauge	01_A	PlP	et	kaugeid =kauge  (PlP  >kauge !01_A
42061	teenijatüdrukud	tüdruku	teenija+tüdruk	02_S	PlN	et	teenijatüdrukud =tüdruku  (PlN  >teenija+tüdruk !02_S
42077	sotsiaalsest	sotsiaalse	sotsiaalne	02_A	SgEl	et	sotsiaalsest =sotsiaalse  (SgEl  >sotsiaalne !02_A
42080	süvenes	süvene	süvenema	27_V	IndIpfSg3	et	süvenes =süvene  (IndIpfSg3  >süvenema !27_V
42087	talunikud	taluniku	talunik	25_S	PlN	et	talunikud =taluniku  (PlN  >talunik !25_S
42090	lasteta	las	laps	14_S	PlAb	et	lasteta =las  (PlAb  >laps !14_S
42092	hoiakud	hoiaku	hoiak	02_S	PlN	et	hoiakud =hoiaku  (PlN  >hoiak !02_S
42093	elutingimustega	tingimus	elu+tingimus	11_S	PlKom	et	elutingimustega =tingimus  (PlKom  >elu+tingimus !11_S
42098	elulaad	laad	elu+laad	22_S	SgN	et	elulaad =laad  (SgN  >elu+laad !22_S
42103	eksisteerib	eksisteeri	eksisteerima	28_V	IndPrSg3	et	eksisteerib =eksisteeri  (IndPrSg3  >eksisteerima !28_V
42114	lakkab	lakka	lakkama	29_V	IndPrSg3	et	lakkab =lakka  (IndPrSg3  >lakkama !29_V
42120	meelestab	meelesta	meelestama	27_V	IndPrSg3	et	meelestab =meelesta  (IndPrSg3  >meelestama !27_V
42125	sagedane	sagedane	sagedane	12_A	SgN	et	sagedane =sagedane  (SgN  >sagedane !12_A
42136	surmakoridorist	koridori	surma+koridor	19_S	SgEl	et	surmakoridorist =koridori  (SgEl  >surma+koridor !19_S
42143	endisega	endise	endine	10~12_A	SgKom	et	endisega =endise  (SgKom  >endine !10~12_A
42155	negatiivsetest	negatiivse	negatiivne	02_A	PlEl	et	negatiivsetest =negatiivse  (PlEl  >negatiivne !02_A
41966	kirjakeelne	keelne	kirja+keelne	02_A	SgN	et	kirjakeelne =keelne  (SgN  >kirja+keelne !02_A
41968	mitteeestlased	eestlase	mitte+eestlane	12?10_S	PlN	et	mitteeestlased =eestlase  (PlN  >mitte+eestlane !12?10_S
41970	maailmatajumist	tajumis	maa+ilma+tajumine	12_S	SgP	et	maailmatajumist =tajumis  (SgP  >maa+ilma+tajumine !12_S
41973	ideede	idee	idee	26_S	PlG	et	ideede =idee  (PlG  >idee !26_S
41977	konfliktiga	konflikti	konflikt	22_S	SgKom	et	konfliktiga =konflikti  (SgKom  >konflikt !22_S
41981	ainepunkte	punkte	aine+punkt	22_S	PlP	et	ainepunkte =punkte  (PlP  >aine+punkt !22_S
41982	ekraanipilt	pilt	ekraani+pilt	22_S	SgN	et	ekraanipilt =pilt  (SgN  >ekraani+pilt !22_S
41986	tunnistada	tunnista	tunnistama	27_V	Inf	et	tunnistada =tunnista  (Inf  >tunnistama !27_V
41989	kindlameelne	meelne	kindla+meelne	02_A	SgN	et	kindlameelne =meelne  (SgN  >kindla+meelne !02_A
41991	segadusse	segadus	segadus	11_S	SgAdt	et	segadusse =segadus  (SgAdt  >segadus !11_S
41995	kohust	kohus	kohus	09_S	SgP	et	kohust =kohus  (SgP  >kohus !09_S
42005	elukorraldust	korraldus	elu+korraldus	11_S	SgP	et	elukorraldust =korraldus  (SgP  >elu+korraldus !11_S
42009	hundid	hundi	hunt	22_S	PlN	et	hundid =hundi  (PlN  >hunt !22_S
42018	töökad	tööka	töökas	02_A	PlN	et	töökad =tööka  (PlN  >töökas !02_A
42024	vabatahtlikke	tahtlikke	vaba+tahtlik	25_A	PlP	et	vabatahtlikke =tahtlikke  (PlP  >vaba+tahtlik !25_A
42030	rahuldama	rahulda	rahuldama	27_V	Sup	et	rahuldama =rahulda  (Sup  >rahuldama !27_V
42036	vennad-õed	õe	vennad-õde	18_S	PlN	et	vennad-õed =õe  (PlN  >vennad-õde !18_S
42037	lihtpered	pere	liht+pere	16_S	PlN	et	lihtpered =pere  (PlN  >liht+pere !16_S
42038	mees-naine	naine	mees-naine	12_S	SgN	et	mees-naine =naine  (SgN  >mees-naine !12_S
42039	mees-naine-lapsed	lapse	mees-naine-laps	14_S	PlN	et	mees-naine-lapsed =lapse  (PlN  >mees-naine-laps !14_S
42050	toodangust	toodangu	toodang	02_S	SgEl	et	toodangust =toodangu  (SgEl  >toodang !02_S
42051	tarbimisüksus	üksus	tarbimis+üksus	11~09_S	SgN	et	tarbimisüksus =üksus  (SgN  >tarbimis+üksus !11~09_S
42055	alluvussuhted	suhte	alluvus+suhe	06_S	PlN	et	alluvussuhted =suhte  (PlN  >alluvus+suhe !06_S
42062	veotöid	tö	veo+töö	26_S	PlP	et	veotöid =tö  (PlP  >veo+töö !26_S
42063	viljakoristamisel	koristamise	vilja+koristamine	12_S	SgAd	et	viljakoristamisel =koristamise  (SgAd  >vilja+koristamine !12_S
42072	asuda	asu	asuma	27_V	Inf	et	asuda =asu  (Inf  >asuma !27_V
42084	suurpered	pere	suur+pere	16_S	PlN	et	suurpered =pere  (PlN  >suur+pere !16_S
42085	talumajandid	majandi	talu+majand	02_S	PlN	et	talumajandid =majandi  (PlN  >talu+majand !02_S
42086	kollektiviseeriti	kollektiviseeri	kollektiviseerima	28_V	IndIpfIps	et	kollektiviseeriti =kollektiviseeri  (IndIpfIps  >kollektiviseerima !28_V
42091	abielluda	ellu	abi+elluma	27_V	Inf	et	abielluda =ellu  (Inf  >abi+elluma !27_V
42102	kultuurivaim	vaim	kultuuri+vaim	22_S	SgN	et	kultuurivaim =vaim  (SgN  >kultuuri+vaim !22_S
42105	tagama	taga	tagama	27_V	Sup	et	tagama =taga  (Sup  >tagama !27_V
42112	perekondadega	perekonda	perekond	22_S	PlKom	et	perekondadega =perekonda  (PlKom  >perekond !22_S
42113	asjaoluga	olu	asja+olu	17_S	SgKom	et	asjaoluga =olu  (SgKom  >asja+olu !17_S
42118	filmijärgsed	järgse	filmi+järgne	02_A	PlN	et	filmijärgsed =järgse  (PlN  >filmi+järgne !02_A
42122	aladega	ala	ala	17_S	PlKom	et	aladega =ala  (PlKom  >ala !17_S
42124	nood	noo	too	00_P	PlN	et	nood =noo  (PlN  >too !00_P
42126	ajaloofilmide	filmi	aja+loo+film	22_S	PlG	et	ajaloofilmide =filmi  (PlG  >aja+loo+film !22_S
42132	võõrkeelne	keelne	võõr+keelne	02_A	SgN	et	võõrkeelne =keelne  (SgN  >võõr+keelne !02_A
42148	järeldub	järeldu	järelduma	27_V	IndPrSg3	et	järeldub =järeldu  (IndPrSg3  >järelduma !27_V
42156	asjaolule	olu	asja+olu	17_S	SgAll	et	asjaolule =olu  (SgAll  >asja+olu !17_S
42157	sõjaolukord	kord	sõja+olu+kord	22_S	SgN	et	sõjaolukord =kord  (SgN  >sõja+olu+kord !22_S
42159	vangis	vangi	vang	22_S	SgIn	et	vangis =vangi  (SgIn  >vang !22_S
42171	näitekirjandus	kirjandus	näite+kirjandus	11_S	SgN	et	näitekirjandus =kirjandus  (SgN  >näite+kirjandus !11_S
42174	kampaaniatega	kampaania	kampaania	01_S	PlKom	et	kampaaniatega =kampaania  (PlKom  >kampaania !01_S
42177	dramaatilisteks	dramaatilis	dramaatiline	12_A	PlTr	et	dramaatilisteks =dramaatilis  (PlTr  >dramaatiline !12_A
42181	draamakirjandus	kirjandus	draama+kirjandus	11_S	SgN	et	draamakirjandus =kirjandus  (SgN  >draama+kirjandus !11_S
42188	sõjasündmuste	sündmus	sõja+sündmus	11~09_S	PlG	et	sõjasündmuste =sündmus  (PlG  >sõja+sündmus !11~09_S
42189	okupatsiooniga	okupatsiooni	okupatsioon	22_S	SgKom	et	okupatsiooniga =okupatsiooni  (SgKom  >okupatsioon !22_S
42197	marksistliku	marksistliku	marksistlik	25_A	SgG	et	marksistliku =marksistliku  (SgG  >marksistlik !25_A
42200	sulgub	sulgu	sulguma	27_V	IndPrSg3	et	sulgub =sulgu  (IndPrSg3  >sulguma !27_V
42201	võitlusi	võitlusi	võitlus	11_S	PlP	et	võitlusi =võitlusi  (PlP  >võitlus !11_S
42001	asjamehed	mehe	asja+mees	13_S	PlN	et	asjamehed =mehe  (PlN  >asja+mees !13_S
42004	tegelaskujud	kuju	tegelas+kuju	17_S	PlN	et	tegelaskujud =kuju  (PlN  >tegelas+kuju !17_S
42015	omistatakse	omista	omistama	27_V	IndPrIps	et	omistatakse =omista  (IndPrIps  >omistama !27_V
42028	rollis	rolli	roll	22_S	SgIn	et	rollis =rolli  (SgIn  >roll !22_S
42035	kooselurühmad	rühma	koos+elu+rühm	22_S	PlN	et	kooselurühmad =rühma  (PlN  >koos+elu+rühm !22_S
42040	üksiksugulane	sugulane	üksik+sugulane	12_S	SgN	et	üksiksugulane =sugulane  (SgN  >üksik+sugulane !12_S
42041	liitpered	pere	liit+pere	16_S	PlN	et	liitpered =pere  (PlN  >liit+pere !16_S
42046	jalatsite	jalatsi	jalats	02_S	PlG	et	jalatsite =jalatsi  (PlG  >jalats !02_S
42054	kasvatusüksus	üksus	kasvatus+üksus	11~09_S	SgN	et	kasvatusüksus =üksus  (SgN  >kasvatus+üksus !11~09_S
42057	poegade	poega	poeg	22_S	PlG	et	poegade =poega  (PlG  >poeg !22_S
42065	õlgadele	õlga	õlg	22_S	PlAll	et	õlgadele =õlga  (PlAll  >õlg !22_S
42066	järk-järgult	järgu	järk-järk	22_S	SgAbl	et	järk-järgult =järgu  (SgAbl  >järk-järk !22_S
42067	naistetöid	tö	naiste+töö	26_S	PlP	et	naistetöid =tö  (PlP  >naiste+töö !26_S
42073	vabadikuks	vabadiku	vabadik	25_S	SgTr	et	vabadikuks =vabadiku  (SgTr  >vabadik !25_S
42079	teoorjuse	orjuse	teo+orjus	11~09_S	SgG	et	teoorjuse =orjuse  (SgG  >teo+orjus !11~09_S
42083	siitpeale	siitpeale	siit+peale	41_D	ID	et	siitpeale =siitpeale  (ID  >siit+peale !41_D
42088	töölisperedeks	pere	töölis+pere	16_S	PlTr	et	töölisperedeks =pere  (PlTr  >töölis+pere !16_S
42096	vastuolus	olu	vastu+olu	17_S	SgIn	et	vastuolus =olu  (SgIn  >vastu+olu !17_S
42099	põhikoormus	koormus	põhi+koormus	11~09_S	SgN	et	põhikoormus =koormus  (SgN  >põhi+koormus !11~09_S
42100	loomulikuks	loomuliku	loomulik	25_A	SgTr	et	loomulikuks =loomuliku  (SgTr  >loomulik !25_A
42106	elanikel	elanike	elanik	25_S	PlAd	et	elanikel =elanike  (PlAd  >elanik !25_S
42119	soojas	sooja	soe	24_AS	SgIn	et	soojas =sooja  (SgIn  >soe !24_AS
42121	mõnest	mõne	mõni	20_P	SgEl	et	mõnest =mõne  (SgEl  >mõni !20_P
42127	romantikaga	romantika	romantika	01_S	SgKom	et	romantikaga =romantika  (SgKom  >romantika !01_S
42128	paljudega	palju	palju	16_P	PlKom	et	paljudega =palju  (PlKom  >palju !16_P
42134	viikingid	viikingi	viiking	02_S	PlN	et	viikingid =viikingi  (PlN  >viiking !02_S
42135	millistel	millis	milline	10_P	PlAd	et	millistel =millis  (PlAd  >milline !10_P
42137	raudsest	raudse	raudne	02_A	SgEl	et	raudsest =raudse  (SgEl  >raudne !02_A
42140	lõpuosas	osa	lõpu+osa	17_S	SgIn	et	lõpuosas =osa  (SgIn  >lõpu+osa !17_S
42144	kindlustunnet	tunne	kindlus+tunne	06_S	SgP	et	kindlustunnet =tunne  (SgP  >kindlus+tunne !06_S
42145	mehenaisega	naise	mehe+naine	12_S	SgKom	et	mehenaisega =naise  (SgKom  >mehe+naine !12_S
42146	enesekaitseks	kaitse	enese+kaitse	06_S	SgTr	et	enesekaitseks =kaitse  (SgTr  >enese+kaitse !06_S
42149	väljapääsväljund	väljund	välja+pääs+väljund	02_S	SgN	et	väljapääsväljund =väljund  (SgN  >välja+pääs+väljund !02_S
42161	heaga	hea	hea	26_AS	SgKom	et	heaga =hea  (SgKom  >hea !26_AS
42169	peaosas	osa	pea+osa	17_S	SgIn	et	peaosas =osa  (SgIn  >pea+osa !17_S
42175	näidendite	näidendi	näidend	02_S	PlG	et	näidendite =näidendi  (PlG  >näidend !02_S
42176	nimetabki	nimeta	nimetama	27_V	IndPrSg3^	et	nimetabki =nimeta  (IndPrSg3^  >nimetama !27_V
42183	tüüpe	tüüpe	tüüp	22_S	PlP	et	tüüpe =tüüpe  (PlP  >tüüp !22_S
42185	variatsioonidega	variatsiooni	variatsioon	22_S	PlKom	et	variatsioonidega =variatsiooni  (PlKom  >variatsioon !22_S
42186	näidendist	näidendi	näidend	02_S	SgEl	et	näidendist =näidendi  (SgEl  >näidend !02_S
42190	raudsepa	sepa	raud+sepp	22_S	SgG	et	raudsepa =sepa  (SgG  >raud+sepp !22_S
42193	sõjajärgseist	järgse	sõja+järgne	02_A	PlEl	et	sõjajärgseist =järgse  (PlEl  >sõja+järgne !02_A
42195	kannatas	kannata	kannatama	27_V	IndIpfSg3	et	kannatas =kannata  (IndIpfSg3  >kannatama !27_V
42204	rindejoon	joon	rinde+joon	13_S	SgN	et	rindejoon =joon  (SgN  >rinde+joon !13_S
42205	luhtub	luhtu	luhtuma	27_V	IndPrSg3	et	luhtub =luhtu  (IndPrSg3  >luhtuma !27_V
42207	eramut	eramu	eramu	01_S	SgP	et	eramut =eramu  (SgP  >eramu !01_S
42208	kokkuvarisemise	varisemise	kokku+varisemine	12_S	SgG	et	kokkuvarisemise =varisemise  (SgG  >kokku+varisemine !12_S
42220	opereerib	opereeri	opereerima	28_V	IndPrSg3	et	opereerib =opereeri  (IndPrSg3  >opereerima !28_V
42222	uudise	uudise	uudis	09_S	SgG	et	uudise =uudise  (SgG  >uudis !09_S
42224	muretseb	muretse	muretsema	27_V	IndPrSg3	et	muretseb =muretse  (IndPrSg3  >muretsema !27_V
42229	sugulasetest	e	sugulas+esi	15_S	PlEl	et	sugulasetest =e  (PlEl  >sugulas+esi !15_S
42237	tütrele-riigi	riigi	tütrele-riik	22_S	SgG	et	tütrele-riigi =riigi  (SgG  >tütrele-riik !22_S
42239	serviisid	serviisi	serviis	22_S	PlN	et	serviisid =serviisi  (PlN  >serviis !22_S
42029	inimrühmadesse	rühma	inim+rühm	22_S	PlIll	et	inimrühmadesse =rühma  (PlIll  >inim+rühm !22_S
42032	arvamusi	arvamusi	arvamus	11_S	PlP	et	arvamusi =arvamusi  (PlP  >arvamus !11_S
42034	talupered	pere	talu+pere	16_S	PlN	et	talupered =pere  (PlN  >talu+pere !16_S
42043	maavaldus	valdus	maa+valdus	11~09_S	SgN	et	maavaldus =valdus  (SgN  >maa+valdus !11~09_S
42044	haris	hari	harima	27_V	IndIpfSg3	et	haris =hari  (IndIpfSg3  >harima !27_V
42049	tarbeesemetest	eseme	tarbe+ese	04_S	PlEl	et	tarbeesemetest =eseme  (PlEl  >tarbe+ese !04_S
42056	kooskõlastamine	kõlastamine	koos+kõlastamine	12_S	SgN	et	kooskõlastamine =kõlastamine  (SgN  >koos+kõlastamine !12_S
42059	talutöödes	töö	talu+töö	26_S	PlIn	et	talutöödes =töö  (PlIn  >talu+töö !26_S
42064	kaluriperedes	pere	kaluri+pere	16_S	PlIn	et	kaluriperedes =pere  (PlIn  >kaluri+pere !16_S
42070	suurperes	pere	suur+pere	16_S	SgIn	et	suurperes =pere  (SgIn  >suur+pere !16_S
42071	ajutist	ajutis	ajutine	12_A	SgP	et	ajutist =ajutis  (SgP  >ajutine !12_A
42074	talust	talu	talu	17_S	SgEl	et	talust =talu  (SgEl  >talu !17_S
42076	kauemat	kauema	kauem	02_A	SgP	et	kauemat =kauema  (SgP  >kauem !02_A
42078	algupoolel	poole	algu+pool	22_S	PlAd	et	algupoolel =poole  (PlAd  >algu+pool !22_S
42081	perede	pere	pere	16_S	PlG	et	perede =pere  (PlG  >pere !16_S
42082	liitperede	pere	liit+pere	16_S	PlG	et	liitperede =pere  (PlG  >liit+pere !16_S
42094	kerkib	kerki	kerkima	27_V	IndPrSg3	et	kerkib =kerki  (IndPrSg3  >kerkima !27_V
42095	korterites	korteri	korter	02_S	PlIn	et	korterites =korteri  (PlIn  >korter !02_S
42097	elulaadiga	laadi	elu+laad	22_S	SgKom	et	elulaadiga =laadi  (SgKom  >elu+laad !22_S
42108	valgustusajal	aja	valgustus+aeg	22_S	SgAd	et	valgustusajal =aja  (SgAd  >valgustus+aeg !22_S
42109	õigustab	õigusta	õigustama	27_V	IndPrSg3	et	õigustab =õigusta  (IndPrSg3  >õigustama !27_V
42116	peremehena	mehe	pere+mees	13_S	SgEs	et	peremehena =mehe  (SgEs  >pere+mees !13_S
42129	mõttele	mõtte	mõte	06_S	SgAll	et	mõttele =mõtte  (SgAll  >mõte !06_S
42131	ülevaatamisest	vaatamise	üle+vaatamine	12_S	SgEl	et	ülevaatamisest =vaatamise  (SgEl  >üle+vaatamine !12_S
42139	kellatornist	torni	kella+torn	22_S	SgEl	et	kellatornist =torni  (SgEl  >kella+torn !22_S
42141	vaatega	vaate	vaade	06_S	SgKom	et	vaatega =vaate  (SgKom  >vaade !06_S
42142	endiseks	endise	endine	10~12_A	SgTr	et	endiseks =endise  (SgTr  >endine !10~12_A
42151	tsitadell	tsitadell	tsitadell	22_S	SgN	et	tsitadell =tsitadell  (SgN  >tsitadell !22_S
42164	suplust	suplus	suplus	11~09_S	SgP	et	suplust =suplus  (SgP  >suplus !11~09_S
42167	sõjajärgne	järgne	sõja+järgne	02_A	SgN	et	sõjajärgne =järgne  (SgN  >sõja+järgne !02_A
42170	näidend	näidend	näidend	02_S	SgN	et	näidend =näidend  (SgN  >näidend !02_S
42173	rõhuasetused	asetuse	rõhu+asetus	11_S	PlN	et	rõhuasetused =asetuse  (PlN  >rõhu+asetus !11_S
42184	rändab	rända	rändama	29_V	IndPrSg3	et	rändab =rända  (IndPrSg3  >rändama !29_V
42187	näidendisse	näidendi	näidend	02_S	SgIll	et	näidendisse =näidendi  (SgIll  >näidend !02_S
42202	eirates	eira	eirama	29_V	Ger	et	eirates =eira  (Ger  >eirama !29_V
42210	perekonnaliikmed	liikme	pere+konna+liige	05_S	PlN	et	perekonnaliikmed =liikme  (PlN  >pere+konna+liige !05_S
42213	onupoeg	poeg	onu+poeg	22_S	SgN	et	onupoeg =poeg  (SgN  >onu+poeg !22_S
42219	opereerida	opereeri	opereerima	28_V	Inf	et	opereerida =opereeri  (Inf  >opereerima !28_V
42230	vabadusvõitlejate	võitleja	vabadus+võitleja	01_SA	PlG	et	vabadusvõitlejate =võitleja  (PlG  >vabadus+võitleja !01_SA
42231	ridadesse	rida	rida	18_S	PlIll	et	ridadesse =rida  (PlIll  >rida !18_S
42232	armub	armu	armuma	27_V	IndPrSg3	et	armub =armu  (IndPrSg3  >armuma !27_V
42233	katsub	katsu	katsuma	28_V	IndPrSg3	et	katsub =katsu  (IndPrSg3  >katsuma !28_V
42245	lõppleheküljel	külje	lõpp+lehe+külg	22_S	SgAd	et	lõppleheküljel =külje  (SgAd  >lõpp+lehe+külg !22_S
42247	esilehel	lehe	esi+leht	22_S	SgAd	et	esilehel =lehe  (SgAd  >esi+leht !22_S
42253	linnauudised	uudise	linna+uudis	09_S	PlN	et	linnauudised =uudise  (PlN  >linna+uudis !09_S
42269	juhtlõigud	lõigu	juht+lõik	22_S	PlN	et	juhtlõigud =lõigu  (PlN  >juht+lõik !22_S
42273	pealkirjadest	kirja	peal+kiri	24_S	PlEl	et	pealkirjadest =kirja  (PlEl  >peal+kiri !24_S
42276	reeglis	reegli	reegel	02_S	SgIn	et	reeglis =reegli  (SgIn  >reegel !02_S
42280	pöördkiri	kiri	pöörd+kiri	24_S	SgN	et	pöördkiri =kiri  (SgN  >pöörd+kiri !24_S
42281	infoga	info	info	16_S	SgKom	et	infoga =info  (SgKom  >info !16_S
42286	tekstiga	teksti	tekst	22_S	SgKom	et	tekstiga =teksti  (SgKom  >tekst !22_S
42291	tõllarattad	ratta	tõlla+ratas	07_S	PlN	et	tõllarattad =ratta  (PlN  >tõlla+ratas !07_S
42293	kaksiklehekülje	külje	kaksik+lehe+külg	22_S	SgG	et	kaksiklehekülje =külje  (SgG  >kaksik+lehe+külg !22_S
42110	käies	käi	käima	38_V	Ger	et	käies =käi  (Ger  >käima !38_V
42111	külaeluga	elu	küla+elu	17_S	SgKom	et	külaeluga =elu  (SgKom  >küla+elu !17_S
42115	kehtimast	kehti	kehtima	27_V	SupEl	et	kehtimast =kehti  (SupEl  >kehtima !27_V
42117	rahva-	rahva	rahvas	07_S	SgG	et	rahva- =rahva  (SgG  >rahvas !07_S
42123	tühjades	tühja	tühi	24_A	PlIn	et	tühjades =tühja  (PlIn  >tühi !24_A
42130	majadega	maja	maja	17_S	PlKom	et	majadega =maja  (PlKom  >maja !17_S
42133	varjaagid	varjaagi	varjaag	22_S	PlN	et	varjaagid =varjaagi  (PlN  >varjaag !22_S
42138	efektiga	efekti	efekt	22_S	SgKom	et	efektiga =efekti  (SgKom  >efekt !22_S
42147	relv	relv	relv	22_S	SgN	et	relv =relv  (SgN  >relv !22_S
42150	kaalub	kaalu	kaaluma	28_V	IndPrSg3	et	kaalub =kaalu  (IndPrSg3  >kaaluma !28_V
42152	kaitseefektile	efekti	kaitse+efekt	22_S	SgAll	et	kaitseefektile =efekti  (SgAll  >kaitse+efekt !22_S
42153	iseasi	asi	ise+asi	24_S	SgN	et	iseasi =asi  (SgN  >ise+asi !24_S
42154	varjutas	varjuta	varjutama	27_V	IndIpfSg3	et	varjutas =varjuta  (IndIpfSg3  >varjutama !27_V
42158	sõjaolukorras	korra	sõja+olu+kord	22_S	SgIn	et	sõjaolukorras =korra  (SgIn  >sõja+olu+kord !22_S
42163	avalikke	avalikke	avalik	25_A	PlP	et	avalikke =avalikke  (PlP  >avalik !25_A
42165	tallinnfilm	film	tallinn+film	22_S	SgN	et	tallinnfilm =film  (SgN  >tallinn+film !22_S
42192	karjäärile	karjääri	karjäär	22_S	SgAll	et	karjäärile =karjääri  (SgAll  >karjäär !22_S
42196	hiljemgi	hiljem	hiljem	41_D	ID^	et	hiljemgi =hiljem  (ID^  >hiljem !41_D
42198	amalgaam	amalgaam	amalgaam	22_S	SgN	et	amalgaam =amalgaam  (SgN  >amalgaam !22_S
42199	prototüübiks	prototüübi	prototüüp	22_S	SgTr	et	prototüübiks =prototüübi  (SgTr  >prototüüp !22_S
42214	loodab	looda	lootma	34_V	IndPrSg3	et	loodab =looda  (IndPrSg3  >lootma !34_V
42216	teadusele	teaduse	teadus	11~09_S	SgAll	et	teadusele =teaduse  (SgAll  >teadus !11~09_S
42217	äkiline	äkiline	äkiline	12_A	SgN	et	äkiline =äkiline  (SgN  >äkiline !12_A
42226	kuritegijad	tegija	kuri+tegija	01_S	PlN	et	kuritegijad =tegija  (PlN  >kuri+tegija !01_S
42236	rumalaks	rumala	rumal	02_A	SgTr	et	rumalaks =rumala  (SgTr  >rumal !02_A
42240	kleidid	kleidi	kleit	22_S	PlN	et	kleidid =kleidi  (PlN  >kleit !22_S
42244	spordiosakond	osakond	spordi+osakond	22_S	SgN	et	spordiosakond =osakond  (SgN  >spordi+osakond !22_S
42254	paigutama	paiguta	paigutama	27_V	Sup	et	paigutama =paiguta  (Sup  >paigutama !27_V
42259	koondata	koonda	koondama	27_V	IndPrIps_	et	koondata =koonda  (IndPrIps_  >koondama !27_V
42263	naisteleht	leht	naiste+leht	22_S	SgN	et	naisteleht =leht  (SgN  >naiste+leht !22_S
42268	stiiliga	stiili	stiil	22_S	SgKom	et	stiiliga =stiili  (SgKom  >stiil !22_S
42278	rasteris	rasteri	raster	02_S	SgIn	et	rasteris =rasteri  (SgIn  >raster !02_S
42296	osakonnade	konna	osa+konn	22_S	PlG	et	osakonnade =konna  (PlG  >osa+konn !22_S
42297	kirjatüüp	tüüp	kirja+tüüp	22_S	SgN	et	kirjatüüp =tüüp  (SgN  >kirja+tüüp !22_S
42298	kirjastiile	stiile	kirja+stiil	22_S	PlP	et	kirjastiile =stiile  (PlP  >kirja+stiil !22_S
42311	üksteiselt	teise	üks+teise	12_P	SgAbl	et	üksteiselt =teise  (SgAbl  >üks+teise !12_P
42316	tiiteltähed	tähe	tiitel+täht	22_S	PlN	et	tiiteltähed =tähe  (PlN  >tiitel+täht !22_S
42318	alapealkirjad	kirja	ala+peal+kiri	24_S	PlN	et	alapealkirjad =kirja  (PlN  >ala+peal+kiri !24_S
42319	esiletõstmiseks	tõstmise	esile+tõstmine	12?10_S	SgTr	et	esiletõstmiseks =tõstmise  (SgTr  >esile+tõstmine !12?10_S
42323	lõikudeks	lõiku	lõik	22_S	PlTr	et	lõikudeks =lõiku  (PlTr  >lõik !22_S
42337	liitlauses	lause	liit+lause	06_S	SgIn	et	liitlauses =lause  (SgIn  >liit+lause !06_S
42354	täiend	täiend	täiend	02_S	SgN	et	täiend =täiend  (SgN  >täiend !02_S
42356	võrdlusastmed	astme	võrdlus+aste	05_S	PlN	et	võrdlusastmed =astme  (PlN  >võrdlus+aste !05_S
42370	odava	odava	odav	02_A	SgG	et	odava =odava  (SgG  >odav !02_A
42373	otsene	otsene	otsene	10_A	SgN	et	otsene =otsene  (SgN  >otsene !10_A
42377	kättemaksuga	maksu	kätte+maks	22_S	SgKom	et	kättemaksuga =maksu  (SgKom  >kätte+maks !22_S
42383	sõnajärjevead	vea	sõna+järje+viga	18_S	PlN	et	sõnajärjevead =vea  (PlN  >sõna+järje+viga !18_S
42384	imet	ime	ime	16_S	SgP	et	imet =ime  (SgP  >ime !16_S
42385	rangeid	range	range	01_A	PlP	et	rangeid =range  (PlP  >range !01_A
42388	sõnajärje-	järje	sõna+järg	22_S	SgG	et	sõnajärje- =järje  (SgG  >sõna+järg !22_S
42390	paar-kolm	kolm	paar-kolm	22_N	SgN	et	paar-kolm =kolm  (SgN  >paar-kolm !22_N
42393	semantikas	semantika	semantika	01_S	SgIn	et	semantikas =semantika  (SgIn  >semantika !01_S
42394	toetusin	toetu	toetuma	27_V	IndIpfSg1	et	toetusin =toetu  (IndIpfSg1  >toetuma !27_V
42398	originaaltekst	tekst	originaal+tekst	22_S	SgN	et	originaaltekst =tekst  (SgN  >originaal+tekst !22_S
42160	muinasjuttudeski	juttu	muinas+jutt	22_S	PlIn^	et	muinasjuttudeski =juttu  (PlIn^  >muinas+jutt !22_S
42162	kinoseansse	seansse	kino+seanss	22_S	PlP	et	kinoseansse =seansse  (PlP  >kino+seanss !22_S
42166	valmib	valmi	valmima	27_V	IndPrSg3	et	valmib =valmi  (IndPrSg3  >valmima !27_V
42168	baasil	baasi	baas	22_S	SgAd	et	baasil =baasi  (SgAd  >baas !22_S
42172	teenides	teeni	teenima	28_V	Ger	et	teenides =teeni  (Ger  >teenima !28_V
42178	tegevusliinid	liini	tegevus+liin	22_S	PlN	et	tegevusliinid =liini  (PlN  >tegevus+liin !22_S
42179	tegelaskond	tegelaskond	tegelaskond	22_S	SgN	et	tegelaskond =tegelaskond  (SgN  >tegelaskond !22_S
42180	remarkides	remarki	remark	22_S	PlIn	et	remarkides =remarki  (PlIn  >remark !22_S
42182	üheülbaline	ülbaline	ühe+ülbaline	12_A	SgN	et	üheülbaline =ülbaline  (SgN  >ühe+ülbaline !12_A
42191	rotid	roti	rott	22_S	PlN	et	rotid =roti  (PlN  >rott !22_S
42194	näidendeist	näidende	näidend	02_S	PlEl	et	näidendeist =näidende  (PlEl  >näidend !02_S
42206	sümboolseks	sümboolse	sümboolne	02_A	SgTr	et	sümboolseks =sümboolse  (SgTr  >sümboolne !02_A
42209	taraga	tara	tara	17_S	SgKom	et	taraga =tara  (SgKom  >tara !17_S
42215	teadusetöös	töö	teaduse+töö	26_S	SgIn	et	teadusetöös =töö  (SgIn  >teaduse+töö !26_S
42218	isalt	isa	isa	17_S	SgAbl	et	isalt =isa  (SgAbl  >isa !17_S
42221	vabastas	vabasta	vabastama	27_V	IndIpfSg3	et	vabastas =vabasta  (IndIpfSg3  >vabastama !27_V
42223	sõdurit	sõduri	sõdur	02_S	SgP	et	sõdurit =sõduri  (SgP  >sõdur !02_S
42225	kaasaitasid	aita	kaas+ait	22_S	PlP	et	kaasaitasid =aita  (PlP  >kaas+ait !22_S
42227	perre	perre	pere	16_S	SgAdt	et	perre =perre  (SgAdt  >pere !16_S
42234	professorile	professori	professor	02_S	SgAll	et	professorile =professori  (SgAll  >professor !02_S
42235	vaenlastega	vaenlas	vaenlane	12?10_S	PlKom	et	vaenlastega =vaenlas  (PlKom  >vaenlane !12?10_S
42238	materiaalsed	materiaalse	materiaalne	02_A	PlN	et	materiaalsed =materiaalse  (PlN  >materiaalne !02_A
42241	üldkujundus	kujundus	üld+kujundus	11_S	SgN	et	üldkujundus =kujundus  (SgN  >üld+kujundus !11_S
42243	poliitikaosakond	osakond	poliitika+osakond	22_S	SgN	et	poliitikaosakond =osakond  (SgN  >poliitika+osakond !22_S
42246	korduse	korduse	kordus	11~09_S	SgG	et	korduse =korduse  (SgG  >kordus !11~09_S
42248	tõmbama	tõmba	tõmbama	29_V	Sup	et	tõmbama =tõmba  (Sup  >tõmbama !29_V
42249	lühiuudiste	uudis	lühi+uudis	09_S	PlG	et	lühiuudiste =uudis  (PlG  >lühi+uudis !09_S
42251	päismiku	miku	päis+mikk	22_S	SgG	et	päismiku =miku  (SgG  >päis+mikk !22_S
42260	ajalooartiklid	artikli	aja+loo+artikkel	02_S	PlN	et	ajalooartiklid =artikli  (PlN  >aja+loo+artikkel !02_S
42261	formaadis	formaadi	formaat	22_S	SgIn	et	formaadis =formaadi  (SgIn  >formaat !22_S
42266	plokk	plokk	plokk	22_S	SgN	et	plokk =plokk  (SgN  >plokk !22_S
42270	põhitekstist	teksti	põhi+tekst	22_S	SgEl	et	põhitekstist =teksti  (SgEl  >põhi+tekst !22_S
42277	leskridu	ridu	lesk+rida	18_S	PlP	et	leskridu =ridu  (PlP  >lesk+rida !18_S
42279	pöördkirjas	kirja	pöörd+kiri	24_S	SgIn	et	pöördkirjas =kirja  (SgIn  >pöörd+kiri !24_S
42282	kaksikleht	leht	kaksik+leht	22_S	SgN	et	kaksikleht =leht  (SgN  >kaksik+leht !22_S
42285	serval	serva	serv	22_S	SgAd	et	serval =serva  (SgAd  >serv !22_S
42290	jääl	jää	jää	26_S	SgAd	et	jääl =jää  (SgAd  >jää !26_S
42292	formaalses	formaalse	formaalne	02_A	SgIn	et	formaalses =formaalse  (SgIn  >formaalne !02_A
42295	osakondades	osakonda	osakond	22_S	PlIn	et	osakondades =osakonda  (PlIn  >osakond !22_S
42300	kujunduselemente	elemente	kujundus+element	22_S	PlP	et	kujunduselemente =elemente  (PlP  >kujundus+element !22_S
42304	sektsiooniks	sektsiooni	sektsioon	22_S	SgTr	et	sektsiooniks =sektsiooni  (SgTr  >sektsioon !22_S
42307	kirjakast	kast	kirja+kast	22_S	SgN	et	kirjakast =kast  (SgN  >kirja+kast !22_S
42313	servades	serva	serv	22_S	PlIn	et	servades =serva  (PlIn  >serv !22_S
42314	lisapealkirjad	kirja	lisa+peal+kiri	24_S	PlN	et	lisapealkirjad =kirja  (PlN  >lisa+peal+kiri !24_S
42320	tsitaatsõnad	sõna	tsitaat+sõna	17_S	PlN	et	tsitaatsõnad =sõna  (PlN  >tsitaat+sõna !17_S
42326	sihitist	sihitis	sihitis	11_S	SgP	et	sihitist =sihitis  (SgP  >sihitis !11_S
42335	elementaarsed	elementaarse	elementaarne	02_A	PlN	et	elementaarsed =elementaarse  (PlN  >elementaarne !02_A
42344	maasse	maa	maa	26_S	SgIll	et	maasse =maa  (SgIll  >maa !26_S
42359	asin	asi	asima	27_V	IndPrSg1	et	asin =asi  (IndPrSg1  >asima !27_V
42363	moodustades	moodusta	moodustama	27_V	Ger	et	moodustades =moodusta  (Ger  >moodustama !27_V
42368	küünlad	küünla	küünal	08_S	PlN	et	küünlad =küünla  (PlN  >küünal !08_S
42369	virgutab	virguta	virgutama	27_V	IndPrSg3	et	virgutab =virguta  (IndPrSg3  >virgutama !27_V
42372	suvilinn	linn	suvi+linn	22_S	SgN	et	suvilinn =linn  (SgN  >suvi+linn !22_S
42378	tulestikuga	tulestiku	tulestik	25_S	SgKom	et	tulestikuga =tulestiku  (SgKom  >tulestik !25_S
42203	vaimutööle	töö	vaimu+töö	26_S	SgAll	et	vaimutööle =töö  (SgAll  >vaimu+töö !26_S
42211	annal	anna	anna	16_S	SgAd	et	annal =anna  (SgAd  >anna !16_S
42212	armees	armee	armee	26_S	SgIn	et	armees =armee  (SgIn  >armee !26_S
42228	ükskõiksed	kõikse	üks+kõikne	02_A	PlN	et	ükskõiksed =kõikse  (PlN  >üks+kõikne !02_A
42256	kultuursündmused	sündmuse	kultuur+sündmus	11~09_S	PlN	et	kultuursündmused =sündmuse  (PlN  >kultuur+sündmus !11~09_S
42257	spordisündmused	sündmuse	spordi+sündmus	11~09_S	PlN	et	spordisündmused =sündmuse  (PlN  >spordi+sündmus !11~09_S
42258	linnasündmuste	sündmus	linna+sündmus	11~09_S	PlG	et	linnasündmuste =sündmus  (PlG  >linna+sündmus !11~09_S
42264	trükikiri	kiri	trüki+kiri	24_S	SgN	et	trükikiri =kiri  (SgN  >trüki+kiri !24_S
42265	põhitekstid	teksti	põhi+tekst	22_S	PlN	et	põhitekstid =teksti  (PlN  >põhi+tekst !22_S
42275	kõrvalekaldumistega	kaldumis	kõrvale+kaldumine	12_S	PlKom	et	kõrvalekaldumistega =kaldumis  (PlKom  >kõrvale+kaldumine !12_S
42284	esileht	leht	esi+leht	22_S	SgN	et	esileht =leht  (SgN  >esi+leht !22_S
42287	illustreerib	illustreeri	illustreerima	28_V	IndPrSg3	et	illustreerib =illustreeri  (IndPrSg3  >illustreerima !28_V
42294	kummalisena	kummalise	kummaline	12_A	SgEs	et	kummalisena =kummalise  (SgEs  >kummaline !12_A
42303	kujundusreeglitele	reegli	kujundus+reegel	02_S	PlAll	et	kujundusreeglitele =reegli  (PlAll  >kujundus+reegel !02_S
42305	osakondade	osakonda	osakond	22_S	PlG	et	osakondade =osakonda  (PlG  >osakond !22_S
42306	alaosakondadeks	osakonda	ala+osakond	22_S	PlTr	et	alaosakondadeks =osakonda  (PlTr  >ala+osakond !22_S
42312	pisilugudel	lugu	pisi+lugu	18_S	PlAd	et	pisilugudel =lugu  (PlAd  >pisi+lugu !18_S
42322	mõlemalt	mõlema	mõlema	02_P	SgAbl	et	mõlemalt =mõlema  (SgAbl  >mõlema !02_P
42324	lihtsustab	lihtsusta	lihtsustama	27_V	IndPrSg3	et	lihtsustab =lihtsusta  (IndPrSg3  >lihtsustama !27_V
42327	nimesõnadest	sõna	nime+sõna	17_S	PlEl	et	nimesõnadest =sõna  (PlEl  >nime+sõna !17_S
42328	kujunduselementidest	elementi	kujundus+element	22_S	PlEl	et	kujunduselementidest =elementi  (PlEl  >kujundus+element !22_S
42331	illustratsioonid	illustratsiooni	illustratsioon	22_S	PlN	et	illustratsioonid =illustratsiooni  (PlN  >illustratsioon !22_S
42332	dramaatilised	dramaatilise	dramaatiline	12_A	PlN	et	dramaatilised =dramaatilise  (PlN  >dramaatiline !12_A
42333	reast	rea	rida	18_S	SgEl	et	reast =rea  (SgEl  >rida !18_S
42334	põhjalikke	põhjalikke	põhjalik	25_A	PlP	et	põhjalikke =põhjalikke  (PlP  >põhjalik !25_A
42338	sääraseid	säärase	säärane	10_P	PlP	et	sääraseid =säärase  (PlP  >säärane !10_P
42349	käändub	käändu	käänduma	27_V	IndPrSg3	et	käändub =käändu  (IndPrSg3  >käänduma !27_V
42350	7-l			xx_Q	SgAd	et	-l =  (SgAd  > !xx_Q
42358	ma-infinitiivist	infinitiivi	ma-infinitiiv	22_S	SgEl	et	ma-infinitiivist =infinitiivi  (SgEl  >ma-infinitiiv !22_S
42364	pöörde	pöörde	pööre	06_S	SgG	et	pöörde =pöörde  (SgG  >pööre !06_S
42382	lubama	luba	lubama	27_V	Sup	et	lubama =luba  (Sup  >lubama !27_V
42389	aegaajavorme	vorme	aega+aja+vorm	22_S	PlP	et	aegaajavorme =vorme  (PlP  >aega+aja+vorm !22_S
42391	morfoloogias	morfoloogia	morfoloogia	01_S	SgIn	et	morfoloogias =morfoloogia  (SgIn  >morfoloogia !01_S
42397	kommentaaridega	kommentaari	kommentaar	22_S	PlKom	et	kommentaaridega =kommentaari  (PlKom  >kommentaar !22_S
42403	oletan	oleta	oletama	27_V	IndPrSg1	et	oletan =oleta  (IndPrSg1  >oletama !27_V
42406	asjatundlikud	tundliku	asja+tundlik	25_A	PlN	et	asjatundlikud =tundliku  (PlN  >asja+tundlik !25_A
42410	kirjapildis	pildi	kirja+pilt	22_S	SgIn	et	kirjapildis =pildi  (SgIn  >kirja+pilt !22_S
42411	interferentsiga	interferentsi	interferents	22_S	SgKom	et	interferentsiga =interferentsi  (SgKom  >interferents !22_S
42414	käänetes	kääne	kääne	06_S	PlIn	et	käänetes =kääne  (PlIn  >kääne !06_S
42415	veinikelder	kelder	veini+kelder	02_S	SgN	et	veinikelder =kelder  (SgN  >veini+kelder !02_S
42422	ülivõrret	võrre	üli+võrre	06_S	SgP	et	ülivõrret =võrre  (SgP  >üli+võrre !06_S
42429	reserveerida	reserveeri	reserveerima	28_V	Inf	et	reserveerida =reserveeri  (Inf  >reserveerima !28_V
42446	sünnitab	sünnita	sünnitama	27_V	IndPrSg3	et	sünnitab =sünnita  (IndPrSg3  >sünnitama !27_V
42448	vaimustan	vaimusta	vaimustama	27_V	IndPrSg1	et	vaimustan =vaimusta  (IndPrSg1  >vaimustama !27_V
42451	tulevikuaspekt	aspekt	tuleviku+aspekt	22_S	SgN	et	tulevikuaspekt =aspekt  (SgN  >tuleviku+aspekt !22_S
42466	kirjalikes	kirjalike	kirjalik	25_A	PlIn	et	kirjalikes =kirjalike  (PlIn  >kirjalik !25_A
42481	tegusõnadest	sõna	tegu+sõna	17_S	PlEl	et	tegusõnadest =sõna  (PlEl  >tegu+sõna !17_S
42483	algvormile	vormi	alg+vorm	22_S	SgAll	et	algvormile =vormi  (SgAll  >alg+vorm !22_S
42492	veesse	vee	vesi	15_S	SgIll	et	veesse =vee  (SgIll  >vesi !15_S
42494	telerile	teleri	teler	02_S	SgAll	et	telerile =teleri  (SgAll  >teler !02_S
42496	tehnikumid	tehnikumi	tehnikum	19_S	PlN	et	tehnikumid =tehnikumi  (PlN  >tehnikum !19_S
42242	miinuseid	miinuse	miinus	09_S	PlP	et	miinuseid =miinuse  (PlP  >miinus !09_S
42250	välisservadel	serva	välis+serv	22_S	PlAd	et	välisservadel =serva  (PlAd  >välis+serv !22_S
42252	mõistlik	mõistlik	mõistlik	25_A	SgN	et	mõistlik =mõistlik  (SgN  >mõistlik !25_A
42255	spordisse	spordi	sport	22_S	SgIll	et	spordisse =spordi  (SgIll  >sport !22_S
42262	viie-	viie	viis	14_N	SgG	et	viie- =viie  (SgG  >viis !14_N
42267	võõrsõnad	sõna	võõr+sõna	17_S	PlN	et	võõrsõnad =sõna  (PlN  >võõr+sõna !17_S
42271	kaksiklehel	lehe	kaksik+leht	22_S	SgAd	et	kaksiklehel =lehe  (SgAd  >kaksik+leht !22_S
42272	murdejoonele	joone	murde+joon	13_S	SgAll	et	murdejoonele =joone  (SgAll  >murde+joon !13_S
42274	nimisõnadest	sõna	nimi+sõna	17_S	PlEl	et	nimisõnadest =sõna  (PlEl  >nimi+sõna !17_S
42283	esileheküljel	külje	esi+lehe+külg	22_S	SgAd	et	esileheküljel =külje  (SgAd  >esi+lehe+külg !22_S
42288	arusaadavas	saadava	aru+saadav	02_A	SgIn	et	arusaadavas =saadava  (SgIn  >aru+saadav !02_A
42289	libedal	libeda	libe	02_AS	SgAd	et	libedal =libeda  (SgAd  >libe !02_AS
42310	eristatakse	erista	eristama	27_V	IndPrIps	et	eristatakse =erista  (IndPrIps  >eristama !27_V
42315	romansi	romansi	romanss	22_S	SgG	et	romansi =romansi  (SgG  >romanss !22_S
42317	osakondadest	osakonda	osakond	22_S	PlEl	et	osakondadest =osakonda  (PlEl  >osakond !22_S
42321	veerudeks	veeru	veer	22_S	PlTr	et	veerudeks =veeru  (PlTr  >veer !22_S
42329	korrastab	korrasta	korrastama	27_V	IndPrSg3	et	korrastab =korrasta  (IndPrSg3  >korrastama !27_V
42330	kujundusvahendeid	vahende	kujundus+vahend	02_S	PlP	et	kujundusvahendeid =vahende  (PlP  >kujundus+vahend !02_S
42336	sarnaneb	sarnane	sarnanema	27_V	IndPrSg3	et	sarnaneb =sarnane  (IndPrSg3  >sarnanema !27_V
42339	vormimoodustuses	moodustuse	vormi+moodustus	11_S	SgIn	et	vormimoodustuses =moodustuse  (SgIn  >vormi+moodustus !11_S
42340	astmes	astme	aste	05_S	SgIn	et	astmes =astme  (SgIn  >aste !05_S
42341	välte	välte	välde	06_S	SgG	et	välte =välte  (SgG  >välde !06_S
42343	tulemusliku	tulemusliku	tulemuslik	25_A	SgG	et	tulemusliku =tulemusliku  (SgG  >tulemuslik !25_A
42347	tegutsetakse	tegutse	tegutsema	27_V	IndPrIps	et	tegutsetakse =tegutse  (IndPrIps  >tegutsema !27_V
42348	küünlapäev	päev	küünla+päev	22_S	SgN	et	küünlapäev =päev  (SgN  >küünla+päev !22_S
42352	põhi-	põhi	põhi	24_S	SgN	et	põhi- =põhi  (SgN  >põhi !24_S
42360	lihtmineviku	mineviku	liht+minevik	25_S	SgG	et	lihtmineviku =mineviku  (SgG  >liht+minevik !25_S
42366	sõnavorm	vorm	sõna+vorm	22_S	SgN	et	sõnavorm =vorm  (SgN  >sõna+vorm !22_S
42367	küünlapäeval	päeva	küünla+päev	22_S	SgAd	et	küünlapäeval =päeva  (SgAd  >küünla+päev !22_S
42371	lise	lise	lise	04_S	SgN	et	lise =lise  (SgN  >lise !04_S
42374	uusmoodustised	moodustise	uus+moodustis	11_S	PlN	et	uusmoodustised =moodustise  (PlN  >uus+moodustis !11_S
42376	kasse	kasse	kass	22_S	PlP	et	kasse =kasse  (PlP  >kass !22_S
42381	keelab	keela	keelama	29_V	IndPrSg3	et	keelab =keela  (IndPrSg3  >keelama !29_V
42392	süntaksis	süntaksi	süntaks	02_S	SgIn	et	süntaksis =süntaksi  (SgIn  >süntaks !02_S
42405	naabruses	naabruse	naabrus	11~09_S	SgIn	et	naabruses =naabruse  (SgIn  >naabrus !11~09_S
42407	konsonandiga	konsonandi	konsonant	22_S	SgKom	et	konsonandiga =konsonandi  (SgKom  >konsonant !22_S
42409	loomulk	mulk	loo+mulk	22_S	SgN	et	loomulk =mulk  (SgN  >loo+mulk !22_S
42412	lihtlausega	lause	liht+lause	06_S	SgKom	et	lihtlausega =lause  (SgKom  >liht+lause !06_S
42416	teatage	teata	teatama	27_V	ImpPrPl2	et	teatage =teata  (ImpPrPl2  >teatama !27_V
42417	reserveerige	reserveeri	reserveerima	28_V	ImpPrPl2	et	reserveerige =reserveeri  (ImpPrPl2  >reserveerima !28_V
42419	kahekordsest	kordse	kahe+kordne	02_AS	SgEl	et	kahekordsest =kordse  (SgEl  >kahe+kordne !02_AS
42420	kompenseerida	kompenseeri	kompenseerima	28_V	Inf	et	kompenseerida =kompenseeri  (Inf  >kompenseerima !28_V
42432	omasest	omase	omane	10_A	SgEl	et	omasest =omase  (SgEl  >omane !10_A
42434	vigadele	viga	viga	18_S	PlAll	et	vigadele =viga  (PlAll  >viga !18_S
42435	lihvima	lihvi	lihvima	28_V	Sup	et	lihvima =lihvi  (Sup  >lihvima !28_V
42440	sõnavalik	valik	sõna+valik	02_S	SgN	et	sõnavalik =valik  (SgN  >sõna+valik !02_S
42443	kujutad	kujuta	kujutama	27_V	IndPrSg2	et	kujutad =kujuta  (IndPrSg2  >kujutama !27_V
42449	sõprust	sõprus	sõprus	11~09_S	SgP	et	sõprust =sõprus  (SgP  >sõprus !11~09_S
42452	tõlkelaen	laen	tõlke+laen	22_S	SgN	et	tõlkelaen =laen  (SgN  >tõlke+laen !22_S
42456	isiksus	isiksus	isiksus	11_S	SgN	et	isiksus =isiksus  (SgN  >isiksus !11_S
42457	andestada	andesta	andestama	27_V	Inf	et	andestada =andesta  (Inf  >andestama !27_V
42460	mitmust	mitmus	mitmus	11~09_S	SgP	et	mitmust =mitmus  (SgP  >mitmus !11~09_S
42464	keeleklassidega	klassi	keele+klass	22_S	PlKom	et	keeleklassidega =klassi  (PlKom  >keele+klass !22_S
42299	ükskülgne	külgne	üks+külgne	02_A	SgN	et	ükskülgne =külgne  (SgN  >üks+külgne !02_A
42301	sisaldaks	sisalda	sisaldama	27_V	KndPrPs	et	sisaldaks =sisalda  (KndPrPs  >sisaldama !27_V
42302	põhilugude	lugu	põhi+lugu	18_S	PlG	et	põhilugude =lugu  (PlG  >põhi+lugu !18_S
42308	katkend	katkend	katkend	02_S	SgN	et	katkend =katkend  (SgN  >katkend !02_S
42309	varieerub	varieeru	varieeruma	27_V	IndPrSg3	et	varieerub =varieeru  (IndPrSg3  >varieeruma !27_V
42325	selged	selge	selge	01_A	PlN	et	selged =selge  (PlN  >selge !01_A
42342	keelesisene	sisene	keele+sisene	10_A	SgN	et	keelesisene =sisene  (SgN  >keele+sisene !10_A
42345	sisekohakäänet	kääne	sise+koha+kääne	06_S	SgP	et	sisekohakäänet =kääne  (SgP  >sise+koha+kääne !06_S
42346	kaar	kaar	kaar	13_S	SgN	et	kaar =kaar  (SgN  >kaar !13_S
42351	eristata	erista	eristama	27_V	IndPrIps_	et	eristata =erista  (IndPrIps_  >eristama !27_V
42353	laus	lau	laug	22_SA	SgIn	et	laus =lau  (SgIn  >laug !22_SA
42355	täiendid	täiendi	täiend	02_S	PlN	et	täiendid =täiendi  (PlN  >täiend !02_S
42357	moodustub	moodustu	moodustuma	27_V	IndPrSg3	et	moodustub =moodustu  (IndPrSg3  >moodustuma !27_V
42361	pöördelõpp	lõpp	pöörde+lõpp	22_SA	SgN	et	pöördelõpp =lõpp  (SgN  >pöörde+lõpp !22_SA
42362	pöördelõpuna	lõpu	pöörde+lõpp	22_SA	SgEs	et	pöördelõpuna =lõpu  (SgEs  >pöörde+lõpp !22_SA
42365	algperioodil	perioodi	alg+periood	22_S	SgAd	et	algperioodil =perioodi  (SgAd  >alg+periood !22_S
42375	keki	keki	kekk	22_A	SgG	et	keki =keki  (SgG  >kekk !22_A
42379	rektsioonid	rektsiooni	rektsioon	22_S	PlN	et	rektsioonid =rektsiooni  (PlN  >rektsioon !22_S
42380	rõõmustama	rõõmusta	rõõmustama	27_V	Sup	et	rõõmustama =rõõmusta  (Sup  >rõõmustama !27_V
42386	venekeelse	keelse	vene+keelne	02_A	SgG	et	venekeelse =keelse  (SgG  >vene+keelne !02_A
42396	soomlasega	soomlase	soomlane	12?10_S	SgKom	et	soomlasega =soomlase  (SgKom  >soomlane !12?10_S
42400	menüült	menüü	menüü	26_S	SgAbl	et	menüült =menüü  (SgAbl  >menüü !26_S
42401	restoranil	restorani	restoran	19_S	SgAd	et	restoranil =restorani  (SgAd  >restoran !19_S
42402	kõrgklassist	klassi	kõrg+klass	22_S	SgEl	et	kõrgklassist =klassi  (SgEl  >kõrg+klass !22_S
42404	tagavokaal	vokaal	taga+vokaal	22_S	SgN	et	tagavokaal =vokaal  (SgN  >taga+vokaal !22_S
42413	omadussõnad	sõna	omadus+sõna	17_S	PlN	et	omadussõnad =sõna  (PlN  >omadus+sõna !17_S
42426	roogasid	rooga	roog	22_S	PlP	et	roogasid =rooga  (PlP  >roog !22_S
42431	laudasid	lauda	laud	22_S	PlP	et	laudasid =lauda  (PlP  >laud !22_S
42433	subjektiivne	subjektiivne	subjektiivne	02_A	SgN	et	subjektiivne =subjektiivne  (SgN  >subjektiivne !02_A
42436	naljakat	naljaka	naljakas	02_A	SgP	et	naljakat =naljaka  (SgP  >naljakas !02_A
42437	lausepooles	poole	lause+pool	22_S	PlIn	et	lausepooles =poole  (PlIn  >lause+pool !22_S
42442	austata	austa	austama	27_V	IndPrIps_	et	austata =austa  (IndPrIps_  >austama !27_V
42463	praktikatundidest	tundi	praktika+tund	22_S	PlEl	et	praktikatundidest =tundi  (PlEl  >praktika+tund !22_S
42472	kirjutata	kirjuta	kirjutama	27_V	IndPrIps_	et	kirjutata =kirjuta  (IndPrIps_  >kirjutama !27_V
42473	häälikuid	hääliku	häälik	02_S	PlP	et	häälikuid =hääliku  (PlP  >häälik !02_S
42474	tajuma	taju	tajuma	27_V	Sup	et	tajuma =taju  (Sup  >tajuma !27_V
42486	kasutataksegi	kasuta	kasutama	27_V	IndPrIps^	et	kasutataksegi =kasuta  (IndPrIps^  >kasutama !27_V
42489	kohakäändeid	käände	koha+kääne	06_S	PlP	et	kohakäändeid =käände  (PlP  >koha+kääne !06_S
42490	väliskohakäändeid	käände	välis+koha+kääne	06_S	PlP	et	väliskohakäändeid =käände  (PlP  >välis+koha+kääne !06_S
42499	lõputäishäälik	häälik	lõpu+täis+häälik	02_S	SgN	et	lõputäishäälik =häälik  (SgN  >lõpu+täis+häälik !02_S
42504	autojuht	juht	auto+juht	22_S	SgN	et	autojuht =juht  (SgN  >auto+juht !22_S
42508	sõnajärjed	järje	sõna+järg	22_S	PlN	et	sõnajärjed =järje  (PlN  >sõna+järg !22_S
42510	tagajärjena	järje	taga+järg	22_S	SgEs	et	tagajärjena =järje  (SgEs  >taga+järg !22_S
42519	despoodi	despoodi	despoot	22_S	SgG	et	despoodi =despoodi  (SgG  >despoot !22_S
42520	reformaatorite	reformaatori	reformaator	02_S	PlG	et	reformaatorite =reformaatori  (PlG  >reformaator !02_S
42526	rumeenlased	rumeenlase	rumeenlane	12?10_S	PlN	et	rumeenlased =rumeenlase  (PlN  >rumeenlane !12?10_S
42531	avalikuks	avaliku	avalik	25_A	SgTr	et	avalikuks =avaliku  (SgTr  >avalik !25_A
42534	piiblid	piibli	piibel	02_S	PlN	et	piiblid =piibli  (PlN  >piibel !02_S
42539	valikud	valiku	valik	02_S	PlN	et	valikud =valiku  (PlN  >valik !02_S
42541	kirikuorganisatsiooniga	organisatsiooni	kiriku+organisatsioon	22_S	SgKom	et	kirikuorganisatsiooniga =organisatsiooni  (SgKom  >kiriku+organisatsioon !22_S
42544	vigasid	viga	viga	18_S	PlP	et	vigasid =viga  (PlP  >viga !18_S
42547	elanikkonna	elanikkonna	elanikkond	22_S	SgG	et	elanikkonna =elanikkonna  (SgG  >elanikkond !22_S
42387	ajavorm	vorm	aja+vorm	22_S	SgN	et	ajavorm =vorm  (SgN  >aja+vorm !22_S
42395	keelekursuse	kursuse	keele+kursus	11~09_S	SgG	et	keelekursuse =kursuse  (SgG  >keele+kursus !11~09_S
42408	tagavokaalide	vokaali	taga+vokaal	22_S	PlG	et	tagavokaalide =vokaali  (PlG  >taga+vokaal !22_S
42418	alalütlev	ütlev	alal+ütlev	02_A	SgN	et	alalütlev =ütlev  (SgN  >alal+ütlev !02_A
42421	omadussõnadega	sõna	omadus+sõna	17_S	PlKom	et	omadussõnadega =sõna  (PlKom  >omadus+sõna !17_S
42425	sõnamoodustuse	moodustuse	sõna+moodustus	11_S	SgG	et	sõnamoodustuse =moodustuse  (SgG  >sõna+moodustus !11_S
42427	kontekstile	konteksti	kontekst	22_S	SgAll	et	kontekstile =konteksti  (SgAll  >kontekst !22_S
42428	kelneritega	kelneri	kelner	02_S	PlKom	et	kelneritega =kelneri  (PlKom  >kelner !02_S
42441	inimeset	ese	inim+ese	04_S	SgP	et	inimeset =ese  (SgP  >inim+ese !04_S
42445	kirjutamisvead	vea	kirjutamis+viga	18_S	PlN	et	kirjutamisvead =vea  (PlN  >kirjutamis+viga !18_S
42453	antrakt	antrakt	antrakt	22_S	SgN	et	antrakt =antrakt  (SgN  >antrakt !22_S
42454	sõnaühendi	ühendi	sõna+ühend	02_S	SgG	et	sõnaühendi =ühendi  (SgG  >sõna+ühend !02_S
42455	sõnavaliku	valiku	sõna+valik	02_S	SgG	et	sõnavaliku =valiku  (SgG  >sõna+valik !02_S
42465	laialdaste	laialdas	laialdane	12_A	PlG	et	laialdaste =laialdas  (PlG  >laialdane !12_A
42470	madala	madala	madal	02_AS	SgG	et	madala =madala  (SgG  >madal !02_AS
42476	alljärgnevate	järgneva	all+järgnev	02_A	PlG	et	alljärgnevate =järgneva  (PlG  >all+järgnev !02_A
42479	automaaler	maaler	auto+maaler	02_S	SgN	et	automaaler =maaler  (SgN  >auto+maaler !02_S
42485	rattas	ratta	ratas	07_S	SgIn	et	rattas =ratta  (SgIn  >ratas !07_S
42491	sisekohakäändeid	käände	sise+koha+kääne	06_S	PlP	et	sisekohakäändeid =käände  (PlP  >sise+koha+kääne !06_S
42495	majani	maja	maja	17_S	SgTer	et	majani =maja  (SgTer  >maja !17_S
42500	ott	ott	ott	22_S	SgN	et	ott =ott  (SgN  >ott !22_S
42505	neljakesi	neljakesi	neljakesi	41_D	ID	et	neljakesi =neljakesi  (ID  >neljakesi !41_D
42509	domineerima	domineeri	domineerima	28_V	Sup	et	domineerima =domineeri  (Sup  >domineerima !28_V
42511	protestantide	protestanti	protestant	22_S	PlG	et	protestantide =protestanti  (PlG  >protestant !22_S
42514	lausesõnajärjevead	vea	lause+sõna+järje+viga	18_S	PlN	et	lausesõnajärjevead =vea  (PlN  >lause+sõna+järje+viga !18_S
42523	teenuseks	teenuse	teenus	09_S	SgTr	et	teenuseks =teenuse  (SgTr  >teenus !09_S
42525	käänes	kääne	käänd	22_S	PlIn	et	käänes =kääne  (PlIn  >käänd !22_S
42528	sätestati	sätesta	sätestama	27_V	IndIpfIps	et	sätestati =sätesta  (IndIpfIps  >sätestama !27_V
42533	juhal	juha	juha	17_S	SgAd	et	juhal =juha  (SgAd  >juha !17_S
42548	neljakümnest	kümnes	nelja+kümnene	10~12_AS	SgP	et	neljakümnest =kümnes  (SgP  >nelja+kümnene !10~12_AS
42549	piirdub	piirdu	piirduma	27_V	IndPrSg3	et	piirdub =piirdu  (IndPrSg3  >piirduma !27_V
42552	kirjandis	kirjandi	kirjand	02_S	SgIn	et	kirjandis =kirjandi  (SgIn  >kirjand !02_S
42556	venekeelsega	keelse	vene+keelne	02_A	SgKom	et	venekeelsega =keelse  (SgKom  >vene+keelne !02_A
42559	vigades	viga	viga	18_S	PlIn	et	vigades =viga  (PlIn  >viga !18_S
42561	piirdus	piirdu	piirduma	27_V	IndIpfSg3	et	piirdus =piirdu  (IndIpfSg3  >piirduma !27_V
42576	grammatilistele	grammatilis	grammatiline	12_A	PlAll	et	grammatilistele =grammatilis  (PlAll  >grammatiline !12_A
42580	hääldame	häälda	hääldama	27_V	IndPrPl1	et	hääldame =häälda  (IndPrPl1  >hääldama !27_V
42581	infinitiivis	infinitiivi	infinitiiv	22_S	SgIn	et	infinitiivis =infinitiivi  (SgIn  >infinitiiv !22_S
42584	tüüpsõnu	sõnu	tüüp+sõna	17_S	PlP	et	tüüpsõnu =sõnu  (PlP  >tüüp+sõna !17_S
42586	sihitiste	sihitis	sihitis	11_S	PlG	et	sihitiste =sihitis  (PlG  >sihitis !11_S
42596	valikuvead	vea	valiku+viga	18_S	PlN	et	valikuvead =vea  (PlN  >valiku+viga !18_S
42606	lahedast	laheda	lahe	02_A	SgEl	et	lahedast =laheda  (SgEl  >lahe !02_A
42618	puudis	puudi	puud	22_S	PlIn	et	puudis =puudi  (PlIn  >puud !22_S
42621	telesaated	saate	tele+saade	06_S	PlN	et	telesaated =saate  (PlN  >tele+saade !06_S
42626	johtus	johtu	johtuma	27_V	IndIpfSg3	et	johtus =johtu  (IndIpfSg3  >johtuma !27_V
42629	itta	itta	ida	17_S	SgAdt	et	itta =itta  (SgAdt  >ida !17_S
42642	keeleseaduse	seaduse	keele+seadus	11~09_S	SgG	et	keeleseaduse =seaduse  (SgG  >keele+seadus !11~09_S
42646	eduga	edu	edu	17_S	SgKom	et	eduga =edu  (SgKom  >edu !17_S
42648	keeltele	keel	keel	13_S	PlAll	et	keeltele =keel  (PlAll  >keel !13_S
42650	silbi	silbi	silp	22_S	SgG	et	silbi =silbi  (SgG  >silp !22_S
42654	kodus-oled	ole	kodus-olema	36_V	IndPrSg2	et	kodus-oled =ole  (IndPrSg2  >kodus-olema !36_V
42658	kapsasupp	supp	kapsa+supp	22_S	SgN	et	kapsasupp =supp  (SgN  >kapsa+supp !22_S
42674	kõrvallaused	lause	kõrval+lause	06_S	PlN	et	kõrvallaused =lause  (PlN  >kõrval+lause !06_S
42399	ühke	ühke	ühe	06_S	SgG	et	ühke =ühke  (SgG  >ühe !06_S
42423	planeerima	planeeri	planeerima	28_V	Sup	et	planeerima =planeeri  (Sup  >planeerima !28_V
42424	tsementeerima	tsementeeri	tsementeerima	28_V	Sup	et	tsementeerima =tsementeeri  (Sup  >tsementeerima !28_V
42430	tellitakse	telli	tellima	28_V	IndPrIps	et	tellitakse =telli  (IndPrIps  >tellima !28_V
42438	partitiiv	partitiiv	partitiiv	22_S	SgN	et	partitiiv =partitiiv  (SgN  >partitiiv !22_S
42439	vaatate	vaata	vaatama	29_V	IndPrPl2	et	vaatate =vaata  (IndPrPl2  >vaatama !29_V
42444	kõiketega	e	kõik+esi	15_S	PlKom	et	kõiketega =e  (PlKom  >kõik+esi !15_S
42447	mõtteist	mõtte	mõte	06_S	PlEl	et	mõtteist =mõtte  (PlEl  >mõte !06_S
42450	paralleelne	paralleelne	paralleelne	02_A	SgN	et	paralleelne =paralleelne  (SgN  >paralleelne !02_A
42458	pronoomenit	pronoomeni	pronoomen	02_S	SgP	et	pronoomenit =pronoomeni  (SgP  >pronoomen !02_S
42459	kunstid	kunsti	kunst	22_S	PlN	et	kunstid =kunsti  (PlN  >kunst !22_S
42461	sõnaühendis	ühendi	sõna+ühend	02_S	SgIn	et	sõnaühendis =ühendi  (SgIn  >sõna+ühend !02_S
42462	anglitsisme	anglitsisme	anglitsism	22_S	PlP	et	anglitsisme =anglitsisme  (PlP  >anglitsism !22_S
42467	sõnavalikuvigu	vigu	sõna+valiku+viga	18_S	PlP	et	sõnavalikuvigu =vigu  (PlP  >sõna+valiku+viga !18_S
42469	koolidest	kooli	kool	22_S	PlEl	et	koolidest =kooli  (PlEl  >kool !22_S
42471	algtasemel	taseme	alg+tase	04_S	SgAd	et	algtasemel =taseme  (SgAd  >alg+tase !04_S
42477	oskusega	oskuse	oskus	11~09_S	SgKom	et	oskusega =oskuse  (SgKom  >oskus !11~09_S
42487	peatab	peata	peatama	27_V	IndPrSg3	et	peatab =peata  (IndPrSg3  >peatama !27_V
42506	autojuhid	juhi	auto+juht	22_S	PlN	et	autojuhid =juhi  (PlN  >auto+juht !22_S
42512	ss-ga	ss	ss	xx_Q	SgKom	et	ss-ga =ss  (SgKom  >ss !xx_Q
42515	lähtuti	lähtu	lähtuma	27_V	IndIpfIps	et	lähtuti =lähtu  (IndIpfIps  >lähtuma !27_V
42536	võimude	võimu	võim	22_S	PlG	et	võimude =võimu  (PlG  >võim !22_S
42537	protestandid	protestandi	protestant	22_S	PlN	et	protestandid =protestandi  (PlN  >protestant !22_S
42540	tegurit	teguri	tegur	02_S	SgP	et	tegurit =teguri  (SgP  >tegur !02_S
42551	kirjatöödes	töö	kirja+töö	26_S	PlIn	et	kirjatöödes =töö  (PlIn  >kirja+töö !26_S
42553	mäletaksime	mäleta	mäletama	27_V	KndPrPl1	et	mäletaksime =mäleta  (KndPrPl1  >mäletama !27_V
42567	intonatsioonile	intonatsiooni	intonatsioon	22_S	SgAll	et	intonatsioonile =intonatsiooni  (SgAll  >intonatsioon !22_S
42573	taolised	taolise	taoline	12?10_A	PlN	et	taolised =taolise  (PlN  >taoline !12?10_A
42578	kesklinnagümnaasiumis	gümnaasiumi	kesk+linna+gümnaasium	19~02_S	SgIn	et	kesklinnagümnaasiumis =gümnaasiumi  (SgIn  >kesk+linna+gümnaasium !19~02_S
42579	eratundides	tundi	era+tund	22_S	PlIn	et	eratundides =tundi  (PlIn  >era+tund !22_S
42587	ekskursioonidele	ekskursiooni	ekskursioon	22_S	PlAll	et	ekskursioonidele =ekskursiooni  (PlAll  >ekskursioon !22_S
42589	tekitabki	tekita	tekitama	27_V	IndPrSg3^	et	tekitabki =tekita  (IndPrSg3^  >tekitama !27_V
42590	perekonnaliikmeid	liikme	pere+konna+liige	05_S	PlP	et	perekonnaliikmeid =liikme  (PlP  >pere+konna+liige !05_S
42592	ülevale	üleva	ülev	02_A	SgAll	et	ülevale =üleva  (SgAll  >ülev !02_A
42595	õppur	õppur	õppur	02_S	SgN	et	õppur =õppur  (SgN  >õppur !02_S
42604	tatarlastega	tatarlas	tatarlane	12_S	PlKom	et	tatarlastega =tatarlas  (PlKom  >tatarlane !12_S
42612	niideti	niide	niitma	34_V	IndIpfIps	et	niideti =niide  (IndIpfIps  >niitma !34_V
42613	reht	reht	rehi	24_S	SgP	et	reht =reht  (SgP  >rehi !24_S
42625	70st	st	st	41_I	ID	et	st =st  (ID  >st !41_I
42627	kill	kill	kill	41_I	ID	et	kill =kill  (ID  >kill !41_I
42636	maride	mari	mari	17~16_S	PlG	et	maride =mari  (PlG  >mari !17~16_S
42652	voib-olla	oll	voib-olema	36_V	Inf	et	voib-olla =oll  (Inf  >voib-olema !36_V
42653	kodus-olen	ole	kodus-olema	36_V	IndPrSg1	et	kodus-olen =ole  (IndPrSg1  >kodus-olema !36_V
42656	koduloolased	loolase	kodu+loolane	12?10_S	PlN	et	koduloolased =loolase  (PlN  >kodu+loolane !12?10_S
42662	noorukid	nooruki	nooruk	02_S	PlN	et	noorukid =nooruki  (PlN  >nooruk !02_S
42670	valitsusajale	aja	valitsus+aeg	22_S	SgAll	et	valitsusajale =aja  (SgAll  >valitsus+aeg !22_S
42677	staatust	staatus	staatus	11~09_S	SgP	et	staatust =staatus  (SgP  >staatus !11~09_S
42687	eluarenemisest	arenemise	elu+arenemine	12_S	SgEl	et	eluarenemisest =arenemise  (SgEl  >elu+arenemine !12_S
42691	alaväärsena	väärse	ala+väärne	02_A	SgEs	et	alaväärsena =väärse  (SgEs  >ala+väärne !02_A
42692	moodse	moodse	moodne	02_A	SgG	et	moodse =moodse  (SgG  >moodne !02_A
42694	teksapüksid	püksi	teksa+püks	23?22_S	PlN	et	teksapüksid =püksi  (PlN  >teksa+püks !23?22_S
42700	raamidesse	raami	raam	22_S	PlIll	et	raamidesse =raami  (PlIll  >raam !22_S
42704	koolijuhatajad	juhataja	kooli+juhataja	01_S	PlN	et	koolijuhatajad =juhataja  (PlN  >kooli+juhataja !01_S
42468	ülesmärkimiseks	märkimise	üles+märkimine	12_S	SgTr	et	ülesmärkimiseks =märkimise  (SgTr  >üles+märkimine !12_S
42475	häälikuga	hääliku	häälik	02_S	SgKom	et	häälikuga =hääliku  (SgKom  >häälik !02_S
42478	väldivad	väldi	vältima	28_V	IndPrPl3	et	väldivad =väldi  (IndPrPl3  >vältima !28_V
42480	treenis	treeni	treenima	28_V	IndIpfSg3	et	treenis =treeni  (IndIpfSg3  >treenima !28_V
42482	algvormis	vormi	alg+vorm	22_S	SgIn	et	algvormis =vormi  (SgIn  >alg+vorm !22_S
42484	pöördelõpu	lõpu	pöörde+lõpp	22_SA	SgG	et	pöördelõpu =lõpu  (SgG  >pöörde+lõpp !22_SA
42488	aitad	aita	aitama	29_V	IndPrSg2	et	aitad =aita  (IndPrSg2  >aitama !29_V
42493	töötada-	tööta	töötama	27_V	Inf	et	töötada- =tööta  (Inf  >töötama !27_V
42497	iluse	iluse	ilus	02_A	SgG	et	iluse =iluse  (SgG  >ilus !02_A
42507	lausepõhistruktuurivead	vea	lause+põhi+struktuuri+viga	18_S	PlN	et	lausepõhistruktuurivead =vea  (PlN  >lause+põhi+struktuuri+viga !18_S
42516	hangiti	hangi	hankima	28_V	IndIpfIps	et	hangiti =hangi  (IndIpfIps  >hankima !28_V
42522	tagakiusamine	kiusamine	taga+kiusamine	12_S	SgN	et	tagakiusamine =kiusamine  (SgN  >taga+kiusamine !12_S
42527	seaduses	seaduse	seadus	11~09_S	SgIn	et	seaduses =seaduse  (SgIn  >seadus !11~09_S
42532	usupuhastuse	puhastuse	usu+puhastus	11_S	SgG	et	usupuhastuse =puhastuse  (SgG  >usu+puhastus !11_S
42535	trükikojas	koja	trüki+koda	18_S	SgIn	et	trükikojas =koja  (SgIn  >trüki+koda !18_S
42542	positsioonidest	positsiooni	positsioon	22_S	PlEl	et	positsioonidest =positsiooni  (PlEl  >positsioon !22_S
42543	ühiskondlikest	ühiskondlike	ühiskondlik	25_A	PlEl	et	ühiskondlikest =ühiskondlike  (PlEl  >ühiskondlik !25_A
42546	klasside	klassi	klass	22_S	PlG	et	klasside =klassi  (PlG  >klass !22_S
42554	erivariandid	variandi	eri+variant	22_S	PlN	et	erivariandid =variandi  (PlN  >eri+variant !22_S
42555	vigadel	viga	viga	18_S	PlAd	et	vigadel =viga  (PlAd  >viga !18_S
42557	lühikirjandis	kirjandi	lühi+kirjand	02_S	SgIn	et	lühikirjandis =kirjandi  (SgIn  >lühi+kirjand !02_S
42558	teistsuguses	suguse	teist+sugune	10_P	SgIn	et	teistsuguses =suguse  (SgIn  >teist+sugune !10_P
42560	arvutada	arvuta	arvutama	27_V	Inf	et	arvutada =arvuta  (Inf  >arvutama !27_V
42566	minevikuta	mineviku	minevik	25_S	SgAb	et	minevikuta =mineviku  (SgAb  >minevik !25_S
42568	esitades	esita	esitama	27_V	Ger	et	esitades =esita  (Ger  >esitama !27_V
42574	ülekandmisest	kandmise	üle+kandmine	12?10_SA	SgEl	et	ülekandmisest =kandmise  (SgEl  >üle+kandmine !12?10_SA
42577	õpetasin	õpeta	õpetama	27_V	IndIpfSg1	et	õpetasin =õpeta  (IndIpfSg1  >õpetama !27_V
42593	üheksasal	asa	üheks+ask	22_S	SgAd	et	üheksasal =asa  (SgAd  >üheks+ask !22_S
42594	tige	tige	tige	02_A	SgN	et	tige =tige  (SgN  >tige !02_A
42598	eksamiajal	aja	eksami+aeg	22_S	SgAd	et	eksamiajal =aja  (SgAd  >eksami+aeg !22_S
42599	eksamile	eksami	eksam	02_S	SgAll	et	eksamile =eksami  (SgAll  >eksam !02_S
42601	mordva	mordva	mordva	41_G	ID	et	mordva =mordva  (ID  >mordva !41_G
42608	mainib	maini	mainima	28_V	IndPrSg3	et	mainib =maini  (IndPrSg3  >mainima !28_V
42610	mordvalastel	mordvalas	mordvalane	12_S	PlAd	et	mordvalastel =mordvalas  (PlAd  >mordvalane !12_S
42614	peksti	peks	peksma	32_V	IndIpfIps	et	peksti =peks  (IndIpfIps  >peksma !32_V
42617	haridusminister	minister	haridus+minister	02_S	SgN	et	haridusminister =minister  (SgN  >haridus+minister !02_S
42620	provotseeris	provotseeri	provotseerima	28_V	IndIpfSg3	et	provotseeris =provotseeri  (IndIpfSg3  >provotseerima !28_V
42624	infoleht	leht	info+leht	22_S	SgN	et	infoleht =leht  (SgN  >info+leht !22_S
42631	rohutavad	tava	rohu+tava	17_S	PlN	et	rohutavad =tava  (PlN  >rohu+tava !17_S
42634	kultuuriaktivistid	aktivisti	kultuuri+aktivist	22_S	PlN	et	kultuuriaktivistid =aktivisti  (PlN  >kultuuri+aktivist !22_S
42643	eeltingimusena	tingimuse	eel+tingimus	11_S	SgEs	et	eeltingimusena =tingimuse  (SgEs  >eel+tingimus !11_S
42644	otsesed	otsese	otsene	10_A	PlN	et	otsesed =otsese  (PlN  >otsene !10_A
42655	kirjandusteadlased	teadlase	kirjandus+teadlane	12?10_S	PlN	et	kirjandusteadlased =teadlase  (PlN  >kirjandus+teadlane !12?10_S
42659	perekondades	perekonda	perekond	22_S	PlIn	et	perekondades =perekonda  (PlIn  >perekond !22_S
42667	pealkirjaks	kirja	peal+kiri	24_S	SgTr	et	pealkirjaks =kirja  (SgTr  >peal+kiri !24_S
42671	ministeeriumis	ministeeriumi	ministeerium	19~02_S	SgIn	et	ministeeriumis =ministeeriumi  (SgIn  >ministeerium !19~02_S
42676	isiklikud	isikliku	isiklik	25_A	PlN	et	isiklikud =isikliku  (PlN  >isiklik !25_A
42684	tülitab	tülita	tülitama	27_V	IndPrSg3	et	tülitab =tülita  (IndPrSg3  >tülitama !27_V
42693	poistel	pois	poiss	23_S	PlAd	et	poistel =pois  (PlAd  >poiss !23_S
42696	sobida	sobi	sobima	27_V	Inf	et	sobida =sobi  (Inf  >sobima !27_V
42697	sobime	sobi	sobima	27_V	IndPrPl1	et	sobime =sobi  (IndPrPl1  >sobima !27_V
42698	mass	mass	mass	22_S	SgN	et	mass =mass  (SgN  >mass !22_S
42498	arvsõnu	sõnu	arv+sõna	17_S	PlP	et	arvsõnu =sõnu  (PlP  >arv+sõna !17_S
42501	arvutimängud	mängu	arvuti+mäng	22_S	PlN	et	arvutimängud =mängu  (PlN  >arvuti+mäng !22_S
42502	autona	auto	auto	16_S	SgEs	et	autona =auto  (SgEs  >auto !16_S
42503	eelmised	eelmise	eelmine	12?10_A	PlN	et	eelmised =eelmise  (PlN  >eelmine !12?10_A
42513	ungarlaste	ungarlas	ungarlane	12_S	PlG	et	ungarlaste =ungarlas  (PlG  >ungarlane !12_S
42517	sõdadega	sõda	sõda	18_S	PlKom	et	sõdadega =sõda  (PlKom  >sõda !18_S
42518	laulikutes	lauliku	laulik	02_S	PlIn	et	laulikutes =lauliku  (PlIn  >laulik !02_S
42521	pretsedendita	pretsedendi	pretsedent	22_S	SgAb	et	pretsedendita =pretsedendi  (SgAb  >pretsedent !22_S
42524	kuninga	kuninga	kuningas	02_S	SgG	et	kuninga =kuninga  (SgG  >kuningas !02_S
42529	usukuulutamise	kuulutamise	usu+kuulutamine	12_S	SgG	et	usukuulutamise =kuulutamise  (SgG  >usu+kuulutamine !12_S
42530	kasvatas	kasvata	kasvatama	27_V	IndIpfSg3	et	kasvatas =kasvata  (IndIpfSg3  >kasvatama !27_V
42538	müstitsism	müstitsism	müstitsism	22_S	SgN	et	müstitsism =müstitsism  (SgN  >müstitsism !22_S
42545	materjalideks	materjali	materjal	19_S	PlTr	et	materjalideks =materjali  (PlTr  >materjal !19_S
42564	lühikirjandites	kirjandi	lühi+kirjand	02_S	PlIn	et	lühikirjandites =kirjandi  (PlIn  >lühi+kirjand !02_S
42565	ilmaaegu	ilmaaegu	ilma+aegu	41_D	ID	et	ilmaaegu =ilmaaegu  (ID  >ilma+aegu !41_D
42570	orjuses	orjuse	orjus	11~09_S	SgIn	et	orjuses =orjuse  (SgIn  >orjus !11~09_S
42582	põhjustabki	põhjusta	põhjustama	27_V	IndPrSg3^	et	põhjustabki =põhjusta  (IndPrSg3^  >põhjustama !27_V
42585	õpetata	õpeta	õpetama	27_V	IndPrIps_	et	õpetata =õpeta  (IndPrIps_  >õpetama !27_V
42588	lühivorm	vorm	lühi+vorm	22_S	SgN	et	lühivorm =vorm  (SgN  >lühi+vorm !22_S
42600	tunniajal	aja	tunni+aeg	22_S	SgAd	et	tunniajal =aja  (SgAd  >tunni+aeg !22_S
42602	pusida	pusi	pusima	27_V	Inf	et	pusida =pusi  (Inf  >pusima !27_V
42603	korvuti	uti	korv+utt	22_S	SgG	et	korvuti =uti  (SgG  >korv+utt !22_S
42609	mordvalastest	mordvalas	mordvalane	12_S	PlEl	et	mordvalastest =mordvalas  (PlEl  >mordvalane !12_S
42611	tahestiku	tiku	tahes+tikk	22_S	SgG	et	tahestiku =tiku  (SgG  >tahes+tikk !22_S
42615	tood	too	tooma	38_V	IndPrSg2	et	tood =too  (IndPrSg2  >tooma !38_V
42623	keskastme	astme	kesk+aste	05_S	SgG	et	keskastme =astme  (SgG  >kesk+aste !05_S
42630	eelarvega	arve	eel+arve	06_S	SgKom	et	eelarvega =arve  (SgKom  >eel+arve !06_S
42633	konverentsil	konverentsi	konverents	22_S	SgAd	et	konverentsil =konverentsi  (SgAd  >konverents !22_S
42638	votjakid	votjaki	votjak	02_S	PlN	et	votjakid =votjaki  (PlN  >votjak !02_S
42660	joodiku	joodiku	joodik	02_SA	SgG	et	joodiku =joodiku  (SgG  >joodik !02_SA
42664	rahapuudus	puudus	raha+puudus	11~09_S	SgN	et	rahapuudus =puudus  (SgN  >raha+puudus !11~09_S
42666	tasandiks	tasandi	tasand	02_S	SgTr	et	tasandiks =tasandi  (SgTr  >tasand !02_S
42672	irooniat	iroonia	iroonia	01_S	SgP	et	irooniat =iroonia  (SgP  >iroonia !01_S
42678	demagoogiat	demagoogia	demagoogia	01_S	SgP	et	demagoogiat =demagoogia  (SgP  >demagoogia !01_S
42679	kuuleme	kuule	kuulma	33_V	IndPrPl1	et	kuuleme =kuule  (IndPrPl1  >kuulma !33_V
42680	arutatakse	aruta	arutama	27_V	IndPrIps	et	arutatakse =aruta  (IndPrIps  >arutama !27_V
42681	nõuannetega	anne	nõu+anne	06_S	PlKom	et	nõuannetega =anne  (PlKom  >nõu+anne !06_S
42682	peaasi	asi	pea+asi	24_S	SgN	et	peaasi =asi  (SgN  >pea+asi !24_S
42683	kaklusega	kakluse	kaklus	11~09_S	SgKom	et	kaklusega =kakluse  (SgKom  >kaklus !11~09_S
42686	suhtutakse	suhtu	suhtuma	27_V	IndPrIps	et	suhtutakse =suhtu  (IndPrIps  >suhtuma !27_V
42688	suhetest	suhe	suhe	06_S	PlEl	et	suhetest =suhe  (PlEl  >suhe !06_S
42695	sviiter	sviiter	sviiter	02_S	SgN	et	sviiter =sviiter  (SgN  >sviiter !02_S
42699	riietuma	riietu	riietuma	27_V	Sup	et	riietuma =riietu  (Sup  >riietuma !27_V
42701	väljakutsuva	kutsuva	välja+kutsuv	02_A	SgG	et	väljakutsuva =kutsuva  (SgG  >välja+kutsuv !02_A
42702	moodsal	moodsa	moodne	02_A	SgAd	et	moodsal =moodsa  (SgAd  >moodne !02_A
42708	koolivormis	vormi	kooli+vorm	22_S	SgIn	et	koolivormis =vormi  (SgIn  >kooli+vorm !22_S
42726	sisekohakäänetega	kääne	sise+koha+kääne	06_S	PlKom	et	sisekohakäänetega =kääne  (PlKom  >sise+koha+kääne !06_S
42729	protsendid	protsendi	protsent	22_S	PlN	et	protsendid =protsendi  (PlN  >protsent !22_S
42739	sisekohakääneteks	kääne	sise+koha+kääne	06_S	PlTr	et	sisekohakääneteks =kääne  (PlTr  >sise+koha+kääne !06_S
42740	illatiiv	illatiiv	illatiiv	22_S	SgN	et	illatiiv =illatiiv  (SgN  >illatiiv !22_S
42747	poesse	poe	pood	22_S	SgIll	et	poesse =poe  (SgIll  >pood !22_S
42760	korrus	korrus	korrus	09_S	SgN	et	korrus =korrus  (SgN  >korrus !09_S
42763	õnnitleda	õnnitle	õnnitlema	27_V	Inf	et	õnnitleda =õnnitle  (Inf  >õnnitlema !27_V
42772	asusime	asu	asuma	27_V	IndIpfPl1	et	asusime =asu  (IndIpfPl1  >asuma !27_V
42550	hindega	hinde	hinne	06_S	SgKom	et	hindega =hinde  (SgKom  >hinne !06_S
42562	venekeelsele	keelse	vene+keelne	02_A	SgAll	et	venekeelsele =keelse  (SgAll  >vene+keelne !02_A
42563	momendid	momendi	moment	22_S	PlN	et	momendid =momendi  (PlN  >moment !22_S
42569	retoorilist	retoorilis	retooriline	12_A	SgP	et	retoorilist =retoorilis  (SgP  >retooriline !12_A
42571	intransitiivsed	intransitiivse	intransitiivne	02_A	PlN	et	intransitiivsed =intransitiivse  (PlN  >intransitiivne !02_A
42572	transitiivsed	transitiivse	transitiivne	02_A	PlN	et	transitiivsed =transitiivse  (PlN  >transitiivne !02_A
42575	lohakusvigu	vigu	lohakus+viga	18_S	PlP	et	lohakusvigu =vigu  (PlP  >lohakus+viga !18_S
42583	kerkida	kerki	kerkima	27_V	Inf	et	kerkida =kerki  (Inf  >kerkima !27_V
42591	ni-na-ta-ga	ni-na-ta	ni-na-ta	xx_Q	SgKom	et	ni-na-ta-ga =ni-na-ta  (SgKom  >ni-na-ta !xx_Q
42597	arvestustööde	töö	arvestus+töö	26_S	PlG	et	arvestustööde =töö  (PlG  >arvestus+töö !26_S
42605	mordvalasteks	mordvalas	mordvalane	12_S	PlTr	et	mordvalasteks =mordvalas  (PlTr  >mordvalane !12_S
42607	mordvalasi	mordvalasi	mordvalane	12_S	PlP	et	mordvalasi =mordvalasi  (PlP  >mordvalane !12_S
42616	toetamast	toeta	toetama	27_V	SupEl	et	toetamast =toeta  (SupEl  >toetama !27_V
42619	purskas	purska	purskama	29_V	IndIpfSg3	et	purskas =purska  (IndIpfSg3  >purskama !29_V
42622	kavandati	kavanda	kavandama	27_V	IndIpfIps	et	kavandati =kavanda  (IndIpfIps  >kavandama !27_V
42628	riigikeelteks	keel	riigi+keel	13_S	PlTr	et	riigikeelteks =keel  (PlTr  >riigi+keel !13_S
42632	vaidlus	vaidlus	vaidlus	11~09_S	SgN	et	vaidlus =vaidlus  (SgN  >vaidlus !11~09_S
42635	pseudoetnonuum	nuum	pseudo+etno+nuum	22_S	SgN	et	pseudoetnonuum =nuum  (SgN  >pseudo+etno+nuum !22_S
42637	udmurtide	udmurti	udmurt	22_S	PlG	et	udmurtide =udmurti  (PlG  >udmurt !22_S
42639	deklaratsioon	deklaratsioon	deklaratsioon	22_S	SgN	et	deklaratsioon =deklaratsioon  (SgN  >deklaratsioon !22_S
42640	garanteeris	garanteeri	garanteerima	28_V	IndIpfSg3	et	garanteeris =garanteeri  (IndIpfSg3  >garanteerima !28_V
42641	riigikeeltena	keel	riigi+keel	13_S	PlEs	et	riigikeeltena =keel  (PlEs  >riigi+keel !13_S
42645	presidendivalimised	valimise	presidendi+valimine	12_S	PlN	et	presidendivalimised =valimise  (PlN  >presidendi+valimine !12_S
42647	laanemeresoome	oome	laane+meres+oom	22_S	PlP	et	laanemeresoome =oome  (PlP  >laane+meres+oom !22_S
42649	vaheldub	vaheldu	vahelduma	27_V	IndPrSg3	et	vaheldub =vaheldu  (IndPrSg3  >vahelduma !27_V
42651	kolmekordseid	kordse	kolme+kordne	02_AS	PlP	et	kolmekordseid =kordse  (PlP  >kolme+kordne !02_AS
42657	mordvalastele	mordvalas	mordvalane	12_S	PlAll	et	mordvalastele =mordvalas  (PlAll  >mordvalane !12_S
42661	käitudes	käitu	käituma	27_V	Ger	et	käitudes =käitu  (Ger  >käituma !27_V
42663	niisugustel	sugus	nii+sugune	10_P	PlAd	et	niisugustel =sugus  (PlAd  >nii+sugune !10_P
42665	elutase	tase	elu+tase	04_S	SgN	et	elutase =tase  (SgN  >elu+tase !04_S
42668	lugejaskonnale	lugejaskonna	lugejaskond	22_S	SgAll	et	lugejaskonnale =lugejaskonna  (SgAll  >lugejaskond !22_S
42669	põhiideeni	idee	põhi+idee	26_S	SgTer	et	põhiideeni =idee  (SgTer  >põhi+idee !26_S
42673	kuninglikud	kuningliku	kuninglik	25_A	PlN	et	kuninglikud =kuningliku  (PlN  >kuninglik !25_A
42685	klassijuhatajale	juhataja	klassi+juhataja	01_S	SgAll	et	klassijuhatajale =juhataja  (SgAll  >klassi+juhataja !01_S
42689	valgeid	valge	valge	01_AS	PlP	et	valgeid =valge  (PlP  >valge !01_AS
42690	kalleid	kalle	kallis	05~07_A	PlP	et	kalleid =kalle  (PlP  >kallis !05~07_A
42703	kavandit	kavandi	kavand	02_S	SgP	et	kavandit =kavandi  (SgP  >kavand !02_S
42714	teaksite	tea	teadma	34_V	KndPrPl2	et	teaksite =tea  (KndPrPl2  >teadma !34_V
42715	infoallikad	allika	info+allikas	02_S	PlN	et	infoallikad =allika  (PlN  >info+allikas !02_S
42723	kolm-neli	neli	kolm-neli	24_N	SgN	et	kolm-neli =neli  (SgN  >kolm-neli !24_N
42733	sihitis	sihitis	sihitis	11_S	SgN	et	sihitis =sihitis  (SgN  >sihitis !11_S
42735	osasihitiseks	sihitise	osa+sihitis	11_S	SgTr	et	osasihitiseks =sihitise  (SgTr  >osa+sihitis !11_S
42738	funktsioon	funktsioon	funktsioon	22_S	SgN	et	funktsioon =funktsioon  (SgN  >funktsioon !22_S
42741	väliskohakääneteks	kääne	välis+koha+kääne	06_S	PlTr	et	väliskohakääneteks =kääne  (PlTr  >välis+koha+kääne !06_S
42742	adessiiv	adessiiv	adessiiv	22_S	SgN	et	adessiiv =adessiiv  (SgN  >adessiiv !22_S
42745	näidetest	näide	näide	06_S	PlEl	et	näidetest =näide  (PlEl  >näide !06_S
42746	udusse	udu	udu	17_S	SgIll	et	udusse =udu  (SgIll  >udu !17_S
42748	jaamasse	jaama	jaam	22_S	SgIll	et	jaamasse =jaama  (SgIll  >jaam !22_S
42755	kasutamisreeglid	reegli	kasutamis+reegel	02_S	PlN	et	kasutamisreeglid =reegli  (PlN  >kasutamis+reegel !02_S
42756	tartuni	tartu	tartu	01_H	SgTer	et	tartuni =tartu  (SgTer  >tartu !01_H
42757	lillepeen	peen	lille+peen	13_A	SgN	et	lillepeen =peen  (SgN  >lille+peen !13_A
42765	kasutamisreegleid	reegle	kasutamis+reegel	02_S	PlP	et	kasutamisreegleid =reegle  (PlP  >kasutamis+reegel !02_S
42675	keelestruktuurid	struktuuri	keele+struktuur	22_S	PlN	et	keelestruktuurid =struktuuri  (PlN  >keele+struktuur !22_S
42707	erineda	erine	erinema	27_V	Inf	et	erineda =erine  (Inf  >erinema !27_V
42717	teadusel	teaduse	teadus	11~09_S	SgAd	et	teadusel =teaduse  (SgAd  >teadus !11~09_S
42721	teadustel	teadus	teadus	11~09_S	PlAd	et	teadustel =teadus  (PlAd  >teadus !11~09_S
42725	rektsiooniga	rektsiooni	rektsioon	22_S	SgKom	et	rektsiooniga =rektsiooni  (SgKom  >rektsioon !22_S
42727	märkus	märkus	märkus	11~09_S	SgN	et	märkus =märkus  (SgN  >märkus !11~09_S
42731	diivaneid	diivane	diivan	02_S	PlP	et	diivaneid =diivane  (PlP  >diivan !02_S
42734	täissihitiseks	sihitise	täis+sihitis	11_S	SgTr	et	täissihitiseks =sihitise  (SgTr  >täis+sihitis !11_S
42749	lasteaja	aja	laste+aeg	22_S	SgG	et	lasteaja =aja  (SgG  >laste+aeg !22_S
42750	mäge	mäge	mägi	21_S	SgP	et	mäge =mäge  (SgP  >mägi !21_S
42752	kinda	kinda	kinnas	07_S	SgG	et	kinda =kinda  (SgG  >kinnas !07_S
42759	lau	lau	laug	22_SA	SgG	et	lau =lau  (SgG  >laug !22_SA
42762	remondime	remondi	remontima	28_V	IndPrPl1	et	remondime =remondi  (IndPrPl1  >remontima !28_V
42774	mööblikaupluse	kaupluse	mööbli+kauplus	11~09_S	SgG	et	mööblikaupluse =kaupluse  (SgG  >mööbli+kauplus !11~09_S
42776	unustati	unusta	unustama	27_V	IndIpfIps	et	unustati =unusta  (IndIpfIps  >unustama !27_V
42777	loodan-	looda	lootma	34_V	IndPrSg1	et	loodan- =looda  (IndPrSg1  >lootma !34_V
42781	piilub	piilu	piiluma	28_V	IndPrSg3	et	piilub =piilu  (IndPrSg3  >piiluma !28_V
42792	arutab	aruta	arutama	27_V	IndPrSg3	et	arutab =aruta  (IndPrSg3  >arutama !27_V
42802	tahakski	taha	tahtma	34_V	KndPrPs^	et	tahakski =taha  (KndPrPs^  >tahtma !34_V
42805	vastutad	vastuta	vastutama	27_V	IndPrSg2	et	vastutad =vastuta  (IndPrSg2  >vastutama !27_V
42807	nutis	nuti	nutt	22_S	SgIn	et	nutis =nuti  (SgIn  >nutt !22_S
42810	magasi	magasi	magas	02_S	SgG	et	magasi =magasi  (SgG  >magas !02_S
42817	piknikule	pikniku	piknik	02_S	SgAll	et	piknikule =pikniku  (SgAll  >piknik !02_S
42827	lamamistoolide	tooli	lamamis+tool	22_S	PlG	et	lamamistoolide =tooli  (PlG  >lamamis+tool !22_S
42836	linnude	ude	linn+ude	04_S	SgN	et	linnude =ude  (SgN  >linn+ude !04_S
42842	määrige	määri	määrima	28_V	ImpPrPl2	et	määrige =määri  (ImpPrPl2  >määrima !28_V
42845	keskkonnanõuniku	nõuniku	kesk+konna+nõunik	25_S	SgG	et	keskkonnanõuniku =nõuniku  (SgG  >kesk+konna+nõunik !25_S
42851	loodusressursse	ressursse	loodus+ressurss	22_S	PlP	et	loodusressursse =ressursse  (PlP  >loodus+ressurss !22_S
42870	viil	viil	viil	22_S	SgN	et	viil =viil  (SgN  >viil !22_S
42871	looduskeskkonna	keskkonna	loodus+keskkond	22_S	SgG	et	looduskeskkonna =keskkonna  (SgG  >loodus+keskkond !22_S
42875	kõlama	kõla	kõlama	27_V	Sup	et	kõlama =kõla  (Sup  >kõlama !27_V
42878	kallur	kallur	kallur	02_S	SgN	et	kallur =kallur  (SgN  >kallur !02_S
42888	tabeli	tabeli	tabel	02_S	SgG	et	tabeli =tabeli  (SgG  >tabel !02_S
42890	kiirendama	kiirenda	kiirendama	27_V	Sup	et	kiirendama =kiirenda  (Sup  >kiirendama !27_V
42894	langema	lange	langema	27_V	Sup	et	langema =lange  (Sup  >langema !27_V
42896	rahunema	rahune	rahunema	27_V	Sup	et	rahunema =rahune  (Sup  >rahunema !27_V
42900	jahtuma	jahtu	jahtuma	27_V	Sup	et	jahtuma =jahtu  (Sup  >jahtuma !27_V
42908	maandab	maanda	maandama	27_V	IndPrSg3	et	maandab =maanda  (IndPrSg3  >maandama !27_V
42909	harilik	harilik	harilik	25_A	SgN	et	harilik =harilik  (SgN  >harilik !25_A
42913	köhis	köhi	köhima	27_V	IndIpfSg3	et	köhis =köhi  (IndIpfSg3  >köhima !27_V
42917	saatke	saat	saatma	34_V	ImpPrPl2	et	saatke =saat  (ImpPrPl2  >saatma !34_V
42919	bill	bill	bill	22_S	SgN	et	bill =bill  (SgN  >bill !22_S
42925	haiglat	haigla	haigla	01_S	SgP	et	haiglat =haigla  (SgP  >haigla !01_S
42929	elektromeeter	meeter	elektro+meeter	02_S	SgN	et	elektromeeter =meeter  (SgN  >elektro+meeter !02_S
42930	spetsialistile	spetsialisti	spetsialist	22_S	SgAll	et	spetsialistile =spetsialisti  (SgAll  >spetsialist !22_S
42931	toredaks	toreda	tore	02_A	SgTr	et	toredaks =toreda  (SgTr  >tore !02_A
42945	oskasin	oska	oskama	29_V	IndIpfSg1	et	oskasin =oska  (IndIpfSg1  >oskama !29_V
42955	2-e			xx_Q	PlP	et	-e =  (PlP  > !xx_Q
42962	prits	prits	prits	22_S	SgN	et	prits =prits  (SgN  >prits !22_S
42963	höövel	höövel	höövel	02_S	SgN	et	höövel =höövel  (SgN  >höövel !02_S
42973	vanaks	vana	vana	17_AS	SgTr	et	vanaks =vana  (SgTr  >vana !17_AS
42979	juhtmes	juhtme	juhe	05_S	SgIn	et	juhtmes =juhtme  (SgIn  >juhe !05_S
42985	töökäik	käik	töö+käik	22_S	SgN	et	töökäik =käik  (SgN  >töö+käik !22_S
42991	sõjalahingud	lahingu	sõja+lahing	02_S	PlN	et	sõjalahingud =lahingu  (PlN  >sõja+lahing !02_S
43000	vaatles	vaatle	vaatlema	30_V	IndIpfSg3	et	vaatles =vaatle  (IndIpfSg3  >vaatlema !30_V
42705	triiksärk	särk	triik+särk	22_S	SgN	et	triiksärk =särk  (SgN  >triik+särk !22_S
42709	kindal	kinda	kinnas	07_S	SgAd	et	kindal =kinda  (SgAd  >kinnas !07_S
42710	lastehoidjana	hoidja	laste+hoidja	01_S	SgEs	et	lastehoidjana =hoidja  (SgEs  >laste+hoidja !01_S
42718	ajudest	aju	aju	17_S	PlEl	et	ajudest =aju  (PlEl  >aju !17_S
42720	väljendiga	väljendi	väljend	02_S	SgKom	et	väljendiga =väljendi  (SgKom  >väljend !02_S
42728	kontrolltööga	töö	kont+roll+töö	26_S	SgKom	et	kontrolltööga =töö  (SgKom  >kont+roll+töö !26_S
42730	üte	üte	üte	06_S	SgN	et	üte =üte  (SgN  >üte !06_S
42732	k-s	k	k	xx_Q	SgIn	et	k-s =k  (SgIn  >k !xx_Q
42736	kasutuspiirid	piiri	kasutus+piir	22_S	PlN	et	kasutuspiirid =piiri  (PlN  >kasutus+piir !22_S
42737	panime	pan	panema	36_V	IndIpfPl1	et	panime =pan  (IndIpfPl1  >panema !36_V
42743	ablatiiv	ablatiiv	ablatiiv	22_S	SgN	et	ablatiiv =ablatiiv  (SgN  >ablatiiv !22_S
42751	vesisse	vesi	vesi	15_S	PlIll	et	vesisse =vesi  (PlIll  >vesi !15_S
42761	öelge	öel	ütlema	30_V	ImpPrPl2	et	öelge =öel  (ImpPrPl2  >ütlema !30_V
42764	kimpudesse	kimpu	kimp	22_S	PlIll	et	kimpudesse =kimpu  (PlIll  >kimp !22_S
42766	kukku	kukku	kukku	41_I	ID	et	kukku =kukku  (ID  >kukku !41_I
42767	käske	käske	käsk	22_S	PlP	et	käske =käske  (PlP  >käsk !22_S
42769	supel	supe	supp	22_S	PlAd	et	supel =supe  (PlAd  >supp !22_S
42775	mööblikaupluses	kaupluse	mööbli+kauplus	11~09_S	SgIn	et	mööblikaupluses =kaupluse  (SgIn  >mööbli+kauplus !11~09_S
42785	harvaesineva	esineva	harva+esinev	02_A	SgG	et	harvaesineva =esineva  (SgG  >harva+esinev !02_A
42786	toolides	tooli	tool	22_S	PlIn	et	toolides =tooli  (PlIn  >tool !22_S
42787	koob	koo	kuduma	28_V	IndPrSg3	et	koob =koo  (IndPrSg3  >kuduma !28_V
42796	lahkuminek	minek	lahku+minek	02_S	SgN	et	lahkuminek =minek  (SgN  >lahku+minek !02_S
42806	kadestab	kadesta	kadestama	27_V	IndPrSg3	et	kadestab =kadesta  (IndPrSg3  >kadestama !27_V
42808	tädid	tädi	tädi	17_S	PlN	et	tädid =tädi  (PlN  >tädi !17_S
42814	salakuulama	kuula	sala+kuulama	29_V	Sup	et	salakuulama =kuula  (Sup  >sala+kuulama !29_V
42819	oksale	oksa	oks	23?22_S	SgAll	et	oksale =oksa  (SgAll  >oks !23?22_S
42824	lamamistoolidel	tooli	lamamis+tool	22_S	PlAd	et	lamamistoolidel =tooli  (PlAd  >lamamis+tool !22_S
42831	tornist	torni	torn	22_S	SgEl	et	tornist =torni  (SgEl  >torn !22_S
42837	jalakreem	kreem	jala+kreem	22_SA	SgN	et	jalakreem =kreem  (SgN  >jala+kreem !22_SA
42843	tuub	tuub	tuub	22_S	SgN	et	tuub =tuub  (SgN  >tuub !22_S
42849	taaskasutussüsteem	süsteem	taas+kasutus+süsteem	22_S	SgN	et	taaskasutussüsteem =süsteem  (SgN  >taas+kasutus+süsteem !22_S
42852	sõnajärjele	järje	sõna+järg	22_S	SgAll	et	sõnajärjele =järje  (SgAll  >sõna+järg !22_S
42853	puhastatakse	puhasta	puhastama	27_V	IndPrIps	et	puhastatakse =puhasta  (IndPrIps  >puhastama !27_V
42854	rutem	rutem	rutem	41_D	ID	et	rutem =rutem  (ID  >rutem !41_D
42865	püüate	püüa	püüdma	34_V	IndPrPl2	et	püüate =püüa  (IndPrPl2  >püüdma !34_V
42873	heakord	kord	hea+kord	22_S	SgN	et	heakord =kord  (SgN  >hea+kord !22_S
42884	1tõlkige	tõlki	tõlkima	28_V	ImpPrPl2	et	tõlkige =tõlki  (ImpPrPl2  >tõlkima !28_V
42887	tõotab	tõota	tõotama	27_V	IndPrSg3	et	tõotab =tõota  (IndPrSg3  >tõotama !27_V
42897	rahustama	rahusta	rahustama	27_V	Sup	et	rahustama =rahusta  (Sup  >rahustama !27_V
42904	nakkama	nakka	nakkama	29_V	Sup	et	nakkama =nakka  (Sup  >nakkama !29_V
42905	leidke	leid	leidma	34_V	ImpPrPl2	et	leidke =leid  (ImpPrPl2  >leidma !34_V
42907	lõdvestab	lõdvesta	lõdvestama	27_V	IndPrSg3	et	lõdvestab =lõdvesta  (IndPrSg3  >lõdvestama !27_V
42910	taks	taks	taks	22_S	SgN	et	taks =taks  (SgN  >taks !22_S
42915	keemiatoodete	toode	keemia+toode	06_S	PlG	et	keemiatoodete =toode  (PlG  >keemia+toode !06_S
42921	enamiku	enamiku	enamik	25_S	SgG	et	enamiku =enamiku  (SgG  >enamik !25_S
42927	jaamal	jaama	jaam	22_S	SgAd	et	jaamal =jaama  (SgAd  >jaam !22_S
42932	tanklas	tankla	tankla	01_S	SgIn	et	tanklas =tankla  (SgIn  >tankla !01_S
42941	arvutivõrgu	võrgu	arvuti+võrk	22_S	SgG	et	arvutivõrgu =võrgu  (SgG  >arvuti+võrk !22_S
42944	äraminekuga	mineku	ära+minek	02_S	SgKom	et	äraminekuga =mineku  (SgKom  >ära+minek !02_S
42949	aeglustub	aeglustu	aeglustuma	27_V	IndPrSg3	et	aeglustub =aeglustu  (IndPrSg3  >aeglustuma !27_V
42950	kirub	kiru	kiruma	27_V	IndPrSg3	et	kirub =kiru  (IndPrSg3  >kiruma !27_V
42951	luubi	luubi	luup	22_S	SgG	et	luubi =luubi  (SgG  >luup !22_S
42957	juukseföön	föön	juukse+föön	22_S	SgN	et	juukseföön =föön  (SgN  >juukse+föön !22_S
42959	pump	pump	pump	22_S	SgN	et	pump =pump  (SgN  >pump !22_S
42964	venitab	venita	venitama	27_V	IndPrSg3	et	venitab =venita  (IndPrSg3  >venitama !27_V
42965	venisin	veni	venima	27_V	IndIpfSg1	et	venisin =veni  (IndIpfSg1  >venima !27_V
42706	botased	botase	botas	09_S	PlN	et	botased =botase  (PlN  >botas !09_S
42711	põhjamere	mere	põhja+meri	20_S	SgG	et	põhjamere =mere  (SgG  >põhja+meri !20_S
42712	10oktoobril	oktoobri	oktoober	02_S	SgAd	et	oktoobril =oktoobri  (SgAd  >oktoober !02_S
42713	triumfikaar	kaar	triumfi+kaar	13_S	SgN	et	triumfikaar =kaar  (SgN  >triumfi+kaar !13_S
42716	haridusse	haridus	haridus	11_S	SgAdt	et	haridusse =haridus  (SgAdt  >haridus !11_S
42719	loogikat	loogika	loogika	01_S	SgP	et	loogikat =loogika  (SgP  >loogika !01_S
42722	talvesemestri	semestri	talve+semester	02_S	SgG	et	talvesemestri =semestri  (SgG  >talve+semester !02_S
42724	kolmed	kolme	kolm	22_N	PlN	et	kolmed =kolme  (PlN  >kolm !22_N
42744	eessõnadega	sõna	ees+sõna	17_S	PlKom	et	eessõnadega =sõna  (PlKom  >ees+sõna !17_S
42753	selgis	selgi	selgima	27_V	IndIpfSg3	et	selgis =selgi  (IndIpfSg3  >selgima !27_V
42754	tehast	tehas	tehas	09_S	SgP	et	tehast =tehas  (SgP  >tehas !09_S
42758	lillepeenrad	peenra	lille+peenar	08_S	PlN	et	lillepeenrad =peenra  (PlN  >lille+peenar !08_S
42779	ilusal	ilusa	ilus	02_A	SgAd	et	ilusal =ilusa  (SgAd  >ilus !02_A
42780	suvepäeval	päeva	suve+päev	22_S	SgAd	et	suvepäeval =päeva  (SgAd  >suve+päev !22_S
42782	tagant	tagant	tagant	41_DK	ID	et	tagant =tagant  (ID  >tagant !41_DK
42784	taevale	taeva	taevas	07_S	SgAll	et	taevale =taeva  (SgAll  >taevas !07_S
42788	imikut	imiku	imik	02_S	SgP	et	imikut =imiku  (SgP  >imik !02_S
42791	vahib	vahi	vahtima	28_V	IndPrSg3	et	vahib =vahi  (IndPrSg3  >vahtima !28_V
42795	armsate	armsa	armas	03~05_A	PlG	et	armsate =armsa  (PlG  >armas !03~05_A
42812	kaukas	kauka	kaugas	07_S	SgIn	et	kaukas =kauka  (SgIn  >kaugas !07_S
42822	vihastasin	vihasta	vihastama	27_V	IndIpfSg1	et	vihastasin =vihasta  (IndIpfSg1  >vihastama !27_V
42829	ronib	roni	ronima	27_V	IndPrSg3	et	ronib =roni  (IndPrSg3  >ronima !27_V
42832	ümbrust	ümbrus	ümbrus	11~09_S	SgP	et	ümbrust =ümbrus  (SgP  >ümbrus !11~09_S
42835	imik	imik	imik	02_S	SgN	et	imik =imik  (SgN  >imik !02_S
42839	naha	naha	nahk	22_S	SgG	et	naha =naha  (SgG  >nahk !22_S
42850	teadvustama	teadvusta	teadvustama	27_V	Sup	et	teadvustama =teadvusta  (Sup  >teadvustama !27_V
42863	pestakse	pes	pesema	36_V	IndPrIps	et	pestakse =pes  (IndPrIps  >pesema !36_V
42864	kriipsutage	kriipsuta	kriipsutama	27_V	ImpPrPl2	et	kriipsutage =kriipsuta  (ImpPrPl2  >kriipsutama !27_V
42869	kahjustatakse	kahjusta	kahjustama	27_V	IndPrIps	et	kahjustatakse =kahjusta  (IndPrIps  >kahjustama !27_V
42876	kõlar-	kõlar	kõlar	02_S	SgN	et	kõlar- =kõlar  (SgN  >kõlar !02_S
42880	helkima	helki	helkima	28_V	Sup	et	helkima =helki  (Sup  >helkima !28_V
42881	printima	printi	printima	28_V	Sup	et	printima =printi  (Sup  >printima !28_V
42885	kaminas	kamina	kamin	02_S	SgIn	et	kaminas =kamina  (SgIn  >kamin !02_S
42886	õunakook	kook	õuna+kook	22_S	SgN	et	õunakook =kook  (SgN  >õuna+kook !22_S
42889	kiirenema	kiirene	kiirenema	27_V	Sup	et	kiirenema =kiirene  (Sup  >kiirenema !27_V
42891	innustuma	innustu	innustuma	27_V	Sup	et	innustuma =innustu  (Sup  >innustuma !27_V
42895	halvendama	halvenda	halvendama	27_V	Sup	et	halvendama =halvenda  (Sup  >halvendama !27_V
42899	aeglustama	aeglusta	aeglustama	27_V	Sup	et	aeglustama =aeglusta  (Sup  >aeglustama !27_V
42902	meenuma	meenu	meenuma	27_V	Sup	et	meenuma =meenu  (Sup  >meenuma !27_V
42912	sõnajärje	järje	sõna+järg	22_S	SgG	et	sõnajärje =järje  (SgG  >sõna+järg !22_S
42914	külmetas	külmeta	külmetama	27_V	IndIpfSg3	et	külmetas =külmeta  (IndIpfSg3  >külmetama !27_V
42916	arvake	arva	arvama	29_V	ImpPrPl2	et	arvake =arva  (ImpPrPl2  >arvama !29_V
42924	ebatervislikuks	tervisliku	eba+tervislik	25_A	SgTr	et	ebatervislikuks =tervisliku  (SgTr  >eba+tervislik !25_A
42926	mobiil	mobiil	mobiil	22_S	SgN	et	mobiil =mobiil  (SgN  >mobiil !22_S
42935	õhtusöögiks	söögi	õhtu+söök	22_S	SgTr	et	õhtusöögiks =söögi  (SgTr  >õhtu+söök !22_S
42937	digitaaltehnoloogiale	tehnoloogia	digitaal+tehnoloogia	01_S	SgAll	et	digitaaltehnoloogiale =tehnoloogia  (SgAll  >digitaal+tehnoloogia !01_S
42938	käskluse	käskluse	käsklus	11~09_S	SgG	et	käskluse =käskluse  (SgG  >käsklus !11~09_S
42952	kiusab	kiusa	kiusama	29_V	IndPrSg3	et	kiusab =kiusa  (IndPrSg3  >kiusama !29_V
42953	päriselt	päriselt	päriselt	41_D	ID	et	päriselt =päriselt  (ID  >päriselt !41_D
42954	raamatutegelased	tegelase	raamatu+tegelane	12_S	PlN	et	raamatutegelased =tegelase  (PlN  >raamatu+tegelane !12_S
42960	muruniiduk	niiduk	muru+niiduk	02_S	SgN	et	muruniiduk =niiduk  (SgN  >muru+niiduk !02_S
42961	ketassaag	saag	ketas+saag	22_S	SgN	et	ketassaag =saag  (SgN  >ketas+saag !22_S
42971	külmiku	külmiku	külmik	02_S	SgG	et	külmiku =külmiku  (SgG  >külmik !02_S
42972	vorst	vorst	vorst	22_S	SgN	et	vorst =vorst  (SgN  >vorst !22_S
42975	rikkis	rikkis	rikkis	41_DA	ID	et	rikkis =rikkis  (ID  >rikkis !41_DA
42768	kaardilt	kaardi	kaart	22_S	SgAbl	et	kaardilt =kaardi  (SgAbl  >kaart !22_S
42770	sõidate	sõida	sõitma	34_V	IndPrPl2	et	sõidate =sõida  (IndPrPl2  >sõitma !34_V
42771	puha	puha	puha	41_D	ID	et	puha =puha  (ID  >puha !41_D
42773	hüüdnimi	nimi	hüüd+nimi	20_S	SgN	et	hüüdnimi =nimi  (SgN  >hüüd+nimi !20_S
42778	sellepärast-	sellepärast	selle+pärast	41_D	ID	et	sellepärast- =sellepärast  (ID  >selle+pärast !41_D
42790	piknik	piknik	piknik	02_S	SgN	et	piknik =piknik  (SgN  >piknik !02_S
42794	pilkudelt	pilku	pilk	22_S	PlAbl	et	pilkudelt =pilku  (PlAbl  >pilk !22_S
42798	murul	muru	muru	17_S	SgAd	et	murul =muru  (SgAd  >muru !17_S
42800	mustadest	musta	must	22_AS	PlEl	et	mustadest =musta  (PlEl  >must !22_AS
42801	ohkab	ohka	ohkama	29_V	IndPrSg3	et	ohkab =ohka  (IndPrSg3  >ohkama !29_V
42804	otsustadki	otsusta	otsustama	27_V	IndPrSg2^	et	otsustadki =otsusta  (IndPrSg2^  >otsustama !27_V
42809	piknikis	pikniki	piknik	02_S	SgIn	et	piknikis =pikniki  (SgIn  >piknik !02_S
42811	loes	loe	lood	22_S	SgIn	et	loes =loe  (SgIn  >lood !22_S
42816	spioon	spioon	spioon	22_S	SgN	et	spioon =spioon  (SgN  >spioon !22_S
42820	kakles	kakle	kaklema	30_V	IndIpfSg3	et	kakles =kakle  (IndIpfSg3  >kaklema !30_V
42823	seisan	seisa	seisma	32_V	IndPrSg1	et	seisan =seisa  (IndPrSg1  >seisma !32_V
42826	jänes	jänes	jänes	09_S	SgN	et	jänes =jänes  (SgN  >jänes !09_S
42828	hüppab	hüppa	hüppama	29_V	IndPrSg3	et	hüppab =hüppa  (IndPrSg3  >hüppama !29_V
42840	pehmeks	pehme	pehme	01_A	SgTr	et	pehmeks =pehme  (SgTr  >pehme !01_A
42841	jalgadele	jalga	jalg	22_S	PlAll	et	jalgadele =jalga  (PlAll  >jalg !22_S
42847	ohtlikele	ohtlike	ohtlik	25_A	PlAll	et	ohtlikele =ohtlike  (PlAll  >ohtlik !25_A
42848	praht	praht	praht	22_S	SgN	et	praht =praht  (SgN  >praht !22_S
42855	korgiga	korgi	kork	22_S	SgKom	et	korgiga =korgi  (SgKom  >kork !22_S
42857	tagavaraks	vara	taga+vara	17_S	SgTr	et	tagavaraks =vara  (SgTr  >taga+vara !17_S
42858	kreemidele	kreemi	kreem	22_SA	PlAll	et	kreemidele =kreemi  (PlAll  >kreem !22_SA
42861	kaubale	kauba	kaup	22_S	SgAll	et	kaubale =kauba  (SgAll  >kaup !22_S
42867	keelustatakse	keelusta	keelustama	27_V	IndPrIps	et	keelustatakse =keelusta  (IndPrIps  >keelustama !27_V
42868	kehtestatakse	kehtesta	kehtestama	27_V	IndPrIps	et	kehtestatakse =kehtesta  (IndPrIps  >kehtestama !27_V
42874	vedur	vedur	vedur	02_S	SgN	et	vedur =vedur  (SgN  >vedur !02_S
42877	kallama	kalla	kallama	29_V	Sup	et	kallama =kalla  (Sup  >kallama !29_V
42879	kuvar	kuvar	kuvar	02_S	SgN	et	kuvar =kuvar  (SgN  >kuvar !02_S
42898	aeglustuma	aeglustu	aeglustuma	27_V	Sup	et	aeglustuma =aeglustu  (Sup  >aeglustuma !27_V
42903	avalduma	avaldu	avalduma	27_V	Sup	et	avalduma =avaldu  (Sup  >avalduma !27_V
42911	6-e			xx_Q	PlP	et	-e =  (PlP  > !xx_Q
42920	arhitektidele	arhitekti	arhitekt	22_S	PlAll	et	arhitektidele =arhitekti  (PlAll  >arhitekt !22_S
42923	lünkadesse	lünka	lünk	22_S	PlIll	et	lünkadesse =lünka  (PlIll  >lünk !22_S
42928	mõõdab	mõõda	mõõtma	34_V	IndPrSg3	et	mõõdab =mõõda  (IndPrSg3  >mõõtma !34_V
42933	mõõdetakse	mõõde	mõõtma	34_V	IndPrIps	et	mõõdetakse =mõõde  (IndPrIps  >mõõtma !34_V
42936	mikroprotsessoreile	protsessore	mikro+protsessor	02_S	PlAll	et	mikroprotsessoreile =protsessore  (PlAll  >mikro+protsessor !02_S
42940	nuppude	nuppu	nupp	22_S	PlG	et	nuppude =nuppu  (PlG  >nupp !22_S
42943	venib	veni	venima	27_V	IndPrSg3	et	venib =veni  (IndPrSg3  >venima !27_V
42946	toetuda	toetu	toetuma	27_V	Inf	et	toetuda =toetu  (Inf  >toetuma !27_V
42948	pulss	pulss	pulss	22_S	SgN	et	pulss =pulss  (SgN  >pulss !22_S
42958	näpitstangid	tangi	näpits+tang	22_S	PlN	et	näpitstangid =tangi  (PlN  >näpits+tang !22_S
42968	soojendada	soojenda	soojendama	27_V	Inf	et	soojendada =soojenda  (Inf  >soojendama !27_V
42974	kõlar	kõlar	kõlar	02_S	SgN	et	kõlar =kõlar  (SgN  >kõlar !02_S
42977	lambipirn	pirn	lambi+pirn	22_S	SgN	et	lambipirn =pirn  (SgN  >lambi+pirn !22_S
42982	sõnaraamatut	raamatu	sõna+raamat	02_S	SgP	et	sõnaraamatut =raamatu  (SgP  >sõna+raamat !02_S
42993	kohustusliku	kohustusliku	kohustuslik	25_A	SgG	et	kohustusliku =kohustusliku  (SgG  >kohustuslik !25_A
42998	oskuslik	oskuslik	oskuslik	25_A	SgN	et	oskuslik =oskuslik  (SgN  >oskuslik !25_A
43002	koolipoistele	pois	kooli+poiss	23_S	PlAll	et	koolipoistele =pois  (PlAll  >kooli+poiss !23_S
43003	järg-järgult	järgu	järg-järk	22_S	SgAbl	et	järg-järgult =järgu  (SgAbl  >järg-järk !22_S
43005	koolipoiste	pois	kooli+poiss	23_S	PlG	et	koolipoiste =pois  (PlG  >kooli+poiss !23_S
43006	osavõtmine	võtmine	osa+võtmine	12?10_S	SgN	et	osavõtmine =võtmine  (SgN  >osa+võtmine !12?10_S
43008	laialdast	laialdas	laialdane	12_A	SgP	et	laialdast =laialdas  (SgP  >laialdane !12_A
42783	binokliga	binokli	binokkel	02_S	SgKom	et	binokliga =binokli  (SgKom  >binokkel !02_S
42789	karjub	karju	karjuma	28_V	IndPrSg3	et	karjub =karju  (IndPrSg3  >karjuma !28_V
42793	oksad	oksa	oks	23?22_S	PlN	et	oksad =oksa  (PlN  >oks !23?22_S
42797	tiksub	tiksu	tiksuma	28_V	IndPrSg3	et	tiksub =tiksu  (IndPrSg3  >tiksuma !28_V
42799	võimalikkudest	võimalikku	võimalik	25_A	PlEl	et	võimalikkudest =võimalikku  (PlEl  >võimalik !25_A
42803	võimaluste	võimalus	võimalus	11_S	PlG	et	võimaluste =võimalus  (PlG  >võimalus !11_S
42813	naaberi	naaberi	naaber	02_S	SgG	et	naaberi =naaberi  (SgG  >naaber !02_S
42815	binokkel	binokkel	binokkel	02_S	SgN	et	binokkel =binokkel  (SgN  >binokkel !02_S
42818	pikniku	pikniku	piknik	02_S	SgG	et	pikniku =pikniku  (SgG  >piknik !02_S
42821	püsiga	püsi	püsi	17_S	SgKom	et	püsiga =püsi  (SgKom  >püsi !17_S
42825	rohis	rohi	rohima	27_V	IndIpfSg3	et	rohis =rohi  (IndIpfSg3  >rohima !27_V
42830	järvega	järve	järv	22_S	SgKom	et	järvega =järve  (SgKom  >järv !22_S
42833	salaja	salaja	salaja	41_D	ID	et	salaja =salaja  (ID  >salaja !41_D
42834	haukus	hauku	haukuma	28_V	IndIpfSg3	et	haukus =hauku  (IndIpfSg3  >haukuma !28_V
42838	kreem	kreem	kreem	22_SA	SgN	et	kreem =kreem  (SgN  >kreem !22_SA
42844	sorteerida	sorteeri	sorteerima	28_V	Inf	et	sorteerida =sorteeri  (Inf  >sorteerima !28_V
42846	väitel	väite	väide	06_S	SgAd	et	väitel =väite  (SgAd  >väide !06_S
42856	keemiavahendeid	vahende	keemia+vahend	02_S	PlP	et	keemiavahendeid =vahende  (PlP  >keemia+vahend !02_S
42859	kulutada	kuluta	kulutama	27_V	Inf	et	kulutada =kuluta  (Inf  >kulutama !27_V
42860	loosisedelitega	sedeli	loosi+sedel	02_S	PlKom	et	loosisedelitega =sedeli  (PlKom  >loosi+sedel !02_S
42862	kaupadesse	kaupa	kaup	22_S	PlIll	et	kaupadesse =kaupa  (PlIll  >kaup !22_S
42866	mahaviskamise	viskamise	maha+viskamine	12_S	SgG	et	mahaviskamise =viskamise  (SgG  >maha+viskamine !12_S
42872	teostada	teosta	teostama	27_V	Inf	et	teostada =teosta  (Inf  >teostama !27_V
42882	sidur	sidur	sidur	02_S	SgN	et	sidur =sidur  (SgN  >sidur !02_S
42883	puhur	puhur	puhur	02_S	SgN	et	puhur =puhur  (SgN  >puhur !02_S
42892	innustama	innusta	innustama	27_V	Sup	et	innustama =innusta  (Sup  >innustama !27_V
42893	kosuma	kosu	kosuma	27_V	Sup	et	kosuma =kosu  (Sup  >kosuma !27_V
42901	jahutama	jahuta	jahutama	27_V	Sup	et	jahutama =jahuta  (Sup  >jahutama !27_V
42906	sünonüümsete	sünonüümse	sünonüümne	02_A	PlG	et	sünonüümsete =sünonüümse  (PlG  >sünonüümne !02_A
42918	tänuavaldused	avalduse	tänu+avaldus	11_S	PlN	et	tänuavaldused =avalduse  (PlN  >tänu+avaldus !11_S
42922	arvutivõrk	võrk	arvuti+võrk	22_S	SgN	et	arvutivõrk =võrk  (SgN  >arvuti+võrk !22_S
42934	elektrimõõtjaga	mõõtja	elektri+mõõtja	01_S	SgKom	et	elektrimõõtjaga =mõõtja  (SgKom  >elektri+mõõtja !01_S
42939	reguleerida	reguleeri	reguleerima	28_V	Inf	et	reguleerida =reguleeri  (Inf  >reguleerima !28_V
42942	kõrvetad	kõrveta	kõrvetama	27_V	IndPrSg2	et	kõrvetad =kõrveta  (IndPrSg2  >kõrvetama !27_V
42947	aeglustab	aeglusta	aeglustama	27_V	IndPrSg3	et	aeglustab =aeglusta  (IndPrSg3  >aeglustama !27_V
42956	jagage	jaga	jagama	27_V	ImpPrPl2	et	jagage =jaga  (ImpPrPl2  >jagama !27_V
42967	äratuskellalt	kella	äratus+kell	22_S	SgAbl	et	äratuskellalt =kella  (SgAbl  >äratus+kell !22_S
42969	rõõsk	rõõsk	rõõsk	22_A	SgN	et	rõõsk =rõõsk  (SgN  >rõõsk !22_A
42970	monitor	monitor	monitor	19_S	SgN	et	monitor =monitor  (SgN  >monitor !19_S
42976	eluohtlik	ohtlik	elu+ohtlik	25_A	SgN	et	eluohtlik =ohtlik  (SgN  >elu+ohtlik !25_A
42978	laualambi	lambi	laua+lamp	22_SA	SgG	et	laualambi =lambi  (SgG  >laua+lamp !22_SA
42980	pirn	pirn	pirn	22_S	SgN	et	pirn =pirn  (SgN  >pirn !22_S
42984	välisõpilane	õpilane	välis+õpilane	12_S	SgN	et	välisõpilane =õpilane  (SgN  >välis+õpilane !12_S
42987	kinnitan	kinnita	kinnitama	27_V	IndPrSg1	et	kinnitan =kinnita  (IndPrSg1  >kinnitama !27_V
42990	teguritest	teguri	tegur	02_S	PlEl	et	teguritest =teguri  (PlEl  >tegur !02_S
42992	ähvardab	ähvarda	ähvardama	27_V	IndPrSg3	et	ähvardab =ähvarda  (IndPrSg3  >ähvardama !27_V
42994	karaktereid	karaktere	karakter	02_S	PlP	et	karaktereid =karaktere  (PlP  >karakter !02_S
43016	käsib	käsi	käskima	28_V	IndPrSg3	et	käsib =käsi  (IndPrSg3  >käskima !28_V
43020	sõjavõitlejate	võitleja	sõja+võitleja	01_SA	PlG	et	sõjavõitlejate =võitleja  (PlG  >sõja+võitleja !01_SA
43021	melanhoolset	melanhoolse	melanhoolne	02_A	SgP	et	melanhoolset =melanhoolse  (SgP  >melanhoolne !02_A
43025	põhja-viljandimaalt	maa	põhja-viljandi+maa	26_S	SgAbl	et	põhja-viljandimaalt =maa  (SgAbl  >põhja-viljandi+maa !26_S
43026	teenijatüdrukuna	tüdruku	teenija+tüdruk	02_S	SgEs	et	teenijatüdrukuna =tüdruku  (SgEs  >teenija+tüdruk !02_S
43027	kangruna	kangru	kangur	02_S	SgEs	et	kangruna =kangru  (SgEs  >kangur !02_S
42966	venin	veni	venima	27_V	IndPrSg1	et	venin =veni  (IndPrSg1  >venima !27_V
42981	vajaduse	vajaduse	vajadus	11_S	SgG	et	vajaduse =vajaduse  (SgG  >vajadus !11_S
42988	vaatajaskonna	vaatajaskonna	vaatajaskond	22_S	SgG	et	vaatajaskonna =vaatajaskonna  (SgG  >vaatajaskond !22_S
42989	huvidest	huvi	huvi	17_S	PlEl	et	huvidest =huvi  (PlEl  >huvi !17_S
42996	vapraid	vapra	vapper	02_A	PlP	et	vapraid =vapra  (PlP  >vapper !02_A
43001	selget	selge	selge	01_A	SgP	et	selget =selge  (SgP  >selge !01_A
43004	punasemeelsed	meelse	punase+meelne	02_A	PlN	et	punasemeelsed =meelse  (PlN  >punase+meelne !02_A
43007	vähestest	vähes	vähene	10_A	PlEl	et	vähestest =vähes  (PlEl  >vähene !10_A
43013	keelabki	keela	keelama	29_V	IndPrSg3^	et	keelabki =keela  (IndPrSg3^  >keelama !29_V
43014	nolgid	nolgi	nolk	22_S	PlN	et	nolgid =nolgi  (PlN  >nolk !22_S
43022	nahal	naha	nahk	22_S	SgAd	et	nahal =naha  (SgAd  >nahk !22_S
43036	kirdekaldal	kalda	kirde+kallas	07_S	SgAd	et	kirdekaldal =kalda  (SgAd  >kirde+kallas !07_S
43039	rasketesse	raske	raske	01_A	PlIll	et	rasketesse =raske  (PlIll  >raske !01_A
43041	vabadusvõitluse	võitluse	vabadus+võitlus	11~09_S	SgG	et	vabadusvõitluse =võitluse  (SgG  >vabadus+võitlus !11~09_S
43044	linnateatri	teatri	linna+teater	02_S	SgG	et	linnateatri =teatri  (SgG  >linna+teater !02_S
43045	peanäitejuht	juht	pea+näite+juht	22_S	SgN	et	peanäitejuht =juht  (SgN  >pea+näite+juht !22_S
43053	rindele	rinde	rinne	06_S	SgAll	et	rindele =rinde  (SgAll  >rinne !06_S
43055	lõpuga	lõpu	lõpp	22_SA	SgKom	et	lõpuga =lõpu  (SgKom  >lõpp !22_SA
43057	terviklikuks	tervikliku	terviklik	25_A	SgTr	et	terviklikuks =tervikliku  (SgTr  >terviklik !25_A
43067	hindame	hinda	hindama	29_V	IndPrPl1	et	hindame =hinda  (IndPrPl1  >hindama !29_V
43073	avastasin	avasta	avastama	27_V	IndIpfSg1	et	avastasin =avasta  (IndIpfSg1  >avastama !27_V
43079	taolisi	taolisi	taoline	12_A	PlP	et	taolisi =taolisi  (PlP  >taoline !12_A
43082	vabatahtlike	tahtlike	vaba+tahtlik	25_A	PlG	et	vabatahtlike =tahtlike  (PlG  >vaba+tahtlik !25_A
43086	võitleksime	võitle	võitlema	30_V	KndPrPl1	et	võitleksime =võitle  (KndPrPl1  >võitlema !30_V
43097	säärase	säärase	säärane	10_P	SgG	et	säärase =säärase  (SgG  >säärane !10_P
43099	kinokultuurile	kultuuri	kino+kultuur	22_S	SgAll	et	kinokultuurile =kultuuri  (SgAll  >kino+kultuur !22_S
43101	niisugustes	sugus	nii+sugune	10_P	PlIn	et	niisugustes =sugus  (PlIn  >nii+sugune !10_P
43106	eriarvamusi	arvamusi	eri+arvamus	11_S	PlP	et	eriarvamusi =arvamusi  (PlP  >eri+arvamus !11_S
43109	poistega	pois	poiss	23_S	PlKom	et	poistega =pois  (PlKom  >poiss !23_S
43114	püsse	püsse	püss	22_S	PlP	et	püsse =püsse  (PlP  >püss !22_S
43120	tundeküllasse	külla	tunde+küll	22_S	SgIll	et	tundeküllasse =külla  (SgIll  >tunde+küll !22_S
43121	kõre	kõre	kõre	02_A	SgN	et	kõre =kõre  (SgN  >kõre !02_A
43130	võib-	või	võima	37_V	IndPrSg3	et	võib- =või  (IndPrSg3  >võima !37_V
43144	sattusin	sattu	sattuma	27~28_V	IndIpfSg1	et	sattusin =sattu  (IndIpfSg1  >sattuma !27~28_V
43155	vaagub	vaagu	vaakuma	28_V	IndPrSg3	et	vaagub =vaagu  (IndPrSg3  >vaakuma !28_V
43157	miinuseks	miinuse	miinus	09_S	SgTr	et	miinuseks =miinuse  (SgTr  >miinus !09_S
43158	tegelaskujude	kuju	tegelas+kuju	17_S	PlG	et	tegelaskujude =kuju  (PlG  >tegelas+kuju !17_S
43159	pealiskaudset	kaudse	pealis+kaudne	02_A	SgP	et	pealiskaudset =kaudse  (SgP  >pealis+kaudne !02_A
43161	pühendama	pühenda	pühendama	27_V	Sup	et	pühendama =pühenda  (Sup  >pühendama !27_V
43174	traagikas	traagika	traagika	01_S	SgIn	et	traagikas =traagika  (SgIn  >traagika !01_S
43175	heitlus	heitlus	heitlus	11~09_S	SgN	et	heitlus =heitlus  (SgN  >heitlus !11~09_S
43177	käämeri	käämeri	käämer	02_S	SgG	et	käämeri =käämeri  (SgG  >käämer !02_S
43191	stseenis	stseeni	stseen	22_S	SgIn	et	stseenis =stseeni  (SgIn  >stseen !22_S
43192	dramaatiline	dramaatiline	dramaatiline	12_A	SgN	et	dramaatiline =dramaatiline  (SgN  >dramaatiline !12_A
43194	kontekstiga	konteksti	kontekst	22_S	SgKom	et	kontekstiga =konteksti  (SgKom  >kontekst !22_S
43198	rõkkas	rõkka	rõkkama	29_V	IndIpfSg3	et	rõkkas =rõkka  (IndIpfSg3  >rõkkama !29_V
43204	samastada	samasta	samastama	27_V	Inf	et	samastada =samasta  (Inf  >samastama !27_V
43205	eesmärkidest	märki	ees+märk	22_S	PlEl	et	eesmärkidest =märki  (PlEl  >ees+märk !22_S
43222	õuduste	õudus	õudus	11~09_S	PlG	et	õuduste =õudus  (PlG  >õudus !11~09_S
43227	tutvust	tutvus	tutvus	11~09_S	SgP	et	tutvust =tutvus  (SgP  >tutvus !11~09_S
43230	peaeesmärgiks	märgi	pea+ees+märk	22_S	SgTr	et	peaeesmärgiks =märgi  (SgTr  >pea+ees+märk !22_S
43235	seansi	seansi	seanss	22_S	SgG	et	seansi =seansi  (SgG  >seanss !22_S
43236	pühkida	pühki	pühkima	28_V	Inf	et	pühkida =pühki  (Inf  >pühkima !28_V
43238	surmaohus	ohu	surma+oht	22_S	SgIn	et	surmaohus =ohu  (SgIn  >surma+oht !22_S
42983	täiendharidus	haridus	täiend+haridus	11_S	SgN	et	täiendharidus =haridus  (SgN  >täiend+haridus !11_S
42986	käesolevaga	oleva	käes+olev	02_A	SgKom	et	käesolevaga =oleva  (SgKom  >käes+olev !02_A
42995	inimtüüpe	tüüpe	inim+tüüp	22_S	PlP	et	inimtüüpe =tüüpe  (PlP  >inim+tüüp !22_S
42997	argpükse	pükse	arg+püks	23?22_S	PlP	et	argpükse =pükse  (PlP  >arg+püks !23?22_S
42999	näitemäng	mäng	näite+mäng	22_S	SgN	et	näitemäng =mäng  (SgN  >näite+mäng !22_S
43015	ronite	roni	ronima	27_V	IndPrPl2	et	ronite =roni  (IndPrPl2  >ronima !27_V
43023	alluda	allu	alluma	27_V	Inf	et	alluda =allu  (Inf  >alluma !27_V
43028	punaarmeelane	armeelane	puna+armeelane	12?10_S	SgN	et	punaarmeelane =armeelane  (SgN  >puna+armeelane !12?10_S
43035	pataljon	pataljon	pataljon	19_S	SgN	et	pataljon =pataljon  (SgN  >pataljon !19_S
43037	jõesuus	suu	jõe+suu	26_S	SgIn	et	jõesuus =suu  (SgIn  >jõe+suu !26_S
43049	tegevusajaks	aja	tegevus+aeg	22_S	SgTr	et	tegevusajaks =aja  (SgTr  >tegevus+aeg !22_S
43054	filmil	filmi	film	22_S	SgAd	et	filmil =filmi  (SgAd  >film !22_S
43056	tahvlil	tahvli	tahvel	02_S	SgAd	et	tahvlil =tahvli  (SgAd  >tahvel !02_S
43059	tõustaks	tõus	tõusma	32_V	KndPrIps	et	tõustaks =tõus  (KndPrIps  >tõusma !32_V
43060	tümitama	tümita	tümitama	27_V	Sup	et	tümitama =tümita  (Sup  >tümitama !27_V
43062	negatiivseks	negatiivse	negatiivne	02_A	SgTr	et	negatiivseks =negatiivse  (SgTr  >negatiivne !02_A
43064	tegelaskujudele	kuju	tegelas+kuju	17_S	PlAll	et	tegelaskujudele =kuju  (PlAll  >tegelas+kuju !17_S
43065	kriisiseisuga	seisu	kriisi+seis	22_S	SgKom	et	kriisiseisuga =seisu  (SgKom  >kriisi+seis !22_S
43072	koolitunnis	tunni	kooli+tund	22_S	SgIn	et	koolitunnis =tunni  (SgIn  >kooli+tund !22_S
43074	esmakordsel	kordse	esma+kordne	02_AS	SgAd	et	esmakordsel =kordse  (SgAd  >esma+kordne !02_AS
43094	kuntsel	kuntse	kunts	22_S	PlAd	et	kuntsel =kuntse  (PlAd  >kunts !22_S
43095	raamatki	raamat	raamat	02_S	SgN^	et	raamatki =raamat  (SgN^  >raamat !02_S
43100	sisekonflikt	konflikt	sise+konflikt	22_S	SgN	et	sisekonflikt =konflikt  (SgN  >sise+konflikt !22_S
43122	poistele	pois	poiss	23_S	PlAll	et	poistele =pois  (PlAll  >poiss !23_S
43129	tõustes	tõus	tõusma	32_V	Ger	et	tõustes =tõus  (Ger  >tõusma !32_V
43131	isamaasse	maa	isa+maa	26_S	SgIll	et	isamaasse =maa  (SgIll  >isa+maa !26_S
43139	troonilt	trooni	troon	22_S	SgAbl	et	troonilt =trooni  (SgAbl  >troon !22_S
43141	puudujäägid	jäägi	puudu+jääk	22_S	PlN	et	puudujäägid =jäägi  (PlN  >puudu+jääk !22_S
43142	seose	seose	seos	09_S	SgG	et	seose =seose  (SgG  >seos !09_S
43143	kokkuvõtlik	võtlik	kokku+võtlik	25_A	SgN	et	kokkuvõtlik =võtlik  (SgN  >kokku+võtlik !25_A
43150	huilgama	huilga	huilgama	29_V	Sup	et	huilgama =huilga  (Sup  >huilgama !29_V
43160	üksik	üksik	üksik	02_A	SgN	et	üksik =üksik  (SgN  >üksik !02_A
43167	marmor	marmor	marmor	02_S	SgN	et	marmor =marmor  (SgN  >marmor !02_S
43168	filmivaatajad	vaataja	filmi+vaataja	01_S	PlN	et	filmivaatajad =vaataja  (PlN  >filmi+vaataja !01_S
43170	leiaks	leia	leidma	34_V	KndPrPs	et	leiaks =leia  (KndPrPs  >leidma !34_V
43183	kaitsel	kaitse	kaitse	06_S	SgAd	et	kaitsel =kaitse  (SgAd  >kaitse !06_S
43185	patriotismile	patriotismi	patriotism	22_S	SgAll	et	patriotismile =patriotismi  (SgAll  >patriotism !22_S
43186	kodanlased	kodanlase	kodanlane	12_S	PlN	et	kodanlased =kodanlase  (PlN  >kodanlane !12_S
43187	kehvikud	kehviku	kehvik	02_S	PlN	et	kehvikud =kehviku  (PlN  >kehvik !02_S
43202	väärtushinnanguid	hinnangu	väärtus+hinnang	02_S	PlP	et	väärtushinnanguid =hinnangu  (PlP  >väärtus+hinnang !02_S
43212	orjade	orja	ori	24_S	PlG	et	orjade =orja  (PlG  >ori !24_S
43215	vabatahtlikena	tahtlike	vaba+tahtlik	25_A	PlEs	et	vabatahtlikena =tahtlike  (PlEs  >vaba+tahtlik !25_A
43224	noortes	noor	noor	13_AS	PlIn	et	noortes =noor  (PlIn  >noor !13_AS
43231	teismeliste	teismelis	teismeline	12_SA	PlG	et	teismeliste =teismelis  (PlG  >teismeline !12_SA
43232	ideaalis	ideaali	ideaal	22_S	SgIn	et	ideaalis =ideaali  (SgIn  >ideaal !22_S
43233	patrioodid	patrioodi	patrioot	22_S	PlN	et	patrioodid =patrioodi  (PlN  >patrioot !22_S
43234	eesmärgini	märgi	ees+märk	22_S	SgTer	et	eesmärgini =märgi  (SgTer  >ees+märk !22_S
43237	okupatsioonist	okupatsiooni	okupatsioon	22_S	SgEl	et	okupatsioonist =okupatsiooni  (SgEl  >okupatsioon !22_S
43240	ootusi	ootusi	ootus	11_S	PlP	et	ootusi =ootusi  (PlP  >ootus !11_S
43241	põhijoontes	joon	põhi+joon	13_S	PlIn	et	põhijoontes =joon  (PlIn  >põhi+joon !13_S
43242	ühtsustunne	tunne	ühtsus+tunne	06_S	SgN	et	ühtsustunne =tunne  (SgN  >ühtsus+tunne !06_S
43245	vaenlasega	vaenlase	vaenlane	12?10_S	SgKom	et	vaenlasega =vaenlase  (SgKom  >vaenlane !12?10_S
43246	kõhe	kõhe	kõhe	02_A	SgN	et	kõhe =kõhe  (SgN  >kõhe !02_A
43250	maailmavaadete	vaade	maa+ilma+vaade	06_S	PlG	et	maailmavaadete =vaade  (PlG  >maa+ilma+vaade !06_S
43009	kriitikute	kriitiku	kriitik	02_S	PlG	et	kriitikute =kriitiku  (PlG  >kriitik !02_S
43011	kõhkleb	kõhkle	kõhklema	30_V	IndPrSg3	et	kõhkleb =kõhkle  (IndPrSg3  >kõhklema !30_V
43017	vabadussõjas	sõja	vabadus+sõda	18_S	SgIn	et	vabadussõjas =sõja  (SgIn  >vabadus+sõda !18_S
43018	maailmamastaabis	mastaabi	maa+ilma+mastaap	22_S	SgIn	et	maailmamastaabis =mastaabi  (SgIn  >maa+ilma+mastaap !22_S
43019	äkkrünnaku	rünnaku	äkk+rünnak	02_S	SgG	et	äkkrünnaku =rünnaku  (SgG  >äkk+rünnak !02_S
43042	kojusõit	sõit	koju+sõit	22_S	SgN	et	kojusõit =sõit  (SgN  >koju+sõit !22_S
43043	lahingus	lahingu	lahing	02_S	SgIn	et	lahingus =lahingu  (SgIn  >lahing !02_S
43051	klassivahedest	vahe	klassi+vahe	16_S	PlEl	et	klassivahedest =vahe  (PlEl  >klassi+vahe !16_S
43052	kõhklustest	kõhklus	kõhklus	11~09_S	PlEl	et	kõhklustest =kõhklus  (PlEl  >kõhklus !11~09_S
43058	poolikuks	pooliku	poolik	02_AS	SgTr	et	poolikuks =pooliku  (SgTr  >poolik !02_AS
43063	lahtiseletamatuks	seletamatu	lahti+seletamatu	01_A	SgTr	et	lahtiseletamatuks =seletamatu  (SgTr  >lahti+seletamatu !01_A
43068	tsiteeritakse	tsiteeri	tsiteerima	28_V	IndPrIps	et	tsiteeritakse =tsiteeri  (IndPrIps  >tsiteerima !28_V
43075	ridade	rida	rida	18_S	PlG	et	ridade =rida  (PlG  >rida !18_S
43077	mitteeestlane	eestlane	mitte+eestlane	12?10_S	SgN	et	mitteeestlane =eestlane  (SgN  >mitte+eestlane !12?10_S
43080	veidigi	veidi	veidi	41_D	ID^	et	veidigi =veidi  (ID^  >veidi !41_D
43081	iseseisvusaja	aja	ise+seisvus+aeg	22_S	SgG	et	iseseisvusaja =aja  (SgG  >ise+seisvus+aeg !22_S
43087	kõiguksime	kõigu	kõikuma	28_V	KndPrPl1	et	kõiguksime =kõigu  (KndPrPl1  >kõikuma !28_V
43102	ebareaalsed	reaalse	eba+reaalne	02_A	PlN	et	ebareaalsed =reaalse  (PlN  >eba+reaalne !02_A
43105	sõduritel	sõduri	sõdur	02_S	PlAd	et	sõduritel =sõduri  (PlAd  >sõdur !02_S
43107	kokkulepe	lepe	kokku+lepe	06_S	SgN	et	kokkulepe =lepe  (SgN  >kokku+lepe !06_S
43108	kangelased	kangelase	kangelane	12_S	PlN	et	kangelased =kangelase  (PlN  >kangelane !12_S
43115	ainsad	ainsa	ainus	03~05_AS	PlN	et	ainsad =ainsa  (PlN  >ainus !03~05_AS
43119	iseendi	end	ise+enda	00_P	PlG	et	iseendi =end  (PlG  >ise+enda !00_P
43123	vapraks	vapra	vapper	02_A	SgTr	et	vapraks =vapra  (SgTr  >vapper !02_A
43125	raiskasin	raiska	raiskama	29_V	IndIpfSg1	et	raiskasin =raiska  (IndIpfSg1  >raiskama !29_V
43132	baseerub	baseeru	baseeruma	27_V	IndPrSg3	et	baseerub =baseeru  (IndPrSg3  >baseeruma !27_V
43136	maatasa	maatasa	maa+tasa	41_D	ID	et	maatasa =maatasa  (ID  >maa+tasa !41_D
43138	tõukas	tõuka	tõukama	29_V	IndIpfSg3	et	tõukas =tõuka  (IndIpfSg3  >tõukama !29_V
43140	kõneainet	aine	kõne+aine	06_S	SgP	et	kõneainet =aine  (SgP  >kõne+aine !06_S
43146	maigu	maigu	maik	22_S	SgG	et	maigu =maigu  (SgG  >maik !22_S
43154	kirstudes	kirstu	kirst	22_S	PlIn	et	kirstudes =kirstu  (PlIn  >kirst !22_S
43162	omanikke	omanikke	omanik	25_S	PlP	et	omanikke =omanikke  (PlP  >omanik !25_S
43164	kodanlaste	kodanlas	kodanlane	12_S	PlG	et	kodanlaste =kodanlas  (PlG  >kodanlane !12_S
43176	maailmavaadetega	vaade	maa+ilma+vaade	06_S	PlKom	et	maailmavaadetega =vaade  (PlKom  >maa+ilma+vaade !06_S
43181	segast	segas	segane	10_A	SgP	et	segast =segas  (SgP  >segane !10_A
43188	absurdne	absurdne	absurdne	02_A	SgN	et	absurdne =absurdne  (SgN  >absurdne !02_A
43193	pereliiget	liige	pere+liige	05_S	SgP	et	pereliiget =liige  (SgP  >pere+liige !05_S
43201	teismelised	teismelise	teismeline	12_SA	PlN	et	teismelised =teismelise  (PlN  >teismeline !12_SA
43210	olemuselt	olemuse	olemus	11_S	SgAbl	et	olemuselt =olemuse  (SgAbl  >olemus !11_S
43217	sõdida	sõdi	sõdima	27_V	Inf	et	sõdida =sõdi  (Inf  >sõdima !27_V
43226	minulgi	minu	mina	00_P	SgAd^	et	minulgi =minu  (SgAd^  >mina !00_P
43247	tollastest	tollas	tollane	10_A	PlEl	et	tollastest =tollas  (PlEl  >tollane !10_A
43251	poliitikud	poliitiku	poliitik	02_S	PlN	et	poliitikud =poliitiku  (PlN  >poliitik !02_S
43254	ajutise	ajutise	ajutine	12_A	SgG	et	ajutise =ajutise  (SgG  >ajutine !12_A
43257	tühistas	tühista	tühistama	27_V	IndIpfSg3	et	tühistas =tühista  (IndIpfSg3  >tühistama !27_V
43264	punaarmeele	armee	puna+armee	26_S	SgAll	et	punaarmeele =armee  (SgAll  >puna+armee !26_S
43270	rinnetel	rinne	rinne	06_S	PlAd	et	rinnetel =rinne  (PlAd  >rinne !06_S
43284	üksused	üksuse	üksus	11~09_S	PlN	et	üksused =üksuse  (PlN  >üksus !11~09_S
43288	kaitsel20-24	kaitse	kaitse	06_S	SgAd	et	kaitsel- =kaitse  (SgAd  >kaitse !06_S
43289	pataljoniks	pataljoni	pataljon	19_S	SgTr	et	pataljoniks =pataljoni  (SgTr  >pataljon !19_S
43291	abivägede	väge	abi+vägi	21_S	PlG	et	abivägede =väge  (PlG  >abi+vägi !21_S
43295	võimalustesse	võimalus	võimalus	11_S	PlIll	et	võimalustesse =võimalus  (PlIll  >võimalus !11_S
43299	maakonnavalitsused	valitsuse	maa+konna+valitsus	11_S	PlN	et	maakonnavalitsused =valitsuse  (PlN  >maa+konna+valitsus !11_S
43010	rivist	rivi	rivi	17_S	SgEl	et	rivist =rivi  (SgEl  >rivi !17_S
43012	veli	veli	veli	24_S	SgN	et	veli =veli  (SgN  >veli !24_S
43024	ajaperioodil	perioodi	aja+periood	22_S	SgAd	et	ajaperioodil =perioodi  (SgAd  >aja+periood !22_S
43030	vallutama	valluta	vallutama	27_V	Sup	et	vallutama =valluta  (Sup  >vallutama !27_V
43031	koolipoistest	pois	kooli+poiss	23_S	PlEl	et	koolipoistest =pois  (PlEl  >kooli+poiss !23_S
43032	kiidusõnu	sõnu	kiidu+sõna	17_S	PlP	et	kiidusõnu =sõnu  (PlP  >kiidu+sõna !17_S
43034	väesalgad	salga	väe+salk	22_S	PlN	et	väesalgad =salga  (PlN  >väe+salk !22_S
43038	ründama	ründa	ründama	29_V	Sup	et	ründama =ründa  (Sup  >ründama !29_V
43046	tuhandetele	tuhande	tuhat	02_N	PlAll	et	tuhandetele =tuhande  (PlAll  >tuhat !02_N
43047	hingeminev	minev	hinge+minev	02_A	SgN	et	hingeminev =minev  (SgN  >hinge+minev !02_A
43050	tegelasteks	tegelas	tegelane	12_S	PlTr	et	tegelasteks =tegelas  (PlTr  >tegelane !12_S
43061	joostaks	joos	jooksma	32_V	KndPrIps	et	joostaks =joos  (KndPrIps  >jooksma !32_V
43071	mingisuguste	sugus	mingi+sugune	10_P	PlG	et	mingisuguste =sugus  (PlG  >mingi+sugune !10_P
43078	mälestama	mälesta	mälestama	27_V	Sup	et	mälestama =mälesta  (Sup  >mälestama !27_V
43083	üksus	üksus	üksus	11~09_S	SgN	et	üksus =üksus  (SgN  >üksus !11~09_S
43085	tunneksime	tunne	tundma	34_V	KndPrPl1	et	tunneksime =tunne  (KndPrPl1  >tundma !34_V
43089	peategelastega	tegelas	pea+tegelane	12_S	PlKom	et	peategelastega =tegelas  (PlKom  >pea+tegelane !12_S
43090	lavastas	lavasta	lavastama	27_V	IndIpfSg3	et	lavastas =lavasta  (IndIpfSg3  >lavastama !27_V
43091	jäädvustas	jäädvusta	jäädvustama	27_V	IndIpfSg3	et	jäädvustas =jäädvusta  (IndIpfSg3  >jäädvustama !27_V
43110	eluvõõrad	võõra	elu+võõras	07_AS	PlN	et	eluvõõrad =võõra  (PlN  >elu+võõras !07_AS
43116	kinosaalis	saali	kino+saal	22_S	SgIn	et	kinosaalis =saali  (SgIn  >kino+saal !22_S
43126	koolipinkidest	pinki	kooli+pink	22_S	PlEl	et	koolipinkidest =pinki  (PlEl  >kooli+pink !22_S
43127	padrunid	padruni	padrun	02_S	PlN	et	padrunid =padruni  (PlN  >padrun !02_S
43128	padruneid	padrune	padrun	02_S	PlP	et	padruneid =padrune  (PlP  >padrun !02_S
43134	alustaksin	alusta	alustama	27_V	KndPrSg1	et	alustaksin =alusta  (KndPrSg1  >alustama !27_V
43148	stseen	stseen	stseen	22_S	SgN	et	stseen =stseen  (SgN  >stseen !22_S
43152	vabadusetunnet	tunne	vabaduse+tunne	06_S	SgP	et	vabadusetunnet =tunne  (SgP  >vabaduse+tunne !06_S
43153	kujutades	kujuta	kujutama	27_V	Ger	et	kujutades =kujuta  (Ger  >kujutama !27_V
43172	lembehetkedest	hetke	lembe+hetk	22_S	PlEl	et	lembehetkedest =hetke  (PlEl  >lembe+hetk !22_S
43173	lõpustseenist	stseeni	lõpu+stseen	22_S	SgEl	et	lõpustseenist =stseeni  (SgEl  >lõpu+stseen !22_S
43179	ilmestab	ilmesta	ilmestama	27_V	IndPrSg3	et	ilmestab =ilmesta  (IndPrSg3  >ilmestama !27_V
43182	üldmobilisatsioon	mobilisatsioon	üld+mobilisatsioon	22_S	SgN	et	üldmobilisatsioon =mobilisatsioon  (SgN  >üld+mobilisatsioon !22_S
43184	vabatahtlikuna	tahtliku	vaba+tahtlik	25_A	SgEs	et	vabatahtlikuna =tahtliku  (SgEs  >vaba+tahtlik !25_A
43195	eesmärgina	märgi	ees+märk	22_S	SgEs	et	eesmärgina =märgi  (SgEs  >ees+märk !22_S
43197	saal	saal	saal	22_S	SgN	et	saal =saal  (SgN  >saal !22_S
43200	kriitikutele	kriitiku	kriitik	02_S	PlAll	et	kriitikutele =kriitiku  (PlAll  >kriitik !02_S
43203	kujutlusvõimet	võime	kujutlus+võime	06_S	SgP	et	kujutlusvõimet =võime  (SgP  >kujutlus+võime !06_S
43209	otses	otse	ots	22_S	PlIn	et	otses =otse  (PlIn  >ots !22_S
43213	praegustel	praegus	praegune	10~12_A	PlAd	et	praegustel =praegus  (PlAd  >praegune !10~12_A
43214	eestlaseks	eestlase	eestlane	12?10_S	SgTr	et	eestlaseks =eestlase  (SgTr  >eestlane !12?10_S
43216	adekvaatne	adekvaatne	adekvaatne	02_A	SgN	et	adekvaatne =adekvaatne  (SgN  >adekvaatne !02_A
43218	pealehakkamist	hakkamis	peale+hakkamine	12_S	SgP	et	pealehakkamist =hakkamis  (SgP  >peale+hakkamine !12_S
43220	ideaalid	ideaali	ideaal	22_S	PlN	et	ideaalid =ideaali  (PlN  >ideaal !22_S
43221	kokkupuudet	puude	kokku+puude	06_S	SgP	et	kokkupuudet =puude  (SgP  >kokku+puude !06_S
43223	vastumeelt	vastumeelt	vastu+meelt	41_D	ID	et	vastumeelt =vastumeelt  (ID  >vastu+meelt !41_D
43225	tärkab	tärka	tärkama	29_V	IndPrSg3	et	tärkab =tärka  (IndPrSg3  >tärkama !29_V
43239	seiklusfilm	film	seiklus+film	22_S	SgN	et	seiklusfilm =film  (SgN  >seiklus+film !22_S
43244	heitlusse	heitlus	heitlus	11_S	SgAdt	et	heitlusse =heitlus  (SgAdt  >heitlus !11_S
43252	teatati	teata	teatama	27_V	IndIpfIps	et	teatati =teata  (IndIpfIps  >teatama !27_V
43265	takistas	takista	takistama	27_V	IndIpfSg3	et	takistas =takista  (IndIpfSg3  >takistama !27_V
43268	vastupanuta	panu	vastu+panu	17_S	SgAb	et	vastupanuta =panu  (SgAb  >vastu+panu !17_S
43274	piiridest	piiri	piir	22_S	PlEl	et	piiridest =piiri  (PlEl  >piir !22_S
43276	ülemjuhatajaks	juhataja	ülem+juhataja	01_S	SgTr	et	ülemjuhatajaks =juhataja  (SgTr  >ülem+juhataja !01_S
43029	okupandid	okupandi	okupant	22_S	PlN	et	okupandid =okupandi  (PlN  >okupant !22_S
43033	kaitseliidu	liidu	kaitse+liit	22_S	SgG	et	kaitseliidu =liidu  (SgG  >kaitse+liit !22_S
43040	ülev	ülev	ülev	02_A	SgN	et	ülev =ülev  (SgN  >ülev !02_A
43048	romaanil	romaani	romaan	22_S	SgAd	et	romaanil =romaani  (SgAd  >romaan !22_S
43066	möödalaskmisi	laskmisi	mööda+laskmine	12_S	PlP	et	möödalaskmisi =laskmisi  (PlP  >mööda+laskmine !12_S
43069	koosviibimistel	viibimis	koos+viibimine	12_S	PlAd	et	koosviibimistel =viibimis  (PlAd  >koos+viibimine !12_S
43070	kuulun	kuulu	kuuluma	27_V	IndPrSg1	et	kuulun =kuulu  (IndPrSg1  >kuuluma !27_V
43076	jääbki	jää	jääma	37_V	IndPrSg3^	et	jääbki =jää  (IndPrSg3^  >jääma !37_V
43084	muserdab	muserda	muserdama	27_V	IndPrSg3	et	muserdab =muserda  (IndPrSg3  >muserdama !27_V
43088	otsustaksime	otsusta	otsustama	27_V	KndPrPl1	et	otsustaksime =otsusta  (KndPrPl1  >otsustama !27_V
43092	filmilindile	lindi	filmi+lint	22_S	SgAll	et	filmilindile =lindi  (SgAll  >filmi+lint !22_S
43093	peaosades	osa	pea+osa	17_S	PlIn	et	peaosades =osa  (PlIn  >pea+osa !17_S
43096	tülidest	tüli	tüli	17_S	PlEl	et	tülidest =tüli  (PlEl  >tüli !17_S
43098	ühtsustunnet	tunne	ühtsus+tunne	06_S	SgP	et	ühtsustunnet =tunne  (SgP  >ühtsus+tunne !06_S
43103	võideldakse	võidel	võitlema	30_V	IndPrIps	et	võideldakse =võidel  (IndPrIps  >võitlema !30_V
43104	sõditakse	sõdi	sõdima	27_V	IndPrIps	et	sõditakse =sõdi  (IndPrIps  >sõdima !27_V
43111	kartus	kartus	kartus	11~09_S	SgN	et	kartus =kartus  (SgN  >kartus !11~09_S
43112	surmahirm	hirm	surma+hirm	22_S	SgN	et	surmahirm =hirm  (SgN  >surma+hirm !22_S
43113	põgenetakse	põgene	põgenema	27_V	IndPrIps	et	põgenetakse =põgene  (IndPrIps  >põgenema !27_V
43117	küsite	küsi	küsima	27_V	IndPrPl2	et	küsite =küsi  (IndPrPl2  >küsima !27_V
43118	gümnasist	gümnasist	gümnasist	22_S	SgN	et	gümnasist =gümnasist  (SgN  >gümnasist !22_S
43124	sellile	selli	sell	22_S	SgAll	et	sellile =selli  (SgAll  >sell !22_S
43133	osadest	osa	osa	17_S	PlEl	et	osadest =osa  (PlEl  >osa !17_S
43135	taevani	taeva	taevas	07_S	SgTer	et	taevani =taeva  (SgTer  >taevas !07_S
43137	kõnekad	kõneka	kõnekas	02_A	PlN	et	kõnekad =kõneka  (PlN  >kõnekas !02_A
43145	taandumas	taandu	taanduma	27_V	SupIn	et	taandumas =taandu  (SupIn  >taanduma !27_V
43147	filmile	filmi	film	22_S	SgAll	et	filmile =filmi  (SgAll  >film !22_S
43149	sihtmärgiks	märgi	siht+märk	22_S	SgTr	et	sihtmärgiks =märgi  (SgTr  >siht+märk !22_S
43151	soomusrong	rong	soomus+rong	22_S	SgN	et	soomusrong =rong  (SgN  >soomus+rong !22_S
43156	eufooriasse	eufooria	eufooria	01_S	SgIll	et	eufooriasse =eufooria  (SgIll  >eufooria !01_S
43163	tuvastada	tuvasta	tuvastama	27_V	Inf	et	tuvastada =tuvasta  (Inf  >tuvastama !27_V
43165	stseenid	stseeni	stseen	22_S	PlN	et	stseenid =stseeni  (PlN  >stseen !22_S
43166	kerkis	kerki	kerkima	27_V	IndIpfSg3	et	kerkis =kerki  (IndIpfSg3  >kerkima !27_V
43169	puudusi	puudusi	puudus	11_S	PlP	et	puudusi =puudusi  (PlP  >puudus !11_S
43171	romaanile	romaani	romaan	22_S	SgAll	et	romaanile =romaani  (SgAll  >romaan !22_S
43178	tänavavaidluses	vaidluse	tänava+vaidlus	11~09_S	SgIn	et	tänavavaidluses =vaidluse  (SgIn  >tänava+vaidlus !11~09_S
43180	tolleaegset	aegse	tolle+aegne	02_A	SgP	et	tolleaegset =aegse  (SgP  >tolle+aegne !02_A
43189	osutub	osutu	osutuma	27_V	IndPrSg3	et	osutub =osutu  (IndPrSg3  >osutuma !27_V
43190	vaenlaseks	vaenlase	vaenlane	12?10_S	SgTr	et	vaenlaseks =vaenlase  (SgTr  >vaenlane !12?10_S
43196	mingeidki	minge	mingi	01_P	PlP^	et	mingeidki =minge  (PlP^  >mingi !01_P
43199	tagaigatsevatele	igatseva	taga+igatsev	02_A	PlAll	et	tagaigatsevatele =igatseva  (PlAll  >taga+igatsev !02_A
43206	võrdlusi	võrdlusi	võrdlus	11_S	PlP	et	võrdlusi =võrdlusi  (PlP  >võrdlus !11_S
43207	esiisad	isa	esi+isa	17_S	PlN	et	esiisad =isa  (PlN  >esi+isa !17_S
43208	teismelistega	teismelis	teismeline	12_SA	PlKom	et	teismelistega =teismelis  (PlKom  >teismeline !12_SA
43211	tsivilisatsioonide	tsivilisatsiooni	tsivilisatsioon	22_S	PlG	et	tsivilisatsioonide =tsivilisatsiooni  (PlG  >tsivilisatsioon !22_S
43219	lahinguväljal	välja	lahingu+väli	24_S	SgAd	et	lahinguväljal =välja  (SgAd  >lahingu+väli !24_S
43228	tolleaegsega	aegse	tolle+aegne	02_A	SgKom	et	tolleaegsega =aegse  (SgKom  >tolle+aegne !02_A
43229	ootustele	ootus	ootus	11~09_S	PlAll	et	ootustele =ootus  (PlAll  >ootus !11~09_S
43243	isiklike	isiklike	isiklik	25_A	PlG	et	isiklike =isiklike  (PlG  >isiklik !25_A
43248	katsumused	katsumuse	katsumus	11_S	PlN	et	katsumused =katsumuse  (PlN  >katsumus !11_S
43249	rahvuslase	rahvuslase	rahvuslane	12_S	SgG	et	rahvuslase =rahvuslase  (SgG  >rahvuslane !12_S
43255	iseseisvast	seisva	ise+seisev	02_A	SgEl	et	iseseisvast =seisva  (SgEl  >ise+seisev !02_A
43258	saksamaaga	maa	saksa+maa	26_S	SgKom	et	saksamaaga =maa  (SgKom  >saksa+maa !26_S
43253	rahvusväeosade	osa	rahvus+väe+osa	17_S	PlG	et	rahvusväeosade =osa  (PlG  >rahvus+väe+osa !17_S
43261	ohustas	ohusta	ohustama	27_V	IndIpfSg3	et	ohustas =ohusta  (IndIpfSg3  >ohustama !27_V
43272	vastupealetung	tung	vastu+peale+tung	22_S	SgN	et	vastupealetung =tung  (SgN  >vastu+peale+tung !22_S
43278	tugevdas	tugevda	tugevdama	27_V	IndIpfSg3	et	tugevdas =tugevda  (IndIpfSg3  >tugevdama !27_V
43282	raporteerib	raporteeri	raporteerima	28_V	IndPrSg3	et	raporteerib =raporteeri  (IndPrSg3  >raporteerima !28_V
43292	vallutab	valluta	vallutama	27_V	IndPrSg3	et	vallutab =valluta  (IndPrSg3  >vallutama !27_V
43296	suurvõimudele	võimu	suur+võim	22_S	PlAll	et	suurvõimudele =võimu  (PlAll  >suur+võim !22_S
43297	vägedega	väge	vägi	21_S	PlKom	et	vägedega =väge  (PlKom  >vägi !21_S
43298	alevi-	alevi	alev	02_S	SgG	et	alevi- =alevi  (SgG  >alev !02_S
43301	täitis	täit	täitma	34_V	IndIpfSg3	et	täitis =täit  (IndIpfSg3  >täitma !34_V
43303	anarhistliku	anarhistliku	anarhistlik	25_A	SgG	et	anarhistliku =anarhistliku  (SgG  >anarhistlik !25_A
43311	hauad	haua	haud	22_S	PlN	et	hauad =haua  (PlN  >haud !22_S
43314	võitluse	võitluse	võitlus	11~09_S	SgG	et	võitluse =võitluse  (SgG  >võitlus !11~09_S
43316	sealse	sealse	sealne	02_A	SgG	et	sealse =sealse  (SgG  >sealne !02_A
43318	säilida	säili	säilima	28_V	Inf	et	säilida =säili  (Inf  >säilima !28_V
43320	sõjaga	sõja	sõda	18_S	SgKom	et	sõjaga =sõja  (SgKom  >sõda !18_S
43322	asetleidnule	leidnu	aset+leidnu	01_S	SgAll	et	asetleidnule =leidnu  (SgAll  >aset+leidnu !01_S
43330	paris	pari	pari	17_S	SgIn	et	paris =pari  (SgIn  >pari !17_S
43336	seisneda	seisne	seisnema	27_V	Inf	et	seisneda =seisne  (Inf  >seisnema !27_V
43338	kirjapildiga	pildi	kirja+pilt	22_S	SgKom	et	kirjapildiga =pildi  (SgKom  >kirja+pilt !22_S
43339	pintsak	pintsak	pintsak	02_S	SgN	et	pintsak =pintsak  (SgN  >pintsak !02_S
43342	bandiidid	bandiidi	bandiit	22_S	PlN	et	bandiidid =bandiidi  (PlN  >bandiit !22_S
43343	asendatakse	asenda	asendama	27_V	IndPrIps	et	asendatakse =asenda  (IndPrIps  >asendama !27_V
43356	hukkuma	hukku	hukkuma	27~28_V	Sup	et	hukkuma =hukku  (Sup  >hukkuma !27~28_V
43360	kones	kone	kone	16_S	SgIn	et	kones =kone  (SgIn  >kone !16_S
43364	vajaduseta	vajaduse	vajadus	11_S	SgAb	et	vajaduseta =vajaduse  (SgAb  >vajadus !11_S
43367	tema-poore	poore	tema-poor	22_S	PlP	et	tema-poore =poore  (PlP  >tema-poor !22_S
43384	saabas	saabas	saabas	07_S	SgN	et	saabas =saabas  (SgN  >saabas !07_S
43398	hiilib	hiili	hiilima	28_V	IndPrSg3	et	hiilib =hiili  (IndPrSg3  >hiilima !28_V
43412	esseedekirjandite	kirjandi	esseede+kirjand	02_S	PlG	et	esseedekirjandite =kirjandi  (PlG  >esseede+kirjand !02_S
43415	tüüpväljenditega	väljendi	tüüp+väljend	02_S	PlKom	et	tüüpväljenditega =väljendi  (PlKom  >tüüp+väljend !02_S
43420	19-ks			xx_Q	SgTr	et	-ks =  (SgTr  > !xx_Q
43423	tiitli	tiitli	tiitel	02_S	SgG	et	tiitli =tiitli  (SgG  >tiitel !02_S
43424	paevikusse	viku	pae+vikk	22_S	SgIll	et	paevikusse =viku  (SgIll  >pae+vikk !22_S
43427	visuaalsele	visuaalse	visuaalne	02_A	SgAll	et	visuaalsele =visuaalse  (SgAll  >visuaalne !02_A
43429	asa	asa	ask	22_S	SgG	et	asa =asa  (SgG  >ask !22_S
43432	sümbolitega	sümboli	sümbol	02_S	PlKom	et	sümbolitega =sümboli  (PlKom  >sümbol !02_S
43436	tabelis	tabeli	tabel	02_S	SgIn	et	tabelis =tabeli  (SgIn  >tabel !02_S
43439	keeletundidest	tundi	keele+tund	22_S	PlEl	et	keeletundidest =tundi  (PlEl  >keele+tund !22_S
43445	väldib	väldi	vältima	28_V	IndPrSg3	et	väldib =väldi  (IndPrSg3  >vältima !28_V
43450	sappa	sappa	saba	17_S	SgAdt	et	sappa =sappa  (SgAdt  >saba !17_S
43452	imestab	imesta	imestama	27_V	IndPrSg3	et	imestab =imesta  (IndPrSg3  >imestama !27_V
43454	keeletarvitajal	tarvitaja	keele+tarvitaja	01_S	SgAd	et	keeletarvitajal =tarvitaja  (SgAd  >keele+tarvitaja !01_S
43458	bisnesmenina	bisnesmeni	bisnesmen	19_S	SgEs	et	bisnesmenina =bisnesmeni  (SgEs  >bisnesmen !19_S
43462	leppida	leppi	leppima	28_V	Inf	et	leppida =leppi  (Inf  >leppima !28_V
43467	madalaga	madala	madal	02_AS	SgKom	et	madalaga =madala  (SgKom  >madal !02_AS
43478	st-ga	st	st	xx_Q	SgKom	et	st-ga =st  (SgKom  >st !xx_Q
43481	jalgrattal	ratta	jalg+ratas	07_S	SgAd	et	jalgrattal =ratta  (SgAd  >jalg+ratas !07_S
43485	mile	mi	mi	26_S	SgAll	et	mile =mi  (SgAll  >mi !26_S
43511	poore	poore	poor	22_S	PlP	et	poore =poore  (PlP  >poor !22_S
43514	maaral	maara	maara	16_S	SgAd	et	maaral =maara  (SgAd  >maara !16_S
43515	stiiliveaks	vea	stiili+viga	18_S	SgTr	et	stiiliveaks =vea  (SgTr  >stiili+viga !18_S
43517	omaparast	paras	oma+paras	02_A	SgP	et	omaparast =paras  (SgP  >oma+paras !02_A
43526	millegiparast	paras	millegi+paras	02_A	SgP	et	millegiparast =paras  (SgP  >millegi+paras !02_A
43527	kabi	kabi	kabi	24_S	SgN	et	kabi =kabi  (SgN  >kabi !24_S
43256	ebakindel	kindel	eba+kindel	02_A	SgN	et	ebakindel =kindel  (SgN  >eba+kindel !02_A
43266	rahvuslike	rahvuslike	rahvuslik	25_A	PlG	et	rahvuslike =rahvuslike  (PlG  >rahvuslik !25_A
43267	relvajõudude	jõudu	relva+jõud	22_S	PlG	et	relvajõudude =jõudu  (PlG  >relva+jõud !22_S
43271	rahvaväe	väe	rahva+vägi	21_S	SgG	et	rahvaväe =väe  (SgG  >rahva+vägi !21_S
43275	polkovnik	polkovnik	polkovnik	02_S	SgN	et	polkovnik =polkovnik  (SgN  >polkovnik !02_S
43279	laevastikueskaader	eskaader	laevastiku+eskaader	02_S	SgN	et	laevastikueskaader =eskaader  (SgN  >laevastiku+eskaader !02_S
43290	pikasilla26	silla	pika+sild	22_S	SgG	et	pikasilla =silla  (SgG  >pika+sild !22_S
43300	sõjaväevalitsusteks	valitsus	sõja+väe+valitsus	11_S	PlTr	et	sõjaväevalitsusteks =valitsus  (PlTr  >sõja+väe+valitsus !11_S
43302	auga	au	au	26_S	SgKom	et	auga =au  (SgKom  >au !26_S
43309	võitluses	võitluse	võitlus	11~09_S	SgIn	et	võitluses =võitluse  (SgIn  >võitlus !11~09_S
43315	hargneb	hargne	hargnema	27_V	IndPrSg3	et	hargneb =hargne  (IndPrSg3  >hargnema !27_V
43325	järeltulijad	tulija	järel+tulija	01_S	PlN	et	järeltulijad =tulija  (PlN  >järel+tulija !01_S
43331	naites	nait	naitma	34_V	Ger	et	naites =nait  (Ger  >naitma !34_V
43334	kaande	kaan	kaas	14_S	SgAdt	et	kaande =kaan  (SgAdt  >kaas !14_S
43361	igapaevases	vase	iga+pae+vask	22_S	SgIn	et	igapaevases =vase  (SgIn  >iga+pae+vask !22_S
43369	kuulmis-	mi	kuul+mi	26_S	SgIn	et	kuulmis- =mi  (SgIn  >kuul+mi !26_S
43370	kuulamiskogemus	kogemus	kuulamis+kogemus	11_S	SgN	et	kuulamiskogemus =kogemus  (SgN  >kuulamis+kogemus !11_S
43376	rodus	rodu	rodu	17_S	SgIn	et	rodus =rodu  (SgIn  >rodu !17_S
43379	ebaselgena	selge	eba+selge	01_A	SgEs	et	ebaselgena =selge  (SgEs  >eba+selge !01_A
43391	kortereid	kortere	korter	02_S	PlP	et	kortereid =kortere  (PlP  >korter !02_S
43397	pikapeale	pikapeale	pika+peale	41_D	ID	et	pikapeale =pikapeale  (ID  >pika+peale !41_D
43409	harjutades	harjuta	harjutama	27_V	Ger	et	harjutades =harjuta  (Ger  >harjutama !27_V
43414	piirduma	piirdu	piirduma	27_V	Sup	et	piirduma =piirdu  (Sup  >piirduma !27_V
43417	20-ni			xx_Q	SgTer	et	-ni =  (SgTer  > !xx_Q
43425	õppesõnastike	sõnastike	õppe+sõnastik	25_S	PlG	et	õppesõnastike =sõnastike  (PlG  >õppe+sõnastik !25_S
43430	märgistan	märgista	märgistama	27_V	IndPrSg1	et	märgistan =märgista  (IndPrSg1  >märgistama !27_V
43434	klassitahvlile	tahvli	klassi+tahvel	02_S	SgAll	et	klassitahvlile =tahvli  (SgAll  >klassi+tahvel !02_S
43438	diftonge	diftonge	diftong	22_S	PlP	et	diftonge =diftonge  (PlP  >diftong !22_S
43444	klassifitseerida	klassifitseeri	klassifitseerima	28_V	Inf	et	klassifitseerida =klassifitseeri  (Inf  >klassifitseerima !28_V
43455	süntaksivigu	vigu	süntaksi+viga	18_S	PlP	et	süntaksivigu =vigu  (PlP  >süntaksi+viga !18_S
43457	igasugust	sugus	iga+sugune	10_A	SgP	et	igasugust =sugus  (SgP  >iga+sugune !10_A
43459	pangadirektorina	direktori	panga+direktor	02_S	SgEs	et	pangadirektorina =direktori  (SgEs  >panga+direktor !02_S
43460	kõrgega	kõrge	kõrge	01_A	SgKom	et	kõrgega =kõrge  (SgKom  >kõrge !01_A
43465	tööandjaid	andja	töö+andja	01_S	PlP	et	tööandjaid =andja  (PlP  >töö+andja !01_S
43466	võlgades	võlga	võlg	22_S	PlIn	et	võlgades =võlga  (PlIn  >võlg !22_S
43469	oskustes	oskus	oskus	11~09_S	PlIn	et	oskustes =oskus  (PlIn  >oskus !11~09_S
43470	püstitab	püstita	püstitama	27_V	IndPrSg3	et	püstitab =püstita  (IndPrSg3  >püstitama !27_V
43484	kattemaksuga	maksu	katte+maks	22_S	SgKom	et	kattemaksuga =maksu  (SgKom  >katte+maks !22_S
43487	itaaliaparaseid	parase	itaalia+paras	02_A	PlP	et	itaaliaparaseid =parase  (PlP  >itaalia+paras !02_A
43489	korgeks	korge	kork	22_S	PlTr	et	korgeks =korge  (PlTr  >kork !22_S
43498	platsele	platse	plats	22_S	PlAll	et	platsele =platse  (PlAll  >plats !22_S
43499	kulas	kula	kula	17_S	SgIn	et	kulas =kula  (SgIn  >kula !17_S
43500	vaikese	ese	vaik+ese	04_S	SgN	et	vaikese =ese  (SgN  >vaik+ese !04_S
43503	aiandus	aiandus	aiandus	11_S	SgN	et	aiandus =aiandus  (SgN  >aiandus !11_S
43504	a-ga	a	a	xx_Q	SgKom	et	a-ga =a  (SgKom  >a !xx_Q
43509	lahtus	lahtu	lahtuma	27_V	IndIpfSg3	et	lahtus =lahtu  (IndIpfSg3  >lahtuma !27_V
43510	variandist	variandi	variant	22_S	SgEl	et	variandist =variandi  (SgEl  >variant !22_S
43513	uusmoodustiseks	moodustise	uus+moodustis	11_S	SgTr	et	uusmoodustiseks =moodustise  (SgTr  >uus+moodustis !11_S
43518	mangus	mangu	manguma	28_V	IndIpfSg3	et	mangus =mangu  (IndIpfSg3  >manguma !28_V
43521	eesmark	mark	ees+mark	22_S	SgN	et	eesmark =mark  (SgN  >ees+mark !22_S
43528	veenaidud	naidu	vee+naidu	01_S	PlN	et	veenaidud =naidu  (PlN  >vee+naidu !01_S
43532	valis-	vali	valima	27_V	IndIpfSg3	et	valis- =vali  (IndIpfSg3  >valima !27_V
43533	margi	margi	mark	22_S	SgG	et	margi =margi  (SgG  >mark !22_S
43534	suutakse	takse	suu+taks	22_S	PlP	et	suutakse =takse  (PlP  >suu+taks !22_S
43259	lepingud	lepingu	leping	02_S	PlN	et	lepingud =lepingu  (PlN  >leping !02_S
43260	rünnak	rünnak	rünnak	02_S	SgN	et	rünnak =rünnak  (SgN  >rünnak !02_S
43262	edasitung	tung	edasi+tung	22_S	SgN	et	edasitung =tung  (SgN  >edasi+tung !22_S
43263	põhja-eestis	eesti	põhja-eesti	16_H	SgIn	et	põhja-eestis =eesti  (SgIn  >põhja-eesti !16_H
43269	kaitsevägi	vägi	kaitse+vägi	21_S	SgN	et	kaitsevägi =vägi  (SgN  >kaitse+vägi !21_S
43273	veebruariks	veebruari	veebruar	19_S	SgTr	et	veebruariks =veebruari  (SgTr  >veebruar !19_S
43277	rekvisitsioonidele	rekvisitsiooni	rekvisitsioon	22_S	PlAll	et	rekvisitsioonidele =rekvisitsiooni  (PlAll  >rekvisitsioon !22_S
43283	vaenuvägedest	väge	vaenu+vägi	21_S	PlEl	et	vaenuvägedest =väge  (PlEl  >vaenu+vägi !21_S
43285	rahulepinguga	lepingu	rahu+leping	02_S	SgKom	et	rahulepinguga =lepingu  (SgKom  >rahu+leping !02_S
43286	tunnustab	tunnusta	tunnustama	27_V	IndPrSg3	et	tunnustab =tunnusta  (IndPrSg3  >tunnustama !27_V
43287	enamlaselt	enamlase	enamlane	12_S	SgAbl	et	enamlaselt =enamlase  (SgAbl  >enamlane !12_S
43294	likvideeritakse	likvideeri	likvideerima	28_V	IndPrIps	et	likvideeritakse =likvideeri  (IndPrIps  >likvideerima !28_V
43306	tagurlikele	tagurlike	tagurlik	25_A	PlAll	et	tagurlikele =tagurlike  (PlAll  >tagurlik !25_A
43307	põlvkondadele	põlvkonda	põlvkond	22_S	PlAll	et	põlvkondadele =põlvkonda  (PlAll  >põlvkond !22_S
43310	marmortahvlitele	tahvli	marmor+tahvel	02_S	PlAll	et	marmortahvlitele =tahvli  (PlAll  >marmor+tahvel !02_S
43321	harjudes	harju	harjuma	27_V	Ger	et	harjudes =harju  (Ger  >harjuma !27_V
43323	vapper	vapper	vapper	02_A	SgN	et	vapper =vapper  (SgN  >vapper !02_A
43333	konsonantide	konsonanti	konsonant	22_S	PlG	et	konsonantide =konsonanti  (PlG  >konsonant !22_S
43348	halvast	halva	halb	22_A	SgEl	et	halvast =halva  (SgEl  >halb !22_A
43350	vaevuta	vaevu	vaevuma	27_V	IndPrIps_	et	vaevuta =vaevu  (IndPrIps_  >vaevuma !27_V
43352	toodes	toode	toot	22_S	PlIn	et	toodes =toode  (PlIn  >toot !22_S
43353	aravahetamist	vahetamis	ara+vahetamine	12_S	SgP	et	aravahetamist =vahetamis  (SgP  >ara+vahetamine !12_S
43357	eestikeelsest	keelse	eesti+keelne	02_A	SgEl	et	eestikeelsest =keelse  (SgEl  >eesti+keelne !02_A
43359	kasutamisvaljad	valja	kasutamis+valjas	07_S	PlN	et	kasutamisvaljad =valja  (PlN  >kasutamis+valjas !07_S
43365	insenerina	inseneri	insener	19_S	SgEs	et	insenerina =inseneri  (SgEs  >insener !19_S
43372	maletab	maleta	maletama	27_V	IndPrSg3	et	maletab =maleta  (IndPrSg3  >maletama !27_V
43378	kokkuleppeni	leppe	kokku+lepe	06_S	SgTer	et	kokkuleppeni =leppe  (SgTer  >kokku+lepe !06_S
43381	tapal	tapa	tapp	22_S	SgAd	et	tapal =tapa  (SgAd  >tapp !22_S
43388	harv	harv	harv	22_A	SgN	et	harv =harv  (SgN  >harv !22_A
43393	liikumapanevaks	paneva	liikuma+panev	02_A	SgTr	et	liikumapanevaks =paneva  (SgTr  >liikuma+panev !02_A
43400	kurdavad	kurda	kurtma	34_V	IndPrPl3	et	kurdavad =kurda  (IndPrPl3  >kurtma !34_V
43402	pedagooge	pedagooge	pedagoog	22_S	PlP	et	pedagooge =pedagooge  (PlP  >pedagoog !22_S
43403	peegeldub	peegeldu	peegelduma	27_V	IndPrSg3	et	peegeldub =peegeldu  (IndPrSg3  >peegelduma !27_V
43406	diftongide	diftongi	diftong	22_S	PlG	et	diftongide =diftongi  (PlG  >diftong !22_S
43408	lisaülesandeid	ande	lisa+üles+anne	06_S	PlP	et	lisaülesandeid =ande  (PlP  >lisa+üles+anne !06_S
43410	mudeleid	mudele	mudel	02_S	PlP	et	mudeleid =mudele  (PlP  >mudel !02_S
43421	korraldame	korralda	korraldama	27_V	IndPrPl1	et	korraldame =korralda  (IndPrPl1  >korraldama !27_V
43437	meeldejätmist	jätmis	meelde+jätmine	12?10_S	SgP	et	meeldejätmist =jätmis  (SgP  >meelde+jätmine !12?10_S
43441	sõnastikest	sõnastike	sõnastik	25_S	PlEl	et	sõnastikest =sõnastike  (PlEl  >sõnastik !25_S
43442	kohmakad	kohmaka	kohmakas	02_A	PlN	et	kohmakad =kohmaka  (PlN  >kohmakas !02_A
43446	keelekasutamiseks	kasutamise	keele+kasutamine	12_S	SgTr	et	keelekasutamiseks =kasutamise  (SgTr  >keele+kasutamine !12_S
43447	pedagoogidega	pedagoogi	pedagoog	22_S	PlKom	et	pedagoogidega =pedagoogi  (PlKom  >pedagoog !22_S
43451	vastutulijaid	tulija	vastu+tulija	01_S	PlP	et	vastutulijaid =tulija  (PlP  >vastu+tulija !01_S
43453	kirjutamisoskuse	oskuse	kirjutamis+oskus	11~09_S	SgG	et	kirjutamisoskuse =oskuse  (SgG  >kirjutamis+oskus !11~09_S
43461	tegelikke	tegelikke	tegelik	25_A	PlP	et	tegelikke =tegelikke  (PlP  >tegelik !25_A
43472	kultuuri-ja	ja	kultuuri-ja	41_J	ID	et	kultuuri-ja =ja  (ID  >kultuuri-ja !41_J
43476	lasnamäes	mäe	lasna+mägi	21_S	SgIn	et	lasnamäes =mäe  (SgIn  >lasna+mägi !21_S
43477	s-ga	s	s	xx_Q	SgKom	et	s-ga =s  (SgKom  >s !xx_Q
43479	armastusest-ga	armastusest	armastusest	xx_Q	SgKom	et	armastusest-ga =armastusest  (SgKom  >armastusest !xx_Q
43488	b-ga	b	b	xx_Q	SgKom	et	b-ga =b  (SgKom  >b !xx_Q
43495	pronoomen	pronoomen	pronoomen	02_S	SgN	et	pronoomen =pronoomen  (SgN  >pronoomen !02_S
43502	kodundus	kodundus	kodundus	11_S	SgN	et	kodundus =kodundus  (SgN  >kodundus !11_S
43280	vabatahtlikud	tahtliku	vaba+tahtlik	25_A	PlN	et	vabatahtlikud =tahtliku  (PlN  >vaba+tahtlik !25_A
43281	paraadil	paraadi	paraad	22_S	SgAd	et	paraadil =paraadi  (SgAd  >paraad !22_S
43293	marsivad	marsi	marssima	28_V	IndPrPl3	et	marsivad =marsi  (IndPrPl3  >marssima !28_V
43304	kaitsevõitluse	võitluse	kaitse+võitlus	11~09_S	SgG	et	kaitsevõitluse =võitluse  (SgG  >kaitse+võitlus !11~09_S
43305	pinnale	pinna	pind	22_S	SgAll	et	pinnale =pinna  (SgAll  >pind !22_S
43308	pooldan	poolda	pooldama	27_V	IndPrSg1	et	pooldan =poolda  (IndPrSg1  >pooldama !27_V
43313	tundrani	tundra	tundra	01_S	SgTer	et	tundrani =tundra  (SgTer  >tundra !01_S
43324	rahvuslased	rahvuslase	rahvuslane	12_S	PlN	et	rahvuslased =rahvuslase  (PlN  >rahvuslane !12_S
43326	toodest	toode	toot	22_S	PlEl	et	toodest =toode  (PlEl  >toot !22_S
43327	keeletasemega	taseme	keele+tase	04_S	SgKom	et	keeletasemega =taseme  (SgKom  >keele+tase !04_S
43328	miki	miki	mikk	22_S	SgG	et	miki =miki  (SgG  >mikk !22_S
43329	kull	kull	kull	22_S	SgN	et	kull =kull  (SgN  >kull !22_S
43332	unustades	unusta	unustama	27_V	Ger	et	unustades =unusta  (Ger  >unustama !27_V
43337	korv	korv	korv	22_S	SgN	et	korv =korv  (SgN  >korv !22_S
43340	peened	peene	peen	13_A	PlN	et	peened =peene  (PlN  >peen !13_A
43341	tasemega	taseme	tase	04_S	SgKom	et	tasemega =taseme  (SgKom  >tase !04_S
43345	eelviimases	viimase	eel+viimane	10_A	SgIn	et	eelviimases =viimase  (SgIn  >eel+viimane !10_A
43346	naol	nao	nadu	18_S	SgAd	et	naol =nao  (SgAd  >nadu !18_S
43347	lasevad	lase	laskma	34_V	IndPrPl3	et	lasevad =lase  (IndPrPl3  >laskma !34_V
43362	suhtluses	suhtluse	suhtlus	11~09_S	SgIn	et	suhtluses =suhtluse  (SgIn  >suhtlus !11~09_S
43366	taolist	taolis	taoline	12?10_A	SgP	et	taolist =taolis  (SgP  >taoline !12?10_A
43373	sagedaseks	sagedase	sagedane	12_A	SgTr	et	sagedaseks =sagedase  (SgTr  >sagedane !12_A
43375	ebareegliparaseid	parase	eba+reegli+paras	02_A	PlP	et	ebareegliparaseid =parase  (PlP  >eba+reegli+paras !02_A
43377	seinalambid	lambi	seina+lamp	22_SA	PlN	et	seinalambid =lambi  (PlN  >seina+lamp !22_SA
43380	hiiumaas	maa	hiiu+maa	26_S	SgIn	et	hiiumaas =maa  (SgIn  >hiiu+maa !26_S
43383	sall	sall	sall	22_S	SgN	et	sall =sall  (SgN  >sall !22_S
43387	mitmendaks	mitmenda	mitmes	02_P	SgTr	et	mitmendaks =mitmenda  (SgTr  >mitmes !02_P
43390	novemberil	novemberi	november	02_S	SgAd	et	novemberil =novemberi  (SgAd  >november !02_S
43394	sundus	sundus	sundus	11~09_S	SgN	et	sundus =sundus  (SgN  >sundus !11~09_S
43395	paberileht	leht	paberi+leht	22_S	SgN	et	paberileht =leht  (SgN  >paberi+leht !22_S
43405	põhivormide	vormi	põhi+vorm	22_S	PlG	et	põhivormide =vormi  (PlG  >põhi+vorm !22_S
43413	spontaanse	spontaanse	spontaanne	02_A	SgG	et	spontaanse =spontaanse  (SgG  >spontaanne !02_A
43418	kodutööks	töö	kodu+töö	26_S	SgTr	et	kodutööks =töö  (SgTr  >kodu+töö !26_S
43419	18-ks			xx_Q	SgTr	et	-ks =  (SgTr  > !xx_Q
43422	kirjatarga	targa	kirja+tark	22_AS	SgG	et	kirjatarga =targa  (SgG  >kirja+tark !22_AS
43426	õppematerjaliga	materjali	õppe+materjal	19_S	SgKom	et	õppematerjaliga =materjali  (SgKom  >õppe+materjal !19_S
43435	vihikusse	vihiku	vihik	02_S	SgIll	et	vihikusse =vihiku  (SgIll  >vihik !02_S
43449	krabinad	krabina	krabin	02_S	PlN	et	krabinad =krabina  (PlN  >krabin !02_S
43456	puruneks	purune	purunema	27_V	KndPrPs	et	puruneks =purune  (KndPrPs  >purunema !27_V
43468	selguda	selgu	selguma	27_V	Inf	et	selguda =selgu  (Inf  >selguma !27_V
43473	retseptsioon	retseptsioon	retseptsioon	22_S	SgN	et	retseptsioon =retseptsioon  (SgN  >retseptsioon !22_S
43480	trammil	trammi	tramm	22_S	SgAd	et	trammil =trammi  (SgAd  >tramm !22_S
43482	mitmenda	mitmenda	mitmes	02_P	SgG	et	mitmenda =mitmenda  (SgG  >mitmes !02_P
43483	mitmendat	mitmenda	mitmes	02_P	SgP	et	mitmendat =mitmenda  (SgP  >mitmes !02_P
43490	ortograafiaga	ortograafia	ortograafia	01_S	SgKom	et	ortograafiaga =ortograafia  (SgKom  >ortograafia !01_S
43494	valjendab	valjenda	valjendama	27_V	IndPrSg3	et	valjendab =valjenda  (IndPrSg3  >valjendama !27_V
43497	korgel	korge	kork	22_S	PlAd	et	korgel =korge  (PlAd  >kork !22_S
43506	e-ks	e	e	xx_Q	SgTr	et	e-ks =e  (SgTr  >e !xx_Q
43508	uhtegi	uhte	uhe	06_S	SgG^	et	uhtegi =uhte  (SgG^  >uhe !06_S
43516	ebaoige	oige	eba+oie	06_S	SgG	et	ebaoige =oige  (SgG  >eba+oie !06_S
43529	ood	ood	ood	22_S	SgN	et	ood =ood  (SgN  >ood !22_S
43537	p-ga	p	p	xx_Q	SgKom	et	p-ga =p  (SgKom  >p !xx_Q
43540	eripurad	pura	eri+pura	17_S	PlN	et	eripurad =pura  (PlN  >eri+pura !17_S
43542	reel	ree	regi	21_S	SgAd	et	reel =ree  (SgAd  >regi !21_S
43546	naite	nai	naima	37_V	IndPrPl2	et	naite =nai  (IndPrPl2  >naima !37_V
43551	keeletase	tase	keele+tase	04_S	SgN	et	keeletase =tase  (SgN  >keele+tase !04_S
43312	soodest-metsadest	metsa	soodest-mets	22_S	PlEl	et	soodest-metsadest =metsa  (PlEl  >soodest-mets !22_S
43317	kommunist	kommunist	kommunist	22_S	SgN	et	kommunist =kommunist  (SgN  >kommunist !22_S
43319	isikliku	isikliku	isiklik	25_A	SgG	et	isikliku =isikliku  (SgG  >isiklik !25_A
43335	kate	kate	kate	06_S	SgN	et	kate =kate  (SgN  >kate !06_S
43344	meremehed	mehe	mere+mees	13_S	PlN	et	meremehed =mehe  (PlN  >mere+mees !13_S
43349	valjendada	valjenda	valjendama	27_V	Inf	et	valjendada =valjenda  (Inf  >valjendama !27_V
43351	oige	oige	oie	06_S	SgG	et	oige =oige  (SgG  >oie !06_S
43354	lahkume	lahku	lahkuma	27_V	IndPrPl1	et	lahkume =lahku  (IndPrPl1  >lahkuma !27_V
43355	illustreerimaks	illustreeri	illustreerima	28_V	SupTr	et	illustreerimaks =illustreeri  (SupTr  >illustreerima !28_V
43358	kirjatoodes	toode	kirja+toot	22_S	PlIn	et	kirjatoodes =toode  (PlIn  >kirja+toot !22_S
43363	kinnistuda	kinnistu	kinnistuma	27_V	Inf	et	kinnistuda =kinnistu  (Inf  >kinnistuma !27_V
43368	sobima	sobi	sobima	27_V	Sup	et	sobima =sobi  (Sup  >sobima !27_V
43371	aravahetamine	vahetamine	ara+vahetamine	12_S	SgN	et	aravahetamine =vahetamine  (SgN  >ara+vahetamine !12_S
43374	tappide	tappi	tapp	22_S	PlG	et	tappide =tappi  (PlG  >tapp !22_S
43382	saaremaas	maa	saare+maa	26_S	SgIn	et	saaremaas =maa  (SgIn  >saare+maa !26_S
43385	kinnas	kinnas	kinnas	07_S	SgN	et	kinnas =kinnas  (SgN  >kinnas !07_S
43386	kusimus	imu	kus+imu	17_S	SgIn	et	kusimus =imu  (SgIn  >kus+imu !17_S
43389	viiel	viie	viis	14_N	SgAd	et	viiel =viie  (SgAd  >viis !14_N
43392	keelepraktikat	praktika	keele+praktika	01_S	SgP	et	keelepraktikat =praktika  (SgP  >keele+praktika !01_S
43396	kummitamas	kummita	kummitama	27_V	SupIn	et	kummitamas =kummita  (SupIn  >kummitama !27_V
43399	kirjapanek	panek	kirja+panek	02_S	SgN	et	kirjapanek =panek  (SgN  >kirja+panek !02_S
43401	viletsa	viletsa	vilets	02_A	SgG	et	viletsa =viletsa  (SgG  >vilets !02_A
43404	möödalaskmistes	laskmis	mööda+laskmine	12?10_S	PlIn	et	möödalaskmistes =laskmis  (PlIn  >mööda+laskmine !12?10_S
43407	teemadega	teema	teema	16_S	PlKom	et	teemadega =teema  (PlKom  >teema !16_S
43411	hakkamatulema-	tulema	hakkama+tulem	02_S	SgG	et	hakkamatulema- =tulema  (SgG  >hakkama+tulem !02_S
43416	14-st			xx_Q	SgEl	et	-st =  (SgEl  > !xx_Q
43428	parandan	paranda	parandama	27_V	IndPrSg1	et	parandan =paranda  (IndPrSg1  >parandama !27_V
43431	allakriipsutamisega	kriipsutamise	alla+kriipsutamine	12_S	SgKom	et	allakriipsutamisega =kriipsutamise  (SgKom  >alla+kriipsutamine !12_S
43433	1korraldasin	korralda	korraldama	27_V	IndIpfSg1	et	korraldasin =korralda  (IndIpfSg1  >korraldama !27_V
43440	tõlgetest	tõlge	tõlge	06_S	PlEl	et	tõlgetest =tõlge  (PlEl  >tõlge !06_S
43443	algustähega	tähe	algus+täht	22_S	SgKom	et	algustähega =tähe  (SgKom  >algus+täht !22_S
43448	andekat	andeka	andekas	02_A	SgP	et	andekat =andeka  (SgP  >andekas !02_A
43463	maksuga	maksu	maks	22_S	SgKom	et	maksuga =maksu  (SgKom  >maks !22_S
43464	ametikoht	koht	ameti+koht	22_S	SgN	et	ametikoht =koht  (SgN  >ameti+koht !22_S
43471	autoritekst	tekst	autori+tekst	22_S	SgN	et	autoritekst =tekst  (SgN  >autori+tekst !22_S
43474	ige	ige	ige	04_S	SgN	et	ige =ige  (SgN  >ige !04_S
43475	pudru	pudru	puder	24_S	SgG	et	pudru =pudru  (SgG  >puder !24_S
43486	lahtuda	lahtu	lahtuma	27_V	Inf	et	lahtuda =lahtu  (Inf  >lahtuma !27_V
43491	menuust	us	menu+uks	14_S	SgP	et	menuust =us  (SgP  >menu+uks !14_S
43492	o-ks	o	o	xx_Q	SgTr	et	o-ks =o  (SgTr  >o !xx_Q
43493	t-ga	t	t	xx_Q	SgKom	et	t-ga =t  (SgKom  >t !xx_Q
43496	kolab	kola	kolama	27_V	IndPrSg3	et	kolab =kola  (IndPrSg3  >kolama !27_V
43501	autondust	autondus	autondus	11_S	SgP	et	autondust =autondus  (SgP  >autondus !11_S
43505	eesvokaal	vokaal	ees+vokaal	22_S	SgN	et	eesvokaal =vokaal  (SgN  >ees+vokaal !22_S
43512	jutule	jutu	jutt	22_S	SgAll	et	jutule =jutu  (SgAll  >jutt !22_S
43520	kais	kai	kai	26_S	SgIn	et	kais =kai  (SgIn  >kai !26_S
43522	uhised	uhise	uhisema	27_V	IndPrSg2	et	uhised =uhise  (IndPrSg2  >uhisema !27_V
43525	uheteist	uhete	uhet	02_S	PlEl	et	uheteist =uhete  (PlEl  >uhet !02_S
43535	kaime	kaime	kaim	22_S	PlP	et	kaime =kaime  (PlP  >kaim !22_S
43544	nasi-z-s	nasi-z	nasi-z	xx_Q	SgIn	et	nasi-z-s =nasi-z  (SgIn  >nasi-z !xx_Q
43548	lihavõtted	võtte	liha+võte	06_S	PlN	et	lihavõtted =võtte  (PlN  >liha+võte !06_S
43549	arge	arge	arg	22_A	PlP	et	arge =arge  (PlP  >arg !22_A
43552	9klassis	klassi	klass	22_S	SgIn	et	klassis =klassi  (SgIn  >klass !22_S
43553	tekibki	teki	tekkima	28_V	IndPrSg3^	et	tekibki =teki  (IndPrSg3^  >tekkima !28_V
43557	9klass	klass	klass	22_S	SgN	et	klass =klass  (SgN  >klass !22_S
43559	lemmikloomad	looma	lemmik+loom	22_S	PlN	et	lemmikloomad =looma  (PlN  >lemmik+loom !22_S
43507	jutul	jutu	jutt	22_S	SgAd	et	jutul =jutu  (SgAd  >jutt !22_S
43519	konet	kone	kone	16_S	SgP	et	konet =kone  (SgP  >kone !16_S
43523	konele	kone	kone	16_S	SgAll	et	konele =kone  (SgAll  >kone !16_S
43524	koogis	koogi	kook	22_S	SgIn	et	koogis =koogi  (SgIn  >kook !22_S
43531	uhis	uhi	uhk	22_S	PlIn	et	uhis =uhi  (PlIn  >uhk !22_S
43536	valde	valde	vald	22_S	PlP	et	valde =valde  (PlP  >vald !22_S
43538	puss	puss	puss	22_S	SgN	et	puss =puss  (SgN  >puss !22_S
43539	puuavad	ava	puu+ava	17_S	PlN	et	puuavad =ava  (PlN  >puu+ava !17_S
43555	grammatilise	grammatilise	grammatiline	12_A	SgG	et	grammatilise =grammatilise  (SgG  >grammatiline !12_A
43556	eruditsioon	eruditsioon	eruditsioon	22_S	SgN	et	eruditsioon =eruditsioon  (SgN  >eruditsioon !22_S
43561	ametlike	ametlike	ametlik	25_A	PlG	et	ametlike =ametlike  (PlG  >ametlik !25_A
43565	silbid	silbi	silp	22_S	PlN	et	silbid =silbi  (PlN  >silp !22_S
43577	resultatiivne	resultatiivne	resultatiivne	02_A	SgN	et	resultatiivne =resultatiivne  (SgN  >resultatiivne !02_A
43588	lõunasöögiks	söögi	lõuna+söök	22_S	SgTr	et	lõunasöögiks =söögi  (SgTr  >lõuna+söök !22_S
43589	i-ks	i	i	xx_Q	SgTr	et	i-ks =i  (SgTr  >i !xx_Q
43602	paronüümid	paronüümi	paronüüm	22_S	PlN	et	paronüümid =paronüümi  (PlN  >paronüüm !22_S
43603	kõlalt	kõla	kõla	17_S	SgAbl	et	kõlalt =kõla  (SgAbl  >kõla !17_S
43606	ametlikest	ametlike	ametlik	25_A	PlEl	et	ametlikest =ametlike  (PlEl  >ametlik !25_A
43608	ühendeis	ühende	ühend	02_S	PlIn	et	ühendeis =ühende  (PlIn  >ühend !02_S
43609	numbritega	numbri	number	02_S	PlKom	et	numbritega =numbri  (PlKom  >number !02_S
43617	loengukursusele	kursuse	loengu+kursus	11~09_S	SgAll	et	loengukursusele =kursuse  (SgAll  >loengu+kursus !11~09_S
43630	kooshääldamise	hääldamise	koos+hääldamine	12_S	SgG	et	kooshääldamise =hääldamise  (SgG  >koos+hääldamine !12_S
43632	samasse	sama	sama	17_P	SgIll	et	samasse =sama  (SgIll  >sama !17_P
43638	nukra	nukra	nukker	02_A	SgG	et	nukra =nukra  (SgG  >nukker !02_A
43643	juhindub	juhindu	juhinduma	27_V	IndPrSg3	et	juhindub =juhindu  (IndPrSg3  >juhinduma !27_V
43644	kujult	kuju	kuju	17_S	SgAbl	et	kujult =kuju  (SgAbl  >kuju !17_S
43649	pragmaatilised	pragmaatilise	pragmaatiline	12_A	PlN	et	pragmaatilised =pragmaatilise  (PlN  >pragmaatiline !12_A
43653	kirjutaski	kirjuta	kirjutama	27_V	IndIpfSg3^	et	kirjutaski =kirjuta  (IndIpfSg3^  >kirjutama !27_V
43654	juhindudes	juhindu	juhinduma	27_V	Ger	et	juhindudes =juhindu  (Ger  >juhinduma !27_V
43663	täissihitis	sihitis	täis+sihitis	11_S	SgN	et	täissihitis =sihitis  (SgN  >täis+sihitis !11_S
43664	stiilivea	vea	stiili+viga	18_S	SgG	et	stiilivea =vea  (SgG  >stiili+viga !18_S
43668	liigses	liigse	liigne	02_A	SgIn	et	liigses =liigse  (SgIn  >liigne !02_A
43675	homonüüme	homonüüme	homonüüm	22_S	PlP	et	homonüüme =homonüüme  (PlP  >homonüüm !22_S
43676	väljendeist	väljende	väljend	02_S	PlEl	et	väljendeist =väljende  (PlEl  >väljend !02_S
43677	homonüümid	homonüümi	homonüüm	22_S	PlN	et	homonüümid =homonüümi  (PlN  >homonüüm !22_S
43689	keelelaagris	laagri	keele+laager	02_S	SgIn	et	keelelaagris =laagri  (SgIn  >keele+laager !02_S
43695	lahenebki	lahene	lahenema	27_V	IndPrSg3^	et	lahenebki =lahene  (IndPrSg3^  >lahenema !27_V
43703	sõrmused	sõrmuse	sõrmus	09_S	PlN	et	sõrmused =sõrmuse  (PlN  >sõrmus !09_S
43707	kultuurilis-poliitilised	poliitilise	kultuurilis-poliitiline	12_A	PlN	et	kultuurilis-poliitilised =poliitilise  (PlN  >kultuurilis-poliitiline !12_A
43720	parteikontrollile	kontrolli	part+ei+kontroll	22_S	SgAll	et	parteikontrollile =kontrolli  (SgAll  >part+ei+kontroll !22_S
43722	teles	tele	tele	16_S	SgIn	et	teles =tele  (SgIn  >tele !16_S
43729	pakimajandus	majandus	paki+majandus	11_S	SgN	et	pakimajandus =majandus  (SgN  >paki+majandus !11_S
43740	lähendas	lähenda	lähendama	27_V	IndIpfSg3	et	lähendas =lähenda  (IndIpfSg3  >lähendama !27_V
43759	tsensuurita	tsensuuri	tsensuur	22_S	SgAb	et	tsensuurita =tsensuuri  (SgAb  >tsensuur !22_S
43765	korterijärjekorrad	korra	korteri+järje+kord	22_S	PlN	et	korterijärjekorrad =korra  (PlN  >korteri+järje+kord !22_S
43767	baltiketist	keti	balti+kett	22_S	SgEl	et	baltiketist =keti  (SgEl  >balti+kett !22_S
43770	tingis	tingi	tingima	28_V	IndIpfSg3	et	tingis =tingi  (IndIpfSg3  >tingima !28_V
43771	vabaduspüüet	püüe	vabadus+püüe	06_S	SgP	et	vabaduspüüet =püüe  (SgP  >vabadus+püüe !06_S
43772	peideti	peide	peitma	34_V	IndIpfIps	et	peideti =peide  (IndIpfIps  >peitma !34_V
43778	maakultuur	kultuur	maa+kultuur	22_S	SgN	et	maakultuur =kultuur  (SgN  >maa+kultuur !22_S
43779	hääbus	hääbu	hääbuma	27_V	IndIpfSg3	et	hääbus =hääbu  (IndIpfSg3  >hääbuma !27_V
43780	huvide	huvi	huvi	17_S	PlG	et	huvide =huvi  (PlG  >huvi !17_S
43781	vajadustega	vajadus	vajadus	11_S	PlKom	et	vajadustega =vajadus  (PlKom  >vajadus !11_S
43530	tappidega	tappi	tapp	22_S	PlKom	et	tappidega =tappi  (PlKom  >tapp !22_S
43545	tooriietusel	riietuse	too+riietus	11_S	SgAd	et	tooriietusel =riietuse  (SgAd  >too+riietus !11_S
43547	eriparasustega	us	eri+paras+uks	14_S	PlKom	et	eriparasustega =us  (PlKom  >eri+paras+uks !14_S
43550	tiibades	tiiba	tiib	22_S	PlIn	et	tiibades =tiiba  (PlIn  >tiib !22_S
43558	10klass	klass	klass	22_S	SgN	et	klass =klass  (SgN  >klass !22_S
43560	11klass	klass	klass	22_S	SgN	et	klass =klass  (SgN  >klass !22_S
43563	o-ga	o	o	xx_Q	SgKom	et	o-ga =o  (SgKom  >o !xx_Q
43572	lipul	lipu	lipp	22_S	SgAd	et	lipul =lipu  (SgAd  >lipp !22_S
43573	10klassis	klassi	klass	22_S	SgIn	et	klassis =klassi  (SgIn  >klass !22_S
43574	rotile	roti	rott	22_S	SgAll	et	rotile =roti  (SgAll  >rott !22_S
43582	kohakäänded	käände	koha+kääne	06_S	PlN	et	kohakäänded =käände  (PlN  >koha+kääne !06_S
43587	päriseestlane	eestlane	päris+eestlane	12?10_S	SgN	et	päriseestlane =eestlane  (SgN  >päris+eestlane !12?10_S
43596	grammatilisilt	grammatilisi	grammatiline	12_A	PlAbl	et	grammatilisilt =grammatilisi  (PlAbl  >grammatiline !12_A
43600	koort	koor	koor	13_S	SgP	et	koort =koor  (SgP  >koor !13_S
43601	varastama	varasta	varastama	27_V	Sup	et	varastama =varasta  (Sup  >varastama !27_V
43605	varastab	varasta	varastama	27_V	IndPrSg3	et	varastab =varasta  (IndPrSg3  >varastama !27_V
43607	keskharidusega	hariduse	kesk+haridus	11_S	SgKom	et	keskharidusega =hariduse  (SgKom  >kesk+haridus !11_S
43611	tähega	tähe	täht	22_S	SgKom	et	tähega =tähe  (SgKom  >täht !22_S
43612	13kanded	kande	kanne	06_S	PlN	et	kanded =kande  (PlN  >kanne !06_S
43614	16kokke	kokke	kokk	22_S	PlP	et	kokke =kokke  (PlP  >kokk !22_S
43615	17hakkas	hakka	hakkama	29_V	IndIpfSg3	et	hakkas =hakka  (IndIpfSg3  >hakkama !29_V
43622	õelt	õe	õde	18_S	SgAbl	et	õelt =õe  (SgAbl  >õde !18_S
43625	juhtumite	juhtumi	juhtum	02_S	PlG	et	juhtumite =juhtumi  (PlG  >juhtum !02_S
43628	mällu	mällu	mälu	17_S	SgAdt	et	mällu =mällu  (SgAdt  >mälu !17_S
43633	moodustame	moodusta	moodustama	27_V	IndPrPl1	et	moodustame =moodusta  (IndPrPl1  >moodustama !27_V
43642	semantilised	semantilise	semantiline	12_A	PlN	et	semantilised =semantilise  (PlN  >semantiline !12_A
43648	valele	vale	vale	16_SA	SgAll	et	valele =vale  (SgAll  >vale !16_SA
43657	kindlas	kindla	kindel	02_A	SgIn	et	kindlas =kindla  (SgIn  >kindel !02_A
43658	parandatagi	paranda	parandama	27_V	IndPrIps_^	et	parandatagi =paranda  (IndPrIps_^  >parandama !27_V
43662	emakeelset	keelse	ema+keelne	02_A	SgP	et	emakeelset =keelse  (SgP  >ema+keelne !02_A
43665	argikeelse	keelse	argi+keelne	02_A	SgG	et	argikeelse =keelse  (SgG  >argi+keelne !02_A
43666	samma	samma	samb	22_S	SgG	et	samma =samma  (SgG  >samb !22_S
43670	keelekasutamisega	kasutamise	keele+kasutamine	12_S	SgKom	et	keelekasutamisega =kasutamise  (SgKom  >keele+kasutamine !12_S
43680	lapsused	lapsuse	lapsus	11~09_S	PlN	et	lapsused =lapsuse  (PlN  >lapsus !11~09_S
43682	tähelepanematusega	panematuse	tähele+panematus	11?09_S	SgKom	et	tähelepanematusega =panematuse  (SgKom  >tähele+panematus !11?09_S
43698	sonaj-arg	arg	sonaj-arg	22_A	SgN	et	sonaj-arg =arg  (SgN  >sonaj-arg !22_A
43700	uhte	uhte	uhe	06_S	SgG	et	uhte =uhte  (SgG  >uhe !06_S
43702	usuteaduse	teaduse	usu+teadus	11~09_S	SgG	et	usuteaduse =teaduse  (SgG  >usu+teadus !11~09_S
43705	büroos	büroo	büroo	26_S	SgIn	et	büroos =büroo  (SgIn  >büroo !26_S
43708	kujutas	kujuta	kujutama	27_V	IndIpfSg3	et	kujutas =kujuta  (IndIpfSg3  >kujutama !27_V
43709	isemajandamise	majandamise	ise+majandamine	12_S	SgG	et	isemajandamise =majandamise  (SgG  >ise+majandamine !12_S
43711	riputakse	ripu	rippuma	28_V	IndPrIps	et	riputakse =ripu  (IndPrIps  >rippuma !28_V
43721	nukufilmid	filmi	nuku+film	22_S	PlN	et	nukufilmid =filmi  (PlN  >nuku+film !22_S
43731	kultuuriväljaannete	anne	kultuuri+välja+anne	06_S	PlG	et	kultuuriväljaannete =anne  (PlG  >kultuuri+välja+anne !06_S
43739	hunniku	hunniku	hunnik	02_S	SgG	et	hunniku =hunniku  (SgG  >hunnik !02_S
43743	kajastati	kajasta	kajastama	27_V	IndIpfIps	et	kajastati =kajasta  (IndIpfIps  >kajastama !27_V
43744	südamlik	südamlik	südamlik	25_A	SgN	et	südamlik =südamlik  (SgN  >südamlik !25_A
43757	sõjaõudused	õuduse	sõja+õudus	11~09_S	PlN	et	sõjaõudused =õuduse  (PlN  >sõja+õudus !11~09_S
43758	igasuguse	suguse	iga+sugune	10_A	SgG	et	igasuguse =suguse  (SgG  >iga+sugune !10_A
43774	vanapagan	pagan	vana+pagan	02_S	SgN	et	vanapagan =pagan  (SgN  >vana+pagan !02_S
43775	kuldsed	kuldse	kuldne	02_A	PlN	et	kuldsed =kuldse  (PlN  >kuldne !02_A
43783	multifilm	film	multi+film	22_S	SgN	et	multifilm =film  (SgN  >multi+film !22_S
43788	kollektsionääride	kollektsionääri	kollektsionäär	22_S	PlG	et	kollektsionääride =kollektsionääri  (PlG  >kollektsionäär !22_S
43790	tehastega	tehas	tehas	09_S	PlKom	et	tehastega =tehas  (PlKom  >tehas !09_S
43541	raagivad	iva	raag+iva	17_S	PlN	et	raagivad =iva  (PlN  >raag+iva !17_S
43543	piiksid	piiksi	piiks	22_S	PlN	et	piiksid =piiksi  (PlN  >piiks !22_S
43562	ümberjutustuse	jutustuse	ümber+jutustus	11_S	SgG	et	ümberjutustuse =jutustuse  (SgG  >ümber+jutustus !11_S
43566	päriseestlased	eestlase	päris+eestlane	12?10_S	PlN	et	päriseestlased =eestlase  (PlN  >päris+eestlane !12?10_S
43569	käsitlesime	käsitle	käsitlema	27_V	IndIpfPl1	et	käsitlesime =käsitle  (IndIpfPl1  >käsitlema !27_V
43571	jalgratast7	ratas	jalg+ratas	07_S	SgP	et	jalgratast =ratas  (SgP  >jalg+ratas !07_S
43580	osasihitist	sihitis	osa+sihitis	11_S	SgP	et	osasihitist =sihitis  (SgP  >osa+sihitis !11_S
43595	autojuhilube	lube	auto+juhi+luba	18_S	PlP	et	autojuhilube =lube  (PlP  >auto+juhi+luba !18_S
43599	tähelepanematuse	panematuse	tähele+panematus	11?09_S	SgG	et	tähelepanematuse =panematuse  (SgG  >tähele+panematus !11?09_S
43604	naeruväärne	väärne	naeru+väärne	02_A	SgN	et	naeruväärne =väärne  (SgN  >naeru+väärne !02_A
43629	ortograafiat	ortograafia	ortograafia	01_S	SgP	et	ortograafiat =ortograafia  (SgP  >ortograafia !01_S
43637	nukker	nukker	nukker	02_A	SgN	et	nukker =nukker  (SgN  >nukker !02_A
43639	tulenes	tulene	tulenema	27_V	IndIpfSg3	et	tulenes =tulene  (IndIpfSg3  >tulenema !27_V
43640	seinale	seina	sein	23?22_S	SgAll	et	seinale =seina  (SgAll  >sein !23?22_S
43641	õigete	õige	õige	01_A	PlG	et	õigete =õige  (PlG  >õige !01_A
43652	jätame	jäta	jätma	35_V	IndPrPl1	et	jätame =jäta  (IndPrPl1  >jätma !35_V
43656	leksikaalsel	leksikaalse	leksikaalne	02_A	SgAd	et	leksikaalsel =leksikaalse  (SgAd  >leksikaalne !02_A
43661	lõpetatakse	lõpeta	lõpetama	27_V	IndPrIps	et	lõpetatakse =lõpeta  (IndPrIps  >lõpetama !27_V
43688	mittetundmisest	tundmise	mitte+tundmine	12?10_S	SgEl	et	mittetundmisest =tundmise  (SgEl  >mitte+tundmine !12?10_S
43691	iseloomustades	musta	ise+loo+must	22_AS	PlIn	et	iseloomustades =musta  (PlIn  >ise+loo+must !22_AS
43694	keelekeskkond	keskkond	keele+keskkond	22_S	SgN	et	keelekeskkond =keskkond  (SgN  >keele+keskkond !22_S
43697	kasitse	itse	kas+its	22_S	PlP	et	kasitse =itse  (PlP  >kas+its !22_S
43699	igaljuhul	juhu	igal+juht	22_S	SgAd	et	igaljuhul =juhu  (SgAd  >igal+juht !22_S
43706	kuuekümnendatel	ate	kuue+kümnend+att	22_S	PlAd	et	kuuekümnendatel =ate  (PlAd  >kuue+kümnend+att !22_S
43713	tühistatakse	tühista	tühistama	27_V	IndPrIps	et	tühistatakse =tühista  (IndPrIps  >tühistama !27_V
43714	tunnustatakse	tunnusta	tunnustama	27_V	IndPrIps	et	tunnustatakse =tunnusta  (IndPrIps  >tunnustama !27_V
43724	horoskoop	horoskoop	horoskoop	22_S	SgN	et	horoskoop =horoskoop  (SgN  >horoskoop !22_S
43726	värvikombinatsioonid	kombinatsiooni	värvi+kombinatsioon	22_S	PlN	et	värvikombinatsioonid =kombinatsiooni  (PlN  >värvi+kombinatsioon !22_S
43728	teeninduskultuurile	kultuuri	teenindus+kultuur	22_S	SgAll	et	teeninduskultuurile =kultuuri  (SgAll  >teenindus+kultuur !22_S
43730	hinnas	hinna	hind	22_S	SgIn	et	hinnas =hinna  (SgIn  >hind !22_S
43737	teklid	tekli	tekkel	02_S	PlN	et	teklid =tekli  (PlN  >tekkel !02_S
43751	nukufilm	film	nuku+film	22_S	SgN	et	nukufilm =film  (SgN  >nuku+film !22_S
43753	sulaperioodiks	perioodi	sula+periood	22_S	SgTr	et	sulaperioodiks =perioodi  (SgTr  >sula+periood !22_S
43755	põlu	põlu	põlg	22_S	SgG	et	põlu =põlu  (SgG  >põlg !22_S
43761	valitsemisajal	aja	valitsemis+aeg	22_S	SgAd	et	valitsemisajal =aja  (SgAd  >valitsemis+aeg !22_S
43776	tulekuga	tuleku	tulek	02_S	SgKom	et	tulekuga =tuleku  (SgKom  >tulek !02_S
43792	sisserännanuid	rännanu	sisse+rännanu	01_S	PlP	et	sisserännanuid =rännanu  (PlP  >sisse+rännanu !01_S
43793	progressiks	progressi	progress	22_S	SgTr	et	progressiks =progressi  (SgTr  >progress !22_S
43795	poliitikale	poliitika	poliitika	01_S	SgAll	et	poliitikale =poliitika  (SgAll  >poliitika !01_S
43815	kirjanduseks	kirjanduse	kirjandus	11_S	SgTr	et	kirjanduseks =kirjanduse  (SgTr  >kirjandus !11_S
43817	eitab	eita	eitama	27_V	IndPrSg3	et	eitab =eita  (IndPrSg3  >eitama !27_V
43818	loosungites	loosungi	loosung	02_S	PlIn	et	loosungites =loosungi  (PlIn  >loosung !02_S
43821	teave	teave	teave	06_S	SgN	et	teave =teave  (SgN  >teave !06_S
43831	maailmameistriteks	meistri	maa+ilma+meister	02_S	PlTr	et	maailmameistriteks =meistri  (PlTr  >maa+ilma+meister !02_S
43833	maleturniirid	turniiri	male+turniir	22_S	PlN	et	maleturniirid =turniiri  (PlN  >male+turniir !22_S
43839	nsv-st	nsv	nsv	xx_Q	SgEl	et	nsv-st =nsv  (SgEl  >nsv !xx_Q
43840	haritlast	haritlas	haritlane	12_S	SgP	et	haritlast =haritlas  (SgP  >haritlane !12_S
43842	eksemplaris	eksemplari	eksemplar	19_S	SgIn	et	eksemplaris =eksemplari  (SgIn  >eksemplar !19_S
43843	juhiti	juhi	juhtima	28_V	IndIpfIps	et	juhiti =juhi  (IndIpfIps  >juhtima !28_V
43848	vikerkaar	kaar	viker+kaar	13_S	SgN	et	vikerkaar =kaar  (SgN  >viker+kaar !13_S
43852	rinnet	rinne	rinne	06_S	SgP	et	rinnet =rinne  (SgP  >rinne !06_S
43860	võõrväed	väe	võõr+vägi	21_S	PlN	et	võõrväed =väe  (PlN  >võõr+vägi !21_S
43554	headmuljet	mulje	head+mulje	06_S	SgP	et	headmuljet =mulje  (SgP  >head+mulje !06_S
43567	k-ga	k	k	xx_Q	SgKom	et	k-ga =k  (SgKom  >k !xx_Q
43575	rott	rott	rott	22_S	SgN	et	rott =rott  (SgN  >rott !22_S
43578	tarvitatakse	tarvita	tarvitama	27_V	IndPrIps	et	tarvitatakse =tarvita  (IndPrIps  >tarvitama !27_V
43581	kodustada	kodusta	kodustama	27_V	Inf	et	kodustada =kodusta  (Inf  >kodustama !27_V
43585	sisekohakäänded	käände	sise+koha+kääne	06_S	PlN	et	sisekohakäänded =käände  (PlN  >sise+koha+kääne !06_S
43590	silbis	silbi	silp	22_S	SgIn	et	silbis =silbi  (SgIn  >silp !22_S
43591	sütt	sü	süsi	15_S	SgP	et	sütt =sü  (SgP  >süsi !15_S
43597	olümpiamäng	mäng	olümpia+mäng	22_S	SgN	et	olümpiamäng =mäng  (SgN  >olümpia+mäng !22_S
43598	olümpiamängud	mängu	olümpia+mäng	22_S	PlN	et	olümpiamängud =mängu  (PlN  >olümpia+mäng !22_S
43610	jälegi	jäle	jäle	02_A	SgN^	et	jälegi =jäle  (SgN^  >jäle !02_A
43613	14täitsa	täitsa	täitsa	41_D	ID	et	täitsa =täitsa  (ID  >täitsa !41_D
43621	nimisõnad	sõna	nimi+sõna	17_S	PlN	et	nimisõnad =sõna  (PlN  >nimi+sõna !17_S
43623	keelsega	keelse	keelne	02_A	SgKom	et	keelsega =keelse  (SgKom  >keelne !02_A
43626	sõbralt	sõbra	sõber	24_S	SgAbl	et	sõbralt =sõbra  (SgAbl  >sõber !24_S
43627	õigekirjavigades	viga	õige+kirja+viga	18_S	PlIn	et	õigekirjavigades =viga  (PlIn  >õige+kirja+viga !18_S
43634	erandite	erandi	erand	02_S	PlG	et	erandite =erandi  (PlG  >erand !02_S
43635	kade	kade	kade	02_A	SgN	et	kade =kade  (SgN  >kade !02_A
43636	kadeda	kadeda	kade	02_A	SgG	et	kadeda =kadeda  (SgG  >kade !02_A
43645	paronüümide	paronüümi	paronüüm	22_S	PlG	et	paronüümide =paronüümi  (PlG  >paronüüm !22_S
43647	viibki	vii	viima	38_V	IndPrSg3^	et	viibki =vii  (IndPrSg3^  >viima !38_V
43651	juhindus	juhindu	juhinduma	27_V	IndIpfSg3	et	juhindus =juhindu  (IndIpfSg3  >juhinduma !27_V
43655	klassifikatsioonis	klassifikatsiooni	klassifikatsioon	22_S	SgIn	et	klassifikatsioonis =klassifikatsiooni  (SgIn  >klassifikatsioon !22_S
43659	klapib	klapi	klappima	28_V	IndPrSg3	et	klapib =klapi  (IndPrSg3  >klappima !28_V
43660	kasutusolukorraga	korra	kasutus+olu+kord	22_S	SgKom	et	kasutusolukorraga =korra  (SgKom  >kasutus+olu+kord !22_S
43669	normatiivse	normatiivse	normatiivne	02_A	SgG	et	normatiivse =normatiivse  (SgG  >normatiivne !02_A
43672	ununema	unune	ununema	27_V	Sup	et	ununema =unune  (Sup  >ununema !27_V
43673	tüübi	tüübi	tüüp	22_S	SgG	et	tüübi =tüübi  (SgG  >tüüp !22_S
43683	kuldast	ast	kuld+ast	22_S	SgN	et	kuldast =ast  (SgN  >kuld+ast !22_S
43686	kesised	kesise	kesine	10_A	PlN	et	kesised =kesise  (PlN  >kesine !10_A
43687	mõneti	mõneti	mõneti	41_D	ID	et	mõneti =mõneti  (ID  >mõneti !41_D
43690	abituriendi	abituriendi	abiturient	22_S	SgG	et	abituriendi =abituriendi  (SgG  >abiturient !22_S
43696	oigeid	oige	oie	06_S	PlP	et	oigeid =oige  (PlP  >oie !06_S
43704	kodanikke	kodanikke	kodanik	25_S	PlP	et	kodanikke =kodanikke  (PlP  >kodanik !25_S
43710	iseseisvusdeklaratsioon	deklaratsioon	ise+seisvus+deklaratsioon	22_S	SgN	et	iseseisvusdeklaratsioon =deklaratsioon  (SgN  >ise+seisvus+deklaratsioon !22_S
43716	hingede	hinge	hing	22_S	PlG	et	hingede =hinge  (PlG  >hing !22_S
43718	intelligent	intelligent	intelligent	22_S	SgN	et	intelligent =intelligent  (SgN  >intelligent !22_S
43719	poeemide	poeemi	poeem	22_S	PlG	et	poeemide =poeemi  (PlG  >poeem !22_S
43727	reisilaev	laev	reisi+laev	22_S	SgN	et	reisilaev =laev  (SgN  >reisi+laev !22_S
43732	tõlkekirjanduses	kirjanduse	tõlke+kirjandus	11_S	SgIn	et	tõlkekirjanduses =kirjanduse  (SgIn  >tõlke+kirjandus !11_S
43733	tormis	tormi	torm	22_SA	SgIn	et	tormis =tormi  (SgIn  >torm !22_SA
43736	värvimütsid	mütsi	värvi+müts	22_S	PlN	et	värvimütsid =mütsi  (PlN  >värvi+müts !22_S
43748	iseseisvumiseni	seisvumise	ise+seisvumine	12_S	SgTer	et	iseseisvumiseni =seisvumise  (SgTer  >ise+seisvumine !12_S
43749	hirvepargi	pargi	hirve+park	22_S	SgG	et	hirvepargi =pargi  (SgG  >hirve+park !22_S
43750	miiting	miiting	miiting	02_S	SgN	et	miiting =miiting  (SgN  >miiting !02_S
43754	kultuuriinimesed	inimese	kultuuri+inimene	12_S	PlN	et	kultuuriinimesed =inimese  (PlN  >kultuuri+inimene !12_S
43756	repressioonide	repressiooni	repressioon	22_S	PlG	et	repressioonide =repressiooni  (PlG  >repressioon !22_S
43760	pealesurumine	surumine	peale+surumine	12_S	SgN	et	pealesurumine =surumine  (SgN  >peale+surumine !12_S
43762	koduraamatukogud	kogu	kodu+raamatu+kogu	17_S	PlN	et	koduraamatukogud =kogu  (PlN  >kodu+raamatu+kogu !17_S
43764	kodudesse	kodu	kodu	17_S	PlIll	et	kodudesse =kodu  (PlIll  >kodu !17_S
43773	innustati	innusta	innustama	27_V	IndIpfIps	et	innustati =innusta  (IndIpfIps  >innustama !27_V
43777	sotsialism	sotsialism	sotsialism	22_S	SgN	et	sotsialism =sotsialism  (SgN  >sotsialism !22_S
43785	muusikasaated	saate	muusika+saade	06_S	PlN	et	muusikasaated =saate  (PlN  >muusika+saade !06_S
43564	silp	silp	silp	22_S	SgN	et	silp =silp  (SgN  >silp !22_S
43568	silbiga	silbi	silp	22_S	SgKom	et	silbiga =silbi  (SgKom  >silp !22_S
43570	mustad-valged	valge	mustad-valge	01_AS	PlN	et	mustad-valged =valge  (PlN  >mustad-valge !01_AS
43576	lihatüki	tüki	liha+tükk	22_S	SgG	et	lihatüki =tüki  (SgG  >liha+tükk !22_S
43579	täissihitist	sihitis	täis+sihitis	11_S	SgP	et	täissihitist =sihitis  (SgP  >täis+sihitis !11_S
43583	kohasuhteid	suhte	koha+suhe	06_S	PlP	et	kohasuhteid =suhte  (PlP  >koha+suhe !06_S
43584	tunnuste	tunnus	tunnus	09_S	PlG	et	tunnuste =tunnus  (PlG  >tunnus !09_S
43586	pinnaga	pinna	pind	22_S	SgKom	et	pinnaga =pinna  (SgKom  >pind !22_S
43592	siirdutakse	siirdu	siirduma	27_V	IndPrIps	et	siirdutakse =siirdu  (IndPrIps  >siirduma !27_V
43593	väljendaks	väljenda	väljendama	27_V	KndPrPs	et	väljendaks =väljenda  (KndPrPs  >väljendama !27_V
43594	ilmaütlev	ütlev	ilma+ütlev	02_A	SgN	et	ilmaütlev =ütlev  (SgN  >ilma+ütlev !02_A
43616	musid	musi	musi	17_S	PlN	et	musid =musi  (PlN  >musi !17_S
43618	meisterdas	meisterda	meisterdama	27_V	IndIpfSg3	et	meisterdas =meisterda  (IndIpfSg3  >meisterdama !27_V
43619	trepilt	trepi	trepp	22_S	SgAbl	et	trepilt =trepi  (SgAbl  >trepp !22_S
43620	kategoorias	kategooria	kategooria	01_S	SgIn	et	kategoorias =kategooria  (SgIn  >kategooria !01_S
43624	tulenebki	tulene	tulenema	27_V	IndPrSg3^	et	tulenebki =tulene  (IndPrSg3^  >tulenema !27_V
43631	etteütluse	ütluse	ette+ütlus	11~09_S	SgG	et	etteütluse =ütluse  (SgG  >ette+ütlus !11~09_S
43646	valel	vale	vale	16_SA	SgAd	et	valel =vale  (SgAd  >vale !16_SA
43650	kategooriast	kategooria	kategooria	01_S	SgEl	et	kategooriast =kategooria  (SgEl  >kategooria !01_S
43667	stiilide	stiili	stiil	22_S	PlG	et	stiilide =stiili  (PlG  >stiil !22_S
43671	väljendi	väljendi	väljend	02_S	SgG	et	väljendi =väljendi  (SgG  >väljend !02_S
43674	normaallauses	lause	normaal+lause	06_S	SgIn	et	normaallauses =lause  (SgIn  >normaal+lause !06_S
43678	ajan	aja	ajama	27_V	IndPrSg1	et	ajan =aja  (IndPrSg1  >ajama !27_V
43679	polüseemidel	mi	polü+see+mi	26_S	PlAd	et	polüseemidel =mi  (PlAd  >polü+see+mi !26_S
43681	iseendaga	enda	ise+enda	00_P	SgKom	et	iseendaga =enda  (SgKom  >ise+enda !00_P
43684	põhiuseks	use	põhi+usk	22_S	PlTr	et	põhiuseks =use  (PlTr  >põhi+usk !22_S
43685	gümnaasiumiõpilasel	õpilase	gümnaasiumi+õpilane	12_S	SgAd	et	gümnaasiumiõpilasel =õpilase  (SgAd  >gümnaasiumi+õpilane !12_S
43692	keeletaset	tase	keele+tase	04_S	SgP	et	keeletaset =tase  (SgP  >keele+tase !04_S
43693	vestluse	vestluse	vestlus	11~09_S	SgG	et	vestluse =vestluse  (SgG  >vestlus !11~09_S
43701	valguga	valgu	valk	22_S	SgKom	et	valguga =valgu  (SgKom  >valk !22_S
43712	tornile	torni	torn	22_S	SgAll	et	tornile =torni  (SgAll  >torn !22_S
43715	emigratsioonis	emigratsiooni	emigratsioon	22_S	SgIn	et	emigratsioonis =emigratsiooni  (SgIn  >emigratsioon !22_S
43717	naiskirjanik	kirjanik	nais+kirjanik	25_S	SgN	et	naiskirjanik =kirjanik  (SgN  >nais+kirjanik !25_S
43723	lastesaateid	saate	laste+saade	06_S	PlP	et	lastesaateid =saate  (PlP  >laste+saade !06_S
43725	rukkilill	lill	rukki+lill	22_S	SgN	et	rukkilill =lill  (SgN  >rukki+lill !22_S
43734	teatri-	teatri	teater	02_S	SgG	et	teatri- =teatri  (SgG  >teater !02_S
43735	saavutatagi	saavuta	saavutama	27_V	IndPrIps_^	et	saavutatagi =saavuta  (IndPrIps_^  >saavutama !27_V
43738	pakisüsteem	süsteem	paki+süsteem	22_S	SgN	et	pakisüsteem =süsteem  (SgN  >paki+süsteem !22_S
43741	lätlasi	lätlasi	lätlane	12_S	PlP	et	lätlasi =lätlasi  (PlP  >lätlane !12_S
43742	ärahoidmiseks	hoidmise	ära+hoidmine	12?10_S	SgTr	et	ärahoidmiseks =hoidmise  (SgTr  >ära+hoidmine !12?10_S
43745	kätest	kä	käsi	15_S	PlEl	et	kätest =kä  (PlEl  >käsi !15_S
43746	rahvustunne	tunne	rahvus+tunne	06_S	SgN	et	rahvustunne =tunne  (SgN  >rahvus+tunne !06_S
43747	ketile	keti	kett	22_S	SgAll	et	ketile =keti  (SgAll  >kett !22_S
43752	teisisõnu	teisisõnu	teisi+sõnu	41_D	ID	et	teisisõnu =teisisõnu  (ID  >teisi+sõnu !41_D
43763	koguti	kogu	koguma	27_V	IndIpfIps	et	koguti =kogu  (IndIpfIps  >koguma !27_V
43766	paneelmaju	maju	paneel+maja	17_S	PlP	et	paneelmaju =maju  (PlP  >paneel+maja !17_S
43768	kõikvõimas	võimas	kõik+võimas	03~05_A	SgN	et	kõikvõimas =võimas  (SgN  >kõik+võimas !03~05_A
43769	ühtekuuluvustunne	tunne	ühte+kuuluvus+tunne	06_S	SgN	et	ühtekuuluvustunne =tunne  (SgN  >ühte+kuuluvus+tunne !06_S
43782	regioonideks	regiooni	regioon	22_S	PlTr	et	regioonideks =regiooni  (PlTr  >regioon !22_S
43784	peresaated	saate	pere+saade	06_S	PlN	et	peresaated =saate  (PlN  >pere+saade !06_S
43787	välismaadega	maa	välis+maa	26_S	PlKom	et	välismaadega =maa  (PlKom  >välis+maa !26_S
43794	utopistliku	utopistliku	utopistlik	25_A	SgG	et	utopistliku =utopistliku  (SgG  >utopistlik !25_A
43803	publitsistikas	publitsistika	publitsistika	01_S	SgIn	et	publitsistikas =publitsistika  (SgIn  >publitsistika !01_S
43786	kirjavahetamiseks	vahetamise	kirja+vahetamine	12_S	SgTr	et	kirjavahetamiseks =vahetamise  (SgTr  >kirja+vahetamine !12_S
43797	ajaviiteks	viite	aja+viide	06_S	SgTr	et	ajaviiteks =viite  (SgTr  >aja+viide !06_S
43802	mutt	mutt	mutt	22_S	SgN	et	mutt =mutt  (SgN  >mutt !22_S
43806	stsenaariumid	stsenaariumi	stsenaarium	19~02_S	PlN	et	stsenaariumid =stsenaariumi  (PlN  >stsenaarium !19~02_S
43809	isetrükk	trükk	ise+trükk	22_S	SgN	et	isetrükk =trükk  (SgN  >ise+trükk !22_S
43811	probleemile	probleemi	probleem	22_S	SgAll	et	probleemile =probleemi  (SgAll  >probleem !22_S
43814	maapaikadest	paika	maa+paik	22_S	PlEl	et	maapaikadest =paika  (PlEl  >maa+paik !22_S
43819	some-ugri	ugri	some-ugri	41_G	ID	et	some-ugri =ugri  (ID  >some-ugri !41_G
43826	edasikandjateks	kandja	edasi+kandja	01_S	PlTr	et	edasikandjateks =kandja  (PlTr  >edasi+kandja !01_S
43827	alad	ala	ala	17_S	PlN	et	alad =ala  (PlN  >ala !17_S
43828	keres	kere	kere	16_S	SgIn	et	keres =kere  (SgIn  >kere !16_S
43832	sünnikoht-linn	linn	sünnikoht-linn	22_S	SgN	et	sünnikoht-linn =linn  (SgN  >sünnikoht-linn !22_S
43835	1980-te			xx_Q	PlG	et	-te =  (PlG  > !xx_Q
43836	sfäärides	sfääri	sfäär	22_S	PlIn	et	sfäärides =sfääri  (PlIn  >sfäär !22_S
43838	iseseisvumist	seisvumis	ise+seisvumine	12_S	SgP	et	iseseisvumist =seisvumis  (SgP  >ise+seisvumine !12_S
43844	rahvussuhete	suhe	rahvus+suhe	06_S	PlG	et	rahvussuhete =suhe  (PlG  >rahvus+suhe !06_S
43849	heisatakse	heisa	heiskama	29_V	IndPrIps	et	heisatakse =heisa  (IndPrIps  >heiskama !29_V
43854	nl-st	nl	nl	xx_Q	SgEl	et	nl-st =nl  (SgEl  >nl !xx_Q
43855	piiriprobleem	probleem	piiri+probleem	22_S	SgN	et	piiriprobleem =probleem  (SgN  >piiri+probleem !22_S
43857	majandusreforme	reforme	majandus+reform	22_S	PlP	et	majandusreforme =reforme  (PlP  >majandus+reform !22_S
43861	sahtlikirjandus	kirjandus	sahtli+kirjandus	11_S	SgN	et	sahtlikirjandus =kirjandus  (SgN  >sahtli+kirjandus !11_S
43864	ühtviisi	ühtviisi	üht+viisi	41_D	ID	et	ühtviisi =ühtviisi  (ID  >üht+viisi !41_D
43869	äravahetamist	vahetamis	ära+vahetamine	12_S	SgP	et	äravahetamist =vahetamis  (SgP  >ära+vahetamine !12_S
43870	eessõnad	sõna	ees+sõna	17_S	PlN	et	eessõnad =sõna  (PlN  >ees+sõna !17_S
43871	tähenduslik	tähenduslik	tähenduslik	25_A	SgN	et	tähenduslik =tähenduslik  (SgN  >tähenduslik !25_A
43878	sõnalõpul	lõpu	sõna+lõpp	22_SA	SgAd	et	sõnalõpul =lõpu  (SgAd  >sõna+lõpp !22_SA
43879	pöördega	pöörde	pööre	06_S	SgKom	et	pöördega =pöörde  (SgKom  >pööre !06_S
43890	problemaatilised	problemaatilise	problemaatiline	12_A	PlN	et	problemaatilised =problemaatilise  (PlN  >problemaatiline !12_A
43893	mitmetähenduslike	tähenduslike	mitme+tähenduslik	25_A	PlG	et	mitmetähenduslike =tähenduslike  (PlG  >mitme+tähenduslik !25_A
43901	probleemideta	probleemi	probleem	22_S	PlAb	et	probleemideta =probleemi  (PlAb  >probleem !22_S
43911	bisnesmen	bisnesmen	bisnesmen	19_S	SgN	et	bisnesmen =bisnesmen  (SgN  >bisnesmen !19_S
43912	süntaksivead	vea	süntaksi+viga	18_S	PlN	et	süntaksivead =vea  (PlN  >süntaksi+viga !18_S
43919	kuup	kuup	kuup	22_S	SgN	et	kuup =kuup  (SgN  >kuup !22_S
43937	õigest	õige	õige	01_A	SgEl	et	õigest =õige  (SgEl  >õige !01_A
43940	müügiesindajaks	esindaja	müügi+esindaja	01_S	SgTr	et	müügiesindajaks =esindaja  (SgTr  >müügi+esindaja !01_S
43950	hinnale	hinna	hind	22_S	SgAll	et	hinnale =hinna  (SgAll  >hind !22_S
43976	tasahilju	tasahilju	tasa+hilju	41_D	ID	et	tasahilju =tasahilju  (ID  >tasa+hilju !41_D
43977	puudelehed	lehe	puude+leht	22_S	PlN	et	puudelehed =lehe  (PlN  >puude+leht !22_S
43980	septembrit	septembri	september	02_S	SgP	et	septembrit =septembri  (SgP  >september !02_S
43985	keeleõppijat	õppija	keele+õppija	01_S	SgP	et	keeleõppijat =õppija  (SgP  >keele+õppija !01_S
43986	sekretärid	sekretäri	sekretär	19_S	PlN	et	sekretärid =sekretäri  (PlN  >sekretär !19_S
43987	konsultandid	konsultandi	konsultant	22_S	PlN	et	konsultandid =konsultandi  (PlN  >konsultant !22_S
43988	klienditeenindajad	teenindaja	kliendi+teenindaja	01_S	PlN	et	klienditeenindajad =teenindaja  (PlN  >kliendi+teenindaja !01_S
43995	tumedate	tumeda	tume	02_A	PlG	et	tumedate =tumeda  (PlG  >tume !02_A
44004	veresoonte	soon	vere+soon	13_S	PlG	et	veresoonte =soon  (PlG  >vere+soon !13_S
44005	8oktoober	oktoober	oktoober	02_S	SgN	et	oktoober =oktoober  (SgN  >oktoober !02_S
44009	pluus	pluus	pluus	22_S	SgN	et	pluus =pluus  (SgN  >pluus !22_S
44025	jalgrattamatkale	matka	jalg+ratta+matk	22_S	SgAll	et	jalgrattamatkale =matka  (SgAll  >jalg+ratta+matk !22_S
44037	emadepäeval	päeva	emade+päev	22_S	SgAd	et	emadepäeval =päeva  (SgAd  >emade+päev !22_S
44045	saabusime	saabu	saabuma	27_V	IndIpfPl1	et	saabusime =saabu  (IndIpfPl1  >saabuma !27_V
44050	ökopargis	pargi	öko+park	22_S	SgIn	et	ökopargis =pargi  (SgIn  >öko+park !22_S
44055	kuld-	kuld	kuld	22_S	SgN	et	kuld- =kuld  (SgN  >kuld !22_S
43789	rasketööstuse	tööstuse	raske+tööstus	11~09_S	SgG	et	rasketööstuse =tööstuse  (SgG  >raske+tööstus !11~09_S
43791	individuaalelamud	elamu	individuaal+elamu	01_S	PlN	et	individuaalelamud =elamu  (PlN  >individuaal+elamu !01_S
43796	elamiskoht	koht	elamis+koht	22_S	SgN	et	elamiskoht =koht  (SgN  >elamis+koht !22_S
43799	lemmiktegelaseks	tegelase	lemmik+tegelane	12_S	SgTr	et	lemmiktegelaseks =tegelase  (SgTr  >lemmik+tegelane !12_S
43800	siseeluga	elu	sise+elu	17_S	SgKom	et	siseeluga =elu  (SgKom  >sise+elu !17_S
43801	meeserudiit	erudiit	mees+erudiit	22_S	SgN	et	meeserudiit =erudiit  (SgN  >mees+erudiit !22_S
43820	rahvani	rahva	rahvas	07_S	SgTer	et	rahvani =rahva  (SgTer  >rahvas !07_S
43825	edasikandjaks	kandja	edasi+kandja	01_S	SgTr	et	edasikandjaks =kandja  (SgTr  >edasi+kandja !01_S
43830	tõestas	tõesta	tõestama	27_V	IndIpfSg3	et	tõestas =tõesta  (IndIpfSg3  >tõestama !27_V
43837	baltiriikide	riiki	balti+riik	22_S	PlG	et	baltiriikide =riiki  (PlG  >balti+riik !22_S
43845	valitseti	valitse	valitsema	27_V	IndIpfIps	et	valitseti =valitse  (IndIpfIps  >valitsema !27_V
43846	eestis2	eesti	eesti	16_H	SgIn	et	eestis =eesti  (SgIn  >eesti !16_H
43859	tagastama	tagasta	tagastama	27_V	Sup	et	tagastama =tagasta  (Sup  >tagastama !27_V
43863	lemmiknäitlejaid	näitleja	lemmik+näitleja	01_S	PlP	et	lemmiknäitlejaid =näitleja  (PlP  >lemmik+näitleja !01_S
43866	kõrv	kõrv	kõrv	22_S	SgN	et	kõrv =kõrv  (SgN  >kõrv !22_S
43867	sõnavormid	vormi	sõna+vorm	22_S	PlN	et	sõnavormid =vormi  (PlN  >sõna+vorm !22_S
43868	keeleõpetuse	õpetuse	keele+õpetus	11_S	SgG	et	keeleõpetuse =õpetuse  (SgG  >keele+õpetus !11_S
43883	ärajätmine	jätmine	ära+jätmine	12?10_S	SgN	et	ärajätmine =jätmine  (SgN  >ära+jätmine !12?10_S
43892	homonüümide	homonüümi	homonüüm	22_S	PlG	et	homonüümide =homonüümi  (PlG  >homonüüm !22_S
43896	langet	lange	lange	06_S	SgP	et	langet =lange  (SgP  >lange !06_S
43906	direktorina	direktori	direktor	02_S	SgEs	et	direktorina =direktori  (SgEs  >direktor !02_S
43909	väärtuse	väärtuse	väärtus	11~09_S	SgG	et	väärtuse =väärtuse  (SgG  >väärtus !11~09_S
43910	ärimehena	mehe	äri+mees	13_S	SgEs	et	ärimehena =mehe  (SgEs  >äri+mees !13_S
43913	tähelepanekud	paneku	tähele+panek	02_S	PlN	et	tähelepanekud =paneku  (PlN  >tähele+panek !02_S
43914	mõningates	mõninga	mõningas	02_P	PlIn	et	mõningates =mõninga  (PlIn  >mõningas !02_P
43920	kuupäevaga	päeva	kuu+päev	22_S	SgKom	et	kuupäevaga =päeva  (SgKom  >kuu+päev !22_S
43923	vahetame	vaheta	vahetama	27_V	IndPrPl1	et	vahetame =vaheta  (IndPrPl1  >vahetama !27_V
43926	meietest	test	meie+test	22_S	SgN	et	meietest =test  (SgN  >meie+test !22_S
43927	mänge	mänge	mäng	22_S	PlP	et	mänge =mänge  (PlP  >mäng !22_S
43939	sooviavaldus	avaldus	soovi+avaldus	11_S	SgN	et	sooviavaldus =avaldus  (SgN  >soovi+avaldus !11_S
43941	pearaamatupidajana	pidaja	pea+raamatu+pidaja	01_S	SgEs	et	pearaamatupidajana =pidaja  (SgEs  >pea+raamatu+pidaja !01_S
43944	esinduskaupluses	kaupluse	esindus+kauplus	11~09_S	SgIn	et	esinduskaupluses =kaupluse  (SgIn  >esindus+kauplus !11~09_S
43945	terviseprobleemidest	probleemi	tervise+probleem	22_S	PlEl	et	terviseprobleemidest =probleemi  (PlEl  >tervise+probleem !22_S
43951	spordiklubid	klubi	spordi+klubi	17_S	PlN	et	spordiklubid =klubi  (PlN  >spordi+klubi !17_S
43955	tornil	torni	torn	22_S	SgAd	et	tornil =torni  (SgAd  >torn !22_S
43956	tipust	tipu	tipp	22_S	SgEl	et	tipust =tipu  (SgEl  >tipp !22_S
43957	laternad	laterna	latern	02_S	PlN	et	laternad =laterna  (PlN  >latern !02_S
43959	mälestuskivid	kivi	mälestus+kivi	17_S	PlN	et	mälestuskivid =kivi  (PlN  >mälestus+kivi !17_S
43960	etteütlus	ütlus	ette+ütlus	11~09_S	SgN	et	etteütlus =ütlus  (SgN  >ette+ütlus !11~09_S
43961	septembrialgul	algu	septembri+alg	22_S	SgAd	et	septembrialgul =algu  (SgAd  >septembri+alg !22_S
43963	järkjärgult	järkjärgult	järk+järgult	41_D	ID	et	järkjärgult =järkjärgult  (ID  >järk+järgult !41_D
43966	kastanimunasid	muna	kastani+muna	17_S	PlP	et	kastanimunasid =muna  (PlP  >kastani+muna !17_S
43973	talvaks	talva	talb	22_S	SgTr	et	talvaks =talva  (SgTr  >talb !22_S
43983	ametireisides	reisi	ameti+reis	22_S	PlIn	et	ametireisides =reisi  (PlIn  >ameti+reis !22_S
43989	meiepoolesed	poolese	meie+poolene	10_A	PlN	et	meiepoolesed =poolese  (PlN  >meie+poolene !10_A
43990	algaks	alga	algama	29_V	KndPrPs	et	algaks =alga  (KndPrPs  >algama !29_V
43992	13-ni			xx_Q	SgTer	et	-ni =  (SgTer  > !xx_Q
43996	prillidega	prilli	prill	22_S	PlKom	et	prillidega =prilli  (PlKom  >prill !22_S
43997	daamid	daami	daam	22_S	PlN	et	daamid =daami  (PlN  >daam !22_S
44000	keemikud	keemiku	keemik	02_S	PlN	et	keemikud =keemiku  (PlN  >keemik !02_S
44002	pareneb	parene	parenema	27_V	IndPrSg3	et	pareneb =parene  (IndPrSg3  >parenema !27_V
44008	raamatupidamisprogramm	programm	raamatu+pidamis+programm	22_S	SgN	et	raamatupidamisprogramm =programm  (SgN  >raamatu+pidamis+programm !22_S
43798	filmiloojana	looja	filmi+looja	01_S	SgEs	et	filmiloojana =looja  (SgEs  >filmi+looja !01_S
43813	tekest	teke	tekk	22_S	PlEl	et	tekest =teke  (PlEl  >tekk !22_S
43816	viisistati	viisista	viisistama	27_V	IndIpfIps	et	viisistati =viisista  (IndIpfIps  >viisistama !27_V
43822	üliõpilasseltsid	seltsi	üli+õpilas+selts	22_S	PlN	et	üliõpilasseltsid =seltsi  (PlN  >üli+õpilas+selts !22_S
43834	nsv-s	nsv	nsv	xx_Q	SgIn	et	nsv-s =nsv  (SgIn  >nsv !xx_Q
43847	liidrid	liidri	liider	02_S	PlN	et	liidrid =liidri  (PlN  >liider !02_S
43851	kehtetuks	kehtetu	kehtetu	01_A	SgTr	et	kehtetuks =kehtetu  (SgTr  >kehtetu !01_A
43853	riputatakse	riputa	riputama	27_V	IndPrIps	et	riputatakse =riputa  (IndPrIps  >riputama !27_V
43858	omandireform	reform	omandi+reform	22_S	SgN	et	omandireform =reform  (SgN  >omandi+reform !22_S
43873	kasutamisväljad	välja	kasutamis+väli	24_S	PlN	et	kasutamisväljad =välja  (PlN  >kasutamis+väli !24_S
43874	õppetundides	tundi	õppe+tund	22_S	PlIn	et	õppetundides =tundi  (PlIn  >õppe+tund !22_S
43876	äravahetamine	vahetamine	ära+vahetamine	12_S	SgN	et	äravahetamine =vahetamine  (SgN  >ära+vahetamine !12_S
43884	keeleõpetus	õpetus	keele+õpetus	11_S	SgN	et	keeleõpetus =õpetus  (SgN  >keele+õpetus !11_S
43885	riigieksamite	eksami	riigi+eksam	02_S	PlG	et	riigieksamite =eksami  (PlG  >riigi+eksam !02_S
43886	mu1l	mu	ma	00_P	SgAd	et	mul =mu  (SgAd  >ma !00_P
43887	tõlkevead	vea	tõlke+viga	18_S	PlN	et	tõlkevead =vea  (PlN  >tõlke+viga !18_S
43891	kõlaga	kõla	kõla	17_S	SgKom	et	kõlaga =kõla  (SgKom  >kõla !17_S
43902	sõnatüvi	tüvi	sõna+tüvi	20_S	SgN	et	sõnatüvi =tüvi  (SgN  >sõna+tüvi !20_S
43907	väljendile	väljendi	väljend	02_S	SgAll	et	väljendile =väljendi  (SgAll  >väljend !02_S
43916	võrdlusastmeid	astme	võrdlus+aste	05_S	PlP	et	võrdlusastmeid =astme  (PlP  >võrdlus+aste !05_S
43924	õued	õue	õu	22_S	PlN	et	õued =õue  (PlN  >õu !22_S
43933	radade	rada	rada	18_S	PlG	et	radade =rada  (PlG  >rada !18_S
43935	võõrkeeleõppijaile	õppija	võõr+keele+õppija	01_S	PlAll	et	võõrkeeleõppijaile =õppija  (PlAll  >võõr+keele+õppija !01_S
43936	katsumuseks	katsumuse	katsumus	11_S	SgTr	et	katsumuseks =katsumuse  (SgTr  >katsumus !11_S
43938	direktorile	direktori	direktor	02_S	SgAll	et	direktorile =direktori  (SgAll  >direktor !02_S
43942	enamlevinud	levinu	enam+levinu	01_S	PlN	et	enamlevinud =levinu  (PlN  >enam+levinu !01_S
43943	süsteemides	süsteemi	süsteem	22_S	PlIn	et	süsteemides =süsteemi  (PlIn  >süsteem !22_S
43946	keskne	keskne	keskne	02_A	SgN	et	keskne =keskne  (SgN  >keskne !02_A
43947	aedvilju	vilju	aed+vili	24_S	PlP	et	aedvilju =vilju  (PlP  >aed+vili !24_S
43948	piirama	piira	piirama	29_V	Sup	et	piirama =piira  (Sup  >piirama !29_V
43952	vabast	vaba	vaba	17_A	SgEl	et	vabast =vaba  (SgEl  >vaba !17_A
43965	tuulega	tuule	tuul	13_S	SgKom	et	tuulega =tuule  (SgKom  >tuul !13_S
43967	sarapult	pult	sara+pult	22_S	SgN	et	sarapult =pult  (SgN  >sara+pult !22_S
43971	oravad	orava	orav	02_S	PlN	et	oravad =orava  (PlN  >orav !02_S
43991	reedeni	reede	reede	01_S	SgTer	et	reedeni =reede  (SgTer  >reede !01_S
43993	tasume	tasu	tasuma	27_V	IndPrPl1	et	tasume =tasu  (IndPrPl1  >tasuma !27_V
44006	tütarfirmad	firma	tütar+firma	16_S	PlN	et	tütarfirmad =firma  (PlN  >tütar+firma !16_S
44022	pearaamatupidajad	pidaja	pea+raamatu+pidaja	01_S	PlN	et	pearaamatupidajad =pidaja  (PlN  >pea+raamatu+pidaja !01_S
44024	jalgrattamatk	matk	jalg+ratta+matk	22_S	SgN	et	jalgrattamatk =matk  (SgN  >jalg+ratta+matk !22_S
44028	raamatupidajale	pidaja	raamatu+pidaja	01_S	SgAll	et	raamatupidajale =pidaja  (SgAll  >raamatu+pidaja !01_S
44036	mantlid	mantli	mantel	02_S	PlN	et	mantlid =mantli  (PlN  >mantel !02_S
44044	kajutid	kajuti	kajut	02_S	PlN	et	kajutid =kajuti  (PlN  >kajut !02_S
44049	giid	giid	giid	22_S	SgN	et	giid =giid  (SgN  >giid !22_S
44054	kullatoas	toa	kulla+tuba	18_S	SgIn	et	kullatoas =toa  (SgIn  >kulla+tuba !18_S
44065	tõllad	tõlla	tõld	22_S	PlN	et	tõllad =tõlla  (PlN  >tõld !22_S
44070	kaebame	kaeba	kaebama	29_V	IndPrPl1	et	kaebame =kaeba  (IndPrPl1  >kaebama !29_V
44072	ruumide	ruumi	ruum	22_S	PlG	et	ruumide =ruumi  (PlG  >ruum !22_S
44074	peredel	pere	pere	16_S	PlAd	et	peredel =pere  (PlAd  >pere !16_S
44081	muretsen	muretse	muretsema	27_V	IndPrSg1	et	muretsen =muretse  (IndPrSg1  >muretsema !27_V
44084	heitgaasid	gaasi	heit+gaas	22_S	PlN	et	heitgaasid =gaasi  (PlN  >heit+gaas !22_S
44085	onusid	onu	onu	17_S	PlP	et	onusid =onu  (PlP  >onu !17_S
44086	tädisid	tädi	tädi	17_S	PlP	et	tädisid =tädi  (PlP  >tädi !17_S
44091	tramm	tramm	tramm	22_S	SgN	et	tramm =tramm  (SgN  >tramm !22_S
44092	ronge	ronge	rong	22_S	PlP	et	ronge =ronge  (PlP  >rong !22_S
44095	tiiger	tiiger	tiiger	02_S	SgN	et	tiiger =tiiger  (SgN  >tiiger !02_S
43804	professionaalloomingu	loomingu	professionaal+looming	02_S	SgG	et	professionaalloomingu =loomingu  (SgG  >professionaal+looming !02_S
43805	iseseisvumisest	seisvumise	ise+seisvumine	12_S	SgEl	et	iseseisvumisest =seisvumise  (SgEl  >ise+seisvumine !12_S
43807	läbiviimisega	viimise	läbi+viimine	12?10_S	SgKom	et	läbiviimisega =viimise  (SgKom  >läbi+viimine !12?10_S
43808	tsenseeriti	tsenseeri	tsenseerima	28_V	IndIpfIps	et	tsenseeriti =tsenseeri  (IndIpfIps  >tsenseerima !28_V
43810	ain	ain	ain	22_S	SgN	et	ain =ain  (SgN  >ain !22_S
43812	arvult	arvu	arv	22_S	SgAbl	et	arvult =arvu  (SgAbl  >arv !22_S
43823	vähemkättesaadav	saadav	vähem+kätte+saadav	02_A	SgN	et	vähemkättesaadav =saadav  (SgN  >vähem+kätte+saadav !02_A
43824	välisturistide	turisti	välis+turist	22_S	PlG	et	välisturistide =turisti  (PlG  >välis+turist !22_S
43829	maailmameister	meister	maa+ilma+meister	02_S	SgN	et	maailmameister =meister  (SgN  >maa+ilma+meister !02_S
43841	tuhandeis	tuhande	tuhat	02_N	PlIn	et	tuhandeis =tuhande  (PlIn  >tuhat !02_N
43850	riigilipud	lipu	riigi+lipp	22_S	PlN	et	riigilipud =lipu  (PlN  >riigi+lipp !22_S
43856	vaidlema	vaidle	vaidlema	30_V	Sup	et	vaidlema =vaidle  (Sup  >vaidlema !30_V
43862	võõrnimesid	nime	võõr+nimi	20_S	PlP	et	võõrnimesid =nime  (PlP  >võõr+nimi !20_S
43865	väldet	välde	välde	06_S	SgP	et	väldet =välde  (SgP  >välde !06_S
43872	tegusõnaks	sõna	tegu+sõna	17_S	SgTr	et	tegusõnaks =sõna  (SgTr  >tegu+sõna !17_S
43875	kohakäänetega	kääne	koha+kääne	06_S	PlKom	et	kohakäänetega =kääne  (PlKom  >koha+kääne !06_S
43877	ärkad	ärka	ärkama	29_V	IndPrSg2	et	ärkad =ärka  (IndPrSg2  >ärkama !29_V
43881	j-ühendina	ühendi	j-ühend	02_S	SgEs	et	j-ühendina =ühendi  (SgEs  >j-ühend !02_S
43889	vaatad	vaata	vaatama	29_V	IndPrSg2	et	vaatad =vaata  (IndPrSg2  >vaatama !29_V
43894	minema-	mine	minema	36_V	Sup	et	minema- =mine  (Sup  >minema !36_V
43897	irinale	irina	irin	02_S	SgAll	et	irinale =irina  (SgAll  >irin !02_S
43898	palgale	palga	palk	22_S	SgAll	et	palgale =palga  (SgAll  >palk !22_S
43900	elukutsevalik	valik	elu+kutse+valik	02_S	SgN	et	elukutsevalik =valik  (SgN  >elu+kutse+valik !02_S
43903	kaovad	kao	kaduma	28_V	IndPrPl3	et	kaovad =kao  (IndPrPl3  >kaduma !28_V
43921	ebaõigsus	õigsus	eba+õigsus	11~09_S	SgN	et	ebaõigsus =õigsus  (SgN  >eba+õigsus !11~09_S
43922	mäletame	mäleta	mäletama	27_V	IndPrPl1	et	mäletame =mäleta  (IndPrPl1  >mäletama !27_V
43925	keelelaagri	laagri	keele+laager	02_S	SgG	et	keelelaagri =laagri  (SgG  >keele+laager !02_S
43929	meeldisin	meeldi	meeldima	27_V	IndIpfSg1	et	meeldisin =meeldi  (IndIpfSg1  >meeldima !27_V
43954	poode	poode	pood	22_S	PlP	et	poode =poode  (PlP  >pood !22_S
43958	uljana	ulja	uljas	07_A	SgEs	et	uljana =ulja  (SgEs  >uljas !07_A
43968	aedades	aeda	aed	22_S	PlIn	et	aedades =aeda  (PlIn  >aed !22_S
43972	talvevarusid	varu	talve+varu	17_S	PlP	et	talvevarusid =varu  (PlP  >talve+varu !17_S
43975	nädalaid	nädala	nädal	02_S	PlP	et	nädalaid =nädala  (PlP  >nädal !02_S
43978	tõrusid	tõru	tõru	17_S	PlP	et	tõrusid =tõru  (PlP  >tõru !17_S
43982	ao	ao	agu	18_S	SgG	et	ao =ao  (SgG  >agu !18_S
43984	palgasoov	soov	palga+soov	22_S	SgN	et	palgasoov =soov  (SgN  >palga+soov !22_S
43994	kirjale	kirja	kiri	24_S	SgAll	et	kirjale =kirja  (SgAll  >kiri !24_S
44001	kuumtöötlus	töötlus	kuum+töötlus	11~09_S	SgN	et	kuumtöötlus =töötlus  (SgN  >kuum+töötlus !11~09_S
44003	lükopeenide-pigmentide	pigmenti	lükopeenide-pigment	22_S	PlG	et	lükopeenide-pigmentide =pigmenti  (PlG  >lükopeenide-pigment !22_S
44012	neljajalgsele	jalgse	nelja+jalgne	02_AS	SgAll	et	neljajalgsele =jalgse  (SgAll  >nelja+jalgne !02_AS
44014	taskust	tasku	tasku	01_S	SgEl	et	taskust =tasku  (SgEl  >tasku !01_S
44019	pesin	pes	pesema	36_V	IndIpfSg1	et	pesin =pes  (IndIpfSg1  >pesema !36_V
44027	pidulikul	piduliku	pidulik	25_A	SgAd	et	pidulikul =piduliku  (SgAd  >pidulik !25_A
44029	trepikoja	koja	trepi+koda	18_S	SgG	et	trepikoja =koja  (SgG  >trepi+koda !18_S
44032	pulmapäev	päev	pulma+päev	22_S	SgN	et	pulmapäev =päev  (SgN  >pulma+päev !22_S
44039	moodsaid	moodsa	moodne	02_A	PlP	et	moodsaid =moodsa  (PlP  >moodne !02_A
44042	majandites	majandi	majand	02_S	PlIn	et	majandites =majandi  (PlIn  >majand !02_S
44043	praamis	praami	praam	22_S	SgIn	et	praamis =praami  (SgIn  >praam !22_S
44046	registreerisime	registreeri	registreerima	28_V	IndIpfPl1	et	registreerisime =registreeri  (IndIpfPl1  >registreerima !28_V
44051	linnarahvuspark	park	linna+rahvus+park	22_S	SgN	et	linnarahvuspark =park  (SgN  >linna+rahvus+park !22_S
44053	rahvamuuseum	muuseum	rahva+muuseum	19~02_S	SgN	et	rahvamuuseum =muuseum  (SgN  >rahva+muuseum !19~02_S
44068	riigisaalis	saali	riigi+saal	22_S	SgIn	et	riigisaalis =saali  (SgIn  >riigi+saal !22_S
44073	perekonnaliikmete	liikme	pere+konna+liige	05_S	PlG	et	perekonnaliikmete =liikme  (PlG  >pere+konna+liige !05_S
43880	häälik	häälik	häälik	02_S	SgN	et	häälik =häälik  (SgN  >häälik !02_S
43882	täppide	täppi	täpp	22_S	PlG	et	täppide =täppi  (PlG  >täpp !22_S
43888	rühmitades	rühmita	rühmitama	27_V	Ger	et	rühmitades =rühmita  (Ger  >rühmitama !27_V
43895	palm	palm	palm	22_S	SgN	et	palm =palm  (SgN  >palm !22_S
43899	ühekordne	kordne	ühe+kordne	02_AS	SgN	et	ühekordne =kordne  (SgN  >ühe+kordne !02_AS
43904	ärimeheks	mehe	äri+mees	13_S	SgTr	et	ärimeheks =mehe  (SgTr  >äri+mees !13_S
43905	pangadirektoriks	direktori	panga+direktor	02_S	SgTr	et	pangadirektoriks =direktori  (SgTr  >panga+direktor !02_S
43908	õlgivad	iva	õlg+iva	17_S	PlN	et	õlgivad =iva  (PlN  >õlg+iva !17_S
43915	tähes	tähe	täht	22_S	SgIn	et	tähes =tähe  (SgIn  >täht !22_S
43917	rõdus	rõdu	rõdu	17_S	SgIn	et	rõdus =rõdu  (SgIn  >rõdu !17_S
43918	keelevaist	vaist	keele+vaist	22_S	SgN	et	keelevaist =vaist  (SgN  >keele+vaist !22_S
43928	lemmikaastaajad	aja	lemmik+aasta+aeg	22_S	PlN	et	lemmikaastaajad =aja  (PlN  >lemmik+aasta+aeg !22_S
43930	rahvastepall	pall	rahvaste+pall	22_S	SgN	et	rahvastepall =pall  (SgN  >rahvaste+pall !22_S
43931	rõivatootjate	tootja	rõiva+tootja	01_S	PlG	et	rõivatootjate =tootja  (PlG  >rõiva+tootja !01_S
43932	konstruktsioonivead	vea	konstruktsiooni+viga	18_S	PlN	et	konstruktsioonivead =vea  (PlN  >konstruktsiooni+viga !18_S
43934	lemmikaastaaeg	aeg	lemmik+aasta+aeg	22_S	SgN	et	lemmikaastaaeg =aeg  (SgN  >lemmik+aasta+aeg !22_S
43949	magusa	magusa	magus	02_A	SgG	et	magusa =magusa  (SgG  >magus !02_A
43953	tugitoolis	tooli	tugi+tool	22_S	SgIn	et	tugitoolis =tooli  (SgIn  >tugi+tool !22_S
43962	puud-põõsad	põõsa	puud-põõsas	07_S	PlN	et	puud-põõsad =põõsa  (PlN  >puud-põõsas !07_S
43964	vaher	vaher	vaher	03_S	SgN	et	vaher =vaher  (SgN  >vaher !03_S
43969	öökülm	külm	öö+külm	22_AS	SgN	et	öökülm =külm  (SgN  >öö+külm !22_AS
43970	kured	kure	kurg	22_S	PlN	et	kured =kure  (PlN  >kurg !22_S
43974	vihmasajud	saju	vihma+sadu	18_S	PlN	et	vihmasajud =saju  (PlN  >vihma+sadu !18_S
43979	lompidel	lompi	lomp	22_S	PlAd	et	lompidel =lompi  (PlAd  >lomp !22_S
43981	sarapuult	puu	sara+puu	26_S	SgAbl	et	sarapuult =puu  (SgAbl  >sara+puu !26_S
43998	päikeseprille	prille	päikese+prill	22_S	PlP	et	päikeseprille =prille  (PlP  >päikese+prill !22_S
43999	võõramaalased	maalase	võõra+maalane	12?10_S	PlN	et	võõramaalased =maalase  (PlN  >võõra+maalane !12?10_S
44007	seadusandlusele	andluse	seadus+andlus	11~09_S	SgAll	et	seadusandlusele =andluse  (SgAll  >seadus+andlus !11~09_S
44010	jõukal	jõuka	jõukas	02_A	SgAd	et	jõukal =jõuka  (SgAd  >jõukas !02_A
44011	mõtleme1	mõtle	mõtlema	30_V	IndPrPl1	et	mõtleme =mõtle  (IndPrPl1  >mõtlema !30_V
44018	aeroobikat	aeroobika	aeroobika	01_S	SgP	et	aeroobikat =aeroobika  (SgP  >aeroobika !01_S
44021	arved	arve	arve	06_S	PlN	et	arved =arve  (PlN  >arve !06_S
44023	lukk	lukk	lukk	22_S	SgN	et	lukk =lukk  (SgN  >lukk !22_S
44030	pearaamatupidajale	pidaja	pea+raamatu+pidaja	01_S	SgAll	et	pearaamatupidajale =pidaja  (SgAll  >pea+raamatu+pidaja !01_S
44031	näidake	näida	näitama	29_V	ImpPrPl2	et	näidake =näida  (ImpPrPl2  >näitama !29_V
44040	lüpstakse	lüps	lüpsma	32_V	IndPrIps	et	lüpstakse =lüps  (IndPrIps  >lüpsma !32_V
44041	masinatega	masina	masin	02_S	PlKom	et	masinatega =masina  (PlKom  >masin !02_S
44047	puhkamaks	puhka	puhkama	29_V	SupTr	et	puhkamaks =puhka  (SupTr  >puhkama !29_V
44052	taimestik	taimestik	taimestik	25_S	SgN	et	taimestik =taimestik  (SgN  >taimestik !25_S
44056	hõbeeset	ese	hõbe+ese	04_S	SgP	et	hõbeeset =ese  (SgP  >hõbe+ese !04_S
44058	loomadest	looma	loom	22_S	PlEl	et	loomadest =looma  (PlEl  >loom !22_S
44066	varakambris	kambri	vara+kamber	02_S	SgIn	et	varakambris =kambri  (SgIn  >vara+kamber !02_S
44067	kroone	kroone	kroon	22_S	PlP	et	kroone =kroone  (PlP  >kroon !22_S
44069	pisiasjadest	asja	pisi+asi	24_S	PlEl	et	pisiasjadest =asja  (PlEl  >pisi+asi !24_S
44075	eraldit	eraldi	eraldi	01_S	SgP	et	eraldit =eraldi  (SgP  >eraldi !01_S
44078	pereinimesed	inimese	pere+inimene	12_S	PlN	et	pereinimesed =inimese  (PlN  >pere+inimene !12_S
44082	korterisisustus	sisustus	korteri+sisustus	11_S	SgN	et	korterisisustus =sisustus  (SgN  >korteri+sisustus !11_S
44089	sekundeid	sekunde	sekund	02_S	PlP	et	sekundeid =sekunde  (PlP  >sekund !02_S
44093	lennukeid	lennuke	lennuk	02_S	PlP	et	lennukeid =lennuke  (PlP  >lennuk !02_S
44097	liblikaid	liblika	liblikas	02_S	PlP	et	liblikaid =liblika  (PlP  >liblikas !02_S
44098	taldrikuid	taldriku	taldrik	02_S	PlP	et	taldrikuid =taldriku  (PlP  >taldrik !02_S
44099	makaron	makaron	makaron	19_S	SgN	et	makaron =makaron  (SgN  >makaron !19_S
44100	makarone	makarone	makaron	19_S	PlP	et	makarone =makarone  (PlP  >makaron !19_S
44102	võileibasid	leiba	või+leib	22_S	PlP	et	võileibasid =leiba  (PlP  >või+leib !22_S
44013	leiate	leia	leidma	34_V	IndPrPl2	et	leiate =leia  (IndPrPl2  >leidma !34_V
44015	grupiga	grupi	grupp	22_S	SgKom	et	grupiga =grupi  (SgKom  >grupp !22_S
44016	nukrad	nukra	nukker	02_A	PlN	et	nukrad =nukra  (PlN  >nukker !02_A
44017	aeroobikale	aeroobika	aeroobika	01_S	SgAll	et	aeroobikale =aeroobika  (SgAll  >aeroobika !01_S
44020	12oo	oo	oo	41_I	ID	et	oo =oo  (ID  >oo !41_I
44026	reisiksin	reisi	reisima	28_V	KndPrSg1	et	reisiksin =reisi  (KndPrSg1  >reisima !28_V
44033	astutakse	astu	astuma	28_V	IndPrIps	et	astutakse =astu  (IndPrIps  >astuma !28_V
44034	õnnitletakse	õnnitle	õnnitlema	27_V	IndPrIps	et	õnnitletakse =õnnitle  (IndPrIps  >õnnitlema !27_V
44035	ekskursioonile	ekskursiooni	ekskursioon	22_S	SgAll	et	ekskursioonile =ekskursiooni  (SgAll  >ekskursioon !22_S
44038	emadele	ema	ema	17_S	PlAll	et	emadele =ema  (PlAll  >ema !17_S
44048	hotellibaaris	baari	hotelli+baar	22_S	SgIn	et	hotellibaaris =baari  (SgIn  >hotelli+baar !22_S
44060	kivististest	kivistis	kivistis	11_S	PlEl	et	kivististest =kivistis  (PlEl  >kivistis !11_S
44062	barokkstiilis	stiili	barokk+stiil	22_S	SgIn	et	barokkstiilis =stiili  (SgIn  >barokk+stiil !22_S
44071	elutingimused	tingimuse	elu+tingimus	11_S	PlN	et	elutingimused =tingimuse  (PlN  >elu+tingimus !11_S
44080	elamistingimuste	tingimus	elamis+tingimus	11_S	PlG	et	elamistingimuste =tingimus  (PlG  >elamis+tingimus !11_S
44087	vanur	vanur	vanur	02_S	SgN	et	vanur =vanur  (SgN  >vanur !02_S
44113	laevasid	laeva	laev	22_S	PlP	et	laevasid =laeva  (PlP  >laev !22_S
44134	õhutemperatuuriga	temperatuuri	õhu+temperatuur	22_S	SgKom	et	õhutemperatuuriga =temperatuuri  (SgKom  >õhu+temperatuur !22_S
44139	terminaaliga	terminaali	terminaal	22_S	SgKom	et	terminaaliga =terminaali  (SgKom  >terminaal !22_S
44145	rõõmustad	rõõmusta	rõõmustama	27_V	IndPrSg2	et	rõõmustad =rõõmusta  (IndPrSg2  >rõõmustama !27_V
44151	õmblen	õmble	õmblema	30_V	IndPrSg1	et	õmblen =õmble  (IndPrSg1  >õmblema !30_V
44153	bussile	bussi	buss	22_S	SgAll	et	bussile =bussi  (SgAll  >buss !22_S
44158	ilad	ila	ila	17_S	PlN	et	ilad =ila  (PlN  >ila !17_S
44161	munasid	muna	muna	17_S	PlP	et	munasid =muna  (PlP  >muna !17_S
44169	tekkisin	tekki	tekkima	27~28_V	IndIpfSg1	et	tekkisin =tekki  (IndIpfSg1  >tekkima !27~28_V
44171	sugustel	sugus	sugune	10_A	PlAd	et	sugustel =sugus  (PlAd  >sugune !10_A
44173	teenindan	teeninda	teenindama	27_V	IndPrSg1	et	teenindan =teeninda  (IndPrSg1  >teenindama !27_V
44175	pidule	pidu	pidu	17_S	SgAll	et	pidule =pidu  (SgAll  >pidu !17_S
44178	töögraafiku	graafiku	töö+graafik	02_S	SgG	et	töögraafiku =graafiku  (SgG  >töö+graafik !02_S
44180	kassal	kassa	kassa	16_S	SgAd	et	kassal =kassa  (SgAd  >kassa !16_S
44182	matkasin	matka	matkama	29_V	IndIpfSg1	et	matkasin =matka  (IndIpfSg1  >matkama !29_V
44193	kohkus	kohku	kohkuma	27_V	IndIpfSg3	et	kohkus =kohku  (IndIpfSg3  >kohkuma !27_V
44213	küpsisse	küpsi	küps	02_A	SgIll	et	küpsisse =küpsi  (SgIll  >küps !02_A
44220	kurjuta	kurju	kurjuma	27_V	IndPrIps_	et	kurjuta =kurju  (IndPrIps_  >kurjuma !27_V
44221	lillepoos	poos	lille+poos	22_S	SgN	et	lillepoos =poos  (SgN  >lille+poos !22_S
44226	seniks	seniks	seniks	41_D	ID	et	seniks =seniks  (ID  >seniks !41_D
44229	praktiku	praktiku	praktik	02_S	SgG	et	praktiku =praktiku  (SgG  >praktik !02_S
44232	kaheksani	kaheksa	kaheksa	01_N	SgTer	et	kaheksani =kaheksa  (SgTer  >kaheksa !01_N
44237	joonistab	joonista	joonistama	27_V	IndPrSg3	et	joonistab =joonista  (IndPrSg3  >joonistama !27_V
44240	onedasi-tagasi	tagasi	onedasi-tagasi	41_DK	ID	et	onedasi-tagasi =tagasi  (ID  >onedasi-tagasi !41_DK
44249	ekskursioonil	ekskursiooni	ekskursioon	22_S	SgAd	et	ekskursioonil =ekskursiooni  (SgAd  >ekskursioon !22_S
44253	purunes	purune	purunema	27_V	IndIpfSg3	et	purunes =purune  (IndIpfSg3  >purunema !27_V
44255	maakond	maakond	maakond	22_S	SgN	et	maakond =maakond  (SgN  >maakond !22_S
44273	firmadel	firma	firma	16_S	PlAd	et	firmadel =firma  (PlAd  >firma !16_S
44282	teller	teller	teller	02_S	SgN	et	teller =teller  (SgN  >teller !02_S
44284	kinoteatris	teatri	kino+teater	02_S	SgIn	et	kinoteatris =teatri  (SgIn  >kino+teater !02_S
44288	tingimalt	ima	ting+ima	17_S	SgAbl	et	tingimalt =ima  (SgAbl  >ting+ima !17_S
44295	oodake	ooda	ootama	29_V	ImpPrPl2	et	oodake =ooda  (ImpPrPl2  >ootama !29_V
44303	suudeldes	suudel	suudlema	30_V	Ger	et	suudeldes =suudel  (Ger  >suudlema !30_V
44305	soovitaksite	soovita	soovitama	27_V	KndPrPl2	et	soovitaksite =soovita  (KndPrPl2  >soovitama !27_V
44306	arvutikursid	kursi	arvuti+kurss	22_S	PlN	et	arvutikursid =kursi  (PlN  >arvuti+kurss !22_S
44308	kaubamajja	majja	kauba+maja	17_S	SgAdt	et	kaubamajja =majja  (SgAdt  >kauba+maja !17_S
44309	toidukauplusse	kauplus	toidu+kauplus	11_S	SgAdt	et	toidukauplusse =kauplus  (SgAdt  >toidu+kauplus !11_S
44311	arvutikursuse	kursuse	arvuti+kursus	11~09_S	SgG	et	arvutikursuse =kursuse  (SgG  >arvuti+kursus !11~09_S
44057	loodusmuuseumis	muuseumi	loodus+muuseum	19~02_S	SgIn	et	loodusmuuseumis =muuseumi  (SgIn  >loodus+muuseum !19~02_S
44059	fossiilidest	fossiili	fossiil	22_S	PlEl	et	fossiilidest =fossiili  (PlEl  >fossiil !22_S
44061	mineraalides	mineraali	mineraal	22_S	PlIn	et	mineraalides =mineraali  (PlIn  >mineraal !22_S
44063	kuningalossis	lossi	kuninga+loss	22_S	SgIn	et	kuningalossis =lossi  (SgIn  >kuninga+loss !22_S
44064	relvakamber	kamber	relva+kamber	02_S	SgN	et	relvakamber =kamber  (SgN  >relva+kamber !02_S
44076	autogaasid	gaasi	auto+gaas	22_S	PlN	et	autogaasid =gaasi  (PlN  >auto+gaas !22_S
44077	kurdame	kurda	kurtma	34_V	IndPrPl1	et	kurdame =kurda  (IndPrPl1  >kurtma !34_V
44088	sekund	sekund	sekund	02_S	SgN	et	sekund =sekund  (SgN  >sekund !02_S
44094	taksosid	takso	takso	16_S	PlP	et	taksosid =takso  (PlP  >takso !16_S
44096	tiigreid	tiigre	tiiger	02_S	PlP	et	tiigreid =tiigre  (PlP  >tiiger !02_S
44104	pipraid	pipra	pipar	08_S	PlP	et	pipraid =pipra  (PlP  >pipar !08_S
44107	klaase	klaase	klaas	22_S	PlP	et	klaase =klaase  (PlP  >klaas !22_S
44109	suureid	reid	suu+reid	22_S	SgN	et	suureid =reid  (SgN  >suu+reid !22_S
44111	tigedaid	tigeda	tige	02_A	PlP	et	tigedaid =tigeda  (PlP  >tige !02_A
44114	praamind	ind	praam+ind	22_S	SgN	et	praamind =ind  (SgN  >praam+ind !22_S
44115	linlasi	linlasi	linlane	12_S	PlP	et	linlasi =linlasi  (PlP  >linlane !12_S
44117	murakaid	muraka	murakas	02_S	PlP	et	murakaid =muraka  (PlP  >murakas !02_S
44122	koolilõpetamine	lõpetamine	kooli+lõpetamine	12_S	SgN	et	koolilõpetamine =lõpetamine  (SgN  >kooli+lõpetamine !12_S
44124	põhjendama	põhjenda	põhjendama	27_V	Sup	et	põhjendama =põhjenda  (Sup  >põhjendama !27_V
44128	juristina	juristi	jurist	22_S	SgEs	et	juristina =juristi  (SgEs  >jurist !22_S
44132	albumid	albumi	album	02_S	PlN	et	albumid =albumi  (PlN  >album !02_S
44133	pakkisin	pakki	pakkima	28_V	IndIpfSg1	et	pakkisin =pakki  (IndIpfSg1  >pakkima !28_V
44137	telliskivid	kivi	tellis+kivi	17_S	PlN	et	telliskivid =kivi  (PlN  >tellis+kivi !17_S
44142	toodet	toode	toode	06_S	SgP	et	toodet =toode  (SgP  >toode !06_S
44146	postkontoris	kontori	post+kontor	02_S	SgIn	et	postkontoris =kontori  (SgIn  >post+kontor !02_S
44147	õmblema	õmble	õmblema	30_V	Sup	et	õmblema =õmble  (Sup  >õmblema !30_V
44148	hoov	hoov	hoov	22_S	SgN	et	hoov =hoov  (SgN  >hoov !22_S
44149	muusikuid	muusiku	muusik	02_S	PlP	et	muusikuid =muusiku  (PlP  >muusik !02_S
44154	kanditaatidelt	taati	kandi+taat	22_S	PlAbl	et	kanditaatidelt =taati  (PlAbl  >kandi+taat !22_S
44166	lendasin	lenda	lendama	29_V	IndIpfSg1	et	lendasin =lenda  (IndIpfSg1  >lendama !29_V
44168	täitsin	täit	täitma	34_V	IndIpfSg1	et	täitsin =täit  (IndIpfSg1  >täitma !34_V
44170	tõlkisin	tõlki	tõlkima	28_V	IndIpfSg1	et	tõlkisin =tõlki  (IndIpfSg1  >tõlkima !28_V
44174	suitsule	suitsu	suits	22_S	SgAll	et	suitsule =suitsu  (SgAll  >suits !22_S
44181	keskeriharidus	haridus	kesk+eri+haridus	11_S	SgN	et	keskeriharidus =haridus  (SgN  >kesk+eri+haridus !11_S
44186	järjekindlustus	kindlustus	järje+kindlustus	11_S	SgN	et	järjekindlustus =kindlustus  (SgN  >järje+kindlustus !11_S
44195	saadad	saada	saatma	34_V	IndPrSg2	et	saadad =saada  (IndPrSg2  >saatma !34_V
44199	kaalusin	kaalu	kaaluma	28_V	IndIpfSg1	et	kaalusin =kaalu  (IndIpfSg1  >kaaluma !28_V
44203	kassaga	kassa	kassa	16_S	SgKom	et	kassaga =kassa  (SgKom  >kassa !16_S
44205	maksuordenit	ordeni	maksu+orden	02_S	SgP	et	maksuordenit =ordeni  (SgP  >maksu+orden !02_S
44209	seletan	seleta	seletama	27_V	IndPrSg1	et	seletan =seleta  (IndPrSg1  >seletama !27_V
44215	mängid	mängi	mängima	28_V	IndPrSg2	et	mängid =mängi  (IndPrSg2  >mängima !28_V
44219	elektrikaubad	kauba	elektri+kaup	22_S	PlN	et	elektrikaubad =kauba  (PlN  >elektri+kaup !22_S
44224	millena	mille	mis	00_P	SgEs	et	millena =mille  (SgEs  >mis !00_P
44230	allahindlus	hindlus	alla+hindlus	11~09_S	SgN	et	allahindlus =hindlus  (SgN  >alla+hindlus !11~09_S
44234	õigeta	õige	õige	01_A	SgAb	et	õigeta =õige  (SgAb  >õige !01_A
44235	aastana	aasta	aasta	01_S	SgEs	et	aastana =aasta  (SgEs  >aasta !01_S
44241	poolt-ja	ja	poolt-ja	41_J	ID	et	poolt-ja =ja  (ID  >poolt-ja !41_J
44242	saateit	eit	saat+eit	22_S	SgN	et	saateit =eit  (SgN  >saat+eit !22_S
44244	veedate	veeda	veetma	34_V	IndPrPl2	et	veedate =veeda  (IndPrPl2  >veetma !34_V
44259	kuusissetulek	tulek	kuu+sisse+tulek	02_S	SgN	et	kuusissetulek =tulek  (SgN  >kuu+sisse+tulek !02_S
44260	mänguasi	asi	mängu+asi	24_S	SgN	et	mänguasi =asi  (SgN  >mängu+asi !24_S
44261	suue	suue	suue	05_S	SgN	et	suue =suue  (SgN  >suue !05_S
44262	aasaegne	aegne	aas+aegne	02_A	SgN	et	aasaegne =aegne  (SgN  >aas+aegne !02_A
44264	majades	maja	maja	17_S	PlIn	et	majades =maja  (PlIn  >maja !17_S
44267	kooliõpilane	õpilane	kooli+õpilane	12_S	SgN	et	kooliõpilane =õpilane  (SgN  >kooli+õpilane !12_S
44079	suhetega	suhe	suhe	06_S	PlKom	et	suhetega =suhe  (PlKom  >suhe !06_S
44083	elamispinna	pinna	elamis+pind	22_S	SgG	et	elamispinna =pinna  (SgG  >elamis+pind !22_S
44090	tramme	tramme	tramm	22_S	PlP	et	tramme =tramme  (PlP  >tramm !22_S
44119	tütre	tütre	tütar	08_S	SgG	et	tütre =tütre  (SgG  >tütar !08_S
44123	hoidlik	hoidlik	hoidlik	25_A	SgN	et	hoidlik =hoidlik  (SgN  >hoidlik !25_A
44126	dessantväelasest	väelase	dessant+väelane	12?10_S	SgEl	et	dessantväelasest =väelase  (SgEl  >dessant+väelane !12?10_S
44127	öötundidel	tundi	öö+tund	22_S	PlAd	et	öötundidel =tundi  (PlAd  >öö+tund !22_S
44129	a-kaubad	kauba	a-kaup	22_S	PlN	et	a-kaubad =kauba  (PlN  >a-kaup !22_S
44131	laelambid	lambi	lae+lamp	22_SA	PlN	et	laelambid =lambi  (PlN  >lae+lamp !22_SA
44135	haarasin	haara	haarama	29_V	IndIpfSg1	et	haarasin =haara  (IndIpfSg1  >haarama !29_V
44141	jõhvisse	jõhvi	jõhv	22_S	SgIll	et	jõhvisse =jõhvi  (SgIll  >jõhv !22_S
44152	tassima	tassi	tassima	28_V	Sup	et	tassima =tassi  (Sup  >tassima !28_V
44156	arvutitehnikad	tehnika	arvuti+tehnika	01_S	PlN	et	arvutitehnikad =tehnika  (PlN  >arvuti+tehnika !01_S
44167	võistlesin	võistle	võistlema	30_V	IndIpfSg1	et	võistlesin =võistle  (IndIpfSg1  >võistlema !30_V
44172	soojemad	sooje	soe	24_AS	M_cA	et	"soojem %sooje  )M_cA  <soe ;24_AS
44179	müüjakursuste	kursus	müüja+kursus	11~09_S	PlG	et	müüjakursuste =kursus  (PlG  >müüja+kursus !11~09_S
44185	tööharjumused	harjumuse	töö+harjumus	11_S	PlN	et	tööharjumused =harjumuse  (PlN  >töö+harjumus !11_S
44188	ööl	öö	öö	26_S	SgAd	et	ööl =öö  (SgAd  >öö !26_S
44190	tarke	tarke	tark	22_AS	PlP	et	tarke =tarke  (PlP  >tark !22_AS
44191	hiliste	hilis	hiline	10_A	PlG	et	hiliste =hilis  (PlG  >hiline !10_A
44201	tatar	tatar	tatar	08_S	SgN	et	tatar =tatar  (SgN  >tatar !08_S
44214	koduperenaine	naine	kodu+pere+naine	12_S	SgN	et	koduperenaine =naine  (SgN  >kodu+pere+naine !12_S
44217	müüna	müü	müü	26_S	SgEs	et	müüna =müü  (SgEs  >müü !26_S
44223	ülihuvitav	huvitav	üli+huvitav	02_A	SgN	et	ülihuvitav =huvitav  (SgN  >üli+huvitav !02_A
44243	viisaankeedi	ankeedi	viisa+ankeet	22_S	SgG	et	viisaankeedi =ankeedi  (SgG  >viisa+ankeet !22_S
44251	küljeaken	aken	külje+aken	08_S	SgN	et	küljeaken =aken  (SgN  >külje+aken !08_S
44263	käiame	käia	käiama	29_V	IndPrPl1	et	käiame =käia  (IndPrPl1  >käiama !29_V
44265	võõrkelle	kelle	võõr+kell	22_S	PlP	et	võõrkelle =kelle  (PlP  >võõr+kell !22_S
44270	tuulevikust	viku	tuule+vikk	22_S	SgEl	et	tuulevikust =viku  (SgEl  >tuule+vikk !22_S
44277	hindast	ast	hind+ast	22_S	SgN	et	hindast =ast  (SgN  >hind+ast !22_S
44285	draamateatrisse	teatri	draama+teater	02_S	SgIll	et	draamateatrisse =teatri  (SgIll  >draama+teater !02_S
44286	ülehomme	ülehomme	üle+homme	41_D	ID	et	ülehomme =ülehomme  (ID  >üle+homme !41_D
44292	juuniks	juuni	juuni	16_S	SgTr	et	juuniks =juuni  (SgTr  >juuni !16_S
44296	tervitab	tervita	tervitama	27_V	IndPrSg3	et	tervitab =tervita  (IndPrSg3  >tervitama !27_V
44300	autojaam	jaam	auto+jaam	22_S	SgN	et	autojaam =jaam  (SgN  >auto+jaam !22_S
44315	pöördun	pöördu	pöörduma	27_V	IndPrSg1	et	pöördun =pöördu  (IndPrSg1  >pöörduma !27_V
44324	puurvili	vili	puur+vili	24_S	SgN	et	puurvili =vili  (SgN  >puur+vili !24_S
44326	pihustama	pihusta	pihustama	27_V	Sup	et	pihustama =pihusta  (Sup  >pihustama !27_V
44327	lakkama	lakka	lakkama	29_V	Sup	et	lakkama =lakka  (Sup  >lakkama !29_V
44328	kuluma	kulu	kuluma	27_V	Sup	et	kuluma =kulu  (Sup  >kuluma !27_V
44332	vahenditeta	vahendi	vahend	02_S	PlAb	et	vahenditeta =vahendi  (PlAb  >vahend !02_S
44335	kaanega	kaane	kaas	14_S	SgKom	et	kaanega =kaane  (SgKom  >kaas !14_S
44347	ümbertöötamise	töötamise	ümber+töötamine	12_S	SgG	et	ümbertöötamise =töötamise  (SgG  >ümber+töötamine !12_S
44349	säästate	säästa	säästma	34_V	IndPrPl2	et	säästate =säästa  (IndPrPl2  >säästma !34_V
44350	kliente	kliente	klient	22_S	PlP	et	kliente =kliente  (PlP  >klient !22_S
44354	põdema	põde	põdema	28_V	Sup	et	põdema =põde  (Sup  >põdema !28_V
44359	ümbertegemine	tegemine	ümber+tegemine	12_S	SgN	et	ümbertegemine =tegemine  (SgN  >ümber+tegemine !12_S
44363	hoiate	hoia	hoidma	34_V	IndPrPl2	et	hoiate =hoia  (IndPrPl2  >hoidma !34_V
44384	üldjoontes	joon	üld+joon	13_S	PlIn	et	üldjoontes =joon  (PlIn  >üld+joon !13_S
44385	kummarduma	kummardu	kummarduma	27_V	Sup	et	kummarduma =kummardu  (Sup  >kummarduma !27_V
44395	tööandjate	andja	töö+andja	01_S	PlG	et	tööandjate =andja  (PlG  >töö+andja !01_S
44399	täisajaga	aja	täis+aeg	22_S	SgKom	et	täisajaga =aja  (SgKom  >täis+aeg !22_S
44401	tööotsijat	otsija	töö+otsija	01_S	SgP	et	tööotsijat =otsija  (SgP  >töö+otsija !01_S
44414	seitsepäevik	päevik	seitse+päevik	02_S	SgN	et	seitsepäevik =päevik  (SgN  >seitse+päevik !02_S
44101	võileib	leib	või+leib	22_S	SgN	et	võileib =leib  (SgN  >või+leib !22_S
44103	pipar	pipar	pipar	08_S	SgN	et	pipar =pipar  (SgN  >pipar !08_S
44105	konserv	konserv	konserv	22_S	SgN	et	konserv =konserv  (SgN  >konserv !22_S
44110	liiliaid	liilia	liilia	01_S	PlP	et	liiliaid =liilia  (PlP  >liilia !01_S
44112	vanamehi	mehi	vana+mees	13_S	PlP	et	vanamehi =mehi  (PlP  >vana+mees !13_S
44118	kahekorruses	korruse	kahe+korrus	09_S	SgIn	et	kahekorruses =korruse  (SgIn  >kahe+korrus !09_S
44121	koolitusreisil	reisi	koolitus+reis	22_S	SgAd	et	koolitusreisil =reisi  (SgAd  >koolitus+reis !22_S
44136	tsement	tsement	tsement	22_S	SgN	et	tsement =tsement  (SgN  >tsement !22_S
44138	boss	boss	boss	22_S	SgN	et	boss =boss  (SgN  >boss !22_S
44140	arvutasin	arvuta	arvutama	27_V	IndIpfSg1	et	arvutasin =arvuta  (IndIpfSg1  >arvutama !27_V
44144	ostus	ostu	ost	22_S	SgIn	et	ostus =ostu  (SgIn  >ost !22_S
44159	tammetõrusid	tõru	tamme+tõru	17_S	PlP	et	tammetõrusid =tõru  (PlP  >tamme+tõru !17_S
44163	kastanipuult	puu	kastani+puu	26_S	SgAbl	et	kastanipuult =puu  (SgAbl  >kastani+puu !26_S
44164	tõlkima	tõlki	tõlkima	28_V	Sup	et	tõlkima =tõlki  (Sup  >tõlkima !28_V
44165	näitasin	näita	näitama	29_V	IndIpfSg1	et	näitasin =näita  (IndIpfSg1  >näitama !29_V
44176	narkotikud	tiku	narko+tikk	22_S	PlN	et	narkotikud =tiku  (PlN  >narko+tikk !22_S
44187	unistas	unista	unistama	27_V	IndIpfSg3	et	unistas =unista  (IndIpfSg3  >unistama !27_V
44189	kodanik	kodanik	kodanik	25_S	SgN	et	kodanik =kodanik  (SgN  >kodanik !25_S
44192	1kas	kas	kas	41_D	ID	et	kas =kas  (ID  >kas !41_D
44196	tööharjumus	harjumus	töö+harjumus	11_S	SgN	et	tööharjumus =harjumus  (SgN  >töö+harjumus !11_S
44200	küpsised	küpsise	küpsis	09_S	PlN	et	küpsised =küpsise  (PlN  >küpsis !09_S
44216	osakondid	kondi	osa+kont	22_S	PlN	et	osakondid =kondi  (PlN  >osa+kont !22_S
44218	makaronid	makaroni	makaron	19_S	PlN	et	makaronid =makaroni  (PlN  >makaron !19_S
44225	vastukiri	kiri	vastu+kiri	24_S	SgN	et	vastukiri =kiri  (SgN  >vastu+kiri !24_S
44227	autobussile	bussi	auto+buss	22_S	SgAll	et	autobussile =bussi  (SgAll  >auto+buss !22_S
44239	harvasti	harvasti	harvasti	41_D	ID	et	harvasti =harvasti  (ID  >harvasti !41_D
44245	spordilaagris	laagri	spordi+laager	02_S	SgIn	et	spordilaagris =laagri  (SgIn  >spordi+laager !02_S
44246	õhud	õhu	õhk	22_S	PlN	et	õhud =õhu  (PlN  >õhk !22_S
44248	pühapäevati	ati	püha+päev+att	22_S	SgG	et	pühapäevati =ati  (SgG  >püha+päev+att !22_S
44254	küsitletakse	küsitle	küsitlema	27_V	IndPrIps	et	küsitletakse =küsitle  (IndPrIps  >küsitlema !27_V
44256	kulutate	kuluta	kulutama	27_V	IndPrPl2	et	kulutate =kuluta  (IndPrPl2  >kulutama !27_V
44257	söögile	söögi	söök	22_S	SgAll	et	söögile =söögi  (SgAll  >söök !22_S
44266	võõrkeeltele	keel	võõr+keel	13_S	PlAll	et	võõrkeeltele =keel  (PlAll  >võõr+keel !13_S
44269	laboriraamatuid	raamatu	labori+raamat	02_S	PlP	et	laboriraamatuid =raamatu  (PlP  >labori+raamat !02_S
44271	õppige	õppi	õppima	28_V	ImpPrPl2	et	õppige =õppi  (ImpPrPl2  >õppima !28_V
44276	riidehoidjad	hoidja	riide+hoidja	01_S	PlN	et	riidehoidjad =hoidja  (PlN  >riide+hoidja !01_S
44289	kaubamajasse	maja	kauba+maja	17_S	SgIll	et	kaubamajasse =maja  (SgIll  >kauba+maja !17_S
44302	tervitama	tervita	tervitama	27_V	Sup	et	tervitama =tervita  (Sup  >tervitama !27_V
44314	toidukaupluse	kaupluse	toidu+kauplus	11~09_S	SgG	et	toidukaupluse =kaupluse  (SgG  >toidu+kauplus !11~09_S
44319	arvutikasutamise	kasutamise	arvuti+kasutamine	12_S	SgG	et	arvutikasutamise =kasutamise  (SgG  >arvuti+kasutamine !12_S
44320	loodad	looda	lootma	34_V	IndPrSg2	et	loodad =looda  (IndPrSg2  >lootma !34_V
44321	pühapäevadel	päeva	püha+päev	22_S	PlAd	et	pühapäevadel =päeva  (PlAd  >püha+päev !22_S
44329	külmama	külma	külmama	29_V	Sup	et	külmama =külma  (Sup  >külmama !29_V
44331	üteldi	ütel	ütlema	30_V	IndIpfIps	et	üteldi =ütel  (IndIpfIps  >ütlema !30_V
44339	kisuvad	kisu	kiskuma	28_V	IndPrPl3	et	kisuvad =kisu  (IndPrPl3  >kiskuma !28_V
44340	lühendate	lühenda	lühendama	27_V	IndPrPl2	et	lühendate =lühenda  (IndPrPl2  >lühendama !27_V
44341	piinliku	piinliku	piinlik	25_A	SgG	et	piinliku =piinliku  (SgG  >piinlik !25_A
44342	kassis	kassi	kass	22_S	SgIn	et	kassis =kassi  (SgIn  >kass !22_S
44345	haarama	haara	haarama	29_V	Sup	et	haarama =haara  (Sup  >haarama !29_V
44348	tellides	telli	tellima	28_V	Ger	et	tellides =telli  (Ger  >tellima !28_V
44362	kataloogist	kataloogi	kataloog	22_S	SgEl	et	kataloogist =kataloogi  (SgEl  >kataloog !22_S
44364	ümbertöötlemise	töötlemise	ümber+töötlemine	12_S	SgG	et	ümbertöötlemise =töötlemise  (SgG  >ümber+töötlemine !12_S
44366	kergest	kerge	kerge	01_A	SgEl	et	kergest =kerge  (SgEl  >kerge !01_A
44367	printsiipe	printsiipe	printsiip	22_S	PlP	et	printsiipe =printsiipe  (PlP  >printsiip !22_S
44106	konserve	konserve	konserv	22_S	PlP	et	konserve =konserve  (PlP  >konserv !22_S
44108	jõuluvanu	vanu	jõulu+vana	17_AS	PlP	et	jõuluvanu =vanu  (PlP  >jõulu+vana !17_AS
44116	mustikaid	mustika	mustikas	02_S	PlP	et	mustikaid =mustika  (PlP  >mustikas !02_S
44120	kutsume	kutsu	kutsuma	28_V	IndPrPl1	et	kutsume =kutsu  (IndPrPl1  >kutsuma !28_V
44125	sõbrustame	sõbrusta	sõbrustama	27_V	IndPrPl1	et	sõbrustame =sõbrusta  (IndPrPl1  >sõbrustama !27_V
44130	kööginõud	nõu	köögi+nõu	26_S	PlN	et	kööginõud =nõu  (PlN  >köögi+nõu !26_S
44143	võrdlema	võrdle	võrdlema	30_V	Sup	et	võrdlema =võrdle  (Sup  >võrdlema !30_V
44150	lõbused	lõbuse	lõbus	02_A	PlN	et	lõbused =lõbuse  (PlN  >lõbus !02_A
44155	arvutikasutusoskus	oskus	arvuti+kasutus+oskus	11~09_S	SgN	et	arvutikasutusoskus =oskus  (SgN  >arvuti+kasutus+oskus !11~09_S
44157	erialalt	ala	eri+ala	17_S	SgAbl	et	erialalt =ala  (SgAbl  >eri+ala !17_S
44160	kastani	kastani	kastan	02_S	SgG	et	kastani =kastani  (SgG  >kastan !02_S
44162	sajud	saju	sadu	18_S	PlN	et	sajud =saju  (PlN  >sadu !18_S
44177	päeviti	päeviti	päeviti	41_D	ID	et	päeviti =päeviti  (ID  >päeviti !41_D
44183	tööpäeval	päeva	töö+päev	22_S	SgAd	et	tööpäeval =päeva  (SgAd  >töö+päev !22_S
44184	juurist	juuri	juur	13_S	PlEl	et	juurist =juuri  (PlEl  >juur !13_S
44194	soovlik	soovlik	soovlik	25_A	SgN	et	soovlik =soovlik  (SgN  >soovlik !25_A
44197	12-s			xx_Q	SgIn	et	-s =  (SgIn  > !xx_Q
44198	öö-tundidel	tundi	öö-tund	22_S	PlAd	et	öö-tundidel =tundi  (PlAd  >öö-tund !22_S
44202	piimakombitist	biti	piima+kom+bitt	22_S	SgEl	et	piimakombitist =biti  (SgEl  >piima+kom+bitt !22_S
44204	täitasin	täita	täitama	27_V	IndIpfSg1	et	täitasin =täita  (IndIpfSg1  >täitama !27_V
44206	oktoobrile	oktoobri	oktoober	02_S	SgAll	et	oktoobrile =oktoobri  (SgAll  >oktoober !02_S
44207	müüsin	müü	müüma	38_V	IndIpfSg1	et	müüsin =müü  (IndIpfSg1  >müüma !38_V
44208	poel	poe	pood	22_S	SgAd	et	poel =poe  (SgAd  >pood !22_S
44210	soovitab	soovita	soovitama	27_V	IndPrSg3	et	soovitab =soovita  (IndPrSg3  >soovitama !27_V
44211	kompleksoskustega	oskus	kompleks+oskus	11~09_S	PlKom	et	kompleksoskustega =oskus  (PlKom  >kompleks+oskus !11~09_S
44212	turuplats	plats	turu+plats	22_S	SgN	et	turuplats =plats  (SgN  >turu+plats !22_S
44222	lillekimp	kimp	lille+kimp	22_S	SgN	et	lillekimp =kimp  (SgN  >lille+kimp !22_S
44228	kiirja	kiirja	kiirjas	02_A	SgG	et	kiirja =kiirja  (SgG  >kiirjas !02_A
44231	saapad	saapa	saabas	07_S	PlN	et	saapad =saapa  (PlN  >saabas !07_S
44233	parandas	paranda	parandama	27_V	IndIpfSg3	et	parandas =paranda  (IndIpfSg3  >parandama !27_V
44236	48aastat	aasta	aasta	01_S	SgP	et	aastat =aasta  (SgP  >aasta !01_S
44238	sõnastikule	sõnastiku	sõnastik	25_S	SgAll	et	sõnastikule =sõnastiku  (SgAll  >sõnastik !25_S
44247	söögid	söögi	söök	22_S	PlN	et	söögid =söögi  (PlN  >söök !22_S
44250	nädalalõpul	lõpu	nädala+lõpp	22_SA	SgAd	et	nädalalõpul =lõpu  (SgAd  >nädala+lõpp !22_SA
44252	bussil	bussi	buss	22_S	SgAd	et	bussil =bussi  (SgAd  >buss !22_S
44258	einestate	einesta	einestama	27_V	IndPrPl2	et	einestate =einesta  (IndPrPl2  >einestama !27_V
44278	0-ga			xx_Q	SgKom	et	-ga =  (SgKom  > !xx_Q
44279	kask	kask	kask	22_S	SgN	et	kask =kask  (SgN  >kask !22_S
44283	lauluväljakuse	kuse	laulu+välja+kusi	20_S	SgG	et	lauluväljakuse =kuse  (SgG  >laulu+välja+kusi !20_S
44287	2kaks	kaks	kaks	22_N	SgN	et	kaks =kaks  (SgN  >kaks !22_N
44290	päevaks	päeva	päev	22_S	SgTr	et	päevaks =päeva  (SgTr  >päev !22_S
44294	viibisin	viibi	viibima	27_V	IndIpfSg1	et	viibisin =viibi  (IndIpfSg1  >viibima !27_V
44298	rae	rae	raad	22_S	SgG	et	rae =rae  (SgG  >raad !22_S
44313	töötada5	tööta	töötama	27_V	Inf	et	töötada =tööta  (Inf  >töötama !27_V
44318	paikuse	kuse	pai+kusi	20_S	SgG	et	paikuse =kuse  (SgG  >pai+kusi !20_S
44325	jäätmed	jäätme	jääde	05_S	PlN	et	jäätmed =jäätme  (PlN  >jääde !05_S
44333	kosmeetikavahendeid	vahende	kosmeetika+vahend	02_S	PlP	et	kosmeetikavahendeid =vahende  (PlP  >kosmeetika+vahend !02_S
44336	omapead	omapead	oma+pead	41_D	ID	et	omapead =omapead  (ID  >oma+pead !41_D
44353	põhimõtetesse	mõte	põhi+mõte	06_S	PlIll	et	põhimõtetesse =mõte  (PlIll  >põhi+mõte !06_S
44356	vabaturu	turu	vaba+turg	22_S	SgG	et	vabaturu =turu  (SgG  >vaba+turg !22_S
44357	kosmeetikavahendid	vahendi	kosmeetika+vahend	02_S	PlN	et	kosmeetikavahendid =vahendi  (PlN  >kosmeetika+vahend !02_S
44361	arestima	aresti	arestima	28_V	Sup	et	arestima =aresti  (Sup  >arestima !28_V
44375	parenema	parene	parenema	27_V	Sup	et	parenema =parene  (Sup  >parenema !27_V
44376	kreemile	kreemi	kreem	22_SA	SgAll	et	kreemile =kreemi  (SgAll  >kreem !22_SA
44377	hirmuseid	hirmuse	hirmus	02_A	PlP	et	hirmuseid =hirmuse  (PlP  >hirmus !02_A
44268	võõrkeet	keet	võõr+keet	22_S	SgN	et	võõrkeet =keet  (SgN  >võõr+keet !22_S
44272	võõrkelt	kelt	võõr+kelt	22_S	SgN	et	võõrkelt =kelt  (SgN  >võõr+kelt !22_S
44274	mehaanilisel	mehaanilise	mehaaniline	12_A	SgAd	et	mehaanilisel =mehaanilise  (SgAd  >mehaaniline !12_A
44275	valvurid	valvuri	valvur	02_S	PlN	et	valvurid =valvuri  (PlN  >valvur !02_S
44280	tellerina	telleri	teller	02_S	SgEs	et	tellerina =telleri  (SgEs  >teller !02_S
44281	turvamehena	mehe	turva+mees	13_S	SgEs	et	turvamehena =mehe  (SgEs  >turva+mees !13_S
44291	botaanikaaed	aed	botaanika+aed	22_S	SgN	et	botaanikaaed =aed  (SgN  >botaanika+aed !22_S
44293	sõidis	sõidi	sõit	22_S	SgIn	et	sõidis =sõidi  (SgIn  >sõit !22_S
44297	raeplatsele	platse	rae+plats	22_S	PlAll	et	raeplatsele =platse  (PlAll  >rae+plats !22_S
44299	majakaubad	kauba	maja+kaup	22_S	PlN	et	majakaubad =kauba  (PlN  >maja+kaup !22_S
44301	lapsud	lapsu	laps	22_S	PlN	et	lapsud =lapsu  (PlN  >laps !22_S
44304	otsite	otsi	otsima	28_V	IndPrPl2	et	otsite =otsi  (IndPrPl2  >otsima !28_V
44307	päras	pära	pära	17_S	SgIn	et	päras =pära  (SgIn  >pära !17_S
44310	võtsite	võt	võtma	35_V	IndIpfPl2	et	võtsite =võt  (IndIpfPl2  >võtma !35_V
44312	kauplusejuht	juht	kaupluse+juht	22_S	SgN	et	kauplusejuht =juht  (SgN  >kaupluse+juht !22_S
44317	kordnikuna	kordniku	kordnik	25_S	SgEs	et	kordnikuna =kordniku  (SgEs  >kordnik !25_S
44323	puhkad	puhka	puhkama	29_V	IndPrSg2	et	puhkad =puhka  (IndPrSg2  >puhkama !29_V
44330	suletama	sule	sulgema	28_V	SupIps	et	suletama =sule  (SupIps  >sulgema !28_V
44338	õmblused	õmbluse	õmblus	11~09_S	PlN	et	õmblused =õmbluse  (PlN  >õmblus !11~09_S
44343	haigestuma	haigestu	haigestuma	27_V	Sup	et	haigestuma =haigestu  (Sup  >haigestuma !27_V
44351	sekkub	sekku	sekkuma	27_V	IndPrSg3	et	sekkub =sekku  (IndPrSg3  >sekkuma !27_V
44355	ümbertootmise	tootmise	ümber+tootmine	12?10_S	SgG	et	ümbertootmise =tootmise  (SgG  >ümber+tootmine !12?10_S
44368	reputatsioon	reputatsioon	reputatsioon	22_S	SgN	et	reputatsioon =reputatsioon  (SgN  >reputatsioon !22_S
44373	jubedat	jubeda	jube	02_A	SgP	et	jubedat =jubeda  (SgP  >jube !02_A
44374	haigestama	haigesta	haigestama	27_V	Sup	et	haigestama =haigesta  (Sup  >haigestama !27_V
44378	printsiipide	printsiipi	printsiip	22_S	PlG	et	printsiipide =printsiipi  (PlG  >printsiip !22_S
44383	otstarve	tarve	ots+tarve	06_S	SgN	et	otstarve =tarve  (SgN  >ots+tarve !06_S
44387	teesklema	teeskle	teesklema	30_V	Sup	et	teesklema =teeskle  (Sup  >teesklema !30_V
44396	konts	konts	konts	22_S	SgN	et	konts =konts  (SgN  >konts !22_S
44398	muutke	muut	muutma	34_V	ImpPrPl2	et	muutke =muut  (ImpPrPl2  >muutma !34_V
44404	nõusolekul	oleku	nõus+olek	02_S	SgAd	et	nõusolekul =oleku  (SgAd  >nõus+olek !02_S
44407	pigistama	pigista	pigistama	27_V	Sup	et	pigistama =pigista  (Sup  >pigistama !27_V
44408	lühendid	lühendi	lühend	02_S	PlN	et	lühendid =lühendi  (PlN  >lühend !02_S
44427	rõhutas	rõhuta	rõhutama	27_V	IndIpfSg3	et	rõhutas =rõhuta  (IndIpfSg3  >rõhutama !27_V
44429	uurest	uure	uur	22_S	PlEl	et	uurest =uure  (PlEl  >uur !22_S
44430	panne	panne	pann	22_S	PlP	et	panne =panne  (PlP  >pann !22_S
44439	pigistas	pigista	pigistama	27_V	IndIpfSg3	et	pigistas =pigista  (IndIpfSg3  >pigistama !27_V
44440	üürnik	üürnik	üürnik	25_S	SgN	et	üürnik =üürnik  (SgN  >üürnik !25_S
44443	rumalal	rumala	rumal	02_A	SgAd	et	rumalal =rumala  (SgAd  >rumal !02_A
44444	mängudel	mängu	mäng	22_S	PlAd	et	mängudel =mängu  (PlAd  >mäng !22_S
44453	küsimustiku	küsimustiku	küsimustik	25_S	SgG	et	küsimustiku =küsimustiku  (SgG  >küsimustik !25_S
44455	tüütab	tüüta	tüütama	29_V	IndPrSg3	et	tüütab =tüüta  (IndPrSg3  >tüütama !29_V
44461	totra	totra	totter	02_A	SgG	et	totra =totra  (SgG  >totter !02_A
44463	esineks	esine	esinema	27_V	KndPrPs	et	esineks =esine  (KndPrPs  >esinema !27_V
44477	toidujäätmed	jäätme	toidu+jääde	05_S	PlN	et	toidujäätmed =jäätme  (PlN  >toidu+jääde !05_S
44480	näokreem	kreem	näo+kreem	22_SA	SgN	et	näokreem =kreem  (SgN  >näo+kreem !22_SA
44483	kreemide	kreemi	kreem	22_SA	PlG	et	kreemide =kreemi  (PlG  >kreem !22_SA
44486	pesumasinas	masina	pesu+masin	02_S	SgIn	et	pesumasinas =masina  (SgIn  >pesu+masin !02_S
44491	vabaturukaubanduse	kaubanduse	vaba+turu+kaubandus	11_S	SgG	et	vabaturukaubanduse =kaubanduse  (SgG  >vaba+turu+kaubandus !11_S
44498	sisekohakäänetesse	kääne	sise+koha+kääne	06_S	PlIll	et	sisekohakäänetesse =kääne  (PlIll  >sise+koha+kääne !06_S
44504	baltisakslased	sakslase	balti+sakslane	12?10_S	PlN	et	baltisakslased =sakslase  (PlN  >balti+sakslane !12?10_S
44505	baltisakslasest	sakslase	balti+sakslane	12?10_S	SgEl	et	baltisakslasest =sakslase  (SgEl  >balti+sakslane !12?10_S
44510	viimasest	viimase	viimane	10_A	SgEl	et	viimasest =viimase  (SgEl  >viimane !10_A
44316	politseiprefektuuris	prefektuuri	politsei+prefektuur	22_S	SgIn	et	politseiprefektuuris =prefektuuri  (SgIn  >politsei+prefektuur !22_S
44322	toidukauplusele	kaupluse	toidu+kauplus	11~09_S	SgAll	et	toidukauplusele =kaupluse  (SgAll  >toidu+kauplus !11~09_S
44334	niisutab	niisuta	niisutama	27_V	IndPrSg3	et	niisutab =niisuta  (IndPrSg3  >niisutama !27_V
44337	pintsaku	pintsaku	pintsak	02_S	SgG	et	pintsaku =pintsaku  (SgG  >pintsak !02_S
44344	hülgama	hülga	hülgama	29_V	Sup	et	hülgama =hülga  (Sup  >hülgama !29_V
44346	vahenditega	vahendi	vahend	02_S	PlKom	et	vahenditega =vahendi  (PlKom  >vahend !02_S
44352	vabakaubanduse	kaubanduse	vaba+kaubandus	11_S	SgG	et	vabakaubanduse =kaubanduse  (SgG  >vaba+kaubandus !11_S
44358	pestava	pes	pesema	36_V	TAV_vAS	et	"pestav %pes  )TAV_vAS  <pesema ;36_V
44360	peibutab	peibuta	peibutama	27_V	IndPrSg3	et	peibutab =peibuta  (IndPrSg3  >peibutama !27_V
44365	kaubanduse	kaubanduse	kaubandus	11_S	SgG	et	kaubanduse =kaubanduse  (SgG  >kaubandus !11_S
44370	kaan	kaan	kaan	22_S	SgN	et	kaan =kaan  (SgN  >kaan !22_S
44381	tunnustama	tunnusta	tunnustama	27_V	Sup	et	tunnustama =tunnusta  (Sup  >tunnustama !27_V
44388	asjatundlik	tundlik	asja+tundlik	25_A	SgN	et	asjatundlik =tundlik  (SgN  >asja+tundlik !25_A
44392	sooduspakkumistega	pakkumis	soodus+pakkumine	12_S	PlKom	et	sooduspakkumistega =pakkumis  (PlKom  >soodus+pakkumine !12_S
44400	ehitustöid	tö	ehitus+töö	26_S	PlP	et	ehitustöid =tö  (PlP  >ehitus+töö !26_S
44403	sõlmib	sõlmi	sõlmima	28_V	IndPrSg3	et	sõlmib =sõlmi  (IndPrSg3  >sõlmima !28_V
44405	sõlmitakse	sõlmi	sõlmima	28_V	IndPrIps	et	sõlmitakse =sõlmi  (IndPrIps  >sõlmima !28_V
44413	leppima	leppi	leppima	28_V	Sup	et	leppima =leppi  (Sup  >leppima !28_V
44421	küsige	küsi	küsima	27_V	ImpPrPl2	et	küsige =küsi  (ImpPrPl2  >küsima !27_V
44423	sarnaneda	sarnane	sarnanema	27_V	Inf	et	sarnaneda =sarnane  (Inf  >sarnanema !27_V
44431	unistades	unista	unistama	27_V	Ger	et	unistades =unista  (Ger  >unistama !27_V
44432	tahelepanelik	nelik	tahe+lepa+nelik	02_S	SgN	et	tahelepanelik =nelik  (SgN  >tahe+lepa+nelik !02_S
44433	kokkutulek	tulek	kokku+tulek	02_S	SgN	et	kokkutulek =tulek  (SgN  >kokku+tulek !02_S
44435	juhuse	juhuse	juhus	09_S	SgG	et	juhuse =juhuse  (SgG  >juhus !09_S
44437	lubata	luba	lubama	27_V	IndPrIps_	et	lubata =luba  (IndPrIps_  >lubama !27_V
44442	püüdke	püüd	püüdma	34_V	ImpPrPl2	et	püüdke =püüd  (ImpPrPl2  >püüdma !34_V
44448	kujundlik	kujundlik	kujundlik	25_A	SgN	et	kujundlik =kujundlik  (SgN  >kujundlik !25_A
44454	lobiseb	lobise	lobisema	27_V	IndPrSg3	et	lobiseb =lobise  (IndPrSg3  >lobisema !27_V
44465	ruumalad	ala	ruum+ala	17_S	PlN	et	ruumalad =ala  (PlN  >ruum+ala !17_S
44466	mainid	maini	mainima	28_V	IndPrSg2	et	mainid =maini  (IndPrSg2  >mainima !28_V
44469	sisekorraeeskirjad	kirja	sise+korra+ees+kiri	24_S	PlN	et	sisekorraeeskirjad =kirja  (PlN  >sise+korra+ees+kiri !24_S
44473	mesikäpp	käpp	mesi+käpp	22_S	SgN	et	mesikäpp =käpp  (SgN  >mesi+käpp !22_S
44481	tav-kesksõnaga	sõna	tav-kesk+sõna	17_S	SgKom	et	tav-kesksõnaga =sõna  (SgKom  >tav-kesk+sõna !17_S
44490	kästi	käs	käskima	28_V	IndIpfIps	et	kästi =käs  (IndIpfIps  >käskima !28_V
44502	oktoobrisse	oktoobri	oktoober	02_S	SgIll	et	oktoobrisse =oktoobri  (SgIll  >oktoober !02_S
44503	vastutan	vastuta	vastutama	27_V	IndPrSg1	et	vastutan =vastuta  (IndPrSg1  >vastutama !27_V
44514	hõreda	hõreda	hõre	02_A	SgG	et	hõreda =hõreda  (SgG  >hõre !02_A
44521	sooritas	soorita	sooritama	27_V	IndIpfSg3	et	sooritas =soorita  (IndIpfSg3  >sooritama !27_V
44526	kolmeni	kolme	kolm	22_N	SgTer	et	kolmeni =kolme  (SgTer  >kolm !22_N
44527	kaasaütlevasse	ütleva	kaasa+ütlev	02_A	SgIll	et	kaasaütlevasse =ütleva  (SgIll  >kaasa+ütlev !02_A
44540	sabata	saba	saba	17_S	SgAb	et	sabata =saba  (SgAb  >saba !17_S
44542	vähendades	vähenda	vähendama	27_V	Ger	et	vähendades =vähenda  (Ger  >vähendama !27_V
44544	veata	vea	viga	18_S	SgAb	et	veata =vea  (SgAb  >viga !18_S
44550	nõuannes	anne	nõu+and	22_S	PlIn	et	nõuannes =anne  (PlIn  >nõu+and !22_S
44551	ajasse	aja	aeg	22_S	SgIll	et	ajasse =aja  (SgIll  >aeg !22_S
44557	möödud	möödu	mööduma	27_V	IndPrSg2	et	möödud =möödu  (IndPrSg2  >mööduma !27_V
44558	igasuguste	sugus	iga+sugune	10_A	PlG	et	igasuguste =sugus  (PlG  >iga+sugune !10_A
44567	6kask	kask	kask	22_S	SgN	et	kask =kask  (SgN  >kask !22_S
44590	unne	unne	uni	20_S	SgAdt	et	unne =unne  (SgAdt  >uni !20_S
44609	olukorrale	korra	olu+kord	22_S	SgAll	et	olukorrale =korra  (SgAll  >olu+kord !22_S
44613	partnerlusele	partnerluse	partnerlus	11_S	SgAll	et	partnerlusele =partnerluse  (SgAll  >partnerlus !11_S
44623	ahe	ahe	ahe	06_S	SgN	et	ahe =ahe  (SgN  >ahe !06_S
44628	ollakse	oll	olema	36_V	IndPrIps	et	ollakse =oll  (IndPrIps  >olema !36_V
44631	ameerikaliku	ameerikaliku	ameerikalik	25_A	SgG	et	ameerikaliku =ameerikaliku  (SgG  >ameerikalik !25_A
44369	juhendit	juhendi	juhend	02_S	SgP	et	juhendit =juhendi  (SgP  >juhend !02_S
44371	tellite	telli	tellima	28_V	IndPrPl2	et	tellite =telli  (IndPrPl2  >tellima !28_V
44372	kataloog	kataloog	kataloog	22_S	SgN	et	kataloog =kataloog  (SgN  >kataloog !22_S
44380	kukla	kukla	kukal	08_S	SgG	et	kukla =kukla  (SgG  >kukal !08_S
44382	kõikuma	kõiku	kõikuma	28_V	Sup	et	kõikuma =kõiku  (Sup  >kõikuma !28_V
44389	kirjutaks	kirjuta	kirjutama	27_V	KndPrPs	et	kirjutaks =kirjuta  (KndPrPs  >kirjutama !27_V
44393	hooldame	hoolda	hooldama	27_V	IndPrPl1	et	hooldame =hoolda  (IndPrPl1  >hooldama !27_V
44394	mainis	maini	mainima	28_V	IndIpfSg3	et	mainis =maini  (IndIpfSg3  >mainima !28_V
44397	murdus	murdu	murduma	27_V	IndIpfSg3	et	murdus =murdu  (IndIpfSg3  >murduma !27_V
44409	nii-nii	nii	nii-nii	41_D	ID	et	nii-nii =nii  (ID  >nii-nii !41_D
44410	des-lauselühendiga	lühendi	des-lause+lühend	02_S	SgKom	et	des-lauselühendiga =lühendi  (SgKom  >des-lause+lühend !02_S
44412	aednik	aednik	aednik	25_S	SgN	et	aednik =aednik  (SgN  >aednik !25_S
44417	säilitage	säilita	säilitama	27_V	ImpPrPl2	et	säilitage =säilita  (ImpPrPl2  >säilitama !27_V
44420	pahandama	pahanda	pahandama	27_V	Sup	et	pahandama =pahanda  (Sup  >pahandama !27_V
44426	hulguvad	hulgu	hulkuma	28_V	IndPrPl3	et	hulguvad =hulgu  (IndPrPl3  >hulkuma !28_V
44428	ametniku	ametniku	ametnik	25_S	SgG	et	ametniku =ametniku  (SgG  >ametnik !25_S
44438	tüütas	tüüta	tüütama	29_V	IndIpfSg3	et	tüütas =tüüta  (IndIpfSg3  >tüütama !29_V
44441	hakake	haka	hakkama	29_V	ImpPrPl2	et	hakake =haka  (ImpPrPl2  >hakkama !29_V
44447	ametnikuga	ametniku	ametnik	25_S	SgKom	et	ametnikuga =ametniku  (SgKom  >ametnik !25_S
44450	bussist	bussi	buss	22_S	SgEl	et	bussist =bussi  (SgEl  >buss !22_S
44470	kogeb	koge	kogema	27_V	IndPrSg3	et	kogeb =koge  (IndPrSg3  >kogema !27_V
44475	purunema	purune	purunema	27_V	Sup	et	purunema =purune  (Sup  >purunema !27_V
44476	rikki	rikki	rikki	41_D	ID	et	rikki =rikki  (ID  >rikki !41_D
44478	määrima	määri	määrima	28_V	Sup	et	määrima =määri  (Sup  >määrima !28_V
44493	viitamiine	amiine	viit+amiin	22_S	PlP	et	viitamiine =amiine  (PlP  >viit+amiin !22_S
44497	ületöötamise	töötamise	üle+töötamine	12_S	SgG	et	ületöötamise =töötamise  (SgG  >üle+töötamine !12_S
44500	vabaneda	vabane	vabanema	27_V	Inf	et	vabaneda =vabane  (Inf  >vabanema !27_V
44501	lükkub	lükku	lükkuma	27_V	IndPrSg3	et	lükkub =lükku  (IndPrSg3  >lükkuma !27_V
44506	ilmaütlevasse	ütleva	ilma+ütlev	02_A	SgIll	et	ilmaütlevasse =ütleva  (SgIll  >ilma+ütlev !02_A
44508	uskuge	usku	uskuma	28_V	ImpPrPl2	et	uskuge =usku  (ImpPrPl2  >uskuma !28_V
44509	viisat	viisa	viisa	16_S	SgP	et	viisat =viisa  (SgP  >viisa !16_S
44511	oravat	orava	orav	02_S	SgP	et	oravat =orava  (SgP  >orav !02_S
44512	kolmandiku	kolmandiku	kolmandik	25_N	SgG	et	kolmandiku =kolmandiku  (SgG  >kolmandik !25_N
44529	kohvrid	kohvri	kohver	02_S	PlN	et	kohvrid =kohvri  (PlN  >kohver !02_S
44534	kodutarve	tarve	kodu+tarve	06_S	SgN	et	kodutarve =tarve  (SgN  >kodu+tarve !06_S
44535	võidad	võida	võitma	34_V	IndPrSg2	et	võidad =võida  (IndPrSg2  >võitma !34_V
44546	noaga	noa	nuga	18_S	SgKom	et	noaga =noa  (SgKom  >nuga !18_S
44548	mantliga	mantli	mantel	02_S	SgKom	et	mantliga =mantli  (SgKom  >mantel !02_S
44549	vajasime	vaja	vajama	27_V	IndIpfPl1	et	vajasime =vaja  (IndIpfPl1  >vajama !27_V
44555	tähtajana	aja	täht+aeg	22_S	SgEs	et	tähtajana =aja  (SgEs  >täht+aeg !22_S
44568	1venelased	venelase	venelane	12_S	PlN	et	venelased =venelase  (PlN  >venelane !12_S
44574	7soome	soome	soome	41_G	ID	et	soome =soome  (ID  >soome !41_G
44595	peamise	peamise	peamine	12?10_A	SgG	et	peamise =peamise  (SgG  >peamine !12?10_A
44596	katsumus	katsumus	katsumus	11_S	SgN	et	katsumus =katsumus  (SgN  >katsumus !11_S
44598	omistada	omista	omistama	27_V	Inf	et	omistada =omista  (Inf  >omistama !27_V
44599	kavala	kavala	kaval	02_A	SgG	et	kavala =kavala  (SgG  >kaval !02_A
44604	enamlasi	enamlasi	enamlane	12_S	PlP	et	enamlasi =enamlasi  (PlP  >enamlane !12_S
44608	isikuna	isiku	isik	02_S	SgEs	et	isikuna =isiku  (SgEs  >isik !02_S
44615	parlament	parlament	parlament	22_S	SgN	et	parlament =parlament  (SgN  >parlament !22_S
44625	atele	ate	att	22_S	PlAll	et	atele =ate  (PlAll  >att !22_S
44630	muigama	muiga	muigama	29_V	Sup	et	muigama =muiga  (Sup  >muigama !29_V
44641	lati	lati	latt	22_S	SgG	et	lati =lati  (SgG  >latt !22_S
44643	keskülast	ülas	kesk+ülane	10_S	SgP	et	keskülast =ülas  (SgP  >kesk+ülane !10_S
44651	nõustada	nõusta	nõustama	27_V	Inf	et	nõustada =nõusta  (Inf  >nõustama !27_V
44652	liidri	liidri	liider	02_S	SgG	et	liidri =liidri  (SgG  >liider !02_S
44655	temana	tema	tema	00_P	SgEs	et	temana =tema  (SgEs  >tema !00_P
44379	äärega	ääre	äär	13_S	SgKom	et	äärega =ääre  (SgKom  >äär !13_S
44386	ämmaemand	emand	ämma+emand	02_S	SgN	et	ämmaemand =emand  (SgN  >ämma+emand !02_S
44390	voldik	voldik	voldik	02_S	SgN	et	voldik =voldik  (SgN  >voldik !02_S
44391	teadlik	teadlik	teadlik	25_A	SgN	et	teadlik =teadlik  (SgN  >teadlik !25_A
44402	saadatakse	takse	saada+taks	22_S	PlP	et	saadatakse =takse  (PlP  >saada+taks !22_S
44406	esinetakse	esine	esinema	27_V	IndPrIps	et	esinetakse =esine  (IndPrIps  >esinema !27_V
44411	unistate	unista	unistama	27_V	IndPrPl2	et	unistate =unista  (IndPrPl2  >unistama !27_V
44425	hoolime	hooli	hoolima	28_V	IndPrPl1	et	hoolime =hooli  (IndPrPl1  >hoolima !28_V
44451	kuueliigne	liigne	kuue+liigne	02_A	SgN	et	kuueliigne =liigne  (SgN  >kuue+liigne !02_A
44456	närvitseb	närvitse	närvitsema	27_V	IndPrSg3	et	närvitseb =närvitse  (IndPrSg3  >närvitsema !27_V
44457	pigistab	pigista	pigistama	27_V	IndPrSg3	et	pigistab =pigista  (IndPrSg3  >pigistama !27_V
44459	enesemõistetav	mõistetav	enese+mõistetav	02_A	SgN	et	enesemõistetav =mõistetav  (SgN  >enese+mõistetav !02_A
44462	kokkuvõtteid	võtte	kokku+võte	06_S	PlP	et	kokkuvõtteid =võtte  (PlP  >kokku+võte !06_S
44464	komplimendid	komplimendi	kompliment	22_S	PlN	et	komplimendid =komplimendi  (PlN  >kompliment !22_S
44467	küsitage	küsita	küsitama	27_V	ImpPrPl2	et	küsitage =küsita  (ImpPrPl2  >küsitama !27_V
44471	ebaõnnestumisi	õnnestumisi	eba+õnnestumine	12_S	PlP	et	ebaõnnestumisi =õnnestumisi  (PlP  >eba+õnnestumine !12_S
44484	vitamiine	vitamiine	vitamiin	22_S	PlP	et	vitamiine =vitamiine  (PlP  >vitamiin !22_S
44487	keemiavahenditel	vahendi	keemia+vahend	02_S	PlAd	et	keemiavahenditel =vahendi  (PlAd  >keemia+vahend !02_S
44489	sidesõnad	sõna	side+sõna	17_S	PlN	et	sidesõnad =sõna  (PlN  >side+sõna !17_S
44495	veetleb	veetle	veetlema	30_V	IndPrSg3	et	veetleb =veetle  (IndPrSg3  >veetlema !30_V
44496	keemiavahendite	vahendi	keemia+vahend	02_S	PlG	et	keemiavahendite =vahendi  (PlG  >keemia+vahend !02_S
44499	1homme	homme	homme	41_D	ID	et	homme =homme  (ID  >homme !41_D
44520	näidise	näidise	näidis	09_S	SgG	et	näidise =näidise  (SgG  >näidis !09_S
44524	mägedest	mäge	mägi	21_S	PlEl	et	mägedest =mäge  (PlEl  >mägi !21_S
44536	liht-	liht	liht	22_S	SgN	et	liht- =liht  (SgN  >liht !22_S
44537	majandusjuhatajaks	juhataja	majandus+juhataja	01_S	SgTr	et	majandusjuhatajaks =juhataja  (SgTr  >majandus+juhataja !01_S
44538	majandusjuhatajana	juhataja	majandus+juhataja	01_S	SgEs	et	majandusjuhatajana =juhataja  (SgEs  >majandus+juhataja !01_S
44543	riiest	riie	riid	22_S	PlEl	et	riiest =riie  (PlEl  >riid !22_S
44564	4suured	suure	suur	13_A	PlN	et	suured =suure  (PlN  >suur !13_A
44566	oktoobrilt	oktoobri	oktoober	02_S	SgAbl	et	oktoobrilt =oktoobri  (SgAbl  >oktoober !02_S
44578	8inimeste	inimes	inimene	12_S	PlG	et	inimeste =inimes  (PlG  >inimene !12_S
44585	suurtega	suur	suur	13_A	PlKom	et	suurtega =suur  (PlKom  >suur !13_A
44587	detailne	detailne	detailne	02_A	SgN	et	detailne =detailne  (SgN  >detailne !02_A
44588	enesehinnangu	hinnangu	enese+hinnang	02_S	SgG	et	enesehinnangu =hinnangu  (SgG  >enese+hinnang !02_S
44594	rivaalitseda	rivaalitse	rivaalitsema	27_V	Inf	et	rivaalitseda =rivaalitse  (Inf  >rivaalitsema !27_V
44603	rindel	rinde	rinne	06_S	SgAd	et	rindel =rinde  (SgAd  >rinne !06_S
44605	kuulutada	kuuluta	kuulutama	27_V	Inf	et	kuulutada =kuuluta  (Inf  >kuulutama !27_V
44611	egoist	egoist	egoist	22_S	SgN	et	egoist =egoist  (SgN  >egoist !22_S
44616	vabastuspüüded	püüde	vabastus+püüe	06_S	PlN	et	vabastuspüüded =püüde  (PlN  >vabastus+püüe !06_S
44619	ms-s	ms	ms	xx_Q	SgIn	et	ms-s =ms  (SgIn  >ms !xx_Q
44621	lähtutakse	lähtu	lähtuma	27_V	IndPrIps	et	lähtutakse =lähtu  (IndPrIps  >lähtuma !27_V
44622	poliitiku	poliitiku	poliitik	02_S	SgG	et	poliitiku =poliitiku  (SgG  >poliitik !02_S
44627	vaenulikuks	vaenuliku	vaenulik	25_A	SgTr	et	vaenulikuks =vaenuliku  (SgTr  >vaenulik !25_A
44633	õpetlik	õpetlik	õpetlik	25_A	SgN	et	õpetlik =õpetlik  (SgN  >õpetlik !25_A
44635	eed	ee	esi	15_S	PlN	et	eed =ee  (PlN  >esi !15_S
44638	koomilisi	koomilisi	koomiline	12_A	PlP	et	koomilisi =koomilisi  (PlP  >koomiline !12_A
44647	aoks	ao	agu	18_S	SgTr	et	aoks =ao  (SgTr  >agu !18_S
44648	õib-olla	oll	õib-olema	36_V	Inf	et	õib-olla =oll  (Inf  >õib-olema !36_V
44653	piltidega	pilti	pilt	22_S	PlKom	et	piltidega =pilti  (PlKom  >pilt !22_S
44660	sunnade	sunna	sunna	16_S	PlG	et	sunnade =sunna  (PlG  >sunna !16_S
44669	finantsvahendeid	vahende	finants+vahend	02_S	PlP	et	finantsvahendeid =vahende  (PlP  >finants+vahend !02_S
44670	aparaadile	aparaadi	aparaat	22_S	SgAll	et	aparaadile =aparaadi  (SgAll  >aparaat !22_S
44678	vastasel	vastase	vastane	10_AS	SgAd	et	vastasel =vastase  (SgAd  >vastane !10_AS
44683	järgsed	järgse	järgne	02_A	PlN	et	järgsed =järgse  (PlN  >järgne !02_A
44415	valetama	valeta	valetama	27_V	Sup	et	valetama =valeta  (Sup  >valetama !27_V
44416	valetage	valeta	valetama	27_V	ImpPrPl2	et	valetage =valeta  (ImpPrPl2  >valetama !27_V
44418	rääkige	rääki	rääkima	28_V	ImpPrPl2	et	rääkige =rääki  (ImpPrPl2  >rääkima !28_V
44419	kuulage	lage	kuu+lagi	21_S	SgP	et	kuulage =lage  (SgP  >kuu+lagi !21_S
44422	kõhklema	kõhkle	kõhklema	30_V	Sup	et	kõhklema =kõhkle  (Sup  >kõhklema !30_V
44424	hoolitseme	hoolitse	hoolitsema	27_V	IndPrPl1	et	hoolitseme =hoolitse  (IndPrPl1  >hoolitsema !27_V
44434	hilinege	hiline	hilinema	27_V	ImpPrPl2	et	hilinege =hiline  (ImpPrPl2  >hilinema !27_V
44436	turundusdirektor	direktor	turundus+direktor	02_S	SgN	et	turundusdirektor =direktor  (SgN  >turundus+direktor !02_S
44445	mitmesugustega	sugus	mitme+sugune	10_A	PlKom	et	mitmesugustega =sugus  (PlKom  >mitme+sugune !10_A
44446	tööotsijaid	otsija	töö+otsija	01_S	PlP	et	tööotsijaid =otsija  (PlP  >töö+otsija !01_S
44449	kaupalaost	ost	kaup+ala+ost	22_S	SgN	et	kaupalaost =ost  (SgN  >kaup+ala+ost !22_S
44452	turundus	turundus	turundus	11_S	SgN	et	turundus =turundus  (SgN  >turundus !11_S
44458	niinimetatud	nimetatu	nii+nimetatu	01_S	PlN	et	niinimetatud =nimetatu  (PlN  >nii+nimetatu !01_S
44460	ülem	ülem	ülem	02_AS	SgN	et	ülem =ülem  (SgN  >ülem !02_AS
44468	omandatakse	omanda	omandama	27_V	IndPrIps	et	omandatakse =omanda  (IndPrIps  >omandama !27_V
44472	topib	topi	toppima	28_V	IndPrSg3	et	topib =topi  (IndPrSg3  >toppima !28_V
44474	ühendage	ühenda	ühendama	27_V	ImpPrPl2	et	ühendage =ühenda  (ImpPrPl2  >ühendama !27_V
44479	rebenema	rebene	rebenema	27_V	Sup	et	rebenema =rebene  (Sup  >rebenema !27_V
44482	kreeme	kreeme	kreem	22_SA	PlP	et	kreeme =kreeme  (PlP  >kreem !22_SA
44485	pesupulbrit	pulbri	pesu+pulber	02_S	SgP	et	pesupulbrit =pulbri  (SgP  >pesu+pulber !02_S
44488	püsikliendil	kliendi	püsi+klient	22_S	SgAd	et	püsikliendil =kliendi  (SgAd  >püsi+klient !22_S
44492	töödeldakse	töödel	töötlema	30_V	IndPrIps	et	töödeldakse =töödel  (IndPrIps  >töötlema !30_V
44494	maiasmokk	mokk	maias+mokk	22_S	SgN	et	maiasmokk =mokk  (SgN  >maias+mokk !22_S
44507	ettepanekusse	paneku	ette+panek	02_S	SgIll	et	ettepanekusse =paneku  (SgIll  >ette+panek !02_S
44515	lootis	loot	lootma	34_V	IndIpfSg3	et	lootis =loot  (IndIpfSg3  >lootma !34_V
44517	taim	taim	taim	22_S	SgN	et	taim =taim  (SgN  >taim !22_S
44523	mäega	mäe	mägi	21_S	SgKom	et	mäega =mäe  (SgKom  >mägi !21_S
44525	kunstnikul	kunstniku	kunstnik	25_S	SgAd	et	kunstnikul =kunstniku  (SgAd  >kunstnik !25_S
44531	istuge	istu	istuma	28_V	ImpPrPl2	et	istuge =istu  (ImpPrPl2  >istuma !28_V
44532	hapud	hapu	hapu	16_A	PlN	et	hapud =hapu  (PlN  >hapu !16_A
44533	mantel	mantel	mantel	02_S	SgN	et	mantel =mantel  (SgN  >mantel !02_S
44539	maakondadeks	maakonda	maakond	22_S	PlTr	et	maakondadeks =maakonda  (PlTr  >maakond !22_S
44541	avaldades	avalda	avaldama	27_V	Ger	et	avaldades =avalda  (Ger  >avaldama !27_V
44545	kohvritega	kohvri	kohver	02_S	PlKom	et	kohvritega =kohvri  (PlKom  >kohver !02_S
44554	majapidamistarvatesse	ate	maja+pidamist+arv+att	22_S	PlIll	et	majapidamistarvatesse =ate  (PlIll  >maja+pidamist+arv+att !22_S
44559	ametliku	ametliku	ametlik	25_A	SgG	et	ametliku =ametliku  (SgG  >ametlik !25_A
44561	mägedel	mäge	mägi	21_S	PlAd	et	mägedel =mäge  (PlAd  >mägi !21_S
44563	7inimesed	inimese	inimene	12_S	PlN	et	inimesed =inimese  (PlN  >inimene !12_S
44569	sugulaselt	sugulase	sugulane	12_S	SgAbl	et	sugulaselt =sugulase  (SgAbl  >sugulane !12_S
44575	2paljud	palju	palju	16_P	PlN	et	paljud =palju  (PlN  >palju !16_P
44579	oktoobriks	oktoobri	oktoober	02_S	SgTr	et	oktoobriks =oktoobri  (SgTr  >oktoober !02_S
44580	maakonnadeks	konna	maa+konn	22_S	PlTr	et	maakonnadeks =konna  (PlTr  >maa+konn !22_S
44583	töötingimustest	tingimus	töö+tingimus	11_S	PlEl	et	töötingimustest =tingimus  (PlEl  >töö+tingimus !11_S
44586	nägudega	nägu	nägu	18_S	PlKom	et	nägudega =nägu  (PlKom  >nägu !18_S
44589	läbirääkimine	rääkimine	läbi+rääkimine	12_S	SgN	et	läbirääkimine =rääkimine  (SgN  >läbi+rääkimine !12_S
44591	teisikute	teisiku	teisik	02_S	PlG	et	teisikute =teisiku  (PlG  >teisik !02_S
44600	saavutamaks	saavuta	saavutama	27_V	SupTr	et	saavutamaks =saavuta  (SupTr  >saavutama !27_V
44602	suur-	suur	suur	13_A	SgN	et	suur- =suur  (SgN  >suur !13_A
44610	huve	huve	huvi	17_S	PlP	et	huve =huve  (PlP  >huvi !17_S
44614	monarhistlik	monarhistlik	monarhistlik	25_A	SgN	et	monarhistlik =monarhistlik  (SgN  >monarhistlik !25_A
44618	sisekonfliktidele	konflikti	sise+konflikt	22_S	PlAll	et	sisekonfliktidele =konflikti  (PlAll  >sise+konflikt !22_S
44624	seisneski	seisne	seisnema	27_V	IndIpfSg3^	et	seisneski =seisne  (IndIpfSg3^  >seisnema !27_V
44626	habras	habras	habras	07_A	SgN	et	habras =habras  (SgN  >habras !07_A
44636	aske	aske	ask	22_S	PlP	et	aske =aske  (PlP  >ask !22_S
44513	ettevaatlikud	vaatliku	ette+vaatlik	25_A	PlN	et	ettevaatlikud =vaatliku  (PlN  >ette+vaatlik !25_A
44516	abile	abi	abi	17_S	SgAll	et	abile =abi  (SgAll  >abi !17_S
44518	inimorganismile	organismi	inim+organism	22_S	SgAll	et	inimorganismile =organismi  (SgAll  >inim+organism !22_S
44519	jätkake	jätka	jätkama	29_V	ImpPrPl2	et	jätkake =jätka  (ImpPrPl2  >jätkama !29_V
44522	viimasena	viimase	viimane	10_A	SgEs	et	viimasena =viimase  (SgEs  >viimane !10_A
44528	1turistid	turisti	turist	22_S	PlN	et	turistid =turisti  (PlN  >turist !22_S
44530	terav	terav	terav	02_A	SgN	et	terav =terav  (SgN  >terav !02_A
44547	hapude	hapu	hapu	16_A	PlG	et	hapude =hapu  (PlG  >hapu !16_A
44552	aud	au	au	26_S	PlN	et	aud =au  (PlN  >au !26_S
44553	seinasse	seina	sein	23?22_S	SgIll	et	seinasse =seina  (SgIll  >sein !23?22_S
44556	inimeseni	inimese	inimene	12_S	SgTer	et	inimeseni =inimese  (SgTer  >inimene !12_S
44560	oles	oles	oles	09_S	SgN	et	oles =oles  (SgN  >oles !09_S
44562	näole	näo	nägu	18_S	SgAll	et	näole =näo  (SgAll  >nägu !18_S
44565	juhtisin	juhti	juhtima	28_V	IndIpfSg1	et	juhtisin =juhti  (IndIpfSg1  >juhtima !28_V
44570	riielt	riie	riid	22_S	PlAbl	et	riielt =riie  (PlAbl  >riid !22_S
44571	kohviga	kohvi	kohv	22_S	SgKom	et	kohviga =kohvi  (SgKom  >kohv !22_S
44572	osakonnadesse	konna	osa+konn	22_S	PlIll	et	osakonnadesse =konna  (PlIll  >osa+konn !22_S
44573	veod	veo	vedu	18_S	PlN	et	veod =veo  (PlN  >vedu !18_S
44576	5ärge	är	ära	--_V	ImpPrPl2N	et	ärge =är  (ImpPrPl2N  >ära !--_V
44577	5kas	kas	kas	41_D	ID	et	kas =kas  (ID  >kas !41_D
44581	baltisakslaseks	sakslase	balti+sakslane	12?10_S	SgTr	et	baltisakslaseks =sakslase  (SgTr  >balti+sakslane !12?10_S
44582	tööandjaga	andja	töö+andja	01_S	SgKom	et	tööandjaga =andja  (SgKom  >töö+andja !01_S
44584	mägedes	mäge	mägi	21_S	PlIn	et	mägedes =mäge  (PlIn  >mägi !21_S
44592	mõneski	mõne	mõni	20_P	SgIn^	et	mõneski =mõne  (SgIn^  >mõni !20_P
44593	teisik	teisik	teisik	02_S	SgN	et	teisik =teisik  (SgN  >teisik !02_S
44597	augeltki	auge	auk	22_S	PlAbl^	et	augeltki =auge  (PlAbl^  >auk !22_S
44601	kinnisideeks	idee	kinnis+idee	26_S	SgTr	et	kinnisideeks =idee  (SgTr  >kinnis+idee !26_S
44606	nõuannete	anne	nõu+anne	06_S	PlG	et	nõuannete =anne  (PlG  >nõu+anne !06_S
44607	tegelast	tegelas	tegelane	12_S	SgP	et	tegelast =tegelas  (SgP  >tegelane !12_S
44612	revolutsionäär	revolutsionäär	revolutsionäär	22_S	SgN	et	revolutsionäär =revolutsionäär  (SgN  >revolutsionäär !22_S
44617	impeeriumit	impeeriumi	impeerium	02_S	SgP	et	impeeriumit =impeeriumi  (SgP  >impeerium !02_S
44620	ettekäänet	kääne	ette+kääne	06_S	SgP	et	ettekäänet =kääne  (SgP  >ette+kääne !06_S
44629	niikaua	niikaua	nii+kaua	41_D	ID	et	niikaua =niikaua  (ID  >nii+kaua !41_D
44632	olukordade	korda	olu+kord	22_S	PlG	et	olukordade =korda  (PlG  >olu+kord !22_S
44634	ärast	äras	ärane	10_A	SgP	et	ärast =äras  (SgP  >ärane !10_A
44637	sikuga	siku	sikk	22_S	SgKom	et	sikuga =siku  (SgKom  >sikk !22_S
44639	traagilisi	traagilisi	traagiline	12_A	PlP	et	traagilisi =traagilisi  (PlP  >traagiline !12_A
44644	ulge	ulge	ulg	22_S	PlP	et	ulge =ulge  (PlP  >ulg !22_S
44646	evolutsiooniga	evolutsiooni	evolutsioon	22_S	SgKom	et	evolutsiooniga =evolutsiooni  (SgKom  >evolutsioon !22_S
44657	revolutsiooniga	revolutsiooni	revolutsioon	22_S	SgKom	et	revolutsiooniga =revolutsiooni  (SgKom  >revolutsioon !22_S
44661	vaatlema	vaatle	vaatlema	30_V	Sup	et	vaatlema =vaatle  (Sup  >vaatlema !30_V
44665	eritab	erita	eritama	27_V	IndPrSg3	et	eritab =erita  (IndPrSg3  >eritama !27_V
44672	salajas	salajas	salajas	41_D	ID	et	salajas =salajas  (ID  >salajas !41_D
44688	haritlaste	haritlas	haritlane	12_S	PlG	et	haritlaste =haritlas  (PlG  >haritlane !12_S
44690	seltsil	seltsi	selts	22_S	SgAd	et	seltsil =seltsi  (SgAd  >selts !22_S
44692	initsiatiivgrupp	grupp	initsiatiiv+grupp	22_S	SgN	et	initsiatiivgrupp =grupp  (SgN  >initsiatiiv+grupp !22_S
44698	madalat	madala	madal	02_AS	SgP	et	madalat =madala  (SgP  >madal !02_AS
44699	tekstiilitööstus	tööstus	tekstiili+tööstus	11~09_S	SgN	et	tekstiilitööstus =tööstus  (SgN  >tekstiili+tööstus !11~09_S
44718	vahepealset	pealse	vahe+pealne	02_AS	SgP	et	vahepealset =pealse  (SgP  >vahe+pealne !02_AS
44720	pastorina	pastori	pastor	02_S	SgEs	et	pastorina =pastori  (SgEs  >pastor !02_S
44726	inglismaaga	maa	inglis+maa	26_S	SgKom	et	inglismaaga =maa  (SgKom  >inglis+maa !26_S
44727	1930-te			xx_Q	PlG	et	-te =  (PlG  > !xx_Q
44728	tööjõupuudus	puudus	töö+jõu+puudus	11~09_S	SgN	et	tööjõupuudus =puudus  (SgN  >töö+jõu+puudus !11~09_S
44735	seltsiliikumisele	liikumise	seltsi+liikumine	12_S	SgAll	et	seltsiliikumisele =liikumise  (SgAll  >seltsi+liikumine !12_S
44739	parlamendiks	parlamendi	parlament	22_S	SgTr	et	parlamendiks =parlamendi  (SgTr  >parlament !22_S
44640	patriootideks	patriooti	patrioot	22_S	PlTr	et	patriootideks =patriooti  (PlTr  >patrioot !22_S
44649	faktidest	fakti	fakt	22_S	PlEl	et	faktidest =fakti  (PlEl  >fakt !22_S
44650	lõbutüdrukud	tüdruku	lõbu+tüdruk	02_S	PlN	et	lõbutüdrukud =tüdruku  (PlN  >lõbu+tüdruk !02_S
44654	filmiautor	autor	filmi+autor	02_S	SgN	et	filmiautor =autor  (SgN  >filmi+autor !02_S
44663	sorima	sori	sorima	27_V	Sup	et	sorima =sori  (Sup  >sorima !27_V
44667	järjekordses	kordse	järje+kordne	02_AS	SgIn	et	järjekordses =kordse  (SgIn  >järje+kordne !02_AS
44673	faktiks	fakti	fakt	22_S	SgTr	et	faktiks =fakti  (SgTr  >fakt !22_S
44679	väljaviskamine	viskamine	välja+viskamine	12_S	SgN	et	väljaviskamine =viskamine  (SgN  >välja+viskamine !12_S
44680	laevapardalt	parda	laeva+parras	07_S	SgAbl	et	laevapardalt =parda  (SgAbl  >laeva+parras !07_S
44682	eeltingimusteks	tingimus	eel+tingimus	11_S	PlTr	et	eeltingimusteks =tingimus  (PlTr  >eel+tingimus !11_S
44685	otsingud	otsingu	otsing	02_S	PlN	et	otsingud =otsingu  (PlN  >otsing !02_S
44686	rahvuskultuurist	kultuuri	rahvus+kultuur	22_S	SgEl	et	rahvuskultuurist =kultuuri  (SgEl  >rahvus+kultuur !22_S
44701	tsemendivabrikud	vabriku	tsemendi+vabrik	02_S	PlN	et	tsemendivabrikud =vabriku  (PlN  >tsemendi+vabrik !02_S
44702	aparaadivabrikud	vabriku	aparaadi+vabrik	02_S	PlN	et	aparaadivabrikud =vabriku  (PlN  >aparaadi+vabrik !02_S
44711	sonetid	soneti	sonett	22_S	PlN	et	sonetid =soneti  (PlN  >sonett !22_S
44712	avardas	avarda	avardama	27_V	IndIpfSg3	et	avardas =avarda  (IndIpfSg3  >avardama !27_V
44723	piimatööstus	tööstus	piima+tööstus	11~09_S	SgN	et	piimatööstus =tööstus  (SgN  >piima+tööstus !11~09_S
44730	mitteamet	amet	mitte+amet	02_S	SgN	et	mitteamet =amet  (SgN  >mitte+amet !02_S
44732	naisliikumised	liikumise	nais+liikumine	12_S	PlN	et	naisliikumised =liikumise  (PlN  >nais+liikumine !12_S
44738	kompromisse	kompromisse	kompromiss	22_S	PlP	et	kompromisse =kompromisse  (PlP  >kompromiss !22_S
44743	rahulepingule	lepingu	rahu+leping	02_S	SgAll	et	rahulepingule =lepingu  (SgAll  >rahu+leping !02_S
44752	moodustama	moodusta	moodustama	27_V	Sup	et	moodustama =moodusta  (Sup  >moodustama !27_V
44760	kultuuriarenguga	arengu	kultuuri+areng	02_S	SgKom	et	kultuuriarenguga =arengu  (SgKom  >kultuuri+areng !02_S
44764	kirjaviisile	viisi	kirja+viis	22_S	SgAll	et	kirjaviisile =viisi  (SgAll  >kirja+viis !22_S
44773	vabariigile	riigi	vaba+riik	22_S	SgAll	et	vabariigile =riigi  (SgAll  >vaba+riik !22_S
44776	kultuuriseltsile	seltsi	kultuuri+selts	22_S	SgAll	et	kultuuriseltsile =seltsi  (SgAll  >kultuuri+selts !22_S
44793	koolilugemikke	lugemikke	kooli+lugemik	25_S	PlP	et	koolilugemikke =lugemikke  (PlP  >kooli+lugemik !25_S
44797	turust	turu	turg	22_S	SgEl	et	turust =turu  (SgEl  >turg !22_S
44801	kurnati	kurna	kurnama	29_V	IndIpfIps	et	kurnati =kurna  (IndIpfIps  >kurnama !29_V
44802	kütusepuudus	puudus	kütuse+puudus	11~09_S	SgN	et	kütusepuudus =puudus  (SgN  >kütuse+puudus !11~09_S
44803	rahuleping	leping	rahu+leping	02_S	SgN	et	rahuleping =leping  (SgN  >rahu+leping !02_S
44806	ilukirjandusega	kirjanduse	ilu+kirjandus	11_S	SgKom	et	ilukirjandusega =kirjanduse  (SgKom  >ilu+kirjandus !11_S
44811	tipptasemel	taseme	tipp+tase	04_S	SgAd	et	tipptasemel =taseme  (SgAd  >tipp+tase !04_S
44826	tük-s	tük	tük	xx_Q	SgIn	et	tük-s =tük  (SgIn  >tük !xx_Q
44834	kutseharidus	haridus	kutse+haridus	11_S	SgN	et	kutseharidus =haridus  (SgN  >kutse+haridus !11_S
44836	arenemisriik	riik	arenemis+riik	22_S	SgN	et	arenemisriik =riik  (SgN  >arenemis+riik !22_S
44840	koiduaeg	aeg	koidu+aeg	22_S	SgN	et	koiduaeg =aeg  (SgN  >koidu+aeg !22_S
44844	man	man	man	41_DK	ID	et	man =man  (ID  >man !41_DK
44851	keskkoll	koll	kesk+koll	22_S	SgN	et	keskkoll =koll  (SgN  >kesk+koll !22_S
44855	uuriti	uuri	uurima	28_V	IndIpfIps	et	uuriti =uuri  (IndIpfIps  >uurima !28_V
44860	jumaldada	jumalda	jumaldama	27_V	Inf	et	jumaldada =jumalda  (Inf  >jumaldama !27_V
44862	vägivaldne	valdne	vägi+valdne	02_A	SgN	et	vägivaldne =valdne  (SgN  >vägi+valdne !02_A
44867	hindab	hinda	hindama	29_V	IndPrSg3	et	hindab =hinda  (IndPrSg3  >hindama !29_V
44868	püüet	püüe	püüe	06_S	SgP	et	püüet =püüe  (SgP  >püüe !06_S
44870	propageerima	propageeri	propageerima	28_V	Sup	et	propageerima =propageeri  (Sup  >propageerima !28_V
44872	taunis	tauni	taunima	28_V	IndIpfSg3	et	taunis =tauni  (IndIpfSg3  >taunima !28_V
44874	vähemusrahvused	rahvuse	vähemus+rahvus	11~09_S	PlN	et	vähemusrahvused =rahvuse  (PlN  >vähemus+rahvus !11~09_S
44876	omakeelset	keelse	oma+keelne	02_A	SgP	et	omakeelset =keelse  (SgP  >oma+keelne !02_A
44886	merekoolid	kooli	mere+kool	22_S	PlN	et	merekoolid =kooli  (PlN  >mere+kool !22_S
44888	keeleuuendusega	uuenduse	keele+uuendus	11_S	SgKom	et	keeleuuendusega =uuenduse  (SgKom  >keele+uuendus !11_S
44894	põllumajandusnäituseid	näituse	põllu+majandus+näitus	09_S	PlP	et	põllumajandusnäituseid =näituse  (PlP  >põllu+majandus+näitus !09_S
44642	avantüristlik	avantüristlik	avantüristlik	25_A	SgN	et	avantüristlik =avantüristlik  (SgN  >avantüristlik !25_A
44645	elluviimises	viimise	ellu+viimine	12?10_S	SgIn	et	elluviimises =viimise  (SgIn  >ellu+viimine !12?10_S
44658	rahvamassid	massi	rahva+mass	22_S	PlN	et	rahvamassid =massi  (PlN  >rahva+mass !22_S
44659	nälg	nälg	nälg	22_S	SgN	et	nälg =nälg  (SgN  >nälg !22_S
44668	lastehaiglas	haigla	laste+haigla	01_S	SgIn	et	lastehaiglas =haigla  (SgIn  >laste+haigla !01_S
44674	arvul	arvu	arv	22_S	SgAd	et	arvul =arvu  (SgAd  >arv !22_S
44676	paradiis	paradiis	paradiis	22_S	SgN	et	paradiis =paradiis  (SgN  >paradiis !22_S
44681	püüdles	püüdle	püüdlema	30_V	IndIpfSg3	et	püüdles =püüdle  (IndIpfSg3  >püüdlema !30_V
44693	tugipunktideks	punkti	tugi+punkt	22_S	PlTr	et	tugipunktideks =punkti  (PlTr  >tugi+punkt !22_S
44695	peekon	peekon	peekon	02_S	SgN	et	peekon =peekon  (SgN  >peekon !02_S
44704	euroopalist	euroopalis	euroopaline	12_A	SgP	et	euroopalist =euroopalis  (SgP  >euroopaline !12_A
44716	sekkus	sekku	sekkuma	27_V	IndIpfSg3	et	sekkus =sekku  (IndIpfSg3  >sekkuma !27_V
44721	rahvusriigi	riigi	rahvus+riik	22_S	SgG	et	rahvusriigi =riigi  (SgG  >rahvus+riik !22_S
44722	majandusmasinate	masina	majandus+masin	02_S	PlG	et	majandusmasinate =masina  (PlG  >majandus+masin !02_S
44729	seltsiliikumise	liikumise	seltsi+liikumine	12_S	SgG	et	seltsiliikumise =liikumise  (SgG  >seltsi+liikumine !12_S
44733	poliitikuga	poliitiku	poliitik	02_S	SgKom	et	poliitikuga =poliitiku  (SgKom  >poliitik !02_S
44737	salaliikumisega	liikumise	sala+liikumine	12_S	SgKom	et	salaliikumisega =liikumise  (SgKom  >sala+liikumine !12_S
44749	naisteseltsid	seltsi	naiste+selts	22_S	PlN	et	naisteseltsid =seltsi  (PlN  >naiste+selts !22_S
44754	korporandid	korporandi	korporant	22_S	PlN	et	korporandid =korporandi  (PlN  >korporant !22_S
44755	haridusseltsid	seltsi	haridus+selts	22_S	PlN	et	haridusseltsid =seltsi  (PlN  >haridus+selts !22_S
44756	kõnega	kõne	kõne	16_S	SgKom	et	kõnega =kõne  (SgKom  >kõne !16_S
44761	maaomanikke	omanikke	maa+omanik	25_S	PlP	et	maaomanikke =omanikke  (PlP  >maa+omanik !25_S
44763	foneetilisele	foneetilise	foneetiline	12_A	SgAll	et	foneetilisele =foneetilise  (SgAll  >foneetiline !12_A
44765	liidreid	liidre	liider	02_S	PlP	et	liidreid =liidre  (PlP  >liider !02_S
44778	õnnistas	õnnista	õnnistama	27_V	IndIpfSg3	et	õnnistas =õnnista  (IndIpfSg3  >õnnistama !27_V
44781	kutsekoolid	kooli	kutse+kool	22_S	PlN	et	kutsekoolid =kooli  (PlN  >kutse+kool !22_S
44784	keeleuuendus	uuendus	keele+uuendus	11_S	SgN	et	keeleuuendus =uuendus  (SgN  >keele+uuendus !11_S
44788	pärisorjastamine	orjastamine	päris+orjastamine	12_S	SgN	et	pärisorjastamine =orjastamine  (SgN  >päris+orjastamine !12_S
44790	rahvusärkamine	ärkamine	rahvus+ärkamine	12_S	SgN	et	rahvusärkamine =ärkamine  (SgN  >rahvus+ärkamine !12_S
44792	lugemisoskust	oskus	lugemis+oskus	11~09_S	SgP	et	lugemisoskust =oskus  (SgP  >lugemis+oskus !11~09_S
44796	regioon	regioon	regioon	22_S	SgN	et	regioon =regioon  (SgN  >regioon !22_S
44799	küündis	küündi	küündima	27~28_V	IndIpfSg3	et	küündis =küündi  (IndIpfSg3  >küündima !27~28_V
44805	postimee	mee	posti+mesi	15_S	SgG	et	postimee =mee  (SgG  >posti+mesi !15_S
44808	tähetorn	torn	tähe+torn	22_S	SgN	et	tähetorn =torn  (SgN  >tähe+torn !22_S
44812	1934a-ni	a	a	xx_Q	SgTer	et	a-ni =a  (SgTer  >a !xx_Q
44815	seltsiliikumine	liikumine	seltsi+liikumine	12_S	SgN	et	seltsiliikumine =liikumine  (SgN  >seltsi+liikumine !12_S
44816	põllumajandusseltsid	seltsi	põllu+majandus+selts	22_S	PlN	et	põllumajandusseltsid =seltsi  (PlN  >põllu+majandus+selts !22_S
44817	tuletõrjeseltsid	seltsi	tule+tõrje+selts	22_S	PlN	et	tuletõrjeseltsid =seltsi  (PlN  >tule+tõrje+selts !22_S
44819	karskusseltsid	seltsi	karskus+selts	22_S	PlN	et	karskusseltsid =seltsi  (PlN  >karskus+selts !22_S
44821	rahvusküsimustega	küsimus	rahvus+küsimus	11_S	PlKom	et	rahvusküsimustega =küsimus  (PlKom  >rahvus+küsimus !11_S
44824	naisseltsid	seltsi	nais+selts	22_S	PlN	et	naisseltsid =seltsi  (PlN  >nais+selts !22_S
44828	rusikajõust	jõu	rusika+jõud	22_S	SgEl	et	rusikajõust =jõu  (SgEl  >rusika+jõud !22_S
44829	omakeelse	keelse	oma+keelne	02_A	SgG	et	omakeelse =keelse  (SgG  >oma+keelne !02_A
44842	kirja-lugemisoskust	oskus	kirja-lugemis+oskus	11~09_S	SgP	et	kirja-lugemisoskust =oskus  (SgP  >kirja-lugemis+oskus !11~09_S
44845	olingi	ol	olema	36_V	IndIpfSg1^	et	olingi =ol  (IndIpfSg1^  >olema !36_V
44846	juudid	juudi	juut	22_S	PlN	et	juudid =juudi  (PlN  >juut !22_S
44863	mahajäänum	jäänum	maha+jäänum	02_A	SgN	et	mahajäänum =jäänum  (SgN  >maha+jäänum !02_A
44875	kultuurautonoomiat	autonoomia	kultuur+autonoomia	01_S	SgP	et	kultuurautonoomiat =autonoomia  (SgP  >kultuur+autonoomia !01_S
44882	ida-euroopas	euroopa	ida-euroopa	01_H	SgIn	et	ida-euroopas =euroopa  (SgIn  >ida-euroopa !01_H
44887	kutseõpe	õpe	kutse+õpe	06_S	SgN	et	kutseõpe =õpe  (SgN  >kutse+õpe !06_S
44656	klounid	klouni	kloun	22_S	PlN	et	klounid =klouni  (PlN  >kloun !22_S
44662	palgad	palga	palk	22_S	PlN	et	palgad =palga  (PlN  >palk !22_S
44664	kopikates	kopika	kopikas	02_S	PlIn	et	kopikates =kopika  (PlIn  >kopikas !02_S
44666	poliitikute	poliitiku	poliitik	02_S	PlG	et	poliitikute =poliitiku  (PlG  >poliitik !02_S
44671	ühikud	ühiku	ühik	02_S	PlN	et	ühikud =ühiku  (PlN  >ühik !02_S
44675	paradiisis	paradiisi	paradiis	22_S	SgIn	et	paradiisis =paradiisi  (SgIn  >paradiis !22_S
44677	julm	julm	julm	22_A	SgN	et	julm =julm  (SgN  >julm !22_A
44691	seminaridel	seminari	seminar	19_S	PlAd	et	seminaridel =seminari  (PlAd  >seminar !19_S
44697	metsaraiele	raie	metsa+raie	06_S	SgAll	et	metsaraiele =raie  (SgAll  >metsa+raie !06_S
44700	metallitööstus	tööstus	metalli+tööstus	11~09_S	SgN	et	metallitööstus =tööstus  (SgN  >metalli+tööstus !11~09_S
44703	jäägem	jää	jääma	37_V	ImpPrPl1	et	jäägem =jää  (ImpPrPl1  >jääma !37_V
44705	luulekogud	kogu	luule+kogu	17_S	PlN	et	luulekogud =kogu  (PlN  >luule+kogu !17_S
44707	kirjandus-	kirjandus	kirjandus	11_S	SgN	et	kirjandus- =kirjandus  (SgN  >kirjandus !11_S
44709	mõjudele	mõju	mõju	17_S	PlAll	et	mõjudele =mõju  (PlAll  >mõju !17_S
44710	stiilitunnetus	tunnetus	stiili+tunnetus	11_S	SgN	et	stiilitunnetus =tunnetus  (SgN  >stiili+tunnetus !11_S
44724	laevandus	laevandus	laevandus	11_S	SgN	et	laevandus =laevandus  (SgN  >laevandus !11_S
44725	lennundus	lennundus	lennundus	11_S	SgN	et	lennundus =lennundus  (SgN  >lennundus !11_S
44736	seltsidel	seltsi	selts	22_S	PlAd	et	seltsidel =seltsi  (PlAd  >selts !22_S
44740	b-sakslastele	sakslas	b-sakslane	12?10_S	PlAll	et	b-sakslastele =sakslas  (PlAll  >b-sakslane !12?10_S
44741	fikseeriti	fikseeri	fikseerima	28_V	IndIpfIps	et	fikseeriti =fikseeri  (IndIpfIps  >fikseerima !28_V
44745	likvideerima	likvideeri	likvideerima	28_V	Sup	et	likvideerima =likvideeri  (Sup  >likvideerima !28_V
44747	vetest	ve	vesi	15_S	PlEl	et	vetest =ve  (PlEl  >vesi !15_S
44753	korporatsioone	korporatsioone	korporatsioon	22_S	PlP	et	korporatsioone =korporatsioone  (PlP  >korporatsioon !22_S
44766	seminarid	seminari	seminar	19_S	PlN	et	seminarid =seminari  (PlN  >seminar !19_S
44768	näitused	näituse	näitus	11~09_S	PlN	et	näitused =näituse  (PlN  >näitus !11~09_S
44769	ärkamisaegses	aegse	ärkamis+aegne	02_A	SgIn	et	ärkamisaegses =aegse  (SgIn  >ärkamis+aegne !02_A
44772	naisliikumise	liikumise	nais+liikumine	12_S	SgG	et	naisliikumise =liikumise  (SgG  >nais+liikumine !12_S
44777	üleskirjutamisele	kirjutamise	üles+kirjutamine	12_S	SgAll	et	üleskirjutamisele =kirjutamise  (SgAll  >üles+kirjutamine !12_S
44779	areenilt	areeni	areen	22_S	SgAbl	et	areenilt =areeni  (SgAbl  >areen !22_S
44786	keeleuurijad	uurija	keele+uurija	01_S	PlN	et	keeleuurijad =uurija  (PlN  >keele+uurija !01_S
44787	ristirüütlid	rüütli	risti+rüütel	02_S	PlN	et	ristirüütlid =rüütli  (PlN  >risti+rüütel !02_S
44789	toiduaeg	aeg	toidu+aeg	22_S	SgN	et	toiduaeg =aeg  (SgN  >toidu+aeg !22_S
44794	sakalaajaleht	leht	sakala+aja+leht	22_S	SgN	et	sakalaajaleht =leht  (SgN  >sakala+aja+leht !22_S
44798	väe	väe	vägi	21_S	SgG	et	väe =väe  (SgG  >vägi !21_S
44807	eestvõtel	võte	eest+võtt	22_S	PlAd	et	eestvõtel =võte  (PlAd  >eest+võtt !22_S
44810	viljandimaalt	maa	viljandi+maa	26_S	SgAbl	et	viljandimaalt =maa  (SgAbl  >viljandi+maa !26_S
44813	a-l	a	a	xx_Q	SgAd	et	a-l =a  (SgAd  >a !xx_Q
44818	alguss	uss	alg+uss	22_S	SgN	et	alguss =uss  (SgN  >alg+uss !22_S
44820	poliitikaga	poliitika	poliitika	01_S	SgKom	et	poliitikaga =poliitika  (SgKom  >poliitika !01_S
44822	mänguseltsid	seltsi	mängu+selts	22_S	PlN	et	mänguseltsid =seltsi  (PlN  >mängu+selts !22_S
44832	komertsharidus	haridus	kom+erts+haridus	11_S	SgN	et	komertsharidus =haridus  (SgN  >kom+erts+haridus !11_S
44837	koidu	koidu	koit	22_S	SgG	et	koidu =koidu  (SgG  >koit !22_S
44838	kõned	kõne	kõne	16_S	PlN	et	kõned =kõne  (PlN  >kõne !16_S
44841	euroopaliku	euroopaliku	euroopalik	25_A	SgG	et	euroopaliku =euroopaliku  (SgG  >euroopalik !25_A
44848	sellides	selli	sell	22_S	PlIn	et	sellides =selli  (PlIn  >sell !22_S
44852	reaal-	reaal	reaal	22_S	SgN	et	reaal- =reaal  (SgN  >reaal !22_S
44853	algkoll	koll	alg+koll	22_S	SgN	et	algkoll =koll  (SgN  >alg+koll !22_S
44856	peajooned	joone	pea+joon	13_S	PlN	et	peajooned =joone  (PlN  >pea+joon !13_S
44873	poisski	poiss	poiss	23?22_S	SgN^	et	poisski =poiss  (SgN^  >poiss !23?22_S
44877	toimuks	toimu	toimuma	27_V	KndPrPs	et	toimuks =toimu  (KndPrPs  >toimuma !27_V
44879	maailmatähendust	tähendus	maa+ilma+tähendus	11_S	SgP	et	maailmatähendust =tähendus  (SgP  >maa+ilma+tähendus !11_S
44881	natsionalism	natsionalism	natsionalism	22_S	SgN	et	natsionalism =natsionalism  (SgN  >natsionalism !22_S
44884	loomeühingud	ühingu	loome+ühing	02_S	PlN	et	loomeühingud =ühingu  (PlN  >loome+ühing !02_S
44684	avaliku	avaliku	avalik	25_A	SgG	et	avaliku =avaliku  (SgG  >avalik !25_A
44687	seltskond	seltskond	seltskond	22_S	SgN	et	seltskond =seltskond  (SgN  >seltskond !22_S
44689	kult	kult	kult	22_S	SgN	et	kult =kult  (SgN  >kult !22_S
44694	ekspordiartiklid	artikli	ekspordi+artikkel	02_S	PlN	et	ekspordiartiklid =artikli  (PlN  >ekspordi+artikkel !02_S
44696	kalandusega	kalanduse	kalandus	11_S	SgKom	et	kalandusega =kalanduse  (SgKom  >kalandus !11_S
44706	põhirõhk	rõhk	põhi+rõhk	22_S	SgN	et	põhirõhk =rõhk  (SgN  >põhi+rõhk !22_S
44708	kunstikriitikale	kriitika	kunsti+kriitika	01_S	SgAll	et	kunstikriitikale =kriitika  (SgAll  >kunsti+kriitika !01_S
44713	tipud	tipu	tipp	22_S	PlN	et	tipud =tipu  (PlN  >tipp !22_S
44714	vahendas	vahenda	vahendama	27_V	IndIpfSg3	et	vahendas =vahenda  (IndIpfSg3  >vahendama !27_V
44715	kultuuriellu	ellu	kultuuri+elu	17_S	SgAdt	et	kultuuriellu =ellu  (SgAdt  >kultuuri+elu !17_S
44717	pooldas	poolda	pooldama	27_V	IndIpfSg3	et	pooldas =poolda  (IndIpfSg3  >pooldama !27_V
44719	hurdale	hurda	hurt	22_S	SgAll	et	hurdale =hurda  (SgAll  >hurt !22_S
44731	rahvuslipp	lipp	rahvus+lipp	22_S	SgN	et	rahvuslipp =lipp  (SgN  >rahvus+lipp !22_S
44734	saladusseltsid	seltsi	saladus+selts	22_S	PlN	et	saladusseltsid =seltsi  (PlN  >saladus+selts !22_S
44742	2veebruaril	veebruari	veebruar	19_S	SgAd	et	veebruaril =veebruari  (SgAd  >veebruar !19_S
44746	riismed	riisme	riise	05_S	PlN	et	riismed =riisme  (PlN  >riise !05_S
44757	julgustas	julgusta	julgustama	27_V	IndIpfSg3	et	julgustas =julgusta  (IndIpfSg3  >julgustama !27_V
44758	poliitikuna	poliitiku	poliitik	02_S	SgEs	et	poliitikuna =poliitiku  (SgEs  >poliitik !02_S
44767	keeleteadusega	teaduse	keele+teadus	11~09_S	SgKom	et	keeleteadusega =teaduse  (SgKom  >keele+teadus !11~09_S
44770	erakorra	korra	era+kord	22_S	SgG	et	erakorra =korra  (SgG  >era+kord !22_S
44783	asuti	asu	asuma	27_V	IndIpfIps	et	asuti =asu  (IndIpfIps  >asuma !27_V
44800	meheni	mehe	mees	13_S	SgTer	et	meheni =mehe  (SgTer  >mees !13_S
44804	ärkamisaegseid	aegse	ärkamis+aegne	02_A	PlP	et	ärkamisaegseid =aegse  (PlP  >ärkamis+aegne !02_A
44809	skulptorid	skulptori	skulptor	02_S	PlN	et	skulptorid =skulptori  (PlN  >skulptor !02_S
44823	akt	akt	akt	22_S	SgN	et	akt =akt  (SgN  >akt !22_S
44831	tehnilist	tehnilis	tehniline	12_A	SgP	et	tehnilist =tehnilis  (SgP  >tehniline !12_A
44839	valgusaeg	aeg	valgus+aeg	22_S	SgN	et	valgusaeg =aeg  (SgN  >valgus+aeg !22_S
44843	kostab	kosta	kostma	34_V	IndPrSg3	et	kostab =kosta  (IndPrSg3  >kostma !34_V
44847	gümnaasiumil	gümnaasiumi	gümnaasium	19~02_S	SgAd	et	gümnaasiumil =gümnaasiumi  (SgAd  >gümnaasium !19~02_S
44849	kirjanikude	kirjaniku	kirjanik	25_S	PlG	et	kirjanikude =kirjaniku  (PlG  >kirjanik !25_S
44858	puusepp	sepp	puu+sepp	22_S	SgN	et	puusepp =sepp  (SgN  >puu+sepp !22_S
44859	valguseaeg	aeg	valguse+aeg	22_S	SgN	et	valguseaeg =aeg  (SgN  >valguse+aeg !22_S
44861	ristisõdijate	sõdija	risti+sõdija	01_S	PlG	et	ristisõdijate =sõdija  (PlG  >risti+sõdija !01_S
44866	alistub	alistu	alistuma	27_V	IndPrSg3	et	alistub =alistu  (IndPrSg3  >alistuma !27_V
44883	kõnepidamiseks	pidamise	kõne+pidamine	12_S	SgTr	et	kõnepidamiseks =pidamise  (SgTr  >kõne+pidamine !12_S
44885	algkoolmis	mi	alg+kool+mi	26_S	SgIn	et	algkoolmis =mi  (SgIn  >alg+kool+mi !26_S
44890	arheoloogiaga	arheoloogia	arheoloogia	01_S	SgKom	et	arheoloogiaga =arheoloogia  (SgKom  >arheoloogia !01_S
44893	piimatööstusega	tööstuse	piima+tööstus	11~09_S	SgKom	et	piimatööstusega =tööstuse  (SgKom  >piima+tööstus !11~09_S
44898	ristirüütlitega	rüütli	risti+rüütel	02_S	PlKom	et	ristirüütlitega =rüütli  (PlKom  >risti+rüütel !02_S
44899	pärisorjusega	orjuse	päris+orjus	11~09_S	SgKom	et	pärisorjusega =orjuse  (SgKom  >päris+orjus !11~09_S
44900	selt	se	see	00_P	SgAbl	et	selt =se  (SgAbl  >see !00_P
44905	vähemusrahva	rahva	vähemus+rahvas	07_S	SgG	et	vähemusrahva =rahva  (SgG  >vähemus+rahvas !07_S
44908	juurat	juura	juura	16_S	SgP	et	juurat =juura  (SgP  >juura !16_S
44910	pastoriteks	pastori	pastor	02_S	PlTr	et	pastoriteks =pastori  (PlTr  >pastor !02_S
44913	kultuuritegelase	tegelase	kultuuri+tegelane	12_S	SgG	et	kultuuritegelase =tegelase  (SgG  >kultuuri+tegelane !12_S
44914	koolilugemisraamat	raamat	kooli+lugemis+raamat	02_S	SgN	et	koolilugemisraamat =raamat  (SgN  >kooli+lugemis+raamat !02_S
44920	põlisrahvale	rahva	põlis+rahvas	07_S	SgAll	et	põlisrahvale =rahva  (SgAll  >põlis+rahvas !07_S
44921	rahulepingu	lepingu	rahu+leping	02_S	SgG	et	rahulepingu =lepingu  (SgG  >rahu+leping !02_S
44929	protestidega	protesti	protest	22_S	PlKom	et	protestidega =protesti  (PlKom  >protest !22_S
44930	streikidega	streiki	streik	22_S	PlKom	et	streikidega =streiki  (PlKom  >streik !22_S
44961	inglismaalt	maa	inglis+maa	26_S	SgAbl	et	inglismaalt =maa  (SgAbl  >inglis+maa !26_S
44963	paberitööstus	tööstus	paberi+tööstus	11~09_S	SgN	et	paberitööstus =tööstus  (SgN  >paberi+tööstus !11~09_S
44744	diplomaatilised	diplomaatilise	diplomaatiline	12_A	PlN	et	diplomaatilised =diplomaatilise  (PlN  >diplomaatiline !12_A
44748	baseerus	baseeru	baseeruma	27_V	IndIpfSg3	et	baseerus =baseeru  (IndIpfSg3  >baseeruma !27_V
44750	suburg	urg	sub+urg	22_S	SgN	et	suburg =urg  (SgN  >sub+urg !22_S
44751	üliõpilasselts	selts	üli+õpilas+selts	22_S	SgN	et	üliõpilasselts =selts  (SgN  >üli+õpilas+selts !22_S
44759	määrati	määra	määrama	29_V	IndIpfIps	et	määrati =määra  (IndIpfIps  >määrama !29_V
44762	nõuanded	ande	nõu+anne	06_S	PlN	et	nõuanded =ande  (PlN  >nõu+anne !06_S
44771	kõrgperiood	periood	kõrg+periood	22_S	SgN	et	kõrgperiood =periood  (SgN  >kõrg+periood !22_S
44774	seltsiliikumistesse	liikumis	seltsi+liikumine	12_S	PlIll	et	seltsiliikumistesse =liikumis  (PlIll  >seltsi+liikumine !12_S
44775	haarati	haara	haarama	29_V	IndIpfIps	et	haarati =haara  (IndIpfIps  >haarama !29_V
44780	algkoolides	kooli	alg+kool	22_S	PlIn	et	algkoolides =kooli  (PlIn  >alg+kool !22_S
44782	täienduskoolid	kooli	täiendus+kool	22_S	PlN	et	täienduskoolid =kooli  (PlN  >täiendus+kool !22_S
44785	akad	aka	aka	16_S	PlN	et	akad =aka  (PlN  >aka !16_S
44791	kirjaoskust	oskus	kirja+oskus	11~09_S	SgP	et	kirjaoskust =oskus  (SgP  >kirja+oskus !11~09_S
44795	järgmistele	järgmis	järgmine	12?10_A	PlAll	et	järgmistele =järgmis  (PlAll  >järgmine !12?10_A
44814	1seltsiliikumise	liikumise	seltsi+liikumine	12_S	SgG	et	seltsiliikumise =liikumise  (SgG  >seltsi+liikumine !12_S
44825	teadvustad	teadvusta	teadvustama	27_V	IndPrSg2	et	teadvustad =teadvusta  (IndPrSg2  >teadvustama !27_V
44827	edendada	edenda	edendama	27_V	Inf	et	edendada =edenda  (Inf  >edendama !27_V
44830	kõrgharidussüsteem	süsteem	kõrg+haridus+süsteem	22_S	SgN	et	kõrgharidussüsteem =süsteem  (SgN  >kõrg+haridus+süsteem !22_S
44833	vajama	vaja	vajama	27_V	Sup	et	vajama =vaja  (Sup  >vajama !27_V
44835	haridusreform	reform	haridus+reform	22_S	SgN	et	haridusreform =reform  (SgN  >haridus+reform !22_S
44850	kultuuriarenemine	arenemine	kultuuri+arenemine	12_S	SgN	et	kultuuriarenemine =arenemine  (SgN  >kultuuri+arenemine !12_S
44854	muuk	muuk	muuk	22_S	SgN	et	muuk =muuk  (SgN  >muuk !22_S
44857	eestikeelemuinasjutte	jutte	eesti+keele+muinas+jutt	22_S	PlP	et	eestikeelemuinasjutte =jutte  (PlP  >eesti+keele+muinas+jutt !22_S
44864	sõjaväge	väge	sõja+vägi	21_S	SgP	et	sõjaväge =väge  (SgP  >sõja+vägi !21_S
44865	ristirüütlite	rüütli	risti+rüütel	02_S	PlG	et	ristirüütlite =rüütli  (PlG  >risti+rüütel !02_S
44869	süüdistab	süüdista	süüdistama	27_V	IndPrSg3	et	süüdistab =süüdista  (IndPrSg3  >süüdistama !27_V
44871	nõiaprotsessidega	protsessi	nõia+protsess	22_S	PlKom	et	nõiaprotsessidega =protsessi  (PlKom  >nõia+protsess !22_S
44878	kultuurisündmused	sündmuse	kultuuri+sündmus	11~09_S	PlN	et	kultuurisündmused =sündmuse  (PlN  >kultuuri+sündmus !11~09_S
44880	juurutati	juuruta	juurutama	27_V	IndIpfIps	et	juurutati =juuruta  (IndIpfIps  >juurutama !27_V
44892	orienteerus	orienteeru	orienteeruma	27_V	IndIpfSg3	et	orienteerus =orienteeru  (IndIpfSg3  >orienteeruma !27_V
44912	rahuläbirääkimised	rääkimise	rahu+läbi+rääkimine	12_S	PlN	et	rahuläbirääkimised =rääkimise  (PlN  >rahu+läbi+rääkimine !12_S
44923	mänguseltsile	seltsi	mängu+selts	22_S	SgAll	et	mänguseltsile =seltsi  (SgAll  >mängu+selts !22_S
44924	rahvusteartrile	artri	rahvuste+arter	02_S	SgAll	et	rahvusteartrile =artri  (SgAll  >rahvuste+arter !02_S
44925	suleti	sule	sulgema	28_V	IndIpfIps	et	suleti =sule  (IndIpfIps  >sulgema !28_V
44927	saavutati	saavuta	saavutama	27_V	IndIpfIps	et	saavutati =saavuta  (IndIpfIps  >saavutama !27_V
44933	areste	areste	arest	22_S	PlP	et	areste =areste  (PlP  >arest !22_S
44935	mälestussamma	samma	mälestus+samb	22_S	SgG	et	mälestussamma =samma  (SgG  >mälestus+samb !22_S
44936	mätsis	mätsi	mätsima	28_V	IndIpfSg3	et	mätsis =mätsi  (IndIpfSg3  >mätsima !28_V
44937	tehtigi	teh	tegema	28_V	IndIpfIps^	et	tehtigi =teh  (IndIpfIps^  >tegema !28_V
44939	segaduse	segaduse	segadus	11_S	SgG	et	segaduse =segaduse  (SgG  >segadus !11_S
44947	ametinimeks	nime	ameti+nimi	20_S	SgTr	et	ametinimeks =nime  (SgTr  >ameti+nimi !20_S
44950	baaside	baasi	baas	22_S	PlG	et	baaside =baasi  (PlG  >baas !22_S
44952	rahvusena	rahvuse	rahvus	11~09_S	SgEs	et	rahvusena =rahvuse  (SgEs  >rahvus !11~09_S
44954	kirjanukud	nuku	kirja+nukk	22_S	PlN	et	kirjanukud =nuku  (PlN  >kirja+nukk !22_S
44956	päästekomitees	komitee	pääste+komitee	26_S	SgIn	et	päästekomitees =komitee  (SgIn  >pääste+komitee !26_S
44957	väideti	väide	väitma	34_V	IndIpfIps	et	väideti =väide  (IndIpfIps  >väitma !34_V
44972	turusse	turu	turg	22_S	SgIll	et	turusse =turu  (SgIll  >turg !22_S
44974	pank	pank	pank	22_S	SgN	et	pank =pank  (SgN  >pank !22_S
44975	isamaakõnet	kõne	isa+maa+kõne	16_S	SgP	et	isamaakõnet =kõne  (SgP  >isa+maa+kõne !16_S
44984	nimigi	nimi	nimi	20_S	SgN^	et	nimigi =nimi  (SgN^  >nimi !20_S
44994	masinaehitusvarikud	variku	masina+ehitus+varik	02_S	PlN	et	masinaehitusvarikud =variku  (PlN  >masina+ehitus+varik !02_S
44889	etnograafiaga	etnograafia	etnograafia	01_S	SgKom	et	etnograafiaga =etnograafia  (SgKom  >etnograafia !01_S
44897	teadlastest	teadlas	teadlane	12?10_S	PlEl	et	teadlastest =teadlas  (PlEl  >teadlane !12?10_S
44901	laisad	laisa	laisk	22_A	PlN	et	laisad =laisa  (PlN  >laisk !22_A
44902	rahvusliikumisega	liikumise	rahvus+liikumine	12_S	SgKom	et	rahvusliikumisega =liikumise  (SgKom  >rahvus+liikumine !12_S
44903	kultuur-	kultuur	kultuur	22_S	SgN	et	kultuur- =kultuur  (SgN  >kultuur !22_S
44911	autonoomiad	autonoomia	autonoomia	01_S	PlN	et	autonoomiad =autonoomia  (PlN  >autonoomia !01_S
44926	konstitutsioon	konstitutsioon	konstitutsioon	22_S	SgN	et	konstitutsioon =konstitutsioon  (SgN  >konstitutsioon !22_S
44938	allakirjutamisega	kirjutamise	alla+kirjutamine	12_S	SgKom	et	allakirjutamisega =kirjutamise  (SgKom  >alla+kirjutamine !12_S
44946	ametinimi	nimi	ameti+nimi	20_S	SgN	et	ametinimi =nimi  (SgN  >ameti+nimi !20_S
44949	valitsemisstiil	stiil	valitsemis+stiil	22_S	SgN	et	valitsemisstiil =stiil  (SgN  >valitsemis+stiil !22_S
44958	radikaalne	radikaalne	radikaalne	02_A	SgN	et	radikaalne =radikaalne  (SgN  >radikaalne !02_A
44960	majandusturg	turg	majandus+turg	22_S	SgN	et	majandusturg =turg  (SgN  >majandus+turg !22_S
44965	motoks	moto	moto	16_S	SgTr	et	motoks =moto  (SgTr  >moto !16_S
44966	lutsuga	lutsu	luts	22_S	SgKom	et	lutsuga =lutsu  (SgKom  >luts !22_S
44970	aastaarv	arv	aasta+arv	22_S	SgN	et	aastaarv =arv  (SgN  >aasta+arv !22_S
44976	ühingute	ühingu	ühing	02_S	PlG	et	ühingute =ühingu  (PlG  >ühing !02_S
44978	kaitsetollid	tolli	kaitse+toll	22_S	PlN	et	kaitsetollid =tolli  (PlN  >kaitse+toll !22_S
44982	kanamunad	muna	kana+muna	17_S	PlN	et	kanamunad =muna  (PlN  >kana+muna !17_S
44988	pärisorjad	orja	päris+ori	24_S	PlN	et	pärisorjad =orja  (PlN  >päris+ori !24_S
44992	majandusselts	selts	majandus+selts	22_S	SgN	et	majandusselts =selts  (SgN  >majandus+selts !22_S
45004	telliskivitööstus	tööstus	tellis+kivi+tööstus	11~09_S	SgN	et	telliskivitööstus =tööstus  (SgN  >tellis+kivi+tööstus !11~09_S
45011	võrdlen	võrdle	võrdlema	30_V	IndPrSg1	et	võrdlen =võrdle  (IndPrSg1  >võrdlema !30_V
45014	kohvis	kohvi	kohv	22_S	SgIn	et	kohvis =kohvi  (SgIn  >kohv !22_S
45016	liidete	liide	liide	06_S	PlG	et	liidete =liide  (PlG  >liide !06_S
45018	õpik	õpik	õpik	02_S	SgN	et	õpik =õpik  (SgN  >õpik !02_S
45019	mõtlik	mõtlik	mõtlik	25_A	SgN	et	mõtlik =mõtlik  (SgN  >mõtlik !25_A
45024	elatis	elatis	elatis	11_S	SgN	et	elatis =elatis  (SgN  >elatis !11_S
45030	soojemalt	sooje	soe	24_AS	M_cA	et	"soojem %sooje  )M_cA  <soe ;24_AS
45031	ebasüdamlik	südamlik	eba+südamlik	25_A	SgN	et	ebasüdamlik =südamlik  (SgN  >eba+südamlik !25_A
45032	juttust	us	jutt+uks	14_S	SgP	et	juttust =us  (SgP  >jutt+uks !14_S
45038	lehk	lehk	lehk	22_S	SgN	et	lehk =lehk  (SgN  >lehk !22_S
45041	söögis	söögi	söök	22_S	SgIn	et	söögis =söögi  (SgIn  >söök !22_S
45043	kõikvõimsat	võimsa	kõik+võimas	03_A	SgP	et	kõikvõimsat =võimsa  (SgP  >kõik+võimas !03_A
45046	üksmeelse	meelse	üks+meelne	02_A	SgG	et	üksmeelse =meelse  (SgG  >üks+meelne !02_A
45049	lõkendama	lõkenda	lõkendama	27_V	Sup	et	lõkendama =lõkenda  (Sup  >lõkendama !27_V
45052	sedavõrd	sedavõrd	seda+võrd	41_D	ID	et	sedavõrd =sedavõrd  (ID  >seda+võrd !41_D
45054	füüsilisele	füüsilise	füüsiline	12_A	SgAll	et	füüsilisele =füüsilise  (SgAll  >füüsiline !12_A
45059	arvamusele	arvamuse	arvamus	11_S	SgAll	et	arvamusele =arvamuse  (SgAll  >arvamus !11_S
45066	inimsuhetele	suhe	inim+suhe	06_S	PlAll	et	inimsuhetele =suhe  (PlAll  >inim+suhe !06_S
45067	kriisiolukordades	korda	kriisi+olu+kord	22_S	PlIn	et	kriisiolukordades =korda  (PlIn  >kriisi+olu+kord !22_S
45072	argpükslike	pükslike	arg+pükslik	25_A	PlG	et	argpükslike =pükslike  (PlG  >arg+pükslik !25_A
45073	ägedatele	ägeda	äge	02_A	PlAll	et	ägedatele =ägeda  (PlAll  >äge !02_A
45075	mõisteti	mõiste	mõistma	34_V	IndIpfIps	et	mõisteti =mõiste  (IndIpfIps  >mõistma !34_V
45081	pisara	pisara	pisar	02_S	SgG	et	pisara =pisara  (SgG  >pisar !02_S
45085	ülearu	ülearu	üle+aru	41_D	ID	et	ülearu =ülearu  (ID  >üle+aru !41_D
45092	ühiskonnakorraldust	korraldus	ühis+konna+korraldus	11_S	SgP	et	ühiskonnakorraldust =korraldus  (SgP  >ühis+konna+korraldus !11_S
45095	tegelikest	tegelike	tegelik	25_A	PlEl	et	tegelikest =tegelike  (PlEl  >tegelik !25_A
45100	teatrilaval	lava	teatri+lava	17_S	SgAd	et	teatrilaval =lava  (SgAd  >teatri+lava !17_S
45109	väljailmumine	ilmumine	välja+ilmumine	12_S	SgN	et	väljailmumine =ilmumine  (SgN  >välja+ilmumine !12_S
45114	desertööriks	desertööri	desertöör	22_S	SgTr	et	desertööriks =desertööri  (SgTr  >desertöör !22_S
45120	urineerima	urineeri	urineerima	28_V	Sup	et	urineerima =urineeri  (Sup  >urineerima !28_V
45132	kommunistide	kommunisti	kommunist	22_S	PlG	et	kommunistide =kommunisti  (PlG  >kommunist !22_S
44891	reaalteadused	teaduse	reaal+teadus	11~09_S	PlN	et	reaalteadused =teaduse  (PlN  >reaal+teadus !11~09_S
44909	seminarides	seminari	seminar	19_S	PlIn	et	seminarides =seminari  (PlIn  >seminar !19_S
44915	maavalitsuse	valitsuse	maa+valitsus	11_S	SgG	et	maavalitsuse =valitsuse  (SgG  >maa+valitsus !11_S
44918	püüe	püüe	püüe	06_S	SgN	et	püüe =püüe  (SgN  >püüe !06_S
44940	suruma	suru	suruma	27_V	Sup	et	suruma =suru  (Sup  >suruma !27_V
44941	läkski	läk	minema	36_V	IndIpfSg3^	et	läkski =läk  (IndIpfSg3^  >minema !36_V
44948	soomlastele	soomlas	soomlane	12?10_S	PlAll	et	soomlastele =soomlas  (PlAll  >soomlane !12?10_S
44951	välispoliitikaga	poliitika	välis+poliitika	01_S	SgKom	et	välispoliitikaga =poliitika  (SgKom  >välis+poliitika !01_S
44953	iseseisvuda	seisvu	ise+seisvuma	27_V	Inf	et	iseseisvuda =seisvu  (Inf  >ise+seisvuma !27_V
44959	esialgne	algne	esi+algne	02_A	SgN	et	esialgne =algne  (SgN  >esi+algne !02_A
44962	tekstiilitootmine	tootmine	tekstiili+tootmine	12?10_S	SgN	et	tekstiilitootmine =tootmine  (SgN  >tekstiili+tootmine !12?10_S
44964	ehitusmaterjalide	materjali	ehitus+materjal	19_S	PlG	et	ehitusmaterjalide =materjali  (PlG  >ehitus+materjal !19_S
44969	maalikunst	kunst	maali+kunst	22_S	SgN	et	maalikunst =kunst  (SgN  >maali+kunst !22_S
44981	eksporditi	ekspordi	eksportima	28_V	IndIpfIps	et	eksporditi =ekspordi  (IndIpfIps  >eksportima !28_V
44987	albumeid	albume	album	02_S	PlP	et	albumeid =albume  (PlP  >album !02_S
44989	maarahvaks	rahva	maa+rahvas	07_S	SgTr	et	maarahvaks =rahva  (SgTr  >maa+rahvas !07_S
44990	kultuurileevendamine	leevendamine	kultuuri+leevendamine	12_S	SgN	et	kultuurileevendamine =leevendamine  (SgN  >kultuuri+leevendamine !12_S
44993	ekspordile	ekspordi	eksport	22_S	SgAll	et	ekspordile =ekspordi  (SgAll  >eksport !22_S
44995	vagunivabrik	vabrik	vaguni+vabrik	02_S	SgN	et	vagunivabrik =vabrik  (SgN  >vaguni+vabrik !02_S
44998	puuvalmistamine	valmistamine	puu+valmistamine	12_S	SgN	et	puuvalmistamine =valmistamine  (SgN  >puu+valmistamine !12_S
45003	dolomiidi	dolomiidi	dolomiit	22_S	SgG	et	dolomiidi =dolomiidi  (SgG  >dolomiit !22_S
45007	skaudid	skaudi	skaut	22_S	PlN	et	skaudid =skaudi  (PlN  >skaut !22_S
45029	jäti	jäti	jätt	22_S	SgG	et	jäti =jäti  (SgG  >jätt !22_S
45037	sojalt	soja	soja	17_S	SgAbl	et	sojalt =soja  (SgAbl  >soja !17_S
45055	vastaspoolele	poole	vastas+pool	22_S	PlAll	et	vastaspoolele =poole  (PlAll  >vastas+pool !22_S
45056	teisitimõtlejad	mõtleja	teisiti+mõtleja	01_S	PlN	et	teisitimõtlejad =mõtleja  (PlN  >teisiti+mõtleja !01_S
45057	sõnumina	sõnumi	sõnum	02_S	SgEs	et	sõnumina =sõnumi  (SgEs  >sõnum !02_S
45062	edaspidised	pidise	edas+pidine	10_A	PlN	et	edaspidised =pidise  (PlN  >edas+pidine !10_A
45065	rõhke	rõhke	rõhk	22_S	PlP	et	rõhke =rõhke  (PlP  >rõhk !22_S
45068	sellegipoolest	sellegipoolest	sellegi+poolest	41_D	ID	et	sellegipoolest =sellegipoolest  (ID  >sellegi+poolest !41_D
45074	vaidlustele	vaidlus	vaidlus	11~09_S	PlAll	et	vaidlustele =vaidlus  (PlAll  >vaidlus !11~09_S
45077	vihastati	vihasta	vihastama	27_V	IndIpfIps	et	vihastati =vihasta  (IndIpfIps  >vihastama !27_V
45080	esmaemotsioonide	emotsiooni	esma+emotsioon	22_S	PlG	et	esmaemotsioonide =emotsiooni  (PlG  >esma+emotsioon !22_S
45082	julgeid	julge	julge	01_A	PlP	et	julgeid =julge  (PlP  >julge !01_A
45090	vinduma	vindu	vinduma	27_V	Sup	et	vinduma =vindu  (Sup  >vinduma !27_V
45101	paberilt	paberi	paber	02_S	SgAbl	et	paberilt =paberi  (SgAbl  >paber !02_S
45103	ebaloomulik	loomulik	eba+loomulik	25_A	SgN	et	ebaloomulik =loomulik  (SgN  >eba+loomulik !25_A
45104	sisutihedat	tiheda	sisu+tihe	02_A	SgP	et	sisutihedat =tiheda  (SgP  >sisu+tihe !02_A
45122	eufoorias	eufooria	eufooria	01_S	SgIn	et	eufoorias =eufooria  (SgIn  >eufooria !01_S
45123	vabadussõjaaegsest	aegse	vabadus+sõja+aegne	02_A	SgEl	et	vabadussõjaaegsest =aegse  (SgEl  >vabadus+sõja+aegne !02_A
45130	rahumeelset	meelse	rahu+meelne	02_A	SgP	et	rahumeelset =meelse  (SgP  >rahu+meelne !02_A
45146	trükk	trükk	trükk	22_S	SgN	et	trükk =trükk  (SgN  >trükk !22_S
45148	peategelaseks	tegelase	pea+tegelane	12_S	SgTr	et	peategelaseks =tegelase  (SgTr  >pea+tegelane !12_S
45150	eestisid	eesti	eesti	16_H	PlP	et	eestisid =eesti  (PlP  >eesti !16_H
45158	hingepõhjani	põhja	hinge+põhi	24_S	SgTer	et	hingepõhjani =põhja  (SgTer  >hinge+põhi !24_S
45159	vabadussõtta	sõtta	vabadus+sõda	18_S	SgAdt	et	vabadussõtta =sõtta  (SgAdt  >vabadus+sõda !18_S
45160	sõjahirmud	hirmu	sõja+hirm	22_S	PlN	et	sõjahirmud =hirmu  (PlN  >sõja+hirm !22_S
45162	realistlikuks	realistliku	realistlik	25_A	SgTr	et	realistlikuks =realistliku  (SgTr  >realistlik !25_A
45172	põrkas	põrka	põrkama	29_V	IndIpfSg3	et	põrkas =põrka  (IndIpfSg3  >põrkama !29_V
45180	loodeti	loode	lootma	34_V	IndIpfIps	et	loodeti =loode  (IndIpfIps  >lootma !34_V
45181	kangekaelse	kaelse	kange+kaelne	02_A	SgG	et	kangekaelse =kaelse  (SgG  >kange+kaelne !02_A
44895	kultuurieluga	elu	kultuuri+elu	17_S	SgKom	et	kultuurieluga =elu  (SgKom  >kultuuri+elu !17_S
44896	rootsikeelsed	keelse	rootsi+keelne	02_A	PlN	et	rootsikeelsed =keelse  (PlN  >rootsi+keelne !02_A
44904	ühinguid	ühingu	ühing	02_S	PlP	et	ühinguid =ühingu  (PlP  >ühing !02_S
44906	autonoomiast	autonoomia	autonoomia	01_S	SgEl	et	autonoomiast =autonoomia  (SgEl  >autonoomia !01_S
44907	alg-	alg	alg	22_S	SgN	et	alg- =alg  (SgN  >alg !22_S
44916	advokaadina	advokaadi	advokaat	22_S	SgEs	et	advokaadina =advokaadi  (SgEs  >advokaat !22_S
44917	blokk	blokk	blokk	22_S	SgN	et	blokk =blokk  (SgN  >blokk !22_S
44919	liidritel	liidri	liider	02_S	PlAd	et	liidritel =liidri  (PlAd  >liider !02_S
44922	kultuuritegelastel	tegelas	kultuuri+tegelane	12_S	PlAd	et	kultuuritegelastel =tegelas  (PlAd  >kultuuri+tegelane !12_S
44928	ühtlasena	ühtlase	ühtlane	12?10_A	SgEs	et	ühtlasena =ühtlase  (SgEs  >ühtlane !12?10_A
44931	ekms-is	ekms	ekms	xx_Q	SgIn	et	ekms-is =ekms  (SgIn  >ekms !xx_Q
44932	keeleuuendamisega	uuendamise	keele+uuendamine	12_S	SgKom	et	keeleuuendamisega =uuendamise  (SgKom  >keele+uuendamine !12_S
44934	uurimusega	uurimuse	uurimus	11_S	SgKom	et	uurimusega =uurimuse  (SgKom  >uurimus !11_S
44942	postimeheks	mehe	posti+mees	13_S	SgTr	et	postimeheks =mehe  (SgTr  >posti+mees !13_S
44943	lehes	lehe	leht	22_S	SgIn	et	lehes =lehe  (SgIn  >leht !22_S
44944	ametilt	ameti	amet	02_S	SgAbl	et	ametilt =ameti  (SgAbl  >amet !02_S
44945	eesvedamisel	vedamise	ees+vedamine	12_S	SgAd	et	eesvedamisel =vedamise  (SgAd  >ees+vedamine !12_S
44955	luuled	luule	luule	06_S	PlN	et	luuled =luule  (PlN  >luule !06_S
44968	rahvamajandus	majandus	rahva+majandus	11_S	SgN	et	rahvamajandus =majandus  (SgN  >rahva+majandus !11_S
44971	tootlus	tootlus	tootlus	11~09_S	SgN	et	tootlus =tootlus  (SgN  >tootlus !11~09_S
44973	turuprobleem	probleem	turu+probleem	22_S	SgN	et	turuprobleem =probleem  (SgN  >turu+probleem !22_S
44977	paekivimurrud	murru	pae+kivi+murd	22_S	PlN	et	paekivimurrud =murru  (PlN  >pae+kivi+murd !22_S
44979	miinustes	miinus	miinus	09_S	PlIn	et	miinustes =miinus  (PlIn  >miinus !09_S
44980	masina-	masina	masin	02_S	SgG	et	masina- =masina  (SgG  >masin !02_S
44983	tööstusharusid	haru	tööstus+haru	17_S	PlP	et	tööstusharusid =haru  (PlP  >tööstus+haru !17_S
44985	sünniga	sünni	sünd	22_S	SgKom	et	sünniga =sünni  (SgKom  >sünd !22_S
44991	siseturg	turg	sise+turg	22_S	SgN	et	siseturg =turg  (SgN  >sise+turg !22_S
45002	toormaterjale	materjale	toor+materjal	19_S	PlP	et	toormaterjale =materjale  (PlP  >toor+materjal !19_S
45005	kruus	kruus	kruus	22_S	SgN	et	kruus =kruus  (SgN  >kruus !22_S
45008	kotkad	kotka	kotkas	07_S	PlN	et	kotkad =kotka  (PlN  >kotkas !07_S
45009	vabariigist	riigi	vaba+riik	22_S	SgEl	et	vabariigist =riigi  (SgEl  >vaba+riik !22_S
45012	kukun	kuku	kukkuma	28_V	IndPrSg1	et	kukun =kuku  (IndPrSg1  >kukkuma !28_V
45022	rõõmsasti	rõõmsasti	rõõmsasti	41_D	ID	et	rõõmsasti =rõõmsasti  (ID  >rõõmsasti !41_D
45025	kasvus	kasvu	kasv	22_S	SgIn	et	kasvus =kasvu  (SgIn  >kasv !22_S
45026	lauljatar	lauljatar	lauljatar	19_S	SgN	et	lauljatar =lauljatar  (SgN  >lauljatar !19_S
45048	koolivennad	venna	kooli+vend	22_S	PlN	et	koolivennad =venna  (PlN  >kooli+vend !22_S
45060	suhetele	suhe	suhe	06_S	PlAll	et	suhetele =suhe  (PlAll  >suhe !06_S
45063	kahega	kahe	kaks	22_N	SgKom	et	kahega =kahe  (SgKom  >kaks !22_N
45071	närviga	närvi	närv	22_S	SgKom	et	närviga =närvi  (SgKom  >närv !22_S
45084	teatrilavastajaid	lavastaja	teatri+lavastaja	01_S	PlP	et	teatrilavastajaid =lavastaja  (PlP  >teatri+lavastaja !01_S
45087	esilinastust	linastus	esi+linastus	11_S	SgP	et	esilinastust =linastus  (SgP  >esi+linastus !11_S
45091	kohustuslikuks	kohustusliku	kohustuslik	25_A	SgTr	et	kohustuslikuks =kohustusliku  (SgTr  >kohustuslik !25_A
45098	kinonäitlejaid	näitleja	kino+näitleja	01_S	PlP	et	kinonäitlejaid =näitleja  (PlP  >kino+näitleja !01_S
45108	vihjedki	vihje	vihje	06_S	PlN^	et	vihjedki =vihje  (PlN^  >vihje !06_S
45110	lahinguväljalt	välja	lahingu+väli	24_S	SgAbl	et	lahinguväljalt =välja  (SgAbl  >lahingu+väli !24_S
45111	haihtus	haihtu	haihtuma	27_V	IndIpfSg3	et	haihtus =haihtu  (IndIpfSg3  >haihtuma !27_V
45112	ülemaga	ülema	ülem	02_AS	SgKom	et	ülemaga =ülema  (SgKom  >ülem !02_AS
45115	soomlast	soomlas	soomlane	12?10_S	SgP	et	soomlast =soomlas  (SgP  >soomlane !12?10_S
45116	rolle	rolle	roll	22_S	PlP	et	rolle =rolle  (PlP  >roll !22_S
45118	idiootidena	idiooti	idioot	22_S	PlEs	et	idiootidena =idiooti  (PlEs  >idioot !22_S
45119	ilmsest	ilmse	ilmne	02_A	SgEl	et	ilmsest =ilmse  (SgEl  >ilmne !02_A
45121	nolke	nolke	nolk	22_S	PlP	et	nolke =nolke  (PlP  >nolk !22_S
45125	ülemaiilmse	ilmse	üle+mai+ilmne	02_A	SgG	et	ülemaiilmse =ilmse  (SgG  >üle+mai+ilmne !02_A
45131	pooldaks	poolda	pooldama	27_V	KndPrPs	et	pooldaks =poolda  (KndPrPs  >pooldama !27_V
44967	kubermang	kubermang	kubermang	22_S	SgN	et	kubermang =kubermang  (SgN  >kubermang !22_S
44986	alatoon	toon	ala+toon	22_S	SgN	et	alatoon =toon  (SgN  >ala+toon !22_S
44997	ekstensiivne	ekstensiivne	ekstensiivne	02_A	SgN	et	ekstensiivne =ekstensiivne  (SgN  >ekstensiivne !02_A
44999	metsandus	metsandus	metsandus	11_S	SgN	et	metsandus =metsandus  (SgN  >metsandus !11_S
45001	partneri	partneri	partner	02_S	SgG	et	partneri =partneri  (SgG  >partner !02_S
45010	avama	ava	avama	27_V	Sup	et	avama =ava  (Sup  >avama !27_V
45015	suhkrut	suhkru	suhkur	02_S	SgP	et	suhkrut =suhkru  (SgP  >suhkur !02_S
45020	õigsus	õigsus	õigsus	11~09_S	SgN	et	õigsus =õigsus  (SgN  >õigsus !11~09_S
45021	lendan	lenda	lendama	29_V	IndPrSg1	et	lendan =lenda  (IndPrSg1  >lendama !29_V
45023	ausasti	ausasti	ausasti	41_D	ID	et	ausasti =ausasti  (ID  >ausasti !41_D
45042	õigsuse	õigsuse	õigsus	11~09_S	SgG	et	õigsuse =õigsuse  (SgG  >õigsus !11~09_S
45044	dollarit	dollari	dollar	02_S	SgP	et	dollarit =dollari  (SgP  >dollar !02_S
45050	variandina	variandi	variant	22_S	SgEs	et	variandina =variandi  (SgEs  >variant !22_S
45051	vaidluse	vaidluse	vaidlus	11~09_S	SgG	et	vaidluse =vaidluse  (SgG  >vaidlus !11~09_S
45053	mõningasele	mõningase	mõningane	12_P	SgAll	et	mõningasele =mõningase  (SgAll  >mõningane !12_P
45058	vaadetele	vaade	vaade	06_S	PlAll	et	vaadetele =vaade  (PlAll  >vaade !06_S
45069	püssilaskudest	lasku	püssi+lask	22_S	PlEl	et	püssilaskudest =lasku  (PlEl  >püssi+lask !22_S
45070	rühmajuht	juht	rühma+juht	22_S	SgN	et	rühmajuht =juht  (SgN  >rühma+juht !22_S
45076	ainuvõimalik	võimalik	ainu+võimalik	25_A	SgN	et	ainuvõimalik =võimalik  (SgN  >ainu+võimalik !25_A
45078	eneseõigustus	õigustus	enese+õigustus	11_S	SgN	et	eneseõigustus =õigustus  (SgN  >enese+õigustus !11_S
45086	üleskiitmine	kiitmine	üles+kiitmine	12?10_S	SgN	et	üleskiitmine =kiitmine  (SgN  >üles+kiitmine !12?10_S
45088	viletsaid	viletsa	vilets	02_A	PlP	et	viletsaid =viletsa  (PlP  >vilets !02_A
45089	filmitööstus	tööstus	filmi+tööstus	11~09_S	SgN	et	filmitööstus =tööstus  (SgN  >filmi+tööstus !11~09_S
45093	põhjuseid	põhjuse	põhjus	09_S	PlP	et	põhjuseid =põhjuse  (PlP  >põhjus !09_S
45099	teatrilavale	lava	teatri+lava	17_S	SgAll	et	teatrilavale =lava  (SgAll  >teatri+lava !17_S
45102	vuristada	vurista	vuristama	27_V	Inf	et	vuristada =vurista  (Inf  >vuristama !27_V
45113	tembeldada	tembelda	tembeldama	27_V	Inf	et	tembeldada =tembelda  (Inf  >tembeldama !27_V
45128	ohver	ohver	ohver	02_S	SgN	et	ohver =ohver  (SgN  >ohver !02_S
45134	okupeerida	okupeeri	okupeerima	28_V	Inf	et	okupeerida =okupeeri  (Inf  >okupeerima !28_V
45147	okupatsioonivõimude	võimu	okupatsiooni+võim	22_S	PlG	et	okupatsioonivõimude =võimu  (PlG  >okupatsiooni+võim !22_S
45152	seesuguse	suguse	see+sugune	10_P	SgG	et	seesuguse =suguse  (SgG  >see+sugune !10_P
45161	kuulide	kuuli	kuul	22_S	PlG	et	kuulide =kuuli  (PlG  >kuul !22_S
45163	sõduritega	sõduri	sõdur	02_S	PlKom	et	sõduritega =sõduri  (PlKom  >sõdur !02_S
45171	olusid	olu	olu	17_S	PlP	et	olusid =olu  (PlP  >olu !17_S
45177	kritiseerida	kritiseeri	kritiseerima	28_V	Inf	et	kritiseerida =kritiseeri  (Inf  >kritiseerima !28_V
45182	jonnaka	jonnaka	jonnakas	02_A	SgG	et	jonnaka =jonnaka  (SgG  >jonnakas !02_A
45185	ollagi	oll	olema	36_V	Inf^	et	ollagi =oll  (Inf^  >olema !36_V
45201	vaadetest	vaade	vaade	06_S	PlEl	et	vaadetest =vaade  (PlEl  >vaade !06_S
45205	kodumaaga	maa	kodu+maa	26_S	SgKom	et	kodumaaga =maa  (SgKom  >kodu+maa !26_S
45211	lennates	lenna	lendama	29_V	Ger	et	lennates =lenna  (Ger  >lendama !29_V
45215	kujutasin	kujuta	kujutama	27_V	IndIpfSg1	et	kujutasin =kujuta  (IndIpfSg1  >kujutama !27_V
45217	märkaksin	märka	märkama	29_V	KndPrSg1	et	märkaksin =märka  (KndPrSg1  >märkama !29_V
45218	avantürist	avantürist	avantürist	22_S	SgN	et	avantürist =avantürist  (SgN  >avantürist !22_S
45219	aferist	aferist	aferist	22_S	SgN	et	aferist =aferist  (SgN  >aferist !22_S
45220	enamlane	enamlane	enamlane	12_S	SgN	et	enamlane =enamlane  (SgN  >enamlane !12_S
45231	egoistlik	egoistlik	egoistlik	25_A	SgN	et	egoistlik =egoistlik  (SgN  >egoistlik !25_A
45232	fanaatiline	fanaatiline	fanaatiline	12_A	SgN	et	fanaatiline =fanaatiline  (SgN  >fanaatiline !12_A
45236	toredaid	toreda	tore	02_A	PlP	et	toredaid =toreda  (PlP  >tore !02_A
45239	fenomeniks	fenomeni	fenomen	19_S	SgTr	et	fenomeniks =fenomeni  (SgTr  >fenomen !19_S
45240	poliitikad	poliitika	poliitika	01_S	PlN	et	poliitikad =poliitika  (PlN  >poliitika !01_S
45248	elupäevad	päeva	elu+päev	22_S	PlN	et	elupäevad =päeva  (PlN  >elu+päev !22_S
45260	tähtsatel	tähtsa	tähtis	02_A	PlAd	et	tähtsatel =tähtsa  (PlAd  >tähtis !02_A
45274	tagaotsitavaks	otsitava	taga+otsitav	02_AS	SgTr	et	tagaotsitavaks =otsitava  (SgTr  >taga+otsitav !02_AS
44996	masinatehas	tehas	masina+tehas	09_S	SgN	et	masinatehas =tehas  (SgN  >masina+tehas !09_S
45000	karjandus	karjandus	karjandus	11_S	SgN	et	karjandus =karjandus  (SgN  >karjandus !11_S
45006	gaidid	gaidi	gaid	22_S	PlN	et	gaidid =gaidi  (PlN  >gaid !22_S
45013	soojamalt	jama	soo+jama	17_S	SgAbl	et	soojamalt =jama  (SgAbl  >soo+jama !17_S
45017	laulik	laulik	laulik	02_S	SgN	et	laulik =laulik  (SgN  >laulik !02_S
45027	südamik	südamik	südamik	25_S	SgN	et	südamik =südamik  (SgN  >südamik !25_S
45028	südalinn	linn	süda+linn	22_S	SgN	et	südalinn =linn  (SgN  >süda+linn !22_S
45033	käida	käi	käima	38_V	IndPrIps_	et	käida =käi  (IndPrIps_  >käima !38_V
45034	lugemik	lugemik	lugemik	25_S	SgN	et	lugemik =lugemik  (SgN  >lugemik !25_S
45035	kästakse	käs	käskima	28_V	IndPrIps	et	kästakse =käs  (IndPrIps  >käskima !28_V
45036	kasvik	kasvik	kasvik	02_S	SgN	et	kasvik =kasvik  (SgN  >kasvik !02_S
45039	käitud	käitu	käituma	27_V	IndPrSg2	et	käitud =käitu  (IndPrSg2  >käituma !27_V
45040	tingimusi	tingimusi	tingimus	11_S	PlP	et	tingimusi =tingimusi  (PlP  >tingimus !11_S
45045	ideaalse	ideaalse	ideaalne	02_A	SgG	et	ideaalse =ideaalse  (SgG  >ideaalne !02_A
45047	nõusolekuna	oleku	nõus+olek	02_S	SgEs	et	nõusolekuna =oleku  (SgEs  >nõus+olek !02_S
45061	esisel	esise	esine	10_AS	SgAd	et	esisel =esise  (SgAd  >esine !10_AS
45064	asjaoludest	olu	asja+olu	17_S	PlEl	et	asjaoludest =olu  (PlEl  >asja+olu !17_S
45079	hetkemuresid	mure	hetke+mure	16_S	PlP	et	hetkemuresid =mure  (PlP  >hetke+mure !16_S
45083	marmortahvlile	tahvli	marmor+tahvel	02_S	SgAll	et	marmortahvlile =tahvli  (SgAll  >marmor+tahvel !02_S
45094	sõjakeerises	keerise	sõja+keeris	09_S	SgIn	et	sõjakeerises =keerise  (SgIn  >sõja+keeris !09_S
45096	osatäitjate	täitja	osa+täitja	01_S	PlG	et	osatäitjate =täitja  (PlG  >osa+täitja !01_S
45097	teatrinäitlejaid	näitleja	teatri+näitleja	01_S	PlP	et	teatrinäitlejaid =näitleja  (PlP  >teatri+näitleja !01_S
45105	stsenaariumiks	stsenaariumi	stsenaarium	19~02_S	SgTr	et	stsenaariumiks =stsenaariumi  (SgTr  >stsenaarium !19~02_S
45106	hüples	hüple	hüplema	30_V	IndIpfSg3	et	hüples =hüple  (IndIpfSg3  >hüplema !30_V
45107	stseenilt	stseeni	stseen	22_S	SgAbl	et	stseenilt =stseeni  (SgAbl  >stseen !22_S
45117	mõtestama	mõtesta	mõtestama	27_V	Sup	et	mõtestama =mõtesta  (Sup  >mõtestama !27_V
45124	hukk	hukk	hukk	22_S	SgN	et	hukk =hukk  (SgN  >hukk !22_S
45126	klassivõitluse	võitluse	klassi+võitlus	11~09_S	SgG	et	klassivõitluse =võitluse  (SgG  >klassi+võitlus !11~09_S
45127	kangelaslik	kangelaslik	kangelaslik	25_A	SgN	et	kangelaslik =kangelaslik  (SgN  >kangelaslik !25_A
45129	pealetung	tung	peale+tung	22_S	SgN	et	pealetung =tung  (SgN  >peale+tung !22_S
45138	utoopiline	utoopiline	utoopiline	12_A	SgN	et	utoopiline =utoopiline  (SgN  >utoopiline !12_A
45140	südame	südame	süda	04_S	SgG	et	südame =südame  (SgG  >süda !04_S
45153	kinotükk	tükk	kino+tükk	22_S	SgN	et	kinotükk =tükk  (SgN  >kino+tükk !22_S
45155	kaitseväe	väe	kaitse+vägi	21_S	SgG	et	kaitseväe =väe  (SgG  >kaitse+vägi !21_S
45156	prominendid	prominendi	prominent	22_S	PlN	et	prominendid =prominendi  (PlN  >prominent !22_S
45165	sõjafilm	film	sõja+film	22_S	SgN	et	sõjafilm =film  (SgN  >sõja+film !22_S
45166	realistlikke	realistlikke	realistlik	25_A	PlP	et	realistlikke =realistlikke  (PlP  >realistlik !25_A
45168	järjekordne	kordne	järje+kordne	02_AS	SgN	et	järjekordne =kordne  (SgN  >järje+kordne !02_AS
45169	enamikkes	ikke	enam+ike	06_S	SgIn	et	enamikkes =ikke  (SgIn  >enam+ike !06_S
45173	osatäitjad	täitja	osa+täitja	01_S	PlN	et	osatäitjad =täitja  (PlN  >osa+täitja !01_S
45178	massidele	massi	mass	22_S	PlAll	et	massidele =massi  (PlAll  >mass !22_S
45179	teemalt	teema	teema	16_S	SgAbl	et	teemalt =teema  (SgAbl  >teema !16_S
45193	nägemust	nägemus	nägemus	11_S	SgP	et	nägemust =nägemus  (SgP  >nägemus !11_S
45200	saadiku	saadiku	saadik	02_S	SgG	et	saadiku =saadiku  (SgG  >saadik !02_S
45204	kihutuskirjandust	kirjandus	kihutus+kirjandus	11_S	SgP	et	kihutuskirjandust =kirjandus  (SgP  >kihutus+kirjandus !11_S
45210	lähedastele	lähedas	lähedane	12_AS	PlAll	et	lähedastele =lähedas  (PlAll  >lähedane !12_AS
45214	mitteinimlik	inimlik	mitte+inimlik	25_A	SgN	et	mitteinimlik =inimlik  (SgN  >mitte+inimlik !25_A
45216	käidaks	käi	käima	38_V	KndPrIps	et	käidaks =käi  (KndPrIps  >käima !38_V
45222	meelelahutuslik	lahutuslik	meele+lahutuslik	25_A	SgN	et	meelelahutuslik =lahutuslik  (SgN  >meele+lahutuslik !25_A
45226	organisaator	organisaator	organisaator	02_S	SgN	et	organisaator =organisaator  (SgN  >organisaator !02_S
45228	humanistliku	humanistliku	humanistlik	25_A	SgG	et	humanistliku =humanistliku  (SgG  >humanistlik !25_A
45229	usurpeerib	usurpeeri	usurpeerima	28_V	IndPrSg3	et	usurpeerib =usurpeeri  (IndPrSg3  >usurpeerima !28_V
45233	inimlik	inimlik	inimlik	25_A	SgN	et	inimlik =inimlik  (SgN  >inimlik !25_A
45133	tõtu	tõtu	tõtt	22_S	SgG	et	tõtu =tõtu  (SgG  >tõtt !22_S
45135	radikaalse	radikaalse	radikaalne	02_A	SgG	et	radikaalse =radikaalse  (SgG  >radikaalne !02_A
45137	väljakuulutamisega	kuulutamise	välja+kuulutamine	12_S	SgKom	et	väljakuulutamisega =kuulutamise  (SgKom  >välja+kuulutamine !12_S
45139	kommunistidega	kommunisti	kommunist	22_S	PlKom	et	kommunistidega =kommunisti  (PlKom  >kommunist !22_S
45141	äraootavale	ootava	ära+ootav	02_A	SgAll	et	äraootavale =ootava  (SgAll  >ära+ootav !02_A
45145	üldhariduskoolides	kooli	üld+haridus+kool	22_S	PlIn	et	üldhariduskoolides =kooli  (PlIn  >üld+haridus+kool !22_S
45164	kassarekordeid	rekorde	kassa+rekord	02_S	PlP	et	kassarekordeid =rekorde  (PlP  >kassa+rekord !02_S
45167	viimastest	viimas	viimane	10_A	PlEl	et	viimastest =viimas  (PlEl  >viimane !10_A
45170	tollaseid	tollase	tollane	10_A	PlP	et	tollaseid =tollase  (PlP  >tollane !10_A
45175	kunstiteose	teose	kunsti+teos	09_S	SgG	et	kunstiteose =teose  (SgG  >kunsti+teos !09_S
45176	osades	osa	osa	17_S	PlIn	et	osades =osa  (PlIn  >osa !17_S
45183	optimistlikuna	optimistliku	optimistlik	25_A	SgEs	et	optimistlikuna =optimistliku  (SgEs  >optimistlik !25_A
45198	suur-eestist	eesti	suur-eesti	16_H	SgEl	et	suur-eestist =eesti  (SgEl  >suur-eesti !16_H
45199	koostööpakkumisega	pakkumise	koos+töö+pakkumine	12_S	SgKom	et	koostööpakkumisega =pakkumise  (SgKom  >koos+töö+pakkumine !12_S
45203	agendi	agendi	agent	22_S	SgG	et	agendi =agendi  (SgG  >agent !22_S
45206	rahadega	raha	raha	17_S	PlKom	et	rahadega =raha  (PlKom  >raha !17_S
45241	tsaaririigi	riigi	tsaari+riik	22_S	SgG	et	tsaaririigi =riigi  (SgG  >tsaari+riik !22_S
45246	katkestas	katkesta	katkestama	27_V	IndIpfSg3	et	katkestas =katkesta  (IndIpfSg3  >katkestama !27_V
45250	õppetunnid	tunni	õppe+tund	22_S	PlN	et	õppetunnid =tunni  (PlN  >õppe+tund !22_S
45252	aspektist	aspekti	aspekt	22_S	SgEl	et	aspektist =aspekti  (SgEl  >aspekt !22_S
45253	idealiseeriti	idealiseeri	idealiseerima	28_V	IndIpfIps	et	idealiseeriti =idealiseeri  (IndIpfIps  >idealiseerima !28_V
45263	patrioot	patrioot	patrioot	22_S	SgN	et	patrioot =patrioot  (SgN  >patrioot !22_S
45278	igaühet	ühe	iga+ühe	06_S	SgP	et	igaühet =ühe  (SgP  >iga+ühe !06_S
45280	teisikutega	teisiku	teisik	02_S	PlKom	et	teisikutega =teisiku  (PlKom  >teisik !02_S
45282	õpingutel	õpingu	õping	02_S	PlAd	et	õpingutel =õpingu  (PlAd  >õping !02_S
45284	teisikutele	teisiku	teisik	02_S	PlAll	et	teisikutele =teisiku  (PlAll  >teisik !02_S
45285	ohu	ohu	oht	22_S	SgG	et	ohu =ohu  (SgG  >oht !22_S
45293	peatub	peatu	peatuma	27_V	IndPrSg3	et	peatub =peatu  (IndPrSg3  >peatuma !27_V
45297	kaasaitamisel	aitamise	kaas+aitamine	12_S	SgAd	et	kaasaitamisel =aitamise  (SgAd  >kaas+aitamine !12_S
45298	keiserlik	keiserlik	keiserlik	25_A	SgN	et	keiserlik =keiserlik  (SgN  >keiserlik !25_A
45308	koomiline	koomiline	koomiline	12_A	SgN	et	koomiline =koomiline  (SgN  >koomiline !12_A
45309	miimikat	miimika	miimika	01_S	SgP	et	miimikat =miimika  (SgP  >miimika !01_S
45317	teistkordsel	kordse	teist+kordne	02_AS	SgAd	et	teistkordsel =kordse  (SgAd  >teist+kordne !02_AS
45327	filmisse	filmi	film	22_S	SgIll	et	filmisse =filmi  (SgIll  >film !22_S
45328	seletatakse	seleta	seletama	27_V	IndPrIps	et	seletatakse =seleta  (IndPrIps  >seletama !27_V
45345	püksile	püksi	püks	23?22_S	SgAll	et	püksile =püksi  (SgAll  >püks !23?22_S
45363	difteeriale	difteeria	difteeria	01_S	SgAll	et	difteeriale =difteeria  (SgAll  >difteeria !01_S
45364	jõudmas	jõud	jõudma	34_V	SupIn	et	jõudmas =jõud  (SupIn  >jõudma !34_V
45365	mõnusasti	mõnusasti	mõnusasti	41_D	ID	et	mõnusasti =mõnusasti  (ID  >mõnusasti !41_D
45367	ilusade	sade	ilu+sade	04_S	SgN	et	ilusade =sade  (SgN  >ilu+sade !04_S
45369	igatühte	ühte	igat+ühe	06_S	SgG	et	igatühte =ühte  (SgG  >igat+ühe !06_S
45377	odavate	odava	odav	02_A	PlG	et	odavate =odava  (PlG  >odav !02_A
45391	väljatöötamise	töötamise	välja+töötamine	12_S	SgG	et	väljatöötamise =töötamise  (SgG  >välja+töötamine !12_S
45392	kõrvaldati	kõrvalda	kõrvaldama	27_V	IndIpfIps	et	kõrvaldati =kõrvalda  (IndIpfIps  >kõrvaldama !27_V
45398	järeltulijate	tulija	järel+tulija	01_S	PlG	et	järeltulijate =tulija  (PlG  >järel+tulija !01_S
45404	vastaspervedel	perve	vastas+perv	22_S	PlAd	et	vastaspervedel =perve  (PlAd  >vastas+perv !22_S
45413	ettekandena	kande	ette+kanne	06_S	SgEs	et	ettekandena =kande  (SgEs  >ette+kanne !06_S
45427	õigusmõisnik	mõisnik	õigus+mõisnik	25_S	SgN	et	õigusmõisnik =mõisnik  (SgN  >õigus+mõisnik !25_S
45428	paljutõotavatele	tõotava	palju+tõotav	02_A	PlAll	et	paljutõotavatele =tõotava  (PlAll  >palju+tõotav !02_A
45429	võimalustele	võimalus	võimalus	11_S	PlAll	et	võimalustele =võimalus  (PlAll  >võimalus !11_S
45432	ööedud	edu	öö+edu	17_S	PlN	et	ööedud =edu  (PlN  >öö+edu !17_S
45435	võimudele	võimu	võim	22_S	PlAll	et	võimudele =võimu  (PlAll  >võim !22_S
45136	ideoloogias	ideoloogia	ideoloogia	01_S	SgIn	et	ideoloogias =ideoloogia  (SgIn  >ideoloogia !01_S
45142	kirgedel	kirge	kirg	22_S	PlAd	et	kirgedel =kirge  (PlAd  >kirg !22_S
45143	lüüa	lüü	lööma	38_V	Inf	et	lüüa =lüü  (Inf  >lööma !38_V
45144	kassarekordite	rekordi	kassa+rekord	02_S	PlG	et	kassarekordite =rekordi  (PlG  >kassa+rekord !02_S
45149	vabadussõjaaegses	aegse	vabadus+sõja+aegne	02_A	SgIn	et	vabadussõjaaegses =aegse  (SgIn  >vabadus+sõja+aegne !02_A
45151	kasvamas	kasva	kasvama	28_V	SupIn	et	kasvamas =kasva  (SupIn  >kasvama !28_V
45154	pessimistlik	pessimistlik	pessimistlik	25_A	SgN	et	pessimistlik =pessimistlik  (SgN  >pessimistlik !25_A
45157	banaalne	banaalne	banaalne	02_A	SgN	et	banaalne =banaalne  (SgN  >banaalne !02_A
45174	tollasest	tollase	tollane	10_A	SgEl	et	tollasest =tollase  (SgEl  >tollane !10_A
45189	süfiliitik	süfiliitik	süfiliitik	02_S	SgN	et	süfiliitik =süfiliitik  (SgN  >süfiliitik !02_S
45190	abikaasana	kaasa	abi+kaasa	16_S	SgEs	et	abikaasana =kaasa  (SgEs  >abi+kaasa !16_S
45191	patrioodina	patrioodi	patrioot	22_S	SgEs	et	patrioodina =patrioodi  (SgEs  >patrioot !22_S
45192	saaremäe	mäe	saare+mägi	21_S	SgG	et	saaremäe =mäe  (SgG  >saare+mägi !21_S
45202	saatkond	saatkond	saatkond	22_S	SgN	et	saatkond =saatkond  (SgN  >saatkond !22_S
45208	julgeoleku	oleku	julge+olek	02_S	SgG	et	julgeoleku =oleku  (SgG  >julge+olek !02_S
45209	koopiaid	koopia	koopia	01_S	PlP	et	koopiaid =koopia  (PlP  >koopia !01_S
45212	väljaõpetamine	õpetamine	välja+õpetamine	12_S	SgN	et	väljaõpetamine =õpetamine  (SgN  >välja+õpetamine !12_S
45225	teisikut	teisiku	teisik	02_S	SgP	et	teisikut =teisiku  (SgP  >teisik !02_S
45227	loomuse	loomuse	loomus	11~09_S	SgG	et	loomuse =loomuse  (SgG  >loomus !11~09_S
45234	lüüriline	lüüriline	lüüriline	12_A	SgN	et	lüüriline =lüüriline  (SgN  >lüüriline !12_A
45237	äravahetamisel	vahetamise	ära+vahetamine	12_S	SgAd	et	äravahetamisel =vahetamise  (SgAd  >ära+vahetamine !12_S
45238	kogesin	koge	kogema	27_V	IndIpfSg1	et	kogesin =koge  (IndIpfSg1  >kogema !27_V
45242	jäänustele	jäänus	jäänus	09_S	PlAll	et	jäänustele =jäänus  (PlAll  >jäänus !09_S
45255	pöörded	pöörde	pööre	06_S	PlN	et	pöörded =pöörde  (PlN  >pööre !06_S
45259	keerukad	keeruka	keerukas	02_A	PlN	et	keerukad =keeruka  (PlN  >keerukas !02_A
45267	mängud	mängu	mäng	22_S	PlN	et	mängud =mängu  (PlN  >mäng !22_S
45272	võimsale	võimsa	võimas	03~05_A	SgAll	et	võimsale =võimsa  (SgAll  >võimas !03~05_A
45273	ehtsad	ehtsa	ehtne	02_A	PlN	et	ehtsad =ehtsa  (PlN  >ehtne !02_A
45275	ülestõusud	tõusu	üles+tõus	22_S	PlN	et	ülestõusud =tõusu  (PlN  >üles+tõus !22_S
45291	võimsat	võimsa	võimas	03_A	SgP	et	võimsat =võimsa  (SgP  >võimas !03_A
45300	murda	murd	murdma	34_V	Inf	et	murda =murd  (Inf  >murdma !34_V
45302	revolutsionääre	revolutsionääre	revolutsionäär	22_S	PlP	et	revolutsionääre =revolutsionääre  (PlP  >revolutsionäär !22_S
45307	parajat	paraja	paras	02_A	SgP	et	parajat =paraja  (SgP  >paras !02_A
45312	dokumentaalfilmidest	filmi	dokumentaal+film	22_S	PlEl	et	dokumentaalfilmidest =filmi  (PlEl  >dokumentaal+film !22_S
45313	juhile	juhi	juht	22_S	SgAll	et	juhile =juhi  (SgAll  >juht !22_S
45315	muljetavaldavalt	avaldava	muljet+avaldav	02_A	SgAbl	et	muljetavaldavalt =avaldava  (SgAbl  >muljet+avaldav !02_A
45316	analoogses	analoogse	analoogne	02_A	SgIn	et	analoogses =analoogse  (SgIn  >analoogne !02_A
45321	laagrid	laagri	laager	02_S	PlN	et	laagrid =laagri  (PlN  >laager !02_S
45322	loosungiks	loosungi	loosung	02_S	SgTr	et	loosungiks =loosungi  (SgTr  >loosung !02_S
45325	kriitiliseks	kriitilise	kriitiline	12_A	SgTr	et	kriitiliseks =kriitilise  (SgTr  >kriitiline !12_A
45331	toredast	toreda	tore	02_A	SgEl	et	toredast =toreda  (SgEl  >tore !02_A
45332	niisugusena	suguse	nii+sugune	10_P	SgEs	et	niisugusena =suguse  (SgEs  >nii+sugune !10_P
45335	ideisse	ide	idee	26_S	PlIll	et	ideisse =ide  (PlIll  >idee !26_S
45341	lapsemäng	mäng	lapse+mäng	22_S	SgN	et	lapsemäng =mäng  (SgN  >lapse+mäng !22_S
45344	hingame	hinga	hingama	29_V	IndPrPl1	et	hingame =hinga  (IndPrPl1  >hingama !29_V
45346	näin	näi	näima	37_V	IndPrSg1	et	näin =näi  (IndPrSg1  >näima !37_V
45349	valmistud	valmistu	valmistuma	27_V	IndPrSg2	et	valmistud =valmistu  (IndPrSg2  >valmistuma !27_V
45351	üllatud	üllatu	üllatuma	27_V	IndPrSg2	et	üllatud =üllatu  (IndPrSg2  >üllatuma !27_V
45357	ilusast	ilusa	ilus	02_A	SgEl	et	ilusast =ilusa  (SgEl  >ilus !02_A
45358	püksist	püksi	püks	23?22_S	SgEl	et	püksist =püksi  (SgEl  >püks !23?22_S
45362	kiirtest	kiir	kiir	13_S	PlEl	et	kiirtest =kiir  (PlEl  >kiir !13_S
45374	õigusjärgsetele	järgse	õigus+järgne	02_A	PlAll	et	õigusjärgsetele =järgse  (PlAll  >õigus+järgne !02_A
45378	keemiat	keemia	keemia	01_S	SgP	et	keemiat =keemia  (SgP  >keemia !01_S
45184	intiimstseenid	stseeni	intiim+stseen	22_S	PlN	et	intiimstseenid =stseeni  (PlN  >intiim+stseen !22_S
45186	jant	jant	jant	22_S	SgN	et	jant =jant  (SgN  >jant !22_S
45187	elektrik	elektrik	elektrik	02_S	SgN	et	elektrik =elektrik  (SgN  >elektrik !02_S
45188	munk	munk	munk	22_S	SgN	et	munk =munk  (SgN  >munk !22_S
45194	monotoonne	monotoonne	monotoonne	02_A	SgN	et	monotoonne =monotoonne  (SgN  >monotoonne !02_A
45195	emotsioonideta	emotsiooni	emotsioon	22_S	PlAb	et	emotsioonideta =emotsiooni  (PlAb  >emotsioon !22_S
45196	kangeid	kange	kange	01_A	PlP	et	kangeid =kange  (PlP  >kange !01_A
45197	kodusõjaks	sõja	kodu+sõda	18_S	SgTr	et	kodusõjaks =sõja  (SgTr  >kodu+sõda !18_S
45207	asendaks	asenda	asendama	27_V	KndPrPs	et	asendaks =asenda  (KndPrPs  >asendama !27_V
45213	koomilises	koomilise	koomiline	12_A	SgIn	et	koomilises =koomilise  (SgIn  >koomiline !12_A
45221	loode-venemaast	maa	loode-vene+maa	26_S	SgEl	et	loode-venemaast =maa  (SgEl  >loode-vene+maa !26_S
45223	stseenidest	stseeni	stseen	22_S	PlEl	et	stseenidest =stseeni  (PlEl  >stseen !22_S
45224	otsustatakse	otsusta	otsustama	27_V	IndPrIps	et	otsustatakse =otsusta  (IndPrIps  >otsustama !27_V
45230	originaalse	originaalse	originaalne	02_A	SgG	et	originaalse =originaalse  (SgG  >originaalne !02_A
45243	impeeriumid	impeeriumi	impeerium	19~02_S	PlN	et	impeeriumid =impeeriumi  (PlN  >impeerium !19~02_S
45244	rahvusriike	riike	rahvus+riik	22_S	PlP	et	rahvusriike =riike  (PlP  >rahvus+riik !22_S
45249	iroonilisi	iroonilisi	irooniline	12_A	PlP	et	iroonilisi =iroonilisi  (PlP  >irooniline !12_A
45251	äravahetamised	vahetamise	ära+vahetamine	12_S	PlN	et	äravahetamised =vahetamise  (PlN  >ära+vahetamine !12_S
45254	tegudega	tegu	tegu	18_S	PlKom	et	tegudega =tegu  (PlKom  >tegu !18_S
45258	keerukad	keeruka	keerukas	02_A	PlN	et	keerukad =keeruka  (PlN  >keerukas !02_A
45264	suur-eestit	eesti	suur-eesti	16_H	SgP	et	suur-eestit =eesti  (SgP  >suur-eesti !16_H
45268	valitsemisviis	viis	valitsemis+viis	22_S	SgN	et	valitsemisviis =viis  (SgN  >valitsemis+viis !22_S
45270	sakslaselt	sakslase	sakslane	12?10_S	SgAbl	et	sakslaselt =sakslase  (SgAbl  >sakslane !12?10_S
45277	meestetöid	tö	meeste+töö	26_S	PlP	et	meestetöid =tö  (PlP  >meeste+töö !26_S
45286	kajutisse	kajuti	kajut	02_S	SgIll	et	kajutisse =kajuti  (SgIll  >kajut !02_S
45287	teisikus	teisiku	teisik	02_S	SgIn	et	teisikus =teisiku  (SgIn  >teisik !02_S
45295	panusel	panuse	panus	09_S	SgAd	et	panusel =panuse  (SgAd  >panus !09_S
45301	tsaarivastaseid	vastase	tsaari+vastane	10_AS	PlP	et	tsaarivastaseid =vastase  (PlP  >tsaari+vastane !10_AS
45303	revolutsionäärid	revolutsionääri	revolutsionäär	22_S	PlN	et	revolutsionäärid =revolutsionääri  (PlN  >revolutsionäär !22_S
45310	kõnepidamist	pidamis	kõne+pidamine	12_S	SgP	et	kõnepidamist =pidamis  (SgP  >kõne+pidamine !12_S
45311	rollid	rolli	roll	22_S	PlN	et	rollid =rolli  (PlN  >roll !22_S
45314	paroodiana	paroodia	paroodia	01_S	SgEs	et	paroodiana =paroodia  (SgEs  >paroodia !01_S
45320	pilkas	pilka	pilkama	29_V	IndIpfSg3	et	pilkas =pilka  (IndIpfSg3  >pilkama !29_V
45330	nsvl-is	nsvl	nsvl	xx_Q	SgIn	et	nsvl-is =nsvl  (SgIn  >nsvl !xx_Q
45338	lollid	lolli	loll	22_AS	PlN	et	lollid =lolli  (PlN  >loll !22_AS
45342	korralikuga	korraliku	korralik	25_A	SgKom	et	korralikuga =korraliku  (SgKom  >korralik !25_A
45343	kütma	küt	kütma	35_V	Sup	et	kütma =küt  (Sup  >kütma !35_V
45352	siberiast	ast	siberi+ast	22_S	SgN	et	siberiast =ast  (SgN  >siberi+ast !22_S
45359	külmetama	külmeta	külmetama	27_V	Sup	et	külmetama =külmeta  (Sup  >külmetama !27_V
45366	mahlakati	kati	mahla+katt	22_S	SgG	et	mahlakati =kati  (SgG  >mahla+katt !22_S
45372	pükstel	püks	püks	23_S	PlAd	et	pükstel =püks  (PlAd  >püks !23_S
45379	importtoiduainete	aine	import+toidu+aine	06_S	PlG	et	importtoiduainete =aine  (PlG  >import+toidu+aine !06_S
45386	vangilaagrid	laagri	vangi+laager	02_S	PlN	et	vangilaagrid =laagri  (PlN  >vangi+laager !02_S
45390	tagasiandmine	andmine	tagasi+andmine	12?10_S	SgN	et	tagasiandmine =andmine  (SgN  >tagasi+andmine !12?10_S
45394	sulada	sula	sulama	27_V	Inf	et	sulada =sula  (Inf  >sulama !27_V
45395	peakomitees	komitee	pea+komitee	26_S	SgIn	et	peakomitees =komitee  (SgIn  >pea+komitee !26_S
45396	nägemus	nägemus	nägemus	11_S	SgN	et	nägemus =nägemus  (SgN  >nägemus !11_S
45407	baltisakslasi	sakslasi	balti+sakslane	12_S	PlP	et	baltisakslasi =sakslasi  (PlP  >balti+sakslane !12_S
45412	eepos	eepos	eepos	11~09_S	SgN	et	eepos =eepos  (SgN  >eepos !11~09_S
45418	linnakodanikest	kodanike	linna+kodanik	25_S	PlEl	et	linnakodanikest =kodanike  (PlEl  >linna+kodanik !25_S
45423	harida	hari	harima	27_V	Inf	et	harida =hari  (Inf  >harima !27_V
45434	keisririigi	riigi	keisri+riik	22_S	SgG	et	keisririigi =riigi  (SgG  >keisri+riik !22_S
45436	kubjaste	kubjas	kubjas	07_S	PlG	et	kubjaste =kubjas  (PlG  >kubjas !07_S
45235	armsa	armsa	armas	03~05_A	SgG	et	armsa =armsa  (SgG  >armas !03~05_A
45245	imperialistliku	imperialistliku	imperialistlik	25_A	SgG	et	imperialistliku =imperialistliku  (SgG  >imperialistlik !25_A
45247	suurest-eestimaast	maa	suurest-eesti+maa	26_S	SgEl	et	suurest-eestimaast =maa  (SgEl  >suurest-eesti+maa !26_S
45256	türann	türann	türann	22_S	SgN	et	türann =türann  (SgN  >türann !22_S
45257	miljonid	miljoni	miljon	02_N	PlN	et	miljonid =miljoni  (PlN  >miljon !02_N
45261	väljamõeldis	mõeldis	välja+mõeldis	11~09_S	SgN	et	väljamõeldis =mõeldis  (SgN  >välja+mõeldis !11~09_S
45262	imestas	imesta	imestama	27_V	IndIpfSg3	et	imestas =imesta  (IndIpfSg3  >imestama !27_V
45265	revolutsionääriks	revolutsionääri	revolutsionäär	22_S	SgTr	et	revolutsionääriks =revolutsionääri  (SgTr  >revolutsionäär !22_S
45266	mõjuavaldavalt	avaldava	mõju+avaldav	02_A	SgAbl	et	mõjuavaldavalt =avaldava  (SgAbl  >mõju+avaldav !02_A
45269	elluviimist	viimis	ellu+viimine	12?10_S	SgP	et	elluviimist =viimis  (SgP  >ellu+viimine !12?10_S
45271	patriootlikud	patriootliku	patriootlik	25_A	PlN	et	patriootlikud =patriootliku  (PlN  >patriootlik !25_A
45276	praegusele	praeguse	praegune	10~12_A	SgAll	et	praegusele =praeguse  (SgAll  >praegune !10~12_A
45279	monarhiat	monarhia	monarhia	01_S	SgP	et	monarhiat =monarhia  (SgP  >monarhia !01_S
45281	mängureeglid	reegli	mängu+reegel	02_S	PlN	et	mängureeglid =reegli  (PlN  >mängu+reegel !02_S
45288	manipuleeriti	manipuleeri	manipuleerima	28_V	IndIpfIps	et	manipuleeriti =manipuleeri  (IndIpfIps  >manipuleerima !28_V
45290	ebameeldivad	meeldiva	eba+meeldiv	02_A	PlN	et	ebameeldivad =meeldiva  (PlN  >eba+meeldiv !02_A
45294	isikul	isiku	isik	02_S	SgAd	et	isikul =isiku  (SgAd  >isik !02_S
45296	ettevalmistamise	valmistamise	ette+valmistamine	12_S	SgG	et	ettevalmistamise =valmistamise  (SgG  >ette+valmistamine !12_S
45299	rinne	rinne	rinne	06_S	SgN	et	rinne =rinne  (SgN  >rinne !06_S
45304	vaiksest	vaikse	vaikne	02_A	SgEl	et	vaiksest =vaikse  (SgEl  >vaikne !02_A
45305	ookeanist	ookeani	ookean	19_S	SgEl	et	ookeanist =ookeani  (SgEl  >ookean !19_S
45306	koomilise	koomilise	koomiline	12_A	SgG	et	koomilise =koomilise  (SgG  >koomiline !12_A
45319	keelas	keela	keelama	29_V	IndIpfSg3	et	keelas =keela  (IndIpfSg3  >keelama !29_V
45323	eesmärgidest	märgi	ees+märg	22_AS	PlEl	et	eesmärgidest =märgi  (PlEl  >ees+märg !22_AS
45334	tutvungi	tutvu	tutvuma	27_V	IndPrSg1^	et	tutvungi =tutvu  (IndPrSg1^  >tutvuma !27_V
45336	isevalitsuse	valitsuse	ise+valitsus	11_S	SgG	et	isevalitsuse =valitsuse  (SgG  >ise+valitsus !11_S
45337	võimalusega	võimaluse	võimalus	11_S	SgKom	et	võimalusega =võimaluse  (SgKom  >võimalus !11_S
45350	igaüksele	ükse	iga+üks	22_P	PlAll	et	igaüksele =ükse  (PlAll  >iga+üks !22_P
45355	naerad	naera	naerma	33_V	IndPrSg2	et	naerad =naera  (IndPrSg2  >naerma !33_V
45356	igaühed	ühe	iga+üks	22_P	PlN	et	igaühed =ühe  (PlN  >iga+üks !22_P
45360	kuid-ehk	ehk	kuid-ehk	41_JD	ID	et	kuid-ehk =ehk  (ID  >kuid-ehk !41_JD
45361	puhkehetkede	hetke	puhke+hetk	22_S	PlG	et	puhkehetkede =hetke  (PlG  >puhke+hetk !22_S
45368	valmistumas	valmistu	valmistuma	27_V	SupIn	et	valmistumas =valmistu  (SupIn  >valmistuma !27_V
45370	maanduge	maandu	maanduma	27_V	ImpPrPl2	et	maanduge =maandu  (ImpPrPl2  >maanduma !27_V
45376	vabakaubanduslepingu	lepingu	vaba+kaubandus+leping	02_S	SgG	et	vabakaubanduslepingu =lepingu  (SgG  >vaba+kaubandus+leping !02_S
45380	kolhoosivarade	vara	kolhoosi+vara	17_S	PlG	et	kolhoosivarade =vara  (PlG  >kolhoosi+vara !17_S
45389	maailmaklassikat	klassika	maa+ilma+klassika	01_S	SgP	et	maailmaklassikat =klassika  (SgP  >maa+ilma+klassika !01_S
45393	saksameelne	meelne	saksa+meelne	02_A	SgN	et	saksameelne =meelne  (SgN  >saksa+meelne !02_A
45397	võimudega	võimu	võim	22_S	PlKom	et	võimudega =võimu  (PlKom  >võim !22_S
45400	ärkamisajas	aja	ärkamis+aeg	22_S	SgIn	et	ärkamisajas =aja  (SgIn  >ärkamis+aeg !22_S
45401	hurdal	hurda	hurt	22_S	SgAd	et	hurdal =hurda  (SgAd  >hurt !22_S
45402	liidriks	liidri	liider	02_S	SgTr	et	liidriks =liidri  (SgTr  >liider !02_S
45403	eemaldama	eemalda	eemaldama	27_V	Sup	et	eemaldama =eemalda  (Sup  >eemaldama !27_V
45411	müütide	müüti	müüt	22_S	PlG	et	müütide =müüti  (PlG  >müüt !22_S
45414	kalendreid	kalendre	kalender	02_S	PlP	et	kalendreid =kalendre  (PlP  >kalender !02_S
45415	kättesaadavad	saadava	kätte+saadav	02_A	PlN	et	kättesaadavad =saadava  (PlN  >kätte+saadav !02_A
45421	sisuks	sisu	sisu	17_S	SgTr	et	sisuks =sisu  (SgTr  >sisu !17_S
45425	talupoegadesse	poega	talu+poeg	22_S	PlIll	et	talupoegadesse =poega  (PlIll  >talu+poeg !22_S
45431	tagasiandmist	andmis	tagasi+andmine	12?10_S	SgP	et	tagasiandmist =andmis  (SgP  >tagasi+andmine !12?10_S
45439	kirjamehed	mehe	kirja+mees	13_S	PlN	et	kirjamehed =mehe  (PlN  >kirja+mees !13_S
45443	hõbemünte	münte	hõbe+münt	22_S	PlP	et	hõbemünte =münte  (PlP  >hõbe+münt !22_S
45283	impulsiivsena	impulsiivse	impulsiivne	02_A	SgEs	et	impulsiivsena =impulsiivse  (SgEs  >impulsiivne !02_A
45289	maailmategijad	tegija	maa+ilma+tegija	01_S	PlN	et	maailmategijad =tegija  (PlN  >maa+ilma+tegija !01_S
45292	kukutada	kukuta	kukutama	27_V	Inf	et	kukutada =kukuta  (Inf  >kukutama !27_V
45318	kommunistlikuks	kommunistliku	kommunistlik	25_A	SgTr	et	kommunistlikuks =kommunistliku  (SgTr  >kommunistlik !25_A
45324	ebakindlas	kindla	eba+kindel	02_A	SgIn	et	ebakindlas =kindla  (SgIn  >eba+kindel !02_A
45326	leeninid	ini	leen+ini	17_S	PlN	et	leeninid =ini  (PlN  >leen+ini !17_S
45329	haridustase	tase	haridus+tase	04_S	SgN	et	haridustase =tase  (SgN  >haridus+tase !04_S
45333	juhtidele	juhti	juht	22_S	PlAll	et	juhtidele =juhti  (PlAll  >juht !22_S
45339	mõistusega	mõistuse	mõistus	11~09_S	SgKom	et	mõistusega =mõistuse  (SgKom  >mõistus !11~09_S
45340	kaastegijatega	tegija	kaas+tegija	01_S	PlKom	et	kaastegijatega =tegija  (PlKom  >kaas+tegija !01_S
45347	töökohte	kohte	töö+koht	22_S	PlP	et	töökohte =kohte  (PlP  >töö+koht !22_S
45348	muudatuses	muudatuse	muudatus	11_S	SgIn	et	muudatuses =muudatuse  (SgIn  >muudatus !11_S
45353	mahlakad	mahlaka	mahlakas	02_A	PlN	et	mahlakad =mahlaka  (PlN  >mahlakas !02_A
45354	tõime	tõ	tooma	38_V	IndIpfPl1	et	tõime =tõ  (IndIpfPl1  >tooma !38_V
45371	muudatustel	muudatus	muudatus	11_S	PlAd	et	muudatustel =muudatus  (PlAd  >muudatus !11_S
45373	naistesse	nais	naine	12_S	PlIll	et	naistesse =nais  (PlIll  >naine !12_S
45375	täieõiguslikuks	õigusliku	täie+õiguslik	25_A	SgTr	et	täieõiguslikuks =õigusliku  (SgTr  >täie+õiguslik !25_A
45381	laialijagamine	jagamine	laiali+jagamine	12_S	SgN	et	laialijagamine =jagamine  (SgN  >laiali+jagamine !12_S
45384	ajutisi	ajutisi	ajutine	12_A	PlP	et	ajutisi =ajutisi  (PlP  >ajutine !12_A
45385	karpmaju	maju	karp+maja	17_S	PlP	et	karpmaju =maju  (PlP  >karp+maja !17_S
45399	üleandmisega	andmise	üle+andmine	12?10_S	SgKom	et	üleandmisega =andmise  (SgKom  >üle+andmine !12?10_S
45409	huviobjektiks	objekti	huvi+objekt	22_S	SgTr	et	huviobjektiks =objekti  (SgTr  >huvi+objekt !22_S
45410	valgustuskirjanduse	kirjanduse	valgustus+kirjandus	11_S	SgG	et	valgustuskirjanduse =kirjanduse  (SgG  >valgustus+kirjandus !11_S
45417	kõrgem-ametnikud	ametniku	kõrgem-ametnik	25_S	PlN	et	kõrgem-ametnikud =ametniku  (PlN  >kõrgem-ametnik !25_S
45420	kohalehäbimärk	märk	kohale+häbi+märk	22_S	SgN	et	kohalehäbimärk =märk  (SgN  >kohale+häbi+märk !22_S
45422	ülesanneteks	anne	üles+anne	06_S	PlTr	et	ülesanneteks =anne  (PlTr  >üles+anne !06_S
45424	esikaant	kaan	esi+kaas	14_S	SgP	et	esikaant =kaan  (SgP  >esi+kaas !14_S
45437	allutada	alluta	allutama	27_V	Inf	et	allutada =alluta  (Inf  >allutama !27_V
45446	väesse	väe	vägi	21_S	SgIll	et	väesse =väe  (SgIll  >vägi !21_S
45455	puutudes	puutu	puutuma	27_V	Ger	et	puutudes =puutu  (Ger  >puutuma !27_V
45456	tutvuti	tutvu	tutvuma	27_V	IndIpfIps	et	tutvuti =tutvu  (IndIpfIps  >tutvuma !27_V
45459	tammikus	tammiku	tammik	02_S	SgIn	et	tammikus =tammiku  (SgIn  >tammik !02_S
45463	viikingite	viikingi	viiking	02_S	PlG	et	viikingite =viikingi  (PlG  >viiking !02_S
45465	kauba-	kauba	kaup	22_S	SgG	et	kauba- =kauba  (SgG  >kaup !22_S
45467	sõjakäikudelt	käiku	sõja+käik	22_S	PlAbl	et	sõjakäikudelt =käiku  (PlAbl  >sõja+käik !22_S
45468	riidesortide	sorti	riide+sort	22_S	PlG	et	riidesortide =sorti  (PlG  >riide+sort !22_S
45475	ruunikivid	kivi	ruuni+kivi	17_S	PlN	et	ruunikivid =kivi  (PlN  >ruuni+kivi !17_S
45476	vastukäike	käike	vastu+käik	22_S	PlP	et	vastukäike =käike  (PlP  >vastu+käik !22_S
45479	slaavlastelt	slaavlas	slaavlane	12?10_S	PlAbl	et	slaavlastelt =slaavlas  (PlAbl  >slaavlane !12?10_S
45482	sõjakäikudel	käiku	sõja+käik	22_S	PlAd	et	sõjakäikudel =käiku  (PlAd  >sõja+käik !22_S
45484	kultuurisse	kultuuri	kultuur	22_S	SgIll	et	kultuurisse =kultuuri  (SgIll  >kultuur !22_S
45488	vibudega	vibu	vibu	17_S	PlKom	et	vibudega =vibu  (PlKom  >vibu !17_S
45498	hüljeste	hüljes	hüljes	07_S	PlG	et	hüljeste =hüljes  (PlG  >hüljes !07_S
45499	mongoliidide	mongoliidi	mongoliid	22_S	PlG	et	mongoliidide =mongoliidi  (PlG  >mongoliid !22_S
45512	äraelatamiseks	elatamise	ära+elatamine	12_S	SgTr	et	äraelatamiseks =elatamise  (SgTr  >ära+elatamine !12_S
45513	okste	oks	oks	23_S	PlG	et	okste =oks  (PlG  >oks !23_S
45518	graniiditükke	tükke	graniidi+tükk	22_S	PlP	et	graniiditükke =tükke  (PlP  >graniidi+tükk !22_S
45524	leiumaterjal	materjal	leiu+materjal	19_S	SgN	et	leiumaterjal =materjal  (SgN  >leiu+materjal !19_S
45525	põhjapõdraküttide	kütti	põhja+põdra+kütt	22_S	PlG	et	põhjapõdraküttide =kütti  (PlG  >põhja+põdra+kütt !22_S
45530	loodusolude	olu	loodus+olu	17_S	PlG	et	loodusolude =olu  (PlG  >loodus+olu !17_S
45535	jõgede	jõge	jõgi	21_S	PlG	et	jõgede =jõge  (PlG  >jõgi !21_S
45536	ritvadest	ritva	ritv	22_S	PlEl	et	ritvadest =ritva  (PlEl  >ritv !22_S
45382	ajateenimises	teenimise	aja+teenimine	12_S	SgIn	et	ajateenimises =teenimise  (SgIn  >aja+teenimine !12_S
45383	riigikorraldusega	korralduse	riigi+korraldus	11_S	SgKom	et	riigikorraldusega =korralduse  (SgKom  >riigi+korraldus !11_S
45387	tõlketeosed	teose	tõlke+teos	09_S	PlN	et	tõlketeosed =teose  (PlN  >tõlke+teos !09_S
45388	keelustada	keelusta	keelustama	27_V	Inf	et	keelustada =keelusta  (Inf  >keelustama !27_V
45405	sotsiaal-majandusliku	majandusliku	sotsiaal-majanduslik	25_A	SgG	et	sotsiaal-majandusliku =majandusliku  (SgG  >sotsiaal-majanduslik !25_A
45406	likvideerida	likvideeri	likvideerima	28_V	Inf	et	likvideerida =likvideeri  (Inf  >likvideerima !28_V
45408	estofiilideks	estofiili	estofiil	22_S	PlTr	et	estofiilideks =estofiili  (PlTr  >estofiil !22_S
45416	maaomand	omand	maa+omand	02_S	SgN	et	maaomand =omand  (SgN  >maa+omand !02_S
45419	aadliku	aadliku	aadlik	25_S	SgG	et	aadliku =aadliku  (SgG  >aadlik !25_S
45426	raamees	ee	raam+esi	15_S	SgIn	et	raamees =ee  (SgIn  >raam+esi !15_S
45430	sakslaseks	sakslase	sakslane	12?10_S	SgTr	et	sakslaseks =sakslase  (SgTr  >sakslane !12?10_S
45433	pärisorjusse	orjus	päris+orjus	11_S	SgAdt	et	pärisorjusse =orjus  (SgAdt  >päris+orjus !11_S
45438	tohtrid	tohtri	tohter	02_S	PlN	et	tohtrid =tohtri  (PlN  >tohter !02_S
45440	eeposeta	eepose	eepos	11~09_S	SgAb	et	eeposeta =eepose  (SgAb  >eepos !11~09_S
45441	mütoloogiaid	mütoloogia	mütoloogia	01_S	PlP	et	mütoloogiaid =mütoloogia  (PlP  >mütoloogia !01_S
45445	lõng	lõng	lõng	22_S	SgN	et	lõng =lõng  (SgN  >lõng !22_S
45449	vajaminevat	mineva	vaja+minev	02_A	SgP	et	vajaminevat =mineva  (SgP  >vaja+minev !02_A
45450	sõjariistu	riistu	sõja+riist	22_S	PlP	et	sõjariistu =riistu  (PlP  >sõja+riist !22_S
45458	hauakividel	kivi	haua+kivi	17_S	PlAd	et	hauakividel =kivi  (PlAd  >haua+kivi !17_S
45462	alepõllunduseks	põllunduse	ale+põllundus	11_S	SgTr	et	alepõllunduseks =põllunduse  (SgTr  >ale+põllundus !11_S
45480	potikeder	keder	poti+keder	24_S	SgN	et	potikeder =keder  (SgN  >poti+keder !24_S
45487	kalanduse	kalanduse	kalandus	11_S	SgG	et	kalanduse =kalanduse  (SgG  >kalandus !11_S
45490	hülgeid	hülge	hüljes	07_S	PlP	et	hülgeid =hülge  (PlP  >hüljes !07_S
45494	teokarpidest	karpi	teo+karp	22_S	PlEl	et	teokarpidest =karpi  (PlEl  >teo+karp !22_S
45497	otri	otri	oder	24_S	PlP	et	otri =otri  (PlP  >oder !24_S
45503	tuhandel	tuhande	tuhat	02_N	SgAd	et	tuhandel =tuhande  (SgAd  >tuhat !02_N
45508	sõjaks	sõja	sõda	18_S	SgTr	et	sõjaks =sõja  (SgTr  >sõda !18_S
45516	sarv-	sarv	sarv	22_S	SgN	et	sarv- =sarv  (SgN  >sarv !22_S
45517	neemeni	neeme	neem	22_S	SgTer	et	neemeni =neeme  (SgTer  >neem !22_S
45522	hahaga	haha	hahk	22_AS	SgKom	et	hahaga =haha  (SgKom  >hahk !22_AS
45529	tarberiistade	riista	tarbe+riist	22_S	PlG	et	tarberiistade =riista  (PlG  >tarbe+riist !22_S
45533	kohapealseid	pealse	koha+pealne	02_AS	PlP	et	kohapealseid =pealse  (PlP  >koha+pealne !02_AS
45538	puukoorte	koor	puu+koor	13_S	PlG	et	puukoorte =koor  (PlG  >puu+koor !13_S
45540	riist	riist	riist	22_S	SgN	et	riist =riist  (SgN  >riist !22_S
45542	õngekonksud	konksu	õnge+konks	22_S	PlN	et	õngekonksud =konksu  (PlN  >õnge+konks !22_S
45548	seente	seen	seen	13_S	PlG	et	seente =seen  (PlG  >seen !13_S
45558	roigastest	roigas	roigas	07_S	PlEl	et	roigastest =roigas  (PlEl  >roigas !07_S
45563	savipotte	potte	savi+pott	22_S	PlP	et	savipotte =potte  (PlP  >savi+pott !22_S
45565	nöörijäljendid	jäljendi	nööri+jäljend	02_S	PlN	et	nöörijäljendid =jäljendi  (PlN  >nööri+jäljend !02_S
45578	riietusmood	mood	riietus+mood	22_S	SgN	et	riietusmood =mood  (SgN  >riietus+mood !22_S
45580	turistidelt	turisti	turist	22_S	PlAbl	et	turistidelt =turisti  (PlAbl  >turist !22_S
45584	koomiksiraamat	raamat	koomiksi+raamat	02_S	SgN	et	koomiksiraamat =raamat  (SgN  >koomiksi+raamat !02_S
45586	vaadati	vaada	vaatama	29_V	IndIpfIps	et	vaadati =vaada  (IndIpfIps  >vaatama !29_V
45587	saadetest	saade	saade	06_S	PlEl	et	saadetest =saade  (PlEl  >saade !06_S
45588	enammeeldinud	meeldinu	enam+meeldinu	01_S	PlN	et	enammeeldinud =meeldinu  (PlN  >enam+meeldinu !01_S
45591	telekoolid	kooli	tele+kool	22_S	PlN	et	telekoolid =kooli  (PlN  >tele+kool !22_S
45593	saadete	saade	saade	06_S	PlG	et	saadete =saade  (PlG  >saade !06_S
45594	külalisteatrid	teatri	külalis+teater	02_S	PlN	et	külalisteatrid =teatri  (PlN  >külalis+teater !02_S
45600	proosale	proosa	proosa	16_S	SgAll	et	proosale =proosa  (SgAll  >proosa !16_S
45605	muusikariistade	riista	muusika+riist	22_S	PlG	et	muusikariistade =riista  (PlG  >muusika+riist !22_S
45609	karakter	karakter	karakter	02_S	SgN	et	karakter =karakter  (SgN  >karakter !02_S
45620	elektritööstus	tööstus	elektri+tööstus	11~09_S	SgN	et	elektritööstus =tööstus  (SgN  >elektri+tööstus !11~09_S
45623	natsionaalsele	natsionaalse	natsionaalne	02_A	SgAll	et	natsionaalsele =natsionaalse  (SgAll  >natsionaalne !02_A
45442	mütoloogiale	mütoloogia	mütoloogia	01_S	SgAll	et	mütoloogiale =mütoloogia  (SgAll  >mütoloogia !01_S
45444	rüüstama	rüüsta	rüüstama	29_V	Sup	et	rüüstama =rüüsta  (Sup  >rüüstama !29_V
45447	jumalani	jumala	jumal	02_S	SgTer	et	jumalani =jumala  (SgTer  >jumal !02_S
45466	röövretkedel	retke	rööv+retk	22_S	PlAd	et	röövretkedel =retke  (PlAd  >rööv+retk !22_S
45478	kaubitsemas	kaubitse	kaubitsema	27_V	SupIn	et	kaubitsemas =kaubitse  (SupIn  >kaubitsema !27_V
45483	periodiseerida	periodiseeri	periodiseerima	28_V	Inf	et	periodiseerida =periodiseeri  (Inf  >periodiseerima !28_V
45489	harpuunidega	harpuuni	harpuun	22_S	PlKom	et	harpuunidega =harpuuni  (PlKom  >harpuun !22_S
45501	segainimestega	inimes	sega+inimene	12_S	PlKom	et	segainimestega =inimes  (PlKom  >sega+inimene !12_S
45504	püstkodade	koda	püst+koda	18_S	PlG	et	püstkodade =koda  (PlG  >püst+koda !18_S
45505	matkida	matki	matkima	28_V	Inf	et	matkida =matki  (Inf  >matkima !28_V
45515	luuesemed	eseme	luu+ese	04_S	PlN	et	luuesemed =eseme  (PlN  >luu+ese !04_S
45519	kausi	kausi	kauss	22_S	SgG	et	kausi =kausi  (SgG  >kauss !22_S
45520	ääred	ääre	äär	13_S	PlN	et	ääred =ääre  (PlN  >äär !13_S
45523	vanakiviaeg	aeg	vana+kivi+aeg	22_S	SgN	et	vanakiviaeg =aeg  (SgN  >vana+kivi+aeg !22_S
45528	põhjapõder	põder	põhja+põder	24_S	SgN	et	põhjapõder =põder  (SgN  >põhja+põder !24_S
45531	kohalikele	kohalike	kohalik	25_AS	PlAll	et	kohalikele =kohalike  (PlAll  >kohalik !25_AS
45534	asukad	asuka	asukas	02_S	PlN	et	asukad =asuka  (PlN  >asukas !02_S
45545	riistad	riista	riist	22_S	PlN	et	riistad =riista  (PlN  >riist !22_S
45547	marjade	marja	mari	24_S	PlG	et	marjade =marja  (PlG  >mari !24_S
45550	kiviesemed	eseme	kivi+ese	04_S	PlN	et	kiviesemed =eseme  (PlN  >kivi+ese !04_S
45555	paleoliitikumis	paleoliitikumi	paleoliitikum	19_S	SgIn	et	paleoliitikumis =paleoliitikumi  (SgIn  >paleoliitikum !19_S
45557	kojast	koja	koda	18_S	SgEl	et	kojast =koja  (SgEl  >koda !18_S
45567	hauapanustega	panus	haua+panus	09_S	PlKom	et	hauapanustega =panus  (PlKom  >haua+panus !09_S
45576	ajastut	ajastu	ajastu	01_S	SgP	et	ajastut =ajastu  (SgP  >ajastu !01_S
45596	täpp	täpp	täpp	22_S	SgN	et	täpp =täpp  (SgN  >täpp !22_S
45602	ajaloodokumentide	dokumenti	aja+loo+dokument	22_S	PlG	et	ajaloodokumentide =dokumenti  (PlG  >aja+loo+dokument !22_S
45627	ühingutele	ühingu	ühing	02_S	PlAll	et	ühingutele =ühingu  (PlAll  >ühing !02_S
45629	raamatukogusi	kogusi	raamatu+kogus	02_A	SgG	et	raamatukogusi =kogusi  (SgG  >raamatu+kogus !02_A
45638	miljonini	miljoni	miljon	02_N	SgTer	et	miljonini =miljoni  (SgTer  >miljon !02_N
45641	paralleel	paralleel	paralleel	22_S	SgN	et	paralleel =paralleel  (SgN  >paralleel !22_S
45648	ebakompetentne	kompetentne	eba+kompetentne	02_A	SgN	et	ebakompetentne =kompetentne  (SgN  >eba+kompetentne !02_A
45667	betoonimaju	maju	betooni+maja	17_S	PlP	et	betoonimaju =maju  (PlP  >betooni+maja !17_S
45675	kuldesemeid	eseme	kuld+ese	04_S	PlP	et	kuldesemeid =eseme  (PlP  >kuld+ese !04_S
45681	karjatama	karjata	karjatama	27_V	Sup	et	karjatama =karjata  (Sup  >karjatama !27_V
45688	ettevõtmised	võtmise	ette+võtmine	12?10_S	PlN	et	ettevõtmised =võtmise  (PlN  >ette+võtmine !12?10_S
45700	energiaga	energia	energia	01_S	SgKom	et	energiaga =energia  (SgKom  >energia !01_S
45713	pühapäevakoolid	kooli	püha+päeva+kool	22_S	PlN	et	pühapäevakoolid =kooli  (PlN  >püha+päeva+kool !22_S
45715	metsavendade	venda	metsa+vend	22_S	PlG	et	metsavendade =venda  (PlG  >metsa+vend !22_S
45716	liitudest	liitu	liit	22_S	PlEl	et	liitudest =liitu  (PlEl  >liit !22_S
45717	tohtis	tohti	tohtima	28_V	IndIpfSg3	et	tohtis =tohti  (IndIpfSg3  >tohtima !28_V
45728	noorkotkad	kotka	noor+kotkas	07_S	PlN	et	noorkotkad =kotka  (PlN  >noor+kotkas !07_S
45734	võõrtööjõu	jõu	võõr+töö+jõud	22_S	SgG	et	võõrtööjõu =jõu  (SgG  >võõr+töö+jõud !22_S
45737	demonstratiivsed	demonstratiivse	demonstratiivne	02_A	PlN	et	demonstratiivsed =demonstratiivse  (PlN  >demonstratiivne !02_A
45745	malevad	maleva	malev	02_S	PlN	et	malevad =maleva  (PlN  >malev !02_S
45755	klaariti	klaari	klaarima	28_V	IndIpfIps	et	klaariti =klaari  (IndIpfIps  >klaarima !28_V
45759	nõrgenes	nõrgene	nõrgenema	27_V	IndIpfSg3	et	nõrgenes =nõrgene  (IndIpfSg3  >nõrgenema !27_V
45761	juhtimissüsteemide	süsteemi	juhtimis+süsteem	22_S	PlG	et	juhtimissüsteemide =süsteemi  (PlG  >juhtimis+süsteem !22_S
45763	ladvik	ladvik	ladvik	02_SA	SgN	et	ladvik =ladvik  (SgN  >ladvik !02_SA
45765	ümberjaotumine	jaotumine	ümber+jaotumine	12_S	SgN	et	ümberjaotumine =jaotumine  (SgN  >ümber+jaotumine !12_S
45771	majandid	majandi	majand	02_S	PlN	et	majandid =majandi  (PlN  >majand !02_S
45783	natsionaliseerida	natsionaliseeri	natsionaliseerima	28_V	Inf	et	natsionaliseerida =natsionaliseeri  (Inf  >natsionaliseerima !28_V
45785	ettekirjutuste	kirjutus	ette+kirjutus	11_S	PlG	et	ettekirjutuste =kirjutus  (PlG  >ette+kirjutus !11_S
45448	piirkonniti	piirkonniti	piirkonniti	41_D	ID	et	piirkonniti =piirkonniti  (ID  >piirkonniti !41_D
45451	peied	peie	peie	06_S	PlN	et	peied =peie  (PlN  >peie !06_S
45452	matustele	matus	matus	09_S	PlAll	et	matustele =matus  (PlAll  >matus !09_S
45454	raiuda	raiu	raiuma	28_V	Inf	et	raiuda =raiu  (Inf  >raiuma !28_V
45457	kujutama	kujuta	kujutama	27_V	Sup	et	kujutama =kujuta  (Sup  >kujutama !27_V
45461	kristlastel	kristlas	kristlane	12?10_S	PlAd	et	kristlastel =kristlas  (PlAd  >kristlane !12?10_S
45464	skandinaavlased	skandinaavlase	skandinaavlane	12?10_S	PlN	et	skandinaavlased =skandinaavlase  (PlN  >skandinaavlane !12?10_S
45469	retkedest	retke	retk	22_S	PlEl	et	retkedest =retke  (PlEl  >retk !22_S
45470	saagad	saaga	saaga	16_S	PlN	et	saagad =saaga  (PlN  >saaga !16_S
45471	viikingitele	viikingi	viiking	02_S	PlAll	et	viikingitele =viikingi  (PlAll  >viiking !02_S
45472	relvade	relva	relv	22_S	PlG	et	relvade =relva  (PlG  >relv !22_S
45491	ajajärgul	järgu	aja+järk	22_S	SgAd	et	ajajärgul =järgu  (SgAd  >aja+järk !22_S
45492	nöörivajutistega	vajutis	nööri+vajutis	11_S	PlKom	et	nöörivajutistega =vajutis  (PlKom  >nööri+vajutis !11_S
45496	pooside	poosi	poos	22_S	PlG	et	pooside =poosi  (PlG  >poos !22_S
45509	hõre	hõre	hõre	02_A	SgN	et	hõre =hõre  (SgN  >hõre !02_A
45511	leidudel	leidu	leid	22_S	PlAd	et	leidudel =leidu  (PlAd  >leid !22_S
45521	servadesse	serva	serv	22_S	PlIll	et	servadesse =serva  (PlIll  >serv !22_S
45526	tööriiste	riiste	töö+riist	22_S	PlP	et	tööriiste =riiste  (PlP  >töö+riist !22_S
45532	oludele	olu	olu	17_S	PlAll	et	oludele =olu  (PlAll  >olu !17_S
45537	nahkade	nahka	nahk	22_S	PlG	et	nahkade =nahka  (PlG  >nahk !22_S
45549	pähklite	pähkli	pähkel	02_S	PlG	et	pähklite =pähkli  (PlG  >pähkel !02_S
45554	savitaimed	taime	savi+taim	22_S	PlN	et	savitaimed =taime  (PlN  >savi+taim !22_S
45559	sambla	sambla	sammal	08_S	SgG	et	sambla =sambla  (SgG  >sammal !08_S
45561	mageveehoogude	hoogu	mage+vee+hoog	22_S	PlG	et	mageveehoogude =hoogu  (PlG  >mage+vee+hoog !22_S
45566	pottidel	potti	pott	22_S	PlAd	et	pottidel =potti  (PlAd  >pott !22_S
45573	väsis	väsi	väsima	27_V	IndIpfSg3	et	väsis =väsi  (IndIpfSg3  >väsima !27_V
45585	mälumäng	mäng	mälu+mäng	22_S	SgN	et	mälumäng =mäng  (SgN  >mälu+mäng !22_S
45589	stuudiosse	stuudio	stuudio	01_S	SgIll	et	stuudiosse =stuudio  (SgIll  >stuudio !01_S
45601	poliitilisest	poliitilise	poliitiline	12_A	SgEl	et	poliitilisest =poliitilise  (SgEl  >poliitiline !12_A
45611	nägemusega	nägemuse	nägemus	11_S	SgKom	et	nägemusega =nägemuse  (SgKom  >nägemus !11_S
45619	elektritööstuse	tööstuse	elektri+tööstus	11~09_S	SgG	et	elektritööstuse =tööstuse  (SgG  >elektri+tööstus !11~09_S
45625	filmitegemisele	tegemise	filmi+tegemine	12_S	SgAll	et	filmitegemisele =tegemise  (SgAll  >filmi+tegemine !12_S
45626	kirjandusteostega	teos	kirjandus+teos	09_S	PlKom	et	kirjandusteostega =teos  (PlKom  >kirjandus+teos !09_S
45631	avangardism	ism	avangard+ism	22_S	SgN	et	avangardism =ism  (SgN  >avangard+ism !22_S
45635	sotsrealism	realism	sots+realism	22_S	SgN	et	sotsrealism =realism  (SgN  >sots+realism !22_S
45637	plakati	plakati	plakat	02_S	SgG	et	plakati =plakati  (SgG  >plakat !02_S
45640	kabinetidest	kabineti	kabinet	22_S	PlEl	et	kabinetidest =kabineti  (PlEl  >kabinet !22_S
45652	põhiideeks	idee	põhi+idee	26_S	SgTr	et	põhiideeks =idee  (SgTr  >põhi+idee !26_S
45658	jalgrattaid	ratta	jalg+ratas	07_S	PlP	et	jalgrattaid =ratta  (PlP  >jalg+ratas !07_S
45664	esmatähtsal	tähtsa	esma+tähtis	02_A	SgAd	et	esmatähtsal =tähtsa  (SgAd  >esma+tähtis !02_A
45668	pilvelõhkujatena	lõhkuja	pilve+lõhkuja	01_S	PlEs	et	pilvelõhkujatena =lõhkuja  (PlEs  >pilve+lõhkuja !01_S
45670	9-kordsed	kordse	-kordne	02_AS	PlN	et	-kordsed =kordse  (PlN  >-kordne !02_AS
45672	suurendamas	suurenda	suurendama	27_V	SupIn	et	suurendamas =suurenda  (SupIn  >suurendama !27_V
45674	elusloodusele	looduse	elus+loodus	11~09_S	SgAll	et	elusloodusele =looduse  (SgAll  >elus+loodus !11~09_S
45679	terariistu	riistu	tera+riist	22_S	PlP	et	terariistu =riistu  (PlP  >tera+riist !22_S
45684	kütusega	kütuse	kütus	09_S	SgKom	et	kütusega =kütuse  (SgKom  >kütus !09_S
45686	sõjakriisis	kriisi	sõja+kriis	22_S	SgIn	et	sõjakriisis =kriisi  (SgIn  >sõja+kriis !22_S
45699	oblastit	oblasti	oblast	02_S	SgP	et	oblastit =oblasti  (SgP  >oblast !02_S
45701	kaevandati	kaevanda	kaevandama	27_V	IndIpfIps	et	kaevandati =kaevanda  (IndIpfIps  >kaevandama !27_V
45703	ülemnõukoguks	kogu	ülem+nõu+kogu	17_S	SgTr	et	ülemnõukoguks =kogu  (SgTr  >ülem+nõu+kogu !17_S
45705	eluharud	haru	elu+haru	17_S	PlN	et	eluharud =haru  (PlN  >elu+haru !17_S
45707	privileege	privileege	privileeg	22_S	PlP	et	privileege =privileege  (PlP  >privileeg !22_S
45722	riigiasjade	asja	riigi+asi	24_S	PlG	et	riigiasjade =asja  (PlG  >riigi+asi !24_S
45453	omaksed	omakse	omas	09_S	PlN	et	omaksed =omakse  (PlN  >omas !09_S
45460	tammik	tammik	tammik	02_S	SgN	et	tammik =tammik  (SgN  >tammik !02_S
45473	nooleotsad	otsa	noole+ots	23?22_S	PlN	et	nooleotsad =otsa  (PlN  >noole+ots !23?22_S
45474	käikudest	käiku	käik	22_S	PlEl	et	käikudest =käiku  (PlEl  >käik !22_S
45477	ilmeni	ilme	ilme	06_S	SgTer	et	ilmeni =ilme  (SgTer  >ilme !06_S
45481	mõõtühiku	ühiku	mõõt+ühik	02_S	SgG	et	mõõtühiku =ühiku  (SgG  >mõõt+ühik !02_S
45485	inimasustus	asustus	inim+asustus	11_S	SgN	et	inimasustus =asustus  (SgN  >inim+asustus !11_S
45486	muistsetelt	muistse	muistne	02_A	PlAbl	et	muistsetelt =muistse  (PlAbl  >muistne !02_A
45493	savinõud	nõu	savi+nõu	26_S	PlN	et	savinõud =nõu  (PlN  >savi+nõu !26_S
45495	venekirve	kirve	vene+kirves	07_S	SgG	et	venekirve =kirve  (SgG  >vene+kirves !07_S
45500	europiidide	europiidi	europiid	22_S	PlG	et	europiidide =europiidi  (PlG  >europiid !22_S
45502	indoeurooplastega	eurooplas	indo+eurooplane	12?10_S	PlKom	et	indoeurooplastega =eurooplas  (PlKom  >indo+eurooplane !12?10_S
45506	magamisasendit	asendi	magamis+asend	02_S	SgP	et	magamisasendit =asendi  (SgP  >magamis+asend !02_S
45507	kujusid	kuju	kuju	17_S	PlP	et	kujusid =kuju  (PlP  >kuju !17_S
45510	muististel	muistis	muistis	09_S	PlAd	et	muististel =muistis  (PlAd  >muistis !09_S
45514	sammaldega	sammal	sammal	08_S	PlKom	et	sammaldega =sammal  (PlKom  >sammal !08_S
45527	taandudes	taandu	taanduma	27_V	Ger	et	taandudes =taandu  (Ger  >taanduma !27_V
45539	valimistati	tati	valimis+tatt	22_S	SgG	et	valimistati =tati  (SgG  >valimis+tatt !22_S
45541	ahing	ahing	ahing	02_S	SgN	et	ahing =ahing  (SgN  >ahing !02_S
45546	sarvast	ast	sarv+ast	22_S	SgN	et	sarvast =ast  (SgN  >sarv+ast !22_S
45551	vajutistega	vajutis	vajutis	11_S	PlKom	et	vajutistega =vajutis  (PlKom  >vajutis !11_S
45552	ornamendiga	ornamendi	ornament	22_S	SgKom	et	ornamendiga =ornamendi  (SgKom  >ornament !22_S
45556	jääaeg	aeg	jää+aeg	22_S	SgN	et	jääaeg =aeg  (SgN  >jää+aeg !22_S
45564	esemega	eseme	ese	04_S	SgKom	et	esemega =eseme  (SgKom  >ese !04_S
45568	ooker	ooker	ooker	02_S	SgN	et	ooker =ooker  (SgN  >ooker !02_S
45569	piiresse	piire	piir	22_S	PlIll	et	piiresse =piire  (PlIll  >piir !22_S
45571	patriarhaalsed	patriarhaalse	patriarhaalne	02_A	PlN	et	patriarhaalsed =patriarhaalse  (PlN  >patriarhaalne !02_A
45574	väljakaevamistel	kaevamis	välja+kaevamine	12_S	PlAd	et	väljakaevamistel =kaevamis  (PlAd  >välja+kaevamine !12_S
45581	väljavahetamise	vahetamise	välja+vahetamine	12_S	SgG	et	väljavahetamise =vahetamise  (SgG  >välja+vahetamine !12_S
45583	teleekraanidel	ekraani	tele+ekraan	22_S	PlAd	et	teleekraanidel =ekraani  (PlAd  >tele+ekraan !22_S
45590	interaktiivne	aktiivne	inter+aktiivne	02_A	SgN	et	interaktiivne =aktiivne  (SgN  >inter+aktiivne !02_A
45592	tõsielusarju	sarju	tõsi+elu+sari	24_S	PlP	et	tõsielusarju =sarju  (PlP  >tõsi+elu+sari !24_S
45599	ideedega	idee	idee	26_S	PlKom	et	ideedega =idee  (PlKom  >idee !26_S
45613	karjainstinktile	instinkti	karja+instinkt	22_S	SgAll	et	karjainstinktile =instinkti  (SgAll  >karja+instinkt !22_S
45614	massile	massi	mass	22_S	SgAll	et	massile =massi  (SgAll  >mass !22_S
45615	tööjõu	jõu	töö+jõud	22_S	SgG	et	tööjõu =jõu  (SgG  >töö+jõud !22_S
45617	liitlastega	liitlas	liitlane	12?10_S	PlKom	et	liitlastega =liitlas  (PlKom  >liitlane !12?10_S
45618	turistidega	turisti	turist	22_S	PlKom	et	turistidega =turisti  (PlKom  >turist !22_S
45621	toodangud	toodangu	toodang	02_S	PlN	et	toodangud =toodangu  (PlN  >toodang !02_S
45622	vitriin	vitriin	vitriin	22_S	SgN	et	vitriin =vitriin  (SgN  >vitriin !22_S
45628	kukerpillid	pilli	kuker+pill	22_S	PlN	et	kukerpillid =pilli  (PlN  >kuker+pill !22_S
45632	tegevussuund	suund	tegevus+suund	22_S	SgN	et	tegevussuund =suund  (SgN  >tegevus+suund !22_S
45634	maalide	maali	maal	22_S	PlG	et	maalide =maali  (PlG  >maal !22_S
45636	võimalustega	võimalus	võimalus	11_S	PlKom	et	võimalustega =võimalus  (PlKom  >võimalus !11_S
45643	naabrist	naabri	naaber	02_S	SgEl	et	naabrist =naabri  (SgEl  >naaber !02_S
45645	omajärel	järe	oma+järg	22_S	PlAd	et	omajärel =järe  (PlAd  >oma+järg !22_S
45646	ühiskonnakriitikat	kriitika	ühis+konna+kriitika	01_S	SgP	et	ühiskonnakriitikat =kriitika  (SgP  >ühis+konna+kriitika !01_S
45647	eilne	eilne	eilne	02_A	SgN	et	eilne =eilne  (SgN  >eilne !02_A
45649	libahundi	hundi	liba+hunt	22_S	SgG	et	libahundi =hundi  (SgG  >liba+hunt !22_S
45651	ühiskonnakriitikaks	kriitika	ühis+konna+kriitika	01_S	SgTr	et	ühiskonnakriitikaks =kriitika  (SgTr  >ühis+konna+kriitika !01_S
45659	televiisoreid	televiisore	televiisor	02_S	PlP	et	televiisoreid =televiisore  (PlP  >televiisor !02_S
45660	mujalgi	mujal	mujal	41_D	ID^	et	mujalgi =mujal  (ID^  >mujal !41_D
45663	tähtsammad	samma	täht+samb	22_S	PlN	et	tähtsammad =samma  (PlN  >täht+samb !22_S
45543	viske	viske	vise	06_S	SgG	et	viske =viske  (SgG  >vise !06_S
45544	nooltega	nool	nool	13_S	PlKom	et	nooltega =nool  (PlKom  >nool !13_S
45553	lammas	lammas	lammas	07_S	SgN	et	lammas =lammas  (SgN  >lammas !07_S
45560	loomanahkadega	nahka	looma+nahk	22_S	PlKom	et	loomanahkadega =nahka  (PlKom  >looma+nahk !22_S
45562	kitsed	kitse	kits	22_S	PlN	et	kitsed =kitse  (PlN  >kits !22_S
45570	asulat	asula	asula	01_S	SgP	et	asulat =asula  (SgP  >asula !01_S
45572	künti	kün	kündma	34_V	IndIpfIps	et	künti =kün  (IndIpfIps  >kündma !34_V
45575	luustikud	luustiku	luustik	25_S	PlN	et	luustikud =luustiku  (PlN  >luustik !25_S
45577	individuaalmaju	maju	individuaal+maja	17_S	PlP	et	individuaalmaju =maju  (PlP  >individuaal+maja !17_S
45579	laevaliin	liin	laeva+liin	22_S	SgN	et	laevaliin =liin  (SgN  >laeva+liin !22_S
45582	margata	marga	mark	22_S	SgAb	et	margata =marga  (SgAb  >mark !22_S
45595	tipp	tipp	tipp	22_S	SgN	et	tipp =tipp  (SgN  >tipp !22_S
45597	kinokunstis	kunsti	kino+kunst	22_S	SgIn	et	kinokunstis =kunsti  (SgIn  >kino+kunst !22_S
45598	kiisk	kiisk	kiisk	22_S	SgN	et	kiisk =kiisk  (SgN  >kiisk !22_S
45603	tõetruul	truu	tõe+truu	26_A	SgAd	et	tõetruul =truu  (SgAd  >tõe+truu !26_A
45604	hirme	hirme	hirm	22_S	PlP	et	hirme =hirme  (PlP  >hirm !22_S
45606	müstilise	müstilise	müstiline	12_A	SgG	et	müstilise =müstilise  (SgG  >müstiline !12_A
45607	varjundi	varjundi	varjund	02_S	SgG	et	varjundi =varjundi  (SgG  >varjund !02_S
45608	kostüüme	kostüüme	kostüüm	22_S	PlP	et	kostüüme =kostüüme  (PlP  >kostüüm !22_S
45610	iseendaks	enda	ise+enda	00_P	SgTr	et	iseendaks =enda  (SgTr  >ise+enda !00_P
45612	vastanduda	vastandu	vastanduma	27_V	Inf	et	vastanduda =vastandu  (Inf  >vastanduma !27_V
45616	sissetulek	tulek	sisse+tulek	02_S	SgN	et	sissetulek =tulek  (SgN  >sisse+tulek !02_S
45624	alternatiiv	alternatiiv	alternatiiv	22_S	SgN	et	alternatiiv =alternatiiv  (SgN  >alternatiiv !22_S
45633	oksjonid	oksjoni	oksjon	02_S	PlN	et	oksjonid =oksjoni  (PlN  >oksjon !02_S
45642	värk	värk	värk	22_S	SgN	et	värk =värk  (SgN  >värk !22_S
45644	pooldad	poolda	pooldama	27_V	IndPrSg2	et	pooldad =poolda  (IndPrSg2  >pooldama !27_V
45654	vili	vili	vili	24_S	SgN	et	vili =vili  (SgN  >vili !24_S
45657	valuutapoed	poe	valuuta+pood	22_S	PlN	et	valuutapoed =poe  (PlN  >valuuta+pood !22_S
45662	näitemänguga	mängu	näite+mäng	22_S	SgKom	et	näitemänguga =mängu  (SgKom  >näite+mäng !22_S
45665	põhiained	aine	põhi+aine	06_S	PlN	et	põhiained =aine  (PlN  >põhi+aine !06_S
45680	põllusaadusi	saadusi	põllu+saadus	11_S	PlP	et	põllusaadusi =saadusi  (PlP  >põllu+saadus !11_S
45685	pagulasvalitsus	valitsus	pagulas+valitsus	11_S	SgN	et	pagulasvalitsus =valitsus  (SgN  >pagulas+valitsus !11_S
45687	arhiivides	arhiivi	arhiiv	22_S	PlIn	et	arhiivides =arhiivi  (PlIn  >arhiiv !22_S
45691	maanaisteselts	selts	maa+naiste+selts	22_S	SgN	et	maanaisteselts =selts  (SgN  >maa+naiste+selts !22_S
45695	eraomandust	omandus	era+omandus	11_S	SgP	et	eraomandust =omandus  (SgP  >era+omandus !11_S
45708	haldusreform	reform	haldus+reform	22_S	SgN	et	haldusreform =reform  (SgN  >haldus+reform !22_S
45709	külanõukoguks	kogu	küla+nõu+kogu	17_S	SgTr	et	külanõukoguks =kogu  (SgTr  >küla+nõu+kogu !17_S
45711	hävitatakse	hävita	hävitama	27_V	IndPrIps	et	hävitatakse =hävita  (IndPrIps  >hävitama !27_V
45720	erialadel	ala	eri+ala	17_S	PlAd	et	erialadel =ala  (PlAd  >eri+ala !17_S
45721	välislektorid	lektori	välis+lektor	02_S	PlN	et	välislektorid =lektori  (PlN  >välis+lektor !02_S
45724	maailmajaod	jao	maa+ilma+jagu	18_S	PlN	et	maailmajaod =jao  (PlN  >maa+ilma+jagu !18_S
45725	kingissepa	sepa	kingis+sepp	22_S	SgG	et	kingissepa =sepa  (SgG  >kingis+sepp !22_S
45730	riigiomand	omand	riigi+omand	02_S	SgN	et	riigiomand =omand  (SgN  >riigi+omand !02_S
45732	majand	majand	majand	02_S	SgN	et	majand =majand  (SgN  >majand !02_S
45753	sagenes	sagene	sagenema	27_V	IndIpfSg3	et	sagenes =sagene  (IndIpfSg3  >sagenema !27_V
45769	varustas	varusta	varustama	27_V	IndIpfSg3	et	varustas =varusta  (IndIpfSg3  >varustama !27_V
45772	majandama	majanda	majandama	27_V	Sup	et	majandama =majanda  (Sup  >majandama !27_V
45774	radikaalset	radikaalse	radikaalne	02_A	SgP	et	radikaalset =radikaalse  (SgP  >radikaalne !02_A
45776	ühinema	ühine	ühinema	27_V	Sup	et	ühinema =ühine  (Sup  >ühinema !27_V
45779	direktorid	direktori	direktor	02_S	PlN	et	direktorid =direktori  (PlN  >direktor !02_S
45782	täitevkomiteedeks	komitee	täitev+komitee	26_S	PlTr	et	täitevkomiteedeks =komitee  (PlTr  >täitev+komitee !26_S
45784	omanikusuhted	suhte	omaniku+suhe	06_S	PlN	et	omanikusuhted =suhte  (PlN  >omaniku+suhe !06_S
45789	näitekunst	kunst	näite+kunst	22_S	SgN	et	näitekunst =kunst  (SgN  >näite+kunst !22_S
45794	ülempiiskopiks	piiskopi	ülem+piiskop	22_S	SgTr	et	ülempiiskopiks =piiskopi  (SgTr  >ülem+piiskop !22_S
45630	kerkima	kerki	kerkima	27_V	Sup	et	kerkima =kerki  (Sup  >kerkima !27_V
45639	parteisekretäride	sekretäri	part+ei+sekretär	19_S	PlG	et	parteisekretäride =sekretäri  (PlG  >part+ei+sekretär !19_S
45650	elukorraldus	korraldus	elu+korraldus	11_S	SgN	et	elukorraldus =korraldus  (SgN  >elu+korraldus !11_S
45653	järjel	järje	järg	22_S	SgAd	et	järjel =järje  (SgAd  >järg !22_S
45655	mujale	mujale	mujale	41_D	ID	et	mujale =mujale  (ID  >mujale !41_D
45656	nõudlus	nõudlus	nõudlus	11~09_S	SgN	et	nõudlus =nõudlus  (SgN  >nõudlus !11~09_S
45661	püüeldi	püüel	püüdlema	30_V	IndIpfIps	et	püüeldi =püüel  (IndIpfIps  >püüdlema !30_V
45666	mehe-naise	naise	mehe-naine	12_S	SgG	et	mehe-naise =naise  (SgG  >mehe-naine !12_S
45671	harimas	hari	harima	27_V	SupIn	et	harimas =hari  (SupIn  >harima !27_V
45676	vase	vase	vask	22_S	SgG	et	vase =vase  (SgG  >vask !22_S
45677	harutama	haruta	harutama	27_V	Sup	et	harutama =haruta  (Sup  >harutama !27_V
45690	haridusselts	selts	haridus+selts	22_S	SgN	et	haridusselts =selts  (SgN  >haridus+selts !22_S
45704	peaparteiks	partei	pea+partei	26_S	SgTr	et	peaparteiks =partei  (SgTr  >pea+partei !26_S
45714	tsoonid	tsooni	tsoon	22_S	PlN	et	tsoonid =tsooni  (PlN  >tsoon !22_S
45723	kodanikele	kodanike	kodanik	25_S	PlAll	et	kodanikele =kodanike  (PlAll  >kodanik !25_S
45726	tänavanimede	nime	tänava+nimi	20_S	PlG	et	tänavanimede =nime  (PlG  >tänava+nimi !20_S
45729	kodutütred	tütre	kodu+tütar	08_S	PlN	et	kodutütred =tütre  (PlN  >kodu+tütar !08_S
45731	vabrikuid	vabriku	vabrik	02_S	PlP	et	vabrikuid =vabriku  (PlP  >vabrik !02_S
45736	lihtrahva	rahva	liht+rahvas	07_S	SgG	et	lihtrahva =rahva  (SgG  >liht+rahvas !07_S
45739	tuusikud	tuusiku	tuusik	02_S	PlN	et	tuusikud =tuusiku  (PlN  >tuusik !02_S
45742	elektroonikatööstuse	tööstuse	elektroonika+tööstus	11~09_S	SgG	et	elektroonikatööstuse =tööstuse  (SgG  >elektroonika+tööstus !11~09_S
45744	pioneerid	pioneeri	pioneer	22_S	PlN	et	pioneerid =pioneeri  (PlN  >pioneer !22_S
45749	kõlbmatuks	kõlbmatu	kõlbmatu	01_A	SgTr	et	kõlbmatuks =kõlbmatu  (SgTr  >kõlbmatu !01_A
45752	tasalülitamine	lülitamine	tasa+lülitamine	12_S	SgN	et	tasalülitamine =lülitamine  (SgN  >tasa+lülitamine !12_S
45754	pealekabamine	kabamine	peale+kabamine	12_S	SgN	et	pealekabamine =kabamine  (SgN  >peale+kabamine !12_S
45756	ässitati	ässita	ässitama	27_V	IndIpfIps	et	ässitati =ässita  (IndIpfIps  >ässitama !27_V
45758	metsavahendus	vahendus	metsa+vahendus	11_S	SgN	et	metsavahendus =vahendus  (SgN  >metsa+vahendus !11_S
45764	keskorganid	organi	kesk+organ	02_S	PlN	et	keskorganid =organi  (PlN  >kesk+organ !02_S
45766	omatahtel	tahte	oma+tahe	06_S	SgAd	et	omatahtel =tahte  (SgAd  >oma+tahe !06_S
45775	põhjendati	põhjenda	põhjendama	27_V	IndIpfIps	et	põhjendati =põhjenda  (IndIpfIps  >põhjendama !27_V
45781	suveräänsetest	suveräänse	suveräänne	02_A	PlEl	et	suveräänsetest =suveräänse  (PlEl  >suveräänne !02_A
45786	sotsiaalseid	sotsiaalse	sotsiaalne	02_A	PlP	et	sotsiaalseid =sotsiaalse  (PlP  >sotsiaalne !02_A
45787	kultuurikapital	kapital	kultuuri+kapital	19_S	SgN	et	kultuurikapital =kapital  (SgN  >kultuuri+kapital !19_S
45788	helikunst	kunst	heli+kunst	22_S	SgN	et	helikunst =kunst  (SgN  >heli+kunst !22_S
45793	apostliku	apostliku	apostlik	25_A	SgG	et	apostliku =apostliku  (SgG  >apostlik !25_A
45796	vaimuinimesed	inimese	vaimu+inimene	12_S	PlN	et	vaimuinimesed =inimese  (PlN  >vaimu+inimene !12_S
45808	teadustöid	tö	teadus+töö	26_S	PlP	et	teadustöid =tö  (PlP  >teadus+töö !26_S
45809	lauter	lauter	lauter	02_S	SgN	et	lauter =lauter  (SgN  >lauter !02_S
45815	dissidente	dissidente	dissident	22_S	PlP	et	dissidente =dissidente  (PlP  >dissident !22_S
45829	rõõmud	rõõmu	rõõm	22_S	PlN	et	rõõmud =rõõmu  (PlN  >rõõm !22_S
45836	majanduslikule	majandusliku	majanduslik	25_A	SgAll	et	majanduslikule =majandusliku  (SgAll  >majanduslik !25_A
45839	peetkase	kase	peet+kask	22_S	SgG	et	peetkase =kase  (SgG  >peet+kask !22_S
45847	matemaatikas	matemaatika	matemaatika	01_S	SgIn	et	matemaatikas =matemaatika  (SgIn  >matemaatika !01_S
45850	dokumentaalkaadreid	kaadre	dokumentaal+kaader	02_S	PlP	et	dokumentaalkaadreid =kaadre  (PlP  >dokumentaal+kaader !02_S
45856	nõrgeneb	nõrgene	nõrgenema	27_V	IndPrSg3	et	nõrgeneb =nõrgene  (IndPrSg3  >nõrgenema !27_V
45869	diivanid	diivani	diivan	02_S	PlN	et	diivanid =diivani  (PlN  >diivan !02_S
45877	haridussaateid	saate	haridus+saade	06_S	PlP	et	haridussaateid =saate  (PlP  >haridus+saade !06_S
45886	üritati	ürita	üritama	27_V	IndIpfIps	et	üritati =ürita  (IndIpfIps  >üritama !27_V
45890	kohalolekut	oleku	kohal+olek	02_S	SgP	et	kohalolekut =oleku  (SgP  >kohal+olek !02_S
45895	loomingumeetodina	meetodi	loomingu+meetod	02_S	SgEs	et	loomingumeetodina =meetodi  (SgEs  >loomingu+meetod !02_S
45898	diktaadita	diktaadi	diktaat	22_S	SgAb	et	diktaadita =diktaadi  (SgAb  >diktaat !22_S
45902	nõukogudele	kogu	nõu+kogu	17_S	PlAll	et	nõukogudele =kogu  (PlAll  >nõu+kogu !17_S
45669	mustamäe	mäe	musta+mägi	21_S	SgG	et	mustamäe =mäe  (SgG  >musta+mägi !21_S
45673	loodusnähtustele	nähtus	loodus+nähtus	11~09_S	PlAll	et	loodusnähtustele =nähtus  (PlAll  >loodus+nähtus !11~09_S
45678	kõrgkultuurid	kultuuri	kõrg+kultuur	22_S	PlN	et	kõrgkultuurid =kultuuri  (PlN  >kõrg+kultuur !22_S
45682	ideoloogiast	ideoloogia	ideoloogia	01_S	SgEl	et	ideoloogiast =ideoloogia  (SgEl  >ideoloogia !01_S
45683	tööstused	tööstuse	tööstus	11~09_S	PlN	et	tööstused =tööstuse  (PlN  >tööstus !11~09_S
45689	tuletõrjeselts	selts	tule+tõrje+selts	22_S	SgN	et	tuletõrjeselts =selts  (SgN  >tule+tõrje+selts !22_S
45692	ooperid	ooperi	ooper	02_S	PlN	et	ooperid =ooperi  (PlN  >ooper !02_S
45693	filmimaailmas	ilma	filmi+maa+ilm	22_S	SgIn	et	filmimaailmas =ilma  (SgIn  >filmi+maa+ilm !22_S
45694	tehased	tehase	tehas	09_S	PlN	et	tehased =tehase  (PlN  >tehas !09_S
45696	pangad	panga	pank	22_S	PlN	et	pangad =panga  (PlN  >pank !22_S
45697	teadusharud	haru	teadus+haru	17_S	PlN	et	teadusharud =haru  (PlN  >teadus+haru !17_S
45698	kasvatad	kasvata	kasvatama	27_V	IndPrSg2	et	kasvatad =kasvata  (IndPrSg2  >kasvatama !27_V
45702	riigisüsteem	süsteem	riigi+süsteem	22_S	SgN	et	riigisüsteem =süsteem  (SgN  >riigi+süsteem !22_S
45706	riigikorraks	korra	riigi+kord	22_S	SgTr	et	riigikorraks =korra  (SgTr  >riigi+kord !22_S
45710	eriseltse	seltse	eri+selts	22_S	PlP	et	eriseltse =seltse  (PlP  >eri+selts !22_S
45712	algüksus	üksus	alg+üksus	11~09_S	SgN	et	algüksus =üksus  (SgN  >alg+üksus !11~09_S
45718	kirin	kirin	kirin	02_S	SgN	et	kirin =kirin  (SgN  >kirin !02_S
45719	spetsiifilistel	spetsiifilis	spetsiifiline	12_A	PlAd	et	spetsiifilistel =spetsiifilis  (PlAd  >spetsiifiline !12_A
45735	ümberasustamine	asustamine	ümber+asustamine	12_S	SgN	et	ümberasustamine =asustamine  (SgN  >ümber+asustamine !12_S
45740	sots	sots	sots	22_S	SgN	et	sots =sots  (SgN  >sots !22_S
45746	ensv-l	ensv	ensv	xx_Q	SgAd	et	ensv-l =ensv  (SgAd  >ensv !xx_Q
45760	tsiviilühiskond	ühiskond	tsiviil+ühiskond	22_S	SgN	et	tsiviilühiskond =ühiskond  (SgN  >tsiviil+ühiskond !22_S
45762	sõjajärgsel	järgse	sõja+järgne	02_A	SgAd	et	sõjajärgsel =järgse  (SgAd  >sõja+järgne !02_A
45767	nõukogude-meelsed	meelse	nõukogude-meelne	02_A	PlN	et	nõukogude-meelsed =meelse  (PlN  >nõukogude-meelne !02_A
45773	ühismajanditesse	majandi	ühis+majand	02_S	PlIll	et	ühismajanditesse =majandi  (PlIll  >ühis+majand !02_S
45780	loobus	loobu	loobuma	27_V	IndIpfSg3	et	loobus =loobu  (IndIpfSg3  >loobuma !27_V
45791	voolud	voolu	vool	22_S	PlN	et	voolud =voolu  (PlN  >vool !22_S
45792	viljeleda	viljele	viljelema	27_V	Inf	et	viljeleda =viljele  (Inf  >viljelema !27_V
45804	taludega	talu	talu	17_S	PlKom	et	taludega =talu  (PlKom  >talu !17_S
45805	pisirahvad	rahva	pisi+rahvas	07_S	PlN	et	pisirahvad =rahva  (PlN  >pisi+rahvas !07_S
45810	ensv-st	ensv	ensv	xx_Q	SgEl	et	ensv-st =ensv  (SgEl  >ensv !xx_Q
45813	majandusharud	haru	majandus+haru	17_S	PlN	et	majandusharud =haru  (PlN  >majandus+haru !17_S
45817	start1	start	start	22_S	SgN	et	start =start  (SgN  >start !22_S
45824	nsv-liidu	liidu	nsv-liit	22_S	SgG	et	nsv-liidu =liidu  (SgG  >nsv-liit !22_S
45826	loodusprobleemide	probleemi	loodus+probleem	22_S	PlG	et	loodusprobleemide =probleemi  (PlG  >loodus+probleem !22_S
45831	sulaajal	aja	sula+aeg	22_S	SgAd	et	sulaajal =aja  (SgAd  >sula+aeg !22_S
45832	aastatega	aasta	aasta	01_S	PlKom	et	aastatega =aasta  (PlKom  >aasta !01_S
45834	järgult	järgu	järk	22_S	SgAbl	et	järgult =järgu  (SgAbl  >järk !22_S
45838	migratsioon	migratsioon	migratsioon	22_S	SgN	et	migratsioon =migratsioon  (SgN  >migratsioon !22_S
45845	televiktoriinid	viktoriini	tele+viktoriin	22_S	PlN	et	televiktoriinid =viktoriini  (PlN  >tele+viktoriin !22_S
45849	loodusteaduses	teaduse	loodus+teadus	11~09_S	SgIn	et	loodusteaduses =teaduse  (SgIn  >loodus+teadus !11~09_S
45859	aktiviseeris	aktiviseeri	aktiviseerima	28_V	IndIpfSg3	et	aktiviseeris =aktiviseeri  (IndIpfSg3  >aktiviseerima !28_V
45862	õpingu	õpingu	õping	02_S	SgG	et	õpingu =õpingu  (SgG  >õping !02_S
45868	nl-le	nl	nl	xx_Q	SgAll	et	nl-le =nl  (SgAll  >nl !xx_Q
45873	lepik	lepik	lepik	02_S	SgN	et	lepik =lepik  (SgN  >lepik !02_S
45875	vapraga	vapra	vapper	02_A	SgKom	et	vapraga =vapra  (SgKom  >vapper !02_A
45880	leies	leie	leid	22_S	PlIn	et	leies =leie  (PlIn  >leid !22_S
45882	analüüsiti	analüüsi	analüüsima	28_V	IndIpfIps	et	analüüsiti =analüüsi  (IndIpfIps  >analüüsima !28_V
45885	parandati	paranda	parandama	27_V	IndIpfIps	et	parandati =paranda  (IndIpfIps  >parandama !27_V
45899	lavakeelu	keelu	lava+keeld	22_S	SgG	et	lavakeelu =keelu  (SgG  >lava+keeld !22_S
45909	demokraatlikul	demokraatliku	demokraatlik	25_A	SgAd	et	demokraatlikul =demokraatliku  (SgAd  >demokraatlik !25_A
45911	sotsialistlikule	sotsialistliku	sotsialistlik	25_A	SgAll	et	sotsialistlikule =sotsialistliku  (SgAll  >sotsialistlik !25_A
45727	ümbernimetamine	nimetamine	ümber+nimetamine	12_S	SgN	et	ümbernimetamine =nimetamine  (SgN  >ümber+nimetamine !12_S
45733	ühisomandisse	omandi	ühis+omand	02_S	SgIll	et	ühisomandisse =omandi  (SgIll  >ühis+omand !02_S
45738	nõusolekuta	oleku	nõus+olek	02_S	SgAb	et	nõusolekuta =oleku  (SgAb  >nõus+olek !02_S
45741	rahulduma	rahuldu	rahulduma	27_V	Sup	et	rahulduma =rahuldu  (Sup  >rahulduma !27_V
45743	oktoobrilapsed	lapse	oktoobri+laps	14_S	PlN	et	oktoobrilapsed =lapse  (PlN  >oktoobri+laps !14_S
45747	välisministeerium	ministeerium	välis+ministeerium	19~02_S	SgN	et	välisministeerium =ministeerium  (SgN  >välis+ministeerium !19~02_S
45748	amnestiat	amnestia	amnestia	01_S	SgP	et	amnestiat =amnestia  (SgP  >amnestia !01_S
45750	allutati	alluta	allutama	27_V	IndIpfIps	et	allutati =alluta  (IndIpfIps  >allutama !27_V
45751	ta-le	ta	ta	xx_Q	SgAll	et	ta-le =ta  (SgAll  >ta !xx_Q
45757	põllumehed	mehe	põllu+mees	13_S	PlN	et	põllumehed =mehe  (PlN  >põllu+mees !13_S
45768	elektritootmist	tootmis	elektri+tootmine	12?10_S	SgP	et	elektritootmist =tootmis  (SgP  >elektri+tootmine !12?10_S
45770	taustu	taustu	taust	22_S	PlP	et	taustu =taustu  (PlP  >taust !22_S
45777	näpati	näpa	näppama	29_V	IndIpfIps	et	näpati =näpa  (IndIpfIps  >näppama !29_V
45778	edutas	eduta	edutama	27_V	IndIpfSg3	et	edutas =eduta  (IndIpfSg3  >edutama !27_V
45790	kehakultuur	kultuur	keha+kultuur	22_S	SgN	et	kehakultuur =kultuur  (SgN  >keha+kultuur !22_S
45797	ev-s	ev	ev	xx_Q	SgIn	et	ev-s =ev  (SgIn  >ev !xx_Q
45798	hinnati	hinna	hindama	29_V	IndIpfIps	et	hinnati =hinna  (IndIpfIps  >hindama !29_V
45802	sisseseadmine	seadmine	sisse+seadmine	12?10_S	SgN	et	sisseseadmine =seadmine  (SgN  >sisse+seadmine !12?10_S
45803	köidete	köide	köide	06_S	PlG	et	köidete =köide  (PlG  >köide !06_S
45806	kunstiühing	ühing	kunsti+ühing	02_S	SgN	et	kunstiühing =ühing  (SgN  >kunsti+ühing !02_S
45811	sovhoosid	sovhoosi	sovhoos	22_S	PlN	et	sovhoosid =sovhoosi  (PlN  >sovhoos !22_S
45812	elektritootmine	tootmine	elektri+tootmine	12?10_S	SgN	et	elektritootmine =tootmine  (SgN  >elektri+tootmine !12?10_S
45814	kultuurtegelasi	tegelasi	kultuur+tegelane	12_S	PlP	et	kultuurtegelasi =tegelasi  (PlP  >kultuur+tegelane !12_S
45819	õppevahendina	vahendi	õppe+vahend	02_S	SgEs	et	õppevahendina =vahendi  (SgEs  >õppe+vahend !02_S
45820	põhikoolilapsed	lapse	põhi+kooli+laps	14_S	PlN	et	põhikoolilapsed =lapse  (PlN  >põhi+kooli+laps !14_S
45825	järjekorrata	korra	järje+kord	22_S	SgAb	et	järjekorrata =korra  (SgAb  >järje+kord !22_S
45827	loodusobjekte	objekte	loodus+objekt	22_S	PlP	et	loodusobjekte =objekte  (PlP  >loodus+objekt !22_S
45835	elektri-toodangut	toodangu	elektri-toodang	02_S	SgP	et	elektri-toodangut =toodangu  (SgP  >elektri-toodang !02_S
45841	tänaste	tänas	tänane	10_A	PlG	et	tänaste =tänas  (PlG  >tänane !10_A
45844	kriimsilm	silm	kriim+silm	22_S	SgN	et	kriimsilm =silm  (SgN  >kriim+silm !22_S
45846	telekanalid	kanali	tele+kanal	02_S	PlN	et	telekanalid =kanali  (PlN  >tele+kanal !02_S
45852	reklaamindus	reklaamindus	reklaamindus	11_S	SgN	et	reklaamindus =reklaamindus  (SgN  >reklaamindus !11_S
45854	viktoriinimänge	mänge	viktoriini+mäng	22_S	PlP	et	viktoriinimänge =mänge  (PlP  >viktoriini+mäng !22_S
45855	teleteatrilastusi	lastusi	tele+teatri+lastus	11_S	PlP	et	teleteatrilastusi =lastusi  (PlP  >tele+teatri+lastus !11_S
45857	kultuurüritused	ürituse	kultuur+üritus	11_S	PlN	et	kultuurüritused =ürituse  (PlN  >kultuur+üritus !11_S
45860	lavatsensuur	tsensuur	lava+tsensuur	22_S	SgN	et	lavatsensuur =tsensuur  (SgN  >lava+tsensuur !22_S
45871	põhja-eestlased	eestlase	põhja-eestlane	12?10_S	PlN	et	põhja-eestlased =eestlase  (PlN  >põhja-eestlane !12?10_S
45874	sõimusse	sõimu	sõim	22_S	SgIll	et	sõimusse =sõimu  (SgIll  >sõim !22_S
45884	rahvakultuurseid	kultuurse	rahva+kultuurne	02_A	PlP	et	rahvakultuurseid =kultuurse  (PlP  >rahva+kultuurne !02_A
45893	vaadatakse	vaada	vaatama	29_V	IndPrIps	et	vaadatakse =vaada  (IndPrIps  >vaatama !29_V
45900	kroop	kroop	kroop	22_S	SgN	et	kroop =kroop  (SgN  >kroop !22_S
45901	madrus	madrus	madrus	09_S	SgN	et	madrus =madrus  (SgN  >madrus !09_S
45907	stagnaperioodist	perioodi	stagna+periood	22_S	SgEl	et	stagnaperioodist =perioodi  (SgEl  >stagna+periood !22_S
45908	ülistada	ülista	ülistama	27_V	Inf	et	ülistada =ülista  (Inf  >ülistama !27_V
45914	loodushoiu	hoiu	loodus+hoid	22_S	SgG	et	loodushoiu =hoiu  (SgG  >loodus+hoid !22_S
45919	a-ks	a	a	xx_Q	SgTr	et	a-ks =a  (SgTr  >a !xx_Q
45921	põhielanikel	elanike	põhi+elanik	25_S	PlAd	et	põhielanikel =elanike  (PlAd  >põhi+elanik !25_S
45922	erilubadega	luba	eri+luba	18_S	PlKom	et	erilubadega =luba  (PlKom  >eri+luba !18_S
45924	kaevandama	kaevanda	kaevandama	27_V	Sup	et	kaevandama =kaevanda  (Sup  >kaevandama !27_V
45930	nsvl-st	nsvl	nsvl	xx_Q	SgEl	et	nsvl-st =nsvl  (SgEl  >nsvl !xx_Q
45941	aluna	alu	alg	22_S	SgEs	et	aluna =alu  (SgEs  >alg !22_S
45795	leeris	leeri	leer	22_S	SgIn	et	leeris =leeri  (SgIn  >leer !22_S
45800	kreedoks	kreedo	kreedo	16_S	SgTr	et	kreedoks =kreedo  (SgTr  >kreedo !16_S
45801	jõult	jõu	jõud	22_S	SgAbl	et	jõult =jõu  (SgAbl  >jõud !22_S
45822	migrantide	migranti	migrant	22_S	PlG	et	migrantide =migranti  (PlG  >migrant !22_S
45828	üleliidu	liidu	üle+liit	22_S	SgG	et	üleliidu =liidu  (SgG  >üle+liit !22_S
45830	stagnatsiooniperioodiks	perioodi	stagnatsiooni+periood	22_S	SgTr	et	stagnatsiooniperioodiks =perioodi  (SgTr  >stagnatsiooni+periood !22_S
45837	haritlase	haritlase	haritlane	12_S	SgG	et	haritlase =haritlase  (SgG  >haritlane !12_S
45840	tollaste	tollas	tollane	10_A	PlG	et	tollaste =tollas  (PlG  >tollane !10_A
45843	vaprat	vapra	vapper	02_A	SgP	et	vaprat =vapra  (SgP  >vapper !02_A
45853	reklaamiklubid	klubi	reklaami+klubi	17_S	PlN	et	reklaamiklubid =klubi  (PlN  >reklaami+klubi !17_S
45861	rektorit	rektori	rektor	02_S	SgP	et	rektorit =rektori  (SgP  >rektor !02_S
45863	ettevalmistuseksami	eksami	ette+valmistus+eksam	02_S	SgG	et	ettevalmistuseksami =eksami  (SgG  >ette+valmistus+eksam !02_S
45864	medõe	õe	med+õde	18_S	SgG	et	medõe =õe  (SgG  >med+õde !18_S
45865	haridusprogramm	programm	haridus+programm	22_S	SgN	et	haridusprogramm =programm  (SgN  >haridus+programm !22_S
45867	vooglaid	laid	voog+laid	22_S	SgN	et	vooglaid =laid  (SgN  >voog+laid !22_S
45870	erisoodustused	soodustuse	eri+soodustus	11_S	PlN	et	erisoodustused =soodustuse  (PlN  >eri+soodustus !11_S
45872	käsitöösuveniire	suveniire	käsi+töö+suveniir	22_S	PlP	et	käsitöösuveniire =suveniire  (PlP  >käsi+töö+suveniir !22_S
45876	keeleõppega	õppe	keele+õpe	06_S	SgKom	et	keeleõppega =õppe  (SgKom  >keele+õpe !06_S
45878	kolleegium	kolleegium	kolleegium	19~02_S	SgN	et	kolleegium =kolleegium  (SgN  >kolleegium !19~02_S
45881	lastesaadetele	saade	laste+saade	06_S	PlAll	et	lastesaadetele =saade  (PlAll  >laste+saade !06_S
45891	lauluvõistlusi	võistlusi	laulu+võistlus	11_S	PlP	et	lauluvõistlusi =võistlusi  (PlP  >laulu+võistlus !11_S
45892	lavaetendusi	etendusi	lava+etendus	11_S	PlP	et	lavaetendusi =etendusi  (PlP  >lava+etendus !11_S
45896	kultuuritegelaste	tegelas	kultuuri+tegelane	12_S	PlG	et	kultuuritegelaste =tegelas  (PlG  >kultuuri+tegelane !12_S
45897	väljapääsmatuse	matuse	välja+pääs+matus	09_S	SgG	et	väljapääsmatuse =matuse  (SgG  >välja+pääs+matus !09_S
45913	mõeldis	mõeldis	mõeldis	11~09_S	SgN	et	mõeldis =mõeldis  (SgN  >mõeldis !11~09_S
45915	vastasseis	seis	vastas+seis	22_S	SgN	et	vastasseis =seis  (SgN  >vastas+seis !22_S
45918	iive	iive	iive	06_S	SgN	et	iive =iive  (SgN  >iive !06_S
45925	allikakopad	kopa	allika+kopp	22_S	PlN	et	allikakopad =kopa  (PlN  >allika+kopp !22_S
45926	näidismajandeid	majande	näidis+majand	02_S	PlP	et	näidismajandeid =majande  (PlP  >näidis+majand !02_S
45927	riigilt	riigi	riik	22_S	SgAbl	et	riigilt =riigi  (SgAbl  >riik !22_S
45935	loodusvarad	vara	loodus+vara	17_S	PlN	et	loodusvarad =vara  (PlN  >loodus+vara !17_S
45936	tühistati	tühista	tühistama	27_V	IndIpfIps	et	tühistati =tühista  (IndIpfIps  >tühistama !27_V
45942	vanaisale	isa	vana+isa	17_S	SgAll	et	vanaisale =isa  (SgAll  >vana+isa !17_S
45947	noormehena	mehe	noor+mees	13_S	SgEs	et	noormehena =mehe  (SgEs  >noor+mees !13_S
45956	allakäik	käik	alla+käik	22_S	SgN	et	allakäik =käik  (SgN  >alla+käik !22_S
45959	stagnatsiooniks	stagnatsiooni	stagnatsioon	22_S	SgTr	et	stagnatsiooniks =stagnatsiooni  (SgTr  >stagnatsioon !22_S
45960	seisakuks	seisaku	seisak	02_S	SgTr	et	seisakuks =seisaku  (SgTr  >seisak !02_S
45961	loodusvaresid	vare	loodus+vare	16_S	PlP	et	loodusvaresid =vare  (PlP  >loodus+vare !16_S
45971	tehaste	tehas	tehas	09_S	PlG	et	tehaste =tehas  (PlG  >tehas !09_S
45974	teosedki	teose	teos	09_S	PlN^	et	teosedki =teose  (PlN^  >teos !09_S
45975	noormehel	mehe	noor+mees	13_S	SgAd	et	noormehel =mehe  (SgAd  >noor+mees !13_S
45982	kunstiinimesed	inimese	kunsti+inimene	12_S	PlN	et	kunstiinimesed =inimese  (PlN  >kunsti+inimene !12_S
45985	palvetamas	palveta	palvetama	27_V	SupIn	et	palvetamas =palveta  (SupIn  >palvetama !27_V
45992	mittesakslastega	sakslas	mitte+sakslane	12?10_S	PlKom	et	mittesakslastega =sakslas  (PlKom  >mitte+sakslane !12?10_S
46002	väljasuremisele	suremise	välja+suremine	12_S	SgAll	et	väljasuremisele =suremise  (SgAll  >välja+suremine !12_S
46005	looduskaitsjad	kaitsja	loodus+kaitsja	01_S	PlN	et	looduskaitsjad =kaitsja  (PlN  >loodus+kaitsja !01_S
46006	riigivargus	vargus	riigi+vargus	11~09_S	SgN	et	riigivargus =vargus  (SgN  >riigi+vargus !11~09_S
46009	aegset	aegse	aegne	02_A	SgP	et	aegset =aegse  (SgP  >aegne !02_A
46018	välispasside	passi	välis+pass	22_S	PlG	et	välispasside =passi  (PlG  >välis+pass !22_S
46025	haruks	haru	haru	17_S	SgTr	et	haruks =haru  (SgTr  >haru !17_S
46034	äärtesse	äär	äär	13_S	PlIll	et	äärtesse =äär  (PlIll  >äär !13_S
46038	nii-öelda	nii-öelda	nii+-öelda	41_D	ID	et	nii-öelda =nii-öelda  (ID  >nii+-öelda !41_D
45799	ev-st	ev	ev	xx_Q	SgEl	et	ev-st =ev  (SgEl  >ev !xx_Q
45807	veskile	veski	veski	01_S	SgAll	et	veskile =veski  (SgAll  >veski !01_S
45816	demokraatlikuks	demokraatliku	demokraatlik	25_A	SgTr	et	demokraatlikuks =demokraatliku  (SgTr  >demokraatlik !25_A
45818	õppevahendiks	vahendi	õppe+vahend	02_S	SgTr	et	õppevahendiks =vahendi  (SgTr  >õppe+vahend !02_S
45821	keskvõim	võim	kesk+võim	22_S	SgN	et	keskvõim =võim  (SgN  >kesk+võim !22_S
45823	migrantidega	migranti	migrant	22_S	PlKom	et	migrantidega =migranti  (PlKom  >migrant !22_S
45833	juurdekasv	kasv	juurde+kasv	22_S	SgN	et	juurdekasv =kasv  (SgN  >juurde+kasv !22_S
45842	lapstähed	tähe	laps+täht	22_S	PlN	et	lapstähed =tähe  (PlN  >laps+täht !22_S
45848	keemias	keemia	keemia	01_S	SgIn	et	keemias =keemia  (SgIn  >keemia !01_S
45851	nukulavastused	lavastuse	nuku+lavastus	11_S	PlN	et	nukulavastused =lavastuse  (PlN  >nuku+lavastus !11_S
45858	pant	pant	pant	22_S	SgN	et	pant =pant  (SgN  >pant !22_S
45866	labor	labor	labor	02_S	SgN	et	labor =labor  (SgN  >labor !02_S
45879	kultuuriüritus	üritus	kultuuri+üritus	11_S	SgN	et	kultuuriüritus =üritus  (SgN  >kultuuri+üritus !11_S
45883	külakapellid	kapelli	küla+kapell	22_S	PlN	et	külakapellid =kapelli  (PlN  >küla+kapell !22_S
45887	ametisse	ameti	amet	02_S	SgIll	et	ametisse =ameti  (SgIll  >amet !02_S
45888	esmatähtis	tähtis	esma+tähtis	02_A	SgN	et	esmatähtis =tähtis  (SgN  >esma+tähtis !02_A
45889	mõttelaad	laad	mõtte+laad	22_S	SgN	et	mõttelaad =laad  (SgN  >mõtte+laad !22_S
45894	kunstiteadlased	teadlase	kunsti+teadlane	12?10_S	PlN	et	kunstiteadlased =teadlase  (PlN  >kunsti+teadlane !12?10_S
45904	metskapten	kapten	mets+kapten	02_S	SgN	et	metskapten =kapten  (SgN  >mets+kapten !02_S
45906	a-st	a	a	xx_Q	SgEl	et	a-st =a  (SgEl  >a !xx_Q
45923	nappima	nappi	nappima	28_V	Sup	et	nappima =nappi  (Sup  >nappima !28_V
45934	maavarad9	vara	maa+vara	17_S	PlN	et	maavarad =vara  (PlN  >maa+vara !17_S
45944	fantaseerida	fantaseeri	fantaseerima	28_V	Inf	et	fantaseerida =fantaseeri  (Inf  >fantaseerima !28_V
45951	tatel	tate	tatt	22_S	PlAd	et	tatel =tate  (PlAd  >tatt !22_S
45955	loodusressursside	ressurssi	loodus+ressurss	22_S	PlG	et	loodusressursside =ressurssi  (PlG  >loodus+ressurss !22_S
45958	oleku	oleku	olek	02_S	SgG	et	oleku =oleku  (SgG  >olek !02_S
45965	loomaliigid	liigi	looma+liik	22_S	PlN	et	loomaliigid =liigi  (PlN  >looma+liik !22_S
45969	maavaradest	vara	maa+vara	17_S	PlEl	et	maavaradest =vara  (PlEl  >maa+vara !17_S
45973	romaanidest	romaani	romaan	22_S	PlEl	et	romaanidest =romaani  (PlEl  >romaan !22_S
45983	suhetes	suhe	suhe	06_S	PlIn	et	suhetes =suhe  (PlIn  >suhe !06_S
45993	igalühel	lühe	iga+lüht	22_S	PlAd	et	igalühel =lühe  (PlAd  >iga+lüht !22_S
45995	selleäärseid	äärse	selle+äärne	02_A	PlP	et	selleäärseid =äärse  (PlP  >selle+äärne !02_A
45999	levitada	levita	levitama	27_V	Inf	et	levitada =levita  (Inf  >levitama !27_V
46012	terminoloogiast	terminoloogia	terminoloogia	01_S	SgEl	et	terminoloogiast =terminoloogia  (SgEl  >terminoloogia !01_S
46013	väherahvuste	rahvus	vähe+rahvus	11~09_S	PlG	et	väherahvuste =rahvus  (PlG  >vähe+rahvus !11~09_S
46024	kolhoosikorra	korra	kolhoosi+kord	22_S	SgG	et	kolhoosikorra =korra  (SgG  >kolhoosi+kord !22_S
46026	kehvikute	kehviku	kehvik	02_S	PlG	et	kehvikute =kehviku  (PlG  >kehvik !02_S
46036	aimdus	aimdus	aimdus	11~09_S	SgN	et	aimdus =aimdus  (SgN  >aimdus !11~09_S
46037	kirjandusteostest	teos	kirjandus+teos	09_S	PlEl	et	kirjandusteostest =teos  (PlEl  >kirjandus+teos !09_S
46042	kirjandusteosed	teose	kirjandus+teos	09_S	PlN	et	kirjandusteosed =teose  (PlN  >kirjandus+teos !09_S
46046	koolitama	koolita	koolitama	27_V	Sup	et	koolitama =koolita  (Sup  >koolitama !27_V
46048	suurenema	suurene	suurenema	27_V	Sup	et	suurenema =suurene  (Sup  >suurenema !27_V
46054	polnudki	pol	olema	36_V	IndIpfPsN^	et	polnudki =pol  (IndIpfPsN^  >olema !36_V
46063	teatritegelane	tegelane	teatri+tegelane	12_S	SgN	et	teatritegelane =tegelane  (SgN  >teatri+tegelane !12_S
46068	kõrgkoolides	kooli	kõrg+kool	22_S	PlIn	et	kõrgkoolides =kooli  (PlIn  >kõrg+kool !22_S
46071	tsensuuriga	tsensuuri	tsensuur	22_S	SgKom	et	tsensuuriga =tsensuuri  (SgKom  >tsensuur !22_S
46072	veeb	veeb	veeb	22_S	SgN	et	veeb =veeb  (SgN  >veeb !22_S
46075	teri	teri	tera	17_S	PlP	et	teri =teri  (PlP  >tera !17_S
46093	baltiühing	ühing	balti+ühing	02_S	SgN	et	baltiühing =ühing  (SgN  >balti+ühing !02_S
46103	masinaehitusele	ehituse	masina+ehitus	11_S	SgAll	et	masinaehitusele =ehituse  (SgAll  >masina+ehitus !11_S
46110	ilukirjanduses	kirjanduse	ilu+kirjandus	11_S	SgIn	et	ilukirjanduses =kirjanduse  (SgIn  >ilu+kirjandus !11_S
46127	kommivabrik	vabrik	kommi+vabrik	02_S	SgN	et	kommivabrik =vabrik  (SgN  >kommi+vabrik !02_S
46132	laulukonkursid	konkursi	laulu+konkurss	22_S	PlN	et	laulukonkursid =konkursi  (PlN  >laulu+konkurss !22_S
45903	lojaalsed	lojaalse	lojaalne	02_A	PlN	et	lojaalsed =lojaalse  (PlN  >lojaalne !02_A
45905	meelelahutuslikud	lahutusliku	meele+lahutuslik	25_A	PlN	et	meelelahutuslikud =lahutusliku  (PlN  >meele+lahutuslik !25_A
45910	seisnes	seisne	seisnema	27_V	IndIpfSg3	et	seisnes =seisne  (IndIpfSg3  >seisnema !27_V
45916	identiteediprobleemid	probleemi	identiteedi+probleem	22_S	PlN	et	identiteediprobleemid =probleemi  (PlN  >identiteedi+probleem !22_S
45917	sakslast	sakslas	sakslane	12?10_S	SgP	et	sakslast =sakslas  (SgP  >sakslane !12?10_S
45928	delikatess	delikatess	delikatess	22_S	SgN	et	delikatess =delikatess  (SgN  >delikatess !22_S
45929	tööliseid	töölise	tööline	10_S	PlP	et	tööliseid =töölise  (PlP  >tööline !10_S
45931	välismaalasi	maalasi	välis+maalane	12_S	PlP	et	välismaalasi =maalasi  (PlP  >välis+maalane !12_S
45939	maavarade	vara	maa+vara	17_S	PlG	et	maavarade =vara  (PlG  >maa+vara !17_S
45940	defitsiitset	defitsiitse	defitsiitne	02_A	SgP	et	defitsiitset =defitsiitse  (SgP  >defitsiitne !02_A
45948	nimetaksin	nimeta	nimetama	27_V	KndPrSg1	et	nimetaksin =nimeta  (KndPrSg1  >nimetama !27_V
45949	sisemised	sisemise	sisemine	12_A	PlN	et	sisemised =sisemise  (PlN  >sisemine !12_A
45957	lääneriikidest	riiki	lääne+riik	22_S	PlEl	et	lääneriikidest =riiki  (PlEl  >lääne+riik !22_S
45963	sõjaväebaasidega	baasi	sõja+väe+baas	22_S	PlKom	et	sõjaväebaasidega =baasi  (PlKom  >sõja+väe+baas !22_S
45966	pärlijõe	jõe	pärli+jõgi	21_S	SgG	et	pärlijõe =jõe  (SgG  >pärli+jõgi !21_S
45968	taimeliikidest	liiki	taime+liik	22_S	PlEl	et	taimeliikidest =liiki  (PlEl  >taime+liik !22_S
45980	daamile	daami	daam	22_S	SgAll	et	daamile =daami  (SgAll  >daam !22_S
45986	elustiiliks	stiili	elu+stiil	22_S	SgTr	et	elustiiliks =stiili  (SgTr  >elu+stiil !22_S
45987	vähese	vähese	vähene	10_A	SgG	et	vähese =vähese  (SgG  >vähene !10_A
45997	varad	vara	vara	17_S	PlN	et	varad =vara  (PlN  >vara !17_S
46010	tähtsateks	tähtsa	tähtis	02_A	PlTr	et	tähtsateks =tähtsa  (PlTr  >tähtis !02_A
46016	terror	terror	terror	02_S	SgN	et	terror =terror  (SgN  >terror !02_S
46017	sovhoosidest	sovhoosi	sovhoos	22_S	PlEl	et	sovhoosidest =sovhoosi  (PlEl  >sovhoos !22_S
46020	kirjanikele	kirjanike	kirjanik	25_S	PlAll	et	kirjanikele =kirjanike  (PlAll  >kirjanik !25_S
46022	riigivaenlaste	vaenlas	riigi+vaenlane	12?10_S	PlG	et	riigivaenlaste =vaenlas  (PlG  >riigi+vaenlane !12?10_S
46027	väljaarendamine	arendamine	välja+arendamine	12_S	SgN	et	väljaarendamine =arendamine  (SgN  >välja+arendamine !12_S
46028	emakeelse	keelse	ema+keelne	02_A	SgG	et	emakeelse =keelse  (SgG  >ema+keelne !02_A
46029	auhinnati	hinna	au+hindama	29_V	IndIpfIps	et	auhinnati =hinna  (IndIpfIps  >au+hindama !29_V
46030	tõrjuma	tõrju	tõrjuma	28_V	Sup	et	tõrjuma =tõrju  (Sup  >tõrjuma !28_V
46031	vähemusrahvaid	rahva	vähemus+rahvas	07_S	PlP	et	vähemusrahvaid =rahva  (PlP  >vähemus+rahvas !07_S
46033	maanteede	tee	maan+tee	26_S	PlG	et	maanteede =tee  (PlG  >maan+tee !26_S
46040	2sotsialistlik	sotsialistlik	sotsialistlik	25_A	SgN	et	sotsialistlik =sotsialistlik  (SgN  >sotsialistlik !25_A
46044	ideaal	ideaal	ideaal	22_S	SgN	et	ideaal =ideaal  (SgN  >ideaal !22_S
46045	astronoomid	astronoomi	astronoom	22_S	PlN	et	astronoomid =astronoomi  (PlN  >astronoom !22_S
46049	kõikvõimalikud	võimaliku	kõik+võimalik	25_A	PlN	et	kõikvõimalikud =võimaliku  (PlN  >kõik+võimalik !25_A
46053	legaalne	legaalne	legaalne	02_A	SgN	et	legaalne =legaalne  (SgN  >legaalne !02_A
46059	ismid	ismi	ism	22_S	PlN	et	ismid =ismi  (PlN  >ism !22_S
46062	maakondade	maakonda	maakond	22_S	PlG	et	maakondade =maakonda  (PlG  >maakond !22_S
46066	stipendiumit	stipendiumi	stipendium	02_S	SgP	et	stipendiumit =stipendiumi  (SgP  >stipendium !02_S
46073	funktsioneeris	funktsioneeri	funktsioneerima	28_V	IndIpfSg3	et	funktsioneeris =funktsioneeri  (IndIpfSg3  >funktsioneerima !28_V
46074	masinaid	masina	masin	02_S	PlP	et	masinaid =masina  (PlP  >masin !02_S
46076	tarbeid	tarbe	tarve	06_S	PlP	et	tarbeid =tarbe  (PlP  >tarve !06_S
46077	harimismasinaid	masina	hari+mis+masin	02_S	PlP	et	harimismasinaid =masina  (PlP  >hari+mis+masin !02_S
46085	tööstusele	tööstuse	tööstus	11~09_S	SgAll	et	tööstusele =tööstuse  (SgAll  >tööstus !11~09_S
46086	kultuuriruumis	ruumi	kultuuri+ruum	22_S	SgIn	et	kultuuriruumis =ruumi  (SgIn  >kultuuri+ruum !22_S
46087	väljapaistvatele	paistva	välja+paistev	02_A	PlAll	et	väljapaistvatele =paistva  (PlAll  >välja+paistev !02_A
46088	kultuuritegijatele	tegija	kultuuri+tegija	01_S	PlAll	et	kultuuritegijatele =tegija  (PlAll  >kultuuri+tegija !01_S
46101	8suurim	suuri	suur	13_A	IM_sA	et	"suurim %suuri  )IM_sA  <suur ;13_A
46102	välisjõu	jõu	välis+jõud	22_S	SgG	et	välisjõu =jõu  (SgG  >välis+jõud !22_S
46105	oopium	oopium	oopium	19~02_S	SgN	et	oopium =oopium  (SgN  >oopium !19~02_S
46107	kandidaadi	kandidaadi	kandidaat	22_S	SgG	et	kandidaadi =kandidaadi  (SgG  >kandidaat !22_S
45912	mudelile	mudeli	mudel	02_S	SgAll	et	mudelile =mudeli  (SgAll  >mudel !02_S
45920	soojuselektrijaam	jaam	soojus+elektri+jaam	22_S	SgN	et	soojuselektrijaam =jaam  (SgN  >soojus+elektri+jaam !22_S
45932	grandioosne	grandioosne	grandioosne	02_A	SgN	et	grandioosne =grandioosne  (SgN  >grandioosne !02_A
45933	ratsionalistlik	ratsionalistlik	ratsionalistlik	25_A	SgN	et	ratsionalistlik =ratsionalistlik  (SgN  >ratsionalistlik !25_A
45937	kaevandata	kaevanda	kaevandama	27_V	IndPrIps_	et	kaevandata =kaevanda  (IndPrIps_  >kaevandama !27_V
45938	tulemusega	tulemuse	tulemus	11_S	SgKom	et	tulemusega =tulemuse  (SgKom  >tulemus !11_S
45945	kleidis	kleidi	kleit	22_S	SgIn	et	kleidis =kleidi  (SgIn  >kleit !22_S
45952	majandusharuks	haru	majandus+haru	17_S	SgTr	et	majandusharuks =haru  (SgTr  >majandus+haru !17_S
45954	perioodile	perioodi	periood	22_S	SgAll	et	perioodile =perioodi  (SgAll  >periood !22_S
45962	tööstusrajooniks	rajooni	tööstus+rajoon	22_S	SgTr	et	tööstusrajooniks =rajooni  (SgTr  >tööstus+rajoon !22_S
45967	karbid	karbi	karp	22_S	PlN	et	karbid =karbi  (PlN  >karp !22_S
45970	valitsemiskorral	korra	valitsemis+kord	22_S	SgAd	et	valitsemiskorral =korra  (SgAd  >valitsemis+kord !22_S
45972	jäänuste	jäänus	jäänus	09_S	PlG	et	jäänuste =jäänus  (PlG  >jäänus !09_S
45981	paljudki	palju	palju	16_P	PlN^	et	paljudki =palju  (PlN^  >palju !16_P
45988	lõppudeks	lõppu	lõpp	22_SA	PlTr	et	lõppudeks =lõppu  (PlTr  >lõpp !22_SA
45989	romaanikirjandus	kirjandus	romaani+kirjandus	11_S	SgN	et	romaanikirjandus =kirjandus  (SgN  >romaani+kirjandus !11_S
45998	metsadesse	metsa	mets	22_S	PlIll	et	metsadesse =metsa  (PlIll  >mets !22_S
46019	headele	hea	hea	26_AS	PlAll	et	headele =hea  (PlAll  >hea !26_AS
46032	aegseid	aegse	aegne	02_A	PlP	et	aegseid =aegse  (PlP  >aegne !02_A
46041	preemiaid	preemia	preemia	01_S	PlP	et	preemiaid =preemia  (PlP  >preemia !01_S
46047	kinomajade	maja	kino+maja	17_S	PlG	et	kinomajade =maja  (PlG  >kino+maja !17_S
46052	prostitutsioonist	prostitutsiooni	prostitutsioon	22_S	SgEl	et	prostitutsioonist =prostitutsiooni  (SgEl  >prostitutsioon !22_S
46055	tõstma	tõst	tõstma	34_V	Sup	et	tõstma =tõst  (Sup  >tõstma !34_V
46056	siiberisse	siiberi	siiber	02_S	SgIll	et	siiberisse =siiberi  (SgIll  >siiber !02_S
46058	kunstiloomind	ind	kunsti+loom+ind	22_S	SgN	et	kunstiloomind =ind  (SgN  >kunsti+loom+ind !22_S
46061	rahvusriikides	riiki	rahvus+riik	22_S	PlIn	et	rahvusriikides =riiki  (PlIn  >rahvus+riik !22_S
46064	karskusselts	selts	karskus+selts	22_S	SgN	et	karskusselts =selts  (SgN  >karskus+selts !22_S
46070	likvideeruma	likvideeru	likvideeruma	27_V	Sup	et	likvideeruma =likvideeru  (Sup  >likvideeruma !27_V
46078	tuhandeni	tuhande	tuhat	02_N	SgTer	et	tuhandeni =tuhande  (SgTer  >tuhat !02_N
46081	tooteturg	turg	toote+turg	22_S	SgN	et	tooteturg =turg  (SgN  >toote+turg !22_S
46091	inimkäitumisele	käitumise	inim+käitumine	12_S	SgAll	et	inimkäitumisele =käitumise  (SgAll  >inim+käitumine !12_S
46092	garanteerida	garanteeri	garanteerima	28_V	Inf	et	garanteerida =garanteeri  (Inf  >garanteerima !28_V
46097	kokkutulekud	tuleku	kokku+tulek	02_S	PlN	et	kokkutulekud =tuleku  (PlN  >kokku+tulek !02_S
46098	kp-kokkutulekud	tuleku	kp-kokku+tulek	02_S	PlN	et	kp-kokkutulekud =tuleku  (PlN  >kp-kokku+tulek !02_S
46108	sotsiaalideoloogiale	ideoloogia	sotsiaal+ideoloogia	01_S	SgAll	et	sotsiaalideoloogiale =ideoloogia  (SgAll  >sotsiaal+ideoloogia !01_S
46111	ideele	idee	idee	26_S	SgAll	et	ideele =idee  (SgAll  >idee !26_S
46119	ensv-aegses	aegse	ensv-aegne	02_A	SgIn	et	ensv-aegses =aegse  (SgIn  >ensv-aegne !02_A
46121	taasavaldama	avalda	taas+avaldama	27_V	Sup	et	taasavaldama =avalda  (Sup  >taas+avaldama !27_V
46126	eksport	eksport	eksport	22_S	SgN	et	eksport =eksport  (SgN  >eksport !22_S
46131	reklaamfilm	film	reklaam+film	22_S	SgN	et	reklaamfilm =film  (SgN  >reklaam+film !22_S
46133	hitte	hitte	hitt	22_S	PlP	et	hitte =hitte  (PlP  >hitt !22_S
46140	ühestainsast	ainsa	ühest+ainus	03~05_AS	SgEl	et	ühestainsast =ainsa  (SgEl  >ühest+ainus !03~05_AS
46146	lähivälismaana	maa	lähi+välis+maa	26_S	SgEs	et	lähivälismaana =maa  (SgEs  >lähi+välis+maa !26_S
46148	valuutakauplused	kaupluse	valuuta+kauplus	11~09_S	PlN	et	valuutakauplused =kaupluse  (PlN  >valuuta+kauplus !11~09_S
46151	kartuste	kartus	kartus	11~09_S	PlG	et	kartuste =kartus  (PlG  >kartus !11~09_S
46157	tekkele	tekke	teke	06_S	SgAll	et	tekkele =tekke  (SgAll  >teke !06_S
46158	kuulujuttudega	juttu	kuulu+jutt	22_S	PlKom	et	kuulujuttudega =juttu  (PlKom  >kuulu+jutt !22_S
46163	tarbijakaupu	kaupu	tarbija+kaup	22_S	PlP	et	tarbijakaupu =kaupu  (PlP  >tarbija+kaup !22_S
46164	külmkapid	kapi	külm+kapp	22_S	PlN	et	külmkapid =kapi  (PlN  >külm+kapp !22_S
46165	erisoodustus	soodustus	eri+soodustus	11_S	SgN	et	erisoodustus =soodustus  (SgN  >eri+soodustus !11_S
46172	stagnaperiood	periood	stagna+periood	22_S	SgN	et	stagnaperiood =periood  (SgN  >stagna+periood !22_S
46181	loomeinimesed	inimese	loome+inimene	12_S	PlN	et	loomeinimesed =inimese  (PlN  >loome+inimene !12_S
45943	perekonnaliikmetele	liikme	pere+konna+liige	05_S	PlAll	et	perekonnaliikmetele =liikme  (PlAll  >pere+konna+liige !05_S
45946	imetles	imetle	imetlema	27_V	IndIpfSg3	et	imetles =imetle  (IndIpfSg3  >imetlema !27_V
45950	aas	aas	aas	22_S	SgN	et	aas =aas  (SgN  >aas !22_S
45953	sõjatööstus	tööstus	sõja+tööstus	11~09_S	SgN	et	sõjatööstus =tööstus  (SgN  >sõja+tööstus !11~09_S
45964	joogiveeta	vee	joogi+vesi	15_S	SgAb	et	joogiveeta =vee  (SgAb  >joogi+vesi !15_S
45976	tammsaarel	saare	tamm+saar	13_S	SgAd	et	tammsaarel =saare  (SgAd  >tamm+saar !13_S
45977	mõttekäigust	käigu	mõtte+käik	22_S	SgEl	et	mõttekäigust =käigu  (SgEl  >mõtte+käik !22_S
45978	niisugusele	suguse	nii+sugune	10_P	SgAll	et	niisugusele =suguse  (SgAll  >nii+sugune !10_P
45979	peenele	peene	peen	13_A	SgAll	et	peenele =peene  (SgAll  >peen !13_A
45984	sissekirjutus	kirjutus	sisse+kirjutus	11_S	SgN	et	sissekirjutus =kirjutus  (SgN  >sisse+kirjutus !11_S
45990	päritolust	olu	pärit+olu	17_S	SgEl	et	päritolust =olu  (SgEl  >pärit+olu !17_S
45991	ideaalidele	ideaali	ideaal	22_S	PlAll	et	ideaalidele =ideaali  (PlAll  >ideaal !22_S
45994	mahus	mahu	maht	22_S	SgIn	et	mahus =mahu  (SgIn  >maht !22_S
45996	rajoone	rajoone	rajoon	22_S	PlP	et	rajoone =rajoone  (PlP  >rajoon !22_S
46000	põldudele	põldu	põld	22_S	PlAll	et	põldudele =põldu  (PlAll  >põld !22_S
46001	loodusliku	loodusliku	looduslik	25_A	SgG	et	loodusliku =loodusliku  (SgG  >looduslik !25_A
46003	mineraalvee	vee	mineraal+vesi	15_S	SgG	et	mineraalvee =vee  (SgG  >mineraal+vesi !15_S
46004	looduskaitsjate	kaitsja	loodus+kaitsja	01_S	PlG	et	looduskaitsjate =kaitsja  (PlG  >loodus+kaitsja !01_S
46007	varastati	varasta	varastama	27_V	IndIpfIps	et	varastati =varasta  (IndIpfIps  >varastama !27_V
46008	piimatoodete	toode	piima+toode	06_S	PlG	et	piimatoodete =toode  (PlG  >piima+toode !06_S
46011	suurtemas	ema	suurt+ema	17_S	SgIn	et	suurtemas =ema  (SgIn  >suurt+ema !17_S
46014	kultuurmudeli	mudeli	kultuur+mudel	02_S	SgG	et	kultuurmudeli =mudeli  (SgG  >kultuur+mudel !02_S
46015	pansione	pansione	pansion	19_S	PlP	et	pansione =pansione  (PlP  >pansion !19_S
46021	auhinnaks	hinna	au+hind	22_S	SgTr	et	auhinnaks =hinna  (SgTr  >au+hind !22_S
46023	hüsteerilise	hüsteerilise	hüsteeriline	12_A	SgG	et	hüsteerilise =hüsteerilise  (SgG  >hüsteeriline !12_A
46035	kipsist	kipsi	kips	22_S	SgEl	et	kipsist =kipsi  (SgEl  >kips !22_S
46039	koondama	koonda	koondama	27_V	Sup	et	koondama =koonda  (Sup  >koondama !27_V
46065	finantseeris	finantseeri	finantseerima	28_V	IndIpfSg3	et	finantseeris =finantseeri  (IndIpfSg3  >finantseerima !28_V
46069	instituute	instituute	instituut	22_S	PlP	et	instituute =instituute  (PlP  >instituut !22_S
46082	turukaotamine	kaotamine	turu+kaotamine	12_S	SgN	et	turukaotamine =kaotamine  (SgN  >turu+kaotamine !12_S
46083	majanduspoliitikat	poliitika	majandus+poliitika	01_S	SgP	et	majanduspoliitikat =poliitika  (SgP  >majandus+poliitika !01_S
46089	kirjandusnäide	näide	kirjandus+näide	06_S	SgN	et	kirjandusnäide =näide  (SgN  >kirjandus+näide !06_S
46094	kokkuleppega	leppe	kokku+lepe	06_S	SgKom	et	kokkuleppega =leppe  (SgKom  >kokku+lepe !06_S
46095	alghariduse	hariduse	alg+haridus	11_S	SgG	et	alghariduse =hariduse  (SgG  >alg+haridus !11_S
46096	oblastid	oblasti	oblast	02_S	PlN	et	oblastid =oblasti  (PlN  >oblast !02_S
46099	väljapaistvate	paistva	välja+paistev	02_A	PlG	et	väljapaistvate =paistva  (PlG  >välja+paistev !02_A
46100	elektrijaame	jaame	elektri+jaam	22_S	PlP	et	elektrijaame =jaame  (PlP  >elektri+jaam !22_S
46109	traktaadid	traktaadi	traktaat	22_S	PlN	et	traktaadid =traktaadi  (PlN  >traktaat !22_S
46114	kogemustega	kogemus	kogemus	11_S	PlKom	et	kogemustega =kogemus  (PlKom  >kogemus !11_S
46115	kaadri	kaadri	kaader	02_S	SgG	et	kaadri =kaadri  (SgG  >kaader !02_S
46120	liitudesse	liitu	liit	22_S	PlIll	et	liitudesse =liitu  (PlIll  >liit !22_S
46129	erisoodustuse	soodustuse	eri+soodustus	11_S	SgG	et	erisoodustuse =soodustuse  (SgG  >eri+soodustus !11_S
46134	lastesaated	saate	laste+saade	06_S	PlN	et	lastesaated =saate  (PlN  >laste+saade !06_S
46138	rahvustunnetus	tunnetus	rahvus+tunnetus	11_S	SgN	et	rahvustunnetus =tunnetus  (SgN  >rahvus+tunnetus !11_S
46143	igiomane	omane	igi+omane	10_A	SgN	et	igiomane =omane  (SgN  >igi+omane !10_A
46145	äärmuslike	äärmuslike	äärmuslik	25_A	PlG	et	äärmuslike =äärmuslike  (PlG  >äärmuslik !25_A
46147	siide	siide	siid	22_S	PlP	et	siide =siide  (PlP  >siid !22_S
46160	libahundiski	hundi	liba+hunt	22_S	SgIn^	et	libahundiski =hundi  (SgIn^  >liba+hunt !22_S
46167	telerid	teleri	teler	02_S	PlN	et	telerid =teleri  (PlN  >teler !02_S
46173	humanitaarteadustes	teadus	humanitaar+teadus	11~09_S	PlIn	et	humanitaarteadustes =teadus  (PlIn  >humanitaar+teadus !11~09_S
46174	pealekasv	kasv	peale+kasv	22_S	SgN	et	pealekasv =kasv  (SgN  >peale+kasv !22_S
46176	maakoolid	kooli	maa+kool	22_S	PlN	et	maakoolid =kooli  (PlN  >maa+kool !22_S
46043	loosungid	loosungi	loosung	02_S	PlN	et	loosungid =loosungi  (PlN  >loosung !02_S
46050	tubakatoodete	toode	tubaka+toode	06_S	PlG	et	tubakatoodete =toode  (PlG  >tubaka+toode !06_S
46051	müügist	müügi	müük	22_S	SgEl	et	müügist =müügi  (SgEl  >müük !22_S
46057	kriitikale	kriitika	kriitika	01_S	SgAll	et	kriitikale =kriitika  (SgAll  >kriitika !01_S
46060	linnastub	linnastu	linnastuma	27_V	IndPrSg3	et	linnastub =linnastu  (IndPrSg3  >linnastuma !27_V
46067	raamatukogude	kogu	raamatu+kogu	17_S	PlG	et	raamatukogude =kogu  (PlG  >raamatu+kogu !17_S
46079	baltiriikidega	riiki	balti+riik	22_S	PlKom	et	baltiriikidega =riiki  (PlKom  >balti+riik !22_S
46080	stabiliseerus	stabiliseeru	stabiliseeruma	27_V	IndIpfSg3	et	stabiliseerus =stabiliseeru  (IndIpfSg3  >stabiliseeruma !27_V
46084	pöördudes	pöördu	pöörduma	27_V	Ger	et	pöördudes =pöördu  (Ger  >pöörduma !27_V
46090	eludes	elu	elu	17_S	PlIn	et	eludes =elu  (PlIn  >elu !17_S
46104	peet	peet	peet	22_S	SgN	et	peet =peet  (SgN  >peet !22_S
46106	vaikus	vaikus	vaikus	11~09_S	SgN	et	vaikus =vaikus  (SgN  >vaikus !11~09_S
46112	pärastsõjajärgsel	järgse	pärast+sõja+järgne	02_A	SgAd	et	pärastsõjajärgsel =järgse  (SgAd  >pärast+sõja+järgne !02_A
46113	haridusjanus	janu	haridus+janu	17_S	SgIn	et	haridusjanus =janu  (SgIn  >haridus+janu !17_S
46116	rahvamajad	maja	rahva+maja	17_S	PlN	et	rahvamajad =maja  (PlN  >rahva+maja !17_S
46117	laulukooride	koori	laulu+koor	22_S	PlG	et	laulukooride =koori  (PlG  >laulu+koor !22_S
46118	ev-ajakirjanduse	kirjanduse	ev-aja+kirjandus	11_S	SgG	et	ev-ajakirjanduse =kirjanduse  (SgG  >ev-aja+kirjandus !11_S
46124	tänul	tänu	tänu	17_S	SgAd	et	tänul =tänu  (SgAd  >tänu !17_S
46130	reklaamisaated	saate	reklaami+saade	06_S	PlN	et	reklaamisaated =saate  (PlN  >reklaami+saade !06_S
46135	koomiks	koomiks	koomiks	02_S	SgN	et	koomiks =koomiks  (SgN  >koomiks !02_S
46141	teistsuguse	suguse	teist+sugune	10_P	SgG	et	teistsuguse =suguse  (SgG  >teist+sugune !10_P
46144	kokkukuuluvustunne	tunne	kokku+kuuluvus+tunne	06_S	SgN	et	kokkukuuluvustunne =tunne  (SgN  >kokku+kuuluvus+tunne !06_S
46149	ebaõiglast	õiglas	eba+õiglane	12?10_A	SgP	et	ebaõiglast =õiglas  (SgP  >eba+õiglane !12?10_A
46150	süüdlaseks	süüdlase	süüdlane	12?10_S	SgTr	et	süüdlaseks =süüdlase  (SgTr  >süüdlane !12?10_S
46152	nõrgust	nõrgu	nõrk	22_A	PlEl	et	nõrgust =nõrgu  (PlEl  >nõrk !22_A
46154	eelarvamustele	arvamus	eel+arvamus	11_S	PlAll	et	eelarvamustele =arvamus  (PlAll  >eel+arvamus !11_S
46155	massist	massi	mass	22_S	SgEl	et	massist =massi  (SgEl  >mass !22_S
46177	maalapsed	lapse	maa+laps	14_S	PlN	et	maalapsed =lapse  (PlN  >maa+laps !14_S
46182	ignoreeriti	ignoreeri	ignoreerima	28_V	IndIpfIps	et	ignoreeriti =ignoreeri  (IndIpfIps  >ignoreerima !28_V
46193	taasiseseisvumisest	seisvumise	taas+ise+seisvumine	12_S	SgEl	et	taasiseseisvumisest =seisvumise  (SgEl  >taas+ise+seisvumine !12_S
46194	ebakindla	kindla	eba+kindel	02_A	SgG	et	ebakindla =kindla  (SgG  >eba+kindel !02_A
46195	maavarad	vara	maa+vara	17_S	PlN	et	maavarad =vara  (PlN  >maa+vara !17_S
46213	heisati	heisa	heiskama	29_V	IndIpfIps	et	heisati =heisa  (IndIpfIps  >heiskama !29_V
46214	võidame	võida	võitma	34_V	IndPrPl1	et	võidame =võida  (IndPrPl1  >võitma !34_V
46215	kütet	küte	küte	06_S	SgP	et	kütet =küte  (SgP  >küte !06_S
46221	väärarenguga	arengu	väär+areng	02_S	SgKom	et	väärarenguga =arengu  (SgKom  >väär+areng !02_S
46230	osavõtjat	võtja	osa+võtja	01_S	SgP	et	osavõtjat =võtja  (SgP  >osa+võtja !01_S
46243	kateeder	kateeder	kateeder	02_S	SgN	et	kateeder =kateeder  (SgN  >kateeder !02_S
46244	ametid	ameti	amet	02_S	PlN	et	ametid =ameti  (PlN  >amet !02_S
46259	poolne	poolne	poolne	02_A	SgN	et	poolne =poolne  (SgN  >poolne !02_A
46263	suveräänsusdeklaratsioon	deklaratsioon	suveräänsus+deklaratsioon	22_S	SgN	et	suveräänsusdeklaratsioon =deklaratsioon  (SgN  >suveräänsus+deklaratsioon !22_S
46269	külastab	külasta	külastama	27_V	IndPrSg3	et	külastab =külasta  (IndPrSg3  >külastama !27_V
46277	algkoolidest	kooli	alg+kool	22_S	PlEl	et	algkoolidest =kooli  (PlEl  >alg+kool !22_S
46288	erialaseltsid	seltsi	eri+ala+selts	22_S	PlN	et	erialaseltsid =seltsi  (PlN  >eri+ala+selts !22_S
46290	mõlemast	mõlema	mõlema	02_P	SgEl	et	mõlemast =mõlema  (SgEl  >mõlema !02_P
46303	pätsist	pätsi	päts	22_S	SgEl	et	pätsist =pätsi  (SgEl  >päts !22_S
46307	sini-must-valgeid	valge	sini-must-valge	01_AS	PlP	et	sini-must-valgeid =valge  (PlP  >sini-must-valge !01_AS
46309	rr-le	rr	rr	xx_Q	SgAll	et	rr-le =rr  (SgAll  >rr !xx_Q
46311	kemplus	kemplus	kemplus	11~09_S	SgN	et	kemplus =kemplus  (SgN  >kemplus !11~09_S
46315	taolise	taolise	taoline	12?10_A	SgG	et	taolise =taolise  (SgG  >taoline !12?10_A
46317	info-postid	posti	info-post	22_S	PlN	et	info-postid =posti  (PlN  >info-post !22_S
46325	savisaarelt	saare	savi+saar	13_S	SgAbl	et	savisaarelt =saare  (SgAbl  >savi+saar !13_S
46122	kunstivooludega	voolu	kunsti+vool	22_S	PlKom	et	kunstivooludega =voolu  (PlKom  >kunsti+vool !22_S
46123	võimuorganid	organi	võimu+organ	02_S	PlN	et	võimuorganid =organi  (PlN  >võimu+organ !02_S
46125	edasiminekut	mineku	edasi+minek	02_S	SgP	et	edasiminekut =mineku  (SgP  >edasi+minek !02_S
46128	pudi-padi	padi	pudi-padi	24_S	SgN	et	pudi-padi =padi  (SgN  >pudi-padi !24_S
46136	rahvalike	rahvalike	rahvalik	25_A	PlG	et	rahvalike =rahvalike  (PlG  >rahvalik !25_A
46137	protestivaim	vaim	protesti+vaim	22_S	SgN	et	protestivaim =vaim  (SgN  >protesti+vaim !22_S
46139	nõiaprotsessid	protsessi	nõia+protsess	22_S	PlN	et	nõiaprotsessid =protsessi  (PlN  >nõia+protsess !22_S
46153	nõid	nõid	nõid	22_S	SgN	et	nõid =nõid  (SgN  >nõid !22_S
46156	julgeb	julge	julgema	27_V	IndPrSg3	et	julgeb =julge  (IndPrSg3  >julgema !27_V
46161	igapäevaellu	ellu	iga+päeva+elu	17_S	SgAdt	et	igapäevaellu =ellu  (SgAdt  >iga+päeva+elu !17_S
46162	kohalviibimist	viibimis	kohal+viibimine	12_S	SgP	et	kohalviibimist =viibimis  (SgP  >kohal+viibimine !12_S
46166	kaupadele	kaupa	kaup	22_S	PlAll	et	kaupadele =kaupa  (PlAll  >kaup !22_S
46180	püsiühendus	ühendus	püsi+ühendus	11_S	SgN	et	püsiühendus =ühendus  (SgN  >püsi+ühendus !11_S
46184	teisitimõtlejaid	mõtleja	teisiti+mõtleja	01_S	PlP	et	teisitimõtlejaid =mõtleja  (PlP  >teisiti+mõtleja !01_S
46186	siinsele	siinse	siinne	02_A	SgAll	et	siinsele =siinse  (SgAll  >siinne !02_A
46187	piirangutega	piirangu	piirang	02_S	PlKom	et	piirangutega =piirangu  (PlKom  >piirang !02_S
46188	maailmaga	ilma	maa+ilm	22_S	SgKom	et	maailmaga =ilma  (SgKom  >maa+ilm !22_S
46200	kaartide	kaarti	kaart	22_S	PlG	et	kaartide =kaarti  (PlG  >kaart !22_S
46202	panganduses	panganduse	pangandus	11_S	SgIn	et	panganduses =panganduse  (SgIn  >pangandus !11_S
46205	välisinvesteeringutele	investeeringu	välis+investeering	02_S	PlAll	et	välisinvesteeringutele =investeeringu  (PlAll  >välis+investeering !02_S
46206	elanikule	elaniku	elanik	25_S	SgAll	et	elanikule =elaniku  (SgAll  >elanik !25_S
46211	takistada	takista	takistama	27_V	Inf	et	takistada =takista  (Inf  >takistama !27_V
46216	najaad	najaad	najaad	22_S	SgN	et	najaad =najaad  (SgN  >najaad !22_S
46217	traktoritega	traktori	traktor	02_S	PlKom	et	traktoritega =traktori  (PlKom  >traktor !02_S
46223	vajalikudega	vajaliku	vajalik	25_A	PlKom	et	vajalikudega =vajaliku  (PlKom  >vajalik !25_A
46225	toiduvarusid	varu	toidu+varu	17_S	PlP	et	toiduvarusid =varu  (PlP  >toidu+varu !17_S
46227	reaktsioon	reaktsioon	reaktsioon	22_S	SgN	et	reaktsioon =reaktsioon  (SgN  >reaktsioon !22_S
46228	masside	massi	mass	22_S	PlG	et	masside =massi  (PlG  >mass !22_S
46229	nsv-sse	nsv	nsv	xx_Q	SgIll	et	nsv-sse =nsv  (SgIll  >nsv !xx_Q
46237	seltskonna	seltskonna	seltskond	22_S	SgG	et	seltskonna =seltskonna  (SgG  >seltskond !22_S
46245	isiklukult	luku	isik+lukk	22_S	SgAbl	et	isiklukult =luku  (SgAbl  >isik+lukk !22_S
46250	aladeks	ala	ala	17_S	PlTr	et	aladeks =ala  (PlTr  >ala !17_S
46254	arutlema	arutle	arutlema	27_V	Sup	et	arutlema =arutle  (Sup  >arutlema !27_V
46255	valitsemisaeg	aeg	valitsemis+aeg	22_S	SgN	et	valitsemisaeg =aeg  (SgN  >valitsemis+aeg !22_S
46260	kodanike	kodanike	kodanik	25_S	PlG	et	kodanike =kodanike  (PlG  >kodanik !25_S
46262	registreerida	registreeri	registreerima	28_V	Inf	et	registreerida =registreeri  (Inf  >registreerima !28_V
46265	süsteemiks	süsteemi	süsteem	22_S	SgTr	et	süsteemiks =süsteemi  (SgTr  >süsteem !22_S
46268	ammenduma	ammendu	ammenduma	27_V	Sup	et	ammenduma =ammendu  (Sup  >ammenduma !27_V
46270	rahvarevolutsioon	revolutsioon	rahva+revolutsioon	22_S	SgN	et	rahvarevolutsioon =revolutsioon  (SgN  >rahva+revolutsioon !22_S
46271	iseseisvuspäev	päev	ise+seisvus+päev	22_S	SgN	et	iseseisvuspäev =päev  (SgN  >ise+seisvus+päev !22_S
46272	peatakse	takse	pea+taks	22_S	PlP	et	peatakse =takse  (PlP  >pea+taks !22_S
46273	folklooriorganisatsioon	organisatsioon	folkloori+organisatsioon	22_S	SgN	et	folklooriorganisatsioon =organisatsioon  (SgN  >folkloori+organisatsioon !22_S
46276	rakendusliku	rakendusliku	rakenduslik	25_A	SgG	et	rakendusliku =rakendusliku  (SgG  >rakenduslik !25_A
46279	lülitatakse	lülita	lülitama	27_V	IndPrIps	et	lülitatakse =lülita  (IndPrIps  >lülitama !27_V
46283	muudati	ati	muud+att	22_S	SgG	et	muudati =ati  (SgG  >muud+att !22_S
46285	bakalaureuse	bakalaureuse	bakalaureus	11_S	SgG	et	bakalaureuse =bakalaureuse  (SgG  >bakalaureus !11_S
46286	gümnaasiumideks	gümnaasiumi	gümnaasium	19_S	PlTr	et	gümnaasiumideks =gümnaasiumi  (PlTr  >gümnaasium !19_S
46289	korporatsioonid	korporatsiooni	korporatsioon	22_S	PlN	et	korporatsioonid =korporatsiooni  (PlN  >korporatsioon !22_S
46294	etnilised	etnilise	etniline	12_A	PlN	et	etnilised =etnilise  (PlN  >etniline !12_A
46295	aastapäeval	päeva	aasta+päev	22_S	SgAd	et	aastapäeval =päeva  (SgAd  >aasta+päev !22_S
46301	teemadeks	teema	teema	16_S	PlTr	et	teemadeks =teema  (PlTr  >teema !16_S
46310	laitis	lait	laitma	34_V	IndIpfSg3	et	laitis =lait  (IndIpfSg3  >laitma !34_V
46142	mahategemist	tegemis	maha+tegemine	12_S	SgP	et	mahategemist =tegemis  (SgP  >maha+tegemine !12_S
46159	igavasse	igava	igav	02_A	SgIll	et	igavasse =igava  (SgIll  >igav !02_A
46168	pükse	pükse	püks	23?22_S	PlP	et	pükse =pükse  (PlP  >püks !23?22_S
46169	kestma	kest	kestma	34_V	Sup	et	kestma =kest  (Sup  >kestma !34_V
46170	kultuuritarbimine	tarbimine	kultuuri+tarbimine	12_S	SgN	et	kultuuritarbimine =tarbimine  (SgN  >kultuuri+tarbimine !12_S
46171	teatrikülastajate	külastaja	teatri+külastaja	01_S	PlG	et	teatrikülastajate =külastaja  (PlG  >teatri+külastaja !01_S
46175	mälumängud	mängu	mälu+mäng	22_S	PlN	et	mälumängud =mängu  (PlN  >mälu+mäng !22_S
46178	töökohtadelt	kohta	töö+koht	22_S	PlAbl	et	töökohtadelt =kohta  (PlAbl  >töö+koht !22_S
46185	tiibadesse	tiiba	tiib	22_S	PlIll	et	tiibadesse =tiiba  (PlIll  >tiib !22_S
46190	piiririik	riik	piiri+riik	22_S	SgN	et	piiririik =riik  (SgN  >piiri+riik !22_S
46196	endistele	endis	endine	10~12_A	PlAll	et	endistele =endis  (PlAll  >endine !10~12_A
46197	omanikele	omanike	omanik	25_S	PlAll	et	omanikele =omanike  (PlAll  >omanik !25_S
46198	kauged	kauge	kauge	01_A	PlN	et	kauged =kauge  (PlN  >kauge !01_A
46201	kohtulikud	kohtuliku	kohtulik	25_A	PlN	et	kohtulikud =kohtuliku  (PlN  >kohtulik !25_A
46203	1990-te			xx_Q	PlG	et	-te =  (PlG  > !xx_Q
46209	rahvarindega	rinde	rahva+rinne	06_S	SgKom	et	rahvarindega =rinde  (SgKom  >rahva+rinne !06_S
46222	sund	sund	sund	22_S	SgN	et	sund =sund  (SgN  >sund !22_S
46232	õppematerjalidest	materjali	õppe+materjal	19_S	PlEl	et	õppematerjalidest =materjali  (PlEl  >õppe+materjal !19_S
46241	kunstile	kunsti	kunst	22_S	SgAll	et	kunstile =kunsti  (SgAll  >kunst !22_S
46258	vastaseks	vastase	vastane	10_AS	SgTr	et	vastaseks =vastase  (SgTr  >vastane !10_AS
46264	dotatsioon	dotatsioon	dotatsioon	22_S	SgN	et	dotatsioon =dotatsioon  (SgN  >dotatsioon !22_S
46267	pensionisüsteem	süsteem	pensioni+süsteem	22_S	SgN	et	pensionisüsteem =süsteem  (SgN  >pensioni+süsteem !22_S
46280	iseseisvumisteele	tee	ise+seisvumis+tee	26_S	SgAll	et	iseseisvumisteele =tee  (SgAll  >ise+seisvumis+tee !26_S
46287	mütsidki	mütsi	müts	22_S	PlN^	et	mütsidki =mütsi  (PlN^  >müts !22_S
46293	väärtseks	seks	väärt+seks	22_S	SgN	et	väärtseks =seks  (SgN  >väärt+seks !22_S
46298	rahvarindlased	rindlase	rahva+rindlane	12?10_S	PlN	et	rahvarindlased =rindlase  (PlN  >rahva+rindlane !12?10_S
46299	kohviõhtuid	õhtu	kohvi+õhtu	01_S	PlP	et	kohviõhtuid =õhtu  (PlP  >kohvi+õhtu !01_S
46304	sini-must-valged	valge	sini-must-valge	01_AS	PlN	et	sini-must-valged =valge  (PlN  >sini-must-valge !01_AS
46305	lipud	lipu	lipp	22_S	PlN	et	lipud =lipu  (PlN  >lipp !22_S
46306	sõnavõtud	võtu	sõna+võtt	22_S	PlN	et	sõnavõtud =võtu  (PlN  >sõna+võtt !22_S
46312	meeleavalduse	avalduse	meele+avaldus	11_S	SgG	et	meeleavalduse =avalduse  (SgG  >meele+avaldus !11_S
46313	vägivallatsemine	vallatsemine	vägi+vallatsemine	12_S	SgN	et	vägivallatsemine =vallatsemine  (SgN  >vägi+vallatsemine !12_S
46316	loosungiga	loosungi	loosung	02_S	SgKom	et	loosungiga =loosungi  (SgKom  >loosung !02_S
46319	aktiivseid	aktiivse	aktiivne	02_A	PlP	et	aktiivseid =aktiivse  (PlP  >aktiivne !02_A
46321	muinaskogude	kogu	muinas+kogu	17_S	PlG	et	muinaskogude =kogu  (PlG  >muinas+kogu !17_S
46323	ühistunnet	tunne	ühis+tunne	06_S	SgP	et	ühistunnet =tunne  (SgP  >ühis+tunne !06_S
46326	telesaates	saate	tele+saade	06_S	SgIn	et	telesaates =saate  (SgIn  >tele+saade !06_S
46335	nsvl-halb	halb	nsvl-halb	22_A	SgN	et	nsvl-halb =halb  (SgN  >nsvl-halb !22_A
46337	halvendas	halvenda	halvendama	27_V	IndIpfSg3	et	halvendas =halvenda  (IndIpfSg3  >halvendama !27_V
46340	detsembrikuus	kuu	detsembri+kuu	26_S	SgIn	et	detsembrikuus =kuu  (SgIn  >detsembri+kuu !26_S
46342	koosolekuid	oleku	koos+olek	02_S	PlP	et	koosolekuid =oleku  (PlP  >koos+olek !02_S
46347	seletaks	seleta	seletama	27_V	KndPrPs	et	seletaks =seleta  (KndPrPs  >seletama !27_V
46349	avalikustati	avalikusta	avalikustama	27_V	IndIpfIps	et	avalikustati =avalikusta  (IndIpfIps  >avalikustama !27_V
46353	seisud	seisu	seis	22_S	PlN	et	seisud =seisu  (PlN  >seis !22_S
46357	baasseadusi	seadusi	baas+seadus	11_S	PlP	et	baasseadusi =seadusi  (PlP  >baas+seadus !11_S
46366	jogurti	jogurti	jogurt	02_S	SgG	et	jogurti =jogurti  (SgG  >jogurt !02_S
46367	parter	parter	parter	02_S	SgN	et	parter =parter  (SgN  >parter !02_S
46386	sõiduvahendid	vahendi	sõidu+vahend	02_S	PlN	et	sõiduvahendid =vahendi  (PlN  >sõidu+vahend !02_S
46392	teravad	terava	terav	02_A	PlN	et	teravad =terava  (PlN  >terav !02_A
46393	mõõgad	mõõga	mõõk	22_S	PlN	et	mõõgad =mõõga  (PlN  >mõõk !22_S
46394	leiutiste	leiutis	leiutis	11_S	PlG	et	leiutiste =leiutis  (PlG  >leiutis !11_S
46401	transiitlinn	linn	transiit+linn	22_S	SgN	et	transiitlinn =linn  (SgN  >transiit+linn !22_S
46407	toomkoolid	kooli	toom+kool	22_S	PlN	et	toomkoolid =kooli  (PlN  >toom+kool !22_S
46179	naelu	naelu	nael	23?22_S	PlP	et	naelu =naelu  (PlP  >nael !23?22_S
46191	lihtsate	lihtsa	lihtne	02_A	PlG	et	lihtsate =lihtsa  (PlG  >lihtne !02_A
46208	natsionalismile	natsionalismi	natsionalism	22_S	SgAll	et	natsionalismile =natsionalismi  (SgAll  >natsionalism !22_S
46212	üleminna	inna	ülem+ind	22_S	SgG	et	üleminna =inna  (SgG  >ülem+ind !22_S
46218	banaane	banaane	banaan	22_S	PlP	et	banaane =banaane  (PlP  >banaan !22_S
46219	jogurtit	jogurti	jogurt	02_S	SgP	et	jogurtit =jogurti  (SgP  >jogurt !02_S
46220	odekolonne	odekolonne	odekolonn	22_S	PlP	et	odekolonne =odekolonne  (PlP  >odekolonn !22_S
46224	poeletid	leti	poe+lett	22_S	PlN	et	poeletid =leti  (PlN  >poe+lett !22_S
46226	abipakkidena	pakki	abi+pakk	22_S	PlEs	et	abipakkidena =pakki  (PlEs  >abi+pakk !22_S
46233	liitlaste	liitlas	liitlane	12?10_S	PlG	et	liitlaste =liitlas  (PlG  >liitlane !12?10_S
46234	seisakut	seisaku	seisak	02_S	SgP	et	seisakut =seisaku  (SgP  >seisak !02_S
46235	loominguid	loomingu	looming	02_S	PlP	et	loominguid =loomingu  (PlP  >looming !02_S
46236	lindid	lindi	lint	22_S	PlN	et	lindid =lindi  (PlN  >lint !22_S
46246	eurooplastena	eurooplas	eurooplane	12?10_S	PlEs	et	eurooplastena =eurooplas  (PlEs  >eurooplane !12?10_S
46249	tühjendati	tühjenda	tühjendama	27_V	IndIpfIps	et	tühjendati =tühjenda  (IndIpfIps  >tühjendama !27_V
46251	tagused	taguse	tagune	10_AS	PlN	et	tagused =taguse  (PlN  >tagune !10_AS
46252	koolivorme	vorme	kooli+vorm	22_S	PlP	et	koolivorme =vorme  (PlP  >kooli+vorm !22_S
46253	minevikuks	mineviku	minevik	25_S	SgTr	et	minevikuks =mineviku  (SgTr  >minevik !25_S
46257	massorganisatsioon	organisatsioon	mass+organisatsioon	22_S	SgN	et	massorganisatsioon =organisatsioon  (SgN  >mass+organisatsioon !22_S
46261	autonoomseks	autonoomse	autonoomne	02_A	SgTr	et	autonoomseks =autonoomse  (SgTr  >autonoomne !02_A
46266	meditsiiniks	meditsiini	meditsiin	22_S	SgTr	et	meditsiiniks =meditsiini  (SgTr  >meditsiin !22_S
46275	numbrid	numbri	number	02_S	PlN	et	numbrid =numbri  (PlN  >number !02_S
46278	sõjaväed	väe	sõja+vägi	21_S	PlN	et	sõjaväed =väe  (PlN  >sõja+vägi !21_S
46284	ainekavadega	kava	aine+kava	17_S	PlKom	et	ainekavadega =kava  (PlKom  >aine+kava !17_S
46291	taassünnib	sünni	taas+sündima	28_V	IndPrSg3	et	taassünnib =sünni  (IndPrSg3  >taas+sündima !28_V
46292	kultuurtegelased	tegelase	kultuur+tegelane	12_S	PlN	et	kultuurtegelased =tegelase  (PlN  >kultuur+tegelane !12_S
46297	riigina	riigi	riik	22_S	SgEs	et	riigina =riigi  (SgEs  >riik !22_S
46318	fosforiitki	fosforiit	fosforiit	22_S	SgN^	et	fosforiitki =fosforiit  (SgN^  >fosforiit !22_S
46330	tõkke	tõkke	tõke	06_S	SgG	et	tõkke =tõkke  (SgG  >tõke !06_S
46339	eesriie	riie	ees+riie	06_S	SgN	et	eesriie =riie  (SgN  >ees+riie !06_S
46344	ümberkorraldusi	korraldusi	ümber+korraldus	11_S	PlP	et	ümberkorraldusi =korraldusi  (PlP  >ümber+korraldus !11_S
46346	ümberkorraldamine	korraldamine	ümber+korraldamine	12_S	SgN	et	ümberkorraldamine =korraldamine  (SgN  >ümber+korraldamine !12_S
46354	korruptsioon	korruptsioon	korruptsioon	22_S	SgN	et	korruptsioon =korruptsioon  (SgN  >korruptsioon !22_S
46358	keelereform	reform	keele+reform	22_S	SgN	et	keelereform =reform  (SgN  >keele+reform !22_S
46359	kaubaga	kauba	kaup	22_S	SgKom	et	kaubaga =kauba  (SgKom  >kaup !22_S
46363	kaubapuudus	puudus	kauba+puudus	11~09_S	SgN	et	kaubapuudus =puudus  (SgN  >kauba+puudus !11~09_S
46364	ülearugi	ülearu	üle+aru	41_D	ID^	et	ülearugi =ülearu  (ID^  >üle+aru !41_D
46371	nüüdses	nüüdse	nüüdne	02_A	SgIn	et	nüüdses =nüüdse  (SgIn  >nüüdne !02_A
46373	kuivkünkad	künka	kuiv+küngas	07_S	PlN	et	kuivkünkad =künka  (PlN  >kuiv+küngas !07_S
46377	kaubandussuhted	suhte	kaubandus+suhe	06_S	PlN	et	kaubandussuhted =suhte  (PlN  >kaubandus+suhe !06_S
46379	tähestiku	tähestiku	tähestik	25_S	SgG	et	tähestiku =tähestiku  (SgG  >tähestik !25_S
46380	piltkivid	kivi	pilt+kivi	17_S	PlN	et	piltkivid =kivi  (PlN  >pilt+kivi !17_S
46383	purskati	ati	pursk+att	22_S	SgG	et	purskati =ati  (SgG  >pursk+att !22_S
46389	purjedega	purje	puri	24_S	PlKom	et	purjedega =purje  (PlKom  >puri !24_S
46406	visitatsioonid	visitatsiooni	visitatsioon	22_S	PlN	et	visitatsioonid =visitatsiooni  (PlN  >visitatsioon !22_S
46409	toomkirik	kirik	toom+kirik	02_S	SgN	et	toomkirik =kirik  (SgN  >toom+kirik !02_S
46410	väljapääs	pääs	välja+pääs	22_S	SgN	et	väljapääs =pääs  (SgN  >välja+pääs !22_S
46411	läänemerele	mere	lääne+meri	20_S	SgAll	et	läänemerele =mere  (SgAll  >lääne+meri !20_S
46412	transiidimaaks	maa	transiidi+maa	26_S	SgTr	et	transiidimaaks =maa  (SgTr  >transiidi+maa !26_S
46422	samastati	samasta	samastama	27_V	IndIpfIps	et	samastati =samasta  (IndIpfIps  >samastama !27_V
46430	meeltmööda	meeltmööda	meelt+mööda	41_A	ID	et	meeltmööda =meeltmööda  (ID  >meelt+mööda !41_A
46431	hansaliidu	liidu	hansa+liit	22_S	SgG	et	hansaliidu =liidu  (SgG  >hansa+liit !22_S
46183	väljatõrjumise	tõrjumise	välja+tõrjumine	12_S	SgG	et	väljatõrjumise =tõrjumise  (SgG  >välja+tõrjumine !12_S
46189	asendile	asendi	asend	02_S	SgAll	et	asendile =asendi  (SgAll  >asend !02_S
46192	elusfäärid	sfääri	elu+sfäär	22_S	PlN	et	elusfäärid =sfääri  (PlN  >elu+sfäär !22_S
46199	kinnisvarasid	vara	kinnis+vara	17_S	PlP	et	kinnisvarasid =vara  (PlP  >kinnis+vara !17_S
46204	täisliikmeks	liikme	täis+liige	05_S	SgTr	et	täisliikmeks =liikme  (SgTr  >täis+liige !05_S
46207	majandussfäärid	sfääri	majandus+sfäär	22_S	PlN	et	majandussfäärid =sfääri  (PlN  >majandus+sfäär !22_S
46210	streike	streike	streik	22_S	PlP	et	streike =streike  (PlP  >streik !22_S
46231	kõrgenes	kõrgene	kõrgenema	27_V	IndIpfSg3	et	kõrgenes =kõrgene  (IndIpfSg3  >kõrgenema !27_V
46238	101-st			xx_Q	SgEl	et	-st =  (SgEl  > !xx_Q
46239	kaubavahetusleping	leping	kauba+vahetus+leping	02_S	SgN	et	kaubavahetusleping =leping  (SgN  >kauba+vahetus+leping !02_S
46240	kasutuselevõtust	võtu	kasutusele+võtt	22_S	SgEl	et	kasutuselevõtust =võtu  (SgEl  >kasutusele+võtt !22_S
46242	reorganiseeriti	reorganiseeri	reorganiseerima	28_V	IndIpfIps	et	reorganiseeriti =reorganiseeri  (IndIpfIps  >reorganiseerima !28_V
46247	vabadena	vaba	vaba	17_A	PlEs	et	vabadena =vaba  (PlEs  >vaba !17_A
46248	keti	keti	kett	22_S	SgG	et	keti =keti  (SgG  >kett !22_S
46256	uutmoodi	uutmoodi	uut+moodi	41_D	ID	et	uutmoodi =uutmoodi  (ID  >uut+moodi !41_D
46274	õppimissuunad	suuna	õppimis+suund	22_S	PlN	et	õppimissuunad =suuna  (PlN  >õppimis+suund !22_S
46281	iseseisvateks	seisva	ise+seisev	02_A	PlTr	et	iseseisvateks =seisva  (PlTr  >ise+seisev !02_A
46282	seob	seo	siduma	28_V	IndPrSg3	et	seob =seo  (IndPrSg3  >siduma !28_V
46296	demokraatiaks	demokraatia	demokraatia	01_S	SgTr	et	demokraatiaks =demokraatia  (SgTr  >demokraatia !01_S
46300	kultuuripärandist	pärandi	kultuuri+pärand	02_S	SgEl	et	kultuuripärandist =pärandi  (SgEl  >kultuuri+pärand !02_S
46302	eestilk	tilk	ees+tilk	22_S	SgN	et	eestilk =tilk  (SgN  >ees+tilk !22_S
46308	taastas	taasta	taastama	27_V	IndIpfSg3	et	taastas =taasta  (IndIpfSg3  >taastama !27_V
46314	lased	lase	laskma	34_V	IndPrSg2	et	lased =lase  (IndPrSg2  >laskma !34_V
46322	eitas	eita	eitama	27_V	IndIpfSg3	et	eitas =eita  (IndIpfSg3  >eitama !27_V
46324	rahvus-meelsed	meelse	rahvus-meelne	02_A	PlN	et	rahvus-meelsed =meelse  (PlN  >rahvus-meelne !02_A
46328	interrindega	rinde	inter+rinne	06_S	SgKom	et	interrindega =rinde  (SgKom  >inter+rinne !06_S
46334	miitinguid	miitingu	miiting	02_S	PlP	et	miitinguid =miitingu  (PlP  >miiting !02_S
46336	kriisini	kriisi	kriis	22_S	SgTer	et	kriisini =kriisi  (SgTer  >kriis !22_S
46338	raudne	raudne	raudne	02_A	SgN	et	raudne =raudne  (SgN  >raudne !02_A
46343	rahvarinnete	rinne	rahva+rinne	06_S	PlG	et	rahvarinnete =rinne  (PlG  >rahva+rinne !06_S
46345	rahaühik	ühik	raha+ühik	02_S	SgN	et	rahaühik =ühik  (SgN  >raha+ühik !02_S
46352	varanduslik	varanduslik	varanduslik	25_A	SgN	et	varanduslik =varanduslik  (SgN  >varanduslik !25_A
46376	tavaks	tava	tava	17_S	SgTr	et	tavaks =tava  (SgTr  >tava !17_S
46381	ruunid	ruuni	ruun	22_S	PlN	et	ruunid =ruuni  (PlN  >ruun !22_S
46382	tähestikus	tähestiku	tähestik	25_S	SgIn	et	tähestikus =tähestiku  (SgIn  >tähestik !25_S
46385	üksusi	üksusi	üksus	11_S	PlP	et	üksusi =üksusi  (PlP  >üksus !11_S
46387	oid	oid	oid	22_S	SgN	et	oid =oid  (SgN  >oid !22_S
46390	kilbid	kilbi	kilp	22_S	PlN	et	kilbid =kilbi  (PlN  >kilp !22_S
46391	kiivrid	kiivri	kiiver	02_S	PlN	et	kiivrid =kiivri  (PlN  >kiiver !02_S
46395	muinasajavõitlusega	võitluse	muinas+aja+võitlus	11~09_S	SgKom	et	muinasajavõitlusega =võitluse  (SgKom  >muinas+aja+võitlus !11~09_S
46397	annuste	annus	annus	09_S	PlG	et	annuste =annus  (PlG  >annus !09_S
46399	nimedest	nime	nimi	20_S	PlEl	et	nimedest =nime  (PlEl  >nimi !20_S
46400	maapindade	pinda	maa+pind	22_S	PlG	et	maapindade =pinda  (PlG  >maa+pind !22_S
46402	teravili	vili	tera+vili	24_S	SgN	et	teravili =vili  (SgN  >tera+vili !24_S
46413	vallutas	valluta	vallutama	27_V	IndIpfSg3	et	vallutas =valluta  (IndIpfSg3  >vallutama !27_V
46416	pühakultused	kultuse	püha+kultus	11~09_S	PlN	et	pühakultused =kultuse  (PlN  >püha+kultus !11~09_S
46418	kultused	kultuse	kultus	11~09_S	PlN	et	kultused =kultuse  (PlN  >kultus !11~09_S
46434	humalat	humala	humal	02_S	SgP	et	humalat =humala  (SgP  >humal !02_S
46435	linnakultuurist	kultuuri	linna+kultuur	22_S	SgEl	et	linnakultuurist =kultuuri  (SgEl  >linna+kultuur !22_S
46436	meresõitude	sõitu	mere+sõit	22_S	PlG	et	meresõitude =sõitu  (PlG  >mere+sõit !22_S
46437	saksteks	saks	saks	23_S	PlTr	et	saksteks =saks  (PlTr  >saks !23_S
46447	tsunftide	tsunfti	tsunft	22_S	PlG	et	tsunftide =tsunfti  (PlG  >tsunft !22_S
46460	surmatants	tants	surma+tants	22_S	SgN	et	surmatants =tants  (SgN  >surma+tants !22_S
46461	määr	määr	määr	22_S	SgN	et	määr =määr  (SgN  >määr !22_S
46320	võõravõimude	võimu	võõra+võim	22_S	PlG	et	võõravõimude =võimu  (PlG  >võõra+võim !22_S
46329	põhilise	põhilise	põhiline	12_A	SgG	et	põhilise =põhilise  (SgG  >põhiline !12_A
46332	rr-ga	rr	rr	xx_Q	SgKom	et	rr-ga =rr  (SgKom  >rr !xx_Q
46350	enesetundmise	tundmise	enese+tundmine	12?10_S	SgG	et	enesetundmise =tundmise  (SgG  >enese+tundmine !12?10_S
46355	majandusolukord	kord	majandus+olu+kord	22_S	SgN	et	majandusolukord =kord  (SgN  >majandus+olu+kord !22_S
46356	stabiliseerida	stabiliseeri	stabiliseerima	28_V	Inf	et	stabiliseerida =stabiliseeri  (Inf  >stabiliseerima !28_V
46360	sõjaväeüksused	üksuse	sõja+väe+üksus	11~09_S	PlN	et	sõjaväeüksused =üksuse  (PlN  >sõja+väe+üksus !11~09_S
46361	elektrikriis	kriis	elektri+kriis	22_S	SgN	et	elektrikriis =kriis  (SgN  >elektri+kriis !22_S
46368	asitõendeid	tõende	asi+tõend	02_S	PlP	et	asitõendeid =tõende  (PlP  >asi+tõend !02_S
46370	kivipilt	pilt	kivi+pilt	22_S	SgN	et	kivipilt =pilt  (SgN  >kivi+pilt !22_S
46372	alades	ala	ala	17_S	PlIn	et	alades =ala  (PlIn  >ala !17_S
46374	vallid	valli	vall	22_S	PlN	et	vallid =valli  (PlN  >vall !22_S
46375	aaretes	aare	aare	06_S	PlIn	et	aaretes =aare  (PlIn  >aare !06_S
46378	tähestik	tähestik	tähestik	25_S	SgN	et	tähestik =tähestik  (SgN  >tähestik !25_S
46388	esimestega	esimes	esimene	12_OP	PlKom	et	esimestega =esimes  (PlKom  >esimene !12_OP
46396	elamud	elamu	elamu	01_S	PlN	et	elamud =elamu  (PlN  >elamu !01_S
46403	kangad	kanga	kangas	07_S	PlN	et	kangad =kanga  (PlN  >kangas !07_S
46404	raat	raat	raat	22_S	SgN	et	raat =raat  (SgN  >raat !22_S
46408	maaelanikele	elanike	maa+elanik	25_S	PlAll	et	maaelanikele =elanike  (PlAll  >maa+elanik !25_S
46414	paganlik	paganlik	paganlik	25_A	SgN	et	paganlik =paganlik  (SgN  >paganlik !25_A
46424	muinasusud	usu	muinas+usk	22_S	PlN	et	muinasusud =usu  (PlN  >muinas+usk !22_S
46425	kirikuteenistus	teenistus	kiriku+teenistus	11_S	SgN	et	kirikuteenistus =teenistus  (SgN  >kiriku+teenistus !11_S
46426	pihtida	pihti	pihtima	28_V	Inf	et	pihtida =pihti  (Inf  >pihtima !28_V
46432	hansaliit	liit	hansa+liit	22_S	SgN	et	hansaliit =liit  (SgN  >hansa+liit !22_S
46433	keskpunkt	punkt	kesk+punkt	22_S	SgN	et	keskpunkt =punkt  (SgN  >kesk+punkt !22_S
46442	rahasepad	sepa	raha+sepp	22_S	PlN	et	rahasepad =sepa  (PlN  >raha+sepp !22_S
46444	alamtööga	töö	alam+töö	26_S	SgKom	et	alamtööga =töö  (SgKom  >alam+töö !26_S
46446	kingsepad	sepa	king+sepp	22_S	PlN	et	kingsepad =sepa  (PlN  >king+sepp !22_S
46450	transiitkaubandus	kaubandus	transiit+kaubandus	11_S	SgN	et	transiitkaubandus =kaubandus  (SgN  >transiit+kaubandus !11_S
46451	altarite	altari	altar	02_S	PlG	et	altarite =altari  (PlG  >altar !02_S
46454	linnarahvale	rahva	linna+rahvas	07_S	SgAll	et	linnarahvale =rahva  (SgAll  >linna+rahvas !07_S
46455	kirikuõpetajatel	õpetaja	kiriku+õpetaja	01_S	PlAd	et	kirikuõpetajatel =õpetaja  (PlAd  >kiriku+õpetaja !01_S
46458	rootsiajal	aja	rootsi+aeg	22_S	SgAd	et	rootsiajal =aja  (SgAd  >rootsi+aeg !22_S
46459	maalikultuur	kultuur	maali+kultuur	22_S	SgN	et	maalikultuur =kultuur  (SgN  >maali+kultuur !22_S
46466	senise	senise	senine	10_A	SgG	et	senise =senise  (SgG  >senine !10_A
46479	müntida	münti	müntima	28_V	Inf	et	müntida =münti  (Inf  >müntima !28_V
46493	emakirik	kirik	ema+kirik	02_S	SgN	et	emakirik =kirik  (SgN  >ema+kirik !02_S
46504	julmad	julma	julm	22_A	PlN	et	julmad =julma  (PlN  >julm !22_A
46505	pommitatakse	pommita	pommitama	27_V	IndPrIps	et	pommitatakse =pommita  (IndPrIps  >pommitama !27_V
46513	dolomiit	dolomiit	dolomiit	22_S	SgN	et	dolomiit =dolomiit  (SgN  >dolomiit !22_S
46515	linnamüürid	müüri	linna+müür	22_S	PlN	et	linnamüürid =müüri  (PlN  >linna+müür !22_S
46516	kitsad	kitsa	kitsas	07_A	PlN	et	kitsad =kitsa  (PlN  >kitsas !07_A
46541	põikpäisus	päisus	põik+päisus	11~09_S	SgN	et	põikpäisus =päisus  (SgN  >põik+päisus !11~09_S
46542	muinasusunditavade	tava	muinas+usundi+tava	17_S	PlG	et	muinasusunditavade =tava  (PlG  >muinas+usundi+tava !17_S
46543	usundile	usundi	usund	02_S	SgAll	et	usundile =usundi  (SgAll  >usund !02_S
46554	põllumajanduslikel	majanduslike	põllu+majanduslik	25_A	PlAd	et	põllumajanduslikel =majanduslike  (PlAd  >põllu+majanduslik !25_A
46562	piiskopid	piiskopi	piiskop	22_S	PlN	et	piiskopid =piiskopi  (PlN  >piiskop !22_S
46568	põhja-saksamaalt	maa	põhja-saksa+maa	26_S	SgAbl	et	põhja-saksamaalt =maa  (SgAbl  >põhja-saksa+maa !26_S
46570	kroonik	kroonik	kroonik	02_S	SgN	et	kroonik =kroonik  (SgN  >kroonik !02_S
46593	talupoegael	gael	talu+poe+gael	22_S	SgN	et	talupoegael =gael  (SgN  >talu+poe+gael !22_S
46598	kiht	kiht	kiht	22_S	SgN	et	kiht =kiht  (SgN  >kiht !22_S
46607	vennaskond	vennaskond	vennaskond	22_S	SgN	et	vennaskond =vennaskond  (SgN  >vennaskond !22_S
46619	kott	kott	kott	22_S	SgN	et	kott =kott  (SgN  >kott !22_S
46327	vanameelsete	meelse	vana+meelne	02_A	PlG	et	vanameelsete =meelse  (PlG  >vana+meelne !02_A
46331	võimsaks	võimsa	võimas	03~05_A	SgTr	et	võimsaks =võimsa  (SgTr  >võimas !03~05_A
46333	rahvakogunemisi	kogunemisi	rahva+kogunemine	12_S	PlP	et	rahvakogunemisi =kogunemisi  (PlP  >rahva+kogunemine !12_S
46341	maikuus	kuu	mai+kuu	26_S	SgIn	et	maikuus =kuu  (SgIn  >mai+kuu !26_S
46348	ümberkorraldamise	korraldamise	ümber+korraldamine	12_S	SgG	et	ümberkorraldamise =korraldamise  (SgG  >ümber+korraldamine !12_S
46351	valimisliiduga	liidu	valimis+liit	22_S	SgKom	et	valimisliiduga =liidu  (SgKom  >valimis+liit !22_S
46362	elamurajoonid	rajooni	elamu+rajoon	22_S	PlN	et	elamurajoonid =rajooni  (PlN  >elamu+rajoon !22_S
46365	liikmesriikide	riiki	liikmes+riik	22_S	PlG	et	liikmesriikide =riiki  (PlG  >liikmes+riik !22_S
46369	piltkive	kive	pilt+kivi	17_S	PlP	et	piltkive =kive  (PlP  >pilt+kivi !17_S
46384	territoriaalseid	territoriaalse	territoriaalne	02_A	PlP	et	territoriaalseid =territoriaalse  (PlP  >territoriaalne !02_A
46398	õppimisprotsess	protsess	õppimis+protsess	22_S	SgN	et	õppimisprotsess =protsess  (SgN  >õppimis+protsess !22_S
46405	piiskop	piiskop	piiskop	22_S	SgN	et	piiskop =piiskop  (SgN  >piiskop !22_S
46427	tavapäradega	pära	tava+pära	17_S	PlKom	et	tavapäradega =pära  (PlKom  >tava+pära !17_S
46438	päritoluga	olu	pärit+olu	17_S	SgKom	et	päritoluga =olu  (SgKom  >pärit+olu !17_S
46441	vasesepad	sepa	vase+sepp	22_S	PlN	et	vasesepad =sepa  (PlN  >vase+sepp !22_S
46448	gildide	gildi	gild	22_S	PlG	et	gildide =gildi  (PlG  >gild !22_S
46449	ametimehed	mehe	ameti+mees	13_S	PlN	et	ametimehed =mehe  (PlN  >ameti+mees !13_S
46453	abieluinimesed	inimese	abi+elu+inimene	12_S	PlN	et	abieluinimesed =inimese  (PlN  >abi+elu+inimene !12_S
46457	tõlkide	tõlki	tõlk	22_S	PlG	et	tõlkide =tõlki  (PlG  >tõlk !22_S
46488	köit	köi	köis	14_S	SgP	et	köit =köi  (SgP  >köis !14_S
46490	põleda	põle	põlema	27_V	Inf	et	põleda =põle  (Inf  >põlema !27_V
46491	kaubanduslinn	linn	kaubandus+linn	22_S	SgN	et	kaubanduslinn =linn  (SgN  >kaubandus+linn !22_S
46492	jälgiti	jälgi	jälgima	27_V	IndIpfIps	et	jälgiti =jälgi  (IndIpfIps  >jälgima !27_V
46496	püsib19	püsi	püsima	27_V	IndPrSg3	et	püsib =püsi  (IndPrSg3  >püsima !27_V
46501	usklikke	usklikke	usklik	25_AS	PlP	et	usklikke =usklikke  (PlP  >usklik !25_AS
46503	tatarlased	tatarlase	tatarlane	12_S	PlN	et	tatarlased =tatarlase  (PlN  >tatarlane !12_S
46506	mõneks	mõne	mõni	20_P	SgTr	et	mõneks =mõne  (SgTr  >mõni !20_P
46508	eelkäijaks	käija	eel+käija	01_S	SgTr	et	eelkäijaks =käija  (SgTr  >eel+käija !01_S
46512	misjonärid	misjonäri	misjonär	19_S	PlN	et	misjonärid =misjonäri  (PlN  >misjonär !19_S
46519	bürgermeistrid	meistri	bürger+meister	02_S	PlN	et	bürgermeistrid =meistri  (PlN  >bürger+meister !02_S
46521	linnafoogt	foogt	linna+foogt	22_S	SgN	et	linnafoogt =foogt  (SgN  >linna+foogt !22_S
46523	gild	gild	gild	22_S	SgN	et	gild =gild  (SgN  >gild !22_S
46525	ladinakeelne	keelne	ladina+keelne	02_A	SgN	et	ladinakeelne =keelne  (SgN  >ladina+keelne !02_A
46534	sisemereks	mere	sise+meri	20_S	SgTr	et	sisemereks =mere  (SgTr  >sise+meri !20_S
46545	sarnanes	sarnane	sarnanema	27_V	IndIpfSg3	et	sarnanes =sarnane  (IndIpfSg3  >sarnanema !27_V
46547	rituaalidele	rituaali	rituaal	22_S	PlAll	et	rituaalidele =rituaali  (PlAll  >rituaal !22_S
46551	õitseajaga	aja	õitse+aeg	22_S	SgKom	et	õitseajaga =aja  (SgKom  >õitse+aeg !22_S
46553	vähesest	vähese	vähene	10_A	SgEl	et	vähesest =vähese  (SgEl  >vähene !10_A
46566	maksudeks	maksu	maks	22_S	PlTr	et	maksudeks =maksu  (PlTr  >maks !22_S
46567	kroonikut	krooniku	kroonik	02_S	SgP	et	kroonikut =krooniku  (SgP  >kroonik !02_S
46569	eestimaast	maa	eesti+maa	26_S	SgEl	et	eestimaast =maa  (SgEl  >eesti+maa !26_S
46571	pühitseti	pühitse	pühitsema	27_V	IndIpfIps	et	pühitseti =pühitse  (IndIpfIps  >pühitsema !27_V
46575	keeltesse	keel	keel	13_S	PlIll	et	keeltesse =keel  (PlIll  >keel !13_S
46580	mõisamajandus	majandus	mõisa+majandus	11_S	SgN	et	mõisamajandus =majandus  (SgN  >mõisa+majandus !11_S
46583	ärakirjade	kirja	ära+kiri	24_S	PlG	et	ärakirjade =kirja  (PlG  >ära+kiri !24_S
46594	kristlased	kristlase	kristlane	12?10_S	PlN	et	kristlased =kristlase  (PlN  >kristlane !12?10_S
46608	tsunft	tsunft	tsunft	22_S	SgN	et	tsunft =tsunft  (SgN  >tsunft !22_S
46612	jumalateenused	teenuse	jumala+teenus	09_S	PlN	et	jumalateenused =teenuse  (PlN  >jumala+teenus !09_S
46614	e-l	e	e	xx_Q	SgAd	et	e-l =e  (SgAd  >e !xx_Q
46616	tööõpetus	õpetus	töö+õpetus	11_S	SgN	et	tööõpetus =õpetus  (SgN  >töö+õpetus !11_S
46617	täiskasvasel	vase	täis+kas+vask	22_S	SgAd	et	täiskasvasel =vase  (SgAd  >täis+kas+vask !22_S
46618	politseile	politsei	politsei	26_S	SgAll	et	politseile =politsei  (SgAll  >politsei !26_S
46627	mõlkis	mõlkis	mõlkis	41_DA	ID	et	mõlkis =mõlkis  (ID  >mõlkis !41_DA
46415	paganlike	paganlike	paganlik	25_A	PlG	et	paganlike =paganlike  (PlG  >paganlik !25_A
46417	paganate	pagana	pagan	02_S	PlG	et	paganate =pagana  (PlG  >pagan !02_S
46419	kalmistutel	kalmistu	kalmistu	01_S	PlAd	et	kalmistutel =kalmistu  (PlAd  >kalmistu !01_S
46420	kiriklike	kiriklike	kiriklik	25_A	PlG	et	kiriklike =kiriklike  (PlG  >kiriklik !25_A
46421	rituaale	rituaale	rituaal	22_S	PlP	et	rituaale =rituaale  (PlP  >rituaal !22_S
46423	põhjustest	põhjus	põhjus	11~09_S	PlEl	et	põhjustest =põhjus  (PlEl  >põhjus !11~09_S
46428	paganatele	pagana	pagan	02_S	PlAll	et	paganatele =pagana  (PlAll  >pagan !02_S
46429	kirikukalmistutel	kalmistu	kiriku+kalmistu	01_S	PlAd	et	kirikukalmistutel =kalmistu  (PlAd  >kiriku+kalmistu !01_S
46439	aadlis	aadli	aadel	02_S	SgIn	et	aadlis =aadli  (SgIn  >aadel !02_S
46440	kullassepad	sepa	kullas+sepp	22_S	PlN	et	kullassepad =sepa  (PlN  >kullas+sepp !22_S
46445	puusepad	sepa	puu+sepp	22_S	PlN	et	puusepad =sepa  (PlN  >puu+sepp !22_S
46452	ladinakeelse	keelse	ladina+keelne	02_A	SgG	et	ladinakeelse =keelse  (SgG  >ladina+keelne !02_A
46463	toonasesse	toonase	toonane	10_A	SgIll	et	toonasesse =toonase  (SgIll  >toonane !10_A
46464	laatsaretis	laatsareti	laatsaret	22_S	SgIn	et	laatsaretis =laatsareti  (SgIn  >laatsaret !22_S
46465	misjonäridest	misjonäri	misjonär	19_S	PlEl	et	misjonäridest =misjonäri  (PlEl  >misjonär !19_S
46467	siseriiklikud	riikliku	sise+riiklik	25_A	PlN	et	siseriiklikud =riikliku  (PlN  >sise+riiklik !25_A
46475	vürtsiriigid	riigi	vürtsi+riik	22_S	PlN	et	vürtsiriigid =riigi  (PlN  >vürtsi+riik !22_S
46480	põlde	põlde	põld	22_S	PlP	et	põlde =põlde  (PlP  >põld !22_S
46482	sadamad	sadama	sadam	02_S	PlN	et	sadamad =sadama  (PlN  >sadam !02_S
46483	käsitöölise	töölise	käsi+tööline	12?10_S	SgG	et	käsitöölise =töölise  (SgG  >käsi+tööline !12?10_S
46484	ehte-	ehte	ehe	06_S	SgG	et	ehte- =ehte  (SgG  >ehe !06_S
46489	ehitusmaterjaliks	materjali	ehitus+materjal	19_S	SgTr	et	ehitusmaterjaliks =materjali  (SgTr  >ehitus+materjal !19_S
46499	liivimaaga	maa	liivi+maa	26_S	SgKom	et	liivimaaga =maa  (SgKom  >liivi+maa !26_S
46507	sajandiks	sajandi	sajand	02_S	SgTr	et	sajandiks =sajandi  (SgTr  >sajand !02_S
46509	katoliiklik	katoliiklik	katoliiklik	25_A	SgN	et	katoliiklik =katoliiklik  (SgN  >katoliiklik !25_A
46520	maahärrade	härra	maa+härra	16_S	PlG	et	maahärrade =härra  (PlG  >maa+härra !16_S
46527	usule	usu	usk	22_S	SgAll	et	usule =usu  (SgAll  >usk !22_S
46530	sõjakäigud	käigu	sõja+käik	22_S	PlN	et	sõjakäigud =käigu  (PlN  >sõja+käik !22_S
46532	poolaga	aga	pool+aga	41_JD	ID	et	poolaga =aga  (ID  >pool+aga !41_JD
46535	pühakud	pühaku	pühak	02_S	PlN	et	pühakud =pühaku  (PlN  >pühak !02_S
46537	muinasrituaale	rituaale	muinas+rituaal	22_S	PlP	et	muinasrituaale =rituaale  (PlP  >muinas+rituaal !22_S
46539	rituaalide	rituaali	rituaal	22_S	PlG	et	rituaalide =rituaali  (PlG  >rituaal !22_S
46544	reliikviad	reliikvia	reliikvia	01_S	PlN	et	reliikviad =reliikvia  (PlN  >reliikvia !01_S
46549	juhtimiskeskused	keskuse	juhtimis+keskus	11~09_S	PlN	et	juhtimiskeskused =keskuse  (PlN  >juhtimis+keskus !11~09_S
46550	rukkis	rukki	rukis	07_S	SgIn	et	rukkis =rukki  (SgIn  >rukis !07_S
46555	talupoegkond	poegkond	talu+poegkond	22_S	SgN	et	talupoegkond =poegkond  (SgN  >talu+poegkond !22_S
46558	suurperedena	pere	suur+pere	16_S	PlEs	et	suurperedena =pere  (PlEs  >suur+pere !16_S
46563	misjonäriks	misjonäri	misjonär	19_S	SgTr	et	misjonäriks =misjonäri  (SgTr  >misjonär !19_S
46572	originaalkäsikiri	kiri	originaal+käsi+kiri	24_S	SgN	et	originaalkäsikiri =kiri  (SgN  >originaal+käsi+kiri !24_S
46574	eesnimesid	nime	ees+nimi	20_S	PlP	et	eesnimesid =nime  (PlP  >ees+nimi !20_S
46576	paganliku	paganliku	paganlik	25_A	SgG	et	paganliku =paganliku  (SgG  >paganlik !25_A
46582	misjonärina	misjonäri	misjonär	19_S	SgEs	et	misjonärina =misjonäri  (SgEs  >misjonär !19_S
46586	õlletunni	tunni	õlle+tund	22_S	SgG	et	õlletunni =tunni  (SgG  >õlle+tund !22_S
46590	ümberkirjutamise	kirjutamise	ümber+kirjutamine	12_S	SgG	et	ümberkirjutamise =kirjutamise  (SgG  >ümber+kirjutamine !12_S
46596	katoliikliku	katoliikliku	katoliiklik	25_A	SgG	et	katoliikliku =katoliikliku  (SgG  >katoliiklik !25_A
46604	sõjaretkega	retke	sõja+retk	22_S	SgKom	et	sõjaretkega =retke  (SgKom  >sõja+retk !22_S
46606	talupoegadeks	poega	talu+poeg	22_S	PlTr	et	talupoegadeks =poega  (PlTr  >talu+poeg !22_S
46609	kloostrite	kloostri	klooster	02_S	PlG	et	kloostrite =kloostri  (PlG  >klooster !02_S
46613	väljaandlusele	andluse	välja+andlus	11~09_S	SgAll	et	väljaandlusele =andluse  (SgAll  >välja+andlus !11~09_S
46620	sõidupilet	pilet	sõidu+pilet	02_S	SgN	et	sõidupilet =pilet  (SgN  >sõidu+pilet !02_S
46622	päästab	päästa	päästma	34_V	IndPrSg3	et	päästab =päästa  (IndPrSg3  >päästma !34_V
46632	kuritegelikke	tegelikke	kuri+tegelik	25_A	PlP	et	kuritegelikke =tegelikke  (PlP  >kuri+tegelik !25_A
46443	liivlased	liivlase	liivlane	12?10_S	PlN	et	liivlased =liivlase  (PlN  >liivlane !12?10_S
46456	väljaõppeks	õppe	välja+õpe	06_S	SgTr	et	väljaõppeks =õppe  (SgTr  >välja+õpe !06_S
46468	ordumeistri	meistri	ordu+meister	02_S	SgG	et	ordumeistri =meistri  (SgG  >ordu+meister !02_S
46470	tarvilik	tarvilik	tarvilik	25_A	SgN	et	tarvilik =tarvilik  (SgN  >tarvilik !25_A
46471	sõjakäikudeks	käiku	sõja+käik	22_S	PlTr	et	sõjakäikudeks =käiku  (PlTr  >sõja+käik !22_S
46472	võitudest	võitu	võit	22_S	PlEl	et	võitudest =võitu  (PlEl  >võit !22_S
46473	fatasi-mongoli	mongoli	fatasi-mongol	02_S	SgG	et	fatasi-mongoli =mongoli  (SgG  >fatasi-mongol !02_S
46476	omavalitsuslikud	valitsusliku	oma+valitsuslik	25_A	PlN	et	omavalitsuslikud =valitsusliku  (PlN  >oma+valitsuslik !25_A
46478	maksustada	maksusta	maksustama	27_V	Inf	et	maksustada =maksusta  (Inf  >maksustama !27_V
46485	relvameistrid	meistri	relva+meister	02_S	PlN	et	relvameistrid =meistri  (PlN  >relva+meister !02_S
46486	eksportkaup	kaup	eks+port+kaup	22_S	SgN	et	eksportkaup =kaup  (SgN  >eks+port+kaup !22_S
46487	leivale	leiva	leib	22_S	SgAll	et	leivale =leiva  (SgAll  >leib !22_S
46494	kihelkond	kihelkond	kihelkond	22_S	SgN	et	kihelkond =kihelkond  (SgN  >kihelkond !22_S
46497	dominiiklaste	dominiiklas	dominiiklane	12?10_S	PlG	et	dominiiklaste =dominiiklas  (PlG  >dominiiklane !12?10_S
46498	monumentaalsed	monumentaalse	monumentaalne	02_A	PlN	et	monumentaalsed =monumentaalse  (PlN  >monumentaalne !02_A
46500	kiusatakse	kiusa	kiusama	29_V	IndPrIps	et	kiusatakse =kiusa  (IndPrIps  >kiusama !29_V
46502	tatarlaste	tatarlas	tatarlane	12_S	PlG	et	tatarlaste =tatarlas  (PlG  >tatarlane !12_S
46510	ristisõdade	sõda	risti+sõda	18_S	PlG	et	ristisõdade =sõda  (PlG  >risti+sõda !18_S
46511	muistne	muistne	muistne	02_A	SgN	et	muistne =muistne  (SgN  >muistne !02_A
46514	ehitiste	ehitis	ehitis	11_S	PlG	et	ehitiste =ehitis  (PlG  >ehitis !11_S
46517	keskaegsest	aegse	kesk+aegne	02_A	SgEl	et	keskaegsest =aegse  (SgEl  >kesk+aegne !02_A
46518	siinsel	siinse	siinne	02_A	SgAd	et	siinsel =siinse  (SgAd  >siinne !02_A
46522	suurgild	gild	suur+gild	22_S	SgN	et	suurgild =gild  (SgN  >suur+gild !22_S
46528	lugemisoskus	oskus	lugemis+oskus	11~09_S	SgN	et	lugemisoskus =oskus  (SgN  >lugemis+oskus !11~09_S
46531	aladelt	ala	ala	17_S	PlAbl	et	aladelt =ala  (PlAbl  >ala !17_S
46533	rahuga	rahu	rahu	17_S	SgKom	et	rahuga =rahu  (SgKom  >rahu !17_S
46536	kaitsevaimud	vaimu	kaitse+vaim	22_S	PlN	et	kaitsevaimud =vaimu  (PlN  >kaitse+vaim !22_S
46538	pühale	püha	püha	17_SA	SgAll	et	pühale =püha  (SgAll  >püha !17_SA
46540	haldusalas	ala	haldus+ala	17_S	SgIn	et	haldusalas =ala  (SgIn  >haldus+ala !17_S
46548	läänemere-äärsete	äärse	läänemere-äärne	02_A	PlG	et	läänemere-äärsete =äärse  (PlG  >läänemere-äärne !02_A
46557	rahvatraditsiooniga	traditsiooni	rahva+traditsioon	22_S	SgKom	et	rahvatraditsiooniga =traditsiooni  (SgKom  >rahva+traditsioon !22_S
46559	etnilise	etnilise	etniline	12_A	SgG	et	etnilise =etnilise  (SgG  >etniline !12_A
46565	kolitati	tati	koli+tatt	22_S	SgG	et	kolitati =tati  (SgG  >koli+tatt !22_S
46578	taanlane	taanlane	taanlane	12?10_S	SgN	et	taanlane =taanlane  (SgN  >taanlane !12?10_S
46584	1740a1881a	aa	aa	41_I	ID	et	aa =aa  (ID  >aa !41_I
46589	ristiusk	usk	risti+usk	22_S	SgN	et	ristiusk =usk  (SgN  >risti+usk !22_S
46597	ristiretked	retke	risti+retk	22_S	PlN	et	ristiretked =retke  (PlN  >risti+retk !22_S
46600	reformatsioonini	reformatsiooni	reformatsioon	22_S	SgTer	et	reformatsioonini =reformatsiooni  (SgTer  >reformatsioon !22_S
46601	teenistus	teenistus	teenistus	11_S	SgN	et	teenistus =teenistus  (SgN  >teenistus !11_S
46602	rüütlitel	rüütli	rüütel	02_S	PlAd	et	rüütlitel =rüütli  (PlAd  >rüütel !02_S
46603	rahumeelne	meelne	rahu+meelne	02_A	SgN	et	rahumeelne =meelne  (SgN  >rahu+meelne !02_A
46605	enamikus	enamiku	enamik	25_S	SgIn	et	enamikus =enamiku  (SgIn  >enamik !25_S
46611	maakabelite	kabeli	maa+kabel	02_S	PlG	et	maakabelite =kabeli  (PlG  >maa+kabel !02_S
46623	vangist	vangi	vang	22_S	SgEl	et	vangist =vangi  (SgEl  >vang !22_S
46630	pikivahet	vahe	piki+vahe	16_S	SgP	et	pikivahet =vahe  (SgP  >piki+vahe !16_S
46636	kiirabil	abi	kiir+abi	17_S	SgAd	et	kiirabil =abi  (SgAd  >kiir+abi !17_S
46641	töörõivastuses	rõivastuse	töö+rõivastus	11_S	SgIn	et	töörõivastuses =rõivastuse  (SgIn  >töö+rõivastus !11_S
46645	kaantel	kaan	kaas	14_S	PlAd	et	kaantel =kaan  (PlAd  >kaas !14_S
46649	rahandussektori	sektori	rahandus+sektor	02_S	SgG	et	rahandussektori =sektori  (SgG  >rahandus+sektor !02_S
46652	internetikasutajaid	kasutaja	interneti+kasutaja	01_S	PlP	et	internetikasutajaid =kasutaja  (PlP  >interneti+kasutaja !01_S
46654	arengutasemele	taseme	arengu+tase	04_S	SgAll	et	arengutasemele =taseme  (SgAll  >arengu+tase !04_S
46666	ajendi	ajendi	ajend	02_S	SgG	et	ajendi =ajendi  (SgG  >ajend !02_S
46673	elutaseme	taseme	elu+tase	04_S	SgG	et	elutaseme =taseme  (SgG  >elu+tase !04_S
46462	rahvamurrust	murru	rahva+murd	22_S	SgEl	et	rahvamurrust =murru  (SgEl  >rahva+murd !22_S
46469	vürstiriigi	riigi	vürsti+riik	22_S	SgG	et	vürstiriigi =riigi  (SgG  >vürsti+riik !22_S
46474	troonil	trooni	troon	22_S	SgAd	et	troonil =trooni  (SgAd  >troon !22_S
46477	elanikeks	elanike	elanik	25_S	PlTr	et	elanikeks =elanike  (PlTr  >elanik !25_S
46481	transiitsadam	sadam	transiit+sadam	02_S	SgN	et	transiitsadam =sadam  (SgN  >transiit+sadam !02_S
46495	murraks	murra	murdma	34_V	KndPrPs	et	murraks =murra  (KndPrPs  >murdma !34_V
46524	linnakodanik	kodanik	linna+kodanik	25_S	SgN	et	linnakodanik =kodanik  (SgN  >linna+kodanik !25_S
46526	kristlikule	kristliku	kristlik	25_A	SgAll	et	kristlikule =kristliku  (SgAll  >kristlik !25_A
46529	idanaaber	naaber	ida+naaber	02_S	SgN	et	idanaaber =naaber  (SgN  >ida+naaber !02_S
46546	muinasusundile	usundi	muinas+usund	02_S	SgAll	et	muinasusundile =usundi  (SgAll  >muinas+usund !02_S
46552	muinasusund	usund	muinas+usund	02_S	SgN	et	muinasusund =usund  (SgN  >muinas+usund !02_S
46556	pühakultuse	kultuse	püha+kultus	11~09_S	SgG	et	pühakultuse =kultuse  (SgG  >püha+kultus !11~09_S
46560	saj-st	saj	saj	xx_Q	SgEl	et	saj-st =saj  (SgEl  >saj !xx_Q
46561	põllumajandusliku	majandusliku	põllu+majanduslik	25_A	SgG	et	põllumajandusliku =majandusliku  (SgG  >põllu+majanduslik !25_A
46564	mälestis	mälestis	mälestis	11_S	SgN	et	mälestis =mälestis  (SgN  >mälestis !11_S
46573	lätimaalt	maa	läti+maa	26_S	SgAbl	et	lätimaalt =maa  (SgAbl  >läti+maa !26_S
46577	autotiks	tiks	auto+tiks	22_S	SgN	et	autotiks =tiks  (SgN  >auto+tiks !22_S
46579	teoorjuslik	orjuslik	teo+orjuslik	25_A	SgN	et	teoorjuslik =orjuslik  (SgN  >teo+orjuslik !25_A
46581	kloostrihariduse	hariduse	kloostri+haridus	11_S	SgG	et	kloostrihariduse =hariduse  (SgG  >kloostri+haridus !11_S
46585	äikesejumal	jumal	äikese+jumal	02_S	SgN	et	äikesejumal =jumal  (SgN  >äikese+jumal !02_S
46587	laadina	laadi	laad	22_S	SgEs	et	laadina =laadi  (SgEs  >laad !22_S
46588	ristisõdu	sõdu	risti+sõda	18_S	PlP	et	ristisõdu =sõdu  (PlP  >risti+sõda !18_S
46591	tähtsast	tähtsa	tähtis	02_A	SgEl	et	tähtsast =tähtsa  (SgEl  >tähtis !02_A
46592	kirikuõpetajad	õpetaja	kiriku+õpetaja	01_S	PlN	et	kirikuõpetajad =õpetaja  (PlN  >kiriku+õpetaja !01_S
46595	põgenikena	põgenike	põgenik	25_S	PlEs	et	põgenikena =põgenike  (PlEs  >põgenik !25_S
46599	teenistused	teenistuse	teenistus	11_S	PlN	et	teenistused =teenistuse  (PlN  >teenistus !11_S
46610	feodaalne	feodaalne	feodaalne	02_A	SgN	et	feodaalne =feodaalne  (SgN  >feodaalne !02_A
46615	tasakaalustada	kaalusta	tasa+kaalustama	27_V	Inf	et	tasakaalustada =kaalusta  (Inf  >tasa+kaalustama !27_V
46626	tagab	taga	tagama	27_V	IndPrSg3	et	tagab =taga  (IndPrSg3  >tagama !27_V
46628	kiirabisse	abi	kiir+abi	17_S	SgIll	et	kiirabisse =abi  (SgIll  >kiir+abi !17_S
46629	normaalset	normaalse	normaalne	02_A	SgP	et	normaalset =normaalse  (SgP  >normaalne !02_A
46631	sündmuses	sündmuse	sündmus	11~09_S	SgIn	et	sündmuses =sündmuse  (SgIn  >sündmus !11~09_S
46634	toituda	toitu	toituma	27_V	Inf	et	toituda =toitu  (Inf  >toituma !27_V
46635	vitamiinid	vitamiini	vitamiin	22_S	PlN	et	vitamiinid =vitamiini  (PlN  >vitamiin !22_S
46642	kostüümid	kostüümi	kostüüm	22_S	PlN	et	kostüümid =kostüümi  (PlN  >kostüüm !22_S
46643	kostüümikleidid	kleidi	kostüümi+kleit	22_S	PlN	et	kostüümikleidid =kleidi  (PlN  >kostüümi+kleit !22_S
46647	ärikogud	kogu	äri+kogu	17_S	PlN	et	ärikogud =kogu  (PlN  >äri+kogu !17_S
46648	pangandus-	pangandus	pangandus	11_S	SgN	et	pangandus- =pangandus  (SgN  >pangandus !11_S
46663	puiduturg	turg	puidu+turg	22_S	SgN	et	puiduturg =turg  (SgN  >puidu+turg !22_S
46669	barjääriks	barjääri	barjäär	22_S	SgTr	et	barjääriks =barjääri  (SgTr  >barjäär !22_S
46676	kuritegijaks	tegija	kuri+tegija	01_S	SgTr	et	kuritegijaks =tegija  (SgTr  >kuri+tegija !01_S
46688	karv	karv	karv	22_S	SgN	et	karv =karv  (SgN  >karv !22_S
46690	küüned	küüne	küüs	14_S	PlN	et	küüned =küüne  (PlN  >küüs !14_S
46692	kihvad	kihva	kihv	22_S	PlN	et	kihvad =kihva  (PlN  >kihv !22_S
46694	õppevorm	vorm	õppe+vorm	22_S	SgN	et	õppevorm =vorm  (SgN  >õppe+vorm !22_S
46700	personalile	personali	personal	19_S	SgAll	et	personalile =personali  (SgAll  >personal !19_S
46708	visiit	visiit	visiit	22_S	SgN	et	visiit =visiit  (SgN  >visiit !22_S
46716	tänaks	täna	tänama	27_V	KndPrPs	et	tänaks =täna  (KndPrPs  >tänama !27_V
46723	tehinguga	tehingu	tehing	02_S	SgKom	et	tehinguga =tehingu  (SgKom  >tehing !02_S
46724	sisestada	sisesta	sisestama	27_V	Inf	et	sisestada =sisesta  (Inf  >sisestama !27_V
46736	tekstianalüüs	analüüs	teksti+analüüs	22_S	SgN	et	tekstianalüüs =analüüs  (SgN  >teksti+analüüs !22_S
46741	magamiskambri	kambri	magamis+kamber	02_S	SgG	et	magamiskambri =kambri  (SgG  >magamis+kamber !02_S
46746	palgist	palgi	palk	22_S	SgEl	et	palgist =palgi  (SgEl  >palk !22_S
46621	vastuargumendid	argumendi	vastu+argument	22_S	PlN	et	vastuargumendid =argumendi  (PlN  >vastu+argument !22_S
46624	vanglakaristus	karistus	vangla+karistus	11_S	SgN	et	vanglakaristus =karistus  (SgN  >vangla+karistus !11_S
46625	kurjategijat	tegija	kurja+tegija	01_S	SgP	et	kurjategijat =tegija  (SgP  >kurja+tegija !01_S
46640	keskpunktis	punkti	kesk+punkt	22_S	SgIn	et	keskpunktis =punkti  (SgIn  >kesk+punkt !22_S
46650	pangandussüsteemid	süsteemi	pangandus+süsteem	22_S	PlN	et	pangandussüsteemid =süsteemi  (PlN  >pangandus+süsteem !22_S
46655	turgude	turgu	turg	22_S	PlG	et	turgude =turgu  (PlG  >turg !22_S
46658	otseses	otsese	otsene	10_A	SgIn	et	otseses =otsese  (SgIn  >otsene !10_A
46670	leivata	leiva	leib	22_S	SgAb	et	leivata =leiva  (SgAb  >leib !22_S
46679	madaldada	madalda	madaldama	27_V	Inf	et	madaldada =madalda  (Inf  >madaldama !27_V
46684	pesupesemist	pesemis	pesu+pesemine	12_S	SgP	et	pesupesemist =pesemis  (SgP  >pesu+pesemine !12_S
46686	numbrile	numbri	number	02_S	SgAll	et	numbrile =numbri  (SgAll  >number !02_S
46698	järelepärimiskiri	kiri	järele+päri+mis+kiri	24_S	SgN	et	järelepärimiskiri =kiri  (SgN  >järele+päri+mis+kiri !24_S
46699	reiside	reisi	reis	22_S	PlG	et	reiside =reisi  (PlG  >reis !22_S
46705	reisidest	reisi	reis	22_S	PlEl	et	reisidest =reisi  (PlEl  >reis !22_S
46713	pangateenus	teenus	panga+teenus	09_S	SgN	et	pangateenus =teenus  (SgN  >panga+teenus !09_S
46717	kaupmehe	mehe	kaup+mees	13_S	SgG	et	kaupmehe =mehe  (SgG  >kaup+mees !13_S
46719	lühinumber	number	lühi+number	02_S	SgN	et	lühinumber =number  (SgN  >lühi+number !02_S
46720	1214kaupmehe	mehe	kaup+mees	13_S	SgG	et	kaupmehe =mehe  (SgG  >kaup+mees !13_S
46726	hansapanga	panga	hansa+pank	22_S	SgG	et	hansapanga =panga  (SgG  >hansa+pank !22_S
46728	väikefirmadele	firma	väike+firma	16_S	PlAll	et	väikefirmadele =firma  (PlAll  >väike+firma !16_S
46739	klaar	klaar	klaar	22_A	SgN	et	klaar =klaar  (SgN  >klaar !22_A
46745	lauatagusest	taguse	laua+tagune	10_AS	SgEl	et	lauatagusest =taguse  (SgEl  >laua+tagune !10_AS
46752	kirjapanemisega	panemise	kirja+panemine	12_S	SgKom	et	kirjapanemisega =panemise  (SgKom  >kirja+panemine !12_S
46756	publitsist	publitsist	publitsist	22_S	SgN	et	publitsist =publitsist  (SgN  >publitsist !22_S
46772	ilukirjandusteosega	teose	ilu+kirjandus+teos	09_S	SgKom	et	ilukirjandusteosega =teose  (SgKom  >ilu+kirjandus+teos !09_S
46773	esitluslaad	laad	esitlus+laad	22_S	SgN	et	esitluslaad =laad  (SgN  >esitlus+laad !22_S
46775	viidab	viida	viitma	34_V	IndPrSg3	et	viidab =viida  (IndPrSg3  >viitma !34_V
46776	tiitlile	tiitli	tiitel	02_S	SgAll	et	tiitlile =tiitli  (SgAll  >tiitel !02_S
46779	võtmesõnade	sõna	võtme+sõna	17_S	PlG	et	võtmesõnade =sõna  (PlG  >võtme+sõna !17_S
46786	sõnalt	sõna	sõna	17_S	SgAbl	et	sõnalt =sõna  (SgAbl  >sõna !17_S
46788	ärkel	ärkel	ärkel	02_S	SgN	et	ärkel =ärkel  (SgN  >ärkel !02_S
46794	piklik	piklik	piklik	25_A	SgN	et	piklik =piklik  (SgN  >piklik !25_A
46807	sõnakordusmehhanism	mehhanism	sõna+kordus+mehhanism	22_S	SgN	et	sõnakordusmehhanism =mehhanism  (SgN  >sõna+kordus+mehhanism !22_S
46808	nimisõnakordus-paberid	paberi	nimisõnakordus-paber	02_S	PlN	et	nimisõnakordus-paberid =paberi  (PlN  >nimisõnakordus-paber !02_S
46809	asesõnakordus-need	nee	asesõnakordus-see	00_P	PlN	et	asesõnakordus-need =nee  (PlN  >asesõnakordus-see !00_P
46811	võttele	võtte	võte	06_S	SgAll	et	võttele =võtte  (SgAll  >võte !06_S
46842	võluda	võlu	võluma	27_V	Inf	et	võluda =võlu  (Inf  >võluma !27_V
46845	kujutlusvõimega	võime	kujutlus+võime	06_S	SgKom	et	kujutlusvõimega =võime  (SgKom  >kujutlus+võime !06_S
46854	mehikestest	mehikes	mehike	12_S	PlEl	et	mehikestest =mehikes  (PlEl  >mehike !12_S
46855	lambist	lambi	lamp	22_SA	SgEl	et	lambist =lambi  (SgEl  >lamp !22_SA
46866	nimisõnana	sõna	nimi+sõna	17_S	SgEs	et	nimisõnana =sõna  (SgEs  >nimi+sõna !17_S
46874	kooloniga	kooloni	koolon	02_S	SgKom	et	kooloniga =kooloni  (SgKom  >koolon !02_S
46883	dokumentaalne	dokumentaalne	dokumentaalne	02_A	SgN	et	dokumentaalne =dokumentaalne  (SgN  >dokumentaalne !02_A
46884	proove	proove	proov	22_S	PlP	et	proove =proove  (PlP  >proov !22_S
46891	territooriumisse	territooriumi	territoorium	19~02_S	SgIll	et	territooriumisse =territooriumi  (SgIll  >territoorium !19~02_S
46895	tankide	tanki	tank	22_S	PlG	et	tankide =tanki  (PlG  >tank !22_S
46902	võidurõõmuks	rõõmu	võidu+rõõm	22_S	SgTr	et	võidurõõmuks =rõõmu  (SgTr  >võidu+rõõm !22_S
46905	öölaulupidud	pidu	öö+laulu+pidu	17_S	PlN	et	öölaulupidud =pidu  (PlN  >öö+laulu+pidu !17_S
46906	ohutunnet	tunne	ohu+tunne	06_S	SgP	et	ohutunnet =tunne  (SgP  >ohu+tunne !06_S
46917	lemmiktelesaatele	saate	lemmik+tele+saade	06_S	SgAll	et	lemmiktelesaatele =saate  (SgAll  >lemmik+tele+saade !06_S
46918	kõhnuda	kõhnu	kõhnuma	27_V	Inf	et	kõhnuda =kõhnu  (Inf  >kõhnuma !27_V
46919	dieet	dieet	dieet	22_S	SgN	et	dieet =dieet  (SgN  >dieet !22_S
46633	sööd	söö	sööma	38_V	IndPrSg2	et	sööd =söö  (IndPrSg2  >sööma !38_V
46637	otsekohene	kohene	otse+kohene	10_A	SgN	et	otsekohene =kohene  (SgN  >otse+kohene !10_A
46638	kahjulikest	kahjulike	kahjulik	25_A	PlEl	et	kahjulikest =kahjulike  (PlEl  >kahjulik !25_A
46651	pangandussüsteem	süsteem	pangandus+süsteem	22_S	SgN	et	pangandussüsteem =süsteem  (SgN  >pangandus+süsteem !22_S
46653	üliliia	liia	üli+liig	22_S	SgG	et	üliliia =liia  (SgG  >üli+liig !22_S
46657	filiaalid	filiaali	filiaal	22_S	PlN	et	filiaalid =filiaali  (PlN  >filiaal !22_S
46659	turuga	turu	turg	22_S	SgKom	et	turuga =turu  (SgKom  >turg !22_S
46662	el-ga	el	el	xx_Q	SgKom	et	el-ga =el  (SgKom  >el !xx_Q
46667	välispartnerite	partneri	välis+partner	02_S	PlG	et	välispartnerite =partneri  (PlG  >välis+partner !02_S
46675	kuritegijatel	tegija	kuri+tegija	01_S	PlAd	et	kuritegijatel =tegija  (PlAd  >kuri+tegija !01_S
46693	kikkis	kikkis	kikkis	41_DA	ID	et	kikkis =kikkis  (ID  >kikkis !41_DA
46695	vaalida	vaali	vaalima	28_V	Inf	et	vaalida =vaali  (Inf  >vaalima !28_V
46696	õppemisvahend	vahend	õppe+mis+vahend	02_S	SgN	et	õppemisvahend =vahend  (SgN  >õppe+mis+vahend !02_S
46697	kodumasin	masin	kodu+masin	02_S	SgN	et	kodumasin =masin  (SgN  >kodu+masin !02_S
46701	püsikliendiks	kliendi	püsi+klient	22_S	SgTr	et	püsikliendiks =kliendi  (SgTr  >püsi+klient !22_S
46712	pöörangu	pöörangu	pöörang	02_S	SgG	et	pöörangu =pöörangu  (SgG  >pöörang !02_S
46722	kõnekeskus	keskus	kõne+keskus	11~09_S	SgN	et	kõnekeskus =keskus  (SgN  >kõne+keskus !11~09_S
46725	hansapangaga	panga	hansa+pank	22_S	SgKom	et	hansapangaga =panga  (SgKom  >hansa+pank !22_S
46742	sättisin	sätti	sättima	28_V	IndIpfSg1	et	sättisin =sätti  (IndIpfSg1  >sättima !28_V
46744	kaant	kaan	kaas	14_S	SgP	et	kaant =kaan  (SgP  >kaas !14_S
46748	sealtsamast	sealtsamast	sealt+samast	41_D	ID	et	sealtsamast =sealtsamast  (ID  >sealt+samast !41_D
46751	päevasündmuste	sündmus	päeva+sündmus	11~09_S	PlG	et	päevasündmuste =sündmus  (PlG  >päeva+sündmus !11~09_S
46758	luuletõlkijana	tõlkija	luule+tõlkija	01_S	SgEs	et	luuletõlkijana =tõlkija  (SgEs  >luule+tõlkija !01_S
46760	inimsuhete	suhe	inim+suhe	06_S	PlG	et	inimsuhete =suhe  (PlG  >inim+suhe !06_S
46761	seistes	seis	seisma	32_V	Ger	et	seistes =seis  (Ger  >seisma !32_V
46763	kuuletuma	kuuletu	kuuletuma	27_V	Sup	et	kuuletuma =kuuletu  (Sup  >kuuletuma !27_V
46764	ohustab	ohusta	ohustama	27_V	IndPrSg3	et	ohustab =ohusta  (IndPrSg3  >ohustama !27_V
46770	saksakeelse	keelse	saksa+keelne	02_A	SgG	et	saksakeelse =keelse  (SgG  >saksa+keelne !02_A
46785	originaalsele	originaalse	originaalne	02_A	SgAll	et	originaalsele =originaalse  (SgAll  >originaalne !02_A
46806	lausele	lause	lause	06_S	SgAll	et	lausele =lause  (SgAll  >lause !06_S
46810	täpsustab	täpsusta	täpsustama	27_V	IndPrSg3	et	täpsustab =täpsusta  (IndPrSg3  >täpsustama !27_V
46812	sõnavarana	vara	sõna+vara	17_S	SgEs	et	sõnavarana =vara  (SgEs  >sõna+vara !17_S
46816	koksama	koksa	koksama	29_V	Sup	et	koksama =koksa  (Sup  >koksama !29_V
46817	nottima	notti	nottima	28_V	Sup	et	nottima =notti  (Sup  >nottima !28_V
46826	torkas	torka	torkama	29_V	IndIpfSg3	et	torkas =torka  (IndIpfSg3  >torkama !29_V
46827	pehmest	pehme	pehme	01_A	SgEl	et	pehmest =pehme  (SgEl  >pehme !01_A
46837	peategelased-	tegelase	pea+tegelane	12_S	PlN	et	peategelased- =tegelase  (PlN  >pea+tegelane !12_S
46847	keelsest	keelse	keelne	02_A	SgEl	et	keelsest =keelse  (SgEl  >keelne !02_A
46850	lillekiosk	kiosk	lille+kiosk	02_S	SgN	et	lillekiosk =kiosk  (SgN  >lille+kiosk !02_S
46858	kõlada	kõla	kõlama	27_V	Inf	et	kõlada =kõla  (Inf  >kõlama !27_V
46859	peegeldaks	peegelda	peegeldama	27_V	KndPrPs	et	peegeldaks =peegelda  (KndPrPs  >peegeldama !27_V
46861	komani	koma	koma	17_S	SgTer	et	komani =koma  (SgTer  >koma !17_S
46864	jäätisemüüjat	müüja	jäät+ise+müüja	01_S	SgP	et	jäätisemüüjat =müüja  (SgP  >jäät+ise+müüja !01_S
46865	torkama	torka	torkama	29_V	Sup	et	torkama =torka  (Sup  >torkama !29_V
46868	oivaline	oivaline	oivaline	12_A	SgN	et	oivaline =oivaline  (SgN  >oivaline !12_A
46871	momendi	momendi	moment	22_S	SgG	et	momendi =momendi  (SgG  >moment !22_S
46877	ekvivalent	ekvivalent	ekvivalent	22_S	SgN	et	ekvivalent =ekvivalent  (SgN  >ekvivalent !22_S
46878	lisakirjandus	kirjandus	lisa+kirjandus	11_S	SgN	et	lisakirjandus =kirjandus  (SgN  >lisa+kirjandus !11_S
46879	ühendama	ühenda	ühendama	27_V	Sup	et	ühendama =ühenda  (Sup  >ühendama !27_V
46887	hoiti	hoi	hoidma	34_V	IndIpfIps	et	hoiti =hoi  (IndIpfIps  >hoidma !34_V
46896	dokumentaalkaadrid	kaadri	dokumentaal+kaader	02_S	PlN	et	dokumentaalkaadrid =kaadri  (PlN  >dokumentaal+kaader !02_S
46897	minge	min	minema	36_V	ImpPrPl2	et	minge =min  (ImpPrPl2  >minema !36_V
46900	reformaatorit	reformaatori	reformaator	02_S	SgP	et	reformaatorit =reformaatori  (SgP  >reformaator !02_S
46639	kolleegide	kolleegi	kolleeg	22_S	PlG	et	kolleegide =kolleegi  (PlG  >kolleeg !22_S
46644	korrektsed	korrektse	korrektne	02_A	PlN	et	korrektsed =korrektse  (PlN  >korrektne !02_A
46646	usa-ga	usa	usa	xx_Q	SgKom	et	usa-ga =usa  (SgKom  >usa !xx_Q
46656	igasuguses	suguse	iga+sugune	10_A	SgIn	et	igasuguses =suguse  (SgIn  >iga+sugune !10_A
46660	sektoris	sektori	sektor	02_S	SgIn	et	sektoris =sektori  (SgIn  >sektor !02_S
46661	liitumisprotsess	protsess	liitumis+protsess	22_S	SgN	et	liitumisprotsess =protsess  (SgN  >liitumis+protsess !22_S
46664	muutlik	muutlik	muutlik	25_A	SgN	et	muutlik =muutlik  (SgN  >muutlik !25_A
46665	ettevõtetele	võte	ette+võte	06_S	PlAll	et	ettevõtetele =võte  (PlAll  >ette+võte !06_S
46668	otsinguks	otsingu	otsing	02_S	SgTr	et	otsinguks =otsingu  (SgTr  >otsing !02_S
46671	väidete	väide	väide	06_S	PlG	et	väidete =väide  (PlG  >väide !06_S
46672	sooritatakse	soorita	sooritama	27_V	IndPrIps	et	sooritatakse =soorita  (IndPrIps  >sooritama !27_V
46674	enesekaitsmises	kaitsmise	enese+kaitsmine	12?10_S	SgIn	et	enesekaitsmises =kaitsmise  (SgIn  >enese+kaitsmine !12?10_S
46680	jagub	jagu	jaguma	27_V	IndPrSg3	et	jagub =jagu  (IndPrSg3  >jaguma !27_V
46683	kapsuni	kapsu	kaps	22_S	SgTer	et	kapsuni =kapsu  (SgTer  >kaps !22_S
46691	käppad	käppa	käppama	29_V	IndPrSg2	et	käppad =käppa  (IndPrSg2  >käppama !29_V
46703	järelepärimiskirjale	kirja	järele+päri+mis+kiri	24_S	SgAll	et	järelepärimiskirjale =kirja  (SgAll  >järele+päri+mis+kiri !24_S
46706	jalutuskäigust	käigu	jalutus+käik	22_S	SgEl	et	jalutuskäigust =käigu  (SgEl  >jalutus+käik !22_S
46709	soovidele	soovi	soov	22_S	PlAll	et	soovidele =soovi  (PlAll  >soov !22_S
46710	peajuht	juht	pea+juht	22_S	SgN	et	peajuht =juht  (SgN  >pea+juht !22_S
46714	teenus	teenus	teenus	09_S	SgN	et	teenus =teenus  (SgN  >teenus !09_S
46715	klientidele	klienti	klient	22_S	PlAll	et	klientidele =klienti  (PlAll  >klient !22_S
46718	kaardiga	kaardi	kaart	22_S	SgKom	et	kaardiga =kaardi  (SgKom  >kaart !22_S
46729	euroliidu	liidu	euro+liit	22_S	SgG	et	euroliidu =liidu  (SgG  >euro+liit !22_S
46730	väikefirmade	firma	väike+firma	16_S	PlG	et	väikefirmade =firma  (PlG  >väike+firma !16_S
46732	riigihangete	hange	riigi+hange	06_S	PlG	et	riigihangete =hange  (PlG  >riigi+hange !06_S
46733	konkureerida	konkureeri	konkureerima	28_V	Inf	et	konkureerida =konkureeri  (Inf  >konkureerima !28_V
46734	import	import	import	22_S	SgN	et	import =import  (SgN  >import !22_S
46735	piirikontrollid	kontrolli	piiri+kontroll	22_S	PlN	et	piirikontrollid =kontrolli  (PlN  >piiri+kontroll !22_S
46737	tõlkekvaliteedist	kvaliteedi	tõlke+kvaliteet	22_S	SgEl	et	tõlkekvaliteedist =kvaliteedi  (SgEl  >tõlke+kvaliteet !22_S
46743	küübi	küübi	küüp	22_S	SgG	et	küübi =küübi  (SgG  >küüp !22_S
46750	kahtlased	kahtlase	kahtlane	12?10_A	PlN	et	kahtlased =kahtlase  (PlN  >kahtlane !12?10_A
46754	mahavaikimine	vaikimine	maha+vaikimine	12_S	SgN	et	mahavaikimine =vaikimine  (SgN  >maha+vaikimine !12_S
46765	päeviku	päeviku	päevik	02_S	SgG	et	päeviku =päeviku  (SgG  >päevik !02_S
46766	naisevenna	venna	naise+vend	22_S	SgG	et	naisevenna =venna  (SgG  >naise+vend !22_S
46771	kihi	kihi	kiht	22_S	SgG	et	kihi =kihi  (SgG  >kiht !22_S
46777	vulgaarsena	vulgaarse	vulgaarne	02_A	SgEs	et	vulgaarsena =vulgaarse  (SgEs  >vulgaarne !02_A
46780	kirjapanemine	panemine	kirja+panemine	12_S	SgN	et	kirjapanemine =panemine  (SgN  >kirja+panemine !12_S
46782	päevasündmused	sündmuse	päeva+sündmus	11~09_S	PlN	et	päevasündmused =sündmuse  (PlN  >päeva+sündmus !11~09_S
46783	katkendite	katkendi	katkend	02_S	PlG	et	katkendite =katkendi  (PlG  >katkend !02_S
46784	ajafoon	foon	aja+foon	22_S	SgN	et	ajafoon =foon  (SgN  >aja+foon !22_S
46791	sõnastik	sõnastik	sõnastik	25_S	SgN	et	sõnastik =sõnastik  (SgN  >sõnastik !25_S
46793	küüp	küüp	küüp	22_S	SgN	et	küüp =küüp  (SgN  >küüp !22_S
46797	pinal	pinal	pinal	02_S	SgN	et	pinal =pinal  (SgN  >pinal !02_S
46798	palgist-missugusest	suguse	palgist-mis+sugune	10_A	SgEl	et	palgist-missugusest =suguse  (SgEl  >palgist-mis+sugune !10_A
46805	asjadele	asja	asi	24_S	PlAll	et	asjadele =asja  (PlAll  >asi !24_S
46814	vasteid	vaste	vaste	06_S	PlP	et	vasteid =vaste  (PlP  >vaste !06_S
46818	sõnaraamat2001	raamat	sõna+raamat	02_S	SgN	et	sõnaraamat =raamat  (SgN  >sõna+raamat !02_S
46821	ilukirjanduslikud	kirjandusliku	ilu+kirjanduslik	25_A	PlN	et	ilukirjanduslikud =kirjandusliku  (PlN  >ilu+kirjanduslik !25_A
46831	peanupp	nupp	pea+nupp	22_S	SgN	et	peanupp =nupp  (SgN  >pea+nupp !22_S
46832	labajalad	jala	laba+jalg	22_S	PlN	et	labajalad =jala  (PlN  >laba+jalg !22_S
46839	mingisugustest	sugus	mingi+sugune	10_P	PlEl	et	mingisugustest =sugus  (PlEl  >mingi+sugune !10_P
46840	ennekuulmatutest	kuulmatu	enne+kuulmatu	01_A	PlEl	et	ennekuulmatutest =kuulmatu  (PlEl  >enne+kuulmatu !01_A
46844	pealkirjale	kirja	peal+kiri	24_S	SgAll	et	pealkirjale =kirja  (SgAll  >peal+kiri !24_S
46677	rajutakse	takse	raju+taks	22_S	PlP	et	rajutakse =takse  (PlP  >raju+taks !22_S
46678	levitab	levita	levitama	27_V	IndPrSg3	et	levitab =levita  (IndPrSg3  >levitama !27_V
46681	kuhjaga	kuhja	kuhi	24_S	SgKom	et	kuhjaga =kuhja  (SgKom  >kuhi !24_S
46682	osalen	osale	osalema	27_V	IndPrSg1	et	osalen =osale  (IndPrSg1  >osalema !27_V
46685	pesus	pesu	pesu	17_S	SgIn	et	pesus =pesu  (SgIn  >pesu !17_S
46687	küülik	küülik	küülik	02_S	SgN	et	küülik =küülik  (SgN  >küülik !02_S
46689	vurrud	vurru	vurr	22_S	PlN	et	vurrud =vurru  (PlN  >vurr !22_S
46702	teatame	teata	teatama	27_V	IndPrPl1	et	teatame =teata  (IndPrPl1  >teatama !27_V
46704	saadame	saada	saatma	34_V	IndPrPl1	et	saadame =saada  (IndPrPl1  >saatma !34_V
46707	akvapargi	pargi	akva+park	22_S	SgG	et	akvapargi =pargi  (SgG  >akva+park !22_S
46711	mööduma	möödu	mööduma	27_V	Sup	et	mööduma =möödu  (Sup  >mööduma !27_V
46721	automaatne	automaatne	automaatne	02_A	SgN	et	automaatne =automaatne  (SgN  >automaatne !02_A
46727	euroliit	liit	euro+liit	22_S	SgN	et	euroliit =liit  (SgN  >euro+liit !22_S
46731	ettevõtjatele	võtja	ette+võtja	01_S	PlAll	et	ettevõtjatele =võtja  (PlAll  >ette+võtja !01_S
46738	keisri	keisri	keiser	02_S	SgG	et	keisri =keisri  (SgG  >keiser !02_S
46740	peidupaik	paik	peidu+paik	22_S	SgN	et	peidupaik =paik  (SgN  >peidu+paik !22_S
46747	saagisin	saagi	saagima	28_V	IndIpfSg1	et	saagisin =saagi  (IndIpfSg1  >saagima !28_V
46753	turgatas	turgata	turgatama	27_V	IndIpfSg3	et	turgatas =turgata  (IndIpfSg3  >turgatama !27_V
46762	tõukepinnaks	pinna	tõuke+pind	22_S	SgTr	et	tõukepinnaks =pinna  (SgTr  >tõuke+pind !22_S
46769	võõrkeelsed	keelse	võõr+keelne	02_A	PlN	et	võõrkeelsed =keelse  (PlN  >võõr+keelne !02_A
46789	eh	eh	eh	41_I	ID	et	eh =eh  (ID  >eh !41_I
46790	ülakorruste	korrus	üla+korrus	09_S	PlG	et	ülakorruste =korrus  (PlG  >üla+korrus !09_S
46792	olemasolev	olev	olemas+olev	02_A	SgN	et	olemasolev =olev  (SgN  >olemas+olev !02_A
46795	lükandkaanega	kaane	lükand+kaas	14_S	SgKom	et	lükandkaanega =kaane  (SgKom  >lükand+kaas !14_S
46796	missugusest	suguse	mis+sugune	10_P	SgEl	et	missugusest =suguse  (SgEl  >mis+sugune !10_P
46799	asesõnaga	sõna	ase+sõna	17_S	SgKom	et	asesõnaga =sõna  (SgKom  >ase+sõna !17_S
46804	elusa	elusa	elus	02_A	SgG	et	elusa =elusa  (SgG  >elus !02_A
46819	tekstivalik	valik	teksti+valik	02_S	SgN	et	tekstivalik =valik  (SgN  >teksti+valik !02_S
46820	tõlgetega	tõlge	tõlge	06_S	PlKom	et	tõlgetega =tõlge  (PlKom  >tõlge !06_S
46823	nõudlikud	nõudliku	nõudlik	25_A	PlN	et	nõudlikud =nõudliku  (PlN  >nõudlik !25_A
46824	mehikest	mehikes	mehike	12_S	SgP	et	mehikest =mehikes  (SgP  >mehike !12_S
46825	muhv	muhv	muhv	22_S	SgN	et	muhv =muhv  (SgN  >muhv !22_S
46828	pohlad	pohla	pohl	22_S	PlN	et	pohlad =pohla  (PlN  >pohl !22_S
46830	varbaid	varba	varvas	07_S	PlP	et	varbaid =varba  (PlP  >varvas !07_S
46838	reas-	rea	rida	18_S	SgIn	et	reas- =rea  (SgIn  >rida !18_S
46846	tegelasel	tegelase	tegelane	12_S	SgAd	et	tegelasel =tegelase  (SgAd  >tegelane !12_S
46848	olendit	olendi	olend	02_S	SgP	et	olendit =olendi  (SgP  >olend !02_S
46849	ajalehekiosk	kiosk	aja+lehe+kiosk	02_S	SgN	et	ajalehekiosk =kiosk  (SgN  >aja+lehe+kiosk !02_S
46851	vastupidises	pidise	vastu+pidine	10_A	SgIn	et	vastupidises =pidise  (SgIn  >vastu+pidine !10_A
46862	sõnastikus	sõnastiku	sõnastik	25_S	SgIn	et	sõnastikus =sõnastiku  (SgIn  >sõnastik !25_S
46867	muinasjuttudele	juttu	muinas+jutt	22_S	PlAll	et	muinasjuttudele =juttu  (PlAll  >muinas+jutt !22_S
46875	värving	värving	värving	02_S	SgN	et	värving =värving  (SgN  >värving !02_S
46882	kuiodas	oda	kui+oda	17_S	SgIn	et	kuiodas =oda  (SgIn  >kui+oda !17_S
46888	äralõigatuna	lõigatu	ära+lõigatu	01_AS	SgEs	et	äralõigatuna =lõigatu  (SgEs  >ära+lõigatu !01_AS
46889	tervisliku	tervisliku	tervislik	25_A	SgG	et	tervisliku =tervisliku  (SgG  >tervislik !25_A
46892	siseneb	sisene	sisenema	27_V	IndPrSg3	et	siseneb =sisene  (IndPrSg3  >sisenema !27_V
46911	narkootikumidega	narkootikumi	narkootikum	19_S	PlKom	et	narkootikumidega =narkootikumi  (PlKom  >narkootikum !19_S
46913	narkootikume	narkootikume	narkootikum	19_S	PlP	et	narkootikume =narkootikume  (PlP  >narkootikum !19_S
46931	kujus	kuju	kuju	17_S	SgIn	et	kujus =kuju  (SgIn  >kuju !17_S
46934	mihkli	mihkli	mihkel	02_SA	SgG	et	mihkli =mihkli  (SgG  >mihkel !02_SA
46950	leiutiseta	leiutise	leiutis	11_S	SgAb	et	leiutiseta =leiutise  (SgAb  >leiutis !11_S
46955	kosmososse	sosse	kosmo+soss	22_S	PlP	et	kosmososse =sosse  (PlP  >kosmo+soss !22_S
46964	maksed	makse	makse	06_S	PlN	et	maksed =makse  (PlN  >makse !06_S
46965	tarbe	tarbe	tarve	06_S	SgG	et	tarbe =tarbe  (SgG  >tarve !06_S
46981	üldaineid	aine	üld+aine	06_S	PlP	et	üldaineid =aine  (PlP  >üld+aine !06_S
46749	tühemikus	tühemiku	tühemik	25_S	SgIn	et	tühemikus =tühemiku  (SgIn  >tühemik !25_S
46755	ettevaatuse	vaatuse	ette+vaatus	11~09_S	SgG	et	ettevaatuse =vaatuse  (SgG  >ette+vaatus !11~09_S
46757	prosaist	prosaist	prosaist	22_S	SgN	et	prosaist =prosaist  (SgN  >prosaist !22_S
46759	proosat	proosa	proosa	16_S	SgP	et	proosat =proosa  (SgP  >proosa !16_S
46767	saatesõnas	sõna	saate+sõna	17_S	SgIn	et	saatesõnas =sõna  (SgIn  >saate+sõna !17_S
46768	prantsuse-	prantsuse	prantsuse	41_G	ID	et	prantsuse- =prantsuse  (ID  >prantsuse !41_G
46774	mitmeti	mitmeti	mitmeti	41_D	ID	et	mitmeti =mitmeti  (ID  >mitmeti !41_D
46778	mikroteemad	teema	mikro+teema	16_S	PlN	et	mikroteemad =teema  (PlN  >mikro+teema !16_S
46781	keelses	keelse	keelne	02_A	SgIn	et	keelses =keelse  (SgIn  >keelne !02_A
46787	ühtmoodi	ühtmoodi	üht+moodi	41_DA	ID	et	ühtmoodi =ühtmoodi  (ID  >üht+moodi !41_DA
46800	mõõdusüsteem	süsteem	mõõdu+süsteem	22_S	SgN	et	mõõdusüsteem =süsteem  (SgN  >mõõdu+süsteem !22_S
46801	täpsustatakse	täpsusta	täpsustama	27_V	IndPrIps	et	täpsustatakse =täpsusta  (IndPrIps  >täpsustama !27_V
46802	tühemikus-	tühemiku	tühemik	25_S	SgIn	et	tühemikus- =tühemiku  (SgIn  >tühemik !25_S
46803	ilukirjanduskeelega	keele	ilu+kirjandus+keel	13_S	SgKom	et	ilukirjanduskeelega =keele  (SgKom  >ilu+kirjandus+keel !13_S
46813	turgatama	turgata	turgatama	27_V	Sup	et	turgatama =turgata  (Sup  >turgatama !27_V
46815	peavarjuta	varju	pea+vari	24_S	SgAb	et	peavarjuta =varju  (SgAb  >pea+vari !24_S
46822	deminutiive	deminutiive	deminutiiv	22_S	PlP	et	deminutiive =deminutiive  (PlP  >deminutiiv !22_S
46829	kinganinad	nina	kinga+nina	17_S	PlN	et	kinganinad =nina  (PlN  >kinga+nina !17_S
46833	lõikes	lõike	lõige	06_S	SgIn	et	lõikes =lõike  (SgIn  >lõige !06_S
46834	käivitab	käivita	käivitama	27_V	IndPrSg3	et	käivitab =käivita  (IndPrSg3  >käivitama !27_V
46835	sõnaga-	sõna	sõna	17_S	SgKom	et	sõnaga- =sõna  (SgKom  >sõna !17_S
46836	mikroteemadeks	teema	mikro+teema	16_S	PlTr	et	mikroteemadeks =teema  (PlTr  >mikro+teema !16_S
46841	autorisoov	soov	autori+soov	22_S	SgN	et	autorisoov =soov  (SgN  >autori+soov !22_S
46843	variandile	variandi	variant	22_S	SgAll	et	variandile =variandi  (SgAll  >variant !22_S
46852	jäätis-	jäätis	jäätis	11~09_S	SgN	et	jäätis- =jäätis  (SgN  >jäätis !11~09_S
46853	sotsiaalteadmistele	teadmis	sotsiaal+teadmine	12?10_S	PlAll	et	sotsiaalteadmistele =teadmis  (PlAll  >sotsiaal+teadmine !12?10_S
46857	noogutas	nooguta	noogutama	27_V	IndIpfSg3	et	noogutas =nooguta  (IndIpfSg3  >noogutama !27_V
46860	muhv-	muhv	muhv	22_S	SgN	et	muhv- =muhv  (SgN  >muhv !22_S
46863	autentne	autentne	autentne	02_A	SgN	et	autentne =autentne  (SgN  >autentne !02_A
46870	nii-	nii	nii	41_D	ID	et	nii- =nii  (ID  >nii !41_D
46872	lauseosale	osa	lause+osa	17_S	SgAll	et	lauseosale =osa  (SgAll  >lause+osa !17_S
46873	värvingu	värvingu	värving	02_S	SgG	et	värvingu =värvingu  (SgG  >värving !02_S
46880	ausas	ausa	aus	02_A	SgIn	et	ausas =ausa  (SgIn  >aus !02_A
46881	rüütleid	rüütle	rüütel	02_S	PlP	et	rüütleid =rüütle  (PlP  >rüütel !02_S
46885	katseid	katse	katse	06_S	PlP	et	katseid =katse  (PlP  >katse !06_S
46886	võimalikuga	võimaliku	võimalik	25_A	SgKom	et	võimalikuga =võimaliku  (SgKom  >võimalik !25_A
46890	seisundiga	seisundi	seisund	02_S	SgKom	et	seisundiga =seisundi  (SgKom  >seisund !02_S
46893	tavainimesed	inimese	tava+inimene	12_S	PlN	et	tavainimesed =inimese  (PlN  >tava+inimene !12_S
46894	taasiseseisvumisse	seisvumis	taas+ise+seisvumine	12_S	SgAdt	et	taasiseseisvumisse =seisvumis  (SgAdt  >taas+ise+seisvumine !12_S
46899	patriootilist	patriootilis	patriootiline	12_A	SgP	et	patriootilist =patriootilis  (SgP  >patriootiline !12_A
46921	tablett	tablett	tablett	22_S	SgN	et	tablett =tablett  (SgN  >tablett !22_S
46924	maffiamehega	mehe	maffia+mees	13_S	SgKom	et	maffiamehega =mehe  (SgKom  >maffia+mees !13_S
46930	momentidel	momenti	moment	22_S	PlAd	et	momentidel =momenti  (PlAd  >moment !22_S
46932	paaremal	ema	paar+ema	17_S	SgAd	et	paaremal =ema  (SgAd  >paar+ema !17_S
46938	ööbida	ööbi	ööbima	27_V	Inf	et	ööbida =ööbi  (Inf  >ööbima !27_V
46939	pansionaadi	pansionaadi	pansionaat	22_S	SgG	et	pansionaadi =pansionaadi  (SgG  >pansionaat !22_S
46942	ettepanekute	paneku	ette+panek	02_S	PlG	et	ettepanekute =paneku  (PlG  >ette+panek !02_S
46956	mobiiltelefonid	telefoni	mobiil+telefon	19_S	PlN	et	mobiiltelefonid =telefoni  (PlN  >mobiil+telefon !19_S
46960	arvutiseta	arvutise	arvutis	11_S	SgAb	et	arvutiseta =arvutise  (SgAb  >arvutis !11_S
46962	leiutist	leiutis	leiutis	11_S	SgP	et	leiutist =leiutis  (SgP  >leiutis !11_S
46966	ebakasulikud	kasuliku	eba+kasulik	25_A	PlN	et	ebakasulikud =kasuliku  (PlN  >eba+kasulik !25_A
46967	majalt	maja	maja	17_S	SgAbl	et	majalt =maja  (SgAbl  >maja !17_S
46972	saavutama	saavuta	saavutama	27_V	Sup	et	saavutama =saavuta  (Sup  >saavutama !27_V
46856	pealkirjas	kirja	peal+kiri	24_S	SgIn	et	pealkirjas =kirja  (SgIn  >peal+kiri !24_S
46869	õevane	õevane	õevane	10_A	SgN	et	õevane =õevane  (SgN  >õevane !10_A
46876	limpsima	limpsi	limpsima	28_V	Sup	et	limpsima =limpsi  (Sup  >limpsima !28_V
46898	unustaks	unusta	unustama	27_V	KndPrPs	et	unustaks =unusta  (KndPrPs  >unustama !27_V
46904	meeleavalduseks	avalduse	meele+avaldus	11_S	SgTr	et	meeleavalduseks =avalduse  (SgTr  >meele+avaldus !11_S
46909	reekviem	reekviem	reekviem	19_S	SgN	et	reekviem =reekviem  (SgN  >reekviem !19_S
46936	kümnenda	kümnenda	kümnes	02_O	SgG	et	kümnenda =kümnenda  (SgG  >kümnes !02_O
46940	maalik	maalik	maalik	25_A	SgN	et	maalik =maalik  (SgN  >maalik !25_A
46945	leiutisi	leiutisi	leiutis	11_S	PlP	et	leiutisi =leiutisi  (PlP  >leiutis !11_S
46946	kasulikuks	kasuliku	kasulik	25_A	SgTr	et	kasulikuks =kasuliku  (SgTr  >kasulik !25_A
46948	piloodi	piloodi	piloot	22_S	SgG	et	piloodi =piloodi  (SgG  >piloot !22_S
46951	telefonita	telefoni	telefon	19_S	SgAb	et	telefonita =telefoni  (SgAb  >telefon !19_S
46959	id-pileti	pileti	id-pilet	02_S	SgG	et	id-pileti =pileti  (SgG  >id-pilet !02_S
46961	tänapäevas	päeva	täna+päev	22_S	SgIn	et	tänapäevas =päeva  (SgIn  >täna+päev !22_S
46969	maailmal	ilma	maa+ilm	22_S	SgAd	et	maailmal =ilma  (SgAd  >maa+ilm !22_S
46971	sümboolne	sümboolne	sümboolne	02_A	SgN	et	sümboolne =sümboolne  (SgN  >sümboolne !02_A
46973	kahetseda	kahetse	kahetsema	27_V	Inf	et	kahetseda =kahetse  (Inf  >kahetsema !27_V
46975	konspekteerida	konspekteeri	konspekteerima	28_V	Inf	et	konspekteerida =konspekteeri  (Inf  >konspekteerima !28_V
46976	konspekt	konspekt	konspekt	22_S	SgN	et	konspekt =konspekt  (SgN  >konspekt !22_S
46984	paberil	paberi	paber	02_S	SgAd	et	paberil =paberi  (SgAd  >paber !02_S
46985	põhiterminitest	termini	põhi+termin	02_S	PlEl	et	põhiterminitest =termini  (PlEl  >põhi+termin !02_S
46988	koostame	koosta	koostama	27_V	IndPrPl1	et	koostame =koosta  (IndPrPl1  >koostama !27_V
46995	telefonis	telefoni	telefon	19_S	SgIn	et	telefonis =telefoni  (SgIn  >telefon !19_S
46996	kiirabile	abi	kiir+abi	17_S	SgAll	et	kiirabile =abi  (SgAll  >kiir+abi !17_S
46999	teedeehituse	ehituse	teede+ehitus	11_S	SgG	et	teedeehituse =ehituse  (SgG  >teede+ehitus !11_S
47004	sõbrata	sõbra	sõber	24_S	SgAb	et	sõbrata =sõbra  (SgAb  >sõber !24_S
47006	trennist	trenni	trenn	22_S	SgEl	et	trennist =trenni  (SgEl  >trenn !22_S
47007	lauatelefon	telefon	laua+telefon	19_S	SgN	et	lauatelefon =telefon  (SgN  >laua+telefon !19_S
47009	kalapüügil	püügi	kala+püük	22_S	SgAd	et	kalapüügil =püügi  (SgAd  >kala+püük !22_S
47010	kaatrimootor	mootor	kaatri+mootor	02_S	SgN	et	kaatrimootor =mootor  (SgN  >kaatri+mootor !02_S
47012	võitsime	võit	võitma	34_V	IndIpfPl1	et	võitsime =võit  (IndIpfPl1  >võitma !34_V
47024	cd-sse	cd	cd	xx_Q	SgIll	et	cd-sse =cd  (SgIll  >cd !xx_Q
47026	andmebaasid	baasi	andme+baas	22_S	PlN	et	andmebaasid =baasi  (PlN  >andme+baas !22_S
47032	elanikudest	elaniku	elanik	25_S	PlEl	et	elanikudest =elaniku  (PlEl  >elanik !25_S
47039	elektrirongid	rongi	elektri+rong	22_S	PlN	et	elektrirongid =rongi  (PlN  >elektri+rong !22_S
47040	trammid	trammi	tramm	22_S	PlN	et	trammid =trammi  (PlN  >tramm !22_S
47048	autodes	auto	auto	16_S	PlIn	et	autodes =auto  (PlIn  >auto !16_S
47052	tüübid	tüübi	tüüp	22_S	PlN	et	tüübid =tüübi  (PlN  >tüüp !22_S
47055	jalgratturit	ratturi	jalg+rattur	02_S	SgP	et	jalgratturit =ratturi  (SgP  >jalg+rattur !02_S
47058	põletik	põletik	põletik	25_S	SgN	et	põletik =põletik  (SgN  >põletik !25_S
47067	elamispind	pind	elamis+pind	22_S	SgN	et	elamispind =pind  (SgN  >elamis+pind !22_S
47073	hoolida	hooli	hoolima	28_V	Inf	et	hoolida =hooli  (Inf  >hoolima !28_V
47077	harmooniat	harmoonia	harmoonia	01_S	SgP	et	harmooniat =harmoonia  (SgP  >harmoonia !01_S
47078	huviringid	ringi	huvi+ring	22_S	PlN	et	huviringid =ringi  (PlN  >huvi+ring !22_S
47080	nõudevahendid	vahendi	nõude+vahend	02_S	PlN	et	nõudevahendid =vahendi  (PlN  >nõude+vahend !02_S
47084	tuhmid	tuhmi	tuhm	22_A	PlN	et	tuhmid =tuhmi  (PlN  >tuhm !22_A
47091	lisaained	aine	lisa+aine	06_S	PlN	et	lisaained =aine  (PlN  >lisa+aine !06_S
47098	prügimäele	mäe	prügi+mägi	21_S	SgAll	et	prügimäele =mäe  (SgAll  >prügi+mägi !21_S
47102	järske	järske	järsk	22_A	PlP	et	järske =järske  (PlP  >järsk !22_A
47106	koduperenaiseks	naise	kodu+pere+naine	12_S	SgTr	et	koduperenaiseks =naise  (SgTr  >kodu+pere+naine !12_S
47107	lastekasvatamine	kasvatamine	laste+kasvatamine	12_S	SgN	et	lastekasvatamine =kasvatamine  (SgN  >laste+kasvatamine !12_S
47110	algklassis	klassi	alg+klass	22_S	SgIn	et	algklassis =klassi  (SgIn  >alg+klass !22_S
47122	1st	st	st	41_I	ID	et	st =st  (ID  >st !41_I
47124	kujutame	kujuta	kujutama	27_V	IndPrPl1	et	kujutame =kujuta  (IndPrPl1  >kujutama !27_V
46901	reformaatoriks	reformaatori	reformaator	02_S	SgTr	et	reformaatoriks =reformaatori  (SgTr  >reformaator !02_S
46903	sinimust	must	sini+must	22_AS	SgN	et	sinimust =must  (SgN  >sini+must !22_AS
46907	infosulg	sulg	info+sulg	22_S	SgN	et	infosulg =sulg  (SgN  >info+sulg !22_S
46908	teravdas	teravda	teravdama	27_V	IndIpfSg3	et	teravdas =teravda  (IndIpfSg3  >teravdama !27_V
46910	narkomaanidest	narkomaani	narkomaan	22_S	PlEl	et	narkomaanidest =narkomaani  (PlEl  >narkomaan !22_S
46912	üksildane	üksildane	üksildane	12_A	SgN	et	üksildane =üksildane  (SgN  >üksildane !12_A
46914	rõivakaupluse	kaupluse	rõiva+kauplus	11~09_S	SgG	et	rõivakaupluse =kaupluse  (SgG  >rõiva+kauplus !11~09_S
46915	narkootikumid	narkootikumi	narkootikum	19_S	PlN	et	narkootikumid =narkootikumi  (PlN  >narkootikum !19_S
46916	narkootikumideta	narkootikumi	narkootikum	19_S	PlAb	et	narkootikumideta =narkootikumi  (PlAb  >narkootikum !19_S
46920	tablette	tablette	tablett	22_S	PlP	et	tablette =tablette  (PlP  >tablett !22_S
46922	gangreen	gangreen	gangreen	22_S	SgN	et	gangreen =gangreen  (SgN  >gangreen !22_S
46923	lepib	lepi	leppima	28_V	IndPrSg3	et	lepib =lepi  (IndPrSg3  >leppima !28_V
46925	orgiatest	orgia	orgia	01_S	PlEl	et	orgiatest =orgia  (PlEl  >orgia !01_S
46926	hullumeelseks	meelse	hullu+meelne	02_A	SgTr	et	hullumeelseks =meelse  (SgTr  >hullu+meelne !02_A
46927	hoogne	hoogne	hoogne	02_A	SgN	et	hoogne =hoogne  (SgN  >hoogne !02_A
46928	klippides	klippi	klipp	22_S	PlIn	et	klippides =klippi  (PlIn  >klipp !22_S
46929	hämarad	hämara	hämar	02_AS	PlN	et	hämarad =hämara  (PlN  >hämar !02_AS
46937	juunini	juuni	juuni	16_S	SgTer	et	juunini =juuni  (SgTer  >juuni !16_S
46944	projekteerida	projekteeri	projekteerima	28_V	Inf	et	projekteerida =projekteeri  (Inf  >projekteerima !28_V
46953	lennukid	lennuki	lennuk	02_S	PlN	et	lennukid =lennuki  (PlN  >lennuk !02_S
46954	tuumafüüsikas	füüsika	tuuma+füüsika	01_S	SgIn	et	tuumafüüsikas =füüsika  (SgIn  >tuuma+füüsika !01_S
46957	leppisite	leppi	leppima	28_V	IndIpfPl2	et	leppisite =leppi  (IndIpfPl2  >leppima !28_V
46963	operatsioonid	operatsiooni	operatsioon	22_S	PlN	et	operatsioonid =operatsiooni  (PlN  >operatsioon !22_S
46968	odavat	odava	odav	02_A	SgP	et	odavat =odava  (SgP  >odav !02_A
46977	prooviksin	proovi	proovima	28_V	KndPrSg1	et	prooviksin =proovi  (KndPrSg1  >proovima !28_V
46979	elektrivahendeid	vahende	elektri+vahend	02_S	PlP	et	elektrivahendeid =vahende  (PlP  >elektri+vahend !02_S
46991	jõuludeks	jõulu	jõul	22_S	PlTr	et	jõuludeks =jõulu  (PlTr  >jõul !22_S
46994	helistad	helista	helistama	27_V	IndPrSg2	et	helistad =helista  (IndPrSg2  >helistama !27_V
46997	momendiks	momendi	moment	22_S	SgTr	et	momendiks =momendi  (SgTr  >moment !22_S
47000	ehitusmaterjalides	materjali	ehitus+materjal	19_S	PlIn	et	ehitusmaterjalides =materjali  (PlIn  >ehitus+materjal !19_S
47001	kontrolltöid	tö	kont+roll+töö	26_S	PlP	et	kontrolltöid =tö  (PlP  >kont+roll+töö !26_S
47020	automootor	mootor	auto+mootor	02_S	SgN	et	automootor =mootor  (SgN  >auto+mootor !02_S
47021	raiskaksin	raiska	raiskama	29_V	KndPrSg1	et	raiskaksin =raiska  (KndPrSg1  >raiskama !29_V
47028	üks-kaks	kaks	üks-kaks	22_N	SgN	et	üks-kaks =kaks  (SgN  >üks-kaks !22_N
47029	külmakapp	kapp	külma+kapp	22_S	SgN	et	külmakapp =kapp  (SgN  >külma+kapp !22_S
47030	playerist	eri	play+eri	17_S	SgEl	et	playerist =eri  (SgEl  >play+eri !17_S
47033	köögikombainid	kombaini	köögi+kombain	22_S	PlN	et	köögikombainid =kombaini  (PlN  >köögi+kombain !22_S
47034	personaal	personaal	personaal	22_S	SgN	et	personaal =personaal  (SgN  >personaal !22_S
47035	protsessorid	protsessori	protsessor	02_S	PlN	et	protsessorid =protsessori  (PlN  >protsessor !02_S
47041	millegigi	mille	miski	00_P	SgG^	et	millegigi =mille  (SgG^  >miski !00_P
47045	tipptundides	tundi	tipp+tund	22_S	PlIn	et	tipptundides =tundi  (PlIn  >tipp+tund !22_S
47046	astud	astu	astuma	28_V	IndPrSg2	et	astud =astu  (IndPrSg2  >astuma !28_V
47051	mootor	mootor	mootor	02_S	SgN	et	mootor =mootor  (SgN  >mootor !02_S
47053	golf	golf	golf	22_S	SgN	et	golf =golf  (SgN  >golf !22_S
47059	vähendame	vähenda	vähendama	27_V	IndPrPl1	et	vähendame =vähenda  (IndPrPl1  >vähendama !27_V
47060	hommikvõimlemist	võimlemis	hommik+võimlemine	12_S	SgP	et	hommikvõimlemist =võimlemis  (SgP  >hommik+võimlemine !12_S
47066	paigaldasime	paigalda	paigaldama	27_V	IndIpfPl1	et	paigaldasime =paigalda  (IndIpfPl1  >paigaldama !27_V
47068	veemõõtjad	mõõtja	vee+mõõtja	01_S	PlN	et	veemõõtjad =mõõtja  (PlN  >vee+mõõtja !01_S
47088	keemiatoodetes	toode	keemia+toode	06_S	PlIn	et	keemiatoodetes =toode  (PlIn  >keemia+toode !06_S
47095	kasutamisjuhisel	juhise	kasutamis+juhis	09_S	SgAd	et	kasutamisjuhisel =juhise  (SgAd  >kasutamis+juhis !09_S
47099	rikkuda	rikku	rikkuma	28_V	Inf	et	rikkuda =rikku  (Inf  >rikkuma !28_V
47104	väsisin	väsi	väsima	27_V	IndIpfSg1	et	väsisin =väsi  (IndIpfSg1  >väsima !27_V
46933	infotelefonid	telefoni	info+telefon	19_S	PlN	et	infotelefonid =telefoni  (PlN  >info+telefon !19_S
46935	pansionaadis	pansionaadi	pansionaat	22_S	SgIn	et	pansionaadis =pansionaadi  (SgIn  >pansionaat !22_S
46941	talutoodangut	toodangu	talu+toodang	02_S	SgP	et	talutoodangut =toodangu  (SgP  >talu+toodang !02_S
46943	leiutisena	leiutise	leiutis	11_S	SgEs	et	leiutisena =leiutise  (SgEs  >leiutis !11_S
46947	automargid	margi	auto+mark	22_S	PlN	et	automargid =margi  (PlN  >auto+mark !22_S
46949	elaksime	ela	elama	27_V	KndPrPl1	et	elaksime =ela  (KndPrPl1  >elama !27_V
46952	sõnaraamatuid	raamatu	sõna+raamat	02_S	PlP	et	sõnaraamatuid =raamatu  (PlP  >sõna+raamat !02_S
46958	hilinete	hiline	hilinema	27_V	IndPrPl2	et	hilinete =hiline  (IndPrPl2  >hilinema !27_V
46970	õhkkondades	õhkkonda	õhkkond	22_S	PlIn	et	õhkkondades =õhkkonda  (PlIn  >õhkkond !22_S
46974	termineid	termine	termin	02_S	PlP	et	termineid =termine  (PlP  >termin !02_S
46978	rühmade	rühma	rühm	22_S	PlG	et	rühmade =rühma  (PlG  >rühm !22_S
46992	leksikat	leksika	leksika	01_S	SgP	et	leksikat =leksika  (SgP  >leksika !01_S
46993	vananemaks	vanane	vananema	27_V	SupTr	et	vananemaks =vanane  (SupTr  >vananema !27_V
47002	sooritasime	soorita	sooritama	27_V	IndIpfPl1	et	sooritasime =soorita  (IndIpfPl1  >sooritama !27_V
47014	mobiiltelefonis	telefoni	mobiil+telefon	19_S	SgIn	et	mobiiltelefonis =telefoni  (SgIn  >mobiil+telefon !19_S
47019	nõusavad	ava	nõus+ava	17_S	PlN	et	nõusavad =ava  (PlN  >nõus+ava !17_S
47023	infotehnoloogiateta	tehnoloogia	info+tehnoloogia	01_S	PlAb	et	infotehnoloogiateta =tehnoloogia  (PlAb  >info+tehnoloogia !01_S
47025	email-le	email	email	xx_Q	SgAll	et	email-le =email  (SgAll  >email !xx_Q
47031	segastada	segasta	segastama	27_V	Inf	et	segastada =segasta  (Inf  >segastama !27_V
47038	linnaelanik	elanik	linna+elanik	25_S	SgN	et	linnaelanik =elanik  (SgN  >linna+elanik !25_S
47042	sõltun	sõltu	sõltuma	27_V	IndPrSg1	et	sõltun =sõltu  (IndPrSg1  >sõltuma !27_V
47047	võimsaid	võimsa	võimas	03~05_A	PlP	et	võimsaid =võimsa  (PlP  >võimas !03~05_A
47056	suitsutab	suitsuta	suitsutama	27_V	IndPrSg3	et	suitsutab =suitsuta  (IndPrSg3  >suitsutama !27_V
47057	maohaavanud	haavanu	mao+haavanu	01_S	PlN	et	maohaavanud =haavanu  (PlN  >mao+haavanu !01_S
47062	köögiviljad	vilja	köögi+vili	24_S	PlN	et	köögiviljad =vilja  (PlN  >köögi+vili !24_S
47069	kahetariifne	tariifne	kahe+tariifne	02_A	SgN	et	kahetariifne =tariifne  (SgN  >kahe+tariifne !02_A
47074	kõrgkunst	kunst	kõrg+kunst	22_S	SgN	et	kõrgkunst =kunst  (SgN  >kõrg+kunst !22_S
47082	loputas	loputa	loputama	27_V	IndIpfSg3	et	loputas =loputa  (IndIpfSg3  >loputama !27_V
47090	lisaaineteid	te	lisa+aine+tee	26_S	PlP	et	lisaaineteid =te  (PlP  >lisa+aine+tee !26_S
47096	tuleohtlik	ohtlik	tule+ohtlik	25_A	SgN	et	tuleohtlik =ohtlik  (SgN  >tule+ohtlik !25_A
47103	rabasin	raba	rabama	27_V	IndIpfSg1	et	rabasin =raba  (IndIpfSg1  >rabama !27_V
47113	jõustub	jõustu	jõustuma	27_V	IndPrSg3	et	jõustub =jõustu  (IndPrSg3  >jõustuma !27_V
47116	põhilistest	põhilis	põhiline	12_A	PlEl	et	põhilistest =põhilis  (PlEl  >põhiline !12_A
47117	õppematerjalide	materjali	õppe+materjal	19_S	PlG	et	õppematerjalide =materjali  (PlG  >õppe+materjal !19_S
47119	õppematerjale	materjale	õppe+materjal	19_S	PlP	et	õppematerjale =materjale  (PlP  >õppe+materjal !19_S
47125	valdama	valda	valdama	29_V	Sup	et	valdama =valda  (Sup  >valdama !29_V
47127	haridusministeerium	ministeerium	haridus+ministeerium	19~02_S	SgN	et	haridusministeerium =ministeerium  (SgN  >haridus+ministeerium !19~02_S
47130	elanikkonnas	elanikkonna	elanikkond	22_S	SgIn	et	elanikkonnas =elanikkonna  (SgIn  >elanikkond !22_S
47132	probleemis	probleemi	probleem	22_S	SgIn	et	probleemis =probleemi  (SgIn  >probleem !22_S
47134	haridusministeeriumile	ministeeriumi	haridus+ministeerium	19~02_S	SgAll	et	haridusministeeriumile =ministeeriumi  (SgAll  >haridus+ministeerium !19~02_S
47148	teologiliises	liise	teo+logi+liisk	22_S	PlIn	et	teologiliises =liise  (PlIn  >teo+logi+liisk !22_S
47154	hansas	hansa	hansa	16_S	SgIn	et	hansas =hansa  (SgIn  >hansa !16_S
47156	peatne	peatne	peatne	02_A	SgN	et	peatne =peatne  (SgN  >peatne !02_A
47162	kordasin	korda	kordama	29_V	IndIpfSg1	et	kordasin =korda  (IndIpfSg1  >kordama !29_V
47163	paisul	paisu	pais	22_S	SgAd	et	paisul =paisu  (SgAd  >pais !22_S
47167	instituudisse	instituudi	instituut	22_S	SgIll	et	instituudisse =instituudi  (SgIll  >instituut !22_S
47169	eksamis	eksami	eksam	02_S	SgIn	et	eksamis =eksami  (SgIn  >eksam !02_S
47184	soovisime	soovi	soovima	28_V	IndIpfPl1	et	soovisime =soovi  (IndIpfPl1  >soovima !28_V
47185	pargisse	pargi	park	22_S	SgIll	et	pargisse =pargi  (SgIll  >park !22_S
47186	viibisime	viibi	viibima	27_V	IndIpfPl1	et	viibisime =viibi  (IndIpfPl1  >viibima !27_V
47190	vaatlesime	vaatle	vaatlema	30_V	IndIpfPl1	et	vaatlesime =vaatle  (IndIpfPl1  >vaatlema !30_V
47194	heitsime	heit	heitma	34_V	IndIpfPl1	et	heitsime =heit  (IndIpfPl1  >heitma !34_V
46980	ttk-s	ttk	ttk	xx_Q	SgIn	et	ttk-s =ttk  (SgIn  >ttk !xx_Q
46983	põhitermineid	termine	põhi+termin	02_S	PlP	et	põhitermineid =termine  (PlP  >põhi+termin !02_S
46989	teemadelt	teema	teema	16_S	PlAbl	et	teemadelt =teema  (PlAbl  >teema !16_S
46990	näiteksmiks	mi	näit+eks+mi	26_S	SgTr	et	näiteksmiks =mi  (SgTr  >näit+eks+mi !26_S
46998	metalliõpetus	õpetus	metalli+õpetus	11_S	SgN	et	metalliõpetus =õpetus  (SgN  >metalli+õpetus !11_S
47003	inseneriks	inseneri	insener	19_S	SgTr	et	inseneriks =inseneri  (SgTr  >insener !19_S
47013	sattuks	sattu	sattuma	27_V	KndPrPs	et	sattuks =sattu  (KndPrPs  >sattuma !27_V
47015	äratuskell	kell	äratus+kell	22_S	SgN	et	äratuskell =kell  (SgN  >äratus+kell !22_S
47016	kalkulaator	kalkulaator	kalkulaator	02_S	SgN	et	kalkulaator =kalkulaator  (SgN  >kalkulaator !02_S
47018	kaubaveod	veo	kauba+vedu	18_S	PlN	et	kaubaveod =veo  (PlN  >kauba+vedu !18_S
47022	kõrgarenevateta	areneva	kõrg+arenev	02_A	PlAb	et	kõrgarenevateta =areneva  (PlAb  >kõrg+arenev !02_A
47036	uuringute	uuringu	uuring	02_S	PlG	et	uuringute =uuringu  (PlG  >uuring !02_S
47049	salong	salong	salong	22_S	SgN	et	salong =salong  (SgN  >salong !22_S
47054	saaksamaast	ast	saak+sama+ast	22_S	SgN	et	saaksamaast =ast  (SgN  >saak+sama+ast !22_S
47063	mustamäelt	mäe	musta+mägi	21_S	SgAbl	et	mustamäelt =mäe  (SgAbl  >musta+mägi !21_S
47070	elektrimõõtjaid	mõõtja	elektri+mõõtja	01_S	PlP	et	elektrimõõtjaid =mõõtja  (PlP  >elektri+mõõtja !01_S
47071	tubades	tuba	tuba	18_S	PlIn	et	tubades =tuba  (PlIn  >tuba !18_S
47079	õhuvärskendajad	värskendaja	õhu+värskendaja	01_S	PlN	et	õhuvärskendajad =värskendaja  (PlN  >õhu+värskendaja !01_S
47085	kraanikausside	kaussi	kraani+kauss	22_S	PlG	et	kraanikausside =kaussi  (PlG  >kraani+kauss !22_S
47086	vannide	vanni	vann	22_S	PlG	et	vannide =vanni  (PlG  >vann !22_S
47089	sisaldatakse	sisalda	sisaldama	27_V	IndPrIps	et	sisaldatakse =sisalda  (IndPrIps  >sisaldama !27_V
47092	keemiatoodet	toode	keemia+toode	06_S	SgP	et	keemiatoodet =toode  (SgP  >keemia+toode !06_S
47093	pestes	pes	pesema	36_V	Ger	et	pestes =pes  (Ger  >pesema !36_V
47094	kummikindaid	kinda	kummi+kinnas	07_S	PlP	et	kummikindaid =kinda  (PlP  >kummi+kinnas !07_S
47097	sattudes	sattu	sattuma	27~28_V	Ger	et	sattudes =sattu  (Ger  >sattuma !27~28_V
47100	joogivee	vee	joogi+vesi	15_S	SgG	et	joogivee =vee  (SgG  >joogi+vesi !15_S
47101	ohtlike	ohtlike	ohtlik	25_A	PlG	et	ohtlike =ohtlike  (PlG  >ohtlik !25_A
47105	kadusin	kadu	kaduma	28_V	IndIpfSg1	et	kadusin =kadu  (IndIpfSg1  >kaduma !28_V
47108	lapseta	lapse	laps	14_S	SgAb	et	lapseta =lapse  (SgAb  >laps !14_S
47112	majandusetase	tase	majanduse+tase	04_S	SgN	et	majandusetase =tase  (SgN  >majanduse+tase !04_S
47118	keeleklassis	klassi	keele+klass	22_S	SgIn	et	keeleklassis =klassi  (SgIn  >keele+klass !22_S
47128	keelteoskuste	oskus	keelte+oskus	11~09_S	PlG	et	keelteoskuste =oskus  (PlG  >keelte+oskus !11~09_S
47131	prantslased	prantslase	prantslane	12?10_S	PlN	et	prantslased =prantslase  (PlN  >prantslane !12?10_S
47137	diskriminatsioon	diskriminatsioon	diskriminatsioon	22_S	SgN	et	diskriminatsioon =diskriminatsioon  (SgN  >diskriminatsioon !22_S
47139	edasijõudmise	jõudmise	edasi+jõudmine	12?10_S	SgG	et	edasijõudmise =jõudmise  (SgG  >edasi+jõudmine !12?10_S
47152	jakk	jakk	jakk	22_S	SgN	et	jakk =jakk  (SgN  >jakk !22_S
47153	jumalateenistusse	teenistus	jumala+teenistus	11_S	SgAdt	et	jumalateenistusse =teenistus  (SgAdt  >jumala+teenistus !11_S
47155	kaneeliõlu	õlu	kaneeli+õlu	24_S	SgN	et	kaneeliõlu =õlu  (SgN  >kaneeli+õlu !24_S
47158	küünalde	küünal	küünal	08_S	PlG	et	küünalde =küünal  (PlG  >küünal !08_S
47160	lendame	lenda	lendama	29_V	IndPrPl1	et	lendame =lenda  (IndPrPl1  >lendama !29_V
47166	kaastunnet	tunne	kaas+tunne	06_S	SgP	et	kaastunnet =tunne  (SgP  >kaas+tunne !06_S
47168	pagaril	pagari	pagar	02_S	SgAd	et	pagaril =pagari  (SgAd  >pagar !02_S
47173	küsitles	küsitle	küsitlema	27_V	IndIpfSg3	et	küsitles =küsitle  (IndIpfSg3  >küsitlema !27_V
47174	lõunauinakut	uinaku	lõuna+uinak	02_S	SgP	et	lõunauinakut =uinaku  (SgP  >lõuna+uinak !02_S
47175	vahtisime	vahti	vahtima	28_V	IndIpfPl1	et	vahtisime =vahti  (IndIpfPl1  >vahtima !28_V
47189	asetasime	aseta	asetama	27_V	IndIpfPl1	et	asetasime =aseta  (IndIpfPl1  >asetama !27_V
47193	väljub	välju	väljuma	27_V	IndPrSg3	et	väljub =välju  (IndPrSg3  >väljuma !27_V
47198	pagasi	pagasi	pagas	02_S	SgG	et	pagasi =pagasi  (SgG  >pagas !02_S
47202	valdasime	valda	valdama	29_V	IndIpfPl1	et	valdasime =valda  (IndIpfPl1  >valdama !29_V
47207	praadisime	praadi	praadima	28_V	IndIpfPl1	et	praadisime =praadi  (IndIpfPl1  >praadima !28_V
47212	õhtusöök	söök	õhtu+söök	22_S	SgN	et	õhtusöök =söök  (SgN  >õhtu+söök !22_S
47217	grillisime	grilli	grillima	28_V	IndIpfPl1	et	grillisime =grilli  (IndIpfPl1  >grillima !28_V
47222	pagas	pagas	pagas	02_S	SgN	et	pagas =pagas  (SgN  >pagas !02_S
46982	põhinetakse	põhine	põhinema	27_V	IndPrIps	et	põhinetakse =põhine  (IndPrIps  >põhinema !27_V
46986	õpiksime	õpi	õppima	28_V	KndPrPl1	et	õpiksime =õpi  (KndPrPl1  >õppima !28_V
46987	annate	anna	andma	34_V	IndPrPl2	et	annate =anna  (IndPrPl2  >andma !34_V
47005	muretsed	muretse	muretsema	27_V	IndPrSg2	et	muretsed =muretse  (IndPrSg2  >muretsema !27_V
47008	hakkangi	hakka	hakkama	29_V	IndPrSg1^	et	hakkangi =hakka  (IndPrSg1^  >hakkama !29_V
47011	rahunesime	rahune	rahunema	27_V	IndIpfPl1	et	rahunesime =rahune  (IndIpfPl1  >rahunema !27_V
47017	kaameraga	kaamera	kaamera	01_S	SgKom	et	kaameraga =kaamera  (SgKom  >kaamera !01_S
47027	elektripliidita	pliidi	elektri+pliit	22_S	SgAb	et	elektripliidita =pliidi  (SgAb  >elektri+pliit !22_S
47037	esmavajalikud	vajaliku	esma+vajalik	25_A	PlN	et	esmavajalikud =vajaliku  (PlN  >esma+vajalik !25_A
47043	kommunikatsioonita	kommunikatsiooni	kommunikatsioon	22_S	SgAb	et	kommunikatsioonita =kommunikatsiooni  (SgAb  >kommunikatsioon !22_S
47044	päevitamas	päevita	päevitama	27_V	SupIn	et	päevitamas =päevita  (SupIn  >päevitama !27_V
47050	sisseruum	ruum	sisse+ruum	22_S	SgN	et	sisseruum =ruum  (SgN  >sisse+ruum !22_S
47061	õhus	õhu	õhk	22_S	SgIn	et	õhus =õhu  (SgIn  >õhk !22_S
47064	kotid	koti	kott	22_S	PlN	et	kotid =koti  (PlN  >kott !22_S
47065	katusekate	kate	katuse+kate	06_S	SgN	et	katusekate =kate  (SgN  >katuse+kate !06_S
47072	lastetoa	toa	laste+tuba	18_S	SgG	et	lastetoa =toa  (SgG  >laste+tuba !18_S
47075	äratundmist	tundmis	ära+tundmine	12?10_S	SgP	et	äratundmist =tundmis  (SgP  >ära+tundmine !12?10_S
47076	vormistatakse	vormista	vormistama	27_V	IndPrIps	et	vormistatakse =vormista  (IndPrIps  >vormistama !27_V
47081	mäletasin	mäleta	mäletama	27_V	IndIpfSg1	et	mäletasin =mäleta  (IndIpfSg1  >mäletama !27_V
47083	seebi	seebi	seep	22_S	SgG	et	seebi =seebi  (SgG  >seep !22_S
47087	seinaplaatide	plaati	seina+plaat	22_S	PlG	et	seinaplaatide =plaati  (PlG  >seina+plaat !22_S
47114	koolieksamid	eksami	kooli+eksam	02_S	PlN	et	koolieksamid =eksami  (PlN  >kooli+eksam !02_S
47115	mõelge	mõel	mõtlema	30_V	ImpPrPl2	et	mõelge =mõel  (ImpPrPl2  >mõtlema !30_V
47121	resultaadi	resultaadi	resultaat	22_S	SgG	et	resultaadi =resultaadi  (SgG  >resultaat !22_S
47123	inimessest	esse	inim+ess	22_S	PlEl	et	inimessest =esse  (PlEl  >inim+ess !22_S
47126	koolidega	kooli	kool	22_S	PlKom	et	koolidega =kooli  (PlKom  >kool !22_S
47136	jaame	jaame	jaam	22_S	PlP	et	jaame =jaame  (PlP  >jaam !22_S
47141	õppekavale	kava	õppe+kava	17_S	SgAll	et	õppekavale =kava  (SgAll  >õppe+kava !17_S
47142	aktiivsel	aktiivse	aktiivne	02_A	SgAd	et	aktiivsel =aktiivse  (SgAd  >aktiivne !02_A
47143	erined	erine	erinema	27_V	IndPrSg2	et	erined =erine  (IndPrSg2  >erinema !27_V
47145	skandaaliks	skandaali	skandaal	22_S	SgTr	et	skandaaliks =skandaali  (SgTr  >skandaal !22_S
47147	kohvidega	kohvi	kohv	22_S	PlKom	et	kohvidega =kohvi  (PlKom  >kohv !22_S
47161	hommikueinet	eine	hommiku+eine	06_S	SgP	et	hommikueinet =eine  (SgP  >hommiku+eine !06_S
47165	märkmeid	märkme	märge	05_S	PlP	et	märkmeid =märkme  (PlP  >märge !05_S
47171	koertega	koer	koer	23_SA	PlKom	et	koertega =koer  (PlKom  >koer !23_SA
47181	ajalehtesid	lehte	aja+leht	22_S	PlP	et	ajalehtesid =lehte  (PlP  >aja+leht !22_S
47192	raudteejaam	jaam	raud+tee+jaam	22_S	SgN	et	raudteejaam =jaam  (SgN  >raud+tee+jaam !22_S
47195	jälgisime	jälgi	jälgima	27_V	IndIpfPl1	et	jälgisime =jälgi  (IndIpfPl1  >jälgima !27_V
47196	tõusime	tõus	tõusma	32_V	IndIpfPl1	et	tõusime =tõus  (IndIpfPl1  >tõusma !32_V
47200	meeres	meere	meer	22_S	PlIn	et	meeres =meere  (PlIn  >meer !22_S
47206	oa	oa	uba	18_S	SgG	et	oa =oa  (SgG  >uba !18_S
47208	viineri	viineri	viiner	02_S	SgG	et	viineri =viineri  (SgG  >viiner !02_S
47209	kõrtsis	kõrtsi	kõrts	22_S	SgIn	et	kõrtsis =kõrtsi  (SgIn  >kõrts !22_S
47213	singi	singi	sink	22_S	SgG	et	singi =singi  (SgG  >sink !22_S
47214	eesnimi-ga	eesnimi	eesnimi	xx_Q	SgKom	et	eesnimi-ga =eesnimi  (SgKom  >eesnimi !xx_Q
47218	kõnelesime	kõnele	kõnelema	31~27_V	IndIpfPl1	et	kõnelesime =kõnele  (IndIpfPl1  >kõnelema !31~27_V
47227	vabaõhkumuuseum	muuseum	vaba+õhku+muuseum	19~02_S	SgN	et	vabaõhkumuuseum =muuseum  (SgN  >vaba+õhku+muuseum !19~02_S
47236	laut	laut	laut	22_S	SgN	et	laut =laut  (SgN  >laut !22_S
47240	kogesime	koge	kogema	27_V	IndIpfPl1	et	kogesime =koge  (IndIpfPl1  >kogema !27_V
47243	pillimängust	mängu	pilli+mäng	22_S	SgEl	et	pillimängust =mängu  (SgEl  >pilli+mäng !22_S
47244	tuletame	tuleta	tuletama	27_V	IndPrPl1	et	tuletame =tuleta  (IndPrPl1  >tuletama !27_V
47249	hingedest	hinge	hing	22_S	PlEl	et	hingedest =hinge  (PlEl  >hing !22_S
47251	kiigutas	kiiguta	kiigutama	27_V	IndIpfSg3	et	kiigutas =kiiguta  (IndIpfSg3  >kiigutama !27_V
47253	instrumendid	instrumendi	instrument	22_S	PlN	et	instrumendid =instrumendi  (PlN  >instrument !22_S
47109	emakelles	kelle	ema+kell	22_S	PlIn	et	emakelles =kelle  (PlIn  >ema+kell !22_S
47111	rahvustega	rahvus	rahvus	11~09_S	PlKom	et	rahvustega =rahvus  (PlKom  >rahvus !11~09_S
47120	protesteeriks	protesteeri	protesteerima	28_V	KndPrPs	et	protesteeriks =protesteeri  (KndPrPs  >protesteerima !28_V
47133	soovitaksin	soovita	soovitama	27_V	KndPrSg1	et	soovitaksin =soovita  (KndPrSg1  >soovitama !27_V
47135	sellisse	selli	sell	22_S	SgIll	et	sellisse =selli  (SgIll  >sell !22_S
47140	unistada	unista	unistama	27_V	Inf	et	unistada =unista  (Inf  >unistama !27_V
47146	nunn	nunn	nunn	22_S	SgN	et	nunn =nunn  (SgN  >nunn !22_S
47151	seespool	seespool	sees+pool	41_DK	ID	et	seespool =seespool  (ID  >sees+pool !41_DK
47159	jaki	jaki	jakk	22_S	SgG	et	jaki =jaki  (SgG  >jakk !22_S
47176	üheksat	üheksa	üheksa	01_N	SgP	et	üheksat =üheksa  (SgP  >üheksa !01_N
47178	nuudleid	nuudle	nuudel	02_S	PlP	et	nuudleid =nuudle  (PlP  >nuudel !02_S
47179	spinatiga	spinati	spinat	02_S	SgKom	et	spinatiga =spinati  (SgKom  >spinat !02_S
47182	mahutile	mahuti	mahuti	01_S	SgAll	et	mahutile =mahuti  (SgAll  >mahuti !01_S
47191	beleuchteten-valgustama	valgusta	beleuchteten-valgustama	27_V	Sup	et	beleuchteten-valgustama =valgusta  (Sup  >beleuchteten-valgustama !27_V
47197	pakkisime	pakki	pakkima	28_V	IndIpfPl1	et	pakkisime =pakki  (IndIpfPl1  >pakkima !28_V
47199	bussijaam	jaam	bussi+jaam	22_S	SgN	et	bussijaam =jaam  (SgN  >bussi+jaam !22_S
47201	matkasime	matka	matkama	29_V	IndIpfPl1	et	matkasime =matka  (IndIpfPl1  >matkama !29_V
47210	bussijaamasse	jaama	bussi+jaam	22_S	SgIll	et	bussijaamasse =jaama  (SgIll  >bussi+jaam !22_S
47216	tulisi	tulisi	tulisi	41_D	ID	et	tulisi =tulisi  (ID  >tulisi !41_D
47219	närvidele	närvi	närv	22_S	PlAll	et	närvidele =närvi  (PlAll  >närv !22_S
47220	keskpäevani	päeva	kesk+päev	22_S	SgTer	et	keskpäevani =päeva  (SgTer  >kesk+päev !22_S
47221	päeviki	päeviki	päevik	02_S	SgG	et	päeviki =päeviki  (SgG  >päevik !02_S
47228	restoranidega	restorani	restoran	19_S	PlKom	et	restoranidega =restorani  (PlKom  >restoran !19_S
47229	ärkasime	ärka	ärkama	29_V	IndIpfPl1	et	ärkasime =ärka  (IndIpfPl1  >ärkama !29_V
47237	koristasime	korista	koristama	27_V	IndIpfPl1	et	koristasime =korista  (IndIpfPl1  >koristama !27_V
47241	valutasime	valuta	valutama	27_V	IndIpfPl1	et	valutasime =valuta  (IndIpfPl1  >valutama !27_V
47250	lauludele	laulu	laul	22_S	PlAll	et	lauludele =laulu  (PlAll  >laul !22_S
47255	lauluharrastus	harrastus	laulu+harrastus	11_S	SgN	et	lauluharrastus =harrastus  (SgN  >laulu+harrastus !11_S
47259	senistele	senis	senine	10_A	PlAll	et	senistele =senis  (PlAll  >senine !10_A
47261	segakoorid	koori	sega+koor	22_S	PlN	et	segakoorid =koori  (PlN  >sega+koor !22_S
47265	pulmalaulud	laulu	pulma+laul	22_S	PlN	et	pulmalaulud =laulu  (PlN  >pulma+laul !22_S
47279	teisedes	ede	teis+ede	16_S	SgIn	et	teisedes =ede  (SgIn  >teis+ede !16_S
47283	kogurahvuslik	rahvuslik	kogu+rahvuslik	25_A	SgN	et	kogurahvuslik =rahvuslik  (SgN  >kogu+rahvuslik !25_A
47292	kasutad	kasuta	kasutama	27_V	IndPrSg2	et	kasutad =kasuta  (IndPrSg2  >kasutama !27_V
47296	pöörame	pööra	pöörama	29_V	IndPrPl1	et	pöörame =pööra  (IndPrPl1  >pöörama !29_V
47298	taludel	talu	talu	17_S	PlAd	et	taludel =talu  (PlAd  >talu !17_S
47305	põlvidel	põlvi	põlv	22_S	PlAd	et	põlvidel =põlvi  (PlAd  >põlv !22_S
47306	peasõnu	sõnu	pea+sõna	17_S	PlP	et	peasõnu =sõnu  (PlP  >pea+sõna !17_S
47315	rahvulaulud	laulu	rahvu+laul	22_S	PlN	et	rahvulaulud =laulu  (PlN  >rahvu+laul !22_S
47320	tantse	tantse	tants	22_S	PlP	et	tantse =tantse  (PlP  >tants !22_S
47324	arhiividest	arhiivi	arhiiv	22_S	PlEl	et	arhiividest =arhiivi  (PlEl  >arhiiv !22_S
47325	salmiraamatuid	raamatu	salmi+raamat	02_S	PlP	et	salmiraamatuid =raamatu  (PlP  >salmi+raamat !02_S
47339	laulukultuuris	kultuuri	laulu+kultuur	22_S	SgIn	et	laulukultuuris =kultuuri  (SgIn  >laulu+kultuur !22_S
47355	toeks	toe	tugi	21_S	SgTr	et	toeks =toe  (SgTr  >tugi !21_S
47360	niisuguses	suguse	nii+sugune	10_P	SgIn	et	niisuguses =suguse  (SgIn  >nii+sugune !10_P
47363	rahvalikeks	rahvalike	rahvalik	25_A	PlTr	et	rahvalikeks =rahvalike  (PlTr  >rahvalik !25_A
47365	kuulsaid	kuulsa	kuulus	02_A	PlP	et	kuulsaid =kuulsa  (PlP  >kuulus !02_A
47371	kurva	kurva	kurb	22_A	SgG	et	kurva =kurva  (SgG  >kurb !22_A
47373	vanavanaisade	isa	vana+vana+isa	17_S	PlG	et	vanavanaisade =isa  (PlG  >vana+vana+isa !17_S
47375	keerukaks	keeruka	keerukas	02_A	SgTr	et	keerukaks =keeruka  (SgTr  >keerukas !02_A
47379	salmikutesse	salmiku	salmik	02_S	PlIll	et	salmikutesse =salmiku  (PlIll  >salmik !02_S
47387	rõõmustades	rõõmusta	rõõmustama	27_V	Ger	et	rõõmustades =rõõmusta  (Ger  >rõõmustama !27_V
47389	lühteri	lühteri	lühter	02_S	SgG	et	lühteri =lühteri  (SgG  >lühter !02_S
47404	teravilju	vilju	tera+vili	24_S	PlP	et	teravilju =vilju  (PlP  >tera+vili !24_S
47129	keelduda	keeldu	keelduma	27_V	Inf	et	keelduda =keeldu  (Inf  >keelduma !27_V
47138	protestima	protesti	protestima	28_V	Sup	et	protestima =protesti  (Sup  >protestima !28_V
47144	õppetakse	takse	õppe+taks	22_S	PlP	et	õppetakse =takse  (PlP  >õppe+taks !22_S
47149	ahjukartulid	kartuli	ahju+kartul	02_S	PlN	et	ahjukartulid =kartuli  (PlN  >ahju+kartul !02_S
47150	sööke	sööke	söök	22_S	PlP	et	sööke =sööke  (PlP  >söök !22_S
47157	lõunasöögile	söögi	lõuna+söök	22_S	SgAll	et	lõunasöögile =söögi  (SgAll  >lõuna+söök !22_S
47164	heitsin	heit	heitma	34_V	IndIpfSg1	et	heitsin =heit  (IndIpfSg1  >heitma !34_V
47170	sadas	sada	sadama	28_V	IndIpfSg3	et	sadas =sada  (IndIpfSg3  >sadama !28_V
47172	kaaselanik	elanik	kaas+elanik	25_S	SgN	et	kaaselanik =elanik  (SgN  >kaas+elanik !25_S
47177	vastasin	vasta	vastama	29_V	IndIpfSg1	et	vastasin =vasta  (IndIpfSg1  >vastama !29_V
47180	vahtisin	vahti	vahtima	28_V	IndIpfSg1	et	vahtisin =vahti  (IndIpfSg1  >vahtima !28_V
47183	pagarile	pagari	pagar	02_S	SgAll	et	pagarile =pagari  (SgAll  >pagar !02_S
47187	eesnimi-lt	eesnimi	eesnimi	xx_Q	SgAbl	et	eesnimi-lt =eesnimi  (SgAbl  >eesnimi !xx_Q
47188	leidsime	leid	leidma	34_V	IndIpfPl1	et	leidsime =leid  (IndIpfPl1  >leidma !34_V
47204	katsusime	katsu	katsuma	28_V	IndIpfPl1	et	katsusime =katsu  (IndIpfPl1  >katsuma !28_V
47205	keetsime	keet	keetma	34_V	IndIpfPl1	et	keetsime =keet  (IndIpfPl1  >keetma !34_V
47211	kingapaelid	paeli	kinga+pael	22_S	PlN	et	kingapaelid =paeli  (PlN  >kinga+pael !22_S
47215	autosõidile	sõidi	auto+sõit	22_S	SgAll	et	autosõidile =sõidi  (SgAll  >auto+sõit !22_S
47225	tahtsi	tahtsi	tahtsi	41_D	ID	et	tahtsi =tahtsi  (ID  >tahtsi !41_D
47231	lend	lend	lend	22_S	SgN	et	lend =lend  (SgN  >lend !22_S
47233	pagasiga	pagasi	pagas	02_S	SgKom	et	pagasiga =pagasi  (SgKom  >pagas !02_S
47234	toompeale	pea	toom+pea	26_S	SgAll	et	toompeale =pea  (SgAll  >toom+pea !26_S
47238	tagastasime	tagasta	tagastama	27_V	IndIpfPl1	et	tagastasime =tagasta  (IndIpfPl1  >tagastama !27_V
47246	tänapäevadeni	päeva	täna+päev	22_S	PlTer	et	tänapäevadeni =päeva  (PlTer  >täna+päev !22_S
47247	pillide	pilli	pill	22_S	PlG	et	pillide =pilli  (PlG  >pill !22_S
47252	vokaalne	vokaalne	vokaalne	02_A	SgN	et	vokaalne =vokaalne  (SgN  >vokaalne !02_A
47258	rõhutad	rõhuta	rõhutama	27_V	IndPrSg2	et	rõhutad =rõhuta  (IndPrSg2  >rõhutama !27_V
47275	laulukultuurist	kultuuri	laulu+kultuur	22_S	SgEl	et	laulukultuurist =kultuuri  (SgEl  >laulu+kultuur !22_S
47281	rahuldati	rahulda	rahuldama	27_V	IndIpfIps	et	rahuldati =rahulda  (IndIpfIps  >rahuldama !27_V
47300	käsitöid	tö	käsi+töö	26_S	PlP	et	käsitöid =tö  (PlP  >käsi+töö !26_S
47309	vanadele	vana	vana	17_AS	PlAll	et	vanadele =vana  (PlAll  >vana !17_AS
47316	eeskujulik	kujulik	ees+kujulik	25_A	SgN	et	eeskujulik =kujulik  (SgN  >ees+kujulik !25_A
47317	laulutraditsioonide	traditsiooni	laulu+traditsioon	22_S	PlG	et	laulutraditsioonide =traditsiooni  (PlG  >laulu+traditsioon !22_S
47321	autorit	autori	autor	02_S	SgP	et	autorit =autori  (SgP  >autor !02_S
47323	sajandit	sajandi	sajand	02_S	SgP	et	sajandit =sajandi  (SgP  >sajand !02_S
47327	esipoolel	poole	esi+pool	22_S	PlAd	et	esipoolel =poole  (PlAd  >esi+pool !22_S
47331	muusikasündmus	sündmus	muusika+sündmus	11~09_S	SgN	et	muusikasündmus =sündmus  (SgN  >muusika+sündmus !11~09_S
47334	iseend	end	ise+enda	00_P	SgP	et	iseend =end  (SgP  >ise+enda !00_P
47336	ühined	ühine	ühinema	27_V	IndPrSg2	et	ühined =ühine  (IndPrSg2  >ühinema !27_V
47337	kultuurisündmusi	sündmusi	kultuuri+sündmus	11_S	PlP	et	kultuurisündmusi =sündmusi  (PlP  >kultuuri+sündmus !11_S
47338	laulufestivale	festivale	laulu+festival	19_S	PlP	et	laulufestivale =festivale  (PlP  >laulu+festival !19_S
47344	meremehi	mehi	mere+mees	13_S	PlP	et	meremehi =mehi  (PlP  >mere+mees !13_S
47346	väljenduda	väljendu	väljenduma	27_V	Inf	et	väljenduda =väljendu  (Inf  >väljenduma !27_V
47347	külastuskäik	käik	külastus+käik	22_S	SgN	et	külastuskäik =käik  (SgN  >külastus+käik !22_S
47356	jõululaulud	laulu	jõulu+laul	22_S	PlN	et	jõululaulud =laulu  (PlN  >jõulu+laul !22_S
47362	väljakutseid	kutse	välja+kutse	06_S	PlP	et	väljakutseid =kutse  (PlP  >välja+kutse !06_S
47366	liis	lii	lii	26_S	SgIn	et	liis =lii  (SgIn  >lii !26_S
47367	tegigi	teg	tegema	28_V	IndIpfSg3^	et	tegigi =teg  (IndIpfSg3^  >tegema !28_V
47369	vokaalsed	vokaalse	vokaalne	02_A	PlN	et	vokaalsed =vokaalse  (PlN  >vokaalne !02_A
47374	rikke	rikke	rike	06_S	SgG	et	rikke =rikke  (SgG  >rike !06_S
47380	magaks	maga	magama	27_V	KndPrPs	et	magaks =maga  (KndPrPs  >magama !27_V
47384	folkloristid	folkloristi	folklorist	22_S	PlN	et	folkloristid =folkloristi  (PlN  >folklorist !22_S
47390	lõppriim	riim	lõpp+riim	22_S	SgN	et	lõppriim =riim  (SgN  >lõpp+riim !22_S
47203	võitlesime	võitle	võitlema	30_V	IndIpfPl1	et	võitlesime =võitle  (IndIpfPl1  >võitlema !30_V
47224	nuudlisalati	salati	nuudli+salat	02_S	SgG	et	nuudlisalati =salati  (SgG  >nuudli+salat !02_S
47226	bussijaamas	jaama	bussi+jaam	22_S	SgIn	et	bussijaamas =jaama  (SgIn  >bussi+jaam !22_S
47232	väljusime	välju	väljuma	27_V	IndIpfPl1	et	väljusime =välju  (IndIpfPl1  >väljuma !27_V
47235	pannkoogid	koogi	pann+kook	22_S	PlN	et	pannkoogid =koogi  (PlN  >pann+kook !22_S
47245	eestisõpru	sõpru	eesti+sõber	24_S	PlP	et	eestisõpru =sõpru  (PlP  >eesti+sõber !24_S
47254	kooridest	koori	koor	22_S	PlEl	et	kooridest =koori  (PlEl  >koor !22_S
47260	puhkpilliorkestritele	orkestri	puhk+pilli+orkester	02_S	PlAll	et	puhkpilliorkestritele =orkestri  (PlAll  >puhk+pilli+orkester !02_S
47262	vabadusesõja	sõja	vabaduse+sõda	18_S	SgG	et	vabadusesõja =sõja  (SgG  >vabaduse+sõda !18_S
47263	rahvuslikuks	rahvusliku	rahvuslik	25_A	SgTr	et	rahvuslikuks =rahvusliku  (SgTr  >rahvuslik !25_A
47264	tegeledes	tegele	tegelema	27_V	Ger	et	tegeledes =tegele  (Ger  >tegelema !27_V
47273	omade	oma	oma	17_A	PlG	et	omade =oma  (PlG  >oma !17_A
47280	mõõtega	mõõte	mõõde	06_S	SgKom	et	mõõtega =mõõte  (SgKom  >mõõde !06_S
47288	rahvalaulades	la	rahva+lau+la	26_S	PlIn	et	rahvalaulades =la  (PlIn  >rahva+lau+la !26_S
47289	ringeid	ringe	ringe	06_S	PlP	et	ringeid =ringe  (PlP  >ringe !06_S
47291	rahvatantsimine	tantsimine	rahva+tantsimine	12_S	SgN	et	rahvatantsimine =tantsimine  (SgN  >rahva+tantsimine !12_S
47295	tantsidest	tantsi	tants	22_S	PlEl	et	tantsidest =tantsi  (PlEl  >tants !22_S
47301	tantsudega	tantsu	tants	22_S	PlKom	et	tantsudega =tantsu  (PlKom  >tants !22_S
47304	okupatsioonidele	okupatsiooni	okupatsioon	22_S	PlAll	et	okupatsioonidele =okupatsiooni  (PlAll  >okupatsioon !22_S
47307	salvestada	salvesta	salvestama	27_V	Inf	et	salvestada =salvesta  (Inf  >salvestama !27_V
47308	merest	mere	meri	20_S	SgEl	et	merest =mere  (SgEl  >meri !20_S
47311	kättesadavamaks	sadavama	kätte+sadavam	02_A	SgTr	et	kättesadavamaks =sadavama  (SgTr  >kätte+sadavam !02_A
47313	imperialism	imperialism	imperialism	22_S	SgN	et	imperialism =imperialism  (SgN  >imperialism !22_S
47322	orkestrid	orkestri	orkester	02_S	PlN	et	orkestrid =orkestri  (PlN  >orkester !02_S
47328	regilauludest	laulu	regi+laul	22_S	PlEl	et	regilauludest =laulu  (PlEl  >regi+laul !22_S
47332	ülevalpidamist	pidamis	üleval+pidamine	12_S	SgP	et	ülevalpidamist =pidamis  (SgP  >üleval+pidamine !12_S
47341	väljendades	väljenda	väljendama	27_V	Ger	et	väljendades =väljenda  (Ger  >väljendama !27_V
47343	nõustage	nõusta	nõustama	27_V	ImpPrPl2	et	nõustage =nõusta  (ImpPrPl2  >nõustama !27_V
47352	üheksateistkümnendast	ast	üheksa+teist+kümnend+ast	22_S	SgN	et	üheksateistkümnendast =ast  (SgN  >üheksa+teist+kümnend+ast !22_S
47358	muusikaalised	alise	muusika+alis	09_S	PlN	et	muusikaalised =alise  (PlN  >muusika+alis !09_S
47368	teistpidi	pidi	teist+pidi	41_D	ID	et	teistpidi =pidi  (ID  >teist+pidi !41_D
47370	pillidega	pilli	pill	22_S	PlKom	et	pillidega =pilli  (PlKom  >pill !22_S
47385	naabreid	naabre	naaber	02_S	PlP	et	naabreid =naabre  (PlP  >naaber !02_S
47399	raamatukauplused	kaupluse	raamatu+kauplus	11~09_S	PlN	et	raamatukauplused =kaupluse  (PlN  >raamatu+kauplus !11~09_S
47403	teraviljad	vilja	tera+vili	24_S	PlN	et	teraviljad =vilja  (PlN  >tera+vili !24_S
47406	vagunis	vaguni	vagun	02_S	SgIn	et	vagunis =vaguni  (SgIn  >vagun !02_S
47412	poliitikaelust	elu	poliitika+elu	17_S	SgEl	et	poliitikaelust =elu  (SgEl  >poliitika+elu !17_S
47417	kirjanduspreemiat	preemia	kirjandus+preemia	01_S	SgP	et	kirjanduspreemiat =preemia  (SgP  >kirjandus+preemia !01_S
47419	sõjaväeosades	osa	sõja+väe+osa	17_S	PlIn	et	sõjaväeosades =osa  (PlIn  >sõja+väe+osa !17_S
47420	allüksusi	üksusi	all+üksus	11_S	PlP	et	allüksusi =üksusi  (PlP  >all+üksus !11_S
47437	sotsid	sotsi	sots	22_S	PlN	et	sotsid =sotsi  (PlN  >sots !22_S
47444	vikerlased	vikerlase	vikerlane	12_S	PlN	et	vikerlased =vikerlase  (PlN  >vikerlane !12_S
47446	kunstiõpetus	õpetus	kunsti+õpetus	11_S	SgN	et	kunstiõpetus =õpetus  (SgN  >kunsti+õpetus !11_S
47451	kolhoosides	kolhoosi	kolhoos	22_S	PlIn	et	kolhoosides =kolhoosi  (PlIn  >kolhoos !22_S
47457	instrumentaalsed	instrumentaalse	instrumentaalne	02_A	PlN	et	instrumentaalsed =instrumentaalse  (PlN  >instrumentaalne !02_A
47461	muusikafestivalidel	festivali	muusika+festival	19_S	PlAd	et	muusikafestivalidel =festivali  (PlAd  >muusika+festival !19_S
47464	töötlusi	töötlusi	töötlus	11_S	PlP	et	töötlusi =töötlusi  (PlP  >töötlus !11_S
47466	võõrvõimude	võimu	võõr+võim	22_S	PlG	et	võõrvõimude =võimu  (PlG  >võõr+võim !22_S
47473	lauluharrastused	harrastuse	laulu+harrastus	11_S	PlN	et	lauluharrastused =harrastuse  (PlN  >laulu+harrastus !11_S
47480	kujuneski	kujune	kujunema	27_V	IndIpfSg3^	et	kujuneski =kujune  (IndIpfSg3^  >kujunema !27_V
47483	tantsustuudioid	stuudio	tantsu+stuudio	01_S	PlP	et	tantsustuudioid =stuudio  (PlP  >tantsu+stuudio !01_S
47223	kanadalast	kanadalas	kanadalane	12_S	SgP	et	kanadalast =kanadalas  (SgP  >kanadalane !12_S
47230	kartsis	kartsi	karts	22_S	SgIn	et	kartsis =kartsi  (SgIn  >karts !22_S
47239	maandusime	maandu	maanduma	27_V	IndIpfPl1	et	maandusime =maandu  (IndIpfPl1  >maanduma !27_V
47242	aitasime	aita	aitama	29_V	IndIpfPl1	et	aitasime =aita  (IndIpfPl1  >aitama !29_V
47248	stiilidega	stiili	stiil	22_S	PlKom	et	stiilidega =stiili  (PlKom  >stiil !22_S
47266	festivalidel	festivali	festival	19_S	PlAd	et	festivalidel =festivali  (PlAd  >festival !19_S
47267	eestlaseid	eestlase	eestlane	10_S	PlP	et	eestlaseid =eestlase  (PlP  >eestlane !10_S
47268	kergeneda	kergene	kergenema	27_V	Inf	et	kergeneda =kergene  (Inf  >kergenema !27_V
47269	massharrastus	harrastus	mass+harrastus	11_S	SgN	et	massharrastus =harrastus  (SgN  >mass+harrastus !11_S
47270	rahvainstrumentidel	instrumenti	rahva+instrument	22_S	PlAd	et	rahvainstrumentidel =instrumenti  (PlAd  >rahva+instrument !22_S
47271	kombetega	kombe	kombe	06_S	PlKom	et	kombetega =kombe  (PlKom  >kombe !06_S
47274	rahvusel	rahvuse	rahvus	11~09_S	SgAd	et	rahvusel =rahvuse  (SgAd  >rahvus !11~09_S
47276	pulmalauljad	laulja	pulma+laulja	01_S	PlN	et	pulmalauljad =laulja  (PlN  >pulma+laulja !01_S
47278	elukaaslaseks	kaaslase	elu+kaaslane	12?10_S	SgTr	et	elukaaslaseks =kaaslase  (SgTr  >elu+kaaslane !12?10_S
47284	pereliikmed	liikme	pere+liige	05_S	PlN	et	pereliikmed =liikme  (PlN  >pere+liige !05_S
47290	kihnust	kihnu	kihn	22_S	SgEl	et	kihnust =kihnu  (SgEl  >kihn !22_S
47293	igades	iga	iga	18_S	PlIn	et	igades =iga  (PlIn  >iga !18_S
47294	koduelanikud	elaniku	kodu+elanik	25_S	PlN	et	koduelanikud =elaniku  (PlN  >kodu+elanik !25_S
47299	väsitati	väsita	väsitama	27_V	IndIpfIps	et	väsitati =väsita  (IndIpfIps  >väsitama !27_V
47310	rühme	rühme	rühm	22_S	PlP	et	rühme =rühme  (PlP  >rühm !22_S
47335	laulutahtmine	tahtmine	laulu+tahtmine	12?10_S	SgN	et	laulutahtmine =tahtmine  (SgN  >laulu+tahtmine !12?10_S
47349	meisterdades	meisterda	meisterdama	27_V	Ger	et	meisterdades =meisterda  (Ger  >meisterdama !27_V
47350	saames	saame	saam	22_S	PlIn	et	saames =saame  (PlIn  >saam !22_S
47351	sümbioosiks	sümbioosi	sümbioos	22_S	SgTr	et	sümbioosiks =sümbioosi  (SgTr  >sümbioos !22_S
47354	aidates	aida	aitama	29_V	Ger	et	aidates =aida  (Ger  >aitama !29_V
47357	aisakell	kell	aisa+kell	22_S	SgN	et	aisakell =kell  (SgN  >aisa+kell !22_S
47364	aegadeks	aega	aeg	22_S	PlTr	et	aegadeks =aega  (PlTr  >aeg !22_S
47372	matustes	matus	matus	09_S	PlIn	et	matustes =matus  (PlIn  >matus !09_S
47382	eestilt	eesti	eesti	16_H	SgAbl	et	eestilt =eesti  (SgAbl  >eesti !16_H
47383	katkeda	katke	katkema	27_V	Inf	et	katkeda =katke  (Inf  >katkema !27_V
47386	kaugesse	kauge	kauge	01_A	SgIll	et	kaugesse =kauge  (SgIll  >kauge !01_A
47388	vokaalsel	vokaalse	vokaalne	02_A	SgAd	et	vokaalsel =vokaalse  (SgAd  >vokaalne !02_A
47405	rongid	rongi	rong	22_S	PlN	et	rongid =rongi  (PlN  >rong !22_S
47408	kultuurseal	sea	kultuur+siga	18_SA	SgAd	et	kultuurseal =sea  (SgAd  >kultuur+siga !18_SA
47418	kirte	kir	kirs	14_S	PlG	et	kirte =kir  (PlG  >kirs !14_S
47422	pataljonid	pataljoni	pataljon	19_S	PlN	et	pataljonid =pataljoni  (PlN  >pataljon !19_S
47427	taavet	taavet	taavet	02_S	SgN	et	taavet =taavet  (SgN  >taavet !02_S
47432	karistussalgiga	salgi	karistus+salk	22_S	SgKom	et	karistussalgiga =salgi  (SgKom  >karistus+salk !22_S
47441	agraarriik	riik	agraar+riik	22_S	SgN	et	agraarriik =riik  (SgN  >agraar+riik !22_S
47448	trikoloor	trikoloor	trikoloor	22_S	SgN	et	trikoloor =trikoloor  (SgN  >trikoloor !22_S
47456	pillimänguga	mängu	pilli+mäng	22_S	SgKom	et	pillimänguga =mängu  (SgKom  >pilli+mäng !22_S
47465	viideks	viide	viit	22_S	PlTr	et	viideks =viide  (PlTr  >viit !22_S
47474	verevalamiseta	valamise	vere+valamine	12_S	SgAb	et	verevalamiseta =valamise  (SgAb  >vere+valamine !12_S
47475	kaasneda	kaasne	kaasnema	27_V	Inf	et	kaasneda =kaasne  (Inf  >kaasnema !27_V
47476	jalapõrutamisega	põrutamise	jala+põrutamine	12_S	SgKom	et	jalapõrutamisega =põrutamise  (SgKom  >jala+põrutamine !12_S
47485	kontsertidest	kontserti	kontsert	22_S	PlEl	et	kontsertidest =kontserti  (PlEl  >kontsert !22_S
47486	lauluvõistlused	võistluse	laulu+võistlus	11~09_S	PlN	et	lauluvõistlused =võistluse  (PlN  >laulu+võistlus !11~09_S
47488	meeslauljad	laulja	mees+laulja	01_S	PlN	et	meeslauljad =laulja  (PlN  >mees+laulja !01_S
47493	rahvalauludel	laulu	rahva+laul	22_S	PlAd	et	rahvalauludel =laulu  (PlAd  >rahva+laul !22_S
47494	rahvatraditsioonidest	traditsiooni	rahva+traditsioon	22_S	PlEl	et	rahvatraditsioonidest =traditsiooni  (PlEl  >rahva+traditsioon !22_S
47495	eestast	ast	eest+ast	22_S	SgN	et	eestast =ast  (SgN  >eest+ast !22_S
47501	popp	popp	popp	22_AS	SgN	et	popp =popp  (SgN  >popp !22_AS
47502	muusikute	muusiku	muusik	02_S	PlG	et	muusikute =muusiku  (PlG  >muusik !02_S
47256	vanemuises	uise	vanem+uisk	22_S	PlIn	et	vanemuises =uise  (PlIn  >vanem+uisk !22_S
47257	puhkepilliorkestrit	orkestri	puhke+pilli+orkester	02_S	SgP	et	puhkepilliorkestrit =orkestri  (SgP  >puhke+pilli+orkester !02_S
47272	lauluvormis	vormi	laulu+vorm	22_S	SgIn	et	lauluvormis =vormi  (SgIn  >laulu+vorm !22_S
47277	lauluvõistlusel	võistluse	laulu+võistlus	11~09_S	SgAd	et	lauluvõistlusel =võistluse  (SgAd  >laulu+võistlus !11~09_S
47282	mõõted	mõõte	mõõde	06_S	PlN	et	mõõted =mõõte  (PlN  >mõõde !06_S
47285	sajandid	sajandi	sajand	02_S	PlN	et	sajandid =sajandi  (PlN  >sajand !02_S
47286	rahvalaulus	laulu	rahva+laul	22_S	SgIn	et	rahvalaulus =laulu  (SgIn  >rahva+laul !22_S
47287	rahvalaulmine	laulmine	rahva+laulmine	12?10_S	SgN	et	rahvalaulmine =laulmine  (SgN  >rahva+laulmine !12?10_S
47297	eluviit	viit	elu+viit	22_S	SgN	et	eluviit =viit  (SgN  >elu+viit !22_S
47302	kõrgtasemel	taseme	kõrg+tase	04_S	SgAd	et	kõrgtasemel =taseme  (SgAd  >kõrg+tase !04_S
47303	laulale	la	lau+la	26_S	SgAll	et	laulale =la  (SgAll  >lau+la !26_S
47312	ebasobivad	sobiva	eba+sobiv	02_A	PlN	et	ebasobivad =sobiva  (PlN  >eba+sobiv !02_A
47314	ebapopulaarsed	populaarse	eba+populaarne	02_A	PlN	et	ebapopulaarsed =populaarse  (PlN  >eba+populaarne !02_A
47318	taiu	taiu	taid	22_S	SgG	et	taiu =taiu  (SgG  >taid !22_S
47319	lugupidamist	pidamis	lugu+pidamine	12_S	SgP	et	lugupidamist =pidamis  (SgP  >lugu+pidamine !12_S
47326	salmidest	salmi	salm	22_S	PlEl	et	salmidest =salmi  (PlEl  >salm !22_S
47329	rahvakalendrist	kalendri	rahva+kalender	02_S	SgEl	et	rahvakalendrist =kalendri  (SgEl  >rahva+kalender !02_S
47330	noorpoiste	pois	noor+poiss	23_S	PlG	et	noorpoiste =pois  (PlG  >noor+poiss !23_S
47333	rokk-muusikat	muusika	rokk-muusika	01_S	SgP	et	rokk-muusikat =muusika  (SgP  >rokk-muusika !01_S
47340	moraalseid	moraalse	moraalne	02_A	PlP	et	moraalseid =moraalse  (PlP  >moraalne !02_A
47342	lauladel	la	lau+la	26_S	PlAd	et	lauladel =la  (PlAd  >lau+la !26_S
47345	merekaldal	kalda	mere+kallas	07_S	SgAd	et	merekaldal =kalda  (SgAd  >mere+kallas !07_S
47348	kasvatades	kasvata	kasvatama	27_V	Ger	et	kasvatades =kasvata  (Ger  >kasvatama !27_V
47353	mainima	maini	mainima	28_V	Sup	et	mainima =maini  (Sup  >mainima !28_V
47359	pereliikmetega	liikme	pere+liige	05_S	PlKom	et	pereliikmetega =liikme  (PlKom  >pere+liige !05_S
47361	algriim	riim	alg+riim	22_S	SgN	et	algriim =riim  (SgN  >alg+riim !22_S
47376	rahvariietes	riie	rahva+riie	06_S	PlIn	et	rahvariietes =riie  (PlIn  >rahva+riie !06_S
47377	usus	usu	usk	22_S	SgIn	et	usus =usu  (SgIn  >usk !22_S
47378	jumalatesse	jumala	jumal	02_S	PlIll	et	jumalatesse =jumala  (PlIll  >jumal !02_S
47381	meloodilised	meloodilise	meloodiline	12_A	PlN	et	meloodilised =meloodilise  (PlN  >meloodiline !12_A
47394	laulukombed	kombe	laulu+komme	06_S	PlN	et	laulukombed =kombe  (PlN  >laulu+komme !06_S
47395	regilauludes	laulu	regi+laul	22_S	PlIn	et	regilauludes =laulu  (PlIn  >regi+laul !22_S
47397	aegades	aega	aeg	22_S	PlIn	et	aegades =aega  (PlIn  >aeg !22_S
47400	trükikojad	koja	trüki+koda	18_S	PlN	et	trükikojad =koja  (PlN  >trüki+koda !18_S
47401	ekraniseeriti	ekraniseeri	ekraniseerima	28_V	IndIpfIps	et	ekraniseeriti =ekraniseeri  (IndIpfIps  >ekraniseerima !28_V
47409	kerises	kerise	keris	09_S	SgIn	et	kerises =kerise  (SgIn  >keris !09_S
47410	iseseisusele	seisuse	ise+seisus	11~09_S	SgAll	et	iseseisusele =seisuse  (SgAll  >ise+seisus !11~09_S
47411	sõjamehi	mehi	sõja+mees	13_S	PlP	et	sõjamehi =mehi  (PlP  >sõja+mees !13_S
47415	keerises	keerise	keeris	09_S	SgIn	et	keerises =keerise  (SgIn  >keeris !09_S
47421	üldmobiliseerimine	mobiliseerimine	üld+mobiliseerimine	12_S	SgN	et	üldmobiliseerimine =mobiliseerimine  (SgN  >üld+mobiliseerimine !12_S
47426	tasa	tasa	tasa	41_D	ID	et	tasa =tasa  (ID  >tasa !41_D
47428	loomismeetodit	meetodi	loo+mis+meetod	02_S	SgP	et	loomismeetodit =meetodi  (SgP  >loo+mis+meetod !02_S
47430	karistussalk	salk	karistus+salk	22_S	SgN	et	karistussalk =salk  (SgN  >karistus+salk !22_S
47433	laipmann	mann	laip+mann	22_S	SgN	et	laipmann =mann  (SgN  >laip+mann !22_S
47436	ukaasiga	ukaasi	ukaas	22_S	SgKom	et	ukaasiga =ukaasi  (SgKom  >ukaas !22_S
47440	domineerib	domineeri	domineerima	28_V	IndPrSg3	et	domineerib =domineeri  (IndPrSg3  >domineerima !28_V
47449	lipuks	lipu	lipp	22_S	SgTr	et	lipuks =lipu  (SgTr  >lipp !22_S
47453	folkloorifestival	festival	folkloori+festival	19_S	SgN	et	folkloorifestival =festival  (SgN  >folkloori+festival !19_S
47458	kokkutulekutel	tuleku	kokku+tulek	02_S	PlAd	et	kokkutulekutel =tuleku  (PlAd  >kokku+tulek !02_S
47460	muusikaseltsidel	seltsi	muusika+selts	22_S	PlAd	et	muusikaseltsidel =seltsi  (PlAd  >muusika+selts !22_S
47467	iseseisvumisese	ese	ise+seisvumis+ese	04_S	SgN	et	iseseisvumisese =ese  (SgN  >ise+seisvumis+ese !04_S
47468	loomingud	loomingu	looming	02_S	PlN	et	loomingud =loomingu  (PlN  >looming !02_S
47469	heliloojateks	looja	heli+looja	01_S	PlTr	et	heliloojateks =looja  (PlTr  >heli+looja !01_S
47391	instrumentaalne	instrumentaalne	instrumentaalne	02_A	SgN	et	instrumentaalne =instrumentaalne  (SgN  >instrumentaalne !02_A
47392	pop-muusikas	muusika	pop-muusika	01_S	SgIn	et	pop-muusikas =muusika  (SgIn  >pop-muusika !01_S
47393	ühislaulmised	laulmise	ühis+laulmine	12?10_S	PlN	et	ühislaulmised =laulmise  (PlN  >ühis+laulmine !12?10_S
47396	aitades	aita	ait	22_S	PlIn	et	aitades =aita  (PlIn  >ait !22_S
47398	kirjanduserühmid	rühmi	kirjanduse+rühm	22_S	PlN	et	kirjanduserühmid =rühmi  (PlN  >kirjanduse+rühm !22_S
47402	värvifilm	film	värvi+film	22_S	SgN	et	värvifilm =film  (SgN  >värvi+film !22_S
47407	veoautod	auto	veo+auto	16_S	PlN	et	veoautod =auto  (PlN  >veo+auto !16_S
47414	valikuvõimalused	võimaluse	valiku+võimalus	11_S	PlN	et	valikuvõimalused =võimaluse  (PlN  >valiku+võimalus !11_S
47423	hukatuslikest	hukatuslike	hukatuslik	25_A	PlEl	et	hukatuslikest =hukatuslike  (PlEl  >hukatuslik !25_A
47424	töölaagrite	laagri	töö+laager	02_S	PlG	et	töölaagrite =laagri  (PlG  >töö+laager !02_S
47429	töökatkestamisega	katkestamise	töö+katkestamine	12_S	SgKom	et	töökatkestamisega =katkestamise  (SgKom  >töö+katkestamine !12_S
47431	veresaun	saun	vere+saun	22_S	SgN	et	veresaun =saun  (SgN  >vere+saun !22_S
47434	draamateatris	teatri	draama+teater	02_S	SgIn	et	draamateatris =teatri  (SgIn  >draama+teater !02_S
47435	lühenes	lühene	lühenema	27_V	IndIpfSg3	et	lühenes =lühene  (IndIpfSg3  >lühenema !27_V
47438	usuõpetamise	õpetamise	usu+õpetamine	12_S	SgG	et	usuõpetamise =õpetamise  (SgG  >usu+õpetamine !12_S
47439	monoetniline	etniline	mono+etniline	12_A	SgN	et	monoetniline =etniline  (SgN  >mono+etniline !12_A
47442	neurokirurg	kirurg	neuro+kirurg	22_S	SgN	et	neurokirurg =kirurg  (SgN  >neuro+kirurg !22_S
47443	ajuoperatsioone	operatsioone	aju+operatsioon	22_S	PlP	et	ajuoperatsioone =operatsioone  (PlP  >aju+operatsioon !22_S
47450	vähemusrahvustele	rahvus	vähemus+rahvus	11~09_S	PlAll	et	vähemusrahvustele =rahvus  (PlAll  >vähemus+rahvus !11~09_S
47454	põlvkondade	põlvkonda	põlvkond	22_S	PlG	et	põlvkondade =põlvkonda  (PlG  >põlvkond !22_S
47462	kollektiivid	kollektiivi	kollektiiv	22_S	PlN	et	kollektiivid =kollektiivi  (PlN  >kollektiiv !22_S
47463	modernseid	modernse	modernne	02_A	PlP	et	modernseid =modernse  (PlP  >modernne !02_A
47470	olulust	lust	olu+lust	22_S	SgN	et	olulust =lust  (SgN  >olu+lust !22_S
47478	viisilt	viisi	viis	22_S	SgAbl	et	viisilt =viisi  (SgAbl  >viis !22_S
47481	ärkamisajaks	aja	ärkamis+aeg	22_S	SgTr	et	ärkamisajaks =aja  (SgTr  >ärkamis+aeg !22_S
47490	laulukoorid	koori	laulu+koor	22_S	PlN	et	laulukoorid =koori  (PlN  >laulu+koor !22_S
47498	kultuurüritusi	üritusi	kultuur+üritus	11_S	PlP	et	kultuurüritusi =üritusi  (PlP  >kultuur+üritus !11_S
47515	laulufunktsioonist	funktsiooni	laulu+funktsioon	22_S	SgEl	et	laulufunktsioonist =funktsiooni  (SgEl  >laulu+funktsioon !22_S
47523	minges	minge	mink	22_S	PlIn	et	minges =minge  (PlIn  >mink !22_S
47526	saksarüütlitega	rüütli	saksa+rüütel	02_S	PlKom	et	saksarüütlitega =rüütli  (PlKom  >saksa+rüütel !02_S
47529	muinasaegseid	aegse	muinas+aegne	02_A	PlP	et	muinasaegseid =aegse  (PlP  >muinas+aegne !02_A
47535	rõõmusega	rõõmuse	rõõmus	02_A	SgKom	et	rõõmusega =rõõmuse  (SgKom  >rõõmus !02_A
47546	asukohtades	kohta	asu+koht	22_S	PlIn	et	asukohtades =kohta  (PlIn  >asu+koht !22_S
47551	pealvaatajate	vaataja	peal+vaataja	01_S	PlG	et	pealvaatajate =vaataja  (PlG  >peal+vaataja !01_S
47555	lavaesindusi	esindusi	lava+esindus	11_S	PlP	et	lavaesindusi =esindusi  (PlP  >lava+esindus !11_S
47561	xxi-sajandi	sajandi	xxi-sajand	02_S	SgG	et	xxi-sajandi =sajandi  (SgG  >xxi-sajand !02_S
47562	kokkuvõtes	võte	kokku+võtt	22_S	PlIn	et	kokkuvõtes =võte  (PlIn  >kokku+võtt !22_S
47566	puhkpilliorkestrid	orkestri	puhk+pilli+orkester	02_S	PlN	et	puhkpilliorkestrid =orkestri  (PlN  >puhk+pilli+orkester !02_S
47567	osavõitjate	võitja	osa+võitja	01_S	PlG	et	osavõitjate =võitja  (PlG  >osa+võitja !01_S
47581	saari	saar	saar	13_S	PlP	et	saari =saar  (PlP  >saar !13_S
47587	muusikalid	muusikali	muusikal	19_S	PlN	et	muusikalid =muusikali  (PlN  >muusikal !19_S
47589	popp-	popp	popp	22_AS	SgN	et	popp- =popp  (SgN  >popp !22_AS
47592	tutvudes	tutvu	tutvuma	27_V	Ger	et	tutvudes =tutvu  (Ger  >tutvuma !27_V
47595	laulule	laulu	laul	22_S	SgAll	et	laulule =laulu  (SgAll  >laul !22_S
47601	heliloomingu	loomingu	heli+looming	02_S	SgG	et	heliloomingu =loomingu  (SgG  >heli+looming !02_S
47607	nüüdisaja	aja	nüüdis+aeg	22_S	SgG	et	nüüdisaja =aja  (SgG  >nüüdis+aeg !22_S
47610	erastab	erasta	erastama	27_V	IndPrSg3	et	erastab =erasta  (IndPrSg3  >erastama !27_V
47627	pealtvaatajad	vaataja	pealt+vaataja	01_S	PlN	et	pealtvaatajad =vaataja  (PlN  >pealt+vaataja !01_S
47632	rock-ansambel	ansambel	rock-ansambel	02_S	SgN	et	rock-ansambel =ansambel  (SgN  >rock-ansambel !02_S
47634	patriootiline	patriootiline	patriootiline	12_A	SgN	et	patriootiline =patriootiline  (SgN  >patriootiline !12_A
47638	praktiseerima	praktiseeri	praktiseerima	28_V	Sup	et	praktiseerima =praktiseeri  (Sup  >praktiseerima !28_V
47413	parandata	paranda	parandama	27_V	IndPrIps_	et	parandata =paranda  (IndPrIps_  >parandama !27_V
47416	prosaistid	prosaisti	prosaist	22_S	PlN	et	prosaistid =prosaisti  (PlN  >prosaist !22_S
47425	väeosade	osa	väe+osa	17_S	PlG	et	väeosade =osa  (PlG  >väe+osa !17_S
47445	koolireform	reform	kooli+reform	22_S	SgN	et	koolireform =reform  (SgN  >kooli+reform !22_S
47447	raudteejaamad	jaama	raud+tee+jaam	22_S	PlN	et	raudteejaamad =jaama  (PlN  >raud+tee+jaam !22_S
47452	emotsioonide	emotsiooni	emotsioon	22_S	PlG	et	emotsioonide =emotsiooni  (PlG  >emotsioon !22_S
47455	võibki	või	võima	37_V	IndPrSg3^	et	võibki =või  (IndPrSg3^  >võima !37_V
47459	naaberriigid	riigi	naaber+riik	22_S	PlN	et	naaberriigid =riigi  (PlN  >naaber+riik !22_S
47471	folkloris	lori	folk+lori	17_S	SgIn	et	folkloris =lori  (SgIn  >folk+lori !17_S
47477	igakord	kord	iga+kord	22_S	SgN	et	igakord =kord  (SgN  >iga+kord !22_S
47484	lauluväljakutel	väljaku	laulu+väljak	02_S	PlAd	et	lauluväljakutel =väljaku  (PlAd  >laulu+väljak !02_S
47499	jaanipäeval	päeva	jaani+päev	22_S	SgAd	et	jaanipäeval =päeva  (SgAd  >jaani+päev !22_S
47504	paganlikke	paganlikke	paganlik	25_A	PlP	et	paganlikke =paganlikke  (PlP  >paganlik !25_A
47509	rahvatraditsioone	traditsioone	rahva+traditsioon	22_S	PlP	et	rahvatraditsioone =traditsioone  (PlP  >rahva+traditsioon !22_S
47518	mitmesugust	sugus	mitme+sugune	10_A	SgP	et	mitmesugust =sugus  (SgP  >mitme+sugune !10_A
47525	vihmametsades	metsa	vihma+mets	22_S	PlIn	et	vihmametsades =metsa  (PlIn  >vihma+mets !22_S
47532	rahvasse	rahva	rahvas	07_S	SgIll	et	rahvasse =rahva  (SgIll  >rahvas !07_S
47533	muusika-instrumente	instrumente	muusika-instrument	22_S	PlP	et	muusika-instrumente =instrumente  (PlP  >muusika-instrument !22_S
47539	rahvakostüümides	kostüümi	rahva+kostüüm	22_S	PlIn	et	rahvakostüümides =kostüümi  (PlIn  >rahva+kostüüm !22_S
47544	rõõmsaga	rõõmsa	rõõmus	02_A	SgKom	et	rõõmsaga =rõõmsa  (SgKom  >rõõmus !02_A
47547	väljust	välju	väli	24_S	PlEl	et	väljust =välju  (PlEl  >väli !24_S
47552	lavas	lava	lava	17_S	SgIn	et	lavas =lava  (SgIn  >lava !17_S
47564	kasvame	kasva	kasvama	28_V	IndPrPl1	et	kasvame =kasva  (IndPrPl1  >kasvama !28_V
47571	võik	võik	võik	22_SA	SgN	et	võik =võik  (SgN  >võik !22_SA
47572	ajaloose	loose	aja+loos	22_S	PlP	et	ajaloose =loose  (PlP  >aja+loos !22_S
47578	kooselavad	elava	koos+elav	02_A	PlN	et	kooselavad =elava  (PlN  >koos+elav !02_A
47584	riigieksamil	eksami	riigi+eksam	02_S	SgAd	et	riigieksamil =eksami  (SgAd  >riigi+eksam !02_S
47585	kostüümides	kostüümi	kostüüm	22_S	PlIn	et	kostüümides =kostüümi  (PlIn  >kostüüm !22_S
47599	ümbertöötlusi	töötlusi	ümber+töötlus	11_S	PlP	et	ümbertöötlusi =töötlusi  (PlP  >ümber+töötlus !11_S
47604	viidid	viidi	viit	22_S	PlN	et	viidid =viidi  (PlN  >viit !22_S
47605	viitma	viit	viitma	34_V	Sup	et	viitma =viit  (Sup  >viitma !34_V
47609	vaimuga	vaimu	vaim	22_S	SgKom	et	vaimuga =vaimu  (SgKom  >vaim !22_S
47614	tantsuseltsid	seltsi	tantsu+selts	22_S	PlN	et	tantsuseltsid =seltsi  (PlN  >tantsu+selts !22_S
47619	vanalaulude	laulu	vana+laul	22_S	PlG	et	vanalaulude =laulu  (PlG  >vana+laul !22_S
47622	pidetakse	takse	pide+taks	22_S	PlP	et	pidetakse =takse  (PlP  >pide+taks !22_S
47625	esindasime	esinda	esindama	27_V	IndIpfPl1	et	esindasime =esinda  (IndIpfPl1  >esindama !27_V
47630	eeslauljata	laulja	ees+laulja	01_S	SgAb	et	eeslauljata =laulja  (SgAb  >ees+laulja !01_S
47636	tankidel	tanki	tank	22_S	PlAd	et	tankidel =tanki  (PlAd  >tank !22_S
47641	ülendab	ülenda	ülendama	27_V	IndPrSg3	et	ülendab =ülenda  (IndPrSg3  >ülendama !27_V
47642	nais-	nai	naima	37_V	IndIpfSg3	et	nais- =nai  (IndIpfSg3  >naima !37_V
47648	pöörates	pööra	pöörama	29_V	Ger	et	pöörates =pööra  (Ger  >pöörama !29_V
47653	sarnaneks	sarnane	sarnanema	27_V	KndPrPs	et	sarnaneks =sarnane  (KndPrPs  >sarnanema !27_V
47654	vanarahvalauludega	laulu	vana+rahva+laul	22_S	PlKom	et	vanarahvalauludega =laulu  (PlKom  >vana+rahva+laul !22_S
47655	olemasolevat	oleva	olemas+olev	02_A	SgP	et	olemasolevat =oleva  (SgP  >olemas+olev !02_A
47661	pop-ansamblid	ansambli	pop-ansambel	02_S	PlN	et	pop-ansamblid =ansambli  (PlN  >pop-ansambel !02_S
47662	laulumängudest	mängu	laulu+mäng	22_S	PlEl	et	laulumängudest =mängu  (PlEl  >laulu+mäng !22_S
47667	rahvaulud	ulu	rahva+ulg	22_S	PlN	et	rahvaulud =ulu  (PlN  >rahva+ulg !22_S
47672	sündmusteks	sündmus	sündmus	11~09_S	PlTr	et	sündmusteks =sündmus  (PlTr  >sündmus !11~09_S
47677	salmialbumite	albumi	salmi+album	02_S	PlG	et	salmialbumite =albumi  (PlG  >salmi+album !02_S
47687	eestimaalased	maalase	eesti+maalane	12?10_S	PlN	et	eestimaalased =maalase  (PlN  >eesti+maalane !12?10_S
47692	minusuguste	sugus	minu+sugune	10_A	PlG	et	minusuguste =sugus  (PlG  >minu+sugune !10_A
47695	mittevokaalsed	vokaalse	mitte+vokaalne	02_A	PlN	et	mittevokaalsed =vokaalse  (PlN  >mitte+vokaalne !02_A
47472	tantsist	tantsi	tants	22_S	SgEl	et	tantsist =tantsi  (SgEl  >tants !22_S
47479	ületähendus	tähendus	üle+tähendus	11_S	SgN	et	ületähendus =tähendus  (SgN  >üle+tähendus !11_S
47482	laulustuudioid	stuudio	laulu+stuudio	01_S	PlP	et	laulustuudioid =stuudio  (PlP  >laulu+stuudio !01_S
47487	tantsurahvaks	rahva	tantsu+rahvas	07_S	SgTr	et	tantsurahvaks =rahva  (SgTr  >tantsu+rahvas !07_S
47491	rahvatantsudega	tantsu	rahva+tants	22_S	PlKom	et	rahvatantsudega =tantsu  (PlKom  >rahva+tants !22_S
47496	rahvusmuusikaga	muusika	rahvus+muusika	01_S	SgKom	et	rahvusmuusikaga =muusika  (SgKom  >rahvus+muusika !01_S
47497	ehtsa	ehtsa	ehtne	02_A	SgG	et	ehtsa =ehtsa  (SgG  >ehtne !02_A
47513	heinaajal	aja	heina+aeg	22_S	SgAd	et	heinaajal =aja  (SgAd  >heina+aeg !22_S
47519	lauludeni	laulu	laul	22_S	PlTer	et	lauludeni =laulu  (PlTer  >laul !22_S
47521	saatega	saate	saade	06_S	SgKom	et	saatega =saate  (SgKom  >saade !06_S
47524	kesk-ameerika	ameerika	kesk-ameerika	41_G	ID	et	kesk-ameerika =ameerika  (ID  >kesk-ameerika !41_G
47527	laulutraditsioone	traditsioone	laulu+traditsioon	22_S	PlP	et	laulutraditsioone =traditsioone  (PlP  >laulu+traditsioon !22_S
47530	esindama	esinda	esindama	27_V	Sup	et	esindama =esinda  (Sup  >esindama !27_V
47536	muusikasfääris	sfääri	muusika+sfäär	22_S	SgIn	et	muusikasfääris =sfääri  (SgIn  >muusika+sfäär !22_S
47542	kodutöid	tö	kodu+töö	26_S	PlP	et	kodutöid =tö  (PlP  >kodu+töö !26_S
47548	20-sajandid	sajandi	-sajand	02_S	PlN	et	-sajandid =sajandi  (PlN  >-sajand !02_S
47554	näitaks	näita	näitama	29_V	KndPrPs	et	näitaks =näita  (KndPrPs  >näitama !29_V
47558	rahvalauludeta	laulu	rahva+laul	22_S	PlAb	et	rahvalauludeta =laulu  (PlAb  >rahva+laul !22_S
47570	üksikuna	üksiku	üksik	02_A	SgEs	et	üksikuna =üksiku  (SgEs  >üksik !02_A
47573	perenaised	naise	pere+naine	12_S	PlN	et	perenaised =naise  (PlN  >pere+naine !12_S
47574	pereelamise	elamise	pere+elamine	12_S	SgG	et	pereelamise =elamise  (SgG  >pere+elamine !12_S
47577	meenutad	meenuta	meenutama	27_V	IndPrSg2	et	meenutad =meenuta  (IndPrSg2  >meenutama !27_V
47579	päevadel	päeva	päev	22_S	PlAd	et	päevadel =päeva  (PlAd  >päev !22_S
47588	maailmatuntud	tuntu	maa+ilma+tuntu	01_S	PlN	et	maailmatuntud =tuntu  (PlN  >maa+ilma+tuntu !01_S
47594	tutvud	tutvu	tutvuma	27_V	IndPrSg2	et	tutvud =tutvu  (IndPrSg2  >tutvuma !27_V
47596	vokaalesitus	esitus	vokaal+esitus	11_S	SgN	et	vokaalesitus =esitus  (SgN  >vokaal+esitus !11_S
47598	ümbertöötlused	töötluse	ümber+töötlus	11~09_S	PlN	et	ümbertöötlused =töötluse  (PlN  >ümber+töötlus !11~09_S
47602	rõõmusi	rõõmusi	rõõmus	02_A	SgG	et	rõõmusi =rõõmusi  (SgG  >rõõmus !02_A
47616	meeliülendavaks	ülendava	meeli+ülendav	02_A	SgTr	et	meeliülendavaks =ülendava  (SgTr  >meeli+ülendav !02_A
47617	sajanditel	sajandi	sajand	02_S	PlAd	et	sajanditel =sajandi  (PlAd  >sajand !02_S
47623	toda	to	too	00_P	SgP	et	toda =to  (SgP  >too !00_P
47628	põllutööl	töö	põllu+töö	26_S	SgAd	et	põllutööl =töö  (SgAd  >põllu+töö !26_S
47633	noorikute	nooriku	noorik	02_S	PlG	et	noorikute =nooriku  (PlG  >noorik !02_S
47643	pahu	pahu	paha	17_AS	PlP	et	pahu =pahu  (PlP  >paha !17_AS
47645	saadeta	saade	saatma	34_V	IndPrIps_	et	saadeta =saade  (IndPrIps_  >saatma !34_V
47646	peodest	peo	peo	26_S	PlEl	et	peodest =peo  (PlEl  >peo !26_S
47650	popi	popi	popp	22_AS	SgG	et	popi =popi  (SgG  >popp !22_AS
47656	poistebänd	bänd	poiste+bänd	22_S	SgN	et	poistebänd =bänd  (SgN  >poiste+bänd !22_S
47659	baarides	baari	baar	22_S	PlIn	et	baarides =baari  (PlIn  >baar !22_S
47678	igasugustes	sugus	iga+sugune	10_A	PlIn	et	igasugustes =sugus  (PlIn  >iga+sugune !10_A
47681	materiaalväärtused	väärtuse	materiaal+väärtus	11~09_S	PlN	et	materiaalväärtused =väärtuse  (PlN  >materiaal+väärtus !11~09_S
47682	vaidlen	vaidle	vaidlema	30_V	IndPrSg1	et	vaidlen =vaidle  (IndPrSg1  >vaidlema !30_V
47693	põllutöödest	töö	põllu+töö	26_S	PlEl	et	põllutöödest =töö  (PlEl  >põllu+töö !26_S
47702	pälvida	pälvi	pälvima	28_V	Inf	et	pälvida =pälvi  (Inf  >pälvima !28_V
47713	regilaulus	laulu	regi+laul	22_S	SgIn	et	regilaulus =laulu  (SgIn  >regi+laul !22_S
47717	kooridega	koori	koor	22_S	PlKom	et	kooridega =koori  (PlKom  >koor !22_S
47718	regilaulude	laulu	regi+laul	22_S	PlG	et	regilaulude =laulu  (PlG  >regi+laul !22_S
47721	sajandilt	sajandi	sajand	02_S	SgAbl	et	sajandilt =sajandi  (SgAbl  >sajand !02_S
47723	rahvalauludele	laulu	rahva+laul	22_S	PlAll	et	rahvalauludele =laulu  (PlAll  >rahva+laul !22_S
47725	kõnel	kõne	kõne	16_S	SgAd	et	kõnel =kõne  (SgAd  >kõne !16_S
47727	lauladele	la	lau+la	26_S	PlAll	et	lauladele =la  (PlAll  >lau+la !26_S
47728	mõttega	mõtte	mõte	06_S	SgKom	et	mõttega =mõtte  (SgKom  >mõte !06_S
47730	tantsuliikumised	liikumise	tantsu+liikumine	12_S	PlN	et	tantsuliikumised =liikumise  (PlN  >tantsu+liikumine !12_S
47489	muusikainstrumentidega	instrumenti	muusika+instrument	22_S	PlKom	et	muusikainstrumentidega =instrumenti  (PlKom  >muusika+instrument !22_S
47492	kultuurisündmus	sündmus	kultuuri+sündmus	11~09_S	SgN	et	kultuurisündmus =sündmus  (SgN  >kultuuri+sündmus !11~09_S
47500	vabaõhumuuseumis	muuseumi	vaba+õhu+muuseum	19~02_S	SgIn	et	vabaõhumuuseumis =muuseumi  (SgIn  >vaba+õhu+muuseum !19~02_S
47506	kirikulaulmist	laulmis	kiriku+laulmine	12?10_S	SgP	et	kirikulaulmist =laulmis  (SgP  >kiriku+laulmine !12?10_S
47507	rütme	rütme	rütm	22_S	PlP	et	rütme =rütme  (PlP  >rütm !22_S
47512	regilauludeks	laulu	regi+laul	22_S	PlTr	et	regilauludeks =laulu  (PlTr  >regi+laul !22_S
47514	regilauludel	laulu	regi+laul	22_S	PlAd	et	regilauludel =laulu  (PlAd  >regi+laul !22_S
47517	geenides	geeni	geen	22_S	PlIn	et	geenides =geeni  (PlIn  >geen !22_S
47520	tänapäevad	päeva	täna+päev	22_S	PlN	et	tänapäevad =päeva  (PlN  >täna+päev !22_S
47537	neiusid	neiu	neiu	16_S	PlP	et	neiusid =neiu  (PlP  >neiu !16_S
47538	sünnipäevadel	päeva	sünni+päev	22_S	PlAd	et	sünnipäevadel =päeva  (PlAd  >sünni+päev !22_S
47541	rõõmsal	rõõmsa	rõõmus	02_A	SgAd	et	rõõmsal =rõõmsa  (SgAd  >rõõmus !02_A
47543	1860-tes			xx_Q	PlIn	et	-tes =  (PlIn  > !xx_Q
47549	sissetunne	tunne	sisse+tunne	06_S	SgN	et	sissetunne =tunne  (SgN  >sisse+tunne !06_S
47557	meelahustus	lahustus	mee+lahustus	11_S	SgN	et	meelahustus =lahustus  (SgN  >mee+lahustus !11_S
47560	lasterahvaansamblid	ansambli	laste+rahva+ansambel	02_S	PlN	et	lasterahvaansamblid =ansambli  (PlN  >laste+rahva+ansambel !02_S
47569	eeslauljat	laulja	ees+laulja	01_S	SgP	et	eeslauljat =laulja  (SgP  >ees+laulja !01_S
47575	meiepäevadel	päeva	meie+päev	22_S	PlAd	et	meiepäevadel =päeva  (PlAd  >meie+päev !22_S
47580	pianistide	pianisti	pianist	22_S	PlG	et	pianistide =pianisti  (PlG  >pianist !22_S
47586	ajaloofaktor	faktor	aja+loo+faktor	02_S	SgN	et	ajaloofaktor =faktor  (SgN  >aja+loo+faktor !02_S
47590	rahvalauljad	laulja	rahva+laulja	01_S	PlN	et	rahvalauljad =laulja  (PlN  >rahva+laulja !01_S
47593	rahvalaulutraditsioonidega	traditsiooni	rahva+laulu+traditsioon	22_S	PlKom	et	rahvalaulutraditsioonidega =traditsiooni  (PlKom  >rahva+laulu+traditsioon !22_S
47603	pillisaateid	saate	pilli+saade	06_S	PlP	et	pillisaateid =saate  (PlP  >pilli+saade !06_S
47606	rahvalaulutraditsioonid	traditsiooni	rahva+laulu+traditsioon	22_S	PlN	et	rahvalaulutraditsioonid =traditsiooni  (PlN  >rahva+laulu+traditsioon !22_S
47612	muistsel	muistse	muistne	02_A	SgAd	et	muistsel =muistse  (SgAd  >muistne !02_A
47615	vabadusetundmiseks	tundmise	vabaduse+tundmine	12?10_S	SgTr	et	vabadusetundmiseks =tundmise  (SgTr  >vabaduse+tundmine !12?10_S
47618	helinaid	helina	helin	02_S	PlP	et	helinaid =helina  (PlP  >helin !02_S
47624	pärandab	päranda	pärandama	27_V	IndPrSg3	et	pärandab =päranda  (IndPrSg3  >pärandama !27_V
47631	pop-kultuurile	kultuuri	pop-kultuur	22_S	SgAll	et	pop-kultuurile =kultuuri  (SgAll  >pop-kultuur !22_S
47635	laulurevolutsiooniga	revolutsiooni	laulu+revolutsioon	22_S	SgKom	et	laulurevolutsiooniga =revolutsiooni  (SgKom  >laulu+revolutsioon !22_S
47637	rahvusmuusikat	muusika	rahvus+muusika	01_S	SgP	et	rahvusmuusikat =muusika  (SgP  >rahvus+muusika !01_S
47647	loodushääli	hääl	loodus+hääl	13_S	PlP	et	loodushääli =hääl  (PlP  >loodus+hääl !13_S
47651	tempos	tempo	tempo	16_S	SgIn	et	tempos =tempo  (SgIn  >tempo !16_S
47657	kandist	kandi	kant	22_S	SgEl	et	kandist =kandi  (SgEl  >kant !22_S
47664	pulmariided	riide	pulma+riie	06_S	PlN	et	pulmariided =riide  (PlN  >pulma+riie !06_S
47668	algusaegu	aegu	algus+aeg	22_S	PlP	et	algusaegu =aegu  (PlP  >algus+aeg !22_S
47671	18st	st	st	41_I	ID	et	st =st  (ID  >st !41_I
47674	süvenedes	süvene	süvenema	27_V	Ger	et	süvenedes =süvene  (Ger  >süvenema !27_V
47675	väljendusvahendiks	vahendi	väljendus+vahend	02_S	SgTr	et	väljendusvahendiks =vahendi  (SgTr  >väljendus+vahend !02_S
47704	kasvades	kasva	kasvama	28_V	Ger	et	kasvades =kasva  (Ger  >kasvama !28_V
47707	liikmena	liikme	liige	05_S	SgEs	et	liikmena =liikme  (SgEs  >liige !05_S
47711	loodustingimused	tingimuse	loodus+tingimus	11_S	PlN	et	loodustingimused =tingimuse  (PlN  >loodus+tingimus !11_S
47719	esindati	esinda	esindama	27_V	IndIpfIps	et	esindati =esinda  (IndIpfIps  >esindama !27_V
47720	laulmisstiil	stiil	laulmis+stiil	22_S	SgN	et	laulmisstiil =stiil  (SgN  >laulmis+stiil !22_S
47731	festivalil	festivali	festival	19_S	SgAd	et	festivalil =festivali  (SgAd  >festival !19_S
47732	võrdsest	võrdse	võrdne	02_A	SgEl	et	võrdsest =võrdse  (SgEl  >võrdne !02_A
47738	kokkutulekute	tuleku	kokku+tulek	02_S	PlG	et	kokkutulekute =tuleku  (PlG  >kokku+tulek !02_S
47751	mitteüksikuna	üksiku	mitte+üksik	02_A	SgEs	et	mitteüksikuna =üksiku  (SgEs  >mitte+üksik !02_A
47757	organiseerima	organiseeri	organiseerima	28_V	Sup	et	organiseerima =organiseeri  (Sup  >organiseerima !28_V
47761	demonstratsioon	demonstratsioon	demonstratsioon	22_S	SgN	et	demonstratsioon =demonstratsioon  (SgN  >demonstratsioon !22_S
47503	kauges	kauge	kauge	01_A	SgIn	et	kauges =kauge  (SgIn  >kauge !01_A
47505	imeilusat	ilusa	ime+ilus	02_A	SgP	et	imeilusat =ilusa  (SgP  >ime+ilus !02_A
47508	vaks	vaks	vaks	22_S	SgN	et	vaks =vaks  (SgN  >vaks !22_S
47510	idasse	ida	ida	17_S	SgIll	et	idasse =ida  (SgIll  >ida !17_S
47511	valgevenemaalt	maa	valge+vene+maa	26_S	SgAbl	et	valgevenemaalt =maa  (SgAbl  >valge+vene+maa !26_S
47516	pillimehi	mehi	pilli+mees	13_S	PlP	et	pillimehi =mehi  (PlP  >pilli+mees !13_S
47522	rahvustantsud	tantsu	rahvus+tants	22_S	PlN	et	rahvustantsud =tantsu  (PlN  >rahvus+tants !22_S
47528	muinasaegsel	aegse	muinas+aegne	02_A	SgAd	et	muinasaegsel =aegse  (SgAd  >muinas+aegne !02_A
47531	laengut	laengu	laeng	02_S	SgP	et	laengut =laengu  (SgP  >laeng !02_S
47534	kuulaksin	kuula	kuulama	29_V	KndPrSg1	et	kuulaksin =kuula  (KndPrSg1  >kuulama !29_V
47540	pidulikud	piduliku	pidulik	25_A	PlN	et	pidulikud =piduliku  (PlN  >pidulik !25_A
47545	mäletades	mäleta	mäletama	27_V	Ger	et	mäletades =mäleta  (Ger  >mäletama !27_V
47550	lauluväljakud	väljaku	laulu+väljak	02_S	PlN	et	lauluväljakud =väljaku  (PlN  >laulu+väljak !02_S
47553	rahvariietus	riietus	rahva+riietus	11_S	SgN	et	rahvariietus =riietus  (SgN  >rahva+riietus !11_S
47556	saarega	saare	saar	13_S	SgKom	et	saarega =saare  (SgKom  >saar !13_S
47559	suurüritusi	üritusi	suur+üritus	11_S	PlP	et	suurüritusi =üritusi  (PlP  >suur+üritus !11_S
47563	praeguseni	praeguse	praegune	10~12_A	SgTer	et	praeguseni =praeguse  (SgTer  >praegune !10~12_A
47565	vanemait	ait	vanem+ait	22_S	SgN	et	vanemait =ait  (SgN  >vanem+ait !22_S
47568	kolmekümnend	kümnend	kolme+kümnend	02_S	SgN	et	kolmekümnend =kümnend  (SgN  >kolme+kümnend !02_S
47576	külasid	küla	küla	17_S	PlP	et	külasid =küla  (PlP  >küla !17_S
47582	kadakad	kadaka	kadakas	02_S	PlN	et	kadakad =kadaka  (PlN  >kadakas !02_S
47583	muusikakoolides	kooli	muusika+kool	22_S	PlIn	et	muusikakoolides =kooli  (PlIn  >muusika+kool !22_S
47591	klubimuusikat	muusika	klubi+muusika	01_S	SgP	et	klubimuusikat =muusika  (SgP  >klubi+muusika !01_S
47597	olekuga	oleku	olek	02_S	SgKom	et	olekuga =oleku  (SgKom  >olek !02_S
47600	laulukunst	kunst	laulu+kunst	22_S	SgN	et	laulukunst =kunst  (SgN  >laulu+kunst !22_S
47608	ülaltoodud	toodu	ülal+toodu	01_S	PlN	et	ülaltoodud =toodu  (PlN  >ülal+toodu !01_S
47611	teevadki	tee	tegema	28_V	IndPrPl3^	et	teevadki =tee  (IndPrPl3^  >tegema !28_V
47613	salmikud	salmiku	salmik	02_S	PlN	et	salmikud =salmiku  (PlN  >salmik !02_S
47620	eluosaks	osa	elu+osa	17_S	SgTr	et	eluosaks =osa  (SgTr  >elu+osa !17_S
47621	kultuurisündmuseks	sündmuse	kultuuri+sündmus	11~09_S	SgTr	et	kultuurisündmuseks =sündmuse  (SgTr  >kultuuri+sündmus !11~09_S
47626	rahvustantsudega	tantsu	rahvus+tants	22_S	PlKom	et	rahvustantsudega =tantsu  (PlKom  >rahvus+tants !22_S
47629	laulusõnu	sõnu	laulu+sõna	17_S	PlP	et	laulusõnu =sõnu  (PlP  >laulu+sõna !17_S
47639	rahvariiete	riie	rahva+riie	06_S	PlG	et	rahvariiete =riie  (PlG  >rahva+riie !06_S
47649	lauluüritusi	üritusi	laulu+üritus	11_S	PlP	et	lauluüritusi =üritusi  (PlP  >laulu+üritus !11_S
47660	lauluvõistlus	võistlus	laulu+võistlus	11~09_S	SgN	et	lauluvõistlus =võistlus  (SgN  >laulu+võistlus !11~09_S
47665	muusikakoolid	kooli	muusika+kool	22_S	PlN	et	muusikakoolid =kooli  (PlN  >muusika+kool !22_S
47669	rõõmudest	rõõmu	rõõm	22_S	PlEl	et	rõõmudest =rõõmu  (PlEl  >rõõm !22_S
47670	laulmiskultuur	kultuur	laulmis+kultuur	22_S	SgN	et	laulmiskultuur =kultuur  (SgN  >laulmis+kultuur !22_S
47679	ujub	uju	ujuma	27_V	IndPrSg3	et	ujub =uju  (IndPrSg3  >ujuma !27_V
47683	lõuna-eestil	eesti	lõuna-eesti	16_H	SgAd	et	lõuna-eestil =eesti  (SgAd  >lõuna-eesti !16_H
47684	laulutraditsioonita	traditsiooni	laulu+traditsioon	22_S	SgAb	et	laulutraditsioonita =traditsiooni  (SgAb  >laulu+traditsioon !22_S
47685	rahandus	rahandus	rahandus	11_S	SgN	et	rahandus =rahandus  (SgN  >rahandus !11_S
47688	teadlast	teadlas	teadlane	12?10_S	SgP	et	teadlast =teadlas  (SgP  >teadlane !12?10_S
47694	pillisaatmist	saatmis	pilli+saatmine	12?10_S	SgP	et	pillisaatmist =saatmis  (SgP  >pilli+saatmine !12?10_S
47698	vanamoodsaid	moodsa	vana+moodne	02_A	PlP	et	vanamoodsaid =moodsa  (PlP  >vana+moodne !02_A
47705	temata	tema	tema	00_P	SgAb	et	temata =tema  (SgAb  >tema !00_P
47706	liikmena	liikme	liige	05_S	SgEs	et	liikmena =liikme  (SgEs  >liige !05_S
47712	paigani	paiga	paik	22_S	SgTer	et	paigani =paiga  (SgTer  >paik !22_S
47715	algati	ati	alg+att	22_S	SgG	et	algati =ati  (SgG  >alg+att !22_S
47733	arvame	arva	arvama	29_V	IndPrPl1	et	arvame =arva  (IndPrPl1  >arvama !29_V
47742	spetsiifilised	spetsiifilise	spetsiifiline	12_A	PlN	et	spetsiifilised =spetsiifilise  (PlN  >spetsiifiline !12_A
47755	põlvkonde	põlvkonde	põlvkond	22_S	PlP	et	põlvkonde =põlvkonde  (PlP  >põlvkond !22_S
47760	majandusreformid	reformi	majandus+reform	22_S	PlN	et	majandusreformid =reformi  (PlN  >majandus+reform !22_S
47640	imesuurt	suur	ime+suur	13_A	SgP	et	imesuurt =suur  (SgP  >ime+suur !13_A
47644	põlul	põlu	põlg	22_S	SgAd	et	põlul =põlu  (SgAd  >põlg !22_S
47652	sajandiga	sajandi	sajand	02_S	SgKom	et	sajandiga =sajandi  (SgKom  >sajand !02_S
47658	rock-muusikat	muusika	rock-muusika	01_S	SgP	et	rock-muusikat =muusika  (SgP  >rock-muusika !01_S
47663	karjuda	karju	karjuma	28_V	Inf	et	karjuda =karju  (Inf  >karjuma !28_V
47666	populaarse	populaarse	populaarne	02_A	SgG	et	populaarse =populaarse  (SgG  >populaarne !02_A
47673	ringkond	ringkond	ringkond	22_S	SgN	et	ringkond =ringkond  (SgN  >ringkond !22_S
47676	muistsetest	muistse	muistne	02_A	PlEl	et	muistsetest =muistse  (PlEl  >muistne !02_A
47680	lihtinimene	inimene	liht+inimene	12_S	SgN	et	lihtinimene =inimene  (SgN  >liht+inimene !12_S
47686	rootslaseid	rootslase	rootslane	10_S	PlP	et	rootslaseid =rootslase  (PlP  >rootslane !10_S
47689	rahuldata	rahulda	rahuldama	27_V	IndPrIps_	et	rahuldata =rahulda  (IndPrIps_  >rahuldama !27_V
47690	põhjusteni	põhjus	põhjus	11~09_S	PlTer	et	põhjusteni =põhjus  (PlTer  >põhjus !11~09_S
47691	tingimusteni	tingimus	tingimus	11_S	PlTer	et	tingimusteni =tingimus  (PlTer  >tingimus !11_S
47697	mõttelaadid	laadi	mõtte+laad	22_S	PlN	et	mõttelaadid =laadi  (PlN  >mõtte+laad !22_S
47700	ülemaailmsed	ilmse	üle+maa+ilmne	02_A	PlN	et	ülemaailmsed =ilmse  (PlN  >üle+maa+ilmne !02_A
47701	tendentsid	tendentsi	tendents	22_S	PlN	et	tendentsid =tendentsi  (PlN  >tendents !22_S
47714	samatähega	tähe	sama+täht	22_S	SgKom	et	samatähega =tähe  (SgKom  >sama+täht !22_S
47724	kuidki	ku	kuu	26_S	PlP^	et	kuidki =ku  (PlP^  >kuu !26_S
47726	ülestõusmise	tõusmise	üles+tõusmine	12?10_S	SgG	et	ülestõusmise =tõusmise  (SgG  >üles+tõusmine !12?10_S
47729	laulutekstid	teksti	laulu+tekst	22_S	PlN	et	laulutekstid =teksti  (PlN  >laulu+tekst !22_S
47734	nurk	nurk	nurk	22_S	SgN	et	nurk =nurk  (SgN  >nurk !22_S
47735	abikaasade	kaasa	abi+kaasa	16_S	PlG	et	abikaasade =kaasa  (PlG  >abi+kaasa !16_S
47741	eeslauljad	laulja	ees+laulja	01_S	PlN	et	eeslauljad =laulja  (PlN  >ees+laulja !01_S
47743	vokaalseid	vokaalse	vokaalne	02_A	PlP	et	vokaalseid =vokaalse  (PlP  >vokaalne !02_A
47744	kirjanduslikul	kirjandusliku	kirjanduslik	25_A	SgAd	et	kirjanduslikul =kirjandusliku  (SgAd  >kirjanduslik !25_A
47752	karjudes	karju	karjuma	28_V	Ger	et	karjudes =karju  (Ger  >karjuma !28_V
47754	säilitades	säilita	säilitama	27_V	Ger	et	säilitades =säilita  (Ger  >säilitama !27_V
47758	natsionaalsed	natsionaalse	natsionaalne	02_A	PlN	et	natsionaalsed =natsionaalse  (PlN  >natsionaalne !02_A
47767	hästikasvatud	kasvatu	hästi+kasvatu	01_AS	PlN	et	hästikasvatud =kasvatu  (PlN  >hästi+kasvatu !01_AS
47780	kaaluga	kaalu	kaal	22_S	SgKom	et	kaaluga =kaalu  (SgKom  >kaal !22_S
47781	grammid	grammi	gramm	22_S	PlN	et	grammid =grammi  (PlN  >gramm !22_S
47782	meenis	meenis	meenis	09_S	SgN	et	meenis =meenis  (SgN  >meenis !09_S
47783	sugulasedele	ede	sugulas+ede	16_S	SgAll	et	sugulasedele =ede  (SgAll  >sugulas+ede !16_S
47792	kõneaeg	aeg	kõne+aeg	22_S	SgN	et	kõneaeg =aeg  (SgN  >kõne+aeg !22_S
47797	telefoniraamat	raamat	telefoni+raamat	02_S	SgN	et	telefoniraamat =raamat  (SgN  >telefoni+raamat !02_S
47799	lusika	lusika	lusikas	02_S	SgG	et	lusika =lusika  (SgG  >lusikas !02_S
47809	pruunist	pruuni	pruun	22_AS	SgEl	et	pruunist =pruuni  (SgEl  >pruun !22_AS
47813	uinuma	uinu	uinuma	27_V	Sup	et	uinuma =uinu  (Sup  >uinuma !27_V
47817	vähk	vähk	vähk	22_S	SgN	et	vähk =vähk  (SgN  >vähk !22_S
47821	hoidke	hoid	hoidma	34_V	ImpPrPl2	et	hoidke =hoid  (ImpPrPl2  >hoidma !34_V
47842	vaniljekastmega	kastme	vanilje+kaste	05_S	SgKom	et	vaniljekastmega =kastme  (SgKom  >vanilje+kaste !05_S
47844	rumm	rumm	rumm	22_S	SgN	et	rumm =rumm  (SgN  >rumm !22_S
47846	rostbiif	rostbiif	rostbiif	22_S	SgN	et	rostbiif =rostbiif  (SgN  >rostbiif !22_S
47852	morss	morss	morss	22_S	SgN	et	morss =morss  (SgN  >morss !22_S
47855	lastepraad	praad	laste+praad	22_S	SgN	et	lastepraad =praad  (SgN  >laste+praad !22_S
47858	tillikastmega	kastme	tilli+kaste	05_S	SgKom	et	tillikastmega =kastme  (SgKom  >tilli+kaste !05_S
47859	magustoit	toit	magus+toit	22_S	SgN	et	magustoit =toit  (SgN  >magus+toit !22_S
47861	keedisega	keedise	keedis	09_S	SgKom	et	keedisega =keedise  (SgKom  >keedis !09_S
47864	kondenspiimaga	piima	kondens+piim	22_S	SgKom	et	kondenspiimaga =piima  (SgKom  >kondens+piim !22_S
47869	fileega	filee	filee	26_S	SgKom	et	fileega =filee  (SgKom  >filee !26_S
47872	kana-peedi	peedi	kana-peet	22_S	SgG	et	kana-peedi =peedi  (SgG  >kana-peet !22_S
47876	fri-kartul	kartul	fri-kartul	02_S	SgN	et	fri-kartul =kartul  (SgN  >fri-kartul !02_S
47885	ostke	ost	ostma	34_V	ImpPrPl2	et	ostke =ost  (ImpPrPl2  >ostma !34_V
47886	käele	käe	käsi	15_S	SgAll	et	käele =käe  (SgAll  >käsi !15_S
47696	arenemas	arene	arenema	27_V	SupIn	et	arenemas =arene  (SupIn  >arenema !27_V
47699	sümbioosiga	sümbioosi	sümbioos	22_S	SgKom	et	sümbioosiga =sümbioosi  (SgKom  >sümbioos !22_S
47703	mõjude	mõju	mõju	17_S	PlG	et	mõjude =mõju  (PlG  >mõju !17_S
47708	pealinnaelanikel	elanike	pea+linna+elanik	25_S	PlAd	et	pealinnaelanikel =elanike  (PlAd  >pea+linna+elanik !25_S
47709	kahekordne	kordne	kahe+kordne	02_AS	SgN	et	kahekordne =kordne  (SgN  >kahe+kordne !02_AS
47710	sellina	selli	sell	22_S	SgEs	et	sellina =selli  (SgEs  >sell !22_S
47716	laulutraditsiooniks	traditsiooni	laulu+traditsioon	22_S	SgTr	et	laulutraditsiooniks =traditsiooni  (SgTr  >laulu+traditsioon !22_S
47722	laulupeode	peo	laulu+peo	26_S	PlG	et	laulupeode =peo  (PlG  >laulu+peo !26_S
47736	iseseisvale	seisva	ise+seisev	02_A	SgAll	et	iseseisvale =seisva  (SgAll  >ise+seisev !02_A
47737	vanasid	vana	vana	17_AS	PlP	et	vanasid =vana  (PlP  >vana !17_AS
47739	rutiinis	rutiini	rutiin	22_S	SgIn	et	rutiinis =rutiini  (SgIn  >rutiin !22_S
47746	niisugustele	sugus	nii+sugune	10_P	PlAll	et	niisugustele =sugus  (PlAll  >nii+sugune !10_P
47753	valust	valu	valu	17_S	SgEl	et	valust =valu  (SgEl  >valu !17_S
47756	väljendama	väljenda	väljendama	27_V	Sup	et	väljendama =väljenda  (Sup  >väljendama !27_V
47759	skandinaaviass	ass	skandinaavi+ass	22_S	SgN	et	skandinaaviass =ass  (SgN  >skandinaavi+ass !22_S
47762	kujutan	kujuta	kujutama	27_V	IndPrSg1	et	kujutan =kujuta  (IndPrSg1  >kujutama !27_V
47768	kuulate	kuula	kuulama	29_V	IndPrPl2	et	kuulate =kuula  (IndPrPl2  >kuulama !29_V
47773	ühiskonnades	konna	ühis+konn	22_S	PlIn	et	ühiskonnades =konna  (PlIn  >ühis+konn !22_S
47784	rippus	rippu	rippuma	28_V	IndIpfSg3	et	rippus =rippu  (IndIpfSg3  >rippuma !28_V
47793	ärid	äri	äri	17_S	PlN	et	ärid =äri  (PlN  >äri !17_S
47803	turist	turist	turist	22_S	SgN	et	turist =turist  (SgN  >turist !22_S
47807	tehtuma	teh	tegema	28_V	TUM1_cA	et	"tehtum %teh  )TUM1_cA  <tegema ;28_V
47814	heliseb	helise	helisema	27_V	IndPrSg3	et	heliseb =helise  (IndPrSg3  >helisema !27_V
47828	mannavaht	vaht	manna+vaht	22_S	SgN	et	mannavaht =vaht  (SgN  >manna+vaht !22_S
47829	joogit	joogi	joogi	16_S	SgP	et	joogit =joogi  (SgP  >joogi !16_S
47830	apelsinimahl	mahl	apelsini+mahl	22_S	SgN	et	apelsinimahl =mahl  (SgN  >apelsini+mahl !22_S
47835	vahukoorega	koore	vahu+koor	13_S	SgKom	et	vahukoorega =koore  (SgKom  >vahu+koor !13_S
47836	kook	kook	kook	22_S	SgN	et	kook =kook  (SgN  >kook !22_S
47849	vormiroog	roog	vormi+roog	22_S	SgN	et	vormiroog =roog  (SgN  >vormi+roog !22_S
47854	liköör	liköör	liköör	22_S	SgN	et	liköör =liköör  (SgN  >liköör !22_S
47862	kohupiimamarjakastmega	kastme	kohu+piima+marja+kaste	05_S	SgKom	et	kohupiimamarjakastmega =kastme  (SgKom  >kohu+piima+marja+kaste !05_S
47868	majoneesiga	majoneesi	majonees	22_S	SgKom	et	majoneesiga =majoneesi  (SgKom  >majonees !22_S
47883	ebamugavustunnet	tunne	eba+mugavus+tunne	06_S	SgP	et	ebamugavustunnet =tunne  (SgP  >eba+mugavus+tunne !06_S
47889	näidiseid	näidise	näidis	09_S	PlP	et	näidiseid =näidise  (PlP  >näidis !09_S
47912	kringlit	kringli	kringel	02_S	SgP	et	kringlit =kringli  (SgP  >kringel !02_S
47915	moodsa	moodsa	moodne	02_A	SgG	et	moodsa =moodsa  (SgG  >moodne !02_A
47916	keeglisaalis	saali	keegli+saal	22_S	SgIn	et	keeglisaalis =saali  (SgIn  >keegli+saal !22_S
47917	tordiga	tordi	tort	22_S	SgKom	et	tordiga =tordi  (SgKom  >tort !22_S
47926	ettevõtetes	võte	ette+võte	06_S	PlIn	et	ettevõtetes =võte  (PlIn  >ette+võte !06_S
47927	täiendõpetamisesse	õpetamise	täiend+õpetamine	12_S	SgIll	et	täiendõpetamisesse =õpetamise  (SgIll  >täiend+õpetamine !12_S
47929	tarifikatsioon	tarifikatsioon	tarifikatsioon	22_S	SgN	et	tarifikatsioon =tarifikatsioon  (SgN  >tarifikatsioon !22_S
47930	õppekavade	kava	õppe+kava	17_S	PlG	et	õppekavade =kava  (PlG  >õppe+kava !17_S
47934	kontrollin	kontrolli	kontrollima	28_V	IndPrSg1	et	kontrollin =kontrolli  (IndPrSg1  >kontrollima !28_V
47938	õppetöökojas	koja	õppe+töö+koda	18_S	SgIn	et	õppetöökojas =koja  (SgIn  >õppe+töö+koda !18_S
47949	tumedad	tumeda	tume	02_A	PlN	et	tumedad =tumeda  (PlN  >tume !02_A
47950	reibas	reibas	reibas	07_A	SgN	et	reibas =reibas  (SgN  >reibas !07_A
47959	kokas	koka	kokk	22_S	SgIn	et	kokas =koka  (SgIn  >kokk !22_S
47963	kududa	kudu	kuduma	28_V	Inf	et	kududa =kudu  (Inf  >kuduma !28_V
47967	laisklen	laiskle	laisklema	30_V	IndPrSg1	et	laisklen =laiskle  (IndPrSg1  >laisklema !30_V
47969	orienteeruma	orienteeru	orienteeruma	27_V	Sup	et	orienteeruma =orienteeru  (Sup  >orienteeruma !27_V
47972	kvaliteedil	kvaliteedi	kvaliteet	22_S	SgAd	et	kvaliteedil =kvaliteedi  (SgAd  >kvaliteet !22_S
47978	siski	si	si	26_S	SgIn^	et	siski =si  (SgIn^  >si !26_S
47980	kohin	kohin	kohin	02_S	SgN	et	kohin =kohin  (SgN  >kohin !02_S
47982	teatis	teatis	teatis	11~09_S	SgN	et	teatis =teatis  (SgN  >teatis !11~09_S
47740	ajaviide	viide	aja+viide	06_S	SgN	et	ajaviide =viide  (SgN  >aja+viide !06_S
47745	eeskujudel	kuju	ees+kuju	17_S	PlAd	et	eeskujudel =kuju  (PlAd  >ees+kuju !17_S
47747	kontserdisaalis	saali	kontserdi+saal	22_S	SgIn	et	kontserdisaalis =saali  (SgIn  >kontserdi+saal !22_S
47748	pealtvaatajaid	vaataja	pealt+vaataja	01_S	PlP	et	pealtvaatajaid =vaataja  (PlP  >pealt+vaataja !01_S
47749	sündmusega	sündmuse	sündmus	11~09_S	SgKom	et	sündmusega =sündmuse  (SgKom  >sündmus !11~09_S
47750	väljendati	väljenda	väljendama	27_V	IndIpfIps	et	väljendati =väljenda  (IndIpfIps  >väljendama !27_V
47763	iseloomujoon	joon	ise+loomu+joon	13_S	SgN	et	iseloomujoon =joon  (SgN  >ise+loomu+joon !13_S
47764	kogudus	kogudus	kogudus	11_S	SgN	et	kogudus =kogudus  (SgN  >kogudus !11_S
47765	kuultuur	tuur	kuul+tuur	22_S	SgN	et	kuultuur =tuur  (SgN  >kuul+tuur !22_S
47766	mõistetakse	mõiste	mõistma	34_V	IndPrIps	et	mõistetakse =mõiste  (IndPrIps  >mõistma !34_V
47776	suveniir	suveniir	suveniir	22_S	SgN	et	suveniir =suveniir  (SgN  >suveniir !22_S
47777	märgil	märgi	märk	22_S	SgAd	et	märgil =märgi  (SgAd  >märk !22_S
47788	helinad	helina	helin	02_S	PlN	et	helinad =helina  (PlN  >helin !02_S
47790	vajutan	vajuta	vajutama	27_V	IndPrSg1	et	vajutan =vajuta  (IndPrSg1  >vajutama !27_V
47796	telefoninumbrid	numbri	telefoni+number	02_S	PlN	et	telefoninumbrid =numbri  (PlN  >telefoni+number !02_S
47798	kaktus	kaktus	kaktus	11~09_S	SgN	et	kaktus =kaktus  (SgN  >kaktus !11~09_S
47804	sõlm	sõlm	sõlm	22_S	SgN	et	sõlm =sõlm  (SgN  >sõlm !22_S
47805	hankima	hanki	hankima	28_V	Sup	et	hankima =hanki  (Sup  >hankima !28_V
47806	medalil	medali	medal	02_S	SgAd	et	medalil =medali  (SgAd  >medal !02_S
47812	äratama	ärata	äratama	27_V	Sup	et	äratama =ärata  (Sup  >äratama !27_V
47819	kaladele	kala	kala	17_S	PlAll	et	kaladele =kala  (PlAll  >kala !17_S
47820	kaladesse	kala	kala	17_S	PlIll	et	kaladesse =kala  (PlIll  >kala !17_S
47822	ennest	ennest	ennest	41_D	ID	et	ennest =ennest  (ID  >ennest !41_D
47823	kartulisalat	salat	kartuli+salat	02_S	SgN	et	kartulisalat =salat  (SgN  >kartuli+salat !02_S
47825	porgandisalat	salat	porgandi+salat	02_S	SgN	et	porgandisalat =salat  (SgN  >porgandi+salat !02_S
47826	kotletid	kotleti	kotlet	22_S	PlN	et	kotletid =kotleti  (PlN  >kotlet !22_S
47838	krevetisalat	salat	kreveti+salat	02_S	SgN	et	krevetisalat =salat  (SgN  >kreveti+salat !02_S
47843	majavein	vein	maja+vein	22_S	SgN	et	majavein =vein  (SgN  >maja+vein !22_S
47847	hakklihapallid	palli	hakk+liha+pall	22_S	PlN	et	hakklihapallid =palli  (PlN  >hakk+liha+pall !22_S
47853	kissell	kissell	kissell	22_S	SgN	et	kissell =kissell  (SgN  >kissell !22_S
47860	linnapiim	piim	linna+piim	22_S	SgN	et	linnapiim =piim  (SgN  >linna+piim !22_S
47867	ahjukartul	kartul	ahju+kartul	02_S	SgN	et	ahjukartul =kartul  (SgN  >ahju+kartul !02_S
47878	optimaalsest	optimaalse	optimaalne	02_A	SgEl	et	optimaalsest =optimaalse  (SgEl  >optimaalne !02_A
47881	seljatoe	toe	selja+tugi	21_S	SgG	et	seljatoe =toe  (SgG  >selja+tugi !21_S
47884	paigutage	paiguta	paigutama	27_V	ImpPrPl2	et	paigutage =paiguta  (ImpPrPl2  >paigutama !27_V
47890	läbivaatamist	vaatamis	läbi+vaatamine	12_S	SgP	et	läbivaatamist =vaatamis  (SgP  >läbi+vaatamine !12_S
47897	klassiõhtuid	õhtu	klassi+õhtu	01_S	PlP	et	klassiõhtuid =õhtu  (PlP  >klassi+õhtu !01_S
47899	kookide	kooki	kook	22_S	PlG	et	kookide =kooki  (PlG  >kook !22_S
47900	tortidega	torti	tort	22_S	PlKom	et	tortidega =torti  (PlKom  >tort !22_S
47901	küpsistega	küpsis	küpsis	09_S	PlKom	et	küpsistega =küpsis  (PlKom  >küpsis !09_S
47902	kooliklassist	klassi	kooli+klass	22_S	SgEl	et	kooliklassist =klassi  (SgEl  >kooli+klass !22_S
47913	kompvekid	kompveki	kompvek	22_S	PlN	et	kompvekid =kompveki  (PlN  >kompvek !22_S
47923	erialaainete	aine	eri+ala+aine	06_S	PlG	et	erialaainete =aine  (PlG  >eri+ala+aine !06_S
47928	õppetöökorraldamine	korraldamine	õppe+töö+korraldamine	12_S	SgN	et	õppetöökorraldamine =korraldamine  (SgN  >õppe+töö+korraldamine !12_S
47936	käskkiri	kiri	käsk+kiri	24_S	SgN	et	käskkiri =kiri  (SgN  >käsk+kiri !24_S
47941	meeldisime	meeldi	meeldima	27_V	IndIpfPl1	et	meeldisime =meeldi  (IndIpfPl1  >meeldima !27_V
47944	tü-s	tü	tü	xx_Q	SgIn	et	tü-s =tü  (SgIn  >tü !xx_Q
47946	mäetaguse	taguse	mäe+tagune	10_AS	SgG	et	mäetaguse =taguse  (SgG  >mäe+tagune !10_AS
47951	näidaks	näi	näima	37_V	KndPrIps	et	näidaks =näi  (KndPrIps  >näima !37_V
47952	kolleegil	kolleegi	kolleeg	22_S	SgAd	et	kolleegil =kolleegi  (SgAd  >kolleeg !22_S
47955	unistan	unista	unistama	27_V	IndPrSg1	et	unistan =unista  (IndPrSg1  >unistama !27_V
47956	kõnepraktikat	praktika	kõne+praktika	01_S	SgP	et	kõnepraktikat =praktika  (SgP  >kõne+praktika !01_S
47957	operaatori	operaatori	operaator	02_S	SgG	et	operaatori =operaatori  (SgG  >operaator !02_S
47961	meeldida	meeldi	meeldima	27_V	Inf	et	meeldida =meeldi  (Inf  >meeldima !27_V
47769	anekdoote	anekdoote	anekdoot	22_S	PlP	et	anekdoote =anekdoote  (PlP  >anekdoot !22_S
47774	iseseisevaks	seiseva	ise+seisev	02_A	SgTr	et	iseseisevaks =seiseva  (SgTr  >ise+seisev !02_A
47775	rahvatoit	toit	rahva+toit	22_S	SgN	et	rahvatoit =toit  (SgN  >rahva+toit !22_S
47778	millisel	millise	milline	10_P	SgAd	et	millisel =millise  (SgAd  >milline !10_P
47779	riigilipp	lipp	riigi+lipp	22_S	SgN	et	riigilipp =lipp  (SgN  >riigi+lipp !22_S
47785	kodusedele	ede	kodus+ede	16_S	SgAll	et	kodusedele =ede  (SgAll  >kodus+ede !16_S
47787	salvestan	salvesta	salvestama	27_V	IndPrSg1	et	salvestan =salvesta  (IndPrSg1  >salvestama !27_V
47789	logod	logo	logo	17~16_S	PlN	et	logod =logo  (PlN  >logo !17~16_S
47800	arvasa	asa	arv+ask	22_S	SgG	et	arvasa =asa  (SgG  >arv+ask !22_S
47801	välimuselt	välimuse	välimus	11_S	SgAbl	et	välimuselt =välimuse  (SgAbl  >välimus !11_S
47802	hõbelusika	lusika	hõbe+lusikas	02_S	SgG	et	hõbelusika =lusika  (SgG  >hõbe+lusikas !02_S
47810	südamele	südame	süda	04_S	SgAll	et	südamele =südame  (SgAll  >süda !04_S
47816	mahlasse	mahla	mahl	22_S	SgIll	et	mahlasse =mahla  (SgIll  >mahl !22_S
47818	veekogudesse	kogu	vee+kogu	17_S	PlIll	et	veekogudesse =kogu  (PlIll  >vee+kogu !17_S
47824	kapsarullid	rulli	kapsa+rull	22_S	PlN	et	kapsarullid =rulli  (PlN  >kapsa+rull !22_S
47839	aedviljasalat	salat	aed+vilja+salat	02_S	SgN	et	aedviljasalat =salat  (SgN  >aed+vilja+salat !02_S
47840	spinat	spinat	spinat	02_S	SgN	et	spinat =spinat  (SgN  >spinat !02_S
47851	rulaad	rulaad	rulaad	22_S	SgN	et	rulaad =rulaad  (SgN  >rulaad !22_S
47856	friikartul	kartul	frii+kartul	02_S	SgN	et	friikartul =kartul  (SgN  >frii+kartul !02_S
47865	apelsinikastmega	kastme	apelsini+kaste	05_S	SgKom	et	apelsinikastmega =kastme  (SgKom  >apelsini+kaste !05_S
47871	meresalat	salat	mere+salat	02_S	SgN	et	meresalat =salat  (SgN  >mere+salat !02_S
47873	ahjuõunad	õuna	ahju+õun	23?22_S	PlN	et	ahjuõunad =õuna  (PlN  >ahju+õun !23?22_S
47877	mugavast	mugava	mugav	02_A	SgEl	et	mugavast =mugava  (SgEl  >mugav !02_A
47879	mahtuma	mahtu	mahtuma	28_V	Sup	et	mahtuma =mahtu  (Sup  >mahtuma !28_V
47880	töötool	tool	töö+tool	22_S	SgN	et	töötool =tool  (SgN  >töö+tool !22_S
47882	käetoed	toe	käe+tugi	21_S	PlN	et	käetoed =toe  (PlN  >käe+tugi !21_S
47887	kataloogikaubandused	kaubanduse	kataloogi+kaubandus	11_S	PlN	et	kataloogikaubandused =kaubanduse  (PlN  >kataloogi+kaubandus !11_S
47891	kvaliteedile	kvaliteedi	kvaliteet	22_S	SgAll	et	kvaliteedile =kvaliteedi  (SgAll  >kvaliteet !22_S
47892	tähtajad	aja	täht+aeg	22_S	PlN	et	tähtajad =aja  (PlN  >täht+aeg !22_S
47893	kaupadega	kaupa	kaup	22_S	PlKom	et	kaupadega =kaupa  (PlKom  >kaup !22_S
47904	t-särg	särg	t-särg	22_S	SgN	et	t-särg =särg  (SgN  >t-särg !22_S
47906	seelik	seelik	seelik	02_S	SgN	et	seelik =seelik  (SgN  >seelik !02_S
47910	küpsetasime	küpseta	küpsetama	27_V	IndIpfPl1	et	küpsetasime =küpseta  (IndIpfPl1  >küpsetama !27_V
47918	meenutasime	meenuta	meenutama	27_V	IndIpfPl1	et	meenutasime =meenuta  (IndIpfPl1  >meenutama !27_V
47921	pidurõivad	rõiva	pidu+rõivas	07_S	PlN	et	pidurõivad =rõiva  (PlN  >pidu+rõivas !07_S
47925	polütehniline	polütehniline	polütehniline	12_A	SgN	et	polütehniline =polütehniline  (SgN  >polütehniline !12_A
47937	juhin	juhi	juhtima	28_V	IndPrSg1	et	juhin =juhi  (IndPrSg1  >juhtima !28_V
47942	andsime	and	andma	34_V	IndIpfPl1	et	andsime =and  (IndIpfPl1  >andma !34_V
47954	ülesmäge	ülesmäge	üles+mäge	41_D	ID	et	ülesmäge =ülesmäge  (ID  >üles+mäge !41_D
47960	kelneriks	kelneri	kelner	02_S	SgTr	et	kelneriks =kelneri  (SgTr  >kelner !02_S
47971	arstiabist	abi	arsti+abi	17_S	SgEl	et	arstiabist =abi  (SgEl  >arsti+abi !17_S
47973	meditsini	itsi	med+its	22_S	SgTer	et	meditsini =itsi  (SgTer  >med+its !22_S
47979	kalapüügile	püügi	kala+püük	22_S	SgAll	et	kalapüügile =püügi  (SgAll  >kala+püük !22_S
47983	pretensioon	pretensioon	pretensioon	22_S	SgN	et	pretensioon =pretensioon  (SgN  >pretensioon !22_S
47986	õppimiskursustele	kursus	õppimis+kursus	11~09_S	PlAll	et	õppimiskursustele =kursus  (PlAll  >õppimis+kursus !11~09_S
47996	labrador	labrador	labrador	19_S	SgN	et	labrador =labrador  (SgN  >labrador !19_S
48014	tegelesime	tegele	tegelema	31~27_V	IndIpfPl1	et	tegelesime =tegele  (IndIpfPl1  >tegelema !31~27_V
48018	arutasime	aruta	arutama	27_V	IndIpfPl1	et	arutasime =aruta  (IndIpfPl1  >arutama !27_V
48020	suhtlesime	suhtle	suhtlema	30_V	IndIpfPl1	et	suhtlesime =suhtle  (IndIpfPl1  >suhtlema !30_V
48021	jutustasime	jutusta	jutustama	27_V	IndIpfPl1	et	jutustasime =jutusta  (IndIpfPl1  >jutustama !27_V
48029	eesmärkeni	märke	ees+märge	06_S	SgTer	et	eesmärkeni =märke  (SgTer  >ees+märge !06_S
48035	koosoleku	oleku	koos+olek	02_S	SgG	et	koosoleku =oleku  (SgG  >koos+olek !02_S
48046	seksuaalsest	seksuaalse	seksuaalne	02_A	SgEl	et	seksuaalsest =seksuaalse  (SgEl  >seksuaalne !02_A
47770	huvitamaks	huvita	huvitama	27_V	SupTr	et	huvitamaks =huvita  (SupTr  >huvitama !27_V
47771	assotsiatsioon	assotsiatsioon	assotsiatsioon	22_S	SgN	et	assotsiatsioon =assotsiatsioon  (SgN  >assotsiatsioon !22_S
47772	rahvuseepos	eepos	rahvus+eepos	11~09_S	SgN	et	rahvuseepos =eepos  (SgN  >rahvus+eepos !11~09_S
47786	toimetasin	toimeta	toimetama	27_V	IndIpfSg1	et	toimetasin =toimeta  (IndIpfSg1  >toimetama !27_V
47791	tärn	tärn	tärn	22_S	SgN	et	tärn =tärn  (SgN  >tärn !22_S
47794	sugulasedega	ede	sugulas+ede	16_S	SgKom	et	sugulasedega =ede  (SgKom  >sugulas+ede !16_S
47795	pleier	pleier	pleier	02_S	SgN	et	pleier =pleier  (SgN  >pleier !02_S
47808	küünlajalg	jalg	küünla+jalg	22_S	SgN	et	küünlajalg =jalg  (SgN  >küünla+jalg !22_S
47811	hüljes	hüljes	hüljes	07_S	SgN	et	hüljes =hüljes  (SgN  >hüljes !07_S
47815	põhjani	põhja	põhi	24_S	SgTer	et	põhjani =põhja  (SgTer  >põhi !24_S
47827	kanasupp	supp	kana+supp	22_S	SgN	et	kanasupp =supp  (SgN  >kana+supp !22_S
47831	vitamiinisalat	salat	vitamiini+salat	02_S	SgN	et	vitamiinisalat =salat  (SgN  >vitamiini+salat !02_S
47832	kilpkonnasupp	supp	kilp+konna+supp	22_S	SgN	et	kilpkonnasupp =supp  (SgN  >kilp+konna+supp !22_S
47833	seenesupp	supp	seene+supp	22_S	SgN	et	seenesupp =supp  (SgN  >seene+supp !22_S
47834	peedisupp	supp	peedi+supp	22_S	SgN	et	peedisupp =supp  (SgN  >peedi+supp !22_S
47837	kalasupp	supp	kala+supp	22_S	SgN	et	kalasupp =supp  (SgN  >kala+supp !22_S
47841	jäätisega	jäätise	jäätis	11~09_S	SgKom	et	jäätisega =jäätise  (SgKom  >jäätis !11~09_S
47845	külmsupp	supp	külm+supp	22_S	SgN	et	külmsupp =supp  (SgN  >külm+supp !22_S
47848	marmelaad	marmelaad	marmelaad	22_S	SgN	et	marmelaad =marmelaad  (SgN  >marmelaad !22_S
47850	vahvlid	vahvli	vahvel	02_S	PlN	et	vahvlid =vahvli  (PlN  >vahvel !02_S
47857	tomatikastmega	kastme	tomati+kaste	05_S	SgKom	et	tomatikastmega =kastme  (SgKom  >tomati+kaste !05_S
47863	puuviljade	vilja	puu+vili	24_S	PlG	et	puuviljade =vilja  (PlG  >puu+vili !24_S
47866	puuviljaga	vilja	puu+vili	24_S	SgKom	et	puuviljaga =vilja  (SgKom  >puu+vili !24_S
47870	kohupiimaga	piima	kohu+piim	22_S	SgKom	et	kohupiimaga =piima  (SgKom  >kohu+piim !22_S
47874	kirss	kirss	kirss	22_S	SgN	et	kirss =kirss  (SgN  >kirss !22_S
47875	pähklid	pähkli	pähkel	02_S	PlN	et	pähklid =pähkli  (PlN  >pähkel !02_S
47888	kataloogide	kataloogi	kataloog	22_S	PlG	et	kataloogide =kataloogi  (PlG  >kataloog !22_S
47895	kaubavalik	valik	kauba+valik	02_S	SgN	et	kaubavalik =valik  (SgN  >kauba+valik !02_S
47896	saatuslik	saatuslik	saatuslik	25_A	SgN	et	saatuslik =saatuslik  (SgN  >saatuslik !25_A
47898	klassiõhtul	õhtu	klassi+õhtu	01_S	SgAd	et	klassiõhtul =õhtu  (SgAd  >klassi+õhtu !01_S
47905	bluus	bluus	bluus	22_S	SgN	et	bluus =bluus  (SgN  >bluus !22_S
47908	magusaid	magusa	magus	02_A	PlP	et	magusaid =magusa  (PlP  >magus !02_A
47909	küpsiseid	küpsise	küpsis	09_S	PlP	et	küpsiseid =küpsise  (PlP  >küpsis !09_S
47922	pühapäevaülikond	ülikond	püha+päeva+ülikond	22_S	SgN	et	pühapäevaülikond =ülikond  (SgN  >püha+päeva+ülikond !22_S
47933	elektronpost	post	elektron+post	22_S	SgN	et	elektronpost =post  (SgN  >elektron+post !22_S
47935	õppekavades	kava	õppe+kava	17_S	PlIn	et	õppekavades =kava  (PlIn  >õppe+kava !17_S
47940	koolibaarisse	baari	kooli+baar	22_S	SgIll	et	koolibaarisse =baari  (SgIll  >kooli+baar !22_S
47945	purus	puru	puru	17_S	SgIn	et	purus =puru  (SgIn  >puru !17_S
47948	keskmis	mi	kesk+mi	26_S	SgIn	et	keskmis =mi  (SgIn  >kesk+mi !26_S
47953	õnnitlen	õnnitle	õnnitlema	27_V	IndPrSg1	et	õnnitlen =õnnitle  (IndPrSg1  >õnnitlema !27_V
47965	sale	sale	sale	02_A	SgN	et	sale =sale  (SgN  >sale !02_A
47966	lesin	lesi	lesima	27_V	IndPrSg1	et	lesin =lesi  (IndPrSg1  >lesima !27_V
47970	navigatsioonitarkvaraga	vara	navigatsiooni+tark+vara	17_S	SgKom	et	navigatsioonitarkvaraga =vara  (SgKom  >navigatsiooni+tark+vara !17_S
47975	paljuteid	te	palju+tee	26_S	PlP	et	paljuteid =te  (PlP  >palju+tee !26_S
47976	ravimitel	ravimi	ravim	02_S	PlAd	et	ravimitel =ravimi  (PlAd  >ravim !02_S
47977	kõrvaltoimeid	toime	kõrval+toime	06_S	PlP	et	kõrvaltoimeid =toime  (PlP  >kõrval+toime !06_S
47981	maksin	maks	maksma	32_V	IndIpfSg1	et	maksin =maks  (IndIpfSg1  >maksma !32_V
47985	elukordades	korda	elu+kord	22_S	PlIn	et	elukordades =korda  (PlIn  >elu+kord !22_S
47988	kuupäeval	päeva	kuu+päev	22_S	SgAd	et	kuupäeval =päeva  (SgAd  >kuu+päev !22_S
47989	võeta	võe	võtma	35_V	IndPrIps_	et	võeta =võe  (IndPrIps_  >võtma !35_V
47999	reks	re	re	26_S	SgTr	et	reks =re  (SgTr  >re !26_S
48000	firmasse	firma	firma	16_S	SgIll	et	firmasse =firma  (SgIll  >firma !16_S
48003	reaktiividega	reaktiivi	reaktiiv	22_S	PlKom	et	reaktiividega =reaktiivi  (PlKom  >reaktiiv !22_S
48008	kohvimasina	masina	kohvi+masin	02_S	SgG	et	kohvimasina =masina  (SgG  >kohvi+masin !02_S
47894	lisapakkumise	pakkumise	lisa+pakkumine	12_S	SgG	et	lisapakkumise =pakkumise  (SgG  >lisa+pakkumine !12_S
47903	küpsid	küpsi	küps	02_A	PlN	et	küpsid =küpsi  (PlN  >küps !02_A
47907	klassiõhtud	õhtu	klassi+õhtu	01_S	PlN	et	klassiõhtud =õhtu  (PlN  >klassi+õhtu !01_S
47911	ülikondid	kondi	üli+kont	22_S	PlN	et	ülikondid =kondi  (PlN  >üli+kont !22_S
47914	viigipüksid	püksi	viigi+püks	23?22_S	PlN	et	viigipüksid =püksi  (PlN  >viigi+püks !23?22_S
47919	küpsitega	küpsi	küps	02_A	PlKom	et	küpsitega =küpsi  (PlKom  >küps !02_A
47920	klassirummis	rummi	klassi+rumm	22_S	SgIn	et	klassirummis =rummi  (SgIn  >klassi+rumm !22_S
47924	arvutiõpetuse	õpetuse	arvuti+õpetus	11_S	SgG	et	arvutiõpetuse =õpetuse  (SgG  >arvuti+õpetus !11_S
47931	metoodiline	metoodiline	metoodiline	12_A	SgN	et	metoodiline =metoodiline  (SgN  >metoodiline !12_A
47932	lülitan	lülita	lülitama	27_V	IndPrSg1	et	lülitan =lülita  (IndPrSg1  >lülitama !27_V
47939	printeriga	printeri	printer	02_S	SgKom	et	printeriga =printeri  (SgKom  >printer !02_S
47943	ametile	ameti	amet	02_S	SgAll	et	ametile =ameti  (SgAll  >amet !02_S
47947	kutsehariduskeskus	keskus	kutse+haridus+keskus	11~09_S	SgN	et	kutsehariduskeskus =keskus  (SgN  >kutse+haridus+keskus !11~09_S
47958	pagar-kondiiter	kondiiter	pagar-kondiiter	02_S	SgN	et	pagar-kondiiter =kondiiter  (SgN  >pagar-kondiiter !02_S
47962	lemmikõppeained	aine	lemmik+õppe+aine	06_S	PlN	et	lemmikõppeained =aine  (PlN  >lemmik+õppe+aine !06_S
47974	seadmestikud	seadmestiku	seadmestik	25_S	PlN	et	seadmestikud =seadmestiku  (PlN  >seadmestik !25_S
47984	direktoriga	direktori	direktor	02_S	SgKom	et	direktoriga =direktori  (SgKom  >direktor !02_S
47993	administratsiooniga	administratsiooni	administratsioon	22_S	SgKom	et	administratsiooniga =administratsiooni  (SgKom  >administratsioon !22_S
47995	kontaktandmed	andme	kontakt+anne	05_S	PlN	et	kontaktandmed =andme  (PlN  >kontakt+anne !05_S
47997	eritingimused	tingimuse	eri+tingimus	11_S	PlN	et	eritingimused =tingimuse  (PlN  >eri+tingimus !11_S
48004	logistikat	logistika	logistika	01_S	SgP	et	logistikat =logistika  (SgP  >logistika !01_S
48012	lahendasin	lahenda	lahendama	27_V	IndIpfSg1	et	lahendasin =lahenda  (IndIpfSg1  >lahendama !27_V
48013	klassikastlastega	las	klassi+kast+laps	14_S	PlKom	et	klassikastlastega =las  (PlKom  >klassi+kast+laps !14_S
48017	lahendasime	lahenda	lahendama	27_V	IndIpfPl1	et	lahendasime =lahenda  (IndIpfPl1  >lahendama !27_V
48019	teooriat	teooria	teooria	01_S	SgP	et	teooriat =teooria  (SgP  >teooria !01_S
48026	mobiiltelefonilt	telefoni	mobiil+telefon	19_S	SgAbl	et	mobiiltelefonilt =telefoni  (SgAbl  >mobiil+telefon !19_S
48028	postkaarteid	te	post+kaar+tee	26_S	PlP	et	postkaarteid =te  (PlP  >post+kaar+tee !26_S
48033	iseteenindust	teenindus	ise+teenindus	11_S	SgP	et	iseteenindust =teenindus  (SgP  >ise+teenindus !11_S
48039	ministrinaiseks	naise	ministri+naine	12_S	SgTr	et	ministrinaiseks =naise  (SgTr  >ministri+naine !12_S
48048	sugulasete	e	sugulas+esi	15_S	PlG	et	sugulasete =e  (PlG  >sugulas+esi !15_S
48056	piljard	piljard	piljard	02_S	SgN	et	piljard =piljard  (SgN  >piljard !02_S
48060	sillad	silla	sild	22_S	PlN	et	sillad =silla  (PlN  >sild !22_S
48061	uuendati	uuenda	uuendama	27_V	IndIpfIps	et	uuendati =uuenda  (IndIpfIps  >uuendama !27_V
48062	ati	ati	att	22_S	SgG	et	ati =ati  (SgG  >att !22_S
48066	tujus	tuju	tuju	17_S	SgIn	et	tujus =tuju  (SgIn  >tuju !17_S
48069	kaldas	kalda	kallas	07_S	SgIn	et	kaldas =kalda  (SgIn  >kallas !07_S
48076	käe-	käe	käsi	15_S	SgG	et	käe- =käe  (SgG  >käsi !15_S
48083	ujumas	uju	ujuma	27_V	SupIn	et	ujumas =uju  (SupIn  >ujuma !27_V
48085	tööotsijale	otsija	töö+otsija	01_S	SgAll	et	tööotsijale =otsija  (SgAll  >töö+otsija !01_S
48089	sooviksite	soovi	soovima	28_V	KndPrPl2	et	sooviksite =soovi  (KndPrPl2  >soovima !28_V
48094	puldist	puldi	pult	22_S	SgEl	et	puldist =puldi  (SgEl  >pult !22_S
48098	pereprobleemidest	probleemi	pere+probleem	22_S	PlEl	et	pereprobleemidest =probleemi  (PlEl  >pere+probleem !22_S
48106	tellin	telli	tellima	28_V	IndPrSg1	et	tellin =telli  (IndPrSg1  >tellima !28_V
48118	passiivsete	passiivse	passiivne	02_A	PlG	et	passiivsete =passiivse  (PlG  >passiivne !02_A
48123	meditsiinisüsteem	süsteem	meditsiini+süsteem	22_S	SgN	et	meditsiinisüsteem =süsteem  (SgN  >meditsiini+süsteem !22_S
48125	särtsakad	särtsaka	särtsakas	02_A	PlN	et	särtsakad =särtsaka  (PlN  >särtsakas !02_A
48130	arenguvõimalusi	võimalusi	arengu+võimalus	11_S	PlP	et	arenguvõimalusi =võimalusi  (PlP  >arengu+võimalus !11_S
48142	arvamusega	arvamuse	arvamus	11_S	SgKom	et	arvamusega =arvamuse  (SgKom  >arvamus !11_S
48147	geniaalseid	geniaalse	geniaalne	02_A	PlP	et	geniaalseid =geniaalse  (PlP  >geniaalne !02_A
48148	mitmetähenduslik	tähenduslik	mitme+tähenduslik	25_A	SgN	et	mitmetähenduslik =tähenduslik  (SgN  >mitme+tähenduslik !25_A
48149	taval	tava	tava	17_S	SgAd	et	taval =tava  (SgAd  >tava !17_S
47964	kaastundlik	tundlik	kaas+tundlik	25_A	SgN	et	kaastundlik =tundlik  (SgN  >kaas+tundlik !25_A
47968	kaardistikuga	kaardistiku	kaardistik	25_S	SgKom	et	kaardistikuga =kaardistiku  (SgKom  >kaardistik !25_S
47987	keelekursused	kursuse	keele+kursus	11~09_S	PlN	et	keelekursused =kursuse  (PlN  >keele+kursus !11~09_S
47990	magnetofonid	magnetofoni	magnetofon	19_S	PlN	et	magnetofonid =magnetofoni  (PlN  >magnetofon !19_S
47992	kõrvaklapid	klapi	kõrva+klapp	22_S	PlN	et	kõrvaklapid =klapi  (PlN  >kõrva+klapp !22_S
47994	administratsioon	administratsioon	administratsioon	22_S	SgN	et	administratsioon =administratsioon  (SgN  >administratsioon !22_S
48006	kutsekoolide	kooli	kutse+kool	22_S	PlG	et	kutsekoolide =kooli  (PlG  >kutse+kool !22_S
48007	ujumisvõistluse	võistluse	ujumis+võistlus	11~09_S	SgG	et	ujumisvõistluse =võistluse  (SgG  >ujumis+võistlus !11~09_S
48011	tagastatakse	tagasta	tagastama	27_V	IndPrIps	et	tagastatakse =tagasta  (IndPrIps  >tagastama !27_V
48015	olümpiaadile	olümpiaadi	olümpiaad	22_S	SgAll	et	olümpiaadile =olümpiaadi  (SgAll  >olümpiaad !22_S
48022	soengus	soengu	soeng	02_S	SgIn	et	soengus =soengu  (SgIn  >soeng !02_S
48034	koolitunni	tunni	kooli+tund	22_S	SgG	et	koolitunni =tunni  (SgG  >kooli+tund !22_S
48045	klaverist	klaveri	klaver	02_S	SgEl	et	klaverist =klaveri  (SgEl  >klaver !02_S
48049	kreml	kreml	kreml	02_S	SgN	et	kreml =kreml  (SgN  >kreml !02_S
48054	administraatorilt	administraatori	administraator	02_S	SgAbl	et	administraatorilt =administraatori  (SgAbl  >administraator !02_S
48063	tõlkeid	tõlke	tõlge	06_S	PlP	et	tõlkeid =tõlke  (PlP  >tõlge !06_S
48070	mõnusaid	mõnusa	mõnus	02_A	PlP	et	mõnusaid =mõnusa  (PlP  >mõnus !02_A
48087	cv-st	cv	cv	xx_Q	SgEl	et	cv-st =cv  (SgEl  >cv !xx_Q
48090	lõunavaheaeg	aeg	lõuna+vahe+aeg	22_S	SgN	et	lõunavaheaeg =aeg  (SgN  >lõuna+vahe+aeg !22_S
48102	muudaksin	muuda	muutma	34_V	KndPrSg1	et	muudaksin =muuda  (KndPrSg1  >muutma !34_V
48108	abiturient	abiturient	abiturient	22_S	SgN	et	abiturient =abiturient  (SgN  >abiturient !22_S
48109	vähenõudlike	nõudlike	vähe+nõudlik	25_A	PlG	et	vähenõudlike =nõudlike  (PlG  >vähe+nõudlik !25_A
48110	värskust	värskus	värskus	11~09_S	SgP	et	värskust =värskus  (SgP  >värskus !11~09_S
48111	ministriks	ministri	minister	02_S	SgTr	et	ministriks =ministri  (SgTr  >minister !02_S
48112	mittetoimiva	toimiva	mitte+toimiv	02_A	SgG	et	mittetoimiva =toimiva  (SgG  >mitte+toimiv !02_A
48127	organisatsioonide	organisatsiooni	organisatsioon	22_S	PlG	et	organisatsioonide =organisatsiooni  (PlG  >organisatsioon !22_S
48128	julgeteks	julge	julge	01_A	PlTr	et	julgeteks =julge  (PlTr  >julge !01_A
48129	tarku	tarku	tark	22_AS	PlP	et	tarku =tarku  (PlP  >tark !22_AS
48132	meditsiinisüsteemiga	süsteemi	meditsiini+süsteem	22_S	SgKom	et	meditsiinisüsteemiga =süsteemi  (SgKom  >meditsiini+süsteem !22_S
48137	valite	vali	valima	27_V	IndPrPl2	et	valite =vali  (IndPrPl2  >valima !27_V
48143	ametist	ameti	amet	02_S	SgEl	et	ametist =ameti  (SgEl  >amet !02_S
48152	emotsioonidega	emotsiooni	emotsioon	22_S	PlKom	et	emotsioonidega =emotsiooni  (PlKom  >emotsioon !22_S
48157	huulepulga	pulga	huule+pulk	22_S	SgG	et	huulepulga =pulga  (SgG  >huule+pulk !22_S
48163	võrdlemas	võrdle	võrdlema	30_V	SupIn	et	võrdlemas =võrdle  (SupIn  >võrdlema !30_V
48171	gümnaasiumite	gümnaasiumi	gümnaasium	02_S	PlG	et	gümnaasiumite =gümnaasiumi  (PlG  >gümnaasium !02_S
48173	streigilaines	laine	streigi+laine	06_S	SgIn	et	streigilaines =laine  (SgIn  >streigi+laine !06_S
48176	10-tunniks	tunni	-tund	22_S	SgTr	et	-tunniks =tunni  (SgTr  >-tund !22_S
48179	massiküüditamine	küüditamine	massi+küüditamine	12_S	SgN	et	massiküüditamine =küüditamine  (SgN  >massi+küüditamine !12_S
48185	toitudest	toitu	toit	22_S	PlEl	et	toitudest =toitu  (PlEl  >toit !22_S
48200	sõltudes	sõltu	sõltuma	27_V	Ger	et	sõltudes =sõltu  (Ger  >sõltuma !27_V
48202	ühendis	ühendi	ühend	02_S	SgIn	et	ühendis =ühendi  (SgIn  >ühend !02_S
48208	täisväärtusliku	väärtusliku	täis+väärtuslik	25_A	SgG	et	täisväärtusliku =väärtusliku  (SgG  >täis+väärtuslik !25_A
48217	väitele	väite	väide	06_S	SgAll	et	väitele =väite  (SgAll  >väide !06_S
48219	töökollektiiv	kollektiiv	töö+kollektiiv	22_S	SgN	et	töökollektiiv =kollektiiv  (SgN  >töö+kollektiiv !22_S
48224	õhkuta	õhku	õhkuma	27_V	IndPrIps_	et	õhkuta =õhku  (IndPrIps_  >õhkuma !27_V
48228	väljendis	väljendi	väljend	02_S	SgIn	et	väljendis =väljendi  (SgIn  >väljend !02_S
48232	jubedate	jubeda	jube	02_A	PlG	et	jubedate =jubeda  (PlG  >jube !02_A
48235	headel	hea	hea	26_AS	PlAd	et	headel =hea  (PlAd  >hea !26_AS
48252	juulini	juuli	juuli	16_S	SgTer	et	juulini =juuli  (SgTer  >juuli !16_S
48260	muuseimid	seimi	muu+seim	22_S	PlN	et	muuseimid =seimi  (PlN  >muu+seim !22_S
48264	ekskursiooniga	ekskursiooni	ekskursioon	22_S	SgKom	et	ekskursiooniga =ekskursiooni  (SgKom  >ekskursioon !22_S
47991	mikrofonid	mikrofoni	mikrofon	19_S	PlN	et	mikrofonid =mikrofoni  (PlN  >mikrofon !19_S
47998	käpaotsad	otsa	käpa+ots	23?22_S	PlN	et	käpaotsad =otsa  (PlN  >käpa+ots !23?22_S
48001	keemiku	keemiku	keemik	02_S	SgG	et	keemiku =keemiku  (SgG  >keemik !02_S
48002	as-s	as	as	xx_Q	SgIn	et	as-s =as  (SgIn  >as !xx_Q
48005	keskhariduse	hariduse	kesk+haridus	11_S	SgG	et	keskhariduse =hariduse  (SgG  >kesk+haridus !11_S
48009	tagastasin	tagasta	tagastama	27_V	IndIpfSg1	et	tagastasin =tagasta  (IndIpfSg1  >tagastama !27_V
48016	lisatunnid	tunni	lisa+tund	22_S	PlN	et	lisatunnid =tunni  (PlN  >lisa+tund !22_S
48024	mobiiltelefonile	telefoni	mobiil+telefon	19_S	SgAll	et	mobiiltelefonile =telefoni  (SgAll  >mobiil+telefon !19_S
48025	riputada	riputa	riputama	27_V	Inf	et	riputada =riputa  (Inf  >riputama !27_V
48027	e-postid	posti	e-post	22_S	PlN	et	e-postid =posti  (PlN  >e-post !22_S
48031	taskusse	tasku	tasku	01_S	SgIll	et	taskusse =tasku  (SgIll  >tasku !01_S
48040	kuninganaks	naks	kuninga+naks	22_S	SgN	et	kuninganaks =naks  (SgN  >kuninga+naks !22_S
48041	käsutada	käsuta	käsutama	27_V	Inf	et	käsutada =käsuta  (Inf  >käsutama !27_V
48044	lennukist	lennuki	lennuk	02_S	SgEl	et	lennukist =lennuki  (SgEl  >lennuk !02_S
48047	sekretärist	sekretäri	sekretär	19_S	SgEl	et	sekretärist =sekretäri  (SgEl  >sekretär !19_S
48055	keerasin	keera	keerama	29_V	IndIpfSg1	et	keerasin =keera  (IndIpfSg1  >keerama !29_V
48059	taksoga	takso	takso	16_S	SgKom	et	taksoga =takso  (SgKom  >takso !16_S
48067	impressioon	impressioon	impressioon	22_S	SgN	et	impressioon =impressioon  (SgN  >impressioon !22_S
48068	päikeseloojangut	loojangu	päikese+loojang	02_S	SgP	et	päikeseloojangut =loojangu  (SgP  >päikese+loojang !02_S
48091	meditsiiniarengust	arengu	meditsiini+areng	02_S	SgEl	et	meditsiiniarengust =arengu  (SgEl  >meditsiini+areng !02_S
48093	kuidagimoodi	kuidagimoodi	kuidagi+moodi	41_D	ID	et	kuidagimoodi =kuidagimoodi  (ID  >kuidagi+moodi !41_D
48095	väljanägemine	nägemine	välja+nägemine	12_S	SgN	et	väljanägemine =nägemine  (SgN  >välja+nägemine !12_S
48097	cv-ga	cv	cv	xx_Q	SgKom	et	cv-ga =cv  (SgKom  >cv !xx_Q
48099	prismasse	prisma	prisma	16_S	SgIll	et	prismasse =prisma  (SgIll  >prisma !16_S
48101	rõiva	rõiva	rõivas	07_S	SgG	et	rõiva =rõiva  (SgG  >rõivas !07_S
48104	tasandist	tasandi	tasand	02_S	SgEl	et	tasandist =tasandi  (SgEl  >tasand !02_S
48117	passiivseid	passiivse	passiivne	02_A	PlP	et	passiivseid =passiivse  (PlP  >passiivne !02_A
48126	ministrid	ministri	minister	02_S	PlN	et	ministrid =ministri  (PlN  >minister !02_S
48133	jaguda	jagu	jaguma	27_V	Inf	et	jaguda =jagu  (Inf  >jaguma !27_V
48136	arukat	aruka	arukas	02_A	SgP	et	arukat =aruka  (SgP  >arukas !02_A
48138	neljakümnesed	kümnese	nelja+kümnene	10~12_AS	PlN	et	neljakümnesed =kümnese  (PlN  >nelja+kümnene !10~12_AS
48140	liising	liising	liising	02_S	SgN	et	liising =liising  (SgN  >liising !02_S
48164	riietereklaamid	reklaami	riiete+reklaam	22_S	PlN	et	riietereklaamid =reklaami  (PlN  >riiete+reklaam !22_S
48166	insenerid	inseneri	insener	19_S	PlN	et	insenerid =inseneri  (PlN  >insener !19_S
48174	raudteelased	teelase	raud+teelane	12?10_S	PlN	et	raudteelased =teelase  (PlN  >raud+teelane !12?10_S
48178	elualades	ala	elu+ala	17_S	PlIn	et	elualades =ala  (PlIn  >elu+ala !17_S
48191	piduliku	piduliku	pidulik	25_A	SgG	et	piduliku =piduliku  (SgG  >pidulik !25_A
48197	sõnastikes	sõnastike	sõnastik	25_S	PlIn	et	sõnastikes =sõnastike  (PlIn  >sõnastik !25_S
48198	ööst	öö	öö	26_S	SgEl	et	ööst =öö  (SgEl  >öö !26_S
48199	ühildub	ühildu	ühilduma	27_V	IndPrSg3	et	ühildub =ühildu  (IndPrSg3  >ühilduma !27_V
48209	süvaõppega	õppe	süva+õpe	06_S	SgKom	et	süvaõppega =õppe  (SgKom  >süva+õpe !06_S
48215	tarve	tarve	tarve	06_S	SgN	et	tarve =tarve  (SgN  >tarve !06_S
48220	keeleoskuseta	oskuse	keele+oskus	11~09_S	SgAb	et	keeleoskuseta =oskuse  (SgAb  >keele+oskus !11~09_S
48222	korterita	korteri	korter	02_S	SgAb	et	korterita =korteri  (SgAb  >korter !02_S
48225	uudisteta	uudis	uudis	09_S	PlAb	et	uudisteta =uudis  (PlAb  >uudis !09_S
48231	terroristide	terroristi	terrorist	22_S	PlG	et	terroristide =terroristi  (PlG  >terrorist !22_S
48237	lähedasteta	lähedas	lähedane	12_AS	PlAb	et	lähedasteta =lähedas  (PlAb  >lähedane !12_AS
48244	õhkub	õhku	õhkuma	27_V	IndPrSg3	et	õhkub =õhku  (IndPrSg3  >õhkuma !27_V
48247	kalliks	kalli	kallis	05~07_A	SgTr	et	kalliks =kalli  (SgTr  >kallis !05~07_A
48249	augustiks	augusti	august	02_S	SgTr	et	augustiks =augusti  (SgTr  >august !02_S
48253	ööbima	ööbi	ööbima	27_V	Sup	et	ööbima =ööbi  (Sup  >ööbima !27_V
48263	võõrastemajas	maja	võõraste+maja	17_S	SgIn	et	võõrastemajas =maja  (SgIn  >võõraste+maja !17_S
48265	hotellid	hotelli	hotell	22_S	PlN	et	hotellid =hotelli  (PlN  >hotell !22_S
48267	saatan	saatan	saatan	02_S	SgN	et	saatan =saatan  (SgN  >saatan !02_S
48010	tootjafirmale	firma	tootja+firma	16_S	SgAll	et	tootjafirmale =firma  (SgAll  >tootja+firma !16_S
48023	seelikuid	seeliku	seelik	02_S	PlP	et	seelikuid =seeliku  (PlP  >seelik !02_S
48030	puhkereisis	reisi	puhke+reis	22_S	SgIn	et	puhkereisis =reisi  (SgIn  >puhke+reis !22_S
48032	sõnumeid	sõnume	sõnum	02_S	PlP	et	sõnumeid =sõnume  (PlP  >sõnum !02_S
48036	muudan	muuda	muutma	34_V	IndPrSg1	et	muudan =muuda  (IndPrSg1  >muutma !34_V
48037	peatun	peatu	peatuma	27_V	IndPrSg1	et	peatun =peatu  (IndPrSg1  >peatuma !27_V
48038	joodan	jooda	jootma	34_V	IndPrSg1	et	joodan =jooda  (IndPrSg1  >jootma !34_V
48042	papagoist	papagoi	papagoi	26_S	SgEl	et	papagoist =papagoi  (SgEl  >papagoi !26_S
48043	mänguasjadest	asja	mängu+asi	24_S	PlEl	et	mänguasjadest =asja  (PlEl  >mängu+asi !24_S
48052	keskküttega	kütte	kesk+küte	06_S	SgKom	et	keskküttega =kütte  (SgKom  >kesk+küte !06_S
48053	kämpingus	kämpingu	kämping	02_S	SgIn	et	kämpingus =kämpingu  (SgIn  >kämping !02_S
48064	printida	printi	printima	28_V	Inf	et	printida =printi  (Inf  >printima !28_V
48072	põnevad	põneva	põnev	02_A	PlN	et	põnevad =põneva  (PlN  >põnev !02_A
48075	mitmefunktsionaalne	funktsionaalne	mitme+funktsionaalne	02_A	SgN	et	mitmefunktsionaalne =funktsionaalne  (SgN  >mitme+funktsionaalne !02_A
48077	sisekujundust	kujundus	sise+kujundus	11_S	SgP	et	sisekujundust =kujundus  (SgP  >sise+kujundus !11_S
48078	tujule	tuju	tuju	17_S	SgAll	et	tujule =tuju  (SgAll  >tuju !17_S
48079	koolielust	elu	kooli+elu	17_S	SgEl	et	koolielust =elu  (SgEl  >kooli+elu !17_S
48080	ttu-s	ttu	ttu	xx_Q	SgIn	et	ttu-s =ttu  (SgIn  >ttu !xx_Q
48081	rühmajuhatajaks	juhataja	rühma+juhataja	01_S	SgTr	et	rühmajuhatajaks =juhataja  (SgTr  >rühma+juhataja !01_S
48086	töövõimalused	võimaluse	töö+võimalus	11_S	PlN	et	töövõimalused =võimaluse  (PlN  >töö+võimalus !11_S
48105	tellimus	tellimus	tellimus	11_S	SgN	et	tellimus =tellimus  (SgN  >tellimus !11_S
48113	võtmepositsioone	positsioone	võtme+positsioon	22_S	PlP	et	võtmepositsioone =positsioone  (PlP  >võtme+positsioon !22_S
48115	passiivsed	passiivse	passiivne	02_A	PlN	et	passiivsed =passiivse  (PlN  >passiivne !02_A
48119	kirjutasite	kirjuta	kirjutama	27_V	IndIpfPl2	et	kirjutasite =kirjuta  (IndIpfPl2  >kirjutama !27_V
48120	sektori	sektori	sektor	02_S	SgG	et	sektori =sektori  (SgG  >sektor !02_S
48122	panga-	panga	pank	22_S	SgG	et	panga- =panga  (SgG  >pank !22_S
48124	tootearendus	arendus	toote+arendus	11_S	SgN	et	tootearendus =arendus  (SgN  >toote+arendus !11_S
48131	abituriente	abituriente	abiturient	22_S	PlP	et	abituriente =abituriente  (PlP  >abiturient !22_S
48141	intressiga	intressi	intress	22_S	SgKom	et	intressiga =intressi  (SgKom  >intress !22_S
48144	vähenõudlik	nõudlik	vähe+nõudlik	25_A	SgN	et	vähenõudlik =nõudlik  (SgN  >vähe+nõudlik !25_A
48146	heata	hea	hea	26_AS	SgAb	et	heata =hea  (SgAb  >hea !26_AS
48160	pikenes	pikene	pikenema	27_V	IndIpfSg3	et	pikenes =pikene  (IndIpfSg3  >pikenema !27_V
48168	maapäeval	päeva	maa+päev	22_S	SgAd	et	maapäeval =päeva  (SgAd  >maa+päev !22_S
48172	demokraatiat	demokraatia	demokraatia	01_S	SgP	et	demokraatiat =demokraatia  (SgP  >demokraatia !01_S
48181	kirikukalendris	kalendri	kiriku+kalender	02_S	SgIn	et	kirikukalendris =kalendri  (SgIn  >kiriku+kalender !02_S
48183	rahvapühal	püha	rahva+püha	17_SA	SgAd	et	rahvapühal =püha  (SgAd  >rahva+püha !17_SA
48189	kelgud	kelgu	kelk	22_S	PlN	et	kelgud =kelgu  (PlN  >kelk !22_S
48190	naljade	nalja	nali	24_S	PlG	et	naljade =nalja  (PlG  >nali !24_S
48195	autoril	autori	autor	02_S	SgAd	et	autoril =autori  (SgAd  >autor !02_S
48196	järjestatakse	järjesta	järjestama	27_V	IndPrIps	et	järjestatakse =järjesta  (IndPrIps  >järjestama !27_V
48204	sõnajärjestus	järjestus	sõna+järjestus	11_S	SgN	et	sõnajärjestus =järjestus  (SgN  >sõna+järjestus !11_S
48207	ebakindlustus	kindlustus	eba+kindlustus	11_S	SgN	et	ebakindlustus =kindlustus  (SgN  >eba+kindlustus !11_S
48211	vaimsed	vaimse	vaimne	02_A	PlN	et	vaimsed =vaimse  (PlN  >vaimne !02_A
48214	inimedeta	ede	inim+ede	16_S	SgAb	et	inimedeta =ede  (SgAb  >inim+ede !16_S
48216	kati	kati	katt	22_S	SgG	et	kati =kati  (SgG  >katt !22_S
48218	briljant	briljant	briljant	22_S	SgN	et	briljant =briljant  (SgN  >briljant !22_S
48221	töövõimaluseta	võimaluse	töö+võimalus	11_S	SgAb	et	töövõimaluseta =võimaluse  (SgAb  >töö+võimalus !11_S
48223	telefonideta	telefoni	telefon	19_S	PlAb	et	telefonideta =telefoni  (PlAb  >telefon !19_S
48227	söögita	söögi	söök	22_S	SgAb	et	söögita =söögi  (SgAb  >söök !22_S
48238	kavata	kava	kava	17_S	SgAb	et	kavata =kava  (SgAb  >kava !17_S
48239	koduta	kodu	kodu	17_S	SgAb	et	koduta =kodu  (SgAb  >kodu !17_S
48246	edudega	edu	edu	17_S	PlKom	et	edudega =edu  (PlKom  >edu !17_S
48248	plaanime	plaani	plaanima	28_V	IndPrPl1	et	plaanime =plaani  (IndPrPl1  >plaanima !28_V
48050	botaaniline	botaaniline	botaaniline	12_A	SgN	et	botaaniline =botaaniline  (SgN  >botaaniline !12_A
48051	zoopark	park	zoo+park	22_S	SgN	et	zoopark =park  (SgN  >zoo+park !22_S
48057	ilusalong	salong	ilu+salong	22_S	SgN	et	ilusalong =salong  (SgN  >ilu+salong !22_S
48058	tsaarid	tsaari	tsaar	22_S	PlN	et	tsaarid =tsaari  (PlN  >tsaar !22_S
48065	videomakk	makk	video+makk	22_S	SgN	et	videomakk =makk  (SgN  >video+makk !22_S
48071	elamused	elamuse	elamus	11_S	PlN	et	elamused =elamuse  (PlN  >elamus !11_S
48073	kvaliteet-kaupade	kaupa	kvaliteet-kaup	22_S	PlG	et	kvaliteet-kaupade =kaupa  (PlG  >kvaliteet-kaup !22_S
48074	avarad	avara	avar	02_A	PlN	et	avarad =avara  (PlN  >avar !02_A
48082	noortelaagris	laagri	noorte+laager	02_S	SgIn	et	noortelaagris =laagri  (SgIn  >noorte+laager !02_S
48084	lauamänge	mänge	laua+mäng	22_S	PlP	et	lauamänge =mänge  (PlP  >laua+mäng !22_S
48088	lobiseda	lobise	lobisema	27_V	Inf	et	lobiseda =lobise  (Inf  >lobisema !27_V
48092	jõudukust	kus	jõudu+kusi	20_S	SgP	et	jõudukust =kus  (SgP  >jõudu+kusi !20_S
48096	töökonkursile	konkursi	töö+konkurss	22_S	SgAll	et	töökonkursile =konkursi  (SgAll  >töö+konkurss !22_S
48100	tööintervjuule	intervjuu	töö+intervjuu	26_S	SgAll	et	tööintervjuule =intervjuu  (SgAll  >töö+intervjuu !26_S
48103	koolitunnistuse	tunnistuse	kooli+tunnistus	11_S	SgG	et	koolitunnistuse =tunnistuse  (SgG  >kooli+tunnistus !11_S
48107	summat	summa	summa	16_S	SgP	et	summat =summa  (SgP  >summa !16_S
48114	ütlete	ütle	ütlema	30_V	IndPrPl2	et	ütlete =ütle  (IndPrPl2  >ütlema !30_V
48116	töökohtadega	kohta	töö+koht	22_S	PlKom	et	töökohtadega =kohta  (PlKom  >töö+koht !22_S
48121	riske	riske	risk	22_S	PlP	et	riske =riske  (PlP  >risk !22_S
48134	riigieksamitega	eksami	riigi+eksam	02_S	PlKom	et	riigieksamitega =eksami  (PlKom  >riigi+eksam !02_S
48135	kogusi	kogusi	kogus	02_A	SgG	et	kogusi =kogusi  (SgG  >kogus !02_A
48139	sobil	sobi	sobi	17_S	SgAd	et	sobil =sobi  (SgAd  >sobi !17_S
48145	reklaamideta	reklaami	reklaam	22_S	PlAb	et	reklaamideta =reklaami  (PlAb  >reklaam !22_S
48153	maailmanaisena	naise	maa+ilma+naine	12_S	SgEs	et	maailmanaisena =naise  (SgEs  >maa+ilma+naine !12_S
48154	olekski	ole	olema	36_V	KndPrPs^	et	olekski =ole  (KndPrPs^  >olema !36_V
48155	osaleme	osale	osalema	27_V	IndPrPl1	et	osaleme =osale  (IndPrPl1  >osalema !27_V
48158	püsib	püsi	püsima	27_V	IndPrSg3	et	püsib =püsi  (IndPrSg3  >püsima !27_V
48169	sõnastas	sõnasta	sõnastama	27_V	IndIpfSg3	et	sõnastas =sõnasta  (IndIpfSg3  >sõnastama !27_V
48182	iidsel	iidse	iidne	02_A	SgAd	et	iidsel =iidse  (SgAd  >iidne !02_A
48186	küpsetatakse	küpseta	küpsetama	27_V	IndPrIps	et	küpsetatakse =küpseta  (IndPrIps  >küpsetama !27_V
48187	võinädalaks	nädala	või+nädal	02_S	SgTr	et	võinädalaks =nädala  (SgTr  >või+nädal !02_S
48188	vastlakombed	kombe	vastla+komme	06_S	PlN	et	vastlakombed =kombe  (PlN  >vastla+komme !06_S
48192	tuttavatel	tuttava	tuttav	02_AS	PlAd	et	tuttavatel =tuttava  (PlAd  >tuttav !02_AS
48194	väljendata	väljenda	väljendama	27_V	IndPrIps_	et	väljendata =väljenda  (IndPrIps_  >väljendama !27_V
48201	neutraalseks	neutraalse	neutraalne	02_A	SgTr	et	neutraalseks =neutraalse  (SgTr  >neutraalne !02_A
48205	võimaluseks	võimaluse	võimalus	11_S	SgTr	et	võimaluseks =võimaluse  (SgTr  >võimalus !11_S
48206	lohakast	lohaka	lohakas	02_A	SgEl	et	lohakast =lohaka  (SgEl  >lohakas !02_A
48212	võimaldata	võimalda	võimaldama	27_V	IndPrIps_	et	võimaldata =võimalda  (IndPrIps_  >võimaldama !27_V
48230	efekt	efekt	efekt	22_S	SgN	et	efekt =efekt  (SgN  >efekt !22_S
48233	infotehnoloogiata	tehnoloogia	info+tehnoloogia	01_S	SgAb	et	infotehnoloogiata =tehnoloogia  (SgAb  >info+tehnoloogia !01_S
48236	ametikohtadel	kohta	ameti+koht	22_S	PlAd	et	ametikohtadel =kohta  (PlAd  >ameti+koht !22_S
48241	proovime	proovi	proovima	28_V	IndPrPl1	et	proovime =proovi  (IndPrPl1  >proovima !28_V
48242	põhipalk	palk	põhi+palk	22_S	SgN	et	põhipalk =palk  (SgN  >põhi+palk !22_S
48257	plaanist	plaani	plaan	22_S	SgEl	et	plaanist =plaani  (SgEl  >plaan !22_S
48259	kalli	kalli	kallis	05~07_A	SgG	et	kalli =kalli  (SgG  >kallis !05~07_A
48261	loomapark	park	looma+park	22_S	SgN	et	loomapark =park  (SgN  >looma+park !22_S
48274	puhkasemajja	majja	puhk+ase+maja	17_S	SgAdt	et	puhkasemajja =majja  (SgAdt  >puhk+ase+maja !17_S
48282	kordaminekut	mineku	korda+minek	02_S	SgP	et	kordaminekut =mineku  (SgP  >korda+minek !02_S
48295	tsirkusse	tsirkus	tsirkus	11_S	SgAdt	et	tsirkusse =tsirkus  (SgAdt  >tsirkus !11_S
48297	lõppesin	lõppe	lõppema	27~28_V	IndIpfSg1	et	lõppesin =lõppe  (IndIpfSg1  >lõppema !27~28_V
48298	reisimis-	mi	reisi+mi	26_S	SgIn	et	reisimis- =mi  (SgIn  >reisi+mi !26_S
48305	uhkustada	uhkusta	uhkustama	27_V	Inf	et	uhkustada =uhkusta  (Inf  >uhkustama !27_V
48307	kasvatan	kasvata	kasvatama	27_V	IndPrSg1	et	kasvatan =kasvata  (IndPrSg1  >kasvatama !27_V
48150	riidereklaamid	reklaami	riide+reklaam	22_S	PlN	et	riidereklaamid =reklaami  (PlN  >riide+reklaam !22_S
48151	väljaandmine	andmine	välja+andmine	12?10_S	SgN	et	väljaandmine =andmine  (SgN  >välja+andmine !12?10_S
48156	viiekümnendalt	alt	viie+kümnend+alt	22_S	SgN	et	viiekümnendalt =alt  (SgN  >viie+kümnend+alt !22_S
48159	säär	säär	säär	13_S	SgN	et	säär =säär  (SgN  >säär !13_S
48161	valgendab	valgenda	valgendama	27_V	IndPrSg3	et	valgendab =valgenda  (IndPrSg3  >valgendama !27_V
48162	perenaist	nais	pere+naine	12_S	SgP	et	perenaist =nais  (SgP  >pere+naine !12_S
48165	filoloogid	filoloogi	filoloog	22_S	PlN	et	filoloogid =filoloogi  (PlN  >filoloog !22_S
48167	rakendati	rakenda	rakendama	27_V	IndIpfIps	et	rakendati =rakenda  (IndIpfIps  >rakendama !27_V
48170	edaspidises	pidise	edas+pidine	10_A	SgIn	et	edaspidises =pidise  (SgIn  >edas+pidine !10_A
48175	vabrikute	vabriku	vabrik	02_S	PlG	et	vabrikute =vabriku  (PlG  >vabrik !02_S
48177	eriparasust	us	eri+paras+uks	14_S	SgP	et	eriparasust =us  (SgP  >eri+paras+uks !14_S
48180	vastlapäev	päev	vastla+päev	22_S	SgN	et	vastlapäev =päev  (SgN  >vastla+päev !22_S
48184	usklikel	usklike	usklik	25_AS	PlAd	et	usklikel =usklike  (PlAd  >usklik !25_AS
48193	solvangute	solvangu	solvang	02_S	PlG	et	solvangute =solvangu  (PlG  >solvang !02_S
48203	põhisõnad	sõna	põhi+sõna	17_S	PlN	et	põhisõnad =sõna  (PlN  >põhi+sõna !17_S
48210	armsat	armsa	armas	03_A	SgP	et	armsat =armsa  (SgP  >armas !03_A
48213	teleriit	riit	tele+riit	22_S	SgN	et	teleriit =riit  (SgN  >tele+riit !22_S
48226	füüsilisest	füüsilise	füüsiline	12_A	SgEl	et	füüsilisest =füüsilise  (SgEl  >füüsiline !12_A
48229	ümbruskeskkonna	keskkonna	ümbrus+keskkond	22_S	SgG	et	ümbruskeskkonna =keskkonna  (SgG  >ümbrus+keskkond !22_S
48234	lennukita	lennuki	lennuk	02_S	SgAb	et	lennukita =lennuki  (SgAb  >lennuk !02_S
48240	mitmendates	mitmenda	mitmes	02_P	PlIn	et	mitmendates =mitmenda  (PlIn  >mitmes !02_P
48243	kvalifikatsioonist	kvalifikatsiooni	kvalifikatsioon	22_S	SgEl	et	kvalifikatsioonist =kvalifikatsiooni  (SgEl  >kvalifikatsioon !22_S
48245	jagame	jaga	jagama	27_V	IndPrPl1	et	jagame =jaga  (IndPrPl1  >jagama !27_V
48250	ööbime	ööbi	ööbima	27_V	IndPrPl1	et	ööbime =ööbi  (IndPrPl1  >ööbima !27_V
48256	kirjutaksin	kirjuta	kirjutama	27_V	KndPrSg1	et	kirjutaksin =kirjuta  (KndPrSg1  >kirjutama !27_V
48258	kalli	kalli	kallis	05~07_A	SgG	et	kalli =kalli  (SgG  >kallis !05~07_A
48262	paleesid	palee	palee	26_S	PlP	et	paleesid =palee  (PlP  >palee !26_S
48266	bussireisid	reisi	bussi+reis	22_S	PlN	et	bussireisid =reisi  (PlN  >bussi+reis !22_S
48273	kloosterisse	kloosteri	klooster	02_S	SgIll	et	kloosterisse =kloosteri  (SgIll  >klooster !02_S
48276	abikaasat	kaasa	abi+kaasa	16_S	SgP	et	abikaasat =kaasa  (SgP  >abi+kaasa !16_S
48277	oblasti	oblasti	oblast	02_S	SgG	et	oblasti =oblasti  (SgG  >oblast !02_S
48284	väljakut	väljaku	väljak	02_S	SgP	et	väljakut =väljaku  (SgP  >väljak !02_S
48287	öömajal	maja	öö+maja	17_S	SgAd	et	öömajal =maja  (SgAd  >öö+maja !17_S
48290	mapina	mapi	mapp	22_S	SgEs	et	mapina =mapi  (SgEs  >mapp !22_S
48292	pajud	paju	paju	17_S	PlN	et	pajud =paju  (PlN  >paju !17_S
48299	töötamis-	mi	tööta+mi	26_S	SgIn	et	töötamis- =mi  (SgIn  >tööta+mi !26_S
48300	suhtlemisvõimaluste	võimalus	suhtlemis+võimalus	11_S	PlG	et	suhtlemisvõimaluste =võimalus  (PlG  >suhtlemis+võimalus !11_S
48309	õppetöös	töö	õppe+töö	26_S	SgIn	et	õppetöös =töö  (SgIn  >õppe+töö !26_S
48317	midagikäivad	käiva	midagi+käiv	02_A	PlN	et	midagikäivad =käiva  (PlN  >midagi+käiv !02_A
48319	pärssis	pärssi	pärssima	28_V	IndIpfSg3	et	pärssis =pärssi  (IndIpfSg3  >pärssima !28_V
48324	telekanalilt	kanali	tele+kanal	02_S	SgAbl	et	telekanalilt =kanali  (SgAbl  >tele+kanal !02_S
48327	tiiter	tiiter	tiiter	02_S	SgN	et	tiiter =tiiter  (SgN  >tiiter !02_S
48329	tähemärkide	märki	tähe+märk	22_S	PlG	et	tähemärkide =märki  (PlG  >tähe+märk !22_S
48331	jutumärkides	märki	jutu+märk	22_S	PlIn	et	jutumärkides =märki  (PlIn  >jutu+märk !22_S
48336	seriaalis	seriaali	seriaal	22_S	SgIn	et	seriaalis =seriaali  (SgIn  >seriaal !22_S
48337	ülaossa	ossa	üla+osa	17_S	SgAdt	et	ülaossa =ossa  (SgAdt  >üla+osa !17_S
48341	järgmisesse	järgmise	järgmine	12?10_A	SgIll	et	järgmisesse =järgmise  (SgIll  >järgmine !12?10_A
48342	normaaltekstis	teksti	normaal+tekst	22_S	SgIn	et	normaaltekstis =teksti  (SgIn  >normaal+tekst !22_S
48358	tunnetuslikud	tunnetusliku	tunnetuslik	25_A	PlN	et	tunnetuslikud =tunnetusliku  (PlN  >tunnetuslik !25_A
48359	jagasite	jaga	jagama	27_V	IndIpfPl2	et	jagasite =jaga  (IndIpfPl2  >jagama !27_V
48364	esmakursuslane	kursuslane	esma+kursuslane	12_S	SgN	et	esmakursuslane =kursuslane  (SgN  >esma+kursuslane !12_S
48369	lendurid	lenduri	lendur	02_S	PlN	et	lendurid =lenduri  (PlN  >lendur !02_S
48251	kremli	kremli	kreml	02_S	SgG	et	kremli =kremli  (SgG  >kreml !02_S
48254	bussipilet	pilet	bussi+pilet	02_S	SgN	et	bussipilet =pilet  (SgN  >bussi+pilet !02_S
48255	toreda	toreda	tore	02_A	SgG	et	toreda =toreda  (SgG  >tore !02_A
48271	õndsa	õndsa	õnnis	03~05_A	SgG	et	õndsa =õndsa  (SgG  >õnnis !03~05_A
48275	broneerin	broneeri	broneerima	28_V	IndPrSg1	et	broneerin =broneeri  (IndPrSg1  >broneerima !28_V
48278	sugulane	sugulane	sugulane	12_S	SgN	et	sugulane =sugulane  (SgN  >sugulane !12_S
48280	puhkusule	usu	puhk+usk	22_S	SgAll	et	puhkusule =usu  (SgAll  >puhk+usk !22_S
48283	külastaksime	külasta	külastama	27_V	KndPrPl1	et	külastaksime =külasta  (KndPrPl1  >külastama !27_V
48285	istutame	istuta	istutama	27_V	IndPrPl1	et	istutame =istuta  (IndPrPl1  >istutama !27_V
48286	pereliikmetel	liikme	pere+liige	05_S	PlAd	et	pereliikmetel =liikme  (PlAd  >pere+liige !05_S
48289	saabun	saabu	saabuma	27_V	IndPrSg1	et	saabun =saabu  (IndPrSg1  >saabuma !27_V
48304	eluväärtused	väärtuse	elu+väärtus	11~09_S	PlN	et	eluväärtused =väärtuse  (PlN  >elu+väärtus !11~09_S
48311	püstitasin	püstita	püstitama	27_V	IndIpfSg1	et	püstitasin =püstita  (IndIpfSg1  >püstitama !27_V
48313	väsin	väsi	väsima	27_V	IndPrSg1	et	väsin =väsi  (IndPrSg1  >väsima !27_V
48320	erudeeritud	erudeeritud	erudeeritud	41_A	ID	et	erudeeritud =erudeeritud  (ID  >erudeeritud !41_A
48333	nõmmik	nõmmik	nõmmik	02_S	SgN	et	nõmmik =nõmmik  (SgN  >nõmmik !02_S
48334	laanejärv	järv	laane+järv	22_S	SgN	et	laanejärv =järv  (SgN  >laane+järv !22_S
48348	tulevikuplaane	plaane	tuleviku+plaan	22_S	PlP	et	tulevikuplaane =plaane  (PlP  >tuleviku+plaan !22_S
48351	põnnid	põnni	põnn	22_S	PlN	et	põnnid =põnni  (PlN  >põnn !22_S
48357	hüvang	hüvang	hüvang	02_S	SgN	et	hüvang =hüvang  (SgN  >hüvang !02_S
48373	noorinimestest	inimes	noor+inimene	12_S	PlEl	et	noorinimestest =inimes  (PlEl  >noor+inimene !12_S
48374	mainite	maini	mainima	28_V	IndPrPl2	et	mainite =maini  (IndPrPl2  >mainima !28_V
48375	sotsiaaltöötajana	töötaja	sotsiaal+töötaja	01_S	SgEs	et	sotsiaaltöötajana =töötaja  (SgEs  >sotsiaal+töötaja !01_S
48378	pikaldased	pikaldase	pikaldane	12_A	PlN	et	pikaldased =pikaldase  (PlN  >pikaldane !12_A
48389	rühmadeks	rühma	rühm	22_S	PlTr	et	rühmadeks =rühma  (PlTr  >rühm !22_S
48394	eksamipunkte	punkte	eksami+punkt	22_S	PlP	et	eksamipunkte =punkte  (PlP  >eksami+punkt !22_S
48397	abiturientidest	abiturienti	abiturient	22_S	PlEl	et	abiturientidest =abiturienti  (PlEl  >abiturient !22_S
48399	maksimalistid	maksimalisti	maksimalist	22_S	PlN	et	maksimalistid =maksimalisti  (PlN  >maksimalist !22_S
48401	stopp-nupp	nupp	stopp-nupp	22_S	SgN	et	stopp-nupp =nupp  (SgN  >stopp-nupp !22_S
48409	kodakondsusele	kodakondsuse	kodakondsus	11~09_S	SgAll	et	kodakondsusele =kodakondsuse  (SgAll  >kodakondsus !11~09_S
48418	lihad	liha	liha	17_S	PlN	et	lihad =liha  (PlN  >liha !17_S
48422	vormistan	vormista	vormistama	27_V	IndPrSg1	et	vormistan =vormista  (IndPrSg1  >vormistama !27_V
48427	klienditeenindajaks	teenindaja	kliendi+teenindaja	01_S	SgTr	et	klienditeenindajaks =teenindaja  (SgTr  >kliendi+teenindaja !01_S
48429	lillekauplusse	kauplus	lille+kauplus	11_S	SgAdt	et	lillekauplusse =kauplus  (SgAdt  >lille+kauplus !11_S
48432	puhkekodus	kodu	puhke+kodu	17_S	SgIn	et	puhkekodus =kodu  (SgIn  >puhke+kodu !17_S
48438	reisirong	rong	reisi+rong	22_S	SgN	et	reisirong =rong  (SgN  >reisi+rong !22_S
48445	riida	riida	riit	22_S	SgG	et	riida =riida  (SgG  >riit !22_S
48449	instituudid	instituudi	instituut	22_S	PlN	et	instituudid =instituudi  (PlN  >instituut !22_S
48454	parteijuht	juht	part+ei+juht	22_S	SgN	et	parteijuht =juht  (SgN  >part+ei+juht !22_S
48464	õppevahendite	vahendi	õppe+vahend	02_S	PlG	et	õppevahendite =vahendi  (PlG  >õppe+vahend !02_S
48466	magustoidu	toidu	magus+toit	22_S	SgG	et	magustoidu =toidu  (SgG  >magus+toit !22_S
48473	selgitame	selgita	selgitama	27_V	IndPrPl1	et	selgitame =selgita  (IndPrPl1  >selgitama !27_V
48475	luge	luge	luga	18_S	PlP	et	luge =luge  (PlP  >luga !18_S
48476	teeniksin	teeni	teenima	28_V	KndPrSg1	et	teeniksin =teeni  (KndPrSg1  >teenima !28_V
48478	põhiharidus	haridus	põhi+haridus	11_S	SgN	et	põhiharidus =haridus  (SgN  >põhi+haridus !11_S
48487	püstitama	püstita	püstitama	27_V	Sup	et	püstitama =püstita  (Sup  >püstitama !27_V
48489	5missugused	suguse	mis+sugune	10_P	PlN	et	missugused =suguse  (PlN  >mis+sugune !10_P
48495	laiskvorstid	vorsti	laisk+vorst	22_S	PlN	et	laiskvorstid =vorsti  (PlN  >laisk+vorst !22_S
48499	talurahvakoolid	kooli	talu+rahva+kool	22_S	PlN	et	talurahvakoolid =kooli  (PlN  >talu+rahva+kool !22_S
48504	usuteaduseprofessorid	professori	usu+teaduse+professor	02_S	PlN	et	usuteaduseprofessorid =professori  (PlN  >usu+teaduse+professor !02_S
48505	rootsiaegses	aegse	rootsi+aegne	02_A	SgIn	et	rootsiaegses =aegse  (SgIn  >rootsi+aegne !02_A
48509	laadakaubandus	kaubandus	laada+kaubandus	11_S	SgN	et	laadakaubandus =kaubandus  (SgN  >laada+kaubandus !11_S
48268	südamlike	südamlike	südamlik	25_A	PlG	et	südamlike =südamlike  (PlG  >südamlik !25_A
48270	pühades	püha	püha	17_SA	PlIn	et	pühades =püha  (PlIn  >püha !17_SA
48281	mälestisi	mälestisi	mälestis	11_S	PlP	et	mälestisi =mälestisi  (PlP  >mälestis !11_S
48291	suplemas	suple	suplema	30_V	SupIn	et	suplemas =suple  (SupIn  >suplema !30_V
48293	külastaksin	külasta	külastama	27_V	KndPrSg1	et	külastaksin =külasta  (KndPrSg1  >külastama !27_V
48301	koostööks	töö	koos+töö	26_S	SgTr	et	koostööks =töö  (SgTr  >koos+töö !26_S
48308	kontaktandmeid	andme	kontakt+anne	05_S	PlP	et	kontaktandmeid =andme  (PlP  >kontakt+anne !05_S
48312	2missugused	suguse	mis+sugune	10_P	PlN	et	missugused =suguse  (PlN  >mis+sugune !10_P
48315	4kus	kus	kus	41_D	ID	et	kus =kus  (ID  >kus !41_D
48325	seriaal	seriaal	seriaal	22_S	SgN	et	seriaal =seriaal  (SgN  >seriaal !22_S
48332	inglisekeelse	keelse	inglise+keelne	02_A	SgG	et	inglisekeelse =keelse  (SgG  >inglise+keelne !02_A
48343	keerukaid	keeruka	keerukas	02_A	PlP	et	keerukaid =keeruka  (PlP  >keerukas !02_A
48347	abiturientidel	abiturienti	abiturient	22_S	PlAd	et	abiturientidel =abiturienti  (PlAd  >abiturient !22_S
48355	taheta	tahe	tahtma	34_V	IndPrIps_	et	taheta =tahe  (IndPrIps_  >tahtma !34_V
48362	rahasuhtes	suhte	raha+suhe	06_S	SgIn	et	rahasuhtes =suhte  (SgIn  >raha+suhe !06_S
48363	aastakäikude	käiku	aasta+käik	22_S	PlG	et	aastakäikude =käiku  (PlG  >aasta+käik !22_S
48365	heaolus	olu	hea+olu	17_S	SgIn	et	heaolus =olu  (SgIn  >hea+olu !17_S
48368	kuulades	la	kuu+la	26_S	PlIn	et	kuulades =la  (PlIn  >kuu+la !26_S
48372	näidisena	näidise	näidis	09_S	SgEs	et	näidisena =näidise  (SgEs  >näidis !09_S
48376	nõustan	nõusta	nõustama	27_V	IndPrSg1	et	nõustan =nõusta  (IndPrSg1  >nõustama !27_V
48377	juhtkiri	kiri	juht+kiri	24_S	SgN	et	juhtkiri =kiri  (SgN  >juht+kiri !24_S
48381	panustada	panusta	panustama	27_V	Inf	et	panustada =panusta  (Inf  >panustama !27_V
48385	halbadest	halba	halb	22_A	PlEl	et	halbadest =halba  (PlEl  >halb !22_A
48387	vahenõudlike	nõudlike	vahe+nõudlik	25_A	PlG	et	vahenõudlike =nõudlike  (PlG  >vahe+nõudlik !25_A
48390	väärtushinnangute	hinnangu	väärtus+hinnang	02_S	PlG	et	väärtushinnangute =hinnangu  (PlG  >väärtus+hinnang !02_S
48392	tõemeelseks	meelse	tõe+meelne	02_A	SgTr	et	tõemeelseks =meelse  (SgTr  >tõe+meelne !02_A
48395	liikusin	liiku	liikuma	28_V	IndIpfSg1	et	liikusin =liiku  (IndIpfSg1  >liikuma !28_V
48407	vabaaja	aja	vaba+aeg	22_S	SgG	et	vabaaja =aja  (SgG  >vaba+aeg !22_S
48417	orule	oru	org	22_S	SgAll	et	orule =oru  (SgAll  >org !22_S
48419	produkt	produkt	produkt	22_S	SgN	et	produkt =produkt  (SgN  >produkt !22_S
48424	teoreetilise	teoreetilise	teoreetiline	12_A	SgG	et	teoreetilise =teoreetilise  (SgG  >teoreetiline !12_A
48425	linnaraamatukogusse	kogu	linna+raamatu+kogu	17_S	SgIll	et	linnaraamatukogusse =kogu  (SgIll  >linna+raamatu+kogu !17_S
48428	remonditeenindus	teenindus	remondi+teenindus	11_S	SgN	et	remonditeenindus =teenindus  (SgN  >remondi+teenindus !11_S
48431	stardib	stardi	startima	28_V	IndPrSg3	et	stardib =stardi  (IndPrSg3  >startima !28_V
48434	samarasse	rasse	sama+rass	22_S	PlP	et	samarasse =rasse  (PlP  >sama+rass !22_S
48439	numbritoas	toa	numbri+tuba	18_S	SgIn	et	numbritoas =toa  (SgIn  >numbri+tuba !18_S
48441	kirjate	kirja	kirjama	29_V	IndPrPl2	et	kirjate =kirja  (IndPrPl2  >kirjama !29_V
48456	veeloomad	looma	vee+loom	22_S	PlN	et	veeloomad =looma  (PlN  >vee+loom !22_S
48463	sanitaarremont	remont	sanitaar+remont	22_S	SgN	et	sanitaarremont =remont  (SgN  >sanitaar+remont !22_S
48467	mineraal	mineraal	mineraal	22_S	SgN	et	mineraal =mineraal  (SgN  >mineraal !22_S
48469	kulata	kula	kula	17_S	SgAb	et	kulata =kula  (SgAb  >kula !17_S
48480	tükke	tükke	tükk	22_S	PlP	et	tükke =tükke  (PlP  >tükk !22_S
48482	kultuurset	kultuurse	kultuurne	02_A	SgP	et	kultuurset =kultuurse  (SgP  >kultuurne !02_A
48488	järk-	järk	järk	22_S	SgN	et	järk- =järk  (SgN  >järk !22_S
48497	rahvakoolid	kooli	rahva+kool	22_S	PlN	et	rahvakoolid =kooli  (PlN  >rahva+kool !22_S
48501	aabitsad	aabitsa	aabits	02_S	PlN	et	aabitsad =aabitsa  (PlN  >aabits !02_S
48502	pastorid	pastori	pastor	02_S	PlN	et	pastorid =pastori  (PlN  >pastor !02_S
48511	majandusellu	ellu	majandus+elu	17_S	SgAdt	et	majandusellu =ellu  (SgAdt  >majandus+elu !17_S
48515	erikorras	korra	eri+kord	22_S	SgIn	et	erikorras =korra  (SgIn  >eri+kord !22_S
48531	vastuseisjal	seisja	vastu+seisja	01_S	SgAd	et	vastuseisjal =seisja  (SgAd  >vastu+seisja !01_S
48536	vihmajumal	jumal	vihma+jumal	02_S	SgN	et	vihmajumal =jumal  (SgN  >vihma+jumal !02_S
48537	muistsetel	muistse	muistne	02_A	PlAd	et	muistsetel =muistse  (PlAd  >muistne !02_A
48540	tavaelusse	elu	tava+elu	17_S	SgIll	et	tavaelusse =elu  (SgIll  >tava+elu !17_S
48546	mõeldi	mõel	mõtlema	30_V	IndIpfIps	et	mõeldi =mõel  (IndIpfIps  >mõtlema !30_V
48269	kirjutad	kirjuta	kirjutama	27_V	IndPrSg2	et	kirjutad =kirjuta  (IndPrSg2  >kirjutama !27_V
48272	kloosteri	kloosteri	klooster	02_S	SgG	et	kloosteri =kloosteri  (SgG  >klooster !02_S
48279	lapselapsega	lapse	lapse+laps	14_S	SgKom	et	lapselapsega =lapse  (SgKom  >lapse+laps !14_S
48288	vähi	vähi	vähk	22_S	SgG	et	vähi =vähi  (SgG  >vähk !22_S
48294	käiksin	käi	käima	38_V	KndPrSg1	et	käiksin =käi  (KndPrSg1  >käima !38_V
48296	personalijuht	juht	personali+juht	22_S	SgN	et	personalijuht =juht  (SgN  >personali+juht !22_S
48302	tugevdab	tugevda	tugevdama	27_V	IndPrSg3	et	tugevdab =tugevda  (IndPrSg3  >tugevdama !27_V
48303	hankida	hanki	hankima	28_V	Inf	et	hankida =hanki  (Inf  >hankima !28_V
48306	abivahendiks	vahendi	abi+vahend	02_S	SgTr	et	abivahendiks =vahendi  (SgTr  >abi+vahend !02_S
48310	õppe-eesmärgid	märgi	õppe-ees+märk	22_S	PlN	et	õppe-eesmärgid =märgi  (PlN  >õppe-ees+märk !22_S
48314	3kus	kus	kus	41_D	ID	et	kus =kus  (ID  >kus !41_D
48316	6kas	kas	kas	41_D	ID	et	kas =kas  (ID  >kas !41_D
48321	lõppeksamite	eksami	lõpp+eksam	02_S	PlG	et	lõppeksamite =eksami  (PlG  >lõpp+eksam !02_S
48322	kukru	kukru	kukkur	02_S	SgG	et	kukru =kukru  (SgG  >kukkur !02_S
48326	kanalil	kanali	kanal	02_S	SgAd	et	kanalil =kanali  (SgAd  >kanal !02_S
48335	dokumentaalsarjas	sarja	dokumentaal+sari	24_S	SgIn	et	dokumentaalsarjas =sarja  (SgIn  >dokumentaal+sari !24_S
48338	alaosas	osa	ala+osa	17_S	SgIn	et	alaosas =osa  (SgIn  >ala+osa !17_S
48339	pausid	pausi	paus	22_S	PlN	et	pausid =pausi  (PlN  >paus !22_S
48340	toppama	toppa	toppama	29_V	Sup	et	toppama =toppa  (Sup  >toppama !29_V
48345	loteriiga	loterii	loterii	26_S	SgKom	et	loteriiga =loterii  (SgKom  >loterii !26_S
48346	punktidega	punkti	punkt	22_S	PlKom	et	punktidega =punkti  (PlKom  >punkt !22_S
48352	idüll	idüll	idüll	22_S	SgN	et	idüll =idüll  (SgN  >idüll !22_S
48356	rühmale	rühma	rühm	22_S	SgAll	et	rühmale =rühma  (SgAll  >rühm !22_S
48360	vähenema	vähene	vähenema	27_V	Sup	et	vähenema =vähene  (Sup  >vähenema !27_V
48361	abituriendil	abituriendi	abiturient	22_S	SgAd	et	abituriendil =abituriendi  (SgAd  >abiturient !22_S
48366	homses	homse	homne	02_A	SgIn	et	homses =homse  (SgIn  >homne !02_A
48367	eesmärkidega	märki	ees+märk	22_S	PlKom	et	eesmärkidega =märki  (PlKom  >ees+märk !22_S
48379	viimse	viimse	viimne	02_A	SgG	et	viimse =viimse  (SgG  >viimne !02_A
48382	elektriajamite	ajami	elektri+ajam	02_S	PlG	et	elektriajamite =ajami  (PlG  >elektri+ajam !02_S
48391	ebastabiilses	stabiilse	eba+stabiilne	02_A	SgIn	et	ebastabiilses =stabiilse  (SgIn  >eba+stabiilne !02_A
48400	saatsite	saat	saatma	34_V	IndIpfPl2	et	saatsite =saat  (IndIpfPl2  >saatma !34_V
48403	muudate	muuda	muutma	34_V	IndPrPl2	et	muudate =muuda  (IndPrPl2  >muutma !34_V
48408	arvutiõppimine	õppimine	arvuti+õppimine	12_S	SgN	et	arvutiõppimine =õppimine  (SgN  >arvuti+õppimine !12_S
48413	marke	marke	mark	22_S	PlP	et	marke =marke  (PlP  >mark !22_S
48415	kirjapaberit	paberi	kirja+paber	02_S	SgP	et	kirjapaberit =paberi  (SgP  >kirja+paber !02_S
48436	etendub	etendu	etenduma	27_V	IndPrSg3	et	etendub =etendu  (IndPrSg3  >etenduma !27_V
48437	palvetan	palveta	palvetama	27_V	IndPrSg1	et	palvetan =palveta  (IndPrSg1  >palvetama !27_V
48440	kunstimuuseumis	muuseumi	kunsti+muuseum	19~02_S	SgIn	et	kunstimuuseumis =muuseumi  (SgIn  >kunsti+muuseum !19~02_S
48446	nõmetakse	takse	nõme+taks	22_S	PlP	et	nõmetakse =takse  (PlP  >nõme+taks !22_S
48451	strateeg	strateeg	strateeg	22_S	SgN	et	strateeg =strateeg  (SgN  >strateeg !22_S
48453	ettevalmistused	valmistuse	ette+valmistus	11_S	PlN	et	ettevalmistused =valmistuse  (PlN  >ette+valmistus !11_S
48457	paberlipakaseid	lipakase	paber+lipakas	02_S	PlP	et	paberlipakaseid =lipakase  (PlP  >paber+lipakas !02_S
48458	prügisid	prügi	prügi	17_S	PlP	et	prügisid =prügi  (PlP  >prügi !17_S
48459	lastemänguväljakute	väljaku	laste+mängu+väljak	02_S	PlG	et	lastemänguväljakute =väljaku  (PlG  >laste+mängu+väljak !02_S
48461	kellab	kella	kellama	29_V	IndPrSg3	et	kellab =kella  (IndPrSg3  >kellama !29_V
48462	aktus	aktus	aktus	11~09_S	SgN	et	aktus =aktus  (SgN  >aktus !11~09_S
48470	loomulikul	loomuliku	loomulik	25_A	SgAd	et	loomulikul =loomuliku  (SgAd  >loomulik !25_A
48472	lahendan	lahenda	lahendama	27_V	IndPrSg1	et	lahendan =lahenda  (IndPrSg1  >lahendama !27_V
48477	algharidus	haridus	alg+haridus	11_S	SgN	et	algharidus =haridus  (SgN  >alg+haridus !11_S
48484	kaasaaegses	aegse	kaasa+aegne	02_A	SgIn	et	kaasaaegses =aegse  (SgIn  >kaasa+aegne !02_A
48485	2kuidas	kuidas	kuidas	41_D	ID	et	kuidas =kuidas  (ID  >kuidas !41_D
48490	edasise	edasise	edasine	12_A	SgG	et	edasise =edasise  (SgG  >edasine !12_A
48492	8kuidas	kuidas	kuidas	41_D	ID	et	kuidas =kuidas  (ID  >kuidas !41_D
48498	majanduselule	elu	majandus+elu	17_S	SgAll	et	majanduselule =elu  (SgAll  >majandus+elu !17_S
48318	valdkondadele	valdkonda	valdkond	22_S	PlAll	et	valdkondadele =valdkonda  (PlAll  >valdkond !22_S
48323	lindistasin	lindista	lindistama	27_V	IndIpfSg1	et	lindistasin =lindista  (IndIpfSg1  >lindistama !27_V
48328	telepilt	pilt	tele+pilt	22_S	SgN	et	telepilt =pilt  (SgN  >tele+pilt !22_S
48330	alumine	alumine	alumine	12_A	SgN	et	alumine =alumine  (SgN  >alumine !12_A
48344	umbkaudu	umbkaudu	umb+kaudu	41_D	ID	et	umbkaudu =umbkaudu  (ID  >umb+kaudu !41_D
48349	märkasite	märka	märkama	29_V	IndIpfPl2	et	märkasite =märka  (IndIpfPl2  >märkama !29_V
48350	soetada	soeta	soetama	27_V	Inf	et	soetada =soeta  (Inf  >soetama !27_V
48353	lastena	las	laps	14_S	PlEs	et	lastena =las  (PlEs  >laps !14_S
48354	ihaldusväärne	väärne	ihaldus+väärne	02_A	SgN	et	ihaldusväärne =väärne  (SgN  >ihaldus+väärne !02_A
48380	looder	looder	looder	02_S	SgN	et	looder =looder  (SgN  >looder !02_S
48386	õpilasena	õpilase	õpilane	12_S	SgEs	et	õpilasena =õpilase  (SgEs  >õpilane !12_S
48396	sihele	sihe	siht	22_S	PlAll	et	sihele =sihe  (PlAll  >siht !22_S
48398	stimuleerib	stimuleeri	stimuleerima	28_V	IndPrSg3	et	stimuleerib =stimuleeri  (IndPrSg3  >stimuleerima !28_V
48402	koolidirektori	direktori	kooli+direktor	02_S	SgG	et	koolidirektori =direktori  (SgG  >kooli+direktor !02_S
48414	ümbrikuid	ümbriku	ümbrik	02_S	PlP	et	ümbrikuid =ümbriku  (PlP  >ümbrik !02_S
48421	teenindada	teeninda	teenindama	27_V	Inf	et	teenindada =teeninda  (Inf  >teenindama !27_V
48423	stiiliõpetus	õpetus	stiili+õpetus	11_S	SgN	et	stiiliõpetus =õpetus  (SgN  >stiili+õpetus !11_S
48433	mänguplats	plats	mängu+plats	22_S	SgN	et	mänguplats =plats  (SgN  >mängu+plats !22_S
48442	linne	linne	linne	06_S	SgN	et	linne =linne  (SgN  >linne !06_S
48443	tervitage	tervita	tervitama	27_V	ImpPrPl2	et	tervitage =tervita  (ImpPrPl2  >tervitama !27_V
48448	arstiteaduse	teaduse	arsti+teadus	11~09_S	SgG	et	arstiteaduse =teaduse  (SgG  >arsti+teadus !11~09_S
48450	avatati	tati	ava+tatt	22_S	SgG	et	avatati =tati  (SgG  >ava+tatt !22_S
48465	fregati	fregati	fregatt	22_S	SgG	et	fregati =fregati  (SgG  >fregatt !22_S
48468	interneti-võimalus	võimalus	interneti-võimalus	11_S	SgN	et	interneti-võimalus =võimalus  (SgN  >interneti-võimalus !11_S
48471	toniseerib	toniseeri	toniseerima	28_V	IndPrSg3	et	toniseerib =toniseeri  (IndPrSg3  >toniseerima !28_V
48479	edaspidine	pidine	edas+pidine	10_A	SgN	et	edaspidine =pidine  (SgN  >edas+pidine !10_A
48486	3kuidas	kuidas	kuidas	41_D	ID	et	kuidas =kuidas  (ID  >kuidas !41_D
48491	6missugused	suguse	mis+sugune	10_P	PlN	et	missugused =suguse  (PlN  >mis+sugune !10_P
48494	hästialgklassides	klassi	hästi+alg+klass	22_S	PlIn	et	hästialgklassides =klassi  (PlIn  >hästi+alg+klass !22_S
48496	rootsiaegne	aegne	rootsi+aegne	02_A	SgN	et	rootsiaegne =aegne  (SgN  >rootsi+aegne !02_A
48500	hariduselule	elu	haridus+elu	17_S	SgAll	et	hariduselule =elu  (SgAll  >haridus+elu !17_S
48506	omavalitsev	valitsev	oma+valitsev	02_A	SgN	et	omavalitsev =valitsev  (SgN  >oma+valitsev !02_A
48514	kindralkubernerideks	kuberneri	kindral+kuberner	19_S	PlTr	et	kindralkubernerideks =kuberneri  (PlTr  >kindral+kuberner !19_S
48519	keskaegsel	aegse	kesk+aegne	02_A	SgAd	et	keskaegsel =aegse  (SgAd  >kesk+aegne !02_A
48524	künnimaaga	maa	künni+maa	26_S	SgKom	et	künnimaaga =maa  (SgKom  >künni+maa !26_S
48526	kihelkonnad	kihelkonna	kihelkond	22_S	PlN	et	kihelkonnad =kihelkonna  (PlN  >kihelkond !22_S
48528	lepne	lepne	lepne	02_A	SgN	et	lepne =lepne  (SgN  >lepne !02_A
48535	hiliskeskajal	aja	hilis+kesk+aeg	22_S	SgAd	et	hiliskeskajal =aja  (SgAd  >hilis+kesk+aeg !22_S
48538	ristiusust	usu	risti+usk	22_S	SgEl	et	ristiusust =usu  (SgEl  >risti+usk !22_S
48553	kultuuritegelejaid	tegeleja	kultuuri+tegeleja	01_S	PlP	et	kultuuritegelejaid =tegeleja  (PlP  >kultuuri+tegeleja !01_S
48556	kirjanduseselts	selts	kirjanduse+selts	22_S	SgN	et	kirjanduseselts =selts  (SgN  >kirjanduse+selts !22_S
48557	manufaktuurid	manufaktuuri	manufaktuur	22_S	PlN	et	manufaktuurid =manufaktuuri  (PlN  >manufaktuur !22_S
48563	põllundust	põllundus	põllundus	11_S	SgP	et	põllundust =põllundus  (SgP  >põllundus !11_S
48564	karjakasvatusega	kasvatuse	karja+kasvatus	11_S	SgKom	et	karjakasvatusega =kasvatuse  (SgKom  >karja+kasvatus !11_S
48566	loomadel	looma	loom	22_S	PlAd	et	loomadel =looma  (PlAd  >loom !22_S
48570	renessansi	renessansi	renessanss	22_S	SgG	et	renessansi =renessansi  (SgG  >renessanss !22_S
48585	talupojadel	poja	talu+poja	17_S	PlAd	et	talupojadel =poja  (PlAd  >talu+poja !17_S
48589	manitses	manitse	manitsema	27_V	IndIpfSg3	et	manitses =manitse  (IndIpfSg3  >manitsema !27_V
48590	väljaandmisest	andmise	välja+andmine	12?10_S	SgEl	et	väljaandmisest =andmise  (SgEl  >välja+andmine !12?10_S
48623	keskaegset	aegse	kesk+aegne	02_A	SgP	et	keskaegset =aegse  (SgP  >kesk+aegne !02_A
48626	viljamajandusele	majanduse	vilja+majandus	11_S	SgAll	et	viljamajandusele =majanduse  (SgAll  >vilja+majandus !11_S
48645	elatusviisid	viisi	elatus+viis	22_S	PlN	et	elatusviisid =viisi  (PlN  >elatus+viis !22_S
48370	puudutasite	puuduta	puudutama	27_V	IndIpfPl2	et	puudutasite =puuduta  (IndIpfPl2  >puudutama !27_V
48371	aspektidega	aspekti	aspekt	22_S	PlKom	et	aspektidega =aspekti  (PlKom  >aspekt !22_S
48383	looteri	teri	loo+tera	17_S	PlP	et	looteri =teri  (PlP  >loo+tera !17_S
48384	põlvkonnadele	konna	põlv+konn	22_S	PlAll	et	põlvkonnadele =konna  (PlAll  >põlv+konn !22_S
48388	põlvkondadest	põlvkonda	põlvkond	22_S	PlEl	et	põlvkondadest =põlvkonda  (PlEl  >põlvkond !22_S
48393	eelesitatud	esitatu	eel+esitatu	01_S	PlN	et	eelesitatud =esitatu  (PlN  >eel+esitatu !01_S
48404	õppepäev	päev	õppe+päev	22_S	SgN	et	õppepäev =päev  (SgN  >õppe+päev !22_S
48405	kooliülesandeid	ande	kooli+üles+anne	06_S	PlP	et	kooliülesandeid =ande  (PlP  >kooli+üles+anne !06_S
48406	vaheaja	aja	vahe+aeg	22_S	SgG	et	vaheaja =aja  (SgG  >vahe+aeg !22_S
48410	detsembrist	detsembri	detsember	02_S	SgEl	et	detsembrist =detsembri  (SgEl  >detsember !02_S
48411	postis	posti	post	22_S	SgIn	et	postis =posti  (SgIn  >post !22_S
48412	postisse	posti	post	22_S	SgIll	et	postisse =posti  (SgIll  >post !22_S
48416	sorteerima	sorteeri	sorteerima	28_V	Sup	et	sorteerima =sorteeri  (Sup  >sorteerima !28_V
48420	seaduseandlus	andlus	seaduse+andlus	11~09_S	SgN	et	seaduseandlus =andlus  (SgN  >seaduse+andlus !11~09_S
48426	raamatukoguhoidjana	hoidja	raamatu+kogu+hoidja	01_S	SgEs	et	raamatukoguhoidjana =hoidja  (SgEs  >raamatu+kogu+hoidja !01_S
48430	reisibüroos	büroo	reisi+büroo	26_S	SgIn	et	reisibüroos =büroo  (SgIn  >reisi+büroo !26_S
48435	plaanidest	plaani	plaan	22_S	PlEl	et	plaanidest =plaani  (PlEl  >plaan !22_S
48444	kavatseme	kavatse	kavatsema	27_V	IndPrPl1	et	kavatseme =kavatse  (IndPrPl1  >kavatsema !27_V
48447	sugulasele	sugulase	sugulane	12_S	SgAll	et	sugulasele =sugulase  (SgAll  >sugulane !12_S
48452	võistlustega	võistlus	võistlus	11~09_S	PlKom	et	võistlustega =võistlus  (PlKom  >võistlus !11~09_S
48455	kriitiliste	kriitilis	kriitiline	12_A	PlG	et	kriitiliste =kriitilis  (PlG  >kriitiline !12_A
48460	pühariides	riide	püha+riie	06_S	SgIn	et	pühariides =riide  (SgIn  >püha+riie !06_S
48474	vaheaed	aed	vahe+aed	22_S	SgN	et	vaheaed =aed  (SgN  >vahe+aed !22_S
48481	seejäärel	jääre	see+jäär	22_S	PlAd	et	seejäärel =jääre  (PlAd  >see+jäär !22_S
48483	õping	õping	õping	02_S	SgN	et	õping =õping  (SgN  >õping !02_S
48493	ühena	ühe	üks	22_NP	SgEs	et	ühena =ühe  (SgEs  >üks !22_NP
48503	lätlastele	lätlas	lätlane	12?10_S	PlAll	et	lätlastele =lätlas  (PlAll  >lätlane !12?10_S
48507	autonoomsed	autonoomse	autonoomne	02_A	PlN	et	autonoomsed =autonoomse  (PlN  >autonoomne !02_A
48508	rahvuspäringuga	päringu	rahvus+päring	02_S	SgKom	et	rahvuspäringuga =päringu  (SgKom  >rahvus+päring !02_S
48518	üleminekul	mineku	üle+minek	02_S	SgAd	et	üleminekul =mineku  (SgAd  >üle+minek !02_S
48523	maakorraldusega	korralduse	maa+korraldus	11_S	SgKom	et	maakorraldusega =korralduse  (SgKom  >maa+korraldus !11_S
48525	peredega	pere	pere	16_S	PlKom	et	peredega =pere  (PlKom  >pere !16_S
48534	hiliskeskaegset	aegse	hilis+kesk+aegne	02_A	SgP	et	hiliskeskaegset =aegse  (SgP  >hilis+kesk+aegne !02_A
48539	vabana	vaba	vaba	17_A	SgEs	et	vabana =vaba  (SgEs  >vaba !17_A
48541	negatiivseteks	negatiivse	negatiivne	02_A	PlTr	et	negatiivseteks =negatiivse  (PlTr  >negatiivne !02_A
48543	talupojadega	poja	talu+poja	17_S	PlKom	et	talupojadega =poja  (PlKom  >talu+poja !17_S
48551	ametiühingut	ühingu	ameti+ühing	02_S	SgP	et	ametiühingut =ühingu  (SgP  >ameti+ühing !02_S
48554	testament	testament	testament	22_S	SgN	et	testament =testament  (SgN  >testament !22_S
48558	linnaelaniku	elaniku	linna+elanik	25_S	SgG	et	linnaelaniku =elaniku  (SgG  >linna+elanik !25_S
48562	allpõllundust	põllundus	all+põllundus	11_S	SgP	et	allpõllundust =põllundus  (SgP  >all+põllundus !11_S
48568	rauaajas	aja	raua+aeg	22_S	SgIn	et	rauaajas =aja  (SgIn  >raua+aeg !22_S
48571	kultuurisüda	süda	kultuuri+süda	04_S	SgN	et	kultuurisüda =süda  (SgN  >kultuuri+süda !04_S
48573	formeerus	formeeru	formeeruma	27_V	IndIpfSg3	et	formeerus =formeeru  (IndIpfSg3  >formeeruma !27_V
48579	kultuurpoliitilised	poliitilise	kultuur+poliitiline	12_A	PlN	et	kultuurpoliitilised =poliitilise  (PlN  >kultuur+poliitiline !12_A
48580	rahvavalgustuslik	valgustuslik	rahva+valgustuslik	25_A	SgN	et	rahvavalgustuslik =valgustuslik  (SgN  >rahva+valgustuslik !25_A
48581	pärsiorjuse	orjuse	pärsi+orjus	11~09_S	SgG	et	pärsiorjuse =orjuse  (SgG  >pärsi+orjus !11~09_S
48582	pehmenema	pehmene	pehmenema	27_V	Sup	et	pehmenema =pehmene  (Sup  >pehmenema !27_V
48583	valgustusliku	valgustusliku	valgustuslik	25_A	SgG	et	valgustusliku =valgustusliku  (SgG  >valgustuslik !25_A
48584	rahvaseadustega	seadus	rahva+seadus	11~09_S	PlKom	et	rahvaseadustega =seadus  (PlKom  >rahva+seadus !11~09_S
48586	maatükk	tükk	maa+tükk	22_S	SgN	et	maatükk =tükk  (SgN  >maa+tükk !22_S
48594	muld	muld	muld	22_S	SgN	et	muld =muld  (SgN  >muld !22_S
48510	kilud	kilu	kilu	17_S	PlN	et	kilud =kilu  (PlN  >kilu !17_S
48520	vabadusvõitlus	võitlus	vabadus+võitlus	11~09_S	SgN	et	vabadusvõitlus =võitlus  (SgN  >vabadus+võitlus !11~09_S
48542	mõisnikel	mõisnike	mõisnik	25_S	PlAd	et	mõisnikel =mõisnike  (PlAd  >mõisnik !25_S
48544	erakord	kord	era+kord	22_S	SgN	et	erakord =kord  (SgN  >era+kord !22_S
48545	õigusliku	õigusliku	õiguslik	25_A	SgG	et	õigusliku =õigusliku  (SgG  >õiguslik !25_A
48569	jumalastruktuur	struktuur	jumala+struktuur	22_S	SgN	et	jumalastruktuur =struktuur  (SgN  >jumala+struktuur !22_S
48575	põllutööga	töö	põllu+töö	26_S	SgKom	et	põllutööga =töö  (SgKom  >põllu+töö !26_S
48578	maakondadega	maakonda	maakond	22_S	PlKom	et	maakondadega =maakonda  (PlKom  >maakond !22_S
48603	rahvakalendreid	kalendre	rahva+kalender	02_S	PlP	et	rahvakalendreid =kalendre  (PlP  >rahva+kalender !02_S
48605	gümnaasiume	gümnaasiume	gümnaasium	19_S	PlP	et	gümnaasiume =gümnaasiume  (PlP  >gümnaasium !19_S
48611	aadlitele	aadli	aadel	02_S	PlAll	et	aadlitele =aadli  (PlAll  >aadel !02_S
48613	valgustusideid	ide	valgustus+idee	26_S	PlP	et	valgustusideid =ide  (PlP  >valgustus+idee !26_S
48621	poolehoidjaid	hoidja	poole+hoidja	01_S	PlP	et	poolehoidjaid =hoidja  (PlP  >poole+hoidja !01_S
48622	väljaandjaks	andja	välja+andja	01_S	SgTr	et	väljaandjaks =andja  (SgTr  >välja+andja !01_S
48624	ülestõusul	tõusu	üles+tõus	22_S	SgAd	et	ülestõusul =tõusu  (SgAd  >üles+tõus !22_S
48625	rauaesemeid	eseme	raua+ese	04_S	PlP	et	rauaesemeid =eseme  (PlP  >raua+ese !04_S
48629	relve	relve	relv	22_S	PlP	et	relve =relve  (PlP  >relv !22_S
48632	pärisorjusesüsteemis	süsteemi	päris+orjuse+süsteem	22_S	SgIn	et	pärisorjusesüsteemis =süsteemi  (SgIn  >päris+orjuse+süsteem !22_S
48639	tarbeteosed	teose	tarbe+teos	09_S	PlN	et	tarbeteosed =teose  (PlN  >tarbe+teos !09_S
48644	puuehteid	ehte	puu+ehe	06_S	PlP	et	puuehteid =ehte  (PlP  >puu+ehe !06_S
48649	põtrade	põtra	põder	24_S	PlG	et	põtrade =põtra  (PlG  >põder !24_S
48654	täiustati	täiusta	täiustama	27_V	IndIpfIps	et	täiustati =täiusta  (IndIpfIps  >täiustama !27_V
48662	lauluselts	selts	laulu+selts	22_S	SgN	et	lauluselts =selts  (SgN  >laulu+selts !22_S
48664	emakeelseid	keelse	ema+keelne	02_A	PlP	et	emakeelseid =keelse  (PlP  >ema+keelne !02_A
48673	nunnid	nunni	nunn	22_S	PlN	et	nunnid =nunni  (PlN  >nunn !22_S
48680	teatrietendused	etenduse	teatri+etendus	11_S	PlN	et	teatrietendused =etenduse  (PlN  >teatri+etendus !11_S
48681	asjaarmastajad	armastaja	asja+armastaja	01_S	PlN	et	asjaarmastajad =armastaja  (PlN  >asja+armastaja !01_S
48690	karistati	karista	karistama	27_V	IndIpfIps	et	karistati =karista  (IndIpfIps  >karistama !27_V
48691	tulistati	tulista	tulistama	27_V	IndIpfIps	et	tulistati =tulista  (IndIpfIps  >tulistama !27_V
48693	keskvõimud	võimu	kesk+võim	22_S	PlN	et	keskvõimud =võimu  (PlN  >kesk+võim !22_S
48694	ametiühinguid	ühingu	ameti+ühing	02_S	PlP	et	ametiühinguid =ühingu  (PlP  >ameti+ühing !02_S
48695	riigijuhid	juhi	riigi+juht	22_S	PlN	et	riigijuhid =juhi  (PlN  >riigi+juht !22_S
48697	mahasurumine	surumine	maha+surumine	12_S	SgN	et	mahasurumine =surumine  (SgN  >maha+surumine !12_S
48700	rehaga	reha	reha	17_S	SgKom	et	rehaga =reha  (SgKom  >reha !17_S
48701	esemetega	eseme	ese	04_S	PlKom	et	esemetega =eseme  (PlKom  >ese !04_S
48720	toibuma	toibu	toibuma	27_V	Sup	et	toibuma =toibu  (Sup  >toibuma !27_V
48723	välisüliõpilasi	õpilasi	välis+üli+õpilane	12_S	PlP	et	välisüliõpilasi =õpilasi  (PlP  >välis+üli+õpilane !12_S
48738	hilisrauaaja	aja	hilis+raua+aeg	22_S	SgG	et	hilisrauaaja =aja  (SgG  >hilis+raua+aeg !22_S
48739	murranguks	murrangu	murrang	02_S	SgTr	et	murranguks =murrangu  (SgTr  >murrang !02_S
48742	tööjõujaotumiseni	jaotumise	töö+jõu+jaotumine	12_S	SgTer	et	tööjõujaotumiseni =jaotumise  (SgTer  >töö+jõu+jaotumine !12_S
48749	liivakääbastesse	kääbas	liiva+kääbas	07_S	PlIll	et	liivakääbastesse =kääbas  (PlIll  >liiva+kääbas !07_S
48752	muistses	muistse	muistne	02_A	SgIn	et	muistses =muistse  (SgIn  >muistne !02_A
48756	andamit	andami	andam	02_S	SgP	et	andamit =andami  (SgP  >andam !02_S
48762	harjumaalt	maa	harju+maa	26_S	SgAbl	et	harjumaalt =maa  (SgAbl  >harju+maa !26_S
48766	orjadel	orja	ori	24_S	PlAd	et	orjadel =orja  (PlAd  >ori !24_S
48777	trükised	trükise	trükis	09_S	PlN	et	trükised =trükise  (PlN  >trükis !09_S
48778	viljelusmajandus	majandus	viljelus+majandus	11_S	SgN	et	viljelusmajandus =majandus  (SgN  >viljelus+majandus !11_S
48784	kolmeviljasüsteem	süsteem	kolme+vilja+süsteem	22_S	SgN	et	kolmeviljasüsteem =süsteem  (SgN  >kolme+vilja+süsteem !22_S
48787	ümmargused	ümmarguse	ümmargune	12_A	PlN	et	ümmargused =ümmarguse  (PlN  >ümmargune !12_A
48793	allpõllundus	põllundus	all+põllundus	11_S	SgN	et	allpõllundus =põllundus  (SgN  >all+põllundus !11_S
48794	arvestati	arvesta	arvestama	27_V	IndIpfIps	et	arvestati =arvesta  (IndIpfIps  >arvestama !27_V
48512	esinemisoskus	oskus	esinemis+oskus	11~09_S	SgN	et	esinemisoskus =oskus  (SgN  >esinemis+oskus !11~09_S
48513	ministriteks	ministri	minister	02_S	PlTr	et	ministriteks =ministri  (PlTr  >minister !02_S
48516	rüütelkonnad	konna	rüütel+konn	22_S	PlN	et	rüütelkonnad =konna  (PlN  >rüütel+konn !22_S
48517	maapäevadel	päeva	maa+päev	22_S	PlAd	et	maapäevadel =päeva  (PlAd  >maa+päev !22_S
48521	aegadega	aega	aeg	22_S	PlKom	et	aegadega =aega  (PlKom  >aeg !22_S
48522	kariloomadega	looma	kari+loom	22_S	PlKom	et	kariloomadega =looma  (PlKom  >kari+loom !22_S
48527	vabadusvõistlus	võistlus	vabadus+võistlus	11~09_S	SgN	et	vabadusvõistlus =võistlus  (SgN  >vabadus+võistlus !11~09_S
48529	hõivama	hõiva	hõivama	29_V	Sup	et	hõivama =hõiva  (Sup  >hõivama !29_V
48530	vabadusvõistluse	võistluse	vabadus+võistlus	11~09_S	SgG	et	vabadusvõistluse =võistluse  (SgG  >vabadus+võistlus !11~09_S
48532	vastuseisjatelt	seisja	vastu+seisja	01_S	PlAbl	et	vastuseisjatelt =seisja  (PlAbl  >vastu+seisja !01_S
48533	sõjakogemust	kogemus	sõja+kogemus	11_S	SgP	et	sõjakogemust =kogemus  (SgP  >sõja+kogemus !11_S
48548	linnadele	linna	linn	22_S	PlAll	et	linnadele =linna  (PlAll  >linn !22_S
48549	manifestatsioonid	manifestatsiooni	manifestatsioon	22_S	PlN	et	manifestatsioonid =manifestatsiooni  (PlN  >manifestatsioon !22_S
48552	demokraadid	demokraadi	demokraat	22_S	PlN	et	demokraadid =demokraadi  (PlN  >demokraat !22_S
48559	metalltehased	tehase	metall+tehas	09_S	PlN	et	metalltehased =tehase  (PlN  >metall+tehas !09_S
48560	manufaktuur	manufaktuur	manufaktuur	22_S	SgN	et	manufaktuur =manufaktuur  (SgN  >manufaktuur !22_S
48572	läbindas	läbinda	läbindama	27_V	IndIpfSg3	et	läbindas =läbinda  (IndIpfSg3  >läbindama !27_V
48574	seisuslik	seisuslik	seisuslik	25_A	SgN	et	seisuslik =seisuslik  (SgN  >seisuslik !25_A
48576	lahingu	lahingu	lahing	02_S	SgG	et	lahingu =lahingu  (SgG  >lahing !02_S
48577	strateegiast	strateegia	strateegia	01_S	SgEl	et	strateegiast =strateegia  (SgEl  >strateegia !01_S
48588	näht	näht	näht	22_S	SgN	et	näht =näht  (SgN  >näht !22_S
48593	argivahendid	vahendi	argi+vahend	02_S	PlN	et	argivahendid =vahendi  (PlN  >argi+vahend !02_S
48599	märkmed	märkme	märge	05_S	PlN	et	märkmed =märkme  (PlN  >märge !05_S
48600	hilisrauaajas	aja	hilis+raua+aeg	22_S	SgIn	et	hilisrauaajas =aja  (SgIn  >hilis+raua+aeg !22_S
48601	momendist	momendi	moment	22_S	SgEl	et	momendist =momendi  (SgEl  >moment !22_S
48606	monarh	monarh	monarh	22_S	SgN	et	monarh =monarh  (SgN  >monarh !22_S
48607	kehtiks	kehti	kehtima	27_V	KndPrPs	et	kehtiks =kehti  (KndPrPs  >kehtima !27_V
48619	mõõduka	mõõduka	mõõdukas	02_A	SgG	et	mõõduka =mõõduka  (SgG  >mõõdukas !02_A
48627	kivikirstides	kirsti	kivi+kirst	22_S	PlIn	et	kivikirstides =kirsti  (PlIn  >kivi+kirst !22_S
48636	missioon	missioon	missioon	22_S	SgN	et	missioon =missioon  (SgN  >missioon !22_S
48646	metsandide	andi	mets+and	22_S	PlG	et	metsandide =andi  (PlG  >mets+and !22_S
48657	keskaegsed	aegse	kesk+aegne	02_A	PlN	et	keskaegsed =aegse  (PlN  >kesk+aegne !02_A
48658	religioosset	religioosse	religioosne	02_A	SgP	et	religioosset =religioosse  (SgP  >religioosne !02_A
48663	spordiselts	selts	spordi+selts	22_S	SgN	et	spordiselts =selts  (SgN  >spordi+selts !22_S
48665	survele	surve	surve	06_S	SgAll	et	survele =surve  (SgAll  >surve !06_S
48676	kündma	künd	kündma	34_V	Sup	et	kündma =künd  (Sup  >kündma !34_V
48677	aspektid	aspekti	aspekt	22_S	PlN	et	aspektid =aspekti  (PlN  >aspekt !22_S
48687	demonstratsioone	demonstratsioone	demonstratsioon	22_S	PlP	et	demonstratsioone =demonstratsioone  (PlP  >demonstratsioon !22_S
48709	keskplatsil	platsi	kesk+plats	22_S	SgAd	et	keskplatsil =platsi  (SgAd  >kesk+plats !22_S
48713	kasutuselevõtmisega	võtmise	kasutusele+võtmine	12?10_S	SgKom	et	kasutuselevõtmisega =võtmise  (SgKom  >kasutusele+võtmine !12?10_S
48719	maakoolidesse	kooli	maa+kool	22_S	PlIll	et	maakoolidesse =kooli  (PlIll  >maa+kool !22_S
48722	gümnaasiumides	gümnaasiumi	gümnaasium	19_S	PlIn	et	gümnaasiumides =gümnaasiumi  (PlIn  >gümnaasium !19_S
48724	välismaailmaga	ilma	välis+maa+ilm	22_S	SgKom	et	välismaailmaga =ilma  (SgKom  >välis+maa+ilm !22_S
48731	ajalehega	lehe	aja+leht	22_S	SgKom	et	ajalehega =lehe  (SgKom  >aja+leht !22_S
48743	raudesemeid	eseme	raud+ese	04_S	PlP	et	raudesemeid =eseme  (PlP  >raud+ese !04_S
48748	kalmetesse	kalme	kalme	06_S	PlIll	et	kalmetesse =kalme  (PlIll  >kalme !06_S
48751	härja	härja	härg	22_S	SgG	et	härja =härja  (SgG  >härg !22_S
48754	saare	saare	saar	13_S	SgG	et	saare =saare  (SgG  >saar !13_S
48765	juuriti	juuri	juurima	28_V	IndIpfIps	et	juuriti =juuri  (IndIpfIps  >juurima !28_V
48767	kirikupastoriks	pastori	kiriku+pastor	02_S	SgTr	et	kirikupastoriks =pastori  (SgTr  >kiriku+pastor !02_S
48768	segakooride	koori	sega+koor	22_S	PlG	et	segakooride =koori  (PlG  >sega+koor !22_S
48779	raudtööriistadeks	riista	raud+töö+riist	22_S	PlTr	et	raudtööriistadeks =riista  (PlTr  >raud+töö+riist !22_S
48547	rändama	rända	rändama	29_V	Sup	et	rändama =rända  (Sup  >rändama !29_V
48550	demonstratsioonid	demonstratsiooni	demonstratsioon	22_S	PlN	et	demonstratsioonid =demonstratsiooni  (PlN  >demonstratsioon !22_S
48555	eestimeelse	meelse	eesti+meelne	02_A	SgG	et	eestimeelse =meelse  (SgG  >eesti+meelne !02_A
48561	põllundusega	põllunduse	põllundus	11_S	SgKom	et	põllundusega =põllunduse  (SgKom  >põllundus !11_S
48565	uskusüsteem	süsteem	usku+süsteem	22_S	SgN	et	uskusüsteem =süsteem  (SgN  >usku+süsteem !22_S
48567	eellaseid	eellase	eellane	10_S	PlP	et	eellaseid =eellase  (PlP  >eellane !10_S
48587	vendlus	vendlus	vendlus	11~09_S	SgN	et	vendlus =vendlus  (SgN  >vendlus !11~09_S
48591	patriootilisi	patriootilisi	patriootiline	12_A	PlP	et	patriootilisi =patriootilisi  (PlP  >patriootiline !12_A
48592	argikultuur	kultuur	argi+kultuur	22_S	SgN	et	argikultuur =kultuur  (SgN  >argi+kultuur !22_S
48604	koraale	koraale	koraal	22_S	PlP	et	koraale =koraale  (PlP  >koraal !22_S
48609	religiooniõpetust	õpetus	religiooni+õpetus	11_S	SgP	et	religiooniõpetust =õpetus  (SgP  >religiooni+õpetus !11_S
48610	aadel	aadel	aadel	02_S	SgN	et	aadel =aadel  (SgN  >aadel !02_S
48612	aadlite	aadli	aadel	02_S	PlG	et	aadlite =aadli  (PlG  >aadel !02_S
48614	mõisatesse	mõisa	mõis	02_S	PlIll	et	mõisatesse =mõisa  (PlIll  >mõis !02_S
48615	kooliõpetajatena	õpetaja	kooli+õpetaja	01_S	PlEs	et	kooliõpetajatena =õpetaja  (PlEs  >kooli+õpetaja !01_S
48617	vabadusmõtet	mõte	vabadus+mõte	06_S	SgP	et	vabadusmõtet =mõte  (SgP  >vabadus+mõte !06_S
48620	kirgliku	kirgliku	kirglik	25_A	SgG	et	kirgliku =kirgliku  (SgG  >kirglik !25_A
48630	viljamajandus	majandus	vilja+majandus	11_S	SgN	et	viljamajandus =majandus  (SgN  >vilja+majandus !11_S
48633	passikorraldus	korraldus	passi+korraldus	11_S	SgN	et	passikorraldus =korraldus  (SgN  >passi+korraldus !11_S
48635	väikerahva	rahva	väike+rahvas	07_S	SgG	et	väikerahva =rahva  (SgG  >väike+rahvas !07_S
48638	rootsiajaks	aja	rootsi+aeg	22_S	SgTr	et	rootsiajaks =aja  (SgTr  >rootsi+aeg !22_S
48640	algkooliõpikud	õpiku	alg+kooli+õpik	02_S	PlN	et	algkooliõpikud =õpiku  (PlN  >alg+kooli+õpik !02_S
48641	rahvahariduse	hariduse	rahva+haridus	11_S	SgG	et	rahvahariduse =hariduse  (SgG  >rahva+haridus !11_S
48642	leidudega	leidu	leid	22_S	PlKom	et	leidudega =leidu  (PlKom  >leid !22_S
48643	muististe	muistis	muistis	09_S	PlG	et	muististe =muistis  (PlG  >muistis !09_S
48647	põhjapõtru	põtru	põhja+põder	24_S	PlP	et	põhjapõtru =põtru  (PlP  >põhja+põder !24_S
48653	muinaseestlased	eestlase	muinas+eestlane	12?10_S	PlN	et	muinaseestlased =eestlase  (PlN  >muinas+eestlane !12?10_S
48655	viljeluspõllumajandusele	majanduse	viljelus+põllu+majandus	11_S	SgAll	et	viljeluspõllumajandusele =majanduse  (SgAll  >viljelus+põllu+majandus !11_S
48656	põldudel	põldu	põld	22_S	PlAd	et	põldudel =põldu  (PlAd  >põld !22_S
48659	eludesse	elu	elu	17_S	PlIll	et	eludesse =elu  (PlIll  >elu !17_S
48667	eliit	eliit	eliit	22_S	SgN	et	eliit =eliit  (SgN  >eliit !22_S
48672	ebakorduv	korduv	eba+korduv	02_A	SgN	et	ebakorduv =korduv  (SgN  >eba+korduv !02_A
48674	esialgul	algu	esi+alg	22_S	SgAd	et	esialgul =algu  (SgAd  >esi+alg !22_S
48682	rahvusärkamise	ärkamise	rahvus+ärkamine	12_S	SgG	et	rahvusärkamise =ärkamise  (SgG  >rahvus+ärkamine !12_S
48688	taotleti	taotle	taotlema	27_V	IndIpfIps	et	taotleti =taotle  (IndIpfIps  >taotlema !27_V
48689	mässumeelseid	meelse	mässu+meelne	02_A	PlP	et	mässumeelseid =meelse  (PlP  >mässu+meelne !02_A
48692	karistusrühmad	rühma	karistus+rühm	22_S	PlN	et	karistusrühmad =rühma  (PlN  >karistus+rühm !22_S
48702	sadamalinnades	linna	sadama+linn	22_S	PlIn	et	sadamalinnades =linna  (PlIn  >sadama+linn !22_S
48704	sepad	sepa	sepp	22_S	PlN	et	sepad =sepa  (PlN  >sepp !22_S
48708	meistriteks	meistri	meister	02_S	PlTr	et	meistriteks =meistri  (PlTr  >meister !02_S
48710	toodetega	toode	toode	06_S	PlKom	et	toodetega =toode  (PlKom  >toode !06_S
48716	leidlik	leidlik	leidlik	25_A	SgN	et	leidlik =leidlik  (SgN  >leidlik !25_A
48717	loomapidamisega	pidamise	looma+pidamine	12_S	SgKom	et	loomapidamisega =pidamise  (SgKom  >looma+pidamine !12_S
48728	päriseksostmisega	ostmise	päri+seks+ostmine	12?10_S	SgKom	et	päriseksostmisega =ostmise  (SgKom  >päri+seks+ostmine !12?10_S
48729	raharendile	rendi	raha+rent	22_S	SgAll	et	raharendile =rendi  (SgAll  >raha+rent !22_S
48730	kõnede	kõne	kõne	16_S	PlG	et	kõnede =kõne  (PlG  >kõne !16_S
48732	taotles	taotle	taotlema	27_V	IndIpfSg3	et	taotles =taotle  (IndIpfSg3  >taotlema !27_V
48734	läbirääkimisi	rääkimisi	läbi+rääkimine	12_S	PlP	et	läbirääkimisi =rääkimisi  (PlP  >läbi+rääkimine !12_S
48745	viikingiajal	aja	viikingi+aeg	22_S	SgAd	et	viikingiajal =aja  (SgAd  >viikingi+aeg !22_S
48746	talivili	vili	tali+vili	24_S	SgN	et	talivili =vili  (SgN  >tali+vili !24_S
48755	talupojakultuur	kultuur	talu+poja+kultuur	22_S	SgN	et	talupojakultuur =kultuur  (SgN  >talu+poja+kultuur !22_S
48595	pingutama	pinguta	pingutama	27_V	Sup	et	pingutama =pinguta  (Sup  >pingutama !27_V
48596	perekondade	perekonda	perekond	22_S	PlG	et	perekondade =perekonda  (PlG  >perekond !22_S
48597	ajalooperiood	periood	aja+loo+periood	22_S	SgN	et	ajalooperiood =periood  (SgN  >aja+loo+periood !22_S
48598	tõendid	tõendi	tõend	02_S	PlN	et	tõendid =tõendi  (PlN  >tõend !02_S
48602	kihelkondadesse	kihelkonda	kihelkond	22_S	PlIll	et	kihelkondadesse =kihelkonda  (PlIll  >kihelkond !22_S
48608	asehalduskord	kord	ase+haldus+kord	22_S	SgN	et	asehalduskord =kord  (SgN  >ase+haldus+kord !22_S
48616	estofiilidena	estofiili	estofiil	22_S	PlEs	et	estofiilidena =estofiili  (PlEs  >estofiil !22_S
48618	targu	targu	targu	41_D	ID	et	targu =targu  (ID  >targu !41_D
48628	kirstidesse	kirsti	kirst	22_S	PlIll	et	kirstidesse =kirsti  (PlIll  >kirst !22_S
48631	maksmisvahendina	vahendi	maksmis+vahend	02_S	SgEs	et	maksmisvahendina =vahendi  (SgEs  >maksmis+vahend !02_S
48634	vasttärganud	tärganu	vast+tärganu	01_S	PlN	et	vasttärganud =tärganu  (PlN  >vast+tärganu !01_S
48637	rootsiaeg	aeg	rootsi+aeg	22_S	SgN	et	rootsiaeg =aeg  (SgN  >rootsi+aeg !22_S
48650	hõimude	hõimu	hõim	22_S	PlG	et	hõimude =hõimu  (PlG  >hõim !22_S
48660	ühiskonnateadlane	teadlane	ühis+konna+teadlane	12?10_S	SgN	et	ühiskonnateadlane =teadlane  (SgN  >ühis+konna+teadlane !12?10_S
48666	eluandel	ande	elu+anne	06_S	SgAd	et	eluandel =ande  (SgAd  >elu+anne !06_S
48669	volikoogu	koogu	voli+kook	22_S	SgG	et	volikoogu =koogu  (SgG  >voli+kook !22_S
48670	juurduma	juurdu	juurduma	27_V	Sup	et	juurduma =juurdu  (Sup  >juurduma !27_V
48671	eset	ese	ese	04_S	SgP	et	eset =ese  (SgP  >ese !04_S
48675	kalapüükidega	püüki	kala+püük	22_S	PlKom	et	kalapüükidega =püüki  (PlKom  >kala+püük !22_S
48678	seppade	seppa	sepp	22_S	PlG	et	seppade =seppa  (PlG  >sepp !22_S
48679	aktiivses	aktiivse	aktiivne	02_A	SgIn	et	aktiivses =aktiivse  (SgIn  >aktiivne !02_A
48683	õigustas	õigusta	õigustama	27_V	IndIpfSg3	et	õigustas =õigusta  (IndIpfSg3  >õigustama !27_V
48684	ülemkihtide	kihti	ülem+kiht	22_S	PlG	et	ülemkihtide =kihti  (PlG  >ülem+kiht !22_S
48685	maapuuduse	puuduse	maa+puudus	11~09_S	SgG	et	maapuuduse =puuduse  (SgG  >maa+puudus !11~09_S
48686	privileegide	privileegi	privileeg	22_S	PlG	et	privileegide =privileegi  (PlG  >privileeg !22_S
48696	repressioone	repressioone	repressioon	22_S	PlP	et	repressioone =repressioone  (PlP  >repressioon !22_S
48698	võrdleme	võrdle	võrdlema	30_V	IndPrPl1	et	võrdleme =võrdle  (IndPrPl1  >võrdlema !30_V
48705	kultuurkihtide	kihti	kultuur+kiht	22_S	PlG	et	kultuurkihtide =kihti  (PlG  >kultuur+kiht !22_S
48706	mingisugusel	suguse	mingi+sugune	10_P	SgAd	et	mingisugusel =suguse  (SgAd  >mingi+sugune !10_P
48707	ametil	ameti	amet	02_S	SgAd	et	ametil =ameti  (SgAd  >amet !02_S
48711	merelt	mere	meri	20_S	SgAbl	et	merelt =mere  (SgAbl  >meri !20_S
48715	ülejäägid	jäägi	üle+jääk	22_S	PlN	et	ülejäägid =jäägi  (PlN  >üle+jääk !22_S
48721	talviti	talviti	talviti	41_D	ID	et	talviti =talviti  (ID  >talviti !41_D
48727	määrused	määruse	määrus	11~09_S	PlN	et	määrused =määruse  (PlN  >määrus !11~09_S
48735	rauaajaks	aja	raua+aeg	22_S	SgTr	et	rauaajaks =aja  (SgTr  >raua+aeg !22_S
48744	hajali	hajali	hajali	41_DA	ID	et	hajali =hajali  (ID  >hajali !41_DA
48750	ehete	ehe	ehe	06_S	PlG	et	ehete =ehe  (PlG  >ehe !06_S
48753	vabadusvõitluses	võitluse	vabadus+võitlus	11~09_S	SgIn	et	vabadusvõitluses =võitluse  (SgIn  >vabadus+võitlus !11~09_S
48757	kümnis	kümnis	kümnis	11~09_S	SgN	et	kümnis =kümnis  (SgN  >kümnis !11~09_S
48758	andamiks	andami	andam	02_S	SgTr	et	andamiks =andami  (SgTr  >andam !02_S
48770	erandkorras	korra	erand+kord	22_S	SgIn	et	erandkorras =korra  (SgIn  >erand+kord !22_S
48782	kaheväljasüsteemiks	süsteemi	kahe+välja+süsteem	22_S	SgTr	et	kaheväljasüsteemiks =süsteemi  (SgTr  >kahe+välja+süsteem !22_S
48786	talirukis	rukis	tali+rukis	07_S	SgN	et	talirukis =rukis  (SgN  >tali+rukis !07_S
48790	võidukat	võiduka	võidukas	02_A	SgP	et	võidukat =võiduka  (SgP  >võidukas !02_A
48798	järvesaartele	saar	järve+saar	13_S	PlAll	et	järvesaartele =saar  (PlAll  >järve+saar !13_S
48800	alistada	alista	alistama	27_V	Inf	et	alistada =alista  (Inf  >alistama !27_V
48804	rootsile	rootsi	roots	22_S	SgAll	et	rootsile =rootsi  (SgAll  >roots !22_S
48808	maaviljelus	viljelus	maa+viljelus	11_S	SgN	et	maaviljelus =viljelus  (SgN  >maa+viljelus !11_S
48817	prantslane	prantslane	prantslane	12?10_S	SgN	et	prantslane =prantslane  (SgN  >prantslane !12?10_S
48822	loodusrahvaid	rahva	loodus+rahvas	07_S	PlP	et	loodusrahvaid =rahva  (PlP  >loodus+rahvas !07_S
48823	tegelaskujuks	kuju	tegelas+kuju	17_S	SgTr	et	tegelaskujuks =kuju  (SgTr  >tegelas+kuju !17_S
48833	kaaren	kaaren	kaaren	02_S	SgN	et	kaaren =kaaren  (SgN  >kaaren !02_S
48845	maailmapilt	pilt	maa+ilma+pilt	22_S	SgN	et	maailmapilt =pilt  (SgN  >maa+ilma+pilt !22_S
48648	hõimudel	hõimu	hõim	22_S	PlAd	et	hõimudel =hõimu  (PlAd  >hõim !22_S
48651	peatuspaigad	paiga	peatus+paik	22_S	PlN	et	peatuspaigad =paiga  (PlN  >peatus+paik !22_S
48652	kalapüüdmist	püüdmis	kala+püüdmine	12?10_S	SgP	et	kalapüüdmist =püüdmis  (SgP  >kala+püüdmine !12?10_S
48661	pedagoog	pedagoog	pedagoog	22_S	SgN	et	pedagoog =pedagoog  (SgN  >pedagoog !22_S
48668	kauptöötajad	töötaja	kaup+töötaja	01_S	PlN	et	kauptöötajad =töötaja  (PlN  >kaup+töötaja !01_S
48699	nooled	noole	nool	13_S	PlN	et	nooled =noole  (PlN  >nool !13_S
48703	ost	ost	ost	22_S	SgN	et	ost =ost  (SgN  >ost !22_S
48712	üleminemisel	minemise	üle+minemine	12_S	SgAd	et	üleminemisel =minemise  (SgAd  >üle+minemine !12_S
48714	põllunduses	põllunduse	põllundus	11_S	SgIn	et	põllunduses =põllunduse  (SgIn  >põllundus !11_S
48718	ebavajalikuks	vajaliku	eba+vajalik	25_A	SgTr	et	ebavajalikuks =vajaliku  (SgTr  >eba+vajalik !25_A
48725	sadamaid	sadama	sadam	02_S	PlP	et	sadamaid =sadama  (PlP  >sadam !02_S
48726	maksusüsteem	süsteem	maksu+süsteem	22_S	SgN	et	maksusüsteem =süsteem  (SgN  >maksu+süsteem !22_S
48733	mõisnikega	mõisnike	mõisnik	25_S	PlKom	et	mõisnikega =mõisnike  (PlKom  >mõisnik !25_S
48736	rauaajaks	aja	raua+aeg	22_S	SgTr	et	rauaajaks =aja  (SgTr  >raua+aeg !22_S
48737	hilisrauaajaks	aja	hilis+raua+aeg	22_S	SgTr	et	hilisrauaajaks =aja  (SgTr  >hilis+raua+aeg !22_S
48740	raudesemed	eseme	raud+ese	04_S	PlN	et	raudesemed =eseme  (PlN  >raud+ese !04_S
48741	eestialadel	ala	eesti+ala	17_S	PlAd	et	eestialadel =ala  (PlAd  >eesti+ala !17_S
48747	suvivili	vili	suvi+vili	24_S	SgN	et	suvivili =vili  (SgN  >suvi+vili !24_S
48759	kummardamas	kummarda	kummardama	27_V	SupIn	et	kummardamas =kummarda  (SupIn  >kummardama !27_V
48760	maausu	usu	maa+usk	22_S	SgG	et	maausu =usu  (SgG  >maa+usk !22_S
48772	rahatööle	töö	raha+töö	26_S	SgAll	et	rahatööle =töö  (SgAll  >raha+töö !26_S
48773	mõisamoonakad	moonaka	mõisa+moonakas	02_S	PlN	et	mõisamoonakad =moonaka  (PlN  >mõisa+moonakas !02_S
48774	rahaabiga	abi	raha+abi	17_S	SgKom	et	rahaabiga =abi  (SgKom  >raha+abi !17_S
48775	filosoof	filosoof	filosoof	22_S	SgN	et	filosoof =filosoof  (SgN  >filosoof !22_S
48781	üheväljasüsteem	süsteem	ühe+välja+süsteem	22_S	SgN	et	üheväljasüsteem =süsteem  (SgN  >ühe+välja+süsteem !22_S
48783	suvirukist	rukis	suvi+rukis	07_S	SgP	et	suvirukist =rukis  (SgP  >suvi+rukis !07_S
48796	tööriistadele	riista	töö+riist	22_S	PlAll	et	tööriistadele =riista  (PlAll  >töö+riist !22_S
48799	liitlasi	liitlasi	liitlane	12_S	PlP	et	liitlasi =liitlasi  (PlP  >liitlane !12_S
48807	3-e			xx_Q	PlP	et	-e =  (PlP  > !xx_Q
48814	kentsakad	kentsaka	kentsakas	02_A	PlN	et	kentsakad =kentsaka  (PlN  >kentsakas !02_A
48815	malevit	malevi	malev	02_S	SgP	et	malevit =malevi  (SgP  >malev !02_S
48825	sisemise	sisemise	sisemine	12_A	SgG	et	sisemise =sisemise  (SgG  >sisemine !12_A
48829	rahvalikke	rahvalikke	rahvalik	25_A	PlP	et	rahvalikke =rahvalikke  (PlP  >rahvalik !25_A
48842	rahvuslaseks	rahvuslase	rahvuslane	12_S	SgTr	et	rahvuslaseks =rahvuslase  (SgTr  >rahvuslane !12_S
48843	patrioote	patrioote	patrioot	22_S	PlP	et	patrioote =patrioote  (PlP  >patrioot !22_S
48847	orjastati	orjasta	orjastama	27_V	IndIpfIps	et	orjastati =orjasta  (IndIpfIps  >orjastama !27_V
48863	kirpe	kirpe	kirp	22_S	PlP	et	kirpe =kirpe  (PlP  >kirp !22_S
48864	toppima	toppi	toppima	28_V	Sup	et	toppima =toppi  (Sup  >toppima !28_V
48865	uskumuse	uskumuse	uskumus	11_S	SgG	et	uskumuse =uskumuse  (SgG  >uskumus !11_S
48871	austusväärsed	väärse	austus+väärne	02_A	PlN	et	austusväärsed =väärse  (PlN  >austus+väärne !02_A
48878	prantslasest	prantslase	prantslane	12?10_S	SgEl	et	prantslasest =prantslase  (SgEl  >prantslane !12?10_S
48880	jäetakse	jäe	jätma	35_V	IndPrIps	et	jäetakse =jäe  (IndPrIps  >jätma !35_V
48882	võideldes	võidel	võitlema	30_V	Ger	et	võideldes =võidel  (Ger  >võitlema !30_V
48885	eneseirooniat	iroonia	enese+iroonia	01_S	SgP	et	eneseirooniat =iroonia  (SgP  >enese+iroonia !01_S
48887	mõningatele	mõninga	mõningas	02_P	PlAll	et	mõningatele =mõninga  (PlAll  >mõningas !02_P
48895	mäeots	ots	mäe+ots	23?22_S	SgN	et	mäeots =ots  (SgN  >mäe+ots !23?22_S
48904	dokumentaalfilmiga	filmi	dokumentaal+film	22_S	SgKom	et	dokumentaalfilmiga =filmi  (SgKom  >dokumentaal+film !22_S
48916	13sajandil	sajandi	sajand	02_S	SgAd	et	sajandil =sajandi  (SgAd  >sajand !02_S
48917	naeravad	naera	naerma	33_V	IndPrPl3	et	naeravad =naera  (IndPrPl3  >naerma !33_V
48918	nalju	nalju	nali	24_S	PlP	et	nalju =nalju  (PlP  >nali !24_S
48920	humoorikast	humoorika	humoorikas	02_A	SgEl	et	humoorikast =humoorika  (SgEl  >humoorikas !02_A
48921	tapariistu	riistu	tapa+riist	22_S	PlP	et	tapariistu =riistu  (PlP  >tapa+riist !22_S
48923	vägevatena	vägeva	vägev	02_A	PlEs	et	vägevatena =vägeva  (PlEs  >vägev !02_A
48761	järgima	järgi	järgima	27_V	Sup	et	järgima =järgi  (Sup  >järgima !27_V
48763	rängad	ränga	ränk	22_A	PlN	et	rängad =ränga  (PlN  >ränk !22_A
48764	koormised	koormise	koormis	11~09_S	PlN	et	koormised =koormise  (PlN  >koormis !11~09_S
48769	teorent	rent	teo+rent	22_S	SgN	et	teorent =rent  (SgN  >teo+rent !22_S
48771	raharendiga	rendi	raha+rent	22_S	SgKom	et	raharendiga =rendi  (SgKom  >raha+rent !22_S
48776	võidukäik	käik	võidu+käik	22_S	SgN	et	võidukäik =käik  (SgN  >võidu+käik !22_S
48789	hauas	haua	haud	22_S	SgIn	et	hauas =haua  (SgIn  >haud !22_S
48801	liivlasi	liivlasi	liivlane	12_S	PlP	et	liivlasi =liivlasi  (PlP  >liivlane !12_S
48811	eurooplaseks	eurooplase	eurooplane	12?10_S	SgTr	et	eurooplaseks =eurooplase  (SgTr  >eurooplane !12?10_S
48816	mitteeestikeelsele	keelse	mitte+eesti+keelne	02_A	SgAll	et	mitteeestikeelsele =keelse  (SgAll  >mitte+eesti+keelne !02_A
48818	publikust	publiku	publik	02_S	SgEl	et	publikust =publiku  (SgEl  >publik !02_S
48826	intriigide	intriigi	intriig	22_S	PlG	et	intriigide =intriigi  (PlG  >intriig !22_S
48835	tõestisündinud	sündinu	tõesti+sündinu	01_S	PlN	et	tõestisündinud =sündinu  (PlN  >tõesti+sündinu !01_S
48836	ajalooallikad	allika	aja+loo+allikas	02_S	PlN	et	ajalooallikad =allika  (PlN  >aja+loo+allikas !02_S
48839	urule	uru	urg	22_S	SgAll	et	urule =uru  (SgAll  >urg !22_S
48841	naaseb	naase	naasma	32_V	IndPrSg3	et	naaseb =naase  (IndPrSg3  >naasma !32_V
48846	sõjapidajatena	pidaja	sõja+pidaja	01_S	PlEs	et	sõjapidajatena =pidaja  (PlEs  >sõja+pidaja !01_S
48851	ülemäära	ülemäära	üle+määra	41_D	ID	et	ülemäära =ülemäära  (ID  >üle+määra !41_D
48854	varastatakse	varasta	varastama	27_V	IndPrIps	et	varastatakse =varasta  (IndPrIps  >varastama !27_V
48858	konnavarudest	varu	konna+varu	17_S	PlEl	et	konnavarudest =varu  (PlEl  >konna+varu !17_S
48866	ütlusi	ütlusi	ütlus	11_S	PlP	et	ütlusi =ütlusi  (PlP  >ütlus !11_S
48883	möödudes	möödu	mööduma	27_V	Ger	et	möödudes =möödu  (Ger  >mööduma !27_V
48884	ameeriklastele	ameeriklas	ameeriklane	12_S	PlAll	et	ameeriklastele =ameeriklas  (PlAll  >ameeriklane !12_S
48888	rahvustel	rahvus	rahvus	11~09_S	PlAd	et	rahvustel =rahvus  (PlAd  >rahvus !11~09_S
48893	hoiatada	hoiata	hoiatama	27_V	Inf	et	hoiatada =hoiata  (Inf  >hoiatama !27_V
48898	mõningased	mõningase	mõningane	12_P	PlN	et	mõningased =mõningase  (PlN  >mõningane !12_P
48899	naerdes	naer	naerma	33_V	Ger	et	naerdes =naer  (Ger  >naerma !33_V
48905	uutele	uu	uus	14_A	PlAll	et	uutele =uu  (PlAll  >uus !14_A
48906	vaatenurkadele	nurka	vaate+nurk	22_S	PlAll	et	vaatenurkadele =nurka  (PlAll  >vaate+nurk !22_S
48910	urust	uru	urg	22_S	SgEl	et	urust =uru  (SgEl  >urg !22_S
48912	töörabamise	rabamise	töö+rabamine	12_S	SgG	et	töörabamise =rabamise  (SgG  >töö+rabamine !12_S
48914	valusa	valusa	valus	02_A	SgG	et	valusa =valusa  (SgG  >valus !02_A
48919	inimtüüpide	tüüpi	inim+tüüp	22_S	PlG	et	inimtüüpide =tüüpi  (PlG  >inim+tüüp !22_S
48924	euroopalikele	euroopalike	euroopalik	25_A	PlAll	et	euroopalikele =euroopalike  (PlAll  >euroopalik !25_A
48927	valmistage	valmista	valmistama	27_V	ImpPrPl2	et	valmistage =valmista  (ImpPrPl2  >valmistama !27_V
48929	valmistatakse	valmista	valmistama	27_V	IndPrIps	et	valmistatakse =valmista  (IndPrIps  >valmistama !27_V
48933	kiibid	kiibi	kiipima	28_V	IndPrSg2	et	kiibid =kiibi  (IndPrSg2  >kiipima !28_V
48949	kelder	kelder	kelder	02_S	SgN	et	kelder =kelder  (SgN  >kelder !02_S
48950	kelderis	kelderi	kelder	02_S	SgIn	et	kelderis =kelderi  (SgIn  >kelder !02_S
48953	põrandaküte	küte	põranda+küte	06_S	SgN	et	põrandaküte =küte  (SgN  >põranda+küte !06_S
48958	soojendama	soojenda	soojendama	27_V	Sup	et	soojendama =soojenda  (Sup  >soojendama !27_V
48960	paigaldan	paigalda	paigaldama	27_V	IndPrSg1	et	paigaldan =paigalda  (IndPrSg1  >paigaldama !27_V
48961	wc-pott	pott	wc-pott	22_S	SgN	et	wc-pott =pott  (SgN  >wc-pott !22_S
48970	isolatsiooniga	isolatsiooni	isolatsioon	22_S	SgKom	et	isolatsiooniga =isolatsiooni  (SgKom  >isolatsioon !22_S
48989	kuumutada	kuumuta	kuumutama	27_V	Inf	et	kuumutada =kuumuta  (Inf  >kuumutama !27_V
48992	haigestab	haigesta	haigestama	27_V	IndPrSg3	et	haigestab =haigesta  (IndPrSg3  >haigestama !27_V
49001	kihutama	kihuta	kihutama	27_V	Sup	et	kihutama =kihuta  (Sup  >kihutama !27_V
49002	taimer	taimer	taimer	02_S	SgN	et	taimer =taimer  (SgN  >taimer !02_S
49012	ruume	ruume	ruum	22_S	PlP	et	ruume =ruume  (PlP  >ruum !22_S
49020	vood	voo	voog	22_S	PlN	et	vood =voo  (PlN  >voog !22_S
49027	mõõteriistad	riista	mõõte+riist	22_S	PlN	et	mõõteriistad =riista  (PlN  >mõõte+riist !22_S
49030	rebis	rebi	rebima	27_V	IndIpfSg3	et	rebis =rebi  (IndIpfSg3  >rebima !27_V
49034	30-aastat	aasta	-aasta	01_S	SgP	et	-aastat =aasta  (SgP  >-aasta !01_S
48780	tarbe-	tarbe	tarve	06_S	SgG	et	tarbe- =tarbe  (SgG  >tarve !06_S
48785	talirukist	rukis	tali+rukis	07_S	SgP	et	talirukist =rukis  (SgP  >tali+rukis !07_S
48788	kivihunnikutesse	hunniku	kivi+hunnik	02_S	PlIll	et	kivihunnikutesse =hunniku  (PlIll  >kivi+hunnik !02_S
48791	asulate	asula	asula	01_S	PlG	et	asulate =asula  (PlG  >asula !01_S
48792	jahiti	jahi	jahtima	28_V	IndIpfIps	et	jahiti =jahi  (IndIpfIps  >jahtima !28_V
48802	baltirahvaid	rahva	balti+rahvas	07_S	PlP	et	baltirahvaid =rahva  (PlP  >balti+rahvas !07_S
48803	rüütlid	rüütli	rüütel	02_S	PlN	et	rüütlid =rüütli  (PlN  >rüütel !02_S
48805	ettekäändeks	käände	ette+kääne	06_S	SgTr	et	ettekäändeks =käände  (SgTr  >ette+kääne !06_S
48810	malev	malev	malev	02_S	SgN	et	malev =malev  (SgN  >malev !02_S
48821	muistseid	muistse	muistne	02_A	PlP	et	muistseid =muistse  (PlP  >muistne !02_A
48824	noormehega	mehe	noor+mees	13_S	SgKom	et	noormehega =mehe  (SgKom  >noor+mees !13_S
48831	minusugustele	sugus	minu+sugune	10_A	PlAll	et	minusugustele =sugus  (PlAll  >minu+sugune !10_A
48834	kaer	kaer	kaer	23?22_S	SgN	et	kaer =kaer  (SgN  >kaer !23?22_S
48837	ajaloofaktide	fakti	aja+loo+fakt	22_S	PlG	et	ajaloofaktide =fakti  (PlG  >aja+loo+fakt !22_S
48838	ristirüütel	rüütel	risti+rüütel	02_S	SgN	et	ristirüütel =rüütel  (SgN  >risti+rüütel !02_S
48840	eestlasena	eestlase	eestlane	12?10_S	SgEs	et	eestlasena =eestlase  (SgEs  >eestlane !12?10_S
48844	taluda	talu	taluma	27_V	Inf	et	taluda =talu  (Inf  >taluma !27_V
48853	koolijütsile	jütsi	kooli+jüts	22_S	SgAll	et	koolijütsile =jütsi  (SgAll  >kooli+jüts !22_S
48860	malevat	maleva	malev	02_S	SgP	et	malevat =maleva  (SgP  >malev !02_S
48862	jootma	joot	jootma	34_V	Sup	et	jootma =joot  (Sup  >jootma !34_V
48868	kultuuriajakiri	kiri	kultuuri+aja+kiri	24_S	SgN	et	kultuuriajakiri =kiri  (SgN  >kultuuri+aja+kiri !24_S
48870	võitlusvaim	vaim	võitlus+vaim	22_S	SgN	et	võitlusvaim =vaim  (SgN  >võitlus+vaim !22_S
48900	naerame	naera	naerma	33_V	IndPrPl1	et	naerame =naera  (IndPrPl1  >naerma !33_V
48903	rõõmsameelseid	meelse	rõõmsa+meelne	02_A	PlP	et	rõõmsameelseid =meelse  (PlP  >rõõmsa+meelne !02_A
48915	rüütliga	rüütli	rüütel	02_S	SgKom	et	rüütliga =rüütli  (SgKom  >rüütel !02_S
48932	mikroskeemid	skeemi	mikro+skeem	22_S	PlN	et	mikroskeemid =skeemi  (PlN  >mikro+skeem !22_S
48936	laevade	laeva	laev	22_S	PlG	et	laevade =laeva  (PlG  >laev !22_S
48939	elektronkellad	kella	elektron+kell	22_S	PlN	et	elektronkellad =kella  (PlN  >elektron+kell !22_S
48942	pesumisruumis	ruumi	pesu+mis+ruum	22_S	SgIn	et	pesumisruumis =ruumi  (SgIn  >pesu+mis+ruum !22_S
48952	betoneerin	betoneeri	betoneerima	28_V	IndPrSg1	et	betoneerin =betoneeri  (IndPrSg1  >betoneerima !28_V
48954	krohvin	krohvi	krohvima	28_V	IndPrSg1	et	krohvin =krohvi  (IndPrSg1  >krohvima !28_V
48955	pahteldan	pahtelda	pahteldama	27_V	IndPrSg1	et	pahteldan =pahtelda  (IndPrSg1  >pahteldama !27_V
48959	külalistetoas	toa	külaliste+tuba	18_S	SgIn	et	külalistetoas =toa  (SgIn  >külaliste+tuba !18_S
48963	kiviseinad	seina	kivi+sein	23?22_S	PlN	et	kiviseinad =seina  (PlN  >kivi+sein !23?22_S
48964	eksplikatsioon	eksplikatsioon	eksplikatsioon	22_S	SgN	et	eksplikatsioon =eksplikatsioon  (SgN  >eksplikatsioon !22_S
48968	paigaldada	paigalda	paigaldama	27_V	Inf	et	paigaldada =paigalda  (Inf  >paigaldama !27_V
48969	sisustada	sisusta	sisustama	27_V	Inf	et	sisustada =sisusta  (Inf  >sisustama !27_V
48971	isoleeritakse	isoleeri	isoleerima	28_V	IndPrIps	et	isoleeritakse =isoleeri  (IndPrIps  >isoleerima !28_V
48972	toaga	toa	tuba	18_S	SgKom	et	toaga =toa  (SgKom  >tuba !18_S
48979	välimuses	välimuse	välimus	11_S	SgIn	et	välimuses =välimuse  (SgIn  >välimus !11_S
48980	paigaldatakse	paigalda	paigaldama	27_V	IndPrIps	et	paigaldatakse =paigalda  (IndPrIps  >paigaldama !27_V
48983	kamin	kamin	kamin	02_S	SgN	et	kamin =kamin  (SgN  >kamin !02_S
48985	varustatakse	varusta	varustama	27_V	IndPrIps	et	varustatakse =varusta  (IndPrIps  >varustama !27_V
49005	plaadimistöid	tö	plaadi+mis+töö	26_S	PlP	et	plaadimistöid =tö  (PlP  >plaadi+mis+töö !26_S
49006	laudadest	lauda	laud	22_S	PlEl	et	laudadest =lauda  (PlEl  >laud !22_S
49010	soojustada	soojusta	soojustama	27_V	Inf	et	soojustada =soojusta  (Inf  >soojustama !27_V
49014	müüre	müüre	müür	22_S	PlP	et	müüre =müüre  (PlP  >müür !22_S
49016	piljardi	piljardi	piljard	02_S	SgG	et	piljardi =piljardi  (SgG  >piljard !02_S
49023	puhketoa	toa	puhke+tuba	18_S	SgG	et	puhketoa =toa  (SgG  >puhke+tuba !18_S
49026	hantelid	hanteli	hantel	02_S	PlN	et	hantelid =hanteli  (PlN  >hantel !02_S
49035	sülle	sülle	süli	20_S	SgAdt	et	sülle =sülle  (SgAdt  >süli !20_S
49039	varguse	varguse	vargus	11~09_S	SgG	et	varguse =varguse  (SgG  >vargus !11~09_S
49048	terviselt	tervise	tervis	09~11_S	SgAbl	et	terviselt =tervise  (SgAbl  >tervis !09~11_S
48795	edaspidisel	pidise	edas+pidine	10_A	SgAd	et	edaspidisel =pidise  (SgAd  >edas+pidine !10_A
48797	rünnakuid	rünnaku	rünnak	02_S	PlP	et	rünnakuid =rünnaku  (PlP  >rünnak !02_S
48806	vastuhakkamist	hakkamis	vastu+hakkamine	12_S	SgP	et	vastuhakkamist =hakkamis  (SgP  >vastu+hakkamine !12_S
48809	äraelamine	elamine	ära+elamine	12_S	SgN	et	äraelamine =elamine  (SgN  >ära+elamine !12_S
48812	seigad	seiga	seik	22_S	PlN	et	seigad =seiga  (PlN  >seik !22_S
48813	veidrad	veidra	veider	02_A	PlN	et	veidrad =veidra  (PlN  >veider !02_A
48819	komöödiasugemetega	sugeme	komöödia+suge	04_S	PlKom	et	komöödiasugemetega =sugeme  (PlKom  >komöödia+suge !04_S
48820	võimsad	võimsa	võimas	03~05_A	PlN	et	võimsad =võimsa  (PlN  >võimas !03~05_A
48827	ajalooteadmistega	teadmis	aja+loo+teadmine	12?10_S	PlKom	et	ajalooteadmistega =teadmis  (PlKom  >aja+loo+teadmine !12?10_S
48828	mängufilmide	filmi	mängu+film	22_S	PlG	et	mängufilmide =filmi  (PlG  >mängu+film !22_S
48830	ajaloomüüte	müüte	aja+loo+müüt	22_S	PlP	et	ajaloomüüte =müüte  (PlP  >aja+loo+müüt !22_S
48832	estofiilidele	estofiili	estofiil	22_S	PlAll	et	estofiilidele =estofiili  (PlAll  >estofiil !22_S
48848	eripäradest	pära	eri+pära	17_S	PlEl	et	eripäradest =pära  (PlEl  >eri+pära !17_S
48852	filmikogemus	kogemus	filmi+kogemus	11_S	SgN	et	filmikogemus =kogemus  (SgN  >filmi+kogemus !11_S
48857	ümberjagamine	jagamine	ümber+jagamine	12_S	SgN	et	ümberjagamine =jagamine  (SgN  >ümber+jagamine !12_S
48861	vaenlaselt	vaenlase	vaenlane	12?10_S	SgAbl	et	vaenlaselt =vaenlase  (SgAbl  >vaenlane !12?10_S
48873	foogt	foogt	foogt	22_S	SgN	et	foogt =foogt  (SgN  >foogt !22_S
48875	hirmuäravateks	vate	hirmu+ära+vatt	22_S	PlTr	et	hirmuäravateks =vate  (PlTr  >hirmu+ära+vatt !22_S
48876	niisugusteks	sugus	nii+sugune	10_P	PlTr	et	niisugusteks =sugus  (PlTr  >nii+sugune !10_P
48877	maaalade	ala	maa+ala	17_S	PlG	et	maaalade =ala  (PlG  >maa+ala !17_S
48881	mõtisklema	mõtiskle	mõtisklema	27_V	Sup	et	mõtisklema =mõtiskle  (Sup  >mõtisklema !27_V
48889	ristirüütlitele	rüütli	risti+rüütel	02_S	PlAll	et	ristirüütlitele =rüütli  (PlAll  >risti+rüütel !02_S
48890	figureerib	figureeri	figureerima	28_V	IndPrSg3	et	figureerib =figureeri  (IndPrSg3  >figureerima !28_V
48891	konnavarude	varu	konna+varu	17_S	PlG	et	konnavarude =varu  (PlG  >konna+varu !17_S
48896	ettevõetavas	võetava	ette+võetav	02_A	SgIn	et	ettevõetavas =võetava  (SgIn  >ette+võetav !02_A
48897	ühismalev	malev	ühis+malev	02_S	SgN	et	ühismalev =malev  (SgN  >ühis+malev !02_S
48901	samade	sama	sama	17_P	PlG	et	samade =sama  (PlG  >sama !17_P
48902	tunnusjoontega	joon	tunnus+joon	13_S	PlKom	et	tunnusjoontega =joon  (PlKom  >tunnus+joon !13_S
48909	konnavarusid	varu	konna+varu	17_S	PlP	et	konnavarusid =varu  (PlP  >konna+varu !17_S
48911	meelestada	meelesta	meelestama	27_V	Inf	et	meelestada =meelesta  (Inf  >meelestama !27_V
48922	võimsate	võimsa	võimas	03~05_A	PlG	et	võimsate =võimsa  (PlG  >võimas !03~05_A
48925	väidetega	väide	väide	06_S	PlKom	et	väidetega =väide  (PlKom  >väide !06_S
48926	peske	pes	pesema	36_V	ImpPrPl2	et	peske =pes  (ImpPrPl2  >pesema !36_V
48928	kahjustada	kahjusta	kahjustama	27_V	Inf	et	kahjustada =kahjusta  (Inf  >kahjustama !27_V
48931	kilbi	kilbi	kilp	22_S	SgG	et	kilbi =kilbi  (SgG  >kilp !22_S
48943	laadusse	laadu	laat	22_S	PlIll	et	laadusse =laadu  (PlIll  >laat !22_S
48951	tellisest	tellise	tellis	09_S	SgEl	et	tellisest =tellise  (SgEl  >tellis !09_S
48957	niiskustõke	tõke	niiskus+tõke	06_S	SgN	et	niiskustõke =tõke  (SgN  >niiskus+tõke !06_S
48966	imitatsioon	imitatsioon	imitatsioon	22_S	SgN	et	imitatsioon =imitatsioon  (SgN  >imitatsioon !22_S
48973	värvilahendus	lahendus	värvi+lahendus	11_S	SgN	et	värvilahendus =lahendus  (SgN  >värvi+lahendus !11_S
48984	jõhkrast	jõhkra	jõhker	02_A	SgEl	et	jõhkrast =jõhkra  (SgEl  >jõhker !02_A
48987	sööge	söö	sööma	38_V	ImpPrPl2	et	sööge =söö  (ImpPrPl2  >sööma !38_V
48993	pesumasinaga	masina	pesu+masin	02_S	SgKom	et	pesumasinaga =masina  (SgKom  >pesu+masin !02_S
48994	prinditakse	prindi	printima	28_V	IndPrIps	et	prinditakse =prindi  (IndPrIps  >printima !28_V
48996	kohvimasinaga	masina	kohvi+masin	02_S	SgKom	et	kohvimasinaga =masina  (SgKom  >kohvi+masin !02_S
48997	vahustatakse	vahusta	vahustama	27_V	IndPrIps	et	vahustatakse =vahusta  (IndPrIps  >vahustama !27_V
48998	laadima	laadi	laadima	28_V	Sup	et	laadima =laadi  (Sup  >laadima !28_V
48999	üritama	ürita	üritama	27_V	Sup	et	üritama =ürita  (Sup  >üritama !27_V
49008	piljardisaal	saal	piljardi+saal	22_S	SgN	et	piljardisaal =saal  (SgN  >piljardi+saal !22_S
49009	jalgadel	jalga	jalg	22_S	PlAd	et	jalgadel =jalga  (PlAd  >jalg !22_S
49017	piljardisse	piljardi	piljard	02_S	SgIll	et	piljardisse =piljardi  (SgIll  >piljard !02_S
49021	allalas	ala	all+ala	17_S	SgIn	et	allalas =ala  (SgIn  >all+ala !17_S
48849	tõdemus	tõdemus	tõdemus	11_S	SgN	et	tõdemus =tõdemus  (SgN  >tõdemus !11_S
48850	heroilistest	heroilis	heroiline	12?10_A	PlEl	et	heroilistest =heroilis  (PlEl  >heroiline !12?10_A
48855	peksuga	peksu	peks	22_S	SgKom	et	peksuga =peksu  (SgKom  >peks !22_S
48856	kaardil	kaardi	kaart	22_S	SgAd	et	kaardil =kaardi  (SgAd  >kaart !22_S
48859	sakslasest	sakslase	sakslane	12?10_S	SgEl	et	sakslasest =sakslase  (SgEl  >sakslane !12?10_S
48867	prantslaste	prantslas	prantslane	12?10_S	PlG	et	prantslaste =prantslas  (PlG  >prantslane !12?10_S
48869	tihedasti	tihedasti	tihedasti	41_D	ID	et	tihedasti =tihedasti  (ID  >tihedasti !41_D
48872	episoodist	episoodi	episood	22_S	SgEl	et	episoodist =episoodi  (SgEl  >episood !22_S
48874	episoodid	episoodi	episood	22_S	PlN	et	episoodid =episoodi  (PlN  >episood !22_S
48879	munga	munga	munk	22_S	SgG	et	munga =munga  (SgG  >munk !22_S
48886	kultuuritraditsioonide	traditsiooni	kultuuri+traditsioon	22_S	PlG	et	kultuuritraditsioonide =traditsiooni  (PlG  >kultuuri+traditsioon !22_S
48892	haaratakse	haara	haarama	29_V	IndPrIps	et	haaratakse =haara  (IndPrIps  >haarama !29_V
48894	õhutada	õhuta	õhutama	27_V	Inf	et	õhutada =õhuta  (Inf  >õhutama !27_V
48907	13sajandi	sajandi	sajand	02_S	SgG	et	sajandi =sajandi  (SgG  >sajand !02_S
48908	eurooplane	eurooplane	eurooplane	12?10_S	SgN	et	eurooplane =eurooplane  (SgN  >eurooplane !12?10_S
48913	langebki	lange	langema	27_V	IndPrSg3^	et	langebki =lange  (IndPrSg3^  >langema !27_V
48938	aparatuuriga-	aparatuuri	aparatuur	22_S	SgKom	et	aparatuuriga- =aparatuuri  (SgKom  >aparatuur !22_S
48940	telemängud-	mängu	tele+mäng	22_S	PlN	et	telemängud- =mängu  (PlN  >tele+mäng !22_S
48945	sisukujundust	kujundus	sisu+kujundus	11_S	SgP	et	sisukujundust =kujundus  (SgP  >sisu+kujundus !11_S
48946	pinka	pinka	pingas	07_S	SgG	et	pinka =pinka  (SgG  >pingas !07_S
48956	värvin	värvi	värvima	28_V	IndPrSg1	et	värvin =värvi  (IndPrSg1  >värvima !28_V
48962	keldri	keldri	kelder	02_S	SgG	et	keldri =keldri  (SgG  >kelder !02_S
48965	stilistikas	stilistika	stilistika	01_S	SgIn	et	stilistikas =stilistika  (SgIn  >stilistika !01_S
48975	seintel	sein	sein	23_S	PlAd	et	seintel =sein  (PlAd  >sein !23_S
48976	tumbat	tumba	tumba	16_S	SgP	et	tumbat =tumba  (SgP  >tumba !16_S
48986	mikroobe	mikroobe	mikroob	22_S	PlP	et	mikroobe =mikroobe  (PlP  >mikroob !22_S
48995	kuulatakse	kuula	kuulama	29_V	IndPrIps	et	kuulatakse =kuula  (IndPrIps  >kuulama !29_V
49003	remonditöid	tö	remondi+töö	26_S	PlP	et	remonditöid =tö  (PlP  >remondi+töö !26_S
49007	vahesein	sein	vahe+sein	23?22_S	SgN	et	vahesein =sein  (SgN  >vahe+sein !23?22_S
49018	laag	laag	laag	22_S	SgN	et	laag =laag  (SgN  >laag !22_S
49024	kand	kand	kand	22_S	SgN	et	kand =kand  (SgN  >kand !22_S
49025	puhketoas	toa	puhke+tuba	18_S	SgIn	et	puhketoas =toa  (SgIn  >puhke+tuba !18_S
49029	väljusin	välju	väljuma	27_V	IndIpfSg1	et	väljusin =välju  (IndIpfSg1  >väljuma !27_V
49041	embama	emba	embama	29_V	Sup	et	embama =emba  (Sup  >embama !29_V
49052	kamber	kamber	kamber	02_S	SgN	et	kamber =kamber  (SgN  >kamber !02_S
49054	plastmassist	massi	plast+mass	22_S	SgEl	et	plastmassist =massi  (SgEl  >plast+mass !22_S
49072	kraan	kraan	kraan	22_S	SgN	et	kraan =kraan  (SgN  >kraan !22_S
49082	rattad	ratta	ratas	07_S	PlN	et	rattad =ratta  (PlN  >ratas !07_S
49092	parteiks	partei	partei	26_S	SgTr	et	parteiks =partei  (SgTr  >partei !26_S
49100	kursustesse	kursus	kursus	11~09_S	PlIll	et	kursustesse =kursus  (PlIll  >kursus !11~09_S
49101	üliõpilasena	õpilase	üli+õpilane	12_S	SgEs	et	üliõpilasena =õpilase  (SgEs  >üli+õpilane !12_S
49105	videot	video	video	01_S	SgP	et	videot =video  (SgP  >video !01_S
49107	aktused	aktuse	aktus	11~09_S	PlN	et	aktused =aktuse  (PlN  >aktus !11~09_S
49108	3d-graafikat	graafika	d-graafika	01_S	SgP	et	d-graafikat =graafika  (SgP  >d-graafika !01_S
49121	tundidelt	tundi	tund	22_S	PlAbl	et	tundidelt =tundi  (PlAbl  >tund !22_S
49125	teaduseid	teaduse	teadus	09_S	PlP	et	teaduseid =teaduse  (PlP  >teadus !09_S
49128	kolmat	kolma	kolmas	02_O	SgP	et	kolmat =kolma  (SgP  >kolmas !02_O
49129	semestrit	semestri	semester	02_S	SgP	et	semestrit =semestri  (SgP  >semester !02_S
49131	avaneda	avane	avanema	27_V	Inf	et	avaneda =avane  (Inf  >avanema !27_V
49135	reserv	reserv	reserv	22_S	SgN	et	reserv =reserv  (SgN  >reserv !22_S
49137	hoon	hoon	hoon	22_A	SgN	et	hoon =hoon  (SgN  >hoon !22_A
49146	doktoriks	doktori	doktor	02_S	SgTr	et	doktoriks =doktori  (SgTr  >doktor !02_S
49150	huviring	ring	huvi+ring	22_S	SgN	et	huviring =ring  (SgN  >huvi+ring !22_S
49154	börsil	börsi	börs	22_S	SgAd	et	börsil =börsi  (SgAd  >börs !22_S
49161	valemite	valemi	valem	02_S	PlG	et	valemite =valemi  (PlG  >valem !02_S
48930	mikroobidel	mikroobi	mikroob	22_S	PlAd	et	mikroobidel =mikroobi  (PlAd  >mikroob !22_S
48934	autotest	test	auto+test	22_S	SgN	et	autotest =test  (SgN  >auto+test !22_S
48935	kosmosi	kosmosi	kosmos	11_S	PlP	et	kosmosi =kosmosi  (PlP  >kosmos !11_S
48937	seadmeteni	seadme	seade	05_S	PlTer	et	seadmeteni =seadme  (PlTer  >seade !05_S
48941	pesumisruum	ruum	pesu+mis+ruum	22_S	SgN	et	pesumisruum =ruum  (SgN  >pesu+mis+ruum !22_S
48944	vaheseinu	seinu	vahe+sein	23?22_S	PlP	et	vaheseinu =seinu  (PlP  >vahe+sein !23?22_S
48947	puupõrand	põrand	puu+põrand	02_S	SgN	et	puupõrand =põrand  (SgN  >puu+põrand !02_S
48948	elektrisaun	saun	elektri+saun	22_S	SgN	et	elektrisaun =saun  (SgN  >elektri+saun !22_S
48967	kujutis	kujutis	kujutis	11_S	SgN	et	kujutis =kujutis  (SgN  >kujutis !11_S
48974	plaadist	plaadi	plaat	22_S	SgEl	et	plaadist =plaadi  (SgEl  >plaat !22_S
48977	vaheseinas	seina	vahe+sein	23?22_S	SgIn	et	vaheseinas =seina  (SgIn  >vahe+sein !23?22_S
48978	zooniks	niks	zoo+niks	22_S	SgN	et	zooniks =niks  (SgN  >zoo+niks !22_S
48981	kaljudesse	kalju	kalju	16_S	PlIll	et	kaljudesse =kalju  (PlIll  >kalju !16_S
48982	dekoratiivse	dekoratiivse	dekoratiivne	02_A	SgG	et	dekoratiivse =dekoratiivse  (SgG  >dekoratiivne !02_A
48988	kuumutage	kuumuta	kuumutama	27_V	ImpPrPl2	et	kuumutage =kuumuta  (ImpPrPl2  >kuumutama !27_V
48990	mikroobid	mikroobi	mikroob	22_S	PlN	et	mikroobid =mikroobi  (PlN  >mikroob !22_S
48991	rikkuma	rikku	rikkuma	28_V	Sup	et	rikkuma =rikku  (Sup  >rikkuma !28_V
49000	põrandahari	hari	põranda+hari	24_S	SgN	et	põrandahari =hari  (SgN  >põranda+hari !24_S
49004	ventilatsioon	ventilatsioon	ventilatsioon	22_S	SgN	et	ventilatsioon =ventilatsioon  (SgN  >ventilatsioon !22_S
49011	põrandat	põranda	põrand	02_S	SgP	et	põrandat =põranda  (SgP  >põrand !02_S
49013	ehaksin	eha	ehama	27_V	KndPrSg1	et	ehaksin =eha  (KndPrSg1  >ehama !27_V
49015	teostaksin	teosta	teostama	27_V	KndPrSg1	et	teostaksin =teosta  (KndPrSg1  >teostama !27_V
49019	lillad	lilla	lilla	16_AS	PlN	et	lillad =lilla  (PlN  >lilla !16_AS
49022	võimlas	võimla	võimla	01_S	SgIn	et	võimlas =võimla  (SgIn  >võimla !01_S
49045	klaasitõstuk	tõstuk	klaasi+tõstuk	02_S	SgN	et	klaasitõstuk =tõstuk  (SgN  >klaasi+tõstuk !02_S
49047	talgud	talgu	talgu	01_S	PlN	et	talgud =talgu  (PlN  >talgu !01_S
49051	kõrvaldama	kõrvalda	kõrvaldama	27_V	Sup	et	kõrvaldama =kõrvalda  (Sup  >kõrvaldama !27_V
49053	paigutab	paiguta	paigutama	27_V	IndPrSg3	et	paigutab =paiguta  (IndPrSg3  >paigutama !27_V
49057	väheldase	väheldase	väheldane	12_A	SgG	et	väheldase =väheldase  (SgG  >väheldane !12_A
49059	elektrivirku	virku	elektri+virk	22_A	PlP	et	elektrivirku =virku  (PlP  >elektri+virk !22_A
49060	laikivad	iva	laik+iva	17_S	PlN	et	laikivad =iva  (PlN  >laik+iva !17_S
49070	akud	aku	aku	16_S	PlN	et	akud =aku  (PlN  >aku !16_S
49077	varuvõimalus	võimalus	varu+võimalus	11_S	SgN	et	varuvõimalus =võimalus  (SgN  >varu+võimalus !11_S
49078	pangakaardid	kaardi	panga+kaart	22_S	PlN	et	pangakaardid =kaardi  (PlN  >panga+kaart !22_S
49093	lojaalne	lojaalne	lojaalne	02_A	SgN	et	lojaalne =lojaalne  (SgN  >lojaalne !02_A
49095	laagrisse	laagri	laager	02_S	SgIll	et	laagrisse =laagri  (SgIll  >laager !02_S
49097	inimohvreid	ohvre	inim+ohver	02_S	PlP	et	inimohvreid =ohvre  (PlP  >inim+ohver !02_S
49110	üliõpilasele	õpilase	üli+õpilane	12_S	SgAll	et	üliõpilasele =õpilase  (SgAll  >üli+õpilane !12_S
49112	lõputunnistuse	tunnistuse	lõpu+tunnistus	11_S	SgG	et	lõputunnistuse =tunnistuse  (SgG  >lõpu+tunnistus !11_S
49114	tehnoloogiatega	tehnoloogia	tehnoloogia	01_S	PlKom	et	tehnoloogiatega =tehnoloogia  (PlKom  >tehnoloogia !01_S
49117	nägal	nägal	nägal	02_A	SgN	et	nägal =nägal  (SgN  >nägal !02_A
49118	imetlesin	imetle	imetlema	27_V	IndIpfSg1	et	imetlesin =imetle  (IndIpfSg1  >imetlema !27_V
49119	energeetikas	energeetika	energeetika	01_S	SgIn	et	energeetikas =energeetika  (SgIn  >energeetika !01_S
49120	õppekoht	koht	õppe+koht	22_S	SgN	et	õppekoht =koht  (SgN  >õppe+koht !22_S
49123	toimisin	toimi	toimima	28_V	IndIpfSg1	et	toimisin =toimi  (IndIpfSg1  >toimima !28_V
49126	süsteemide	süsteemi	süsteem	22_S	PlG	et	süsteemide =süsteemi  (PlG  >süsteem !22_S
49136	onuga	onu	onu	17_S	SgKom	et	onuga =onu  (SgKom  >onu !17_S
49139	sassi	sassi	sassi	41_D	ID	et	sassi =sassi  (ID  >sassi !41_D
49144	lektori	lektori	lektor	02_S	SgG	et	lektori =lektori  (SgG  >lektor !02_S
49160	üldväljendite	väljendi	üld+väljend	02_S	PlG	et	üldväljendite =väljendi  (PlG  >üld+väljend !02_S
49172	ülivõrdes	võrde	üli+võrre	06_S	SgIn	et	ülivõrdes =võrde  (SgIn  >üli+võrre !06_S
49174	luikede	luike	luik	22_S	PlG	et	luikede =luike  (PlG  >luik !22_S
49175	edule	edu	edu	17_S	SgAll	et	edule =edu  (SgAll  >edu !17_S
49176	lähiaja	aja	lähi+aeg	22_S	SgG	et	lähiaja =aja  (SgG  >lähi+aeg !22_S
49028	höövelriistad	riista	höövel+riist	22_S	PlN	et	höövelriistad =riista  (PlN  >höövel+riist !22_S
49031	rusika	rusika	rusikas	02_S	SgG	et	rusika =rusika  (SgG  >rusikas !02_S
49032	isikukirjeldus	kirjeldus	isiku+kirjeldus	11_S	SgN	et	isikukirjeldus =kirjeldus  (SgN  >isiku+kirjeldus !11_S
49033	kehaehituse	ehituse	keha+ehitus	11_S	SgG	et	kehaehituse =ehituse  (SgG  >keha+ehitus !11_S
49037	ühispanga	panga	ühis+pank	22_S	SgG	et	ühispanga =panga  (SgG  >ühis+pank !22_S
49040	õlapeal	pea	õla+pea	26_S	SgAd	et	õlapeal =pea  (SgAd  >õla+pea !26_S
49044	ümbert	ümbert	ümbert	41_DK	ID	et	ümbert =ümbert  (ID  >ümbert !41_DK
49046	esituled	tule	esi+tuli	20_S	PlN	et	esituled =tule  (PlN  >esi+tuli !20_S
49049	ovaalne	ovaalne	ovaalne	02_A	SgN	et	ovaalne =ovaalne  (SgN  >ovaalne !02_A
49065	upuvad	upu	uppuma	28_V	IndPrPl3	et	upuvad =upu  (IndPrPl3  >uppuma !28_V
49066	pumbad	pumba	pump	22_S	PlN	et	pumbad =pumba  (PlN  >pump !22_S
49067	avariigeneraatorid	generaatori	avarii+generaator	02_S	PlN	et	avariigeneraatorid =generaatori  (PlN  >avarii+generaator !02_S
49075	haiglates	haigla	haigla	01_S	PlIn	et	haiglates =haigla  (PlIn  >haigla !01_S
49081	väsiks	väsi	väsima	27_V	KndPrPs	et	väsiks =väsi  (KndPrPs  >väsima !27_V
49083	süüdati	süüda	süütama	29_V	IndIpfIps	et	süüdati =süüda  (IndIpfIps  >süütama !29_V
49087	lõkete	lõke	lõke	06_S	PlG	et	lõkete =lõke  (PlG  >lõke !06_S
49089	tõrvikutega	tõrviku	tõrvik	02_S	PlKom	et	tõrvikutega =tõrviku  (PlKom  >tõrvik !02_S
49113	tudengitel	tudengi	tudeng	02_S	PlAd	et	tudengitel =tudengi  (PlAd  >tudeng !02_S
49115	tammiku	tammiku	tammik	02_S	SgG	et	tammiku =tammiku  (SgG  >tammik !02_S
49116	liikmeid	liikme	liige	05_S	PlP	et	liikmeid =liikme  (PlP  >liige !05_S
49122	keet	keet	keet	22_S	SgN	et	keet =keet  (SgN  >keet !22_S
49130	õppejõuga	jõu	õppe+jõud	22_S	SgKom	et	õppejõuga =jõu  (SgKom  >õppe+jõud !22_S
49141	astun	astu	astuma	28_V	IndPrSg1	et	astun =astu  (IndPrSg1  >astuma !28_V
49143	imetlen	imetle	imetlema	27_V	IndPrSg1	et	imetlen =imetle  (IndPrSg1  >imetlema !27_V
49145	magistriks	magistri	magister	02_S	SgTr	et	magistriks =magistri  (SgTr  >magister !02_S
49149	lahed	lahe	laht	22_S	PlN	et	lahed =lahe  (PlN  >laht !22_S
49152	ärimänge	mänge	äri+mäng	22_S	PlP	et	ärimänge =mänge  (PlP  >äri+mäng !22_S
49153	lemmikmänguks	mängu	lemmik+mäng	22_S	SgTr	et	lemmikmänguks =mängu  (SgTr  >lemmik+mäng !22_S
49155	investeerime	investeeri	investeerima	28_V	IndPrPl1	et	investeerime =investeeri  (IndPrPl1  >investeerima !28_V
49162	uutega	uu	uus	14_A	PlKom	et	uutega =uu  (PlKom  >uus !14_A
49165	ärinduse	ärinduse	ärindus	11_S	SgG	et	ärinduse =ärinduse  (SgG  >ärindus !11_S
49170	balletitantsijad	tantsija	balleti+tantsija	01_S	PlN	et	balletitantsijad =tantsija  (PlN  >balleti+tantsija !01_S
49171	oks	oks	oks	23?22_S	SgN	et	oks =oks  (SgN  >oks !23?22_S
49178	klassiruum	ruum	klassi+ruum	22_S	SgN	et	klassiruum =ruum  (SgN  >klassi+ruum !22_S
49187	tasakesi	tasakesi	tasakesi	41_D	ID	et	tasakesi =tasakesi  (ID  >tasakesi !41_D
49191	noortelt	noor	noor	13_AS	PlAbl	et	noortelt =noor  (PlAbl  >noor !13_AS
49192	tagasihoidlikud	hoidliku	tagasi+hoidlik	25_A	PlN	et	tagasihoidlikud =hoidliku  (PlN  >tagasi+hoidlik !25_A
49196	suhtusse	usse	suht+uss	22_S	PlP	et	suhtusse =usse  (PlP  >suht+uss !22_S
49202	tervistele	tervis	tervis	09~11_S	PlAll	et	tervistele =tervis  (PlAll  >tervis !09~11_S
49203	tagasihoidlikuks	hoidliku	tagasi+hoidlik	25_A	SgTr	et	tagasihoidlikuks =hoidliku  (SgTr  >tagasi+hoidlik !25_A
49206	tuha	tuha	tuhk	22_S	SgG	et	tuha =tuha  (SgG  >tuhk !22_S
49210	tagashoidlikul	hoidliku	tagas+hoidlik	25_A	SgAd	et	tagashoidlikul =hoidliku  (SgAd  >tagas+hoidlik !25_A
49211	inglismaas	maa	inglis+maa	26_S	SgIn	et	inglismaas =maa  (SgIn  >inglis+maa !26_S
49214	enesetunnust	tunnus	enese+tunnus	09_S	SgP	et	enesetunnust =tunnus  (SgP  >enese+tunnus !09_S
49218	koorimuusikat	muusika	koori+muusika	01_S	SgP	et	koorimuusikat =muusika  (SgP  >koori+muusika !01_S
49219	eestiballaadide	ballaadi	eesti+ballaad	22_S	PlG	et	eestiballaadide =ballaadi  (PlG  >eesti+ballaad !22_S
49222	saladusi	saladusi	saladus	11_S	PlP	et	saladusi =saladusi  (PlP  >saladus !11_S
49227	ametiisik	isik	ameti+isik	02_S	SgN	et	ametiisik =isik  (SgN  >ameti+isik !02_S
49239	ajaviidet	viide	aja+viide	06_S	SgP	et	ajaviidet =viide  (SgP  >aja+viide !06_S
49242	traditsionaalseid	traditsionaalse	traditsionaalne	02_A	PlP	et	traditsionaalseid =traditsionaalse  (PlP  >traditsionaalne !02_A
49248	sõjaajalt	aja	sõja+aeg	22_S	SgAbl	et	sõjaajalt =aja  (SgAbl  >sõja+aeg !22_S
49251	tibud	tibu	tibu	17_S	PlN	et	tibud =tibu  (PlN  >tibu !17_S
49261	liivirannad	ranna	liivi+rand	22_S	PlN	et	liivirannad =ranna  (PlN  >liivi+rand !22_S
49265	tiibadega	tiiba	tiib	22_S	PlKom	et	tiibadega =tiiba  (PlKom  >tiib !22_S
49036	isikukirjeldused	kirjelduse	isiku+kirjeldus	11_S	PlN	et	isikukirjeldused =kirjelduse  (PlN  >isiku+kirjeldus !11_S
49038	mante	mante	mant	22_S	PlP	et	mante =mante  (PlP  >mant !22_S
49042	krabis	krabi	krabi	17_S	SgIn	et	krabis =krabi  (SgIn  >krabi !17_S
49043	kuritegijaga	tegija	kuri+tegija	01_S	SgKom	et	kuritegijaga =tegija  (SgKom  >kuri+tegija !01_S
49064	objektidel	objekti	objekt	22_S	PlAd	et	objektidel =objekti  (PlAd  >objekt !22_S
49074	sidesüsteemidele	süsteemi	side+süsteem	22_S	PlAll	et	sidesüsteemidele =süsteemi  (PlAll  >side+süsteem !22_S
49076	varugeneraatorid	generaatori	varu+generaator	02_S	PlN	et	varugeneraatorid =generaatori  (PlN  >varu+generaator !02_S
49079	elektripakk	pakk	elektri+pakk	22_S	SgN	et	elektripakk =pakk  (SgN  >elektri+pakk !22_S
49080	selg	selg	selg	22_S	SgN	et	selg =selg  (SgN  >selg !22_S
49084	tavandit	tavandi	tavand	02_S	SgP	et	tavandit =tavandi  (SgP  >tavand !02_S
49085	teostati	teosta	teostama	27_V	IndIpfIps	et	teostati =teosta  (IndIpfIps  >teostama !27_V
49091	käskete	e	käsk+esi	15_S	PlG	et	käskete =e  (PlG  >käsk+esi !15_S
49094	parteile	partei	partei	26_S	SgAll	et	parteile =partei  (SgAll  >partei !26_S
49096	töödele	töö	töö	26_S	PlAll	et	töödele =töö  (PlAll  >töö !26_S
49099	teaduskondades	teaduskonda	teaduskond	22_S	PlIn	et	teaduskondades =teaduskonda  (PlIn  >teaduskond !22_S
49102	ehitusteadusosakond	osakond	ehitus+teadus+osakond	22_S	SgN	et	ehitusteadusosakond =osakond  (SgN  >ehitus+teadus+osakond !22_S
49106	aktusel	aktuse	aktus	11~09_S	SgAd	et	aktusel =aktuse  (SgAd  >aktus !11~09_S
49111	kursusi	kursusi	kursus	11_S	PlP	et	kursusi =kursusi  (PlP  >kursus !11_S
49124	eelnädalal	nädala	eel+nädal	02_S	SgAd	et	eelnädalal =nädala  (SgAd  >eel+nädal !02_S
49127	saksakelt	kelt	saksa+kelt	22_S	SgN	et	saksakelt =kelt  (SgN  >saksa+kelt !22_S
49142	elektroenergeetikat	energeetika	elektro+energeetika	01_S	SgP	et	elektroenergeetikat =energeetika  (SgP  >elektro+energeetika !01_S
49148	seletasin	seleta	seletama	27_V	IndIpfSg1	et	seletasin =seleta  (IndIpfSg1  >seletama !27_V
49157	ärinaine	naine	äri+naine	12_S	SgN	et	ärinaine =naine  (SgN  >äri+naine !12_S
49158	suurendama	suurenda	suurendama	27_V	Sup	et	suurendama =suurenda  (Sup  >suurendama !27_V
49169	maailmakuulsad	kuulsa	maa+ilma+kuulus	02_A	PlN	et	maailmakuulsad =kuulsa  (PlN  >maa+ilma+kuulus !02_A
49182	postitage	postita	postitama	27_V	ImpPrPl2	et	postitage =postita  (ImpPrPl2  >postitama !27_V
49183	kupong	kupong	kupong	22_S	SgN	et	kupong =kupong  (SgN  >kupong !22_S
49190	külastage	külasta	külastama	27_V	ImpPrPl2	et	külastage =külasta  (ImpPrPl2  >külastama !27_V
49194	tagasihoidliku	hoidliku	tagasi+hoidlik	25_A	SgG	et	tagasihoidliku =hoidliku  (SgG  >tagasi+hoidlik !25_A
49198	üheksaaja	aja	üheksa+aeg	22_S	SgG	et	üheksaaja =aja  (SgG  >üheksa+aeg !22_S
49200	seitsmendast	seitsmenda	seitsmes	02_O	SgEl	et	seitsmendast =seitsmenda  (SgEl  >seitsmes !02_O
49205	nooredelt	ede	noor+ede	16_S	SgAbl	et	nooredelt =ede  (SgAbl  >noor+ede !16_S
49217	valikuvõimalus	võimalus	valiku+võimalus	11_S	SgN	et	valikuvõimalus =võimalus  (SgN  >valiku+võimalus !11_S
49221	kultuuritarbijate	tarbija	kultuuri+tarbija	01_S	PlG	et	kultuuritarbijate =tarbija  (PlG  >kultuuri+tarbija !01_S
49224	pidupäeve	päeve	pidu+päev	22_S	PlP	et	pidupäeve =päeve  (PlP  >pidu+päev !22_S
49228	kodumaafilmid	filmi	kodu+maa+film	22_S	PlN	et	kodumaafilmid =filmi  (PlN  >kodu+maa+film !22_S
49231	paaridelt	paari	paar	22_NS	PlAbl	et	paaridelt =paari  (PlAbl  >paar !22_NS
49232	tagapõhjal	põhja	taga+põhi	24_S	SgAd	et	tagapõhjal =põhja  (SgAd  >taga+põhi !24_S
49238	kodumaafilm	film	kodu+maa+film	22_S	SgN	et	kodumaafilm =film  (SgN  >kodu+maa+film !22_S
49243	kodumaafilmides	filmi	kodu+maa+film	22_S	PlIn	et	kodumaafilmides =filmi  (PlIn  >kodu+maa+film !22_S
49256	pihlakad	pihlaka	pihlakas	02_S	PlN	et	pihlakad =pihlaka  (PlN  >pihlakas !02_S
49257	tammid	tammi	tamm	22_S	PlN	et	tammid =tammi  (PlN  >tamm !22_S
49264	õhusse	õhu	õhk	22_S	SgIll	et	õhusse =õhu  (SgIll  >õhk !22_S
49268	taanlasi	taanlasi	taanlane	12_S	PlP	et	taanlasi =taanlasi  (PlP  >taanlane !12_S
49271	ajasin	aja	ajama	27_V	IndIpfSg1	et	ajasin =aja  (IndIpfSg1  >ajama !27_V
49272	saabusin	saabu	saabuma	27_V	IndIpfSg1	et	saabusin =saabu  (IndIpfSg1  >saabuma !27_V
49292	papagoiga	papagoi	papagoi	26_S	SgKom	et	papagoiga =papagoi  (SgKom  >papagoi !26_S
49293	noornaine	naine	noor+naine	12_S	SgN	et	noornaine =naine  (SgN  >noor+naine !12_S
49307	sõimas	sõima	sõimama	29_V	IndIpfSg3	et	sõimas =sõima  (IndIpfSg3  >sõimama !29_V
49314	fotomodellina	modelli	foto+modell	22_S	SgEs	et	fotomodellina =modelli  (SgEs  >foto+modell !22_S
49322	lõviga	lõvi	lõvi	17_S	SgKom	et	lõviga =lõvi  (SgKom  >lõvi !17_S
49334	taldrikutäie	täie	taldriku+täis	14_AS	SgG	et	taldrikutäie =täie  (SgG  >taldriku+täis !14_AS
49050	kvadraatne	kvadraatne	kvadraatne	02_A	SgN	et	kvadraatne =kvadraatne  (SgN  >kvadraatne !02_A
49055	ekraan	ekraan	ekraan	22_S	SgN	et	ekraan =ekraan  (SgN  >ekraan !22_S
49056	knopkad	knopka	knopka	16_S	PlN	et	knopkad =knopka  (PlN  >knopka !16_S
49058	kihutan	kihuta	kihutama	27_V	IndPrSg1	et	kihutan =kihuta  (IndPrSg1  >kihutama !27_V
49061	külmkapsis	kapsi	külm+kaps	22_S	SgIn	et	külmkapsis =kapsi  (SgIn  >külm+kaps !22_S
49062	kihutada	kihuta	kihutama	27_V	Inf	et	kihutada =kihuta  (Inf  >kihutama !27_V
49063	pildita	pildi	pilt	22_S	SgAb	et	pildita =pildi  (SgAb  >pilt !22_S
49068	generaatorid	generaatori	generaator	02_S	PlN	et	generaatorid =generaatori  (PlN  >generaator !02_S
49069	liftid	lifti	lift	22_S	PlN	et	liftid =lifti  (PlN  >lift !22_S
49071	voolukatkestus	katkestus	voolu+katkestus	11_S	SgN	et	voolukatkestus =katkestus  (SgN  >voolu+katkestus !11_S
49073	teletornis	torni	tele+torn	22_S	SgIn	et	teletornis =torni  (SgIn  >tele+torn !22_S
49086	maakondades	maakonda	maakond	22_S	PlIn	et	maakondades =maakonda  (PlIn  >maakond !22_S
49088	ritvadel	ritva	ritv	22_S	PlAd	et	ritvadel =ritva  (PlAd  >ritv !22_S
49090	pöördepunkt	punkt	pöörde+punkt	22_S	SgN	et	pöördepunkt =punkt  (SgN  >pöörde+punkt !22_S
49098	ärinduses	ärinduse	ärindus	11_S	SgIn	et	ärinduses =ärinduse  (SgIn  >ärindus !11_S
49103	taipoksiga	poksi	tai+poks	22_S	SgKom	et	taipoksiga =poksi  (SgKom  >tai+poks !22_S
49104	esmast	esmas	esmane	10_A	SgP	et	esmast =esmas  (SgP  >esmane !10_A
49109	informaatikas	informaatika	informaatika	01_S	SgIn	et	informaatikas =informaatika  (SgIn  >informaatika !01_S
49132	kergejõustikuga	jõustiku	kerge+jõustik	25_S	SgKom	et	kergejõustikuga =jõustiku  (SgKom  >kerge+jõustik !25_S
49133	boksiga	boksi	boks	22_S	SgKom	et	boksiga =boksi  (SgKom  >boks !22_S
49134	tellerit	telleri	teller	02_S	SgP	et	tellerit =telleri  (SgP  >teller !02_S
49138	planeerisin	planeeri	planeerima	28_V	IndIpfSg1	et	planeerisin =planeeri  (IndIpfSg1  >planeerima !28_V
49140	ttü-is	ttü	ttü	xx_Q	SgIn	et	ttü-is =ttü  (SgIn  >ttü !xx_Q
49147	energeetikaga	energeetika	energeetika	01_S	SgKom	et	energeetikaga =energeetika  (SgKom  >energeetika !01_S
49151	ärikorraldus	korraldus	äri+korraldus	11_S	SgN	et	ärikorraldus =korraldus  (SgN  >äri+korraldus !11_S
49156	ärindus	ärindus	ärindus	11_S	SgN	et	ärindus =ärindus  (SgN  >ärindus !11_S
49159	riskida	riski	riskima	28_V	Inf	et	riskida =riski  (Inf  >riskima !28_V
49166	kaupuses	use	kaup+usk	22_S	PlIn	et	kaupuses =use  (PlIn  >kaup+usk !22_S
49167	ilusalongis	salongi	ilu+salong	22_S	SgIn	et	ilusalongis =salongi  (SgIn  >ilu+salong !22_S
49168	sulud	sulu	sulg	22_S	PlN	et	sulud =sulu  (PlN  >sulg !22_S
49177	umbne	umbne	umbne	02_A	SgN	et	umbne =umbne  (SgN  >umbne !02_A
49179	koduõppesüsteem	süsteem	kodu+õppe+süsteem	22_S	SgN	et	koduõppesüsteem =süsteem  (SgN  >kodu+õppe+süsteem !22_S
49181	individuaalsele	individuaalse	individuaalne	02_A	SgAll	et	individuaalsele =individuaalse  (SgAll  >individuaalne !02_A
49189	käige	käi	käima	38_V	ImpPrPl2	et	käige =käi  (ImpPrPl2  >käima !38_V
49208	külaslage	lage	külas+lagi	21_S	SgP	et	külaslage =lage  (SgP  >külas+lagi !21_S
49216	ühiskondlikke	ühiskondlikke	ühiskondlik	25_A	PlP	et	ühiskondlikke =ühiskondlikke  (PlP  >ühiskondlik !25_A
49230	romantilistelt	romantilis	romantiline	12_A	PlAbl	et	romantilistelt =romantilis  (PlAbl  >romantiline !12_A
49236	maa-elust	elu	maa-elu	17_S	SgEl	et	maa-elust =elu  (SgEl  >maa-elu !17_S
49241	iluseid	iluse	ilus	02_A	PlP	et	iluseid =iluse  (PlP  >ilus !02_A
49249	kodumaafilme	filme	kodu+maa+film	22_S	PlP	et	kodumaafilme =filme  (PlP  >kodu+maa+film !22_S
49250	kukk	kukk	kukk	22_S	SgN	et	kukk =kukk  (SgN  >kukk !22_S
49252	viinamarid	mari	viina+mari	17~16_S	PlN	et	viinamarid =mari  (PlN  >viina+mari !17~16_S
49253	viljad	vilja	vili	24_S	PlN	et	viljad =vilja  (PlN  >vili !24_S
49254	kõrvitsaid	kõrvitsa	kõrvits	02_S	PlP	et	kõrvitsaid =kõrvitsa  (PlP  >kõrvits !02_S
49258	põhis	põhis	põhis	09_S	SgN	et	põhis =põhis  (SgN  >põhis !09_S
49263	rannalt	ranna	rand	22_S	SgAbl	et	rannalt =ranna  (SgAbl  >rand !22_S
49267	vabapäev	päev	vaba+päev	22_S	SgN	et	vabapäev =päev  (SgN  >vaba+päev !22_S
49274	sulab	sula	sulama	27_V	IndPrSg3	et	sulab =sula  (IndPrSg3  >sulama !27_V
49275	jahedat	jaheda	jahe	02_AS	SgP	et	jahedat =jaheda  (SgP  >jahe !02_AS
49278	piknikut	pikniku	piknik	02_S	SgP	et	piknikut =pikniku  (SgP  >piknik !02_S
49280	mereääres	ääre	mere+äär	13_S	SgIn	et	mereääres =ääre  (SgIn  >mere+äär !13_S
49288	margareta	re	marga+re	26_S	SgAb	et	margareta =re  (SgAb  >marga+re !26_S
49299	harjutab	harjuta	harjutama	27_V	IndPrSg3	et	harjutab =harjuta  (IndPrSg3  >harjutama !27_V
49303	ebatsensuursed	tsensuurse	eba+tsensuurne	02_A	PlN	et	ebatsensuursed =tsensuurse  (PlN  >eba+tsensuurne !02_A
49163	diplomit	diplomi	diplom	02_S	SgP	et	diplomit =diplomi  (SgP  >diplom !02_S
49164	erialatest	test	eri+ala+test	22_S	SgN	et	erialatest =test  (SgN  >eri+ala+test !22_S
49173	murdma	murd	murdma	34_V	Sup	et	murdma =murd  (Sup  >murdma !34_V
49193	seitsmenda	seitsmenda	seitsmes	02_O	SgG	et	seitsmenda =seitsmenda  (SgG  >seitsmes !02_O
49199	tagasihoidlikuna	hoidliku	tagasi+hoidlik	25_A	SgEs	et	tagasihoidlikuna =hoidliku  (SgEs  >tagasi+hoidlik !25_A
49201	tagasihoidlikuga	hoidliku	tagasi+hoidlik	25_A	SgKom	et	tagasihoidlikuga =hoidliku  (SgKom  >tagasi+hoidlik !25_A
49204	teatriga	teatri	teater	02_S	SgKom	et	teatriga =teatri  (SgKom  >teater !02_S
49207	murdub	murdu	murduma	27_V	IndPrSg3	et	murdub =murdu  (IndPrSg3  >murduma !27_V
49212	tervises	tervise	tervis	09~11_S	SgIn	et	tervises =tervise  (SgIn  >tervis !09~11_S
49213	tagasihoidjad	hoidja	tagasi+hoidja	01_S	PlN	et	tagasihoidjad =hoidja  (PlN  >tagasi+hoidja !01_S
49215	jõududesse	jõudu	jõud	22_S	PlIll	et	jõududesse =jõudu  (PlIll  >jõud !22_S
49220	teaduskraadiga	kraadi	teadus+kraad	22_S	SgKom	et	teaduskraadiga =kraadi  (SgKom  >teadus+kraad !22_S
49223	melanhoolsed	melanhoolse	melanhoolne	02_A	PlN	et	melanhoolsed =melanhoolse  (PlN  >melanhoolne !02_A
49225	tõlgivad	tõlgi	tõlkima	28_V	IndPrPl3	et	tõlgivad =tõlgi  (IndPrPl3  >tõlkima !28_V
49234	partner	partner	partner	02_S	SgN	et	partner =partner  (SgN  >partner !02_S
49237	mustmetsas	metsa	must+mets	22_S	SgIn	et	mustmetsas =metsa  (SgIn  >must+mets !22_S
49244	metsavaht	vaht	metsa+vaht	22_S	SgN	et	metsavaht =vaht  (SgN  >metsa+vaht !22_S
49245	veemöll	möll	vee+möll	22_S	SgN	et	veemöll =möll  (SgN  >vee+möll !22_S
49246	maa-linn	linn	maa-linn	22_S	SgN	et	maa-linn =linn  (SgN  >maa-linn !22_S
49255	tomateid	tomate	tomat	02_S	PlP	et	tomateid =tomate  (PlP  >tomat !02_S
49269	nelipäeval	päeva	neli+päev	22_S	SgAd	et	nelipäeval =päeva  (SgAd  >neli+päev !22_S
49273	korterikaaslasega	kaaslase	korteri+kaaslane	12?10_S	SgKom	et	korterikaaslasega =kaaslase  (SgKom  >korteri+kaaslane !12?10_S
49276	suved	suve	suvi	20_S	PlN	et	suved =suve  (PlN  >suvi !20_S
49281	pühitseme	pühitse	pühitsema	27_V	IndPrPl1	et	pühitseme =pühitse  (IndPrPl1  >pühitsema !27_V
49282	sügised	sügise	sügis	09_S	PlN	et	sügised =sügise  (PlN  >sügis !09_S
49283	tuulised	tuulise	tuuline	10_A	PlN	et	tuulised =tuulise  (PlN  >tuuline !10_A
49284	pakast	pakas	pakane	10_S	SgP	et	pakast =pakas  (SgP  >pakane !10_S
49285	kelgutama	kelguta	kelgutama	27_V	Sup	et	kelgutama =kelguta  (Sup  >kelgutama !27_V
49287	võrtsjärv	järv	võrts+järv	22_S	SgN	et	võrtsjärv =järv  (SgN  >võrts+järv !22_S
49291	türklased	türklase	türklane	12?10_S	PlN	et	türklased =türklase  (PlN  >türklane !12?10_S
49296	harjutasin	harjuta	harjutama	27_V	IndIpfSg1	et	harjutasin =harjuta  (IndIpfSg1  >harjutama !27_V
49311	hellid	helli	hell	22_A	PlN	et	hellid =helli  (PlN  >hell !22_A
49326	hülgas	hülga	hülgama	29_V	IndIpfSg3	et	hülgas =hülga  (IndIpfSg3  >hülgama !29_V
49328	seltskondlikud	seltskondliku	seltskondlik	25_A	PlN	et	seltskondlikud =seltskondliku  (PlN  >seltskondlik !25_A
49329	jumaldab	jumalda	jumaldama	27_V	IndPrSg3	et	jumaldab =jumalda  (IndPrSg3  >jumaldama !27_V
49332	kohtleb	kohtle	kohtlema	30_V	IndPrSg3	et	kohtleb =kohtle  (IndPrSg3  >kohtlema !30_V
49344	alatasa	alatasa	ala+tasa	41_D	ID	et	alatasa =alatasa  (ID  >ala+tasa !41_D
49345	pidupäev	päev	pidu+päev	22_S	SgN	et	pidupäev =päev  (SgN  >pidu+päev !22_S
49351	säilitan	säilita	säilitama	27_V	IndPrSg1	et	säilitan =säilita  (IndPrSg1  >säilitama !27_V
49353	puhkepäeval	päeva	puhke+päev	22_S	SgAd	et	puhkepäeval =päeva  (SgAd  >puhke+päev !22_S
49360	kaasaga	kaasa	kaasa	16_S	SgKom	et	kaasaga =kaasa  (SgKom  >kaasa !16_S
49361	lähendab	lähenda	lähendama	27_V	IndPrSg3	et	lähendab =lähenda  (IndPrSg3  >lähendama !27_V
49365	dekoratiivseid	dekoratiivse	dekoratiivne	02_A	PlP	et	dekoratiivseid =dekoratiivse  (PlP  >dekoratiivne !02_A
49384	meteoriidi	meteoriidi	meteoriit	22_S	SgG	et	meteoriidi =meteoriidi  (SgG  >meteoriit !22_S
49385	allakukkumine	kukkumine	alla+kukkumine	12_S	SgN	et	allakukkumine =kukkumine  (SgN  >alla+kukkumine !12_S
49392	eellased	eellase	eellane	12?10_S	PlN	et	eellased =eellase  (PlN  >eellane !12?10_S
49399	germaanlastest	germaanlas	germaanlane	12?10_S	PlEl	et	germaanlastest =germaanlas  (PlEl  >germaanlane !12?10_S
49404	võlgneme	võlgne	võlgnema	27_V	IndPrPl1	et	võlgneme =võlgne  (IndPrPl1  >võlgnema !27_V
49408	kroonikad	kroonika	kroonika	01_S	PlN	et	kroonikad =kroonika  (PlN  >kroonika !01_S
49418	seosele	seose	seos	09_S	SgAll	et	seosele =seose  (SgAll  >seos !09_S
49430	näidendis	näidendi	näidend	02_S	SgIn	et	näidendis =näidendi  (SgIn  >näidend !02_S
49445	töölist	töölis	tööline	12?10_S	SgP	et	töölist =töölis  (SgP  >tööline !12?10_S
49453	tudengiga	tudengi	tudeng	02_S	SgKom	et	tudengiga =tudengi  (SgKom  >tudeng !02_S
49180	interaktiivse	aktiivse	inter+aktiivne	02_A	SgG	et	interaktiivse =aktiivse  (SgG  >inter+aktiivne !02_A
49184	soovitad	soovita	soovitama	27_V	IndPrSg2	et	soovitad =soovita  (IndPrSg2  >soovitama !27_V
49185	solvud	solvu	solvuma	27_V	IndPrSg2	et	solvud =solvu  (IndPrSg2  >solvuma !27_V
49186	tasule	tasu	tasu	17_S	SgAll	et	tasule =tasu  (SgAll  >tasu !17_S
49188	tasakaalule	kaalu	tasa+kaal	22_S	SgAll	et	tasakaalule =kaalu  (SgAll  >tasa+kaal !22_S
49195	seitsmendalt	seitsmenda	seitsmes	02_O	SgAbl	et	seitsmendalt =seitsmenda  (SgAbl  >seitsmes !02_O
49197	kolmkümnend	kümnend	kolm+kümnend	02_S	SgN	et	kolmkümnend =kümnend  (SgN  >kolm+kümnend !02_S
49209	inglismaalis	maali	inglis+maal	22_S	SgIn	et	inglismaalis =maali  (SgIn  >inglis+maal !22_S
49226	võõrkeelse	keelse	võõr+keelne	02_A	SgG	et	võõrkeelse =keelse  (SgG  >võõr+keelne !02_A
49229	armastusfilm	film	armastus+film	22_S	SgN	et	armastusfilm =film  (SgN  >armastus+film !22_S
49233	armastusfilmis	filmi	armastus+film	22_S	SgIn	et	armastusfilmis =filmi  (SgIn  >armastus+film !22_S
49235	armastusfilmid	filmi	armastus+film	22_S	PlN	et	armastusfilmid =filmi  (PlN  >armastus+film !22_S
49240	sõjalt	sõja	sõda	18_S	SgAbl	et	sõjalt =sõja  (SgAbl  >sõda !18_S
49247	vanad-noored	noore	vanad-noor	13_AS	PlN	et	vanad-noored =noore  (PlN  >vanad-noor !13_AS
49259	saaril	saari	saar	13_S	PlAd	et	saaril =saari  (PlAd  >saar !13_S
49260	siniseks	seks	sini+seks	22_S	SgN	et	siniseks =seks  (SgN  >sini+seks !22_S
49262	lõunamerel	mere	lõuna+meri	20_S	SgAd	et	lõunamerel =mere  (SgAd  >lõuna+meri !20_S
49266	raudteejaamal	jaama	raud+tee+jaam	22_S	SgAd	et	raudteejaamal =jaama  (SgAd  >raud+tee+jaam !22_S
49279	päevitame	päevita	päevitama	27_V	IndPrPl1	et	päevitame =päevita  (IndPrPl1  >päevitama !27_V
49295	ehmatab	ehmata	ehmatama	27_V	IndPrSg3	et	ehmatab =ehmata  (IndPrSg3  >ehmatama !27_V
49297	linnuga	linnu	lind	22_S	SgKom	et	linnuga =linnu  (SgKom  >lind !22_S
49298	peatas	peata	peatama	27_V	IndIpfSg3	et	peatas =peata  (IndIpfSg3  >peatama !27_V
49300	silitada	silita	silitama	27_V	Inf	et	silitada =silita  (Inf  >silitama !27_V
49301	harjutas	harjuta	harjutama	27_V	IndIpfSg3	et	harjutas =harjuta  (IndIpfSg3  >harjutama !27_V
49302	juuksega	juukse	juus	09_S	SgKom	et	juuksega =juukse  (SgKom  >juus !09_S
49306	papagoile	papagoi	papagoi	26_S	SgAll	et	papagoile =papagoi  (SgAll  >papagoi !26_S
49310	kärale	kära	kära	17_S	SgAll	et	kärale =kära  (SgAll  >kära !17_S
49312	kilpkonn	konn	kilp+konn	22_S	SgN	et	kilpkonn =konn  (SgN  >kilp+konn !22_S
49319	telekaekraanile	ekraani	teleka+ekraan	22_S	SgAll	et	telekaekraanile =ekraani  (SgAll  >teleka+ekraan !22_S
49327	ülemvahi	vahi	ülem+vaht	22_S	SgG	et	ülemvahi =vahi  (SgG  >ülem+vaht !22_S
49331	närib	näri	närima	27_V	IndPrSg3	et	närib =näri  (IndPrSg3  >närima !27_V
49338	kulukaks	kuluka	kulukas	02_A	SgTr	et	kulukaks =kuluka  (SgTr  >kulukas !02_A
49339	liigitatakse	liigita	liigitama	27_V	IndPrIps	et	liigitatakse =liigita  (IndPrIps  >liigitama !27_V
49342	vehiti	vehi	vehkima	28_V	IndIpfIps	et	vehiti =vehi  (IndIpfIps  >vehkima !28_V
49343	jääkide	jääki	jääk	22_S	PlG	et	jääkide =jääki  (PlG  >jääk !22_S
49347	pabistan	pabista	pabistama	27_V	IndPrSg1	et	pabistan =pabista  (IndPrSg1  >pabistama !27_V
49352	lõbustan	lõbusta	lõbustama	27_V	IndPrSg1	et	lõbustan =lõbusta  (IndPrSg1  >lõbustama !27_V
49355	ühisgümnaasium	gümnaasium	ühis+gümnaasium	19~02_S	SgN	et	ühisgümnaasium =gümnaasium  (SgN  >ühis+gümnaasium !19~02_S
49358	kung-fu-ga	kung-fu	kung-fu	xx_Q	SgKom	et	kung-fu-ga =kung-fu  (SgKom  >kung-fu !xx_Q
49374	jutustage	jutusta	jutustama	27_V	ImpPrPl2	et	jutustage =jutusta  (ImpPrPl2  >jutustama !27_V
49391	preislaste	preislas	preislane	12?10_S	PlG	et	preislaste =preislas  (PlG  >preislane !12?10_S
49393	miilidega	miili	miil	22_S	PlKom	et	miilidega =miili  (PlKom  >miil !22_S
49396	laheni	lahe	laht	22_S	SgTer	et	laheni =lahe  (SgTer  >laht !22_S
49398	asendi	asendi	asend	02_S	SgG	et	asendi =asendi  (SgG  >asend !02_S
49402	moeasjaks	asja	moe+asi	24_S	SgTr	et	moeasjaks =asja  (SgTr  >moe+asi !24_S
49410	ajalike	ajalike	ajalik	25_A	PlG	et	ajalike =ajalike  (PlG  >ajalik !25_A
49413	leetopiss	leetopiss	leetopiss	22_S	SgN	et	leetopiss =leetopiss  (SgN  >leetopiss !22_S
49414	ümberkirjutatuna	kirjutatu	ümber+kirjutatu	01_S	SgEs	et	ümberkirjutatuna =kirjutatu  (SgEs  >ümber+kirjutatu !01_S
49421	taganeda	tagane	taganema	27_V	Inf	et	taganeda =tagane  (Inf  >taganema !27_V
49424	laevadest	laeva	laev	22_S	PlEl	et	laevadest =laeva  (PlEl  >laev !22_S
49425	kindlustise	kindlustise	kindlustis	11_S	SgG	et	kindlustise =kindlustise  (SgG  >kindlustis !11_S
49426	vabadusvõitlusega	võitluse	vabadus+võitlus	11~09_S	SgKom	et	vabadusvõitlusega =võitluse  (SgKom  >vabadus+võitlus !11~09_S
49427	lõplikud	lõpliku	lõplik	25_A	PlN	et	lõplikud =lõpliku  (PlN  >lõplik !25_A
49270	seminarisse	seminari	seminar	19_S	SgIll	et	seminarisse =seminari  (SgIll  >seminar !19_S
49277	siks	si	si	26_S	SgTr	et	siks =si  (SgTr  >si !26_S
49286	miljon	miljon	miljon	02_N	SgN	et	miljon =miljon  (SgN  >miljon !02_N
49289	põhja-meri	meri	põhja-meri	20_S	SgN	et	põhja-meri =meri  (SgN  >põhja-meri !20_S
49290	ida-meri	meri	ida-meri	20_S	SgN	et	ida-meri =meri  (SgN  >ida-meri !20_S
49294	ehmuma	ehmu	ehmuma	27_V	Sup	et	ehmuma =ehmu  (Sup  >ehmuma !27_V
49308	klassikaaslasele	kaaslase	klassi+kaaslane	12?10_S	SgAll	et	klassikaaslasele =kaaslase  (SgAll  >klassi+kaaslane !12?10_S
49315	spordidress	dress	spordi+dress	22_S	SgN	et	spordidress =dress  (SgN  >spordi+dress !22_S
49323	isepäine	päine	ise+päine	10_A	SgN	et	isepäine =päine  (SgN  >ise+päine !10_A
49325	personalil	personali	personal	19_S	SgAd	et	personalil =personali  (SgAd  >personal !19_S
49330	loodussaated	saate	loodus+saade	06_S	PlN	et	loodussaated =saate  (PlN  >loodus+saade !06_S
49335	padjal	padja	padi	24_S	SgAd	et	padjal =padja  (SgAd  >padi !24_S
49346	närvitsen	närvitse	närvitsema	27_V	IndPrSg1	et	närvitsen =närvitse  (IndPrSg1  >närvitsema !27_V
49363	lobiseme	lobise	lobisema	27_V	IndPrPl1	et	lobiseme =lobise  (IndPrPl1  >lobisema !27_V
49367	kohustisi	kohustisi	kohustis	11_S	PlP	et	kohustisi =kohustisi  (PlP  >kohustis !11_S
49371	paluda	palu	paluma	27_V	Inf	et	paluda =palu  (Inf  >paluma !27_V
49373	koolipäevad	päeva	kooli+päev	22_S	PlN	et	koolipäevad =päeva  (PlN  >kooli+päev !22_S
49378	seniajani	seniajani	seni+ajani	41_D	ID	et	seniajani =seniajani  (ID  >seni+ajani !41_D
49379	heidab	heida	heitma	34_V	IndPrSg3	et	heidab =heida  (IndPrSg3  >heitma !34_V
49381	kaaliga	kaali	kaal	22_S	SgKom	et	kaaliga =kaali  (SgKom  >kaal !22_S
49386	hõimult	hõimu	hõim	22_S	SgAbl	et	hõimult =hõimu  (SgAbl  >hõim !22_S
49390	gootide	gooti	goot	22_S	PlG	et	gootide =gooti  (PlG  >goot !22_S
49394	tervik	tervik	tervik	02_S	SgN	et	tervik =tervik  (SgN  >tervik !02_S
49395	rannikut	ranniku	rannik	02_S	SgP	et	rannikut =ranniku  (SgP  >rannik !02_S
49405	leetopissid	leetopissi	leetopiss	22_S	PlN	et	leetopissid =leetopissi  (PlN  >leetopiss !22_S
49406	ruunikivide	kivi	ruuni+kivi	17_S	PlG	et	ruunikivide =kivi  (PlG  >ruuni+kivi !17_S
49416	nooleteravik	teravik	noole+teravik	25_S	SgN	et	nooleteravik =teravik  (SgN  >noole+teravik !25_S
49420	justnagu	justnagu	just+nagu	41_J	ID	et	justnagu =justnagu  (ID  >just+nagu !41_J
49422	väejuhid	juhi	väe+juht	22_S	PlN	et	väejuhid =juhi  (PlN  >väe+juht !22_S
49423	tähelepanuta	panu	tähele+panu	17_S	SgAb	et	tähelepanuta =panu  (SgAb  >tähele+panu !17_S
49429	sotsiaaltagatised	tagatise	sotsiaal+tagatis	11_S	PlN	et	sotsiaaltagatised =tagatise  (PlN  >sotsiaal+tagatis !11_S
49433	rahaasjus	asju	raha+asi	24_S	PlIn	et	rahaasjus =asju  (PlIn  >raha+asi !24_S
49434	rühmasse	rühma	rühm	22_S	SgIll	et	rühmasse =rühma  (SgIll  >rühm !22_S
49435	stressist	stressi	stress	22_S	SgEl	et	stressist =stressi  (SgEl  >stress !22_S
49436	leidsite	leid	leidma	34_V	IndIpfPl2	et	leidsite =leid  (IndIpfPl2  >leidma !34_V
49440	pärivett	pärivett	päri+vett	41_D	ID	et	pärivett =pärivett  (ID  >päri+vett !41_D
49442	teadlaseks	teadlase	teadlane	12?10_S	SgTr	et	teadlaseks =teadlase  (SgTr  >teadlane !12?10_S
49444	rahaasju	asju	raha+asi	24_S	PlP	et	rahaasju =asju  (PlP  >raha+asi !24_S
49447	üldvaates	vaate	üld+vaade	06_S	SgIn	et	üldvaates =vaate  (SgIn  >üld+vaade !06_S
49449	väärtusliku	väärtusliku	väärtuslik	25_A	SgG	et	väärtusliku =väärtusliku  (SgG  >väärtuslik !25_A
49450	mõistetega	mõiste	mõiste	06_S	PlKom	et	mõistetega =mõiste  (PlKom  >mõiste !06_S
49455	petta	pett	petma	35_V	Inf	et	petta =pett  (Inf  >petma !35_V
49457	sõnadeks	sõna	sõna	17_S	PlTr	et	sõnadeks =sõna  (PlTr  >sõna !17_S
49465	järgmisele	järgmise	järgmine	12?10_A	SgAll	et	järgmisele =järgmise  (SgAll  >järgmine !12?10_A
49479	uurisin	uuri	uurima	28_V	IndIpfSg1	et	uurisin =uuri  (IndIpfSg1  >uurima !28_V
49482	seletas	seleta	seletama	27_V	IndIpfSg3	et	seletas =seleta  (IndIpfSg3  >seletama !27_V
49485	miinimum	miinimum	miinimum	19_S	SgN	et	miinimum =miinimum  (SgN  >miinimum !19_S
49497	millisele	millise	milline	10_P	SgAll	et	millisele =millise  (SgAll  >milline !10_P
49501	eristuda	eristu	eristuma	27_V	Inf	et	eristuda =eristu  (Inf  >eristuma !27_V
49502	kaaslased	kaaslase	kaaslane	12?10_S	PlN	et	kaaslased =kaaslase  (PlN  >kaaslane !12?10_S
49507	kavalad	kavala	kaval	02_A	PlN	et	kavalad =kavala  (PlN  >kaval !02_A
49511	viibime	viibi	viibima	27_V	IndPrPl1	et	viibime =viibi  (IndPrPl1  >viibima !27_V
49514	noorsugude	sugu	noor+sugu	18_S	PlG	et	noorsugude =sugu  (PlG  >noor+sugu !18_S
49518	üleliigis	liigi	üle+liik	22_S	SgIn	et	üleliigis =liigi  (SgIn  >üle+liik !22_S
49304	ümberkasvatamiseks	kasvatamise	ümber+kasvatamine	12_S	SgTr	et	ümberkasvatamiseks =kasvatamise  (SgTr  >ümber+kasvatamine !12_S
49305	sõbrannateid	te	sõbranna+tee	26_S	PlP	et	sõbrannateid =te  (PlP  >sõbranna+tee !26_S
49309	porgandiga	porgandi	porgand	02_S	SgKom	et	porgandiga =porgandi  (SgKom  >porgand !02_S
49313	kilpkonn	konn	kilp+konn	22_S	SgN	et	kilpkonn =konn  (SgN  >kilp+konn !22_S
49316	tumeda	tumeda	tume	02_A	SgG	et	tumeda =tumeda  (SgG  >tume !02_A
49317	ülemvahil	vahi	ülem+vaht	22_S	SgAd	et	ülemvahil =vahi  (SgAd  >ülem+vaht !22_S
49318	lamada	lama	lamama	27_V	Inf	et	lamada =lama  (Inf  >lamama !27_V
49320	taldriku	taldriku	taldrik	02_S	SgG	et	taldriku =taldriku  (SgG  >taldrik !02_S
49321	erikoostisega	koostise	eri+koostis	11~09_S	SgKom	et	erikoostisega =koostise  (SgKom  >eri+koostis !11~09_S
49324	safaripargis	pargi	safari+park	22_S	SgIn	et	safaripargis =pargi  (SgIn  >safari+park !22_S
49333	saagina	saagi	saak	22_S	SgEs	et	saagina =saagi  (SgEs  >saak !22_S
49341	prügikast	kast	prügi+kast	22_S	SgN	et	prügikast =kast  (SgN  >prügi+kast !22_S
49348	muredest	mure	mure	16_S	PlEl	et	muredest =mure  (PlEl  >mure !16_S
49349	nõuandeid	ande	nõu+anne	06_S	PlP	et	nõuandeid =ande  (PlP  >nõu+anne !06_S
49350	targas	targa	tark	22_AS	SgIn	et	targas =targa  (SgIn  >tark !22_AS
49356	lemmikõppeaineid	aine	lemmik+õppe+aine	06_S	PlP	et	lemmikõppeaineid =aine  (PlP  >lemmik+õppe+aine !06_S
49357	ühiskonnaõpetus	õpetus	ühis+konna+õpetus	11_S	SgN	et	ühiskonnaõpetus =õpetus  (SgN  >ühis+konna+õpetus !11_S
49362	õnnitlema	õnnitle	õnnitlema	27_V	Sup	et	õnnitlema =õnnitle  (Sup  >õnnitlema !27_V
49366	kutsekeskharidus	haridus	kutse+kesk+haridus	11_S	SgN	et	kutsekeskharidus =haridus  (SgN  >kutse+kesk+haridus !11_S
49368	silman	silma	silmama	29_V	IndPrSg1	et	silman =silma  (IndPrSg1  >silmama !29_V
49370	detektiivid	detektiivi	detektiiv	22_S	PlN	et	detektiivid =detektiivi  (PlN  >detektiiv !22_S
49375	vaikib	vaiki	vaikima	27_V	IndPrSg3	et	vaikib =vaiki  (IndPrSg3  >vaikima !27_V
49376	maailmapildist	pildi	maa+ilma+pilt	22_S	SgEl	et	maailmapildist =pildi  (SgEl  >maa+ilma+pilt !22_S
49377	maailmameri	meri	maa+ilma+meri	20_S	SgN	et	maailmameri =meri  (SgN  >maa+ilma+meri !20_S
49380	ajaloolasi	loolasi	aja+loolane	12_S	PlP	et	ajaloolasi =loolasi  (PlP  >aja+loolane !12_S
49383	pealtnägijatele	nägija	pealt+nägija	01_S	PlAll	et	pealtnägijatele =nägija  (PlAll  >pealt+nägija !01_S
49387	hõimule	hõimu	hõim	22_S	SgAll	et	hõimule =hõimu  (SgAll  >hõim !22_S
49388	nägemast	näge	nägema	28_V	SupEl	et	nägemast =näge  (SupEl  >nägema !28_V
49389	idamere-suund	suund	idamere-suund	22_S	SgN	et	idamere-suund =suund  (SgN  >idamere-suund !22_S
49397	hõime	hõime	hõim	22_S	PlP	et	hõime =hõime  (PlP  >hõim !22_S
49401	haudades	hauda	haud	22_S	PlIn	et	haudades =hauda  (PlIn  >haud !22_S
49407	kirjalikeks	kirjalike	kirjalik	25_A	PlTr	et	kirjalikeks =kirjalike  (PlTr  >kirjalik !25_A
49411	nestor	nestor	nestor	02_S	SgN	et	nestor =nestor  (SgN  >nestor !02_S
49412	originaalkujul	kuju	originaal+kuju	17_S	SgAd	et	originaalkujul =kuju  (SgAd  >originaal+kuju !17_S
49415	sõjakäigu	käigu	sõja+käik	22_S	SgG	et	sõjakäigu =käigu  (SgG  >sõja+käik !22_S
49432	tõendada	tõenda	tõendama	27_V	Inf	et	tõendada =tõenda  (Inf  >tõendama !27_V
49437	asjalikud	asjaliku	asjalik	25_A	PlN	et	asjalikud =asjaliku  (PlN  >asjalik !25_A
49438	sihiteadlikud	teadliku	sihi+teadlik	25_A	PlN	et	sihiteadlikud =teadliku  (PlN  >sihi+teadlik !25_A
49446	õppetavad	tava	õppe+tava	17_S	PlN	et	õppetavad =tava  (PlN  >õppe+tava !17_S
49456	tegite	teg	tegema	28_V	IndIpfPl2	et	tegite =teg  (IndIpfPl2  >tegema !28_V
49459	kujutate	kujuta	kujutama	27_V	IndPrPl2	et	kujutate =kujuta  (IndPrPl2  >kujutama !27_V
49461	ootasite	oota	ootama	29_V	IndIpfPl2	et	ootasite =oota  (IndIpfPl2  >ootama !29_V
49463	sooritan	soorita	sooritama	27_V	IndPrSg1	et	sooritan =soorita  (IndPrSg1  >sooritama !27_V
49471	sõidavadki	sõida	sõitma	34_V	IndPrPl3^	et	sõidavadki =sõida  (IndPrPl3^  >sõitma !34_V
49477	kaalutleda	kaalutle	kaalutlema	27_V	Inf	et	kaalutleda =kaalutle  (Inf  >kaalutlema !27_V
49478	lõpueksamite	eksami	lõpu+eksam	02_S	PlG	et	lõpueksamite =eksami  (PlG  >lõpu+eksam !02_S
49481	paigalseisuks	seisu	paigal+seis	22_S	SgTr	et	paigalseisuks =seisu  (SgTr  >paigal+seis !22_S
49488	otsustan	otsusta	otsustama	27_V	IndPrSg1	et	otsustan =otsusta  (IndPrSg1  >otsustama !27_V
49491	kavatseb	kavatse	kavatsema	27_V	IndPrSg3	et	kavatseb =kavatse  (IndPrSg3  >kavatsema !27_V
49496	disainer	disainer	disainer	02_S	SgN	et	disainer =disainer  (SgN  >disainer !02_S
49499	palgaks	palga	palk	22_S	SgTr	et	palgaks =palga  (SgTr  >palk !22_S
49500	heaolutunne	tunne	hea+olu+tunne	06_S	SgN	et	heaolutunne =tunne  (SgN  >hea+olu+tunne !06_S
49503	mereväes	väe	mere+vägi	21_S	SgIn	et	mereväes =väe  (SgIn  >mere+vägi !21_S
49336	lõvidega	lõvi	lõvi	17_S	PlKom	et	lõvidega =lõvi  (PlKom  >lõvi !17_S
49337	asjatundjaga	tundja	asja+tundja	01_S	SgKom	et	asjatundjaga =tundja  (SgKom  >asja+tundja !01_S
49340	patareide	patarei	patarei	26_S	PlG	et	patareide =patarei  (PlG  >patarei !26_S
49354	käpa	käpa	käpp	22_S	SgG	et	käpa =käpa  (SgG  >käpp !22_S
49359	pühapäevad	päeva	püha+päev	22_S	PlN	et	pühapäevad =päeva  (PlN  >püha+päev !22_S
49364	üksinduses	üksinduse	üksindus	11_S	SgIn	et	üksinduses =üksinduse  (SgIn  >üksindus !11_S
49369	ehitame	ehita	ehitama	27_V	IndPrPl1	et	ehitame =ehita  (IndPrPl1  >ehitama !27_V
49372	konkursse	konkursse	konkurss	22_S	PlP	et	konkursse =konkursse  (PlP  >konkurss !22_S
49382	meteoriidikraatri	kraatri	meteoriidi+kraater	02_S	SgG	et	meteoriidikraatri =kraatri  (SgG  >meteoriidi+kraater !02_S
49400	roomlasi	roomlasi	roomlane	12_S	PlP	et	roomlasi =roomlasi  (PlP  >roomlane !12_S
49403	eestid	eesti	eesti	16_H	PlN	et	eestid =eesti  (PlN  >eesti !16_H
49409	leetopissiks	leetopissi	leetopiss	22_S	SgTr	et	leetopissiks =leetopissi  (SgTr  >leetopiss !22_S
49417	vägedes	väge	vägi	21_S	PlIn	et	vägedes =väge  (PlIn  >vägi !21_S
49419	kurelased	kurelase	kurelane	12_S	PlN	et	kurelased =kurelase  (PlN  >kurelane !12_S
49441	riskigrupp	grupp	riski+grupp	22_S	SgN	et	riskigrupp =grupp  (SgN  >riski+grupp !22_S
49452	liigvähendavad	vähendava	liig+vähendav	02_A	PlN	et	liigvähendavad =vähendava  (PlN  >liig+vähendav !02_A
49454	kujutleks	kujutle	kujutlema	27_V	KndPrPs	et	kujutleks =kujutle  (KndPrPs  >kujutlema !27_V
49458	pretensioonid	pretensiooni	pretensioon	22_S	PlN	et	pretensioonid =pretensiooni  (PlN  >pretensioon !22_S
49464	klassitoas	toa	klassi+tuba	18_S	SgIn	et	klassitoas =toa  (SgIn  >klassi+tuba !18_S
49474	lükkab	lükka	lükkama	29_V	IndPrSg3	et	lükkab =lükka  (IndPrSg3  >lükkama !29_V
49476	eluaspekte	aspekte	elu+aspekt	22_S	PlP	et	eluaspekte =aspekte  (PlP  >elu+aspekt !22_S
49480	pangandus	pangandus	pangandus	11_S	SgN	et	pangandus =pangandus  (SgN  >pangandus !11_S
49483	elukutsete	kutse	elu+kutse	06_S	PlG	et	elukutsete =kutse  (PlG  >elu+kutse !06_S
49484	rahaküsimuse	küsimuse	raha+küsimus	11_S	SgG	et	rahaküsimuse =küsimuse  (SgG  >raha+küsimus !11_S
49489	riskima	riski	riskima	28_V	Sup	et	riskima =riski  (Sup  >riskima !28_V
49492	disaineriks	disaineri	disainer	02_S	SgTr	et	disaineriks =disaineri  (SgTr  >disainer !02_S
49493	hingemeelne	meelne	hinge+meelne	02_A	SgN	et	hingemeelne =meelne  (SgN  >hinge+meelne !02_A
49495	disaineri	disaineri	disainer	02_S	SgG	et	disaineri =disaineri  (SgG  >disainer !02_S
49504	kirjeldasite	kirjelda	kirjeldama	27_V	IndIpfPl2	et	kirjeldasite =kirjelda  (IndIpfPl2  >kirjeldama !27_V
49512	töökohtadele	kohta	töö+koht	22_S	PlAll	et	töökohtadele =kohta  (PlAll  >töö+koht !22_S
49522	arutaksin	aruta	arutama	27_V	KndPrSg1	et	arutaksin =aruta  (KndPrSg1  >arutama !27_V
49524	töölisena	töölise	tööline	12?10_S	SgEs	et	töölisena =töölise  (SgEs  >tööline !12?10_S
49526	noorpõlvkond	põlvkond	noor+põlvkond	22_S	SgN	et	noorpõlvkond =põlvkond  (SgN  >noor+põlvkond !22_S
49530	noorinimesed	inimese	noor+inimene	12_S	PlN	et	noorinimesed =inimese  (PlN  >noor+inimene !12_S
49549	loengult	loengu	loeng	02_S	SgAbl	et	loengult =loengu  (SgAbl  >loeng !02_S
49552	raamatupidajaks	pidaja	raamatu+pidaja	01_S	SgTr	et	raamatupidajaks =pidaja  (SgTr  >raamatu+pidaja !01_S
49554	püssis	püssi	püss	22_S	SgIn	et	püssis =püssi  (SgIn  >püss !22_S
49573	õppevahenditeks	vahendi	õppe+vahend	02_S	PlTr	et	õppevahenditeks =vahendi  (PlTr  >õppe+vahend !02_S
49576	sissetulekute	tuleku	sisse+tulek	02_S	PlG	et	sissetulekute =tuleku  (PlG  >sisse+tulek !02_S
49578	kõrgtase	tase	kõrg+tase	04_S	SgN	et	kõrgtase =tase  (SgN  >kõrg+tase !04_S
49582	kabinetid	kabineti	kabinet	22_S	PlN	et	kabinetid =kabineti  (PlN  >kabinet !22_S
49589	maleklubis	klubi	male+klubi	17_S	SgIn	et	maleklubis =klubi  (SgIn  >male+klubi !17_S
49593	üliõpilaselt	õpilase	üli+õpilane	12_S	SgAbl	et	üliõpilaselt =õpilase  (SgAbl  >üli+õpilane !12_S
49594	maksupress	press	maksu+press	22_S	SgN	et	maksupress =press  (SgN  >maksu+press !22_S
49603	teatrikultuur	kultuur	teatri+kultuur	22_S	SgN	et	teatrikultuur =kultuur  (SgN  >teatri+kultuur !22_S
49607	sündimust	sündimus	sündimus	11_S	SgP	et	sündimust =sündimus  (SgP  >sündimus !11_S
49610	pearollis	rolli	pea+roll	22_S	SgIn	et	pearollis =rolli  (SgIn  >pea+roll !22_S
49614	visuaalset	visuaalse	visuaalne	02_A	SgP	et	visuaalset =visuaalse  (SgP  >visuaalne !02_A
49621	saake	saake	saak	22_S	PlP	et	saake =saake  (PlP  >saak !22_S
49622	sorte	sorte	sort	22_S	PlP	et	sorte =sorte  (PlP  >sort !22_S
49623	koosolekut	oleku	koos+olek	02_S	SgP	et	koosolekut =oleku  (SgP  >koos+olek !02_S
49630	polütehnikum	polütehnikum	polütehnikum	19_S	SgN	et	polütehnikum =polütehnikum  (SgN  >polütehnikum !19_S
49428	kulun	kulu	kuluma	27_V	IndPrSg1	et	kulun =kulu  (IndPrSg1  >kuluma !27_V
49431	lubaks	luba	lubama	27_V	KndPrPs	et	lubaks =luba  (KndPrPs  >lubama !27_V
49439	elumõte	mõte	elu+mõte	06_S	SgN	et	elumõte =mõte  (SgN  >elu+mõte !06_S
49443	õppust	õppus	õppus	11~09_S	SgP	et	õppust =õppus  (SgP  >õppus !11~09_S
49448	nõudlused	nõudluse	nõudlus	11~09_S	PlN	et	nõudlused =nõudluse  (PlN  >nõudlus !11~09_S
49451	ühikut	ühiku	ühik	02_S	SgP	et	ühikut =ühiku  (SgP  >ühik !02_S
49462	kindlaid	kindla	kindel	02_A	PlP	et	kindlaid =kindla  (PlP  >kindel !02_A
49466	õpinguprogramm	programm	õpingu+programm	22_S	SgN	et	õpinguprogramm =programm  (SgN  >õpingu+programm !22_S
49467	üleõpilased	õpilase	üle+õpilane	12_S	PlN	et	üleõpilased =õpilase  (PlN  >üle+õpilane !12_S
49468	individuaalne	individuaalne	individuaalne	02_A	SgN	et	individuaalne =individuaalne  (SgN  >individuaalne !02_A
49472	nooruslik	nooruslik	nooruslik	25_A	SgN	et	nooruslik =nooruslik  (SgN  >nooruslik !25_A
49473	ind	ind	ind	22_S	SgN	et	ind =ind  (SgN  >ind !22_S
49475	vähenõudlikest	nõudlike	vähe+nõudlik	25_A	PlEl	et	vähenõudlikest =nõudlike  (PlEl  >vähe+nõudlik !25_A
49486	elumoodse	moodse	elu+moodne	02_A	SgG	et	elumoodse =moodse  (SgG  >elu+moodne !02_A
49490	sundisite	sundi	sundima	28_V	IndIpfPl2	et	sundisite =sundi  (IndIpfPl2  >sundima !28_V
49498	tunduma	tundu	tunduma	27_V	Sup	et	tunduma =tundu  (Sup  >tunduma !27_V
49505	ebaaktiivne	aktiivne	eba+aktiivne	02_A	SgN	et	ebaaktiivne =aktiivne  (SgN  >eba+aktiivne !02_A
49509	optimistid	optimisti	optimist	22_S	PlN	et	optimistid =optimisti  (PlN  >optimist !22_S
49510	oskaksin	oska	oskama	29_V	KndPrSg1	et	oskaksin =oska  (KndPrSg1  >oskama !29_V
49515	tunnistan	tunnista	tunnistama	27_V	IndPrSg1	et	tunnistan =tunnista  (IndPrSg1  >tunnistama !27_V
49517	normalselt	alse	norm+alss	22_S	PlAbl	et	normalselt =alse  (PlAbl  >norm+alss !22_S
49525	sihikindlad	kindla	sihi+kindel	02_A	PlN	et	sihikindlad =kindla  (PlN  >sihi+kindel !02_A
49532	elunõuded	nõude	elu+nõue	06_S	PlN	et	elunõuded =nõude  (PlN  >elu+nõue !06_S
49537	ekstraordinaarseid	ordinaarse	ekstra+ordinaarne	02_A	PlP	et	ekstraordinaarseid =ordinaarse  (PlP  >ekstra+ordinaarne !02_A
49538	edasilükkavaid	lükkava	edasi+lükkav	02_A	PlP	et	edasilükkavaid =lükkava  (PlP  >edasi+lükkav !02_A
49541	erialasse	ala	eri+ala	17_S	SgIll	et	erialasse =ala  (SgIll  >eri+ala !17_S
49543	kanged	kange	kange	01_A	PlN	et	kanged =kange  (PlN  >kange !01_A
49545	kaitseväkke	väkke	kaitse+vägi	21_S	SgAdt	et	kaitseväkke =väkke  (SgAdt  >kaitse+vägi !21_S
49551	maatemaatikat	temaatika	maa+temaatika	01_S	SgP	et	maatemaatikat =temaatika  (SgP  >maa+temaatika !01_S
49557	elemendi	elemendi	element	22_S	SgG	et	elemendi =elemendi  (SgG  >element !22_S
49559	huvitun	huvitu	huvituma	27_V	IndPrSg1	et	huvitun =huvitu  (IndPrSg1  >huvituma !27_V
49561	treeningu-	treeningu	treening	02_S	SgG	et	treeningu- =treeningu  (SgG  >treening !02_S
49571	üliõpilaselamud	elamu	üli+õpilas+elamu	01_S	PlN	et	üliõpilaselamud =elamu  (PlN  >üli+õpilas+elamu !01_S
49574	maksumusega	maksumuse	maksumus	11_S	SgKom	et	maksumusega =maksumuse  (SgKom  >maksumus !11_S
49580	tsiviilehituses	ehituse	tsiviil+ehitus	11_S	SgIn	et	tsiviilehituses =ehituse  (SgIn  >tsiviil+ehitus !11_S
49585	täiendõpe	õpe	täiend+õpe	06_S	SgN	et	täiendõpe =õpe  (SgN  >täiend+õpe !06_S
49588	targed	targe	targema	27_V	IndPrSg2	et	targed =targe  (IndPrSg2  >targema !27_V
49597	aasate	aasa	aasama	29_V	IndPrPl2	et	aasate =aasa  (IndPrPl2  >aasama !29_V
49598	millistest	millis	milline	10_P	PlEl	et	millistest =millis  (PlEl  >milline !10_P
49599	plakatid	plakati	plakat	02_S	PlN	et	plakatid =plakati  (PlN  >plakat !02_S
49608	vapustas	vapusta	vapustama	27_V	IndIpfSg3	et	vapustas =vapusta  (IndIpfSg3  >vapustama !27_V
49611	loenguses	use	loeng+usk	22_S	PlIn	et	loenguses =use  (PlIn  >loeng+usk !22_S
49625	postitöölised	töölise	posti+tööline	12?10_S	PlN	et	postitöölised =töölise  (PlN  >posti+tööline !12?10_S
49635	jooksisid	jooksi	jooks	22_S	PlP	et	jooksisid =jooksi  (PlP  >jooks !22_S
49643	reasse	rea	rida	18_S	SgIll	et	reasse =rea  (SgIll  >rida !18_S
49654	tunnetada	tunneta	tunnetama	27_V	Inf	et	tunnetada =tunneta  (Inf  >tunnetama !27_V
49655	komponentidele	komponenti	komponent	22_S	PlAll	et	komponentidele =komponenti  (PlAll  >komponent !22_S
49658	inimesehakatis	hakatis	inimese+hakatis	11_S	SgN	et	inimesehakatis =hakatis  (SgN  >inimese+hakatis !11_S
49659	aegruumis	ruumi	aeg+ruum	22_S	SgIn	et	aegruumis =ruumi  (SgIn  >aeg+ruum !22_S
49667	raamide	raami	raam	22_S	PlG	et	raamide =raami  (PlG  >raam !22_S
49671	minapildile	pildi	mina+pilt	22_S	SgAll	et	minapildile =pildi  (SgAll  >mina+pilt !22_S
49672	tahkudena	tahku	tahk	22_S	PlEs	et	tahkudena =tahku  (PlEs  >tahk !22_S
49673	mitmekeelses	keelse	mitme+keelne	02_A	SgIn	et	mitmekeelses =keelse  (SgIn  >mitme+keelne !02_A
49460	rühmadele	rühma	rühm	22_S	PlAll	et	rühmadele =rühma  (PlAll  >rühm !22_S
49469	vaadete	vaade	vaade	06_S	PlG	et	vaadete =vaade  (PlG  >vaade !06_S
49470	pangale	panga	pank	22_S	SgAll	et	pangale =panga  (SgAll  >pank !22_S
49487	materialism	materialism	materialism	22_S	SgN	et	materialism =materialism  (SgN  >materialism !22_S
49494	keskmised	keskmise	keskmine	12?10_A	PlN	et	keskmised =keskmise  (PlN  >keskmine !12?10_A
49513	õigupoolest	õigupoolest	õigu+poolest	41_D	ID	et	õigupoolest =õigupoolest  (ID  >õigu+poolest !41_D
49519	kapitalistlike	kapitalistlike	kapitalistlik	25_A	PlG	et	kapitalistlike =kapitalistlike  (PlG  >kapitalistlik !25_A
49520	katab	kata	katma	35_V	IndPrSg3	et	katab =kata  (IndPrSg3  >katma !35_V
49527	koostasin	koosta	koostama	27_V	IndIpfSg1	et	koostasin =koosta  (IndIpfSg1  >koostama !27_V
49529	õpitanud	tanu	õpi+tanu	17_S	PlN	et	õpitanud =tanu  (PlN  >õpi+tanu !17_S
49531	eksaamitulemused	tulemuse	eks+aami+tulemus	11_S	PlN	et	eksaamitulemused =tulemuse  (PlN  >eks+aami+tulemus !11_S
49534	teenid	teeni	teenima	28_V	IndPrSg2	et	teenid =teeni  (IndPrSg2  >teenima !28_V
49539	plaanidega	plaani	plaan	22_S	PlKom	et	plaanidega =plaani  (PlKom  >plaan !22_S
49550	esitasin	esita	esitama	27_V	IndIpfSg1	et	esitasin =esita  (IndIpfSg1  >esitama !27_V
49553	kirjalik-	kirjalik	kirjalik	25_A	SgN	et	kirjalik- =kirjalik  (SgN  >kirjalik !25_A
49558	e-betoonelemendis	elemendi	e-betoon+element	22_S	SgIn	et	e-betoonelemendis =elemendi  (SgIn  >e-betoon+element !22_S
49562	võistlusväljak	väljak	võistlus+väljak	02_S	SgN	et	võistlusväljak =väljak  (SgN  >võistlus+väljak !02_S
49566	sulg-	sulg	sulg	22_S	SgN	et	sulg- =sulg  (SgN  >sulg !22_S
49572	arvutuskeskuse	keskuse	arvutus+keskus	11~09_S	SgG	et	arvutuskeskuse =keskuse  (SgG  >arvutus+keskus !11~09_S
49579	keskkonnatehnikas	tehnika	kesk+konna+tehnika	01_S	SgIn	et	keskkonnatehnikas =tehnika  (SgIn  >kesk+konna+tehnika !01_S
49583	praktikumid	praktikumi	praktikum	19_S	PlN	et	praktikumid =praktikumi  (PlN  >praktikum !19_S
49584	diskreetne	diskreetne	diskreetne	02_A	SgN	et	diskreetne =diskreetne  (SgN  >diskreetne !02_A
49590	kohvid	kohvi	kohv	22_S	PlN	et	kohvid =kohvi  (PlN  >kohv !22_S
49592	ökonoomikat	ökonoomika	ökonoomika	01_S	SgP	et	ökonoomikat =ökonoomika  (SgP  >ökonoomika !01_S
49595	olukorral	korra	olu+kord	22_S	SgAd	et	olukorral =korra  (SgAd  >olu+kord !22_S
49596	maailmasõjajärgne	järgne	maa+ilma+sõja+järgne	02_A	SgN	et	maailmasõjajärgne =järgne  (SgN  >maa+ilma+sõja+järgne !02_A
49600	voolad	voola	voolama	29_V	IndPrSg2	et	voolad =voola  (IndPrSg2  >voolama !29_V
49602	joodik	joodik	joodik	02_SA	SgN	et	joodik =joodik  (SgN  >joodik !02_SA
49604	keskused	keskuse	keskus	11~09_S	PlN	et	keskused =keskuse  (PlN  >keskus !11~09_S
49605	sulaaeg	aeg	sula+aeg	22_S	SgN	et	sulaaeg =aeg  (SgN  >sula+aeg !22_S
49615	tajuda	taju	tajuma	27_V	Inf	et	tajuda =taju  (Inf  >tajuma !27_V
49618	õpitati	tati	õpi+tatt	22_S	SgG	et	õpitati =tati  (SgG  >õpi+tatt !22_S
49627	kolhoosidel	kolhoosi	kolhoos	22_S	PlAd	et	kolhoosidel =kolhoosi  (PlAd  >kolhoos !22_S
49629	hästikasvatatud	kasvatatu	hästi+kasvatatu	01_S	PlN	et	hästikasvatatud =kasvatatu  (PlN  >hästi+kasvatatu !01_S
49634	ttü-l	ttü	ttü	xx_Q	SgAd	et	ttü-l =ttü  (SgAd  >ttü !xx_Q
49637	ju-doga	do	ju-do	26_S	SgKom	et	ju-doga =do  (SgKom  >ju-do !26_S
49638	ellusuhtumine	suhtumine	ellu+suhtumine	12_S	SgN	et	ellusuhtumine =suhtumine  (SgN  >ellu+suhtumine !12_S
49644	kaasõpilased	õpilase	kaas+õpilane	12_S	PlN	et	kaasõpilased =õpilase  (PlN  >kaas+õpilane !12_S
49647	järelekult	kult	järele+kult	22_S	SgN	et	järelekult =kult  (SgN  >järele+kult !22_S
49650	lõbusas	lõbusa	lõbus	02_A	SgIn	et	lõbusas =lõbusa  (SgIn  >lõbus !02_A
49653	visuaalne	visuaalne	visuaalne	02_A	SgN	et	visuaalne =visuaalne  (SgN  >visuaalne !02_A
49661	tabudeks	tabu	tabu	17_S	PlTr	et	tabudeks =tabu  (PlTr  >tabu !17_S
49662	taluvuspiir	piir	taluvus+piir	22_S	SgN	et	taluvuspiir =piir  (SgN  >taluvus+piir !22_S
49664	diskussioonis	diskussiooni	diskussioon	22_S	SgIn	et	diskussioonis =diskussiooni  (SgIn  >diskussioon !22_S
49665	kumab	kuma	kumama	27_V	IndPrSg3	et	kumab =kuma  (IndPrSg3  >kumama !27_V
49670	samastades	samasta	samastama	27_V	Ger	et	samastades =samasta  (Ger  >samastama !27_V
49676	rullnokad	noka	rull+nokk	22_S	PlN	et	rullnokad =noka  (PlN  >rull+nokk !22_S
49682	isiksustest	isiksus	isiksus	11_S	PlEl	et	isiksustest =isiksus  (PlEl  >isiksus !11_S
49711	ülemaailmse	ilmse	üle+maa+ilmne	02_A	SgG	et	ülemaailmse =ilmse  (SgG  >üle+maa+ilmne !02_A
49713	emotsionaalset	emotsionaalse	emotsionaalne	02_A	SgP	et	emotsionaalset =emotsionaalse  (SgP  >emotsionaalne !02_A
49714	väidab	väida	väitma	34_V	IndPrSg3	et	väidab =väida  (IndPrSg3  >väitma !34_V
49715	intelligentsed	intelligentse	intelligentne	02_A	PlN	et	intelligentsed =intelligentse  (PlN  >intelligentne !02_A
49506	kännud	kännu	känd	22_S	PlN	et	kännud =kännu  (PlN  >känd !22_S
49508	kännu	kännu	känd	22_S	SgG	et	kännu =kännu  (SgG  >känd !22_S
49516	kirjeldaksite	kirjelda	kirjeldama	27_V	KndPrPl2	et	kirjeldaksite =kirjelda  (KndPrPl2  >kirjeldama !27_V
49523	ambitsioosne	ambitsioosne	ambitsioosne	02_A	SgN	et	ambitsioosne =ambitsioosne  (SgN  >ambitsioosne !02_A
49528	tunniplaan	plaan	tunni+plaan	22_S	SgN	et	tunniplaan =plaan  (SgN  >tunni+plaan !22_S
49536	loteriist	loterii	loterii	26_S	SgEl	et	loteriist =loterii  (SgEl  >loterii !26_S
49548	turvateenuse	teenuse	turva+teenus	09_S	SgG	et	turvateenuse =teenuse  (SgG  >turva+teenus !09_S
49556	hõbemedaliga	medali	hõbe+medal	02_S	SgKom	et	hõbemedaliga =medali  (SgKom  >hõbe+medal !02_S
49560	jalgpalliväljak	väljak	jalg+palli+väljak	02_S	SgN	et	jalgpalliväljak =väljak  (SgN  >jalg+palli+väljak !02_S
49563	pallimängudeks	mängu	palli+mäng	22_S	PlTr	et	pallimängudeks =mängu  (PlTr  >palli+mäng !22_S
49564	seinatenniseväljakut	väljaku	seina+tennise+väljak	02_S	SgP	et	seinatenniseväljakut =väljaku  (SgP  >seina+tennise+väljak !02_S
49567	korv-	korv	korv	22_S	SgN	et	korv- =korv  (SgN  >korv !22_S
49575	leibkondade	leibkonda	leibkond	22_S	PlG	et	leibkondade =leibkonda  (PlG  >leibkond !22_S
49581	järeldama	järelda	järeldama	27_V	Sup	et	järeldama =järelda  (Sup  >järeldama !27_V
49586	infotehnoloogiasse	tehnoloogia	info+tehnoloogia	01_S	SgIll	et	infotehnoloogiasse =tehnoloogia  (SgIll  >info+tehnoloogia !01_S
49606	aspektidele	aspekti	aspekt	22_S	PlAll	et	aspektidele =aspekti  (PlAll  >aspekt !22_S
49609	streik	streik	streik	22_S	SgN	et	streik =streik  (SgN  >streik !22_S
49612	kolhoosis	kolhoosi	kolhoos	22_S	SgIn	et	kolhoosis =kolhoosi  (SgIn  >kolhoos !22_S
49613	preemiad	preemia	preemia	01_S	PlN	et	preemiad =preemia  (PlN  >preemia !01_S
49616	eesti-soome-ugri	ugri	eesti-soome-ugri	41_G	ID	et	eesti-soome-ugri =ugri  (ID  >eesti-soome-ugri !41_G
49617	etnograafiat	etnograafia	etnograafia	01_S	SgP	et	etnograafiat =etnograafia  (SgP  >etnograafia !01_S
49619	observatooriumis	observatooriumi	observatoorium	19~02_S	SgIn	et	observatooriumis =observatooriumi  (SgIn  >observatoorium !19~02_S
49620	astronoomiat	astronoomia	astronoomia	01_S	SgP	et	astronoomiat =astronoomia  (SgP  >astronoomia !01_S
49624	üldstreik	streik	üld+streik	22_S	SgN	et	üldstreik =streik  (SgN  >üld+streik !22_S
49631	treenime	treeni	treenima	28_V	IndPrPl1	et	treenime =treeni  (IndPrPl1  >treenima !28_V
49636	humanitaargümnaasiumis	gümnaasiumi	humanitaar+gümnaasium	19~02_S	SgIn	et	humanitaargümnaasiumis =gümnaasiumi  (SgIn  >humanitaar+gümnaasium !19~02_S
49639	riigikeeleoskust	oskus	riigi+keele+oskus	11~09_S	SgP	et	riigikeeleoskust =oskus  (SgP  >riigi+keele+oskus !11~09_S
49641	kvaliteetse	kvaliteetse	kvaliteetne	02_A	SgG	et	kvaliteetse =kvaliteetse  (SgG  >kvaliteetne !02_A
49642	paneme	pane	panema	36_V	IndPrPl1	et	paneme =pane  (IndPrPl1  >panema !36_V
49646	ttü-tudeng	tudeng	ttü-tudeng	02_S	SgN	et	ttü-tudeng =tudeng  (SgN  >ttü-tudeng !02_S
49651	kampaanias	kampaania	kampaania	01_S	SgIn	et	kampaanias =kampaania  (SgIn  >kampaania !01_S
49652	1-sse			xx_Q	SgIll	et	-sse =  (SgIll  > !xx_Q
49660	normideks	normi	norm	22_S	PlTr	et	normideks =normi  (PlTr  >norm !22_S
49684	meeskonnaliikmeid	liikme	mees+konna+liige	05_S	PlP	et	meeskonnaliikmeid =liikme  (PlP  >mees+konna+liige !05_S
49687	pealispinna	pinna	pealis+pind	22_S	SgG	et	pealispinna =pinna  (SgG  >pealis+pind !22_S
49690	lobedast	lobeda	lobe	02_A	SgEl	et	lobedast =lobeda  (SgEl  >lobe !02_A
49691	progressiivsed	progressiivse	progressiivne	02_A	PlN	et	progressiivsed =progressiivse  (PlN  >progressiivne !02_A
49699	oomen	oomen	oomen	02_S	SgN	et	oomen =oomen  (SgN  >oomen !02_S
49704	olemuse	olemuse	olemus	11_S	SgG	et	olemuse =olemuse  (SgG  >olemus !11_S
49705	ulmejutus	jutu	ulme+jutt	22_S	SgIn	et	ulmejutus =jutu  (SgIn  >ulme+jutt !22_S
49706	positsiooniga	positsiooni	positsioon	22_S	SgKom	et	positsiooniga =positsiooni  (SgKom  >positsioon !22_S
49708	normile	normi	norm	22_S	SgAll	et	normile =normi  (SgAll  >norm !22_S
49710	ennatlik	ennatlik	ennatlik	25_A	SgN	et	ennatlik =ennatlik  (SgN  >ennatlik !25_A
49718	tutvustades	tutvusta	tutvustama	27_V	Ger	et	tutvustades =tutvusta  (Ger  >tutvustama !27_V
49721	ihaldab	ihalda	ihaldama	27_V	IndPrSg3	et	ihaldab =ihalda  (IndPrSg3  >ihaldama !27_V
49723	nõeltega	nõel	nõel	23_S	PlKom	et	nõeltega =nõel  (PlKom  >nõel !23_S
49726	kohapealt	pea	koha+pea	26_S	SgAbl	et	kohapealt =pea  (SgAbl  >koha+pea !26_S
49731	paindlikud	paindliku	paindlik	25_A	PlN	et	paindlikud =paindliku  (PlN  >paindlik !25_A
49736	väheke	väheke	väheke	12_S	SgN	et	väheke =väheke  (SgN  >väheke !12_S
49737	lahterdatakse	lahterda	lahterdama	27_V	IndPrIps	et	lahterdatakse =lahterda  (IndPrIps  >lahterdama !27_V
49750	maskuliinsed	maskuliinse	maskuliinne	02_A	PlN	et	maskuliinsed =maskuliinse  (PlN  >maskuliinne !02_A
49751	feminiinsed	feminiinse	feminiinne	02_A	PlN	et	feminiinsed =feminiinse  (PlN  >feminiinne !02_A
49521	väljendasin	väljenda	väljendama	27_V	IndIpfSg1	et	väljendasin =väljenda  (IndIpfSg1  >väljendama !27_V
49533	lõpetad	lõpeta	lõpetama	27_V	IndPrSg2	et	lõpetad =lõpeta  (IndPrSg2  >lõpetama !27_V
49535	erialadele	ala	eri+ala	17_S	PlAll	et	erialadele =ala  (PlAll  >eri+ala !17_S
49540	rehviekspert	ekspert	rehvi+ekspert	22_S	SgN	et	rehviekspert =ekspert  (SgN  >rehvi+ekspert !22_S
49542	rühmal	rühma	rühm	22_S	SgAd	et	rühmal =rühma  (SgAd  >rühm !22_S
49544	kakstuhad	tuha	kaks+tuhk	22_S	PlN	et	kakstuhad =tuha  (PlN  >kaks+tuhk !22_S
49546	pioneeripataljonis	pataljoni	pioneeri+pataljon	19_S	SgIn	et	pioneeripataljonis =pataljoni  (SgIn  >pioneeri+pataljon !19_S
49547	teenistust	teenistus	teenistus	11_S	SgP	et	teenistust =teenistus  (SgP  >teenistus !11_S
49555	näisin	näi	näima	37_V	IndIpfSg1	et	näisin =näi  (IndIpfSg1  >näima !37_V
49565	lauatennise	tennise	laua+tennis	09_S	SgG	et	lauatennise =tennise  (SgG  >laua+tennis !09_S
49568	võrk-	võrk	võrk	22_S	SgN	et	võrk- =võrk  (SgN  >võrk !22_S
49569	spinninguga	spinningu	spinning	02_S	SgKom	et	spinninguga =spinningu  (SgKom  >spinning !02_S
49570	terviseklubis	klubi	tervise+klubi	17_S	SgIn	et	terviseklubis =klubi  (SgIn  >tervise+klubi !17_S
49577	heameelne	meelne	hea+meelne	02_A	SgN	et	heameelne =meelne  (SgN  >hea+meelne !02_A
49587	narva-sse	narva	narva	xx_Q	SgIll	et	narva-sse =narva  (SgIll  >narva !xx_Q
49591	üleõpilasi	õpilasi	üle+õpilane	12_S	PlP	et	üleõpilasi =õpilasi  (PlP  >üle+õpilane !12_S
49601	langusinimesed	inimese	langus+inimene	12_S	PlN	et	langusinimesed =inimese  (PlN  >langus+inimene !12_S
49626	võitlused	võitluse	võitlus	11~09_S	PlN	et	võitlused =võitluse  (PlN  >võitlus !11~09_S
49628	tsivilisatsioon	tsivilisatsioon	tsivilisatsioon	22_S	SgN	et	tsivilisatsioon =tsivilisatsioon  (SgN  >tsivilisatsioon !22_S
49632	ostutaksid	taksi	ostu+taks	22_S	PlN	et	ostutaksid =taksi  (PlN  >ostu+taks !22_S
49633	koolidel	kooli	kool	22_S	PlAd	et	koolidel =kooli  (PlAd  >kool !22_S
49649	digitaalsüsteemide	süsteemi	digitaal+süsteem	22_S	PlG	et	digitaalsüsteemide =süsteemi  (PlG  >digitaal+süsteem !22_S
49666	olemuslik	olemuslik	olemuslik	25_A	SgN	et	olemuslik =olemuslik  (SgN  >olemuslik !25_A
49668	tasakaal	kaal	tasa+kaal	22_S	SgN	et	tasakaal =kaal  (SgN  >tasa+kaal !22_S
49669	teadvustades	teadvusta	teadvustama	27_V	Ger	et	teadvustades =teadvusta  (Ger  >teadvustama !27_V
49679	tavakujutluses	kujutluse	tava+kujutlus	11_S	SgIn	et	tavakujutluses =kujutluse  (SgIn  >tava+kujutlus !11_S
49683	lisaväärtus	väärtus	lisa+väärtus	11~09_S	SgN	et	lisaväärtus =väärtus  (SgN  >lisa+väärtus !11~09_S
49685	efektist	efekti	efekt	22_S	SgEl	et	efektist =efekti  (SgEl  >efekt !22_S
49689	suhtlusoskused	oskuse	suhtlus+oskus	11~09_S	PlN	et	suhtlusoskused =oskuse  (PlN  >suhtlus+oskus !11~09_S
49692	pealtnäha	pealtnäha	pealt+näha	41_D	ID	et	pealtnäha =pealtnäha  (ID  >pealt+näha !41_D
49700	entusiastlik	entusiastlik	entusiastlik	25_A	SgN	et	entusiastlik =entusiastlik  (SgN  >entusiastlik !25_A
49703	murelikke	murelikke	murelik	25_A	PlP	et	murelikke =murelikke  (PlP  >murelik !25_A
49712	rikkudes	rikku	rikkuma	28_V	Ger	et	rikkudes =rikku  (Ger  >rikkuma !28_V
49716	nihutada	nihuta	nihutama	27_V	Inf	et	nihutada =nihuta  (Inf  >nihutama !27_V
49754	kinnisuse	kinnisuse	kinnisus	11_S	SgG	et	kinnisuse =kinnisuse  (SgG  >kinnisus !11_S
49755	rollide	rolli	roll	22_S	PlG	et	rollide =rolli  (PlG  >roll !22_S
49756	piirjooned	joone	piir+joon	13_S	PlN	et	piirjooned =joone  (PlN  >piir+joon !13_S
49765	muudatustele	muudatus	muudatus	11_S	PlAll	et	muudatustele =muudatus  (PlAll  >muudatus !11_S
49770	polariseeritud	seeritu	polari+seeritu	01_AS	PlN	et	polariseeritud =seeritu  (PlN  >polari+seeritu !01_AS
49777	visad	visa	visa	17_A	PlN	et	visad =visa  (PlN  >visa !17_A
49780	tuulde	tuul	tuul	13_S	SgAdt	et	tuulde =tuul  (SgAdt  >tuul !13_S
49782	emana	ema	ema	17_S	SgEs	et	emana =ema  (SgEs  >ema !17_S
49785	üleslaadimise	laadimise	üles+laadimine	12_S	SgG	et	üleslaadimise =laadimise  (SgG  >üles+laadimine !12_S
49787	moesuunal	suuna	moe+suund	22_S	SgAd	et	moesuunal =suuna  (SgAd  >moe+suund !22_S
49790	konstruktiivset	konstruktiivse	konstruktiivne	02_A	SgP	et	konstruktiivset =konstruktiivse  (SgP  >konstruktiivne !02_A
49796	e-poodides	poodi	e-pood	22_S	PlIn	et	e-poodides =poodi  (PlIn  >e-pood !22_S
49805	seminaril	seminari	seminar	19_S	SgAd	et	seminaril =seminari  (SgAd  >seminar !19_S
49815	eetiline	eetiline	eetiline	12_A	SgN	et	eetiline =eetiline  (SgN  >eetiline !12_A
49816	ihkab	ihka	ihkama	29_V	IndPrSg3	et	ihkab =ihka  (IndPrSg3  >ihkama !29_V
49825	lipse	lipse	lips	22_S	PlP	et	lipse =lipse  (PlP  >lips !22_S
49838	feministlik	feministlik	feministlik	25_A	SgN	et	feministlik =feministlik  (SgN  >feministlik !25_A
49844	vastuvõetavad	võetava	vastu+võetav	02_A	PlN	et	vastuvõetavad =võetava  (PlN  >vastu+võetav !02_A
49640	momendini	momendi	moment	22_S	SgTer	et	momendini =momendi  (SgTer  >moment !22_S
49645	sillamäes	mäe	silla+mägi	21_S	SgIn	et	sillamäes =mäe  (SgIn  >silla+mägi !21_S
49648	elektriajamid	ajami	elektri+ajam	02_S	PlN	et	elektriajamid =ajami  (PlN  >elektri+ajam !02_S
49656	grupid	grupi	grupp	22_S	PlN	et	grupid =grupi  (PlN  >grupp !22_S
49657	komponent	komponent	komponent	22_S	SgN	et	komponent =komponent  (SgN  >komponent !22_S
49663	kujunetakse	kujune	kujunema	27_V	IndPrIps	et	kujunetakse =kujune  (IndPrIps  >kujunema !27_V
49677	legendaarsed	legendaarse	legendaarne	02_A	PlN	et	legendaarsed =legendaarse  (PlN  >legendaarne !02_A
49678	mõtestada	mõtesta	mõtestama	27_V	Inf	et	mõtestada =mõtesta  (Inf  >mõtestama !27_V
49680	mahtuda	mahtu	mahtuma	28_V	Inf	et	mahtuda =mahtu  (Inf  >mahtuma !28_V
49681	annete	anne	anne	06_S	PlG	et	annete =anne  (PlG  >anne !06_S
49688	suhtlusoskustel	oskus	suhtlus+oskus	11~09_S	PlAd	et	suhtlusoskustel =oskus  (PlAd  >suhtlus+oskus !11~09_S
49693	tipp-positsioonil	positsiooni	tipp-positsioon	22_S	SgAd	et	tipp-positsioonil =positsiooni  (SgAd  >tipp-positsioon !22_S
49697	ülienergiline	energiline	üli+energiline	12_A	SgN	et	ülienergiline =energiline  (SgN  >üli+energiline !12_A
49698	tegevjuht	juht	tegev+juht	22_S	SgN	et	tegevjuht =juht  (SgN  >tegev+juht !22_S
49709	telepaatiat	telepaatia	telepaatia	01_S	SgP	et	telepaatiat =telepaatia  (SgP  >telepaatia !01_S
49720	praegusega	praeguse	praegune	10~12_A	SgKom	et	praegusega =praeguse  (SgKom  >praegune !10~12_A
49724	kanta	kan	kandma	34_V	IndPrIps_	et	kanta =kan  (IndPrIps_  >kandma !34_V
49735	pingeseisund	seisund	pinge+seisund	02_S	SgN	et	pingeseisund =seisund  (SgN  >pinge+seisund !02_S
49757	juhivad	juhi	juhtima	28_V	IndPrPl3	et	juhivad =juhi  (IndPrPl3  >juhtima !28_V
49758	ettevõtet	võte	ette+võte	06_S	SgP	et	ettevõtet =võte  (SgP  >ette+võte !06_S
49759	kraanat	kraana	kraana	16_S	SgP	et	kraanat =kraana  (SgP  >kraana !16_S
49766	tuultes	tuul	tuul	13_S	PlIn	et	tuultes =tuul  (PlIn  >tuul !13_S
49769	kasvatusviis	viis	kasvatus+viis	22_S	SgN	et	kasvatusviis =viis  (SgN  >kasvatus+viis !22_S
49773	feminiinseid	feminiinse	feminiinne	02_A	PlP	et	feminiinseid =feminiinse  (PlP  >feminiinne !02_A
49778	hüppe	hüppe	hüpe	06_S	SgG	et	hüppe =hüppe  (SgG  >hüpe !06_S
49793	pildiks	pildi	pilt	22_S	SgTr	et	pildiks =pildi  (SgTr  >pilt !22_S
49794	foorumites	foorumi	foorum	02_S	PlIn	et	foorumites =foorumi  (PlIn  >foorum !02_S
49807	räägitigi	räägi	rääkima	28_V	IndIpfIps^	et	räägitigi =räägi  (IndIpfIps^  >rääkima !28_V
49820	tehnoloogiamaailmas	ilma	tehno+loogia+maa+ilm	22_S	SgIn	et	tehnoloogiamaailmas =ilma  (SgIn  >tehno+loogia+maa+ilm !22_S
49822	minad	mina	mina	17_S	PlN	et	minad =mina  (PlN  >mina !17_S
49826	mõttemaailm	ilm	mõtte+maa+ilm	22_S	SgN	et	mõttemaailm =ilm  (SgN  >mõtte+maa+ilm !22_S
49829	seksuaalseid	seksuaalse	seksuaalne	02_A	PlP	et	seksuaalseid =seksuaalse  (PlP  >seksuaalne !02_A
49831	skandaaliga	skandaali	skandaal	22_S	SgKom	et	skandaaliga =skandaali  (SgKom  >skandaal !22_S
49833	eeldatakse	eelda	eeldama	27_V	IndPrIps	et	eeldatakse =eelda  (IndPrIps  >eeldama !27_V
49836	autoriteedi	autoriteedi	autoriteet	22_S	SgG	et	autoriteedi =autoriteedi  (SgG  >autoriteet !22_S
49837	isana	isa	isa	17_S	SgEs	et	isana =isa  (SgEs  >isa !17_S
49856	rollidele	rolli	roll	22_S	PlAll	et	rollidele =rolli  (PlAll  >roll !22_S
49857	karjääriredelil	redeli	karjääri+redel	02_S	SgAd	et	karjääriredelil =redeli  (SgAd  >karjääri+redel !02_S
49858	rollile	rolli	roll	22_S	SgAll	et	rollile =rolli  (SgAll  >roll !22_S
49861	abikaasad	kaasa	abi+kaasa	16_S	PlN	et	abikaasad =kaasa  (PlN  >abi+kaasa !16_S
49864	rõhuasetus	asetus	rõhu+asetus	11_S	SgN	et	rõhuasetus =asetus  (SgN  >rõhu+asetus !11_S
49869	meestekeskses	keskse	meeste+keskne	02_A	SgIn	et	meestekeskses =keskse  (SgIn  >meeste+keskne !02_A
49870	poliitikauudistes	uudis	poliitika+uudis	09_S	PlIn	et	poliitikauudistes =uudis  (PlIn  >poliitika+uudis !09_S
49872	tippjuhi	juhi	tipp+juht	22_S	SgG	et	tippjuhi =juhi  (SgG  >tipp+juht !22_S
49881	tõestama	tõesta	tõestama	27_V	Sup	et	tõestama =tõesta  (Sup  >tõestama !27_V
49887	tõrjuta	tõrju	tõrjuma	28_V	IndPrIps_	et	tõrjuta =tõrju  (IndPrIps_  >tõrjuma !28_V
49889	tõrjutakse	tõrju	tõrjuma	28_V	IndPrIps	et	tõrjutakse =tõrju  (IndPrIps  >tõrjuma !28_V
49893	sadade	sada	sada	18_N	PlG	et	sadade =sada  (PlG  >sada !18_N
49895	roboti-	roboti	robot	02_S	SgG	et	roboti- =roboti  (SgG  >robot !02_S
49896	kirglikud	kirgliku	kirglik	25_A	PlN	et	kirglikud =kirgliku  (PlN  >kirglik !25_A
49904	haridusruum	ruum	haridus+ruum	22_S	SgN	et	haridusruum =ruum  (SgN  >haridus+ruum !22_S
49906	eelistada	eelista	eelistama	27_V	Inf	et	eelistada =eelista  (Inf  >eelistama !27_V
49909	utoopilistena	utoopilis	utoopiline	12_A	PlEs	et	utoopilistena =utoopilis  (PlEs  >utoopiline !12_A
49674	normidele	normi	norm	22_S	PlAll	et	normidele =normi  (PlAll  >norm !22_S
49675	identifitseerib	identifitseeri	identifitseerima	28_V	IndPrSg3	et	identifitseerib =identifitseeri  (IndPrSg3  >identifitseerima !28_V
49686	esmakohtumisel	kohtumise	esma+kohtumine	12_S	SgAd	et	esmakohtumisel =kohtumise  (SgAd  >esma+kohtumine !12_S
49694	teoksil	teoksil	teoksil	41_D	ID	et	teoksil =teoksil  (ID  >teoksil !41_D
49695	osutas	osuta	osutama	27_V	IndIpfSg3	et	osutas =osuta  (IndIpfSg3  >osutama !27_V
49696	kollektiivile	kollektiivi	kollektiiv	22_S	SgAll	et	kollektiivile =kollektiivi  (SgAll  >kollektiiv !22_S
49701	töövõitudele	võitu	töö+võit	22_S	PlAll	et	töövõitudele =võitu  (PlAll  >töö+võit !22_S
49702	tippjuhtide	juhti	tipp+juht	22_S	PlG	et	tippjuhtide =juhti  (PlG  >tipp+juht !22_S
49707	napakaks	napaka	napakas	02_A	SgTr	et	napakaks =napaka  (SgTr  >napakas !02_A
49728	generatsioon	generatsioon	generatsioon	22_S	SgN	et	generatsioon =generatsioon  (SgN  >generatsioon !22_S
49739	mittenormaalsed	normaalse	mitte+normaalne	02_A	PlN	et	mittenormaalsed =normaalse  (PlN  >mitte+normaalne !02_A
49741	justnimelt	nime	just+nimi	20_S	SgAbl	et	justnimelt =nime  (SgAbl  >just+nimi !20_S
49744	vooruste	voorus	voorus	11~09_S	PlG	et	vooruste =voorus  (PlG  >voorus !11~09_S
49746	nentima	nenti	nentima	28_V	Sup	et	nentima =nenti  (Sup  >nentima !28_V
49747	isasid	isa	isa	17_S	PlP	et	isasid =isa  (PlP  >isa !17_S
49748	poegasid	poega	poeg	22_S	PlP	et	poegasid =poega  (PlP  >poeg !22_S
49749	hangivad	hangi	hankima	28_V	IndPrPl3	et	hangivad =hangi  (IndPrPl3  >hankima !28_V
49760	juhtimisoskusi	oskusi	juhtimis+oskus	11_S	PlP	et	juhtimisoskusi =oskusi  (PlP  >juhtimis+oskus !11_S
49762	maskuliinsetest	maskuliinse	maskuliinne	02_A	PlEl	et	maskuliinsetest =maskuliinse  (PlEl  >maskuliinne !02_A
49763	feminiinsetest	feminiinse	feminiinne	02_A	PlEl	et	feminiinsetest =feminiinse  (PlEl  >feminiinne !02_A
49768	joont	joon	joon	13_S	SgP	et	joont =joon  (SgP  >joon !13_S
49772	maskuliinseid	maskuliinse	maskuliinne	02_A	PlP	et	maskuliinseid =maskuliinse  (PlP  >maskuliinne !02_A
49775	sisemiselt	sisemise	sisemine	12_A	SgAbl	et	sisemiselt =sisemise  (SgAbl  >sisemine !12_A
49783	emapalk	palk	ema+palk	22_S	SgN	et	emapalk =palk  (SgN  >ema+palk !22_S
49788	teiseteiste	teiste	teise+teist	22_S	PlP	et	teiseteiste =teiste  (PlP  >teise+teist !22_S
49797	arutelud	arutelu	arutelu	17_S	PlN	et	arutelud =arutelu  (PlN  >arutelu !17_S
49798	jututubades	tuba	jutu+tuba	18_S	PlIn	et	jututubades =tuba  (PlIn  >jutu+tuba !18_S
49802	kirjandusfoorumites	foorumi	kirjandus+foorum	02_S	PlIn	et	kirjandusfoorumites =foorumi  (PlIn  >kirjandus+foorum !02_S
49806	uurimistööst	töö	uurimis+töö	26_S	SgEl	et	uurimistööst =töö  (SgEl  >uurimis+töö !26_S
49809	näitel	näite	näide	06_S	SgAd	et	näitel =näite  (SgAd  >näide !06_S
49810	üleslaadivad	laadiva	üles+laadiv	02_A	PlN	et	üleslaadivad =laadiva  (PlN  >üles+laadiv !02_A
49813	noorteni	noor	noor	13_AS	PlTer	et	noorteni =noor  (PlTer  >noor !13_AS
49819	täiendan	täienda	täiendama	27_V	IndPrSg1	et	täiendan =täienda  (IndPrSg1  >täiendama !27_V
49823	mehelikke	mehelikke	mehelik	25_A	PlP	et	mehelikke =mehelikke  (PlP  >mehelik !25_A
49839	feministid	feministi	feminist	22_S	PlN	et	feministid =feministi  (PlN  >feminist !22_S
49840	võrdset	võrdse	võrdne	02_A	SgP	et	võrdset =võrdse  (SgP  >võrdne !02_A
49843	ametikõrgenduse	kõrgenduse	ameti+kõrgendus	11_S	SgG	et	ametikõrgenduse =kõrgenduse  (SgG  >ameti+kõrgendus !11_S
49848	indiviidina	indiviidi	indiviid	22_S	SgEs	et	indiviidina =indiviidi  (SgEs  >indiviid !22_S
49849	karjääriinimene	inimene	karjääri+inimene	12_S	SgN	et	karjääriinimene =inimene  (SgN  >karjääri+inimene !12_S
49851	kirjeldame	kirjelda	kirjeldama	27_V	IndPrPl1	et	kirjeldame =kirjelda  (IndPrPl1  >kirjeldama !27_V
49854	korrektuurid	korrektuuri	korrektuur	22_S	PlN	et	korrektuurid =korrektuuri  (PlN  >korrektuur !22_S
49859	sotsiaalsele	sotsiaalse	sotsiaalne	02_A	SgAll	et	sotsiaalsele =sotsiaalse  (SgAll  >sotsiaalne !02_A
49860	täidavad	täida	täitma	34_V	IndPrPl3	et	täidavad =täida  (IndPrPl3  >täitma !34_V
49868	naisõiguslased	õiguslase	nais+õiguslane	12_S	PlN	et	naisõiguslased =õiguslase  (PlN  >nais+õiguslane !12_S
49873	transformeerumas	transformeeru	transformeeruma	27_V	SupIn	et	transformeerumas =transformeeru  (SupIn  >transformeeruma !27_V
49884	hasartmängud	mängu	hasart+mäng	22_S	PlN	et	hasartmängud =mängu  (PlN  >hasart+mäng !22_S
49885	minimaalseni	minimaalse	minimaalne	02_A	SgTer	et	minimaalseni =minimaalse  (SgTer  >minimaalne !02_A
49891	leiutistele	leiutis	leiutis	11_S	PlAll	et	leiutistele =leiutis  (PlAll  >leiutis !11_S
49892	peremudel	mudel	pere+mudel	02_S	SgN	et	peremudel =mudel  (SgN  >pere+mudel !02_S
49903	lasteaiaaastad	aasta	laste+aia+aasta	01_S	PlN	et	lasteaiaaastad =aasta  (PlN  >laste+aia+aasta !01_S
49915	universaalset	universaalse	universaalne	02_A	SgP	et	universaalset =universaalse  (SgP  >universaalne !02_A
49717	hõlbustab	hõlbusta	hõlbustama	27_V	IndPrSg3	et	hõlbustab =hõlbusta  (IndPrSg3  >hõlbustama !27_V
49719	nentida	nenti	nentima	28_V	Inf	et	nentida =nenti  (Inf  >nentima !28_V
49722	kultuurinormidele	normi	kultuuri+norm	22_S	PlAll	et	kultuurinormidele =normi  (PlAll  >kultuuri+norm !22_S
49725	teistsugusest	suguse	teist+sugune	10_P	SgEl	et	teistsugusest =suguse  (SgEl  >teist+sugune !10_P
49727	eriajastutel	ajastu	eri+ajastu	01_S	PlAd	et	eriajastutel =ajastu  (PlAd  >eri+ajastu !01_S
49729	tublideks	tubli	tubli	16_A	PlTr	et	tublideks =tubli  (PlTr  >tubli !16_A
49730	eripaikasid	paika	eri+paik	22_S	PlP	et	eripaikasid =paika  (PlP  >eri+paik !22_S
49732	paratamatuses	paratamatuse	paratamatus	11?09_S	SgIn	et	paratamatuses =paratamatuse  (SgIn  >paratamatus !11?09_S
49733	narkojoobes	joobe	narko+joove	06_S	SgIn	et	narkojoobes =joobe  (SgIn  >narko+joove !06_S
49734	paratamatud	paratamatu	paratamatu	01_A	PlN	et	paratamatud =paratamatu  (PlN  >paratamatu !01_A
49738	kastidesse	kasti	kast	22_S	PlIll	et	kastidesse =kasti  (PlIll  >kast !22_S
49740	sõnakõlksud	kõlksu	sõna+kõlks	22_S	PlN	et	sõnakõlksud =kõlksu  (PlN  >sõna+kõlks !22_S
49742	kliinilises	kliinilise	kliiniline	12_A	SgIn	et	kliinilises =kliinilise  (SgIn  >kliiniline !12_A
49743	psühholoogias	psühholoogia	psühholoogia	01_S	SgIn	et	psühholoogias =psühholoogia  (SgIn  >psühholoogia !01_S
49745	võrdluses	võrdluse	võrdlus	11~09_S	SgIn	et	võrdluses =võrdluse  (SgIn  >võrdlus !11~09_S
49752	maskuliinseteks	maskuliinse	maskuliinne	02_A	PlTr	et	maskuliinseteks =maskuliinse  (PlTr  >maskuliinne !02_A
49753	tooks	too	tooma	38_V	KndPrPs	et	tooks =too  (KndPrPs  >tooma !38_V
49761	juhtimisoskus	oskus	juhtimis+oskus	11~09_S	SgN	et	juhtimisoskus =oskus  (SgN  >juhtimis+oskus !11~09_S
49771	meheliku	meheliku	mehelik	25_A	SgG	et	meheliku =meheliku  (SgG  >mehelik !25_A
49776	tingibki	tingi	tingima	28_V	IndPrSg3^	et	tingibki =tingi  (IndPrSg3^  >tingima !28_V
49779	niisamuti	niisamuti	nii+samuti	41_D	ID	et	niisamuti =niisamuti  (ID  >nii+samuti !41_D
49792	virtuaalset	virtuaalse	virtuaalne	02_A	SgP	et	virtuaalset =virtuaalse  (SgP  >virtuaalne !02_A
49799	organiseerisin	organiseeri	organiseerima	28_V	IndIpfSg1	et	organiseerisin =organiseeri  (IndIpfSg1  >organiseerima !28_V
49803	eelpoolnimetatud	nimetatu	eel+pool+nimetatu	01_S	PlN	et	eelpoolnimetatud =nimetatu  (PlN  >eel+pool+nimetatu !01_S
49814	kanalites	kanali	kanal	02_S	PlIn	et	kanalites =kanali  (PlIn  >kanal !02_S
49817	suhtlusprobleemidele	probleemi	suhtlus+probleem	22_S	PlAll	et	suhtlusprobleemidele =probleemi  (PlAll  >suhtlus+probleem !22_S
49827	homoseksuaalsete	sete	homo+seksuaal+sete	06_S	SgN	et	homoseksuaalsete =sete  (SgN  >homo+seksuaal+sete !06_S
49830	peremudelis	mudeli	pere+mudel	02_S	SgIn	et	peremudelis =mudeli  (SgIn  >pere+mudel !02_S
49832	lepitakse	lepi	leppima	28_V	IndPrIps	et	lepitakse =lepi  (IndPrIps  >leppima !28_V
49871	soorollidele	rolli	soo+roll	22_S	PlAll	et	soorollidele =rolli  (PlAll  >soo+roll !22_S
49874	karjäärinaisi	naisi	karjääri+naine	12_S	PlP	et	karjäärinaisi =naisi  (PlP  >karjääri+naine !12_S
49877	arengult	arengu	areng	02_S	SgAbl	et	arengult =arengu  (SgAbl  >areng !02_S
49882	häbiasi	asi	häbi+asi	24_S	SgN	et	häbiasi =asi  (SgN  >häbi+asi !24_S
49898	kritiseeritakse	kritiseeri	kritiseerima	28_V	IndPrIps	et	kritiseeritakse =kritiseeri  (IndPrIps  >kritiseerima !28_V
49908	hõlmates	hõlma	hõlmama	29_V	Ger	et	hõlmates =hõlma  (Ger  >hõlmama !29_V
49912	globaalses	globaalse	globaalne	02_A	SgIn	et	globaalses =globaalse  (SgIn  >globaalne !02_A
49919	ignoreerides	ignoreeri	ignoreerima	28_V	Ger	et	ignoreerides =ignoreeri  (Ger  >ignoreerima !28_V
49928	globaalruum	ruum	globaal+ruum	22_S	SgN	et	globaalruum =ruum  (SgN  >globaal+ruum !22_S
49931	emotsioon	emotsioon	emotsioon	22_S	SgN	et	emotsioon =emotsioon  (SgN  >emotsioon !22_S
49932	kardetakse	karde	kartma	34_V	IndPrIps	et	kardetakse =karde  (IndPrIps  >kartma !34_V
49935	vastuvõetamatut	võetamatu	vastu+võetamatu	01_A	SgP	et	vastuvõetamatut =võetamatu  (SgP  >vastu+võetamatu !01_A
49943	suurkorporatsioon	korporatsioon	suur+korporatsioon	22_S	SgN	et	suurkorporatsioon =korporatsioon  (SgN  >suur+korporatsioon !22_S
49954	korporatsioonis	korporatsiooni	korporatsioon	22_S	SgIn	et	korporatsioonis =korporatsiooni  (SgIn  >korporatsioon !22_S
49955	ärkveloleku	oleku	ärkvel+olek	02_S	SgG	et	ärkveloleku =oleku  (SgG  >ärkvel+olek !02_S
49956	katsetada	katseta	katsetama	27_V	Inf	et	katsetada =katseta  (Inf  >katsetama !27_V
49963	ühiskondlike	ühiskondlike	ühiskondlik	25_A	PlG	et	ühiskondlike =ühiskondlike  (PlG  >ühiskondlik !25_A
49965	esialgsed	algse	esi+algne	02_A	PlN	et	esialgsed =algse  (PlN  >esi+algne !02_A
49968	ilmudes	ilmu	ilmuma	27_V	Ger	et	ilmudes =ilmu  (Ger  >ilmuma !27_V
49984	sihtkoht	koht	siht+koht	22_S	SgN	et	sihtkoht =koht  (SgN  >siht+koht !22_S
49986	iseloomulikul	loomuliku	ise+loomulik	25_A	SgAd	et	iseloomulikul =loomuliku  (SgAd  >ise+loomulik !25_A
49764	avanemaks	avane	avanema	27_V	SupTr	et	avanemaks =avane  (SupTr  >avanema !27_V
49767	isad	isa	isa	17_S	PlN	et	isad =isa  (PlN  >isa !17_S
49774	edusamm	samm	edu+samm	22_S	SgN	et	edusamm =samm  (SgN  >edu+samm !22_S
49781	tihtilugu	tihtilugu	tihti+lugu	41_D	ID	et	tihtilugu =tihtilugu  (ID  >tihti+lugu !41_D
49784	koosviibimise	viibimise	koos+viibimine	12_S	SgG	et	koosviibimise =viibimise  (SgG  >koos+viibimine !12_S
49786	jututubasid	tuba	jutu+tuba	18_S	PlP	et	jututubasid =tuba  (PlP  >jutu+tuba !18_S
49789	tehnoloogiamaailm	ilm	tehno+loogia+maa+ilm	22_S	SgN	et	tehnoloogiamaailm =ilm  (SgN  >tehno+loogia+maa+ilm !22_S
49791	kliendis	kliendi	klient	22_S	SgIn	et	kliendis =kliendi  (SgIn  >klient !22_S
49795	kaustades	kausta	kaust	22_S	PlIn	et	kaustades =kausta  (PlIn  >kaust !22_S
49800	sihtgrupini	grupi	siht+grupp	22_S	SgTer	et	sihtgrupini =grupi  (SgTer  >siht+grupp !22_S
49801	pressiteated	teate	pressi+teade	06_S	PlN	et	pressiteated =teate  (PlN  >pressi+teade !06_S
49804	märtsikuus	kuu	märtsi+kuu	26_S	SgIn	et	märtsikuus =kuu  (SgIn  >märtsi+kuu !26_S
49808	virtuaalsest	virtuaalse	virtuaalne	02_A	SgEl	et	virtuaalsest =virtuaalse  (SgEl  >virtuaalne !02_A
49811	edastama	edasta	edastama	27_V	Sup	et	edastama =edasta  (Sup  >edastama !27_V
49812	aruteludel	arutelu	arutelu	17_S	PlAd	et	aruteludel =arutelu  (PlAd  >arutelu !17_S
49818	oskuseni	oskuse	oskus	11~09_S	SgTer	et	oskuseni =oskuse  (SgTer  >oskus !11~09_S
49821	virtuaalsed	virtuaalse	virtuaalne	02_A	PlN	et	virtuaalsed =virtuaalse  (PlN  >virtuaalne !02_A
49824	naiselikke	naiselikke	naiselik	25_A	PlP	et	naiselikke =naiselikke  (PlP  >naiselik !25_A
49828	vähemusgrupi	grupi	vähemus+grupp	22_S	SgG	et	vähemusgrupi =grupi  (SgG  >vähemus+grupp !22_S
49834	autoriteet	autoriteet	autoriteet	22_S	SgN	et	autoriteet =autoriteet  (SgN  >autoriteet !22_S
49835	mängukaaslane	kaaslane	mängu+kaaslane	12?10_S	SgN	et	mängukaaslane =kaaslane  (SgN  >mängu+kaaslane !12?10_S
49841	keskenduda	keskendu	keskenduma	27_V	Inf	et	keskenduda =keskendu  (Inf  >keskenduma !27_V
49842	vastsele	vastse	vastne	02_SA	SgAll	et	vastsele =vastse  (SgAll  >vastne !02_SA
49850	omadussõnu	sõnu	omadus+sõna	17_S	PlP	et	omadussõnu =sõnu  (PlP  >omadus+sõna !17_S
49853	austas	austa	austama	27_V	IndIpfSg3	et	austas =austa  (IndIpfSg3  >austama !27_V
49863	marsilt	marsi	marss	22_S	SgAbl	et	marsilt =marsi  (SgAbl  >marss !22_S
49865	sugupooleks	poole	sugu+pool	22_S	PlTr	et	sugupooleks =poole  (PlTr  >sugu+pool !22_S
49866	vältas	välta	vältama	29_V	IndIpfSg3	et	vältas =välta  (IndIpfSg3  >vältama !29_V
49867	ülalmainitud	mainitu	ülal+mainitu	01_S	PlN	et	ülalmainitud =mainitu  (PlN  >ülal+mainitu !01_S
49876	lapsevanemakohused	kohuse	lapse+vanema+kohus	09_S	PlN	et	lapsevanemakohused =kohuse  (PlN  >lapse+vanema+kohus !09_S
49879	pereemad	ema	pere+ema	17_S	PlN	et	pereemad =ema  (PlN  >pere+ema !17_S
49880	ühtäkki	ühtäkki	üht+äkki	41_D	ID	et	ühtäkki =ühtäkki  (ID  >üht+äkki !41_D
49883	vajaka	vajaka	vajaka	41_D	ID	et	vajaka =vajaka  (ID  >vajaka !41_D
49886	soorollide	rolli	soo+roll	22_S	PlG	et	soorollide =rolli  (PlG  >soo+roll !22_S
49897	ühistatakse	ühista	ühistama	27_V	IndPrIps	et	ühistatakse =ühista  (IndPrIps  >ühistama !27_V
49901	globaalmõtlemine	mõtlemine	globaal+mõtlemine	12_S	SgN	et	globaalmõtlemine =mõtlemine  (SgN  >globaal+mõtlemine !12_S
49902	maailmakodanikena	kodanike	maa+ilma+kodanik	25_S	PlEs	et	maailmakodanikena =kodanike  (PlEs  >maa+ilma+kodanik !25_S
49905	feminiinsete	feminiinse	feminiinne	02_A	PlG	et	feminiinsete =feminiinse  (PlG  >feminiinne !02_A
49916	universaalne	universaalne	universaalne	02_A	SgN	et	universaalne =universaalne  (SgN  >universaalne !02_A
49927	petlik	petlik	petlik	25_A	SgN	et	petlik =petlik  (SgN  >petlik !25_A
49929	unelmate	unelma	unelm	02_S	PlG	et	unelmate =unelma  (PlG  >unelm !02_S
49930	keskmeks	keskme	kese	05_S	SgTr	et	keskmeks =keskme  (SgTr  >kese !05_S
49934	väikerahvuste	rahvus	väike+rahvus	11~09_S	PlG	et	väikerahvuste =rahvus  (PlG  >väike+rahvus !11~09_S
49940	komponentideks	komponenti	komponent	22_S	PlTr	et	komponentideks =komponenti  (PlTr  >komponent !22_S
49948	infoühiskond	ühiskond	info+ühiskond	22_S	SgN	et	infoühiskond =ühiskond  (SgN  >info+ühiskond !22_S
49972	veenmisoskust	oskus	veenmis+oskus	11~09_S	SgP	et	veenmisoskust =oskus  (SgP  >veenmis+oskus !11~09_S
49975	turundusjuht	juht	turundus+juht	22_S	SgN	et	turundusjuht =juht  (SgN  >turundus+juht !22_S
49979	tööriideks	riide	töö+riie	06_S	SgTr	et	tööriideks =riide  (SgTr  >töö+riie !06_S
49981	iseäralikul	äraliku	ise+äralik	25_A	SgAd	et	iseäralikul =äraliku  (SgAd  >ise+äralik !25_A
49982	mõtlebki	mõtle	mõtlema	30_V	IndPrSg3^	et	mõtlebki =mõtle  (IndPrSg3^  >mõtlema !30_V
49983	seljakoti	koti	selja+kott	22_S	SgG	et	seljakoti =koti  (SgG  >selja+kott !22_S
49991	suurettevõtted	võtte	suur+ette+võte	06_S	PlN	et	suurettevõtted =võtte  (PlN  >suur+ette+võte !06_S
49845	aspektis	aspekti	aspekt	22_S	SgIn	et	aspektis =aspekti  (SgIn  >aspekt !22_S
49846	oodatakse	ooda	ootama	29_V	IndPrIps	et	oodatakse =ooda  (IndPrIps  >ootama !29_V
49847	lähedastega	lähedas	lähedane	12_AS	PlKom	et	lähedastega =lähedas  (PlKom  >lähedane !12_AS
49852	kultuuriruum	ruum	kultuuri+ruum	22_S	SgN	et	kultuuriruum =ruum  (SgN  >kultuuri+ruum !22_S
49855	prioriteedid	prioriteedi	prioriteet	22_S	PlN	et	prioriteedid =prioriteedi  (PlN  >prioriteet !22_S
49862	karjääriinimesed	inimese	karjääri+inimene	12_S	PlN	et	karjääriinimesed =inimese  (PlN  >karjääri+inimene !12_S
49875	lisatrump	trump	lisa+trump	22_S	SgN	et	lisatrump =trump  (SgN  >lisa+trump !22_S
49878	vagurad	vagura	vagur	02_A	PlN	et	vagurad =vagura  (PlN  >vagur !02_A
49888	sekundaarsele	sekundaarse	sekundaarne	02_A	SgAll	et	sekundaarsele =sekundaarse  (SgAll  >sekundaarne !02_A
49890	infoajastul	ajastu	info+ajastu	01_S	SgAd	et	infoajastul =ajastu  (SgAd  >info+ajastu !01_S
49894	senimaani	maa	seni+maa	26_S	SgTer	et	senimaani =maa  (SgTer  >seni+maa !26_S
49899	globaalne	globaalne	globaalne	02_A	SgN	et	globaalne =globaalne  (SgN  >globaalne !02_A
49900	sõnavarasse	vara	sõna+vara	17_S	SgIll	et	sõnavarasse =vara  (SgIll  >sõna+vara !17_S
49907	kogub	kogu	koguma	27_V	IndPrSg3	et	kogub =kogu  (IndPrSg3  >koguma !27_V
49911	paradigmade	paradigma	paradigma	16_S	PlG	et	paradigmade =paradigma  (PlG  >paradigma !16_S
49918	kohandades	kohanda	kohandama	27_V	Ger	et	kohandades =kohanda  (Ger  >kohandama !27_V
49920	tingib	tingi	tingima	28_V	IndPrSg3	et	tingib =tingi  (IndPrSg3  >tingima !28_V
49921	maailmakodanike	kodanike	maa+ilma+kodanik	25_S	PlG	et	maailmakodanike =kodanike  (PlG  >maa+ilma+kodanik !25_S
49923	globaalse	globaalse	globaalne	02_A	SgG	et	globaalse =globaalse  (SgG  >globaalne !02_A
49925	ammutada	ammuta	ammutama	27_V	Inf	et	ammutada =ammuta  (Inf  >ammutama !27_V
49926	kogustes	kogus	kogus	09_S	PlIn	et	kogustes =kogus  (PlIn  >kogus !09_S
49937	maailmakodanik	kodanik	maa+ilma+kodanik	25_S	SgN	et	maailmakodanik =kodanik  (SgN  >maa+ilma+kodanik !25_S
49941	käitumismallid	malli	käitumis+mall	22_S	PlN	et	käitumismallid =malli  (PlN  >käitumis+mall !22_S
49942	väikeettevõte	võte	väike+ette+võte	06_S	SgN	et	väikeettevõte =võte  (SgN  >väike+ette+võte !06_S
49944	organisatsioonist	organisatsiooni	organisatsioon	22_S	SgEl	et	organisatsioonist =organisatsiooni  (SgEl  >organisatsioon !22_S
49951	kuvandit	kuvandi	kuvand	02_S	SgP	et	kuvandit =kuvandi  (SgP  >kuvand !02_S
49959	korporatsiooniga	korporatsiooni	korporatsioon	22_S	SgKom	et	korporatsiooniga =korporatsiooni  (SgKom  >korporatsioon !22_S
49962	teenuste	teenus	teenus	09_S	PlG	et	teenuste =teenus  (PlG  >teenus !09_S
49966	visioonid	visiooni	visioon	22_S	PlN	et	visioonid =visiooni  (PlN  >visioon !22_S
49973	ajakirjadesse	kirja	aja+kiri	24_S	PlIll	et	ajakirjadesse =kirja  (PlIll  >aja+kiri !24_S
49974	reklaampostidele	posti	reklaam+post	22_S	PlAll	et	reklaampostidele =posti  (PlAll  >reklaam+post !22_S
49987	sätime	säti	sättima	28_V	IndPrPl1	et	sätime =säti  (IndPrPl1  >sättima !28_V
50001	visuaalse	visuaalse	visuaalne	02_A	SgG	et	visuaalse =visuaalse  (SgG  >visuaalne !02_A
50004	infokirjad	kirja	info+kiri	24_S	PlN	et	infokirjad =kirja  (PlN  >info+kiri !24_S
50011	huvigrupi	grupi	huvi+grupp	22_S	SgG	et	huvigrupi =grupi  (SgG  >huvi+grupp !22_S
50012	infomaterjale	materjale	info+materjal	19_S	PlP	et	infomaterjale =materjale  (PlP  >info+materjal !19_S
50028	turuliidriks	liidri	turu+liider	02_S	SgTr	et	turuliidriks =liidri  (SgTr  >turu+liider !02_S
50029	tarbijauuringuid	uuringu	tarbija+uuring	02_S	PlP	et	tarbijauuringuid =uuringu  (PlP  >tarbija+uuring !02_S
50034	telefonioperaatorid	operaatori	telefoni+operaator	02_S	PlN	et	telefonioperaatorid =operaatori  (PlN  >telefoni+operaator !02_S
50035	potentsiaalne	potentsiaalne	potentsiaalne	02_A	SgN	et	potentsiaalne =potentsiaalne  (SgN  >potentsiaalne !02_A
50036	sihtrühm	rühm	siht+rühm	22_S	SgN	et	sihtrühm =rühm  (SgN  >siht+rühm !22_S
50037	kliendini	kliendi	klient	22_S	SgTer	et	kliendini =kliendi  (SgTer  >klient !22_S
50042	samavõrra	samavõrra	sama+võrra	41_D	ID	et	samavõrra =samavõrra  (ID  >sama+võrra !41_D
50048	negatiivsele	negatiivse	negatiivne	02_A	SgAll	et	negatiivsele =negatiivse  (SgAll  >negatiivne !02_A
50055	kinnistada	kinnista	kinnistama	27_V	Inf	et	kinnistada =kinnista  (Inf  >kinnistama !27_V
50056	tükkideks	tükki	tükk	22_S	PlTr	et	tükkideks =tükki  (PlTr  >tükk !22_S
50057	jaotussüsteem	süsteem	jaotus+süsteem	22_S	SgN	et	jaotussüsteem =süsteem  (SgN  >jaotus+süsteem !22_S
50066	soorollid	rolli	soo+roll	22_S	PlN	et	soorollid =rolli  (PlN  >soo+roll !22_S
50067	tublisti	tublisti	tublisti	41_D	ID	et	tublisti =tublisti  (ID  >tublisti !41_D
50068	keskendub	keskendu	keskenduma	27_V	IndPrSg3	et	keskendub =keskendu  (IndPrSg3  >keskenduma !27_V
50070	elukorraldusse	korraldus	elu+korraldus	11_S	SgAdt	et	elukorraldusse =korraldus  (SgAdt  >elu+korraldus !11_S
49910	äreva	äreva	ärev	02_A	SgG	et	äreva =äreva  (SgG  >ärev !02_A
49913	vooderdada	vooderda	vooderdama	27_V	Inf	et	vooderdada =vooderda  (Inf  >vooderdama !27_V
49914	absoluutset	absoluutse	absoluutne	02_A	SgP	et	absoluutset =absoluutse  (SgP  >absoluutne !02_A
49917	globaalmaailm	ilm	globaal+maa+ilm	22_S	SgN	et	globaalmaailm =ilm  (SgN  >globaal+maa+ilm !22_S
49922	toidetakse	toide	toitma	34_V	IndPrIps	et	toidetakse =toide  (IndPrIps  >toitma !34_V
49924	lokaalseid	lokaalse	lokaalne	02_A	PlP	et	lokaalseid =lokaalse  (PlP  >lokaalne !02_A
49936	tasandit	tasandi	tasand	02_S	SgP	et	tasandit =tasandi  (SgP  >tasand !02_S
49939	kuvandist	kuvandi	kuvand	02_S	SgEl	et	kuvandist =kuvandi  (SgEl  >kuvand !02_S
49946	kujundatakse	kujunda	kujundama	27_V	IndPrIps	et	kujundatakse =kujunda  (IndPrIps  >kujundama !27_V
49947	ettevõttemajanduse	majanduse	ette+võtte+majandus	11_S	SgG	et	ettevõttemajanduse =majanduse  (SgG  >ette+võtte+majandus !11_S
49949	suhtlus-situatsioonis	situatsiooni	suhtlus-situatsioon	22_S	SgIn	et	suhtlus-situatsioonis =situatsiooni  (SgIn  >suhtlus-situatsioon !22_S
49950	võimuorganite	organi	võimu+organ	02_S	PlG	et	võimuorganite =organi  (PlG  >võimu+organ !02_S
49952	samasid	sama	sama	17_P	PlP	et	samasid =sama  (PlP  >sama !17_P
49957	enesehinnangut	hinnangu	enese+hinnang	02_S	SgP	et	enesehinnangut =hinnangu  (SgP  >enese+hinnang !02_S
49960	kokkupuutuva	puutuva	kokku+puutuv	02_A	SgG	et	kokkupuutuva =puutuva  (SgG  >kokku+puutuv !02_A
49964	algsest	algse	algne	02_A	SgEl	et	algsest =algse  (SgEl  >algne !02_A
49970	normaalseid	normaalse	normaalne	02_A	PlP	et	normaalseid =normaalse  (PlP  >normaalne !02_A
49980	tunked	tunke	tunke	16_S	PlN	et	tunked =tunke  (PlN  >tunke !16_S
49988	ritta	ritta	rida	18_S	SgAdt	et	ritta =ritta  (SgAdt  >rida !18_S
49992	müüginuppe	nuppe	müügi+nupp	22_S	PlP	et	müüginuppe =nuppe  (PlP  >müügi+nupp !22_S
49994	klientide	klienti	klient	22_S	PlG	et	klientide =klienti  (PlG  >klient !22_S
50006	kontorites	kontori	kontor	02_S	PlIn	et	kontorites =kontori  (PlIn  >kontor !02_S
50008	kontorit	kontori	kontor	02_S	SgP	et	kontorit =kontori  (SgP  >kontor !02_S
50017	defineerib	defineeri	defineerima	28_V	IndPrSg3	et	defineerib =defineeri  (IndPrSg3  >defineerima !28_V
50030	selgitamaks	selgita	selgitama	27_V	SupTr	et	selgitamaks =selgita  (SupTr  >selgitama !27_V
50031	tarbijakäitumist	käitumis	tarbija+käitumine	12_S	SgP	et	tarbijakäitumist =käitumis  (SgP  >tarbija+käitumine !12_S
50040	mittesiduvate	siduva	mitte+siduv	02_A	PlG	et	mittesiduvate =siduva  (PlG  >mitte+siduv !02_A
50043	peegeldada	peegelda	peegeldama	27_V	Inf	et	peegeldada =peegelda  (Inf  >peegeldama !27_V
50045	piirivalvet	valve	piiri+valve	06_S	SgP	et	piirivalvet =valve  (SgP  >piiri+valve !06_S
50047	konfliktidele	konflikti	konflikt	22_S	PlAll	et	konfliktidele =konflikti  (PlAll  >konflikt !22_S
50060	tasanditel	tasandi	tasand	02_S	PlAd	et	tasanditel =tasandi  (PlAd  >tasand !02_S
50063	kiviaegsed	aegse	kivi+aegne	02_A	PlN	et	kiviaegsed =aegse  (PlN  >kivi+aegne !02_A
50064	koopaelanikud	elaniku	koopa+elanik	25_S	PlN	et	koopaelanikud =elaniku  (PlN  >koopa+elanik !25_S
50069	igivanad	vana	igi+vana	17_AS	PlN	et	igivanad =vana  (PlN  >igi+vana !17_AS
50075	naispoliitikuid	poliitiku	nais+poliitik	02_S	PlP	et	naispoliitikuid =poliitiku  (PlP  >nais+poliitik !02_S
50079	rühmab	rühma	rühmama	29_V	IndPrSg3	et	rühmab =rühma  (IndPrSg3  >rühmama !29_V
50084	plahvatuslikke	plahvatuslikke	plahvatuslik	25_A	PlP	et	plahvatuslikke =plahvatuslikke  (PlP  >plahvatuslik !25_A
50095	valikuvõimalusi	võimalusi	valiku+võimalus	11_S	PlP	et	valikuvõimalusi =võimalusi  (PlP  >valiku+võimalus !11_S
50099	teemadevalikut	valiku	teemade+valik	02_S	SgP	et	teemadevalikut =valiku  (SgP  >teemade+valik !02_S
50103	käsitlesin	käsitle	käsitlema	27_V	IndIpfSg1	et	käsitlesin =käsitle  (IndIpfSg1  >käsitlema !27_V
50108	org-ni	org	org	xx_Q	SgTer	et	org-ni =org  (SgTer  >org !xx_Q
50109	õppemeetodid	meetodi	õppe+meetod	02_S	PlN	et	õppemeetodid =meetodi  (PlN  >õppe+meetod !02_S
50115	dekaadiga	dekaadi	dekaad	22_S	SgKom	et	dekaadiga =dekaadi  (SgKom  >dekaad !22_S
50119	koletut	koletu	koletu	01_A	SgP	et	koletut =koletu  (SgP  >koletu !01_A
50120	sõdurpoisiga	poisi	sõdur+poiss	23?22_S	SgKom	et	sõdurpoisiga =poisi  (SgKom  >sõdur+poiss !23?22_S
50126	venelases	venelase	venelane	12_S	SgIn	et	venelases =venelase  (SgIn  >venelane !12_S
50132	muutmas	muut	muutma	34_V	SupIn	et	muutmas =muut  (SupIn  >muutma !34_V
50134	õdedest-vendadest	venda	õdedest-vend	22_S	PlEl	et	õdedest-vendadest =venda  (PlEl  >õdedest-vend !22_S
50138	peetrit	peetri	peeter	02_S	SgP	et	peetrit =peetri  (SgP  >peeter !02_S
50141	integratsiooniprojektid	projekti	integratsiooni+projekt	22_S	PlN	et	integratsiooniprojektid =projekti  (PlN  >integratsiooni+projekt !22_S
50142	meediakajastused	kajastuse	meedia+kajastus	11_S	PlN	et	meediakajastused =kajastuse  (PlN  >meedia+kajastus !11_S
50174	lihale	liha	liha	17_S	SgAll	et	lihale =liha  (SgAll  >liha !17_S
49933	põhihirm	hirm	põhi+hirm	22_S	SgN	et	põhihirm =hirm  (SgN  >põhi+hirm !22_S
49938	defineerime	defineeri	defineerima	28_V	IndPrPl1	et	defineerime =defineeri  (IndPrPl1  >defineerima !28_V
49945	kõrvaltvaatajad	vaataja	kõrvalt+vaataja	01_S	PlN	et	kõrvaltvaatajad =vaataja  (PlN  >kõrvalt+vaataja !01_S
49953	väärtuseid	väärtuse	väärtus	09_S	PlP	et	väärtuseid =väärtuse  (PlP  >väärtus !09_S
49958	positiivse	positiivse	positiivne	02_A	SgG	et	positiivse =positiivse  (SgG  >positiivne !02_A
49961	kaubamärkide	märki	kauba+märk	22_S	PlG	et	kaubamärkide =märki  (PlG  >kauba+märk !22_S
49967	kasuminumbrite	numbri	kasumi+number	02_S	PlG	et	kasuminumbrite =numbri  (PlG  >kasumi+number !02_S
49969	nutab	nuta	nutma	35_V	IndPrSg3	et	nutab =nuta  (IndPrSg3  >nutma !35_V
49971	kolmekümnendates	ate	kolme+kümnend+att	22_S	PlIn	et	kolmekümnendates =ate  (PlIn  >kolme+kümnend+att !22_S
49976	ratsionaalse	ratsionaalse	ratsionaalne	02_A	SgG	et	ratsionaalse =ratsionaalse  (SgG  >ratsionaalne !02_A
49977	argumenteerides	argumenteeri	argumenteerima	28_V	Ger	et	argumenteerides =argumenteeri  (Ger  >argumenteerima !28_V
49978	autoremondilukksepaks	sepa	auto+remondi+lukk+sepp	22_S	SgTr	et	autoremondilukksepaks =sepa  (SgTr  >auto+remondi+lukk+sepp !22_S
49985	seiklus	seiklus	seiklus	11~09_S	SgN	et	seiklus =seiklus  (SgN  >seiklus !11~09_S
49989	üldsuse	üldsuse	üldsus	11~09_S	SgG	et	üldsuse =üldsuse  (SgG  >üldsus !11~09_S
49999	huvigruppidest	gruppi	huvi+grupp	22_S	PlEl	et	huvigruppidest =gruppi  (PlEl  >huvi+grupp !22_S
50003	reklaamistendid	stendi	reklaami+stend	22_S	PlN	et	reklaamistendid =stendi  (PlN  >reklaami+stend !22_S
50013	teenust	teenus	teenus	09_S	SgP	et	teenust =teenus  (SgP  >teenus !09_S
50020	põhiosadeks	osa	põhi+osa	17_S	PlTr	et	põhiosadeks =osa  (PlTr  >põhi+osa !17_S
50025	riigisektoris	sektori	riigi+sektor	02_S	SgIn	et	riigisektoris =sektori  (SgIn  >riigi+sektor !02_S
50027	potentsiaalseid	potentsiaalse	potentsiaalne	02_A	PlP	et	potentsiaalseid =potentsiaalse  (PlP  >potentsiaalne !02_A
50046	piiririkkumised	rikkumise	piiri+rikkumine	12_S	PlN	et	piiririkkumised =rikkumise  (PlN  >piiri+rikkumine !12_S
50052	esiletoodavamate	toodavama	esile+toodavam	02_A	PlG	et	esiletoodavamate =toodavama  (PlG  >esile+toodavam !02_A
50054	mõjuteguritega	teguri	mõju+tegur	02_S	PlKom	et	mõjuteguritega =teguri  (PlKom  >mõju+tegur !02_S
50061	vaatepunkte	punkte	vaate+punkt	22_S	PlP	et	vaatepunkte =punkte  (PlP  >vaate+punkt !22_S
50065	mammuteid	mammute	mammut	02_S	PlP	et	mammuteid =mammute  (PlP  >mammut !02_S
50076	erarindel	rinde	era+rinne	06_S	SgAd	et	erarindel =rinde  (SgAd  >era+rinne !06_S
50077	sissetuleku	tuleku	sisse+tulek	02_S	SgG	et	sissetuleku =tuleku  (SgG  >sisse+tulek !02_S
50080	kõrghariduseni	hariduse	kõrg+haridus	11_S	SgTer	et	kõrghariduseni =hariduse  (SgTer  >kõrg+haridus !11_S
50093	telekanalites	kanali	tele+kanal	02_S	PlIn	et	telekanalites =kanali  (PlIn  >tele+kanal !02_S
50094	kõikjalt	kõikjalt	kõikjalt	41_D	ID	et	kõikjalt =kõikjalt  (ID  >kõikjalt !41_D
50101	esiuudiste	uudis	esi+uudis	09_S	PlG	et	esiuudiste =uudis  (PlG  >esi+uudis !09_S
50102	positiivses	positiivse	positiivne	02_A	SgIn	et	positiivses =positiivse  (SgIn  >positiivne !02_A
50113	segmendid	segmendi	segment	22_S	PlN	et	segmendid =segmendi  (PlN  >segment !22_S
50122	tolerantsist	tolerantsi	tolerants	22_S	SgEl	et	tolerantsist =tolerantsi  (SgEl  >tolerants !22_S
50124	diskussioon	diskussioon	diskussioon	22_S	SgN	et	diskussioon =diskussioon  (SgN  >diskussioon !22_S
50130	numbritena	numbri	number	02_S	PlEs	et	numbritena =numbri  (PlEs  >number !02_S
50131	paberitel	paberi	paber	02_S	PlAd	et	paberitel =paberi  (PlAd  >paber !02_S
50133	ühistranspordis	transpordi	ühis+transport	22_S	SgIn	et	ühistranspordis =transpordi  (SgIn  >ühis+transport !22_S
50143	minimaalset	minimaalse	minimaalne	02_A	SgP	et	minimaalset =minimaalse  (SgP  >minimaalne !02_A
50147	suhtlemisaltid	alti	suhtlemis+aldis	07_A	PlN	et	suhtlemisaltid =alti  (PlN  >suhtlemis+aldis !07_A
50149	eelarvamused	arvamuse	eel+arvamus	11_S	PlN	et	eelarvamused =arvamuse  (PlN  >eel+arvamus !11_S
50152	töövestlustel	vestlus	töö+vestlus	11~09_S	PlAd	et	töövestlustel =vestlus  (PlAd  >töö+vestlus !11~09_S
50153	poliitilistesse	poliitilis	poliitiline	12_A	PlIll	et	poliitilistesse =poliitilis  (PlIll  >poliitiline !12_A
50160	standardit	standardi	standard	02_S	SgP	et	standardit =standardi  (SgP  >standard !02_S
50170	normaalpiiridesse	piiri	normaal+piir	22_S	PlIll	et	normaalpiiridesse =piiri  (PlIll  >normaal+piir !22_S
50172	lesida	lesi	lesima	27_V	Inf	et	lesida =lesi  (Inf  >lesima !27_V
50173	vorstile	vorsti	vorst	22_S	SgAll	et	vorstile =vorsti  (SgAll  >vorst !22_S
50175	veetase	tase	vee+tase	04_S	SgN	et	veetase =tase  (SgN  >vee+tase !04_S
50186	kooliõpilaselt	õpilase	kooli+õpilane	12_S	SgAbl	et	kooliõpilaselt =õpilase  (SgAbl  >kooli+õpilane !12_S
50193	kaalun	kaalu	kaaluma	28_V	IndPrSg1	et	kaalun =kaalu  (IndPrSg1  >kaaluma !28_V
49990	põhivajadused	vajaduse	põhi+vajadus	11_S	PlN	et	põhivajadused =vajaduse  (PlN  >põhi+vajadus !11_S
49993	harutades	haruta	harutama	27_V	Ger	et	harutades =haruta  (Ger  >harutama !27_V
49995	kontolt	konto	konto	16_S	SgAbl	et	kontolt =konto  (SgAbl  >konto !16_S
49997	pankade	panka	pank	22_S	PlG	et	pankade =panka  (PlG  >pank !22_S
50000	visioon	visioon	visioon	22_S	SgN	et	visioon =visioon  (SgN  >visioon !22_S
50002	infomaterjalid	materjali	info+materjal	19_S	PlN	et	infomaterjalid =materjali  (PlN  >info+materjal !19_S
50005	kliendipiirkond	piirkond	kliendi+piirkond	22_S	SgN	et	kliendipiirkond =piirkond  (SgN  >kliendi+piirkond !22_S
50022	tavainimesele	inimese	tava+inimene	12_S	SgAll	et	tavainimesele =inimese  (SgAll  >tava+inimene !12_S
50032	edasisi	edasisi	edasine	12_A	PlP	et	edasisi =edasisi  (PlP  >edasine !12_A
50051	konkurentidest	konkurenti	konkurent	22_S	PlEl	et	konkurentidest =konkurenti  (PlEl  >konkurent !22_S
50053	kohanduda	kohandu	kohanduma	27_V	Inf	et	kohanduda =kohandu  (Inf  >kohanduma !27_V
50072	teljel	telje	telg	22_S	SgAd	et	teljel =telje  (SgAd  >telg !22_S
50073	esmane	esmane	esmane	10_A	SgN	et	esmane =esmane  (SgN  >esmane !10_A
50081	positsioonideni	positsiooni	positsioon	22_S	PlTer	et	positsioonideni =positsiooni  (PlTer  >positsioon !22_S
50090	pööretele	pööre	pööre	06_S	PlAll	et	pööretele =pööre  (PlAll  >pööre !06_S
50091	uudisteportaalides	portaali	uudiste+portaal	22_S	PlIn	et	uudisteportaalides =portaali  (PlIn  >uudiste+portaal !22_S
50092	vastaksin	vasta	vastama	29_V	KndPrSg1	et	vastaksin =vasta  (KndPrSg1  >vastama !29_V
50096	ühiskondlikes	ühiskondlike	ühiskondlik	25_A	PlIn	et	ühiskondlikes =ühiskondlike  (PlIn  >ühiskondlik !25_A
50098	kõneminuti	minuti	kõne+minut	02_S	SgG	et	kõneminuti =minuti  (SgG  >kõne+minut !02_S
50104	arvamusavaldusi	avaldusi	arvamus+avaldus	11_S	PlP	et	arvamusavaldusi =avaldusi  (PlP  >arvamus+avaldus !11_S
50105	kommentaatorit	kommentaatori	kommentaator	02_S	SgP	et	kommentaatorit =kommentaatori  (SgP  >kommentaator !02_S
50106	rumalate	rumala	rumal	02_A	PlG	et	rumalate =rumala  (PlG  >rumal !02_A
50112	kontingent	kontingent	kontingent	22_S	SgN	et	kontingent =kontingent  (SgN  >kontingent !22_S
50116	edusammude	sammu	edu+samm	22_S	PlG	et	edusammude =sammu  (PlG  >edu+samm !22_S
50121	naabritena	naabri	naaber	02_S	PlEs	et	naabritena =naabri  (PlEs  >naaber !02_S
50123	teineteisesse	teise	teine+teise	12_P	SgIll	et	teineteisesse =teise  (SgIll  >teine+teise !12_P
50137	ühises	ühise	ühine	10_A	SgIn	et	ühises =ühise  (SgIn  >ühine !10_A
50139	integratsioon	integratsioon	integratsioon	22_S	SgN	et	integratsioon =integratsioon  (SgN  >integratsioon !22_S
50140	meediakajastus	kajastus	meedia+kajastus	11_S	SgN	et	meediakajastus =kajastus  (SgN  >meedia+kajastus !11_S
50145	sõbruneda	sõbrune	sõbrunema	27_V	Inf	et	sõbruneda =sõbrune  (Inf  >sõbrunema !27_V
50155	õllesummeril	summeri	õlle+summer	02_S	SgAd	et	õllesummeril =summeri  (SgAd  >õlle+summer !02_S
50156	foobiaid	foobia	foobia	01_S	PlP	et	foobiaid =foobia  (PlP  >foobia !01_S
50158	rõvedad	rõveda	rõve	02_A	PlN	et	rõvedad =rõveda  (PlN  >rõve !02_A
50163	normidest	normi	norm	22_S	PlEl	et	normidest =normi  (PlEl  >norm !22_S
50164	kalduda	kaldu	kalduma	27_V	Inf	et	kalduda =kaldu  (Inf  >kalduma !27_V
50177	katastroofe	katastroofe	katastroof	22_S	PlP	et	katastroofe =katastroofe  (PlP  >katastroof !22_S
50182	totaalse	totaalse	totaalne	02_A	SgG	et	totaalse =totaalse  (SgG  >totaalne !02_A
50194	kah	kah	kah	41_D	ID	et	kah =kah  (ID  >kah !41_D
50202	maailmavaatedki	vaate	maa+ilma+vaade	06_S	PlN^	et	maailmavaatedki =vaate  (PlN^  >maa+ilma+vaade !06_S
50215	liitlast	liitlas	liitlane	12?10_S	SgP	et	liitlast =liitlas  (SgP  >liitlane !12?10_S
50216	õnnelikena	õnnelike	õnnelik	25_A	PlEs	et	õnnelikena =õnnelike  (PlEs  >õnnelik !25_A
50218	kaaslaseks	kaaslase	kaaslane	12?10_S	SgTr	et	kaaslaseks =kaaslase  (SgTr  >kaaslane !12?10_S
50237	väljasuremist	suremis	välja+suremine	12_S	SgP	et	väljasuremist =suremis  (SgP  >välja+suremine !12_S
50239	kultuursed	kultuurse	kultuurne	02_A	PlN	et	kultuursed =kultuurse  (PlN  >kultuurne !02_A
50242	aspektiks	aspekti	aspekt	22_S	SgTr	et	aspektiks =aspekti  (SgTr  >aspekt !22_S
50243	võrdväärne	väärne	võrd+väärne	02_A	SgN	et	võrdväärne =väärne  (SgN  >võrd+väärne !02_A
50245	olemusega	olemuse	olemus	11_S	SgKom	et	olemusega =olemuse  (SgKom  >olemus !11_S
50246	tumedaid	tumeda	tume	02_A	PlP	et	tumedaid =tumeda  (PlP  >tume !02_A
50257	selletaoliste	taolis	selle+taoline	12?10_A	PlG	et	selletaoliste =taolis  (PlG  >selle+taoline !12?10_A
50271	turvatöötajana	töötaja	turva+töötaja	01_S	SgEs	et	turvatöötajana =töötaja  (SgEs  >turva+töötaja !01_S
50277	elutingimuses	tingimuse	elu+tingimus	11_S	SgIn	et	elutingimuses =tingimuse  (SgIn  >elu+tingimus !11_S
50279	usalduslikud	usaldusliku	usalduslik	25_A	PlN	et	usalduslikud =usaldusliku  (PlN  >usalduslik !25_A
49996	kommertspankade	panka	kommerts+pank	22_S	PlG	et	kommertspankade =panka  (PlG  >kommerts+pank !22_S
49998	ettevõttele	võtte	ette+võte	06_S	SgAll	et	ettevõttele =võtte  (SgAll  >ette+võte !06_S
50007	väljendudes	väljendu	väljenduma	27_V	Ger	et	väljendudes =väljendu  (Ger  >väljenduma !27_V
50009	eespoolnimetatud	nimetatu	ees+pool+nimetatu	01_S	PlN	et	eespoolnimetatud =nimetatu  (PlN  >ees+pool+nimetatu !01_S
50010	vaatenurgalt	nurga	vaate+nurk	22_S	SgAbl	et	vaatenurgalt =nurga  (SgAbl  >vaate+nurk !22_S
50014	vajada	vaja	vajama	27_V	Inf	et	vajada =vaja  (Inf  >vajama !27_V
50015	aadetest	aade	aade	06_S	PlEl	et	aadetest =aade  (PlEl  >aade !06_S
50016	tuluüksuse	üksuse	tulu+üksus	11~09_S	SgG	et	tuluüksuse =üksuse  (SgG  >tulu+üksus !11~09_S
50018	tuues	tuu	tooma	38_V	Ger	et	tuues =tuu  (Ger  >tooma !38_V
50019	tunnetatakse	tunneta	tunnetama	27_V	IndPrIps	et	tunnetatakse =tunneta  (IndPrIps  >tunnetama !27_V
50021	põhiväärtusi	väärtusi	põhi+väärtus	11_S	PlP	et	põhiväärtusi =väärtusi  (PlP  >põhi+väärtus !11_S
50023	ettevõtlust	võtlus	ette+võtlus	11~09_S	SgP	et	ettevõtlust =võtlus  (SgP  >ette+võtlus !11~09_S
50024	kommunaar	kommunaar	kommunaar	22_S	SgN	et	kommunaar =kommunaar  (SgN  >kommunaar !22_S
50026	konkurentsieelis	eelis	konkurentsi+eelis	09_S	SgN	et	konkurentsieelis =eelis  (SgN  >konkurentsi+eelis !09_S
50033	samme	samme	samm	22_S	PlP	et	samme =samme  (PlP  >samm !22_S
50038	argumendiga	argumendi	argument	22_S	SgKom	et	argumendiga =argumendi  (SgKom  >argument !22_S
50039	teenuspakkujaid	pakkuja	teenus+pakkuja	01_S	PlP	et	teenuspakkujaid =pakkuja  (PlP  >teenus+pakkuja !01_S
50041	lepingutega	lepingu	leping	02_S	PlKom	et	lepingutega =lepingu  (PlKom  >leping !02_S
50044	institutsiooniks	institutsiooni	institutsioon	22_S	SgTr	et	institutsiooniks =institutsiooni  (SgTr  >institutsioon !22_S
50049	meediakajastusele	kajastuse	meedia+kajastus	11_S	SgAll	et	meediakajastusele =kajastuse  (SgAll  >meedia+kajastus !11_S
50050	grupiettevõtetest	võte	grupi+ette+võte	06_S	PlEl	et	grupiettevõtetest =võte  (PlEl  >grupi+ette+võte !06_S
50058	moraalsete	moraalse	moraalne	02_A	PlG	et	moraalsete =moraalse  (PlG  >moraalne !02_A
50059	tõekspidamistega	pidamis	tõeks+pidamine	12_S	PlKom	et	tõekspidamistega =pidamis  (PlKom  >tõeks+pidamine !12_S
50062	planeedil	planeedi	planeet	22_S	SgAd	et	planeedil =planeedi  (SgAd  >planeet !22_S
50071	hariliku	hariliku	harilik	25_A	SgG	et	hariliku =hariliku  (SgG  >harilik !25_A
50078	dünaamikal	dünaamika	dünaamika	01_S	SgAd	et	dünaamikal =dünaamika  (SgAd  >dünaamika !01_S
50085	täiel	täie	täis	14_AS	SgAd	et	täiel =täie  (SgAd  >täis !14_AS
50086	rinnal	rinna	rind	22_S	SgAd	et	rinnal =rinna  (SgAd  >rind !22_S
50087	käitumisstandardeid	standarde	käitumis+standard	02_S	PlP	et	käitumisstandardeid =standarde  (PlP  >käitumis+standard !02_S
50088	kriteeriumidel	kriteeriumi	kriteerium	19_S	PlAd	et	kriteeriumidel =kriteeriumi  (PlAd  >kriteerium !19_S
50089	fenomenide	fenomeni	fenomen	19_S	PlG	et	fenomenide =fenomeni  (PlG  >fenomen !19_S
50100	kitseneb	kitsene	kitsenema	27_V	IndPrSg3	et	kitseneb =kitsene  (IndPrSg3  >kitsenema !27_V
50107	kommentaaride	kommentaari	kommentaar	22_S	PlG	et	kommentaaride =kommentaari  (PlG  >kommentaar !22_S
50110	samastab	samasta	samastama	27_V	IndPrSg3	et	samastab =samasta  (IndPrSg3  >samastama !27_V
50111	uudistega	uudis	uudis	09_S	PlKom	et	uudistega =uudis  (PlKom  >uudis !09_S
50114	eestivenelased	venelase	eesti+venelane	12_S	PlN	et	eestivenelased =venelase  (PlN  >eesti+venelane !12_S
50117	tajume	taju	tajuma	27_V	IndPrPl1	et	tajume =taju  (IndPrPl1  >tajuma !27_V
50118	vitsahoope	hoope	vitsa+hoop	22_S	PlP	et	vitsahoope =hoope  (PlP  >vitsa+hoop !22_S
50125	venelasest	venelase	venelane	12_S	SgEl	et	venelasest =venelase  (SgEl  >venelane !12_S
50128	tobedaid	tobeda	tobe	02_A	PlP	et	tobedaid =tobeda  (PlP  >tobe !02_A
50129	raportitel	raporti	raport	02_S	PlAd	et	raportitel =raporti  (PlAd  >raport !02_S
50135	ühisosaks	osa	ühis+osa	17_S	SgTr	et	ühisosaks =osa  (SgTr  >ühis+osa !17_S
50136	maalapil	lapi	maa+lapp	22_S	SgAd	et	maalapil =lapi  (SgAd  >maa+lapp !22_S
50144	hämmingus	hämmingu	hämming	02_S	SgIn	et	hämmingus =hämmingu  (SgIn  >hämming !02_S
50148	vaenuõhutajaid	õhutaja	vaenu+õhutaja	01_S	PlP	et	vaenuõhutajaid =õhutaja  (PlP  >vaenu+õhutaja !01_S
50150	valestimõistmised	mõistmise	valesti+mõistmine	12?10_S	PlN	et	valestimõistmised =mõistmise  (PlN  >valesti+mõistmine !12?10_S
50154	erakondadesse	erakonda	erakond	22_S	PlIll	et	erakondadesse =erakonda  (PlIll  >erakond !22_S
50161	standard	standard	standard	02_S	SgN	et	standard =standard  (SgN  >standard !02_S
50162	hoiakutes	hoiaku	hoiak	02_S	PlIn	et	hoiakutes =hoiaku  (PlIn  >hoiak !02_S
50165	täppisteaduse	teaduse	täppis+teadus	11~09_S	SgG	et	täppisteaduse =teaduse  (SgG  >täppis+teadus !11~09_S
50166	viguri	viguri	vigur	02_S	SgG	et	viguri =viguri  (SgG  >vigur !02_S
50074	tänini	tänini	tänini	41_D	ID	et	tänini =tänini  (ID  >tänini !41_D
50082	maskuliinses	maskuliinse	maskuliinne	02_A	SgIn	et	maskuliinses =maskuliinse  (SgIn  >maskuliinne !02_A
50083	elukorralduse	korralduse	elu+korraldus	11_S	SgG	et	elukorralduse =korralduse  (SgG  >elu+korraldus !11_S
50097	aruteludes	arutelu	arutelu	17_S	PlIn	et	aruteludes =arutelu  (PlIn  >arutelu !17_S
50127	surveavaldamist	avaldamis	surve+avaldamine	12_S	SgP	et	surveavaldamist =avaldamis  (SgP  >surve+avaldamine !12_S
50146	noorusaja	aja	noorus+aeg	22_S	SgG	et	noorusaja =aja  (SgG  >noorus+aeg !22_S
50151	intriigid	intriigi	intriig	22_S	PlN	et	intriigid =intriigi  (PlN  >intriig !22_S
50157	nõudepesulapid	lapi	nõude+pesu+lapp	22_S	PlN	et	nõudepesulapid =lapi  (PlN  >nõude+pesu+lapp !22_S
50159	psühhiaatrit	psühhiaatri	psühhiaater	02_S	SgP	et	psühhiaatrit =psühhiaatri  (SgP  >psühhiaater !02_S
50167	normaalkõver	kõver	normaal+kõver	02_AS	SgN	et	normaalkõver =kõver  (SgN  >normaal+kõver !02_AS
50169	hälbeks	hälbe	hälve	06_S	SgTr	et	hälbeks =hälbe  (SgTr  >hälve !06_S
50171	iseloomustamises	mustamise	ise+loo+mustamine	12_S	SgIn	et	iseloomustamises =mustamise  (SgIn  >ise+loo+mustamine !12_S
50184	nahavärv	värv	naha+värv	22_S	SgN	et	nahavärv =värv  (SgN  >naha+värv !22_S
50185	aktsepteerime	aktsepteeri	aktsepteerima	28_V	IndPrPl1	et	aktsepteerime =aktsepteeri  (IndPrPl1  >aktsepteerima !28_V
50187	elukaaslaselt	kaaslase	elu+kaaslane	12?10_S	SgAbl	et	elukaaslaselt =kaaslase  (SgAbl  >elu+kaaslane !12?10_S
50188	pahatihti	pahatihti	paha+tihti	41_D	ID	et	pahatihti =pahatihti  (ID  >paha+tihti !41_D
50192	rõhutan	rõhuta	rõhutama	27_V	IndPrSg1	et	rõhutan =rõhuta  (IndPrSg1  >rõhutama !27_V
50196	ämblikke	ämblikke	ämblik	25_S	PlP	et	ämblikke =ämblikke  (PlP  >ämblik !25_S
50198	kurdeta	kurde	kurtma	34_V	IndPrIps_	et	kurdeta =kurde  (IndPrIps_  >kurtma !34_V
50211	liitlane	liitlane	liitlane	12?10_S	SgN	et	liitlane =liitlane  (SgN  >liitlane !12?10_S
50212	ohvrina	ohvri	ohver	02_S	SgEs	et	ohvrina =ohvri  (SgEs  >ohver !02_S
50217	kulutasime	kuluta	kulutama	27_V	IndIpfPl1	et	kulutasime =kuluta  (IndIpfPl1  >kulutama !27_V
50226	ebatäpseteks	täpse	eba+täpne	02_A	PlTr	et	ebatäpseteks =täpse  (PlTr  >eba+täpne !02_A
50230	multikultuurse	kultuurse	multi+kultuurne	02_A	SgG	et	multikultuurse =kultuurse  (SgG  >multi+kultuurne !02_A
50252	koduga	kodu	kodu	17_S	SgKom	et	koduga =kodu  (SgKom  >kodu !17_S
50254	nähakse	näh	nägema	28_V	IndPrIps	et	nähakse =näh  (IndPrIps  >nägema !28_V
50255	elukaaslasena	kaaslase	elu+kaaslane	12?10_S	SgEs	et	elukaaslasena =kaaslase  (SgEs  >elu+kaaslane !12?10_S
50268	grammatiku	grammatiku	grammatik	02_S	SgG	et	grammatiku =grammatiku  (SgG  >grammatik !02_S
50287	nullasendisse	asendi	null+asend	02_S	SgIll	et	nullasendisse =asendi  (SgIll  >null+asend !02_S
50288	seinakontaktist	kontakti	seina+kontakt	22_S	SgEl	et	seinakontaktist =kontakti  (SgEl  >seina+kontakt !22_S
50297	teadusliku	teadusliku	teaduslik	25_A	SgG	et	teadusliku =teadusliku  (SgG  >teaduslik !25_A
50307	õpilasega	õpilase	õpilane	12_S	SgKom	et	õpilasega =õpilase  (SgKom  >õpilane !12_S
50320	tagupidi	pidi	tagu+pidi	41_D	ID	et	tagupidi =pidi  (ID  >tagu+pidi !41_D
50321	faktoreid	faktore	faktor	02_S	PlP	et	faktoreid =faktore  (PlP  >faktor !02_S
50333	tundlikud	tundliku	tundlik	25_A	PlN	et	tundlikud =tundliku  (PlN  >tundlik !25_A
50341	poisikoorid	koori	poisi+koor	22_S	PlN	et	poisikoorid =koori  (PlN  >poisi+koor !22_S
50349	rahvalaus	lau	rahva+laug	22_SA	SgIn	et	rahvalaus =lau  (SgIn  >rahva+laug !22_SA
50364	paraad	paraad	paraad	22_S	SgN	et	paraad =paraad  (SgN  >paraad !22_S
50366	elukorraga	korra	elu+kord	22_S	SgKom	et	elukorraga =korra  (SgKom  >elu+kord !22_S
50369	lauluväljakus	väljaku	laulu+väljak	02_S	SgIn	et	lauluväljakus =väljaku  (SgIn  >laulu+väljak !02_S
50373	pillimängijaid	mängija	pilli+mängija	01_S	PlP	et	pillimängijaid =mängija  (PlP  >pilli+mängija !01_S
50378	kooridesse	koori	koor	22_S	PlIll	et	kooridesse =koori  (PlIll  >koor !22_S
50384	sellepäras	pära	selle+pära	17_S	SgIn	et	sellepäras =pära  (SgIn  >selle+pära !17_S
50386	muinasjuttulaulud	laulu	muinas+juttu+laul	22_S	PlN	et	muinasjuttulaulud =laulu  (PlN  >muinas+juttu+laul !22_S
50388	folkloorikollektiive	kollektiive	folkloori+kollektiiv	22_S	PlP	et	folkloorikollektiive =kollektiive  (PlP  >folkloori+kollektiiv !22_S
50389	tõuk	tõuk	tõuk	22_S	SgN	et	tõuk =tõuk  (SgN  >tõuk !22_S
50390	muusikapillid	pilli	muusika+pill	22_S	PlN	et	muusikapillid =pilli  (PlN  >muusika+pill !22_S
50394	lühikises	kise	lühi+kisk	22_S	PlIn	et	lühikises =kise  (PlIn  >lühi+kisk !22_S
50395	samadest	sama	sama	17_P	PlEl	et	samadest =sama  (PlEl  >sama !17_P
50408	rahvusriided	riide	rahvus+riie	06_S	PlN	et	rahvusriided =riide  (PlN  >rahvus+riie !06_S
50411	nüüdaegsel	aegse	nüüd+aegne	02_A	SgAd	et	nüüdaegsel =aegse  (SgAd  >nüüd+aegne !02_A
50168	normaalkõvera	kõvera	normaal+kõver	02_AS	SgG	et	normaalkõvera =kõvera  (SgG  >normaal+kõver !02_AS
50180	taimetoitlasest	toitlase	taime+toitlane	12?10_S	SgEl	et	taimetoitlasest =toitlase  (SgEl  >taime+toitlane !12?10_S
50181	hukkuks	hukku	hukkuma	27_V	KndPrPs	et	hukkuks =hukku  (KndPrPs  >hukkuma !27_V
50183	riietusstiil	stiil	riietus+stiil	22_S	SgN	et	riietusstiil =stiil  (SgN  >riietus+stiil !22_S
50190	vastaks	vasta	vastama	29_V	KndPrPs	et	vastaks =vasta  (KndPrPs  >vastama !29_V
50199	idaeurooplasest	eurooplase	ida+eurooplane	12?10_S	SgEl	et	idaeurooplasest =eurooplase  (SgEl  >ida+eurooplane !12?10_S
50200	jututoas	toa	jutu+tuba	18_S	SgIn	et	jututoas =toa  (SgIn  >jutu+tuba !18_S
50210	kaaslane	kaaslane	kaaslane	12?10_S	SgN	et	kaaslane =kaaslane  (SgN  >kaaslane !12?10_S
50220	kaklema	kakle	kaklema	30_V	Sup	et	kaklema =kakle  (Sup  >kaklema !30_V
50221	süüdistagem	süüdista	süüdistama	27_V	ImpPrPl1	et	süüdistagem =süüdista  (ImpPrPl1  >süüdistama !27_V
50223	kõrvetada	kõrveta	kõrvetama	27_V	Inf	et	kõrvetada =kõrveta  (Inf  >kõrvetama !27_V
50225	vestlustes	vestlus	vestlus	11~09_S	PlIn	et	vestlustes =vestlus  (PlIn  >vestlus !11~09_S
50227	ebausklik	usklik	eba+usklik	25_AS	SgN	et	ebausklik =usklik  (SgN  >eba+usklik !25_AS
50231	territoriaalsed	territoriaalse	territoriaalne	02_A	PlN	et	territoriaalsed =territoriaalse  (PlN  >territoriaalne !02_A
50240	taolisest	taolise	taoline	12?10_A	SgEl	et	taolisest =taolise  (SgEl  >taoline !12?10_A
50244	keeruka	keeruka	keerukas	02_A	SgG	et	keeruka =keeruka  (SgG  >keerukas !02_A
50249	reisimisvõimalused	võimaluse	reisi+mis+võimalus	11_S	PlN	et	reisimisvõimalused =võimaluse  (PlN  >reisi+mis+võimalus !11_S
50250	perel	pere	pere	16_S	SgAd	et	perel =pere  (SgAd  >pere !16_S
50251	valehäbita	häbi	vale+häbi	17_S	SgAb	et	valehäbita =häbi  (SgAb  >vale+häbi !17_S
50256	autoliisingu	liisingu	auto+liising	02_S	SgG	et	autoliisingu =liisingu  (SgG  >auto+liising !02_S
50260	majandusblokaad	blokaad	majandus+blokaad	22_S	SgN	et	majandusblokaad =blokaad  (SgN  >majandus+blokaad !22_S
50261	maksureform	reform	maksu+reform	22_S	SgN	et	maksureform =reform  (SgN  >maksu+reform !22_S
50272	puududa	puudu	puuduma	27_V	Inf	et	puududa =puudu  (Inf  >puuduma !27_V
50273	konkurentsivõimalik	võimalik	konkurentsi+võimalik	25_A	SgN	et	konkurentsivõimalik =võimalik  (SgN  >konkurentsi+võimalik !25_A
50274	kasvatab	kasvata	kasvatama	27_V	IndPrSg3	et	kasvatab =kasvata  (IndPrSg3  >kasvatama !27_V
50276	kavatavad	tava	kava+tava	17_S	PlN	et	kavatavad =tava  (PlN  >kava+tava !17_S
50278	heasoovlik	soovlik	hea+soovlik	25_A	SgN	et	heasoovlik =soovlik  (SgN  >hea+soovlik !25_A
50281	tahtel	tahte	tahe	06_S	SgAd	et	tahtel =tahte  (SgAd  >tahe !06_S
50284	kasutusjuhend	juhend	kasutus+juhend	02_S	SgN	et	kasutusjuhend =juhend  (SgN  >kasutus+juhend !02_S
50289	elektriohtlik	ohtlik	elektri+ohtlik	25_A	SgN	et	elektriohtlik =ohtlik  (SgN  >elektri+ohtlik !25_A
50290	puistake	puista	puistama	29_V	ImpPrPl2	et	puistake =puista  (ImpPrPl2  >puistama !29_V
50293	jõukased	kase	jõu+kask	22_S	PlN	et	jõukased =kase  (PlN  >jõu+kask !22_S
50294	emigratsioon	emigratsioon	emigratsioon	22_S	SgN	et	emigratsioon =emigratsioon  (SgN  >emigratsioon !22_S
50295	usa-st	usa	usa	xx_Q	SgEl	et	usa-st =usa  (SgEl  >usa !xx_Q
50301	ajaloolasena	loolase	aja+loolane	12?10_S	SgEs	et	ajaloolasena =loolase  (SgEs  >aja+loolane !12?10_S
50306	ilukirjanduse	kirjanduse	ilu+kirjandus	11_S	SgG	et	ilukirjanduse =kirjanduse  (SgG  >ilu+kirjandus !11_S
50309	laabub	laabu	laabuma	27_V	IndPrSg3	et	laabub =laabu  (IndPrSg3  >laabuma !27_V
50312	uskliku	uskliku	usklik	25_AS	SgG	et	uskliku =uskliku  (SgG  >usklik !25_AS
50315	väljendusvahendi	vahendi	väljendus+vahend	02_S	SgG	et	väljendusvahendi =vahendi  (SgG  >väljendus+vahend !02_S
50318	peodes	peo	peo	26_S	PlIn	et	peodes =peo  (PlIn  >peo !26_S
50323	kaneel	kaneel	kaneel	22_S	SgN	et	kaneel =kaneel  (SgN  >kaneel !22_S
50328	kuulasin	kuula	kuulama	29_V	IndIpfSg1	et	kuulasin =kuula  (IndIpfSg1  >kuulama !29_V
50329	laulan	laula	laulma	33_V	IndPrSg1	et	laulan =laula  (IndPrSg1  >laulma !33_V
50335	lõbusait	sait	lõbu+sait	22_S	SgN	et	lõbusait =sait  (SgN  >lõbu+sait !22_S
50338	laulupidud	pidu	laulu+pidu	17_S	PlN	et	laulupidud =pidu  (PlN  >laulu+pidu !17_S
50342	rahvapidud	pidu	rahva+pidu	17_S	PlN	et	rahvapidud =pidu  (PlN  >rahva+pidu !17_S
50347	improvisatsioon	improvisatsioon	improvisatsioon	22_S	SgN	et	improvisatsioon =improvisatsioon  (SgN  >improvisatsioon !22_S
50356	maaimaga	ima	maa+ima	17_S	SgKom	et	maaimaga =ima  (SgKom  >maa+ima !17_S
50371	lauluvõistlustes	võistlus	laulu+võistlus	11~09_S	PlIn	et	lauluvõistlustes =võistlus  (PlIn  >laulu+võistlus !11~09_S
50372	komposeerivad	poseeriva	kom+poseeriv	02_A	PlN	et	komposeerivad =poseeriva  (PlN  >kom+poseeriv !02_A
50377	koorimeistrid	meistri	koori+meister	02_S	PlN	et	koorimeistrid =meistri  (PlN  >koori+meister !02_S
50176	normaalsest	normaalse	normaalne	02_A	SgEl	et	normaalsest =normaalse  (SgEl  >normaalne !02_A
50178	hälbega	hälbe	hälve	06_S	SgKom	et	hälbega =hälbe  (SgKom  >hälve !06_S
50179	isendid	isendi	isend	02_S	PlN	et	isendid =isendi  (PlN  >isend !02_S
50189	paradoksaalsel	paradoksaalse	paradoksaalne	02_A	SgAd	et	paradoksaalsel =paradoksaalse  (SgAd  >paradoksaalne !02_A
50191	elukaaslane	kaaslane	elu+kaaslane	12?10_S	SgN	et	elukaaslane =kaaslane  (SgN  >elu+kaaslane !12?10_S
50195	nõudepesulappide	lappi	nõude+pesu+lapp	22_S	PlG	et	nõudepesulappide =lappi  (PlG  >nõude+pesu+lapp !22_S
50201	klappis	klappi	klappima	28_V	IndIpfSg3	et	klappis =klappi  (IndIpfSg3  >klappima !28_V
50203	fotodesse	foto	foto	16_S	PlIll	et	fotodesse =foto  (PlIll  >foto !16_S
50204	hingesugulased	sugulase	hinge+sugulane	12_S	PlN	et	hingesugulased =sugulase  (PlN  >hinge+sugulane !12_S
50205	suhtele	suhte	suhe	06_S	SgAll	et	suhtele =suhte  (SgAll  >suhe !06_S
50206	ühiskonnaheidik	heidik	ühis+konna+heidik	02_S	SgN	et	ühiskonnaheidik =heidik  (SgN  >ühis+konna+heidik !02_S
50207	nõdrameelne	meelne	nõdra+meelne	02_A	SgN	et	nõdrameelne =meelne  (SgN  >nõdra+meelne !02_A
50209	üksindusega	üksinduse	üksindus	11_S	SgKom	et	üksindusega =üksinduse  (SgKom  >üksindus !11_S
50213	jätaks	jäta	jätma	35_V	KndPrPs	et	jätaks =jäta  (KndPrPs  >jätma !35_V
50228	staadiumis	staadiumi	staadium	19~02_S	SgIn	et	staadiumis =staadiumi  (SgIn  >staadium !19~02_S
50229	poolepealt	pea	poole+pea	26_S	SgAbl	et	poolepealt =pea  (SgAbl  >poole+pea !26_S
50234	eredaks	ereda	ere	02_A	SgTr	et	eredaks =ereda  (SgTr  >ere !02_A
50236	üleminekud	mineku	üle+minek	02_S	PlN	et	üleminekud =mineku  (PlN  >üle+minek !02_S
50238	universaalse	universaalse	universaalne	02_A	SgG	et	universaalse =universaalse  (SgG  >universaalne !02_A
50241	arengud	arengu	areng	02_S	PlN	et	arengud =arengu  (PlN  >areng !02_S
50248	õppimisvõimalused	võimaluse	õppimis+võimalus	11_S	PlN	et	õppimisvõimalused =võimaluse  (PlN  >õppimis+võimalus !11_S
50253	kooseluks	elu	koos+elu	17_S	SgTr	et	kooseluks =elu  (SgTr  >koos+elu !17_S
50263	põlisrahvuse	rahvuse	põlis+rahvus	11~09_S	SgG	et	põlisrahvuse =rahvuse  (SgG  >põlis+rahvus !11~09_S
50264	mahajäämus	jäämus	maha+jäämus	11~09_S	SgN	et	mahajäämus =jäämus  (SgN  >maha+jäämus !11~09_S
50265	ekstensiivarengult	arengu	ekstensiiv+areng	02_S	SgAbl	et	ekstensiivarengult =arengu  (SgAbl  >ekstensiiv+areng !02_S
50266	intensiivarengule	arengu	intensiiv+areng	02_S	SgAll	et	intensiivarengule =arengu  (SgAll  >intensiiv+areng !02_S
50267	vastaksite	vasta	vastama	29_V	KndPrPl2	et	vastaksite =vasta  (KndPrPl2  >vastama !29_V
50269	ep	ep	ep	41_D	ID	et	ep =ep  (ID  >ep !41_D
50280	mõjutame	mõjuta	mõjutama	27_V	IndPrPl1	et	mõjutame =mõjuta  (IndPrPl1  >mõjutama !27_V
50285	karbist	karbi	karp	22_S	SgEl	et	karbist =karbi  (SgEl  >karp !22_S
50291	vajutage	vajuta	vajutama	27_V	ImpPrPl2	et	vajutage =vajuta  (ImpPrPl2  >vajutama !27_V
50292	järelevalveta	valve	järele+valve	06_S	SgAb	et	järelevalveta =valve  (SgAb  >järele+valve !06_S
50296	terviklikke	terviklikke	terviklik	25_A	PlP	et	terviklikke =terviklikke  (PlP  >terviklik !25_A
50299	malle	malle	mall	22_S	PlP	et	malle =malle  (PlP  >mall !22_S
50300	võtmeesinejaks	esineja	võtme+esineja	01_S	SgTr	et	võtmeesinejaks =esineja  (SgTr  >võtme+esineja !01_S
50302	organid	organi	organ	02_S	PlN	et	organid =organi  (PlN  >organ !02_S
50303	sektorist	sektori	sektor	02_S	SgEl	et	sektorist =sektori  (SgEl  >sektor !02_S
50305	õppimissoov	soov	õppimis+soov	22_S	SgN	et	õppimissoov =soov  (SgN  >õppimis+soov !22_S
50308	õppisite	õppi	õppima	28_V	IndIpfPl2	et	õppisite =õppi  (IndIpfPl2  >õppima !28_V
50324	heliloojat	looja	heli+looja	01_S	SgP	et	heliloojat =looja  (SgP  >heli+looja !01_S
50325	tühjal	tühja	tühi	24_A	SgAd	et	tühjal =tühja  (SgAd  >tühi !24_A
50331	juubeli	juubeli	juubel	02_S	SgG	et	juubeli =juubeli  (SgG  >juubel !02_S
50339	eestirahvale	rahva	eesti+rahvas	07_S	SgAll	et	eestirahvale =rahva  (SgAll  >eesti+rahvas !07_S
50359	rahvuskleit	kleit	rahvus+kleit	22_S	SgN	et	rahvuskleit =kleit  (SgN  >rahvus+kleit !22_S
50360	katuse	katuse	katus	09_S	SgG	et	katuse =katuse  (SgG  >katus !09_S
50362	rokk-	rokk	rokk	22_S	SgN	et	rokk- =rokk  (SgN  >rokk !22_S
50370	muusikatega	muusika	muusika	01_S	PlKom	et	muusikatega =muusika  (PlKom  >muusika !01_S
50376	laulupiduta	pidu	laulu+pidu	17_S	SgAb	et	laulupiduta =pidu  (SgAb  >laulu+pidu !17_S
50385	osaled	osale	osalema	27_V	IndPrSg2	et	osaled =osale  (IndPrSg2  >osalema !27_V
50392	nimetata	nimeta	nimetama	27_V	IndPrIps_	et	nimetata =nimeta  (IndPrIps_  >nimetama !27_V
50396	rahvalauludesse	laulu	rahva+laul	22_S	PlIll	et	rahvalauludesse =laulu  (PlIll  >rahva+laul !22_S
50398	muusikainstrumendita	instrumendi	muusika+instrument	22_S	SgAb	et	muusikainstrumendita =instrumendi  (SgAb  >muusika+instrument !22_S
50197	jumaldatakse	jumalda	jumaldama	27_V	IndPrIps	et	jumaldatakse =jumalda  (IndPrIps  >jumaldama !27_V
50208	jäägu	jää	jääma	37_V	ImpPrPs	et	jäägu =jää  (ImpPrPs  >jääma !37_V
50214	liitlasena	liitlase	liitlane	12?10_S	SgEs	et	liitlasena =liitlase  (SgEs  >liitlane !12?10_S
50219	imelikki	imelik	imelik	25_A	SgN^	et	imelikki =imelik  (SgN^  >imelik !25_A
50222	iseennast	ennas	ise+enese	00_P	SgP	et	iseennast =ennas  (SgP  >ise+enese !00_P
50224	uudistes	uudis	uudis	09_S	PlIn	et	uudistes =uudis  (PlIn  >uudis !09_S
50232	elukvaliteedile	kvaliteedi	elu+kvaliteet	22_S	SgAll	et	elukvaliteedile =kvaliteedi  (SgAll  >elu+kvaliteet !22_S
50233	eneseteadvustamine	teadvustamine	enese+teadvustamine	12_S	SgN	et	eneseteadvustamine =teadvustamine  (SgN  >enese+teadvustamine !12_S
50235	multikultuurne	kultuurne	multi+kultuurne	02_A	SgN	et	multikultuurne =kultuurne  (SgN  >multi+kultuurne !02_A
50247	stsenaariume	stsenaariume	stsenaarium	19_S	PlP	et	stsenaariume =stsenaariume  (PlP  >stsenaarium !19_S
50258	ettevõtjana	võtja	ette+võtja	01_S	SgEs	et	ettevõtjana =võtja  (SgEs  >ette+võtja !01_S
50259	äriasjadega	asja	äri+asi	24_S	PlKom	et	äriasjadega =asja  (PlKom  >äri+asi !24_S
50262	sotsiaalses	sotsiaalse	sotsiaalne	02_A	SgIn	et	sotsiaalses =sotsiaalse  (SgIn  >sotsiaalne !02_A
50270	rahvuselt	rahvuse	rahvus	11~09_S	SgAbl	et	rahvuselt =rahvuse  (SgAbl  >rahvus !11~09_S
50275	soobid	soobi	soop	22_S	PlN	et	soobid =soobi  (PlN  >soop !22_S
50286	vajalikule	vajaliku	vajalik	25_A	SgAll	et	vajalikule =vajaliku  (SgAll  >vajalik !25_A
50298	teadlaste-	teadlas	teadlane	12?10_S	PlG	et	teadlaste- =teadlas  (PlG  >teadlane !12?10_S
50304	ajaloolasest	loolase	aja+loolane	12?10_S	SgEl	et	ajaloolasest =loolase  (SgEl  >aja+loolane !12?10_S
50313	nõukoguajal	aja	nõu+kogu+aeg	22_S	SgAd	et	nõukoguajal =aja  (SgAd  >nõu+kogu+aeg !22_S
50314	tähistas	tähista	tähistama	27_V	IndIpfSg3	et	tähistas =tähista  (IndIpfSg3  >tähistama !27_V
50316	rahvukostüümid	kostüümi	rahvu+kostüüm	22_S	PlN	et	rahvukostüümid =kostüümi  (PlN  >rahvu+kostüüm !22_S
50319	hingedes	hinge	hing	22_S	PlIn	et	hingedes =hinge  (PlIn  >hing !22_S
50322	rahvaviis	viis	rahva+viis	22_S	SgN	et	rahvaviis =viis  (SgN  >rahva+viis !22_S
50326	põlvkonnade	konna	põlv+konn	22_S	PlG	et	põlvkonnade =konna  (PlG  >põlv+konn !22_S
50330	rongkäiguga	käigu	rong+käik	22_S	SgKom	et	rongkäiguga =käigu  (SgKom  >rong+käik !22_S
50332	eestvedajaks	vedaja	eest+vedaja	01_S	SgTr	et	eestvedajaks =vedaja  (SgTr  >eest+vedaja !01_S
50337	rock-muusikaga	muusika	rock-muusika	01_S	SgKom	et	rock-muusikaga =muusika  (SgKom  >rock-muusika !01_S
50346	koorilauluajal	aja	koori+laulu+aeg	22_S	SgAd	et	koorilauluajal =aja  (SgAd  >koori+laulu+aeg !22_S
50348	meelelahustuseks	lahustuse	meele+lahustus	11_S	SgTr	et	meelelahustuseks =lahustuse  (SgTr  >meele+lahustus !11_S
50351	soendab	soenda	soendama	27_V	IndPrSg3	et	soendab =soenda  (IndPrSg3  >soendama !27_V
50352	lauliku	lauliku	laulik	02_S	SgG	et	lauliku =lauliku  (SgG  >laulik !02_S
50353	serblased	serblase	serblane	12?10_S	PlN	et	serblased =serblase  (PlN  >serblane !12?10_S
50354	rokk-kontsert	kontsert	rokk-kontsert	22_S	SgN	et	rokk-kontsert =kontsert  (SgN  >rokk-kontsert !22_S
50367	eeldame	eelda	eeldama	27_V	IndPrPl1	et	eeldame =eelda  (IndPrPl1  >eeldama !27_V
50374	spetsiifiline	spetsiifiline	spetsiifiline	12_A	SgN	et	spetsiifiline =spetsiifiline  (SgN  >spetsiifiline !12_A
50375	niisugustest	sugus	nii+sugune	10_P	PlEl	et	niisugustest =sugus  (PlEl  >nii+sugune !10_P
50381	häbis	häbi	häbi	17_S	SgIn	et	häbis =häbi  (SgIn  >häbi !17_S
50382	mitmendast	mitmenda	mitmes	02_P	SgEl	et	mitmendast =mitmenda  (SgEl  >mitmes !02_P
50413	raadiosaadete	saade	raadio+saade	06_S	PlG	et	raadiosaadete =saade  (PlG  >raadio+saade !06_S
50414	eestikeeltes	keel	eesti+keel	13_S	PlIn	et	eestikeeltes =keel  (PlIn  >eesti+keel !13_S
50417	pealtvaatajatele	vaataja	pealt+vaataja	01_S	PlAll	et	pealtvaatajatele =vaataja  (PlAll  >pealt+vaataja !01_S
50420	täishääliku	hääliku	täis+häälik	02_S	SgG	et	täishääliku =hääliku  (SgG  >täis+häälik !02_S
50424	harmoonias	harmoonia	harmoonia	01_S	SgIn	et	harmoonias =harmoonia  (SgIn  >harmoonia !01_S
50428	pulmale	pulma	pulm	22_S	SgAll	et	pulmale =pulma  (SgAll  >pulm !22_S
50430	loodushäälte	hääl	loodus+hääl	13_S	PlG	et	loodushäälte =hääl  (PlG  >loodus+hääl !13_S
50431	ringide	ringi	ring	22_S	PlG	et	ringide =ringi  (PlG  >ring !22_S
50441	laulurahval	rahva	laulu+rahvas	07_S	SgAd	et	laulurahval =rahva  (SgAd  >laulu+rahvas !07_S
50442	arvamuste	arvamus	arvamus	11_S	PlG	et	arvamuste =arvamus  (PlG  >arvamus !11_S
50450	sõjaväelane	väelane	sõja+väelane	12?10_S	SgN	et	sõjaväelane =väelane  (SgN  >sõja+väelane !12?10_S
50451	sõjale	sõja	sõda	18_S	SgAll	et	sõjale =sõja  (SgAll  >sõda !18_S
50452	uueaja	aja	uue+aeg	22_S	SgG	et	uueaja =aja  (SgG  >uue+aeg !22_S
50455	arhiivist	arhiivi	arhiiv	22_S	SgEl	et	arhiivist =arhiivi  (SgEl  >arhiiv !22_S
50282	korraldata	korralda	korraldama	27_V	IndPrIps_	et	korraldata =korralda  (IndPrIps_  >korraldama !27_V
50283	puhuri	puhuri	puhur	02_S	SgG	et	puhuri =puhuri  (SgG  >puhur !02_S
50310	esitate	esita	esitama	27_V	IndPrPl2	et	esitate =esita  (IndPrPl2  >esitama !27_V
50311	laulutüüp	tüüp	laulu+tüüp	22_S	SgN	et	laulutüüp =tüüp  (SgN  >laulu+tüüp !22_S
50317	mängudest	mängu	mäng	22_S	PlEl	et	mängudest =mängu  (PlEl  >mäng !22_S
50327	allates	ate	all+att	22_S	PlIn	et	allates =ate  (PlIn  >all+att !22_S
50334	ainulaadsed	laadse	ainu+laadne	02_AS	PlN	et	ainulaadsed =laadse  (PlN  >ainu+laadne !02_AS
50336	arvamustes	arvamus	arvamus	11_S	PlIn	et	arvamustes =arvamus  (PlIn  >arvamus !11_S
50340	alustakse	takse	alus+taks	22_S	PlP	et	alustakse =takse  (PlP  >alus+taks !22_S
50343	mängusid	mängu	mäng	22_S	PlP	et	mängusid =mängu  (PlP  >mäng !22_S
50344	jutustame	jutusta	jutustama	27_V	IndPrPl1	et	jutustame =jutusta  (IndPrPl1  >jutustama !27_V
50345	elanikul	elaniku	elanik	25_S	SgAd	et	elanikul =elaniku  (SgAd  >elanik !25_S
50350	laulurahvusega	rahvuse	laulu+rahvus	11~09_S	SgKom	et	laulurahvusega =rahvuse  (SgKom  >laulu+rahvus !11~09_S
50355	pärinema	pärine	pärinema	27_V	Sup	et	pärinema =pärine  (Sup  >pärinema !27_V
50357	kombete	kombe	kombe	06_S	PlG	et	kombete =kombe  (PlG  >kombe !06_S
50358	rahvusriietes	riie	rahvus+riie	06_S	PlIn	et	rahvusriietes =riie  (PlIn  >rahvus+riie !06_S
50361	audiokasette	e	audio+kas+esi	15_S	SgAdt	et	audiokasette =e  (SgAdt  >audio+kas+esi !15_S
50363	transpordiliikumine	liikumine	transpordi+liikumine	12_S	SgN	et	transpordiliikumine =liikumine  (SgN  >transpordi+liikumine !12_S
50365	lauluväljakuni	väljaku	laulu+väljak	02_S	SgTer	et	lauluväljakuni =väljaku  (SgTer  >laulu+väljak !02_S
50368	unustasime	unusta	unustama	27_V	IndIpfPl1	et	unustasime =unusta  (IndIpfPl1  >unustama !27_V
50379	1869-l			xx_Q	SgAd	et	-l =  (SgAd  > !xx_Q
50391	kontrollitati	tati	kont+rolli+tatt	22_S	SgG	et	kontrollitati =tati  (SgG  >kont+rolli+tatt !22_S
50393	piirangud	piirangu	piirang	02_S	PlN	et	piirangud =piirangu  (PlN  >piirang !02_S
50397	üldsõnaga	sõna	üld+sõna	17_S	SgKom	et	üldsõnaga =sõna  (SgKom  >üld+sõna !17_S
50403	veedaksin	veeda	veetma	34_V	KndPrSg1	et	veedaksin =veeda  (KndPrSg1  >veetma !34_V
50407	muusitita	siti	muu+sitt	22_SA	SgAb	et	muusitita =siti  (SgAb  >muu+sitt !22_SA
50410	vokaalset	vokaalse	vokaalne	02_A	SgP	et	vokaalset =vokaalse  (SgP  >vokaalne !02_A
50433	kiriklaulud	laulu	kirik+laul	22_S	PlN	et	kiriklaulud =laulu  (PlN  >kirik+laul !22_S
50437	veetmas	veet	veetma	34_V	SupIn	et	veetmas =veet  (SupIn  >veetma !34_V
50445	võivad-olla	oll	võivad-olema	36_V	Inf	et	võivad-olla =oll  (Inf  >võivad-olema !36_V
50453	vajutame	vajuta	vajutama	27_V	IndPrPl1	et	vajutame =vajuta  (IndPrPl1  >vajutama !27_V
50458	nukraid	nukra	nukker	02_A	PlP	et	nukraid =nukra  (PlP  >nukker !02_A
50459	pillimehed	mehe	pilli+mees	13_S	PlN	et	pillimehed =mehe  (PlN  >pilli+mees !13_S
50471	tervikuga	terviku	tervik	02_S	SgKom	et	tervikuga =terviku  (SgKom  >tervik !02_S
50475	võitleme	võitle	võitlema	30_V	IndPrPl1	et	võitleme =võitle  (IndPrPl1  >võitlema !30_V
50488	rahvaarhiivis	arhiivi	rahva+arhiiv	22_S	SgIn	et	rahvaarhiivis =arhiivi  (SgIn  >rahva+arhiiv !22_S
50491	noorinimestel	inimes	noor+inimene	12_S	PlAd	et	noorinimestel =inimes  (PlAd  >noor+inimene !12_S
50497	diplomitööks	töö	diplomi+töö	26_S	SgTr	et	diplomitööks =töö  (SgTr  >diplomi+töö !26_S
50498	diplomitöös	töö	diplomi+töö	26_S	SgIn	et	diplomitöös =töö  (SgIn  >diplomi+töö !26_S
50513	ettekandega	kande	ette+kanne	06_S	SgKom	et	ettekandega =kande  (SgKom  >ette+kanne !06_S
50514	eesnimega	nime	ees+nimi	20_S	SgKom	et	eesnimega =nime  (SgKom  >ees+nimi !20_S
50516	läänemeres	mere	lääne+meri	20_S	SgIn	et	läänemeres =mere  (SgIn  >lääne+meri !20_S
50532	teaterid	teateri	teater	02_S	PlN	et	teaterid =teateri  (PlN  >teater !02_S
50537	maapealset	pealse	maa+pealne	02_AS	SgP	et	maapealset =pealse  (SgP  >maa+pealne !02_AS
50545	lõpik	lõpik	lõpik	02_S	SgN	et	lõpik =lõpik  (SgN  >lõpik !02_S
50552	peen	peen	peen	13_A	SgN	et	peen =peen  (SgN  >peen !13_A
50567	klassijuhatajaid	juhataja	klassi+juhataja	01_S	PlP	et	klassijuhatajaid =juhataja  (PlP  >klassi+juhataja !01_S
50572	kodumis	mi	kodu+mi	26_S	SgIn	et	kodumis =mi  (SgIn  >kodu+mi !26_S
50573	maakleri	maakleri	maakler	02_S	SgG	et	maakleri =maakleri  (SgG  >maakler !02_S
50574	vastuvõetava	võetava	vastu+võetav	02_A	SgG	et	vastuvõetava =võetava  (SgG  >vastu+võetav !02_A
50588	toodab	tooda	tootma	34_V	IndPrSg3	et	toodab =tooda  (IndPrSg3  >tootma !34_V
50589	ravimit	ravimi	ravim	02_S	SgP	et	ravimit =ravimi  (SgP  >ravim !02_S
50600	festivalipäev	päev	festivali+päev	22_S	SgN	et	festivalipäev =päev  (SgN  >festivali+päev !22_S
50380	patriootilised	patriootilise	patriootiline	12_A	PlN	et	patriootilised =patriootilise  (PlN  >patriootiline !12_A
50383	hitt	hitt	hitt	22_S	SgN	et	hitt =hitt  (SgN  >hitt !22_S
50387	laude	laude	laud	22_S	PlP	et	laude =laude  (PlP  >laud !22_S
50399	regilauladel	la	regi+lau+la	26_S	PlAd	et	regilauladel =la  (PlAd  >regi+lau+la !26_S
50401	lõbutsedes	lõbutse	lõbutsema	27_V	Ger	et	lõbutsedes =lõbutse  (Ger  >lõbutsema !27_V
50402	tantsusaateks	saate	tantsu+saade	06_S	SgTr	et	tantsusaateks =saate  (SgTr  >tantsu+saade !06_S
50405	loodushäältega	hääl	loodus+hääl	13_S	PlKom	et	loodushäältega =hääl  (PlKom  >loodus+hääl !13_S
50406	muusikakultuur	kultuur	muusika+kultuur	22_S	SgN	et	muusikakultuur =kultuur  (SgN  >muusika+kultuur !22_S
50409	grupiks	grupi	grupp	22_S	SgTr	et	grupiks =grupi  (SgTr  >grupp !22_S
50416	laulupidus	pidu	laulu+pidu	17_S	SgIn	et	laulupidus =pidu  (SgIn  >laulu+pidu !17_S
50418	mitmepoolne	poolne	mitme+poolne	02_A	SgN	et	mitmepoolne =poolne  (SgN  >mitme+poolne !02_A
50419	rajanes	rajane	rajanema	27_V	IndIpfSg3	et	rajanes =rajane  (IndIpfSg3  >rajanema !27_V
50425	lahutama	lahuta	lahutama	27_V	Sup	et	lahutama =lahuta  (Sup  >lahutama !27_V
50439	aspektidest	aspekti	aspekt	22_S	PlEl	et	aspektidest =aspekti  (PlEl  >aspekt !22_S
50444	vanud	vanu	vanuma	27_V	IndPrSg2	et	vanud =vanu  (IndPrSg2  >vanuma !27_V
50449	koovad	koo	kuduma	28_V	IndPrPl3	et	koovad =koo  (IndPrPl3  >kuduma !28_V
50462	põhul	põhu	põhk	22_S	SgAd	et	põhul =põhu  (SgAd  >põhk !22_S
50463	traditsioonides	traditsiooni	traditsioon	22_S	PlIn	et	traditsioonides =traditsiooni  (PlIn  >traditsioon !22_S
50464	jutustades	jutusta	jutustama	27_V	Ger	et	jutustades =jutusta  (Ger  >jutustama !27_V
50465	sellena	selle	see	00_P	SgEs	et	sellena =selle  (SgEs  >see !00_P
50466	filmidel	filmi	film	22_S	PlAd	et	filmidel =filmi  (PlAd  >film !22_S
50468	instrumentideta	instrumenti	instrument	22_S	PlAb	et	instrumentideta =instrumenti  (PlAb  >instrument !22_S
50472	ajades	aja	ajama	27_V	Ger	et	ajades =aja  (Ger  >ajama !27_V
50477	orkestriid	orkestri	orkester	02_S	PlP	et	orkestriid =orkestri  (PlP  >orkester !02_S
50490	mõjult	mõju	mõju	17_S	SgAbl	et	mõjult =mõju  (SgAbl  >mõju !17_S
50495	plaadil	plaadi	plaat	22_S	SgAd	et	plaadil =plaadi  (SgAd  >plaat !22_S
50499	juhendada	juhenda	juhendama	27_V	Inf	et	juhendada =juhenda  (Inf  >juhendama !27_V
50506	puhkusereisid	reisi	puhkuse+reis	22_S	PlN	et	puhkusereisid =reisi  (PlN  >puhkuse+reis !22_S
50515	talispordi	spordi	tali+sport	22_S	SgG	et	talispordi =spordi  (SgG  >tali+sport !22_S
50518	nautisin	nauti	nautima	28_V	IndIpfSg1	et	nautisin =nauti  (IndIpfSg1  >nautima !28_V
50519	päevitasin	päevita	päevitama	27_V	IndIpfSg1	et	päevitasin =päevita  (IndIpfSg1  >päevitama !27_V
50520	päikeseloojakut	loojaku	päikese+loojak	02_S	SgP	et	päikeseloojakut =loojaku  (SgP  >päikese+loojak !02_S
50522	murrakut	murraku	murrak	02_S	SgP	et	murrakut =murraku  (SgP  >murrak !02_S
50533	spordikeskused	keskuse	spordi+keskus	11~09_S	PlN	et	spordikeskused =keskuse  (PlN  >spordi+keskus !11~09_S
50538	põrgut	põrgu	põrgu	01_S	SgP	et	põrgut =põrgu  (SgP  >põrgu !01_S
50539	otsekohesed	kohese	otse+kohene	10_A	PlN	et	otsekohesed =kohese  (PlN  >otse+kohene !10_A
50541	valetas	valeta	valetama	27_V	IndIpfSg3	et	valetas =valeta  (IndIpfSg3  >valetama !27_V
50550	kõrgemajas	maja	kõrge+maja	17_S	SgIn	et	kõrgemajas =maja  (SgIn  >kõrge+maja !17_S
50559	laudal	lauda	laut	22_S	SgAd	et	laudal =lauda  (SgAd  >laut !22_S
50563	mustaga	musta	must	22_AS	SgKom	et	mustaga =musta  (SgKom  >must !22_AS
50571	cv-il	cv	cv	xx_Q	SgAd	et	cv-il =cv  (SgAd  >cv !xx_Q
50581	neerud	neeru	neer	22_S	PlN	et	neerud =neeru  (PlN  >neer !22_S
50585	äriplaan	plaan	äri+plaan	22_S	SgN	et	äriplaan =plaan  (SgN  >äri+plaan !22_S
50603	laulufestival	festival	laulu+festival	19_S	SgN	et	laulufestival =festival  (SgN  >laulu+festival !19_S
50604	karneval	karneval	karneval	19_S	SgN	et	karneval =karneval  (SgN  >karneval !19_S
50605	rahvatantse	tantse	rahva+tants	22_S	PlP	et	rahvatantse =tantse  (PlP  >rahva+tants !22_S
50610	lahendatakse	lahenda	lahendama	27_V	IndPrIps	et	lahendatakse =lahenda  (IndPrIps  >lahendama !27_V
50622	sahtliga	sahtli	sahtel	02_S	SgKom	et	sahtliga =sahtli  (SgKom  >sahtel !02_S
50631	dessert	dessert	dessert	22_S	SgN	et	dessert =dessert  (SgN  >dessert !22_S
50634	medpunkt	punkt	med+punkt	22_S	SgN	et	medpunkt =punkt  (SgN  >med+punkt !22_S
50639	elektriboiler	boiler	elektri+boiler	02_S	SgN	et	elektriboiler =boiler  (SgN  >elektri+boiler !02_S
50641	sulepadja	padja	sule+padi	24_S	SgG	et	sulepadja =padja  (SgG  >sule+padi !24_S
50659	sissekäigid	käigi	sisse+käik	22_S	PlN	et	sissekäigid =käigi  (PlN  >sisse+käik !22_S
50662	sõiduteel	tee	sõidu+tee	26_S	SgAd	et	sõiduteel =tee  (SgAd  >sõidu+tee !26_S
50400	kohte	kohte	koht	22_S	PlP	et	kohte =kohte  (PlP  >koht !22_S
50404	lauluõhtud	õhtu	laulu+õhtu	01_S	PlN	et	lauluõhtud =õhtu  (PlN  >laulu+õhtu !01_S
50415	laulufestivalide	festivali	laulu+festival	19_S	PlG	et	laulufestivalide =festivali  (PlG  >laulu+festival !19_S
50421	uksi	uks	uks	14_S	PlP	et	uksi =uks  (PlP  >uks !14_S
50423	teedes	tee	tee	26_S	PlIn	et	teedes =tee  (PlIn  >tee !26_S
50427	kultuurilt	kultuuri	kultuur	22_S	SgAbl	et	kultuurilt =kultuuri  (SgAbl  >kultuur !22_S
50435	lauarahva	rahva	laua+rahvas	07_S	SgG	et	lauarahva =rahva  (SgG  >laua+rahvas !07_S
50438	oskuseid	oskuse	oskus	09_S	PlP	et	oskuseid =oskuse  (PlP  >oskus !09_S
50447	rahvalauluansambleid	ansamble	rahva+laulu+ansambel	02_S	PlP	et	rahvalauluansambleid =ansamble  (PlP  >rahva+laulu+ansambel !02_S
50454	lauluüritus	üritus	laulu+üritus	11_S	SgN	et	lauluüritus =üritus  (SgN  >laulu+üritus !11_S
50457	folkrühme	rühme	folk+rühm	22_S	PlP	et	folkrühme =rühme  (PlP  >folk+rühm !22_S
50469	riimiga	riimi	riim	22_S	SgKom	et	riimiga =riimi  (SgKom  >riim !22_S
50479	kasutakse	takse	kasu+taks	22_S	PlP	et	kasutakse =takse  (PlP  >kasu+taks !22_S
50486	iseseisvate	seisva	ise+seisev	02_A	PlG	et	iseseisvate =seisva  (PlG  >ise+seisev !02_A
50487	varajaste	varajas	varajane	12_A	PlG	et	varajaste =varajas  (PlG  >varajane !12_A
50492	puhkpilliorkestrile	orkestri	puhk+pilli+orkester	02_S	SgAll	et	puhkpilliorkestrile =orkestri  (SgAll  >puhk+pilli+orkester !02_S
50493	aastapäev	päev	aasta+päev	22_S	SgN	et	aastapäev =päev  (SgN  >aasta+päev !22_S
50500	soovitage	soovita	soovitama	27_V	ImpPrPl2	et	soovitage =soovita  (ImpPrPl2  >soovitama !27_V
50501	vanemand	and	vanem+and	22_S	SgN	et	vanemand =and  (SgN  >vanem+and !22_S
50503	rulluisutada	uisuta	rull+uisutama	27_V	Inf	et	rulluisutada =uisuta  (Inf  >rull+uisutama !27_V
50504	lihavõttepühadel	püha	liha+võtte+püha	17_SA	PlAd	et	lihavõttepühadel =püha  (PlAd  >liha+võtte+püha !17_SA
50509	krudiseb	krudise	krudisema	27_V	IndPrSg3	et	krudiseb =krudise  (IndPrSg3  >krudisema !27_V
50524	talvidel	talvi	talv	22_S	PlAd	et	talvidel =talvi  (PlAd  >talv !22_S
50526	suitsumehed	mehe	suitsu+mees	13_S	PlN	et	suitsumehed =mehe  (PlN  >suitsu+mees !13_S
50527	inglid	ingli	ingel	02_S	PlN	et	inglid =ingli  (PlN  >ingel !02_S
50528	raamatupoes	poe	raamatu+pood	22_S	SgIn	et	raamatupoes =poe  (SgIn  >raamatu+pood !22_S
50529	suveõhtud	õhtu	suve+õhtu	01_S	PlN	et	suveõhtud =õhtu  (PlN  >suve+õhtu !01_S
50531	transpordistruktuur	struktuur	transpordi+struktuur	22_S	SgN	et	transpordistruktuur =struktuur  (SgN  >transpordi+struktuur !22_S
50534	ujulad	ujula	ujula	01_S	PlN	et	ujulad =ujula  (PlN  >ujula !01_S
50544	ülistas	ülista	ülistama	27_V	IndIpfSg3	et	ülistas =ülista  (IndIpfSg3  >ülistama !27_V
50551	kardinit	kardini	kardin	02_S	SgP	et	kardinit =kardini  (SgP  >kardin !02_S
50555	fesenciek-jaamalt	jaama	fesenciek-jaam	22_S	SgAbl	et	fesenciek-jaamalt =jaama  (SgAbl  >fesenciek-jaam !22_S
50557	sael	sae	saag	22_S	SgAd	et	sael =sae  (SgAd  >saag !22_S
50561	modellina	modelli	modell	22_S	SgEs	et	modellina =modelli  (SgEs  >modell !22_S
50562	särgis	särgi	särk	22_S	SgIn	et	särgis =särgi  (SgIn  >särk !22_S
50569	kuritegijana	tegija	kuri+tegija	01_S	SgEs	et	kuritegijana =tegija  (SgEs  >kuri+tegija !01_S
50570	ohtliku	ohtliku	ohtlik	25_A	SgG	et	ohtliku =ohtliku  (SgG  >ohtlik !25_A
50576	metsloom	loom	mets+loom	22_S	SgN	et	metsloom =loom  (SgN  >mets+loom !22_S
50577	metsikuks	metsiku	metsik	02_AS	SgTr	et	metsikuks =metsiku  (SgTr  >metsik !02_AS
50584	tõnismäel	mäe	tõnis+mägi	21_S	SgAd	et	tõnismäel =mäe  (SgAd  >tõnis+mägi !21_S
50586	käivet	käive	käive	06_S	SgP	et	käivet =käive  (SgP  >käive !06_S
50587	sihtgrupi	grupi	siht+grupp	22_S	SgG	et	sihtgrupi =grupi  (SgG  >siht+grupp !22_S
50592	elage	ela	elama	27_V	ImpPrPl2	et	elage =ela  (ImpPrPl2  >elama !27_V
50595	külastaksite	külasta	külastama	27_V	KndPrPl2	et	külastaksite =külasta  (KndPrPl2  >külastama !27_V
50599	rütmide	rütmi	rütm	22_S	PlG	et	rütmide =rütmi  (PlG  >rütm !22_S
50616	välisreeded	reede	välis+reede	01_S	PlN	et	välisreeded =reede  (PlN  >välis+reede !01_S
50617	arvutilaua	laua	arvuti+laud	22_S	SgG	et	arvutilaua =laua  (SgG  >arvuti+laud !22_S
50620	telerilaual	laua	teleri+laud	22_S	SgAd	et	telerilaual =laua  (SgAd  >teleri+laud !22_S
50621	hali	hali	hali	24_S	SgN	et	hali =hali  (SgN  >hali !24_S
50627	riiulis	riiuli	riiul	02_S	SgIn	et	riiulis =riiuli  (SgIn  >riiul !02_S
50628	magustoidutaldrikud	taldriku	magus+toidu+taldrik	02_S	PlN	et	magustoidutaldrikud =taldriku  (PlN  >magus+toidu+taldrik !02_S
50630	supi-	supi	supp	22_S	SgG	et	supi- =supi  (SgG  >supp !22_S
50632	teelusikad	lusika	tee+lusikas	02_S	PlN	et	teelusikad =lusika  (PlN  >tee+lusikas !02_S
50633	taburete	taburete	taburet	22_S	PlP	et	taburete =taburete  (PlP  >taburet !22_S
50412	rock-festival	festival	rock-festival	19_S	SgN	et	rock-festival =festival  (SgN  >rock-festival !19_S
50422	poiste-	pois	poiss	23_S	PlG	et	poiste- =pois  (PlG  >poiss !23_S
50426	lõbutsema	lõbutse	lõbutsema	27_V	Sup	et	lõbutsema =lõbutse  (Sup  >lõbutsema !27_V
50429	kiirikus	kiiriku	kiirik	02_S	SgIn	et	kiirikus =kiiriku  (SgIn  >kiirik !02_S
50432	eestirahvuslik	rahvuslik	eesti+rahvuslik	25_A	SgN	et	eestirahvuslik =rahvuslik  (SgN  >eesti+rahvuslik !25_A
50434	regirahvalaulud	laulu	regi+rahva+laul	22_S	PlN	et	regirahvalaulud =laulu  (PlN  >regi+rahva+laul !22_S
50436	rõõmudega	rõõmu	rõõm	22_S	PlKom	et	rõõmudega =rõõmu  (PlKom  >rõõm !22_S
50440	väärtusega	väärtuse	väärtus	11~09_S	SgKom	et	väärtusega =väärtuse  (SgKom  >väärtus !11~09_S
50443	eestlased-jahimehed	mehe	eestlased-jahi+mees	13_S	PlN	et	eestlased-jahimehed =mehe  (PlN  >eestlased-jahi+mees !13_S
50446	sajanditena	sajandi	sajand	02_S	PlEs	et	sajanditena =sajandi  (PlEs  >sajand !02_S
50448	neiut	neiu	neiu	16_S	SgP	et	neiut =neiu  (SgP  >neiu !16_S
50456	muusikut	muusiku	muusik	02_S	SgP	et	muusikut =muusiku  (SgP  >muusik !02_S
50460	folk-ansamblid	ansambli	folk-ansambel	02_S	PlN	et	folk-ansamblid =ansambli  (PlN  >folk-ansambel !02_S
50467	igatseb	igatse	igatsema	27_V	IndPrSg3	et	igatseb =igatse  (IndPrSg3  >igatsema !27_V
50473	musikaal	kaal	musi+kaal	22_S	SgN	et	musikaal =kaal  (SgN  >musi+kaal !22_S
50474	kliimas	kliima	kliima	16_S	SgIn	et	kliimas =kliima  (SgIn  >kliima !16_S
50476	positiivseks	positiivse	positiivne	02_A	SgTr	et	positiivseks =positiivse  (SgTr  >positiivne !02_A
50478	lauluvaljale	valja	laulu+valjas	07_S	SgAll	et	lauluvaljale =valja  (SgAll  >laulu+valjas !07_S
50481	unustad	unusta	unustama	27_V	IndPrSg2	et	unustad =unusta  (IndPrSg2  >unustama !27_V
50482	folkloorifestivalid	festivali	folkloori+festival	19_S	PlN	et	folkloorifestivalid =festivali  (PlN  >folkloori+festival !19_S
50483	tekstisõnad	sõna	teksti+sõna	17_S	PlN	et	tekstisõnad =sõna  (PlN  >teksti+sõna !17_S
50484	häälte	hääl	hääl	13_S	PlG	et	häälte =hääl  (PlG  >hääl !13_S
50485	vanale	vana	vana	17_AS	SgAll	et	vanale =vana  (SgAll  >vana !17_AS
50489	vanaaegsest	aegse	vana+aegne	02_A	SgEl	et	vanaaegsest =aegse  (SgEl  >vana+aegne !02_A
50494	setumaalt	maa	setu+maa	26_S	SgAbl	et	setumaalt =maa  (SgAbl  >setu+maa !26_S
50505	piknikuid	pikniku	piknik	02_S	PlP	et	piknikuid =pikniku  (PlP  >piknik !02_S
50542	helged	helge	helge	01_A	PlN	et	helged =helge  (PlN  >helge !01_A
50543	külainimesed	inimese	küla+inimene	12_S	PlN	et	külainimesed =inimese  (PlN  >küla+inimene !12_S
50547	puumajas	maja	puu+maja	17_S	SgIn	et	puumajas =maja  (SgIn  >puu+maja !17_S
50553	paberilehed	lehe	paberi+leht	22_S	PlN	et	paberilehed =lehe  (PlN  >paberi+leht !22_S
50554	maks	maks	maks	22_S	SgN	et	maks =maks  (SgN  >maks !22_S
50556	pallimängud	mängu	palli+mäng	22_S	PlN	et	pallimängud =mängu  (PlN  >palli+mäng !22_S
50560	helepruun	pruun	hele+pruun	22_AS	SgN	et	helepruun =pruun  (SgN  >hele+pruun !22_AS
50575	hindadele	hinda	hind	22_S	PlAll	et	hindadele =hinda  (PlAll  >hind !22_S
50578	kare	kare	kare	02_A	SgN	et	kare =kare  (SgN  >kare !02_A
50579	kihve	kihve	kihv	22_S	PlP	et	kihve =kihve  (PlP  >kihv !22_S
50580	tubaka-	tubaka	tubakas	02_S	SgG	et	tubaka- =tubaka  (SgG  >tubakas !02_S
50583	poolaastas	aasta	pool+aasta	01_S	SgIn	et	poolaastas =aasta  (SgIn  >pool+aasta !01_S
50590	magame	maga	magama	27_V	IndPrPl1	et	magame =maga  (IndPrPl1  >magama !27_V
50593	sanatoorium	sanatoorium	sanatoorium	19~02_S	SgN	et	sanatoorium =sanatoorium  (SgN  >sanatoorium !19~02_S
50594	otsustame	otsusta	otsustama	27_V	IndPrPl1	et	otsustame =otsusta  (IndPrPl1  >otsustama !27_V
50596	mändjala	jala	mänd+jalg	22_S	SgG	et	mändjala =jala  (SgG  >mänd+jalg !22_S
50597	laadina-ameerika	ameerika	laadina-ameerika	41_G	ID	et	laadina-ameerika =ameerika  (ID  >laadina-ameerika !41_G
50598	tantsude	tantsu	tants	22_S	PlG	et	tantsude =tantsu  (PlG  >tants !22_S
50602	ühiskontsert	kontsert	ühis+kontsert	22_S	SgN	et	ühiskontsert =kontsert  (SgN  >ühis+kontsert !22_S
50608	kaitsealad	ala	kaitse+ala	17_S	PlN	et	kaitsealad =ala  (PlN  >kaitse+ala !17_S
50609	suurettevõtetele	võte	suur+ette+võte	06_S	PlAll	et	suurettevõtetele =võte  (PlAll  >suur+ette+võte !06_S
50619	aknalt	akna	aken	08_S	SgAbl	et	aknalt =akna  (SgAbl  >aken !08_S
50623	sahtlites	sahtli	sahtel	02_S	PlIn	et	sahtlites =sahtli  (PlIn  >sahtel !02_S
50640	lasterõivad	rõiva	laste+rõivas	07_S	PlN	et	lasterõivad =rõiva  (PlN  >laste+rõivas !07_S
50642	vatitekk	tekk	vati+tekk	22_S	SgN	et	vatitekk =tekk  (SgN  >vati+tekk !22_S
50647	supilusikad	lusika	supi+lusikas	02_S	PlN	et	supilusikad =lusika  (PlN  >supi+lusikas !02_S
50660	sissekäigu	käigu	sisse+käik	22_S	SgG	et	sissekäigu =käigu  (SgG  >sisse+käik !22_S
50666	linad	lina	lina	17_S	PlN	et	linad =lina  (PlN  >lina !17_S
50461	iseväljendusvahendina	vahendi	ise+väljendus+vahend	02_S	SgEs	et	iseväljendusvahendina =vahendi  (SgEs  >ise+väljendus+vahend !02_S
50470	väärismõõdult	mõõdu	vääris+mõõt	22_S	SgAbl	et	väärismõõdult =mõõdu  (SgAbl  >vääris+mõõt !22_S
50480	torupillide	pilli	toru+pill	22_S	PlG	et	torupillide =pilli  (PlG  >toru+pill !22_S
50496	homset	homse	homne	02_A	SgP	et	homset =homse  (SgP  >homne !02_A
50502	aastaring	ring	aasta+ring	22_S	SgN	et	aastaring =ring  (SgN  >aasta+ring !22_S
50507	värvib	värvi	värvima	28_V	IndPrSg3	et	värvib =värvi  (IndPrSg3  >värvima !28_V
50508	pidutsen	pidutse	pidutsema	27_V	IndPrSg1	et	pidutsen =pidutse  (IndPrSg1  >pidutsema !27_V
50510	lepatriinude	triinu	lepa+triinu	16_S	PlG	et	lepatriinude =triinu  (PlG  >lepa+triinu !16_S
50511	neljapäevani	päeva	nelja+päev	22_S	SgTer	et	neljapäevani =päeva  (SgTer  >nelja+päev !22_S
50512	ülikoolinädal	nädal	üli+kooli+nädal	02_S	SgN	et	ülikoolinädal =nädal  (SgN  >üli+kooli+nädal !02_S
50517	ööbisin	ööbi	ööbima	27_V	IndIpfSg1	et	ööbisin =ööbi  (IndIpfSg1  >ööbima !27_V
50521	mäestik	mäestik	mäestik	25_S	SgN	et	mäestik =mäestik  (SgN  >mäestik !25_S
50523	mäesuusatamist	suusatamis	mäe+suusatamine	12_S	SgP	et	mäesuusatamist =suusatamis  (SgP  >mäe+suusatamine !12_S
50525	järvedes	järve	järv	22_S	PlIn	et	järvedes =järve  (PlIn  >järv !22_S
50530	linnana	linna	linn	22_S	SgEs	et	linnana =linna  (SgEs  >linn !22_S
50535	restoranid	restorani	restoran	19_S	PlN	et	restoranid =restorani  (PlN  >restoran !19_S
50536	tähendaks	tähenda	tähendama	27_V	KndPrPs	et	tähendaks =tähenda  (KndPrPs  >tähendama !27_V
50540	valet	vale	vale	16_SA	SgP	et	valet =vale  (SgP  >vale !16_SA
50546	ükses	ükse	üks	22_NP	PlIn	et	ükses =ükse  (PlIn  >üks !22_NP
50548	arvutiinsener	insener	arvuti+insener	19_S	SgN	et	arvutiinsener =insener  (SgN  >arvuti+insener !19_S
50549	perekonne	konne	pere+konn	22_S	PlP	et	perekonne =konne  (PlP  >pere+konn !22_S
50558	tobe	tobe	tobe	02_A	SgN	et	tobe =tobe  (SgN  >tobe !02_A
50564	küsitatakse	küsita	küsitama	27_V	IndPrIps	et	küsitatakse =küsita  (IndPrIps  >küsitama !27_V
50565	vaheajad	aja	vahe+aeg	22_S	PlN	et	vaheajad =aja  (PlN  >vahe+aeg !22_S
50566	õppetati	tati	õppe+tatt	22_S	SgG	et	õppetati =tati  (SgG  >õppe+tatt !22_S
50568	heategijana	tegija	hea+tegija	01_S	SgEs	et	heategijana =tegija  (SgEs  >hea+tegija !01_S
50582	pikendada	pikenda	pikendama	27_V	Inf	et	pikendada =pikenda  (Inf  >pikendama !27_V
50591	suitsetame	suitseta	suitsetama	27_V	IndPrPl1	et	suitsetame =suitseta  (IndPrPl1  >suitsetama !27_V
50606	merepäevadel	päeva	mere+päev	22_S	PlAd	et	merepäevadel =päeva  (PlAd  >mere+päev !22_S
50607	aktsiooniga	aktsiooni	aktsioon	22_S	SgKom	et	aktsiooniga =aktsiooni  (SgKom  >aktsioon !22_S
50614	üürikorteris	korteri	üüri+korter	02_S	SgIn	et	üürikorteris =korteri  (SgIn  >üüri+korter !02_S
50618	külgkardin	kardin	külg+kardin	02_S	SgN	et	külgkardin =kardin  (SgN  >külg+kardin !02_S
50624	padjapüür	püür	padja+püür	22_S	SgN	et	padjapüür =püür  (SgN  >padja+püür !22_S
50625	sügavkülmik	külmik	sügav+külmik	02_S	SgN	et	sügavkülmik =külmik  (SgN  >sügav+külmik !02_S
50629	praetaldrikud	taldriku	prae+taldrik	02_S	PlN	et	praetaldrikud =taldriku  (PlN  >prae+taldrik !02_S
50638	saunalinad	lina	sauna+lina	17_S	PlN	et	saunalinad =lina  (PlN  >sauna+lina !17_S
50644	salatikausid	kausi	salati+kauss	22_S	PlN	et	salatikausid =kausi  (PlN  >salati+kauss !22_S
50646	lauanõud	nõu	laua+nõu	26_S	PlN	et	lauanõud =nõu  (PlN  >laua+nõu !26_S
50649	taburetiga	tabureti	taburet	22_S	SgKom	et	taburetiga =tabureti  (SgKom  >taburet !22_S
50652	ühispank	pank	ühis+pank	22_S	SgN	et	ühispank =pank  (SgN  >ühis+pank !22_S
50658	õpingute	õpingu	õping	02_S	PlG	et	õpingute =õpingu  (PlG  >õping !02_S
50671	tekk	tekk	tekk	22_S	SgN	et	tekk =tekk  (SgN  >tekk !22_S
50679	korterivõtmed	võtme	korteri+võti	05_S	PlN	et	korterivõtmed =võtme  (PlN  >korteri+võti !05_S
50683	kuivatan	kuivata	kuivatama	27_V	IndPrSg1	et	kuivatan =kuivata  (IndPrSg1  >kuivatama !27_V
50714	muusikariiulil	riiuli	muusika+riiul	02_S	SgAd	et	muusikariiulil =riiuli  (SgAd  >muusika+riiul !02_S
50715	kummutit	kummuti	kummut	02_S	SgP	et	kummutit =kummuti  (SgP  >kummut !02_S
50719	nõudekapis	kapi	nõude+kapp	22_S	SgIn	et	nõudekapis =kapi  (SgIn  >nõude+kapp !22_S
50723	tööstuskauplus	kauplus	tööstus+kauplus	11~09_S	SgN	et	tööstuskauplus =kauplus  (SgN  >tööstus+kauplus !11~09_S
50724	kontor	kontor	kontor	02_S	SgN	et	kontor =kontor  (SgN  >kontor !02_S
50727	fotoalbumid	albumi	foto+album	02_S	PlN	et	fotoalbumid =albumi  (PlN  >foto+album !02_S
50735	õle	õle	õlg	22_S	SgG	et	õle =õle  (SgG  >õlg !22_S
50736	kohvipress	press	kohvi+press	22_S	SgN	et	kohvipress =press  (SgN  >kohvi+press !22_S
50743	ühisrõdul	rõdu	ühis+rõdu	17_S	SgAd	et	ühisrõdul =rõdu  (SgAd  >ühis+rõdu !17_S
50601	rongkäik	käik	rong+käik	22_S	SgN	et	rongkäik =käik  (SgN  >rong+käik !22_S
50611	kastid	kasti	kast	22_S	PlN	et	kastid =kasti  (PlN  >kast !22_S
50612	plastikule	plastiku	plastik	02_S	SgAll	et	plastikule =plastiku  (SgAll  >plastik !02_S
50613	puhastakse	takse	puhas+taks	22_S	PlP	et	puhastakse =takse  (PlP  >puhas+taks !22_S
50615	eraldid	eraldi	eraldi	01_S	PlN	et	eraldid =eraldi  (PlN  >eraldi !01_S
50626	sügavkülmiku	külmiku	sügav+külmik	02_S	SgG	et	sügavkülmiku =külmiku  (SgG  >sügav+külmik !02_S
50651	liumäed	mäe	liu+mägi	21_S	PlN	et	liumäed =mäe  (PlN  >liu+mägi !21_S
50653	köögilaual	laua	köögi+laud	22_S	SgAd	et	köögilaual =laua  (SgAd  >köögi+laud !22_S
50654	taburet	taburet	taburet	22_S	SgN	et	taburet =taburet  (SgN  >taburet !22_S
50664	tekikotid	koti	teki+kott	22_S	PlN	et	tekikotid =koti  (PlN  >teki+kott !22_S
50665	padjapüürid	püüri	padja+püür	22_S	PlN	et	padjapüürid =püüri  (PlN  >padja+püür !22_S
50672	sojapuhur	puhur	soja+puhur	02_S	SgN	et	sojapuhur =puhur  (SgN  >soja+puhur !02_S
50673	sahveris	sahveri	sahver	02_S	SgIn	et	sahveris =sahveri  (SgIn  >sahver !02_S
50674	tühje	tühje	tühi	24_A	PlP	et	tühje =tühje  (PlP  >tühi !24_A
50676	suhkruga	suhkru	suhkur	02_S	SgKom	et	suhkruga =suhkru  (SgKom  >suhkur !02_S
50681	tööstusinstrumendid	instrumendi	tööstus+instrument	22_S	PlN	et	tööstusinstrumendid =instrumendi  (PlN  >tööstus+instrument !22_S
50684	viinerid	viineri	viiner	02_S	PlN	et	viinerid =viineri  (PlN  >viiner !02_S
50687	kurgid	kurgi	kurk	22_S	PlN	et	kurgid =kurgi  (PlN  >kurk !22_S
50689	küpsetusmasin	masin	küpsetus+masin	02_S	SgN	et	küpsetusmasin =masin  (SgN  >küpsetus+masin !02_S
50696	köögiseinakapp	kapp	köögi+seina+kapp	22_S	SgN	et	köögiseinakapp =kapp  (SgN  >köögi+seina+kapp !22_S
50699	alustassid	tassi	alus+tass	22_S	PlN	et	alustassid =tassi  (PlN  >alus+tass !22_S
50705	küüslaugupipar	pipar	küüs+laugu+pipar	08_S	SgN	et	küüslaugupipar =pipar  (SgN  >küüs+laugu+pipar !08_S
50706	suhkru	suhkru	suhkur	02_S	SgG	et	suhkru =suhkru  (SgG  >suhkur !02_S
50713	aparatuur	aparatuur	aparatuur	22_S	SgN	et	aparatuur =aparatuur  (SgN  >aparatuur !22_S
50716	gaasimõõtur	mõõtur	gaasi+mõõtur	02_S	SgN	et	gaasimõõtur =mõõtur  (SgN  >gaasi+mõõtur !02_S
50726	telleri	telleri	teller	02_S	SgG	et	telleri =telleri  (SgG  >teller !02_S
50729	kummutite	kummuti	kummut	02_S	PlG	et	kummutite =kummuti  (PlG  >kummut !02_S
50730	külmkapist	kapi	külm+kapp	22_S	SgEl	et	külmkapist =kapi  (SgEl  >külm+kapp !22_S
50740	sendi	sendi	sent	22_S	SgG	et	sendi =sendi  (SgG  >sent !22_S
50746	telefonikataloog	kataloog	telefoni+kataloog	22_S	SgN	et	telefonikataloog =kataloog  (SgN  >telefoni+kataloog !22_S
50747	sarved	sarve	sarv	22_S	PlN	et	sarved =sarve  (PlN  >sarv !22_S
50748	majonees	majonees	majonees	22_S	SgN	et	majonees =majonees  (SgN  >majonees !22_S
50751	sööginõud	nõu	söögi+nõu	26_S	PlN	et	sööginõud =nõu  (PlN  >söögi+nõu !26_S
50762	gaasimõõturid	mõõturi	gaasi+mõõtur	02_S	PlN	et	gaasimõõturid =mõõturi  (PlN  >gaasi+mõõtur !02_S
50767	tull	tull	tull	22_S	SgN	et	tull =tull  (SgN  >tull !22_S
50773	pimm	pimm	pimm	41_I	ID	et	pimm =pimm  (ID  >pimm !41_I
50776	kanas	kana	kana	17_S	SgIn	et	kanas =kana  (SgIn  >kana !17_S
50777	porgand	porgand	porgand	02_S	SgN	et	porgand =porgand  (SgN  >porgand !02_S
50778	magustoidu-	toidu	magus+toit	22_S	SgG	et	magustoidu- =toidu  (SgG  >magus+toit !22_S
50780	dessert-	dessert	dessert	22_S	SgN	et	dessert- =dessert  (SgN  >dessert !22_S
50784	turismimajandust	majandus	turismi+majandus	11_S	SgP	et	turismimajandust =majandus  (SgP  >turismi+majandus !11_S
50793	toosel	toose	toos	22_S	PlAd	et	toosel =toose  (PlAd  >toos !22_S
50800	sõjaväelase	väelase	sõja+väelane	12?10_S	SgG	et	sõjaväelase =väelase  (SgG  >sõja+väelane !12?10_S
50806	kordsel	kordse	kordne	02_AS	SgAd	et	kordsel =kordse  (SgAd  >kordne !02_AS
50808	eestikeeletase	tase	eesti+keele+tase	04_S	SgN	et	eestikeeletase =tase  (SgN  >eesti+keele+tase !04_S
50822	nooredes	ede	noor+ede	16_S	SgIn	et	nooredes =ede  (SgIn  >noor+ede !16_S
50845	sõjaväesse	väe	sõja+vägi	21_S	SgIll	et	sõjaväesse =väe  (SgIll  >sõja+vägi !21_S
50846	mänguasju	asju	mängu+asi	24_S	PlP	et	mänguasju =asju  (PlP  >mängu+asi !24_S
50849	hõivab	hõiva	hõivama	29_V	IndPrSg3	et	hõivab =hõiva  (IndPrSg3  >hõivama !29_V
50854	minuks	minu	mina	00_P	SgTr	et	minuks =minu  (SgTr  >mina !00_P
50855	paistma	paist	paistma	34_V	Sup	et	paistma =paist  (Sup  >paistma !34_V
50859	vabariigid	riigi	vaba+riik	22_S	PlN	et	vabariigid =riigi  (PlN  >vaba+riik !22_S
50860	maksasid	maksa	maks	22_S	PlP	et	maksasid =maksa  (PlP  >maks !22_S
50861	läheneb	lähene	lähenema	27_V	IndPrSg3	et	läheneb =lähene  (IndPrSg3  >lähenema !27_V
50862	nukrutseda	nukrutse	nukrutsema	27_V	Inf	et	nukrutseda =nukrutse  (Inf  >nukrutsema !27_V
50635	väiksevõtu	võtu	väikse+võtt	22_S	SgG	et	väiksevõtu =võtu  (SgG  >väikse+võtt !22_S
50636	seinajuures	juure	seina+juur	13_S	SgIn	et	seinajuures =juure  (SgIn  >seina+juur !13_S
50637	joped	jope	jope	16_S	PlN	et	joped =jope  (PlN  >jope !16_S
50643	keediseid	keedise	keedis	09_S	PlP	et	keediseid =keedise  (PlP  >keedis !09_S
50645	ümmarguse	ümmarguse	ümmargune	12_A	SgG	et	ümmarguse =ümmarguse  (SgG  >ümmargune !12_A
50648	vahukulp	kulp	vahu+kulp	22_S	SgN	et	vahukulp =kulp  (SgN  >vahu+kulp !22_S
50650	köögiseinad	seina	köögi+sein	23?22_S	PlN	et	köögiseinad =seina  (PlN  >köögi+sein !23?22_S
50655	laulamp	lamp	lau+lamp	22_SA	SgN	et	laulamp =lamp  (SgN  >lau+lamp !22_SA
50656	kaugekõnesid	kõne	kauge+kõne	16_S	PlP	et	kaugekõnesid =kõne  (PlP  >kauge+kõne !16_S
50657	pesupulbri	pulbri	pesu+pulber	02_S	SgG	et	pesupulbri =pulbri  (SgG  >pesu+pulber !02_S
50661	autoregistri	registri	auto+register	02_S	SgG	et	autoregistri =registri  (SgG  >auto+register !02_S
50667	köögikäterätikud	rätiku	köögi+käte+rätik	02_S	PlN	et	köögikäterätikud =rätiku  (PlN  >köögi+käte+rätik !02_S
50668	aknale	akna	aken	08_S	SgAll	et	aknale =akna  (SgAll  >aken !08_S
50669	lauariiulis	riiuli	laua+riiul	02_S	SgIn	et	lauariiulis =riiuli  (SgIn  >laua+riiul !02_S
50677	kartuliroogade	rooga	kartuli+roog	22_S	PlG	et	kartuliroogade =rooga  (PlG  >kartuli+roog !22_S
50680	mõõtur	mõõtur	mõõtur	02_S	SgN	et	mõõtur =mõõtur  (SgN  >mõõtur !02_S
50688	kööginurgadiivan	diivan	köögi+nurga+diivan	02_S	SgN	et	kööginurgadiivan =diivan  (SgN  >köögi+nurga+diivan !02_S
50690	prügiämbri	ämbri	prügi+ämber	02_S	SgG	et	prügiämbri =ämbri  (SgG  >prügi+ämber !02_S
50691	supiga	supi	supp	22_S	SgKom	et	supiga =supi  (SgKom  >supp !22_S
50692	praega	prae	praad	22_S	SgKom	et	praega =prae  (SgKom  >praad !22_S
50698	taldrikut	taldriku	taldrik	02_S	SgP	et	taldrikut =taldriku  (SgP  >taldrik !02_S
50703	pajalapid	lapi	paja+lapp	22_S	PlN	et	pajalapid =lapi  (PlN  >paja+lapp !22_S
50704	kuivpärm	pärm	kuiv+pärm	22_S	SgN	et	kuivpärm =pärm  (SgN  >kuiv+pärm !22_S
50707	köögipõrandat	põranda	köögi+põrand	02_S	SgP	et	köögipõrandat =põranda  (SgP  >köögi+põrand !02_S
50709	seinadel	seina	sein	22_S	PlAd	et	seinadel =seina  (PlAd  >sein !22_S
50710	riidekapi	kapi	riide+kapp	22_S	SgG	et	riidekapi =kapi  (SgG  >riide+kapp !22_S
50711	linoleum	linoleum	linoleum	22_S	SgN	et	linoleum =linoleum  (SgN  >linoleum !22_S
50720	supitaldrikud	taldriku	supi+taldrik	02_S	PlN	et	supitaldrikud =taldriku  (PlN  >supi+taldrik !02_S
50722	köögilaua	laua	köögi+laud	22_S	SgG	et	köögilaua =laua  (SgG  >köögi+laud !22_S
50733	sahtli	sahtli	sahtel	02_S	SgG	et	sahtli =sahtli  (SgG  >sahtel !02_S
50742	lasteautod	auto	laste+auto	16_S	PlN	et	lasteautod =auto  (PlN  >laste+auto !16_S
50752	kruupidega	kruupi	kruup	22_S	PlKom	et	kruupidega =kruupi  (PlKom  >kruup !22_S
50756	sahtelis	sahteli	sahtel	02_S	SgIn	et	sahtelis =sahteli  (SgIn  >sahtel !02_S
50759	käterätiku	rätiku	käte+rätik	02_S	SgG	et	käterätiku =rätiku  (SgG  >käte+rätik !02_S
50760	hambapastad	pasta	hamba+pasta	16_S	PlN	et	hambapastad =pasta  (PlN  >hamba+pasta !16_S
50761	veemõõturid	mõõturi	vee+mõõtur	02_S	PlN	et	veemõõturid =mõõturi  (PlN  >vee+mõõtur !02_S
50763	elektrimõõturid	mõõturi	elektri+mõõtur	02_S	PlN	et	elektrimõõturid =mõõturi  (PlN  >elektri+mõõtur !02_S
50765	maakri	maakri	maaker	02_S	SgG	et	maakri =maakri  (SgG  >maaker !02_S
50766	hell	hell	hell	22_A	SgN	et	hell =hell  (SgN  >hell !22_A
50770	tüll	tüll	tüll	22_S	SgN	et	tüll =tüll  (SgN  >tüll !22_S
50772	külmik	külmik	külmik	02_S	SgN	et	külmik =külmik  (SgN  >külmik !02_S
50781	kasiinos	kasiino	kasiino	16_S	SgIn	et	kasiinos =kasiino  (SgIn  >kasiino !16_S
50782	meeldub	meeldu	meelduma	27_V	IndPrSg3	et	meeldub =meeldu  (IndPrSg3  >meelduma !27_V
50789	elukogemus	kogemus	elu+kogemus	11_S	SgN	et	elukogemus =kogemus  (SgN  >elu+kogemus !11_S
50792	pärist	päri	pärg	22_S	PlEl	et	pärist =päri  (PlEl  >pärg !22_S
50794	ülikolisse	koli	üli+koli	17_S	SgIll	et	ülikolisse =koli  (SgIll  >üli+koli !17_S
50802	igavat	igava	igav	02_A	SgP	et	igavat =igava  (SgP  >igav !02_A
50807	tudengile	tudengi	tudeng	02_S	SgAll	et	tudengile =tudengi  (SgAll  >tudeng !02_S
50814	reaalgümnaasium	gümnaasium	reaal+gümnaasium	19~02_S	SgN	et	reaalgümnaasium =gümnaasium  (SgN  >reaal+gümnaasium !19~02_S
50815	elektroonikaga	elektroonika	elektroonika	01_S	SgKom	et	elektroonikaga =elektroonika  (SgKom  >elektroonika !01_S
50820	murdatud	atu	murd+att	22_S	PlN	et	murdatud =atu  (PlN  >murd+att !22_S
50823	erinedes	erine	erinema	27_V	Ger	et	erinedes =erine  (Ger  >erinema !27_V
50832	näideks	näide	näit	22_S	PlTr	et	näideks =näide  (PlTr  >näit !22_S
50834	pimedaks	pimeda	pime	02_AS	SgTr	et	pimedaks =pimeda  (SgTr  >pime !02_AS
50663	eluaken	aken	elu+aken	08_S	SgN	et	eluaken =aken  (SgN  >elu+aken !08_S
50670	nurgadiivanis	diivani	nurga+diivan	02_S	SgIn	et	nurgadiivanis =diivani  (SgIn  >nurga+diivan !02_S
50675	purke	purke	purk	22_S	PlP	et	purke =purke  (PlP  >purk !22_S
50678	toidupaketid	paketi	toidu+pakett	22_S	PlN	et	toidupaketid =paketi  (PlN  >toidu+pakett !22_S
50682	lokitang	tang	loki+tang	22_S	SgN	et	lokitang =tang  (SgN  >loki+tang !22_S
50694	vaagnad	vaagna	vaagen	02_S	PlN	et	vaagnad =vaagna  (PlN  >vaagen !02_S
50695	kandikud	kandiku	kandik	02_S	PlN	et	kandikud =kandiku  (PlN  >kandik !02_S
50697	supi	supi	supp	22_S	SgG	et	supi =supi  (SgG  >supp !22_S
50700	koorekann	kann	koore+kann	22_S	SgN	et	koorekann =kann  (SgN  >koore+kann !22_S
50701	köögiseinakapi	kapi	köögi+seina+kapp	22_S	SgG	et	köögiseinakapi =kapi  (SgG  >köögi+seina+kapp !22_S
50708	lasteajad	aja	laste+aeg	22_S	PlN	et	lasteajad =aja  (PlN  >laste+aeg !22_S
50717	söögikapid	kapi	söögi+kapp	22_S	PlN	et	söögikapid =kapi  (PlN  >söögi+kapp !22_S
50718	nõudekapp	kapp	nõude+kapp	22_S	SgN	et	nõudekapp =kapp  (SgN  >nõude+kapp !22_S
50728	riidekapist	kapi	riide+kapp	22_S	SgEl	et	riidekapist =kapi  (SgEl  >riide+kapp !22_S
50739	liumäe	mäe	liu+mägi	21_S	SgG	et	liumäe =mäe  (SgG  >liu+mägi !21_S
50749	kahvelid	kahveli	kahvel	02_S	PlN	et	kahvelid =kahveli  (PlN  >kahvel !02_S
50753	köögipisiasjasid	asja	köögi+pisi+asi	24_S	PlP	et	köögipisiasjasid =asja  (PlP  >köögi+pisi+asi !24_S
50758	seisukapi	kapi	seisu+kapp	22_S	SgG	et	seisukapi =kapi  (SgG  >seisu+kapp !22_S
50785	lütseum	lütseum	lütseum	19~02_S	SgN	et	lütseum =lütseum  (SgN  >lütseum !19~02_S
50786	pareneda	parene	parenema	27_V	Inf	et	pareneda =parene  (Inf  >parenema !27_V
50790	hobide	hobi	hobi	17_S	PlG	et	hobide =hobi  (PlG  >hobi !17_S
50799	auditooriumites	auditooriumi	auditoorium	02_S	PlIn	et	auditooriumites =auditooriumi  (PlIn  >auditoorium !02_S
50801	märkan	märka	märkama	29_V	IndPrSg1	et	märkan =märka  (IndPrSg1  >märkama !29_V
50803	muljast	mulja	muljas	02_A	SgEl	et	muljast =mulja  (SgEl  >muljas !02_A
50809	lennukitega	lennuki	lennuk	02_S	PlKom	et	lennukitega =lennuki  (PlKom  >lennuk !02_S
50811	pingereas	rea	pinge+rida	18_S	SgIn	et	pingereas =rea  (SgIn  >pinge+rida !18_S
50813	praktikuta	praktiku	praktik	02_S	SgAb	et	praktikuta =praktiku  (SgAb  >praktik !02_S
50821	planeeris	planeeri	planeerima	28_V	IndIpfSg3	et	planeeris =planeeri  (IndIpfSg3  >planeerima !28_V
50825	murduda	murdu	murduma	27_V	Inf	et	murduda =murdu  (Inf  >murduma !27_V
50826	inglismaales	maale	inglis+maal	22_S	PlIn	et	inglismaales =maale  (PlIn  >inglis+maal !22_S
50833	lumekanged	kange	lume+kange	01_A	PlN	et	lumekanged =kange  (PlN  >lume+kange !01_A
50843	viisidele	viisi	viis	22_S	PlAll	et	viisidele =viisi  (PlAll  >viis !22_S
50848	immatrikuleerida	immatrikuleeri	immatrikuleerima	28_V	Inf	et	immatrikuleerida =immatrikuleeri  (Inf  >immatrikuleerima !28_V
50853	ootaksin	oota	ootama	29_V	KndPrSg1	et	ootaksin =oota  (KndPrSg1  >ootama !29_V
50857	teenite	teeni	teenima	28_V	IndPrPl2	et	teenite =teeni  (IndPrPl2  >teenima !28_V
50858	tulena	tule	tuli	20_S	SgEs	et	tulena =tule  (SgEs  >tuli !20_S
50865	õppeainetega	aine	õppe+aine	06_S	PlKom	et	õppeainetega =aine  (PlKom  >õppe+aine !06_S
50867	sukelduda	sukeldu	sukelduma	27_V	Inf	et	sukelduda =sukeldu  (Inf  >sukelduma !27_V
50877	uueneti	uuene	uuenema	27_V	IndIpfIps	et	uueneti =uuene  (IndIpfIps  >uuenema !27_V
50878	püües	püüe	püüd	22_S	PlIn	et	püües =püüe  (PlIn  >püüd !22_S
50879	reformide	reformi	reform	22_S	PlG	et	reformide =reformi  (PlG  >reform !22_S
50887	delegatsioon	delegatsioon	delegatsioon	22_S	SgN	et	delegatsioon =delegatsioon  (SgN  >delegatsioon !22_S
50904	lubage	luba	lubama	27_V	ImpPrPl2	et	lubage =luba  (ImpPrPl2  >lubama !27_V
50905	ebareaalne	reaalne	eba+reaalne	02_A	SgN	et	ebareaalne =reaalne  (SgN  >eba+reaalne !02_A
50923	töökonkursil	konkursi	töö+konkurss	22_S	SgAd	et	töökonkursil =konkursi  (SgAd  >töö+konkurss !22_S
50925	õpite	õpi	õppima	28_V	IndPrPl2	et	õpite =õpi  (IndPrPl2  >õppima !28_V
50928	nahajopis	jopi	naha+jopp	22_S	SgIn	et	nahajopis =jopi  (SgIn  >naha+jopp !22_S
50930	püksides	püksi	püks	22_S	PlIn	et	püksides =püksi  (PlIn  >püks !22_S
50932	süsivesikud	vesiku	süsi+vesik	02_S	PlN	et	süsivesikud =vesiku  (PlN  >süsi+vesik !02_S
50938	krabas	kraba	krabama	27_V	IndIpfSg3	et	krabas =kraba  (IndIpfSg3  >krabama !27_V
50939	pikali	pikali	pikali	41_D	ID	et	pikali =pikali  (ID  >pikali !41_D
50941	elektrilöögi	löögi	elektri+löök	22_S	SgG	et	elektrilöögi =löögi  (SgG  >elektri+löök !22_S
50942	ekt-asse	asse	ekt-ass	22_S	PlP	et	ekt-asse =asse  (PlP  >ekt-ass !22_S
50947	käivituks	käivitu	käivituma	27_V	KndPrPs	et	käivituks =käivitu  (KndPrPs  >käivituma !27_V
50948	lisaseadmete	seadme	lisa+seade	05_S	PlG	et	lisaseadmete =seadme  (PlG  >lisa+seade !05_S
50685	apelsinid	apelsini	apelsin	19_S	PlN	et	apelsinid =apelsini  (PlN  >apelsin !19_S
50686	porgandid	porgandi	porgand	02_S	PlN	et	porgandid =porgandi  (PlN  >porgand !02_S
50693	praeahi	ahi	prae+ahi	24_S	SgN	et	praeahi =ahi  (SgN  >prae+ahi !24_S
50702	supitirin	tirin	supi+tirin	02_S	SgN	et	supitirin =tirin  (SgN  >supi+tirin !02_S
50712	rullikardin	kardin	rulli+kardin	02_S	SgN	et	rullikardin =kardin  (SgN  >rulli+kardin !02_S
50721	kombain	kombain	kombain	22_S	SgN	et	kombain =kombain  (SgN  >kombain !22_S
50725	läbikäidavad	käidava	läbi+käidav	02_A	PlN	et	läbikäidavad =käidava  (PlN  >läbi+käidav !02_A
50731	gaasipliidis	pliidi	gaasi+pliit	22_S	SgIn	et	gaasipliidis =pliidi  (SgIn  >gaasi+pliit !22_S
50732	ravimtaimed	taime	ravim+taim	22_S	PlN	et	ravimtaimed =taime  (PlN  >ravim+taim !22_S
50734	niitnuudlid	nuudli	niit+nuudel	02_S	PlN	et	niitnuudlid =nuudli  (PlN  >niit+nuudel !02_S
50737	tööstuslinn	linn	tööstus+linn	22_S	SgN	et	tööstuslinn =linn  (SgN  >tööstus+linn !22_S
50738	maanteel	tee	maan+tee	26_S	SgAd	et	maanteel =tee  (SgAd  >maan+tee !26_S
50741	lastenurga	nurga	laste+nurk	22_S	SgG	et	lastenurga =nurga  (SgG  >laste+nurk !22_S
50754	seisukapp	kapp	seisu+kapp	22_S	SgN	et	seisukapp =kapp  (SgN  >seisu+kapp !22_S
50755	seisukapis	kapi	seisu+kapp	22_S	SgIn	et	seisukapis =kapi  (SgIn  >seisu+kapp !22_S
50764	mõõturite	mõõturi	mõõtur	02_S	PlG	et	mõõturite =mõõturi  (PlG  >mõõtur !02_S
50768	riidekapiga	kapi	riide+kapp	22_S	SgKom	et	riidekapiga =kapi  (SgKom  >riide+kapp !22_S
50774	sügavkülmikus	külmiku	sügav+külmik	02_S	SgIn	et	sügavkülmikus =külmiku  (SgIn  >sügav+külmik !02_S
50779	vaagen	vaagen	vaagen	02_S	SgN	et	vaagen =vaagen  (SgN  >vaagen !02_S
50783	tasemal	tasema	tasem	02_A	SgAd	et	tasemal =tasema  (SgAd  >tasem !02_A
50788	muljetest	mulje	mulje	06_S	PlEl	et	muljetest =mulje  (PlEl  >mulje !06_S
50791	neljadele	nelja	neli	24_N	PlAll	et	neljadele =nelja  (PlAll  >neli !24_N
50795	kadrid	kadri	kadri	16_S	PlN	et	kadrid =kadri  (PlN  >kadri !16_S
50797	õppekollektiiv	kollektiiv	õppe+kollektiiv	22_S	SgN	et	õppekollektiiv =kollektiiv  (SgN  >õppe+kollektiiv !22_S
50798	rägina	rägina	rägin	02_S	SgG	et	rägina =rägina  (SgG  >rägin !02_S
50804	ruumile	ruumi	ruum	22_S	SgAll	et	ruumile =ruumi  (SgAll  >ruum !22_S
50805	muljad	mulja	muljas	02_A	PlN	et	muljad =mulja  (PlN  >muljas !02_A
50816	tagasin	taga	tagama	27_V	IndIpfSg1	et	tagasin =taga  (IndIpfSg1  >tagama !27_V
50824	nordest	norde	nord	22_S	PlEl	et	nordest =norde  (PlEl  >nord !22_S
50827	tagasihoidiku	hoidiku	tagasi+hoidik	02_S	SgG	et	tagasihoidiku =hoidiku  (SgG  >tagasi+hoidik !02_S
50828	valitsen	valitse	valitsema	27_V	IndPrSg1	et	valitsen =valitse  (IndPrSg1  >valitsema !27_V
50829	eksmatrikuleerida	eksmatrikuleeri	eksmatrikuleerima	28_V	Inf	et	eksmatrikuleerida =eksmatrikuleeri  (Inf  >eksmatrikuleerima !28_V
50831	uusaastasoovid	soovi	uus+aasta+soov	22_S	PlN	et	uusaastasoovid =soovi  (PlN  >uus+aasta+soov !22_S
50835	targuks	targu	tark	22_AS	PlTr	et	targuks =targu  (PlTr  >tark !22_AS
50836	maaimas	ima	maa+ima	17_S	SgIn	et	maaimas =ima  (SgIn  >maa+ima !17_S
50838	seitsmelt	seitsme	seitse	05_N	SgAbl	et	seitsmelt =seitsme  (SgAbl  >seitse !05_N
50839	kodulinnaks	linna	kodu+linn	22_S	SgTr	et	kodulinnaks =linna  (SgTr  >kodu+linn !22_S
50851	piduks	pidu	pidu	17_S	SgTr	et	piduks =pidu  (SgTr  >pidu !17_S
50852	eksamisessioon	sessioon	eksami+sessioon	22_S	SgN	et	eksamisessioon =sessioon  (SgN  >eksami+sessioon !22_S
50863	aegapidi	pidi	aega+pidi	41_D	ID	et	aegapidi =pidi  (ID  >aega+pidi !41_D
50864	eksamisessioonist	sessiooni	eksami+sessioon	22_S	SgEl	et	eksamisessioonist =sessiooni  (SgEl  >eksami+sessioon !22_S
50868	täitub	täitu	täituma	27_V	IndPrSg3	et	täitub =täitu  (IndPrSg3  >täituma !27_V
50883	infoedastamise	edastamise	info+edastamine	12_S	SgG	et	infoedastamise =edastamise  (SgG  >info+edastamine !12_S
50885	kiirustas	kiirusta	kiirustama	27_V	IndIpfSg3	et	kiirustas =kiirusta  (IndIpfSg3  >kiirustama !27_V
50889	kultuurilooinimesed	inimese	kultuuri+loo+inimene	12_S	PlN	et	kultuurilooinimesed =inimese  (PlN  >kultuuri+loo+inimene !12_S
50890	käigud	käigu	käik	22_S	PlN	et	käigud =käigu  (PlN  >käik !22_S
50898	arvumust	must	arvu+must	22_AS	SgN	et	arvumust =must  (SgN  >arvu+must !22_AS
50909	erakorras	korra	era+kord	22_S	SgIn	et	erakorras =korra  (SgIn  >era+kord !22_S
50920	kandsin	kand	kandma	34_V	IndIpfSg1	et	kandsin =kand  (IndIpfSg1  >kandma !34_V
50927	pöörasin	pööra	pöörama	29_V	IndIpfSg1	et	pöörasin =pööra  (IndIpfSg1  >pöörama !29_V
50936	autodel	auto	auto	16_S	PlAd	et	autodel =auto  (PlAd  >auto !16_S
50940	kasvuga	kasvu	kasv	22_S	SgKom	et	kasvuga =kasvu  (SgKom  >kasv !22_S
50944	takerduda	takerdu	takerduma	27_V	Inf	et	takerduda =takerdu  (Inf  >takerduma !27_V
50954	pikeneb	pikene	pikenema	27_V	IndPrSg3	et	pikeneb =pikene  (IndPrSg3  >pikenema !27_V
50744	timuti	timuti	timut	02_S	SgG	et	timuti =timuti  (SgG  >timut !02_S
50745	kodutelefon	telefon	kodu+telefon	19_S	SgN	et	kodutelefon =telefon  (SgN  >kodu+telefon !19_S
50750	nõudepesuvahendid	vahendi	nõude+pesu+vahend	02_S	PlN	et	nõudepesuvahendid =vahendi  (PlN  >nõude+pesu+vahend !02_S
50757	seisukapil	kapi	seisu+kapp	22_S	SgAd	et	seisukapil =kapi  (SgAd  >seisu+kapp !22_S
50769	seine	seine	sein	22_S	PlP	et	seine =seine  (PlP  >sein !22_S
50771	vannivaip	vaip	vanni+vaip	22_S	SgN	et	vannivaip =vaip  (SgN  >vanni+vaip !22_S
50775	pannis	panni	pann	22_S	SgIn	et	pannis =panni  (SgIn  >pann !22_S
50787	asjatundjaks	tundja	asja+tundja	01_S	SgTr	et	asjatundjaks =tundja  (SgTr  >asja+tundja !01_S
50796	autoremondid	remondi	auto+remont	22_S	PlN	et	autoremondid =remondi  (PlN  >auto+remont !22_S
50810	sisseastujate	astuja	sisse+astuja	01_S	PlG	et	sisseastujate =astuja  (PlG  >sisse+astuja !01_S
50812	koolituskursustele	kursus	koolitus+kursus	11~09_S	PlAll	et	koolituskursustele =kursus  (PlAll  >koolitus+kursus !11~09_S
50817	elektroonikuna	elektrooniku	elektroonik	02_S	SgEs	et	elektroonikuna =elektrooniku  (SgEs  >elektroonik !02_S
50818	olem	olem	olem	02_S	SgN	et	olem =olem  (SgN  >olem !02_S
50819	üliõpilastekülas	küla	üli+õpi+laste+küla	17_S	SgIn	et	üliõpilastekülas =küla  (SgIn  >üli+õpi+laste+küla !17_S
50830	arvutisüsteemidega	süsteemi	arvuti+süsteem	22_S	PlKom	et	arvutisüsteemidega =süsteemi  (PlKom  >arvuti+süsteem !22_S
50837	kristust	kristus	kristus	11~09_S	SgP	et	kristust =kristus  (SgP  >kristus !11~09_S
50840	jõuluvanaisale	isa	jõulu+vana+isa	17_S	SgAll	et	jõuluvanaisale =isa  (SgAll  >jõulu+vana+isa !17_S
50841	geomeetriaga	geomeetria	geomeetria	01_S	SgKom	et	geomeetriaga =geomeetria  (SgKom  >geomeetria !01_S
50842	tähtseim	seim	täht+seim	22_S	SgN	et	tähtseim =seim  (SgN  >täht+seim !22_S
50844	aastak	aastak	aastak	02_S	SgN	et	aastak =aastak  (SgN  >aastak !02_S
50872	ümberorienteerumise	orienteerumise	ümber+orienteerumine	12_S	SgG	et	ümberorienteerumise =orienteerumise  (SgG  >ümber+orienteerumine !12_S
50873	moodsateks	moodsa	moodne	02_A	PlTr	et	moodsateks =moodsa  (PlTr  >moodne !02_A
50884	taasiseseisvumisaja	aja	taas+ise+seisvumis+aeg	22_S	SgG	et	taasiseseisvumisaja =aja  (SgG  >taas+ise+seisvumis+aeg !22_S
50894	vastupanelikud	paneliku	vastu+panelik	25_A	PlN	et	vastupanelikud =paneliku  (PlN  >vastu+panelik !25_A
50897	alandada	alanda	alandama	27_V	Inf	et	alandada =alanda  (Inf  >alandama !27_V
50906	vastame	vasta	vastama	29_V	IndPrPl1	et	vastame =vasta  (IndPrPl1  >vastama !29_V
50916	partnereid	partnere	partner	02_S	PlP	et	partnereid =partnere  (PlP  >partner !02_S
50918	täiustama	täiusta	täiustama	27_V	Sup	et	täiustama =täiusta  (Sup  >täiustama !27_V
50924	osalesite	osale	osalema	27_V	IndIpfPl2	et	osalesite =osale  (IndIpfPl2  >osalema !27_V
50929	mustades	musta	must	22_AS	PlIn	et	mustades =musta  (PlIn  >must !22_AS
50949	spordikoti	koti	spordi+kott	22_S	SgG	et	spordikoti =koti  (SgG  >spordi+kott !22_S
50950	elektrijuht	juht	elektri+juht	22_S	SgN	et	elektrijuht =juht  (SgN  >elektri+juht !22_S
50957	tulumaksuseaduse	seaduse	tulu+maksu+seadus	11~09_S	SgG	et	tulumaksuseaduse =seaduse  (SgG  >tulu+maksu+seadus !11~09_S
50958	ettevõtlustel	võtlus	ette+võtlus	11~09_S	PlAd	et	ettevõtlustel =võtlus  (PlAd  >ette+võtlus !11~09_S
50962	valdlinn	linn	vald+linn	22_S	SgN	et	valdlinn =linn  (SgN  >vald+linn !22_S
50968	osoon	osoon	osoon	22_S	SgN	et	osoon =osoon  (SgN  >osoon !22_S
50971	stratosfääris	stratosfääri	stratosfäär	22_S	SgIn	et	stratosfääris =stratosfääri  (SgIn  >stratosfäär !22_S
50974	kontsentratsioon	kontsentratsioon	kontsentratsioon	22_S	SgN	et	kontsentratsioon =kontsentratsioon  (SgN  >kontsentratsioon !22_S
50980	ultraviolettkiirgus	kiirgus	ultra+violett+kiirgus	11~09_S	SgN	et	ultraviolettkiirgus =kiirgus  (SgN  >ultra+violett+kiirgus !11~09_S
50983	pilved	pilve	pilv	22_S	PlN	et	pilved =pilve  (PlN  >pilv !22_S
50992	võlakohustused	kohustuse	võla+kohustus	11_S	PlN	et	võlakohustused =kohustuse  (PlN  >võla+kohustus !11_S
50994	võlad	võla	võlg	22_S	PlN	et	võlad =võla  (PlN  >võlg !22_S
51010	liblikatüdruk	tüdruk	liblika+tüdruk	02_S	SgN	et	liblikatüdruk =tüdruk  (SgN  >liblika+tüdruk !02_S
51018	suusatamas	suusata	suusatama	27_V	SupIn	et	suusatamas =suusata  (SupIn  >suusatama !27_V
51026	pühendasin	pühenda	pühendama	27_V	IndIpfSg1	et	pühendasin =pühenda  (IndIpfSg1  >pühendama !27_V
51031	kuldnõud	nõu	kuld+nõu	26_S	PlN	et	kuldnõud =nõu  (PlN  >kuld+nõu !26_S
51038	sõlmatu	atu	sõlm+att	22_S	SgG	et	sõlmatu =atu  (SgG  >sõlm+att !22_S
51040	lööda	löö	lööma	38_V	IndPrIps_	et	lööda =löö  (IndPrIps_  >lööma !38_V
51047	naabertalude	talu	naaber+talu	17_S	PlG	et	naabertalude =talu  (PlG  >naaber+talu !17_S
51048	dialoogid	dialoogi	dialoog	22_S	PlN	et	dialoogid =dialoogi  (PlN  >dialoog !22_S
51052	südametunnistuse	tunnistuse	südame+tunnistus	11_S	SgG	et	südametunnistuse =tunnistuse  (SgG  >südame+tunnistus !11_S
50847	2007-st			xx_Q	SgEl	et	-st =  (SgEl  > !xx_Q
50850	poisiks	poisi	poiss	23?22_S	SgTr	et	poisiks =poisi  (SgTr  >poiss !23?22_S
50856	eksamitega	eksami	eksam	02_S	PlKom	et	eksamitega =eksami  (PlKom  >eksam !02_S
50866	õppetöösse	töö	õppe+töö	26_S	SgIll	et	õppetöösse =töö  (SgIll  >õppe+töö !26_S
50869	sulaaja	aja	sula+aeg	22_S	SgG	et	sulaaja =aja  (SgG  >sula+aeg !22_S
50870	enesetaastamiseks	taastamise	enese+taastamine	12_S	SgTr	et	enesetaastamiseks =taastamise  (SgTr  >enese+taastamine !12_S
50880	languse	languse	langus	11~09_S	SgG	et	languse =languse  (SgG  >langus !11~09_S
50891	kinodesse	kino	kino	17_S	PlIll	et	kinodesse =kino  (PlIll  >kino !17_S
50892	libahundis	hundi	liba+hunt	22_S	SgIn	et	libahundis =hundi  (SgIn  >liba+hunt !22_S
50893	nõiaks	nõia	nõid	22_S	SgTr	et	nõiaks =nõia  (SgTr  >nõid !22_S
50896	äriinimesed	inimese	äri+inimene	12_S	PlN	et	äriinimesed =inimese  (PlN  >äri+inimene !12_S
50900	poliitikasaadet	saade	poliitika+saade	06_S	SgP	et	poliitikasaadet =saade  (SgP  >poliitika+saade !06_S
50902	diskrimineerida	diskrimineeri	diskrimineerima	28_V	Inf	et	diskrimineerida =diskrimineeri  (Inf  >diskrimineerima !28_V
50903	transpordis	transpordi	transport	22_S	SgIn	et	transpordis =transpordi  (SgIn  >transport !22_S
50907	pakun	paku	pakkuma	28_V	IndPrSg1	et	pakun =paku  (IndPrSg1  >pakkuma !28_V
50910	koolipingidest	pingi	kooli+ping	22_S	PlEl	et	koolipingidest =pingi  (PlEl  >kooli+ping !22_S
50911	määrasin	määra	määrama	29_V	IndIpfSg1	et	määrasin =määra  (IndIpfSg1  >määrama !29_V
50912	aineõpetajaks	õpetaja	aine+õpetaja	01_S	SgTr	et	aineõpetajaks =õpetaja  (SgTr  >aine+õpetaja !01_S
50915	pidurdasin	pidurda	pidurdama	27_V	IndIpfSg1	et	pidurdasin =pidurda  (IndIpfSg1  >pidurdama !27_V
50922	tagastaksite	tagasta	tagastama	27_V	KndPrPl2	et	tagastaksite =tagasta  (KndPrPl2  >tagastama !27_V
50931	elustiilis	stiili	elu+stiil	22_S	SgIn	et	elustiilis =stiili  (SgIn  >elu+stiil !22_S
50937	mustest	muste	must	22_AS	PlEl	et	mustest =muste  (PlEl  >must !22_AS
50946	puhtana	puhta	puhas	07_A	SgEs	et	puhtana =puhta  (SgEs  >puhas !07_A
50951	tööriistaga	riista	töö+riist	22_S	SgKom	et	tööriistaga =riista  (SgKom  >töö+riist !22_S
50952	elektrilöök	löök	elektri+löök	22_S	SgN	et	elektrilöök =löök  (SgN  >elektri+löök !22_S
50961	dokumentidele	dokumenti	dokument	22_S	PlAll	et	dokumentidele =dokumenti  (PlAll  >dokument !22_S
50965	tööruumid	ruumi	töö+ruum	22_S	PlN	et	tööruumid =ruumi  (PlN  >töö+ruum !22_S
50967	maksuamet	amet	maksu+amet	02_S	SgN	et	maksuamet =amet  (SgN  >maksu+amet !02_S
50969	kaitsekilbi	kilbi	kaitse+kilp	22_S	SgG	et	kaitsekilbi =kilbi  (SgG  >kaitse+kilp !22_S
50972	moodustaks	moodusta	moodustama	27_V	KndPrPs	et	moodustaks =moodusta  (KndPrPs  >moodustama !27_V
50979	osoonikiht	kiht	osooni+kiht	22_S	SgN	et	osoonikiht =kiht  (SgN  >osooni+kiht !22_S
50981	osoonikihis	kihi	osooni+kiht	22_S	SgIn	et	osoonikihis =kihi  (SgIn  >osooni+kiht !22_S
50982	osoonikihi	kihi	osooni+kiht	22_S	SgG	et	osoonikihi =kihi  (SgG  >osooni+kiht !22_S
50985	tsoonis	tsooni	tsoon	22_S	SgIn	et	tsoonis =tsooni  (SgIn  >tsoon !22_S
50990	töövõtjaid	võtja	töö+võtja	01_S	PlP	et	töövõtjaid =võtja  (PlP  >töö+võtja !01_S
50991	väljamakstavat	makstava	välja+makstav	02_A	SgP	et	väljamakstavat =makstava  (SgP  >välja+makstav !02_A
50993	ettemaksed	makse	ette+makse	06_S	PlN	et	ettemaksed =makse  (PlN  >ette+makse !06_S
51001	puruneda	purune	purunema	27_V	Inf	et	puruneda =purune  (Inf  >purunema !27_V
51011	sol	sol	sol	22_S	SgN	et	sol =sol  (SgN  >sol !22_S
51016	kirjeldan	kirjelda	kirjeldama	27_V	IndPrSg1	et	kirjeldan =kirjelda  (IndPrSg1  >kirjeldama !27_V
51021	niisugusest	suguse	nii+sugune	10_P	SgEl	et	niisugusest =suguse  (SgEl  >nii+sugune !10_P
51029	mustal	musta	must	22_AS	SgAd	et	mustal =musta  (SgAd  >must !22_AS
51043	meisterlik	meisterlik	meisterlik	25_A	SgN	et	meisterlik =meisterlik  (SgN  >meisterlik !25_A
51049	kaasahaaravad	haarava	kaasa+haarav	02_A	PlN	et	kaasahaaravad =haarava  (PlN  >kaasa+haarav !02_A
51050	läbielamiste	elamis	läbi+elamine	12_S	PlG	et	läbielamiste =elamis  (PlG  >läbi+elamine !12_S
51051	praktilisest	praktilise	praktiline	12_A	SgEl	et	praktilisest =praktilise  (SgEl  >praktiline !12_A
51054	südametunnistus	tunnistus	südame+tunnistus	11_S	SgN	et	südametunnistus =tunnistus  (SgN  >südame+tunnistus !11_S
51066	hüvangi	hüvangi	hüvang	02_S	SgG	et	hüvangi =hüvangi  (SgG  >hüvang !02_S
51068	kirjutades	kirjuta	kirjutama	27_V	Ger	et	kirjutades =kirjuta  (Ger  >kirjutama !27_V
51072	alandlik	alandlik	alandlik	25_A	SgN	et	alandlik =alandlik  (SgN  >alandlik !25_A
51075	viskab	viska	viskama	29_V	IndPrSg3	et	viskab =viska  (IndPrSg3  >viskama !29_V
51096	nõustab	nõusta	nõustama	27_V	IndPrSg3	et	nõustab =nõusta  (IndPrSg3  >nõustama !27_V
51099	sündida	sündi	sündima	28_V	Inf	et	sündida =sündi  (Inf  >sündima !28_V
50871	jalale	jala	jalg	22_S	SgAll	et	jalale =jala  (SgAll  >jalg !22_S
50874	tegevusaladeks	ala	tegevus+ala	17_S	PlTr	et	tegevusaladeks =ala  (PlTr  >tegevus+ala !17_S
50875	massiteabe	teabe	massi+teave	06_S	SgG	et	massiteabe =teabe  (SgG  >massi+teave !06_S
50876	kultuuritarbimises	tarbimise	kultuuri+tarbimine	12_S	SgIn	et	kultuuritarbimises =tarbimise  (SgIn  >kultuuri+tarbimine !12_S
50881	riigiringhääl	hääl	riigi+ring+hääl	13_S	SgN	et	riigiringhääl =hääl  (SgN  >riigi+ring+hääl !13_S
50882	asustama	asusta	asustama	27_V	Sup	et	asustama =asusta  (Sup  >asustama !27_V
50886	pingne	pingne	pingne	02_A	SgN	et	pingne =pingne  (SgN  >pingne !02_A
50888	ebaõiglaseks	õiglase	eba+õiglane	12?10_A	SgTr	et	ebaõiglaseks =õiglase  (SgTr  >eba+õiglane !12?10_A
50895	pärisjuhtunud	juhtunu	päris+juhtunu	01_S	PlN	et	pärisjuhtunud =juhtunu  (PlN  >päris+juhtunu !01_S
50899	argumente	argumente	argument	22_S	PlP	et	argumente =argumente  (PlP  >argument !22_S
50901	kuritegijaid	tegija	kuri+tegija	01_S	PlP	et	kuritegijaid =tegija  (PlP  >kuri+tegija !01_S
50908	klassikoosolekuid	oleku	klassi+koos+olek	02_S	PlP	et	klassikoosolekuid =oleku  (PlP  >klassi+koos+olek !02_S
50913	minibuss	buss	mini+buss	22_S	SgN	et	minibuss =buss  (SgN  >mini+buss !22_S
50914	jalgratturile	ratturi	jalg+rattur	02_S	SgAll	et	jalgratturile =ratturi  (SgAll  >jalg+rattur !02_S
50917	saavutab	saavuta	saavutama	27_V	IndPrSg3	et	saavutab =saavuta  (IndPrSg3  >saavutama !27_V
50919	haridustaseme	taseme	haridus+tase	04_S	SgG	et	haridustaseme =taseme  (SgG  >haridus+tase !04_S
50921	märjaks	märja	märg	22_AS	SgTr	et	märjaks =märja  (SgTr  >märg !22_AS
50926	toimumisaeg	aeg	toimumis+aeg	22_S	SgN	et	toimumisaeg =aeg  (SgN  >toimumis+aeg !22_S
50933	mineraalained	aine	mineraal+aine	06_S	PlN	et	mineraalained =aine  (PlN  >mineraal+aine !06_S
50934	katuseluuk	luuk	katuse+luuk	22_S	SgN	et	katuseluuk =luuk  (SgN  >katuse+luuk !22_S
50935	kabriolett	kabriolett	kabriolett	22_S	SgN	et	kabriolett =kabriolett  (SgN  >kabriolett !22_S
50943	koormuse	koormuse	koormus	11~09_S	SgG	et	koormuse =koormuse  (SgG  >koormus !11~09_S
50945	hingamisteedesse	tee	hingamis+tee	26_S	PlIll	et	hingamisteedesse =tee  (PlIll  >hingamis+tee !26_S
50953	töörist	rist	töö+rist	22_S	SgN	et	töörist =rist  (SgN  >töö+rist !22_S
50955	juhtmed	juhtme	juhe	05_S	PlN	et	juhtmed =juhtme  (PlN  >juhe !05_S
50959	kahjum	kahjum	kahjum	02_S	SgN	et	kahjum =kahjum  (SgN  >kahjum !02_S
50960	märkusi	märkusi	märkus	11_S	PlP	et	märkusi =märkusi  (PlP  >märkus !11_S
50963	saunasiseseid	sisese	sauna+sisene	10_A	PlP	et	saunasiseseid =sisese  (PlP  >sauna+sisene !10_A
50970	efektiivse	efektiivse	efektiivne	02_A	SgG	et	efektiivse =efektiivse  (SgG  >efektiivne !02_A
50973	sentimeetri	meetri	senti+meeter	02_S	SgG	et	sentimeetri =meetri  (SgG  >senti+meeter !02_S
50976	kahjuliku	kahjuliku	kahjulik	25_A	SgG	et	kahjuliku =kahjuliku  (SgG  >kahjulik !25_A
50977	ultraviolettkiirguse	kiirguse	ultra+violett+kiirgus	11~09_S	SgG	et	ultraviolettkiirguse =kiirguse  (SgG  >ultra+violett+kiirgus !11~09_S
50987	äärmist	äärmis	äärmine	12?10_A	SgP	et	äärmist =äärmis  (SgP  >äärmine !12?10_A
50988	käigushoidmine	hoidmine	käigus+hoidmine	12?10_S	SgN	et	käigushoidmine =hoidmine  (SgN  >käigus+hoidmine !12?10_S
50995	maksuvõlad	võla	maksu+võlg	22_S	PlN	et	maksuvõlad =võla  (PlN  >maksu+võlg !22_S
50997	töövõtjatele	võtja	töö+võtja	01_S	PlAll	et	töövõtjatele =võtja  (PlAll  >töö+võtja !01_S
51002	väärtuspabereid	pabere	väärtus+paber	02_S	PlP	et	väärtuspabereid =pabere  (PlP  >väärtus+paber !02_S
51006	tehing	tehing	tehing	02_S	SgN	et	tehing =tehing  (SgN  >tehing !02_S
51009	konnaga	konna	konn	22_S	SgKom	et	konnaga =konna  (SgKom  >konn !22_S
51014	liblikaemale	ema	liblika+ema	17_S	SgAll	et	liblikaemale =ema  (SgAll  >liblika+ema !17_S
51017	austriasse	asse	austri+ass	22_S	PlP	et	austriasse =asse  (PlP  >austri+ass !22_S
51022	spordilaagreid	laagre	spordi+laager	02_S	PlP	et	spordilaagreid =laagre  (PlP  >spordi+laager !02_S
51023	suvesid	suve	suvi	20_S	PlP	et	suvesid =suve  (PlP  >suvi !20_S
51036	mõtlikuks	mõtliku	mõtlik	25_A	SgTr	et	mõtlikuks =mõtliku  (SgTr  >mõtlik !25_A
51042	prototüüp	prototüüp	prototüüp	22_S	SgN	et	prototüüp =prototüüp  (SgN  >prototüüp !22_S
51053	karakteri	karakteri	karakter	02_S	SgG	et	karakteri =karakteri  (SgG  >karakter !02_S
51055	marit	mari	mari	16_S	SgP	et	marit =mari  (SgP  >mari !16_S
51057	piimamehe	mehe	piima+mees	13_S	SgG	et	piimamehe =mehe  (SgG  >piima+mees !13_S
51058	etteheiteid	heite	ette+heide	06_S	PlP	et	etteheiteid =heite  (PlP  >ette+heide !06_S
51061	valikude	ude	valik+ude	04_S	SgN	et	valikude =ude  (SgN  >valik+ude !04_S
51064	kahetseb	kahetse	kahetsema	27_V	IndPrSg3	et	kahetseb =kahetse  (IndPrSg3  >kahetsema !27_V
51069	tulutoovat	toova	tulu+toov	02_A	SgP	et	tulutoovat =toova  (SgP  >tulu+toov !02_A
50956	tulumaks	maks	tulu+maks	22_S	SgN	et	tulumaks =maks  (SgN  >tulu+maks !22_S
50966	toll-	toll	toll	22_S	SgN	et	toll- =toll  (SgN  >toll !22_S
50998	dividendivõlad	võla	dividendi+võlg	22_S	PlN	et	dividendivõlad =võla  (PlN  >dividendi+võlg !22_S
51000	pankrot	pankrot	pankrot	22_S	SgN	et	pankrot =pankrot  (SgN  >pankrot !22_S
51003	liisingud	liisingu	liising	02_S	PlN	et	liisingud =liisingu  (PlN  >liising !02_S
51004	pangalaen	laen	panga+laen	22_S	SgN	et	pangalaen =laen  (SgN  >panga+laen !22_S
51005	ettevõtjale	võtja	ette+võtja	01_S	SgAll	et	ettevõtjale =võtja  (SgAll  >ette+võtja !01_S
51007	põhivahendi	vahendi	põhi+vahend	02_S	SgG	et	põhivahendi =vahendi  (SgG  >põhi+vahend !02_S
51012	hüplen	hüple	hüplema	30_V	IndPrSg1	et	hüplen =hüple  (IndPrSg1  >hüplema !30_V
51019	arhitektuurist	arhitektuuri	arhitektuur	22_S	SgEl	et	arhitektuurist =arhitektuuri  (SgEl  >arhitektuur !22_S
51025	võistlustantsule	tantsu	võistlus+tants	22_S	SgAll	et	võistlustantsule =tantsu  (SgAll  >võistlus+tants !22_S
51028	hõbedaid	hõbeda	hõbe	02_S	PlP	et	hõbedaid =hõbeda  (PlP  >hõbe !02_S
51033	realistlik	realistlik	realistlik	25_A	SgN	et	realistlik =realistlik  (SgN  >realistlik !25_A
51034	õnnelikkudeks	õnnelikku	õnnelik	25_A	PlTr	et	õnnelikkudeks =õnnelikku  (PlTr  >õnnelik !25_A
51035	vaine	vaine	vain	22_S	PlP	et	vaine =vaine  (PlP  >vain !22_S
51037	mõisnikust	mõisniku	mõisnik	25_S	SgEl	et	mõisnikust =mõisniku  (SgEl  >mõisnik !25_S
51039	marile	mari	mari	17~16_S	SgAll	et	marile =mari  (SgAll  >mari !17~16_S
51041	vastuoksa	vastuoksa	vastu+oksa	41_D	ID	et	vastuoksa =vastuoksa  (ID  >vastu+oksa !41_D
51059	maril	mari	mari	17~16_S	SgAd	et	maril =mari  (SgAd  >mari !17~16_S
51062	ööseti	seti	öö+sett	22_S	SgG	et	ööseti =seti  (SgG  >öö+sett !22_S
51063	ohverdab	ohverda	ohverdama	27_V	IndPrSg3	et	ohverdab =ohverda  (IndPrSg3  >ohverdama !27_V
51070	nõustub	nõustu	nõustuma	27_V	IndPrSg3	et	nõustub =nõustu  (IndPrSg3  >nõustuma !27_V
51078	sarnas	sarna	sarn	22_S	SgIn	et	sarnas =sarna  (SgIn  >sarn !22_S
51082	kadestada	kadesta	kadestama	27_V	Inf	et	kadestada =kadesta  (Inf  >kadestama !27_V
51083	peetub	peetu	peetuma	27_V	IndPrSg3	et	peetub =peetu  (IndPrSg3  >peetuma !27_V
51092	talutüdruk	tüdruk	talu+tüdruk	02_S	SgN	et	talutüdruk =tüdruk  (SgN  >talu+tüdruk !02_S
51095	lähedases	lähedase	lähedane	12_AS	SgIn	et	lähedases =lähedase  (SgIn  >lähedane !12_AS
51102	trügitakse	trügi	trügima	27_V	IndPrIps	et	trügitakse =trügi  (IndPrIps  >trügima !27_V
51113	huvituda	huvitu	huvituma	27_V	Inf	et	huvituda =huvitu  (Inf  >huvituma !27_V
51116	arstidega	arsti	arst	22_S	PlKom	et	arstidega =arsti  (PlKom  >arst !22_S
51120	tollasesse	tollase	tollane	10_A	SgIll	et	tollasesse =tollase  (SgIll  >tollane !10_A
51121	kasumi	kasumi	kasum	02_S	SgG	et	kasumi =kasumi  (SgG  >kasum !02_S
51128	jõuluaeg	aeg	jõulu+aeg	22_S	SgN	et	jõuluaeg =aeg  (SgN  >jõulu+aeg !22_S
51130	kaunistama	kaunista	kaunistama	27_V	Sup	et	kaunistama =kaunista  (Sup  >kaunistama !27_V
51133	uusaastat	aasta	uus+aasta	01_S	SgP	et	uusaastat =aasta  (SgP  >uus+aasta !01_S
51141	õigeusklik	usklik	õige+usklik	25_AS	SgN	et	õigeusklik =usklik  (SgN  >õige+usklik !25_AS
51146	jõuludel	jõulu	jõul	22_S	PlAd	et	jõuludel =jõulu  (PlAd  >jõul !22_S
51157	jõulunädal	nädal	jõulu+nädal	02_S	SgN	et	jõulunädal =nädal  (SgN  >jõulu+nädal !02_S
51160	jõulumõtte	mõtte	jõulu+mõte	06_S	SgG	et	jõulumõtte =mõtte  (SgG  >jõulu+mõte !06_S
51164	sooritaksin	soorita	sooritama	27_V	KndPrSg1	et	sooritaksin =soorita  (KndPrSg1  >sooritama !27_V
51170	muutun	muutu	muutuma	27_V	IndPrSg1	et	muutun =muutu  (IndPrSg1  >muutuma !27_V
51172	õllesid	õlle	õlu	24_S	PlP	et	õllesid =õlle  (PlP  >õlu !24_S
51180	jõuluvaheaeg	aeg	jõulu+vahe+aeg	22_S	SgN	et	jõuluvaheaeg =aeg  (SgN  >jõulu+vahe+aeg !22_S
51181	jõulupäevad	päeva	jõulu+päev	22_S	PlN	et	jõulupäevad =päeva  (PlN  >jõulu+päev !22_S
51185	suusatasime	suusata	suusatama	27_V	IndIpfPl1	et	suusatasime =suusata  (IndIpfPl1  >suusatama !27_V
51186	lumelörts	lörts	lume+lörts	22_SA	SgN	et	lumelörts =lörts  (SgN  >lume+lörts !22_SA
51199	lahtivõtmine	võtmine	lahti+võtmine	12?10_S	SgN	et	lahtivõtmine =võtmine  (SgN  >lahti+võtmine !12?10_S
51200	hotelliteeninduses	teeninduse	hotelli+teenindus	11_S	SgIn	et	hotelliteeninduses =teeninduse  (SgIn  >hotelli+teenindus !11_S
51201	globaalseid	globaalse	globaalne	02_A	PlP	et	globaalseid =globaalse  (PlP  >globaalne !02_A
51219	globaalsed	globaalse	globaalne	02_A	PlN	et	globaalsed =globaalse  (PlN  >globaalne !02_A
51221	vähendama	vähenda	vähendama	27_V	Sup	et	vähendama =vähenda  (Sup  >vähendama !27_V
51230	saastab	saasta	saastama	29~27_V	IndPrSg3	et	saastab =saasta  (IndPrSg3  >saastama !29~27_V
51236	pakendit	pakendi	pakend	02_S	SgP	et	pakendit =pakendi  (SgP  >pakend !02_S
50964	puitdetaile	detaile	puit+detail	22_S	PlP	et	puitdetaile =detaile  (PlP  >puit+detail !22_S
50975	filtritest	filtri	filter	02_S	PlEl	et	filtritest =filtri  (PlEl  >filter !02_S
50978	neelab	neela	neelama	29_V	IndPrSg3	et	neelab =neela  (IndPrSg3  >neelama !29_V
50984	heitgaasidest	gaasi	heit+gaas	22_S	PlEl	et	heitgaasidest =gaasi  (PlEl  >heit+gaas !22_S
50986	eksaam	aam	eks+aam	22_S	SgN	et	eksaam =aam  (SgN  >eks+aam !22_S
50989	väljamakstava	makstava	välja+makstav	02_A	SgG	et	väljamakstava =makstava  (SgG  >välja+makstav !02_A
50996	viitvõlad	võla	viit+võlg	22_S	PlN	et	viitvõlad =võla  (PlN  >viit+võlg !22_S
50999	intressivõlad	võla	intressi+võlg	22_S	PlN	et	intressivõlad =võla  (PlN  >intressi+võlg !22_S
51008	liisingulepingu	lepingu	liisingu+leping	02_S	SgG	et	liisingulepingu =lepingu  (SgG  >liisingu+leping !02_S
51013	mängigu	mängi	mängima	28_V	ImpPrPs	et	mängigu =mängi  (ImpPrPs  >mängima !28_V
51015	savisaari	saar	savi+saar	13_S	PlP	et	savisaari =saar  (PlP  >savi+saar !13_S
51020	seinades	seina	sein	22_S	PlIn	et	seinades =seina  (PlIn  >sein !22_S
51024	spordikarjäär	karjäär	spordi+karjäär	22_S	SgN	et	spordikarjäär =karjäär  (SgN  >spordi+karjäär !22_S
51027	sild	sild	sild	22_S	SgN	et	sild =sild  (SgN  >sild !22_S
51030	tantsuklubiga	klubi	tantsu+klubi	17_S	SgKom	et	tantsuklubiga =klubi  (SgKom  >tantsu+klubi !17_S
51032	aardeid	aarde	aare	06_S	PlP	et	aardeid =aarde  (PlP  >aare !06_S
51044	piimamehes	mehe	piima+mees	13_S	SgIn	et	piimamehes =mehe  (SgIn  >piima+mees !13_S
51045	psüühilisi	psüühilisi	psüühiline	12_A	PlP	et	psüühilisi =psüühilisi  (PlP  >psüühiline !12_A
51046	läbielamisi	elamisi	läbi+elamine	12_S	PlP	et	läbielamisi =elamisi  (PlP  >läbi+elamine !12_S
51060	tundmused	tundmuse	tundmus	11~09_S	PlN	et	tundmused =tundmuse  (PlN  >tundmus !11~09_S
51074	taipas	taipa	taipama	29_V	IndIpfSg3	et	taipas =taipa  (IndIpfSg3  >taipama !29_V
51077	tänapäevana	päeva	täna+päev	22_S	SgEs	et	tänapäevana =päeva  (SgEs  >täna+päev !22_S
51079	ebamuretsev	muretsev	eba+muretsev	02_A	SgN	et	ebamuretsev =muretsev  (SgN  >eba+muretsev !02_A
51085	piimamehena	mehe	piima+mees	13_S	SgEs	et	piimamehena =mehe  (SgEs  >piima+mees !13_S
51087	aktuaalseid	aktuaalse	aktuaalne	02_A	PlP	et	aktuaalseid =aktuaalse  (PlP  >aktuaalne !02_A
51088	kaasaeglased	aeglase	kaas+aeglane	12?10_A	PlN	et	kaasaeglased =aeglase  (PlN  >kaas+aeglane !12?10_A
51090	amoraalne	amoraalne	amoraalne	02_A	SgN	et	amoraalne =amoraalne  (SgN  >amoraalne !02_A
51093	tänapaevased	vase	täna+pae+vask	22_S	PlN	et	tänapaevased =vase  (PlN  >täna+pae+vask !22_S
51098	sarnest	sarne	sarn	22_S	PlEl	et	sarnest =sarne  (PlEl  >sarn !22_S
51100	veeretatakse	veereta	veeretama	27_V	IndPrIps	et	veeretatakse =veereta  (IndPrIps  >veeretama !27_V
51109	hirmutas	hirmuta	hirmutama	27_V	IndIpfSg3	et	hirmutas =hirmuta  (IndIpfSg3  >hirmutama !27_V
51111	pakute	paku	pakkuma	28_V	IndPrPl2	et	pakute =paku  (IndPrPl2  >pakkuma !28_V
51112	oleksite	ole	olema	36_V	KndPrPl2	et	oleksite =ole  (KndPrPl2  >olema !36_V
51123	kaardifirmas	firma	kaardi+firma	16_S	SgIn	et	kaardifirmas =firma  (SgIn  >kaardi+firma !16_S
51124	silmal	silma	silm	22_S	SgAd	et	silmal =silma  (SgAd  >silm !22_S
51126	järjekordse	kordse	järje+kordne	02_AS	SgG	et	järjekordse =kordse  (SgG  >järje+kordne !02_AS
51127	jõulumõtted	mõtte	jõulu+mõte	06_S	PlN	et	jõulumõtted =mõtte  (PlN  >jõulu+mõte !06_S
51129	suusabaasile	baasi	suusa+baas	22_S	SgAll	et	suusabaasile =baasi  (SgAll  >suusa+baas !22_S
51135	kaunistame	kaunista	kaunistama	27_V	IndPrPl1	et	kaunistame =kaunista  (IndPrPl1  >kaunistama !27_V
51143	pidutsetakse	pidutse	pidutsema	27_V	IndPrIps	et	pidutsetakse =pidutse  (IndPrIps  >pidutsema !27_V
51153	suurepäärase	rase	suure+pää+rase	02_AS	SgN	et	suurepäärase =rase  (SgN  >suure+pää+rase !02_AS
51171	jõuluööl	öö	jõulu+öö	26_S	SgAd	et	jõuluööl =öö  (SgAd  >jõulu+öö !26_S
51176	kallile	kalli	kallis	05~07_A	SgAll	et	kallile =kalli  (SgAll  >kallis !05~07_A
51182	matemaatiline	matemaatiline	matemaatiline	12_A	SgN	et	matemaatiline =matemaatiline  (SgN  >matemaatiline !12_A
51187	ootad	oota	ootama	29_V	IndPrSg2	et	ootad =oota  (IndPrSg2  >ootama !29_V
51188	jõulumõte	mõte	jõulu+mõte	06_S	SgN	et	jõulumõte =mõte  (SgN  >jõulu+mõte !06_S
51194	lumehang	hang	lume+hang	22_S	SgN	et	lumehang =hang  (SgN  >lume+hang !22_S
51202	tasemest	taseme	tase	04_S	SgEl	et	tasemest =taseme  (SgEl  >tase !04_S
51204	naljas	nalja	nali	24_S	SgIn	et	naljas =nalja  (SgIn  >nali !24_S
51205	päevitusin	päevitu	päevituma	27_V	IndIpfSg1	et	päevitusin =päevitu  (IndIpfSg1  >päevituma !27_V
51206	veepargis	pargi	vee+park	22_S	SgIn	et	veepargis =pargi  (SgIn  >vee+park !22_S
51208	avalas	avala	aval	02_A	SgIn	et	avalas =avala  (SgIn  >aval !02_A
51209	algusi	algusi	algus	11_S	PlP	et	algusi =algusi  (PlP  >algus !11_S
51056	hämmastab	hämmasta	hämmastama	27_V	IndPrSg3	et	hämmastab =hämmasta  (IndPrSg3  >hämmastama !27_V
51065	enesearmastajad	armastaja	enese+armastaja	01_S	PlN	et	enesearmastajad =armastaja  (PlN  >enese+armastaja !01_S
51067	mariga	mari	mari	17~16_S	SgKom	et	mariga =mari  (SgKom  >mari !17~16_S
51071	vahendina	vahendi	vahend	02_S	SgEs	et	vahendina =vahendi  (SgEs  >vahend !02_S
51076	hindas	hinda	hindama	29_V	IndIpfSg3	et	hindas =hinda  (IndIpfSg3  >hindama !29_V
51084	omamoodne	moodne	oma+moodne	02_A	SgN	et	omamoodne =moodne  (SgN  >oma+moodne !02_A
51086	põrub	põru	põruma	27_V	IndPrSg3	et	põrub =põru  (IndPrSg3  >põruma !27_V
51089	juhatada	juhata	juhatama	27_V	Inf	et	juhatada =juhata  (Inf  >juhatama !27_V
51091	piimameheks	mehe	piima+mees	13_S	SgTr	et	piimameheks =mehe  (SgTr  >piima+mees !13_S
51103	askeldada	askelda	askeldama	27_V	Inf	et	askeldada =askelda  (Inf  >askeldama !27_V
51104	kapsaid	kapsa	kapsas	07_S	PlP	et	kapsaid =kapsa  (PlP  >kapsas !07_S
51105	koolivägivald	vald	kooli+vägi+vald	22_S	SgN	et	koolivägivald =vald  (SgN  >kooli+vägi+vald !22_S
51106	andmeil	andme	anne	05_S	PlAd	et	andmeil =andme  (PlAd  >anne !05_S
51107	koolivägivallaga	valla	kooli+vägi+vald	22_S	SgKom	et	koolivägivallaga =valla  (SgKom  >kooli+vägi+vald !22_S
51108	koolivägivalla	valla	kooli+vägi+vald	22_S	SgG	et	koolivägivalla =valla  (SgG  >kooli+vägi+vald !22_S
51118	seltskondlik	seltskondlik	seltskondlik	25_A	SgN	et	seltskondlik =seltskondlik  (SgN  >seltskondlik !25_A
51132	haa	haa	haa	41_I	ID	et	haa =haa  (ID  >haa !41_I
51138	soritama	sori	sorima	27_V	SupIps	et	soritama =sori  (SupIps  >sorima !27_V
51144	korvidega	korvi	korv	22_S	PlKom	et	korvidega =korvi  (PlKom  >korv !22_S
51155	jõulusöök	söök	jõulu+söök	22_S	SgN	et	jõulusöök =söök  (SgN  >jõulu+söök !22_S
51167	päevak	päevak	päevak	02_S	SgN	et	päevak =päevak  (SgN  >päevak !02_S
51168	headest	hea	hea	26_AS	PlEl	et	headest =hea  (PlEl  >hea !26_AS
51183	geomeetriat	geomeetria	geomeetria	01_S	SgP	et	geomeetriat =geomeetria  (SgP  >geomeetria !01_S
51190	eksamiteks	eksami	eksam	02_S	PlTr	et	eksamiteks =eksami  (PlTr  >eksam !02_S
51195	suusatan	suusata	suusatama	27_V	IndPrSg1	et	suusatan =suusata  (IndPrSg1  >suusatama !27_V
51197	peolaua	laua	peo+laud	22_S	SgG	et	peolaua =laua  (SgG  >peo+laud !22_S
51220	happevihmad	vihma	happe+vihm	22_S	PlN	et	happevihmad =vihma  (PlN  >happe+vihm !22_S
51225	ökoeluviis	viis	öko+elu+viis	22_S	SgN	et	ökoeluviis =viis  (SgN  >öko+elu+viis !22_S
51229	plastmass	mass	plast+mass	22_S	SgN	et	plastmass =mass  (SgN  >plast+mass !22_S
51231	peseb	pese	pesema	36_V	IndPrSg3	et	peseb =pese  (IndPrSg3  >pesema !36_V
51233	ökoloogiast	ökoloogia	ökoloogia	01_S	SgEl	et	ökoloogiast =ökoloogia  (SgEl  >ökoloogia !01_S
51234	säästetakse	sääste	säästma	34_V	IndPrIps	et	säästetakse =sääste  (IndPrIps  >säästma !34_V
51235	pakend	pakend	pakend	02_S	SgN	et	pakend =pakend  (SgN  >pakend !02_S
51238	kilekotte	kotte	kile+kott	22_S	PlP	et	kilekotte =kotte  (PlP  >kile+kott !22_S
51240	lülitab	lülita	lülitama	27_V	IndPrSg3	et	lülitab =lülita  (IndPrSg3  >lülitama !27_V
51243	vabanema	vabane	vabanema	27_V	Sup	et	vabanema =vabane  (Sup  >vabanema !27_V
51245	balansseerima	balansseeri	balansseerima	28_V	Sup	et	balansseerima =balansseeri  (Sup  >balansseerima !28_V
51248	elukord	kord	elu+kord	22_S	SgN	et	elukord =kord  (SgN  >elu+kord !22_S
51252	reovett	ve	reo+vesi	15_S	SgP	et	reovett =ve  (SgP  >reo+vesi !15_S
51254	alternatiivseid	alternatiivse	alternatiivne	02_A	PlP	et	alternatiivseid =alternatiivse  (PlP  >alternatiivne !02_A
51256	keskkonnasõbralikke	sõbralikke	kesk+konna+sõbralik	25_A	PlP	et	keskkonnasõbralikke =sõbralikke  (PlP  >kesk+konna+sõbralik !25_A
51259	firmadele	firma	firma	16_S	PlAll	et	firmadele =firma  (PlAll  >firma !16_S
51266	täidan	täida	täitma	34_V	IndPrSg1	et	täidan =täida  (IndPrSg1  >täitma !34_V
51275	tuule-	tuule	tuul	13_S	SgG	et	tuule- =tuule  (SgG  >tuul !13_S
51279	kaubanduskeskused	keskuse	kaubandus+keskus	11~09_S	PlN	et	kaubanduskeskused =keskuse  (PlN  >kaubandus+keskus !11~09_S
51280	katalooge	katalooge	kataloog	22_S	PlP	et	katalooge =katalooge  (PlP  >kataloog !22_S
51294	kompenseerib	kompenseeri	kompenseerima	28_V	IndPrSg3	et	kompenseerib =kompenseeri  (IndPrSg3  >kompenseerima !28_V
51297	pakendeid	pakende	pakend	02_S	PlP	et	pakendeid =pakende  (PlP  >pakend !02_S
51298	rekordarv	arv	rekord+arv	22_S	SgN	et	rekordarv =arv  (SgN  >rekord+arv !22_S
51300	kilekoti	koti	kile+kott	22_S	SgG	et	kilekoti =koti  (SgG  >kile+kott !22_S
51301	koti	koti	kott	22_S	SgG	et	koti =koti  (SgG  >kott !22_S
51312	ökoloogiat	ökoloogia	ökoloogia	01_S	SgP	et	ökoloogiat =ökoloogia  (SgP  >ökoloogia !01_S
51314	nõustama	nõusta	nõustama	27_V	Sup	et	nõustama =nõusta  (Sup  >nõustama !27_V
51315	diisli	diisli	diisel	02_S	SgG	et	diisli =diisli  (SgG  >diisel !02_S
51073	lugupidamise	pidamise	lugu+pidamine	12_S	SgG	et	lugupidamise =pidamise  (SgG  >lugu+pidamine !12_S
51080	noores	noore	noor	13_AS	SgIn	et	noores =noore  (SgIn  >noor !13_AS
51081	äri-naisteks	nais	äri-naine	12_S	PlTr	et	äri-naisteks =nais  (PlTr  >äri-naine !12_S
51094	19-sajandi	sajandi	-sajand	02_S	SgG	et	-sajandi =sajandi  (SgG  >-sajand !02_S
51097	garanteerib	garanteeri	garanteerima	28_V	IndPrSg3	et	garanteerib =garanteeri  (IndPrSg3  >garanteerima !28_V
51114	remondist	remondi	remont	22_S	SgEl	et	remondist =remondi  (SgEl  >remont !22_S
51119	ebaõnnestumiste	õnnestumis	eba+õnnestumine	12_S	PlG	et	ebaõnnestumiste =õnnestumis  (PlG  >eba+õnnestumine !12_S
51125	kadestan	kadesta	kadestama	27_V	IndPrSg1	et	kadestan =kadesta  (IndPrSg1  >kadestama !27_V
51136	soovitame	soovita	soovitama	27_V	IndPrPl1	et	soovitame =soovita  (IndPrPl1  >soovitama !27_V
51142	jõuludest	jõulu	jõul	22_S	PlEl	et	jõuludest =jõulu  (PlEl  >jõul !22_S
51147	jõululaude	laude	jõulu+laud	22_S	PlP	et	jõululaude =laude  (PlP  >jõulu+laud !22_S
51148	õus	õu	õud	22_S	SgIn	et	õus =õu  (SgIn  >õud !22_S
51150	maksatakse	takse	maksa+taks	22_S	PlP	et	maksatakse =takse  (PlP  >maksa+taks !22_S
51152	vodkat	vodka	vodka	16_S	SgP	et	vodkat =vodka  (SgP  >vodka !16_S
51154	pereringil	ringi	pere+ring	22_S	SgAd	et	pereringil =ringi  (SgAd  >pere+ring !22_S
51156	ülikoolieksamid	eksami	üli+kooli+eksam	02_S	PlN	et	ülikoolieksamid =eksami  (PlN  >üli+kooli+eksam !02_S
51161	jõulusid	jõulu	jõul	22_S	PlP	et	jõulusid =jõulu  (PlP  >jõul !22_S
51162	lumelinn	linn	lume+linn	22_S	SgN	et	lumelinn =linn  (SgN  >lume+linn !22_S
51165	rõõmsast	rõõmsa	rõõmus	02_A	SgEl	et	rõõmsast =rõõmsa  (SgEl  >rõõmus !02_A
51166	uskusin	usku	uskuma	28_V	IndIpfSg1	et	uskusin =usku  (IndIpfSg1  >uskuma !28_V
51169	jõuluõhtul	õhtu	jõulu+õhtu	01_S	SgAd	et	jõuluõhtul =õhtu  (SgAd  >jõulu+õhtu !01_S
51173	jõuludega	jõulu	jõul	22_S	PlKom	et	jõuludega =jõulu  (PlKom  >jõul !22_S
51178	taituksid	tuksi	tai+tuks	22_S	PlN	et	taituksid =tuksi  (PlN  >tai+tuks !22_S
51179	õhustik	õhustik	õhustik	25_S	SgN	et	õhustik =õhustik  (SgN  >õhustik !25_S
51189	jõulunädalas	nädala	jõulu+nädal	02_S	SgIn	et	jõulunädalas =nädala  (SgIn  >jõulu+nädal !02_S
51191	jõulumõtteid	mõtte	jõulu+mõte	06_S	PlP	et	jõulumõtteid =mõtte  (PlP  >jõulu+mõte !06_S
51192	pereringis	ringi	pere+ring	22_S	SgIn	et	pereringis =ringi  (SgIn  >pere+ring !22_S
51193	uisutamas	uisuta	uisutama	27_V	SupIn	et	uisutamas =uisuta  (SupIn  >uisutama !27_V
51203	juulikult	kult	juuli+kult	22_S	SgN	et	juulikult =kult  (SgN  >juuli+kult !22_S
51210	majandusteaduskondis	kondi	majandus+teadus+kont	22_S	SgIn	et	majandusteaduskondis =kondi  (SgIn  >majandus+teadus+kont !22_S
51211	telkidega	telki	telk	22_S	PlKom	et	telkidega =telki  (PlKom  >telk !22_S
51212	alatskivisse	kivi	alats+kivi	17_S	SgIll	et	alatskivisse =kivi  (SgIll  >alats+kivi !17_S
51215	õpingukorraldusele	korralduse	õpingu+korraldus	11_S	SgAll	et	õpingukorraldusele =korralduse  (SgAll  >õpingu+korraldus !11_S
51217	turniir	turniir	turniir	22_S	SgN	et	turniir =turniir  (SgN  >turniir !22_S
51222	katsun	katsu	katsuma	28_V	IndPrSg1	et	katsun =katsu  (IndPrSg1  >katsuma !28_V
51228	viskame	viska	viskama	29_V	IndPrPl1	et	viskame =viska  (IndPrPl1  >viskama !29_V
51246	saastame	saasta	saastama	29~27_V	IndPrPl1	et	saastame =saasta  (IndPrPl1  >saastama !29~27_V
51250	tööstuskeskus	keskus	tööstus+keskus	11~09_S	SgN	et	tööstuskeskus =keskus  (SgN  >tööstus+keskus !11~09_S
51265	lasen	lase	laskma	34_V	IndPrSg1	et	lasen =lase  (IndPrSg1  >laskma !34_V
51269	peer	peer	peer	22_S	SgN	et	peer =peer  (SgN  >peer !22_S
51270	viskan	viska	viskama	29_V	IndPrSg1	et	viskan =viska  (IndPrSg1  >viskama !29_V
51278	kollektiivlepinguid	lepingu	kollektiiv+leping	02_S	PlP	et	kollektiivlepinguid =lepingu  (PlP  >kollektiiv+leping !02_S
51281	ürgsed	ürgse	ürgne	02_A	PlN	et	ürgsed =ürgse  (PlN  >ürgne !02_A
51286	jäägid	jäägi	jääk	22_S	PlN	et	jäägid =jäägi  (PlN  >jääk !22_S
51287	visatakse	visa	viskama	29_V	IndPrIps	et	visatakse =visa  (IndPrIps  >viskama !29_V
51295	pakendi	pakendi	pakend	02_S	SgG	et	pakendi =pakendi  (SgG  >pakend !02_S
51303	loodussäästule	säästu	loodus+sääst	22_S	SgAll	et	loodussäästule =säästu  (SgAll  >loodus+sääst !22_S
51304	säilitusaineid	aine	säilitus+aine	06_S	PlP	et	säilitusaineid =aine  (PlP  >säilitus+aine !06_S
51305	raadiokanalit	kanali	raadio+kanal	02_S	SgP	et	raadiokanalit =kanali  (SgP  >raadio+kanal !02_S
51313	poolitikud	tiku	pooli+tikk	22_S	PlN	et	poolitikud =tiku  (PlN  >pooli+tikk !22_S
51319	biokütuse	kütuse	bio+kütus	09_S	SgG	et	biokütuse =kütuse  (SgG  >bio+kütus !09_S
51333	maakeraga	kera	maa+kera	17_S	SgKom	et	maakeraga =kera  (SgKom  >maa+kera !17_S
51336	ökoeluga	elu	öko+elu	17_S	SgKom	et	ökoeluga =elu  (SgKom  >öko+elu !17_S
51101	hädavajalikke	vajalikke	häda+vajalik	25_A	PlP	et	hädavajalikke =vajalikke  (PlP  >häda+vajalik !25_A
51110	järelpärimine	pärimine	järel+pärimine	12_S	SgN	et	järelpärimine =pärimine  (SgN  >järel+pärimine !12_S
51115	nõue	nõue	nõue	06_S	SgN	et	nõue =nõue  (SgN  >nõue !06_S
51117	arvutiprogrammidest	programmi	arvuti+programm	22_S	PlEl	et	arvutiprogrammidest =programmi  (PlEl  >arvuti+programm !22_S
51122	osaniku	osaniku	osanik	25_S	SgG	et	osaniku =osaniku  (SgG  >osanik !25_S
51131	sess	sess	sess	22_S	SgN	et	sess =sess  (SgN  >sess !22_S
51134	kiireneb	kiirene	kiirenema	27_V	IndPrSg3	et	kiireneb =kiirene  (IndPrSg3  >kiirenema !27_V
51137	jõuluvaheaed	aed	jõulu+vahe+aed	22_S	SgN	et	jõuluvaheaed =aed  (SgN  >jõulu+vahe+aed !22_S
51139	jõulus	jõulu	jõul	22_S	SgIn	et	jõulus =jõulu  (SgIn  >jõul !22_S
51140	viied	viie	viis	14_N	PlN	et	viied =viie  (PlN  >viis !14_N
51145	läheda	läheda	läheda	02_A	SgG	et	läheda =läheda  (SgG  >läheda !02_A
51149	ülekolis	koli	üle+koli	17_S	SgIn	et	ülekolis =koli  (SgIn  >üle+koli !17_S
51151	lõbuses	lõbuse	lõbus	02_A	SgIn	et	lõbuses =lõbuse  (SgIn  >lõbus !02_A
51158	jõulupuhkus	puhkus	jõulu+puhkus	11~09_S	SgN	et	jõulupuhkus =puhkus  (SgN  >jõulu+puhkus !11~09_S
51159	jõuluni	jõulu	jõul	22_S	SgTer	et	jõuluni =jõulu  (SgTer  >jõul !22_S
51163	jõuluvanad	vana	jõulu+vana	17_AS	PlN	et	jõuluvanad =vana  (PlN  >jõulu+vana !17_AS
51174	jõulupäevadel	päeva	jõulu+päev	22_S	PlAd	et	jõulupäevadel =päeva  (PlAd  >jõulu+päev !22_S
51175	mandariinid	mandariini	mandariin	22_S	PlN	et	mandariinid =mandariini  (PlN  >mandariin !22_S
51177	vennaõe	õe	venna+õde	18_S	SgG	et	vennaõe =õe  (SgG  >venna+õde !18_S
51184	jõulule	jõulu	jõul	22_S	SgAll	et	jõulule =jõulu  (SgAll  >jõul !22_S
51196	tunnetab	tunneta	tunnetama	27_V	IndPrSg3	et	tunnetab =tunneta  (IndPrSg3  >tunnetama !27_V
51198	meeleks	meele	meel	13_S	SgTr	et	meeleks =meele  (SgTr  >meel !13_S
51207	eestikodaniku	kodaniku	eesti+kodanik	25_S	SgG	et	eestikodaniku =kodaniku  (SgG  >eesti+kodanik !25_S
51223	ettekirjutuse	kirjutuse	ette+kirjutus	11_S	SgG	et	ettekirjutuse =kirjutuse  (SgG  >ette+kirjutus !11_S
51224	röövpüük	püük	rööv+püük	22_S	SgN	et	röövpüük =püük  (SgN  >rööv+püük !22_S
51226	pudelit	pudeli	pudel	02_S	SgP	et	pudelit =pudeli  (SgP  >pudel !02_S
51227	pudelid	pudeli	pudel	02_S	PlN	et	pudelid =pudeli  (PlN  >pudel !02_S
51232	autopesulas	pesula	auto+pesula	01_S	SgIn	et	autopesulas =pesula  (SgIn  >auto+pesula !01_S
51237	ökoloogiaga	ökoloogia	ökoloogia	01_S	SgKom	et	ökoloogiaga =ökoloogia  (SgKom  >ökoloogia !01_S
51244	autorehvidest	rehvi	auto+rehv	22_S	PlEl	et	autorehvidest =rehvi  (PlEl  >auto+rehv !22_S
51247	taastame	taasta	taastama	27_V	IndPrPl1	et	taastame =taasta  (IndPrPl1  >taastama !27_V
51253	valuutaks	valuuta	valuuta	16_S	SgTr	et	valuutaks =valuuta  (SgTr  >valuuta !16_S
51255	transpordivahendeid	vahende	transpordi+vahend	02_S	PlP	et	transpordivahendeid =vahende  (PlP  >transpordi+vahend !02_S
51260	dünaamilise	dünaamilise	dünaamiline	12_A	SgG	et	dünaamilise =dünaamilise  (SgG  >dünaamiline !12_A
51262	keskkonnasaastamine	saastamine	kesk+konna+saastamine	12_S	SgN	et	keskkonnasaastamine =saastamine  (SgN  >kesk+konna+saastamine !12_S
51263	hammaste	hammas	hammas	07_S	PlG	et	hammaste =hammas  (PlG  >hammas !07_S
51264	kloppida	kloppi	kloppima	28_V	Inf	et	kloppida =kloppi  (Inf  >kloppima !28_V
51267	toiduvalmistamisel	valmistamise	toidu+valmistamine	12_S	SgAd	et	toiduvalmistamisel =valmistamise  (SgAd  >toidu+valmistamine !12_S
51268	akendele	aken	aken	08_S	PlAll	et	akendele =aken  (PlAll  >aken !08_S
51274	energiaallikaid	allika	energia+allikas	02_S	PlP	et	energiaallikaid =allika  (PlP  >energia+allikas !02_S
51276	hüdroenergiat	energia	hüdro+energia	01_S	SgP	et	hüdroenergiat =energia  (SgP  >hüdro+energia !01_S
51283	metsapindalad	ala	metsa+pind+ala	17_S	PlN	et	metsapindalad =ala  (PlN  >metsa+pind+ala !17_S
51285	taimeliikides	liiki	taime+liik	22_S	PlIn	et	taimeliikides =liiki  (PlIn  >taime+liik !22_S
51289	rahvuspargi	pargi	rahvus+park	22_S	SgG	et	rahvuspargi =pargi  (SgG  >rahvus+park !22_S
51291	lõhnaga	lõhna	lõhn	22_S	SgKom	et	lõhnaga =lõhna  (SgKom  >lõhn !22_S
51309	tuuleenergiat	energia	tuule+energia	01_S	SgP	et	tuuleenergiat =energia  (SgP  >tuule+energia !01_S
51311	reostab	reosta	reostama	27_V	IndPrSg3	et	reostab =reosta  (IndPrSg3  >reostama !27_V
51317	panditaarana	taara	pandi+taara	16_S	SgEs	et	panditaarana =taara  (SgEs  >pandi+taara !16_S
51320	ümbertöötlemist	töötlemis	ümber+töötlemine	12_S	SgP	et	ümbertöötlemist =töötlemis  (SgP  >ümber+töötlemine !12_S
51324	postil	posti	post	22_S	SgAd	et	postil =posti  (SgAd  >post !22_S
51325	tehnoloogiaid	tehnoloogia	tehnoloogia	01_S	PlP	et	tehnoloogiaid =tehnoloogia  (PlP  >tehnoloogia !01_S
51328	misjuures	misjuures	mis+juures	41_D	ID	et	misjuures =misjuures  (ID  >mis+juures !41_D
51213	võrusse	võru	võru	17_S	SgIll	et	võrusse =võru  (SgIll  >võru !17_S
51214	suvimajas	maja	suvi+maja	17_S	SgIn	et	suvimajas =maja  (SgIn  >suvi+maja !17_S
51216	2006-l			xx_Q	SgAd	et	-l =  (SgAd  > !xx_Q
51218	arendan	arenda	arendama	27_V	IndPrSg1	et	arendan =arenda  (IndPrSg1  >arendama !27_V
51239	parlamendis	parlamendi	parlament	22_S	SgIn	et	parlamendis =parlamendi  (SgIn  >parlament !22_S
51242	utiliseerin	utiliseeri	utiliseerima	28_V	IndPrSg1	et	utiliseerin =utiliseeri  (IndPrSg1  >utiliseerima !28_V
51258	küttemaavarad	vara	kütte+maa+vara	17_S	PlN	et	küttemaavarad =vara  (PlN  >kütte+maa+vara !17_S
51261	ökoelust	elu	öko+elu	17_S	SgEl	et	ökoelust =elu  (SgEl  >öko+elu !17_S
51271	plast-	plast	plast	22_S	SgN	et	plast- =plast  (SgN  >plast !22_S
51273	katalüsaatoriga	katalüsaatori	katalüsaator	02_S	SgKom	et	katalüsaatoriga =katalüsaatori  (SgKom  >katalüsaator !02_S
51282	elamuid	elamu	elamu	01_S	PlP	et	elamuid =elamu  (PlP  >elamu !01_S
51284	planeedi	planeedi	planeet	22_S	SgG	et	planeedi =planeedi  (SgG  >planeet !22_S
51288	lohutab	lohuta	lohutama	27_V	IndPrSg3	et	lohutab =lohuta  (IndPrSg3  >lohutama !27_V
51293	hoolib	hooli	hoolima	28_V	IndPrSg3	et	hoolib =hooli  (IndPrSg3  >hoolima !28_V
51306	hingematva	matva	hinge+mattev	02_A	SgG	et	hingematva =matva  (SgG  >hinge+mattev !02_A
51310	päikeseenergiat	energia	päikese+energia	01_S	SgP	et	päikeseenergiat =energia  (SgP  >päikese+energia !01_S
51318	kamina	kamina	kamin	02_S	SgG	et	kamina =kamina  (SgG  >kamin !02_S
51322	raisaks	raisa	raisk	22_S	SgTr	et	raisaks =raisa  (SgTr  >raisk !22_S
51330	ökoelule	elu	öko+elu	17_S	SgAll	et	ökoelule =elu  (SgAll  >öko+elu !17_S
51331	kujutlete	kujutle	kujutlema	27_V	IndPrPl2	et	kujutlete =kujutle  (IndPrPl2  >kujutlema !27_V
51341	kursid	kursi	kurss	22_S	PlN	et	kursid =kursi  (PlN  >kurss !22_S
51351	sadet	sade	sade	04_S	SgP	et	sadet =sade  (SgP  >sade !04_S
51360	ühtset	ühtse	ühtne	02_A	SgP	et	ühtset =ühtse  (SgP  >ühtne !02_A
51369	elektrisaadet	saade	elektri+saade	06_S	SgP	et	elektrisaadet =saade  (SgP  >elektri+saade !06_S
51370	hooleks	hoole	hool	13_S	SgTr	et	hooleks =hoole  (SgTr  >hool !13_S
51380	elektripirn	pirn	elektri+pirn	22_S	SgN	et	elektripirn =pirn  (SgN  >elektri+pirn !22_S
51381	elektriloenduri	loenduri	elektri+loendur	02_S	SgG	et	elektriloenduri =loenduri  (SgG  >elektri+loendur !02_S
51382	spetsialistidele	spetsialisti	spetsialist	22_S	PlAll	et	spetsialistidele =spetsialisti  (PlAll  >spetsialist !22_S
51385	regulaator	regulaator	regulaator	02_S	SgN	et	regulaator =regulaator  (SgN  >regulaator !02_S
51388	käivitusnupp	nupp	käivitus+nupp	22_S	SgN	et	käivitusnupp =nupp  (SgN  >käivitus+nupp !22_S
51392	võimsas	võimsa	võimas	03~05_A	SgIn	et	võimsas =võimsa  (SgIn  >võimas !03~05_A
51393	kohvikeetjat	keetja	kohvi+keetja	01_S	SgP	et	kohvikeetjat =keetja  (SgP  >kohvi+keetja !01_S
51396	kahetoas	toa	kahe+tuba	18_S	SgIn	et	kahetoas =toa  (SgIn  >kahe+tuba !18_S
51402	arvestame	arvesta	arvestama	27_V	IndPrPl1	et	arvestame =arvesta  (IndPrPl1  >arvestama !27_V
51403	astrit	astri	aster	02_S	SgP	et	astrit =astri  (SgP  >aster !02_S
51414	vedurijuhina	juhi	veduri+juht	22_S	SgEs	et	vedurijuhina =juhi  (SgEs  >veduri+juht !22_S
51425	kosed	kose	kosk	22_S	PlN	et	kosed =kose  (PlN  >kosk !22_S
51427	teineteisel	teise	teine+teise	12_P	SgAd	et	teineteisel =teise  (SgAd  >teine+teise !12_P
51428	telgidega	telgi	telg	22_S	PlKom	et	telgidega =telgi  (PlKom  >telg !22_S
51430	karjääris	karjääri	karjäär	22_S	SgIn	et	karjääris =karjääri  (SgIn  >karjäär !22_S
51434	töödejuhatajana	juhataja	tööde+juhataja	01_S	SgEs	et	töödejuhatajana =juhataja  (SgEs  >tööde+juhataja !01_S
51438	lastemänguväljak	väljak	laste+mängu+väljak	02_S	SgN	et	lastemänguväljak =väljak  (SgN  >laste+mängu+väljak !02_S
51440	videomaki	maki	video+makk	22_S	SgG	et	videomaki =maki  (SgG  >video+makk !22_S
51443	prügiämbrit	ämbri	prügi+ämber	02_S	SgP	et	prügiämbrit =ämbri  (SgP  >prügi+ämber !02_S
51452	kindlusemüürid	müüri	kindluse+müür	22_S	PlN	et	kindlusemüürid =müüri  (PlN  >kindluse+müür !22_S
51460	näitad	näita	näitama	29_V	IndPrSg2	et	näitad =näita  (IndPrSg2  >näitama !29_V
51467	kliendiga	kliendi	klient	22_S	SgKom	et	kliendiga =kliendi  (SgKom  >klient !22_S
51473	ülevaatlikud	vaatliku	üle+vaatlik	25_A	PlN	et	ülevaatlikud =vaatliku  (PlN  >üle+vaatlik !25_A
51474	nelle-liis	lii	nelle-lii	26_S	SgIn	et	nelle-liis =lii  (SgIn  >nelle-lii !26_S
51476	kodukujundamise	kujundamise	kodu+kujundamine	12_S	SgG	et	kodukujundamise =kujundamise  (SgG  >kodu+kujundamine !12_S
51477	peauudised	uudise	pea+uudis	09_S	PlN	et	peauudised =uudise  (PlN  >pea+uudis !09_S
51478	rubriigiga	rubriigi	rubriik	22_S	SgKom	et	rubriigiga =rubriigi  (SgKom  >rubriik !22_S
51491	üldisel	üldise	üldine	10~12_A	SgAd	et	üldisel =üldise  (SgAd  >üldine !10~12_A
51241	saastan	saasta	saastama	29~27_V	IndPrSg1	et	saastan =saasta  (IndPrSg1  >saastama !29~27_V
51249	arvestatakse	arvesta	arvestama	27_V	IndPrIps	et	arvestatakse =arvesta  (IndPrIps  >arvestama !27_V
51251	põlemisjäätmeid	jäätme	põlemis+jääde	05_S	PlP	et	põlemisjäätmeid =jäätme  (PlP  >põlemis+jääde !05_S
51257	maagaas	gaas	maa+gaas	22_S	SgN	et	maagaas =gaas  (SgN  >maa+gaas !22_S
51272	klaaspudelid	pudeli	klaas+pudel	02_S	PlN	et	klaaspudelid =pudeli  (PlN  >klaas+pudel !02_S
51277	maailmariigid	riigi	maa+ilma+riik	22_S	PlN	et	maailmariigid =riigi  (PlN  >maa+ilma+riik !22_S
51290	naudime	naudi	nautima	28_V	IndPrPl1	et	naudime =naudi  (IndPrPl1  >nautima !28_V
51292	mõõn	mõõn	mõõn	22_S	SgN	et	mõõn =mõõn  (SgN  >mõõn !22_S
51296	saastama	saasta	saastama	29~27_V	Sup	et	saastama =saasta  (Sup  >saastama !29~27_V
51299	kilekottidest	kotti	kile+kott	22_S	PlEl	et	kilekottidest =kotti  (PlEl  >kile+kott !22_S
51302	habet	habe	habe	04_S	SgP	et	habet =habe  (SgP  >habe !04_S
51307	pinkidel	pinki	pink	22_S	PlAd	et	pinkidel =pinki  (PlAd  >pink !22_S
51308	kamba	kamba	kamp	22_S	SgG	et	kamba =kamba  (SgG  >kamp !22_S
51338	tallinnaset	ase	tallinn+ase	04_S	SgP	et	tallinnaset =ase  (SgP  >tallinn+ase !04_S
51340	tähelepanekult	paneku	tähele+panek	02_S	SgAbl	et	tähelepanekult =paneku  (SgAbl  >tähele+panek !02_S
51345	noogutan	nooguta	noogutama	27_V	IndPrSg1	et	noogutan =nooguta  (IndPrSg1  >noogutama !27_V
51349	teguri	teguri	tegur	02_S	SgG	et	teguri =teguri  (SgG  >tegur !02_S
51355	sirvima	sirvi	sirvima	28_V	Sup	et	sirvima =sirvi  (Sup  >sirvima !28_V
51359	vanasõnas	sõna	vana+sõna	17_S	SgIn	et	vanasõnas =sõna  (SgIn  >vana+sõna !17_S
51362	tähtemad	ema	täht+ema	17_S	PlN	et	tähtemad =ema  (PlN  >täht+ema !17_S
51364	riidekaupluse	kaupluse	riide+kauplus	11~09_S	SgG	et	riidekaupluse =kaupluse  (SgG  >riide+kauplus !11~09_S
51371	pakendist	pakendi	pakend	02_S	SgEl	et	pakendist =pakendi  (SgEl  >pakend !02_S
51372	kerige	keri	kerima	27_V	ImpPrPl2	et	kerige =keri  (ImpPrPl2  >kerima !27_V
51373	sisselülitamiseks	lülitamise	sisse+lülitamine	12_S	SgTr	et	sisselülitamiseks =lülitamise  (SgTr  >sisse+lülitamine !12_S
51375	päripäeva	päripäeva	päri+päeva	41_D	ID	et	päripäeva =päripäeva  (ID  >päri+päeva !41_D
51377	sümbolile	sümboli	sümbol	02_S	SgAll	et	sümbolile =sümboli  (SgAll  >sümbol !02_S
51391	nullasendis	asendi	null+asend	02_S	SgIn	et	nullasendis =asendi  (SgIn  >null+asend !02_S
51400	sirel	sirel	sirel	02_S	SgN	et	sirel =sirel  (SgN  >sirel !02_S
51407	roheluse	roheluse	rohelus	11_S	SgG	et	roheluse =roheluse  (SgG  >rohelus !11_S
51408	koduümbris	ümbris	kodu+ümbris	09_S	SgN	et	koduümbris =ümbris  (SgN  >kodu+ümbris !09_S
51412	kunstigaleriis	galerii	kunsti+galerii	26_S	SgIn	et	kunstigaleriis =galerii  (SgIn  >kunsti+galerii !26_S
51413	raudteel	tee	raud+tee	26_S	SgAd	et	raudteel =tee  (SgAd  >raud+tee !26_S
51416	abiellusin	ellu	abi+elluma	27_V	IndIpfSg1	et	abiellusin =ellu  (IndIpfSg1  >abi+elluma !27_V
51417	kuuendas	kuuenda	kuues	02_O	SgIn	et	kuuendas =kuuenda  (SgIn  >kuues !02_O
51419	elektrijaamas	jaama	elektri+jaam	22_S	SgIn	et	elektrijaamas =jaama  (SgIn  >elektri+jaam !22_S
51424	metsesse	metse	mets	22_S	PlIll	et	metsesse =metse  (PlIll  >mets !22_S
51429	korruse	korruse	korrus	09_S	SgG	et	korruse =korruse  (SgG  >korrus !09_S
51432	suvekodus	kodu	suve+kodu	17_S	SgIn	et	suvekodus =kodu  (SgIn  >suve+kodu !17_S
51439	maki	maki	makk	22_S	SgG	et	maki =maki  (SgG  >makk !22_S
51444	õetütrega	tütre	õe+tütar	08_S	SgKom	et	õetütrega =tütre  (SgKom  >õe+tütar !08_S
51458	näitasime	näita	näitama	29_V	IndIpfPl1	et	näitasime =näita  (IndIpfPl1  >näitama !29_V
51463	turundust	turundus	turundus	11_S	SgP	et	turundust =turundus  (SgP  >turundus !11_S
51472	peauudise	uudise	pea+uudis	09_S	SgG	et	peauudise =uudise  (SgG  >pea+uudis !09_S
51486	kesksed	keskse	keskne	02_A	PlN	et	kesksed =keskse  (PlN  >keskne !02_A
51490	pealtpoolt	pealtpoolt	pealt+poolt	41_DK	ID	et	pealtpoolt =pealtpoolt  (ID  >pealt+poolt !41_DK
51492	finantsuudised	uudise	finants+uudis	09_S	PlN	et	finantsuudised =uudise  (PlN  >finants+uudis !09_S
51493	tegelastele	tegelas	tegelane	12_S	PlAll	et	tegelastele =tegelas  (PlAll  >tegelane !12_S
51501	äripäevas	päeva	äri+päev	22_S	SgIn	et	äripäevas =päeva  (SgIn  >äri+päev !22_S
51514	horisontaalsed	horisontaalse	horisontaalne	02_A	PlN	et	horisontaalsed =horisontaalse  (PlN  >horisontaalne !02_A
51520	järgmistes	järgmis	järgmine	12?10_A	PlIn	et	järgmistes =järgmis  (PlIn  >järgmine !12?10_A
51526	paiknetakse	paikne	paiknema	27_V	IndPrIps	et	paiknetakse =paikne  (IndPrIps  >paiknema !27_V
51534	veeruõhu	õhu	veeru+õhk	22_S	SgG	et	veeruõhu =õhu  (SgG  >veeru+õhk !22_S
51537	võrdluseks	võrdluse	võrdlus	11~09_S	SgTr	et	võrdluseks =võrdluse  (SgTr  >võrdlus !11~09_S
51316	optimist	optimist	optimist	22_S	SgN	et	optimist =optimist  (SgN  >optimist !22_S
51321	ümbertöötlemisele	töötlemise	ümber+töötlemine	12_S	SgAll	et	ümbertöötlemisele =töötlemise  (SgAll  >ümber+töötlemine !12_S
51323	lisavett	ve	lisa+vesi	15_S	SgP	et	lisavett =ve  (SgP  >lisa+vesi !15_S
51326	maaelanikust	elaniku	maa+elanik	25_S	SgEl	et	maaelanikust =elaniku  (SgEl  >maa+elanik !25_S
51327	eeldada	eelda	eeldama	27_V	Inf	et	eeldada =eelda  (Inf  >eeldama !27_V
51329	teenistuses	teenistuse	teenistus	11_S	SgIn	et	teenistuses =teenistuse  (SgIn  >teenistus !11_S
51335	pärineda	pärine	pärinema	27_V	Inf	et	pärineda =pärine  (Inf  >pärinema !27_V
51339	algud	algu	alg	22_S	PlN	et	algud =algu  (PlN  >alg !22_S
51350	22aastat	aasta	aasta	01_S	SgP	et	aastat =aasta  (SgP  >aasta !01_S
51363	eluse	eluse	elus	02_A	SgG	et	eluse =eluse  (SgG  >elus !02_A
51367	laheneb	lahene	lahenema	27_V	IndPrSg3	et	laheneb =lahene  (IndPrSg3  >lahenema !27_V
51368	kaotad	kaota	kaotama	27_V	IndPrSg2	et	kaotad =kaota  (IndPrSg2  >kaotama !27_V
51374	lülitit	lüliti	lüliti	01_S	SgP	et	lülitit =lüliti  (SgP  >lüliti !01_S
51376	tiiviku	tiiviku	tiivik	02_S	SgG	et	tiiviku =tiiviku  (SgG  >tiivik !02_S
51379	paigaldage	paigalda	paigaldama	27_V	ImpPrPl2	et	paigaldage =paigalda  (ImpPrPl2  >paigaldama !27_V
51383	taldrikul	taldriku	taldrik	02_S	SgAd	et	taldrikul =taldriku  (SgAd  >taldrik !02_S
51387	asutage	asuta	asutama	27_V	ImpPrPl2	et	asutage =asuta  (ImpPrPl2  >asutama !27_V
51389	häälestage	häälesta	häälestama	27_V	ImpPrPl2	et	häälestage =häälesta  (ImpPrPl2  >häälestama !27_V
51390	teleprogrammid	programmi	tele+programm	22_S	PlN	et	teleprogrammid =programmi  (PlN  >tele+programm !22_S
51395	lülitage	lülita	lülitama	27_V	ImpPrPl2	et	lülitage =lülita  (ImpPrPl2  >lülitama !27_V
51399	toominga	toominga	toomingas	02_S	SgG	et	toominga =toominga  (SgG  >toomingas !02_S
51404	ajaloomuuseum	muuseum	aja+loo+muuseum	19~02_S	SgN	et	ajaloomuuseum =muuseum  (SgN  >aja+loo+muuseum !19~02_S
51410	lasteaeg	aeg	laste+aeg	22_S	SgN	et	lasteaeg =aeg  (SgN  >laste+aeg !22_S
51411	korjan	korja	korjama	29_V	IndPrSg1	et	korjan =korja  (IndPrSg1  >korjama !29_V
51418	kontrolörina	kontrolöri	kontrolör	19_S	SgEs	et	kontrolörina =kontrolöri  (SgEs  >kontrolör !19_S
51426	pimeaed	aed	pime+aed	22_S	SgN	et	pimeaed =aed  (SgN  >pime+aed !22_S
51433	üürikorter	korter	üüri+korter	02_S	SgN	et	üürikorter =korter  (SgN  >üüri+korter !02_S
51436	tantsuõhtul	õhtu	tantsu+õhtu	01_S	SgAd	et	tantsuõhtul =õhtu  (SgAd  >tantsu+õhtu !01_S
51445	suvemajas	maja	suve+maja	17_S	SgIn	et	suvemajas =maja  (SgIn  >suve+maja !17_S
51448	narva-jõesuhu	su	narva-jõe+suu	26_S	SgAdt	et	narva-jõesuhu =su  (SgAdt  >narva-jõe+suu !26_S
51449	kurde-eestis	eesti	kurde-eesti	16_H	SgIn	et	kurde-eestis =eesti  (SgIn  >kurde-eesti !16_H
51453	käisite	käi	käima	38_V	IndIpfPl2	et	käisite =käi  (IndIpfPl2  >käima !38_V
51454	elusat	elusa	elus	02_A	SgP	et	elusat =elusa  (SgP  >elus !02_A
51456	onutütar	tütar	onu+tütar	08_S	SgN	et	onutütar =tütar  (SgN  >onu+tütar !08_S
51461	tööhõiveamet	amet	töö+hõive+amet	02_S	SgN	et	tööhõiveamet =amet  (SgN  >töö+hõive+amet !02_S
51462	kursusteid	te	kursus+tee	26_S	PlP	et	kursusteid =te  (PlP  >kursus+tee !26_S
51465	sekretäril	sekretäri	sekretär	19_S	SgAd	et	sekretäril =sekretäri  (SgAd  >sekretär !19_S
51466	dokumentidega	dokumenti	dokument	22_S	PlKom	et	dokumentidega =dokumenti  (PlKom  >dokument !22_S
51469	16märts	märts	märts	22_S	SgN	et	märts =märts  (SgN  >märts !22_S
51470	turvamehe	mehe	turva+mees	13_S	SgG	et	turvamehe =mehe  (SgG  >turva+mees !13_S
51480	illustratsioon	illustratsioon	illustratsioon	22_S	SgN	et	illustratsioon =illustratsioon  (SgN  >illustratsioon !22_S
51484	rasvakiri	kiri	rasva+kiri	24_S	SgN	et	rasvakiri =kiri  (SgN  >rasva+kiri !24_S
51495	börs	börs	börs	22_S	SgN	et	börs =börs  (SgN  >börs !22_S
51497	indeksid	indeksi	indeks	02_S	PlN	et	indeksid =indeksi  (PlN  >indeks !02_S
51498	fondid	fondi	fond	22_S	PlN	et	fondid =fondi  (PlN  >fond !22_S
51516	äripäevaga	päeva	äri+päev	22_S	SgKom	et	äripäevaga =päeva  (SgKom  >äri+päev !22_S
51519	hinnangust	hinnangu	hinnang	02_S	SgEl	et	hinnangust =hinnangu  (SgEl  >hinnang !02_S
51522	eelloendanud	loendanu	eel+loendanu	01_S	PlN	et	eelloendanud =loendanu  (PlN  >eel+loendanu !01_S
51524	15st	st	st	41_I	ID	et	st =st  (ID  >st !41_I
51525	üldmustade	musta	üld+must	22_AS	PlG	et	üldmustade =musta  (PlG  >üld+must !22_AS
51530	põhimõttes	mõtte	põhi+mõte	06_S	SgIn	et	põhimõttes =mõtte  (SgIn  >põhi+mõte !06_S
51535	ajalehekujunduse	kujunduse	aja+lehe+kujundus	11_S	SgG	et	ajalehekujunduse =kujunduse  (SgG  >aja+lehe+kujundus !11_S
51536	kompetentne	kompetentne	kompetentne	02_A	SgN	et	kompetentne =kompetentne  (SgN  >kompetentne !02_A
51332	geen	geen	geen	22_S	SgN	et	geen =geen  (SgN  >geen !22_S
51334	tundidega	tundi	tund	22_S	PlKom	et	tundidega =tundi  (PlKom  >tund !22_S
51347	siirutab	siiruta	siirutama	27_V	IndPrSg3	et	siirutab =siiruta  (IndPrSg3  >siirutama !27_V
51357	asjaolutest	test	asja+olu+test	22_S	SgN	et	asjaolutest =test  (SgN  >asja+olu+test !22_S
51358	nakatun	nakatu	nakatuma	27_V	IndPrSg1	et	nakatun =nakatu  (IndPrSg1  >nakatuma !27_V
51366	muheleb	muhele	muhelema	31~27_V	IndPrSg3	et	muheleb =muhele  (IndPrSg3  >muhelema !31~27_V
51384	ahjusse	ahju	ahi	24_S	SgIll	et	ahjusse =ahju  (SgIll  >ahi !24_S
51394	kohvikeetjasse	keetja	kohvi+keetja	01_S	SgIll	et	kohvikeetjasse =keetja  (SgIll  >kohvi+keetja !01_S
51398	narva-jõesusse	susse	narva-jõe+suss	22_S	PlP	et	narva-jõesusse =susse  (PlP  >narva-jõe+suss !22_S
51401	juubeleid	juubele	juubel	02_S	PlP	et	juubeleid =juubele  (PlP  >juubel !02_S
51405	pereliikmes	liikme	pere+liige	05_S	SgIn	et	pereliikmes =liikme  (SgIn  >pere+liige !05_S
51409	bastionid	bastioni	bastion	19~02_S	PlN	et	bastionid =bastioni  (PlN  >bastion !19~02_S
51423	istutan	istuta	istutama	27_V	IndPrSg1	et	istutan =istuta  (IndPrSg1  >istutama !27_V
51431	vabrikus	vabriku	vabrik	02_S	SgIn	et	vabrikus =vabriku  (SgIn  >vabrik !02_S
51437	tolliamet	amet	tolli+amet	02_S	SgN	et	tolliamet =amet  (SgN  >tolli+amet !02_S
51450	lahedata	laheda	lahe	02_A	SgAb	et	lahedata =laheda  (SgAb  >lahe !02_A
51451	arhitektuurimälestisi	mälestisi	arhitektuuri+mälestis	11_S	PlP	et	arhitektuurimälestisi =mälestisi  (PlP  >arhitektuuri+mälestis !11_S
51455	orelimuusikat	muusika	oreli+muusika	01_S	SgP	et	orelimuusikat =muusika  (SgP  >oreli+muusika !01_S
51457	kunstigaaleriis	riis	kunst+iga+ale+riis	22_S	SgN	et	kunstigaaleriis =riis  (SgN  >kunst+iga+ale+riis !22_S
51468	õhtuleht	leht	õhtu+leht	22_S	SgN	et	õhtuleht =leht  (SgN  >õhtu+leht !22_S
51471	miskipärast	miskipärast	miski+pärast	41_D	ID	et	miskipärast =miskipärast  (ID  >miski+pärast !41_D
51479	lülitub	lülitu	lülituma	27_V	IndPrSg3	et	lülitub =lülitu  (IndPrSg3  >lülituma !27_V
51481	veerg	veerg	veerg	22_S	SgN	et	veerg =veerg  (SgN  >veerg !22_S
51482	illustratsioonist	illustratsiooni	illustratsioon	22_S	SgEl	et	illustratsioonist =illustratsiooni  (SgEl  >illustratsioon !22_S
51488	määrdub	määrdu	määrduma	27_V	IndPrSg3	et	määrdub =määrdu  (IndPrSg3  >määrduma !27_V
51489	hierarhiale	hierarhia	hierarhia	01_S	SgAll	et	hierarhiale =hierarhia  (SgAll  >hierarhia !01_S
51500	uudisasjadest	asja	uudis+asi	24_S	PlEl	et	uudisasjadest =asja  (PlEl  >uudis+asi !24_S
51502	õhtulehes	lehe	õhtu+leht	22_S	SgIn	et	õhtulehes =lehe  (SgIn  >õhtu+leht !22_S
51503	illustratsioonides	illustratsiooni	illustratsioon	22_S	PlIn	et	illustratsioonides =illustratsiooni  (PlIn  >illustratsioon !22_S
51504	kirjastiilid	stiili	kirja+stiil	22_S	PlN	et	kirjastiilid =stiili  (PlN  >kirja+stiil !22_S
51512	siluett	siluett	siluett	22_S	SgN	et	siluett =siluett  (SgN  >siluett !22_S
51515	vertikaalsed	vertikaalse	vertikaalne	02_A	PlN	et	vertikaalsed =vertikaalse  (PlN  >vertikaalne !02_A
51518	21märts	märts	märts	22_S	SgN	et	märts =märts  (SgN  >märts !22_S
51527	paksudega	paksu	paks	22_AS	PlKom	et	paksudega =paksu  (PlKom  >paks !22_AS
51528	silmatorkavad	torkava	silma+torkav	02_A	PlN	et	silmatorkavad =torkava  (PlN  >silma+torkav !02_A
51541	osakondadeks	osakonda	osakond	22_S	PlTr	et	osakondadeks =osakonda  (PlTr  >osakond !22_S
51542	reklaamileheküljed	külje	reklaami+lehe+külg	22_S	PlN	et	reklaamileheküljed =külje  (PlN  >reklaami+lehe+külg !22_S
51543	materjaliga	materjali	materjal	19_S	SgKom	et	materjaliga =materjali  (SgKom  >materjal !19_S
51554	vertikaalne	vertikaalne	vertikaalne	02_A	SgN	et	vertikaalne =vertikaalne  (SgN  >vertikaalne !02_A
51557	kultuuritekstid	teksti	kultuuri+tekst	22_S	PlN	et	kultuuritekstid =teksti  (PlN  >kultuuri+tekst !22_S
51565	päismikes	mike	päis+mikk	22_S	PlIn	et	päismikes =mike  (PlIn  >päis+mikk !22_S
51575	pealiskaudse	kaudse	pealis+kaudne	02_A	SgG	et	pealiskaudse =kaudse  (SgG  >pealis+kaudne !02_A
51596	numbrist	numbri	number	02_S	SgEl	et	numbrist =numbri  (SgEl  >number !02_S
51598	mõjur	mõjur	mõjur	02_S	SgN	et	mõjur =mõjur  (SgN  >mõjur !02_S
51603	tiiteltähe	tähe	tiitel+täht	22_S	SgG	et	tiiteltähe =tähe  (SgG  >tiitel+täht !22_S
51610	joonega	joone	joon	13_S	SgKom	et	joonega =joone  (SgKom  >joon !13_S
51618	peategelasi	tegelasi	pea+tegelane	12_S	PlP	et	peategelasi =tegelasi  (PlP  >pea+tegelane !12_S
51621	siluett-fotosid	foto	siluett-foto	16_S	PlP	et	siluett-fotosid =foto  (PlP  >siluett-foto !16_S
51623	asendiga	asendi	asend	02_S	SgKom	et	asendiga =asendi  (SgKom  >asend !02_S
51637	üks-	üks	üks	22_NP	SgN	et	üks- =üks  (SgN  >üks !22_NP
51639	teine-	teine	teine	12_OP	SgN	et	teine- =teine  (SgN  >teine !12_OP
51650	koondada	koonda	koondama	27_V	Inf	et	koondada =koonda  (Inf  >koondama !27_V
51651	staatilised	staatilise	staatiline	12_A	PlN	et	staatilised =staatilise  (PlN  >staatiline !12_A
51337	eestissest	tisse	ees+tiss	22_S	PlEl	et	eestissest =tisse  (PlEl  >ees+tiss !22_S
51342	käitun	käitu	käituma	27_V	IndPrSg1	et	käitun =käitu  (IndPrSg1  >käituma !27_V
51343	tagakaas	kaas	taga+kaas	14_S	SgN	et	tagakaas =kaas  (SgN  >taga+kaas !14_S
51344	loomingeist	loominge	looming	02_S	PlEl	et	loomingeist =loominge  (PlEl  >looming !02_S
51346	temaks	tema	tema	00_P	SgTr	et	temaks =tema  (SgTr  >tema !00_P
51348	tähtkujusse	kuju	täht+kuju	17_S	SgIll	et	tähtkujusse =kuju  (SgIll  >täht+kuju !17_S
51352	puudujääk	jääk	puudu+jääk	22_S	SgN	et	puudujääk =jääk  (SgN  >puudu+jääk !22_S
51353	tekkin	tekki	tekkima	27_V	IndPrSg1	et	tekkin =tekki  (IndPrSg1  >tekkima !27_V
51354	heidan	heida	heitma	34_V	IndPrSg1	et	heidan =heida  (IndPrSg1  >heitma !34_V
51356	puudujakk	jakk	puudu+jakk	22_S	SgN	et	puudujakk =jakk  (SgN  >puudu+jakk !22_S
51361	tegused	teguse	tegus	02_A	PlN	et	tegused =teguse  (PlN  >tegus !02_A
51365	perekonnanimest	nime	pere+konna+nimi	20_S	SgEl	et	perekonnanimest =nime  (SgEl  >pere+konna+nimi !20_S
51378	puhurit	puhuri	puhur	02_S	SgP	et	puhurit =puhuri  (SgP  >puhur !02_S
51386	grill	grill	grill	22_S	SgN	et	grill =grill  (SgN  >grill !22_S
51397	kursussell	sell	kursus+sell	22_S	SgN	et	kursussell =sell  (SgN  >kursus+sell !22_S
51406	küpsetada	küpseta	küpsetama	27_V	Inf	et	küpsetada =küpseta  (Inf  >küpsetama !27_V
51415	kirde-eestis	eesti	kirde-eesti	16_H	SgIn	et	kirde-eestis =eesti  (SgIn  >kirde-eesti !16_H
51420	hambakliinik	kliinik	hamba+kliinik	02_S	SgN	et	hambakliinik =kliinik  (SgN  >hamba+kliinik !02_S
51421	pimeaeg	aeg	pime+aeg	22_S	SgN	et	pimeaeg =aeg  (SgN  >pime+aeg !22_S
51422	saksaliiv	liiv	saksa+liiv	22_S	SgN	et	saksaliiv =liiv  (SgN  >saksa+liiv !22_S
51435	lemmiktegevis	tegevi	lemmik+tegev	02_A	SgIn	et	lemmiktegevis =tegevi  (SgIn  >lemmik+tegev !02_A
51441	remondib	remondi	remontima	28_V	IndPrSg3	et	remondib =remondi  (IndPrSg3  >remontima !28_V
51442	klopib	klopi	kloppima	28_V	IndPrSg3	et	klopib =klopi  (IndPrSg3  >kloppima !28_V
51446	suvilat	suvila	suvila	01_S	SgP	et	suvilat =suvila  (SgP  >suvila !01_S
51447	nurgal	nurga	nurk	22_S	SgAd	et	nurgal =nurga  (SgAd  >nurk !22_S
51459	sugulasega	sugulase	sugulane	12_S	SgKom	et	sugulasega =sugulase  (SgKom  >sugulane !12_S
51464	arvutiõpetust	õpetus	arvuti+õpetus	11_S	SgP	et	arvutiõpetust =õpetus  (SgP  >arvuti+õpetus !11_S
51475	rubriigis	rubriigi	rubriik	22_S	SgIn	et	rubriigis =rubriigi  (SgIn  >rubriik !22_S
51483	ribaks	riba	riba	17_S	SgTr	et	ribaks =riba  (SgTr  >riba !17_S
51485	toimetada	toimeta	toimetama	27_V	Inf	et	toimetada =toimeta  (Inf  >toimetama !27_V
51487	illustratsioone	illustratsioone	illustratsioon	22_S	PlP	et	illustratsioone =illustratsioone  (PlP  >illustratsioon !22_S
51496	börsid	börsi	börs	22_S	PlN	et	börsid =börsi  (PlN  >börs !22_S
51499	valuutakursid	kursi	valuuta+kurss	22_S	PlN	et	valuutakursid =kursi  (PlN  >valuuta+kurss !22_S
51508	lisand	lisand	lisand	02_S	SgN	et	lisand =lisand  (SgN  >lisand !02_S
51509	äristiil	stiil	äri+stiil	22_S	SgN	et	äristiil =stiil  (SgN  >äri+stiil !22_S
51510	illustratsioone-	illustratsioone	illustratsioon	22_S	PlP	et	illustratsioone- =illustratsioone  (PlP  >illustratsioon !22_S
51511	graafikat	graafika	graafika	01_S	SgP	et	graafikat =graafika  (SgP  >graafika !01_S
51517	ajalehestiil	stiil	aja+lehe+stiil	22_S	SgN	et	ajalehestiil =stiil  (SgN  >aja+lehe+stiil !22_S
51521	väljaandmistes	andmis	välja+andmine	12?10_S	PlIn	et	väljaandmistes =andmis  (PlIn  >välja+andmine !12?10_S
51523	reklaamile	reklaami	reklaam	22_S	SgAll	et	reklaamile =reklaami  (SgAll  >reklaam !22_S
51531	numbrilt	numbri	number	02_S	SgAbl	et	numbrilt =numbri  (SgAbl  >number !02_S
51533	vaimustada	vaimusta	vaimustama	27_V	Inf	et	vaimustada =vaimusta  (Inf  >vaimustama !27_V
51538	õhtulehe	lehe	õhtu+leht	22_S	SgG	et	õhtulehe =lehe  (SgG  >õhtu+leht !22_S
51547	nädalalõpulisas	lisa	nädala+lõpu+lisa	17_S	SgIn	et	nädalalõpulisas =lisa  (SgIn  >nädala+lõpu+lisa !17_S
51552	börsiinfot	info	börsi+info	16_S	SgP	et	börsiinfot =info  (SgP  >börsi+info !16_S
51556	kultuuritekste	tekste	kultuuri+tekst	22_S	PlP	et	kultuuritekste =tekste  (PlP  >kultuuri+tekst !22_S
51573	sirvib	sirvi	sirvima	28_V	IndPrSg3	et	sirvib =sirvi  (IndPrSg3  >sirvima !28_V
51577	ühetähenduslik	tähenduslik	ühe+tähenduslik	25_A	SgN	et	ühetähenduslik =tähenduslik  (SgN  >ühe+tähenduslik !25_A
51580	kaksikleheküljed	külje	kaksik+lehe+külg	22_S	PlN	et	kaksikleheküljed =külje  (PlN  >kaksik+lehe+külg !22_S
51583	eristub	eristu	eristuma	27_V	IndPrSg3	et	eristub =eristu  (IndPrSg3  >eristuma !27_V
51588	sissepoole	sissepoole	sisse+poole	41_DK	ID	et	sissepoole =sissepoole  (ID  >sisse+poole !41_DK
51589	kaksiklehekülg	külg	kaksik+lehe+külg	22_S	SgN	et	kaksiklehekülg =külg  (SgN  >kaksik+lehe+külg !22_S
51594	välisservadesse	serva	välis+serv	22_S	PlIll	et	välisservadesse =serva  (PlIll  >välis+serv !22_S
51494	peauudiste	uudis	pea+uudis	09_S	PlG	et	peauudiste =uudis  (PlG  >pea+uudis !09_S
51505	informatiivsed	informatiivse	informatiivne	02_A	PlN	et	informatiivsed =informatiivse  (PlN  >informatiivne !02_A
51506	ärile	äri	äri	17_S	SgAll	et	ärile =äri  (SgAll  >äri !17_S
51507	paberivärv	värv	paberi+värv	22_S	SgN	et	paberivärv =värv  (SgN  >paberi+värv !22_S
51513	varieerib	varieeri	varieerima	28_V	IndPrSg3	et	varieerib =varieeri  (IndPrSg3  >varieerima !28_V
51529	köidavad	köida	köitma	34_V	IndPrPl3	et	köidavad =köida  (IndPrPl3  >köitma !34_V
51532	õhtulehel	lehe	õhtu+leht	22_S	SgAd	et	õhtulehel =lehe  (SgAd  >õhtu+leht !22_S
51540	artiklireklaamid	reklaami	artikli+reklaam	22_S	PlN	et	artiklireklaamid =reklaami  (PlN  >artikli+reklaam !22_S
51544	telekavad	kava	tele+kava	17_S	PlN	et	telekavad =kava  (PlN  >tele+kava !17_S
51546	kaksikleheküljele	külje	kaksik+lehe+külg	22_S	SgAll	et	kaksikleheküljele =külje  (SgAll  >kaksik+lehe+külg !22_S
51548	kõvade	kõva	kõva	17_A	PlG	et	kõvade =kõva  (PlG  >kõva !17_A
51551	veergudesse	veergu	veerg	22_S	PlIll	et	veergudesse =veergu  (PlIll  >veerg !22_S
51559	siluett-fotod	foto	siluett-foto	16_S	PlN	et	siluett-fotod =foto  (PlN  >siluett-foto !16_S
51560	statistikat	statistika	statistika	01_S	SgP	et	statistikat =statistika  (SgP  >statistika !01_S
51562	vertikaalset	vertikaalse	vertikaalne	02_A	SgP	et	vertikaalset =vertikaalse  (SgP  >vertikaalne !02_A
51567	kujunduselemendid	elemendi	kujundus+element	22_S	PlN	et	kujunduselemendid =elemendi  (PlN  >kujundus+element !22_S
51569	elementideks	elementi	element	22_S	PlTr	et	elementideks =elementi  (PlTr  >element !22_S
51571	kuupäevarea	rea	kuu+päeva+rida	18_S	SgG	et	kuupäevarea =rea  (SgG  >kuu+päeva+rida !18_S
51576	lehekujundus	kujundus	lehe+kujundus	11_S	SgN	et	lehekujundus =kujundus  (SgN  >lehe+kujundus !11_S
51578	esikülje	külje	esi+külg	22_S	SgG	et	esikülje =külje  (SgG  >esi+külg !22_S
51579	esiküljed	külje	esi+külg	22_S	PlN	et	esiküljed =külje  (PlN  >esi+külg !22_S
51582	numbril	numbri	number	02_S	SgAd	et	numbril =numbri  (SgAd  >number !02_S
51584	numbrite	numbri	number	02_S	PlG	et	numbrite =numbri  (PlG  >number !02_S
51586	foonil	fooni	foon	22_S	SgAd	et	foonil =fooni  (SgAd  >foon !22_S
51590	jätkukoht	koht	jätku+koht	22_S	SgN	et	jätkukoht =koht  (SgN  >jätku+koht !22_S
51601	tiiteltäht	täht	tiitel+täht	22_S	SgN	et	tiiteltäht =täht  (SgN  >tiitel+täht !22_S
51606	kirjatekst	tekst	kirja+tekst	22_S	SgN	et	kirjatekst =tekst  (SgN  >kirja+tekst !22_S
51607	intervjuudes	intervjuu	intervjuu	26_S	PlIn	et	intervjuudes =intervjuu  (PlIn  >intervjuu !26_S
51624	plokis	ploki	plokk	22_S	SgIn	et	plokis =ploki  (SgIn  >plokk !22_S
51628	kapslis	kapsli	kapsel	02_S	SgIn	et	kapslis =kapsli  (SgIn  >kapsel !02_S
51634	soojal	sooja	soe	24_AS	SgAd	et	soojal =sooja  (SgAd  >soe !24_AS
51640	ribas	riba	riba	17_S	SgIn	et	ribas =riba  (SgIn  >riba !17_S
51643	äriga	äri	äri	17_S	SgKom	et	äriga =äri  (SgKom  >äri !17_S
51644	ribal	riba	riba	17_S	SgAd	et	ribal =riba  (SgAd  >riba !17_S
51647	vaatlus	vaatlus	vaatlus	11~09_S	SgN	et	vaatlus =vaatlus  (SgN  >vaatlus !11~09_S
51659	õhtulehed	lehe	õhtu+leht	22_S	PlN	et	õhtulehed =lehe  (PlN  >õhtu+leht !22_S
51661	värve	värve	värv	22_S	PlP	et	värve =värve  (PlP  >värv !22_S
51664	õhtuajalehes	lehe	õhtu+aja+leht	22_S	SgIn	et	õhtuajalehes =lehe  (SgIn  >õhtu+aja+leht !22_S
51677	koomiksid	koomiksi	koomiks	02_S	PlN	et	koomiksid =koomiksi  (PlN  >koomiks !02_S
51682	rubriikidesse	rubriiki	rubriik	22_S	PlIll	et	rubriikidesse =rubriiki  (PlIll  >rubriik !22_S
51685	paraja	paraja	paras	02_A	SgG	et	paraja =paraja  (SgG  >paras !02_A
51688	hinnataseme	taseme	hinna+tase	04_S	SgG	et	hinnataseme =taseme  (SgG  >hinna+tase !04_S
51691	esiletõstmisviisid	viisi	esile+tõstmis+viis	22_S	PlN	et	esiletõstmisviisid =viisi  (PlN  >esile+tõstmis+viis !22_S
51696	veerge	veerge	veerg	22_S	PlP	et	veerge =veerge  (PlP  >veerg !22_S
51700	resümeedega	resümee	resümee	26_S	PlKom	et	resümeedega =resümee  (PlKom  >resümee !26_S
51701	kaksikleheküljeks	külje	kaksik+lehe+külg	22_S	SgTr	et	kaksikleheküljeks =külje  (SgTr  >kaksik+lehe+külg !22_S
51703	uudisele	uudise	uudis	09_S	SgAll	et	uudisele =uudise  (SgAll  >uudis !09_S
51705	tuvastas	tuvasta	tuvastama	27_V	IndIpfSg3	et	tuvastas =tuvasta  (IndIpfSg3  >tuvastama !27_V
51708	murdejoon	joon	murde+joon	13_S	SgN	et	murdejoon =joon  (SgN  >murde+joon !13_S
51713	grupifotodeks	foto	grupi+foto	16_S	PlTr	et	grupifotodeks =foto  (PlTr  >grupi+foto !16_S
51718	emotsionaalseteks	emotsionaalse	emotsionaalne	02_A	PlTr	et	emotsionaalseteks =emotsionaalse  (PlTr  >emotsionaalne !02_A
51719	numbrites	numbri	number	02_S	PlIn	et	numbrites =numbri  (PlIn  >number !02_S
51720	vertikaalses	vertikaalse	vertikaalne	02_A	SgIn	et	vertikaalses =vertikaalse  (SgIn  >vertikaalne !02_A
51539	vanune	vanune	vanune	10_A	SgN	et	vanune =vanune  (SgN  >vanune !10_A
51553	pension	pension	pension	19~02_S	SgN	et	pension =pension  (SgN  >pension !19~02_S
51558	lugudele	lugu	lugu	18_S	PlAll	et	lugudele =lugu  (PlAll  >lugu !18_S
51561	horisontaalset	horisontaalse	horisontaalne	02_A	SgP	et	horisontaalset =horisontaalse  (SgP  >horisontaalne !02_A
51574	leheküljes	külje	lehe+külg	22_S	SgIn	et	leheküljes =külje  (SgIn  >lehe+külg !22_S
51581	esikülg	külg	esi+külg	22_S	SgN	et	esikülg =külg  (SgN  >esi+külg !22_S
51587	samale	sama	sama	17_P	SgAll	et	samale =sama  (SgAll  >sama !17_P
51591	jätkukohtades	kohta	jätku+koht	22_S	PlIn	et	jätkukohtades =kohta  (PlIn  >jätku+koht !22_S
51593	elemendile	elemendi	element	22_S	SgAll	et	elemendile =elemendi  (SgAll  >element !22_S
51595	uudistel	uudis	uudis	09_S	PlAd	et	uudistel =uudis  (PlAd  >uudis !09_S
51602	lugudes	lugu	lugu	18_S	PlIn	et	lugudes =lugu  (PlIn  >lugu !18_S
51604	ridu	ridu	rida	18_S	PlP	et	ridu =ridu  (PlP  >rida !18_S
51609	horisontaalse	horisontaalse	horisontaalne	02_A	SgG	et	horisontaalse =horisontaalse  (SgG  >horisontaalne !02_A
51612	kasutamiskõlblikud	kõlbliku	kasutamis+kõlblik	25_A	PlN	et	kasutamiskõlblikud =kõlbliku  (PlN  >kasutamis+kõlblik !25_A
51614	dünaamilised	dünaamilise	dünaamiline	12_A	PlN	et	dünaamilised =dünaamilise  (PlN  >dünaamiline !12_A
51617	sõlm-momente	momente	sõlm-moment	22_S	PlP	et	sõlm-momente =momente  (PlP  >sõlm-moment !22_S
51619	tegutsemas	tegutse	tegutsema	27_V	SupIn	et	tegutsemas =tegutse  (SupIn  >tegutsema !27_V
51620	fotodega	foto	foto	16_S	PlKom	et	fotodega =foto  (PlKom  >foto !16_S
51625	fotoallikad	allika	foto+allikas	02_S	PlN	et	fotoallikad =allika  (PlN  >foto+allikas !02_S
51626	siluett-fotol	foto	siluett-foto	16_S	SgAd	et	siluett-fotol =foto  (SgAd  >siluett-foto !16_S
51629	juuresolevat	oleva	juures+olev	02_A	SgP	et	juuresolevat =oleva  (SgP  >juures+olev !02_A
51631	trükivead	vea	trüki+viga	18_S	PlN	et	trükivead =vea  (PlN  >trüki+viga !18_S
51635	sõlm-momendi	momendi	sõlm-moment	22_S	SgG	et	sõlm-momendi =momendi  (SgG  >sõlm-moment !22_S
51642	köidab	köida	köitma	34_V	IndPrSg3	et	köidab =köida  (IndPrSg3  >köitma !34_V
51648	allosad	osa	all+osa	17_S	PlN	et	allosad =osa  (PlN  >all+osa !17_S
51655	diagrammide	diagrammi	diagramm	22_S	PlG	et	diagrammide =diagrammi  (PlG  >diagramm !22_S
51660	vihjetelefon	telefon	vihje+telefon	19_S	SgN	et	vihjetelefon =telefon  (SgN  >vihje+telefon !19_S
51662	õhtuajaleht	leht	õhtu+aja+leht	22_S	SgN	et	õhtuajaleht =leht  (SgN  >õhtu+aja+leht !22_S
51672	lehitseda	lehitse	lehitsema	27_V	Inf	et	lehitseda =lehitse  (Inf  >lehitsema !27_V
51676	pooleldi	pooleldi	pooleldi	41_D	ID	et	pooleldi =pooleldi  (ID  >pooleldi !41_D
51681	vahelehed	lehe	vahe+leht	22_S	PlN	et	vahelehed =lehe  (PlN  >vahe+leht !22_S
51683	vastuvõetavasse	võetava	vastu+võetav	02_A	SgIll	et	vastuvõetavasse =võetava  (SgIll  >vastu+võetav !02_A
51684	tekstikiri	kiri	teksti+kiri	24_S	SgN	et	tekstikiri =kiri  (SgN  >teksti+kiri !24_S
51686	värv-	värv	värv	22_S	SgN	et	värv- =värv  (SgN  >värv !22_S
51690	paemaks	maks	pae+maks	22_S	SgN	et	paemaks =maks  (SgN  >pae+maks !22_S
51695	võõrsõõnu	sõõnu	võõr+sõõn	22_S	PlP	et	võõrsõõnu =sõõnu  (PlP  >võõr+sõõn !22_S
51707	polt	polt	polt	22_S	SgN	et	polt =polt  (SgN  >polt !22_S
51715	jalgpallimeeskond	meeskond	jalg+palli+meeskond	22_S	SgN	et	jalgpallimeeskond =meeskond  (SgN  >jalg+palli+meeskond !22_S
51723	ümmarguseks	ümmarguse	ümmargune	12_A	SgTr	et	ümmarguseks =ümmarguse  (SgTr  >ümmargune !12_A
51731	üleliigset	liigse	üle+liigne	02_A	SgP	et	üleliigset =liigse  (SgP  >üle+liigne !02_A
51732	täiusliku	täiusliku	täiuslik	25_A	SgG	et	täiusliku =täiusliku  (SgG  >täiuslik !25_A
51733	vanimatest	vani	vana	17_AS	IM_sA	et	"vanim %vani  )IM_sA  <vana ;17_AS
51735	semestriks	semestri	semester	02_S	SgTr	et	semestriks =semestri  (SgTr  >semester !02_S
51740	morfoloogiat	morfoloogia	morfoloogia	01_S	SgP	et	morfoloogiat =morfoloogia  (SgP  >morfoloogia !01_S
51749	võlub	võlu	võluma	27_V	IndPrSg3	et	võlub =võlu  (IndPrSg3  >võluma !27_V
51752	piiridel	piiri	piir	22_S	PlAd	et	piiridel =piiri  (PlAd  >piir !22_S
51755	modernne	modernne	modernne	02_A	SgN	et	modernne =modernne  (SgN  >modernne !02_A
51761	jaksan	jaksa	jaksama	29_V	IndPrSg1	et	jaksan =jaksa  (IndPrSg1  >jaksama !29_V
51762	koplita	kopli	koppel	02_S	SgAb	et	koplita =kopli  (SgAb  >koppel !02_S
51763	naeratan	naerata	naeratama	27_V	IndPrSg1	et	naeratan =naerata  (IndPrSg1  >naeratama !27_V
51772	tüdrukult	tüdruku	tüdruk	02_S	SgAbl	et	tüdrukult =tüdruku  (SgAbl  >tüdruk !02_S
51776	eitohtinud	tohtinu	ei+tohtinu	01_S	PlN	et	eitohtinud =tohtinu  (PlN  >ei+tohtinu !01_S
51779	seesamaks	seesama	seesam	02_S	SgTr	et	seesamaks =seesama  (SgTr  >seesam !02_S
51545	keskmisele	keskmise	keskmine	12?10_A	SgAll	et	keskmisele =keskmise  (SgAll  >keskmine !12?10_A
51549	lühiuudised	uudise	lühi+uudis	09_S	PlN	et	lühiuudised =uudise  (PlN  >lühi+uudis !09_S
51550	välimistes	välimis	välimine	12_A	PlIn	et	välimistes =välimis  (PlIn  >välimine !12_A
51555	kultuuriosakond	osakond	kultuuri+osakond	22_S	SgN	et	kultuuriosakond =osakond  (SgN  >kultuuri+osakond !22_S
51563	äratuntavaks	tuntava	ära+tuntav	02_A	SgTr	et	äratuntavaks =tuntava  (SgTr  >ära+tuntav !02_A
51564	trükikirjad	kirja	trüki+kiri	24_S	PlN	et	trükikirjad =kirja  (PlN  >trüki+kiri !24_S
51566	horisontaalne	horisontaalne	horisontaalne	02_A	SgN	et	horisontaalne =horisontaalne  (SgN  >horisontaalne !02_A
51568	püsiosaks	osa	püsi+osa	17_S	SgTr	et	püsiosaks =osa  (SgTr  >püsi+osa !17_S
51570	püsiosad	osa	püsi+osa	17_S	PlN	et	püsiosad =osa  (PlN  >püsi+osa !17_S
51572	servale	serva	serv	22_S	SgAll	et	servale =serva  (SgAll  >serv !22_S
51585	esilehed	lehe	esi+leht	22_S	PlN	et	esilehed =lehe  (PlN  >esi+leht !22_S
51592	parempoolse	poolse	parem+poolne	02_A	SgG	et	parempoolse =poolse  (SgG  >parem+poolne !02_A
51597	numbrisse	numbri	number	02_S	SgIll	et	numbrisse =numbri  (SgIll  >number !02_S
51600	lisab	lisa	lisama	27_V	IndPrSg3	et	lisab =lisa  (IndPrSg3  >lisama !27_V
51605	kujunduselemendina	elemendi	kujundus+element	22_S	SgEs	et	kujunduselemendina =elemendi  (SgEs  >kujundus+element !22_S
51611	sunnivad	sunni	sundima	28_V	IndPrPl3	et	sunnivad =sunni  (IndPrPl3  >sundima !28_V
51613	dokumentaalfotod	foto	dokumentaal+foto	16_S	PlN	et	dokumentaalfotod =foto  (PlN  >dokumentaal+foto !16_S
51616	keskse	keskse	keskne	02_A	SgG	et	keskse =keskse  (SgG  >keskne !02_A
51627	fotoallkirjadest	kirja	foto+all+kiri	24_S	PlEl	et	fotoallkirjadest =kirja  (PlEl  >foto+all+kiri !24_S
51638	äripäevalehe	lehe	äri+päeva+leht	22_S	SgG	et	äripäevalehe =lehe  (SgG  >äri+päeva+leht !22_S
51641	väljaannes	anne	välja+and	22_S	PlIn	et	väljaannes =anne  (PlIn  >välja+and !22_S
51645	avanedes	avane	avanema	27_V	Ger	et	avanedes =avane  (Ger  >avanema !27_V
51646	hajameelne	meelne	haja+meelne	02_A	SgN	et	hajameelne =meelne  (SgN  >haja+meelne !02_A
51649	paiknes	paikne	paiknema	27_V	IndIpfSg3	et	paiknes =paikne  (IndIpfSg3  >paiknema !27_V
51652	portreefotosid	foto	port+ree+foto	16_S	PlP	et	portreefotosid =foto  (PlP  >port+ree+foto !16_S
51656	leidavad	ava	leid+ava	17_S	PlN	et	leidavad =ava  (PlN  >leid+ava !17_S
51657	ülemal	ülema	ülem	02_AS	SgAd	et	ülemal =ülema  (SgAd  >ülem !02_AS
51663	osaga	osa	osa	17_S	SgKom	et	osaga =osa  (SgKom  >osa !17_S
51668	vastupidi-	vastupidi	vastu+pidi	41_D	ID	et	vastupidi- =vastupidi  (ID  >vastu+pidi !41_D
51670	fotoallikaid	allika	foto+allikas	02_S	PlP	et	fotoallikaid =allika  (PlP  >foto+allikas !02_S
51678	milline-	milline	milline	10_P	SgN	et	milline- =milline  (SgN  >milline !10_P
51679	uurimuses	uurimuse	uurimus	11_S	SgIn	et	uurimuses =uurimuse  (SgIn  >uurimus !11_S
51680	rahaturust	turu	raha+turg	22_S	SgEl	et	rahaturust =turu  (SgEl  >raha+turg !22_S
51694	gigantsed	gigantse	gigantne	02_A	PlN	et	gigantsed =gigantse  (PlN  >gigantne !02_A
51706	mõnuainet	aine	mõnu+aine	06_S	SgP	et	mõnuainet =aine  (SgP  >mõnu+aine !06_S
51711	sündmusfotodeks	foto	sündmus+foto	16_S	PlTr	et	sündmusfotodeks =foto  (PlTr  >sündmus+foto !16_S
51714	terrorirünnaku	rünnaku	terrori+rünnak	02_S	SgG	et	terrorirünnaku =rünnaku  (SgG  >terrori+rünnak !02_S
51721	vertikaalseid	vertikaalse	vertikaalne	02_A	PlP	et	vertikaalseid =vertikaalse  (PlP  >vertikaalne !02_A
51728	pööraksin	pööra	pöörama	29_V	KndPrSg1	et	pööraksin =pööra  (KndPrSg1  >pöörama !29_V
51741	kollokviumit	kollokviumi	kollokvium	02_S	SgP	et	kollokviumit =kollokviumi  (SgP  >kollokvium !02_S
51742	eksamitesse	eksami	eksam	02_S	PlIll	et	eksamitesse =eksami  (PlIll  >eksam !02_S
51743	õpingutesse	õpingu	õping	02_S	PlIll	et	õpingutesse =õpingu  (PlIll  >õping !02_S
51748	ebasõbralikud	sõbraliku	eba+sõbralik	25_A	PlN	et	ebasõbralikud =sõbraliku  (PlN  >eba+sõbralik !25_A
51754	lektorist	lektori	lektor	02_S	SgEl	et	lektorist =lektori  (SgEl  >lektor !02_S
51756	teistsugust	sugus	teist+sugune	10_P	SgP	et	teistsugust =sugus  (SgP  >teist+sugune !10_P
51768	sõbratariga	sõbratari	sõbratar	19_S	SgKom	et	sõbratariga =sõbratari  (SgKom  >sõbratar !19_S
51780	filmiosas	osa	filmi+osa	17_S	SgIn	et	filmiosas =osa  (SgIn  >filmi+osa !17_S
51782	järgsetest	järgse	järgne	02_A	PlEl	et	järgsetest =järgse  (PlEl  >järgne !02_A
51797	näiteksalg	alg	näit+eks+alg	22_S	SgN	et	näiteksalg =alg  (SgN  >näit+eks+alg !22_S
51801	mudelis	mudeli	mudel	02_S	SgIn	et	mudelis =mudeli  (SgIn  >mudel !02_S
51813	kogunesime	kogune	kogunema	27_V	IndIpfPl1	et	kogunesime =kogune  (IndIpfPl1  >kogunema !27_V
51819	koolisööklas	söökla	kooli+söökla	01_S	SgIn	et	koolisööklas =söökla  (SgIn  >kooli+söökla !01_S
51820	koridoris	koridori	koridor	19_S	SgIn	et	koridoris =koridori  (SgIn  >koridor !19_S
51599	veerusid	veeru	veer	22_S	PlP	et	veerusid =veeru  (PlP  >veer !22_S
51608	esiletõstmisel	tõstmise	esile+tõstmine	12?10_S	SgAd	et	esiletõstmisel =tõstmise  (SgAd  >esile+tõstmine !12?10_S
51615	spontaansed	spontaanse	spontaanne	02_A	PlN	et	spontaansed =spontaanse  (PlN  >spontaanne !02_A
51622	nelinurksed	nurkse	neli+nurkne	02_A	PlN	et	nelinurksed =nurkse  (PlN  >neli+nurkne !02_A
51630	fotoallkirjaga	kirja	foto+all+kiri	24_S	SgKom	et	fotoallkirjaga =kirja  (SgKom  >foto+all+kiri !24_S
51632	popstaar	staar	pop+staar	22_S	SgN	et	popstaar =staar  (SgN  >pop+staar !22_S
51633	uudisel	uudise	uudis	09_S	SgAd	et	uudisel =uudise  (SgAd  >uudis !09_S
51636	lehekujundamise	kujundamise	lehe+kujundamine	12_S	SgG	et	lehekujundamise =kujundamise  (SgG  >lehe+kujundamine !12_S
51653	diagramme	diagramme	diagramm	22_S	PlP	et	diagramme =diagramme  (PlP  >diagramm !22_S
51658	liigseid	liigse	liigne	02_A	PlP	et	liigseid =liigse  (PlP  >liigne !02_A
51665	koomilised	koomilise	koomiline	12_A	PlN	et	koomilised =koomilise  (PlN  >koomiline !12_A
51666	dünaamiliseks	dünaamilise	dünaamiline	12_A	SgTr	et	dünaamiliseks =dünaamilise  (SgTr  >dünaamiline !12_A
51667	hiigelsuuri	suur	hiigel+suur	13_A	PlP	et	hiigelsuuri =suur  (PlP  >hiigel+suur !13_A
51669	peletab	peleta	peletama	27_V	IndPrSg3	et	peletab =peleta  (IndPrSg3  >peletama !27_V
51689	katkendid	katkendi	katkend	02_S	PlN	et	katkendid =katkendi  (PlN  >katkend !02_S
51697	esiküljel	külje	esi+külg	22_S	SgAd	et	esiküljel =külje  (SgAd  >esi+külg !22_S
51698	erakordne	kordne	era+kordne	02_AS	SgN	et	erakordne =kordne  (SgN  >era+kordne !02_AS
51702	parempoolsel	poolse	parem+poolne	02_A	SgAd	et	parempoolsel =poolse  (SgAd  >parem+poolne !02_A
51704	politseireidist	reidi	politsei+reid	22_S	SgEl	et	politseireidist =reidi  (SgEl  >politsei+reid !22_S
51716	spordifotod	foto	spordi+foto	16_S	PlN	et	spordifotod =foto  (PlN  >spordi+foto !16_S
51729	spontaanseid	spontaanse	spontaanne	02_A	PlP	et	spontaanseid =spontaanse  (PlP  >spontaanne !02_A
51730	fotoallkirjadele	kirja	foto+all+kiri	24_S	PlAll	et	fotoallkirjadele =kirja  (PlAll  >foto+all+kiri !24_S
51734	ülikoolidest	kooli	üli+kool	22_S	PlEl	et	ülikoolidest =kooli  (PlEl  >üli+kool !22_S
51737	magistriõppes	õppe	magistri+õpe	06_S	SgIn	et	magistriõppes =õppe  (SgIn  >magistri+õpe !06_S
51745	viimaseni	viimase	viimane	10_A	SgTer	et	viimaseni =viimase  (SgTer  >viimane !10_A
51750	arad	ara	arg	22_A	PlN	et	arad =ara  (PlN  >arg !22_A
51759	reatsoone	tsoone	rea+tsoon	22_S	PlP	et	reatsoone =tsoone  (PlP  >rea+tsoon !22_S
51769	kolida	koli	kolima	27_V	Inf	et	kolida =koli  (Inf  >kolima !27_V
51773	üürimajas	maja	üüri+maja	17_S	SgIn	et	üürimajas =maja  (SgIn  >üüri+maja !17_S
51774	mugavate	mugava	mugav	02_A	PlG	et	mugavate =mugava  (PlG  >mugav !02_A
51775	rahvakülas	küla	rahva+küla	17_S	SgIn	et	rahvakülas =küla  (SgIn  >rahva+küla !17_S
51777	salakaubavedajaid	vedaja	sala+kauba+vedaja	01_S	PlP	et	salakaubavedajaid =vedaja  (PlP  >sala+kauba+vedaja !01_S
51781	ministrile	ministri	minister	02_S	SgAll	et	ministrile =ministri  (SgAll  >minister !02_S
51783	väest	väe	vägi	21_S	SgEl	et	väest =väe  (SgEl  >vägi !21_S
51788	võlts	võlts	võlts	22_A	SgN	et	võlts =võlts  (SgN  >võlts !22_A
51794	vabaaeg	aeg	vaba+aeg	22_S	SgN	et	vabaaeg =aeg  (SgN  >vaba+aeg !22_S
51798	õppetööga	töö	õppe+töö	26_S	SgKom	et	õppetööga =töö  (SgKom  >õppe+töö !26_S
51803	tekstisõnum	sõnum	teksti+sõnum	02_S	SgN	et	tekstisõnum =sõnum  (SgN  >teksti+sõnum !02_S
51805	sõnumitekst	tekst	sõnumi+tekst	22_S	SgN	et	sõnumitekst =tekst  (SgN  >sõnumi+tekst !22_S
51808	näitlesime	näitle	näitlema	30_V	IndIpfPl1	et	näitlesime =näitle  (IndIpfPl1  >näitlema !30_V
51809	muinasjutus	jutu	muinas+jutt	22_S	SgIn	et	muinasjutus =jutu  (SgIn  >muinas+jutt !22_S
51836	teatrikülastajale	külastaja	teatri+külastaja	01_S	SgAll	et	teatrikülastajale =külastaja  (SgAll  >teatri+külastaja !01_S
51844	lohakile	lohakile	lohakile	41_D	ID	et	lohakile =lohakile  (ID  >lohakile !41_D
51851	üleliigne	liigne	üle+liigne	02_A	SgN	et	üleliigne =liigne  (SgN  >üle+liigne !02_A
51859	hädavajalikest	vajalike	häda+vajalik	25_A	PlEl	et	hädavajalikest =vajalike  (PlEl  >häda+vajalik !25_A
51860	eratelekanalid	kanali	era+tele+kanal	02_S	PlN	et	eratelekanalid =kanali  (PlN  >era+tele+kanal !02_S
51862	teleprogrammides	programmi	tele+programm	22_S	PlIn	et	teleprogrammides =programmi  (PlIn  >tele+programm !22_S
51863	mõistlikul	mõistliku	mõistlik	25_A	SgAd	et	mõistlikul =mõistliku  (SgAd  >mõistlik !25_A
51867	kitarre	kitarre	kitarr	22_S	PlP	et	kitarre =kitarre  (PlP  >kitarr !22_S
51873	parklas	parkla	parkla	01_S	SgIn	et	parklas =parkla  (SgIn  >parkla !01_S
51884	tammleht	leht	tamm+leht	22_S	SgN	et	tammleht =leht  (SgN  >tamm+leht !22_S
51893	hommikut	hommiku	hommik	02_S	SgP	et	hommikut =hommiku  (SgP  >hommik !02_S
51654	kõhn	kõhn	kõhn	22_A	SgN	et	kõhn =kõhn  (SgN  >kõhn !22_A
51671	telefoninumbreid	numbre	telefoni+number	02_S	PlP	et	telefoninumbreid =numbre  (PlP  >telefoni+number !02_S
51673	hüüdsõnu	sõnu	hüüd+sõna	17_S	PlP	et	hüüdsõnu =sõnu  (PlP  >hüüd+sõna !17_S
51674	diagrammid	diagrammi	diagramm	22_S	PlN	et	diagrammid =diagrammi  (PlN  >diagramm !22_S
51675	spetsiifilisi	spetsiifilisi	spetsiifiline	12_A	PlP	et	spetsiifilisi =spetsiifilisi  (PlP  >spetsiifiline !12_A
51687	ülevaated	vaate	üle+vaade	06_S	PlN	et	ülevaated =vaate  (PlN  >üle+vaade !06_S
51692	väljavõtete	võte	välja+võte	06_S	PlG	et	väljavõtete =võte  (PlG  >välja+võte !06_S
51693	kapsli	kapsli	kapsel	02_S	SgG	et	kapsli =kapsli  (SgG  >kapsel !02_S
51699	juhtumiga	juhtumi	juhtum	02_S	SgKom	et	juhtumiga =juhtumi  (SgKom  >juhtum !02_S
51709	keskelt	keskelt	keskelt	41_DK	ID	et	keskelt =keskelt  (ID  >keskelt !41_DK
51710	dekoratsioon	dekoratsioon	dekoratsioon	22_S	SgN	et	dekoratsioon =dekoratsioon  (SgN  >dekoratsioon !22_S
51712	portreefotodeks	foto	port+ree+foto	16_S	PlTr	et	portreefotodeks =foto  (PlTr  >port+ree+foto !16_S
51717	dünaamilisteks	dünaamilis	dünaamiline	12_A	PlTr	et	dünaamilisteks =dünaamilis  (PlTr  >dünaamiline !12_A
51722	horisontaalseid	horisontaalse	horisontaalne	02_A	PlP	et	horisontaalseid =horisontaalse  (PlP  >horisontaalne !02_A
51726	allkirjaga	kirja	all+kiri	24_S	SgKom	et	allkirjaga =kirja  (SgKom  >all+kiri !24_S
51727	äripäevaleht	leht	äri+päeva+leht	22_S	SgN	et	äripäevaleht =leht  (SgN  >äri+päeva+leht !22_S
51736	magistriõpe	õpe	magistri+õpe	06_S	SgN	et	magistriõpe =õpe  (SgN  >magistri+õpe !06_S
51738	ilusates	ilusa	ilus	02_A	PlIn	et	ilusates =ilusa  (PlIn  >ilus !02_A
51739	õppevahenditega	vahendi	õppe+vahend	02_S	PlKom	et	õppevahenditega =vahendi  (PlKom  >õppe+vahend !02_S
51744	auditooriumides	auditooriumi	auditoorium	19_S	PlIn	et	auditooriumides =auditooriumi  (PlIn  >auditoorium !19_S
51746	kaasüliõpilased	õpilase	kaas+üli+õpilane	12_S	PlN	et	kaasüliõpilased =õpilase  (PlN  >kaas+üli+õpilane !12_S
51766	kotiigatsus	igatsus	koti+igatsus	11_S	SgN	et	kotiigatsus =igatsus  (SgN  >koti+igatsus !11_S
51767	maasikamoosiga	moosi	maasika+moos	22_S	SgKom	et	maasikamoosiga =moosi  (SgKom  >maasika+moos !22_S
51778	käsu	käsu	käsk	22_S	SgG	et	käsu =käsu  (SgG  >käsk !22_S
51784	maatüki	tüki	maa+tükk	22_S	SgG	et	maatüki =tüki  (SgG  >maa+tükk !22_S
51787	valelikud	valeliku	valelik	25_A	PlN	et	valelikud =valeliku  (PlN  >valelik !25_A
51790	pageb	page	pagema	27_V	IndPrSg3	et	pageb =page  (IndPrSg3  >pagema !27_V
51793	rahvahulga	hulga	rahva+hulk	22_S	SgG	et	rahvahulga =hulga  (SgG  >rahva+hulk !22_S
51807	tähistasime	tähista	tähistama	27_V	IndIpfPl1	et	tähistasime =tähista  (IndIpfPl1  >tähistama !27_V
51811	mardipäeval	päeva	mardi+päev	22_S	SgAd	et	mardipäeval =päeva  (SgAd  >mardi+päev !22_S
51814	näljanumbrid	numbri	nälja+number	02_S	PlN	et	näljanumbrid =numbri  (PlN  >nälja+number !02_S
51815	kooliõhtud	õhtu	kooli+õhtu	01_S	PlN	et	kooliõhtud =õhtu  (PlN  >kooli+õhtu !01_S
51824	küllalduselt	küllalduse	küllaldus	11_S	SgAbl	et	küllalduselt =küllalduse  (SgAbl  >küllaldus !11_S
51825	juhtideks	juhti	juht	22_S	PlTr	et	juhtideks =juhti  (PlTr  >juht !22_S
51826	järjekindla	kindla	järje+kindel	02_A	SgG	et	järjekindla =kindla  (SgG  >järje+kindel !02_A
51829	valimiseelsed	eelse	valimis+eelne	02_A	PlN	et	valimiseelsed =eelse  (PlN  >valimis+eelne !02_A
51837	soosaar	saar	soo+saar	13_S	SgN	et	soosaar =saar  (SgN  >soo+saar !13_S
51843	tööasjad	asja	töö+asi	24_S	PlN	et	tööasjad =asja  (PlN  >töö+asi !24_S
51853	süvenemaks	süvene	süvenema	27_V	SupTr	et	süvenemaks =süvene  (SupTr  >süvenema !27_V
51856	informeerib	informeeri	informeerima	28_V	IndPrSg3	et	informeerib =informeeri  (IndPrSg3  >informeerima !28_V
51864	televaatajal	vaataja	tele+vaataja	01_S	SgAd	et	televaatajal =vaataja  (SgAd  >tele+vaataja !01_S
51868	auditooriumiga	auditooriumi	auditoorium	19~02_S	SgKom	et	auditooriumiga =auditooriumi  (SgKom  >auditoorium !19~02_S
51875	eakaaslased	kaaslase	ea+kaaslane	12?10_S	PlN	et	eakaaslased =kaaslase  (PlN  >ea+kaaslane !12?10_S
51885	keskväljaku	väljaku	kesk+väljak	02_S	SgG	et	keskväljaku =väljaku  (SgG  >kesk+väljak !02_S
51892	võimalikke	võimalikke	võimalik	25_A	PlP	et	võimalikke =võimalikke  (PlP  >võimalik !25_A
51898	kokkuvõtted	võtte	kokku+võte	06_S	PlN	et	kokkuvõtted =võtte  (PlN  >kokku+võte !06_S
51903	maavalitsusena	valitsuse	maa+valitsus	11_S	SgEs	et	maavalitsusena =valitsuse  (SgEs  >maa+valitsus !11_S
51909	arutlesin	arutle	arutlema	27_V	IndIpfSg1	et	arutlesin =arutle  (IndIpfSg1  >arutlema !27_V
51920	plink	plink	plink	22_SA	SgN	et	plink =plink  (SgN  >plink !22_SA
51925	piletite	pileti	pilet	02_S	PlG	et	piletite =pileti  (PlG  >pilet !02_S
51929	optimistil	optimisti	optimist	22_S	SgAd	et	optimistil =optimisti  (SgAd  >optimist !22_S
51724	portreefotol	foto	port+ree+foto	16_S	SgAd	et	portreefotol =foto  (SgAd  >port+ree+foto !16_S
51725	allkirjata	kirja	all+kiri	24_S	SgAb	et	allkirjata =kirja  (SgAb  >all+kiri !24_S
51747	kogukond	kogukond	kogukond	22_S	SgN	et	kogukond =kogukond  (SgN  >kogukond !22_S
51751	õppejõududega	jõudu	õppe+jõud	22_S	PlKom	et	õppejõududega =jõudu  (PlKom  >õppe+jõud !22_S
51753	traktaate	traktaate	traktaat	22_S	PlP	et	traktaate =traktaate  (PlP  >traktaat !22_S
51757	ergutab	erguta	ergutama	27_V	IndPrSg3	et	ergutab =erguta  (IndPrSg3  >ergutama !27_V
51758	restoranides	restorani	restoran	19_S	PlIn	et	restoranides =restorani  (PlIn  >restoran !19_S
51760	nägudel	nägu	nägu	18_S	PlAd	et	nägudel =nägu  (PlAd  >nägu !18_S
51764	jutukad	jutuka	jutukas	02_A	PlN	et	jutukad =jutuka  (PlN  >jutukas !02_A
51765	reisidele	reisi	reis	22_S	PlAll	et	reisidele =reisi  (PlAll  >reis !22_S
51770	seljakotid	koti	selja+kott	22_S	PlN	et	seljakotid =koti  (PlN  >selja+kott !22_S
51771	linnapiirkond	piirkond	linna+piirkond	22_S	SgN	et	linnapiirkond =piirkond  (SgN  >linna+piirkond !22_S
51786	vastupidised	pidise	vastu+pidine	10_A	PlN	et	vastupidised =pidise  (PlN  >vastu+pidine !10_A
51789	libahundina	hundi	liba+hunt	22_S	SgEs	et	libahundina =hundi  (SgEs  >liba+hunt !22_S
51791	näpuga	näpu	näpp	22_S	SgKom	et	näpuga =näpu  (SgKom  >näpp !22_S
51792	näidates	näida	näitama	29_V	Ger	et	näidates =näida  (Ger  >näitama !29_V
51795	väärustavad	ustava	väär+ustav	02_A	PlN	et	väärustavad =ustava  (PlN  >väär+ustav !02_A
51799	sms-sõnumeid	sõnume	sms-sõnum	02_S	PlP	et	sms-sõnumeid =sõnume  (PlP  >sms-sõnum !02_S
51802	pildides	pildi	pild	22_S	PlIn	et	pildides =pildi  (PlIn  >pild !22_S
51806	leiad	leia	leidma	34_V	IndPrSg2	et	leiad =leia  (IndPrSg2  >leidma !34_V
51816	lemmiktund	tund	lemmik+tund	22_S	SgN	et	lemmiktund =tund  (SgN  >lemmik+tund !22_S
51817	vahetunni	tunni	vahe+tund	22_S	SgG	et	vahetunni =tunni  (SgG  >vahe+tund !22_S
51818	õppetunniks	tunni	õppe+tund	22_S	SgTr	et	õppetunniks =tunni  (SgTr  >õppe+tund !22_S
51821	konstitutsioonile	konstitutsiooni	konstitutsioon	22_S	SgAll	et	konstitutsioonile =konstitutsiooni  (SgAll  >konstitutsioon !22_S
51822	eliitkoolidesse	kooli	eliit+kool	22_S	PlIll	et	eliitkoolidesse =kooli  (PlIll  >eliit+kool !22_S
51835	teatritüki	tüki	teatri+tükk	22_S	SgG	et	teatritüki =tüki  (SgG  >teatri+tükk !22_S
51841	kokkupõrgetele	põrge	kokku+põrge	06_S	PlAll	et	kokkupõrgetele =põrge  (PlAll  >kokku+põrge !06_S
51845	arvutisõltlane	sõltlane	arvuti+sõltlane	12?10_S	SgN	et	arvutisõltlane =sõltlane  (SgN  >arvuti+sõltlane !12?10_S
51847	ooperit	ooperi	ooper	02_S	SgP	et	ooperit =ooperi  (SgP  >ooper !02_S
51850	elamusega	elamuse	elamus	11_S	SgKom	et	elamusega =elamuse  (SgKom  >elamus !11_S
51852	televaatajat	vaataja	tele+vaataja	01_S	SgP	et	televaatajat =vaataja  (SgP  >tele+vaataja !01_S
51854	reklaamiklipid	klipi	reklaami+klipp	22_S	PlN	et	reklaamiklipid =klipi  (PlN  >reklaami+klipp !22_S
51861	riiklikes	riiklike	riiklik	25_A	PlIn	et	riiklikes =riiklike  (PlIn  >riiklik !25_A
51866	bass	bass	bass	22_S	SgN	et	bass =bass  (SgN  >bass !22_S
51870	atraktsioonid	atraktsiooni	atraktsioon	22_S	PlN	et	atraktsioonid =atraktsiooni  (PlN  >atraktsioon !22_S
51871	avapäeval	päeva	ava+päev	22_S	SgAd	et	avapäeval =päeva  (SgAd  >ava+päev !22_S
51872	lõpupäeval	päeva	lõpu+päev	22_S	SgAd	et	lõpupäeval =päeva  (SgAd  >lõpu+päev !22_S
51882	koolieast	ea	kooli+iga	18_S	SgEl	et	koolieast =ea  (SgEl  >kooli+iga !18_S
51888	mikrofon	mikrofon	mikrofon	19_S	SgN	et	mikrofon =mikrofon  (SgN  >mikrofon !19_S
51889	üldhariduskoolidele	kooli	üld+haridus+kool	22_S	PlAll	et	üldhariduskoolidele =kooli  (PlAll  >üld+haridus+kool !22_S
51890	maavalitsus	valitsus	maa+valitsus	11_S	SgN	et	maavalitsus =valitsus  (SgN  >maa+valitsus !11_S
51896	rühmatööks	töö	rühma+töö	26_S	SgTr	et	rühmatööks =töö  (SgTr  >rühma+töö !26_S
51900	esimehed	mehe	esi+mees	13_S	PlN	et	esimehed =mehe  (PlN  >esi+mees !13_S
51902	edastan	edasta	edastama	27_V	IndPrSg1	et	edastan =edasta  (IndPrSg1  >edastama !27_V
51907	kokkuvõtet	võte	kokku+võte	06_S	SgP	et	kokkuvõtet =võte  (SgP  >kokku+võte !06_S
51908	omavalitsuste	valitsus	oma+valitsus	11_S	PlG	et	omavalitsuste =valitsus  (PlG  >oma+valitsus !11_S
51914	muusikafestival	festival	muusika+festival	19_S	SgN	et	muusikafestival =festival  (SgN  >muusika+festival !19_S
51916	muusikastiilid	stiili	muusika+stiil	22_S	PlN	et	muusikastiilid =stiili  (PlN  >muusika+stiil !22_S
51919	gruppidele	gruppi	grupp	22_S	PlAll	et	gruppidele =gruppi  (PlAll  >grupp !22_S
51922	broneerida	broneeri	broneerima	28_V	Inf	et	broneerida =broneeri  (Inf  >broneerima !28_V
51926	igapäevamured	mure	iga+päeva+mure	16_S	PlN	et	igapäevamured =mure  (PlN  >iga+päeva+mure !16_S
51928	tõsielufilme	filme	tõsi+elu+film	22_S	PlP	et	tõsielufilme =filme  (PlP  >tõsi+elu+film !22_S
51785	põllumajandusmaksed	makse	põllu+majandus+makse	06_S	PlN	et	põllumajandusmaksed =makse  (PlN  >põllu+majandus+makse !06_S
51796	õppeainetes	aine	õppe+aine	06_S	PlIn	et	õppeainetes =aine  (PlIn  >õppe+aine !06_S
51800	sms-sõnumi	sõnumi	sms-sõnum	02_S	SgG	et	sms-sõnumi =sõnumi  (SgG  >sms-sõnum !02_S
51804	mms-sõnum	sõnum	mms-sõnum	02_S	SgN	et	mms-sõnum =sõnum  (SgN  >mms-sõnum !02_S
51810	metsloomad	looma	mets+loom	22_S	PlN	et	metsloomad =looma  (PlN  >mets+loom !22_S
51812	vedasime	veda	vedama	28_V	IndIpfPl1	et	vedasime =veda  (IndIpfPl1  >vedama !28_V
51827	enesekasvatuse	kasvatuse	enese+kasvatus	11_S	SgG	et	enesekasvatuse =kasvatuse  (SgG  >enese+kasvatus !11_S
51828	tegudeks	tegu	tegu	18_S	PlTr	et	tegudeks =tegu  (PlTr  >tegu !18_S
51830	lubadused	lubaduse	lubadus	11_S	PlN	et	lubadused =lubaduse  (PlN  >lubadus !11_S
51831	spordisündmusi	sündmusi	spordi+sündmus	11_S	PlP	et	spordisündmusi =sündmusi  (PlP  >spordi+sündmus !11_S
51832	elupeegel	peegel	elu+peegel	02_S	SgN	et	elupeegel =peegel  (SgN  >elu+peegel !02_S
51840	pühendutakse	pühendu	pühenduma	27_V	IndPrIps	et	pühendutakse =pühendu  (IndPrIps  >pühenduma !27_V
51842	peegeldades	peegelda	peegeldama	27_V	Ger	et	peegeldades =peegelda  (Ger  >peegeldama !27_V
51846	läheksite	lähe	minema	36_V	KndPrPl2	et	läheksite =lähe  (KndPrPl2  >minema !36_V
51849	harrastan	harrasta	harrastama	27_V	IndPrSg1	et	harrastan =harrasta  (IndPrSg1  >harrastama !27_V
51857	harib	hari	harima	27_V	IndPrSg3	et	harib =hari  (IndPrSg3  >harima !27_V
51858	eelolevatest	oleva	eel+olev	02_A	PlEl	et	eelolevatest =oleva  (PlEl  >eel+olev !02_A
51865	trumm	trumm	trumm	22_S	SgN	et	trumm =trumm  (SgN  >trumm !22_S
51869	ädala	ädala	ädal	02_S	SgG	et	ädala =ädala  (SgG  >ädal !02_S
51874	rajakoja	koja	raja+koda	18_S	SgG	et	rajakoja =koja  (SgG  >raja+koda !18_S
51876	homne	homne	homne	02_A	SgN	et	homne =homne  (SgN  >homne !02_A
51878	mõtteks	mõtte	mõte	06_S	SgTr	et	mõtteks =mõtte  (SgTr  >mõte !06_S
51881	pildistati	pildista	pildistama	27_V	IndIpfIps	et	pildistati =pildista  (IndIpfIps  >pildistama !27_V
51895	tänasime	täna	tänama	27_V	IndIpfPl1	et	tänasime =täna  (IndIpfPl1  >tänama !27_V
51899	huvijuhid	juhi	huvi+juht	22_S	PlN	et	huvijuhid =juhi  (PlN  >huvi+juht !22_S
51904	huvijuht	juht	huvi+juht	22_S	SgN	et	huvijuht =juht  (SgN  >huvi+juht !22_S
51913	registreerusime	registreeru	registreeruma	27_V	IndIpfPl1	et	registreerusime =registreeru  (IndIpfPl1  >registreeruma !27_V
51915	ühiskülastuse	külastuse	ühis+külastus	11_S	SgG	et	ühiskülastuse =külastuse  (SgG  >ühis+külastus !11_S
51921	piletiinfot	info	pileti+info	16_S	SgP	et	piletiinfot =info  (SgP  >pileti+info !16_S
51930	naeratada	naerata	naeratama	27_V	Inf	et	naeratada =naerata  (Inf  >naeratama !27_V
51933	esietendusel	etenduse	esi+etendus	11_S	SgAd	et	esietendusel =etenduse  (SgAd  >esi+etendus !11_S
51935	muusikalavastus	lavastus	muusika+lavastus	11_S	SgN	et	muusikalavastus =lavastus  (SgN  >muusika+lavastus !11_S
51936	tantsulavastus	lavastus	tantsu+lavastus	11_S	SgN	et	tantsulavastus =lavastus  (SgN  >tantsu+lavastus !11_S
51939	vundamentis	vundamenti	vundamentima	28_V	IndIpfSg3	et	vundamentis =vundamenti  (IndIpfSg3  >vundamentima !28_V
51947	koogiga	koogi	kook	22_S	SgKom	et	koogiga =koogi  (SgKom  >kook !22_S
51960	mahe	mahe	mahe	02_A	SgN	et	mahe =mahe  (SgN  >mahe !02_A
51965	korjab	korja	korjama	29_V	IndPrSg3	et	korjab =korja  (IndPrSg3  >korjama !29_V
51969	lingile	lingi	link	22_S	SgAll	et	lingile =lingi  (SgAll  >link !22_S
51973	kopsutas	kopsuta	kopsutama	27_V	IndIpfSg3	et	kopsutas =kopsuta  (IndIpfSg3  >kopsutama !27_V
51978	puuraiujate	raiuja	puu+raiuja	01_S	PlG	et	puuraiujate =raiuja  (PlG  >puu+raiuja !01_S
51986	panes	pane	pan	19_S	PlIn	et	panes =pane  (PlIn  >pan !19_S
51996	sotssüsteem	süsteem	sots+süsteem	22_S	SgN	et	sotssüsteem =süsteem  (SgN  >sots+süsteem !22_S
51998	miinustega	miinus	miinus	09_S	PlKom	et	miinustega =miinus  (PlKom  >miinus !09_S
52001	individuaalses	individuaalse	individuaalne	02_A	SgIn	et	individuaalses =individuaalse  (SgIn  >individuaalne !02_A
52006	kasvatusprobleemid	probleemi	kasvatus+probleem	22_S	PlN	et	kasvatusprobleemid =probleemi  (PlN  >kasvatus+probleem !22_S
52009	lemmikained	aine	lemmik+aine	06_S	PlN	et	lemmikained =aine  (PlN  >lemmik+aine !06_S
52012	graafikute	graafiku	graafik	02_S	PlG	et	graafikute =graafiku  (PlG  >graafik !02_S
52013	elusolenditest	olendi	elus+olend	02_S	PlEl	et	elusolenditest =olendi  (PlEl  >elus+olend !02_S
52014	ärritas	ärrita	ärritama	27_V	IndIpfSg3	et	ärritas =ärrita  (IndIpfSg3  >ärritama !27_V
52027	senikaua	senikaua	seni+kaua	41_D	ID	et	senikaua =senikaua  (ID  >seni+kaua !41_D
52042	tsitaat	tsitaat	tsitaat	22_S	SgN	et	tsitaat =tsitaat  (SgN  >tsitaat !22_S
52043	liigisse	liigi	liik	22_S	SgIll	et	liigisse =liigi  (SgIll  >liik !22_S
51823	erakoolidesse	kooli	era+kool	22_S	PlIll	et	erakoolidesse =kooli  (PlIll  >era+kool !22_S
51833	kunstidest	kunsti	kunst	22_S	PlEl	et	kunstidest =kunsti  (PlEl  >kunst !22_S
51834	tegeliku	tegeliku	tegelik	25_A	SgG	et	tegeliku =tegeliku  (SgG  >tegelik !25_A
51838	hiljutises	hiljutise	hiljutine	12_A	SgIn	et	hiljutises =hiljutise  (SgIn  >hiljutine !12_A
51839	tegelikud	tegeliku	tegelik	25_A	PlN	et	tegelikud =tegeliku  (PlN  >tegelik !25_A
51848	ooperiteatrit	teatri	ooperi+teater	02_S	SgP	et	ooperiteatrit =teatri  (SgP  >ooperi+teater !02_S
51855	intiimtarbeesemeid	eseme	intiim+tarbe+ese	04_S	PlP	et	intiimtarbeesemeid =eseme  (PlP  >intiim+tarbe+ese !04_S
51877	õigustama	õigusta	õigustama	27_V	Sup	et	õigustama =õigusta  (Sup  >õigustama !27_V
51879	potte	potte	pott	22_S	PlP	et	potte =potte  (PlP  >pott !22_S
51880	taldrikutega	taldriku	taldrik	02_S	PlKom	et	taldrikutega =taldriku  (PlKom  >taldrik !02_S
51883	taldrikule	taldriku	taldrik	02_S	SgAll	et	taldrikule =taldriku  (SgAll  >taldrik !02_S
51886	huvijuhtidele	juhti	huvi+juht	22_S	PlAll	et	huvijuhtidele =juhti  (PlAll  >huvi+juht !22_S
51887	rühmatööst	töö	rühma+töö	26_S	SgEl	et	rühmatööst =töö  (SgEl  >rühma+töö !26_S
51891	projektidega	projekti	projekt	22_S	PlKom	et	projektidega =projekti  (PlKom  >projekt !22_S
51897	arutame	aruta	arutama	27_V	IndPrPl1	et	arutame =aruta  (IndPrPl1  >arutama !27_V
51906	rühmatööga	töö	rühma+töö	26_S	SgKom	et	rühmatööga =töö  (SgKom  >rühma+töö !26_S
51910	9jaanuaril	jaanuari	jaanuar	19_S	SgAd	et	jaanuaril =jaanuari  (SgAd  >jaanuar !19_S
51924	koolipäev	päev	kooli+päev	22_S	SgN	et	koolipäev =päev  (SgN  >kooli+päev !22_S
51927	ulmefilme	filme	ulme+film	22_S	PlP	et	ulmefilme =filme  (PlP  >ulme+film !22_S
51934	reipaks	reipa	reibas	07_A	SgTr	et	reipaks =reipa  (SgTr  >reibas !07_A
51938	veed	vee	vesi	15_S	PlN	et	veed =vee  (PlN  >vesi !15_S
51943	kimp	kimp	kimp	22_S	SgN	et	kimp =kimp  (SgN  >kimp !22_S
51945	heitis	heit	heitma	34_V	IndIpfSg3	et	heitis =heit  (IndIpfSg3  >heitma !34_V
51954	paisis	paisi	pais	22_S	SgIn	et	paisis =paisi  (SgIn  >pais !22_S
51961	ajame	aja	ajama	27_V	IndPrPl1	et	ajame =aja  (IndPrPl1  >ajama !27_V
51962	vajutas	vajuta	vajutama	27_V	IndIpfSg3	et	vajutas =vajuta  (IndIpfSg3  >vajutama !27_V
51966	korjasin	korja	korjama	29_V	IndIpfSg1	et	korjasin =korja  (IndIpfSg1  >korjama !29_V
51967	kõigid	kõigi	kõik	22_S	PlN	et	kõigid =kõigi  (PlN  >kõik !22_S
51968	ukses	ukse	uks	14_S	SgIn	et	ukses =ukse  (SgIn  >uks !14_S
51976	korvis	korvi	korv	22_S	SgIn	et	korvis =korvi  (SgIn  >korv !22_S
51977	jämeda	jämeda	jäme	02_A	SgG	et	jämeda =jämeda  (SgG  >jäme !02_A
51980	üksele	ükse	üks	22_NP	PlAll	et	üksele =ükse  (PlAll  >üks !22_NP
51981	vajutab	vajuta	vajutama	27_V	IndPrSg3	et	vajutab =vajuta  (IndPrSg3  >vajutama !27_V
51990	rutu	rutu	rutt	22_S	SgG	et	rutu =rutu  (SgG  >rutt !22_S
51993	jõesse	jõe	jõgi	21_S	SgIll	et	jõesse =jõe  (SgIll  >jõgi !21_S
51999	ümberveenata	nata	ümber+vee+natt	22_S	SgG	et	ümberveenata =nata  (SgG  >ümber+vee+natt !22_S
52000	õppesüsteemiga	süsteemi	õppe+süsteem	22_S	SgKom	et	õppesüsteemiga =süsteemi  (SgKom  >õppe+süsteem !22_S
52004	psühholoogial	psühholoogia	psühholoogia	01_S	SgAd	et	psühholoogial =psühholoogia  (SgAd  >psühholoogia !01_S
52005	probleemidesse	probleemi	probleem	22_S	PlIll	et	probleemidesse =probleemi  (PlIll  >probleem !22_S
52008	alandas	alanda	alandama	27_V	IndIpfSg3	et	alandas =alanda  (IndIpfSg3  >alandama !27_V
52011	aineteks	aine	aine	06_S	PlTr	et	aineteks =aine  (PlTr  >aine !06_S
52015	õppetunnil	tunni	õppe+tund	22_S	SgAd	et	õppetunnil =tunni  (SgAd  >õppe+tund !22_S
52019	õppetundidel	tundi	õppe+tund	22_S	PlAd	et	õppetundidel =tundi  (PlAd  >õppe+tund !22_S
52026	ettevõtlusi	võtlusi	ette+võtlus	11_S	PlP	et	ettevõtlusi =võtlusi  (PlP  >ette+võtlus !11_S
52030	otsekohe	otsekohe	otse+kohe	41_D	ID	et	otsekohe =otsekohe  (ID  >otse+kohe !41_D
52032	kõikedele	ede	kõik+ede	16_S	SgAll	et	kõikedele =ede  (SgAll  >kõik+ede !16_S
52033	palvetele	palve	palve	06_S	PlAll	et	palvetele =palve  (PlAll  >palve !06_S
52035	väljakutsed	kutse	välja+kutse	06_S	PlN	et	väljakutsed =kutse  (PlN  >välja+kutse !06_S
52036	söödeti	sööde	söötma	34_V	IndIpfIps	et	söödeti =sööde  (IndIpfIps  >söötma !34_V
52037	meeleheitele	heite	meele+heide	06_S	SgAll	et	meeleheitele =heite  (SgAll  >meele+heide !06_S
52045	teates	teate	teade	06_S	SgIn	et	teates =teate  (SgIn  >teade !06_S
52050	rännates	ränna	rändama	29_V	Ger	et	rännates =ränna  (Ger  >rändama !29_V
52052	algse	algse	algne	02_A	SgG	et	algse =algse  (SgG  >algne !02_A
52054	jutuga	jutu	jutt	22_S	SgKom	et	jutuga =jutu  (SgKom  >jutt !22_S
52057	seesugune	sugune	see+sugune	10_P	SgN	et	seesugune =sugune  (SgN  >see+sugune !10_P
51894	mikrofonile	mikrofoni	mikrofon	19_S	SgAll	et	mikrofonile =mikrofoni  (SgAll  >mikrofon !19_S
51901	vabariiklike	riiklike	vaba+riiklik	25_A	PlG	et	vabariiklike =riiklike  (PlG  >vaba+riiklik !25_A
51905	ülevaateks	vaate	üle+vaade	06_S	SgTr	et	ülevaateks =vaate  (SgTr  >üle+vaade !06_S
51911	kokkuvõttetest	test	kokku+võtte+test	22_S	SgN	et	kokkuvõttetest =test  (SgN  >kokku+võtte+test !22_S
51912	ajakirjanikul	kirjaniku	aja+kirjanik	25_S	SgAd	et	ajakirjanikul =kirjaniku  (SgAd  >aja+kirjanik !25_S
51917	rokkfestivalid	festivali	rokk+festival	19_S	PlN	et	rokkfestivalid =festivali  (PlN  >rokk+festival !19_S
51918	muusikaüritused	ürituse	muusika+üritus	11_S	PlN	et	muusikaüritused =ürituse  (PlN  >muusika+üritus !11_S
51923	toimetab	toimeta	toimetama	27_V	IndPrSg3	et	toimetab =toimeta  (IndPrSg3  >toimetama !27_V
51932	teatrietendus	etendus	teatri+etendus	11_S	SgN	et	teatrietendus =etendus  (SgN  >teatri+etendus !11_S
51940	rumalaid	rumala	rumal	02_A	PlP	et	rumalaid =rumala  (PlP  >rumal !02_A
51942	tapavad	tapa	tapma	35_V	IndPrPl3	et	tapavad =tapa  (IndPrPl3  >tapma !35_V
51944	korjatama	korja	korjama	29_V	SupIps	et	korjatama =korja  (SupIps  >korjama !29_V
51946	õmbles	õmble	õmblema	30_V	IndIpfSg3	et	õmbles =õmble  (IndIpfSg3  >õmblema !30_V
51948	mahlaga	mahla	mahl	22_S	SgKom	et	mahlaga =mahla  (SgKom  >mahl !22_S
51951	korvisse	korvi	korv	22_S	SgIll	et	korvisse =korvi  (SgIll  >korv !22_S
51958	puuraiujad	raiuja	puu+raiuja	01_S	PlN	et	puuraiujad =raiuja  (PlN  >puu+raiuja !01_S
51964	küpsetasin	küpseta	küpsetama	27_V	IndIpfSg1	et	küpsetasin =küpseta  (IndIpfSg1  >küpsetama !27_V
51971	kõhust	kõhu	kõht	22_S	SgEl	et	kõhust =kõhu  (SgEl  >kõht !22_S
51974	lingil	lingi	link	22_S	SgAd	et	lingil =lingi  (SgAd  >link !22_S
51975	norskama	norska	norskama	29_V	Sup	et	norskama =norska  (Sup  >norskama !29_V
51982	hundile	hundi	hunt	22_S	SgAll	et	hundile =hundi  (SgAll  >hunt !22_S
51985	üteldakse	ütel	ütlema	30_V	IndPrIps	et	üteldakse =ütel  (IndPrIps  >ütlema !30_V
51994	ebameldivad	meldiva	eba+meldiv	02_A	PlN	et	ebameldivad =meldiva  (PlN  >eba+meldiv !02_A
52003	haridusprobleemid	probleemi	haridus+probleem	22_S	PlN	et	haridusprobleemid =probleemi  (PlN  >haridus+probleem !22_S
52007	kapital	kapital	kapital	19_S	SgN	et	kapital =kapital  (SgN  >kapital !19_S
52010	muuresid	re	muu+re	26_S	PlP	et	muuresid =re  (PlP  >muu+re !26_S
52016	tahvli	tahvli	tahvel	02_S	SgG	et	tahvli =tahvli  (SgG  >tahvel !02_S
52021	kooliasjad	asja	kooli+asi	24_S	PlN	et	kooliasjad =asja  (PlN  >kooli+asi !24_S
52024	kooliüritustes	üritus	kooli+üritus	11_S	PlIn	et	kooliüritustes =üritus  (PlIn  >kooli+üritus !11_S
52025	humanitaarained	aine	humanitaar+aine	06_S	PlN	et	humanitaarained =aine  (PlN  >humanitaar+aine !06_S
52028	puuduseid	puuduse	puudus	09_S	PlP	et	puuduseid =puuduse  (PlP  >puudus !09_S
52031	vihkab	vihka	vihkama	29_V	IndPrSg3	et	vihkab =vihka  (IndPrSg3  >vihkama !29_V
52038	palusime	palu	paluma	27_V	IndIpfPl1	et	palusime =palu  (IndIpfPl1  >paluma !27_V
52039	vaesedes	ede	vaes+ede	16_S	SgIn	et	vaesedes =ede  (SgIn  >vaes+ede !16_S
52046	tööpuudusega	puuduse	töö+puudus	11~09_S	SgKom	et	tööpuudusega =puuduse  (SgKom  >töö+puudus !11~09_S
52048	tõusest	tõuse	tõus	22_S	PlEl	et	tõusest =tõuse  (PlEl  >tõus !22_S
52049	kohapärimus	pärimus	koha+pärimus	11_S	SgN	et	kohapärimus =pärimus  (SgN  >koha+pärimus !11_S
52053	kohapärimuse	pärimuse	koha+pärimus	11_S	SgG	et	kohapärimuse =pärimuse  (SgG  >koha+pärimus !11_S
52060	oludest	olu	olu	17_S	PlEl	et	oludest =olu  (PlEl  >olu !17_S
52069	äratan	ärata	äratama	27_V	IndPrSg1	et	äratan =ärata  (IndPrSg1  >äratama !27_V
52076	kujundasin	kujunda	kujundama	27_V	IndIpfSg1	et	kujundasin =kujunda  (IndIpfSg1  >kujundama !27_V
52090	liigutati	liiguta	liigutama	27_V	IndIpfIps	et	liigutati =liiguta  (IndIpfIps  >liigutama !27_V
52092	märatses	märatse	märatsema	27_V	IndIpfSg3	et	märatses =märatse  (IndIpfSg3  >märatsema !27_V
52094	rüüstati	rüüsta	rüüstama	29_V	IndIpfIps	et	rüüstati =rüüsta  (IndIpfIps  >rüüstama !29_V
52097	kartlikud	kartliku	kartlik	25_A	PlN	et	kartlikud =kartliku  (PlN  >kartlik !25_A
52103	dokumentaalfilm	film	dokumentaal+film	22_S	SgN	et	dokumentaalfilm =film  (SgN  >dokumentaal+film !22_S
52112	sarnaneme	sarnane	sarnanema	27_V	IndPrPl1	et	sarnaneme =sarnane  (IndPrPl1  >sarnanema !27_V
52116	lumes	lume	lumi	20_S	SgIn	et	lumes =lume  (SgIn  >lumi !20_S
52117	lumega	lume	lumi	20_S	SgKom	et	lumega =lume  (SgKom  >lumi !20_S
52118	marjul	marju	mari	24_S	PlAd	et	marjul =marju  (PlAd  >mari !24_S
52120	failid	faili	fail	22_S	PlN	et	failid =faili  (PlN  >fail !22_S
52125	töis	tö	töö	26_S	PlIn	et	töis =tö  (PlIn  >töö !26_S
52126	soose	soose	soos	22_S	PlP	et	soose =soose  (PlP  >soos !22_S
52129	avastati	avasta	avastama	27_V	IndIpfIps	et	avastati =avasta  (IndIpfIps  >avastama !27_V
51931	teatrimaailm	ilm	teatri+maa+ilm	22_S	SgN	et	teatrimaailm =ilm  (SgN  >teatri+maa+ilm !22_S
51937	suvefestival	festival	suve+festival	19_S	SgN	et	suvefestival =festival  (SgN  >suve+festival !19_S
51950	kopp	kopp	kopp	22_S	SgN	et	kopp =kopp  (SgN  >kopp !22_S
51952	korjad	korja	korjama	29_V	IndPrSg2	et	korjad =korja  (IndPrSg2  >korjama !29_V
51953	kopp-kopp	kopp	kopp-kopp	22_S	SgN	et	kopp-kopp =kopp  (SgN  >kopp-kopp !22_S
51956	sisenes	sisene	sisenema	27_V	IndIpfSg3	et	sisenes =sisene  (IndIpfSg3  >sisenema !27_V
51957	neelas	neela	neelama	29_V	IndIpfSg3	et	neelas =neela  (IndIpfSg3  >neelama !29_V
51979	õmblus	õmblus	õmblus	11~09_S	SgN	et	õmblus =õmblus  (SgN  >õmblus !11~09_S
51984	pirukate	piruka	pirukas	02_S	PlG	et	pirukate =piruka  (PlG  >pirukas !02_S
51988	loll	loll	loll	22_AS	SgN	et	loll =loll  (SgN  >loll !22_AS
51989	jookses	jookse	jooks	22_S	PlIn	et	jookses =jookse  (PlIn  >jooks !22_S
51995	lagunes	lagune	lagunema	27_V	IndIpfSg3	et	lagunes =lagune  (IndIpfSg3  >lagunema !27_V
52017	õppetunni	tunni	õppe+tund	22_S	SgG	et	õppetunni =tunni  (SgG  >õppe+tund !22_S
52018	toonidel	tooni	toon	22_S	PlAd	et	toonidel =tooni  (PlAd  >toon !22_S
52029	õpilaseks	õpilase	õpilane	12_S	SgTr	et	õpilaseks =õpilase  (SgTr  >õpilane !12_S
52041	kvartalis	kvartali	kvartal	02_S	SgIn	et	kvartalis =kvartali  (SgIn  >kvartal !02_S
52044	iseloomustasid	musta	ise+loo+must	22_AS	PlP	et	iseloomustasid =musta  (PlP  >ise+loo+must !22_AS
52070	pillel	pille	pill	22_S	PlAd	et	pillel =pille  (PlAd  >pill !22_S
52073	poegid	poegi	poegima	27_V	IndPrSg2	et	poegid =poegi  (IndPrSg2  >poegima !27_V
52074	armastate	armasta	armastama	27_V	IndPrPl2	et	armastate =armasta  (IndPrPl2  >armastama !27_V
52083	peatama	peata	peatama	27_V	Sup	et	peatama =peata  (Sup  >peatama !27_V
52085	maailmameistrivõistlused	võistluse	maa+ilma+meistri+võistlus	11~09_S	PlN	et	maailmameistrivõistlused =võistluse  (PlN  >maa+ilma+meistri+võistlus !11~09_S
52095	pronksööl	öö	pronks+öö	26_S	SgAd	et	pronksööl =öö  (SgAd  >pronks+öö !26_S
52096	lepingus	lepingu	leping	02_S	SgIn	et	lepingus =lepingu  (SgIn  >leping !02_S
52099	karurahvastik	rahvastik	karu+rahvastik	25_S	SgN	et	karurahvastik =rahvastik  (SgN  >karu+rahvastik !25_S
52100	koerade	koera	koer	22_SA	PlG	et	koerade =koera  (PlG  >koer !22_SA
52108	fotos	foto	foto	16_S	SgIn	et	fotos =foto  (SgIn  >foto !16_S
52113	suvipäev	päev	suvi+päev	22_S	SgN	et	suvipäev =päev  (SgN  >suvi+päev !22_S
52121	instituudist	instituudi	instituut	22_S	SgEl	et	instituudist =instituudi  (SgEl  >instituut !22_S
52131	kuumaveeallikaid	allika	kuuma+vee+allikas	02_S	PlP	et	kuumaveeallikaid =allika  (PlP  >kuuma+vee+allikas !02_S
52152	kavandatakse	kavanda	kavandama	27_V	IndPrIps	et	kavandatakse =kavanda  (IndPrIps  >kavandama !27_V
52155	kanalisatsioonivõrgud	võrgu	kanalisatsiooni+võrk	22_S	PlN	et	kanalisatsioonivõrgud =võrgu  (PlN  >kanalisatsiooni+võrk !22_S
52157	arenduskavas	kava	arendus+kava	17_S	SgIn	et	arenduskavas =kava  (SgIn  >arendus+kava !17_S
52176	maaväring	väring	maa+väring	02_S	SgN	et	maaväring =väring  (SgN  >maa+väring !02_S
52177	leitigi	lei	leidma	34_V	IndIpfIps^	et	leitigi =lei  (IndIpfIps^  >leidma !34_V
52183	proovide	proovi	proov	22_S	PlG	et	proovide =proovi  (PlG  >proov !22_S
52186	hinnasoodus	soodus	hinna+soodus	02_A	SgN	et	hinnasoodus =soodus  (SgN  >hinna+soodus !02_A
52188	välismaalidel	maali	välis+maal	22_S	PlAd	et	välismaalidel =maali  (PlAd  >välis+maal !22_S
52195	reisibüroo-st	reisibüroo	reisibüroo	xx_Q	SgEl	et	reisibüroo-st =reisibüroo  (SgEl  >reisibüroo !xx_Q
52198	lahkeit	eit	lahk+eit	22_S	SgN	et	lahkeit =eit  (SgN  >lahk+eit !22_S
52206	otsustage	otsusta	otsustama	27_V	ImpPrPl2	et	otsustage =otsusta  (ImpPrPl2  >otsustama !27_V
52208	veedaks	veeda	veetma	34_V	KndPrPs	et	veedaks =veeda  (KndPrPs  >veetma !34_V
52209	ühteviisi	ühteviisi	ühte+viisi	41_D	ID	et	ühteviisi =ühteviisi  (ID  >ühte+viisi !41_D
52212	igalajal	aja	igal+aeg	22_S	SgAd	et	igalajal =aja  (SgAd  >igal+aeg !22_S
52213	naeratama	naerata	naeratama	27_V	Sup	et	naeratama =naerata  (Sup  >naeratama !27_V
52215	graafiku	graafiku	graafik	02_S	SgG	et	graafiku =graafiku  (SgG  >graafik !02_S
52217	küsitleti	küsitle	küsitlema	27_V	IndIpfIps	et	küsitleti =küsitle  (IndIpfIps  >küsitlema !27_V
52219	1september	september	september	02_S	SgN	et	september =september  (SgN  >september !02_S
52224	lõppega	lõppe	lõpe	06_S	SgKom	et	lõppega =lõppe  (SgKom  >lõpe !06_S
52232	asjaajajal	ajaja	asja+ajaja	01_S	SgAd	et	asjaajajal =ajaja  (SgAd  >asja+ajaja !01_S
52234	kaevurid	kaevuri	kaevur	02_S	PlN	et	kaevurid =kaevuri  (PlN  >kaevur !02_S
52236	skandinavistikat	skandinavistika	skandinavistika	01_S	SgP	et	skandinavistikat =skandinavistika  (SgP  >skandinavistika !01_S
52239	merisigasid	siga	meri+siga	18_SA	PlP	et	merisigasid =siga  (PlP  >meri+siga !18_SA
51941	lõhet	lõhe	lõhe	16_S	SgP	et	lõhet =lõhe  (SgP  >lõhe !16_S
51949	kopp	kopp	kopp	22_S	SgN	et	kopp =kopp  (SgN  >kopp !22_S
51955	kandib	kandi	kantima	28_V	IndPrSg3	et	kandib =kandi  (IndPrSg3  >kantima !28_V
51959	norskab	norska	norskama	29_V	IndPrSg3	et	norskab =norska  (IndPrSg3  >norskama !29_V
51963	kallistada	kallista	kallistama	27_V	Inf	et	kallistada =kallista  (Inf  >kallistama !27_V
51970	nagid	nagi	nagi	17_S	PlN	et	nagid =nagi  (PlN  >nagi !17_S
51972	kõhus	kõhu	kõht	22_S	SgIn	et	kõhus =kõhu  (SgIn  >kõht !22_S
51983	puuraiujaid	raiuja	puu+raiuja	01_S	PlP	et	puuraiujaid =raiuja  (PlP  >puu+raiuja !01_S
51987	küsiks	küsi	küsima	27_V	KndPrPs	et	küsiks =küsi  (KndPrPs  >küsima !27_V
51991	mütsist	mütsi	müts	22_S	SgEl	et	mütsist =mütsi  (SgEl  >müts !22_S
51992	lõikisid	lõiki	lõik	22_S	PlP	et	lõikisid =lõiki  (PlP  >lõik !22_S
51997	ümberkorraldus	korraldus	ümber+korraldus	11_S	SgN	et	ümberkorraldus =korraldus  (SgN  >ümber+korraldus !11_S
52002	pedagoogiharidus	haridus	pedagoogi+haridus	11_S	SgN	et	pedagoogiharidus =haridus  (SgN  >pedagoogi+haridus !11_S
52020	kooliained	aine	kooli+aine	06_S	PlN	et	kooliained =aine  (PlN  >kooli+aine !06_S
52022	koolimajja	majja	kooli+maja	17_S	SgAdt	et	koolimajja =majja  (SgAdt  >kooli+maja !17_S
52023	loodusõpetus	õpetus	loodus+õpetus	11_S	SgN	et	loodusõpetus =õpetus  (SgN  >loodus+õpetus !11_S
52034	meelepahadele	paha	meele+paha	17_AS	PlAll	et	meelepahadele =paha  (PlAll  >meele+paha !17_AS
52040	tööpuuduse	puuduse	töö+puudus	11~09_S	SgG	et	tööpuuduse =puuduse  (SgG  >töö+puudus !11~09_S
52055	kohaldada	kohalda	kohaldama	27_V	Inf	et	kohaldada =kohalda  (Inf  >kohaldama !27_V
52056	paikadega	paika	paik	22_S	PlKom	et	paikadega =paika  (PlKom  >paik !22_S
52063	kurgaanidest	kurgaani	kurgaan	22_S	PlEl	et	kurgaanidest =kurgaani  (PlEl  >kurgaan !22_S
52065	käibesse	käibe	käive	06_S	SgIll	et	käibesse =käibe  (SgIll  >käive !06_S
52071	reisimas	reisi	reisima	28_V	SupIn	et	reisimas =reisi  (SupIn  >reisima !28_V
52072	visiteerid	visiteeri	visiteerima	28_V	IndPrSg2	et	visiteerid =visiteeri  (IndPrSg2  >visiteerima !28_V
52075	kujundamas	kujunda	kujundama	27_V	SupIn	et	kujundamas =kujunda  (SupIn  >kujundama !27_V
52078	värvisin	värvi	värvima	28_V	IndIpfSg1	et	värvisin =värvi  (IndIpfSg1  >värvima !28_V
52081	vajuda	vaju	vajuma	27_V	Inf	et	vajuda =vaju  (Inf  >vajuma !27_V
52082	valulik	valulik	valulik	25_A	SgN	et	valulik =valulik  (SgN  >valulik !25_A
52086	pronkssõdur	sõdur	pronks+sõdur	02_S	SgN	et	pronkssõdur =sõdur  (SgN  >pronks+sõdur !02_S
52098	koobastel	koobas	koobas	07_S	PlAd	et	koobastel =koobas  (PlAd  >koobas !07_S
52101	kostüüm	kostüüm	kostüüm	22_S	SgN	et	kostüüm =kostüüm  (SgN  >kostüüm !22_S
52105	meeled	meele	meel	13_S	PlN	et	meeled =meele  (PlN  >meel !13_S
52109	suves	suve	suvi	20_S	SgIn	et	suves =suve  (SgIn  >suvi !20_S
52114	asute	asu	asuma	27_V	IndPrPl2	et	asute =asu  (IndPrPl2  >asuma !27_V
52122	otsustad	otsusta	otsustama	27_V	IndPrSg2	et	otsustad =otsusta  (IndPrSg2  >otsustama !27_V
52124	pide	pide	pide	04_S	SgN	et	pide =pide  (SgN  >pide !04_S
52133	jääkilp	kilp	jää+kilp	22_S	SgN	et	jääkilp =kilp  (SgN  >jää+kilp !22_S
52134	eluvormid	vormi	elu+vorm	22_S	PlN	et	eluvormid =vormi  (PlN  >elu+vorm !22_S
52135	planeetidel	planeeti	planeet	22_S	PlAd	et	planeetidel =planeeti  (PlAd  >planeet !22_S
52144	maavärinaga	värina	maa+värin	02_S	SgKom	et	maavärinaga =värina  (SgKom  >maa+värin !02_S
52163	tallinlaste	tallinlas	tallinlane	12_S	PlG	et	tallinlaste =tallinlas  (PlG  >tallinlane !12_S
52164	lemmikpuhkekoht	koht	lemmik+puhke+koht	22_S	SgN	et	lemmikpuhkekoht =koht  (SgN  >lemmik+puhke+koht !22_S
52165	suveajal	aja	suve+aeg	22_S	SgAd	et	suveajal =aja  (SgAd  >suve+aeg !22_S
52166	linnaosadest	osa	linna+osa	17_S	PlEl	et	linnaosadest =osa  (PlEl  >linna+osa !17_S
52167	parkmets	mets	park+mets	22_S	SgN	et	parkmets =mets  (SgN  >park+mets !22_S
52173	jääproovide	proovi	jää+proov	22_S	PlG	et	jääproovide =proovi  (PlG  >jää+proov !22_S
52182	planeetides	planeeti	planeet	22_S	PlIn	et	planeetides =planeeti  (PlIn  >planeet !22_S
52185	toetate	toeta	toetama	27_V	IndPrPl2	et	toetate =toeta  (IndPrPl2  >toetama !27_V
52189	tots	tots	tots	22_S	SgN	et	tots =tots  (SgN  >tots !22_S
52190	kooligrupp	grupp	kooli+grupp	22_S	SgN	et	kooligrupp =grupp  (SgN  >kooli+grupp !22_S
52191	rongipiletiga	pileti	rongi+pilet	02_S	SgKom	et	rongipiletiga =pileti  (SgKom  >rongi+pilet !02_S
52193	teoreetilist	teoreetilis	teoreetiline	12_A	SgP	et	teoreetilist =teoreetilis  (SgP  >teoreetiline !12_A
52200	eesmärg	märg	ees+märg	22_AS	SgN	et	eesmärg =märg  (SgN  >ees+märg !22_AS
52203	vaide	vaide	vaie	06_S	SgG	et	vaide =vaide  (SgG  >vaie !06_S
52047	kriteeriumid	kriteeriumi	kriteerium	19~02_S	PlN	et	kriteeriumid =kriteeriumi  (PlN  >kriteerium !19~02_S
52051	ülekandmisel	kandmise	üle+kandmine	12?10_SA	SgAd	et	ülekandmisel =kandmise  (SgAd  >üle+kandmine !12?10_SA
52059	väljarändajaid	rändaja	välja+rändaja	01_S	PlP	et	väljarändajaid =rändaja  (PlP  >välja+rändaja !01_S
52062	aegladest	la	aeg+la	26_S	PlEl	et	aegladest =la  (PlEl  >aeg+la !26_S
52064	kääbastest	kääbas	kääbas	07_S	PlEl	et	kääbastest =kääbas  (PlEl  >kääbas !07_S
52088	pronkssõdurit	sõduri	pronks+sõdur	02_S	SgP	et	pronkssõdurit =sõduri  (SgP  >pronks+sõdur !02_S
52091	sõjakalmistusse	kalmistu	sõja+kalmistu	01_S	SgIll	et	sõjakalmistusse =kalmistu  (SgIll  >sõja+kalmistu !01_S
52102	moodsest	moodse	moodne	02_A	SgEl	et	moodsest =moodse  (SgEl  >moodne !02_A
52128	omasin	oma	omama	27_V	IndIpfSg1	et	omasin =oma  (IndIpfSg1  >omama !27_V
52136	kaaslasel	kaaslase	kaaslane	12?10_S	SgAd	et	kaaslasel =kaaslase  (SgAd  >kaaslane !12?10_S
52145	geneetilisi	geneetilisi	geneetiline	12_A	PlP	et	geneetilisi =geneetilisi  (PlP  >geneetiline !12_A
52146	keskkonnaks	keskkonna	keskkond	22_S	SgTr	et	keskkonnaks =keskkonna  (SgTr  >keskkond !22_S
52149	väljatöötamist	töötamis	välja+töötamine	12_S	SgP	et	väljatöötamist =töötamis  (SgP  >välja+töötamine !12_S
52150	tähtaegadele	aega	täht+aeg	22_S	PlAll	et	tähtaegadele =aega  (PlAll  >täht+aeg !22_S
52154	kanalisatsiooniprobleemid	probleemi	kanalisatsiooni+probleem	22_S	PlN	et	kanalisatsiooniprobleemid =probleemi  (PlN  >kanalisatsiooni+probleem !22_S
52156	liiklussõlm	sõlm	liiklus+sõlm	22_S	SgN	et	liiklussõlm =sõlm  (SgN  >liiklus+sõlm !22_S
52161	spordisaalide	saali	spordi+saal	22_S	PlG	et	spordisaalide =saali  (PlG  >spordi+saal !22_S
52169	jääkate	kate	jää+kate	06_S	SgN	et	jääkate =kate  (SgN  >jää+kate !06_S
52171	eluvorm	vorm	elu+vorm	22_S	SgN	et	eluvorm =vorm  (SgN  >elu+vorm !22_S
52172	euroopal	euroopa	euroopa	01_H	SgAd	et	euroopal =euroopa  (SgAd  >euroopa !01_H
52174	kihte	kihte	kiht	22_S	PlP	et	kihte =kihte  (PlP  >kiht !22_S
52178	mudelite	mudeli	mudel	02_S	PlG	et	mudelite =mudeli  (PlG  >mudel !02_S
52204	kõrgelttasustaval	tasustava	kõrgelt+tasustav	02_A	SgAd	et	kõrgelttasustaval =tasustava  (SgAd  >kõrgelt+tasustav !02_A
52205	neutraalsel	neutraalse	neutraalne	02_A	SgAd	et	neutraalsel =neutraalse  (SgAd  >neutraalne !02_A
52238	kodutelefoninumber	number	kodu+telefoni+number	02_S	SgN	et	kodutelefoninumber =number  (SgN  >kodu+telefoni+number !02_S
52243	käetoeni	toe	käe+tugi	21_S	SgTer	et	käetoeni =toe  (SgTer  >käe+tugi !21_S
52245	vadatakse	vada	vadama	27_V	IndPrIps	et	vadatakse =vada  (IndPrIps  >vadama !27_V
52256	liina	lii	lii	26_S	SgEs	et	liina =lii  (SgEs  >lii !26_S
52258	lautadest	lauta	laut	22_S	PlEl	et	lautadest =lauta  (PlEl  >laut !22_S
52261	noorusaeg	aeg	noorus+aeg	22_S	SgN	et	noorusaeg =aeg  (SgN  >noorus+aeg !22_S
52264	abiellume	ellu	abi+elluma	27_V	IndPrPl1	et	abiellume =ellu  (IndPrPl1  >abi+elluma !27_V
52269	õiglasel	õiglase	õiglane	12?10_A	SgAd	et	õiglasel =õiglase  (SgAd  >õiglane !12?10_A
52271	arvutiprogramme	programme	arvuti+programm	22_S	PlP	et	arvutiprogramme =programme  (PlP  >arvuti+programm !22_S
52278	asjaolud	olu	asja+olu	17_S	PlN	et	asjaolud =olu  (PlN  >asja+olu !17_S
52280	isamaata	maa	isa+maa	26_S	SgAb	et	isamaata =maa  (SgAb  >isa+maa !26_S
52282	nõukoguga	kogu	nõu+kogu	17_S	SgKom	et	nõukoguga =kogu  (SgKom  >nõu+kogu !17_S
52287	eksin	eksi	eksima	28_V	IndPrSg1	et	eksin =eksi  (IndPrSg1  >eksima !28_V
52290	lume	lume	lumi	20_S	SgG	et	lume =lume  (SgG  >lumi !20_S
52292	halveneb	halvene	halvenema	27_V	IndPrSg3	et	halveneb =halvene  (IndPrSg3  >halvenema !27_V
52293	kodumasinateta	masina	kodu+masin	02_S	PlAb	et	kodumasinateta =masina  (PlAb  >kodu+masin !02_S
52294	mööblita	mööbli	mööbel	02_S	SgAb	et	mööblita =mööbli  (SgAb  >mööbel !02_S
52298	ihnuskoiks	koi	ihnus+koi	26_S	SgTr	et	ihnuskoiks =koi  (SgTr  >ihnus+koi !26_S
52303	kasulike	kasulike	kasulik	25_A	PlG	et	kasulike =kasulike  (PlG  >kasulik !25_A
52304	toiduta	toidu	toit	22_S	SgAb	et	toiduta =toidu  (SgAb  >toit !22_S
52310	roboteid	robote	robot	02_S	PlP	et	roboteid =robote  (PlP  >robot !02_S
52311	toitumisharjumuis	mu	toitumis+harju+muu	26_S	PlIn	et	toitumisharjumuis =mu  (PlIn  >toitumis+harju+muu !26_S
52312	toidureklaam	reklaam	toidu+reklaam	22_S	SgN	et	toidureklaam =reklaam  (SgN  >toidu+reklaam !22_S
52058	väljarändamist	rändamis	välja+rändamine	12_S	SgP	et	väljarändamist =rändamis  (SgP  >välja+rändamine !12_S
52061	kasinad	kasina	kasin	02_A	PlN	et	kasinad =kasina  (PlN  >kasin !02_A
52066	võõraks	võõra	võõras	07_AS	SgTr	et	võõraks =võõra  (SgTr  >võõras !07_AS
52067	inglane	inglane	inglane	12?10_S	SgN	et	inglane =inglane  (SgN  >inglane !12?10_S
52068	segakauplus	kauplus	sega+kauplus	11~09_S	SgN	et	segakauplus =kauplus  (SgN  >sega+kauplus !11~09_S
52077	konega	kone	kone	16_S	SgKom	et	konega =kone  (SgKom  >kone !16_S
52079	hallo	hallo	hallo	41_I	ID	et	hallo =hallo  (ID  >hallo !41_I
52080	leiutasin	leiuta	leiutama	27_V	IndIpfSg1	et	leiutasin =leiuta  (IndIpfSg1  >leiutama !27_V
52084	vigastasin	vigasta	vigastama	27_V	IndIpfSg1	et	vigastasin =vigasta  (IndIpfSg1  >vigastama !27_V
52087	pronkssõduri	sõduri	pronks+sõdur	02_S	SgG	et	pronkssõduri =sõduri  (SgG  >pronks+sõdur !02_S
52089	mudelina	mudeli	mudel	02_S	SgEs	et	mudelina =mudeli  (SgEs  >mudel !02_S
52093	sõjakalmistus	kalmistu	sõja+kalmistu	01_S	SgIn	et	sõjakalmistus =kalmistu  (SgIn  >sõja+kalmistu !01_S
52104	hüüdavad	ava	hüüd+ava	17_S	PlN	et	hüüdavad =ava  (PlN  >hüüd+ava !17_S
52106	raamaturiiu	riiu	raamatu+riid	22_S	SgG	et	raamaturiiu =riiu  (SgG  >raamatu+riid !22_S
52107	välgatada	välgata	välgatama	27_V	Inf	et	välgatada =välgata  (Inf  >välgatama !27_V
52110	püüdlen	püüdle	püüdlema	30_V	IndPrSg1	et	püüdlen =püüdle  (IndPrSg1  >püüdlema !30_V
52111	tüdruksõbral	sõbra	tüdruk+sõber	24_S	SgAd	et	tüdruksõbral =sõbra  (SgAd  >tüdruk+sõber !24_S
52115	lumel	lume	lumi	20_S	SgAd	et	lumel =lume  (SgAd  >lumi !20_S
52119	magasis	magasi	magas	02_S	SgIn	et	magasis =magasi  (SgIn  >magas !02_S
52123	grand	grand	grand	22_S	SgN	et	grand =grand  (SgN  >grand !22_S
52127	muusikakeskusis	keskusi	muusika+keskus	11_S	PlIn	et	muusikakeskusis =keskusi  (PlIn  >muusika+keskus !11_S
52132	järvesid	järve	järv	22_S	PlP	et	järvesid =järve  (PlP  >järv !22_S
52139	jääproovides	proovi	jää+proov	22_S	PlIn	et	jääproovides =proovi  (PlIn  >jää+proov !22_S
52140	sisaldub	sisaldu	sisalduma	27_V	IndPrSg3	et	sisaldub =sisaldu  (IndPrSg3  >sisalduma !27_V
52141	järvevett	ve	järve+vesi	15_S	SgP	et	järvevett =ve  (SgP  >järve+vesi !15_S
52142	pele	pele	pele	41_I	ID	et	pele =pele  (ID  >pele !41_I
52148	põhiteguriteks	teguri	põhi+tegur	02_S	PlTr	et	põhiteguriteks =teguri  (PlTr  >põhi+tegur !02_S
52159	täieneb	täiene	täienema	27_V	IndPrSg3	et	täieneb =täiene  (IndPrSg3  >täienema !27_V
52162	noortekeskuse	keskuse	noorte+keskus	11~09_S	SgG	et	noortekeskuse =keskuse  (SgG  >noorte+keskus !11~09_S
52170	miljonite	miljoni	miljon	02_N	PlG	et	miljonite =miljoni  (PlG  >miljon !02_N
52175	põhjalt	põhja	põhi	24_S	SgAbl	et	põhjalt =põhja  (SgAbl  >põhi !24_S
52184	maaväringuga	väringu	maa+väring	02_S	SgKom	et	maaväringuga =väringu  (SgKom  >maa+väring !02_S
52187	valisime	vali	valima	27_V	IndIpfPl1	et	valisime =vali  (IndIpfPl1  >valima !27_V
52214	koolivormilt	vormi	kooli+vorm	22_S	SgAbl	et	koolivormilt =vormi  (SgAbl  >kooli+vorm !22_S
52216	septembrile	septembri	september	02_S	SgAll	et	septembrile =septembri  (SgAll  >september !02_S
52218	sestap	sestap	sestap	41_D	ID	et	sestap =sestap  (ID  >sestap !41_D
52221	seostab	seosta	seostama	27_V	IndPrSg3	et	seostab =seosta  (IndPrSg3  >seostama !27_V
52225	päevitades	päevita	päevitama	27_V	Ger	et	päevitades =päevita  (Ger  >päevitama !27_V
52226	suvilades	la	suvi+la	26_S	PlIn	et	suvilades =la  (PlIn  >suvi+la !26_S
52228	seostuda	seostu	seostuma	27_V	Inf	et	seostuda =seostu  (Inf  >seostuma !27_V
52229	praktikaaeg	aeg	praktika+aeg	22_S	SgN	et	praktikaaeg =aeg  (SgN  >praktika+aeg !22_S
52231	topiseid	topise	topis	09_S	PlP	et	topiseid =topise  (PlP  >topis !09_S
52248	laiub	laiu	laiuma	27_V	IndPrSg3	et	laiub =laiu  (IndPrSg3  >laiuma !27_V
52253	naeratab	naerata	naeratama	27_V	IndPrSg3	et	naeratab =naerata  (IndPrSg3  >naeratama !27_V
52257	maaelanik	elanik	maa+elanik	25_S	SgN	et	maaelanik =elanik  (SgN  >maa+elanik !25_S
52260	sellejaoks	jao	selle+jagu	18_S	SgTr	et	sellejaoks =jao  (SgTr  >selle+jagu !18_S
52267	kevadsemestril	semestri	kevad+semester	02_S	SgAd	et	kevadsemestril =semestri  (SgAd  >kevad+semester !02_S
52273	kosmeetikasalongist	salongi	kosmeetika+salong	22_S	SgEl	et	kosmeetikasalongist =salongi  (SgEl  >kosmeetika+salong !22_S
52295	karistama	karista	karistama	27_V	Sup	et	karistama =karista  (Sup  >karistama !27_V
52297	vastutustunne	tunne	vastutus+tunne	06_S	SgN	et	vastutustunne =tunne  (SgN  >vastutus+tunne !06_S
52301	käitumismudelid	mudeli	käitumis+mudel	02_S	PlN	et	käitumismudelid =mudeli  (PlN  >käitumis+mudel !02_S
52306	venelatel	late	vene+latt	22_S	PlAd	et	venelatel =late  (PlAd  >vene+latt !22_S
52307	keeleteadmist	teadmis	keele+teadmine	12?10_S	SgP	et	keeleteadmist =teadmis  (SgP  >keele+teadmine !12?10_S
52130	järvepinna	pinna	järve+pind	22_S	SgG	et	järvepinna =pinna  (SgG  >järve+pind !22_S
52137	teadlastel	teadlas	teadlane	12?10_S	PlAd	et	teadlastel =teadlas  (PlAd  >teadlane !12?10_S
52138	jääkilbi	kilbi	jää+kilp	22_S	SgG	et	jääkilbi =kilbi  (SgG  >jää+kilp !22_S
52143	vahekihte	kihte	vahe+kiht	22_S	PlP	et	vahekihte =kihte  (PlP  >vahe+kiht !22_S
52147	eluvorme	vorme	elu+vorm	22_S	PlP	et	eluvorme =vorme  (PlP  >elu+vorm !22_S
52151	võimalikele	võimalike	võimalik	25_A	PlAll	et	võimalikele =võimalike  (PlAll  >võimalik !25_A
52153	asumid	asumi	asum	02_S	PlN	et	asumid =asumi  (PlN  >asum !02_S
52158	projektidele	projekti	projekt	22_S	PlAll	et	projektidele =projekti  (PlAll  >projekt !22_S
52160	materiaal-tehniline	tehniline	materiaal-tehniline	12_A	SgN	et	materiaal-tehniline =tehniline  (SgN  >materiaal-tehniline !12_A
52168	jääkihi	kihi	jää+kiht	22_S	SgG	et	jääkihi =kihi  (SgG  >jää+kiht !22_S
52179	uurimistulemused	tulemuse	uurimis+tulemus	11_S	PlN	et	uurimistulemused =tulemuse  (PlN  >uurimis+tulemus !11_S
52180	järvepõhjas	põhja	järve+põhi	24_S	SgIn	et	järvepõhjas =põhja  (SgIn  >järve+põhi !24_S
52181	pindalaga	ala	pind+ala	17_S	SgKom	et	pindalaga =ala  (SgKom  >pind+ala !17_S
52192	kutseid	kutse	kutse	06_S	PlP	et	kutseid =kutse  (PlP  >kutse !06_S
52194	teatrite	teatri	teater	02_S	PlG	et	teatrite =teatri  (PlG  >teater !02_S
52196	20st	st	st	41_I	ID	et	st =st  (ID  >st !41_I
52197	vajaksime	vaja	vajama	27_V	KndPrPl1	et	vajaksime =vaja  (KndPrPl1  >vajama !27_V
52199	eluteel	tee	elu+tee	26_S	SgAd	et	eluteel =tee  (SgAd  >elu+tee !26_S
52201	investeerib	investeeri	investeerima	28_V	IndPrSg3	et	investeerib =investeeri  (IndPrSg3  >investeerima !28_V
52202	mõistega	mõiste	mõiste	06_S	SgKom	et	mõistega =mõiste  (SgKom  >mõiste !06_S
52210	tähelepaneku	paneku	tähele+panek	02_S	SgG	et	tähelepaneku =paneku  (SgG  >tähele+panek !02_S
52223	imekspandav	pandav	imeks+pandav	02_A	SgN	et	imekspandav =pandav  (SgN  >imeks+pandav !02_A
52227	septembriks	septembri	september	02_S	SgTr	et	septembriks =septembri  (SgTr  >september !02_S
52237	kassel	kasse	kass	22_S	PlAd	et	kassel =kasse  (PlAd  >kass !22_S
52240	sole	sole	sol	22_S	PlP	et	sole =sole  (PlP  >sol !22_S
52244	käetoe	toe	käe+tugi	21_S	SgG	et	käetoe =toe  (SgG  >käe+tugi !21_S
52246	piirneb	piirne	piirnema	27_V	IndPrSg3	et	piirneb =piirne  (IndPrSg3  >piirnema !27_V
52247	lookleb	lookle	looklema	30_V	IndPrSg3	et	lookleb =lookle  (IndPrSg3  >looklema !30_V
52255	katavad	kata	katma	35_V	IndPrPl3	et	katavad =kata  (IndPrPl3  >katma !35_V
52262	kõrtse	kõrtse	kõrts	22_S	PlP	et	kõrtse =kõrtse  (PlP  >kõrts !22_S
52266	eristan	erista	eristama	27_V	IndPrSg1	et	eristan =erista  (IndPrSg1  >eristama !27_V
52268	sissekord	kord	sisse+kord	22_S	SgN	et	sissekord =kord  (SgN  >sisse+kord !22_S
52275	igadel	iga	iga	18_S	PlAd	et	igadel =iga  (PlAd  >iga !18_S
52276	hammastele	hammas	hammas	07_S	PlAll	et	hammastele =hammas  (PlAll  >hammas !07_S
52284	meelne	meelne	meelne	02_A	SgN	et	meelne =meelne  (SgN  >meelne !02_A
52305	materiaalsest	materiaalse	materiaalne	02_A	SgEl	et	materiaalsest =materiaalse  (SgEl  >materiaalne !02_A
52207	organiseerib	organiseeri	organiseerima	28_V	IndPrSg3	et	organiseerib =organiseeri  (IndPrSg3  >organiseerima !28_V
52211	korralikuna	korraliku	korralik	25_A	SgEs	et	korralikuna =korraliku  (SgEs  >korralik !25_A
52220	neljandik	neljandik	neljandik	25_N	SgN	et	neljandik =neljandik  (SgN  >neljandik !25_N
52222	rahupäevaga	päeva	rahu+päev	22_S	SgKom	et	rahupäevaga =päeva  (SgKom  >rahu+päev !22_S
52230	muuseumit	muuseumi	muuseum	02_S	SgP	et	muuseumit =muuseumi  (SgP  >muuseum !02_S
52233	põlevkivisse	kivi	põlev+kivi	17_S	SgIll	et	põlevkivisse =kivi  (SgIll  >põlev+kivi !17_S
52235	blondid	blondi	blond	22_SA	PlN	et	blondid =blondi  (PlN  >blond !22_SA
52249	merelaht	laht	mere+laht	22_S	SgN	et	merelaht =laht  (SgN  >mere+laht !22_S
52250	mägedega	mäge	mägi	21_S	PlKom	et	mägedega =mäge  (PlKom  >mägi !21_S
52251	tume-pruun	pruun	tume-pruun	22_AS	SgN	et	tume-pruun =pruun  (SgN  >tume-pruun !22_AS
52254	sadakond	sadakond	sadakond	22_NS	SgN	et	sadakond =sadakond  (SgN  >sadakond !22_NS
52263	raamatupoode	poode	raamatu+pood	22_S	PlP	et	raamatupoode =poode  (PlP  >raamatu+pood !22_S
52265	pigemini	pigemini	pigemini	41_D	ID	et	pigemini =pigemini  (ID  >pigemini !41_D
52270	lemmikut	lemmiku	lemmik	02_S	SgP	et	lemmikut =lemmiku  (SgP  >lemmik !02_S
52272	arenguseks	seks	arengu+seks	22_S	SgN	et	arenguseks =seks  (SgN  >arengu+seks !22_S
52274	sportidega	sporti	sport	22_S	PlKom	et	sportidega =sporti  (PlKom  >sport !22_S
52279	kaotame	kaota	kaotama	27_V	IndPrPl1	et	kaotame =kaota  (IndPrPl1  >kaotama !27_V
52281	tilk	tilk	tilk	22_S	SgN	et	tilk =tilk  (SgN  >tilk !22_S
52288	igaühelt	ühe	iga+üks	22_P	SgAbl	et	igaühelt =ühe  (SgAbl  >iga+üks !22_P
52289	soojeneb	soojene	soojenema	27_V	IndPrSg3	et	soojeneb =soojene  (IndPrSg3  >soojenema !27_V
52302	mineraale	mineraale	mineraal	22_S	PlP	et	mineraale =mineraale  (PlP  >mineraal !22_S
52241	küülikuid	küüliku	küülik	02_S	PlP	et	küülikuid =küüliku  (PlP  >küülik !02_S
52242	keemik	keemik	keemik	02_S	SgN	et	keemik =keemik  (SgN  >keemik !02_S
52252	varrukate	varruka	varrukas	02_S	PlG	et	varrukate =varruka  (PlG  >varrukas !02_S
52259	sestsaadik	sestsaadik	sest+saadik	41_D	ID	et	sestsaadik =sestsaadik  (ID  >sest+saadik !41_D
52277	hoolduskosmeetikad	kosmeetika	hooldus+kosmeetika	01_S	PlN	et	hoolduskosmeetikad =kosmeetika  (PlN  >hooldus+kosmeetika !01_S
52283	vanurile	vanuri	vanur	02_S	SgAll	et	vanurile =vanuri  (SgAll  >vanur !02_S
52285	tervised	tervise	tervis	09~11_S	PlN	et	tervised =tervise  (PlN  >tervis !09~11_S
52286	hooldama	hoolda	hooldama	27_V	Sup	et	hooldama =hoolda  (Sup  >hooldama !27_V
52291	5-ni			xx_Q	SgTer	et	-ni =  (SgTer  > !xx_Q
52296	potilill	lill	poti+lill	22_S	SgN	et	potilill =lill  (SgN  >poti+lill !22_S
52299	täisväärtuseid	väärtuse	täis+väärtus	09_S	PlP	et	täisväärtuseid =väärtuse  (PlP  >täis+väärtus !09_S
52300	raamatuteta	raamatu	raamat	02_S	PlAb	et	raamatuteta =raamatu  (PlAb  >raamat !02_S
52309	ootaks	oota	ootama	29_V	KndPrPs	et	ootaks =oota  (KndPrPs  >ootama !29_V
52314	rõõm-	rõõm	rõõm	22_S	SgN	et	rõõm- =rõõm  (SgN  >rõõm !22_S
52315	lehmaga	lehma	lehm	22_S	SgKom	et	lehmaga =lehma  (SgKom  >lehm !22_S
52316	prismas	prisma	prisma	16_S	SgIn	et	prismas =prisma  (SgIn  >prisma !16_S
52308	parkemisega	emise	park+emis	09_S	SgKom	et	parkemisega =emise  (SgKom  >park+emis !09_S
52313	hambaarstid	arsti	hamba+arst	22_S	PlN	et	hambaarstid =arsti  (PlN  >hamba+arst !22_S
52317	aurat	aura	aura	16_S	SgP	et	aurat =aura  (SgP  >aura !16_S
52318	1mina	mina	mina	17_S	SgN	et	mina =mina  (SgN  >mina !17_S
\.


--
-- Name: aliases_pkey; Type: CONSTRAINT; Schema: public; Owner: evkk; Tablespace: 
--

ALTER TABLE ONLY aliases
    ADD CONSTRAINT aliases_pkey PRIMARY KEY ("ID");


--
-- Name: docid; Type: CONSTRAINT; Schema: public; Owner: evkk; Tablespace: 
--

ALTER TABLE ONLY documents
    ADD CONSTRAINT docid PRIMARY KEY ("DocumentID");


--
-- Name: documents_pkey; Type: CONSTRAINT; Schema: public; Owner: evkk; Tablespace: 
--

ALTER TABLE ONLY docrefs
    ADD CONSTRAINT documents_pkey PRIMARY KEY ("ID");


--
-- Name: undecided_pkey; Type: CONSTRAINT; Schema: public; Owner: evkk; Tablespace: 
--

ALTER TABLE ONLY undecided
    ADD CONSTRAINT undecided_pkey PRIMARY KEY ("ID");


--
-- Name: words_pkey; Type: CONSTRAINT; Schema: public; Owner: evkk; Tablespace: 
--

ALTER TABLE ONLY words
    ADD CONSTRAINT words_pkey PRIMARY KEY ("ID");


--
-- Name: alindex; Type: INDEX; Schema: public; Owner: evkk; Tablespace: 
--

CREATE INDEX alindex ON aliases USING btree (fromword);


--
-- Name: docindex; Type: INDEX; Schema: public; Owner: evkk; Tablespace: 
--

CREATE INDEX docindex ON docrefs USING btree ("DocumentID");


--
-- Name: fromindex; Type: INDEX; Schema: public; Owner: evkk; Tablespace: 
--

CREATE INDEX fromindex ON aliases USING btree (fromword);


--
-- Name: langindex; Type: INDEX; Schema: public; Owner: evkk; Tablespace: 
--

CREATE INDEX langindex ON undecided USING btree ("language");


--
-- Name: toindex; Type: INDEX; Schema: public; Owner: evkk; Tablespace: 
--

CREATE INDEX toindex ON aliases USING btree (toword);


--
-- Name: windex; Type: INDEX; Schema: public; Owner: evkk; Tablespace: 
--

CREATE INDEX windex ON undecided USING btree (word);


--
-- Name: wordindex; Type: INDEX; Schema: public; Owner: evkk; Tablespace: 
--

CREATE INDEX wordindex ON words USING btree (word);


--
-- Name: wrdindex; Type: INDEX; Schema: public; Owner: evkk; Tablespace: 
--

CREATE INDEX wrdindex ON docrefs USING btree (word);


--
-- Name: wstatidx; Type: INDEX; Schema: public; Owner: evkk; Tablespace: 
--

CREATE INDEX wstatidx ON docrefs USING btree (wstat);


--
-- Name: word; Type: FK CONSTRAINT; Schema: public; Owner: evkk
--

ALTER TABLE ONLY aliases
    ADD CONSTRAINT word FOREIGN KEY ("WordID") REFERENCES words("ID");


--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- Name: docfreq; Type: ACL; Schema: public; Owner: evkk
--

REVOKE ALL ON TABLE docfreq FROM PUBLIC;
REVOKE ALL ON TABLE docfreq FROM evkk;
GRANT ALL ON TABLE docfreq TO evkk;
GRANT ALL ON TABLE docfreq TO postgres;
GRANT ALL ON TABLE docfreq TO PUBLIC;


--
-- PostgreSQL database dump complete
--

